(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[  95652975,    3016014]*)
(*NotebookOutlinePosition[  95740567,    3018739]*)
(*  CellTagsIndexPosition[  95728610,    3018380]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["7. Nonlinear Partial Differential Equations", "Title",
  CellTags->"c:1"],

Cell["", "Text"],

Cell["\<\
\tLinear partial  differential equations depend on only the first \
power of the unknown function. On the other hand, many natural phenomena \
require nonlinear partial differential equations for their description. These \
equations can depend on the unknown function in an arbitrary fashion, and \
consequently the principle of superposition no longer applies: the sum of two \
solutions to the homogenous PDE is no longer itself  a solution.  Therefore, \
the eigenmode and Fourier expansion methods developed previously for linear \
PDEs will not work on nonlinear PDEs. \
\>", "Text"],

Cell[TextData[{
  "\tGenerally, nonlinear PDEs require numerical methods for their solution. \
The Galerkin method and the grid methods discussed in Chapter ",
  ButtonBox["6",
    ButtonData:>{"Chapter6.nb", None},
    ButtonStyle->"Hyperlink"],
  " can still be applied, and we will see examples in this chapter. We will \
also examine an advanced simulation method, the particle-in-cell method, for \
the numerical solution of some classes of nonlinear PDEs."
}], "Text"],

Cell["\<\
\tFirst, however, we will discuss an analytic method that can be \
applied to solve first-order nonlinear PDEs: the method of characteristics. \
\
\>", "Text"],

Cell[CellGroupData[{

Cell["7.1 The Method of Characteristics for First-Order PDEs", "Subtitle",
  CellTags->{"i:1", "c:3"}],

Cell[" ", "Text"],

Cell[CellGroupData[{

Cell["7.1.1 Characteristics", "Subsubtitle",
  CellTags->{"i:15", "c:4"}],

Cell[TextData[{
  "Consider the following PDE for a function ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(f(x, t)\)\(:\)\)\)]]
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]f\/\[PartialD]t + \(v(x, t, 
              f)\) \[PartialD]f\/\[PartialD]x = s(x, t, f)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(7.1.1)"],

Cell["\<\
This equation is first-order in time, and so requires a single \
initial condition:\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`f(x, 0)\  = \ \(f\_o\)(x)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(7.1.2)"],

Cell[TextData[{
  "The equation is also first-order in space, and so in principle a single \
boundary condition could be imposed. However, this can lead to difficulties \
that are tangential to the discussion at hand.  In what follows, for \
simplicity we will solve the PDE on the entire real line without imposing \
boundary conditions, as we did in Chapter ",
  ButtonBox["5",
    ButtonData:>{"Chapter5.nb", None},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  "\tFirst-order PDEs of this sort arise in a number of different physical \
contexts. For example, the energy and wave action equations ",
  ButtonBox["(5.2.59)",
    ButtonData:>{"Chapter5.nb", "(5.2.59)"},
    ButtonStyle->"Hyperlink"],
  "  and ",
  ButtonBox["(5.3.23)",
    ButtonData:>{"Chapter5.nb", "(5.3.23)"},
    ButtonStyle->"Hyperlink"],
  "  describing wave-packet dynamics are of this general form.  We will also \
see that this equation and its generalizations describe dye in a fluid flow, \
nonlinear waves, ideal gases in an external force field, plasmas, and \
self-gravitating matter such as stars and galaxies. "
}], "Text"],

Cell[TextData[{
  "\tWe will solve Eq. ",
  ButtonBox["(7.1.1)",
    ButtonData:>{"Chapter7.nb", "(7.1.1)"},
    ButtonStyle->"Hyperlink"],
  "  using the method of characteristics, which is specially suited for PDEs \
of this form, and which works whether or not the PDE is linear in ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  ". In this method, by means of a coordinate transformation ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Rule] \ \ \(x\_o\)(x, t)\)]],
  " that takes us to a moving frame,  we convert the PDE into an ODE. The \
moving frame that we choose is one that moves with velocity ",
  Cell[BoxData[
      \(TraditionalForm\`v(x, t, f)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\t This is not a standard Galilean transformation, where the entire frame \
moves with the same velocity. Rather, the velocity varies from place to place \
and from time to time.  Because of this, it is best to think of the \
transformation in terms of an infinite number of moving observers, spread \
along the ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\)\(-\)\)\)]],
  "axis. Each observer moves along a trajectory ",
  Cell[BoxData[
      \(TraditionalForm\`x = x(t, \ x\_o)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`x\_o\)]],
  " is  the initial location of the observer:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(x = x\_o\)\)\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  ". "
}], "NumberedEquation",
  CellTags->"(7.1.3)"],

Cell[TextData[{
  "The trajectory ",
  Cell[BoxData[
      \(TraditionalForm\`x(t, x\_o)\)]],
  " of some given observer is called a ",
  StyleBox["characteristic.",
    FontSlant->"Italic"]
}], "Text",
  CellTags->"i:2"],

Cell[TextData[{
  "\tEach observer is responsible for recording the behavior of ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " at his or her own (moving) position.  Along this trajectory, ",
  Cell[BoxData[
      \(TraditionalForm\`f = f(x(t, x\_o), t)\)]],
  ". Taking a differential and applying the chain rule, we find that each \
observer sees a differential change in ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " given by"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]f\  = \(\[PartialD]f\/\[PartialD]t\) \
\[DifferentialD]t + \(\[PartialD]f\/\[PartialD]x\) \(\[DifferentialD]x\/\
\[DifferentialD]t\) \[DifferentialD]t\)]],
  ". "
}], "UNNEQ"],

Cell[TextData[{
  "If we now divide by ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]t\)]],
  " and substitute for ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]f/\[PartialD]t\)]],
  " from Eq. ",
  ButtonBox["(7.1.1)",
    ButtonData:>{"Chapter7.nb", "(7.1.1)"},
    ButtonStyle->"Hyperlink"],
  " , we obtain the following equation for the ",
  StyleBox["total time derivative ",
    FontSlant->"Italic"],
  "of ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " along the characteristic trajectory, ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]f/\[DifferentialD]t\)]],
  ":"
}], "Text",
  CellTags->"i:3"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]f\/\[DifferentialD]t = \
\(\[PartialD]f\/\[PartialD]x\) \[DifferentialD]x\/\[DifferentialD]t + 
          s\  - \ \(\(v\)\(\ \)\(\[PartialD]f\/\[PartialD]x\)\(\ \)\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(7.1.4)"],

Cell[TextData[{
  "This equation simplifies if we take  ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]x/\[DifferentialD]t\  = \ v\)]],
  ":"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[DifferentialD]f\/\[DifferentialD]t = \(\(s(x, t, 
          f)\)\(.\)\)\)]]], "NumberedEquation",
  CellTags->"(7.1.5)"],

Cell[TextData[{
  "With this choice the original PDE, Eq. ",
  ButtonBox["(7.1.1)",
    ButtonData:>{"Chapter7.nb", "(7.1.1)"},
    ButtonStyle->"Hyperlink"],
  " , is converted into an ODE involving the total rate of change of ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " as seen by an observer moving along the characteristic.  The \
characteristic itself is defined by the ODE"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]x\/\[DifferentialD]t = 
        v(x, t, f)\)]],
  ","
}], "NumberedEquation",
  CellTags->"(7.1.6)"],

Cell[TextData[{
  "with initial condition ",
  Cell[BoxData[
      \(TraditionalForm\`x = x\_o\)]],
  " at time ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  ". The solution to this ODE is our transformation ",
  Cell[BoxData[
      \(TraditionalForm\`x = x(t, x\_o)\)]],
  ", and we use this solution in solving Eq. ",
  ButtonBox["(7.1.5)",
    ButtonData:>{"Chapter7.nb", "(7.1.5)"},
    ButtonStyle->"Hyperlink"],
  "  for ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tBefore we go on to solve Eq. ",
  ButtonBox["(7.1.5)",
    ButtonData:>{"Chapter7.nb", "(7.1.5)"},
    ButtonStyle->"Hyperlink"],
  " , it is instructive to compare it with Eq. ",
  ButtonBox["(7.1.1)",
    ButtonData:>{"Chapter7.nb", "(7.1.1)"},
    ButtonStyle->"Hyperlink"],
  " . We can then  immediately make the following identification:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]f\/\[DifferentialD]t = \
\[PartialD]f\/\[PartialD]t + v \[PartialD]f\/\[PartialD]x\)]],
  "."
}], "NumberedEquation",
  CellTags->"(7.1.7)"],

Cell[TextData[{
  "The total rate of change of ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " as seen by the moving observer consists of two terms. The origin of the \
first term, ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]f/\[PartialD]t\)]],
  ", is obvious. This term would occur even if the observer were stationary.  \
The second term,  ",
  Cell[BoxData[
      \(TraditionalForm\`v\ \[PartialD]f/\[PartialD]x\)]],
  ", would occur even if ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " were not a function of time. This term arises because  the observer sees \
a change in ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " due to his or her own motion at velocity ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tThere is another useful way to write the total derivative ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]f/\[DifferentialD]t\)]],
  ". Since ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\)\(=\)\(x(t, x\_o)\)\(\ \)\)\)]],
  " defines a transformation from coordinate ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`x\_o\)]],
  ", we could write ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " in terms of ",
  Cell[BoxData[
      \(TraditionalForm\`x\_o\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " rather than ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ". If we now consider a general variation of ",
  Cell[BoxData[
      \(TraditionalForm\`f(x\_o, t)\)]],
  ", as ",
  Cell[BoxData[
      \(TraditionalForm\`x\_o\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " are varied by infinitesimal amounts, we obtain the differential relation"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]f = \[PartialD]f\/\[PartialD]t\( | \
\_\(x\_o\)\)\[DifferentialD]t + \[PartialD]f\/\[PartialD]x\_o\( | \_t\)\ \
\[DifferentialD]x\_o\)]],
  ". "
}], "NumberedEquation",
  CellTags->"(7.1.8)"],

Cell[TextData[{
  "However, a given characteristic is defined by a single initial condition \
",
  Cell[BoxData[
      \(TraditionalForm\`x\_o\)]],
  "that does not vary, so ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]x\_o = 0\)]],
  " along the characteristic. Dividing through by ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]t\)]],
  ", we then obtain"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[DifferentialD]f\/\[DifferentialD]t = \
\(\(\[PartialD]f\/\[PartialD]t\)\( | \_\(x\_o\)\)\)\)]]], "NumberedEquation",
  CellTags->"(7.1.9)"],

Cell[TextData[{
  "Since the initial condition ",
  Cell[BoxData[
      \(TraditionalForm\`x\_o\)]],
  " is a fixed parameter of the characteristic, it should hardly  be \
surprising that the total time derivative along a characteristic is the same \
as a partial derivative, holding ",
  Cell[BoxData[
      \(TraditionalForm\`x\_o\)]],
  " fixed.  "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["7.1.2 Linear Cases", "Subsubtitle",
  CellTags->"c:5"],

Cell[TextData[{
  "\tWe now turn to the solution of Eqs. ",
  ButtonBox["(7.1.5)",
    ButtonData:>{"Chapter7.nb", "(7.1.5)"},
    ButtonStyle->"Hyperlink"],
  "  and ",
  ButtonBox["(7.1.6)",
    ButtonData:>{"Chapter7.nb", "(7.1.6)"},
    ButtonStyle->"Hyperlink"],
  " . These are coupled first-order ODEs. It is easiest to understand the \
solution  to these ODEs by first considering a linear case, where ",
  Cell[BoxData[
      \(TraditionalForm\`s = s(x, t)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`v = v(x, t)\)]],
  ". Then Eqs. ",
  ButtonBox["(7.1.5)",
    ButtonData:>{"Chapter7.nb", "(7.1.5)"},
    ButtonStyle->"Hyperlink"],
  "  and ",
  ButtonBox["(7.1.6)",
    ButtonData:>{"Chapter7.nb", "(7.1.6)"},
    ButtonStyle->"Hyperlink"],
  "  become"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\(\[DifferentialD]f/\[DifferentialD]t = 
      s(x, t)\)\(,\)\)\)]]], "NumberedEquation",
  CellTags->"(7.1.10)"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[DifferentialD]x/\[DifferentialD]t\  = \ \(\(v(x, 
          t)\)\(.\)\)\)]]], "NumberedEquation",
  CellTags->"(7.1.11)"],

Cell[TextData[{
  "\tWe first solve Eq. ",
  ButtonBox["(7.1.11)",
    ButtonData:>{"Chapter7.nb", "(7.1.11)"},
    ButtonStyle->"Hyperlink"],
  "  for the characteristics.  This is a first",
  "-order",
  " ODE with initial condition ",
  Cell[BoxData[
      \(TraditionalForm\`x = x\_o\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  ". We  write the solution as ",
  Cell[BoxData[
      \(TraditionalForm\`x = x(t, x\_o)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tNext, we use these characteristics in solving Eq. ",
  ButtonBox["(7.1.10)",
    ButtonData:>{"Chapter7.nb", "(7.1.10)"},
    ButtonStyle->"Hyperlink"],
  "  for ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, t)\)]],
  ". Here, it must be remembered that  ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]f/\[DifferentialD]t\)]],
  " is the ",
  StyleBox["total",
    FontSlant->"Italic"],
  " rate of change, as seen by the moving observer. Thus, ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " varies in time as ",
  Cell[BoxData[
      \(TraditionalForm\`x(t, x\_o)\)]],
  " along the characteristic, and ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  " varies in time as  ",
  Cell[BoxData[
      \(TraditionalForm\`s(x(t, x\_o), t)\)]],
  ". The solution to ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]f/\[DifferentialD]t = s\)]],
  "  is therefore"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`f(t) = 
        f(0)\  + \ \[Integral]\_0\%t\( s(x(t\^\[Prime], x\_o), 
                t\^\[Prime])\) \[DifferentialD]t\^\[Prime]\)]],
  ", "
}], "NumberedEquation",
  CellTags->"(7.1.12)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`f(0) = \(f\_o\)(x\_o)\)]],
  " is the initial value for ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " at position ",
  Cell[BoxData[
      \(TraditionalForm\`x\_o\)]],
  ", and where ",
  Cell[BoxData[
      \(TraditionalForm\`f(
          t) = \(\(f(x, t)\)\( | \_\(x = x(t, x\_o)\)\)\)\)]],
  " is the value of ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " on the characteristic at time ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tThe ",
  "right-hand",
  " side is written in terms of  ",
  Cell[BoxData[
      \(TraditionalForm\`x\_o\)]],
  " rather than ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ", so we must invert ",
  Cell[BoxData[
      \(TraditionalForm\`x = x(t, x\_o)\)]],
  " to obtain ",
  Cell[BoxData[
      \(TraditionalForm\`x\_o = \(x\_o\)(x, t)\)]],
  ". Using this equation in Eq. ",
  ButtonBox["(7.1.12)",
    ButtonData:>{"Chapter7.nb", "(7.1.12)"},
    ButtonStyle->"Hyperlink"],
  "  yields "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`f(x, 
          t) = \(\(\(f\_o\)(\(x\_o\)(x, 
                t))\  + \ \[Integral]\_0\%t\( s(x(t\^\[Prime], x\_o), 
                  t\^\[Prime])\) \[DifferentialD]t\^\[Prime]\)\( | \_\(x\_o = \
\(x\_o\)(x, t)\)\)\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(7.1.13)"],

Cell[TextData[{
  "This is our solution for ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  ", written explicitly as a function of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ".  In order to clarify the meaning of this result, we consider several \
examples below. Other examples can be found in the exercises."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  "Example 1:  ",
  Cell[BoxData[
      \(TraditionalForm\`s = 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`v(x, t, f) = c\)]]
}], "Section",
  CellTags->"c:6"],

Cell[TextData[{
  "Now Eq. ",
  ButtonBox["(7.1.1)",
    ButtonData:>{"Chapter7.nb", "(7.1.1)"},
    ButtonStyle->"Hyperlink"],
  "  is "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]f\/\[PartialD]t + \ 
          c\ \[PartialD]f\/\[PartialD]x = 0\)]],
  "."
}], "NumberedEquation",
  CellTags->"(7.1.14)"],

Cell[TextData[{
  "We will see that the solutions to this equation are like those to the wave \
equation, except that propagation is now only in one direction. The solution \
is obtained using Eqs. ",
  ButtonBox["(7.1.5)",
    ButtonData:>{"Chapter7.nb", "(7.1.5)"},
    ButtonStyle->"Hyperlink"],
  "  and ",
  ButtonBox["(7.1.6)",
    ButtonData:>{"Chapter7.nb", "(7.1.6)"},
    ButtonStyle->"Hyperlink"],
  " : "
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[DifferentialD]f/\[DifferentialD]t = 
      0, \[IndentingNewLine]\[DifferentialD]x/\[DifferentialD]t\  = \ \(\(c\)\
\(.\)\)\)]]], "UNNEQ"],

Cell[TextData[{
  "The solution to ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]x/\[DifferentialD]t\  = \ c\)]],
  " with initial condition ",
  Cell[BoxData[
      \(TraditionalForm\`x = x\_o\)]],
  " is ",
  Cell[BoxData[
      \(TraditionalForm\`x = x\_o\  + \ c\ t\)]],
  ".  These straight parallel lines are the characteristics for the PDE for \
this example, and are shown for three initial positions ",
  Cell[BoxData[
      \(TraditionalForm\`x\_o\)]],
  " in Fig. ",
  ButtonBox["7.1",
    ButtonData:>"Fig. 7.1",
    ButtonStyle->"Hyperlink"],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tThe equation ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]f/\[DifferentialD]t = 0\)]],
  " implies that ",
  Cell[BoxData[
      \(TraditionalForm\`f = constant\)]],
  " along these characteristics; that is,  along each characteristic the \
value of ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " remains unchanged from its initial value. For the characteristic starting \
at ",
  Cell[BoxData[
      \(TraditionalForm\`x = x\_o\)]],
  ", this value is ",
  Cell[BoxData[
      \(TraditionalForm\`f = \(f\_o\)(x\_o)\)]],
  ", according to Eq. ",
  ButtonBox["(7.1.2)",
    ButtonData:>{"Chapter7.nb", "(7.1.2)"},
    ButtonStyle->"Hyperlink"],
  " . Therefore, the solution for ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " is"
}], "Text"],

Cell[TextData[{
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`f(t)\  = \ \(f\_o\)(x\_o)\)], "NumberedEquation"], 
    "NumberedEquation"],
  StyleBox[",", "NumberedEquation"]
}], "NumberedEquation",
  CellTags->"(7.1.15)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`f(
          t) = \(\(f(x, t)\)\( | \_\(x = x\_o + \ c\ t\)\)\)\)]],
  " is the value of ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " at time ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ", evaluated along the characteristic."
}], "Text"],

Cell[TextData[{
  "\tThis equation could equally well have been obtained by using Eq.  ",
  ButtonBox["(7.1.9)",
    ButtonData:>{"Chapter7.nb", "(7.1.9)"},
    ButtonStyle->"Hyperlink"],
  " , which when combined with ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]f/\[DifferentialD]t = 0\)]],
  " yields\n \t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[PartialD]f/\[PartialD]t\)\( | \_\(x\_o\)\)\) = 
        0\)]],
  ". \n The solution to this equation is clearly any function ",
  Cell[BoxData[
      \(TraditionalForm\`f(x\_o)\)]],
  ", since any such function can be differentiated with respect to ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " (holding ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\_o\)\(\ \)\)\)]],
  "fixed) to yield zero.  To satisfy the initial condition, Eq. ",
  ButtonBox["(7.1.2)",
    ButtonData:>{"Chapter7.nb", "(7.1.2)"},
    ButtonStyle->"Hyperlink"],
  " , we require that ",
  Cell[BoxData[
      \(TraditionalForm\`f(x\_o) = \(f\_o\)(x\_o)\)]],
  " (because ",
  Cell[BoxData[
      \(TraditionalForm\`x = x\_o\)]],
  "at ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  "), and so we return to Eq. ",
  ButtonBox["(7.1.15)",
    ButtonData:>{"Chapter7.nb", "(7.1.15)"},
    ButtonStyle->"Hyperlink"],
  " ."
}], "Text"],

Cell[TextData[{
  "\t  To finish the solution, we now invert the characteristic equation ",
  Cell[BoxData[
      \(TraditionalForm\`x = x\_o + \ c\ t\)]],
  " to obtain ",
  Cell[BoxData[
      \(TraditionalForm\`x\_o = x\  - \ c\ t\)]],
  ". Substituting into Eq. ",
  ButtonBox["(7.1.14)",
    ButtonData:>{"Chapter7.nb", "(7.1.14)"},
    ButtonStyle->"Hyperlink"],
  "  yields"
}], "Text"],

Cell[TextData[{
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`f(x, t)\  = \ \(f\_o\)(x - c\ t)\)], 
    "NumberedEquation"], "NumberedEquation"],
  StyleBox[".", "NumberedEquation"]
}], "UNNEQ"],

Cell[TextData[{
  "This solution is simply a disturbance that moves at velocity ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " without varying from its initial shape ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_o\)(x)\)]],
  ". One can verify that this is the solution to Eq. ",
  ButtonBox["(7.1.14)",
    ButtonData:>{"Chapter7.nb", "(7.1.14)"},
    ButtonStyle->"Hyperlink"],
  "  by direct substitution:"
}], "Text",
  CellTags->"i:78"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[
      D[f[x, t], t]\  + \ c\ D[f[x, t], x] \[Equal] 0\  /. 
        f \[Rule] Function[{x, t}, f0[x\  - \ c\ t]]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.1"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This form of  the solution is similar to d'Alembert's solution for the \
wave equation, Eq. ",
  ButtonBox["(5.1.11)",
    ButtonData:>{"Chapter5.nb", "(5.1.11)"},
    ButtonStyle->"Hyperlink"],
  " . Here, however, the disturbance moves only in one direction, because ",
  ButtonBox["(7.1.1)",
    ButtonData:>{"Chapter7.nb", "(7.1.1)"},
    ButtonStyle->"Hyperlink"],
  "  is first-order rather than second-order  in time and space. The shape of \
the disturbance does not change, because ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " does not vary along each characteristic, and because the characteristics \
are  parallel lines. Thus, the entire solution is transported without change \
along the characteristics, as depicted in Fig. ",
  ButtonBox["7.1",
    ButtonData:>"Fig. 7.1",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .8808 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.08149 -0.0489684 1.08149 [
[.18494 .02919 -9.4794 -12 ]
[.18494 .02919 .5206 0 ]
[.83708 .32929 0 -7.96501 ]
[.83708 .32929 10 4.03499 ]
[-0.06873 .27044 -58 -3.77786 ]
[-0.06873 .27044 0 8.22214 ]
[ 0 0 0 0 ]
[ 1 .8808 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01448 .17452 m
.47602 0 L
s
gsave
.18494 .02919 -70.4794 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.47602 0 m
.98951 .64108 L
s
gsave
.83708 .32929 -61 -11.965 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.01448 .17452 m
0 .31187 L
s
gsave
-0.06873 .27044 -119 -7.77786 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(H) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
105.000 13.000 moveto
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
111.000 13.000 moveto
(L) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.01448 .17452 m
0 .31187 L
s
0 .31187 m
.59195 .8808 L
s
.59195 .8808 m
.59083 .75623 L
s
.59083 .75623 m
.01448 .17452 L
s
.47602 0 m
.98951 .64108 L
s
.98951 .64108 m
1 .76863 L
s
1 .76863 m
.47414 .14006 L
s
.47414 .14006 m
.47602 0 L
s
.01448 .17452 m
0 .31187 L
s
0 .31187 m
.47414 .14006 L
s
.47414 .14006 m
.47602 0 L
s
.47602 0 m
.01448 .17452 L
s
.59083 .75623 m
.98951 .64108 L
s
.98951 .64108 m
1 .76863 L
s
1 .76863 m
.59195 .8808 L
s
.59195 .8808 m
.59083 .75623 L
s
0 0 m
1 0 L
1 .8808 L
0 .8808 L
closepath
clip
newpath
.5 Mabswid
.96219 .63323 m
.96988 .63455 L
s
.015 w
.967 .63341 m
.97005 .63673 L
s
.5 Mabswid
.95449 .63191 m
.96219 .63323 L
s
.94678 .63059 m
.95449 .63191 L
s
.93907 .62926 m
.94678 .63059 L
s
.015 w
.96394 .63018 m
.967 .63341 L
s
.5 Mabswid
.93134 .62794 m
.93907 .62926 L
s
.92361 .62662 m
.93134 .62794 L
s
.91587 .62529 m
.92361 .62662 L
s
.90813 .62396 m
.91587 .62529 L
s
.015 w
.96088 .62707 m
.96394 .63018 L
s
.5 Mabswid
.90037 .62263 m
.90813 .62396 L
s
.89261 .6213 m
.90037 .62263 L
s
.88484 .61997 m
.89261 .6213 L
s
.015 w
.95782 .62408 m
.96088 .62707 L
s
.5 Mabswid
.87707 .61864 m
.88484 .61997 L
s
.86928 .6173 m
.87707 .61864 L
s
.86149 .61596 m
.86928 .6173 L
s
.015 w
.95477 .62124 m
.95782 .62408 L
s
.5 Mabswid
.85369 .61463 m
.86149 .61596 L
s
.84589 .61329 m
.85369 .61463 L
s
.83807 .61195 m
.84589 .61329 L
s
.015 w
.95172 .61856 m
.95477 .62124 L
s
.5 Mabswid
.83025 .61061 m
.83807 .61195 L
s
.82242 .60927 m
.83025 .61061 L
s
.81458 .60792 m
.82242 .60927 L
s
.80674 .60658 m
.81458 .60792 L
s
.015 w
.94867 .61607 m
.95172 .61856 L
s
.5 Mabswid
.79889 .60523 m
.80674 .60658 L
s
.79103 .60388 m
.79889 .60523 L
s
.78316 .60253 m
.79103 .60388 L
s
.015 w
.94563 .61379 m
.94867 .61607 L
s
.5 Mabswid
.77528 .60118 m
.78316 .60253 L
s
.7674 .59983 m
.77528 .60118 L
s
.015 w
.77461 .60042 m
.778 .60383 L
s
.5 Mabswid
.75951 .59848 m
.7674 .59983 L
s
.75161 .59712 m
.75951 .59848 L
s
.015 w
.94259 .61174 m
.94563 .61379 L
s
.5 Mabswid
.7437 .59577 m
.75161 .59712 L
s
.015 w
.77122 .5971 m
.77461 .60042 L
s
.5 Mabswid
.73578 .59441 m
.7437 .59577 L
s
.72786 .59305 m
.73578 .59441 L
s
.015 w
.93956 .60993 m
.94259 .61174 L
s
.5 Mabswid
.71993 .59169 m
.72786 .59305 L
s
.015 w
.76782 .59389 m
.77122 .5971 L
s
.5 Mabswid
.71199 .59033 m
.71993 .59169 L
s
.70405 .58897 m
.71199 .59033 L
s
.69609 .58761 m
.70405 .58897 L
s
.015 w
.93655 .60839 m
.93956 .60993 L
s
.76441 .59082 m
.76782 .59389 L
s
.5 Mabswid
.68813 .58624 m
.69609 .58761 L
s
.68016 .58487 m
.68813 .58624 L
s
.67218 .58351 m
.68016 .58487 L
s
.6642 .58214 m
.67218 .58351 L
s
.015 w
.76101 .58789 m
.76441 .59082 L
s
.93354 .60713 m
.93655 .60839 L
s
.5 Mabswid
.6562 .58077 m
.6642 .58214 L
s
.6482 .57939 m
.6562 .58077 L
s
.64019 .57802 m
.6482 .57939 L
s
.015 w
.75759 .58512 m
.76101 .58789 L
s
.5 Mabswid
.63217 .57665 m
.64019 .57802 L
s
.015 w
.93054 .60617 m
.93354 .60713 L
s
.5 Mabswid
.62415 .57527 m
.63217 .57665 L
s
.61611 .57389 m
.62415 .57527 L
s
.015 w
.75417 .58254 m
.75759 .58512 L
s
.5 Mabswid
.60807 .57251 m
.61611 .57389 L
s
.60002 .57113 m
.60807 .57251 L
s
.015 w
.92755 .60552 m
.93054 .60617 L
s
.5 Mabswid
.59196 .56975 m
.60002 .57113 L
s
.5839 .56837 m
.59196 .56975 L
s
.015 w
.75075 .58017 m
.75417 .58254 L
s
.5 Mabswid
.57582 .56699 m
.5839 .56837 L
s
.56774 .5656 m
.57582 .56699 L
s
.015 w
.57749 .56661 m
.58122 .57012 L
s
.92457 .60518 m
.92755 .60552 L
s
.5 Mabswid
.55965 .56421 m
.56774 .5656 L
s
.015 w
.74733 .57803 m
.75075 .58017 L
s
.5 Mabswid
.55156 .56282 m
.55965 .56421 L
s
.54345 .56143 m
.55156 .56282 L
s
.015 w
.57374 .5632 m
.57749 .56661 L
s
.5 Mabswid
.53534 .56004 m
.54345 .56143 L
s
.015 w
.9216 .60516 m
.92457 .60518 L
s
.5 Mabswid
.52721 .55865 m
.53534 .56004 L
s
.015 w
.7439 .57614 m
.74733 .57803 L
s
.5 Mabswid
.51908 .55726 m
.52721 .55865 L
s
.015 w
.56998 .5599 m
.57374 .5632 L
s
.5 Mabswid
.51094 .55586 m
.51908 .55726 L
s
.5028 .55446 m
.51094 .55586 L
s
.015 w
.91864 .60545 m
.9216 .60516 L
s
.5 Mabswid
.49464 .55307 m
.5028 .55446 L
s
.015 w
.74047 .57452 m
.7439 .57614 L
s
.56622 .55673 m
.56998 .5599 L
s
.5 Mabswid
.48648 .55167 m
.49464 .55307 L
s
.47831 .55027 m
.48648 .55167 L
s
.47013 .54886 m
.47831 .55027 L
s
.015 w
.56243 .55371 m
.56622 .55673 L
s
.73704 .57318 m
.74047 .57452 L
s
.5 Mabswid
.46194 .54746 m
.47013 .54886 L
s
.015 w
.91569 .60603 m
.91864 .60545 L
s
.5 Mabswid
.45374 .54605 m
.46194 .54746 L
s
.44554 .54465 m
.45374 .54605 L
s
.43733 .54324 m
.44554 .54465 L
s
.015 w
.55864 .55085 m
.56243 .55371 L
s
.73361 .57214 m
.73704 .57318 L
s
.5 Mabswid
.42911 .54183 m
.43733 .54324 L
s
.015 w
.91274 .60689 m
.91569 .60603 L
s
.5 Mabswid
.42088 .54042 m
.42911 .54183 L
s
.41264 .53901 m
.42088 .54042 L
s
.015 w
.55484 .54818 m
.55864 .55085 L
s
.5 Mabswid
.4044 .53759 m
.41264 .53901 L
s
.015 w
.73017 .57141 m
.73361 .57214 L
s
.5 Mabswid
.39614 .53618 m
.4044 .53759 L
s
.38788 .53476 m
.39614 .53618 L
s
.015 w
.9098 .60801 m
.91274 .60689 L
s
.55102 .54572 m
.55484 .54818 L
s
.5 Mabswid
.37961 .53334 m
.38788 .53476 L
s
.015 w
.37544 .53196 m
.37954 .53556 L
s
.72673 .57099 m
.73017 .57141 L
s
.54719 .54349 m
.55102 .54572 L
s
.90685 .60934 m
.9098 .60801 L
s
.37133 .52845 m
.37544 .53196 L
s
.72329 .57089 m
.72673 .57099 L
s
.54334 .54151 m
.54719 .54349 L
s
.36719 .52506 m
.37133 .52845 L
s
.9039 .61086 m
.90685 .60934 L
s
.71984 .5711 m
.72329 .57089 L
s
.53948 .5398 m
.54334 .54151 L
s
.36304 .52179 m
.36719 .52506 L
s
.90095 .61249 m
.9039 .61086 L
s
.35887 .51867 m
.36304 .52179 L
s
.53561 .53837 m
.53948 .5398 L
s
.71638 .57162 m
.71984 .5711 L
s
.35468 .51571 m
.35887 .51867 L
s
.53172 .53725 m
.53561 .53837 L
s
.89798 .61419 m
.90095 .61249 L
s
.71292 .57241 m
.71638 .57162 L
s
.35047 .51295 m
.35468 .51571 L
s
.52781 .53644 m
.53172 .53725 L
s
.895 .6159 m
.89798 .61419 L
s
.70944 .57345 m
.71292 .57241 L
s
.34624 .51039 m
.35047 .51295 L
s
.52388 .53594 m
.52781 .53644 L
s
.34198 .50807 m
.34624 .51039 L
s
.70596 .57472 m
.70944 .57345 L
s
.892 .61754 m
.895 .6159 L
s
.51994 .53576 m
.52388 .53594 L
s
.3377 .506 m
.34198 .50807 L
s
.70247 .57616 m
.70596 .57472 L
s
.88897 .61903 m
.892 .61754 L
s
0 1 0 r
.5 Mabswid
.84914 .4848 m
.84924 .48645 L
s
0 g
.84096 .48333 m
.84914 .4848 L
s
.015 w
.51598 .53589 m
.51994 .53576 L
s
0 1 0 r
.5 Mabswid
.84924 .48645 m
.84933 .4881 L
s
0 g
.015 w
.33338 .5042 m
.3377 .506 L
s
.5 Mabswid
.83277 .48186 m
.84096 .48333 L
s
0 1 0 r
.84933 .4881 m
.84943 .48976 L
s
.84943 .48976 m
.84952 .49141 L
s
0 g
.82457 .48039 m
.83277 .48186 L
s
0 1 0 r
.84952 .49141 m
.84962 .49307 L
s
0 g
.81637 .47891 m
.82457 .48039 L
s
0 1 0 r
.84962 .49307 m
.84972 .49472 L
s
.84972 .49472 m
.84981 .49638 L
s
0 g
.80815 .47744 m
.81637 .47891 L
s
0 1 0 r
.84981 .49638 m
.84991 .49804 L
s
0 g
.015 w
.69896 .57773 m
.70247 .57616 L
s
.88592 .62031 m
.88897 .61903 L
s
.32904 .50268 m
.33338 .5042 L
s
0 1 0 r
.5 Mabswid
.84991 .49804 m
.85001 .4997 L
s
0 g
.79993 .47596 m
.80815 .47744 L
s
.015 w
.51199 .53633 m
.51598 .53589 L
s
0 1 0 r
.5 Mabswid
.85001 .4997 m
.8501 .50136 L
s
0 g
.7917 .47448 m
.79993 .47596 L
s
0 1 0 r
.8501 .50136 m
.8502 .50302 L
s
.8502 .50302 m
.8503 .50468 L
s
0 g
.78346 .473 m
.7917 .47448 L
s
0 1 0 r
.8503 .50468 m
.85039 .50635 L
s
.85039 .50635 m
.85049 .50801 L
s
0 g
.77521 .47152 m
.78346 .473 L
s
0 1 0 r
.85049 .50801 m
.85059 .50968 L
s
0 g
.015 w
.32467 .50147 m
.32904 .50268 L
s
.5 Mabswid
.76695 .47004 m
.77521 .47152 L
s
0 1 0 r
.85059 .50968 m
.85068 .51135 L
s
0 g
.015 w
.88282 .62128 m
.88592 .62031 L
s
.69543 .57936 m
.69896 .57773 L
s
.50799 .53704 m
.51199 .53633 L
s
0 1 0 r
.5 Mabswid
.85068 .51135 m
.85078 .51302 L
s
0 g
.75869 .46856 m
.76695 .47004 L
s
0 1 0 r
.85078 .51302 m
.85088 .51468 L
s
.85088 .51468 m
.85097 .51635 L
s
0 g
.75041 .46707 m
.75869 .46856 L
s
0 1 0 r
.85097 .51635 m
.85107 .51803 L
s
0 g
.74213 .46558 m
.75041 .46707 L
s
0 1 0 r
.85107 .51803 m
.85117 .5197 L
s
0 g
.015 w
.32027 .50057 m
.32467 .50147 L
s
0 1 0 r
.5 Mabswid
.85117 .5197 m
.85127 .52137 L
s
0 g
.73384 .46409 m
.74213 .46558 L
s
0 1 0 r
.85127 .52137 m
.85136 .52305 L
s
0 g
.015 w
.87969 .62188 m
.88282 .62128 L
s
0 1 0 r
.5 Mabswid
.85136 .52305 m
.85146 .52472 L
s
0 g
.72554 .4626 m
.73384 .46409 L
s
.015 w
.69189 .581 m
.69543 .57936 L
s
.50396 .53801 m
.50799 .53704 L
s
0 1 0 r
.5 Mabswid
.85146 .52472 m
.85156 .5264 L
s
0 g
.71723 .46111 m
.72554 .4626 L
s
0 1 0 r
.85156 .5264 m
.85166 .52808 L
s
.85166 .52808 m
.85175 .52975 L
s
0 g
.70891 .45962 m
.71723 .46111 L
s
0 1 0 r
.85175 .52975 m
.85185 .53143 L
s
0 g
.015 w
.31584 .49998 m
.32027 .50057 L
s
0 1 0 r
.5 Mabswid
.85185 .53143 m
.85195 .53311 L
s
0 g
.70059 .45812 m
.70891 .45962 L
s
0 1 0 r
.85195 .53311 m
.85205 .5348 L
s
0 g
.69225 .45663 m
.70059 .45812 L
s
0 1 0 r
.85205 .5348 m
.85214 .53648 L
s
0 g
.015 w
.87652 .62202 m
.87969 .62188 L
s
0 1 0 r
.5 Mabswid
.85214 .53648 m
.85224 .53816 L
s
0 g
.68391 .45513 m
.69225 .45663 L
s
.015 w
.49992 .53921 m
.50396 .53801 L
s
.68833 .58257 m
.69189 .581 L
s
0 1 0 r
.5 Mabswid
.85224 .53816 m
.85234 .53985 L
s
0 g
.67556 .45363 m
.68391 .45513 L
s
0 1 0 r
.85234 .53985 m
.85244 .54153 L
s
.85244 .54153 m
.85254 .54322 L
s
0 g
.015 w
.31137 .49972 m
.31584 .49998 L
s
.5 Mabswid
.6672 .45213 m
.67556 .45363 L
s
0 1 0 r
.85254 .54322 m
.85263 .54491 L
s
.85263 .54491 m
.85273 .5466 L
s
0 g
.65883 .45063 m
.6672 .45213 L
s
0 1 0 r
.85273 .5466 m
.85283 .54829 L
s
0 g
.015 w
.8733 .62163 m
.87652 .62202 L
s
.5 Mabswid
.65045 .44912 m
.65883 .45063 L
s
0 1 0 r
.85283 .54829 m
.85293 .54998 L
s
.85293 .54998 m
.85303 .55167 L
s
0 g
.64207 .44762 m
.65045 .44912 L
s
.015 w
.49585 .54057 m
.49992 .53921 L
s
.68474 .584 m
.68833 .58257 L
s
0 1 0 r
.5 Mabswid
.85303 .55167 m
.85313 .55337 L
s
.64486 .44812 m
.6449 .44978 L
s
.85313 .55337 m
.85323 .55506 L
s
0 g
.63367 .44611 m
.64207 .44762 L
s
.015 w
.30687 .49977 m
.31137 .49972 L
s
0 1 0 r
.5 Mabswid
.6449 .44978 m
.64493 .45144 L
s
.85323 .55506 m
.85332 .55676 L
s
.64493 .45144 m
.64496 .4531 L
s
0 g
.62527 .4446 m
.63367 .44611 L
s
0 1 0 r
.85332 .55676 m
.85342 .55845 L
s
.64496 .4531 m
.64499 .45477 L
s
.85342 .55845 m
.85352 .56015 L
s
0 g
.61685 .44309 m
.62527 .4446 L
s
0 1 0 r
.64499 .45477 m
.64503 .45643 L
s
0 g
.015 w
.87003 .62066 m
.8733 .62163 L
s
0 1 0 r
.5 Mabswid
.85352 .56015 m
.85362 .56185 L
s
.64503 .45643 m
.64506 .4581 L
s
.85362 .56185 m
.85372 .56355 L
s
0 g
.60843 .44158 m
.61685 .44309 L
s
0 1 0 r
.64506 .4581 m
.64509 .45977 L
s
.85372 .56355 m
.85382 .56525 L
s
.64509 .45977 m
.64513 .46144 L
s
0 g
.015 w
.49176 .54207 m
.49585 .54057 L
s
.5 Mabswid
.6 .44006 m
.60843 .44158 L
s
.015 w
.68113 .5852 m
.68474 .584 L
s
0 1 0 r
.5 Mabswid
.85382 .56525 m
.85392 .56695 L
s
.64513 .46144 m
.64516 .46311 L
s
.85392 .56695 m
.85402 .56866 L
s
0 g
.015 w
.30233 .50012 m
.30687 .49977 L
s
.5 Mabswid
.59156 .43855 m
.6 .44006 L
s
0 1 0 r
.64516 .46311 m
.64519 .46478 L
s
.85402 .56866 m
.85411 .57036 L
s
.64519 .46478 m
.64523 .46645 L
s
.85411 .57036 m
.85421 .57207 L
s
0 g
.58312 .43703 m
.59156 .43855 L
s
.015 w
.86671 .61903 m
.87003 .62066 L
s
0 1 0 r
.5 Mabswid
.64523 .46645 m
.64526 .46812 L
s
.85421 .57207 m
.85431 .57377 L
s
.64526 .46812 m
.64529 .4698 L
s
0 g
.57466 .43551 m
.58312 .43703 L
s
0 1 0 r
.85431 .57377 m
.85441 .57548 L
s
.64529 .4698 m
.64532 .47147 L
s
.85441 .57548 m
.85451 .57719 L
s
0 g
.56619 .43399 m
.57466 .43551 L
s
0 1 0 r
.64532 .47147 m
.64536 .47315 L
s
.85451 .57719 m
.85461 .5789 L
s
.64536 .47315 m
.64539 .47482 L
s
0 g
.015 w
.67749 .5861 m
.68113 .5852 L
s
.48765 .54363 m
.49176 .54207 L
s
0 1 0 r
.5 Mabswid
.85461 .5789 m
.85471 .58061 L
s
0 g
.55772 .43247 m
.56619 .43399 L
s
.015 w
.29776 .50076 m
.30233 .50012 L
s
0 1 0 r
.5 Mabswid
.64539 .47482 m
.64542 .4765 L
s
.85471 .58061 m
.85481 .58232 L
s
0 g
.015 w
.86333 .61671 m
.86671 .61903 L
s
0 1 0 r
.5 Mabswid
.64542 .4765 m
.64546 .47818 L
s
0 g
.54924 .43095 m
.55772 .43247 L
s
0 1 0 r
.85481 .58232 m
.85491 .58403 L
s
.64546 .47818 m
.64549 .47986 L
s
.85491 .58403 m
.85501 .58575 L
s
0 g
.54075 .42942 m
.54924 .43095 L
s
0 1 0 r
.64549 .47986 m
.64552 .48154 L
s
.85501 .58575 m
.85511 .58746 L
s
.64552 .48154 m
.64556 .48322 L
s
.85511 .58746 m
.85521 .58918 L
s
0 g
.53224 .4279 m
.54075 .42942 L
s
0 1 0 r
.64556 .48322 m
.64559 .48491 L
s
.85521 .58918 m
.85531 .5909 L
s
0 g
.52373 .42637 m
.53224 .4279 L
s
0 1 0 r
.64559 .48491 m
.64562 .48659 L
s
.85531 .5909 m
.85541 .59261 L
s
0 g
.015 w
.8599 .61366 m
.86333 .61671 L
s
.67383 .58662 m
.67749 .5861 L
s
0 1 0 r
.5 Mabswid
.64562 .48659 m
.64566 .48828 L
s
.85541 .59261 m
.85551 .59433 L
s
0 g
.015 w
.48351 .5452 m
.48765 .54363 L
s
.5 Mabswid
.51522 .42484 m
.52373 .42637 L
s
.015 w
.29316 .50165 m
.29776 .50076 L
s
0 1 0 r
.5 Mabswid
.64566 .48828 m
.64569 .48996 L
s
.85551 .59433 m
.85561 .59605 L
s
.64569 .48996 m
.64572 .49165 L
s
0 g
.50669 .42331 m
.51522 .42484 L
s
0 1 0 r
.85561 .59605 m
.85571 .59778 L
s
.64572 .49165 m
.64576 .49334 L
s
.85571 .59778 m
.85581 .5995 L
s
0 g
.49815 .42177 m
.50669 .42331 L
s
0 1 0 r
.64576 .49334 m
.64579 .49503 L
s
.85581 .5995 m
.85591 .60122 L
s
.64579 .49503 m
.64582 .49672 L
s
0 g
.015 w
.85641 .60986 m
.8599 .61366 L
s
0 1 0 r
.5 Mabswid
.85591 .60122 m
.85601 .60295 L
s
0 g
.48961 .42024 m
.49815 .42177 L
s
0 1 0 r
.64582 .49672 m
.64586 .49841 L
s
.85601 .60295 m
.85611 .60467 L
s
.64586 .49841 m
.64589 .50011 L
s
0 g
.48105 .4187 m
.48961 .42024 L
s
0 1 0 r
.85611 .60467 m
.85621 .6064 L
s
0 g
.015 w
.67013 .58668 m
.67383 .58662 L
s
0 1 0 r
.5 Mabswid
.64589 .50011 m
.64592 .5018 L
s
.85621 .6064 m
.85631 .60813 L
s
0 g
.015 w
.28852 .50277 m
.29316 .50165 L
s
.47936 .5467 m
.48351 .5452 L
s
.5 Mabswid
.47249 .41717 m
.48105 .4187 L
s
0 1 0 r
.64592 .5018 m
.64596 .5035 L
s
.85631 .60813 m
.85641 .60986 L
s
.64596 .5035 m
.64599 .50519 L
s
0 g
.015 w
.85287 .6053 m
.85641 .60986 L
s
.5 Mabswid
.46392 .41563 m
.47249 .41717 L
s
0 1 0 r
.64599 .50519 m
.64602 .50689 L
s
.64602 .50689 m
.64606 .50859 L
s
0 g
.45533 .41409 m
.46392 .41563 L
s
0 1 0 r
.64606 .50859 m
.64609 .51029 L
s
0 g
.44674 .41254 m
.45533 .41409 L
s
0 1 0 r
.64609 .51029 m
.64613 .51199 L
s
0 g
.015 w
.66641 .58621 m
.67013 .58668 L
s
.84928 .59998 m
.85287 .6053 L
s
0 1 0 r
.5 Mabswid
.64613 .51199 m
.64616 .51369 L
s
0 g
.43814 .411 m
.44674 .41254 L
s
0 1 0 r
.64616 .51369 m
.64619 .51539 L
s
0 g
.015 w
.28385 .50406 m
.28852 .50277 L
s
.47518 .54805 m
.47936 .5467 L
s
0 1 0 r
.5 Mabswid
.64619 .51539 m
.64623 .5171 L
s
0 g
.42953 .40945 m
.43814 .411 L
s
0 1 0 r
.43527 .41048 m
.43524 .41215 L
s
.64623 .5171 m
.64626 .5188 L
s
.43524 .41215 m
.43521 .41383 L
s
0 g
.42092 .40791 m
.42953 .40945 L
s
0 1 0 r
.64626 .5188 m
.64629 .52051 L
s
0 g
.015 w
.84563 .59393 m
.84928 .59998 L
s
0 1 0 r
.5 Mabswid
.43521 .41383 m
.43517 .4155 L
s
.64629 .52051 m
.64633 .52222 L
s
0 g
.41229 .40636 m
.42092 .40791 L
s
0 1 0 r
.43517 .4155 m
.43514 .41717 L
s
.64633 .52222 m
.64636 .52392 L
s
.43514 .41717 m
.43511 .41885 L
s
0 g
.015 w
.66266 .58514 m
.66641 .58621 L
s
0 1 0 r
.5 Mabswid
.64636 .52392 m
.6464 .52563 L
s
0 g
.40365 .40481 m
.41229 .40636 L
s
0 1 0 r
.43511 .41885 m
.43507 .42052 L
s
0 g
.015 w
.84194 .58717 m
.84563 .59393 L
s
0 1 0 r
.5 Mabswid
.6464 .52563 m
.64643 .52734 L
s
.43507 .42052 m
.43504 .4222 L
s
0 g
.39501 .40325 m
.40365 .40481 L
s
0 1 0 r
.64643 .52734 m
.64646 .52906 L
s
.43504 .4222 m
.435 .42388 L
s
0 g
.015 w
.27915 .50548 m
.28385 .50406 L
s
.47099 .54917 m
.47518 .54805 L
s
0 1 0 r
.5 Mabswid
.64646 .52906 m
.6465 .53077 L
s
0 g
.38635 .4017 m
.39501 .40325 L
s
0 1 0 r
.435 .42388 m
.43497 .42556 L
s
.6465 .53077 m
.64653 .53248 L
s
0 g
.015 w
.83821 .57976 m
.84194 .58717 L
s
0 1 0 r
.5 Mabswid
.43497 .42556 m
.43494 .42724 L
s
.64653 .53248 m
.64656 .5342 L
s
0 g
.37769 .40014 m
.38635 .4017 L
s
0 1 0 r
.43494 .42724 m
.4349 .42892 L
s
.64656 .5342 m
.6466 .53591 L
s
0 g
.015 w
.65888 .58342 m
.66266 .58514 L
s
.5 Mabswid
.36902 .39859 m
.37769 .40014 L
s
0 1 0 r
.4349 .42892 m
.43487 .4306 L
s
.6466 .53591 m
.64663 .53763 L
s
0 g
.015 w
.83444 .57173 m
.83821 .57976 L
s
0 1 0 r
.5 Mabswid
.43487 .4306 m
.43483 .43229 L
s
.64663 .53763 m
.64667 .53935 L
s
0 g
.36034 .39703 m
.36902 .39859 L
s
0 1 0 r
.43483 .43229 m
.4348 .43397 L
s
.64667 .53935 m
.6467 .54107 L
s
.4348 .43397 m
.43477 .43566 L
s
0 g
.015 w
.83063 .56317 m
.83444 .57173 L
s
.5 Mabswid
.35164 .39547 m
.36034 .39703 L
s
0 1 0 r
.6467 .54107 m
.64673 .54279 L
s
.43477 .43566 m
.43473 .43734 L
s
0 g
.015 w
.46678 .55 m
.47099 .54917 L
s
.27442 .50697 m
.27915 .50548 L
s
0 1 0 r
.5 Mabswid
.64673 .54279 m
.64677 .54451 L
s
0 g
.34294 .3939 m
.35164 .39547 L
s
0 1 0 r
.43473 .43734 m
.4347 .43903 L
s
.64677 .54451 m
.6468 .54623 L
s
0 g
.015 w
.82679 .55412 m
.83063 .56317 L
s
.65506 .58101 m
.65888 .58342 L
s
0 1 0 r
.5 Mabswid
.4347 .43903 m
.43466 .44072 L
s
.6468 .54623 m
.64684 .54796 L
s
0 g
.33423 .39234 m
.34294 .3939 L
s
0 1 0 r
.43466 .44072 m
.43463 .44241 L
s
.64684 .54796 m
.64687 .54968 L
s
0 g
.015 w
.82292 .54468 m
.82679 .55412 L
s
0 1 0 r
.5 Mabswid
.43463 .44241 m
.4346 .4441 L
s
0 g
.32552 .39078 m
.33423 .39234 L
s
0 1 0 r
.64687 .54968 m
.6469 .55141 L
s
.4346 .4441 m
.43456 .4458 L
s
0 g
.015 w
.81904 .53492 m
.82292 .54468 L
s
0 1 0 r
.5 Mabswid
.6469 .55141 m
.64694 .55313 L
s
0 g
.31679 .38921 m
.32552 .39078 L
s
0 1 0 r
.43456 .4458 m
.43453 .44749 L
s
.64694 .55313 m
.64697 .55486 L
s
0 g
.015 w
.81514 .52492 m
.81904 .53492 L
s
0 1 0 r
.5 Mabswid
.43453 .44749 m
.43449 .44918 L
s
.64697 .55486 m
.64701 .55659 L
s
0 g
.30805 .38764 m
.31679 .38921 L
s
.015 w
.65122 .57785 m
.65506 .58101 L
s
.46256 .55043 m
.46678 .55 L
s
0 1 0 r
.5 Mabswid
.43449 .44918 m
.43446 .45088 L
s
.64701 .55659 m
.64704 .55832 L
s
0 g
.015 w
.81123 .51475 m
.81514 .52492 L
s
.26966 .50845 m
.27442 .50697 L
s
0 1 0 r
.5 Mabswid
.43446 .45088 m
.43443 .45258 L
s
0 g
.2993 .38607 m
.30805 .38764 L
s
0 1 0 r
.64704 .55832 m
.64708 .56005 L
s
0 g
.015 w
.80731 .5045 m
.81123 .51475 L
s
0 1 0 r
.5 Mabswid
.43443 .45258 m
.43439 .45427 L
s
.64708 .56005 m
.64711 .56179 L
s
0 g
.29055 .3845 m
.2993 .38607 L
s
0 1 0 r
.43439 .45427 m
.43436 .45597 L
s
0 g
.015 w
.80338 .49423 m
.80731 .5045 L
s
0 1 0 r
.5 Mabswid
.64711 .56179 m
.64714 .56352 L
s
.43436 .45597 m
.43432 .45767 L
s
.64714 .56352 m
.64718 .56525 L
s
0 g
.28178 .38292 m
.29055 .3845 L
s
.015 w
.79946 .48402 m
.80338 .49423 L
s
0 1 0 r
.5 Mabswid
.43432 .45767 m
.43429 .45937 L
s
0 g
.015 w
.64735 .57394 m
.65122 .57785 L
s
0 1 0 r
.5 Mabswid
.64718 .56525 m
.64721 .56699 L
s
0 g
.015 w
.79554 .47391 m
.79946 .48402 L
s
0 1 0 r
.5 Mabswid
.43429 .45937 m
.43425 .46108 L
s
0 g
.27301 .38135 m
.28178 .38292 L
s
0 1 0 r
.64721 .56699 m
.64725 .56873 L
s
.43425 .46108 m
.43422 .46278 L
s
.64725 .56873 m
.64728 .57046 L
s
0 g
.015 w
.79162 .46397 m
.79554 .47391 L
s
.45832 .55041 m
.46256 .55043 L
s
.5 Mabswid
.26422 .37977 m
.27301 .38135 L
s
0 1 0 r
.43422 .46278 m
.43419 .46448 L
s
.64728 .57046 m
.64732 .5722 L
s
0 g
.015 w
.26489 .50987 m
.26966 .50845 L
s
0 1 0 r
.5 Mabswid
.43419 .46448 m
.43415 .46619 L
s
0 g
.015 w
.78771 .45423 m
.79162 .46397 L
s
0 1 0 r
.5 Mabswid
.64732 .5722 m
.64735 .57394 L
s
0 g
.25543 .37819 m
.26422 .37977 L
s
0 1 0 r
.43415 .46619 m
.43412 .4679 L
s
0 g
.015 w
.64345 .56927 m
.64735 .57394 L
s
.7838 .44474 m
.78771 .45423 L
s
0 1 0 r
.5 Mabswid
.43412 .4679 m
.43408 .4696 L
s
0 g
.24663 .37661 m
.25543 .37819 L
s
0 1 0 r
.43408 .4696 m
.43405 .47131 L
s
0 g
.015 w
.77991 .43552 m
.7838 .44474 L
s
.5 Mabswid
.23782 .37503 m
.24663 .37661 L
s
0 1 0 r
.43405 .47131 m
.43401 .47302 L
s
.43401 .47302 m
.43398 .47473 L
s
0 g
.229 .37344 m
.23782 .37503 L
s
.015 w
.77602 .42659 m
.77991 .43552 L
s
.45407 .54985 m
.45832 .55041 L
s
.63953 .56384 m
.64345 .56927 L
s
0 1 0 r
.5 Mabswid
.43398 .47473 m
.43394 .47645 L
s
.43394 .47645 m
.43391 .47816 L
s
0 g
.22016 .37186 m
.229 .37344 L
s
.015 w
.77214 .41797 m
.77602 .42659 L
s
.2601 .51115 m
.26489 .50987 L
s
0 1 0 r
.5 Mabswid
.43391 .47816 m
.43387 .47987 L
s
.22016 .37186 m
.22006 .37354 L
s
.43387 .47987 m
.43384 .48159 L
s
.22006 .37354 m
.21996 .37522 L
s
.43384 .48159 m
.43381 .4833 L
s
0 g
.015 w
.63558 .55766 m
.63953 .56384 L
s
.76827 .40966 m
.77214 .41797 L
s
0 1 0 r
.5 Mabswid
.21996 .37522 m
.21985 .3769 L
s
.43381 .4833 m
.43377 .48502 L
s
.21985 .3769 m
.21975 .37859 L
s
.43377 .48502 m
.43374 .48674 L
s
.21975 .37859 m
.21965 .38027 L
s
0 g
.015 w
.76441 .40166 m
.76827 .40966 L
s
.44981 .54869 m
.45407 .54985 L
s
0 1 0 r
.5 Mabswid
.43374 .48674 m
.4337 .48846 L
s
.21965 .38027 m
.21954 .38196 L
s
0 g
.015 w
.63162 .55078 m
.63558 .55766 L
s
0 1 0 r
.5 Mabswid
.4337 .48846 m
.43367 .49018 L
s
.21954 .38196 m
.21944 .38364 L
s
.43367 .49018 m
.43363 .4919 L
s
0 g
.015 w
.76055 .39396 m
.76441 .40166 L
s
0 1 0 r
.5 Mabswid
.21944 .38364 m
.21933 .38533 L
s
0 g
.015 w
.25529 .51219 m
.2601 .51115 L
s
0 1 0 r
.5 Mabswid
.43363 .4919 m
.4336 .49363 L
s
.21933 .38533 m
.21923 .38702 L
s
.4336 .49363 m
.43356 .49535 L
s
0 g
.015 w
.62763 .54323 m
.63162 .55078 L
s
0 1 0 r
.5 Mabswid
.21923 .38702 m
.21912 .38871 L
s
.43356 .49535 m
.43353 .49708 L
s
0 g
.015 w
.7567 .38657 m
.76055 .39396 L
s
0 1 0 r
.5 Mabswid
.21912 .38871 m
.21902 .3904 L
s
.43353 .49708 m
.43349 .4988 L
s
0 g
.015 w
.44554 .54688 m
.44981 .54869 L
s
0 1 0 r
.5 Mabswid
.21902 .3904 m
.21891 .39209 L
s
.43349 .4988 m
.43346 .50053 L
s
0 g
.015 w
.62363 .53507 m
.62763 .54323 L
s
0 1 0 r
.5 Mabswid
.21891 .39209 m
.21881 .39379 L
s
.43346 .50053 m
.43342 .50226 L
s
0 g
.015 w
.75285 .37946 m
.7567 .38657 L
s
0 1 0 r
.5 Mabswid
.21881 .39379 m
.21871 .39548 L
s
.43342 .50226 m
.43339 .50399 L
s
.21871 .39548 m
.2186 .39718 L
s
0 g
.015 w
.61961 .52636 m
.62363 .53507 L
s
0 1 0 r
.5 Mabswid
.43339 .50399 m
.43335 .50572 L
s
.2186 .39718 m
.2185 .39887 L
s
0 g
.015 w
.25048 .51293 m
.25529 .51219 L
s
0 1 0 r
.5 Mabswid
.43335 .50572 m
.43332 .50745 L
s
.2185 .39887 m
.21839 .40057 L
s
0 g
.015 w
.74901 .37261 m
.75285 .37946 L
s
0 1 0 r
.5 Mabswid
.43332 .50745 m
.43328 .50919 L
s
0 g
.015 w
.61558 .51717 m
.61961 .52636 L
s
.44127 .54436 m
.44554 .54688 L
s
0 1 0 r
.5 Mabswid
.21839 .40057 m
.21829 .40227 L
s
.43328 .50919 m
.43325 .51092 L
s
.21829 .40227 m
.21818 .40397 L
s
.43325 .51092 m
.43321 .51266 L
s
0 g
.015 w
.61154 .50758 m
.61558 .51717 L
s
0 1 0 r
.5 Mabswid
.21818 .40397 m
.21808 .40567 L
s
.43321 .51266 m
.43318 .51439 L
s
0 g
.015 w
.74517 .36602 m
.74901 .37261 L
s
0 1 0 r
.5 Mabswid
.21808 .40567 m
.21797 .40737 L
s
0 g
.015 w
.60749 .49767 m
.61154 .50758 L
s
0 1 0 r
.5 Mabswid
.43318 .51439 m
.43314 .51613 L
s
.21797 .40737 m
.21787 .40908 L
s
.43314 .51613 m
.43311 .51787 L
s
0 g
.015 w
.60343 .48752 m
.60749 .49767 L
s
0 1 0 r
.5 Mabswid
.21787 .40908 m
.21776 .41078 L
s
.43311 .51787 m
.43307 .51961 L
s
0 g
.015 w
.43699 .5411 m
.44127 .54436 L
s
.24566 .51328 m
.25048 .51293 L
s
0 1 0 r
.5 Mabswid
.21776 .41078 m
.21766 .41249 L
s
.43307 .51961 m
.43304 .52135 L
s
0 g
.015 w
.59937 .4772 m
.60343 .48752 L
s
.74132 .35966 m
.74517 .36602 L
s
0 1 0 r
.5 Mabswid
.21766 .41249 m
.21755 .41419 L
s
.43304 .52135 m
.433 .52309 L
s
0 g
.015 w
.5953 .46679 m
.59937 .4772 L
s
0 1 0 r
.5 Mabswid
.21755 .41419 m
.21744 .4159 L
s
.433 .52309 m
.43297 .52484 L
s
.21744 .4159 m
.21734 .41761 L
s
0 g
.015 w
.59123 .45637 m
.5953 .46679 L
s
0 1 0 r
.5 Mabswid
.43297 .52484 m
.43293 .52658 L
s
.21734 .41761 m
.21723 .41932 L
s
0 g
.015 w
.73748 .3535 m
.74132 .35966 L
s
0 1 0 r
.5 Mabswid
.43293 .52658 m
.4329 .52833 L
s
0 g
.015 w
.58716 .446 m
.59123 .45637 L
s
0 1 0 r
.5 Mabswid
.21723 .41932 m
.21713 .42103 L
s
0 g
.015 w
.43272 .53707 m
.43699 .5411 L
s
0 1 0 r
.5 Mabswid
.4329 .52833 m
.43286 .53008 L
s
0 g
.015 w
.58308 .43574 m
.58716 .446 L
s
0 1 0 r
.5 Mabswid
.21713 .42103 m
.21702 .42274 L
s
.43286 .53008 m
.43283 .53182 L
s
.21702 .42274 m
.21692 .42446 L
s
.43283 .53182 m
.43279 .53357 L
s
0 g
.015 w
.579 .42565 m
.58308 .43574 L
s
.24085 .51317 m
.24566 .51328 L
s
0 1 0 r
.5 Mabswid
.21692 .42446 m
.21681 .42617 L
s
0 g
.015 w
.73364 .34753 m
.73748 .3535 L
s
0 1 0 r
.5 Mabswid
.43279 .53357 m
.43276 .53532 L
s
.21681 .42617 m
.2167 .42789 L
s
0 g
.015 w
.57492 .41576 m
.579 .42565 L
s
0 1 0 r
.5 Mabswid
.43276 .53532 m
.43272 .53707 L
s
.2167 .42789 m
.2166 .42961 L
s
0 g
.015 w
.42845 .53228 m
.43272 .53707 L
s
.57083 .40612 m
.57492 .41576 L
s
0 1 0 r
.5 Mabswid
.2166 .42961 m
.21649 .43132 L
s
.21649 .43132 m
.21639 .43304 L
s
0 g
.015 w
.72979 .34173 m
.73364 .34753 L
s
.56674 .39675 m
.57083 .40612 L
s
0 1 0 r
.5 Mabswid
.21639 .43304 m
.21628 .43476 L
s
.21628 .43476 m
.21617 .43648 L
s
0 g
.015 w
.56265 .38768 m
.56674 .39675 L
s
.23604 .51252 m
.24085 .51317 L
s
.42418 .52673 m
.42845 .53228 L
s
0 1 0 r
.5 Mabswid
.21617 .43648 m
.21607 .43821 L
s
.21607 .43821 m
.21596 .43993 L
s
0 g
.015 w
.72594 .33608 m
.72979 .34173 L
s
.55855 .37891 m
.56265 .38768 L
s
0 1 0 r
.5 Mabswid
.21596 .43993 m
.21585 .44165 L
s
.21585 .44165 m
.21575 .44338 L
s
.21575 .44338 m
.21564 .44511 L
s
0 g
.015 w
.41992 .52042 m
.42418 .52673 L
s
.55445 .37045 m
.55855 .37891 L
s
0 1 0 r
.5 Mabswid
.21564 .44511 m
.21553 .44683 L
s
0 g
.015 w
.72208 .33055 m
.72594 .33608 L
s
0 1 0 r
.5 Mabswid
.21553 .44683 m
.21543 .44856 L
s
0 g
.015 w
.55034 .36231 m
.55445 .37045 L
s
.23125 .51126 m
.23604 .51252 L
s
0 1 0 r
.5 Mabswid
.21543 .44856 m
.21532 .45029 L
s
0 g
.015 w
.41566 .51341 m
.41992 .52042 L
s
0 1 0 r
.5 Mabswid
.21532 .45029 m
.21521 .45203 L
s
.21521 .45203 m
.21511 .45376 L
s
0 g
.015 w
.54622 .35448 m
.55034 .36231 L
s
.71821 .32513 m
.72208 .33055 L
s
0 1 0 r
.5 Mabswid
.21511 .45376 m
.215 .45549 L
s
.215 .45549 m
.21489 .45723 L
s
0 g
.015 w
.41141 .50572 m
.41566 .51341 L
s
0 1 0 r
.5 Mabswid
.21489 .45723 m
.21478 .45896 L
s
0 g
.015 w
.5421 .34694 m
.54622 .35448 L
s
0 1 0 r
.5 Mabswid
.21478 .45896 m
.21468 .4607 L
s
0 g
.015 w
.22648 .50935 m
.23125 .51126 L
s
0 1 0 r
.5 Mabswid
.21468 .4607 m
.21457 .46244 L
s
0 g
.015 w
.40717 .49741 m
.41141 .50572 L
s
.71434 .31981 m
.71821 .32513 L
s
0 1 0 r
.5 Mabswid
.21457 .46244 m
.21446 .46418 L
s
0 g
.015 w
.53796 .33969 m
.5421 .34694 L
s
0 1 0 r
.5 Mabswid
.21446 .46418 m
.21435 .46592 L
s
0 g
.015 w
.40293 .48856 m
.40717 .49741 L
s
0 1 0 r
.5 Mabswid
.21435 .46592 m
.21425 .46766 L
s
0 g
.70553 .31587 m
.71426 .31752 L
s
0 1 0 r
.21425 .46766 m
.21414 .4694 L
s
0 g
.015 w
.53382 .33271 m
.53796 .33969 L
s
0 1 0 r
.5 Mabswid
.21414 .4694 m
.21403 .47115 L
s
0 g
.015 w
.3987 .47922 m
.40293 .48856 L
s
.5 Mabswid
.69678 .31422 m
.70553 .31587 L
s
.015 w
.22172 .50672 m
.22648 .50935 L
s
0 1 0 r
.5 Mabswid
.21403 .47115 m
.21392 .47289 L
s
0 g
.68803 .31257 m
.69678 .31422 L
s
0 1 0 r
.21392 .47289 m
.21382 .47464 L
s
0 g
.015 w
.39447 .46948 m
.3987 .47922 L
s
0 1 0 r
.5 Mabswid
.21382 .47464 m
.21371 .47639 L
s
0 g
.67927 .31092 m
.68803 .31257 L
s
.015 w
.52967 .32598 m
.53382 .33271 L
s
.39025 .45942 m
.39447 .46948 L
s
0 1 0 r
.5 Mabswid
.21371 .47639 m
.2136 .47814 L
s
.2136 .47814 m
.21349 .47989 L
s
0 g
.6705 .30927 m
.67927 .31092 L
s
.015 w
.38603 .44911 m
.39025 .45942 L
s
0 1 0 r
.5 Mabswid
.21349 .47989 m
.21338 .48164 L
s
0 g
.015 w
.217 .50335 m
.22172 .50672 L
s
.5 Mabswid
.66172 .30761 m
.6705 .30927 L
s
0 1 0 r
.21338 .48164 m
.21328 .48339 L
s
0 g
.015 w
.38181 .43863 m
.38603 .44911 L
s
.5255 .31948 m
.52967 .32598 L
s
0 1 0 r
.5 Mabswid
.21328 .48339 m
.21317 .48514 L
s
0 g
.65293 .30596 m
.66172 .30761 L
s
.015 w
.37759 .42807 m
.38181 .43863 L
s
0 1 0 r
.5 Mabswid
.21317 .48514 m
.21306 .4869 L
s
0 g
.015 w
.37336 .41749 m
.37759 .42807 L
s
0 1 0 r
.5 Mabswid
.21306 .4869 m
.21295 .48865 L
s
0 g
.64413 .3043 m
.65293 .30596 L
s
.015 w
.52133 .31319 m
.5255 .31948 L
s
0 1 0 r
.5 Mabswid
.21295 .48865 m
.21284 .49041 L
s
0 g
.015 w
.36913 .40697 m
.37336 .41749 L
s
.5 Mabswid
.63532 .30264 m
.64413 .3043 L
s
.015 w
.2123 .49921 m
.217 .50335 L
s
0 1 0 r
.5 Mabswid
.21284 .49041 m
.21273 .49217 L
s
0 g
.015 w
.36489 .39655 m
.36913 .40697 L
s
0 1 0 r
.5 Mabswid
.21273 .49217 m
.21263 .49393 L
s
0 g
.6265 .30098 m
.63532 .30264 L
s
0 1 0 r
.21263 .49393 m
.21252 .49569 L
s
0 g
.015 w
.36064 .3863 m
.36489 .39655 L
s
.51714 .30708 m
.52133 .31319 L
s
0 1 0 r
.5 Mabswid
.21252 .49569 m
.21241 .49745 L
s
0 g
.61767 .29931 m
.6265 .30098 L
s
.015 w
.35638 .37625 m
.36064 .3863 L
s
0 1 0 r
.5 Mabswid
.21241 .49745 m
.2123 .49921 L
s
0 g
.60883 .29765 m
.61767 .29931 L
s
.015 w
.20763 .4943 m
.2123 .49921 L
s
.35211 .36646 m
.35638 .37625 L
s
.5 Mabswid
.59998 .29598 m
.60883 .29765 L
s
.015 w
.51294 .30115 m
.51714 .30708 L
s
.34782 .35694 m
.35211 .36646 L
s
.5 Mabswid
.59112 .29431 m
.59998 .29598 L
s
.015 w
.34351 .34771 m
.34782 .35694 L
s
.203 .48861 m
.20763 .4943 L
s
.5 Mabswid
.58226 .29264 m
.59112 .29431 L
s
.015 w
.50873 .29536 m
.51294 .30115 L
s
.5 Mabswid
.57338 .29096 m
.58226 .29264 L
s
.015 w
.33918 .33879 m
.34351 .34771 L
s
.5 Mabswid
.56449 .28929 m
.57338 .29096 L
s
.015 w
.19841 .48218 m
.203 .48861 L
s
.33483 .33018 m
.33918 .33879 L
s
.5 Mabswid
.5556 .28761 m
.56449 .28929 L
s
.015 w
.5045 .2897 m
.50873 .29536 L
s
.5 Mabswid
.54669 .28593 m
.5556 .28761 L
s
.015 w
.33046 .32189 m
.33483 .33018 L
s
.19384 .47502 m
.19841 .48218 L
s
.5 Mabswid
.53777 .28425 m
.54669 .28593 L
s
.015 w
.32607 .31391 m
.33046 .32189 L
s
.5 Mabswid
.52885 .28257 m
.53777 .28425 L
s
.015 w
.50026 .28415 m
.5045 .2897 L
s
.18932 .46719 m
.19384 .47502 L
s
.5 Mabswid
.51991 .28089 m
.52885 .28257 L
s
.015 w
.32166 .30623 m
.32607 .31391 L
s
.5 Mabswid
.51096 .2792 m
.51991 .28089 L
s
.015 w
.18482 .45874 m
.18932 .46719 L
s
.49601 .27869 m
.50026 .28415 L
s
.5 Mabswid
.50201 .27751 m
.51096 .2792 L
s
.015 w
.31723 .29884 m
.32166 .30623 L
s
.5 Mabswid
.49304 .27582 m
.50201 .27751 L
s
.015 w
.18035 .44973 m
.18482 .45874 L
s
.5 Mabswid
.48407 .27413 m
.49304 .27582 L
s
.015 w
.31277 .29172 m
.31723 .29884 L
s
.17591 .44025 m
.18035 .44973 L
s
.5 Mabswid
.47508 .27244 m
.48407 .27413 L
s
.015 w
.17149 .43035 m
.17591 .44025 L
s
.5 Mabswid
.46609 .27074 m
.47508 .27244 L
s
.015 w
.30829 .28484 m
.31277 .29172 L
s
.16709 .42013 m
.17149 .43035 L
s
.5 Mabswid
.45708 .26904 m
.46609 .27074 L
s
.015 w
.1627 .40965 m
.16709 .42013 L
s
.5 Mabswid
.44806 .26735 m
.45708 .26904 L
s
.015 w
.15831 .39902 m
.1627 .40965 L
s
.30378 .2782 m
.30829 .28484 L
s
.5 Mabswid
.43904 .26564 m
.44806 .26735 L
s
.015 w
.15393 .38829 m
.15831 .39902 L
s
.5 Mabswid
.43 .26394 m
.43904 .26564 L
s
.015 w
.14955 .37755 m
.15393 .38829 L
s
.5 Mabswid
.42096 .26224 m
.43 .26394 L
s
.015 w
.29926 .27177 m
.30378 .2782 L
s
.14515 .36686 m
.14955 .37755 L
s
.5 Mabswid
.4119 .26053 m
.42096 .26224 L
s
.015 w
.14074 .35628 m
.14515 .36686 L
s
.5 Mabswid
.40284 .25882 m
.4119 .26053 L
s
.015 w
.13632 .34587 m
.14074 .35628 L
s
.29471 .26553 m
.29926 .27177 L
s
.5 Mabswid
.39376 .25711 m
.40284 .25882 L
s
.015 w
.13187 .33567 m
.13632 .34587 L
s
.5 Mabswid
.38468 .2554 m
.39376 .25711 L
s
.015 w
.1274 .32571 m
.13187 .33567 L
s
.5 Mabswid
.37558 .25368 m
.38468 .2554 L
s
.015 w
.29014 .25945 m
.29471 .26553 L
s
.12289 .31603 m
.1274 .32571 L
s
.5 Mabswid
.36648 .25197 m
.37558 .25368 L
s
.015 w
.11836 .30664 m
.12289 .31603 L
s
.5 Mabswid
.35736 .25025 m
.36648 .25197 L
s
.015 w
.28555 .25352 m
.29014 .25945 L
s
.11379 .29757 m
.11836 .30664 L
s
.5 Mabswid
.34823 .24853 m
.35736 .25025 L
s
.3391 .24681 m
.34823 .24853 L
s
.015 w
.10919 .28881 m
.11379 .29757 L
s
.5 Mabswid
.32995 .24508 m
.3391 .24681 L
s
.015 w
.28094 .24773 m
.28555 .25352 L
s
.10454 .28037 m
.10919 .28881 L
s
.5 Mabswid
.32079 .24336 m
.32995 .24508 L
s
.31163 .24163 m
.32079 .24336 L
s
.015 w
.09987 .27224 m
.10454 .28037 L
s
.27631 .24204 m
.28094 .24773 L
s
.5 Mabswid
.30245 .2399 m
.31163 .24163 L
s
.29326 .23817 m
.30245 .2399 L
s
.015 w
.09515 .26441 m
.09987 .27224 L
s
.5 Mabswid
.28407 .23644 m
.29326 .23817 L
s
.015 w
.27166 .23644 m
.27631 .24204 L
s
.5 Mabswid
.27486 .2347 m
.28407 .23644 L
s
.015 w
.0904 .25686 m
.09515 .26441 L
s
.5 Mabswid
.26564 .23296 m
.27486 .2347 L
s
.25641 .23122 m
.26564 .23296 L
s
.015 w
.08561 .24959 m
.0904 .25686 L
s
.5 Mabswid
.24717 .22948 m
.25641 .23122 L
s
.23792 .22774 m
.24717 .22948 L
s
.015 w
.08079 .24257 m
.08561 .24959 L
s
.5 Mabswid
.22866 .22599 m
.23792 .22774 L
s
.21939 .22425 m
.22866 .22599 L
s
.015 w
.07593 .23578 m
.08079 .24257 L
s
.5 Mabswid
.21011 .2225 m
.21939 .22425 L
s
.20082 .22075 m
.21011 .2225 L
s
.015 w
.07104 .22921 m
.07593 .23578 L
s
.5 Mabswid
.19152 .21899 m
.20082 .22075 L
s
.18221 .21724 m
.19152 .21899 L
s
.17289 .21548 m
.18221 .21724 L
s
.015 w
.06611 .22282 m
.07104 .22921 L
s
.5 Mabswid
.16356 .21372 m
.17289 .21548 L
s
.15421 .21196 m
.16356 .21372 L
s
.015 w
.06116 .2166 m
.06611 .22282 L
s
.5 Mabswid
.14486 .2102 m
.15421 .21196 L
s
.1355 .20843 m
.14486 .2102 L
s
.12612 .20667 m
.1355 .20843 L
s
.015 w
.05617 .21052 m
.06116 .2166 L
s
.5 Mabswid
.11674 .2049 m
.12612 .20667 L
s
.10734 .20313 m
.11674 .2049 L
s
.015 w
.05115 .20458 m
.05617 .21052 L
s
.5 Mabswid
.09794 .20136 m
.10734 .20313 L
s
.08852 .19958 m
.09794 .20136 L
s
.07909 .1978 m
.08852 .19958 L
s
.015 w
.04611 .19875 m
.05115 .20458 L
s
.5 Mabswid
.06965 .19602 m
.07909 .1978 L
s
.0602 .19424 m
.06965 .19602 L
s
.05074 .19246 m
.0602 .19424 L
s
.015 w
.04104 .19301 m
.04611 .19875 L
s
.5 Mabswid
.04127 .19068 m
.05074 .19246 L
s
.25 Mabswid
.47602 0 m
.98951 .64108 L
s
.98951 .64108 m
1 .76863 L
s
1 .76863 m
.47414 .14006 L
s
.47414 .14006 m
.47602 0 L
s
.01448 .17452 m
0 .31187 L
s
0 .31187 m
.47414 .14006 L
s
.47414 .14006 m
.47602 0 L
s
.47602 0 m
.01448 .17452 L
s
.01448 .17452 m
.47602 0 L
s
gsave
.18494 .02919 -70.4794 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{383, 337.188},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007N0001YB000`400?l00000o`00003ooooooooO
ooooo`00oooooooOooooo`00oooooooOooooo`00oooooooOooooo`00oooooooOooooo`00oooooooO
ooooo`00oooooooOooooo`00oooooooOooooo`00oooooooOooooo`00oooooooOooooo`00oooooooO
ooooo`00oooooooOooooo`00oooooooOooooo`00oooooooOooooo`00oooooooOooooo`00oooooooO
ooooo`00oooooooOooooo`00oooooooOooooo`00oooooooOooooo`00oooooooOooooo`00oooooooO
ooooo`00oooooooOooooo`00oooooooOooooo`00oooooooOooooo`00oooooooOooooo`00oooooooO
ooooo`00oooooooOooooo`00oooooooOooooo`00oooooooOooooo`00oooooooOooooo`00oooooooO
ooooo`00oooooooOooooo`00oooooooOooooo`00oooooooOooooo`00oooooooOooooo`00oooooooO
ooooo`00oooooooOooooo`00oooooooOooooo`00oooooooOooooo`00oooooooOooooo`00oooooooO
ooooo`00oooooooOooooo`00oooooooOooooo`00oooooooOooooo`00oooooooOooooo`00oooooolG
ooooo`;o0000a_ooool00:7ooooo00GoV9RHo`000?l0003oA4A4okZj^P1]ooooo`?o000000?ooooo
o`000?ooool0aOooool00:7ooooo00Go410@okZj^_o^k^koMgMgoa0@401Zooooo`?o00001?ooool2
o`000<Gooooo002Qooooo`03o`000?oooooooooo06[ooooo0_l00007ooooo`03o`000?oooooo0000
0<Cooooo002Qooooo`03o`000?oooooooooo06Oooooo0ol00009ooooo`04o`000?ooooooooooo`00
0<?ooooo002Qooooo`03o`000?oooooooooo06Cooooo0ol0000<ooooo`05o`000?oooooooooooooo
ool00000`_ooool009oooooo00?o410@o`000?l000000ol0001Qooooo`;o00003oooool01Ol0003o
oooooooooooooooo00000<;ooooo002Qooooo`03o`000?oooooooooo05oooooo0ol0000Aooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0_oooool00:7ooooo00?o0000ooooooooool0
G?ooool3o`0001Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2nooooo`00o_oo
ool2o`0001Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2mooooo`00noooool3
o`0001Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2looooo`00nOooool2o`00
01cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2looooo`00m_ooool3o`0001ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2kooooo`00loooool3o`00027ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`2jooooo`00lOooool2o`0002Cooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`2iooooo`00k_ooool3o`0002Kooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`2hooooo`00joooool3o`0002Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`2hooooo`00jOooool2o`0002cooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`2gooooo`00i_ooool3o`0002kooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`2fooooo`00hoooool3o`00037ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`2eooooo`00hOooool2o`0003Cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`2dooooo`00g_ooool3o`0003Kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`2dooooo`00foooool3o`0003Wooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`2cooooo`00fOooool2o`0003cooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`2booooo`00e_ooool3o`0003kooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`2aooooo`00doooool3o`00047ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`2`
ooooo`00dOooool2o`0004Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`2`oooo
o`00c_ooool3o`0004Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`2_ooooo`00
boooool3o`0004Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2^ooooo`00bOoo
ool2o`0004_ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`2]ooooo`00a_ooool3
o`0004gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`2/ooooo`00`oooool3o`00
053ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`2/ooooo`00`Oooool2o`0005?o
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`2[ooooo`00__ooool3o`0005Gooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`2Zooooo`00_?ooool2o`0005Sooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`2Yooooo`00^Oooool3o`0005[ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`2Xooooo`00]_ooool3o`0005gooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`2Xooooo`00]?ooool2o`00063ooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`2Wooooo`00/Oooool3o`0006;ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`2Vooooo`00[_ooool3o`0006Gooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`2Uooooo`00[?ooool2o`0006Sooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`2Tooooo`00ZOooool3o`0006[ooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`2Tooooo`00Y_ooool3o`0006gooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`2Sooooo`00Y?ooool2o`00073ooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`2Rooooo`00XOooool3o`0007;ooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`2Qooooo`00W_ooool3o`0007Gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`2P
ooooo`00W?ooool2o`0007Sooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`2Poooo
o`00VOooool3o`0007[ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`2Oooooo`00
U_ooool3o`0007gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`2Nooooo`00U?oo
ool2o`00083ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`2Mooooo`00TOooool3
o`0008;ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`2Looooo`00S_ooool3o`00
08Gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`2Looooo`00S?ooool2o`0008So
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`2Kooooo`00ROooool3o`0008Wooooo
0_l0000Zooooo`03o`000?oooooooooo09[ooooo0026ooooo`?o0000ROooool3o`000003ooooool0
003ooooo02[ooooo00?o0000ooooooooool0VOooool008Cooooo0_l00029ooooo`?o00001Oooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo09Sooooo0021ooooo`?o0000R?ooool3o`00
00Wooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`2Hooooo`00Ooooool2o`0008Wo
oooo0_l0000=ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0Uoooool007cooooo
0ol00028ooooo`?o00004?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo09Kooooo
001iooooo`?o0000R?ooool3o`0001Cooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`2Eooooo`00Moooool2o`0008Wooooo0_l0000Gooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool0U?ooool007Cooooo0ol00028ooooo`?o00006_ooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo09Cooooo001aooooo`?o0000R?ooool3o`0001kooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`2Cooooo`00Koooool2o`0008Sooooo0ol0000Rooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool0T_ooool006cooooo0ol00028ooooo`;o00009_oo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo097ooooo001Yooooo`?o0000R?ooool3
o`0002Wooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`2Aooooo`00J?ooool00ol0
003oooooooooo`26ooooo`?o0000;?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
093ooooo001Xooooo`03o`000?oooooooooo08?ooooo0ol0000`ooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool0Soooool006Sooooo0_l00022ooooo`;o0000=?ooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo08kooooo001Xooooo`03o`000?oooooo000007kooooo0ol0
000gooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0SOooool006Sooooo00Co0000
oooooooooooo0000N_ooool3o`0003_ooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`2=ooooo`00Ioooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`Go0000Kooo
ool2o`0003oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`2<ooooo`00Ioooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Go0000K?ooool3o`00047ooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`2;ooooo`00Ioooool00ol0003oooooooooo`04oooo
o`03o`000?oooooo000000Oo0000I_ooool3o`0004Gooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`2:ooooo`00Ioooool00ol0003oooooooooo`05ooooo`So000000?oooooo`000?l0
00000_l0001Oooooo`?o0000BOooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo08Wo
oooo001Wooooo`03o`000?oooooooooo00Kooooo1ol00005ooooo`Oo0000E_ooool2o`0004gooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`29ooooo`00Ioooool00ol0003ooooooooo
o`06ooooo`So00002oooool4o`0004oooooo0ol0001@ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool0R?ooool006Oooooo00?o0000ooooooooool01oooool8o`0000kooooo1ol00015
ooooo`?o0000E?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo08Oooooo001Woooo
o`03o`000?oooooooooo00Sooooo2?l0000Dooooo`?o0000?oooool3o`0005Oooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`26ooooo`00Ioooool00ol0003oooooooooo`08ooooo`Wo
00005_ooool7o`0003Kooooo0_l0001Kooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool0QOooool006Kooooo00?o0000ooooooooool02_ooool9o`0001cooooo1?l0000_ooooo`?o0000
G_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo08Gooooo001Vooooo`03o`000?oo
oooooooo00_ooooo2?l0000Pooooo`Oo00009Oooool3o`0006;ooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`24ooooo`00I_ooool00ol0003oooooooooo`0<ooooo`So00009_ooool4
o`0001oooooo0_l0001Vooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Poooool0
06Kooooo00?o0000ooooooooool03Oooool8o`0002Wooooo1ol0000Eooooo`?o0000JOooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo08;ooooo001Vooooo`03o`000?oooooooooo00ko
oooo2?l0000_ooooo`?o00003oooool3o`0006cooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`21ooooo`00I_ooool00ol0003oooooooooo`0>ooooo`Wo0000<Oooool7o`0000Gooooo
0ol0001`ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0POooool006Kooooo00?o
0000ooooooooool03oooool8o`0003Sooooo1Ol0001dooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool0P?ooool006Kooooo00?o0000ooooooooool04?ooool8o`0003Oooooo0ol00000
0ooooooo0000o`000005o`0006oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1o
ooooo`00I_ooool00ol0003oooooooooo`0Aooooo`So0000<oooool3o`0000_ooooo0ol000000ooo
oooo0000o`000003o`0006Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1noooo
o`00IOooool00ol0003oooooooooo`0Cooooo`So0000;oooool3o`00017ooooo1ol0001Wooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0OOooool006Gooooo00?o0000ooooooooool0
4oooool9o`0002cooooo0_l0000Eooooo`[o0000Hoooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo07gooooo001Uooooo`03o`000?oooooooooo01Cooooo2?l0000Yooooo`?o00005ooo
ool8o`0000;ooooo1ol0001Mooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0O?oo
ool006Gooooo00?o0000ooooooooool05Oooool8o`0002Gooooo0ol0000Jooooo`Wo00002?ooool3
o`0005_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1kooooo`00IOooool00ol0
003oooooooooo`0Fooooo`So00008_ooool2o`0001kooooo2?l0000;ooooo`Oo0000EOooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo07[ooooo001Uooooo`03o`000?oooooooooo01Oo
oooo1ol0000Oooooo`?o00008Oooool8o`00017ooooo1ol0001?ooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool0NOooool006Gooooo00?o0000ooooooooool05oooool8o`0001_ooooo
0ol0000Uooooo`Oo00006?ooool4o`0004cooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`1iooooo`00IOooool00ol0003oooooooooo`0Hooooo`Oo00006?ooool3o`0002Wooooo1ol0
000Kooooo`Ko0000A_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo07Sooooo001U
ooooo`03o`000?oooooooooo01Wooooo1_l0000Fooooo`;o0000;?ooool8o`00023ooooo1?l00013
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Moooool006Cooooo00?o0000oooo
ooooool06_ooool7o`0001;ooooo0ol0000_ooooo`So00008oooool7o`0003gooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`1fooooo`00I?ooool00ol0003oooooooooo`0Kooooo`Oo
00003_ooool3o`0003;ooooo2Ol0000Yooooo`?o0000>oooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo07Gooooo001Tooooo`03o`000?oooooooooo01_ooooo2?l0000:ooooo`?o0000
=_ooool9o`0002_ooooo1ol0000eooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
MOooool000oooooo00?oMgMgofIVI_ooool0;Oooool00omVIVKoMgMgooooo`0Rooooo`03o`000?oo
oooooooo01_ooooo2Ol00007ooooo`;o0000>_ooool9o`00037ooooo1?l0000booooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool0M?ooool000kooooo00?ogMgMoa0@4?o^k^h0;_ooool0
0oo^k^ko410@omgMg@0Rooooo`03o`000?oooooooooo01cooooo2Ol00003ooooo`?o0000?Oooool8
o`0003Gooooo1_l0000/ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Loooool0
00?ooooo00?o410@o`000?l000000_l000000ol@413oooooooooo`03ooooo`04oeEEEOnHV9Sooooo
ooooo`;o00000_ooool2o`0001;ooooo00GoIVIVo`000?l0003oA4A4olc<c00:ooooo`05oiRHV?l0
003o0000odA4A?nj^[X00_ooool00on7QhOoIVIVooooo`0Qooooo`03o`000?oooooooooo01gooooo
2ol00011ooooo`So0000>_ooool4o`0002Wooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`1booooo`001Oooool00ol0003oooooooooo`06ooooo`0:o`000?ooooooooooooooooo^k^ko
8B4QohN7Qonj^[[o0000omgMgA7ooooo00KoIVIVogMgMoooooooooooohN7Qol@410:ooooo`05oa0@
4?nj^[[ok^k^ogMgMol@41000_ooool00oo^k^ko0000ooooo`0Qooooo`03o`000?oooooooooo01ko
oooo1ol000000ooooooo0000ooooo`12ooooo`Oo0000?_ooool;o`0001oooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`1aooooo`001Oooool00ol0003oooooooooo`06ooooo`03oc8b
<_oooooooooo00;ooooo00CogMgMo`000?l@413oc<c<0oooool6o`0000Wooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool07oooool7o`000003ooooool0003ooooo04;ooooo1ol00013ooooo`Oo00007_ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo077ooooo0005ooooo`03o`000?oooooooooo00Kooooo
00?o<S8booooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^hBooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01go
oooo2Ol00002ooooo`03o`000?oooooooooo043ooooo2?l00012ooooo`_o00006oooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo073ooooo0005ooooo`03o`000?oooooooooo00Kooooo
00?o0000onk^k_ooool00_ooool01?lQ8B7oMgMgogMgMolb<S8Booooo`06ofIVI_mgMgOooooooooo
oon7QhOo00002_ooool00ol0003oooooooooo`04ooooo`03onk^k_l0003ooooo023ooooo00?o0000
ooooooooool06oooool3o`0000?ooooo1ol00002ooooo`03o`000?oooooooooo043ooooo1ol00012
ooooo`Oo00001?ooool7o`0001Gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1_
ooooo`000oooool00ol@413o0000o`000003o`0000Gooooo00CoEEEEogMgMooooooooooo0_l00002
ooooo`;o00004Oooool01_o^k^koIVIVo`000?l0003oA4A4o`0000Sooooo00?o410@o`000?l00000
0ol00003ooooo`03ogMgMomEEEGooooo023ooooo00?o0000ooooooooool06Oooool2o`0000Kooooo
1ol00003ooooo`03o`000?oooooooooo03oooooo2?l00011ooooo`So00002_ooool3o`0001;ooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`1^ooooo`001Oooool00ol0003ooooooooo
o`06ooooo`03omgMgOl@413ok^k^02Sooooo00?o0000ooooooooool00oooool00oo^k^ko410@omgM
g@0Qooooo`03o`000?oooooooooo01Kooooo0ol00009ooooo`Ko00001?ooool00ol0003ooooooooo
o`0oooooo`So0000@Oooool8o`0000cooooo1ol0000<ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool0KOooool000Gooooo00?o410@okZj^_ooool01oooool00omgMgOoIVIVooooo`0W
ooooo`03o`000?oooooooooo00?ooooo00?oIVIVogMgMoooool08Oooool00ol0003oooooooooo`0C
ooooo`?o00003?ooool7o`0000Cooooo00?o0000ooooooooool0?oooool7o`0004;ooooo2?l0000B
ooooo`?o00002_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo06gooooo0005oooo
o`04okZj^_l@413o0000oa0@45[ooooo00?o0000ooooooooool04?ooool3o`00013ooooo1ol00004
ooooo`03o`000?oooooooooo03kooooo2?l00011ooooo`Wo00005?ooool7o`0000Cooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`1/ooooo`00Hoooool00ol0003oooooooooo`0>oooo
o`;o00004oooool7o`0000Gooooo00?o0000ooooooooool0?_ooool7o`0004;ooooo2Ol0000Joooo
o`Oo00009oooool00ol0003oooooooooo`1[ooooo`00Hoooool00ol0003oooooooooo`0;ooooo`?o
00005Oooool8o`0000Gooooo00?o0000ooooooooool0?_ooool7o`0004;ooooo2?l0000Pooooo`Co
00009Oooool00ol0003oooooooooo`1Zooooo`00Hoooool00ol0003oooooooooo`08ooooo`?o0000
6Oooool7o`0000Kooooo00?o0000ooooooooool0?Oooool8o`0004;ooooo2?l0000Oooooo`04o`00
0?ooooooooooooooo`Oo00007oooool00ol0003oooooooooo`1Yooooo`00Hoooool00ol0003ooooo
ooooo`06ooooo`;o00007Oooool7o`0000Kooooo00?o0000ooooooooool0?Oooool7o`0004?ooooo
1ol0000Pooooo`03o`000?oooooooooo00Oooooo0ol0000Looooo`03o`000?oooooooooo06Wooooo
001Rooooo`03o`000?oooooooooo00Cooooo0ol0000Oooooo`Oo00001oooool00ol0003ooooooooo
o`0looooo`So0000@oooool7o`00023ooooo00?o0000ooooooooool02Oooool7o`0001Kooooo00?o
0000ooooooooool0J?ooool006;ooooo00Co0000oooooooooooooooo0ol0000Sooooo`Oo00001ooo
ool00ol0003oooooooooo`0looooo`So0000@_ooool8o`00023ooooo00?o0000ooooooooool03ooo
ool3o`0001Cooooo00?o0000ooooooooool0Ioooool006;ooooo1?l0000Vooooo`So00001oooool0
0ol0003oooooooooo`0looooo`Oo0000@oooool7o`00027ooooo00?o0000ooooooooool04Oooool7
o`0000kooooo00?o0000ooooooooool0I_ooool006;ooooo0_l0000Yooooo`Oo00002?ooool00ol0
003oooooooooo`0kooooo`So0000@_ooool8o`00027ooooo00?o0000ooooooooool05oooool6o`00
00Wooooo00?o0000ooooooooool0IOooool006Cooooo00?o0000ooooooooool09_ooool7o`0000Wo
oooo00?o0000ooooooooool0>oooool7o`0004?ooooo1ol0000Qooooo`03o`000?oooooooooo01go
oooo1ol00002ooooo`03o`000?oooooooooo02[ooooo0_l00002ooooo`;o0000=Oooool006Gooooo
00?o0000ooooooooool09_ooool7o`0000Wooooo00?o0000ooooooooool0>oooool6o`0004Cooooo
1ol0000Qooooo`03o`000?oooooooooo01kooooo1Ol00003ooooo`03o`000?oooooooooo02Wooooo
00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMdeooooo`00I_ooool00ol0003oooooooooo`0Vooooo`Ko
00002_ooool00ol0003oooooooooo`0jooooo`Oo0000@oooool8o`00027ooooo00?o0000oooooooo
ool07Oooool6o`0000?ooooo00?o0000ooooooooool0:Oooool01?oMgMgo0000oa0@4?o<c<`foooo
o`00Ioooool00ol0003oooooooooo`0Uooooo`Ko00002oooool00ol0003oooooooooo`0jooooo`Oo
0000@oooool7o`0002;ooooo00?o0000ooooooooool07?ooool7o`0000?ooooo00?o0000oooooooo
ool0:?ooool01?o^k^ko8B4Qoa0@4?o^k^hfooooo`00J?ooool00ol0003oooooooooo`0Tooooo`Oo
00002oooool00ol0003oooooooooo`0iooooo`Oo0000@oooool8o`0002;ooooo00?o0000oooooooo
ool06oooool8o`0000?ooooo00?o0000ooooooooool09oooool01?lQ8B7oMgMgogMgMolb<S8foooo
o`00JOooool00ol0003oooooooooo`0Tooooo`Ko00003?ooool00ol0003oooooooooo`0hooooo`So
0000@oooool7o`0002?ooooo00?o0000ooooooooool06_ooool8o`0000?ooooo00?o0000oooooooo
ool09_ooool2o`0000;ooooo0_l0000eooooo`00J_ooool00ol0003oooooooooo`0Sooooo`Oo0000
3?ooool00ol0003oooooooooo`0hooooo`Oo0000A?ooool7o`0002;ooooo00?o0000ooooooooool0
6oooool8o`0000?ooooo00?o0000ooooooooool0H?ooool006_ooooo00?o0000ooooooooool08_oo
ool7o`0000gooooo00?o0000ooooooooool0>?ooool7o`0004?ooooo2?l0000Rooooo`03o`000?oo
oooooooo01_ooooo2?l00003ooooo`03o`000?oooooooooo05oooooo001/ooooo`03o`000?oooooo
oooo02;ooooo1ol0000=ooooo`03o`000?oooooooooo03Oooooo1ol00014ooooo`Oo00008oooool0
0ol0003oooooooooo`0Kooooo`So00000oooool00ol0003oooooooooo`1Nooooo`00KOooool00ol0
003oooooooooo`0Qooooo`So00003Oooool00ol0003oooooooooo`0gooooo`Oo0000@oooool8o`00
02?ooooo00?o0000ooooooooool06_ooool8o`0000Cooooo00?o0000ooooooooool0GOooool006ko
oooo00?o0000ooooooooool08Oooool7o`0000kooooo00?o0000ooooooooool0=_ooool7o`0004Co
oooo2?l0000Sooooo`03o`000?oooooooooo01[ooooo2?l00003ooooo`03o`000?oooooooooo05go
oooo001_ooooo`03o`000?oooooooooo023ooooo1ol0000?ooooo`03o`000?oooooooooo03Kooooo
1_l00015ooooo`Oo00009?ooool00ol0003oooooooooo`0Jooooo`So00000oooool00ol0003ooooo
ooooo`1Looooo`00L?ooool00ol0003oooooooooo`0Pooooo`Oo00003oooool00ol0003ooooooooo
o`0eooooo`Oo0000A?ooool8o`0002?ooooo00?o0000ooooooooool06oooool8o`0000?ooooo00?o
0000ooooooooool0Foooool0077ooooo00?o0000ooooooooool08?ooool6o`00013ooooo00?o0000
ooooooooool0=Oooool6o`0004Gooooo1ol0000Tooooo`03o`000?oooooooooo01[ooooo2?l00004
ooooo`03o`000?oooooooooo05[ooooo001booooo`03o`000?oooooooooo01oooooo1_l0000Aoooo
o`03o`000?oooooooooo03Cooooo1ol00015ooooo`Ko00009Oooool00ol0003oooooooooo`0Joooo
o`So00001?ooool00ol0003oooooooooo`1Iooooo`00Loooool00ol0003oooooooooo`0Nooooo`Oo
00004Oooool00ol0003oooooooooo`0cooooo`Oo0000AOooool7o`0002Gooooo00?o0000oooooooo
ool06_ooool7o`0000Cooooo00?o0000ooooooooool0FOooool007Cooooo00?o0000ooooooooool0
7_ooool6o`0001;ooooo00?o0000ooooooooool0<oooool7o`0004Gooooo1ol0000Uooooo`03o`00
0?oooooooooo01[ooooo1ol00004ooooo`03o`000?oooooooooo05Sooooo001eooooo`03o`000?oo
oooooooo01gooooo1ol0000Booooo`03o`000?oooooooooo03;ooooo2?l00014ooooo`Oo00009_oo
ool00ol0003oooooooooo`0Iooooo`So00001?ooool00ol0003oooooooooo`1Gooooo`00M_ooool0
0ol0003oooooooooo`0Looooo`Oo00004oooool00ol0003oooooooooo`0booooo`Oo0000A?ooool8
o`0002Gooooo00?o0000ooooooooool06_ooool7o`0000Gooooo00?o0000ooooooooool0E_ooool0
07Oooooo00?o0000ooooooooool07?ooool7o`0001?ooooo00?o0000ooooooooool0<Oooool7o`00
04Gooooo1ol0000Vooooo`03o`000?oooooooooo01Wooooo2?l00005ooooo`03o`000?oooooooooo
05Gooooo001hooooo`;o00007?ooool7o`0001Cooooo00?o0000ooooooooool0<Oooool7o`0004Go
oooo1_l0000Wooooo`03o`000?oooooooooo01Wooooo1ol00005ooooo`03o`000?oooooooooo05Go
oooo001jooooo`03o`000?oooooooooo01[ooooo1ol0000Cooooo`03o`000?oooooooooo00;ooooo
00?o0?l0o`000?l00000;Oooool6o`0004Gooooo1ol0000Wooooo`03o`000?oooooooooo01Wooooo
1ol00005ooooo`03o`000?oooooooooo05Cooooo001kooooo`03o`000?oooooooooo01Wooooo1ol0
000Dooooo`05o`000?ooooooooooooooool0o`000_ooool6o`0002Oooooo1_l00016ooooo`Oo0000
9oooool00ol0003oooooooooo`0Hooooo`So00001Oooool00ol0003oooooooooo`1Cooooo`00O?oo
ool00ol0003oooooooooo`0Iooooo`Ko00005Oooool00ol0003oooooo`3o0009ooooo`Co00008ooo
ool7o`0004Gooooo1ol0000Xooooo`03o`000?oooooooooo01Sooooo1ol00006ooooo`03o`000?oo
oooooooo05;ooooo001mooooo`03o`000?oooooooooo01Sooooo1ol0000Eooooo`03o`000?l0o`3o
oooo00cooooo1_l0000Nooooo`Ko0000AOooool8o`0002Oooooo00?o0000ooooooooool06?ooool8
o`0000Kooooo00?o0000ooooooooool0DOooool007kooooo00?o0000ooooooooool06?ooool6o`00
01Kooooo00?o0?l0ooooooooool04Oooool7o`0001Oooooo1ol00015ooooo`Oo0000:?ooool00ol0
003oooooooooo`0Hooooo`Oo00001_ooool00ol0003oooooooooo`1Aooooo`00Ooooool00ol0003o
ooooooooo`0Gooooo`Ko00005_ooool00ol0o`3o0000ooooo`0Hooooo`?o00005?ooool7o`0004Ko
oooo1_l0000Yooooo`03o`000?oooooooooo01Sooooo1_l00007ooooo`03o`000?oooooooooo053o
oooo0020ooooo`03o`000?oooooooooo01Kooooo1ol0000Eooooo`03o`3o0?oooooo000001_ooooo
1ol0000>ooooo`Ko0000A_ooool7o`0002Wooooo00?o0000ooooooooool05oooool7o`0000Oooooo
00?o0000ooooooooool0Coooool0087ooooo00?o0000ooooooooool05_ooool6o`0001Gooooo00Co
0?l0oooooooooooo00008Oooool6o`0000Sooooo1ol00016ooooo`Ko0000:_ooool00ol0003ooooo
ooooo`0Gooooo`Ko00002?ooool00ol0003oooooooooo`1>ooooo`00P_ooool00ol0003ooooooooo
o`0Eooooo`Ko00005Oooool01Ol0o`3ooooooooooooooooo000002Kooooo1?l00005ooooo`Ko0000
A_ooool7o`0002[ooooo00?o0000ooooooooool05_ooool6o`0000Wooooo00?o0000ooooooooool0
COooool008?ooooo00?o0000ooooooooool05?ooool7o`0001Cooooo00?o0?l0ooooooooool00_oo
ool00ol0003oooooooooo`0Wooooo`_o0000A_ooool7o`0002[ooooo00?o0000ooooooooool05_oo
ool7o`0000Sooooo00?o0000ooooooooool0COooool008Cooooo00?o0000ooooooooool05?ooool6
o`0001Cooooo00?o0?l0ooooooooool00oooool00ol0003oooooooooo`0[ooooo`So0000AOooool7
o`0002[ooooo00?o0000ooooooooool05_ooool7o`0000Sooooo00?o0000ooooooooool0C?ooool0
08Gooooo00?o0000ooooooooool04oooool7o`0001?ooooo00?o0?l0ooooooooool01?ooool00ol0
003oooooooooo`0[ooooo`Ko000000Coooooo`000?l0003o0000@_ooool8o`0002[ooooo00?o0000
ooooooooool05Oooool7o`0000Wooooo00?o0000ooooooooool0Boooool008Kooooo00?o0000oooo
ooooool04_ooool7o`0001?ooooo00?o0?l0ooooooooool01Oooool00ol0003oooooooooo`0Zoooo
o`Oo00000oooool7o`0003cooooo1ol0000[ooooo`03o`000?oooooooooo01Cooooo2?l00009oooo
o`03o`000?oooooooooo04[ooooo0027ooooo`03o`000?oooooooooo01;ooooo1ol0000Booooo`03
o`3o0?oooooooooo00Kooooo00?o0000ooooooooool0:Oooool7o`0000[ooooo1_l0000fooooo`Oo
0000;?ooool00ol0003oooooooooo`0Dooooo`Oo00002_ooool00ol0003oooooooooo`19ooooo`00
R?ooool00ol0003oooooooooo`0Aooooo`Oo00004_ooool00ol0o`3oooooooooo`07ooooo`03o`00
0?oooooooooo02Wooooo1ol0000?ooooo`Co0000<oooool7o`0002cooooo00?o0000ooooooooool0
5?ooool6o`0000[ooooo00?o0000ooooooooool0BOooool008Wooooo00?o0000ooooooooool04Ooo
ool6o`0001;ooooo00?o0?l0ooooooooool02?ooool00ol0003oooooooooo`0Xooooo`Oo00004ooo
ool2o`000004o`3o0?l0003o0000o`0002kooooo1_l0000/ooooo`03o`000?oooooooooo01Cooooo
1ol0000:ooooo`03o`000?oooooooooo04Sooooo002:ooooo`03o`000?oooooooooo013ooooo1ol0
000Aooooo`03o`3o0?oooooooooo00Wooooo00?o0000ooooooooool0:?ooool7o`0001Cooooo00Co
0?l0oooooooooooooooo1ol0000Wooooo`Ko0000;Oooool00ol0003oooooooooo`0Dooooo`Oo0000
2_ooool00ol0003oooooooooo`17ooooo`00Roooool00ol0003oooooooooo`0@ooooo`Ko00004Ooo
ool00ol0o`3oooooooooo`0:ooooo`03o`000?oooooooooo02Oooooo1ol0000Dooooo`03o`3o0?oo
oooooooo00Sooooo1_l0000Qooooo`Oo0000;Oooool00ol0003oooooooooo`0Cooooo`Oo00002ooo
ool00ol0003oooooooooo`16ooooo`00S?ooool00ol0003oooooooooo`0?ooooo`Ko00004?ooool0
0ol0o`3oooooooooo`0<ooooo`03o`000?oooooooooo02Oooooo1_l0000Dooooo`03o`3o0?oooooo
oooo00kooooo0ol0000Oooooo`Ko0000;_ooool00ol0003oooooooooo`0Booooo`So00002oooool0
0ol0003oooooooooo`15ooooo`00SOooool00ol0003oooooooooo`0>ooooo`Oo00003oooool00ol0
o`3oooooooooo`0=ooooo`03o`000?oooooooooo02Kooooo1ol0000Cooooo`03o`3o0?oooooooooo
017ooooo1ol0000Hooooo`Oo0000;_ooool00ol0003oooooooooo`0Booooo`Oo00002oooool00ol0
003oooooooooo`15ooooo`00S_ooool00ol0003oooooooooo`0>ooooo`Oo00003_ooool00ol0o`3o
ooooooooo`0>ooooo`03o`000?oooooooooo02Kooooo1_l0000Cooooo`03o`3o0?oooooooooo01So
oooo1_l0000Booooo`Oo0000;oooool00ol0003oooooooooo`0Booooo`Ko00003?ooool00ol0003o
ooooooooo`14ooooo`00Soooool2o`0000kooooo1ol0000>ooooo`03o`3o0?oooooooooo00oooooo
00?o0000ooooooooool09Oooool6o`0001?ooooo00?o0?l0ooooooooool07_ooool4o`0000oooooo
1ol0000^ooooo`03o`000?oooooooooo01;ooooo1ol0000<ooooo`03o`000?oooooooooo04?ooooo
002Aooooo`03o`000?oooooooooo00_ooooo2?l0000=ooooo`03o`3o0?oooooooooo013ooooo00?o
0000ooooooooool09?ooool7o`0001;ooooo00?o0?l0ooooooooool08_ooool6o`0000Wooooo1ol0
000_ooooo`03o`000?oooooooooo01;ooooo1ol0000<ooooo`03o`000?oooooooooo04;ooooo002B
ooooo`03o`000?oooooooooo00_ooooo1ol0000=ooooo`03o`3o0?oooooooooo017ooooo00?o0000
ooooooooool09?ooool6o`0001;ooooo00?o0?l0ooooooooool0:?ooool7o`0000?ooooo1_l0000`
ooooo`03o`000?oooooooooo017ooooo1ol0000=ooooo`03o`000?oooooooooo047ooooo002Coooo
o`03o`000?oooooooooo00_ooooo1ol0000<ooooo`03o`3o0?oooooooooo01;ooooo00?o0000oooo
ooooool08oooool7o`00017ooooo00?o0?l0ooooooooool0;oooool:o`00033ooooo00?o0000oooo
ooooool04?ooool7o`0000gooooo00?o0000ooooooooool0@Oooool009Cooooo00?o0000oooooooo
ool02_ooool7o`0000cooooo00?o0?l0ooooooooool04oooool00ol0003oooooooooo`0Rooooo`Oo
00004Oooool00ol0o`3oooooooooo`0cooooo`Ko0000<Oooool00ol0003oooooooooo`0@ooooo`Oo
00003Oooool00ol0003oooooooooo`10ooooo`00UOooool00ol0003oooooooooo`0:ooooo`Ko0000
3?ooool00ol0o`3oooooooooo`0Dooooo`03o`000?oooooooooo02;ooooo1_l0000Aooooo`03o`3o
0?oooooooooo03?ooooo3?l0000/ooooo`03o`000?oooooooooo013ooooo1_l0000>ooooo`03o`00
0?oooooooooo03oooooo002Fooooo`03o`000?oooooooooo00Wooooo1ol0000;ooooo`03o`3o0?oo
oooooooo01Gooooo00?o0000ooooooooool08Oooool7o`00013ooooo00?o0?l0ooooooooool0<ooo
ool7o`0000Gooooo1_l0000Vooooo`03o`000?oooooooooo013ooooo1_l0000?ooooo`03o`000?oo
oooooooo03kooooo002Gooooo`03o`000?oooooooooo00Wooooo1_l0000;ooooo`03o`3o0?oooooo
oooo01Kooooo00?o0000ooooooooool08Oooool6o`00013ooooo00?o0?l0ooooooooool0=?ooool6
o`0000_ooooo1_l0000Qooooo`03o`000?oooooooooo00oooooo1ol0000?ooooo`03o`000?oooooo
oooo03gooooo002Hooooo`03o`000?oooooooooo00Sooooo1_l0000;ooooo`03o`3o0?oooooooooo
01Oooooo00?o0000ooooooooool08?ooool6o`00013ooooo00?o0?l0ooooooooool0=?ooool7o`00
013ooooo0_l000000ol0o`3o0000ooooo`0Mooooo`03o`000?oooooooooo00oooooo1ol0000>oooo
o`03o`000?oooooooooo03gooooo002Iooooo`03o`000?oooooooooo00Oooooo1ol0000:ooooo`03
o`3o0?oooooooooo01Sooooo00?o0000ooooooooool07oooool7o`0000oooooo00?o0?l0oooooooo
ool0=Oooool6o`0001;ooooo00?o0?l0ooooool000001Ol0000Iooooo`03o`000?oooooooooo00ko
oooo1ol0000?ooooo`03o`000?oooooooooo03cooooo002Jooooo`03o`000?oooooooooo00Oooooo
1ol00009ooooo`03o`3o0?oooooooooo01Wooooo00?o0000ooooooooool07oooool7o`0000kooooo
00?o0?l0ooooooooool0=Oooool6o`0001;ooooo00?o0?l0ooooooooool01Oooool6o`0001Cooooo
00?o0000ooooooooool03Oooool7o`00013ooooo00?o0000ooooooooool0>oooool009_ooooo00?o
0000ooooooooool01_ooool7o`0000Wooooo00?o0?l0ooooooooool06_ooool00ol0003ooooooooo
o`0Nooooo`Oo00003_ooool00ol0o`3oooooooooo`0eooooo`Oo00004Oooool00ol0o`3ooooooooo
o`0;ooooo`Oo00003_ooool00ol0003oooooooooo`0=ooooo`Oo00004?ooool00ol0003ooooooooo
o`0jooooo`00W?ooool00ol0003oooooooooo`05ooooo`So00002?ooool00ol0o`3oooooooooo`0K
ooooo`03o`000?oooooooooo01gooooo2?l0000=ooooo`03o`3o0?oooooooooo03Kooooo1_l0000A
ooooo`03o`3o0?oooooooooo01;ooooo0ol0000;ooooo`03o`000?oooooooooo00kooooo1_l0000A
ooooo`03o`000?oooooooooo03Wooooo002Mooooo`03o`000?oooooooooo00Gooooo2?l00006oooo
o`03o`3o0?oooooooooo01gooooo00?o0000ooooooooool07Oooool7o`0000gooooo00?o0?l0oooo
ooooool0=_ooool7o`00013ooooo00?o0?l0ooooooooool05Oooool6o`0000Kooooo00?o0000oooo
ooooool03Oooool6o`00017ooooo00?o0000ooooooooool0>Oooool009kooooo00?o0000oooooooo
ool01Oooool7o`0000Kooooo00?o0?l0ooooooooool07_ooool00ol0003oooooooooo`0Mooooo`Oo
00003?ooool00ol0o`3oooooooooo`0fooooo`Oo00004?ooool00ol0o`3oooooooooo`0Kooooo`Ko
000000?oooooo`000?ooool03Oooool7o`00017ooooo00?o0000ooooooooool0>?ooool009oooooo
00?o0000ooooooooool01?ooool8o`0000Gooooo00?o0?l0ooooooooool07oooool00ol0003ooooo
ooooo`0Looooo`Oo00003?ooool00ol0o`3oooooooooo`0gooooo`Ko00004?ooool00ol0o`3ooooo
ooooo`0Qooooo`Oo00002_ooool6o`0001;ooooo00?o0000ooooooooool0=oooool00:3ooooo00?o
0000ooooooooool01?ooool8o`0000Cooooo00?o0?l0ooooooooool08?ooool00ol0003ooooooooo
o`0Looooo`Ko00003?ooool00ol0o`3oooooooooo`0gooooo`Oo00003oooool00ol0o`3ooooooooo
o`0Tooooo`04o`000?ooooooooooooooo`Ko00001?ooool7o`0001;ooooo00?o0000ooooooooool0
=_ooool00:7ooooo00?o0000ooooooooool01?ooool7o`0000Cooooo00?o0?l0ooooooooool08Ooo
ool00ol0003oooooooooo`0Kooooo`Oo00002oooool00ol0o`3oooooooooo`0hooooo`Ko00003ooo
ool00ol0o`3oooooooooo`0Tooooo`03o`000?oooooooooo00Oooooo0ol000000ooooooo0000o`00
0005o`0001?ooooo00?o0000ooooooooool0=Oooool00:;ooooo00?o0000ooooooooool00oooool8
o`0000?ooooo00?o0?l0ooooooooool08_ooool00ol0003oooooooooo`0Kooooo`Ko00002oooool0
0ol0o`3oooooooooo`0hooooo`Ko00003oooool00ol0o`3oooooooooo`0Uooooo`03o`000?oooooo
oooo00Wooooo2?l0000Cooooo`03o`000?oooooooooo03Gooooo002Sooooo`03o`000?oooooooooo
00?ooooo1ol00003ooooo`03o`3o0?oooooooooo02?ooooo00?o0000ooooooooool06_ooool6o`00
00_ooooo00?o0?l0ooooooooool0>?ooool7o`0000kooooo00?o0?l0ooooooooool09_ooool00ol0
003oooooooooo`0:ooooo`_o00003oooool00ol0003oooooooooo`0dooooo`00Y?ooool00ol0003o
ooooooooo`03ooooo`Ko00000oooool00ol0o`3oooooooooo`0Tooooo`03o`000?oooooooooo01Wo
oooo1ol0000:ooooo`03o`3o0?oooooooooo03Wooooo1_l0000>ooooo`03o`3o0?oooooooooo02Oo
oooo00?o0000ooooooooool02_ooool6o`0000Cooooo1_l0000:ooooo`03o`000?oooooooooo03?o
oooo002Uooooo`;o00000oooool7o`0000;ooooo00?o0?l0ooooooooool09Oooool00ol0003ooooo
ooooo`0Iooooo`Ko00002_ooool00ol0o`3oooooooooo`0iooooo`Oo00003Oooool00ol0o`3ooooo
ooooo`0Xooooo`03o`000?oooooooooo00Wooooo1_l0000:ooooo`?o00002?ooool00ol0003ooooo
ooooo`0booooo`00Yoooool01?l0003oooooooooooooool7o`000003ooooool0o`3ooooo02Oooooo
00?o0000ooooooooool06?ooool7o`0000Wooooo00?o0?l0ooooooooool0>Oooool7o`0000gooooo
00?o0?l0ooooooooool0:Oooool00ol0003oooooooooo`08ooooo`Oo00003?ooool4o`0000Cooooo
00?o0000ooooooooool0<_ooool00:Sooooo00?o0000ooooooooool02?l000000ol0o`3ooooooooo
o`0Wooooo`03o`000?oooooooooo01Oooooo1ol00009ooooo`03o`3o0?oooooooooo03[ooooo1_l0
000=ooooo`03o`3o0?oooooooooo02Wooooo00?o0000ooooooooool02Oooool6o`0000oooooo00?o
0?l0ooooooooool00oooool00ol0003oooooooooo`0aooooo`00ZOooool00ol0003oooooo`000008
o`0002[ooooo00?o0000ooooooooool05oooool7o`0000Sooooo00?o0?l0ooooooooool0>_ooool7
o`0000cooooo00?o0?l0ooooooooool0:_ooool00ol0003oooooooooo`08ooooo`Oo00003_ooool0
0ol0o`3oooooooooo`04ooooo`03o`000?oooooooooo033ooooo002Zooooo`03o`000?oooooo0000
00So0000:_ooool00ol0003oooooooooo`0Fooooo`Oo00001oooool00ol0o`3oooooooooo`0loooo
o`Ko00003?ooool00ol0o`3oooooooooo`0[ooooo`03o`000?oooooooooo00Oooooo1ol0000>oooo
o`03o`3o0?oooooooooo00Gooooo00?o0000ooooooooool0;oooool00:_ooooo00?o0000ooooool0
00002?l0000Hoooooa?o00006?ooool6o`0000Oooooo00?o0?l0ooooooooool0??ooool6o`0000co
oooo00?o0?l0ooooooooool0;?ooool00ol0003oooooooooo`07ooooo`Ko00003_ooool00ol0o`3o
ooooooooo`06ooooo`03o`000?oooooooooo02kooooo002/ooooo`03o`000?oooooo000000Wo0000
4ooooolIo`0001Gooooo1ol00006ooooo`03o`3o0?oooooooooo03cooooo1ol0000;ooooo`03o`3o
0?oooooooooo02gooooo00?o0000ooooooooool01_ooool7o`0000gooooo00?o0?l0ooooooooool0
1_ooool00ol0003oooooooooo`0^ooooo`00[Oooool00ol0003oooooo`00000:o`0000gooooo7ol0
000Dooooo`Oo00001Oooool00ol0o`3oooooooooo`0mooooo`Ko00002oooool00ol0o`3ooooooooo
o`0^ooooo`03o`000?oooooooooo00Kooooo1_l0000=ooooo`03o`3o0?oooooooooo00Oooooo00?o
0000ooooooooool0;Oooool00:kooooo00?o0000ooooool000002ol0000:ooooob7o00004oooool7
o`0000Gooooo00?o0?l0ooooooooool0?Oooool7o`0000[ooooo00?o0?l0ooooooooool0;_ooool0
0ol0003oooooooooo`06ooooo`Ko00003Oooool00ol0o`3oooooooooo`08ooooo`03o`000?oooooo
oooo02cooooo002_ooooo`03o`000?oooooo000000co00000_oooolYo`00017ooooo2?l00004oooo
o`03o`3o0?oooooooooo03gooooo1ol0000:ooooo`03o`3o0?oooooooooo02oooooo00?o0000oooo
ooooool01Oooool7o`0000cooooo0_l0o`0:ooooo`03o`000?oooooooooo02_ooooo002`ooooo`03
o`000?oooooo000001oo00002oooool>o`00013ooooo2?l00003ooooo`03o`3o0?oooooooooo03ko
oooo1ol00009ooooo`03o`3o0?oooooooooo033ooooo00?o0000ooooooooool01Oooool7o`0000co
oooo00?o0?l0ooooooooool02Oooool00ol0003oooooooooo`0Zooooo`00/Oooool00ol0003ooooo
ooooo`0Ko`00017ooooo3?l0000@ooooo`Oo00000oooool00ol0o`3oooooooooo`0nooooo`Oo0000
2Oooool00ol0o`3oooooooooo`0aooooo`03o`000?oooooooooo00Cooooo1ol0000<ooooo`03o`3o
0?oooooooooo00Wooooo00?o0000ooooooooool0:_ooool00;;ooooo00Co0000oooooooooooooooo
5Ol0000Gooooo`co00003_ooool8o`0000;ooooo00?o0?l0ooooooooool0?oooool6o`0000Wooooo
00?o0?l0ooooooooool0<_ooool00ol0003oooooooooo`03ooooo`Oo00003?ooool00ol0o`3ooooo
ooooo`0:ooooo`03o`000?oooooooooo02Wooooo002cooooo`03o`000?oooooooooo00;ooooo4_l0
000Iooooo`co00003_ooool7o`0000;ooooo00?o0?l0ooooooooool0?oooool7o`0000Sooooo00?o
0?l0ooooooooool0<oooool00ol0003oooooooooo`03ooooo`Oo00002oooool00ol0o`3ooooooooo
o`0;ooooo`03o`000?oooooooooo02Sooooo002dooooo`03o`000?oooooooooo00?ooooo2_l0000Q
ooooo`_o00003_ooool7o`000003ooooool0o`3ooooo047ooooo1_l00008ooooo`03o`3o0?oooooo
oooo03?ooooo00?o0000ooooooooool01?ooool6o`0000_ooooo00?o0?l0ooooooooool03?ooool0
0ol0003oooooooooo`0Wooooo`00]Oooool00ol0003oooooooooo`0_ooooo`[o00003Oooool8o`00
0003o`3o0?oooooooooo043ooooo1ol00007ooooo`03o`3o0?oooooooooo03Cooooo00?o0000oooo
ooooool00oooool6o`0000_ooooo00?o0?l0ooooooooool03Oooool00ol0003oooooooooo`0Voooo
o`00]_ooool00ol0003oooooooooo`0_ooooo`[o00003Oooool8o`0004;ooooo1ol00007ooooo`03
o`3o0?oooooooooo03Gooooo00?o0000ooooooooool00_ooool7o`0000[ooooo00?o0?l0oooooooo
ool03Oooool00ol0003oooooooooo`0Vooooo`00]oooool00ol0003oooooooooo`0`ooooo`[o0000
2oooool9o`0004;ooooo1ol00006ooooo`03o`3o0?oooooooooo03Kooooo00?o0000ooooooooool0
0_ooool6o`0000[ooooo00?o0?l0ooooooooool03_ooool00ol0003oooooooooo`0Uooooo`00^?oo
ool00ol0003oooooooooo`0`ooooo`[o00002oooool8o`0001_ooooo2Ol0000Nooooo`So00001Ooo
ool00ol0o`3oooooooooo`0gooooo`04o`000?ooooooooooooooo`Oo00002Oooool00ol0o`3ooooo
ooooo`0?ooooo`03o`000?oooooooooo02Cooooo002iooooo`03o`000?oooooooooo033ooooo2Ol0
000<ooooo`Wo00005OoooolBo`0001[ooooo1ol00005ooooo`03o`3o0?oooooooooo03Sooooo00?o
0000ooooooooool01ol00009ooooo`03o`3o0?oooooooooo013ooooo00?o0000ooooooooool08ooo
ool00;[ooooo00?o0000ooooooooool0<?ooool;o`0000[ooooo2Ol0000AoooooaKo00006Oooool8
o`0000Cooooo00?o0?l0ooooooooool0>?ooool01?l0003oooooooooooooool6o`0000Wooooo00?o
0?l0ooooooooool04Oooool00ol0003oooooooooo`0Rooooo`00^oooool00ol0003oooooooooo`0`
ooooo`Oo00000oooool6o`0000Gooooo2?l0000=oooooago00005oooool7o`0000Cooooo00?o0?l0
ooooooooool0>Oooool00ol0003oooooooooo`07o`0000Sooooo00?o0?l0ooooooooool04Oooool0
0ol0003oooooooooo`0Rooooo`00_?ooool2o`0003;ooooo1Ol00009ooooo`oo00002_oooolOo`00
01Oooooo1_l00004ooooo`03o`3o0?oooooooooo03[ooooo00?o0000ooooooooool01_l00008oooo
o`03o`3o0?oooooooooo01;ooooo00?o0000ooooooooool08Oooool00;kooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`0?ooooo`co00000_oooolEo`000003ooooool0003o000000ko
00005Oooool7o`0000?ooooo00?o0?l0ooooooooool0>oooool00ol0003oooooo`000005o`0000So
oooo00?o0?l0ooooooooool04oooool00ol0003oooooooooo`0Pooooo`00_oooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo013ooooo7Ol0000:ooooo`co00005Oooool7o`0000;ooooo
00?o0?l0ooooooooool0??ooool8o`0000Oooooo00?o0?l0ooooooooool05?ooool00ol0003ooooo
ooooo`0Oooooo`00`?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00oooooo6_l0
000>ooooo`go00004oooool7o`0000;ooooo00?o0?l0ooooooooool0?Oooool8o`0000Kooooo00?o
0?l0ooooooooool05Oooool00ol0003oooooooooo`0Nooooo`00`Oooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo00oooooo5ol0000Cooooo`_o00004_ooool8o`000003ooooool0o`3o
oooo03kooooo2?l00006ooooo`;o0?l05_ooool00ol0003oooooooooo`0Nooooo`00`_ooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo013ooooo4_l00003ooooo`Ko00003_ooool:o`00
01?ooooo1ol000000ooooooo0?l0ooooo`0oooooo`Oo00001oooool00ol0o`3oooooooooo`0Eoooo
o`03o`000?oooooooooo01gooooo0033ooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool04_ooool:o`0000kooooo0ol0000=ooooo`[o00004_ooool7o`000003o`3o0?oooooooooo03oo
oooo1ol00006ooooo`03o`3o0?oooooooooo01Kooooo00?o0000ooooooooool07?ooool00<Cooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0/ooooo`Ko00002?ooool:o`00017ooooo
2?l00012ooooo`Ko00001_ooool00ol0o`3oooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo
0035ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0<Oooool6o`0000Cooooo2Ol0
000Aooooo`Oo0000@_ooool6o`0000Kooooo00?o0?l0ooooooooool06?ooool00ol0003ooooooooo
o`0Jooooo`00a_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo03Oooooo3_l0000@
ooooo`So0000@Oooool7o`0000Gooooo00?o0?l0ooooooooool06?ooool00ol0003oooooooooo`0J
ooooo`00aoooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo03_ooooo2Ol0000Aoooo
o`So00005?ooool>o`0001oooooo1_l00005ooooo`03o`3o0?oooooooooo01Wooooo00?o0000oooo
ooooool06Oooool00<Sooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0looooo`co
00003Oooool8o`00013ooooo4ol0000Mooooo`Ko00001Oooool00ol0o`3oooooooooo`0Jooooo`03
o`000?oooooooooo01Sooooo0039ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
??ooool6o`0000Gooooo1_l00007ooooo`Wo00003OoooolHo`0001[ooooo1ol00004ooooo`03o`3o
0?oooooooooo01_ooooo00?o0000ooooooooool05oooool00<[ooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`0looooo`Go00002oooool6o`0000;ooooo2?l0000;oooooa_o00006_oo
ool7o`0000?ooooo00?o0?l0ooooooooool07?ooool00ol0003oooooooooo`0Fooooo`00boooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo057ooooo3Ol00006oooooako00006Oooool7
o`0000?ooooo00?o0?l0ooooooooool07?ooool00ol0003oooooooooo`0Fooooo`00c?ooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo05Cooooo7?l00006ooooo`go00005oooool8o`00
00;ooooo00?o0?l0ooooooooool07Oooool00ol0003oooooooooo`0Eooooo`00cOooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo05Cooooo6?l0000;ooooo`co00005oooool7o`0000;o
oooo00?o0?l0ooooooooool07_ooool00ol0003oooooooooo`0Dooooo`00c_ooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo05?ooooo5_l0000@ooooo`[o00005oooool7o`000003oooo
ool0o`3ooooo023ooooo00?o0000ooooooooool04oooool00<oooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`1CoooooaGo00004Oooool:o`0001Kooooo2?l000000ol0o`3ooooooooo
o`0Pooooo`03o`000?oooooooooo01;ooooo003@ooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool0EOooool>o`0000Cooooo1_l0000<ooooo`[o00005_ooool7o`000003o`3o0?oooooo
oooo023ooooo00?o0000ooooooooool04_ooool00=7ooooo00?o0000ooooooooool0<?ooool00ol0
003oooooooooo`1Fooooo`So00003_ooool6o`0000Sooooo2Ol0000Eooooo`So00008oooool00ol0
003oooooooooo`0Aooooo`00d_ooool2o`00037ooooo00?o0000ooooooooool0LOooool6o`0000?o
oooo2Ol0000Eooooo`Oo00009?ooool00ol0003oooooooooo`0@ooooo`00e?ooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo07Kooooo3Ol0000Eooooo`Ko000000?o0?l0ooooooooool0
8_ooool00ol0003oooooooooo`0?ooooo`00eOooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo07[ooooo2?l0000Eooooo`Oo00004_ooool=o`0000Kooooo00?o0000ooooooooool03_oo
ool00=Kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1jooooo`co00004Oooool7
o`0000oooooo4?l00005ooooo`03o`000?oooooooooo00kooooo003Gooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool0N_ooool6o`0000Gooooo1_l0000;ooooo`So00003?oooolEo`00
00?ooooo00?o0000ooooooooool03Oooool00=Sooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`1jooooo`Go00002oooool6o`0000Gooooo2Ol00009oooooaSo00000oooool00ol0003o
ooooooooo`0<ooooo`00fOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo08oooooo
4?l00005oooooa_o00000oooool00ol0003oooooooooo`0;ooooo`00f_ooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo09Cooooo2ol00002ooooo`ko00001Oooool;o`0000?ooooo00?o
0000ooooooooool02_ooool00=_ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`2E
oooooaOo00002?ooool;o`0000;ooooo00?o0000ooooooooool02_ooool00=cooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`2EoooooaCo00003Oooool9o`0000;ooooo00?o0000oooo
ooooool02Oooool00=gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`2Eoooooa?o
00003_ooool:o`000003ooooool0003ooooo00Wooooo003Nooooo`03o`000?oooooooooo02oooooo
00?o0000ooooooooool0U_ooool=o`0000Cooooo1_l00009ooooo`[o000000?oooooo`000?ooool0
2?ooool00=oooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`2Fooooo`[o00003?oo
ool6o`0000Cooooo2_l000000ooooooo0000ooooo`07ooooo`00h?ooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo09_ooooo00?o0000ooooooooool04oooool>o`000003ooooool0003o
oooo00Oooooo003Qooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0Voooool00ol0
003oooooooooo`0Hooooo`Wo000000?oooooo`000?ooool01_ooool00>;ooooo00?o0000oooooooo
ool0;oooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo01Wooooo1ol00002ooooo`03
o`000?oooooooooo00Cooooo003Sooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
Voooool00ol0003oooooooooo`0Iooooo`Ko00000oooool00ol0003oooooooooo`03ooooo`00i?oo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo09_ooooo00?o0000ooooooooool06?oo
ool6o`0000;ooooo0ol00004ooooo`00iOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo09_ooooo00?o0000ooooooooool06?ooool7o`0000;ooooo00?o0000ooooooooool00_ooool0
0>Kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo
01Sooooo1?l00005ooooo`03o`000?oooooooooo00;ooooo003Wooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0Dooooo`?o00002Oooool00ol0003o
ooooooooo`02ooooo`00j?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo09[ooooo
00?o0000ooooooooool04?ooool3o`0000cooooo00?o0000ooooooooool00_ooool00>Wooooo0_l0
000`ooooo`03o`000?oooooooooo09[ooooo00?o0000ooooooooool02oooool4o`0000oooooo00?o
0000ooooooooool00_ooool00>_ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`2J
ooooo`03o`000?oooooooooo00Oooooo0ol0000Cooooo`03o`000?oooooooooo00;ooooo003/oooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`02oooo
o`Co00005oooool00ol0003oooooooooo`01ooooo`00kOooool00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo09Wooooo00?o0000ooooool000000_l0000Kooooo`03o`000?oooooooooo007o
oooo003^ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0U_ooool4o`0001kooooo
00?o0000ooooooooool00Oooool00>oooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`2Booooo`?o00001?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo007ooooo003`
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0S_ooool3o`0000Sooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`01ooooo`00lOooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo08Wooooo1?l0000<ooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool00Oooool00?;ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`25ooooo`?o
00004Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo007ooooo003cooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool0P?ooool4o`0001Cooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`01ooooo`00m?ooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo07cooooo0ol0000Iooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00Ooo
ool00?Gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1gooooo`Co00007Oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo007ooooo003fooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool0Loooool3o`0002;ooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`01ooooo`00moooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo06oo
oooo0ol0000Vooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00Oooool00?Sooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Zooooo`Co0000:_ooool00ol0003ooooo
ooooo`0Dooooo`7o00000Oooool1ooooo`00nOooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo06Kooooo0ol0000^ooooo`03o`000?oooooooooo01Cooooo0Ol00001ooooo`7ooooo003j
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0HOooool4o`0003;ooooo00?o0000
ooooooooool04oooool1o`00007ooooo0Oooool00?_ooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`1Mooooo`?o0000=oooool00ol0003oooooooooo`0Booooo`7o00000Oooool1oooo
o`00o?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo05Sooooo1?l0000kooooo`03
o`000?oooooooooo017ooooo0Ol00001ooooo`7ooooo003mooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool0E?ooool3o`00043ooooo00?o0000ooooooooool04?ooool1o`00007ooooo
0Oooool00?kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1?ooooo`Co0000A?oo
ool00ol0003oooooooooo`0?ooooo`7o00000Oooool1ooooo`00ooooool2o`0002oooooo00?o0000
ooooooooool0Boooool3o`0004Sooooo00?o0000ooooooooool03oooool1o`00007ooooo0Oooool0
0?oooooo0_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo04Oooooo0ol0001<oooo
o`03o`000?oooooooooo00kooooo0Ol00001ooooo`7ooooo003oooooo`?ooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`12ooooo`Co0000D?ooool00ol0003oooooooooo`0=ooooo`7o
00000Oooool1ooooo`00ooooool4ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
?_ooool3o`0005Gooooo00?o0000ooooooooool03?ooool1o`00007ooooo0Oooool00?oooooo1Ooo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo03Wooooo1?l0001Iooooo`03o`000?oo
oooooooo00_ooooo0Ol00001ooooo`7ooooo003oooooo`Kooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`0eooooo`?o0000G_ooool00ol0003oooooooooo`0:ooooo`7o00000Oooool1
ooooo`00ooooool7ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0<?ooool4o`00
067ooooo00?o0000ooooooooool02oooool1o`00007ooooo003oooooo`Sooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`0/ooooo`?o0000I_ooool00ol0003oooooooooo`0:ooooo`7o
00000Oooool00?oooooo2Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02Sooooo
0ol0001Zooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`00ooooool:ooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool08oooool4o`0006kooooo00?o0000ooooooooool02?oo
ool1o`00007ooooo003oooooo`_ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0O
ooooo`?o0000Loooool00ol0003oooooooooo`07ooooo`7o00000Oooool00?oooooo3?ooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo01[ooooo1?l0001gooooo`03o`000?oooooooooo
00Kooooo0Ol00001ooooo`00ooooool=ooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool05_ooool3o`0007_ooooo00?o0000ooooooooool01_ooool1o`00007ooooo003oooooo`kooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Aooooo`Co0000Ooooool00ol0003ooooo
ooooo`05ooooo`7o00000Oooool00?oooooo3oooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo00gooooo0ol00024ooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`00ooooool@
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool02Oooool3o`0008Sooooo00?o0000
ooooooooool00oooool1o`00007ooooo003ooooooa7ooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`04ooooo`Co0000S?ooool00ol0003oooooooooo`02ooooo`7o00000Oooool00?oo
oooo4_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00?o0000TOooool01Ol0003o
oooooooooooooooo0000007ooooo003ooooooa?ooooo00?o0000ooooooooool0;Oooool2o`0009Co
oooo00?o0000ooooooooool00_ooool1o`000000oooooolDooooo`03o`000?oooooooooo02cooooo
00?o0000ooooooooool0U?ooool01?l0003oooooooooooooool1o`000000oooooolEooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool0UOooool00ol0003oooooooooo`01o`000000oooo
oolFooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0U_ooool1o`00007ooooo0Ol0
00000?oooooo5oooool2o`0002[ooooo00?o0000ooooooooool0Uoooool2o`000000oooooolIoooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0U_ooool3o`000000oooooolJooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool0T_ooool4o`0000?ooooo003ooooooa_ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`2?ooooo`?o00001oooool00?oooooo7?oo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo08_ooooo1?l0000:ooooo`00oooooolM
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0Qoooool4o`0000kooooo003ooooo
oakooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`24ooooo`?o00004_ooool00?oo
oooo7oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo083ooooo1?l0000Eooooo`00
oooooolPooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0O?ooool4o`0001Wooooo
003oooooob7ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1iooooo`?o00007Ooo
ool00?oooooo8_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo07Gooooo1?l0000P
ooooo`00oooooolSooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0LOooool4o`00
02Cooooo003oooooobCooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1^ooooo`?o
0000:?ooool00?oooooo9Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo06[ooooo
1?l0000[ooooo`00oooooolVooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0I_oo
ool4o`0002oooooo003oooooobOooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1S
ooooo`?o0000<oooool00?oooooo:?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
05oooooo1?l0000fooooo`00oooooolYooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool0Foooool4o`0003[ooooo003oooooob[ooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`1Hooooo`?o0000?_ooool00?oooooo:oooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo05Cooooo1?l00011ooooo`00ooooool/ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0Coooool4o`0004Gooooo003oooooobgooooo0_l0000Eooooo`03o`000?oooooooooo
04cooooo0ol00019ooooo`00ooooool_ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool0B?ooool4o`0004cooooo003ooooooc3ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`14ooooo`Co0000D?ooool00?oooooo<Oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo047ooooo0ol0001Dooooo`00oooooolbooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0?Oooool4o`0005Oooooo003ooooooc?ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0iooooo`Co0000Foooool00?oooooo=?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo03Kooooo0ol0001Oooooo`00ooooooleooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0<_ooool4o`0006;ooooo003oooooocKooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0^ooooo`Co0000I_ooool00?oooooo=oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo02_ooooo0ol0001Zooooo`00oooooolhooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool09oooool4o`0006gooooo003oooooocWooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Sooooo`Co0000LOooool00?oooooo>_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo023ooooo0ol0001eooooo`00oooooolkooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool07?ooool4o`0007Sooooo003ooooooccooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Hooooo`Co0000O?ooool00?oooooo?Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo01Gooooo0ol00020ooooo`00oooooolnooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool4o`0008?ooooo003oooooocoooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`Co0000Qoooool00?oooooo@?oo
ool01Ol0003ooooooooooooooooo000000cooooo0ol0002;ooooo`00oooooom1ooooo`04o`000?oo
ooooooooo`0000Sooooo1?l0002>ooooo`00oooooom2ooooo`03o`000?oooooo000000Cooooo1?l0
002Booooo`00oooooom3ooooo`;o000000Coooooo`000?l0003o0000U_ooool00?ooooooA?ooool2
o`0009Wooooo003oooooomoooooo003oooooomoooooo003oooooomoooooo003oooooomoooooo003o
ooooomoooooo003oooooomoooooo003oooooomoooooo003oooooomoooooo003oooooomoooooo003o
ooooomoooooo003oooooomoooooo003oooooomoooooo003oooooomoooooo003oooooomoooooo003o
ooooomoooooo003oooooomoooooo003oooooomoooooo003oooooomoooooo003oooooomoooooo003o
ooooomoooooo003oooooomoooooo003oooooomoooooo003oooooomoooooo003oooooomoooooo003o
ooooomoooooo003oooooomoooooo003oooooomoooooo003oooooomoooooo003oooooomoooooo003o
ooooomoooooo003oooooomoooooo003oooooomoooooo003oooooomoooooo003oooooomoooooo003o
ooooomoooooo003oooooomoooooo003oooooomoooooo003oooooomoooooo003oooooomoooooo003o
ooooomoooooo003oooooomoooooo0000\
\>"],
  ImageRangeCache->{{{0, 477.75}, {420.438, 0}} -> {0, 0, 0, 0}}],

Cell[TextData[{
  "Fig. 7.1 The solution to Eq. ",
  ButtonBox["(7.1.1)",
    ButtonData:>{"Chapter7.nb", "(7.1.1)"},
    ButtonStyle->"Hyperlink"],
  "  for ",
  Cell[BoxData[
      \(TraditionalForm\`s = 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`v = c\)]],
  ", at four times. Also shown are three characteristics. "
}], "Caption",
  CellTags->"Fig. 7.1"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Example 2: ",
  Cell[BoxData[
      \(TraditionalForm\`s = a\ x\^n\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`v = b\ x\)]],
  "."
}], "Section",
  CellTags->"c:7"],

Cell[TextData[{
  "\tEquations ",
  ButtonBox["(7.1.5)",
    ButtonData:>{"Chapter7.nb", "(7.1.5)"},
    ButtonStyle->"Hyperlink"],
  "  and ",
  ButtonBox["(7.1.6)",
    ButtonData:>{"Chapter7.nb", "(7.1.6)"},
    ButtonStyle->"Hyperlink"],
  "  are now"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[DifferentialD]f/\[DifferentialD]t = 
      a\ x\^n, \[IndentingNewLine]\[DifferentialD]x/\[DifferentialD]t\  = 
      b\ \(\(x\)\(.\)\)\)]]], "UNNEQ"],

Cell[TextData[{
  "The solution to  ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]x/\[DifferentialD]t\  = b\ x\)]],
  " with initial condition ",
  Cell[BoxData[
      \(TraditionalForm\`x = x\_o\)]],
  " provides us with the characteristics:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`x(t, x\_o) = 
        x\_o\ \[ExponentialE]\^\(\(\ \)\(b\ t\)\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(7.1.16)"],

Cell[TextData[{
  "These characteristics are shown in Fig. ",
  ButtonBox["7.2",
    ButtonData:>"Fig. 7.2",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9646 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.66533e-16 1.07848 -0.00533562 1.07848 [
[.21289 .03628 -9.3742 -12 ]
[.21289 .03628 .6258 0 ]
[.84871 .30553 0 -8.01227 ]
[.84871 .30553 10 3.98773 ]
[-0.06055 .34522 -40 -3.77786 ]
[-0.06055 .34522 0 8.22214 ]
[ 0 0 0 0 ]
[ 1 .9646 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02975 .1885 m
.51756 0 L
s
gsave
.21289 .03628 -70.3742 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.51756 0 m
.9781 .59953 L
s
gsave
.84871 .30553 -61 -12.0123 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02975 .1885 m
0 .45327 L
s
gsave
-0.06055 .34522 -101 -7.77786 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(H) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(L) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02975 .1885 m
0 .45327 L
s
0 .45327 m
.55672 .9646 L
s
.55672 .9646 m
.55593 .72459 L
s
.55593 .72459 m
.02975 .1885 L
s
.51756 0 m
.9781 .59953 L
s
.9781 .59953 m
1 .84627 L
s
1 .84627 m
.51621 .27089 L
s
.51621 .27089 m
.51756 0 L
s
.02975 .1885 m
0 .45327 L
s
0 .45327 m
.51621 .27089 L
s
.51621 .27089 m
.51756 0 L
s
.51756 0 m
.02975 .1885 L
s
.55593 .72459 m
.9781 .59953 L
s
.9781 .59953 m
1 .84627 L
s
1 .84627 m
.55672 .9646 L
s
.55672 .9646 m
.55593 .72459 L
s
0 0 m
1 0 L
1 .9646 L
0 .9646 L
closepath
clip
newpath
.5 Mabswid
.95043 .59464 m
.95906 .59668 L
s
.94182 .59264 m
.95043 .59464 L
s
.015 w
.95464 .59576 m
.95941 .6008 L
s
.5 Mabswid
.93324 .59069 m
.94182 .59264 L
s
.92468 .58878 m
.93324 .59069 L
s
.91615 .58692 m
.92468 .58878 L
s
.015 w
.94986 .59102 m
.95464 .59576 L
s
.5 Mabswid
.90764 .58511 m
.91615 .58692 L
s
.89916 .58334 m
.90764 .58511 L
s
.89071 .58162 m
.89916 .58334 L
s
.88228 .57994 m
.89071 .58162 L
s
.015 w
.94509 .58662 m
.94986 .59102 L
s
.5 Mabswid
.87387 .5783 m
.88228 .57994 L
s
.8655 .57671 m
.87387 .5783 L
s
.85715 .57516 m
.8655 .57671 L
s
.84882 .57365 m
.85715 .57516 L
s
.84052 .57218 m
.84882 .57365 L
s
.015 w
.94032 .58265 m
.94509 .58662 L
s
.5 Mabswid
.83224 .57076 m
.84052 .57218 L
s
.82399 .56937 m
.83224 .57076 L
s
.81577 .56803 m
.82399 .56937 L
s
.80757 .56673 m
.81577 .56803 L
s
.7994 .56546 m
.80757 .56673 L
s
.79125 .56424 m
.7994 .56546 L
s
.015 w
.93557 .57918 m
.94032 .58265 L
s
.5 Mabswid
.78313 .56305 m
.79125 .56424 L
s
.77503 .5619 m
.78313 .56305 L
s
.76696 .56079 m
.77503 .5619 L
s
.75892 .55972 m
.76696 .56079 L
s
.7509 .55868 m
.75892 .55972 L
s
.7429 .55769 m
.7509 .55868 L
s
.73494 .55672 m
.7429 .55769 L
s
.015 w
.93084 .57628 m
.93557 .57918 L
s
.5 Mabswid
.72699 .5558 m
.73494 .55672 L
s
.71907 .5549 m
.72699 .5558 L
s
.71118 .55405 m
.71907 .5549 L
s
.70331 .55323 m
.71118 .55405 L
s
.69547 .55244 m
.70331 .55323 L
s
.68765 .55168 m
.69547 .55244 L
s
.67985 .55096 m
.68765 .55168 L
s
.67208 .55028 m
.67985 .55096 L
s
.66434 .54962 m
.67208 .55028 L
s
.65662 .549 m
.66434 .54962 L
s
.64892 .54841 m
.65662 .549 L
s
.015 w
.92613 .57403 m
.93084 .57628 L
s
.5 Mabswid
.64125 .54785 m
.64892 .54841 L
s
.6336 .54732 m
.64125 .54785 L
s
.62598 .54682 m
.6336 .54732 L
s
.61838 .54635 m
.62598 .54682 L
s
.015 w
.65327 .55046 m
.65672 .55315 L
s
.5 Mabswid
.61081 .54591 m
.61838 .54635 L
s
.60326 .54551 m
.61081 .54591 L
s
.59573 .54513 m
.60326 .54551 L
s
.38744 .54524 m
.39432 .54492 L
s
.58823 .54478 m
.59573 .54513 L
s
.39432 .54492 m
.40121 .54463 L
s
.58075 .54445 m
.58823 .54478 L
s
.40121 .54463 m
.40813 .54435 L
s
.5733 .54416 m
.58075 .54445 L
s
.40813 .54435 m
.41507 .54409 L
s
.56587 .54389 m
.5733 .54416 L
s
.41507 .54409 m
.42203 .54385 L
s
.55846 .54365 m
.56587 .54389 L
s
.42203 .54385 m
.42901 .54364 L
s
.55107 .54344 m
.55846 .54365 L
s
.42901 .54364 m
.43601 .54344 L
s
.54371 .54326 m
.55107 .54344 L
s
.43601 .54344 m
.44304 .54327 L
s
.44304 .54327 m
.45008 .54311 L
s
.53637 .5431 m
.54371 .54326 L
s
.45008 .54311 m
.45715 .54298 L
s
.52906 .54296 m
.53637 .5431 L
s
.015 w
.38491 .54826 m
.38731 .5494 L
s
.5 Mabswid
.45715 .54298 m
.46424 .54288 L
s
.52177 .54286 m
.52906 .54296 L
s
.46424 .54288 m
.47136 .54279 L
s
.5145 .54277 m
.52177 .54286 L
s
.47136 .54279 m
.47849 .54273 L
s
.50725 .54272 m
.5145 .54277 L
s
.47849 .54273 m
.48565 .54269 L
s
.50003 .54268 m
.50725 .54272 L
s
.48565 .54269 m
.49282 .54267 L
s
.49282 .54267 m
.50003 .54268 L
s
.015 w
.64982 .54808 m
.65327 .55046 L
s
.92144 .57251 m
.92613 .57403 L
s
.3825 .54744 m
.38491 .54826 L
s
.64637 .54608 m
.64982 .54808 L
s
.38006 .547 m
.3825 .54744 L
s
.37761 .54701 m
.38006 .547 L
s
.64291 .54452 m
.64637 .54608 L
s
.91679 .57179 m
.92144 .57251 L
s
.37513 .54755 m
.37761 .54701 L
s
.63945 .54347 m
.64291 .54452 L
s
.37262 .54868 m
.37513 .54755 L
s
.63598 .54302 m
.63945 .54347 L
s
.91216 .57194 m
.91679 .57179 L
s
.37009 .55049 m
.37262 .54868 L
s
.36751 .55305 m
.37009 .55049 L
s
.63251 .54324 m
.63598 .54302 L
s
.3649 .55644 m
.36751 .55305 L
s
.90757 .573 m
.91216 .57194 L
s
.62904 .54421 m
.63251 .54324 L
s
.36224 .56072 m
.3649 .55644 L
s
.62557 .546 m
.62904 .54421 L
s
.90301 .57502 m
.90757 .573 L
s
.35954 .56593 m
.36224 .56072 L
s
.62209 .54868 m
.62557 .546 L
s
.35679 .57212 m
.35954 .56593 L
s
.89848 .57801 m
.90301 .57502 L
s
.6186 .5523 m
.62209 .54868 L
s
.35399 .57929 m
.35679 .57212 L
s
.61511 .55688 m
.6186 .5523 L
s
.35114 .58743 m
.35399 .57929 L
s
.89397 .58195 m
.89848 .57801 L
s
0 1 0 r
.5 Mabswid
.3158 .47203 m
.31565 .47514 L
s
0 g
.3158 .47203 m
.32186 .47067 L
s
.32186 .47067 m
.32793 .46932 L
s
0 1 0 r
.31565 .47514 m
.31551 .47825 L
s
0 g
.015 w
.61161 .56245 m
.61511 .55688 L
s
.34824 .59648 m
.35114 .58743 L
s
.5 Mabswid
.32793 .46932 m
.33402 .46797 L
s
0 1 0 r
.31551 .47825 m
.31537 .48137 L
s
0 g
.33402 .46797 m
.34012 .46663 L
s
0 1 0 r
.31537 .48137 m
.31522 .48448 L
s
0 g
.34012 .46663 m
.34623 .46529 L
s
.34623 .46529 m
.35235 .46396 L
s
0 1 0 r
.31522 .48448 m
.31508 .48761 L
s
0 g
.35235 .46396 m
.35849 .46263 L
s
.015 w
.88949 .5868 m
.89397 .58195 L
s
0 1 0 r
.5 Mabswid
.31508 .48761 m
.31493 .49073 L
s
0 g
.35849 .46263 m
.36464 .46131 L
s
0 1 0 r
.31493 .49073 m
.31479 .49386 L
s
0 g
.36464 .46131 m
.37081 .46 L
s
.015 w
.34528 .60636 m
.34824 .59648 L
s
.6081 .56898 m
.61161 .56245 L
s
.5 Mabswid
.37081 .46 m
.37699 .4587 L
s
0 1 0 r
.31479 .49386 m
.31464 .497 L
s
0 g
.37699 .4587 m
.38318 .4574 L
s
0 1 0 r
.31464 .497 m
.31449 .50013 L
s
0 g
.38318 .4574 m
.38939 .4561 L
s
0 1 0 r
.31449 .50013 m
.31435 .50328 L
s
0 g
.38939 .4561 m
.39561 .45482 L
s
.39561 .45482 m
.40184 .45354 L
s
0 1 0 r
.31435 .50328 m
.3142 .50642 L
s
0 g
.40184 .45354 m
.40809 .45227 L
s
0 1 0 r
.3142 .50642 m
.31406 .50957 L
s
0 g
.40809 .45227 m
.41435 .451 L
s
.015 w
.34228 .61696 m
.34528 .60636 L
s
0 1 0 r
.5 Mabswid
.31406 .50957 m
.31391 .51273 L
s
0 g
.41435 .451 m
.42062 .44975 L
s
.015 w
.88501 .59246 m
.88949 .5868 L
s
.60457 .57644 m
.6081 .56898 L
s
.5 Mabswid
.42062 .44975 m
.42691 .4485 L
s
0 1 0 r
.31391 .51273 m
.31376 .51589 L
s
0 g
.42691 .4485 m
.43322 .44726 L
s
0 1 0 r
.31376 .51589 m
.31362 .51905 L
s
0 g
.43322 .44726 m
.43953 .44603 L
s
.43953 .44603 m
.44586 .4448 L
s
0 1 0 r
.31362 .51905 m
.31347 .52222 L
s
0 g
.44586 .4448 m
.45221 .44358 L
s
0 1 0 r
.31347 .52222 m
.31332 .52539 L
s
0 g
.45221 .44358 m
.45857 .44238 L
s
.45857 .44238 m
.46494 .44118 L
s
0 1 0 r
.31332 .52539 m
.31318 .52856 L
s
0 g
.015 w
.33924 .62811 m
.34228 .61696 L
s
.5 Mabswid
.46494 .44118 m
.47133 .43998 L
s
0 1 0 r
.31318 .52856 m
.31303 .53174 L
s
0 g
.47133 .43998 m
.47774 .4388 L
s
.015 w
.60102 .58473 m
.60457 .57644 L
s
.5 Mabswid
.47774 .4388 m
.48416 .43763 L
s
0 1 0 r
.31303 .53174 m
.31288 .53493 L
s
0 g
.48416 .43763 m
.49059 .43646 L
s
0 1 0 r
.31288 .53493 m
.31273 .53811 L
s
0 g
.015 w
.88053 .59884 m
.88501 .59246 L
s
.5 Mabswid
.49059 .43646 m
.49704 .43531 L
s
.49704 .43531 m
.5035 .43416 L
s
0 1 0 r
.31273 .53811 m
.31259 .54131 L
s
0 g
.5035 .43416 m
.50998 .43303 L
s
0 1 0 r
.31259 .54131 m
.31244 .5445 L
s
0 g
.50998 .43303 m
.51647 .4319 L
s
.51647 .4319 m
.52298 .43079 L
s
.015 w
.33617 .63961 m
.33924 .62811 L
s
0 1 0 r
.5 Mabswid
.31244 .5445 m
.31229 .5477 L
s
0 g
.52298 .43079 m
.5295 .42968 L
s
0 1 0 r
.31229 .5477 m
.31214 .55091 L
s
0 g
.5295 .42968 m
.53604 .42858 L
s
.53604 .42858 m
.54259 .4275 L
s
.015 w
.59745 .59373 m
.60102 .58473 L
s
0 1 0 r
.5 Mabswid
.31214 .55091 m
.31199 .55412 L
s
0 g
.54259 .4275 m
.54916 .42642 L
s
.54916 .42642 m
.55574 .42536 L
s
0 1 0 r
.54916 .42642 m
.54917 .42955 L
s
.31199 .55412 m
.31184 .55733 L
s
0 g
.55574 .42536 m
.56234 .42431 L
s
0 1 0 r
.54917 .42955 m
.54917 .43269 L
s
.31184 .55733 m
.31169 .56055 L
s
0 g
.56234 .42431 m
.56896 .42327 L
s
.56896 .42327 m
.57559 .42224 L
s
0 1 0 r
.54917 .43269 m
.54918 .43582 L
s
.31169 .56055 m
.31154 .56377 L
s
0 g
.015 w
.87604 .60576 m
.88053 .59884 L
s
.5 Mabswid
.57559 .42224 m
.58224 .42122 L
s
.015 w
.33307 .65123 m
.33617 .63961 L
s
.5 Mabswid
.58224 .42122 m
.5889 .42021 L
s
0 1 0 r
.54918 .43582 m
.54919 .43897 L
s
.31154 .56377 m
.31139 .56699 L
s
0 g
.5889 .42021 m
.59558 .41922 L
s
0 1 0 r
.54919 .43897 m
.54919 .44211 L
s
0 g
.59558 .41922 m
.60227 .41824 L
s
0 1 0 r
.31139 .56699 m
.31124 .57022 L
s
0 g
.60227 .41824 m
.60898 .41727 L
s
0 1 0 r
.54919 .44211 m
.5492 .44526 L
s
.31124 .57022 m
.31109 .57346 L
s
0 g
.60898 .41727 m
.61571 .41631 L
s
.015 w
.59386 .60329 m
.59745 .59373 L
s
.5 Mabswid
.61571 .41631 m
.62245 .41537 L
s
0 1 0 r
.5492 .44526 m
.54921 .44841 L
s
.31109 .57346 m
.31094 .57669 L
s
0 g
.62245 .41537 m
.62921 .41444 L
s
.62921 .41444 m
.63598 .41352 L
s
0 1 0 r
.54921 .44841 m
.54921 .45157 L
s
.31094 .57669 m
.31079 .57994 L
s
0 g
.63598 .41352 m
.64277 .41261 L
s
.64277 .41261 m
.64958 .41172 L
s
0 1 0 r
.54921 .45157 m
.54922 .45473 L
s
.31079 .57994 m
.31064 .58318 L
s
0 g
.64958 .41172 m
.65641 .41085 L
s
.015 w
.32996 .66271 m
.33307 .65123 L
s
.5 Mabswid
.65641 .41085 m
.66325 .40999 L
s
0 1 0 r
.54922 .45473 m
.54923 .4579 L
s
.31064 .58318 m
.31049 .58644 L
s
0 g
.66325 .40999 m
.6701 .40914 L
s
.6701 .40914 m
.67698 .4083 L
s
0 1 0 r
.54923 .4579 m
.54923 .46107 L
s
.31049 .58644 m
.31034 .58969 L
s
0 g
.67698 .4083 m
.68387 .40749 L
s
.015 w
.87152 .61302 m
.87604 .60576 L
s
.5 Mabswid
.68387 .40749 m
.69078 .40668 L
s
.69078 .40668 m
.6977 .40589 L
s
0 1 0 r
.54923 .46107 m
.54924 .46425 L
s
.31034 .58969 m
.31019 .59295 L
s
0 g
.6977 .40589 m
.70464 .40512 L
s
.70464 .40512 m
.7116 .40437 L
s
.015 w
.59024 .6132 m
.59386 .60329 L
s
0 1 0 r
.5 Mabswid
.54924 .46425 m
.54924 .46742 L
s
.31019 .59295 m
.31004 .59621 L
s
0 g
.7116 .40437 m
.71858 .40362 L
s
.71858 .40362 m
.72557 .4029 L
s
0 1 0 r
.54924 .46742 m
.54925 .47061 L
s
.31004 .59621 m
.30989 .59948 L
s
0 g
.72557 .4029 m
.73258 .40219 L
s
.73258 .40219 m
.73961 .4015 L
s
.73961 .4015 m
.74665 .40083 L
s
0 1 0 r
.54925 .47061 m
.54926 .4738 L
s
.30989 .59948 m
.30974 .60276 L
s
0 g
.015 w
.32685 .67375 m
.32996 .66271 L
s
.5 Mabswid
.74665 .40083 m
.75372 .40017 L
s
.015 w
.25746 .43742 m
.25977 .44531 L
s
.25511 .43031 m
.25746 .43742 L
s
.5 Mabswid
.75372 .40017 m
.7608 .39953 L
s
.015 w
.25272 .42389 m
.25511 .43031 L
s
.25977 .44531 m
.26202 .45405 L
s
.25029 .4181 m
.25272 .42389 L
s
.5 Mabswid
.7608 .39953 m
.76789 .39891 L
s
0 1 0 r
.54926 .4738 m
.54926 .47699 L
s
.30974 .60276 m
.30958 .60603 L
s
0 g
.015 w
.26202 .45405 m
.26423 .46369 L
s
.5 Mabswid
.76789 .39891 m
.77501 .39831 L
s
.015 w
.24783 .41285 m
.25029 .4181 L
s
.5 Mabswid
.77501 .39831 m
.78214 .39772 L
s
.015 w
.26423 .46369 m
.26638 .47428 L
s
.5 Mabswid
.78214 .39772 m
.78929 .39716 L
s
.015 w
.24533 .40806 m
.24783 .41285 L
s
0 1 0 r
.5 Mabswid
.54926 .47699 m
.54927 .48018 L
s
.30958 .60603 m
.30943 .60931 L
s
0 g
.78929 .39716 m
.79646 .39661 L
s
.79646 .39661 m
.80365 .39608 L
s
.015 w
.24281 .40368 m
.24533 .40806 L
s
0 1 0 r
.5 Mabswid
.80365 .39608 m
.80383 .39923 L
s
0 g
.015 w
.26638 .47428 m
.26848 .48585 L
s
0 1 0 r
.5 Mabswid
.54927 .48018 m
.54928 .48338 L
s
.30943 .60931 m
.30928 .6126 L
s
0 g
.015 w
.24026 .39964 m
.24281 .40368 L
s
0 1 0 r
.5 Mabswid
.80383 .39923 m
.804 .40238 L
s
.54928 .48338 m
.54928 .48659 L
s
.30928 .6126 m
.30913 .61589 L
s
0 g
.015 w
.26848 .48585 m
.27053 .4984 L
s
.58659 .62324 m
.59024 .6132 L
s
.86695 .6204 m
.87152 .61302 L
s
.23769 .39587 m
.24026 .39964 L
s
0 1 0 r
.5 Mabswid
.804 .40238 m
.80418 .40553 L
s
.54928 .48659 m
.54929 .48979 L
s
.30913 .61589 m
.30897 .61918 L
s
0 g
.015 w
.32375 .68405 m
.32685 .67375 L
s
0 1 0 r
.5 Mabswid
.80418 .40553 m
.80435 .40868 L
s
0 g
.015 w
.27053 .4984 m
.27254 .5119 L
s
.2351 .39233 m
.23769 .39587 L
s
0 1 0 r
.5 Mabswid
.54929 .48979 m
.5493 .49301 L
s
.30897 .61918 m
.30882 .62248 L
s
.80435 .40868 m
.80453 .41185 L
s
.5493 .49301 m
.5493 .49622 L
s
.30882 .62248 m
.30867 .62579 L
s
0 g
.015 w
.2325 .38897 m
.2351 .39233 L
s
.27254 .5119 m
.27451 .5263 L
s
0 1 0 r
.5 Mabswid
.80453 .41185 m
.80471 .41501 L
s
.5493 .49622 m
.54931 .49945 L
s
.30867 .62579 m
.30851 .62909 L
s
0 g
.015 w
.22988 .38577 m
.2325 .38897 L
s
0 1 0 r
.5 Mabswid
.80471 .41501 m
.80488 .41818 L
s
.54931 .49945 m
.54932 .50267 L
s
.30851 .62909 m
.30836 .63241 L
s
0 g
.015 w
.22725 .38267 m
.22988 .38577 L
s
0 1 0 r
.5 Mabswid
.80488 .41818 m
.80506 .42135 L
s
0 g
.015 w
.27451 .5263 m
.27644 .5415 L
s
0 1 0 r
.5 Mabswid
.54932 .50267 m
.54932 .5059 L
s
.30836 .63241 m
.30821 .63572 L
s
.80506 .42135 m
.80524 .42453 L
s
0 g
.015 w
.32068 .6933 m
.32375 .68405 L
s
.2246 .37966 m
.22725 .38267 L
s
0 1 0 r
.5 Mabswid
.54932 .5059 m
.54933 .50914 L
s
.30821 .63572 m
.30805 .63904 L
s
0 g
.015 w
.5829 .63313 m
.58659 .62324 L
s
0 1 0 r
.5 Mabswid
.80524 .42453 m
.80541 .42771 L
s
.54933 .50914 m
.54934 .51237 L
s
.30805 .63904 m
.3079 .64237 L
s
0 g
.015 w
.27644 .5415 m
.27834 .55737 L
s
.22195 .37673 m
.2246 .37966 L
s
0 1 0 r
.5 Mabswid
.80541 .42771 m
.80559 .4309 L
s
0 g
.015 w
.86231 .62762 m
.86695 .6204 L
s
0 1 0 r
.5 Mabswid
.54934 .51237 m
.54935 .51562 L
s
.3079 .64237 m
.30774 .6457 L
s
0 g
.015 w
.21929 .37384 m
.22195 .37673 L
s
0 1 0 r
.5 Mabswid
.80559 .4309 m
.80577 .43409 L
s
.54935 .51562 m
.54935 .51886 L
s
.30774 .6457 m
.30759 .64903 L
s
.80577 .43409 m
.80595 .43728 L
s
0 g
.015 w
.27834 .55737 m
.28022 .57374 L
s
0 1 0 r
.5 Mabswid
.54935 .51886 m
.54936 .52212 L
s
.30759 .64903 m
.30743 .65237 L
s
0 g
.015 w
.21662 .37099 m
.21929 .37384 L
s
0 1 0 r
.5 Mabswid
.80595 .43728 m
.80613 .44048 L
s
0 g
.015 w
.31764 .7012 m
.32068 .6933 L
s
0 1 0 r
.5 Mabswid
.54936 .52212 m
.54937 .52537 L
s
.30743 .65237 m
.30728 .65571 L
s
0 g
.015 w
.21394 .36816 m
.21662 .37099 L
s
0 1 0 r
.5 Mabswid
.80613 .44048 m
.8063 .44368 L
s
.54937 .52537 m
.54937 .52863 L
s
.30728 .65571 m
.30712 .65906 L
s
0 g
.015 w
.28022 .57374 m
.28211 .59039 L
s
0 1 0 r
.5 Mabswid
.8063 .44368 m
.80648 .44689 L
s
0 g
.015 w
.57917 .64258 m
.5829 .63313 L
s
0 1 0 r
.5 Mabswid
.54937 .52863 m
.54938 .5319 L
s
.30712 .65906 m
.30697 .66241 L
s
0 g
.015 w
.21126 .36536 m
.21394 .36816 L
s
0 1 0 r
.5 Mabswid
.80648 .44689 m
.80666 .4501 L
s
.54938 .5319 m
.54939 .53516 L
s
.30697 .66241 m
.30681 .66577 L
s
0 g
.015 w
.20857 .36256 m
.21126 .36536 L
s
0 1 0 r
.5 Mabswid
.80666 .4501 m
.80684 .45332 L
s
.54939 .53516 m
.54939 .53844 L
s
.30681 .66577 m
.30666 .66913 L
s
0 g
.015 w
.31467 .70747 m
.31764 .7012 L
s
.28211 .59039 m
.284 .60709 L
s
0 1 0 r
.5 Mabswid
.80684 .45332 m
.80702 .45654 L
s
0 g
.015 w
.20587 .35978 m
.20857 .36256 L
s
0 1 0 r
.5 Mabswid
.54939 .53844 m
.5494 .54172 L
s
.30666 .66913 m
.3065 .6725 L
s
0 g
.015 w
.85759 .6344 m
.86231 .62762 L
s
0 1 0 r
.5 Mabswid
.80702 .45654 m
.8072 .45976 L
s
.5494 .54172 m
.54941 .545 L
s
.3065 .6725 m
.30634 .67587 L
s
0 g
.015 w
.20317 .35699 m
.20587 .35978 L
s
0 1 0 r
.5 Mabswid
.8072 .45976 m
.80738 .46299 L
s
.54941 .545 m
.54941 .54828 L
s
.30634 .67587 m
.30619 .67924 L
s
0 g
.015 w
.284 .60709 m
.28591 .62356 L
s
0 1 0 r
.5 Mabswid
.80738 .46299 m
.80756 .46622 L
s
0 g
.015 w
.20046 .35421 m
.20317 .35699 L
s
0 1 0 r
.5 Mabswid
.54941 .54828 m
.54942 .55158 L
s
.30619 .67924 m
.30603 .68262 L
s
0 g
.015 w
.57541 .65129 m
.57917 .64258 L
s
.31176 .71186 m
.31467 .70747 L
s
0 1 0 r
.5 Mabswid
.80756 .46622 m
.80774 .46946 L
s
.54942 .55158 m
.54943 .55487 L
s
.30603 .68262 m
.30587 .686 L
s
0 g
.20046 .35418 m
.20509 .35102 L
s
0 1 0 r
.80774 .46946 m
.80792 .4727 L
s
.54943 .55487 m
.54943 .55817 L
s
0 g
.015 w
.28591 .62356 m
.28785 .6395 L
s
0 1 0 r
.5 Mabswid
.30587 .686 m
.30572 .68939 L
s
.80792 .4727 m
.8081 .47595 L
s
.54943 .55817 m
.54944 .56147 L
s
.30572 .68939 m
.30556 .69278 L
s
0 g
.20509 .35102 m
.20972 .34784 L
s
0 1 0 r
.8081 .47595 m
.80829 .4792 L
s
0 g
.015 w
.30894 .71418 m
.31176 .71186 L
s
0 1 0 r
.5 Mabswid
.54944 .56147 m
.54945 .56478 L
s
.30556 .69278 m
.3054 .69618 L
s
0 g
.015 w
.28785 .6395 m
.28985 .65462 L
s
.5 Mabswid
.20972 .34784 m
.21434 .34464 L
s
0 1 0 r
.80829 .4792 m
.80847 .48245 L
s
.54945 .56478 m
.54945 .5681 L
s
.3054 .69618 m
.30524 .69958 L
s
0 g
.015 w
.85276 .64042 m
.85759 .6344 L
s
0 1 0 r
.5 Mabswid
.80847 .48245 m
.80865 .48571 L
s
.54945 .5681 m
.54946 .57141 L
s
.30524 .69958 m
.30509 .70299 L
s
0 g
.21434 .34464 m
.21895 .34141 L
s
.015 w
.57161 .65894 m
.57541 .65129 L
s
0 1 0 r
.5 Mabswid
.80865 .48571 m
.80883 .48898 L
s
0 g
.015 w
.3062 .71428 m
.30894 .71418 L
s
.28985 .65462 m
.29192 .66858 L
s
0 1 0 r
.5 Mabswid
.54946 .57141 m
.54947 .57474 L
s
.30509 .70299 m
.30493 .7064 L
s
.80883 .48898 m
.80901 .49225 L
s
.54947 .57474 m
.54948 .57806 L
s
.30493 .7064 m
.30477 .70982 L
s
0 g
.21895 .34141 m
.22357 .33816 L
s
.015 w
.29192 .66858 m
.29406 .68112 L
s
0 1 0 r
.5 Mabswid
.80901 .49225 m
.8092 .49552 L
s
.54948 .57806 m
.54948 .58139 L
s
0 g
.015 w
.30357 .71208 m
.3062 .71428 L
s
0 1 0 r
.5 Mabswid
.30477 .70982 m
.30461 .71324 L
s
.8092 .49552 m
.80938 .4988 L
s
0 g
.22357 .33816 m
.22817 .33488 L
s
0 1 0 r
.54948 .58139 m
.54949 .58473 L
s
0 g
.015 w
.29406 .68112 m
.29629 .69194 L
s
.30104 .70757 m
.30357 .71208 L
s
0 1 0 r
.5 Mabswid
.80938 .4988 m
.80956 .50208 L
s
.54949 .58473 m
.5495 .58807 L
s
0 g
.015 w
.29629 .69194 m
.29861 .70082 L
s
.29861 .70082 m
.30104 .70757 L
s
.5 Mabswid
.22817 .33488 m
.23277 .33158 L
s
0 1 0 r
.80956 .50208 m
.80974 .50536 L
s
.5495 .58807 m
.5495 .59141 L
s
0 g
.015 w
.56777 .66523 m
.57161 .65894 L
s
0 1 0 r
.5 Mabswid
.80974 .50536 m
.80993 .50865 L
s
.5495 .59141 m
.54951 .59476 L
s
0 g
.015 w
.84782 .64538 m
.85276 .64042 L
s
.5 Mabswid
.23277 .33158 m
.23737 .32826 L
s
0 1 0 r
.80993 .50865 m
.81011 .51195 L
s
.54951 .59476 m
.54952 .59812 L
s
.81011 .51195 m
.8103 .51525 L
s
.54952 .59812 m
.54952 .60148 L
s
0 g
.23737 .32826 m
.24196 .32491 L
s
0 1 0 r
.8103 .51525 m
.81048 .51855 L
s
.54952 .60148 m
.54953 .60484 L
s
0 g
.24196 .32491 m
.24654 .32154 L
s
0 1 0 r
.81048 .51855 m
.81066 .52186 L
s
.54953 .60484 m
.54954 .60821 L
s
.81066 .52186 m
.81085 .52517 L
s
.54954 .60821 m
.54954 .61158 L
s
0 g
.015 w
.56389 .66987 m
.56777 .66523 L
s
.5 Mabswid
.24654 .32154 m
.25112 .31814 L
s
0 1 0 r
.81085 .52517 m
.81103 .52849 L
s
.54954 .61158 m
.54955 .61495 L
s
.81103 .52849 m
.81122 .53181 L
s
.54955 .61495 m
.54956 .61834 L
s
0 g
.25112 .31814 m
.25569 .31471 L
s
.015 w
.84273 .64895 m
.84782 .64538 L
s
0 1 0 r
.5 Mabswid
.81122 .53181 m
.8114 .53514 L
s
.54956 .61834 m
.54957 .62172 L
s
.8114 .53514 m
.81159 .53847 L
s
.54957 .62172 m
.54957 .62511 L
s
0 g
.25569 .31471 m
.26026 .31126 L
s
.015 w
.47247 .38206 m
.47644 .39472 L
s
.46849 .37036 m
.47247 .38206 L
s
.47644 .39472 m
.4804 .40835 L
s
.46449 .35956 m
.46849 .37036 L
s
0 1 0 r
.5 Mabswid
.81159 .53847 m
.81178 .5418 L
s
0 g
.015 w
.4804 .40835 m
.48435 .42295 L
s
0 1 0 r
.5 Mabswid
.54957 .62511 m
.54958 .62851 L
s
0 g
.015 w
.55997 .67262 m
.56389 .66987 L
s
.46047 .3496 m
.46449 .35956 L
s
.48435 .42295 m
.48829 .43851 L
s
0 1 0 r
.5 Mabswid
.81178 .5418 m
.81196 .54514 L
s
0 g
.26026 .31126 m
.26482 .30778 L
s
.015 w
.45643 .34042 m
.46047 .3496 L
s
0 1 0 r
.5 Mabswid
.54958 .62851 m
.54959 .63191 L
s
0 g
.015 w
.48829 .43851 m
.49223 .45497 L
s
0 1 0 r
.5 Mabswid
.81196 .54514 m
.81215 .54849 L
s
0 g
.015 w
.45238 .33194 m
.45643 .34042 L
s
0 1 0 r
.5 Mabswid
.54959 .63191 m
.54959 .63531 L
s
0 g
.26482 .30778 m
.26938 .30428 L
s
.015 w
.49223 .45497 m
.49618 .47222 L
s
0 1 0 r
.5 Mabswid
.81215 .54849 m
.81234 .55184 L
s
.54959 .63531 m
.5496 .63872 L
s
0 g
.015 w
.4483 .32407 m
.45238 .33194 L
s
0 1 0 r
.5 Mabswid
.81234 .55184 m
.81252 .55519 L
s
.5496 .63872 m
.54961 .64213 L
s
0 g
.015 w
.49618 .47222 m
.50012 .49013 L
s
.5 Mabswid
.26938 .30428 m
.27392 .30074 L
s
.015 w
.55603 .67327 m
.55997 .67262 L
s
.44421 .31674 m
.4483 .32407 L
s
.8375 .65087 m
.84273 .64895 L
s
0 1 0 r
.5 Mabswid
.81252 .55519 m
.81271 .55855 L
s
.54961 .64213 m
.54962 .64555 L
s
0 g
.015 w
.50012 .49013 m
.50407 .50853 L
s
0 1 0 r
.5 Mabswid
.81271 .55855 m
.8129 .56191 L
s
.54962 .64555 m
.54962 .64898 L
s
0 g
.015 w
.4401 .30987 m
.44421 .31674 L
s
.5 Mabswid
.27392 .30074 m
.27846 .29718 L
s
0 1 0 r
.8129 .56191 m
.81309 .56528 L
s
.54962 .64898 m
.54963 .6524 L
s
0 g
.015 w
.50407 .50853 m
.50802 .5272 L
s
0 1 0 r
.5 Mabswid
.81309 .56528 m
.81327 .56865 L
s
0 g
.015 w
.43597 .30341 m
.4401 .30987 L
s
0 1 0 r
.5 Mabswid
.54963 .6524 m
.54964 .65584 L
s
0 g
.27846 .29718 m
.283 .29359 L
s
.015 w
.55206 .67168 m
.55603 .67327 L
s
0 1 0 r
.5 Mabswid
.81327 .56865 m
.81346 .57203 L
s
.54964 .65584 m
.54964 .65927 L
s
0 g
.015 w
.50802 .5272 m
.51199 .54591 L
s
.43182 .29727 m
.43597 .30341 L
s
0 1 0 r
.5 Mabswid
.81346 .57203 m
.81365 .57541 L
s
0 g
.283 .29359 m
.28753 .28997 L
s
0 1 0 r
.54964 .65927 m
.54965 .66272 L
s
.81365 .57541 m
.81384 .5788 L
s
.54965 .66272 m
.54966 .66616 L
s
0 g
.015 w
.8321 .65086 m
.8375 .65087 L
s
.51199 .54591 m
.51597 .56436 L
s
.54807 .66777 m
.55206 .67168 L
s
.5 Mabswid
.28753 .28997 m
.29204 .28632 L
s
.015 w
.42765 .2914 m
.43182 .29727 L
s
0 1 0 r
.5 Mabswid
.81384 .5788 m
.81403 .58219 L
s
.54966 .66616 m
.54967 .66961 L
s
.81403 .58219 m
.81422 .58558 L
s
0 g
.015 w
.51597 .56436 m
.51996 .58227 L
s
.5 Mabswid
.29204 .28632 m
.29656 .28264 L
s
0 1 0 r
.81422 .58558 m
.81441 .58898 L
s
0 g
.015 w
.42347 .28575 m
.42765 .2914 L
s
.54406 .66151 m
.54807 .66777 L
s
.51996 .58227 m
.52396 .59932 L
s
0 1 0 r
.5 Mabswid
.81441 .58898 m
.8146 .59239 L
s
0 g
.29656 .28264 m
.30106 .27894 L
s
.015 w
.54004 .65297 m
.54406 .66151 L
s
0 1 0 r
.5 Mabswid
.8146 .59239 m
.81479 .5958 L
s
0 g
.015 w
.52396 .59932 m
.52797 .6152 L
s
.41926 .28027 m
.42347 .28575 L
s
0 1 0 r
.5 Mabswid
.81479 .5958 m
.81498 .59921 L
s
0 g
.015 w
.52797 .6152 m
.53199 .62961 L
s
.53602 .64228 m
.54004 .65297 L
s
.82654 .64873 m
.8321 .65086 L
s
.5 Mabswid
.30106 .27894 m
.30556 .2752 L
s
.015 w
.53199 .62961 m
.53602 .64228 L
s
0 1 0 r
.5 Mabswid
.81498 .59921 m
.81517 .60263 L
s
0 g
.015 w
.41504 .27494 m
.41926 .28027 L
s
0 1 0 r
.5 Mabswid
.81517 .60263 m
.81536 .60605 L
s
0 g
.30556 .2752 m
.31005 .27142 L
s
0 1 0 r
.81536 .60605 m
.81555 .60948 L
s
0 g
.015 w
.4108 .26971 m
.41504 .27494 L
s
0 1 0 r
.5 Mabswid
.81555 .60948 m
.81574 .61292 L
s
0 g
.31005 .27142 m
.31453 .26762 L
s
0 1 0 r
.81574 .61292 m
.81593 .61635 L
s
0 g
.015 w
.8208 .64433 m
.82654 .64873 L
s
0 1 0 r
.5 Mabswid
.81593 .61635 m
.81613 .6198 L
s
0 g
.015 w
.40655 .26456 m
.4108 .26971 L
s
.5 Mabswid
.31453 .26762 m
.319 .26378 L
s
0 1 0 r
.81613 .6198 m
.81632 .62324 L
s
.81632 .62324 m
.81651 .6267 L
s
0 g
.319 .26378 m
.32346 .25992 L
s
.015 w
.40228 .25947 m
.40655 .26456 L
s
0 1 0 r
.5 Mabswid
.81651 .6267 m
.8167 .63015 L
s
.8167 .63015 m
.8169 .63362 L
s
0 g
.32346 .25992 m
.32792 .25601 L
s
.015 w
.8149 .63756 m
.8208 .64433 L
s
.398 .25441 m
.40228 .25947 L
s
0 1 0 r
.5 Mabswid
.8169 .63362 m
.81709 .63708 L
s
0 g
.32792 .25601 m
.33236 .25208 L
s
0 1 0 r
.81709 .63708 m
.81728 .64055 L
s
0 g
.015 w
.39369 .24939 m
.398 .25441 L
s
.5 Mabswid
.33236 .25208 m
.3368 .24811 L
s
.015 w
.80884 .62842 m
.8149 .63756 L
s
.38938 .24437 m
.39369 .24939 L
s
.5 Mabswid
.3368 .24811 m
.34122 .2441 L
s
.34122 .2441 m
.34564 .24006 L
s
.015 w
.38505 .23937 m
.38938 .24437 L
s
.80263 .61695 m
.80884 .62842 L
s
.5 Mabswid
.34564 .24006 m
.35005 .23598 L
s
.015 w
.3807 .23437 m
.38505 .23937 L
s
.79629 .60327 m
.80263 .61695 L
s
.5 Mabswid
.35005 .23598 m
.35444 .23186 L
s
.015 w
.37634 .22936 m
.3807 .23437 L
s
.78982 .58757 m
.79629 .60327 L
s
.5 Mabswid
.35444 .23186 m
.35883 .22771 L
s
.015 w
.78325 .57008 m
.78982 .58757 L
s
.37196 .22435 m
.37634 .22936 L
s
.72924 .40084 m
.73599 .42217 L
s
.7225 .38014 m
.72924 .40084 L
s
.73599 .42217 m
.74277 .44396 L
s
.7158 .36021 m
.7225 .38014 L
s
.77661 .55107 m
.78325 .57008 L
s
.74277 .44396 m
.74956 .46598 L
s
.70912 .34114 m
.7158 .36021 L
s
.74956 .46598 m
.75636 .48799 L
s
.5 Mabswid
.35883 .22771 m
.3632 .22352 L
s
.015 w
.76989 .53085 m
.77661 .55107 L
s
.75636 .48799 m
.76314 .50972 L
s
.76314 .50972 m
.76989 .53085 L
s
.70247 .323 m
.70912 .34114 L
s
.69584 .30582 m
.70247 .323 L
s
.36757 .21932 m
.37196 .22435 L
s
.5 Mabswid
.3632 .22352 m
.36757 .21929 L
s
.015 w
.68924 .28959 m
.69584 .30582 L
s
.68265 .27429 m
.68924 .28959 L
s
.5 Mabswid
.36757 .21929 m
.37192 .21502 L
s
.015 w
.67607 .25986 m
.68265 .27429 L
s
.5 Mabswid
.37192 .21502 m
.37626 .21071 L
s
.015 w
.6695 .24626 m
.67607 .25986 L
s
.5 Mabswid
.37626 .21071 m
.38059 .20636 L
s
.015 w
.66292 .23341 m
.6695 .24626 L
s
.5 Mabswid
.38059 .20636 m
.38491 .20197 L
s
.38491 .20197 m
.38922 .19754 L
s
.015 w
.65634 .22123 m
.66292 .23341 L
s
.5 Mabswid
.38922 .19754 m
.39351 .19306 L
s
.015 w
.64975 .20964 m
.65634 .22123 L
s
.5 Mabswid
.39351 .19306 m
.39779 .18854 L
s
.015 w
.64315 .19857 m
.64975 .20964 L
s
.5 Mabswid
.39779 .18854 m
.40206 .18398 L
s
.40206 .18398 m
.40632 .17937 L
s
.015 w
.63652 .18793 m
.64315 .19857 L
s
.5 Mabswid
.40632 .17937 m
.41056 .17471 L
s
.015 w
.62987 .17766 m
.63652 .18793 L
s
.5 Mabswid
.41056 .17471 m
.41478 .17001 L
s
.41478 .17001 m
.419 .16526 L
s
.015 w
.6232 .1677 m
.62987 .17766 L
s
.5 Mabswid
.419 .16526 m
.42319 .16046 L
s
.42319 .16046 m
.42738 .15562 L
s
.015 w
.61649 .15797 m
.6232 .1677 L
s
.5 Mabswid
.42738 .15562 m
.43155 .15072 L
s
.015 w
.60975 .14843 m
.61649 .15797 L
s
.5 Mabswid
.43155 .15072 m
.4357 .14577 L
s
.4357 .14577 m
.43984 .14077 L
s
.015 w
.60298 .13904 m
.60975 .14843 L
s
.5 Mabswid
.43984 .14077 m
.44396 .13572 L
s
.44396 .13572 m
.44806 .13061 L
s
.015 w
.59618 .12975 m
.60298 .13904 L
s
.5 Mabswid
.44806 .13061 m
.45215 .12545 L
s
.015 w
.58934 .12054 m
.59618 .12975 L
s
.5 Mabswid
.45215 .12545 m
.45622 .12023 L
s
.45622 .12023 m
.46028 .11496 L
s
.015 w
.58246 .11137 m
.58934 .12054 L
s
.5 Mabswid
.46028 .11496 m
.46431 .10963 L
s
.015 w
.57554 .10222 m
.58246 .11137 L
s
.5 Mabswid
.46431 .10963 m
.46833 .10424 L
s
.46833 .10424 m
.47233 .09879 L
s
.015 w
.56858 .09308 m
.57554 .10222 L
s
.5 Mabswid
.47233 .09879 m
.47631 .09328 L
s
.47631 .09328 m
.48027 .08771 L
s
.015 w
.56158 .08393 m
.56858 .09308 L
s
.5 Mabswid
.48027 .08771 m
.48421 .08207 L
s
.015 w
.55454 .07476 m
.56158 .08393 L
s
.5 Mabswid
.48421 .08207 m
.48813 .07637 L
s
.48813 .07637 m
.49203 .07061 L
s
.015 w
.54746 .06555 m
.55454 .07476 L
s
.5 Mabswid
.49203 .07061 m
.49591 .06478 L
s
.015 w
.54034 .05632 m
.54746 .06555 L
s
.5 Mabswid
.49591 .06478 m
.49976 .05887 L
s
.49976 .05887 m
.5036 .05291 L
s
.015 w
.53317 .04704 m
.54034 .05632 L
s
.5 Mabswid
.5036 .05291 m
.50741 .04687 L
s
.015 w
.52596 .03771 m
.53317 .04704 L
s
.5 Mabswid
.50741 .04687 m
.5112 .04075 L
s
.5112 .04075 m
.51497 .03457 L
s
.015 w
.51871 .02834 m
.52596 .03771 L
s
.5 Mabswid
.51497 .03457 m
.51871 .02831 L
s
.25 Mabswid
.51756 0 m
.9781 .59953 L
s
.9781 .59953 m
1 .84627 L
s
1 .84627 m
.51621 .27089 L
s
.51621 .27089 m
.51756 0 L
s
.02975 .1885 m
0 .45327 L
s
0 .45327 m
.51621 .27089 L
s
.51621 .27089 m
.51756 0 L
s
.51756 0 m
.02975 .1885 L
s
.02975 .1885 m
.51756 0 L
s
gsave
.21289 .03628 -70.3742 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{288, 277.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001Fb000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00N_ooool0
1OnHV9So0000o`000?m4A4Co^[Zj05[ooooo0_l0002=ooooo`00N_ooool01Ol@413o^[Zjonk^k_mg
MgOo410@05Oooooo0ol000000ooooooo0000ooooo`2<ooooo`00N_ooool00ol0003oooooooooo`1G
ooooo`;o00001?ooool2o`0008cooooo001jooooo`03o`000?oooooooooo05Cooooo0ol00006oooo
o`03o`000?oooooo000008_ooooo001jooooo`03o`000?oooooooooo057ooooo0ol00009ooooo`04
o`000?ooooooooooo`0008[ooooo001hooooo`03oa0@4?l0003o000000?o0000C_ooool2o`0000co
oooo00Co0000oooooooooooo0000R_ooool007[ooooo00?o0000ooooooooool0C?ooool3o`0000ko
oooo00Go0000ooooooooooooooooo`000029ooooo`00N_ooool00ol0003oooooooooo`1:ooooo`;o
00003oooool4o`0000?ooooo00?o0000ooooooooool0Q_ooool00<Cooooo0ol0000Aooooo`Co0000
1?ooool00ol0003oooooooooo`25ooooo`00`Oooool3o`0001Cooooo1Ol00004ooooo`03o`000?oo
oooooooo08Cooooo002oooooo`;o00005oooool6o`0000?ooooo00?o0000ooooooooool0Q?ooool0
0;cooooo0ol0000Iooooo`Ko00001?ooool00ol0003oooooooooo`23ooooo`00^_ooool2o`0001co
oooo1ol00004ooooo`03o`000?oooooooooo08;ooooo002gooooo`?o00007_ooool00ol0003ooooo
o`000005o`0000Cooooo00?o0000ooooooooool0POooool00;Gooooo0_l0000Pooooo`03o`000?oo
oooooooo00Oo00000oooool00ol0003oooooooooo`21ooooo`00/_ooool3o`0002;ooooo00?o0000
ooooooooool02?l00003ooooo`03o`000?oooooooooo083ooooo002_ooooo`?o00009?ooool01_l0
003ooooooooooooooooo0000ooooo`Oo00000oooool00ol0003oooooooooo`1oooooo`00[Oooool2
o`0002Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07o`0000?ooooo00?o0000
ooooooooool0O_ooool00:[ooooo0ol0000Xooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooooooo1ol00002ooooo`03o`000?oooooooooo07kooooo002Xooooo`;o0000:_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo1_l00003ooooo`03o`000?oooooooooo
07gooooo002Uooooo`?o0000;?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo1_l00003ooooo`03o`000?oooooooooo07cooooo002Rooooo`?o0000;Oooool2o`0000Kooooo
00?o0000ooooooooool01?ooool6o`0000?ooooo00?o0000ooooooooool0Noooool00:3ooooo0_l0
000_ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool6o`0000?ooooo00?o
0000ooooooooool0Noooool009gooooo0ol0000aooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool6o`0000?ooooo00?o0000ooooooooool0N_ooool009_ooooo0_l0000coooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool6o`0000?ooooo00?o0000oooo
ooooool0NOooool009Sooooo0ol0000eooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01_ooool7o`0000?ooooo00?o0000ooooooooool0N?ooool009Kooooo0_l0000gooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool01oooool7o`0000?ooooo00?o0000ooooooooool0
Moooool009?ooooo0ol0000hooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?oo
ool6o`0000?ooooo00?o0000ooooooooool0Moooool0093ooooo0ol0000kooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02Oooool6o`0000?ooooo00?o0000ooooooooool0M_ooool0
08kooooo0_l0000mooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool6o`00
00?ooooo00?o0000ooooooooool0MOooool008_ooooo0ol0000nooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool02_ooool6o`0000Cooooo00?o0000ooooooooool0M?ooool008Wooooo
0_l00010ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool6o`0000?ooooo
00?o0000ooooooooool0M?ooool008Kooooo0ol00011ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03?ooool6o`0000?ooooo00?o0000ooooooooool0Loooool008Cooooo0_l00014
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool7o`0000?ooooo00?o0000
ooooooooool0L_ooool0087ooooo0ol00015ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool7o`0000?ooooo00?o0000ooooooooool0LOooool007kooooo0ol00017ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool6o`0000?ooooo00?o0000oooooooo
ool0LOooool007cooooo0_l0001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
3oooool6o`0000?ooooo00?o0000ooooooooool0L?ooool007Wooooo0ol0001;ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool04?ooool6o`0000?ooooo00?o0000ooooooooool0Kooo
ool007Oooooo0_l0001=ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool6
o`0000Cooooo00?o0000ooooooooool0K_ooool007Cooooo0ol0001>ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool04Oooool6o`0000?ooooo00?o0000ooooooooool0K_ooool0077o
oooo0ol0001@ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool6o`0000?o
oooo00?o0000ooooooooool0KOooool006oooooo0_l0001Booooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool04_ooool7o`0000?ooooo00?o0000ooooooooool0K?ooool006cooooo0ol0
001Dooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04oooool7o`0000?ooooo00?o
0000ooooooooool0Joooool006[ooooo0_l0001Fooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool05?ooool6o`0000Cooooo00?o0000ooooooooool0J_ooool006Oooooo0ol0001Goooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool05Oooool6o`0000?ooooo00?o0000oooo
ooooool0J_ooool006Gooooo0_l0001Iooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool05_ooool6o`0000?ooooo00?o0000ooooooooool0JOooool006;ooooo0ol0001Jooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool05_ooool6o`0000Cooooo00?o0000ooooooooool0
J?ooool005oooooo0ol0001Looooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05ooo
ool6o`0000Cooooo00?o0000ooooooooool0Ioooool005gooooo0_l0001Nooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool06?ooool6o`0000?ooooo00?o0000ooooooooool0Ioooool0
05[ooooo0ol0001Pooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06?ooool6o`00
00Cooooo00?o0000ooooooooool0I_ooool005Sooooo0_l0001Rooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool06Oooool6o`0000Cooooo00?o0000ooooooooool0IOooool005Gooooo
0ol0001Sooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06_ooool6o`0000Cooooo
00?o0000ooooooooool0I?ooool005;ooooo0ol0001Uooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool06_ooool6o`0000Cooooo00?o0000ooooooooool0I?ooool0053ooooo0_l0001W
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool06oooool6o`0000Cooooo00?o0000
ooooooooool0Hoooool004gooooo0ol0001Xooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool07?ooool6o`0000Cooooo00?o0000ooooooooool0H_ooool004cooooo00?o0000oooooooo
ool0J?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01cooooo1_l00005ooooo`03
o`000?oooooooooo067ooooo001<ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`0Mooooo`Ko00001?ooool00ol0003oooooooooo`1Qooooo`00C?oo
ool2o`0006Sooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Nooooo`Ko00001?oo
ool00ol0003oooooooooo`1Pooooo`00C?ooool00ol0003oooooo`00001Uooooo`;o00009?ooool0
0ol0003oooooooooo`0Nooooo`Ko00001Oooool00ol0003oooooooooo`1Oooooo`00C?ooool01?l0
003oooooooooool0001Sooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07oooool6
o`0000Gooooo00?o0000ooooooooool0G_ooool004_ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`1Oooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool08?ooool5o`00
00Kooooo00?o0000ooooooooool0GOooool004_ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`1Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool08?ooool5o`0000Ko
oooo00?o0000ooooooooool0GOooool004_ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1Looooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool08Oooool5o`0000Kooooo
00?o0000ooooooooool0G?ooool004_ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1Fooooo`Go0000:Oooool00ol0003oooooooooo`0Qooooo`Go00001oooool00ol0003ooooooooo
o`1Kooooo`00Boooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Gooooo1_l0000X
ooooo`03o`000?oooooooooo027ooooo1_l00007ooooo`03o`000?oooooooooo05[ooooo001;oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0E?ooool6o`0002Sooooo00?o0000oooo
ooooool08_ooool5o`0000Oooooo00?o0000ooooooooool0F_ooool004_ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`1Cooooo`Oo00009oooool00ol0003oooooooooo`0Rooooo`Ko
00001oooool00ol0003oooooooooo`1Iooooo`00Boooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo057ooooo00?o0000ooooooooool01_l0000Vooooo`03o`000?oooooooooo02?ooooo
1_l00007ooooo`03o`000?oooooooooo05Sooooo001;ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0Coooool01?l0003oooooooooooooool6o`0002Kooooo00?o0000ooooooooool0
8oooool6o`0000Sooooo00?o0000ooooooooool0Eoooool004[ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo00?ooooo1ol0000Tooooo`03o`000?oo
oooooooo02Cooooo1_l00007ooooo`03o`000?oooooooooo05Oooooo001:ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`05ooooo`Oo00008oooool0
0ol0003oooooooooo`0Uooooo`Go00002?ooool00ol0003oooooooooo`1Fooooo`00B_ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo04Sooooo0_l00008ooooo`Oo00008oooool00ol0
003oooooooooo`0Uooooo`Ko00002?ooool00ol0003oooooooooo`1Eooooo`00B_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool02Oooool7o`0002;o
oooo00?o0000ooooooooool09_ooool5o`0000Wooooo00?o0000ooooooooool0E?ooool004[ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo00_ooooo
1_l0000Qooooo`03o`000?oooooooooo02Kooooo1_l00009ooooo`03o`000?oooooooooo05?ooooo
001:ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`0<ooooo`Ko00008Oooool00ol0003oooooooooo`0Wooooo`Go00002Oooool00ol0003ooooooooo
o`1Cooooo`00B_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo043ooooo0_l0000@
ooooo`Oo00007oooool00ol0003oooooooooo`0Wooooo`Ko00002Oooool00ol0003oooooooooo`1B
ooooo`00B_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool04Oooool7o`0001kooooo00?o0000ooooooooool0:?ooool5o`0000[ooooo00?o0000oooo
ooooool0DOooool004Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0looooo`03
o`000?oooooooooo01;ooooo1ol0000Nooooo`03o`000?oooooooooo02Sooooo1_l0000:ooooo`03
o`000?oooooooooo053ooooo0019ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
>Oooool2o`0001Kooooo1ol0000Mooooo`03o`000?oooooooooo02Wooooo1Ol0000:ooooo`03o`00
0?oooooooooo053ooooo0019ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`0Hooooo`Ko00006oooool2o`0002_ooooo1_l0000:ooooo`03o`000?oo
oooooooo04oooooo0019ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0=Oooool0
0ol0003oooooooooo`0Iooooo`Ko00006?ooool3o`000003ooooool0003ooooo02_ooooo1Ol0000;
ooooo`03o`000?oooooooooo04kooooo0019ooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`0Kooooo`Oo00004oooool3o`0000Gooooo00?o0000oooo
ooooool0:Oooool6o`0000_ooooo00?o0000ooooooooool0COooool004Wooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01gooooo1ol0000?ooooo`?o
00002Oooool00ol0003oooooooooo`0Yooooo`Go00002oooool00ol0003oooooooooo`1=ooooo`00
BOooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
7_ooool7o`0000cooooo0ol0000=ooooo`03o`000?oooooooooo02Sooooo1_l0000;ooooo`03o`00
0?oooooooooo04cooooo0019ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`0Pooooo`Oo00002?ooool3o`00017ooooo00?o0000ooooooooool0:?oo
ool5o`0000cooooo00?o0000ooooooooool08Oooool2o`0000;ooooo0_l0000Tooooo`00BOooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool08oooool5
o`0000Gooooo0ol0000Eooooo`03o`000?oooooooooo02Oooooo1_l0000<ooooo`03o`000?oooooo
oooo023ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMdTooooo`00B?ooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo02Sooooo0_l0000Vooooo`Ko00000_ooool2o`0001Sooooo00?o
0000ooooooooool0:?ooool5o`0000cooooo00?o0000ooooooooool08Oooool01?oMgMgo0000oa0@
4?o<c<`Uooooo`00B?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool09oooool7o`0001_ooooo00?o0000ooooooooool09oooool5o`0000gooooo00?o
0000ooooooooool08?ooool01?o^k^ko8B4Qoa0@4?o^k^hUooooo`00B?ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0:?ooool6o`0001gooooo00?o
0000ooooooooool09oooool5o`0000gooooo00?o0000ooooooooool07oooool01?lQ8B7oMgMgogMg
Molb<S8Uooooo`00B?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo027ooooo0_l0
000Yooooo`Wo00007Oooool00ol0003oooooooooo`0Vooooo`Go00003_ooool00ol0003ooooooooo
o`0Mooooo`;o00000_ooool2o`0002Cooooo0018ooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0Vooooo`?o00001?ooool6o`0001gooooo00?o0000
ooooooooool09Oooool6o`0000kooooo00?o0000ooooooooool0A_ooool004Sooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Cooooo0ol00007oooo
o`Oo00007Oooool00ol0003oooooooooo`0Uooooo`Go00003_ooool00ol0003oooooooooo`16oooo
o`00B?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01[ooooo0_l0000Uooooo`;o
00002oooool6o`0001gooooo00?o0000ooooooooool09Oooool5o`0000oooooo00?o0000oooooooo
ool0AOooool004Sooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo02;ooooo0ol0000>ooooo`Ko00007Oooool00ol0003oooooooooo`0Uooooo`Go0000
3oooool00ol0003oooooooooo`14ooooo`00Aoooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool08?ooool3o`0001;ooooo1Ol0000Nooooo`03o`000?oo
oooooooo02Cooooo1Ol0000@ooooo`03o`000?oooooooooo04?ooooo0017ooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool04oooool2o`00023ooooo0ol0000Eooooo`Go00007oooool0
0ol0003oooooooooo`0Sooooo`Ko00003oooool00ol0003oooooooooo`13ooooo`00Aoooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool07Oooool3o`00
01Wooooo1Ol0000Oooooo`03o`000?oooooooooo02?ooooo1Ol0000@ooooo`03o`000?oooooooooo
04;ooooo0017ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0Kooooo`?o00007?ooool5o`00023ooooo00?o0000ooooooooool08_ooool5o`00017o
oooo00?o0000ooooooooool0@Oooool004Oooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`0<ooooo`;o00006oooool3o`0001oooooo1_l0000Pooooo`03o`000?oooooooooo02;ooooo
1Ol0000Aooooo`03o`000?oooooooooo043ooooo000?ooooo`03ogMgMomVIVKooooo00Wooooo00?o
0000okZj^_ooool02oooool00omVIVKoMgMgooooo`0Kooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Iooooo`;o00008oooool5o`00023ooooo00?o
0000ooooooooool08_ooool5o`00017ooooo00?o0000ooooooooool0@?ooool000kooooo00?ogMgM
oa0@4?o^k^h02_ooool2oc8b<Pcooooo00?ok^k^oa0@4?oMgMd06oooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05oooool3o`0002Gooooo1_l0000P
ooooo`03o`000?oooooooooo027ooooo1_l0000Aooooo`03o`000?oooooooooo03oooooo0003oooo
o`03oa0@4?l0003o000000;o000000?o410@ooooooooool00oooool01?mEEEGoV9RHooooooooool2
o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj
^P03ooooo`03ohN7QomVIVKooooo01[ooooo00?o0000ooooooooool0;oooool00ol0003ooooooooo
o`04ooooo`?o00005oooool3o`0002Wooooo1Ol0000Qooooo`03o`000?oooooooooo027ooooo1Ol0
000Booooo`03o`000?oooooooooo03kooooo0005ooooo`03o`000?oooooooooo00Kooooo00[o0000
ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@4004oooo
o`05oa0@4?nj^[[ok^k^ogMgMol@41000oooool00oo^k^ko0000ooooo`0Jooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooool000000ol0000Gooooo`?o0000;?ooool5o`0002;ooooo00?o0000
ooooooooool08?ooool5o`0001?ooooo00?o0000ooooooooool0?Oooool000Gooooo00?o0000oooo
ooooool01_ooool00olb<S;oooooooooo`02ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo03;ooooo1Ol0000D
ooooo`?o0000<?ooool5o`0002;ooooo00?o0000ooooooooool08?ooool5o`0001;ooooo00?o0000
ooooooooool0?Oooool000Gooooo00?o0000ooooooooool01_ooool00olb<S;oooooooooo`02oooo
o`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo03?ooooo1Ol0000@ooooo`?o0000<oooool5o`0002?ooooo00?o0000
ooooooooool07oooool5o`0001?ooooo00?o0000ooooooooool0??ooool000Gooooo00?o0000oooo
ooooool01_ooool00ol0003ok^k^ooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000
ooooooooool01Oooool00oo^k^ko0000ooooo`0Iooooo`03o`000?oooooooooo03?ooooo1_l0000<
ooooo`?o0000=_ooool5o`0002?ooooo00?o0000ooooooooool07oooool5o`0001Cooooo00?o0000
ooooooooool0>oooool000?ooooo00?o410@o`000?l000000ol00005ooooo`04oeEEEOmgMgOooooo
ooooo`;o00000_ooool2o`0000Sooooo00?o410@o`000?l000000ol00004ooooo`03ogMgMomEEEGo
oooo01Wooooo00?o0000ooooooooool0<oooool7o`0000Wooooo0_l0000jooooo`Go00008oooool0
0ol0003oooooooooo`0Oooooo`Go00005?ooool00ol0003oooooooooo`0jooooo`001Oooool00ol0
003oooooooooo`06ooooo`03omgMgOl@413ok^k^017ooooo00?o0000ooooooooool01?ooool00oo^
k^ko410@omgMg@0Jooooo`03o`000?oooooooooo03Cooooo1ol00005ooooo`?o0000??ooool6o`00
02?ooooo00?o0000ooooooooool07_ooool5o`0001Gooooo00?o0000ooooooooool0>Oooool000Go
oooo00?o410@okZj^_ooool01oooool00omgMgOoIVIVooooo`0@ooooo`03o`000?oooooooooo00Co
oooo00?oIVIVogMgMoooool06_ooool00ol0003oooooooooo`0eooooo`Oo000000Coooooo`000?l0
003o0000?oooool6o`0002Cooooo00?o0000ooooooooool07Oooool5o`0001Gooooo00?o0000oooo
ooooool0>Oooool000Gooooo00Co^[Zjoa0@4?l0003o410@?Oooool00ol0003oooooooooo`0foooo
o`Oo0000@oooool6o`0002Cooooo00?o0000ooooooooool07Oooool5o`0001Gooooo00?o0000oooo
ooooool0>?ooool004Kooooo00?o0000ooooooooool0=oooool7o`0004?ooooo1Ol0000Uooooo`03
o`000?oooooooooo01cooooo1Ol0000Fooooo`03o`000?oooooooooo03Oooooo0016ooooo`03o`00
0?oooooooooo03Cooooo0ol000000ooooooo0000o`000005o`0004;ooooo1Ol0000Uooooo`03o`00
0?oooooooooo01cooooo1Ol0000Gooooo`03o`000?oooooooooo03Kooooo0015ooooo`03o`000?oo
oooooooo03?ooooo0_l00005ooooo`Oo0000@_ooool4o`0002Kooooo00?o0000ooooooooool07?oo
ool5o`0001Kooooo00?o0000ooooooooool0=_ooool004Gooooo00?o0000ooooooooool0<?ooool3
o`0000Sooooo1ol00011ooooo`Go00009_ooool00ol0003oooooooooo`0Kooooo`Go00005oooool0
0ol0003oooooooooo`0eooooo`00AOooool00ol0003oooooooooo`0]ooooo`?o00002oooool7o`00
047ooooo1Ol0000Wooooo`03o`000?oooooooooo01[ooooo1Ol0000Hooooo`03o`000?oooooooooo
03Cooooo0015ooooo`03o`000?oooooooooo02[ooooo0ol0000@ooooo`Go0000@Oooool5o`0002So
oooo00?o0000ooooooooool06_ooool5o`0001;ooooo00?o0000o`3o0?ooool00oooool00ol0003o
ooooooooo`0cooooo`00AOooool00ol0003oooooooooo`0Wooooo`?o00005?ooool5o`00047ooooo
1?l0000Yooooo`03o`000?oooooooooo01Wooooo1Ol00008ooooo`[o000000?oooooo`3o0?ooool0
0oooool00ol0003oooooooooo`0cooooo`00AOooool00ol0003oooooooooo`0Tooooo`?o00005ooo
ool6o`00043ooooo1Ol0000Xooooo`03o`000?oooooooooo01Wooooo3Ol0000;ooooo`03o`3o0?oo
oooooooo00?ooooo00?o0000ooooooooool0<_ooool004Gooooo00?o0000ooooooooool08Oooool3
o`0001[ooooo1ol0000oooooo`Go0000:Oooool00ol0003oooooooooo`0@ooooo`ko00004_ooool0
0ol0o`3oooooooooo`04ooooo`03o`000?oooooooooo037ooooo0015ooooo`03o`000?oooooooooo
01oooooo0_l0000Nooooo`Ko0000?oooool5o`0002[ooooo00?o0000ooooooooool01oooool8o`00
00Wooooo1Ol0000Booooo`03o`3o0?oooooooooo00Gooooo00?o0000ooooooooool0<?ooool004Co
oooo00?o0000ooooooooool07Oooool3o`00027ooooo1Ol00010ooooo`Co0000:oooool9o`00017o
oooo1Ol0000Cooooo`03o`3o0?oooooooooo00Gooooo00?o0000ooooooooool0;oooool004Cooooo
00?o0000ooooooooool06_ooool3o`0002Gooooo1Ol0000oooooo`Go00009?ooool8o`0001Wooooo
1Ol0000Booooo`03o`3o0?oooooooooo00Gooooo00?o0000ooooooooool0;oooool004Cooooo00?o
0000ooooooooool05oooool3o`0002Sooooo1Ol0000oooooo`Go00007_ooool6o`0000Sooooo00?o
0000ooooooooool05_ooool5o`0001;ooooo00?o0?l0ooooooooool01_ooool00ol0003ooooooooo
o`0^ooooo`00A?ooool00ol0003oooooooooo`0Dooooo`?o0000:oooool6o`0003kooooo1Ol0000F
ooooo`So00003oooool00ol0003oooooooooo`0Eooooo`Go00004_ooool00ol0o`3oooooooooo`07
ooooo`03o`000?oooooooooo02gooooo0014ooooo`03o`000?oooooooooo017ooooo0ol0000_oooo
o`Ko0000?_ooool4o`00013ooooo00?o0000o`3o0?l000000ol0000Gooooo`03o`000?oooooooooo
01Kooooo1Ol0000Aooooo`03o`3o0?oooooooooo00Sooooo00?o0000ooooooooool0;?ooool004Co
oooo00?o0000ooooooooool03oooool2o`0003;ooooo1Ol000000ooooooo0000ooooo`0looooo`Go
00002_ooool5o`000003ooooool0o`3ooooo01_ooooo00?o0000ooooooooool05Oooool5o`00017o
oooo00?o0?l0ooooooooool02?ooool00ol0003oooooooooo`0/ooooo`00A?ooool00ol0003ooooo
ooooo`0<ooooo`?o0000=Oooool5o`000003ooooool0003ooooo03_ooooo1Ol00004ooooo`Ko0000
1_ooool00ol0o`3oooooooooo`0Kooooo`03o`000?oooooooooo01Cooooo1Ol0000Aooooo`03o`3o
0?oooooooooo00Wooooo00?o0000ooooooooool0:oooool004Cooooo00?o0000ooooooooool02Ooo
ool3o`0003Sooooo1Ol00002ooooo`03o`000?oooooooooo03Wooooo2Ol0000<ooooo`03o`3o0?oo
oooooooo01cooooo00?o0000ooooooooool05?ooool5o`00013ooooo00?o0?l0ooooooooool02_oo
ool00ol0003oooooooooo`0Zooooo`00A?ooool00ol0003oooooooooo`06ooooo`?o0000>oooool5
o`0000?ooooo00?o0000ooooooooool0=_ooool7o`00013ooooo00?o0?l0ooooooooool07Oooool0
0ol0003oooooooooo`0Cooooo`Go00004?ooool00ol0o`3oooooooooo`0;ooooo`03o`000?oooooo
oooo02Wooooo0013ooooo`03o`000?oooooooooo00Cooooo0ol0000oooooo`Go00000oooool00ol0
003oooooooooo`0_ooooo`Ko00000oooool5o`0000oooooo00?o0?l0ooooooooool07_ooool00ol0
003oooooooooo`0Booooo`Go00004?ooool00ol0o`3oooooooooo`0;ooooo`03o`000?oooooooooo
02Wooooo0013ooooo`04o`000?ooooooooooooooo`?o0000@_ooool5o`0000Cooooo00?o0000oooo
ooooool0:Oooool5o`0000Wooooo1Ol0000?ooooo`03o`3o0?oooooooooo01kooooo00?o0000oooo
ooooool04oooool4o`00013ooooo00?o0?l0ooooooooool03?ooool00ol0003oooooooooo`0Xoooo
o`00@oooool4o`0004Gooooo1Ol00005ooooo`03o`000?oooooooooo02;ooooo1_l0000>ooooo`Go
00003oooool00ol0o`3oooooooooo`0Oooooo`03o`000?oooooooooo01;ooooo1Ol0000?ooooo`03
o`3o0?oooooooooo00gooooo00?o0000ooooooooool09oooool004?ooooo0_l00018ooooo`Co0000
1_ooool00ol0003oooooooooo`0Mooooo`Co00005Oooool5o`0000kooooo00?o0?l0ooooooooool0
8?ooool00ol0003oooooooooo`0Aooooo`Go00003oooool00ol0o`3oooooooooo`0>ooooo`03o`00
0?oooooooooo02Kooooo0015ooooo`03o`000?oooooooooo04Gooooo1Ol00006ooooo`03o`000?oo
oooooooo01Oooooo1Ol0000Iooooo`Go00003_ooool00ol0o`3oooooooooo`0Qooooo`03o`000?oo
oooooooo013ooooo1Ol0000?ooooo`03o`3o0?oooooooooo00kooooo00?o0000ooooooooool09_oo
ool004Kooooo00?o0000ooooooooool0A?ooool5o`0000Oooooo00?o0000ooooooooool04_ooool4
o`0001kooooo1Ol0000>ooooo`03o`3o0?oooooooooo02;ooooo00?o0000ooooooooool04?ooool5
o`0000kooooo00?o0?l0ooooooooool03oooool00ol0003oooooooooo`0Uooooo`00Aoooool00ol0
003oooooooooo`13ooooo`Go00002?ooool00ol0003oooooooooo`0<ooooo`Go00008oooool5o`00
00gooooo00?o0?l0ooooooooool08oooool00ol0003oooooooooo`0?ooooo`Go00003_ooool00ol0
o`3oooooooooo`0@ooooo`03o`000?oooooooooo02Cooooo0018ooooo`03o`000?oooooooooo04?o
oooo1Ol00008ooooo`03o`000?oooooooooo00Kooooo1Ol0000Xooooo`Go00003Oooool00ol0o`3o
ooooooooo`0Sooooo`03o`000?oooooooooo00oooooo1Ol0000>ooooo`03o`3o0?oooooooooo017o
oooo00?o0000ooooooooool08oooool004Wooooo00?o0000ooooooooool0@_ooool5o`0000Wooooo
00Co0000oooooooooooooooo1?l0000]ooooo`Go00003Oooool00ol0o`3oooooooooo`0Tooooo`03
o`000?oooooooooo00oooooo1Ol0000=ooooo`03o`3o0?oooooooooo01;ooooo00?o0000oooooooo
ool08_ooool004[ooooo00?o0000ooooooooool0@Oooool5o`0000[ooooo00?o0000ooooool00000
<_ooool4o`0000gooooo00?o0?l0ooooooooool09Oooool00ol0003oooooooooo`0>ooooo`Go0000
3_ooool00ol0o`3oooooooooo`0Aooooo`03o`000?oooooooooo02;ooooo001;ooooo`03o`000?oo
oooooooo047ooooo1?l0000;ooooo`03o`000?l0o`3ooooo037ooooo1?l0000=ooooo`03o`3o0?oo
oooooooo02Kooooo00?o0000ooooooooool03Oooool5o`0000kooooo00?o0?l0ooooooooool04_oo
ool00ol0003oooooooooo`0Qooooo`00C?ooool00ol0003oooooooooo`10ooooo`Co00003?ooool0
0ol0o`3oooooooooo`0`ooooo`Go00003?ooool00ol0o`3oooooooooo`0Wooooo`03o`000?oooooo
oooo00gooooo1Ol0000=ooooo`03o`3o0?oooooooooo01?ooooo00?o0000ooooooooool08?ooool0
04gooooo00?o0000ooooooooool0?oooool4o`0000cooooo00?o0?l0o`000?ooool0<?ooool5o`00
00cooooo00?o0?l0ooooooooool0:?ooool00ol0003oooooooooo`0<ooooo`Go00003Oooool00ol0
o`3oooooooooo`0Dooooo`03o`000?oooooooooo01oooooo001>ooooo`03o`000?oooooooooo03ko
oooo1?l0000<ooooo`03o`3o0?oooooo0000033ooooo1Ol0000<ooooo`03o`3o0?oooooooooo02So
oooo00?o0000ooooooooool03?ooool5o`0000gooooo00?o0?l0ooooooooool05?ooool00ol0003o
ooooooooo`0Oooooo`00Coooool2o`0003kooooo1Ol0000;ooooo`04o`3o0?ooooooooooo`00033o
oooo1?l0000<ooooo`03o`3o0?oooooooooo02Wooooo00?o0000ooooooooool03?ooool4o`0000go
oooo00?o0?l0ooooooooool05Oooool00ol0003oooooooooo`0Nooooo`00DOooool00ol0003ooooo
ooooo`0kooooo`Go00002oooool01Ol0o`3ooooooooooooooooo000002oooooo1?l0000<ooooo`03
o`3o0?oooooooooo02[ooooo00?o0000ooooooooool02oooool4o`0000gooooo00?o0?l0oooooooo
ool05_ooool00ol0003oooooooooo`0Mooooo`00D_ooool00ol0003oooooooooo`0jooooo`Go0000
2oooool00ol0o`3oooooooooo`02ooooo`03o`000?oooooooooo02cooooo1Ol0000;ooooo`03o`3o
0?oooooooooo02_ooooo00?o0000ooooooooool02_ooool5o`0000cooooo00?o0?l0ooooooooool0
5oooool00ol0003oooooooooo`0Looooo`00Doooool00ol0003oooooooooo`0jooooo`Co00002ooo
ool00ol0o`3oooooooooo`03ooooo`03o`000?oooooooooo02_ooooo1Ol0000;ooooo`03o`3o0?oo
oooooooo02cooooo00?o0000ooooooooool02Oooool5o`0000cooooo00?o0?l0ooooooooool05ooo
ool00ol0003oooooooooo`0Looooo`00E?ooool00ol0003oooooooooo`0iooooo`Go00002_ooool0
0ol0o`3oooooooooo`04ooooo`03o`000?oooooooooo02[ooooo1Ol0000;ooooo`03o`3o0?oooooo
oooo02gooooo00?o0000ooooooooool02?ooool5o`0000cooooo00?o0?l0ooooooooool06?ooool0
0ol0003oooooooooo`0Kooooo`00EOooool00ol0003oooooooooo`0hooooo`Go00002_ooool00ol0
o`3oooooooooo`05ooooo`03o`000?oooooooooo02[ooooo1?l0000;ooooo`03o`3o0?oooooooooo
02gooooo00?o0000ooooooooool02Oooool4o`0000cooooo00?o0?l0ooooooooool06Oooool00ol0
003oooooooooo`0Jooooo`00E_ooool00ol0003oooooooooo`0gooooo`Go00002_ooool00ol0o`3o
ooooooooo`06ooooo`03o`000?oooooooooo02Wooooo1?l0000;ooooo`03o`3o0?oooooooooo02ko
oooo00?o0000ooooooooool02?ooool4o`0000cooooo00?o0?l0ooooooooool06_ooool00ol0003o
ooooooooo`0Iooooo`00Eoooool00ol0003oooooooooo`0gooooo`Co00002_ooool00ol0o`3ooooo
ooooo`07ooooo`03o`000?oooooooooo02Sooooo1?l0000;ooooo`03o`3o0?oooooooooo02oooooo
00?o0000ooooooooool01oooool5o`0000_ooooo00?o0?l0ooooooooool06_ooool00ol0003ooooo
ooooo`0Iooooo`00F?ooool00ol0003oooooooooo`0fooooo`Co00002_ooool00ol0o`3ooooooooo
o`08ooooo`03o`000?oooooooooo02Oooooo1Ol0000:ooooo`03o`3o0?oooooooooo033ooooo00?o
0000ooooooooool01_ooool5o`0000_ooooo00?o0?l0ooooooooool06oooool00ol0003ooooooooo
o`0Hooooo`00FOooool00ol0003oooooooooo`0eooooo`Co00002Oooool00ol0o`3oooooooooo`0:
ooooo`03o`000?oooooooooo02Kooooo1Ol0000:ooooo`03o`3o0?oooooooooo037ooooo00?o0000
ooooooooool01Oooool5o`0000_ooooo00?o0?l0ooooooooool07?ooool00ol0003oooooooooo`0G
ooooo`00F_ooool00ol0003oooooooooo`0dooooo`Co00002Oooool00ol0o`3oooooooooo`0;oooo
o`03o`000?oooooooooo02Gooooo1Ol0000:ooooo`03o`3o0?oooooooooo03;ooooo00?o0000oooo
ooooool01Oooool5o`0000[ooooo00?o0?l0ooooooooool07Oooool00ol0003oooooooooo`0Foooo
o`00Foooool00ol0003oooooooooo`0cooooo`Co00002Oooool00ol0o`3oooooooooo`0<ooooo`03
o`000?oooooooooo02Gooooo1?l0000:ooooo`03o`3o0?oooooooooo03?ooooo00?o0000oooooooo
ool01?ooool5o`0000[ooooo00?o0?l0ooooooooool07_ooool00ol0003oooooooooo`0Eooooo`00
G?ooool2o`0003?ooooo1Ol00008ooooo`03o`3o0?oooooooooo00gooooo00?o0000ooooooooool0
9?ooool4o`0000[ooooo00?o0?l0ooooooooool0<oooool00ol0003oooooooooo`04ooooo`Go0000
2_ooool00ol0o`3oooooooooo`0Nooooo`03o`000?oooooooooo01Gooooo001Nooooo`03o`000?oo
oooooooo033ooooo1Ol00008ooooo`03o`3o0?oooooooooo00kooooo00?o0000ooooooooool08ooo
ool5o`0000Wooooo00?o0?l0ooooooooool0=?ooool00ol0003oooooooooo`04ooooo`Go00002_oo
ool00ol0o`3oooooooooo`0Nooooo`03o`000?oooooooooo01Cooooo001Oooooo`03o`000?oooooo
oooo02oooooo1Ol00008ooooo`03o`3o0?oooooooooo00oooooo00?o0000ooooooooool08_ooool5
o`0000Wooooo00?o0?l0ooooooooool04oooool6o`0001cooooo00?o0000ooooooooool00oooool5
o`0000[ooooo00?o0?l0ooooooooool07oooool00ol0003oooooooooo`0Cooooo`00H?ooool00ol0
003oooooooooo`0_ooooo`Co00002?ooool00ol0o`3oooooooooo`0>ooooo`Go00002ooooolTo`00
0003o`3o0?l0003o000000;o00003oooool:o`0001_ooooo00?o0000ooooooooool00_ooool5o`00
00[ooooo00?o0?l0ooooooooool08?ooool00ol0003oooooooooo`0Booooo`00HOooool00ol0003o
ooooooooo`0^ooooo`Co00002?ooool00ol0o`3oooooooooo`0<oooooa;o00005oooool4o`0000Wo
oooo00?o0?l0ooooooooool00_oooolKo`0001[ooooo00?o0000ooooooooool00_ooool5o`0000Wo
oooo00?o0?l0ooooooooool08?ooool00ol0003oooooooooo`0Booooo`00H_ooool00ol0003ooooo
ooooo`0]ooooo`Co00002?ooool00ol0o`3oooooooooo`0;ooooo`[o00008?ooool4o`0000Wooooo
00?o0?l0ooooooooool03ooooolDo`0001Gooooo00Co0000oooooooooooooooo1Ol00009ooooo`03
o`3o0?oooooooooo027ooooo00?o0000ooooooooool04Oooool006?ooooo00?o0000ooooooooool0
;?ooool4o`0000Sooooo00?o0?l0ooooooooool02_ooool;o`00023ooooo1?l00009ooooo`03o`3o
0?oooooooooo00kooooo4?l00005ooooo`Wo00003?ooool01?l0003oooooooooooooool5o`0000Wo
oooo00?o0?l0ooooooooool08_ooool00ol0003oooooooooo`0@ooooo`00I?ooool00ol0003ooooo
ooooo`0[ooooo`Co00002?ooool00ol0o`3oooooooooo`0:ooooo`_o00008?ooool5o`0000Sooooo
00?o0?l0ooooooooool03_ooool6o`0000Cooooo1_l0000>ooooo`[o00000oooool01?l0003ooooo
ooooooooool5o`0000Sooooo00?o0?l0ooooooooool08oooool00ol0003oooooooooo`0?ooooo`00
IOooool00ol0003oooooooooo`0Zooooo`Co00002?ooool00ol0o`3oooooooooo`0:ooooo`Go0000
1Oooool00ol0003oooooooooo`0Nooooo`Go00002?ooool00ol0o`3oooooooooo`0=ooooo`Ko0000
1oooool4o`0001Sooooo3?l00008ooooo`03o`3o0?oooooooooo02?ooooo00?o0000ooooooooool0
3oooool006Kooooo00?o0000ooooooooool0:Oooool5o`0000Oooooo00?o0?l0ooooooooool02Ooo
ool5o`0000Oooooo00?o0000ooooooooool07Oooool5o`0000Sooooo00?o0?l0ooooooooool03Ooo
ool5o`0002Wooooo00?o0000ooooool000002?l00004ooooo`03o`3o0?oooooooooo02Cooooo00?o
0000ooooooooool03_ooool006Oooooo00?o0000ooooooooool0:?ooool5o`0000Oooooo00?o0?l0
ooooooooool02Oooool5o`0000Sooooo00?o0000ooooooooool07Oooool4o`0000Sooooo00?o0?l0
ooooooooool03?ooool6o`0002[ooooo00?o0000ooooool000001?l00003ooooo`Co000000?o0?l0
ooooooooool09Oooool00ol0003oooooooooo`0=ooooo`00J?ooool2o`0002Sooooo1Ol00007oooo
o`03o`3o0?oooooooooo00Sooooo1_l00009ooooo`03o`000?oooooooooo01cooooo1Ol00007oooo
o`03o`3o0?oooooooooo00cooooo1Ol0000/ooooo`Ko00001oooool00ol0o`3o0000o`000005o`00
017ooooo2_l00006ooooo`03o`000?oooooooooo00cooooo001Zooooo`03o`000?oooooooooo02Ko
oooo1?l00007ooooo`03o`3o0?oooooooooo00Sooooo1Ol0000;ooooo`03o`000?oooooooooo01_o
oooo1Ol00007ooooo`03o`3o0?oooooooooo00_ooooo1_l0000/ooooo`Oo00001_ooool00ol0o`3o
ooooooooo`05ooooo`Go00002oooool=o`0000Cooooo00?o0000ooooooooool03?ooool006_ooooo
00?o0000ooooooooool09Oooool4o`0000Oooooo00?o0?l0ooooooooool01oooool6o`0000cooooo
00?o0000ooooooooool06_ooool5o`0000Oooooo00?o0?l0ooooooooool02oooool5o`0002kooooo
1_l00006ooooo`03o`3o0?oooooooooo00[ooooo1Ol00005ooooo`oo00001?ooool00ol0003ooooo
ooooo`0;ooooo`00K?ooool00ol0003oooooooooo`0Tooooo`Co00001oooool00ol0o`3ooooooooo
o`07ooooo`Go00003_ooool00ol0003oooooooooo`0Jooooo`Go00001_ooool00ol0o`3ooooooooo
o`0:ooooo`Ko0000;oooool5o`0000Kooooo00?o0?l0ooooooooool03ooooolFo`0000?ooooo00?o
0000ooooooooool02_ooool006gooooo00?o0000ooooooooool08oooool4o`0000Oooooo00?o0?l0
ooooooooool01_ooool6o`0000oooooo00?o0000ooooooooool06Oooool5o`0000Kooooo00?o0?l0
ooooooooool02_ooool5o`00037ooooo1Ol00005ooooo`03o`3o0?oooooooooo017ooooo2?l00004
ooooo`Wo00000oooool00ol0003oooooooooo`09ooooo`00K_ooool00ol0003oooooooooo`0Roooo
o`Co00001oooool00ol0o`3oooooooooo`06ooooo`Go00004Oooool00ol0003oooooooooo`0Hoooo
o`Go00001_ooool00ol0o`3oooooooooo`09ooooo`Ko0000<Oooool5o`0000Gooooo00?o0?l0oooo
ooooool04Oooool7o`000003ooooool0003o000000?o000000?oooooo`000?l000001_l00003oooo
o`03o`000?oooooooooo00Sooooo001_ooooo`03o`000?oooooooooo027ooooo1?l00007ooooo`03
o`3o0?oooooooooo00Kooooo1Ol0000Booooo`03o`000?oooooooooo01Sooooo1Ol00005ooooo`03
o`3o0?oooooooooo00Wooooo1Ol0000booooo`Ko00001?ooool00ol0o`3oooooooooo`0@ooooo`Oo
00001oooool9o`0000?ooooo00?o0000ooooooooool02?ooool0073ooooo00?o0000ooooooooool0
8?ooool4o`0000Oooooo00?o0?l0ooooooooool01_ooool4o`0001Cooooo00?o0000ooooooooool0
5oooool5o`0000Gooooo00?o0?l0ooooooooool02Oooool5o`0003?ooooo1Ol00004ooooo`03o`3o
0?oooooooooo013ooooo1Ol0000=ooooo`Oo00000_ooool00ol0003oooooooooo`07ooooo`00LOoo
ool00ol0003oooooooooo`0Oooooo`Go00001Oooool00ol0o`3oooooooooo`07ooooo`Co00005Ooo
ool00ol0003oooooooooo`0Fooooo`Go00001Oooool00ol0o`3oooooooooo`08ooooo`Go0000=?oo
ool5o`0000Gooooo00?o0?l0ooooooooool03_ooool6o`0000kooooo1ol00002ooooo`03o`000?oo
oooooooo00Kooooo001booooo`03o`000?oooooooooo01kooooo1Ol00005ooooo`03o`3o0?oooooo
oooo00Kooooo1Ol0000Fooooo`03o`000?oooooooooo01Kooooo1?l00005ooooo`03o`3o0?oooooo
oooo00Sooooo1Ol0000eooooo`Go00001?ooool00ol0o`3oooooooooo`0=ooooo`Ko00003oooool7
o`000004ooooool0003o0000o`0000Oooooo001cooooo`03o`000?oooooooooo01gooooo1Ol00005
ooooo`03o`3o0?oooooooooo00Kooooo1Ol0000Gooooo`03o`000?oooooooooo01Gooooo1?l00005
ooooo`03o`3o0?oooooooooo00Sooooo1Ol0000eooooo`Go00001?ooool00ol0o`3oooooooooo`0<
ooooo`Oo00004?ooool7o`0000;ooooo00?o0000ooooooooool01Oooool007Cooooo00?o0000oooo
ooooool07Oooool4o`0000Gooooo00?o0?l0ooooooooool01_ooool5o`0001Sooooo00?o0000oooo
ooooool05?ooool5o`0000Cooooo00?o0?l0ooooooooool01oooool5o`0003Kooooo1_l00003oooo
o`03o`3o0?oooooooooo00cooooo1_l0000Aooooo`Ko00000oooool00ol0003oooooooooo`05oooo
o`00MOooool2o`0001gooooo1?l00005ooooo`03o`3o0?oooooooooo00Gooooo1Ol0000Jooooo`03
o`000?oooooooooo01?ooooo1Ol00004ooooo`03o`3o0?oooooooooo00Oooooo1Ol0000gooooo`Go
00000oooool00ol0o`3oooooooooo`0;ooooo`Ko00003oooool3o`0000Wooooo00?o0000oooooooo
ool01Oooool007Oooooo00?o0000ooooooooool06_ooool4o`0000Gooooo00?o0?l0ooooooooool0
1Oooool5o`0001_ooooo00?o0000ooooooooool04_ooool5o`0000Cooooo00?o0?l0ooooooooool0
1oooool5o`0003Oooooo1_l00002ooooo`03o`3o0?oooooooooo00_ooooo1Ol0000=ooooo`?o0000
3?ooool00ol0003oooooooooo`05ooooo`00N?ooool00ol0003oooooooooo`0Iooooo`Co00001Ooo
ool00ol0o`3oooooooooo`05ooooo`Go00007?ooool00ol0003oooooooooo`0Booooo`Co00001?oo
ool00ol0o`3oooooooooo`06ooooo`Go0000>Oooool5o`0000;ooooo00?o0?l0ooooooooool02_oo
ool6o`0000Wooooo1?l0000?ooooo`03o`000?oooooooooo00Gooooo001iooooo`03o`000?oooooo
oooo01Sooooo1?l00005ooooo`03o`3o0?oooooooooo00Cooooo1Ol0000Nooooo`03o`000?oooooo
oooo017ooooo1Ol00003ooooo`03o`3o0?oooooooooo00Kooooo1Ol0000iooooo`Ko000000?ooooo
o`3o0?ooool02_ooool6o`0000Oooooo0ol0000Dooooo`03o`000?oooooooooo00Cooooo001joooo
o`03o`000?oooooooooo01Oooooo1?l00005ooooo`03o`3o0?oooooooooo00Cooooo1Ol0000Ooooo
o`03o`000?oooooooooo013ooooo1Ol00003ooooo`03o`3o0?oooooooooo00Kooooo1Ol0000joooo
o`Ko000000?o0?l0ooooooooool02?ooool7o`0000?ooooo1?l0000Gooooo`03o`000?oooooooooo
00Cooooo001kooooo`03o`000?oooooooooo01Kooooo1?l00005ooooo`03o`3o0?oooooooooo00Co
oooo1Ol0000Pooooo`03o`000?oooooooooo00oooooo1Ol00003ooooo`03o`3o0?oooooooooo00Go
oooo1Ol0000kooooo`Oo00002_ooool6o`000004ooooool0003o0000o`0001_ooooo00?o0000oooo
ooooool01?ooool007cooooo00?o0000ooooooooool05Oooool5o`0000Cooooo00?o0?l0oooooooo
ool00oooool5o`0002;ooooo00?o0000ooooooooool03oooool4o`0000?ooooo00?o0?l0oooooooo
ool01Oooool5o`0003cooooo1ol00008ooooo`So00007_ooool00ol0003oooooooooo`04ooooo`00
OOooool00ol0003oooooooooo`0Dooooo`Go00001?ooool00ol0o`3oooooooooo`03ooooo`Go0000
8oooool00ol0003oooooooooo`0>ooooo`Go00000_ooool00ol0o`3oooooooooo`05ooooo`Go0000
?Oooool7o`0000Oooooo1Ol0000Qooooo`03o`000?oooooooooo00Cooooo001nooooo`03o`000?oo
oooooooo01?ooooo1Ol00004ooooo`03o`3o0?oooooooooo00?ooooo1Ol0000Tooooo`03o`000?oo
oooooooo00gooooo1Ol00002ooooo`03o`3o0?oooooooooo00Cooooo1Ol0000nooooo`Oo00001Ooo
ool7o`00027ooooo00?o0000ooooooooool01?ooool007oooooo00?o0000ooooooooool04oooool4
o`0000Cooooo00?o0?l0ooooooooool00oooool4o`0002Kooooo00?o0000ooooooooool03?ooool5
o`0000;ooooo00?o0?l0ooooooooool01?ooool5o`0003oooooo4Ol0000Rooooo`03o`000?oooooo
oooo00Cooooo0020ooooo`03o`000?oooooooooo01;ooooo1Ol00003ooooo`03o`3o0?oooooooooo
00;ooooo1Ol0000Wooooo`03o`000?oooooooooo00cooooo1Ol000000ooooooo0?l0ooooo`04oooo
o`Ko0000@?ooool@o`0002;ooooo00?o0000ooooooooool01?ooool0087ooooo0_l0000Booooo`Go
00000oooool00ol0o`3oooooooooo`02ooooo`Go0000:?ooool00ol0003oooooooooo`0;ooooo`Go
000000?oooooo`3o0?ooool01?ooool5o`00043ooooo4?l0000Sooooo`03o`000?oooooooooo00Co
oooo0023ooooo`03o`000?oooooooooo00oooooo1Ol00003ooooo`03o`3o0?oooooooooo00;ooooo
1Ol0000Yooooo`03o`000?oooooooooo00[ooooo1Ol000000ooooooo0?l0ooooo`04ooooo`Go0000
?Oooool3o`0000;ooooo3?l0000Uooooo`03o`000?oooooooooo00Cooooo0024ooooo`03o`000?oo
oooooooo00oooooo1?l00003ooooo`04o`3o0?ooooooooooooooo`Go0000:oooool00ol0003ooooo
ooooo`0:ooooo`Go000000?o0?l0ooooooooool00_ooool5o`0003_ooooo0ol00007ooooo`Wo0000
9oooool00ol0003oooooooooo`03ooooo`00QOooool00ol0003oooooooooo`0>ooooo`Co00000ooo
ool01?l0o`3oooooooooooooool5o`0002cooooo00?o0000ooooooooool02Oooool6o`0000Cooooo
1Ol0000gooooo`Co00003?ooool5o`0002Wooooo00?o0000ooooooooool00oooool008Kooooo00?o
0000ooooooooool03Oooool4o`0000?ooooo00Co0?l0oooooooooooooooo1Ol0000]ooooo`03o`00
0?oooooooooo00Sooooo1_l00002ooooo`Oo0000=?ooool3o`0001Gooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`03ooooo`00Qoooool00ol0003oooooooooo`0<ooooo`Co00000ooo
ool00ol0o`3oooooooooo`05o`0002oooooo00?o0000ooooooooool02?ooool=o`00037ooooo1?l0
000Iooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00oooool008Sooooo00?o0000
ooooooooool02oooool4o`0000;ooooo00Co0?l0oooooooooooooooo1Ol0000`ooooo`03o`000?oo
oooooooo00Sooooo3?l0000^ooooo`?o00007_ooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo00?ooooo0029ooooo`03o`000?oooooooooo00[ooooo1?l00002ooooo`04o`3o0?oooooo
ooooooooo`Go0000<Oooool00ol0003oooooooooo`07ooooo`_o0000;?ooool3o`0002;ooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`03ooooo`00R_ooool00ol0003oooooooooo`09
ooooo`Go000000Coooooo`3o0?oooooooooo1Ol0000cooooo`03o`000?oooooooooo00Oooooo2?l0
000Zooooo`Co00009_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00?ooooo002;
ooooo`03o`000?oooooooooo00Sooooo1Ol000001?oooooo0?l0ooooooooool5o`0003Cooooo00?o
0000ooooooooool01oooool6o`0002Sooooo0ol0000Zooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool00oooool008cooooo00?o0000ooooooooool01oooool5o`000004ooooool0o`3o
ooooooooo`Go0000=Oooool00ol0003oooooooooo`0`ooooo`Co0000;_ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo00?ooooo002=ooooo`03o`000?oooooooooo00Oooooo1?l00000
1?oooooo0?l0ooooooooool4o`0003Oooooo00?o0000ooooooooool0;?ooool3o`0003?ooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`03ooooo`00S_ooool2o`0000Oooooo1?l00000
1?oooooo0?l0ooooooooool4o`0003Sooooo00?o0000ooooooooool09oooool4o`0003Oooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`03ooooo`00T?ooool00ol0003oooooooooo`04
ooooo`Co000000Coooooo`3o0?oooooooooo1?l0000iooooo`03o`000?oooooooooo02?ooooo0ol0
000looooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool00_ooool0097ooooo00?o0000
ooooooooool00oooool5o`000003o`3o0?oooooo000000Co0000>_ooool00ol0003oooooooooo`0O
ooooo`?o0000@?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00;ooooo002Boooo
o`03o`000?oooooooooo00;ooooo1Ol000000ol0o`3oooooo`000004o`0003_ooooo00?o0000oooo
ooooool06_ooool4o`0004?ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`02oooo
o`00Toooool01?l0003oooooooooooooool<o`0003cooooo00?o0000ooooooooool05_ooool3o`00
04Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02ooooo`00U?ooool01?l0003o
ooooooooooooool:o`0003kooooo00?o0000ooooooooool04Oooool4o`0004cooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`02ooooo`00UOooool00ol0003oooooooooo`0:o`0003oo
oooo00?o0000ooooooooool03Oooool3o`00057ooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`02ooooo`00U_ooool00ol0003oooooooooo`08o`00047ooooo00?o0000ooooooooool0
2Oooool3o`0005Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02ooooo`00Uooo
ool00ol0003oooooo`000007o`0004;ooooo00?o0000ooooooooool01?ooool4o`0005Wooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`02ooooo`00V?ooool00ol0003oooooo`000005
o`0004Cooooo00?o0000ooooooooool00ol0001Nooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool00_ooool009Wooooo00?o0000ooooooooool0BOooool2o`00067ooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`02ooooo`00V_ooool2o`0004Wooooo00?o0000oooooooo
ool0HOooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo007ooooo002Looooo`03o`00
0?oooooooooo04Kooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo007ooooo002Mooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0Hooo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo007ooooo002Nooooo`03o`000?oooooo
oooo04Cooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo007ooooo002Oooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0IOooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo007ooooo002Pooooo`03o`000?oooooooooo04;o
oooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo007o
oooo002Qooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0I_ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo007ooooo002Rooooo`03o`000?oooooooooo043ooooo00?o
0000ooooooooool0Ioooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo007ooooo002S
ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo007ooooo002Tooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool0JOooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo007ooooo002Uooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0@ooooo`7o
00000Oooool1ooooo`00Y_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo06[ooooo
00?o0000ooooooooool04?ooool1o`00007ooooo0Oooool00:Oooooo0_l0000looooo`03o`000?oo
oooooooo06_ooooo00?o0000ooooooooool03oooool1o`00007ooooo0Oooool00:Wooooo00?o0000
ooooooooool0>Oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo00kooooo0Ol00001
ooooo`7ooooo002Zooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`0=ooooo`7o00000Oooool1ooooo`00Zoooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo06kooooo00?o0000ooooooooool03?ooool1o`00007ooooo0Oooool00:cooooo
00?o0000ooooooooool0=_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00_ooooo
0Ol00001ooooo`7ooooo002]ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0Kooo
ool00ol0003oooooooooo`0;ooooo`7o00000Oooool1ooooo`00[_ooool00ol0003oooooooooo`0d
ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool02_ooool1o`00007ooooo0Oooool0
0:oooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo
00Wooooo0Ol00001ooooo`7ooooo002`ooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool0L_ooool00ol0003oooooooooo`08ooooo`7o00000Oooool1ooooo`00/Oooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool02?ooool1o`00007ooooo
002booooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0M?ooool00ol0003ooooooooo
o`07ooooo`7o00000Oooool00;?ooooo0_l0000`ooooo`03o`000?oooooooooo07Gooooo00?o0000
ooooooooool01_ooool1o`00007ooooo002eooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool0MOooool00ol0003oooooooooo`06ooooo`7o00000Oooool00;Kooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo00Gooooo0Ol00001ooooo`00
]oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool0
1?ooool1o`00007ooooo002hooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0N?oo
ool00ol0003oooooooooo`03ooooo`7o00000Oooool00;Wooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`1iooooo`03o`000?oooooooooo00;ooooo0Ol00001ooooo`00^_ooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo07[ooooo00Go0000ooooooooooooooooo`000001
ooooo`00^oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo07[ooooo00Go0000oooo
ooooooooooooo`000001ooooo`00_?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
07_ooooo00Co0000oooooooooooooooo0Ol000000;gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1looooo`03o`000?oooooooooo007o0000002nooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool0OOooool1o`00007ooooo0Ol000000;oooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`1nooooo`;o00000030ooooo`;o00008oooool00ol0003ooooooooo
o`1mooooo`?o00000032ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0NOooool4
o`0000?ooooo0033ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0MOooool4o`00
00Oooooo0034ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0L_ooool3o`0000_o
oooo0035ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0K_ooool4o`0000kooooo
0036ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0J_ooool4o`0001;ooooo0037
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0I_ooool4o`0001Kooooo0038oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0H_ooool4o`0001[ooooo0039ooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool0G_ooool4o`0001kooooo003:ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool0Foooool3o`0002;ooooo003;ooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool0Eoooool4o`0002Gooooo003<ooooo`;o00005oooool0
0ol0003oooooooooo`1Cooooo`Co0000:Oooool00<kooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`1?ooooo`Co0000;Oooool00<oooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`1;ooooo`Co0000<Oooool00=3ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`18ooooo`?o0000=Oooool00=7ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`14ooooo`Co0000>?ooool00=;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`10
ooooo`Co0000??ooool00=?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0loooo
o`Co0000@?ooool00=Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0hooooo`Co
0000A?ooool00=Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0dooooo`Co0000
B?ooool00=Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0aooooo`?o0000C?oo
ool00=Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0]ooooo`Co0000Coooool0
0=Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Yooooo`Co0000Doooool00=Wo
oooo0_l0000:ooooo`03o`000?oooooooooo02Gooooo1?l0001Gooooo`00foooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo027ooooo1?l0001Kooooo`00g?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo01gooooo1?l0001Oooooo`00gOooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01[ooooo0ol0001Sooooo`00g_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo01Kooooo1?l0001Vooooo`00goooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo01;ooooo1?l0001Zooooo`00h?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00kooooo1?l0001^ooooo`00hOooool01Ol0003ooooooooooooooooo000000cooooo
1?l0001booooo`00h_ooool01?l0003oooooooooool00009ooooo`?o0000M_ooool00>?ooooo00?o
0000ooooool000001Oooool4o`0007Wooooo003Tooooo`;o000000?oooooo`000?l000000_l0001m
ooooo`00iOooool2o`00087ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {346.188, 0}} -> {0, 0, 0, 0}}],

Cell[TextData[{
  "Fig. 7.2 The solution to Eq. ",
  ButtonBox["(7.1.1)",
    ButtonData:>{"Chapter7.nb", "(7.1.1)"},
    ButtonStyle->"Hyperlink"],
  "  for ",
  Cell[BoxData[
      \(TraditionalForm\`s = 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`v = b\ x\)]],
  ", at three times. Also shown are three characteristics with initial \
conditions ",
  Cell[BoxData[
      \(TraditionalForm\`x\_o = \(-2\), 1, 3\)]],
  ". "
}], "Caption",
  CellTags->"Fig. 7.2"],

Cell[TextData[{
  "\tThe characteristics must be used when solving ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]f/\[DifferentialD]t = a\ x\^n\)]],
  ". The solution to ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]f/\[DifferentialD]t = 
        a\ \(x\_o\^n\) \[ExponentialE]\^\(n\ b\ t\)\)]],
  "  is"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`f(t) = 
        f(0) + \ \(\(\(a\ x\_o\^n\)\/\(n\ b\)\) \((\[ExponentialE]\^\(n\ b\ t\
\) - 1)\)\(\ \)\)\)]],
  ". "
}], "NumberedEquation",
  CellTags->"(7.1.17)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`f(0) = \(f\_o\)(x\_o)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`f(
          t) = \(\(f(x, t)\)\( | \_\(x = x(t, x\_o)\)\)\)\)]],
  ". Finally, we must invert Eq. ",
  ButtonBox["(7.1.16)",
    ButtonData:>{"Chapter7.nb", "(7.1.16)"},
    ButtonStyle->"Hyperlink"],
  "  to obtain ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_o\)(x, t) = 
        x\ \[ExponentialE]\^\(\(-b\)\ t\)\)]],
  ". Substituting this result into  Eq. ",
  ButtonBox["(7.1.17)",
    ButtonData:>{"Chapter7.nb", "(7.1.17)"},
    ButtonStyle->"Hyperlink"],
  "  yields "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`f(x, 
          t)\  = \ \(f\_o\)(
            x\ \[ExponentialE]\^\(\(-b\)\ t\))\  + \ \(\(a\ x\^n\ \(\(\
\[ExponentialE]\)\(\ \)\)\^\(\(-n\)\ b\ t\)\)\/\(n\ b\)\) \
\(\((\[ExponentialE]\^\(n\ b\ t\) - 1)\)\(\ \ \)\(.\)\)\)]],
  " "
}], "UNNEQ"],

Cell[TextData[{
  " An example of the resulting evolution is shown in Cell ",
  ButtonBox["7.2",
    ButtonData:>"Cell 7.2",
    ButtonStyle->"Hyperlink"],
  ", for ",
  Cell[BoxData[
      \(TraditionalForm\`a = 0, b = 1\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_o\)(
          x)\  = \ \[ExponentialE]\^\(-\((x - 1)\)\^2\)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(f0[x_]\  = \ Exp[\(-\((x - 1)\)\^2\)];\)\), "\n", 
    \(\(f[x_, t_]\  = \ f0[x\ Exp[\(-\ t\)]];\)\), "\n", 
    \(\(Table[
        Plot[f[x, t], {x, \(-10\), 20}, PlotRange \[Rule] {0, 1}], {t, 0, 
          4,  .2}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.2"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.32877 .12361 -18 -4.5 ]
[.32877 .12361 0 4.5 ]
[.32877 .24721 -18 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -18 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -18 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-5)] .18254 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(10)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(15)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.34127 .12361 m
.34752 .12361 L
s
[(0.2)] .32877 .12361 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(0.4)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(0.6)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(0.8)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(1)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0309 m
.34502 .0309 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .09271 m
.34502 .09271 L
s
.34127 .15451 m
.34502 .15451 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .21631 m
.34502 .21631 L
s
.34127 .27812 m
.34502 .27812 L
s
.34127 .30902 m
.34502 .30902 L
s
.34127 .33992 m
.34502 .33992 L
s
.34127 .40172 m
.34502 .40172 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .46353 m
.34502 .46353 L
s
.34127 .52533 m
.34502 .52533 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .58713 m
.34502 .58713 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02499 0 L
.02605 0 L
.02729 0 L
.02846 0 L
.02954 0 L
.03053 0 L
.03163 0 L
.03279 0 L
.03395 0 L
.0352 0 L
.03638 0 L
.03746 0 L
.03873 0 L
.03944 0 L
.04011 0 L
.04132 0 L
.04262 0 L
.04327 0 L
.04396 0 L
.04519 0 L
.04588 0 L
.04652 0 L
.04722 0 L
.04797 0 L
.04862 0 L
.04933 0 L
.05061 0 L
.05186 0 L
.05302 0 L
.05414 0 L
.05519 0 L
.05634 0 L
.05759 0 L
.05882 0 L
.06012 0 L
.06123 0 L
.06244 0 L
.06315 0 L
.06381 0 L
.06453 0 L
.06529 0 L
.06657 0 L
.06729 0 L
.06797 0 L
.06924 0 L
.0704 0 L
.07103 0 L
.07173 0 L
.073 0 L
Mistroke
.07376 0 L
.07448 0 L
.07513 0 L
.07583 0 L
.0766 0 L
.0774 0 L
.07809 0 L
.07885 0 L
.07956 0 L
.0802 0 L
.08095 0 L
.08166 0 L
.08291 0 L
.08362 0 L
.08427 0 L
.08544 0 L
.08669 0 L
.08787 0 L
.08896 0 L
.09016 0 L
.09148 0 L
.09214 0 L
.09285 0 L
.09413 0 L
.09483 0 L
.09548 0 L
.09619 0 L
.09695 0 L
.09821 0 L
.09893 0 L
.09961 0 L
.10086 0 L
.10201 0 L
.10333 0 L
.10458 0 L
.10572 0 L
.10694 0 L
.1081 0 L
.10916 0 L
.11033 0 L
.11162 0 L
.11227 0 L
.11297 0 L
.11422 0 L
.11491 0 L
.11554 0 L
.11624 0 L
.11698 0 L
.11822 0 L
.11892 0 L
Mistroke
.11958 0 L
.12081 0 L
.12194 0 L
.12323 0 L
.12446 0 L
.12562 0 L
.12668 0 L
.12789 0 L
.12903 0 L
.13009 0 L
.13107 0 L
.13214 0 L
.13327 0 L
.13441 0 L
.13564 0 L
.1368 0 L
.13785 0 L
.13909 0 L
.13979 0 L
.14043 0 L
.14162 0 L
.14288 0 L
.14402 0 L
.14526 0 L
.14656 0 L
.14777 0 L
.14891 0 L
.14994 0 L
.15113 0 L
.15226 0 L
.15348 0 L
.15478 0 L
.15589 0 L
.15711 0 L
.15842 0 L
.15915 0 L
.15982 0 L
.16113 0 L
.16236 0 L
.16352 0 L
.16456 0 L
.16577 0 L
.1669 0 L
.16796 0 L
.16893 0 L
.16999 0 L
.17111 0 L
.17225 0 L
.17347 0 L
.17462 0 L
Mistroke
.17566 0 L
.17689 0 L
.17758 0 L
.17823 0 L
.1794 0 L
.18065 0 L
.18185 0 L
.18316 0 L
.18441 0 L
.18556 0 L
.1867 0 L
.18773 0 L
.18893 0 L
.19005 0 L
.19128 0 L
.19258 0 L
.19369 0 L
.19491 0 L
.19623 0 L
.19696 0 L
.19763 0 L
.19894 0 L
.20017 0 L
.20122 0 L
.20238 0 L
.20359 0 L
.20472 0 L
.20578 0 L
.20675 0 L
.20781 0 L
.20894 0 L
.21008 0 L
.21129 0 L
.21244 0 L
.21349 0 L
.21472 0 L
.21541 0 L
.21605 0 L
.21723 0 L
.21847 0 L
.21968 0 L
.221 0 L
.22224 0 L
.2234 0 L
.22454 0 L
.22558 0 L
.22677 0 L
.2279 0 L
.22914 0 L
.23044 0 L
Mistroke
.23155 0 L
.23277 0 L
.23409 0 L
.23482 0 L
.2355 0 L
.2368 0 L
.23804 0 L
.23909 0 L
.24025 0 L
.24146 0 L
.2426 0 L
.24365 0 L
.24462 0 L
.24569 0 L
.24681 0 L
.24795 0 L
.24917 0 L
.25032 0 L
.25137 0 L
.2526 0 L
.25393 0 L
.25519 0 L
.25635 0 L
.2576 0 L
.25879 0 L
.25987 0 L
.26103 0 L
.2623 0 L
.26364 0 L
.26479 1e-05 L
.26606 1e-05 L
.26723 1e-05 L
.26831 1e-05 L
.26949 1e-05 L
.27074 2e-05 L
.27284 3e-05 L
.27403 4e-05 L
.27514 5e-05 L
.27643 6e-05 L
.27782 8e-05 L
.27914 .0001 L
.28036 .00012 L
.28267 .00019 L
.28383 .00023 L
.28512 .00029 L
.28777 .00046 L
.28926 .00059 L
.29063 .00073 L
.29189 .0009 L
.29327 .00112 L
Mistroke
.29579 .00166 L
.29712 .00204 L
.29834 .00244 L
.3011 .00365 L
.30354 .00514 L
.30611 .00728 L
.30842 .00983 L
.31057 .0129 L
.31293 .0172 L
.31547 .02311 L
.31817 .03123 L
.3211 .04262 L
.32369 .05528 L
.32644 .07181 L
.33164 .11301 L
.33644 .16389 L
.34604 .30019 L
.35614 .46591 L
.36031 .52658 L
.36477 .57768 L
.36608 .58926 L
.36733 .5985 L
.36854 .60586 L
.36965 .61114 L
.37071 .61479 L
.37184 .61718 L
.37296 .61803 L
.3742 .61718 L
.37549 .61428 L
.37672 .60968 L
.37782 .60404 L
.37902 .59631 L
.38171 .5734 L
.3842 .54591 L
.39355 .4067 L
.4043 .23402 L
.40957 .16414 L
.41441 .11288 L
.41922 .0743 L
.4243 .04547 L
.42694 .03453 L
.42939 .02638 L
.43209 .01937 L
.43498 .01369 L
.43738 .01013 L
.43999 .00721 L
.44245 .00517 L
.44473 .00376 L
.44677 .0028 L
.44903 .002 L
Mistroke
.45139 .00139 L
.4536 .00098 L
.45484 .0008 L
.45617 .00065 L
.45855 .00043 L
.46002 .00034 L
.46139 .00027 L
.46264 .00021 L
.46397 .00017 L
.46514 .00014 L
.46643 .00011 L
.4687 7e-05 L
.46998 5e-05 L
.47135 4e-05 L
.47264 3e-05 L
.47383 3e-05 L
.47496 2e-05 L
.47621 2e-05 L
.47746 1e-05 L
.4788 1e-05 L
.47997 1e-05 L
.48123 1e-05 L
.48242 0 L
.48351 0 L
.48557 0 L
.48673 0 L
.48781 0 L
.48896 0 L
.49001 0 L
.49121 0 L
.49235 0 L
.4935 0 L
.49473 0 L
.4959 0 L
.49697 0 L
.49822 0 L
.49958 0 L
.50086 0 L
.50206 0 L
.5034 0 L
.50467 0 L
.50581 0 L
.50704 0 L
.50838 0 L
.50906 0 L
.5098 0 L
.51112 0 L
.51234 0 L
.51349 0 L
.51474 0 L
Mistroke
.51591 0 L
.517 0 L
.51798 0 L
.51906 0 L
.52019 0 L
.52125 0 L
.52242 0 L
.52364 0 L
.52469 0 L
.52584 0 L
.52708 0 L
.52777 0 L
.5284 0 L
.52963 0 L
.53079 0 L
.53194 0 L
.53319 0 L
.53436 0 L
.53543 0 L
.53668 0 L
.53739 0 L
.53804 0 L
.53924 0 L
.54052 0 L
.54122 0 L
.54186 0 L
.54255 0 L
.54331 0 L
.54459 0 L
.54528 0 L
.54593 0 L
.54717 0 L
.54829 0 L
.54959 0 L
.55082 0 L
.55189 0 L
.55306 0 L
.55428 0 L
.55543 0 L
.55649 0 L
.55747 0 L
.5586 0 L
.55967 0 L
.56083 0 L
.56206 0 L
.56322 0 L
.56427 0 L
.56551 0 L
.56621 0 L
.56685 0 L
Mistroke
.56803 0 L
.56928 0 L
.5705 0 L
.57119 0 L
.57183 0 L
.573 0 L
.57424 0 L
.57535 0 L
.57639 0 L
.57753 0 L
.57876 0 L
.57999 0 L
.58069 0 L
.58134 0 L
.58265 0 L
.58339 0 L
.58406 0 L
.58526 0 L
.58656 0 L
.58778 0 L
.58892 0 L
.58997 0 L
.59111 0 L
.59218 0 L
.59316 0 L
.5943 0 L
.59555 0 L
.59673 0 L
.59782 0 L
.59906 0 L
.60022 0 L
.60126 0 L
.60239 0 L
.60362 0 L
.60492 0 L
.60603 0 L
.60725 0 L
.60856 0 L
.60977 0 L
.6104 0 L
.6111 0 L
.61182 0 L
.61251 0 L
.61376 0 L
.6149 0 L
.61616 0 L
.61748 0 L
.6186 0 L
.61979 0 L
.62091 0 L
Mistroke
.62193 0 L
.62313 0 L
.62443 0 L
.62566 0 L
.62679 0 L
.628 0 L
.6293 0 L
.63052 0 L
.63164 0 L
.63295 0 L
.63369 0 L
.63437 0 L
.63563 0 L
.63626 0 L
.63697 0 L
.63764 0 L
.63836 0 L
.63963 0 L
.64034 0 L
.64101 0 L
.64173 0 L
.64251 0 L
.64318 0 L
.64391 0 L
.6446 0 L
.64524 0 L
.64644 0 L
.64772 0 L
.64893 0 L
.65024 0 L
.65149 0 L
.65264 0 L
.65378 0 L
.65482 0 L
.65601 0 L
.65714 0 L
.65837 0 L
.65967 0 L
.66079 0 L
.66201 0 L
.66332 0 L
.66406 0 L
.66473 0 L
.66603 0 L
.66727 0 L
.66832 0 L
.66948 0 L
.67069 0 L
.67182 0 L
.67288 0 L
Mistroke
.67385 0 L
.67492 0 L
.67604 0 L
.67718 0 L
.6784 0 L
.67955 0 L
.68059 0 L
.68182 0 L
.68251 0 L
.68315 0 L
.68433 0 L
.68557 0 L
.68678 0 L
.6881 0 L
.68935 0 L
.69051 0 L
.69165 0 L
.69269 0 L
.69389 0 L
.69502 0 L
.69625 0 L
.69756 0 L
.69867 0 L
.69989 0 L
.70121 0 L
.70195 0 L
.70262 0 L
.70392 0 L
.70516 0 L
.70621 0 L
.70737 0 L
.70859 0 L
.70972 0 L
.71078 0 L
.71175 0 L
.71287 0 L
.71394 0 L
.71508 0 L
.7163 0 L
.71745 0 L
.7185 0 L
.71973 0 L
.72042 0 L
.72106 0 L
.72223 0 L
.72347 0 L
.72469 0 L
.72538 0 L
.72602 0 L
.72718 0 L
Mistroke
.72843 0 L
.72953 0 L
.73057 0 L
.73171 0 L
.73294 0 L
.73418 0 L
.73487 0 L
.73552 0 L
.73684 0 L
.73757 0 L
.73824 0 L
.73944 0 L
.74074 0 L
.74197 0 L
.7431 0 L
.74415 0 L
.74529 0 L
.74636 0 L
.74734 0 L
.74848 0 L
.74973 0 L
.75091 0 L
.752 0 L
.75323 0 L
.7544 0 L
.75544 0 L
.75657 0 L
.7578 0 L
.7591 0 L
.76021 0 L
.76143 0 L
.76274 0 L
.76395 0 L
.76458 0 L
.76527 0 L
.766 0 L
.76668 0 L
.76793 0 L
.76907 0 L
.77033 0 L
.77165 0 L
.77277 0 L
.77396 0 L
.77508 0 L
.7761 0 L
.7773 0 L
.7786 0 L
.77983 0 L
.78096 0 L
.78217 0 L
Mistroke
.78347 0 L
.78469 0 L
.78581 0 L
.78712 0 L
.78786 0 L
.78854 0 L
.7898 0 L
.79043 0 L
.79113 0 L
.79181 0 L
.79252 0 L
.7938 0 L
.79451 0 L
.79517 0 L
.7959 0 L
.79668 0 L
.79735 0 L
.79808 0 L
.79877 0 L
.79941 0 L
.80061 0 L
.80189 0 L
.80309 0 L
.80441 0 L
.80565 0 L
.8068 0 L
.80795 0 L
.80898 0 L
.81018 0 L
.8113 0 L
.81253 0 L
.81383 0 L
.81495 0 L
.81616 0 L
.81748 0 L
.81821 0 L
.81889 0 L
.82019 0 L
.82143 0 L
.82247 0 L
.82363 0 L
.82484 0 L
.82598 0 L
.82704 0 L
.82801 0 L
.82907 0 L
.83019 0 L
.83133 0 L
.83255 0 L
.8337 0 L
Mistroke
.83475 0 L
.83597 0 L
.83667 0 L
.83731 0 L
.83848 0 L
.83973 0 L
.84094 0 L
.84226 0 L
.8435 0 L
.84466 0 L
.8458 0 L
.84684 0 L
.84804 0 L
.84916 0 L
.8504 0 L
.8517 0 L
.85282 0 L
.85404 0 L
.85535 0 L
.85609 0 L
.85676 0 L
.85807 0 L
.8593 0 L
.86036 0 L
.86152 0 L
.86273 0 L
.86387 0 L
.86493 0 L
.8659 0 L
.86696 0 L
.86808 0 L
.86922 0 L
.87044 0 L
.87159 0 L
.87264 0 L
.87387 0 L
.87456 0 L
.8752 0 L
.87638 0 L
.87762 0 L
.87883 0 L
.87952 0 L
.88016 0 L
.88132 0 L
.88256 0 L
.88367 0 L
.88471 0 L
.88585 0 L
.88708 0 L
.88831 0 L
Mistroke
.88901 0 L
.88966 0 L
.89097 0 L
.89171 0 L
.89237 0 L
.89357 0 L
.89487 0 L
.8961 0 L
.89723 0 L
.89829 0 L
.89942 0 L
.90049 0 L
.90147 0 L
.90261 0 L
.90386 0 L
.90504 0 L
.90613 0 L
.90736 0 L
.90853 0 L
.90957 0 L
.9107 0 L
.91193 0 L
.91323 0 L
.91434 0 L
.91556 0 L
.91687 0 L
.91807 0 L
.9187 0 L
.9194 0 L
.92013 0 L
.92081 0 L
.92206 0 L
.9232 0 L
.92445 0 L
.92578 0 L
.92689 0 L
.92808 0 L
.9292 0 L
.93022 0 L
.93142 0 L
.93273 0 L
.93395 0 L
.93509 0 L
.93629 0 L
.93759 0 L
.93881 0 L
.93993 0 L
.94123 0 L
.94197 0 L
.94266 0 L
Mistroke
.94391 0 L
.94462 0 L
.94525 0 L
.94593 0 L
.94664 0 L
.94792 0 L
.94863 0 L
.94929 0 L
.95002 0 L
.95079 0 L
.95147 0 L
.9522 0 L
.95289 0 L
.95352 0 L
.95473 0 L
.95601 0 L
.95665 0 L
.95735 0 L
.95863 0 L
.95987 0 L
.96103 0 L
.96173 0 L
.9624 0 L
.96364 0 L
.96434 0 L
.96498 0 L
.96568 0 L
.96643 0 L
.96759 0 L
.96883 0 L
.97001 0 L
.97108 0 L
.97234 0 L
.97305 0 L
.9737 0 L
.97491 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h/ooooo`05odA4A?l0003o0000oc8b<_oMgMd0G_ooool01Om4A4Co0000o`000?lb<S;ogMgM02[o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^:?ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0Tooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01?ooooo000Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0_ooooo`03ogMgMolb<S;ooooo063ooooo00?oMgMgoc8b<_ooool0:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo02Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL04oooool000oooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Sooooo`Ko00001oooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000;oooool00omgMgOo<S8booooo`1Pooooo`03ogMgMolb<S;ooooo02_o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002[ooooo00?o0000oooo
ooooool01_ooool00omgMgOo<S8booooo`0Vooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000;?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<05kooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00/ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Zooooo`03
o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Xooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@4100;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Aooooo`006_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Wooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01?ooooo000Hooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0/ooooo`Co0000Goooool4o`0002_ooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo00?oEEEEofIVI_l000001Oooool4o`0002Kooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001?ooooo
ool00016o`00013ooooo000Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooo`000004o`0000?ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool01?l0003ooooooooo
ooooool5o`000003ooooool0003ooooo00Wooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05_ooool001[ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo0_l0
00000ooooooo0000ooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`04o`000?oooooo0000o`0000Kooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Fooooo`00M_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool0a?ooool007Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo0<Gooooo001gooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`35ooooo`00N?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0aOooool007Sooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo0<Kooooo
001iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`36ooooo`00NOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool0aoooool007[ooooo00?o0000ooooooooool01?ooool3o`0001[ooooo00?o0000oooo
ooooool0aoooool007[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo0<Sooooo001jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`38ooooo`00Noooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0b?ooool007_ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo0<Wooooo001kooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`39ooooo`00Noooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0bOooool007cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo0<Wooooo
001looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`39ooooo`00O?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool0bOooool007cooooo00?o0000ooooooooool00_ooool3o`0001Sooooo00?o0000oooo
ooooool0bOooool007cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo0<[ooooo001looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`3:ooooo`00O?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool0b_ooool007cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0<[ooooo001looooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`3:ooooo`00O?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0b_ooool007cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0<[ooooo
001mooooo`05o`000?ooooooooooooooool000006Oooool00ol0003oooooooooo`3:ooooo`00OOoo
ool01Ol0003ooooooooooooooooo000001Sooooo00?o0000ooooooooool0boooool007gooooo00Co
0000oooooooooooooooo0ol0000Fooooo`03o`000?oooooooooo0<_ooooo001mooooo`05o`000?oo
ooooooooooooool000006?ooool00ol0003oooooooooo`3;ooooo`00OOooool01Ol0003ooooooooo
oooooooo000001Sooooo00?o0000ooooooooool0boooool007gooooo00Go0000oooooooooooooooo
o`00000Hooooo`03o`000?oooooooooo0<_ooooo001mooooo`05o`000?ooooooooooooooool00000
6?ooool00ol0003oooooooooo`3;ooooo`00O_ooool01?l0003oooooooooool0000Gooooo`03o`00
0?oooooooooo0<cooooo001nooooo`04o`000?ooooooooooo`0001Oooooo00?o0000ooooooooool0
c?ooool007kooooo00Co0000oooooooooooo00005oooool00ol0003oooooooooo`3<ooooo`00I_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00000oooool01?l0003ooooo
ooooool0000Gooooo`03o`000?oooooooooo0<cooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`04o`000?oooooooooo
o`0001Oooooo00?o0000ooooooooool0c?ooool006Kooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Co0000oooooooooooo00005oooool00ol0003ooooooooo
o`3<ooooo`00I_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h00ooo
ool00ol0003oooooooooo`03o`0001Gooooo00?o0000ooooooooool0c?ooool006Kooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00?o0000ooooool000005_oo
ool00ol0003oooooooooo`3=ooooo`00I_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o
0000ooooooooool00_ooool00ol0003oooooo`00000Fooooo`03o`000?oooooooooo0<gooooo001V
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo
00?o0000ooooool000005_ooool00ol0003oooooooooo`3=ooooo`00I_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`03o`000?oooooo000001Ko
oooo00?o0000ooooooooool0cOooool007oooooo00?o0000ooooool000005_ooool00ol0003ooooo
ooooo`3=ooooo`00Ooooool00ol0003oooooo`00000Fooooo`03o`000?oooooooooo0<gooooo001o
ooooo`03o`000?oooooo000001Kooooo00?o0000ooooooooool0cOooool007oooooo00?o0000oooo
ool000005_ooool00ol0003oooooooooo`3=ooooo`00Ooooool00ol0003oooooo`00000Fooooo`03
o`000?oooooooooo0<gooooo0020ooooo`Co00004oooool00ol0003oooooooooo`3>ooooo`00P?oo
ool2o`0001Gooooo00?o0000ooooooooool0c_ooool0083ooooo0_l0000Eooooo`03o`000?oooooo
oooo0<kooooo0020ooooo`;o00005Oooool00ol0003oooooooooo`3>ooooo`00P?ooool2o`0001Go
oooo00?o0000ooooooooool0c_ooool0083ooooo0_l0000Eooooo`03o`000?oooooooooo0<kooooo
0020ooooo`;o00005Oooool00ol0003oooooooooo`3>ooooo`00P?ooool2o`0001Gooooo00?o0000
ooooooooool0c_ooool0083ooooo0_l0000Eooooo`03o`000?oooooooooo0<kooooo0020ooooo`;o
00005Oooool00ol0003oooooooooo`3>ooooo`00P?ooool4o`0001?ooooo00?o0000ooooooooool0
c_ooool0087ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`3>ooooo`00POooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo0<kooooo0021ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0c_ooool0087ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`3>ooooo`00POooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0<oooooo
0021ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0coooool0087ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`3?ooooo`00POooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo0<oooooo0021ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool0coooool0087ooooo0ol0000Booooo`03o`000?oooooooooo0<oooooo0021ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0coooool0087ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`3?ooooo`00POooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
0<oooooo0021ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0coooool0087ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`3?ooooo`00POooool2o`0001?ooooo00?o
0000ooooooooool0coooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo00Cooooo0_l0000Cooooo`03o`000?oooooooooo0<oooooo001V
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Ooo
ool2o`0001?ooooo00?o0000ooooooooool0coooool006Kooooo00Go410@oooooooooooooooooa0@
400;ooooo`Go00001_ooool2o`0001?ooooo00?o0000ooooooooool0coooool006Kooooo00Go0000
ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0000Booooo`03o`00
0?oooooooooo0<oooooo001Vooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEE
ooooool00007ooooo`;o00004oooool00ol0003oooooooooo`3?ooooo`00I_ooool01Ol@413ooooo
oooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool2o`0001?ooooo00?o0000oooooooo
ool0coooool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oo
oooo0_l0000Booooo`03o`000?oooooooooo0=3ooooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03Oooool00omgMgOo0000ooooo`06ooooo`;o00004_ooool00ol0003oooooooooo`3@ooooo`00
POooool2o`0001;ooooo00?o0000ooooooooool0d?ooool0087ooooo0_l0000Booooo`03o`000?oo
oooooooo0=3ooooo0021ooooo`;o00004_ooool00ol0003oooooooooo`3@ooooo`00POooool2o`00
01;ooooo00?o0000ooooooooool0d?ooool0087ooooo0_l0000Booooo`03o`000?oooooooooo0=3o
oooo0021ooooo`?o00004Oooool00ol0003oooooooooo`3@ooooo`00POooool00ol0003oooooo`00
000Aooooo`03o`000?oooooooooo0=3ooooo0021ooooo`03o`000?oooooo0000017ooooo00?o0000
ooooooooool0d?ooool0087ooooo00?o0000ooooool000004Oooool00ol0003oooooooooo`3@oooo
o`00POooool00ol0003oooooo`00000Aooooo`03o`000?oooooooooo0=3ooooo0021ooooo`03o`00
0?oooooo0000017ooooo00?o0000ooooooooool0d?ooool0087ooooo00?o0000ooooool000004Ooo
ool00ol0003oooooooooo`3@ooooo`00POooool00ol0003oooooo`00000@ooooo`03o`000?oooooo
oooo0=7ooooo0021ooooo`03o`000?oooooo0000013ooooo00?o0000ooooooooool0dOooool0087o
oooo00?o0000ooooool000004?ooool00ol0003oooooooooo`3Aooooo`00POooool3o`00013ooooo
00?o0000ooooooooool0dOooool0087ooooo00?o0000ooooool000004?ooool00ol0003ooooooooo
o`3Aooooo`00POooool00ol0003oooooo`00000@ooooo`03o`000?oooooooooo0=7ooooo0021oooo
o`03o`000?oooooo0000013ooooo00?o0000ooooooooool0dOooool0087ooooo00?o0000ooooool0
00004?ooool00ol0003oooooooooo`3Aooooo`00POooool00ol0003oooooo`00000@ooooo`03o`00
0?oooooooooo0=7ooooo0021ooooo`03o`000?oooooo0000013ooooo00?o0000ooooooooool0dOoo
ool0087ooooo00Co0000oooooooooooo00003oooool00ol0003oooooooooo`3Aooooo`00POooool0
1?l0003oooooooooool0000?ooooo`03o`000?oooooooooo0=7ooooo0021ooooo`04o`000?oooooo
ooooo`0000oooooo00?o0000ooooooooool0dOooool0087ooooo1?l0000?ooooo`03o`000?oooooo
oooo0=7ooooo0021ooooo`04o`000?ooooooooooo`0000kooooo00?o0000ooooooooool0d_ooool0
087ooooo00Co0000oooooooooooo00003_ooool00ol0003oooooooooo`3Booooo`00POooool01?l0
003oooooooooool0000>ooooo`03o`000?oooooooooo0=;ooooo0021ooooo`04o`000?oooooooooo
o`0000kooooo00?o0000ooooooooool0d_ooool0087ooooo00Co0000oooooooooooo00003_ooool0
0ol0003oooooooooo`3Booooo`00POooool01?l0003oooooooooool0000>ooooo`03o`000?oooooo
oooo0=;ooooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`04o`000?ooooooooooo`0000kooooo00?o0000ooooooooool0
d_ooool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMg
oooooonHV9So8B4Q00Kooooo00Co0000oooooooooooo00003_ooool00ol0003oooooooooo`3Boooo
o`00I_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006
ooooo`04o`000?ooooooooooo`0000kooooo00?o0000ooooooooool0d_ooool006Kooooo00Go0000
ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool4o`0000kooooo
00?o0000ooooooooool0d_ooool006Kooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?mEEEGo0000oa0@4?o<c<`01_ooool01?l0003oooooooooool0000>ooooo`03o`000?oooooooooo
0=;ooooo001Vooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08oooo
o`04o`000?ooooooooooo`0000kooooo00?o0000ooooooooool0d_ooool006Kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00Co0000oooooooooooo00003_oo
ool00ol0003oooooooooo`3Booooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Co
c<c<odA4A?l0003o410@1_ooool01?l0003oooooooooool0000>ooooo`03o`000?oooooooooo0=;o
oooo0021ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003oooooooooo`3Cooooo`00
POooool01Ol0003ooooooooooooooooo000000cooooo00?o0000ooooooooool0doooool0087ooooo
00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo0=?ooooo0021ooooo`05o`00
0?ooooooooooooooool000003?ooool00ol0003oooooooooo`3Cooooo`00POooool01Ol0003ooooo
oooooooooooo000000cooooo00?o0000ooooooooool0doooool0087ooooo0ol000000ooooooo0000
ooooo`0;ooooo`03o`000?oooooooooo0=?ooooo0021ooooo`05o`000?ooooooooooooooool00000
3?ooool00ol0003oooooooooo`3Cooooo`00POooool01Ol0003ooooooooooooooooo000000cooooo
00?o0000ooooooooool0doooool0087ooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`00
0?oooooooooo0=?ooooo0021ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003ooooo
ooooo`3Cooooo`00POooool01Ol0003ooooooooooooooooo000000cooooo00?o0000ooooooooool0
doooool0087ooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo0=?ooooo
0021ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003oooooooooo`3Cooooo`00POoo
ool01Ol0003ooooooooooooooooo000000cooooo00?o0000ooooooooool0doooool0087ooooo00Go
0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo0=Cooooo0021ooooo`?o000000?o
ooooo`000?ooool02_ooool00ol0003oooooooooo`3Dooooo`00POooool01Ol0003ooooooooooooo
oooo000000_ooooo00?o0000ooooooooool0e?ooool0087ooooo00Go0000ooooooooooooooooo`00
000;ooooo`03o`000?oooooooooo0=Cooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`3Dooooo`00POooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0e?ooool0087ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0=Cooooo0021ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`3Dooooo`00POoo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0e?oo
ool0087ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo0=Cooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`3Dooooo`00POooool3o`0000;ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`3Dooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0e?ooool0087ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo0=Cooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`3Dooooo`00POooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0eOooool0087ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0=Gooooo0021ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3Eooooo`00I_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<
c<`01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0eOooool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7o
V9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo0=Gooooo001Vooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0=Gooooo001Vooooo`05o`000?ooooooooooooooool000002oooool0
1Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol00002ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0eOooool006Kooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0
003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0eOooool006Kooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@
4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0eOooool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0eOooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0eOooool0087ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo0=Gooooo0021ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3Eooooo`00POooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0eOooool0087ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0=Gooooo0021
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3F
ooooo`00POooool3o`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3Foooo
o`00POooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0e_ooool0087ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0=Kooooo0021ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`3Fooooo`00POooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0e_ooool0087ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo0=Kooooo0021ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3Fooooo`00POooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0e_ooool0087ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0=Kooooo0021
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3F
ooooo`00POooool3o`0000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3Foooo
o`00POooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0eoooool0087ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo0=Oooooo0021ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`3Gooooo`00POooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0eoooool0087ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo0=Oooooo0021ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3Gooooo`00POooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0eoooool0087ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0=Oooooo0021
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3G
ooooo`00POooool3o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3Goooo
o`00POooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0eoooool0087ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0=Oooooo0021ooooo`03o`000?oooooooooo00Kooooo00Go0000oooooooooooooooo
o`00003Iooooo`00POooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool00000
fOooool0087ooooo00?o0000ooooooooool01_ooool01?l0003oooooooooool0003Jooooo`00POoo
ool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`000=[ooooo001gooooo`Co000000?o
410@ooooooooool00oooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`000=[ooooo
001iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool01?l0003ooooooooo
ool0003Jooooo`00NOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo0_l0
003Kooooo`00NOooool00ol0003oooooooooo`05ooooo`?o00001oooool2o`000=_ooooo001ioooo
o`03o`000?oooooooooo0>cooooo001iooooo`03o`000?oooooooooo0>cooooo001iooooo`03o`00
0?oooooooooo0>cooooo001gooooo`03oeEEEOmVIVKo00000>kooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-12, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.32877 .12361 -18 -4.5 ]
[.32877 .12361 0 4.5 ]
[.32877 .24721 -18 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -18 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -18 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-5)] .18254 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(10)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(15)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.34127 .12361 m
.34752 .12361 L
s
[(0.2)] .32877 .12361 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(0.4)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(0.6)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(0.8)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(1)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0309 m
.34502 .0309 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .09271 m
.34502 .09271 L
s
.34127 .15451 m
.34502 .15451 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .21631 m
.34502 .21631 L
s
.34127 .27812 m
.34502 .27812 L
s
.34127 .30902 m
.34502 .30902 L
s
.34127 .33992 m
.34502 .33992 L
s
.34127 .40172 m
.34502 .40172 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .46353 m
.34502 .46353 L
s
.34127 .52533 m
.34502 .52533 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .58713 m
.34502 .58713 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02499 0 L
.02605 0 L
.02729 0 L
.02846 0 L
.02954 0 L
.03053 0 L
.03163 0 L
.03279 0 L
.03395 0 L
.0352 0 L
.03638 0 L
.03746 0 L
.03873 0 L
.03944 0 L
.04011 0 L
.04132 0 L
.04262 0 L
.04327 0 L
.04396 0 L
.04519 0 L
.04588 0 L
.04652 0 L
.04722 0 L
.04797 0 L
.04862 0 L
.04933 0 L
.05061 0 L
.05186 0 L
.05302 0 L
.05414 0 L
.05519 0 L
.05634 0 L
.05759 0 L
.05882 0 L
.06012 0 L
.06123 0 L
.06244 0 L
.06315 0 L
.06381 0 L
.06453 0 L
.06529 0 L
.06657 0 L
.06729 0 L
.06797 0 L
.06924 0 L
.0704 0 L
.07103 0 L
.07173 0 L
.073 0 L
Mistroke
.07376 0 L
.07448 0 L
.07513 0 L
.07583 0 L
.0766 0 L
.0774 0 L
.07809 0 L
.07885 0 L
.07956 0 L
.0802 0 L
.08095 0 L
.08166 0 L
.08291 0 L
.08362 0 L
.08427 0 L
.08544 0 L
.08669 0 L
.08787 0 L
.08896 0 L
.09016 0 L
.09148 0 L
.09214 0 L
.09285 0 L
.09413 0 L
.09483 0 L
.09548 0 L
.09619 0 L
.09695 0 L
.09821 0 L
.09893 0 L
.09961 0 L
.10086 0 L
.10201 0 L
.10333 0 L
.10458 0 L
.10572 0 L
.10694 0 L
.1081 0 L
.10916 0 L
.11033 0 L
.11162 0 L
.11227 0 L
.11297 0 L
.11422 0 L
.11491 0 L
.11554 0 L
.11624 0 L
.11698 0 L
.11822 0 L
.11892 0 L
Mistroke
.11958 0 L
.12081 0 L
.12194 0 L
.12323 0 L
.12446 0 L
.12562 0 L
.12668 0 L
.12789 0 L
.12903 0 L
.13009 0 L
.13107 0 L
.13214 0 L
.13327 0 L
.13441 0 L
.13564 0 L
.1368 0 L
.13785 0 L
.13909 0 L
.13979 0 L
.14043 0 L
.14162 0 L
.14288 0 L
.14402 0 L
.14526 0 L
.14656 0 L
.14777 0 L
.14891 0 L
.14994 0 L
.15113 0 L
.15226 0 L
.15348 0 L
.15478 0 L
.15589 0 L
.15711 0 L
.15842 0 L
.15915 0 L
.15982 0 L
.16113 0 L
.16236 0 L
.16352 0 L
.16456 0 L
.16577 0 L
.1669 0 L
.16796 0 L
.16893 0 L
.16999 0 L
.17111 0 L
.17225 0 L
.17347 0 L
.17462 0 L
Mistroke
.17566 0 L
.17689 0 L
.17823 0 L
.17948 0 L
.18065 0 L
.18189 0 L
.18308 0 L
.18414 0 L
.1853 0 L
.18656 0 L
.1879 0 L
.18916 0 L
.19031 0 L
.19148 0 L
.19255 0 L
.19373 0 L
.19497 0 L
.19605 0 L
.19707 0 L
.19817 0 L
.19936 0 L
.20074 0 L
.20202 0 L
.20342 0 L
.2049 0 L
.20619 0 L
.2074 0 L
.20872 0 L
.21015 0 L
.21134 0 L
.21265 0 L
.21401 0 L
.21528 0 L
.21647 0 L
.21756 0 L
.21881 0 L
.21999 0 L
.22114 0 L
.22238 0 L
.22354 0 L
.22461 0 L
.22586 0 L
.22722 0 L
.22851 0 L
.2297 0 L
.23105 0 L
.23232 0 L
.23468 0 L
.23601 0 L
.23723 0 L
Mistroke
.23858 0 L
.23999 0 L
.24219 0 L
.24342 0 L
.24454 0 L
.24559 0 L
.24673 0 L
.24879 1e-05 L
.24995 1e-05 L
.25122 1e-05 L
.25247 1e-05 L
.25381 2e-05 L
.25505 2e-05 L
.2562 2e-05 L
.25844 3e-05 L
.25972 4e-05 L
.26093 5e-05 L
.26319 7e-05 L
.26563 .0001 L
.267 .00013 L
.26826 .00015 L
.27038 .00021 L
.2727 .00029 L
.27513 .00041 L
.27739 .00056 L
.28007 .0008 L
.28262 .00112 L
.2849 .0015 L
.28738 .00205 L
.29008 .00284 L
.29295 .00398 L
.2954 .00526 L
.2981 .0071 L
.30044 .00914 L
.30301 .01193 L
.3055 .01535 L
.30817 .01991 L
.31296 .03098 L
.31742 .04551 L
.32303 .07113 L
.32833 .10437 L
.3331 .14266 L
.33826 .19353 L
.35772 .44359 L
.36304 .50996 L
.36598 .54188 L
.36878 .56798 L
.37136 .58782 L
.37273 .59643 L
.37419 .60409 L
Mistroke
.37553 .60973 L
.37675 .6136 L
.37798 .61629 L
.37914 .6177 L
.38032 .618 L
.38142 .61726 L
.38263 .61529 L
.38393 .61187 L
.38529 .60684 L
.38657 .60076 L
.38899 .58603 L
.39333 .54962 L
.39805 .49821 L
.40777 .37069 L
.4185 .23118 L
.42341 .17697 L
.4287 .128 L
.43327 .09389 L
.43828 .06479 L
.44362 .04204 L
.44653 .03268 L
.44924 .02559 L
.4541 .01611 L
.45681 .01226 L
.45929 .00949 L
.46179 .00726 L
.46414 .0056 L
.46658 .00424 L
.46927 .0031 L
.47159 .00235 L
.47371 .00181 L
.47615 .00133 L
.47848 .00098 L
.48098 .00071 L
.48364 .00049 L
.48615 .00035 L
.48843 .00025 L
.49111 .00017 L
.49263 .00013 L
.49402 .00011 L
.49658 7e-05 L
.49786 6e-05 L
.49927 5e-05 L
.5018 3e-05 L
.50322 3e-05 L
.50453 2e-05 L
.50695 1e-05 L
.50817 1e-05 L
.50951 1e-05 L
.51183 1e-05 L
Mistroke
.51313 0 L
.51432 0 L
.51542 0 L
.51663 0 L
.51883 0 L
.52025 0 L
.52158 0 L
.5228 0 L
.52408 0 L
.52548 0 L
.52677 0 L
.52816 0 L
.52968 0 L
.53099 0 L
.53219 0 L
.53358 0 L
.53489 0 L
.5361 0 L
.53722 0 L
.53845 0 L
.53976 0 L
.54089 0 L
.54214 0 L
.54343 0 L
.54464 0 L
.54577 0 L
.5468 0 L
.54799 0 L
.54912 0 L
.55034 0 L
.55164 0 L
.55274 0 L
.55396 0 L
.55527 0 L
.55667 0 L
.558 0 L
.55921 0 L
.56034 0 L
.56154 0 L
.56267 0 L
.56369 0 L
.5649 0 L
.56621 0 L
.56745 0 L
.56858 0 L
.56965 0 L
.57065 0 L
.57174 0 L
.57291 0 L
.57414 0 L
Mistroke
.57531 0 L
.57635 0 L
.57748 0 L
.5787 0 L
.57982 0 L
.58105 0 L
.58234 0 L
.58347 0 L
.58452 0 L
.58567 0 L
.5869 0 L
.58824 0 L
.589 0 L
.5897 0 L
.59098 0 L
.59163 0 L
.59234 0 L
.59357 0 L
.59489 0 L
.59614 0 L
.59728 0 L
.59858 0 L
.5993 0 L
.59996 0 L
.60124 0 L
.60244 0 L
.60313 0 L
.60385 0 L
.60514 0 L
.60587 0 L
.60654 0 L
.60727 0 L
.60806 0 L
.60876 0 L
.60939 0 L
.61065 0 L
.61179 0 L
.61301 0 L
.61431 0 L
.61552 0 L
.61622 0 L
.61686 0 L
.61755 0 L
.61829 0 L
.61958 0 L
.62079 0 L
.62197 0 L
.62306 0 L
.62424 0 L
.62553 0 L
Mistroke
.62618 0 L
.62688 0 L
.62814 0 L
.62931 0 L
.63059 0 L
.6318 0 L
.63292 0 L
.63392 0 L
.63503 0 L
.63619 0 L
.63728 0 L
.63849 0 L
.63917 0 L
.63981 0 L
.6411 0 L
.64182 0 L
.64248 0 L
.64366 0 L
.64493 0 L
.64614 0 L
.64725 0 L
.64853 0 L
.64973 0 L
.65105 0 L
.65179 0 L
.65247 0 L
.65317 0 L
.65383 0 L
.65454 0 L
.65531 0 L
.65603 0 L
.65672 0 L
.658 0 L
.65916 0 L
.66041 0 L
.66159 0 L
.66267 0 L
.66393 0 L
.66464 0 L
.6653 0 L
.6665 0 L
.66779 0 L
.66901 0 L
.67032 0 L
.67156 0 L
.6727 0 L
.67396 0 L
.67467 0 L
.67534 0 L
.67604 0 L
Mistroke
.67668 0 L
.67742 0 L
.67811 0 L
.67918 0 L
.68036 0 L
.68159 0 L
.68273 0 L
.68381 0 L
.68479 0 L
.68592 0 L
.68699 0 L
.68814 0 L
.68938 0 L
.69043 0 L
.69159 0 L
.69283 0 L
.69353 0 L
.69417 0 L
.69535 0 L
.6966 0 L
.69783 0 L
.69852 0 L
.69916 0 L
.70034 0 L
.70159 0 L
.7027 0 L
.70375 0 L
.70489 0 L
.70612 0 L
.70743 0 L
.70817 0 L
.70885 0 L
.71011 0 L
.71081 0 L
.71144 0 L
.71265 0 L
.71395 0 L
.71518 0 L
.71631 0 L
.71737 0 L
.71851 0 L
.71959 0 L
.72057 0 L
.72172 0 L
.72297 0 L
.72415 0 L
.72524 0 L
.72636 0 L
.72741 0 L
.72857 0 L
Mistroke
.72981 0 L
.73105 0 L
.73235 0 L
.73345 0 L
.73467 0 L
.73599 0 L
.73721 0 L
.73784 0 L
.73854 0 L
.73927 0 L
.73996 0 L
.74122 0 L
.74237 0 L
.743 0 L
.74369 0 L
.74495 0 L
.74618 0 L
.7473 0 L
.74859 0 L
.7498 0 L
.75092 0 L
.75196 0 L
.75309 0 L
.75429 0 L
.7556 0 L
.75679 0 L
.75745 0 L
.75816 0 L
.75946 0 L
.76068 0 L
.76197 0 L
.76307 0 L
.76429 0 L
.76502 0 L
.76571 0 L
.76701 0 L
.76774 0 L
.76841 0 L
.76915 0 L
.76994 0 L
.77063 0 L
.77137 0 L
.77208 0 L
.77272 0 L
.77395 0 L
.77524 0 L
.77646 0 L
.77715 0 L
.77779 0 L
.77895 0 L
Mistroke
.7802 0 L
.7813 0 L
.78234 0 L
.78348 0 L
.78471 0 L
.78595 0 L
.78664 0 L
.78729 0 L
.78861 0 L
.78934 0 L
.79001 0 L
.79121 0 L
.79251 0 L
.79374 0 L
.79487 0 L
.79592 0 L
.79706 0 L
.79813 0 L
.79911 0 L
.80025 0 L
.8015 0 L
.80268 0 L
.80377 0 L
.805 0 L
.80617 0 L
.80721 0 L
.80834 0 L
.80957 0 L
.81087 0 L
.81198 0 L
.8132 0 L
.81451 0 L
.81572 0 L
.81635 0 L
.81704 0 L
.81777 0 L
.81845 0 L
.8197 0 L
.82084 0 L
.8221 0 L
.82342 0 L
.82454 0 L
.82573 0 L
.82685 0 L
.82787 0 L
.82907 0 L
.83037 0 L
.8316 0 L
.83273 0 L
.83394 0 L
Mistroke
.83524 0 L
.83646 0 L
.83758 0 L
.83889 0 L
.83963 0 L
.84031 0 L
.84157 0 L
.8422 0 L
.8429 0 L
.84358 0 L
.84429 0 L
.84557 0 L
.84628 0 L
.84694 0 L
.84767 0 L
.84845 0 L
.84912 0 L
.84985 0 L
.85054 0 L
.85118 0 L
.85238 0 L
.85366 0 L
.85486 0 L
.85618 0 L
.85742 0 L
.85857 0 L
.85972 0 L
.86075 0 L
.86195 0 L
.86307 0 L
.8643 0 L
.8656 0 L
.86672 0 L
.86793 0 L
.86925 0 L
.86998 0 L
.87066 0 L
.87196 0 L
.8732 0 L
.87424 0 L
.8754 0 L
.87661 0 L
.87775 0 L
.87881 0 L
.87978 0 L
.88084 0 L
.88196 0 L
.8831 0 L
.88432 0 L
.88547 0 L
Mistroke
.88652 0 L
.88774 0 L
.88844 0 L
.88908 0 L
.89025 0 L
.8915 0 L
.89271 0 L
.89403 0 L
.89527 0 L
.89643 0 L
.89757 0 L
.89861 0 L
.89981 0 L
.90093 0 L
.90217 0 L
.90347 0 L
.90459 0 L
.90581 0 L
.90712 0 L
.90786 0 L
.90853 0 L
.90984 0 L
.91107 0 L
.91213 0 L
.91329 0 L
.9145 0 L
.91564 0 L
.9167 0 L
.91767 0 L
.91873 0 L
.91985 0 L
.92099 0 L
.92221 0 L
.92336 0 L
.92441 0 L
.92564 0 L
.92633 0 L
.92697 0 L
.92815 0 L
.92939 0 L
.9306 0 L
.93129 0 L
.93193 0 L
.93309 0 L
.93433 0 L
.93544 0 L
.93648 0 L
.93762 0 L
.93885 0 L
.94008 0 L
Mistroke
.94078 0 L
.94143 0 L
.94274 0 L
.94348 0 L
.94414 0 L
.94534 0 L
.94664 0 L
.94787 0 L
.949 0 L
.95006 0 L
.95119 0 L
.95226 0 L
.95324 0 L
.95438 0 L
.95563 0 L
.95681 0 L
.9579 0 L
.95913 0 L
.9603 0 L
.96134 0 L
.96247 0 L
.9637 0 L
.965 0 L
.96611 0 L
.96733 0 L
.96848 0 L
.96957 0 L
.97054 0 L
.97161 0 L
.97276 0 L
.97399 0 L
.97504 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h/ooooo`05odA4A?l0003o0000oc8b<_oMgMd0G_ooool01Om4A4Co0000o`000?lb<S;ogMgM02[o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^:?ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0Tooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01?ooooo000Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0_ooooo`03ogMgMolb<S;ooooo063ooooo00?oMgMgoc8b<_ooool0:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo02Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL04oooool000oooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Sooooo`Ko00001oooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000;oooool00omgMgOo<S8booooo`1Pooooo`03ogMgMolb<S;ooooo02_o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002[ooooo00?o0000oooo
ooooool01_ooool00omgMgOo<S8booooo`0Vooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000;?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<05kooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00/ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Zooooo`03
o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Xooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@4100;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Aooooo`006_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Wooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01?ooooo000Hooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0/ooooo`Co0000Goooool4o`0002_ooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo00?oEEEEofIVI_l000001Oooool4o`0002Kooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001?ooooo
ool00016o`00013ooooo000Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool7o`0000Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`So00000ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Fooooo`006_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool2o`0000[ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05_ooool0
07?ooooo0_l0000<ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0_Oooool007Go
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Sooooo`;o0000_oooool007Kooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo0;kooooo
001fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`2oooooo`00Moooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool0_oooool007Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo0<3ooooo001hooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`31ooooo`00N?ooool00ol0003oooooooooo`06ooooo`?o0000
8?ooool00ol0003oooooooooo`31ooooo`00N?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool0`_ooool007Wooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo0<;ooooo001iooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`33ooooo`00NOooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0`oooool007[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo0<?ooooo
001jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`33ooooo`00N_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool0`oooool007[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo0<Cooooo001jooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`34ooooo`00Noooool00ol0003oooooooooo`03ooooo`?o0000
7Oooool00ol0003oooooooooo`34ooooo`00Noooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool0a?ooool007_ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo0<Cooooo001kooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`34ooooo`00Noooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0aOooool007_ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo0<Gooooo
001kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`35ooooo`00O?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool0aOooool007cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo0<Gooooo001looooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`36ooooo`00O?ooool00ol0003oooooooooo`02ooooo`?o0000
6oooool00ol0003oooooooooo`36ooooo`00O?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool0a_ooool007gooooo00Go0000ooooooooooooooooo`00
000Mooooo`03o`000?oooooooooo0<Kooooo001mooooo`05o`000?ooooooooooooooool000007Ooo
ool00ol0003oooooooooo`36ooooo`00OOooool01Ol0003ooooooooooooooooo000001gooooo00?o
0000ooooooooool0a_ooool007gooooo00Go0000ooooooooooooooooo`00000Mooooo`03o`000?oo
oooooooo0<Kooooo001mooooo`05o`000?ooooooooooooooool000007Oooool00ol0003ooooooooo
o`36ooooo`00OOooool01Ol0003ooooooooooooooooo000001cooooo00?o0000ooooooooool0aooo
ool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000?ooooo00Co
0000oooooooooooo00007?ooool00ol0003oooooooooo`37ooooo`00I_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01?l0003o
ooooooooool0000Looooo`03o`000?oooooooooo0<Oooooo001Vooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00onHV9So8B4Qonk^kP04ooooo`04o`000?ooooooooooo`0001cooooo00?o0000
ooooooooool0aoooool006Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^00?ooooo00?o0000ooooooooool00ol0000Jooooo`03o`000?oooooooooo0<Oooooo001Voooo
o`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`02ooooo`04o`000?oooooo
ooooo`0001cooooo00?o0000ooooooooool0aoooool006Kooooo00Go410@oooooooooooooooooa0@
400?ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo0<Oooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zj
oooooonHV9So410@00?ooooo00Co0000oooooooooooo00007?ooool00ol0003oooooooooo`37oooo
o`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004
ooooo`03o`000?oooooo000001cooooo00?o0000ooooooooool0aoooool007oooooo00?o0000oooo
ool000007?ooool00ol0003oooooooooo`37ooooo`00Ooooool00ol0003oooooo`00000Kooooo`03
o`000?oooooooooo0<Sooooo001oooooo`03o`000?oooooo000001_ooooo00?o0000ooooooooool0
b?ooool007oooooo00?o0000ooooool000006oooool00ol0003oooooooooo`38ooooo`00Ooooool0
0ol0003oooooo`00000Kooooo`03o`000?oooooooooo0<Sooooo001oooooo`03o`000?oooooo0000
00;o00006Oooool00ol0003oooooooooo`38ooooo`00Ooooool00ol0003oooooo`00000Kooooo`03
o`000?oooooooooo0<Sooooo001oooooo`03o`000?oooooo000001_ooooo00?o0000ooooooooool0
b?ooool007oooooo00?o0000ooooool000006oooool00ol0003oooooooooo`38ooooo`00Ooooool0
0ol0003oooooo`00000Jooooo`03o`000?oooooooooo0<Wooooo0020ooooo`;o00006_ooool00ol0
003oooooooooo`39ooooo`00P?ooool2o`0001[ooooo00?o0000ooooooooool0bOooool0083ooooo
0_l0000Jooooo`03o`000?oooooooooo0<Wooooo0020ooooo`;o00006_ooool00ol0003ooooooooo
o`39ooooo`00P?ooool2o`0001[ooooo00?o0000ooooooooool0bOooool0083ooooo1?l0000Hoooo
o`03o`000?oooooooooo0<Wooooo0020ooooo`;o00006_ooool00ol0003oooooooooo`39ooooo`00
P?ooool2o`0001Wooooo00?o0000ooooooooool0b_ooool0083ooooo0_l0000Iooooo`03o`000?oo
oooooooo0<[ooooo0020ooooo`;o00006Oooool00ol0003oooooooooo`3:ooooo`00P?ooool2o`00
01Wooooo00?o0000ooooooooool0b_ooool0083ooooo0_l0000Iooooo`03o`000?oooooooooo0<[o
oooo0020ooooo`;o00006Oooool00ol0003oooooooooo`3:ooooo`00P?ooool2o`0001Wooooo00?o
0000ooooooooool0b_ooool0087ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`3:
ooooo`00POooool3o`0001Oooooo00?o0000ooooooooool0b_ooool0087ooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`3;ooooo`00POooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo0<_ooooo0021ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0booo
ool0087ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`3;ooooo`00POooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo0<_ooooo0021ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool0boooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`3;ooooo`00I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`3;ooooo`00
I_ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool0boooool006Kooooo00Go0000ooooooooooooooooo`00000;ooooo`04
odA4A?oMgMgoooooo`0000Oooooo0ol0000Fooooo`03o`000?oooooooooo0<_ooooo001Vooooo`05
o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`;o00005oooool0
0ol0003oooooooooo`3;ooooo`00I_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMg
olc<c?l000001oooool2o`0001Oooooo00?o0000ooooooooool0boooool006Kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo0_l0000Fooooo`03o`000?oooooo
oooo0<cooooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06
ooooo`;o00005_ooool00ol0003oooooooooo`3<ooooo`00POooool2o`0001Kooooo00?o0000oooo
ooooool0c?ooool0087ooooo0_l0000Fooooo`03o`000?oooooooooo0<cooooo0021ooooo`;o0000
5_ooool00ol0003oooooooooo`3<ooooo`00POooool2o`0001Kooooo00?o0000ooooooooool0c?oo
ool0087ooooo0_l0000Fooooo`03o`000?oooooooooo0<cooooo0021ooooo`?o00005Oooool00ol0
003oooooooooo`3<ooooo`00POooool2o`0001Kooooo00?o0000ooooooooool0c?ooool0087ooooo
00?o0000ooooool000005Oooool00ol0003oooooooooo`3<ooooo`00POooool00ol0003oooooo`00
000Eooooo`03o`000?oooooooooo0<cooooo0021ooooo`03o`000?oooooo000001Gooooo00?o0000
ooooooooool0c?ooool0087ooooo00?o0000ooooool000005Oooool00ol0003oooooooooo`3<oooo
o`00POooool00ol0003oooooo`00000Eooooo`03o`000?oooooooooo0<cooooo0021ooooo`03o`00
0?oooooo000001Gooooo00?o0000ooooooooool0c?ooool0087ooooo00?o0000ooooool000005?oo
ool00ol0003oooooooooo`3=ooooo`00POooool00ol0003oooooo`00000Dooooo`03o`000?oooooo
oooo0<gooooo0021ooooo`?o00005?ooool00ol0003oooooooooo`3=ooooo`00POooool00ol0003o
ooooo`00000Dooooo`03o`000?oooooooooo0<gooooo0021ooooo`03o`000?oooooo000001Cooooo
00?o0000ooooooooool0cOooool0087ooooo00Co0000oooooooooooo00004oooool00ol0003ooooo
ooooo`3=ooooo`00POooool01?l0003oooooooooool0000Cooooo`03o`000?oooooooooo0<gooooo
0021ooooo`04o`000?ooooooooooo`0001?ooooo00?o0000ooooooooool0cOooool0087ooooo00Co
0000oooooooooooo00004oooool00ol0003oooooooooo`3=ooooo`00POooool01?l0003ooooooooo
ool0000Cooooo`03o`000?oooooooooo0<gooooo0021ooooo`04o`000?ooooooooooo`0001?ooooo
00?o0000ooooooooool0cOooool0087ooooo00Co0000oooooooooooo00004oooool00ol0003ooooo
ooooo`3=ooooo`00POooool4o`0001?ooooo00?o0000ooooooooool0cOooool0087ooooo00Co0000
oooooooooooo00004oooool00ol0003oooooooooo`3=ooooo`00POooool01?l0003oooooooooool0
000Cooooo`03o`000?oooooooooo0<gooooo0021ooooo`04o`000?ooooooooooo`0001;ooooo00?o
0000ooooooooool0c_ooool0087ooooo00Co0000oooooooooooo00004_ooool00ol0003ooooooooo
o`3>ooooo`00POooool01Ol0003ooooooooooooooooo0000017ooooo00?o0000ooooooooool0c_oo
ool0087ooooo00Go0000ooooooooooooooooo`00000Aooooo`03o`000?oooooooooo0<kooooo001V
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@
olc<c006ooooo`05o`000?ooooooooooooooool000004Oooool00ol0003oooooooooo`3>ooooo`00
I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRH
V?lQ8B401_ooool01Ol0003ooooooooooooooooo0000017ooooo00?o0000ooooooooool0c_ooool0
06Kooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_oo
ool01Ol0003ooooooooooooooooo0000017ooooo00?o0000ooooooooool0c_ooool006Kooooo00Go
0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`000003
ooooool0003ooooo013ooooo00?o0000ooooooooool0c_ooool006Kooooo00Go0000oooooooooooo
ooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool01Ol0003ooooooooooooooooo
0000017ooooo00?o0000ooooooooool0c_ooool006Kooooo00Go410@oooooooooooooooooa0@400;
ooooo`03oeEEEOn7QhOooooo00Sooooo00Go0000ooooooooooooooooo`00000Aooooo`03o`000?oo
oooooooo0<kooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRH
V008ooooo`05o`000?ooooooooooooooool000004Oooool00ol0003oooooooooo`3>ooooo`00I_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_ooool01Ol0003o
oooooooooooooooo0000017ooooo00?o0000ooooooooool0c_ooool0087ooooo00Go0000oooooooo
ooooooooo`00000Aooooo`03o`000?oooooooooo0<kooooo0021ooooo`05o`000?oooooooooooooo
ool000004Oooool00ol0003oooooooooo`3>ooooo`00POooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool0c_ooool0087ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0<oooooo0021ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`3?ooooo`00POooool3
o`0000;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`3?ooooo`00POooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0coooool0087o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0<oo
oooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`3?ooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool0coooool0087ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo0<oooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`3?ooooo`00POooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0coooool0087ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0<oooooo0021ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`3?ooooo`00POooool3
o`0000?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`3?ooooo`00POooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0d?ooool0087o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0=3o
oooo0021ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`3@ooooo`00POooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0d?ooool0087ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo0=3ooooo0021ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`3@ooooo`00POooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0d?ooool0087ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0=3ooooo0021ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`3@ooooo`00POooool3
o`0000?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`3@ooooo`00POooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0d?ooool0087o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0=3o
oooo0021ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`3@ooooo`00POooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0d?ooool0087ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo0=7ooooo0021ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`3Aooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0dOooool006Kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0=7ooooo001V
ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0=7ooooo
001Vooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Ko
oooo0ol00004ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0dOooool006Kooooo
00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0dOooool006Ko
oooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0dOooool0
06Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0dOoo
ool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0
1_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
dOooool0087ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo0=7ooooo0021ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`3Booooo`00POooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0d_ooool0087ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo0=;ooooo0021ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`3Booooo`00POooool3o`0000Cooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`3Booooo`00POooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0d_ooool0087ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0=;ooooo0021ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3Booooo`00
POooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
d_ooool0087ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0=?ooooo0021ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`3Cooooo`00POooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0doooool0087ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo0=?ooooo0021ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`3Cooooo`00POooool3o`0000Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`3Cooooo`00POooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0doooool0087ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0=?ooooo0021ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3Cooooo`00
POooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
e?ooool0087ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0=Cooooo0021ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3Dooooo`00POooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0e?ooool0087ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo0=Cooooo0021ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3Dooooo`00POooool3o`0000Oooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`3Dooooo`00POooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0e?ooool0087ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0=Gooooo0021ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3Eooooo`00
POooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
eOooool0087ooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo00000=Oooooo
0021ooooo`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`00003Gooooo`00Mooo
ool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooo
oooooooo00000=Oooooo001iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooo`00003Hooooo`00NOooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooool00000f?ooool007Wooooo00?o0000ooooooooool01Oooool3o`00
00[ooooo00?o0000ooooooooool0eoooool007Wooooo00?o0000ooooooooool0k?ooool007Wooooo
00?o0000ooooooooool0k?ooool007Wooooo00?o0000ooooooooool0k?ooool007Oooooo00?oEEEE
ofIVI_l00000k_ooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-12, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.32877 .12361 -18 -4.5 ]
[.32877 .12361 0 4.5 ]
[.32877 .24721 -18 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -18 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -18 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-5)] .18254 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(10)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(15)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.34127 .12361 m
.34752 .12361 L
s
[(0.2)] .32877 .12361 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(0.4)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(0.6)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(0.8)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(1)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0309 m
.34502 .0309 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .09271 m
.34502 .09271 L
s
.34127 .15451 m
.34502 .15451 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .21631 m
.34502 .21631 L
s
.34127 .27812 m
.34502 .27812 L
s
.34127 .30902 m
.34502 .30902 L
s
.34127 .33992 m
.34502 .33992 L
s
.34127 .40172 m
.34502 .40172 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .46353 m
.34502 .46353 L
s
.34127 .52533 m
.34502 .52533 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .58713 m
.34502 .58713 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02499 0 L
.02605 0 L
.02729 0 L
.02846 0 L
.02954 0 L
.03053 0 L
.03163 0 L
.03279 0 L
.03395 0 L
.0352 0 L
.03638 0 L
.03746 0 L
.03873 0 L
.03944 0 L
.04011 0 L
.04132 0 L
.04262 0 L
.04327 0 L
.04396 0 L
.04519 0 L
.04588 0 L
.04652 0 L
.04726 0 L
.04797 0 L
.04925 0 L
.05041 0 L
.05166 0 L
.05236 0 L
.05302 0 L
.05414 0 L
.05519 0 L
.05634 0 L
.05759 0 L
.05882 0 L
.06012 0 L
.06123 0 L
.06244 0 L
.06315 0 L
.06381 0 L
.06451 0 L
.06529 0 L
.06659 0 L
.06731 0 L
.06797 0 L
.06924 0 L
.0704 0 L
.07103 0 L
.07173 0 L
.073 0 L
Mistroke
.07376 0 L
.07448 0 L
.07583 0 L
.07659 0 L
.07728 0 L
.07809 0 L
.07885 0 L
.08011 0 L
.08077 0 L
.08149 0 L
.08224 0 L
.08294 0 L
.08427 0 L
.08544 0 L
.08673 0 L
.08807 0 L
.08933 0 L
.09051 0 L
.09158 0 L
.09276 0 L
.09401 0 L
.09527 0 L
.09663 0 L
.0979 0 L
.09906 0 L
.10042 0 L
.10119 0 L
.1019 0 L
.1032 0 L
.10458 0 L
.1058 0 L
.10712 0 L
.10837 0 L
.10953 0 L
.11057 0 L
.11172 0 L
.11291 0 L
.11404 0 L
.11528 0 L
.11659 0 L
.1177 0 L
.11892 0 L
.12024 0 L
.12165 0 L
.12298 0 L
.12419 0 L
.12533 0 L
.12654 0 L
.12758 0 L
.12871 0 L
Mistroke
.12993 0 L
.13125 0 L
.13248 0 L
.13362 0 L
.13475 0 L
.1358 0 L
.13695 0 L
.13818 0 L
.13935 0 L
.14046 0 L
.14252 0 L
.14368 0 L
.14493 0 L
.14611 0 L
.14718 0 L
.14844 0 L
.14981 0 L
.1511 0 L
.15229 0 L
.15352 0 L
.15467 0 L
.15594 0 L
.1573 0 L
.15865 0 L
.16007 0 L
.16129 0 L
.16261 0 L
.16386 0 L
.16504 0 L
.16724 0 L
.16848 0 L
.16962 0 L
.17086 0 L
.17219 0 L
.17324 0 L
.17438 0 L
.17643 0 L
.17768 0 L
.17886 0 L
.18109 0 L
.18234 0 L
.18369 0 L
.18488 0 L
.18614 0 L
.18728 0 L
.18852 0 L
.19071 0 L
.19205 0 L
.19327 0 L
.19459 0 L
Mistroke
.19601 0 L
.19733 0 L
.19855 0 L
.19971 0 L
.20095 0 L
.20314 0 L
.2052 0 L
.20645 0 L
.20765 0 L
.20988 0 L
.21102 0 L
.21223 0 L
.21441 0 L
.21575 0 L
.217 0 L
.21935 0 L
.22176 0 L
.22401 0 L
.22647 1e-05 L
.22785 1e-05 L
.22911 1e-05 L
.23165 1e-05 L
.23308 1e-05 L
.23441 2e-05 L
.23684 2e-05 L
.23942 3e-05 L
.2416 4e-05 L
.24395 5e-05 L
.24617 7e-05 L
.2482 9e-05 L
.25046 .00012 L
.25292 .00017 L
.2555 .00023 L
.25789 .0003 L
.26052 .00041 L
.26294 .00054 L
.2656 .00072 L
.26841 .00098 L
.27085 .00127 L
.27314 .00162 L
.27565 .00209 L
.27834 .00273 L
.28072 .00344 L
.28332 .0044 L
.28561 .00545 L
.28805 .0068 L
.29266 .01017 L
.29693 .01454 L
.3023 .02228 L
.30723 .03222 L
Mistroke
.31265 .04712 L
.31837 .06842 L
.32335 .09244 L
.32799 .11998 L
.33855 .20201 L
.35721 .39802 L
.36705 .5022 L
.37244 .54989 L
.3775 .58481 L
.38003 .59798 L
.38275 .60859 L
.38423 .61272 L
.38503 .61448 L
.38578 .6158 L
.38642 .61669 L
.3871 .61739 L
.38786 .61787 L
.38855 .61803 L
.38986 .61761 L
.39108 .61639 L
.39171 .61543 L
.3924 .61412 L
.39381 .61069 L
.39505 .6068 L
.39637 .60173 L
.39877 .59035 L
.40417 .55495 L
.40929 .51091 L
.4189 .41078 L
.43708 .21696 L
.44745 .13219 L
.45252 .10013 L
.45718 .07604 L
.46171 .05712 L
.46668 .04088 L
.47167 .02857 L
.47442 .02322 L
.47692 .01912 L
.48218 .01249 L
.48507 .00978 L
.48779 .00771 L
.49265 .00496 L
.49539 .00384 L
.49792 .00301 L
.50258 .00189 L
.5052 .00145 L
.50759 .00112 L
.50981 .00089 L
.51224 .00068 L
.51451 .00053 L
Mistroke
.51665 .00041 L
.51937 .0003 L
.52183 .00023 L
.52448 .00016 L
.52735 .00012 L
.52986 8e-05 L
.53252 6e-05 L
.53479 5e-05 L
.53728 3e-05 L
.53979 2e-05 L
.54252 2e-05 L
.5451 1e-05 L
.54749 1e-05 L
.54963 1e-05 L
.552 0 L
.55447 0 L
.55679 0 L
.55935 0 L
.56064 0 L
.56205 0 L
.56325 0 L
.56454 0 L
.56686 0 L
.56826 0 L
.56979 0 L
.57113 0 L
.57255 0 L
.57383 0 L
.57523 0 L
.57771 0 L
.57901 0 L
.58021 0 L
.58163 0 L
.58293 0 L
.58532 0 L
.58664 0 L
.58788 0 L
.58901 0 L
.5902 0 L
.59234 0 L
.59353 0 L
.59464 0 L
.59595 0 L
.59716 0 L
.59846 0 L
.59988 0 L
.60112 0 L
.60245 0 L
.60473 0 L
.60604 0 L
Mistroke
.60726 0 L
.60865 0 L
.60997 0 L
.61116 0 L
.61246 0 L
.61386 0 L
.61536 0 L
.61678 0 L
.61806 0 L
.61926 0 L
.62038 0 L
.62161 0 L
.62292 0 L
.62431 0 L
.62562 0 L
.62679 0 L
.62807 0 L
.62917 0 L
.63039 0 L
.63166 0 L
.63286 0 L
.63389 0 L
.63499 0 L
.63619 0 L
.63729 0 L
.63859 0 L
.63977 0 L
.64114 0 L
.64243 0 L
.64363 0 L
.64473 0 L
.64594 0 L
.64722 0 L
.64851 0 L
.6499 0 L
.65121 0 L
.6524 0 L
.6538 0 L
.65532 0 L
.65676 0 L
.6581 0 L
.65939 0 L
.66075 0 L
.66191 0 L
.66318 0 L
.66456 0 L
.66603 0 L
.66742 0 L
.66868 0 L
.66996 0 L
Mistroke
.67113 0 L
.67243 0 L
.6738 0 L
.67499 0 L
.6761 0 L
.67733 0 L
.67864 0 L
.67982 0 L
.6809 0 L
.6821 0 L
.68338 0 L
.68472 0 L
.68599 0 L
.68712 0 L
.68836 0 L
.68943 0 L
.69061 0 L
.69184 0 L
.69299 0 L
.69407 0 L
.69505 0 L
.69618 0 L
.69726 0 L
.69851 0 L
.69921 0 L
.69986 0 L
.70105 0 L
.70231 0 L
.70344 0 L
.70449 0 L
.70565 0 L
.70688 0 L
.7082 0 L
.70895 0 L
.70964 0 L
.7109 0 L
.71154 0 L
.71224 0 L
.71346 0 L
.71476 0 L
.716 0 L
.71712 0 L
.71826 0 L
.71946 0 L
.7206 0 L
.72163 0 L
.72285 0 L
.72417 0 L
.72541 0 L
.72656 0 L
Mistroke
.72763 0 L
.72864 0 L
.72974 0 L
.73092 0 L
.73216 0 L
.73333 0 L
.73438 0 L
.73553 0 L
.73675 0 L
.73786 0 L
.73909 0 L
.74038 0 L
.7415 0 L
.74255 0 L
.7437 0 L
.74493 0 L
.74562 0 L
.74627 0 L
.74696 0 L
.74772 0 L
.749 0 L
.74971 0 L
.75036 0 L
.75161 0 L
.75274 0 L
.75405 0 L
.7553 0 L
.75598 0 L
.75663 0 L
.75783 0 L
.75912 0 L
.75985 0 L
.76052 0 L
.76164 0 L
.76287 0 L
.76415 0 L
.76535 0 L
.76603 0 L
.76677 0 L
.76743 0 L
.76812 0 L
.76943 0 L
.77064 0 L
.77131 0 L
.77203 0 L
.77334 0 L
.77409 0 L
.77489 0 L
.77557 0 L
.77631 0 L
Mistroke
.77695 0 L
.77763 0 L
.77885 0 L
.78017 0 L
.78091 0 L
.78161 0 L
.78287 0 L
.78402 0 L
.78465 0 L
.78535 0 L
.78661 0 L
.78772 0 L
.78896 0 L
.79025 0 L
.79146 0 L
.79259 0 L
.79362 0 L
.79476 0 L
.79595 0 L
.79726 0 L
.79846 0 L
.79912 0 L
.79983 0 L
.80113 0 L
.80235 0 L
.80364 0 L
.80475 0 L
.80596 0 L
.80669 0 L
.80738 0 L
.80869 0 L
.80941 0 L
.81009 0 L
.81083 0 L
.81162 0 L
.8123 0 L
.81305 0 L
.81375 0 L
.8144 0 L
.81562 0 L
.81692 0 L
.81814 0 L
.81883 0 L
.81946 0 L
.82063 0 L
.82188 0 L
.82299 0 L
.82403 0 L
.82517 0 L
.8264 0 L
Mistroke
.82764 0 L
.82833 0 L
.82898 0 L
.8303 0 L
.83104 0 L
.8317 0 L
.8329 0 L
.83421 0 L
.83543 0 L
.83657 0 L
.83762 0 L
.83876 0 L
.83983 0 L
.84081 0 L
.84195 0 L
.8432 0 L
.84438 0 L
.84547 0 L
.84671 0 L
.84787 0 L
.84891 0 L
.85004 0 L
.85127 0 L
.85258 0 L
.85369 0 L
.8549 0 L
.85621 0 L
.85743 0 L
.85806 0 L
.85875 0 L
.85948 0 L
.86017 0 L
.86142 0 L
.86256 0 L
.86388 0 L
.86514 0 L
.86626 0 L
.86745 0 L
.86858 0 L
.8696 0 L
.8708 0 L
.8721 0 L
.87333 0 L
.87446 0 L
.87567 0 L
.87697 0 L
.87819 0 L
.87931 0 L
.88062 0 L
.88136 0 L
Mistroke
.88205 0 L
.8833 0 L
.88394 0 L
.88464 0 L
.88532 0 L
.88603 0 L
.88731 0 L
.88802 0 L
.88868 0 L
.88941 0 L
.89018 0 L
.89086 0 L
.89159 0 L
.89228 0 L
.89291 0 L
.89412 0 L
.89539 0 L
.8966 0 L
.89792 0 L
.89917 0 L
.90032 0 L
.90146 0 L
.9025 0 L
.9037 0 L
.90482 0 L
.90606 0 L
.90736 0 L
.90847 0 L
.90969 0 L
.91101 0 L
.91174 0 L
.91242 0 L
.91372 0 L
.91496 0 L
.91601 0 L
.91717 0 L
.91838 0 L
.91951 0 L
.92057 0 L
.92154 0 L
.92261 0 L
.92373 0 L
.92487 0 L
.92609 0 L
.92724 0 L
.92829 0 L
.92952 0 L
.93021 0 L
.93085 0 L
.93202 0 L
Mistroke
.93326 0 L
.93448 0 L
.9358 0 L
.93705 0 L
.93821 0 L
.93925 0 L
.94039 0 L
.94159 0 L
.94272 0 L
.94396 0 L
.94526 0 L
.94638 0 L
.9476 0 L
.94892 0 L
.94965 0 L
.95033 0 L
.95163 0 L
.95287 0 L
.95392 0 L
.95508 0 L
.9563 0 L
.95743 0 L
.95849 0 L
.95947 0 L
.96059 0 L
.96165 0 L
.9628 0 L
.96402 0 L
.96517 0 L
.96621 0 L
.96744 0 L
.96814 0 L
.96877 0 L
.96995 0 L
.97119 0 L
.97244 0 L
.97314 0 L
.97377 0 L
.97502 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h/ooooo`05odA4A?l0003o0000oc8b<_oMgMd0G_ooool01Om4A4Co0000o`000?lb<S;ogMgM02[o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^:?ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0Tooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01?ooooo000Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0_ooooo`03ogMgMolb<S;ooooo063ooooo00?oMgMgoc8b<_ooool0:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo02Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL04oooool000oooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Sooooo`Ko00001oooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000;oooool00omgMgOo<S8booooo`1Pooooo`03ogMgMolb<S;ooooo02_o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002[ooooo00?o0000oooo
ooooool01_ooool00omgMgOo<S8booooo`0Vooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000;?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<05kooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00/ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Zooooo`03
o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Xooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@4100;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Aooooo`006_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Wooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01?ooooo000Hooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0/ooooo`Co0000Goooool4o`0002_ooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo00?oEEEEofIVI_l000001Oooool4o`0002Kooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001?ooooo
ool00016o`00013ooooo000Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Ol0
0009ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`Wo00000_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool05_ooool001[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08
ooooo`?o00001oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01Oooool2o`000003ooooool0003ooooo00Sooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo001`ooooo`;o00003oooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo0;Cooooo001booooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0:oooool2o`000;Oooooo001cooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0:oooool00ol0003oooooooooo`2fooooo`00Loooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0]oooool007Cooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0;Sooooo001eoooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`2ioooo
o`00MOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool0^Oooool007Kooooo00?o0000ooooooooool02?ooool3o`0002Sooooo00?o0000ooooooooool0
^Oooool007Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo0;Wooooo001fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`2jooooo`00Moooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool0^_ooool007Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo0;_ooooo001gooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`2kooooo`00N?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0_?ooool007Sooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo0;cooooo001hoooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`2loooo
o`00NOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool0_Oooool007Wooooo00?o0000ooooooooool01Oooool3o`0002Cooooo00?o0000ooooooooool0
_Oooool007Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo0;gooooo001jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`2mooooo`00N_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool0__ooool007[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo0;kooooo001jooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`2nooooo`00N_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0__ooool007_ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo0;kooooo001koooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`2ooooo
o`00Noooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool0_oooool007_ooooo00?o0000ooooooooool00oooool3o`0002;ooooo00?o0000ooooooooool0
_oooool007_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo0;oooooo001kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`30ooooo`00O?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool0`?ooool007cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo0<3ooooo001looooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`30ooooo`00O?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0`?ooool007cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo0<3ooooo001Voooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00002ooooo`05o`000?oooooo
ooooooooool000008oooool00ol0003oooooooooo`30ooooo`00I_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00_ooool01Ol0003ooooo
oooooooooooo000002;ooooo00?o0000ooooooooool0`Oooool006Kooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Roooo
o`03o`000?oooooooooo0<7ooooo001Vooooo`05o`000?ooooooooooooooool000003Oooool00onH
V9So8B4Qonk^kP02ooooo`04o`000?ooooooooooooooo`?o00008?ooool00ol0003oooooooooo`31
ooooo`00I_ooool01Ol0003ooooooooooooooooo000000kooooo00GoMgMgofIVI_ooooooooooo`00
0003ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0`Oooool006Kooooo00Go410@
oooooooooooooooooa0@400?ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`31ooooo`00I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go0000okZj^_ooooooV9RHoa0@4003ooooo`04o`000?ooooooooooo`0002;ooooo00?o0000oooo
ooooool0`Oooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`00oooool01?l0003oooooooooool0000Rooooo`03o`000?oooooooooo0<7ooooo001n
ooooo`04o`000?ooooooooooo`0002;ooooo00?o0000ooooooooool0`Oooool007kooooo00Co0000
oooooooooooo00008Oooool00ol0003oooooooooo`32ooooo`00O_ooool01?l0003oooooooooool0
000Qooooo`03o`000?oooooooooo0<;ooooo001nooooo`04o`000?ooooooooooo`00027ooooo00?o
0000ooooooooool0`_ooool007kooooo00Co0000oooooooooooo00008Oooool00ol0003ooooooooo
o`32ooooo`00O_ooool00ol0003oooooooooo`03o`0001oooooo00?o0000ooooooooool0`_ooool0
07kooooo00Co0000oooooooooooo00008Oooool00ol0003oooooooooo`32ooooo`00Ooooool00ol0
003oooooo`00000Qooooo`03o`000?oooooooooo0<;ooooo001oooooo`03o`000?oooooo0000023o
oooo00?o0000ooooooooool0`oooool007oooooo00?o0000ooooool000008?ooool00ol0003ooooo
ooooo`33ooooo`00Ooooool00ol0003oooooo`00000Pooooo`03o`000?oooooooooo0<?ooooo001o
ooooo`03o`000?oooooo0000023ooooo00?o0000ooooooooool0`oooool007oooooo00?o0000oooo
ool000008?ooool00ol0003oooooooooo`33ooooo`00Ooooool00ol0003oooooo`00000Pooooo`03
o`000?oooooooooo0<?ooooo001oooooo`03o`000?oooooo0000023ooooo00?o0000ooooooooool0
`oooool007oooooo00?o0000ooooool000000_l0000Mooooo`03o`000?oooooooooo0<Cooooo0020
ooooo`;o00007oooool00ol0003oooooooooo`34ooooo`00P?ooool2o`0001oooooo00?o0000oooo
ooooool0a?ooool0083ooooo0_l0000Oooooo`03o`000?oooooooooo0<Cooooo0020ooooo`;o0000
7oooool00ol0003oooooooooo`34ooooo`00P?ooool2o`0001oooooo00?o0000ooooooooool0a?oo
ool0083ooooo0_l0000Oooooo`03o`000?oooooooooo0<Cooooo0020ooooo`;o00007_ooool00ol0
003oooooooooo`35ooooo`00P?ooool2o`0001kooooo00?o0000ooooooooool0aOooool0083ooooo
0_l0000Nooooo`03o`000?oooooooooo0<Gooooo0020ooooo`Co00007?ooool00ol0003ooooooooo
o`35ooooo`00POooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo0<Gooooo0021oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool0aOooool0087ooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`35ooooo`00POooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo0<Gooooo0021ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0aOoo
ool0087ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`36ooooo`00I_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo0<Kooooo001Vooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo0<Kooooo001Vooooo`05oa0@4?ooooooooooooooool@41002oooool5
o`0000Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`36ooooo`00I_ooool01Ol0
003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool3o`0001_ooooo00?o
0000ooooooooool0a_ooool006Kooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0000Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`36ooooo`00I_oo
ool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool2o`0001cooooo
00?o0000ooooooooool0a_ooool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^
k_m4A4Co000000Oooooo0_l0000Looooo`03o`000?oooooooooo0<Kooooo001Vooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`;o00007?ooool00ol0003ooooo
ooooo`36ooooo`00POooool2o`0001cooooo00?o0000ooooooooool0a_ooool0087ooooo0_l0000L
ooooo`03o`000?oooooooooo0<Kooooo0021ooooo`;o00006oooool00ol0003oooooooooo`37oooo
o`00POooool2o`0001_ooooo00?o0000ooooooooool0aoooool0087ooooo0_l0000Kooooo`03o`00
0?oooooooooo0<Oooooo0021ooooo`?o00006_ooool00ol0003oooooooooo`37ooooo`00POooool2
o`0001_ooooo00?o0000ooooooooool0aoooool0087ooooo0_l0000Kooooo`03o`000?oooooooooo
0<Oooooo0021ooooo`03o`000?oooooo000001[ooooo00?o0000ooooooooool0aoooool0087ooooo
00?o0000ooooool000006_ooool00ol0003oooooooooo`37ooooo`00POooool00ol0003oooooo`00
000Jooooo`03o`000?oooooooooo0<Oooooo0021ooooo`03o`000?oooooo000001[ooooo00?o0000
ooooooooool0aoooool0087ooooo00?o0000ooooool000006Oooool00ol0003oooooooooo`38oooo
o`00POooool00ol0003oooooo`00000Iooooo`03o`000?oooooooooo0<Sooooo0021ooooo`03o`00
0?oooooo000001Wooooo00?o0000ooooooooool0b?ooool0087ooooo0ol0000Iooooo`03o`000?oo
oooooooo0<Sooooo0021ooooo`03o`000?oooooo000001Wooooo00?o0000ooooooooool0b?ooool0
087ooooo00?o0000ooooool000006Oooool00ol0003oooooooooo`38ooooo`00POooool01?l0003o
ooooooooool0000Hooooo`03o`000?oooooooooo0<Sooooo0021ooooo`04o`000?ooooooooooo`00
01Sooooo00?o0000ooooooooool0b?ooool0087ooooo00Co0000oooooooooooo00006?ooool00ol0
003oooooooooo`38ooooo`00POooool01?l0003oooooooooool0000Hooooo`03o`000?oooooooooo
0<Sooooo0021ooooo`04o`000?ooooooooooo`0001Sooooo00?o0000ooooooooool0b?ooool0087o
oooo00Co0000oooooooooooo00005oooool00ol0003oooooooooo`39ooooo`00POooool01?l0003o
ooooooooool0000Gooooo`03o`000?oooooooooo0<Wooooo0021ooooo`Co00005oooool00ol0003o
ooooooooo`39ooooo`00POooool01?l0003oooooooooool0000Gooooo`03o`000?oooooooooo0<Wo
oooo0021ooooo`04o`000?ooooooooooo`0001Oooooo00?o0000ooooooooool0bOooool0087ooooo
00Co0000oooooooooooo00005oooool00ol0003oooooooooo`39ooooo`00POooool01Ol0003ooooo
oooooooooooo000001Kooooo00?o0000ooooooooool0bOooool0087ooooo00Go0000oooooooooooo
ooooo`00000Fooooo`03o`000?oooooooooo0<Wooooo0021ooooo`05o`000?ooooooooooooooool0
00005_ooool00ol0003oooooooooo`39ooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool01Ol0003ooooooooooooooooo
000001Kooooo00?o0000ooooooooool0bOooool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00Go0000oooooooooooooooo
o`00000Eooooo`03o`000?oooooooooo0<[ooooo001Vooooo`05oa0@4?ooooooooooooooool@4100
2oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`00000Eoooo
o`03o`000?oooooooooo0<[ooooo001Vooooo`05o`000?ooooooooooooooool000002oooool01Ol0
003oV9RHoooooonHV9So8B4Q00Kooooo0ol000000ooooooo0000ooooo`0Dooooo`03o`000?oooooo
oooo0<[ooooo001Vooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@
413oc<c<00Kooooo00Go0000ooooooooooooooooo`00000Eooooo`03o`000?oooooooooo0<[ooooo
001Vooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`05o`00
0?ooooooooooooooool000005Oooool00ol0003oooooooooo`3:ooooo`00I_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool01Ol0003ooooooooooooooooo0000
01Gooooo00?o0000ooooooooool0b_ooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`04olc<c?m4A4Co0000oa0@40Kooooo00Go0000ooooooooooooooooo`00000Eooooo`03o`000?oo
oooooooo0<[ooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`3:ooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool0b_ooool0087ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo0<[ooooo0021ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`3:ooooo`00POooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0boooool0087ooooo0ol00002
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0boooool0087ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo0<_ooooo0021ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`3;ooooo`00
POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
boooool0087ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo0<_ooooo0021ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`3;ooooo`00POooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0boooool0087ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo0<_ooooo0021ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`3;ooooo`00POooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0c?ooool0087ooooo0ol00003
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0c?ooool0087ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0<cooooo0021ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`3<ooooo`00
POooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
c?ooool0087ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo0<cooooo0021ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`3<ooooo`00POooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0c?ooool0087ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo0<cooooo0021ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`3<ooooo`00POooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0c?ooool0087ooooo0ol00004
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0cOooool0087ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0<gooooo0021ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`3=ooooo`00
POooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
cOooool0087ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo0<gooooo0021ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`3=ooooo`00POooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0cOooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0<gooooo001Vooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`3=ooooo`00I_ooool0
1Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`3=ooooo`00I_oo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o
00001_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0<gooooo001Vooooo`05o`00
0?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0<kooooo001Vooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0<kooooo001Voooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0<kooooo001V
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0<kooooo
0021ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`3>ooooo`00POooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0c_ooool0087ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo0<kooooo0021ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`3>ooooo`00POooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0c_ooool0087ooooo0ol00006ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0c_ooool0087ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo0<kooooo0021ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`3>ooooo`00POooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0coooool0087ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0<oooooo
0021ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`3?ooooo`00POooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0coooool0087ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo0<oooooo0021ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`3?ooooo`00POooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0coooool0087ooooo0ol00007ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0coooool0087ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo0<oooooo0021ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3?ooooo`00POooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0d?ooool0087ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0=3ooooo
0021ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`3@ooooo`00POooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0d?ooool0087ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0=3ooooo0021ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3@ooooo`00POooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0dOooool0087ooooo0ol00009ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0dOooool0087ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0=7ooooo0021ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3Aooooo`00POooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0dOooool0087ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0=;ooooo
0021ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`3Booooo`00POooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool00000e?oo
ool007Oooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00Co0000
oooooooooooo0000eOooool007Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;
ooooo`04o`000?ooooooooooo`000=Gooooo001iooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02oooool4o`000=Gooooo001iooooo`03o`000?oooooooooo00Gooooo0ol0000<oooo
o`;o0000e_ooool007Wooooo00?o0000ooooooooool0k?ooool007Wooooo00?o0000ooooooooool0
k?ooool007Wooooo00?o0000ooooooooool0k?ooool007Oooooo00?oEEEEofIVI_l00000k_ooool0
0?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-12, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.32877 .12361 -18 -4.5 ]
[.32877 .12361 0 4.5 ]
[.32877 .24721 -18 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -18 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -18 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-5)] .18254 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(10)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(15)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.34127 .12361 m
.34752 .12361 L
s
[(0.2)] .32877 .12361 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(0.4)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(0.6)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(0.8)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(1)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0309 m
.34502 .0309 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .09271 m
.34502 .09271 L
s
.34127 .15451 m
.34502 .15451 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .21631 m
.34502 .21631 L
s
.34127 .27812 m
.34502 .27812 L
s
.34127 .30902 m
.34502 .30902 L
s
.34127 .33992 m
.34502 .33992 L
s
.34127 .40172 m
.34502 .40172 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .46353 m
.34502 .46353 L
s
.34127 .52533 m
.34502 .52533 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .58713 m
.34502 .58713 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02499 0 L
.02605 0 L
.02729 0 L
.02846 0 L
.02954 0 L
.03053 0 L
.03163 0 L
.03279 0 L
.03395 0 L
.0352 0 L
.03638 0 L
.03746 0 L
.03873 0 L
.04011 0 L
.04141 0 L
.04262 0 L
.04386 0 L
.04521 0 L
.04648 0 L
.04765 0 L
.04871 0 L
.04987 0 L
.05108 0 L
.05221 0 L
.05354 0 L
.0548 0 L
.05592 0 L
.05715 0 L
.05848 0 L
.0599 0 L
.06111 0 L
.06244 0 L
.06371 0 L
.0651 0 L
.06655 0 L
.0679 0 L
.06917 0 L
.07032 0 L
.07165 0 L
.0729 0 L
.07427 0 L
.07572 0 L
.07695 0 L
.07831 0 L
.07977 0 L
.08134 0 L
.08282 0 L
.08418 0 L
.08544 0 L
Mistroke
.08678 0 L
.08918 0 L
.09066 0 L
.09205 0 L
.0933 0 L
.09464 0 L
.09716 0 L
.09843 0 L
.09982 0 L
.10101 0 L
.10228 0 L
.10458 0 L
.1058 0 L
.10715 0 L
.10856 0 L
.10988 0 L
.11224 0 L
.11357 0 L
.11478 0 L
.11736 0 L
.11882 0 L
.12018 0 L
.12293 0 L
.12447 0 L
.12586 0 L
.12712 0 L
.12845 0 L
.13084 0 L
.13216 0 L
.1334 0 L
.13485 0 L
.13622 0 L
.1374 0 L
.13869 0 L
.14094 0 L
.14221 0 L
.14356 0 L
.14472 0 L
.14599 0 L
.14837 0 L
.14966 0 L
.15087 0 L
.15303 0 L
.15535 0 L
.15665 0 L
.15807 0 L
.16063 0 L
.16313 0 L
.16544 0 L
.16762 0 L
Mistroke
.16966 0 L
.1719 0 L
.17431 0 L
.17683 0 L
.17922 0 L
.18137 0 L
.18371 0 L
.18627 0 L
.18903 0 L
.19164 0 L
.19404 0 L
.19621 0 L
.19859 0 L
.20108 1e-05 L
.2034 1e-05 L
.20612 1e-05 L
.2087 1e-05 L
.21101 2e-05 L
.21353 2e-05 L
.21626 3e-05 L
.21916 4e-05 L
.22164 5e-05 L
.22438 7e-05 L
.22673 9e-05 L
.2293 .00011 L
.23198 .00015 L
.23448 .00019 L
.23896 .00029 L
.24146 .00037 L
.24374 .00045 L
.24889 .00073 L
.25179 .00094 L
.25447 .00119 L
.25939 .00181 L
.26187 .00222 L
.2646 .00277 L
.2671 .00338 L
.26982 .00418 L
.27477 .00609 L
.27959 .00865 L
.28406 .01183 L
.28938 .0169 L
.29419 .02301 L
.29974 .0323 L
.30496 .04369 L
.31476 .07369 L
.31969 .09381 L
.32509 .12018 L
.34358 .24589 L
.36478 .43454 L
Mistroke
.37481 .51805 L
.37922 .5491 L
.38408 .57766 L
.38874 .59847 L
.39129 .60684 L
.39368 .61261 L
.39503 .61496 L
.39631 .61658 L
.39746 .61753 L
.39871 .618 L
.39942 .61802 L
.40006 .61787 L
.40081 .6175 L
.40151 .61697 L
.40276 .61558 L
.40347 .61455 L
.40411 .61343 L
.40638 .60835 L
.4085 .60196 L
.41333 .58184 L
.41802 .55541 L
.42306 .52071 L
.44286 .34883 L
.45331 .25694 L
.46441 .17285 L
.47424 .11442 L
.47946 .08976 L
.4851 .06784 L
.49025 .05165 L
.49497 .03967 L
.49983 .02982 L
.50424 .02273 L
.50898 .01677 L
.51404 .01193 L
.51873 .00859 L
.52316 .00622 L
.52832 .00421 L
.53309 .00289 L
.53558 .00237 L
.53832 .00189 L
.54096 .00151 L
.54385 .00118 L
.54656 .00093 L
.54906 .00075 L
.55166 .00059 L
.55401 .00048 L
.5585 .00031 L
.56097 .00025 L
.56329 .0002 L
.56584 .00015 L
Mistroke
.56852 .00012 L
.57082 9e-05 L
.57333 7e-05 L
.57604 5e-05 L
.57895 4e-05 L
.58168 3e-05 L
.58418 2e-05 L
.58647 2e-05 L
.589 1e-05 L
.59164 1e-05 L
.59411 1e-05 L
.59642 1e-05 L
.59853 0 L
.60085 0 L
.60329 0 L
.60578 0 L
.60844 0 L
.61094 0 L
.61322 0 L
.6159 0 L
.61731 0 L
.6188 0 L
.62154 0 L
.62407 0 L
.6266 0 L
.62901 0 L
.63117 0 L
.63352 0 L
.63607 0 L
.63736 0 L
.63879 0 L
.64131 0 L
.64367 0 L
.64591 0 L
.64826 0 L
.65028 0 L
.65248 0 L
.65486 0 L
.65619 0 L
.65741 0 L
.65976 0 L
.66199 0 L
.66314 0 L
.66438 0 L
.66661 0 L
.66797 0 L
.66926 0 L
.67169 0 L
.67293 0 L
.67424 0 L
Mistroke
.67661 0 L
.67806 0 L
.67942 0 L
.68064 0 L
.68197 0 L
.68422 0 L
.68544 0 L
.68659 0 L
.68864 0 L
.68979 0 L
.69083 0 L
.69319 0 L
.69452 0 L
.69575 0 L
.69801 0 L
.69916 0 L
.70041 0 L
.70276 0 L
.7041 0 L
.70533 0 L
.70662 0 L
.70784 0 L
.70924 0 L
.71051 0 L
.71163 0 L
.71282 0 L
.71495 0 L
.71614 0 L
.71725 0 L
.71855 0 L
.71977 0 L
.72106 0 L
.72246 0 L
.7237 0 L
.72502 0 L
.72632 0 L
.72754 0 L
.72863 0 L
.72982 0 L
.73114 0 L
.73253 0 L
.73382 0 L
.73502 0 L
.73643 0 L
.73773 0 L
.73922 0 L
.74063 0 L
.74177 0 L
.743 0 L
.74407 0 L
Mistroke
.74523 0 L
.74659 0 L
.74788 0 L
.74914 0 L
.75031 0 L
.75165 0 L
.75291 0 L
.75405 0 L
.75528 0 L
.75662 0 L
.75804 0 L
.75925 0 L
.76058 0 L
.76181 0 L
.76298 0 L
.76404 0 L
.76518 0 L
.76642 0 L
.76774 0 L
.76887 0 L
.77011 0 L
.77126 0 L
.77232 0 L
.77348 0 L
.7747 0 L
.77577 0 L
.77676 0 L
.77785 0 L
.77901 0 L
.78024 0 L
.7816 0 L
.78301 0 L
.78434 0 L
.78557 0 L
.7867 0 L
.78801 0 L
.78924 0 L
.79058 0 L
.792 0 L
.79334 0 L
.79455 0 L
.79599 0 L
.79674 0 L
.79753 0 L
.799 0 L
.80034 0 L
.8016 0 L
.80274 0 L
.80406 0 L
.80531 0 L
Mistroke
.80647 0 L
.80753 0 L
.80871 0 L
.80995 0 L
.81119 0 L
.81253 0 L
.8138 0 L
.81496 0 L
.81625 0 L
.81765 0 L
.81836 0 L
.81912 0 L
.82049 0 L
.82172 0 L
.82308 0 L
.8245 0 L
.82583 0 L
.82707 0 L
.8282 0 L
.8295 0 L
.83074 0 L
.83208 0 L
.83283 0 L
.8335 0 L
.83482 0 L
.83606 0 L
.83677 0 L
.83751 0 L
.83885 0 L
.83959 0 L
.84028 0 L
.8411 0 L
.84186 0 L
.84311 0 L
.84448 0 L
.84568 0 L
.84695 0 L
.84809 0 L
.84916 0 L
.85033 0 L
.85159 0 L
.85293 0 L
.85368 0 L
.85438 0 L
.85567 0 L
.85638 0 L
.85703 0 L
.85827 0 L
.85891 0 L
.8596 0 L
Mistroke
.86086 0 L
.86201 0 L
.86323 0 L
.86388 0 L
.86456 0 L
.86581 0 L
.86697 0 L
.86808 0 L
.86912 0 L
.87026 0 L
.87149 0 L
.87272 0 L
.87342 0 L
.87407 0 L
.87538 0 L
.87612 0 L
.87679 0 L
.87799 0 L
.87929 0 L
.88052 0 L
.88165 0 L
.8827 0 L
.88384 0 L
.88491 0 L
.88589 0 L
.88703 0 L
.88828 0 L
.88946 0 L
.89055 0 L
.89179 0 L
.89295 0 L
.89399 0 L
.89512 0 L
.89635 0 L
.89765 0 L
.89876 0 L
.89998 0 L
.90129 0 L
.9025 0 L
.90313 0 L
.90383 0 L
.90456 0 L
.90524 0 L
.90647 0 L
.90712 0 L
.9078 0 L
.90895 0 L
.91021 0 L
.91143 0 L
.91255 0 L
Mistroke
.91383 0 L
.91504 0 L
.91616 0 L
.91719 0 L
.91833 0 L
.91953 0 L
.92083 0 L
.92201 0 L
.92267 0 L
.92338 0 L
.92468 0 L
.92589 0 L
.92718 0 L
.92828 0 L
.9295 0 L
.93019 0 L
.93091 0 L
.93221 0 L
.93294 0 L
.93361 0 L
.9344 0 L
.93514 0 L
.93579 0 L
.93649 0 L
.93771 0 L
.9384 0 L
.93914 0 L
.94045 0 L
.94159 0 L
.94283 0 L
.94401 0 L
.9451 0 L
.94618 0 L
.94715 0 L
.94828 0 L
.94935 0 L
.95051 0 L
.95174 0 L
.95279 0 L
.95394 0 L
.95518 0 L
.95588 0 L
.95651 0 L
.95774 0 L
.95891 0 L
.9599 0 L
.96099 0 L
.96214 0 L
.96321 0 L
.96421 0 L
Mistroke
.96512 0 L
.96613 0 L
.96719 0 L
.96826 0 L
.96942 0 L
.9705 0 L
.97149 0 L
.97265 0 L
.97391 0 L
.9751 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h/ooooo`05odA4A?l0003o0000oc8b<_oMgMd0G_ooool01Om4A4Co0000o`000?lb<S;ogMgM02[o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^:?ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0Tooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01?ooooo000Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0_ooooo`03ogMgMolb<S;ooooo063ooooo00?oMgMgoc8b<_ooool0:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo02Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL04oooool000oooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Sooooo`Ko00001oooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000;oooool00omgMgOo<S8booooo`1Pooooo`03ogMgMolb<S;ooooo02_o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002[ooooo00?o0000oooo
ooooool01_ooool00omgMgOo<S8booooo`0Vooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000;?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<05kooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00/ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Zooooo`03
o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Xooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@4100;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Aooooo`006_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Wooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01?ooooo000Hooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0/ooooo`Co0000Goooool4o`0002_ooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo00?oEEEEofIVI_l000001Oooool4o`0002Kooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001?ooooo
ool00016o`00013ooooo000Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo2Ol00004ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01oooool;o`0000[ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05_oo
ool001[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`Go00002Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`04ooooo`Co00002Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01Kooooo001]ooooo`;o00004_ooool00ol0003oooooooooo`0fooooo`;o0000[?ooool006oo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo0:co
oooo001_ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`2/ooooo`00L?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Cooooo00?o
0000ooooooooool0[Oooool0077ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0c
ooooo`03o`000?oooooooooo0:kooooo001booooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool0<_ooool00ol0003oooooooooo`2_ooooo`00L_ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool0[oooool007?ooooo00?o0000ooooooooool0
2oooool3o`00037ooooo00?o0000ooooooooool0/?ooool007Cooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo0;3ooooo001dooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`2aooooo`00MOooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0/_ooool007Go
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo0;;o
oooo001fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`2booooo`00M_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool0/oooool007Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo0;?ooooo001gooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`2cooooo`00Moooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool0]?ooool007Sooooo00?o0000ooooooooool0
1_ooool3o`0002gooooo00?o0000ooooooooool0]?ooool007Sooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo0;Cooooo001hooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`2eooooo`00NOooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0]Oooool007Wo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo0;Go
oooo001iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`2fooooo`00NOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02_ooooo00?o
0000ooooooooool0]_ooool007Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo0;Kooooo001jooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`2fooooo`00N_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool0]oooool007[ooooo00?o0000ooooooooool0
1?ooool3o`0002[ooooo00?o0000ooooooooool0]oooool007[ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo0;Oooooo001jooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`2gooooo`00N_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0^?ooool007_o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0;So
oooo001kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`2hooooo`00Noooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool0^?ooool007_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo0;Wooooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo1Ol000000ooooooo0000ooooo`03ooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool0^Oooool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1onHV9So8B4Qonk^k_ooooooA4A4ooooool000001?ooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo0;Wooooo001Vooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Q
onk^kP02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`2iooooo`00I_ooool01Ol0003ooooooooooooooooo000000gooooo00GoV9RHob4Q8Oo^k^ko
ooooo`000004ooooo`?o0000:?ooool00ol0003oooooooooo`2iooooo`00I_ooool01Ol0003ooooo
oooooooooooo000000kooooo00CoMgMgofIVI_oooooo00001?ooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo0;[ooooo001Vooooo`05oa0@4?ooooooooooooooool@41003oooool01?l0
003oooooooooool00003ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0^_ooool0
06Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41000_oo
ool01Ol0003ooooooooooooooooo000002Wooooo00?o0000ooooooooool0^_ooool006Kooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00_ooool01Ol0003o
oooooooooooooooo000002Wooooo00?o0000ooooooooool0^_ooool007gooooo00Go0000oooooooo
ooooooooo`00000Yooooo`03o`000?oooooooooo0;[ooooo001mooooo`05o`000?oooooooooooooo
ool00000:Oooool00ol0003oooooooooo`2jooooo`00OOooool01Ol0003ooooooooooooooooo0000
02Sooooo00?o0000ooooooooool0^oooool007gooooo00Go0000ooooooooooooooooo`00000Xoooo
o`03o`000?oooooooooo0;_ooooo001nooooo`04o`000?ooooooooooo`0002Sooooo00?o0000oooo
ooooool0^oooool007kooooo00?o0000ooooooooool00ol0000Vooooo`03o`000?oooooooooo0;_o
oooo001nooooo`04o`000?ooooooooooo`0002Sooooo00?o0000ooooooooool0^oooool007kooooo
00Co0000oooooooooooo0000:?ooool00ol0003oooooooooo`2kooooo`00O_ooool01?l0003ooooo
ooooool0000Wooooo`03o`000?oooooooooo0;cooooo001nooooo`04o`000?ooooooooooo`0002Oo
oooo00?o0000ooooooooool0_?ooool007kooooo00Co0000oooooooooooo00009oooool00ol0003o
ooooooooo`2looooo`00Ooooool00ol0003oooooo`00000Wooooo`03o`000?oooooooooo0;cooooo
001oooooo`03o`000?oooooo000002Oooooo00?o0000ooooooooool0_?ooool007oooooo00?o0000
ooooool000009oooool00ol0003oooooooooo`2looooo`00Ooooool00ol0003oooooo`00000Woooo
o`03o`000?oooooooooo0;cooooo001oooooo`03o`000?oooooo000000;o00009Oooool00ol0003o
ooooooooo`2looooo`00Ooooool00ol0003oooooo`00000Vooooo`03o`000?oooooooooo0;gooooo
001oooooo`03o`000?oooooo000002Kooooo00?o0000ooooooooool0_Oooool0083ooooo0_l0000V
ooooo`03o`000?oooooooooo0;gooooo0020ooooo`;o00009_ooool00ol0003oooooooooo`2moooo
o`00P?ooool2o`0002Kooooo00?o0000ooooooooool0_Oooool0083ooooo0_l0000Vooooo`03o`00
0?oooooooooo0;gooooo0020ooooo`;o00009_ooool00ol0003oooooooooo`2mooooo`00P?ooool2
o`0002Kooooo00?o0000ooooooooool0_Oooool0083ooooo0_l0000Vooooo`03o`000?oooooooooo
0;gooooo0021ooooo`?o00008oooool00ol0003oooooooooo`2nooooo`00POooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo0;kooooo0021ooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool0__ooool0087ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`2n
ooooo`00POooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo0;kooooo0021ooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool0__ooool0087ooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`2nooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool2o`0002Cooooo00?o0000ooooooooool0
__ooool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003ooooo
ooooo`05ooooo`;o00009?ooool00ol0003oooooooooo`2nooooo`00I_ooool01Ol@413ooooooooo
oooooooo410@00_ooooo1Ol00006ooooo`;o00008oooool00ol0003oooooooooo`2oooooo`00I_oo
ool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool3o`0002;o
oooo00?o0000ooooooooool0_oooool006Kooooo00Go0000ooooooooooooooooo`00000;ooooo`04
omgMgOmEEEGoooooo`0000Oooooo0_l0000Sooooo`03o`000?oooooooooo0;oooooo001Vooooo`05
oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007ooooo`;o00008oooool00ol0
003oooooooooo`2oooooo`00I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4
A?l000001oooool2o`0002?ooooo00?o0000ooooooooool0_oooool006Kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooool000008_ooool00ol0
003oooooooooo`2oooooo`00POooool00ol0003oooooo`00000Rooooo`03o`000?oooooooooo0;oo
oooo0021ooooo`03o`000?oooooo000002;ooooo00?o0000ooooooooool0_oooool0087ooooo00?o
0000ooooool000008_ooool00ol0003oooooooooo`2oooooo`00POooool00ol0003oooooo`00000Q
ooooo`03o`000?oooooooooo0<3ooooo0021ooooo`03o`000?oooooo0000027ooooo00?o0000oooo
ooooool0`?ooool0087ooooo0ol0000Qooooo`03o`000?oooooooooo0<3ooooo0021ooooo`03o`00
0?oooooo0000027ooooo00?o0000ooooooooool0`?ooool0087ooooo00?o0000ooooool000008Ooo
ool00ol0003oooooooooo`30ooooo`00POooool01?l0003oooooooooool0000Pooooo`03o`000?oo
oooooooo0<3ooooo0021ooooo`04o`000?ooooooooooo`00023ooooo00?o0000ooooooooool0`?oo
ool0087ooooo00Co0000oooooooooooo00007oooool00ol0003oooooooooo`31ooooo`00POooool0
1?l0003oooooooooool0000Oooooo`03o`000?oooooooooo0<7ooooo0021ooooo`04o`000?oooooo
ooooo`0001oooooo00?o0000ooooooooool0`Oooool0087ooooo00Co0000oooooooooooo00007ooo
ool00ol0003oooooooooo`31ooooo`00POooool01?l0003oooooooooool0000Oooooo`03o`000?oo
oooooooo0<7ooooo0021ooooo`Co00007oooool00ol0003oooooooooo`31ooooo`00POooool01?l0
003oooooooooool0000Oooooo`03o`000?oooooooooo0<7ooooo0021ooooo`05o`000?oooooooooo
ooooool000007_ooool00ol0003oooooooooo`31ooooo`00POooool01Ol0003ooooooooooooooooo
000001gooooo00?o0000ooooooooool0`_ooool0087ooooo00Go0000ooooooooooooooooo`00000M
ooooo`03o`000?oooooooooo0<;ooooo0021ooooo`05o`000?ooooooooooooooool000007Oooool0
0ol0003oooooooooo`32ooooo`00POooool01Ol0003ooooooooooooooooo000001gooooo00?o0000
ooooooooool0`_ooool0087ooooo00Go0000ooooooooooooooooo`00000Mooooo`03o`000?oooooo
oooo0<;ooooo0021ooooo`05o`000?ooooooooooooooool000007Oooool00ol0003oooooooooo`32
ooooo`00POooool01Ol0003ooooooooooooooooo000001gooooo00?o0000ooooooooool0`_ooool0
087ooooo0ol00002ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0`oooool0087o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo0<?o
oooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`33ooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool0`oooool0087ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo0<?ooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`33ooooo`00POooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool0`oooool006Kooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo0<?ooooo001Vooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`33
ooooo`00I_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`34ooooo`00I_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RH
ob4Q8@06ooooo`?o00000oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0<Cooooo
001Vooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0<Co
oooo001Vooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`34ooooo`00
I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0a?ooool006Kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0<Cooooo0021ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`34ooooo`00
POooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
a?ooool0087ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo0<Cooooo0021ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`35ooooo`00POooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool0aOooool0087ooooo0ol00004ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool0aOooool0087ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo0<Gooooo0021ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`35ooooo`00POooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0aOooool0087ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0<Gooooo0021ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`35ooooo`00
POooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
aOooool0087ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo0<Kooooo0021ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`36ooooo`00POooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0a_ooool0087ooooo0ol00005ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool0a_ooool0087ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo0<Kooooo0021ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`36ooooo`00POooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0a_ooool0087ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo0<Kooooo0021ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`36ooooo`00
POooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
aoooool0087ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo0<Oooooo0021ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`37ooooo`00POooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0aoooool0087ooooo0ol00006ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool0aoooool0087ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo0<Oooooo0021ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`37ooooo`00POooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0aoooool0087ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0<Oooooo0021ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`38ooooo`00
POooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
b?ooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Q
o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo0<Sooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`38ooooo`00I_ooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`38ooooo`00I_ooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o00001oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo0<Sooooo001Vooooo`05o`000?ooooooooooooooool000002ooo
ool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo0<Sooooo001Vooooo`05oa0@4?ooooooooooooooool@4100
2oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo0<Sooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo0<Sooooo001Vooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0<Wooooo0021ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`39ooooo`00POooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0bOooool0087ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0<Wooooo
0021ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`39ooooo`00POooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0bOooool0087ooooo0ol00008ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool0bOooool0087ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo0<Wooooo0021ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`3:ooooo`00POooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool0b_ooool0087ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0<[ooooo0021ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`3:ooooo`00POooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0b_ooool0087ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0<[ooooo
0021ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`3;ooooo`00POooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0boooool0087ooooo0ol0000:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0boooool0087ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo0<_ooooo0021ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`3;ooooo`00POooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0boooool0087ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo0<_ooooo0021ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3<ooooo`00POooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0c?ooool0087ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0<cooooo
0021ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`3<ooooo`00POooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0c?ooool0087ooooo0ol0000<ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0c?ooool0087ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0<gooooo0021ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`3=ooooo`00POooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0cOooool0087ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo0<kooooo0021ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3>ooooo`00POooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0c_ooool007Oooooo
1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00kooooo00Go0000oooooooooooo
ooooo`00003Aooooo`00NOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00kooooo
00Go0000ooooooooooooooooo`00003Aooooo`00NOooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooool00000d_ooool007Wooooo00?o0000ooooooooool01Ooo
ool3o`00013ooooo0_l0003Booooo`00NOooool00ol0003oooooooooo`3/ooooo`00NOooool00ol0
003oooooooooo`3/ooooo`00NOooool00ol0003oooooooooo`3/ooooo`00Moooool00omEEEGoIVIV
o`00003^ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-12, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.32877 .12361 -18 -4.5 ]
[.32877 .12361 0 4.5 ]
[.32877 .24721 -18 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -18 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -18 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-5)] .18254 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(10)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(15)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.34127 .12361 m
.34752 .12361 L
s
[(0.2)] .32877 .12361 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(0.4)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(0.6)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(0.8)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(1)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0309 m
.34502 .0309 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .09271 m
.34502 .09271 L
s
.34127 .15451 m
.34502 .15451 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .21631 m
.34502 .21631 L
s
.34127 .27812 m
.34502 .27812 L
s
.34127 .30902 m
.34502 .30902 L
s
.34127 .33992 m
.34502 .33992 L
s
.34127 .40172 m
.34502 .40172 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .46353 m
.34502 .46353 L
s
.34127 .52533 m
.34502 .52533 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .58713 m
.34502 .58713 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02499 0 L
.02605 0 L
.02846 0 L
.03068 0 L
.03279 0 L
.03524 0 L
.0375 0 L
.03998 0 L
.04124 0 L
.04262 0 L
.04394 0 L
.04519 0 L
.04755 0 L
.04886 0 L
.05009 0 L
.05151 0 L
.05285 0 L
.05529 0 L
.0575 0 L
.05987 0 L
.06244 0 L
.06371 0 L
.06508 0 L
.06753 0 L
.06903 0 L
.07045 0 L
.07312 0 L
.07448 0 L
.07592 0 L
.07852 0 L
.07996 0 L
.08131 0 L
.08278 0 L
.08439 0 L
.08686 0 L
.08946 0 L
.09187 0 L
.09411 0 L
.09676 0 L
.09917 0 L
.10195 0 L
.10458 0 L
.10697 0 L
.10921 0 L
.11166 0 L
.1143 0 L
.11706 0 L
.11968 0 L
.12203 0 L
Mistroke
.12459 0 L
.12703 0 L
.12923 0 L
.13177 0 L
.13417 0 L
.13639 0 L
.13844 0 L
.14068 0 L
.14305 0 L
.1456 0 L
.14802 0 L
.15019 0 L
.15255 0 L
.15512 0 L
.15784 0 L
.16016 0 L
.16272 0 L
.16728 0 L
.16985 0 L
.17219 1e-05 L
.17652 1e-05 L
.17869 1e-05 L
.18107 1e-05 L
.18362 2e-05 L
.18637 2e-05 L
.1888 3e-05 L
.19137 4e-05 L
.19369 4e-05 L
.19624 6e-05 L
.20072 8e-05 L
.20345 .0001 L
.20595 .00013 L
.20863 .00016 L
.21156 .0002 L
.21426 .00025 L
.21675 .0003 L
.22168 .00044 L
.22631 .00062 L
.23129 .0009 L
.236 .00125 L
.24032 .00169 L
.24511 .00234 L
.25035 .00331 L
.25582 .00469 L
.26092 .00641 L
.26596 .00866 L
.27142 .01185 L
.27659 .01576 L
.28135 .02031 L
.29037 .03203 L
Mistroke
.29492 .03981 L
.29993 .0501 L
.31008 .07737 L
.31935 .11104 L
.33006 .16144 L
.34024 .22077 L
.37845 .49379 L
.38859 .55418 L
.39356 .57769 L
.39814 .59495 L
.40066 .60253 L
.40343 .60916 L
.40477 .61173 L
.40621 .614 L
.40773 .61586 L
.40846 .61655 L
.40914 .61708 L
.41043 .61776 L
.4111 .61795 L
.41182 .61803 L
.41303 .61788 L
.41372 .61764 L
.41436 .6173 L
.41556 .6164 L
.41665 .61527 L
.41912 .61166 L
.4216 .60654 L
.42386 .60063 L
.42893 .58324 L
.43805 .53901 L
.45876 .39824 L
.47958 .24704 L
.48872 .18964 L
.49876 .13643 L
.50778 .09808 L
.51746 .06636 L
.52281 .05264 L
.52769 .04217 L
.53725 .02658 L
.54204 .0208 L
.54713 .01587 L
.55153 .01245 L
.55629 .0095 L
.5619 .00682 L
.56717 .00494 L
.57231 .00357 L
.57703 .00263 L
.58175 .00191 L
.5868 .00135 L
.59157 .00096 L
Mistroke
.59591 .0007 L
.601 .00048 L
.60388 .00038 L
.60654 .00031 L
.61142 .00021 L
.61388 .00017 L
.61659 .00014 L
.61907 .00011 L
.62178 9e-05 L
.62417 7e-05 L
.62672 6e-05 L
.62924 5e-05 L
.63152 4e-05 L
.63599 3e-05 L
.63868 2e-05 L
.64115 2e-05 L
.64381 1e-05 L
.64674 1e-05 L
.64911 1e-05 L
.65166 1e-05 L
.65435 0 L
.65686 0 L
.65942 0 L
.66214 0 L
.66447 0 L
.66703 0 L
.66978 0 L
.67274 0 L
.67553 0 L
.67809 0 L
.68052 0 L
.68277 0 L
.68525 0 L
.68789 0 L
.69067 0 L
.6933 0 L
.69566 0 L
.69821 0 L
.70057 0 L
.7031 0 L
.70549 0 L
.70767 0 L
.71023 0 L
.71301 0 L
.71564 0 L
.71808 0 L
.72083 0 L
.72343 0 L
.72575 0 L
.72827 0 L
Mistroke
.73102 0 L
.7324 0 L
.73392 0 L
.73661 0 L
.73912 0 L
.74173 0 L
.74414 0 L
.74678 0 L
.74812 0 L
.74959 0 L
.75205 0 L
.75471 0 L
.75721 0 L
.7595 0 L
.76174 0 L
.76383 0 L
.76611 0 L
.76855 0 L
.76978 0 L
.77112 0 L
.77354 0 L
.7759 0 L
.77807 0 L
.78052 0 L
.78275 0 L
.78399 0 L
.78533 0 L
.78778 0 L
.79007 0 L
.79249 0 L
.79457 0 L
.79686 0 L
.79816 0 L
.79953 0 L
.80198 0 L
.80335 0 L
.80462 0 L
.8061 0 L
.80751 0 L
.80872 0 L
.81004 0 L
.81234 0 L
.81365 0 L
.81503 0 L
.81751 0 L
.81872 0 L
.82003 0 L
.82119 0 L
.82243 0 L
.82365 0 L
Mistroke
.82476 0 L
.82693 0 L
.82823 0 L
.82943 0 L
.83072 0 L
.83214 0 L
.83453 0 L
.83583 0 L
.83705 0 L
.83819 0 L
.83942 0 L
.84051 0 L
.84167 0 L
.84271 0 L
.84386 0 L
.84588 0 L
.84711 0 L
.84824 0 L
.84945 0 L
.85077 0 L
.853 0 L
.85422 0 L
.85535 0 L
.85663 0 L
.85798 0 L
.8604 0 L
.86175 0 L
.86301 0 L
.86439 0 L
.86588 0 L
.86715 0 L
.86854 0 L
.86977 0 L
.87107 0 L
.87236 0 L
.87353 0 L
.87582 0 L
.87698 0 L
.87822 0 L
.88042 0 L
.88165 0 L
.88279 0 L
.88413 0 L
.8854 0 L
.88649 0 L
.88767 0 L
.88975 0 L
.89092 0 L
.89217 0 L
.89441 0 L
Mistroke
.89561 0 L
.89692 0 L
.89808 0 L
.89931 0 L
.90053 0 L
.90164 0 L
.90381 0 L
.90511 0 L
.90631 0 L
.90762 0 L
.90901 0 L
.91022 0 L
.91135 0 L
.91259 0 L
.91392 0 L
.91514 0 L
.91627 0 L
.91751 0 L
.91883 0 L
.9199 0 L
.92105 0 L
.92231 0 L
.92349 0 L
.92571 0 L
.92682 0 L
.92804 0 L
.92909 0 L
.9302 0 L
.93222 0 L
.93345 0 L
.9348 0 L
.93621 0 L
.93754 0 L
.93877 0 L
.9399 0 L
.94121 0 L
.94245 0 L
.94378 0 L
.9452 0 L
.94654 0 L
.94775 0 L
.94919 0 L
.95074 0 L
.9522 0 L
.95354 0 L
.95471 0 L
.95596 0 L
.95714 0 L
.95822 0 L
.95948 0 L
Mistroke
.96085 0 L
.96215 0 L
.96334 0 L
.96457 0 L
.96573 0 L
.967 0 L
.96836 0 L
.96972 0 L
.97114 0 L
.97236 0 L
.97369 0 L
.9749 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h/ooooo`05odA4A?l0003o0000oc8b<_oMgMd0G_ooool01Om4A4Co0000o`000?lb<S;ogMgM02[o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^:?ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0Tooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01?ooooo000Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0_ooooo`03ogMgMolb<S;ooooo063ooooo00?oMgMgoc8b<_ooool0:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo02Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL04oooool000oooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Sooooo`Ko00001oooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000;oooool00omgMgOo<S8booooo`1Pooooo`03ogMgMolb<S;ooooo02_o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002[ooooo00?o0000oooo
ooooool01_ooool00omgMgOo<S8booooo`0Vooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000;?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<05kooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00/ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Zooooo`03
o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Xooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@4100;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Aooooo`006_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Wooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01?ooooo000Hooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0/ooooo`Co0000Goooool4o`0002_ooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo00?oEEEEofIVI_l000001Oooool4o`0002Kooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001?ooooo
ool00016o`00013ooooo000Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`co00002Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool01?l0003oooooooooooooool;o`0000Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo
000Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000000_l00006ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`Co00001ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Fooooo`00Ioooool4o`0001Kooooo00?o0000ooooooooool0A?ooool2
o`0009kooooo001[ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0@Oooool3o`00
0:3ooooo001[ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0@Oooool00ol0003o
ooooooooo`2Pooooo`00K?ooool2o`0001?ooooo00?o0000ooooooooool0?oooool2o`000:?ooooo
001^ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0?_ooool00ol0003ooooooooo
o`2Sooooo`00K_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03kooooo00?o0000
ooooooooool0Xoooool006oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0moooo
o`03o`000?oooooooooo0:Cooooo001`ooooo`03o`000?oooooooooo00kooooo0ol0000mooooo`03
o`000?oooooooooo0:Cooooo001aooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`2Uooooo`00LOooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0Y_ooool007;ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo0:Kooooo001booooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`2Wooooo`00Loooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0Yoooool007?ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo0:Sooooo
001dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>Oooool00ol0003ooooooooo
o`2Xooooo`00M?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool0ZOooool007Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo0:Wooooo001eooooo`03o`000?oooooooooo00Wooooo0ol0000gooooo`03
o`000?oooooooooo0:[ooooo001eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
=oooool00ol0003oooooooooo`2Zooooo`00M_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool0Zoooool007Kooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0fooooo`03o`000?oooooooooo0:_ooooo001fooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`2[ooooo`00Moooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0[?ooool007Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo0:cooooo
001gooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`2/ooooo`00Moooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Cooooo00?o0000
ooooooooool0[Oooool007Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo0:gooooo001hooooo`03o`000?oooooooooo00Kooooo0ol0000dooooo`03
o`000?oooooooooo0:gooooo001hooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
<oooool00ol0003oooooooooo`2^ooooo`00NOooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool0[_ooool007Wooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo0:kooooo001iooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`2^ooooo`00N_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0[oooool007[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo0:oooooo
001jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<_ooool00ol0003ooooooooo
o`2_ooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_oo
ool00ol0003oooooooooo`0booooo`03o`000?oooooooooo0:oooooo001Vooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00KoV9RHob4Q8Oo^k^koooooodA4A?l00005ooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool0/?ooool006Kooooo00Go410@oooooooooooo
oooooa0@400<ooooo`05oiRHV?lQ8B7ok^k^ooooool000001Oooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo0;3ooooo001Vooooo`05o`000?ooooooooooooooool000003Oooool01?nH
V9So8B4Qonk^k_l00005ooooo`?o0000<Oooool00ol0003oooooooooo`2`ooooo`00I_ooool01Ol0
003ooooooooooooooooo000000kooooo00?oMgMgofIVI_l000001Oooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo0;3ooooo001Vooooo`05oa0@4?ooooooooooooooool@41003oooool0
0ol0003oooooo`000004ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0/?ooool0
06Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`07o`000?nj^[[ooooooiRHV?l@413ooooo
o`000004ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0/Oooool006Kooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`07oiRHV?l@413o0000ob4Q8Oo<c<coooooo`000004oooo
o`03o`000?oooooooooo033ooooo00?o0000ooooooooool0/Oooool007cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo0;7ooooo001looooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`2aooooo`00OOoo
ool01Ol0003ooooooooooooooooo000003;ooooo00?o0000ooooooooool0/Oooool007gooooo00Go
0000ooooooooooooooooo`00000aooooo`03o`000?oooooooooo0;;ooooo001mooooo`05o`000?oo
ooooooooooooool00000<Oooool00ol0003oooooooooo`2booooo`00OOooool01?l0003ooooooooo
ooooool3o`0002oooooo00?o0000ooooooooool0/_ooool007kooooo00Co0000oooooooooooo0000
<Oooool00ol0003oooooooooo`2booooo`00O_ooool01?l0003oooooooooool0000aooooo`03o`00
0?oooooooooo0;;ooooo001nooooo`04o`000?ooooooooooo`00033ooooo00?o0000ooooooooool0
/oooool007kooooo00Co0000oooooooooooo0000<?ooool00ol0003oooooooooo`2cooooo`00O_oo
ool01?l0003oooooooooool0000`ooooo`03o`000?oooooooooo0;?ooooo001oooooo`03o`000?oo
oooo0000033ooooo00?o0000ooooooooool0/oooool007oooooo00?o0000ooooool00000<?ooool0
0ol0003oooooooooo`2cooooo`00Ooooool00ol0003oooooo`00000`ooooo`03o`000?oooooooooo
0;?ooooo001oooooo`03o`000?oooooo000002oooooo00?o0000ooooooooool0]?ooool007oooooo
00?o0000ooooool000000_l0000]ooooo`03o`000?oooooooooo0;Cooooo001oooooo`03o`000?oo
oooo000002oooooo00?o0000ooooooooool0]?ooool0083ooooo0_l0000_ooooo`03o`000?oooooo
oooo0;Cooooo0020ooooo`;o0000;oooool00ol0003oooooooooo`2dooooo`00P?ooool2o`0002oo
oooo00?o0000ooooooooool0]?ooool0083ooooo0_l0000^ooooo`03o`000?oooooooooo0;Gooooo
0020ooooo`;o0000;_ooool00ol0003oooooooooo`2eooooo`00P?ooool2o`0002kooooo00?o0000
ooooooooool0]Oooool0083ooooo0_l0000^ooooo`03o`000?oooooooooo0;Gooooo0021ooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool0]Oooool0087ooooo0ol0000/ooooo`03o`00
0?oooooooooo0;Gooooo0021ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0]_oo
ool0087ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`2fooooo`00POooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo0;Kooooo0021ooooo`03o`000?oooooooooo02_o
oooo00?o0000ooooooooool0]_ooool0087ooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`2fooooo`00POooool2o`0002cooooo00?o0000ooooooooool0]_ooool006Kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo0_l0
000/ooooo`03o`000?oooooooooo0;Kooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool2o`0002_ooooo00?o0000ooooooooool0]ooo
ool006Kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool2o`0002_ooooo00?o
0000ooooooooool0]oooool006Kooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oM
gMgoooooo`0000Oooooo0ol0000Zooooo`03o`000?oooooooooo0;Oooooo001Vooooo`05o`000?oo
ooooooooooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`;o0000:oooool00ol0003o
ooooooooo`2gooooo`00I_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l0
00001oooool2o`0002_ooooo00?o0000ooooooooool0]oooool006Kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooool00000:_ooool00ol0003o
ooooooooo`2gooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?oo
ool01_ooool00ol0003oooooo`00000Yooooo`03o`000?oooooooooo0;Sooooo0021ooooo`03o`00
0?oooooo000002Wooooo00?o0000ooooooooool0^?ooool0087ooooo00?o0000ooooool00000:Ooo
ool00ol0003oooooooooo`2hooooo`00POooool00ol0003oooooo`00000Yooooo`03o`000?oooooo
oooo0;Sooooo0021ooooo`03o`000?oooooo000002Wooooo00?o0000ooooooooool0^?ooool0087o
oooo00?o0000ooooool00000:Oooool00ol0003oooooooooo`2hooooo`00POooool3o`0002Wooooo
00?o0000ooooooooool0^?ooool0087ooooo00Co0000oooooooooooo00009oooool00ol0003ooooo
ooooo`2iooooo`00POooool01?l0003oooooooooool0000Wooooo`03o`000?oooooooooo0;Wooooo
0021ooooo`04o`000?ooooooooooo`0002Oooooo00?o0000ooooooooool0^Oooool0087ooooo00Co
0000oooooooooooo00009oooool00ol0003oooooooooo`2iooooo`00POooool01?l0003ooooooooo
ool0000Wooooo`03o`000?oooooooooo0;Wooooo0021ooooo`04o`000?ooooooooooo`0002Oooooo
00?o0000ooooooooool0^Oooool0087ooooo00Co0000oooooooooooo00009oooool00ol0003ooooo
ooooo`2iooooo`00POooool01Ol0003ooooooooooooooooo000002Gooooo00?o0000ooooooooool0
^_ooool0087ooooo00Go0000ooooooooooooooooo`00000Uooooo`03o`000?oooooooooo0;[ooooo
0021ooooo`?o000000?oooooo`000?ooool09?ooool00ol0003oooooooooo`2jooooo`00POooool0
1Ol0003ooooooooooooooooo000002Gooooo00?o0000ooooooooool0^_ooool0087ooooo00Go0000
ooooooooooooooooo`00000Uooooo`03o`000?oooooooooo0;[ooooo0021ooooo`05o`000?oooooo
ooooooooool000009Oooool00ol0003oooooooooo`2jooooo`00POooool01Ol0003ooooooooooooo
oooo000002Gooooo00?o0000ooooooooool0^_ooool0087ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo0;_ooooo0021ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`2kooooo`00POooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0^oooool0087ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo0;_ooooo
0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`2kooooo`00POooool3o`0000;ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`2k
ooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool0^oooool0087ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo0;cooooo0021ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`2looooo`00POooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool0_?ooool0087ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo0;cooooo0021ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`2looooo`00I_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0_?ooool0
06Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonH
V9So8B4Q00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo0;cooooo001Vooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo0;gooooo001Vooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RH
oooooonHV9So8B4Q00Kooooo0ol00004ooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool0_Oooool006Kooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool0_Oooool006Kooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo
00Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
0;gooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`2moooo
o`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0_Oooool0
087ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
0;gooooo0021ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`2nooooo`00POooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool0__ooool0087ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo0;kooooo0021ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`2nooooo`00POooool3o`0000Gooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`2nooooo`00POooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool0__ooool0087ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo0;kooooo0021ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`2nooooo`00POooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0_oooool0
087ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
0;oooooo0021ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`2oooooo`00POooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool0_oooool0087ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo0;oooooo0021ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`2oooooo`00POooool3o`0000Kooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`2oooooo`00POooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool0`?ooool0087ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0<3ooooo0021ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`30ooooo`00POooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0`?ooool0
087ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
0<3ooooo0021ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`30ooooo`00POooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0`?ooool0087ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo0<3ooooo0021ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`31ooooo`00POooool3o`0000Sooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`31ooooo`00POooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool0`Oooool0087ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0<7ooooo0021ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`31ooooo`00POooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0`Oooool0
087ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
0<7ooooo0021ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`32ooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0`_ooool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo0<;ooooo001Vooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo0<;ooooo001Vooooo`05o`000?oooooo
ooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol00009ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool0`_ooool006Kooooo00Go0000oooooooooooooooo
o`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool0`_ooool006Kooooo00Go410@oooooooooooo
oooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0`_ooool006Kooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0`_ooool006Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0`oooool0087ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo0<?ooooo0021oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`33oooo
o`00POooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0`oooool0087ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo0<?ooooo0021ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`33ooooo`00POooool3o`0000_ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`33ooooo`00POooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0a?ooool0087ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo0<Cooooo0021ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`34ooooo`00POooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0a?ooool0087ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo0<Cooooo0021oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`34oooo
o`00POooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool0aOooool0087ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo0<Gooooo0021ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`35ooooo`00POooool3o`0000gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`35ooooo`00POooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0aOooool0087ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo0<Kooooo0021ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`36ooooo`00POooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0a_ooool0087ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0<Kooooo0021oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`36oooo
o`00POooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0aoooool0087ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo0<Oooooo0021ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`37ooooo`00POooool3o`0000oooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`37ooooo`00POooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0b?ooool0087ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo0<Sooooo0021ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`38ooooo`00POooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0bOooool0087ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0<Wooooo0021oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3:oooo
o`00Moooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo0<[ooooo001iooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0<[ooooo
001iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04_ooool2o`000003ooooool0
003o00000<gooooo001iooooo`03o`000?oooooooooo00Gooooo0ol0000Cooooo`?o0000c_ooool0
07Wooooo00?o0000ooooooooool0k?ooool007Wooooo00?o0000ooooooooool0k?ooool007Wooooo
00?o0000ooooooooool0k?ooool007Oooooo00?oEEEEofIVI_l00000k_ooool00?ooooooJOooool0
0001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-12, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.32877 .12361 -18 -4.5 ]
[.32877 .12361 0 4.5 ]
[.32877 .24721 -18 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -18 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -18 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-5)] .18254 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(10)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(15)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.34127 .12361 m
.34752 .12361 L
s
[(0.2)] .32877 .12361 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(0.4)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(0.6)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(0.8)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(1)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0309 m
.34502 .0309 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .09271 m
.34502 .09271 L
s
.34127 .15451 m
.34502 .15451 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .21631 m
.34502 .21631 L
s
.34127 .27812 m
.34502 .27812 L
s
.34127 .30902 m
.34502 .30902 L
s
.34127 .33992 m
.34502 .33992 L
s
.34127 .40172 m
.34502 .40172 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .46353 m
.34502 .46353 L
s
.34127 .52533 m
.34502 .52533 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .58713 m
.34502 .58713 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02605 0 L
.02846 0 L
.03072 0 L
.03279 0 L
.03521 0 L
.03784 0 L
.04032 0 L
.04262 0 L
.04498 0 L
.0472 0 L
.04963 0 L
.05224 0 L
.05497 0 L
.05757 0 L
.0599 0 L
.06244 0 L
.0653 0 L
.06799 0 L
.07041 0 L
.07302 0 L
.07588 0 L
.07889 0 L
.08147 0 L
.08429 0 L
.08694 0 L
.08936 0 L
.09196 0 L
.09479 0 L
.0974 0 L
.09982 0 L
.1023 0 L
.10458 0 L
.10921 0 L
.11165 0 L
.11421 0 L
.11852 0 L
.12097 0 L
.12324 0 L
.12593 0 L
.12846 0 L
.1332 1e-05 L
.13586 1e-05 L
.13831 1e-05 L
.1412 1e-05 L
.14385 1e-05 L
.14852 2e-05 L
.15354 3e-05 L
.15819 4e-05 L
.16261 5e-05 L
Mistroke
.16773 7e-05 L
.17248 .0001 L
.1777 .00014 L
.18325 .0002 L
.18862 .00029 L
.19356 .0004 L
.19898 .00055 L
.2047 .00078 L
.20968 .00105 L
.21433 .00138 L
.21943 .00184 L
.22488 .00248 L
.23018 .0033 L
.23508 .00427 L
.24046 .00561 L
.24616 .00745 L
.25574 .01173 L
.26119 .01502 L
.2663 .0188 L
.27615 .02845 L
.28652 .04274 L
.29537 .05913 L
.30504 .08231 L
.32469 .14919 L
.33568 .19888 L
.34565 .25101 L
.36649 .37453 L
.38568 .48834 L
.39536 .5377 L
.40441 .57509 L
.40934 .59107 L
.41384 .6026 L
.41623 .60747 L
.41884 .61175 L
.42027 .61363 L
.42159 .61508 L
.42286 .6162 L
.42356 .6167 L
.4242 .6171 L
.42535 .61763 L
.42661 .61796 L
.42768 .61803 L
.42883 .6179 L
.42947 .61773 L
.43017 .61747 L
.43144 .61679 L
.43267 .61587 L
.43381 .6148 L
.4359 .61229 L
.4382 .60872 L
Mistroke
.44284 .59896 L
.44797 .58443 L
.45348 .56474 L
.46344 .51996 L
.50468 .27809 L
.52529 .17142 L
.53532 .12998 L
.54441 .09881 L
.5533 .07397 L
.56291 .05281 L
.57306 .03601 L
.58262 .02448 L
.59214 .01627 L
.59754 .01277 L
.60258 .01011 L
.6078 .00788 L
.61275 .00618 L
.61845 .00463 L
.62365 .00354 L
.62863 .00271 L
.63331 .0021 L
.63819 .0016 L
.64357 .00117 L
.6482 .0009 L
.65244 .00069 L
.6571 .00052 L
.66199 .00039 L
.667 .00028 L
.67155 .00021 L
.6768 .00015 L
.68175 .00011 L
.68634 8e-05 L
.69057 6e-05 L
.69521 4e-05 L
.70012 3e-05 L
.70506 2e-05 L
.70957 1e-05 L
.71206 1e-05 L
.71477 1e-05 L
.71737 1e-05 L
.71971 1e-05 L
.72432 0 L
.72684 0 L
.72922 0 L
.73346 0 L
.73803 0 L
.74042 0 L
.74297 0 L
.74757 0 L
.75038 0 L
Mistroke
.75304 0 L
.75802 0 L
.76057 0 L
.76328 0 L
.76813 0 L
.77083 0 L
.77335 0 L
.77612 0 L
.77911 0 L
.78164 0 L
.78434 0 L
.78668 0 L
.7892 0 L
.79218 0 L
.79499 0 L
.79772 0 L
.80023 0 L
.80248 0 L
.80489 0 L
.80753 0 L
.81 0 L
.81277 0 L
.81539 0 L
.81775 0 L
.82032 0 L
.82265 0 L
.82516 0 L
.82753 0 L
.82971 0 L
.83212 0 L
.83476 0 L
.83752 0 L
.84008 0 L
.84282 0 L
.8454 0 L
.84772 0 L
.85024 0 L
.85298 0 L
.85588 0 L
.85836 0 L
.86109 0 L
.86358 0 L
.8663 0 L
.86886 0 L
.87124 0 L
.8736 0 L
.87574 0 L
.87821 0 L
.88053 0 L
.88307 0 L
Mistroke
.88576 0 L
.88805 0 L
.89057 0 L
.89328 0 L
.89618 0 L
.89892 0 L
.90142 0 L
.90371 0 L
.90623 0 L
.90887 0 L
.91135 0 L
.91366 0 L
.91577 0 L
.91809 0 L
.92053 0 L
.92302 0 L
.92567 0 L
.92818 0 L
.93045 0 L
.93313 0 L
.93464 0 L
.93604 0 L
.93859 0 L
.93988 0 L
.9413 0 L
.94346 0 L
.94582 0 L
.94804 0 L
.9501 0 L
.95195 0 L
.95399 0 L
.95612 0 L
.95813 0 L
.96033 0 L
.96266 0 L
.96464 0 L
.96682 0 L
.96916 0 L
.97045 0 L
.97167 0 L
.97404 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h/ooooo`05odA4A?l0003o0000oc8b<_oMgMd0G_ooool01Om4A4Co0000o`000?lb<S;ogMgM02[o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^:?ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0Tooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01?ooooo000Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0_ooooo`03ogMgMolb<S;ooooo063ooooo00?oMgMgoc8b<_ooool0:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo02Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL04oooool000oooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Sooooo`Ko00001oooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000;oooool00omgMgOo<S8booooo`1Pooooo`03ogMgMolb<S;ooooo02_o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002[ooooo00?o0000oooo
ooooool01_ooool00omgMgOo<S8booooo`0Vooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000;?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<05kooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00/ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Zooooo`03
o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Xooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@4100;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Aooooo`006_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Wooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01?ooooo000Hooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0/ooooo`Co0000Goooool4o`0002_ooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo00?oEEEEofIVI_l000001Oooool4o`0002Kooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001?ooooo
ool00016o`00013ooooo000Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooo`00000>o`0000?ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Oooooo3_l00007ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo000J
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Cooooo1?l0000:ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool00_ooool6o`0000Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0F
ooooo`00H_ooool3o`0001cooooo00?o0000ooooooooool0Doooool2o`0008oooooo001Uooooo`;o
00006_ooool00ol0003oooooooooo`1Aooooo`;o0000TOooool006Oooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo097ooooo001Xooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0C_ooool2o`0009Cooooo001Yooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`2Dooooo`00J_ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0UOooool006_o
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo09Ko
oooo001/ooooo`03o`000?oooooooooo01;ooooo0ol0001:ooooo`03o`000?oooooooooo09Oooooo
001]ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0BOooool00ol0003ooooooooo
o`2Hooooo`00K_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04Sooooo00?o0000
ooooooooool0VOooool006oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`18oooo
o`03o`000?oooooooooo09Wooooo001`ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0Aoooool00ol0003oooooooooo`2Jooooo`00L?ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo04Oooooo00?o0000ooooooooool0V_ooool0077ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo09_ooooo001aooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`2Kooooo`00LOooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0W?ooool007;o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo09co
oooo001booooo`03o`000?oooooooooo00cooooo0ol00014ooooo`03o`000?oooooooooo09gooooo
001booooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0A?ooool00ol0003ooooooooo
o`2Mooooo`00Loooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04?ooooo00?o0000
ooooooooool0W_ooool007?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`13oooo
o`03o`000?oooooooooo09kooooo001dooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0@_ooool00ol0003oooooooooo`2Oooooo`00MOooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo04;ooooo00?o0000ooooooooool0Woooool007Gooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo0:3ooooo001fooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`2Pooooo`00M_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0X?ooool007Ko
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo0:7o
oooo001gooooo`03o`000?oooooooooo00Oooooo0ol00010ooooo`03o`000?oooooooooo0:7ooooo
001gooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0@?ooool00ol0003ooooooooo
o`2Qooooo`00Moooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03oooooo00?o0000
ooooooooool0X_ooool007Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0ooooo
o`03o`000?oooooooooo0:;ooooo001hooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0?oooool00ol0003oooooooooo`2Rooooo`00N?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool0Xoooool007Sooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo0:?ooooo001iooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`2Sooooo`00I_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`0m
ooooo`03o`000?oooooooooo0:Cooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^ko0000odA4A006ooooo`03o`000?oooooooooo03gooooo00?o
0000ooooooooool0Y?ooool006Kooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7o000000Oooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`2Tooooo`00I_ooool0
1Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Ol000001_ooool3o`0003gooooo00?o
0000ooooooooool0Y?ooool006Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMol0
003ooooo00Gooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`2Uooooo`00I_ooool0
1Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0looooo`03o`000?oooooooooo0:Gooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01_l0003o^[ZjoooooonHV9So410@o`0000Gooooo00?o0000ooooooooool0??ooool00ol0003o
ooooooooo`2Uooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00KoV9RHoa0@4?l0
003o8B4Qolc<c?l00005ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0YOooool0
07_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
0:Kooooo001kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`2Vooooo`00O?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool0Y_ooool007cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo0:Kooooo001looooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`2Wooooo`00O?ooool00ol0003oooooooooo`02oooo
o`?o0000>_ooool00ol0003oooooooooo`2Wooooo`00O?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo03[ooooo00?o0000ooooooooool0Yoooool007gooooo00Go0000oooooooooooo
ooooo`00000looooo`03o`000?oooooooooo0:Oooooo001mooooo`05o`000?ooooooooooooooool0
0000??ooool00ol0003oooooooooo`2Wooooo`00OOooool01Ol0003ooooooooooooooooo000003_o
oooo00?o0000ooooooooool0Z?ooool007gooooo00Go0000ooooooooooooooooo`00000kooooo`03
o`000?oooooooooo0:Sooooo001mooooo`05o`000?ooooooooooooooool00000>oooool00ol0003o
ooooooooo`2Xooooo`00O_ooool01?l0003oooooooooool0000kooooo`03o`000?oooooooooo0:So
oooo001nooooo`04o`000?ooooooooooo`0003[ooooo00?o0000ooooooooool0ZOooool007kooooo
00Co0000oooooooooooo0000>_ooool00ol0003oooooooooo`2Yooooo`00O_ooool00ol0003ooooo
ooooo`03o`0003Sooooo00?o0000ooooooooool0ZOooool007kooooo00Co0000oooooooooooo0000
>_ooool00ol0003oooooooooo`2Yooooo`00Ooooool00ol0003oooooo`00000jooooo`03o`000?oo
oooooooo0:Wooooo001oooooo`03o`000?oooooo000003Wooooo00?o0000ooooooooool0Z_ooool0
07oooooo00?o0000ooooool00000>Oooool00ol0003oooooooooo`2Zooooo`00Ooooool00ol0003o
ooooo`00000iooooo`03o`000?oooooooooo0:[ooooo001oooooo`03o`000?oooooo000003Wooooo
00?o0000ooooooooool0Z_ooool0083ooooo0_l0000iooooo`03o`000?oooooooooo0:[ooooo0020
ooooo`;o0000>?ooool00ol0003oooooooooo`2[ooooo`00P?ooool2o`0003Sooooo00?o0000oooo
ooooool0Zoooool0083ooooo1?l0000fooooo`03o`000?oooooooooo0:_ooooo0021ooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool0Zoooool0087ooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`2[ooooo`00POooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo0:cooooo0021ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0[?ooool0087o
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`2/ooooo`00POooool2o`0003Kooooo
00?o0000ooooooooool0[?ooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1_ooool2o`000003oa0@4?oooooooooo00Cooooo0_l0000fooooo`03o`000?oooooooooo0:cooooo
001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool0
1Oooool2o`0003Gooooo00?o0000ooooooooool0[Oooool006Kooooo00Go410@oooooooooooooooo
oa0@400;ooooo`Go00001_ooool2o`0003Gooooo00?o0000ooooooooool0[Oooool006Kooooo00Go
0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0000dooooo`03
o`000?oooooooooo0:gooooo001Vooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgo
EEEEooooool00007ooooo`03o`000?oooooo000003Cooooo00?o0000ooooooooool0[Oooool006Ko
oooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ool00000=?ooool00ol0003oooooooooo`2]ooooo`00I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooo`00000cooooo`03o`000?oooooooooo
0:kooooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06oooo
o`03o`000?oooooo000003?ooooo00?o0000ooooooooool0[_ooool0087ooooo00Co0000oooooooo
oooo0000<_ooool00ol0003oooooooooo`2^ooooo`00POooool01?l0003oooooooooool0000boooo
o`03o`000?oooooooooo0:kooooo0021ooooo`04o`000?ooooooooooo`0003;ooooo00?o0000oooo
ooooool0[_ooool0087ooooo00Co0000oooooooooooo0000<Oooool00ol0003oooooooooo`2_oooo
o`00POooool01?l0003oooooooooool0000aooooo`03o`000?oooooooooo0:oooooo0021ooooo`Co
0000<Oooool00ol0003oooooooooo`2_ooooo`00POooool01?l0003oooooooooool0000aooooo`03
o`000?oooooooooo0:oooooo0021ooooo`05o`000?ooooooooooooooool00000<?ooool00ol0003o
ooooooooo`2_ooooo`00POooool01Ol0003ooooooooooooooooo0000033ooooo00?o0000oooooooo
ool0[oooool0087ooooo00Go0000ooooooooooooooooo`00000_ooooo`03o`000?oooooooooo0;3o
oooo0021ooooo`05o`000?ooooooooooooooool00000;oooool00ol0003oooooooooo`2`ooooo`00
POooool01Ol0003ooooooooooooooooo000002oooooo00?o0000ooooooooool0/?ooool0087ooooo
00Go0000ooooooooooooooooo`00000_ooooo`03o`000?oooooooooo0;3ooooo0021ooooo`05o`00
0?ooooooooooooooool00000;oooool00ol0003oooooooooo`2`ooooo`00POooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0/?ooool0087ooooo0ol0
0002ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0/Oooool0087ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo0;7ooooo0021oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`2aoooo
o`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool0/Oooool0087ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo0;7ooooo0021ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`2aooooo`00POooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool0/_ooool0087ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo0;;ooooo0021ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`2booooo`00POooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0/_ooool0087ooooo0ol0
0003ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0/_ooool0087ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0;;ooooo0021oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`2coooo
o`00POooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool0/oooool0087ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo0;?ooooo0021ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`2cooooo`00POooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool0/oooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo0;?ooooo001Vooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`2dooooo`00I_oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`2dooooo`00
I_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06oooo
o`?o00001Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo0;Cooooo001Vooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo0;Cooooo001Voooo
o`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`2dooooo`00I_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0]?ooool006Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo0;Gooooo0021ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`2eooooo`00POooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0]Oooool0087o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo0;Go
oooo0021ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`2eooooo`00POooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool0]Oooool0087ooooo0ol00007ooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool0]_ooool0087ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo0;Kooooo0021ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`2fooooo`00POooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool0]_ooool0087ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo0;Kooooo0021ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`2fooooo`00POooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0]oooool0087o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo0;Oo
oooo0021ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`2gooooo`00POooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool0]oooool0087ooooo0ol00009ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool0]oooool0087ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo0;Oooooo0021ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`2hooooo`00POooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool0^?ooool0087ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo0;Sooooo0021ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`2hooooo`00POooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0^?ooool0087o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo0;So
oooo0021ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`2iooooo`00POooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool0^Oooool0087ooooo0ol0000:ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool0^Oooool0087ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo0;Wooooo0021ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`2iooooo`00POooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool0^Oooool0087ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo0;[ooooo0021ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`2jooooo`00POooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0^_ooool006Ko
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo0;[ooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4Q
oiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`2jooooo`00I_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`2jooooo`00I_ooool01Ol0003ooooooooooooooooo000000_ooooo
00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o00003?ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo0;_ooooo001Vooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co
0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo0;_ooooo001Vooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@
413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo0;_ooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo0;_ooooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo0;_ooooo0021ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`2kooooo`00POooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0_?ooool0087ooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0;cooooo0021ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2looooo`00
POooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
_?ooool0087ooooo0ol0000>ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0_?oo
ool0087ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo0;gooooo0021ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`2mooooo`00POooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0_Oooool0087ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo0;gooooo0021ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`2mooooo`00POooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0__ooool0087ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0;kooooo0021ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`2nooooo`00
POooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
__ooool0087ooooo0ol0000@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0__oo
ool0087ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo0;oooooo0021ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`2oooooo`00POooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0_oooool0087ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo0;oooooo0021ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`30ooooo`00POooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0`?ooool0087ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0<3ooooo0021ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`31ooooo`00
POooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
`Oooool0087ooooo0ol0000Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0`Ooo
ool0087ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo0<;ooooo0021ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`32ooooo`00POooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0`_ooool0087ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0<?ooooo0021ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`33ooooo`00POooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0a?ooool007Oooooo1?l000000ol@
413oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`34ooooo`00NOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Ko
oooo0_l00004ooooo`03o`000?oooooooooo0<Gooooo001iooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool05oooool2o`0000;ooooo00?o0000ooooooooool0a_ooool007Wooooo00?o
0000ooooooooool01Oooool3o`0001Sooooo0ol00039ooooo`00NOooool00ol0003oooooooooo`3/
ooooo`00NOooool00ol0003oooooooooo`3/ooooo`00NOooool00ol0003oooooooooo`3/ooooo`00
Moooool00omEEEGoIVIVo`00003^ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-12, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.32877 .12361 -18 -4.5 ]
[.32877 .12361 0 4.5 ]
[.32877 .24721 -18 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -18 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -18 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-5)] .18254 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(10)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(15)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.34127 .12361 m
.34752 .12361 L
s
[(0.2)] .32877 .12361 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(0.4)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(0.6)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(0.8)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(1)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0309 m
.34502 .0309 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .09271 m
.34502 .09271 L
s
.34127 .15451 m
.34502 .15451 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .21631 m
.34502 .21631 L
s
.34127 .27812 m
.34502 .27812 L
s
.34127 .30902 m
.34502 .30902 L
s
.34127 .33992 m
.34502 .33992 L
s
.34127 .40172 m
.34502 .40172 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .46353 m
.34502 .46353 L
s
.34127 .52533 m
.34502 .52533 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .58713 m
.34502 .58713 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02846 0 L
.03279 0 L
.03754 0 L
.04262 0 L
.04518 0 L
.04795 0 L
.053 0 L
.05791 0 L
.06244 0 L
.06747 0 L
.07218 0 L
.07734 0 L
.0829 0 L
.08567 0 L
.0887 1e-05 L
.09422 1e-05 L
.09959 1e-05 L
.10458 2e-05 L
.10966 2e-05 L
.11515 3e-05 L
.12033 4e-05 L
.1251 6e-05 L
.12942 7e-05 L
.13415 9e-05 L
.13909 .00012 L
.14371 .00016 L
.14872 .00021 L
.15416 .00028 L
.1593 .00037 L
.16406 .00047 L
.17306 .00073 L
.1776 .00091 L
.18262 .00116 L
.18753 .00147 L
.19271 .00186 L
.20196 .00282 L
.20712 .00353 L
.21193 .00433 L
.21715 .00539 L
.22282 .00679 L
.23334 .01028 L
.24328 .01492 L
.25295 .02108 L
.26187 .02857 L
.27156 .03911 L
.28063 .05167 L
.29122 .0702 L
.30127 .09216 L
.32156 .15103 L
Mistroke
.34009 .22232 L
.37834 .40596 L
.3997 .5067 L
.40978 .54676 L
.41904 .57698 L
.42367 .58928 L
.42874 .60041 L
.43384 .60895 L
.43663 .61245 L
.43922 .61496 L
.44041 .61586 L
.44169 .61666 L
.4429 .61725 L
.44403 .61765 L
.44503 .61789 L
.44615 .61802 L
.44731 .61801 L
.4484 .61787 L
.4496 .61756 L
.45087 .61706 L
.45195 .61649 L
.45313 .61572 L
.45577 .61345 L
.45822 .61066 L
.46328 .60287 L
.46877 .59146 L
.47872 .56347 L
.49732 .49062 L
.53829 .29033 L
.55868 .19976 L
.57774 .13165 L
.59604 .08294 L
.60631 .06233 L
.61568 .04724 L
.62492 .03539 L
.63474 .0256 L
.64552 .01759 L
.65549 .0122 L
.66485 .00851 L
.66976 .007 L
.67494 .00568 L
.67949 .0047 L
.68447 .00381 L
.69321 .0026 L
.69849 .00205 L
.70347 .00163 L
.7128 .00105 L
.71802 .00082 L
.72284 .00064 L
.72813 .00049 L
Mistroke
.73374 .00037 L
.73866 .00029 L
.74316 .00023 L
.74836 .00017 L
.75329 .00013 L
.75753 .0001 L
.76205 8e-05 L
.767 6e-05 L
.7716 5e-05 L
.77696 3e-05 L
.78189 3e-05 L
.78731 2e-05 L
.79302 1e-05 L
.798 1e-05 L
.80264 1e-05 L
.80774 0 L
.8132 0 L
.81849 0 L
.82338 0 L
.82875 0 L
.83146 0 L
.83445 0 L
.83945 0 L
.84226 0 L
.84484 0 L
.84958 0 L
.85458 0 L
.85716 0 L
.85959 0 L
.86413 0 L
.86903 0 L
.87179 0 L
.87434 0 L
.87859 0 L
.88326 0 L
.88562 0 L
.88814 0 L
.89271 0 L
.89526 0 L
.89797 0 L
.90285 0 L
.90584 0 L
.90865 0 L
.9112 0 L
.9139 0 L
.9163 0 L
.91894 0 L
.92357 0 L
.92618 0 L
.92897 0 L
Mistroke
.934 0 L
.93658 0 L
.93931 0 L
.94421 0 L
.94694 0 L
.94949 0 L
.95229 0 L
.9553 0 L
.95788 0 L
.96069 0 L
.96335 0 L
.96581 0 L
.97047 0 L
.97308 0 L
.97544 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h/ooooo`05odA4A?l0003o0000oc8b<_oMgMd0G_ooool01Om4A4Co0000o`000?lb<S;ogMgM02[o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^:?ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0Tooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01?ooooo000Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0_ooooo`03ogMgMolb<S;ooooo063ooooo00?oMgMgoc8b<_ooool0:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo02Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL04oooool000oooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Sooooo`Ko00001oooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000;oooool00omgMgOo<S8booooo`1Pooooo`03ogMgMolb<S;ooooo02_o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002[ooooo00?o0000oooo
ooooool01_ooool00omgMgOo<S8booooo`0Vooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000;?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<05kooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00/ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Zooooo`03
o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Xooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@4100;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Aooooo`006_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Wooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01?ooooo000Hooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0/ooooo`Co0000Goooool4o`0002_ooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo00?oEEEEofIVI_l000001Oooool4o`0002Kooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001?ooooo
ool00016o`00013ooooo000Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo4_l00002ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooooa?o00000_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo000Jooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`Go00001oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo1Ol000000ooooooo0000ooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0F
ooooo`00Foooool3o`0002?ooooo00?o0000ooooooooool0IOooool4o`0007_ooooo001Nooooo`?o
00008?ooool00ol0003oooooooooo`1Rooooo`?o0000Ooooool0067ooooo0ol0000Mooooo`03o`00
0?oooooooooo067ooooo00?o0000ooooooooool0P?ooool006Cooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`1Oooooo`;o0000Poooool006Gooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`1Nooooo`03o`000?oooooooooo08?ooooo001Vooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`24ooooo`00Ioooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0QOooool006Sooooo
00?o0000ooooooooool05_ooool3o`0005_ooooo00?o0000ooooooooool0Q_ooool006Wooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo08Oooooo001Z
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`28
ooooo`00Joooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo05Wooooo00?o0000oooo
ooooool0R?ooool006_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1Hooooo`03
o`000?oooooooooo08Wooooo001/ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
Eoooool00ol0003oooooooooo`2:ooooo`00KOooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo05Kooooo00?o0000ooooooooool0Roooool006kooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`1Fooooo`03o`000?oooooooooo08_ooooo001^ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`2<ooooo`00Koooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0SOooool006oooooo
00?o0000ooooooooool03oooool3o`0005Cooooo00?o0000ooooooooool0SOooool0073ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo08kooooo001`
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`2>
ooooo`00LOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo05;ooooo00?o0000oooo
ooooool0Soooool0077ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Booooo`03
o`000?oooooooooo08oooooo001booooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
DOooool00ol0003oooooooooo`2@ooooo`00L_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo057ooooo00?o0000ooooooooool0T?ooool007?ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`1@ooooo`03o`000?oooooooooo097ooooo001cooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`2Aooooo`00Loooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0T_ooool007Cooooo
00?o0000ooooooooool02_ooool3o`0004oooooo00?o0000ooooooooool0T_ooool007Cooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo09;ooooo001e
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`2C
ooooo`00MOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04kooooo00?o0000oooo
ooooool0Toooool007Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1>ooooo`03
o`000?oooooooooo09?ooooo001fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
COooool00ol0003oooooooooo`2Dooooo`00M_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo04gooooo00?o0000ooooooooool0U?ooool007Kooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`1<ooooo`03o`000?oooooooooo09Gooooo001Vooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo04cooooo00?o0000
ooooooooool0UOooool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So0000onk^k_ooooooA4A400Kooooo00?o0000ooooooooool0C?ooool00ol0003ooooooooo
o`2Eooooo`00I_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHo`000?o^k^h01ooo
ool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo09Kooooo001Vooooo`05o`000?oooooo
ooooooooool000003Oooool00ol0003o8B4Qonk^kP06ooooo`?o0000Boooool00ol0003ooooooooo
o`2Fooooo`00I_ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ogMgMomVIVH01_oo
ool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo09Kooooo001Vooooo`05oa0@4?oooooo
ooooooooool@41003_ooool2o`0000Kooooo00?o0000ooooooooool0B_ooool00ol0003ooooooooo
o`2Gooooo`00I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo0000
oa0@4006ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0Uoooool006Kooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000o`000?o<c<`01_ooool00ol0003o
ooooooooo`1:ooooo`03o`000?oooooooooo09Oooooo001jooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0BOooool00ol0003oooooooooo`2Hooooo`00N_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0V?ooool007[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo09Sooooo001koooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`2Ioooo
o`00Noooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04Sooooo00?o0000oooooooo
ool0VOooool007_ooooo00?o0000ooooooooool00oooool3o`0004Sooooo00?o0000ooooooooool0
VOooool007cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`18ooooo`03o`000?oo
oooooooo09Wooooo001looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Aoooool0
0ol0003oooooooooo`2Jooooo`00O?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
04Oooooo00?o0000ooooooooool0V_ooool007cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`17ooooo`03o`000?oooooooooo09[ooooo001mooooo`05o`000?ooooooooooooooool0
0000BOooool00ol0003oooooooooo`2Jooooo`00OOooool01Ol0003ooooooooooooooooo000004So
oooo00?o0000ooooooooool0Voooool007gooooo00Go0000ooooooooooooooooo`000018ooooo`03
o`000?oooooooooo09_ooooo001mooooo`05o`000?ooooooooooooooool00000B?ooool00ol0003o
ooooooooo`2Kooooo`00O_ooool01?l0003oooooooooool00017ooooo`03o`000?oooooooooo09co
oooo001nooooo`03o`000?oooooooooo00?o0000AOooool00ol0003oooooooooo`2Looooo`00O_oo
ool01?l0003oooooooooool00017ooooo`03o`000?oooooooooo09cooooo001nooooo`04o`000?oo
ooooooooo`0004Oooooo00?o0000ooooooooool0W?ooool007oooooo00?o0000ooooool00000A_oo
ool00ol0003oooooooooo`2Mooooo`00Ooooool00ol0003oooooo`000016ooooo`03o`000?oooooo
oooo09gooooo001oooooo`03o`000?oooooo000004Kooooo00?o0000ooooooooool0WOooool007oo
oooo00?o0000ooooool00000A_ooool00ol0003oooooooooo`2Mooooo`00P?ooool2o`0004Gooooo
00?o0000ooooooooool0W_ooool0083ooooo0_l00015ooooo`03o`000?oooooooooo09kooooo0020
ooooo`;o0000AOooool00ol0003oooooooooo`2Nooooo`00P?ooool4o`0004?ooooo00?o0000oooo
ooooool0W_ooool0087ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`2Oooooo`00
POooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo09oooooo0021ooooo`03o`000?oo
oooooooo04;ooooo00?o0000ooooooooool0Woooool0087ooooo00?o0000ooooooooool0@_ooool0
0ol0003oooooooooo`2Oooooo`00POooool2o`0004?ooooo00?o0000ooooooooool0Woooool0087o
oooo0_l00012ooooo`03o`000?oooooooooo0:3ooooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`;o0000@_ooool00ol0003o
ooooooooo`2Pooooo`00I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03
o`000?oooooooooo00Gooooo0_l00012ooooo`03o`000?oooooooooo0:3ooooo001Vooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0000Kooooo0_l00012ooooo`03o`000?oooooooooo0:3o
oooo001Vooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00007oooo
o`?o0000@?ooool00ol0003oooooooooo`2Qooooo`00I_ooool01Ol0003ooooooooooooooooo0000
00_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooo`000010ooooo`03o`000?oooooo
oooo0:7ooooo001Vooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007
ooooo`03o`000?oooooo0000043ooooo00?o0000ooooooooool0XOooool006Kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooool00000@?ooool0
0ol0003oooooooooo`2Qooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMg
o`000?ooool01_ooool00ol0003oooooo`00000oooooo`03o`000?oooooooooo0:;ooooo0021oooo
o`04o`000?ooooooooooo`0003kooooo00?o0000ooooooooool0X_ooool0087ooooo00Co0000oooo
oooooooo0000?_ooool00ol0003oooooooooo`2Rooooo`00POooool01?l0003oooooooooool0000n
ooooo`03o`000?oooooooooo0:;ooooo0021ooooo`04o`000?ooooooooooo`0003kooooo00?o0000
ooooooooool0X_ooool0087ooooo00Co0000oooooooooooo0000?Oooool00ol0003oooooooooo`2S
ooooo`00POooool3o`000003ooooool0003ooooo03_ooooo00?o0000ooooooooool0Xoooool0087o
oooo00Go0000ooooooooooooooooo`00000looooo`03o`000?oooooooooo0:?ooooo0021ooooo`05
o`000?ooooooooooooooool00000??ooool00ol0003oooooooooo`2Sooooo`00POooool01Ol0003o
oooooooooooooooo000003_ooooo00?o0000ooooooooool0Y?ooool0087ooooo00Go0000oooooooo
ooooooooo`00000kooooo`03o`000?oooooooooo0:Cooooo0021ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`2Tooooo`00POooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0Y?ooool0087ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo0:Gooooo0021
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`2U
ooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool0YOooool0087ooooo0ol00003ooooo`03o`000?oooooooooo03Kooooo00?o0000oooooooo
ool0YOooool0087ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo0:Gooooo0021ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`2Vooooo`00POooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool0Y_ooool0087ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo0:Kooooo0021ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`2Vooooo`00POooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0Y_ooool0087ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo0:Oooooo0021
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`2W
ooooo`00POooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool0Yoooool0087ooooo0ol00005ooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool0Yoooool0087ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0booooo`03o`00
0?oooooooooo0:Oooooo0021ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`2Xooooo`00POooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool0Z?ooool0087ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo0:Sooooo0021ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`2Xooooo`00POooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0Z?ooool006Kooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo0:Wo
oooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMooo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`2Yooooo`00I_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`2Yooooo`00I_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000
oiRHV?ooooooV9RHob4Q8@06ooooo`?o00001oooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo0:Wooooo001Vooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`00
0?l@413oc<c<00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo0:Wooooo001Vooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7
ooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`2Zooooo`00I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0
2?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
Z_ooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo0:[o
oooo0021ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`2Zooooo`00POooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02cooooo00?o
0000ooooooooool0Z_ooool0087ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo0:_ooooo0021ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`2[ooooo`00POooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo02_ooooo00?o0000ooooooooool0Zoooool0087ooooo0ol00009ooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool0Zoooool0087ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo0:_ooooo0021ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`2/ooooo`00POooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0[?ooool0087o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0:co
oooo0021ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`2/ooooo`00POooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool0[?ooool0087ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo0:gooooo0021ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`2]ooooo`00POooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool0[Oooool0087ooooo0ol0000;ooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool0[Oooool0087ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo0:gooooo0021ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`2^ooooo`00POooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0[_ooool0087o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo0:ko
oooo0021ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`2^ooooo`00POooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0[_ooool0087ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo0:oooooo0021ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`2_ooooo`00POooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool0[oooool0087ooooo0ol0000=ooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool0[oooool0087ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo0:oooooo0021ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`2`ooooo`00POooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0/?ooool0087o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0;3o
oooo0021ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`2`ooooo`00POooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool0/?ooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo0;7ooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`2aooooo`00I_ooool01Ol@413ooooo
oooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`2aooooo`00I_ooool01Ol0003o
oooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o00003oooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo0;7ooooo001Vooooo`05o`000?oooooooooo
ooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo0;7ooooo001Vooooo`05oa0@4?oooooo
ooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo0;;ooooo001Vooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo0;;ooooo001Vooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo0;;ooooo0021ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`2booooo`00
POooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
/oooool0087ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo0;?ooooo0021ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`2cooooo`00POooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0/oooool0087ooooo0ol0000Booooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool0]?ooool0087ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo0;Cooooo0021ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`2dooooo`00POooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0]Oooool0087ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo0;Gooooo0021ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`2eooooo`00
POooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
]Oooool0087ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo0;Kooooo0021ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`2fooooo`00POooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0]_ooool0087ooooo0ol0000Eooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool0]_ooool0087ooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo0;Oooooo0021ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`2gooooo`00POooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0]oooool0087ooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0;Sooooo0021ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`2hooooo`00
POooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
^?ooool0087ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo0;Wooooo0021ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`2iooooo`00POooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0^Oooool0087ooooo0ol0000Hooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0^_ooool0087ooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo0;[ooooo0021ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`2jooooo`00POooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0^oooool0087ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0;_ooooo0021ooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2looooo`00
POooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
_Oooool007Oooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`2nooooo`00NOooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2o
ooooo`00NOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01gooooo0_l00002oooo
o`;o0000`Oooool007Wooooo00?o0000ooooooooool01Oooool3o`0001kooooo1?l00032ooooo`00
NOooool00ol0003oooooooooo`3/ooooo`00NOooool00ol0003oooooooooo`3/ooooo`00NOooool0
0ol0003oooooooooo`3/ooooo`00Moooool00omEEEGoIVIVo`00003^ooooo`00oooooomYooooo`00
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-12, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.32877 .12361 -18 -4.5 ]
[.32877 .12361 0 4.5 ]
[.32877 .24721 -18 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -18 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -18 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-5)] .18254 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(10)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(15)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.34127 .12361 m
.34752 .12361 L
s
[(0.2)] .32877 .12361 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(0.4)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(0.6)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(0.8)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(1)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0309 m
.34502 .0309 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .09271 m
.34502 .09271 L
s
.34127 .15451 m
.34502 .15451 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .21631 m
.34502 .21631 L
s
.34127 .27812 m
.34502 .27812 L
s
.34127 .30902 m
.34502 .30902 L
s
.34127 .33992 m
.34502 .33992 L
s
.34127 .40172 m
.34502 .40172 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .46353 m
.34502 .46353 L
s
.34127 .52533 m
.34502 .52533 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .58713 m
.34502 .58713 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02846 0 L
.03279 1e-05 L
.03754 1e-05 L
.04262 1e-05 L
.04795 1e-05 L
.053 2e-05 L
.05753 2e-05 L
.06244 3e-05 L
.06751 4e-05 L
.07308 5e-05 L
.0789 6e-05 L
.08435 8e-05 L
.0941 .00012 L
.09957 .00016 L
.10458 .0002 L
.10934 .00024 L
.11442 .0003 L
.12357 .00044 L
.12916 .00056 L
.13443 .00069 L
.13913 .00084 L
.14429 .00103 L
.15405 .0015 L
.15939 .00183 L
.16437 .0022 L
.17328 .00305 L
.18284 .00427 L
.19301 .00603 L
.20408 .00867 L
.21453 .01204 L
.2242 .01613 L
.23383 .02134 L
.24286 .02748 L
.2529 .03596 L
.26347 .04711 L
.28365 .07602 L
.30215 .1129 L
.3219 .1645 L
.34026 .22382 L
.37931 .37622 L
.39922 .45678 L
.42081 .53404 L
.43091 .56358 L
.44161 .58868 L
.45074 .60435 L
.45593 .61069 L
.45828 .61293 L
.46079 .61487 L
.46214 .61573 L
Mistroke
.46337 .61639 L
.46462 .61695 L
.46577 .61736 L
.46711 .61772 L
.46782 .61786 L
.46856 .61796 L
.46982 .61803 L
.47053 .61802 L
.47119 .61798 L
.47248 .61781 L
.47369 .61753 L
.47478 .61718 L
.47597 .61671 L
.47862 .61527 L
.48107 .61348 L
.48535 .60931 L
.49007 .6032 L
.49961 .5862 L
.50973 .5619 L
.519 .53471 L
.53987 .46038 L
.57954 .29964 L
.6177 .16572 L
.63735 .11406 L
.65832 .07274 L
.66859 .05723 L
.6797 .04352 L
.68931 .03394 L
.69987 .0255 L
.71016 .01904 L
.71978 .01433 L
.72994 .01048 L
.74084 .00739 L
.751 .00527 L
.76205 .0036 L
.7725 .00247 L
.78217 .00173 L
.79178 .0012 L
.80081 .00084 L
.81071 .00056 L
.81629 .00045 L
.8214 .00036 L
.82613 .00029 L
.83119 .00024 L
.8403 .00016 L
.84587 .00012 L
.85114 .0001 L
.85583 8e-05 L
.86099 6e-05 L
.8707 4e-05 L
Mistroke
.87601 3e-05 L
.88098 2e-05 L
.88987 1e-05 L
.89486 1e-05 L
.89943 1e-05 L
.9042 1e-05 L
.90928 1e-05 L
.91408 0 L
.91843 0 L
.92356 0 L
.9291 0 L
.93434 0 L
.93916 0 L
.94357 0 L
.94829 0 L
.95275 0 L
.95682 0 L
.96158 0 L
.96677 0 L
.97166 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h/ooooo`05odA4A?l0003o0000oc8b<_oMgMd0G_ooool01Om4A4Co0000o`000?lb<S;ogMgM02[o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^:?ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0Tooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01?ooooo000Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0_ooooo`03ogMgMolb<S;ooooo063ooooo00?oMgMgoc8b<_ooool0:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo02Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL04oooool000oooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Sooooo`Ko00001oooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000;oooool00omgMgOo<S8booooo`1Pooooo`03ogMgMolb<S;ooooo02_o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002[ooooo00?o0000oooo
ooooool01_ooool00omgMgOo<S8booooo`0Vooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000;?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<05kooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00/ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Zooooo`03
o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Xooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@4100;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Aooooo`006_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Wooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01?ooooo000Hooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0/ooooo`Co0000Goooool4o`0002_ooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo00?oEEEEofIVI_l000001Oooool4o`0002Kooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001?ooooo
ool00016o`00013ooooo000Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`04oooooaWo00002Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool00_oooolFo`0000Cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Fooooo`006_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo1_l00004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool7
o`0000Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool05_ooool005Cooooo1?l0000Yooooo`03o`000?oooooooooo
07gooooo1?l0001Sooooo`00F?ooool2o`0002Oooooo00?o0000ooooooooool0N_ooool3o`0006Oo
oooo001Jooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0Moooool3o`0006[ooooo
001Kooooo`?o00008oooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo06_ooooo001N
ooooo`;o00008Oooool00ol0003oooooooooo`1dooooo`;o0000K_ooool0063ooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo06kooooo001Qooooo`;o
00007_ooool00ol0003oooooooooo`1aooooo`;o0000LOooool006?ooooo00?o0000ooooooooool0
6oooool3o`0006oooooo0_l0001cooooo`00I?ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo06kooooo00?o0000ooooooooool0Loooool006Gooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`1^ooooo`03o`000?oooooooooo07?ooooo001Uooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`1dooooo`00I_ooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0MOooool006Oooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo07Kooooo
001Xooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0J_ooool00ol0003ooooooooo
o`1gooooo`00J?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo06Wooooo00?o0000
ooooooooool0N?ooool006Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Xoooo
o`03o`000?oooooooooo07Wooooo001Zooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0Ioooool00ol0003oooooooooo`1jooooo`00Joooool00ol0003oooooooooo`0Cooooo`?o0000
Ioooool00ol0003oooooooooo`1jooooo`00K?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo06Kooooo00?o0000ooooooooool0Noooool006cooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`1Uooooo`03o`000?oooooooooo07cooooo001]ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1looooo`00K_ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0OOooool006oooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo07gooooo
001_ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Hoooool00ol0003ooooooooo
o`1nooooo`00L?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo06?ooooo00?o0000
ooooooooool0O_ooool0073ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1Roooo
o`03o`000?oooooooooo07oooooo001aooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool0H_ooool00ol0003oooooooooo`1oooooo`00LOooool00ol0003oooooooooo`0=ooooo`?o0000
HOooool00ol0003oooooooooo`20ooooo`00L_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo063ooooo00?o0000ooooooooool0POooool007;ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`1Pooooo`03o`000?oooooooooo087ooooo001cooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`22ooooo`00Loooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0P_ooool007Cooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo08?ooooo
001dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0G_ooool00ol0003ooooooooo
o`23ooooo`00MOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05gooooo00?o0000
ooooooooool0Q?ooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q0oooool6
o`0000Kooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`24ooooo`00I_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05o`000?lQ8B7ok^k^oooooom4A4@01_oo
ool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo08Gooooo001Vooooo`05oa0@4?oooooo
ooooooooool@41002oooool01?l0003oV9RHob4Q8Oo^k^h7ooooo`03o`000?oooooooooo05cooooo
00?o0000ooooooooool0QOooool006Kooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?ooooooV9RHob4Q8Oo^k^h01_ooool3o`0005cooooo00?o0000ooooooooool0QOooool006Kooooo
00Go0000ooooooooooooooooo`00000<ooooo`04o`000?ooooooMgMgofIVIPKooooo00?o0000oooo
ooooool0Foooool00ol0003oooooooooo`26ooooo`00I_ooool01Ol@413ooooooooooooooooo410@
00cooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooo
oooo08Kooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool2o`000003oooooonHV9So
410@00Kooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`26ooooo`00I_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oo
oooooooo05[ooooo00?o0000ooooooooool0Qoooool007Sooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`1Jooooo`03o`000?oooooooooo08Oooooo001hooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`27ooooo`00NOooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0R?ooool007Wooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo08Sooooo
001iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0FOooool00ol0003ooooooooo
o`28ooooo`00N_ooool00ol0003oooooooooo`04ooooo`?o0000F?ooool00ol0003oooooooooo`29
ooooo`00N_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Sooooo00?o0000oooo
ooooool0ROooool007[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Hooooo`03
o`000?oooooooooo08Wooooo001kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
Eoooool00ol0003oooooooooo`2:ooooo`00Noooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo05Oooooo00?o0000ooooooooool0R_ooool007_ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1Gooooo`03o`000?oooooooooo08[ooooo001looooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`2;ooooo`00O?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0Roooool007cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo08_ooooo
001mooooo`05o`000?ooooooooooooooool00000Eoooool00ol0003oooooooooo`2<ooooo`00OOoo
ool01?l0003oooooooooooooool3o`0005Gooooo00?o0000ooooooooool0S?ooool007gooooo00Go
0000ooooooooooooooooo`00001Gooooo`03o`000?oooooooooo08cooooo001nooooo`04o`000?oo
ooooooooo`0005Oooooo00?o0000ooooooooool0S?ooool007kooooo00Co0000oooooooooooo0000
E_ooool00ol0003oooooooooo`2=ooooo`00O_ooool01?l0003oooooooooool0001Fooooo`03o`00
0?oooooooooo08gooooo001oooooo`03o`000?oooooo000005Kooooo00?o0000ooooooooool0SOoo
ool007oooooo00?o0000ooooool00000E_ooool00ol0003oooooooooo`2=ooooo`00Ooooool00ol0
003oooooo`00001Eooooo`03o`000?oooooooooo08kooooo0020ooooo`;o0000EOooool00ol0003o
ooooooooo`2>ooooo`00P?ooool2o`0005Gooooo00?o0000ooooooooool0S_ooool0083ooooo1?l0
001Booooo`03o`000?oooooooooo08oooooo0021ooooo`03o`000?oooooooooo05;ooooo00?o0000
ooooooooool0Soooool0087ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`2?oooo
o`00POooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo08oooooo0021ooooo`03o`00
0?oooooooooo057ooooo00?o0000ooooooooool0T?ooool0087ooooo0_l0001Booooo`03o`000?oo
oooooooo093ooooo0021ooooo`;o0000D_ooool00ol0003oooooooooo`2@ooooo`00I_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool2
o`0005;ooooo00?o0000ooooooooool0T?ooool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`;o0000DOooool00ol0003oooooooooo`2A
ooooo`00I_ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`03o`000?oooooo
0000053ooooo00?o0000ooooooooool0TOooool006Kooooo00Go0000ooooooooooooooooo`00000;
ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0001@ooooo`03o`000?oooooooooo097ooooo001V
ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`00
0?oooooo000004oooooo00?o0000ooooooooool0T_ooool006Kooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00Co0000oooooooooooo0000C_ooool00ol0003o
ooooooooo`2Booooo`00I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l0
00001oooool01?l0003oooooooooool0001>ooooo`03o`000?oooooooooo09;ooooo001Vooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`04o`000?oooooooooo
o`0004kooooo00?o0000ooooooooool0T_ooool0087ooooo00Co0000oooooooooooo0000COooool0
0ol0003oooooooooo`2Cooooo`00POooool01Ol0003ooooooooooooooooo000004cooooo00?o0000
ooooooooool0Toooool0087ooooo00Go0000ooooooooooooooooo`00001<ooooo`03o`000?oooooo
oooo09?ooooo0021ooooo`05o`000?ooooooooooooooool00000C?ooool00ol0003oooooooooo`2C
ooooo`00POooool01Ol0003ooooooooooooooooo000004_ooooo00?o0000ooooooooool0U?ooool0
087ooooo0ol00002ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0U?ooool0087o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo09Co
oooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Aoooool00ol0003ooooo
ooooo`2Eooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04Oooooo00?o
0000ooooooooool0UOooool0087ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`16
ooooo`03o`000?oooooooooo09Gooooo0021ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`2Eooooo`00POooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo04Gooooo00?o0000ooooooooool0U_ooool0087ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo09Kooooo0021ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`2Fooooo`00POooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0U_ooool0
087ooooo0ol00004ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0Uoooool0087o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo09Oo
oooo0021ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0@_ooool00ol0003ooooo
ooooo`2Gooooo`00POooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04;ooooo00?o
0000ooooooooool0Uoooool0087ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`11
ooooo`03o`000?oooooooooo09Sooooo0021ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0@?ooool00ol0003oooooooooo`2Hooooo`00POooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo043ooooo00?o0000ooooooooool0V?ooool0087ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo09Sooooo0021ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`2Iooooo`00POooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0VOooool0
087ooooo0ol00007ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0VOooool0087o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo09Wo
oooo0021ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0?Oooool00ol0003ooooo
ooooo`2Jooooo`00POooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03cooooo00?o
0000ooooooooool0V_ooool0087ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0l
ooooo`03o`000?oooooooooo09[ooooo0021ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0??ooool00ol0003oooooooooo`2Jooooo`00POooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo03[ooooo00?o0000ooooooooool0Voooool006Kooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo09_ooooo001Vooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`2K
ooooo`00I_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>_ooool00ol0003ooooooooo
o`2Kooooo`00I_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RH
ob4Q8@06ooooo`?o00002_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo09cooooo
001Vooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Ko
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo09co
oooo001Vooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`2Looooo`00
I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0W?ooool006Kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo09gooooo0021ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`2Mooooo`00
POooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
WOooool0087ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo09gooooo0021ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0=Oooool0
0ol0003oooooooooo`2Nooooo`00POooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
03Cooooo00?o0000ooooooooool0W_ooool0087ooooo0ol0000<ooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool0W_ooool0087ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0dooooo`03o`000?oooooooooo09kooooo0021ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0<oooool00ol0003oooooooooo`2Oooooo`00POooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0Woooool0087ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo09oooooo0021ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`2Oooooo`00
POooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
X?ooool0087ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo0:3ooooo0021ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`2Pooooo`00POooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool0X?ooool0087ooooo0ol0000>ooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool0XOooool0087ooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo0:7ooooo0021ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`2Qooooo`00POooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0XOooool0087ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo0:;ooooo0021ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`2Rooooo`00
POooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
X_ooool0087ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo0:;ooooo0021ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`2Sooooo`00POooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool0Xoooool0087ooooo0ol0000@ooooo`03o`000?oooooooooo02_o
oooo00?o0000ooooooooool0Xoooool0087ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo0:?ooooo0021ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`2Tooooo`00POooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0Y?ooool0087ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0:Cooooo0021ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`2Uooooo`00
POooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
YOooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Q
o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo0:Gooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`2Uooooo`00I_ooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`2Vooooo`00I_ooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o00004oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo0:Kooooo001Vooooo`05o`000?ooooooooooooooool000002ooo
ool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo0:Kooooo001Vooooo`05oa0@4?ooooooooooooooool@4100
2oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo0:Oooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo0:Oooooo001Vooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo0:Oooooo0021ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`2Xooooo`00POooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0Z?ooool0087ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo0:Sooooo
0021ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`2Xooooo`00POooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool0ZOooool0087ooooo0ol0000Fooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool0ZOooool0087ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo0:Wooooo0021ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`2Zooooo`00POooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool0Z_ooool0087ooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo0:[ooooo0021ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`2[ooooo`00POooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0Zoooool0087ooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo0:_ooooo
0021ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`2/ooooo`00POooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0[?ooool0087ooooo0ol0000Iooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool0[?ooool0087ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo0:gooooo0021ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`2]ooooo`00POooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool0[Oooool0087ooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0:kooooo0021ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`2^ooooo`00POooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0[_ooool0087ooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo0:oooooo
0021ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`2_ooooo`00POooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0[oooool0087ooooo0ol0000Nooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0/?ooool0087ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo0;3ooooo0021ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`2aooooo`00POooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0/_ooool0087ooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0;;ooooo0021ooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`2cooooo`00POooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0]?ooool007Oooooo
1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`2eooooo`00NOooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2fooooo`00NOooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Cooooo0_l00003ooooo`;o0000^Oooool0
07Wooooo00?o0000ooooooooool01Oooool3o`0002Gooooo1Ol0002jooooo`00NOooool00ol0003o
ooooooooo`3/ooooo`00NOooool00ol0003oooooooooo`3/ooooo`00NOooool00ol0003ooooooooo
o`3/ooooo`00Moooool00omEEEGoIVIVo`00003^ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-12, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.32877 .12361 -18 -4.5 ]
[.32877 .12361 0 4.5 ]
[.32877 .24721 -18 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -18 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -18 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-5)] .18254 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(10)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(15)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.34127 .12361 m
.34752 .12361 L
s
[(0.2)] .32877 .12361 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(0.4)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(0.6)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(0.8)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(1)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0309 m
.34502 .0309 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .09271 m
.34502 .09271 L
s
.34127 .15451 m
.34502 .15451 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .21631 m
.34502 .21631 L
s
.34127 .27812 m
.34502 .27812 L
s
.34127 .30902 m
.34502 .30902 L
s
.34127 .33992 m
.34502 .33992 L
s
.34127 .40172 m
.34502 .40172 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .46353 m
.34502 .46353 L
s
.34127 .52533 m
.34502 .52533 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .58713 m
.34502 .58713 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 7e-05 m
.03279 .0001 L
.04262 .00014 L
.05288 .0002 L
.06244 .00028 L
.0731 .00041 L
.0828 .00057 L
.094 .00083 L
.10458 .00116 L
.11428 .00158 L
.12455 .00216 L
.13333 .00281 L
.14299 .00372 L
.15313 .00496 L
.1624 .00641 L
.17311 .00853 L
.18328 .01111 L
.19287 .01413 L
.20309 .01811 L
.22147 .02773 L
.23176 .03476 L
.24289 .04398 L
.26306 .06565 L
.283 .09444 L
.30406 .13392 L
.34203 .22957 L
.38246 .35845 L
.42136 .48582 L
.44118 .54109 L
.45162 .56546 L
.46273 .58684 L
.47256 .60143 L
.47816 .60777 L
.48342 .61237 L
.48576 .61399 L
.48823 .6154 L
.49033 .61637 L
.49264 .61717 L
.49394 .61751 L
.49513 .61775 L
.49578 .61785 L
.49649 .61793 L
.49778 .61802 L
.49899 .61803 L
.50027 .61796 L
.50137 .61783 L
.50257 .61762 L
.50386 .61732 L
.50506 .61696 L
.50778 .61589 L
Mistroke
.51018 .61464 L
.51273 .613 L
.51761 .60898 L
.52202 .60437 L
.53278 .58936 L
.54291 .57067 L
.56303 .52227 L
.58151 .46772 L
.62105 .33669 L
.65908 .21784 L
.68026 .16246 L
.69955 .12051 L
.7198 .08527 L
.73851 .06014 L
.75764 .04088 L
.76836 .0325 L
.77841 .02599 L
.79711 .01678 L
.80704 .01315 L
.81773 .01002 L
.82814 .00763 L
.83781 .00587 L
.8479 .00443 L
.85892 .00323 L
.86947 .00236 L
.87942 .00175 L
.88835 .00132 L
.89802 .00097 L
.90751 .00071 L
.91793 .0005 L
.92882 .00035 L
.93899 .00024 L
.94898 .00017 L
.95844 .00012 L
.96694 9e-05 L
.97619 6e-05 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h/ooooo`05odA4A?l0003o0000oc8b<_oMgMd0G_ooool01Om4A4Co0000o`000?lb<S;ogMgM02[o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^:?ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0Tooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01?ooooo000Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0_ooooo`03ogMgMolb<S;ooooo063ooooo00?oMgMgoc8b<_ooool0:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo02Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL04oooool000oooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Sooooo`Ko00001oooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000;oooool00omgMgOo<S8booooo`1Pooooo`03ogMgMolb<S;ooooo02_o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002[ooooo00?o0000oooo
ooooool01_ooool00omgMgOo<S8booooo`0Vooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000;?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<05kooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00/ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Zooooo`03
o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Xooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@4100;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Aooooo`006_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Wooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01?ooooo000Hooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0/ooooo`Co0000Goooool4o`0002_ooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo00?oEEEEofIVI_l000001Oooool4o`0002Kooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001?ooooo
ool00016o`00013ooooo000Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooool000006Ol0
0003ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000007Ol00009ooooo`03o`000?oo
oooooooo01Kooooo000Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo1_l00007ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`Oo00002?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Fooooo`00Aoooool7o`0003?ooooo00?o0000ooooooooool0V_ooool3o`00
04Oooooo001>ooooo`?o0000<?ooool00ol0003oooooooooo`2Fooooo`Co0000B_ooool0057ooooo
0ol0000]ooooo`03o`000?oooooooooo09?ooooo0ol0001>ooooo`00E?ooool2o`0002_ooooo00?o
0000ooooooooool0T?ooool3o`00057ooooo001Fooooo`;o0000:Oooool00ol0003oooooooooo`2>
ooooo`;o0000E?ooool005Sooooo0_l0000Wooooo`03o`000?oooooooooo08cooooo0_l0001Foooo
o`00F_ooool2o`0002Gooooo00?o0000ooooooooool0R_ooool2o`0005Sooooo001Looooo`03o`00
0?oooooooooo02;ooooo0ol00029ooooo`03o`000?oooooooooo05Sooooo001Mooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0Qoooool2o`0005_ooooo001Nooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`1Kooooo`00Goooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool0G?ooool0063o
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo05go
oooo001Qooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0Poooool00ol0003ooooo
ooooo`1Nooooo`00H_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo08;ooooo00?o
0000ooooooooool0Goooool006?ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`21
ooooo`03o`000?oooooooooo063ooooo001Tooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool0P?ooool00ol0003oooooooooo`1Qooooo`00IOooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo07oooooo00?o0000ooooooooool0H_ooool006Kooooo00?o0000ooooooooool0
6?ooool3o`0007kooooo00?o0000ooooooooool0Hoooool006Oooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo06?ooooo001Xooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`1Tooooo`00J?ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0IOooool006Wo
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo06Ko
oooo001Zooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0Noooool00ol0003ooooo
ooooo`1Vooooo`00J_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo07[ooooo00?o
0000ooooooooool0Ioooool006_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1i
ooooo`03o`000?oooooooooo06Sooooo001/ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool0N?ooool00ol0003oooooooooo`1Yooooo`00K?ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo07Sooooo00?o0000ooooooooool0JOooool006gooooo00?o0000ooooooooool0
4Oooool3o`0007Oooooo00?o0000ooooooooool0J_ooool006kooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo06[ooooo001^ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`1[ooooo`00Koooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool0K?ooool006oo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo06co
oooo001`ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0M?ooool00ol0003ooooo
ooooo`1]ooooo`00L?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo07Cooooo00?o
0000ooooooooool0KOooool0077ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1c
ooooo`03o`000?oooooooooo06kooooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@04o`000?ooooooooooooooo`Go00001_ooool00ol0003oooooooooo`1booooo`03o`000?oo
oooooooo06oooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@09o`000?oo
oooooooooooooonHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0L_ooool00ol0
003oooooooooo`1_ooooo`00I_ooool01Ol@413ooooooooooooooooo410@00Sooooo00Oo0000oooo
oooooooooooooiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0LOooool00ol0003ooooooooo
o`1`ooooo`00I_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_oo
ool00onHV9So8B4Qonk^kP06ooooo`?o0000LOooool00ol0003oooooooooo`1`ooooo`00I_ooool0
1Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool00_ooool00omgMgOoIVIVoooo
o`05ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0LOooool006Kooooo00Go410@
oooooooooooooooooa0@4009ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo077ooooo001Vooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02_ooool2o`000004okZj^_ooooooV9RHoa0@40Kooooo00?o0000ooooooooool0
Koooool00ol0003oooooooooo`1booooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00[ooooo
00Ko0000oiRHV?l@413o0000ob4Q8Oo<c<`6ooooo`03o`000?oooooooooo06oooooo00?o0000oooo
ooooool0L_ooool007Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1^ooooo`03
o`000?oooooooooo07?ooooo001fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
K_ooool00ol0003oooooooooo`1cooooo`00M_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo06kooooo00?o0000ooooooooool0Loooool007Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo07Cooooo001gooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`1dooooo`00N?ooool00ol0003o
ooooooooo`06ooooo`?o0000K?ooool00ol0003oooooooooo`1eooooo`00N?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0MOooool007Wooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo07Kooooo001i
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`1f
ooooo`00NOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06[ooooo00?o0000oooo
ooooool0Moooool007[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Zooooo`03
o`000?oooooooooo07Oooooo001jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
J_ooool00ol0003oooooooooo`1gooooo`00Noooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo06Wooooo00?o0000ooooooooool0N?ooool007_ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1Yooooo`03o`000?oooooooooo07Sooooo001looooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`1iooooo`00O?ooool00ol0003o
ooooooooo`02ooooo`?o0000J?ooool00ol0003oooooooooo`1iooooo`00O?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0NOooool007gooooo00Go
0000ooooooooooooooooo`00001Yooooo`03o`000?oooooooooo07[ooooo001mooooo`05o`000?oo
ooooooooooooool00000JOooool00ol0003oooooooooo`1jooooo`00O_ooool01?l0003ooooooooo
ool0001Yooooo`03o`000?oooooooooo07[ooooo001nooooo`04o`000?ooooooooooo`0006Sooooo
00?o0000ooooooooool0Noooool007kooooo00Co0000oooooooooooo0000J?ooool00ol0003ooooo
ooooo`1kooooo`00Ooooool00ol0003oooooo`00001Wooooo`03o`000?oooooooooo07cooooo001o
ooooo`03o`000?oooooo000006Oooooo00?o0000ooooooooool0O?ooool0083ooooo0_l0001Woooo
o`03o`000?oooooooooo07cooooo0020ooooo`Co0000I?ooool00ol0003oooooooooo`1mooooo`00
POooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo07gooooo0021ooooo`03o`000?oo
oooooooo06Cooooo00?o0000ooooooooool0OOooool0087ooooo00?o0000ooooooooool0Hoooool0
0ol0003oooooooooo`1nooooo`00POooool2o`0006Cooooo00?o0000ooooooooool0O_ooool0087o
oooo0_l0001Tooooo`03o`000?oooooooooo07kooooo0021ooooo`;o0000Hoooool00ol0003ooooo
ooooo`1oooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o0000
00?o410@ooooooooool01?ooool00ol0003oooooo`00001Rooooo`03o`000?oooooooooo07oooooo
001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooo`00001Rooooo`03o`000?oooooooooo07oooooo001Vooooo`05oa0@4?oo
ooooooooooooool@41002oooool5o`0000Kooooo00?o0000ooooool00000HOooool00ol0003ooooo
ooooo`20ooooo`00I_ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo
00001oooool4o`00063ooooo00?o0000ooooooooool0P?ooool006Kooooo00Go0000oooooooooooo
ooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00Co0000oooooooooooo0000H?ooool0
0ol0003oooooooooo`20ooooo`00I_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMg
olc<c?l000001oooool01?l0003oooooooooool0001Oooooo`03o`000?oooooooooo087ooooo001V
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007ooooo`05o`000?oo
ooooooooooooool00000G_ooool00ol0003oooooooooo`21ooooo`00I_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool01Ol0003ooooooooooooooooo000005ko
oooo00?o0000ooooooooool0POooool0087ooooo00Go0000ooooooooooooooooo`00001Nooooo`03
o`000?oooooooooo087ooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
F_ooool00ol0003oooooooooo`22ooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo05[ooooo00?o0000ooooooooool0P_ooool0087ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1Jooooo`03o`000?oooooooooo08;ooooo0021ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`23ooooo`00POooool3o`0000?o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`23ooooo`00POooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0Poooool0087ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo08Cooooo0021
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`24
ooooo`00POooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Kooooo00?o0000oooo
ooooool0Q?ooool0087ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Eooooo`03
o`000?oooooooooo08Gooooo0021ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
E?ooool00ol0003oooooooooo`25ooooo`00POooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo05Cooooo00?o0000ooooooooool0QOooool0087ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1Dooooo`03o`000?oooooooooo08Gooooo0021ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`26ooooo`00POooool3o`0000Ko
oooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`26ooooo`00POooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0Q_ooool0087ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo08Oooooo0021
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`27
ooooo`00POooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo053ooooo00?o0000oooo
ooooool0Qoooool0087ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1?ooooo`03
o`000?oooooooooo08Sooooo0021ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
C_ooool00ol0003oooooooooo`28ooooo`00POooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo04kooooo00?o0000ooooooooool0R?ooool0087ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`1=ooooo`03o`000?oooooooooo08Wooooo0021ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`29ooooo`00POooool3o`0000Wo
oooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`29ooooo`00POooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0ROooool0087ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo08[ooooo0021
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`2:
ooooo`00POooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04[ooooo00?o0000oooo
ooooool0R_ooool0087ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`18ooooo`03
o`000?oooooooooo08_ooooo0021ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
B?ooool00ol0003oooooooooo`2;ooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo04Sooooo00?o0000ooooooooool0Roooool006Kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo08cooooo001Vooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo08cooooo001Voooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0
000<ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0S?ooool006Kooooo00Go0000
ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0SOooool006Kooooo00Go
410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo08gooooo001Vooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0A?ooool00ol0003oooooooooo`2=ooooo`00I_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo04Cooooo00?o0000ooooooooool0SOooool0087ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo08kooooo0021ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`2>ooooo`00POooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0S_ooool0
087ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo
08oooooo0021ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0@?ooool00ol0003o
ooooooooo`2?ooooo`00POooool3o`0000oooooo00?o0000ooooooooool0@?ooool00ol0003ooooo
ooooo`2?ooooo`00POooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool0T?ooool0087ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo093ooooo0021ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0?_ooool00ol0003oooooooooo`2@ooooo`00POooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool0TOooool0087ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo097ooooo0021ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`2Aooooo`00POooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0T_ooool0
087ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
09;ooooo0021ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0>_ooool00ol0003o
ooooooooo`2Booooo`00POooool3o`0001;ooooo00?o0000ooooooooool0>_ooool00ol0003ooooo
ooooo`2Booooo`00POooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool0Toooool0087ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo09?ooooo0021ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`2Cooooo`00POooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool0U?ooool0087ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo09Cooooo0021ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`2Dooooo`00POooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0UOooool0
087ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
09Gooooo0021ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`2Eooooo`00POooool3o`0001Gooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`2Fooooo`00POooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool0U_ooool0087ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0c
ooooo`03o`000?oooooooooo09Kooooo0021ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`2Gooooo`00POooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool0Uoooool0087ooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo09Oooooo0021ooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`2Hooooo`00I_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0
1_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
V?ooool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RH
oooooonHV9So8B4Q00Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo09Sooooo001Vooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0]oooo
o`03o`000?oooooooooo09Wooooo001Vooooo`05o`000?ooooooooooooooool000002oooool01Olb
<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0000Hooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool0VOooool006Kooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o
0000o`000?o<c<`01_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool0VOooool006Kooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj
^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02_ooooo
00?o0000ooooooooool0V_ooool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02_o
oooo00?o0000ooooooooool0V_ooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool0V_ooool0087ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo09_ooooo0021ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`2Kooooo`00POooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0Voooool0087ooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo09cooooo0021oooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`2Loooo
o`00POooool3o`0001cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`2Looooo`00
POooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
WOooool0087ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo09gooooo0021ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`2Mooooo`00POooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool0W_ooool0087ooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo09kooooo0021ooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`2Nooooo`00POooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0Woooool0087ooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo09oooooo0021oooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`2Poooo
o`00POooool3o`00023ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`2Pooooo`00
POooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
X?ooool0087ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo0:7ooooo0021ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`2Qooooo`00POooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool0XOooool0087ooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo0:;ooooo0021ooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`2Rooooo`00POooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0Xoooool0087ooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo0:Cooooo0021oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`2Toooo
o`00POooool3o`0002Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2Uooooo`00
POooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
Y_ooool0087ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo0:Kooooo0021ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`2Wooooo`00POooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0Z?ooool0087ooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo0:Wooooo0021ooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`2Zooooo`00Moooool4o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo0:_ooooo001iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0:cooooo001iooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0;?ooool3o`0000Cooooo0_l0002_ooooo`00NOooool00ol0003o
ooooooooo`05ooooo`?o0000;_ooool5o`000;7ooooo001iooooo`03o`000?oooooooooo0>cooooo
001iooooo`03o`000?oooooooooo0>cooooo001iooooo`03o`000?oooooooooo0>cooooo001goooo
o`03oeEEEOmVIVKo00000>kooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-12, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.32877 .12361 -18 -4.5 ]
[.32877 .12361 0 4.5 ]
[.32877 .24721 -18 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -18 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -18 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-5)] .18254 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(10)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(15)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.34127 .12361 m
.34752 .12361 L
s
[(0.2)] .32877 .12361 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(0.4)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(0.6)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(0.8)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(1)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0309 m
.34502 .0309 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .09271 m
.34502 .09271 L
s
.34127 .15451 m
.34502 .15451 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .21631 m
.34502 .21631 L
s
.34127 .27812 m
.34502 .27812 L
s
.34127 .30902 m
.34502 .30902 L
s
.34127 .33992 m
.34502 .33992 L
s
.34127 .40172 m
.34502 .40172 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .46353 m
.34502 .46353 L
s
.34127 .52533 m
.34502 .52533 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .58713 m
.34502 .58713 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .00054 m
.03279 .00069 L
.04262 .0009 L
.05288 .00118 L
.06244 .00151 L
.0731 .00198 L
.0828 .00252 L
.094 .0033 L
.10458 .00423 L
.11428 .00529 L
.12455 .00666 L
.14299 .00993 L
.1524 .01209 L
.16253 .01486 L
.18083 .02128 L
.20196 .03149 L
.22205 .04469 L
.24186 .06177 L
.26025 .08184 L
.29938 .14015 L
.34096 .22662 L
.38102 .32954 L
.41958 .43518 L
.43912 .48588 L
.46058 .53543 L
.48123 .5742 L
.49025 .58772 L
.50007 .59978 L
.50527 .60499 L
.51008 .60905 L
.51498 .61242 L
.51958 .61488 L
.52209 .61592 L
.5244 .6167 L
.52696 .61736 L
.5283 .61761 L
.52904 .61773 L
.52972 .61782 L
.53101 .61794 L
.53171 .61799 L
.53238 .61802 L
.53357 .61803 L
.53486 .61799 L
.53554 .61795 L
.53628 .61789 L
.53706 .6178 L
.53779 .6177 L
.5391 .61748 L
.54049 .61717 L
.54307 .61644 L
Mistroke
.54547 .61557 L
.5509 .61288 L
.55608 .60941 L
.56078 .60553 L
.57033 .59551 L
.57931 .58359 L
.59943 .54897 L
.61792 .50904 L
.65746 .40698 L
.69548 .30297 L
.73596 .20302 L
.77492 .12698 L
.7962 .09492 L
.81633 .07046 L
.83459 .05276 L
.85471 .03757 L
.87453 .02632 L
.89555 .01762 L
.91493 .01192 L
.92583 .00948 L
.9358 .00765 L
.95476 .00501 L
.9655 .00391 L
.97548 .00308 L
.97619 .00303 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h/ooooo`05odA4A?l0003o0000oc8b<_oMgMd0G_ooool01Om4A4Co0000o`000?lb<S;ogMgM02[o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^:?ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0Tooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01?ooooo000Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0_ooooo`03ogMgMolb<S;ooooo063ooooo00?oMgMgoc8b<_ooool0:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo02Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL04oooool000oooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Sooooo`Ko00001oooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000;oooool00omgMgOo<S8booooo`1Pooooo`03ogMgMolb<S;ooooo02_o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002[ooooo00?o0000oooo
ooooool01_ooool00omgMgOo<S8booooo`0Vooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000;?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<05kooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00/ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Zooooo`03
o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Xooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@4100;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Aooooo`006_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Wooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01?ooooo000Hooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0/ooooo`Co0000Goooool4o`0002_ooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo00?oEEEEofIVI_l000001Oooool4o`0002Kooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001?ooooo
ool00016o`00013ooooo000Joooooa[o00001Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01_ooool2o`0001Sooooo000Jooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`Oo00002Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`07ooooo`Wo000000?oooooo`000?ooool05oooool003_ooooo1?l00012oooo
o`03o`000?oooooooooo0;gooooo1?l0000Sooooo`00?oooool8o`0003[ooooo00?o0000oooooooo
ool0]_ooool7o`0002Oooooo0017ooooo`?o0000=oooool00ol0003oooooooooo`2cooooo`?o0000
;_ooool004[ooooo0ol0000dooooo`03o`000?oooooooooo0;3ooooo0ol0000aooooo`00COooool2
o`0003;ooooo00?o0000ooooooooool0[Oooool3o`0003Cooooo001?ooooo`;o0000<?ooool00ol0
003oooooooooo`2[ooooo`;o0000=oooool0057ooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`2Yooooo`;o0000>Oooool005;ooooo0_l0000]ooooo`?o0000Z?ooool00ol0003ooooo
ooooo`0iooooo`00E?ooool2o`0002_ooooo00?o0000ooooooooool0Y_ooool2o`0003cooooo001F
ooooo`;o0000:Oooool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo03cooooo001Hoooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0Xoooool2o`0003oooooo001Iooooo`;o
00009_ooool00ol0003oooooooooo`2Rooooo`03o`000?oooooooooo03oooooo001Kooooo`;o0000
9?ooool00ol0003oooooooooo`2Pooooo`;o0000@_ooool005gooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`2Oooooo`03o`000?oooooooooo04;ooooo001Nooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`13ooooo`00Goooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo09cooooo0_l00016ooooo`00H?ooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo09_ooooo00?o0000ooooooooool0A_ooool0067ooooo
00?o0000ooooooooool07Oooool3o`0009[ooooo00?o0000ooooooooool0Aoooool0067ooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`2Iooooo`03o`000?oooooooooo04Sooooo001R
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`19
ooooo`00Hoooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo09Oooooo00?o0000oooo
ooooool0B_ooool006Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`2Gooooo`03
o`000?oooooooooo04[ooooo001Uooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
U_ooool00ol0003oooooooooo`1;ooooo`00I_ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo09Gooooo00?o0000ooooooooool0C?ooool006Oooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`2Dooooo`03o`000?oooooooooo04gooooo001Wooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool0U?ooool00ol0003oooooooooo`1=ooooo`00J?ooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo09?ooooo00?o0000ooooooooool0C_ooool006Wooooo
00?o0000ooooooooool05Oooool3o`0009;ooooo00?o0000ooooooooool0Coooool006Wooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`2Aooooo`03o`000?oooooooooo053ooooo001Z
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`1@
ooooo`00Joooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo093ooooo00?o0000oooo
ooooool0DOooool006_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`2?ooooo`03
o`000?oooooooooo05;ooooo001/ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
Soooool00ol0003oooooooooo`1Booooo`00KOooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo08kooooo00?o0000ooooooooool0Doooool006kooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`2=ooooo`03o`000?oooooooooo05Cooooo001Vooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01?l0003oooooob4Q8OlQ8B44ooooo`Go00001_ooool00ol0003ooooooooo
o`2=ooooo`03o`000?oooooooooo05Cooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?oo
ool00ol0003o8B4Qob4Q8@04ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003ooooo
ooooo`2<ooooo`03o`000?oooooooooo05Gooooo001Vooooo`05oa0@4?ooooooooooooooool@4100
1Oooool00ol0003oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0
S?ooool00ol0003oooooooooo`1Eooooo`00I_ooool01Ol0003ooooooooooooooooo000000Gooooo
00?o0000ooooooooool01Oooool00onHV9So8B4Qonk^kP06ooooo`?o0000Roooool00ol0003ooooo
ooooo`1Fooooo`00I_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
1Oooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo08[ooooo00?o0000ooooooooool0
Eoooool006Kooooo00Go410@oooooooooooooooooa0@4007ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo05Oooooo
001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL01oooool02Ol0003ooooooooooooooooo0000okZj
^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0F?ooool0
06Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`08o`000?oooooooooooiRHV?l@413o0000
ob4Q8Oo<c<`6ooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0F?ooool007Cooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo05Wooooo
001dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0R?ooool00ol0003ooooooooo
o`1Iooooo`00MOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo08Oooooo00?o0000
ooooooooool0F_ooool007Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`26oooo
o`03o`000?oooooooooo05_ooooo001fooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0Q_ooool00ol0003oooooooooo`1Kooooo`00M_ooool00ol0003oooooooooo`08ooooo`?o0000
QOooool00ol0003oooooooooo`1Looooo`00Moooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo08Gooooo00?o0000ooooooooool0G?ooool007Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`24ooooo`03o`000?oooooooooo05gooooo001gooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`1Mooooo`00N?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool0G_ooool007Sooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo05kooooo
001iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0P_ooool00ol0003ooooooooo
o`1Oooooo`00NOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08;ooooo00?o0000
ooooooooool0Goooool007[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`21oooo
o`03o`000?oooooooooo063ooooo001jooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0POooool00ol0003oooooooooo`1Pooooo`00Noooool00ol0003oooooooooo`03ooooo`?o0000
P?ooool00ol0003oooooooooo`1Qooooo`00Noooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo07oooooo00?o0000ooooooooool0H_ooool007cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1oooooo`03o`000?oooooooooo06;ooooo001looooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`1Sooooo`00OOooool01Ol0003o
oooooooooooooooo0000083ooooo00?o0000ooooooooool0Hoooool007gooooo00Go0000oooooooo
ooooooooo`00001oooooo`03o`000?oooooooooo06Cooooo001nooooo`04o`000?ooooooooooo`00
07oooooo00?o0000ooooooooool0I?ooool007kooooo00Co0000oooooooooooo0000O_ooool00ol0
003oooooooooo`1Uooooo`00O_ooool01?l0003oooooooooool0001nooooo`03o`000?oooooooooo
06Gooooo001oooooo`03o`000?oooooo000007kooooo00?o0000ooooooooool0IOooool007oooooo
00?o0000ooooool000000_l0001kooooo`03o`000?oooooooooo06Kooooo0020ooooo`;o0000OOoo
ool00ol0003oooooooooo`1Vooooo`00P?ooool2o`0007cooooo00?o0000ooooooooool0Ioooool0
087ooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`1Wooooo`00POooool00ol0003o
ooooooooo`1jooooo`03o`000?oooooooooo06Oooooo0021ooooo`;o0000N_ooool00ol0003ooooo
ooooo`1Xooooo`00POooool2o`0007[ooooo00?o0000ooooooooool0J?ooool006Kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo0_l0
001iooooo`03o`000?oooooooooo06Wooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooo`00001hooooo`03o`000?oo
oooooooo06Wooooo001Vooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo00?o
0000ooooool00000N?ooool00ol0003oooooooooo`1Yooooo`00I_ooool01Ol0003ooooooooooooo
oooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool4o`0007Kooooo00?o0000ooooooooool0
J_ooool006Kooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oo
oooo00Co0000oooooooooooo0000M_ooool00ol0003oooooooooo`1Zooooo`00I_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool01?l0003oooooooooool0001e
ooooo`03o`000?oooooooooo06_ooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0oo^k^koA4A4o`000007ooooo`05o`000?ooooooooooooooool00000M?ooool00ol0003ooooooooo
o`1[ooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_oo
ool01Ol0003ooooooooooooooooo000007Cooooo00?o0000ooooooooool0Joooool0087ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo06cooooo0021
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1/
ooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo073ooooo00?o0000oooo
ooooool0K?ooool0087ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1^ooooo`03
o`000?oooooooooo06gooooo0021ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
K_ooool00ol0003oooooooooo`1]ooooo`00POooool3o`0000Cooooo00?o0000ooooooooool0K?oo
ool00ol0003oooooooooo`1^ooooo`00POooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06cooooo00?o0000ooooooooool0K_ooool0087ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`1/ooooo`03o`000?oooooooooo06kooooo0021ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`1_ooooo`00POooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0Koooool0087ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo073ooooo0021
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`1`
ooooo`00POooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06Sooooo00?o0000oooo
ooooool0L?ooool0087ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Vooooo`03
o`000?oooooooooo077ooooo0021ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
I_ooool00ol0003oooooooooo`1aooooo`00POooool3o`0000Oooooo00?o0000ooooooooool0IOoo
ool00ol0003oooooooooo`1booooo`00POooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo06Cooooo00?o0000ooooooooool0L_ooool0087ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`1Tooooo`03o`000?oooooooooo07;ooooo0021ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1cooooo`00POooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0Loooool0087ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo07?ooooo0021
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1d
ooooo`00POooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo063ooooo00?o0000oooo
ooooool0M?ooool0087ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Oooooo`03
o`000?oooooooooo07Cooooo0021ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
G_ooool00ol0003oooooooooo`1eooooo`00POooool3o`0000_ooooo00?o0000ooooooooool0G_oo
ool00ol0003oooooooooo`1eooooo`00POooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo05cooooo00?o0000ooooooooool0M_ooool0087ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`1Looooo`03o`000?oooooooooo07Kooooo0021ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`1fooooo`00POooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool0Moooool0087ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo07Oooooo0021
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`1g
ooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o
0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05Sooooo00?o
0000ooooooooool0N?ooool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`1Hooooo`03o`000?oooooooooo07Sooooo001Vooooo`05oa0@4?ooooooooooooooool@4100
2oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`1Gooooo`03o`000?oooooooooo07Sooooo001Vooooo`05o`000?ooooooooooooooool0
00002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0000?ooooo`03o`000?oooooooooo
05Kooooo00?o0000ooooooooool0NOooool006Kooooo00Go0000ooooooooooooooooo`00000;oooo
o`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo05Kooooo00?o0000ooooooooool0NOooool006Kooooo00Go410@oooooooooooooooooa0@400;
ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1D
ooooo`03o`000?oooooooooo07[ooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
0ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0E?ooool0
0ol0003oooooooooo`1jooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<
odA4A?l0003o410@1_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo05?ooooo00?o
0000ooooooooool0N_ooool0087ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1B
ooooo`03o`000?oooooooooo07_ooooo0021ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0D_ooool00ol0003oooooooooo`1kooooo`00POooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo057ooooo00?o0000ooooooooool0Noooool0087ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo07cooooo0021ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`1looooo`00POooool3
o`0001?ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`1looooo`00POooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0OOooool0087o
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo07go
oooo0021ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0C?ooool00ol0003ooooo
ooooo`1nooooo`00POooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04cooooo00?o
0000ooooooooool0O_ooool0087ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1;
ooooo`03o`000?oooooooooo07kooooo0021ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0B_ooool00ol0003oooooooooo`1oooooo`00POooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo04[ooooo00?o0000ooooooooool0Ooooool0087ooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo07oooooo0021ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`20ooooo`00POooool3
o`0001Kooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`20ooooo`00POooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0POooool0087o
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo087o
oooo0021ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`21ooooo`00POooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04Cooooo00?o
0000ooooooooool0P_ooool0087ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`14
ooooo`03o`000?oooooooooo08;ooooo0021ooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool0@_ooool00ol0003oooooooooo`23ooooo`00POooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo04;ooooo00?o0000ooooooooool0Poooool0087ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo08?ooooo0021ooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`24ooooo`00POooool3
o`0001[ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`24ooooo`00POooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0Q?ooool0087o
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo08Go
oooo0021ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`25ooooo`00POooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo03cooooo00?o
0000ooooooooool0Q_ooool0087ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0l
ooooo`03o`000?oooooooooo08Kooooo0021ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool0??ooool00ol0003oooooooooo`26ooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0Qoooool006Kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo08Oooooo001V
ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo08Sooooo
001Vooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Ko
oooo0ol0000Nooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0R?ooool006Kooooo
00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0R?ooool006Ko
oooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0ROooool0
06Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_oo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0ROoo
ool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0
1_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
ROooool0087ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo08[ooooo0021ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`2:ooooo`00POooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool0Roooool0087ooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo08_ooooo0021ooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`2<ooooo`00POooool3o`0002;ooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`2<ooooo`00POooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0SOooool0087ooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo08gooooo0021ooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`2>ooooo`00
POooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
S_ooool0087ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo08oooooo0021ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`2?ooooo`00POooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool0T?ooool0087ooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo093ooooo0021ooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`2Aooooo`00POooool3o`0002Sooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`2Aooooo`00POooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0T_ooool0087ooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo09?ooooo0021ooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`2Cooooo`00
POooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
U?ooool0087ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo09Cooooo0021ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`2Eooooo`00POooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool0U_ooool0087ooooo00?o0000ooooooooool0;?ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo09Kooooo0021ooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`2Gooooo`00POooool3o`0002kooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`2Gooooo`00POooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0V?ooool0087ooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo09Sooooo0021ooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool05?ooool2o`0009_ooooo0021ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`2Kooooo`00POoo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0W?oo
ool0087ooooo00?o0000ooooooooool0<_ooool2o`00013ooooo00?o0000ooooooooool0WOooool0
07Oooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo03Cooooo0_l0000<oooo
o`;o0000X?ooool007Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0fooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0X?ooool007Wooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0gooooo`?o00001Oooool2o`000:?ooooo001iooooo`03o`000?oo
oooooooo00Gooooo0ol0000jooooo`Go0000YOooool007Wooooo00?o0000ooooooooool0k?ooool0
07Wooooo00?o0000ooooooooool0k?ooool007Wooooo00?o0000ooooooooool0k?ooool007Oooooo
00?oEEEEofIVI_l00000k_ooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-12, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.32877 .12361 -18 -4.5 ]
[.32877 .12361 0 4.5 ]
[.32877 .24721 -18 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -18 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -18 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-5)] .18254 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(10)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(15)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.34127 .12361 m
.34752 .12361 L
s
[(0.2)] .32877 .12361 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(0.4)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(0.6)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(0.8)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(1)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0309 m
.34502 .0309 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .09271 m
.34502 .09271 L
s
.34127 .15451 m
.34502 .15451 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .21631 m
.34502 .21631 L
s
.34127 .27812 m
.34502 .27812 L
s
.34127 .30902 m
.34502 .30902 L
s
.34127 .33992 m
.34502 .33992 L
s
.34127 .40172 m
.34502 .40172 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .46353 m
.34502 .46353 L
s
.34127 .52533 m
.34502 .52533 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .58713 m
.34502 .58713 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .00243 m
.04262 .00352 L
.06244 .00514 L
.08255 .00742 L
.10458 .01092 L
.12415 .01516 L
.14509 .02121 L
.16639 .02936 L
.18653 .03933 L
.22495 .06595 L
.24479 .08433 L
.26581 .10774 L
.30365 .16079 L
.34394 .23256 L
.38271 .31377 L
.42393 .40633 L
.46364 .49164 L
.50184 .55948 L
.52151 .58575 L
.53243 .59722 L
.54248 .60566 L
.55277 .61208 L
.55818 .61454 L
.56093 .61554 L
.56389 .61643 L
.56649 .61705 L
.56887 .61749 L
.57001 .61765 L
.57125 .6178 L
.57242 .6179 L
.57351 .61797 L
.57476 .61802 L
.57594 .61803 L
.57723 .61801 L
.57796 .61798 L
.57863 .61795 L
.57989 .61785 L
.58127 .6177 L
.58272 .6175 L
.58406 .61728 L
.58911 .61606 L
.59196 .61512 L
.59459 .6141 L
.60452 .60887 L
.61355 .60227 L
.62311 .59344 L
.64268 .56984 L
.661 .54173 L
.69982 .46741 L
.7411 .37625 L
Mistroke
.78086 .28792 L
.8191 .21084 L
.8598 .14276 L
.89898 .09265 L
.919 .07271 L
.94062 .05506 L
.97619 .03357 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h/ooooo`05odA4A?l0003o0000oc8b<_oMgMd0G_ooool01Om4A4Co0000o`000?lb<S;ogMgM02[o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^:?ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0Tooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01?ooooo000Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0_ooooo`03ogMgMolb<S;ooooo063ooooo00?oMgMgoc8b<_ooool0:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo02Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL04oooool000oooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Sooooo`Ko00001oooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000;oooool00omgMgOo<S8booooo`1Pooooo`03ogMgMolb<S;ooooo02_o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002[ooooo00?o0000oooo
ooooool01_ooool00omgMgOo<S8booooo`0Vooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000;?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<05kooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00/ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Zooooo`03
o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Xooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@4100;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Aooooo`006_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Wooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01?ooooo000Hooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0/ooooo`Co0000Goooool4o`0002_ooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo00?oEEEEofIVI_l000001Oooool4o`0002Kooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001?ooooo
ool00016o`00013ooooo000Jooooo`Co00001oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool05_ooool001[ooooo00Co0000oooooooooooooooo3Ol0
0004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05_ooool002_ooooo1ol0001?
ooooo`03o`000?oooooooooo0>Cooooo000booooo`Oo0000B?ooool00ol0003oooooooooo`3Toooo
o`00>Oooool5o`0004?ooooo00?o0000ooooooooool0i?ooool003kooooo0ol00010ooooo`03o`00
0?oooooooooo0>Cooooo0011ooooo`?o0000?Oooool00ol0003oooooooooo`3Tooooo`00A?ooool3
o`0003[ooooo00?o0000ooooooooool0i?ooool004Oooooo0_l0000hooooo`03o`000?oooooooooo
0>Cooooo0019ooooo`;o0000=_ooool3o`000>Cooooo001;ooooo`;o0000=?ooool00ol0003ooooo
ooooo`3:ooooo`;o00006?ooool004gooooo0_l0000booooo`03o`000?oooooooooo0<Wooooo00?o
0000ooooooooool06?ooool004oooooo0_l0000`ooooo`03o`000?oooooooooo0<Oooooo0_l0000K
ooooo`00DOooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo0<Gooooo0_l0000Moooo
o`00D_ooool2o`0002gooooo00?o0000ooooooooool0a?ooool00ol0003oooooooooo`0Mooooo`00
E?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo0<;ooooo0_l0000Pooooo`00EOoo
ool2o`0002[ooooo00?o0000ooooooooool0`Oooool00ol0003oooooooooo`0Pooooo`00Eoooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo0;oooooo0_l0000Sooooo`00F?ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo0;kooooo00?o0000ooooooooool08oooool005Wo
oooo0_l0000Vooooo`?o0000_Oooool00ol0003oooooooooo`0Tooooo`00Foooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo0;cooooo00?o0000ooooooooool09Oooool005cooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`2kooooo`03o`000?oooooooooo02Kooooo001M
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`0W
ooooo`00G_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0;Sooooo0_l0000Zoooo
o`00Goooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo0;Oooooo00?o0000oooooooo
ool0:_ooool0063ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`2fooooo`03o`00
0?oooooooooo02_ooooo001Qooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0]Ooo
ool00ol0003oooooooooo`0/ooooo`00H_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo0;Cooooo00?o0000ooooooooool0;Oooool006?ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`2cooooo`03o`000?oooooooooo02kooooo001Tooooo`03o`000?oooooooooo01[o
oooo0ol0002booooo`03o`000?oooooooooo02oooooo001Uooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0_ooooo`00I_ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool0<?ooool006Oooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`2`ooooo`03o`000?oooooooooo037ooooo001Xoooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0[oooool00ol0003oooooooooo`0boooo
o`00JOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0:oooooo00?o0000oooooooo
ool0<_ooool006Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`2^ooooo`03o`00
0?oooooooooo03?ooooo001Zooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0[Ooo
ool00ol0003oooooooooo`0dooooo`00I_ooool01_o^k^ko<S8bo`000?lb<S;ok^k^o`0000Cooooo
0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`2/ooooo`03o`000?oooooooooo03Gooooo
001Vooooo`06ogMgMonHV9SooooooiRHV?mgMgOo00001?ooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A006ooooo`03o`000?oooooooooo0:_ooooo00?o0000ooooooooool0=_ooool006Ko
oooo00Oo410@oooooooooooooooooa0@4?oooooo000000[ooooo00?oV9RHob4Q8Oo^k^h01oooool0
0ol0003oooooooooo`2[ooooo`03o`000?oooooooooo03Kooooo001Vooooo`05o`000?oooooooooo
ooooool000000_ooool00ol0003oooooooooo`08ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0002Z
ooooo`03o`000?oooooooooo03Oooooo001Vooooo`05o`000?ooooooooooooooool000000_ooool0
0ol0003oooooooooo`09ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0ZOooool0
0ol0003oooooooooo`0hooooo`00I_ooool01Ol@413ooooooooooooooooo410@00?ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0:Sooooo00?o0000
ooooooooool0>Oooool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03o`000?oooooo
oooo00Cooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0:Sooooo00?o
0000ooooooooool0>Oooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`03o`000?oo
oooooooo00Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0:Oooooo
00?o0000ooooooooool0>_ooool0073ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`2Vooooo`03o`000?oooooooooo03_ooooo001aooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0YOooool00ol0003oooooooooo`0looooo`00LOooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool0??ooool007;ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`2Tooooo`03o`000?oooooooooo03gooooo001cooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0Y?ooool00ol0003oooooooooo`0mooooo`00Looo
ool00ol0003oooooooooo`0;ooooo`?o0000Xoooool00ol0003oooooooooo`0nooooo`00M?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0:;ooooo00?o0000ooooooooool0?oooool0
07Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Rooooo`03o`000?oooooooooo
03oooooo001eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0XOooool00ol0003o
ooooooooo`10ooooo`00M_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0:7ooooo
00?o0000ooooooooool0@?ooool007Kooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`2Pooooo`03o`000?oooooooooo047ooooo001gooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0Woooool00ol0003oooooooooo`12ooooo`00N?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo09oooooo00?o0000ooooooooool0@_ooool007Sooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo04?ooooo001iooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`13ooooo`00NOoo
ool00ol0003oooooooooo`05ooooo`?o0000WOooool00ol0003oooooooooo`14ooooo`00N_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo09cooooo00?o0000ooooooooool0AOooool0
07[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo
04Gooooo001kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Voooool00ol0003o
ooooooooo`16ooooo`00O?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo09_ooooo
00?o0000ooooooooool0A_ooool007cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`2Jooooo`03o`000?oooooooooo04Oooooo001mooooo`05o`000?ooooooooooooooool00000Vooo
ool00ol0003oooooooooo`18ooooo`00OOooool01Ol0003ooooooooooooooooo000009_ooooo00?o
0000ooooooooool0B?ooool007kooooo00Co0000oooooooooooo0000V_ooool00ol0003ooooooooo
o`19ooooo`00O_ooool01?l0003oooooooooool0002Jooooo`03o`000?oooooooooo04Wooooo001o
ooooo`03o`000?oooooo000000;o0000Uoooool00ol0003oooooooooo`1:ooooo`00Ooooool00ol0
003oooooo`00002Iooooo`03o`000?oooooooooo04[ooooo0020ooooo`;o0000V?ooool00ol0003o
ooooooooo`1;ooooo`00POooool00ol0003oooooooooo`2Fooooo`03o`000?oooooooooo04_ooooo
0021ooooo`03o`000?oooooooooo09Gooooo00?o0000ooooooooool0C?ooool0087ooooo0_l0002F
ooooo`03o`000?oooooooooo04cooooo0021ooooo`;o0000UOooool00ol0003oooooooooo`1=oooo
o`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@oooo
ooooool01?ooool00ol0003oooooo`00002Dooooo`03o`000?oooooooooo04gooooo001Vooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooo`00002Cooooo`03o`000?oooooooooo04kooooo001Vooooo`05oa0@4?oooooooooooooo
ool@41002oooool5o`0000Kooooo00Co0000oooooooooooo0000T_ooool00ol0003oooooooooo`1>
ooooo`00I_ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001ooo
ool4o`00097ooooo00?o0000ooooooooool0Coooool006Kooooo00Go0000ooooooooooooooooo`00
000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00Go0000ooooooooooooooooo`00002@ooooo`03
o`000?oooooooooo04oooooo001Vooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOo
c<c<o`000007ooooo`05o`000?ooooooooooooooool00000T?ooool00ol0003oooooooooo`1?oooo
o`00I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool0D?ooool006Ko
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo053ooooo0021ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`1Aooooo`00
POooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08[ooooo00?o0000ooooooooool0
DOooool0087ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`28ooooo`03o`000?oo
oooooooo05;ooooo0021ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0R?ooool0
0ol0003oooooooooo`1Booooo`00POooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
08Kooooo00?o0000ooooooooool0Doooool0087ooooo0ol00005ooooo`03o`000?oooooooooo08Ko
oooo00?o0000ooooooooool0Doooool0087ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`24ooooo`03o`000?oooooooooo05Cooooo0021ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0Q?ooool00ol0003oooooooooo`1Dooooo`00POooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0EOooool0087ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo05Gooooo0021ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`1Fooooo`00
POooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool0
E_ooool0087ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1nooooo`03o`000?oo
oooooooo05Oooooo0021ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0O_ooool0
0ol0003oooooooooo`1Gooooo`00POooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
07cooooo00?o0000ooooooooool0F?ooool0087ooooo0ol0000:ooooo`03o`000?oooooooooo07co
oooo00?o0000ooooooooool0F?ooool0087ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`1kooooo`03o`000?oooooooooo05Sooooo0021ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0N_ooool00ol0003oooooooooo`1Iooooo`00POooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0FOooool0087ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo05[ooooo0021ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`1Jooooo`00
POooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool0
Foooool0087ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1fooooo`03o`000?oo
oooooooo05_ooooo0021ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0M?ooool0
0ol0003oooooooooo`1Looooo`00POooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
07Cooooo00?o0000ooooooooool0G?ooool0087ooooo0ol0000?ooooo`03o`000?oooooooooo07;o
oooo00?o0000ooooooooool0GOooool0087ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`1booooo`03o`000?oooooooooo05gooooo0021ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0L?ooool00ol0003oooooooooo`1Nooooo`00POooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0G_ooool0087ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo05oooooo0021ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`1Oooooo`00
POooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0
Goooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1/ooooo`03
o`000?oooooooooo063ooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool0K?ooool00ol0003oooooooooo`1Pooooo`00I_ooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool0J_ooool00ol0003oooooooooo`1Qooooo`00I_ooool01Ol0003ooooooooooooooooo
000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o00004oooool00ol0003ooooooooo
o`1Zooooo`03o`000?oooooooooo067ooooo001Vooooo`05o`000?ooooooooooooooool000002ooo
ool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`1Yooooo`03o`000?oooooooooo06;ooooo001Vooooo`05oa0@4?ooooooooooooooool@4100
2oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
J?ooool00ol0003oooooooooo`1Rooooo`00I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo
00?o0000ooooooooool0Hoooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<
c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Vooooo`03
o`000?oooooooooo06?ooooo0021ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
IOooool00ol0003oooooooooo`1Tooooo`00POooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo06Cooooo00?o0000ooooooooool0I?ooool0087ooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`1Tooooo`03o`000?oooooooooo06Cooooo0021ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`1Uooooo`00POooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0IOooool0087ooooo
0ol0000Gooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0I_ooool0087ooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo06Kooooo0021
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`1W
ooooo`00POooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo05kooooo00?o0000oooo
ooooool0Ioooool0087ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1Nooooo`03
o`000?oooooooooo06Oooooo0021ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
G?ooool00ol0003oooooooooo`1Xooooo`00POooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo05cooooo00?o0000ooooooooool0J?ooool0087ooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`1Jooooo`03o`000?oooooooooo06Wooooo0021ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`1Yooooo`00POooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0J_ooool0087ooooo
0ol0000Looooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0J_ooool0087ooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo06[ooooo0021
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`1[
ooooo`00POooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05Kooooo00?o0000oooo
ooooool0Joooool0087ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Dooooo`03
o`000?oooooooooo06cooooo0021ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
E?ooool00ol0003oooooooooo`1/ooooo`00POooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo05;ooooo00?o0000ooooooooool0KOooool0087ooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`1Booooo`03o`000?oooooooooo06gooooo0021ooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`1]ooooo`00POooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0K_ooool0087ooooo
0ol0000Qooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0K_ooool0087ooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo06oooooo0021
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`1_
ooooo`00POooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo04cooooo00?o0000oooo
ooooool0L?ooool0087ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1<ooooo`03
o`000?oooooooooo073ooooo0021ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
B_ooool00ol0003oooooooooo`1aooooo`00POooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo04[ooooo00?o0000ooooooooool0LOooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo07;ooooo001Vooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1cooooo`00
I_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`1coooo
o`00I_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06
ooooo`?o00009Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo07Cooooo001Voooo
o`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo07Cooooo001V
ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo07Gooooo
001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Ko
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo07Go
oooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY
00Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo
07Kooooo0021ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0@?ooool00ol0003o
ooooooooo`1fooooo`00POooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool0Moooool0087ooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo07Oooooo0021ooooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool0??ooool00ol0003oooooooooo`1hooooo`00POooool00ol0003oooooooooo`0Zoooo
o`03o`000?oooooooooo03cooooo00?o0000ooooooooool0N?ooool0087ooooo0ol0000[ooooo`03
o`000?oooooooooo03[ooooo00?o0000ooooooooool0NOooool0087ooooo00?o0000ooooooooool0
:oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo07[ooooo0021ooooo`03o`000?oo
oooooooo02cooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1jooooo`00POooool0
0ol0003oooooooooo`0/ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0Noooool0
087ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
07_ooooo0021ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`1looooo`00POooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool0O?ooool0087ooooo00?o0000ooooooooool0;oooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo07gooooo0021ooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`1nooooo`00POooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo033ooooo00?o0000ooooooooool0O_ooool0087ooooo0ol0000`ooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool0Ooooool0087ooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo083ooooo0021ooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`20ooooo`00POooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0POooool0
087ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
08;ooooo0021ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`22ooooo`00POooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool0Poooool0087ooooo00?o0000ooooooooool0=_ooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo08Cooooo0021ooooo`03o`000?oooooooooo03Oooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`25ooooo`00POooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool0QOooool0087ooooo0ol0000hooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0Q_ooool0087ooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo08Oooooo0021ooooo`03o`000?oo
oooooooo03[ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`28ooooo`00POooool0
0ol0003oooooooooo`0kooooo`;o00006oooool00ol0003oooooooooo`29ooooo`00POooool00ol0
003oooooooooo`0mooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0R_ooool0087o
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Dooooo`;o0000SOooool0087ooooo
00?o0000ooooooooool0?oooool2o`0001?ooooo00?o0000ooooooooool0SOooool007Oooooo1?l0
00000ol@413oooooooooo`03ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool03_oo
ool2o`00093ooooo001iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0@_ooool2
o`0000cooooo0_l0002Booooo`00NOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
04Cooooo0_l00007ooooo`?o0000U?ooool007Wooooo00?o0000ooooooooool01Oooool3o`0004Ko
oooo1ol0002Gooooo`00NOooool00ol0003oooooooooo`3/ooooo`00NOooool00ol0003ooooooooo
o`3/ooooo`00NOooool00ol0003oooooooooo`3/ooooo`00Moooool00omEEEGoIVIVo`00003^oooo
o`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-12, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.32877 .12361 -18 -4.5 ]
[.32877 .12361 0 4.5 ]
[.32877 .24721 -18 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -18 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -18 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-5)] .18254 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(10)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(15)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.34127 .12361 m
.34752 .12361 L
s
[(0.2)] .32877 .12361 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(0.4)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(0.6)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(0.8)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(1)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0309 m
.34502 .0309 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .09271 m
.34502 .09271 L
s
.34127 .15451 m
.34502 .15451 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .21631 m
.34502 .21631 L
s
.34127 .27812 m
.34502 .27812 L
s
.34127 .30902 m
.34502 .30902 L
s
.34127 .33992 m
.34502 .33992 L
s
.34127 .40172 m
.34502 .40172 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .46353 m
.34502 .46353 L
s
.34127 .52533 m
.34502 .52533 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .58713 m
.34502 .58713 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .00726 m
.04262 .00954 L
.06244 .01259 L
.08255 .01653 L
.10458 .02202 L
.12579 .0287 L
.14509 .03617 L
.18408 .05616 L
.22401 .08482 L
.26243 .12156 L
.30329 .17138 L
.34264 .22955 L
.38048 .29339 L
.42077 .36668 L
.45954 .43778 L
.50076 .50776 L
.52135 .53838 L
.54047 .56323 L
.56014 .58453 L
.57866 .60014 L
.58852 .60654 L
.59919 .61191 L
.6039 .61376 L
.60888 .61535 L
.61313 .61642 L
.61779 .61728 L
.6203 .61761 L
.62172 .61776 L
.62303 .61786 L
.62418 .61794 L
.62544 .61799 L
.62676 .61803 L
.628 .61803 L
.62914 .61802 L
.63033 .61798 L
.63136 .61794 L
.63248 .61787 L
.63368 .61777 L
.63498 .61764 L
.6373 .61735 L
.64001 .61691 L
.64294 .61631 L
.64826 .61488 L
.65344 .6131 L
.65822 .6111 L
.67698 .60007 L
.68764 .59163 L
.69762 .58238 L
.73644 .53523 L
.77772 .46996 L
Mistroke
.81748 .39867 L
.85573 .32818 L
.89642 .25656 L
.93561 .19484 L
.97619 .14086 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h/ooooo`05odA4A?l0003o0000oc8b<_oMgMd0G_ooool01Om4A4Co0000o`000?lb<S;ogMgM02[o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^:?ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0Tooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01?ooooo000Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0_ooooo`03ogMgMolb<S;ooooo063ooooo00?oMgMgoc8b<_ooool0:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo02Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL04oooool000oooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Sooooo`Ko00001oooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000;oooool00omgMgOo<S8booooo`1Pooooo`03ogMgMolb<S;ooooo02_o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002[ooooo00?o0000oooo
ooooool01_ooool00omgMgOo<S8booooo`0Vooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000;?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<05kooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00/ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Zooooo`03
o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Xooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@4100;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Aooooo`006_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Wooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01?ooooo000Hooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0/ooooo`Co0000Goooool4o`0002_ooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo00?oEEEEofIVI_l000001Oooool4o`0002Kooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001?ooooo
ool00016o`00013ooooo000Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo000Jooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01Kooooo000Jooooo`Co0000Hoooool00ol0003oooooooooo`3Tooooo`007_ooool7o`0005co
oooo00?o0000ooooooooool0i?ooool002Gooooo1_l0001Fooooo`03o`000?oooooooooo0>Cooooo
000[ooooo`Go0000DOooool00ol0003oooooooooo`3Tooooo`00<?ooool4o`0004gooooo00?o0000
ooooooooool0i?ooool003Cooooo1?l00019ooooo`03o`000?oooooooooo0>Cooooo000hooooo`?o
0000A_ooool00ol0003oooooooooo`3Tooooo`00>oooool3o`0004?ooooo0ol0003Tooooo`00?_oo
ool3o`00043ooooo00?o0000ooooooooool0i?ooool0047ooooo0ol0000mooooo`03o`000?oooooo
oooo0>Cooooo0014ooooo`;o0000>oooool00ol0003oooooooooo`3Tooooo`00A_ooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo0>Cooooo0017ooooo`;o0000>?ooool00ol0003ooooo
ooooo`3Tooooo`00BOooool2o`0003Kooooo00?o0000ooooooooool0i?ooool004_ooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`3Tooooo`00C?ooool2o`0003?ooooo00?o0000oooo
ooooool0i?ooool004kooooo0_l0000aooooo`03o`000?oooooooooo0>Cooooo001@ooooo`03o`00
0?oooooooooo02kooooo0ol0003Tooooo`00DOooool2o`0002kooooo00?o0000ooooooooool0i?oo
ool005?ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`3Tooooo`00E?ooool2o`00
02_ooooo00?o0000ooooooooool0i?ooool005Kooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`3Tooooo`00Eoooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo0>Cooooo
001Hooooo`;o00009oooool00ol0003oooooooooo`3Tooooo`00F_ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo0>Cooooo001Kooooo`;o00009?ooool00ol0003oooooooooo`3Toooo
o`00GOooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo0>Cooooo001Nooooo`03o`00
0?oooooooooo023ooooo0ol0003Tooooo`00Goooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo0>Cooooo001Pooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0i?ooool0
067ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`3Tooooo`00H_ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo0>Cooooo001Sooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0i?ooool006Cooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`3Tooooo`00IOooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo0>Cooooo001Voooo
o`05o`000?lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooo
oooo0>Cooooo001Vooooo`05ogMgMol0003ooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0>Cooooo001Vooooo`05oa0@4?oooooo
0000ooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0>Cooooo001V
ooooo`05o`000?oooooo0000ooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`?o0000i?oo
ool006Kooooo00?o0000ooooooooool00_l0000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000
ooooooooool0i?ooool006Kooooo00Go410@ooooooooooooooooo`00000?ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0i?ooool006Kooooo00KoMgMgoiRHV?ooooooV9RHogMgMol0
000:ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`3Tooooo`00I_oo
ool01oo^k^ko<S8bo`000?lb<S;ok^k^ooooool000002Oooool01OnHV9So410@o`000?lQ8B7oc<c<
00Kooooo00?o0000ooooooooool0i?ooool006cooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`3;ooooo`03o`000?oooooooooo01Kooooo001]ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0boooool00ol0003oooooooooo`0Fooooo`00K_ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo0<[ooooo00?o0000ooooooooool05oooool006oooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`39ooooo`03o`000?oooooooooo01Sooooo001`oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool0b?ooool00ol0003oooooooooo`0Ioooo
o`00LOooool00ol0003oooooooooo`0=ooooo`?o0000b?ooool00ol0003oooooooooo`0Iooooo`00
LOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0<Oooooo00?o0000ooooooooool0
6_ooool007;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`36ooooo`03o`000?oo
oooooooo01_ooooo001cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0a_ooool0
0ol0003oooooooooo`0Kooooo`00M?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
0<Gooooo00?o0000ooooooooool07?ooool007Gooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`34ooooo`03o`000?oooooooooo01gooooo001eooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0`oooool00ol0003oooooooooo`0Nooooo`00M_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo0<?ooooo00?o0000ooooooooool07_ooool007Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`32ooooo`03o`000?oooooooooo01oooooo001goooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0`Oooool00ol0003oooooooooo`0Poooo
o`00N?ooool00ol0003oooooooooo`06ooooo`?o0000`Oooool00ol0003oooooooooo`0Pooooo`00
NOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0<3ooooo00?o0000ooooooooool0
8Oooool007Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2oooooo`03o`000?oo
oooooooo02;ooooo001jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0__ooool0
0ol0003oooooooooo`0Sooooo`00Noooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
0;kooooo00?o0000ooooooooool08oooool007cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`2mooooo`03o`000?oooooooooo02Cooooo001looooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0_?ooool00ol0003oooooooooo`0Uooooo`00OOooool01Ol0003ooooooooo
oooooooo00000;kooooo00?o0000ooooooooool09Oooool007kooooo00Co0000oooooooooooo0000
_Oooool00ol0003oooooooooo`0Vooooo`00O_ooool01?l0003oooooooooool0002looooo`03o`00
0?oooooooooo02Oooooo001oooooo`03o`000?oooooo000000;o0000^_ooool00ol0003ooooooooo
o`0Wooooo`00P?ooool2o`000;_ooooo00?o0000ooooooooool0:?ooool0083ooooo0_l0002joooo
o`03o`000?oooooooooo02Wooooo0021ooooo`03o`000?oooooooooo0;Sooooo00?o0000oooooooo
ool0:Oooool0087ooooo0_l0002hooooo`03o`000?oooooooooo02[ooooo0021ooooo`;o0000^?oo
ool00ol0003oooooooooo`0Zooooo`00POooool00ol0003oooooo`00002fooooo`03o`000?oooooo
oooo02_ooooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l00000
0ol@413oooooooooo`04ooooo`03o`000?oooooo00000;Gooooo00?o0000ooooooooool0;?ooool0
06Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05
ooooo`04o`000?ooooooooooo`000;Cooooo00?o0000ooooooooool0;?ooool006Kooooo00Go410@
oooooooooooooooooa0@400;ooooo`Go00001_ooool01Ol0003ooooooooooooooooo00000;;ooooo
00?o0000ooooooooool0;Oooool006Kooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4
A?oMgMgoooooo`0000Oooooo0ol000000ooooooo0000ooooo`2`ooooo`03o`000?oooooooooo02ko
oooo001Vooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0[_ooool00ol0003oooooooooo`0^oooo
o`00I_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo0:gooooo00?o0000ooooooooool0;oooool006Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`2[ooooo`03o`000?oooooooooo033ooooo001Vooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0Zoooool00ol0003oooooooooo`0`ooooo`00POooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool0<Oooool0087ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo037ooooo
0021ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Yoooool00ol0003ooooooooo
o`0booooo`00POooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0:Gooooo00?o0000
ooooooooool0<oooool0087ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2Uoooo
o`03o`000?oooooooooo03?ooooo0021ooooo`?o00001oooool00ol0003oooooooooo`2Sooooo`03
o`000?oooooooooo03Cooooo0021ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
Xoooool00ol0003oooooooooo`0dooooo`00POooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo0:7ooooo00?o0000ooooooooool0=Oooool0087ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`2Pooooo`03o`000?oooooooooo03Gooooo0021ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0Woooool00ol0003oooooooooo`0fooooo`00POooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool0=oooool0087ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo03Oooooo
0021ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Voooool00ol0003ooooooooo
o`0hooooo`00POooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo09_ooooo00?o0000
ooooooooool0>?ooool0087ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`2Ioooo
o`03o`000?oooooooooo03Wooooo0021ooooo`?o00003Oooool00ol0003oooooooooo`2Hooooo`03
o`000?oooooooooo03Wooooo0021ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
Uoooool00ol0003oooooooooo`0jooooo`00POooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo09Kooooo00?o0000ooooooooool0>_ooool0087ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`2Eooooo`03o`000?oooooooooo03_ooooo0021ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0Toooool00ol0003oooooooooo`0looooo`00POooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo09?ooooo00?o0000ooooooooool0??ooool0087ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`2Aooooo`03o`000?oooooooooo03gooooo
0021ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0T?ooool00ol0003ooooooooo
o`0mooooo`00POooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo08oooooo00?o0000
ooooooooool0?_ooool0087ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`2>oooo
o`03o`000?oooooooooo03kooooo0021ooooo`?o00004_ooool00ol0003oooooooooo`2=ooooo`03
o`000?oooooooooo03oooooo0021ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
S?ooool00ol0003oooooooooo`0oooooo`00POooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo08_ooooo00?o0000ooooooooool0@?ooool0087ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`2:ooooo`03o`000?oooooooooo043ooooo0021ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`11ooooo`00POooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool0@Oooool0087ooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo04;ooooo
001Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o
410@olc<c006ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Q_ooool00ol0003o
ooooooooo`12ooooo`00I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
08Cooooo00?o0000ooooooooool0@oooool006Kooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo08?ooooo00?o0000ooooooooool0A?ooool006Kooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0001Sooooo00?o0000ooooooooool0P_oo
ool00ol0003oooooooooo`14ooooo`00I_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go
0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
POooool00ol0003oooooooooo`15ooooo`00I_ooool01Ol@413ooooooooooooooooo410@00_ooooo
00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo083ooooo
00?o0000ooooooooool0AOooool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgM
gOl@413oV9RH00Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1nooooo`03o`00
0?oooooooooo04Kooooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4
o`000?l@4106ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0O_ooool00ol0003o
ooooooooo`16ooooo`00POooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo07cooooo
00?o0000ooooooooool0Aoooool0087ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`1looooo`03o`000?oooooooooo04Oooooo0021ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool0N_ooool00ol0003oooooooooo`18ooooo`00POooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0B?ooool0087ooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo04Wooooo0021ooooo`?o0000
7_ooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo04Wooooo0021ooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`1:ooooo`00POooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool0B_ooool0
087ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo
04_ooooo0021ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0L_ooool00ol0003o
ooooooooo`1<ooooo`00POooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo07;ooooo
00?o0000ooooooooool0C?ooool0087ooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`1`ooooo`03o`000?oooooooooo04gooooo0021ooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool0L?ooool00ol0003oooooooooo`1=ooooo`00POooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo06kooooo00?o0000ooooooooool0C_ooool0087ooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo04kooooo0021ooooo`?o0000
8oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo04oooooo0021ooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`1@ooooo`00POooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0D?ooool0
087ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo
057ooooo0021ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0J?ooool00ol0003o
ooooooooo`1Aooooo`00POooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo06Kooooo
00?o0000ooooooooool0D_ooool0087ooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`1Uooooo`03o`000?oooooooooo05;ooooo0021ooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool0I?ooool00ol0003oooooooooo`1Cooooo`00POooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0Doooool0087ooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo05Cooooo0021ooooo`?o0000
:Oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo05Gooooo0021ooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Eooooo`00POooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0E_ooool0
087ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo
05Kooooo0021ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0G?ooool00ol0003o
ooooooooo`1Gooooo`00POooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo05[ooooo
00?o0000ooooooooool0F?ooool0087ooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`1Jooooo`03o`000?oooooooooo05Sooooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool0F?ooool00ol0003oooooooooo`1Iooooo`00I_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0F_ooool006Kooooo
00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0F_ooool006Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3
o`0002kooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`1Kooooo`00I_ooool01Ol0
003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`1Looooo`00I_ooool0
1Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`1Looooo`00I_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`1Mooooo`00
I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06oooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`1Noooo
o`00POooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo04oooooo00?o0000oooooooo
ool0G_ooool0087ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`1=ooooo`03o`00
0?oooooooooo05oooooo0021ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0Booo
ool00ol0003oooooooooo`1Pooooo`00POooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo04_ooooo00?o0000ooooooooool0H?ooool0087ooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`19ooooo`03o`000?oooooooooo067ooooo0021ooooo`?o0000=Oooool00ol0003o
ooooooooo`17ooooo`03o`000?oooooooooo06;ooooo0021ooooo`03o`000?oooooooooo03Kooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`1Rooooo`00POooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0Hoooool0087ooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo06Cooooo0021oooo
o`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`1Toooo
o`00POooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo047ooooo00?o0000oooooooo
ool0IOooool0087ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo06Kooooo0021ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`1Wooooo`00POooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0J?ooool0087ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo06Sooooo0021ooooo`?o0000??ooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo06Wooooo0021ooooo`03o`000?oooooooooo03gooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`1Zooooo`00POooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0Joooool0087ooooo00?o0000
ooooooooool0?_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo06cooooo0021oooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`1/oooo
o`00POooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool0KOooool0087ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo06kooooo0021ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`1_ooooo`00POooool00ol0003oooooooooo`13ooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool0L?ooool0087ooooo00?o0000ooooooooool0A?ooool2o`00
02[ooooo00?o0000ooooooooool0LOooool0087ooooo0ol00016ooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0L_ooool0087ooooo00?o0000ooooooooool0Aoooool00ol0003ooooo
ooooo`0Sooooo`;o0000MOooool0087ooooo00?o0000ooooooooool0B?ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo07Gooooo0021ooooo`03o`000?oooooooooo04Wooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`1fooooo`00POooool00ol0003oooooooooo`1:oooo
o`;o00007Oooool2o`0007Wooooo0021ooooo`03o`000?oooooooooo04cooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`1iooooo`00POooool00ol0003oooooooooo`1=ooooo`;o0000
5oooool2o`0007cooooo001gooooo`Co000000?o410@ooooooooool00oooool00ol0003ooooooooo
o`1?ooooo`;o00005?ooool00ol0003oooooooooo`1looooo`00NOooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo057ooooo0ol0000>ooooo`?o0000Ooooool007Wooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`1Dooooo`?o00002?ooool3o`0008;ooooo001iooooo`03
o`000?oooooooooo00Gooooo0ol0001Gooooo`So0000QOooool007Wooooo00?o0000ooooooooool0
k?ooool007Wooooo00?o0000ooooooooool0k?ooool007Wooooo00?o0000ooooooooool0k?ooool0
07Oooooo00?oEEEEofIVI_l00000k_ooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-12, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.32877 .12361 -18 -4.5 ]
[.32877 .12361 0 4.5 ]
[.32877 .24721 -18 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -18 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -18 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-5)] .18254 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(10)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(15)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.34127 .12361 m
.34752 .12361 L
s
[(0.2)] .32877 .12361 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(0.4)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(0.6)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(0.8)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(1)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0309 m
.34502 .0309 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .09271 m
.34502 .09271 L
s
.34127 .15451 m
.34502 .15451 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .21631 m
.34502 .21631 L
s
.34127 .27812 m
.34502 .27812 L
s
.34127 .30902 m
.34502 .30902 L
s
.34127 .33992 m
.34502 .33992 L
s
.34127 .40172 m
.34502 .40172 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .46353 m
.34502 .46353 L
s
.34127 .52533 m
.34502 .52533 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .58713 m
.34502 .58713 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01627 m
.06244 .02449 L
.10458 .0372 L
.14415 .05366 L
.18221 .0745 L
.22272 .10295 L
.26171 .13702 L
.30316 .1807 L
.34309 .22973 L
.3815 .28238 L
.42237 .34252 L
.46172 .402 L
.49955 .45787 L
.53984 .51257 L
.57861 .55725 L
.59832 .57599 L
.61984 .59285 L
.6298 .59929 L
.64043 .60515 L
.65038 .60968 L
.65954 .61299 L
.66983 .61573 L
.67524 .61675 L
.67796 .61715 L
.68096 .6175 L
.68359 .61774 L
.68599 .6179 L
.68732 .61796 L
.68807 .61798 L
.68876 .618 L
.69003 .61803 L
.69068 .61803 L
.69139 .61803 L
.69265 .61802 L
.6938 .618 L
.69507 .61796 L
.69641 .6179 L
.69866 .61775 L
.70113 .61754 L
.70366 .61725 L
.70641 .61687 L
.7114 .61598 L
.72074 .61365 L
.73164 .60984 L
.74169 .60531 L
.76045 .59431 L
.78109 .57858 L
.82143 .53812 L
.86025 .48941 L
.90153 .43066 L
Mistroke
.94129 .37087 L
.97619 .31842 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h/ooooo`05odA4A?l0003o0000oc8b<_oMgMd0G_ooool01Om4A4Co0000o`000?lb<S;ogMgM02[o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^:?ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0Tooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01?ooooo000Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0_ooooo`03ogMgMolb<S;ooooo063ooooo00?oMgMgoc8b<_ooool0:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo02Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL04oooool000oooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Sooooo`Ko00001oooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000;oooool00omgMgOo<S8booooo`1Pooooo`03ogMgMolb<S;ooooo02_o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002[ooooo00?o0000oooo
ooooool01_ooool00omgMgOo<S8booooo`0Vooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000;?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<05kooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00/ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Zooooo`03
o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Xooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@4100;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Aooooo`006_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Wooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01?ooooo000Hooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0/ooooo`Co0000Goooool4o`0002_ooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo00?oEEEEofIVI_l000001Oooool4o`0002Kooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001?ooooo
ool00016o`00013ooooo000Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo000Jooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01Kooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Co
oooo0021ooooo`03o`000?oooooooooo0>Cooooo000Jooooo`Co0000Hoooool00ol0003ooooooooo
o`3Tooooo`007_ooool7o`0005cooooo00?o0000ooooooooool0i?ooool002Gooooo1Ol0001Goooo
o`03o`000?oooooooooo0>Cooooo000Zooooo`?o0000E?ooool00ol0003oooooooooo`3Tooooo`00
;Oooool4o`00053ooooo0ol0003Tooooo`00<Oooool3o`0004gooooo00?o0000ooooooooool0i?oo
ool003Cooooo0ol0001:ooooo`03o`000?oooooooooo0>Cooooo000gooooo`;o0000B?ooool00ol0
003oooooooooo`3Tooooo`00>Oooool2o`0004Kooooo00?o0000ooooooooool0i?ooool003_ooooo
0_l00014ooooo`03o`000?oooooooooo0>Cooooo000mooooo`;o0000@_ooool00ol0003ooooooooo
o`3Tooooo`00?oooool2o`00043ooooo00?o0000ooooooooool0i?ooool0047ooooo0_l0000noooo
o`03o`000?oooooooooo0>Cooooo0013ooooo`;o0000??ooool00ol0003oooooooooo`3Tooooo`00
AOooool2o`0003[ooooo0ol0003Tooooo`00Aoooool2o`0003Sooooo00?o0000ooooooooool0i?oo
ool004Wooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`3Tooooo`00B_ooool2o`00
03Gooooo00?o0000ooooooooool0i?ooool004cooooo0_l0000cooooo`03o`000?oooooooooo0>Co
oooo001>ooooo`;o0000<Oooool00ol0003oooooooooo`3Tooooo`00D?ooool00ol0003ooooooooo
o`0^ooooo`03o`000?oooooooooo0>Cooooo001Aooooo`;o0000;_ooool00ol0003oooooooooo`3T
ooooo`00Doooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo0>Cooooo001Dooooo`;o
0000:oooool00ol0003oooooooooo`3Tooooo`00E_ooool00ol0003oooooooooo`0Xooooo`?o0000
i?ooool005Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`3Tooooo`00F?ooool2
o`0002Oooooo00?o0000ooooooooool0i?ooool005[ooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`3Tooooo`00Foooool2o`0002Cooooo00?o0000ooooooooool0i?ooool005gooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`3Tooooo`00G_ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo0>Cooooo001Oooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool0i?ooool0063ooooo00?o0000ooooooooool00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`3Tooooo`00HOooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0>Cooooo001Rooooo`05o`000?oooooo
ooooooooool@41000oooool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o
0000ooooooooool0i?ooool006?ooooo00Co0000oooooooooooo00000oooool00ol0003ooooooooo
o`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003Tooooo`00I?ooool00ol0003oooooo`000003
ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`3T
ooooo`00IOooool00ol0003o410@ooooo`02ooooo`03oa0@4?oooooooooo00gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`3Tooooo`00I_ooool01Ol0003oV9RHoooooonHV9SoMgMg
00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0>Cooooo001Voooo
o`05onk^k_l0003o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o
0000ooooooooool0i?ooool006Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`3T
ooooo`00JOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0>Cooooo001Zooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0i?ooool006_ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`3Tooooo`00K?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo0>Cooooo001]ooooo`03o`000?oooooooooo017ooooo0ol0003Tooooo`00K_ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo0>Cooooo001_ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0i?ooool0073ooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`3Tooooo`00LOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0>Cooooo001b
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0i?ooool007?ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`3Tooooo`00M?ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo0>Cooooo001eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
i?ooool007Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`3Tooooo`00M_ooool0
0ol0003oooooooooo`08ooooo`?o0000i?ooool007Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`3Tooooo`00N?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0>Co
oooo001iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0i?ooool007Wooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`3Tooooo`00N_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0>Cooooo001kooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0i?ooool007cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3Tooooo`00
OOooool01Ol0003ooooooooooooooooo00000>Kooooo001nooooo`04o`000?ooooooooooo`000>Ko
oooo001nooooo`03o`000?oooooooooo00?o0000i?ooool007oooooo00?o0000ooooool00000i_oo
ool0083ooooo0_l0003Vooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool2o`000>Go
oooo0021ooooo`;o0000iOooool0087ooooo00?o0000ooooool00000i?ooool006Kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00Co
0000oooooooooooo0000hoooool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`000>?ooooo001Vooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0000Kooooo00Go0000ooooooooooooooooo`00003Roooo
o`00I_ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool3
o`0000;ooooo00?o0000ooooooooool0goooool006Kooooo00Go0000ooooooooooooooooo`00000;
ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`3Nooooo`00I_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0=kooooo001Vooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0gOooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0
003ooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3Looooo`00POooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0=cooooo0021ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0foooool0087ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`3Jooooo`00POooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0=Wooooo
0021ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0fOooool0087ooooo0ol00009
ooooo`03o`000?oooooooooo0=Sooooo0021ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0eoooool0087ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3Gooooo`00
POooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0=Kooooo0021ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0eOooool0087ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`3Eooooo`00POooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
0=Cooooo0021ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0doooool0087ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`3Booooo`00POooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo0=;ooooo0021ooooo`?o00004?ooool00ol0003oooooooooo`3A
ooooo`00POooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo0=3ooooo0021ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool0d?ooool0087ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`2fooooo`03o`000?oooooooooo01Kooooo0021ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0]Oooool00ol0003oooooooooo`0Fooooo`00POooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo0;Cooooo00?o0000ooooooooool05oooool0
087ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo
01Sooooo0021ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0/Oooool00ol0003o
ooooooooo`0Hooooo`00POooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo0:oooooo
00?o0000ooooooooool06Oooool0087ooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`2^ooooo`03o`000?oooooooooo01[ooooo0021ooooo`?o00005oooool00ol0003oooooooooo`2]
ooooo`03o`000?oooooooooo01[ooooo0021ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool0Zoooool00ol0003oooooooooo`0Kooooo`00POooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo0:[ooooo00?o0000ooooooooool07?ooool0087ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`2Yooooo`03o`000?oooooooooo01cooooo0021ooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool0Yoooool00ol0003oooooooooo`0Mooooo`00POooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo0:Oooooo00?o0000ooooooooool07Oooool0
087ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo
01kooooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b
<_l0003o410@olc<c006ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0Y?ooool0
0ol0003oooooooooo`0Oooooo`00I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo0:?ooooo00?o0000ooooooooool07oooool006Kooooo00Go410@oooooooooooooooooa0@
400;ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo0:7ooooo00?o0000ooooooooool08?ooool006Kooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0001gooooo00?o0000oooooooo
ool0X?ooool00ol0003oooooooooo`0Qooooo`00I_ooool01Ol0003ooooooooooooooooo000000_o
oooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool0Woooool00ol0003oooooooooo`0Qooooo`00I_ooool01Ol@413ooooooooooooooooo410@
00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
09gooooo00?o0000ooooooooool08_ooool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`2Loooo
o`03o`000?oooooooooo02?ooooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<
c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0Voooool0
0ol0003oooooooooo`0Sooooo`00POooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
09Wooooo00?o0000ooooooooool09?ooool0087ooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`2Hooooo`03o`000?oooooooooo02Gooooo0021ooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool0Uoooool00ol0003oooooooooo`0Uooooo`00POooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo09Kooooo00?o0000ooooooooool09_ooool0087ooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`2Dooooo`03o`000?oooooooooo02Oooooo0021oooo
o`?o00009?ooool00ol0003oooooooooo`2Booooo`03o`000?oooooooooo02Sooooo0021ooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0T_ooool00ol0003oooooooooo`0Xooooo`00
POooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool0
:Oooool0087ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`2>ooooo`03o`000?oo
oooooooo02[ooooo0021ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0SOooool0
0ol0003oooooooooo`0Zooooo`00POooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
08cooooo00?o0000ooooooooool0:oooool0087ooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`2:ooooo`03o`000?oooooooooo02cooooo0021ooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool0ROooool00ol0003oooooooooo`0/ooooo`00POooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool0;Oooool0087ooooo00?o0000
ooooooooool0:_ooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo02kooooo0021oooo
o`?o0000:oooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo02kooooo0021ooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`0_ooooo`00
POooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0
<?ooool0087ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`21ooooo`03o`000?oo
oooooooo033ooooo0021ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0Ooooool0
0ol0003oooooooooo`0aooooo`00POooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
07kooooo00?o0000ooooooooool0<_ooool0087ooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`1mooooo`03o`000?oooooooooo03;ooooo0021ooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool0Noooool00ol0003oooooooooo`0cooooo`00POooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0=?ooool0087ooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo03Gooooo0021oooo
o`?o0000<_ooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo03Gooooo0021ooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool0MOooool00ol0003oooooooooo`0fooooo`00
POooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0
=oooool0087ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`1cooooo`03o`000?oo
oooooooo03Oooooo0021ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0LOooool0
0ol0003oooooooooo`0hooooo`00POooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
06oooooo00?o0000ooooooooool0>Oooool0087ooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`1_ooooo`03o`000?oooooooooo03Wooooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0jooooo`00I_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool0
0ol0003oooooooooo`0hooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0>oooool0
06Kooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0>ooo
ool006Kooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80
1_ooool3o`0003Wooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0looooo`00I_oo
ool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03
o`000?oooooooooo03[ooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0mooooo`00
I_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006oooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0noooo
o`00I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0o
ooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVY
Z@06ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0Hoooool00ol0003ooooooooo
o`0oooooo`00POooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo067ooooo00?o0000
ooooooooool0@?ooool0087ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`1Ooooo
o`03o`000?oooooooooo047ooooo0021ooooo`03o`000?oooooooooo03kooooo00?o0000oooooooo
ool0G_ooool00ol0003oooooooooo`12ooooo`00POooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo05cooooo00?o0000ooooooooool0@oooool0087ooooo00?o0000ooooooooool0@?oo
ool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo04Cooooo0021ooooo`?o0000@Oooool0
0ol0003oooooooooo`1Iooooo`03o`000?oooooooooo04Cooooo0021ooooo`03o`000?oooooooooo
04;ooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`15ooooo`00POooool00ol0003o
ooooooooo`13ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0A_ooool0087ooooo
00?o0000ooooooooool0A?ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo04Oooooo
0021ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0D_ooool00ol0003ooooooooo
o`18ooooo`00POooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo053ooooo00?o0000
ooooooooool0BOooool0087ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`1>oooo
o`03o`000?oooooooooo04[ooooo0021ooooo`03o`000?oooooooooo04Oooooo00?o0000oooooooo
ool0C?ooool00ol0003oooooooooo`1;ooooo`00POooool00ol0003oooooooooo`18ooooo`03o`00
0?oooooooooo04[ooooo00?o0000ooooooooool0C?ooool0087ooooo00?o0000ooooooooool0BOoo
ool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo04gooooo0021ooooo`?o0000B_ooool2
o`0004Oooooo00?o0000ooooooooool0C_ooool0087ooooo00?o0000ooooooooool0C?ooool00ol0
003oooooooooo`13ooooo`03o`000?oooooooooo04oooooo0021ooooo`03o`000?oooooooooo04go
oooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`1@ooooo`00POooool00ol0003ooooo
ooooo`1>ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0DOooool0087ooooo00?o
0000ooooooooool0Coooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo05;ooooo0021
ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`1C
ooooo`00POooool00ol0003oooooooooo`1Aooooo`;o0000>_ooool00ol0003oooooooooo`1Doooo
o`00POooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo03Gooooo0_l0001Gooooo`00
POooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0
Eoooool0087ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0`ooooo`;o0000F_oo
ool0087ooooo0ol0001Fooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0F_ooool0
087ooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
05_ooooo0021ooooo`03o`000?oooooooooo05Sooooo0_l0000Zooooo`;o0000G_ooool0087ooooo
00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05kooooo
0021ooooo`03o`000?oooooooooo05_ooooo0_l0000Tooooo`;o0000HOooool0087ooooo00?o0000
ooooooooool0GOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo067ooooo0021oooo
o`03o`000?oooooooooo05kooooo0ol0000Mooooo`;o0000I?ooool007Oooooo1?l000000ol@413o
ooooooooo`03ooooo`03o`000?oooooooooo067ooooo1?l0000Eooooo`Co0000I_ooool007Wooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Uooooo`?o00003oooool3o`0006[ooooo
001iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0J?ooool3o`0000Wooooo0ol0
001]ooooo`00NOooool00ol0003oooooooooo`05ooooo`?o0000J_ooool:o`00073ooooo001ioooo
o`03o`000?oooooooooo0>cooooo001iooooo`03o`000?oooooooooo0>cooooo001iooooo`03o`00
0?oooooooooo0>cooooo001gooooo`03oeEEEOmVIVKo00000>kooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-12, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.32877 .12361 -18 -4.5 ]
[.32877 .12361 0 4.5 ]
[.32877 .24721 -18 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -18 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -18 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-5)] .18254 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(10)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(15)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.34127 .12361 m
.34752 .12361 L
s
[(0.2)] .32877 .12361 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(0.4)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(0.6)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(0.8)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(1)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0309 m
.34502 .0309 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .09271 m
.34502 .09271 L
s
.34127 .15451 m
.34502 .15451 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .21631 m
.34502 .21631 L
s
.34127 .27812 m
.34502 .27812 L
s
.34127 .30902 m
.34502 .30902 L
s
.34127 .33992 m
.34502 .33992 L
s
.34127 .40172 m
.34502 .40172 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .46353 m
.34502 .46353 L
s
.34127 .52533 m
.34502 .52533 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .58713 m
.34502 .58713 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .02965 m
.06244 .0403 L
.10458 .05528 L
.14415 .07308 L
.18221 .09404 L
.22272 .12089 L
.26171 .15135 L
.30316 .18872 L
.34309 .2293 L
.3815 .27203 L
.42237 .32054 L
.46172 .36898 L
.49955 .41573 L
.53984 .46399 L
.57861 .50713 L
.61984 .54744 L
.65954 .57902 L
.67958 .59174 L
.69774 .60124 L
.71741 .6092 L
.72821 .61252 L
.73838 .61493 L
.74815 .61661 L
.75306 .61721 L
.75589 .61748 L
.75846 .61768 L
.76083 .61782 L
.76307 .61793 L
.7643 .61797 L
.76544 .618 L
.76669 .61802 L
.76732 .61803 L
.76801 .61803 L
.76917 .61803 L
.77023 .61803 L
.77139 .61801 L
.77261 .61798 L
.77368 .61795 L
.77468 .61791 L
.77693 .6178 L
.77956 .61763 L
.78198 .61744 L
.78746 .61684 L
.79228 .61615 L
.79739 .61525 L
.80624 .61328 L
.81598 .61052 L
.83543 .60315 L
.85632 .5926 L
.89759 .5643 L
Mistroke
.93736 .52891 L
.9756 .48892 L
.97619 .48827 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h/ooooo`05odA4A?l0003o0000oc8b<_oMgMd0G_ooool01Om4A4Co0000o`000?lb<S;ogMgM02[o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^:?ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0Tooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01?ooooo000Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0_ooooo`03ogMgMolb<S;ooooo063ooooo00?oMgMgoc8b<_ooool0:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo02Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL04oooool000oooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Sooooo`Ko00001oooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000;oooool00omgMgOo<S8booooo`1Pooooo`03ogMgMolb<S;ooooo02_o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002[ooooo00?o0000oooo
ooooool01_ooool00omgMgOo<S8booooo`0Vooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000;?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<05kooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00/ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Zooooo`03
o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Xooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@4100;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Aooooo`006_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Wooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01?ooooo000Hooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0/ooooo`Co0000Goooool4o`0002_ooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo00?oEEEEofIVI_l000001Oooool4o`0002Kooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001?ooooo
ool00016o`00013ooooo000Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo000Jooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01Kooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Co
oooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021
ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03
o`000?oooooooooo0>Cooooo000Jooooo`?o0000I?ooool3o`000>Cooooo000Mooooo`Go0000Gooo
ool00ol0003oooooooooo`3Tooooo`008_ooool4o`0005_ooooo00?o0000ooooooooool0i?ooool0
02Kooooo0ol0001Hooooo`03o`000?oooooooooo0>Cooooo000Yooooo`?o0000EOooool00ol0003o
ooooooooo`3Tooooo`00;?ooool3o`0005;ooooo00?o0000ooooooooool0i?ooool002oooooo0ol0
001?ooooo`03o`000?oooooooooo0>Cooooo000booooo`?o0000C?ooool00ol0003oooooooooo`3T
ooooo`00=Oooool2o`0004[ooooo00?o0000ooooooooool0i?ooool003Oooooo0_l00018ooooo`03
o`000?oooooooooo0>Cooooo000iooooo`;o0000A_ooool3o`000>Cooooo000kooooo`;o0000A?oo
ool00ol0003oooooooooo`3Tooooo`00?Oooool2o`0004;ooooo00?o0000ooooooooool0i?ooool0
03oooooo0_l00010ooooo`03o`000?oooooooooo0>Cooooo0011ooooo`;o0000?_ooool00ol0003o
ooooooooo`3Tooooo`00@oooool2o`0003cooooo00?o0000ooooooooool0i?ooool004Gooooo0_l0
000jooooo`03o`000?oooooooooo0>Cooooo0017ooooo`;o0000>?ooool00ol0003oooooooooo`3T
ooooo`00BOooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo0>Cooooo001:ooooo`;o
0000=Oooool00ol0003oooooooooo`3Tooooo`00C?ooool2o`0003?ooooo0ol0003Tooooo`00C_oo
ool2o`00037ooooo00?o0000ooooooooool0i?ooool0053ooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`3Tooooo`00DOooool2o`0002kooooo00?o0000ooooooooool0i?ooool005?o
oooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`3Tooooo`00E?ooool2o`0002_ooooo
00?o0000ooooooooool0i?ooool005Kooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`3Tooooo`00Eoooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo0>Cooooo001Hoooo
o`;o00003?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool0
0ol0003oooooooooo`3Tooooo`00F_ooool00ol0003oooooooooo`09ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oo
oooooooo0>Cooooo001Kooooo`;o00002Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`3Tooooo`00GOooool00ol0003oooooooooo`06
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`?o0000i?oo
ool005kooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool01Oooool00ol0003oooooooooo`3Tooooo`00Goooool00ol0003oooooooooo`04
ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0>Cooooo001Pooooo`03o`000?oooooooooo00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`3Tooooo`00HOoo
ool2o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`01_ooool00ol0003oooooooooo`3Tooooo`00Hoooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo0>Cooooo001Tooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0i?oo
ool006Gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`3Tooooo`00I_ooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo0>Cooooo001Wooooo`;o00006?ooool00ol0003o
ooooooooo`3Tooooo`00JOooool00ol0003oooooooooo`0Eooooo`?o0000i?ooool006[ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`3Tooooo`00Joooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo0>Cooooo001/ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool0i?ooool006gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`3Tooooo`00
K_ooool2o`00017ooooo00?o0000ooooooooool0i?ooool0073ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`3Tooooo`00LOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo0>Cooooo001booooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0i?ooool007?o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`3Tooooo`00M?ooool00ol0003ooooo
ooooo`0:ooooo`?o0000i?ooool007Gooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`3Tooooo`00M_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0>Cooooo001goooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0i?ooool007Sooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`3Tooooo`00NOooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0>Cooooo001jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0i?oo
ool007_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3Tooooo`00O?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo0>Cooooo001mooooo`05o`000?oooooooooooooo
ool00000i_ooool007kooooo00?o0000ooooooooool00ol0003Tooooo`00Ooooool00ol0003ooooo
o`00003Vooooo`00P?ooool2o`000>Kooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021oooo
o`;o0000iOooool0087ooooo0_l0003Uooooo`00POooool00ol0003oooooo`00003Tooooo`00I_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0
1?ooool01?l0003oooooooooool0003Sooooo`00I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`00003Roooo
o`00I_ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0goooool006Kooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol00003ooooo`03o`000?oooooooooo0=kooooo001Voooo
o`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0gOooool006Kooooo00Go410@oooooooooooooooooa0@
400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`3Mooooo`00I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0=cooooo001Vooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0foooool0087ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3J
ooooo`00POooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0=Wooooo0021ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0f?ooool0087ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`3Gooooo`00POooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo0=Oooooo0021ooooo`?o00002oooool00ol0003oooooooooo`3Fooooo`00POooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo0=Gooooo0021ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0e?ooool0087ooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`3Cooooo`00POooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0=;ooooo0021
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0dOooool0087ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`3@ooooo`00POooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo0<oooooo0021ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
c_ooool0087ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`3=ooooo`00POooool3
o`0001Gooooo00?o0000ooooooooool0c?ooool0087ooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`3;ooooo`00POooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0<[o
oooo0021ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0bOooool0087ooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`39ooooo`00POooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo0<Sooooo0021ooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool0aoooool0087ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`36ooooo`00
POooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo0<Kooooo0021ooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool0aOooool0087ooooo0ol0000Mooooo`03o`000?oooooo
oooo0<Cooooo0021ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0`oooool0087o
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`33ooooo`00POooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo0<;ooooo0021ooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool0`Oooool0087ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`30
ooooo`00POooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo0<3ooooo001Vooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0_oooool006Kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`2nooooo`00I_ooool01Ol@413ooooooooooooo
oooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0_Oooool006Kooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?nHV9SooooooiRHV?lQ8B401_ooool3o`0002Cooooo00?o0000ooooooooool0_Oooool006Kooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo0;cooooo001Vooooo`05oa0@4?oooooooooooooo
ool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool0^oooool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH
00Sooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`2jooooo`00I_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo0;Wooooo0021ooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool0^?ooool0087ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`2gooooo`00
POooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo0;Kooooo0021ooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool0]_ooool0087ooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`2eooooo`00POooool3o`0002gooooo00?o0000ooooooooool0]?ooool0087o
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`2cooooo`00POooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo0;;ooooo0021ooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool0/Oooool0087ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2`
ooooo`00POooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo0;3ooooo0021ooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool0[oooool0087ooooo00?o0000ooooooooool0
<oooool00ol0003oooooooooo`2^ooooo`00POooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo0:gooooo0021ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0[?ooool0
087ooooo0ol0000eooooo`03o`000?oooooooooo0:cooooo0021ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool0Zoooool0087ooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`2Zooooo`00POooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo0:Wooooo0021
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0Z?ooool0087ooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`2Wooooo`00POooool00ol0003oooooooooo`0jooooo`03
o`000?oooooooooo0:Oooooo0021ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
Y_ooool0087ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`2Uooooo`00POooool0
0ol0003oooooooooo`0mooooo`03o`000?oooooooooo0:Cooooo0021ooooo`?o0000?_ooool00ol0
003oooooooooo`2Sooooo`00POooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo0:?o
oooo0021ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0X_ooool0087ooooo00?o
0000ooooooooool0@?ooool00ol0003oooooooooo`2Qooooo`00POooool00ol0003oooooooooo`11
ooooo`03o`000?oooooooooo0:3ooooo0021ooooo`03o`000?oooooooooo04;ooooo00?o0000oooo
ooooool0Woooool0087ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`2Nooooo`00
I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q
8Oo<c<`01_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo09gooooo001Vooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06
ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`0F
ooooo`00I_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0Poooool00ol0003ooooooooo
o`0Fooooo`00I_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RH
oc8b<P06ooooo`?o0000A_ooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo01Oooooo
001Vooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Ko
oooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo01So
oooo001Vooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@
00Kooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo
01Wooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o
000000Kooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`1kooooo`03o`000?oooooo
oooo01[ooooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00Kooooo00?o0000ooooooooool0B_ooool2o`0007[ooooo00?o0000ooooooooool06ooo
ool0087ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1fooooo`03o`000?oooooo
oooo01cooooo0021ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0M?ooool00ol0
003oooooooooo`0Mooooo`00POooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo07;o
oooo00?o0000ooooooooool07_ooool0087ooooo00?o0000ooooooooool0Coooool00ol0003ooooo
ooooo`1`ooooo`03o`000?oooooooooo01oooooo0021ooooo`03o`000?oooooooooo053ooooo00?o
0000ooooooooool0K_ooool00ol0003oooooooooo`0Pooooo`00POooool3o`00057ooooo00?o0000
ooooooooool0K?ooool00ol0003oooooooooo`0Qooooo`00POooool00ol0003oooooooooo`1Boooo
o`03o`000?oooooooooo06Wooooo0_l0000Tooooo`00POooool00ol0003oooooooooo`1Cooooo`03
o`000?oooooooooo06Oooooo00?o0000ooooooooool09?ooool0087ooooo00?o0000ooooooooool0
E?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo02Gooooo0021ooooo`03o`000?oo
oooooooo05Gooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Vooooo`00POooool0
0ol0003oooooooooo`1Fooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool09oooool0
087ooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`1Nooooo`;o0000:_ooool0087o
oooo00?o0000ooooooooool0F?ooool2o`0005gooooo00?o0000ooooooooool0:_ooool0087ooooo
00?o0000ooooooooool0F_ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo02_ooooo
0021ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0Eoooool00ol0003ooooooooo
o`0/ooooo`00POooool3o`0005cooooo0_l0001Fooooo`03o`000?oooooooooo02gooooo0021oooo
o`03o`000?oooooooooo05kooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0^oooo
o`00POooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo04oooooo0_l0000aooooo`00
POooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0
<Oooool0087ooooo00?o0000ooooooooool0HOooool2o`0004_ooooo0_l0000dooooo`00POooool0
0ol0003oooooooooo`1Sooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0=?ooool0
087ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo
03Gooooo0021ooooo`03o`000?oooooooooo06Gooooo0_l00013ooooo`;o0000>?ooool0087ooooo
00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo03Sooooo
0021ooooo`03o`000?oooooooooo06Sooooo0_l0000mooooo`;o0000>oooool0087ooooo0ol0001Z
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0>oooool0087ooooo00?o0000oooo
ooooool0Joooool2o`0003Sooooo00?o0000ooooooooool0??ooool0087ooooo00?o0000oooooooo
ool0KOooool2o`0003Cooooo0_l0000oooooo`00POooool00ol0003oooooooooo`1_ooooo`;o0000
<?ooool2o`00047ooooo0021ooooo`03o`000?oooooooooo077ooooo0_l0000/ooooo`;o0000@ooo
ool0087ooooo00?o0000ooooooooool0Loooool2o`0002Oooooo0ol00015ooooo`00POooool00ol0
003oooooooooo`1eooooo`;o00008_ooool3o`0004Sooooo001gooooo`Co000000?o410@oooooooo
ool00oooool00ol0003oooooooooo`1gooooo`?o00007?ooool3o`0004_ooooo001iooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0N_ooool4o`0001Gooooo0ol0001>ooooo`00NOoo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07kooooo1Ol0000:ooooo`Ko0000DOoo
ool007Wooooo00?o0000ooooooooool01Oooool3o`0008?ooooo2_l0001Gooooo`00NOooool00ol0
003oooooooooo`3/ooooo`00NOooool00ol0003oooooooooo`3/ooooo`00NOooool00ol0003ooooo
ooooo`3/ooooo`00Moooool00omEEEGoIVIVo`00003^ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-12, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.32877 .12361 -18 -4.5 ]
[.32877 .12361 0 4.5 ]
[.32877 .24721 -18 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -18 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -18 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-5)] .18254 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(10)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(15)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.34127 .12361 m
.34752 .12361 L
s
[(0.2)] .32877 .12361 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(0.4)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(0.6)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(0.8)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(1)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0309 m
.34502 .0309 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .09271 m
.34502 .09271 L
s
.34127 .15451 m
.34502 .15451 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .21631 m
.34502 .21631 L
s
.34127 .27812 m
.34502 .27812 L
s
.34127 .30902 m
.34502 .30902 L
s
.34127 .33992 m
.34502 .33992 L
s
.34127 .40172 m
.34502 .40172 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .46353 m
.34502 .46353 L
s
.34127 .52533 m
.34502 .52533 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .58713 m
.34502 .58713 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04655 m
.06244 .05874 L
.10458 .07476 L
.14415 .09265 L
.18221 .11266 L
.22272 .13711 L
.26171 .16378 L
.30316 .19543 L
.34309 .22895 L
.3815 .26368 L
.42237 .30281 L
.46172 .34198 L
.49955 .38032 L
.53984 .42098 L
.57861 .45903 L
.61984 .49721 L
.65954 .53069 L
.69774 .55888 L
.73838 .58363 L
.77751 .60156 L
.79892 .6087 L
.80873 .61131 L
.81909 .61361 L
.82867 .61532 L
.83374 .61605 L
.83917 .61671 L
.84417 .6172 L
.84873 .61755 L
.85092 .61769 L
.85331 .61781 L
.85556 .6179 L
.85765 .61796 L
.85882 .61799 L
.86006 .61801 L
.86112 .61802 L
.86228 .61803 L
.86353 .61803 L
.86423 .61803 L
.86486 .61803 L
.8661 .61802 L
.86727 .618 L
.86837 .61798 L
.86953 .61795 L
.87161 .61788 L
.87385 .61778 L
.87631 .61765 L
.88144 .61729 L
.88695 .61677 L
.89691 .61548 L
.90704 .61371 L
Mistroke
.91809 .61127 L
.93819 .60545 L
.95659 .59862 L
.97619 .58981 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h/ooooo`05odA4A?l0003o0000oc8b<_oMgMd0G_ooool01Om4A4Co0000o`000?lb<S;ogMgM02[o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^:?ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0Tooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01?ooooo000Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0_ooooo`03ogMgMolb<S;ooooo063ooooo00?oMgMgoc8b<_ooool0:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo02Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL04oooool000oooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Sooooo`Ko00001oooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000;oooool00omgMgOo<S8booooo`1Pooooo`03ogMgMolb<S;ooooo02_o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002[ooooo00?o0000oooo
ooooool01_ooool00omgMgOo<S8booooo`0Vooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000;?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<05kooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00/ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Zooooo`03
o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Xooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@4100;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Aooooo`006_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Wooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01?ooooo000Hooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0/ooooo`Co0000Goooool4o`0002_ooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo00?oEEEEofIVI_l000001Oooool4o`0002Kooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001?ooooo
ool00016o`00013ooooo000Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo000Jooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01Kooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Co
oooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021
ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03
o`000?oooooooooo0>Cooooo0021ooooo`?o0000i?ooool0087ooooo00?o0000ooooooooool0i?oo
ool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087o
oooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool001[ooooo0ol0
001Tooooo`03o`000?oooooooooo0>Cooooo000Mooooo`Go0000Goooool00ol0003oooooooooo`3T
ooooo`008_ooool4o`0005_ooooo00?o0000ooooooooool0i?ooool002Kooooo0ol0001Hooooo`03
o`000?oooooooooo0>Cooooo000Yooooo`?o0000EOooool3o`000>Cooooo000/ooooo`;o0000Dooo
ool00ol0003oooooooooo`3Tooooo`00;_ooool2o`00057ooooo00?o0000ooooooooool0i?ooool0
033ooooo0ol0001>ooooo`03o`000?oooooooooo0>Cooooo000cooooo`;o0000C?ooool00ol0003o
ooooooooo`3Tooooo`00=Oooool2o`0004[ooooo00?o0000ooooooooool0i?ooool003Oooooo0ol0
0017ooooo`03o`000?oooooooooo0>Cooooo000jooooo`;o0000AOooool00ol0003oooooooooo`3T
ooooo`00??ooool2o`0004?ooooo00?o0000ooooooooool0i?ooool003kooooo0ol00010ooooo`03
o`000?oooooooooo0>Cooooo0011ooooo`;o0000?_ooool3o`000>Cooooo0013ooooo`;o0000??oo
ool00ol0003oooooooooo`3Tooooo`00AOooool2o`0003[ooooo00?o0000ooooooooool0i?ooool0
04Oooooo0_l0000hooooo`03o`000?oooooooooo0>Cooooo0019ooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool0i?ooool004[ooooo0_l0000eooooo`03o`000?oooooooooo0>Cooooo
001<ooooo`;o0000<oooool00ol0003oooooooooo`3Tooooo`00C_ooool2o`00037ooooo00?o0000
ooooooooool0i?ooool0053ooooo00?o0000ooooooooool04oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`3Tooooo`00DOooool2o`00
01?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Kooooo00?o0000ooooooooool0i?ooool005?ooooo0_l0000Aooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0>Cooooo001E
ooooo`03o`000?oooooooooo00kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ
8B7ok^k^00Kooooo0ol0003Tooooo`00E_ooool2o`0000kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0i?ooool005Sooooo0_l0000<
ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0>Cooooo001Jooooo`03o`000?oooooooooo00Wooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`3Tooooo`00Fooo
ool2o`0000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`01_ooool00ol0003oooooooooo`3Tooooo`00GOooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo0>Cooooo001Nooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0i?oo
ool005oooooo0_l0000Pooooo`03o`000?oooooooooo0>Cooooo001Qooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool0i?ooool006;ooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`3Tooooo`00Hoooool2o`0001cooooo0ol0003Tooooo`00IOooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo0>Cooooo001Vooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool0i?ooool006Oooooo0_l0000Hooooo`03o`000?oooooooooo0>Cooooo001Yooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool0i?ooool006[ooooo0_l0000Eooooo`03o`00
0?oooooooooo0>Cooooo001/ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0i?oo
ool006gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`3Tooooo`00K_ooool2o`00
017ooooo00?o0000ooooooooool0i?ooool0073ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`3Tooooo`00LOooool2o`0000kooooo0ol0003Tooooo`00Loooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo0>Cooooo001dooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0i?ooool007Gooooo0_l0000:ooooo`03o`000?oooooooooo0>Cooooo001gooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0i?ooool007Sooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`3Tooooo`00NOooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0>Cooooo001jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0i?ooool0
07_ooooo0_l00004ooooo`03o`000?oooooooooo0>Cooooo001mooooo`05o`000?oooooooooooooo
ool00000i_ooool007kooooo00?o0000ooooooooool00ol0003Tooooo`00Ooooool00ol0003ooooo
o`00003Vooooo`00P?ooool2o`000>Kooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021oooo
o`?o0000i?ooool0087ooooo00Co0000oooooooooooo0000hoooool0087ooooo00Go0000oooooooo
ooooooooo`00003Rooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
0=oooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0=kooooo001Vooooo`05
oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3Mooooo`00I_ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgM
gOoooooo00001oooool3o`0000Gooooo00?o0000ooooooooool0g?ooool006Kooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`3Kooooo`00I_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l000001oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0=[ooooo001V
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0fOooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`3Hooooo`00POooool00ol0003oooooooooo`0:ooooo`;o0000f?ooool0087ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`3Eooooo`00POooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo0=Cooooo0021ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
doooool0087ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`3Booooo`00POooool3
o`00013ooooo00?o0000ooooooooool0dOooool0087ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`3@ooooo`00POooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0<oo
oooo0021ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0c_ooool0087ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`3=ooooo`00POooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo0<cooooo0021ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool0boooool0087ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`3:ooooo`00
POooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo0<Wooooo0021ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0b?ooool0087ooooo0ol0000Jooooo`03o`000?oooooo
oooo0<Oooooo0021ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0a_ooool0087o
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`35ooooo`00POooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo0<Cooooo0021ooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool0`oooool0087ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`32
ooooo`00POooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0<7ooooo0021ooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool0`?ooool0087ooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`2oooooo`00POooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo0;kooooo0021ooooo`?o00009?ooool00ol0003oooooooooo`2mooooo`00POooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo0;cooooo0021ooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0^oooool0087ooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`2jooooo`00POooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0;Wooooo0021
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0^?ooool0087ooooo00?o0000oooo
ooooool0:_ooool00ol0003oooooooooo`2gooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo0;Kooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo02cooooo00?o
0000ooooooooool0]Oooool006Kooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo0;Cooooo
001Vooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Ko
oooo0ol0000^ooooo`03o`000?oooooooooo0;?ooooo001Vooooo`05o`000?ooooooooooooooool0
00002oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`2booooo`00I_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7
Qoooool02?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo0;7ooooo001Vooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool0/?ooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`2_
ooooo`00POooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo0:kooooo0021ooooo`03
o`000?oooooooooo03Cooooo00?o0000ooooooooool0[Oooool0087ooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`2/ooooo`00POooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo0:_ooooo0021ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0Z_ooool0
087ooooo0ol0000hooooo`03o`000?oooooooooo0:Wooooo0021ooooo`03o`000?oooooooooo03Wo
oooo00?o0000ooooooooool0Z?ooool0087ooooo00?o0000ooooooooool0>_ooool00ol0003ooooo
ooooo`2Wooooo`00POooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0:Kooooo0021
ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0YOooool0087ooooo00?o0000oooo
ooooool0?Oooool00ol0003oooooooooo`2Tooooo`00POooool00ol0003oooooooooo`0nooooo`03
o`000?oooooooooo0:?ooooo0021ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0
X_ooool0087ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`2Qooooo`00POooool0
0ol0003oooooooooo`11ooooo`03o`000?oooooooooo0:3ooooo0021ooooo`?o0000@_ooool00ol0
003oooooooooo`2Oooooo`00POooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo09ko
oooo0021ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0WOooool0087ooooo00?o
0000ooooooooool0AOooool00ol0003oooooooooo`2Looooo`00POooool00ol0003oooooooooo`16
ooooo`03o`000?oooooooooo09_ooooo0021ooooo`03o`000?oooooooooo04Oooooo00?o0000oooo
ooooool0V_ooool0087ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`2Iooooo`00
POooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo09Sooooo0021ooooo`03o`000?oo
oooooooo04[ooooo0_l0002Hooooo`00POooool00ol0003oooooooooo`1<ooooo`03o`000?oooooo
oooo09Gooooo0021ooooo`?o0000COooool00ol0003oooooooooo`2Dooooo`00POooool00ol0003o
ooooooooo`1>ooooo`03o`000?oooooooooo09?ooooo0021ooooo`03o`000?oooooooooo04oooooo
00?o0000ooooooooool0T_ooool0087ooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`2Aooooo`00POooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo093ooooo0021oooo
o`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0Soooool0087ooooo00?o0000oooooooo
ool0Doooool00ol0003oooooooooo`2>ooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Doooo
o`03o`000?oooooooooo08gooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo05Gooooo00?o0000
ooooooooool0S?ooool006Kooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo08_ooooo001V
ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo
0ol0001Gooooo`03o`000?oooooooooo08[ooooo001Vooooo`05o`000?ooooooooooooooool00000
2oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0F?ooool2o`0008[o
oooo001Vooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@
00Kooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`27ooooo`00I_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooo
oooo05_ooooo00?o0000ooooooooool0Q_ooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`1Looooo`03o`000?oo
oooooooo08Gooooo0021ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0Q?ooool0
087ooooo00?o0000ooooooooool0G_ooool2o`0008Cooooo0021ooooo`03o`000?oooooooooo063o
oooo00?o0000ooooooooool0POooool0087ooooo00?o0000ooooooooool0HOooool00ol0003ooooo
ooooo`20ooooo`00POooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo07oooooo0021
ooooo`?o0000Hoooool00ol0003oooooooooo`1nooooo`00POooool00ol0003oooooooooo`1Toooo
o`03o`000?oooooooooo07gooooo0021ooooo`03o`000?oooooooooo06Gooooo0_l0001mooooo`00
POooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo07[ooooo0021ooooo`03o`000?oo
oooooooo06Sooooo00?o0000ooooooooool0NOooool0087ooooo00?o0000ooooooooool0JOooool2
o`0007Wooooo0021ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0M_ooool0087o
oooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`1eooooo`00POooool00ol0003ooooo
ooooo`1]ooooo`;o0000MOooool0087ooooo00?o0000ooooooooool0Koooool00ol0003ooooooooo
o`1booooo`00POooool3o`00073ooooo00?o0000ooooooooool0LOooool0087ooooo00?o0000oooo
ooooool0LOooool2o`00077ooooo0021ooooo`03o`000?oooooooooo07?ooooo00?o0000oooooooo
ool0K_ooool0087ooooo00?o0000ooooooooool0M?ooool2o`0006kooooo0021ooooo`03o`000?oo
oooooooo07Kooooo0_l0001/ooooo`00POooool00ol0003oooooooooo`1hooooo`03o`000?oooooo
oooo06Wooooo0021ooooo`03o`000?oooooooooo07Wooooo0_l0001Yooooo`00POooool00ol0003o
ooooooooo`1kooooo`;o0000Ioooool0087ooooo00?o0000ooooooooool0OOooool00ol0003ooooo
ooooo`1Tooooo`00POooool00ol0003oooooooooo`1nooooo`;o0000I?ooool0087ooooo0ol00020
ooooo`;o0000H_ooool0087ooooo00?o0000ooooooooool0P_ooool2o`0004Kooooo0_l0000Hoooo
o`00POooool00ol0003oooooooooo`24ooooo`?o0000@Oooool2o`0001[ooooo0021ooooo`03o`00
0?oooooooooo08Oooooo0_l0000mooooo`;o00007?ooool0087ooooo00?o0000ooooooooool0ROoo
ool2o`0003Wooooo0_l0000Nooooo`00POooool00ol0003oooooooooo`2;ooooo`?o0000<oooool3
o`00023ooooo0021ooooo`03o`000?oooooooooo08kooooo0ol0000/ooooo`Co00008oooool007Oo
oooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo097ooooo1?l0000Uooooo`?o
00009oooool007Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Eooooo`Ko0000
6?ooool7o`0002[ooooo001iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Vooo
ool5o`0000gooooo1_l0000aooooo`00NOooool00ol0003oooooooooo`05ooooo`?o0000X?ooool=
o`0003Oooooo001iooooo`03o`000?oooooooooo0>cooooo001iooooo`03o`000?oooooooooo0>co
oooo001iooooo`03o`000?oooooooooo0>cooooo001gooooo`03oeEEEOmVIVKo00000>kooooo003o
ooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-12, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.32877 .12361 -18 -4.5 ]
[.32877 .12361 0 4.5 ]
[.32877 .24721 -18 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -18 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -18 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-5)] .18254 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(10)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(15)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.34127 .12361 m
.34752 .12361 L
s
[(0.2)] .32877 .12361 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(0.4)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(0.6)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(0.8)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(1)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0309 m
.34502 .0309 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .09271 m
.34502 .09271 L
s
.34127 .15451 m
.34502 .15451 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .21631 m
.34502 .21631 L
s
.34127 .27812 m
.34502 .27812 L
s
.34127 .30902 m
.34502 .30902 L
s
.34127 .33992 m
.34502 .33992 L
s
.34127 .40172 m
.34502 .40172 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .46353 m
.34502 .46353 L
s
.34127 .52533 m
.34502 .52533 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .58713 m
.34502 .58713 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .06556 m
.06244 .07832 L
.10458 .09429 L
.14415 .11135 L
.18221 .12972 L
.22272 .15143 L
.26171 .17441 L
.30316 .20102 L
.34309 .22866 L
.3815 .25692 L
.42237 .28851 L
.46172 .32011 L
.49955 .35121 L
.53984 .38467 L
.57861 .41673 L
.61984 .45008 L
.65954 .48091 L
.69774 .50882 L
.73838 .53606 L
.77751 .55936 L
.81909 .58041 L
.85916 .59662 L
.89771 .60809 L
.91765 .61236 L
.92782 .61408 L
.93871 .61558 L
.94885 .61666 L
.9581 .61738 L
.96255 .61763 L
.96489 .61774 L
.96739 .61783 L
.96956 .6179 L
.97196 .61796 L
.97301 .61798 L
.97414 .618 L
.97521 .61801 L
.97619 .61802 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h/ooooo`05odA4A?l0003o0000oc8b<_oMgMd0G_ooool01Om4A4Co0000o`000?lb<S;ogMgM02[o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^:?ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0Tooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01?ooooo000Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0_ooooo`03ogMgMolb<S;ooooo063ooooo00?oMgMgoc8b<_ooool0:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo02Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL04oooool000oooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Sooooo`Ko00001oooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000;oooool00omgMgOo<S8booooo`1Pooooo`03ogMgMolb<S;ooooo02_o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002[ooooo00?o0000oooo
ooooool01_ooool00omgMgOo<S8booooo`0Vooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000;?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<05kooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00/ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Zooooo`03
o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Xooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@4100;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Aooooo`006_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Wooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01?ooooo000Hooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0/ooooo`Co0000Goooool4o`0002_ooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo00?oEEEEofIVI_l000001Oooool4o`0002Kooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001?ooooo
ool00016o`00013ooooo000Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo000Jooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01Kooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Co
oooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021
ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03
o`000?oooooooooo0>Cooooo0021ooooo`?o0000i?ooool0087ooooo00?o0000ooooooooool0i?oo
ool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087o
oooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o
0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000oooo
ooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo0ol0003Tooooo`00POoo
ool00ol0003oooooooooo`3Tooooo`006_ooool3o`0006Cooooo00?o0000ooooooooool0i?ooool0
01gooooo0ol0001Qooooo`03o`000?oooooooooo0>Cooooo000Pooooo`?o0000G_ooool00ol0003o
ooooooooo`3Tooooo`008oooool3o`0005_ooooo00?o0000ooooooooool0i?ooool002Kooooo0ol0
001Hooooo`03o`000?oooooooooo0>Cooooo000Yooooo`?o0000EOooool00ol0003oooooooooo`3T
ooooo`00;?ooool3o`0005;ooooo00?o0000ooooooooool0i?ooool002oooooo0ol0001?ooooo`03
o`000?oooooooooo0>Cooooo000booooo`?o0000C?ooool3o`000>Cooooo000eooooo`;o0000B_oo
ool00ol0003oooooooooo`3Tooooo`00=oooool2o`0004Sooooo00?o0000ooooooooool0i?ooool0
03Wooooo0_l00016ooooo`03o`000?oooooooooo0>Cooooo000kooooo`;o0000A?ooool00ol0003o
ooooooooo`3Tooooo`00?Oooool2o`0004;ooooo00?o0000ooooooooool0i?ooool003oooooo0_l0
0010ooooo`03o`000?oooooooooo0>Cooooo0011ooooo`;o0000?_ooool00ol0003oooooooooo`3T
ooooo`00@oooool3o`00023ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0000Kooooo00?o0000ooooooooool0i?ooool004Kooooo0ol0000Mooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oo
oooooooo0>Cooooo0019ooooo`;o00006oooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`3Tooooo`00Boooool3o`0001Sooooo00Go0000
ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003Tooooo`00C_ooool2
o`0001Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o
0000ooooooooool0i?ooool0053ooooo00?o0000ooooooooool04oooool01Ol@413ooooooooooooo
oooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3Tooooo`00DOooool2
o`0001?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
1_ooool00ol0003oooooooooo`3Tooooo`00Doooool2o`00017ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3Tooooo`00
EOooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0>Cooooo001Fooooo`;o0000:Ooo
ool00ol0003oooooooooo`3Tooooo`00F?ooool2o`0002Oooooo00?o0000ooooooooool0i?ooool0
05[ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`3Tooooo`00Foooool2o`0002Co
oooo00?o0000ooooooooool0i?ooool005gooooo0_l0000Rooooo`?o0000i?ooool005oooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`3Tooooo`00H?ooool2o`0001oooooo00?o0000
ooooooooool0i?ooool006;ooooo0_l0000Mooooo`03o`000?oooooooooo0>Cooooo001Tooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool0i?ooool006Gooooo0_l0000Jooooo`03o`00
0?oooooooooo0>Cooooo001Wooooo`;o00006?ooool00ol0003oooooooooo`3Tooooo`00JOooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0>Cooooo001Zooooo`;o00005Oooool00ol0
003oooooooooo`3Tooooo`00K?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0>Co
oooo001]ooooo`;o00004_ooool3o`000>Cooooo001_ooooo`;o00004?ooool00ol0003ooooooooo
o`3Tooooo`00LOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0>Cooooo001boooo
o`;o00003Oooool00ol0003oooooooooo`3Tooooo`00M?ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo0>Cooooo001eooooo`;o00002_ooool00ol0003oooooooooo`3Tooooo`00Mooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0>Cooooo001hooooo`;o00001oooool0
0ol0003oooooooooo`3Tooooo`00N_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
0>Cooooo001kooooo`;o00001?ooool00ol0003oooooooooo`3Tooooo`00OOooool01?l0003ooooo
ooooooooool3o`000>Cooooo001nooooo`04o`000?ooooooooooo`000>Kooooo001oooooo`?o0000
i_ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo0ol0003Tooooo`00POooool01?l0
003oooooooooool0003Sooooo`00POooool01Ol0003ooooooooooooooooo00000>;ooooo001Voooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo0_l0003Pooooo`00I_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3Mooooo`00I_ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0g?ooool006Kooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol00006ooooo`;o0000g?oo
ool006Kooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`3Iooooo`00I_ooool01Ol@413ooooooooo
oooooooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo0=Sooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4
o`000007ooooo`03o`000?oooooooooo00[ooooo0_l0003Hooooo`00I_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo0=Gooooo0021ooooo`03o`000?oooooooooo00gooooo0_l0003Eooooo`00POooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0=;ooooo0021ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0dOooool0087ooooo00?o0000ooooooooool04Oooool2o`000=7o
oooo0021ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0c_ooool0087ooooo0ol0
000Dooooo`;o0000c_ooool0087ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`3;
ooooo`00POooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0<[ooooo0021ooooo`03
o`000?oooooooooo01Sooooo0_l0003:ooooo`00POooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo0<Oooooo0021ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0a_oo
ool0087ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`35ooooo`00POooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo0<Cooooo0021ooooo`03o`000?oooooooooo01ko
oooo0_l00034ooooo`00POooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0<7ooooo
0021ooooo`?o00008Oooool00ol0003oooooooooo`30ooooo`00POooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo0;oooooo0021ooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool0__ooool0087ooooo00?o0000ooooooooool09?ooool2o`000;kooooo0021ooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool0^oooool0087ooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`2jooooo`00POooool00ol0003oooooooooo`0Xooooo`;o0000^_ooool0
087ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`2gooooo`00POooool00ol0003o
ooooooooo`0[ooooo`03o`000?oooooooooo0;Kooooo0021ooooo`03o`000?oooooooooo02cooooo
00?o0000ooooooooool0]Oooool0087ooooo0ol0000]ooooo`;o0000]Oooool0087ooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`2booooo`00POooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo0;7ooooo0021ooooo`03o`000?oooooooooo037ooooo0_l0002aooooo`00
POooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo0:kooooo0021ooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool0[Oooool0087ooooo00?o0000ooooooooool0=Oooool0
0ol0003oooooooooo`2/ooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo0:_ooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
EEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo03Oooooo0_l0002[ooooo`00I_oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool0Z?ooool006Kooooo00Go0000oooooooooooo
ooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0003[ooooo00?o0000oooo
ooooool0Yoooool006Kooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000
oa0@4?o<c<`01_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0:Kooooo001Voooo
o`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool0YOooool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`2T
ooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_oo
ool00ol0003oooooooooo`0nooooo`;o0000Y?ooool0087ooooo00?o0000ooooooooool0@?ooool0
0ol0003oooooooooo`2Qooooo`00POooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo
0:3ooooo0021ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0Woooool0087ooooo
00?o0000ooooooooool0@oooool00ol0003oooooooooo`2Nooooo`00POooool00ol0003ooooooooo
o`14ooooo`03o`000?oooooooooo09gooooo0021ooooo`?o0000AOooool00ol0003oooooooooo`2L
ooooo`00POooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo09_ooooo0021ooooo`03
o`000?oooooooooo04Oooooo00?o0000ooooooooool0V_ooool0087ooooo00?o0000ooooooooool0
B?ooool00ol0003oooooooooo`2Iooooo`00POooool00ol0003oooooooooo`19ooooo`03o`000?oo
oooooooo09Sooooo0021ooooo`03o`000?oooooooooo04[ooooo0_l0002Hooooo`00POooool00ol0
003oooooooooo`1<ooooo`03o`000?oooooooooo09Gooooo0021ooooo`03o`000?oooooooooo04go
oooo0_l0002Eooooo`00POooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo09;ooooo
0021ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0TOooool0087ooooo0ol0001A
ooooo`;o0000TOooool0087ooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`2>oooo
o`00POooool00ol0003oooooooooo`1Dooooo`;o0000S_ooool0087ooooo00?o0000ooooooooool0
E_ooool00ol0003oooooooooo`2;ooooo`00POooool00ol0003oooooooooo`1Gooooo`03o`000?oo
oooooooo08[ooooo0021ooooo`03o`000?oooooooooo05Sooooo0_l0002:ooooo`00POooool00ol0
003oooooooooo`1Jooooo`03o`000?oooooooooo08Oooooo0021ooooo`03o`000?oooooooooo05_o
oooo00?o0000ooooooooool0Q_ooool0087ooooo00?o0000ooooooooool0G?ooool2o`0008Kooooo
0021ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0Poooool0087ooooo0ol0001O
ooooo`03o`000?oooooooooo08;ooooo0021ooooo`03o`000?oooooooooo063ooooo00?o0000oooo
ooooool0POooool0087ooooo00?o0000ooooooooool0HOooool2o`00087ooooo0021ooooo`03o`00
0?oooooooooo06?ooooo00?o0000ooooooooool0O_ooool0087ooooo00?o0000ooooooooool0I?oo
ool00ol0003oooooooooo`1mooooo`00POooool00ol0003oooooooooo`1Uooooo`;o0000OOooool0
087ooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`1jooooo`00I_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`1Xooooo`03o`000?oooooooooo07Wooooo001Vooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oo
oooooooo06Wooooo0_l0001iooooo`00I_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0
M_ooool006Kooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb
<S801_ooool3o`0006cooooo00?o0000ooooooooool0MOooool006Kooooo00Go0000oooooooooooo
ooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`1]oooo
o`;o0000MOooool006Kooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooo
okZj^_l@41001_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo07;ooooo001Voooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o
0000ooooooooool0L?ooool00ol0003oooooooooo`1aooooo`00I_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo077ooooo
0_l0001aooooo`00POooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo06kooooo0021
ooooo`03o`000?oooooooooo07Cooooo0_l0001^ooooo`00POooool00ol0003oooooooooo`1foooo
o`03o`000?oooooooooo06_ooooo0021ooooo`03o`000?oooooooooo07Oooooo0_l0001[ooooo`00
POooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo06Sooooo0021ooooo`?o0000N_oo
ool00ol0003oooooooooo`1Wooooo`00POooool00ol0003oooooooooo`1kooooo`;o0000Ioooool0
087ooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`1Tooooo`00POooool00ol0003o
ooooooooo`1nooooo`;o0000I?ooool0087ooooo00?o0000ooooooooool0P?ooool00ol0003ooooo
ooooo`1Qooooo`00POooool00ol0003oooooooooo`21ooooo`;o0000HOooool0087ooooo00?o0000
ooooooooool0Poooool2o`0005oooooo0021ooooo`03o`000?oooooooooo08Gooooo00?o0000oooo
ooooool0G?ooool0087ooooo00?o0000ooooooooool0Q_ooool2o`0005cooooo0021ooooo`03o`00
0?oooooooooo08Sooooo0_l0001Jooooo`00POooool3o`0008[ooooo00?o0000ooooooooool0Eooo
ool0087ooooo00?o0000ooooooooool0Roooool2o`0005Oooooo0021ooooo`03o`000?oooooooooo
08gooooo0_l0001Eooooo`00POooool00ol0003oooooooooo`2?ooooo`;o0000Doooool0087ooooo
00?o0000ooooooooool0TOooool2o`00057ooooo0021ooooo`03o`000?oooooooooo09?ooooo00?o
0000ooooooooool0C_ooool0087ooooo00?o0000ooooooooool0U?ooool2o`0004kooooo0021oooo
o`03o`000?oooooooooo09Kooooo0_l0001<ooooo`00POooool00ol0003oooooooooo`2Hooooo`;o
0000B_ooool0087ooooo00?o0000ooooooooool0V_ooool3o`0004Oooooo0021ooooo`?o0000WOoo
ool3o`0004Cooooo0021ooooo`03o`000?oooooooooo0:3ooooo0_l00012ooooo`00POooool00ol0
003oooooooooo`2Rooooo`?o0000?oooool0087ooooo00?o0000ooooooooool0YOooool3o`0003co
oooo0021ooooo`03o`000?oooooooooo0:Sooooo0ol0000iooooo`00POooool00ol0003ooooooooo
o`2[ooooo`?o0000=_ooool0087ooooo00?o0000ooooooooool0[_ooool3o`0003?ooooo001goooo
o`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`2aooooo`Go0000;_ooool007Wo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2fooooo`Go0000:Oooool007Wooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`2kooooo`[o00007oooool007Wooooo00?o
0000ooooooooool01Oooool3o`000<Gooooo1ol0000Hooooo`00NOooool00ol0003oooooooooo`3/
ooooo`00NOooool00ol0003oooooooooo`3/ooooo`00NOooool00ol0003oooooooooo`3/ooooo`00
Moooool00omEEEGoIVIVo`00003^ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-12, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.32877 .12361 -18 -4.5 ]
[.32877 .12361 0 4.5 ]
[.32877 .24721 -18 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -18 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -18 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-5)] .18254 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(10)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(15)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.34127 .12361 m
.34752 .12361 L
s
[(0.2)] .32877 .12361 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(0.4)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(0.6)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(0.8)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(1)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0309 m
.34502 .0309 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .09271 m
.34502 .09271 L
s
.34127 .15451 m
.34502 .15451 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .21631 m
.34502 .21631 L
s
.34127 .27812 m
.34502 .27812 L
s
.34127 .30902 m
.34502 .30902 L
s
.34127 .33992 m
.34502 .33992 L
s
.34127 .40172 m
.34502 .40172 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .46353 m
.34502 .46353 L
s
.34127 .52533 m
.34502 .52533 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .58713 m
.34502 .58713 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .08521 m
.06244 .09774 L
.10458 .11288 L
.14415 .12855 L
.18221 .14495 L
.22272 .16385 L
.26171 .18342 L
.30316 .20567 L
.34309 .22842 L
.3815 .25144 L
.42237 .27698 L
.46172 .30246 L
.49955 .32757 L
.53984 .35477 L
.57861 .38114 L
.61984 .4091 L
.65954 .43566 L
.69774 .46057 L
.73838 .48606 L
.77751 .50931 L
.81909 .53229 L
.85916 .55242 L
.89771 .56965 L
.93871 .58541 L
.97619 .59729 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h/ooooo`05odA4A?l0003o0000oc8b<_oMgMd0G_ooool01Om4A4Co0000o`000?lb<S;ogMgM02[o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^:?ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0Tooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01?ooooo000Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0_ooooo`03ogMgMolb<S;ooooo063ooooo00?oMgMgoc8b<_ooool0:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo02Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL04oooool000oooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Sooooo`Ko00001oooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000;oooool00omgMgOo<S8booooo`1Pooooo`03ogMgMolb<S;ooooo02_o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002[ooooo00?o0000oooo
ooooool01_ooool00omgMgOo<S8booooo`0Vooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000;?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<05kooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00/ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Zooooo`03
o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Xooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@4100;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Aooooo`006_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Wooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01?ooooo000Hooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0/ooooo`Co0000Goooool4o`0002_ooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo00?oEEEEofIVI_l000001Oooool4o`0002Kooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001?ooooo
ool00016o`00013ooooo000Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo000Jooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01Kooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Co
oooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021
ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03
o`000?oooooooooo0>Cooooo0021ooooo`?o0000i?ooool0087ooooo00?o0000ooooooooool0i?oo
ool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087o
oooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o
0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000oooo
ooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo0ol0003Tooooo`00POoo
ool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0
003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003ooooo
ooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3T
ooooo`006_ooool3o`0006Cooooo00?o0000ooooooooool0i?ooool001gooooo0ol0001Qooooo`03
o`000?oooooooooo0>Cooooo000Pooooo`?o0000G_ooool3o`000>Cooooo000Sooooo`?o0000Fooo
ool00ol0003oooooooooo`3Tooooo`009_ooool3o`0005Sooooo00?o0000ooooooooool0i?ooool0
02Wooooo0ol0001Eooooo`03o`000?oooooooooo0>Cooooo000/ooooo`?o0000D_ooool00ol0003o
ooooooooo`3Tooooo`00;oooool3o`0004oooooo00?o0000ooooooooool0i?ooool003;ooooo0ol0
001<ooooo`03o`000?oooooooooo0>Cooooo000eooooo`;o0000B_ooool00ol0003oooooooooo`3T
ooooo`00=oooool3o`0002cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0000Kooooo00?o0000ooooooooool0i?ooool003[ooooo0_l0000Zooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oo
oooooooo0>Cooooo000looooo`;o0000:?ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`3Tooooo`00?_ooool3o`0002Gooooo00Go0000
ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003Tooooo`00@Oooool2
o`0002?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o
0000ooooooooool0i?ooool004?ooooo0ol0000Pooooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0>Cooooo0016ooooo`?o00007Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`00
0?oooooooooo0>Cooooo0019ooooo`;o00006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0>Cooooo001;ooooo`?o0000
<oooool00ol0003oooooooooo`3Tooooo`00C_ooool2o`00037ooooo00?o0000ooooooooool0i?oo
ool0053ooooo0_l0000_ooooo`03o`000?oooooooooo0>Cooooo001Booooo`;o0000;Oooool00ol0
003oooooooooo`3Tooooo`00E?ooool2o`0002_ooooo00?o0000ooooooooool0i?ooool005Kooooo
00?o0000ooooooooool0:?ooool3o`000>Cooooo001Gooooo`;o0000:?ooool00ol0003ooooooooo
o`3Tooooo`00FOooool2o`0002Kooooo00?o0000ooooooooool0i?ooool005_ooooo0_l0000Toooo
o`03o`000?oooooooooo0>Cooooo001Mooooo`;o00008_ooool00ol0003oooooooooo`3Tooooo`00
Goooool2o`00023ooooo00?o0000ooooooooool0i?ooool0067ooooo0_l0000Nooooo`03o`000?oo
oooooooo0>Cooooo001Sooooo`;o00007?ooool00ol0003oooooooooo`3Tooooo`00IOooool2o`00
01[ooooo00?o0000ooooooooool0i?ooool006Oooooo0_l0000Hooooo`03o`000?oooooooooo0>Co
oooo001Yooooo`;o00005_ooool3o`000>Cooooo001[ooooo`;o00005?ooool00ol0003ooooooooo
o`3Tooooo`00KOooool2o`0001;ooooo00?o0000ooooooooool0i?ooool006oooooo0_l0000@oooo
o`03o`000?oooooooooo0>Cooooo001aooooo`;o00003_ooool00ol0003oooooooooo`3Tooooo`00
Loooool2o`0000cooooo00?o0000ooooooooool0i?ooool007Gooooo0_l0000:ooooo`03o`000?oo
oooooooo0>Cooooo001gooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0i?ooool0
07Sooooo0_l00007ooooo`03o`000?oooooooooo0>Cooooo001jooooo`;o00001Oooool00ol0003o
ooooooooo`3Tooooo`00O?ooool00ol0003oooooooooo`02ooooo`?o0000i?ooool007gooooo0_l0
0002ooooo`03o`000?oooooooooo0>Cooooo001oooooo`?o0000i_ooool0087ooooo00?o0000oooo
ooooool0i?ooool0087ooooo0ol0003Tooooo`00POooool00ol0003oooooooooo`02o`000>;ooooo
0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0goooool006Kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool00oooool2o`000=oooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`;o0000gOoo
ool006Kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0=[ooooo001Vooooo`05o`000?ooooooooooooooool000002ooo
ool01?m4A4CogMgMooooool00007ooooo`?o00002?ooool2o`000=[ooooo001Vooooo`05o`000?oo
ooooooooooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo00[o
oooo0_l0003Hooooo`00I_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l0
00001oooool00ol0003oooooooooo`0<ooooo`;o0000e_ooool006Kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`3Cooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?oo
ool01_ooool00ol0003oooooooooo`0?ooooo`;o0000doooool0087ooooo00?o0000ooooooooool0
4Oooool2o`000=7ooooo0021ooooo`03o`000?oooooooooo01?ooooo0_l0003?ooooo`00POooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0<cooooo0021ooooo`03o`000?oooooooooo
01Kooooo0_l0003<ooooo`00POooool00ol0003oooooooooo`0Hooooo`;o0000b_ooool0087ooooo
0ol0000Jooooo`03o`000?oooooooooo0<Oooooo0021ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool0a_ooool0087ooooo00?o0000ooooooooool07?ooool2o`000<Kooooo0021oooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool0`oooool0087ooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`32ooooo`00POooool00ol0003oooooooooo`0Pooooo`;o0000
`_ooool0087ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`2oooooo`00POooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo0;kooooo0021ooooo`03o`000?oooooooooo
02Cooooo0_l0002nooooo`00POooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo0;_o
oooo0021ooooo`?o00009oooool2o`000;_ooooo0021ooooo`03o`000?oooooooooo02Wooooo0_l0
002iooooo`00POooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo0;Kooooo0021oooo
o`03o`000?oooooooooo02cooooo0_l0002fooooo`00POooool00ol0003oooooooooo`0^ooooo`;o
0000]?ooool0087ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`2aooooo`00POoo
ool00ol0003oooooooooo`0aooooo`;o0000/Oooool0087ooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`2^ooooo`00POooool00ol0003oooooooooo`0dooooo`;o0000[_ooool0087o
oooo00?o0000ooooooooool0=_ooool2o`000:cooooo0021ooooo`?o0000>?ooool00ol0003ooooo
ooooo`2Yooooo`00POooool00ol0003oooooooooo`0iooooo`;o0000ZOooool0087ooooo00?o0000
ooooooooool0>oooool2o`000:Oooooo0021ooooo`03o`000?oooooooooo03gooooo00?o0000oooo
ooooool0Y?ooool0087ooooo00?o0000ooooooooool0?_ooool2o`000:Cooooo0021ooooo`03o`00
0?oooooooooo043ooooo00?o0000ooooooooool0XOooool0087ooooo00?o0000ooooooooool0@Ooo
ool00ol0003oooooooooo`2Pooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`12ooooo`;o0000
X?ooool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMg
oooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`2Mooooo`00
I_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0W?ooool006Kooooo00Go0000oooooooo
ooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0004Kooooo0_l0002L
ooooo`00I_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<
c006ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0VOooool006Kooooo00Go410@
oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0BOoo
ool00ol0003oooooooooo`2Hooooo`00I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o
gMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`1:ooooo`;o0000V?ooool006Kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0
C?ooool00ol0003oooooooooo`2Eooooo`00POooool00ol0003oooooooooo`1=ooooo`;o0000UOoo
ool0087ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`2Booooo`00POooool00ol0
003oooooooooo`1@ooooo`;o0000T_ooool0087ooooo00?o0000ooooooooool0D_ooool2o`00093o
oooo0021ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0SOooool0087ooooo0ol0
001Eooooo`;o0000SOooool0087ooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`2:
ooooo`00POooool00ol0003oooooooooo`1Hooooo`;o0000R_ooool0087ooooo00?o0000oooooooo
ool0F_ooool00ol0003oooooooooo`27ooooo`00POooool00ol0003oooooooooo`1Kooooo`;o0000
Qoooool0087ooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`24ooooo`00POooool0
0ol0003oooooooooo`1Nooooo`;o0000Q?ooool0087ooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`21ooooo`00POooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo083o
oooo0021ooooo`03o`000?oooooooooo06;ooooo0_l00020ooooo`00POooool3o`0006Cooooo00?o
0000ooooooooool0OOooool0087ooooo00?o0000ooooooooool0IOooool2o`0007gooooo0021oooo
o`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0N_ooool0087ooooo00?o0000oooooooo
ool0J?ooool2o`0007[ooooo0021ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0
Moooool0087ooooo00?o0000ooooooooool0Joooool2o`0007Oooooo0021ooooo`03o`000?oooooo
oooo06gooooo00?o0000ooooooooool0M?ooool0087ooooo00?o0000ooooooooool0K_ooool2o`00
07Cooooo0021ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0LOooool0087ooooo
00?o0000ooooooooool0LOooool2o`00077ooooo0021ooooo`?o0000Loooool00ol0003ooooooooo
o`1^ooooo`00POooool00ol0003oooooooooo`1dooooo`;o0000K_ooool0087ooooo00?o0000oooo
ooooool0M_ooool2o`0006cooooo0021ooooo`03o`000?oooooooooo07Sooooo00?o0000oooooooo
ool0JOooool0087ooooo00?o0000ooooooooool0NOooool2o`0006Wooooo0021ooooo`03o`000?oo
oooooooo07_ooooo0_l0001Wooooo`00POooool00ol0003oooooooooo`1mooooo`03o`000?oooooo
oooo06Cooooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<
ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo07kooooo0_l0001Tooooo`00I_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40
1_ooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo067ooooo001Vooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool0POooool2o`00067ooooo001Vooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;o
V9RHoooooonHV9So<S8b00Kooooo0ol00023ooooo`;o0000Goooool006Kooooo00Go0000oooooooo
ooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`25
ooooo`03o`000?oooooooooo05cooooo001Vooooo`05oa0@4?ooooooooooooooool@41002oooool0
1Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0Q_ooool2o`0005cooooo001V
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo
00?o0000ooooooooool0R?ooool2o`0005[ooooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0R_ooool00ol0003o
ooooooooo`1Gooooo`00POooool00ol0003oooooooooo`2;ooooo`;o0000Eoooool0087ooooo00?o
0000ooooooooool0SOooool2o`0005Gooooo0021ooooo`03o`000?oooooooooo08oooooo0_l0001C
ooooo`00POooool00ol0003oooooooooo`2Aooooo`;o0000DOooool0087ooooo00?o0000oooooooo
ool0Toooool00ol0003oooooooooo`1>ooooo`00POooool3o`0009Cooooo0_l0001>ooooo`00POoo
ool00ol0003oooooooooo`2Fooooo`;o0000C?ooool0087ooooo00?o0000ooooooooool0V?ooool2
o`0004[ooooo0021ooooo`03o`000?oooooooooo09[ooooo0_l00018ooooo`00POooool00ol0003o
ooooooooo`2Looooo`;o0000A_ooool0087ooooo00?o0000ooooooooool0W_ooool2o`0004Cooooo
0021ooooo`03o`000?oooooooooo0:3ooooo00?o0000ooooooooool0@Oooool0087ooooo00?o0000
ooooooooool0XOooool2o`00047ooooo0021ooooo`03o`000?oooooooooo0:?ooooo0_l0000ooooo
o`00POooool00ol0003oooooooooo`2Uooooo`;o0000?Oooool0087ooooo0ol0002Wooooo`?o0000
>_ooool0087ooooo00?o0000ooooooooool0Z_ooool3o`0003Oooooo0021ooooo`03o`000?oooooo
oooo0:gooooo0_l0000eooooo`00POooool00ol0003oooooooooo`2_ooooo`?o0000<_ooool0087o
oooo00?o0000ooooooooool0/_ooool2o`00033ooooo0021ooooo`03o`000?oooooooooo0;Cooooo
0ol0000]ooooo`00POooool00ol0003oooooooooo`2gooooo`?o0000:_ooool0087ooooo00?o0000
ooooooooool0^_ooool2o`0002Sooooo0021ooooo`03o`000?oooooooooo0;cooooo0ol0000Uoooo
o`00POooool00ol0003oooooooooo`2oooooo`?o00008_ooool0087ooooo0ol00032ooooo`?o0000
7oooool0087ooooo00?o0000ooooooooool0aOooool3o`0001cooooo0021ooooo`03o`000?oooooo
oooo0<Sooooo0ol0000Iooooo`00POooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo
01Kooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo
0021ooooo`03o`000?oooooooooo0>Cooooo001gooooo`Co000000?o410@ooooooooool00oooool0
0ol0003oooooooooo`3Tooooo`00NOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0>Cooooo001iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0i?ooool007Wooooo
00?o0000ooooooooool01Oooool3o`000>Cooooo001iooooo`03o`000?oooooooooo0>cooooo001i
ooooo`03o`000?oooooooooo0>cooooo001iooooo`03o`000?oooooooooo0>cooooo001gooooo`03
oeEEEOmVIVKo00000>kooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-12, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.32877 .12361 -18 -4.5 ]
[.32877 .12361 0 4.5 ]
[.32877 .24721 -18 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -18 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -18 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-5)] .18254 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(10)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(15)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.34127 .12361 m
.34752 .12361 L
s
[(0.2)] .32877 .12361 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(0.4)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(0.6)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(0.8)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(1)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0309 m
.34502 .0309 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .09271 m
.34502 .09271 L
s
.34127 .15451 m
.34502 .15451 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .21631 m
.34502 .21631 L
s
.34127 .27812 m
.34502 .27812 L
s
.34127 .30902 m
.34502 .30902 L
s
.34127 .33992 m
.34502 .33992 L
s
.34127 .40172 m
.34502 .40172 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .46353 m
.34502 .46353 L
s
.34127 .52533 m
.34502 .52533 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .58713 m
.34502 .58713 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .10434 m
.06244 .11609 L
.10458 .12993 L
.14415 .14391 L
.18221 .15825 L
.22272 .17447 L
.26171 .191 L
.30316 .20952 L
.34309 .22823 L
.3815 .24699 L
.42237 .26768 L
.46172 .28823 L
.49955 .30848 L
.53984 .33045 L
.57861 .35188 L
.61984 .37483 L
.65954 .39693 L
.69774 .41805 L
.73838 .44019 L
.77751 .46102 L
.81909 .48244 L
.85916 .5022 L
.89771 .52024 L
.93871 .53819 L
.97619 .55334 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h/ooooo`05odA4A?l0003o0000oc8b<_oMgMd0G_ooool01Om4A4Co0000o`000?lb<S;ogMgM02[o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^:?ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0Tooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01?ooooo000Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0_ooooo`03ogMgMolb<S;ooooo063ooooo00?oMgMgoc8b<_ooool0:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo02Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL04oooool000oooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Sooooo`Ko00001oooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000;oooool00omgMgOo<S8booooo`1Pooooo`03ogMgMolb<S;ooooo02_o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002[ooooo00?o0000oooo
ooooool01_ooool00omgMgOo<S8booooo`0Vooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000;?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<05kooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00/ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Zooooo`03
o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Xooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@4100;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Aooooo`006_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Wooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01?ooooo000Hooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0/ooooo`Co0000Goooool4o`0002_ooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo00?oEEEEofIVI_l000001Oooool4o`0002Kooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001?ooooo
ool00016o`00013ooooo000Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo000Jooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01Kooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Co
oooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021
ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03
o`000?oooooooooo0>Cooooo0021ooooo`?o0000i?ooool0087ooooo00?o0000ooooooooool0i?oo
ool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087o
oooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o
0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000oooo
ooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo0ol0003Tooooo`00POoo
ool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0
003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003ooooo
ooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3T
ooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00
POooool3o`000>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooo
oooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo000Jooooo`?o0000I?ooool00ol0003o
ooooooooo`3Tooooo`007Oooool3o`00067ooooo00?o0000ooooooooool0i?ooool0023ooooo0ol0
001Nooooo`03o`000?oooooooooo0>Cooooo000Sooooo`?o0000Foooool00ol0003oooooooooo`3T
ooooo`009_ooool3o`0003gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0000Kooooo00?o0000ooooooooool0i?ooool002Wooooo0ol0000jooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oo
oooooooo0>Cooooo000/ooooo`?o0000=oooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`3Tooooo`00;oooool3o`0003Cooooo00Go0000
ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003Tooooo`00<_ooool3
o`00037ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o
0000ooooooooool0i?ooool003Gooooo0ol0000^ooooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0>Cooooo000hooooo`?o0000:oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`00
0?oooooooooo0>Cooooo000kooooo`?o0000:?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0>Cooooo000nooooo`?o0000
@?ooool00ol0003oooooooooo`3Tooooo`00@Oooool2o`0003kooooo00?o0000ooooooooool0i?oo
ool004?ooooo0ol0000kooooo`03o`000?oooooooooo0>Cooooo0016ooooo`?o0000>?ooool00ol0
003oooooooooo`3Tooooo`00BOooool2o`0003Kooooo00?o0000ooooooooool0i?ooool004_ooooo
0ol0000cooooo`?o0000i?ooool004kooooo0_l0000aooooo`03o`000?oooooooooo0>Cooooo001@
ooooo`?o0000;_ooool00ol0003oooooooooo`3Tooooo`00Doooool3o`0002_ooooo00?o0000oooo
ooooool0i?ooool005Kooooo0_l0000Yooooo`03o`000?oooooooooo0>Cooooo001Hooooo`?o0000
9_ooool00ol0003oooooooooo`3Tooooo`00Foooool2o`0002Cooooo00?o0000ooooooooool0i?oo
ool005gooooo0ol0000Qooooo`03o`000?oooooooooo0>Cooooo001Pooooo`;o00007oooool00ol0
003oooooooooo`3Tooooo`00H_ooool2o`0001gooooo00?o0000ooooooooool0i?ooool006Cooooo
0ol0000Jooooo`?o0000i?ooool006Oooooo0_l0000Hooooo`03o`000?oooooooooo0>Cooooo001Y
ooooo`?o00005Oooool00ol0003oooooooooo`3Tooooo`00K?ooool2o`0001?ooooo00?o0000oooo
ooooool0i?ooool006kooooo0_l0000Aooooo`03o`000?oooooooooo0>Cooooo001`ooooo`?o0000
3_ooool00ol0003oooooooooo`3Tooooo`00Loooool2o`0000cooooo00?o0000ooooooooool0i?oo
ool007Gooooo0_l0000:ooooo`03o`000?oooooooooo0>Cooooo001gooooo`;o00002?ooool00ol0
003oooooooooo`3Tooooo`00NOooool2o`0000Kooooo00?o0000ooooooooool0i?ooool007_ooooo
0ol00003ooooo`?o0000i?ooool007kooooo0_l000000ooooooo0000ooooo`3Uooooo`00P?ooool2
o`000>Kooooo0021ooooo`?o0000i?ooool0087ooooo00?o0000ooooooooool00_l0003Rooooo`00
POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0=oooooo0021ooooo`03o`000?oo
oooooooo00?ooooo0_l0003Oooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`05ooooo`;o0000gOoo
ool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0f_ooool006Kooooo00Go410@
oooooooooooooooooa0@400;ooooo`Go00001_ooool00ol0003oooooooooo`08ooooo`;o0000f_oo
ool006Kooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo
0ol0000:ooooo`;o0000f?ooool006Kooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgM
gOmEEEGoooooo`0000Oooooo00?o0000ooooooooool03?ooool3o`000=Gooooo001Vooooo`05oa0@
4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo00oo
oooo0_l0003Cooooo`00I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l0
00001oooool00ol0003oooooooooo`0Aooooo`;o0000dOooool006Kooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool04oooool3o`000<ko
oooo0021ooooo`03o`000?oooooooooo01Kooooo0_l0003<ooooo`00POooool00ol0003ooooooooo
o`0Hooooo`;o0000b_ooool0087ooooo00?o0000ooooooooool06_ooool2o`000<Sooooo0021oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool0aOooool0087ooooo00?o0000oooooooo
ool07Oooool2o`000<Gooooo0021ooooo`?o00007oooool2o`000<?ooooo0021ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0`?ooool0087ooooo00?o0000ooooooooool08_ooool2
o`000<3ooooo0021ooooo`03o`000?oooooooooo02Cooooo0_l0002nooooo`00POooool00ol0003o
ooooooooo`0Vooooo`;o0000_?ooool0087ooooo00?o0000ooooooooool0:?ooool2o`000;[ooooo
0021ooooo`03o`000?oooooooooo02[ooooo0ol0002gooooo`00POooool00ol0003oooooooooo`0]
ooooo`;o0000]Oooool0087ooooo00?o0000ooooooooool0;oooool2o`000;?ooooo0021ooooo`03
o`000?oooooooooo037ooooo0_l0002aooooo`00POooool3o`0003?ooooo00?o0000ooooooooool0
[_ooool0087ooooo00?o0000ooooooooool0=?ooool2o`000:kooooo0021ooooo`03o`000?oooooo
oooo03Kooooo0_l0002/ooooo`00POooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
0:Wooooo0021ooooo`03o`000?oooooooooo03Wooooo0_l0002Yooooo`00POooool00ol0003ooooo
ooooo`0kooooo`;o0000Yoooool0087ooooo00?o0000ooooooooool0?Oooool00ol0003ooooooooo
o`2Tooooo`00POooool00ol0003oooooooooo`0nooooo`;o0000Y?ooool0087ooooo00?o0000oooo
ooooool0@?ooool2o`000:;ooooo0021ooooo`03o`000?oooooooooo04;ooooo00?o0000oooooooo
ool0Woooool0087ooooo0ol00013ooooo`;o0000Woooool0087ooooo00?o0000ooooooooool0AOoo
ool2o`0009gooooo0021ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0V_ooool0
087ooooo00?o0000ooooooooool0B?ooool2o`0009[ooooo0021ooooo`03o`000?oooooooooo04[o
oooo0_l0002Hooooo`00POooool00ol0003oooooooooo`1<ooooo`;o0000U_ooool0087ooooo00?o
0000ooooooooool0C_ooool2o`0009Cooooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo053ooooo
0_l0002Booooo`00I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEE
EOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1Booooo`;o0000T?ooool006Kooooo
00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`1Dooooo`;o0000S_ooool006Kooooo00Go0000ooooooooooooooooo`00000;oooo
o`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0005Kooooo0_l0002<ooooo`00I_ooool01Ol0
003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oo
oooooooo05Sooooo0_l0002:ooooo`00I_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o
EEEEohN7Qoooool02?ooool00ol0003oooooooooo`1Jooooo`;o0000R?ooool006Kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0G?oo
ool2o`0008Kooooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`00
0?l@4106ooooo`03o`000?oooooooooo05kooooo0_l00024ooooo`00POooool00ol0003ooooooooo
o`1Pooooo`03o`000?oooooooooo087ooooo0021ooooo`03o`000?oooooooooo067ooooo0_l00021
ooooo`00POooool00ol0003oooooooooo`1Sooooo`;o0000Ooooool0087ooooo00?o0000oooooooo
ool0IOooool2o`0007gooooo0021ooooo`03o`000?oooooooooo06Oooooo0_l0001kooooo`00POoo
ool3o`0006Wooooo00?o0000ooooooooool0N?ooool0087ooooo00?o0000ooooooooool0J_ooool2
o`0007Sooooo0021ooooo`03o`000?oooooooooo06cooooo0_l0001fooooo`00POooool00ol0003o
ooooooooo`1^ooooo`03o`000?oooooooooo07?ooooo0021ooooo`03o`000?oooooooooo06oooooo
0_l0001cooooo`00POooool00ol0003oooooooooo`1aooooo`;o0000LOooool0087ooooo00?o0000
ooooooooool0Loooool2o`0006oooooo0021ooooo`03o`000?oooooooooo07Gooooo0_l0001]oooo
o`00POooool00ol0003oooooooooo`1gooooo`;o0000Joooool0087ooooo00?o0000ooooooooool0
NOooool00ol0003oooooooooo`1Xooooo`00POooool3o`0007[ooooo0_l0001Xooooo`00POooool0
0ol0003oooooooooo`1looooo`;o0000I_ooool0087ooooo00?o0000ooooooooool0O_ooool2o`00
06Cooooo0021ooooo`03o`000?oooooooooo083ooooo0_l0001Rooooo`00POooool00ol0003ooooo
ooooo`22ooooo`;o0000H?ooool0087ooooo00?o0000ooooooooool0Q?ooool2o`0005kooooo0021
ooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool0Foooool0087ooooo00?o0000oooo
ooooool0Qoooool2o`0005_ooooo0021ooooo`03o`000?oooooooooo08Wooooo0_l0001Iooooo`00
POooool00ol0003oooooooooo`2;ooooo`;o0000Eoooool0087ooooo0ol0002=ooooo`;o0000EOoo
ool0087ooooo00?o0000ooooooooool0Soooool2o`0005?ooooo0021ooooo`03o`000?oooooooooo
097ooooo0_l0001Aooooo`00POooool00ol0003oooooooooo`2Cooooo`03o`000?oooooooooo04ko
oooo0021ooooo`03o`000?oooooooooo09Cooooo0_l0001>ooooo`00POooool00ol0003ooooooooo
o`2Fooooo`;o0000C?ooool0087ooooo00?o0000ooooooooool0V?ooool2o`0004[ooooo001Voooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<
c006ooooo`03o`000?oooooooooo09[ooooo0_l00018ooooo`00I_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`2Looooo`;o0000A_ooool006Kooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`2Nooooo`?o0000@oooool006Kooooo
00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`00
0:7ooooo0_l00011ooooo`00I_ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`00
0?l0003o0000olc<c006ooooo`03o`000?oooooooooo0:?ooooo0_l0000oooooo`00I_ooool01Ol@
413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oo
oooooooo0:Gooooo0_l0000mooooo`00I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0:Oooooo0_l0000kooooo`00I_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03
o`000?oooooooooo0:Wooooo0_l0000iooooo`00POooool00ol0003oooooooooo`2[ooooo`?o0000
=_ooool0087ooooo00?o0000ooooooooool0[_ooool2o`0003Cooooo0021ooooo`03o`000?oooooo
oooo0;3ooooo0_l0000booooo`00POooool00ol0003oooooooooo`2booooo`;o0000<?ooool0087o
oooo00?o0000ooooooooool0]?ooool2o`0002kooooo0021ooooo`?o0000]_ooool2o`0002cooooo
0021ooooo`03o`000?oooooooooo0;Sooooo0ol0000Yooooo`00POooool00ol0003oooooooooo`2k
ooooo`;o00009oooool0087ooooo00?o0000ooooooooool0_Oooool2o`0002Gooooo0021ooooo`03
o`000?oooooooooo0;oooooo0_l0000Sooooo`00POooool00ol0003oooooooooo`31ooooo`?o0000
8?ooool0087ooooo00?o0000ooooooooool0a?ooool2o`0001kooooo0021ooooo`03o`000?oooooo
oooo0<Kooooo0_l0000Looooo`00POooool00ol0003oooooooooo`38ooooo`?o00006Oooool0087o
oooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Fooooo`00POooool3o`000>Cooooo
0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021oooo
o`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`00
0?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooo
oooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Co
oooo0021ooooo`?o0000i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000
ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000oooooooo
ool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?oo
ool007Oooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0>Cooooo001ioooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0i?ooool007Wooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3Tooooo`00NOooool00ol0003oooooooooo`05ooooo`?o0000
i?ooool007Wooooo00?o0000ooooooooool0k?ooool007Wooooo00?o0000ooooooooool0k?ooool0
07Wooooo00?o0000ooooooooool0k?ooool007Oooooo00?oEEEEofIVI_l00000k_ooool00?oooooo
JOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-12, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.32877 .12361 -18 -4.5 ]
[.32877 .12361 0 4.5 ]
[.32877 .24721 -18 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -18 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -18 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-5)] .18254 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(10)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(15)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.34127 .12361 m
.34752 .12361 L
s
[(0.2)] .32877 .12361 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(0.4)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(0.6)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(0.8)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(1)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0309 m
.34502 .0309 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .09271 m
.34502 .09271 L
s
.34127 .15451 m
.34502 .15451 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .21631 m
.34502 .21631 L
s
.34127 .27812 m
.34502 .27812 L
s
.34127 .30902 m
.34502 .30902 L
s
.34127 .33992 m
.34502 .33992 L
s
.34127 .40172 m
.34502 .40172 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .46353 m
.34502 .46353 L
s
.34127 .52533 m
.34502 .52533 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .58713 m
.34502 .58713 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12217 m
.06244 .13282 L
.10458 .14513 L
.14415 .15735 L
.18221 .16969 L
.22272 .18347 L
.26171 .19733 L
.30316 .21269 L
.34309 .22807 L
.3815 .24337 L
.42237 .26015 L
.46172 .27675 L
.49955 .29308 L
.53984 .3108 L
.57861 .32812 L
.61984 .34674 L
.65954 .36481 L
.69774 .38223 L
.73838 .40074 L
.77751 .41843 L
.81909 .437 L
.85916 .45457 L
.89771 .47108 L
.93871 .48812 L
.97619 .50313 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h/ooooo`05odA4A?l0003o0000oc8b<_oMgMd0G_ooool01Om4A4Co0000o`000?lb<S;ogMgM02[o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^:?ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0Tooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01?ooooo000Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0_ooooo`03ogMgMolb<S;ooooo063ooooo00?oMgMgoc8b<_ooool0:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo02Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL04oooool000oooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Sooooo`Ko00001oooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000;oooool00omgMgOo<S8booooo`1Pooooo`03ogMgMolb<S;ooooo02_o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002[ooooo00?o0000oooo
ooooool01_ooool00omgMgOo<S8booooo`0Vooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000;?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<05kooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00/ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Zooooo`03
o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Xooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@4100;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Aooooo`006_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Wooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01?ooooo000Hooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0/ooooo`Co0000Goooool4o`0002_ooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo00?oEEEEofIVI_l000001Oooool4o`0002Kooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001?ooooo
ool00016o`00013ooooo000Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo000Jooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01Kooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Co
oooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021
ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03
o`000?oooooooooo0>Cooooo0021ooooo`?o0000i?ooool0087ooooo00?o0000ooooooooool0i?oo
ool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087o
oooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o
0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000oooo
ooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo0ol0003Tooooo`00POoo
ool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0
003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003ooooo
ooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3T
ooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00
POooool3o`000>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooo
oooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Co
oooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021
ooooo`03o`000?oooooooooo0>Cooooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0>Cooooo001Vooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oo
oooooooo0>Cooooo000Jooooo`?o0000BOooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`3Tooooo`007Oooool3o`0004Kooooo00Go0000
ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003Tooooo`008?ooool3
o`0004?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o
0000ooooooooool0i?ooool002?ooooo0ol00010ooooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0>Cooooo000Vooooo`Co0000??ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`00
0?oooooooooo0>Cooooo000Zooooo`Go0000=oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0>Cooooo000_ooooo`Go0000
COooool00ol0003oooooooooo`3Tooooo`00=?ooool4o`0004Wooooo00?o0000ooooooooool0i?oo
ool003Sooooo0ol00016ooooo`03o`000?oooooooooo0>Cooooo000kooooo`?o0000@oooool00ol0
003oooooooooo`3Tooooo`00?_ooool3o`00043ooooo00?o0000ooooooooool0i?ooool0047ooooo
0ol0000mooooo`?o0000i?ooool004Cooooo0ol0000jooooo`03o`000?oooooooooo0>Cooooo0017
ooooo`?o0000=oooool00ol0003oooooooooo`3Tooooo`00B_ooool3o`0003Cooooo00?o0000oooo
ooooool0i?ooool004gooooo0ol0000aooooo`03o`000?oooooooooo0>Cooooo001@ooooo`?o0000
;_ooool00ol0003oooooooooo`3Tooooo`00Doooool3o`0002_ooooo00?o0000ooooooooool0i?oo
ool005Kooooo0_l0000Yooooo`03o`000?oooooooooo0>Cooooo001Hooooo`?o00009_ooool00ol0
003oooooooooo`3Tooooo`00Foooool3o`0002?ooooo00?o0000ooooooooool0i?ooool005kooooo
0ol0000Pooooo`?o0000i?ooool0067ooooo0ol0000Mooooo`03o`000?oooooooooo0>Cooooo001T
ooooo`?o00006_ooool00ol0003oooooooooo`3Tooooo`00Ioooool2o`0001Sooooo00?o0000oooo
ooooool0i?ooool006Wooooo0ol0000Eooooo`03o`000?oooooooooo0>Cooooo001/ooooo`?o0000
4_ooool00ol0003oooooooooo`3Tooooo`00Koooool3o`0000oooooo00?o0000ooooooooool0i?oo
ool007;ooooo0ol0000<ooooo`03o`000?oooooooooo0>Cooooo001eooooo`;o00002_ooool00ol0
003oooooooooo`3Tooooo`00Moooool3o`0000Oooooo00?o0000ooooooooool0i?ooool007[ooooo
0ol00004ooooo`?o0000i?ooool007gooooo0_l00002ooooo`03o`000?oooooooooo0>Cooooo001o
ooooo`?o0000i_ooool0087ooooo0ol0003Tooooo`00POooool00ol0003oooooooooo`03o`000>7o
oooo0021ooooo`03o`000?oooooooooo00?ooooo0_l0003Oooooo`00POooool00ol0003ooooooooo
o`05ooooo`;o0000gOooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool01oooool3o`000=[ooooo001V
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0:ooooo`;o0000f?ooool006Kooooo00Go410@oooooooooooooooooa0@
400;ooooo`Go00001_ooool00ol0003oooooooooo`0<ooooo`?o0000eOooool006Kooooo00Go0000
ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0000?ooooo`;o0000
doooool006Kooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oo
oooo00?o0000ooooooooool04Oooool2o`000=7ooooo001Vooooo`05oa0@4?ooooooooooooooool@
41003?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo01?ooooo0ol0003>ooooo`00
I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0003o
ooooooooo`0Fooooo`;o0000c?ooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03
ogMgMol0003ooooo00Kooooo00?o0000ooooooooool06?ooool2o`000<[ooooo0021ooooo`03o`00
0?oooooooooo01[ooooo0ol00037ooooo`00POooool00ol0003oooooooooo`0Mooooo`;o0000aOoo
ool0087ooooo00?o0000ooooooooool07oooool2o`000<?ooooo0021ooooo`03o`000?oooooooooo
027ooooo0ol00030ooooo`00POooool00ol0003oooooooooo`0Tooooo`;o0000__ooool0087ooooo
0ol0000Vooooo`?o0000^oooool0087ooooo00?o0000ooooooooool0:Oooool3o`000;Sooooo0021
ooooo`03o`000?oooooooooo02cooooo0_l0002fooooo`00POooool00ol0003oooooooooo`0^oooo
o`?o0000/oooool0087ooooo00?o0000ooooooooool0<Oooool2o`000;7ooooo0021ooooo`03o`00
0?oooooooooo03?ooooo0_l0002_ooooo`00POooool00ol0003oooooooooo`0eooooo`;o0000[Ooo
ool0087ooooo00?o0000ooooooooool0=oooool3o`000:[ooooo0021ooooo`03o`000?oooooooooo
03[ooooo0_l0002Xooooo`00POooool00ol0003oooooooooo`0looooo`;o0000Y_ooool0087ooooo
0ol0000nooooo`;o0000Y?ooool0087ooooo00?o0000ooooooooool0@?ooool2o`000:;ooooo0021
ooooo`03o`000?oooooooooo04;ooooo0_l0002Pooooo`00POooool00ol0003oooooooooo`14oooo
o`;o0000W_ooool0087ooooo00?o0000ooooooooool0A_ooool2o`0009cooooo0021ooooo`03o`00
0?oooooooooo04Sooooo0_l0002Jooooo`00POooool00ol0003oooooooooo`1:ooooo`;o0000V?oo
ool0087ooooo00?o0000ooooooooool0C?ooool3o`0009Gooooo0021ooooo`03o`000?oooooooooo
04oooooo0_l0002Cooooo`00POooool00ol0003oooooooooo`1Aooooo`;o0000TOooool0087ooooo
0ol0001Cooooo`?o0000S_ooool0087ooooo00?o0000ooooooooool0E_ooool2o`0008cooooo0021
ooooo`03o`000?oooooooooo05Sooooo0_l0002:ooooo`00POooool00ol0003oooooooooo`1Joooo
o`;o0000R?ooool0087ooooo00?o0000ooooooooool0G?ooool2o`0008Kooooo0021ooooo`03o`00
0?oooooooooo05kooooo0ol00023ooooo`00POooool00ol0003oooooooooo`1Qooooo`;o0000POoo
ool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`00
0?l@413oc<c<00Kooooo00?o0000ooooooooool0Hoooool2o`0007oooooo001Vooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03
o`000?oooooooooo06Gooooo0_l0001mooooo`00I_ooool01Ol@413ooooooooooooooooo410@00_o
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo06Oooooo0ol0001joooo
o`00I_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06
ooooo`?o0000J_ooool2o`0007Sooooo001Vooooo`05o`000?ooooooooooooooool000002oooool0
1Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0K?ooool2o`0007Kooooo001V
ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo06kooooo0ol0001cooooo`00I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o
gMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`1aooooo`;o0000LOooool006Kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0
Loooool2o`0006oooooo0021ooooo`03o`000?oooooooooo07Gooooo0_l0001]ooooo`00POooool0
0ol0003oooooooooo`1gooooo`?o0000J_ooool0087ooooo00?o0000ooooooooool0N_ooool2o`00
06Sooooo0021ooooo`03o`000?oooooooooo07cooooo0_l0001Vooooo`00POooool00ol0003ooooo
ooooo`1nooooo`;o0000I?ooool0087ooooo0ol00020ooooo`;o0000H_ooool0087ooooo00?o0000
ooooooooool0P_ooool2o`00063ooooo0021ooooo`03o`000?oooooooooo08Cooooo0ol0001Moooo
o`00POooool00ol0003oooooooooo`27ooooo`;o0000Foooool0087ooooo00?o0000ooooooooool0
ROooool2o`0005Wooooo0021ooooo`03o`000?oooooooooo08_ooooo0_l0001Gooooo`00POooool0
0ol0003oooooooooo`2=ooooo`;o0000EOooool0087ooooo00?o0000ooooooooool0Soooool2o`00
05?ooooo0021ooooo`03o`000?oooooooooo097ooooo0ol0001@ooooo`00POooool00ol0003ooooo
ooooo`2Dooooo`;o0000C_ooool0087ooooo0ol0002Fooooo`;o0000C?ooool0087ooooo00?o0000
ooooooooool0V?ooool2o`0004[ooooo0021ooooo`03o`000?oooooooooo09[ooooo0_l00018oooo
o`00POooool00ol0003oooooooooo`2Looooo`;o0000A_ooool0087ooooo00?o0000ooooooooool0
W_ooool3o`0004?ooooo0021ooooo`03o`000?oooooooooo0:7ooooo0_l00011ooooo`00POooool0
0ol0003oooooooooo`2Sooooo`;o0000?oooool0087ooooo00?o0000ooooooooool0YOooool2o`00
03gooooo0021ooooo`03o`000?oooooooooo0:Oooooo0ol0000jooooo`00POooool00ol0003ooooo
ooooo`2Zooooo`?o0000=oooool0087ooooo0ol0002]ooooo`;o0000=Oooool0087ooooo00?o0000
ooooooooool0[oooool3o`0003;ooooo0021ooooo`03o`000?oooooooooo0;;ooooo0_l0000`oooo
o`00POooool00ol0003oooooooooo`2dooooo`;o0000;_ooool0087ooooo00?o0000ooooooooool0
]_ooool2o`0002cooooo0021ooooo`03o`000?oooooooooo0;Sooooo0ol0000Yooooo`00POooool0
0ol0003oooooooooo`2kooooo`;o00009oooool006Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0_Ooo
ool2o`0002Gooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;oooooo0_l0000Sooooo`00I_oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo0<7ooooo0ol0000Pooooo`00I_ooool01Ol0003ooooooooooooooooo000000_o
oooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000a?ooool2o`0001kooooo001Vooooo`05
o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000
ooooooooool0a_ooool2o`0001cooooo001Vooooo`05oa0@4?ooooooooooooooool@41002oooool0
1Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0b?ooool3o`0001Wooooo001V
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo
00?o0000ooooooooool0boooool00ol0003oooooooooo`0Fooooo`00I_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo0>Co
oooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021
ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03
o`000?oooooooooo0>Cooooo0021ooooo`?o0000i?ooool0087ooooo00?o0000ooooooooool0i?oo
ool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087o
oooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o
0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000oooo
ooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo0ol0003Tooooo`00POoo
ool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0
003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003ooooo
ooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3T
ooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00
POooool3o`000>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooo
oooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Co
oooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo001g
ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3Tooooo`00NOooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0>Cooooo001iooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0i?ooool007Wooooo00?o0000ooooooooool01Oooool3o`000>Cooooo
001iooooo`03o`000?oooooooooo0>cooooo001iooooo`03o`000?oooooooooo0>cooooo001ioooo
o`03o`000?oooooooooo0>cooooo001gooooo`03oeEEEOmVIVKo00000>kooooo003oooooofWooooo
0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-12, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.32877 .12361 -18 -4.5 ]
[.32877 .12361 0 4.5 ]
[.32877 .24721 -18 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -18 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -18 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-5)] .18254 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(10)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(15)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.34127 .12361 m
.34752 .12361 L
s
[(0.2)] .32877 .12361 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(0.4)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(0.6)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(0.8)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(1)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0309 m
.34502 .0309 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .09271 m
.34502 .09271 L
s
.34127 .15451 m
.34502 .15451 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .21631 m
.34502 .21631 L
s
.34127 .27812 m
.34502 .27812 L
s
.34127 .30902 m
.34502 .30902 L
s
.34127 .33992 m
.34502 .33992 L
s
.34127 .40172 m
.34502 .40172 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .46353 m
.34502 .46353 L
s
.34127 .52533 m
.34502 .52533 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .58713 m
.34502 .58713 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .13825 m
.06244 .14767 L
.10458 .1584 L
.14415 .16892 L
.18221 .17943 L
.22272 .19104 L
.26171 .20261 L
.30316 .21532 L
.34309 .22794 L
.3815 .24043 L
.42237 .25406 L
.46172 .26749 L
.49955 .28067 L
.53984 .29495 L
.57861 .30892 L
.61984 .32396 L
.65954 .33859 L
.69774 .35278 L
.73838 .36794 L
.77751 .38255 L
.81909 .39806 L
.85916 .41292 L
.89771 .4271 L
.93871 .442 L
.97619 .45541 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h/ooooo`05odA4A?l0003o0000oc8b<_oMgMd0G_ooool01Om4A4Co0000o`000?lb<S;ogMgM02[o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^:?ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0Tooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01?ooooo000Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0_ooooo`03ogMgMolb<S;ooooo063ooooo00?oMgMgoc8b<_ooool0:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo02Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL04oooool000oooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Sooooo`Ko00001oooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000;oooool00omgMgOo<S8booooo`1Pooooo`03ogMgMolb<S;ooooo02_o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002[ooooo00?o0000oooo
ooooool01_ooool00omgMgOo<S8booooo`0Vooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000;?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<05kooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00/ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Zooooo`03
o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Xooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@4100;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Aooooo`006_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Wooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01?ooooo000Hooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0/ooooo`Co0000Goooool4o`0002_ooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo00?oEEEEofIVI_l000001Oooool4o`0002Kooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001?ooooo
ool00016o`00013ooooo000Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo000Jooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01Kooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Co
oooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021
ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03
o`000?oooooooooo0>Cooooo0021ooooo`?o0000i?ooool0087ooooo00?o0000ooooooooool0i?oo
ool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087o
oooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o
0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000oooo
ooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo0ol0003Tooooo`00POoo
ool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0
003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003ooooo
ooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3T
ooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00
POooool3o`000>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooo
oooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Co
oooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021
ooooo`03o`000?oooooooooo0>Cooooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0>Cooooo001Vooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oo
oooooooo0>Cooooo001Vooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^
kP07ooooo`03o`000?oooooooooo0>Cooooo001Vooooo`05o`000?ooooooooooooooool000003Ooo
ool00onHV9So8B4Qonk^kP06ooooo`?o0000i?ooool006Kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0i?ooool006Kooooo00Go410@
oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0i?oo
ool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
1_ooool00ol0003oooooooooo`3Tooooo`006_ooool3o`0004Wooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3Tooooo`00
7Oooool5o`0005oooooo00?o0000ooooooooool0i?ooool002;ooooo1?l0001Kooooo`03o`000?oo
oooooooo0>Cooooo000Vooooo`Co0000Eoooool00ol0003oooooooooo`3Tooooo`00:_ooool3o`00
05Cooooo00?o0000ooooooooool0i?ooool002gooooo1?l0001@ooooo`03o`000?oooooooooo0>Co
oooo000aooooo`?o0000COooool3o`000>Cooooo000dooooo`Co0000BOooool00ol0003ooooooooo
o`3Tooooo`00>?ooool4o`0004Gooooo00?o0000ooooooooool0i?ooool003cooooo1?l00011oooo
o`03o`000?oooooooooo0>Cooooo0010ooooo`Co0000?Oooool00ol0003oooooooooo`3Tooooo`00
A?ooool3o`0003[ooooo00?o0000ooooooooool0i?ooool004Oooooo0ol0000gooooo`03o`000?oo
oooooooo0>Cooooo001:ooooo`?o0000=?ooool00ol0003oooooooooo`3Tooooo`00COooool4o`00
033ooooo00?o0000ooooooooool0i?ooool0057ooooo1Ol0000[ooooo`03o`000?oooooooooo0>Co
oooo001Fooooo`Co00009oooool3o`000>Cooooo001Jooooo`Co00008oooool00ol0003ooooooooo
o`3Tooooo`00G_ooool3o`00023ooooo00?o0000ooooooooool0i?ooool0067ooooo0ol0000Moooo
o`03o`000?oooooooooo0>Cooooo001Tooooo`?o00006_ooool00ol0003oooooooooo`3Tooooo`00
Ioooool3o`0001Oooooo00?o0000ooooooooool0i?ooool006[ooooo0ol0000Dooooo`03o`000?oo
oooooooo0>Cooooo001]ooooo`Co00004?ooool00ol0003oooooooooo`3Tooooo`00LOooool3o`00
00gooooo00?o0000ooooooooool0i?ooool007Cooooo1?l00009ooooo`03o`000?oooooooooo0>Co
oooo001hooooo`?o00001_ooool3o`000>Cooooo001kooooo`?o00000oooool00ol0003ooooooooo
o`3Tooooo`00O_ooool4o`000>Kooooo0021ooooo`Co0000hoooool0087ooooo00Co0000oooooooo
oooooooo0ol0003Pooooo`00POooool00ol0003oooooooooo`04ooooo`?o0000gOooool0087ooooo
00?o0000ooooooooool01oooool3o`000=[ooooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo
0_l0003Hooooo`00I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool03?ooool3o`000=Gooooo001Vooooo`05oa0@4?oo
ooooooooooooool@41002oooool5o`0000Kooooo00?o0000ooooooooool03oooool3o`000=;ooooo
001Vooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00007ooooo`?o
00004_ooool3o`000<oooooo001Vooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgo
EEEEooooool00007ooooo`03o`000?oooooooooo01Gooooo0ol0003<ooooo`00I_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0Hoooo
o`?o0000bOooool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co0000
00Oooooo00?o0000ooooooooool06oooool3o`000<Kooooo001Vooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo01kooooo0ol00033oooo
o`00POooool00ol0003oooooooooo`0Qooooo`?o0000`?ooool0087ooooo00?o0000ooooooooool0
9?ooool3o`000;gooooo0021ooooo`03o`000?oooooooooo02Oooooo0ol0002jooooo`00POooool0
0ol0003oooooooooo`0Zooooo`?o0000]oooool0087ooooo00?o0000ooooooooool0;Oooool3o`00
0;Cooooo0021ooooo`?o0000<?ooool3o`000;7ooooo0021ooooo`03o`000?oooooooooo03?ooooo
0ol0002^ooooo`00POooool00ol0003oooooooooo`0fooooo`?o0000Zoooool0087ooooo00?o0000
ooooooooool0>Oooool2o`000:Wooooo0021ooooo`03o`000?oooooooooo03_ooooo0ol0002Voooo
o`00POooool00ol0003oooooooooo`0nooooo`;o0000Y?ooool0087ooooo00?o0000ooooooooool0
@?ooool3o`000:7ooooo0021ooooo`03o`000?oooooooooo04?ooooo0_l0002Oooooo`00POooool0
0ol0003oooooooooo`15ooooo`;o0000WOooool0087ooooo00?o0000ooooooooool0Aoooool3o`00
09[ooooo0021ooooo`?o0000B_ooool3o`0009Oooooo0021ooooo`03o`000?oooooooooo04gooooo
0ol0002Dooooo`00POooool00ol0003oooooooooo`1@ooooo`Co0000T?ooool0087ooooo00?o0000
ooooooooool0E?ooool3o`0008gooooo0021ooooo`03o`000?oooooooooo05Oooooo0ol0002:oooo
o`00POooool00ol0003oooooooooo`1Jooooo`?o0000Qoooool0087ooooo00?o0000ooooooooool0
GOooool3o`0008Cooooo0021ooooo`03o`000?oooooooooo063ooooo0_l00022ooooo`00POooool0
0ol0003oooooooooo`1Rooooo`?o0000Ooooool0087ooooo00?o0000ooooooooool0IOooool2o`00
07gooooo0021ooooo`?o0000Ioooool3o`0007[ooooo0021ooooo`03o`000?oooooooooo06[ooooo
0_l0001hooooo`00POooool00ol0003oooooooooo`1/ooooo`;o0000M_ooool0087ooooo00?o0000
ooooooooool0K_ooool3o`0007?ooooo0021ooooo`03o`000?oooooooooo077ooooo0_l0001aoooo
o`00POooool00ol0003oooooooooo`1cooooo`?o0000K_ooool0087ooooo00?o0000ooooooooool0
M_ooool3o`0006_ooooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo07Wooooo0_l0001Yooooo`00
I_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRH
V?lQ8B401_ooool00ol0003oooooooooo`1kooooo`?o0000I_ooool006Kooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`1n
ooooo`?o0000Hoooool006Kooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9So
oooooiRHV?lQ8B401_ooool3o`00087ooooo0ol0001Pooooo`00I_ooool01Ol0003ooooooooooooo
oooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo08Cooooo
0ol0001Mooooo`00I_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
2?ooool00ol0003oooooooooo`27ooooo`?o0000F_ooool006Kooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0R_ooool3o`0005Oooooo
001Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03
o`000?oooooooooo08gooooo0_l0001Eooooo`00POooool00ol0003oooooooooo`2?ooooo`;o0000
Doooool0087ooooo00?o0000ooooooooool0TOooool3o`00053ooooo0021ooooo`03o`000?oooooo
oooo09Cooooo0_l0001>ooooo`00POooool00ol0003oooooooooo`2Fooooo`;o0000C?ooool0087o
oooo00?o0000ooooooooool0V?ooool3o`0004Wooooo0021ooooo`?o0000Voooool3o`0004Kooooo
0021ooooo`03o`000?oooooooooo09kooooo0ol00013ooooo`00POooool00ol0003oooooooooo`2Q
ooooo`?o0000@?ooool0087ooooo00?o0000ooooooooool0Y?ooool3o`0003gooooo0021ooooo`03
o`000?oooooooooo0:Oooooo0ol0000jooooo`00POooool00ol0003oooooooooo`2Zooooo`?o0000
=oooool0087ooooo00?o0000ooooooooool0[Oooool2o`0003Gooooo0021ooooo`03o`000?oooooo
oooo0:oooooo0ol0000booooo`00POooool00ol0003oooooooooo`2booooo`;o0000<?ooool0087o
oooo00?o0000ooooooooool0]?ooool3o`0002gooooo0021ooooo`?o0000]oooool3o`0002[ooooo
0021ooooo`03o`000?oooooooooo0;[ooooo0_l0000Xooooo`00POooool00ol0003oooooooooo`2l
ooooo`?o00009Oooool0087ooooo00?o0000ooooooooool0_oooool3o`0002;ooooo0021ooooo`03
o`000?oooooooooo0<;ooooo0ol0000Oooooo`00POooool00ol0003oooooooooo`35ooooo`?o0000
7?ooool0087ooooo00?o0000ooooooooool0b?ooool3o`0001Wooooo0021ooooo`03o`000?oooooo
oooo0<_ooooo00?o0000ooooooooool05_ooool0087ooooo00?o0000ooooooooool0i?ooool0087o
oooo00?o0000ooooooooool0i?ooool0087ooooo0ol0003Tooooo`00POooool00ol0003ooooooooo
o`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Toooo
o`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POoo
ool00ol0003oooooooooo`3Tooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3Tooooo`00I_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ
8B401_ooool00ol0003oooooooooo`3Tooooo`00I_ooool01Ol@413ooooooooooooooooo410@00_o
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0>Cooooo001Vooooo`05
o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0003T
ooooo`00I_ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c006ooooo`03o`000?oooooooooo0>Cooooo001Vooooo`05oa0@4?ooooooooooooooool@41002ooo
ool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0i?ooool006Kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003o
ooooooooo`3Tooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@06ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Co
oooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021
ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`?o
0000i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?oo
ool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087o
oooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o
0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000oooo
ooooool0i?ooool0087ooooo0ol0003Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POoo
ool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0
003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003ooooo
ooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3T
ooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool3o`000>Cooooo0021ooooo`03o`00
0?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooo
oooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Co
oooo0021ooooo`03o`000?oooooooooo0>Cooooo001gooooo`Co000000?o410@ooooooooool00ooo
ool00ol0003oooooooooo`3Tooooo`00NOooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0>Cooooo001iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0i?ooool007Wo
oooo00?o0000ooooooooool01Oooool3o`000>Cooooo001iooooo`03o`000?oooooooooo0>cooooo
001iooooo`03o`000?oooooooooo0>cooooo001iooooo`03o`000?oooooooooo0>cooooo001goooo
o`03oeEEEOmVIVKo00000>kooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-12, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.32877 .12361 -18 -4.5 ]
[.32877 .12361 0 4.5 ]
[.32877 .24721 -18 -4.5 ]
[.32877 .24721 0 4.5 ]
[.32877 .37082 -18 -4.5 ]
[.32877 .37082 0 4.5 ]
[.32877 .49443 -18 -4.5 ]
[.32877 .49443 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-5)] .18254 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(10)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(15)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.34127 .12361 m
.34752 .12361 L
s
[(0.2)] .32877 .12361 1 0 Mshowa
.34127 .24721 m
.34752 .24721 L
s
[(0.4)] .32877 .24721 1 0 Mshowa
.34127 .37082 m
.34752 .37082 L
s
[(0.6)] .32877 .37082 1 0 Mshowa
.34127 .49443 m
.34752 .49443 L
s
[(0.8)] .32877 .49443 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(1)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0309 m
.34502 .0309 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .09271 m
.34502 .09271 L
s
.34127 .15451 m
.34502 .15451 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .21631 m
.34502 .21631 L
s
.34127 .27812 m
.34502 .27812 L
s
.34127 .30902 m
.34502 .30902 L
s
.34127 .33992 m
.34502 .33992 L
s
.34127 .40172 m
.34502 .40172 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .46353 m
.34502 .46353 L
s
.34127 .52533 m
.34502 .52533 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .58713 m
.34502 .58713 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .15243 m
.06244 .1606 L
.10458 .16983 L
.14415 .17878 L
.18221 .18765 L
.22272 .19737 L
.26171 .20698 L
.30316 .21747 L
.34309 .22784 L
.3815 .23804 L
.42237 .24912 L
.46172 .26 L
.49955 .27065 L
.53984 .28218 L
.57861 .29344 L
.61984 .30556 L
.65954 .31737 L
.69774 .32884 L
.73838 .34113 L
.77751 .35304 L
.81909 .36573 L
.85916 .37798 L
.89771 .38977 L
.93871 .40227 L
.97619 .41363 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h/ooooo`05odA4A?l0003o0000oc8b<_oMgMd0G_ooool01Om4A4Co0000o`000?lb<S;ogMgM02[o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^:?ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0Tooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01?ooooo000Jooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0_ooooo`03ogMgMolb<S;ooooo063ooooo00?oMgMgoc8b<_ooool0:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo02Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL04oooool000oooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Sooooo`Ko00001oooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000;oooool00omgMgOo<S8booooo`1Pooooo`03ogMgMolb<S;ooooo02_o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002[ooooo00?o0000oooo
ooooool01_ooool00omgMgOo<S8booooo`0Vooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000;?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<05kooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00/ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Zooooo`03
o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Xooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`006_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@4100;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Aooooo`006_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0;?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Wooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01?ooooo000Hooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0/ooooo`Co0000Goooool4o`0002_ooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo00?oEEEEofIVI_l000001Oooool4o`0002Kooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001?ooooo
ool00016o`00013ooooo000Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo000Jooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01Kooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Co
oooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021
ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03
o`000?oooooooooo0>Cooooo0021ooooo`?o0000i?ooool0087ooooo00?o0000ooooooooool0i?oo
ool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087o
oooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o
0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000oooo
ooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo0ol0003Tooooo`00POoo
ool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0
003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003ooooo
ooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3T
ooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00
POooool3o`000>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooo
oooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Co
oooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021
ooooo`03o`000?oooooooooo0>Cooooo001Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0>Cooooo001Vooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oo
oooooooo0>Cooooo001Vooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^
kP07ooooo`03o`000?oooooooooo0>Cooooo001Vooooo`05o`000?ooooooooooooooool000003Ooo
ool00onHV9So8B4Qonk^kP06ooooo`?o0000i?ooool006Kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0i?ooool006Kooooo00Go410@
oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0i?oo
ool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
1_ooool00ol0003oooooooooo`3Tooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`00
0?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooo
oooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo000Jooooo`?o0000I?ooool00ol0003o
ooooooooo`3Tooooo`007Oooool5o`0005oooooo0ol0003Tooooo`008_ooool4o`0005_ooooo00?o
0000ooooooooool0i?ooool002Kooooo1?l0001Gooooo`03o`000?oooooooooo0>Cooooo000Zoooo
o`Go0000D_ooool00ol0003oooooooooo`3Tooooo`00;oooool5o`0004gooooo00?o0000oooooooo
ool0i?ooool003Cooooo1Ol00018ooooo`03o`000?oooooooooo0>Cooooo000iooooo`Ko0000@_oo
ool00ol0003oooooooooo`3Tooooo`00?oooool5o`0003gooooo00?o0000ooooooooool0i?ooool0
04Cooooo1Ol0000hooooo`03o`000?oooooooooo0>Cooooo0019ooooo`Co0000=?ooool00ol0003o
ooooooooo`3Tooooo`00COooool4o`00033ooooo0ol0003Tooooo`00DOooool5o`0002_ooooo00?o
0000ooooooooool0i?ooool005Kooooo1?l0000Wooooo`03o`000?oooooooooo0>Cooooo001Joooo
o`Co00008oooool00ol0003oooooooooo`3Tooooo`00G_ooool3o`00023ooooo00?o0000oooooooo
ool0i?ooool0067ooooo0ol0000Mooooo`03o`000?oooooooooo0>Cooooo001Tooooo`?o00006_oo
ool00ol0003oooooooooo`3Tooooo`00Ioooool3o`0001Oooooo00?o0000ooooooooool0i?ooool0
06[ooooo1Ol0000Booooo`03o`000?oooooooooo0>Cooooo001_ooooo`Go00003Oooool00ol0003o
ooooooooo`3Tooooo`00M?ooool4o`0000Wooooo0ol0003Tooooo`00N?ooool5o`0000Cooooo00?o
0000ooooooooool0i?ooool007gooooo1Ol0003Vooooo`00POooool4o`000>?ooooo0021ooooo`04
o`000?ooooooooooooooo`?o0000h?ooool0087ooooo00?o0000ooooooooool01?ooool3o`000=go
oooo0021ooooo`03o`000?oooooooooo00Oooooo0ol0003Jooooo`00I_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003ooooo
ooooo`0:ooooo`?o0000eoooool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00gooooo1Ol0003Booooo`00I_oo
ool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`03o`000?oooooooooo01;ooooo
1Ol0003=ooooo`00I_ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo
00001oooool3o`0001Oooooo1?l00039ooooo`00I_ooool01Ol0003ooooooooooooooooo000000_o
oooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`0Kooooo`?o0000a_ooool006Ko
oooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool07_ooool3o`000<?ooooo001Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^
k^koA4A4o`000007ooooo`03o`000?oooooooooo027ooooo0ol00030ooooo`00I_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`0Toooo
o`?o0000_Oooool0087ooooo00?o0000ooooooooool09oooool5o`000;Sooooo0021ooooo`03o`00
0?oooooooooo02cooooo1?l0002dooooo`00POooool00ol0003oooooooooo`0`ooooo`Co0000/?oo
ool0087ooooo00?o0000ooooooooool0=?ooool3o`000:gooooo0021ooooo`03o`000?oooooooooo
03Oooooo0ol0002Zooooo`00POooool3o`0003[ooooo0ol0002Wooooo`00POooool00ol0003ooooo
ooooo`0mooooo`Co0000Xoooool0087ooooo00?o0000ooooooooool0@Oooool3o`000:3ooooo0021
ooooo`03o`000?oooooooooo04Cooooo0ol0002Mooooo`00POooool00ol0003oooooooooo`17oooo
o`?o0000V_ooool0087ooooo00?o0000ooooooooool0B_ooool3o`0009Oooooo0021ooooo`03o`00
0?oooooooooo04gooooo0ol0002Dooooo`00POooool00ol0003oooooooooo`1@ooooo`Co0000T?oo
ool0087ooooo00?o0000ooooooooool0E?ooool3o`0008gooooo0021ooooo`03o`000?oooooooooo
05Oooooo1?l00029ooooo`00POooool3o`0005_ooooo1Ol00024ooooo`00POooool00ol0003ooooo
ooooo`1Pooooo`Co0000P?ooool0087ooooo00?o0000ooooooooool0I?ooool4o`0007cooooo0021
ooooo`03o`000?oooooooooo06Sooooo0ol0001iooooo`00POooool00ol0003oooooooooo`1[oooo
o`?o0000M_ooool0087ooooo00?o0000ooooooooool0K_ooool3o`0007?ooooo0021ooooo`03o`00
0?oooooooooo077ooooo0ol0001`ooooo`00POooool00ol0003oooooooooo`1dooooo`?o0000KOoo
ool0087ooooo00?o0000ooooooooool0Moooool3o`0006[ooooo0021ooooo`03o`000?oooooooooo
07[ooooo0ol0001Wooooo`00POooool3o`0007gooooo1?l0001Sooooo`00POooool00ol0003ooooo
ooooo`21ooooo`?o0000H?ooool0087ooooo00?o0000ooooooooool0Q?ooool3o`0005gooooo0021
ooooo`03o`000?oooooooooo08Oooooo0ol0001Jooooo`00POooool00ol0003oooooooooo`2:oooo
o`Co0000E_ooool0087ooooo00?o0000ooooooooool0S_ooool3o`0005?ooooo0021ooooo`03o`00
0?oooooooooo097ooooo0ol0001@ooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2Dooooo`?o
0000COooool006Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGo
MgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0Uoooool4o`0004Wooooo001Vooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool0Voooool3o`0004Kooooo001Vooooo`05o`000?ooooooooooooooool000002oooool0
1Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0002Nooooo`?o0000@oooool006Kooooo00Go0000
ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003ooooo
ooooo`2Qooooo`?o0000@?ooool006Kooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEE
EOn7QhOooooo00Sooooo00?o0000ooooooooool0Y?ooool4o`0003cooooo001Vooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo0:Sooooo
0ol0000iooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o
410@1_ooool00ol0003oooooooooo`2[ooooo`?o0000=_ooool0087ooooo00?o0000ooooooooool0
[_ooool3o`0003?ooooo0021ooooo`03o`000?oooooooooo0;7ooooo1?l0000_ooooo`00POooool0
0ol0003oooooooooo`2eooooo`?o0000;?ooool0087ooooo00?o0000ooooooooool0^?ooool3o`00
02Wooooo0021ooooo`03o`000?oooooooooo0;_ooooo0ol0000Vooooo`00POooool3o`000;kooooo
1?l0000Rooooo`00POooool00ol0003oooooooooo`32ooooo`?o00007oooool0087ooooo00?o0000
ooooooooool0aOooool3o`0001cooooo0021ooooo`03o`000?oooooooooo0<Sooooo0ol0000Ioooo
o`00POooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo01Kooooo0021ooooo`03o`00
0?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooo
oooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Co
oooo0021ooooo`?o0000i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000
ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000oooooooo
ool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?oo
ool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087o
oooo00?o0000ooooooooool0i?ooool0087ooooo0ol0003Tooooo`00POooool00ol0003ooooooooo
o`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Toooo
o`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POoo
ool00ol0003oooooooooo`3Tooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3Tooooo`00I_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ
8B401_ooool00ol0003oooooooooo`3Tooooo`00I_ooool01Ol@413ooooooooooooooooo410@00_o
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0>Cooooo001Vooooo`05
o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0003T
ooooo`00I_ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c006ooooo`03o`000?oooooooooo0>Cooooo001Vooooo`05oa0@4?ooooooooooooooool@41002ooo
ool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0i?ooool006Kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003o
ooooooooo`3Tooooo`00I_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@06ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Co
oooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021
ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`?o
0000i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?oo
ool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087o
oooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o
0000ooooooooool0i?ooool0087ooooo00?o0000ooooooooool0i?ooool0087ooooo00?o0000oooo
ooooool0i?ooool0087ooooo0ol0003Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POoo
ool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0
003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003ooooo
ooooo`3Tooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool00ol0003oooooooooo`3T
ooooo`00POooool00ol0003oooooooooo`3Tooooo`00POooool3o`000>Cooooo0021ooooo`03o`00
0?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooo
oooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Cooooo0021ooooo`03o`000?oooooooooo0>Co
oooo0021ooooo`03o`000?oooooooooo0>Cooooo001gooooo`Co000000?o410@ooooooooool00ooo
ool00ol0003oooooooooo`3Tooooo`00NOooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0>Cooooo001iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0i?ooool007Wo
oooo00?o0000ooooooooool01Oooool3o`000>Cooooo001iooooo`03o`000?oooooooooo0>cooooo
001iooooo`03o`000?oooooooooo0>cooooo001iooooo`03o`000?oooooooooo0>cooooo001goooo
o`03oeEEEOmVIVKo00000>kooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-12, 0, 0, 0}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "Although ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " is constant along each characteristic (",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]f/\[DifferentialD]t = 0\)]],
  " when ",
  Cell[BoxData[
      \(TraditionalForm\`a = 0\)]],
  "), the spreading of the characteristics results in a change in shape of \
the solution over time. The reader is invited to vary the parameters of the \
problem so as to investigate other solutions. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 3: Mixing Dye ", "Section",
  CellTags->"c:8"],

Cell[TextData[{
  "Next, we consider a generalization of Eq. ",
  ButtonBox["(7.1.1)",
    ButtonData:>{"Chapter7.nb", "(7.1.1)"},
    ButtonStyle->"Hyperlink"],
  "  to two  spatial dimensions:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]f\/\[PartialD]t + \(\(v\_x\)(x, y, 
              t)\) \[PartialD]f\/\[PartialD]x + \(\(v\_y\)(x, y, 
              t)\) \[PartialD]f\/\[PartialD]y = 0\)]],
  "."
}], "NumberedEquation",
  CellTags->{"i:4", "(7.1.18)"}],

Cell[TextData[{
  "Here, the functions ",
  Cell[BoxData[
      \(TraditionalForm\`v\_x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`v\_y\)]],
  " provide the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " components of the velocity. Equation ",
  ButtonBox["(7.1.18)",
    ButtonData:>{"Chapter7.nb", "(7.1.18)"},
    ButtonStyle->"Hyperlink"],
  "  describes the behavior of dye placed in a fluid that moves with flow \
velocity ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["v",
            FontWeight->"Bold",
            FontSlant->"Plain"], "=", \((v\_x, \ v\_y)\)}], 
        TraditionalForm]]],
  ". The density of the dye, ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, y, t)\)]],
  ", is carried along with the fluid, and so follows "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]f\/\[DifferentialD]t = 0\)]],
  "."
}], "NumberedEquation",
  CellTags->"(7.1.19)"],

Cell[TextData[{
  "Equation ",
  ButtonBox["(7.1.18)",
    ButtonData:>{"Chapter7.nb", "(7.1.18)"},
    ButtonStyle->"Hyperlink"],
  "  is merely an expression for this total time derivative, analogous to the \
one-dimensional total time derivative of Eq. ",
  ButtonBox["(7.1.7)",
    ButtonData:>{"Chapter7.nb", "(7.1.7)"},
    ButtonStyle->"Hyperlink"],
  " .  Equation ",
  ButtonBox["(7.1.19)",
    ButtonData:>{"Chapter7.nb", "(7.1.19)"},
    ButtonStyle->"Hyperlink"],
  "  implies that ",
  Cell[BoxData[
      \(TraditionalForm\`f = constant\)]],
  " along the characteristics.  This means that elements of the dye are \
carried along by the fluid without change in their density."
}], "Text"],

Cell[TextData[{
  "\t The characteristics for Eq. ",
  ButtonBox["(7.1.18)",
    ButtonData:>{"Chapter7.nb", "(7.1.18)"},
    ButtonStyle->"Hyperlink"],
  "  are the coupled first-order ODEs, "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]x/\[DifferentialD]t\  = \ \(v\_x\)(
          x, y, t)\)]],
  ",\n",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[DifferentialD]y/\[DifferentialD]t\  = \ \(v\_y\
\)(x, y, t)\)\(,\)\)\)]]
}], "NumberedEquation",
  CellTags->"(7.1.20)"],

Cell[TextData[{
  "with initial conditions ",
  Cell[BoxData[
      \(TraditionalForm\`x = x\_o\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`y = y\_o\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  ". For general functions ",
  Cell[BoxData[
      \(TraditionalForm\`v\_x\)]],
  "  and ",
  Cell[BoxData[
      \(TraditionalForm\`v\_y\)]],
  ", these ODEs need not have an analytic solution and can even display \
chaotic behavior.  That is, the dye can be mixed chaotically if the fluid \
flow is sufficiently complex.  Thus, even though Eq. ",
  ButtonBox["(7.1.18)",
    ButtonData:>{"Chapter7.nb", "(7.1.18)"},
    ButtonStyle->"Hyperlink"],
  "  is linear, it is not always be possible to find a closed-form analytic \
solution. "
}], "Text"],

Cell[TextData[{
  "\tBelow, we show some characteristics for  a fluid flow with\n\t\t ",
  Cell[BoxData[
      \(TraditionalForm\`v\_x\  = \ y\  + x\)]],
  ", \n\t\t ",
  Cell[BoxData[
      \(TraditionalForm\`v\_y = \ \(-y\)\  - \ \((x\^3 - 1)\)\ \((1 + 
                Cos\ t)\)\)]],
  "."
}], "Text",
  CellTags->"i:5"],

Cell[TextData[{
  "Note that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\(\(\[CenterDot]\)\((v\_x, v\_y)\)\) = 0\)]],
  ",",
  "  so this flow is incompressible [see Eq. ",
  ButtonBox["(1.2.12)",
    ButtonData:>{"Chapter1.nb", "(1.2.12)"},
    ButtonStyle->"Hyperlink"],
  " ]. Therefore, the area of a patch of dye carried along by this particular \
flow will not change over time.  "
}], "Text"],

Cell[TextData[{
  "\tThe characteristics for the flow can be computed using ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", for given initial conditions ",
  Cell[BoxData[
      \(TraditionalForm\`\((x\_o, y\_o)\)\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(c[x0_, 
          y0_]\  := \ \(c[x0, 
            y0]\  = {x[t], 
              y[t]} /. \(NDSolve[{\(x'\)[
                      t]\  \[Equal] \((y[t] + x[t])\), \ \(y'\)[
                      t]\  \[Equal] \ \(-y[
                          t]\) - \((x[t]^3 - 1)\) \((1 + \ Cos[t])\), 
                  x[0] \[Equal] x0, y[0] \[Equal] y0}, {x, y}, {t, 0, 
                  10}]\)[\([1]\)]\);\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.3"],

Cell[TextData[{
  "The characteristics can then be plotted in the ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y)\)\)]],
  " plane using ",
  StyleBox["ParametricPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", as shown in Cell ",
  ButtonBox["7.4",
    ButtonData:>"Cell 7.4",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(Table[
        ParametricPlot[Evaluate[c[x0, y0]], {t, 0, 10}, 
          DisplayFunction \[Rule] Identity], {x0, \(-2\), 2}, {y0, \(-2\), 
          2}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(Show[%, DisplayFunction -> $DisplayFunction, 
        PlotRange \[Rule] {{\(-30\), 30}, {\(-30\), 30}}, 
        AspectRatio \[Rule] 1];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.4"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0166667 0.5 0.0166667 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.16667 .4875 -9 -9 ]
[.16667 .4875 9 0 ]
[.33333 .4875 -9 -9 ]
[.33333 .4875 9 0 ]
[.66667 .4875 -6 -9 ]
[.66667 .4875 6 0 ]
[.83333 .4875 -6 -9 ]
[.83333 .4875 6 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .16667 -18 -4.5 ]
[.4875 .16667 0 4.5 ]
[.4875 .33333 -18 -4.5 ]
[.4875 .33333 0 4.5 ]
[.4875 .66667 -12 -4.5 ]
[.4875 .66667 0 4.5 ]
[.4875 .83333 -12 -4.5 ]
[.4875 .83333 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-30)] 0 .4875 0 1 Mshowa
.16667 .5 m
.16667 .50625 L
s
[(-20)] .16667 .4875 0 1 Mshowa
.33333 .5 m
.33333 .50625 L
s
[(-10)] .33333 .4875 0 1 Mshowa
.66667 .5 m
.66667 .50625 L
s
[(10)] .66667 .4875 0 1 Mshowa
.83333 .5 m
.83333 .50625 L
s
[(20)] .83333 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(30)] 1 .4875 0 1 Mshowa
.125 Mabswid
.03333 .5 m
.03333 .50375 L
s
.06667 .5 m
.06667 .50375 L
s
.1 .5 m
.1 .50375 L
s
.13333 .5 m
.13333 .50375 L
s
.2 .5 m
.2 .50375 L
s
.23333 .5 m
.23333 .50375 L
s
.26667 .5 m
.26667 .50375 L
s
.3 .5 m
.3 .50375 L
s
.36667 .5 m
.36667 .50375 L
s
.4 .5 m
.4 .50375 L
s
.43333 .5 m
.43333 .50375 L
s
.46667 .5 m
.46667 .50375 L
s
.53333 .5 m
.53333 .50375 L
s
.56667 .5 m
.56667 .50375 L
s
.6 .5 m
.6 .50375 L
s
.63333 .5 m
.63333 .50375 L
s
.7 .5 m
.7 .50375 L
s
.73333 .5 m
.73333 .50375 L
s
.76667 .5 m
.76667 .50375 L
s
.8 .5 m
.8 .50375 L
s
.86667 .5 m
.86667 .50375 L
s
.9 .5 m
.9 .50375 L
s
.93333 .5 m
.93333 .50375 L
s
.96667 .5 m
.96667 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-30)] .4875 0 1 0 Mshowa
.5 .16667 m
.50625 .16667 L
s
[(-20)] .4875 .16667 1 0 Mshowa
.5 .33333 m
.50625 .33333 L
s
[(-10)] .4875 .33333 1 0 Mshowa
.5 .66667 m
.50625 .66667 L
s
[(10)] .4875 .66667 1 0 Mshowa
.5 .83333 m
.50625 .83333 L
s
[(20)] .4875 .83333 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(30)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .03333 m
.50375 .03333 L
s
.5 .06667 m
.50375 .06667 L
s
.5 .1 m
.50375 .1 L
s
.5 .13333 m
.50375 .13333 L
s
.5 .2 m
.50375 .2 L
s
.5 .23333 m
.50375 .23333 L
s
.5 .26667 m
.50375 .26667 L
s
.5 .3 m
.50375 .3 L
s
.5 .36667 m
.50375 .36667 L
s
.5 .4 m
.50375 .4 L
s
.5 .43333 m
.50375 .43333 L
s
.5 .46667 m
.50375 .46667 L
s
.5 .53333 m
.50375 .53333 L
s
.5 .56667 m
.50375 .56667 L
s
.5 .6 m
.50375 .6 L
s
.5 .63333 m
.50375 .63333 L
s
.5 .7 m
.50375 .7 L
s
.5 .73333 m
.50375 .73333 L
s
.5 .76667 m
.50375 .76667 L
s
.5 .8 m
.50375 .8 L
s
.5 .86667 m
.50375 .86667 L
s
.5 .9 m
.50375 .9 L
s
.5 .93333 m
.50375 .93333 L
s
.5 .96667 m
.50375 .96667 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.46667 .46667 m
.46517 .47487 L
.46376 .48439 L
.46271 .49316 L
.46178 .50316 L
.46131 .50945 L
.46096 .51535 L
.46069 .52104 L
.46048 .5271 L
.46036 .5325 L
.46031 .53753 L
.46032 .54299 L
.4604 .54876 L
.46057 .55457 L
.4608 .55981 L
.46113 .56535 L
.46157 .57096 L
.46208 .57602 L
.46263 .58049 L
.46383 .58803 L
.46521 .59438 L
.46665 .59924 L
.46839 .60351 L
.46931 .60525 L
.47037 .60686 L
.47148 .60819 L
.47208 .60878 L
.47273 .60931 L
.47331 .60971 L
.47395 .61007 L
.47509 .61053 L
.47622 .61079 L
.47686 .61085 L
.47745 .61086 L
.47856 .61076 L
.47973 .61052 L
.4804 .61033 L
.48102 .61012 L
.4824 .60955 L
.48492 .60822 L
.49075 .6043 L
.50147 .59654 L
.51168 .58962 L
.51684 .58568 L
.5217 .58102 L
.52673 .57447 L
.52936 .57006 L
.53212 .56443 L
.53477 .55779 L
.53751 .54931 L
Mistroke
.53976 .54071 L
.54196 .53042 L
.54388 .51918 L
.54538 .50821 L
.54664 .49662 L
.54756 .48537 L
.54793 .47964 L
.54826 .4735 L
.54849 .46772 L
.54865 .46251 L
.54876 .45646 L
.54878 .4531 L
.54878 .45003 L
.54873 .44451 L
.5486 .43883 L
.54841 .43362 L
.54812 .42825 L
.54778 .42344 L
.54741 .41926 L
.54635 .41047 L
.54571 .40656 L
.54495 .40267 L
.54352 .3971 L
.54208 .39304 L
.54123 .39118 L
.54027 .38947 L
.53942 .38825 L
.53845 .38715 L
.53753 .38636 L
.53665 .3858 L
.53571 .3854 L
.53468 .38516 L
.53371 .38511 L
.53278 .3852 L
.53193 .38539 L
.53101 .3857 L
.52994 .38619 L
.52896 .38674 L
.52673 .38832 L
.52266 .39207 L
.51344 .40274 L
.49535 .42374 L
.46156 .45691 L
.44457 .47457 L
.43717 .48124 L
.43322 .48421 L
.42897 .48684 L
.42675 .48797 L
.42428 .48904 L
.4198 .49047 L
Mistroke
.41755 .49097 L
.41508 .4914 L
.41269 .4917 L
.41046 .49192 L
.40506 .49237 L
.40354 .49252 L
.40189 .49272 L
.39887 .49324 L
.39736 .4936 L
.39571 .49409 L
.39425 .49463 L
.39269 .49532 L
.3897 .49707 L
.38693 .49929 L
.38388 .5026 L
.38102 .50675 L
.37849 .51151 L
.37581 .51797 L
.37303 .52677 L
.37029 .53844 L
.36818 .55053 L
.36715 .55791 L
.36617 .56637 L
.36541 .57427 L
.36468 .58354 L
.36411 .59266 L
.36368 .60143 L
.3633 .61243 L
.36305 .62487 L
.36297 .63702 L
.36304 .649 L
.36324 .66066 L
.36361 .67339 L
.36405 .68456 L
.36466 .69709 L
.36659 .72574 L
.3691 .7529 L
.37289 .78399 L
.37724 .81152 L
.38293 .8393 L
.38995 .865 L
.39349 .8752 L
.3975 .88498 L
.40121 .89248 L
.40526 .89924 L
.40905 .90433 L
.41332 .90879 L
.4173 .91185 L
.42109 .91388 L
.42518 .9152 L
Mistroke
.4297 .91571 L
.43402 .91537 L
.43806 .9144 L
.44172 .91304 L
.44577 .91105 L
.45404 .90571 L
.47281 .88929 L
.49044 .87171 L
.5093 .85326 L
.52994 .83317 L
.53936 .82261 L
.54935 .80885 L
.55863 .79195 L
.56682 .77182 L
.57507 .744 L
.58214 .71104 L
.58909 .66554 L
.59219 .63871 L
.59522 .60624 L
.59749 .57577 L
.59931 .54497 L
.60098 .50746 L
.60208 .47171 L
.60272 .43708 L
.60297 .40453 L
.60285 .36863 L
.60227 .33079 L
.60124 .29469 L
.59963 .2567 L
.5974 .21935 L
.59485 .18723 L
.58925 .13718 L
.58559 .11383 L
.58198 .09562 L
.57744 .07789 L
.573 .06496 L
.5679 .05431 L
.56525 .05026 L
.56229 .04675 L
.55721 .04291 L
.55165 .04131 L
.54633 .04181 L
.54141 .04368 L
.53649 .04661 L
.53123 .05063 L
.52174 .05943 L
.50026 .08191 L
.48128 .10167 L
.47093 .11346 L
.46134 .12679 L
Mistroke
.45038 .14773 L
.44472 .16237 L
.43883 .18168 L
.43365 .20321 L
.42898 .22747 L
.42106 .28428 L
.41715 .32373 L
.41358 .37103 L
.41109 .41543 L
.40998 .44064 L
.40899 .468 L
.40814 .49869 L
.40756 .52738 L
.40718 .55868 L
.40703 .59308 L
.40714 .62288 L
.40751 .65435 L
.40808 .68352 L
.40879 .70935 L
.41069 .75767 L
.41189 .78058 L
.4134 .80449 L
.4165 .84316 L
.41986 .87477 L
.42434 .90614 L
.42884 .92918 L
.43147 .93969 L
.43443 .94943 L
.4373 .95702 L
.44006 .96287 L
.44509 .97045 L
.45081 .97516 L
.4565 .97668 L
.45973 .97644 L
.46272 .97564 L
.46778 .97327 L
.47334 .96954 L
.4846 .9599 L
.50924 .93677 L
.52138 .92512 L
.53258 .91217 L
.54266 .89596 L
.54767 .88519 L
.5531 .87062 L
.55839 .85257 L
.56388 .82861 L
.56879 .80106 L
.573 .77126 L
.57742 .73135 L
.58156 .68209 L
Mistroke
.58482 .62965 L
.58717 .57775 L
.58829 .54418 L
.58911 .51243 L
.58976 .47688 L
.59014 .43887 L
.5901 .37491 L
.58969 .33921 L
.58906 .30666 L
.58827 .2775 L
.58718 .24698 L
.58464 .19538 L
.58151 .15079 L
.5781 .11505 L
.57394 .08273 L
.56885 .05452 L
.56613 .04318 L
.5631 .03296 L
.55737 .01934 L
.55169 .01151 L
.5464 .00805 L
.54019 .00756 L
.53425 .00973 L
.52872 .0134 L
.52361 .01777 L
.51205 .02949 L
.48809 .05514 L
.47543 .06953 L
.46848 .07897 L
.46194 .08985 L
.45575 .10284 L
.44914 .12086 L
.44331 .14169 L
.43813 .16555 L
.43304 .19549 L
.42876 .22761 L
.42427 .27085 L
.42058 .3175 L
.4173 .37327 L
.41593 .40336 L
.41467 .43764 L
.41308 .50089 L
.41237 .56144 L
.41231 .59832 L
.41251 .63285 L
.41357 .69561 L
.41453 .72907 L
.41565 .75862 L
.41712 .78928 L
.41895 .81957 L
Mistroke
.42225 .86127 L
.42646 .89955 L
.43093 .92866 L
.43544 .94978 L
.44018 .96547 L
.44466 .97567 L
.45002 .98329 L
.45519 .98703 L
.46095 .98805 L
.46711 .98645 L
.47241 .98352 L
.47825 .97918 L
.50358 .95606 L
.52564 .93461 L
.53198 .92675 L
.53796 .91765 L
.54335 .90745 L
.549 .89395 L
.55381 .87952 L
.55897 .86008 L
.56756 .8152 L
.57199 .78333 L
.57636 .74326 L
.58003 .70003 L
.58294 .65603 L
.58578 .59868 L
.58777 .54073 L
.58893 .48663 L
.58949 .42703 L
.58928 .36268 L
.58885 .33104 L
.58812 .29721 L
.58622 .2408 L
.58378 .19288 L
.58073 .1504 L
.57735 .11565 L
.57395 .08924 L
.56991 .06552 L
.56522 .04553 L
.55991 .03022 L
.55468 .02076 L
.54981 .01577 L
.54382 .01348 L
.54078 .01359 L
.53741 .0145 L
.53142 .01775 L
.5258 .02217 L
.49953 .04933 L
.48756 .062 L
.47488 .07629 L
Mistroke
.46412 .09142 L
.45806 .10239 L
.45246 .11494 L
.44175 .14833 L
.43604 .17342 L
.43108 .20109 L
.42637 .23431 L
.42169 .27656 L
.41744 .32711 L
.41417 .37944 L
.41172 .43363 L
.41007 .4873 L
.40917 .53664 L
.40882 .59025 L
.4092 .64758 L
.40969 .67556 L
.41045 .70534 L
.41234 .75488 L
.4147 .79688 L
.41749 .83306 L
.42104 .86705 L
.42481 .89385 L
.42862 .91417 L
.43265 .93027 L
.43647 .94159 L
.44107 .9512 L
.44553 .95723 L
.45054 .961 L
.45593 .96228 L
.46059 .96162 L
.46574 .95946 L
.47132 .95587 L
.47732 .95106 L
.48816 .94109 L
.51053 .91988 L
.5228 .908 L
.53429 .89486 L
.54656 .87552 L
.55296 .86175 L
.55969 .84328 L
.56561 .82254 L
.57101 .79886 L
.57604 .77142 L
.5803 .74286 L
.58777 .67537 L
.59117 .63285 L
.59385 .58984 L
.59584 .54791 L
.59724 .50813 L
.59827 .4638 L
Mistroke
.59878 .41698 L
.59868 .37058 L
.59836 .34528 L
.5979 .32281 L
.59658 .2812 L
.59483 .24472 L
.59223 .20646 L
.58932 .17539 L
.58565 .14628 L
.58125 .12107 L
.57758 .10551 L
.57333 .0921 L
.56866 .08178 L
.56415 .07519 L
.5598 .07131 L
.55577 .06947 L
.55106 .06906 L
.54655 .07005 L
.5416 .07238 L
.53633 .07594 L
.52685 .08421 L
.50541 .10631 L
.48545 .12673 L
.46652 .14691 L
.44969 .16998 L
.44034 .18719 L
.4319 .20694 L
.42302 .23359 L
.41542 .26281 L
.40736 .3028 L
.40062 .34632 L
.39448 .39864 L
.38998 .45036 L
.3881 .47827 L
.38642 .50913 L
.38574 .52468 L
.38512 .54125 L
.3843 .57076 L
.3839 .59784 L
.38382 .62205 L
.38407 .64753 L
.38469 .67309 L
.38552 .69385 L
.38652 .71206 L
.38786 .73056 L
.38957 .7487 L
.39316 .77597 L
.39523 .78752 L
.39765 .79855 L
.39987 .80673 L
Mistroke
.40235 .81421 L
.40476 .82009 L
.40708 .82468 L
.41015 .82937 L
.41195 .83152 L
.41362 .83314 L
.41527 .83444 L
.4171 .83556 L
.41904 .83641 L
.42091 .83693 L
.42429 .83721 L
.42792 .83672 L
.43106 .83572 L
.43455 .8341 L
.43862 .83164 L
.44237 .82893 L
.45087 .82163 L
.46628 .8061 L
.52374 .7483 L
.58316 .69885 L
.61326 .67885 L
.6279 .66968 L
.64164 .65995 L
.65604 .64626 L
.6636 .6364 L
.67152 .62294 L
.67822 .60798 L
.68429 .5905 L
.6906 .56662 L
.69685 .53444 L
.6999 .51395 L
.70251 .49279 L
.70528 .46478 L
.70744 .43665 L
.70915 .40729 L
.71041 .37743 L
.71135 .34363 L
.71168 .3236 L
.71185 .30458 L
.71184 .26994 L
.71146 .23625 L
.71059 .19802 L
.70912 .1559 L
.70696 .11088 L
.70432 .06794 L
Mfstroke
.70432 .06794 m
.69873 0 L
s
.46667 .48333 m
.46556 .49103 L
.46457 .49974 L
.46381 .50832 L
.46329 .51632 L
.46305 .52126 L
.46288 .52583 L
.46276 .53084 L
.46273 .53336 L
.46271 .53611 L
.46272 .54067 L
.4628 .5455 L
.46294 .54995 L
.46311 .55391 L
.46336 .55815 L
.46368 .5625 L
.46442 .56979 L
.46497 .5739 L
.46556 .57749 L
.46679 .58346 L
.46815 .58824 L
.46952 .59185 L
.47116 .59494 L
.47203 .59618 L
.47301 .59729 L
.47402 .59818 L
.47457 .59856 L
.47515 .5989 L
.47567 .59914 L
.47624 .59935 L
.47727 .59959 L
.47829 .59968 L
.47886 .59967 L
.47939 .59962 L
.48038 .59946 L
.48143 .59918 L
.48257 .59878 L
.48381 .59824 L
.48606 .59704 L
.49126 .59364 L
.51002 .58112 L
.51482 .57778 L
.51997 .57336 L
.52267 .57045 L
.52561 .5666 L
.52829 .56233 L
.53068 .55771 L
.53517 .54632 L
.53746 .53866 L
.53948 .53046 L
Mistroke
.54258 .51389 L
.54402 .50355 L
.54513 .49353 L
.54562 .48811 L
.54607 .48236 L
.54639 .47736 L
.54667 .47202 L
.5468 .46903 L
.5469 .46631 L
.54704 .46106 L
.54709 .45815 L
.54712 .45503 L
.54713 .45213 L
.54711 .44948 L
.54704 .44491 L
.54692 .44076 L
.54673 .43636 L
.54647 .43184 L
.54614 .42758 L
.54572 .42337 L
.54483 .41656 L
.54385 .41119 L
.54265 .40636 L
.54138 .40264 L
.54014 .39994 L
.53934 .3986 L
.53858 .39755 L
.53772 .39662 L
.53679 .39586 L
.53596 .39538 L
.53517 .39507 L
.53429 .39488 L
.53333 .39484 L
.53241 .39495 L
.53188 .39507 L
.53138 .39522 L
.53037 .39562 L
.52927 .39619 L
.52726 .39755 L
.52542 .3991 L
.51668 .40872 L
.5013 .42738 L
.4716 .45543 L
.45603 .46795 L
.44899 .47276 L
.44107 .47705 L
.43649 .47892 L
.43213 .48031 L
.4278 .48138 L
.42304 .48233 L
Mistroke
.41817 .48326 L
.4154 .48388 L
.41271 .4846 L
.40948 .48573 L
.40648 .48713 L
.40363 .48888 L
.4005 .49144 L
.3976 .49455 L
.39448 .49893 L
.39159 .50424 L
.38901 .51034 L
.38676 .51702 L
.38443 .52577 L
.3822 .53668 L
.38034 .54865 L
.37941 .55617 L
.37851 .56503 L
.37782 .57343 L
.3772 .58297 L
.37676 .59206 L
.3764 .60268 L
.3762 .61283 L
.37612 .62277 L
.37614 .62855 L
.37619 .63501 L
.3763 .64188 L
.37646 .64839 L
.37685 .66033 L
.37745 .67339 L
.37839 .68905 L
.37952 .70402 L
.3823 .73204 L
.38553 .75648 L
.38917 .7782 L
.39383 .80011 L
.39958 .82072 L
.40272 .82971 L
.40633 .83841 L
.40966 .84509 L
.41334 .85115 L
.41712 .85608 L
.42064 .85964 L
.42427 .86235 L
.42775 .86415 L
.43107 .8652 L
.43476 .86567 L
.43866 .86545 L
.44234 .86466 L
.44581 .86343 L
.449 .86194 L
Mistroke
.4562 .8575 L
.47251 .84367 L
.48797 .82839 L
.5202 .79727 L
.52872 .78878 L
.53787 .77839 L
.54629 .76655 L
.55418 .75215 L
.56111 .73543 L
.56837 .71193 L
.57454 .68479 L
.57977 .65398 L
.58275 .63178 L
.5853 .60876 L
.58933 .56051 L
.59112 .53073 L
.59242 .50185 L
.59346 .46885 L
.59382 .45183 L
.59408 .43293 L
.59421 .39731 L
.59389 .36439 L
.59356 .3474 L
.59306 .32888 L
.59239 .30991 L
.59163 .29252 L
.5899 .26203 L
.58796 .23586 L
.58544 .20946 L
.5824 .18457 L
.57956 .1661 L
.57625 .14896 L
.5732 .13632 L
.56971 .12485 L
.56541 .11423 L
.56117 .10687 L
.55692 .10197 L
.5529 .09925 L
.54846 .09801 L
.54363 .09838 L
.53902 .10008 L
.53478 .10255 L
.5298 .1063 L
.52435 .11119 L
.51443 .12127 L
.49328 .14372 L
.48293 .15459 L
.47344 .16542 L
.46431 .17805 L
.45483 .19578 L
Mistroke
.45001 .20765 L
.44562 .22084 L
.44067 .23928 L
.43619 .26019 L
.43267 .28036 L
.42909 .30537 L
.42359 .35705 L
.42097 .39069 L
.41865 .4295 L
.41708 .46482 L
.41582 .50558 L
.41537 .52729 L
.41504 .55128 L
.41488 .57646 L
.4149 .59986 L
.41535 .64134 L
.41641 .68417 L
.41727 .70738 L
.41841 .73149 L
.42099 .77197 L
.42408 .80677 L
.4274 .83437 L
.43091 .85648 L
.43446 .87356 L
.43862 .88845 L
.44106 .89515 L
.44334 .90028 L
.44805 .90797 L
.45078 .91092 L
.45335 .91284 L
.45813 .91457 L
.46329 .9143 L
.4678 .91267 L
.47277 .90977 L
.48285 .90171 L
.50094 .88493 L
.52074 .86644 L
.52644 .86026 L
.53182 .85346 L
.53668 .8461 L
.54179 .83662 L
.54622 .82648 L
.551 .81291 L
.55908 .78144 L
.56334 .75875 L
.56763 .72987 L
.57104 .70099 L
.57438 .6653 L
.57723 .6261 L
.57944 .58644 L
Mistroke
.58111 .54607 L
.58239 .50103 L
.58312 .45551 L
.58331 .41229 L
.58307 .37385 L
.58238 .33333 L
.58097 .28725 L
.57915 .24825 L
.57648 .2076 L
.57344 .17401 L
.57022 .14752 L
.56696 .12692 L
.56309 .10856 L
.55871 .09365 L
.55412 .08308 L
.55145 .07885 L
.54897 .07595 L
.54431 .07278 L
.53932 .07204 L
.53664 .07254 L
.53376 .07365 L
.52855 .07685 L
.52233 .08212 L
.51668 .08775 L
.49512 .11109 L
.48381 .12336 L
.47189 .13816 L
.4616 .15567 L
.45586 .16897 L
.45062 .18446 L
.44187 .22074 L
.43731 .2471 L
.43345 .27537 L
.42969 .31006 L
.42658 .34688 L
.42417 .38319 L
.42203 .42542 L
.42028 .47447 L
.41964 .49997 L
.41915 .52829 L
.41878 .5788 L
.41904 .62533 L
.41989 .67081 L
.42121 .71151 L
.42281 .74555 L
.42496 .77935 L
.42774 .81196 L
.43115 .8415 L
.43439 .86254 L
.43825 .88139 L
Mistroke
.4405 .88995 L
.44304 .89786 L
.44785 .90871 L
.45271 .91536 L
.45735 .91863 L
.46023 .91947 L
.46296 .91957 L
.46812 .91829 L
.47103 .91689 L
.47372 .91527 L
.47981 .91072 L
.49972 .89269 L
.51072 .88268 L
.52117 .87268 L
.53122 .86084 L
.53687 .85221 L
.54204 .84236 L
.55096 .81898 L
.55531 .80352 L
.55994 .78304 L
.56762 .73616 L
.57148 .70372 L
.57465 .6701 L
.57732 .63477 L
.57944 .59931 L
.58125 .56009 L
.58274 .51517 L
.58373 .46463 L
.58399 .4359 L
.58404 .40951 L
.58364 .36192 L
.58256 .31376 L
.58103 .27354 L
.57914 .23896 L
.57661 .20494 L
.57341 .1733 L
.56954 .14555 L
.56716 .13246 L
.56485 .12194 L
.56038 .10653 L
.55778 .09996 L
.55536 .09515 L
.55065 .08878 L
.54794 .08659 L
.54542 .08536 L
.54072 .0848 L
.53571 .08618 L
.53084 .08898 L
.52553 .09319 L
.51585 .10268 L
Mistroke
.49776 .12213 L
.47811 .14337 L
.46741 .15733 L
.45751 .17474 L
.44922 .19518 L
.44068 .22503 L
.43632 .24524 L
.43199 .26993 L
.4285 .29421 L
.42507 .32314 L
.4222 .35263 L
.41989 .38147 L
.41785 .4126 L
.41626 .44263 L
.41478 .479 L
.41366 .51937 L
.4131 .55525 L
.41294 .59294 L
.41327 .6318 L
.41418 .67226 L
.41556 .70802 L
.41726 .73856 L
.41932 .76607 L
.42147 .7884 L
.42428 .81103 L
.42719 .82923 L
.43066 .84585 L
.43457 .85973 L
.43809 .86885 L
.4421 .8762 L
.44657 .88141 L
.44913 .88323 L
.45149 .88429 L
.45613 .88491 L
.46057 .88403 L
.4644 .88238 L
.46865 .8798 L
.47727 .87295 L
.4928 .85827 L
.50962 .8423 L
.52804 .82423 L
.53797 .81219 L
.54711 .79793 L
.55567 .78023 L
.56446 .75558 L
.57259 .72441 L
.5796 .68812 L
.5852 .6498 L
.59036 .60278 L
.59479 .54583 L
Mistroke
.59666 .5119 L
.59797 .47974 L
.5985 .46228 L
.59888 .44579 L
.59928 .41528 L
.59932 .39855 L
.59925 .38335 L
.59906 .36705 L
.59871 .35022 L
.59792 .32574 L
.59673 .30105 L
.59529 .27955 L
.59373 .26148 L
.59174 .24336 L
.58929 .22588 L
.58644 .21023 L
.58356 .19799 L
.58055 .18804 L
.57718 .17962 L
.57418 .17403 L
.57078 .16943 L
.56882 .1675 L
.56701 .16611 L
.56489 .16494 L
.56285 .16421 L
.5592 .16377 L
.55711 .16395 L
.55516 .16436 L
.55131 .16579 L
.54766 .16777 L
.54081 .17275 L
.52537 .18746 L
.46948 .24397 L
.44011 .27594 L
.40996 .32037 L
.36212 .41537 L
.35097 .436 L
.34078 .45138 L
.33523 .45796 L
.32921 .46353 L
.32654 .46549 L
.3237 .46725 L
.31856 .46966 L
.31595 .47055 L
.31313 .4713 L
.31045 .47186 L
.308 .47226 L
.30253 .47297 L
.29936 .47338 L
.29641 .47385 L
Mistroke
.29386 .47438 L
.29114 .47513 L
.28839 .47614 L
.28534 .47765 L
.28269 .47936 L
.27984 .4817 L
.2747 .48758 L
.2717 .49225 L
.26846 .49856 L
.26565 .50533 L
.26272 .51396 L
.26017 .52308 L
.25744 .53486 L
.25297 .5605 L
.25052 .57944 L
.24848 .59927 L
.24653 .6239 L
.24566 .63765 L
.24484 .65327 L
.24371 .68183 L
.243 .71092 L
.24273 .72989 L
.24261 .74863 L
.24273 .78579 L
.24324 .81998 L
.24425 .85969 L
.24586 .90319 L
.2479 .94551 L
Mfstroke
.2479 .94551 m
.25138 1 L
s
.46667 .5 m
.46596 .5072 L
.46563 .51125 L
.46537 .51512 L
.46517 .51874 L
.46499 .5227 L
.46487 .52629 L
.4648 .52959 L
.46475 .53348 L
.46475 .53708 L
.4648 .54097 L
.46491 .54507 L
.46498 .54708 L
.46508 .54924 L
.4653 .55308 L
.46557 .55668 L
.46586 .55988 L
.46667 .56651 L
.4676 .57204 L
.46858 .57639 L
.46976 .5804 L
.4712 .58398 L
.47197 .58546 L
.47285 .58686 L
.47363 .58787 L
.47449 .58877 L
.47532 .58946 L
.47609 .58995 L
.47696 .59035 L
.47746 .59052 L
.47794 .59064 L
.47844 .59073 L
.47891 .59078 L
.47942 .5908 L
.47997 .59079 L
.48089 .59068 L
.48176 .5905 L
.48272 .59022 L
.48375 .58984 L
.48839 .58741 L
.4927 .58461 L
.50152 .57883 L
.50999 .57369 L
.51831 .56766 L
.52255 .56332 L
.52717 .55683 L
.53163 .54792 L
.534 .54169 L
.53605 .53518 L
.53784 .52843 L
Mistroke
.53962 .52033 L
.54236 .50389 L
.5435 .49463 L
.54447 .48432 L
.54483 .47954 L
.54514 .47449 L
.54535 .47016 L
.54552 .46555 L
.54564 .46113 L
.54569 .45716 L
.5457 .45326 L
.54567 .44965 L
.54559 .44557 L
.54546 .44192 L
.54527 .43806 L
.54501 .43416 L
.5447 .43052 L
.54437 .42737 L
.54347 .42095 L
.54252 .4161 L
.54137 .41183 L
.5407 .4099 L
.53996 .40809 L
.53852 .4055 L
.53759 .4043 L
.53668 .40343 L
.53585 .40284 L
.53537 .4026 L
.53492 .40241 L
.53409 .4022 L
.53328 .40212 L
.53255 .40216 L
.53175 .40231 L
.53087 .40258 L
.52993 .40299 L
.52821 .404 L
.52513 .40653 L
.52171 .41006 L
.50726 .42791 L
.49323 .44344 L
.48034 .45493 L
.46641 .46545 L
.4593 .46998 L
.45257 .47354 L
.44528 .47651 L
.43697 .47893 L
.43226 .48008 L
.42705 .48144 L
.42243 .48301 L
.41974 .48421 L
Mistroke
.41719 .48563 L
.41466 .48739 L
.41223 .48947 L
.40769 .49482 L
.40519 .49884 L
.40291 .50337 L
.40051 .50933 L
.39803 .51715 L
.39571 .5267 L
.39373 .53737 L
.39206 .54944 L
.39079 .56207 L
.3902 .56981 L
.38974 .57746 L
.38934 .5863 L
.38917 .59147 L
.38905 .59629 L
.38896 .60147 L
.38891 .60636 L
.3889 .61185 L
.38893 .6178 L
.38909 .62804 L
.38924 .63401 L
.38943 .63969 L
.38985 .64968 L
.39045 .66052 L
.39191 .68032 L
.39432 .70381 L
.39715 .72455 L
.40074 .74501 L
.40534 .76506 L
.41032 .78142 L
.4154 .79391 L
.42044 .80301 L
.42542 .80941 L
.42838 .81217 L
.43115 .81412 L
.4344 .81571 L
.43755 .8166 L
.44062 .81692 L
.44394 .8167 L
.4471 .81602 L
.44999 .81502 L
.45342 .81343 L
.45715 .81127 L
.46396 .80637 L
.52105 .75219 L
.53498 .73723 L
.54273 .7264 L
.54966 .71383 L
Mistroke
.55761 .69416 L
.5647 .66927 L
.57067 .6398 L
.57373 .62009 L
.57631 .59984 L
.57849 .5791 L
.58033 .55785 L
.58179 .53734 L
.5831 .51433 L
.58421 .48831 L
.58494 .46333 L
.58524 .44774 L
.58542 .43292 L
.58548 .40506 L
.58522 .38047 L
.58464 .35487 L
.5839 .33355 L
.58282 .31095 L
.58135 .28782 L
.57946 .26467 L
.57524 .228 L
.57223 .20932 L
.56919 .19454 L
.56559 .18111 L
.56151 .16995 L
.55781 .16274 L
.55421 .15789 L
.55211 .15588 L
.55015 .15451 L
.54798 .15347 L
.54567 .15287 L
.54192 .15287 L
.53788 .15401 L
.53403 .15598 L
.53051 .15838 L
.51368 .17451 L
.49785 .19162 L
.48115 .2095 L
.467 .228 L
.4591 .24257 L
.45193 .26083 L
.44811 .2734 L
.4441 .28953 L
.44072 .30606 L
.43734 .32624 L
.43424 .34897 L
.43167 .37195 L
.42949 .39581 L
.42747 .42303 L
.42552 .45741 L
Mistroke
.42417 .49087 L
.4236 .5101 L
.4232 .52831 L
.42291 .54848 L
.42276 .57019 L
.42278 .58891 L
.42295 .60909 L
.42325 .62791 L
.42365 .64498 L
.42473 .67621 L
.42631 .70732 L
.42807 .73289 L
.43036 .75818 L
.43312 .78138 L
.43599 .79987 L
.43891 .81455 L
.44174 .82565 L
.44518 .83595 L
.44856 .84334 L
.45239 .84909 L
.45656 .85283 L
.46019 .85438 L
.46425 .85462 L
.46866 .85349 L
.47115 .85235 L
.47344 .85104 L
.48212 .84453 L
.49757 .83054 L
.51447 .8153 L
.52223 .80769 L
.53047 .79772 L
.53744 .78641 L
.54497 .76919 L
.54892 .75719 L
.55249 .74395 L
.55657 .72529 L
.56008 .70531 L
.5665 .6549 L
.56948 .62173 L
.57186 .58707 L
.57356 .55494 L
.57494 .51905 L
.57578 .48734 L
.57631 .45176 L
.57643 .41346 L
.57601 .37297 L
.57512 .3362 L
.57389 .30441 L
.57201 .27051 L
.56949 .23828 L
Mistroke
.56669 .21193 L
.56382 .19162 L
.56011 .17204 L
.55787 .16304 L
.55574 .15599 L
.55166 .14593 L
.54954 .14217 L
.54716 .13898 L
.5449 .1368 L
.54273 .1354 L
.53861 .13431 L
.53411 .13502 L
.53155 .13613 L
.52917 .13752 L
.52082 .14444 L
.51195 .15373 L
.49596 .1714 L
.47921 .19021 L
.47051 .20224 L
.46596 .21005 L
.46116 .22001 L
.45681 .23108 L
.45295 .24303 L
.44578 .27264 L
.44249 .29059 L
.43922 .31226 L
.43401 .35817 L
.43155 .38749 L
.42957 .41713 L
.4278 .45176 L
.42699 .47184 L
.42638 .49085 L
.42559 .52538 L
.42519 .56339 L
.42525 .59664 L
.42574 .63116 L
.42662 .6637 L
.42782 .69257 L
.42917 .71675 L
.43092 .74077 L
.43335 .76633 L
.43587 .78653 L
.4391 .80616 L
.44241 .82117 L
.44567 .83213 L
.44882 .83994 L
.45241 .8462 L
.45633 .85049 L
.46035 .85272 L
.46265 .8532 L
Mistroke
.46476 .85321 L
.4689 .85225 L
.47287 .85036 L
.47749 .8473 L
.48179 .84389 L
.49159 .83515 L
.50965 .81878 L
.51854 .81053 L
.52674 .80173 L
.53614 .78829 L
.54102 .77895 L
.54608 .76675 L
.55397 .74064 L
.5582 .72167 L
.56193 .70093 L
.56528 .67811 L
.56853 .65075 L
.57105 .6246 L
.57343 .59402 L
.57554 .55895 L
.5771 .52424 L
.57779 .50357 L
.57836 .48152 L
.57871 .46256 L
.57894 .4418 L
.57897 .40444 L
.57855 .3714 L
.57815 .35369 L
.57757 .33506 L
.57616 .30311 L
.57445 .27571 L
.57225 .24968 L
.57008 .23007 L
.56743 .21135 L
.56443 .19515 L
.56136 .18262 L
.55846 .17361 L
.55515 .16602 L
.55144 .1602 L
.54931 .15793 L
.54736 .15643 L
.5435 .15484 L
.5398 .15476 L
.53628 .15573 L
.53254 .15765 L
.52933 .15986 L
.52581 .16276 L
.51056 .17829 L
.49489 .19517 L
.47792 .21344 L
Mistroke
.47018 .22304 L
.46204 .2354 L
.45522 .24868 L
.44791 .26729 L
.44004 .29479 L
.4359 .31364 L
.43233 .33318 L
.42644 .37489 L
.42387 .39848 L
.42141 .42601 L
.41951 .4523 L
.41803 .47798 L
.41735 .49246 L
.41672 .50829 L
.41589 .53609 L
.41545 .56258 L
.41534 .59015 L
.41553 .61303 L
.41605 .63722 L
.41695 .66184 L
.41809 .68313 L
.41965 .70461 L
.42165 .72514 L
.42386 .74241 L
.42617 .75652 L
.42845 .7676 L
.43102 .77751 L
.43351 .78511 L
.43637 .79185 L
.43907 .79664 L
.44165 .80005 L
.44479 .80289 L
.4477 .80447 L
.45113 .80525 L
.45441 .80508 L
.4577 .80419 L
.45959 .8034 L
.46136 .8025 L
.46883 .7974 L
.48232 .78512 L
.5129 .75551 L
.52691 .74216 L
.54218 .72527 L
.5564 .70437 L
.56911 .67848 L
.58084 .64559 L
.59041 .60966 L
.59981 .56266 L
.60676 .51581 L
.61174 .46974 L
Mistroke
.61369 .44525 L
.61495 .42403 L
.61543 .41331 L
.61574 .4037 L
.61593 .39556 L
.61602 .38722 L
.61603 .38313 L
.61601 .3788 L
.61595 .37447 L
.61587 .37059 L
.61565 .3641 L
.61549 .36069 L
.61532 .35773 L
.61499 .35305 L
.61457 .3485 L
.61368 .34146 L
.61305 .33784 L
.61241 .33489 L
.6111 .33049 L
.61039 .32876 L
.60959 .3273 L
.6089 .32633 L
.60811 .32554 L
.60724 .32499 L
.6063 .32473 L
.60539 .32477 L
.60455 .32503 L
.60359 .32555 L
.60269 .32624 L
.60099 .32801 L
.59918 .33047 L
.59724 .33365 L
.59091 .34694 L
.58492 .3619 L
.57936 .37574 L
.57712 .38067 L
.57484 .38488 L
.57377 .38652 L
.57276 .38783 L
.57187 .3888 L
.57089 .38967 L
.56985 .39036 L
.56927 .39064 L
.56873 .39084 L
.56821 .39099 L
.56774 .39107 L
.56721 .39113 L
.56665 .39114 L
.56608 .3911 L
.56575 .39106 L
Mistroke
.56545 .39101 L
.56486 .39089 L
.56429 .39074 L
.56299 .3903 L
.56151 .38968 L
Mfstroke
.46667 .51667 m
.46648 .52017 L
.46635 .52336 L
.46624 .52704 L
.46618 .5305 L
.46616 .53368 L
.46617 .53657 L
.46622 .53971 L
.46631 .54297 L
.46645 .54617 L
.46664 .54951 L
.46709 .55526 L
.46744 .55855 L
.46783 .56152 L
.46866 .56664 L
.46961 .57098 L
.47076 .57493 L
.47196 .57801 L
.47314 .58028 L
.47463 .58233 L
.4755 .58322 L
.47633 .58386 L
.47707 .58431 L
.47791 .58467 L
.47833 .58481 L
.47879 .58492 L
.47963 .58504 L
.48007 .58506 L
.48056 .58506 L
.48108 .58502 L
.48157 .58496 L
.48245 .58479 L
.48295 .58466 L
.48341 .58452 L
.48548 .5837 L
.48769 .58258 L
.49578 .57753 L
.5034 .57288 L
.51191 .5679 L
.51641 .56476 L
.52071 .56089 L
.52456 .55624 L
.52865 .54951 L
.53235 .54113 L
.53596 .5299 L
.53868 .51841 L
.54116 .50401 L
.54225 .49565 L
.54321 .48625 L
.54357 .48189 L
Mistroke
.5439 .47725 L
.54415 .47291 L
.54433 .46895 L
.54447 .4648 L
.54457 .46038 L
.54461 .45657 L
.54459 .45263 L
.54454 .44919 L
.54446 .44607 L
.54433 .44276 L
.54414 .43934 L
.54387 .43552 L
.54357 .43218 L
.54318 .42881 L
.5427 .42537 L
.54175 .42025 L
.54058 .41574 L
.53938 .41247 L
.53866 .41097 L
.53798 .40979 L
.53665 .40809 L
.53596 .40746 L
.53518 .40694 L
.53479 .40673 L
.53437 .40656 L
.53361 .40636 L
.53277 .40627 L
.53229 .40629 L
.53184 .40634 L
.53102 .40653 L
.53026 .40679 L
.52938 .40719 L
.52854 .40767 L
.52552 .40998 L
.52222 .41329 L
.50836 .43054 L
.49618 .44455 L
.48279 .45682 L
.46949 .46674 L
.45643 .47423 L
.44938 .47708 L
.44144 .47944 L
.43273 .4817 L
.4301 .48251 L
.42756 .48342 L
.42521 .48444 L
.42269 .48578 L
.42043 .48726 L
.41793 .48928 L
.41351 .49415 L
Mistroke
.41105 .49782 L
.40845 .50272 L
.40627 .50786 L
.40399 .51459 L
.40189 .5225 L
.40009 .53109 L
.39855 .54052 L
.39713 .55194 L
.39655 .55784 L
.396 .56459 L
.39558 .57085 L
.39522 .57778 L
.39496 .58432 L
.39476 .59178 L
.39465 .59881 L
.39461 .60557 L
.39468 .61469 L
.39476 .61941 L
.39488 .62469 L
.3952 .63419 L
.39562 .64326 L
.39626 .65408 L
.39699 .66407 L
.39917 .68659 L
.40149 .70456 L
.40459 .72327 L
.40843 .74123 L
.41252 .75605 L
.41702 .76858 L
.42165 .77825 L
.42607 .78506 L
.42867 .78812 L
.43113 .79043 L
.43382 .79239 L
.43639 .79375 L
.43925 .79473 L
.44238 .7952 L
.4457 .7951 L
.44889 .79449 L
.45178 .79354 L
.45495 .79211 L
.46164 .78801 L
.46893 .78225 L
.4822 .76982 L
.50702 .7457 L
.52118 .73247 L
.52892 .72456 L
.53611 .71592 L
.54272 .70606 L
.54863 .69481 L
Mistroke
.555 .67889 L
.56146 .65677 L
.56651 .63317 L
.57147 .60138 L
.57368 .58302 L
.5758 .56154 L
.57739 .5416 L
.57886 .51852 L
.58002 .49459 L
.58081 .47154 L
.5813 .44897 L
.58153 .42456 L
.58145 .40051 L
.58111 .37804 L
.58057 .35821 L
.57975 .33734 L
.57845 .31347 L
.57693 .29249 L
.57494 .27119 L
.57247 .25061 L
.56952 .23177 L
.56643 .21662 L
.56344 .20526 L
.55998 .19527 L
.55686 .18857 L
.55327 .18308 L
.55143 .18103 L
.54941 .17932 L
.5457 .17743 L
.54213 .17692 L
.53833 .17753 L
.53506 .17885 L
.53146 .18099 L
.52378 .18729 L
.51545 .19574 L
.50036 .2122 L
.48697 .22653 L
.47231 .24399 L
.46423 .25692 L
.45685 .27307 L
.45289 .28431 L
.44939 .29635 L
.44546 .31284 L
.44202 .3307 L
.43654 .36875 L
.43402 .39227 L
.43167 .41981 L
.42979 .44829 L
.42837 .47676 L
.4274 .50341 L
Mistroke
.42671 .53302 L
.42638 .56396 L
.42643 .59211 L
.42691 .62402 L
.42777 .65315 L
.4289 .67872 L
.43023 .70093 L
.43198 .72347 L
.43415 .74504 L
.43661 .76407 L
.43956 .78157 L
.44258 .79525 L
.44553 .80544 L
.44898 .81426 L
.451 .81818 L
.45292 .82117 L
.45498 .82369 L
.45689 .82544 L
.45911 .82689 L
.46124 .82772 L
.46496 .82811 L
.4671 .82781 L
.46911 .82724 L
.47319 .82536 L
.4776 .8225 L
.49295 .80934 L
.51106 .79315 L
.51906 .78572 L
.5279 .7758 L
.53178 .77035 L
.53594 .76338 L
.54333 .74684 L
.54732 .73484 L
.55139 .71958 L
.55817 .68453 L
.5614 .66169 L
.56453 .63381 L
.56712 .60433 L
.56913 .57506 L
.57103 .5381 L
.57186 .51626 L
.57247 .49563 L
.57288 .47733 L
.57318 .45701 L
.57333 .43573 L
.57332 .41587 L
.57295 .38118 L
.57254 .36207 L
.57204 .3448 L
.5708 .31464 L
Mistroke
.56905 .28499 L
.56695 .25877 L
.56464 .237 L
.56233 .21996 L
.5596 .20424 L
.55636 .19014 L
.55257 .17832 L
.55058 .17371 L
.54839 .16971 L
.54629 .16676 L
.54434 .16472 L
.54055 .16237 L
.53837 .16185 L
.53634 .16183 L
.53259 .16276 L
.52858 .16489 L
.52491 .16763 L
.52089 .17125 L
.51278 .17972 L
.49835 .19582 L
.4827 .21321 L
.47416 .22417 L
.46619 .23734 L
.45889 .25396 L
.45489 .26584 L
.45132 .27872 L
.44535 .30674 L
.44252 .32385 L
.43968 .34446 L
.43723 .36601 L
.43519 .38744 L
.43186 .4338 L
.43042 .46182 L
.42922 .49363 L
.42846 .52445 L
.42809 .5533 L
.42807 .58756 L
.42823 .60451 L
.42855 .62274 L
.42944 .65383 L
.43065 .68102 L
.43155 .69655 L
.43251 .71047 L
.43459 .73439 L
.43719 .75683 L
.4404 .77717 L
.44323 .79058 L
.44658 .80237 L
.44833 .80718 L
.45027 .81158 L
Mistroke
.45389 .81761 L
.45759 .82143 L
.4612 .82332 L
.46449 .82381 L
.46813 .82326 L
.472 .8217 L
.47568 .81953 L
.48258 .81422 L
.49815 .80017 L
.51271 .78714 L
.52636 .77336 L
.53339 .76386 L
.54083 .75032 L
.54498 .74048 L
.54883 .72941 L
.55571 .70331 L
.55901 .68699 L
.56231 .66726 L
.5676 .62563 L
.5701 .59927 L
.57215 .57261 L
.574 .54161 L
.5748 .52486 L
.57552 .50662 L
.57636 .47818 L
.57683 .45152 L
.577 .42002 L
.57679 .392 L
.5762 .3638 L
.57516 .33489 L
.57381 .30956 L
.57225 .28816 L
.5706 .27035 L
.56886 .25531 L
.56658 .23952 L
.56431 .22708 L
.56194 .21674 L
.55921 .20741 L
.55618 .19963 L
.55319 .19407 L
.55145 .19165 L
.54959 .18963 L
.5462 .18724 L
.54248 .18622 L
.54034 .18627 L
.53833 .18667 L
.53466 .18814 L
.53129 .19019 L
.52369 .19653 L
.49626 .22564 L
Mistroke
.4812 .24153 L
.47329 .25062 L
.46495 .26192 L
.45778 .27406 L
.45007 .29099 L
.44335 .31047 L
.43742 .33287 L
.43181 .36035 L
.42715 .38994 L
.42278 .42645 L
.41911 .46911 L
.41769 .49162 L
.41648 .51637 L
.41605 .52776 L
.41568 .53979 L
.41523 .56118 L
.41505 .58133 L
.41512 .59965 L
.41544 .61902 L
.41574 .6295 L
.41607 .63878 L
.41683 .6547 L
.41785 .67054 L
.41901 .68438 L
.42021 .69592 L
.4218 .70833 L
.4237 .72023 L
.4255 .72927 L
.42761 .73787 L
.42958 .74435 L
.43179 .75021 L
.43423 .75526 L
.43658 .75897 L
.439 .7618 L
.44134 .76374 L
.44347 .76493 L
.44583 .76566 L
.44858 .76588 L
.45111 .76556 L
.45407 .76466 L
.45691 .76334 L
.46198 .76011 L
.46755 .75562 L
.49196 .73157 L
.54154 .68403 L
.58708 .62367 L
.6103 .58385 L
.63013 .5531 L
.6397 .5422 L
.64452 .53801 L
Mistroke
.64984 .53441 L
.65525 .53177 L
.65832 .53067 L
.66115 .52987 L
.66675 .52874 L
.67217 .52794 L
.67734 .52712 L
.67999 .52657 L
.68295 .52576 L
.68549 .52486 L
.68824 .52359 L
.69085 .52204 L
.69326 .52027 L
.69875 .51464 L
.70184 .51023 L
.7047 .50516 L
.71034 .49149 L
.71338 .48148 L
.71604 .47067 L
.71973 .45137 L
.72335 .42496 L
.72496 .40942 L
.7265 .39093 L
.72776 .37172 L
.72871 .35263 L
.72946 .33229 L
.72996 .31213 L
.73029 .28858 L
.73035 .2619 L
.73012 .23497 L
.72963 .20839 L
.72895 .18358 L
.72795 .15586 L
.72458 .09003 L
.72197 .05147 L
.71905 .01516 L
Mfstroke
.71905 .01516 m
.71753 0 L
s
.46667 .53333 m
.46669 .5366 L
.46674 .53953 L
.46684 .54285 L
.46698 .54591 L
.46715 .54866 L
.46732 .55114 L
.46783 .55645 L
.46848 .56138 L
.46934 .56624 L
.47039 .57065 L
.4715 .57414 L
.47279 .57713 L
.47411 .57937 L
.47537 .5809 L
.47611 .58158 L
.47681 .58209 L
.47765 .58256 L
.47846 .58288 L
.47919 .58307 L
.48 .58319 L
.48043 .58321 L
.4809 .5832 L
.4814 .58317 L
.48186 .58311 L
.4827 .58295 L
.48361 .58271 L
.48559 .58196 L
.48745 .58106 L
.49175 .57855 L
.49984 .57354 L
.50801 .56892 L
.51216 .56648 L
.51603 .56382 L
.51972 .56065 L
.5236 .55625 L
.52743 .55035 L
.53145 .54175 L
.53523 .53037 L
.53713 .52283 L
.53871 .51528 L
.54002 .50772 L
.54125 .49904 L
.54221 .49048 L
.54291 .48249 L
.54345 .47427 L
.54366 .46976 L
.54381 .46553 L
.5439 .46168 L
.54394 .45818 L
Mistroke
.54394 .4544 L
.5439 .45049 L
.54385 .4483 L
.54379 .44632 L
.5436 .442 L
.54338 .43837 L
.54309 .43474 L
.54246 .42892 L
.54203 .42593 L
.54159 .42333 L
.5405 .41835 L
.53931 .41451 L
.53813 .41178 L
.53743 .41052 L
.53676 .40954 L
.53607 .40872 L
.5353 .40801 L
.53486 .40769 L
.53444 .40744 L
.53401 .40723 L
.53361 .40707 L
.53279 .40688 L
.53236 .40683 L
.53188 .40682 L
.53138 .40686 L
.53091 .40694 L
.53048 .40705 L
.53001 .40719 L
.52919 .40752 L
.52844 .40791 L
.52674 .40902 L
.52363 .41174 L
.5166 .41986 L
.50298 .43707 L
.4901 .45066 L
.47805 .46103 L
.4651 .47055 L
.45844 .47462 L
.45206 .47779 L
.44526 .48032 L
.44151 .48138 L
.43741 .48235 L
.42868 .48429 L
.42603 .48503 L
.42348 .4859 L
.42112 .48689 L
.41858 .48823 L
.41628 .48975 L
.41373 .49186 L
.40924 .49704 L
Mistroke
.40674 .501 L
.40412 .50629 L
.40173 .51245 L
.39965 .51921 L
.39785 .52649 L
.39609 .53547 L
.39439 .54687 L
.39306 .55898 L
.39251 .56547 L
.392 .5729 L
.39161 .5803 L
.39133 .58742 L
.39114 .59412 L
.39101 .60174 L
.39098 .60998 L
.39103 .61792 L
.39122 .6277 L
.39136 .63274 L
.39156 .63838 L
.39202 .64849 L
.39258 .65812 L
.3943 .68006 L
.39689 .70356 L
.39985 .72376 L
.40362 .74363 L
.40735 .759 L
.41193 .77373 L
.4169 .78582 L
.42178 .79454 L
.42461 .79842 L
.42776 .80185 L
.43083 .80438 L
.43371 .8061 L
.43643 .80719 L
.439 .8078 L
.44186 .80802 L
.44497 .80777 L
.44826 .80702 L
.45141 .80586 L
.45426 .80451 L
.45738 .80271 L
.47206 .7911 L
.48594 .77765 L
.5119 .75262 L
.52557 .73955 L
.53994 .72227 L
.54734 .70979 L
.55521 .69162 L
.56201 .66958 L
.56787 .64322 L
Mistroke
.5706 .62753 L
.57329 .60906 L
.5775 .57117 L
.57945 .54759 L
.58098 .52402 L
.58231 .49674 L
.5829 .48087 L
.58332 .46607 L
.5838 .4393 L
.58393 .41414 L
.58371 .38657 L
.58343 .3713 L
.58307 .35762 L
.58217 .3331 L
.58084 .30772 L
.57925 .28516 L
.57753 .26581 L
.57565 .24875 L
.57341 .23214 L
.56883 .20681 L
.56574 .19435 L
.56262 .18463 L
.5597 .17757 L
.5564 .17158 L
.55309 .16734 L
.54935 .16432 L
.54535 .16282 L
.54153 .16275 L
.53794 .16368 L
.53462 .16524 L
.53096 .1676 L
.52709 .17067 L
.49684 .20225 L
.48031 .22008 L
.47223 .23009 L
.46485 .24145 L
.45801 .25524 L
.451 .27455 L
.44436 .30033 L
.44083 .31837 L
.43773 .3377 L
.43516 .35699 L
.43292 .37711 L
.4293 .41944 L
.42766 .44546 L
.4264 .47087 L
.42534 .49992 L
.42458 .53179 L
.42422 .5649 L
.42421 .58371 L
Mistroke
.42432 .60115 L
.42458 .61937 L
.42493 .6357 L
.42547 .65413 L
.42611 .67107 L
.42756 .69966 L
.42924 .72413 L
.43142 .74852 L
.4341 .77131 L
.4371 .79068 L
.44065 .80784 L
.44425 .8206 L
.44774 .82955 L
.44982 .8336 L
.45179 .83668 L
.45398 .83936 L
.45637 .84148 L
.45891 .84294 L
.46134 .84368 L
.46354 .84387 L
.46594 .84363 L
.47004 .8423 L
.47391 .84023 L
.48276 .83356 L
.50074 .8173 L
.51756 .8021 L
.52498 .79435 L
.5292 .7891 L
.53314 .78336 L
.5411 .76812 L
.54508 .75793 L
.54927 .74465 L
.55344 .72805 L
.55761 .70699 L
.56099 .6856 L
.56432 .65931 L
.56715 .63101 L
.56942 .60262 L
.57136 .57177 L
.57285 .54079 L
.57414 .50294 L
.57489 .46693 L
.57519 .42699 L
.57514 .40695 L
.57492 .38515 L
.57416 .34906 L
.573 .31653 L
.57162 .28923 L
.56976 .26187 L
.56736 .23543 L
Mistroke
.56442 .21118 L
.56132 .1921 L
.55827 .17796 L
.55498 .16652 L
.55181 .15845 L
.54819 .15206 L
.54426 .14782 L
.54076 .14594 L
.53744 .14549 L
.53376 .1462 L
.52979 .14811 L
.52566 .15105 L
.52109 .15511 L
.51184 .16479 L
.49528 .18314 L
.47735 .20364 L
.47247 .21039 L
.46738 .21869 L
.46303 .22724 L
.45847 .23817 L
.45423 .25066 L
.45051 .26411 L
.44365 .29709 L
.44014 .31985 L
.43667 .34815 L
.43376 .37829 L
.43146 .40882 L
.42967 .43901 L
.42833 .46872 L
.42725 .50251 L
.42654 .53959 L
.42638 .55824 L
.42634 .57849 L
.42665 .61473 L
.42741 .64867 L
.42852 .67843 L
.4302 .70936 L
.43242 .73866 L
.43467 .76069 L
.43744 .78153 L
.44077 .80012 L
.44273 .80866 L
.44465 .81569 L
.4465 .82134 L
.44856 .82657 L
.45229 .83356 L
.45593 .83793 L
.46005 .84058 L
.46215 .84117 L
.46444 .84132 L
Mistroke
.4686 .84052 L
.47278 .83863 L
.47677 .83607 L
.48431 .83 L
.51381 .80333 L
.52194 .79544 L
.53059 .78513 L
.53867 .77196 L
.54583 .75556 L
.55299 .73236 L
.55686 .71584 L
.56029 .69798 L
.56656 .65447 L
.56961 .6257 L
.57204 .59693 L
.57385 .57033 L
.57544 .54059 L
.57678 .50666 L
.57763 .47451 L
.57806 .44451 L
.57815 .41653 L
.57791 .38645 L
.57725 .3552 L
.57609 .32368 L
.57463 .29653 L
.57262 .26956 L
.57004 .2443 L
.56691 .22191 L
.56361 .20468 L
.56041 .19235 L
.55853 .18667 L
.55672 .18211 L
.55337 .17564 L
.54956 .17085 L
.54575 .16823 L
.54357 .16753 L
.54156 .16732 L
.53796 .16785 L
.53399 .16952 L
.53022 .17192 L
.52672 .17471 L
.49358 .20933 L
.47742 .22673 L
.47037 .23544 L
.4627 .24682 L
.4559 .25955 L
.44971 .27427 L
.44343 .29349 L
.43709 .31891 L
.43079 .35293 L
Mistroke
.42562 .39105 L
.42176 .42963 L
.41995 .45299 L
.41854 .47511 L
.41739 .49754 L
.41647 .52141 L
.41583 .54541 L
.41547 .57139 L
.41545 .59347 L
.41571 .61631 L
.41622 .63696 L
.41691 .65482 L
.41807 .6762 L
.41942 .69433 L
.42117 .71239 L
.42332 .72929 L
.42541 .74211 L
.42753 .75255 L
.43002 .76232 L
.43286 .77093 L
.43593 .77788 L
.4389 .78275 L
.44066 .78493 L
.44227 .78653 L
.44416 .78796 L
.44596 .78894 L
.44758 .78953 L
.4493 .78988 L
.45241 .78989 L
.45416 .78958 L
.4558 .78912 L
.45761 .78843 L
.45955 .7875 L
.46659 .78286 L
.47329 .77716 L
.48587 .76494 L
.53414 .7182 L
.54737 .70291 L
.56136 .68218 L
.57407 .65731 L
.58499 .62977 L
.59539 .59681 L
.60531 .55787 L
.61902 .48838 L
.62832 .42876 L
.63101 .4112 L
.6329 .401 L
.63371 .39787 L
.6341 .39673 L
.63452 .39578 L
Mistroke
.63494 .39514 L
.63517 .39491 L
.63538 .39477 L
.6358 .3947 L
.6362 .39486 L
.63658 .39518 L
.63699 .39569 L
.63777 .39698 L
.63974 .4012 L
.64197 .40597 L
.64329 .40832 L
.64478 .4104 L
.64561 .41127 L
.64606 .41164 L
.64655 .41195 L
.647 .41217 L
.64742 .4123 L
.64825 .41235 L
.64909 .4121 L
.64957 .41181 L
.65001 .41144 L
.65082 .41049 L
.65122 .40986 L
.65167 .40906 L
.65312 .40543 L
.65391 .40267 L
.65461 .3996 L
.65581 .39262 L
.65642 .3879 L
.65692 .38308 L
.65733 .37816 L
.6577 .37246 L
.65804 .36559 L
.65828 .35869 L
.65842 .35174 L
.65849 .34482 L
.65849 .33672 L
.65837 .32749 L
.6581 .31616 L
.65771 .30503 L
.6571 .29213 L
.65625 .27773 L
.65429 .25209 L
.65131 .22228 L
.64791 .19511 L
.64341 .16596 L
.63306 .11653 L
Mfstroke
.48333 .46667 m
.48096 .47181 L
.47888 .47714 L
.47663 .48427 L
.47484 .49154 L
.47327 .49991 L
.47214 .50836 L
.47167 .51313 L
.47135 .51756 L
.47122 .51987 L
.47111 .52241 L
.47107 .52368 L
.47103 .52504 L
.47101 .52631 L
.47099 .52747 L
.47098 .52873 L
.47099 .52992 L
.47101 .5321 L
.47104 .5333 L
.47107 .5344 L
.47117 .53682 L
.47128 .53871 L
.47143 .54072 L
.47181 .54456 L
.47208 .54663 L
.47236 .54842 L
.47309 .55208 L
.47389 .55502 L
.47474 .55738 L
.47561 .55922 L
.4766 .5608 L
.47751 .56186 L
.47856 .56274 L
.47917 .5631 L
.47974 .56336 L
.48038 .56357 L
.4807 .56365 L
.48106 .56371 L
.48168 .56376 L
.48202 .56377 L
.48234 .56376 L
.48297 .5637 L
.48356 .5636 L
.48414 .56347 L
.48476 .56329 L
.4859 .56289 L
.48855 .56164 L
.49409 .55835 L
.50466 .5522 L
.51086 .54881 L
Mistroke
.51425 .54675 L
.51793 .54413 L
.52152 .541 L
.52477 .53748 L
.53096 .52822 L
.53393 .52222 L
.53686 .51493 L
.5414 .49992 L
.54344 .49091 L
.545 .48245 L
.54631 .47346 L
.54682 .46903 L
.54724 .46456 L
.54751 .46091 L
.54761 .45907 L
.5477 .45717 L
.54775 .45551 L
.54779 .45406 L
.5478 .45272 L
.5478 .45139 L
.54779 .45065 L
.54778 .45 L
.54776 .44928 L
.54773 .44861 L
.54768 .44749 L
.5476 .44635 L
.5475 .44518 L
.54737 .44406 L
.54723 .4431 L
.54709 .44231 L
.54681 .44107 L
.54665 .44052 L
.54646 .44 L
.54628 .43958 L
.54611 .43925 L
.54594 .43897 L
.54575 .43873 L
.54554 .43851 L
.54534 .43836 L
.54523 .4383 L
.5451 .43824 L
.54488 .43818 L
.54476 .43817 L
.54464 .43817 L
.54441 .43821 L
.54427 .43826 L
.54414 .43831 L
.54389 .43845 L
.54344 .4388 L
.54303 .43923 L
Mistroke
.54209 .44057 L
.5412 .44223 L
.54031 .44431 L
.53889 .44852 L
.53786 .45258 L
.53742 .45477 L
.53706 .45706 L
.53692 .45815 L
.53681 .45915 L
.53673 .46003 L
.53666 .46097 L
.53663 .4615 L
.53661 .46199 L
.5366 .4625 L
.53659 .46278 L
.53659 .46303 L
.53659 .46348 L
.53659 .46396 L
.5366 .46441 L
.53661 .46481 L
.53664 .46527 L
.53666 .46569 L
.53675 .46661 L
.53685 .46746 L
.537 .46833 L
.53714 .46901 L
.53732 .46968 L
.5377 .47075 L
.53796 .47132 L
.53823 .47178 L
.53849 .47213 L
.53879 .47243 L
.53893 .47255 L
.53909 .47266 L
.53919 .47271 L
.53927 .47275 L
.53936 .47278 L
.53944 .47281 L
.53954 .47283 L
.53962 .47285 L
.53973 .47286 L
.53982 .47286 L
.53991 .47285 L
.54001 .47283 L
.54011 .47281 L
.54019 .47279 L
.54036 .47272 L
.54052 .47263 L
.54087 .47236 L
.54122 .47199 L
Mistroke
.54159 .47145 L
.54194 .47081 L
.5423 .46999 L
.5429 .4681 L
.54321 .46682 L
.54346 .46547 L
.5437 .46382 L
.54382 .46283 L
.54391 .46185 L
.54399 .4609 L
.54405 .46 L
.5441 .45897 L
.54412 .45839 L
.54414 .45783 L
.54416 .45679 L
.54416 .4558 L
.54415 .45469 L
.54414 .45412 L
.54413 .45348 L
.54409 .45236 L
.54404 .45131 L
.54388 .44889 L
.54367 .4466 L
.54341 .4444 L
.54269 .43992 L
.54161 .43511 L
.54015 .43051 L
.53937 .42862 L
.53848 .4268 L
.53765 .42539 L
.53668 .42404 L
.53574 .42299 L
.53485 .4222 L
.53375 .42147 L
.53312 .42117 L
.53252 .42095 L
.53196 .42081 L
.53143 .42072 L
.53084 .42068 L
.53021 .42069 L
.52958 .42076 L
.52889 .42091 L
.52823 .4211 L
.52761 .42133 L
.52644 .42191 L
.52517 .42269 L
.52224 .42511 L
.51958 .42792 L
.5098 .44155 L
.49979 .45752 L
Mistroke
.49166 .47032 L
.48467 .48297 L
.48167 .4905 L
.4802 .4953 L
.479 .50015 L
.47801 .50532 L
.47758 .50815 L
.4772 .51121 L
.47693 .51391 L
.47682 .51534 L
.47671 .51689 L
.47664 .51831 L
.47658 .5196 L
.47654 .52083 L
.47652 .52211 L
.47651 .52336 L
.47651 .52449 L
.47653 .52578 L
.47657 .52697 L
.47662 .52807 L
.47667 .52906 L
.47683 .53123 L
.47705 .53333 L
.47735 .53551 L
.47773 .53762 L
.47815 .53945 L
.47918 .54271 L
.47987 .54424 L
.48055 .54546 L
.48125 .54643 L
.48194 .54718 L
.4827 .54782 L
.48312 .5481 L
.48358 .54836 L
.48435 .54869 L
.48479 .54883 L
.4852 .54892 L
.48558 .54899 L
.48594 .54903 L
.48636 .54906 L
.48676 .54907 L
.48721 .54906 L
.48768 .54903 L
.48809 .54898 L
.48854 .54892 L
.48957 .54872 L
.49055 .54847 L
.49867 .54574 L
.50882 .54244 L
.51173 .54129 L
Mistroke
.51492 .53967 L
.51801 .53754 L
.52084 .53493 L
.52374 .53136 L
.5268 .52631 L
.52955 .52026 L
.53189 .51357 L
.534 .50581 L
.53592 .49655 L
.53735 .48722 L
.53785 .48301 L
.53829 .47853 L
.5385 .47603 L
.53869 .47329 L
.53884 .4708 L
.53894 .46855 L
.53903 .46595 L
.53906 .46461 L
.53909 .46322 L
.5391 .46092 L
.5391 .45965 L
.53908 .45848 L
.53904 .45628 L
.53896 .45427 L
.53887 .45254 L
.53875 .45073 L
.53859 .44885 L
.53839 .44697 L
.53796 .44388 L
.53744 .44113 L
.53686 .43888 L
.53629 .43717 L
.5356 .43561 L
.5348 .43429 L
.53433 .43371 L
.53389 .43328 L
.53347 .43295 L
.53301 .43267 L
.53256 .43249 L
.53214 .43238 L
.53174 .43232 L
.53131 .43232 L
.5309 .43236 L
.53052 .43244 L
.53007 .43257 L
.52958 .43277 L
.52868 .43325 L
.52773 .4339 L
.52671 .43475 L
.52488 .43659 L
Mistroke
.51058 .45642 L
.50357 .46555 L
.49739 .47207 L
.49093 .47738 L
.48442 .48146 L
.4693 .48934 L
.46734 .49073 L
Mfstroke
.48333 .48333 m
.48177 .48754 L
.48044 .49174 L
.47904 .49708 L
.47796 .50222 L
.47706 .50786 L
.47673 .51049 L
.47644 .5133 L
.4762 .51628 L
.47612 .5176 L
.47604 .51901 L
.47599 .5205 L
.47595 .52189 L
.47594 .52273 L
.47593 .52351 L
.47593 .52422 L
.47593 .52498 L
.47594 .52575 L
.47596 .52645 L
.47598 .52721 L
.47601 .52801 L
.47607 .52932 L
.47616 .53072 L
.47638 .53319 L
.47666 .53534 L
.47706 .53766 L
.47749 .53958 L
.47807 .54154 L
.47869 .54314 L
.47927 .54433 L
.47994 .5454 L
.48055 .54617 L
.48125 .54685 L
.48204 .54741 L
.48251 .54765 L
.48294 .54782 L
.48333 .54794 L
.48376 .54804 L
.48398 .54808 L
.48422 .54811 L
.48465 .54814 L
.48508 .54814 L
.48532 .54813 L
.48555 .54811 L
.48602 .54806 L
.48629 .54802 L
.48653 .54797 L
.48746 .54775 L
.48835 .54748 L
.49267 .5456 L
Mistroke
.50121 .54136 L
.51072 .53696 L
.51518 .5345 L
.52019 .53093 L
.52566 .5255 L
.53071 .51856 L
.53613 .50844 L
.5405 .49768 L
.54708 .47602 L
.54917 .46782 L
.55059 .46249 L
.55118 .46064 L
.55147 .45988 L
.55176 .45923 L
.55202 .45878 L
.55215 .45859 L
.55229 .45842 L
.55242 .45829 L
.55254 .4582 L
.55266 .45814 L
.55278 .4581 L
.55292 .45808 L
.55305 .45808 L
.5532 .45812 L
.55335 .45819 L
.55349 .45827 L
.55361 .45836 L
.55392 .45864 L
.55462 .45952 L
.55545 .46078 L
.55729 .46368 L
.55984 .46719 L
.56132 .46883 L
.56287 .47022 L
.56438 .47124 L
.56528 .47169 L
.56569 .47185 L
.56615 .47199 L
.56662 .47211 L
.56713 .47218 L
.5676 .47222 L
.56805 .47221 L
.56859 .47215 L
.56908 .47205 L
.56936 .47197 L
.56966 .47187 L
.57021 .47162 L
.57121 .47099 L
.57172 .47058 L
.57228 .47003 L
Mistroke
.57327 .46885 L
.5742 .46743 L
.57536 .46517 L
.57638 .46261 L
.57743 .45928 L
.57849 .45489 L
.57932 .4504 L
.58008 .44488 L
.58041 .44193 L
.58067 .43897 L
.5809 .43593 L
.58108 .43301 L
.58123 .42975 L
.58135 .4261 L
.58142 .42257 L
.58145 .41911 L
.58143 .41494 L
.58136 .41096 L
.58122 .40646 L
.58113 .40414 L
.58101 .40154 L
.58041 .39205 L
.57995 .38657 L
.57944 .38151 L
.57823 .37152 L
.57683 .36232 L
.57365 .3466 L
.57163 .33894 L
.56922 .33145 L
.56642 .32448 L
.56355 .31888 L
.5608 .31474 L
.55766 .31123 L
.55594 .30981 L
.55433 .30875 L
.55244 .30784 L
.55062 .30726 L
.54891 .30696 L
.5473 .30689 L
.54552 .30702 L
.54361 .3074 L
.5425 .30773 L
.54147 .30809 L
.53915 .30912 L
.53491 .31168 L
.52689 .31836 L
.49298 .35517 L
.47849 .37092 L
.47047 .38169 L
.46338 .39469 L
Mistroke
.45952 .40412 L
.45554 .41654 L
.45205 .43069 L
.44913 .44603 L
.44676 .46217 L
.44456 .48208 L
.44364 .49286 L
.44281 .50496 L
.44217 .5168 L
.44173 .5279 L
.4414 .54013 L
.44124 .55177 L
.44122 .56225 L
.44133 .57352 L
.44161 .58567 L
.44182 .5917 L
.4421 .59821 L
.44271 .60943 L
.44342 .61949 L
.44519 .63777 L
.44721 .65248 L
.44847 .65971 L
.44997 .66681 L
.45296 .67764 L
.45476 .68249 L
.45653 .68632 L
.45854 .68974 L
.45961 .69118 L
.46079 .69254 L
.4619 .69358 L
.46309 .69449 L
.46437 .69523 L
.46558 .69573 L
.46679 .69606 L
.46795 .69621 L
.47014 .69615 L
.47226 .6957 L
.47452 .69486 L
.47647 .69389 L
.47863 .69261 L
.48801 .68537 L
.50629 .66987 L
.51542 .66231 L
.52393 .65371 L
.52863 .64737 L
.53356 .63861 L
.53885 .62557 L
.54337 .60994 L
.54717 .59199 L
.55081 .56835 L
Mistroke
.55227 .55603 L
.55366 .54208 L
.55569 .51498 L
.5565 .49976 L
.55686 .49154 L
.55718 .4827 L
.5576 .46629 L
.5578 .45101 L
.55781 .43644 L
.55768 .42294 L
.55736 .40845 L
.55681 .39338 L
.55607 .37897 L
.55503 .36421 L
.55372 .35009 L
.5523 .33825 L
.54934 .32034 L
.54746 .31225 L
.54565 .30608 L
.54383 .30118 L
.54181 .29705 L
.54004 .29432 L
.53803 .29212 L
.53583 .29061 L
.53341 .28987 L
.53109 .28991 L
.52896 .29049 L
.5268 .29152 L
.52479 .29283 L
.52021 .29673 L
.5119 .30585 L
.49491 .3261 L
.48609 .33646 L
.47692 .34891 L
.47213 .35723 L
.46704 .36855 L
.46261 .38153 L
.45873 .39639 L
.45508 .41483 L
.45214 .43446 L
.4507 .44646 L
.4493 .46032 L
.44814 .4742 L
.44724 .48741 L
.44654 .50019 L
.44594 .51442 L
.4455 .52965 L
.44527 .54416 L
.44523 .55757 L
.44536 .57162 L
Mistroke
.44564 .58451 L
.44604 .59581 L
.44635 .60263 L
.44673 .60962 L
.44754 .62155 L
.44859 .63345 L
.44995 .64529 L
.45128 .65444 L
.45285 .6631 L
.45434 .6697 L
.45603 .67573 L
.45803 .68132 L
.45997 .68545 L
.46215 .68886 L
.46343 .69035 L
.46464 .69147 L
.46572 .69225 L
.46687 .69288 L
.46896 .69354 L
.47014 .69367 L
.47124 .69366 L
.47246 .69351 L
.47377 .6932 L
.47605 .69236 L
.47855 .69106 L
.48311 .68797 L
.49173 .68086 L
.5105 .66515 L
.51979 .65691 L
.52828 .64695 L
.53282 .63976 L
.53703 .63127 L
.54134 .62018 L
.54579 .60521 L
.54998 .58648 L
.55391 .5627 L
.55699 .53696 L
.5582 .52397 L
.55917 .51144 L
.56 .49853 L
.56062 .48659 L
.56115 .47322 L
.56153 .4589 L
.56171 .44527 L
.56174 .43768 L
.56171 .43076 L
.56153 .41834 L
.56117 .40566 L
.56073 .39542 L
.56012 .38496 L
Mistroke
.55942 .37566 L
.55868 .36769 L
.5577 .35905 L
.5565 .35049 L
.554 .33727 L
.55232 .33083 L
.55065 .32572 L
.54906 .32191 L
.54727 .31856 L
.54525 .31577 L
.5442 .31468 L
.54304 .31373 L
.54203 .31309 L
.54094 .31259 L
.53893 .31211 L
.5369 .31214 L
.53574 .31236 L
.53466 .31267 L
.53267 .31352 L
.53054 .31476 L
.52683 .31755 L
.52272 .32135 L
.48877 .35826 L
.47406 .37395 L
.46636 .38362 L
.45829 .39602 L
.45066 .41098 L
.44414 .42722 L
.43309 .46554 L
.42835 .48848 L
.42429 .51352 L
.42154 .53595 L
.4199 .55458 L
.41935 .56336 L
.41916 .56725 L
.41903 .57069 L
.41892 .57443 L
.41888 .57632 L
.41885 .57826 L
.41884 .58168 L
.41886 .58456 L
.41892 .58727 L
.419 .58958 L
.41913 .59193 L
.41929 .5942 L
.41945 .59599 L
.41963 .59753 L
.42008 .60052 L
.42037 .6019 L
.42071 .60317 L
Mistroke
.42105 .60417 L
.42138 .60493 L
.42169 .60548 L
.42204 .60595 L
.42241 .60629 L
.42277 .60649 L
.42318 .60656 L
.42338 .60655 L
.42361 .6065 L
.42401 .60632 L
.42439 .60606 L
.42484 .60563 L
.42525 .60514 L
.42615 .60375 L
.42764 .6006 L
.4291 .59655 L
.4313 .58839 L
.43298 .57972 L
.43362 .57531 L
.43402 .57173 L
.43426 .56896 L
.43433 .5677 L
.43436 .56718 L
.43438 .56675 L
.43439 .56638 L
.4344 .56605 L
.4344 .56579 L
.4344 .5656 L
.4344 .56545 L
.4344 .56534 L
.4344 .56531 L
.43439 .56529 L
.43439 .56532 L
.43439 .5654 L
.43438 .56554 L
.43438 .56576 L
.43439 .56589 L
.43439 .56606 L
.4344 .56639 L
.43441 .56681 L
.43445 .56776 L
.43452 .56899 L
.43462 .5704 L
.43492 .57366 L
.43502 .57463 L
Mfstroke
.48333 .5 m
.48258 .50329 L
.482 .5064 L
.48149 .50984 L
.48127 .51175 L
.48111 .51348 L
.48105 .51435 L
.48099 .51527 L
.48095 .51605 L
.48092 .51689 L
.48089 .51778 L
.48088 .5186 L
.48088 .51909 L
.48088 .51955 L
.48089 .51997 L
.48089 .52042 L
.48092 .52122 L
.48095 .52194 L
.48099 .52275 L
.48105 .5235 L
.48117 .52479 L
.48134 .52611 L
.48157 .52747 L
.48182 .52864 L
.48217 .52993 L
.48252 .53099 L
.48337 .53283 L
.48391 .53365 L
.48445 .53431 L
.48494 .53479 L
.48549 .5352 L
.48598 .5355 L
.48654 .53575 L
.48686 .53586 L
.48716 .53594 L
.4875 .53602 L
.48767 .53605 L
.48786 .53608 L
.48817 .53611 L
.48848 .53613 L
.48866 .53614 L
.48884 .53614 L
.48917 .53614 L
.48948 .53612 L
.48982 .5361 L
.49014 .53606 L
.49043 .53602 L
.49188 .53575 L
.49344 .53534 L
.49498 .53488 L
Mistroke
.50117 .53287 L
.505 .53163 L
.50887 .53029 L
.51288 .52861 L
.51676 .52651 L
.52113 .52334 L
.52593 .51857 L
.53063 .51228 L
.53531 .50418 L
.54759 .47491 L
.54869 .47243 L
.54982 .47025 L
.55084 .46869 L
.55133 .46811 L
.55178 .46767 L
.55229 .46728 L
.55257 .46712 L
.55287 .46698 L
.55317 .46688 L
.55332 .46685 L
.55349 .46682 L
.55364 .4668 L
.55379 .46679 L
.55407 .4668 L
.55436 .46683 L
.55452 .46686 L
.55467 .46689 L
.55495 .46697 L
.55526 .46708 L
.5558 .46733 L
.55641 .46768 L
.55944 .46997 L
.56295 .47282 L
.5647 .47406 L
.56671 .47524 L
.56783 .47575 L
.56843 .47598 L
.5691 .47619 L
.56973 .47635 L
.57031 .47645 L
.57087 .47652 L
.57147 .47655 L
.57211 .47654 L
.57271 .47647 L
.57326 .47636 L
.57387 .4762 L
.57453 .47595 L
.57524 .47561 L
.57651 .47475 L
.5777 .47366 L
Mistroke
.57881 .47233 L
.58001 .47051 L
.58129 .46806 L
.58261 .46481 L
.58399 .46045 L
.58519 .45546 L
.58619 .45003 L
.58706 .44383 L
.58772 .43749 L
.58803 .43368 L
.5883 .42931 L
.58851 .42497 L
.58865 .42078 L
.58875 .41603 L
.58878 .41134 L
.58875 .40699 L
.58867 .40212 L
.58851 .39666 L
.5884 .39384 L
.58826 .3907 L
.58757 .37965 L
.58666 .36907 L
.58537 .35756 L
.58219 .33712 L
.57988 .32612 L
.57697 .315 L
.57351 .30471 L
.56994 .29659 L
.56629 .29039 L
.56277 .28603 L
.56075 .28415 L
.5585 .28254 L
.55632 .28142 L
.55428 .28073 L
.55209 .28034 L
.54998 .28028 L
.54806 .28048 L
.54596 .28095 L
.54365 .28175 L
.54118 .28289 L
.53669 .28565 L
.52776 .29313 L
.51965 .30139 L
.49954 .3234 L
.48121 .34265 L
.47225 .3533 L
.46404 .36598 L
.46001 .37406 L
.45583 .38442 L
.45141 .39844 L
Mistroke
.44766 .41388 L
.444 .43376 L
.44107 .45514 L
.43845 .48181 L
.4374 .49639 L
.43648 .51318 L
.43589 .52836 L
.43552 .54253 L
.4354 .55043 L
.43532 .55909 L
.43535 .57486 L
.43558 .58942 L
.43603 .60465 L
.43666 .61861 L
.43738 .63081 L
.43936 .65429 L
.44075 .66635 L
.44221 .67669 L
.4456 .69457 L
.44772 .70281 L
.44979 .70919 L
.45166 .71386 L
.45373 .71799 L
.45608 .72157 L
.45832 .72405 L
.46045 .72569 L
.46249 .72669 L
.46475 .72726 L
.46723 .72729 L
.46992 .72676 L
.47244 .72581 L
.47524 .72436 L
.47823 .72241 L
.49004 .71263 L
.51136 .69411 L
.52212 .68406 L
.52753 .67755 L
.53343 .66826 L
.53645 .66219 L
.53964 .65449 L
.54252 .64611 L
.54517 .63689 L
.54766 .62656 L
.55024 .61375 L
.55433 .58717 L
.55626 .57071 L
.55788 .55389 L
.55916 .53758 L
.56031 .51944 L
.56081 .50966 L
Mistroke
.5613 .49872 L
.56196 .47906 L
.56222 .46781 L
.56241 .45568 L
.5625 .44422 L
.56251 .43381 L
.56233 .41396 L
.56194 .39606 L
.56125 .37713 L
.56081 .36793 L
.56025 .35813 L
.55914 .34258 L
.55772 .32717 L
.55463 .30322 L
.55266 .29227 L
.55074 .28375 L
.54837 .27559 L
.54601 .26946 L
.54373 .26506 L
.54157 .26203 L
.53913 .25973 L
.53649 .25837 L
.53379 .25798 L
.53226 .25814 L
.53085 .2585 L
.5281 .2597 L
.52548 .26138 L
.51959 .26653 L
.51317 .27346 L
.4909 .29923 L
.47921 .31349 L
.47273 .32347 L
.46692 .33515 L
.4621 .34796 L
.45709 .36575 L
.45232 .38927 L
.44842 .41608 L
.44673 .43104 L
.44531 .44615 L
.44312 .47667 L
.44219 .49477 L
.44154 .51192 L
.44105 .53104 L
.4409 .54073 L
.4408 .55139 L
.44078 .56161 L
.44084 .57267 L
.44098 .58297 L
.44117 .59238 L
.44171 .60962 L
Mistroke
.44253 .62707 L
.4431 .63645 L
.4438 .64614 L
.44529 .66241 L
.44698 .67652 L
.44873 .68792 L
.45042 .69676 L
.45237 .7049 L
.45465 .71229 L
.45688 .71781 L
.45813 .72025 L
.45951 .72252 L
.46075 .7242 L
.46209 .72568 L
.46467 .72765 L
.4671 .72863 L
.46946 .7289 L
.47207 .72857 L
.47482 .72764 L
.4774 .72634 L
.48205 .72325 L
.48706 .71925 L
.5091 .70042 L
.51998 .69067 L
.52533 .68474 L
.53023 .67798 L
.53464 .6703 L
.5392 .66014 L
.54362 .64737 L
.54822 .62986 L
.55266 .60712 L
.55479 .59328 L
.55687 .57719 L
.55867 .56049 L
.5601 .54443 L
.56136 .5273 L
.56233 .51099 L
.5631 .49457 L
.56371 .47699 L
.56411 .45923 L
.5643 .43988 L
.56425 .4234 L
.56398 .40622 L
.56353 .39062 L
.56296 .37704 L
.56202 .361 L
.56078 .34533 L
.55954 .33317 L
.55799 .32112 L
.55613 .30982 L
Mistroke
.55392 .29955 L
.55167 .2916 L
.54949 .28575 L
.54721 .28118 L
.54501 .27801 L
.54254 .2756 L
.54112 .2747 L
.53983 .27414 L
.53742 .27369 L
.53604 .27374 L
.53477 .27396 L
.53241 .27475 L
.52991 .27607 L
.52742 .27777 L
.52471 .27998 L
.51977 .28473 L
.51051 .29487 L
.48989 .31759 L
.48072 .32759 L
.4709 .33992 L
.46183 .35494 L
.45387 .3733 L
.45 .38488 L
.44598 .39937 L
.43883 .43444 L
.43562 .45626 L
.43279 .48129 L
.43166 .49388 L
.43074 .50593 L
.42999 .51764 L
.42942 .5286 L
.42896 .54004 L
.42877 .54606 L
.42861 .55247 L
.42849 .55909 L
.42842 .56529 L
.42841 .57665 L
.42854 .58687 L
.42878 .59597 L
.42916 .60552 L
.4297 .61511 L
.43045 .62487 L
.43142 .63453 L
.4325 .64278 L
.43361 .64961 L
.436 .6606 L
.43733 .66518 L
.43887 .66949 L
.44029 .67268 L
.44186 .6755 L
Mistroke
.44364 .67797 L
.44534 .67971 L
.44696 .68089 L
.44851 .68164 L
.45024 .68211 L
.45123 .68222 L
.45214 .68224 L
.45373 .68206 L
.45523 .6817 L
.45688 .68111 L
.45866 .68026 L
.46233 .67797 L
.46568 .67536 L
.4967 .64404 L
.52769 .61583 L
.55714 .59229 L
.58752 .57399 L
.60417 .56674 L
.60872 .56463 L
.61374 .56197 L
.62303 .55536 L
.62785 .55052 L
.63297 .5438 L
.63772 .53552 L
.64192 .52599 L
.64592 .51425 L
.64998 .49853 L
.65349 .48036 L
.65635 .46049 L
.65761 .44954 L
.65882 .43693 L
.65976 .42526 L
.66064 .41179 L
.66149 .39489 L
.66209 .37786 L
.66247 .36032 L
.66263 .34334 L
.6626 .32471 L
.66235 .30661 L
.66185 .28611 L
.66102 .26343 L
.65982 .23922 L
.65836 .21588 L
.65473 .17196 L
.65431 .16768 L
Mfstroke
.48333 .51667 m
.48334 .51728 L
.48335 .51783 L
.48337 .51846 L
.48339 .51904 L
.48342 .51957 L
.48346 .52006 L
.48355 .52112 L
.48368 .52215 L
.48385 .52323 L
.48406 .52431 L
.48429 .52524 L
.48484 .52695 L
.4852 .52778 L
.48556 .5285 L
.48629 .52961 L
.48717 .53057 L
.48772 .53101 L
.48826 .53136 L
.48877 .53162 L
.48934 .53185 L
.48998 .53204 L
.49059 .53217 L
.49094 .53223 L
.49127 .53227 L
.49163 .5323 L
.49184 .53232 L
.49204 .53233 L
.49236 .53234 L
.49253 .53234 L
.49271 .53234 L
.49304 .53234 L
.49335 .53233 L
.49353 .53232 L
.49372 .53231 L
.49406 .53229 L
.49485 .53223 L
.49622 .53208 L
.49779 .53188 L
.50447 .53082 L
.50661 .5304 L
.50873 .52991 L
.51069 .52934 L
.51292 .52852 L
.51514 .52749 L
.51727 .52625 L
.51955 .52457 L
.52203 .52227 L
.52432 .51963 L
.52647 .51662 L
Mistroke
.53033 .50965 L
.5341 .50027 L
.53738 .48902 L
.53963 .47833 L
.54033 .47399 L
.54093 .46958 L
.54137 .46535 L
.54153 .46327 L
.54159 .46235 L
.54163 .46151 L
.54167 .46077 L
.54169 .46 L
.54171 .45933 L
.54172 .45875 L
.54172 .45815 L
.54171 .45753 L
.5417 .45692 L
.54168 .45639 L
.54165 .45588 L
.54161 .45537 L
.54156 .45489 L
.54151 .45448 L
.5414 .45386 L
.54134 .45356 L
.54127 .45333 L
.5412 .45311 L
.54111 .45292 L
.54107 .45284 L
.54102 .45276 L
.54097 .4527 L
.54092 .45265 L
.54083 .45258 L
.54078 .45256 L
.54074 .45255 L
.54065 .45254 L
.54056 .45257 L
.54047 .45262 L
.54039 .45269 L
.5403 .45279 L
.5402 .45292 L
.54005 .45319 L
.53988 .45355 L
.53971 .45403 L
.53953 .45462 L
.53925 .45586 L
.53912 .45661 L
.539 .45748 L
.53891 .45834 L
.53887 .45877 L
.53884 .45917 L
Mistroke
.53882 .45957 L
.5388 .45993 L
.53879 .46034 L
.53878 .46079 L
.53878 .46122 L
.53878 .46146 L
.53878 .46169 L
.53879 .46211 L
.5388 .46256 L
.53882 .46299 L
.53885 .46347 L
.53894 .46443 L
.53904 .46531 L
.53916 .46614 L
.53952 .46796 L
.54004 .46984 L
.54067 .47149 L
.54139 .47293 L
.54212 .47408 L
.54255 .47462 L
.54303 .47515 L
.54353 .4756 L
.544 .47595 L
.54448 .47623 L
.54499 .47645 L
.54527 .47654 L
.54543 .47657 L
.54558 .4766 L
.54588 .47664 L
.54615 .47665 L
.5463 .47665 L
.54647 .47663 L
.54678 .47659 L
.54695 .47655 L
.54711 .4765 L
.54748 .47637 L
.5478 .47621 L
.54816 .476 L
.54882 .47548 L
.54946 .47481 L
.55005 .47402 L
.55135 .47161 L
.55205 .46984 L
.55264 .46796 L
.55363 .46375 L
.55405 .46125 L
.55445 .45821 L
.55472 .45536 L
.55485 .45367 L
.55495 .45207 L
Mistroke
.55502 .45053 L
.55508 .44881 L
.55511 .44713 L
.55513 .44554 L
.55513 .44367 L
.5551 .44161 L
.55504 .43962 L
.55497 .43776 L
.55485 .43556 L
.55469 .43312 L
.55429 .4286 L
.55373 .42385 L
.55297 .41881 L
.55116 .41011 L
.55003 .40605 L
.54868 .40208 L
.5459 .39604 L
.54417 .39338 L
.54244 .39138 L
.5414 .39045 L
.54043 .38976 L
.53988 .38943 L
.53928 .38912 L
.53875 .38889 L
.53817 .38869 L
.5372 .38845 L
.53628 .38833 L
.53575 .38831 L
.53518 .38832 L
.53415 .38843 L
.53362 .38852 L
.53305 .38866 L
.53203 .38899 L
.5308 .3895 L
.52967 .39008 L
.52543 .3931 L
.5214 .39694 L
.48995 .43609 L
.4821 .44652 L
.4784 .45262 L
.47515 .45925 L
.47195 .46767 L
.46887 .47871 L
.46745 .48535 L
.46609 .49328 L
.465 .50137 L
.46418 .50931 L
.46385 .51342 L
.46355 .51782 L
.46335 .52167 L
Mistroke
.46317 .52583 L
.4631 .52818 L
.46305 .53032 L
.46299 .53452 L
.46298 .53685 L
.46299 .53938 L
.46301 .54175 L
.46306 .54393 L
.46317 .54773 L
.46332 .55123 L
.46353 .55498 L
.46381 .5589 L
.46457 .56642 L
.46546 .57268 L
.46643 .57782 L
.46746 .58203 L
.46872 .58601 L
.47019 .58952 L
.47098 .591 L
.47186 .59239 L
.47267 .59344 L
.47355 .59437 L
.47436 .59506 L
.47527 .59567 L
.47612 .59609 L
.47692 .59637 L
.4779 .59658 L
.4784 .59663 L
.47895 .59665 L
.47994 .59661 L
.48088 .59647 L
.48142 .59635 L
.48199 .59619 L
.48302 .59585 L
.48538 .59482 L
.49389 .58962 L
.51077 .5794 L
.51545 .57625 L
.51992 .5723 L
.52239 .56945 L
.52506 .56565 L
.52724 .56181 L
.52958 .55674 L
.53361 .5449 L
.53562 .53688 L
.53735 .52836 L
.53995 .51085 L
.54111 .49994 L
.54194 .48946 L
.54232 .48312 L
Mistroke
.54261 .47709 L
.5428 .47165 L
.54295 .46578 L
.54302 .45941 L
.54303 .45624 L
.54301 .45279 L
.54291 .44678 L
.54275 .44133 L
.54252 .43601 L
.54224 .43116 L
.54155 .42264 L
.54107 .41823 L
.54058 .41441 L
.5393 .40668 L
.5378 .40031 L
.53621 .39556 L
.53524 .39338 L
.53432 .39171 L
.53326 .39022 L
.53267 .38955 L
.53212 .38903 L
.53105 .38826 L
.53045 .38795 L
.52988 .38774 L
.52885 .38754 L
.52772 .38756 L
.52713 .38766 L
.52646 .38783 L
.52577 .38809 L
.52511 .38839 L
.52267 .38996 L
.52029 .39206 L
.51809 .39438 L
.51313 .40047 L
.50432 .41237 L
.48855 .43226 L
.47987 .44367 L
.47576 .45021 L
.47212 .45712 L
.46588 .47295 L
.46303 .48279 L
.46043 .49413 L
.45831 .50614 L
.45684 .51724 L
.45623 .5233 L
.45597 .52644 L
.45573 .52972 L
.45556 .53253 L
.45541 .53556 L
.45531 .53824 L
Mistroke
.45525 .5407 L
.45522 .54304 L
.45521 .54553 L
.45523 .54779 L
.45528 .54982 L
.45535 .55176 L
.45543 .55346 L
.45555 .55533 L
.45568 .55702 L
.45604 .56055 L
.45646 .56344 L
.45701 .56622 L
.45767 .56873 L
.45841 .5708 L
.45918 .57238 L
.45992 .57349 L
.46077 .5744 L
.46122 .57474 L
.46174 .57504 L
.462 .57516 L
.46228 .57526 L
.46281 .57538 L
.46331 .57542 L
.46384 .5754 L
.4643 .57533 L
.46481 .57519 L
.46533 .57501 L
.46583 .57479 L
.46677 .57426 L
.4689 .57264 L
.47275 .56864 L
.48846 .54787 L
.49571 .53908 L
.50349 .53122 L
.51105 .52531 L
.5186 .52078 L
.51921 .52044 L
Mfstroke
.48333 .53333 m
.4842 .5348 L
.48511 .53589 L
.48568 .5364 L
.48621 .53679 L
.48686 .53716 L
.48749 .53744 L
.48813 .53765 L
.48846 .53774 L
.48883 .53781 L
.48915 .53787 L
.4895 .53791 L
.48983 .53794 L
.49014 .53796 L
.49053 .53797 L
.4909 .53798 L
.49111 .53797 L
.49131 .53797 L
.49154 .53796 L
.49175 .53795 L
.49215 .53792 L
.49251 .53789 L
.49336 .5378 L
.4967 .53729 L
.50071 .53659 L
.50537 .53578 L
.50755 .53533 L
.51002 .5347 L
.51251 .53386 L
.51489 .53277 L
.51721 .53135 L
.51972 .52931 L
.52236 .52646 L
.52481 .523 L
.5274 .51822 L
.53002 .51188 L
.5321 .50539 L
.53379 .49865 L
.53535 .49069 L
.53662 .48187 L
.53709 .47742 L
.53729 .4751 L
.53747 .47268 L
.5376 .4706 L
.53771 .46835 L
.53775 .46738 L
.53778 .46636 L
.53782 .46453 L
.53784 .4627 L
.53784 .46168 L
Mistroke
.53784 .46076 L
.53781 .45911 L
.53775 .45742 L
.53768 .45582 L
.53758 .45439 L
.53736 .45188 L
.53722 .45068 L
.53705 .44947 L
.5367 .44747 L
.53622 .4454 L
.53572 .44381 L
.53515 .44244 L
.53483 .44184 L
.53447 .44128 L
.53415 .44087 L
.53379 .44048 L
.53347 .44021 L
.53312 .43998 L
.53279 .43981 L
.53243 .43969 L
.53209 .43962 L
.53178 .4396 L
.5314 .43961 L
.53105 .43967 L
.53064 .43978 L
.53026 .43993 L
.52955 .44029 L
.5289 .44072 L
.52741 .442 L
.52431 .44566 L
.5215 .44971 L
.51564 .45915 L
.50646 .47312 L
.50233 .47818 L
.49795 .48263 L
.48952 .48923 L
.48507 .49243 L
.48262 .49446 L
.47994 .49718 L
.47745 .50058 L
.4764 .50241 L
.4753 .5047 L
.47351 .50975 L
.47268 .513 L
.47204 .51634 L
.47176 .51819 L
.47151 .52023 L
.4714 .52132 L
.4713 .52254 L
.47122 .52368 L
Mistroke
.47115 .52474 L
.47111 .52581 L
.47107 .52685 L
.47105 .52794 L
.47105 .52857 L
.47105 .52914 L
.47106 .53021 L
.47108 .53117 L
.47112 .53228 L
.47116 .53332 L
.4713 .53528 L
.47149 .53731 L
.4717 .53901 L
.47197 .54082 L
.47233 .54271 L
.47277 .54463 L
.47372 .54779 L
.47433 .54934 L
.47504 .55082 L
.47646 .55302 L
.47733 .55398 L
.47819 .55472 L
.47918 .55534 L
.47975 .55561 L
.48029 .5558 L
.48074 .55593 L
.48123 .55603 L
.48169 .55609 L
.48212 .55612 L
.48263 .55613 L
.48293 .55613 L
.4832 .55611 L
.4837 .55607 L
.48423 .55599 L
.48475 .55589 L
.48532 .55576 L
.48635 .55547 L
.48877 .55458 L
.4983 .55032 L
.50381 .54829 L
.50701 .54725 L
.51013 .54616 L
.51326 .54482 L
.51494 .54391 L
.51673 .54273 L
.51826 .54152 L
.51994 .53991 L
.52288 .53618 L
.52579 .53094 L
.52736 .52726 L
Mistroke
.52873 .52339 L
.53117 .51443 L
.53314 .50423 L
.53401 .49822 L
.5347 .49228 L
.53532 .48549 L
.53559 .48162 L
.53579 .47799 L
.53596 .47421 L
.53603 .47221 L
.53608 .47009 L
.53612 .46807 L
.53614 .46618 L
.53615 .46267 L
.53611 .45926 L
.53604 .45619 L
.53592 .45289 L
.53574 .44952 L
.53554 .44668 L
.53533 .44418 L
.53475 .43892 L
.53409 .43454 L
.53336 .43087 L
.5324 .42721 L
.53142 .42442 L
.53024 .42202 L
.52961 .42106 L
.5289 .42019 L
.52824 .41958 L
.52761 .41914 L
.52691 .41881 L
.52651 .41869 L
.52615 .41862 L
.5254 .41858 L
.52498 .41861 L
.52458 .41868 L
.52385 .4189 L
.52307 .41924 L
.52169 .42012 L
.52038 .4212 L
.51741 .42441 L
.50529 .44276 L
.48619 .47104 L
.48177 .47796 L
.47731 .48635 L
.4736 .49525 L
.47074 .50412 L
.46835 .51388 L
.46748 .51843 L
.46686 .52234 L
Mistroke
.46644 .52557 L
.46611 .52876 L
.466 .53027 L
.46593 .53157 L
.4659 .53225 L
.46588 .53283 L
.46587 .53348 L
.46586 .53407 L
.46586 .53457 L
.46587 .53509 L
.46589 .53555 L
.46591 .53594 L
.46593 .53636 L
.46597 .53678 L
.46601 .53719 L
.46605 .53754 L
.46611 .53788 L
.46616 .53817 L
.46628 .53863 L
.46635 .53885 L
.46641 .53903 L
.46649 .53919 L
.46658 .53934 L
.46665 .53943 L
.46672 .53949 L
.46679 .53955 L
.46686 .53958 L
.46694 .5396 L
.46701 .5396 L
.46709 .53959 L
.46718 .53955 L
.46726 .53951 L
.46735 .53944 L
.4675 .53927 L
.46769 .53901 L
.46785 .53871 L
.46817 .53798 L
.46848 .53701 L
.46873 .53596 L
.46893 .53491 L
.46902 .53429 L
.4691 .5336 L
.46914 .53324 L
.46917 .53283 L
.4692 .53246 L
.46922 .53211 L
.46924 .53176 L
.46925 .53142 L
.46925 .53106 L
.46926 .53086 L
Mistroke
.46926 .53067 L
.46925 .53033 L
.46925 .53001 L
.46923 .52965 L
.46922 .52931 L
.46917 .52864 L
.46911 .52801 L
.46903 .52733 L
.46891 .52661 L
.46861 .52516 L
.46825 .5239 L
.46784 .52279 L
.46731 .52166 L
.46673 .52068 L
.46612 .51986 L
.46551 .5192 L
.46478 .5186 L
.46436 .51833 L
.46391 .5181 L
.4635 .51795 L
.46327 .51788 L
.46305 .51783 L
.46281 .5178 L
.46256 .51777 L
.46231 .51777 L
.46208 .51778 L
.46187 .5178 L
.46163 .51784 L
.46138 .5179 L
.46115 .51797 L
.46062 .5182 L
.46012 .51849 L
.45954 .51893 L
.459 .51946 L
Mfstroke
.5 .46667 m
.49403 .47867 L
.48896 .48973 L
.48695 .49497 L
.48518 .50055 L
.48436 .50373 L
.48375 .50658 L
.48328 .50921 L
.48308 .51061 L
.48292 .5119 L
.4828 .51307 L
.48271 .51411 L
.48264 .51523 L
.48261 .51583 L
.48259 .51639 L
.48258 .51684 L
.48258 .51732 L
.48258 .51776 L
.48259 .51816 L
.4826 .51861 L
.48262 .51909 L
.48264 .51953 L
.48267 .51992 L
.48275 .52076 L
.48285 .5215 L
.48298 .52225 L
.48314 .52299 L
.48334 .52369 L
.48355 .52429 L
.48378 .52481 L
.48401 .52524 L
.48448 .5259 L
.48475 .52617 L
.48506 .52642 L
.48538 .52662 L
.48556 .5267 L
.48574 .52677 L
.4859 .52682 L
.48605 .52685 L
.48622 .52688 L
.48631 .5269 L
.4864 .52691 L
.48655 .52692 L
.48672 .52692 L
.48689 .52692 L
.48706 .5269 L
.48722 .52689 L
.48736 .52686 L
.48769 .5268 L
.48806 .5267 L
Mistroke
.48846 .52657 L
.4892 .52626 L
.49093 .52532 L
.49255 .52425 L
.49638 .52149 L
.50438 .51595 L
.50846 .51352 L
.51337 .51106 L
.51883 .50897 L
.52549 .50714 L
.52907 .50622 L
.53272 .50504 L
.53483 .50412 L
.5372 .50278 L
.53939 .50112 L
.54143 .49908 L
.5434 .49651 L
.54546 .49294 L
.54731 .48866 L
.54887 .48383 L
.5504 .47736 L
.55115 .47316 L
.55174 .4689 L
.55226 .46403 L
.55263 .45931 L
.55278 .45658 L
.55284 .45511 L
.5529 .45354 L
.55294 .45214 L
.55297 .4506 L
.553 .44783 L
.55299 .44495 L
.55295 .44225 L
.55286 .43926 L
.5528 .43774 L
.55272 .43605 L
.55256 .43324 L
.55234 .4302 L
.55182 .42474 L
.55117 .41948 L
.55032 .41414 L
.5484 .40534 L
.54712 .40096 L
.54558 .39681 L
.54399 .39345 L
.54243 .39091 L
.54048 .38856 L
.53933 .38755 L
.53824 .38681 L
.53727 .38632 L
Mistroke
.53671 .3861 L
.53617 .38594 L
.53509 .38574 L
.53447 .38569 L
.5339 .38569 L
.53281 .38579 L
.53177 .38601 L
.53082 .38631 L
.52979 .38673 L
.52746 .38804 L
.52529 .38962 L
.5171 .39796 L
.49915 .421 L
.49099 .43112 L
.48247 .44239 L
.47849 .44893 L
.47489 .45639 L
.47185 .46449 L
.46887 .47513 L
.46641 .48728 L
.46524 .49501 L
.46431 .50276 L
.46353 .5113 L
.46301 .51941 L
.46281 .52373 L
.46271 .52622 L
.46265 .52848 L
.46259 .53088 L
.46255 .53345 L
.46253 .53804 L
.46256 .54203 L
.46265 .5462 L
.46276 .5497 L
.46293 .55347 L
.46317 .55743 L
.46348 .56154 L
.4642 .56853 L
.46511 .57495 L
.46613 .58038 L
.46718 .58466 L
.46844 .58868 L
.47006 .5925 L
.47103 .59425 L
.47195 .59562 L
.47286 .59671 L
.47373 .59755 L
.47466 .59825 L
.47516 .59855 L
.47571 .59883 L
.47667 .59919 L
Mistroke
.47759 .5994 L
.47851 .59949 L
.47936 .59948 L
.48029 .59938 L
.48133 .59917 L
.48242 .59884 L
.48345 .59846 L
.48806 .59607 L
.49237 .5933 L
.50235 .58689 L
.51113 .58167 L
.51608 .57821 L
.5208 .57379 L
.52348 .57047 L
.52634 .56599 L
.53116 .55538 L
.5334 .54859 L
.53561 .54018 L
.53907 .52196 L
.54057 .51074 L
.54174 .49932 L
.54256 .48857 L
.54293 .48236 L
.54319 .47657 L
.54341 .47037 L
.54354 .46456 L
.5436 .45825 L
.5436 .45473 L
.54358 .45154 L
.54348 .4456 L
.54339 .4423 L
.54328 .43928 L
.543 .43336 L
.54261 .42732 L
.54218 .42225 L
.54173 .41783 L
.5405 .40884 L
.5392 .40215 L
.53762 .39636 L
.53607 .39229 L
.53451 .38942 L
.53358 .38815 L
.5327 .38723 L
.53167 .38642 L
.53067 .3859 L
.52957 .3856 L
.52894 .38553 L
.52835 .38553 L
.52727 .3857 L
.52612 .38607 L
Mistroke
.52508 .38656 L
.5241 .38714 L
.52187 .38884 L
.51724 .39361 L
.51231 .39976 L
.49585 .42128 L
.48757 .43126 L
.47898 .44251 L
.47466 .44943 L
.4701 .45841 L
.4662 .46813 L
.46296 .47831 L
.46019 .48927 L
.45775 .50159 L
.45586 .51431 L
.45505 .52147 L
.45447 .52796 L
.45426 .53082 L
.45408 .53386 L
.45395 .53647 L
.45384 .53917 L
.45377 .54155 L
.45373 .54408 L
.45372 .54631 L
.45373 .54833 L
.45377 .55078 L
.45385 .55299 L
.45394 .5549 L
.45406 .55688 L
.45423 .55892 L
.45443 .56095 L
.45488 .56428 L
.4554 .56704 L
.45603 .56953 L
.45663 .57131 L
.45735 .57292 L
.45818 .57428 L
.45867 .57487 L
.45913 .57531 L
.45957 .57565 L
.46006 .57592 L
.46053 .57611 L
.46097 .57622 L
.46138 .57627 L
.46183 .57627 L
.46226 .57622 L
.46265 .57614 L
.46312 .576 L
.46363 .5758 L
.46457 .57531 L
Mistroke
.46557 .57464 L
.46663 .57377 L
.46855 .5719 L
.48504 .54935 L
.49228 .53969 L
.49862 .53246 L
.51137 .52212 L
Mfstroke
.5 .48333 m
.49857 .48783 L
.49734 .49228 L
.49639 .49649 L
.49608 .49818 L
.49582 .49991 L
.49571 .50085 L
.49562 .5017 L
.49556 .50248 L
.49554 .50287 L
.49552 .50328 L
.49551 .50351 L
.4955 .50372 L
.4955 .50391 L
.4955 .50411 L
.49549 .50432 L
.49549 .50455 L
.49549 .50477 L
.4955 .50496 L
.4955 .50515 L
.49551 .50533 L
.49552 .50572 L
.49554 .50605 L
.49557 .5064 L
.49563 .50701 L
.49571 .50763 L
.4959 .50869 L
.49605 .5093 L
.49621 .50985 L
.49657 .5108 L
.49695 .51159 L
.49744 .51238 L
.49803 .51312 L
.49864 .51374 L
.49989 .51467 L
.50069 .51509 L
.50147 .51543 L
.50234 .51572 L
.50284 .51586 L
.50333 .51598 L
.50381 .51607 L
.50433 .51615 L
.50482 .51622 L
.50529 .51626 L
.50556 .51628 L
.50586 .5163 L
.50603 .51631 L
.5062 .51632 L
.50651 .51632 L
.50667 .51633 L
Mistroke
.50684 .51633 L
.50715 .51632 L
.50735 .51632 L
.50753 .51631 L
.5077 .51631 L
.50788 .5163 L
.50852 .51625 L
.50886 .51622 L
.50922 .51618 L
.51052 .51599 L
.51123 .51586 L
.51202 .51568 L
.51349 .51526 L
.5164 .51416 L
.51999 .51228 L
.52346 .50993 L
.5307 .50369 L
.5376 .49713 L
.54086 .49437 L
.54436 .49198 L
.54624 .491 L
.54726 .49057 L
.54837 .49017 L
.54941 .48988 L
.55037 .48966 L
.55084 .48957 L
.55136 .48949 L
.55184 .48943 L
.5523 .48938 L
.55285 .48934 L
.55335 .48932 L
.5539 .48931 L
.55421 .4893 L
.55451 .48931 L
.55499 .48932 L
.55554 .48934 L
.55612 .48938 L
.55667 .48943 L
.55795 .48957 L
.55917 .48974 L
.56204 .49023 L
.56505 .49075 L
.56659 .49098 L
.56804 .49114 L
.56884 .49121 L
.56961 .49125 L
.57043 .49127 L
.5709 .49127 L
.57133 .49126 L
.5722 .49121 L
Mistroke
.57269 .49116 L
.57316 .4911 L
.57411 .49094 L
.57514 .4907 L
.57607 .49042 L
.57692 .49009 L
.57884 .48912 L
.58063 .48784 L
.58233 .48624 L
.58432 .4838 L
.58612 .48091 L
.58805 .47693 L
.59002 .47166 L
.59152 .46645 L
.59302 .45988 L
.59429 .45265 L
.5953 .44514 L
.59628 .43518 L
.59672 .429 L
.59704 .42294 L
.59726 .41737 L
.59742 .41095 L
.59746 .40761 L
.59749 .40394 L
.59746 .3971 L
.59734 .39012 L
.59715 .3836 L
.59683 .37589 L
.59642 .36847 L
.59544 .35499 L
.59398 .34024 L
.5919 .32411 L
.58915 .30768 L
.58635 .29454 L
.58283 .2814 L
.57868 .2695 L
.5745 .26051 L
.57205 .25637 L
.56927 .25257 L
.56656 .24964 L
.56397 .24751 L
.5627 .24668 L
.5613 .24592 L
.55873 .24492 L
.55619 .24439 L
.55382 .24428 L
.55122 .24455 L
.54973 .24487 L
.54833 .24527 L
.54549 .24637 L
Mistroke
.54243 .24796 L
.53674 .25181 L
.53066 .25696 L
.51972 .26791 L
.49511 .29426 L
.4737 .31698 L
.46758 .32488 L
.46183 .33384 L
.45671 .34376 L
.45142 .35681 L
.44644 .37281 L
.44223 .39049 L
.43837 .41164 L
.43516 .43481 L
.43355 .44937 L
.43204 .4658 L
.43091 .4808 L
.42988 .49762 L
.42901 .51643 L
.42842 .53453 L
.42817 .54576 L
.42802 .55649 L
.42794 .57671 L
.42808 .59269 L
.42845 .61014 L
.42905 .62795 L
.42983 .64415 L
.43074 .65863 L
.43172 .67131 L
.43442 .69742 L
.43609 .7096 L
.4378 .71991 L
.43999 .73083 L
.44213 .73947 L
.44435 .74677 L
.44688 .7534 L
.44967 .75899 L
.4524 .76302 L
.45523 .76593 L
.45786 .76768 L
.46097 .76873 L
.46396 .76889 L
.46675 .7684 L
.46936 .76748 L
.47224 .76603 L
.47533 .76408 L
.50171 .74106 L
.51626 .72817 L
.52342 .72102 L
.52999 .71291 L
Mistroke
.53591 .70332 L
.54202 .68987 L
.54791 .67175 L
.55108 .65898 L
.5539 .64526 L
.55647 .63025 L
.55899 .61237 L
.56293 .57529 L
.56472 .55212 L
.56612 .52895 L
.56731 .5022 L
.56781 .48671 L
.56817 .47231 L
.56853 .44775 L
.56858 .42489 L
.56834 .40009 L
.56773 .37437 L
.56728 .36179 L
.5667 .34856 L
.56538 .32581 L
.5638 .30544 L
.56209 .28842 L
.56032 .27428 L
.55823 .26088 L
.55627 .2508 L
.55401 .24139 L
.55121 .23239 L
.54842 .22577 L
.54559 .22099 L
.5429 .21791 L
.54003 .21592 L
.53728 .21508 L
.53423 .21515 L
.53089 .21621 L
.52757 .2181 L
.52405 .22078 L
.51773 .22681 L
.49234 .25528 L
.4857 .26276 L
.47852 .27157 L
.47237 .28056 L
.46571 .29309 L
.45968 .30852 L
.45361 .33016 L
.44845 .35607 L
.44416 .38602 L
.44224 .40327 L
.44059 .42092 L
.43801 .45702 L
.43689 .47859 L
Mistroke
.43607 .49929 L
.43543 .52253 L
.43505 .54758 L
.43499 .57304 L
.4351 .58731 L
.4353 .60044 L
.43561 .61404 L
.43598 .62614 L
.43652 .63986 L
.43712 .6521 L
.43839 .67258 L
.44009 .69289 L
.44182 .70893 L
.44389 .72397 L
.44632 .73766 L
.44916 .74978 L
.45204 .75882 L
.45481 .7652 L
.45646 .76809 L
.45801 .77032 L
.45975 .77227 L
.46163 .77384 L
.46364 .77495 L
.46556 .77555 L
.4673 .77574 L
.4692 .77563 L
.47244 .77478 L
.4755 .77335 L
.47887 .77126 L
.48251 .76856 L
.4968 .75619 L
.50929 .74539 L
.52267 .7328 L
.53005 .72339 L
.53664 .71179 L
.54308 .69582 L
.54884 .67566 L
.55194 .66157 L
.55503 .64449 L
.55995 .6081 L
.5623 .5847 L
.56419 .56107 L
.5659 .53343 L
.56663 .5185 L
.56727 .50234 L
.5677 .48917 L
.56807 .47453 L
.56846 .44863 L
.56853 .43413 L
.56849 .41867 L
Mistroke
.56834 .40429 L
.56811 .39137 L
.56741 .36737 L
.56688 .35438 L
.56629 .34276 L
.565 .32274 L
.56334 .30334 L
.56148 .28669 L
.55921 .27104 L
.55684 .25855 L
.5545 .24897 L
.55227 .24185 L
.54971 .2356 L
.54693 .23071 L
.54425 .22752 L
.5412 .22536 L
.53964 .22476 L
.53789 .22446 L
.53478 .22472 L
.53183 .22577 L
.53014 .22666 L
.52835 .2278 L
.52513 .23026 L
.51787 .23721 L
.49257 .26513 L
.4817 .27711 L
.47018 .29222 L
.46368 .30348 L
.45792 .31629 L
.45234 .33232 L
.44736 .35091 L
.44253 .37442 L
.43848 .40019 L
.43469 .43241 L
.43148 .47083 L
.43026 .49111 L
.42973 .502 L
.42924 .5137 L
.42885 .52499 L
.42857 .53522 L
.42822 .5551 L
.42813 .574 L
.4283 .59389 L
.42871 .61196 L
.4293 .6278 L
.43002 .64186 L
.43098 .65601 L
.43314 .67888 L
.43472 .69107 L
.43637 .70134 L
Mistroke
.43984 .71725 L
.44178 .72376 L
.44394 .72953 L
.44586 .73357 L
.44805 .73715 L
.45047 .74004 L
.45315 .74215 L
.45573 .7433 L
.45813 .7437 L
.46086 .74352 L
.46347 .74282 L
.46583 .74181 L
.46839 .74037 L
.47958 .73148 L
.49985 .71202 L
.52188 .69164 L
.5336 .67941 L
.54605 .66251 L
.55756 .64052 L
.56738 .61427 L
.57621 .58188 L
.5833 .54666 L
.58654 .52644 L
.58947 .50458 L
.59157 .48577 L
.59337 .46594 L
.59424 .45414 L
.59489 .44366 L
.59537 .43419 L
.59557 .42934 L
.59575 .42427 L
.59597 .41577 L
.59607 .40825 L
.59609 .40401 L
.59607 .40013 L
.59597 .39321 L
.59581 .38738 L
.59555 .38153 L
.59524 .37641 L
.59489 .37207 L
.59443 .3674 L
.59384 .3628 L
.59261 .3557 L
.59184 .35249 L
.5911 .34997 L
.59027 .34766 L
.58931 .34558 L
.58839 .34404 L
.58751 .34293 L
.58664 .34212 L
Mistroke
.58571 .34152 L
.58483 .34118 L
.58401 .34104 L
.58305 .34107 L
.58214 .34128 L
.58128 .3416 L
.58049 .34201 L
.57868 .34329 L
.57686 .34499 L
.57485 .34727 L
.57082 .35281 L
.54323 .4017 L
.52445 .43033 L
Mfstroke
.5 .5 m
.5 .50041 L
.50001 .50078 L
.50002 .5012 L
.50004 .50159 L
.50006 .50194 L
.50008 .50227 L
.50015 .503 L
.50023 .50371 L
.50035 .50447 L
.50065 .50595 L
.50104 .50731 L
.50156 .50869 L
.50276 .51094 L
.50359 .51208 L
.50463 .5132 L
.50565 .51409 L
.50686 .51492 L
.50817 .51559 L
.50945 .51606 L
.5101 .51624 L
.51046 .51631 L
.51083 .51637 L
.51117 .51642 L
.51154 .51646 L
.51189 .51648 L
.51221 .51649 L
.5126 .51648 L
.51279 .51648 L
.51301 .51646 L
.51339 .51643 L
.51376 .51638 L
.5142 .5163 L
.5146 .51621 L
.51552 .51594 L
.51629 .51564 L
.51714 .51523 L
.51888 .51409 L
.5205 .51266 L
.52222 .51068 L
.52524 .50587 L
.52693 .50224 L
.52838 .49844 L
.52979 .49394 L
.53112 .48864 L
.53201 .48421 L
.53277 .47947 L
.53309 .47691 L
.53334 .47464 L
.53353 .47238 L
Mistroke
.53365 .47043 L
.5337 .46949 L
.53373 .46851 L
.53376 .46761 L
.53377 .4668 L
.53377 .46598 L
.53376 .4651 L
.53375 .46467 L
.53374 .46423 L
.5337 .46345 L
.53367 .46275 L
.53361 .46203 L
.53349 .46081 L
.53334 .45975 L
.53317 .45888 L
.53295 .45798 L
.53272 .45726 L
.53244 .45661 L
.53229 .45633 L
.53211 .45607 L
.53195 .45586 L
.53177 .45568 L
.53157 .45553 L
.53138 .45543 L
.53129 .45539 L
.53119 .45536 L
.531 .45533 L
.53082 .45532 L
.53065 .45534 L
.53046 .45538 L
.53029 .45545 L
.53012 .45552 L
.52995 .45562 L
.52955 .4559 L
.52918 .45624 L
.5278 .45801 L
.52637 .46061 L
.52501 .46375 L
.52399 .46661 L
.52311 .46964 L
.52249 .47237 L
.52226 .47362 L
.52211 .47472 L
.52197 .47592 L
.52195 .47623 L
.52192 .47656 L
.52191 .47685 L
.52189 .47716 L
.52188 .47744 L
.52188 .4777 L
Mistroke
.52187 .47797 L
.52187 .47826 L
.52188 .47853 L
.52188 .47877 L
.52189 .479 L
.5219 .47923 L
.52192 .47954 L
.52194 .47982 L
.522 .48034 L
.52207 .48088 L
.52217 .48144 L
.5224 .48242 L
.52267 .48326 L
.52299 .48404 L
.52339 .48481 L
.52379 .48542 L
.52427 .48602 L
.52491 .48663 L
.52523 .48687 L
.52558 .48709 L
.52591 .48727 L
.52629 .48743 L
.52646 .48749 L
.52665 .48755 L
.52682 .48759 L
.52699 .48763 L
.52719 .48766 L
.52737 .48768 L
.52756 .48769 L
.52768 .48769 L
.52778 .48769 L
.52795 .48768 L
.52815 .48766 L
.52835 .48763 L
.52855 .48759 L
.52878 .48753 L
.529 .48745 L
.52942 .48728 L
.52988 .48702 L
.53038 .48667 L
.53133 .48575 L
.53186 .48509 L
.53234 .48438 L
.53323 .48268 L
.53403 .48069 L
.53471 .4784 L
.53536 .47546 L
.53563 .4738 L
.53589 .47191 L
.53608 .47001 L
Mistroke
.53614 .46914 L
.53621 .46819 L
.53625 .46731 L
.53629 .46632 L
.53632 .4654 L
.53633 .46453 L
.53634 .46349 L
.53633 .46253 L
.53631 .46141 L
.53627 .46034 L
.53623 .45941 L
.53617 .45842 L
.53603 .45663 L
.53581 .45452 L
.53556 .45263 L
.53483 .44867 L
.53438 .44681 L
.53381 .44489 L
.53327 .44338 L
.53264 .44191 L
.53137 .43967 L
.53053 .43862 L
.53006 .43816 L
.52955 .43773 L
.5291 .43743 L
.52859 .43716 L
.52811 .43697 L
.52765 .43684 L
.5272 .43677 L
.52671 .43675 L
.52629 .43677 L
.52582 .43683 L
.52531 .43695 L
.52503 .43704 L
.52476 .43713 L
.52376 .43761 L
.52282 .4382 L
.52178 .43901 L
.51967 .44111 L
.51592 .44605 L
.50823 .45978 L
.50196 .47331 L
.49759 .48388 L
.49432 .49325 L
.49319 .49732 L
.49243 .50076 L
.49215 .50239 L
.49191 .50408 L
.49181 .50499 L
.49174 .50579 L
Mistroke
.49169 .50655 L
.49167 .50692 L
.49165 .50733 L
.49165 .50753 L
.49164 .50776 L
.49164 .50816 L
.49164 .50855 L
.49164 .5089 L
.49165 .50928 L
.49166 .50949 L
.49167 .50969 L
.49169 .51008 L
.49172 .51049 L
.49179 .51117 L
.49188 .51187 L
.49211 .51304 L
.49226 .51363 L
.49242 .51417 L
.49276 .51511 L
.4932 .51603 L
.49376 .51692 L
.49431 .51762 L
.49496 .51828 L
.49629 .51926 L
.49713 .51971 L
.49796 .52008 L
.49891 .52041 L
.50002 .52071 L
.50112 .52094 L
.50162 .52103 L
.5022 .52111 L
.50271 .52117 L
.50328 .52123 L
.5036 .52126 L
.5039 .52128 L
.50418 .52129 L
.50449 .52131 L
.50484 .52132 L
.50517 .52133 L
.5055 .52133 L
.50581 .52133 L
.50614 .52133 L
.50652 .52131 L
.50671 .52131 L
.50691 .5213 L
.50729 .52128 L
.50803 .52122 L
.50875 .52114 L
.51014 .52093 L
.51096 .52076 L
Mistroke
.51185 .52055 L
.5135 .52004 L
.51553 .51923 L
.51743 .51824 L
.52125 .51555 L
.52483 .51205 L
.5287 .50706 L
.53259 .50066 L
.54325 .47722 L
.54425 .47515 L
.54529 .47328 L
.54618 .47198 L
.54711 .47095 L
.54762 .47053 L
.54789 .47036 L
.54819 .4702 L
.54847 .47009 L
.54872 .47001 L
.54896 .46996 L
.54923 .46993 L
.54947 .46992 L
.54973 .46993 L
.54998 .46995 L
.55021 .47 L
.55048 .47006 L
.55079 .47016 L
.55135 .47039 L
.55252 .47103 L
.55369 .47183 L
.55677 .47418 L
.55853 .47549 L
.56065 .47689 L
.56169 .47748 L
.56284 .47806 L
.56396 .47851 L
.56503 .47885 L
.56563 .47899 L
.56627 .4791 L
.56661 .47914 L
.56692 .47917 L
.56727 .47919 L
.56765 .47919 L
.56798 .47918 L
.56834 .47915 L
.569 .47906 L
.56964 .47891 L
.57025 .47872 L
.57084 .47848 L
.5714 .4782 L
.57269 .47735 L
Mistroke
.57394 .47621 L
.5753 .47459 L
.57653 .47267 L
.57785 .47006 L
.57898 .46727 L
.58014 .46373 L
.58121 .4596 L
.58211 .45529 L
.58287 .45072 L
.5836 .44519 L
.58429 .43797 L
Mfstroke
.5 .51667 m
.50172 .51816 L
.50396 .51961 L
.50524 .52025 L
.50672 .52084 L
.50748 .52109 L
.50822 .52129 L
.50891 .52143 L
.50967 .52156 L
.51009 .52161 L
.51032 .52163 L
.51054 .52165 L
.51098 .52167 L
.51138 .52167 L
.51161 .52167 L
.51186 .52166 L
.51232 .52163 L
.5126 .5216 L
.51287 .52157 L
.51337 .52149 L
.51387 .52138 L
.51441 .52124 L
.51539 .52091 L
.51647 .52041 L
.51766 .5197 L
.51965 .51805 L
.52179 .51555 L
.52377 .51241 L
.52549 .50883 L
.52716 .50442 L
.52875 .49899 L
.52994 .49383 L
.53101 .48773 L
.53147 .48444 L
.53187 .48095 L
.53221 .47714 L
.53232 .47546 L
.53242 .4737 L
.53249 .47204 L
.53254 .47056 L
.53257 .46909 L
.53258 .46774 L
.53258 .4662 L
.53255 .46481 L
.53253 .46411 L
.5325 .46334 L
.53243 .46184 L
.53234 .46051 L
.53225 .45933 L
.53197 .45683 L
Mistroke
.53165 .45486 L
.53126 .453 L
.53082 .45142 L
.53036 .45016 L
.52991 .44921 L
.52939 .44838 L
.52878 .44768 L
.52842 .44739 L
.52808 .44718 L
.52789 .44708 L
.52771 .44701 L
.52736 .44692 L
.52717 .44689 L
.52699 .44688 L
.52678 .44688 L
.52657 .44689 L
.52624 .44695 L
.52588 .44705 L
.52554 .44718 L
.52522 .44733 L
.52448 .44779 L
.52369 .4484 L
.52089 .45148 L
.51799 .45567 L
.51322 .46373 L
.50875 .4715 L
.50457 .47807 L
.50121 .48244 L
.49764 .48606 L
.49416 .48871 L
.4902 .49099 L
.48578 .49308 L
.48126 .49531 L
.47886 .49682 L
.47618 .49904 L
.47494 .50036 L
.47363 .50202 L
.47137 .50584 L
.47024 .50843 L
.46928 .51117 L
.46833 .51461 L
.46749 .51873 L
.46719 .52062 L
.46692 .52272 L
.46671 .52462 L
.46654 .52674 L
.46645 .52806 L
.46639 .52931 L
.46634 .53051 L
.46631 .5318 L
Mistroke
.46629 .53297 L
.46629 .53407 L
.4663 .53528 L
.46633 .53659 L
.46635 .53732 L
.46638 .538 L
.46645 .53929 L
.46653 .54067 L
.46665 .54215 L
.46693 .5448 L
.46725 .54718 L
.46823 .55236 L
.46886 .55475 L
.46965 .55716 L
.47119 .56068 L
.47217 .5623 L
.47313 .56354 L
.47408 .56451 L
.47515 .56533 L
.47566 .56564 L
.47622 .56591 L
.47674 .56612 L
.47724 .56627 L
.47776 .56639 L
.47834 .56648 L
.47892 .56652 L
.47954 .56653 L
.48013 .56649 L
.48069 .56642 L
.4812 .56633 L
.48176 .56621 L
.48306 .56582 L
.48446 .56528 L
.48702 .56404 L
.49723 .55814 L
.5033 .55512 L
.50939 .55246 L
.51215 .55114 L
.51515 .54942 L
.51849 .54688 L
.52161 .5436 L
.52333 .54124 L
.52517 .53818 L
.52675 .53499 L
.52837 .53107 L
.52977 .52699 L
.53123 .52191 L
.53352 .51145 L
.53472 .50405 L
.53566 .49678 L
Mistroke
.5361 .49256 L
.53652 .48785 L
.53682 .4837 L
.53709 .47907 L
.53729 .47475 L
.53742 .4707 L
.5375 .46643 L
.53752 .46404 L
.53753 .46187 L
.53749 .45806 L
.53741 .45397 L
.53727 .4502 L
.5371 .4468 L
.53686 .44308 L
.53654 .43932 L
.53583 .43308 L
.53488 .42716 L
.53426 .4242 L
.53364 .42171 L
.53239 .41788 L
.53115 .41515 L
.53042 .41395 L
.5296 .41288 L
.5288 .4121 L
.52805 .41156 L
.52737 .41122 L
.52662 .411 L
.52591 .41092 L
.52525 .41096 L
.5245 .4111 L
.52369 .41138 L
.52283 .41181 L
.52202 .41231 L
.51881 .41517 L
.5154 .41932 L
.50244 .43916 L
.48993 .45771 L
.48453 .46603 L
.47922 .47604 L
.47521 .48626 L
.47323 .49281 L
.47162 .49937 L
.47025 .50637 L
.46965 .51012 L
.4691 .51412 L
.46868 .51793 L
.46837 .52132 L
.46826 .52293 L
.46815 .52464 L
.46807 .52622 L
Mistroke
.46801 .52766 L
.46797 .52904 L
.46794 .53049 L
.46793 .53206 L
.46794 .53344 L
.46796 .53485 L
.46799 .53562 L
.46801 .53632 L
.46808 .53757 L
.46816 .53885 L
.46835 .54097 L
.46857 .54281 L
.46886 .54465 L
.46923 .54642 L
.46965 .54797 L
.47015 .5494 L
.47067 .55053 L
.47118 .55138 L
.47181 .55218 L
.47218 .55253 L
.47254 .5528 L
.47285 .553 L
.47321 .55317 L
.47339 .55323 L
.47358 .55329 L
.47394 .55337 L
.47414 .55339 L
.47435 .55341 L
.47473 .5534 L
.47495 .55338 L
.47515 .55335 L
.47537 .55331 L
.47562 .55325 L
.47603 .55312 L
.47647 .55294 L
.47727 .55254 L
.47879 .55153 L
.48048 .55012 L
.49328 .53595 L
.50519 .52439 L
.51201 .51953 L
.51899 .5158 L
.53315 .50917 L
Mfstroke
.5 .53333 m
.50041 .53333 L
.5008 .53333 L
.50124 .53333 L
.50167 .53333 L
.50207 .53333 L
.50244 .53333 L
.50285 .53333 L
.50329 .53333 L
.50374 .53332 L
.50423 .53331 L
.5047 .5333 L
.50514 .53329 L
.50565 .53328 L
.50622 .53325 L
.50727 .53319 L
.50785 .53314 L
.50839 .53309 L
.50944 .53296 L
.51058 .53277 L
.51185 .53248 L
.51299 .53214 L
.51421 .53168 L
.51644 .53052 L
.51774 .52963 L
.51893 .52863 L
.52161 .52566 L
.52406 .52186 L
.52627 .51718 L
.52866 .51035 L
.53059 .50274 L
.53232 .49317 L
.53301 .48799 L
.53361 .48212 L
.53394 .47764 L
.53409 .47511 L
.53419 .47278 L
.53427 .47032 L
.53432 .46813 L
.53433 .46692 L
.53433 .46563 L
.53432 .46333 L
.53428 .46141 L
.53421 .45934 L
.53411 .45726 L
.53399 .45538 L
.53371 .45219 L
.53333 .44906 L
.53278 .44581 L
.53206 .44278 L
Mistroke
.53129 .44042 L
.53049 .43866 L
.53006 .43792 L
.52965 .43732 L
.52883 .43645 L
.52835 .43608 L
.52791 .43583 L
.52741 .43564 L
.52716 .43558 L
.52687 .43553 L
.52635 .43551 L
.52587 .43556 L
.52561 .43561 L
.52532 .43569 L
.52474 .4359 L
.52423 .43615 L
.52368 .43648 L
.52267 .43722 L
.52061 .43919 L
.51874 .44141 L
.5104 .4539 L
.50315 .46512 L
.49701 .47319 L
.49128 .47916 L
.48506 .48414 L
.48167 .48631 L
.47784 .48835 L
.47433 .48986 L
.47021 .49122 L
.46587 .49225 L
.46146 .49301 L
.45893 .49339 L
.45604 .49386 L
.45317 .49444 L
.45041 .4952 L
.4477 .49624 L
.44612 .49704 L
.44461 .49795 L
.44155 .50041 L
.43983 .50226 L
.43825 .50431 L
.43568 .50861 L
.433 .51487 L
.43173 .51874 L
.43045 .52348 L
.42842 .53369 L
.42747 .54044 L
.42702 .54444 L
.42665 .54839 L
.42612 .55582 L
Mistroke
.42591 .55999 L
.42582 .56222 L
.42574 .56464 L
.42568 .56728 L
.42564 .56978 L
.42561 .5728 L
.42561 .57558 L
.42563 .57826 L
.42567 .58119 L
.42573 .58399 L
.42581 .58659 L
.426 .59152 L
.42629 .597 L
.42712 .60817 L
.42826 .61896 L
.42959 .62858 L
.43146 .6392 L
.43357 .64857 L
.43563 .65594 L
.43806 .66292 L
.44098 .66947 L
.4439 .67439 L
.44695 .67813 L
.44855 .6796 L
.45033 .68089 L
.4519 .68175 L
.4536 .68242 L
.45523 .68281 L
.45673 .68298 L
.45864 .68295 L
.46043 .6827 L
.46242 .68218 L
.46343 .68184 L
.46454 .68139 L
.46845 .67935 L
.47215 .67688 L
.50108 .65069 L
.5178 .63617 L
.5261 .62776 L
.53012 .62267 L
.53372 .61717 L
.5404 .60347 L
.54388 .59364 L
.547 .58259 L
.55016 .5683 L
.55278 .55302 L
.55529 .53387 L
.55639 .52328 L
.55743 .51117 L
.55831 .49856 L
Mistroke
.55897 .48649 L
.55946 .47464 L
.55982 .46182 L
.56001 .45025 L
.56006 .43937 L
.55999 .42747 L
.55974 .41483 L
.5593 .40177 L
.55897 .39457 L
.55861 .38802 L
.55775 .37552 L
.55681 .36483 L
.55462 .34642 L
.5532 .33756 L
.55175 .33006 L
.54881 .31857 L
.5472 .31387 L
.54536 .30955 L
.54373 .30652 L
.54193 .30392 L
.54018 .30205 L
.53855 .30082 L
.53648 .29987 L
.53453 .29951 L
.53236 .29966 L
.53003 .30036 L
.52799 .30136 L
.52608 .30258 L
.52168 .30621 L
.50401 .32618 L
.48573 .34749 L
.47829 .35726 L
.47053 .37072 L
.46623 .38086 L
.46249 .39215 L
.45896 .40587 L
.45589 .42123 L
.453 .4401 L
.45069 .46016 L
.44868 .48452 L
.44781 .49907 L
.44719 .51278 L
.44674 .52731 L
.44649 .54089 L
.44643 .54872 L
.44642 .55578 L
.44647 .56387 L
.44657 .57141 L
.4469 .58487 L
.44736 .59682 L
Mistroke
.44803 .60937 L
.44893 .62182 L
.4508 .64028 L
.45205 .64939 L
.4533 .65689 L
.45455 .66316 L
.456 .66921 L
.45885 .67816 L
.46055 .68207 L
.46249 .68553 L
.4635 .68695 L
.4646 .68825 L
.46663 .69004 L
.46859 .69112 L
.47069 .69168 L
.4725 .69176 L
.47451 .69146 L
.47563 .69115 L
.47683 .69071 L
.47898 .6897 L
.48389 .68658 L
.49288 .6794 L
.50994 .66567 L
.51886 .65797 L
.52388 .6525 L
.52843 .64617 L
.5337 .63632 L
.53853 .62383 L
.54272 .60903 L
.5469 .58881 L
.55001 .56836 L
.55146 .5564 L
.55284 .54295 L
.55391 .53049 L
.55493 .51624 L
.55569 .50294 L
.55627 .49007 L
.55656 .48204 L
.55682 .47328 L
.55711 .45791 L
.55719 .44923 L
.5572 .44009 L
.55716 .43237 L
.55705 .42397 L
.5567 .40939 L
.55643 .40146 L
.55612 .3944 L
.55538 .38128 L
.55452 .36963 L
.55338 .35758 L
Mistroke
.55219 .34768 L
.55075 .33814 L
.54904 .32917 L
.54733 .32209 L
.54565 .31662 L
.54396 .31229 L
.54211 .30862 L
.54003 .30563 L
.53883 .30437 L
.53773 .30347 L
.53554 .30234 L
.53344 .30195 L
.53224 .30199 L
.53096 .30223 L
.52863 .30309 L
.52734 .30378 L
.52612 .30455 L
.52333 .30669 L
.51493 .31522 L
.50581 .32594 L
.48768 .34674 L
.47965 .35641 L
.47122 .36899 L
.46723 .37659 L
.46356 .38499 L
.45708 .40458 L
.45373 .41813 L
.45085 .43251 L
.44803 .45012 L
.44545 .47092 L
.44436 .48194 L
.44333 .4943 L
.44257 .50542 L
.44191 .5174 L
.44164 .52354 L
.44142 .52931 L
.44112 .54005 L
.44095 .55002 L
.4409 .56059 L
.44098 .57029 L
.44116 .57907 L
.44147 .58836 L
.44193 .59784 L
.44256 .60722 L
.44327 .61551 L
.44403 .62253 L
.44492 .6294 L
.44679 .64037 L
.44877 .64874 L
.45112 .65591 L
Mistroke
.45255 .65918 L
.45394 .66173 L
.45548 .66395 L
.45717 .66577 L
.4588 .66701 L
.46031 .66778 L
.46125 .66808 L
.46213 .66827 L
.4631 .66836 L
.46413 .66835 L
.46588 .66808 L
.46688 .66781 L
.46782 .66748 L
.46964 .66667 L
.47138 .6657 L
.47466 .66346 L
.4821 .65711 L
.5093 .63163 L
.52365 .61885 L
.53897 .6024 L
.55172 .58348 L
.56479 .55652 L
.57658 .52407 L
.58535 .49495 L
.59329 .46765 L
.59648 .4582 L
.59777 .45494 L
.59913 .452 L
.60042 .4497 L
.6016 .44806 L
.60273 .44692 L
.60329 .4465 L
.60392 .44614 L
.60459 .44588 L
.60521 .44574 L
.60555 .44571 L
.60593 .4457 L
.60663 .44577 L
.60728 .44593 L
.608 .44618 L
.60931 .44683 L
.61255 .44907 L
.61632 .45189 L
.61799 .45296 L
.61985 .45391 L
.62041 .45414 L
.62095 .45432 L
.62196 .45459 L
.62294 .45472 L
.62401 .45472 L
Mistroke
.62503 .45456 L
.62562 .45439 L
.62618 .45417 L
.6273 .45357 L
.62793 .45311 L
.62851 .45262 L
.63057 .45022 L
.63159 .44859 L
.6327 .44644 L
.63497 .44052 L
.63618 .43627 L
.63724 .43178 L
.63817 .42699 L
.63912 .42113 L
.63993 .41496 L
.64062 .40858 L
.64123 .4015 L
.64172 .39448 L
.64215 .38605 L
.64235 .38111 L
.64249 .37624 L
.64261 .37136 L
.64269 .36599 L
.64274 .35585 L
.6427 .34934 L
.64262 .34302 L
.6425 .33718 L
.64233 .33072 L
.64192 .31944 L
.64131 .3066 L
.63951 .27942 L
.63711 .25322 L
.63421 .22847 L
.63191 .21202 L
Mfstroke
.51667 .46667 m
.51518 .47006 L
.51379 .47412 L
.51266 .47845 L
.51226 .48035 L
.51192 .48237 L
.51177 .48349 L
.51165 .4845 L
.51156 .48543 L
.51152 .48592 L
.51149 .48643 L
.51146 .48689 L
.51144 .4873 L
.51143 .48771 L
.51142 .48809 L
.51142 .48851 L
.51142 .4889 L
.51143 .48932 L
.51143 .48955 L
.51144 .48976 L
.51146 .49019 L
.51149 .49064 L
.51156 .49143 L
.51166 .49223 L
.5118 .49308 L
.51195 .49377 L
.51213 .49447 L
.51253 .49563 L
.51302 .49668 L
.51355 .4975 L
.51422 .49824 L
.51458 .49854 L
.515 .49882 L
.51539 .49901 L
.51576 .49914 L
.51596 .4992 L
.51618 .49924 L
.51629 .49926 L
.51641 .49928 L
.51652 .49929 L
.51663 .4993 L
.51684 .4993 L
.51704 .4993 L
.51726 .49928 L
.51737 .49927 L
.51749 .49925 L
.5177 .49921 L
.51792 .49916 L
.51834 .49903 L
.51881 .49884 L
Mistroke
.51931 .49858 L
.52024 .49798 L
.52135 .49703 L
.52236 .49596 L
.52433 .49333 L
.52608 .49036 L
.53135 .47828 L
.53232 .4761 L
.53276 .4753 L
.53314 .47473 L
.53354 .47429 L
.53376 .47411 L
.53397 .47399 L
.53409 .47395 L
.53415 .47393 L
.53421 .47391 L
.53431 .47389 L
.53436 .47389 L
.53442 .47388 L
.53449 .47388 L
.53455 .47388 L
.53462 .47389 L
.53469 .4739 L
.53475 .47391 L
.53481 .47392 L
.53494 .47396 L
.53516 .47405 L
.53541 .47418 L
.53595 .47455 L
.53707 .47553 L
.54052 .4789 L
.54277 .48084 L
.54534 .48264 L
.54694 .48353 L
.54785 .48394 L
.54885 .48432 L
.54972 .48458 L
.55019 .48469 L
.55071 .48479 L
.5512 .48486 L
.55165 .4849 L
.55209 .48491 L
.55255 .48491 L
.55304 .48488 L
.55332 .48485 L
.55357 .48481 L
.55405 .48472 L
.55456 .4846 L
.55546 .48428 L
.55646 .48379 L
Mistroke
.55753 .48307 L
.5587 .48203 L
.5598 .48078 L
.56079 .47938 L
.56266 .47588 L
.56367 .47337 L
.56457 .47067 L
.56608 .46469 L
.56682 .46073 L
.56741 .45674 L
.56796 .45209 L
.56843 .44649 L
.56861 .44348 L
.56869 .44176 L
.56876 .44011 L
.56886 .43681 L
.56891 .4337 L
.56892 .43069 L
.5689 .42742 L
.56884 .42457 L
.56875 .42136 L
.5686 .41787 L
.56839 .41404 L
.56787 .407 L
.56709 .39928 L
.56598 .39089 L
.56452 .38238 L
.56289 .37487 L
.55935 .36285 L
.55703 .3572 L
.55474 .35284 L
.55242 .34947 L
.54973 .34662 L
.54832 .34553 L
.54677 .34462 L
.54528 .344 L
.54389 .34363 L
.54249 .34345 L
.54118 .34344 L
.53973 .3436 L
.53816 .34396 L
.53666 .34448 L
.53523 .3451 L
.53254 .34662 L
.52587 .3519 L
.51973 .35814 L
.50599 .37403 L
.48252 .40051 L
.47621 .40877 L
.4728 .41414 L
Mistroke
.46965 .42003 L
.46679 .4264 L
.46381 .43447 L
.45903 .45206 L
.45694 .46253 L
.45494 .47516 L
.45334 .48833 L
.45213 .50133 L
.45154 .50957 L
.45109 .51744 L
.4507 .52625 L
.45054 .53123 L
.45042 .53578 L
.4503 .54417 L
.45027 .54889 L
.45028 .55323 L
.45038 .56116 L
.45059 .56942 L
.45092 .57778 L
.45133 .58519 L
.45192 .59341 L
.4526 .60082 L
.45406 .61292 L
.45602 .62435 L
.45717 .62954 L
.45855 .63463 L
.45998 .63893 L
.46161 .64285 L
.46321 .64585 L
.46473 .64808 L
.46622 .64976 L
.46785 .65108 L
.4694 .65194 L
.47029 .65227 L
.47112 .65248 L
.47266 .65264 L
.47431 .65254 L
.47581 .65223 L
.47722 .65178 L
.47878 .65111 L
.48047 .65024 L
.48785 .64514 L
.49468 .63966 L
.50735 .62994 L
.51443 .62453 L
.52115 .61827 L
.52478 .61387 L
.52867 .60787 L
.53213 .60095 L
.53522 .59308 L
Mistroke
.53801 .5841 L
.54089 .57233 L
.54364 .55779 L
.5459 .54214 L
.54703 .53238 L
.54813 .52114 L
.54896 .51074 L
.54971 .49928 L
.55026 .48868 L
.55071 .47676 L
.55099 .4658 L
.55112 .45551 L
.55113 .44341 L
.55107 .4374 L
.55096 .43092 L
.55064 .4197 L
.5502 .40966 L
.54952 .39836 L
.54875 .38875 L
.54769 .37854 L
.54654 .36985 L
.54548 .36335 L
.54424 .35713 L
.54177 .34789 L
.54014 .34348 L
.53852 .34012 L
.53701 .33776 L
.53532 .33585 L
.53364 .33461 L
.53266 .33415 L
.53173 .33387 L
.53075 .33373 L
.52985 .33373 L
.52885 .33387 L
.52779 .33415 L
.526 .33492 L
.52434 .33592 L
.52052 .33904 L
.51364 .34656 L
.50744 .35429 L
.49376 .37123 L
.48073 .38783 L
.47435 .39844 L
.46767 .41404 L
.46442 .42438 L
.46119 .43748 L
.45845 .45179 L
.45625 .46649 L
.45444 .48219 L
.45364 .49092 L
Mistroke
.4529 .50049 L
.45231 .50986 L
.45189 .51846 L
.45156 .52715 L
.45136 .53532 L
.45125 .54362 L
.45124 .55239 L
.45133 .56048 L
.45151 .56767 L
.45181 .57581 L
.45204 .58025 L
.45228 .58425 L
.45282 .59174 L
.45343 .59834 L
.45489 .61008 L
.4558 .61558 L
.45686 .62091 L
.45801 .62559 L
.4593 .62986 L
.46058 .63328 L
.4618 .63591 L
.4629 .63786 L
.46414 .63961 L
.46548 .64108 L
.46677 .64213 L
.46801 .64283 L
.46935 .64331 L
.47051 .64352 L
.47179 .64356 L
.47332 .64336 L
.47474 .64298 L
.47552 .64269 L
.47638 .64233 L
.47795 .64153 L
.48386 .63749 L
.50938 .61605 L
.51642 .61024 L
.52391 .6031 L
.53028 .59535 L
.5371 .58414 L
.54368 .56897 L
.54926 .55101 L
.55444 .52768 L
.55685 .51321 L
.5587 .49947 L
.56004 .48717 L
.56115 .47412 L
.5616 .4674 L
.56199 .4601 L
.56213 .45695 L
Mistroke
.56226 .4536 L
.56243 .44767 L
.56252 .4419 L
.56254 .43871 L
.56254 .43582 L
.56249 .43066 L
.56236 .4254 L
.56216 .42049 L
.56192 .41609 L
.56165 .41235 L
.5613 .40852 L
.56045 .40145 L
.55989 .39792 L
.55933 .39497 L
.55813 .38999 L
.55685 .38613 L
.55608 .38432 L
.55523 .38267 L
.55446 .38145 L
.55361 .38035 L
.55267 .37941 L
.55177 .37874 L
.55124 .37843 L
.55067 .37818 L
.55018 .37801 L
.54964 .37788 L
.54912 .37781 L
.54855 .37778 L
.54801 .37781 L
.54751 .37787 L
.54655 .37808 L
.54552 .37843 L
.54441 .37895 L
.54337 .37955 L
.54096 .38129 L
.53266 .38979 L
.50247 .42584 L
.48648 .44063 L
.4707 .45208 L
.44355 .47637 L
Mfstroke
.51667 .48333 m
.51667 .48354 L
.51667 .48372 L
.51668 .48393 L
.51669 .48413 L
.5167 .4843 L
.51671 .48446 L
.51674 .48482 L
.51678 .48516 L
.51684 .48553 L
.51691 .48589 L
.51699 .4862 L
.51717 .48677 L
.51729 .48705 L
.51741 .48728 L
.51765 .48763 L
.5178 .48779 L
.51794 .4879 L
.51811 .488 L
.51821 .48804 L
.51825 .48806 L
.5183 .48807 L
.51838 .48809 L
.51847 .4881 L
.51856 .48811 L
.51861 .48811 L
.51866 .4881 L
.51875 .48809 L
.51883 .48807 L
.51892 .48805 L
.51902 .48801 L
.51918 .48793 L
.51937 .48781 L
.51978 .48746 L
.52022 .48694 L
.52099 .48566 L
.52162 .48421 L
.52219 .48245 L
.52265 .48062 L
.52293 .47906 L
.52302 .47838 L
.52305 .47806 L
.52308 .47774 L
.5231 .47749 L
.52311 .47736 L
.52311 .47723 L
.52312 .47712 L
.52312 .47702 L
.52312 .47693 L
.52312 .47685 L
Mistroke
.52312 .47677 L
.52312 .4767 L
.52311 .47662 L
.52311 .47656 L
.52311 .47651 L
.5231 .47646 L
.52309 .47637 L
.52308 .47633 L
.52308 .47629 L
.52307 .47626 L
.52306 .47623 L
.52305 .47621 L
.52304 .4762 L
.52303 .47619 L
.52303 .47618 L
.52302 .47618 L
.52301 .47618 L
.523 .47619 L
.52299 .47619 L
.52298 .47621 L
.52297 .47623 L
.52296 .47625 L
.52294 .47631 L
.52292 .47639 L
.5229 .47648 L
.52289 .47658 L
.52288 .47669 L
.52288 .47676 L
.52287 .47683 L
.52287 .47691 L
.52287 .47696 L
.52287 .477 L
.52286 .47704 L
.52286 .47709 L
.52286 .47714 L
.52286 .47719 L
.52287 .47728 L
.52287 .47734 L
.52287 .47739 L
.52287 .47748 L
.52288 .47758 L
.52289 .47776 L
.52291 .47797 L
.52294 .47821 L
.52302 .4787 L
.52312 .47919 L
.52341 .48016 L
.52387 .48126 L
.52456 .48248 L
.52535 .48357 L
Mistroke
.52645 .48478 L
.5279 .48608 L
.52952 .48728 L
.5313 .48839 L
.53357 .48956 L
.53498 .49014 L
.53639 .49061 L
.53784 .49098 L
.53827 .49106 L
.53868 .49113 L
.53906 .49118 L
.53948 .49123 L
.53989 .49126 L
.54026 .49128 L
.54065 .49129 L
.54102 .49128 L
.54145 .49126 L
.54186 .49123 L
.54231 .49118 L
.5428 .4911 L
.54323 .491 L
.54371 .49088 L
.54458 .49059 L
.54563 .49011 L
.5466 .48952 L
.54824 .4882 L
.55004 .48614 L
.55188 .48316 L
.55351 .47949 L
.55518 .47423 L
.55602 .47067 L
.55671 .46698 L
.55725 .46343 L
.55775 .45917 L
.55796 .45689 L
.55816 .45434 L
.55831 .45186 L
.55843 .44949 L
.55851 .44712 L
.55857 .44453 L
.55858 .44301 L
.55859 .44157 L
.55857 .43884 L
.55852 .43617 L
.55845 .43368 L
.55833 .43091 L
.55817 .42796 L
.55779 .42278 L
.55731 .41795 L
.55666 .41268 L
Mistroke
.55581 .40716 L
.55471 .40146 L
.55336 .39578 L
.55043 .38685 L
.54855 .38276 L
.54664 .37956 L
.54439 .3768 L
.54307 .37561 L
.54183 .37474 L
.54073 .37417 L
.53954 .37373 L
.5384 .37347 L
.53734 .37337 L
.53669 .37336 L
.53608 .3734 L
.53542 .37349 L
.53471 .37362 L
.5335 .37396 L
.53217 .37448 L
.52975 .37577 L
.52713 .3776 L
.52237 .38189 L
.5028 .40532 L
.49284 .41723 L
.48247 .42989 L
.47816 .43624 L
.47367 .44457 L
.47121 .45029 L
.46906 .4563 L
.46699 .46325 L
.46521 .47053 L
.46247 .48527 L
.46127 .49403 L
.46021 .50405 L
.45976 .50932 L
.45935 .51517 L
.45904 .52079 L
.45882 .52605 L
.45867 .53082 L
.45857 .53608 L
.45854 .54157 L
.45857 .54668 L
.45868 .5521 L
.45877 .55509 L
.45887 .55776 L
.45912 .56289 L
.45942 .56757 L
.46031 .57751 L
.46094 .58268 L
.46159 .58714 L
Mistroke
.46286 .59399 L
.46447 .6004 L
.46636 .60583 L
.46727 .60784 L
.46829 .60974 L
.46934 .61133 L
.47033 .61255 L
.47128 .6135 L
.47236 .61434 L
.47334 .6149 L
.47427 .61529 L
.47527 .61556 L
.47637 .61569 L
.4775 .61568 L
.47875 .61551 L
.47939 .61537 L
.48008 .61517 L
.48132 .61473 L
.48376 .61358 L
.486 .61228 L
.50645 .59827 L
.5123 .59441 L
.51553 .59201 L
.51858 .58937 L
.52396 .58321 L
.52677 .57882 L
.52973 .57299 L
.53243 .5662 L
.53517 .55744 L
.53734 .5486 L
.53954 .53735 L
.54159 .52363 L
.54252 .51579 L
.54339 .50711 L
.54405 .49919 L
.54464 .49026 L
.54508 .48197 L
.54538 .47415 L
.54559 .4662 L
.54566 .46172 L
.54569 .4576 L
.54569 .4501 L
.54558 .44231 L
.54539 .43553 L
.54514 .42937 L
.54479 .42286 L
.54431 .41619 L
.54371 .40955 L
.54294 .40284 L
.54217 .39743 L
Mistroke
.54126 .39221 L
.54028 .38759 L
.53932 .3839 L
.53829 .38064 L
.53729 .37802 L
.53618 .37568 L
.53514 .37391 L
.53395 .37235 L
.53263 .37111 L
.53133 .37031 L
.53059 .37003 L
.5299 .36986 L
.52861 .36978 L
.52722 .37 L
.52604 .3704 L
.52476 .37104 L
.52243 .37264 L
.51965 .37517 L
.51709 .37792 L
.49482 .40643 L
.48543 .41807 L
.47574 .4327 L
.47049 .4438 L
.4661 .45636 L
.46222 .47158 L
.46056 .47991 L
.45918 .48816 L
.45698 .50545 L
.45612 .51492 L
.45545 .52512 L
.45522 .53018 L
.45512 .53282 L
.45504 .53561 L
.45498 .53827 L
.45494 .54065 L
.45491 .54522 L
.45494 .54951 L
.45503 .55401 L
.45518 .5581 L
.45536 .56172 L
.45557 .56498 L
.45584 .56832 L
.45643 .57393 L
.45731 .57987 L
.45825 .58456 L
.45936 .58872 L
.46071 .59242 L
.4621 .59515 L
.46347 .59705 L
.46427 .59788 L
Mistroke
.46505 .59851 L
.46576 .59896 L
.46656 .59932 L
.46744 .59958 L
.46793 .59966 L
.46839 .5997 L
.46928 .59969 L
.47013 .59958 L
.47094 .59939 L
.4718 .5991 L
.47336 .59841 L
.47506 .59742 L
.47694 .5961 L
.49292 .58107 L
.52511 .55391 L
.54091 .54189 L
.54958 .53589 L
.55916 .53041 L
.56416 .52818 L
.56988 .52615 L
.58057 .52339 L
.58613 .52202 L
.58914 .52112 L
.59236 .51992 L
.59524 .51857 L
.59844 .51664 L
.60136 .51435 L
.6041 .51165 L
.60907 .50482 L
.61182 .49962 L
.61429 .49378 L
.61857 .47993 L
.62056 .47118 L
.62256 .46002 L
.62417 .44845 L
.62545 .43659 L
.62606 .4295 L
.62665 .42132 L
.62714 .41308 L
.6275 .40525 L
.62778 .39701 L
.62798 .38894 L
.6281 .38012 L
.62814 .37024 L
.62808 .3613 L
.62793 .3516 L
.62772 .34313 L
.6274 .33366 L
Mfstroke
.51667 .5 m
.51687 .49999 L
.51706 .49997 L
.51729 .49993 L
.5175 .49988 L
.51788 .49974 L
.5183 .49953 L
.51877 .49922 L
.51926 .4988 L
.52016 .49781 L
.52107 .49645 L
.52189 .49487 L
.52274 .4928 L
.52357 .49021 L
.52429 .48731 L
.52462 .48568 L
.52493 .48389 L
.52517 .48214 L
.52536 .48054 L
.5255 .47893 L
.52555 .47822 L
.5256 .47744 L
.52563 .47669 L
.52566 .47601 L
.52568 .47529 L
.52568 .4749 L
.52568 .47454 L
.52568 .47391 L
.52567 .47324 L
.52566 .47262 L
.52563 .47206 L
.5256 .47144 L
.52556 .47087 L
.5255 .47021 L
.52544 .46964 L
.52529 .46854 L
.52509 .46747 L
.52488 .46663 L
.52467 .46596 L
.5244 .46529 L
.52412 .46476 L
.52385 .46437 L
.52358 .46408 L
.52344 .46397 L
.52328 .46386 L
.52311 .46377 L
.52294 .46371 L
.52276 .46367 L
.52266 .46366 L
.52256 .46365 L
Mistroke
.52238 .46366 L
.52219 .4637 L
.522 .46376 L
.52181 .46383 L
.52147 .46402 L
.52106 .46432 L
.52068 .46467 L
.51983 .46568 L
.51838 .46799 L
.51714 .47054 L
.51587 .47371 L
.51487 .47669 L
.51411 .47943 L
.51379 .48079 L
.51351 .48216 L
.51332 .48325 L
.51316 .48438 L
.51311 .48485 L
.51306 .48535 L
.51303 .4858 L
.51301 .4862 L
.513 .48644 L
.513 .48667 L
.51299 .48686 L
.51299 .48708 L
.513 .4873 L
.513 .48741 L
.513 .48754 L
.51301 .48775 L
.51302 .48795 L
.51305 .48832 L
.51308 .48865 L
.51313 .48901 L
.51319 .48935 L
.51335 .49005 L
.51354 .49064 L
.51379 .49124 L
.51411 .49182 L
.51477 .49268 L
.51521 .49311 L
.51565 .49346 L
.51657 .49406 L
.5177 .49461 L
.51902 .49512 L
.52064 .49561 L
.52239 .49603 L
.52418 .49636 L
.52525 .49651 L
.52582 .49657 L
.52615 .4966 L
Mistroke
.52646 .49662 L
.52673 .49664 L
.52702 .49665 L
.52734 .49667 L
.52764 .49667 L
.52793 .49668 L
.52824 .49668 L
.52853 .49667 L
.5288 .49666 L
.52915 .49664 L
.52953 .49661 L
.52985 .49658 L
.53021 .49654 L
.53103 .49641 L
.53181 .49623 L
.53257 .49601 L
.53327 .49577 L
.53489 .49499 L
.53641 .49396 L
.53805 .49243 L
.53944 .4907 L
.54094 .48825 L
.54247 .48489 L
.54323 .48278 L
.54399 .48029 L
.5446 .47786 L
.54522 .47494 L
.54571 .47203 L
.54612 .46915 L
.54648 .46576 L
.54664 .46392 L
.54678 .46184 L
.54689 .45998 L
.54696 .4582 L
.54702 .45629 L
.54704 .45519 L
.54705 .45419 L
.54705 .45228 L
.54703 .45049 L
.54699 .4485 L
.54691 .44637 L
.54681 .44432 L
.54669 .44239 L
.5464 .43878 L
.54594 .43456 L
.54532 .43021 L
.54385 .42292 L
.54285 .41925 L
.5418 .41615 L
.54052 .41314 L
Mistroke
.53903 .41043 L
.53761 .40852 L
.5368 .40766 L
.53602 .40698 L
.53529 .40646 L
.5346 .40607 L
.53382 .40574 L
.53338 .4056 L
.53297 .40549 L
.53251 .40541 L
.5321 .40537 L
.53162 .40534 L
.53116 .40535 L
.53034 .40544 L
.52987 .40554 L
.52944 .40564 L
.52852 .40595 L
.52751 .4064 L
.52543 .40764 L
.52188 .41063 L
.51806 .41477 L
.5113 .42364 L
.49836 .44205 L
.49195 .45081 L
.48544 .46021 L
.48003 .47011 L
.47722 .47704 L
.47483 .48468 L
.47294 .49271 L
.4715 .50091 L
.47088 .50549 L
.47031 .51067 L
.47007 .51335 L
.46986 .51623 L
.46969 .51894 L
.46956 .52148 L
.46946 .52412 L
.46942 .52552 L
.46939 .52702 L
.46937 .52858 L
.46936 .53006 L
.46937 .53281 L
.46941 .53534 L
.46948 .53765 L
.46959 .54014 L
.46975 .54273 L
.46996 .54547 L
.47024 .54831 L
.47087 .55313 L
.47164 .55735 L
Mistroke
.47246 .56078 L
.47335 .56365 L
.47427 .56594 L
.47536 .56804 L
.47661 .56982 L
.47727 .57053 L
.47801 .57118 L
.47872 .57168 L
.4794 .57205 L
.48002 .5723 L
.48071 .57251 L
.48145 .57264 L
.48215 .57269 L
.48284 .57268 L
.48358 .57261 L
.48428 .5725 L
.48493 .57235 L
.48654 .57185 L
.48808 .57124 L
.49471 .56784 L
.50747 .56153 L
.51117 .5597 L
.51471 .55762 L
.51846 .55472 L
.52059 .55262 L
.5226 .55021 L
.52612 .54474 L
.52921 .53816 L
.53232 .52913 L
.53381 .52357 L
.5353 .51694 L
.53661 .50989 L
.53767 .50297 L
.5386 .49557 L
.53931 .48844 L
.53992 .48044 L
.54016 .47618 L
.54037 .47164 L
.54045 .46936 L
.54051 .4669 L
.54056 .46459 L
.54059 .46248 L
.5406 .45854 L
.54056 .45445 L
.54047 .4505 L
.54033 .447 L
.54012 .44312 L
.53986 .43959 L
.53929 .43379 L
.53889 .43078 L
Mistroke
.53849 .42817 L
.53741 .42287 L
.53629 .41892 L
.53561 .41709 L
.53484 .41538 L
.53407 .41402 L
.53334 .413 L
.53269 .41226 L
.53197 .41163 L
.53118 .41113 L
.53043 .41082 L
.52971 .41065 L
.52893 .41061 L
.52826 .41067 L
.52752 .41083 L
.52709 .41097 L
.52664 .41115 L
.52583 .41154 L
.52398 .41276 L
.52061 .41589 L
.50695 .43359 L
.48414 .45981 L
.46051 .48529 L
.44994 .4965 L
.44705 .49897 L
.44394 .50117 L
.44124 .50269 L
.43819 .50393 L
.43649 .50443 L
.43489 .50477 L
.434 .50491 L
.43301 .50503 L
.43256 .50507 L
.43207 .50511 L
.43164 .50514 L
.43118 .50516 L
.43071 .50518 L
.43027 .50519 L
.4298 .50519 L
.42929 .50519 L
.42883 .50519 L
.42834 .50518 L
.42745 .50515 L
.42651 .5051 L
.42561 .50505 L
.42389 .50494 L
.42204 .50481 L
.42101 .50476 L
.42003 .50471 L
.41918 .50469 L
Mistroke
.41826 .50468 L
.41723 .50469 L
.41627 .50473 L
.41573 .50477 L
.41516 .50482 L
.41411 .50495 L
.41347 .50506 L
.41285 .50518 L
.4117 .50546 L
.41058 .50581 L
.40954 .50621 L
.40717 .50743 L
.4052 .50885 L
.40339 .51053 L
.4013 .51302 L
.39935 .516 L
.39595 .5231 L
.39412 .52831 L
.39251 .53402 L
.39098 .5407 L
.38947 .54904 L
.38802 .55966 L
.38689 .57109 L
.38642 .57743 L
.38598 .5848 L
.38563 .59296 L
.38541 .60098 L
.38529 .60887 L
.38526 .61633 L
.38534 .62526 L
.38552 .63398 L
Mfstroke
.51667 .51667 m
.51746 .51622 L
.51831 .51562 L
.51986 .51418 L
.52168 .51179 L
.5233 .5089 L
.5249 .5051 L
.52648 .50009 L
.52777 .49455 L
.52875 .48889 L
.52916 .48577 L
.52953 .48234 L
.52979 .47906 L
.52989 .47761 L
.52997 .47606 L
.53001 .47512 L
.53004 .47426 L
.53009 .4726 L
.53011 .47168 L
.53012 .4707 L
.53012 .46977 L
.53012 .46893 L
.5301 .46743 L
.53007 .46659 L
.53005 .46581 L
.52998 .46428 L
.52989 .4627 L
.52976 .46111 L
.52962 .4597 L
.52923 .45675 L
.52879 .45446 L
.52825 .45236 L
.52771 .45078 L
.52715 .44956 L
.52649 .44851 L
.52609 .44804 L
.52572 .4477 L
.52536 .44744 L
.52502 .44725 L
.5247 .44713 L
.52435 .44705 L
.52396 .44703 L
.52376 .44703 L
.52354 .44706 L
.52316 .44714 L
.52279 .44726 L
.52242 .44743 L
.52206 .44762 L
.52139 .44808 L
.51987 .44949 L
Mistroke
.51823 .4515 L
.51673 .45369 L
.5135 .45926 L
.50436 .47804 L
.50103 .48468 L
.49805 .48976 L
.49678 .49154 L
.49548 .49308 L
.49427 .49424 L
.49315 .4951 L
.49196 .49583 L
.49062 .49644 L
.48929 .4969 L
.48796 .49724 L
.48639 .49753 L
.48457 .49779 L
.48085 .49822 L
.47869 .49853 L
.4774 .49876 L
.47617 .49903 L
.47377 .49977 L
.4725 .5003 L
.47109 .50105 L
.46952 .50211 L
.46803 .50342 L
.46668 .5049 L
.46524 .5069 L
.46372 .50965 L
.46221 .51328 L
.46104 .51704 L
.46048 .51929 L
.45993 .52194 L
.45945 .52478 L
.45906 .5276 L
.45876 .53046 L
.45863 .53198 L
.45851 .53366 L
.45842 .5352 L
.45835 .53663 L
.45831 .53803 L
.45827 .53953 L
.45825 .54119 L
.45826 .54276 L
.45828 .5445 L
.45833 .54638 L
.45837 .54735 L
.45842 .54839 L
.45852 .55026 L
.45886 .55447 L
.45927 .55808 L
Mistroke
.45985 .56195 L
.46046 .56527 L
.46124 .56866 L
.46294 .57417 L
.46398 .5767 L
.46518 .57907 L
.46631 .58083 L
.4676 .58242 L
.46843 .58323 L
.46921 .58386 L
.46997 .58437 L
.47081 .58481 L
.47159 .58512 L
.47233 .58533 L
.47313 .58548 L
.47358 .58553 L
.47399 .58555 L
.47477 .58554 L
.47517 .58551 L
.47562 .58546 L
.47641 .58533 L
.47716 .58515 L
.47887 .58457 L
.48074 .58372 L
.48749 .5794 L
.50169 .5693 L
.50961 .56463 L
.51412 .56184 L
.51845 .55851 L
.52262 .55408 L
.52496 .55079 L
.52707 .54711 L
.53067 .53874 L
.53237 .5335 L
.53412 .52688 L
.5369 .51258 L
.53818 .50332 L
.53914 .4942 L
.53983 .48528 L
.54014 .48009 L
.54036 .47523 L
.54052 .47051 L
.54062 .46623 L
.54068 .4613 L
.54067 .4567 L
.54061 .45197 L
.54048 .44699 L
.54029 .44241 L
.54007 .43835 L
.53976 .43375 L
Mistroke
.53934 .42899 L
.53839 .42103 L
.53783 .41743 L
.53716 .41378 L
.53645 .41054 L
.53562 .40742 L
.5348 .40486 L
.534 .4028 L
.53322 .4011 L
.53235 .39957 L
.53145 .39831 L
.53062 .39739 L
.52976 .39668 L
.52893 .39619 L
.52795 .39583 L
.52703 .39569 L
.52601 .39574 L
.52492 .396 L
.52403 .39636 L
.52306 .39687 L
.52131 .39812 L
.51732 .40212 L
.50011 .42661 L
.49276 .43701 L
.4853 .44791 L
.4789 .45967 L
.47556 .46796 L
.47272 .4771 L
.47046 .48665 L
.46872 .49631 L
.46725 .50768 L
.4667 .51356 L
.46644 .51693 L
.46625 .52004 L
.46609 .52307 L
.46596 .52639 L
.46591 .5281 L
.46588 .52969 L
.46585 .53135 L
.46584 .53312 L
.46584 .53466 L
.46585 .53631 L
.46589 .53926 L
.46598 .54205 L
.46609 .54457 L
.46625 .54717 L
.46642 .54952 L
.46684 .55368 L
.46739 .55777 L
.46811 .56171 L
Mistroke
.46897 .56518 L
.47002 .56836 L
.4706 .56973 L
.47125 .57101 L
.47184 .57198 L
.4725 .57289 L
.47318 .57365 L
.47382 .57423 L
.47446 .57468 L
.47514 .57505 L
.47576 .5753 L
.47636 .57545 L
.47702 .57555 L
.47774 .57557 L
.47845 .57552 L
.47911 .5754 L
.47987 .57521 L
.48059 .57497 L
.48189 .57441 L
.48332 .57365 L
.4897 .56913 L
.50306 .55884 L
.51615 .5497 L
.52338 .54381 L
.53121 .53559 L
.53856 .52547 L
.54488 .5146 L
.55564 .49235 L
.56005 .48325 L
.56434 .47602 L
.5665 .47342 L
.56772 .47231 L
.56888 .4715 L
.56939 .47122 L
.56994 .47097 L
.57042 .47079 L
.57094 .47064 L
.5715 .47052 L
.57203 .47045 L
.57235 .47042 L
.57267 .47041 L
.57325 .47042 L
.57378 .47047 L
.57436 .47055 L
.57491 .47066 L
.57543 .47079 L
.57798 .47168 L
.58065 .47288 L
.58379 .47434 L
.58526 .47496 L
Mistroke
.58689 .47553 L
.58771 .47577 L
.58848 .47596 L
.58919 .4761 L
.58997 .47621 L
.59073 .47628 L
.59157 .47629 L
.59246 .47623 L
.5933 .4761 L
.5941 .47591 L
.59483 .47567 L
.59568 .4753 L
.59649 .47486 L
.59812 .47367 L
.59966 .47213 L
.60134 .46989 L
.60313 .46673 L
.60485 .46273 L
.6066 .45746 L
.608 .452 L
.60941 .44492 L
.6106 .43709 L
.61153 .42895 L
.61198 .42402 L
.61241 .41832 L
.61274 .4126 L
.61299 .40704 L
.61317 .40166 L
.61329 .39641 L
.61336 .39043 L
.61337 .38375 L
.61329 .3765 L
.61313 .36937 L
.61292 .36279 L
.61262 .35543 L
Mfstroke
.51667 .53333 m
.51912 .53136 L
.52141 .52877 L
.52389 .52491 L
.52642 .5194 L
.52885 .51191 L
.53084 .50325 L
.53229 .49433 L
.53294 .48893 L
.53343 .48379 L
.5338 .47842 L
.53396 .47539 L
.53406 .47263 L
.53413 .47009 L
.53417 .46733 L
.53417 .46477 L
.53414 .46244 L
.53411 .46103 L
.53407 .45954 L
.53396 .45689 L
.53382 .45439 L
.53366 .45218 L
.53319 .44748 L
.53289 .4453 L
.53253 .44306 L
.53174 .43929 L
.5309 .43642 L
.5304 .43507 L
.52982 .43379 L
.5293 .43284 L
.5287 .43196 L
.52813 .43131 L
.52757 .43082 L
.52698 .43043 L
.52664 .43027 L
.52632 .43015 L
.52578 .43003 L
.52518 .43 L
.52488 .43002 L
.52455 .43007 L
.52396 .43023 L
.52336 .43047 L
.5227 .43081 L
.52136 .43176 L
.51893 .43416 L
.51356 .44156 L
.50468 .45624 L
.48981 .47769 L
.47707 .49287 L
.47096 .50012 L
Mistroke
.46781 .50356 L
.46447 .50668 L
.46277 .50797 L
.46114 .50899 L
.45964 .50974 L
.45886 .51005 L
.45798 .51035 L
.45719 .51056 L
.45634 .51074 L
.45585 .51082 L
.45541 .51088 L
.45496 .51092 L
.45452 .51095 L
.45412 .51097 L
.45369 .51099 L
.45331 .51099 L
.4529 .51098 L
.45244 .51096 L
.45195 .51093 L
.45148 .51089 L
.45104 .51085 L
.44908 .51058 L
.44686 .51016 L
.44249 .50927 L
.44111 .50903 L
.44037 .50891 L
.43956 .50881 L
.43885 .50873 L
.43847 .5087 L
.43805 .50867 L
.43732 .50864 L
.43662 .50863 L
.43589 .50864 L
.43547 .50867 L
.43508 .5087 L
.43436 .50878 L
.43358 .5089 L
.43288 .50905 L
.43222 .50922 L
.43069 .50977 L
.42916 .51053 L
.42772 .51149 L
.42614 .51287 L
.42444 .51477 L
.42268 .51733 L
.42104 .52036 L
.41959 .5237 L
.41811 .52792 L
.4169 .53221 L
.41566 .53765 L
Mistroke
.41462 .54336 L
.41378 .54922 L
.41293 .5569 L
.41254 .5615 L
.41223 .56612 L
.41199 .57057 L
.41182 .57487 L
.41168 .57978 L
.41161 .5852 L
.4116 .59079 L
.41163 .59404 L
.41168 .59713 L
.41176 .60043 L
.41185 .60349 L
.41213 .61048 L
.41246 .61655 L
.41291 .62326 L
.41399 .63559 L
.41569 .65 L
.41801 .66489 L
.42042 .67693 L
.42351 .68913 L
.42679 .69919 L
.4301 .70712 L
.43405 .71423 L
.43614 .71716 L
.43851 .71984 L
.44063 .72174 L
.44268 .72317 L
.44383 .7238 L
.44509 .72438 L
.44732 .72508 L
.44949 .72543 L
.45182 .72545 L
.45383 .7252 L
.45606 .72467 L
.45853 .7238 L
.46084 .72273 L
.46612 .71954 L
.47583 .71167 L
.49416 .69403 L
.51553 .67445 L
.52608 .6642 L
.53069 .65883 L
.53572 .65184 L
.54026 .64401 L
.54501 .63366 L
.54983 .61996 L
.55405 .60413 L
.55856 .58128 L
Mistroke
.56225 .55517 L
.56495 .5281 L
.56619 .51146 L
.56712 .49534 L
.56775 .48133 L
.56825 .46588 L
.56856 .45105 L
.5687 .43736 L
.56867 .42135 L
.56842 .40401 L
.56797 .38794 L
.56737 .37342 L
.56648 .35769 L
.56545 .34362 L
.56303 .31963 L
.56141 .3077 L
.55978 .29776 L
.55772 .28755 L
.55562 .27919 L
.55352 .2725 L
.55113 .26648 L
.54886 .2621 L
.54669 .25893 L
.54429 .25641 L
.54158 .25463 L
.5402 .2541 L
.53869 .25378 L
.53593 .25381 L
.53349 .25442 L
.53079 .25563 L
.52796 .2574 L
.52532 .25944 L
.51548 .26914 L
.49162 .29596 L
.48002 .30936 L
.47497 .3162 L
.46948 .32516 L
.46425 .33607 L
.45951 .34891 L
.45476 .36593 L
.45008 .38885 L
.44786 .40288 L
.44564 .41983 L
.44389 .43615 L
.44225 .45488 L
.44089 .47465 L
.43989 .49344 L
.43914 .51297 L
.43865 .53175 L
.43841 .54902 L
Mistroke
.43837 .56794 L
.43858 .58744 L
.43901 .60518 L
.43961 .62123 L
.44031 .63525 L
.44131 .65058 L
.44243 .66414 L
.44383 .6777 L
.44551 .69068 L
.44896 .71019 L
.45109 .71891 L
.45322 .72574 L
.45566 .73181 L
.45706 .73456 L
.45841 .73678 L
.46103 .74005 L
.46347 .74203 L
.46616 .74324 L
.46769 .74354 L
.46911 .7436 L
.47152 .74329 L
.47418 .74243 L
.47698 .74106 L
.47961 .73942 L
.50397 .71916 L
.51626 .70868 L
.52234 .70259 L
.52796 .69554 L
.53432 .68472 L
.53761 .6774 L
.54103 .66808 L
.5463 .64913 L
.54912 .6359 L
.55162 .62173 L
.55368 .6078 L
.55571 .59142 L
.55886 .55825 L
.56041 .53594 L
.56158 .51371 L
.56239 .49304 L
.56298 .47013 L
.56327 .44758 L
.5633 .4348 L
.56324 .42294 L
.5631 .41061 L
.56288 .39952 L
.56254 .387 L
.56213 .37544 L
.56119 .35598 L
.56009 .33915 L
Mistroke
.55864 .32222 L
.55684 .30609 L
.55494 .2929 L
.55303 .28241 L
.55076 .2727 L
.54821 .26442 L
.54588 .25879 L
.54362 .25476 L
.54107 .25159 L
.53826 .24952 L
.53572 .24868 L
.53292 .2487 L
.53024 .24948 L
.52774 .25076 L
.52549 .25228 L
.523 .25429 L
.51795 .25918 L
.49602 .2841 L
.48419 .29753 L
.47331 .31222 L
.4677 .32224 L
.46188 .33583 L
.45575 .35551 L
.45063 .37844 L
.44647 .40387 L
.44452 .419 L
.44266 .43624 L
.44123 .45226 L
.43987 .47075 L
.4389 .48712 L
.43808 .50497 L
.43743 .52459 L
.43707 .54287 L
.43696 .55402 L
.43693 .56442 L
.43708 .58351 L
.43746 .60123 L
.43802 .61681 L
.43886 .63299 L
.43997 .64886 L
.44108 .66112 L
.44244 .67311 L
.44528 .69162 L
.44724 .70095 L
.44922 .70841 L
.4511 .71403 L
.45324 .71903 L
.45562 .72321 L
.45794 .72609 L
.45929 .72733 L
Mistroke
.46054 .72821 L
.462 .72897 L
.46341 .72943 L
.46477 .72966 L
.46624 .7297 L
.4689 .72927 L
.47055 .72873 L
.4721 .72805 L
.47503 .72643 L
.48529 .71838 L
.49647 .70816 L
.50718 .69863 L
.51873 .6883 L
.52435 .68264 L
.52966 .67642 L
.53948 .66111 L
.54467 .65 L
.5493 .6375 L
.55412 .62105 L
.55886 .60023 L
.5631 .57597 L
.56652 .55039 L
.56954 .51986 L
.57087 .50192 L
.57185 .4852 L
.57252 .47029 L
.57298 .45628 L
.57324 .44384 L
.57337 .43059 L
.57333 .41655 L
.57323 .40965 L
.57308 .40223 L
.57267 .38959 L
.57213 .37837 L
.57145 .36777 L
.57067 .35834 L
.56891 .34244 L
.56776 .33462 L
.56661 .32804 L
.56367 .31553 L
.56197 .31022 L
.56004 .30545 L
.55812 .30181 L
.5563 .29916 L
.5546 .2973 L
.55269 .2958 L
.55066 .2948 L
.54873 .29433 L
.54763 .29425 L
.54643 .2943 L
Mistroke
.54422 .29473 L
.54205 .29553 L
.54003 .29655 L
.53542 .2997 L
.53048 .30399 L
.46532 .36999 L
.42921 .40916 L
.41373 .42692 L
.40561 .43537 L
.39693 .44314 L
.38827 .44924 L
.38024 .45334 L
.37629 .45487 L
.37194 .45625 L
.36384 .45831 L
.35895 .4595 L
.35428 .46083 L
.34933 .4627 L
.34667 .464 L
.3438 .46572 L
.34135 .4675 L
.33867 .46984 L
.33381 .47541 L
.32911 .4829 L
.32485 .49213 L
.32049 .50488 L
.3167 .51978 L
.31287 .54022 L
.31112 .5523 L
.30935 .56702 L
.30682 .59561 L
.30567 .61376 L
.30483 .63163 L
.30423 .64946 L
.3038 .67007 L
.30363 .69071 L
.30367 .71072 L
.30391 .73062 L
.30439 .75284 L
.30507 .77452 L
.30589 .79488 L
.30874 .84622 L
.31258 .89617 L
.31774 .94731 L
.32363 .99324 L
Mfstroke
.32363 .99324 m
.32472 1 L
s
.53333 .46667 m
.53332 .46421 L
.53328 .46202 L
.5332 .45953 L
.5331 .45724 L
.53297 .45517 L
.53284 .45331 L
.53246 .44933 L
.53198 .44565 L
.53133 .44202 L
.53054 .43874 L
.52971 .43618 L
.52926 .43509 L
.52875 .43403 L
.52828 .43322 L
.52777 .43248 L
.52724 .43187 L
.52675 .43142 L
.52625 .43106 L
.52577 .43081 L
.52519 .43062 L
.52458 .43054 L
.52404 .43055 L
.52345 .43066 L
.52311 .43076 L
.5228 .43087 L
.52211 .43121 L
.52084 .43207 L
.51954 .43323 L
.51817 .43474 L
.51572 .43798 L
.51043 .44663 L
.50196 .46217 L
.48963 .48313 L
.47972 .50098 L
.47369 .51555 L
.47261 .51815 L
.47172 .5199 L
.4713 .52054 L
.47085 .52104 L
.4706 .52125 L
.47047 .52133 L
.47036 .52139 L
.47025 .52144 L
.47014 .52148 L
.47002 .52151 L
.46996 .52152 L
.46989 .52153 L
.46978 .52154 L
.46972 .52154 L
Mistroke
.46966 .52154 L
.46954 .52153 L
.46943 .52151 L
.46937 .5215 L
.4693 .52148 L
.46918 .52145 L
.4689 .52134 L
.4684 .52107 L
.4678 .52066 L
.4651 .51841 L
.46101 .51531 L
.45955 .51444 L
.45803 .51368 L
.45656 .51311 L
.45568 .51286 L
.45527 .51276 L
.45484 .51267 L
.45444 .5126 L
.454 .51255 L
.4536 .51251 L
.45321 .51249 L
.45275 .51249 L
.45233 .51251 L
.45209 .51253 L
.45184 .51255 L
.45136 .51262 L
.45095 .5127 L
.45049 .51282 L
.44955 .51315 L
.44866 .51357 L
.44783 .51408 L
.44676 .51492 L
.44574 .51592 L
.44384 .51847 L
.4428 .52032 L
.44186 .52234 L
.4408 .52515 L
.43988 .52816 L
.43843 .53444 L
.43778 .53832 L
.43719 .54283 L
.43677 .54714 L
.43646 .55145 L
.43632 .55405 L
.43623 .5565 L
.43615 .55941 L
.43611 .56224 L
.43611 .56515 L
.43615 .56843 L
.43619 .57011 L
Mistroke
.43624 .57194 L
.43637 .57529 L
.43655 .57867 L
.43677 .58191 L
.43729 .58807 L
.43811 .59532 L
.43908 .60197 L
.44047 .60957 L
.44199 .61618 L
.44549 .62728 L
.44763 .63216 L
.4501 .63647 L
.4524 .63948 L
.45467 .64164 L
.45601 .6426 L
.45727 .6433 L
.45797 .64361 L
.45875 .64389 L
.46017 .64426 L
.46144 .64443 L
.46265 .64446 L
.46399 .64435 L
.46545 .64409 L
.46691 .64368 L
.46847 .6431 L
.47127 .64172 L
.47638 .63833 L
.48204 .63369 L
.50817 .61075 L
.5143 .60583 L
.52085 .60002 L
.52644 .59374 L
.53249 .58428 L
.5354 .57816 L
.53841 .57025 L
.54089 .56214 L
.54343 .55183 L
.54607 .53793 L
.54824 .52274 L
.54913 .51494 L
.54997 .50622 L
.5512 .48963 L
.55169 .48034 L
.55204 .47163 L
.5523 .46194 L
.55238 .45703 L
.55243 .45165 L
.55242 .44259 L
.55229 .43298 L
.55204 .42408 L
Mistroke
.55172 .41616 L
.55127 .40818 L
.55078 .40107 L
.55015 .39376 L
.54935 .38615 L
.54776 .37455 L
.54577 .36403 L
.54451 .3589 L
.54326 .35472 L
.54169 .35046 L
.5402 .34727 L
.53872 .34479 L
.53729 .34296 L
.53573 .34151 L
.53483 .3409 L
.534 .34048 L
.53252 .34001 L
.53113 .33988 L
.52958 .34004 L
.5279 .34055 L
.52612 .3414 L
.52443 .34248 L
.52125 .34509 L
.5073 .36127 L
.4925 .37962 L
.48005 .39602 L
.47673 .40155 L
.47323 .4085 L
.46723 .42463 L
.46444 .435 L
.46164 .44825 L
.45909 .46426 L
.45711 .48102 L
.45631 .48968 L
.45566 .49814 L
.45516 .50602 L
.45473 .51453 L
.45437 .52391 L
.45415 .53262 L
.45403 .54197 L
.45402 .54725 L
.45405 .55215 L
.45419 .56098 L
.45432 .56582 L
.45447 .57012 L
.45484 .57829 L
.45529 .58566 L
.45594 .59384 L
.45665 .60088 L
.45759 .60848 L
Mistroke
.45859 .61492 L
.4605 .62431 L
.46161 .62852 L
.46288 .63246 L
.46428 .63597 L
.46567 .63873 L
.46696 .64076 L
.4684 .64251 L
.46975 .64373 L
.47105 .64456 L
.47249 .64515 L
.47408 .64546 L
.47567 .64546 L
.47648 .64536 L
.47737 .64517 L
.47896 .64468 L
.48044 .64405 L
.48341 .64241 L
.48613 .6406 L
.49228 .63594 L
.505 .62625 L
.51208 .62103 L
.51878 .61537 L
.52603 .60688 L
.52982 .6007 L
.53378 .59227 L
.53724 .58265 L
.54034 .57161 L
.54291 .56001 L
.54544 .54557 L
.54751 .53043 L
.54935 .51261 L
.55006 .504 L
.55069 .4947 L
.55119 .48586 L
.55155 .47773 L
.55187 .46799 L
.55199 .46265 L
.55207 .45762 L
.55213 .44876 L
.55208 .43932 L
.55201 .43446 L
.55189 .42922 L
.55172 .42386 L
.55152 .41895 L
.55107 .41052 L
.55046 .40197 L
.5497 .39375 L
.54888 .38672 L
.54776 .37917 L
Mistroke
.54664 .37311 L
.5443 .36383 L
.54289 .35981 L
.54149 .35668 L
.54016 .35437 L
.53871 .35245 L
.53744 .35122 L
.53601 .35026 L
.53444 .34967 L
.53355 .34951 L
.53273 .34948 L
.53112 .34968 L
.52958 .35016 L
.52814 .35084 L
.52657 .35179 L
.52372 .35399 L
.51721 .36058 L
.50418 .3761 L
.48132 .40178 L
.46972 .41732 L
.46342 .42871 L
.45789 .44163 L
.45254 .45791 L
.44829 .47481 L
.44425 .49607 L
.44267 .50677 L
.44143 .51678 L
.44047 .52611 L
.43979 .53441 L
.43923 .54328 L
.43901 .54798 L
.43887 .55229 L
.43878 .55629 L
.43874 .56039 L
.43875 .56409 L
.4388 .56729 L
.43885 .56919 L
.43891 .57089 L
.43909 .57454 L
.43929 .57755 L
.43955 .58052 L
.44007 .58494 L
.44075 .58903 L
.4415 .59229 L
.44225 .59478 L
.44321 .59713 L
.4438 .5982 L
.44435 .59904 L
.44489 .59971 L
.44542 .60022 L
Mistroke
.44597 .60064 L
.4466 .60098 L
.44723 .6012 L
.44758 .60128 L
.4479 .60131 L
.44854 .60131 L
.44915 .60122 L
.4495 .60114 L
.44987 .60102 L
.45054 .60075 L
.45127 .60036 L
.45207 .59985 L
.45486 .59741 L
.45747 .59445 L
.46718 .58029 L
.48445 .55364 L
.49997 .53536 L
Mfstroke
.53333 .48333 m
.53352 .48065 L
.53367 .47818 L
.5338 .47553 L
.5339 .47264 L
.53397 .46997 L
.534 .46753 L
.534 .46522 L
.53398 .4628 L
.53392 .46024 L
.53383 .45755 L
.5337 .45508 L
.53356 .45288 L
.53337 .4504 L
.53311 .44782 L
.53254 .44346 L
.53182 .43946 L
.53106 .43633 L
.53006 .43334 L
.52957 .4322 L
.52903 .43114 L
.52854 .43035 L
.528 .42962 L
.52748 .42906 L
.52699 .42865 L
.52641 .42827 L
.52609 .42811 L
.52577 .428 L
.52521 .42787 L
.52459 .42784 L
.52396 .42791 L
.52361 .42799 L
.52328 .42809 L
.52267 .42835 L
.52202 .4287 L
.52064 .42971 L
.51912 .43117 L
.51333 .43905 L
.50393 .45532 L
.48882 .47986 L
.483 .48929 L
.47762 .49991 L
.47333 .51093 L
.47063 .51933 L
.46966 .52233 L
.46892 .52425 L
.46858 .52489 L
.4684 .52516 L
.46823 .52536 L
.46814 .52544 L
Mistroke
.46805 .52551 L
.468 .52554 L
.46795 .52557 L
.4679 .52559 L
.46785 .52561 L
.4678 .52562 L
.46776 .52563 L
.46771 .52563 L
.46766 .52564 L
.46761 .52564 L
.46756 .52563 L
.46747 .52562 L
.46738 .52559 L
.46728 .52555 L
.46707 .52543 L
.46687 .52527 L
.46667 .5251 L
.46558 .52388 L
.46274 .52052 L
.46082 .51862 L
.45959 .51761 L
.45834 .51672 L
.45708 .51597 L
.45585 .51538 L
.45516 .51512 L
.45438 .51489 L
.45395 .51479 L
.45354 .51471 L
.45315 .51466 L
.45272 .51462 L
.4523 .5146 L
.45206 .51459 L
.45184 .5146 L
.45143 .51463 L
.45098 .51468 L
.45058 .51475 L
.4502 .51484 L
.44932 .51513 L
.44886 .51533 L
.44837 .51558 L
.44748 .51615 L
.44651 .51694 L
.44546 .51805 L
.44371 .52055 L
.44276 .52235 L
.44192 .52428 L
.44037 .52886 L
.43908 .53431 L
.43844 .53785 L
.43792 .54151 L
Mistroke
.43744 .54589 L
.43722 .54853 L
.43705 .55105 L
.4369 .55376 L
.4368 .55638 L
.43675 .55793 L
.43672 .55935 L
.4367 .56102 L
.43669 .56262 L
.4367 .56559 L
.43674 .56839 L
.43683 .57153 L
.43689 .57313 L
.43698 .5749 L
.43736 .58111 L
.43786 .58686 L
.43861 .59353 L
.43951 .59978 L
.44156 .61046 L
.44296 .61608 L
.44442 .62092 L
.4479 .62964 L
.45011 .63359 L
.45228 .63656 L
.45429 .63865 L
.45658 .64034 L
.45778 .64097 L
.45908 .64148 L
.46032 .6418 L
.46147 .64197 L
.46288 .64202 L
.46359 .64198 L
.46439 .6419 L
.4658 .64163 L
.46714 .64125 L
.46873 .64066 L
.47019 .63998 L
.47352 .63807 L
.48538 .62847 L
.51035 .60687 L
.51676 .60164 L
.52282 .59586 L
.52825 .58911 L
.53101 .58474 L
.53397 .57902 L
.53935 .56479 L
.54207 .55482 L
.5444 .54399 L
.54634 .53265 L
.54796 .52075 L
Mistroke
.54952 .50572 L
.55064 .491 L
.55109 .48303 L
.55148 .47407 L
.55177 .46456 L
.55192 .45557 L
.55196 .44718 L
.55191 .43954 L
.55174 .43082 L
.55148 .42269 L
.55109 .41419 L
.55055 .40547 L
.54926 .39085 L
.54828 .38272 L
.54723 .3757 L
.54619 .36993 L
.54498 .36436 L
.54375 .35965 L
.54255 .35589 L
.54005 .34995 L
.53858 .34742 L
.53778 .34631 L
.53691 .3453 L
.5353 .34385 L
.53377 .34297 L
.53218 .34249 L
.53044 .34241 L
.52878 .34271 L
.52724 .34327 L
.52552 .34418 L
.52363 .34548 L
.51981 .34887 L
.49482 .37933 L
.48846 .38711 L
.48167 .3962 L
.47541 .40672 L
.46992 .41948 L
.46705 .42833 L
.4641 .43979 L
.46133 .45381 L
.45907 .46885 L
.45735 .48419 L
.4561 .49926 L
.45556 .50791 L
.4551 .51752 L
.45478 .5267 L
.4546 .53525 L
.45452 .54432 L
.45453 .54884 L
.45458 .55376 L
Mistroke
.45474 .56233 L
.455 .57009 L
.45521 .57469 L
.45544 .57893 L
.45595 .5866 L
.45662 .59438 L
.45748 .60224 L
.45924 .61397 L
.46025 .6191 L
.46147 .62412 L
.46257 .62786 L
.46381 .63137 L
.46504 .63417 L
.46622 .63637 L
.46752 .6383 L
.46873 .63971 L
.47011 .64092 L
.47162 .64183 L
.47309 .64235 L
.47394 .64251 L
.47472 .64258 L
.47618 .64252 L
.47774 .64221 L
.47907 .64179 L
.48052 .64118 L
.48315 .63977 L
.48921 .63555 L
.50267 .62523 L
.50992 .61996 L
.51774 .61367 L
.52458 .60621 L
.52844 .60046 L
.53199 .59366 L
.53791 .5777 L
.54097 .56608 L
.54355 .55365 L
.54592 .5391 L
.54779 .52447 L
.54868 .51588 L
.54954 .50622 L
.55017 .49765 L
.55076 .48803 L
.55119 .47904 L
.55149 .47059 L
.55171 .46168 L
.55183 .45218 L
.55182 .44352 L
.55172 .43548 L
.55155 .42845 L
.55128 .42102 L
Mistroke
.55106 .41657 L
.5508 .41189 L
.55022 .4038 L
.54954 .39645 L
.54883 .39018 L
.5469 .37774 L
.54578 .37247 L
.54445 .36746 L
.54323 .36379 L
.54203 .36084 L
.54057 .35804 L
.5392 .35604 L
.53786 .35459 L
.5366 .3536 L
.53519 .35289 L
.53366 .35253 L
.53229 .35251 L
.53077 .35278 L
.52918 .35336 L
.52768 .35413 L
.52498 .35601 L
.52208 .35855 L
.50948 .37283 L
.48725 .39819 L
.47501 .4125 L
.46871 .42167 L
.46229 .43347 L
.457 .44593 L
.4517 .46199 L
.44748 .47847 L
.44417 .49499 L
.44138 .51301 L
.44024 .52241 L
.43927 .53212 L
.43857 .54105 L
.43815 .54869 L
.438 .5522 L
.4379 .55586 L
.43784 .55918 L
.43782 .5621 L
.43784 .56483 L
.43789 .56761 L
.43796 .57012 L
.43806 .57229 L
.4382 .5747 L
.43839 .57716 L
.43882 .58118 L
.43907 .58298 L
.43938 .58479 L
.44008 .58797 L
Mistroke
.44081 .59035 L
.44156 .59211 L
.44201 .5929 L
.4425 .59361 L
.44299 .59416 L
.44343 .59454 L
.44369 .59472 L
.44397 .59488 L
.44428 .59502 L
.44457 .59511 L
.4451 .5952 L
.4454 .59521 L
.44568 .59519 L
.44623 .59508 L
.44676 .5949 L
.44724 .59468 L
.44776 .59438 L
.44894 .59348 L
.45003 .59243 L
.45399 .58722 L
.45799 .58042 L
.47051 .55468 L
.47907 .53738 L
.47938 .53682 L
Mfstroke
.53333 .5 m
.53406 .49435 L
.53471 .48803 L
.53518 .48186 L
.53535 .4791 L
.53549 .47616 L
.53562 .47267 L
.53571 .46945 L
.53575 .46601 L
.53576 .46407 L
.53575 .46227 L
.53571 .45906 L
.53563 .45619 L
.5355 .45295 L
.53533 .44997 L
.53512 .44699 L
.53489 .4444 L
.53425 .43901 L
.53353 .43457 L
.53274 .43093 L
.53168 .42735 L
.53061 .42472 L
.53002 .42359 L
.52934 .42254 L
.5286 .42166 L
.5279 .42103 L
.52754 .42078 L
.52716 .42056 L
.52646 .42028 L
.52607 .42019 L
.5257 .42014 L
.52529 .42012 L
.52484 .42016 L
.52408 .42032 L
.52369 .42044 L
.52327 .42062 L
.5218 .42147 L
.52035 .42265 L
.5188 .42422 L
.51601 .42764 L
.50387 .44675 L
.49414 .46178 L
.48464 .47572 L
.48058 .48262 L
.47666 .49071 L
.47349 .49904 L
.47111 .50698 L
.46924 .51502 L
.46852 .5189 L
.46792 .52285 L
Mistroke
.46752 .52614 L
.46738 .5276 L
.46728 .52885 L
.4672 .53005 L
.46718 .53058 L
.46715 .53111 L
.46714 .53166 L
.46713 .53214 L
.46712 .53263 L
.46712 .53315 L
.46713 .53366 L
.46714 .53411 L
.46715 .53433 L
.46716 .53456 L
.46719 .53502 L
.46722 .53538 L
.46726 .53575 L
.4673 .53604 L
.46734 .53633 L
.46744 .53681 L
.4675 .53702 L
.46756 .53721 L
.46762 .53737 L
.46768 .5375 L
.46774 .5376 L
.4678 .5377 L
.46788 .53779 L
.46792 .53782 L
.46796 .53785 L
.46804 .53789 L
.46812 .53791 L
.46816 .53791 L
.46821 .53791 L
.46826 .5379 L
.46831 .53788 L
.46839 .53783 L
.46848 .53776 L
.46864 .53759 L
.4688 .53737 L
.46913 .53669 L
.46941 .53591 L
.46967 .53491 L
.46979 .53435 L
.46991 .53373 L
.46999 .53316 L
.47007 .53253 L
.47013 .53189 L
.47016 .5316 L
.47018 .53128 L
.47019 .531 L
Mistroke
.4702 .53069 L
.47021 .53036 L
.47022 .53006 L
.47022 .52976 L
.47022 .52943 L
.47021 .52913 L
.4702 .52884 L
.47019 .52856 L
.47018 .5283 L
.47014 .52772 L
.47007 .52711 L
.46999 .52643 L
.46975 .52509 L
.46946 .52389 L
.46911 .5228 L
.46862 .52158 L
.46809 .52053 L
.46737 .51944 L
.4666 .51853 L
.46585 .51786 L
.46538 .51754 L
.46494 .51729 L
.46446 .51708 L
.46419 .51699 L
.46391 .51692 L
.46366 .51687 L
.46343 .51683 L
.46317 .51681 L
.46302 .51681 L
.46288 .51681 L
.46264 .51683 L
.46237 .51687 L
.46215 .51691 L
.46189 .51698 L
.46162 .51707 L
.46132 .51719 L
.46078 .51748 L
.46023 .51787 L
.45971 .51834 L
.45873 .51948 L
.45759 .52136 L
.4566 .5236 L
.45609 .52509 L
.45557 .52691 L
.45515 .52866 L
.45473 .53078 L
.4544 .53278 L
.45411 .5351 L
.45396 .53646 L
.45385 .53774 L
Mistroke
.45375 .53908 L
.45367 .54036 L
.45361 .54158 L
.45356 .5429 L
.45353 .54425 L
.45351 .54578 L
.45351 .54713 L
.45352 .5486 L
.45355 .55001 L
.4536 .55132 L
.45368 .55304 L
.45377 .55469 L
.45401 .5578 L
.45436 .56118 L
.45485 .56484 L
.45603 .57127 L
.45744 .57682 L
.45935 .58222 L
.4606 .58488 L
.46186 .58707 L
.46327 .58899 L
.46468 .59049 L
.46549 .59117 L
.46639 .5918 L
.46724 .59228 L
.46803 .59262 L
.46876 .59287 L
.46954 .59305 L
.47033 .59317 L
.47122 .59321 L
.47199 .59319 L
.47283 .5931 L
.47363 .59295 L
.47436 .59277 L
.47618 .59215 L
.47819 .59121 L
.4819 .58895 L
.49793 .57652 L
.51368 .56608 L
.51818 .56262 L
.52068 .56026 L
.52305 .55756 L
.52523 .55457 L
.52757 .55064 L
.53152 .54168 L
.53352 .53556 L
.53528 .52889 L
.53817 .51402 L
.53951 .50436 L
.54052 .49476 L
Mistroke
.54136 .48359 L
.54167 .47778 L
.54181 .4747 L
.54193 .47133 L
.54207 .46571 L
.54213 .46038 L
.54213 .45523 L
.54207 .45052 L
.54195 .44551 L
.54174 .44011 L
.54144 .43465 L
.54109 .42972 L
.54028 .42133 L
.53934 .4144 L
.53812 .40772 L
.53664 .40183 L
.53582 .39928 L
.53488 .39688 L
.53401 .39506 L
.53307 .39344 L
.53218 .39223 L
.53118 .39117 L
.53025 .39045 L
.52937 .38998 L
.52824 .38963 L
.52715 .38955 L
.52616 .38966 L
.52508 .38998 L
.52451 .39021 L
.52388 .39052 L
.52261 .3913 L
.52031 .39318 L
.51617 .39767 L
.51176 .40349 L
.50399 .41469 L
.48793 .43724 L
.48377 .44364 L
.47949 .45148 L
.47569 .46039 L
.47254 .47016 L
.46972 .48202 L
.4676 .49451 L
.4667 .50151 L
.4659 .50949 L
.46558 .51357 L
.46529 .51799 L
.46508 .52217 L
.46493 .52597 L
.46484 .52953 L
.46479 .53327 L
Mistroke
.46479 .53675 L
.46482 .53984 L
.46491 .54342 L
.46498 .54539 L
.46506 .54717 L
.46524 .55036 L
.46547 .55361 L
.46601 .5591 L
.46664 .56376 L
.46746 .56834 L
.46848 .57257 L
.46965 .57614 L
.47103 .57918 L
.47229 .58117 L
.47305 .58207 L
.47378 .58277 L
.47459 .58338 L
.47504 .58365 L
.47547 .58386 L
.47623 .58414 L
.47664 .58425 L
.47709 .58433 L
.47757 .58439 L
.47809 .58441 L
.47859 .58439 L
.47906 .58435 L
.47948 .58429 L
.47995 .58419 L
.4809 .58393 L
.48182 .5836 L
.4827 .58322 L
.48437 .58235 L
.48818 .5799 L
.49522 .57468 L
.51043 .56418 L
.51737 .55916 L
.52499 .55187 L
.52923 .54637 L
.53304 .54017 L
.53999 .52451 L
.54313 .51486 L
.54615 .50331 L
.54876 .49067 L
.55064 .47889 L
.55195 .46801 L
.55246 .46225 L
.55265 .45963 L
.5528 .45726 L
.55291 .45509 L
.553 .45318 L
Mistroke
.55306 .45114 L
.55311 .44903 L
.55312 .44711 L
.55312 .44607 L
.55311 .44512 L
.55308 .44346 L
.55302 .44179 L
.55294 .44026 L
.55285 .43894 L
.55273 .43758 L
.55258 .43626 L
.55229 .43428 L
.55191 .43245 L
.55153 .43111 L
.5513 .43049 L
.55108 .42997 L
.55086 .42955 L
.55062 .42916 L
.55041 .42888 L
.55018 .42863 L
.5499 .4284 L
.54965 .42825 L
.54937 .42815 L
.54906 .4281 L
.54878 .4281 L
.54848 .42816 L
.5482 .42827 L
.54794 .4284 L
.5473 .42886 L
.54661 .42955 L
.54536 .43126 L
.54408 .43352 L
.5428 .43627 L
.54076 .44167 L
.53919 .44683 L
.53792 .45212 L
.53746 .45453 L
.53711 .45669 L
.53687 .45851 L
.53669 .46037 L
.53663 .46131 L
.5366 .46182 L
.53658 .46228 L
.53657 .46267 L
.53657 .46309 L
.53656 .46351 L
.53657 .4639 L
.53658 .46426 L
.53659 .4646 L
.5366 .46489 L
Mistroke
.53662 .4652 L
.53667 .46585 L
.53674 .46641 L
.53683 .46696 L
.53692 .46742 L
.53704 .46788 L
.53719 .46829 L
.53735 .46863 L
.53744 .46879 L
.53753 .46891 L
.53761 .469 L
.53769 .46907 L
.53778 .46913 L
.53783 .46915 L
.53788 .46917 L
Mfstroke
.53333 .51667 m
.53445 .51051 L
.53551 .5034 L
.5363 .49685 L
.537 .48942 L
.53736 .48475 L
.53762 .48038 L
.53783 .47617 L
.53799 .4717 L
.53808 .4677 L
.53813 .46399 L
.53813 .45995 L
.53807 .45568 L
.53796 .45137 L
.53779 .44748 L
.53755 .44336 L
.53723 .43917 L
.53687 .43538 L
.53647 .43202 L
.53559 .42632 L
.53457 .42147 L
.5335 .41774 L
.53222 .41444 L
.53153 .4131 L
.53075 .41185 L
.52992 .41083 L
.52947 .41039 L
.52899 .40999 L
.52856 .4097 L
.52809 .40945 L
.52724 .40915 L
.5264 .40903 L
.52592 .40904 L
.52548 .40908 L
.52466 .40928 L
.5238 .40961 L
.52285 .41012 L
.52183 .41082 L
.51999 .4124 L
.51583 .41719 L
.50219 .43739 L
.49011 .45438 L
.48413 .46287 L
.47817 .47308 L
.4734 .48409 L
.47103 .49124 L
.46908 .49841 L
.46759 .50514 L
.46643 .51162 L
.4654 .51899 L
Mistroke
.46506 .52214 L
.46477 .52545 L
.46464 .52721 L
.46455 .5288 L
.46448 .53025 L
.46441 .53181 L
.46438 .53317 L
.46436 .5344 L
.46435 .53566 L
.46436 .53697 L
.46439 .53835 L
.46441 .5391 L
.46444 .53977 L
.4645 .54097 L
.46459 .54218 L
.46478 .54413 L
.46491 .54515 L
.46505 .54605 L
.46533 .54756 L
.46568 .54894 L
.466 .54997 L
.46639 .55093 L
.46684 .55179 L
.4671 .55218 L
.46736 .55251 L
.4676 .55277 L
.46787 .55301 L
.46812 .55318 L
.46836 .55332 L
.46864 .55344 L
.46891 .55352 L
.4692 .55356 L
.46936 .55358 L
.46951 .55358 L
.46977 .55356 L
.47006 .55351 L
.47036 .55343 L
.47065 .55333 L
.47131 .55301 L
.47193 .55262 L
.47333 .55143 L
.47598 .54838 L
.47869 .54453 L
.48688 .5309 L
.49349 .52025 L
.49609 .51679 L
.49882 .51401 L
.50033 .51289 L
.50101 .51248 L
.50178 .51209 L
Mistroke
.50325 .51153 L
.5041 .5113 L
.50492 .51113 L
.50578 .51101 L
.50628 .51095 L
.50676 .51091 L
.50767 .51085 L
.5082 .51083 L
.50869 .51081 L
.50966 .51078 L
.51062 .51075 L
.51112 .51073 L
.51166 .5107 L
.51228 .51065 L
.51286 .5106 L
.51347 .51053 L
.51416 .51042 L
.51477 .5103 L
.51544 .51014 L
.51675 .50973 L
.518 .50917 L
.51948 .50827 L
.52088 .50711 L
.52243 .50541 L
.52406 .50296 L
.52544 .50022 L
.52664 .49712 L
.52783 .49309 L
.52891 .48809 L
.52936 .48531 L
.52978 .48214 L
.53009 .47903 L
.53021 .47751 L
.5303 .47608 L
.53037 .47467 L
.53042 .47339 L
.53046 .47195 L
.53048 .47116 L
.53049 .47041 L
.53049 .46892 L
.53047 .46755 L
.53043 .46606 L
.5304 .46524 L
.53037 .4645 L
.53021 .46194 L
.53009 .46053 L
.52996 .45925 L
.52964 .45679 L
.52922 .45435 L
.52876 .45229 L
Mistroke
.52826 .45055 L
.52778 .44918 L
.5272 .44788 L
.52651 .44671 L
.52614 .44622 L
.52573 .44577 L
.52534 .44542 L
.52497 .44516 L
.5246 .44496 L
.52423 .44482 L
.52381 .44472 L
.52357 .44469 L
.52334 .44469 L
.52291 .44472 L
.5225 .44481 L
.52226 .44489 L
.52201 .44498 L
.52155 .4452 L
.52052 .44588 L
.51962 .44667 L
.51877 .44758 L
.51718 .44963 L
.51375 .45538 L
.50842 .46729 L
.50446 .47843 L
.50282 .484 L
.50165 .48869 L
.50085 .49277 L
.50054 .49486 L
.50043 .4958 L
.50035 .49665 L
.50028 .49747 L
.50025 .49788 L
.50023 .49832 L
.50022 .49856 L
.50021 .49879 L
.50021 .499 L
.5002 .49923 L
.5002 .49961 L
.5002 .50002 L
.5002 .50024 L
.5002 .50044 L
.50021 .50083 L
.50022 .50103 L
.50023 .50123 L
.50026 .50166 L
.50032 .50235 L
.50041 .50307 L
.50051 .50374 L
.50065 .50441 L
Mistroke
.50095 .50554 L
.50135 .50666 L
.50189 .50776 L
.50244 .50862 L
.50311 .50944 L
.50376 .51007 L
.50453 .51067 L
.50541 .51121 L
.5063 .51162 L
.50733 .51196 L
.50795 .51212 L
.50855 .51223 L
.5091 .5123 L
.50938 .51233 L
.50954 .51234 L
.50969 .51235 L
.50996 .51237 L
.51025 .51238 L
.51053 .51238 L
.51079 .51237 L
.5111 .51236 L
.51126 .51236 L
.51143 .51234 L
.51174 .51232 L
.51204 .51229 L
.51272 .5122 L
.51346 .51206 L
.5149 .5117 L
.51629 .51124 L
.51959 .50968 L
.52265 .50773 L
.52599 .50509 L
.53246 .499 L
.53845 .49338 L
.54162 .49097 L
.54328 .48996 L
.54509 .48909 L
.54607 .48871 L
.54697 .48843 L
.54789 .4882 L
.54879 .48803 L
.5493 .48795 L
.54985 .48789 L
.55033 .48785 L
.55086 .48783 L
.55116 .48782 L
.55143 .48781 L
.55176 .48782 L
.55206 .48782 L
.55262 .48784 L
Mistroke
.55293 .48786 L
.55323 .48788 L
.55766 .48853 L
.56021 .48906 L
.56309 .48966 L
.56437 .48989 L
.56578 .49009 L
.56661 .49018 L
.56737 .49025 L
.56815 .49029 L
.5689 .4903 L
.56959 .49028 L
.57033 .49024 L
.57096 .49018 L
.57167 .49008 L
.57244 .48993 L
.57327 .48971 L
.5748 .48917 L
.57622 .48848 L
.57754 .48762 L
.57901 .48642 L
.58058 .48479 L
.58222 .48262 L
.58375 .48009 L
.58511 .47733 L
.58652 .47387 L
.5877 .47037 L
.58893 .46596 L
.59091 .45662 L
.59188 .4504 L
.59279 .44292 L
.5935 .43508 L
.594 .42726 L
Mfstroke
.53333 .53333 m
.53485 .52668 L
.53632 .51875 L
.53745 .51127 L
.53851 .50256 L
.53907 .49699 L
.53952 .49169 L
.53988 .48663 L
.54021 .48098 L
.54044 .47586 L
.5406 .47106 L
.54072 .46599 L
.54077 .46057 L
.54075 .45494 L
.54066 .44982 L
.54058 .44693 L
.54048 .44434 L
.54021 .43872 L
.5399 .43402 L
.5395 .42918 L
.53909 .42523 L
.53857 .42115 L
.53746 .41432 L
.53607 .40828 L
.53463 .40381 L
.53315 .40059 L
.53219 .39904 L
.53127 .3979 L
.53023 .39696 L
.52969 .3966 L
.52909 .39629 L
.52808 .39597 L
.5275 .39589 L
.52696 .39588 L
.52597 .39601 L
.52491 .39633 L
.52395 .39678 L
.52291 .3974 L
.52104 .39885 L
.51678 .40334 L
.49925 .4277 L
.48448 .44739 L
.48064 .45326 L
.47672 .46034 L
.47351 .4674 L
.47034 .47613 L
.46762 .48562 L
.46549 .49512 L
.46375 .50525 L
.46249 .51511 L
Mistroke
.46196 .52062 L
.46173 .52361 L
.46155 .52639 L
.46141 .52895 L
.46129 .53167 L
.46122 .53409 L
.46118 .53627 L
.46116 .53881 L
.46118 .54111 L
.4612 .54239 L
.46122 .54354 L
.46127 .54484 L
.46132 .54605 L
.46144 .54838 L
.46159 .55043 L
.46179 .55256 L
.46203 .5547 L
.4625 .5578 L
.46308 .56066 L
.46365 .56279 L
.46433 .56478 L
.46514 .56656 L
.46561 .56737 L
.46608 .56804 L
.46652 .56857 L
.46702 .56906 L
.46748 .56942 L
.46792 .5697 L
.46834 .56991 L
.4688 .57007 L
.46932 .57019 L
.46981 .57024 L
.47032 .57024 L
.47088 .57017 L
.47141 .57006 L
.47191 .56991 L
.47281 .56954 L
.4738 .56901 L
.47585 .56758 L
.48047 .56327 L
.4847 .55864 L
.49406 .54821 L
.50315 .53929 L
.5118 .53228 L
.52059 .52662 L
.53085 .52157 L
.53665 .51896 L
.53984 .51735 L
.54332 .51527 L
.54641 .51294 L
Mistroke
.54983 .50954 L
.55292 .5054 L
.55574 .50032 L
.55856 .49331 L
.56004 .4885 L
.56132 .48342 L
.56243 .47806 L
.56336 .47249 L
.56428 .46544 L
.56496 .45847 L
.56544 .45152 L
.56562 .44787 L
.56577 .44374 L
.56585 .44013 L
.5659 .43618 L
.5659 .43238 L
.56587 .42888 L
.56577 .42442 L
.56563 .42026 L
.56541 .41567 L
.56511 .41077 L
.56445 .40258 L
.56347 .3937 L
.5623 .3855 L
.56075 .37702 L
.55885 .3689 L
.55684 .36216 L
.55475 .35665 L
.5527 .35239 L
.55016 .3484 L
.54762 .34556 L
.54625 .34445 L
.54471 .3435 L
.54393 .34313 L
.54307 .34281 L
.54151 .34244 L
.53993 .34232 L
.53841 .34242 L
.53703 .34269 L
.53551 .34315 L
.53368 .34394 L
.53201 .34485 L
.52824 .34749 L
.52141 .35382 L
.49442 .38479 L
.48286 .39788 L
.47682 .40583 L
.47356 .41095 L
.47053 .41652 L
.46767 .42275 L
Mistroke
.46469 .43065 L
.45987 .44785 L
.45775 .45811 L
.45573 .47031 L
.45423 .48179 L
.45284 .49546 L
.45218 .5038 L
.45165 .51197 L
.45126 .51947 L
.45093 .52779 L
.45079 .53256 L
.4507 .53691 L
.45062 .54194 L
.45058 .54668 L
.4506 .5551 L
.45066 .55981 L
.45075 .56411 L
.45097 .57177 L
.45127 .57877 L
.45169 .58623 L
.45225 .59393 L
.45295 .6016 L
.45372 .60844 L
.45542 .62006 L
.45744 .62999 L
.4596 .63763 L
.46221 .64413 L
.46377 .64696 L
.46525 .64905 L
.46676 .65067 L
.46819 .6518 L
.4698 .65266 L
.47071 .65298 L
.47155 .65318 L
.47326 .65332 L
.47423 .65326 L
.47514 .65312 L
.47682 .65268 L
.47861 .65198 L
.48162 .65038 L
.48489 .64821 L
.49085 .64364 L
.50462 .63289 L
.51174 .62759 L
.51942 .621 L
.52385 .61602 L
.52782 .61022 L
.53174 .6027 L
.53531 .59367 L
.53854 .583 L
Mistroke
.5417 .56928 L
.54414 .55547 L
.54649 .53813 L
.54855 .51712 L
.54947 .50447 L
.55015 .49253 L
.55063 .48114 L
.55084 .47463 L
.551 .46859 L
.55117 .45749 L
.55121 .44578 L
.55111 .43533 L
.55086 .42418 L
.55044 .41295 L
.5499 .40299 L
.54928 .3941 L
.54862 .38649 L
.54683 .37118 L
.54565 .36373 L
.54447 .35763 L
.54309 .35189 L
.54148 .34656 L
.53999 .34273 L
.53855 .3398 L
.53697 .33737 L
.53522 .33545 L
.53354 .33428 L
.53196 .33367 L
.5302 .33348 L
.5283 .33377 L
.52664 .33439 L
.52508 .33524 L
.52148 .33797 L
.51529 .34443 L
.50865 .35256 L
.49375 .37099 L
.48021 .38825 L
.4736 .39943 L
.46689 .41553 L
.46335 .4273 L
.46027 .4404 L
.45779 .45384 L
.45545 .47012 L
.45377 .48535 L
.453 .49413 L
.45237 .50268 L
.45187 .51072 L
.45144 .51959 L
.45114 .52768 L
.45095 .53517 L
Mistroke
.45087 .5398 L
.45082 .54478 L
.45082 .55368 L
.45093 .56214 L
.45114 .56969 L
.45146 .57758 L
.45194 .58582 L
.45257 .59391 L
.45328 .60094 L
.45407 .60731 L
.45504 .61364 L
.45599 .61867 L
.45707 .62345 L
.45811 .62725 L
.45933 .63092 L
.46163 .63609 L
.4631 .63845 L
.4645 .64015 L
.46608 .64154 L
.46689 .64206 L
.46779 .6425 L
.46933 .64297 L
.47021 .64308 L
.47101 .6431 L
.47258 .64294 L
.47409 .64256 L
.4755 .64202 L
.47704 .64128 L
.47983 .63958 L
.48626 .63459 L
.49942 .62309 L
.51184 .61288 L
.52354 .60236 L
.53001 .5948 L
.53677 .58435 L
.54392 .56899 L
.54984 .55122 L
.55474 .53117 L
.55697 .5196 L
.55904 .50687 L
.56059 .49541 L
.562 .48277 L
.563 .47138 L
.5637 .46101 L
.56399 .45533 L
.56423 .44946 L
.56436 .44459 L
.56445 .4394 L
.56447 .43657 L
.56447 .43404 L
Mistroke
.56444 .43119 L
.5644 .42855 L
.56428 .42404 L
.56418 .42159 L
.56407 .41939 L
.56382 .41528 L
.56352 .41164 L
.56284 .40548 L
.56239 .40238 L
.56194 .39977 L
.56078 .39465 L
.55968 .39118 L
.55857 .38859 L
.55726 .3864 L
.5565 .38546 L
.55578 .38477 L
.55501 .38421 L
.55428 .38383 L
.55347 .38356 L
.55259 .38343 L
.55182 .38344 L
.55109 .38354 L
.55028 .38375 L
.5494 .38409 L
.54772 .38501 L
.54591 .38633 L
.54262 .38942 L
.53522 .39837 L
.5211 .41769 L
.49562 .44677 L
.47406 .46417 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00X_ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP2iooooo`00X_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`2iooooo`00V_ooool6o`0000Kooooo00Go0000oooooooooooooooooa0@
4003ooooo`03oa0@4?oooooooooo0;Oooooo002Uooooo`03ojVYZOl@413ooooo00;ooooo00Go0000
ooooooooooooooooo`000006ooooo`?o0000@?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo06Kooooo002Tooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`1Vooooo`00YOooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_oo
ool00ol0003oooooooooo`0:ooooo`?o0000<oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo06Kooooo002Rooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Kooooo00?o0000ooooooooool02?ooool2o`0000?ooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06Kooooo002Rooooo`05ojVYZOl@
413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooooooo
ool01oooool01?l0003oooooooooooooool4o`00037ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`1Vooooo`00]Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;o
00000oooool2o`00033ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Vooooo`00
]Oooool00ol0003oooooooooo`05ooooo`04o`000?oooooo0000o`0000Gooooo00?o0000ooooool0
0000;oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06Kooooo002eooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooool000002?ooool2o`00033ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`1Vooooo`00]Oooool00ol0003oooooooooo`03ooooo`04o`000?oo
ooooooooo`0000Sooooo00?o0000ooooool00000;oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo06Kooooo002eooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
2_ooool2o`0002oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Vooooo`00]Ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0I_ooool00;Gooooo0_l0
0002ooooo`03o`000?oooooo000000gooooo0_l0000^ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0I_ooool00;Gooooo00Ko0000oooooooooooo0000ooooool0000?ooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Uooooo`00]Ooo
ool01Ol0003oooooo`000?oooooo0000013ooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo06Gooooo002eooooo`;o000000?oooooo`000?ooool02_oo
ool5o`000003ooooool0003o000002gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`1Uooooo`00]Oooool00ol0003oooooo`00000:ooooo`;o00001Oooool00ol0003oooooo`00000]
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0IOooool00;Cooooo0ol0000:oooo
o`03o`000?oooooooooo00Kooooo0_l0000]ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0IOooool00;?ooooo00?o0000ooooool000002Oooool2o`0000[ooooo0_l0000/ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0IOooool00;;ooooo00Co0000ooooool0003o
00002?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`1Uooooo`00/Oooool01Ol0003oooooo`000?oooooo000000Oo
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0IOooool00;7ooooo0_l00002ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool03Oooool2o`0002cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1Uooooo`00/?ooool2o`0000?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1Uooooo`00[oooool2o`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0?
ooooo`;o0000:oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06Gooooo002^oooo
o`;o00001Oooool2o`0000?ooooo00?o0000ooooooooool02Oooool2o`0000Gooooo0_l0000[oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0IOooool00:gooooo0_l00006ooooo`05
o`000?ooooooooooooooool000002?ooool4o`0000;ooooo0ol00002ooooo`;o0000:oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo06Gooooo002/ooooo`;o00001oooool01?l0003o
ooooooooool00007ooooo`Ko00001Oooool01Ol0003oooooo`000?oooooo000002[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`1Tooooo`00Zoooool2o`0000Sooooo00?o0000oooo
ool000001_ooool2o`000003ooooool0003ooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooo`000002o`0002[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Toooo
o`00Z_ooool00ol0003oooooo`000008ooooo`;o00001_ooool01?l0003oooooooooool00005oooo
o`03o`000?oooooooooo00?ooooo00Co0000ooooool0003o0000:_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo06Cooooo002Zooooo`;o00002Oooool00ol0003oooooooooo`04oooo
o`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool00_ooool01Ol0003oooooo`000?oo
oooo000002Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Tooooo`00ZOooool2
o`0000Wooooo0_l00006ooooo`04o`000?oooooo0000ooooo`Ko000000?oooooo`000?ooool00ooo
ool01Ol0003oooooo`000?oooooo000002Wooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1Tooooo`00Z?ooool00ol0003oooooo`000008ooooo`03o`000?oooooo000000Gooooo00Go
0000ooooool0003oooooo`000006ooooo`03o`000?oooooo000000Cooooo0_l000000ooooooo0000
ooooo`0Xooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0I?ooool00:Sooooo0_l0
0008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooool000000_ooool00ol0003ooooo
ooooo`05ooooo`;o00001Oooool01?l0003oooooooooool0000Yooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0I?ooool00:Oooooo00?o0000ooooool000001oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Co0000ooooool0003ooooo0_l00009ooooo`;o00001?ooool01?l0
003oooooooooool0000Yooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0I?ooool0
0:Oooooo0_l00007ooooo`03o`000?oooooooooo00;ooooo00So0000oooooooooooo0000ooooool0
003oooooo`0000Kooooo1?l000000ooooooo0000o`000004ooooo`04o`000?ooooooooooo`0002Wo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Tooooo`00Yoooool2o`0000Kooooo
00?o0000ooooooooool00oooool3o`000004ooooool0003oooooo`0000Kooooo00?o0000oooooooo
ool00_ooool00ol0003oooooo`000004ooooo`;o000000?oooooo`000?ooool0:?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo06Cooooo002Vooooo`;o00001_ooool00ol0003ooooo
ooooo`04ooooo`;o000000Coooooo`000?oooooo00001Oooool2o`0000Kooooo0ol00004ooooo`03
o`000?oooooo000002Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Tooooo`00
Y_ooool2o`0000Gooooo00?o0000ooooooooool01Oooool01Ol0003oooooo`000?oooooo000000Go
oooo00?o0000ooooooooool01oooool2o`0000Cooooo00Co0000oooooooooooo0000:?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo06Cooooo002Uooooo`;o00001Oooool00ol0003o
ooooooooo`05ooooo`?o000000?oooooo`000?ooool01?ooool00ol0003oooooooooo`08ooooo`;o
00001?ooool01?l0003oooooooooool0000Xooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0I?ooool00:Gooooo0_l00004ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooool0
003oooooo`000005ooooo`03o`000?oooooooooo00[ooooo0_l00003ooooo`;o000000?oooooo`00
0?ooool09oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06Cooooo002Uooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000002o`0000Go
oooo00?o0000ooooooooool02oooool2o`0000?ooooo0_l000000ooooooo0000ooooo`0Wooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0I?ooool00:Cooooo0_l00004ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooool0003oooooo`000005ooooo`03o`000?oooooooooo00co
oooo0_l00003ooooo`;o000000?oooooo`000?ooool03_ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0I?ooool00:Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`04o`000?oooooo0000ooooo`;o00001?ooool00ol0003o
ooooooooo`0>ooooo`;o00000_ooool01?l0003oooooo`000?l0000?ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Tooooo`00Y?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000000_ooool2o`0000Co
oooo00?o0000ooooooooool03_ooool3o`000003ooooool0003ooooo00;o00003oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0I?ooool00:Cooooo
00Go0000ooooooooooooooooo`000006ooooo`;o00000_ooool00ol0003oooooo`000003ooooo`03
o`000?oooooooooo00oooooo0ol000000ooooooo0000o`000002o`00013ooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06?ooooo002Sooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool2o`0000;ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0Aooooo`;o000000Koooooo`000?l0003o0000ooooool0000?
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1S
ooooo`00Xoooool01Ol0003ooooooooooooooooo000000Gooooo0_l00002ooooo`04o`000?oooooo
ooooooooo`?o00005?ooool00ol0003oooooo`000003o`000003ooooool0003ooooo00kooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06?ooooo002S
ooooo`05o`000?ooooooooooooooool000001?ooool2o`0000;ooooo00?o0000ooooooooool00_oo
ool2o`0000Wooooo1Ol00007ooooo`06o`000?oooooo0000ooooool0003ooooo0_l0000?ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Sooooo`00
X_ooool01Ol0003ooooooooooooooooo000000Cooooo0_l00002ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01_ooool2o`0000Gooooo00?o0000ooooooooool01?ooool3o`000003
ooooool0003ooooo00;o00004?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0Hoooool00:;ooooo00Co0000oooooooooooo00001Oooool01?l0003o
ooooooooool00005ooooo`;o00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Cooooo0_l000000ooooooo0000ooooo`02o`00013ooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo06?ooooo002Rooooo`04o`000?ooooooooooo`00
00Cooooo00Co0000oooooooooooo00001?ooool2o`000003ooooool0003ooooo00Gooooo00?o0000
ooooooooool00_ooool2o`0000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000004
o`00013ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo06?ooooo002Qooooo`;o000000?oooooo`000?ooool00oooool2o`0000;ooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l0
0002ooooo`;o000000?oooooo`000?ooool01Oooool00ol0003oooooo`000004o`00013ooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06?ooooo002Q
ooooo`04o`000?ooooooooooo`0000Cooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`03
o`000?oooooo000000Kooooo00?o0000ooooool000001?l0000Aooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Sooooo`00XOooool00ol0003ooooo
o`000004ooooo`;o000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`03ooooo`05o`00
0?ooooooooooooooool000000oooool01?l0003oooooooooooooool7o`0000Gooooo00?o0000oooo
ool000000ol000000ooooooo0000ooooo`0?ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`1Sooooo`00X?ooool2o`000003ooooool0003ooooo00;o
oooo0_l000000ooooooo0000ooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooooooo`Wo00001?ooool00ol0003oooooo`000003
o`000003ooooool0003ooooo00oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo06?ooooo002Pooooo`Wo000000Koooooo`000?lb<S;o0000oc8b<_l0
0006ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooooooo0_l00005ooooo`?o
00001?ooool00ol0003oooooooooo`03o`000003ooooool0003ooooo00oooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06?ooooo002Pooooo`06o`00
0?oooooo0000ob4Q8Oo^k^kooooo0_l000001ooooooo0000ogMgMonHV9Soooooo`000?mgMgL01_oo
ool00ol0003oooooo`000002ooooo`06o`000?ooooooooooooooool0003ooooo1_l000001?oooooo
0000ooooool00004ooooo`03o`000?oooooo000000;o000000?oooooo`000?ooool04?ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Hoooool009[o
oooo1ol000001Ooooooo0000oiRHV?lQ8B7ok^k^00?o000000Kooooooa0@4?oooooo0000ooooool@
4106ooooo`;o00000_ooool01?l0003oooooooooooooool6o`000003ooooool0003ooooo00Oo0000
00?oooooo`000?ooool00_l000000ooooooo0000o`00000Aooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`1Sooooo`00X?ooool01Ol0003oooooo`00
0?ooooooV9RH00;o000000Soooooo`000?oooooo0000ooooool0003oooooo`0000Kooooo1?l00003
ooooo`;o000000?oooooo`000?ooool01Ol000000ooooooo0000o`000002o`000005ooooool0003o
ooooo`000?ooool00_l000000ooooooo0000o`00000Aooooo`04o`000?ooooooooooo`0001;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`1Sooooo`00Woooool3o`0000;ooooo00Co
0000ogMgMol0003o00000_ooool2o`0000;ooooo00?o0000ooooooooool00oooool2o`000003oooo
ool0003ooooo00;ooooo0_l000001?oooooo0000o`000?l00003ooooo`?o000000Coooooo`000?l0
003o00000_ooool2o`000004ooooool0003o0000ooooo`;o00004Oooool01Ol0003ooooooooooooo
oooo0000017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Rooooo`00Woooool0
0ol0003oooooo`000002ooooo`?o00000oooool01Ol0003ooooooooooooooooo410@00Gooooo0ol0
0003ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooo`000?ooool0
0ol00003ooooo`03o`000?oooooo000000Co00004Oooool01Ol0003ooooooooooooooooo0000017o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Rooooo`00Woooool00ol0003ooooo
o`000002o`000003ooooool0003o000000;ooooo00Ko0000ogMgMonHV9SooooooiRHV?mgMgL4oooo
o`03o`000?oooooo000000?ooooo0_l00002ooooo`;o00000oooool6o`000004ooooool0003ooooo
o`0000;ooooo00?o0000ooooooooool01?l0000Aooooo`05o`000?ooooooooooooooool000004Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06;ooooo002Oooooo`;o000000?ooooo
oiRHV?l000000ol00002ooooo`06o`000?o^k^ko<S8bo`000?lb<S;ok^k^0oooool01?l0003ooooo
o`000?l00002ooooo`;o00000_ooool2o`0000;ooooo0_l00004ooooo`;o000000Coooooo`000?l0
003o00000_ooool2o`000006ooooool0003o0000o`000?oooooo00004?ooool01Ol0003ooooooooo
oooooooo000001;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Rooooo`00W_oo
ool3o`000003ooooool0003ooooo00;o00000_ooool00ol0003oooooooooo`06ooooo`0:o`000?oo
oooo0000ooooool0003oooooo`000?oooooo0000ooooo`;o00000_ooool2o`0000Kooooo1Ol00002
ooooo`;o000000Koooooo`000?l0003o0000ooooool0000Aooooo`04o`000?ooooooooooo`0001;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Rooooo`00W_ooool3o`000003oooo
ool0003ooooo00;o00000_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooo`000?oo
ool00_l000000ooooooo0000ooooo`02o`0000;ooooo0_l00002ooooo`?o00000_ooool00ol0003o
ooooo`000002o`0000;ooooo00?o0000ooooool000000ol000000ooooooo0000ooooo`0@ooooo`04
o`000?ooooooooooo`0001;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Roooo
o`00W_ooool01?l0003oooooo`000?l00002ooooo`;o000000?oooooo`000?ooool01_ooool01?l0
003oooooooooool00002ooooo`04o`000?oooooo0000ooooo`;o000000Coooooo`000?l0003o0000
0_ooool01?l0003oooooooooooooool2o`000003ooooool0003o000000?o000000?oooooo`000?oo
ool01?l000000ooooooo0000ooooo`0@ooooo`04o`000?ooooooooooo`0001;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`1Rooooo`00W_ooool2o`000005ooooool0003ooooooooo
ool000000_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo0ol00000
1?oooooo0000o`000?ooool2o`0000;ooooo0_l00005ooooo`03o`000?oooooo000000Co000000?o
ooooo`000?l000001?l000000ooooooo0000ooooo`0@ooooo`04o`000?ooooooooooo`0001;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`1Rooooo`00W_ooool3o`0000;ooooo0_l0
00000ooooooo0000ooooo`06ooooo`03o`000?oooooo000000;ooooo00Co0000ooooool0003ooooo
0_l000000ooooooo0000o`000002ooooo`03o`000?oooooooooo00Kooooo1_l00002ooooo`05o`00
0?oooooo0000o`000?ooool00_l0000Aooooo`05o`000?ooooooooooooooool000004Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo06;ooooo002Mooooo`Co00000_ooool2o`000003
ooooool0003ooooo00Gooooo00?o0000ooooool000000_ooool00ol0003oooooo`000003o`0000;o
oooo00Co0000oooooooooooo00002Oooool6o`0000;ooooo00Go0000ooooool0003o0000ooooo`02
o`00017ooooo00Go0000ooooooooooooooooo`00000Aooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0H_ooool009gooooo0ol00003ooooo`?o00001_ooool00ol0003oooooo`000002
ooooo`04o`000?oooooo0000ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000[ooooo
1Ol00002ooooo`05o`000?oooooo0000o`000?ooool00_l0000Aooooo`05o`000?oooooooooooooo
ool000004Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06;ooooo002Mooooo`?o
00000oooool00ol0003oooooo`000005ooooo`03o`000?oooooo000000;ooooo00Co0000ooooool0
003ooooo0_l00002ooooo`05o`000?ooooooooooooooool000002oooool6o`000003ooooool0003o
oooo00;o000000?oooooo`000?l000004Oooool01Ol0003ooooooooooooooooo0000017ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`1Rooooo`00WOooool2o`0000?ooooo0_l00000
0ooooooo0000ooooo`03ooooo`09o`000?ooooooooooo`000?oooooo0000ooooool0003ooooo00?o
000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`Go000000?oooooo`000?oo
ool00_l000001?oooooo0000ooooool0000@ooooo`05o`000?ooooooooooooooool000004Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo06;ooooo002Mooooo`;o00000oooool3o`00
00Cooooo00Wo0000oooooooooooo0000ooooool0003oooooo`000?ooool00_l000000ooooooo0000
o`000003ooooo`03o`000?oooooooooo00cooooo1Ol000000ooooooo0000ooooo`02o`000004oooo
ool0003oooooo`00013ooooo00Go0000ooooooooooooooooo`00000Aooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0H_ooool009gooooo0_l00003ooooo`03o`000?oooooo000000Co
oooo00?o0000ooooooooool01?l000000ooooooo0000o`000002ooooo`05o`000?oooooooooooooo
ool000003oooool5o`000003ooooool0003ooooo00;o000000Coooooo`000?oooooo00002oooool0
0ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`00017ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1Rooooo`00WOooool2o`0000?ooooo0_l00005ooooo`06o`000?oooooo
0000ooooool0003ooooo0ol00002ooooo`;o00000_ooool00ol0003oooooooooo`04ooooo`Co0000
1oooool4o`000003ooooool0003ooooo00;o000000Coooooo`000?oooooo00002oooool00ol0003o
ooooooooo`03ooooo`04o`000?ooooooooooo`00017ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Rooooo`00WOooool01?l0003oooooooooooooool3o`0000Cooooo00Ko0000oooo
ool0003oooooo`000?ooool3o`0000;ooooo00Go0000ooooool0003oooooo`000006ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool4o`000003ooooool0003ooooo00;o0000
00Coooooo`000?oooooo00002oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`00
017ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Rooooo`00W?ooool2o`0000?o
oooo0_l00005ooooo`04o`000?oooooo0000ooooo`Co00000_ooool00ol0003oooooooooo`02o`00
00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`Ko00000_ooool3o`00
0003ooooool0003ooooo00[ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0000A
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0H_ooool009cooooo0_l00003oooo
o`;o00001Oooool2o`000003ooooool0003o000000;o00000_ooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool00_ooool2o`000003ooooool0003ooooo00Cooooo1ol00000
1_oooooo0000o`000?l0003oooooo`0000cooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000Aooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0H_ooool009cooooo
0_l00003ooooo`;o00001?ooool2o`000003ooooool0003o000000;o00000_ooool00ol0003ooooo
ooooo`03o`0000Gooooo00?o0000ooooooooool00ol00002ooooo`?o00001?ooool7o`000004oooo
ool0003o0000ooooo`;o00003?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
017ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Rooooo`00Voooool3o`0000?o
oooo0_l00003ooooo`04o`000?oooooo0000ooooo`;o000000?oooooo`000?ooool00_l000001Ooo
oooo0000oooooooooooo000000Gooooo00?o0000ooooool000001oooool00ol0003oooooooooo`02
ooooo`Go000000?oooooo`000?ooool00_l000000ooooooo0000o`00000<ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00004Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo06;ooooo002Kooooo`?o00000_ooool2o`0000Cooooo00?o0000ooooool000001?l00000
1Ooooooo0000o`000?oooooo000000?ooooo0_l00003ooooo`04o`000?ooooooooooo`0000Oooooo
0_l00004ooooo`Co000000?oooooo`000?ooool00_l000000ooooooo0000o`00000<ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00004Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo06;ooooo002Kooooo`?o00000_ooool2o`0000Cooooo0ol000001?oooooo0000
o`000?ooool2o`000003ooooool0003ooooo00?ooooo00Go0000ooooooooooooooooo`000002oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool4o`000003ooooool0003ooooo
00;o000000?oooooo`000?l000003?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`00017ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Rooooo`00Voooool3o`00
00;ooooo0_l00003ooooo`03o`000?oooooo000000Ko000000?oooooo`000?ooool01?ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00Sooooo0_l00003ooooo`Ko000000?ooooo
o`000?l000000ol0000<ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00004Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06;ooooo002Jooooo`03o`000?oooooo
000000;ooooo0ol00003ooooo`04o`000?oooooo0000ooooo`Co000000?oooooo`000?ooool01Ooo
ool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooooooo
1_l000000ooooooo0000o`000002o`000003ooooool0003ooooo00[ooooo00?o0000ooooooooool0
0oooool00ol0003oooooo`00000Aooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
H_ooool009[ooooo00?o0000ooooool000000_ooool3o`0000?ooooo1ol00002ooooo`03o`000?oo
oooooooo00Cooooo0_l00002ooooo`03o`000?oooooooooo00Wooooo1Ol000000ooooooo0000o`00
0004o`000003ooooool0003o000000;o000000?oooooo`000?ooool02oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooo0000017ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1Rooooo`00V_ooool3o`0000;ooooo0_l00004ooooo`Co000000Goooooo`000?l0003oooooo`00
0007ooooo`04o`000?ooooooooooo`0000Oooooo0_l000000ooooooo0000o`000002ooooo`;o0000
00?oooooo`000?l000001Ol000000ooooooo0000o`000002o`000003ooooool0003ooooo00_ooooo
00?o0000ooooooooool00_ooool00ol0003oooooo`00000Aooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0H_ooool009Wooooo00Co0000ooooool0003o00000_ooool2o`0000Cooooo
0_l000001_oooooo0000o`000?l0003oooooo`0000Oooooo0_l000000ooooooo0000ooooo`05oooo
o`;o00000_ooool2o`0000?ooooo0_l00003ooooo`Go000000?oooooo`000?l000000_l000000ooo
oooo0000ooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000004Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo06;ooooo002Iooooo`04o`000?oooooo0000o`00
00;ooooo0_l00003ooooo`Go000000Coooooo`000?oooooo00001_ooool01?l0003oooooo`000?l0
0006ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o00000oooool5o`000003ooooool0
003o000000;o000000?oooooo`000?ooool02oooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`00013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Rooooo`00VOoo
ool01?l0003oooooo`000?l00002ooooo`03o`000?oooooooooo00;ooooo1?l000001?oooooo0000
ooooool00006ooooo`04o`000?ooooooooooo`0000Kooooo00Co0000ooooool0003o00000oooool2
o`0000?ooooo00Co0000oooooooooooooooo1Ol000001ooooooo0000o`000?oooooo0000ooooool0
00003?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00013ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`1Rooooo`00V?ooool00ol0003oooooooooo`02o`000003
ooooool0003o000000Cooooo1?l000000ooooooo0000o`000006ooooo`03o`000?oooooooooo00;o
00001Oooool00ol0003oooooo`000005o`000003ooooool0003o000000;ooooo0_l00002ooooo`Go
000000Ooooooo`000?l0003oooooo`000?oooooo000000cooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0H_oo
ool009Sooooo00Co0000oooooooooooo00000_ooool2o`0000?ooooo1?l000000ooooooo0000o`00
0006ooooo`06o`000?ooooooooooo`000?oooooo00001Oooool2o`000003ooooool0003ooooo00?o
oooo0_l000000ooooooo0000ooooo`02o`0000;ooooo1Ol000001ooooooo0000o`000?oooooo0000
ooooool000003?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00013ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`1Rooooo`00V?ooool01?l0003oooooooooool0
0002ooooo`;o00000oooool4o`000003ooooool0003o000000Kooooo00?o0000ooooool000000_oo
ool00ol0003oooooooooo`02ooooo`;o000000?oooooo`000?ooool01Oooool3o`000003ooooool0
003o000000;ooooo1Ol000001?oooooo0000o`000?ooool3o`0000cooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0H_ooool009Sooooo00Co0000ooooool0003o00000_ooool2o`0000?ooooo1_l00006ooooo`04
o`000?ooooooooooo`0000;ooooo0_l00002ooooo`Co00001oooool3o`0000;ooooo00?o0000oooo
ooooool01Ol000001?oooooo0000o`000?ooool3o`0000cooooo00?o0000ooooooooool00oooool0
0ol0003oooooo`00000@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0H_ooool0
09Oooooo00?o0000ooooooooool00_l00002ooooo`04o`000?ooooooooooooooo`Co000000?ooooo
o`000?l000001Oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooo`000?ooool0
0_l00009ooooo`;o00000_ooool00ol0003oooooooooo`05o`0000;ooooo00?o0000ooooool00000
0_l0000<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000004?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo06;ooooo002Gooooo`03o`000?oooooooooo00;o00000_oo
ool00ol0003oooooooooo`07o`0000Gooooo00Co0000oooooooooooo00001?ooool01?l0003ooooo
o`000?ooool2o`0000Gooooo1?l000001_oooooo0000o`000?l0003oooooo`0000;ooooo1Ol00002
ooooo`03o`000?oooooo000000;o00003?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
0000013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Rooooo`00Uoooool00ol0
003oooooooooo`02o`0000;ooooo00Co0000ooooool0003ooooo1_l00004ooooo`04o`000?oooooo
ooooo`0000Gooooo00?o0000ooooool000000_l00004ooooo`;o00000oooool5o`000004ooooool0
003oooooooooo`?o000000Koooooo`000?ooooooooooo`000?ooool3o`0000cooooo00?o0000oooo
ooooool00oooool00ol0003oooooo`00000@ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0H_ooool009Oooooo00?o0000ooooooooool00_l00002ooooo`04o`000?oooooo0000oooo
o`?o000000?oooooo`000?ooool00oooool01Ol0003ooooooooooooooooo000000Gooooo1?l00004
ooooo`03o`000?oooooooooo00Cooooo1ol000001Ooooooo0000o`000?l0003ooooo00;o000000?o
ooooo`000?l000000ol0000<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000004?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06;ooooo002Gooooo`03o`000?oooooo
oooo00;o00000_ooool2o`000003ooooool0003o000000Co00001?ooool01?l0003oooooooooool0
0006ooooo`?o00001Oooool00ol0003oooooooooo`02ooooo`Wo000000?oooooo`000?l000001?l0
00000ooooooo0000o`000003o`0000cooooo00?o0000ooooooooool00oooool00ol0003oooooo`00
000@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0H_ooool009Kooooo00Co0000
oooooooooooooooo0_l000000ooooooo0000o`000002ooooo`Go00001?ooool01?l0003ooooooooo
ool00005ooooo`Co00001?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool2o`000004oooo
ool0003o0000ooooo`Ko000000?oooooo`000?l000000ol0000<ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooool000004?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06;o
oooo002Fooooo`04o`000?ooooooooooooooo`;o000000?oooooo`000?l000000_ooool3o`000003
ooooool0003ooooo00?ooooo00?o0000ooooool000001Oooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool2o`000004ooooool0003o0000
ooooo`Ko000000?oooooo`000?l000000ol0000<ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooool000004?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06;ooooo002Foooo
o`04o`000?ooooooooooooooo`;o000000Coooooo`000?l0003ooooo1_l00004ooooo`;o00001Ooo
ool00ol0003oooooooooo`02o`0000?ooooo00?o0000ooooooooool00_ooool5o`0000?ooooo3ol0
00000ooooooo0000o`00000<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000004?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06;ooooo002Fooooo`04o`000?oooooo
ooooooooo`Co00000_ooool5o`0000Cooooo00?o0000ooooool000001?ooool00ol0003ooooooooo
o`03o`0000;ooooo00?o0000ooooooooool00_ooool2o`0000Cooooo2?l000000ooooooo0000o`00
0007o`000003ooooool0003o000000gooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00
000@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0H_ooool009Kooooo00Ko0000
ooooooooooooooooo`000?ooool2o`0000;ooooo1Ol00004ooooo`;o00001?ooool00ol0003ooooo
ooooo`02o`000005ooooool0003oooooooooool000000oooool2o`0000Cooooo0_l00003ooooo`Co
000000?oooooo`000?l000001ol000000ooooooo0000o`00000=ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooool000004?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06;o
oooo002Eooooo`03o`000?oooooooooo00;ooooo0_l000001?oooooo0000ooooooooool5o`0000?o
oooo00?o0000ooooool000001?ooool01?l0003oooooo`000?l00002ooooo`?o00000oooool2o`00
0003ooooool0003o000000?o000000Coooooo`000?oooooooooo3_l000000ooooooo0000o`00000=
ooooo`03o`000?oooooooooo00?ooooo0_l0000@ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0H_ooool009Gooooo00Co0000oooooooooooooooo0_l000000ooooooo0000o`000002
ooooo`Co00001?ooool2o`0000Cooooo00?o0000ooooool000000_l00002ooooo`;o00000oooool0
0ol0003oooooo`000008o`0000;ooooo1Ol000000ooooooo0000o`000003o`000004ooooool0003o
0000ooooo`;o00003Oooool00ol0003oooooooooo`03ooooo`;o00004?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo06;ooooo002Eooooo`04o`000?ooooooooooooooo`;o000000Co
ooooo`000?l0003ooooo1Ol00004ooooo`;o00000oooool00ol0003oooooo`000002o`0000?ooooo
00Ko0000ooooooooooooooooo`000?ooool3o`000006ooooool0003oooooooooool0003ooooo2?l0
00000ooooooo0000o`000003o`000004ooooool0003o0000ooooo`;o00003Oooool00ol0003ooooo
ooooo`03ooooo`;o00004?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06;ooooo
002Eooooo`04o`000?ooooooooooooooo`;o000000Coooooo`000?l0003ooooo1Ol00003ooooo`;o
00001?ooool4o`0000?ooooo0_l00003ooooo`;o000000Coooooo`000?oooooo00000oooool3o`00
00;ooooo0_l000001?oooooo0000o`000?ooool5o`000004ooooool0003o0000ooooo`;o00003Ooo
ool00ol0003oooooooooo`03ooooo`;o00004?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo06;ooooo002Eooooo`03o`000?oooooooooo00?o000000Coooooo`000?l0003ooooo1?l0
0004ooooo`;o00000oooool4o`0000?ooooo00?o0000ooooool000000_ooool2o`000004ooooool0
003oooooo`0000;ooooo1_l00002ooooo`Co000000?oooooo`000?l000000ol000001?oooooo0000
o`000?ooool2o`0000gooooo00?o0000ooooooooool00oooool2o`00013ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`1Rooooo`00UOooool00ol0003oooooooooo`03o`000004oooo
ool0003o0000ooooo`Co00001?ooool00ol0003oooooooooo`02ooooo`?o00000oooool01Ol0003o
ooooooooool0003ooooo00;o000000Coooooo`000?oooooo00000_ooool2o`0000?ooooo0_l00002
ooooo`05o`000?oooooo0000o`000?ooool01Ol000001ooooooo0000o`000?oooooo0000ooooool0
00003?ooool00ol0003oooooooooo`03ooooo`;o00004?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo06;ooooo002Dooooo`05o`000?ooooooooooo`000?ooool00ol000000ooooooo
0000ooooo`04o`0000?ooooo0_l00003ooooo`;o000000Goooooo`000?ooooooooooo`000003oooo
o`?o000000Coooooo`000?l0003o00000_ooool00ol0003oooooooooo`03ooooo`?o000000?ooooo
o`000?l000000_l000000ooooooo0000o`000003o`000007ooooool0003o0000ooooool0003ooooo
o`00000<ooooo`03o`000?oooooooooo00?ooooo0_l0000@ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0H_ooool009Cooooo00?o0000ooooool000000_ooool5o`000003ooooool0
003o000000;o00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000;ooooo00?o
0000ooooooooool00_ooool2o`000004ooooool0003o0000o`0000;ooooo0_l00006ooooo`;o0000
00?oooooo`000?l000000_l000000ooooooo0000o`000003o`000003ooooool0003o000000;o0000
00?oooooo`000?ooool02oooool00ol0003oooooooooo`03ooooo`;o00004?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo06;ooooo002Dooooo`03o`000?oooooo000000;ooooo1Ol0
00001?oooooo0000o`000?l00004ooooo`04o`000?ooooooooooooooo`?o00000_ooool00ol0003o
ooooooooo`02ooooo`;o000000Coooooo`000?l0003o00000oooool00ol0003oooooooooo`05oooo
o`;o00000_ooool9o`000003ooooool0003o000000;o000000?oooooo`000?l000002oooool00ol0
003oooooooooo`03ooooo`;o00004?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
06;ooooo002Dooooo`;o00000oooool9o`000003ooooool0003o000000;o000000So410@oooooooo
oooo0000oc8b<_l0003o<S8bo`0000Cooooo00?o0000ooooool000000ol00003ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02Ol000000ooooooo0000o`000004o`000003ooooool0
003ooooo00Wooooo00?o0000ooooooooool00oooool2o`00013ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1Rooooo`00U?ooool2o`0000?ooooo1?l000000ooooooo0000o`000002
o`0000?ooooo00Co0000oooooooooooooooo0ol000000oooooooV9RHo`000003ooooo`03o`000?oo
oooooooo00?o00000oooool00ol0003oooooooooo`08ooooo`;o000000?oooooo`000?l000001ol0
00000ooooooo0000o`000004o`000003ooooool0003o000000Wooooo00?o0000ooooooooool00ooo
ool2o`00013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Rooooo`00U?ooool0
0ol0003oooooooooo`02ooooo`Wo00000oooool00ol0003oooooooooo`02o`000005oa0@4?l0003o
ooooo`000?l@41000_ooool01?l0003oooooooooooooool3o`0000;ooooo00?o0000ooooooooool0
0_ooool2o`0000Gooooo0_l000000ooooooo0000o`000007o`000003ooooool0003o000000;o0000
00Goooooo`000?ooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool2o`00013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Rooooo`00
U?ooool00ol0003oooooooooo`02ooooo`Co000000?oooooo`000?l000000_l00003ooooo`03o`00
0?oooooooooo00?o000000Koooooo`000?oooooo0000ooooool00003ooooo`;o00000oooool01?l0
003oooooooooooooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000ooooo`07
o`000003ooooool0003ooooo00;o000000Goooooo`000?ooooooooooo`000004ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool2o`00013ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1Rooooo`00Toooool00ol0003oooooooooo`02ooooo`Go000000?ooooo
o`000?l000000_l00002ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000ooooo`03
o`0000;ooooo0ol00002ooooo`05o`000?ooooooooooooooool000001?ooool2o`0000?ooooo0_l0
00000ooooooo0000ooooo`07o`000003ooooool0003ooooo00;o000000Goooooo`000?oooooooooo
o`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool2o`00013ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`1Rooooo`00Toooool00ol0003ooooooooo
o`02ooooo`?o000000?oooooo`000?ooool00ol00003ooooo`;o000000Koooooo`000?l0003o0000
oa0@4?l00002ooooo`;o00000_ooool2o`000004ooooool0003oooooo`0000?ooooo2Ol00002oooo
o`;o000000?oooooo`000?l000002Ol000001Ooooooo0000o`000?oooooo000000?ooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo0_l0000@ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0H_ooool009;ooooo0_l00004ooooo`?o000000?ooooo
o`000?l000000ol00003ooooo`Ko000000GoMgMgo`000?ooooooV9RHo`000002ooooo`;o00000_oo
ool2o`0000?ooooo3?l000000ooooooo0000ooooo`09o`000003ooooool0003ooooo00;o000000?o
ooooo`000?ooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0
0oooool2o`00013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Rooooo`00T_oo
ool2o`0000Cooooo1_l000000ooooooo0000o`000002ooooo`Ko000000?oooooo`000?lb<S800ol0
00000ooooooo0000o`000003ooooo`04o`000?ooooooooooooooo`;o000000Ooooooo`000?l0003o
0000ooooool0003ooooo00;o00000_oooolAo`000003ooooool0003ooooo00;ooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo0_l0000@ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0H_ooool0097ooooo00?o0000ooooool000001?ooool9o`00
00;ooooo0ol000001?oooooo0000o`000?l00002ooooo`;o000000?oooooo`000?l000000oooool2
o`0000;ooooo0_l000000ooooooo0000o`000007o`0000;ooooo4Ol000000ooooooo0000ooooo`02
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`03ooooo`;o00004?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06;ooooo002Aooooo`03o`000?oooooo
000000Cooooo2Ol00002ooooo`03o`000?oooooo000000;o000000?oooooo`000?ooool00_l00000
0ooooooo0000o`000003ooooo`04o`000?oooooo0000ooooo`;o000000?oooooo`000?ooool02Ol0
0002oooooa3o000000?oooooo`000?ooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool00oooool2o`00013ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1Rooooo`00T?ooool01?l0003oooooooooool00004ooooo`Wo00000_ooool2o`000004oooo
ool0003o0000o`0000;ooooo00Co0000ooooool0003o00000oooool01Ol0003oooooooooool0003o
oooo00?o000000Coooooo`000?l0003o00001?ooool3o`0000;ooooo4?l000001?oooooo0000oooo
ooooool2o`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`;o0000
4?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06;ooooo002@ooooo`04o`000?oo
ooooooooo`0000Cooooo2Ol000001Ooooooo0000o`000?l0003ooooo00?o000000Coooooo`000?l0
003ooooo0_l00002ooooo`;o00000_ooool4o`000004ooooool0003o0000o`0000Kooooo0_l00002
oooooa3o000000Coooooo`000?oooooooooo0_l00003ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool2o`00013ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1Rooooo`00Soooool01?l0003oooooooooool00004ooooo`[o000000Goooooo`000?l0003o0000
ooooo`02o`0000;ooooo1?l00002ooooo`;o00000oooool3o`000003ooooool0003o000000;o0000
1_ooool2o`0000;ooooo4_l00002ooooo`;o00000oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo0_l0000?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
H_ooool008oooooo00Co0000oooooooooooo00001?ooool:o`000003ooooool0003o000000Co0000
00?oooooo`000?l000000_l00002ooooo`;o00001?ooool00ol0003oooooo`000004o`0000Sooooo
00?o0000ooooooooool04_l00002ooooo`;o00000oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo0_l0000?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
Hoooool008kooooo00Go0000ooooooooooooooooo`000004ooooo`[o000000Coooooo`000?l0003o
oooo0_l00002ooooo`Co000000?oooooo`000?l000001?ooool7o`0000Wooooo00?o0000oooooooo
ool04_l00002ooooo`;o00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo0_l0000?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Hoooool008kooooo
00Go0000ooooooooooooooooo`000004ooooo`_o000000?oooooo`000?ooool00_l000000ooooooo
0000o`000002o`000003ooooool0003o000000Cooooo00?o0000ooooool000001?l00003ooooo`Co
00000oooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000002ol00002ooooo`;o
00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo0_l0000?ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0Hoooool008gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`go000000Goooooo`000?l0003o0000ooooo`04o`000003
ooooool0003ooooo00?ooooo0ol000000ooooooo0000o`000004ooooo`03o`000?oooooooooo00Ko
000000?oooooo`000?l000000_l000000ooooooo0000o`00000;o`0000;ooooo0_l00003ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool2o`0000oooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`1Sooooo`00SOooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo5Ol000000ooooooo0000ooooo`03ooooo`Oo00000_ooool2o`000004oooo
ool0003o0000ooooo`;o000000?oooooo`000?l000001Ol000000ooooooo0000o`00000;o`0000;o
oooo0_l00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool2o`0000oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Sooooo`00S?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo2Ol000001?oooooo0000o`000?ooool2o`000003
ooooool0003ooooo00;o000000?oooooo`000?ooool00oooool3o`000004ooooool0003o0000o`00
00?ooooo00?o0000ooooool000001?ooool00ol0003oooooo`00000Do`0000;ooooo0_l00003oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00000?oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Hoooool008cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`Wo000000Coooooo`000?l0003ooooo0ol000001Ooo
oooo0000o`000?oooooo000000Cooooo00?o0000ooooool000001?l00003ooooo`03o`000?oooooo
000000Gooooo0_l000000ooooooo0000o`00000Bo`0000;ooooo0_l00003ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00000?ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0Hoooool008_ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`Wo000000Coooooo`000?l0003ooooo0ol000001Ooooooo0000o`000?oo
oooo000000?ooooo00?o0000ooooool000001?l00003ooooo`03o`000?oooooooooo00Oo000000?o
ooooo`000?l000001ol000000ooooooo0000o`000009o`0000;ooooo0_l00003ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00000?ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0Hoooool008_ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`co000000Soooooo`000?l0003o0000ooooool0003oooooo`0000?o
oooo00?o0000ooooool000001Ol00002ooooo`03o`000?oooooooooo00Wo000000?oooooo`000?l0
00004_l00002ooooo`;o00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooool000003oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06?o
oooo002:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool2o`000003oooo
ool0003o000000[o000000Coooooo`000?l0003o00001?ooool00ol0003oooooo`000003o`000004
ooooool0003oooooo`0000;ooooo00Go0000ooooool0003o0000ooooo`03o`000003ooooool0003o
oooo00;o000000?oooooo`000?l000003ol00002ooooo`;o00000oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000003oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo06?ooooo002:ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool2o`000003ooooool0003o000000[o000000?oooooo`000?l000001?ooool00ol0
003oooooo`000003o`0000;ooooo00Ko0000ooooool0003oooooo`000?oooolBo`000003ooooool0
003o000000Wo00000_ooool2o`0000?ooooo00Ko0000oooooooooooo0000ooooool00004ooooo`03
o`000?oooooo000000oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Sooooo`00
ROooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo0_l000000ooooooo0000
o`000006o`000003ooooool0003o000000;ooooo0_l00003ooooo`Ko00000oooool2o`0000;ooooo
4_l000000ooooooo0000ooooo`0;o`0000;ooooo0_l00003ooooo`03o`000?oooooo000000?o0000
0oooool01?l0003oooooooooool0000?ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0Hoooool008Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`ko0000
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000;o00001?ooool2o`000003oooo
ool0003o000000Go000000?oooooo`000?l000002ol000000ooooooo0000o`000009o`0000;ooooo
0_l00003ooooo`04o`000?oooooo0000ooooo`;o00000oooool01?l0003oooooooooool0000?oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Hoooool008Sooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`03ooooo`ko000000?oooooo`000?l000000oooool5o`0000Co
oooo0_l000000ooooooo0000ooooo`03o`000003ooooool0003o000000ko000000?oooooo`000?l0
00002Ol00002ooooo`;o00000oooool01?l0003oooooo`000?ooool2o`0000?ooooo00Co0000oooo
oooooooo00003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06Cooooo0028oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00ooooolAo`0000?ooooo00?o0000oooo
ool000000_l00003ooooo`05o`000?oooooo0000o`000?ooool03ol000000ooooooo0000o`000003
o`000003ooooool0003o000000Wo00000_ooool2o`0000?ooooo00?o0000ooooool000000_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo06Cooooo0027ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool00ooooolAo`0000?ooooo1?l00004ooooo`04o`000?oooooo0000ooooo`Wo000000?o
ooooo`000?l000001?l000000ooooooo0000o`000003o`000003ooooool0003o000000Wo00000_oo
ool2o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?ooool00_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0I?ooool008Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`03ooooo`So000000?oooooo`000?l000000ol00000
0ooooooo0000o`000002ooooo`Co00001?ooool00ol0003oooooo`000006o`000003ooooool0003o
000000Wo000000?oooooo`000?l000000ol000000ooooooo0000o`000009o`0000;ooooo0_l00003
ooooo`;o00000oooool4o`0000?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo06Cooooo0026ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01?ooool8o`000003ooooool0003o000000Go00000oooool3o`0000Cooooo00Co0000oooo
ool0003ooooo1Ol000001Ooooooo0000o`000?l0003ooooo00ko000000?oooooo`000?l000002Ol0
0002ooooo`;o00000oooool2o`0000;ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0I?ooool008Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`04ooooo`go000000?oooooo`000?l000000oooool3
o`0000?ooooo00Co0000ooooool0003ooooo0ol000000ooooooo0000o`000005o`000003ooooool0
003o000000_o000000?oooooo`000?l000002Ol00002ooooo`;o00000oooool2o`0000;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0I?ooool008Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04
ooooo`go000000?oooooo`000?l000000_ooool3o`0000Cooooo00?o0000ooooool000006_l00000
0ooooooo0000o`000009o`0000;ooooo0_l00003ooooo`;o00000_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1T
ooooo`00QOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo3Ol000000ooo
oooo0000o`000002ooooo`?o00000oooool01?l0003oooooo`000?ooool;o`000003ooooool0003o
000000co000000?oooooo`000?l000002Ol00002ooooo`;o00000oooool2o`0000;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0I?ooool008Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04oooo
o`Wo000000?oooooo`000?l000001?l000001?oooooo0000o`000?l00003ooooo`04o`000?oooooo
0000ooooo`Ko000000?oooooo`000?l000001?l000000ooooooo0000o`00000;o`000003ooooool0
003o000000Wo00000_ooool2o`0000?ooooo0_l00002ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06Cooooo0023
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00ooooolAo`000004ooooool0003o
0000o`0000?ooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000;o000000?o
ooooo`000?l000003ol000000ooooooo0000o`000009o`0000;ooooo0_l00003ooooo`;o00000_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1Tooooo`00Poooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00?ooooo4?l00002ooooo`?o00000_ooool2o`000003ooooool0003o000000_o000000?ooooo
o`000?l000003Ol000000ooooooo0000o`000009o`0000;ooooo0_l00003ooooo`;o00000_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1Tooooo`00P_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00;ooooo4Ol000000ooooooo0000o`000002o`0000;ooooo00?o0000ooooool000001?l000001Ooo
oooo0000o`000?l0003ooooo00?o000000?oooooo`000?l000003_l000000ooooooo0000o`000009
o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?ooool01_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0I?ooool008;ooooo00?o0000oooo
ooooool02oooool01_l0003ooooooooooooooooo0000ooooo`Go000000?oooooo`000?l000002?l0
00001?oooooo0000o`000?l00002ooooo`Oo00000_ooool2o`000005ooooool0003o0000o`000?oo
ool04Ol000000ooooooo0000o`000009o`0000;ooooo0_l00003ooooo`04o`000?ooooooooooo`00
00Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
06Gooooo0021ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`000002oooo
o`Go000000?oooooo`000?l000001Ol000001?oooooo0000o`000?ooool3o`0000;ooooo1Ol00000
0ooooooo0000ooooo`09o`000003ooooool0003o000000go000000?oooooo`000?l000002Ol00002
ooooo`;o00000oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`1Uooooo`00P?ooool00ol0003oooooooooo`0<
ooooo`04o`000?oooooo0000o`0000?ooooo1Ol000000ooooooo0000o`000008o`000005ooooool0
003o0000o`000?ooool00_l000000ooooooo0000o`000006o`000005ooooool0003o0000o`000?oo
ool01?l000000ooooooo0000o`00000;o`000003ooooool0003o000000Wo000000Coooooo`000?oo
oooo00000_ooool2o`0000;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0IOooool0083ooooo00?o0000oooooooo
ool03?ooool2o`0000Gooooo1Ol000000ooooooo0000o`00000<o`000003ooooool0003o000000co
000000?oooooo`000?l000004Ol000000ooooooo0000o`00000;o`000004ooooool0003ooooooooo
o`;o000000?oooooo`000?ooool01oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0IOooool007oooooo00?o0000ooooooooool03?ooool2o`0000Ko
oooo1Ol000000ooooooo0000o`00000;o`000003ooooool0003o000000So000000?oooooo`000?l0
00001_l000000ooooooo0000o`00000=o`000003ooooool0003o000000Wo000000Coooooo`000?l0
003o00000_ooool4o`0000Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo06Gooooo001oooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo
0000ooooo`05ooooo`Go000000?oooooo`000?l000005_l000000ooooooo0000o`000003o`000004
ooooool0003o0000ooooo`oo000000?oooooo`000?l000002Ol000000ooooooo0000ooooo`06o`00
00Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
06Gooooo001nooooo`03o`000?oooooooooo00Oooooo1?l00003ooooo`03o`000?oooooooooo00Co
oooo1Ol000000ooooooo0000o`000008o`000003ooooool0003o000000[o000000?oooooo`000?l0
00001_l00003ooooo`ko000000?oooooo`000?l000001ol000001ooooooo0000ooooool0003ooooo
o`000?ooool00_l0000;ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1Uooooo`00OOooool00ol0003oooooooooo`04ooooo`Co00001oooool00ol0
003oooooooooo`04ooooo`Go000000?oooooo`000?l000005?l000000ooooooo0000o`000007o`00
00;ooooo3ol000000ooooooo0000o`000007o`000005ooooool0003o0000ooooool000000oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00kooooo00Go0000ooooooooooooooooo`00
001Xooooo`002?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0[ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02gooooo1?l000001?l@413o
ooooooooooo^k^h2o`000003oc8b<_o^k^kooooo00Sooooo00?o0000ooooooooool01?ooool00ol0
003oooooo`000002o`000003ooooool0003o000001Co000000?oooooo`000?ooool01_l00002oooo
oa3o000000?oooooo`000?l000001?l000001?oooooo0000o`000?ooool2o`000003ooooool0003o
oooo00;ooooo00?o0000ooooooooool01_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h7ooooo`05o`000?ooooooooooooooool000007oooool5o`0000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0/ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo0008ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RH
oooooonHV9SoMgMg02_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0;Oooool3o`0000?ooooo0_l000001?nHV9SooooooiRHV?mgMgL9ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooool000000_l000000ooooooo0000o`00000Co`000003ooooool0
003o000000Ko00000_ooool2o`000003ooooool0003o000000co000000?oooooo`000?l000001ol0
00001Ooooooo0000o`000?oooooo000000?ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01oooool01Ol0003ooooooooooooooooo0000
01oooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0;?oo
ool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00
1_l00006ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Qooooo`Ko
00000oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41009?ooool6o`00
0003ooooool0003o000000;ooooo00Ko0000oooooooooooo0000ooooool@4103ooooo`03oa0@4?oo
oooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000002o`000003ooooool0
003o000001co000000Goooooo`000?oooooo0000ooooo`0>o`000003ooooool0003o000000Oo0000
00Goooooo`000?ooooooooooo`000002ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@00Oooooo00Co0000oooooooooooo00008Oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@4100<?ooool01Ol0003ooooooooo
oooooooo410@00?ooooo00?o410@ooooooooool00Oooool000_ooooo00?oZJVYoa0@4?ooool00_oo
ool01Ol0003ooooooooooooooooo000002gooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooo
oooooooooooo000002Oooooo1?l00004ooooo`03o`000?oooooo000000;ooooo00Go0000oooooooo
ooooooooo`000009ooooo`03o`000?oooooooooo00Cooooo1Ol000000ooooooo0000o`00000Ho`00
0004ooooool0003o0000ooooo`;o000000?oooooo`000?l000006_l00002ooooo`04o`000?oooooo
ooooo`0000_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Oooooo
00Co0000oooooooooooo00008_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooooooooooo
ool00000;oooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool0
00[ooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000002kooooo00?oMgMg
ofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000002;ooooo1_l00007ooooo`;o00000ooo
ool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool01?ooool5o`000003oooo
ool0003o000001_o000000?oooooo`000?ooool04Ol000000ooooooo0000o`000009o`0000;ooooo
00Co0000oooooooooooo00002_ooool2o`0000Cooooo00Go0000ooooooooooooooooo`000007oooo
o`04o`000?ooooooooooo`0002?ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooo
oooo000002kooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000000?ooooo
000;ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@400_ooooo`05o`00
0?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Mooooo`?o00003Oooool00ol0003o
ooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002Oooool00ol0003oooooooooo`04oooo
ob;o00000_ooool00ol0003oooooo`00000:o`000003ooooool0003o000000go000000Koooooo`00
0?ooooooooooo`000?ooool2o`0000[ooooo0_l00004ooooo`05oa0@4?ooooooooooooooool@4100
1oooool01?l0003oooooooooool0000Tooooo`05o`000?ooooooooooooooool@41000oooool00ol@
413oooooooooo`0]ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4003
ooooo`002?ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0[ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01ko
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02Oooool00ol0003oooooooooo`04ooooo`ko000000?oooooo`000?l000002Ol000001Ooo
oooo0000o`000?l0003ooooo00;o00000_ooool2o`000003ooooool0003o000001Wo000000Kooooo
o`000?ooooooooooo`000?ooool2o`0000[ooooo0_l00004ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01oooool00ol0003oooooo`00000Qooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg02cooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool000Sooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0:oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Mooooo`03o`000?oooooooooo00gooooo00?oEEEEo`000?l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Wooooo00?o0000ooooooooool01?ooool>o`000003ooooool0
003o000000_o000000?oooooo`000?l000000_l00002ooooo`03o`000?oooooo000001_o000000Oo
ooooo`000?ooooooooooo`000?oooooo000000[ooooo00?oEEEEo`000?l000001?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Kooooo00Co0000oooooooooooo00008Oooool01OnHV9So410@o`000?lQ
8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0/ooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo001Yooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`04ooooo`_o000000Coooooo`000?l0
003ooooo3_l000001?oooooo0000o`000?l00002ooooo`03o`000?oooooo000001_o000000Cooooo
o`000?oooooo00000_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00kooooo00Co
0000oooooooooooo0000J_ooool006Sooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo00;ooooo4?l000000ooooooo0000o`000007o`000003ooooool0
003o000000Go00000oooool00ol0003oooooo`00000?o`000003ooooool0003o000000Oo000000Oo
ooooo`000?oooooo0000ooooool0003ooooo00;o00002oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooo000006_ooooo001Wooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
4oooool01?l0003ooooooooooooooolAo`000003ooooool0003o000000oo00000oooool2o`0000;o
oooo2_l000000ooooooo0000o`00000;o`000003ooooool0003o000000;ooooo00Co0000ooooool0
003o00002_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo000006_ooooo001Wooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool04oooool5o`000003ooooool0003o000001[o
00000_ooool3o`0000?ooooo3_l000001Ooooooo0000o`000?l0003ooooo00Wo000000?oooooo`00
0?l000000_ooool01?l0003oooooo`000?l0000:ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooool00000Joooool006Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Boooo
o`;o00000_ooool00ol0003oooooooooo`0Fo`000003ooooool0003ooooo00So00000oooool2o`00
0003ooooool0003o000000go000000?oooooo`000?l000001ol000000ooooooo0000o`000002oooo
o`04o`000?oooooo0000o`0000[ooooo00?o0000ooooooooool03oooool00ol0003oooooo`00001[
ooooo`002oooooooo`0005Ko00002?ooool000_ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooooooo
ool000002oooool00ol0003oooooooooo`02ooooo`;o000000Coooooo`000?oooooooooo4Ol00000
0ooooooo0000o`00000:o`000005ooooool0003o0000ooooool000001oooool:o`000005ooooool0
003o0000o`000?ooool01_l000001?oooooo0000o`000?ooool2o`0000;ooooo0ol00005ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`?o
00002?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01_ooool000_ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo013ooooo00Go0000ooooooooooooooooo`00000?ooooo`05o`000?oooooo0000oooo
ool000000oooool00ol0003oooooo`00000;o`000003ooooool0003o000000Wo000000Coooooo`00
0?oooooooooo1?l00006oooooaKo000000Coooooo`000?l0003ooooo0_l000001Ooooooo0000o`00
0?oooooo000000_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooo000002[ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`06ooooo`00IOoo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00Co0000ooooool0003o0000
0ooooolKo`000004ooooool0003oooooooooo`Go00000oooool=o`000003ooooool0003o000000So
000000Coooooo`000?l0003ooooo0_l000001Ooooooo0000oooooooooooo000000[ooooo00?o0000
ooooooooool03oooool2o`0006gooooo001Tooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04Oooool01?l0003oooooo`000?l00003ooooo`_o000000?oooooo`000?l000003Ol00000
1_oooooo0000oooooooooooo0000oooooa?o000000?oooooo`000?l000002?l000001?oooooo0000
o`000?ooool4o`0000;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0?ooooo`;o
0000KOooool006Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Booooo`04o`00
0?oooooo0000o`0000;ooooo7_l00002ooooo`_o000000?oooooo`000?l000001ol000000ooooooo
0000o`000008o`000004ooooool0003o0000ooooo`;o000000Goooooo`000?ooooooooooo`00000:
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0K?ooool006Cooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000?ooooo2?l00000
0ooooooo0000o`00000Co`0000?ooooo0ol000000ooooooo0000o`000004o`000003ooooool0003o
000000Oo000000?oooooo`000?l000003_l000001?oooooo0000ooooool0000;ooooo`03o`000?oo
oooooooo00kooooo0_l0001^ooooo`00Hoooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo017ooooo00Co0000oooooooooooo00000oooool2o`000003ooooool0003o000001Go000000Co
ooooo`000?l0003o00000oooool9o`000003ooooool0003o000001Ko000000Ooooooo`000?l0003o
ooooo`000?oooooo000000[ooooo00?o0000ooooooooool03Oooool2o`000003ooooool0003ooooo
06gooooo001Sooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000ooooool0003ooooo2Ol000000ooooooo0000o`00000;
o`000004ooooool0003o0000o`0000;ooooo0_l000000ooooooo0000ooooo`04o`000003ooooool0
003o000000So000000?oooooo`000?l000003?l000001ooooooo0000o`000?oooooo0000ooooool0
00002_ooool00ol0003oooooooooo`0;ooooo`;o00000oooool00ol0003oooooooooo`1/ooooo`00
Hoooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00Go0000oooooooooooo
ooooo`000002ooooo`?o000000?oooooo`000?l000001ol000000ooooooo0000o`00000;o`000003
ooooool0003ooooo00Co00000_ooool?o`000003ooooool0003ooooo00ko000000Ooooooo`000?l0
003oooooo`000?oooooo000000Wooooo00?o0000ooooooooool02?ooool4o`0000Cooooo00?o0000
ooooooooool0KOooool006?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aoooo
o`05o`000?ooooooooooooooool000000_ooool3o`000003ooooool0003o000000Oo000000?ooooo
o`000?l000002ol000000ooooooo0000ooooo`03o`0000?ooooo3ol000000ooooooo0000ooooo`05
o`000003ooooool0003o000000[o00000_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00?ooooo1Ol00008ooooo`03o`000?oooooooooo06gooooo001Rooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`02o`0000;ooooo0ol000000ooo
oooo0000o`000007o`000003ooooool0003o000000_o000000?oooooo`000?ooool05Ol000000ooo
oooo0000ooooo`05o`000003ooooool0003o000000Oo000000?oooooo`000?l000000_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo0_l0000=ooooo`03o`000?oooooooooo
06gooooo001Rooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool01?l0003o
ooooooooooooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000001ol000000ooo
oooo0000o`00000;o`000004ooooool0003oooooooooo`_o000000?oooooo`000?l000001_l00000
0ooooooo0000o`000005o`000003ooooool0003o000000Oo000000Goooooo`000?l0003oooooo`00
0009ooooo`03o`000?oooooooooo00;o00003oooool00ol0003oooooooooo`1]ooooo`00H_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00Co0000oooooooooooooooo0_l0
00001?oooooo0000o`000?l00002ooooo`Wo000000?oooooo`000?l000002ol000000ooooooo0000
o`00000=o`000003ooooool0003ooooo00Co000000Coooooo`000?l0003ooooo0ol000000ooooooo
0000o`000005o`000005ooooool0003o0000o`000?ooool00_l000000ooooooo0000ooooo`08oooo
o`?o00004Oooool00ol0003oooooooooo`1]ooooo`00H_ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo017ooooo00Co0000oooooooooooooooo0_l000001?oooooo0000o`000?l00002
ooooo`Wo000000?oooooo`000?l000002ol000001Ooooooo0000o`000?l0003ooooo00Wo000000?o
ooooo`000?l000003Ol000000ooooooo0000o`000005o`000005ooooool0003o0000o`000?ooool0
0_l000000ooooooo0000ooooo`07ooooo`;o00004oooool00ol0003oooooooooo`1]ooooo`00H_oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00Oo0000oooooooooooo0000
ooooool0003ooooo00?o00000_ooool9o`000003ooooool0003o000000ko000000?oooooo`000?oo
ool01Ol00002ooooo`Ko000000Goooooo`000?l0003o0000ooooo`0>o`000005ooooool0003o0000
o`000?ooool00_l000000ooooooo0000ooooo`06ooooo`03o`000?oooooo000001?ooooo00?o0000
ooooooooool0KOooool006;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@oooo
o`06o`000?ooooooooooooooool0003ooooo1Ol00002ooooo`Wo000000?oooooo`000?l000006?l0
00000ooooooo0000o`000002ooooo`Go000000?oooooo`000?l000003?l000001Ooooooo0000oooo
ool0003ooooo00;o000000?oooooo`000?ooool01Oooool00ol0003oooooo`00000Cooooo`03o`00
0?oooooooooo06kooooo001Qooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?oo
ool01_l0003ooooooooooooooooo0000ooooo`Go00000_ooool9o`000003ooooool0003o000000co
000000?oooooo`000?ooool00_l000001?oooooo0000o`000?l00002ooooo`?o00000_ooool6o`00
0003ooooool0003ooooo00co000000Goooooo`000?oooooo0000ooooo`02o`000003ooooool0003o
oooo00Cooooo00?o0000ooooool000005?ooool00ol0003oooooooooo`1^ooooo`00HOooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00Ko0000ooooooooooooooooo`000?oo
ool5o`0000;ooooo2Ol000000ooooooo0000o`00000>o`000004ooooool0003oooooo`0000;ooooo
1?l00003ooooo`Go000000Goooooo`000?l0003o0000ooooo`02o`000003ooooool0003o000000Oo
000000Soooooo`000?oooooo0000ooooool0003oooooo`0000Kooooo0_l0000Eooooo`03o`000?oo
oooooooo06kooooo001Qooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool0
1_l0003ooooooooooooooooo0000ooooo`?o000000Coooooo`000?oooooooooo2Ol000000ooooooo
0000o`00000Ao`0000;ooooo1?l00003ooooo`Oo000000?oooooo`000?l000000ol000000ooooooo
0000o`000007o`000008ooooool0003oooooo`000?oooooo0000ooooool00004ooooo`;o000000?o
ooooo`000?ooool05?ooool00ol0003oooooooooo`1^ooooo`00HOooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo013ooooo00Ko0000ooooooooooooooooo`000?ooool3o`000004oooo
ool0003oooooooooo`Wo000000?oooooo`000?l000004?l000000ooooooo0000o`000003o`000003
ooooool0003o000000;o000000Ooooooo`000?l0003o0000ooooool0003ooooo00Go000000?ooooo
o`000?l000001ol000002?oooooo0000ooooool0003oooooo`000?oooooo00000oooool01?l0003o
ooooooooool0000Fooooo`03o`000?oooooooooo06kooooo001Qooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool04Oooool01_l0003ooooooooooooooooo0000ooooo`?o000000Cooooo
o`000?oooooooooo1Ol000001Ooooooo0000o`000?l0003ooooo01Co000000?oooooo`000?l00000
0_l000000ooooooo0000o`000005o`000003ooooool0003o000000Go000000?oooooo`000?l00000
1ol000000ooooooo0000ooooo`03o`000003ooooool0003ooooo00;o00000_ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo06oooooo001Qooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000?o00000ooo
ool5o`000005ooooool0003o0000o`000?ooool03?l000000ooooooo0000o`000003o`0000;ooooo
0ol000000ooooooo0000o`000002o`000003ooooool0003o000000?o000000Goooooo`000?l0003o
0000ooooo`0<o`000003ooooool0003ooooo00?o000000?oooooo`000?l000001?ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo06oooooo001Qooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo0000ooooo`;o
00000oooool5o`000005ooooool0003o0000o`000?ooool04Ol00002ooooo`;o000000?oooooo`00
0?l000001Ol000001_oooooo0000o`000?oooooo0000ooooo`?o000000?oooooo`000?l000002_l0
00000ooooooo0000ooooo`04o`0000Gooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`1_ooooo`00HOooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?oooooo0000o`0000?ooooo1Ol000000ooooooo0000
o`00000Bo`000003ooooool0003o000000;ooooo1?l000001?oooooo0000ooooooooool2o`000003
ooooool0003o000000Co000000?oooooo`000?l000002_l000000ooooooo0000o`000004o`0000Co
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1_ooooo`00H?ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo013ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?oooooo0000o`0000?ooooo1Ol000000ooooooo0000o`00000@o`000004ooooool0003o0000
o`0000;ooooo1_l00002ooooo`;o000000Coooooo`000?l0003ooooo0ol00002ooooo`ko000000Go
ooooo`000?l0003oooooo`000004ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
Koooool0063ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`05o`000?oo
ooooooooooooool000000_ooool4o`0000?ooooo1Ol000000ooooooo0000o`000008o`000003oooo
ool0003o000000Oo00000oooool5o`0000?ooooo0_l00002ooooo`;o000000Goooooo`000?l0003o
0000ooooo`06o`000003ooooool0003o000000[o00001?ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo073ooooo001Pooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4?ooool01Ol0003ooooooooooooooooo000000;ooooo1?l00003ooooo`Go000000?oooooo`000?l0
00004?l00003ooooo`Ko00000_ooool3o`0000;ooooo0_l000000ooooooo0000o`000002o`000003
ooooool0003o000000Co000000?oooooo`000?l000002_l00004ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool0L?ooool0063ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0@ooooo`05o`000?ooooooooooooooool000000_ooool4o`0000?ooooo1Ol000000ooooooo
0000o`00000Go`000003ooooool0003o000000?o00000_ooool2o`0000;ooooo0ol00002ooooo`Ko
000000?oooooo`000?l000000ol000000ooooooo0000o`000004o`0000?ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`1`ooooo`00H?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo017ooooo00Ko0000ooooooooooooooooo`000?ooool5o`0000?ooooo1Ol000000ooo
oooo0000o`00000Fo`000003ooooool0003o000000;o00000_ooool3o`0000;ooooo1?l00002oooo
o`co000000?oooooo`000?l000000ol00003ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool0L?ooool0063ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`06
o`000?ooooooooooooooool0003ooooo1Ol00003ooooo`Go000000?oooooo`000?l000004?l00000
0ooooooo0000o`000007o`000005ooooool0003o0000ooooool000000_ooool00ol0003oooooo`00
0002o`0000;ooooo1_l000000ooooooo0000o`000003o`000003ooooool0003o000000?o00000ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo077ooooo001Oooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool04Oooool01_l0003ooooooooooooooooo0000ooooo`Go0000
0oooool5o`000003ooooool0003o000000oo000000Ooooooo`000?l0003o0000ooooool0003ooooo
00?o000000Goooooo`000?ooooooooooo`000003ooooo`Co00000_ooool7o`000003ooooool0003o
000000?o000000?oooooo`000?l000000ol00002ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool0LOooool005oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aoooo
o`06o`000?ooooooooooooooool0003ooooo1Ol00003ooooo`Go000000Goooooo`000?l0003o0000
ooooo`08o`000003ooooool0003o000000?o000000?oooooo`000?ooool00ol00002ooooo`;o0000
00?oooooo`000?l000000oooool5o`0000;ooooo1ol000000ooooooo0000o`000003o`000003oooo
ool0003o000000;o00000oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo077ooooo
001Oooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool01_l0003ooooooooo
oooooooo0000ooooo`Go00000oooool9o`000003ooooool0003o000000?o000000Coooooo`000?l0
003ooooo0_l000000ooooooo0000o`000005o`0000;ooooo1?l00005ooooo`03o`000?oooooo0000
00;o000000Goooooo`000?l0003o0000ooooo`04o`000003ooooool0003o000000?o000000?ooooo
o`000?l000000_l00002ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0L_ooool0
05oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooool000001?l00003ooooo`Wo000000?oooooo`000?l000001_l00002oooo
o`Oo00000oooool01?l0003oooooo`000?l00005ooooo`03o`000?oooooo000000;o00000_ooool3
o`000004ooooool0003o0000o`0000;ooooo1Ol000000ooooooo0000o`000002o`0000;ooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`1booooo`00Goooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000004
o`0000?ooooo2Ol000001ooooooo0000o`000?l0003oooooo`000?ooool00_l00002ooooo`;o0000
1oooool4o`0000Cooooo1ol000001Ooooooo0000o`000?l0003ooooo00;o000000Coooooo`000?oo
oooooooo1Ol000000ooooooo0000o`000002o`000003ooooool0003ooooo01[ooooo00?o0000oooo
ooooool0L_ooool005oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooool000001?l00003ooooo`Wo000000Ooooooo`000?l0
003o0000ooooool0003ooooo00;o00000_ooool3o`0000Gooooo0_l00002ooooo`03o`000?oooooo
oooo00[o000000Coooooo`000?l0003ooooo0_l000001?oooooo0000ooooooooool5o`000003oooo
ool0003ooooo00?o00006oooool00ol0003oooooooooo`1cooooo`00Goooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00
0004o`0000?ooooo1Ol000001Ooooooo0000o`000?l0003ooooo00?o000000?oooooo`000?ooool0
0_l00003ooooo`?o000000?oooooo`000?l000000_l00003ooooo`04o`000?oooooo0000ooooo`?o
000000?oooooo`000?ooool00_l000001Ooooooo0000o`000?l0003ooooo00Co00000_ooool5o`00
0003ooooool0003ooooo00?o00006oooool00ol0003oooooooooo`1cooooo`00Goooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooo`000004o`0000?ooooo1Ol000001Ooooooo0000o`000?l0003ooooo00Go000000Coooooo`00
0?l0003o00000_ooool5o`000003ooooool0003ooooo00?ooooo1_l000000ooooooo0000ooooo`02
o`000003ooooool0003ooooo00;o000000?oooooo`000?l000000_l00002ooooo`Go000000?ooooo
o`000?ooool00_l0000Looooo`03o`000?oooooooooo07?ooooo001Oooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo0000
00Co00000oooool5o`000005ooooool0003o0000o`000?ooool01Ol000001?oooooo0000o`000?l0
0003ooooo`Go00001Oooool4o`000004ooooool0003o0000ooooo`;o00000_ooool00ol0003ooooo
o`000002ooooo`Co00000_ooool5o`000003ooooool0003o000000;o00006oooool00ol0003ooooo
ooooo`1dooooo`00Goooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool00_ooool00ol0003oooooo`000004o`0000?ooooo1Ol000001Ooooooo0000o`00
0?l0003ooooo00Wo00003?ooool4o`000004ooooool0003o0000ooooo`;o00000_ooool01?l0003o
ooooo`000?l00002ooooo`;o000000Coooooo`000?oooooooooo1Ol000000ooooooo0000o`000002
o`0001[ooooo00?o0000ooooooooool0MOooool005oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000001?l00003oooo
o`Go000000Goooooo`000?l0003o0000ooooo`06o`000003ooooool0003o000000_ooooo1?l00000
1?oooooo0000o`000?ooool2o`0000?ooooo00Co0000ooooool0003o00000_ooool2o`000003oooo
ool0003ooooo00Go00000_ooool4o`0001[ooooo00?o0000ooooooooool0MOooool005oooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooool000001?l00003ooooo`Go000000Goooooo`000?l0003o0000ooooo`06o`000004oooo
ool0003o0000o`0000Wooooo00Go0000ooooool0003o0000ooooo`05o`0000?ooooo00?o0000oooo
ooooool00_l000000ooooooo0000o`000003o`000003ooooool0003o000000?o000000?oooooo`00
0?l000000_l0000Jooooo`03o`000?oooooooooo07Kooooo001Oooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Co
00000oooool5o`000005ooooool0003o0000o`000?ooool01_l000001?oooooo0000o`000?l00008
ooooo`04o`000?oooooo0000ooooo`Ko00000oooool01Ol0003ooooooooooooooooo000000;ooooo
2ol000000ooooooo0000o`000002o`0001[ooooo00?o0000ooooooooool0M_ooool005oooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooool000001?l00003ooooo`Go000000Goooooo`000?l0003o0000ooooo`06o`000004oooo
ool0003o0000o`0000Kooooo0_l000000ooooooo0000o`000002o`000004ooooool0003oooooo`00
00?ooooo00Co0000oooooooooooooooo0_l00002ooooo`Co000000?oooooo`000?l000001?l00000
0ooooooo0000o`000002o`0001Wooooo00?o0000ooooooooool0Moooool005kooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ool000001?l00003ooooo`Go000000?oooooo`000?l000002?l000000ooooooo0000o`000002o`00
00Cooooo0_l000001Ooooooo0000o`000?l0003ooooo00Co00000oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?o000000?oooooo`000?ooool01?l000000ooooooo0000ooooo`04
o`0001Wooooo00?o0000ooooooooool0Moooool005kooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000001?l00003oooo
o`Go000000?oooooo`000?l000002Ol000001?oooooo0000o`000?l00003ooooo`Ko00000_ooool3
o`0000;ooooo0_l00004ooooo`;o00000_ooool3o`000004ooooool0003o0000ooooo`?o000000?o
ooooo`000?l000001?l0000Hooooo`03o`000?oooooooooo07Sooooo001Nooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
0000ooooo`?o00000oooool5o`000003ooooool0003o000000Wo000000?oooooo`000?l000000_l0
00000ooooooo0000o`000004o`0000;ooooo0ol00002ooooo`03o`000?oooooooooo00Cooooo00Co
0000oooooooooooooooo1_l000001Ooooooo0000o`000?l0003ooooo00Ko00006?ooool00ol0003o
ooooooooo`1hooooo`00G_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool00_ooool01?l0003oooooo`000?ooool3o`0000?ooooo1Ol000000ooooooo
0000o`00000Do`000003ooooool0003o000000;o00000_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;o000000Coooooo`000?l0003o00000_ooool3o`000003ooooool0003ooooo
00;o000000?oooooo`000?ooool05_ooool00ol0003oooooooooo`1iooooo`00G_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00_ooool01?l0003o
ooooo`000?ooool3o`0000?ooooo1Ol000000ooooooo0000o`000008o`000003ooooool0003o0000
00Oo000000?oooooo`000?l000001?l000000ooooooo0000ooooo`06ooooo`04o`000?oooooooooo
ooooo`?o000000?oooooo`000?l000000_ooool8o`000003ooooool0003ooooo01Gooooo00?o0000
ooooooooool0N_ooool005kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00;ooooo00Co0000ooooool0003ooooo0ol00003ooooo`Go000000?ooooo
o`000?l000002Ol00002ooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`;o00001ooo
ool2o`0000?ooooo0ol000000ooooooo0000o`000002ooooo`So000000?oooooo`000?ooool04ooo
ool2o`0007gooooo001Nooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`02ooooo`04o`000?oooooo0000ooooo`;o000000Coooooo`000?oooooooooo
4Ol00003ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`;o00002?ooool01?l0003o
ooooooooooooool4o`000004ooooool0003o0000ooooo`Wo000000?oooooo`000?ooool04_ooool0
0ol0003oooooooooo`1mooooo`00G_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool00_ooool01?l0003oooooo`000?ooool2o`000004ooooool0003o
oooooooooa7o00001?ooool5o`000007ooooool0003o0000ooooool0003oooooo`000007ooooo`04
o`000?ooooooooooooooo`Ko000000?oooooo`000?ooool00ol000000ooooooo0000o`000005o`00
01;ooooo00?o0000ooooooooool0O_ooool005kooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000ooooool0003ooooo0_l000001?oo
oooo0000oooooooooolAo`0000Wooooo0_l000001Ooooooo0000oooooooooooo000000Gooooo0_l0
0003ooooo`03o`000?oooooo000000;o000000?oooooo`000?l000000_ooool3o`000003ooooool0
003o000000Co00004_ooool00ol0003oooooooooo`1oooooo`00G_ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000002
ooooo`03o`000?oooooo000000;ooooo2Ol000000ooooooo0000o`000006o`000007oa0@4?oooooo
ooooonk^k_lb<S;o0000oc8b<P02o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
0_ooool2o`0000?ooooo00?o0000ooooooooool00ol000000ooooooo0000o`000002ooooo`?o0000
00?oooooo`000?l000001?l0000@ooooo`;o0000P_ooool005kooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00So0000oooooooooooo0000
ooooool0003oooooo`0000;ooooo2Ol000000ooooooo0000o`000003o`000003ooooool0003ooooo
00?ooooo00?oMgMgoiRHV?ooool00_l000000ooooooo0000ooooo`03ooooo`04o`000?oooooooooo
ooooo`;o00001?ooool01Ol0003oooooo`000?l0003ooooo00Co000000?oooooo`000?l000000_l0
00000ooooooo0000ooooo`02o`000003ooooool0003ooooo00kooooo00?o0000ooooooooool0P_oo
ool005kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00;ooooo00So0000oooooooooooo0000ooooool0003oooooo`0000;ooooo2Ol00002ooooo`?o
000000Coooooo`000?l0003o00000oooool01_l@413o0000o`000?l0003o410@o`0000Gooooo00?o
0000ooooool000000_l00003ooooo`;o00000_ooool3o`000005ooooool0003o0000o`000?ooool0
1ol000001?oooooo0000ooooool0000>ooooo`03o`000?oooooooooo08?ooooo001Nooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`02ooooo`08o`00
0?ooooooooooo`000?oooooo0000ooooool00002ooooo`[o000000Goooooo`000?l0003o0000oooo
o`02o`000003ooooool0003o000000Co000000?oooooo`000?ooool01Oooool4o`0000?ooooo00Co
0000oooooooooooooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000;o0000
00Soooooo`000?l0003o0000ooooool0003oooooo`0000gooooo00?o0000ooooooooool0Q?ooool0
05kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
00;ooooo00Go0000oooooooooooo0000ooooo`03o`0000?ooooo2Ol000001?oooooo0000o`000?oo
ool4o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`?o00000oooool00ol0003ooooooooo
o`02ooooo`;o000000?oooooo`000?ooool00ol000000ooooooo0000o`000005o`000004ooooool0
003oooooo`0000_ooooo0_l00027ooooo`00G_ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool00_ooool01Ol0003oooooooooool0003ooooo00?o0000
0oooool9o`000003ooooool0003o000000;o000000?oooooo`000?l000000oooool01Ol0003ooooo
o`000?oooooo410@00Gooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo1?l00002ooooo`;o
00000_ooool7o`000004ooooool0003oooooo`0000Wooooo0_l00029ooooo`00G_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00_ooool01Ol0003o
ooooooooool0003ooooo00;o000000Coooooo`000?oooooooooo2Ol000000ooooooo0000o`000002
o`00000;ooooool0003o0000o`000?oooooo0000ogMgMol0003ooooooiRHV?mgMgL01?ooool3o`00
00?ooooo00?o0000ooooooooool00_ooool5o`0000;ooooo0_l000000ooooooo0000o`000002o`00
0008ooooool0003o0000o`000?oooooo0000ooooool00008ooooo`03o`000?oooooooooo08Wooooo
001Nooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooo`000?ooool00_l000001?oooooo0000ooooooooool9o`000003
ooooool0003o000000;o000000?oIVIVo`000?l000000_l000001_oooooo0000oc8b<_l0003o<S8b
onk^kP;ooooo0ol000001Ooooooo0000oooooooooooo000000Gooooo0ol000000ooooooo0000oooo
o`02o`0000;ooooo1Ol000000ooooooo0000ooooo`04o`0000Kooooo0_l0002<ooooo`00G_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00Go0000ooooooooooooooooo`00
0002ooooo`06o`000?oooooo0000o`000?oooooo00000_ooool9o`000003ooooool0003o000000So
00001_ooool3o`0000;ooooo00?o0000ooooool000001Oooool3o`000004ooooool0003ooooooooo
o`;o00000_ooool5o`000003ooooool0003ooooo00Co00001Oooool00ol0003oooooooooo`2<oooo
o`00G_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`06o`000?oooooo0000o`000?oooooo00000_ooool>o`0000;ooooo0ol0
0006ooooo`?o00000oooool2o`0000Gooooo0ol00002ooooo`Go000000?oooooo`000?ooool00ol0
00001?oooooo0000o`000?ooool4o`0000?ooooo0_l0002?ooooo`00G_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo01;ooooo00Go0000ooooooooooooooooo`000002ooooo`06o`00
0?oooooo0000o`000?oooooo00000_ooool8o`000004ooooool0003o0000ooooo`;o00000_ooool0
1?l0003oooooo`000?l00005ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooo000000?ooooo00Oo0000ooooool0003o0000ooooool0003ooooo00Co000000Coooooo`000?l0
003ooooo1?l00002ooooo`03o`000?oooooooooo08oooooo001Nooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04_ooool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000oooo
ool0003o0000ooooool00002ooooo`_o000000?oooooo`000?l000000oooool9o`0000Cooooo0_l0
0004ooooo`?o00000oooool00ol0003oooooooooo`02o`000003ooooool0003ooooo00?o00000_oo
ool2o`000004ooooool0003o0000o`0000;ooooo00?o0000ooooooooool0T?ooool005kooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`05o`000?ooooooooooooooool00000
0_ooool00ol0003oooooooooo`03o`0000;ooooo2ol000001?oooooo0000ooooool00003ooooo`Oo
00001?ooool00ol0003oooooo`000002ooooo`Co00000oooool01?l0003oooooooooooooool3o`00
0003ooooool0003o000000;o00000_ooool00ol0003oooooooooo`05o`0009?ooooo001Nooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooo000000;ooooo0ol00002ooooo`Go000000?oooooo`000?l000000ol000001?oooooo
0000o`000?l00004ooooo`?o00001_ooool01Ol0003oooooooooool0003ooooo00Co00000oooool0
1_l0003ooooooooooooooooo0000ooooo`;o000000?oooooo`000?l000000_l00002ooooo`06o`00
0?ooooooooooo`000?oooooo0000UOooool005gooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000000_ooool3o`0000;o
oooo1Ol000000ooooooo0000o`000003o`0000;ooooo0_l0000<ooooo`04o`000?oooooooooooooo
o`Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo0000ooooo`Go00000_ooool0
0ol0003oooooo`000003o`0009Gooooo001Mooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000;ooooo0ol00002oooo
o`Go000000?oooooo`000?l000000_l000001_oooooo0000ooooool0003oooooo`0000[ooooo00Co
0000oooooooooooooooo0ol000000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooool000001ol00002ooooo`03o`000?oooooo000000?o0000UOooool005gooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o
0000ooooool000000_ooool3o`0000;ooooo1Ol000000ooooooo0000o`000002o`000003ooooool0
003ooooo00?o00002Oooool02Ol0003ooooooooooooooooo0000ooooool0003oooooo`000003oooo
o`03o`000?oooooooooo00?ooooo1?l000000ooooooo0000o`000003o`0000;ooooo1_l0002Eoooo
o`00GOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooo`000002ooooo`?o00000_ooool5o`000003ooooool0003o000000;o
000000Coooooo`000?oooooooooo0_l00008ooooo`04o`000?ooooooooooooooo`Go00000oooool0
0ol0003oooooooooo`03ooooo`07o`000?oooooo0000o`000?oooooo0000ooooo`04o`000004oooo
ool0003o0000ooooo`Co0000UOooool005gooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000000_ooool3o`0000;ooooo
1Ol000000ooooooo0000o`000004o`0000;ooooo0_l00006ooooo`;o00000oooool3o`000003oooo
ool0003ooooo00;ooooo00?o0000ooooooooool00oooool01?l0003oooooo`000?l00002ooooo`Go
000000Goooooo`000?l0003o0000ooooo`03o`0009Kooooo001Mooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000?o
oooo0_l00002ooooo`03o`000?oooooo000000;o000000?oooooo`000?l000001?l00002ooooo`;o
00001Oooool00ol0003oooooooooo`02ooooo`?o000000?oooooo`000?l000000_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool000001?l000001?oooooo
0000o`000?ooool3o`0009Kooooo001Mooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000?ooooo0ol000000ooooooo
0000ooooo`09o`000003ooooool0003ooooo00?o00000oooool00ol0003oooooooooo`02ooooo`?o
000000Koooooo`000?oooooo0000ooooool00006ooooo`07o`000?oooooo0000o`000?oooooo0000
ooooo`02o`000003ooooool0003o000000;ooooo0ol000000ooooooo0000o`00002Fooooo`00GOoo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00ooo
ool2o`0000?ooooo0ol000000ooooooo0000ooooo`07o`000005ooooool0003o0000o`000?ooool0
1?l000000ooooooo0000ooooo`03ooooo`05o`000?oooooo0000ooooool000000_ooool2o`0000Ko
oooo00Co0000ooooool0003o00000_ooool00ol0003oooooo`000004o`000006ooooool0003o0000
ooooool0003ooooo0_l0002Fooooo`00GOooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool00oooool00ol0003oooooo`000002ooooo`?o000000?ooooo
o`000?ooool01ol000001?oooooo0000o`000?l00002ooooo`Co00000oooool4o`000004ooooool0
003oooooooooo`;o00001_ooool01?l0003oooooo`000?l00002ooooo`04o`000?oooooo0000oooo
o`Co000000Coooooo`000?l0003ooooo1?l0002Fooooo`00GOooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00oooool00ol0003oooooo`000002oooo
o`?o000000?oooooo`000?ooool03_l000000ooooooo0000o`000005o`0000;ooooo00?o0000oooo
ooooool00ol00005ooooo`03o`000?oooooo000000;o00000_ooool2o`000003ooooool0003o0000
00?o000000Coooooo`000?l0003ooooo1?l0002Fooooo`00GOooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00oooool00ol0003oooooo`000002oooo
o`;o000000Coooooo`000?l0003ooooo2Ol000001_oooooo0000oooooooooooo0000ooooo`Go0000
0oooool00ol0003oooooo`000002o`000003ooooool0003ooooo00;ooooo0_l000001?oooooo0000
o`000?l00002ooooo`Go000000?oooooo`000?l000000_ooool2o`000005ooooool0003o0000oooo
ool00000U_ooool005gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00?ooooo00?o0000ooooool000000_ooool2o`000003ooooool0003o000000[o
000000?oooooo`000?l000000_ooool00ol0003oooooooooo`04ooooo`;o000000Coooooo`000?oo
oooo00000_ooool2o`000004ooooool0003oooooooooo`?o00000_ooool4o`000003ooooool0003o
oooo00;o000000?oooooo`000?ooool00_l000001?oooooo0000ooooool0002Fooooo`00GOooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooo`000003ooooo`Oo000000?oooooo`000?l000001?l000000ooooooo0000o`000002
ooooo`03o`000?oooooooooo00?ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`00
0?oooooo000000;ooooo0_l00004ooooo`?o00000_ooool01ol0003oooooo`000?l0003oooooo`00
0?ooool00_l000000ooooooo0000o`00002Gooooo`00GOooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool00oooool00ol0003oooooo`000003ooooo`;o
000000?oooooo`000?l000000_l000000ooooooo0000o`000003o`000004ooooool0003oooooo`00
00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo000000Cooooo0_l00002
ooooo`;o00001?ooool3o`0000;ooooo1?l00002ooooo`Co000000?oooooo`000?l00000Uoooool0
05gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooool000000oooool2o`000003ooooool0003o000000;o000000?oooooo`00
0?l000000ol000000ooooooo0000ooooo`03o`0000;ooooo0ol000001Ooooooo0000o`000?oooooo
000000Cooooo0_l00002ooooo`;o00000oooool4o`0000?ooooo1?l000000ooooooo0000ooooo`02
o`000004ooooool0003o0000o`0009Oooooo001Mooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000?ooooo0_l00000
0ooooooo0000o`000002o`000003ooooool0003o000000?o00000_ooool2o`0000;ooooo1_l00002
ooooo`03o`000?oooooooooo00;ooooo00Co0000ooooool0003ooooo0_l00003ooooo`Co00001?oo
ool01ol0003oooooo`000?l0003oooooo`000?ooool00_l000001?oooooo0000o`000?l0002Goooo
o`00GOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool00oooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`000003ooooool0003ooooo00;o
000000Koooooo`000?oooooo0000ooooool00008ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00ol00003ooooo`Co00001?ooool6o`0000;ooooo0_l000001?oooooo0000o`000?l0
002Gooooo`00GOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool00oooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o
000000;o000000Koooooo`000?oooooo0000ooooool00007ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooooooo0_l00003ooooo`Co00001Oooool6o`0000;ooooo0_l000001?oooooo
0000o`000?l0002Gooooo`00GOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool00oooool2o`0000Cooooo1_l000000ooooooo0000o`000004o`0000;o
oooo0_l00006ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0_l00002oooo
o`Go00001_ooool00ol0003oooooo`000002o`0000;ooooo0_l000000ooooooo0000o`000002o`00
09Oooooo001Mooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`03ooooo`;o00001?ooool=o`0000;ooooo00?o0000ooooool000000oooool2o`0000Co
oooo00Co0000oooooooooooooooo0ol000000ooooooo0000ooooo`02o`0000Oooooo1_l00002oooo
o`;o000000Goooooo`000?l0003oooooo`00002Gooooo`00GOooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00oooool00ol0003oooooo`000003oooo
o`go00000oooool2o`0000;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooooooool2
o`000004ooooool0003o0000ooooo`;o00001oooool2o`000004ooooool0003oooooo`0000?ooooo
0_l000001?oooooo0000o`000?l0002Hooooo`00GOooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool00oooool00ol0003oooooo`000004ooooo`co0000
1?ooool00ol0003oooooo`000005ooooo`04o`000?ooooooooooooooo`;o00000_ooool01?l0003o
ooooo`000?l00008ooooo`Co000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`03o`00
09Sooooo001Mooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooo000000Cooooo1ol000000ooooooo0000o`000008o`0000Go
oooo00Co0000oooooooooooooooo0_l00002ooooo`Co00002?ooool2o`000003ooooool0003ooooo
00;o00000oooool00ol0003oooooooooo`03o`0009Sooooo001Mooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Co
oooo1ol000001_oooooo0000o`000?l0003oooooo`0000Cooooo1_l00003ooooo`;o00000_ooool0
1?l0003oooooo`000?l00009ooooo`;o000000Coooooo`000?oooooo00001?ooool01?l0003ooooo
o`000?ooool2o`0009Sooooo001Mooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`03ooooo`;o00001?ooool7o`000006ooooool0003o0000o`000?oo
oooo00001Oooool00ol0003oooooooooo`04ooooo`;o00000_ooool01?l0003oooooo`000?l00009
ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o000000?oooooo`000?ooool00_l0002H
ooooo`00GOooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooo`000003ooooo`03o`000?oooooo000000Co000000?oooooo`00
0?l000000ol00005ooooo`;o00000_ooool3o`0000?ooooo00?o0000ooooool000000_l00008oooo
o`;o00000_ooool00ol0003oooooo`000004ooooo`;o000000?oooooo`000?ooool00_l0002Hoooo
o`00GOooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooo`000004ooooo`;o000000Goooooo`000?l0003o0000ooooo`05o`00
00Oooooo0_l000000ooooooo0000ooooo`02ooooo`06o`000?oooooo0000o`000?oooooo00001ooo
ool2o`0000;ooooo1?l00004ooooo`04o`000?oooooo0000ooooo`?o0000V?ooool005gooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooool000001?ooool6o`000003ooooool0003o000000?o00002Oooool01_l0003ooooooooo
oooooooo0000ooooo`;o00000_ooool00ol0003oooooooooo`04ooooo`;o00000oooool3o`0000Co
oooo0_l000000ooooooo0000ooooo`02o`0009Wooooo001Mooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Cooooo
1_l00002ooooo`Co00001oooool2o`0000?ooooo00Co0000ooooool0003o00000oooool00ol0003o
ooooooooo`03ooooo`;o00000oooool2o`000003ooooool0003ooooo00?ooooo0ol00002ooooo`;o
0000VOooool005gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooool000001?ooool7o`000003ooooool0003o000000?o0000
1Oooool2o`0000?ooooo1?l00004ooooo`03o`000?oooooooooo00;ooooo0_l00003ooooo`;o0000
00?oooooo`000?ooool00oooool01?l0003oooooo`000?l00002ooooo`;o0000VOooool005gooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00?ooooo
0_l00005ooooo`Go000000?oooooo`000?l000000_l000000ooooooo0000ooooo`02ooooo`?o0000
0oooool2o`000003ooooool0003ooooo00Cooooo00?o0000ooooooooool00_l000000ooooooo0000
ooooo`02ooooo`04o`000?oooooo0000o`0000Cooooo00Co0000ooooool0003o00000_ooool2o`00
09Wooooo001Mooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`03ooooo`;o00001Oooool5o`000003ooooool0003o000000So00000oooool3o`000003
ooooool0003ooooo00Gooooo00?o0000ooooool000000_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00?o0000ooooooooool00_ooool01?l0003oooooo`000?l00003ooooo`;o0000VOooool0
05gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
00?ooooo0_l00005ooooo`Go00000oooool6o`0000Cooooo00Go0000ooooool0003oooooo`000007
ooooo`;o000000?oooooo`000?l000000oooool01?l0003oooooooooool00005ooooo`04o`000?oo
oooo0000o`0000;ooooo0_l0002Jooooo`00GOooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool01?ooool2o`0000Cooooo1_l00002ooooo`Co00001Ooo
ool01Ol0003oooooo`000?oooooo000000Sooooo00?o0000ooooool000001?ooool2o`000003oooo
ool0003ooooo00Cooooo00Co0000oooooooooooo00000oooool2o`0009[ooooo001Mooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`03ooooo`;o0000
1?ooool6o`0000;ooooo0ol000000ooooooo0000ooooo`02ooooo`05o`000?oooooo0000ooooool0
00002?ooool3o`0000Cooooo0_l00002ooooo`03o`000?oooooooooo00?ooooo00Co0000ooooool0
003o00000oooool2o`0009[ooooo001Mooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`03ooooo`;o00001?ooool6o`0000;ooooo1Ol00002ooooo`?o
000000?oooooo`000?ooool01oooool3o`0000?ooooo0ol00002ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_l00003ooooo`;o0000V_ooool005kooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool00000
0oooool3o`000003ooooool0003o000000Wo00000_ooool2o`0000Sooooo0_l000001?oooooo0000
ooooooooool2o`0000?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooooooool2o`00
00?ooooo0_l0002Jooooo`00G_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool01?ooool2o`0000?ooooo0ol000000ooooooo0000o`000002ooooo`Go
00000oooool2o`0000Sooooo0_l00002ooooo`04o`000?oooooo0000o`0000?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02o`0000Cooooo00?o0000ooooooooool0VOooool005ko
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooool000000_ooool3o`000004ooooool0003o0000o`0000;ooooo0_l000001?oo
oooo0000o`000?ooool2o`0000Sooooo0_l00003ooooo`?o00000_ooool2o`0000Kooooo00Co0000
oooooooooooooooo0_l00004ooooo`03o`000?oooooooooo09Wooooo001Nooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
000000;ooooo0ol000000ooooooo0000o`000006o`000004ooooool0003o0000o`0000Sooooo0_l0
0004ooooo`;o00000_ooool2o`0000Kooooo00Co0000oooooooooooooooo0ol00004ooooo`03o`00
0?oooooooooo09Wooooo001Nooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`05ooooo`;o00000_ooool01?l0003oooooo`000?ooool2o`0000?ooooo
1_l00008ooooo`;o00001?ooool2o`0000;ooooo00?o0000ooooooooool01Oooool01ol0003ooooo
oooooooooooo0000ooooool000001?ooool2o`0009_ooooo001Nooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`04ooooo`;o00000_ooool01?l0003o
ooooo`000?ooool2o`0000?ooooo2?l00003ooooo`Co00001?ooool3o`000003ooooool0003ooooo
00Kooooo00Ko0000ooooooooooooooooo`000?ooool2o`0000Cooooo0_l0002Kooooo`00G_ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01?ooool0
1ol0003oooooo`000?oooooo0000ooooool000000_ooool00ol0003oooooooooo`02ooooo`?o0000
0_ooool00ol0003oooooo`000002o`0000;ooooo00?o0000ooooooooool00_ooool2o`000003oooo
ool0003o000000Oooooo00Go0000ooooooooooooooooo`000002ooooo`;o00001?ooool2o`0009_o
oooo001Nooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`05ooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooooooool00_ooool7o`0000;ooooo
0ol000001?lb<S;ok^k^ooooooooool2o`0000;ooooo00?o0000ooooooooool01Oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2Joooo
o`00G_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool01Oooool01?l0003oooooo`000?ooool2o`0000;ooooo0_l00003ooooo`Co000000?oooooodA4
A?ooool00ol000001?nHV9SooooooiRHV?mgMgL3o`0000;ooooo0_l00006ooooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09[ooooo001N
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00?o00000_ooool2o`0000;ooooo00Ko0000ooooool0003o0000ob4Q
8Ol00004ooooo`04oa0@4?ooooooooooooooo`?o00000_ooool00ol0003oooooo`000002o`0000?o
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo0_l0002Loooo
o`00G_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`02o`0000;ooooo1?l00002ooooo`05o`000?oooooo0000o`00
0?o^k^h00oooool00ol0003oooooooooo`03o`0000;ooooo00Co0000oooooooooooo00001?ooool0
1Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool00oooool2o`0009cooooo001N
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Ko00001?ooool5o`0000?ooooo1Ol00002ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000Gooooo0_l00005ooooo`;o0000
W?ooool005kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00_l00002ooooo`;o00001Oooool00ol0003ooooooooo
o`08o`000003oa0@4?oooooo000000Cooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo0_l0002Mooooo`00G_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01_ooool00ol0003oooooo`00
0002o`000003ooooool0003o000000Cooooo0ol000000onHV9So410@o`000002o`000004ogMgMol0
003o0000oiRHV0;o00001Oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Cooooo
0_l00005ooooo`;o0000WOooool005kooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000000_l00002ooooo`03o`000?oo
oooooooo00;ooooo00GoV9RHoa0@4?l0003o0000olc<c003ooooo`05o`000?lb<S;o0000o`000?o^
k^h01_ooool2o`0000?ooooo00?o0000ooooooooool01?ooool2o`0000Kooooo0_l0002Mooooo`00
G_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
1_ooool4o`0000;ooooo0_l00006ooooo`;o00000_ooool01?l0003oooooo`000?l00008ooooo`05
o`000?ooooooooooooooool000001oooool2o`0000Gooooo0ol0002Mooooo`00G_ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooo`000002ooooo`;o00001oooool6o`0000Sooooo0_l00002ooooo`03o`000?oooooooooo00Go
oooo0_l00006ooooo`?o0000WOooool005kooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo00Sooooo0_l00002ooooo`;o00002?ooool3o`0000Wooooo
00Go0000ooooool0003oooooo`000008ooooo`;o00001_ooool2o`0009kooooo001Nooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`08ooooo`;o0000
0_ooool00ol0003oooooo`000005ooooo`;o00002oooool00ol0003oooooooooo`02o`0000Sooooo
0_l00006ooooo`?o0000W_ooool005kooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo00Oooooo0ol00002ooooo`;o00000oooool2o`0000cooooo00Go
0000ooooooooooooooooo`000008ooooo`;o00001oooool3o`0009kooooo001Nooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`07ooooo`;o000000?o
ooooo`000?l000001Ol0000=ooooo`04o`000?ooooooooooooooo`;o00001oooool00ol0003ooooo
o`000007ooooo`?o0000W_ooool005kooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo00Oooooo0_l00003ooooo`?o00003_ooool01_l0003ooooooooo
oooooooo0000ooooo`;o00001?ooool2o`000003ooooool0003ooooo00Kooooo0ol0002Oooooo`00
G_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`02ooooo`;o00003Oooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00008ooooo`?o0000Woooool005ko
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Oo
oooo0_l00003ooooo`?o00002_ooool2o`0000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`04o`000?ooooooooooo`0000Wooooo0ol0002Oooooo`00G_ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01_ooool2o`0000?ooooo0ol00009oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo00Oooooo0ol0002Pooooo`00G_ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01_ooool2o`0000?ooooo0_l000000ooo
oooo0000ooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooo`000002ooooo`03o`000?oooooooooo00Sooooo0ol0002Pooooo`00G_ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01Oooool2o`0000Co
oooo00?o0000ooooooooool00_l00003ooooo`;o00001?ooool00ol0003oooooooooo`04ooooo`;o
00000_ooool00ol0003oooooooooo`08ooooo`04o`000?oooooo0000o`000:3ooooo001Nooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`05ooooo`;o
00001?ooool01?l0003oooooooooooooool4o`0000Gooooo00?o0000ooooooooool01Oooool01?l0
003oooooooooool0000:ooooo`05o`000?oooooo0000ooooool00000X?ooool005kooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Gooooo0_l00004
ooooo`;o00002Oooool2o`0000Oooooo0_l000000ooooooo0000ooooo`0:ooooo`04o`000?oooooo
0000o`000:7ooooo001Nooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`04ooooo`;o00001?ooool2o`0000Sooooo00?o0000ooooooooool01_ooool0
1?l0003oooooo`000?l0000;ooooo`05o`000?oooooo0000ooooool00000XOooool005kooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Gooooo0_l0
0004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool01?l0003oooooo`00
0?l0000;ooooo`06o`000?ooooooooooo`000?oooooo0000XOooool005kooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Cooooo0_l00004ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool01Ol0003oooooo`000?oooooo0000
00_ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`2Oooooo`00G_ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00oooool2o`0000Co
oooo0_l00004ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool000000_ooool2o`0000Wo
oooo00Ko0000oooooooooooo0000ooooool0002Rooooo`00G_ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool00oooool2o`0000Gooooo00Go0000oooo
ooooooooooooo`000007ooooo`;o000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`07
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0X?ooool005kooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00;ooooo0_l00005
ooooo`Co00001oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Kooooo00Co
0000oooooooooooo00000oooool00ol0003oooooooooo`2Pooooo`00G_ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo01oooooo0_l00002ooooo`;o00001_ooool00ol0003ooooooooo
o`05ooooo`;o00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo0_l0
0003ooooo`04o`000?ooooooooooo`000:?ooooo001Nooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool08?ooool00ol0003oooooo`000002o`0000Cooooo00?o0000ooooool000000_l0
0002ooooo`;o00000_ooool2o`0000Kooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool00000Xoooool005kooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0Qooooo`So00000oooool01?l0003oooooo`000?l00003ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`00
0?ooooooooooo`000:Cooooo001Nooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
8oooool2o`0000Sooooo00?o0000ooooooooool00ol00009ooooo`05o`000?ooooooooooooooool0
00001Oooool01?l0003oooooooooool0002Uooooo`00G_ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo02?ooooo0_l00009ooooo`;o00003?ooool01?l0003oooooooooool00005oooo
o`05o`000?ooooooooooooooool00000YOooool005kooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0Sooooo`?o00005_ooool00ol0003oooooo`000005ooooo`05o`000?oooooooooo
ooooool00000Y_ooool005oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Toooo
o`;o00005_ooool2o`0000Gooooo00Go0000ooooooooooooooooo`00002Wooooo`00Goooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo02Cooooo0_l0000Fooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Uooooo`00Goooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo02Cooooo0_l0000Eooooo`?o00000oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo0:Kooooo001Oooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool09?ooool2o`0001Cooooo00?o0000ooooool000000oooool01?l0003ooooo
ooooooooool2o`000:Wooooo001Oooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
9?ooool2o`0001;ooooo00Go0000oooooooooooo0000ooooo`02o`0000?ooooo00?o0000oooooooo
ool0ZOooool005oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Tooooo`;o0000
4?ooool2o`0000?ooooo0_l00004ooooo`03o`000?oooooooooo0:[ooooo001Oooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool09?ooool2o`0000oooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0:_ooooo001Oooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool09Oooool2o`0000gooooo00?o0000ooooooooool00oooool2
o`0000?ooooo00?o0000ooooooooool0[?ooool005oooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0Uooooo`;o00003?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo0000
00;ooooo00?o0000ooooooooool0[Oooool005oooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooo000000[ooooo00?o0000ooooooooool00oooool01_l0003o
ooooooooool0003oooooo`000;3ooooo001Oooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool09_ooool2o`0000Sooooo0_l00005ooooo`04o`000?ooooooooooooooo`;o0000/Oooool0
05oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Vooooo`04o`000?oooooo0000
o`0000Cooooo0_l00006ooooo`04o`000?ooooooooooooooo`;o0000/_ooool005oooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0Uooooo`04o`000?ooooooooooooooo`Co00001ooo
ool01ol0003ooooooooooooooooo0000ooooool00000/_ooool005oooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0Uooooo`;o00003?ooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool0/?ooool005oooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000003ooooo`;o
0000/Oooool005oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Vooooo`;o0000
2?ooool2o`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2`ooooo`00Gooo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02Oooooo0_l00005ooooo`;o00001?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo001Pooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool09oooool00ol0003oooooo`000004o`0000Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`2`ooooo`00H?ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0;3ooooo001Pooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0/?ooool0063ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00H?oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02[ooooo1Ol0000:ooooo`03o`000?oo
oooooooo0;3ooooo001Pooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`2`ooooo`00H?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
02Kooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_oo
ool00ol0003oooooooooo`2`ooooo`00H?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo02Kooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1_ooool00ol0003oooooooooo`2`ooooo`00H?ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo02[ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo
0ol0002`ooooo`00YOooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool00000
^Oooool00:Cooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo00000;Wooooo
002Uooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@402iooooo`00X_oo
ool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`2iooooo`00
X_ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP2ioooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-31, -31, 0, 0}}]
}, Open  ]],

Cell["\<\
Even this smooth flow produces a complex pattern of \
characteristics. By computing the Lyapunov exponent for these trajectories, \
one can show that in fact the trajectories are chaotic, exhibiting sensitive \
dependence on the initial conditions.\
\>", "Text"],

Cell[TextData[{
  "\tThe behavior of a patch of dye in this flow can be followed by computing \
the positions of the edge of the patch as a function of time. We do so in \
Cell ",
  ButtonBox["7.5",
    ButtonData:>"Cell 7.5",
    ButtonStyle->"Hyperlink"],
  " for a patch that is initially circular, following 100 points from the \
patch edge."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(patchedge[t1_]\  := 
        Table[c[Sin[\[Theta]], Cos[\[Theta]]], {\[Theta], 0, 
              2  Pi,  .02  Pi}] /. t \[Rule] t1;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(Table[
        ListPlot[Evaluate[patchedge[t1]], PlotJoined \[Rule] True, 
          PlotRange \[Rule] {{\(-10\), 10}, {\(-10\), 10}}, 
          AspectRatio \[Rule] 1], {t1, 0, 5,  .2}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.5"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.05 0.5 0.05 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-10)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-7.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-2.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(2.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(7.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(10)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-10)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-7.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-2.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(2.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(7.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(10)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.5 .55 m
.50314 .5499 L
.50627 .54961 L
.50937 .54911 L
.51243 .54843 L
.51545 .54755 L
.51841 .54649 L
.52129 .54524 L
.52409 .54382 L
.52679 .54222 L
.52939 .54045 L
.53187 .53853 L
.53423 .53645 L
.53645 .53423 L
.53853 .53187 L
.54045 .52939 L
.54222 .52679 L
.54382 .52409 L
.54524 .52129 L
.54649 .51841 L
.54755 .51545 L
.54843 .51243 L
.54911 .50937 L
.54961 .50627 L
.5499 .50314 L
.55 .5 L
.5499 .49686 L
.54961 .49373 L
.54911 .49063 L
.54843 .48757 L
.54755 .48455 L
.54649 .48159 L
.54524 .47871 L
.54382 .47591 L
.54222 .47321 L
.54045 .47061 L
.53853 .46813 L
.53645 .46577 L
.53423 .46355 L
.53187 .46147 L
.52939 .45955 L
.52679 .45778 L
.52409 .45618 L
.52129 .45476 L
.51841 .45351 L
.51545 .45245 L
.51243 .45157 L
.50937 .45089 L
.50627 .45039 L
.50314 .4501 L
Mistroke
.5 .45 L
.49686 .4501 L
.49373 .45039 L
.49063 .45089 L
.48757 .45157 L
.48455 .45245 L
.48159 .45351 L
.47871 .45476 L
.47591 .45618 L
.47321 .45778 L
.47061 .45955 L
.46813 .46147 L
.46577 .46355 L
.46355 .46577 L
.46147 .46813 L
.45955 .47061 L
.45778 .47321 L
.45618 .47591 L
.45476 .47871 L
.45351 .48159 L
.45245 .48455 L
.45157 .48757 L
.45089 .49063 L
.45039 .49373 L
.4501 .49686 L
.45 .5 L
.4501 .50314 L
.45039 .50627 L
.45089 .50937 L
.45157 .51243 L
.45245 .51545 L
.45351 .51841 L
.45476 .52129 L
.45618 .52409 L
.45778 .52679 L
.45955 .52939 L
.46147 .53187 L
.46355 .53423 L
.46577 .53645 L
.46813 .53853 L
.47061 .54045 L
.47321 .54222 L
.47591 .54382 L
.47871 .54524 L
.48159 .54649 L
.48455 .54755 L
.48757 .54843 L
.49063 .54911 L
.49373 .54961 L
.49686 .5499 L
Mistroke
.5 .55 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00Xoooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^jiooooo`00YOooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0^Ooo
ool009[ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
402iooooo`00YOooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_oo
ool3o`000;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0;3ooooo002S
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool009cooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Looooo`03oeEEEOnYZJWo
oooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool0
09;ooooo1_l00004ooooo`03ojVYZOmEEEGooooo013ooooo00?o0000ooooooooool00oooool3o`00
0;3ooooo002Mooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`2`ooooo`00WOooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`2`ooooo`00WOooool00onYZJWoMgMgooooo`0;ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooo
oc8b<P0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo1Ol0
000<ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002[ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`2`ooooo`00[_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002R
ooooo`Ko00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002^oooo
o`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00Zoooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool0/?ooool00:_ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2`ooooo`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo
002[ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Jooooo`Go00001Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h04Oooool0
0ol0003oooooooooo`03ooooo`?o0000/?ooool009cooooo00?oV9RHob4Q8Oo^k^h03oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Mooooo`03ogMgMomVIVKooooo00_o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo002Nooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00
V_ooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2`ooooo`00V_ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l00006ooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
/_ooool7o`000:oooooo002_ooooo`?o00000oooool01?l0003oooooooooooooool3o`000:cooooo
002]ooooo`;o00001_ooool00ol0003oooooooooo`04ooooo`;o0000Z_ooool00:_ooooo0_l00008
ooooo`03o`000?oooooooooo00Kooooo0_l0002Xooooo`002Oooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hKooooo`03o`000?o^k^kooooo00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd07_ooool01Om4A4Co0000o`000?lb<S;ogMgM01cooooo1Ol00005oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM017ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo017ooooo1Ol00005ooooo`;o8B4Q1Oooool0
1Om4A4Co0000o`000?lb<S;ogMgM01kooooo00GoA4A4o`000?l0003o<S8bomgMg@0Nooooo`03o`00
0?o^k^kooooo00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd06_ooool4o`000008
oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`002oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool00omEEEGoZJVYooooo`05ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`0Pooooo`03ogMgMolb<S;ooooo01_ooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A005ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`;o00002oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo013ooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`0Pooooo`03ogMgMolb<S;ooooo01gooooo00?oEEEEojVYZOoo
ool01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06oooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool000Ko00001Oooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41004Oooool6o`0000Cooooo00?oZJVYoeEEEOooool04?ooool00ol0
003oooooooooo`0Cooooo`Ko00001oooool00ol0003oooooooooo`0Booooo`Ko00000oooool00onH
V9So8B4Qonk^kP0Aooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo013ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo01cooooo00?oZJVYoeEEEOooool04?ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003
ooooo`002oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007?ooool0
0olQ8B7oooooooooo`0>ooooo`03ogMgMolb<S;ooooo023ooooo00?oMgMgoc8b<_ooool07Oooool0
0onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;ooooo00gooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo013ooooo00?oV9RHob4Q8Oo^k^h03oooool0
0omgMgOo<S8booooo`0Pooooo`03ogMgMolb<S;ooooo01kooooo00?o8B4Qooooooooool03_ooool0
0omgMgOo<S8booooo`0Kooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`002oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007?oo
ool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`07_ooool01Ol0003o8B4Q
o`000?lb<S;oc<c<01oooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00kooooo00?o0000ooooooooool02oooool2o`0000cooooo00?o0000ooooooooool04Oooool00omg
MgOoIVIVooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`07_ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<01oooooo00?oEEEEolc<c?ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01cooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo000;ooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Looooo`03ojVYZOmgMgOooooo00_o
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool08Oooool00onYZJWoMgMgooooo`0;ooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo000;ooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Iooooo`05oa0@4?oooooooooo
oooooolb<S803?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01kooooo00Go0000
okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00Go0000okZj^_ooooooV9RH
oa0@400<ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool07_ooool01Ol@413ooooo
oooooooooooo<S8b00cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool000Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^01Wooooo1Ol0000<ooooo`Co00007oooool4o`0001gooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00<ooooo`Co00003Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03?ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l0
000Oooooo`Co00007Oooool5o`0000cooooo1?l0000Kooooo`03oeEEEOmVIVKo000000Cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`00YOooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool0X?ooool00:Cooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0:3ooooo002Tooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2Oooooo`00Y?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0Woooool00:Cooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo09oooooo
000;oooooooo0000E_l00008ooooo`002oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Kooooo000;ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_ooool00:Co
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo09oo
oooo002Tooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`2Pooooo`00YOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool0X?ooool00:Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo0:3ooooo002Uooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`2Qooooo`00Y_ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool0XOooool00:Oooooo00?o0000ooooooooool0
2oooool2o`0000cooooo00?o0000ooooooooool0X_ooool00:Oooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0:;ooooo002Xooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`2Sooooo`00Z?ooool2o`00
00_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Tooooo`00Z_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0YOooool00:_ooooo
0_l00008ooooo`03o`000?oooooooooo00Kooooo0_l0002Xooooo`00[Oooool2o`0000Kooooo00?o
0000ooooooooool01?ooool2o`000:[ooooo002_ooooo`?o00000oooool01?l0003ooooooooooooo
ool3o`000:cooooo002booooo`Oo0000[oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002Jooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0;3ooooo002Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00Voooool00onHV9So8B4Q
onk^kP0Aooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009cooooo00?o
V9RHob4Q8Oo^k^h03oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009gooooo00?oMgMg
ofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?oo
ool009kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0;3ooooo002Jooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool4
o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Zoooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool0/?ooool00:kooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`2`ooooo`00[oooool00ol0003oooooooooo`03ooooo`?o0000/?ooool00:kooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00Zoooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool00:_ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`2`ooooo`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0;3ooooo002[ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Looooo`03o`000?o^k^kooooo00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00W?ooool00omE
EEGoZJVYooooo`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
0;3ooooo002Looooo`03ojVYZOmEEEGooooo013ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`2`ooooo`00WOooool00olQ8B7oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo
0ol0002`ooooo`00WOooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`2`ooooo`00WOooool00onYZJWoMgMgooooo`0;ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooc8b
<P0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo1Ol0000<
ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000
/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Sooooo`Co000000So410@oooo
ooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000ooooooooool0/?ooool00:Gooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0
/?ooool00:Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo
0ol0002`ooooo`00YOooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
^Oooool00:Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo00000;Wooooo
002Uooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@402iooooo`00YOoo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0^Oooool00:?ooooo00?o
EEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^0;Wooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-10, -10, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.05 0.5 0.05 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-10)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-7.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-2.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(2.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(7.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(10)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-10)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-7.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-2.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(2.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(7.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(10)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.51207 .55894 m
.51588 .55875 L
.51962 .55829 L
.52329 .55755 L
.52686 .5565 L
.53031 .55511 L
.53363 .5534 L
.53681 .55135 L
.53984 .54898 L
.54269 .54629 L
.54537 .54333 L
.54786 .54011 L
.55015 .53668 L
.55224 .53308 L
.55413 .52935 L
.5558 .52556 L
.55726 .52173 L
.55851 .51793 L
.55953 .5142 L
.56034 .51059 L
.56093 .50714 L
.5613 .50388 L
.56145 .50084 L
.56139 .49805 L
.56111 .49552 L
.56061 .49326 L
.5599 .49127 L
.55898 .48955 L
.55785 .48809 L
.55652 .48687 L
.55498 .48587 L
.55324 .48506 L
.5513 .48442 L
.54917 .4839 L
.54685 .48348 L
.54435 .48313 L
.54167 .48281 L
.53882 .4825 L
.53582 .48218 L
.53266 .48182 L
.52936 .48142 L
.52594 .48096 L
.5224 .48047 L
.51877 .47993 L
.51505 .47937 L
.51126 .47881 L
.50742 .47828 L
.50355 .47781 L
.49967 .47744 L
.49579 .47721 L
Mistroke
.49194 .47715 L
.48813 .4773 L
.48438 .4777 L
.48071 .47837 L
.47714 .47934 L
.47368 .48063 L
.47035 .48224 L
.46717 .48417 L
.46414 .48643 L
.46127 .48899 L
.45859 .49183 L
.4561 .49493 L
.4538 .49823 L
.4517 .50172 L
.44981 .50533 L
.44813 .50903 L
.44666 .51276 L
.44541 .51647 L
.44438 .52013 L
.44357 .52368 L
.44298 .52708 L
.44261 .53031 L
.44246 .53333 L
.44252 .53612 L
.4428 .53866 L
.4433 .54094 L
.44401 .54297 L
.44493 .54474 L
.44606 .54626 L
.4474 .54756 L
.44895 .54864 L
.45069 .54955 L
.45263 .5503 L
.45477 .55093 L
.45709 .55147 L
.4596 .55194 L
.46229 .55238 L
.46514 .55281 L
.46815 .55326 L
.47132 .55373 L
.47462 .55424 L
.47805 .5548 L
.48159 .55539 L
.48523 .55601 L
.48895 .55663 L
.49274 .55725 L
.49658 .55781 L
.50045 .5583 L
.50434 .55868 L
.50822 .55891 L
Mistroke
.51207 .55894 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00Xoooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^jiooooo`00YOooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0^Ooo
ool009[ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
402iooooo`00YOooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_oo
ool3o`000;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0;3ooooo002S
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool009cooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Looooo`03oeEEEOnYZJWo
oooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool0
09;ooooo1_l00004ooooo`03ojVYZOmEEEGooooo013ooooo00?o0000ooooooooool00oooool3o`00
0;3ooooo002Mooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`2`ooooo`00WOooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`2`ooooo`00WOooool00onYZJWoMgMgooooo`0;ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooo
oc8b<P0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo1Ol0
000<ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002[ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`2`ooooo`00[_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002R
ooooo`Ko00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002^oooo
o`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00Zoooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool0/?ooool00:_ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2`ooooo`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo
002[ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Jooooo`Go00001Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h04Oooool0
0ol0003oooooooooo`03ooooo`?o0000/?ooool009cooooo00?oV9RHob4Q8Oo^k^h03oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Mooooo`03ogMgMomVIVKooooo00_o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo002Nooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00
V_ooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2`ooooo`00V_ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l00006ooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo0009ooooo`Co000000So410@oooooooo
ooook^k^oc8b<_l0003o<S8bonk^kQ_ooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00Go
A4A4o`000?l0003o<S8bomgMg@0Nooooo`05odA4A?l0003o0000oc8b<_oMgMd07?ooool5o`0000Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd07?ooool00ol0003oooooooooo`0Loooo
o`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Nooooo`05odA4A?l0003o
0000oc8b<_oMgMd07_ooool00ol0003ok^k^ooooo`05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`00
0?lb<S;ogMgM01[ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool0
00_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00?oEEEE
ojVYZOooool01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool08?ooool00omgMgOo<S8booooo`0K
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06ooo
ool00ol0003oooooooooo`0Looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool08?ooool00omgMgOo<S8booooo`0Mooooo`03oeEEEOnYZJWooooo00Gooooo
0_lQ8B48ooooo`03ogMgMolb<S;ooooo01_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo0006o`0000Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@017ooooo1_l00004ooooo`03ojVYZOmEEEGooooo013ooooo00?o0000oooooooo
ool04oooool6o`0000Oooooo00?o0000ooooooooool04_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^
k^h04Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01gooooo00?oV9RHob4Q8Oo^
k^h04Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01cooooo00?oZJVYoeEEEOoo
ool04?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooo
oooooooooa0@4003ooooo`002oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000007?ooool00olQ8B7oooooooooo`0>ooooo`03ogMgMolb<S;ooooo023ooooo00?oMgMgoc8b
<_ooool07Oooool00onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;ooooo01_ooooo00?o0000oooo
ooooool07_ooool00onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;ooooo023ooooo00?oMgMgoc8b
<_ooool07_ooool00olQ8B7oooooooooo`0>ooooo`03ogMgMolb<S;ooooo01_ooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo000;ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`00000Looooo`03oeEEEOo<c<cooooo00_ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c00Nooooo`05o`000?lQ8B7o0000oc8b<_o<c<`07oooool00omgMgOoIVIV
ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`07?ooool2o`00023ooooo00?oMgMgofIVI_oo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01kooooo00Go0000ob4Q8Ol0003o<S8bolc<c00O
ooooo`03oeEEEOo<c<cooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Looooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`002oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41007?ooool00onYZJWoMgMgooooo`0;ooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo01Sooooo2?l0000Qooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`0Qooooo`03ojVYZOmgMgOooooo00_ooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool000_ooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Wooooo00Go410@oooooooo
oooooooooc8b<P0<ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool07_ooool01Ol0
003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool05Oooool3o`0000Kooooo00?o0000
ooooool000001_l0000Fooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo01kooooo00Go410@oooooooooooooooooc8b<P0<ooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo0009ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Iooooo`Go
00003?ooool4o`0001oooooo1?l0000Mooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool4o`00
01?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`So00003_ooool01OnH
V9So410@o`000?lQ8B7oc<c<00cooooo1?l0000Oooooo`Co00007Oooool5o`0000cooooo1?l0000K
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00ZOooool2
o`0000[ooooo00?o0000ooooooooool03_ooool3o`0009oooooo002Xooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool04?ooool2o`0009kooooo002Wooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`2Looooo`00Y_ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo017ooooo0_l0002Mooooo`00YOooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Voooool000_oooooool0001F
o`0000Sooooo000;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`002oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Kooooo002Sooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`2Kooooo`00
Xoooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
W?ooool00:?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo09cooooo002Rooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`2Looooo`00X_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0WOooool00:;ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo09gooooo002Qooooo`03o`000?oooooooooo017ooooo
0_l0000Aooooo`03o`000?oooooooooo09gooooo002Qooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`2Nooooo`00XOooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0W_ooool00:7ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo09oooooo002Qooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2Oooooo`00
X_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
X?ooool00:;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo0:7ooooo002Sooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`2Rooooo`00Y?ooool2o`0000oooooo0_l0000:ooooo`;o0000YOooool00:Ko
oooo1ol00008ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0YOooool00:gooooo
1ol000000ooooooo0000ooooo`07ooooo`;o0000Z?ooool00;Cooooo2_l0002Zooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool009[ooooo1Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo
00?o0000ooooooooool0/?ooool009[ooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q
2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Kooooo`03oiRHV?lQ
8B7ok^k^017ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2`ooooo`00W?ooool0
0onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00WOooool00omg
MgOoIVIVooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`
ooooo`00W_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0/?ooool009[ooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<oooo
o`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002[ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00[_ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo0;3ooooo002_ooooo`03o`000?oooooooooo00?ooooo0ol0002`ooooo`00[_oo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`ooooo`00Zoooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo1?l00006ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool009cooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Go
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Looooo`03
oeEEEOnYZJWooooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0/?ooool009cooooo00?oZJVYoeEEEOooool04?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo0;3ooooo002Mooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool01?oo
ool3o`000;3ooooo002Mooooo`03oeEEEOo<c<cooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo0;3ooooo002Mooooo`03ojVYZOmgMgOooooo00_ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo
<S8b00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00V_ooool5o`00
00cooooo1?l00006ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:?ooooo1?l000002?l@413o
ooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1_ooool00ol0003oooooooooo`2`ooooo`00YOooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003ooooooooo
o`2`ooooo`00YOooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_oo
ool3o`000;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
002iooooo`00YOooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000^Ooo
ool00:Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@0;Wooooo002U
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`2iooooo`00Xoooool0
0omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0^Oooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-10, -10, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.05 0.5 0.05 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-10)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-7.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-2.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(2.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(7.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(10)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-10)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-7.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-2.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(2.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(7.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(10)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.52849 .5646 m
.53302 .5635 L
.5374 .56186 L
.54159 .55963 L
.54556 .55681 L
.5493 .5534 L
.55278 .54943 L
.55598 .54494 L
.55891 .54001 L
.56156 .53472 L
.56392 .52916 L
.566 .52343 L
.5678 .51763 L
.56933 .51186 L
.5706 .50621 L
.57162 .50079 L
.57241 .49566 L
.57297 .4909 L
.57332 .48657 L
.57346 .48274 L
.57341 .47943 L
.57317 .47668 L
.57276 .4745 L
.57217 .47291 L
.57141 .4719 L
.57048 .47146 L
.56938 .47156 L
.56811 .47216 L
.56667 .47323 L
.56504 .47472 L
.56323 .47655 L
.56123 .47867 L
.55903 .481 L
.55662 .48347 L
.554 .48599 L
.55116 .48849 L
.5481 .49088 L
.54481 .49311 L
.54131 .49509 L
.53758 .49678 L
.53365 .49816 L
.52952 .49918 L
.52521 .49987 L
.52074 .50023 L
.51614 .50031 L
.51144 .50016 L
.50666 .49987 L
.50184 .49953 L
.49702 .49923 L
.49224 .49908 L
Mistroke
.48754 .49917 L
.48294 .49959 L
.47849 .50042 L
.47422 .50173 L
.47015 .50354 L
.46631 .50587 L
.46273 .50873 L
.45941 .51209 L
.45636 .51589 L
.4536 .52008 L
.45113 .52459 L
.44894 .52933 L
.44703 .53421 L
.44541 .53915 L
.44404 .54406 L
.44294 .54885 L
.44208 .55345 L
.44146 .55777 L
.44107 .56177 L
.44089 .56539 L
.44092 .56858 L
.44114 .57132 L
.44155 .57358 L
.44215 .57536 L
.44294 .57665 L
.4439 .57746 L
.44504 .57783 L
.44636 .57777 L
.44787 .57733 L
.44957 .57656 L
.45146 .57551 L
.45355 .57423 L
.45585 .57281 L
.45836 .5713 L
.46109 .56978 L
.46404 .56831 L
.46722 .56695 L
.47061 .56577 L
.47423 .5648 L
.47806 .56408 L
.48209 .56362 L
.48631 .56343 L
.4907 .56348 L
.49523 .56373 L
.49989 .56412 L
.50463 .56457 L
.50944 .56501 L
.51426 .56533 L
.51907 .56544 L
.52382 .56522 L
Mistroke
.52849 .5646 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00Xoooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^jiooooo`00YOooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0^Ooo
ool009[ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
402iooooo`00YOooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_oo
ool3o`000;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0;3ooooo002S
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool009cooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Looooo`03oeEEEOnYZJWo
oooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool0
09;ooooo1_l00004ooooo`03ojVYZOmEEEGooooo013ooooo00?o0000ooooooooool00oooool3o`00
0;3ooooo002Mooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`2`ooooo`00WOooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`2`ooooo`00WOooool00onYZJWoMgMgooooo`0;ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooo
oc8b<P0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo1Ol0
000<ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002[ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`2`ooooo`00[_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002R
ooooo`Ko00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002^oooo
o`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00Zoooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool0/?ooool00:_ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2`ooooo`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo
002[ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Jooooo`Go00001Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h04Oooool0
0ol0003oooooooooo`03ooooo`?o0000/?ooool009cooooo00?oV9RHob4Q8Oo^k^h03oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Mooooo`03ogMgMomVIVKooooo00_o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo002Nooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00
V_ooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2`ooooo`00V_ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l00006ooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo0009ooooo`Co000000So410@oooooooo
ooook^k^oc8b<_l0003o<S8bonk^kQ_ooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00Go
A4A4o`000?l0003o<S8bomgMg@0Nooooo`05odA4A?l0003o0000oc8b<_oMgMd07?ooool5o`0000Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd07?ooool00ol0003oooooooooo`0Loooo
o`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Nooooo`05odA4A?l0003o
0000oc8b<_oMgMd07_ooool00ol0003ok^k^ooooo`05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`00
0?lb<S;ogMgM01[ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool0
00_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00?oEEEE
ojVYZOooool01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool08?ooool00omgMgOo<S8booooo`0K
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06ooo
ool00ol0003oooooooooo`0Looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool08?ooool00omgMgOo<S8booooo`0Mooooo`03oeEEEOnYZJWooooo00Gooooo
0_lQ8B48ooooo`03ogMgMolb<S;ooooo01_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo0006o`0000Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@017ooooo1_l00004ooooo`03ojVYZOmEEEGooooo013ooooo00?o0000oooooooo
ool04oooool6o`0000Oooooo00?o0000ooooooooool04_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^
k^h04Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01gooooo00?oV9RHob4Q8Oo^
k^h04Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01cooooo00?oZJVYoeEEEOoo
ool04?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooo
oooooooooa0@4003ooooo`002oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000007?ooool00olQ8B7oooooooooo`0>ooooo`03ogMgMolb<S;ooooo023ooooo00?oMgMgoc8b
<_ooool07Oooool00onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;ooooo01_ooooo00?o0000oooo
ooooool05?ooool2o`0000Sooooo00?oV9RHob4Q8Oo^k^h03oooool00omgMgOo<S8booooo`0Poooo
o`03ogMgMolb<S;ooooo01kooooo00?o8B4Qooooooooool03_ooool00omgMgOo<S8booooo`0Koooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`002oooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007?ooool00omEEEGoc<c<ooooo`0;
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`07_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01oooooo
00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01cooooo0_l0000Dooooo`Co
00002?ooool00omgMgOoIVIVooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`07_ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<01oooooo00?oEEEEolc<c?ooool02oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<01cooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
000;ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Looooo`03ojVY
ZOmgMgOooooo00_ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Booooo`05o`00
0?ooooooooooooooool000002Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool08Oooool00onYZJWoMgMgooooo`0;ooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo000;ooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Iooooo`05oa0@4?oooooooooo
oooooolb<S803?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01kooooo00Go0000
okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool04_oo
ool01Ol0003ooooooooooooooooo000000Gooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool07_ooool01Ol@413ooooooooooooooooo<S8b
00cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool000Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01Wooooo1Ol0000<ooooo`Co00007oooool4o`0001gooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00007Oooool00ol0003oooooooooo`0@ooooo`;o00001?ooool00ol0003ooooooooo
o`03ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool4o`0001oooooo1?l0000Mooooo`Go0000
3?ooool4o`0001_ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo002eooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2Gooooo`00]Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0Uoooool00;Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo09Oooooo002eooooo`03o`000?oooooooooo00_ooooo0_l00009oooo
o`03o`000?oooooooooo09Oooooo002eooooo`03o`000?oooooooooo00Sooooo0ol0000;ooooo`03
o`000?oooooooooo09Oooooo000;oooooooo0000E_l00008ooooo`002oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`03ooooo`?o00002?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01?ooool2o`0000Sooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`06ooooo`002oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Kooooo002Xoooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`2Hoooo
o`00Yoooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0VOooool00:Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo09Wooooo002Vooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`2Iooooo`00YOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool0VOooool00:Cooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo09[ooooo002Tooooo`03o`000?oooooooooo00ko
oooo0_l0000Dooooo`03o`000?oooooooooo09[ooooo002Tooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`2Jooooo`00Y?ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0V_ooool00:?ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo09_ooooo002Roooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`2Koooo
o`00X_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0W?ooool00:;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo09gooooo002Rooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`2Mooooo`00XOooool00ol0003oooooooooo`0Aooooo`;o00004?ooool0
0ol0003oooooooooo`2Nooooo`00XOooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
00gooooo0_l0002Qooooo`00XOooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0XOooool00:7ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo0:;ooooo002Qooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool02Oooool2o`000:Gooooo002Qooooo`03o`000?oooooooooo00Oooooo5_l0002W
ooooo`00XOooool00ol0003oooooooooo`05ooooo`;o00002_ooool00ol0003oooooooooo`2`oooo
o`00XOooool00ol0003oooooooooo`03ooooo`;o00003?ooool00ol0003oooooooooo`2`ooooo`00
XOooool01?l0003oooooooooooooool2o`0000kooooo00?o0000ooooooooool0/?ooool00:7ooooo
1?l0000@ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00V_ooool5o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`2`ooooo`00V_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009_ooooo00?oV9RHob4Q8Oo^
k^h04Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002Looooo`03oiRH
V?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool01?ooool3o`000;3ooooo002Mooooo`03ogMgMomV
IVKooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo
002Nooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`2`ooooo`00V_ooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`2`ooooo`00V_ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l0
0006ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000
/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:_ooooo00GoA4A4o`000?l0003o<S8bomgM
g@05ooooo`03o`000?oooooooooo0;3ooooo002^ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool0/?ooool00:oooooo00?o0000ooooooooool00oooool3o`000;3ooooo002^ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool00:_ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0/?ooool00:_ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`2`ooooo`00Zoooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00W?ooool00ol0003ok^k^ooooo`05ooooo`;o8B4Q1Oooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009cooooo00?oEEEE
ojVYZOooool01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`
ooooo`00W?ooool00onYZJWoEEEEooooo`0@ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0/?ooool009gooooo00?o8B4Qooooooooool03_ooool00omgMgOo<S8booooo`04ooooo`?o
0000/?ooool009gooooo00?oEEEEolc<c?ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool0/?ooool009gooooo00?oZJVYogMgMoooool02oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?oooooooooooooooolb<S80
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`Go00003?oo
ool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Xoooool4o`000008oa0@4?oooooo
ooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0;3o
oooo002Uooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`?o
0000/?ooool00:Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo00000;Wo
oooo002Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00002iooooo`00
YOooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100^Oooool00:Gooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg0;Wooooo002Sooooo`03oeEE
EOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP2iooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-10, -10, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.05 0.5 0.05 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-10)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-7.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-2.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(2.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(7.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(10)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-10)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-7.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-2.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(2.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(7.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(10)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.54901 .56144 m
.55402 .55711 L
.55867 .55176 L
.56292 .54545 L
.56673 .53831 L
.57011 .53048 L
.57304 .52214 L
.57553 .51349 L
.57761 .50472 L
.5793 .49602 L
.58062 .48754 L
.5816 .47943 L
.58228 .47182 L
.5827 .46479 L
.58288 .45844 L
.58286 .4528 L
.58267 .44791 L
.58233 .44381 L
.58186 .44049 L
.58129 .43796 L
.58064 .43621 L
.57991 .43522 L
.57911 .43499 L
.57825 .43549 L
.57733 .4367 L
.57635 .43859 L
.5753 .44112 L
.57416 .44426 L
.57293 .44797 L
.57158 .45219 L
.5701 .45687 L
.56845 .46193 L
.56661 .4673 L
.56456 .47288 L
.56226 .47857 L
.55968 .48425 L
.55681 .4898 L
.55361 .49509 L
.55006 .49999 L
.54616 .50439 L
.54191 .50818 L
.5373 .51129 L
.53235 .51368 L
.5271 .51535 L
.52159 .51635 L
.51587 .51679 L
.51 .51681 L
.50405 .5166 L
.49811 .51636 L
.49225 .51631 L
Mistroke
.48654 .51662 L
.48107 .51749 L
.47589 .51902 L
.47106 .52129 L
.46662 .52433 L
.4626 .5281 L
.45902 .53254 L
.45589 .53753 L
.45319 .54296 L
.45092 .54867 L
.44906 .55453 L
.44757 .5604 L
.44644 .56616 L
.44564 .57169 L
.44512 .57691 L
.44486 .58172 L
.44482 .58607 L
.44499 .58992 L
.44534 .59323 L
.44584 .59597 L
.44648 .59813 L
.44725 .59972 L
.44812 .60073 L
.4491 .60119 L
.45019 .6011 L
.45139 .60049 L
.4527 .59941 L
.45413 .59788 L
.4557 .59597 L
.45743 .59372 L
.45933 .59121 L
.46143 .5885 L
.46376 .58568 L
.46633 .58284 L
.46917 .58006 L
.47231 .57745 L
.47576 .57508 L
.47954 .57305 L
.48366 .5714 L
.48811 .57019 L
.49288 .56941 L
.49796 .56903 L
.50332 .56898 L
.50891 .56915 L
.51467 .56938 L
.52054 .56949 L
.52645 .56927 L
.53233 .56853 L
.5381 .56707 L
.54368 .56475 L
Mistroke
.54901 .56144 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00Xoooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^jiooooo`00YOooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0^Ooo
ool009[ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
402iooooo`00YOooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_oo
ool3o`000;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0;3ooooo002S
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool009cooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Looooo`03oeEEEOnYZJWo
oooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool0
09;ooooo1_l00004ooooo`03ojVYZOmEEEGooooo013ooooo00?o0000ooooooooool00oooool3o`00
0;3ooooo002Mooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`2`ooooo`00WOooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`2`ooooo`00WOooool00onYZJWoMgMgooooo`0;ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooo
oc8b<P0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo1Ol0
000<ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002[ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`2`ooooo`00[_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002R
ooooo`Ko00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002^oooo
o`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00Zoooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool0/?ooool00:_ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2`ooooo`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo
002[ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Jooooo`Go00001Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h04Oooool0
0ol0003oooooooooo`03ooooo`?o0000/?ooool009cooooo00?oV9RHob4Q8Oo^k^h03oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Mooooo`03ogMgMomVIVKooooo00_o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo002Nooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00
V_ooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2`ooooo`00V_ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l00006ooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`0Gooooo`;o0000Uoooool00;Gooooo00?o0000ooooooooool05oooool00ol0003oooooo`00
002Fooooo`00]Oooool00ol0003oooooooooo`0Fooooo`04o`000?ooooooooooo`0009Kooooo002e
ooooo`03o`000?oooooooooo01Kooooo00Co0000oooooooooooo0000U_ooool00;Gooooo00?o0000
ooooooooool05_ooool01?l0003oooooooooool0002Fooooo`00]Oooool2o`0001Oooooo00Co0000
oooooooooooo0000U_ooool00;Gooooo00?o0000ooooooooool05Oooool01Ol0003ooooooooooooo
oooo000009Kooooo002eooooo`03o`000?oooooooooo01Gooooo00Go0000ooooooooooooooooo`00
002Fooooo`00]Oooool00ol0003oooooooooo`0Eooooo`05o`000?ooooooooooooooool00000U_oo
ool000Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^6oooool00ol0003o
k^k^ooooo`05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01kooooo00GoA4A4o`00
0?l0003o<S8bomgMg@0Looooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@0Looooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`05o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd07_ooool01Om4A4Co0000
o`000?lb<S;ogMgM01kooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0
003o<S8bomgMg@0Jooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo
000;ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`03oeEE
EOnYZJWooooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo023ooooo00?oMgMgoc8b<_ooool0
6oooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01_o
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`08o`000?oooooooooooiRH
V?lQ8B7ok^k^oooooom4A4@5ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Pooooo`03ogMgMolb
<S;ooooo01gooooo00?oEEEEojVYZOooool01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06ooo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool000Ko00001Ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41004Oooool6o`0000Cooooo
00?oZJVYoeEEEOooool04?ooool00ol0003oooooooooo`0Cooooo`Ko00001oooool00ol0003ooooo
ooooo`0Booooo`Ko00000oooool00onHV9So8B4Qonk^kP0Aooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`07o`000?oooooooooooooooonH
V9So8B4Qonk^kP0Aooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool07?ooool00onY
ZJWoEEEEooooo`0@ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@00?ooooo000;ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00000Looooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool08?ooool0
0omgMgOo<S8booooo`0Mooooo`03oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool06oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;ooooo023ooooo00?oMgMgoc8b<_ooool07_ooool0
0olQ8B7oooooooooo`0>ooooo`03ogMgMolb<S;ooooo01_ooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000?ooooo000;ooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`00000Looooo`03oeEEEOo<c<cooooo00_ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00Nooooo`05o`000?lQ8B7o0000oc8b<_o<c<`07oooool00omgMgOoIVIVooooo`0;ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`07?ooool2o`0001Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03ogMgMomVIVKooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00N
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`07oooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`07?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00000oooool000_ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01co
oooo00?oZJVYogMgMoooool02oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Qooooo`03ojVYZOmgMgOooooo00_o
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41000oooool000_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
01Wooooo00Go410@oooooooooooooooooc8b<P0<ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool07_ooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Cooooo00So0000oooooooooooo0000
okZj^_ooooooV9RHoa0@40cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Noooo
o`05oa0@4?oooooooooooooooolb<S803?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`002Oooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06Oooool5o`0000cooooo1?l0000Oooooo`Co00007Ooo
ool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l0000Mooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool01?ooool02?l0003ooooooooooonHV9So410@o`000?lQ8B7oc<c<3?ooool4
o`0001oooooo1?l0000Mooooo`Go00003?ooool4o`0001_ooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo002eooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`2Eooooo`00]Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0UOooool00;Gooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo09Gooooo002eooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2Eooooo`00]Ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0UOoo
ool000_oooooool0001Fo`0000Sooooo000;ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l00007oooo
o`;o00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo000;ooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo02Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo02Sooooo00?o0000ooooooooool01_ooool00;Gooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo09Kooooo002eooooo`03o`000?oo
oooooooo00Wooooo0_l0000<ooooo`03o`000?oooooooooo09Kooooo002eooooo`03o`000?oooooo
oooo00Gooooo1?l0000>ooooo`03o`000?oooooooooo09Kooooo002/oooooa7o00004_ooool00ol0
003oooooooooo`2Fooooo`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool0Uoooool00:[ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo09Oooooo002Yooooo`03o`000?oooooooooo00Wooooo0_l0
000Gooooo`03o`000?oooooooooo09Oooooo002Xooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`2Hooooo`00Yoooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0V?ooool00:Oooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo09Wooooo002Vooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2Iooooo`00Y_oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0V_oo
ool00:Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo09_ooooo002Uooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`2Kooooo`00Y?ooool00ol0003oooooooooo`0>ooooo`;o00004_ooool00ol0003o
ooooooooo`2Looooo`00Y?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo013ooooo
0_l0002Nooooo`00Y?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0W_ooool00:Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo09kooooo002Sooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool03Oooool2o`000:7ooooo002Sooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool02oooool2o`000:?ooooo002Sooooo`03o`000?oooooooooo00gooooo1Ol00007ooooo`Co0000
YOooool00:;ooooo00?o0000ooooooooool02_ooool4o`0000;ooooo00?o0000ooooooooool01ol0
002Yooooo`00X_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0/?ooool00:;ooooo00?o0000ooooooooool01_ooool3o`0000Oooooo0_l0002aoooo
o`00X_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0/?ooool00:;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo0;3ooooo002Rooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`2`ooooo`00X_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0/?ooool00:;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo0;3ooooo002Rooooo`05o`000?oooooooooooooo
ool000003_ooool00ol0003oooooooooo`2`ooooo`00X_ooool2o`000003ooooool0003o000000ko
oooo00?o0000ooooooooool0/?ooool00:?ooooo0ol0000?ooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool009[ooooo1Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo
00?o0000ooooooooool0/?ooool009[ooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q
2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Kooooo`03oiRHV?lQ
8B7ok^k^017ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2`ooooo`00W?ooool0
0onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00WOooool00omg
MgOoIVIVooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`
ooooo`00W_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0/?ooool009[ooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<oooo
o`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002[ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00[_ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo0;3ooooo002_ooooo`03o`000?oooooooooo00?ooooo0ol0002`ooooo`00[_oo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`ooooo`00Zoooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo1?l00006ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool009cooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Go
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Looooo`03
oeEEEOnYZJWooooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0/?ooool009cooooo00?oZJVYoeEEEOooool04?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo0;3ooooo002Mooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool01?oo
ool3o`000;3ooooo002Mooooo`03oeEEEOo<c<cooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo0;3ooooo002Mooooo`03ojVYZOmgMgOooooo00_ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo
<S8b00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00V_ooool5o`00
00cooooo1?l00006ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:?ooooo1?l000002?l@413o
ooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1_ooool00ol0003oooooooooo`2`ooooo`00YOooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003ooooooooo
o`2`ooooo`00YOooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_oo
ool3o`000;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
002iooooo`00YOooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000^Ooo
ool00:Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@0;Wooooo002U
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`2iooooo`00Xoooool0
0omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0^Oooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-10, -10, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.05 0.5 0.05 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-10)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-7.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-2.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(2.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(7.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(10)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-10)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-7.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-2.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(2.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(7.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(10)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.57139 .53707 m
.57589 .52609 L
.57971 .51413 L
.58284 .50156 L
.5853 .48879 L
.58713 .47619 L
.5884 .46408 L
.58917 .45272 L
.5895 .44229 L
.58947 .43292 L
.58914 .42465 L
.58856 .41752 L
.58781 .41149 L
.58691 .40653 L
.58592 .40257 L
.58488 .39954 L
.58382 .39738 L
.58276 .39602 L
.58173 .39538 L
.58074 .39543 L
.57981 .3961 L
.57894 .39737 L
.57815 .3992 L
.57743 .40156 L
.57678 .40445 L
.57619 .40786 L
.57564 .41178 L
.57512 .41621 L
.57461 .42116 L
.57407 .42663 L
.57347 .43262 L
.57277 .43911 L
.57193 .44608 L
.57089 .4535 L
.5696 .46129 L
.568 .46938 L
.56603 .47764 L
.56363 .48591 L
.56073 .49401 L
.55729 .5017 L
.55327 .50877 L
.54864 .51499 L
.5434 .52017 L
.53758 .52418 L
.53124 .52698 L
.52446 .52865 L
.51736 .5294 L
.51008 .52951 L
.50278 .52936 L
.49561 .52935 L
Mistroke
.48873 .52983 L
.48228 .5311 L
.47638 .53333 L
.47109 .53657 L
.46647 .54079 L
.46254 .54583 L
.45929 .55151 L
.4567 .55761 L
.45472 .5639 L
.4533 .57018 L
.45237 .57628 L
.45187 .58206 L
.45175 .58741 L
.45193 .59227 L
.45237 .59659 L
.45302 .60035 L
.45383 .60353 L
.45476 .60614 L
.45579 .60819 L
.45687 .6097 L
.458 .61067 L
.45916 .61113 L
.46033 .61111 L
.46152 .61061 L
.46272 .60966 L
.46395 .60828 L
.46523 .60651 L
.46656 .60438 L
.46798 .60192 L
.46952 .59918 L
.47122 .59621 L
.47313 .5931 L
.47529 .58991 L
.47775 .58673 L
.48056 .58368 L
.48377 .58084 L
.48744 .57833 L
.49158 .57623 L
.49624 .57461 L
.5014 .57348 L
.50707 .57279 L
.5132 .57242 L
.51972 .57216 L
.52654 .57171 L
.53353 .57074 L
.54057 .56886 L
.5475 .56574 L
.55417 .56109 L
.56045 .55475 L
.56622 .5467 L
Mistroke
.57139 .53707 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00Xoooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^jiooooo`00YOooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0^Ooo
ool009[ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
402iooooo`00YOooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_oo
ool3o`000;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0;3ooooo002S
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool009cooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Looooo`03oeEEEOnYZJWo
oooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool0
09;ooooo1_l00004ooooo`03ojVYZOmEEEGooooo013ooooo00?o0000ooooooooool00oooool3o`00
0;3ooooo002Mooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`2`ooooo`00WOooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`2`ooooo`00WOooool00onYZJWoMgMgooooo`0;ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooo
oc8b<P0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo1Ol0
000<ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002[ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`2`ooooo`00[_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002R
ooooo`Ko00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002^oooo
o`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00Zoooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool0/?ooool00:_ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2`ooooo`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo
002[ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Jooooo`Go00001Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h04Oooool0
0ol0003oooooooooo`03ooooo`?o0000/?ooool009cooooo00?oV9RHob4Q8Oo^k^h03oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Mooooo`03ogMgMomVIVKooooo00_o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo002Nooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00
V_ooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2`ooooo`00V_ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l00006ooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo01Sooooo0_l0002Fooooo`00]Oooool00ol0003oooooooooo`0Hooooo`;o0000U_ooool0
0;Gooooo0_l0000Hooooo`04o`000?ooooooooooo`0009Gooooo002eooooo`03o`000?oooooooooo
01Oooooo00Co0000oooooooooooo0000UOooool00;Gooooo00?o0000ooooooooool05oooool01?l0
003oooooooooool0002Eooooo`00]Oooool00ol0003oooooooooo`0Gooooo`04o`000?oooooooooo
o`0009Gooooo002eooooo`03o`000?oooooooooo01Oooooo00Go0000ooooooooooooooooo`00002D
ooooo`00]Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0T_ooool00;Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo09;ooooo002eooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`2Booooo`00]Oooool2o`0001Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`2Booooo`00]Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0T_ooool00;Gooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo09;ooooo002eooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Booooo`00]Oooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0T_ooool00;Gooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo09;ooooo002e
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2B
ooooo`00]Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0T_ooool00;Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo09;ooooo002eooooo`;o00005_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo09;ooooo002eooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`2Booooo`00]Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0T_ooool00;Gooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo09;ooooo0009ooooo`Co000000So410@oooooooo
ooook^k^oc8b<_l0003o<S8bonk^kQ_ooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00Go
A4A4o`000?l0003o<S8bomgMg@0Nooooo`05odA4A?l0003o0000oc8b<_oMgMd07?ooool5o`0000Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd07?ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00?ooooo1_l00005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM01kooooo00GoA4A4o`000?l0003o<S8bomgMg@0Nooooo`03o`000?o^k^kooooo00Gooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd06_ooool4o`000008oa0@4?ooooooooooonk^k_lb
<S;o0000oc8b<_o^k^h3ooooo`002oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL06oooool00omEEEGoZJVYooooo`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0P
ooooo`03ogMgMolb<S;ooooo01_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`0Kooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00ooo
ool01_l0003oV9RHob4Q8Oo^k^koooooodA4A0Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo023o
oooo00?oMgMgoc8b<_ooool07Oooool00omEEEGoZJVYooooo`05ooooo`;o8B4Q2?ooool00omgMgOo
<S8booooo`0Kooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`001_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Aoooo
o`Ko00001?ooool00onYZJWoEEEEooooo`0@ooooo`03o`000?oooooooooo01?ooooo1_l00007oooo
o`03o`000?oooooooooo01;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
oonHV9So8B4Qonk^kP0Aooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool07?ooool0
0onYZJWoEEEEooooo`0@ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@00?ooooo000;ooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`00000Looooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool08?oo
ool00omgMgOo<S8booooo`0Mooooo`03oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool06ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Cooooo00Ko0000ooooooooooooV9RH
ob4Q8Oo^k^h?ooooo`03ogMgMolb<S;ooooo023ooooo00?oMgMgoc8b<_ooool07_ooool00olQ8B7o
ooooooooo`0>ooooo`03ogMgMolb<S;ooooo01_ooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000?ooooo000;ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`00000Looooo`03oeEEEOo<c<cooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00N
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`07oooool00omgMgOoIVIVooooo`0;ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`07?ooool2o`0001Gooooo00?o0000ooooooooool01?ooool01_l0003ooooo
ooooooooooooMgMgofIVIPcooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Nooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`07oooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
7?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool000_ooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01cooooo00?oZJVYogMgMooo
ool02oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`0Qooooo`03ojVYZOmgMgOooooo00_ooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool000_o
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Wooooo00Go410@oooo
oooooooooooooc8b<P0<ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool07_ooool0
1Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo00Gooooo0_l000001?nj^[[ooooooiRHV?l@410<ooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool07_ooool01Ol@413ooooooooooooooooo<S8b00co
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool000Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01Wooooo1Ol0000<ooooo`Co00007oooool4o`0001gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<
ooooo`Co00007Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Gooooo00Ko0000
oiRHV?l@413o0000ob4Q8Oo<c<`<ooooo`Co00007oooool4o`0001gooooo1Ol0000<ooooo`Co0000
6oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00;Gooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo09?ooooo
002eooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`2Cooooo`00]Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0Toooool00;Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo09?ooooo002eooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`2Dooooo`002oooooooo`0005Ko00002?ooool000_ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooo`000005ooooo`04o`000?ooooooooooo`0000Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`002oooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo00Kooooo002eooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`2Dooooo`00]Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0UOooool00;Gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo09Gooooo002eooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Eooooo`00]Ooo
ool00ol0003oooooooooo`0;ooooo`;o00002oooool00ol0003oooooooooo`2Eooooo`00]Oooool0
0ol0003oooooooooo`09ooooo`;o00003?ooool00ol0003oooooooooo`2Fooooo`00]Oooool2o`00
00Sooooo0_l0000>ooooo`03o`000?oooooooooo09Kooooo002`ooooo`oo00004?ooool00ol0003o
ooooooooo`2Fooooo`00[?ooool4o`0000Gooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`2Gooooo`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool0Uoooool00:[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo09Sooooo002Yooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`2Hooooo`00ZOooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0VOooool00:Sooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo09[ooooo002Xooooo`03o`000?oo
oooooooo00[ooooo0_l0000Dooooo`03o`000?oooooooooo09[ooooo002Wooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`2Kooooo`00Yoooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0W?ooool00:Ko
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo09go
oooo002Vooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03_ooool2o`000:3ooooo
002Uooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool2o`000:;ooooo002U
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool2o`000:Cooooo002Uoooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool5o`000:Kooooo002Uooooo`03
o`000?oooooooooo00_ooooo2_l0002[ooooo`00YOooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00;o0000/Oooool00:Gooooo00?o0000ooooooooool02?ooool2o`0000?ooooo00?o
0000ooooooooool0/?ooool00:Gooooo00?o0000ooooooooool01_ooool2o`0000Gooooo00?o0000
ooooooooool0/?ooool00:Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo0;3ooooo002Tooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00YOooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0/?ooool00:Gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00YOooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo0_l0002aooooo`00YOooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0/?ooool00:Gooooo
00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo0;3ooooo002Vooooo`04o`00
0?oooooo0000o`0000_ooooo00?o0000ooooooooool0/?ooool00:Oooooo0_l0000<ooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Jooooo`Go00001Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00Voooool00onHV9So8B4Qonk^kP0Aooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0/?ooool009cooooo00?oV9RHob4Q8Oo^k^h03oooool00omg
MgOo<S8booooo`04ooooo`?o0000/?ooool009gooooo00?oMgMgofIVI_ooool02oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool009kooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05o`00
0?nj^[[ooooooiRHV?l@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3o
oooo002Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool4o`0000Kooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000
/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00Zoooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooooooo
ool0/?ooool00:kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00[ooo
ool00ol0003oooooooooo`03ooooo`?o0000/?ooool00:kooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`2`ooooo`00Zoooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000
ooooooooool0/?ooool00:_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`oooo
o`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`Co0000
1_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002Looooo`03o`000?o^k^kooooo00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01Oooool00ol0003oooooooooo`2`ooooo`00W?ooool00omEEEGoZJVYooooo`05ooooo`;o8B4Q
2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Looooo`03ojVYZOmE
EEGooooo013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2`ooooo`00WOooool0
0olQ8B7oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00WOooool00omE
EEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`
ooooo`00WOooool00onYZJWoMgMgooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0/?ooool009[ooooo00Go410@oooooooooooooooooc8b<P0<ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0/?ooool009[ooooo1Ol0000<ooooo`Co00001_ooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002Sooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kPKooooo00?o0000ooooooooool0/?ooool00:Gooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0/?ooool00:Gooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo0ol0002`ooooo`00YOooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000^Oooool00:Gooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo00000;Wooooo002Uooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@402iooooo`00YOooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL0^Oooool00:?ooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^0;Wooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-10, -10, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.05 0.5 0.05 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-10)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-7.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-2.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(2.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(7.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(10)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-10)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-7.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-2.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(2.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(7.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(10)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.58995 .48076 m
.59226 .46332 L
.59365 .44659 L
.59424 .43111 L
.59416 .41727 L
.59353 .40525 L
.59248 .39512 L
.59112 .38684 L
.58954 .38027 L
.58781 .37527 L
.58602 .37164 L
.5842 .36921 L
.58241 .3678 L
.58068 .36724 L
.57904 .36739 L
.5775 .36812 L
.5761 .36933 L
.57484 .37092 L
.57373 .37283 L
.57278 .375 L
.572 .37739 L
.57139 .37998 L
.57096 .38275 L
.57069 .38569 L
.57059 .38882 L
.57064 .39215 L
.57083 .39572 L
.57114 .39955 L
.57156 .4037 L
.57205 .40823 L
.57257 .41319 L
.57309 .41866 L
.57355 .42471 L
.5739 .43141 L
.57406 .43883 L
.57396 .44698 L
.5735 .45588 L
.57259 .46547 L
.5711 .47561 L
.56893 .48609 L
.56596 .49659 L
.56209 .50671 L
.55726 .51598 L
.55143 .52394 L
.54464 .53023 L
.53699 .53465 L
.52865 .53726 L
.51987 .53841 L
.51095 .53866 L
.5022 .53869 L
Mistroke
.49391 .53918 L
.48634 .5406 L
.47966 .54323 L
.474 .5471 L
.46938 .55201 L
.46578 .5577 L
.46313 .56383 L
.46135 .57007 L
.46032 .57617 L
.45994 .58192 L
.46008 .5872 L
.46065 .59192 L
.46156 .59606 L
.46272 .59961 L
.46407 .60259 L
.46555 .60503 L
.46711 .60697 L
.46869 .60844 L
.47028 .60947 L
.47183 .61008 L
.47334 .61031 L
.47478 .61016 L
.47614 .60966 L
.47744 .60882 L
.47866 .60764 L
.47984 .60616 L
.48099 .60437 L
.48214 .6023 L
.48334 .59999 L
.48463 .59745 L
.48607 .59473 L
.48773 .5919 L
.48969 .58902 L
.49202 .58618 L
.4948 .58347 L
.49814 .581 L
.50209 .57885 L
.50672 .57709 L
.51208 .57571 L
.51815 .57464 L
.52491 .57365 L
.53225 .57237 L
.54001 .5703 L
.54798 .56685 L
.55592 .56145 L
.56355 .55362 L
.57063 .54315 L
.57693 .53013 L
.5823 .51495 L
.58665 .49823 L
Mistroke
.58995 .48076 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00Xoooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^jiooooo`00YOooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0^Ooo
ool009[ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
402iooooo`00YOooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_oo
ool3o`000;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0;3ooooo002S
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool009cooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Looooo`03oeEEEOnYZJWo
oooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool0
09;ooooo1_l00004ooooo`03ojVYZOmEEEGooooo013ooooo00?o0000ooooooooool00oooool3o`00
0;3ooooo002Mooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`2`ooooo`00WOooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`2`ooooo`00WOooool00onYZJWoMgMgooooo`0;ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooo
oc8b<P0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo1Ol0
000<ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002[ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`2`ooooo`00[_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002R
ooooo`Ko00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002^oooo
o`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00Zoooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool0/?ooool00:_ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2`ooooo`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo
002[ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Jooooo`Go00001Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01Oooooo1?l0
002Eooooo`00V_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool05_ooool2o`0000;ooooo00?o0000ooooooooool0Tooo
ool009;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000ooooooooool00oooool3
o`0001Kooooo00Go0000ooooooooooooooooo`00002Eooooo`00W?ooool00onHV9So8B4Qonk^kP0?
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo09;ooooo002Mooooo`03ogMgMomVIVKooooo00_ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`2Booooo`00W_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
09;ooooo002Jooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Aoooo
o`00V_ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l00006ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Aooooo`00]Oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0TOooool00;Gooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo097ooooo
002eooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`2Aooooo`00]Oooool2o`0001Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2A
ooooo`00]Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0T?ooool00;Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo093ooooo002eooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`2@ooooo`00]Oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0T?ooool00;Gooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo093ooooo002eooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2@ooooo`00]Oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0T?ooool00;Gooooo
0_l0000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0T?ooool00;Gooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo093ooooo002e
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2@
ooooo`00]Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0T?ooool00;Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo093ooooo002eooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`2@ooooo`00]Oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0T?ooool00;Gooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo093ooooo002eooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2@ooooo`00]Oooool2o`0001Oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2@ooooo`00]Oooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0T?ooool00;Gooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo093ooooo002e
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2A
ooooo`002Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hKooooo`03o`00
0?o^k^kooooo00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd07_ooool01Om4A4Co
0000o`000?lb<S;ogMgM01cooooo1Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM01cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`03ooooo`Go00001Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Nooooo`05odA4A?l0003o0000oc8b<_oMgMd0
7_ooool00ol0003ok^k^ooooo`05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01[o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool000_ooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00?oEEEEojVYZOooool01Ooo
ool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool08?ooool00omgMgOo<S8booooo`0Kooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06oooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Oo^k^koooooodA4A005ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`0Pooooo`03ogMgMolb<S;ooooo01gooooo00?oEEEEojVYZOoo
ool01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06oooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool000Ko00001Oooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41004Oooool6o`0000Cooooo00?oZJVYoeEEEOooool04?ooool00ol0
003oooooooooo`0Cooooo`Ko00001oooool00ol0003oooooooooo`0Booooo`Ko00000oooool00onH
V9So8B4Qonk^kP0Aooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`03ooooo`04o`000?nHV9So8B4Qonk^kQ7ooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0Looooo`03ojVYZOmEEEGooooo013ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool000_ooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000001cooooo00?o8B4Qooooooooool03_oo
ool00omgMgOo<S8booooo`0Pooooo`03ogMgMolb<S;ooooo01gooooo00?oV9RHob4Q8Oo^k^h03ooo
ool00omgMgOo<S8booooo`0Kooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00ooo
ool01Ol0003ooooooiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool08?ooool00omgMgOo<S8b
ooooo`0Nooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool06oooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool000_ooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000001cooooo00?oEEEEolc<c?ooool02oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<01kooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Oooooo`03ogMgMomVIVKo
oooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Looooo`;o00005_ooool00ol0003ooooooooo
o`03ooooo`06o`000?oooooooooooooooomgMgOoIVIV3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<
01kooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Oooooo`03oeEEEOo<c<cooooo00_ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c00Looooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`000003ooooo`002oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
7?ooool00onYZJWoMgMgooooo`0;ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo027ooooo00?oZJVYogMgMoooool0
2oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`002oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL06Oooool01Ol@413ooooooooooooooooo<S8b00cooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0Nooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00oooool2o`000004okZj^_oooooo
V9RHoa0@40cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Nooooo`05oa0@4?oo
oooooooooooooolb<S803?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`002Oooool00omEEEGoIVIVo`000004ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h06Oooool5o`0000cooooo1?l0000Oooooo`Co00007Oooool01OnHV9So
410@o`000?lQ8B7oc<c<00cooooo1?l0000Mooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool01?ooool01_l0003oV9RHoa0@4?l0003o8B4Qolc<c0cooooo1?l0000Oooooo`Co00007Ooo
ool5o`0000cooooo1?l0000Kooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`00]Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0T_ooool00;Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo09;ooooo002eooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`2Cooooo`00]Oooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0Toooool00;Gooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo09?ooooo000;oooooooo0000E_l0
0008ooooo`002oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`06ooooo`002oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Kooooo002e
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2D
ooooo`00]Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0U?ooool00;Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo09Cooooo002eooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`2Dooooo`00]Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0UOooool00;Gooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo09Gooooo002eooooo`;o00003_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo09Gooooo002eooooo`03o`000?oooooooooo00_o
oooo0_l0000:ooooo`03o`000?oooooooooo09Kooooo002eooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`2Fooooo`00]Oooool00ol0003ooooooooo
o`08ooooo`;o00003?ooool00ol0003oooooooooo`2Gooooo`00/_ooool>o`0000kooooo00?o0000
ooooooooool0Uoooool00:oooooo0ol00003ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool0Uoooool00:gooooo0_l00006ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0V?ooool00:cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo09Wooooo002[ooooo`03o`000?oooooooooo00Oooooo0_l0000Dooooo`03o`000?oo
oooooooo09[ooooo002Zooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`2Kooooo`00Z_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool0Voooool00:Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo09cooooo002Yooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool03oooool2o`0009oooooo002Xooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`2Oooooo`00Z?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00cooooo0_l0002Rooooo`00Z?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo0ol0002Tooooo`00Z?ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00;ooooo1ol0002Wooooo`00Yoooool00ol0003oooooooooo`0;ooooo`Go0000
[_ooool00:Oooooo00?o0000ooooooooool02oooool2o`000;7ooooo002Wooooo`03o`000?oooooo
oooo00Wooooo0ol0002booooo`00Yoooool00ol0003oooooooooo`08ooooo`04o`000?oooooooooo
o`000;;ooooo002Wooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00002b
ooooo`00Yoooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool00000/_ooool0
0:Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
0;3ooooo002Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`2`ooooo`00Z?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
0_l0002aooooo`00ZOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0/?ooool00:Wooooo0_l00003ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0/?ooool00:[ooooo1Ol00006ooooo`03o`000?oooooooooo0;3ooooo002/ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool009[ooooo1Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo
00?o0000ooooooooool0/?ooool009[ooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q
2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Kooooo`03oiRHV?lQ
8B7ok^k^017ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2`ooooo`00W?ooool0
0onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00WOooool00omg
MgOoIVIVooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`
ooooo`00W_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0/?ooool009[ooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<oooo
o`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002[ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00[_ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo0;3ooooo002_ooooo`03o`000?oooooooooo00?ooooo0ol0002`ooooo`00[_oo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`ooooo`00Zoooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo1?l00006ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool009cooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Go
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Looooo`03
oeEEEOnYZJWooooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0/?ooool009cooooo00?oZJVYoeEEEOooool04?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo0;3ooooo002Mooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool01?oo
ool3o`000;3ooooo002Mooooo`03oeEEEOo<c<cooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo0;3ooooo002Mooooo`03ojVYZOmgMgOooooo00_ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo
<S8b00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00V_ooool5o`00
00cooooo1?l00006ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:?ooooo1?l000002?l@413o
ooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1_ooool00ol0003oooooooooo`2`ooooo`00YOooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003ooooooooo
o`2`ooooo`00YOooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_oo
ool3o`000;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
002iooooo`00YOooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000^Ooo
ool00:Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@0;Wooooo002U
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`2iooooo`00Xoooool0
0omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0^Oooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-10, -10, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.05 0.5 0.05 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-10)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-7.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-2.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(2.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(7.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(10)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-10)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-7.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-2.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(2.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(7.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(10)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.59771 .40712 m
.59664 .39115 L
.59486 .37814 L
.59259 .36802 L
.59001 .36058 L
.58725 .35548 L
.58444 .35235 L
.58165 .35085 L
.57895 .35064 L
.57638 .35146 L
.57397 .35304 L
.57175 .35521 L
.56971 .35778 L
.56788 .36062 L
.56625 .36363 L
.56483 .36673 L
.56362 .36985 L
.56262 .37293 L
.56183 .37593 L
.56126 .37884 L
.5609 .38164 L
.56076 .3843 L
.56083 .38684 L
.56111 .38925 L
.5616 .39156 L
.56229 .39378 L
.56318 .39593 L
.56424 .39807 L
.56546 .40025 L
.56683 .40253 L
.56831 .405 L
.56989 .40777 L
.57151 .41096 L
.57313 .41472 L
.5747 .41923 L
.57613 .42466 L
.57734 .43121 L
.57821 .43905 L
.57861 .44829 L
.57836 .45898 L
.57728 .47098 L
.57515 .48398 L
.57177 .49742 L
.56696 .51049 L
.56061 .52224 L
.55275 .53179 L
.54353 .53857 L
.53332 .54253 L
.52261 .54425 L
.51196 .54477 L
Mistroke
.50194 .54522 L
.49299 .54652 L
.48543 .54913 L
.47938 .55308 L
.47485 .55807 L
.47171 .56367 L
.46982 .56946 L
.46897 .57507 L
.46897 .58028 L
.46966 .58495 L
.47087 .58902 L
.47248 .5925 L
.47437 .59542 L
.47645 .59784 L
.47864 .59979 L
.48088 .60134 L
.48312 .60253 L
.48531 .60338 L
.48741 .60393 L
.4894 .6042 L
.49125 .60419 L
.49296 .60392 L
.49451 .60339 L
.4959 .60261 L
.49715 .60157 L
.49828 .60029 L
.49932 .59878 L
.5003 .59705 L
.50129 .59512 L
.50235 .59301 L
.50356 .59076 L
.50501 .58842 L
.50682 .58604 L
.50909 .5837 L
.51195 .58145 L
.51552 .57937 L
.5199 .57747 L
.52519 .5757 L
.5314 .57386 L
.53849 .57159 L
.54634 .56831 L
.55468 .56323 L
.56319 .55552 L
.57145 .54447 L
.57903 .52978 L
.58557 .51167 L
.59079 .49095 L
.59456 .46884 L
.59688 .44672 L
.59787 .42583 L
Mistroke
.59771 .40712 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00Xoooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^jiooooo`00YOooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0^Ooo
ool009[ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
402iooooo`00YOooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_oo
ool3o`000;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0;3ooooo002S
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool009cooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Looooo`03oeEEEOnYZJWo
oooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool0
09;ooooo1_l00004ooooo`03ojVYZOmEEEGooooo013ooooo00?o0000ooooooooool00oooool3o`00
0;3ooooo002Mooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`2`ooooo`00WOooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`2`ooooo`00WOooool00onYZJWoMgMgooooo`0;ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooo
oc8b<P0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo1Ol0
000<ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002[ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`2`ooooo`00[_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002R
ooooo`Ko00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002^oooo
o`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00Zoooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool0/?ooool00:_ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2`ooooo`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo
002[ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`0001Sooooo0ol0002Fooooo`00]Oooool00ol0003oooooooooo`0F
ooooo`05o`000?ooooooooooooooool00000UOooool00;Gooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo09;ooooo002eooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2Booooo`00]Oooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0TOooool00;Gooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo097ooooo
002Jooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2Aooooo`00V_oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo097ooooo
002Booooo`Ko00000oooool00onHV9So8B4Qonk^kP0Aooooo`03o`000?oooooooooo00?ooooo0ol0
000Booooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0TOooool009cooooo00?oV9RH
ob4Q8Oo^k^h03oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`2@ooooo`00WOooool00omgMgOoIVIVooooo`0;oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0T?ooool009kooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`2@ooooo`00V_ooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0T?ooool009[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`Co00001_ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Soooool00;Go
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo08oo
oooo002eooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`2?ooooo`00]Oooool00ol0003oooooooooo`0Booooo`;o00002_ooool00ol0003ooooooooo
o`2?ooooo`00]Oooool2o`0001Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2?
ooooo`00]Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0Soooool00;Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo08oooooo002eooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`2?ooooo`00]Oooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0Soooool00;Gooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo08oooooo002eooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2?ooooo`00]Oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Soooool00;Gooooo
0_l0000Hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Soooool00;Gooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08oooooo002e
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2?
ooooo`00]Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0Soooool00;Gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo08oooooo002eooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`2?ooooo`00]Oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0Soooool00;Gooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo08oooooo002eooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2?ooooo`00]Oooool2o`0001Wo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2?ooooo`00]Oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Soooool00;Gooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08oooooo002e
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2@
ooooo`002Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hKooooo`03o`00
0?o^k^kooooo00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd07_ooool01Om4A4Co
0000o`000?lb<S;ogMgM01cooooo1Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM01cooooo00?o0000ooooooooool06?ooool01?l0003oooooooooooooool5o`0000Gooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd07_ooool01Om4A4Co0000o`000?lb<S;ogMgM01ko
oooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Joooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo000;ooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`03oeEEEOnYZJWooooo00Gooooo
0_lQ8B48ooooo`03ogMgMolb<S;ooooo023ooooo00?oMgMgoc8b<_ooool06oooool01OnHV9So8B4Q
onk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01_ooooo00?o0000oooooooo
ool06?ooool02Ol0003oooooooooooooooooV9RHo`000?o^k^koooooodA4A005ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`0Pooooo`03ogMgMolb<S;ooooo01gooooo00?oEEEEojVYZOooool01Ooo
ool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06oooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool000Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41004Oooool6o`0000Cooooo00?oZJVYoeEEEOooool04?ooool00ol0003ooooo
ooooo`0Cooooo`Ko00001oooool00ol0003oooooooooo`0Booooo`Ko00000oooool00onHV9So8B4Q
onk^kP0Aooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`03ooooo`03o`000?lQ8B7ok^k^017ooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`0Looooo`03ojVYZOmEEEGooooo013ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool000_ooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000001cooooo00?o8B4Qooooooooool03_ooool00omgMgOo
<S8booooo`0Pooooo`03ogMgMolb<S;ooooo01gooooo00?oV9RHob4Q8Oo^k^h03oooool00omgMgOo
<S8booooo`0Kooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00oooool01?l0003o
V9RHob4Q8Oo^k^h?ooooo`03ogMgMolb<S;ooooo023ooooo00?oMgMgoc8b<_ooool07_ooool00olQ
8B7oooooooooo`0>ooooo`03ogMgMolb<S;ooooo01_ooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000?ooooo000;ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00000Looooo`03oeEEEOo<c<cooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Nooooo`05o`000?lQ8B7o0000oc8b<_o<c<`07oooool00omgMgOoIVIVooooo`0;ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`07?ooool2o`0001Sooooo00?o0000ooooooooool00oooool01?l0003o
ooooogMgMomVIVH<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`07_ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<01oooooo00?oEEEEolc<c?ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01cooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo000;ooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Looooo`03ojVYZOmgMgOooooo00_o
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00?o
oooo00Co0000oooooooooooo00003?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
027ooooo00?oZJVYogMgMoooool02oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`002oooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL06Oooool01Ol@413ooooooooooooooooo<S8b00cooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`0Nooooo`05o`000?nj^[[ooooooiRHV?l@4100
3?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
0oooool2o`000003oooooonHV9So410@00cooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`0Nooooo`05oa0@4?oooooooooooooooolb<S803?ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`002Oooool00omEEEGo
IVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06Oooool5o`0000cooooo1?l0000Ooooo
o`Co00007Oooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l0000Mooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool00oooool01Ol0003o410@o`000?lQ8B7oc<c<00cooooo1?l0
000Oooooo`Co00007Oooool5o`0000cooooo1?l0000Kooooo`03oeEEEOmVIVKo000000Cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`00]Oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0TOooool00;Gooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo097ooooo002eooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2Aooooo`00]Oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0TOooool00;Gooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo097ooooo
000;oooooooo0000E_l00008ooooo`002oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Cooooo0_l00004ooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`06ooooo`002oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Kooooo002eoooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2Coooo
o`00]Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0Toooool00;Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo09?ooooo002eooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`2Dooooo`00]Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0U?ooool00;Gooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo09Cooooo002eooooo`;o00004_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo09Gooooo002eooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Eooooo`00]Oooool00ol0003ooooooooo
o`0>ooooo`;o00002?ooool00ol0003oooooooooo`2Eooooo`00]Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0U_ooool00;Gooooo00?o0000oooo
ooooool02_ooool3o`0000Wooooo00?o0000ooooooooool0Uoooool00;Gooooo00?o0000oooooooo
ool01oooool3o`0000cooooo00?o0000ooooooooool0Uoooool00;Cooooo2ol0000>ooooo`03o`00
0?oooooooooo09Sooooo002aooooo`?o000000?oooooo`000?ooool05_ooool00ol0003ooooooooo
o`2Hooooo`00[oooool2o`0000Cooooo0_l0000Eooooo`03o`000?oooooooooo09Wooooo002^oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`2Joooo
o`00[Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool0Voooool00:cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo09cooooo002/ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`2Mooooo`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00kooooo0_l0002Pooooo`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00cooooo0_l0002Rooooo`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wo
oooo0ol0002Tooooo`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
0_l0002Wooooo`00Z_ooool00ol0003oooooooooo`08ooooo`;o00001?ooool4o`000:Wooooo002Z
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2[
ooooo`00Z_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;o0000[_ooool00:_o
oooo00?o0000ooooooooool01oooool00ol0003oooooo`00002`ooooo`00Zoooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooo00000;3ooooo002/ooooo`03o`000?oooooooooo00Kooooo0_l0
002aooooo`00[?ooool00ol0003oooooooooo`06ooooo`;o0000/Oooool00:gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`2`ooooo`00[_ooool00ol0003oooooooooo`03ooooo`?o
0000/Oooool00:oooooo1ol0002booooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00V_ooool5o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Go
oooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009_ooooo
00?oV9RHob4Q8Oo^k^h04Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo
002Looooo`03oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool01?ooool3o`000;3ooooo002M
ooooo`03ogMgMomVIVKooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oo
oooooooo0;3ooooo002Nooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`2`ooooo`00V_ooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OnHV9So410@o`000?lQ8B7o
c<c<00cooooo1?l00006ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:_ooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002^ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool00:oooooo00?o0000ooooooooool00oooool3o`000;3o
oooo002^ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool00:_ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0/?ooool00:_ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`2`ooooo`00Zoooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00W?ooool00ol0003ok^k^ooooo`05oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool0
09cooooo00?oEEEEojVYZOooool01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`2`ooooo`00W?ooool00onYZJWoEEEEooooo`0@ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0/?ooool009gooooo00?o8B4Qooooooooool03_ooool00omgMgOo<S8b
ooooo`04ooooo`?o0000/?ooool009gooooo00?oEEEEolc<c?ooool02oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool009gooooo00?oZJVYogMgMoooool02ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?oooooo
oooooooooolb<S803?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`Go00003?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Xoooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooooooo0;3ooooo
002Uooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`00
0?oooooooooo0;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@4006ooooo`?o0000/?ooool00:Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo00000;Wooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00002iooooo`00YOooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
^Oooool00:Gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg0;Wooooo
002Sooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP2iooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-10, -10, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.05 0.5 0.05 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-10)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-7.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-2.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(2.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(7.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(10)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-10)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-7.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-2.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(2.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(7.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(10)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.59244 .35419 m
.5885 .34751 L
.58443 .34386 L
.58038 .34262 L
.57648 .34321 L
.57279 .34516 L
.56937 .34806 L
.56623 .35161 L
.56339 .35558 L
.56086 .35978 L
.55861 .36407 L
.55664 .36837 L
.55494 .37258 L
.55349 .37666 L
.5523 .38056 L
.55134 .38426 L
.55061 .38772 L
.5501 .39093 L
.54982 .39388 L
.54975 .39655 L
.54989 .39894 L
.55025 .40104 L
.55083 .40285 L
.55161 .40437 L
.55261 .40561 L
.5538 .40656 L
.55519 .40725 L
.55678 .4077 L
.55854 .40792 L
.56046 .40798 L
.56255 .40793 L
.56477 .40786 L
.56711 .40787 L
.56954 .40813 L
.57204 .40881 L
.57456 .41016 L
.57705 .41246 L
.57942 .41604 L
.58157 .42129 L
.58333 .42859 L
.58449 .43827 L
.58478 .45053 L
.58385 .46526 L
.58131 .4819 L
.57679 .4993 L
.57003 .51581 L
.56098 .52964 L
.54995 .53947 L
.53761 .54508 L
.52488 .54749 L
Mistroke
.51277 .54843 L
.50211 .54955 L
.49342 .55181 L
.48687 .55538 L
.4824 .55994 L
.47976 .56495 L
.47864 .56996 L
.47875 .57463 L
.4798 .57881 L
.48155 .58243 L
.48382 .58551 L
.48645 .58809 L
.48931 .59023 L
.49231 .592 L
.49536 .59345 L
.49839 .59461 L
.50135 .5955 L
.50418 .59616 L
.50686 .59658 L
.50934 .59677 L
.5116 .59675 L
.51363 .5965 L
.51541 .59604 L
.51695 .59537 L
.51827 .5945 L
.51939 .59342 L
.52035 .59215 L
.5212 .5907 L
.52202 .58908 L
.52289 .58731 L
.52391 .5854 L
.52521 .5834 L
.52692 .58132 L
.52921 .57918 L
.53222 .57697 L
.53611 .57465 L
.54099 .57203 L
.54694 .5688 L
.5539 .56439 L
.56169 .55799 L
.56996 .54859 L
.57823 .53528 L
.5859 .51753 L
.59238 .49565 L
.59723 .47079 L
.60022 .44483 L
.60135 .41981 L
.6008 .39746 L
.5989 .37888 L
.596 .36449 L
Mistroke
.59244 .35419 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00Xoooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^jiooooo`00YOooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0^Ooo
ool009[ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
402iooooo`00YOooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_oo
ool3o`000;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0;3ooooo002S
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool009cooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Looooo`03oeEEEOnYZJWo
oooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool0
09;ooooo1_l00004ooooo`03ojVYZOmEEEGooooo013ooooo00?o0000ooooooooool00oooool3o`00
0;3ooooo002Mooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`2`ooooo`00WOooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`2`ooooo`00WOooool00onYZJWoMgMgooooo`0;ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooo
oc8b<P0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo1Ol0
000<ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002[ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`2`ooooo`00[_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002R
ooooo`Ko00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002^oooo
o`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00Zoooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool0/?ooool00:_ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2`ooooo`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo
002[ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`0Hooooo`;o0000U_ooool00;Gooooo00?o0000ooooooooool05Oooool3o`0000;o
oooo00?o0000ooooooooool0Toooool00;Gooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo09;ooooo002eooooo`;o00005Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo09;ooooo002eooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`2Aooooo`00]Oooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0TOooool00;Gooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo093ooooo002eooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2@ooooo`00]Ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Sooo
ool009[ooooo1Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo08oooooo002J
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Sooo
ool009;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000ooooooooool00oooool3
o`00013ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`2>ooooo`00W?ooool00onH
V9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo08kooooo002Mooooo`03ogMgMomVIVKooooo00_o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`2>ooooo`00W_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo08kooooo002Jooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`2>ooooo`00V_ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l00006ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2>ooooo`00
]Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
S_ooool00;Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo08kooooo002eooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`2>ooooo`00]Oooool2o`0000oooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`2>ooooo`00]Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0S_ooool00;Gooooo00?o0000ooooooooool03oooool2o`0000kooooo
00?o0000ooooooooool0S_ooool00;Gooooo00?o0000ooooooooool04?ooool7o`0000Sooooo00?o
0000ooooooooool0S_ooool00;Gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo08kooooo002eooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`2>ooooo`00]Oooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0S_ooool00;Gooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08kooooo002eooooo`;o00006_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08kooooo002eooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2>ooooo`00]Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0S_ooool00;Go
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08ko
oooo002eooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`2>ooooo`00]Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0S_ooool00;Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo08kooooo002eooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`2>ooooo`00]Oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0S_ooool00;Gooooo0_l0000Kooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0S_ooool00;Gooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo08kooooo002eooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2>ooooo`00]Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Soooool000Wo
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^6oooool00ol0003ok^k^oooo
o`05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01kooooo00GoA4A4o`000?l0003o
<S8bomgMg@0Looooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Loooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01Ol00005ooooo`;o8B4Q1Oooool01Om4
A4Co0000o`000?lb<S;ogMgM01kooooo00GoA4A4o`000?l0003o<S8bomgMg@0Nooooo`03o`000?o^
k^kooooo00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd06_ooool4o`000008oa0@
4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`002oooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL06oooool00omEEEGoZJVYooooo`05ooooo`;o8B4Q2?ooool0
0omgMgOo<S8booooo`0Pooooo`03ogMgMolb<S;ooooo01_ooooo00GoV9RHob4Q8Oo^k^koooooodA4
A005ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`03o`000?oooooooooo01Wooooo00So
0000ooooooooooooV9RHob4Q8Ol0003oooooodA4A0Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
023ooooo00?oMgMgoc8b<_ooool07Oooool00omEEEGoZJVYooooo`05ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`0Kooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`001_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400A
ooooo`Ko00001?ooool00onYZJWoEEEEooooo`0@ooooo`03o`000?oooooooooo01?ooooo1_l00007
ooooo`03o`000?oooooooooo01;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`07o`000?oooooooooooooooonHV9So0000
onk^kP0Aooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool07?ooool00onYZJWoEEEE
ooooo`0@ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@00?ooooo000;ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`00000Looooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool08?ooool00omgMgOo
<S8booooo`0Mooooo`03oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool06oooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo00;ooooo00?o0000ob4Q8Oo^k^h03oooool00omgMgOo
<S8booooo`0Pooooo`03ogMgMolb<S;ooooo01kooooo00?o8B4Qooooooooool03_ooool00omgMgOo
<S8booooo`0Kooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003oooo
o`002oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007?ooool00omE
EEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`07_ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<01oooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01cooooo
0_l0000Jooooo`03o`000?oooooooooo00;ooooo00?o0000ogMgMomVIVH03?ooool01Ol0003o8B4Q
o`000?lb<S;oc<c<01kooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Oooooo`03oeEEEOo<c<cooooo
00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Looooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`002oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41007?ooool00onYZJWoMgMgooooo`0;ooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000cooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`0Qooooo`03ojVYZOmgMgOooooo00_ooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
0oooool000_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Wooooo
00Go410@oooooooooooooooooc8b<P0<ooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool07_ooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo00;o000000?ooooooiRHV?l@41003?ooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo01kooooo00Go410@oooooooooooooooooc8b<P0<
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo0009ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0Iooooo`Go00003?ooool4o`0001oooooo1?l0000Mooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
3?ooool4o`0001gooooo00?o0000ooooooooool06Oooool01?l0003ooooooooooonHV9P2o`000003
ob4Q8Oo<c<cooooo00_ooooo1?l0000Oooooo`Co00007Oooool5o`0000cooooo1?l0000Kooooo`03
oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00]Oooool00ol0003o
ooooooooo`0Iooooo`05o`000?ooooooooooooooool00000T_ooool00;Gooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo093ooooo002eooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2@ooooo`00]Ooo
ool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool00000Toooool00;Gooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo097ooooo000;
oooooooo0000E_l00008ooooo`002oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo0_l00004ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool0
00_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`06ooooo`00]Oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0T_ooool00;Gooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo09;ooooo
002eooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`2Cooooo`00]Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0Toooool00;Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo09?ooooo002eooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`2Dooooo`00]Oooool2o`0001Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`2Dooooo`00]Oooool00ol0003oooooooooo`0Aooooo`;o00001Ooo
ool00ol0003oooooooooo`2Eooooo`00]Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0UOooool00;Gooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo09Kooooo002eooooo`03o`000?oooooooooo00go
oooo0_l00008ooooo`03o`000?oooooooooo09Kooooo002eooooo`03o`000?oooooooooo00_ooooo
0_l00009ooooo`03o`000?oooooooooo09Oooooo002eooooo`03o`000?oooooooooo00Sooooo0ol0
000;ooooo`03o`000?oooooooooo09Oooooo002eooooo`03o`000?oooooooooo00So00003_ooool0
0ol0003oooooooooo`2Gooooo`00]Oooool3o`0001Gooooo00?o0000ooooooooool0V?ooool00;;o
oooo1?l0000Fooooo`03o`000?oooooooooo09Wooooo002`ooooo`;o00000oooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo09[ooooo002_ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool04Oooool2o`0009gooooo002_ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`2Mooooo`00[_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00kooooo0_l0002Pooooo`00[_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0X?ooool00:kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0:7ooooo002^ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02Oooool3o`000:Cooooo002^ooooo`03o`000?oooooo
oooo00Cooooo0_l00009ooooo`03o`000?oooooooooo0:Gooooo002^ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2Vooooo`00[oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Gooooo0_l0002Yooooo`00[oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Z?ooool00;3ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`;o0000Z_ooool00;7ooooo0_l00002
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0ZOooool00;?ooooo0ol00005oooo
o`03o`000?oooooooooo0:[ooooo002eooooo`Ko0000[Oooool00;Gooooo0_l0002aooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00V_ooool5o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo
0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009_ooooo00?o
V9RHob4Q8Oo^k^h04Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002L
ooooo`03oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool01?ooool3o`000;3ooooo002Moooo
o`03ogMgMomVIVKooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo0;3ooooo002Nooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`2`ooooo`00V_ooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OnHV9So410@o`000?lQ8B7oc<c<
00cooooo1?l00006ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:_ooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002^ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0/?ooool00:oooooo00?o0000ooooooooool00oooool3o`000;3ooooo
002^ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool00:_ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0/?ooool00:_ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`2`ooooo`00Zoooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00W?ooool00ol0003ok^k^ooooo`05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009co
oooo00?oEEEEojVYZOooool01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`2`ooooo`00W?ooool00onYZJWoEEEEooooo`0@ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0/?ooool009gooooo00?o8B4Qooooooooool03_ooool00omgMgOo<S8boooo
o`04ooooo`?o0000/?ooool009gooooo00?oEEEEolc<c?ooool02oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool009gooooo00?oZJVYogMgMoooool02oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?oooooooooo
oooooolb<S803?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Joooo
o`Go00003?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Xoooool4o`000008
oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooooooo0;3ooooo002U
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oo
oooooooo0;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4006ooooo`?o0000/?ooool00:Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo00000;Wooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
002iooooo`00YOooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100^Ooo
ool00:Gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg0;Wooooo002S
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP2iooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-10, -10, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.05 0.5 0.05 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-10)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-7.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-2.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(2.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(7.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(10)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-10)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-7.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-2.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(2.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(7.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(10)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.57851 .3409 m
.57324 .34305 L
.56832 .3467 L
.56381 .3513 L
.55973 .35645 L
.5561 .36186 L
.55289 .36734 L
.5501 .37275 L
.54769 .378 L
.54565 .38305 L
.54393 .38785 L
.54253 .39238 L
.54141 .39663 L
.54055 .4006 L
.53994 .40426 L
.53956 .40763 L
.5394 .41068 L
.53945 .41343 L
.5397 .41586 L
.54015 .41797 L
.54079 .41974 L
.54162 .42118 L
.54265 .42228 L
.54385 .42301 L
.54524 .42338 L
.5468 .42338 L
.54853 .423 L
.55042 .42224 L
.55247 .42111 L
.55466 .41962 L
.55698 .4178 L
.55944 .4157 L
.56203 .41339 L
.56476 .41097 L
.56761 .40857 L
.57058 .40637 L
.57368 .40462 L
.57687 .40364 L
.58011 .40386 L
.58331 .40582 L
.58634 .41015 L
.58894 .41757 L
.59077 .42875 L
.59132 .44409 L
.58996 .46332 L
.586 .48512 L
.57888 .50692 L
.5685 .52557 L
.55539 .5386 L
.54081 .5457 L
Mistroke
.52641 .54869 L
.51366 .55018 L
.5035 .55209 L
.49624 .55508 L
.49171 .55894 L
.48951 .56317 L
.48916 .56731 L
.49023 .57111 L
.49234 .57446 L
.4952 .57733 L
.49858 .57977 L
.5023 .58183 L
.50623 .58356 L
.51024 .58499 L
.51425 .58614 L
.51818 .58703 L
.52197 .58765 L
.52556 .58802 L
.52889 .58815 L
.53194 .58804 L
.53468 .58771 L
.53708 .58719 L
.53914 .58648 L
.54087 .58561 L
.54228 .5846 L
.54341 .58346 L
.5443 .5822 L
.54503 .58081 L
.54569 .57929 L
.54637 .57763 L
.54721 .57581 L
.54836 .57379 L
.54998 .57152 L
.55227 .56892 L
.55538 .56582 L
.55948 .56192 L
.56463 .55675 L
.57081 .54961 L
.57778 .53954 L
.58511 .52554 L
.59217 .50691 L
.59823 .48371 L
.60261 .45715 L
.60488 .42947 L
.60493 .40328 L
.60297 .38083 L
.59943 .36341 L
.59479 .35133 L
.58951 .34413 L
.58399 .34097 L
Mistroke
.57851 .3409 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00Xoooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^jiooooo`00YOooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0^Ooo
ool009[ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
402iooooo`00YOooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_oo
ool3o`000;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0;3ooooo002S
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool009cooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Looooo`03oeEEEOnYZJWo
oooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool0
09;ooooo1_l00004ooooo`03ojVYZOmEEEGooooo013ooooo00?o0000ooooooooool00oooool3o`00
0;3ooooo002Mooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`2`ooooo`00WOooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`2`ooooo`00WOooool00onYZJWoMgMgooooo`0;ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooo
oc8b<P0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo1Ol0
000<ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002[ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`2`ooooo`00[_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002R
ooooo`Ko00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002^oooo
o`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00Zoooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool0/?ooool00:_ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2`ooooo`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo
002[ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`0Gooooo`Co0000UOooool00;Gooooo00?o0000ooooooooool05Oooool2o`0000Co
oooo00?o0000ooooooooool0T_ooool00;Gooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo097ooooo002eooooo`;o00005?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo093ooooo002eooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`2@ooooo`00]Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Soooool00;Gooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo08oooooo002eooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2?ooooo`00]Ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0S_oo
ool009[ooooo1Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08kooooo002J
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0S_oo
ool009;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000ooooooooool00oooool3
o`0000kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2=ooooo`00W?ooool00onH
V9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo08gooooo002Mooooo`03ogMgMomVIVKooooo00_o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`2=ooooo`00W_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo08gooooo002Jooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`2=ooooo`00V_ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l00006ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`2=ooooo`00
]Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
SOooool00;Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo08cooooo002eooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`2<ooooo`00]Oooool2o`0000cooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`2<ooooo`00]Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo0_l00008ooooo`03o`000?oooooooooo08cooooo002eooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02?ooool2o`0000;ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`2<ooooo`00]Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08cooooo002e
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0S?ooool00;Gooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`04ooooo`;o00002?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo08cooooo002eooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0S?ooool00;Gooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000000_o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2<ooooo`00]Oooool2o`0000cooooo
1?l0000<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0S?ooool00;Gooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo08cooooo002e
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2<
ooooo`00]Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0S?ooool00;Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo08cooooo002eooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`2<ooooo`00]Oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0S?ooool00;Gooooo00?o0000ooooooooool07?ooool0
1Ol0003ooooooooooooooooo000008oooooo002eooooo`03o`000?oooooooooo01cooooo00Go0000
ooooooooooooooooo`00002?ooooo`00]Oooool2o`0001gooooo00Go0000ooooooooooooooooo`00
002?ooooo`00]Oooool00ol0003oooooooooo`0Looooo`05o`000?ooooooooooooooool00000Sooo
ool00;Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo08gooooo002eooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`2=ooooo`002Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^hKooooo`03o`000?o^k^kooooo00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
7_ooool01Om4A4Co0000o`000?lb<S;ogMgM01cooooo1Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM01cooooo00?o0000ooooooooool06oooool6o`0000Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd07_ooool01Om4A4Co0000o`000?lb<S;ogMgM01kooooo00?o
0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Jooooo`Co0000
00So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo000;ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`03oeEEEOnYZJWooooo00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo023ooooo00?oMgMgoc8b<_ooool06oooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01_ooooo00?o0000ooooooooool06ooo
ool01_l0003oV9RHob4Q8Oo^k^ko0000odA4A0Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo023o
oooo00?oMgMgoc8b<_ooool07Oooool00omEEEGoZJVYooooo`05ooooo`;o8B4Q2?ooool00omgMgOo
<S8booooo`0Kooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`001_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Aoooo
o`Ko00001?ooool00onYZJWoEEEEooooo`0@ooooo`03o`000?oooooooooo01?ooooo1_l00007oooo
o`03o`000?oooooooooo01;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Kooooo`05o`000?ooooooV9RHob4Q8Ol000004Oooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01cooooo00?oZJVYoeEEEOooool04?ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`002oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007?oo
ool00olQ8B7oooooooooo`0>ooooo`03ogMgMolb<S;ooooo023ooooo00?oMgMgoc8b<_ooool07Ooo
ool00onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;ooooo01_ooooo00?o0000ooooooooool06ooo
ool01_l0003ooooooooooonHV9So0000onk^kPoooooo00?oMgMgoc8b<_ooool08?ooool00omgMgOo
<S8booooo`0Nooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool06oooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool000_ooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000001cooooo00?oEEEEolc<c?ooool02oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<01kooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Oooooo`03ogMgMomV
IVKooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Looooo`;o00007?ooool01_l0003ooooo
oooooooooooo0000ofIVIPcooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Nooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`07oooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
7?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool000_ooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01cooooo00?oZJVYogMgMooo
ool02oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool00_ooool2o`0000cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Qooooo`03
ojVYZOmgMgOooooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41000oooool000_ooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg01Wooooo00Go410@oooooooooooooooooc8b<P0<ooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool07_ooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0Jooooo`07o`000?oooooo0000okZj^_l0003o
V9RHoa0@400<ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool07_ooool01Ol@413o
oooooooooooooooo<S8b00cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool000Wooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^01Wooooo1Ol0000<ooooo`Co00007oooool4o`0001gooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c00<ooooo`Co00007Oooool00ol0003oooooooooo`0Jooooo`07o`000?oo
ooooV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`Co00007oooool4o`0001gooooo1Ol0000<ooooo`Co
00006oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00;Go
oooo00?o0000ooooooooool06_ooool01Ol0003ooooooooooooooooo0000097ooooo002eooooo`03
o`000?oooooooooo01[ooooo00Go0000ooooooooooooooooo`00002Aooooo`00]Oooool00ol0003o
ooooooooo`0Jooooo`04o`000?ooooooooooo`0009;ooooo002eooooo`03o`000?oooooooooo01Wo
oooo00Go0000ooooooooooooooooo`00002Booooo`00]Oooool00ol0003oooooooooo`0Iooooo`05
o`000?ooooooooooooooool00000T_ooool000_oooooool0001Fo`0000Sooooo000;ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000003ooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool000_ooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000002_ooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`06ooooo`00]Oooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool0
0000Toooool00;Gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo097ooooo002eooooo`03o`000?oooooooooo01Oooooo00Go0000oooooooooooooooo
o`00002Dooooo`00]Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0T_ooool00;Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo09;ooooo002eooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`2Cooooo`00]Oooool2o`0001Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`2Cooooo`00]Oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0Toooool00;Gooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo09Cooooo002eooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Eooooo`00]Oooool00ol0
003oooooooooo`0?ooooo`;o00001_ooool00ol0003oooooooooo`2Fooooo`00]Oooool00ol0003o
ooooooooo`0=ooooo`;o00002?ooool00ol0003oooooooooo`2Fooooo`00]Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Uoooool00;Gooooo00?o
0000ooooooooool02Oooool3o`0000[ooooo00?o0000ooooooooool0Uoooool00;Gooooo0_l00000
0ooooooo0000o`000007o`0000cooooo00?o0000ooooooooool0V?ooool00;Gooooo0ol0000Doooo
o`03o`000?oooooooooo09Wooooo002cooooo`?o00005Oooool00ol0003oooooooooo`2Jooooo`00
/_ooool01?l0003oooooooooool0000Dooooo`03o`000?oooooooooo09_ooooo002aooooo`05o`00
0?ooooooooooooooool000004oooool00ol0003oooooooooo`2Looooo`00/Oooool01Ol0003ooooo
oooooooooooo000001;ooooo00?o0000ooooooooool0WOooool00;7ooooo00Go0000oooooooooooo
ooooo`00000Aooooo`03o`000?oooooooooo09kooooo002booooo`04o`000?ooooooooooo`00013o
oooo00?o0000ooooooooool0Woooool00;;ooooo00Co0000oooooooooooo00003oooool00ol0003o
ooooooooo`2Pooooo`00/oooool01?l0003oooooo`000?l0000>ooooo`03o`000?oooooooooo0:3o
oooo002dooooo`;o00003_ooool00ol0003oooooooooo`2Qooooo`00]Oooool3o`0000cooooo00?o
0000ooooooooool0XOooool00;Gooooo00?o0000ooooooooool00ol00007ooooo`;o0000Y?ooool0
0;Gooooo00?o0000ooooooooool00oooool7o`000:Kooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool009[ooooo1Ol00005ooooo`;o8B4Q1Oooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009[ooooo00GoV9RHob4Q
8Oo^k^koooooodA4A005ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo0;3ooooo002Kooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`2`ooooo`00W?ooool00onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;ooooo00Co
oooo0ol0002`ooooo`00WOooool00omgMgOoIVIVooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`2`ooooo`00W_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000okZj^_ooooooV9RH
oa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c00<ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002[ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00[_oo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002_ooooo`03o`000?oooooo
oooo00?ooooo0ol0002`ooooo`00[_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
0;3ooooo002[ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`oooo
o`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool00:_ooooo1?l00006ooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool009cooooo00?o
0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`00
0?oooooooooo0;3ooooo002Looooo`03oeEEEOnYZJWooooo00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009cooooo00?oZJVYoeEEEOooool04?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002Mooooo`03ob4Q8Ooooooooooo
00kooooo00?oMgMgoc8b<_ooool01?ooool3o`000;3ooooo002Mooooo`03oeEEEOo<c<cooooo00_o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo002Mooooo`03
ojVYZOmgMgOooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00
V_ooool01Ol@413ooooooooooooooooo<S8b00cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2`ooooo`00V_ooool5o`0000cooooo1?l00006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00:?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1_ooool00ol0
003oooooooooo`2`ooooo`00YOooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01_ooool00ol0003oooooooooo`2`ooooo`00YOooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41001_ooool3o`000;3ooooo002Uooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`00002iooooo`00YOooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool00000^Oooool00:Gooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@0;Wooooo002Uooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`2iooooo`00Xoooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h0^Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-10, -10, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.05 0.5 0.05 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-10)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-7.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-2.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(2.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(7.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(10)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-10)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-7.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-2.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(2.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(7.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(10)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.56189 .35546 m
.55648 .36191 L
.55166 .36854 L
.54744 .37511 L
.54377 .38147 L
.54064 .38753 L
.53799 .39325 L
.53579 .39861 L
.534 .40363 L
.53259 .40829 L
.53152 .41262 L
.53076 .41663 L
.53028 .42031 L
.53005 .4237 L
.53006 .42678 L
.53027 .42955 L
.53069 .43203 L
.5313 .43421 L
.53208 .43608 L
.53304 .43764 L
.53415 .43887 L
.53543 .43977 L
.53686 .44031 L
.53843 .44049 L
.54014 .44029 L
.54198 .43968 L
.54393 .43866 L
.54599 .43721 L
.54815 .43532 L
.55039 .433 L
.55272 .43024 L
.55513 .42707 L
.55763 .42352 L
.56024 .41964 L
.56298 .41549 L
.56587 .41119 L
.56896 .40687 L
.57227 .40275 L
.57583 .39912 L
.57965 .3964 L
.58369 .39521 L
.58783 .39636 L
.59185 .40091 L
.59533 .4101 L
.59757 .42504 L
.59761 .44609 L
.5943 .47193 L
.58669 .49888 L
.57461 .52188 L
.55921 .53725 L
Mistroke
.54274 .54504 L
.52765 .54836 L
.51567 .55044 L
.5074 .55296 L
.50265 .55613 L
.50081 .5596 L
.50123 .563 L
.5033 .5661 L
.50655 .56883 L
.51062 .57117 L
.51523 .57313 L
.52019 .57473 L
.52532 .57596 L
.53048 .57681 L
.53558 .57727 L
.54051 .57734 L
.54519 .57702 L
.54956 .57633 L
.55356 .57532 L
.55716 .57403 L
.56033 .57255 L
.56304 .57093 L
.56532 .56925 L
.56716 .56757 L
.5686 .56592 L
.56968 .56432 L
.57047 .56276 L
.57104 .56122 L
.5715 .55962 L
.57196 .55789 L
.57256 .55591 L
.57349 .55354 L
.57491 .55058 L
.577 .54676 L
.57992 .54168 L
.58376 .53478 L
.58847 .52533 L
.59383 .51245 L
.59935 .49538 L
.60434 .47387 L
.60802 .44871 L
.60971 .42188 L
.60906 .39618 L
.60611 .3743 L
.60129 .35799 L
.59516 .34769 L
.58833 .34285 L
.58129 .34235 L
.57439 .34497 L
.56788 .34962 L
Mistroke
.56189 .35546 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00Xoooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^jiooooo`00YOooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0^Ooo
ool009[ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
402iooooo`00YOooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_oo
ool3o`000;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0;3ooooo002S
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool009cooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Looooo`03oeEEEOnYZJWo
oooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool0
09;ooooo1_l00004ooooo`03ojVYZOmEEEGooooo013ooooo00?o0000ooooooooool00oooool3o`00
0;3ooooo002Mooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`2`ooooo`00WOooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`2`ooooo`00WOooool00onYZJWoMgMgooooo`0;ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooo
oc8b<P0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo1Ol0
000<ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002[ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`2`ooooo`00[_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002R
ooooo`Ko00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002^oooo
o`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00Zoooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool0/?ooool00:_ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2`ooooo`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo
002[ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`0Hooooo`?o0000UOooool00;Gooooo00?o0000ooooooooool05_ooool2o`0000?o
oooo0_l0002Cooooo`00]Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0T?ooool00;Gooooo0_l0000Eooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0T?ooool00;Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo08oooooo002eooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`2?ooooo`00]Oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0S_ooool00;Gooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo08kooooo002eooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2=ooooo`00V_ooool5
o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0SOooool009[ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2=ooooo`00T_ooool6
o`0000?ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0003oooooooooo`03ooooo`?o00003Oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo08cooooo002Looooo`03oiRHV?lQ8B7ok^k^
00oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0S?ooool009gooooo00?oMgMgofIVI_ooool02oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo08cooooo002Nooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool0S?ooool009[ooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo08co
oooo002Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool4o`0000Kooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo08_ooooo002eooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2;ooooo`00]Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00cooooo0_l00007ooooo`03o`000?oo
oooooooo08_ooooo002eooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool0
1?l0003oooooooooool00006ooooo`03o`000?oooooooooo08_ooooo002eooooo`;o00002_ooool0
0ol0003oooooooooo`0:ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo08_ooooo002eooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Roooool00;Go
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2;ooooo`00]Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo08_ooooo002eooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0Roooool00;Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2;
ooooo`00]Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02Oooool01Ol0003ooooooooooooooooo000008gooooo002eooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`05o`000?oooooooooo
ooooool00000SOooool00;Gooooo0_l00008ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02oooool01Ol0003ooooooooooooooooo000008gooooo002eooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`05o`000?oooooooooo
ooooool00000SOooool00;Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00cooooo00Go0000ooooooooooooooooo`00002=ooooo`00]Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03Oooool01Ol0
003ooooooooooooooooo000008gooooo002eooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0>ooooo`05o`000?ooooooooooooooool00000SOooool0
0;Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03o`00013ooooo00Go0000oooo
ooooooooooooo`00002=ooooo`00]Oooool00ol0003oooooooooo`09ooooo`?o00004_ooool01Ol0
003ooooooooooooooooo000008gooooo002eooooo`03o`000?oooooooooo01kooooo00Go0000oooo
ooooooooooooo`00002=ooooo`00]Oooool00ol0003oooooooooo`0Nooooo`05o`000?oooooooooo
ooooool00000SOooool00;Gooooo0_l0000Oooooo`05o`000?ooooooooooooooool00000SOooool0
0;Gooooo00?o0000ooooooooool07_ooool01Ol0003ooooooooooooooooo000008gooooo002eoooo
o`03o`000?oooooooooo01kooooo00Go0000ooooooooooooooooo`00002=ooooo`00]Oooool00ol0
003oooooooooo`0Nooooo`04o`000?ooooooooooo`0008kooooo0009ooooo`Co000000So410@oooo
ooooooook^k^oc8b<_l0003o<S8bonk^kQ_ooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@0Nooooo`05odA4A?l0003o0000oc8b<_oMgMd07?ooool5o`00
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd07?ooool00ol0003oooooooooo`0L
ooooo`Ko00001?ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Nooooo`05odA4A?l0
003o0000oc8b<_oMgMd07_ooool00ol0003ok^k^ooooo`05ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM01[ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0ooo
ool000_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00?o
EEEEojVYZOooool01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool08?ooool00omgMgOo<S8boooo
o`0Kooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0
6oooool00ol0003oooooooooo`0Looooo`06oiRHV?l0003ok^k^oooooom4A4Co00001?ooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool08?ooool00omgMgOo<S8booooo`0Mooooo`03oeEEEOnYZJWooooo
00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01_ooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo0006o`0000Gooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@017ooooo1_l00004ooooo`03ojVYZOmEEEGooooo013ooooo00?o0000
ooooooooool04oooool6o`0000Oooooo00?o0000ooooooooool04_ooool6o`0000?ooooo00?oV9RH
ob4Q8Oo^k^h04Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01gooooo00Go0000
ob4Q8Oo^k^koooooo`00000?ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool07?oo
ool00onYZJWoEEEEooooo`0@ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00?ooooo000;ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`00000Looooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool0
8?ooool00omgMgOo<S8booooo`0Mooooo`03oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool0
6oooool00ol0003oooooooooo`0Mooooo`04o`000?nHV9So8B4Qo`0000oooooo00?oMgMgoc8b<_oo
ool08?ooool00omgMgOo<S8booooo`0Nooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_oo
ool06oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool000_o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001cooooo00?oEEEEolc<
c?ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01kooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Oooooo`03ogMgMomVIVKooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Looooo`;o0000
7_ooool01?l0003oooooogMgMol0000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`07_ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<01oooooo00?oEEEEolc<c?ooool02oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<01cooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
000;ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Looooo`03ojVY
ZOmgMgOooooo00_ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Mooooo`04o`00
0?ooooooooooo`0000cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Qooooo`03
ojVYZOmgMgOooooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41000oooool000_ooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg01Wooooo00Go410@oooooooooooooooooc8b<P0<ooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool07_ooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0Looooo`05o`000?nj^[[ooooooiRHV?l00000
3?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01kooooo00Go410@oooooooooooo
oooooc8b<P0<ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo0009ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0Iooooo`Go00003?ooool4o`0001oooooo1?l0000Mooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`03?ooool4o`0001gooooo00?o0000ooooooooool07?ooool01Ol0003o410@o`000?lQ
8B7o000000cooooo1?l0000Oooooo`Co00007Oooool5o`0000cooooo1?l0000Kooooo`03oeEEEOmV
IVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00]Oooool00ol0003ooooooooo
o`0Looooo`04o`000?ooooooooooo`00093ooooo002eooooo`03o`000?oooooooooo01_ooooo00Go
0000ooooooooooooooooo`00002@ooooo`00]Oooool00ol0003oooooooooo`0Kooooo`05o`000?oo
ooooooooooooool00000T?ooool00;Gooooo00?o0000ooooooooool06oooool01Ol0003ooooooooo
oooooooo0000093ooooo002eooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`2>ooooo`002oooooooo`0005Ko00002?ooool000_ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool2
o`0000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01_ooool000_ooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`06ooooo`00]Oooool00ol0003oooooooooo`0Iooooo`05o`000?oooooooooooooo
ool00000T_ooool00;Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo093ooooo002eooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`2@ooooo`00]Oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0TOooool00;Gooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo097ooooo002eooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2Aooooo`00]Oooool2o`0001Ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2Booooo`00]Oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0T_ooool00;Gooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo09?ooooo002e
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2D
ooooo`00]Oooool00ol0003oooooooooo`0@ooooo`;o00001oooool00ol0003oooooooooo`2Doooo
o`00]Oooool00ol0003oooooooooo`0=ooooo`?o00002?ooool00ol0003oooooooooo`2Eooooo`00
]Oooool00ol0003oooooooooo`09ooooo`Co00002oooool00ol0003oooooooooo`2Eooooo`00]Ooo
ool00ol0003oooooooooo`04ooooo`Go00003_ooool00ol0003oooooooooo`2Fooooo`00]Oooool2
o`0000;ooooo0ol0000Booooo`03o`000?oooooooooo09Oooooo002eooooo`04o`000?oooooo0000
o`0001Gooooo00?o0000ooooooooool0Uoooool00;Gooooo0_l0000Gooooo`03o`000?oooooooooo
09Oooooo002eooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0V?ooool00;Gooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`2Hooooo`00]Oooool2o`0001Gooooo0_l0
002Jooooo`00]Oooool00ol0003oooooo`00000Dooooo`03o`000?oooooooooo09Wooooo002eoooo
o`03o`000?oooooooooo00;o00004?ooool2o`0009cooooo002eooooo`03o`000?oooooooooo00;o
oooo0ol0000;ooooo`;o0000W_ooool00;Gooooo0_l00006ooooo`_o0000X?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00V_ooool5o`0000Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0/?ooool009_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo0;3ooooo002Looooo`03oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool0
1?ooool3o`000;3ooooo002Mooooo`03ogMgMomVIVKooooo00_ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`03o`000?oooooooooo0;3ooooo002Nooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol0003o^[ZjoooooonH
V9So410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00V_ooool0
1OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l00006ooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002^
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool00:oooooo00?o0000oooo
ooooool00oooool3o`000;3ooooo002^ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0/?ooool00:_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3o
oooo002[ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool00:_ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00Zoooool4o`0000Kooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00W?ooool0
0ol0003ok^k^ooooo`05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool0/?ooool009cooooo00?oEEEEojVYZOooool01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00W?ooool00onYZJWoEEEEooooo`0@oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009gooooo00?o8B4Qoooooooo
ool03_ooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009gooooo00?oEEEEolc<c?ooool0
2oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool009gooooo
00?oZJVYogMgMoooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo
002Jooooo`05oa0@4?oooooooooooooooolb<S803?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`Go00003?ooool4o`0000Kooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00Xoooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03
o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`06ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@4006ooooo`?o0000/?ooool00:Gooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo00000;Wooooo002Uooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`00002iooooo`00YOooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@4100^Oooool00:Gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg0;Wooooo002Sooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP2iooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-10, -10, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.05 0.5 0.05 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-10)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-7.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-2.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(2.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(7.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(10)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-10)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-7.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-2.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(2.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(7.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(10)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.54615 .37992 m
.54111 .38725 L
.53676 .39416 L
.53306 .40059 L
.52996 .40655 L
.52742 .41204 L
.52539 .41711 L
.52383 .42177 L
.52268 .42606 L
.52191 .43001 L
.52149 .43364 L
.52137 .43697 L
.52153 .44001 L
.52194 .44277 L
.52256 .44526 L
.52338 .44749 L
.52438 .44945 L
.52555 .45113 L
.52687 .45254 L
.52833 .45366 L
.52992 .45447 L
.53163 .45498 L
.53346 .45514 L
.53538 .45496 L
.53738 .45441 L
.53945 .45346 L
.54157 .45211 L
.54372 .45033 L
.5459 .44812 L
.54808 .44547 L
.55026 .44237 L
.55246 .43884 L
.55467 .43489 L
.55693 .43053 L
.55928 .42579 L
.56176 .42072 L
.56444 .41536 L
.56739 .40982 L
.57069 .40424 L
.57443 .39885 L
.57867 .39401 L
.58343 .39033 L
.58865 .3887 L
.59412 .39049 L
.59934 .39749 L
.6034 .41166 L
.60485 .43416 L
.60193 .46361 L
.59323 .49476 L
.57891 .5203 L
Mistroke
.56131 .536 L
.54402 .54339 L
.52996 .54679 L
.5204 .54932 L
.51524 .55202 L
.5137 .55488 L
.51489 .55765 L
.51804 .56015 L
.52255 .56228 L
.52798 .56397 L
.53398 .56518 L
.5403 .56583 L
.54673 .56588 L
.55309 .56526 L
.55925 .56395 L
.5651 .56198 L
.57053 .55939 L
.57548 .5563 L
.57991 .55284 L
.58379 .54916 L
.5871 .54542 L
.58986 .54179 L
.59209 .53839 L
.59382 .53532 L
.59511 .53263 L
.596 .53033 L
.59657 .52836 L
.59691 .52662 L
.5971 .52498 L
.59728 .52324 L
.59756 .52115 L
.59812 .51842 L
.59911 .51466 L
.60066 .50944 L
.60287 .50218 L
.60568 .49223 L
.60889 .47894 L
.61207 .46189 L
.61455 .4413 L
.61558 .41836 L
.61456 .39532 L
.61121 .37491 L
.60571 .35939 L
.59856 .34984 L
.59043 .34604 L
.58195 .34691 L
.5736 .3511 L
.56571 .35733 L
.55845 .36462 L
.55193 .3723 L
Mistroke
.54615 .37992 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00Xoooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^jiooooo`00YOooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0^Ooo
ool009[ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
402iooooo`00YOooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_oo
ool3o`000;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0;3ooooo002S
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool009cooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Looooo`03oeEEEOnYZJWo
oooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool0
09;ooooo1_l00004ooooo`03ojVYZOmEEEGooooo013ooooo00?o0000ooooooooool00oooool3o`00
0;3ooooo002Mooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`2`ooooo`00WOooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`2`ooooo`00WOooool00onYZJWoMgMgooooo`0;ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooo
oc8b<P0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo1Ol0
000<ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002[ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`2`ooooo`00[_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002R
ooooo`Ko00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002^oooo
o`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00Zoooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool0/?ooool00:_ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2`ooooo`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo
002[ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`0Hooooo`Ko0000T_ooool00;Gooooo0_l0000Fooooo`?o00001_ooool00ol0003ooooooooo
o`2?ooooo`00]Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0S_ooool00;Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo08gooooo002eooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`2<ooooo`00]Oooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0S?ooool00;Gooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo08_ooooo002Jooooo`Go00001Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`2;ooooo`00V_ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo08_ooooo002Booooo`Ko00000oooool0
0onHV9So8B4Qonk^kP0Aooooo`03o`000?oooooooooo00?ooooo0ol0000?ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool0R_ooool009cooooo00?oV9RHob4Q8Oo^k^h03oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`2:ooooo`00WOooool00omgMgOoIVIVooooo`0;ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0R_ooool009kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`2:ooooo`00
V_ooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0ROooool009[ooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`Co00001_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00cooooo0ol00007ooooo`03o`000?oooooooooo08Wooooo002eooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool03?ooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool0ROooool00;Gooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`29ooooo`00]Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo08Wooooo002e
ooooo`;o00002Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`29ooooo`00]Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo08Wooooo002eooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000Roooool00;Go
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00Go0000ooooooooooooooooo`00002;ooooo`00]Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo0000
08_ooooo002eooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0:ooooo`05o`000?ooooooooooooooool00000Roooool00;Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00Go0000oooooooo
ooooooooo`00002;ooooo`00]Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000008_ooooo002eooooo`;o
00001_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00Go0000oooooooo
ooooooooo`00002;ooooo`00]Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool03Oooool01?l0003oooooooooool0002;ooooo`00]Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03_ooool01?l0003o
ooooooooool0002;ooooo`00]Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool03_ooool01?l0003oooooooooool0002;ooooo`00]Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03oooool01?l0003o
ooooooooool0002;ooooo`00]Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool03oooool01?l0003oooooooooool0002;ooooo`00]Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04?ooool01?l0003o
ooooooooool0002;ooooo`00]Oooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003o
ooooooooo`0Aooooo`04o`000?ooooooooooo`0008_ooooo002eooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`04o`000?ooooooooooo`00
08_ooooo002eooooo`;o00001_ooool2o`0000Gooooo00?o0000ooooooooool04_ooool01?l0003o
ooooooooool0002;ooooo`00]Oooool00ol0003oooooooooo`06ooooo`;o00000_ooool2o`0001Co
oooo00Co0000oooooooooooo0000S?ooool00;Gooooo00?o0000ooooooooool01oooool3o`0001Ko
oooo00Co0000oooooooooooo0000S?ooool00;Gooooo00?o0000ooooooooool08?ooool01?l0003o
ooooooooool0002<ooooo`002Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^hKooooo`03o`000?o^k^kooooo00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
7_ooool01Om4A4Co0000o`000?lb<S;ogMgM01cooooo1Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM01cooooo00?o0000ooooooooool07?ooool5o`0000;ooooo00?o0000oooo
ooooool00_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd07_ooool01Om4A4Co0000o`000?lb
<S;ogMgM01kooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8b
omgMg@0Jooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo000;oooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`03oeEEEOnYZJWo
oooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo023ooooo00?oMgMgoc8b<_ooool06oooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01_ooooo00?o
0000ooooooooool07?ooool01OnHV9So8B4Qonk^k_oooooo000000;ooooo00?o0000ooooooooool0
0_lQ8B48ooooo`03ogMgMolb<S;ooooo023ooooo00?oMgMgoc8b<_ooool07Oooool00omEEEGoZJVY
ooooo`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`001_l00005ooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@400Aooooo`Ko00001?ooool00onYZJWoEEEEooooo`0@ooooo`03
o`000?oooooooooo01?ooooo1_l00007ooooo`03o`000?oooooooooo01;ooooo1_l00003ooooo`03
oiRHV?lQ8B7ok^k^017ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Mooooo`04
oiRHV?lQ8B7ok^k^o`0000;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Poooo
o`03o`000?oooooooooo01cooooo00?oZJVYoeEEEOooool04?ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`002oooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007?ooool00olQ8B7oooooooooo`0>
ooooo`03ogMgMolb<S;ooooo023ooooo00?oMgMgoc8b<_ooool07Oooool00onHV9So8B4Qonk^kP0?
ooooo`03ogMgMolb<S;ooooo01_ooooo00?o0000ooooooooool07_ooool00onHV9So8B4Qo`000002
ooooo`03o`000?oooooooooo00[ooooo00?oMgMgoc8b<_ooool08?ooool00omgMgOo<S8booooo`0N
ooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool06oooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000000oooool000_ooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000001cooooo00?oEEEEolc<c?ooool02oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<01kooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Oooooo`03ogMgMomVIVKooooo00_o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00Looooo`;o00008?ooool01?l0003oIVIVooooool0000:
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`07_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01oooooo
00?oEEEEolc<c?ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01cooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000?ooooo000;ooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@400Looooo`03ojVYZOmgMgOooooo00_ooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0Oooooo`;o000000?oooooo`000?ooool02Oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo027ooooo00?oZJVYogMgMoooool02oooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003
ooooo`002oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06Oooool0
1Ol@413ooooooooooooooooo<S8b00cooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`0Nooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo01cooooo00Oo0000okZj^_oooooo0000oa0@4?oooooo000000[ooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`0Nooooo`05oa0@4?oooooooooooooooolb<S803?ooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`002Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06Ooo
ool5o`0000cooooo1?l0000Oooooo`Co00007Oooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo
1?l0000Mooooo`03o`000?oooooooooo01cooooo00OoV9RHoa0@4?l0003o8B4Qolc<c?oooooo0000
00[ooooo1?l0000Oooooo`Co00007Oooool5o`0000cooooo1?l0000Kooooo`03oeEEEOmVIVKo0000
00Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00]Oooool00ol0003oooooooooo`0Noooo
o`05o`000?ooooooooooooooool00000SOooool00;Gooooo00?o0000ooooooooool07_ooool01?l0
003oooooooooool0002>ooooo`00]Oooool00ol0003oooooooooo`0Mooooo`05o`000?oooooooooo
ooooool00000S_ooool00;Gooooo00?o0000ooooooooool07Oooool01Ol0003ooooooooooooooooo
000008kooooo002eooooo`03o`000?oooooooooo01gooooo00Go0000ooooooooooooooooo`00002>
ooooo`002oooooooo`0005Ko00002?ooool000_ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_l00006ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Kooooo000;ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
1_ooool00;Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo08kooooo002eooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`2>ooooo`00]Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0S_ooool00;Gooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo08oooooo002eooooo`03o`000?oooooooooo01Oooooo
0_l00005ooooo`03o`000?oooooooooo08oooooo002eooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`2?ooooo`00]Oooool2o`0001Kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`2?ooooo`00]Oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Soooool00;Gooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo093ooooo002eooooo`03o`00
0?oooooooooo017ooooo0_l0000:ooooo`03o`000?oooooooooo093ooooo002eooooo`03o`000?oo
oooooooo00oooooo0_l0000;ooooo`03o`000?oooooooooo097ooooo002eooooo`03o`000?oooooo
oooo00gooooo0_l0000<ooooo`03o`000?oooooooooo09;ooooo002eooooo`03o`000?oooooooooo
00[ooooo0ol0000>ooooo`03o`000?oooooooooo09;ooooo002eooooo`03o`000?oooooooooo00Ko
oooo1?l0000@ooooo`03o`000?oooooooooo09?ooooo002eooooo`;o00001?ooool3o`0001?ooooo
00?o0000ooooooooool0U?ooool00;Gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo09Gooooo002eooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool04Oooool2o`0009Sooooo002eooooo`03o`000?oooooooooo00;ooooo0ol0000?oooo
o`;o0000V_ooool00;Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`;o
0000W?ooool00;Gooooo00?o0000ooooooooool01_ooool<o`0009kooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00V_ooool5o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`2`ooooo`00V_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009_ooooo00?oV9RHob4Q
8Oo^k^h04Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002Looooo`03
oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool01?ooool3o`000;3ooooo002Mooooo`03ogMg
MomVIVKooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3o
oooo002Nooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`2`ooooo`00V_ooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo
1?l00006ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aoooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:_ooooo00GoA4A4o`000?l0003o<S8b
omgMg@05ooooo`03o`000?oooooooooo0;3ooooo002^ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0/?ooool00:oooooo00?o0000ooooooooool00oooool3o`000;3ooooo002^oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool00:_ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0/?ooool00:_ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`2`ooooo`00Zoooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00W?ooool00ol0003ok^k^ooooo`05ooooo`;o8B4Q1Ooo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009cooooo00?o
EEEEojVYZOooool01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`2`ooooo`00W?ooool00onYZJWoEEEEooooo`0@ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0/?ooool009gooooo00?o8B4Qooooooooool03_ooool00omgMgOo<S8booooo`04oooo
o`?o0000/?ooool009gooooo00?oEEEEolc<c?ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool0/?ooool009gooooo00?oZJVYogMgMoooool02oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?oooooooooooooooolb
<S803?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`Go0000
3?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Xoooool4o`000008oa0@4?oo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo
0;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006oooo
o`?o0000/?ooool00:Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
0;Wooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00002ioooo
o`00YOooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100^Oooool00:Go
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg0;Wooooo002Sooooo`03
oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP2iooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-10, -10, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.05 0.5 0.05 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-10)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-7.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-2.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(2.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(7.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(10)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-10)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-7.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-2.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(2.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(7.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(10)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.53241 .40393 m
.52782 .41064 L
.52396 .41677 L
.52078 .42235 L
.51823 .42743 L
.51625 .43206 L
.51481 .43629 L
.51384 .44016 L
.51331 .44371 L
.51317 .44696 L
.51339 .44994 L
.51391 .45266 L
.51472 .45513 L
.51576 .45737 L
.51702 .45938 L
.51847 .46115 L
.52008 .46269 L
.52183 .46399 L
.52372 .46504 L
.52571 .46583 L
.5278 .46635 L
.52997 .46658 L
.53221 .4665 L
.53449 .46609 L
.53679 .46534 L
.53909 .46423 L
.54136 .46274 L
.54358 .46087 L
.54574 .45859 L
.54781 .45592 L
.54979 .45286 L
.55169 .4494 L
.55352 .44555 L
.55533 .44131 L
.55715 .4367 L
.55905 .43171 L
.56112 .42636 L
.56347 .42065 L
.5662 .41461 L
.56945 .40833 L
.57335 .40196 L
.57804 .3958 L
.58361 .39039 L
.59005 .38671 L
.59715 .38637 L
.60429 .39174 L
.61019 .40569 L
.61272 .43005 L
.6093 .46274 L
.59838 .49602 L
Mistroke
.58135 .52089 L
.5625 .53455 L
.54635 .54076 L
.53531 .54405 L
.52958 .54663 L
.52828 .54904 L
.53029 .55123 L
.53462 .55302 L
.54051 .55429 L
.54741 .55487 L
.55487 .55462 L
.56255 .55341 L
.57018 .55114 L
.57755 .54778 L
.58447 .54337 L
.59083 .53803 L
.59654 .53197 L
.60155 .52544 L
.60584 .5187 L
.60943 .51203 L
.61237 .50569 L
.61469 .49989 L
.61647 .49478 L
.61776 .49045 L
.61864 .48691 L
.61916 .48414 L
.6194 .48202 L
.61942 .48038 L
.61932 .47899 L
.61917 .47755 L
.61908 .47572 L
.61916 .47308 L
.6195 .46916 L
.62016 .46343 L
.62111 .45536 L
.6222 .44449 L
.62305 .43067 L
.62312 .41428 L
.62179 .39654 L
.6185 .37945 L
.61304 .3653 L
.60559 .35587 L
.5967 .35178 L
.58704 .35257 L
.57726 .35706 L
.56783 .36391 L
.55905 .37197 L
.55109 .38041 L
.544 .38872 L
.53779 .39661 L
Mistroke
.53241 .40393 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00Xoooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^jiooooo`00YOooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0^Ooo
ool009[ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
402iooooo`00YOooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_oo
ool3o`000;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0;3ooooo002S
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool009cooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Looooo`03oeEEEOnYZJWo
oooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool0
09;ooooo1_l00004ooooo`03ojVYZOmEEEGooooo013ooooo00?o0000ooooooooool00oooool3o`00
0;3ooooo002Mooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`2`ooooo`00WOooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`2`ooooo`00WOooool00onYZJWoMgMgooooo`0;ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooo
oc8b<P0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo1Ol0
000<ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002[ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`2`ooooo`00[_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002R
ooooo`Ko00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002^oooo
o`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00Zoooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool0/?ooool00:_ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2`ooooo`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo
002[ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo01Wooooo2?l0002?
ooooo`00]Oooool00ol0003oooooooooo`0Gooooo`;o00002?ooool00ol0003oooooooooo`2<oooo
o`00]Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0S?ooool00;Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo08_ooooo002eooooo`03o`000?oooooooooo01?ooooo0_l0000>ooooo`03o`000?oo
oooooooo08[ooooo002Jooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@05ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`2:ooooo`00V_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo08Wooooo002Booooo`Ko00000oooool00onHV9So8B4Qonk^kP0Aooooo`03o`000?oooooo
oooo00?ooooo0ol0000@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0ROooool0
09cooooo00?oV9RHob4Q8Oo^k^h03oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`29ooooo`00WOooool00omgMgOo
IVIVooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0R?ooool009kooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`28ooooo`00V_ooool01Ol0003o^[ZjoooooonHV9So410@00co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_o
oooo1?l00006ooooo`03o`000?oooooooooo08Sooooo002Jooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`03?ooool4o`0000Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`28ooooo`00
]Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08Oooooo002eooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0Qoooool00;Gooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`27ooooo`00]Oooool2o`0000[ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Qoooool00;Go
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`27ooooo`00]Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool01Ol0003ooooo
oooooooooooo000008Wooooo002eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
Q_ooool00;Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`26ooooo`00]Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo08Kooooo002eooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0Q_ooool00;Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00kooooo00Go0000ooooooooooooooooo`000028oooo
o`00]Oooool2o`0000Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0>ooooo`05
o`000?ooooooooooooooool00000R?ooool00;Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00kooooo00Go0000ooooooooooooooooo`000028oooo
o`00]Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03_ooool01Ol0003ooooooooooooooooo000008Sooooo002eooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0?ooooo`05o`000?oooooooooooooo
ool00000R?ooool00;Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo013ooooo00Go0000ooooooooooooooooo`000028ooooo`00]Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04?ooool01?l0003o
ooooooooool00029ooooo`00]Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool04?ooool01?l0003oooooooooool00029ooooo`00]Oooool01Ol0003o
oooooooooooooooo000000gooooo00?o0000ooooooooool04Oooool01?l0003oooooooooool00029
ooooo`00]Oooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool04?ooool0
1Ol0003ooooooooooooooooo000008Wooooo002eooooo`;o00000_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo017ooooo00Go0000ooooooooooooooooo`000029ooooo`00]Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04Oooool0
1Ol0003ooooooooooooooooo000008Wooooo002eooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Booooo`05o`000?ooooooooooooooool00000ROoo
ool00;Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo01?ooooo00Go0000ooooooooooooooooo`000029ooooo`002Oooool4o`000008oa0@4?oooooo
ooooonk^k_lb<S;o0000oc8b<_o^k^hKooooo`03o`000?o^k^kooooo00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd07_ooool01Om4A4Co0000o`000?lb<S;ogMgM01cooooo1Ol00005
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01cooooo00?o0000ooooooooool00ooo
ool2o`0000Kooooo0_l0000?ooooo`Go000000?oooooo`000?ooool00_ooool00ol0003o8B4Qoooo
o`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd07_ooool01Om4A4Co0000o`000?lb<S;ogMgM01ko
oooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Joooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo000;ooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`03oeEEEOnYZJWooooo00Gooooo
0_lQ8B48ooooo`03ogMgMolb<S;ooooo023ooooo00?oMgMgoc8b<_ooool06oooool01OnHV9So8B4Q
onk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01_ooooo00?o0000oooooooo
ool01?ooool3o`0000;ooooo0_l0000Aooooo`07oiRHV?lQ8B7ok^k^oooooom4A4Coooooo`000003
ooooo`03o`000?lQ8B7ooooo00Oooooo00?oMgMgoc8b<_ooool08?ooool00omgMgOo<S8booooo`0M
ooooo`03oeEEEOnYZJWooooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01_ooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0006o`0000Gooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@017ooooo1_l00004ooooo`03ojVYZOmE
EEGooooo013ooooo00?o0000ooooooooool04oooool6o`0000Oooooo00?o0000ooooooooool04_oo
ool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo00Kooooo0ol0000Dooooo`05oiRHV?lQ8B7ok^k^ooooool000001?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool07?ooool00onYZJWoEEEE
ooooo`0@ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@00?ooooo000;ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`00000Looooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool08?ooool00omgMgOo
<S8booooo`0Mooooo`03oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool06oooool00ol0003o
ooooooooo`0Nooooo`04oiRHV?lQ8B7ok^k^o`0000Cooooo00?o0000ooooooooool01oooool00omg
MgOo<S8booooo`0Pooooo`03ogMgMolb<S;ooooo01kooooo00?o8B4Qooooooooool03_ooool00omg
MgOo<S8booooo`0Kooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003
ooooo`002oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007?ooool0
0omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`07_ooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<01oooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01co
oooo0_l0000Pooooo`03ogMgMomVIVKo000000?ooooo00?o0000ooooooooool01Oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<01kooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Oooooo`03oeEEEOo<c<co
oooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Looooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`002oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41007?ooool00onYZJWoMgMgooooo`0;ooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Qooooo`03ojVYZOmgMgOooooo00_ooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41000oooool000_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Wo
oooo00Go410@oooooooooooooooooc8b<P0<ooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool07_ooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Looooo`05o`000?nj^[[ooooooiRHV?l000001?ooool2o`0000Kooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`0Nooooo`05oa0@4?oooooooooooooooolb<S80
3?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`002Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h06Oooool5o`0000cooooo1?l0000Oooooo`Co00007Oooool01OnHV9So410@o`000?lQ8B7oc<c<
00cooooo1?l0000Mooooo`03o`000?oooooooooo01cooooo00GoV9RHoa0@4?l0003o8B4Qo`000005
ooooo`03o`000?oooooooooo00Cooooo1?l0000Oooooo`Co00007Oooool5o`0000cooooo1?l0000K
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00]Oooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0R?ooool0
0;Gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
08Sooooo002eooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`28ooooo`00]Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0R?ooool00;Gooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo08Sooooo000;oooooooo0000E_l00008ooooo`002oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooo`000004ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo000;ooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooo
ooooool00000:_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool01_ooool00;Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo08[ooooo002eooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`2;ooooo`00]Oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0Roooool00;Gooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08cooooo002eooooo`03o`000?oooooo
oooo01Sooooo0_l00007ooooo`03o`000?oooooooooo08cooooo002eooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2=ooooo`00]Oooool2o`0001Ko
oooo0_l00008ooooo`03o`000?oooooooooo08kooooo002eooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`2>ooooo`00]Oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Soooool00;Gooooo00?o0000
ooooooooool04Oooool2o`0000[ooooo00?o0000ooooooooool0T?ooool00;Gooooo00?o0000oooo
ooooool03_ooool3o`0000_ooooo00?o0000ooooooooool0TOooool00;Gooooo00?o0000oooooooo
ool02oooool3o`0000gooooo00?o0000ooooooooool0T_ooool00;Gooooo00?o0000ooooooooool0
2?ooool3o`0000kooooo0_l0002Eooooo`00]Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00cooooo0ol0002Gooooo`00]Oooool2o`0000Oooooo0ol0000;ooooo`;o0000V_ooool0
0;Gooooo00?o0000ooooooooool02Oooool4o`0000Cooooo0ol0002Looooo`00]Oooool00ol0003o
ooooooooo`0=ooooo`Co0000Woooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002Jooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0;3ooooo002Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00Voooool00onHV9So8B4Q
onk^kP0Aooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009cooooo00?o
V9RHob4Q8Oo^k^h03oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009gooooo00?oMgMg
ofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?oo
ool009kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0;3ooooo002Jooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool4
o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Zoooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool0/?ooool00:kooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`2`ooooo`00[oooool00ol0003oooooooooo`03ooooo`?o0000/?ooool00:kooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00Zoooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool00:_ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`2`ooooo`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0;3ooooo002[ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Looooo`03o`000?o^k^kooooo00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00W?ooool00omE
EEGoZJVYooooo`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
0;3ooooo002Looooo`03ojVYZOmEEEGooooo013ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`2`ooooo`00WOooool00olQ8B7oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo
0ol0002`ooooo`00WOooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`2`ooooo`00WOooool00onYZJWoMgMgooooo`0;ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooc8b
<P0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo1Ol0000<
ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000
/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Sooooo`Co000000So410@oooo
ooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000ooooooooool0/?ooool00:Gooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0
/?ooool00:Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo
0ol0002`ooooo`00YOooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
^Oooool00:Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo00000;Wooooo
002Uooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@402iooooo`00YOoo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0^Oooool00:?ooooo00?o
EEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^0;Wooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-10, -10, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.05 0.5 0.05 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-10)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-7.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-2.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(2.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(7.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(10)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-10)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-7.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-2.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(2.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(7.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(10)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.52053 .42388 m
.51631 .42957 L
.51284 .4347 L
.51009 .43934 L
.50801 .44353 L
.50653 .44735 L
.50561 .45082 L
.50521 .454 L
.50528 .4569 L
.50577 .45957 L
.50663 .462 L
.50782 .46422 L
.5093 .46623 L
.51102 .46805 L
.51296 .46967 L
.51508 .47109 L
.51735 .47231 L
.51975 .47331 L
.52225 .4741 L
.52484 .47465 L
.52748 .47496 L
.53016 .475 L
.53286 .47476 L
.53554 .47423 L
.53817 .47339 L
.54072 .47222 L
.54317 .47071 L
.54547 .46887 L
.5476 .46669 L
.54956 .46418 L
.55132 .46134 L
.5529 .45817 L
.55433 .45469 L
.55563 .45089 L
.55688 .44676 L
.55815 .44229 L
.55955 .43746 L
.56119 .43224 L
.56322 .4266 L
.56581 .42053 L
.56914 .41404 L
.57341 .40723 L
.57881 .40035 L
.58553 .39392 L
.59358 .38901 L
.60271 .38756 L
.61202 .39261 L
.61955 .40785 L
.62212 .43507 L
.61644 .46988 L
Mistroke
.60196 .5016 L
.58271 .52211 L
.56477 .53226 L
.55216 .53706 L
.54576 .53989 L
.54467 .54198 L
.54753 .54352 L
.55312 .54438 L
.56047 .54434 L
.56885 .54319 L
.57768 .5407 L
.58651 .53675 L
.595 .53129 L
.60288 .52442 L
.60996 .51634 L
.61615 .50738 L
.6214 .49791 L
.62572 .48834 L
.62917 .47904 L
.63183 .47034 L
.63382 .46247 L
.63523 .45561 L
.63617 .44985 L
.63674 .4452 L
.637 .44163 L
.63703 .43902 L
.63688 .43723 L
.63659 .43605 L
.63621 .4352 L
.63577 .43438 L
.63532 .43321 L
.6349 .43126 L
.63451 .42807 L
.63412 .42322 L
.6336 .41634 L
.63267 .40734 L
.63092 .39653 L
.62785 .38484 L
.62297 .37377 L
.61608 .3651 L
.60731 .36022 L
.59715 .35967 L
.58627 .36303 L
.57532 .36928 L
.56481 .37723 L
.55505 .38591 L
.54623 .3946 L
.53838 .40289 L
.53152 .41056 L
.52558 .41756 L
Mistroke
.52053 .42388 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00Xoooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^jiooooo`00YOooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0^Ooo
ool009[ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
402iooooo`00YOooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_oo
ool3o`000;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0;3ooooo002S
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool009cooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Looooo`03oeEEEOnYZJWo
oooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool0
09;ooooo1_l00004ooooo`03ojVYZOmEEEGooooo013ooooo00?o0000ooooooooool00oooool3o`00
0;3ooooo002Mooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`2`ooooo`00WOooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`2`ooooo`00WOooool00onYZJWoMgMgooooo`0;ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooo
oc8b<P0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo1Ol0
000<ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002[ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`2`ooooo`00[_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002R
ooooo`Ko00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002^oooo
o`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00Zoooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool0/?ooool00:_ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2`ooooo`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo
002[ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo01cooooo1ol0002=ooooo`00
]Oooool00ol0003oooooooooo`0Jooooo`;o00001oooool00ol0003oooooooooo`2:ooooo`00]Ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0ROoo
ool009[ooooo1Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo08Sooooo002J
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`0Fooooo`;o00003_ooool00ol0003oooooooooo`27ooooo`00T_ooool6
o`0000?ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0003oooooooooo`03ooooo`?o00005?ooool2
o`00017ooooo00?o0000ooooooooool0Q_ooool009cooooo00?oV9RHob4Q8Oo^k^h03oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`26ooooo`00WOooool00omgMgOoIVIVooooo`0;ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool0Q_ooool009kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`25ooooo`00
V_ooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0QOooool009[ooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`Co00001_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00[ooooo1ol00005ooooo`03o`000?oooooooooo08Gooooo002eooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0QOooool00;Gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`24ooooo`00]Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo08Cooooo002eooooo`;o00003?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`24ooooo`00]Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo08?ooooo002eooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0Poooool00;Gooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00gooooo00Go0000ooooooooooooooooo`000025ooooo`00]Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03_oo
ool01Ol0003ooooooooooooooooo000008Gooooo002eooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0?ooooo`05o`000?ooooooooooooooool00000
QOooool00;Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00oooooo00Go0000ooooooooooooooooo`000025ooooo`00]Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04?ooool01Ol0003ooooooooo
oooooooo000008Gooooo002eooooo`;o00001Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`22ooooo`00]Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo08;ooooo002eooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0P_ooool00;Gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`22ooooo`00]Oooool01Ol0003ooooooooooooooooo0000013ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo08;ooooo002eooooo`04o`00
0?ooooooooooo`00013ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`02ooooo`;o
0000Poooool00;Gooooo00Co0000oooooooooooo00004?ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0P_ooool00;Gooooo00Co0000oooooooooooo
00004?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0P_ooool00;Gooooo00?o0000ooooool000004?ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0P_ooool00;Gooooo0ol0000@ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`22ooooo`00]Oooool0
0ol0003oooooo`00000@ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`22ooooo`00]Oooool00ol0003oooooo`00000?ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`22ooooo`00]Oooool00ol0003o
ooooo`00000?ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`22ooooo`002Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hK
ooooo`03o`000?o^k^kooooo00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd07_oo
ool01Om4A4Co0000o`000?lb<S;ogMgM01cooooo1Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM01cooooo00?o0000ooooool000003_ooool00ol0003oooooooooo`0;ooooo`Go
00001?ooool00ol0003o8B4Qob4Q8@02ooooo`04o`000?ooooooooooodA4A0;o000000?o<S8bomgM
gOooool07Oooool01Om4A4Co0000o`000?lb<S;ogMgM01kooooo00?o0000onk^k_ooool01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Jooooo`Co000000So410@ooooooooooook^k^
oc8b<_l0003o<S8bonk^kP?ooooo000;ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0Kooooo`03oeEEEOnYZJWooooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
023ooooo00?oMgMgoc8b<_ooool06oooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo01_ooooo00Co0000oooooooooooo00003Oooool00ol0003ooooooooo
o`0;ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01?l0003oooooob4Q8OlQ8B42ooooo`03
o`000?oooooooooo00?ooooo00?oMgMgoc8b<_ooool08?ooool00omgMgOo<S8booooo`0Mooooo`03
oeEEEOnYZJWooooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01_ooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0006o`0000Gooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@017ooooo1_l00004ooooo`03ojVYZOmEEEGooooo
013ooooo00?o0000ooooooooool04oooool6o`0000Oooooo00?o0000ooooooooool04_ooool6o`00
00?ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
00;o00002_ooool2o`0000oooooo00?oV9RHob4Q8Oo^k^h01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Loooo
o`03ojVYZOmEEEGooooo013ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41000oooool000_ooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000001cooooo00?o8B4Qooooooooool03_ooool00omgMgOo<S8booooo`0P
ooooo`03ogMgMolb<S;ooooo01gooooo00?oV9RHob4Q8Oo^k^h03oooool00omgMgOo<S8booooo`0K
ooooo`04o`000?ooooooooooooooo`;o00002Oooool00ol0003oooooooooo`0?ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03ogMgMolb
<S;ooooo023ooooo00?oMgMgoc8b<_ooool07_ooool00olQ8B7oooooooooo`0>ooooo`03ogMgMolb
<S;ooooo01_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
000;ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Looooo`03oeEE
EOo<c<cooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Nooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`07oooool00omgMgOoIVIVooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`07?ooool2
o`0000Cooooo2Ol0000Cooooo`03ogMgMomVIVKooooo00;ooooo00?o0000ooooooooool00oooool0
2?l0003oooooooooool0003o8B4Qo`000?lb<S;oc<c<7_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<
01oooooo00?oEEEEolc<c?ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01cooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo000;ooooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@400Looooo`03ojVYZOmgMgOooooo00_ooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0Pooooo`04o`000?ooooooooooo`0000Gooooo
00Go0000ooooooooooooooooo`00000Rooooo`03o`000?oooooooooo027ooooo00?oZJVYogMgMooo
ool02oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooo
oooooooooa0@4003ooooo`002oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL06Oooool01Ol@413ooooooooooooooooo<S8b00cooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0Nooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo01cooooo00Go0000okZj^_ooooooV9RHoa0@4002ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00000Rooooo`03o`000?oooooooooo01ko
oooo00Go410@oooooooooooooooooc8b<P0<ooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0009ooooo`03oeEEEOmVIVKo0000
00Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Iooooo`Go00003?ooool4o`0001oooooo1?l0000M
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool4o`0001gooooo00?o0000ooooooooool07?oo
ool01OnHV9So410@o`000?lQ8B7oc<c<00;ooooo00?o0000ooooooooool00oooool01?l0003ooooo
ooooooooool4o`0001oooooo1?l0000Mooooo`Go00003?ooool4o`0001_ooooo00?oEEEEofIVI_l0
00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo002eooooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`25ooooo`00]Oooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0QOooool00;Gooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08Gooooo002e
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`26
ooooo`00]Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0Qoooool000_oooooool0001Fo`0000Sooooo000;ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`;o00001?ooool00ol0003ooooo
o`000008ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`06ooooo`002oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool00oooool00ol0003oooooo`00000Zooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`06ooooo`00]Oooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0ROooool00;Gooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08Wooooo002eooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2:ooooo`00
]Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
Roooool00;Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo08cooooo002eooooo`03o`000?oooooooooo01Sooooo0_l00006ooooo`03o`000?oooooo
oooo08gooooo002eooooo`;o00005oooool2o`0000Oooooo00?o0000ooooooooool0S_ooool00;Go
oooo00?o0000ooooooooool05?ooool2o`0000Sooooo00?o0000ooooooooool0Soooool00;Gooooo
00?o0000ooooooooool04_ooool2o`0000Sooooo0_l0002Booooo`00]Oooool00ol0003ooooooooo
o`0@ooooo`;o00002Oooool00ol0003oooooooooo`2Booooo`00]Oooool00ol0003oooooooooo`0>
ooooo`;o00002Oooool2o`0009Gooooo002eooooo`03o`000?oooooooooo00cooooo0_l00008oooo
o`?o0000Uoooool00;Gooooo00?o0000ooooooooool03Oooool9o`0009[ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002Jooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0;3ooooo002Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00Voooool00onHV9So
8B4Qonk^kP0Aooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009cooooo
00?oV9RHob4Q8Oo^k^h03oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009gooooo00?o
MgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
/?ooool009kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0;3ooooo002Jooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?oo
ool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Zoooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool00:kooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`2`ooooo`00[oooool00ol0003oooooooooo`03ooooo`?o0000/?ooool00:ko
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00Zoooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool00:_ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`2`ooooo`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0;3ooooo002[ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002Looooo`03o`000?o^k^kooooo00Gooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00W?ooool0
0omEEEGoZJVYooooo`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo0;3ooooo002Looooo`03ojVYZOmEEEGooooo013ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`2`ooooo`00WOooool00olQ8B7oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Co
oooo0ol0002`ooooo`00WOooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`2`ooooo`00WOooool00onYZJWoMgMgooooo`0;ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooo
oc8b<P0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo1Ol0
000<ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Sooooo`Co000000So410@
ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000ooooooooool0/?ooool00:Gooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000oooooooo
ool0/?ooool00:Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Ko
oooo0ol0002`ooooo`00YOooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
0000^Oooool00:Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo00000;Wo
oooo002Uooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@402iooooo`00
YOooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0^Oooool00:?ooooo
00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^0;Wooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-10, -10, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.05 0.5 0.05 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-10)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-7.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-2.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(2.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(7.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(10)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-10)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-7.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-2.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(2.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(7.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(10)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.50997 .43941 m
.50595 .44411 L
.50276 .44832 L
.50034 .45212 L
.49863 .45556 L
.49759 .45869 L
.49717 .46153 L
.49733 .46413 L
.49799 .46651 L
.49912 .46869 L
.50066 .47068 L
.50257 .4725 L
.50478 .47415 L
.50725 .47563 L
.50994 .47694 L
.51281 .47809 L
.51583 .47906 L
.51896 .47984 L
.52217 .48043 L
.52543 .48082 L
.52871 .48098 L
.53198 .48091 L
.53521 .48058 L
.53835 .47999 L
.54138 .47912 L
.54424 .47797 L
.5469 .47653 L
.54931 .47481 L
.55146 .47281 L
.55331 .47054 L
.55487 .46802 L
.55614 .46525 L
.55716 .46224 L
.55797 .45899 L
.55865 .45547 L
.55928 .45167 L
.55999 .44755 L
.56092 .44307 L
.56223 .43818 L
.56411 .43281 L
.5668 .42692 L
.57053 .4205 L
.57559 .41361 L
.58226 .40647 L
.59077 .39969 L
.60115 .39454 L
.61292 .39346 L
.62455 .40029 L
.63282 .419 L
.6332 .44939 L
Mistroke
.62282 .48293 L
.60443 .50829 L
.58519 .52225 L
.57104 .52883 L
.56391 .53212 L
.56301 .53396 L
.56677 .53478 L
.57367 .53452 L
.58247 .53293 L
.59223 .52975 L
.60219 .52481 L
.6118 .51805 L
.62062 .50962 L
.62838 .4998 L
.63493 .48903 L
.64022 .4778 L
.64431 .46661 L
.6473 .4559 L
.64936 .44601 L
.65064 .43718 L
.65131 .42956 L
.65155 .42319 L
.65147 .41807 L
.65119 .41412 L
.65079 .41125 L
.65032 .40931 L
.6498 .40814 L
.64925 .40754 L
.64866 .40727 L
.64802 .40708 L
.64729 .40662 L
.64643 .40557 L
.64538 .40357 L
.64399 .40033 L
.64207 .3957 L
.63927 .38981 L
.6352 .38321 L
.62944 .37687 L
.62174 .37206 L
.61216 .36992 L
.60107 .37103 L
.58912 .37522 L
.57699 .38177 L
.56523 .38972 L
.55425 .3982 L
.54425 .40659 L
.53532 .4145 L
.52747 .42175 L
.52067 .4283 L
.51485 .43417 L
Mistroke
.50997 .43941 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00Xoooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^jiooooo`00YOooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0^Ooo
ool009[ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
402iooooo`00YOooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_oo
ool3o`000;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0;3ooooo002S
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool009cooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Looooo`03oeEEEOnYZJWo
oooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool0
09;ooooo1_l00004ooooo`03ojVYZOmEEEGooooo013ooooo00?o0000ooooooooool00oooool3o`00
0;3ooooo002Mooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`2`ooooo`00WOooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`2`ooooo`00WOooool00onYZJWoMgMgooooo`0;ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooo
oc8b<P0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo1Ol0
000<ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002[ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`2`ooooo`00[_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002R
ooooo`Ko00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002^oooo
o`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00Zoooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool0/?ooool00:_ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2`ooooo`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo
002[ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Jooooo`Go00001Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`0Nooooo`[o0000R?ooool009;ooooo1_l00003ooooo`03oiRHV?lQ8B7o
k^k^017ooooo00?o0000ooooooooool00oooool3o`0001cooooo0_l0000:ooooo`03o`000?oooooo
oooo08Gooooo002Looooo`03oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`0Jooooo`;o00003Oooool00ol0003oooooooooo`24ooooo`00WOooool00omgMgOo
IVIVooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Hoooo
o`;o00004?ooool00ol0003oooooooooo`23ooooo`00W_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool05_ooool2o`0001?ooooo00?o0000oooooooo
ool0P_ooool009[ooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool05?ooool2o`0001Gooooo00?o0000ooooooooool0P_ooool009[ooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`Co00001_ooool00ol0003oooooooooo`0Booooo`;o
00006?ooool00ol0003oooooooooo`21ooooo`00]Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool0POooool00;Gooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0;ooooo`Oo00001oooool00ol0003oooooooooo`21ooooo`00]Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool2
o`0000Kooooo00?o0000ooooooooool0P?ooool00;Gooooo0_l0000?ooooo`03o`000?oooooooooo
00[ooooo0_l0000:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Ooooool00;Go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1oooooo`00]Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo07kooooo002eooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0OOooool00;Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1m
ooooo`00]Oooool00ol0003oooooooooo`08ooooo`;o00003Oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0OOooool00;Gooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`1mooooo`00]Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo07gooooo002eooooo`;o00001oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1mooooo`00]Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo07gooooo002eooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0OOooool00;Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`1mooooo`00]Oooool01?l0003oooooooooooooool2o`00013ooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07gooooo002eooooo`04o`00
0?ooooooooooo`00017ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo07gooooo002eooooo`04o`000?ooooooooooo`00017ooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07gooooo002eooooo`03o`00
0?oooooo000001;ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo07gooooo002eooooo`;o00004_ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0OOooool00;Gooooo0_l0000Booooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1mooooo`00]Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`1nooooo`00]?ooool2o`0001?ooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo07kooooo002dooooo`;o00004oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0O_ooool000Wooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^6oooool00ol0003ok^k^ooooo`05oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01kooooo00GoA4A4o`000?l0003o<S8bomgM
g@0Looooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Kooooo`;o0000
4_ooool00ol0003oooooooooo`09ooooo`Go00001Oooool2ob4Q8@03ooooool0003ooooo00;ooooo
00GoA4A4o`000?l0003o<S8bomgMg@0Nooooo`05odA4A?l0003o0000oc8b<_oMgMd07_ooool00ol0
003ok^k^ooooo`05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01[ooooo1?l00000
2?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool000_ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00?oEEEEojVYZOooool01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool08?ooool00omgMgOo<S8booooo`0Kooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool2o`0001;ooooo00?o0000oooo
ooooool02Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B400ooooooo0000ooooo`03
ooooo`04o`000?ooooooMgMgoc8b<R7ooooo00?oMgMgoc8b<_ooool07Oooool00omEEEGoZJVYoooo
o`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`03ooooo`001_l00005ooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@400Aooooo`Ko00001?ooool00onYZJWoEEEEooooo`0@ooooo`03o`00
0?oooooooooo01?ooooo1_l00007ooooo`03o`000?oooooooooo01;ooooo1_l00003ooooo`03oiRH
V?lQ8B7ok^k^017ooooo00?o0000ooooooooool06Oooool2o`0001;ooooo00?o0000ooooooooool0
2_ooool00onHV9So8B4Qonk^kP08ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo
00008_ooool00ol0003oooooooooo`0Looooo`03ojVYZOmEEEGooooo013ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool000_o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001cooooo00?o8B4Qoooo
ooooool03_ooool00omgMgOo<S8booooo`0Pooooo`03ogMgMolb<S;ooooo01gooooo00?oV9RHob4Q
8Oo^k^h03oooool00omgMgOo<S8booooo`0Kooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool03?ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo00?ooooo00Co0000oooo
oomgMgOo<S8b8Oooool00omgMgOo<S8booooo`0Nooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMg
oc8b<_ooool06oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool000_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001cooooo00?o
EEEEolc<c?ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01kooooo00Go0000ob4Q8Ol0003o
<S8bolc<c00Oooooo`03ogMgMomVIVKooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Loooo
o`?o00003_ooool00ol0003oooooooooo`0>ooooo`03ogMgMomVIVKooooo00Kooooo00?o0000oooo
ooooool00_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01kooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Oooooo`03oeEEEOo<c<cooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Looooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`002oooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41007?ooool00onYZJWoMgMgooooo`0;ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo01kooooo00Co0000ooooool0003o00003?ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Poooo
o`03o`000?oooooooooo027ooooo00?oZJVYogMgMoooool02oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`002oooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06Oooool01Ol@413ooooooooooooo
oooo<S8b00cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Nooooo`05o`000?nj
^[[ooooooiRHV?l@41003?ooool00ol0003oooooooooo`0Nooooo`04o`000?ooooooooooooooo`Ko
00000_ooool4o`0000oooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Nooooo`05oa0@4?oooooooooo
oooooolb<S803?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`03ooooo`002Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h06Oooool5o`0000cooooo1?l0000Oooooo`Co00007Oooool01OnHV9So410@o`00
0?lQ8B7oc<c<00cooooo1?l0000Mooooo`03o`000?oooooooooo00Oooooo0_l0000Cooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`02ooooo`Go00007oooool4o`0001go
oooo1Ol0000<ooooo`Co00006oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool00;Gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo087ooooo002eooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`22ooooo`00]Oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0P_ooool00;Gooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo08?ooooo002eooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`23ooooo`002oooooooo`0005Ko
00002?ooool000_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00Co0000oooooooooooo00001?ooool2o`0000Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo000;ooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo00Kooooo002eooooo`03o`000?oooooooooo01oooooo0_l00005ooooo`03o`000?oo
oooooooo08Oooooo002eooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`28ooooo`00]Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0ROooool00;Gooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`03ooooo`;o0000S?ooool00;Gooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo08cooooo002eooooo`03o`000?oooooooooo01Wooooo0_l0
0004ooooo`;o0000Soooool00;Gooooo0_l0000Gooooo`?o00001?ooool2o`00097ooooo002eoooo
o`03o`000?oooooooooo01Cooooo0_l00005ooooo`;o0000Toooool00;Gooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`02ooooo`?o0000UOooool00;Gooooo00?o0000ooooooooool0
4_ooool6o`0009Sooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Joooo
o`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0;3ooooo002Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00Voooool00onHV9So8B4Qonk^kP0Aoooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009cooooo00?oV9RHob4Q8Oo^
k^h03oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009gooooo00?oMgMgofIVI_ooool0
2oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool009kooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo
002Jooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool4o`0000Kooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00Zoooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo
00?o0000ooooooooool0/?ooool00:kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`2`ooooo`00[oooool00ol0003oooooooooo`03ooooo`?o0000/?ooool00:kooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00Zoooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool0/?ooool00:_ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2`ooooo`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo
002[ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002Looooo`03o`000?o^k^kooooo00Gooooo0_lQ8B45ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00W?ooool00omEEEGoZJVYoooo
o`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002L
ooooo`03ojVYZOmEEEGooooo013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2`
ooooo`00WOooool00olQ8B7oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`oooo
o`00WOooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0
003oooooooooo`2`ooooo`00WOooool00onYZJWoMgMgooooo`0;ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooc8b<P0<ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo1Ol0000<ooooo`Co0000
1_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Sooooo`Co000000So410@ooooooooooook^k^
oc8b<_l0003o<S8bonk^kPKooooo00?o0000ooooooooool0/?ooool00:Gooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0/?ooool00:Go
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo0ol0002`oooo
o`00YOooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000^Oooool00:Go
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo00000;Wooooo002Uooooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@402iooooo`00YOooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0^Oooool00:?ooooo00?oEEEEofIVI_l0
00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^0;Wooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-10, -10, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.05 0.5 0.05 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-10)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-7.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-2.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(2.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(7.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(10)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-10)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-7.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-2.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(2.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(7.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(10)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.50009 .45126 m
.49613 .45511 L
.49308 .45856 L
.49088 .46167 L
.48949 .46449 L
.48885 .46705 L
.48892 .46938 L
.48962 .47151 L
.49092 .47345 L
.49274 .47524 L
.49502 .47687 L
.49771 .47835 L
.50074 .4797 L
.50406 .48091 L
.50761 .48199 L
.51135 .48292 L
.51523 .4837 L
.5192 .48432 L
.52324 .48477 L
.52729 .48504 L
.53132 .48511 L
.5353 .48498 L
.53916 .48462 L
.54287 .48403 L
.54638 .4832 L
.54963 .48213 L
.55256 .48082 L
.55515 .47928 L
.55735 .47752 L
.55915 .47555 L
.56053 .47338 L
.56152 .47104 L
.56214 .46851 L
.56247 .4658 L
.56259 .46289 L
.56259 .45975 L
.56263 .45635 L
.56285 .45264 L
.56345 .44855 L
.56466 .44402 L
.56672 .43899 L
.56994 .43339 L
.57467 .4272 L
.58127 .42051 L
.59012 .41362 L
.60149 .40733 L
.61527 .4034 L
.63036 .40499 L
.64378 .41642 L
.65025 .44001 L
Mistroke
.64476 .47064 L
.62809 .49704 L
.60795 .51302 L
.59228 .52082 L
.58433 .52444 L
.58362 .52603 L
.58832 .52622 L
.59657 .52499 L
.60683 .52213 L
.61786 .51743 L
.62873 .51081 L
.63876 .50237 L
.64747 .49244 L
.65462 .48149 L
.66012 .47007 L
.66405 .45872 L
.66657 .44792 L
.66792 .43802 L
.66833 .42925 L
.66806 .42173 L
.66734 .41547 L
.66635 .41043 L
.66526 .40652 L
.66416 .40363 L
.66312 .40163 L
.66219 .40039 L
.66137 .39976 L
.66061 .39959 L
.65988 .39971 L
.65909 .39989 L
.65816 .39992 L
.65696 .39955 L
.65534 .39854 L
.6531 .39671 L
.64994 .39404 L
.64552 .39075 L
.63946 .38736 L
.63146 .38471 L
.62144 .38366 L
.60968 .38489 L
.59671 .38853 L
.58325 .39423 L
.56997 .40128 L
.55736 .40895 L
.54575 .41663 L
.53528 .42393 L
.52601 .43065 L
.5179 .43671 L
.51091 .44213 L
.505 .44696 L
Mistroke
.50009 .45126 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00Xoooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^jiooooo`00YOooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0^Ooo
ool009[ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
402iooooo`00YOooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_oo
ool3o`000;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0;3ooooo002S
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool009cooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Looooo`03oeEEEOnYZJWo
oooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool0
09;ooooo1_l00004ooooo`03ojVYZOmEEEGooooo013ooooo00?o0000ooooooooool00oooool3o`00
0;3ooooo002Mooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`2`ooooo`00WOooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`2`ooooo`00WOooool00onYZJWoMgMgooooo`0;ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooo
oc8b<P0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo1Ol0
000<ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002[ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`2`ooooo`00[_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002R
ooooo`Ko00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002^oooo
o`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00Zoooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool0/?ooool00:_ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2`ooooo`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo
002[ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Jooooo`Go00001Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h04Oooool0
0ol0003oooooooooo`03ooooo`?o0000/?ooool009cooooo00?oV9RHob4Q8Oo^k^h03oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Mooooo`03ogMgMomVIVKooooo00_o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo002Nooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`Go
0000Qoooool009[ooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool08?ooool4o`0000Gooooo0ol00024ooooo`00V_ooool01OnHV9So410@
o`000?lQ8B7oc<c<00cooooo1?l00006ooooo`03o`000?oooooooooo01gooooo0ol0000<ooooo`;o
0000P_ooool00;Gooooo00?o0000ooooooooool06_ooool3o`00017ooooo0_l00020ooooo`00]Ooo
ool00ol0003oooooooooo`0Hooooo`;o00005_ooool00ol0003oooooooooo`1mooooo`00]Oooool0
0ol0003oooooooooo`0Fooooo`;o00006Oooool2o`0007gooooo002eooooo`;o00005Oooool2o`00
01cooooo0ol0001kooooo`00]Oooool00ol0003oooooooooo`0Booooo`;o00003_ooool6o`0000co
oooo0_l0001jooooo`00]Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00_ooooo
0ol00006ooooo`?o00002_ooool00ol0003oooooooooo`1hooooo`00]Oooool00ol0003ooooooooo
o`0?ooooo`;o00003Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0N?ooool00;Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1h
ooooo`00]Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo0_l0000@oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Moooool00;Gooooo00?o0000oooooooo
ool02oooool2o`0000gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo07Oooooo002eooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2oooool2o`0001Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1gooooo`00]Ooo
ool2o`0000Wooooo0_l0000=ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1gooooo`00]Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo07Oooooo002eooooo`03o`000?oooooooooo00Gooooo0_l0000?ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1gooooo`00]Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo07Oooooo002eooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0Moooool00;Gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1gooooo`00]Oooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07Oooooo002eooooo`04o`000?oooooo
ooooo`0001;ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo07Oooooo002eooooo`?o00004_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0Moooool00;Gooooo0_l0000Cooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1gooooo`00]Oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`1gooooo`00]?ooool2o`0001Cooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo07Sooooo002cooooo`03o`000?oooooo000001Cooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07Sooooo0009
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQ_ooooo00?o0000onk^k_oo
ool01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Nooooo`05odA4A?l0003o0000
oc8b<_oMgMd07?ooool5o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd06Ooo
ool01?l0003oooooooooool0000Dooooo`03o`000?oooooooooo00Oooooo1Ol00005ooooo`;o8B4Q
1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00?ooooo00?o0000ooooooooool06?ooool01Om4A4Co
0000o`000?lb<S;ogMgM01kooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@0Jooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo000;ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`03
oeEEEOnYZJWooooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo023ooooo00?oMgMgoc8b<_oo
ool06oooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
01Oooooo00Go0000ooooooooooooooooo`00000Dooooo`03o`000?oooooooooo00Oooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q1_ooool01?l0003oooooogMgMolb<S82ooooo`03o`00
0?oooooooooo01cooooo00?oMgMgoc8b<_ooool07Oooool00omEEEGoZJVYooooo`05ooooo`;o8B4Q
2?ooool00omgMgOo<S8booooo`0Kooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`001_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Aooooo`Ko00001?ooool00onYZJWoEEEEooooo`0@ooooo`03o`000?oooooooooo01?o
oooo1_l00007ooooo`03o`000?oooooooooo01;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^017o
oooo00?o0000ooooooooool05_ooool01Ol0003ooooooooooooooooo000001Cooooo00?o0000oooo
ooooool02?ooool00onHV9So8B4Qonk^kP0>ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0Looooo`03ojVYZOmEEEGooooo013ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool000_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001cooooo00?o
8B4Qooooooooool03_ooool00omgMgOo<S8booooo`0Pooooo`03ogMgMolb<S;ooooo01gooooo00?o
V9RHob4Q8Oo^k^h03oooool00omgMgOo<S8booooo`0Gooooo`05o`000?ooooooooooooooool00000
5?ooool00ol0003oooooooooo`09ooooo`03oiRHV?lQ8B7ok^k^00gooooo00Ko0000oooooomgMgOo
<S8booooool0000Oooooo`03ogMgMolb<S;ooooo01kooooo00?o8B4Qooooooooool03_ooool00omg
MgOo<S8booooo`0Kooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003
ooooo`002oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007?ooool0
0omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`07_ooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<01oooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Wo
oooo00?o0000ooooooooool00_l0000Booooo`03o`000?oooooooooo00_ooooo00?oMgMgofIVI_oo
ool02oooool3o`000004oc8b<_o<c<coooooo`0001cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00O
ooooo`03oeEEEOo<c<cooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Looooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`002oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41007?ooool00onYZJWoMgMgooooo`0;ooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo01_ooooo0_l000000ooooooo0000ooooo`0Aooooo`;o00003_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Qooooo`03ojVYZOmgMgOooooo00_ooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool000_ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Wooooo00Go410@oooooooooooooooooc8b<P0<oooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool07_ooool01Ol0003o^[ZjoooooonHV9So
410@00cooooo00?o0000ooooooooool07Oooool2o`00017ooooo0_l0000;ooooo`05o`000?nj^[[o
oooooiRHV?l@41002oooool2o`0000Cooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0Nooooo`05oa0@4?oooooooooooooooolb<S803?ooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`002Oooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06Oooool5o`0000cooooo1?l0000Oooooo`Co
00007Oooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l0000Mooooo`Ko00002Oooool3o`00
00gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00;ooooo`Ko00007_ooool4o`0001gooooo1Ol0000<
ooooo`Co00006oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool00;Gooooo00?o0000ooooooooool00oooool9o`0001oooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1looooo`00]Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0OOooool00;Gooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo07kooooo002eooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`1nooooo`00]Oooool00ol0003ooooooooo
o`0Wooooo`;o00001Oooool00ol0003oooooooooo`1oooooo`002oooooooo`0005Ko00002?ooool0
00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool00oooool00ol0003oooooo`000004ooooo`05o`000?oooooooooo
ooooool000001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo000;oooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool09?ooool01?l0003oooooooooool00003
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo00Kooooo002eooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`23ooooo`00]Oooool00ol0003oooooooooo`0Qooooo`;o
00001Oooool2o`0008Kooooo002eooooo`03o`000?oooooooooo01oooooo0_l00005ooooo`;o0000
R?ooool00;Gooooo00?o0000ooooooooool07Oooool2o`0000Gooooo0_l0002:ooooo`00]Oooool0
0ol0003oooooooooo`0Kooooo`;o00001Oooool2o`0008cooooo002eooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool00oooool2o`0008kooooo002eooooo`;o00006_ooool7o`00093o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002Jooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0;3ooooo002Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00Voooool00onHV9So8B4Q
onk^kP0Aooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009cooooo00?o
V9RHob4Q8Oo^k^h03oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009gooooo00?oMgMg
ofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?oo
ool009kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0;3ooooo002Jooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool4
o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Zoooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool0/?ooool00:kooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`2`ooooo`00[oooool00ol0003oooooooooo`03ooooo`?o0000/?ooool00:kooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00Zoooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool00:_ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`2`ooooo`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0;3ooooo002[ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Looooo`03o`000?o^k^kooooo00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00W?ooool00omE
EEGoZJVYooooo`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
0;3ooooo002Looooo`03ojVYZOmEEEGooooo013ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`2`ooooo`00WOooool00olQ8B7oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo
0ol0002`ooooo`00WOooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`2`ooooo`00WOooool00onYZJWoMgMgooooo`0;ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooc8b
<P0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo1Ol0000<
ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000
/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Sooooo`Co000000So410@oooo
ooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000ooooooooool0/?ooool00:Gooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0
/?ooool00:Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo
0ol0002`ooooo`00YOooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
^Oooool00:Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo00000;Wooooo
002Uooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@402iooooo`00YOoo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0^Oooool00:?ooooo00?o
EEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^0;Wooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-10, -10, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.05 0.5 0.05 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-10)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-7.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-2.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(2.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(7.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(10)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-10)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-7.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-2.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(2.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(7.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(10)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.49033 .46037 m
.48628 .46352 L
.48324 .46635 L
.48119 .4689 L
.48005 .4712 L
.47979 .4733 L
.48034 .47521 L
.48163 .47695 L
.4836 .47854 L
.48618 .48 L
.4893 .48133 L
.49288 .48255 L
.49686 .48365 L
.50115 .48464 L
.50571 .48552 L
.51046 .48628 L
.51535 .48692 L
.52033 .48742 L
.52535 .48777 L
.53035 .48797 L
.53529 .48801 L
.54011 .48786 L
.54476 .48753 L
.54916 .487 L
.55327 .48626 L
.55701 .48533 L
.56033 .4842 L
.56317 .48288 L
.5655 .48139 L
.56729 .47973 L
.56853 .47793 L
.56926 .47598 L
.56952 .4739 L
.56938 .47168 L
.56893 .4693 L
.56831 .46674 L
.56766 .46396 L
.56719 .46092 L
.5671 .45756 L
.56765 .45383 L
.56915 .44965 L
.57195 .44498 L
.57645 .43975 L
.58313 .43401 L
.59249 .42793 L
.60502 .42207 L
.62089 .4177 L
.63941 .41732 L
.65783 .42469 L
.67031 .44265 L
Mistroke
.66986 .46827 L
.65513 .4921 L
.63404 .50737 L
.61664 .51503 L
.60773 .51851 L
.60718 .51985 L
.61293 .51971 L
.62268 .5181 L
.63452 .51487 L
.64689 .50988 L
.65866 .50313 L
.66902 .49484 L
.67748 .48537 L
.68384 .47524 L
.68814 .46497 L
.69056 .45504 L
.69141 .44583 L
.69103 .43759 L
.68977 .43046 L
.68795 .42448 L
.68583 .41961 L
.68365 .41577 L
.68156 .41286 L
.67967 .41076 L
.67803 .40936 L
.67668 .40854 L
.67556 .4082 L
.67463 .40821 L
.67377 .40844 L
.67287 .40874 L
.67176 .40894 L
.67025 .40886 L
.66811 .40834 L
.66506 .40726 L
.66075 .40564 L
.65479 .40369 L
.64683 .40186 L
.63667 .40077 L
.62439 .40107 L
.61041 .40317 L
.59544 .4071 L
.58025 .41249 L
.56552 .41877 L
.55171 .42536 L
.5391 .43184 L
.52781 .43792 L
.51784 .44347 L
.50916 .44845 L
.50172 .45289 L
.49546 .45685 L
Mistroke
.49033 .46037 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00Xoooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^jiooooo`00YOooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0^Ooo
ool009[ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
402iooooo`00YOooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_oo
ool3o`000;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0;3ooooo002S
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool009cooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Looooo`03oeEEEOnYZJWo
oooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool0
09;ooooo1_l00004ooooo`03ojVYZOmEEEGooooo013ooooo00?o0000ooooooooool00oooool3o`00
0;3ooooo002Mooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`2`ooooo`00WOooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`2`ooooo`00WOooool00onYZJWoMgMgooooo`0;ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooo
oc8b<P0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo1Ol0
000<ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002[ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`2`ooooo`00[_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002R
ooooo`Ko00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002^oooo
o`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00Zoooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool0/?ooool00:_ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2`ooooo`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo
002[ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Jooooo`Go00001Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h04Oooool0
0ol0003oooooooooo`03ooooo`?o0000/?ooool009cooooo00?oV9RHob4Q8Oo^k^h03oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Mooooo`03ogMgMomVIVKooooo00_o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo002Nooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00
V_ooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2`ooooo`00V_ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l00006ooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o00009_ooool9o`00
08;ooooo002eooooo`03o`000?oooooooooo023ooooo1Ol00009ooooo`Ko0000O?ooool00;Gooooo
00?o0000ooooooooool07?ooool4o`0001Cooooo0_l0001jooooo`00]Oooool00ol0003ooooooooo
o`0Iooooo`?o00006_ooool4o`0007Kooooo002eooooo`03o`000?oooooooooo01Oooooo0_l0000Q
ooooo`;o0000M?ooool00;Gooooo00?o0000ooooooooool05?ooool3o`0002Cooooo00?o0000oooo
ooooool0L_ooool00;Gooooo00?o0000ooooooooool04_ooool2o`00013ooooo2ol0000<ooooo`03
o`000?oooooooooo07;ooooo002eooooo`03o`000?oooooooooo013ooooo0_l0000>ooooo`Co0000
2oooool3o`0000[ooooo00?o0000ooooooooool0LOooool00;Gooooo0_l0000@ooooo`03o`000?oo
oooooooo00_ooooo0ol0000Booooo`;o00002Oooool00ol0003oooooooooo`1`ooooo`00]Oooool0
0ol0003oooooooooo`0=ooooo`;o00003Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0L?ooool00;Gooooo00?o0000ooooooooool02oooool2o`00
00kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
073ooooo002eooooo`03o`000?oooooooooo00Wooooo0_l0000?ooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`00]Oooool00ol0003ooooo
ooooo`07ooooo`;o00003oooool2o`0001_ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`1_ooooo`00]Oooool00ol0003oooooooooo`05ooooo`;o00004?ooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Koooool00;Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`1_ooooo`00]Oooool00ol0003oooooooooo`02oooo
o`;o00004Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0Koooool00;Gooooo00?o0000ooooool000000_l0000Cooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1_ooooo`00]Oooool2o`0001Gooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06oooooo
002dooooo`;o00005_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0Koooool00;?ooooo00?o0000ooooool000005_ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Koooool00;?ooooo00?o0000oooo
ool000005_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0Koooool000Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^6ooo
ool00ol0003ok^k^ooooo`05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01kooooo
00GoA4A4o`000?l0003o<S8bomgMg@0Looooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0
003o<S8bomgMg@0Hooooo`;o00000_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
00Gooooo1Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0@ooooo`05odA4A?l0003o0000oc8b<_oMgMd07_oo
ool00ol0003ok^k^ooooo`05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01[ooooo
1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool000_ooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00?oEEEEojVYZOooool01Oooool2
ob4Q8@Sooooo00?oMgMgoc8b<_ooool08?ooool00omgMgOo<S8booooo`0Kooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01Oooool01OnHV9So8B4Qonk^
k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Cooooo`03ogMgMolb<S;ooooo01gooooo00?oEEEEojVYZOooool0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool000Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41004Oooool6o`0000Cooooo00?oZJVYoeEEEOooool04?ooool00ol0003o
ooooooooo`0Cooooo`Ko00001oooool00ol0003oooooooooo`0Booooo`Ko00000oooool00onHV9So
8B4Qonk^kP0Aooooo`03o`000?oooooooooo01?ooooo0_l00005ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool01_ooool00onHV9So8B4Qonk^kP0Aooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01co
oooo00?oZJVYoeEEEOooool04?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@4003ooooo`002oooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000007?ooool00olQ8B7oooooooooo`0>ooooo`03ogMgMolb<S;ooooo
023ooooo00?oMgMgoc8b<_ooool07Oooool00onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;ooooo
01Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
00Oooooo00?oV9RHob4Q8Oo^k^h03oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool05?ooool00omgMgOo<S8booooo`0Nooooo`03ob4Q8Ooooooooooo
00kooooo00?oMgMgoc8b<_ooool06oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000000oooool000_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000001cooooo00?oEEEEolc<c?ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01kooooo00Go
0000ob4Q8Ol0003o<S8bolc<c00Oooooo`03ogMgMomVIVKooooo00_ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c00Eooooo`03o`000?oooooooooo00Cooooo0_l0000Fooooo`03o`000?oooooooooo00Oo
oooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Aooooo`05o`000?lQ8B7o0000oc8b<_o<c<`07oooool0
0omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`07?ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000000oooool000_ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@01cooooo00?oZJVYogMgMoooool02oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Gooooo`;o00001Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Qooooo`03ojVYZOmgMgOooooo00_ooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41000oooool000_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Wo
oooo00Go410@oooooooooooooooooc8b<P0<ooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool07_ooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool06?ooool2
o`0000Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`05ooooo`05o`000?nj^[[o
oooooiRHV?l@41003?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Nooooo`05oa0@4?oooooooooooooooolb<S80
3?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`002Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h06Oooool5o`0000cooooo1?l0000Oooooo`Co00007Oooool01OnHV9So410@o`000?lQ8B7oc<c<
00cooooo1?l0000Iooooo`Go00005?ooool2o`0000Sooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<
ooooo`Co00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo1?l0000M
ooooo`Go00003?ooool4o`0001_ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo002eooooo`Go00003Oooool3o`0002;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1dooooo`00]Oooool00ol0003oooooooooo`02ooooo`go00009?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo07Gooooo002eooooo`03o`000?oooooooooo037o
oooo0_l00004ooooo`03o`000?oooooooooo07Kooooo002eooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`1gooooo`00]Oooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0N?ooool000_oooooool0001F
o`0000Sooooo000;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01_l0
003ooooooooooooooooo0000ooooo`;o00001?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Kooooo000;ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool09oooool0
1Ol0003ooooooooooooooooo000000Cooooo0_l0000Pooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`06ooooo`00]Oooool00ol0003oooooooooo`0Y
ooooo`;o00000oooool2o`00083ooooo002eooooo`03o`000?oooooooooo02Kooooo0ol00003oooo
o`;o0000P_ooool00;Gooooo00?o0000ooooooooool09?ooool2o`0000?ooooo0ol00024ooooo`00
]Oooool00ol0003oooooooooo`0Rooooo`;o000000?oooooo`000?l000000_l00027ooooo`00]Ooo
ool00ol0003oooooooooo`0Qooooo`Co0000Roooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aoooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00V_ooool5o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OnHV9So8B4Qonk^k_ooooooA4A4
00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009_o
oooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3o
oooo002Looooo`03oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool01?ooool3o`000;3ooooo
002Mooooo`03ogMgMomVIVKooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Nooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OnHV9So410@o`000?lQ
8B7oc<c<00cooooo1?l00006ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:_ooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002^ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0/?ooool00:oooooo00?o0000ooooooooool00oooool3o`00
0;3ooooo002^ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool00:_ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool00:_ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`2`ooooo`00Zoooool4o`0000Kooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00W?ooool00ol0003ok^k^ooooo`05
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?oo
ool009cooooo00?oEEEEojVYZOooool01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`2`ooooo`00W?ooool00onYZJWoEEEEooooo`0@ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0/?ooool009gooooo00?o8B4Qooooooooool03_ooool00omgMgOo
<S8booooo`04ooooo`?o0000/?ooool009gooooo00?oEEEEolc<c?ooool02oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool009gooooo00?oZJVYogMgMoooool0
2oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?oo
oooooooooooooolb<S803?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo
002Jooooo`Go00003?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Xoooool4
o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooooooo0;3o
oooo002Uooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03
o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@4006ooooo`?o0000/?ooool00:Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo00000;Wooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`00002iooooo`00YOooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
4100^Oooool00:Gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg0;Wo
oooo002Sooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP2iooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-10, -10, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.05 0.5 0.05 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-10)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-7.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-2.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(2.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(7.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(10)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-10)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-7.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-2.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(2.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(7.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(10)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.48021 .46758 m
.4759 .47015 L
.47276 .47247 L
.47076 .47456 L
.46984 .47645 L
.46994 .47816 L
.471 .47972 L
.47293 .48115 L
.47565 .48245 L
.4791 .48365 L
.48318 .48474 L
.4878 .48573 L
.49287 .48664 L
.49832 .48745 L
.50406 .48817 L
.51002 .48879 L
.51612 .48931 L
.52231 .48972 L
.5285 .49001 L
.53465 .49017 L
.54069 .49019 L
.54655 .49007 L
.55215 .48979 L
.55743 .48935 L
.5623 .48875 L
.56668 .48797 L
.5705 .48704 L
.57371 .48596 L
.57625 .48473 L
.5781 .48337 L
.57926 .48189 L
.57976 .48029 L
.57965 .47859 L
.57903 .47677 L
.578 .47482 L
.57673 .47273 L
.57538 .47045 L
.57419 .46797 L
.5734 .46522 L
.57333 .46216 L
.57432 .45874 L
.57679 .4549 L
.58124 .45061 L
.58823 .44589 L
.59844 .44087 L
.61254 .43601 L
.63103 .43232 L
.65355 .43183 L
.67749 .43762 L
.69631 .45212 L
Mistroke
.70092 .47308 L
.68776 .4928 L
.66512 .50557 L
.64544 .512 L
.63527 .51492 L
.63487 .51602 L
.64185 .51586 L
.65343 .51446 L
.66721 .51169 L
.6813 .50746 L
.69429 .50178 L
.70524 .49482 L
.71364 .48693 L
.71935 .47852 L
.72251 .47003 L
.72346 .46186 L
.72265 .45431 L
.72053 .44758 L
.71756 .44178 L
.71414 .43693 L
.71058 .43299 L
.70715 .42989 L
.70402 .42755 L
.70129 .42587 L
.69902 .42475 L
.6972 .42411 L
.69577 .42385 L
.69464 .42387 L
.69364 .42408 L
.6926 .42434 L
.69129 .42452 L
.68944 .42448 L
.68673 .42409 L
.68279 .42326 L
.67721 .422 L
.66955 .42049 L
.65948 .41909 L
.64687 .41831 L
.63195 .41867 L
.61532 .4205 L
.59785 .42381 L
.58039 .42828 L
.56366 .43347 L
.54813 .43889 L
.53404 .44421 L
.52147 .44919 L
.51041 .45374 L
.50081 .45782 L
.49262 .46145 L
.48577 .46469 L
Mistroke
.48021 .46758 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00Xoooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^jiooooo`00YOooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0^Ooo
ool009[ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
402iooooo`00YOooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_oo
ool3o`000;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0;3ooooo002S
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool009cooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Looooo`03oeEEEOnYZJWo
oooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool0
09;ooooo1_l00004ooooo`03ojVYZOmEEEGooooo013ooooo00?o0000ooooooooool00oooool3o`00
0;3ooooo002Mooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`2`ooooo`00WOooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`2`ooooo`00WOooool00onYZJWoMgMgooooo`0;ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooo
oc8b<P0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo1Ol0
000<ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002[ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`2`ooooo`00[_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002R
ooooo`Ko00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002^oooo
o`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00Zoooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool0/?ooool00:_ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2`ooooo`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo
002[ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Jooooo`Go00001Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h04Oooool0
0ol0003oooooooooo`03ooooo`?o0000/?ooool009cooooo00?oV9RHob4Q8Oo^k^h03oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Mooooo`03ogMgMomVIVKooooo00_o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo002Nooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00
V_ooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2`ooooo`00V_ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l00006ooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool09oooool?o`0007[ooooo002eooooo`03o`00
0?oooooooooo027ooooo1_l0000?ooooo`Go0000MOooool00;Gooooo0_l0000Nooooo`Co00006_oo
ool7o`0006kooooo002eooooo`03o`000?oooooooooo01[ooooo0ol0000Tooooo`;o0000KOooool0
0;Gooooo00?o0000ooooooooool05_ooool4o`0002Wooooo0_l0001[ooooo`00]Oooool00ol0003o
ooooooooo`0Booooo`Co00004?ooool>o`00017ooooo00?o0000ooooooooool0J?ooool00;Gooooo
00?o0000ooooooooool03oooool3o`00013ooooo1?l0000>ooooo`Co00003Oooool00ol0003ooooo
ooooo`1Xooooo`00]Oooool00ol0003oooooooooo`0<ooooo`?o00004?ooool3o`0001Kooooo0ol0
000;ooooo`03o`000?oooooooooo06Oooooo002eooooo`03o`000?oooooooooo00Wooooo0ol0000A
ooooo`;o00007?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo06Kooooo002eoooo
o`03o`000?oooooooooo00Oooooo0_l0000Cooooo`03o`000?oooooooooo01gooooo0_l00009oooo
o`03o`000?oooooooooo06Kooooo002eooooo`03o`000?oooooooooo00Gooooo0_l0000Cooooo`;o
00008_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo06Gooooo002eooooo`;o0000
0oooool3o`0001Cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo06Gooooo002eooooo`03o`000?oooooo000000;o00005_ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0I?ooool00;Gooooo0_l0000H
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1T
ooooo`00]?ooool2o`0001Sooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo06Cooooo0009ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o
<S8bonk^kQ_ooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8b
omgMg@0Nooooo`05odA4A?l0003o0000oc8b<_oMgMd07?ooool5o`0000Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd06?ooool3o`000003ooooool0003ooooo01Oooooo00?o0000oooo
ooooool00oooool5o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd03_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgM
g@0Nooooo`03o`000?o^k^kooooo00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
6_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`002oooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool00omEEEGoZJVYooooo`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Pooooo`03ogMgMolb<S;ooooo01_ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Eooooo`;o00001?oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00?ooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A005ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01oooool00omgMgOo<S8booooo`0Mooooo`03oeEEEOnYZJWooooo00Gooooo
0_lQ8B48ooooo`03ogMgMolb<S;ooooo01_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo0006o`0000Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@017ooooo1_l00004ooooo`03ojVYZOmEEEGooooo013ooooo00?o0000oooooooo
ool04oooool6o`0000Oooooo00?o0000ooooooooool04_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^
k^h04Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool07?ooool00onYZJWoEEEEooooo`0@ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo000;ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`00000Looooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b
<_ooool08?ooool00omgMgOo<S8booooo`0Mooooo`03oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b
<_ooool04oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool01?ooool00onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;ooooo00kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`07ooooo`03ogMgMolb<S;ooooo01kooooo00?o8B4Qoooo
ooooool03_ooool00omgMgOo<S8booooo`0Kooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000003ooooo`002oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000007?ooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`07_oo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<01oooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<01;ooooo0_l00008ooooo`;o00006?ooool00ol0003oooooooooo`05ooooo`03
ogMgMomVIVKooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01oooooo00?oEEEE
olc<c?ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01cooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000?ooooo000;ooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@400Looooo`03ojVYZOmgMgOooooo00_ooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo027ooooo00?oZJVYogMgMoooool0
2oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`002oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL06Oooool01Ol@413ooooooooooooooooo<S8b00cooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0Nooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06?ooool02Ol0003ooooooooooooo
oooo0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01kooooo00Go410@oooooooo
oooooooooc8b<P0<ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo0009ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Iooooo`Go00003?ooool4o`0001oooooo1?l0000Mooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`03?ooool4o`0001Cooooo0ol00006ooooo`03o`000?oooooooooo01Oooooo0_l0
0003ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool4o`0000oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`Co00007Oooool5o`0000cooooo1?l0000Kooooo`03oeEE
EOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00[oooool5o`000003oooo
ool0003ooooo01Oooooo0_l0000Wooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
I_ooool00;Cooooo2?l0000<ooooo`Ko0000:?ooool00ol0003oooooooooo`04ooooo`;o0000JOoo
ool00;Gooooo00?o0000ooooooooool01?ooool<o`0002kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1Yooooo`00]Oooool00ol0003oooooooooo`0looooo`;o00001?ooool2o`00
06cooooo002eooooo`03o`000?oooooooooo03[ooooo0_l00005ooooo`03o`000?oooooooooo06co
oooo000;oooooooo0000E_l00008ooooo`002oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool00oooool3o`0000Gooooo0_l000000ooooooo0000oooo
o`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`06ooooo`002oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool02Oooool3o`0000Kooooo0_l0000Dooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`06ooooo`00]Oooool00ol0003oooooooooo`0`oooo
o`?o00001_ooool3o`0007Cooooo002eooooo`03o`000?oooooooooo02gooooo0ol00004ooooo`Go
0000Moooool00;Gooooo00?o0000ooooooooool0:oooool9o`0007cooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool009[ooooo1Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009[ooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A005ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3o
oooo002Kooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00W?ooool00onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0
002`ooooo`00WOooool00omgMgOoIVIVooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`2`ooooo`00W_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000okZj^_ooooooV9RHoa0@400<
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00<ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002[oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00[_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002_ooooo`03o`000?oooooooooo00?o
oooo0ol0002`ooooo`00[_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo
002[ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`ooooo`00Zooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0/?ooool00:_ooooo1?l00006ooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool009cooooo00?o0000onk^
k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0;3ooooo002Looooo`03oeEEEOnYZJWooooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool009cooooo00?oZJVYoeEEEOooool04?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002Mooooo`03ob4Q8Ooooooooooo00kooooo
00?oMgMgoc8b<_ooool01?ooool3o`000;3ooooo002Mooooo`03oeEEEOo<c<cooooo00_ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo002Mooooo`03ojVYZOmg
MgOooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00V_ooool0
1Ol@413ooooooooooooooooo<S8b00cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`2`ooooo`00V_ooool5o`0000cooooo1?l00006ooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0:?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1_ooool00ol0003ooooo
ooooo`2`ooooo`00YOooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1_ooool00ol0003oooooooooo`2`ooooo`00YOooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41001_ooool3o`000;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`00002iooooo`00YOooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool00000^Oooool00:Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@0;Wooooo002Uooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`2iooooo`00Xoooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
^Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-10, -10, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.05 0.5 0.05 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-10)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-7.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-2.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(2.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(7.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(10)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-10)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-7.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-2.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(2.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(7.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(10)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.46932 .47361 m
.46456 .47573 L
.4612 .47764 L
.45918 .47936 L
.45844 .48091 L
.45891 .48231 L
.4605 .48358 L
.46315 .48474 L
.46674 .4858 L
.47119 .48676 L
.47639 .48765 L
.48223 .48846 L
.48861 .48919 L
.49543 .48986 L
.50259 .49045 L
.50999 .49095 L
.51755 .49137 L
.52518 .4917 L
.53281 .49192 L
.54035 .49202 L
.54773 .492 L
.55486 .49185 L
.56164 .49156 L
.56799 .49113 L
.57381 .49055 L
.579 .48984 L
.58348 .48899 L
.58717 .48803 L
.59002 .48696 L
.592 .4858 L
.59312 .48456 L
.59341 .48324 L
.59294 .48186 L
.59181 .48039 L
.59017 .47883 L
.58819 .47716 L
.5861 .47534 L
.58414 .47334 L
.58263 .47112 L
.58192 .46863 L
.58244 .46581 L
.58468 .46262 L
.58924 .45901 L
.59682 .45495 L
.60826 .45049 L
.62447 .44587 L
.64624 .44171 L
.67352 .43934 L
.70374 .4411 L
.72946 .44971 L
Mistroke
.73923 .46555 L
.72725 .48362 L
.70237 .49727 L
.67976 .50479 L
.66798 .50814 L
.66772 .50907 L
.67617 .50827 L
.68996 .50588 L
.70613 .50189 L
.72236 .49639 L
.73695 .48962 L
.74881 .48197 L
.75738 .47394 L
.7626 .46602 L
.76472 .45858 L
.76423 .45191 L
.76174 .44613 L
.75783 .44129 L
.75309 .43735 L
.74798 .43422 L
.74289 .43182 L
.73812 .43003 L
.73386 .42875 L
.73022 .42791 L
.72725 .42743 L
.72492 .42723 L
.72314 .42727 L
.72177 .42748 L
.72061 .4278 L
.7194 .42818 L
.71785 .42854 L
.7156 .42881 L
.71223 .42891 L
.70729 .42883 L
.70027 .42862 L
.69067 .4284 L
.67816 .42845 L
.66268 .42909 L
.64461 .4306 L
.62474 .43313 L
.60411 .43662 L
.58372 .44082 L
.56436 .44538 L
.54649 .44999 L
.53035 .45442 L
.516 .45853 L
.5034 .46225 L
.49251 .4656 L
.48323 .46858 L
.47552 .47123 L
Mistroke
.46932 .47361 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00Xoooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^jiooooo`00YOooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0^Ooo
ool009[ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
402iooooo`00YOooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_oo
ool3o`000;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0;3ooooo002S
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool009cooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Looooo`03oeEEEOnYZJWo
oooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool0
09;ooooo1_l00004ooooo`03ojVYZOmEEEGooooo013ooooo00?o0000ooooooooool00oooool3o`00
0;3ooooo002Mooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`2`ooooo`00WOooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`2`ooooo`00WOooool00onYZJWoMgMgooooo`0;ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooo
oc8b<P0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo1Ol0
000<ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002[ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`2`ooooo`00[_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002R
ooooo`Ko00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002^oooo
o`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00Zoooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool0/?ooool00:_ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2`ooooo`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo
002[ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Jooooo`Go00001Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h04Oooool0
0ol0003oooooooooo`03ooooo`?o0000/?ooool009cooooo00?oV9RHob4Q8Oo^k^h03oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Mooooo`03ogMgMomVIVKooooo00_o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo002Nooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00
V_ooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2`ooooo`00V_ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l00006ooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`18ooooo`Co0000I?ooool0
0;Gooooo00?o0000ooooooooool0:ooooolNo`0000?ooooo1?l0001Pooooo`00]Oooool00ol0003o
ooooooooo`0Tooooo`Oo00009Oooool00ol0003oooooooooo`1Mooooo`00]Oooool00ol0003ooooo
ooooo`0Nooooo`Ko0000;Oooool2o`0005gooooo002eooooo`03o`000?oooooooooo01_ooooo0ol0
000Fooooo`[o00005Oooool2o`0005_ooooo002eooooo`03o`000?oooooooooo01Kooooo1Ol0000B
ooooo`Oo00002_ooool7o`00013ooooo00?o0000ooooooooool0F?ooool00;Gooooo00?o0000oooo
ooooool04_ooool4o`0001?ooooo1?l0000Hooooo`?o00003Oooool00ol0003oooooooooo`1Hoooo
o`00]Oooool00ol0003oooooooooo`0?ooooo`?o00004oooool4o`0001oooooo0ol0000;ooooo`03
o`000?oooooooooo05Oooooo002eooooo`;o00002oooool5o`0001;ooooo1?l0000Vooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0Eoooool00;Gooooo00?o0000ooooooooool01_oo
ool4o`0001Gooooo0_l0000Zooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0E_oo
ool00;Gooooo00?o0000ooooooooool00oooool3o`0001Oooooo0_l0000]ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0E_ooool00;Gooooo00?o0000ooooooooool00ol0000Hoooo
o`;o0000<?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Kooooo0009ooooo`Co
000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQ_ooooo00?o0000onk^k_ooool01Ooo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Nooooo`05odA4A?l0003o0000oc8b<_oM
gMd07?ooool5o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd06oooool4o`00
01[ooooo00?o0000ooooool000001?l00005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM01_ooooo00Co0000ooooooooooooA4A40_l000001Olb<S;ogMgMoooooooooooo000001_ooooo
00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Jooooo`Co
000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo000;ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`03oeEEEOnYZJWooooo00Gooooo0_lQ
8B48ooooo`03ogMgMolb<S;ooooo023ooooo00?oMgMgoc8b<_ooool06oooool01OnHV9So8B4Qonk^
k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01Oooooo0ol000000ooooooo0000
ooooo`0Jooooo`08o`000?oooooooooooiRHV?lQ8B7ok^k^oooooom4A4@5ooooo`;o8B4Q2?ooool0
0omgMgOo<S8booooo`0Kooooo`03o`000?oooooooooo00;ooooo00CoMgMgoc8b<_oooooo00007?oo
ool00omEEEGoZJVYooooo`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`001_l00005ooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@400Aooooo`Ko00001?ooool00onYZJWoEEEE
ooooo`0@ooooo`03o`000?oooooooooo01?ooooo1_l00007ooooo`03o`000?oooooooooo01;ooooo
1_l00003ooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000ooooooooool04oooool3o`0000Cooooo
00?o0000ooooooooool06Oooool01ol0003oooooooooooooooooV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000007?ooool00onY
ZJWoEEEEooooo`0@ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@00?ooooo000;ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00000Looooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool08?ooool0
0omgMgOo<S8booooo`0Mooooo`03oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool04_ooool2
o`0000Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`02ooooo`03oiRHV?lQ8B7o
k^k^00oooooo00?oMgMgoc8b<_ooool06_ooool00ol0003oooooooooo`03ooooo`03ogMgMolb<S;o
000001kooooo00?o8B4Qooooooooool03_ooool00omgMgOo<S8booooo`0Kooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`002oooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000007?ooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`07_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01oooooo00?oMgMgofIVI_oo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<017ooooo0_l00009ooooo`;o00006oooool00ol0
003oooooooooo`02ooooo`03ogMgMomVIVKooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00J
ooooo`09o`000?ooooooooooooooool0003o8B4Qo`000?lb<S;o000001oooooo00?oEEEEolc<c?oo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01cooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000?ooooo000;ooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@400Looooo`03ojVYZOmgMgOooooo00_ooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04Oooool2
o`0000_ooooo00?o0000ooooooooool06_ooool2o`0000Cooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Looooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`0Mooooo`03ojVYZOmgMgOooooo00_ooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41000oooool000_ooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01Wooooo00Go410@oooooooooooooooooc8b<P0<ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool07_ooool01Ol0003o^[ZjoooooonHV9So410@
00cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
01cooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool0000Mooooo`05oa0@4?oooooooooooooooolb<S80
3?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`002Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h06Oooool5o`0000cooooo1?l0000Oooooo`Co00007Oooool01OnHV9So410@o`000?lQ8B7oc<c<
00cooooo1?l0000?ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07?ooool3o`00
0003ob4Q8Oo<c<cooooo00_ooooo1?l0000Hooooo`;o00001Oooool4o`0001gooooo1Ol0000<oooo
o`Co00006oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
0:Sooooo1Ol00008ooooo`03o`000?oooooooooo01cooooo0_l0000Zooooo`03o`000?oooooooooo
00?ooooo0ol0001Oooooo`00[Oooool6o`0000;ooooo00?o0000ooooooooool06Oooool4o`0002Wo
oooo0_l00004ooooo`;o0000H_ooool00;?ooooo7_l0000[ooooo`;o00001Oooool00ol0003ooooo
ooooo`1Rooooo`00]Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0Hoooool00;Gooooo00?o0000ooooooooool0@Oooool2o`0000Gooooo0_l0001V
ooooo`002oooooooo`0005Ko00002?ooool000_ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00ol00003ooooo`Co
00001?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01_ooool000_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo00kooooo0ol000000ooooooo0000o`000003o`00017ooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Kooooo002eooooo`03o`000?oo
oooooooo03Kooooo1_l0001dooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Joooo
o`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0;3ooooo002Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00Voooool00onHV9So8B4Qonk^kP0Aoooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009cooooo00?oV9RHob4Q8Oo^
k^h03oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009gooooo00?oMgMgofIVI_ooool0
2oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool009kooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo
002Jooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool4o`0000Kooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00Zoooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo
00?o0000ooooooooool0/?ooool00:kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`2`ooooo`00[oooool00ol0003oooooooooo`03ooooo`?o0000/?ooool00:kooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00Zoooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool0/?ooool00:_ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2`ooooo`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo
002[ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002Looooo`03o`000?o^k^kooooo00Gooooo0_lQ8B45ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00W?ooool00omEEEGoZJVYoooo
o`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002L
ooooo`03ojVYZOmEEEGooooo013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2`
ooooo`00WOooool00olQ8B7oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`oooo
o`00WOooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0
003oooooooooo`2`ooooo`00WOooool00onYZJWoMgMgooooo`0;ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooc8b<P0<ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo1Ol0000<ooooo`Co0000
1_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Sooooo`Co000000So410@ooooooooooook^k^
oc8b<_l0003o<S8bonk^kPKooooo00?o0000ooooooooool0/?ooool00:Gooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0/?ooool00:Go
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo0ol0002`oooo
o`00YOooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000^Oooool00:Go
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo00000;Wooooo002Uooooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@402iooooo`00YOooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0^Oooool00:?ooooo00?oEEEEofIVI_l0
00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^0;Wooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-10, -10, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.05 0.5 0.05 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-10)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-7.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-2.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(2.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(7.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(10)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-10)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-7.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-2.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(2.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(7.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(10)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.45728 .47926 m
.45191 .48112 L
.4482 .48279 L
.44608 .48426 L
.44549 .48555 L
.44634 .48668 L
.44855 .48765 L
.452 .48851 L
.4566 .48927 L
.46222 .48996 L
.46874 .4906 L
.47603 .4912 L
.48397 .49177 L
.49243 .4923 L
.50129 .49278 L
.51043 .49319 L
.51975 .49351 L
.52913 .4937 L
.53848 .49376 L
.5477 .49364 L
.55668 .49334 L
.56533 .49283 L
.57352 .49213 L
.58114 .49123 L
.58809 .49017 L
.59423 .48898 L
.59949 .48771 L
.60376 .48639 L
.60699 .48508 L
.60915 .48382 L
.61026 .48264 L
.61034 .48154 L
.60949 .48051 L
.60784 .47953 L
.60554 .47855 L
.60282 .47752 L
.59992 .47637 L
.59715 .47504 L
.59487 .47346 L
.59352 .47155 L
.59359 .46922 L
.59566 .46635 L
.60045 .4628 L
.6088 .45832 L
.62169 .45252 L
.64022 .44475 L
.66537 .434 L
.69714 .41902 L
.73274 .39997 L
.76395 .38325 L
Mistroke
.77813 .38408 L
.76805 .4094 L
.74217 .44199 L
.71738 .46427 L
.70424 .4741 L
.70412 .47495 L
.71387 .46919 L
.72948 .45795 L
.74742 .44218 L
.76496 .4233 L
.78023 .40331 L
.79211 .38436 L
.80016 .36828 L
.80445 .3562 L
.80537 .34842 L
.80355 .34459 L
.79965 .34395 L
.79435 .34562 L
.78827 .34872 L
.78192 .35256 L
.77572 .3566 L
.76997 .36049 L
.76488 .36402 L
.76057 .36706 L
.75709 .36961 L
.75439 .37169 L
.75236 .37337 L
.75083 .37479 L
.74956 .37608 L
.74825 .37744 L
.74654 .37908 L
.744 .38125 L
.74015 .3842 L
.73443 .3882 L
.72626 .39348 L
.71506 .40015 L
.70045 .40811 L
.68235 .41695 L
.66123 .42602 L
.63801 .43464 L
.61391 .44234 L
.59012 .44894 L
.56754 .45449 L
.54672 .45918 L
.52794 .46317 L
.51124 .46664 L
.49661 .4697 L
.48397 .47244 L
.47325 .47493 L
.46438 .4772 L
Mistroke
.45728 .47926 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00Xoooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^jiooooo`00YOooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0^Ooo
ool009[ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
402iooooo`00YOooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_oo
ool3o`000;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0;3ooooo002S
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool009cooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Looooo`03oeEEEOnYZJWo
oooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool0
09;ooooo1_l00004ooooo`03ojVYZOmEEEGooooo013ooooo00?o0000ooooooooool00oooool3o`00
0;3ooooo002Mooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`2`ooooo`00WOooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`2`ooooo`00WOooool00onYZJWoMgMgooooo`0;ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooo
oc8b<P0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo1Ol0
000<ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002[ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`2`ooooo`00[_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002R
ooooo`Ko00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002^oooo
o`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00Zoooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool0/?ooool00:_ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2`ooooo`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo
002[ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`1Qooooo`Co0000Boooool00;Gooooo
00?o0000ooooooooool0H?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04Sooooo
002eooooo`;o0000Goooool2o`0000Gooooo00?o0000ooooooooool0B?ooool00;Gooooo00?o0000
ooooooooool0G?ooool2o`0000Kooooo00?o0000ooooooooool0BOooool00;Gooooo00?o0000oooo
ooooool0Foooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Wooooo002eooooo`03
o`000?oooooooooo05[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`19ooooo`00
]Oooool00ol0003oooooooooo`1Hooooo`;o00002_ooool00ol0003oooooooooo`19ooooo`00]Ooo
ool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0B_oo
ool009[ooooo1Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool0EOooool2o`0000cooooo00?o0000ooooooooool0B_ooool009[ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo05?ooooo0_l0000>ooooo`03o`000?oooooooooo04[ooooo002Booooo`Ko00000oooool0
0onHV9So8B4Qonk^kP0Aooooo`03o`000?oooooooooo00?ooooo0ol0001Booooo`;o00003_ooool0
0ol0003oooooooooo`1;ooooo`00W?ooool00onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0DOooool2o`0000oooooo00?o0000ooooooooool0Boooool009go
oooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0DOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04cooooo002Nooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1@ooooo`03
o`000?oooooooooo00?ooooo1Ol00006ooooo`03o`000?oooooooooo04cooooo002Jooooo`05o`00
0?nj^[[ooooooiRHV?l@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04ko
oooo0_l00004ooooo`;o00001Oooool2o`0000?ooooo00?o0000ooooooooool0COooool009[ooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`Co00001_ooool00ol0003oooooooooo`1<ooooo`;o
00001?ooool2o`0000Sooooo00Go0000ooooooooooooooooo`00001?ooooo`00]Oooool00ol0003o
ooooooooo`1;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool01Ol0003o
oooooooooooooooo0000053ooooo002eooooo`03o`000?oooooooooo04Wooooo0_l00004ooooo`;o
00002_ooool01?l0003oooooooooool0001Aooooo`00]Oooool00ol0003oooooooooo`17ooooo`;o
00001?ooool2o`0000_ooooo00Go0000ooooooooooooooooo`00001Aooooo`00]Oooool2o`0004Ko
oooo0_l00004ooooo`;o00003Oooool01?l0003oooooooooool0001Booooo`00]Oooool00ol0003o
ooooooooo`13ooooo`;o00001?ooool2o`0000kooooo00Co0000oooooooooooo0000Doooool00;Go
oooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`02ooooo`;o00004?ooool01?l0003o
ooooooooool0001Cooooo`00]Oooool00ol0003oooooooooo`10ooooo`;o00000oooool2o`00017o
oooo00Co0000oooooooooooo0000E?ooool00;Gooooo00?o0000ooooooooool0?_ooool2o`0000?o
oooo0_l0000Cooooo`03o`000?oooooo000005Gooooo002eooooo`03o`000?oooooooooo03cooooo
0_l00003ooooo`;o00005?ooool00ol0003oooooo`00001Fooooo`00]Oooool00ol0003ooooooooo
o`0jooooo`;o00000oooool2o`0001Gooooo00Co0000oooooooooooo0000E_ooool00;Gooooo00?o
0000ooooooooool0=oooool3o`0000?ooooo0_l0000Fooooo`04o`000?ooooooooooo`0005Oooooo
002eooooo`;o0000=_ooool2o`0000Cooooo0_l0000Gooooo`04o`000?ooooooooooo`0005Sooooo
002eooooo`03o`000?oooooooooo03?ooooo0_l00005ooooo`03o`000?oooooooooo01Kooooo00Co
0000oooooooooooo0000FOooool00;Gooooo00?o0000ooooooooool0<?ooool3o`0000Gooooo0_l0
000Iooooo`03o`000?oooooo000005[ooooo002eooooo`03o`000?oooooooooo02gooooo0ol00006
ooooo`;o00006_ooool00ol0003oooooo`00001Kooooo`00]Oooool00ol0003oooooooooo`0Zoooo
o`?o00001oooool2o`0001_ooooo00?o0000ooooool00000G?ooool00;Gooooo00?o0000oooooooo
ool09_ooool4o`0000Oooooo0ol0000Looooo`03o`000?oooooo000005gooooo002eooooo`03o`00
0?oooooooooo02?ooooo0ol00008ooooo`?o00007_ooool00ol0003oooooo`00001Nooooo`00]Ooo
ool00ol0003oooooooooo`0Pooooo`?o00002Oooool2o`00023ooooo00?o0000ooooool00000Gooo
ool00;Gooooo00?o0000ooooooooool07Oooool3o`0000Wooooo0ol0000Qooooo`03o`000?oooooo
0000063ooooo002eooooo`;o00006oooool3o`0000[ooooo0_l0000Sooooo`03o`000?oooooo0000
067ooooo002eooooo`03o`000?oooooooooo01Kooooo1?l0000;ooooo`;o00009?ooool00ol0003o
ooooo`00001Rooooo`00]Oooool00ol0003oooooooooo`0Aooooo`Go00003Oooool2o`0002Gooooo
00?o0000ooooool00000Hoooool00;Gooooo00?o0000ooooooooool02_ooool7o`00013ooooo0_l0
000Vooooo`?o0000I?ooool000Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;o
k^k^6oooool00ol0003ok^k^ooooo`05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM
01kooooo00GoA4A4o`000?l0003o<S8bomgMg@0Looooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@0Looooo`03o`000?oooooooooo00Gooooo1Ol0000Booooo`Go00001Ooo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Fooooo`;o00001_ooool01Om4A4Co0000
o`000?lb<S;ogMgM01kooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0
003o<S8bomgMg@0Jooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo
000;ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`03oeEE
EOnYZJWooooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo023ooooo00?oMgMgoc8b<_ooool0
6oooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01_o
oooo00?o0000ooooooooool00_ooool3o`0001Oooooo00GoV9RHob4Q8Ol0003oooooodA4A005oooo
o`;o8B4Q2?ooool00omgMgOo<S8booooo`0Cooooo`?o00002_ooool00omgMgOo<S8booooo`0Moooo
o`03oeEEEOnYZJWooooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01_ooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0006o`0000Gooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@017ooooo1_l00004ooooo`03ojVYZOmEEEGo
oooo013ooooo00?o0000ooooooooool04oooool6o`0000Oooooo00?o0000ooooooooool04_ooool6
o`0000?ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
000000;o00006oooool00ol0003o8B4Qonk^kP0Aooooo`03o`000?oooooooooo013ooooo0_l00000
0ooooooo0000ooooo`0;ooooo`03o`000?oooooooooo01cooooo00?oZJVYoeEEEOooool04?ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`002oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007?oo
ool00olQ8B7oooooooooo`0>ooooo`03ogMgMolb<S;ooooo023ooooo00?oMgMgoc8b<_ooool07Ooo
ool00onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;ooooo01Sooooo1Ol0000Nooooo`04o`000?nH
V9So8B4Qonk^kPoooooo00?oMgMgoc8b<_ooool04?ooool4o`0000cooooo00?oMgMgoc8b<_ooool0
7_ooool00olQ8B7oooooooooo`0>ooooo`03ogMgMolb<S;ooooo01_ooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000?ooooo000;ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`00000Looooo`03oeEEEOo<c<cooooo00_ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c00Nooooo`05o`000?lQ8B7o0000oc8b<_o<c<`07oooool00omgMgOoIVIVooooo`0;
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`04_ooool7o`0000?ooooo0_l0000Nooooo`04o`000?oo
ooooMgMgofIVIPcooooo00Go0000ob4Q8Ol0003o<S8bolc<c00@ooooo`;o00003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<01oooooo00?oEEEEolc<c?ooool02oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<01cooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo000;
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Looooo`03ojVYZOmg
MgOooooo00_ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool04Oooool3o`0000[ooooo00?o0000ooooooooool07_oo
ool3o`0000cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Qooooo`03ojVYZOmg
MgOooooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41000oooool000_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg01Wooooo00Go410@oooooooooooooooooc8b<P0<ooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool07_ooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000oooo
ooooool03oooool2o`0000gooooo00?o0000ooooooooool07?ooool01Ol0003o^[ZjoooooonHV9So
410@00;o00002_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01kooooo00Go410@
oooooooooooooooooc8b<P0<ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0009ooooo`03oeEEEOmVIVKo000000Cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0Iooooo`Go00003?ooool4o`0001oooooo1?l0000Mooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`03?ooool4o`0000_ooooo0ol0000?ooooo`03o`000?oooooooooo01co
oooo00OoV9RHoa0@4?l0003o8B4Qolc<c?oooooo000000[ooooo1?l0000Oooooo`Co00007Oooool5
o`0000cooooo1?l0000Kooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`00X_ooool2o`00017ooooo00?o0000ooooooooool08?ooool2o`0008kooooo002Soooo
o`Go00003Oooool00ol0003oooooooooo`0Looooo`Co0000T?ooool00:Sooooo3_l0000Gooooo`Oo
0000U?ooool00;Gooooo6?l0002Kooooo`00]Oooool00ol0003oooooooooo`2`ooooo`002ooooooo
o`0005Ko00002?ooool000_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`002oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool01_ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00V_ooool5o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`2`ooooo`00V_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ
8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009_ooooo00?oV9RH
ob4Q8Oo^k^h04Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002Loooo
o`03oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool01?ooool3o`000;3ooooo002Mooooo`03
ogMgMomVIVKooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo
0;3ooooo002Nooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2`ooooo`00V_ooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OnHV9So410@o`000?lQ8B7oc<c<00co
oooo1?l00006ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002a
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:_ooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002^ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0/?ooool00:oooooo00?o0000ooooooooool00oooool3o`000;3ooooo002^
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool00:_ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0/?ooool00:_ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2`ooooo`00Zoooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00W?ooool00ol0003ok^k^ooooo`05ooooo`;o8B4Q
1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009cooooo
00?oEEEEojVYZOooool01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00W?ooool00onYZJWoEEEEooooo`0@ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0/?ooool009gooooo00?o8B4Qooooooooool03_ooool00omgMgOo<S8booooo`04
ooooo`?o0000/?ooool009gooooo00?oEEEEolc<c?ooool02oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool0/?ooool009gooooo00?oZJVYogMgMoooool02oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?oooooooooooooo
oolb<S803?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`Go
00003?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Xoooool4o`000008oa0@
4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooooooo0;3ooooo002Uoooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooo
oooo0;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006
ooooo`?o0000/?ooool00:Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
00000;Wooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00002i
ooooo`00YOooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100^Oooool0
0:Gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg0;Wooooo002Soooo
o`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP2iooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-10, -10, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.05 0.5 0.05 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-10)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-7.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-2.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(2.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(7.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(10)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-10)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-7.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-2.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(2.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(7.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(10)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.4439 .48588 m
.43777 .48796 L
.43361 .48978 L
.43134 .49127 L
.43088 .49239 L
.43214 .49317 L
.435 .49365 L
.43935 .49391 L
.44508 .49403 L
.45204 .49412 L
.4601 .49424 L
.46911 .49445 L
.47891 .49474 L
.48934 .49511 L
.50026 .49549 L
.51151 .49581 L
.52294 .49598 L
.53442 .49588 L
.54581 .49542 L
.55697 .49453 L
.56778 .49313 L
.57811 .49122 L
.58781 .48882 L
.59676 .48599 L
.60483 .48285 L
.6119 .47957 L
.61786 .47631 L
.62264 .47328 L
.62619 .47064 L
.62848 .46853 L
.62954 .46702 L
.62942 .46614 L
.62822 .46582 L
.62608 .46596 L
.62319 .46639 L
.61977 .46693 L
.61612 .46739 L
.61258 .46756 L
.60957 .46727 L
.60758 .46632 L
.6072 .46448 L
.60909 .46144 L
.61406 .45668 L
.62301 .44927 L
.63695 .43749 L
.65684 .41817 L
.68323 .38579 L
.71522 .33279 L
.74901 .25557 L
.77705 .1724 L
Mistroke
.79078 .1339 L
.78578 .17522 L
.76638 .25879 L
.74522 .32537 L
.73328 .35605 L
.73331 .3568 L
.74249 .3352 L
.75652 .29659 L
.77165 .24631 L
.78535 .19091 L
.79623 .13745 L
.80384 .09208 L
.8083 .05882 L
.81 .03921 L
.80945 .03257 L
.80712 .03679 L
.80348 .04905 L
.79895 .06646 L
.79388 .08645 L
.78864 .107 L
.78349 .12662 L
.7787 .14434 L
.77442 .15965 L
.77078 .17233 L
.76783 .18244 L
.76554 .19021 L
.76384 .19604 L
.76258 .20049 L
.76156 .20422 L
.7605 .20806 L
.75909 .21296 L
.75695 .22 L
.75361 .23031 L
.74854 .24502 L
.74113 .26496 L
.73071 .29039 L
.71669 .32046 L
.69875 .35301 L
.67703 .38478 L
.65232 .41257 L
.62585 .43438 L
.59904 .44992 L
.5731 .4602 L
.54887 .46675 L
.52682 .47103 L
.50715 .47408 L
.4899 .4766 L
.47502 .47895 L
.46245 .48129 L
.4521 .48362 L
Mistroke
.4439 .48588 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00Xoooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^jiooooo`00YOooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0^Ooo
ool009[ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
402iooooo`00YOooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_oo
ool3o`000;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0;3ooooo002S
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0I_ooool00ol0003oooooooooo`17ooooo`00]Oooool00ol0003oooooooooo`1Uooooo`;o
0000BOooool00;Gooooo00?o0000ooooooooool0IOooool2o`0004Wooooo002eooooo`03o`000?oo
oooooooo06Gooooo0_l00019ooooo`00]Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooo
000004Wooooo002eooooo`03o`000?oooooooooo06Cooooo00?o0000ooooool00000BOooool00;Go
oooo0_l0001Uooooo`03o`000?oooooo000004Wooooo002eooooo`03o`000?oooooooooo06Cooooo
00?o0000ooooool00000BOooool00;Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooo`00
0019ooooo`00]Oooool00ol0003oooooooooo`1Sooooo`04o`000?ooooooooooo`0004Wooooo002e
ooooo`03o`000?oooooooooo06?ooooo00Co0000oooooooooooo0000BOooool00;Gooooo00?o0000
ooooooooool0Hoooool01?l0003oooooooooool00019ooooo`00]Oooool00ol0003oooooooooo`1S
ooooo`04o`000?ooooooooooo`0004Wooooo002eooooo`03o`000?oooooooooo06?ooooo00?o0000
ooooool00000B_ooool00;Gooooo0_l0001Sooooo`04o`000?ooooooooooo`0004[ooooo002eoooo
o`03o`000?oooooooooo06;ooooo00Co0000oooooooooooo0000B_ooool00;Gooooo00?o0000oooo
ooooool0H_ooool01?l0003oooooooooool0001:ooooo`00]Oooool00ol0003oooooooooo`1Qoooo
o`05o`000?ooooooooooooooool00000B_ooool00;Gooooo00?o0000ooooooooool0HOooool01?l0
003oooooooooool0001;ooooo`00]Oooool00ol0003oooooooooo`1Qooooo`04o`000?oooooooooo
o`0004_ooooo002eooooo`03o`000?oooooooooo067ooooo00Co0000oooooooooooo0000Boooool0
0;Gooooo00?o0000ooooooooool0H?ooool01Ol0003ooooooooooooooooo000004_ooooo002eoooo
o`03o`000?oooooooooo063ooooo00Go0000ooooooooooooooooo`00001;ooooo`00]Oooool2o`00
067ooooo00Go0000ooooooooooooooooo`00001;ooooo`00]Oooool00ol0003oooooooooo`1Ooooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0BOooool00;Gooooo00?o0000oooooooo
ool0Goooool01Ol0003ooooooooooooooooo000004cooooo002eooooo`03o`000?oooooooooo05oo
oooo00Go0000ooooooooooooooooo`00001<ooooo`00]Oooool00ol0003oooooooooo`1Oooooo`05
o`000?ooooooooooooooool00000C?ooool00;Gooooo00?o0000ooooooooool0G_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo04[ooooo002Looooo`03o`000?o^k^kooooo00Gooooo
0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`1Nooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0B_ooool009cooooo00?oEEEEojVYZOooool0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1Nooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0B_ooool009;ooooo1_l00004ooooo`03ojVYZOmE
EEGooooo013ooooo00?o0000ooooooooool00oooool3o`0005gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1:ooooo`00WOooool00olQ8B7oooooooooo`0>ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo04[ooooo002Mooooo`03oeEEEOo<c<cooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005
ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1;
ooooo`00WOooool00onYZJWoMgMgooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0GOooool01_l0003oooooooooool0003oooooo`0004gooooo002Jooooo`05oa0@4?oooooo
oooooooooolb<S803?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05gooooo00Ko
0000oooooooooooo0000ooooool0001=ooooo`00V_ooool5o`0000cooooo1?l00006ooooo`03o`00
0?oooooooooo05cooooo00?o0000ooooooooool00_l000000ooooooo0000ooooo`1<ooooo`00]Ooo
ool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo00;o000000?oooooo`000?ooool0C?oo
ool00;Gooooo00?o0000ooooooooool0G?ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo04_ooooo002eooooo`03o`000?oooooooooo05cooooo00Ko0000ooooool0003o0000oooo
ool0001>ooooo`00]Oooool2o`0005cooooo00?o0000ooooooooool00_l000000ooooooo0000oooo
o`1=ooooo`00]Oooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo00;o000000?ooooo
o`000?ooool0COooool00;Gooooo00?o0000ooooooooool0Foooool01ol0003oooooo`000?oooooo
0000ooooool00000C_ooool00;Gooooo00?o0000ooooooooool0F_ooool02?l0003oooooooooool0
003oooooo`000?oooooo0000C_ooool00;Gooooo00?o0000ooooooooool0F_ooool01Ol0003ooooo
ooooool0003ooooo00;o0000Coooool00;Gooooo00?o0000ooooooooool0F_ooool01ol0003ooooo
o`000?oooooo0000ooooool00000Coooool00;Gooooo00?o0000ooooooooool0FOooool02?l0003o
ooooooooool0003oooooo`000?oooooo0000Coooool00;Gooooo00?o0000ooooooooool0FOooool0
2?l0003oooooooooool0003oooooo`000?oooooo0000Coooool00;Gooooo0_l0001Jooooo`03o`00
0?oooooo000000;ooooo0_l0001@ooooo`00]Oooool00ol0003oooooooooo`1Iooooo`03o`000?oo
oooo000000;ooooo0_l0001@ooooo`00]Oooool00ol0003oooooooooo`1Hooooo`04o`000?oooooo
ooooo`0000;ooooo0_l0001@ooooo`00]Oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooo
000000;ooooo00?o0000ooooool00000D?ooool00;Gooooo00?o0000ooooooooool0F?ooool00ol0
003oooooo`000002ooooo`03o`000?oooooo0000053ooooo002eooooo`03o`000?oooooooooo05Oo
oooo00Co0000oooooooooooo00000_ooool2o`00057ooooo002eooooo`03o`000?oooooooooo05Oo
oooo00?o0000ooooool000000oooool2o`00057ooooo002eooooo`03o`000?oooooooooo05Oooooo
00?o0000ooooool000000oooool2o`00057ooooo002eooooo`03o`000?oooooooooo05Oooooo00?o
0000ooooool000000_ooool00ol0003oooooo`00001Aooooo`00]Oooool2o`0005Oooooo00?o0000
ooooool000000oooool2o`0005;ooooo002eooooo`03o`000?oooooooooo05Kooooo00?o0000oooo
ool000000oooool2o`0005;ooooo002eooooo`03o`000?oooooooooo05Kooooo00?o0000ooooool0
00000oooool2o`0005;ooooo002eooooo`03o`000?oooooooooo05Kooooo0_l00004ooooo`;o0000
D_ooool00;Gooooo00?o0000ooooooooool0EOooool00ol0003oooooo`000003ooooo`;o0000Dooo
ool00;Gooooo00?o0000ooooooooool0EOooool00ol0003oooooo`000003ooooo`;o0000Doooool0
0;Gooooo00?o0000ooooooooool0E?ooool00ol0003oooooo`000004ooooo`;o0000Doooool00;Go
oooo00?o0000ooooooooool0E?ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo05;o
oooo002eooooo`;o0000EOooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo05;ooooo
002eooooo`03o`000?oooooooooo05?ooooo00?o0000ooooool000001?ooool2o`0005Cooooo002e
ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooool000001?ooool2o`0005Cooooo002eoooo
o`03o`000?oooooooooo05?ooooo00?o0000ooooool000001?ooool00ol0003oooooooooo`1Coooo
o`00]Oooool00ol0003oooooooooo`1Booooo`03o`000?oooooo000000Gooooo00?o0000oooooooo
ool0Doooool00;Gooooo00?o0000ooooooooool0D_ooool00ol0003oooooo`000005ooooo`03o`00
0?oooooooooo05?ooooo002[ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`1Booooo`03o`000?oooooo000000Cooooo0_l0001Eooooo`00[_ooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo057ooooo00?o0000ooooool000001Oooool00ol0003ooooooooo
o`1Dooooo`00X_ooool6o`0000Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1A
ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool0E?ooool00:kooooo00?oMgMgoc8b
<_ooool01?ooool3o`00057ooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`1Doooo
o`00Zoooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0D?ooool00ol0
003oooooo`000006ooooo`03o`000?oooooooooo05Cooooo002[ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0D?ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo05Go
oooo002[ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0D?ooool00ol0003ooooo
o`000005ooooo`03o`000?oooooooooo05Gooooo002[ooooo`Co00001_ooool00ol0003ooooooooo
o`1?ooooo`03o`000?oooooo000000Kooooo00?o0000ooooooooool0EOooool00;Gooooo00?o0000
ooooooooool0Coooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo05Kooooo002eoooo
o`03o`000?oooooooooo04oooooo0_l00006ooooo`03o`000?oooooooooo05Kooooo002eooooo`03
o`000?oooooooooo04kooooo00?o0000ooooool000001_ooool00ol0003oooooooooo`1Fooooo`00
]Oooool2o`0004oooooo0_l00006ooooo`03o`000?oooooooooo05Oooooo002eooooo`03o`000?oo
oooooooo04gooooo00?o0000ooooool000001_ooool00ol0003oooooooooo`1Gooooo`00]Oooool0
0ol0003oooooooooo`1=ooooo`03o`000?oooooo000000Kooooo00?o0000ooooooooool0Eoooool0
0;Gooooo00?o0000ooooooooool0COooool2o`0000Kooooo0_l0001Iooooo`00]Oooool00ol0003o
ooooooooo`1<ooooo`03o`000?oooooo000000Kooooo00?o0000ooooooooool0F?ooool00;Gooooo
00?o0000ooooooooool0C?ooool2o`0000Oooooo00?o0000ooooooooool0F?ooool00;Gooooo00?o
0000ooooooooool0Boooool00ol0003oooooo`000006ooooo`;o0000F_ooool00;Gooooo00?o0000
ooooooooool0Boooool2o`0000Oooooo00?o0000ooooooooool0FOooool00;Gooooo00?o0000oooo
ooooool0B_ooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo05Wooooo002eooooo`;o
0000Boooool2o`0000Oooooo0_l0001Kooooo`00]Oooool00ol0003oooooooooo`1:ooooo`;o0000
1oooool00ol0003oooooooooo`1Jooooo`00]Oooool00ol0003oooooooooo`19ooooo`;o00002?oo
ool00ol0003oooooooooo`1Jooooo`00]Oooool00ol0003oooooooooo`19ooooo`;o00001oooool2
o`0005cooooo002eooooo`03o`000?oooooooooo04Sooooo0_l00008ooooo`03o`000?oooooooooo
05_ooooo002eooooo`03o`000?oooooooooo04Sooooo0_l00008ooooo`03o`000?oooooooooo05_o
oooo002eooooo`03o`000?oooooooooo04Sooooo0_l00007ooooo`03o`000?oooooooooo05cooooo
002eooooo`03o`000?oooooooooo04Oooooo0_l00008ooooo`03o`000?oooooooooo05cooooo002e
ooooo`;o0000B?ooool2o`0000Sooooo00?o0000ooooooooool0G?ooool00;Gooooo00?o0000oooo
ooooool0A_ooool2o`0000Sooooo00?o0000ooooooooool0GOooool00;Gooooo00?o0000oooooooo
ool0A_ooool2o`0000Sooooo00?o0000ooooooooool0GOooool00;Gooooo00?o0000ooooooooool0
AOooool2o`0000Sooooo0_l0001Oooooo`00]Oooool00ol0003oooooooooo`15ooooo`;o00002?oo
ool00ol0003oooooooooo`1Nooooo`00]Oooool00ol0003oooooooooo`14ooooo`;o00002Oooool0
0ol0003oooooooooo`1Nooooo`00]Oooool00ol0003oooooooooo`13ooooo`;o00002Oooool00ol0
003oooooooooo`1Oooooo`00]Oooool00ol0003oooooooooo`13ooooo`;o00002Oooool00ol0003o
ooooooooo`1Oooooo`00]Oooool00ol0003oooooooooo`12ooooo`;o00002Oooool00ol0003ooooo
ooooo`1Pooooo`00]Oooool2o`0004?ooooo0_l00009ooooo`03o`000?oooooooooo063ooooo002e
ooooo`03o`000?oooooooooo047ooooo0_l0000:ooooo`03o`000?oooooooooo063ooooo002eoooo
o`03o`000?oooooooooo047ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Qoooo
o`00]Oooool00ol0003oooooooooo`10ooooo`;o0000K_ooool00;Gooooo00?o0000ooooooooool0
?oooool2o`0006oooooo002eooooo`03o`000?oooooooooo03kooooo00?o0000ooooool00000Kooo
ool009[ooooo1Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool0?_ooool2o`00073ooooo002Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Ooo
ool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0mooooo`;o0000LOoo
ool009;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000ooooooooool00oooool3
o`0003cooooo00?o0000ooooool00000LOooool009cooooo00?oV9RHob4Q8Oo^k^h03oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo03cooooo0_l0001booooo`00WOooool00omgMgOo
IVIVooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooo000007;ooooo002Nooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0jooooo`03o`000?oooooo000007?ooooo002Jooooo`05o`00
0?nj^[[ooooooiRHV?l@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Wo
oooo00?o0000ooooool00000M?ooool009[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`Co
00001_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooo000007Cooooo002eooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooool00000MOooool00;Gooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooo`00001fooooo`00]Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
000007Oooooo002eooooo`;o0000=_ooool00ol0003oooooo`00001hooooo`00]Oooool00ol0003o
ooooooooo`0dooooo`03o`000?oooooo000007Wooooo002eooooo`03o`000?oooooooooo03?ooooo
00Co0000oooooooooooo0000NOooool00;Gooooo00?o0000ooooooooool0<_ooool01?l0003ooooo
ooooool0001jooooo`00]Oooool00ol0003oooooooooo`0`ooooo`;o00000_ooool00ol0003ooooo
ooooo`1iooooo`00]Oooool00ol0003oooooooooo`0_ooooo`05o`000?ooooooooooooooool00000
O?ooool00;Gooooo00?o0000ooooooooool0;_ooool01Ol0003ooooooooooooooooo000007gooooo
002eooooo`03o`000?oooooooooo02gooooo00Go0000ooooooooooooooooo`00001nooooo`00]Ooo
ool2o`0002gooooo00Go0000ooooooooooooooooo`00001oooooo`00]Oooool00ol0003ooooooooo
o`0[ooooo`05o`000?ooooooooooooooool00000P?ooool00;Gooooo00?o0000ooooooooool0:_oo
ool01Ol0003ooooooooooooooooo0000087ooooo002eooooo`03o`000?oooooooooo02Wooooo00Go
0000ooooooooooooooooo`000022ooooo`00]Oooool00ol0003oooooooooo`0Wooooo`;o00000ooo
ool00ol0003oooooooooo`21ooooo`00]Oooool00ol0003oooooooooo`0Uooooo`;o00001?ooool0
0ol0003oooooooooo`22ooooo`00]Oooool00ol0003oooooooooo`0Sooooo`;o00001Oooool00ol0
003oooooooooo`23ooooo`00]Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0Q?ooool00;Gooooo00?o0000ooooooooool08?ooool2o`0000Kooooo
00?o0000ooooooooool0QOooool00;Gooooo0_l0000Oooooo`;o00001_ooool2o`0008Sooooo002e
ooooo`03o`000?oooooooooo01_ooooo0ol00007ooooo`03o`000?oooooooooo08Sooooo002eoooo
o`03o`000?oooooooooo01Sooooo0ol00009ooooo`03o`000?oooooooooo08Wooooo002eooooo`03
o`000?oooooooooo01Gooooo0ol0000;ooooo`03o`000?oooooooooo08[ooooo0009ooooo`Co0000
00So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQ_ooooo00?o0000onk^k_ooool01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Nooooo`05odA4A?l0003o0000oc8b<_oMgMd0
7?ooool5o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd07?ooool00ol0003o
ooooooooo`0Booooo`?o00001oooool5o`000003ooooool0003ooooo00;ooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd07_ooool01Om4A4Co0000o`000?lb<S;ogMgM01kooooo00?o0000
onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Jooooo`Co000000So
410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo000;ooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`03oeEEEOnYZJWooooo00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo023ooooo00?oMgMgoc8b<_ooool06oooool01OnHV9So8B4Qonk^k_oooooo
A4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01_ooooo00?o0000ooooooooool03oooool3
o`0000[ooooo00KoV9RHob4Q8Oo^k^koooooodA4A?l00004ooooo`;o8B4Q0_l00006ooooo`03ogMg
Molb<S;ooooo023ooooo00?oMgMgoc8b<_ooool07Oooool00omEEEGoZJVYooooo`05ooooo`;o8B4Q
2?ooool00omgMgOo<S8booooo`0Kooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`001_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Aooooo`Ko00001?ooool00onYZJWoEEEEooooo`0@ooooo`03o`000?oooooooooo01?o
oooo1_l00007ooooo`03o`000?oooooooooo01;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^017o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0:ooooo`Go00003_ooool01?nHV9So
8B4Qonk^k_ooool7o`000003ooooool0003ooooo00Kooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0Looooo`03ojVYZOmEEEGooooo013ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool000_ooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000001cooooo00?o8B4Qooooooooool03_ooool0
0omgMgOo<S8booooo`0Pooooo`03ogMgMolb<S;ooooo01gooooo00?oV9RHob4Q8Oo^k^h03oooool0
0omgMgOo<S8booooo`0Kooooo`03o`000?oooooooooo00?ooooo1ol0000Dooooo`03oiRHV?lQ8B7o
k^k^00Oooooo00?o0000ooooooooool01Oooool00omgMgOo<S8booooo`0Pooooo`03ogMgMolb<S;o
oooo01kooooo00?o8B4Qooooooooool03_ooool00omgMgOo<S8booooo`0Kooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`002oooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000007?ooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`07_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01oooooo00?oMgMgofIVI_oo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01_ooooo1ol0000Looooo`03ogMgMomVIVKooooo
00Cooooo0_l00005ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`07_ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<01oooooo00?oEEEEolc<c?ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01cooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo000;ooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Looooo`03ojVYZOmgMgOooooo00_o
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool06?ooool5o`000003ooooool0003ooooo027ooooo00Co0000oooooooo
oooooooo0_l00007ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08Oooool00onY
ZJWoMgMgooooo`0;ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@00?ooooo000;ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Iooooo`05oa0@4?oooooooooooooooolb<S803?ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo01kooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`00
0?oooooooooo01?ooooo1Ol00006ooooo`03o`000?oooooooooo01cooooo00Ko0000okZj^_oooooo
V9RHoa0@4?ooool2o`0000Wooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Noooo
o`05oa0@4?oooooooooooooooolb<S803?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`002Oooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06Oooool5o`0000cooooo1?l0000Oooooo`Co00007Ooo
ool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l0000<ooooo`Ko00002oooool00ol0003ooooo
ooooo`0Looooo`04oiRHV?l@413o0000ob4Q8@;o00002oooool4o`0001oooooo1?l0000Mooooo`Go
00003?ooool4o`0001_ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo002Qooooo`?o00004Oooool00ol0003oooooooooo`0Mooooo`?o0000T?ooool009oooooo
0_l0000Dooooo`03o`000?oooooooooo01Wooooo1?l0002Cooooo`00WOooool2o`0001Kooooo00?o
0000ooooooooool05_ooool3o`0009Oooooo002Noooooa[o00002oooool;o`0009[ooooo002eoooo
o`03o`000?oooooooooo00_o0000YOooool000_oooooool0001Fo`0000Sooooo000;ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01_ooool000_ooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Kooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool009[ooooo1Ol00005ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009[o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo0;3ooooo002Kooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`2`ooooo`00W?ooool00onHV9So8B4Qonk^kP0?ooooo`03ogMg
Molb<S;ooooo00Cooooo0ol0002`ooooo`00WOooool00omgMgOoIVIVooooo`0;ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`ooooo`00W_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?oo
ool009[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`Co00001_ooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002a
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002[ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooooooo
o`2`ooooo`00[_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002_oooo
o`03o`000?oooooooooo00?ooooo0ol0002`ooooo`00[_ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo0;3ooooo002[ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003o
ooooooooo`2`ooooo`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo
002[ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool00:_ooooo1?l00006
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool009cooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@05ooooo`03o`000?oooooooooo0;3ooooo002Looooo`03oeEEEOnYZJWooooo00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009cooooo00?oZJVYoeEE
EOooool04?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002Mooooo`03
ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool3o`000;3ooooo002Mooooo`03oeEE
EOo<c<cooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3o
oooo002Mooooo`03ojVYZOmgMgOooooo00_ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo<S8b00cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`2`ooooo`00V_ooool5o`0000cooooo1?l00006ooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00:?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;o
k^k^1_ooool00ol0003oooooooooo`2`ooooo`00YOooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`2`ooooo`00YOooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool3o`000;3ooooo002Uooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00002iooooo`00YOooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool00000^Oooool00:Gooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@0;Wooooo002Uooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`2iooooo`00Xoooool00omEEEGoIVIVo`000004ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0^Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-10, -10, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.05 0.5 0.05 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-10)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-7.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-2.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(2.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(7.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(10)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-10)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-7.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-2.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(2.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(7.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(10)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.42936 .49633 m
.42245 .49986 L
.41787 .50277 L
.41548 .50482 L
.41516 .50588 L
.4168 .50598 L
.42029 .50527 L
.42553 .504 L
.4324 .50246 L
.44078 .50094 L
.45053 .49968 L
.46148 .49885 L
.47345 .4985 L
.48626 .49855 L
.49966 .49883 L
.51346 .49905 L
.52743 .49889 L
.54136 .49802 L
.55504 .49611 L
.56828 .49293 L
.58089 .48836 L
.59271 .48237 L
.60359 .47511 L
.61341 .46687 L
.62205 .45805 L
.62943 .44915 L
.63551 .44071 L
.64027 .43325 L
.64369 .42722 L
.64582 .42293 L
.64669 .42057 L
.6464 .42011 L
.64501 .4214 L
.64267 .42411 L
.63954 .42781 L
.63583 .43203 L
.63182 .43622 L
.62786 .43989 L
.6244 .44252 L
.62195 .44362 L
.62115 .44263 L
.62271 .43874 L
.62742 .43065 L
.63602 .41604 L
.64914 .39073 L
.66681 .34761 L
.68787 .27616 L
.70906 .16639 L
.72539 .02286 L
s
.72539 .02286 m
.72679 0 L
s
.7382 0 m
.73447 .06785 L
.72958 .1227 L
.72974 .12296 L
.73387 .08184 L
.73888 .01438 L
s
.73888 .01438 m
.73952 0 L
s
.72452 0 m
.72313 .01952 L
.72026 .05362 L
.71557 .09907 L
.70819 .15578 L
.6971 .22097 L
.68143 .28877 L
.66095 .35148 L
.63631 .40239 L
.60895 .43843 L
.58065 .46065 L
.55299 .47262 L
.52714 .4784 L
.50377 .48129 L
.48321 .48341 L
.46556 .48585 L
.45077 .48894 L
.43876 .49255 L
.42936 .49633 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00Xoooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^jiooooo`00YOooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0^Ooo
ool009[ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
402iooooo`00YOooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_oo
ool3o`0004Wooooo0_l00003ooooo`03o`000?oooooooooo05oooooo002Uooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo04Wooooo0_l0
0003ooooo`03o`000?oooooooooo05oooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo04Wooooo0_l00003ooooo`03o`000?oo
oooooooo05oooooo002Uooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`06ooooo`03o`000?oooooooooo04Wooooo0_l00003ooooo`03o`000?oooooooooo05oooooo002S
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
oooooooo04Wooooo0_l00003ooooo`03o`000?oooooooooo05oooooo002eooooo`03o`000?oooooo
oooo04Wooooo0_l00003ooooo`03o`000?oooooooooo05oooooo002eooooo`03o`000?oooooooooo
04Wooooo0_l00003ooooo`03o`000?oooooooooo05oooooo002eooooo`03o`000?oooooooooo04Wo
oooo0_l00003ooooo`03o`000?oooooooooo05oooooo002eooooo`;o0000B_ooool2o`0000?ooooo
00?o0000ooooooooool0Goooool00;Gooooo00?o0000ooooooooool0BOooool2o`0000?ooooo00?o
0000ooooooooool0Goooool00;Gooooo00?o0000ooooooooool0BOooool2o`0000?ooooo00?o0000
ooooooooool0Goooool00;Gooooo00?o0000ooooooooool0BOooool2o`0000?ooooo00?o0000oooo
ooooool0Goooool00;Gooooo00?o0000ooooooooool0BOooool2o`0000;ooooo00?o0000oooooooo
ool0H?ooool00;Gooooo00?o0000ooooooooool0B?ooool2o`0000?ooooo00?o0000ooooooooool0
H?ooool00;Gooooo00?o0000ooooooooool0B?ooool2o`0000?ooooo00?o0000ooooooooool0H?oo
ool00;Gooooo00?o0000ooooooooool0B?ooool2o`0000?ooooo00?o0000ooooooooool0H?ooool0
0;Gooooo00?o0000ooooooooool0B?ooool2o`0000?ooooo00?o0000ooooooooool0H?ooool00;Go
oooo0_l00019ooooo`;o00000oooool00ol0003oooooooooo`1Pooooo`00]Oooool00ol0003ooooo
ooooo`18ooooo`;o00000oooool00ol0003oooooooooo`1Pooooo`00]Oooool00ol0003ooooooooo
o`18ooooo`;o00000oooool00ol0003oooooooooo`1Pooooo`00]Oooool00ol0003oooooooooo`18
ooooo`;o00000oooool00ol0003oooooooooo`1Pooooo`00]Oooool00ol0003oooooooooo`18oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H?ooool00;Gooooo00?o0000oooooooo
ool0B?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo063ooooo002eooooo`03o`00
0?oooooooooo04Oooooo0_l00003ooooo`;o0000H_ooool00;Gooooo00?o0000ooooooooool0Aooo
ool2o`0000?ooooo0_l0001Rooooo`00]Oooool2o`0004Sooooo0_l00003ooooo`;o0000H_ooool0
0;Gooooo00?o0000ooooooooool0Aoooool2o`0000?ooooo0_l0001Rooooo`00]Oooool00ol0003o
ooooooooo`17ooooo`;o00000oooool2o`0006;ooooo002eooooo`03o`000?oooooooooo04Oooooo
0_l00003ooooo`;o0000H_ooool00;Gooooo00?o0000ooooooooool0Aoooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo067ooooo002eooooo`03o`000?oooooooooo04Oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Qooooo`00]Oooool00ol0003oooooooooo`16oooo
o`;o00001?ooool00ol0003oooooooooo`1Qooooo`00]Oooool00ol0003oooooooooo`16ooooo`;o
00001?ooool00ol0003oooooooooo`1Qooooo`00]Oooool00ol0003oooooooooo`16ooooo`;o0000
1?ooool00ol0003oooooooooo`1Qooooo`00]Oooool2o`0004Oooooo0_l00004ooooo`03o`000?oo
oooooooo067ooooo002eooooo`03o`000?oooooooooo04Kooooo0_l00004ooooo`03o`000?oooooo
oooo067ooooo002eooooo`03o`000?oooooooooo04Kooooo0_l00003ooooo`;o0000Hoooool00;Go
oooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`02ooooo`;o0000Hoooool00;Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06;ooooo
002eooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`1Rooooo`00W?ooool00ol0003ok^k^ooooo`05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0AOooool2o`0000Cooooo00?o0000ooooooooool0H_oo
ool009cooooo00?oEEEEojVYZOooool01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`15ooooo`;o00001?ooool00ol0003oooooooooo`1Rooooo`00T_ooool6o`00
00Cooooo00?oZJVYoeEEEOooool04?ooool00ol0003oooooooooo`03ooooo`?o0000AOooool2o`00
00Cooooo00?o0000ooooooooool0H_ooool009gooooo00?o8B4Qooooooooool03_ooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo04Gooooo0_l0001Yooooo`00WOooool00omEEEGoc<c<
ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`15ooooo`;o
0000JOooool009gooooo00?oZJVYogMgMoooool02oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo04Gooooo00?o0000ooooooooool0J?ooool009[ooooo00Go410@oooooooooooooooo
oc8b<P0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`1Xooooo`00V_ooool5o`0000cooooo1?l00006ooooo`03o`000?oooooooooo04Gooooo00?o
0000ooooooooool0J?ooool00;Gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`1X
ooooo`00]Oooool00ol0003oooooooooo`14ooooo`;o0000J_ooool00;Gooooo00?o0000oooooooo
ool0A?ooool2o`0006[ooooo002eooooo`;o0000AOooool2o`0006[ooooo002eooooo`03o`000?oo
oooooooo04Cooooo0_l0001Zooooo`00]Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooo
oooo06Wooooo002eooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0JOooool00;Go
oooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`1Yooooo`00]Oooool00ol0003ooooo
ooooo`14ooooo`03o`000?oooooooooo06Wooooo002eooooo`03o`000?oooooooooo04?ooooo0_l0
001[ooooo`00]Oooool00ol0003oooooooooo`13ooooo`;o0000Joooool00;Gooooo0_l00014oooo
o`;o0000Joooool00;Gooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`1Zooooo`00
]Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo06[ooooo002eooooo`03o`000?oo
oooooooo04;ooooo0_l0001/ooooo`00]Oooool00ol0003oooooooooo`12ooooo`;o0000K?ooool0
0;Gooooo00?o0000ooooooooool0@_ooool2o`0006cooooo002eooooo`03o`000?oooooooooo04;o
oooo00?o0000ooooooooool0Joooool00;Gooooo00?o0000ooooooooool0@_ooool00ol0003ooooo
ooooo`1[ooooo`00]Oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo06_ooooo002e
ooooo`;o0000@_ooool2o`0006gooooo002eooooo`03o`000?oooooooooo047ooooo0_l0001]oooo
o`00]Oooool00ol0003oooooooooo`11ooooo`;o0000KOooool00;Gooooo00?o0000ooooooooool0
@Oooool00ol0003oooooooooo`1/ooooo`00]Oooool00ol0003oooooooooo`11ooooo`03o`000?oo
oooooooo06cooooo002eooooo`03o`000?oooooooooo043ooooo0_l0001^ooooo`00]Oooool00ol0
003oooooooooo`10ooooo`;o0000K_ooool00;Gooooo00?o0000ooooooooool0@?ooool2o`0006ko
oooo002eooooo`;o0000@Oooool00ol0003oooooooooo`1]ooooo`00]Oooool00ol0003ooooooooo
o`10ooooo`03o`000?oooooooooo06gooooo002eooooo`03o`000?oooooooooo03oooooo0_l0001_
ooooo`00]Oooool00ol0003oooooooooo`0oooooo`;o0000Koooool00;Gooooo00?o0000oooooooo
ool0?oooool2o`0006oooooo002eooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0
K_ooool00:_ooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo03oooooo
00?o0000ooooooooool0K_ooool00:kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`0nooooo`;o0000L?ooool00:;ooooo1_l00007ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0?_ooool2o`00073ooooo002^ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000noooo
o`;o0000L?ooool00:_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo
03kooooo0_l0001`ooooo`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03go
oooo0_l0001aooooo`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03gooooo
0_l0001aooooo`00Zoooool4o`0000Kooooo00?o0000ooooooooool0?Oooool2o`00077ooooo002e
ooooo`03o`000?oooooooooo03gooooo0_l0001aooooo`00]Oooool00ol0003oooooooooo`0moooo
o`;o0000LOooool00;Gooooo00?o0000ooooooooool0??ooool2o`0007;ooooo002eooooo`;o0000
?Oooool2o`0007;ooooo002eooooo`03o`000?oooooooooo03cooooo0_l0001booooo`00]Oooool0
0ol0003oooooooooo`0looooo`;o0000L_ooool00;Gooooo00?o0000ooooooooool0??ooool2o`00
07;ooooo002eooooo`03o`000?oooooooooo03_ooooo0_l0001cooooo`00]Oooool00ol0003ooooo
ooooo`0kooooo`;o0000Loooool00;Gooooo00?o0000ooooooooool0>oooool2o`0007?ooooo002e
ooooo`03o`000?oooooooooo03[ooooo0_l0001dooooo`00]Oooool00ol0003oooooooooo`0joooo
o`;o0000M?ooool00;Gooooo0_l0000kooooo`;o0000M?ooool00;Gooooo00?o0000ooooooooool0
>Oooool00ol0003oooooo`00001dooooo`00]Oooool00ol0003oooooooooo`0iooooo`;o0000MOoo
ool00;Gooooo00?o0000ooooooooool0>Oooool2o`0007Gooooo002eooooo`03o`000?oooooooooo
03Sooooo00?o0000ooooool00000MOooool00;Gooooo00?o0000ooooooooool0>?ooool2o`0007Ko
oooo002eooooo`03o`000?oooooooooo03Sooooo0_l0001fooooo`00]Oooool00ol0003ooooooooo
o`0gooooo`03o`000?oooooo000007Kooooo002eooooo`;o0000>?ooool2o`0007Oooooo002eoooo
o`03o`000?oooooooooo03Oooooo0_l0001gooooo`00]Oooool00ol0003oooooooooo`0fooooo`03
o`000?oooooo000007Oooooo002eooooo`03o`000?oooooooooo03Kooooo00?o0000ooooool00000
Moooool00;Gooooo00?o0000ooooooooool0=_ooool2o`0007Sooooo002eooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooool00000N?ooool00;Gooooo00?o0000ooooooooool0=Oooool00ol0
003oooooo`00001hooooo`00]Oooool00ol0003oooooooooo`0eooooo`;o0000NOooool00;Gooooo
00?o0000ooooooooool0=?ooool00ol0003oooooo`00001iooooo`00]Oooool2o`0003Gooooo00?o
0000ooooool00000NOooool00;Gooooo00?o0000ooooooooool0=?ooool2o`0007[ooooo002eoooo
o`03o`000?oooooooooo03?ooooo00?o0000ooooool00000N_ooool00;Gooooo00?o0000oooooooo
ool0<oooool00ol0003oooooo`00001jooooo`00]Oooool00ol0003oooooooooo`0booooo`03o`00
0?oooooo000007_ooooo002eooooo`03o`000?oooooooooo03;ooooo00?o0000ooooool00000Nooo
ool009[ooooo1Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool0<Oooool00ol0003oooooo`00001looooo`00V_ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooo`00001looooo`00T_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h04Oooool0
0ol0003oooooooooo`03ooooo`?o0000<?ooool01?l0003oooooooooool0001looooo`00W?ooool0
0onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooo`00001mooooo`00WOooool00omgMgOoIVIVooooo`0;ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01Oooool00ol0003oooooooooo`0_ooooo`04o`000?ooooooooooo`0007gooooo002N
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooo000007kooooo002Jooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo02kooooo00Co0000oooooooooooo0000O_oo
ool009[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`Co00001_ooool00ol0003ooooooooo
o`0^ooooo`04o`000?ooooooooooo`0007kooooo002eooooo`03o`000?oooooooooo02gooooo00Co
0000oooooooooooo0000Ooooool00;Gooooo00?o0000ooooooooool0;Oooool01?l0003ooooooooo
ool0001oooooo`00]Oooool00ol0003oooooooooo`0/ooooo`04o`000?ooooooooooo`00083ooooo
002eooooo`;o0000;Oooool00ol0003oooooo`000021ooooo`00]Oooool00ol0003oooooooooo`0[
ooooo`04o`000?ooooooooooo`00087ooooo002eooooo`03o`000?oooooooooo02_ooooo00?o0000
ooooool00000P_ooool00;Gooooo00?o0000ooooooooool0:_ooool01?l0003oooooooooool00022
ooooo`00]Oooool00ol0003oooooooooo`0Yooooo`04o`000?ooooooooooo`0008?ooooo002eoooo
o`03o`000?oooooooooo02Sooooo00Co0000oooooooooooo0000Q?ooool00;Gooooo00?o0000oooo
ooooool0:?ooool01?l0003oooooooooool00024ooooo`00]Oooool00ol0003oooooooooo`0Woooo
o`04o`000?ooooooooooo`0000?ooooo0_l00020ooooo`00]Oooool2o`0002Oooooo00Co0000oooo
oooooooo00000oooool2o`00087ooooo002eooooo`03o`000?oooooooooo02Gooooo00Go0000oooo
ooooooooooooo`000002ooooo`03o`000?oooooo0000087ooooo002eooooo`03o`000?oooooooooo
02Gooooo00Co0000oooooooooooo00000oooool00ol0003oooooo`000021ooooo`00]Oooool00ol0
003oooooooooo`0Tooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooo`000022
ooooo`00]Oooool00ol0003oooooooooo`0Sooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool00022ooooo`00]Oooool00ol0003oooooooooo`0Qooooo`;o00001?ooool0
0ol0003oooooo`000002ooooo`03o`000?oooooooooo087ooooo002eooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool00oooool3o`0000;ooooo00?o0000ooooooooool0P_ooool00;Go
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0P_ooool00;Gooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo08?ooooo002eooooo`;o00007Oooool2o`0000_ooooo00?o
0000ooooooooool0Q?ooool00;Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo08Gooooo002eooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`26ooooo`00]Oooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool0Qoooool000Wooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^6oooool00ol0003ok^k^ooooo`05ooooo`;o8B4Q1Oooool0
1Om4A4Co0000o`000?lb<S;ogMgM01kooooo00GoA4A4o`000?l0003o<S8bomgMg@0Looooo`Go0000
1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Looooo`03o`000?oooooooooo01Oo
oooo0_l00003ooooo`Go00001?ooool00ol0003o8B4Qob4Q8@05ooooo`05odA4A?l0003o0000oc8b
<_oMgMd07_ooool01Om4A4Co0000o`000?lb<S;ogMgM01kooooo00?o0000onk^k_ooool01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Jooooo`Co000000So410@ooooooooooook^k^
oc8b<_l0003o<S8bonk^kP?ooooo000;ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0Kooooo`03oeEEEOnYZJWooooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
023ooooo00?oMgMgoc8b<_ooool06oooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo01_ooooo00?o0000ooooooooool05Oooool2o`0000Gooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`04o`000?oooooo8B4Qob4Q8@Sooooo00?oMgMgoc8b<_ooool0
8?ooool00omgMgOo<S8booooo`0Mooooo`03oeEEEOnYZJWooooo00Gooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo01_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo0006o`0000Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@017o
oooo1_l00004ooooo`03ojVYZOmEEEGooooo013ooooo00?o0000ooooooooool04oooool6o`0000Oo
oooo00?o0000ooooooooool04_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo01;ooooo0ol00008ooooo`03oiRHV?lQ8B7ok^k^00?o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01co
oooo00?oZJVYoeEEEOooool04?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@4003ooooo`002oooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000007?ooool00olQ8B7oooooooooo`0>ooooo`03ogMgMolb<S;ooooo
023ooooo00?oMgMgoc8b<_ooool07Oooool00onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;ooooo
01_ooooo00?o0000ooooooooool04?ooool2o`0000cooooo00GoV9RHob4Q8Oo^k^koooooo`00000=
ooooo`03ogMgMolb<S;ooooo023ooooo00?oMgMgoc8b<_ooool07_ooool00olQ8B7oooooooooo`0>
ooooo`03ogMgMolb<S;ooooo01_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000?ooooo000;ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
000Looooo`03oeEEEOo<c<cooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Nooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`07oooool00omgMgOoIVIVooooo`0;ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`07?ooool2o`0000kooooo0ol0000?ooooo`03ogMgMomVIVKo000000_ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c00Nooooo`05o`000?lQ8B7o0000oc8b<_o<c<`07oooool00omEEEGoc<c<oooo
o`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`07?ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000000oooool000_ooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@01cooooo00?oZJVYogMgMoooool02oooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo00Sooooo1Ol0000Booooo`;o00003?ooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo027ooooo00?oZJVYogMgMoooool02oooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`002oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06Oooool01Ol@413ooooooooooooooooo
<S8b00cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Nooooo`05o`000?nj^[[o
oooooiRHV?l@41003?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00;ooooo1_l0
000Dooooo`?o000000?oV9RHoa0@4?ooool02oooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo01kooooo00Go410@oooooooooooooooooc8b<P0<ooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0009ooooo`03oeEE
EOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Iooooo`Go00003?ooool4o`0001oo
oooo1?l0000Mooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool4o`0001Cooooo3_l0000Ioooo
o`;o000000Co410@o`000?lQ8B7oc<c<3?ooool4o`0001oooooo1?l0000Mooooo`Go00003?ooool4
o`0001_ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo002W
ooooo`Go00002Oooool00ol0003oooooooooo`0Iooooo`;o0000UOooool00:;ooooo1Ol0000>oooo
o`03o`000?oooooooooo01Oooooo0_l0002Gooooo`00Woooool3o`0001?ooooo00?o0000oooooooo
ool05Oooool2o`0009Wooooo002Nooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
4_ooool3o`0009_ooooo002Looooo`;o00003?ooool5o`0000Kooooo00?o0000ooooooooool02Ooo
ool9o`0009kooooo000;oooooooo0000E_l00008ooooo`002oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooool000001?l00004ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01_ooool000_ooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool02oooool3o`0001[o
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`06ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aoooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Jooooo`Go00001Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00Voooool00onHV9So8B4Qonk^kP0Aooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0/?ooool009cooooo00?oV9RHob4Q8Oo^k^h03oooool00omg
MgOo<S8booooo`04ooooo`?o0000/?ooool009gooooo00?oMgMgofIVI_ooool02oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool009kooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05o`00
0?nj^[[ooooooiRHV?l@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3o
oooo002Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool4o`0000Kooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000
/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00Zoooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooooooo
ool0/?ooool00:kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00[ooo
ool00ol0003oooooooooo`03ooooo`?o0000/?ooool00:kooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`2`ooooo`00Zoooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000
ooooooooool0/?ooool00:_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`oooo
o`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`Co0000
1_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002Looooo`03o`000?o^k^kooooo00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01Oooool00ol0003oooooooooo`2`ooooo`00W?ooool00omEEEGoZJVYooooo`05ooooo`;o8B4Q
2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Looooo`03ojVYZOmE
EEGooooo013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2`ooooo`00WOooool0
0olQ8B7oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00WOooool00omE
EEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`
ooooo`00WOooool00onYZJWoMgMgooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0/?ooool009[ooooo00Go410@oooooooooooooooooc8b<P0<ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0/?ooool009[ooooo1Ol0000<ooooo`Co00001_ooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002Sooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kPKooooo00?o0000ooooooooool0/?ooool00:Gooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0/?ooool00:Gooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo0ol0002`ooooo`00YOooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000^Oooool00:Gooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo00000;Wooooo002Uooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@402iooooo`00YOooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL0^Oooool00:?ooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^0;Wooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-10, -10, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.05 0.5 0.05 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-10)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-7.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-2.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(2.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(7.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(10)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-10)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-7.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-2.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(2.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(7.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(10)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.41479 .51617 m
.4075 .52362 L
.40281 .52943 L
.40048 .53298 L
.40033 .53403 L
.40222 .53267 L
.40608 .52929 L
.41186 .52447 L
.41954 .51896 L
.42908 .51352 L
.44039 .50884 L
.45335 .50543 L
.46775 .50347 L
.48333 .50281 L
.49975 .50293 L
.51664 .503 L
.5336 .50208 L
.55024 .4992 L
.56619 .49358 L
.58113 .48476 L
.59482 .47263 L
.60707 .45748 L
.61777 .43999 L
.62688 .42105 L
.63443 .40175 L
.64049 .38319 L
.64518 .3664 L
.64862 .35225 L
.65095 .3414 L
.65228 .33423 L
.65272 .33089 L
.65234 .33128 L
.65119 .33507 L
.64935 .3417 L
.64687 .35044 L
.64388 .36042 L
.64053 .37066 L
.6371 .38014 L
.63396 .38779 L
.63158 .39254 L
.63054 .39317 L
.63146 .38812 L
.63488 .37502 L
.64107 .35014 L
.6496 .30784 L
.65883 .24095 L
.66529 .14424 L
.66414 .02242 L
s
.66414 .02242 m
.66203 0 L
s
.66006 0 m
.66151 .01984 L
.66356 .08784 L
.66174 .16946 L
.65393 .25771 L
.63879 .34107 L
.61657 .40795 L
.5891 .45234 L
.55908 .47594 L
.52913 .48552 L
.50123 .48857 L
.47657 .49058 L
.45566 .4943 L
.43855 .50033 L
.42503 .50801 L
.41479 .51617 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00Xoooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^jiooooo`00YOooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0^Ooo
ool009[ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
402iooooo`00YOooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_oo
ool3o`0003?ooooo0_l0001kooooo`00YOooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`0cooooo`;o0000Noooool00:Gooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0<ooo
ool2o`0007_ooooo002Uooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`06ooooo`03o`000?oooooooooo03?ooooo0_l0001kooooo`00Xoooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo07Wooooo002eooooo`03o`000?oooooooooo03Cooooo0_l0001jooooo`00]Oooool00ol0
003oooooooooo`0dooooo`;o0000N_ooool00;Gooooo00?o0000ooooooooool0=?ooool2o`0007[o
oooo002eooooo`;o0000=Oooool2o`0007[ooooo002eooooo`03o`000?oooooooooo03Cooooo0_l0
001jooooo`00]Oooool00ol0003oooooooooo`0dooooo`;o0000N_ooool00;Gooooo00?o0000oooo
ooooool0=?ooool2o`0007[ooooo002eooooo`03o`000?oooooooooo03Cooooo0_l0001jooooo`00
]Oooool00ol0003oooooooooo`0dooooo`;o0000N_ooool00;Gooooo00?o0000ooooooooool0=?oo
ool2o`0007[ooooo002eooooo`03o`000?oooooooooo03Cooooo0_l0001jooooo`00]Oooool00ol0
003oooooooooo`0dooooo`;o0000N_ooool00;Gooooo0_l0000eooooo`;o0000N_ooool00;Gooooo
00?o0000ooooooooool0=?ooool2o`0007[ooooo002eooooo`03o`000?oooooooooo03Gooooo00?o
0000ooooooooool0N?ooool00;Gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1h
ooooo`00]Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo07Sooooo002eooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool0N?ooool00;Gooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`1hooooo`00]Oooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo07Sooooo002eooooo`;o0000=_ooool00ol0003oooooooooo`1hooooo`00]Oooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo07Sooooo002eooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool0N?ooool00;Gooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`1hooooo`00]Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo07Sooooo002e
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0N?ooool00;Gooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`1hooooo`00]Oooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo07Sooooo002eooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
N?ooool00;Gooooo0_l0000fooooo`03o`000?oooooooooo07Sooooo002eooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool0N?ooool00;Gooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`1hooooo`00]Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo07So
oooo002eooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0N?ooool00;Gooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`1hooooo`00W?ooool00ol0003ok^k^ooooo`05
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`1hooooo`00W?ooool00omEEEGoZJVYooooo`05ooooo`;o8B4Q2?ooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0N?ooool0
09;ooooo1_l00004ooooo`03ojVYZOmEEEGooooo013ooooo00?o0000ooooooooool00oooool3o`00
03Gooooo00?o0000ooooooooool0N?ooool009gooooo00?o8B4Qooooooooool03_ooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0N?ooool009gooooo
00?oEEEEolc<c?ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`1hooooo`00WOooool00onYZJWoMgMgooooo`0;ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0=?ooool2o`0007[ooooo002Jooooo`05oa0@4?oo
oooooooooooooolb<S803?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Cooooo
0_l0001jooooo`00V_ooool5o`0000cooooo1?l00006ooooo`03o`000?oooooooooo03Cooooo0_l0
001jooooo`00]Oooool00ol0003oooooooooo`0dooooo`;o0000N_ooool00;Gooooo00?o0000oooo
ooooool0=?ooool2o`0007[ooooo002eooooo`03o`000?oooooooooo03Cooooo0_l0001jooooo`00
]Oooool2o`0003Gooooo0_l0001jooooo`00]Oooool00ol0003oooooooooo`0dooooo`;o0000N_oo
ool00;Gooooo00?o0000ooooooooool0=?ooool2o`0007[ooooo002eooooo`03o`000?oooooooooo
03Cooooo0_l0001jooooo`00]Oooool00ol0003oooooooooo`0dooooo`;o0000N_ooool00;Gooooo
00?o0000ooooooooool0=?ooool2o`0007[ooooo002eooooo`03o`000?oooooooooo03Cooooo0_l0
001jooooo`00]Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo07Wooooo002eoooo
o`;o0000=Oooool00ol0003oooooooooo`1iooooo`00]Oooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo07Wooooo002eooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0
NOooool00;Gooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`1iooooo`00]Oooool0
0ol0003oooooooooo`0dooooo`03o`000?oooooooooo07Wooooo002eooooo`03o`000?oooooooooo
03?ooooo0_l0001kooooo`00]Oooool00ol0003oooooooooo`0cooooo`;o0000Noooool00;Gooooo
00?o0000ooooooooool0<oooool2o`0007_ooooo002eooooo`03o`000?oooooooooo03?ooooo0_l0
001kooooo`00]Oooool2o`0003Cooooo0_l0001kooooo`00]Oooool00ol0003oooooooooo`0coooo
o`;o0000Noooool00;Gooooo00?o0000ooooooooool0<oooool2o`0007_ooooo002eooooo`03o`00
0?oooooooooo03?ooooo0_l0001kooooo`00]Oooool00ol0003oooooooooo`0cooooo`;o0000Nooo
ool00;Gooooo00?o0000ooooooooool0<oooool2o`0007_ooooo002eooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooool00000Noooool00;Gooooo00?o0000ooooooooool0<_ooool2o`0007co
oooo002eooooo`;o0000<oooool2o`0007cooooo002eooooo`03o`000?oooooooooo03;ooooo0_l0
001looooo`00]Oooool00ol0003oooooooooo`0booooo`;o0000O?ooool00;Gooooo00?o0000oooo
ooooool0<_ooool2o`0007cooooo002eooooo`03o`000?oooooooooo03;ooooo0_l0001looooo`00
]Oooool00ol0003oooooooooo`0booooo`;o0000O?ooool00:_ooooo00GoA4A4o`000?l0003o<S8b
omgMg@05ooooo`03o`000?oooooooooo03;ooooo0_l0001looooo`00[_ooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo03;ooooo0_l0001looooo`00X_ooool6o`0000Oooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0aooooo`03o`000?oooooo000007cooooo002^oooo
o`03ogMgMolb<S;ooooo00Cooooo0ol0000aooooo`03o`000?oooooo000007cooooo002[ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooo0000
07cooooo002[ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<Oooool2o`0007go
oooo002[ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<Oooool2o`0007gooooo
002[ooooo`Co00001_ooool00ol0003oooooooooo`0aooooo`;o0000OOooool00;Gooooo00?o0000
ooooooooool0<Oooool2o`0007gooooo002eooooo`03o`000?oooooooooo037ooooo0_l0001moooo
o`00]Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo000007gooooo002eooooo`;o0000
<Oooool00ol0003oooooo`00001mooooo`00]Oooool00ol0003oooooooooo`0`ooooo`;o0000O_oo
ool00;Gooooo00?o0000ooooooooool0<?ooool2o`0007kooooo002eooooo`03o`000?oooooooooo
033ooooo0_l0001nooooo`00]Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo000007ko
oooo002eooooo`03o`000?oooooooooo02oooooo00?o0000ooooool00000O_ooool00;Gooooo00?o
0000ooooooooool0;oooool00ol0003oooooo`00001nooooo`00]Oooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooo000007kooooo002eooooo`03o`000?oooooooooo02oooooo00?o0000oooo
ool00000O_ooool00;Gooooo0_l0000`ooooo`;o0000Ooooool00;Gooooo00?o0000ooooooooool0
;_ooool00ol0003oooooo`00001oooooo`00]Oooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooo000007oooooo002eooooo`03o`000?oooooooooo02kooooo00?o0000ooooool00000Ooooool0
0;Gooooo00?o0000ooooooooool0;_ooool00ol0003oooooo`00001oooooo`00]Oooool00ol0003o
ooooooooo`0^ooooo`03o`000?oooooo000007oooooo002eooooo`03o`000?oooooooooo02kooooo
0_l00020ooooo`00]Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo0000083ooooo002e
ooooo`;o0000;_ooool00ol0003oooooo`000020ooooo`00]Oooool00ol0003oooooooooo`0]oooo
o`03o`000?oooooo0000083ooooo002eooooo`03o`000?oooooooooo02gooooo00Go0000ooooool0
003oooooo`00001nooooo`00]Oooool00ol0003oooooooooo`0]ooooo`;o00000_ooool00ol0003o
ooooooooo`1looooo`00]Oooool00ol0003oooooooooo`0/ooooo`04o`000?oooooo0000ooooo`;o
0000O_ooool00;Gooooo00?o0000ooooooooool0;?ooool01?l0003oooooo`000?ooool2o`0007ko
oooo002eooooo`03o`000?oooooooooo02cooooo00Go0000ooooool0003oooooo`00001oooooo`00
]Oooool00ol0003oooooooooo`0/ooooo`05o`000?oooooo0000ooooool00000Ooooool00;Gooooo
00?o0000ooooooooool0;?ooool2o`000003ooooool0003o000007oooooo002eooooo`;o0000;?oo
ool01Ol0003oooooo`000?oooooo0000083ooooo002eooooo`03o`000?oooooooooo02_ooooo00Go
0000ooooool0003oooooo`000020ooooo`00]Oooool00ol0003oooooooooo`0[ooooo`05o`000?oo
oooo0000ooooool00000P?ooool00;Gooooo00?o0000ooooooooool0:_ooool01?l0003oooooo`00
0?ooool2o`00083ooooo002eooooo`03o`000?oooooooooo02[ooooo00Go0000ooooool0003ooooo
o`000021ooooo`00]Oooool00ol0003oooooooooo`0Zooooo`05o`000?oooooo0000ooooool00000
POooool009[ooooo1Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`03o`00087ooooo002Jooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`0Yooooo`04o`000?oooooo0000ooooo`;o0000POooool009;ooooo1_l00003ooooo`03oiRH
V?lQ8B7ok^k^017ooooo00?o0000ooooooooool00oooool3o`0002Wooooo00Co0000ooooool0003o
oooo0_l00021ooooo`00W?ooool00onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`03o`0008;ooooo002Mooooo`03ogMgMomV
IVKooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool00ol00022ooooo`00W_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0:?ooool01?l0003oooooo`000?ooool2o`0008;ooooo
002Jooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo02Sooooo00Ko0000ooooool0003o0000ooooool00022ooooo`00V_ooool01OnHV9So
410@o`000?lQ8B7oc<c<00cooooo1?l00006ooooo`03o`000?oooooooooo02Oooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`20ooooo`00]Oooool00ol0003oooooooooo`0Woooo
o`06o`000?ooooooooooo`000?oooooo0000Poooool00;Gooooo00?o0000ooooooooool09oooool0
0ol0003oooooo`000002ooooo`03o`000?oooooooooo087ooooo002eooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`21ooooo`00]Oooool2o`0002Oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`22ooooo`00]Oooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0P_ooool00;Gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08;ooooo002e
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`23
ooooo`00]Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0Poooool00;Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo08Cooooo002eooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`24ooooo`00]Oooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0QOooool00;Gooooo0_l0000Sooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0QOooool00;Gooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo08Kooooo002eooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`26ooooo`00]Oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Qoooool00;Gooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08Oooooo002e
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`27
ooooo`00]Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0R?ooool00;Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo08Sooooo002eooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`29ooooo`00]Oooool2o`0001gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`2:ooooo`00]Oooool00ol0003oooooooooo`0Jooooo`;o00001oooool0
0ol0003oooooooooo`2:ooooo`00]Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0Roooool00;Gooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo08cooooo0009ooooo`Co000000So410@oooooooooooo
k^k^oc8b<_l0003o<S8bonk^kQ_ooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@0Nooooo`05odA4A?l0003o0000oc8b<_oMgMd07?ooool5o`0000Gooooo
0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd07?ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo00;ooooo1_l00004ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM
01kooooo00GoA4A4o`000?l0003o<S8bomgMg@0Nooooo`03o`000?o^k^kooooo00Gooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd06_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o
0000oc8b<_o^k^h3ooooo`002oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL06oooool00omEEEGoZJVYooooo`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Poooo
o`03ogMgMolb<S;ooooo01_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q2?ooool0
0omgMgOo<S8booooo`0Kooooo`03o`000?oooooooooo01Gooooo0_l00005ooooo`05oiRHV?lQ8B7o
k^k^ooooool000001Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool08?ooool00omgMgOo<S8boooo
o`0Mooooo`03oeEEEOnYZJWooooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01_ooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0006o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@017ooooo1_l00004ooooo`03ojVY
ZOmEEEGooooo013ooooo00?o0000ooooooooool04oooool6o`0000Oooooo00?o0000ooooooooool0
4_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool01_ooool00onHV9So8B4Qo`00000Aooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool07?ooool00onYZJWoEEEEooooo`0@ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo000;ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Looooo`03
ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool08?ooool00omgMgOo<S8booooo`0Mooooo`03
oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool06oooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo00Sooooo00?o0000ob4Q8Oo^k^h03oooool00omgMgOo<S8booooo`0Pooooo`03
ogMgMolb<S;ooooo01kooooo00?o8B4Qooooooooool03_ooool00omgMgOo<S8booooo`0Kooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`002oooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000007?ooool00omEEEGoc<c<ooooo`0;oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`07_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01oooooo00?o
MgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01cooooo0_l0000Cooooo`03o`00
0?oooooooooo00Oooooo0_l000000oooooooMgMgofIVIP0<ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`07_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01oooooo00?oEEEEolc<c?ooool02oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<01cooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000?ooooo000;ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
400Looooo`03ojVYZOmgMgOooooo00_ooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0?ooooo`?o00002Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`0Qooooo`03ojVYZOmgMgOooooo00_ooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
0oooool000_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Wooooo
00Go410@oooooooooooooooooc8b<P0<ooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool07_ooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`0<ooooo`?o00002oooool01ol0003oooooo`000?nj^[[ooooooiRHV?l@41003?oo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01kooooo00Go410@oooooooooooooooo
oc8b<P0<ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo0009ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0Iooooo`Go00003?ooool4o`0001oooooo1?l0000Mooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`03?ooool4o`0001gooooo00?o0000ooooooooool02Oooool3o`0000gooooo00So0000oooo
ooooooooV9RHoa0@4?l0003o8B4Qolc<c0cooooo1?l0000Oooooo`Co00007Oooool5o`0000cooooo
1?l0000Kooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00
]Oooool00ol0003oooooooooo`02ooooo`Oo00003_ooool2o`0009Oooooo002aooooo`Wo00004ooo
ool2o`0009Wooooo002Zooooo`Oo00001?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo09Wooooo002Uooooo`Go00002oooool00ol0003oooooooooo`0Booooo`;o0000W?ooool00:;o
oooo0ol0000@ooooo`03o`000?oooooooooo00oooooo0ol0002Nooooo`002oooooooo`0005Ko0000
2?ooool000_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`04o`000?oo
oooo0000o`0000Gooooo00Co0000oooooooooooooooo6ol00003ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo000;ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool5o`0000gooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`06ooooo`00V_ooool2o`0000Cooooo0ol0
000Booooo`03o`000?oooooooooo0;3ooooo002Iooooo`03o`000?oooooooooo00;ooooo0_l0000E
ooooo`03o`000?oooooooooo0;3ooooo002Hooooo`04o`000?ooooooooooooooo`;o00005oooool0
0ol0003oooooooooo`2`ooooo`00Uoooool00ol0003oooooo`000002o`0001Wooooo00?o0000oooo
ooooool0/?ooool009Kooooo00?o0000ooooool000007?ooool00ol0003oooooooooo`2`ooooo`00
UOooool00ol0003oooooo`00000Mooooo`03o`000?oooooooooo0;3ooooo002Eooooo`;o00007_oo
ool2o`000;7ooooo002Dooooo`;o00007oooool00ol0003oooooooooo`2`ooooo`00Toooool2o`00
023ooooo00?o0000ooooooooool0/?ooool009?ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00V_ooool5
o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooooooo
o`2`ooooo`00V_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009_ooooo00?oV9RHob4Q8Oo^k^h04Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002Looooo`03oiRHV?lQ8B7ok^k^
00oooooo00?oMgMgoc8b<_ooool01?ooool3o`000;3ooooo002Mooooo`03ogMgMomVIVKooooo00_o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo002Nooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00
V_ooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2`ooooo`00V_ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l00006ooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00:_ooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0;3ooooo002^ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
/?ooool00:oooooo00?o0000ooooooooool00oooool3o`000;3ooooo002^ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0/?ooool00:_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00
Zoooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00W?ooool00ol0003ok^k^ooooo`05ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009cooooo00?oEEEEojVYZOooool0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00W?oo
ool00onYZJWoEEEEooooo`0@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?oo
ool009gooooo00?o8B4Qooooooooool03_ooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool0
09gooooo00?oEEEEolc<c?ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000
ooooooooool0/?ooool009gooooo00?oZJVYogMgMoooool02oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?oooooooooooooooolb<S803?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`Go00003?ooool4o`0000Ko
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aoooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00Xoooool4o`000008oa0@4?ooooooooooonk^k_lb
<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0;3ooooo002Uoooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`?o0000/?ooool0
0:Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo00000;Wooooo002Uoooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00002iooooo`00YOooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100^Oooool00:Gooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg0;Wooooo002Sooooo`03oeEEEOmVIVKo0000
00Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP2iooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-10, -10, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.05 0.5 0.05 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-10)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-7.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-2.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(2.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(7.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(10)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-10)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-7.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-2.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(2.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(7.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(10)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.40307 .55286 m
.39651 .56736 L
.39256 .57798 L
.39075 .58387 L
.39079 .58481 L
.39255 .58102 L
.39606 .57316 L
.40144 .5622 L
.40889 .54945 L
.41859 .53643 L
.4307 .52476 L
.44524 .51577 L
.46207 .51025 L
.4808 .50803 L
.50085 .50786 L
.52147 .50761 L
.54181 .50476 L
.56105 .49708 L
.57851 .4832 L
.59371 .46294 L
.60639 .43721 L
.61652 .4077 L
.62423 .37645 L
.6298 .34547 L
.63359 .31645 L
.63596 .29068 L
.63729 .26901 L
.6379 .2519 L
.63806 .23956 L
.63798 .23196 L
.63777 .22894 L
.63749 .23023 L
.63714 .23548 L
.63665 .24418 L
.63595 .25569 L
.63498 .26918 L
.63371 .28357 L
.63218 .29755 L
.63056 .30958 L
.62913 .31796 L
.62823 .32073 L
.6282 .31565 L
.6291 .29999 L
.63045 .27061 L
.63072 .22481 L
.62701 .16275 L
.61527 .0906 L
.59178 .01942 L
s
.59178 .01942 m
.58095 0 L
s
.57711 0 m
.58881 .02335 L
.60334 .06137 L
.61664 .11438 L
.62557 .18523 L
.6266 .27096 L
.617 .35898 L
.59626 .43098 L
.56681 .47471 L
.53311 .49228 L
.49978 .49611 L
.47014 .49862 L
.44577 .50623 L
.42688 .51952 L
.41292 .53608 L
.40307 .55286 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00Xoooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^jiooooo`00YOooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0^Ooo
ool009[ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
402iooooo`00YOooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_oo
ool3o`0001Oooooo0_l0002Gooooo`00YOooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`0Gooooo`;o0000Uoooool00:Gooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool06?oo
ool2o`0009Kooooo002Uooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`06ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooool00000UOooool00:?ooooo00?oEEEE
ofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool06Ooo
ool2o`0009Gooooo002eooooo`03o`000?oooooooooo01Wooooo00?o0000ooooool00000U?ooool0
0;Gooooo00?o0000ooooooooool06_ooool00ol0003oooooo`00002Cooooo`00]Oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooo000009?ooooo002eooooo`;o00007?ooool2o`0009?ooooo
002eooooo`03o`000?oooooooooo01_ooooo00?o0000ooooool00000T_ooool00;Gooooo00?o0000
ooooooooool07?ooool2o`0009;ooooo002eooooo`03o`000?oooooooooo01cooooo0_l0002Boooo
o`00]Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo0000097ooooo002eooooo`03o`00
0?oooooooooo01gooooo0_l0002Aooooo`00]Oooool00ol0003oooooooooo`0Mooooo`;o0000TOoo
ool00;Gooooo00?o0000ooooooooool07_ooool2o`00093ooooo002eooooo`03o`000?oooooooooo
01kooooo0_l0002@ooooo`00]Oooool2o`0001oooooo0_l0002@ooooo`00]Oooool00ol0003ooooo
ooooo`0Oooooo`;o0000Soooool00;Gooooo00?o0000ooooooooool07oooool2o`0008oooooo002e
ooooo`03o`000?oooooooooo01oooooo0_l0002?ooooo`00]Oooool00ol0003oooooooooo`0Poooo
o`;o0000S_ooool00;Gooooo00?o0000ooooooooool08?ooool2o`0008kooooo002eooooo`03o`00
0?oooooooooo023ooooo0_l0002>ooooo`00]Oooool00ol0003oooooooooo`0Qooooo`;o0000SOoo
ool00;Gooooo0_l0000Rooooo`;o0000SOooool00;Gooooo00?o0000ooooooooool08Oooool2o`00
08gooooo002eooooo`03o`000?oooooooooo02;ooooo0_l0002<ooooo`00]Oooool00ol0003ooooo
ooooo`0Rooooo`;o0000S?ooool00;Gooooo00?o0000ooooooooool08_ooool2o`0008cooooo002e
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooool00000Roooool00;Gooooo00?o0000oooo
ooooool08oooool2o`0008_ooooo002eooooo`03o`000?oooooooooo02?ooooo0_l0002;ooooo`00
]Oooool00ol0003oooooooooo`0Sooooo`;o0000Roooool00;Gooooo0_l0000Tooooo`;o0000Rooo
ool00;Gooooo00?o0000ooooooooool09?ooool2o`0008[ooooo002eooooo`03o`000?oooooooooo
02Cooooo0_l0002:ooooo`00]Oooool00ol0003oooooooooo`0Tooooo`;o0000R_ooool00;Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`28ooooo`00]Oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo08Sooooo002Looooo`03o`000?o^k^kooooo00Gooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo08Sooooo002Looooo`03oeEEEOnYZJWooooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool09Oooool2o`0008Wooooo002Booooo`Ko00001?ooool00onY
ZJWoEEEEooooo`0@ooooo`03o`000?oooooooooo00?ooooo0ol0000Uooooo`;o0000ROooool009go
oooo00?o8B4Qooooooooool03_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02Go
oooo0_l00029ooooo`00WOooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo08Oooooo002Mooooo`03ojVY
ZOmgMgOooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo08Oooooo002Jooooo`05oa0@4?oooooooooooooooolb<S803?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0Qoooool009[ooooo1Ol0
000<ooooo`Co00001_ooool00ol0003oooooooooo`0Vooooo`;o0000R?ooool00;Gooooo00?o0000
ooooooooool09_ooool2o`0008Sooooo002eooooo`03o`000?oooooooooo02Kooooo0_l00028oooo
o`00]Oooool00ol0003oooooooooo`0Vooooo`;o0000R?ooool00;Gooooo0_l0000Wooooo`;o0000
R?ooool00;Gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`26ooooo`00]Oooool0
0ol0003oooooooooo`0Wooooo`;o0000Qoooool00;Gooooo00?o0000ooooooooool09oooool2o`00
08Oooooo002eooooo`03o`000?oooooooooo02Oooooo0_l00027ooooo`00]Oooool00ol0003ooooo
ooooo`0Wooooo`;o0000Qoooool00;Gooooo00?o0000ooooooooool09oooool2o`0008Oooooo002e
ooooo`03o`000?oooooooooo02Oooooo0_l00027ooooo`00]Oooool2o`0002Sooooo0_l00027oooo
o`00]Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo08Gooooo002eooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool0QOooool00;Gooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`25ooooo`00]Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo08Gooooo002eooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0QOooool00;Go
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`25ooooo`00]Oooool00ol0003ooooo
ooooo`0Xooooo`;o0000Q_ooool00;Gooooo00?o0000ooooooooool0:?ooool2o`0008Kooooo002e
ooooo`;o0000:Oooool2o`0008Kooooo002eooooo`03o`000?oooooooooo02Sooooo0_l00026oooo
o`00]Oooool00ol0003oooooooooo`0Xooooo`;o0000Q_ooool00;Gooooo00?o0000ooooooooool0
:?ooool2o`0008Kooooo002eooooo`03o`000?oooooooooo02Sooooo0_l00026ooooo`00]Oooool0
0ol0003oooooooooo`0Xooooo`;o0000Q_ooool00;Gooooo00?o0000ooooooooool0:?ooool2o`00
08Kooooo002eooooo`03o`000?oooooooooo02Sooooo0_l00026ooooo`00]Oooool2o`0002Wooooo
0_l00026ooooo`00]Oooool00ol0003oooooooooo`0Xooooo`;o0000Q_ooool00;Gooooo00?o0000
ooooooooool0:?ooool2o`0000;ooooo00?o0000ooooooooool0POooool00;Gooooo00?o0000oooo
ooooool0:?ooool2o`0000;ooooo00?o0000ooooooooool0POooool00;Gooooo00?o0000oooooooo
ool0:?ooool2o`0000;ooooo00?o0000ooooooooool0POooool00;Gooooo00?o0000ooooooooool0
:?ooool2o`0000;ooooo00?o0000ooooooooool0POooool00:_ooooo00GoA4A4o`000?l0003o<S8b
omgMg@05ooooo`03o`000?oooooooooo02Sooooo0_l000000ooooooo0000o`000023ooooo`00[_oo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02Sooooo0_l000000ooooooo0000o`00
0023ooooo`00X_ooool6o`0000Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0X
ooooo`;o000000?oooooo`000?l00000Poooool00:kooooo00?oMgMgoc8b<_ooool01?ooool3o`00
02Sooooo0_l000000ooooooo0000o`000023ooooo`00Zoooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool0:?ooool2o`000003ooooool0003o000008?ooooo002[ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0:?ooool2o`000003ooooool0003o000008?o
oooo002[ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0:?ooool2o`000003oooo
ool0003o000008?ooooo002[ooooo`Co00001_ooool00ol0003oooooooooo`0Xooooo`;o000000?o
ooooo`000?l00000Poooool00;Gooooo00?o0000ooooooooool0:?ooool2o`000003ooooool0003o
000008?ooooo002eooooo`03o`000?oooooooooo02Sooooo0_l000000ooooooo0000o`000023oooo
o`00]Oooool00ol0003oooooooooo`0Xooooo`;o000000?oooooo`000?l00000Poooool00;Gooooo
0_l0000Yooooo`;o000000?oooooo`000?l00000Poooool00;Gooooo00?o0000ooooooooool0:?oo
ool3o`000003ooooool0003ooooo08;ooooo002eooooo`03o`000?oooooooooo02Sooooo0ol00000
0ooooooo0000ooooo`22ooooo`00]Oooool00ol0003oooooooooo`0Xooooo`Co0000Q?ooool00;Go
oooo00?o0000ooooooooool0:?ooool4o`0008Cooooo002eooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooool000000_l00024ooooo`00]Oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooo000000;o0000Q?ooool00;Gooooo00?o0000ooooooooool09oooool00ol0003oooooo`000002
o`0008Cooooo002eooooo`03o`000?oooooooooo02Oooooo00?o0000ooooool000000_l00024oooo
o`00]Oooool2o`0002Sooooo00?o0000ooooool000000_l00024ooooo`00]Oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooo000000;o0000Q?ooool00;Gooooo00?o0000ooooooooool09ooo
ool01?l0003oooooo`000?l00025ooooo`00]Oooool00ol0003oooooooooo`0Wooooo`Co0000QOoo
ool00;Gooooo00?o0000ooooooooool09oooool4o`0008Gooooo002eooooo`03o`000?oooooooooo
02Oooooo1?l00025ooooo`00]Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo000000;o
0000QOooool00;Gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`02o`0008Gooooo
002eooooo`;o00009oooool01Ol0003ooooooooooooooooo000008Gooooo002eooooo`03o`000?oo
oooooooo02Kooooo00Go0000ooooooooooooooooo`000025ooooo`00]Oooool00ol0003ooooooooo
o`0Vooooo`05o`000?ooooooooooooooool00000QOooool00;Gooooo00?o0000ooooooooool09_oo
ool01?l0003oooooooooool00026ooooo`00]Oooool00ol0003oooooooooo`0Vooooo`04o`000?oo
ooooooooo`0008Kooooo002eooooo`03o`000?oooooooooo02Kooooo00Co0000oooooooooooo0000
Q_ooool00;Gooooo00?o0000ooooooooool09_ooool01?l0003oooooooooool00026ooooo`00]Ooo
ool00ol0003oooooooooo`0Vooooo`04o`000?ooooooooooo`0008Kooooo002eooooo`03o`000?oo
oooooooo02Gooooo00Go0000ooooooooooooooooo`000026ooooo`00]Oooool2o`0002Kooooo00Go
0000ooooooooooooooooo`000026ooooo`00]Oooool00ol0003oooooooooo`0Uooooo`05o`000?oo
ooooooooooooool00000Q_ooool00;Gooooo00?o0000ooooooooool09Oooool01?l0003ooooooooo
ool00027ooooo`00]Oooool00ol0003oooooooooo`0Uooooo`04o`000?ooooooooooo`0008Oooooo
002eooooo`03o`000?oooooooooo02Gooooo00Co0000oooooooooooo0000Qoooool00;Gooooo00?o
0000ooooooooool09Oooool01?l0003oooooooooool00027ooooo`00V_ooool5o`0000Gooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Tooooo`05o`00
0?ooooooooooooooool00000Qoooool009[ooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02Cooooo00Co0000oooooooo
oooo0000R?ooool009;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000oooooooo
ool00oooool3o`0002Cooooo00Co0000oooooooooooo0000R?ooool009cooooo00?oV9RHob4Q8Oo^
k^h03oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02?ooooo00Go0000oooooooo
ooooooooo`000028ooooo`00WOooool00omgMgOoIVIVooooo`0;ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`0Sooooo`05o`000?ooooooooooooooool00000R?ooool0
09kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
02?ooooo00Go0000ooooooooooooooooo`000028ooooo`00V_ooool01Ol0003o^[ZjoooooonHV9So
410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Sooooo`05o`000?oooooo
ooooooooool00000R?ooool009[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`Co00001_oo
ool00ol0003oooooooooo`0Rooooo`05o`000?ooooooooooooooool00000ROooool00;Gooooo00?o
0000ooooooooool08_ooool01Ol0003ooooooooooooooooo000008Wooooo002eooooo`03o`000?oo
oooooooo02;ooooo00Go0000ooooooooooooooooo`000029ooooo`00]Oooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Qoooool00;Gooooo0_l0000R
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Qoooool00;Gooooo00?o0000oooo
ooooool08Oooool01Ol0003ooooooooooooooooo000008[ooooo002eooooo`03o`000?oooooooooo
027ooooo00Go0000ooooooooooooooooo`00002:ooooo`00]Oooool00ol0003oooooooooo`0Poooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0R?ooool00;Gooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo08Sooooo002eooooo`03o`00
0?oooooooooo023ooooo00Go0000ooooooooooooooooo`00002;ooooo`00]Oooool00ol0003ooooo
ooooo`0Pooooo`05o`000?ooooooooooooooool00000Roooool00;Gooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo08Wooooo002eooooo`;o00008?oo
ool01Ol0003ooooooooooooooooo000008cooooo002eooooo`03o`000?oooooooooo01oooooo00Go
0000ooooooooooooooooo`00002<ooooo`00]Oooool00ol0003oooooooooo`0Nooooo`05o`000?oo
ooooooooooooool00000SOooool00;Gooooo00?o0000ooooooooool07_ooool01Ol0003ooooooooo
oooooooo000008gooooo002eooooo`03o`000?oooooooooo01kooooo00Go0000oooooooooooooooo
o`00002=ooooo`00]Oooool00ol0003oooooooooo`0Mooooo`05o`000?ooooooooooooooool00000
S_ooool00;Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo08cooooo002eooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`2=ooooo`00]Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0SOooool00;Gooooo0_l0000Kooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0S_ooool00;Gooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo08kooooo002eooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`2?ooooo`00]Oooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Soooool000Wooooo1?l000002?l@
413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^6oooool00ol0003ok^k^ooooo`05ooooo`;o8B4Q
1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01kooooo00GoA4A4o`000?l0003o<S8bomgMg@0Loooo
o`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Looooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool00_ooool5o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd07_ooool01Om4A4Co0000o`000?lb<S;ogMgM01kooooo00?o0000onk^k_ooool0
1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Jooooo`Co000000So410@oooooooo
ooook^k^oc8b<_l0003o<S8bonk^kP?ooooo000;ooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0Kooooo`03oeEEEOnYZJWooooo00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo023ooooo00?oMgMgoc8b<_ooool06oooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo
0_lQ8B48ooooo`03ogMgMolb<S;ooooo01_ooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`03ooooo`05oiRHV?l0003ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_oo
ool08?ooool00omgMgOo<S8booooo`0Mooooo`03oeEEEOnYZJWooooo00Gooooo0_lQ8B48ooooo`03
ogMgMolb<S;ooooo01_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo0006o`0000Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@
017ooooo1_l00004ooooo`03ojVYZOmEEEGooooo013ooooo00?o0000ooooooooool04oooool6o`00
00Oooooo00?o0000ooooooooool04_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00oooool01?l0
003oV9RHob4Q8Oo^k^hAooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool07?ooool0
0onYZJWoEEEEooooo`0@ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@00?ooooo000;ooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`00000Looooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool08?oo
ool00omgMgOo<S8booooo`0Mooooo`03oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool06ooo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo00Ko0000ooooooooooooV9RH
ob4Q8Oo^k^h?ooooo`03ogMgMolb<S;ooooo023ooooo00?oMgMgoc8b<_ooool07_ooool00olQ8B7o
ooooooooo`0>ooooo`03ogMgMolb<S;ooooo01_ooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000?ooooo000;ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`00000Looooo`03oeEEEOo<c<cooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00N
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`07oooool00omgMgOoIVIVooooo`0;ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`07?ooool2o`0001Cooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo
00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01kooooo00Go0000ob4Q8Ol0
003o<S8bolc<c00Oooooo`03oeEEEOo<c<cooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00L
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`002oooool0
0ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41007?ooool00onYZJWoMgMgoooo
o`0;ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool04Oooool2o`0000Oooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool08Oooool00onYZJWoMgMgooooo`0;ooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo000;ooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Iooooo`05oa0@4?oooooooooooooooolb
<S803?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01kooooo00Go0000okZj^_oo
ooooV9RHoa0@400<ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool03oooool2o`00
00Sooooo00So0000oooooooooooo0000okZj^_ooooooV9RHoa0@40cooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`0Nooooo`05oa0@4?oooooooooooooooolb<S803?ooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`002Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06Oooool5o`00
00cooooo1?l0000Oooooo`Co00007Oooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l0000M
ooooo`03o`000?oooooooooo00gooooo0_l00008ooooo`;o00000oooool01OnHV9So410@o`000?lQ
8B7oc<c<00cooooo1?l0000Oooooo`Co00007Oooool5o`0000cooooo1?l0000Kooooo`03oeEEEOmV
IVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00]Oooool00ol0003ooooooooo
o`0;ooooo`;o00002Oooool00ol0003oooooooooo`2Gooooo`00]Oooool00ol0003oooooooooo`09
ooooo`;o00002_ooool00ol0003oooooooooo`2Hooooo`00]Oooool00ol0003oooooooooo`05oooo
o`Co00002oooool00ol0003oooooooooo`2Iooooo`00]Oooool00ol0003oooooooooo`05o`0000ko
oooo00?o0000ooooooooool0V_ooool00;3ooooo2?l0000Aooooo`;o0000WOooool000_oooooool0
001Fo`0000Sooooo000;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`Go00000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool3o`0000Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo000;ooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
01Cooooo0ol0000Aooooo`03o`000?oooooooooo00Sooooo1?l0000Kooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
00Kooooo002Pooooo`03o`000?oooooooooo00Cooooo6Ol0002Xooooo`00Woooool00ol0003ooooo
ooooo`02ooooo`?o00003_ooool00ol0003oooooooooo`2`ooooo`00W_ooool00ol0003ooooooooo
o`03o`00017ooooo00?o0000ooooooooool0/?ooool009gooooo00Co0000ooooool0003o00005?oo
ool00ol0003oooooooooo`2`ooooo`00W?ooool00ol0003oooooo`00000Fooooo`03o`000?oooooo
oooo0;3ooooo002Kooooo`03o`000?oooooo000001Oooooo00?o0000ooooooooool0/?ooool009[o
oooo00?o0000ooooool000006?ooool2o`000;7ooooo002Iooooo`03o`000?oooooo000001Wooooo
00?o0000ooooooooool0/?ooool009Sooooo00?o0000ooooool000006_ooool00ol0003ooooooooo
o`2`ooooo`00Uoooool00ol0003oooooo`00000Kooooo`03o`000?oooooooooo0;3ooooo002Goooo
o`03o`000?oooooo000001_ooooo00?o0000ooooooooool0/?ooool009Kooooo00?o0000ooooool0
00007?ooool00ol0003oooooooooo`2`ooooo`00U_ooool2o`0001gooooo00?o0000ooooooooool0
/?ooool009Gooooo00?o0000ooooool000007Oooool00ol0003oooooooooo`2`ooooo`00UOooool2
o`0001kooooo0_l0002aooooo`00U?ooool00ol0003oooooo`00000Nooooo`03o`000?oooooooooo
0;3ooooo002Dooooo`;o00007oooool00ol0003oooooooooo`2`ooooo`00Toooool2o`00023ooooo
00?o0000ooooooooool0/?ooool009?ooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`2`ooooo`00Toooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`;o00008Oooool00ol0003oooooooooo`2`ooooo`00T_ooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo0;3ooooo002Aooooo`;o00008_ooool00ol0003oooooooooo`2`ooooo`00TOoo
ool2o`0002;ooooo0_l0002aooooo`00T?ooool2o`0002?ooooo00?o0000ooooooooool0/?ooool0
093ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`2`ooooo`00T?ooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool009[ooooo
1Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooooooo
ool0/?ooool009[ooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q2?ooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Kooooo`03oiRHV?lQ8B7ok^k^017ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`2`ooooo`00W?ooool00onHV9So8B4Qonk^
kP0?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00WOooool00omgMgOoIVIVooooo`0;
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`ooooo`00W_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool0
09[ooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0/?ooool009[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`Co00001_ooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`2`ooooo`00[_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
0;3ooooo002_ooooo`03o`000?oooooooooo00?ooooo0ol0002`ooooo`00[_ooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`2`ooooo`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0;3ooooo002[ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool0
0:_ooooo1?l00006ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool009cooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Looooo`03oeEEEOnYZJWooooo
00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009co
oooo00?oZJVYoeEEEOooool04?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3o
oooo002Mooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool3o`000;3ooooo
002Mooooo`03oeEEEOo<c<cooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Mooooo`03ojVYZOmgMgOooooo00_ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo<S8b00cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00V_ooool5o`0000cooooo1?l00006
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00:?ooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^1_ooool00ol0003oooooooooo`2`ooooo`00YOooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`2`ooooo`00YOoo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool3o`000;3ooooo
002Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00002iooooo`00YOoo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000^Oooool00:Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@0;Wooooo002Uooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`2iooooo`00Xoooool00omEEEGoIVIVo`00
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0^Oooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-10, -10, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.05 0.5 0.05 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-10)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-7.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-2.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(2.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(7.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(10)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-10)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-7.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-2.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(2.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(7.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(10)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.39895 .60797 m
.39496 .62953 L
.39298 .64411 L
.39227 .65153 L
.39248 .65202 L
.39353 .646 L
.39559 .63402 L
.39903 .61688 L
.40438 .59581 L
.41228 .57274 L
.42338 .55037 L
.4382 .53176 L
.45687 .5195 L
.47898 .51424 L
.50338 .51362 L
.52843 .5125 L
.55221 .50496 L
.57305 .48701 L
.58983 .4582 L
.60217 .42129 L
.61027 .38056 L
.61474 .34018 L
.61634 .30317 L
.61587 .27122 L
.61407 .24492 L
.61155 .22413 L
.60881 .20836 L
.60625 .197 L
.60415 .18946 L
.60268 .18525 L
.60193 .18401 L
.60191 .18547 L
.60255 .18943 L
.60369 .19574 L
.60516 .20419 L
.60673 .21447 L
.60818 .22601 L
.60932 .23794 L
.61002 .24897 L
.61022 .25741 L
.60989 .26126 L
.60892 .25842 L
.60689 .24709 L
.60276 .22654 L
.59455 .19826 L
.57937 .16646 L
.55368 .13527 L
.51406 .10217 L
.46003 .06114 L
.40342 .03033 L
Mistroke
.37304 .02512 L
.38752 .01351 L
.43043 .01579 L
.46933 .03306 L
.48859 .04337 L
.48853 .04281 L
.4739 .034 L
.44954 .02087 L
.42003 .00946 L
.38988 .00731 L
.36309 .01859 L
.34241 .03996 L
.32895 .06237 L
.32259 .0773 L
.32242 .08113 L
.32731 .07548 L
.33601 .06477 L
.34728 .05353 L
.35991 .04478 L
.37286 .03967 L
.38528 .03795 L
.39657 .0387 L
.40635 .04086 L
.41446 .04356 L
.42091 .04617 L
.42581 .04838 L
.42943 .05006 L
.43209 .05129 L
.43426 .05226 L
.43648 .05326 L
.43939 .0547 L
.44372 .05709 L
.45026 .06108 L
.45982 .06745 L
.47308 .07699 L
.49038 .09017 L
.51146 .10681 L
.53521 .12648 L
.55968 .15039 L
.58217 .18387 L
.59916 .23568 L
.60619 .31036 L
.59878 .39631 L
.57521 .46555 L
.53938 .4981 L
.4997 .504 L
.46421 .50816 L
.43693 .52424 L
.41811 .55075 L
.40611 .58064 L
Mistroke
.39895 .60797 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00Xoooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^jiooooo`00YOooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0^Ooo
ool009[ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
402iooooo`00YOooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_oo
ool3o`000;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo0;3ooooo002>ooooo`So00003oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`2`ooooo`00S?ooool2
o`0000Sooooo1_l00009ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`06ooooo`03o`000?oooooooooo0;3ooooo0029ooooo`?o00000_ooool9o`0000Gooooo0ol00004
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
oooooooo0;3ooooo0027ooooo`;o00001?ooool00ol0003oooooooooo`07ooooo`[o00005?ooool0
0ol0003oooooooooo`2`ooooo`00Q_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
013ooooo1Ol0000Aooooo`03o`000?oooooooooo0;3ooooo0025ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool04oooool2o`000003ooooool0003o000000oooooo00?o0000oooooooo
ool0/?ooool008Cooooo00?o0000ooooooooool00oooool4o`0001Gooooo1Ol0000=ooooo`;o0000
/Oooool008?ooooo00?o0000ooooooooool02?ooool5o`0001?ooooo1?l0000;ooooo`03o`000?oo
oooooooo0;3ooooo0022ooooo`03o`000?oooooooooo00kooooo0ol0000Booooo`Co00002Oooool0
0ol0003oooooooooo`2`ooooo`00POooool00ol0003oooooooooo`0Booooo`;o00004_ooool4o`00
00Oooooo00?o0000ooooooooool0/?ooool0083ooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`0Aooooo`Co00001Oooool00ol0003oooooooooo`2`ooooo`00Ooooool00ol0003ooooo
ooooo`07ooooo`co00001?ooool2o`0001?ooooo00?o0000ooooool000001?ooool00ol0003ooooo
ooooo`2`ooooo`00Ooooool00ol0003oooooooooo`04ooooo`?o00003?ooool3o`0000?ooooo0_l0
000Booooo`?o00000oooool00ol0003oooooooooo`2`ooooo`00O_ooool00ol0003oooooooooo`03
ooooo`;o00004_ooool2o`0000?ooooo0_l0000Booooo`05o`000?ooooooooooooooool00000/_oo
ool007kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Dooooo`?o00000_ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo0;3ooooo001mooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool06?ooool2o`000003ooooool0003o000001?ooooo0_l0002aoooo
o`00OOooool01Ol0003ooooooooooooooooo000001gooooo1Ol0000Aooooo`03o`000?oooooooooo
0;3ooooo001looooo`05o`000?ooooooooooooooool000008Oooool00ol0003oooooo`00000@oooo
o`03o`000?oooooooooo0;3ooooo001looooo`04o`000?ooooooooooo`0002?ooooo00Co0000oooo
ool0003o00003_ooool00ol0003oooooooooo`2`ooooo`00Noooool01?l0003oooooooooool0000U
ooooo`;o000000?oooooo`000?l000003?ooool00ol0003oooooooooo`2`ooooo`00Noooool00ol0
003oooooo`00000Xooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool0/?ooool0
07[ooooo00Co0000oooooooooooo0000:Oooool2o`000003ooooool0003ooooo00Wooooo00?o0000
ooooooooool0/?ooool007[ooooo00?o0000ooooool00000;?ooool4o`0000Sooooo00?o0000oooo
ooooool0/?ooool007[ooooo0_l0000_ooooo`03o`000?oooooo000000Oooooo0_l0002aooooo`00
NOooool2o`00037ooooo0ol00006ooooo`03o`000?oooooooooo0;3ooooo001hooooo`03o`000?oo
oooooooo03?ooooo0ol00004ooooo`03o`000?oooooooooo0;3ooooo002_ooooo`03o`000?oooooo
000000?ooooo00?o0000ooooooooool0/?ooool00;3ooooo00Ko0000ooooool0003o0000ooooool0
002booooo`00/Oooool00ol0003oooooooooo`02o`000;;ooooo002booooo`;o000000?oooooo`00
0?ooool0/Oooool00;Cooooo1?l0002`ooooo`00]Oooool2o`000003ooooool0003ooooo0:kooooo
002eooooo`?o000000?oooooo`000?ooool0[Oooool00;Gooooo00Go0000oooooooooooo0000oooo
o`02o`000:cooooo002eooooo`04o`000?ooooooooooooooo`;o000000?oooooo`000?ooool0Z_oo
ool00;Gooooo00?o0000ooooooooool00oooool00ol0003oooooo`00002Zooooo`00]Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooo00000:Wooooo002eooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooool00000Z?ooool009cooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00Kooooo00Co0000ooooool0
003o0000Y_ooool009cooooo00?oEEEEojVYZOooool01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooo`000:Gooooo002Booooo`Ko
00001?ooool00onYZJWoEEEEooooo`0@ooooo`03o`000?oooooooooo00?ooooo0ol00008ooooo`04
o`000?ooooooooooo`000:Cooooo002Mooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`000:?ooooo002Mooooo`03
oeEEEOo<c<cooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo
00[ooooo00Co0000oooooooooooo0000X_ooool009gooooo00?oZJVYogMgMoooool02oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooo0000XOooool0
09[ooooo00Go410@oooooooooooooooooc8b<P0<ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool03?ooool01?l0003oooooooooool0002Pooooo`00V_ooool5o`0000cooooo1?l00006
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooool00000X?ooool00;Gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooo`00002Oooooo`00]Oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooo000009kooooo002eooooo`03o`000?oooooooooo013ooooo00?o0000ooooool00000
WOooool00;Gooooo0_l0000Booooo`03o`000?oooooo000009cooooo002eooooo`03o`000?oooooo
oooo017ooooo00Co0000oooooooooooo0000Voooool00;Gooooo00?o0000ooooooooool04_ooool0
0ol0003oooooo`00002Kooooo`00]Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo0000
09[ooooo002eooooo`03o`000?oooooooooo01Cooooo00?o0000ooooool00000VOooool00;Gooooo
00?o0000ooooooooool05?ooool01?l0003oooooooooool0002Hooooo`00]Oooool00ol0003ooooo
ooooo`0Eooooo`04o`000?ooooooooooo`0009Oooooo002eooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooool00000Uoooool00;Gooooo0_l0000Gooooo`04o`000?ooooooooooo`0009Kooooo
002eooooo`03o`000?oooooooooo01Oooooo00?o0000ooooool00000U_ooool00;Gooooo00?o0000
ooooooooool06?ooool00ol0003oooooo`00002Eooooo`00]Oooool00ol0003oooooooooo`0Ioooo
o`;o00001Oooool00ol0003oooooooooo`2=ooooo`00]Oooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooo000000Cooooo00?o0000ooooooooool0SOooool00;Gooooo00?o0000ooooooooool0
6_ooool2o`0000Cooooo00?o0000ooooooooool0SOooool00;Gooooo00?o0000ooooooooool06_oo
ool00ol0003oooooo`000003ooooo`03o`000?oooooooooo08gooooo002eooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooool000000oooool2o`0008kooooo002eooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooool000000_ooool2o`0008kooooo002eooooo`;o00007?ooool00ol0003o
ooooo`000003ooooo`03o`000?oooooooooo08cooooo002eooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooool000000oooool00ol0003oooooooooo`2<ooooo`00]Oooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooo000000;ooooo0_l0002=ooooo`00]Oooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooo000000;ooooo0_l0002=ooooo`00]Oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooo000000;ooooo0_l0002=ooooo`00]Oooool00ol0003oooooooooo`0Mooooo`04
o`000?oooooo0000ooooo`;o0000SOooool00;Gooooo00?o0000ooooooooool07Oooool01ol0003o
ooooo`000?oooooo0000ooooool00000S?ooool00;Gooooo00?o0000ooooooooool07Oooool01ol0
003oooooo`000?oooooo0000ooooool00000S?ooool00;Gooooo0_l0000Oooooo`04o`000?oooooo
0000ooooo`;o0000S?ooool00;Gooooo00?o0000ooooooooool07_ooool01?l0003oooooo`000?oo
ool2o`0008cooooo002eooooo`03o`000?oooooooooo01kooooo00Co0000ooooool0003ooooo0_l0
002<ooooo`00]Oooool00ol0003oooooooooo`0Oooooo`;o000000?oooooo`000?l00000S?ooool0
0;Gooooo00?o0000ooooooooool07oooool2o`000004ooooool0003oooooo`0008_ooooo002eoooo
o`03o`000?oooooooooo01oooooo00Ko0000ooooool0003o0000ooooool0002;ooooo`00Zoooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool07oooool01_l0003oooooo`00
0?l0003oooooo`0008_ooooo002^ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
7oooool01_l0003oooooo`000?l0003oooooo`0008_ooooo002Rooooo`Ko00001oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01oooooo00Ko0000ooooool0003o0000ooooool0002;
ooooo`00[_ooool00omgMgOo<S8booooo`04ooooo`?o00007oooool01_l0003oooooo`000?l0003o
ooooo`0008_ooooo002[ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`0Oooooo`06o`000?oooooo0000o`000?oooooo0000Roooool00:_ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Pooooo`05o`000?oooooo0000ooooool00000Roooool00:_ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Pooooo`05o`000?oooooo0000ooooool0
0000Roooool00:_ooooo1?l00006ooooo`03o`000?oooooooooo023ooooo00Go0000ooooool0003o
ooooo`00002;ooooo`00]Oooool00ol0003oooooooooo`0Pooooo`05o`000?ooooooooooooooool0
0000Roooool00;Gooooo00?o0000ooooooooool08?ooool01Ol0003ooooooooooooooooo000008_o
oooo002eooooo`03o`000?oooooooooo023ooooo00Go0000ooooooooooooooooo`00002;ooooo`00
]Oooool2o`00027ooooo00Go0000ooooooooooooooooo`00002;ooooo`00]Oooool00ol0003ooooo
ooooo`0Pooooo`05o`000?ooooooooooooooool00000Roooool00;Gooooo00?o0000ooooooooool0
8?ooool01Ol0003ooooooooooooooooo000008_ooooo002eooooo`03o`000?oooooooooo023ooooo
00Go0000ooooooooooooooooo`00002;ooooo`00]Oooool00ol0003oooooooooo`0Pooooo`05o`00
0?ooooooooooooooool00000Roooool00;Gooooo00?o0000ooooooooool08?ooool01Ol0003ooooo
oooooooooooo000008_ooooo002eooooo`03o`000?oooooooooo023ooooo00Go0000oooooooooooo
ooooo`00002;ooooo`00]Oooool00ol0003oooooooooo`0Qooooo`04o`000?ooooooooooo`0008_o
oooo002eooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo0000Roooool00;Gooooo
0_l0000Rooooo`04o`000?ooooooooooo`0008_ooooo002eooooo`03o`000?oooooooooo027ooooo
00Co0000oooooooooooo0000Roooool00;Gooooo00?o0000ooooooooool08Oooool01?l0003ooooo
ooooool0002;ooooo`00]Oooool00ol0003oooooooooo`0Qooooo`04o`000?ooooooooooo`0008_o
oooo002eooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo0000Roooool00;Gooooo
00?o0000ooooooooool08Oooool01?l0003oooooooooool0002;ooooo`00]Oooool00ol0003ooooo
ooooo`0Qooooo`04o`000?ooooooooooo`0008_ooooo002eooooo`03o`000?oooooooooo027ooooo
00Co0000oooooooooooo0000Roooool00;Gooooo0_l0000Rooooo`04o`000?ooooooooooo`0008_o
oooo002eooooo`03o`000?oooooooooo023ooooo00Go0000ooooooooooooooooo`00002;ooooo`00
]Oooool00ol0003oooooooooo`0Pooooo`05o`000?ooooooooooooooool00000Roooool00;Gooooo
00?o0000ooooooooool08?ooool01Ol0003ooooooooooooooooo000008_ooooo002eooooo`03o`00
0?oooooooooo023ooooo00Go0000ooooooooooooooooo`00002;ooooo`00]Oooool00ol0003ooooo
ooooo`0Pooooo`05o`000?ooooooooooooooool00000Roooool00;Gooooo00?o0000ooooooooool0
8?ooool01Ol0003ooooooooooooooooo000008_ooooo002eooooo`03o`000?oooooooooo023ooooo
00Go0000ooooooooooooooooo`00002;ooooo`00]Oooool00ol0003oooooooooo`0Pooooo`05o`00
0?ooooooooooooooool00000Roooool00;Gooooo0_l0000Qooooo`05o`000?ooooooooooooooool0
0000Roooool00;Gooooo00?o0000ooooooooool08?ooool01?l0003oooooooooool0002<ooooo`00
]Oooool00ol0003oooooooooo`0Oooooo`05o`000?ooooooooooooooool00000S?ooool00;Gooooo
00?o0000ooooooooool07oooool01Ol0003ooooooooooooooooo000008cooooo002eooooo`03o`00
0?oooooooooo01oooooo00Go0000ooooooooooooooooo`00002<ooooo`00]Oooool00ol0003ooooo
ooooo`0Oooooo`05o`000?ooooooooooooooool00000S?ooool009[ooooo1Ol00005ooooo`;o8B4Q
1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool07oooool01Ol0003o
oooooooooooooooo000008cooooo002Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Oooooo`05o`000?oooooooooo
ooooool00000S?ooool009;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000oooo
ooooool00oooool3o`0001oooooo00Co0000oooooooooooo0000SOooool009cooooo00?oV9RHob4Q
8Oo^k^h03oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01oooooo00Co0000oooo
oooooooo0000SOooool009gooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool07oooool01?l0003oooooooooool0002=ooooo`00W_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07oooool0
1?l0003oooooooooool0002=ooooo`00V_ooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Nooooo`05o`000?ooooooooooooooool00000
SOooool009[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`Co00001_ooool00ol0003ooooo
ooooo`0Nooooo`05o`000?ooooooooooooooool00000SOooool00;Gooooo00?o0000ooooooooool0
7_ooool01?l0003oooooooooool0002>ooooo`00]Oooool00ol0003oooooooooo`0Nooooo`04o`00
0?ooooooooooo`0008kooooo002eooooo`03o`000?oooooooooo01kooooo00Co0000oooooooooooo
0000S_ooool00;Gooooo0_l0000Oooooo`04o`000?ooooooooooo`0008kooooo002eooooo`03o`00
0?oooooooooo01gooooo00Go0000ooooooooooooooooo`00002>ooooo`00]Oooool00ol0003ooooo
ooooo`0Mooooo`05o`000?ooooooooooooooool00000S_ooool00;Gooooo00?o0000ooooooooool0
7Oooool01Ol0003ooooooooooooooooo000008kooooo002eooooo`03o`000?oooooooooo01cooooo
00Go0000ooooooooooooooooo`00002?ooooo`00]Oooool00ol0003oooooooooo`0Looooo`05o`00
0?ooooooooooooooool00000Soooool00;Gooooo00?o0000ooooooooool07?ooool01Ol0003ooooo
oooooooooooo000008oooooo002eooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`2=ooooo`00]Oooool2o`0001cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`2=ooooo`00]Oooool00ol0003oooooooooo`0Kooooo`05o`000?oooooo
ooooooooool00000T?ooool00;Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo08kooooo002eooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`2>ooooo`00]Oooool00ol0003oooooooooo`0Jooooo`05
o`000?ooooooooooooooool00000TOooool00;Gooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo08oooooo002eooooo`03o`000?oooooooooo01Wooooo
00Go0000ooooooooooooooooo`00002Booooo`00]Oooool00ol0003oooooooooo`0Iooooo`05o`00
0?ooooooooooooooool00000T_ooool00;Gooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo093ooooo002eooooo`;o00006Oooool01Ol0003ooooooooo
oooooooo000009?ooooo002eooooo`03o`000?oooooooooo01Sooooo00Go0000oooooooooooooooo
o`00002Cooooo`00]Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0TOooool00;Gooooo00?o0000ooooooooool05oooool01Ol0003ooooooooooooo
oooo000009Cooooo0009ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQ_o
oooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Noooo
o`05odA4A?l0003o0000oc8b<_oMgMd07?ooool5o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd07?ooool00ol0003oooooooooo`0Gooooo`04o`000?ooooooooooooooo`Ko0000
1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Nooooo`05odA4A?l0003o0000oc8b
<_oMgMd07_ooool00ol0003ok^k^ooooo`05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM01[ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool000_ooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00?oEEEEojVYZOoo
ool01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool08?ooool00omgMgOo<S8booooo`0Kooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06oooool00ol0
003oooooooooo`0Eooooo`;o00000oooool01ol0003ooooooiRHV?lQ8B7ok^k^oooooom4A4@01Ooo
ool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool08?ooool00omgMgOo<S8booooo`0Mooooo`03oeEEEOnY
ZJWooooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01_ooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0006o`0000Gooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@017ooooo1_l00004ooooo`03ojVYZOmEEEGooooo013ooooo
00?o0000ooooooooool04oooool6o`0000Oooooo00?o0000ooooooooool04_ooool6o`0000?ooooo
00?oV9RHob4Q8Oo^k^h04Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool00oooool01_l0003ooooooooooonHV9So8B4Qonk^kQ7ooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`0Looooo`03ojVYZOmEEEGooooo013ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool0
00_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001cooooo00?o8B4Q
ooooooooool03_ooool00omgMgOo<S8booooo`0Pooooo`03ogMgMolb<S;ooooo01gooooo00?oV9RH
ob4Q8Oo^k^h03oooool00omgMgOo<S8booooo`0Kooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03oiRHV?lQ8B7ok^k^00oooooo00?oMgMg
oc8b<_ooool08?ooool00omgMgOo<S8booooo`0Nooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMg
oc8b<_ooool06oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool000_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001cooooo00?o
EEEEolc<c?ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01kooooo00Go0000ob4Q8Ol0003o
<S8bolc<c00Oooooo`03ogMgMomVIVKooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Loooo
o`;o00004oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?oMgMgofIV
I_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01kooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Oooooo`03oeEEEOo<c<cooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Looooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`002oooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41007?ooool00onYZJWoMgMgooooo`0;ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo027ooooo00?oZJVYogMgMoooool02oooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`002oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06Oooool01Ol@413ooooooooooooooooo
<S8b00cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Nooooo`05o`000?nj^[[o
oooooiRHV?l@41003?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool01Oooool02Ol0003ooooooooooooooooo0000okZj^_ooooooV9RHoa0@400<oooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool07_ooool01Ol@413ooooooooooooooooo
<S8b00cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool000Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^01Wooooo1Ol0000<ooooo`Co00007oooool4o`0001gooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c00<ooooo`Co00007Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00_ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l0000Oooooo`Co
00007Oooool5o`0000cooooo1?l0000Kooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`00]Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0U_ooool00;Gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`05ooooo`;o0000VOooool00;Gooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo09Wooooo002eooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2Jooooo`00]Oooool00ol0003oooooooooo`07oooo
o`Co00001oooool00ol0003oooooooooo`2Kooooo`002oooooooo`0005Ko00002?ooool000_ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`Ko00001Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Kooooo000;ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01oooooo1_l0
0003ooooo`03o`000?oooooooooo00gooooo0ol0000Gooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Kooooo002X
ooooo`Co00002Oooool00ol0003oooooooooo`09ooooo`Co0000Xoooool00:Kooooo0_l0000=oooo
o`03o`000?oooooooooo00?ooooo1_l0002Wooooo`00Y?ooool2o`0000Kooooo3ol0002]ooooo`00
X_ooool2o`0000Cooooo1?l00009ooooo`03o`000?oooooooooo0;3ooooo002Pooooo`;o00000ooo
ool3o`0000gooooo00?o0000ooooooooool0/?ooool009oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo0;3ooooo002Oooooo`03o`000?oooooooooo
00;o00004Oooool2o`000;7ooooo002Nooooo`04o`000?ooooooooooo`0001?ooooo00?o0000oooo
ooooool0/?ooool009gooooo00Co0000oooooooooooo00005?ooool00ol0003oooooooooo`2`oooo
o`00WOooool01?l0003oooooooooool0000Dooooo`03o`000?oooooooooo0;3ooooo002Looooo`04
o`000?ooooooooooo`0001Gooooo00?o0000ooooooooool0/?ooool009_ooooo00Co0000oooooooo
oooo00005_ooool00ol0003oooooooooo`2`ooooo`00Voooool00ol0003oooooo`00000Gooooo`03
o`000?oooooooooo0;3ooooo002Jooooo`03o`000?oooooo000001Sooooo00?o0000ooooooooool0
/?ooool009Wooooo00?o0000ooooool000006Oooool2o`000;7ooooo002Iooooo`03o`000?oooooo
000001Wooooo00?o0000ooooooooool0/?ooool009Sooooo00?o0000ooooool000006_ooool00ol0
003oooooooooo`2`ooooo`00V?ooool00ol0003oooooo`00000Jooooo`03o`000?oooooooooo0;3o
oooo002Hooooo`;o00006oooool00ol0003oooooooooo`2`ooooo`00Uoooool00ol0003oooooo`00
000Kooooo`03o`000?oooooooooo0;3ooooo002Gooooo`;o00007?ooool00ol0003oooooooooo`2`
ooooo`00U_ooool00ol0003oooooo`00000Looooo`03o`000?oooooooooo0;3ooooo002Fooooo`;o
00007Oooool00ol0003oooooooooo`2`ooooo`00U_ooool2o`0001gooooo0_l0002aooooo`00UOoo
ool2o`0001kooooo00?o0000ooooooooool0/?ooool009Gooooo0_l0000Nooooo`03o`000?oooooo
oooo0;3ooooo002Eooooo`;o00007_ooool00ol0003oooooooooo`2`ooooo`00U?ooool2o`0001oo
oooo00?o0000ooooooooool0/?ooool009Cooooo0_l0000Oooooo`03o`000?oooooooooo0;3ooooo
002Dooooo`;o00007oooool00ol0003oooooooooo`2`ooooo`00Toooool2o`00023ooooo00?o0000
ooooooooool0/?ooool009?ooooo0_l0000Pooooo`;o0000/Oooool009?ooooo0_l0000Pooooo`03
o`000?oooooooooo0;3ooooo002Booooo`03o`000?oooooo0000023ooooo00?o0000ooooooooool0
/?ooool009;ooooo0_l0000Qooooo`03o`000?oooooooooo0;3ooooo002Booooo`;o00008Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool2o`00027ooooo00?o0000ooooooooool0/?ooool009;o
oooo0_l00006ooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0;3ooooo002Aooooo`03o`000?oooooo000000Kooooo00GoV9RHob4Q8Oo^
k^koooooodA4A005ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
0;3ooooo002Aooooo`;o00002?ooool00onHV9So8B4Qonk^kP0Aooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0/?ooool0097ooooo0_l00009ooooo`03oiRHV?lQ8B7ok^k^00oooooo
00?oMgMgoc8b<_ooool01?ooool3o`000;3ooooo002Aooooo`;o00002_ooool00omgMgOoIVIVoooo
o`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`ooooo`00TOoo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`2`ooooo`00TOooool00ol0003oooooooooo`06ooooo`05o`000?nj^[[o
oooooiRHV?l@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002@
ooooo`;o00002?ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l00006ooooo`03o`000?oo
oooooooo0;3ooooo002@ooooo`;o00008oooool00ol0003oooooooooo`2`ooooo`00T?ooool2o`00
02?ooooo00?o0000ooooooooool0/?ooool0093ooooo0_l0000Sooooo`03o`000?oooooooooo0;3o
oooo002@ooooo`;o00008oooool2o`000;7ooooo002@ooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00:_ooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo0;3ooooo002^ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool0
0:oooooo00?o0000ooooooooool00oooool3o`000;3ooooo002^ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0/?ooool00:_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002[ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
/?ooool00:_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00Zoooool4
o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00W?ooool00ol0003ok^k^ooooo`05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009cooooo00?oEEEEojVYZOooool01Oooool2
ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00W?ooool00onY
ZJWoEEEEooooo`0@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009go
oooo00?o8B4Qooooooooool03_ooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009gooooo
00?oEEEEolc<c?ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool0/?ooool009gooooo00?oZJVYogMgMoooool02oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?oooooooooooooooolb<S803?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`Go00003?ooool4o`0000Kooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00Xoooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h6ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`?o0000/?ooool00:Gooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo00000;Wooooo002Uooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00002iooooo`00YOooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@4100^Oooool00:Gooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg0;Wooooo002Sooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP2iooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-10, -10, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.05 0.5 0.05 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-10)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-7.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-2.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(2.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(7.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(10)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-10)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-7.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-2.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(2.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(7.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(10)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.40681 .66502 m
.40691 .68677 L
.40769 .7 L
.40838 .70606 L
.40868 .7059 L
.40858 .69992 L
.40836 .68813 L
.40855 .67031 L
.40995 .64638 L
.41368 .61707 L
.42115 .58479 L
.43384 .55422 L
.45289 .53167 L
.47822 .52135 L
.50783 .52012 L
.53796 .51651 L
.56435 .49843 L
.58404 .46256 L
.59617 .41535 L
.60156 .36654 L
.60181 .32336 L
.5986 .28895 L
.59331 .26339 L
.58697 .24529 L
.58035 .23289 L
.57399 .22459 L
.5683 .21917 L
.56356 .21577 L
.55997 .21384 L
.55765 .21307 L
.55664 .21326 L
.55689 .21431 L
.55831 .21618 L
.56069 .21888 L
.56381 .22243 L
.56735 .22683 L
.571 .23203 L
.57439 .23779 L
.57715 .24361 L
.57893 .24865 L
.57932 .25177 L
.57783 .25184 L
.57368 .24826 L
.5656 .24149 L
.5516 .23299 L
.52874 .22323 L
.49268 .20826 L
.43816 .18723 L
.3676 .21604 L
.30849 .39978 L
Mistroke
.28625 .57043 L
.2939 .48178 L
.32941 .27926 L
.37243 .18168 L
.39625 .16053 L
.39607 .16021 L
.37769 .17433 L
.34906 .22014 L
.31887 .31823 L
.29457 .46744 L
.27952 .6356 L
.27259 .78203 L
.2705 .88205 L
.27041 .92993 L
.27087 .93064 L
.2717 .89304 L
.27343 .82753 L
.27665 .7452 L
.28168 .65699 L
.28838 .57233 L
.29623 .49768 L
.30455 .43617 L
.31262 .38821 L
.31989 .35238 L
.32602 .32657 L
.33087 .30849 L
.33454 .29603 L
.33729 .28728 L
.33955 .28042 L
.34189 .27368 L
.34501 .26529 L
.34978 .25374 L
.35723 .23832 L
.36856 .22005 L
.38501 .20244 L
.4075 .19129 L
.43594 .19164 L
.46869 .20313 L
.50281 .21924 L
.53529 .23452 L
.56363 .25326 L
.58486 .29034 L
.59358 .35903 L
.58226 .44502 L
.5481 .50132 L
.5014 .51225 L
.45929 .51978 L
.43096 .55008 L
.4156 .59297 L
.40885 .63349 L
Mistroke
.40681 .66502 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00Xoooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^jiooooo`00YOooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0^Ooo
ool009[ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
402iooooo`00YOooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_oo
ool3o`000;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0;3ooooo002S
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool009cooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Looooo`03oeEEEOnYZJWo
oooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool0
09;ooooo1_l00004ooooo`03ojVYZOmEEEGooooo013ooooo00?o0000ooooooooool00oooool3o`00
0;3ooooo002Mooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`2`ooooo`00WOooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`2`ooooo`00WOooool00onYZJWoMgMgooooo`0;ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooo
oc8b<P0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo1Ol0
000<ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002Aooooo`;o00008_ooool00ol0003oooooooooo`2`ooooo`00T?ooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo0;3ooooo002>ooooo`;o00009Oooool00ol0003ooooo
ooooo`2`ooooo`00SOooool2o`0002Kooooo00?o0000ooooooooool0/?ooool008cooooo0_l0000W
ooooo`03o`000?oooooooooo0;3ooooo002;ooooo`;o0000:?ooool2o`000;7ooooo002;ooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0/?ooool008[ooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`2`ooooo`00ROooool2o`0002[ooooo00?o0000ooooooooool0/?oo
ool008Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`2`ooooo`00R?ooool00ol0
003oooooooooo`0Dooooo`?o00004oooool00ol0003oooooooooo`2`ooooo`00R?ooool00ol0003o
ooooooooo`09ooooo`go000000Coooooo`000?l0003o00004?ooool00ol0003oooooooooo`2`oooo
o`00Qoooool2o`0000Wooooo0_l00005ooooo`?o00001Oooool3o`000003ooooool0003o000000ko
oooo00?o0000ooooooooool0/?ooool008Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`03ooooo`;o00002oooool6o`0000_ooooo00?o0000ooooooooool0/?ooool008Kooooo0_l0
0007ooooo`;o00000oooool3o`00013ooooo1_l00008ooooo`;o0000/Oooool008Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`03o`0001Kooooo0_l000000ooooooo0000o`000006
ooooo`03o`000?oooooooooo0;3ooooo0025ooooo`;o00001_ooool01?l0003oooooo`000?l0000K
ooooo`Ko00000oooool00ol0003oooooooooo`2`ooooo`00QOooool00ol0003oooooooooo`04oooo
o`?o00008?ooool2o`000005ooooool0003o0000ooooool00000/_ooool008Cooooo0_l00003oooo
o`?o00009Oooool2o`000004ooooool0003o0000o`00017ooooo00?o0000ooooooooool0WOooool0
08?ooooo00?o0000ooooool000000_ooool00ol0003oooooo`00000Xooooo`?o000000Coooooo`00
0?l0003o00003_ooool4o`0009cooooo0023ooooo`;o00000oooool2o`0002_ooooo0ol00002oooo
o`;o00003_ooool00ol0003oooooo`00002Kooooo`00P_ooool00ol0003oooooo`000003ooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool00_l00002ooooo`?o00002oooool01?l0003o
ooooooooool0002Jooooo`00P_ooool2o`0000?ooooo0_l0000/ooooo`;o00000oooool2o`0000?o
oooo0_l0000:ooooo`04o`000?ooooooooooo`0009Wooooo0021ooooo`03o`000?oooooo000000?o
oooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo0ol00008ooooo`03o`000?oooooo000009Wooooo0021ooooo`;o00000oooool2o`0002gooooo
00?o0000ooooooooool01Oooool2o`0000Gooooo0_l00006ooooo`04o`000?ooooooooooo`0009So
oooo0021ooooo`;o00000oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Oooooo
0_l00005ooooo`;o00001Oooool01?l0003oooooooooool0002Gooooo`00P?ooool00ol0003ooooo
o`000002ooooo`;o0000;_ooool00ol0003oooooooooo`09ooooo`;o00001Oooool2o`0000?ooooo
00Co0000oooooooooooo0000Uoooool0083ooooo0_l00002ooooo`03o`000?oooooo000002kooooo
00?o0000ooooooooool02oooool2o`0000Gooooo00Go0000ooooooooooooooooo`000002ooooo`03
o`000?oooooooooo09Cooooo0020ooooo`;o00000_ooool2o`0002Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool2o`000005
ooooool0003oooooooooool00000U_ooool007oooooo0_l00002ooooo`03o`000?oooooo000002So
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0>ooooo`;o00001Oooool00ol0003o
ooooo`000002ooooo`03o`000?oooooooooo09?ooooo001oooooo`;o00000_ooool00ol0003ooooo
o`00000Looooo`Ko00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo013ooooo
0_l00004ooooo`05o`000?oooooo0000ooooool00000UOooool007oooooo00Co0000oooooooooooo
oooo0_l0000Yooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Booooo`07o`000?oooooooooooooo
ool0003oooooo`000002ooooo`03o`000?oooooooooo09;ooooo001nooooo`;o00000_ooool00ol0
003oooooo`00000Vooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0C
ooooo`04o`000?ooooooooooooooo`;o00000_ooool00ol0003oooooooooo`2Booooo`00O_ooool2
o`0000;ooooo00?o0000ooooool000009_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2Aooooo`00O_ooool01_l0
003oooooooooool0003oooooo`0002Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0TOooool007gooooo0_l00002
ooooo`03o`000?oooooo000002Oooooo1?l00006ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`2@ooooo`00OOooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo093ooooo001mooooo`06o`000?ooooooooooo`000?oooooo0000<_oo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0T?oo
ool007cooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2@ooooo`00O?ooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo033ooooo0_l0000Hooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0T?ooool007cooooo00Ko0000oooooooooooo0000oooo
ool0000cooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2?ooooo`00Noooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08oooooo
001kooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Soooool007_ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`2?ooooo`00N_ooool2o`0000;ooooo00?o
0000ooooool00000=?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0Soooool007[ooooo00Oo0000ooooooooooooooooo`000?oooooo000003Cooooo
00?o0000ooooooooool06_ooool01Ol0003ooooooooooooooooo0000097ooooo001jooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Jooooo`05
o`000?ooooooooooooooool00000TOooool007Wooooo0_l00002ooooo`03o`000?oooooo000003Go
oooo00?o0000ooooooooool06_ooool01Ol0003ooooooooooooooooo0000097ooooo001iooooo`;o
00000_ooool00ol0003oooooo`00000eooooo`;o00006oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo08kooooo001iooooo`;o000000Goooooo`000?ooooooooooo`00000eooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2>ooooo`00
N?ooool01ol0003oooooo`000?oooooo0000ooooool00000=_ooool00ol0003oooooooooo`0Koooo
o`05o`000?ooooooooooooooool00000T?ooool007Sooooo0_l000001Ooooooo0000oooooooooooo
000003Kooooo00?o0000ooooooooool06oooool01Ol0003ooooooooooooooooo0000093ooooo001h
ooooo`;o000000Goooooo`000?ooooooooooo`00000fooooo`03o`000?oooooooooo01_ooooo00Go
0000ooooooooooooooooo`00002@ooooo`00Moooool01ol0003oooooo`000?oooooo0000ooooool0
0000=oooool00ol0003oooooooooo`0Kooooo`05o`000?ooooooooooooooool00000T?ooool007Oo
oooo00Oo0000ooooool0003oooooo`000?oooooo000003Oooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo08gooooo001gooooo`04o`000?oooooo0000
o`0000;ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0SOooool007Oooooo0_l000001?oooooo0000ooooool0000h
ooooo`;o00007?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo08gooooo001goooo
o`;o000000Coooooo`000?oooooo0000>?ooool00ol0003oooooooooo`0Looooo`05o`000?oooooo
ooooooooool00000Soooool007Kooooo00Oo0000ooooool0003oooooo`000?oooooo000003Sooooo
00?o0000ooooooooool07?ooool01Ol0003ooooooooooooooooo000008oooooo001fooooo`04o`00
0?oooooo0000ooooo`;o0000>Oooool00ol0003oooooooooo`0Looooo`05o`000?oooooooooooooo
ool00000Soooool007Kooooo00Ko0000ooooool0003o0000ooooool0000iooooo`03o`000?oooooo
oooo01cooooo00Go0000ooooooooooooooooo`00002?ooooo`00M_ooool01_l0003oooooo`000?l0
003oooooo`0003Wooooo00?o0000ooooooooool07?ooool01Ol0003ooooooooooooooooo000008oo
oooo001fooooo`;o000000Coooooo`000?oooooo0000>Oooool00ol0003oooooooooo`0Looooo`05
o`000?ooooooooooooooool00000Soooool007Kooooo0_l000000ooooooo0000o`00000jooooo`03
o`000?oooooooooo01cooooo00Go0000ooooooooooooooooo`00002?ooooo`00M_ooool2o`000003
ooooool0003o000003[ooooo00?o0000ooooooooool07?ooool01?l0003oooooooooool0002@oooo
o`00MOooool01_l0003oooooo`000?l0003oooooo`0003[ooooo0_l0000Nooooo`03o`000?oooooo
0000093ooooo001eooooo`03o`000?oooooo000000;o0000>oooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooo0000093ooooo001eooooo`03o`000?oooooo000000;o0000>oooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooo0000093ooooo001eooooo`;o000000?oooooo`000?l00000
>oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo0000093ooooo001eooooo`Co0000??oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooo0000093ooooo001eooooo`Co0000??ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooo0000093ooooo001dooooo`03o`000?oooooo0000
00;o00008Oooool5o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooo0000093ooooo001dooooo`04o`000?oooooo0000
o`0002;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q2?ooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo01gooooo00?o0000ooooool00000T?ooool007Cooooo00Co0000
ooooool0003o00006_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0003ooooooooo
o`03ooooo`?o00007?ooool01?l0003oooooooooool0002@ooooo`00M?ooool4o`0002Cooooo00?o
V9RHob4Q8Oo^k^h03oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01cooooo00Co
0000oooooooooooo0000T?ooool007Cooooo0ol0000Vooooo`03ogMgMomVIVKooooo00_ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo01cooooo00Co0000oooooooooooo
0000T?ooool007Cooooo0ol0000Wooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Looooo`04o`000?ooooooooooo`00093ooooo001cooooo`04o`00
0?oooooo0000o`0002?ooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool07?ooool01?l0003oooooooooool0002@ooooo`00Loooool00ol0
003oooooo`00000Tooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool4o`0000Kooooo00?o0000
ooooooooool07?ooool01?l0003oooooooooool0002@ooooo`00Loooool3o`0003oooooo00?o0000
ooooooooool07?ooool01?l0003oooooooooool0002@ooooo`00Loooool3o`0003oooooo00?o0000
ooooooooool06oooool01?l0003oooooooooool0002Aooooo`00Loooool3o`0003oooooo00?o0000
ooooooooool06oooool01?l0003oooooooooool0002Aooooo`00Loooool2o`00043ooooo0_l0000L
ooooo`04o`000?ooooooooooo`00097ooooo001cooooo`;o0000@?ooool00ol0003oooooooooo`0K
ooooo`04o`000?ooooooooooo`00097ooooo001booooo`03o`000?oooooo0000043ooooo00?o0000
ooooooooool06oooool01?l0003oooooooooool0002Aooooo`00L_ooool3o`00043ooooo00?o0000
ooooooooool06oooool01?l0003oooooooooool0002Aooooo`00L_ooool3o`00043ooooo00?o0000
ooooooooool06oooool01?l0003oooooooooool0002Aooooo`00L_ooool2o`00047ooooo00?o0000
ooooooooool06_ooool01Ol0003ooooooooooooooooo0000097ooooo001booooo`;o0000@Oooool0
0ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool00000TOooool007;ooooo0_l00011
ooooo`03o`000?oooooooooo01[ooooo00Go0000ooooooooooooooooo`00002Aooooo`00LOooool0
0ol0003oooooo`000011ooooo`;o00006oooool01?l0003oooooooooool0002Booooo`00LOooool3
o`00047ooooo00?o0000ooooooooool06_ooool01?l0003oooooooooool0002Booooo`00LOooool3
o`00047ooooo00?o0000ooooooooool06_ooool01?l0003oooooooooool0002Booooo`00LOooool3
o`00047ooooo00?o0000ooooooooool06_ooool00ol0003oooooo`00002Cooooo`00LOooool2o`00
04;ooooo00?o0000ooooooooool06Oooool01?l0003oooooooooool0002Cooooo`00LOooool2o`00
04;ooooo00?o0000ooooooooool06Oooool01?l0003oooooooooool0002Cooooo`00L?ooool00ol0
003oooooo`000012ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooool00000U?ooool0073o
oooo0ol00012ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooool00000U?ooool0073ooooo
0ol00012ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooool00000U?ooool0073ooooo0ol0
0012ooooo`;o00006Oooool00ol0003oooooo`00002Eooooo`00L?ooool3o`0004;ooooo00?o0000
ooooooooool05oooool01?l0003oooooooooool0002Eooooo`00L?ooool2o`0004?ooooo00?o0000
ooooooooool05oooool01?l0003oooooooooool0002Eooooo`00L?ooool2o`0004?ooooo00?o0000
ooooooooool05_ooool01?l0003oooooooooool0002Fooooo`002Oooool4o`000008oa0@4?oooooo
ooooonk^k_lb<S;o0000oc8b<_o^k^hKooooo`03o`000?o^k^kooooo00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd07_ooool01Om4A4Co0000o`000?lb<S;ogMgM00Sooooo0ol0000A
ooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Looooo`03o`000?oo
oooooooo01Kooooo00Co0000oooooooooooo00000_ooool5o`0000Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd07_ooool01Om4A4Co0000o`000?lb<S;ogMgM01kooooo00?o0000onk^
k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Jooooo`Co000000So410@
ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo000;ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`03oeEEEOnYZJWooooo00Gooooo0_lQ8B48ooooo`03
ogMgMolb<S;ooooo023ooooo00?oMgMgoc8b<_ooool01oooool3o`00017ooooo00GoV9RHob4Q8Oo^
k^koooooodA4A005ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`03o`000?oooooooooo
01Gooooo00Go0000ooooooooooooooooo`000002ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Ooo
ool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool08?ooool00omgMgOo<S8booooo`0Mooooo`03oeEEEOnY
ZJWooooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01_ooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0006o`0000Gooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@017ooooo1_l00004ooooo`03ojVYZOmEEEGooooo013ooooo
00?o0000ooooooooool04oooool6o`0000Oooooo00?o0000ooooooooool01_ooool3o`0000Wooooo
1_l00003ooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Dooooo`05o`000?ooooooooooooooool000001?ooool00onHV9So8B4Qonk^kP0Aooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool07?ooool00onYZJWoEEEEooooo`0@ooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@
00?ooooo000;ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Loooo
o`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool08?ooool00omgMgOo<S8booooo`07oooo
o`?o00004oooool00onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;ooooo01_ooooo00?o0000oooo
ooooool05?ooool01Ol0003ooooooooooooooooo000000Gooooo00?oV9RHob4Q8Oo^k^h03oooool0
0omgMgOo<S8booooo`0Pooooo`03ogMgMolb<S;ooooo01kooooo00?o8B4Qooooooooool03_ooool0
0omgMgOo<S8booooo`0Kooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`002oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007?oo
ool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`07_ooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Sooooo0ol0000Dooooo`03ogMgMomVIVKooooo00_ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c00Looooo`;o00005?ooool01Ol0003ooooooooooooooooo000000Oooooo00?oMgMg
ofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01kooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00Oooooo`03oeEEEOo<c<cooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Looooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`002oooool00ol0003o
ooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41007?ooool00onYZJWoMgMgooooo`0;oooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool02_ooool3o`0001Gooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`0Qooooo`03ojVYZOmgMgOooooo00_ooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool0
00_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Wooooo00Go410@
oooooooooooooooooc8b<P0<ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool02_oo
ool3o`00017ooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool04_ooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000okZj^_oo
ooooV9RHoa0@400<ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool07_ooool01Ol@
413ooooooooooooooooo<S8b00cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool000Wooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^01Wooooo1Ol0000<ooooo`Co00007oooool4o`0000Wooooo0ol0
000Aooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool4o`0001gooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c00<ooooo`Co00007oooool4o`0001gooooo1Ol0000<ooooo`Co00006oooool00omEEEGo
IVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool006oooooo0_l00014ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Hooooo`00
K_ooool3o`0004Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo09Sooooo001^ooooo`?o0000A?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0VOooool006kooooo0ol00014ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Iooooo`00K_ooool3o`00
04Cooooo00?o0000ooooooooool03_ooool01?l0003oooooooooooooool2o`0009cooooo000;oooo
oooo0000E_l00008ooooo`002oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool4o`0000Oooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooo000000?o00000oooool00ol0003oooooo`000005ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`00
2oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
2oooool3o`0001Wooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`03ooooo`Co0000
1oooool2o`0001Oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool01_ooool006kooooo0ol00014ooooo`03o`000?oo
oooo000000?o00002_ooool00ol0003oooooooooo`2Pooooo`00K_ooool2o`0004?ooooo1?l0000=
ooooo`03o`000?oooooooooo0:7ooooo001^ooooo`;o0000?_ooool5o`0000;ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`2Rooooo`00K_ooool2o`0003Wooooo1Ol00007ooooo`03
o`000?oooooooooo00Gooooo1_l0002Uooooo`00KOooool3o`0003Oooooo0_l00003oooooa7o0000
Zoooool006gooooo0ol0000fooooo`04o`000?ooooooooooooooo`;o00002Oooool00ol0003ooooo
ooooo`2`ooooo`00KOooool3o`0003Gooooo00?o0000ooooooooool00_l0000;ooooo`;o0000/Ooo
ool006gooooo0ol0000dooooo`04o`000?oooooo0000o`0000gooooo00?o0000ooooooooool0/?oo
ool006gooooo0ol0000cooooo`03o`000?oooooo000000oooooo00?o0000ooooooooool0/?ooool0
06gooooo0ol0000booooo`03o`000?oooooo0000013ooooo00?o0000ooooooooool0/?ooool006go
oooo0_l0000booooo`03o`000?oooooo0000017ooooo00?o0000ooooooooool0/?ooool006gooooo
0_l0000aooooo`03o`000?oooooo000001;ooooo00?o0000ooooooooool0/?ooool006gooooo0_l0
000`ooooo`03o`000?oooooo000001?ooooo00?o0000ooooooooool0/?ooool006gooooo0_l0000_
ooooo`03o`000?oooooo000001Cooooo00?o0000ooooooooool0/?ooool006gooooo0_l0000^oooo
o`03o`000?oooooo000001Gooooo0_l0002aooooo`00K?ooool3o`0002kooooo0_l0000Fooooo`03
o`000?oooooooooo0;3ooooo001/ooooo`?o0000;Oooool00ol0003oooooo`00000Fooooo`03o`00
0?oooooooooo0;3ooooo001/ooooo`?o0000;Oooool2o`0001Oooooo00?o0000ooooooooool0/?oo
ool006cooooo00?o0000ooooool00000;Oooool2o`0001Oooooo00?o0000ooooooooool0/?ooool0
06cooooo0_l0000]ooooo`03o`000?oooooo000001Oooooo00?o0000ooooooooool0/?ooool006co
oooo0_l0000]ooooo`;o00006?ooool00ol0003oooooooooo`2`ooooo`00K?ooool2o`0002gooooo
0_l0000Hooooo`03o`000?oooooooooo0;3ooooo001/ooooo`;o0000;?ooool00ol0003oooooo`00
000Hooooo`03o`000?oooooooooo0;3ooooo001/ooooo`;o0000;?ooool2o`0001Wooooo0_l0002a
ooooo`00K?ooool2o`0002cooooo0_l0000Iooooo`03o`000?oooooooooo0;3ooooo001/ooooo`;o
0000:oooool00ol0003oooooo`00000Iooooo`03o`000?oooooooooo0;3ooooo001/ooooo`;o0000
:oooool2o`0001[ooooo00?o0000ooooooooool0/?ooool006_ooooo00?o0000ooooool00000:ooo
ool2o`0001[ooooo00?o0000ooooooooool0/?ooool006_ooooo00?o0000ooooool00000:_ooool0
0ol0003oooooo`00000Jooooo`03o`000?oooooooooo0;3ooooo001[ooooo`03o`000?oooooo0000
02[ooooo00?o0000ooooool000006_ooool00ol0003oooooooooo`2`ooooo`00Joooool2o`0002_o
oooo0_l0000Kooooo`03o`000?oooooooooo0;3ooooo001[ooooo`;o0000:oooool2o`0001_ooooo
0_l0002aooooo`00Joooool2o`0002_ooooo0_l0000Kooooo`03o`000?oooooooooo0;3ooooo001[
ooooo`;o0000:_ooool00ol0003oooooo`00000Kooooo`03o`000?oooooooooo0;3ooooo001[oooo
o`;o0000:_ooool00ol0003oooooo`00000Kooooo`03o`000?oooooooooo0;3ooooo001[ooooo`;o
0000:_ooool2o`0001cooooo00?o0000ooooooooool0/?ooool006_ooooo0_l0000Zooooo`;o0000
7?ooool00ol0003oooooooooo`2`ooooo`00Joooool2o`0002[ooooo0_l000000ooooooo0000o`00
0003o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`2`ooooo`00J_ooool00ol0003oooooo`00000Zooooo`;o000000KooooooiRHV?lQ8B7ok^k^
oooooom4A4@5ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3o
oooo001Zooooo`03o`000?oooooo000002[ooooo0_l00002ooooo`03oiRHV?lQ8B7ok^k^017ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`2`ooooo`00J_ooool00ol0003oooooo`00
000Yooooo`;o00001?ooool00onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0
002`ooooo`00J_ooool00ol0003oooooo`00000Yooooo`;o00001Oooool00omgMgOoIVIVooooo`0;
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`ooooo`00J_ooool0
0ol0003oooooo`00000Yooooo`;o00001_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0/?ooool006[ooooo00?o0000ooooool00000:Oooool2o`00
00;ooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0/?ooool006[ooooo0_l0000Zooooo`;o00000_ooool01OnHV9So410@o`000?lQ8B7o
c<c<00cooooo1?l00006ooooo`03o`000?oooooooooo0;3ooooo001Zooooo`;o0000:_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo0;3ooooo001Zooooo`;o0000:_ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo0;3ooooo001Zooooo`;o0000:_ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo0;3ooooo001Zooooo`;o0000:Oooool2o`0001kooooo0_l0
002aooooo`00J_ooool2o`0002Wooooo0_l0000Nooooo`03o`000?oooooooooo0;3ooooo001Zoooo
o`;o0000:Oooool2o`0001kooooo00?o0000ooooooooool0/?ooool006[ooooo0_l0000Yooooo`;o
00007_ooool00ol0003oooooooooo`2`ooooo`00J_ooool2o`0002Wooooo0_l0000Nooooo`03o`00
0?oooooooooo0;3ooooo001Zooooo`;o0000:Oooool2o`0001kooooo00?o0000ooooooooool0/?oo
ool006[ooooo0_l0000Yooooo`;o00007_ooool00ol0003oooooooooo`2`ooooo`00J_ooool2o`00
02Wooooo0_l0000Nooooo`03o`000?oooooooooo0;3ooooo001Yooooo`03o`000?oooooo000002Wo
oooo0_l0000Nooooo`03o`000?oooooooooo0;3ooooo001Yooooo`03o`000?oooooo000002Wooooo
0_l0000Nooooo`;o0000/Oooool006Wooooo0_l0000Zooooo`;o00007_ooool00ol0003ooooooooo
o`2`ooooo`00JOooool2o`0002[ooooo0_l0000Nooooo`03o`000?oooooooooo0;3ooooo001Yoooo
o`;o0000:_ooool2o`0001kooooo00?o0000ooooooooool0/?ooool006Wooooo0_l0000Zooooo`;o
00007_ooool00ol0003oooooooooo`2`ooooo`00JOooool2o`0002[ooooo0_l0000Nooooo`03o`00
0?oooooooooo0;3ooooo001Yooooo`;o0000:_ooool2o`0001kooooo00?o0000ooooooooool0/?oo
ool006Wooooo0_l0000Zooooo`;o00007_ooool00ol0003oooooooooo`2`ooooo`00JOooool2o`00
02[ooooo0_l0000Nooooo`;o0000/Oooool006Wooooo0_l0000Zooooo`;o00007_ooool00ol0003o
ooooooooo`2`ooooo`00JOooool2o`0002_ooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`2`ooooo`00JOooool2o`0004[ooooo00?o0000ooooooooool0/?ooool006Wooooo0_l0001:
ooooo`03o`000?oooooooooo0;3ooooo001Yooooo`;o0000B_ooool00ol0003oooooooooo`2`oooo
o`00JOooool2o`0004[ooooo00?o0000ooooooooool0/?ooool006Wooooo0_l0001:ooooo`03o`00
0?oooooooooo0;3ooooo001Yooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0/?oo
ool006Wooooo00?o0000ooooooooool0BOooool2o`000;7ooooo001Yooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool0/?ooool006Wooooo00?o0000ooooooooool0BOooool00ol0003o
ooooooooo`2`ooooo`00JOooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo0;3ooooo
001Yooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0/?ooool006Wooooo00?o0000
ooooooooool0BOooool00ol0003oooooooooo`2`ooooo`00JOooool00ol0003oooooooooo`0ooooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00J?ooool2o`00
04Cooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00J?ooool2o`0004Go
oooo00?o0000ooooooooool00oooool3o`000;3ooooo001Xooooo`;o0000A?ooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo0;3ooooo001Xooooo`;o0000@Oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool006Sooooo0_l00011ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0/?ooool006Sooooo0_l00011ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0/?ooool006Sooooo0_l00011ooooo`Co00001_ooool00ol0
003oooooooooo`2`ooooo`00J?ooool2o`0004_ooooo00?o0000ooooooooool0/?ooool006Sooooo
0_l0001;ooooo`03o`000?oooooooooo0;3ooooo001Xooooo`;o0000Boooool00ol0003ooooooooo
o`2`ooooo`00J?ooool2o`0004_ooooo0_l0002aooooo`00J?ooool2o`0004_ooooo00?o0000oooo
ooooool0/?ooool006Sooooo0_l0001;ooooo`03o`000?oooooooooo0;3ooooo001Xooooo`;o0000
Boooool00ol0003oooooooooo`2`ooooo`00J?ooool00ol0003oooooooooo`1:ooooo`03o`000?oo
oooooooo0;3ooooo001Xooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0/?ooool0
06Sooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`2`ooooo`00J?ooool00ol0003o
ooooooooo`1:ooooo`03o`000?oooooooooo0;3ooooo001Xooooo`03o`000?oooooooooo04[ooooo
0_l0002aooooo`00J?ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo0;3ooooo001X
ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0/?ooool006Sooooo00?o0000oooo
ooooool0B_ooool00ol0003oooooooooo`2`ooooo`00J?ooool00ol0003oooooooooo`1:ooooo`03
o`000?oooooooooo0;3ooooo001Xooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0
/?ooool006Sooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`2`ooooo`00J?ooool0
0ol0003oooooooooo`1:ooooo`03o`000?oooooooooo0;3ooooo001Xooooo`03o`000?oooooooooo
04[ooooo00?o0000ooooooooool0/?ooool006Sooooo00?o0000ooooooooool0B_ooool2o`000;7o
oooo001Xooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0/?ooool006Sooooo00?o
0000ooooooooool0B_ooool00ol0003oooooooooo`2`ooooo`00Ioooool2o`0004cooooo00?o0000
ooooooooool0/?ooool006Oooooo0_l0001<ooooo`03o`000?oooooooooo0;3ooooo001Wooooo`;o
0000C?ooool00ol0003oooooooooo`2`ooooo`00Ioooool2o`0004cooooo00?o0000ooooooooool0
/?ooool006Oooooo0_l0001<ooooo`03o`000?oooooooooo0;3ooooo001Wooooo`;o0000C?ooool2
o`000;7ooooo001Wooooo`;o0000C?ooool00ol0003oooooooooo`2`ooooo`00Ioooool2o`0004co
oooo00?o0000ooooooooool0/?ooool006Oooooo0_l0001<ooooo`03o`000?oooooooooo0;3ooooo
001Wooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0/?ooool006Oooooo00?o0000
ooooooooool0Boooool00ol0003oooooooooo`2`ooooo`00Ioooool00ol0003oooooooooo`0boooo
o`03o`000?o^k^kooooo00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`2`ooooo`00Ioooool00ol0003oooooooooo`0booooo`03oeEEEOnYZJWooooo
00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool006Oo
oooo00?o0000ooooooooool0<_ooool00onYZJWoEEEEooooo`0@ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0/?ooool006Oooooo00?o0000ooooooooool0<oooool00olQ8B7ooooo
ooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00Ioooool00ol0003ooooooooo
o`0cooooo`03oeEEEOo<c<cooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo001Wooooo`03o`000?oooooooooo03?ooooo00?oZJVYogMgMoooool02ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo001Wooooo`03o`000?oooooo
oooo033ooooo00Go410@oooooooooooooooooc8b<P0<ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0/?ooool006Oooooo00?o0000ooooooooool0<?ooool5o`0000cooooo1?l00006
ooooo`03o`000?oooooooooo0;3ooooo001Wooooo`03o`000?oooooooooo04_ooooo00?o0000oooo
ooooool0/?ooool006Oooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`2`ooooo`00
Ioooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo0;3ooooo001Wooooo`03o`000?oo
oooooooo04_ooooo0_l0002aooooo`00Ioooool00ol0003oooooooooo`1;ooooo`03o`000?oooooo
oooo0;3ooooo001Wooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0/?ooool006Oo
oooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`2`ooooo`00Ioooool00ol0003ooooo
ooooo`1;ooooo`03o`000?oooooooooo0;3ooooo001Wooooo`03o`000?oooooooooo04_ooooo00?o
0000ooooooooool0/?ooool006Oooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`2`
ooooo`00Ioooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo0;3ooooo001Wooooo`03
o`000?oooooooooo04_ooooo00?o0000ooooooooool0/?ooool006Oooooo00?o0000ooooooooool0
Boooool2o`000;7ooooo001Wooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0/?oo
ool006Oooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00:?ooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^1_ooool00ol0003oooooooooo`2`ooooo`00YOooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`2`ooooo`00YOoo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool3o`000;3ooooo
002Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00002iooooo`00YOoo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000^Oooool00:Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@0;Wooooo002Uooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`2iooooo`00Xoooool00omEEEGoIVIVo`00
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0^Oooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-10, -10, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.05 0.5 0.05 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-10)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-7.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-2.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(2.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(7.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(10)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-10)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-7.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-2.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(2.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(7.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(10)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.42676 .69678 m
.43096 .71078 L
.43425 .7182 L
.4361 .72113 L
.43637 .72054 L
.43514 .71667 L
.43269 .70915 L
.42951 .69705 L
.42641 .67891 L
.42468 .65315 L
.42627 .61931 L
.434 .58055 L
.45102 .54645 L
.47895 .52913 L
.51476 .52712 L
.55015 .5167 L
.57644 .47855 L
.59022 .42147 L
.59336 .36621 L
.5895 .32474 L
.58177 .29834 L
.57223 .28347 L
.56208 .27599 L
.55203 .27265 L
.54253 .27134 L
.53392 .2709 L
.52645 .27075 L
.52036 .27073 L
.51583 .27082 L
.51298 .27109 L
.51183 .27159 L
.51234 .27234 L
.51437 .27332 L
.51767 .2745 L
.52197 .27582 L
.52689 .27727 L
.53202 .27883 L
.53694 .28055 L
.54112 .28242 L
.54404 .2844 L
.54508 .28628 L
.54347 .28785 L
.5382 .28901 L
.52778 .28967 L
.50985 .28891 L
.48048 .284 L
.43384 .27974 L
.36942 .35055 L
.31834 .67844 L
s
.31834 .67844 m
.32027 1 L
s
.31457 1 m
.31038 .94076 L
.31587 .64532 L
.32828 .50719 L
.3281 .508 L
.3179 .61264 L
.3096 .80089 L
s
.3096 .80089 m
.31229 1 L
s
.31712 1 m
.31578 .96393 L
.31491 .92903 L
.3145 .90283 L
.31431 .88331 L
.31423 .86737 L
.31422 .85096 L
.31433 .82921 L
.31479 .79635 L
.31612 .74613 L
.3195 .6729 L
.32711 .57503 L
.3422 .4618 L
.36803 .359 L
.40493 .29772 L
.44819 .28412 L
.49068 .29278 L
.52786 .29995 L
.55845 .30717 L
.58038 .33794 L
.58513 .41418 L
.55888 .49838 L
.50533 .52081 L
.45611 .53364 L
.43007 .5814 L
.42209 .6341 L
.42288 .67265 L
.42676 .69678 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00Xoooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^jiooooo`00YOooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0^Ooo
ool009[ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
402iooooo`00YOooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_oo
ool3o`000;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0;3ooooo002S
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool009cooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Looooo`03oeEEEOnYZJWo
oooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool0
09;ooooo1_l00004ooooo`03ojVYZOmEEEGooooo013ooooo00?o0000ooooooooool00oooool3o`00
0;3ooooo002Mooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`2`ooooo`00WOooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`2`ooooo`00WOooool00onYZJWoMgMgooooo`0;ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooo
oc8b<P0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo1Ol0
000<ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002[ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`2`ooooo`00[_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002R
ooooo`Ko00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002^oooo
o`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00Zoooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool0/?ooool00:_ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2`ooooo`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo
002[ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool01?l0003oooooooooooooool=o`00
0:;ooooo002eooooo`;o00000_ooool3o`0000[ooooo1?l0002Nooooo`00]Oooool00ol0003ooooo
ooooo`04ooooo`Co00002_ooool2o`0009cooooo002Nooooo`Go00004_ooool00ol0003ooooooooo
o`08ooooo`?o00002Oooool00ol0003oooooooooo`2Iooooo`00W_ooool00ol0003oooooooooo`02
ooooo`So00002_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0V?ooool009gooooo00Co0000oooooooooooooooo1ol00003ooooo`Wo000000?ooooo
o`000?ooool03Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo09Sooooo002Loooo
o`03o`000?oooooo000000;o00001oooool7o`0000Gooooo4Ol00009ooooo`03o`000?oooooooooo
09Oooooo002Jooooo`Co00004Oooool7o`0001Wooooo00?o0000ooooooooool0U_ooool009Oooooo
1?l0000Jooooo`Co00005oooool00ol0003oooooooooo`2Eooooo`00UOooool2o`0000;ooooo00?o
0000ooooooooool06Oooool01?l0003oooooooooooooool4o`0001Cooooo00?o0000ooooooooool0
U?ooool009Gooooo00Co0000oooooooooooo00007?ooool2o`0000Kooooo1Ol0000?ooooo`03o`00
0?oooooooooo09Cooooo002Dooooo`04o`000?ooooooooooo`0001gooooo00?o0000ooooooooool0
2_ooool5o`0000[ooooo00?o0000ooooooooool0U?ooool009?ooooo00Co0000oooooooooooo0000
7_ooool00ol0003oooooooooo`0?ooooo`?o00002?ooool00ol0003oooooooooo`2Cooooo`00Tooo
ool00ol0003oooooo`00000Oooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`2Cooooo`00T_ooool00ol0003oooooo`00000Pooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Cooooo`00T_ooool2o`00
027ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
09?ooooo002Aooooo`03o`000?oooooo0000027ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo09?ooooo002@ooooo`03o`000?oooooo000002;ooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo09;ooooo
002@ooooo`;o00008oooool2o`0001Kooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`2Booooo`00Soooool2o`0002Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo09;ooooo002>ooooo`;o00009Oooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0T_ooool008kooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0T_ooool008gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0TOooool008cooooo0_l0000Wooooo`03o`000?oo
oooooooo01Sooooo00Go0000ooooooooooooooooo`00002Cooooo`00Roooool2o`0002Sooooo00?o
0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000009?ooooo002:ooooo`;o0000:Ooo
ool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool00000Toooool008Wooooo00?o
0000ooooool00000:Oooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool00000
Toooool008Sooooo00?o0000ooooool00000:_ooool2o`0001Wooooo00Go0000oooooooooooooooo
o`00002Cooooo`00R?ooool00ol0003oooooo`00000Zooooo`03o`000?oooooooooo01Sooooo00Go
0000ooooooooooooooooo`00002Cooooo`00R?ooool2o`0002_ooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo093ooooo0028ooooo`03o`000?oooooo
oooo02[ooooo00?o0000ooooooooool06Oooool01Ol0003ooooooooooooooooo000009;ooooo0027
ooooo`;o0000;?ooool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool00000T_oo
ool008Oooooo0_l0000/ooooo`03o`000?oooooooooo01Wooooo00Go0000ooooooooooooooooo`00
002Booooo`00Qoooool00ol0003oooooooooo`0@ooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01Wooooo00Go0000oooooooooooooooo
o`00002Booooo`00Qoooool00ol0003oooooooooo`0@ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Iooooo`05o`00
0?ooooooooooooooool00000T_ooool008Oooooo00?o0000ooooooooool02?ooool6o`0000?ooooo
00?oV9RHob4Q8Oo^k^h04Oooool00ol0003oooooooooo`03ooooo`?o00006Oooool01Ol0003ooooo
oooooooooooo000009;ooooo0027ooooo`03o`000?oooooooooo01;ooooo00?oV9RHob4Q8Oo^k^h0
3oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01Wooooo00Go0000oooooooooooo
ooooo`00002Booooo`00Q_ooool2o`0001Gooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool06Oooool01Ol0003ooooooooooooooooo0000
09;ooooo0026ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo01Wooooo00Go0000ooooooooooooooooo`00002Boooo
o`00Q_ooool00ol0003oooooooooo`0Aooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo01Wooooo00Go0000ooooooooooooooooo`00002B
ooooo`00Q_ooool00ol0003oooooooooo`0Aooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool4
o`0000Kooooo00?o0000ooooooooool06Oooool01Ol0003ooooooooooooooooo000009;ooooo0025
ooooo`;o0000;_ooool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool00000T_oo
ool008Gooooo0_l0000^ooooo`03o`000?oooooooooo01Wooooo00Co0000oooooooooooo0000Tooo
ool008Gooooo0_l0000^ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooool00000Toooool0
08Gooooo00?o0000ooooooooool0;Oooool2o`0001_ooooo00?o0000ooooool00000Toooool008Co
oooo0_l0000_ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooool00000Toooool008Cooooo
0_l0000_ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooool00000Toooool008Cooooo0_l0
000_ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooool00000Toooool008?ooooo00?o0000
ooooool00000;oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo000009?ooooo0023oooo
o`03o`000?oooooo000002oooooo00?o0000ooooooooool06_ooool00ol0003oooooo`00002Coooo
o`00Poooool00ol0003oooooo`00000_ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooool0
0000Toooool008?ooooo0_l0000`ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooool00000
Toooool008;ooooo00?o0000ooooool00000<?ooool2o`0001[ooooo00Co0000oooooooooooo0000
Toooool008;ooooo00?o0000ooooool00000<?ooool00ol0003oooooooooo`0Iooooo`04o`000?oo
ooooooooo`0009?ooooo0022ooooo`03o`000?oooooo0000033ooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooo`00002Dooooo`00P_ooool00ol0003oooooo`00000`ooooo`03o`000?oooooo
oooo01Sooooo00Co0000oooooooooooo0000U?ooool0087ooooo00Co0000oooooooooooo0000<?oo
ool00ol0003oooooooooo`0Hooooo`04o`000?ooooooooooo`0009Cooooo0021ooooo`04o`000?oo
ooooooooo`00033ooooo00?o0000ooooooooool06?ooool01?l0003oooooooooool0002Dooooo`00
POooool00ol0003oooooo`00000aooooo`03o`000?oooooooooo01Oooooo00Co0000oooooooooooo
0000UOooool0087ooooo00?o0000ooooool00000<Oooool00ol0003oooooooooo`0Gooooo`04o`00
0?ooooooooooo`0009Gooooo0020ooooo`04o`000?ooooooooooo`00037ooooo00?o0000oooooooo
ool05oooool01?l0003oooooooooool0002Eooooo`00P?ooool01?l0003oooooooooool0000aoooo
o`;o00005oooool01Ol0003ooooooooooooooooo000009Gooooo0020ooooo`04o`000?oooooooooo
o`00037ooooo00?o0000ooooooooool05_ooool01?l0003oooooooooool0002Fooooo`00P?ooool0
1?l0003oooooooooool0000aooooo`03o`000?oooooooooo01Kooooo00Co0000oooooooooooo0000
U_ooool007oooooo00Co0000oooooooooooo0000<_ooool00ol0003oooooooooo`0Eooooo`05o`00
0?ooooooooooooooool00000U_ooool000Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^6oooool00ol0003ok^k^ooooo`05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM01kooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`03o`000?oooooooooo00Ko0000
1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Looooo`03o`000?oooooooooo01Go
oooo00Go0000ooooooooooooooooo`000002ooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@0Nooooo`05odA4A?l0003o0000oc8b<_oMgMd07_ooool00ol0003ok^k^oooo
o`05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01[ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool000_ooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg01_ooooo00?oEEEEojVYZOooool01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool08?ooool00omgMgOo<S8booooo`0Gooooo`09o`000?ooooooooooo`000?nHV9So8B4Q
onk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01_ooooo00?o0000oooooooo
ool05Oooool01?l0003oooooooooool00003ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2
ob4Q8@Sooooo00?oMgMgoc8b<_ooool08?ooool00omgMgOo<S8booooo`0Mooooo`03oeEEEOnYZJWo
oooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01_ooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0006o`0000Gooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@017ooooo1_l00004ooooo`03ojVYZOmEEEGooooo013ooooo00?o
0000ooooooooool04oooool6o`0000Oooooo00?o0000ooooooooool04_ooool6o`000006ooooool0
003ooooooiRHV?lQ8B7ok^k^4Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Co
oooo00Go0000ooooooooooooooooo`000004ooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`0Looooo`03ojVYZOmEEEGooooo013ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool0
00_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001cooooo00?o8B4Q
ooooooooool03_ooool00omgMgOo<S8booooo`0Pooooo`03ogMgMolb<S;ooooo01Oooooo00Co0000
oooooooooooo00000_ooool00onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;ooooo01_ooooo00?o
0000ooooooooool05?ooool01Ol0003ooooooooooooooooo000000Gooooo00?oV9RHob4Q8Oo^k^h0
3oooool00omgMgOo<S8booooo`0Pooooo`03ogMgMolb<S;ooooo01kooooo00?o8B4Qooooooooool0
3_ooool00omgMgOo<S8booooo`0Kooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`002oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00007?ooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`07_ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<01Sooooo00Co0000oooooooooooo00000oooool00omgMgOoIVIVoooo
o`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`07?ooool2o`0001Gooooo00Go0000oooooooooooo
ooooo`000006ooooo`03ogMgMomVIVKooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Noooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`07oooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`07?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
0oooool000_ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01cooooo
00?oZJVYogMgMoooool02oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01Wooooo
00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0Cooooo`05o`000?ooooooooooooooool000002?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08Oooool00onY
ZJWoMgMgooooo`0;ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@00?ooooo000;ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Iooooo`05oa0@4?oooooooooooooooolb<S803?ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo01Wooooo00[o0000oooooooooooo0000ooooool0003o^[Zjoooo
oonHV9So410@3?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01?ooooo00Go0000
ooooooooooooooooo`000004ooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo01kooooo00Go410@oooooooooooooooooc8b<P0<ooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo0009ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Ioooo
o`Go00003?ooool4o`0001oooooo1?l0000Hooooo`0:o`000?ooooooooooo`000?ooooooV9RHoa0@
4?l0003o8B4Qolc<c0cooooo1?l0000Mooooo`03o`000?oooooooooo01?ooooo00Go0000oooooooo
ooooooooo`000004ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool4o`0001oooooo1?l0000M
ooooo`Go00003?ooool4o`0001_ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo001nooooo`04o`000?ooooooooooo`0003?ooooo00?o0000ooooooooool04_oo
ool01Ol0003ooooooooooooooooo000009Wooooo001nooooo`04o`000?ooooooooooo`0003?ooooo
00?o0000ooooooooool04_ooool01?l0003oooooooooool0002Jooooo`00O_ooool01?l0003ooooo
ooooool0000cooooo`03o`000?oooooooooo01;ooooo00Co0000oooooooooooo0000V_ooool007ko
oooo00Co0000oooooooooooo0000<oooool00ol0003oooooooooo`0Aooooo`04o`000?oooooooooo
o`0009_ooooo001nooooo`03o`000?oooooo000003Cooooo00?o0000ooooooooool04?ooool2o`00
0003ooooool0003ooooo09_ooooo000;oooooooo0000E_l00008ooooo`002oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooo`000007ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo1?l00003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo000;ooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Gooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
00Wooooo0_l00006ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_ooool007[o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
00Oooooo0_l00007ooooo`03o`000?oooooooooo09gooooo001jooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`05ooooo`;o00002Oooool00ol0
003oooooooooo`2Mooooo`00N_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool00_ooool3o`0000[ooooo00?o0000ooooooooool0W_ooool007[o
oooo00Ko0000oooooooooooo0000ooooool0000eooooo`03o`000?oooooooooo00;o00002_ooool3
o`000:7ooooo001jooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool0<oooool3o`00
00Sooooo1?l0002Tooooo`00N_ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo02oo
oooo1Ol00006ooooo`Co0000Z?ooool007Wooooo0_l000001Ooooooo0000oooooooooooo000002co
oooo1Ol00003ooooo`So0000[?ooool007Wooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0Vooooo`Co000000?oooooo`000?l000001Ol000000ooooooo0000ooooo`2aooooo`00
NOooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo02Cooooo0_l00003ooooo`;o
00002?ooool00ol0003oooooooooo`2`ooooo`00NOooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo02Cooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo
0;3ooooo001iooooo`06o`000?ooooooooooo`000?oooooo00009_ooool00ol0003oooooooooo`02
o`0000_ooooo00?o0000ooooooooool0/?ooool007Wooooo00Ko0000oooooooooooo0000ooooool0
000Vooooo`?o00003Oooool00ol0003oooooooooo`2`ooooo`00NOooool00ol0003oooooo`000002
ooooo`03o`000?oooooooooo02?ooooo0_l0000?ooooo`03o`000?oooooooooo0;3ooooo001ioooo
o`03o`000?oooooo000000;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo0;3ooooo001iooooo`03o`000?oooooo000000;ooooo00?o0000oooooooo
ool08_ooool2o`00013ooooo0_l0002aooooo`00NOooool00ol0003oooooo`000002ooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2`ooooo`00NOoo
ool01Ol0003oooooo`000?oooooo000002Cooooo0_l0000Aooooo`03o`000?oooooooooo0;3ooooo
001iooooo`05o`000?oooooo0000ooooool000008oooool2o`0001;ooooo00?o0000ooooooooool0
/?ooool007Sooooo00Ko0000oooooooooooo0000ooooool0000Sooooo`;o00004_ooool00ol0003o
ooooooooo`2`ooooo`00N?ooool01_l0003oooooooooool0003oooooo`0002;ooooo0_l0000Coooo
o`03o`000?oooooooooo0;3ooooo001hooooo`03o`000?oooooo000000;ooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0;3ooooo001hooooo`03o`00
0?oooooo000000;ooooo00?o0000ooooooooool07oooool2o`0001Cooooo00?o0000ooooooooool0
/?ooool007Sooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0/?ooool007Sooooo00Go0000ooooool0003oooooo`00
000Qooooo`;o00005Oooool2o`000;7ooooo001hooooo`05o`000?oooooo0000ooooool000008Ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0;3ooooo001hooooo`05o`000?oooooo
0000ooooool000008?ooool2o`0001Kooooo00?o0000ooooooooool0/?ooool007Sooooo00Go0000
ooooool0003oooooo`00000Pooooo`;o00005_ooool00ol0003oooooooooo`2`ooooo`00N?ooool0
1Ol0003oooooo`000?oooooo0000023ooooo0_l0000Fooooo`03o`000?oooooooooo0;3ooooo001h
ooooo`05o`000?oooooo0000ooooool000008?ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo0;3ooooo001gooooo`?o000000?oooooo`000?ooool07oooool2o`0001Oooooo00?o0000
ooooooooool0/?ooool007Oooooo00Go0000ooooool0003oooooo`00000Pooooo`;o00005oooool0
0ol0003oooooooooo`2`ooooo`00Moooool01Ol0003oooooo`000?oooooo0000023ooooo0_l0000G
ooooo`;o0000/Oooool007Oooooo00Go0000ooooool0003oooooo`00000Pooooo`;o00005oooool0
0ol0003oooooooooo`2`ooooo`00Moooool01Ol0003oooooo`000?oooooo0000023ooooo0_l0000G
ooooo`03o`000?oooooooooo0;3ooooo001gooooo`05o`000?oooooo0000ooooool000008?ooool2
o`0001Oooooo00?o0000ooooooooool0/?ooool007Oooooo00Go0000ooooool0003oooooo`00000O
ooooo`;o00006?ooool00ol0003oooooooooo`2`ooooo`00Moooool01?l0003oooooo`000?l0000P
ooooo`;o00006?ooool00ol0003oooooooooo`2`ooooo`00Moooool01?l0003oooooo`000?l0000O
ooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo0;3ooooo001gooooo`04o`000?oooooo0000o`0001oooooo00GoV9RHo`000?l0003ooooo
odA4A005ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo
001gooooo`04o`000?oooooo0000o`00023ooooo0_l000000oo^k^koooooooooo`0?ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool007Oooooo0_l000000ooooooo0000oooo
o`0Oooooo`;o000000?o8B4Qonk^k_ooool03_ooool00omgMgOo<S8booooo`04ooooo`?o0000/?oo
ool007Kooooo0ol000000ooooooo0000ooooo`0Nooooo`05o`000?oooooo0000ogMgMomVIVH03?oo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool007Kooooo0ol0
00000ooooooo0000ooooo`0Nooooo`05o`000?oooooo0000ooooool000003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo001fooooo`Co00008?ooool01Ol0003o^[Zjo`00
0?nHV9So410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00M_oo
ool4o`00023ooooo0ol000000olQ8B7oc<c<ooooo`0;ooooo`Co00001_ooool00ol0003ooooooooo
o`2`ooooo`00M_ooool4o`00023ooooo0_l0000Iooooo`03o`000?oooooooooo0;3ooooo001foooo
o`Co00008?ooool2o`0001Wooooo00?o0000ooooooooool0/?ooool007Kooooo00Co0000ooooool0
003o00008?ooool2o`0001Wooooo00?o0000ooooooooool0/?ooool007Kooooo00Co0000ooooool0
003o00008?ooool2o`0001Wooooo0_l0002aooooo`00M_ooool00ol0003oooooo`00000Qooooo`;o
00006Oooool00ol0003oooooooooo`2`ooooo`00M_ooool00ol0003oooooo`00000Rooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool0/?ooool007Kooooo0ol0000Rooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool0/?ooool007Kooooo0ol0000Rooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool0/?ooool007Kooooo0ol0000Rooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool0/?ooool007Kooooo0ol0000Rooooo`;o00006?ooool00ol0003o
ooooooooo`2`ooooo`00M_ooool3o`0002;ooooo0_l0000Hooooo`03o`000?oooooooooo0;3ooooo
001fooooo`;o00008oooool2o`0001Sooooo00?o0000ooooooooool0/?ooool007Kooooo0_l0000S
ooooo`;o00006?ooool2o`000;7ooooo001fooooo`;o00008oooool2o`0001Sooooo00?o0000oooo
ooooool0/?ooool007Kooooo0_l0000Sooooo`;o00006?ooool00ol0003oooooooooo`2`ooooo`00
M_ooool2o`0002?ooooo0_l0000Hooooo`03o`000?oooooooooo0;3ooooo001fooooo`;o00009?oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo0;3ooooo001fooooo`;o00009?ooool2
o`0001Oooooo00?o0000ooooooooool0/?ooool007Kooooo0_l0000Tooooo`;o00005oooool00ol0
003oooooooooo`2`ooooo`00M_ooool2o`0002Cooooo0_l0000Gooooo`03o`000?oooooooooo0;3o
oooo001fooooo`;o00009?ooool2o`0001Oooooo0_l0002aooooo`00M_ooool2o`0002Cooooo0_l0
000Gooooo`03o`000?oooooooooo0;3ooooo001fooooo`;o00009Oooool2o`0001Kooooo00?o0000
ooooooooool0/?ooool007Gooooo0ol0000Uooooo`;o00005_ooool00ol0003oooooooooo`2`oooo
o`00MOooool3o`0002Gooooo0_l0000Fooooo`03o`000?oooooooooo0;3ooooo001eooooo`?o0000
9_ooool2o`0001Gooooo00?o0000ooooooooool0/?ooool007Gooooo0ol0000Wooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0/?ooool007Gooooo0ol0000Wooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool0/?ooool007Gooooo0ol0000mooooo`03o`000?oooooooooo
0;3ooooo001eooooo`?o0000?Oooool2o`000;7ooooo001eooooo`?o0000?Oooool00ol0003ooooo
ooooo`2`ooooo`00MOooool3o`0003gooooo00?o0000ooooooooool0/?ooool007Gooooo0ol0000m
ooooo`03o`000?oooooooooo0;3ooooo001eooooo`?o0000?Oooool00ol0003oooooooooo`2`oooo
o`00MOooool3o`0003gooooo00?o0000ooooooooool0/?ooool007Gooooo0ol0000cooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00MOooool3o`0003Kooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00MOooool3o`0003Oooooo00?o
0000ooooooooool00oooool3o`000;3ooooo001eooooo`?o0000=_ooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo0;3ooooo001eooooo`?o0000<oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool0/?ooool007Gooooo0ol0000cooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0/?ooool007Gooooo0ol0000cooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0/?ooool007Gooooo0ol0000cooooo`Co00001_ooool00ol0003ooooo
ooooo`2`ooooo`00MOooool3o`0003gooooo00?o0000ooooooooool0/?ooool007Cooooo1?l0000m
ooooo`03o`000?oooooooooo0;3ooooo001dooooo`Co0000?Oooool00ol0003oooooooooo`2`oooo
o`00M?ooool4o`0003gooooo0_l0002aooooo`00M?ooool4o`0003gooooo00?o0000ooooooooool0
/?ooool007Cooooo1?l0000mooooo`03o`000?oooooooooo0;3ooooo001dooooo`Co0000?Oooool0
0ol0003oooooooooo`2`ooooo`00M?ooool4o`0003gooooo00?o0000ooooooooool0/?ooool007Co
oooo1?l0000mooooo`03o`000?oooooooooo0;3ooooo001dooooo`Co0000?Oooool00ol0003ooooo
ooooo`2`ooooo`00M?ooool4o`0003gooooo00?o0000ooooooooool0/?ooool007Cooooo1?l0000m
ooooo`;o0000/Oooool007Cooooo1?l0000mooooo`03o`000?oooooooooo0;3ooooo001dooooo`Co
0000?Oooool00ol0003oooooooooo`2`ooooo`00M?ooool4o`0003gooooo00?o0000ooooooooool0
/?ooool007Cooooo1?l0000mooooo`03o`000?oooooooooo0;3ooooo001dooooo`Co0000?Oooool0
0ol0003oooooooooo`2`ooooo`00M?ooool4o`0003gooooo00?o0000ooooooooool0/?ooool007Co
oooo1?l0000mooooo`03o`000?oooooooooo0;3ooooo001dooooo`Co0000?Oooool00ol0003ooooo
ooooo`2`ooooo`00M?ooool4o`0003gooooo0_l0002aooooo`00M?ooool4o`0003gooooo00?o0000
ooooooooool0/?ooool007Cooooo1?l0000mooooo`03o`000?oooooooooo0;3ooooo001dooooo`Co
0000?Oooool00ol0003oooooooooo`2`ooooo`00M?ooool4o`0003gooooo00?o0000ooooooooool0
/?ooool007Cooooo0ol000000ooooooo0000ooooo`0kooooo`03o`000?oooooooooo0;3ooooo001d
ooooo`?o000000?oooooo`000?ooool0>oooool00ol0003oooooooooo`2`ooooo`00M?ooool3o`00
0003ooooool0003ooooo03_ooooo00?o0000ooooooooool0/?ooool007Cooooo0ol000000ooooooo
0000ooooo`0kooooo`;o0000/Oooool007Cooooo0ol000000ooooooo0000ooooo`0kooooo`03o`00
0?oooooooooo0;3ooooo001dooooo`?o000000?oooooo`000?ooool0>oooool00ol0003ooooooooo
o`2`ooooo`00M?ooool3o`000003ooooool0003ooooo03_ooooo00?o0000ooooooooool0/?ooool0
07Cooooo0ol000000ooooooo0000ooooo`0kooooo`03o`000?oooooooooo0;3ooooo001dooooo`?o
000000?oooooo`000?ooool0>oooool00ol0003oooooooooo`2`ooooo`00M?ooool3o`000003oooo
ool0003ooooo02;ooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo001dooooo`05o`000?oooooo0000ooooool0
00008oooool00omEEEGoZJVYooooo`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo0;3ooooo001dooooo`05o`000?oooooo0000ooooool000008oooool00onYZJWo
EEEEooooo`0@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool007Cooooo
00Go0000ooooool0003oooooo`00000Tooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_oo
ool01?ooool3o`000;3ooooo001dooooo`05o`000?oooooo0000ooooool000009?ooool00omEEEGo
c<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`oooo
o`00M?ooool01Ol0003oooooo`000?oooooo000002Cooooo00?oZJVYogMgMoooool02oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo001dooooo`05o`000?oooooo0000oooo
ool000008Oooool01Ol@413ooooooooooooooooo<S8b00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`2`ooooo`00M?ooool01Ol0003oooooo`000?oooooo0000027ooooo1Ol0000<
ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00M?ooool01Ol0003oooooo`000?oooooo
000003cooooo00?o0000ooooooooool0/?ooool007Cooooo00Go0000ooooool0003oooooo`00000l
ooooo`03o`000?oooooooooo0;3ooooo001dooooo`05o`000?oooooo0000ooooool00000??ooool0
0ol0003oooooooooo`2`ooooo`00M?ooool01Ol0003oooooo`000?oooooo000003cooooo0_l0002a
ooooo`00M?ooool3o`000003ooooool0003ooooo03_ooooo00?o0000ooooooooool0/?ooool007Co
oooo0ol000000ooooooo0000ooooo`0kooooo`03o`000?oooooooooo0;3ooooo001dooooo`?o0000
00?oooooo`000?ooool0>oooool00ol0003oooooooooo`2`ooooo`00M?ooool3o`000003ooooool0
003ooooo03_ooooo00?o0000ooooooooool0/?ooool007Cooooo0ol000000ooooooo0000ooooo`0k
ooooo`03o`000?oooooooooo0;3ooooo001dooooo`?o000000?oooooo`000?ooool0>oooool00ol0
003oooooooooo`2`ooooo`00M?ooool3o`000003ooooool0003ooooo03_ooooo00?o0000oooooooo
ool0/?ooool007Cooooo0ol000000ooooooo0000ooooo`0kooooo`03o`000?oooooooooo0;3ooooo
001dooooo`?o000000?oooooo`000?ooool0>oooool2o`000;7ooooo001dooooo`?o000000?ooooo
o`000?ooool0>oooool00ol0003oooooooooo`2`ooooo`00M?ooool3o`000003ooooool0003ooooo
03_ooooo00?o0000ooooooooool0/?ooool007Cooooo0ol000000ooooooo0000ooooo`0kooooo`03
o`000?oooooooooo0;3ooooo001dooooo`?o000000?oooooo`000?ooool0>oooool00ol0003ooooo
ooooo`2`ooooo`00M?ooool3o`000003ooooool0003ooooo03_ooooo00?o0000ooooooooool0/?oo
ool007Cooooo0ol000000ooooooo0000ooooo`0kooooo`03o`000?oooooooooo0;3ooooo001doooo
o`?o000000?oooooo`000?ooool0>oooool00ol0003oooooooooo`2`ooooo`00M?ooool3o`000003
ooooool0003ooooo03_ooooo0_l0002aooooo`00M?ooool3o`000003ooooool0003ooooo03_ooooo
00?o0000ooooooooool0/?ooool007Cooooo0ol000000ooooooo0000ooooo`0kooooo`03o`000?oo
oooooooo0;3ooooo001eooooo`;o000000?oooooo`000?ooool0>oooool00ol0003oooooooooo`2`
ooooo`00MOooool2o`000003ooooool0003ooooo03_ooooo00?o0000ooooooooool0/?ooool007Go
oooo0_l000000ooooooo0000ooooo`0kooooo`03o`000?oooooooooo0;3ooooo001eooooo`;o0000
00?oooooo`000?ooool0>oooool00ol0003oooooooooo`2`ooooo`00MOooool2o`000003ooooool0
003ooooo03_ooooo00?o0000ooooooooool0/?ooool007Gooooo0_l000000ooooooo0000ooooo`0k
ooooo`03o`000?oooooooooo0;3ooooo001eooooo`;o000000?oooooo`000?ooool0>oooool2o`00
0;7ooooo001eooooo`;o000000?oooooo`000?ooool0>oooool00ol0003oooooooooo`2`ooooo`00
MOooool2o`000003ooooool0003ooooo03_ooooo00?o0000ooooooooool0/?ooool007Gooooo00Co
0000ooooool0003o0000??ooool00ol0003oooooooooo`2`ooooo`00MOooool4o`0003cooooo00?o
0000ooooooooool0/?ooool007Gooooo1?l0000looooo`03o`000?oooooooooo0;3ooooo001eoooo
o`Co0000:_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`00
0?oooooooooo0;3ooooo001eooooo`Co0000;?ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`2`ooooo`00MOooool4o`0002cooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo0ol0002`ooooo`00YOoo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000^Oooool00:Gooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo00000;Wooooo002Uooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@402iooooo`00YOooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0^Oooool00:?ooooo00?oEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^0;Wooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-10, -10, 0, 0}}]
}, Closed]]
}, Open  ]],

Cell["\<\
Although the patch area remains constant, the dye patch is \
stretched and folded by the flow in a very complex manner due to the chaotic \
nature of the characteristics. Ultimately, the filaments of dye become so \
thin that they are indistinguishable, and the dye becomes thoroughly mixed \
through the background fluid. \
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 4: The Collisionless Boltzmann Equation", "Section",
  CellTags->"c:9"],

Cell[TextData[{
  "\tEquation ",
  ButtonBox["(7.1.18)",
    ButtonData:>{"Chapter7.nb", "(7.1.18)"},
    ButtonStyle->"Hyperlink"],
  "  can also be interpreted in a different manner. Rather than thinking of \
",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " as the density of dye placed in a fluid, we can instead think of ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " as the density in phase space ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, \ p)\)\)]],
  " of a one-dimensional gas of atoms of mass ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`p = m\ \[DifferentialD]x/\[DifferentialD]t\)]],
  " is the particle momentum. Now ",
  Cell[BoxData[
      \(TraditionalForm\`f = f(x, p, t)\)]],
  ", and Eq. ",
  ButtonBox["(7.1.18)",
    ButtonData:>{"Chapter7.nb", "(7.1.18)"},
    ButtonStyle->"Hyperlink"],
  "  is written as"
}], "Text",
  CellTags->"i:20"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]f\/\[PartialD]t + \(p\/m\) \[PartialD]f\/\
\[PartialD]x + \ \(F(x, p, t)\) \[PartialD]f\/\[PartialD]p = 0\)]],
  "."
}], "NumberedEquation",
  CellTags->"(7.1.21)"],

Cell[TextData[{
  "The physical interpretation of the function ",
  Cell[BoxData[
      \(TraditionalForm\`F(x, p, t)\)]],
  " becomes clear when we write out the characteristic equations:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]x\/\[DifferentialD]t = 
        p/m, \[IndentingNewLine]\[DifferentialD]p\/\[DifferentialD]t = 
        F(x, p, t)\)]],
  "."
}], "UNNEQ",
  CellTags->"i:19"],

Cell[TextData[{
  "These are Newton's equations for the motion of particles in a prescribed \
external force ",
  Cell[BoxData[
      \(TraditionalForm\`F(x, p, t)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\t Equation ",
  ButtonBox["(7.1.21)",
    ButtonData:>{"Chapter7.nb", "(7.1.21)"},
    ButtonStyle->"Hyperlink"],
  "  is called the collisionless Boltzmann ( or Vlasov)  equation. The number \
of particles in the element ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]x\ \[DifferentialD]p\)]],
  " is ",
  Cell[BoxData[
      \(TraditionalForm\`f\ \[DifferentialD]x\ \[DifferentialD]p\)]],
  ". According to our understanding of convective derivatives, Eq. ",
  ButtonBox["(7.1.21)",
    ButtonData:>{"Chapter7.nb", "(7.1.21)"},
    ButtonStyle->"Hyperlink"],
  "  is equivalent to the equation ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]f/\[DifferentialD]t = 0\)]],
  " along the characteristics. This means that the particle density in phase \
space remains constant along the phase-space flow: particles are neither \
created nor destroyed, but are simply carried through phase space by their  \
dynamics."
}], "Text",
  CellTags->"i:6"],

Cell[TextData[{
  "\tInteractions between the particles are neglected in this description of \
the gas, since the only force acting on the particles is the external force \
",
  Cell[BoxData[
      \(TraditionalForm\`F\)]],
  ". ",
  Cell[BoxData[
      FormBox[Cell[TextData[StyleBox["", "Input"]]], TraditionalForm]]],
  " Therefore, Eq. ",
  ButtonBox["(7.1.21)",
    ButtonData:>{"Chapter7.nb", "(7.1.21)"},
    ButtonStyle->"Hyperlink"],
  "  describes the evolution of an ",
  StyleBox["ideal gas",
    FontSlant->"Italic"],
  " of ",
  StyleBox["noninteracting",
    FontSlant->"Italic"],
  " ",
  StyleBox["particles",
    FontSlant->"Italic"],
  ". "
}], "Text",
  CellTags->"i:7"],

Cell[TextData[{
  "\t For example, consider the behavior of a gas of particles falling in \
gravity.  If the particles are confined in an evacuated container, the force \
law could be given by something like ",
  Cell[BoxData[
      \(TraditionalForm\`F = \(-m\)\ g\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`x > 0\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`F = \(-m\)\ g\  - \ k\ x, \ x < 0\)]],
  ", where the term ",
  Cell[BoxData[
      \(TraditionalForm\`k\ x\)]],
  " describes an elastic collision of the atoms with the bottom of the \
container at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  ". A few characteristics for this flow in the ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, p)\)\)]],
  " plane are shown in Cell ",
  ButtonBox["7.6",
    ButtonData:>"Cell 7.6",
    ButtonStyle->"Hyperlink"],
  " for a range of initial conditions, taking ",
  Cell[BoxData[
      \(TraditionalForm\`k = 20, m = \(g = 1\)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(Clear[c];\)\(\n\)
    \)\), "\n", 
    \(m = \(g = 1\); k = 20;\), "\n", 
    \(F[x_]\  := \ \(-m\)\ g\  /; \ x > 0\), "\n", 
    \(F[x_]\  := \ \(-m\)\ g\  - \ k\ x\  /; \ x \[LessEqual] \ 0\), "\n", 
    \(\(\(c[x0_, 
          p0_]\  := \ \(c[x0, 
            p0]\  = \ {x[t], 
              p[t]} /. \(NDSolve[{\(x'\)[t]\  \[Equal] \ 
                    p[t]/m, \(p'\)[t]\  \[Equal] \ F[x[t]], x[0] \[Equal] x0, 
                  p[0] \[Equal] p0}, {x, p}, {t, 0, 50}, 
                MaxSteps \[Rule] 4000]\)[\([1]\)]\);\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(Table[
        ParametricPlot[Evaluate[c[x0, p0]], {t, 0, 20}, 
          DisplayFunction \[Rule] Identity], {x0, 0, 2}, {p0, \(-1\), 
          1}];\)\), "\n", 
    \(\(Show[%, DisplayFunction \[Rule] $DisplayFunction, 
        AxesLabel \[Rule] {"\<x\>", "\<p\>"}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.6"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.196186 0.312003 0.309018 0.130964 [
[.04018 .29652 -12 -9 ]
[.04018 .29652 12 0 ]
[.35219 .29652 -9 -9 ]
[.35219 .29652 9 0 ]
[.50819 .29652 -3 -9 ]
[.50819 .29652 3 0 ]
[.66419 .29652 -9 -9 ]
[.66419 .29652 9 0 ]
[.82019 .29652 -3 -9 ]
[.82019 .29652 3 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.18369 .04709 -12 -4.5 ]
[.18369 .04709 0 4.5 ]
[.18369 .17805 -12 -4.5 ]
[.18369 .17805 0 4.5 ]
[.18369 .43998 -6 -4.5 ]
[.18369 .43998 0 4.5 ]
[.18369 .57095 -6 -4.5 ]
[.18369 .57095 0 4.5 ]
[.19619 .64303 -5 0 ]
[.19619 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04018 .30902 m
.04018 .31527 L
s
[(-0.5)] .04018 .29652 0 1 Mshowa
.35219 .30902 m
.35219 .31527 L
s
[(0.5)] .35219 .29652 0 1 Mshowa
.50819 .30902 m
.50819 .31527 L
s
[(1)] .50819 .29652 0 1 Mshowa
.66419 .30902 m
.66419 .31527 L
s
[(1.5)] .66419 .29652 0 1 Mshowa
.82019 .30902 m
.82019 .31527 L
s
[(2)] .82019 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07139 .30902 m
.07139 .31277 L
s
.10259 .30902 m
.10259 .31277 L
s
.13379 .30902 m
.13379 .31277 L
s
.16499 .30902 m
.16499 .31277 L
s
.22739 .30902 m
.22739 .31277 L
s
.25859 .30902 m
.25859 .31277 L
s
.28979 .30902 m
.28979 .31277 L
s
.32099 .30902 m
.32099 .31277 L
s
.38339 .30902 m
.38339 .31277 L
s
.41459 .30902 m
.41459 .31277 L
s
.44579 .30902 m
.44579 .31277 L
s
.47699 .30902 m
.47699 .31277 L
s
.53939 .30902 m
.53939 .31277 L
s
.57059 .30902 m
.57059 .31277 L
s
.60179 .30902 m
.60179 .31277 L
s
.63299 .30902 m
.63299 .31277 L
s
.69539 .30902 m
.69539 .31277 L
s
.72659 .30902 m
.72659 .31277 L
s
.75779 .30902 m
.75779 .31277 L
s
.78899 .30902 m
.78899 .31277 L
s
.85139 .30902 m
.85139 .31277 L
s
.88259 .30902 m
.88259 .31277 L
s
.91379 .30902 m
.91379 .31277 L
s
.94499 .30902 m
.94499 .31277 L
s
.00898 .30902 m
.00898 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.19619 .04709 m
.20244 .04709 L
s
[(-2)] .18369 .04709 1 0 Mshowa
.19619 .17805 m
.20244 .17805 L
s
[(-1)] .18369 .17805 1 0 Mshowa
.19619 .43998 m
.20244 .43998 L
s
[(1)] .18369 .43998 1 0 Mshowa
.19619 .57095 m
.20244 .57095 L
s
[(2)] .18369 .57095 1 0 Mshowa
.125 Mabswid
.19619 .07328 m
.19994 .07328 L
s
.19619 .09948 m
.19994 .09948 L
s
.19619 .12567 m
.19994 .12567 L
s
.19619 .15186 m
.19994 .15186 L
s
.19619 .20425 m
.19994 .20425 L
s
.19619 .23044 m
.19994 .23044 L
s
.19619 .25663 m
.19994 .25663 L
s
.19619 .28283 m
.19994 .28283 L
s
.19619 .33521 m
.19994 .33521 L
s
.19619 .3614 m
.19994 .3614 L
s
.19619 .3876 m
.19994 .3876 L
s
.19619 .41379 m
.19994 .41379 L
s
.19619 .46617 m
.19994 .46617 L
s
.19619 .49237 m
.19994 .49237 L
s
.19619 .51856 m
.19994 .51856 L
s
.19619 .54475 m
.19994 .54475 L
s
.19619 .0209 m
.19994 .0209 L
s
.19619 .59714 m
.19994 .59714 L
s
.25 Mabswid
.19619 0 m
.19619 .61803 L
s
gsave
.19619 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.19619 .17805 m
.1884 .17563 L
.18124 .17483 L
.17296 .17559 L
.16523 .17795 L
.15825 .18154 L
.152 .18602 L
.14543 .19217 L
.13887 .20003 L
.13279 .20922 L
.12688 .22044 L
.12237 .23112 L
.11814 .24369 L
.11594 .25171 L
.11417 .25939 L
.11142 .27508 L
.10983 .28979 L
.10912 .30574 L
.10915 .31395 L
.10946 .3226 L
.11078 .33793 L
.11191 .3463 L
.11323 .35399 L
.11712 .3708 L
.1215 .38457 L
.12624 .39619 L
.1325 .40831 L
.13913 .41835 L
.14557 .42602 L
.15286 .43271 L
.15936 .43716 L
.16677 .44069 L
.17487 .44279 L
.18369 .44309 L
.19198 .4415 L
.19944 .43861 L
.2606 .40937 L
.30353 .38216 L
.32007 .36844 L
.33397 .35378 L
.34014 .34541 L
.3448 .33751 L
.34802 .33042 L
.34943 .32642 L
.35048 .32273 L
.35123 .31928 L
.35174 .31601 L
.35204 .31308 L
.35218 .30987 L
.35212 .3064 L
Mistroke
.352 .30447 L
.35182 .30271 L
.35132 .29929 L
.35066 .29607 L
.34883 .28982 L
.34653 .28408 L
.34331 .27777 L
.33912 .27112 L
.32768 .25711 L
.31379 .24404 L
.27069 .21436 L
.24517 .20055 L
.23032 .19327 L
.21351 .18554 L
.19796 .1788 L
.19355 .17705 L
.18875 .1757 L
.17999 .17483 L
.17188 .17582 L
.16347 .17872 L
.15649 .18268 L
.14914 .1885 L
.1418 .19629 L
.13537 .20507 L
.12491 .22484 L
.12007 .23758 L
.11634 .25017 L
.1131 .26476 L
.11182 .27236 L
.11069 .28086 L
.10947 .29537 L
.1091 .30876 L
.10956 .32421 L
.11086 .33867 L
.11281 .3517 L
.11522 .36338 L
.11853 .37564 L
.12276 .38792 L
.13349 .40998 L
.13981 .41924 L
.14731 .42779 L
.15414 .43369 L
.16176 .43848 L
.16917 .44149 L
.17603 .44294 L
.18472 .44299 L
.19268 .44128 L
.20125 .43784 L
.21007 .43402 L
.23907 .42053 L
Mistroke
.28605 .39429 L
.31805 .37028 L
.33125 .357 L
.34082 .34437 L
.34483 .33746 L
.34777 .33105 L
.35014 .32401 L
.35107 .32008 L
.35167 .31652 L
.35201 .31336 L
.35218 .31003 L
.35215 .30718 L
.35196 .30406 L
.35155 .30069 L
.35089 .29709 L
.35005 .29369 L
.34909 .29059 L
.34675 .28458 L
.34346 .27805 L
.33549 .26617 L
.32346 .25282 L
.30923 .2403 L
.26613 .21175 L
.24047 .19819 L
.20987 .18393 L
.20153 .18032 L
.19684 .17833 L
.19236 .17665 L
.18699 .17536 L
.18208 .17485 L
.17747 .17495 L
.17249 .17568 L
.16378 .17858 L
.15949 .1808 L
.15485 .18382 L
.14697 .19058 L
.14005 .19848 L
.13341 .20819 L
.12707 .22004 L
.12185 .23251 L
.11784 .24472 L
.11402 .26009 L
.11233 .2691 L
.11109 .27755 L
.10958 .29343 L
.10921 .30153 L
.1091 .31043 L
.10972 .32669 L
.11119 .34126 L
.11237 .34917 L
Mistroke
.11394 .35759 L
.11754 .3723 L
.12175 .38524 L
.12702 .39789 L
.13266 .4086 L
.13836 .4173 L
.14423 .42457 L
.15105 .43123 L
.15862 .43672 L
.16609 .44043 L
.17319 .44249 L
.18084 .44321 L
.18806 .44248 L
.19455 .44063 L
.20268 .43723 L
.20998 .43406 L
.22578 .42691 L
.25206 .41394 L
.29405 .38897 L
.31233 .37522 L
.32647 .36219 L
.3331 .35483 L
.33919 .34682 L
.34336 .34016 L
.34704 .33281 L
.34959 .3259 L
.35063 .32211 L
.35136 .31856 L
.35183 .31525 L
.35209 .31221 L
.35218 .30888 L
.35206 .30537 L
.35173 .30198 L
.35146 .30007 L
.35114 .2983 L
.35041 .29506 L
.34943 .29163 L
.34723 .28568 L
.34406 .27914 L
.33428 .26465 L
.32168 .2511 L
.29064 .22676 L
.24526 .2006 L
.21701 .18711 L
.20901 .18356 L
.20011 .17971 L
.19146 .17638 L
.18336 .17492 L
.17868 .17487 L
.17356 .17547 L
Mistroke
.16825 .17684 L
.16336 .17878 L
.15494 .18375 L
.15039 .18738 L
.14637 .19119 L
.13894 .19995 L
.13157 .21133 L
.12542 .22367 L
.12051 .23629 L
.11667 .24889 L
.11338 .26325 L
.11111 .27738 L
.10977 .29066 L
.10912 .30561 L
.10943 .32199 L
.10999 .3302 L
.11089 .33888 L
.11326 .35415 L
.11498 .36232 L
.11681 .36966 L
.12179 .38536 L
.12709 .39804 L
.13353 .41005 L
.13996 .41943 L
.14643 .42691 L
.15398 .43358 L
.15839 .43658 L
.16249 .43884 L
.17021 .44179 L
.17758 .4431 L
.1857 .44287 L
.19438 .44069 L
.20279 .43718 L
.21141 .43343 L
.22619 .42672 L
.27436 .40152 L
.31344 .37428 L
.32961 .35884 L
.33588 .35136 L
.34076 .34446 L
.34462 .33787 L
.34795 .33061 L
.34921 .32709 L
.35033 .32331 L
.35083 .32123 L
.35122 .31932 L
.35153 .31751 L
.35179 .31558 L
.3521 .31211 L
.35219 .30889 L
Mistroke
.35215 .30692 L
.35204 .30506 L
.35168 .30159 L
.35113 .29826 L
.35045 .2952 L
.34828 .28829 L
.34563 .28216 L
.34253 .27644 L
.33329 .26344 L
.32133 .25077 L
.30527 .2372 L
.26157 .20921 L
.23279 .19444 L
.21534 .18636 L
.20636 .1824 L
.19787 .17877 L
.19019 .17604 L
.18199 .17485 L
.17373 .17544 L
.16909 .17657 L
.16481 .17813 L
.16017 .18041 L
.15587 .18309 L
.14811 .18946 L
.14027 .1982 L
.13251 .20969 L
.12703 .22013 L
.12174 .23283 L
.11712 .24726 L
.1137 .26165 L
.11134 .27569 L
.10991 .28886 L
.10914 .30432 L
.1093 .31905 L
.11041 .33466 L
.11147 .3433 L
.11271 .35111 L
.11563 .36507 L
.1196 .37902 L
.12388 .39074 L
.12845 .40084 L
.134 .41081 L
.14064 .42031 L
.14834 .42878 L
.15608 .43508 L
.16395 .43953 L
.17142 .44211 L
.17959 .4432 L
.18426 .44304 L
.18861 .44237 L
Mistroke
.19728 .43952 L
.20636 .43564 L
.26053 .4094 L
.29964 .38503 L
.31783 .37047 L
.33101 .35727 L
.34192 .3426 L
.34626 .33455 L
.34782 .33093 L
.34926 .32696 L
.35022 .32372 L
.35104 .32024 L
.3514 .31832 L
.35166 .31657 L
.35203 .31314 L
.35217 .31002 L
.35213 .30662 L
.3519 .3034 L
.35151 .30043 L
.35087 .29702 L
.35008 .29382 L
.34758 .28651 L
.3442 .2794 L
.33953 .27172 L
.3286 .2581 L
.3154 .24543 L
.27459 .21665 L
.22032 .18861 L
.21171 .18474 L
.20205 .18054 L
.19751 .17861 L
.19264 .17674 L
.18843 .17563 L
.18376 .17495 L
.17509 .17522 L
.17025 .17623 L
.16587 .1777 L
.15754 .18198 L
.14994 .18778 L
.14261 .19533 L
.13527 .20523 L
.129 .21611 L
.12388 .22729 L
.11953 .23923 L
.1161 .25109 L
.11322 .26409 L
.11092 .27892 L
.11009 .28678 L
.10947 .29541 L
.10911 .31122 L
Mistroke
.10971 .32658 L
.1111 .34059 L
.11348 .35529 L
.11523 .3634 L
.11712 .3708 L
.12165 .38496 L
.12752 .39893 L
.13866 .41771 L
.14582 .42628 L
.15293 .43276 L
.16082 .43798 L
.16823 .44119 L
.17695 .44304 L
.18522 .44293 L
.19234 .44139 L
.19974 .43848 L
.21257 .43291 L
.23948 .42033 L
.28596 .39434 L
.30632 .38003 L
.32219 .36644 L
.33391 .35384 L
.33893 .34718 L
.34339 .34011 L
.34671 .33355 L
.34904 .32762 L
.34993 .32476 L
.35073 .32166 L
.35132 .31874 L
.35173 .31606 L
.35207 .31256 L
.35218 .30926 L
.35212 .30629 L
.35186 .30307 L
.35137 .29956 L
.35104 .29779 L
.35061 .29585 L
.3486 .28918 L
.346 .28295 L
.34241 .27624 L
.33386 .26413 L
.31931 .2489 L
.30157 .23442 L
.25796 .20724 L
.23116 .19367 L
.20284 .18088 L
.19471 .17747 L
.18592 .1752 L
.18129 .17483 L
.17619 .17508 L
Mistroke
.17158 .17589 L
.16731 .17716 L
.15932 .18089 L
.15228 .18579 L
.14455 .19312 L
.13771 .20163 L
.12681 .2206 L
.12216 .23168 L
.11778 .24491 L
.11473 .25683 L
.11215 .27025 L
.11042 .28332 L
.10946 .29554 L
.1091 .31007 L
.10952 .32357 L
.11081 .33822 L
.11313 .35347 L
.11467 .36094 L
.11659 .36884 L
.12077 .3825 L
.12562 .39482 L
.13073 .4052 L
.13709 .41552 L
.14368 .42395 L
.14999 .43031 L
.15722 .43585 L
.16537 .44014 L
.17003 .44174 L
.17428 .44269 L
.18263 .44316 L
.19046 .44193 L
.19774 .43933 L
.20525 .43612 L
.21822 .43038 L
.24529 .41743 L
.29202 .39035 L
.3126 .37499 L
.32792 .36067 L
.33916 .34686 L
.34397 .33906 L
.34744 .33185 L
.34969 .32556 L
.35065 .32198 L
.35134 .31863 L
.35185 .3151 L
.35211 .31187 L
.35218 .30832 L
.35213 .30654 L
.35201 .30459 L
.35162 .30114 L
Mistroke
.35105 .29788 L
.35038 .29495 L
.34948 .29179 L
.34679 .28467 L
.3435 .27812 L
.33548 .26617 L
.32418 .25353 L
.29176 .22751 L
.24328 .1996 L
.21469 .18607 L
.20738 .18284 L
.1994 .17941 L
.19241 .17667 L
.18457 .17503 L
.1776 .17494 L
.17012 .17627 L
.16316 .17887 L
.15692 .18239 L
.15034 .18743 L
.14347 .19432 L
.13678 .20297 L
.13105 .21226 L
.12614 .22206 L
.12143 .23368 L
.11785 .24467 L
.1147 .25696 L
.11244 .2685 L
.11061 .28159 L
.10956 .29373 L
.10913 .30523 L
Mfstroke
.19619 .30902 m
.19609 .30579 L
.19584 .30289 L
.19536 .29962 L
.19472 .29664 L
.19398 .29402 L
.19318 .29173 L
.19096 .28715 L
.18962 .28514 L
.18826 .28352 L
.18668 .28206 L
.18489 .28087 L
.18397 .28043 L
.18295 .28007 L
.18108 .27975 L
.17924 .27984 L
.17755 .28029 L
.17579 .28115 L
.17482 .2818 L
.17396 .28251 L
.17243 .28406 L
.17092 .28603 L
.16864 .29019 L
.16756 .29291 L
.16671 .29565 L
.16631 .29723 L
.16593 .29899 L
.1654 .3023 L
.16509 .30561 L
.16499 .30872 L
.16507 .31207 L
.16521 .31396 L
.1654 .31572 L
.16595 .31917 L
.16636 .32105 L
.1668 .32272 L
.16776 .32569 L
.16883 .32827 L
.17025 .33095 L
.17169 .33307 L
.17316 .33477 L
.1746 .33606 L
.17624 .33715 L
.17805 .33791 L
.1799 .33827 L
.18095 .3383 L
.1819 .3382 L
.18374 .3377 L
.18544 .33685 L
.18637 .33622 L
Mistroke
.18733 .33542 L
.18899 .3337 L
.19079 .33117 L
.19224 .32848 L
.19346 .32554 L
.19453 .32215 L
.19524 .31907 L
.19556 .31726 L
.19579 .31554 L
.196 .31351 L
.19613 .31157 L
.19618 .30982 L
.19617 .30791 L
.19609 .30584 L
.19592 .30367 L
.19571 .30183 L
.1954 .29985 L
.19466 .29638 L
.19378 .29339 L
.1926 .29035 L
.19116 .28748 L
.18973 .2853 L
.1883 .28356 L
.18661 .28201 L
.18563 .28131 L
.18472 .28078 L
.18301 .28009 L
.18138 .27977 L
.17958 .2798 L
.17766 .28025 L
.17672 .28065 L
.17571 .2812 L
.17393 .28254 L
.17229 .28422 L
.17088 .28609 L
.16866 .29015 L
.16759 .29281 L
.16675 .2955 L
.16603 .29848 L
.16553 .30134 L
.16517 .30457 L
.165 .30803 L
.16505 .3116 L
.1653 .31482 L
.16552 .31658 L
.16582 .31845 L
.16653 .32174 L
.16739 .32464 L
.16849 .32751 L
.17088 .33194 L
Mistroke
.17242 .33397 L
.17422 .33575 L
.17601 .33701 L
.17771 .3378 L
.17876 .3381 L
.17974 .33826 L
.18082 .3383 L
.18197 .33819 L
.18306 .33793 L
.18408 .33756 L
.18593 .33653 L
.1875 .33527 L
.18909 .33357 L
.19048 .33166 L
.19164 .32968 L
.19286 .32709 L
.19399 .32399 L
.19486 .32083 L
.19547 .31776 L
.19591 .31449 L
.19614 .31135 L
.19617 .30788 L
.1961 .30593 L
.19597 .30415 L
.19556 .30084 L
.19525 .29901 L
.19489 .29734 L
.19401 .29412 L
.19285 .29092 L
.19164 .28836 L
.1904 .28625 L
.1889 .28424 L
.18719 .28248 L
.18561 .2813 L
.18409 .28048 L
.18238 .27993 L
.18051 .27974 L
.17886 .27991 L
.17709 .28048 L
.17545 .28137 L
.17399 .28248 L
.17261 .28385 L
.17143 .28531 L
.16907 .28927 L
.16795 .29185 L
.16705 .29445 L
.16625 .29749 L
.1656 .30092 L
.16536 .30269 L
.16516 .30465 L
Mistroke
.16499 .30824 L
.16505 .31176 L
.16531 .31497 L
.16572 .3179 L
.16625 .32056 L
.16698 .32335 L
.16794 .32617 L
.16912 .32888 L
.1704 .33119 L
.17175 .33315 L
.17313 .33474 L
.17487 .33626 L
.17652 .33729 L
.17836 .338 L
.17941 .33822 L
.18038 .3383 L
.182 .33818 L
.18377 .33768 L
.18557 .33677 L
.18719 .33555 L
.189 .33368 L
.19057 .33151 L
.19186 .32926 L
.19309 .32652 L
.19422 .32325 L
.19473 .32135 L
.19515 .3195 L
.19572 .31614 L
.19593 .3143 L
.19609 .3123 L
.19619 .30885 L
.19609 .30572 L
.19575 .30216 L
.19522 .29889 L
.19456 .29599 L
.1938 .29344 L
.19281 .29083 L
.19161 .2883 L
.19025 .28603 L
.18865 .28395 L
.18701 .28234 L
.18544 .28119 L
.18446 .28065 L
.18354 .28026 L
.18251 .27996 L
.18141 .27978 L
.18035 .27974 L
.17935 .27983 L
.17751 .28031 L
.17578 .28116 L
Mistroke
.17482 .28181 L
.17395 .28252 L
.17226 .28425 L
.1706 .28652 L
.16921 .28898 L
.16805 .29159 L
.16715 .29413 L
.16634 .29707 L
.16567 .30045 L
.16539 .30244 L
.16519 .30433 L
.16505 .30634 L
.16499 .30819 L
.165 .31023 L
.16509 .31236 L
.16542 .31589 L
.16594 .31908 L
.16632 .32085 L
.16672 .32242 L
.16779 .32576 L
.16887 .32835 L
.17002 .33055 L
.17153 .33286 L
.17303 .33464 L
.17471 .33615 L
.17639 .33722 L
.17821 .33796 L
.17926 .33819 L
.18023 .33829 L
.18183 .33821 L
.18332 .33785 L
.18493 .33714 L
.18661 .33603 L
.1882 .33458 L
.18976 .3327 L
.19223 .32851 L
.19341 .3257 L
.19431 .32293 L
.19474 .32132 L
.19515 .31952 L
.19572 .31613 L
.19605 .31287 L
.19618 .30936 L
.19612 .30635 L
.19586 .30307 L
.19561 .30114 L
.19531 .29933 L
.19457 .29606 L
.19355 .29275 L
.19219 .28945 L
Mistroke
.19081 .28691 L
.18917 .28457 L
.18748 .28275 L
.18586 .28146 L
.18417 .28052 L
.18256 .27997 L
.18076 .27974 L
.17883 .27992 L
.17787 .28018 L
.17683 .2806 L
.175 .28168 L
.1733 .28313 L
.17182 .2848 L
.16943 .28854 L
.16827 .29105 L
.16732 .29362 L
.16649 .2965 L
.16588 .29928 L
.16539 .30245 L
.16508 .30587 L
.16499 .30946 L
.16511 .31271 L
.16526 .31449 L
.16549 .3164 L
.16608 .31978 L
.16682 .3228 L
.1678 .3258 L
.16879 .32818 L
.17002 .33055 L
.17163 .33299 L
.17325 .33485 L
.17418 .33572 L
.17524 .33653 L
.17628 .33716 L
.17723 .33762 L
.17914 .33818 L
.1802 .33829 L
.1812 .33828 L
.18297 .33796 L
.18485 .33718 L
.18658 .33605 L
.18808 .3347 L
.1897 .33278 L
.19111 .33063 L
.19325 .32611 L
.19423 .32322 L
.19496 .32038 L
.19557 .31715 L
.19596 .31403 L
.19616 .31053 L
Mistroke
.19618 .30855 L
.19614 .30674 L
.19587 .30316 L
.19561 .30116 L
.19531 .29934 L
.19459 .29613 L
.19361 .2929 L
.19235 .28979 L
.191 .28722 L
.18935 .28479 L
.18742 .2827 L
.18563 .28131 L
.18389 .2804 L
.18287 .28005 L
.18193 .27985 L
.18084 .27974 L
.1798 .27977 L
.17804 .28013 L
.17621 .28091 L
.17469 .28191 L
.17309 .28334 L
.17149 .28524 L
.16991 .28768 L
.16858 .29032 L
.16753 .293 L
.1666 .29604 L
.16591 .29909 L
.16545 .30193 L
.16513 .30509 L
.16499 .30859 L
.165 .31037 L
.16509 .31231 L
.1654 .31571 L
.16588 .3188 L
.16655 .32179 L
.16734 .32448 L
.16921 .32905 L
.17045 .33127 L
.17171 .33309 L
.1732 .33481 L
.17489 .33627 L
.17582 .3369 L
.17684 .33744 L
.17869 .33808 L
.17974 .33826 L
.18072 .3383 L
.18179 .33821 L
.18293 .33797 L
.18391 .33763 L
.18496 .33713 L
Mistroke
.1868 .33588 L
.1885 .33425 L
.18997 .33241 L
.19239 .32816 L
.19354 .32533 L
.19444 .32247 L
.1952 .31927 L
.19571 .31621 L
.19606 .31276 L
.19615 .311 L
.19618 .30906 L
.19607 .30543 L
.19575 .30214 L
.1955 .30045 L
.19517 .29863 L
.19431 .29509 L
.19335 .29218 L
.19212 .28931 L
.1908 .28689 L
.18947 .28495 L
.18798 .28324 L
.18652 .28194 L
.18485 .28085 L
.18301 .28009 L
.18121 .27976 L
.17952 .27981 L
.17801 .28014 L
.17641 .28081 L
.17459 .28199 L
.17298 .28346 L
.17132 .28546 L
.16972 .28801 L
.16825 .29111 L
.16708 .29436 L
.16624 .29751 L
.16586 .29936 L
.16557 .30111 L
.16519 .30432 L
.16501 .30739 L
.16502 .31077 L
.16511 .31266 L
.16525 .31437 L
.1657 .31775 L
.16604 .31961 L
.16642 .32129 L
.16726 .32424 L
.16835 .32717 L
.16956 .32972 L
.17105 .3322 L
.17278 .33437 L
Mistroke
.17452 .336 L
.17624 .33714 L
.17786 .33785 L
.17976 .33826 L
.18158 .33824 L
.18251 .33808 L
.18353 .33777 L
.18458 .33732 L
.18555 .33678 L
.18722 .33552 L
.18893 .33376 L
.19066 .33137 L
.19228 .32839 L
.19347 .32551 L
.19455 .32208 L
.19495 .32045 L
.19532 .31863 L
.19583 .31523 L
.19611 .31183 L
.19618 .30867 L
.19605 .30524 L
.19589 .30332 L
.19567 .30154 L
.19537 .2997 L
.19505 .29805 L
.19413 .2945 L
.19314 .29165 L
.19207 .28921 L
.19075 .2868 L
.18918 .28458 L
.18756 .28282 L
.18594 .28151 L
.18442 .28064 L
.18275 .28002 L
.18093 .27974 L
.17927 .27984 L
.17737 .28037 L
.17562 .28126 L
.17406 .28242 L
.17269 .28377 L
.17127 .28554 L
.16989 .28771 L
.16864 .29018 L
.16749 .29312 L
.16658 .29612 L
.16592 .29903 L
.16539 .30239 L
.16519 .30434 L
.16506 .30617 L
.165 .30812 L
Mistroke
.16499 .3099 L
.16507 .31195 L
.1652 .31386 L
.1656 .31713 L
.16591 .31894 L
.16626 .3206 L
.16712 .3238 L
.16827 .32699 L
.16953 .32968 L
.17088 .33194 L
.17219 .3337 L
.17374 .33533 L
.17553 .33672 L
.17654 .3373 L
.17751 .33772 L
.17927 .33819 L
.18119 .33828 L
.1822 .33814 L
.1833 .33785 L
.18443 .3374 L
.18547 .33683 L
.18726 .33548 L
.18907 .33359 L
.19052 .3316 L
.19196 .32905 L
.19327 .32605 L
.1943 .32297 L
.19507 .3199 L
.1956 .31696 L
.196 .31346 L
.19617 .31007 L
.19618 .30815 L
.19612 .30641 L
.19599 .30441 L
.1958 .30255 L
.1953 .29931 L
.19494 .29754 L
.19455 .29596 L
.19356 .29277 L
.19224 .28956 L
.19063 .28662 L
.18893 .28429 L
.18733 .28262 L
.18645 .28188 L
.18548 .28122 L
.18366 .28031 L
.18194 .27985 L
.18028 .27974 L
.17872 .27995 L
.17703 .28051 L
Mistroke
.17526 .2815 L
.17356 .28288 L
.17182 .28481 L
.17015 .28726 L
.16878 .28989 L
.16765 .29265 L
.16679 .29536 L
.16638 .29692 L
.16599 .29867 L
.16545 .30195 L
.16512 .30528 L
.16499 .30837 L
.16507 .31194 L
.16535 .31529 L
.16579 .3183 L
.16635 .321 L
.16713 .32383 L
.16813 .32664 L
.16942 .32946 L
.17102 .33214 L
.17269 .33427 L
.17435 .33585 L
.17592 .33696 L
.17771 .3378 L
.17962 .33824 L
.18141 .33826 L
.18332 .33784 L
.18438 .33742 L
.18534 .3369 L
.18706 .33566 L
.18878 .33393 L
.19021 .33206 L
.19144 .33005 L
.19264 .3276 L
.19378 .32464 L
.19476 .32126 L
.19513 .31962 L
.19546 .31784 L
.19592 .31437 L
.19614 .31109 L
.19618 .30908 L
.19614 .3069 L
.19603 .30486 L
.19585 .303 L
.19534 .29954 L
.19501 .29785 L
.19457 .29605 L
.19362 .29294 L
.19257 .29028 L
.19124 .28764 L
Mistroke
.18965 .28519 L
.18815 .28341 L
.18664 .28204 L
.18491 .28089 L
.18391 .28041 L
.18298 .28009 L
.18135 .27977 L
.17982 .27977 L
.17816 .2801 L
.17641 .28081 L
.17463 .28196 L
.17303 .28341 L
.17167 .28499 L
.17031 .28699 L
.16904 .28932 L
.16785 .29212 L
.16676 .29547 L
.16596 .29883 L
.16563 .3007 L
.16535 .30278 L
.16515 .30478 L
.16504 .30665 L
.165 .3102 L
.16508 .31219 L
.16521 .31397 L
.16565 .31743 L
.16624 .32051 L
.1671 .32372 L
.16822 .32686 L
.16937 .32936 L
.17057 .33146 L
.17201 .33347 L
.17368 .33527 L
.17533 .33658 L
.1763 .33717 L
.17722 .33761 L
.17912 .33817 L
.1802 .33829 L
.18119 .33828 L
.18285 .33799 L
.18464 .33729 L
.18644 .33615 L
.18804 .33473 L
.18983 .3326 L
.19136 .3302 L
.19258 .32774 L
.19372 .3248 L
.19474 .32131 L
.19516 .31946 L
.19553 .31738 L
Mistroke
.19579 .31556 L
.19599 .31358 L
.19612 .31169 L
.19618 .30996 L
.19613 .30654 L
.19602 .30482 L
.19584 .30294 L
.19537 .29969 L
.19475 .29675 L
.19381 .29349 L
.19276 .29071 L
.19142 .28795 L
.18981 .28541 L
.18837 .28365 L
.18674 .28211 L
.18511 .281 L
.18359 .28029 L
.18175 .27982 L
.18071 .27974 L
.17975 .27978 L
.17799 .28015 L
.17616 .28094 L
.1745 .28206 L
.17278 .28367 L
.17126 .28555 L
.16996 .28758 L
.16787 .29207 L
.16692 .29491 L
.16622 .29764 L
.16558 .30102 L
.1652 .30424 L
.165 .30784 L
.16499 .30966 L
.16505 .31166 L
.16532 .31499 L
.16582 .31847 L
.16651 .32163 L
.1673 .32436 L
.16825 .32692 L
.1694 .32942 L
.17182 .33324 L
.17333 .33494 L
.17483 .33623 L
.17655 .3373 L
.17754 .33773 L
.17846 .33802 L
.18003 .33828 L
.18149 .33825 L
.18308 .33792 L
.18476 .33723 L
Mistroke
.18646 .33614 L
.188 .33478 L
.18931 .33329 L
.19063 .33142 L
.19192 .32914 L
.193 .32673 L
.19408 .32371 L
.19488 .32074 L
.19546 .31782 L
.19585 .31502 L
.19611 .31188 L
.19618 .3085 L
.19613 .30656 L
.19602 .30479 L
.19584 .30287 L
.19557 .30087 L
.19495 .2976 L
.19404 .2942 L
.19303 .29137 L
.19177 .28861 L
.19052 .28645 L
.18907 .28445 L
.18727 .28256 L
.1855 .28123 L
.18448 .28067 L
.18351 .28026 L
.18244 .27995 L
.18127 .27977 L
.18031 .27974 L
.17927 .27984 L
.17819 .28009 L
.1772 .28044 L
.17546 .28137 L
.17367 .28277 L
.17202 .28455 L
.17038 .28688 L
.16899 .28943 L
.16787 .29206 L
.16701 .29462 L
.16622 .29762 L
.1656 .3009 L
.16521 .30407 L
.16501 .30751 L
.16499 .30925 L
.16503 .31118 L
.16527 .31455 L
.16568 .31766 L
.166 .31938 L
.16639 .32116 L
.16725 .3242 L
Mistroke
.16838 .32724 L
.16984 .33023 L
.17129 .33253 L
.17273 .33431 L
.17451 .33598 L
.17629 .33716 L
.17798 .33789 L
.17958 .33824 L
.18135 .33826 L
.1832 .33788 L
.18484 .33718 L
.1863 .33626 L
.18791 .33487 L
.18935 .33323 L
.19165 .32965 L
.19278 .32728 L
.19369 .32489 L
.19461 .32184 L
.19528 .31881 L
.19574 .31598 L
.19605 .31284 L
.19618 .30936 L
.19616 .3076 L
.19608 .30568 L
.19577 .30231 L
.19529 .29925 L
.19457 .29606 L
.19359 .29286 L
.19259 .29033 L
.19133 .2878 L
.18981 .28541 L
.18801 .28327 L
.18713 .28244 L
.18618 .28169 L
.18442 .28064 L
.18271 .28001 L
.18086 .27974 L
.17912 .27987 L
.17754 .2803 L
.17573 .28119 L
.17474 .28187 L
.17385 .28261 L
.17229 .28423 L
.17075 .28629 L
.16847 .29057 L
.16742 .29333 L
.16661 .29603 L
.16599 .29868 L
.16549 .30167 L
.16517 .30458 L
Mistroke
.16502 .30731 L
.16502 .31082 L
.16522 .31408 L
.16558 .31697 L
.16613 .31999 L
.16692 .32314 L
.16798 .32625 L
.16904 .32869 L
.17035 .3311 L
.17187 .3333 L
.1734 .335 L
.17518 .33648 L
.17611 .33706 L
.17716 .33758 L
.17894 .33813 L
.17996 .33827 L
.18089 .33829 L
.18269 .33803 L
.18438 .33742 L
.18595 .33651 L
.18755 .33522 L
.18898 .33369 L
.1902 .33207 L
.19153 .32989 L
.1928 .32723 L
.19384 .32446 L
.19463 .32174 L
.19531 .31867 L
.19583 .31523 L
.19611 .31191 L
.19618 .30884 L
.19605 .30525 L
.19588 .30324 L
.19565 .30141 L
.19506 .29813 L
.19469 .29653 L
.19423 .29482 L
.19312 .2916 L
.19192 .28891 L
.19042 .28629 L
.18865 .28396 L
.18698 .28231 L
.18534 .28113 L
.18348 .28025 L
.18241 .27994 L
.18143 .27978 L
.17969 .27979 L
.17806 .28013 L
.17632 .28086 L
.1745 .28206 L
Mistroke
.17363 .28282 L
.1727 .28376 L
.17111 .28576 L
.16971 .28804 L
.16854 .29043 L
.1675 .2931 L
.16667 .2958 L
.16606 .29835 L
.16555 .30122 L
.16518 .30445 L
.165 .30792 L
.16502 .3109 L
.16523 .31415 L
.16543 .31595 L
.16572 .31787 L
.16642 .32126 L
.16731 .32438 L
.1683 .32706 L
.16955 .3297 L
.17111 .33227 L
.17291 .33451 L
.17377 .33535 L
.17474 .33616 L
.17644 .33724 L
.1783 .33798 L
.18004 .33828 L
.18167 .33823 L
.18358 .33775 L
.18528 .33694 L
.1862 .33633 L
.18717 .33556 L
.18885 .33385 L
.19066 .33137 L
.19237 .3282 L
.19373 .32479 L
.19472 .32138 L
.19521 .31919 L
.19558 .31711 L
.19588 .31477 L
.19609 .31225 L
.19617 .31004 L
.19617 .30796 L
.19608 .30569 L
.19588 .30326 L
.19558 .30097 L
.19522 .29889 L
.19473 .29667 L
.1941 .29439 L
.19249 .2901 L
.1907 .28672 L
Mistroke
.18879 .28412 L
.18763 .2829 L
.18652 .28194 L
.18543 .28119 L
.18438 .28062 L
.18327 .28018 L
.18203 .27987 L
Mfstroke
.19619 .43998 m
.24946 .4153 L
.29508 .38826 L
.31305 .37462 L
.32852 .36003 L
.33464 .35295 L
.33958 .34625 L
.34358 .33979 L
.34664 .33373 L
.34923 .32705 L
.35028 .32351 L
.35115 .3197 L
.35149 .3178 L
.35178 .31572 L
.35198 .31376 L
.35211 .31194 L
.35219 .3085 L
.35213 .30658 L
.35203 .30483 L
.35166 .3014 L
.35113 .29824 L
.35034 .29477 L
.34927 .2911 L
.34691 .28493 L
.34353 .27816 L
.33301 .26311 L
.31717 .24697 L
.27658 .21784 L
.22305 .18987 L
.2059 .1822 L
.2012 .18018 L
.19605 .178 L
.19112 .17629 L
.18654 .17529 L
.17828 .17489 L
.16962 .17641 L
.16507 .17802 L
.16089 .18002 L
.15639 .18274 L
.1517 .18627 L
.14364 .19414 L
.13673 .20304 L
.12985 .21448 L
.12348 .22829 L
.11881 .2415 L
.11521 .25472 L
.11219 .26998 L
.11093 .27882 L
.11007 .28701 L
.10919 .30229 L
Mistroke
.10921 .31654 L
.11016 .33207 L
.11222 .34826 L
.11517 .36316 L
.11879 .37648 L
.12269 .38773 L
.12755 .399 L
.1334 .40982 L
.1395 .41884 L
.14714 .42762 L
.15455 .434 L
.16185 .43853 L
.16879 .44138 L
.17654 .443 L
.18481 .44298 L
.19304 .44116 L
.1976 .43939 L
.20172 .43764 L
.21679 .43102 L
.24817 .41596 L
.29588 .3877 L
.31437 .3735 L
.33037 .35799 L
.33616 .35099 L
.34143 .34341 L
.3452 .33672 L
.34831 .32966 L
.35034 .32328 L
.35116 .31966 L
.35171 .31627 L
.35203 .31317 L
.35217 .31033 L
.35215 .30705 L
.35195 .30395 L
.35155 .30065 L
.35123 .29877 L
.35087 .297 L
.3499 .29315 L
.34876 .28962 L
.34614 .28323 L
.34248 .27635 L
.33183 .26171 L
.3164 .24629 L
.28025 .22009 L
.25506 .20568 L
.22778 .19207 L
.21434 .18591 L
.19934 .17938 L
.1912 .17631 L
.18651 .17528 L
Mistroke
.18209 .17485 L
.17432 .17534 L
.16607 .17762 L
.1588 .18121 L
.15114 .18673 L
.14427 .19343 L
.13827 .20086 L
.12815 .2178 L
.1233 .22874 L
.11946 .23944 L
.11567 .25283 L
.11287 .26598 L
.11068 .28095 L
.10937 .2974 L
.10912 .30575 L
.10916 .31484 L
.11009 .33126 L
.11201 .34693 L
.11467 .36094 L
.11786 .3734 L
.12147 .38447 L
.12647 .39671 L
.13169 .40691 L
.13729 .4158 L
.14393 .42423 L
.15107 .43124 L
.15899 .43694 L
.16335 .43926 L
.16815 .44117 L
.17275 .44241 L
.17701 .44305 L
.1851 .44295 L
.19361 .44097 L
.19795 .43924 L
.20254 .43729 L
.21065 .43376 L
.22828 .42573 L
.27995 .39814 L
.31809 .37025 L
.33339 .35448 L
.3391 .34694 L
.34353 .33986 L
.34691 .3331 L
.34835 .32954 L
.34963 .3258 L
.3505 .32263 L
.35125 .31916 L
.35174 .31601 L
.35204 .31307 L
.35214 .31129 L
Mistroke
.35218 .30936 L
.3521 .30586 L
.35179 .30245 L
.35133 .2993 L
.35062 .2959 L
.3496 .29215 L
.34675 .28456 L
.34329 .27774 L
.33854 .27028 L
.32729 .2567 L
.31312 .24348 L
.29712 .23121 L
.25077 .20342 L
.21897 .188 L
.20365 .18123 L
.1952 .17765 L
.19036 .17608 L
.18591 .17519 L
.18165 .17484 L
.17701 .17499 L
.16862 .17671 L
.16043 .18027 L
.15309 .18514 L
.14574 .19184 L
.13816 .201 L
.13097 .2124 L
.125 .22464 L
.11973 .23861 L
.11525 .25457 L
.11235 .26898 L
.11111 .27739 L
.11022 .28534 L
.1095 .29472 L
.10915 .30364 L
.10911 .31167 L
.10935 .32036 L
.10996 .32979 L
.11098 .33965 L
.11217 .34794 L
.1138 .35687 L
.11754 .37229 L
.12203 .38601 L
.12678 .39738 L
.13267 .40861 L
.1398 .41923 L
.14811 .42857 L
.15237 .43232 L
.1565 .43537 L
.16444 .43975 L
.1723 .44231 L
Mistroke
.1807 .44322 L
.18787 .44252 L
.19565 .4402 L
.20385 .43673 L
.21238 .433 L
.22712 .42628 L
.27977 .39824 L
.30178 .38346 L
.32078 .36778 L
.3337 .3541 L
.33918 .34683 L
.34401 .33901 L
.34745 .33185 L
.34866 .32871 L
.34978 .32529 L
.35059 .32225 L
.35128 .31901 L
.35179 .31559 L
.35208 .31242 L
.35219 .30901 L
.35215 .30708 L
.35206 .30528 L
.3519 .30337 L
.35169 .30163 L
.35138 .29963 L
.35103 .29772 L
.34931 .29125 L
.34801 .28758 L
.34658 .28419 L
.33789 .26938 L
.33199 .26189 L
.32428 .25362 L
.28804 .22504 L
.24044 .19818 L
.21297 .1853 L
.20492 .18177 L
.20039 .17983 L
.19606 .178 L
.18747 .17545 L
.17958 .17483 L
.1712 .17598 L
.16702 .17726 L
.16247 .1792 L
.15462 .18398 L
.14759 .18997 L
.13981 .19879 L
.13327 .20842 L
.12653 .22121 L
.12101 .23484 L
.11706 .24749 L
Mistroke
.11412 .25959 L
.11155 .27416 L
.10995 .28831 L
.10921 .30165 L
.10915 .314 L
.10978 .3275 L
.11123 .34155 L
.1135 .35538 L
.1168 .3696 L
.12069 .38228 L
.12486 .39308 L
.13045 .40469 L
.13731 .41583 L
.14442 .42478 L
.15146 .43158 L
.15885 .43686 L
.16691 .44074 L
.17394 .44264 L
.18171 .4432 L
.19008 .44203 L
.19472 .44057 L
.19888 .43885 L
.21412 .43222 L
.26422 .40736 L
.28746 .39337 L
.30864 .37821 L
.32469 .364 L
.33639 .3507 L
.34447 .33814 L
.34775 .3311 L
.34996 .32466 L
.35088 .32101 L
.35151 .31763 L
.35178 .31568 L
.35197 .31392 L
.35211 .31188 L
.35218 .30997 L
.35213 .30647 L
.35189 .30326 L
.3514 .29974 L
.35108 .29796 L
.35065 .29602 L
.34959 .29213 L
.34834 .28845 L
.34532 .28155 L
.34111 .27413 L
.3354 .26606 L
.32215 .25155 L
.30649 .23814 L
.26584 .21158 L
Mistroke
.21608 .18669 L
.2082 .1832 L
.19933 .17938 L
.19072 .17618 L
.18259 .17487 L
.17451 .17531 L
.16725 .17718 L
.15904 .18106 L
.15159 .18636 L
.14385 .1939 L
.13627 .20372 L
.13037 .2135 L
.1246 .22557 L
.1193 .23992 L
.11682 .24834 L
.11478 .2566 L
.11315 .2645 L
.11168 .27329 L
.10989 .28906 L
.10914 .30429 L
.10927 .31833 L
.11031 .33361 L
.1124 .34936 L
.11505 .36262 L
.11817 .37444 L
.12228 .38667 L
.12743 .39875 L
.13385 .41056 L
.14164 .42155 L
.14967 .43001 L
.15753 .43604 L
.1649 .43995 L
.17322 .4425 L
.18202 .44319 L
.19023 .44199 L
.19877 .43889 L
.20782 .435 L
.2236 .42792 L
.25075 .41462 L
.2782 .39921 L
.30009 .3847 L
.31719 .37105 L
.33186 .35629 L
.33709 .34976 L
.34176 .34287 L
.34536 .33642 L
.34797 .33054 L
.35023 .32367 L
.35111 .31989 L
.3517 .3163 L
Mistroke
.35204 .313 L
.35218 .30994 L
.35213 .30659 L
.35186 .30302 L
.35136 .29946 L
.35097 .29746 L
.35055 .29562 L
.34842 .28867 L
.34693 .28499 L
.34502 .28096 L
.34028 .27284 L
.32877 .25828 L
.31438 .24454 L
.27824 .21885 L
.2259 .19118 L
.20913 .18361 L
.19952 .17946 L
.19471 .17746 L
.19026 .17605 L
.18222 .17486 L
.17358 .17547 L
.16911 .17656 L
.16429 .17835 L
.15981 .18062 L
.15573 .18319 L
.14778 .18978 L
.13993 .19863 L
.13375 .20763 L
.12763 .21887 L
.12188 .23245 L
.11681 .24839 L
.11479 .25656 L
.11315 .2645 L
.11081 .27982 L
.1095 .29483 L
.1091 .31093 L
.10958 .32466 L
.11098 .33959 L
.11346 .35518 L
.11529 .36365 L
.11723 .37118 L
.12141 .38432 L
.12672 .39725 L
.13255 .40841 L
.13841 .41737 L
.14485 .42524 L
.15113 .4313 L
.15885 .43686 L
.16304 .43911 L
.16753 .44096 L
Mistroke
.1752 .44283 L
.18369 .44309 L
.1916 .44161 L
.1987 .43892 L
.21408 .43224 L
.23978 .42019 L
.28534 .39474 L
.32086 .36771 L
.3341 .35362 L
.33966 .34613 L
.34452 .33806 L
.34792 .33067 L
.3491 .32744 L
.35017 .3239 L
.35098 .32055 L
.35154 .31743 L
.35195 .31414 L
.35216 .31062 L
.35216 .30723 L
.35206 .3053 L
.35191 .3035 L
.35142 .29987 L
.35105 .29783 L
.35064 .29597 L
.34855 .28903 L
.34577 .28245 L
.34158 .27487 L
.33677 .26785 L
.32253 .25192 L
.3061 .23784 L
.2881 .22508 L
.26511 .21117 L
.23704 .1965 L
.20848 .18332 L
.2001 .17971 L
.19539 .17773 L
.19087 .17622 L
.18663 .1753 L
.182 .17485 L
.17389 .17541 L
.16654 .17744 L
.15861 .18132 L
.15064 .18716 L
.14356 .19422 L
.13212 .21037 L
.12652 .22123 L
.12198 .23216 L
.1177 .2452 L
.11403 .26004 L
.11147 .27471 L
Mistroke
.10994 .28842 L
.10913 .30485 L
.10915 .31415 L
.10947 .3227 L
.11081 .33825 L
.11328 .35425 L
.11662 .36895 L
.12122 .38377 L
.12644 .39664 L
.1319 .40729 L
.13904 .41823 L
.14759 .42807 L
.15174 .4318 L
.15627 .43522 L
.16469 .43986 L
.16935 .44155 L
.1745 .44273 L
.17991 .44321 L
.18495 .44296 L
.18967 .44213 L
.19392 .44086 L
.20329 .43697 L
.24081 .41968 L
.2949 .38838 L
Mfstroke
.50819 .17805 m
.44383 .15337 L
.36062 .12633 L
.3136 .11269 L
.25956 .0981 L
.23194 .09102 L
.21803 .08754 L
.20499 .08433 L
.193 .08149 L
.18016 .0803 L
.16727 .08167 L
.15326 .08613 L
.14556 .08995 L
.13856 .09434 L
.12327 .10718 L
.11069 .12168 L
.09841 .14015 L
.08768 .16105 L
.07893 .18293 L
.07232 .20411 L
.06657 .22838 L
.06398 .2427 L
.06202 .25633 L
.0604 .27151 L
.05926 .28797 L
.05876 .30535 L
.05894 .32183 L
.05963 .33657 L
.06097 .35247 L
.06259 .36602 L
.06489 .38074 L
.07113 .40947 L
.0787 .43445 L
.08728 .4561 L
.0966 .47472 L
.108 .49272 L
.12105 .50857 L
.13406 .52041 L
.1469 .52882 L
.15892 .53409 L
.17307 .5373 L
.18653 .53746 L
.20111 .53466 L
.2163 .53092 L
.24291 .52423 L
.30005 .50911 L
.39461 .48117 L
.47126 .45466 L
.53359 .42884 L
.58056 .40491 L
Mistroke
.61924 .37932 L
.63485 .36581 L
.64783 .35142 L
.65308 .34395 L
.65762 .33588 L
.65931 .33218 L
.66082 .32827 L
.66189 .32489 L
.66282 .32127 L
.66349 .31774 L
.66391 .31453 L
.66414 .3113 L
.66418 .30824 L
.66401 .30468 L
.66366 .3014 L
.66304 .29779 L
.66212 .29396 L
.65993 .28739 L
.65677 .28047 L
.64897 .26812 L
.63748 .25483 L
.62124 .2403 L
.58246 .21423 L
.53534 .19 L
.38438 .13362 L
.29942 .10876 L
.24823 .09517 L
.222 .08853 L
.21029 .08563 L
.19736 .08247 L
.1839 .08039 L
.1711 .081 L
.15658 .08478 L
.14345 .09119 L
.13057 .10046 L
.11709 .11382 L
.10407 .13102 L
.09303 .14996 L
.08458 .16819 L
.07684 .18909 L
.07124 .20813 L
.06625 .23001 L
.06225 .25458 L
.05962 .2816 L
.05875 .30748 L
.05931 .33104 L
.06163 .35851 L
.06347 .37212 L
.06601 .38682 L
.07177 .4119 L
Mistroke
.07857 .43406 L
.08819 .45811 L
.0984 .47786 L
.11165 .4976 L
.12547 .51299 L
.13819 .52344 L
.15235 .53151 L
.16609 .53611 L
.17872 .53771 L
.19363 .53642 L
.20196 .53445 L
.20956 .53259 L
.23772 .52555 L
.43039 .46935 L
.50357 .44191 L
.55833 .4169 L
.60307 .39099 L
.63418 .36646 L
.64659 .35301 L
.65514 .34057 L
.65848 .33407 L
.66128 .32691 L
.66233 .32331 L
.66279 .32142 L
.6632 .31943 L
.66351 .31768 L
.66377 .31577 L
.66408 .31241 L
.66419 .30878 L
.66407 .30543 L
.66393 .30368 L
.66371 .30175 L
.66341 .29974 L
.66306 .29786 L
.66131 .29124 L
.65999 .28752 L
.65855 .28413 L
.65101 .27095 L
.64092 .25844 L
.62588 .24412 L
.60862 .23086 L
.55768 .20081 L
.49253 .17164 L
.41714 .14421 L
.33844 .11977 L
.23972 .09299 L
.21283 .08625 L
.2056 .08448 L
.19768 .08255 L
.18316 .08035 L
Mistroke
.16846 .08144 L
.15503 .08539 L
.14296 .09148 L
.13059 .10044 L
.11819 .11257 L
.10577 .1285 L
.09509 .14607 L
.08633 .1641 L
.07746 .18722 L
.07341 .20023 L
.06961 .21462 L
.06647 .22887 L
.06408 .24211 L
.06066 .26864 L
.05903 .2933 L
.05887 .31956 L
.06001 .34189 L
.06259 .36603 L
.0669 .39126 L
.06998 .40496 L
.07321 .41709 L
.08063 .4398 L
.08871 .45923 L
.10713 .49149 L
.11817 .50544 L
.13071 .5177 L
.14211 .52604 L
.15318 .53187 L
.16559 .536 L
.17915 .53772 L
.19348 .53645 L
.20637 .53337 L
.23464 .52633 L
.28331 .51365 L
.38293 .48487 L
.47119 .45469 L
.53791 .42685 L
.58684 .40124 L
.62565 .37411 L
.64051 .36005 L
.65115 .34688 L
.65583 .33934 L
.6592 .33244 L
.66069 .32863 L
.66201 .32448 L
.66298 .32056 L
.66362 .31692 L
.66402 .31337 L
.66413 .31159 L
.66418 .30963 L
Mistroke
.66411 .30616 L
.66385 .30293 L
.6636 .30096 L
.66329 .2991 L
.66256 .29562 L
.66152 .29188 L
.66009 .2878 L
.65699 .28089 L
.65275 .27356 L
.64269 .2604 L
.63014 .24783 L
.61576 .23605 L
.57356 .2092 L
.51768 .1821 L
.4445 .15361 L
.36257 .12692 L
.27697 .10269 L
.22812 .09006 L
.21423 .0866 L
.19931 .08294 L
.18638 .08056 L
.17211 .08086 L
.15726 .08453 L
.14907 .08809 L
.14172 .09225 L
.12792 .10277 L
.11556 .1156 L
.1041 .13098 L
.0944 .14735 L
.0849 .16743 L
.07624 .19093 L
.07017 .21232 L
.06569 .23291 L
.06202 .25633 L
.05962 .28167 L
.05877 .30405 L
.05904 .32495 L
.0605 .34772 L
.0634 .37164 L
.0681 .39689 L
.07493 .42291 L
.08294 .44581 L
.09158 .46522 L
.11084 .49655 L
.12176 .50931 L
.13455 .52078 L
.14851 .52967 L
.1619 .53503 L
.17685 .53763 L
.18525 .53757 L
Mistroke
.19284 .53658 L
.20666 .5333 L
.22138 .52966 L
.24743 .52307 L
.34084 .49756 L
.42793 .47019 L
.50781 .44014 L
.56459 .41366 L
.61128 .38529 L
.63079 .36961 L
.64469 .35532 L
.65005 .34844 L
.65491 .34095 L
.65832 .33441 L
.65981 .33097 L
.66113 .32735 L
.66214 .32402 L
.66301 .32039 L
.6636 .31708 L
.66396 .31401 L
.66416 .31084 L
.66418 .30795 L
.66401 .30463 L
.66367 .30149 L
.66309 .29803 L
.66223 .29436 L
.66009 .28779 L
.65691 .28072 L
.65235 .27295 L
.64102 .25855 L
.62466 .24309 L
.58407 .21517 L
.52942 .18729 L
.45376 .15692 L
.36581 .1279 L
.27297 .10163 L
.22065 .08819 L
.20575 .08451 L
.1975 .0825 L
.18976 .08095 L
.17598 .08046 L
.16095 .08329 L
.14709 .08911 L
.1344 .09737 L
.12348 .10698 L
.11225 .11966 L
.10094 .13594 L
.09013 .15578 L
.082 .17461 L
.07433 .19709 L
Mistroke
.07081 .2098 L
.06745 .22413 L
.06493 .23709 L
.0627 .2512 L
.05984 .27843 L
.05877 .30413 L
.05888 .31976 L
.05964 .33662 L
.06096 .3524 L
.06269 .36675 L
.06731 .39324 L
.07028 .40614 L
.07402 .41988 L
.082 .44343 L
.09093 .4639 L
.10271 .48491 L
.11466 .50137 L
.12681 .51425 L
.13868 .52378 L
.15224 .53146 L
.16708 .53633 L
.18004 .53773 L
.19422 .5363 L
.20885 .53277 L
.22226 .52945 L
.27026 .51713 L
.36835 .48937 L
.51026 .43911 L
.57107 .41021 L
.61455 .3829 L
.62926 .371 L
.64203 .35839 L
.64755 .35181 L
.65271 .34456 L
.65635 .33841 L
.65948 .3318 L
.66196 .32473 L
Mfstroke
.50819 .30902 m
.50809 .30579 L
.50784 .30284 L
.50736 .29945 L
.5067 .29624 L
.50508 .29053 L
.50265 .28433 L
.49916 .27751 L
.49453 .27027 L
.48385 .25729 L
.46961 .24389 L
.45331 .23134 L
.4055 .20276 L
.34142 .17361 L
.26924 .14693 L
.22387 .13221 L
.21075 .12818 L
.20342 .12597 L
.19644 .12388 L
.18985 .12231 L
.18267 .12155 L
.17613 .12169 L
.17014 .12253 L
.15834 .12622 L
.14761 .13202 L
.13631 .14093 L
.12495 .15329 L
.11407 .16912 L
.10493 .18658 L
.09782 .20404 L
.09138 .22466 L
.08683 .24431 L
.08374 .26308 L
.08157 .28425 L
.0807 .30689 L
.08114 .3267 L
.08255 .34495 L
.08518 .36457 L
.08922 .38481 L
.09502 .40576 L
.10283 .42673 L
.11155 .44453 L
.1206 .45895 L
.1295 .47015 L
.13996 .48032 L
.15148 .4884 L
.16267 .49349 L
.17476 .49621 L
.18165 .49652 L
.18804 .49601 L
Mistroke
.19964 .4932 L
.21176 .48955 L
.25383 .47625 L
.33671 .44633 L
.40023 .41796 L
.42776 .40306 L
.45241 .38733 L
.47034 .37353 L
.48601 .3584 L
.49157 .35176 L
.49664 .34464 L
.50026 .33854 L
.50346 .33182 L
.50594 .32475 L
.50691 .32087 L
.50757 .31724 L
.50798 .31385 L
.50816 .31075 L
.50816 .30735 L
.50794 .30377 L
.50772 .30185 L
.50747 .30012 L
.5067 .29622 L
.50574 .29261 L
.50462 .2892 L
.50133 .28157 L
.49658 .27329 L
.48569 .25928 L
.47029 .24447 L
.43271 .21792 L
.38343 .1919 L
.31686 .16398 L
.2795 .15045 L
.24101 .13763 L
.22333 .13205 L
.20391 .12612 L
.19354 .12309 L
.18192 .12152 L
.17134 .12231 L
.16149 .12497 L
.15083 .13002 L
.13983 .13783 L
.12997 .14737 L
.12154 .15778 L
.11241 .17198 L
.10359 .18957 L
.09643 .208 L
.09093 .22635 L
.08644 .24637 L
.08338 .26589 L
Mistroke
.08133 .28787 L
.0808 .30037 L
.08071 .31183 L
.08164 .33473 L
.08283 .34754 L
.08435 .35926 L
.08816 .38016 L
.09364 .40133 L
.1 .41982 L
.10684 .43549 L
.11533 .45098 L
.12529 .46517 L
.13466 .47554 L
.14391 .48343 L
.15449 .49001 L
.16618 .49457 L
.17675 .49639 L
.18829 .49597 L
.19909 .49336 L
.20893 .49041 L
.24577 .47887 L
.3805 .4275 L
.43574 .39826 L
.45546 .38516 L
.47344 .37083 L
.48742 .3568 L
.49721 .34376 L
.50129 .33654 L
.50419 .32999 L
.50545 .32635 L
.50655 .32242 L
.50696 .32061 L
.50733 .3187 L
.50783 .31528 L
.5081 .31212 L
.50818 .30924 L
.5081 .30591 L
.50783 .30275 L
.50742 .29984 L
.5069 .29714 L
.50524 .29103 L
.50399 .28754 L
.50261 .28425 L
.4995 .27812 L
.49006 .26437 L
.47811 .25151 L
.46156 .23742 L
.4172 .209 L
.36301 .18268 L
.30116 .15815 L
Mistroke
.26147 .14432 L
.23915 .13703 L
.21442 .1293 L
.2037 .12605 L
.19195 .12273 L
.18514 .1217 L
.17889 .12154 L
.16667 .12334 L
.15593 .12731 L
.14455 .13413 L
.13428 .14288 L
.12526 .1529 L
.1165 .16518 L
.1079 .1804 L
.10115 .19532 L
.09497 .21244 L
.09027 .2289 L
.08615 .2479 L
.08339 .26581 L
.08167 .28292 L
.08072 .30471 L
.08108 .32541 L
.08243 .34384 L
.085 .36349 L
.08906 .38411 L
.09474 .40489 L
.10065 .42146 L
.10822 .43827 L
.11595 .45198 L
.12502 .46483 L
.13579 .47661 L
.14644 .48523 L
.1524 .48891 L
.15899 .49209 L
.17118 .49569 L
.18319 .49646 L
.19423 .49477 L
.20442 .49177 L
.2138 .48892 L
.2346 .48245 L
.27433 .46936 L
.35226 .43995 L
.4117 .41201 L
.45521 .38534 L
.47409 .37024 L
.4879 .35624 L
.49323 .34957 L
.4975 .34329 L
.50076 .33758 L
.50356 .33156 L
Mistroke
.50476 .32842 L
.50587 .32498 L
.5067 .32181 L
.50729 .31893 L
.5078 .31551 L
.50799 .31364 L
.50811 .31186 L
.50818 .3087 L
.50806 .30527 L
.50773 .30191 L
.50724 .29884 L
.50651 .29546 L
.50552 .29191 L
.50333 .28591 L
.50019 .27937 L
.49021 .26457 L
.47736 .25081 L
.44064 .22284 L
.38576 .193 L
.31895 .16478 L
.27796 .14992 L
.23025 .13421 L
.20875 .12758 L
.20295 .12583 L
.19657 .12392 L
.18482 .12168 L
.17759 .12159 L
.17091 .12239 L
.1648 .12386 L
.15837 .12621 L
.14702 .13241 L
.14075 .13706 L
.13503 .14215 L
.12548 .15263 L
.11614 .16575 L
.10171 .19397 L
.09512 .21195 L
.09003 .22988 L
.08566 .25063 L
.0838 .26262 L
.08248 .27372 L
.081 .29444 L
.08073 .31402 L
.08169 .33544 L
.08418 .35807 L
.08597 .36912 L
.08833 .38092 L
.0937 .40154 L
.10018 .42028 L
.10722 .43627 L
Mistroke
.11533 .45098 L
.12372 .46318 L
.13191 .47276 L
.14105 .48122 L
.1515 .4884 L
.16143 .49305 L
.17234 .49589 L
.18443 .49639 L
.19068 .49557 L
.19743 .49386 L
.20952 .49023 L
.23153 .48342 L
.27793 .46813 L
.35088 .44053 L
.41085 .41247 L
.4541 .38613 L
.47106 .37291 L
.48577 .35866 L
.49219 .35096 L
.49778 .34284 L
.5016 .33592 L
.50339 .33198 L
.50479 .32835 L
.50585 .32502 L
.5068 .32137 L
.5075 .31769 L
.50778 .31568 L
.50798 .3138 L
.50817 .31035 L
.50815 .30719 L
.50807 .30544 L
.50791 .30354 L
.50746 .30008 L
.5068 .29669 L
.50603 .29362 L
.50367 .28675 L
.50073 .28039 L
.49728 .2744 L
.48629 .25996 L
.47285 .24669 L
.43079 .21677 L
.37916 .18992 L
.31922 .16488 L
.24033 .13741 L
.21507 .1295 L
.20224 .12561 L
.19014 .12237 L
.17903 .12153 L
.16728 .12318 L
.15567 .12744 L
Mistroke
.14921 .131 L
.14328 .13508 L
.13274 .14442 L
.12222 .15684 L
.11312 .17074 L
.10567 .185 L
.09798 .2036 L
.09113 .2256 L
.08853 .23623 L
.08617 .24779 L
.08298 .26912 L
.08124 .28949 L
.08071 .3116 L
.08148 .33244 L
.08326 .35121 L
.08662 .37263 L
.08911 .38435 L
.09179 .3949 L
.09754 .41323 L
.10494 .43148 L
.1124 .44604 L
.11993 .458 L
.1282 .46867 L
.13637 .47716 L
.1458 .48479 L
.15654 .49102 L
.1673 .49486 L
.17898 .4965 L
.19053 .4956 L
.197 .49399 L
.20291 .49222 L
.22475 .48554 L
.26347 .47305 L
.39312 .42149 L
.44527 .39218 L
.47994 .36475 L
.4921 .35107 L
.49715 .34385 L
.50148 .33616 L
.50323 .33235 L
.50463 .32877 L
.50578 .32528 L
.50663 .32207 L
.50727 .31902 L
.50777 .31579 L
.50807 .31255 L
.50818 .309 L
.50808 .30558 L
.50778 .30234 L
.50735 .29943 L
Mistroke
.50671 .29627 L
.5058 .29284 L
.50461 .28919 L
.50185 .28264 L
.49499 .27094 L
.48454 .25804 L
.47031 .24449 L
.45174 .23024 L
.40934 .20477 L
.35052 .17736 L
.27059 .14739 L
.23084 .1344 L
.2102 .12802 L
.20091 .12522 L
.19053 .12244 L
.18112 .12151 L
.17231 .12215 L
.16308 .12441 L
.15335 .12861 L
.14303 .13526 L
.13366 .14349 L
.11751 .16362 L
.10932 .17763 L
.10266 .19171 L
.09637 .20819 L
.09068 .2273 L
.08649 .24608 L
.08362 .26399 L
.08178 .28153 L
.08081 .30029 L
.08089 .32078 L
.08231 .34253 L
.08487 .36265 L
.08822 .3804 L
.09334 .40032 L
.10027 .4205 L
.10802 .43788 L
.11613 .45226 L
Mfstroke
.50819 .43998 m
.56146 .4153 L
.60708 .38826 L
.62505 .37462 L
.64053 .36003 L
.64664 .35295 L
.65158 .34625 L
.65558 .33979 L
.65864 .33373 L
.66123 .32705 L
.66228 .32351 L
.66315 .3197 L
.66349 .3178 L
.66378 .31572 L
.66399 .31376 L
.66411 .31194 L
.66419 .3085 L
.66414 .30658 L
.66403 .30483 L
.66366 .3014 L
.66313 .29824 L
.66234 .29477 L
.66127 .2911 L
.65891 .28493 L
.65553 .27816 L
.64502 .26311 L
.62917 .24697 L
.58858 .21784 L
.53506 .18987 L
.46066 .15943 L
.38279 .13313 L
.28222 .10409 L
.23025 .09059 L
.21543 .0869 L
.19956 .083 L
.1858 .08051 L
.17069 .08106 L
.15646 .08483 L
.14382 .09096 L
.12976 .10115 L
.1172 .11369 L
.10633 .12769 L
.09708 .14247 L
.08723 .16205 L
.07936 .18173 L
.07232 .2041 L
.06632 .22963 L
.06228 .25436 L
.05984 .27849 L
.05907 .29222 L
Mistroke
.05875 .3069 L
.05943 .33328 L
.06065 .34931 L
.06235 .36421 L
.06431 .37737 L
.06691 .39132 L
.07313 .41683 L
.08181 .44291 L
.09277 .46756 L
.10455 .48773 L
.11679 .50387 L
.12877 .51602 L
.13569 .52164 L
.14339 .52682 L
.15781 .5337 L
.17167 .53712 L
.18447 .53762 L
.19847 .5353 L
.21299 .53174 L
.26237 .5192 L
.36419 .49063 L
.44948 .46266 L
.52479 .43282 L
.58162 .4043 L
.62038 .37841 L
.63473 .36592 L
.64707 .3524 L
.65162 .34619 L
.65566 .33962 L
.65851 .33399 L
.66095 .32787 L
.66208 .32424 L
.66291 .32088 L
.6635 .31767 L
.66394 .31426 L
.66414 .31122 L
.66418 .30836 L
.66405 .30522 L
.66372 .30184 L
.66317 .29846 L
.66233 .29475 L
.66119 .29089 L
.65989 .28728 L
.65696 .28083 L
.65298 .27392 L
.64264 .26035 L
.62979 .24753 L
.5977 .22352 L
.54971 .19683 L
.48471 .16855 L
Mistroke
.33168 .11782 L
.23546 .09191 L
.22125 .08834 L
.20549 .08445 L
.19819 .08267 L
.19034 .08104 L
.17616 .08045 L
.16128 .08319 L
.14754 .08888 L
.13556 .09649 L
.12317 .10729 L
.11197 .12001 L
.10224 .13386 L
.0917 .15259 L
.08318 .17161 L
.07549 .19331 L
.06946 .21525 L
.0645 .23959 L
.06081 .26706 L
.05919 .28941 L
.05878 .31428 L
.05988 .34019 L
.06234 .36414 L
.06583 .38589 L
.07003 .40516 L
.0757 .4254 L
.08279 .44543 L
.09187 .46579 L
.10305 .48545 L
.11474 .50145 L
.12633 .51381 L
.13736 .52286 L
.14997 .5304 L
.16352 .53548 L
.17639 .5376 L
.19148 .53682 L
.20564 .53355 L
.23164 .52709 L
.28736 .51256 L
.45122 .46204 L
.51851 .43557 L
.57613 .40742 L
.59893 .39372 L
.61726 .38085 L
.63212 .3684 L
.64342 .3568 L
.6531 .34394 L
.657 .33713 L
.66024 .32985 L
.66151 .32618 L
Mistroke
.66261 .3222 L
.66302 .32038 L
.66338 .31844 L
.66387 .31497 L
.66413 .31164 L
.66419 .30853 L
.66405 .30511 L
.66388 .30319 L
.66367 .30143 L
.66314 .2983 L
.66239 .29497 L
.66053 .28897 L
.65747 .28183 L
.65389 .27536 L
.64459 .2626 L
.63312 .25058 L
.59805 .22374 L
.54674 .19538 L
.41827 .14459 L
.33418 .11854 L
.28261 .10419 L
.23029 .0906 L
.20562 .08448 L
.19291 .08147 L
.17873 .08033 L
.17137 .08096 L
.16347 .08257 L
.14939 .08792 L
.13578 .09632 L
.12384 .10662 L
.11347 .11813 L
.10441 .13052 L
.09448 .14721 L
.08634 .16407 L
.07926 .18201 L
.07267 .20284 L
.06703 .22612 L
.063 .24907 L
.06011 .27492 L
.05886 .29896 L
.05912 .32682 L
.06102 .35304 L
.0642 .37667 L
.06832 .3979 L
.07411 .42019 L
.08165 .44249 L
.09145 .46494 L
.10365 .48637 L
.1165 .50354 L
.12927 .51646 L
Mistroke
.14145 .52562 L
.15534 .53277 L
.1702 .5369 L
.18422 .53763 L
.19912 .53514 L
.20745 .53311 L
.21508 .53123 L
.24336 .52412 L
.29386 .5108 L
.39555 .48088 L
.53224 .42947 L
.58855 .40021 L
.60873 .3871 L
.62722 .37277 L
.64085 .35967 L
.65196 .34568 L
.65658 .33794 L
.65983 .33091 L
.66107 .32752 L
.66219 .32385 L
.66301 .32038 L
.66358 .31718 L
.66394 .31424 L
.66415 .31109 L
.66418 .30811 L
.66407 .30539 L
.66377 .30221 L
.66323 .29874 L
.66252 .29547 L
.66169 .29244 L
.65954 .28641 L
.6564 .27975 L
.64756 .26627 L
.63542 .25278 L
.61905 .23857 L
.58059 .21315 L
.52606 .18578 L
.45072 .15582 L
.36661 .12814 L
.2743 .10198 L
.21793 .08752 L
.20182 .08355 L
.19289 .08147 L
.18446 .08042 L
.16956 .08124 L
.16171 .08306 L
.15335 .08609 L
.13934 .09381 L
.13165 .09956 L
.12473 .10575 L
Mistroke
.11166 .12042 L
.10074 .13626 L
.08282 .17252 L
.07489 .19525 L
.06878 .21814 L
.06417 .24155 L
.06077 .26752 L
.05906 .29257 L
.0588 .31558 L
.06006 .34247 L
.06151 .35747 L
.06333 .37117 L
.06782 .39563 L
.07417 .4204 L
.08163 .44247 L
.09112 .46429 L
.10042 .48126 L
.11163 .49758 L
.12515 .51269 L
.1324 .51909 L
.14037 .52492 L
.14804 .52943 L
.15514 .53269 L
.16924 .53674 L
.18241 .53771 L
.19633 .53582 L
.20808 .53295 L
.22083 .5298 L
.27375 .51621 L
.3612 .49154 L
.51279 .43803 L
.57507 .408 L
.59739 .39472 L
.61762 .38057 L
.63433 .36632 L
.64626 .35341 L
.65095 .34718 L
.65521 .34044 L
.65846 .33412 L
.66083 .32824 L
.66197 .32462 L
.66281 .32133 L
.66351 .31768 L
.66379 .31567 L
.66398 .31377 L
.66411 .31192 L
.66418 .30997 L
.66413 .30645 L
.664 .3045 L
.66382 .30267 L
Mistroke
.66356 .30067 L
.66318 .29851 L
.66241 .29502 L
.6613 .2912 L
.65861 .28425 L
.65514 .27748 L
.65118 .2712 L
.63982 .25726 L
.62355 .24217 L
.58346 .21481 L
.53136 .18817 L
.47198 .16365 L
.31087 .11193 L
.25824 .09776 L
.2277 .08995 L
.21225 .08611 L
.19772 .08255 L
.18392 .08039 L
.16921 .0813 L
.15461 .08556 L
.14645 .08946 L
.13894 .09408 L
.12639 .10418 L
.11546 .11571 L
.10427 .13072 L
.09354 .14899 L
.07933 .18179 L
.07287 .20214 L
.06799 .22163 L
.06434 .24053 L
.06139 .26163 L
.0596 .28194 L
.05882 .30089 L
Mfstroke
.82019 .17805 m
.67263 .12633 L
.46436 .0718 L
.34256 .04508 L
.27004 .03038 L
.23296 .02316 L
.21637 .01999 L
.19788 .01649 L
.18735 .01499 L
.17746 .01477 L
.16702 .01582 L
.15587 .01839 L
.14386 .0229 L
.13265 .02881 L
.12281 .03543 L
.11237 .04404 L
.0949 .06256 L
.07783 .08674 L
.06347 .11336 L
.05212 .14031 L
.04166 .17261 L
.03406 .20433 L
.03089 .22154 L
.02807 .24082 L
.02588 .26127 L
.02454 .28059 L
.02386 .3165 L
.02527 .34916 L
.02688 .36703 L
.0293 .38621 L
.03541 .42015 L
.04311 .45051 L
.05175 .47672 L
.06286 .50338 L
.07623 .52866 L
.08827 .54689 L
.10212 .56381 L
.11831 .57911 L
.13413 .5901 L
.14404 .59521 L
.15331 .59883 L
.16361 .60159 L
.17459 .60311 L
.19308 .60239 L
.20354 .60048 L
.21325 .59864 L
.28314 .58506 L
.5429 .52728 L
.73611 .47149 L
.86314 .4205 L
Mistroke
.91149 .39336 L
.94435 .36819 L
.95804 .35369 L
.96714 .34056 L
.97083 .33328 L
.97239 .32945 L
.97374 .32541 L
.97469 .32186 L
.97509 .31999 L
.97546 .31798 L
.97592 .31445 L
.97615 .31115 L
.97617 .30779 L
.9761 .30587 L
.97597 .30408 L
.97552 .30046 L
.97517 .29843 L
.97478 .29657 L
.9729 .29001 L
.97166 .28671 L
.97008 .2831 L
.96594 .27546 L
.96036 .2673 L
.94726 .25263 L
.92991 .23768 L
.90982 .2236 L
.86258 .19726 L
.72279 .1421 L
.54513 .09132 L
.44069 .06638 L
.31605 .03961 L
.27685 .03173 L
.23865 .02426 L
.20349 .01755 L
.19372 .01575 L
.18327 .01476 L
.1645 .01627 L
.14742 .02138 L
.12945 .03081 L
.11314 .04334 L
.09892 .0578 L
.08419 .07693 L
.06951 .10133 L
.05604 .13027 L
.0454 .15996 L
.0369 .19128 L
.03311 .20915 L
.03013 .22628 L
.02625 .25724 L
.02407 .292 L
Mistroke
.02381 .3115 L
.02421 .33001 L
.02662 .36447 L
.0289 .38341 L
.03161 .4007 L
.0398 .43851 L
.04923 .46969 L
.05991 .49688 L
.08398 .54081 L
.09951 .56091 L
.11483 .57618 L
.13257 .58918 L
.14178 .59416 L
.15206 .59841 L
.17027 .60268 L
.18764 .60302 L
.20317 .60055 L
.21989 .59738 L
.28991 .5837 L
.40763 .55904 L
.6244 .50568 L
.71846 .47735 L
.80346 .44682 L
.86868 .41773 L
.91493 .39108 L
.94707 .36559 L
.95876 .35278 L
.96813 .33877 L
.97147 .33179 L
.97287 .32811 L
.97408 .32422 L
.97492 .32082 L
.97527 .31901 L
.97559 .31707 L
.97599 .31367 L
.97616 .31049 L
.97615 .30719 L
.97592 .3036 L
.97548 .30021 L
.97488 .29706 L
.97412 .29394 L
.97327 .29112 L
.97085 .2848 L
.96706 .27736 L
.9627 .27052 L
.94974 .2551 L
.93472 .2415 L
.91525 .22717 L
.87006 .201 L
.80793 .17301 L
Mistroke
.65988 .12254 L
.55746 .09446 L
.43 .06397 L
.36594 .04999 L
.29412 .03518 L
.22964 .02253 L
.21147 .01906 L
.20135 .01715 L
.19167 .01545 L
.17283 .01508 L
.15568 .01845 L
.13783 .02587 L
.12802 .03176 L
.11918 .03823 L
.10354 .05271 L
.08805 .07145 L
.06434 .11156 L
.05296 .13809 L
.04388 .16495 L
.03542 .19789 L
.02946 .23069 L
.0259 .26107 L
.02399 .29473 L
.02382 .31221 L
.02427 .33149 L
.02545 .35152 L
.02723 .37016 L
.03197 .40274 L
.03927 .43647 L
.04746 .46444 L
.05648 .48884 L
.06885 .51545 L
.08149 .53707 L
.09505 .55565 L
.11085 .5726 L
.12857 .58665 L
.14602 .59608 L
.16136 .6011 L
.17845 .60329 L
.19632 .60183 L
.2129 .5987 L
.27283 .5871 L
.50741 .53604 L
.70915 .48036 L
.79499 .45016 L
.85976 .42215 L
.90833 .39538 L
.92966 .38052 L
.94573 .36687 L
.95851 .35308 L
Mistroke
.96369 .34605 L
.96825 .33853 L
.97179 .33097 L
.97303 .32759 L
.97415 .32392 L
.97471 .32168 L
.97515 .31961 L
.97549 .31767 L
.97578 .31553 L
.97598 .31362 L
.9761 .31183 L
.97616 .30994 L
.97616 .3079 L
.97597 .3044 L
.9756 .30115 L
.97498 .29759 L
.97406 .29378 L
.9728 .28977 L
.97135 .286 L
.96793 .27893 L
.95949 .26619 L
.94701 .2524 L
.91396 .22632 L
.86337 .19765 L
.79459 .16773 L
.71558 .13975 L
.51512 .08387 L
.40833 .05916 L
.28255 .03287 L
.25098 .02665 L
.21612 .01995 L
.20626 .01808 L
.1958 .01611 L
.17696 .0148 L
.15935 .01743 L
.14038 .02456 L
.12359 .03486 L
.10894 .04725 L
.09297 .06496 L
.07901 .08485 L
.05741 .12696 L
.04732 .15402 L
.03949 .18073 L
.03273 .21114 L
.02754 .2452 L
.02467 .27821 L
.02381 .30877 L
.02495 .34445 L
.02662 .36445 L
.02881 .38278 L
Mistroke
.03443 .41552 L
.03845 .43321 L
.04262 .4488 L
.05258 .47895 L
.06513 .5081 L
.08102 .53635 L
.09737 .55843 L
.11386 .57533 L
.13012 .58766 L
.14869 .59716 L
.15933 .6006 L
.16911 .60253 L
.18646 .60311 L
.20269 .60063 L
.23906 .59369 L
.31001 .57965 L
.42843 .55442 L
.65368 .49732 L
.73967 .47027 L
.81582 .44179 L
.86975 .41718 L
.91519 .3909 L
.93388 .3772 L
.94839 .36428 L
.95883 .35268 L
.96326 .34669 L
.96738 .3401 L
.97033 .33434 L
.97283 .32816 L
.97391 .32475 L
.97472 .32163 L
.97535 .31849 L
.97578 .31552 L
.97604 .31279 L
.97616 .30989 L
.97613 .30715 L
.97599 .30467 L
.97568 .30175 L
.97517 .29858 L
.97453 .2956 L
.97379 .29286 L
Mfstroke
.82019 .30902 m
.8201 .30579 L
.81985 .30284 L
.81936 .29945 L
.81871 .29624 L
.81708 .29053 L
.81465 .28433 L
.81116 .27751 L
.80654 .27027 L
.79586 .25729 L
.78162 .24389 L
.76532 .23134 L
.7175 .20276 L
.65342 .17361 L
.58124 .14693 L
.4806 .11579 L
.37137 .08688 L
.26344 .06161 L
.23021 .05433 L
.21356 .05076 L
.19803 .04748 L
.18373 .04553 L
.16858 .04642 L
.15352 .0504 L
.13737 .05826 L
.12911 .06381 L
.12035 .07095 L
.10517 .0867 L
.0915 .10531 L
.08 .12515 L
.06899 .14908 L
.05871 .17815 L
.05435 .19367 L
.05026 .21096 L
.04705 .22763 L
.0446 .24347 L
.04151 .27295 L
.0406 .28875 L
.0402 .30571 L
.0404 .32357 L
.04118 .34036 L
.04417 .37138 L
.04875 .39966 L
.05444 .42474 L
.06224 .45083 L
.07216 .47645 L
.08297 .49845 L
.09619 .51965 L
.10987 .5367 L
.12342 .54974 L
Mistroke
.13752 .55987 L
.15071 .56654 L
.16629 .57121 L
.18112 .57258 L
.19737 .5707 L
.21432 .56711 L
.24408 .56069 L
.30846 .54621 L
.50271 .49585 L
.58532 .46971 L
.65999 .44173 L
.71705 .41551 L
.75865 .39127 L
.777 .37793 L
.79347 .36322 L
.80606 .34844 L
.81127 .34034 L
.81507 .33275 L
.81758 .32596 L
.81852 .32255 L
.81897 .3206 L
.81932 .31883 L
.81979 .31563 L
.8201 .31222 L
.82019 .30906 L
.82011 .30608 L
.81982 .3026 L
.81958 .30084 L
.81926 .29891 L
.81853 .29549 L
.81765 .2923 L
.81499 .2851 L
.81108 .27738 L
.80082 .26287 L
.78791 .24944 L
.74654 .21903 L
.69611 .19222 L
.62815 .16371 L
.46077 .11023 L
.36878 .08624 L
.25608 .05998 L
.22506 .05322 L
.20765 .04951 L
.19098 .04618 L
.17531 .04565 L
.1584 .04877 L
.1433 .05492 L
.12976 .06333 L
.11497 .07602 L
.10191 .09073 L
Mistroke
.08865 .10983 L
.07585 .1335 L
.06431 .1613 L
.05527 .19018 L
.04887 .21775 L
.04601 .2339 L
.04385 .24916 L
.04119 .27749 L
.04019 .30853 L
.04103 .33785 L
.04333 .3645 L
.04666 .38812 L
.05163 .41325 L
.05825 .43833 L
.06566 .46042 L
.0758 .48442 L
.08669 .50497 L
.09759 .5216 L
.11006 .53692 L
.12451 .55064 L
.13854 .56048 L
.15416 .56786 L
.16322 .57055 L
.17179 .57206 L
.18731 .57227 L
.2038 .56934 L
.23295 .56311 L
.29647 .54898 L
.41342 .52049 L
.58568 .46959 L
.66081 .44139 L
.72589 .41084 L
.75007 .39682 L
.77176 .38199 L
.78845 .36809 L
.80062 .3554 L
.80563 .34902 L
.81025 .34207 L
.81384 .33543 L
.8164 .32942 L
.81755 .32605 L
.81856 .32241 L
.81901 .32041 L
.81936 .31856 L
.81987 .31495 L
.82012 .31183 L
.82019 .30842 L
.82003 .30485 L
.81968 .30153 L
.81916 .29839 L
Mistroke
.8184 .29498 L
.81647 .28879 L
.81392 .28276 L
.81098 .27719 L
.80221 .26455 L
.78973 .25115 L
.75642 .22528 L
.70697 .19745 L
.58181 .14713 L
.49301 .11936 L
.38002 .08903 L
.3228 .07517 L
.25793 .06039 L
.22497 .0532 L
.20846 .04968 L
.19307 .0465 L
.17892 .04548 L
.16399 .04731 L
.14919 .05213 L
.13336 .06081 L
.11758 .07349 L
.10381 .08835 L
.08984 .10791 L
.07652 .13209 L
.06646 .1555 L
.05836 .17932 L
.0511 .20715 L
.04781 .22334 L
.04527 .23873 L
.04207 .266 L
.04035 .29637 L
.04048 .32613 L
.0426 .35768 L
.04639 .38648 L
.05152 .41278 L
.05738 .4354 L
.065 .45862 L
.07556 .48392 L
.08686 .50525 L
.10066 .5257 L
.11688 .54388 L
.12544 .5514 L
.13507 .55834 L
.14438 .56366 L
.15318 .56751 L
.17007 .57184 L
.1796 .57257 L
.18823 .57219 L
.20518 .56905 L
.22056 .56578 L
Mistroke
.25455 .55839 L
.31361 .54502 L
.52631 .48877 L
.60923 .46131 L
.67282 .43631 L
.72351 .41212 L
.76653 .38583 L
.7848 .37139 L
.79832 .35805 L
.80821 .3453 L
.81208 .33886 L
.81548 .33177 L
.81778 .32529 L
.81874 .32162 L
.81942 .31821 L
.8199 .31459 L
.82014 .31131 L
.82018 .30949 L
.82016 .30752 L
.81995 .30395 L
.81958 .30088 L
.81898 .29751 L
.81813 .29398 L
.81713 .29069 L
.81485 .2848 L
.8117 .27848 L
.80099 .26308 L
.78684 .24847 L
.74986 .22109 L
.70111 .1946 L
.63525 .16643 L
.4806 .11579 L
.38422 .09008 L
.32876 .07658 L
.26671 .06234 L
.23927 .0563 L
.20918 .04983 L
.20015 .04792 L
.19155 .04627 L
.17537 .04564 L
.16026 .04824 L
.14413 .0545 L
.13096 .06248 L
.11701 .07403 L
.10325 .08905 L
.09125 .10569 L
.07242 .141 L
.0635 .16357 L
.05651 .18568 L
.04949 .21468 L
Mistroke
.04463 .24326 L
.04176 .26966 L
.04029 .29867 L
.04065 .3305 L
.04161 .34644 L
.04325 .36378 L
.04765 .39381 L
.05344 .42079 L
.06084 .44661 L
.06922 .46951 L
.08817 .50743 L
.10039 .52536 L
.11258 .53959 L
.12676 .55244 L
.14256 .56272 L
.15899 .56944 L
.17433 .57231 L
.19125 .57181 L
.19972 .5702 L
.20891 .56826 L
.26921 .55514 L
.39496 .52524 L
.58069 .47129 L
.66102 .4413 L
.72058 .41366 L
.767 .38548 L
.78564 .37065 L
.801 .35494 L
.8061 .34837 L
.8107 .3413 L
.81395 .3352 L
.81671 .32854 L
.818 .32451 L
.81893 .32076 L
.81958 .31718 L
.81984 .31518 L
.82001 .31337 L
.82017 .30994 L
.82017 .30801 L
.82011 .30623 L
.81985 .30296 L
.81936 .29951 L
.81867 .29614 L
.81769 .29248 L
.81529 .28583 L
.81218 .27935 L
.80862 .27337 L
.79814 .25979 L
.78335 .24538 L
.75032 .22138 L
Mistroke
.70177 .19492 L
.66699 .17924 L
Mfstroke
.82019 .43998 m
.87346 .4153 L
.91909 .38826 L
.93705 .37462 L
.95253 .36003 L
.95864 .35295 L
.96358 .34625 L
.96758 .33979 L
.97064 .33373 L
.97323 .32705 L
.97428 .32351 L
.97515 .3197 L
.97549 .3178 L
.97578 .31572 L
.97599 .31376 L
.97612 .31194 L
.97619 .3085 L
.97614 .30658 L
.97603 .30483 L
.97566 .3014 L
.97514 .29824 L
.97435 .29477 L
.97327 .2911 L
.97092 .28493 L
.96753 .27816 L
.95702 .26311 L
.94117 .24697 L
.90059 .21784 L
.84706 .18987 L
.77266 .15943 L
.59423 .10409 L
.36459 .04971 L
.30066 .03649 L
.22819 .02224 L
.20732 .01827 L
.19581 .01611 L
.18504 .01483 L
.16594 .016 L
.15591 .01838 L
.14531 .02226 L
.13549 .02715 L
.12506 .03379 L
.10686 .04929 L
.09029 .06842 L
.07625 .08936 L
.06323 .11387 L
.05238 .13964 L
.04389 .16489 L
.03641 .19341 L
.0302 .22581 L
Mistroke
.02629 .25688 L
.02478 .27624 L
.024 .29459 L
.02417 .32896 L
.02611 .35928 L
.02996 .39068 L
.03469 .41673 L
.04132 .4442 L
.05012 .47222 L
.0613 .49999 L
.07245 .52212 L
.08555 .54309 L
.1025 .56422 L
.11934 .57993 L
.12842 .58655 L
.13843 .59248 L
.14963 .59753 L
.16028 .60084 L
.16963 .6026 L
.1799 .60332 L
.19061 .60272 L
.20053 .60104 L
.23677 .59414 L
.37043 .56709 L
.58857 .51546 L
.77006 .45956 L
.84539 .42894 L
.89967 .40074 L
.93803 .37379 L
.95236 .36021 L
.95854 .35306 L
.96422 .34529 L
.96864 .33782 L
.97183 .3309 L
.97407 .32429 L
.97489 .32095 L
.97525 .31916 L
.97557 .31727 L
.97597 .31396 L
.97615 .31092 L
.97617 .30766 L
.97597 .30408 L
.9756 .30098 L
.97502 .29767 L
.97428 .29454 L
.97346 .2917 L
.97064 .28432 L
.96716 .27752 L
.95619 .26213 L
.94295 .24857 L
Mistroke
.92527 .2342 L
.8839 .20829 L
.8258 .18043 L
.68499 .13009 L
.46489 .07192 L
.34298 .04517 L
.27552 .03147 L
.23603 .02375 L
.21686 .02008 L
.19875 .01666 L
.1805 .01472 L
.17082 .01529 L
.16049 .01714 L
.14976 .02046 L
.13973 .02488 L
.12144 .03646 L
.10478 .05141 L
.0903 .06842 L
.07564 .09037 L
.06173 .11709 L
.05172 .14141 L
.0425 .16964 L
.03541 .19793 L
.03034 .22496 L
.02639 .25586 L
.02412 .29035 L
.02409 .32662 L
.02619 .36013 L
.03003 .3911 L
.03617 .42356 L
.04379 .45279 L
.05229 .47817 L
.07197 .52126 L
.08348 .54007 L
.09719 .55822 L
.11314 .57469 L
.1285 .58661 L
.14696 .59647 L
.16494 .60185 L
.1817 .60331 L
.19722 .60167 L
.2141 .59848 L
.23186 .59508 L
.49091 .54 L
.70864 .48053 L
.78889 .45252 L
.85805 .42298 L
.90455 .39776 L
.94221 .37013 L
.9564 .35566 L
Mistroke
.96198 .34854 L
.96631 .34197 L
.9695 .33612 L
.9723 .32968 L
.97435 .3232 L
.97515 .31965 L
.9757 .31633 L
.97605 .31278 L
.97615 .31077 L
.97618 .30891 L
.97607 .30549 L
.97591 .30358 L
.97572 .30185 L
.97519 .29857 L
.9744 .29503 L
.97239 .2886 L
.96907 .28104 L
.96442 .27306 L
.95321 .25876 L
.93906 .24514 L
.92322 .23271 L
.87735 .20478 L
.82217 .17889 L
.75863 .15436 L
.57741 .09963 L
.36115 .04898 L
.29945 .03625 L
.26587 .02956 L
.22962 .02252 L
.21394 .01953 L
.19701 .01633 L
.17827 .01475 L
.16084 .01706 L
.14399 .02285 L
.12846 .03146 L
.115 .04171 L
.10103 .05542 L
.08541 .07516 L
.07202 .09669 L
.05893 .12339 L
.04692 .15523 L
.04178 .1722 L
.03687 .1914 L
.03317 .20883 L
.02989 .22785 L
.02732 .24705 L
.0256 .26469 L
.02389 .29953 L
.02441 .33473 L
.02686 .36678 L
Mistroke
.03169 .40114 L
.03495 .41796 L
.03914 .43594 L
.04762 .46493 L
.05856 .49378 L
.08263 .5388 L
.09729 .55835 L
.11473 .57609 L
.12391 .58341 L
.13405 .59006 L
.15292 .5987 L
.17112 .60278 L
.19039 .60274 L
.20675 .59987 L
.22444 .59651 L
.37532 .56604 L
.60629 .51068 L
.7779 .45666 L
.85075 .42644 L
.9025 .39902 L
.92276 .38565 L
.94065 .37151 L
.95318 .35929 L
.96361 .34617 L
.9681 .3388 L
.97133 .33208 L
.97259 .32884 L
.97375 .32532 L
.97463 .32201 L
.97528 .31891 L
.97581 .31533 L
.97599 .31342 L
.97612 .31137 L
.97617 .30933 L
.97614 .30719 L
.97605 .30536 L
.97588 .30335 L
.97539 .29975 L
.97501 .29773 L
.9746 .29589 L
.9725 .28895 L
.96983 .28262 L
.96604 .27565 L
.95568 .26156 L
.94286 .2485 L
.92803 .23627 L
.88469 .20873 L
.82267 .17911 L
.65452 .12097 L
.43773 .06571 L
Mistroke
.31466 .03934 L
.28011 .03238 L
.24174 .02486 L
.22378 .02141 L
.20457 .01776 L
.18798 .01505 L
.1697 .01543 L
.15131 .01989 L
.1349 .02749 L
.12605 .0331 L
.11664 .04031 L
.10024 .0563 L
.08593 .07441 L
.07199 .09676 L
.06113 .11843 L
.05079 .14396 L
.04228 .17042 L
.03583 .19602 L
.0309 .22149 L
.02709 .24909 L
.02457 .28009 L
.02381 .30923 L
.02475 .34119 L
.02779 .37489 L
.03159 .4006 L
.03719 .428 L
.04456 .45535 L
.05279 .47949 L
.07047 .5185 L
.08189 .53769 L
.09316 .55331 L
.10619 .56807 L
.12082 .5811 L
.13761 .59204 L
.15366 .59894 L
.1704 .60269 L
.18625 .60312 L
.20044 .60106 L
.21563 .59818 L
.42679 .55478 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oB?ooool0
0ol0003oooooooooo`3ooooooakooooo0018ooooo`03o`000?oooooooooo0?oooooo7_ooool004So
oooo00?o0000ooooooooool0oooooolNooooo`00B?ooool00ol0003oooooooooo`3ooooooakooooo
0018ooooo`03o`000?oooooooooo0?oooooo7_ooool003gooooo4?l0003ooooooacooooo000ioooo
o`Oo00002?ooool00ol0003oooooo`000007o`000?oooooo5oooool003Kooooo1_l0000<ooooo`;o
00001Oooool8o`000?oooooo4_ooool003Gooooo1?l0000?ooooo`03o`000?oooooooooo00Sooooo
2Ol0003oooooo`gooooo000cooooo`?o00004_ooool00ol0003oooooooooo`0=ooooo`Wo0000oooo
ool8ooooo`00<_ooool2o`0001Cooooo00?o0000ooooooooool04oooool8o`000?oooooo0oooool0
033ooooo0ol0000Eooooo`03o`000?oooooooooo01Oooooo2Ol0003mooooo`00;oooool2o`0001Oo
oooo00?o0000ooooooooool07?ooool9o`000?Sooooo000^ooooo`;o00003Oooool5o`0000Kooooo
00?o0000ooooooooool08Oooool9o`000??ooooo000]ooooo`;o00003_ooool01OnHV9So8B4Qonk^
k_ooooooA4A400Kooooo00?o0000ooooooooool09_ooool8o`000>oooooo000/ooooo`;o00001ooo
ool6o`0000;ooooo4?l0000Yooooo`So0000j_ooool002_ooooo0_l0000=ooooo`Ko000000?o8B4Q
onk^k_ooool01Oooool00ol0003oooooo`000005o`0002[ooooo2?l0003Vooooo`00:_ooool2o`00
00cooooo1?l00004ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool01Oooool6o`00
02Wooooo2?l0003Qooooo`00:Oooool3o`0000[ooooo0ol00008ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool02?ooool8o`0002Wooooo2?l0003Looooo`00:Oooool2o`0000Wooooo
0ol00006ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`0<ooooo`So
0000:_ooool8o`000=Oooooo000Xooooo`;o00002Oooool2o`0000Sooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c006ooooo`03o`000?oooooooooo013ooooo2?l0000Zooooo`Wo0000d_ooool002Oooooo
0_l00009ooooo`;o00005?ooool00ol0003oooooooooo`0Eooooo`Oo0000:oooool8o`000<kooooo
000Vooooo`;o00002Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01[ooooo1_l0
000[ooooo`So0000b_ooool002Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo01oooooo1Ol0000[ooooo`So0000a_ooool002Gooooo0_l00008oooo
o`03o`000?oooooooooo01Kooooo0_l0000Tooooo`Ko0000:_ooool8o`000<;ooooo000Tooooo`;o
00002?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02Oooooo1Ol0000[ooooo`Wo
0000_Oooool002Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0>ooooo`co0000
;?ooool5o`0002_ooooo2Ol0002iooooo`008oooool2o`0000Oooooo00?o0000ooooooooool03?oo
ool5o`0000Sooooo1ol0000/ooooo`Go0000:_ooool9o`000;Gooooo000Rooooo`;o00001oooool0
0ol0003oooooooooo`0:ooooo`Co00003?ooool01?l0003oooooooooooooool7o`0002cooooo1Ol0
000Zooooo`Wo0000/Oooool002;ooooo0_l00006ooooo`;o00002_ooool4o`0000kooooo00?o0000
ooooooooool01Oooool7o`0002_ooooo1_l0000Zooooo`Wo0000[Oooool0027ooooo0_l00007oooo
o`03o`000?oooooooooo00Sooooo0ol0000@ooooo`03o`000?oooooooooo00Wooooo1ol0000[oooo
o`Ko0000:oooool8o`000:Wooooo000Pooooo`;o00001oooool00ol0003oooooooooo`08ooooo`;o
00004_ooool00ol0003oooooooooo`0=ooooo`Oo0000:oooool6o`0002_ooooo2?l0002Uooooo`00
8?ooool2o`0000Kooooo0_l00009ooooo`;o00004oooool2o`0001;ooooo1_l0000/ooooo`Ko0000
:oooool7o`000:;ooooo000Oooooo`;o00001oooool00ol0003oooooooooo`07ooooo`;o00005?oo
ool00ol0003oooooooooo`0Eooooo`Ko0000:oooool6o`0002_ooooo2?l0002Nooooo`007oooool2
o`0000Kooooo00?o0000ooooooooool01oooool2o`0001Gooooo00?o0000ooooooooool06?ooool6
o`0002cooooo1_l0000[ooooo`So0000V_ooool001kooooo0_l00006ooooo`;o00002?ooool2o`00
01Kooooo00?o0000ooooooooool07?ooool6o`0002cooooo1_l0000[ooooo`Oo0000Uoooool001ko
oooo0_l00006ooooo`03o`000?oooooooooo00Kooooo0_l0000Gooooo`03o`000?oooooooooo01oo
oooo1ol0000[ooooo`Oo0000:oooool7o`0009?ooooo000Nooooo`03o`000?oooooooooo00Cooooo
0_l00007ooooo`;o00006?ooool00ol0003oooooooooo`0Sooooo`Ko0000;?ooool7o`0002[ooooo
2?l0002?ooooo`007Oooool2o`0000Kooooo00?o0000ooooooooool01_ooool2o`0001Sooooo00?o
0000ooooooooool09_ooool7o`0002_ooooo2?l0000Zooooo`Oo0000S?ooool001gooooo00?o0000
ooooooooool01?ooool2o`0000Oooooo0_l0000@ooooo`[o0000;?ooool6o`0002_ooooo2?l0000Z
ooooo`Oo0000ROooool001cooooo0_l00005ooooo`;o00001oooool2o`0000kooooo1Ol00006oooo
o`Ko0000;?ooool5o`0002_ooooo2?l0000Zooooo`Oo0000Q_ooool001cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`05ooooo`;o00003Oooool3o`0000_ooooo00?o0000ooooool0
00001Ol0000/ooooo`Ko0000:_ooool8o`0002_ooooo1_l00023ooooo`006oooool2o`0000Gooooo
0_l00007ooooo`03o`000?oooooooooo00[ooooo0ol0000=ooooo`03o`000?oooooooooo00?ooooo
1Ol0000/ooooo`Ko0000:_ooool8o`0002_ooooo1_l00020ooooo`006oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo0_l0000;ooooo`?o00003_ooool00ol0003ooooooooo
o`06ooooo`Go0000;?ooool6o`0002_ooooo1ol0000/ooooo`Go0000OOooool001[ooooo0_l00005
ooooo`;o00001_ooool2o`0000_ooooo0_l0000@ooooo`03o`000?oooooooooo00Wooooo1_l0000[
ooooo`Ko0000:oooool7o`0002cooooo1Ol0001jooooo`006_ooool2o`0000Gooooo00?o0000oooo
ooooool01Oooool2o`0000[ooooo0_l0000Aooooo`03o`000?oooooooooo00gooooo1Ol0000[oooo
o`Ko0000:oooool7o`0002cooooo1Ol0001gooooo`006Oooool2o`0000Gooooo0_l00006ooooo`;o
00002_ooool2o`0001;ooooo00?o0000ooooooooool04?ooool5o`0002_ooooo1_l0000[ooooo`Oo
0000:oooool6o`0007Cooooo000Iooooo`;o00001Oooool00ol0003oooooooooo`05ooooo`;o0000
2Oooool2o`0001?ooooo00?o0000ooooooooool04oooool5o`0002_ooooo1_l0000[ooooo`Oo0000
:oooool6o`00077ooooo000Iooooo`;o00001?ooool2o`0000Kooooo0_l00009ooooo`;o00005?oo
ool00ol0003oooooooooo`0Fooooo`Co0000;?ooool6o`0002cooooo1_l0000[ooooo`Ko0000K_oo
ool001Sooooo0_l00005ooooo`;o00001_ooool2o`0000Sooooo0_l0000Eooooo`;o00006_ooool4
o`0002cooooo1_l0000/ooooo`Go0000;?ooool6o`0006_ooooo000Hooooo`;o00001?ooool2o`00
00Kooooo0_l00009ooooo`;o00005Oooool00ol0003oooooooooo`0Looooo`Co0000;?ooool6o`00
02cooooo1Ol0000/ooooo`Ko0000J?ooool001Sooooo0_l00004ooooo`;o00001_ooool00ol0003o
ooooooooo`07ooooo`;o00005_ooool00ol0003oooooooooo`0Oooooo`?o0000;Oooool6o`0002co
oooo1Ol0000/ooooo`Ko0000IOooool001Oooooo0_l00005ooooo`;o00001Oooool2o`0000Sooooo
0_l0000Gooooo`03o`000?oooooooooo027ooooo1?l0000]ooooo`Go0000;Oooool4o`0002gooooo
1_l0001Rooooo`005oooool2o`0000Cooooo0_l00006ooooo`;o00002?ooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo02Cooooo0ol0000]ooooo`Go0000;_ooool4o`0002cooooo1_l0
001Pooooo`005oooool2o`0000Cooooo0_l00005ooooo`;o00002?ooool2o`0001Sooooo00?o0000
ooooooooool09_ooool4o`0002gooooo1Ol0000^ooooo`?o0000;Oooool6o`0005gooooo000Goooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool2o`0000Oooooo0_l0000?oooo
o`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`0Yooooo`?o0000;Oooool6o`00
02gooooo1?l0000]ooooo`Ko0000F_ooool001Kooooo0_l00004ooooo`;o00001_ooool00ol0003o
ooooooooo`06ooooo`;o00004Oooool9o`0002gooooo1?l0000]ooooo`Go0000;_ooool3o`0002ko
oooo1_l0001Gooooo`005_ooool2o`0000Cooooo0_l00005ooooo`;o00001oooool2o`0000Oooooo
1_l00002ooooo`Go00001?ooool5o`0002gooooo1?l0000]ooooo`Go0000;_ooool4o`0002kooooo
1?l0001Fooooo`005_ooool2o`0000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00gooooo0ol000000ooooooo0000ooooo`06ooooo`Go0000;_oo
ool3o`0002kooooo1Ol0000]ooooo`Co0000;_ooool4o`0005Cooooo000Fooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`;o00003Oooool3
o`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05o`0002gooooo0ol0000^
ooooo`Go0000;_ooool3o`0002oooooo0ol0001Booooo`005_ooool00ol0003oooooooooo`02oooo
o`;o00001Oooool2o`0000Oooooo00?o0000ooooooooool02oooool2o`0000Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`03ooooo`Co0000;Oooool4o`0002kooooo1?l0000^oooo
o`Co0000;_ooool4o`0004oooooo000Eooooo`;o00001?ooool00ol0003oooooooooo`04ooooo`;o
00001_ooool2o`0000cooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool4o`0002kooooo0ol0000^ooooo`Go0000;Oooool4o`0002kooooo1?l0001=ooooo`00
5Oooool2o`0000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`;o0000
2oooool2o`0000Gooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`07ooooo`Co0000
;_ooool3o`0002oooooo1?l0000^ooooo`Co0000;_ooool4o`0004[ooooo000Eooooo`03o`000?oo
oooooooo00;ooooo0_l00005ooooo`;o00001oooool00ol0003oooooooooo`0:ooooo`;o00003ooo
ool00ol0003oooooooooo`09ooooo`Co0000;_ooool3o`0002oooooo1?l0000^ooooo`Co0000;_oo
ool4o`0004Sooooo000Eooooo`03o`000?oooooooooo00;ooooo0_l00005ooooo`;o00001_ooool2
o`0000_ooooo0_l0000@ooooo`03o`000?oooooooooo00_ooooo1?l0000^ooooo`?o0000;oooool4
o`0002kooooo1?l0000^ooooo`Co0000A_ooool001Cooooo0_l00004ooooo`;o00001Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo0_l0000Aooooo`03o`000?oooooooooo
00gooooo1?l0000^ooooo`?o0000;oooool3o`0002oooooo1?l0000^ooooo`?o0000AOooool001Co
oooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00007ooooo`03o`000?oooooooooo00Wo
oooo0_l0000Aooooo`;o00004?ooool4o`0002kooooo0ol0000_ooooo`?o0000;oooool4o`0002ko
oooo0ol00013ooooo`005?ooool00ol0003oooooooooo`02ooooo`;o00001Oooool2o`0000Kooooo
0_l0000:ooooo`;o00004_ooool00ol0003oooooooooo`0@ooooo`Co0000;oooool3o`0002oooooo
0ol0000_ooooo`?o0000;oooool3o`00047ooooo000Dooooo`03o`000?oooooooooo00;ooooo0_l0
0005ooooo`;o00001_ooool00ol0003oooooooooo`08ooooo`;o00004oooool00ol0003ooooooooo
o`0Booooo`Co0000;oooool2o`00033ooooo0ol0000_ooooo`?o0000;oooool2o`00043ooooo000C
ooooo`;o00001?ooool2o`0000Cooooo0_l00006ooooo`;o00002_ooool2o`0001?ooooo00?o0000
ooooooooool05?ooool4o`0002oooooo0_l0000`ooooo`?o0000;oooool3o`0002oooooo0_l0000n
ooooo`004oooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000Kooooo0_l00009oooo
o`;o00005?ooool00ol0003oooooooooo`0Fooooo`Co0000;oooool2o`00033ooooo0_l0000`oooo
o`?o0000;_ooool3o`0003cooooo000Cooooo`;o00000oooool2o`0000Gooooo0_l00006ooooo`;o
00002Oooool2o`0001Cooooo00?o0000ooooooooool06?ooool3o`0002oooooo0ol0000_ooooo`?o
0000<?ooool2o`0002oooooo0_l0000kooooo`004oooool00ol0003oooooooooo`02ooooo`;o0000
1Oooool2o`0000Gooooo0_l00009ooooo`;o00005Oooool00ol0003oooooooooo`0Iooooo`Co0000
;oooool2o`00033ooooo0_l0000aooooo`;o0000;oooool2o`0003Wooooo000Cooooo`03o`000?oo
oooooooo00;ooooo0_l00005ooooo`03o`000?oooooooooo00Cooooo0_l00009ooooo`;o00005Ooo
ool00ol0003oooooooooo`0Kooooo`?o0000;oooool3o`0002oooooo0ol0000`ooooo`;o0000<?oo
ool2o`0003Oooooo000Cooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`;o00001_ooool2
o`0000Wooooo00?o0000ooooooooool05?ooool2o`0001gooooo1?l0000_ooooo`?o0000;oooool3
o`0002oooooo0ol0000_ooooo`;o0000=_ooool001;ooooo0_l00004ooooo`03o`000?oooooooooo
00?ooooo0_l00006ooooo`03o`000?oooooooooo00Oooooo0_l0000Fooooo`03o`000?oooooooooo
01kooooo0ol0000_ooooo`?o0000;oooool3o`00033ooooo0_l0000`ooooo`;o0000=?ooool001;o
oooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00006ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Pooooo`;o0000;oooool3o`0002oo
oooo0ol0000`ooooo`;o0000<?ooool2o`0003?ooooo000Booooo`;o00001?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo0_l00009ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool08Oooool2o`00033ooooo0_l0000`ooooo`;o0000<?ooool2o`00033ooooo
0_l0000booooo`004_ooool2o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo00Cooooo0_l0
0008ooooo`;o00005oooool00ol0003oooooooooo`0Rooooo`;o0000<?ooool2o`00033ooooo0_l0
000aooooo`03o`000?oooooooooo02kooooo0_l0000aooooo`004_ooool2o`0000?ooooo0_l00004
ooooo`;o00001_ooool00ol0003oooooooooo`07ooooo`;o00005oooool00ol0003oooooooooo`0S
ooooo`;o0000<?ooool2o`00033ooooo0_l0000aooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool0;_ooool001;ooooo00?o0000ooooooooool00_ooool2o`0000Cooooo0_l00006oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Toooo
o`;o0000<?ooool2o`00033ooooo0_l0000`ooooo`;o0000<?ooool2o`0002oooooo000Booooo`03
o`000?oooooooooo00;ooooo0_l00004ooooo`;o00001_ooool00ol0003oooooooooo`06ooooo`;o
00006?ooool00ol0003oooooooooo`0Uooooo`;o0000<?ooool2o`00033ooooo0_l0000`ooooo`;o
0000<?ooool2o`0002kooooo000Booooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`;o0000
1_ooool00ol0003oooooooooo`06ooooo`;o00006?ooool2o`0002Oooooo0_l0000`ooooo`;o0000
<?ooool2o`00033ooooo0_l0000`ooooo`;o0000;Oooool001;ooooo00?o0000ooooooooool00_oo
ool2o`0000Cooooo0_l00005ooooo`;o00002?ooool2o`0001Sooooo00?o0000ooooooooool09ooo
ool2o`00033ooooo0_l0000`ooooo`;o0000<?ooool2o`00033ooooo0_l0000/ooooo`004_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo0_l00005ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Xooooo`;o0000<?ooool2
o`00033ooooo0_l0000`ooooo`;o0000<?ooool2o`0002_ooooo000Aooooo`;o00001?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool2o`00
01Wooooo00?o0000ooooooooool0:Oooool2o`00033ooooo0_l0000`ooooo`;o0000<?ooool2o`00
033ooooo0_l0000Zooooo`003oooool01Oo^k^ko<S8bo`000?l0003ok^k^00?ooooo00Co0000oooo
oolQ8B7o8B4Q0_ooool01?l0003ooooooooooom4A4@2o`000003oc8b<_l0003ooooo00Oooooo0_l0
000Iooooo`03o`000?oooooooooo02Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02o`0000?ooooo
0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd08_ooool00ol0003oooooooooo`04o`000003
oa0@4?oooooooooo02?ooooo1?l000000ol@413o0000o`000002ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM02;ooooo00?o0000ooooooooool01Ol0000Uooooo`Oo00000oooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Jooooo`003oooool01OmgMgOoV9RHo`000?l0003o
MgMg00?ooooo00Go0000oooooolQ8B7o8B4Qooooo`02o`0000Gooooo00?oMgMgo`000?ooool01ooo
ool2o`0001Wooooo00?o0000ooooooooool09?ooool01_mgMgOoV9RHoooooonHV9SoMgMgooooo`;o
00000_ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool08_ooool01Ol0003ooooooooooooooooo0000
02Wooooo00?o0000ooooooooool00_l00002ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Roooo
o`07o`000?ooooooV9RHob4Q8Oo^k^koooooodA4A00Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
0_l00003ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Iooooo`001oooool6o`0000;ooooo00Go
410@ooooool0003o0000oa0@4003ooooo`03o`000?oooooooooo00;ooooo0_l00006ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Tooooo`05oa0@
4?ooooooooooooooool@41000_ooool2o`0000cooooo00?o0000ooooooooool08Oooool2o`0000;o
oooo00?o0000ooooooooool09oooool01?l0003oooooooooooooool2o`0000cooooo00?o0000oooo
ooooool08_ooool01Ol0003ooooooiRHV?lQ8B7ok^k^02Oooooo00?oV9RHob4Q8Oo^k^h00_ooool2
o`0000gooooo00?o0000ooooooooool06?ooool000oooooo00?o0000ooooool000000_l00003oooo
o`03o`000?oooooooooo00;ooooo0_l00005ooooo`03ogMgMol0003ooooo00Oooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0Tooooo`05o`000?ooooooooooooooool000000oooool2
o`0000[ooooo00?oMgMgoc8b<_ooool08oooool2o`000003ooooool0003ooooo02Sooooo00?o0000
ooooooooool00_ooool2o`0000[ooooo00?oMgMgoc8b<_ooool08oooool2o`000004oooooonHV9So
8B4Qonk^kROooooo00?oV9RHob4Q8Oo^k^h00_ooool2o`0000_ooooo00?oMgMgoc8b<_ooool06Ooo
ool000oooooo00?o0000ooooool000000_l00003ooooo`03o`000?oooooooooo00;ooooo0_l00002
ooooo`03o`000?lQ8B7o000000;o00002?ooool00ol0003oooooooooo`0Booooo`Co00000_ooool0
0ol0003oooooooooo`0Tooooo`05o`000?ooooooooooooooool000000oooool2o`0000Oooooo00Go
0000ob4Q8Ol0003o<S8bolc<c00Tooooo`;o000000?oooooo`000?ooool0:?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Gooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Uooooo`05
o`000?ooooooooooogMgMomVIVH0:?ooool00omgMgOoIVIVooooo`02ooooo`03o`000?oooooooooo
00Kooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Jooooo`003oooool01Ol@413oooooo`000?oooooo
410@00;ooooo0_l00004ooooo`;o00000_ooool00ol0003oooooooooo`02o`0000Sooooo00?o0000
ooooooooool04Oooool01?l0003oooooooooooooool2o`000003ooooool0003o000002Gooooo00Go
410@oooooooooooooooooa0@4004ooooo`;o00001_ooool00ol0003oooooooooo`0Wooooo`?o0000
:Oooool00ol0003oooooooooo`03ooooo`;o00001_ooool00ol0003oooooooooo`0Wooooo`;o0000
0_ooool00ol0003oooooooooo`0Wooooo`04o`000?ooooooooooooooo`;o00001oooool00ol0003o
ooooooooo`0Looooo`003oooool01OmgMgOoV9RHo`000?nHV9SoMgMg00;ooooo0_l00004ooooo`;o
00000_ooool00ol0003oooooooooo`02o`0000Oooooo0_l0000Booooo`03o`000?oooooooooo00?o
oooo0ol0000Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool2o`0000Kooooo00?o0000oooo
ooooool09oooool3o`0002Wooooo00?o0000ooooooooool00oooool2o`0000Kooooo00?o0000oooo
ooooool09oooool2o`000003oooooonHV9So410@02Gooooo00Go0000okZj^_ooooooV9RHoa0@4004
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07?ooool000oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP02ooooo`;o00001?ooool2o`0000;ooooo1Ol00007ooooo`;o00004Oooool2
o`0000Kooooo0_l0000Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2o`0000Gooooo1?l0
000Vooooo`03oeEEEOl0003o000002Oooooo00?oEEEEofIVI_l000001_ooool2o`0000Gooooo1?l0
000Vooooo`05oiRHV?l0003o0000ob4Q8Oo<c<`09Oooool01OnHV9So410@o`000?lQ8B7oc<c<00Co
oooo0_l00006ooooo`Co00006oooool0017ooooo00?o0000ooooooooool00_ooool2o`0000Cooooo
00?o0000ooooooooool01?ooool2o`0000Oooooo0_l0000Aooooo`03o`000?oooooooooo00Gooooo
0_l0000`ooooo`;o0000<?ooool2o`00033ooooo0_l0000`ooooo`;o0000<?ooool2o`0002Gooooo
000Aooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`;o00001oooool2o`00017ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0^ooooo`;o0000<Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`0Sooooo`004Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool08oooool0017ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02oooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`0_ooooo`;o00004_ooool2o`0000;ooooo0_l0000<oooo
o`004Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool0;oooool00ol0003oooooooooo`0_ooooo`;o0000<Oooool00ol0003oooooooooo`0@ooooo`06
onk^k_lQ8B7oQhN7okZj^_l0003ogMgM3?ooool000Woooooool00013o`0000cooooo00CogMgMo`00
0?l@413oc<c<3Oooool000cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooool000001oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Aooooo`04onk^k_lQ8B7o
410@onk^kPgooooo000<ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool2o`0000Wooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01_ooool2o`0001?ooooo00Co8B4QogMgMomgMgOo<S8b3Oooool0017ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0?ooooo`;o00002?ooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;oooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04Oooool2o`0000;ooooo0_l0
000<ooooo`004Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`06ooooo`;o00004Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0S
ooooo`004Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`06ooooo`;o00004Oooool00ol0003oooooooooo`05oooo
o`;o0000<Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02oooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02?ooooo000Aooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`;o
00001oooool2o`00017ooooo0_l00006ooooo`;o0000<?ooool2o`00037ooooo00?o0000oooooooo
ool0;_ooool2o`00037ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Sooooo`00
4Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo0_l00005ooooo`;o0000
1oooool2o`00017ooooo0_l00006ooooo`;o0000<?ooool2o`00033ooooo00?o0000ooooooooool0
;oooool2o`00033ooooo0_l0000`ooooo`;o00009Oooool0017ooooo00?o0000ooooooooool00_oo
ool2o`0000Cooooo0_l00005ooooo`;o00002?ooool00ol0003oooooooooo`0@ooooo`;o00001?oo
ool00ol0003oooooo`00000_ooooo`;o0000<Oooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Tooooo`004Oooool0
0ol0003oooooooooo`02ooooo`;o00001?ooool2o`0000Gooooo0_l00008ooooo`03o`000?oooooo
oooo017ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o0000;_ooool2o`00033ooooo0_l0
000`ooooo`;o0000<Oooool00ol0003oooooooooo`0^ooooo`;o00009_ooool0017ooooo00?o0000
ooooooooool00_ooool2o`0000Cooooo0_l00005ooooo`;o00002?ooool00ol0003oooooooooo`0B
ooooo`?o00000oooool00ol0003oooooooooo`0/ooooo`;o0000<Oooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo02oooooo0_l0000`ooooo`03o`000?oooooooooo02Gooooo000Aoooo
o`03o`000?oooooooooo00;ooooo0_l00004ooooo`;o00001Oooool2o`0000Sooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0/ooooo`;o0000<?ooool2o`00033ooooo0_l0000`oooo
o`;o0000<?ooool2o`0002Oooooo000Aooooo`;o00000oooool2o`0000Gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool0:oooool2o`00037ooooo00?o0000ooooooooool0;_ooool2o`00037ooooo00?o0000oooooooo
ool0;_ooool2o`0002Sooooo000Aooooo`;o00000oooool2o`0000Gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`06ooooo`;o00006Oooool00ol0003oooooooooo`0[ooooo`;o0000
<?ooool00ol0003oooooooooo`0_ooooo`;o0000<?ooool2o`00033ooooo00?o0000ooooooooool0
9oooool0017ooooo0_l00003ooooo`;o00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Kooooo0_l0000Iooooo`03o`000?oooooooooo02[ooooo0_l0000`ooooo`03o`000?oo
oooooooo02oooooo0_l0000`ooooo`;o0000<?ooool2o`0002Wooooo000Aooooo`;o00001?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`;o00006Oooool0
0ol0003oooooooooo`0Yooooo`;o0000<?ooool2o`00033ooooo0_l0000`ooooo`;o0000<?ooool2
o`0002[ooooo000Aooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo0_l00007ooooo`;o00006Oooool00ol0003oooooooooo`0Xooooo`;o0000<?ooool2o`00
033ooooo0_l0000`ooooo`;o0000<?ooool2o`0002_ooooo000Aooooo`;o00001?ooool00ol0003o
ooooooooo`03ooooo`;o00001Oooool2o`0000Sooooo00?o0000ooooooooool05oooool2o`0002So
oooo0_l0000`ooooo`;o0000<?ooool2o`00033ooooo0_l0000`ooooo`;o0000;?ooool001;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`;o00001Oooool2o`0000Sooooo
0_l0000Hooooo`03o`000?oooooooooo02Kooooo0_l0000_ooooo`?o0000<?ooool2o`00033ooooo
0_l0000_ooooo`?o0000;Oooool001;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`;o00001_ooool00ol0003oooooooooo`06ooooo`;o00006?ooool00ol0003ooooooooo
o`0Tooooo`?o0000;oooool3o`0002oooooo0ol0000`ooooo`03o`000?oooooooooo02kooooo0ol0
000^ooooo`004_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo0_l00006
ooooo`03o`000?oooooooooo00Kooooo0_l0000Hooooo`03o`000?oooooooooo02?ooooo0ol0000_
ooooo`?o0000;oooool3o`0002oooooo0_l0000`ooooo`?o0000;oooool001;ooooo00?o0000oooo
ooooool00_ooool2o`0000Cooooo0_l00006ooooo`;o00002?ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo02;ooooo0ol0000_ooooo`?o0000;oooool3o`0002oooooo0_l0000`oooo
o`;o0000<Oooool001;ooooo0_l00003ooooo`;o00001Oooool00ol0003oooooooooo`04ooooo`;o
00002?ooool2o`0001Oooooo00?o0000ooooooooool08Oooool3o`0002kooooo0ol0000`ooooo`;o
0000<?ooool2o`00033ooooo0_l0000booooo`004_ooool2o`0000Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo0_l0000Gooooo`03o`00
0?oooooooooo01oooooo0ol0000_ooooo`?o0000;oooool3o`00033ooooo0_l0000_ooooo`?o0000
<oooool001;ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00006ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Nooooo`?o0000;ooo
ool2o`00033ooooo0ol0000`ooooo`;o0000;oooool2o`0003Gooooo000Booooo`;o00001?ooool0
0ol0003oooooooooo`03ooooo`;o00001_ooool00ol0003oooooooooo`07ooooo`;o00005_ooool0
0ol0003oooooooooo`0Looooo`Co0000;oooool2o`00033ooooo0ol0000_ooooo`;o0000<?ooool2
o`0003Kooooo000Cooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`;o00001_ooool00ol0
003oooooooooo`07ooooo`;o00005_ooool2o`0001cooooo0ol0000_ooooo`;o0000<Oooool2o`00
033ooooo0_l0000`ooooo`;o0000=oooool001?ooooo00?o0000ooooooooool00_ooool2o`0000Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool06Oooool3o`00033ooooo0_l0000`ooooo`?o0000;oooool3o`0002oo
oooo0ol0000hooooo`004oooool2o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01oooool2o`0001Gooooo00?o0000ooooooooool06?ooool3o`0002oooooo
0_l0000aooooo`;o0000;oooool3o`0002oooooo0ol0000jooooo`004oooool2o`0000Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Fooooo`?o0000;oooool3o`00033ooooo0_l0
000`ooooo`;o0000<?ooool3o`0003_ooooo000Cooooo`;o00001?ooool00ol0003oooooooooo`03
ooooo`;o00001_ooool2o`0000Wooooo0_l0000Dooooo`03o`000?oooooooooo01Cooooo0ol0000_
ooooo`?o0000<?ooool3o`0002oooooo0_l0000`ooooo`?o0000?Oooool001?ooooo0_l00004oooo
o`03o`000?oooooooooo00?ooooo0_l00006ooooo`;o00002_ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo01?ooooo0ol0000^ooooo`?o0000<?ooool3o`0002oooooo0_l0000`oooo
o`?o0000?oooool001?ooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Sooooo0_l0000Cooooo`03o`000?oooooooooo017ooooo0ol0000_ooooo`?o
0000<?ooool2o`0002oooooo0ol0000_ooooo`?o0000@Oooool001Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo0_l0000:ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool03oooool4o`0002kooooo0ol0000`ooooo`?o0000
;_ooool3o`0002oooooo0ol00013ooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00ooo
ool2o`0000Kooooo0_l0000:ooooo`;o00004_ooool2o`0000kooooo1?l0000^ooooo`Co0000;ooo
ool3o`0002kooooo1?l0000_ooooo`?o0000A?ooool001Cooooo0_l00004ooooo`03o`000?oooooo
oooo00?ooooo0_l00007ooooo`03o`000?oooooooooo00Wooooo0_l0000Aooooo`03o`000?oooooo
oooo00_ooooo1?l0000^ooooo`Co0000;oooool3o`0002kooooo1?l0000_ooooo`?o0000A_ooool0
01Cooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`05ooooo`;o00002oooool2o`00
013ooooo00?o0000ooooooooool02Oooool4o`0002kooooo1?l0000^ooooo`Co0000;_ooool4o`00
02oooooo0ol00018ooooo`005Oooool00ol0003oooooooooo`02ooooo`;o00001Oooool2o`0000Ko
oooo0_l0000<ooooo`;o00003oooool00ol0003oooooooooo`07ooooo`Co0000;Oooool5o`0002ko
oooo1?l0000^ooooo`?o0000;oooool4o`0004[ooooo000Eooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool2o`0000Oooooo0_l0000<ooooo`;o00003_ooool00ol0003ooooo
ooooo`04ooooo`Go0000;Oooool5o`0002kooooo1?l0000^ooooo`?o0000;oooool4o`0004cooooo
000Eooooo`;o00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo0_l0
000=ooooo`;o00003Oooool00ol0003oooooooooo`02ooooo`Go0000;Oooool4o`0002oooooo1?l0
000^ooooo`?o0000;_ooool5o`0004kooooo000Eooooo`;o00001?ooool2o`0000Gooooo0_l00007
ooooo`03o`000?oooooooooo00cooooo0_l00002ooooo`Co000000?o410@ooooooooool00oooool0
0ol0003oooooooooo`04o`0002gooooo1Ol0000^ooooo`Go0000;_ooool3o`0002kooooo1Ol0001@
ooooo`005_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01Oooool2o`0000kooooo1?l000000ooooooo0000ooooo`06ooooo`Go0000;Oooool5o`00
02kooooo1?l0000_ooooo`?o0000;Oooool5o`0005?ooooo000Fooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool03_ooool4o`0000Ko
oooo1?l0000/ooooo`Ko0000;Oooool5o`0002kooooo0ol0000^ooooo`Go0000EOooool001Kooooo
0_l00004ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`;o00004Oooool:o`0002cooooo
1_l0000]ooooo`Go0000;_ooool3o`0002gooooo1Ol0001Hooooo`005_ooool2o`0000Cooooo0_l0
0006ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo02Oooooo1ol0000/ooooo`Go0000;_ooool4o`0002gooooo1Ol0
001Jooooo`005oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo0_l00007
ooooo`;o00004Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Gooooo1_l0000/
ooooo`Go0000;oooool3o`0002gooooo1_l0001Looooo`005oooool2o`0000Cooooo0_l00005oooo
o`;o00002?ooool2o`00013ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Roooo
o`Ko0000;?ooool6o`0002kooooo0ol0000^ooooo`Ko0000G_ooool001Oooooo0_l00004ooooo`;o
00001_ooool2o`0000Oooooo0_l0000>ooooo`03oeEEEOmVIVKo000000Oooooo00?o0000oooooooo
ool08?ooool5o`0002gooooo1Ol0000^ooooo`Co0000;Oooool6o`00067ooooo000Hooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool2o`0000Sooooo0_l0000Gooooo`03o`00
0?oooooooooo01gooooo1Ol0000]ooooo`Ko0000;_ooool3o`0002kooooo1Ol0001Tooooo`006?oo
ool2o`0000Cooooo0_l00005ooooo`;o00002Oooool2o`0001Kooooo00?o0000ooooooooool06ooo
ool4o`0002gooooo1ol0000]ooooo`?o0000;_ooool5o`0006Oooooo000Hooooo`;o00001?ooool2
o`0000Kooooo0_l00009ooooo`;o00005Oooool00ol0003oooooooooo`0Hooooo`Co0000;Oooool7
o`0002gooooo1?l0000^ooooo`Co0000J_ooool001Sooooo0_l00005ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01oooool2o`0001Gooooo0_l0000Gooooo`Co0000;Oooool6o`00
02gooooo1?l0000^ooooo`Co0000KOooool001Wooooo00?o0000ooooooooool00oooool2o`0000Ko
oooo0_l00009ooooo`;o00005?ooool00ol0003oooooooooo`0Cooooo`Co0000;Oooool6o`0002go
oooo1?l0000^ooooo`Co0000L?ooool001Wooooo0_l00004ooooo`;o00001oooool2o`0000[ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`Co0000;?ooool6o`0002gooooo
1?l0000^ooooo`Co0000Loooool001Wooooo0_l00005ooooo`;o00001_ooool2o`0000_ooooo0_l0
000Aooooo`03o`000?oooooooooo00kooooo1?l0000/ooooo`Ko0000;Oooool4o`0002gooooo1Ol0
001fooooo`006_ooool00ol0003oooooooooo`03ooooo`;o00001oooool2o`0000_ooooo0_l0000@
ooooo`03o`000?oooooooooo00_ooooo1?l0000/ooooo`Ko0000;?ooool5o`0002gooooo1Ol0001i
ooooo`006_ooool2o`0000Gooooo0_l00006ooooo`;o00003?ooool3o`0000kooooo00?o0000oooo
ooooool01oooool5o`0002cooooo1_l0000/ooooo`Go0000;?ooool6o`0007cooooo000Kooooo`03
o`000?oooooooooo00?ooooo0_l00007ooooo`;o00003?ooool3o`0000gooooo00?o0000oooooooo
ool01?ooool5o`0002cooooo1_l0000/ooooo`Go0000;?ooool6o`0007oooooo000Kooooo`03o`00
0?oooooooooo00Cooooo0_l00006ooooo`?o00003Oooool3o`0000_ooooo00?o0000ooooooooool0
1_l0000/ooooo`Ko0000:oooool6o`0002cooooo1_l00022ooooo`006oooool2o`0000Kooooo00?o
0000ooooooooool01Oooool2o`0000oooooo1?l00008ooooo`Ko0000;?ooool6o`0002_ooooo1Ol0
000/ooooo`Oo0000QOooool001cooooo00?o0000ooooooooool01?ooool2o`0000Oooooo0_l0000@
ooooo`co0000;?ooool6o`0002cooooo1Ol0000/ooooo`Oo0000R?ooool001cooooo0_l00006oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Xoooo
o`Ko0000:oooool5o`0002cooooo2?l0002;ooooo`007Oooool00ol0003oooooooooo`04ooooo`;o
00001oooool2o`0001Wooooo00?o0000ooooooooool09?ooool7o`0002_ooooo1?l0000/ooooo`So
0000Soooool001gooooo0_l00006ooooo`03o`000?oooooooooo00Kooooo0_l0000Hooooo`03o`00
0?oooooooooo027ooooo1_l0000[ooooo`Co0000;Oooool7o`0009?ooooo000Mooooo`;o00001_oo
ool2o`0000Sooooo0_l0000Gooooo`03o`000?oooooooooo01kooooo1_l0000Zooooo`Go0000;?oo
ool7o`0009Oooooo000Nooooo`;o00001_ooool00ol0003oooooooooo`07ooooo`;o00005_ooool0
0ol0003oooooooooo`0Jooooo`Oo0000:Oooool5o`0002cooooo2?l0002Jooooo`007_ooool2o`00
00Oooooo00?o0000ooooooooool01oooool3o`0001Cooooo00?o0000ooooooooool05oooool6o`00
02Wooooo1_l0000/ooooo`So0000WOooool001oooooo0_l00006ooooo`;o00002_ooool2o`0001?o
oooo00?o0000ooooooooool04_ooool7o`0002Wooooo1ol0000[ooooo`Wo0000X?ooool001oooooo
0_l00007ooooo`03o`000?oooooooooo00Wooooo0ol0000Aooooo`;o00003oooool7o`0002[ooooo
1_l0000[ooooo`Wo0000Y?ooool0023ooooo0_l00007ooooo`03o`000?oooooooooo00Wooooo0ol0
000@ooooo`03o`000?oooooooooo00_ooooo1_l0000Zooooo`Oo0000:oooool7o`000:Wooooo000Q
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool3o`0000oooooo00?o0000
ooooooooool01oooool6o`0002[ooooo2?l0000Zooooo`Oo0000[Oooool0027ooooo0_l00007oooo
o`;o00003?ooool4o`0000cooooo00?o0000ooooooooool00_ooool7o`0002[ooooo2?l0000Zoooo
o`Oo0000/Oooool002;ooooo0_l00007ooooo`;o00003Oooool5o`0000Wooooo2?l0000Zooooo`Oo
0000;?ooool5o`000;Kooooo000Sooooo`03o`000?oooooooooo00Kooooo0_l0000>ooooo`Oo0000
0_ooool8o`0002Wooooo1ol0000/ooooo`Go0000^_ooool002?ooooo0_l00008ooooo`;o00004Ooo
ool9o`0002Wooooo1_l0000/ooooo`Ko0000__ooool002Cooooo0_l00008ooooo`;o00006?ooool0
0ol0003oooooooooo`0Sooooo`Ko0000;?ooool5o`000<?ooooo000Tooooo`;o00002Oooool2o`00
01Oooooo0_l0000Pooooo`Ko0000:oooool6o`000<Oooooo000Uooooo`;o00002Oooool2o`0001Ko
oooo00?o0000ooooooooool06oooool6o`0002_ooooo1_l0003;ooooo`009_ooool2o`0000Wooooo
0ol0000Dooooo`03o`000?oooooooooo01Oooooo1Ol0000[ooooo`So0000c_ooool002Oooooo0_l0
000:ooooo`;o00004oooool00ol0003oooooooooo`0Booooo`Go0000;?ooool8o`000=;ooooo000X
ooooo`;o00002_ooool3o`00017ooooo00?o0000ooooooooool03_ooool5o`0002_ooooo2Ol0003F
ooooo`00:Oooool00ol0003oooooooooo`09ooooo`?o00004?ooool00ol0003oooooooooo`0:oooo
o`Go0000:_ooool:o`000=[ooooo000Zooooo`;o00002oooool4o`0000;ooooo1Ol00006ooooo`03
o`000?oooooooooo00Kooooo1Ol0000Zooooo`Wo0000goooool002_ooooo0_l0000<ooooo`Go0000
00Co8B4Qonk^k_ooooooA4A41_ooool01?l0003oooooooooooooool6o`0002Wooooo2Ol0003Toooo
o`00;?ooool2o`0000kooooo1_l00004ooooo`So0000:Oooool9o`000>Sooooo000]ooooo`;o0000
4?ooool00onHV9So0000o`000007o`0002Wooooo2Ol0003]ooooo`00;_ooool2o`00013ooooo00?o
MgMgofIVI_ooool01Oooool00ol0003oooooooooo`0Rooooo`Wo0000l_ooool002oooooo0ol0000?
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07_ooool8o`000?Oooooo000`oooo
o`?o00002_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool06Oooool8
o`000?cooooo000booooo`?o00002?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000
ooooooooool05?ooool9o`000?oooooo0Oooool003?ooooo1?l0000Aooooo`03o`000?oooooooooo
013ooooo2?l0003oooooo`Kooooo000dooooo`Co00004?ooool00ol0003oooooooooo`0;ooooo`So
0000ooooool;ooooo`00=oooool4o`0000gooooo00?o0000ooooooooool01_ooool7o`000?oooooo
4Oooool003Sooooo1_l0000:ooooo`;o000000?oooooo`000?l000001_l0003ooooooaKooooo000l
oooooa?o0000oooooolJooooo`00@?ooool9o`000?oooooo8?ooool004Sooooo00?o0000oooooooo
ool0oooooolNooooo`00B?ooool00ol0003oooooooooo`3ooooooakooooo0018ooooo`03o`000?oo
oooooooo0?oooooo7_ooool004Sooooo00?o0000ooooooooool0oooooolNooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00A_ooool01?l@413o0000o`000?l0
003ooooooaoooooo0017ooooo`03o`000?oooooooooo0?oooooo7oooool004Oooooo00?o0000oooo
ooooool0oooooolOooooo`00Aoooool01_l0003oMgMgo`000?l0003oEEEEonk^k_oooooo7?ooool0
04Oooooo00Ko0000oeEEEOo^k^koooooogMgMomEEEGooooooacooooo0017ooooo`03o`000?o^k^ko
oooo00;ooooo00?o0000ooooooooool0oooooolJooooo`00Aoooool00ol0003ok^k^ooooo`02oooo
o`03o`000?oooooooooo0?oooooo6_ooool004Oooooo00Ko0000oeEEEOo^k^koooooogMgMomVIVKo
oooooacooooo0016ooooo`03oa0@4?l0003oMgMg00;o000000?oIVIVonk^k_ooool0oooooolKoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -2, 0, 0}}]
}, Open  ]],

Cell[TextData[{
  "These characteristics show particles falling toward ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  ", then rapidly reversing their velocities and returning to their initial \
heights. There is no damping in the equations of motion, so each particle in \
the gas continues to bounce off the bottom of the container forever. Unlike \
the  example of mixing dye presented earlier, the characteristics here are \
not chaotic. Each characteristic curve is parametrized by  the constant \
energy ",
  Cell[BoxData[
      \(TraditionalForm\`E\)]],
  " of particles on the curve. The particle motion is periodic, with a \
frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o\)]],
  " that depends on the energy:"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Omega]\_o = \(\[Omega]\_o\)(
        E)\)]]], "NumberedEquation",
  CellTags->"(7.1.22)"],

Cell[TextData[{
  "Even though the motion is not chaotic, an initial distribution of \
particles will rapidly filament and mix. This kind of nonchaotic mixing is \
called ",
  StyleBox[" phase mixing",
    FontSlant->"Italic"],
  ".  The  phase mixing is due to particles moving around their energy \
surfaces at different frequencies. The particles get ",
  StyleBox["out of phase",
    FontSlant->"Italic"],
  " with one another in their periodic motion. An initially localized patch \
of phase-space density becomes stretched and filamented due to the range of \
frequencies within the patch."
}], "Text",
  CellTags->"i:8"],

Cell[TextData[{
  "\tWe can see this phase mixing by following ",
  Cell[BoxData[
      \(TraditionalForm\`M = 500\)]],
  " particles in their motion. We choose the particles with random initial \
velocities and positions in the range ",
  Cell[BoxData[
      \(TraditionalForm\`0 - 1/2\)]],
  ", and display their subsequent trajectories in Cell ",
  ButtonBox["7.7",
    ButtonData:>"Cell 7.7",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(M = 500;\)\), "\n", 
    \(\(\(particlepos[t1_]\  = 
        Table[c[0.5  Random[], 0.5  Random[]], {M}] /. t \[Rule] t1;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(Table[
        ListPlot[Evaluate[particlepos[t1]], 
          PlotRange \[Rule] {{\(-1\), 1}, {\(-1\), 1}}, 
          AspectRatio \[Rule] 1, AxesLabel \[Rule] {"\<x\>", "\<p\>"}], {t1, 
          0, 50,  .4}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.7"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.62963 .6271 Mdot
.65149 .5696 Mdot
.50576 .51665 Mdot
.52383 .6662 Mdot
.58363 .56646 Mdot
.62397 .60593 Mdot
.5048 .61315 Mdot
.72993 .50499 Mdot
.67404 .69205 Mdot
.552 .61242 Mdot
.54911 .64032 Mdot
.71963 .6004 Mdot
.66948 .51323 Mdot
.56814 .5308 Mdot
.66372 .74658 Mdot
.54431 .61459 Mdot
.58009 .68011 Mdot
.67034 .50867 Mdot
.57529 .56696 Mdot
.69041 .50368 Mdot
.65125 .62491 Mdot
.63842 .64126 Mdot
.60215 .73459 Mdot
.66878 .54086 Mdot
.68267 .72136 Mdot
.60064 .51006 Mdot
.51894 .72478 Mdot
.55633 .64547 Mdot
.68885 .54467 Mdot
.63599 .6368 Mdot
.61356 .72771 Mdot
.69558 .63313 Mdot
.71231 .6028 Mdot
.55716 .74187 Mdot
.61016 .61821 Mdot
.63838 .70101 Mdot
.67749 .64685 Mdot
.53773 .69095 Mdot
.65855 .67207 Mdot
.7314 .54548 Mdot
.7197 .62739 Mdot
.59541 .65867 Mdot
.60614 .64968 Mdot
.64983 .52554 Mdot
.64383 .54688 Mdot
.59267 .53367 Mdot
.53367 .67867 Mdot
.70429 .58266 Mdot
.60617 .53182 Mdot
.66656 .64171 Mdot
.69762 .60975 Mdot
.68516 .59624 Mdot
.72792 .73236 Mdot
.58975 .68757 Mdot
.62179 .58268 Mdot
.68992 .66202 Mdot
.72796 .5358 Mdot
.59725 .62835 Mdot
.69429 .60713 Mdot
.64295 .54569 Mdot
.58812 .57531 Mdot
.72639 .65398 Mdot
.64049 .71555 Mdot
.54124 .55774 Mdot
.66257 .73319 Mdot
.70149 .62017 Mdot
.54079 .65051 Mdot
.51157 .70815 Mdot
.56283 .61472 Mdot
.66432 .5798 Mdot
.61854 .50759 Mdot
.52137 .53411 Mdot
.53042 .68228 Mdot
.54497 .63013 Mdot
.63993 .71673 Mdot
.50374 .57239 Mdot
.72736 .73353 Mdot
.55225 .70222 Mdot
.68657 .58302 Mdot
.54069 .74407 Mdot
.62374 .7183 Mdot
.62636 .66427 Mdot
.5052 .71071 Mdot
.605 .63017 Mdot
.72478 .52843 Mdot
.56002 .50004 Mdot
.58485 .56171 Mdot
.55628 .67765 Mdot
.60749 .57817 Mdot
.50403 .72543 Mdot
.67092 .74515 Mdot
.71334 .73136 Mdot
.54718 .52685 Mdot
.58698 .56709 Mdot
.54198 .56614 Mdot
.73198 .68692 Mdot
.56721 .5377 Mdot
.67196 .68688 Mdot
.73236 .726 Mdot
.61568 .50924 Mdot
.62487 .64782 Mdot
.61165 .53381 Mdot
.70395 .65267 Mdot
.64831 .55245 Mdot
.65677 .62582 Mdot
.56133 .73537 Mdot
.61479 .55969 Mdot
.57935 .54845 Mdot
.54758 .52198 Mdot
.65739 .61156 Mdot
.56522 .54599 Mdot
.54171 .60232 Mdot
.69035 .64816 Mdot
.68006 .56851 Mdot
.7364 .74549 Mdot
.53175 .51606 Mdot
.57963 .61967 Mdot
.72042 .53069 Mdot
.71484 .55998 Mdot
.64107 .73224 Mdot
.66726 .538 Mdot
.73369 .62068 Mdot
.60204 .74201 Mdot
.69198 .51836 Mdot
.66168 .59385 Mdot
.51192 .69985 Mdot
.67528 .59836 Mdot
.73017 .68379 Mdot
.59565 .72869 Mdot
.50975 .6531 Mdot
.63081 .66871 Mdot
.61867 .67086 Mdot
.71355 .63071 Mdot
.63499 .55018 Mdot
.61151 .6387 Mdot
.69301 .53182 Mdot
.69983 .54485 Mdot
.68109 .58198 Mdot
.52454 .69649 Mdot
.70093 .64819 Mdot
.67889 .7178 Mdot
.69118 .74509 Mdot
.54809 .54909 Mdot
.57251 .57423 Mdot
.58454 .66838 Mdot
.68752 .52405 Mdot
.72303 .52968 Mdot
.74451 .74223 Mdot
.5232 .73482 Mdot
.56341 .66025 Mdot
.74866 .53833 Mdot
.61249 .51206 Mdot
.56976 .57054 Mdot
.67131 .51697 Mdot
.52168 .52145 Mdot
.5988 .69274 Mdot
.68714 .60307 Mdot
.66128 .66869 Mdot
.71411 .5734 Mdot
.66677 .67646 Mdot
.6909 .58857 Mdot
.60336 .5162 Mdot
.69224 .55024 Mdot
.74087 .50414 Mdot
.62248 .7297 Mdot
.56957 .73717 Mdot
.6008 .70825 Mdot
.72077 .54444 Mdot
.66367 .60518 Mdot
.55949 .62575 Mdot
.69956 .53179 Mdot
.64271 .6993 Mdot
.50866 .69321 Mdot
.53935 .68309 Mdot
.56642 .64298 Mdot
.54848 .67895 Mdot
.69394 .66327 Mdot
.72891 .69177 Mdot
.59313 .70502 Mdot
.50814 .64734 Mdot
.67947 .59984 Mdot
.69865 .52158 Mdot
.72991 .56805 Mdot
.55594 .57229 Mdot
.72125 .62484 Mdot
.51659 .6392 Mdot
.65483 .73186 Mdot
.71811 .71025 Mdot
.71089 .56859 Mdot
.7392 .51848 Mdot
.61776 .61357 Mdot
.73106 .62115 Mdot
.68829 .51373 Mdot
.5324 .59956 Mdot
.70838 .69568 Mdot
.72646 .52727 Mdot
.73714 .57084 Mdot
.70987 .63807 Mdot
.5823 .58898 Mdot
.74176 .67782 Mdot
.62141 .52039 Mdot
.50256 .65934 Mdot
.50365 .65682 Mdot
.52151 .53819 Mdot
.56536 .64308 Mdot
.7391 .68863 Mdot
.60698 .6974 Mdot
.51264 .66136 Mdot
.61984 .62656 Mdot
.55277 .52329 Mdot
.53754 .53759 Mdot
.56101 .59547 Mdot
.66613 .5172 Mdot
.55845 .68613 Mdot
.66247 .61038 Mdot
.53694 .64793 Mdot
.59711 .7173 Mdot
.54784 .7093 Mdot
.74013 .51989 Mdot
.53519 .54794 Mdot
.62029 .64333 Mdot
.73242 .52465 Mdot
.58275 .60574 Mdot
.67141 .67918 Mdot
.66663 .58854 Mdot
.61297 .74305 Mdot
.50415 .72816 Mdot
.57602 .59512 Mdot
.65704 .51086 Mdot
.52819 .63582 Mdot
.66691 .74097 Mdot
.74299 .58788 Mdot
.54662 .59764 Mdot
.51057 .56323 Mdot
.71386 .7419 Mdot
.58916 .63405 Mdot
.54724 .65335 Mdot
.72619 .641 Mdot
.54308 .67519 Mdot
.65017 .54589 Mdot
.63604 .66433 Mdot
.62198 .66007 Mdot
.71913 .67337 Mdot
.62899 .57219 Mdot
.67252 .57573 Mdot
.61842 .50896 Mdot
.70865 .58383 Mdot
.52926 .62491 Mdot
.66142 .68048 Mdot
.55306 .7339 Mdot
.61833 .50528 Mdot
.6529 .68802 Mdot
.73229 .59095 Mdot
.53091 .52794 Mdot
.51316 .66758 Mdot
.65193 .70575 Mdot
.59064 .59185 Mdot
.53351 .69679 Mdot
.63199 .50802 Mdot
.50425 .57188 Mdot
.72057 .57754 Mdot
.70119 .58798 Mdot
.60223 .57226 Mdot
.54829 .64996 Mdot
.61994 .73131 Mdot
.51738 .62202 Mdot
.60679 .56373 Mdot
.61545 .66626 Mdot
.51615 .72187 Mdot
.58194 .71947 Mdot
.63416 .71385 Mdot
.57769 .64759 Mdot
.66359 .63631 Mdot
.62651 .55962 Mdot
.56136 .56405 Mdot
.57822 .65965 Mdot
.69142 .58274 Mdot
.56084 .53764 Mdot
.58463 .51901 Mdot
.69539 .62137 Mdot
.56849 .54714 Mdot
.61345 .6519 Mdot
.68433 .58328 Mdot
.53576 .50431 Mdot
.52073 .69698 Mdot
.65925 .69469 Mdot
.70937 .63293 Mdot
.58104 .53504 Mdot
.51795 .55019 Mdot
.5202 .7474 Mdot
.68332 .53118 Mdot
.57481 .62602 Mdot
.61484 .73404 Mdot
.71136 .72412 Mdot
.68051 .65076 Mdot
.67561 .71982 Mdot
.65978 .70378 Mdot
.51636 .52513 Mdot
.70041 .57085 Mdot
.68532 .74009 Mdot
.68245 .52066 Mdot
.66512 .74269 Mdot
.74913 .73949 Mdot
.59032 .61667 Mdot
.63429 .50544 Mdot
.62896 .64254 Mdot
.70378 .60469 Mdot
.70335 .67273 Mdot
.544 .65091 Mdot
.68699 .6476 Mdot
.5936 .58005 Mdot
.50167 .65751 Mdot
.66114 .55939 Mdot
.58655 .66482 Mdot
.66201 .5699 Mdot
.74623 .54815 Mdot
.52772 .56446 Mdot
.61728 .65561 Mdot
.57394 .70977 Mdot
.66393 .73288 Mdot
.52993 .55886 Mdot
.72693 .58528 Mdot
.68634 .72881 Mdot
.72526 .67777 Mdot
.52519 .66942 Mdot
.63872 .51296 Mdot
.61318 .59952 Mdot
.64249 .71481 Mdot
.58546 .53506 Mdot
.52521 .5592 Mdot
.51153 .57529 Mdot
.61128 .57632 Mdot
.7316 .51643 Mdot
.63435 .74103 Mdot
.54526 .53762 Mdot
.65909 .56326 Mdot
.52007 .6182 Mdot
.52037 .5503 Mdot
.65688 .51868 Mdot
.62789 .5855 Mdot
.57142 .73362 Mdot
.60268 .5263 Mdot
.55989 .65833 Mdot
.74139 .69998 Mdot
.5783 .64191 Mdot
.60704 .70894 Mdot
.53304 .60429 Mdot
.69795 .64568 Mdot
.51297 .73609 Mdot
.67758 .59538 Mdot
.60609 .71741 Mdot
.54969 .50988 Mdot
.53467 .73379 Mdot
.69702 .73359 Mdot
.72477 .57546 Mdot
.70563 .53361 Mdot
.64647 .68355 Mdot
.59858 .57467 Mdot
.61344 .57926 Mdot
.65063 .67898 Mdot
.60046 .59316 Mdot
.72305 .5836 Mdot
.74437 .62575 Mdot
.67335 .57372 Mdot
.70971 .64196 Mdot
.72634 .59013 Mdot
.73493 .5665 Mdot
.52071 .55652 Mdot
.58846 .63295 Mdot
.67213 .73186 Mdot
.72502 .5537 Mdot
.5215 .55287 Mdot
.62456 .71053 Mdot
.54845 .71927 Mdot
.63019 .58479 Mdot
.62509 .64556 Mdot
.67048 .69283 Mdot
.64876 .55543 Mdot
.68554 .62633 Mdot
.62804 .74891 Mdot
.59708 .74338 Mdot
.70592 .51705 Mdot
.62206 .68969 Mdot
.68442 .71418 Mdot
.7475 .72915 Mdot
.63597 .7449 Mdot
.61731 .64436 Mdot
.51088 .59935 Mdot
.69683 .70153 Mdot
.61213 .54392 Mdot
.51129 .5752 Mdot
.73408 .54502 Mdot
.6642 .58182 Mdot
.52816 .52797 Mdot
.54214 .64214 Mdot
.59374 .56379 Mdot
.54464 .66299 Mdot
.70777 .56889 Mdot
.67733 .51862 Mdot
.69689 .71954 Mdot
.7305 .56709 Mdot
.58476 .67562 Mdot
.71921 .74188 Mdot
.60068 .6306 Mdot
.55501 .66006 Mdot
.57251 .60263 Mdot
.51287 .51792 Mdot
.72877 .53884 Mdot
.71822 .60494 Mdot
.521 .71995 Mdot
.54089 .58632 Mdot
.57411 .50041 Mdot
.56039 .51923 Mdot
.73935 .57479 Mdot
.59118 .52735 Mdot
.63867 .69419 Mdot
.53617 .61729 Mdot
.56616 .59156 Mdot
.5233 .59936 Mdot
.58739 .55272 Mdot
.55508 .74443 Mdot
.56638 .58277 Mdot
.51418 .65811 Mdot
.74227 .58236 Mdot
.70379 .63887 Mdot
.50292 .50756 Mdot
.61261 .61152 Mdot
.61425 .56337 Mdot
.57644 .74424 Mdot
.54809 .72181 Mdot
.55314 .64487 Mdot
.7107 .66909 Mdot
.74807 .65045 Mdot
.64432 .58632 Mdot
.73389 .74234 Mdot
.65205 .50396 Mdot
.53009 .60347 Mdot
.64913 .7464 Mdot
.66748 .74194 Mdot
.53488 .68303 Mdot
.59104 .7477 Mdot
.73679 .71122 Mdot
.53789 .60283 Mdot
.52609 .54213 Mdot
.53982 .70239 Mdot
.63177 .70581 Mdot
.55594 .71005 Mdot
.72972 .70185 Mdot
.52584 .60658 Mdot
.5806 .70545 Mdot
.60836 .61464 Mdot
.54571 .52242 Mdot
.51733 .61694 Mdot
.55892 .56121 Mdot
.72943 .51411 Mdot
.53283 .51908 Mdot
.68961 .56172 Mdot
.65105 .56327 Mdot
.63367 .60167 Mdot
.67133 .61142 Mdot
.60783 .74509 Mdot
.59073 .65598 Mdot
.74947 .63045 Mdot
.54502 .63355 Mdot
.73214 .51351 Mdot
.7361 .57235 Mdot
.50271 .74941 Mdot
.70328 .55327 Mdot
.56309 .68769 Mdot
.55222 .74 Mdot
.67942 .58602 Mdot
.63089 .62857 Mdot
.57159 .59092 Mdot
.54016 .7226 Mdot
.57213 .71048 Mdot
.74513 .58904 Mdot
.58999 .69696 Mdot
.50903 .5167 Mdot
.58728 .69756 Mdot
.55576 .71343 Mdot
.52419 .50987 Mdot
.50354 .72343 Mdot
.59477 .67385 Mdot
.62265 .59486 Mdot
.52317 .58293 Mdot
.58249 .62226 Mdot
.70105 .62245 Mdot
.58736 .53322 Mdot
.61106 .67549 Mdot
.57832 .51652 Mdot
.52378 .72793 Mdot
.52257 .55309 Mdot
.74959 .71806 Mdot
.51903 .57966 Mdot
.65483 .54421 Mdot
.64638 .73481 Mdot
.63165 .71128 Mdot
.56389 .61255 Mdot
.6806 .58882 Mdot
.72654 .57933 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0^Oooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1Oooool00ol0003oooooooooo`2iooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`2iooooo`00POooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVY
ZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000;Wooooo0029ooooo`05o`000?oo
ooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0^Oooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEE
EOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;Wo
oooo0029ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0^Oooool008Wooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo0;Wooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`00
00Cooooo1?l00006ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Ooo
ool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`00
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool0097ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo
00?o0000ooooooooool0^Oooool0097ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`Ko00000_oo
ool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2iooooo`00TOooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool0
1?ooool3o`000;Wooooo002Aooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0^Oooool0097ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0^Oooool0097ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0^Oooool0097ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooooooo
o`2iooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;Wooooo
0021ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0
2Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05o`000?oo
ooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo
0ol0002iooooo`00ROooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool0
0oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0^Oooool008Wooooo
00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`2iooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0^Oooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool000Wooooo1?l000000ol@413ooooooooo
o`0Fooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool0
1?ooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Fooooo`03o`00
0?oooooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM01So
oooo1?l000000ol@413oooooooooo`0Booooo`002oooool00ol0003oooooooooo`0Hooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo
<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01oooool00omgMgOo<S8booooo`0Eooooo`03o`000?oooooooooo01Sooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oo
oooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool0
0omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo01Wooooo00?o0000ooooooooool05?ooool0
00Ko00001Oooool00ol0003oooooooooo`0@ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo
410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`05ooooo`Ko00000_ooool0
1Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool01Oooool6o`0000;ooooo00Go
410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0Hooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP09ooooo`03o`000?oooooooooo00gooooo00Go410@oooooooooooooooooa0@400@oooo
o`03o`000?oooooooooo00gooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGo
oooo00Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0
003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06
ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo
00?oMgMgoc8b<_ooool05Oooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool0
00003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000oooooooo
ooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool06Oooool00ol0003oooooooooo`0D
ooooo`002oooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool0
0omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooo
oooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05_ooool0
0ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000co
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003_ooool0
0omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06_ooool00ol0003ooooooooo
o`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05oa0@4?ooooooooooooooool@41003_oo
ool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool06?ooool3o`0001Sooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04Oooool01Ol@
413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooo
oooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`0Aooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooo
oonHV9So410@00Cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00co
oooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooo
oooooooooooooc8b<P04ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05?ooool0
00Wooooo00?oEEEEofIVI_l000006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004
ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0000Gooooo`03
o`000?oooooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00004?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00006Oooool00omEEEGoIVIV
o`00000Fooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`2^ooooo`;o00000_ooool2o`0000Gooooo002/ooooo`03
o`000?oooooooooo0:kooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd5ooooo`00[?ooool00ol0
003oooooooooo`2_ooooo`04omgMgOl0003o410@olc<c0Kooooo0007oooooooo0000C?l0000<oooo
o`04onk^k_lQ8B7o410@onk^kPKooooo0007ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`04o`000?oooooo0000o`0000Cooooo00Co0000
ooooool0003o00000oooool2o`0000Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`;o00001_ooool01?l0003oooooooooooooool2o`0000;ooooo00?o0000ooooooooool0
1_ooool01?l0003oooooooooooooool2o`0000;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0:ooooo`04ob4Q8OmgMgOoMgMgoc8b<PKooooo0007ooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Ko
oooo0ol00008ooooo`;o00006_ooool2o`000003ooooool0003ooooo00;o00001?ooool2o`0000[o
oooo0_l0000;ooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo00Wooooo0_l00002ooooo`;o00001Oooool00:cooooo
0ol00005ooooo`;o00001_ooool2o`0000oooooo0_l00003ooooo`?o00000_ooool3o`0000[ooooo
0_l0000Aooooo`;o0000Koooool00:cooooo00?o0000ooooooooool01Oooool2o`0000Kooooo0_l0
000?ooooo`;o00000_ooool4o`0000;ooooo1?l00004ooooo`;o00000oooool2o`0001;ooooo0_l0
001^ooooo`00[?ooool3o`0000Oooooo0_l0000=ooooo`;o00001oooool2o`000003ooooool0003o
000000Kooooo0_l00004ooooo`;o00000oooool2o`0000Cooooo0_l0000;ooooo`?o0000K_ooool0
0:cooooo1_l00004ooooo`;o00001oooool2o`0000Cooooo0_l000000ooooooo0000o`000004oooo
o`;o00003oooool2o`000003ooooool0003o000000Co00000_ooool3o`0000?ooooo0_l00005oooo
o`?o000000?oooooo`000?l00000Joooool00:cooooo00?o0000ooooooooool00ol000001?oooooo
0000o`000?ooool2o`0000?ooooo0_l00002ooooo`;o00001oooool2o`0000[ooooo0_l00009oooo
o`;o000000?oooooo`000?l000001_l000000ooooooo0000o`000002o`000003ooooool0003o0000
00Wooooo0_l0001[ooooo`00[?ooool3o`0000;ooooo1?l00006ooooo`Co00005Oooool2o`0000Oo
oooo0_l00009ooooo`?o00000_ooool2o`0000Wooooo0_l000000ooooooo0000o`00001[ooooo`00
[?ooool00ol0003oooooooooo`02ooooo`;o00000_ooool3o`0000?ooooo1?l0000;ooooo`;o0000
00?oooooo`000?l000003_ooool2o`0000[ooooo0_l0000;ooooo`Co0000K_ooool00:cooooo00?o
0000ooooooooool01_ooool3o`0000?ooooo0_l00005ooooo`;o00001_ooool2o`000003ooooool0
003o000001Wooooo0_l00003ooooo`;o00001Oooool4o`00073ooooo002/ooooo`03o`000?oooooo
oooo00Cooooo0_l0000=ooooo`;o00001?ooool4o`0000?ooooo0ol0000Fooooo`;o000000?ooooo
o`000?l000001?l00003ooooo`?o0000LOooool00:cooooo00?o0000ooooooooool01?ooool2o`00
00?ooooo0_l000000ooooooo0000o`000003ooooo`Co00000_ooool6o`0000?ooooo0ol0000Ioooo
o`;o00000_ooool2o`0000Kooooo0_l0001_ooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o
00000oooool2o`000003ooooool0003o000000?ooooo1?l00002ooooo`Co00006Oooool2o`0001;o
oooo0_l00005ooooo`;o0000J?ooool00:cooooo00?o0000ooooooooool01?ooool3o`0001_ooooo
0_l0000@ooooo`;o00004_ooool2o`0000Gooooo0_l0001Xooooo`00[?ooool00ol0003ooooooooo
o`05ooooo`;o00002oooool2o`0000kooooo0_l00008ooooo`Ko00002Oooool2o`0000;ooooo0_l0
0004ooooo`;o00000_ooool3o`0006gooooo002/ooooo`03o`000?oooooooooo00Sooooo0_l00002
ooooo`;o00001?ooool3o`0000;ooooo0_l0000Cooooo`Ko00002Oooool2o`0000;ooooo0_l00004
ooooo`;o00000_ooool3o`0000;ooooo0_l0001Yooooo`00[?ooool3o`0000;ooooo1?l00002oooo
o`;o00000_ooool2o`0000Gooooo0_l00002ooooo`Co00003_ooool2o`0000?ooooo0_l0000<oooo
o`;o00004?ooool2o`0006Wooooo002/ooooo`03o`000?oooooooooo00;ooooo1?l0000Cooooo`;o
00003_ooool2o`0000?ooooo0_l0000<ooooo`;o00000_ooool2o`0000Gooooo0_l0001`ooooo`00
[?ooool00ol0003oooooooooo`03ooooo`Go00000_ooool2o`0002;ooooo0_l0000@ooooo`;o0000
1Oooool2o`00073ooooo002/ooooo`03o`000?oooooooooo00?ooooo1Ol00002ooooo`;o00001?oo
ool2o`0000Oooooo0_l00007ooooo`;o00000_ooool2o`0000[ooooo0_l00007ooooo`;o00001_oo
ool2o`0007Cooooo002/ooooo`03o`000?oooooooooo00;o00000oooool3o`0000Sooooo0ol00006
ooooo`;o000000?oooooo`000?l000000_ooool4o`0000;ooooo0_l00006ooooo`;o000000Cooooo
o`000?l0003o00001oooool2o`0000Kooooo0_l0001dooooo`00[?ooool00ol0003oooooooooo`02
o`0000Cooooo0_l00002ooooo`;o00001Oooool2o`0000;ooooo0_l000001Ooooooo0000o`000?l0
003ooooo00;o00000_ooool4o`0000[ooooo0_l000000ooooooo0000o`00000Eooooo`Co0000KOoo
ool00:cooooo00?o0000ooooooooool02_ooool2o`0000Sooooo0ol000001?oooooo0000o`000?l0
000Dooooo`;o000000?oooooo`000?l000001?ooool2o`0000Gooooo1Ol00004ooooo`Go0000K?oo
ool00:cooooo0ol0000?ooooo`;o00000oooool2o`0000Sooooo0_l00007ooooo`;o00001_ooool2
o`000003ooooool0003o000000;ooooo1?l00005ooooo`Ko00001_ooool2o`0006cooooo002/oooo
o`Go00003Oooool2o`0000?ooooo0_l00004ooooo`;o000000Goooooo`000?l0003o0000ooooo`02
o`0000Cooooo0_l0000=ooooo`;o00002oooool2o`0000;ooooo0_l00002ooooo`?o0000Joooool0
0:cooooo00?o0000ooooooooool00_l000000ooooooo0000o`00000?ooooo`;o00001?ooool5o`00
0003ooooool0003o000000;o00003oooool2o`000003ooooool0003o000000gooooo1?l00003oooo
o`;o0000Joooool00:cooooo00?o0000ooooooooool00oooool3o`0000cooooo0_l00007ooooo`;o
00000oooool4o`000003ooooool0003o000000cooooo0_l00003ooooo`Ko00000_ooool2o`0000?o
oooo1?l00004ooooo`;o0000J_ooool00:cooooo00?o0000ooooooooool01?ooool2o`0000Cooooo
0_l00006ooooo`;o00004Oooool5o`0000;ooooo0_l00005ooooo`;o00000oooool6o`0000;ooooo
0ol00003ooooo`?o00001?ooool2o`0006[ooooo002/ooooo`03o`000?oooooooooo00[ooooo0_l0
000<ooooo`;o00003Oooool3o`0000;ooooo0_l00006ooooo`;o00000_ooool2o`0000;ooooo0_l0
00000ooooooo0000o`000002o`0000?ooooo0ol00004ooooo`;o0000J_ooool00:cooooo00?o0000
ooooooooool04_ooool4o`0000;ooooo1?l0000Hooooo`;o00000_ooool2o`0000;ooooo0_l00000
0ooooooo0000o`000006ooooo`Co00000_ooool2o`0006[ooooo002/ooooo`03o`000?oooooooooo
01;ooooo1_l00002ooooo`;o00000_ooool2o`0000Gooooo0_l0000;ooooo`;o00000oooool2o`00
00kooooo1?l0001^ooooo`00[?ooool00ol0003oooooooooo`0<ooooo`;o00000oooool2o`0000?o
oooo0_l00006ooooo`;o00001Oooool2o`0000_ooooo0_l00002ooooo`?o000000?oooooo`000?l0
0000OOooool00:cooooo1Ol00002ooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo
0_l0000?ooooo`;o00004_ooool6o`0000Wooooo0_l0001booooo`00[?ooool00ol0003ooooooooo
o`02o`0000;ooooo2?l00008ooooo`;o00003?ooool2o`0000Gooooo0_l0000=ooooo`Co00001ooo
ool4o`0007;ooooo002/ooooo`03o`000?oooooooooo00Gooooo1ol00008ooooo`;o00000_ooool2
o`0000_ooooo0_l00002ooooo`;o00002?ooool2o`0000Gooooo0_l000001?oooooo0000o`000?oo
ool2o`000003ooooool0003o000000;o0000L_ooool00:cooooo00?o0000ooooooooool01Oooool2
o`00017ooooo0_l0000;ooooo`;o00002oooool3o`0000Sooooo1Ol00003ooooo`;o0000L_ooool0
0:cooooo0ol0000>ooooo`;o00000_ooool2o`0000kooooo0ol0000<ooooo`?o000000?oooooo`00
0?l000001oooool2o`0007Wooooo002/ooooo`?o00002oooool2o`000004ooooool0003o0000oooo
o`?o00003?ooool5o`0000cooooo0_l00002ooooo`;o0000P_ooool008Wooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo00;ooooo0ol00004ooooo`Co00001?ooool2o`0000Oooooo0_l00004
ooooo`?o0000U_ooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`02ooooo`?o00001?ooool2o`0000cooooo1Ol00005ooooo`;o00006_ooool4o`0000Sooooo0ol0
001]ooooo`00ROooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Ooo
ool00ol0003oooooooooo`03ooooo`?o00000_ooool2o`0000;ooooo0_l0000?ooooo`?o00005?oo
ool2o`0000gooooo1?l00005ooooo`;o000000Coooooo`000?l0003o0000KOooool008Wooooo00Go
0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`06ooooo`;o00002?ooool2o`0000?ooooo0_l00006ooooo`;o0000
1Oooool2o`000004ooooool0003o0000o`0000Cooooo1?l00008ooooo`;o00002Oooool3o`0000Go
oooo0_l0001Zooooo`00ROooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_oo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool02oooool2o`00
00?ooooo0_l00003ooooo`;o00001_ooool4o`0000?ooooo0_l000001?oooooo0000o`000?l00006
ooooo`;o00002?ooool2o`0000Oooooo1?l00006ooooo`Co0000J?ooool008Wooooo00Go410@oooo
oooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0;ooooo`;o00003Oooool2o`0000;ooooo0ol0000Looooo`;o00000oooool3
o`0000[ooooo0_l0001Xooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000
okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool2o`0000?ooooo0_l0000=ooooo`;o00003Oooool2o`0000Sooooo0_l00008ooooo`;o00000ooo
ool2o`0007Gooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`00
0?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o0000
1Oooool2o`0001;ooooo0_l00006ooooo`;o00002?ooool2o`0000_ooooo1?l0001eooooo`00[?oo
ool00ol0003oooooooooo`02ooooo`;o00001_ooool2o`000003ooooool0003o000000?ooooo0_l0
0002ooooo`;o00002Oooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l00000
2?ooool2o`0000[ooooo1?l00003ooooo`;o0000L?ooool00:cooooo00?o0000ooooooooool02_oo
ool2o`0000;ooooo0ol000000ooooooo0000o`000002ooooo`;o00002oooool6o`000003ooooool0
003o000000Sooooo0_l000000ooooooo0000o`000005ooooo`;o00000_ooool2o`0000?ooooo0_l0
001`ooooo`00[?ooool01?l0003oooooo`000?l00008ooooo`;o00000oooool3o`0000Gooooo0_l0
0008ooooo`;o000000Coooooo`000?l0003ooooo0_l0000?ooooo`;o000000Goooooo`000?l0003o
0000ooooo`03o`0007Sooooo002/ooooo`Co00002?ooool6o`0000Oooooo0_l00008ooooo`Co0000
0_ooool2o`00013ooooo1Ol00002ooooo`?o00003?ooool2o`0006Wooooo002/ooooo`03o`000?oo
oooooooo00;o00002?ooool5o`0000cooooo0_l00005ooooo`?o00004oooool2o`0000Kooooo0_l0
0005ooooo`;o00001Oooool2o`0006Wooooo002/ooooo`Ko00002Oooool2o`0000;ooooo0_l00009
ooooo`?o00001Oooool2o`0002;ooooo0_l0001`ooooo`00[?ooool3o`000003ooooool0003o0000
00cooooo1?l00003ooooo`;o00001?ooool2o`0000Oooooo0_l0000Dooooo`;o0000O?ooool00:co
oooo0_l00002ooooo`;o00002?ooool2o`0000;ooooo1?l00003ooooo`;o000000?oooooo`000?l0
00002_ooool3o`000003ooooool0003o0000013ooooo1?l0001jooooo`00[?ooool01?l0003ooooo
ooooooooool2o`000003ooooool0003o000000Gooooo0_l0000<ooooo`;o00002?ooool2o`000004
ooooool0003o0000ooooo`;o00004_ooool2o`0007[ooooo002/ooooo`04o`000?oooooooooooooo
o`;o000000Coooooo`000?l0003o00004Oooool2o`0000Wooooo0ol00002ooooo`;o00002?ooool2
o`0000kooooo0_l0001eooooo`00[?ooool00ol0003oooooooooo`05ooooo`;o00004Oooool2o`00
00;ooooo0_l00006ooooo`;o00000_ooool2o`0000Oooooo0ol0000<ooooo`Co000000?oooooo`00
0?l00000L_ooool00:cooooo0ol0000;ooooo`;o00003?ooool2o`000003ooooool0003o000000?o
oooo0_l0000>ooooo`;o000000?oooooo`000?l000002_ooool2o`0000?ooooo0_l0001booooo`00
[?ooool00ol0003oooooooooo`08ooooo`;o000000?oooooo`000?l000001?l00006ooooo`Co0000
1_ooool2o`0000_ooooo0_l00004ooooo`?o00004?ooool2o`0000?ooooo0_l0001[ooooo`00[?oo
ool00ol0003oooooooooo`07ooooo`Go000000?oooooo`000?l000000_l00006ooooo`;o00005Ooo
ool2o`0000;ooooo0_l000000ooooooo0000o`00000@ooooo`;o00000oooool2o`0006_ooooo002/
ooooo`03o`000?oooooooooo00Oooooo1Ol00004ooooo`;o00006oooool2o`0000?ooooo0_l0000E
ooooo`;o0000K_ooool00:cooooo00?o0000ooooooooool04?ooool3o`0000Oooooo0_l0000Aoooo
o`Co00001?ooool2o`0001;ooooo1?l0001/ooooo`00[?ooool00ol0003oooooooooo`09ooooo`;o
00001_ooool2o`0000Oooooo0_l00009ooooo`;o00002?ooool2o`0000Cooooo0ol0000@ooooo`Go
0000K?ooool00:cooooo00Co0000ooooool0003o00002?ooool2o`0001;ooooo0_l00006ooooo`;o
00000oooool2o`0000Gooooo0_l00002ooooo`?o00004?ooool2o`0006oooooo002/ooooo`04o`00
0?oooooo0000o`0000;ooooo1?l000000ooooooo0000o`00000?ooooo`?o000000Coooooo`000?l0
003ooooo0_l00008ooooo`;o00001Oooool2o`0000;ooooo0_l0000:ooooo`;o0000M_ooool00:co
oooo1Ol000000ooooooo0000o`000002o`000003ooooool0003o000000oooooo0ol00004ooooo`;o
00002?ooool4o`0001?ooooo0_l00009ooooo`;o0000Joooool00:cooooo00?o0000ooooooooool0
0_l00008ooooo`;o00000_ooool2o`0001[ooooo1?l00003ooooo`;o00002oooool2o`0000Sooooo
0_l00002ooooo`;o0000Joooool00:cooooo00?o0000ooooooooool02_ooool2o`0000;ooooo0_l0
0007ooooo`;o00000_ooool2o`0000_ooooo0_l00005ooooo`Co00002oooool2o`0000Sooooo0_l0
001_ooooo`00[?ooool00ol0003oooooooooo`02o`0000[ooooo0_l000000ooooooo0000o`000003
ooooo`Go00000_ooool2o`000003ooooool0003o000000;o00001?ooool4o`0000Gooooo0_l0000D
ooooo`;o0000L_ooool00:cooooo1Ol0000:ooooo`;o000000?oooooo`000?l000000oooool3o`00
00Oooooo1?l00004ooooo`Co00006oooool2o`0000Cooooo0_l0001/ooooo`00[?ooool3o`0000oo
oooo0_l0000Gooooo`Ko00002oooool2o`00013ooooo0_l0001/ooooo`00[?ooool00ol0003ooooo
ooooo`0=ooooo`;o00002Oooool2o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`;o0000
0_ooool5o`0000[ooooo0ol00003ooooo`;o00003oooool2o`0006Sooooo002/ooooo`03o`000?oo
oooooooo00;ooooo0ol00005ooooo`Go00002Oooool2o`0000?ooooo0_l000000ooooooo0000o`00
0003ooooo`;o00001?ooool2o`0000[ooooo1?l00003ooooo`;o00003oooool2o`0006Sooooo002/
ooooo`?o00000_ooool3o`0000Gooooo1?l0000Yooooo`Co00001oooool2o`0007Gooooo002/oooo
o`?o00000oooool3o`0001Kooooo0_l00004ooooo`;o00007_ooool2o`0000Gooooo0_l0001^oooo
o`00[?ooool3o`0000Cooooo0_l0000Fooooo`;o00001?ooool5o`0001?ooooo0_l00007ooooo`;o
00001?ooool2o`0000?ooooo0_l0001Yooooo`00[?ooool00ol0003oooooooooo`08ooooo`;o0000
1?ooool2o`0000Cooooo0_l00008ooooo`;o00000_ooool5o`0000Cooooo0_l00003ooooo`Oo0000
0oooool2o`0000;ooooo0_l00003ooooo`;o00000oooool2o`0000Cooooo0_l0001Yooooo`00[?oo
ool01?l0003oooooooooooooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o0000
00Coooooo`000?l0003ooooo0_l00008ooooo`;o00000_ooool2o`0000Oooooo1?l000000ooooooo
0000o`000005o`0000Oooooo0_l00008ooooo`;o0000Koooool00:cooooo00Co0000oooooooooooo
oooo0_l000000ooooooo0000o`000008ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Goooo
o`;o00002oooool2o`0001?ooooo0_l0001Xooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0>
ooooo`?o00003?ooool3o`0000;ooooo0_l00005ooooo`;o00002?ooool3o`0000Cooooo0_l00007
ooooo`Co00000oooool2o`000003ooooool0003o000000;o0000J?ooool0097ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo00[ooooo0_l00003ooooo`;o00001Oooool2o`0000Gooooo1ol00005ooooo`;o00000oooool2
o`0000?ooooo1?l00005ooooo`;o00001Oooool4o`0000?ooooo1Ol0001Zooooo`00TOooool01Ol@
413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l00005
ooooo`;o00000oooool2o`0000Gooooo0_l00003ooooo`;o00000oooool2o`0000Gooooo1?l00003
ooooo`;o00000oooool4o`0000Gooooo0_l0000=ooooo`;o0000K?ooool0097ooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00003ooooo`;o00005_ooool2
o`0000[ooooo0_l0002@ooooo`00TOooool01Ol0003ooooooooooooooooo000000cooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;Wooooo002Aooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Wooooo002A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0;Wooooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o
0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Ooo
ool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0;Wooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
0;Wooooo0029ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0^Oooool008Wooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`00
0;Wooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2iooooo`00ROooool01Ol@
413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`2iooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Ooo
ool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002Rooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`2iooooo`00Y?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`03o`000?oooooooooo
00Gooooo0ol0002iooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003ooooo
ooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31
ooooo`00X_ooool00omEEEGoIVIVo`000033ooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00Z_ooool01?l@413o0000o`000?l0002jooooo`00Zoooool00ol0
003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool01_l0003oMgMg
o`000?l0003oEEEEonk^k[Oooooo002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoEEEE]oooool0
0:_ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`2eooooo`00Zoooool00ol0003o
k^k^ooooo`02ooooo`03o`000?oooooooooo0;Gooooo002[ooooo`06o`000?mEEEGok^k^oooooomg
MgOoIVIV]oooool00:[ooooo00?o410@o`000?mgMgL00_l000000omVIVKok^k^ooooo`2fooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.64046 .4271 Mdot
.63933 .3696 Mdot
.47556 .36389 Mdot
.55031 .4662 Mdot
.57022 .36646 Mdot
.62634 .40593 Mdot
.51006 .41315 Mdot
.69192 .30499 Mdot
.71086 .49205 Mdot
.55697 .41242 Mdot
.56523 .44032 Mdot
.71979 .4004 Mdot
.63477 .31323 Mdot
.54046 .3308 Mdot
.72235 .54658 Mdot
.55015 .41459 Mdot
.61214 .48011 Mdot
.63381 .30867 Mdot
.56207 .36696 Mdot
.65188 .30368 Mdot
.66122 .42491 Mdot
.65492 .44126 Mdot
.65598 .53459 Mdot
.64513 .34086 Mdot
.73121 .52136 Mdot
.56467 .31006 Mdot
.56886 .52478 Mdot
.57452 .44547 Mdot
.66672 .34467 Mdot
.65071 .4368 Mdot
.66465 .52771 Mdot
.70883 .43313 Mdot
.71343 .4028 Mdot
.61391 .54187 Mdot
.61745 .41821 Mdot
.67878 .50101 Mdot
.69623 .44685 Mdot
.57411 .49095 Mdot
.68738 .47207 Mdot
.70959 .34548 Mdot
.73066 .42739 Mdot
.61888 .45867 Mdot
.62601 .44968 Mdot
.62005 .32554 Mdot
.62258 .34688 Mdot
.56614 .33367 Mdot
.56513 .47867 Mdot
.69736 .38266 Mdot
.5789 .33182 Mdot
.68324 .44171 Mdot
.70152 .40975 Mdot
.68365 .39624 Mdot
.78087 .53236 Mdot
.62478 .48757 Mdot
.61486 .38268 Mdot
.71473 .46202 Mdot
.70227 .3358 Mdot
.60859 .42835 Mdot
.69714 .40713 Mdot
.62123 .34569 Mdot
.57824 .37531 Mdot
.74798 .45398 Mdot
.68672 .51555 Mdot
.52433 .35774 Mdot
.71585 .53319 Mdot
.70955 .42017 Mdot
.56099 .45051 Mdot
.55483 .50815 Mdot
.56872 .41472 Mdot
.65624 .3798 Mdot
.58158 .30759 Mdot
.49503 .33566 Mdot
.56334 .48228 Mdot
.55703 .43013 Mdot
.68662 .51673 Mdot
.49279 .37692 Mdot
.78077 .53353 Mdot
.59314 .50222 Mdot
.67978 .38302 Mdot
.59831 .54407 Mdot
.67106 .5183 Mdot
.65207 .46427 Mdot
.54948 .51071 Mdot
.61706 .43017 Mdot
.69615 .32843 Mdot
.52004 .30004 Mdot
.56953 .36171 Mdot
.58734 .47765 Mdot
.59876 .37817 Mdot
.5542 .52543 Mdot
.72898 .54515 Mdot
.76588 .53136 Mdot
.51792 .32685 Mdot
.57381 .36709 Mdot
.52844 .36614 Mdot
.76675 .48692 Mdot
.54229 .3377 Mdot
.70671 .48688 Mdot
.78276 .526 Mdot
.57937 .30924 Mdot
.644 .44782 Mdot
.58517 .33381 Mdot
.72502 .45267 Mdot
.62929 .35245 Mdot
.6671 .42582 Mdot
.61548 .53537 Mdot
.59866 .35969 Mdot
.55873 .34845 Mdot
.51638 .32198 Mdot
.66201 .41156 Mdot
.54362 .34599 Mdot
.54264 .40232 Mdot
.70962 .44816 Mdot
.66746 .36851 Mdot
.7946 .54549 Mdot
.49817 .31624 Mdot
.5875 .41967 Mdot
.6927 .33069 Mdot
.69883 .35998 Mdot
.69397 .53224 Mdot
.64246 .338 Mdot
.74196 .42068 Mdot
.65884 .54201 Mdot
.65932 .31836 Mdot
.65922 .39385 Mdot
.55185 .49985 Mdot
.67462 .39836 Mdot
.76368 .48379 Mdot
.64713 .52869 Mdot
.53099 .4531 Mdot
.65829 .46871 Mdot
.64702 .47086 Mdot
.72583 .43071 Mdot
.61506 .35018 Mdot
.62699 .4387 Mdot
.66574 .33182 Mdot
.67777 .34485 Mdot
.67388 .38198 Mdot
.56314 .49649 Mdot
.7202 .44819 Mdot
.72601 .5178 Mdot
.74922 .54509 Mdot
.52772 .34909 Mdot
.5622 .37423 Mdot
.61189 .46838 Mdot
.65714 .32405 Mdot
.6949 .32968 Mdot
.8014 .54223 Mdot
.57713 .53482 Mdot
.58751 .46025 Mdot
.72399 .33833 Mdot
.57731 .31206 Mdot
.55798 .37054 Mdot
.63809 .31697 Mdot
.49036 .32704 Mdot
.63589 .49274 Mdot
.68836 .40307 Mdot
.68875 .46869 Mdot
.70346 .3734 Mdot
.69736 .47646 Mdot
.68633 .38857 Mdot
.56984 .3162 Mdot
.67234 .35024 Mdot
.70253 .30414 Mdot
.67436 .5297 Mdot
.62444 .53717 Mdot
.6441 .50825 Mdot
.69854 .34444 Mdot
.66574 .40518 Mdot
.56979 .42575 Mdot
.67227 .33179 Mdot
.68243 .4993 Mdot
.54594 .49321 Mdot
.57259 .48309 Mdot
.58361 .44298 Mdot
.58006 .47895 Mdot
.71925 .46327 Mdot
.76562 .49177 Mdot
.63514 .50502 Mdot
.52708 .44734 Mdot
.6794 .39984 Mdot
.66729 .32158 Mdot
.71713 .36805 Mdot
.54486 .37229 Mdot
.73118 .42484 Mdot
.53227 .4392 Mdot
.70758 .53186 Mdot
.76221 .51025 Mdot
.69833 .36859 Mdot
.70659 .31848 Mdot
.62319 .41357 Mdot
.73951 .42115 Mdot
.65378 .31373 Mdot
.53223 .39956 Mdot
.74665 .49568 Mdot
.69737 .32727 Mdot
.72547 .37084 Mdot
.7251 .43807 Mdot
.57789 .38898 Mdot
.77289 .47782 Mdot
.58957 .32039 Mdot
.5263 .45934 Mdot
.52638 .45682 Mdot
.49679 .33885 Mdot
.5826 .44308 Mdot
.77456 .48863 Mdot
.64594 .4974 Mdot
.53719 .46136 Mdot
.63047 .42656 Mdot
.52209 .32329 Mdot
.51257 .33759 Mdot
.5592 .39547 Mdot
.63301 .3172 Mdot
.5929 .48613 Mdot
.66663 .41038 Mdot
.55611 .44793 Mdot
.64403 .5173 Mdot
.59156 .5093 Mdot
.70809 .31989 Mdot
.51437 .34794 Mdot
.63762 .44333 Mdot
.70228 .32465 Mdot
.58505 .40574 Mdot
.70308 .47918 Mdot
.66204 .38854 Mdot
.67018 .54305 Mdot
.55542 .52816 Mdot
.57407 .39512 Mdot
.62139 .31086 Mdot
.54251 .43582 Mdot
.72329 .54097 Mdot
.73814 .38788 Mdot
.54567 .39764 Mdot
.49588 .36453 Mdot
.77062 .5419 Mdot
.60278 .43405 Mdot
.56858 .45335 Mdot
.74259 .441 Mdot
.57316 .47519 Mdot
.62852 .34589 Mdot
.66178 .46433 Mdot
.64601 .46007 Mdot
.74848 .47337 Mdot
.61786 .37219 Mdot
.66281 .37573 Mdot
.582 .30896 Mdot
.70219 .38383 Mdot
.53922 .42491 Mdot
.69361 .48048 Mdot
.60663 .5339 Mdot
.58045 .30528 Mdot
.6881 .48802 Mdot
.72867 .39095 Mdot
.50209 .32794 Mdot
.54019 .46758 Mdot
.69423 .50575 Mdot
.58738 .39185 Mdot
.57222 .49679 Mdot
.59519 .30802 Mdot
.49309 .37601 Mdot
.71158 .37754 Mdot
.69638 .38798 Mdot
.59114 .37226 Mdot
.56827 .44996 Mdot
.67247 .53131 Mdot
.52618 .42202 Mdot
.59228 .36373 Mdot
.64196 .46626 Mdot
.56489 .52187 Mdot
.62973 .51947 Mdot
.6797 .51385 Mdot
.59673 .44759 Mdot
.67812 .43631 Mdot
.61035 .35962 Mdot
.54698 .36405 Mdot
.60208 .45965 Mdot
.68451 .38274 Mdot
.53589 .33764 Mdot
.55224 .31901 Mdot
.70394 .42137 Mdot
.54734 .34714 Mdot
.63421 .4519 Mdot
.67764 .38328 Mdot
.49748 .30464 Mdot
.55952 .49698 Mdot
.69713 .49469 Mdot
.72254 .43293 Mdot
.55505 .33504 Mdot
.49803 .35045 Mdot
.57915 .5474 Mdot
.65579 .33118 Mdot
.58522 .42602 Mdot
.66845 .53404 Mdot
.76101 .52412 Mdot
.70081 .45076 Mdot
.72353 .51982 Mdot
.70129 .50378 Mdot
.48674 .3365 Mdot
.68875 .37085 Mdot
.74136 .54009 Mdot
.65072 .32066 Mdot
.7222 .54269 Mdot
.80492 .53949 Mdot
.59698 .41667 Mdot
.59647 .30544 Mdot
.64597 .44254 Mdot
.70566 .40469 Mdot
.73244 .47273 Mdot
.56437 .45091 Mdot
.70603 .4476 Mdot
.58562 .38005 Mdot
.52467 .45751 Mdot
.6449 .35939 Mdot
.61247 .46482 Mdot
.64997 .3699 Mdot
.72549 .34815 Mdot
.5135 .36446 Mdot
.63952 .45561 Mdot
.61784 .50977 Mdot
.71708 .53288 Mdot
.51348 .35886 Mdot
.72105 .38528 Mdot
.73786 .52881 Mdot
.75637 .47777 Mdot
.55296 .46942 Mdot
.6039 .31296 Mdot
.61299 .39952 Mdot
.68841 .51481 Mdot
.55949 .33506 Mdot
.50889 .3592 Mdot
.50164 .37529 Mdot
.60181 .37632 Mdot
.69817 .31643 Mdot
.69076 .54103 Mdot
.52031 .33762 Mdot
.64439 .36326 Mdot
.52734 .4182 Mdot
.50049 .3503 Mdot
.62436 .31868 Mdot
.62208 .3855 Mdot
.62487 .53362 Mdot
.57319 .3263 Mdot
.58323 .45833 Mdot
.78138 .49998 Mdot
.59506 .44191 Mdot
.65062 .50894 Mdot
.53475 .40429 Mdot
.71623 .44568 Mdot
.56741 .53609 Mdot
.67573 .39538 Mdot
.65305 .51741 Mdot
.51365 .30988 Mdot
.58818 .53379 Mdot
.75045 .53359 Mdot
.71495 .37546 Mdot
.67907 .33361 Mdot
.67989 .48355 Mdot
.58845 .37467 Mdot
.60514 .37926 Mdot
.68222 .47898 Mdot
.59773 .39316 Mdot
.71649 .3836 Mdot
.75467 .42575 Mdot
.66284 .37372 Mdot
.72649 .44196 Mdot
.72239 .39013 Mdot
.72153 .3665 Mdot
.50332 .35652 Mdot
.60164 .43295 Mdot
.72487 .53186 Mdot
.7065 .3537 Mdot
.50265 .35287 Mdot
.66877 .51053 Mdot
.59616 .51927 Mdot
.6241 .38479 Mdot
.64331 .44556 Mdot
.70761 .49283 Mdot
.63092 .35543 Mdot
.69608 .42633 Mdot
.68761 .54891 Mdot
.65444 .54338 Mdot
.67274 .31705 Mdot
.65793 .48969 Mdot
.73009 .51418 Mdot
.79916 .52915 Mdot
.69393 .5449 Mdot
.63506 .44436 Mdot
.51062 .39935 Mdot
.73744 .50153 Mdot
.58969 .34392 Mdot
.50137 .3752 Mdot
.71209 .34502 Mdot
.65693 .38182 Mdot
.49935 .32799 Mdot
.559 .44214 Mdot
.57926 .36379 Mdot
.56984 .46299 Mdot
.69532 .36889 Mdot
.64478 .31862 Mdot
.7447 .51954 Mdot
.71733 .36709 Mdot
.61501 .47562 Mdot
.77597 .54188 Mdot
.61292 .4306 Mdot
.57903 .46006 Mdot
.57357 .40263 Mdot
.48109 .34205 Mdot
.70431 .33884 Mdot
.7202 .40494 Mdot
.56898 .51995 Mdot
.53542 .38632 Mdot
.53428 .30041 Mdot
.52808 .31923 Mdot
.72927 .37479 Mdot
.56212 .32735 Mdot
.67635 .49419 Mdot
.54308 .41729 Mdot
.56278 .39156 Mdot
.52305 .39936 Mdot
.56847 .35272 Mdot
.61284 .54443 Mdot
.55949 .38277 Mdot
.53743 .45811 Mdot
.73521 .38236 Mdot
.71934 .43887 Mdot
.47177 .37644 Mdot
.61722 .41152 Mdot
.59959 .36337 Mdot
.63414 .54424 Mdot
.59681 .52181 Mdot
.57109 .44487 Mdot
.73834 .46909 Mdot
.76825 .45045 Mdot
.63885 .38632 Mdot
.79082 .54234 Mdot
.61363 .30396 Mdot
.53148 .40347 Mdot
.70769 .5464 Mdot
.72426 .54194 Mdot
.56809 .48303 Mdot
.65012 .5477 Mdot
.78128 .51122 Mdot
.53902 .40283 Mdot
.50294 .34213 Mdot
.58078 .50239 Mdot
.67409 .50581 Mdot
.59996 .51005 Mdot
.77046 .50185 Mdot
.52848 .40658 Mdot
.62277 .50545 Mdot
.61422 .41464 Mdot
.51468 .32242 Mdot
.5241 .41694 Mdot
.5434 .36121 Mdot
.69508 .31411 Mdot
.50046 .31908 Mdot
.6743 .36172 Mdot
.63636 .36327 Mdot
.63434 .40167 Mdot
.6759 .41142 Mdot
.66586 .54509 Mdot
.61312 .45598 Mdot
.76164 .43045 Mdot
.55844 .43355 Mdot
.69754 .31351 Mdot
.72504 .37235 Mdot
.56247 .54941 Mdot
.68458 .35327 Mdot
.59817 .48769 Mdot
.60822 .54 Mdot
.67383 .38602 Mdot
.64232 .42857 Mdot
.56796 .39092 Mdot
.58919 .5226 Mdot
.61632 .51048 Mdot
.74075 .38904 Mdot
.62877 .49696 Mdot
.47771 .35282 Mdot
.6263 .49756 Mdot
.60113 .51343 Mdot
.48831 .31768 Mdot
.55291 .52343 Mdot
.62431 .47385 Mdot
.62059 .39486 Mdot
.51635 .38293 Mdot
.59139 .42226 Mdot
.71003 .42245 Mdot
.56064 .33322 Mdot
.64126 .47549 Mdot
.54493 .31652 Mdot
.57495 .52793 Mdot
.5038 .35309 Mdot
.79682 .51806 Mdot
.51089 .37966 Mdot
.63251 .34421 Mdot
.70031 .53481 Mdot
.67616 .51128 Mdot
.56891 .41255 Mdot
.67613 .38882 Mdot
.71827 .37933 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0^Oooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1Oooool00ol0003oooooooooo`2iooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`2iooooo`00POooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVY
ZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000;Wooooo0029ooooo`05o`000?oo
ooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0^Oooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEE
EOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;Wo
oooo0029ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0^Oooool008Wooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo0;Wooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`00
00Cooooo1?l00006ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Ooo
ool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`00
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool0097ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo
00?o0000ooooooooool0^Oooool0097ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`Ko00000_oo
ool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2iooooo`00TOooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool0
1?ooool3o`000;Wooooo002Aooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0^Oooool0097ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0^Oooool0097ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0^Oooool0097ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`?o00000oooool2o`0000?ooooo0_l0002_ooooo`00[?ooool00ol0003oooooooooo`03
ooooo`;o00000oooool2o`0001Sooooo0_l0000;ooooo`;o00003_ooool2o`0007Sooooo002[oooo
o`;o00006Oooool2o`0000?ooooo0_l00004ooooo`;o00002oooool2o`0000_ooooo0_l000000ooo
oooo0000o`00001hooooo`00Zoooool2o`0000?ooooo0_l0000?ooooo`;o00000oooool3o`0000;o
oooo0_l0000;ooooo`;o00004Oooool2o`0007_ooooo002/ooooo`04o`000?ooooooooooooooo`;o
00003oooool2o`0000;ooooo1?l00002ooooo`;o000000?oooooo`000?l000001?ooool2o`0000;o
oooo0_l0000Cooooo`;o0000NOooool00:_ooooo0_l0000=ooooo`;o00001oooool4o`0000Oooooo
0_l00004ooooo`;o00000_ooool2o`0000Cooooo0_l0000<ooooo`?o0000NOooool00:Sooooo0_l0
00001?oooooo0000o`000?l00007ooooo`;o00000oooool2o`000003ooooool0003o000000Cooooo
0_l0000@ooooo`So000000?oooooo`000?l000000_l00003ooooo`;o00001Oooool3o`000003oooo
ool0003o000007Kooooo002Xooooo`;o00000_ooool2o`0000;ooooo0ol00002ooooo`;o00001_oo
ool2o`0000[ooooo0_l0000:ooooo`[o000000Coooooo`000?l0003ooooo1?l00009ooooo`;o0000
M_ooool00:cooooo0ol000000ooooooo0000o`000003o`0001Cooooo0_l00008ooooo`;o00002?oo
ool4o`0000;ooooo0_l00009ooooo`Co0000M_ooool00:Sooooo0_l000001?oooooo0000o`000?l0
0003ooooo`Co00002oooool2o`0000;ooooo0_l0000=ooooo`;o00002_ooool2o`0000_ooooo1?l0
001hooooo`00Z?ooool2o`000004ooooool0003o0000o`0000?ooooo0_l00006ooooo`;o00001Ooo
ool2o`0000;ooooo1?l0000Gooooo`;o000000?oooooo`000?l000000_l00005ooooo`Co0000NOoo
ool00:cooooo00?o0000ooooooooool02_ooool2o`0000Gooooo0ol00003ooooo`Co00005Oooool2
o`000003ooooool0003o000000;o000000?oooooo`000?l000000_ooool3o`0007[ooooo002Woooo
o`;o000000Coooooo`000?l0003o00000oooool4o`0000?ooooo0_l000000ooooooo0000o`000002
ooooo`Go00001Oooool2o`0001gooooo0_l00005ooooo`;o0000N?ooool00:Oooooo0_l000001?oo
oooo0000o`000?l00003ooooo`Co00000oooool2o`000003ooooool0003o000000;ooooo0ol0000J
ooooo`;o00004Oooool3o`0000Gooooo0_l0001`ooooo`00YOooool2o`0000Cooooo1?l0000Joooo
o`;o00004?ooool2o`0001;ooooo0_l00005ooooo`;o0000L?ooool00:Gooooo0_l00005ooooo`?o
00002oooool2o`0000gooooo0_l00009ooooo`Go00002_ooool2o`000003ooooool0003o000000Go
oooo0_l00002ooooo`?o0000M?ooool00:cooooo00Co0000oooooooooooooooo0_l00003ooooo`;o
00000oooool3o`0000;ooooo0_l0000Cooooo`Go00002_ooool2o`000003ooooool0003o000000Go
oooo0_l00002ooooo`?o00000_ooool2o`00073ooooo002Tooooo`;o00001Oooool4o`000003oooo
ool0003o000000?ooooo0_l00004ooooo`;o00000_ooool2o`000003ooooool0003o000000kooooo
0_l00002ooooo`;o00003?ooool2o`00013ooooo0_l0001`ooooo`00Y?ooool2o`0000Gooooo1?l0
000Cooooo`;o00003_ooool2o`0000;ooooo0ol0000;ooooo`;o00000_ooool2o`0000Kooooo0_l0
001fooooo`00[?ooool3o`000003ooooool0003o000000;ooooo0_l0000Qooooo`;o00003oooool2
o`0000Kooooo0_l0001fooooo`00[?ooool6o`0000;ooooo0_l00004ooooo`;o00001oooool2o`00
00Oooooo0_l00002ooooo`;o00002Oooool2o`0000Sooooo0_l00006ooooo`;o0000NOooool00:?o
oooo0_l00005ooooo`?o000000?oooooo`000?l000000_l00008ooooo`?o00001_ooool2o`000003
ooooool0003o000000;ooooo1?l00002ooooo`;o00001oooool4o`0000Sooooo0_l00006ooooo`;o
0000NOooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@03ooooo`?o00000oooool2o`0000?ooooo0_l00004oooo
o`;o00000oooool2o`000003ooooool0003o000000?o00000_ooool4o`0000_ooooo1?l0000Foooo
o`Co0000LOooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnH
V9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`06
ooooo`;o00002?ooool3o`000004ooooool0003o0000o`0001Cooooo0_l000000ooooooo0000o`00
0004ooooo`;o00001Oooool5o`0000Cooooo1Ol0001`ooooo`00POooool6o`0000;ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0;ooooo`;o00000oooool3o`0000Sooooo0_l00006ooooo`;o00001_oo
ool2o`000003ooooool0003o000000;ooooo1?l00005ooooo`Oo00001Oooool2o`00073ooooo0029
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP04ooooo`;o000000?o
ooooogMgMolb<S800_ooool2o`000004ooooool0003o0000o`0000_ooooo0_l00004ooooo`;o0000
0oooool2o`0000;ooooo0ol000000ooooooo0000o`000003ooooo`;o00003Oooool2o`0000cooooo
0_l00002ooooo`;o000000Coooooo`000?l0003o0000Koooool008Wooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo0ol000001?lb<S;oc<c<ooooooooool2o`00
0004ooooool0003o0000ooooo`;o00005?ooool2o`000005ooooool0003o0000o`000?ooool01?l0
000?ooooo`Co00003_ooool5o`000003ooooool0003o000006oooooo0029ooooo`05oa0@4?oooooo
ooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01?l0000<ooooo`;o00001oooool2o`0000;ooooo1?l000000ooooooo0000o`00
000<ooooo`;o00001?ooool5o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000000ooo
ool2o`0006gooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooo
oonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`;o0000
1?ooool2o`0000Kooooo0_l0000@ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0000Co
oooo0_l00004ooooo`Go00000oooool3o`0000?ooooo1?l00002ooooo`;o0000KOooool008Wooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`00
00Kooooo00?o0000ooooooooool02?ooool2o`0000cooooo0_l0000=ooooo`?o00000_ooool2o`00
00Kooooo0_l00002ooooo`?o000000Coooooo`000?l0003ooooo1?l00003ooooo`Co00000oooool3
o`0006_ooooo002/ooooo`03o`000?oooooooooo017ooooo1?l000001?oooooo0000o`000?ooool2
o`0001Oooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l00007ooooo`Co000000Co
ooooo`000?l0003o0000Joooool00:cooooo00?o0000ooooooooool04?ooool7o`0000;ooooo0_l0
0002ooooo`;o00001Oooool2o`0000_ooooo0_l00004ooooo`;o00003Oooool4o`0006oooooo002/
ooooo`03o`000?oooooooooo00cooooo0_l00002ooooo`;o00000oooool2o`0000Kooooo0_l00005
ooooo`;o00002oooool2o`0000?ooooo1Ol0001nooooo`00[?ooool5o`0000;ooooo0_l000000ooo
oooo0000o`000003ooooo`;o00005?ooool2o`0001;ooooo1Ol0000:ooooo`;o0000L_ooool00:co
oooo00?o0000ooooooooool00_l00002ooooo`;o000000?oooooo`000?l000001?l00008ooooo`;o
00002oooool2o`0000Gooooo0_l0000=ooooo`;o000000?oooooo`000?l000001_ooool4o`0007;o
oooo002/ooooo`03o`000?oooooooooo00Kooooo1ol00008ooooo`;o00000_ooool2o`0000_ooooo
0_l000000ooooooo0000o`000008ooooo`;o00001_ooool2o`000003ooooool0003o000000;o0000
00?oooooo`000?l000000_l0001booooo`00[?ooool00ol0003oooooooooo`06ooooo`;o00004Ooo
ool2o`0000_ooooo0_l0000;ooooo`?o00002?ooool4o`0000?ooooo0_l0001booooo`00[?ooool0
0ol0003oooooooooo`02o`0000gooooo0_l00002ooooo`;o00003_ooool4o`0000_ooooo1?l00000
0ooooooo0000o`000006ooooo`;o0000N?ooool00:cooooo00?o0000ooooooooool00_l0000;oooo
o`Co00000_ooool2o`0000Sooooo0_l00003ooooo`Go00002oooool2o`0000?ooooo0_l00020oooo
o`00[?ooool00ol0003oooooooooo`05ooooo`?o00000oooool4o`0000Cooooo0_l00004ooooo`;o
00000_ooool2o`0000?ooooo0ol0002Dooooo`00[?ooool00ol0003oooooooooo`05ooooo`?o0000
0oooool2o`0000cooooo1?l00006ooooo`;o00006oooool4o`0000Sooooo0_l0001[ooooo`00[?oo
ool3o`0000Gooooo0_l00003ooooo`;o00002?ooool2o`0000Gooooo0_l0000Eooooo`;o00003?oo
ool4o`0000Gooooo0_l000000ooooooo0000o`000003ooooo`;o0000I_ooool00:cooooo00?o0000
ooooooooool02_ooool2o`0000Sooooo0_l00003ooooo`;o00001Oooool2o`0000Kooooo0_l00000
1?oooooo0000o`000?l00004ooooo`Co00001oooool2o`0000[ooooo0_l00006ooooo`;o0000I_oo
ool00:cooooo00?o0000ooooooooool03oooool2o`0000Sooooo0_l00005ooooo`Go00000oooool2
o`000004ooooool0003o0000o`0000Kooooo0_l00007ooooo`;o00002?ooool4o`0000Sooooo0_l0
001Tooooo`00[?ooool00ol0003oooooooooo`0?ooooo`?o00003?ooool2o`0000;ooooo0ol0000M
ooooo`;o00000_ooool3o`0000[ooooo0_l0001Tooooo`00[?ooool00ol0003oooooooooo`0;oooo
o`;o00000oooool2o`0000cooooo0_l0000>ooooo`;o00001oooool2o`0000Wooooo0_l00002oooo
o`;o0000LOooool00:cooooo00?o0000ooooooooool01oooool2o`0000;ooooo0_l00005ooooo`;o
00004_ooool2o`0000Kooooo0_l00007ooooo`;o00003?ooool4o`00073ooooo002/ooooo`03o`00
0?oooooooooo00Oooooo0_l00007ooooo`Co00001?ooool2o`0000;ooooo0_l00008ooooo`;o0000
0_ooool2o`000004ooooool0003o0000ooooo`;o00001oooool2o`0000[ooooo1?l00004ooooo`;o
0000J_ooool00:cooooo00?o0000ooooooooool04?ooool2o`0000;ooooo0ol000000ooooooo0000
o`000002ooooo`;o00002oooool6o`000003ooooool0003o000000Oooooo0_l00002ooooo`;o0000
1Oooool2o`000003ooooool0003o000000Cooooo0_l0001Zooooo`00[?ooool00ol0003ooooooooo
o`06ooooo`;o00001oooool2o`0000;ooooo1?l00005ooooo`;o00002?ooool2o`000004ooooool0
003o0000ooooo`;o00003oooool2o`0000;ooooo1_l0001booooo`00[?ooool3o`0000Kooooo0_l0
0007ooooo`Ko00001oooool2o`0000Sooooo0_l000001?oooooo0000o`000?ooool2o`00017ooooo
1Ol000000ooooooo0000o`000002o`0000cooooo0_l0001Rooooo`00[?ooool00ol0003ooooooooo
o`07ooooo`;o00002?ooool4o`0000gooooo0_l00005ooooo`Co00004_ooool2o`0000Kooooo0_l0
0005ooooo`;o00001Oooool2o`0006;ooooo002/ooooo`03o`000?oooooooooo00Gooooo1_l00008
ooooo`;o00000oooool2o`0000Sooooo1?l00005ooooo`;o00008Oooool2o`0006Wooooo0009oooo
o`Co000000?o410@ooooooooool05_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46
ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000
oc8b<_oMgMd05_ooool00ol0003oooooooooo`05ooooo`;o00000_ooool2o`0000cooooo1?l00000
0olb<S;ok^k^ooooo`02o`0000;ooooo0_lQ8B42o`0000;ooooo1ol00002ooooo`05odA4A?l0003o
0000oc8b<_oMgMd03Oooool2o`000005onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1?l00000
0ol@413oooooooooo`0Booooo`002oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`0>
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01oooool00omgMgOo<S8booooo`0Eooooo`03o`000?oooooooooo00Gooooo0_l00002ooooo`;o
00002Oooool2o`000003ooooool0003o000000;o000000?oV9RHogMgMoooool00_l00002ooooo`;o
00001?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Co000000Goooooo`000?l0003oMgMgoc8b<P0=
ooooo`Co000000?ooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool06Oooool00ol0003oooooooooo`0Dooooo`001_l00005ooooo`03o`000?oooooo
oooo013ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEoooo
o`08ooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@4100
4?ooool00ol0003oooooooooo`05ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00co
oooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00[o
oooo0_l000000ooooooo0000o`000005ooooo`;o00000_ooool01Ol@413ooooooooooooooooo410@
00Gooooo0_l00005ooooo`04oiRHV?lQ8B7o0000o`0000;ooooo0_l000001Ooooooo0000o`000?oo
oooo000000oooooo0_l00002ooooo`03oa0@4?oooooooooo00kooooo00?o0000ooooooooool03Ooo
ool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go
0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool0
3_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003o
oooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`0Eoooo
o`03o`000?oooooooooo00[ooooo0_l000001?oooooo0000o`000?l00008ooooo`05o`000?oooooo
ooooooooool000001?ooool2o`0000Oooooo00?oV9RHo`000?l000000_l00002ooooo`;o000000?o
ooooogMgMolb<S801Oooool2o`0000Sooooo00Ko0000ooooooooooooooooo`000?ooool2o`0000co
oooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qoooo
ooooool01_ooool00omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo000;ooooo`03
o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003?oo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Fooooo`03o`000?oooooooooo
00kooooo0_l00008ooooo`05o`000?ooooooooooooooool000001?ooool2o`0000?ooooo0_l00003
ooooo`04ogMgMomVIVKo0000o`0000;ooooo0ol000000olb<S;oc<c<ooooo`03ooooo`?o00002?oo
ool01?l0003oooooooooooooool4o`0000;ooooo0_l00005ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`03oooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<01[ooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000oooo
ooooool06?ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool0
0ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`0Aooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01Sooooo0ol0000Eooooo`;o000000?ooooooa0@4?ooool00_ooool00ol@413ooooo
ooooo`04ooooo`;o000000?oooooo`000?l000000oooool2o`0000Cooooo00?o0000ooooooooool0
1_ooool2o`0000;ooooo0_l00005ooooo`04oa0@4?ooooooooooooooo`;o00001?ooool2o`0000Go
oooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Cooooo000;ooooo`03
o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooo
oooooolb<S801?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zj
oooooonHV9So410@00Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Booooo`;o
000000?oooooo`000?l000001?l000000onHV9SoMgMgooooo`04ooooo`?o00000oooool00ol0003o
^[Zjooooo`02o`0000Cooooo00?o0000ooooooooool01Oooool2o`0000?ooooo1?l00003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01oooool2o`0000?ooooo0ol0000Aooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Dooooo`002Oooool00omEEEGoIVIVo`00000Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0001Oooooo00?o0000ooooooooool04Oooool:o`000003oc8b<_o^k^kooooo
00Cooooo0_l00004ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Cooooo0_l00000
0ooooooo0000o`000002ooooo`;o00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo0_l0
0003ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co0000
6Oooool00omEEEGoIVIVo`00000Fooooo`00[?ooool00ol0003oooooooooo`0Aooooo`Ko00001?oo
ool2o`0001_ooooo0_l00002ooooo`;o00005_ooool2o`0006?ooooo002/ooooo`03o`000?oooooo
oooo01_ooooo1?l00007ooooo`;o00004?ooool2o`000003ooooool0003o000000Cooooo0_l0000A
ooooo`Go0000H?ooool00:cooooo00?o0000ooooooooool05Oooool2o`0000Kooooo0_l00007oooo
o`;o00002Oooool2o`0000Sooooo0_l00004ooooo`?o00004?ooool5o`0005Gooooo0_l00002oooo
o`;o00001Oooool00:cooooo00?o0000ooooooooool03?ooool2o`0000Oooooo0_l0000Booooo`;o
00001_ooool2o`0000Cooooo0_l00005ooooo`;o000000Coooooo`000?l0003o00004?ooool2o`00
05Sooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd5ooooo`00[?ooool00ol0003oooooooooo`0<
ooooo`;o00000_ooool3o`000003ooooool0003o0000013ooooo1Ol00002ooooo`;o00002?ooool2
o`0000Gooooo0_l000000ooooooo0000o`00000;ooooo`;o0000Goooool01?oMgMgo0000oa0@4?o<
c<`6ooooo`001oooooooo`0004co00003?ooool01?o^k^ko8B4Qoa0@4?o^k^h6ooooo`001oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`;o00001_ooool3o`0000;ooooo0_l000000ooooooo0000ooooo`07
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool4o`0000Cooooo0_l00007
ooooo`03o`000?oooooooooo00;o00000oooool00ol0003oooooooooo`03ooooo`Go00001Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool0
1?lQ8B7oMgMgogMgMolb<S86ooooo`001oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo01Oooooo0_l00002ooooo`;o00002?ooool3o`000003ooooool0003o000000_ooooo0_l00005
ooooo`Co00002_ooool2o`0000?ooooo00?o0000ooooooooool00oooool2o`00027ooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`09ooooo`;o00000_ooool2o`0000Gooooo002/oooo
o`03o`000?oooooooooo00oooooo0_l0000:ooooo`;o000000?oooooo`000?l000000oooool4o`00
00;ooooo0_l000000ooooooo0000o`000002o`0000Cooooo1?l00005ooooo`;o00005?ooool2o`00
06Cooooo002/ooooo`03o`000?oooooooooo00gooooo1?l0000:ooooo`;o000000?oooooo`000?l0
00000oooool2o`0000Oooooo1?l00004ooooo`;o000000?oooooo`000?l000006_ooool2o`0000Co
oooo0_l0001Nooooo`00[?ooool00ol0003oooooooooo`0=ooooo`;o00003oooool2o`0001Oooooo
1_l0000<ooooo`;o00003_ooool2o`0005kooooo002/ooooo`03o`000?oooooooooo01cooooo0_l0
0009ooooo`;o00000oooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`00
0003o`0000[ooooo1?l00002ooooo`;o00004?ooool2o`0005Sooooo002/ooooo`03o`000?oooooo
oooo01;ooooo0ol00005ooooo`Go00002?ooool2o`0000?ooooo0_l000000ooooooo0000o`000004
ooooo`;o00000oooool2o`0000[ooooo1Ol00002ooooo`;o00004?ooool2o`0005Sooooo002/oooo
o`?o00003_ooool2o`0000;ooooo0ol00005ooooo`;o000000?oooooo`000?l000009oooool2o`00
0003ooooool0003o000000Sooooo0_l0001Tooooo`00[?ooool00ol0003oooooooooo`0>ooooo`?o
00000_ooool4o`0001Kooooo0_l00004ooooo`;o00007_ooool2o`0000Gooooo0_l0001Mooooo`00
[?ooool00ol0003oooooooooo`0?ooooo`;o00001?ooool2o`0001Kooooo0_l00004ooooo`Go0000
4oooool2o`0000Oooooo0_l00004ooooo`;o00000oooool2o`0005Sooooo002/ooooo`03o`000?oo
oooooooo01Kooooo0_l00002ooooo`;o00001?ooool2o`0000Cooooo0_l00008ooooo`;o00000_oo
ool4o`0000Gooooo1_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00002ooooo`;o0000
0oooool2o`0000?ooooo0_l00004ooooo`;o0000F?ooool00:cooooo00?o0000ooooooooool04ooo
ool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo
0_l00008ooooo`;o00000_ooool2o`0000Oooooo1_l000001?oooooo0000o`000?ooool2o`0000Ko
oooo0_l00008ooooo`;o0000G_ooool00:cooooo00?o0000ooooooooool04oooool2o`0000_ooooo
0_l000001?oooooo0000o`000?ooool2o`0002Cooooo0_l0000Cooooo`;o0000E_ooool00:cooooo
00?o0000ooooooooool08?ooool4o`0000cooooo0ol00002ooooo`;o00001Oooool2o`0000Sooooo
0ol00003ooooo`;o00002?ooool4o`0000?ooooo0_l000001?oooooo0000o`000?l0001Fooooo`00
[?ooool00ol0003oooooooooo`0Mooooo`;o00000oooool2o`0000Gooooo0_l00005ooooo`Oo0000
1Oooool3o`0000;ooooo0_l00003ooooo`Co00001Oooool2o`0000Gooooo1?l00003ooooo`Go0000
Eoooool00:cooooo00?o0000ooooooooool04Oooool2o`0000Cooooo0_l00004ooooo`;o00000ooo
ool2o`0000Gooooo0_l00003ooooo`;o00000oooool2o`0000Gooooo0_l000000ooooooo0000o`00
0002ooooo`;o00000oooool4o`0000Gooooo0_l0000=ooooo`;o0000FOooool00:cooooo0ol0000A
ooooo`;o00001?ooool2o`0001Gooooo0_l0000:ooooo`;o0000OOooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool00ol0003oooooooooo`2iooooo`00ROooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0002iooooo`00ROooool0
1Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05o`000?ooooooooooooooool000003_oo
ool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`2iooooo`00ROooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`2iooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000
^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;Wooooo002Aooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`2iooooo`00TOooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`2iooooo`00TOooool01Ol0003ooooooooooooooooo000000oooooo
00?oMgMgoc8b<_ooool01?ooool3o`000;Wooooo002Aooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0^Oooool0097ooooo
00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0^Oooool0097ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0^Oooool0097ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co
00001_ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`00
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00
[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0^Oooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0^Oooool008Wooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmE
EEGooooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2iooooo`00ROooool0
1Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8boooo
o`04ooooo`?o0000^Oooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<
c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;Wooooo
0029ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0^Oooool008Wooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0;Wooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Co
oooo1?l00006ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:co
oooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o
0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:;ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0;Wo
oooo002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o
0000ooooooooool01Oooool3o`000;Wooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Toooo
o`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`00
0?oooooooooo0<7ooooo002Rooooo`03oeEEEOmVIVKo00000<?ooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo002Zooooo`04oa0@4?l0003o0000o`000;[ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`06o`000?mgMgOo0000o`000?mEEEGok^k^]oooool00:_ooooo00Ko0000oeEEEOo^k^koooooogMg
MomEEEFgooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo0;Gooooo002[
ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0]Oooool00:_ooooo00Ko0000oeEE
EOo^k^koooooogMgMomVIVJgooooo`00Z_ooool00ol@413o0000ogMgM`02o`000003ofIVI_o^k^ko
oooo0;Kooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.5713 .2271 Mdot
.54717 .1696 Mdot
.44516 .52701 Mdot
.49679 .26665 Mdot
.47721 .18306 Mdot
.54871 .20593 Mdot
.45064 .36494 Mdot
.57392 .10499 Mdot
.66768 .29205 Mdot
.48219 .22414 Mdot
.50136 .24032 Mdot
.63995 .2004 Mdot
.52006 .11323 Mdot
.44166 .25636 Mdot
.70098 .34658 Mdot
.47662 .23564 Mdot
.56418 .28011 Mdot
.51728 .10867 Mdot
.46987 .19711 Mdot
.53336 .10368 Mdot
.59118 .22491 Mdot
.59142 .24126 Mdot
.62982 .33459 Mdot
.54147 .14086 Mdot
.69976 .32136 Mdot
.45204 .17953 Mdot
.53877 .32478 Mdot
.51271 .24547 Mdot
.56459 .14467 Mdot
.58543 .2368 Mdot
.63573 .32771 Mdot
.64208 .23313 Mdot
.63455 .2028 Mdot
.59066 .34187 Mdot
.54473 .21821 Mdot
.63919 .30101 Mdot
.63497 .24685 Mdot
.53049 .29095 Mdot
.6362 .27207 Mdot
.60778 .14548 Mdot
.66161 .22739 Mdot
.56235 .25867 Mdot
.56588 .24968 Mdot
.51027 .12554 Mdot
.52133 .14688 Mdot
.46144 .17965 Mdot
.5166 .27867 Mdot
.61042 .18266 Mdot
.47223 .15427 Mdot
.61993 .24171 Mdot
.62542 .20975 Mdot
.60215 .19624 Mdot
.75381 .33236 Mdot
.5798 .28757 Mdot
.52793 .18268 Mdot
.65954 .26202 Mdot
.59659 .1358 Mdot
.53993 .22835 Mdot
.61999 .20713 Mdot
.51951 .14569 Mdot
.48841 .17955 Mdot
.68957 .25398 Mdot
.65294 .31555 Mdot
.44116 .31515 Mdot
.68913 .33319 Mdot
.63762 .22017 Mdot
.5012 .25051 Mdot
.51809 .30815 Mdot
.49461 .21575 Mdot
.56816 .1798 Mdot
.46566 .14035 Mdot
.43479 .44811 Mdot
.51625 .28228 Mdot
.48914 .23465 Mdot
.65331 .31673 Mdot
.44428 .44894 Mdot
.75418 .33353 Mdot
.55403 .30222 Mdot
.59299 .18302 Mdot
.57594 .34407 Mdot
.63838 .3183 Mdot
.59778 .26427 Mdot
.51377 .31071 Mdot
.54913 .23017 Mdot
.58752 .12843 Mdot
.42574 .34511 Mdot
.47475 .18196 Mdot
.5384 .27765 Mdot
.51003 .17817 Mdot
.52437 .32543 Mdot
.70704 .34515 Mdot
.73843 .33136 Mdot
.43169 .34872 Mdot
.48088 .17862 Mdot
.4452 .29728 Mdot
.72152 .28692 Mdot
.4448 .24922 Mdot
.66147 .28688 Mdot
.75316 .326 Mdot
.46427 .14509 Mdot
.58313 .24782 Mdot
.47895 .14647 Mdot
.66609 .25267 Mdot
.53027 .15245 Mdot
.59743 .22582 Mdot
.58962 .33537 Mdot
.50254 .15969 Mdot
.46036 .20016 Mdot
.43028 .35656 Mdot
.58664 .21156 Mdot
.44817 .24419 Mdot
.4657 .2491 Mdot
.64888 .24816 Mdot
.57487 .16851 Mdot
.77279 .34549 Mdot
.42987 .43857 Mdot
.51537 .21967 Mdot
.58497 .13069 Mdot
.60283 .15998 Mdot
.66686 .33224 Mdot
.53766 .138 Mdot
.67023 .22068 Mdot
.63565 .34201 Mdot
.54666 .11836 Mdot
.57676 .19385 Mdot
.51179 .29985 Mdot
.59397 .19836 Mdot
.7172 .28379 Mdot
.6186 .32869 Mdot
.47364 .28635 Mdot
.60577 .26871 Mdot
.59536 .27086 Mdot
.65812 .23071 Mdot
.51513 .15018 Mdot
.56247 .2387 Mdot
.55847 .13182 Mdot
.57571 .14485 Mdot
.58668 .18198 Mdot
.52174 .29649 Mdot
.65948 .24819 Mdot
.69313 .3178 Mdot
.72725 .34509 Mdot
.44028 .30281 Mdot
.47266 .19932 Mdot
.55924 .26838 Mdot
.54676 .12405 Mdot
.58677 .12968 Mdot
.77829 .34223 Mdot
.55106 .33482 Mdot
.53161 .26025 Mdot
.61933 .13833 Mdot
.46345 .15005 Mdot
.46753 .20653 Mdot
.52488 .11697 Mdot
.43392 .47033 Mdot
.59299 .29274 Mdot
.60959 .20307 Mdot
.63623 .26869 Mdot
.61282 .1734 Mdot
.64794 .27646 Mdot
.60176 .18857 Mdot
.45842 .16739 Mdot
.57243 .15024 Mdot
.58419 .10414 Mdot
.64624 .3297 Mdot
.59931 .33717 Mdot
.6074 .30825 Mdot
.59632 .14444 Mdot
.58781 .20518 Mdot
.50009 .22575 Mdot
.56499 .13179 Mdot
.64215 .2993 Mdot
.50323 .29321 Mdot
.52582 .28309 Mdot
.5208 .24298 Mdot
.53163 .27895 Mdot
.66456 .26327 Mdot
.72233 .29177 Mdot
.59715 .30502 Mdot
.46857 .29623 Mdot
.59934 .19984 Mdot
.55592 .12158 Mdot
.62435 .16805 Mdot
.45738 .24027 Mdot
.66112 .22484 Mdot
.4699 .28104 Mdot
.68032 .33186 Mdot
.72631 .31025 Mdot
.60576 .16859 Mdot
.59398 .11848 Mdot
.54861 .21357 Mdot
.66797 .22115 Mdot
.53928 .11373 Mdot
.45707 .28003 Mdot
.70493 .29568 Mdot
.58828 .12727 Mdot
.63381 .17084 Mdot
.66033 .23807 Mdot
.4935 .19036 Mdot
.72402 .27782 Mdot
.47799 .13374 Mdot
.47196 .29934 Mdot
.47117 .29888 Mdot
.43511 .43973 Mdot
.51983 .24308 Mdot
.73001 .28863 Mdot
.6049 .2974 Mdot
.48214 .27603 Mdot
.56109 .22656 Mdot
.43178 .33132 Mdot
.43343 .37007 Mdot
.47784 .21284 Mdot
.51989 .1172 Mdot
.54735 .28613 Mdot
.59078 .21038 Mdot
.49529 .24883 Mdot
.61095 .3173 Mdot
.55528 .3093 Mdot
.59605 .11989 Mdot
.43604 .35987 Mdot
.57495 .24333 Mdot
.59214 .12465 Mdot
.50735 .20574 Mdot
.65475 .27918 Mdot
.57746 .18854 Mdot
.6474 .34305 Mdot
.52668 .32816 Mdot
.49214 .19718 Mdot
.50573 .11086 Mdot
.47752 .25709 Mdot
.69968 .34097 Mdot
.6533 .18788 Mdot
.46658 .24071 Mdot
.44091 .43815 Mdot
.74738 .3419 Mdot
.5364 .23405 Mdot
.50992 .25335 Mdot
.679 .241 Mdot
.52324 .27519 Mdot
.52688 .14589 Mdot
.60751 .26433 Mdot
.59004 .26007 Mdot
.69783 .27337 Mdot
.52674 .17219 Mdot
.5731 .17573 Mdot
.46655 .14004 Mdot
.61572 .18383 Mdot
.4707 .26128 Mdot
.6458 .28048 Mdot
.58019 .3339 Mdot
.46379 .14175 Mdot
.64331 .28802 Mdot
.64505 .19095 Mdot
.43163 .41889 Mdot
.48736 .27487 Mdot
.65653 .30575 Mdot
.50412 .19185 Mdot
.53094 .29679 Mdot
.47863 .12015 Mdot
.44402 .44786 Mdot
.6226 .17754 Mdot
.61157 .18798 Mdot
.50004 .17226 Mdot
.50826 .24996 Mdot
.64499 .33131 Mdot
.45998 .29937 Mdot
.49777 .16388 Mdot
.58846 .26626 Mdot
.53364 .32187 Mdot
.59752 .31947 Mdot
.64524 .31385 Mdot
.53576 .24759 Mdot
.61264 .23631 Mdot
.5142 .15962 Mdot
.45628 .23362 Mdot
.54594 .25965 Mdot
.59761 .18274 Mdot
.44108 .27252 Mdot
.44565 .2167 Mdot
.63249 .22137 Mdot
.45109 .23209 Mdot
.57497 .2519 Mdot
.59095 .18328 Mdot
.42749 .44412 Mdot
.51831 .29698 Mdot
.655 .29469 Mdot
.65571 .23293 Mdot
.45287 .20851 Mdot
.43737 .4318 Mdot
.55811 .3474 Mdot
.54826 .13118 Mdot
.51563 .22602 Mdot
.64207 .33404 Mdot
.73066 .32412 Mdot
.64112 .25076 Mdot
.69146 .31982 Mdot
.6628 .30378 Mdot
.43677 .48413 Mdot
.59709 .17085 Mdot
.71739 .34009 Mdot
.53898 .12066 Mdot
.69928 .34269 Mdot
.78072 .33949 Mdot
.52365 .21667 Mdot
.47887 .11722 Mdot
.58299 .24254 Mdot
.62753 .20469 Mdot
.68153 .27273 Mdot
.50473 .25091 Mdot
.64507 .2476 Mdot
.49764 .18023 Mdot
.47009 .30379 Mdot
.54865 .15939 Mdot
.5584 .26482 Mdot
.55793 .1699 Mdot
.62475 .14815 Mdot
.43977 .36017 Mdot
.58176 .25561 Mdot
.58175 .30977 Mdot
.69023 .33288 Mdot
.43846 .36147 Mdot
.63516 .18528 Mdot
.70938 .32881 Mdot
.70748 .27777 Mdot
.50073 .26942 Mdot
.48911 .11607 Mdot
.53279 .19952 Mdot
.65433 .31481 Mdot
.45637 .19627 Mdot
.43809 .3818 Mdot
.44206 .41061 Mdot
.51234 .17632 Mdot
.58474 .11643 Mdot
.66718 .34103 Mdot
.43481 .33608 Mdot
.5497 .16326 Mdot
.45957 .29561 Mdot
.43681 .42107 Mdot
.51183 .11868 Mdot
.53628 .1855 Mdot
.59832 .33362 Mdot
.46497 .16258 Mdot
.52656 .25833 Mdot
.74137 .29998 Mdot
.53182 .24191 Mdot
.6142 .30894 Mdot
.4603 .27176 Mdot
.6545 .24568 Mdot
.54185 .33609 Mdot
.59388 .19538 Mdot
.62002 .31741 Mdot
.42718 .3713 Mdot
.5617 .33379 Mdot
.72389 .33359 Mdot
.62514 .17546 Mdot
.57251 .13361 Mdot
.63331 .28355 Mdot
.49832 .17475 Mdot
.51684 .17926 Mdot
.63381 .27898 Mdot
.51499 .19316 Mdot
.62993 .1836 Mdot
.68497 .22575 Mdot
.57233 .17372 Mdot
.66327 .24196 Mdot
.63844 .19013 Mdot
.62813 .1665 Mdot
.43771 .40726 Mdot
.53482 .23295 Mdot
.69761 .33186 Mdot
.60798 .1537 Mdot
.437 .41104 Mdot
.63299 .31053 Mdot
.56386 .31927 Mdot
.53802 .18479 Mdot
.58154 .24556 Mdot
.66474 .29283 Mdot
.5331 .15543 Mdot
.62661 .22633 Mdot
.66717 .34891 Mdot
.63179 .34338 Mdot
.55956 .11705 Mdot
.61381 .28969 Mdot
.69576 .31418 Mdot
.77082 .32915 Mdot
.6719 .3449 Mdot
.5728 .24436 Mdot
.44749 .36542 Mdot
.69806 .30153 Mdot
.48732 .14855 Mdot
.44208 .41184 Mdot
.6101 .14502 Mdot
.56966 .18182 Mdot
.43218 .43089 Mdot
.49585 .24281 Mdot
.48489 .17082 Mdot
.51503 .26299 Mdot
.60288 .16889 Mdot
.53223 .11862 Mdot
.71252 .31954 Mdot
.62417 .16709 Mdot
.56525 .27562 Mdot
.75272 .34188 Mdot
.54516 .2306 Mdot
.52306 .26006 Mdot
.49463 .20362 Mdot
.4392 .5076 Mdot
.59984 .13884 Mdot
.64217 .20494 Mdot
.53696 .31995 Mdot
.45512 .26991 Mdot
.43017 .28454 Mdot
.43265 .30665 Mdot
.63919 .17479 Mdot
.45587 .18838 Mdot
.63403 .29419 Mdot
.4713 .2507 Mdot
.47974 .20574 Mdot
.4517 .31342 Mdot
.47042 .18024 Mdot
.59061 .34443 Mdot
.47335 .20729 Mdot
.48114 .27433 Mdot
.64816 .18236 Mdot
.65489 .23887 Mdot
.44873 .54084 Mdot
.54183 .21152 Mdot
.50494 .16337 Mdot
.61183 .34424 Mdot
.56554 .32181 Mdot
.50904 .24487 Mdot
.68597 .26909 Mdot
.70842 .25045 Mdot
.55337 .18632 Mdot
.76776 .34234 Mdot
.49522 .10454 Mdot
.45778 .28236 Mdot
.68625 .3464 Mdot
.70103 .34194 Mdot
.5213 .28303 Mdot
.6292 .3477 Mdot
.74577 .31122 Mdot
.46301 .25898 Mdot
.43461 .41205 Mdot
.54173 .30239 Mdot
.63642 .30581 Mdot
.56397 .31005 Mdot
.7312 .30185 Mdot
.45679 .29246 Mdot
.58495 .30545 Mdot
.54008 .21464 Mdot
.43016 .36398 Mdot
.45722 .30719 Mdot
.45276 .24451 Mdot
.58072 .11411 Mdot
.43 .42798 Mdot
.57899 .16172 Mdot
.54167 .16327 Mdot
.55501 .20167 Mdot
.60047 .21142 Mdot
.6439 .34509 Mdot
.55551 .25598 Mdot
.69382 .23045 Mdot
.49189 .23608 Mdot
.58295 .11351 Mdot
.63398 .17235 Mdot
.54223 .34941 Mdot
.58589 .15327 Mdot
.55324 .28769 Mdot
.58422 .34 Mdot
.58823 .18602 Mdot
.57375 .22857 Mdot
.48447 .19906 Mdot
.55823 .3226 Mdot
.58051 .31048 Mdot
.65637 .18904 Mdot
.58756 .29696 Mdot
.44228 .51999 Mdot
.58533 .29756 Mdot
.5665 .31343 Mdot
.43232 .48133 Mdot
.52228 .32343 Mdot
.57385 .27385 Mdot
.53853 .19486 Mdot
.44484 .34392 Mdot
.5203 .22226 Mdot
.63901 .22245 Mdot
.45668 .19301 Mdot
.59145 .27549 Mdot
.44013 .24159 Mdot
.54612 .32793 Mdot
.43691 .40585 Mdot
.76404 .31806 Mdot
.44293 .36843 Mdot
.53019 .14421 Mdot
.67423 .33481 Mdot
.64067 .31128 Mdot
.49394 .21385 Mdot
.59166 .18882 Mdot
.63 .17933 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`?o0000^Oooool00:[ooooo0ol0000:ooooo`;o00003_ooool2o`0009oooooo002Zoooo
o`?o00002_ooool2o`0000_ooooo0_l000000ooooooo0000o`00002Oooooo`00[?ooool00ol0003o
ooooooooo`02ooooo`;o00004Oooool2o`000:;ooooo002/ooooo`?o00000_ooool3o`0000Gooooo
0_l0000<ooooo`;o0000Woooool00:Sooooo0_l00002ooooo`?o00000oooool2o`0000Gooooo0_l0
000;ooooo`Co0000W_ooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool00ol0003ok^k^ooooo`04ooooo`03odA4A?l0003o000000;o000000?oooooo`000?l000000_oo
ool00ol0003oooooooooo`02o`000003ooooool0003o000000Co00000oooool2o`0000;ooooo0_l0
0005ooooo`Co000000?oooooo`000?l00000Voooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`;o00001Oooool00ol0003ooooooooo
o`02o`000003ooooool0003o000000Ko000000Coooooo`000?l0003ooooo0ol0000:ooooo`;o0000
Voooool0087ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEE
ooooo`07ooooo`;o00001Oooool5o`0000Oooooo0_l000001?oooooo0000o`000?ooool2o`0000[o
oooo0ol0002Kooooo`00ROooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qoooooooo
ool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00;o00002_ooool2o`0000_o
oooo1?l0002Looooo`00ROooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?oo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool03?ooool2o`00
00;ooooo1?l00005ooooo`?o0000WOooool008Wooooo00Go410@oooooooooooooooooa0@400>oooo
o`03ojVYZOmgMgOooooo00?ooooo00Co0000ooooool0003o00001_ooool00ol0003oooooooooo`0<
ooooo`;o00000_ooool6o`0000?ooooo0_l0002Nooooo`00ROooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`04o`000?oooooo0000o`0000Kooooo
00?o0000ooooooooool02Oooool2o`0000Wooooo0_l00006ooooo`;o0000Voooool008Wooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00000_ooool6o`0000Kooooo00?o0000ooooooooool0
2Oooool3o`00013ooooo1?l00004ooooo`;o0000Toooool00:3ooooo0ol00009ooooo`03o`000?oo
oooooooo00[ooooo0_l0000Booooo`;o00001?ooool2o`0009?ooooo002Pooooo`;o00000oooool2
o`0000Gooooo00?o0000ooooooooool00oooool6o`0000Wooooo0_l00002ooooo`;o00001?ooool2
o`0000;ooooo0ol0002Fooooo`00Woooool3o`0000?ooooo1?l00003ooooo`03o`000?oooooooooo
00?ooooo1_l00009ooooo`;o00000_ooool2o`0000Cooooo0_l00002ooooo`?o00000oooool2o`00
097ooooo002Oooooo`;o00001_ooool2o`0000?ooooo0ol00002ooooo`;o00000oooool2o`0000_o
oooo0_l0000@ooooo`;o0000TOooool00:;ooooo0_l00008ooooo`03o`000?oooooooooo00;ooooo
0_l00003ooooo`;o00002oooool2o`0000?ooooo0_l00005ooooo`;o0000Uoooool00:;ooooo0_l0
0008ooooo`03o`000?oooooooooo00Oooooo0_l0000@ooooo`;o00001Oooool2o`0009Oooooo002/
ooooo`;o00000_ooool2o`0000[ooooo0_l00008ooooo`;o00001_ooool2o`0009Sooooo002Poooo
o`;o00002Oooool4o`000003ooooool0003o000000Oooooo0_l000000ooooooo0000o`000008oooo
o`;o00001_ooool2o`0009Sooooo002Nooooo`Co00002Oooool4o`0000[ooooo0_l000000ooooooo
0000o`00000Gooooo`?o0000T?ooool009kooooo0_l00007ooooo`;o00000oooool00ol0003ooooo
ooooo`0<ooooo`;o00000_ooool2o`0000?ooooo0_l00006ooooo`Co00001Oooool5o`0008kooooo
002Wooooo`;o00000oooool2o`0000Kooooo0_l00005ooooo`;o00000_ooool2o`0000;ooooo0ol0
0006ooooo`Co000000?oooooo`000?l000001Oooool2o`0008kooooo002[ooooo`Co000000?ooooo
o`000?l000000_ooool2o`0000gooooo0ol0000;ooooo`;o00000_ooool2o`000003ooooool0003o
000000;o0000S?ooool009cooooo0_l000001?oooooo0000o`000?ooool2o`000004ooooool0003o
0000ooooo`;o000000?oooooo`000?l000000_ooool4o`0000oooooo1?l0000>ooooo`Co00000_oo
ool2o`0008cooooo002Looooo`;o000000Coooooo`000?l0003ooooo1Ol000001?oooooo0000o`00
0?ooool2o`0000;ooooo1?l00002ooooo`;o00002oooool3o`0000?ooooo1_l00002ooooo`;o0000
0_ooool4o`0000Cooooo0_l0002:ooooo`00Xoooool3o`0000Kooooo00?o0000ooooooooool01_oo
ool2o`000003ooooool0003o000000?ooooo0_l00004ooooo`;o00000oooool6o`0000;ooooo1?l0
0002ooooo`Co00000_ooool2o`0008[ooooo002Mooooo`;o00003Oooool00ol0003oooooooooo`09
ooooo`;o00000oooool2o`0000Kooooo0_l00002ooooo`?o000000Coooooo`000?l0003ooooo1?l0
0002ooooo`Co00001?ooool3o`0008Oooooo002Mooooo`;o00002_ooool2o`000004ooooool0003o
0000o`0001Kooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l00007ooooo`Co0000
00Coooooo`000?l0003o0000Qoooool009gooooo0_l0000:ooooo`;o000000Coooooo`000?l0003o
00000_ooool2o`0000Gooooo0_l0000;ooooo`;o00001?ooool2o`0000cooooo1?l0002;ooooo`00
WOooool2o`0000?ooooo0_l00005ooooo`;o000000?oooooo`000?ooool00oooool2o`0000Gooooo
0_l0000;ooooo`;o00001?ooool4o`0009Wooooo002Mooooo`?o00000_ooool3o`000004ooooool0
003o0000ooooo`;o000000Coooooo`000?l0003o00001oooool2o`0001?ooooo1?l0000;ooooo`;o
0000S?ooool009kooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool3o`0000Wooooo
0_l00006ooooo`;o00003?ooool2o`0000;ooooo0_l00006ooooo`Co0000S?ooool00:7ooooo1_l0
0003ooooo`?o000000?oooooo`000?l000003?ooool4o`0000Wooooo0_l00005ooooo`;o000000Co
ooooo`000?l0003ooooo1_l0002<ooooo`00W?ooool2o`0000?ooooo1_l00005ooooo`04o`000?oo
oooo0000o`0000cooooo0_l0000;ooooo`?o00001oooool5o`0000;ooooo0_l0002<ooooo`00W?oo
ool2o`0000Kooooo0_l00006ooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo0000o`00
000:ooooo`Co000000?oooooo`000?l000001_ooool2o`00097ooooo002Jooooo`;o00002?ooool2
o`0000Cooooo0ol00006ooooo`;o00001?ooool2o`000003ooooool0003o000000[ooooo0_l00003
ooooo`;o0000VOooool009[ooooo0_l0000>ooooo`?o00001?ooool4o`0000Cooooo0ol0002/oooo
o`00[?ooool00ol0003oooooooooo`02ooooo`?o00001_ooool2o`0001_ooooo1?l00008ooooo`?o
0000P_ooool00:Kooooo0_l00004ooooo`?o00000oooool2o`0001Kooooo1?l00009ooooo`Co0000
1_ooool5o`0000?ooooo0_l0001mooooo`00Y_ooool2o`0000Cooooo0_l00003ooooo`;o00001_oo
ool2o`0000Gooooo0_l000001?oooooo0000o`000?l00004ooooo`Co00001oooool2o`0000[ooooo
0_l00006ooooo`;o0000OOooool00:cooooo00?o0000ooooooooool00_ooool2o`0000Kooooo1Ol0
0002ooooo`;o000000Coooooo`000?l0003o00003oooool2o`0000Wooooo0ol00009ooooo`;o0000
N_ooool009_ooooo1?l00009ooooo`;o00000_ooool00ol0003oooooooooo`08ooooo`Oo00007?oo
ool2o`0000?ooooo0ol0000:ooooo`;o0000N_ooool009_ooooo1?l00005ooooo`;o00000_ooool3
o`000003ooooool0003ooooo00Wooooo0ol0000>ooooo`;o00001oooool2o`0000Oooooo0_l00003
ooooo`;o0000Qoooool009gooooo0_l00002ooooo`;o000000?oooooo`000?l000000oooool2o`00
0003ooooool0003o000001;ooooo0_l00006ooooo`;o00001oooool2o`0000cooooo0ol00005oooo
o`;o0000Ooooool0097ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`;o000000?oooooob4Q
8OlQ8B400_l00002ooooo`Co000000?o<S8bomgMgOooool00_ooool4o`0000Cooooo0_l00002oooo
o`;o00002?ooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000Oooooo0_l0000:
ooooo`Co00001?ooool2o`0007oooooo002Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool6
o`0000Oooooo00?oMgMgoc8b<_ooool00_ooool3o`0000;ooooo1Ol00002ooooo`;o00003?ooool5
o`000003ooooool0003o000000Oooooo0_l00003ooooo`;o00001Oooool4o`0008Gooooo0029oooo
o`Ko00000_ooool01Ol@413ooooooooooooooooo410@00?ooooo1Ol00002ooooo`;o00001?ooool0
1?l0003oooooooooooooool3o`000003ooooool0003o000000;o00001Oooool2o`0000Sooooo0_l0
00000ooooooo0000o`000003o`0000oooooo0_l000000ooooooo0000o`000005o`0008Kooooo002A
ooooo`05o`000?ooooooooooooooool000000oooool2o`0000Gooooo1?l000000oooooooMgMgoc8b
<P03ooooo`Ko00001oooool2o`0000Sooooo0_l000001?oooooo0000o`000?ooool2o`00017ooooo
1Ol000000ooooooo0000o`000002o`0000cooooo0_l0001fooooo`00TOooool01Ol0003ooooooooo
oooooooo000000cooooo0ol000000olb<S;oc<c<ooooo`04ooooo`Go00003Oooool2o`0000Cooooo
0_l000000ooooooo0000o`00000Aooooo`;o00001_ooool2o`0000Kooooo0_l00004ooooo`;o0000
M_ooool0097ooooo00Go410@oooooooooooooooooa0@4002ooooo`;o00001Oooool2o`000003oooo
ool0003ooooo00;o00001_ooool00ol0003oooooooooo`02o`0000?ooooo0_l00008ooooo`Co0000
1Oooool2o`00027ooooo0_l0001looooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo
0_l00005ooooo`;o000000?oooooo`000?l000000_l00006ooooo`03o`000?oooooooooo00Cooooo
1Ol00003ooooo`;o00000oooool2o`0000Oooooo0_l0000Eooooo`;o0000Q_ooool0097ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`02ooooo`Co0000
00?oooooo`000?l000000oooool2o`0000;ooooo0_l00008ooooo`;o000000Coooooo`000?l0003o
oooo0_l0000?ooooo`Co0000Q?ooool00:_ooooo0_l00004ooooo`;o00003?ooool2o`0000Sooooo
0_l000001?oooooo0000o`000?ooool2o`00017ooooo0_l00024ooooo`00WOooool2o`0000cooooo
0ol0000Aooooo`;o00002?ooool4o`000003ooooool0003o000000Wooooo0_l0000>ooooo`;o0000
OOooool009Sooooo0_l00003ooooo`?o00001Oooool2o`0000Gooooo0_l0000Aooooo`;o00000ooo
ool2o`0000Gooooo0_l000000ooooooo0000o`000009ooooo`;o00003?ooool4o`0000;ooooo0_l0
001iooooo`00V?ooool2o`0000Cooooo0_l00005ooooo`Co00000oooool3o`0000Cooooo0_l0000<
ooooo`;o000000?oooooo`000?l000001?ooool2o`0000gooooo0_l000000ooooooo0000o`000009
ooooo`;o00001?ooool2o`0007Wooooo002Mooooo`;o00001oooool3o`0000?ooooo00?o0000oooo
ooooool00_ooool4o`000003ooooool0003o000000;o00001oooool2o`0000Oooooo0_l0000<oooo
o`;o00000_ooool2o`000003ooooool0003o000000oooooo0_l00004ooooo`;o0000L?ooool009go
oooo0ol00002ooooo`;o00002?ooool00ol0003oooooooooo`02ooooo`Wo00001oooool2o`0001Go
oooo0_l00002ooooo`;o000000?oooooo`000?l000003oooool2o`0000Cooooo0_l0001`ooooo`00
UOooool2o`0000Oooooo0_l00002ooooo`?o00001oooool00ol0003oooooooooo`02ooooo`Go0000
1Oooool2o`0001_ooooo0_l00002ooooo`;o00005Oooool2o`0007?ooooo002Eooooo`;o00003?oo
ool2o`0000Oooooo00?o0000ooooooooool03?ooool4o`0000Oooooo0_l0000@ooooo`;o000000?o
ooooo`000?l000001?ooool2o`00013ooooo1_l0001_ooooo`00WOooool2o`0000gooooo00?o0000
ooooooooool01oooool2o`0000Gooooo0_l00007ooooo`;o00002Oooool2o`0000Sooooo0_l00004
ooooo`Co00004?ooool4o`0006oooooo002Mooooo`;o00003Oooool3o`0000Oooooo0_l0000Boooo
o`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o000000Coooooo`000?l0003o00004?ooool2
o`00077ooooo002Iooooo`;o00000oooool2o`000003ooooool0003o000000Wooooo0ol00003oooo
o`?o000000?oooooo`000?l000004?ooool4o`0000;ooooo0_l00008ooooo`;o00001Oooool2o`00
0003ooooool0003o000000_ooooo0_l0001gooooo`00VOooool2o`0000?ooooo0_l000001?oooooo
0000o`000?l00008ooooo`Go000000Goooooo`000?l0003o0000ooooo`02o`00013ooooo0_l00004
ooooo`;o00002_ooool2o`00017ooooo1?l0000:ooooo`;o0000Joooool009Sooooo0_l00004oooo
o`;o00000_ooool2o`0000Sooooo00?o0000ooooooooool00_l00008ooooo`;o00000_ooool2o`00
01_ooooo0_l00005ooooo`;o00002_ooool2o`0000Wooooo0_l000000ooooooo0000o`00001[oooo
o`00UOooool2o`000003ooooool0003o000000?ooooo0_l00003ooooo`;o00002?ooool00ol0003o
ooooooooo`0:ooooo`;o00000_ooool2o`0000Wooooo0_l00002ooooo`;o00002oooool2o`0000Co
oooo1?l0000Eooooo`;o0000K_ooool009Gooooo0_l00006ooooo`;o00003Oooool00ol0003ooooo
ooooo`03ooooo`;o00002_ooool2o`000003ooooool0003o000000?ooooo1?l00002ooooo`;o0000
00?oooooo`000?l000000_l00004ooooo`Co00001?ooool2o`0001Gooooo0_l0001`ooooo`00W?oo
ool2o`0000kooooo00Co0000oooooooooooooooo1?l0000:ooooo`;o000000Coooooo`000?l0003o
00000_ooool3o`0000Kooooo1?l00004ooooo`;o000000?oooooo`000?l000006_ooool2o`0000Go
oooo0_l0001Yooooo`00V?ooool2o`0000;ooooo0_l0000>ooooo`04o`000?ooooooooooooooo`;o
00004?ooool2o`0001Kooooo1ol0000;ooooo`;o00003oooool2o`0006Wooooo002Hooooo`;o0000
4_ooool00ol0003oooooooooo`0Booooo`;o00002Oooool2o`0000;ooooo0_l000000ooooooo0000
o`000004ooooo`;o000000?oooooo`000?l000000ol0000:ooooo`?o00001?ooool2o`0000oooooo
0_l0001Sooooo`00[?ooool00ol0003oooooooooo`08ooooo`?o00001Oooool4o`0000Wooooo0_l0
0002ooooo`;o000000?oooooo`000?l000001?ooool2o`00013ooooo0_l000000ooooooo0000o`00
0002ooooo`;o00003oooool2o`0006?ooooo002/ooooo`?o00001?ooool3o`000004ooooool0003o
0000o`0000Gooooo1?l0000Xooooo`;o000000?oooooo`000?l000002?ooool2o`0006kooooo002/
ooooo`03o`000?oooooooooo00Cooooo0ol00002ooooo`;o000000?oooooo`000?l000005_ooool2
o`0000?ooooo0_l0000Gooooo`;o00001Oooool2o`0000Gooooo0_l0001Wooooo`00UOooool2o`00
01Gooooo00?o0000ooooooooool01Oooool2o`0000Gooooo0_l0000Fooooo`;o00000oooool2o`00
0004ooooool0003o0000o`0000Wooooo0_l00004ooooo`;o00000_ooool2o`0000Oooooo0_l00003
ooooo`;o00001?ooool2o`00067ooooo002Eooooo`;o00005Oooool00ol0003oooooooooo`0=oooo
o`;o00000_ooool2o`0000Cooooo0_l00004ooooo`;o00002?ooool2o`0000;ooooo1?l00005oooo
o`Ko000000Coooooo`000?l0003ooooo0_l00006ooooo`;o00000oooool2o`0000?ooooo0_l00004
ooooo`;o0000HOooool009Kooooo0_l0000Dooooo`03o`000?oooooooooo00[ooooo0_l000000ooo
oooo0000o`000002ooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`;o00002?ooool2
o`0000;ooooo0_l00007ooooo`Co00000oooool2o`0000Wooooo0_l00008ooooo`;o0000Ioooool0
09Kooooo0_l0000Dooooo`03o`000?oooooooooo00[ooooo0_l0000<ooooo`Co000000?oooooo`00
0?l000007oooool2o`0000Cooooo0_l0000Cooooo`;o0000G_ooool009Wooooo0_l0000Aooooo`03
o`000?oooooooooo01Sooooo1?l0000<ooooo`?o00000_ooool2o`0000Gooooo0_l00008ooooo`?o
00000oooool2o`0000Sooooo1?l00003ooooo`;o000000Coooooo`000?l0003o0000G_ooool009?o
oooo0_l00004ooooo`;o00004Oooool00ol0003oooooooooo`0Fooooo`;o00000_ooool2o`0000Go
oooo0_l00005ooooo`?o000000Coooooo`000?l0003o00001Oooool3o`0000?ooooo0_l00002oooo
o`Go00001Oooool2o`0000Cooooo1?l00003ooooo`Go0000Goooool009?ooooo1?l0000Eooooo`03
o`000?oooooooooo00_ooooo0_l00003ooooo`;o00001?ooool2o`0000;ooooo0_l00005ooooo`;o
00001?ooool2o`0000?ooooo0_l00006ooooo`?o00000oooool2o`0000?ooooo1?l00005ooooo`;o
00003Oooool2o`00063ooooo002Eooooo`;o00005Oooool3o`0000_ooooo0_l00003ooooo`;o0000
5Oooool2o`0000_ooooo0_l00023ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00UOooool2
o`0001Gooooo00?o0000ooooooooool0^Oooool009Gooooo1Ol0000Booooo`03o`000?oooooooooo
0;Wooooo002Eooooo`Go000000?oooooo`000?l000003oooool00ol0003oooooooooo`2iooooo`00
ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B42o`0000;ooooo1Ol00004ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2iooooo`00ROooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B401?oooooo0000o`000?ooool3o`000003oooooom4A4Co
oooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2iooooo`00POooool6o`00
00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`Co000000Goooooo`000?l0003o8B4Qonk^
kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0^Oooool008Wooooo00Go0000
ooooooooooooooooo`000006ooooo`;o00001Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol0002iooooo`00ROooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
^Oooool008Wooooo00Go410@oooooooooooooooooa0@4009ooooo`;o00001?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0^Oooool008Wooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`09ooooo`?o000000Co^[ZjoooooonHV9So410@1?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo0;Wooooo002Gooooo`?o0000
4_ooool00ol0003oooooooooo`2iooooo`00U_ooool4o`0001;ooooo00?o0000ooooooooool0^Ooo
ool009Kooooo1?l0000Booooo`03o`000?oooooooooo0;Wooooo002Eooooo`;o00005Oooool00ol0
003oooooooooo`2iooooo`00UOooool4o`0001?ooooo00?o0000ooooooooool0^Oooool009Oooooo
0_l0000Cooooo`?o0000^Oooool009Cooooo0_l0000Fooooo`03o`000?oooooooooo0;Wooooo002D
ooooo`Go00004oooool00ol0003oooooooooo`2iooooo`00UOooool4o`0001?ooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool009Cooooo1_l0000Booooo`03o`00
0?oooooooooo0;Wooooo002Dooooo`Ko00004_ooool00ol0003oooooooooo`2iooooo`00U?ooool2
o`0001Kooooo00?o0000ooooooooool0^Oooool009Cooooo1?l000000ooooooo0000o`00000Aoooo
o`03o`000?oooooooooo0;Wooooo002Fooooo`;o000000?oooooo`000?l000004Oooool3o`000;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo0009
ooooo`Co000000?o410@ooooooooool05_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0?oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o
0000oc8b<_oMgMd05_ooool00ol0003oooooooooo`0Hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@0Hooooo`Co000000?o410@ooooooooool04_ooool000_ooooo00?o
0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEE
EOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool05Oooool0
0ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`0Ioooo
o`03o`000?oooooooooo01Cooooo0006o`0000Gooooo00?o0000ooooooooool04?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000oooo
ooooool01Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^
kP09ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool06?ooool01Ol@413ooooooooo
oooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`0=ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0=ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo0000
00kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`0>ooooo`05o`000?oooooooooo
ooooool000003oooool00omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003Ooo
ool00onHV9So8B4Qonk^kP07ooooo`04ogMgMolb<S;o0000o`0001Cooooo00?o0000ooooooooool0
6?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo
<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0>oooo
o`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;o
oooo01Wooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol0
003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`03oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00;o00005?ooool00ol0003oooooooooo`0Hooooo`05o`000?oooooo
ooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
3oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?oooo
o`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`06_ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0H
ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oo
oooooooo017ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo017ooooo
00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool06?ooool3o`0001Sooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000
ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00ooo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooo
oooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S80
1?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003o
ooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@00Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool0
4Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool05?ooool000Wooooo00?oEEEEofIVI_l000006_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@
o`000?lQ8B7oc<c<00Cooooo1_l0000Eooooo`03o`000?oooooooooo01Sooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`00013ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
1Ol00004ooooo`Co00006Oooool00omEEEGoIVIVo`00000Fooooo`00UOooool4o`0001?ooooo00?o
0000ooooooooool0^Oooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo0:kooooo0_l00002ooooo`;o00001Oooool00:cooooo00?o0000oooooooo
ool0[_ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Gooooo002/ooooo`03o`000?oooooooooo
0:oooooo00CogMgMo`000?l@413oc<c<1_ooool000Ooooooool0001<o`0000cooooo00Cok^k^ob4Q
8Ol@413ok^k^1_ooool000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:oooo
o`04ob4Q8OmgMgOoMgMgoc8b<PKooooo0007ooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`09ooooo`;o00000_ooool2o`0000Gooooo002Gooooo`;o
00004oooool00ol0003oooooooooo`2iooooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
09Wooooo0_l0000Aooooo`03o`000?oooooooooo0;Wooooo002Iooooo`;o00004Oooool3o`000;Wo
oooo002Iooooo`;o00004Oooool00ol0003oooooooooo`2iooooo`00VOooool2o`00017ooooo00?o
0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool009_ooooo0_l0000?ooooo`03o`000?oooooooooo0;Wooooo002Kooooo`;o0000
3oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Ooo
ool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o
0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00ROooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0^Oooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`2iooooo`00ROooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RH
ob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000^Oooool008Wooooo00Go0000oooo
ooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`2iooooo`00ROooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMg
ofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0^Ooo
ool008Wooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2iooooo`00ROooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0^Oooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o
0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2iooooo`00TOooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0^Ooo
ool0097ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0^Oooool0097ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol0002iooooo`00TOooool01Ol0003ooooooooooooooooo000000cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;Wooooo002Aooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Wooooo
002Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0;Wooooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00
[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o
0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo0;Wooooo0029ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0^Oooool008Wooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3
o`000;Wooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2iooooo`00ROooool0
1Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`2iooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co0000
1_ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o
0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002Rooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`2iooooo`00Y?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`03o`000?oooooo
oooo00Gooooo0ol0002iooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003o
ooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003ooooooooo
o`31ooooo`00X_ooool00omEEEGoIVIVo`000033ooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00Z_ooool01?l@413o0000o`000?l0002jooooo`00Zoooool0
0ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool01_l0003o
MgMgo`000?l0003oEEEEonk^k[Oooooo002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoEEEE]ooo
ool00:_ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`2eooooo`00Zoooool00ol0
003ok^k^ooooo`02ooooo`03o`000?oooooooooo0;Gooooo002[ooooo`06o`000?mEEEGok^k^oooo
oomgMgOoIVIV]oooool00:[ooooo00?o410@o`000?mgMgL00_l000000omVIVKok^k^ooooo`2foooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.43004 .15672 Mdot
.40124 .25499 Mdot
.48735 .62442 Mdot
.41934 .45532 Mdot
.40533 .55893 Mdot
.41128 .24216 Mdot
.45078 .63556 Mdot
.39573 .15829 Mdot
.54449 .09205 Mdot
.41322 .52828 Mdot
.41262 .44105 Mdot
.48022 .0084 Mdot
.38307 .38549 Mdot
.42902 .69827 Mdot
.59962 .14658 Mdot
.41694 .55013 Mdot
.44179 .1791 Mdot
.38207 .39894 Mdot
.40999 .58795 Mdot
.38187 .32831 Mdot
.44444 .09916 Mdot
.45036 .10159 Mdot
.52365 .13459 Mdot
.39233 .28493 Mdot
.5883 .12136 Mdot
.41001 .66959 Mdot
.43899 .26328 Mdot
.41263 .38952 Mdot
.40203 .18878 Mdot
.44382 .1156 Mdot
.52681 .12771 Mdot
.49533 .0336 Mdot
.47587 .01486 Mdot
.48746 .14637 Mdot
.41287 .25622 Mdot
.51959 .10101 Mdot
.49372 .04773 Mdot
.42629 .30192 Mdot
.50503 .07207 Mdot
.43073 .04529 Mdot
.51257 .02739 Mdot
.43376 .18523 Mdot
.43337 .17385 Mdot
.38623 .42654 Mdot
.39066 .37246 Mdot
.408 .62853 Mdot
.4203 .36491 Mdot
.4459 .04537 Mdot
.40012 .58687 Mdot
.47683 .05382 Mdot
.46975 .02924 Mdot
.44362 .06731 Mdot
.64675 .13236 Mdot
.45682 .13832 Mdot
.3995 .33536 Mdot
.52434 .06202 Mdot
.41899 .07693 Mdot
.41366 .27424 Mdot
.46359 .03561 Mdot
.39034 .38089 Mdot
.40214 .51076 Mdot
.55117 .05398 Mdot
.53916 .11555 Mdot
.44197 .68773 Mdot
.5824 .13319 Mdot
.48573 .02448 Mdot
.41488 .43958 Mdot
.42731 .35197 Mdot
.4087 .47588 Mdot
.41384 .1708 Mdot
.39851 .61861 Mdot
.47237 .68679 Mdot
.4211 .3657 Mdot
.41401 .49567 Mdot
.54 .11673 Mdot
.4705 .64517 Mdot
.6476 .13353 Mdot
.44163 .21124 Mdot
.43168 .0896 Mdot
.47409 .16423 Mdot
.5257 .1183 Mdot
.46441 .09552 Mdot
.42738 .37058 Mdot
.41797 .23656 Mdot
.41046 .10658 Mdot
.45184 .74859 Mdot
.40562 .56988 Mdot
.42589 .27173 Mdot
.39784 .41616 Mdot
.43296 .32111 Mdot
.6051 .14515 Mdot
.63097 .13136 Mdot
.45134 .72183 Mdot
.40357 .54386 Mdot
.43719 .67396 Mdot
.59629 .08692 Mdot
.42679 .68611 Mdot
.53622 .08688 Mdot
.64356 .126 Mdot
.39984 .62363 Mdot
.44572 .12307 Mdot
.39697 .55922 Mdot
.52716 .05267 Mdot
.39279 .33149 Mdot
.45005 .08449 Mdot
.48388 .14272 Mdot
.39479 .45336 Mdot
.41271 .62881 Mdot
.45336 .72627 Mdot
.43626 .10972 Mdot
.42496 .67249 Mdot
.42224 .59488 Mdot
.50815 .04816 Mdot
.41452 .14773 Mdot
.67099 .14549 Mdot
.47135 .71034 Mdot
.40687 .38327 Mdot
.40951 .11519 Mdot
.43168 .06022 Mdot
.55976 .13224 Mdot
.39073 .30208 Mdot
.5185 .02068 Mdot
.53245 .14201 Mdot
.38822 .26716 Mdot
.42342 .13976 Mdot
.42481 .38176 Mdot
.43761 .08831 Mdot
.59071 .08379 Mdot
.51008 .12869 Mdot
.42865 .55217 Mdot
.47362 .0856 Mdot
.46463 .10224 Mdot
.5104 .03071 Mdot
.39136 .39947 Mdot
.42778 .18592 Mdot
.39581 .21523 Mdot
.40806 .14685 Mdot
.42661 .10822 Mdot
.42523 .3384 Mdot
.51875 .04819 Mdot
.58025 .1178 Mdot
.62529 .14509 Mdot
.43946 .69427 Mdot
.40986 .57526 Mdot
.43469 .19522 Mdot
.38966 .2656 Mdot
.41035 .10907 Mdot
.67518 .14223 Mdot
.44983 .22039 Mdot
.41894 .30315 Mdot
.43782 .01526 Mdot
.4011 .62613 Mdot
.41255 .59612 Mdot
.38407 .36312 Mdot
.47741 .68579 Mdot
.47066 .1152 Mdot
.45254 .0526 Mdot
.5037 .06869 Mdot
.44467 .03783 Mdot
.51852 .07646 Mdot
.44061 .06688 Mdot
.40597 .64433 Mdot
.40774 .15827 Mdot
.40115 .12011 Mdot
.53812 .1297 Mdot
.49418 .13812 Mdot
.49072 .11048 Mdot
.42156 .07794 Mdot
.43505 .10591 Mdot
.4097 .4498 Mdot
.3987 .18914 Mdot
.52187 .0993 Mdot
.42386 .42139 Mdot
.42295 .3234 Mdot
.41254 .35398 Mdot
.42364 .29941 Mdot
.52987 .06327 Mdot
.59904 .09177 Mdot
.47936 .11622 Mdot
.43191 .57217 Mdot
.44251 .07476 Mdot
.39212 .2275 Mdot
.45299 .01282 Mdot
.42211 .63311 Mdot
.51105 .02484 Mdot
.4283 .56964 Mdot
.57307 .13186 Mdot
.61041 .11025 Mdot
.43701 .05365 Mdot
.4117 .0854 Mdot
.41327 .24126 Mdot
.51643 .02115 Mdot
.38527 .3001 Mdot
.43086 .62586 Mdot
.5832 .09568 Mdot
.4106 .10407 Mdot
.51556 .03807 Mdot
.4034 .48624 Mdot
.59515 .07782 Mdot
.39439 .56618 Mdot
.43185 .55671 Mdot
.43192 .56022 Mdot
.47047 .68723 Mdot
.41245 .35826 Mdot
.60546 .08863 Mdot
.48395 .10397 Mdot
.42456 .51729 Mdot
.42334 .1918 Mdot
.44753 .7252 Mdot
.45563 .70963 Mdot
.41169 .54973 Mdot
.38395 .3854 Mdot
.43269 .23583 Mdot
.43913 .09822 Mdot
.41578 .46574 Mdot
.49787 .11742 Mdot
.44472 .20708 Mdot
.41356 .07866 Mdot
.45284 .70042 Mdot
.43783 .14546 Mdot
.41236 .09128 Mdot
.40416 .42211 Mdot
.52643 .07918 Mdot
.42224 .13764 Mdot
.54462 .14305 Mdot
.43442 .31085 Mdot
.40518 .4907 Mdot
.38358 .44986 Mdot
.42143 .54157 Mdot
.59607 .14097 Mdot
.42021 .59284 Mdot
.46887 .66223 Mdot
.64414 .1419 Mdot
.4139 .28797 Mdot
.41446 .40028 Mdot
.5354 .041 Mdot
.42046 .33631 Mdot
.39084 .34794 Mdot
.4736 .08106 Mdot
.45588 .10911 Mdot
.56717 .07337 Mdot
.39689 .34287 Mdot
.41558 .15339 Mdot
.39825 .61477 Mdot
.451 .03453 Mdot
.42381 .57043 Mdot
.51799 .08048 Mdot
.47423 .15321 Mdot
.39922 .62647 Mdot
.51851 .08802 Mdot
.46667 .7069 Mdot
.42318 .49472 Mdot
.53883 .10575 Mdot
.40155 .43941 Mdot
.42793 .29894 Mdot
.39129 .56632 Mdot
.47032 .64656 Mdot
.45491 .01937 Mdot
.44882 .04425 Mdot
.39803 .46157 Mdot
.41381 .40843 Mdot
.53751 .13131 Mdot
.43445 .60898 Mdot
.39669 .47331 Mdot
.45673 .1141 Mdot
.43562 .28353 Mdot
.48539 .12523 Mdot
.53078 .11385 Mdot
.4171 .28803 Mdot
.46774 .05998 Mdot
.39349 .40159 Mdot
.4209 .63934 Mdot
.42451 .24464 Mdot
.43522 .07678 Mdot
.43268 .69731 Mdot
.4195 .68945 Mdot
.48114 .02898 Mdot
.42169 .66235 Mdot
.44065 .14586 Mdot
.43021 .09547 Mdot
.47308 .71954 Mdot
.42474 .35337 Mdot
.53288 .09469 Mdot
.50888 .03293 Mdot
.41615 .65969 Mdot
.46825 .67906 Mdot
.45949 .20153 Mdot
.3919 .25778 Mdot
.40831 .38071 Mdot
.53569 .13404 Mdot
.62031 .12412 Mdot
.50142 .05076 Mdot
.57939 .11982 Mdot
.54432 .10378 Mdot
.47981 .67037 Mdot
.43081 .07706 Mdot
.61343 .14009 Mdot
.38687 .29992 Mdot
.59635 .14269 Mdot
.67651 .13949 Mdot
.4068 .34699 Mdot
.3906 .56592 Mdot
.4438 .12276 Mdot
.46981 .02387 Mdot
.55062 .07273 Mdot
.41438 .42392 Mdot
.50411 .0476 Mdot
.40029 .47033 Mdot
.43323 .56389 Mdot
.39916 .25073 Mdot
.43306 .19828 Mdot
.40574 .2111 Mdot
.44605 .00574 Mdot
.45209 .68406 Mdot
.44727 .12769 Mdot
.46662 .14079 Mdot
.58338 .13288 Mdot
.45266 .68952 Mdot
.46965 .00388 Mdot
.60091 .12881 Mdot
.57859 .07777 Mdot
.4191 .43754 Mdot
.38813 .52145 Mdot
.40441 .31044 Mdot
.54025 .11481 Mdot
.41272 .64705 Mdot
.45718 .68672 Mdot
.46261 .66317 Mdot
.39728 .40626 Mdot
.4051 .11706 Mdot
.56359 .14103 Mdot
.44791 .71094 Mdot
.40053 .24567 Mdot
.43372 .61158 Mdot
.46603 .68383 Mdot
.38458 .42107 Mdot
.40187 .2982 Mdot
.49178 .13549 Mdot
.40351 .6168 Mdot
.41714 .32533 Mdot
.62137 .09998 Mdot
.41447 .30592 Mdot
.49777 .10907 Mdot
.42835 .61356 Mdot
.51277 .04568 Mdot
.44405 .25089 Mdot
.43653 .0882 Mdot
.50698 .11741 Mdot
.45725 .73662 Mdot
.45774 .19038 Mdot
.61732 .13359 Mdot
.45646 .01411 Mdot
.40303 .15991 Mdot
.50673 .08355 Mdot
.39895 .46857 Mdot
.39783 .38549 Mdot
.50541 .07898 Mdot
.40094 .39073 Mdot
.46401 .00998 Mdot
.53527 .02575 Mdot
.41452 .15631 Mdot
.52005 .04196 Mdot
.47471 .00305 Mdot
.45588 .00548 Mdot
.46282 .68286 Mdot
.41313 .29489 Mdot
.59035 .13186 Mdot
.43369 .04582 Mdot
.4638 .68515 Mdot
.5172 .11053 Mdot
.45452 .18276 Mdot
.40215 .29087 Mdot
.44366 .12699 Mdot
.54188 .09283 Mdot
.39396 .3184 Mdot
.47733 .03751 Mdot
.56673 .14891 Mdot
.52914 .14338 Mdot
.39237 .21337 Mdot
.4897 .0923 Mdot
.58143 .11418 Mdot
.66248 .12915 Mdot
.56986 .1449 Mdot
.43657 .15198 Mdot
.45157 .64924 Mdot
.57867 .10153 Mdot
.39561 .52224 Mdot
.46288 .66279 Mdot
.43244 .03915 Mdot
.41531 .16515 Mdot
.46918 .70191 Mdot
.41434 .46458 Mdot
.401 .52805 Mdot
.41662 .37533 Mdot
.43475 .06112 Mdot
.38519 .33009 Mdot
.60034 .11954 Mdot
.45247 .01282 Mdot
.44113 .17572 Mdot
.64947 .14188 Mdot
.41631 .25234 Mdot
.41685 .34031 Mdot
.40605 .47843 Mdot
.4844 .65466 Mdot
.42236 .06715 Mdot
.48421 .01006 Mdot
.43669 .27081 Mdot
.42907 .63656 Mdot
.43766 .74234 Mdot
.44195 .72676 Mdot
.41111 .65095 Mdot
.5117 .09419 Mdot
.42137 .57008 Mdot
.40973 .54298 Mdot
.43931 .64211 Mdot
.40618 .58918 Mdot
.48843 .14827 Mdot
.41145 .57051 Mdot
.42441 .52203 Mdot
.51044 .03887 Mdot
.4896 .60589 Mdot
.41004 .26944 Mdot
.39519 .44195 Mdot
.50953 .14424 Mdot
.45677 .17885 Mdot
.41263 .40604 Mdot
.55361 .06909 Mdot
.5686 .05045 Mdot
.40809 .22663 Mdot
.66469 .14234 Mdot
.38429 .49728 Mdot
.43121 .62228 Mdot
.5848 .1464 Mdot
.59781 .14194 Mdot
.42195 .34315 Mdot
.52828 .1477 Mdot
.63025 .11122 Mdot
.42498 .60451 Mdot
.46454 .69539 Mdot
.43425 .25492 Mdot
.51874 .10581 Mdot
.45148 .18142 Mdot
.61194 .10185 Mdot
.43363 .6244 Mdot
.46795 .13352 Mdot
.41022 .27621 Mdot
.45501 .72521 Mdot
.43676 .61936 Mdot
.42404 .65237 Mdot
.40203 .13172 Mdot
.46901 .71207 Mdot
.41506 .13385 Mdot
.39788 .27952 Mdot
.41301 .21777 Mdot
.44755 .07436 Mdot
.54194 .14509 Mdot
.42865 .20913 Mdot
.546 .03045 Mdot
.41373 .48335 Mdot
.40316 .12369 Mdot
.4483 .2487 Mdot
.41701 .11096 Mdot
.43668 .2146 Mdot
.48043 .1511 Mdot
.42907 .10362 Mdot
.43221 .14887 Mdot
.40725 .52374 Mdot
.4512 .19855 Mdot
.46575 .14333 Mdot
.46719 .12575 Mdot
.48644 .63853 Mdot
.46536 .12993 Mdot
.45466 .17514 Mdot
.48016 .6904 Mdot
.43186 .33046 Mdot
.44711 .15082 Mdot
.40478 .28664 Mdot
.44745 .66545 Mdot
.40772 .36069 Mdot
.48802 .0255 Mdot
.41194 .64642 Mdot
.46277 .11094 Mdot
.42613 .70816 Mdot
.44429 .23661 Mdot
.46269 .68669 Mdot
.65127 .11806 Mdot
.45321 .66847 Mdot
.39086 .33361 Mdot
.56815 .13481 Mdot
.52518 .11128 Mdot
.40843 .47921 Mdot
.43259 .09377 Mdot
.46246 .00788 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:;ooooo0ol00007ooooo`03o`000?oooooooooo0;Wo
oooo002Jooooo`;o000000?oooooo`000?l000000oooool3o`0000Oooooo00?o0000ooooooooool0
^Oooool009[ooooo0_l000000ooooooo0000o`000003o`0000;ooooo1?l00004ooooo`03o`000?oo
oooooooo0;Wooooo002Looooo`;o000000Coooooo`000?l0003o00000_ooool4o`0000Cooooo00?o
0000ooooooooool0^Oooool009Oooooo0_l00003ooooo`?o00000oooool01?mEEEGoIVIVo`000?l0
0006ooooo`03o`000?oooooooooo0;Wooooo002Gooooo`;o00001?ooool2o`0000Gooooo0_l00006
ooooo`03o`000?oooooooooo0;Wooooo002Mooooo`;o00003Oooool00ol0003oooooooooo`02oooo
o`?o0000]?ooool00:;ooooo0_l00003ooooo`?o00000_ooool8o`0000?ooooo0_l0002_ooooo`00
X_ooool2o`0000?ooooo0ol00002ooooo`03o`000?oooooooooo00?o00001Oooool2o`000:oooooo
002Rooooo`;o000000?oooooo`000?l000001Oooool00ol0003oooooooooo`03o`0000Wooooo0_l0
002[ooooo`00Voooool2o`0000Gooooo0_l000000ooooooo0000o`000003ooooo`?o000000Cooooo
o`000?l0003o00002_ooool2o`000:_ooooo002Iooooo`Co00000oooool2o`0000;ooooo0_l00004
ooooo`?o000000?oooooo`000?l00000^?ooool009Gooooo0_l00002ooooo`;o00001Oooool2o`00
00;ooooo0_l00006ooooo`03o`000?oooooooooo00Co00001?ooool2o`000:oooooo002Eooooo`;o
00005Oooool00ol0003oooooooooo`05o`0000?ooooo0_l0002_ooooo`00UOooool3o`0000;ooooo
0ol0000?ooooo`04o`000?ooooooooooooooo`Co0000]?ooool009Gooooo0ol00002ooooo`?o0000
3?ooool2o`000003ooooool0003o000000Ko0000]?ooool009cooooo0_l0000;ooooo`;o000000?o
ooooo`000?l000000_l00002ooooo`;o000000?oooooo`000?l000002oooool2o`000:Cooooo002G
ooooo`;o00000oooool2o`0000Kooooo0_l00006ooooo`;o00001oooool2o`0000Gooooo0_l00004
ooooo`;o0000Y?ooool009Oooooo0_l0000;ooooo`;o00001_ooool00ol0003oooooooooo`0=oooo
o`;o0000Z_ooool009Gooooo0ol00009ooooo`;o00002Oooool00ol0003oooooooooo`05ooooo`;o
0000/_ooool009Gooooo0ol00009ooooo`;o00002Oooool00ol0003oooooooooo`05ooooo`?o0000
/Oooool009;ooooo0_l00004ooooo`?o00004Oooool00ol0003oooooooooo`06ooooo`;o0000/Ooo
ool009;ooooo0_l00004ooooo`?o00004Oooool3o`0000kooooo0_l0002Yooooo`00V_ooool2o`00
013ooooo0ol0000=ooooo`?o00000oooool2o`000:Cooooo002Aooooo`;o00000_ooool3o`000004
ooooool0003o0000o`00013ooooo0ol00003ooooo`;o00002?ooool2o`0000Cooooo0_l0002Toooo
o`00Soooool5o`000005ooooool0003o0000o`000?ooool00_l0000Aooooo`?o00000oooool4o`00
013ooooo0_l00003ooooo`;o0000Voooool008oooooo0_l000000ooooooo0000o`00000?ooooo`;o
00001oooool3o`0000?ooooo1?l0000@ooooo`;o00000oooool2o`0009_ooooo002>ooooo`;o0000
2oooool2o`0000Kooooo0_l00007ooooo`04o`000?oooooo0000o`0000;ooooo0_l0000Fooooo`;o
0000W?ooool008kooooo0_l00007ooooo`;o00000_ooool2o`0000Kooooo0_l00007ooooo`04o`00
0?oooooo0000o`0000;ooooo0_l00004ooooo`;o00004?ooool3o`000003ooooool0003o000009So
oooo002?ooooo`;o00001?ooool4o`0000oooooo0_l00002ooooo`03o`000?oooooooooo00?ooooo
0_l00004ooooo`Co00003oooool5o`0009Sooooo002?ooooo`;o00001?ooool2o`0000Wooooo0_l0
0006ooooo`;o00000_ooool00ol0003oooooooooo`02o`0000Gooooo0_l000001?oooooo0000o`00
0?l0000@ooooo`;o0000V_ooool009Gooooo1?l00007ooooo`;o00002_ooool00ol0003ooooooooo
o`02o`0000Gooooo0_l000000ooooooo0000o`00000<ooooo`;o0000Woooool009Oooooo1_l0000?
ooooo`?o00000oooool3o`00017ooooo0ol0000;ooooo`;o0000T_ooool008kooooo0_l00004oooo
o`;o00000oooool4o`0000?ooooo0_l00004ooooo`;o00001?ooool00ol0003oooooooooo`03oooo
o`?o00001Oooool2o`0000[ooooo0_l00009ooooo`;o000000?oooooo`000?l00000T_ooool008ko
oooo0_l00004ooooo`Co00002?ooool2o`0000Cooooo0_l00004ooooo`03o`000?oooooooooo00?o
oooo0_l00004ooooo`Co00005Oooool2o`0009Gooooo002>ooooo`;o00000oooool2o`000004oooo
ool0003o0000o`0000Cooooo0_l00009ooooo`;o000000?oooooo`000?l000001?ooool3o`0000Co
oooo0_l0000Fooooo`;o0000U_ooool008kooooo1?l000000ooooooo0000o`000002ooooo`;o0000
1?ooool4o`0000Oooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l00000
6_ooool2o`0000Gooooo0_l0002?ooooo`00S_ooool4o`0000Oooooo0_l00002ooooo`Co000000Co
ooooo`000?l0003ooooo0_l00005ooooo`03o`000?oooooooooo00Gooooo1ol0000;ooooo`;o0000
3oooool2o`0008oooooo0029ooooo`03onk^k_lb<S;o000000Co00000oooool2ob4Q8@Cooooo0ol0
00000oo^k^ko0000o`000003ooooo`Go00001?ooool2o`000003ooooool0003o000000Cooooo1ol0
000;ooooo`;o00001Oooool2o`0000oooooo0_l00028ooooo`00ROooool00omgMgOoV9RHo`000002
o`0000Gooooo0_lQ8B44ooooo`;o000000?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`03
ooooo`;o000000?oooooo`000?l000001?ooool2o`00013ooooo0_l000000ooooooo0000o`000002
ooooo`;o00003oooool2o`0008Sooooo0021ooooo`Ko00000_ooool00ol@413oooooo`000002o`00
00_ooooo0ol000000omEEEGoooooooooo`02ooooo`;o00000oooool3o`0000?ooooo0ol0000Joooo
o`;o00002?ooool2o`0009?ooooo0029ooooo`03o`000?oooooooooo00;o00002oooool3o`000003
ob4Q8Ooooooooooo00;ooooo0_l00002ooooo`04ogMgMolb<S;o0000o`0000?ooooo00?o0000oooo
ooooool00_l00003ooooo`;o00005oooool2o`0000Cooooo0_l00006ooooo`;o0000Roooool008Wo
oooo00?o0000ooooool000000_l0000;ooooo`?o000000CoEEEEolc<c?oooooooooo0ol000001?lQ
8B7o0000oc8b<_o<c<`5ooooo`03o`000?oooooooooo00;o00000oooool2o`0000;ooooo0_l0000:
ooooo`;o00000oooool2o`0000;ooooo0_l00008ooooo`;o00000_ooool2o`0000Cooooo0_l00025
ooooo`00ROooool01Ol@413oooooo`000?l0003o410@00;ooooo0_l0000:ooooo`04ojVYZOmgMgOo
ooooooooo`?o00002Oooool00ol0003oooooooooo`04ooooo`;o00000_ooool3o`0000Gooooo0_l0
00000ooooooo0000o`000002o`000003ooooool0003o000000;o00001oooool2o`0000?ooooo0_l0
0003ooooo`;o00000oooool2o`0008Gooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_oo
ool4o`0000Gooooo00Go410@oooooooooooooooooc8b<P03ooooo`;o00001_ooool2o`000003oooo
ool0003ooooo00Gooooo0_l00002ooooo`;o00001_ooool2o`000003ooooool0003o000000?ooooo
0_l00009ooooo`;o00002?ooool2o`0008[ooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1?ooool2o`0000Gooooo1_l00002ooooo`Go00000oooool4o`0001Cooooo0_l00008ooooo`;o0000
1?ooool2o`0001?ooooo0_l00020ooooo`00T_ooool2o`0000Wooooo0_l000001?oooooo0000o`00
0?l00003ooooo`;o00000_ooool3o`0000Sooooo0ol00002ooooo`;o00001Oooool2o`0000Sooooo
0ol00003ooooo`;o00002?ooool4o`0000?ooooo0_l000001?oooooo0000o`000?l00020ooooo`00
SOooool2o`0000Sooooo0ol00006ooooo`;o00001?ooool3o`0000?ooooo00?o0000ooooooooool0
0_l00004ooooo`?o000000Coooooo`000?l0003o00001oooool2o`0000?ooooo0_l000000ooooooo
0000o`000003o`0000Gooooo0_l00004ooooo`Co00000oooool5o`00087ooooo002=ooooo`Co0000
1?ooool5o`0000gooooo0ol00002ooooo`03o`000?oooooooooo00;o00001?ooool2o`0000;ooooo
0_l00007ooooo`?o00000oooool2o`0000;ooooo1?l00005ooooo`;o00003Oooool2o`0008;ooooo
002?ooooo`;o00001?ooool4o`000003ooooool0003o000000Wooooo0_l000000ooooooo0000o`00
0002ooooo`?o00001_ooool2o`0000_ooooo0_l0002Tooooo`00T?ooool2o`0000Gooooo0_l00000
0ooooooo0000o`000007ooooo`Co00001Oooool00ol0003oooooooooo`2iooooo`00ROooool2o`00
00;ooooo1Ol00002ooooo`;o00003Oooool2o`0000Oooooo00?o0000ooooooooool0^Oooool008Wo
oooo0_l000000ooooooo0000o`000003o`0000?ooooo0_l0000Fooooo`03o`000?oooooooooo0;Wo
oooo002<ooooo`;o00000_ooool2o`00017ooooo0_l00007ooooo`03o`000?oooooooooo0;Wooooo
002@ooooo`;o00004Oooool2o`0000Oooooo00?o0000ooooooooool0^Oooool008oooooo0_l0000K
ooooo`03o`000?oooooooooo0;Wooooo002?ooooo`;o00001Oooool2o`0001Cooooo00?o0000oooo
ooooool0^Oooool009Kooooo1?l00003ooooo`;o00003Oooool3o`000;Wooooo002Hooooo`;o0000
0oooool2o`0000gooooo00?o0000ooooooooool0^Oooool009Sooooo0_l00002ooooo`?o00003Ooo
ool00ol0003oooooooooo`2iooooo`00U?ooool4o`0000Cooooo0ol0000=ooooo`03o`000?oooooo
oooo0;Wooooo002:ooooo`?o00001oooool4o`0001Cooooo00?o0000ooooooooool0^Oooool008[o
oooo0ol00005ooooo`;o00002_ooool2o`0000cooooo00?o0000ooooooooool0^Oooool009;ooooo
0_l00002ooooo`;o00001_ooool2o`0000cooooo00?o0000ooooooooool0^Oooool009Gooooo0ol0
0003ooooo`;o00003oooool00ol0003oooooooooo`2iooooo`00UOooool2o`0000Cooooo0_l00000
0ooooooo0000o`00000<ooooo`?o0000^Oooool009kooooo0_l0000<ooooo`03o`000?oooooooooo
0;Wooooo002Iooooo`;o00004Oooool00ol0003oooooooooo`2iooooo`00U?ooool2o`0000?ooooo
0_l0000Aooooo`03o`000?oooooooooo0;Wooooo0028ooooo`;o00000_ooool2o`0000Kooooo0_l0
0002ooooo`;o00004_ooool00ol0003oooooooooo`2iooooo`00R?ooool3o`000003ooooool0003o
000000Wooooo0ol0000Booooo`03o`000?oooooooooo0;Wooooo0029ooooo`;o00001?ooool2o`00
00Kooooo0_l0000Cooooo`03o`000?oooooooooo0;Wooooo002?ooooo`;o00002_ooool2o`0000oo
oooo00?o0000ooooooooool0^Oooool009_ooooo0_l0000?ooooo`?o0000^Oooool008Sooooo0_l0
0003ooooo`;o00007Oooool00ol0003oooooooooo`2iooooo`00R?ooool2o`0000?ooooo0_l0000M
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002@ooooo`;o
00000oooool2o`0000;ooooo0_l0000Aooooo`03o`000?oooooooooo0;Wooooo002@ooooo`;o0000
0oooool2o`0000;ooooo0_l0000Aooooo`03o`000?oooooooooo0;Wooooo002>ooooo`?o000000Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Go
oooo00?o0000ooooooooool0^Oooool008_ooooo0_l000001_oooooo0000o`000?l0003oMgMgoiRH
V0;o000000?oMgMgooooooooool00oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`2iooooo`00ROooool6o`0000;ooooo00Go410@ooooool0003o0000oa0@4004oooo
o`;o00002_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;Wooooo002:ooooo`;o
00001?ooool2o`0000?ooooo00Co0000oooooooooooooooo0ol00009ooooo`03ogMgMolb<S;ooooo
00Cooooo0ol0002iooooo`00R_ooool3o`0000?ooooo0_l00003ooooo`?o000000?oooooo`000?l0
00001oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0^Oooool008So
oooo0_l000000ooooooo0000o`000002ooooo`;o000000Go410@oooooooooooooooooa0@4002o`00
00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2iooooo`00R?ooool2o`0000Go
oooo0_l000001OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`2iooooo`00TOooool01_o^k^ko<S8bo`000?lb<S;ok^k^ooooo`;o00002Oooool4
o`0000Kooooo00?o0000ooooooooool0^Oooool008Oooooo0_l0000>ooooo`;o00004oooool00ol0
003oooooooooo`2iooooo`00Qoooool2o`0000Gooooo0_l00007ooooo`;o00004oooool00ol0003o
ooooooooo`2iooooo`00S_ooool3o`0000;ooooo0_l00002ooooo`;o00004oooool00ol0003ooooo
ooooo`2iooooo`00S_ooool3o`0000;ooooo0_l0000Gooooo`?o0000^Oooool008[ooooo0_l00002
ooooo`;o00007?ooool00ol0003oooooooooo`2iooooo`00R_ooool2o`00023ooooo00?o0000oooo
ooooool0^Oooool008Sooooo0_l0000<ooooo`;o00005?ooool00ol0003oooooooooo`2iooooo`00
R?ooool2o`0000;ooooo0_l000001?oooooo0000o`000?l00004ooooo`;o00005?ooool00ol0003o
ooooooooo`2iooooo`00Roooool3o`000004ooooool0003o0000o`0001[ooooo00?o0000oooooooo
ool0^Oooool008_ooooo0_l00002ooooo`;o00006oooool00ol0003oooooooooo`2iooooo`00Rooo
ool2o`0000;ooooo0_l0000Kooooo`03o`000?oooooooooo0;Wooooo0026ooooo`;o00000oooool2
o`0000Gooooo1?l0000Fooooo`?o0000^Oooool008Kooooo0ol00008ooooo`Go00005_ooool00ol0
003oooooooooo`2iooooo`00Qoooool2o`0000Kooooo1_l0000Gooooo`03o`000?oooooooooo0;Wo
oooo002<ooooo`;o000000?oooooo`000?l000006oooool00ol0003oooooooooo`2iooooo`00S?oo
ool2o`0000Sooooo0_l0000Dooooo`03o`000?oooooooooo0;Wooooo002Fooooo`;o00005?ooool0
0ol0003oooooooooo`2iooooo`00ROooool2o`00027ooooo00?o0000ooooooooool0^Oooool008Wo
oooo0_l0000:ooooo`;o00005Oooool00ol0003oooooooooo`2iooooo`00T?ooool4o`000003oooo
ool0003o000001Gooooo0ol0002iooooo`00QOooool2o`0000Wooooo1?l0000Hooooo`03o`000?oo
oooooooo0;Wooooo0025ooooo`Go00002oooool2o`0001Gooooo00?o0000ooooooooool0^Oooool0
08Kooooo1?l0000;ooooo`;o00005Oooool00ol0003oooooooooo`2iooooo`00R?ooool4o`0000Go
oooo0_l0000Iooooo`03o`000?oooooooooo0;Wooooo002:ooooo`;o00001?ooool5o`0001Oooooo
00?o0000ooooooooool0^Oooool008[ooooo0_l00004ooooo`Go00005oooool00ol0003ooooooooo
o`2iooooo`00R_ooool2o`000003ooooool0003o000000?ooooo0_l0000Hooooo`03o`000?oooooo
oooo0;Wooooo0028ooooo`;o00000oooool2o`0001gooooo00?o0000ooooooooool0^Oooool008So
oooo0_l0000:ooooo`;o00005_ooool3o`000;Wooooo002?ooooo`;o00000_ooool3o`0001Kooooo
00?o0000ooooooooool0^Oooool008oooooo0_l00002ooooo`;o00005oooool00ol0003ooooooooo
o`2iooooo`00SOooool4o`0001_ooooo00?o0000ooooooooool0^Oooool008Gooooo0_l00006oooo
o`;o00000_ooool2o`0001Wooooo00?o0000ooooooooool0^Oooool008Gooooo0_l00002ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool3o`000003ob4Q8Ooooooooooo00;ooooo1Ol00004oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2iooooo`00ROooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Cooooo1?l00003ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;Wooooo0021ooooo`So000000Go410@
oooooooooooooooooa0@4006ooooo`;o00001?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0^Oooool008Oooooo0ol00003ooooo`03o`000?oooooo
oooo00;o00002Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002i
ooooo`00ROooool01Ol0003ooooooooooooooooo000000;ooooo0_l0000:ooooo`03ogMgMomVIVKo
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;Wooooo0027
ooooo`;o000000Co410@oooooooooooooooo0_l00004ooooo`;o00002?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0^Oooool008Gooooo1?l00000
1?mgMgOo0000o`000?nHV9P2o`0000Cooooo0_l00004ooooo`05o`000?nj^[[ooooooiRHV?l@4100
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Wooooo0025ooooo`;o00000_oo
ool01Oo^k^ko0000o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co
00001_ooool00ol0003oooooooooo`2iooooo`00Roooool2o`0000;ooooo0_l0000Kooooo`03o`00
0?oooooooooo0;Wooooo002;ooooo`;o00000_ooool2o`0001_ooooo00?o0000ooooooooool0^Ooo
ool00:cooooo00?o0000ooooooooool0^Oooool008Gooooo0_l000000ooooooo0000o`000005oooo
o`;o00006oooool3o`000;Wooooo0025ooooo`;o000000?oooooo`000?l000001Oooool2o`0001_o
oooo00?o0000ooooooooool0^Oooool008Sooooo1?l00003ooooo`;o00006oooool00ol0003ooooo
ooooo`2iooooo`00R_ooool2o`0000?ooooo0_l0000Kooooo`03o`000?oooooooooo0;Wooooo002?
ooooo`;o00006oooool00ol0003oooooooooo`2iooooo`00R_ooool2o`00023ooooo00?o0000oooo
ooooool0^Oooool008[ooooo0_l0000Pooooo`03o`000?oooooooooo0;Wooooo0025ooooo`;o0000
1Oooool2o`0000Cooooo0_l0000Hooooo`03o`000?oooooooooo0;Wooooo0025ooooo`;o00001Ooo
ool2o`000004ooooool0003o0000ooooo`;o00006?ooool3o`000;Wooooo0026ooooo`;o00001ooo
ool2o`0001_ooooo00?o0000ooooooooool0^Oooool008Kooooo0_l0000Tooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Aooooo`;o00006Oooool00ol0003o
ooooooooo`2iooooo`00Roooool2o`0000;ooooo1?l0000Iooooo`03o`000?oooooooooo0;Wooooo
0029ooooo`Co00000_ooool2o`0001_ooooo00?o0000ooooooooool0^Oooool008Wooooo0_l00004
ooooo`;o00006oooool00ol0003oooooooooo`2iooooo`00QOooool2o`0000Oooooo0_l0000Loooo
o`03o`000?oooooooooo0;Wooooo0025ooooo`;o00001oooool2o`0001cooooo0ol0002iooooo`00
ROooool2o`0000Kooooo0_l0000Iooooo`03o`000?oooooooooo0;Wooooo0029ooooo`;o00001_oo
ool2o`0001Wooooo00?o0000ooooooooool0^Oooool000Wooooo1?l000000ol@413oooooooooo`0F
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Fooooo`03o`000?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo
00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo
1?l000000ol@413oooooooooo`0Booooo`002oooool00ol0003oooooooooo`0Hooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8b
ooooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_oo
ool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7o0000
o`000?m4A4@00_ooool2o`0000?ooooo00?oMgMgoc8b<_ooool05Oooool00ol0003oooooooooo`0H
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A007ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo
01Cooooo0006o`0000Gooooo00?o0000ooooooooool04?ooool6o`0000;ooooo00Go410@oooooooo
oooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool01Oooool6o`00
00;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00Gooooo1_l00002
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP03ooooo`?o00000ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Sooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool03Oooool01Ol@413ooooo
oooooooooooo410@013ooooo00?o0000ooooooooool03Oooool01Ol@413ooooooooooooooooo410@
00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo
000000oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000gooooo0ol0
0003ooooo`;o00000_ooool00omgMgOo<S8booooo`0Eooooo`03o`000?oooooooooo01Sooooo00Go
0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0
3_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003o
oooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`0Ioooo
o`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?
ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo
00Go0000ooooooooooooooooo`00000<ooooo`Co00001?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<
01Kooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMg
ofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000oooooooooooooooo
o`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo0000
00kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[ooooo00?o0000
ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol@413ooooooooooooooooo
410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`0Aooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@4100
3?ooool2o`000004ooooool0003o0000o`0000;ooooo00?o0000ooooooooool06?ooool3o`0001So
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool04Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04Oooool0
1Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooo
ooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00;o00000_ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`0Aooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Dooooo`002Oooool00omEEEGoIVIVo`00000Jooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?oo
ool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`00_l00002ooooo`Co00005oooool00ol0003oooooooooo`0Hooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0000@ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go0000
1?ooool4o`0001Wooooo00?oEEEEofIVI_l000005_ooool008cooooo0_l000000ooooooo0000o`00
000Kooooo`03o`000?oooooooooo0;Wooooo002<ooooo`;o000000?oooooo`000?l000006oooool0
0ol0003oooooooooo`2iooooo`00S?ooool2o`0001kooooo00?o0000ooooooooool0[_ooool2o`00
00;ooooo0_l00005ooooo`00S?ooool2o`0000Cooooo0_l0000Hooooo`03o`000?oooooooooo0:ko
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd5ooooo`00QOooool2o`0000Sooooo0_l000000ooo
oooo0000o`00000Hooooo`03o`000?oooooooooo0:oooooo00CogMgMo`000?l@413oc<c<1_ooool0
00Ooooooool0001<o`0000cooooo00Cok^k^ob4Q8Ol@413ok^k^1_ooool000Oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0:ooooo`04ob4Q8OmgMgOoMgMgoc8b<PKooooo0007oooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`09oooo
o`;o00000_ooool2o`0000Gooooo002/ooooo`03o`000?oooooooooo0;Wooooo002;ooooo`;o0000
7oooool00ol0003oooooooooo`2iooooo`00Roooool2o`0001oooooo00?o0000ooooooooool0^Ooo
ool009?ooooo0_l0000Gooooo`03o`000?oooooooooo0;Wooooo0027ooooo`Co00002?ooool2o`00
01Oooooo00?o0000ooooooooool0^Oooool008Oooooo1?l00002ooooo`;o00001?ooool2o`0001Oo
oooo0ol0002iooooo`00Roooool6o`0001_ooooo00?o0000ooooooooool0^Oooool008_ooooo0_l0
0002ooooo`;o00006oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
S?ooool4o`0000;ooooo0_l0000Hooooo`03o`000?oooooooooo0;Wooooo002<ooooo`Co00000_oo
ool2o`0001Sooooo00?o0000ooooooooool0^Oooool008kooooo0_l0000Looooo`03o`000?oooooo
oooo0;Wooooo002>ooooo`Co00000_ooool2o`0001Kooooo0ol0002iooooo`00T?ooool2o`0000;o
oooo0_l0000Fooooo`03o`000?oooooooooo0;Wooooo002<ooooo`;o00001oooool2o`0001Gooooo
00?o0000ooooooooool0^Oooool008[ooooo1?l00007ooooo`;o00005Oooool00ol0003ooooooooo
o`2iooooo`00R_ooool2o`0000Wooooo0ol0000Dooooo`03o`000?oooooooooo0;Wooooo0027oooo
o`Co00002oooool2o`0001Cooooo00?o0000ooooooooool0^Oooool008Oooooo1?l000000ooooooo
0000o`000002o`0000;ooooo1?l0000Fooooo`03o`000?oooooooooo0;Wooooo002<ooooo`Co0000
0_ooool5o`0001Gooooo00?o0000ooooooooool0^Oooool008kooooo0_l00005ooooo`;o00005Ooo
ool3o`000;Wooooo002>ooooo`;o00007?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00Roooool5o`0001cooooo
00?o0000ooooooooool0^Oooool008_ooooo1Ol0000Looooo`03o`000?oooooooooo0;Wooooo002A
ooooo`?o00006?ooool00ol0003oooooooooo`2iooooo`00Soooool5o`0001Sooooo00?o0000oooo
ooooool0^Oooool008oooooo0_l0000Kooooo`?o0000^Oooool009?ooooo0_l0000Gooooo`03o`00
0?oooooooooo0;Wooooo002Cooooo`;o00004oooool2o`0000;ooooo00?o0000ooooooooool0^Ooo
ool009Kooooo0_l0000@ooooo`;o00000_ooool00ol0003oooooooooo`2iooooo`00U?ooool4o`00
01Cooooo00?o0000ooooooooool0^Oooool008[ooooo0_l00008ooooo`Co00005?ooool00ol0003o
ooooooooo`2iooooo`00ROooool00oo^k^ko0000o`000002o`0000Gooooo0_lQ8B42ooooo`Oo0000
1?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0^Oooool008Wooooo
00?oMgMgo`000?l000000_l00005ooooo`;o8B4Q1?l000001OnHV9So8B4Qonk^k_ooooooA4A400Oo
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2iooooo`00ROooool01Ol@413o0000
o`000?oooooo410@00Oooooo0ol00002ooooo`03oiRHV?lQ8B7ok^k^00Wooooo0ol00003ooooo`?o
0000^Oooool008Wooooo1_l00006ooooo`?o00000oooool00onHV9So8B4Qonk^kP07ooooo`04ogMg
Molb<S;o0000o`0000?ooooo00?o0000ooooooooool0^Oooool008Wooooo2?l00004ooooo`;o0000
1Oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003o
ooooooooo`2iooooo`00ROooool01_l@413ooooooooooooooooo410@ooooo`;o000000?oooooo`00
0?l000002Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0^Oooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`Co00000oooool01Ol0
003o^[Zjo`000?l0003o410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2i
ooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo0_l000000ooooooo0000o`000003
ooooo`05oiRHV?l@413o0000o`000?o<c<`01?ooool4o`000003ooooool0003o000000?ooooo00?o
0000ooooooooool0^Oooool0097ooooo0_l00005ooooo`;o00003Oooool2o`0000?ooooo00?o0000
ooooooooool0^Oooool008gooooo0ol00008ooooo`;o00002?ooool2o`0000Sooooo00?o0000oooo
ooooool0^Oooool008gooooo1?l0000;ooooo`;o00001?ooool2o`0000Sooooo00?o0000oooooooo
ool0^Oooool008kooooo0ol000000ooooooo0000o`000008ooooo`;o00003_ooool3o`000;Wooooo
002>ooooo`;o00000_ooool2o`0001;ooooo0_l00004ooooo`03o`000?oooooooooo0;Wooooo002V
ooooo`;o00001?ooool00ol0003oooooooooo`2iooooo`00T?ooool2o`0001[ooooo00?o0000oooo
ooooool0^Oooool0093ooooo1?l0000;ooooo`Co00002Oooool00ol0003oooooooooo`2iooooo`00
T_ooool2o`0000Kooooo0_l00003ooooo`Co00002Oooool00ol0003oooooooooo`2iooooo`00S_oo
ool2o`0000[ooooo1?l00007ooooo`;o00001Oooool00ol0003oooooooooo`2iooooo`00S_ooool2
o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000Oooooo0_l00005ooooo`03o`000?oooooo
oooo0;Wooooo002Cooooo`;o00000_ooool2o`0001?ooooo0ol0002iooooo`00XOooool2o`0000Wo
oooo00?o0000ooooooooool0^Oooool009oooooo1?l00009ooooo`03o`000?oooooooooo0;Wooooo
002Cooooo`;o00001oooool2o`000004ooooool0003o0000o`0000;ooooo0_l00006ooooo`03o`00
0?oooooooooo0;Wooooo002Cooooo`;o00000oooool2o`0000;ooooo2_l00006ooooo`03o`000?oo
oooooooo0;Wooooo002Aooooo`;o00001Oooool2o`0000;ooooo1Ol000001?oooooo0000o`000?oo
ool2o`0000Gooooo00?o0000ooooooooool0^Oooool0097ooooo0_l00005ooooo`;o00000_ooool2
o`0000;ooooo0_l00003ooooo`;o00001Oooool00ol0003oooooooooo`2iooooo`00U?ooool3o`00
0003ooooool0003o000000Kooooo0_l0000:ooooo`03o`000?oooooooooo0;Wooooo002Dooooo`?o
00001Oooool2o`0000kooooo0ol0002iooooo`00W?ooool2o`0000?ooooo0_l00009ooooo`03o`00
0?oooooooooo0;Wooooo002Qooooo`;o00002Oooool00ol0003oooooooooo`2iooooo`00Toooool2
o`0000Sooooo0_l00002ooooo`?o00002?ooool00ol0003oooooooooo`2iooooo`00Toooool2o`00
00Gooooo0_l000000ooooooo0000o`000002ooooo`?o00002?ooool00ol0003oooooooooo`2ioooo
o`00V_ooool2o`0000Gooooo0_l00009ooooo`03o`000?oooooooooo0;Wooooo002Sooooo`;o0000
1oooool00ol0003oooooooooo`2iooooo`00Voooool2o`0000Kooooo0_l00007ooooo`03o`000?oo
oooooooo0;Wooooo002Jooooo`Go00003Oooool3o`000;Wooooo002Hooooo`Oo00003Oooool00ol0
003oooooooooo`2iooooo`00V?ooool2o`0000;ooooo0_l0000>ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002Mooooo`;o00003Oooool00ol0003ooooooooo
o`2iooooo`00WOooool2o`0000gooooo00?o0000ooooooooool0^Oooool0097ooooo00Kok^k^oc8b
<_l0003o<S8bonk^k_ooool2o`0000;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1Oooool00ol0003oooooooooo`2iooooo`00TOooool01_mgMgOoV9RHoooooonHV9SoMgMgooooo`;o
00000_ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2iooooo`00
TOooool01Ol@413ooooooooooooooooo410@00Kooooo0_l00008ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0^Oooool0097ooooo00Go0000ooooooooooooooooo`000006ooooo`;o
00001oooool00omgMgOo<S8booooo`04ooooo`?o0000^Oooool0097ooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2ioooo
o`00TOooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`2iooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`2iooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo1?l00006ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Ooo
ool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`00
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool008Wooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2iooooo`00ROooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2iooooo`00ROooool01Ol@413ooooooooooooooooo410@00gooooo
00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;Wooooo
0029ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMg
Molb<S;ooooo00Cooooo0ol0002iooooo`00ROooool01Ol0003ooooooooooooooooo000000kooooo
00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool0^Oooool008Wooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2iooooo`00ROooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0^Oooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Ooo
ool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002i
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00X_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooo
ooooool0^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00
Y?ooool00ol0003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool0`Ooo
ool00:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:Co
oooo00?o0000ooooooooool0`Oooool00:;ooooo00?oEEEEofIVI_l00000`oooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:[ooooo00Co410@o`000?l0003o
0000^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_oo
ool00:_ooooo00Ko0000ogMgMol0003o0000oeEEEOo^k^jgooooo`00Zoooool01_l0003oEEEEonk^
k_ooooooMgMgoeEEEKOooooo002[ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0
]Oooool00:_ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`2eooooo`00Zoooool0
1_l0003oEEEEonk^k_ooooooMgMgofIVI[Oooooo002Zooooo`03oa0@4?l0003oMgMg00;o000000?o
IVIVonk^k_ooool0]_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.40979 .77059 Mdot
.43747 .87506 Mdot
.50227 .4387 Mdot
.47729 .75268 Mdot
.50294 .79173 Mdot
.4325 .834 Mdot
.51015 .58633 Mdot
.41755 .92005 Mdot
.38123 .28188 Mdot
.49454 .76363 Mdot
.47563 .78511 Mdot
.36655 .58358 Mdot
.46989 .92618 Mdot
.53002 .69765 Mdot
.42472 .06819 Mdot
.4985 .74267 Mdot
.41213 .71442 Mdot
.47304 .9276 Mdot
.50829 .76736 Mdot
.45767 .94375 Mdot
.3941 .72016 Mdot
.39335 .69377 Mdot
.388 .36478 Mdot
.44593 .9075 Mdot
.40882 .10431 Mdot
.52685 .77184 Mdot
.43111 .70844 Mdot
.46437 .7962 Mdot
.42284 .88593 Mdot
.39783 .7193 Mdot
.38667 .35217 Mdot
.36878 .51214 Mdot
.3689 .60116 Mdot
.3951 .52211 Mdot
.43522 .82402 Mdot
.38033 .39025 Mdot
.37221 .51613 Mdot
.4423 .75554 Mdot
.37521 .46136 Mdot
.38531 .79169 Mdot
.36443 .43762 Mdot
.4152 .74814 Mdot
.41281 .75234 Mdot
.47817 .90346 Mdot
.4654 .89583 Mdot
.51778 .77573 Mdot
.45734 .76805 Mdot
.38204 .72541 Mdot
.5102 .81142 Mdot
.3772 .58856 Mdot
.37336 .62479 Mdot
.38733 .73064 Mdot
.39997 .65765 Mdot
.45539 .86528 Mdot
.37164 .37749 Mdot
.39476 .83609 Mdot
.43898 .81667 Mdot
.37609 .65031 Mdot
.46731 .89542 Mdot
.49311 .81579 Mdot
.37366 .26083 Mdot
.38568 .30023 Mdot
.52494 .64011 Mdot
.40865 .12396 Mdot
.36887 .55601 Mdot
.47482 .77557 Mdot
.453 .74023 Mdot
.48408 .79469 Mdot
.41636 .83826 Mdot
.51761 .81778 Mdot
.52171 .5287 Mdot
.45734 .76441 Mdot
.48725 .76722 Mdot
.38614 .29631 Mdot
.50893 .50717 Mdot
.41918 .70815 Mdot
.39478 .77793 Mdot
.40189 .5766 Mdot
.38443 .35917 Mdot
.38899 .63377 Mdot
.45705 .73591 Mdot
.42983 .80598 Mdot
.40307 .8669 Mdot
.54125 .63699 Mdot
.50527 .78876 Mdot
.43579 .7638 Mdot
.47339 .85503 Mdot
.44504 .72225 Mdot
.42848 .05251 Mdot
.53316 .62142 Mdot
.50003 .80241 Mdot
.52231 .65507 Mdot
.40352 .07901 Mdot
.52739 .70307 Mdot
.37838 .31924 Mdot
.51845 .81195 Mdot
.39905 .70939 Mdot
.50481 .8286 Mdot
.36963 .36696 Mdot
.456 .89539 Mdot
.38969 .69884 Mdot
.39508 .53851 Mdot
.48217 .86031 Mdot
.51682 .7547 Mdot
.53434 .61715 Mdot
.39818 .75359 Mdot
.52441 .70718 Mdot
.50715 .71219 Mdot
.36951 .45275 Mdot
.41118 .84028 Mdot
.52951 .55 Mdot
.46425 .82271 Mdot
.40516 .8692 Mdot
.38836 .78429 Mdot
.39646 .20992 Mdot
.45002 .91076 Mdot
.3625 .41264 Mdot
.39069 .3241 Mdot
.44294 .92925 Mdot
.40751 .80315 Mdot
.46005 .74471 Mdot
.39321 .75234 Mdot
.39907 .09858 Mdot
.38695 .42669 Mdot
.49642 .69108 Mdot
.38483 .59568 Mdot
.39041 .63133 Mdot
.36539 .44653 Mdot
.47115 .88692 Mdot
.41665 .77414 Mdot
.42996 .90738 Mdot
.41239 .86868 Mdot
.39994 .79602 Mdot
.45049 .75226 Mdot
.36859 .40551 Mdot
.40283 .13304 Mdot
.44542 .00376 Mdot
.52709 .65299 Mdot
.50553 .76924 Mdot
.41718 .74194 Mdot
.44229 .92332 Mdot
.40364 .86684 Mdot
.4194 .67037 Mdot
.44415 .78734 Mdot
.37722 .76723 Mdot
.51874 .80641 Mdot
.50954 .75535 Mdot
.46479 .92662 Mdot
.52193 .51435 Mdot
.39193 .60221 Mdot
.38219 .69485 Mdot
.3747 .46793 Mdot
.38066 .7324 Mdot
.37488 .40039 Mdot
.38788 .74385 Mdot
.52183 .786 Mdot
.41495 .86762 Mdot
.40804 .90463 Mdot
.38884 .3018 Mdot
.39185 .49455 Mdot
.38656 .51562 Mdot
.39442 .82463 Mdot
.39761 .7597 Mdot
.47817 .79597 Mdot
.42364 .90039 Mdot
.37996 .38044 Mdot
.4689 .7403 Mdot
.44771 .76547 Mdot
.45664 .80432 Mdot
.44232 .76766 Mdot
.3722 .35256 Mdot
.40683 .06959 Mdot
.39027 .56399 Mdot
.50008 .67254 Mdot
.38919 .73385 Mdot
.43344 .9208 Mdot
.3734 .70151 Mdot
.51575 .7131 Mdot
.36403 .44491 Mdot
.5003 .68884 Mdot
.40283 .15805 Mdot
.42098 .03476 Mdot
.38578 .76246 Mdot
.39818 .86609 Mdot
.43187 .8255 Mdot
.36273 .42177 Mdot
.45077 .93501 Mdot
.5122 .67353 Mdot
.39812 .12457 Mdot
.4025 .86684 Mdot
.36811 .66171 Mdot
.36652 .42198 Mdot
.48749 .8156 Mdot
.40004 .08347 Mdot
.50689 .83901 Mdot
.49671 .67613 Mdot
.49747 .67506 Mdot
.52176 .53464 Mdot
.45759 .80376 Mdot
.4103 .04892 Mdot
.3866 .54659 Mdot
.48969 .71649 Mdot
.41889 .79223 Mdot
.5345 .63715 Mdot
.52919 .59879 Mdot
.49955 .76565 Mdot
.46968 .92232 Mdot
.42648 .74189 Mdot
.39505 .74354 Mdot
.48033 .766 Mdot
.38653 .48292 Mdot
.41761 .6956 Mdot
.39631 .85943 Mdot
.52677 .60352 Mdot
.40564 .73901 Mdot
.39932 .86192 Mdot
.47332 .82616 Mdot
.37559 .36446 Mdot
.40731 .80874 Mdot
.39374 .27093 Mdot
.44248 .71809 Mdot
.48807 .80684 Mdot
.48383 .91 Mdot
.49567 .72492 Mdot
.42027 .07863 Mdot
.36086 .55143 Mdot
.50714 .72137 Mdot
.51404 .52294 Mdot
.44193 .81266 Mdot
.46633 .78592 Mdot
.36762 .33277 Mdot
.45106 .77353 Mdot
.46001 .90035 Mdot
.38384 .59676 Mdot
.3938 .66804 Mdot
.38402 .18991 Mdot
.45759 .87502 Mdot
.41219 .83443 Mdot
.51681 .81889 Mdot
.37858 .7055 Mdot
.50145 .70835 Mdot
.37579 .40188 Mdot
.39946 .57837 Mdot
.51923 .81485 Mdot
.37745 .3979 Mdot
.36395 .58021 Mdot
.52802 .56063 Mdot
.48506 .72741 Mdot
.38328 .30375 Mdot
.47766 .83382 Mdot
.44129 .74901 Mdot
.5076 .85277 Mdot
.50934 .5086 Mdot
.37442 .6917 Mdot
.38117 .71293 Mdot
.48326 .84437 Mdot
.46825 .78699 Mdot
.3891 .30411 Mdot
.50762 .65699 Mdot
.48611 .84767 Mdot
.39471 .66326 Mdot
.43626 .71877 Mdot
.39094 .53574 Mdot
.3839 .33752 Mdot
.44125 .79866 Mdot
.38051 .62689 Mdot
.47115 .87717 Mdot
.51745 .71912 Mdot
.43018 .77572 Mdot
.39121 .76525 Mdot
.5291 .68209 Mdot
.52967 .73521 Mdot
.37084 .57511 Mdot
.52266 .71919 Mdot
.40512 .72662 Mdot
.39638 .78306 Mdot
.53294 .5532 Mdot
.45386 .75119 Mdot
.37972 .33236 Mdot
.36607 .45279 Mdot
.52321 .74302 Mdot
.51918 .53591 Mdot
.4132 .63232 Mdot
.4401 .91525 Mdot
.46339 .817 Mdot
.38939 .31155 Mdot
.43366 .01019 Mdot
.37122 .48184 Mdot
.40292 .13599 Mdot
.38403 .28024 Mdot
.51697 .49557 Mdot
.39223 .78442 Mdot
.43348 .02991 Mdot
.45039 .92809 Mdot
.42103 .07779 Mdot
.45635 .83086 Mdot
.50766 .85589 Mdot
.39939 .71783 Mdot
.37218 .62565 Mdot
.3781 .25938 Mdot
.4715 .78112 Mdot
.37002 .4707 Mdot
.48469 .83261 Mdot
.49798 .66856 Mdot
.43699 .88506 Mdot
.4182 .74839 Mdot
.42691 .86489 Mdot
.37336 .73332 Mdot
.5223 .59786 Mdot
.39972 .7016 Mdot
.39839 .6143 Mdot
.40917 .12055 Mdot
.52372 .59836 Mdot
.36785 .63068 Mdot
.41989 .06361 Mdot
.39054 .14407 Mdot
.47346 .75758 Mdot
.49848 .87464 Mdot
.44889 .84921 Mdot
.38574 .29561 Mdot
.52099 .75631 Mdot
.52235 .57976 Mdot
.51502 .54666 Mdot
.47135 .85964 Mdot
.40652 .88805 Mdot
.40056 .19323 Mdot
.53036 .62772 Mdot
.43559 .88016 Mdot
.50836 .66024 Mdot
.52074 .54649 Mdot
.47733 .91185 Mdot
.44677 .86298 Mdot
.39179 .50559 Mdot
.51612 .79539 Mdot
.44938 .79041 Mdot
.42618 .0038 Mdot
.44573 .80626 Mdot
.38473 .48514 Mdot
.50997 .68424 Mdot
.36843 .43274 Mdot
.42731 .68902 Mdot
.39342 .75707 Mdot
.38484 .44288 Mdot
.53741 .61126 Mdot
.41114 .64234 Mdot
.43446 .01916 Mdot
.37293 .68606 Mdot
.41633 .88781 Mdot
.37746 .45134 Mdot
.48459 .83885 Mdot
.4667 .86171 Mdot
.37666 .45818 Mdot
.46717 .84701 Mdot
.3704 .65398 Mdot
.3641 .33663 Mdot
.41305 .83844 Mdot
.36716 .40106 Mdot
.36657 .60877 Mdot
.37118 .69047 Mdot
.52066 .55698 Mdot
.44361 .81453 Mdot
.41339 .09694 Mdot
.38478 .77861 Mdot
.52127 .55497 Mdot
.38249 .39886 Mdot
.41017 .65804 Mdot
.4451 .86332 Mdot
.40035 .71754 Mdot
.38083 .29313 Mdot
.45289 .89312 Mdot
.37353 .5899 Mdot
.40428 .1799 Mdot
.39053 .33844 Mdot
.4303 .92278 Mdot
.38281 .524 Mdot
.40246 .12911 Mdot
.4048 .16852 Mdot
.40734 .74307 Mdot
.51331 .58627 Mdot
.39727 .1407 Mdot
.49703 .84183 Mdot
.51488 .54545 Mdot
.3836 .78552 Mdot
.41481 .83308 Mdot
.5265 .54948 Mdot
.48039 .77251 Mdot
.49713 .81704 Mdot
.46041 .78187 Mdot
.3879 .77068 Mdot
.45734 .92888 Mdot
.41649 .06514 Mdot
.37352 .70378 Mdot
.41154 .71805 Mdot
.43363 .80985 Mdot
.45272 .78844 Mdot
.48521 .80571 Mdot
.51237 .47147 Mdot
.39189 .82348 Mdot
.36605 .5658 Mdot
.43325 .71685 Mdot
.51504 .68249 Mdot
.54053 .68326 Mdot
.53558 .65868 Mdot
.36556 .63377 Mdot
.52225 .76397 Mdot
.3792 .42696 Mdot
.5019 .71915 Mdot
.4985 .77567 Mdot
.51413 .63797 Mdot
.50939 .78421 Mdot
.39531 .51747 Mdot
.50414 .76285 Mdot
.49075 .71614 Mdot
.36218 .58347 Mdot
.36718 .44459 Mdot
.49623 .41961 Mdot
.43872 .8335 Mdot
.47959 .86102 Mdot
.39042 .42577 Mdot
.40883 .6491 Mdot
.46798 .79265 Mdot
.37806 .2473 Mdot
.37859 .18807 Mdot
.4298 .85129 Mdot
.49403 .89664 Mdot
.51131 .67172 Mdot
.41417 .11486 Mdot
.42185 .07336 Mdot
.45223 .76555 Mdot
.39142 .34133 Mdot
.50869 .69944 Mdot
.52436 .55918 Mdot
.43031 .73096 Mdot
.38141 .393 Mdot
.41054 .67161 Mdot
.41937 .02983 Mdot
.51127 .66105 Mdot
.39652 .61005 Mdot
.44016 .83125 Mdot
.53393 .61085 Mdot
.50944 .64682 Mdot
.5198 .70703 Mdot
.41039 .89829 Mdot
.52985 .55776 Mdot
.40803 .84092 Mdot
.44355 .88442 Mdot
.4268 .83172 Mdot
.38802 .71195 Mdot
.39348 .28206 Mdot
.42153 .76528 Mdot
.36681 .28818 Mdot
.48462 .77112 Mdot
.40839 .89507 Mdot
.36805 .65839 Mdot
.42591 .67093 Mdot
.40262 .83737 Mdot
.42099 .72906 Mdot
.39766 .55179 Mdot
.3984 .78631 Mdot
.4076 .76282 Mdot
.49484 .79067 Mdot
.41434 .66915 Mdot
.39914 .61756 Mdot
.36005 .53608 Mdot
.39499 .61508 Mdot
.50709 .45294 Mdot
.3963 .62216 Mdot
.40848 .65908 Mdot
.52414 .51193 Mdot
.44732 .72502 Mdot
.4048 .69734 Mdot
.44361 .85276 Mdot
.51818 .60895 Mdot
.45914 .82389 Mdot
.3686 .54582 Mdot
.52102 .7597 Mdot
.39271 .63756 Mdot
.53309 .71331 Mdot
.42414 .69105 Mdot
.52181 .5598 Mdot
.51792 .58634 Mdot
.45688 .90337 Mdot
.40108 .17636 Mdot
.3828 .36301 Mdot
.48486 .79515 Mdot
.39549 .77306 Mdot
.37028 .66122 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool009?ooooo0_l00005ooooo`;o00002?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo002Cooooo`;o00001Oooool2o`0000Sooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00U_ooool2o`0000cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00U_ooool2o`0000cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002Fooooo`;o00005?ooool00ol0003oooooooooo`2iooooo`00
U_ooool2o`0001Cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00TOooool2o`0000?ooooo0_l0000Dooooo`03o`000?oooooooooo
0;Wooooo002Aooooo`;o00000oooool2o`0001Cooooo00?o0000ooooooooool0^Oooool0097ooooo
0_l0000Iooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002>ooooo`;o
00007?ooool00ol0003oooooooooo`2iooooo`00S_ooool2o`0000Cooooo0_l0000Fooooo`?o0000
^Oooool009Cooooo0_l0000Fooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002@ooooo`?o00006Oooool00ol0003o
ooooooooo`2iooooo`00T?ooool5o`0001Oooooo00?o0000ooooooooool0^Oooool008gooooo0_l0
0004ooooo`;o00005oooool00ol0003oooooooooo`2iooooo`00SOooool2o`0000?ooooo0_l0000H
ooooo`03o`000?oooooooooo0;Wooooo002Booooo`;o00006?ooool3o`000;Wooooo002<ooooo`;o
00000oooool2o`0001Wooooo00?o0000ooooooooool0^Oooool008_ooooo0ol00003ooooo`;o0000
6Oooool00ol0003oooooooooo`2iooooo`00Roooool2o`0001oooooo00?o0000ooooooooool0^Ooo
ool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool0^Oooool008[ooooo0_l00003ooooo`;o00006oooool00ol0003ooooo
ooooo`2iooooo`00R_ooool2o`0000?ooooo0_l0000Kooooo`?o0000^Oooool008gooooo0_l0000M
ooooo`03o`000?oooooooooo0;Wooooo002=ooooo`;o00007Oooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00Sooo
ool2o`0001_ooooo00?o0000ooooooooool0^Oooool008Wooooo00Kok^k^oc8b<_l0003o<S8bonk^
k_ooool2o`0000;ooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00_l00003ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0^Oooool0087ooooo1_l00002ooooo`04oa0@4?l0003o0000ooooo`?o
00002oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002iooooo`00
ROooool3o`000003ooooool0003o000000gooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`03o`000?oooooo000000;o00003_oo
ool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`2iooooo`00ROooool01Ol@413oooooo`000?l0003o410@00kooooo00?oZJVYogMgMoooool0
0oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`03ogMgMonH
V9So000000;o00002oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`2iooooo`00ROooool00oo^k^ko0000o`000002o`0000_ooooo1Ol0
0004ooooo`Co00001_ooool00ol0003oooooooooo`2iooooo`00Qoooool2o`000003ooooool0003o
0000023ooooo00?o0000ooooooooool0^Oooool008Oooooo0_l0000Sooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o
0000ooooooooool0^Oooool008_ooooo0_l0000Oooooo`03o`000?oooooooooo0;Wooooo002;oooo
o`;o00007oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
[?ooool00ol0003oooooooooo`2iooooo`00S?ooool2o`0001kooooo00?o0000ooooooooool0^Ooo
ool008cooooo0_l0000Nooooo`03o`000?oooooooooo0;Wooooo002;ooooo`;o00007oooool3o`00
0;Wooooo002;ooooo`?o00007_ooool00ol0003oooooooooo`2iooooo`00S?ooool2o`0001kooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool008?ooooo0_l0000W
ooooo`03o`000?oooooooooo0;Wooooo0023ooooo`Co00009Oooool00ol0003oooooooooo`2ioooo
o`00QOooool2o`0000Cooooo0_l0000Oooooo`03o`000?oooooooooo0;Wooooo002;ooooo`;o0000
7oooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`;o00008Oooool00ol0003o
ooooooooo`2iooooo`00ROooool2o`00027ooooo00?o0000ooooooooool0^Oooool00:cooooo00?o
0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00TOooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`2iooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0^Oooool008?ooooo0_l00004ooooo`Ko
00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`2iooooo`00Poooool2o`0000cooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo00Cooooo0ol0002iooooo`00TOooool01Ol0003ooooooooooooooooo0000
00cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;Wooooo002Aoooo
o`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0;Wooooo0022ooooo`?o00003?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`2iooooo`00P_ooool3o`0000cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00R?ooool2o`0002;ooooo00?o0000ooooooooool0^Oooool008Sooooo
0_l0000Rooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool008Gooooo0_l0000U
ooooo`03o`000?oooooooooo0;Wooooo0024ooooo`?o000000?oooooo`000?l000008_ooool00ol0
003oooooooooo`2iooooo`00Q?ooool2o`0000;ooooo0_l0000Rooooo`03o`000?oooooooooo0;Wo
oooo0020ooooo`;o0000:_ooool00ol0003oooooooooo`2iooooo`00P?ooool2o`0002[ooooo00?o
0000ooooooooool0^Oooool008Cooooo0_l0000Vooooo`03o`000?oooooooooo0;Wooooo0024oooo
o`Co00009?ooool00ol0003oooooooooo`2iooooo`00Q_ooool2o`0002Cooooo0ol0002iooooo`00
QOooool4o`0002?ooooo00?o0000ooooooooool0^Oooool008Gooooo1?l0000Sooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo0027ooooo`;o00008oooool00ol0
003oooooooooo`2iooooo`00Qoooool2o`0002?ooooo00?o0000ooooooooool0^Oooool008?ooooo
0_l0000Wooooo`03o`000?oooooooooo0;Wooooo0023ooooo`;o00009oooool00ol0003ooooooooo
o`2iooooo`00Qoooool2o`0002?ooooo0ol0002iooooo`00Qoooool2o`0002?ooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool0083ooooo0_l00002ooooo`;o0000
9_ooool00ol0003oooooooooo`2iooooo`00Ooooool3o`0000;ooooo0ol0000Uooooo`03o`000?oo
oooooooo0;Wooooo001oooooo`;o00001?ooool4o`0002?ooooo00?o0000ooooooooool0^Oooool0
08Oooooo0ol0000Rooooo`03o`000?oooooooooo0;Wooooo0028ooooo`;o00008_ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00POooool2o`0000?ooooo0_l0
000Tooooo`?o0000^Oooool0087ooooo0_l00003ooooo`;o00009?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00QOooool2o`0002Gooooo00?o0000oooooooo
ool0^Oooool008;ooooo0_l000000ooooooo0000o`000002o`0002?ooooo00?o0000ooooooooool0
^Oooool0087ooooo0ol000000ooooooo0000o`000002o`000005onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`2iooooo`00POooool2o`0000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`2iooooo`00POooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400<oooo
o`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2ioooo
o`00ROooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omg
MgOo<S8booooo`04ooooo`?o0000^Oooool0087ooooo0_l00006ooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2iooooo`00POooool2o`000003ooooool0003o000000?ooooo00Go410@oooo
oooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`2iooooo`00Q?ooool2o`0000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0;Wooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`00
0?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo0;Wooooo0024ooooo`;o00009_oo
ool00ol0003oooooooooo`2iooooo`00Q?ooool2o`0002Kooooo00?o0000ooooooooool0^Oooool0
08?ooooo0ol0000Vooooo`03o`000?oooooooooo0;Wooooo0020ooooo`Oo00009Oooool3o`000;Wo
oooo0020ooooo`Oo00009Oooool00ol0003oooooooooo`2iooooo`00P?ooool2o`000003ooooool0
003o000002Oooooo00?o0000ooooooooool0^Oooool0083ooooo0_l0000Zooooo`03o`000?oooooo
oooo0;Wooooo001nooooo`;o0000;?ooool00ol0003oooooooooo`2iooooo`00O_ooool2o`0002co
oooo00?o0000ooooooooool0^Oooool00:[ooooo0ol0002kooooo`00O_ooool3o`0002Wooooo0ol0
002kooooo`00O_ooool3o`0000Kooooo0_l0000Sooooo`?o0000^Oooool008Cooooo1Ol0000Soooo
o`03o`000?oooooooooo0;Wooooo0024ooooo`Co00009?ooool00ol0003oooooooooo`2iooooo`00
P?ooool2o`0002[ooooo00?o0000ooooooooool0^Oooool007oooooo0ol0000Zooooo`03o`000?oo
oooooooo0;Wooooo001oooooo`;o0000:oooool2o`000;[ooooo0026ooooo`;o00009?ooool2o`00
0;[ooooo001oooooo`?o00001?ooool2o`0002Cooooo00?o0000ooooooooool0^Oooool007oooooo
0ol0000Zooooo`03o`000?oooooooooo0;Wooooo001oooooo`?o000000?oooooo`000?l000009ooo
ool4o`000;Sooooo001oooooo`?o000000?oooooo`000?l000009oooool01?l0003oooooo`000?l0
002hooooo`00Poooool2o`0002Oooooo00?o0000ooooooooool0^Oooool000Wooooo1?l000000ol@
413oooooooooo`0Fooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000
onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`?o00000oooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0F
ooooo`03o`000?oooooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb
<S;ogMgM01Sooooo1?l000000ol@413oooooooooo`0Booooo`002oooool00ol0003oooooooooo`0H
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01ooo
ool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l00004ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`0Eooooo`03o`000?oooooooooo
01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Oooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B48ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo01Wooooo00?o0000oooooooo
ool05?ooool000Ko00001Oooool00ol0003oooooooooo`0@ooooo`Ko00000_ooool01Ol@413ooooo
oooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`05ooooo`Ko
00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool01Oooool6o`00
00;ooooo00Go410@oooooooooooooooooa0@4005ooooo`;o00001Oooool00onHV9So8B4Qonk^kP09
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool06?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`0=ooooo`05oa0@4?oo
ooooooooooooool@41004?ooool00ol0003oooooooooo`0=ooooo`05oa0@4?ooooooooooooooool@
41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000ko
oooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`0>ooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000001?ooool3
o`0000Kooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`0Eooooo`03o`000?oooooo
oooo01Sooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o
MgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool0
3_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo
<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo
00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00oooooo00Go0000ooooooooooooooooo`000004ooooo`;o00002?ooool00omgMgOoIVIV
ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05_ooool01?l0003oooooooooooooool2o`00
01Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Jooooo`03o`000?oooooooooo01Cooooo000;oooo
o`03o`000?oooooooooo01Sooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOo
oooo00?ooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o
0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Hooooo`?o000000?oooooo`000?l000005Oooool01Ol@413ooooo
oooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Aooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0Aooooo`05oa0@4?oooooooooo
ooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo017ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413o
oooooooooooooooo<S8b00Cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Doooo
o`002Oooool00omEEEGoIVIVo`00000Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`00
00Cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00013ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP04ooooo`;o00000oooool2o`000005oiRHV?l@413o0000ob4Q8Oo<c<`0
1?ooool4o`0001Oooooo00?o0000ooooooooool06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0
000Iooooo`03oeEEEOmVIVKo000001Kooooo0021ooooo`;o00000oooool2o`0002Cooooo00?o0000
ooooooooool0^Oooool008Kooooo0_l0000Tooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03
o`000?oooooooooo0:kooooo0_l00002ooooo`;o00001Oooool008Sooooo0_l0000Rooooo`03o`00
0?oooooooooo0:kooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd5ooooo`00R?ooool2o`0002;o
oooo00?o0000ooooooooool00_ooool2o`000:_ooooo00CogMgMo`000?l@413oc<c<1_ooool000Oo
ooooool0001<o`0000cooooo00Cok^k^ob4Q8Ol@413ok^k^1_ooool000Oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0:ooooo`04ob4Q8OmgMgOoMgMgoc8b<PKooooo0007ooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo00;ooooo0_l0000Rooooo`03o`000?oooooooooo00;o00009Oooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`09ooooo`;o00000_ooool2o`0000Gooooo0028ooooo`;o00008_ooool00ol0003ooooo
ooooo`02o`000;Oooooo0020ooooo`;o0000:_ooool00ol0003oooooooooo`02o`0000?ooooo0_l0
002booooo`00P?ooool3o`0000?ooooo0_l0000Tooooo`03o`000?oooooooooo00Cooooo0ol0002b
ooooo`00POooool2o`0000?ooooo0_l000000ooooooo0000o`00000Qooooo`03o`000?oooooooooo
00Cooooo0_l0002cooooo`00ROooool2o`00027ooooo00?o0000ooooooooool0^Oooool008Gooooo
0_l00002ooooo`;o00008Oooool3o`000003ooooool0003o00000;Kooooo0025ooooo`;o00009Ooo
ool01?l0003oooooooooooooool2o`000003ooooool0003o00000;?ooooo002/ooooo`03o`000?oo
oooooooo00Cooooo0_l0002cooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o0000/oooool0
07gooooo0_l00009ooooo`;o00008_ooool00ol0003oooooooooo`03ooooo`?o0000/oooool007go
oooo0_l00009ooooo`?o00008Oooool00ol0003oooooooooo`03ooooo`;o0000]?ooool008Wooooo
0_l0000Qooooo`03o`000?oooooooooo0;Wooooo0020ooooo`;o00001?ooool2o`0002Cooooo00Co
0000oooooooooooooooo1?l0002dooooo`00P?ooool2o`0000Cooooo0_l0000Tooooo`04o`000?oo
ooooooooooooo`Ko0000/_ooool007kooooo0_l0000:ooooo`;o00008?ooool3o`0000Gooooo0ol0
002aooooo`00O_ooool4o`0000Sooooo0_l0000Pooooo`03o`000?oooooooooo00Cooooo1Ol0002`
ooooo`00P?ooool2o`0002[ooooo00?o0000ooooooooool00oooool6o`000;3ooooo002/ooooo`03
o`000?oooooooooo00?ooooo1Ol0002aooooo`00Qoooool2o`0002?ooooo00?o0000ooooooooool0
1?ooool4o`000;7ooooo001oooooo`;o00001_ooool2o`0002?ooooo00?o0000ooooooooool0^Ooo
ool007oooooo0_l0000[ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo0021ooooo`;o00002?ooool2o`0001oooooo0ol0002iooooo`00Ooooool4o`0000Oooooo
0ol0000Oooooo`03o`000?oooooooooo00Cooooo0_l0002cooooo`00Ooooool2o`0000Wooooo0_l0
000Pooooo`03o`000?oooooooooo00Cooooo0_l0002cooooo`00O_ooool4o`0002[ooooo00?o0000
ooooooooool01?l0002eooooo`00O_ooool4o`000003ooooool0003o000002Oooooo00?o0000oooo
ooooool01?l0002eooooo`00P_ooool3o`0002Oooooo00?o0000ooooooooool0^Oooool008;ooooo
0_l0000Xooooo`03o`000?oooooooooo0;Wooooo0025ooooo`?o00009?ooool00ol0003ooooooooo
o`04ooooo`;o0000/oooool0083ooooo0_l00003ooooo`?o00009?ooool3o`0000Cooooo1?l0002a
ooooo`00P?ooool2o`0000Kooooo0_l0000Rooooo`03o`000?oooooooooo00Gooooo0ol0002aoooo
o`00R?ooool2o`0002;ooooo00?o0000ooooooooool01Oooool2o`000;;ooooo0020ooooo`;o0000
1oooool2o`00027ooooo00?o0000ooooooooool00oooool2o`000;Cooooo0020ooooo`;o00001ooo
ool2o`00027ooooo00?o0000ooooooooool00oooool2o`0000?ooooo0ol0002^ooooo`00ROooool3
o`00023ooooo00?o0000ooooooooool02?ooool3o`000:kooooo0029ooooo`?o000000?o<S8bonk^
k_ooool01?ooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`08ooooo`;o0000[oooool008Wooooo0ol000000onHV9SoMgMgooooo`04oooo
o`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`08ooooo`;o0000[oooool0087ooooo0ol00005ooooo`;o00000_ooool00ol@
413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`00
00Sooooo0_l0002_ooooo`00POooool5o`0000?ooooo00Go0000ooooooooooooooooo`00000=oooo
o`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`07oooo
o`;o0000/?ooool0083ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00000oooool00ol0
003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005
ooooo`03o`000?oooooooooo00Oooooo0_l0002`ooooo`00Ooooool3o`0000Gooooo0_l000001_l@
413ooooooooooooooooo410@ooooo`;o00003?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0^Oooool007oooooo0_l00006ooooo`?o000000GoV9RH
oooooonHV9SoMgMgooooo`02o`0000Sooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02?ooool4o`000:gooooo0028ooooo`;o000000Co
<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`04
o`000?ooooooooooooooo`;o00000_ooool2o`000003ooooool0003o000000;o0000[Oooool008ko
oooo0_l0000Looooo`04o`000?ooooooooooooooo`;o00000_ooool2o`000;;ooooo002>ooooo`;o
00007?ooool00ol0003oooooooooo`02o`000;Oooooo002=ooooo`;o00007Oooool00ol0003ooooo
ooooo`02o`000;Oooooo0023ooooo`;o00002?ooool2o`0001gooooo0ol0002iooooo`00POooool4
o`0002Oooooo00?o0000ooooooooool01?ooool4o`000;7ooooo0020ooooo`?o00002?ooool2o`00
0003ooooool0003o000001cooooo00Co0000ooooool0003o00000oooool6o`000:oooooo0020oooo
o`?o00002?ooool5o`0001cooooo00?o0000ooooool000000_l00006ooooo`;o0000[oooool0083o
oooo0ol00006ooooo`;o00000_ooool2o`0001gooooo00?o0000ooooool000000_l0002gooooo`00
ROooool2o`00027ooooo00?o0000ooooooooool0^Oooool008Wooooo0_l00004ooooo`Ko00005_oo
ool2o`000;_ooooo002>ooooo`Oo00005_ooool3o`000004ooooool0003o0000o`000;Kooooo002>
ooooo`;o00006_ooool8o`000;Kooooo002Zooooo`?o0000^oooool00:cooooo00?o0000oooooooo
ool00_ooool2o`0000;ooooo0_l00002ooooo`;o0000[Oooool008;ooooo0_l0000Xooooo`03o`00
0?oooooooooo00Co00000_ooool2o`0000;ooooo0_l0002]ooooo`00P_ooool2o`00013ooooo0_l0
000Fooooo`;o000000?oooooo`000?l00000]oooool0087ooooo0ol0000?ooooo`?o00005?ooool4
o`000;[ooooo0021ooooo`?o000000Coooooo`000?l0003ooooo0_l00009ooooo`;o00005Oooool3
o`000;_ooooo0025ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l0000Joooo
o`03o`000?oooooooooo00Kooooo0_l0002aooooo`00Qoooool2o`0000?ooooo0_l00002ooooo`;o
00006_ooool4o`0000Gooooo0_l0002aooooo`00P_ooool2o`0000?ooooo0_l000000ooooooo0000
o`00000Pooooo`04o`000?oooooo0000o`0000Gooooo0_l0002aooooo`00P_ooool3o`0000Gooooo
0_l0000Pooooo`03o`000?oooooooooo00?ooooo1Ol0002aooooo`00Poooool2o`0000Gooooo0_l0
0005ooooo`;o00000_ooool2o`0001Gooooo0_l00004ooooo`Co0000/_ooool008Cooooo0_l00000
1?oooooo0000o`000?ooool2o`0000Gooooo0_l00002ooooo`;o00005Oooool4o`000003ooooool0
003o000000?ooooo0_l0002`ooooo`00Q?ooool2o`000003ooooool0003o000000Kooooo0_l0000G
ooooo`?o000000?oooooo`000?ooool00_l000000ooooooo0000o`000003ooooo`;o0000/?ooool0
08[ooooo0ol000001?oooooo0000o`000?l00005ooooo`Go00003Oooool3o`000003ooooool0003o
000000?ooooo1?l0002cooooo`00ROooool4o`000003ooooool0003o000000Kooooo1Ol0000Aoooo
o`Co000000?oooooo`000?l000000_l0002cooooo`00QOooool2o`0000;ooooo0_l0000>ooooo`?o
00003_ooool6o`000;Sooooo0025ooooo`;o00001Oooool2o`0000cooooo0_l0000;ooooo`;o0000
00Coooooo`000?l0003o0000^oooool008Kooooo0_l00004ooooo`;o00000oooool2o`0000;ooooo
0_l0000@ooooo`;o00000oooool00ol0003oooooooooo`2iooooo`00P_ooool7o`0000Sooooo0_l0
0002ooooo`;o00005Oooool00ol0003oooooooooo`2iooooo`00P_ooool4o`000003ooooool0003o
000001Cooooo0_l0000=ooooo`03o`000?oooooooooo00Kooooo0_l0002aooooo`00S?ooool2o`00
00kooooo0ol00002ooooo`;o00002Oooool00ol0003oooooooooo`06ooooo`;o0000/Oooool008Oo
oooo1?l000001Ooooooo0000o`000?l0003ooooo00;o000000Co<S8bo`000?l0003ok^k^1Oooool0
0olQ8B7o0000o`000003ooooo`Co000000?o<S8bomgMgOooool00oooool2o`0000Kooooo0_l0002c
ooooo`00Qoooool4o`0000;ooooo0_l000001?oooooo0000o`000?nHV9P2o`000003ogMgMooooooo
oooo00?ooooo0_lQ8B400ooooooo0000o`000005ooooo`03ogMgMolb<S;ooooo00?ooooo0_l00006
ooooo`;o0000/oooool0093ooooo0ol00002ooooo`03oa0@4?oooooooooo00;o00001?ooool2o`00
00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2iooooo`00R?ooool2o`0000Go
oooo1?l00002ooooo`03o`000?oooooooooo00;o000000Coooooo`000?l0003o00001_ooool2o`00
0003oc8b<_oooooooooo00?ooooo0ol0002iooooo`00R?ooool4o`0000?ooooo0ol00003ooooo`04
o`000?ooooooooooooooo`Go00001?ooool01Ol0003o8B4Qo`000?l0003oc<c<00Gooooo00?o0000
ooooooooool01?l0002eooooo`00R?ooool4o`0000Gooooo00Go410@oooooooooooooooooa0@4003
ooooo`;o00001oooool3o`0000Oooooo00?o0000ooooooooool01Ol0002dooooo`00R?ooool4o`00
00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`?o00001oooool00ol0003oooooooooo`03
ooooo`?o0000/oooool008Kooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00;o00001Oooool2o`0000?ooooo1?l00004ooooo`Go00001?ooool2
o`000;?ooooo0023ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o00000oooool2o`00
00;ooooo0_l000000ooooooo0000o`000004o`0000Kooooo1?l000000ooooooo0000o`000004o`00
00?ooooo0_l0002cooooo`00Poooool2o`0000;ooooo0ol00004ooooo`;o00000_ooool2o`0000Go
oooo1_l00006ooooo`Co00000_ooool5o`000;Sooooo0027ooooo`Co00000oooool4o`0000Wooooo
0_l00008ooooo`?o00001?ooool3o`0000Gooooo0_l0002booooo`00ROooool2o`0000Gooooo0_l0
0003ooooo`;o00001?ooool2o`0000Kooooo1?l00004ooooo`Co00000_ooool2o`000003ooooool0
003o00000;;ooooo0026ooooo`;o000000?oooooo`000?l000002_ooool2o`0000cooooo0_l00006
ooooo`;o00001?ooool2o`000;Gooooo0026ooooo`;o000000?oooooo`000?l000004oooool2o`00
00;ooooo0_l00008ooooo`03o`000?oooooooooo0;Wooooo0025ooooo`Ko00004oooool8o`0000Ko
oooo00?o0000ooooooooool00_l00002ooooo`;o0000/oooool008Gooooo1ol0000=ooooo`;o0000
00?oooooo`000?l000000_ooool3o`000003ooooool0003o000000Kooooo1Ol00002ooooo`;o0000
/oooool008Kooooo0_l00002ooooo`;o00001Oooool2o`0000Kooooo1Ol00003ooooo`;o00001ooo
ool5o`000;Wooooo0026ooooo`;o00002Oooool2o`0000Sooooo0_l00004ooooo`;o00000oooool3
o`000003ooooool0003o000000?o0000^Oooool008_ooooo0_l0000Cooooo`?o000000?oooooo`00
0?l000000ol00003ooooo`03o`000?oooooooooo00;ooooo0_l0002eooooo`00Roooool2o`0000_o
oooo0_l00006ooooo`;o00000_ooool2o`0000Kooooo0ol00002ooooo`;o0000]Oooool008gooooo
0_l00009ooooo`;o00000oooool3o`0000cooooo0_l0002jooooo`00SOooool2o`0000Gooooo0_l0
0004ooooo`;o000000Coooooo`000?l0003o00001oooool3o`0000;ooooo0_l00004ooooo`;o0000
]?ooool008gooooo0_l00005ooooo`Co00000_ooool2o`0000_ooooo0ol00002ooooo`03o`000?oo
oooooooo00?ooooo0_l0002dooooo`00SOooool2o`0000Oooooo1?l0000Booooo`03o`000?oooooo
oooo00;o000000?oooooo`000?l00000]?ooool009Sooooo0ol0000<ooooo`Co000000Coooooo`00
0?oooooooooo0_l000000ooooooo0000o`00002dooooo`00Uoooool4o`0000Cooooo0_l00006oooo
o`Ko00001?ooool3o`000;Cooooo002Gooooo`;o00001_ooool2o`0000[ooooo0_l00004ooooo`;o
0000]Oooool008Sooooo0ol0000:ooooo`?o00001_ooool4o`0000[ooooo0ol0002iooooo`00R?oo
ool3o`0000[ooooo0ol00006ooooo`Co000000?oooooo`000?l000001oooool3o`000;Wooooo002H
ooooo`;o00000oooool2o`0000Cooooo0_l00007ooooo`?o0000^Oooool008oooooo0_l00002oooo
o`Oo00000oooool2o`0000Gooooo0_l000000ooooooo0000o`000003ooooo`03o`000?oooooooooo
0;Wooooo0029ooooo`Co00000_ooool2o`0000;ooooo1_l0000;ooooo`;o000000?oooooo`000?l0
00000oooool00ol0003oooooooooo`2iooooo`00ROooool4o`000003ooooool0003o000000;o0000
5?ooool2o`0000Cooooo00Co0000ooooool0003o0000^?ooool008gooooo1Ol0000Dooooo`;o0000
0oooool2o`000003ooooool0003o00000;Sooooo002=ooooo`;o00005oooool2o`0000?ooooo0_l0
002kooooo`00Voooool2o`0000Cooooo0_l00003ooooo`?o00000oooool00ol0003oooooooooo`2i
ooooo`00U?ooool2o`0000?ooooo1?l00004ooooo`;o00001?ooool2o`0000?ooooo1?l0002hoooo
o`00U?ooool2o`0000?ooooo0_l00008ooooo`;o00001oooool01?l0003oooooo`000?l0002hoooo
o`00Xoooool2o`0000Oooooo00Co0000ooooool0003o0000^?ooool008Wooooo0ol0000Eooooo`?o
000000Coooooo`000?l0003o00001?ooool00ol0003oooooooooo`2iooooo`00ROooool3o`0000Oo
oooo0_l00004ooooo`?o00001Oooool3o`000004ooooool0003o0000o`0000Cooooo00?o0000oooo
ooooool0^Oooool008Wooooo00?ok^k^o`000?l000000_l000000ooooooo0000o`000002ooooo`;o
00001?ooool3o`000003onk^k_l0003o000000?ooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0;Wooooo0029ooooo`03ogMgMol0003o000000;o000000?oooooo`000?l0
00000_ooool2ob4Q8@Kooooo00CoEEEEojVYZOl0003o00001_ooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo0;Wooooo0029ooooo`03oa0@4?oooooooooo00;o000000?oooooo`000?l0
00002_ooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0^Oooool008Wooooo00Go0000ooooooooooooooooo`000009ooooo`;o00000oooool01?lQ8B7o
ooooo`000?l00005ooooo`03ogMgMolb<S;ooooo00?ooooo1?l0002iooooo`00ROooool01Ol0003o
oooooooooooooooo000000Sooooo0ol00003ooooo`04oeEEEOo<c<co0000o`0000;ooooo0ol00000
0olb<S;oc<c<ooooo`03ooooo`;o0000^oooool008Wooooo00Go410@oooooooooooooooooa0@4008
ooooo`;o00001?ooool00onYZJWoMgMgooooo`03ooooo`;o00002?ooool00ol0003oooooooooo`2i
ooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo0_l00003ooooo`Co00000_ooool0
0olb<S;oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0^Oooool0
08Wooooo00Cok^k^oc8b<_l0003o<S8b0_l000000ooooooo0000o`000002o`0000?ooooo1ol00004
ooooo`Co00001_ooool00ol0003oooooooooo`2iooooo`00SOooool2o`000003ooooool0003o0000
013ooooo0_l00008ooooo`03o`000?oooooooooo0;Wooooo002=ooooo`;o00003Oooool2o`0000ko
oooo00?o0000ooooooooool0^Oooool008gooooo0ol0000<ooooo`?o000000Coooooo`000?l0003o
00001oooool3o`000;_ooooo002>ooooo`;o00000_ooool2o`0000Wooooo1_l00007ooooo`Go0000
^Oooool009;ooooo0_l00009ooooo`?o00001?ooool2o`0000Kooooo00?o0000ooooooooool0^Ooo
ool008gooooo0_l00005ooooo`;o00001oooool2o`0000Gooooo0_l00006ooooo`03o`000?oooooo
oooo0;Wooooo002=ooooo`;o00001Oooool2o`0000Cooooo0_l0000:ooooo`;o00001?ooool00ol0
003oooooooooo`2iooooo`00V_ooool3o`0000Oooooo1?l00004ooooo`03o`000?oooooooooo0;Wo
oooo002Hooooo`;o000000?oooooo`000?l000001oooool2o`0000Kooooo00?o0000ooooooooool0
^Oooool009Sooooo0_l0000Booooo`03o`000?oooooooooo0;Wooooo002@ooooo`;o00001?ooool2
o`0000[ooooo0_l00008ooooo`03o`000?oooooooooo0;Wooooo002@ooooo`;o00000oooool3o`00
0003ooooool0003o000000Oooooo0_l00008ooooo`?o0000^Oooool009Gooooo0_l00002ooooo`Co
00000oooool5o`0000Oooooo00?o0000ooooooooool0^Oooool009Wooooo1_l000000ooooooo0000
o`000003o`0000Oooooo00?o0000ooooooooool0^Oooool009Wooooo0_l00002ooooo`;o00003Ooo
ool00ol0003oooooooooo`2iooooo`00Voooool2o`0000oooooo00?o0000ooooooooool0^Oooool0
09_ooooo0_l0000?ooooo`03o`000?oooooooooo0;Wooooo002Nooooo`;o00003?ooool00ol0003o
ooooooooo`2iooooo`00W_ooool2o`0000cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o
0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002Rooooo`Co000000?o410@ooooooooool00oooool00ol0003ooooooooo
o`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo002Toooo
o`03o`000?oooooooooo00Gooooo0ol0002iooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00
Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool0
0ol0003oooooooooo`31ooooo`00X_ooool00omEEEGoIVIVo`000033ooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Z_ooool01?l@413o0000o`000?l0002j
ooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00
Zoooool01_l0003oMgMgo`000?l0003oEEEEonk^k[Oooooo002[ooooo`06o`000?mEEEGok^k^oooo
oomgMgOoEEEE]oooool00:_ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`2eoooo
o`00Zoooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo0;Gooooo002[ooooo`06o`00
0?mEEEGok^k^oooooomgMgOoIVIV]oooool00:[ooooo00?o410@o`000?mgMgL00_l000000omVIVKo
k^k^ooooo`2fooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.55236 .80566 Mdot
.58167 .77325 Mdot
.45589 .39405 Mdot
.54605 .57351 Mdot
.57963 .59173 Mdot
.56835 .75853 Mdot
.50468 .38633 Mdot
.59562 .86651 Mdot
.44767 .95659 Mdot
.56044 .56477 Mdot
.55751 .60624 Mdot
.51678 .96144 Mdot
.60839 .74751 Mdot
.56908 .49765 Mdot
.39161 .81296 Mdot
.55561 .54277 Mdot
.53734 .7742 Mdot
.61055 .74467 Mdot
.57523 .56736 Mdot
.60991 .78376 Mdot
.54235 .85285 Mdot
.53611 .84965 Mdot
.4643 .90913 Mdot
.59375 .77695 Mdot
.40293 .87456 Mdot
.59558 .57184 Mdot
.53227 .69288 Mdot
.55821 .63886 Mdot
.5848 .82565 Mdot
.54139 .83662 Mdot
.46184 .91767 Mdot
.50063 .96116 Mdot
.52017 .95023 Mdot
.49711 .84407 Mdot
.56517 .74282 Mdot
.47152 .93708 Mdot
.50076 .94531 Mdot
.5439 .67405 Mdot
.48815 .94407 Mdot
.56213 .91394 Mdot
.4853 .99629 Mdot
.54547 .77407 Mdot
.54699 .78557 Mdot
.6041 .71537 Mdot
.59493 .72603 Mdot
.58807 .57573 Mdot
.54759 .63415 Mdot
.5461 .90624 Mdot
.59477 .61142 Mdot
.51556 .91362 Mdot
.52448 .93033 Mdot
.5463 .88487 Mdot
.36056 .68025 Mdot
.5262 .81421 Mdot
.58076 .71876 Mdot
.47061 .97779 Mdot
.57249 .89591 Mdot
.56281 .72562 Mdot
.52968 .91963 Mdot
.59555 .72246 Mdot
.58002 .61731 Mdot
.44471 .99422 Mdot
.45071 .93319 Mdot
.54098 .44011 Mdot
.40726 .87105 Mdot
.5102 .95357 Mdot
.55366 .59891 Mdot
.53863 .62753 Mdot
.56529 .60343 Mdot
.57057 .81642 Mdot
.60472 .61778 Mdot
.49323 .33152 Mdot
.54639 .63137 Mdot
.55652 .57342 Mdot
.44976 .93203 Mdot
.47469 .35345 Mdot
.36016 .67495 Mdot
.5344 .74237 Mdot
.55685 .8696 Mdot
.50755 .80447 Mdot
.46385 .92592 Mdot
.52311 .86089 Mdot
.53719 .6114 Mdot
.5599 .74908 Mdot
.58021 .88128 Mdot
.55605 .43699 Mdot
.58078 .58876 Mdot
.54691 .7023 Mdot
.58293 .67512 Mdot
.53392 .64464 Mdot
.38737 .79991 Mdot
.36965 .7396 Mdot
.54173 .42142 Mdot
.58099 .60241 Mdot
.54434 .45507 Mdot
.39856 .90317 Mdot
.56862 .50307 Mdot
.45644 .96097 Mdot
.36219 .70346 Mdot
.60323 .61195 Mdot
.53871 .82865 Mdot
.59625 .6286 Mdot
.46875 .98885 Mdot
.59169 .74365 Mdot
.5381 .86675 Mdot
.5007 .84063 Mdot
.58971 .66923 Mdot
.5787 .5547 Mdot
.5412 .41715 Mdot
.54994 .84625 Mdot
.56728 .50718 Mdot
.55203 .51219 Mdot
.48751 .97082 Mdot
.57165 .83631 Mdot
.35134 .55751 Mdot
.50951 .35 Mdot
.56766 .66215 Mdot
.58068 .87508 Mdot
.55966 .89847 Mdot
.42866 .90567 Mdot
.59573 .77013 Mdot
.45484 .90617 Mdot
.60082 .80248 Mdot
.56157 .83003 Mdot
.54007 .60857 Mdot
.55056 .8666 Mdot
.40379 .91837 Mdot
.47804 .90033 Mdot
.53312 .49176 Mdot
.51548 .87919 Mdot
.52224 .85443 Mdot
.48704 .99013 Mdot
.59402 .70853 Mdot
.55225 .78017 Mdot
.59187 .81961 Mdot
.57993 .84916 Mdot
.56078 .85642 Mdot
.54243 .64393 Mdot
.47739 .98505 Mdot
.4105 .8945 Mdot
.37307 .73651 Mdot
.54829 .45299 Mdot
.57322 .56924 Mdot
.5435 .76343 Mdot
.59863 .79911 Mdot
.58013 .87918 Mdot
.34978 .54586 Mdot
.52506 .73084 Mdot
.55352 .6886 Mdot
.5574 .93901 Mdot
.6013 .60641 Mdot
.57168 .55535 Mdot
.60625 .75563 Mdot
.48788 .32303 Mdot
.51538 .84723 Mdot
.53873 .89879 Mdot
.4897 .94488 Mdot
.54808 .91402 Mdot
.47491 .9587 Mdot
.54946 .88637 Mdot
.59623 .586 Mdot
.57944 .8396 Mdot
.59106 .88708 Mdot
.45037 .91905 Mdot
.4918 .86424 Mdot
.49754 .88276 Mdot
.56939 .8916 Mdot
.55162 .85088 Mdot
.56268 .61232 Mdot
.58939 .83343 Mdot
.46946 .94081 Mdot
.53946 .58082 Mdot
.54662 .66203 Mdot
.55972 .66472 Mdot
.54753 .68157 Mdot
.46505 .98074 Mdot
.39578 .89075 Mdot
.50731 .85757 Mdot
.52909 .47254 Mdot
.54671 .87778 Mdot
.59661 .82018 Mdot
.54216 .93861 Mdot
.56099 .5131 Mdot
.48698 .99644 Mdot
.53584 .48884 Mdot
.41596 .88907 Mdot
.38512 .83653 Mdot
.55454 .90131 Mdot
.5805 .89879 Mdot
.56573 .75481 Mdot
.6046 .78961 Mdot
.54161 .47353 Mdot
.40967 .91692 Mdot
.58025 .88334 Mdot
.53402 .95622 Mdot
.48143 .99052 Mdot
.57567 .62063 Mdot
.40028 .91741 Mdot
.6025 .63901 Mdot
.52741 .47675 Mdot
.52764 .47544 Mdot
.49563 .33584 Mdot
.55966 .66179 Mdot
.39052 .88007 Mdot
.5043 .87636 Mdot
.53822 .52153 Mdot
.55699 .78084 Mdot
.54936 .43715 Mdot
.52871 .39879 Mdot
.56581 .56565 Mdot
.60681 .74415 Mdot
.54196 .72612 Mdot
.54798 .85592 Mdot
.55229 .58083 Mdot
.49041 .88997 Mdot
.53157 .7451 Mdot
.57882 .90212 Mdot
.52818 .40352 Mdot
.54481 .80987 Mdot
.57918 .89224 Mdot
.57198 .64817 Mdot
.46692 .96337 Mdot
.56315 .83365 Mdot
.44257 .90436 Mdot
.53307 .6521 Mdot
.57263 .61154 Mdot
.61032 .71643 Mdot
.54597 .52577 Mdot
.39485 .83014 Mdot
.51094 .98967 Mdot
.55569 .52137 Mdot
.48385 .34031 Mdot
.36213 .6734 Mdot
.56154 .7135 Mdot
.55499 .62555 Mdot
.54913 .65698 Mdot
.59469 .73997 Mdot
.51593 .88356 Mdot
.52994 .84302 Mdot
.42699 .96431 Mdot
.58477 .72233 Mdot
.56984 .82925 Mdot
.60436 .61889 Mdot
.54202 .91674 Mdot
.54479 .50835 Mdot
.47504 .95441 Mdot
.50847 .81512 Mdot
.60517 .61485 Mdot
.47381 .94801 Mdot
.5166 .97325 Mdot
.51227 .36063 Mdot
.53983 .53751 Mdot
.452 .94292 Mdot
.57689 .64893 Mdot
.54206 .67371 Mdot
.60871 .65277 Mdot
.4754 .35197 Mdot
.53963 .93237 Mdot
.54326 .90702 Mdot
.58417 .6526 Mdot
.55583 .62224 Mdot
.45082 .91743 Mdot
.53041 .45699 Mdot
.58735 .65328 Mdot
.52863 .83832 Mdot
.53417 .67665 Mdot
.50099 .85933 Mdot
.45924 .93292 Mdot
.55712 .7058 Mdot
.5234 .89847 Mdot
.59032 .69934 Mdot
.5651 .51912 Mdot
.55095 .72968 Mdot
.55423 .87952 Mdot
.56193 .48209 Mdot
.58375 .53521 Mdot
.51397 .94288 Mdot
.57034 .51919 Mdot
.54177 .80781 Mdot
.55792 .86516 Mdot
.51422 .3532 Mdot
.54203 .63227 Mdot
.45901 .95226 Mdot
.48826 .98582 Mdot
.58041 .54302 Mdot
.49358 .33855 Mdot
.51751 .75276 Mdot
.5955 .79797 Mdot
.56539 .65905 Mdot
.45238 .91458 Mdot
.37701 .78647 Mdot
.49349 .95706 Mdot
.41113 .89349 Mdot
.4467 .94473 Mdot
.47678 .32847 Mdot
.559 .88265 Mdot
.38136 .78299 Mdot
.60201 .78437 Mdot
.3945 .827 Mdot
.34912 .54544 Mdot
.56884 .68731 Mdot
.61002 .65589 Mdot
.54071 .82948 Mdot
.52493 .93567 Mdot
.44343 .97513 Mdot
.55461 .61027 Mdot
.49131 .96471 Mdot
.58047 .63975 Mdot
.52551 .46881 Mdot
.58496 .78233 Mdot
.54503 .76206 Mdot
.57813 .79794 Mdot
.5498 .94581 Mdot
.52144 .39786 Mdot
.53668 .82375 Mdot
.51667 .81823 Mdot
.4064 .86952 Mdot
.52307 .39836 Mdot
.52701 .95518 Mdot
.39165 .83505 Mdot
.41557 .94578 Mdot
.54661 .58532 Mdot
.60836 .67471 Mdot
.57406 .7214 Mdot
.44969 .93395 Mdot
.58352 .55631 Mdot
.51426 .37976 Mdot
.49372 .34938 Mdot
.58377 .68259 Mdot
.58615 .88173 Mdot
.42413 .8914 Mdot
.54145 .42772 Mdot
.58324 .78257 Mdot
.53245 .46024 Mdot
.49934 .34652 Mdot
.60687 .72442 Mdot
.57849 .73812 Mdot
.49422 .86209 Mdot
.59427 .59539 Mdot
.55453 .67444 Mdot
.37723 .8205 Mdot
.55955 .69718 Mdot
.49129 .89736 Mdot
.54367 .48424 Mdot
.48337 .97987 Mdot
.52801 .70174 Mdot
.55172 .86736 Mdot
.48204 .90604 Mdot
.54192 .41126 Mdot
.52025 .76282 Mdot
.3788 .78104 Mdot
.53862 .93799 Mdot
.58553 .84816 Mdot
.48548 .93642 Mdot
.58286 .64594 Mdot
.5827 .69238 Mdot
.48715 .93842 Mdot
.57742 .6781 Mdot
.53175 .94529 Mdot
.57092 .82843 Mdot
.47673 .99224 Mdot
.52237 .96053 Mdot
.54003 .94645 Mdot
.50345 .35698 Mdot
.56217 .70968 Mdot
.40034 .85621 Mdot
.55885 .91117 Mdot
.50326 .35497 Mdot
.47293 .92579 Mdot
.5241 .76913 Mdot
.57841 .74282 Mdot
.54045 .82531 Mdot
.45021 .95593 Mdot
.5901 .74844 Mdot
.51666 .92994 Mdot
.42042 .87804 Mdot
.45801 .90378 Mdot
.597 .83047 Mdot
.50018 .89731 Mdot
.40972 .89696 Mdot
.35311 .62389 Mdot
.41782 .87823 Mdot
.54554 .80432 Mdot
.50782 .38627 Mdot
.41338 .91713 Mdot
.59386 .64209 Mdot
.49311 .34873 Mdot
.56084 .91865 Mdot
.56919 .81891 Mdot
.50629 .34948 Mdot
.55479 .58689 Mdot
.58405 .6173 Mdot
.55254 .63663 Mdot
.55624 .89532 Mdot
.60431 .77087 Mdot
.39272 .84956 Mdot
.54268 .93855 Mdot
.53837 .7779 Mdot
.35948 .6527 Mdot
.56084 .73853 Mdot
.55403 .66308 Mdot
.57028 .61298 Mdot
.46631 .34451 Mdot
.56947 .90101 Mdot
.51297 .96505 Mdot
.53413 .68775 Mdot
.54804 .48249 Mdot
.57383 .48326 Mdot
.55905 .45868 Mdot
.52821 .96555 Mdot
.58784 .56397 Mdot
.47978 .93408 Mdot
.54956 .51915 Mdot
.5688 .57575 Mdot
.52932 .43797 Mdot
.58307 .58421 Mdot
.49605 .84417 Mdot
.56928 .56285 Mdot
.53877 .52019 Mdot
.51771 .98098 Mdot
.48623 .98275 Mdot
.45286 .42472 Mdot
.56817 .73849 Mdot
.58844 .67268 Mdot
.47709 .88537 Mdot
.52231 .77383 Mdot
.5578 .62778 Mdot
.4408 .97792 Mdot
.42776 .98844 Mdot
.57381 .7792 Mdot
.35314 .59009 Mdot
.61304 .69754 Mdot
.54 .47172 Mdot
.40408 .84892 Mdot
.39336 .82435 Mdot
.54659 .6476 Mdot
.45844 .89926 Mdot
.37052 .77494 Mdot
.54847 .49944 Mdot
.50804 .35918 Mdot
.5384 .70587 Mdot
.47189 .93178 Mdot
.52722 .76989 Mdot
.38439 .84463 Mdot
.53569 .46105 Mdot
.51613 .82661 Mdot
.56748 .73243 Mdot
.53827 .41085 Mdot
.52817 .44682 Mdot
.56261 .50703 Mdot
.58901 .875 Mdot
.51296 .35776 Mdot
.57217 .84821 Mdot
.5854 .76391 Mdot
.56786 .77595 Mdot
.5416 .87702 Mdot
.44506 .90306 Mdot
.5491 .75682 Mdot
.55645 .58002 Mdot
.58814 .87971 Mdot
.53327 .95614 Mdot
.52384 .70265 Mdot
.57179 .86649 Mdot
.53945 .74263 Mdot
.50304 .82677 Mdot
.55843 .85831 Mdot
.55065 .81108 Mdot
.57147 .59159 Mdot
.52583 .75274 Mdot
.51724 .81494 Mdot
.50775 .99529 Mdot
.51759 .83346 Mdot
.45952 .36956 Mdot
.51889 .82775 Mdot
.5247 .77678 Mdot
.48906 .31881 Mdot
.53447 .6378 Mdot
.53459 .80066 Mdot
.57472 .73859 Mdot
.52176 .40895 Mdot
.56692 .6747 Mdot
.50803 .95608 Mdot
.58489 .5597 Mdot
.52316 .84452 Mdot
.57842 .51331 Mdot
.52914 .71585 Mdot
.50573 .3598 Mdot
.35791 .6883 Mdot
.51246 .38634 Mdot
.59483 .74889 Mdot
.42034 .89276 Mdot
.46504 .93221 Mdot
.56594 .60304 Mdot
.55546 .86474 Mdot
.53344 .94654 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0^Oooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1Oooool00ol0003oooooooooo`2iooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`2iooooo`00POooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVY
ZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000;Wooooo0029ooooo`05o`000?oo
ooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0^Oooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEE
EOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;Wo
oooo0029ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0^Oooool008Wooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo0;Wooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`00
00Cooooo1?l00006ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Ooo
ool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`00
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool0097ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo
00?o0000ooooooooool0^Oooool0097ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`Ko00000_oo
ool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2iooooo`00TOooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool0
1?ooool3o`000;Wooooo002Aooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0^Oooool0097ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0^Oooool0097ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0^Oooool0097ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:Sooooo0_l00002ooooo`03o`000?oooooo
oooo0;Wooooo002Xooooo`;o00000_ooool00ol0003oooooooooo`2iooooo`00Z?ooool2o`0000;o
oooo0ol0002iooooo`00Y?ooool2o`0000;ooooo0_l00002ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`;o00000oooool2o`000003ooooool0003ooooo0;[ooooo002Yooooo`;o000000?ooooo
o`000?ooool0^_ooool00:[ooooo0ol0002kooooo`00Y_ooool2o`000003ooooool0003o000000;o
0000^oooool00:Kooooo0_l000001Ooooooo0000o`000?oooooo00000;_ooooo002Pooooo`;o0000
2Oooool2o`000;_ooooo002Pooooo`;o00001oooool4o`000004ooooool0003o0000o`000;Oooooo
002Sooooo`;o00001?ooool2o`000003ooooool0003o000000?o0000]oooool00:?ooooo0_l00007
ooooo`?o000000?oooooo`000?l00000]_ooool00:?ooooo0_l00007ooooo`?o000000?oooooo`00
0?l00000]_ooool00:cooooo1_l0002fooooo`00[?ooool6o`000;Kooooo0029ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01Oooool00ol0003oooooooooo`2iooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00_l00005ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0^Oooool0087ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003?ooool01?nHV9So8B4Qonk^k_ooool2o`0000Kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`2iooooo`00ROooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000^Oooool008Wooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`04o`000?ooooooooooooooo`;o0000]_ooool008Wooooo00Go410@oooooooooooooooo
oa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool01?l0003ooooo
ooooooooool2o`000;Kooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o
^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool6o`000;Kooooo0029ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006
ooooo`Ko0000]_ooool00:cooooo00?o0000ooooooooool0^Oooool009gooooo0_l0000=ooooo`03
o`000?oooooooooo0;Wooooo002Mooooo`;o00003Oooool00ol0003oooooooooo`04ooooo`;o0000
/oooool00:cooooo0ol00004ooooo`Co0000/Oooool00:cooooo00?o0000ooooooooool01_ooool2
o`000;7ooooo002/ooooo`03o`000?oooooooooo00Kooooo0_l0002aooooo`00[?ooool00ol0003o
ooooooooo`04ooooo`;o0000/oooool00:cooooo00?o0000ooooooooool01?ooool2o`0000?ooooo
0ol0002]ooooo`00[?ooool00ol0003oooooooooo`09ooooo`?o0000[Oooool00:cooooo00?o0000
ooooooooool02_ooool2o`000:gooooo002/ooooo`03o`000?oooooooooo00[ooooo0_l0002]oooo
o`00W?ooool2o`0000kooooo0ol0000:ooooo`;o0000[Oooool009cooooo0_l0000>ooooo`03o`00
0?oooooooooo00[ooooo0_l0002]ooooo`00[?ooool00ol0003oooooooooo`0:ooooo`;o0000[Ooo
ool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool03Oooool4o`00
0:Sooooo002/ooooo`03o`000?oooooooooo00Kooooo0_l00002ooooo`;o000000?oooooo`000?l0
00000_l0002Xooooo`00[?ooool00ol0003oooooooooo`06ooooo`;o00000_ooool2o`000:gooooo
002/ooooo`03o`000?oooooooooo00Kooooo0_l0002aooooo`00[?ooool00ol0003oooooooooo`06
ooooo`;o0000/Oooool00:cooooo0ol0000=ooooo`;o0000Z_ooool00:cooooo00?o0000oooooooo
ool02oooool4o`000:[ooooo002/ooooo`03o`000?oooooooooo00Oooooo0_l00002ooooo`;o0000
0oooool2o`000:Oooooo0009ooooo`Co000000?o410@ooooooooool05_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o
<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0
0004ooooo`05odA4A?l0003o0000oc8b<_oMgMd05_ooool00ol0003oooooooooo`07ooooo`?o0000
1_ooool2o`0000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM01So
oooo1?l000000ol@413oooooooooo`0Booooo`002oooool00ol0003oooooooooo`0Hooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo
<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01oooool00omgMgOo<S8booooo`0Eooooo`03o`000?oooooooooo00Oooooo0ol0
000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A007ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`0Iooooo`03o`000?oooooo
oooo01Cooooo0006o`0000Gooooo00?o0000ooooooooool04?ooool6o`0000;ooooo00Go410@oooo
oooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool01Oooool6
o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00Gooooo1_l0
0002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool06?ooool01Ol@413ooooooooooooooooo410@00co
oooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`0=ooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol0003oooooooooo`0=ooooo`05oa0@4?ooooooooooooooool@41003Oooool0
0onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05?ooool0
00_ooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Q
ooooooooool01_ooool00omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003ooo
ool00omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Q
onk^kP07ooooo`03ogMgMolb<S;ooooo01Gooooo00?o0000ooooooooool01Oooool2o`00017ooooo
00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_oo
ool03_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0
003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`0I
ooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00?ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oo
oooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c00Fooooo`03o`000?oooooooooo00Gooooo0ol00002ooooo`;o00003?ooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`03oooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<01[ooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000
ooooooooool06?ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00ooo
ool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo01Sooooo0ol00006ooooo`;o00000_ooool2o`0000cooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04Oooool01Ol@
413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooo
oooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`0Aooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`06ooooo`;o00004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0<ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo01Cooooo0009ooooo`03oeEEEOmVIVKo000001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`Go00001?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00004?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co
00005oooool00ol0003oooooooooo`0<ooooo`;o00000oooool2o`0000;ooooo0_l000001_oooooo
k^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00004?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool5o`0000Cooooo1?l0000Iooooo`03oeEEEOmVIVKo000001Kooooo002/ooooo`03o`00
0?oooooooooo00_ooooo0ol00003ooooo`;o00000_ooool2o`000:;ooooo002/ooooo`03o`000?oo
oooooooo00Sooooo0_l000000ooooooo0000o`00002/ooooo`00[?ooool00ol0003oooooooooo`07
ooooo`?o0000Y?ooool2o`0000;ooooo0_l00005ooooo`00[?ooool00ol0003oooooooooo`07oooo
o`;o0000YOooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Gooooo002/ooooo`03o`000?oooooo
oooo01?ooooo0_l0002Jooooo`04omgMgOl0003o410@olc<c0Kooooo0007oooooooo0000C?l0000<
ooooo`04onk^k_lQ8B7o410@onk^kPKooooo0007ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo0_l00004
ooooo`;o000000?oooooo`000?ooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00[ooooo00Co8B4QogMgMomgMgOo<S8b1_ooool000Oooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0Aooooo`Co00004_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`09ooooo`;o00000_ooool2
o`0000Gooooo002/ooooo`03o`000?oooooooooo00_ooooo0_l00004ooooo`Co0000Y?ooool00:co
oooo00?o0000ooooooooool02oooool2o`000004ooooool0003o0000ooooo`;o00000oooool2o`00
0:7ooooo002/ooooo`03o`000?oooooooooo00kooooo0_l000000ooooooo0000o`000003ooooo`;o
0000XOooool00:cooooo00?o0000ooooooooool03Oooool2o`0000?ooooo1?l0002Sooooo`00[?oo
ool00ol0003oooooooooo`09ooooo`;o00000_ooool4o`000003ooooool0003o000000;o0000Xooo
ool00:cooooo0ol00009ooooo`;o00001?ooool2o`000:Sooooo002/ooooo`03o`000?oooooooooo
00cooooo0_l0002[ooooo`00[?ooool00ol0003oooooooooo`0<ooooo`;o0000Zoooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool02_ooool2o`0000cooooo0_l0
002Oooooo`00[?ooool00ol0003oooooooooo`0:ooooo`;o00003?ooool2o`0009oooooo002/oooo
o`03o`000?oooooooooo00oooooo0_l00006ooooo`;o0000X?ooool007[ooooo0_l0000`ooooo`03
o`000?oooooooooo00oooooo0_l00006ooooo`;o0000X?ooool007[ooooo0_l0000`ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool05?ooool2
o`000003ooooool0003o00000:3ooooo001jooooo`;o0000<?ooool00ol0003oooooooooo`0Doooo
o`;o000000Coooooo`000?l0003o0000Woooool007[ooooo0_l0000`ooooo`03o`000?oooooooooo
01Sooooo0ol0002Nooooo`00[?ooool00ol0003oooooooooo`0Aooooo`Co00001?ooool3o`0009go
oooo002/ooooo`03o`000?oooooooooo017ooooo1_l00003ooooo`;o0000WOooool00:cooooo00?o
0000ooooooooool04_ooool2o`000003ooooool0003o00000:;ooooo002/ooooo`03o`000?oooooo
oooo00cooooo0_l000000ooooooo0000o`000004ooooo`;o00001Oooool2o`0009_ooooo002/oooo
o`?o00003?ooool2o`000003ooooool0003o000000;ooooo0_l00005ooooo`Co0000Voooool00:co
oooo00?o0000ooooooooool03oooool2o`0000;ooooo0_l00005ooooo`;o0000WOooool00:cooooo
00?o0000ooooooooool02_ooool2o`0000;ooooo0ol0002Xooooo`00[?ooool00ol0003ooooooooo
o`0:ooooo`Ko00002?ooool2o`0000;ooooo0_l0002Kooooo`00[?ooool00ol0003oooooooooo`0<
ooooo`;o000000?oooooo`000?l000001_ooool3o`0000;ooooo0_l0002Kooooo`00Noooool2o`00
02oooooo00?o0000ooooooooool03oooool2o`0000?ooooo0_l000000ooooooo0000o`00002Poooo
o`00Noooool2o`0002oooooo00?o0000ooooooooool05?ooool2o`000003ooooool0003o000000?o
oooo0_l0002Kooooo`00[?ooool00ol0003oooooooooo`0Looooo`;o0000Voooool00:cooooo0ol0
000>ooooo`;o0000ZOooool00:cooooo00?o0000ooooooooool03_ooool2o`0000;ooooo0_l00003
ooooo`;o0000X?ooool00:cooooo00?o0000ooooooooool04?ooool4o`0000?ooooo0_l00005oooo
o`;o0000VOooool00:cooooo00?o0000ooooooooool02_ooool2o`0000?ooooo0ol0000<ooooo`;o
0000VOooool00:cooooo00?o0000ooooooooool02Oooool3o`0000?ooooo1?l000001?oooooo0000
o`000?l00005ooooo`;o000000?oooooo`000?l00000V?ooool00:cooooo00?o0000ooooooooool0
2Oooool2o`0000Kooooo0_l000001?oooooo0000o`000?l00005ooooo`;o000000?oooooo`000?l0
0000V?ooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01Oooooo0ol00005oooo
o`;o0000V?ooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnH
V9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0?
ooooo`;o00001Oooool4o`0000Gooooo0_l0002Hooooo`00Noooool2o`0000cooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3
o`0000oooooo0_l00005ooooo`;o0000XOooool007_ooooo0_l0000<ooooo`05o`000?oooooooooo
ooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool02Oooool2o`0000Cooooo0ol0000:ooooo`;o0000Voooool008Wooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo00Wooooo0_l000000ooooooo0000o`000002ooooo`;o00002_oo
ool2o`0009_ooooo0029ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool4o`000:_ooooo0029
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`So0000ZOooool008Wooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Ko
oooo00?o0000ooooooooool02?ooool2o`0000Cooooo1?l00005ooooo`;o00001Oooool2o`0009Wo
oooo002/ooooo`03o`000?oooooooooo013ooooo0_l00005ooooo`;o00000oooool4o`0009Wooooo
002/ooooo`03o`000?oooooooooo00Sooooo0_l000000ooooooo0000o`00000;ooooo`;o00000_oo
ool2o`0009_ooooo002/ooooo`03o`000?oooooooooo00Sooooo0_l000001?oooooo0000o`000?l0
0006ooooo`Ko0000Woooool007gooooo0_l0000]ooooo`?o00001oooool2o`0000?ooooo0_l00006
ooooo`Ko00001_ooool2o`0009Oooooo001mooooo`;o0000;Oooool00ol0003oooooooooo`07oooo
o`;o00003oooool3o`0000Gooooo0ol0002Fooooo`00[?ooool00ol0003oooooooooo`0=ooooo`;o
00002_ooool2o`0000Kooooo0_l0002Fooooo`00[?ooool00ol0003oooooooooo`0<ooooo`?o0000
00?oooooo`000?l000000_l0002Uooooo`00[?ooool00ol0003oooooooooo`0<ooooo`Wo0000Y?oo
ool00:cooooo00?o0000ooooooooool03_ooool4o`000003ooooool0003o00000:Cooooo002/oooo
o`03o`000?oooooooooo01[ooooo0_l0002Mooooo`00O_ooool2o`0002cooooo00?o0000oooooooo
ool02_ooool3o`0000gooooo0_l0002Mooooo`00OOooool3o`0002cooooo0ol00008ooooo`Go0000
0_ooool2o`0000;ooooo0_l00003ooooo`Co00001?ooool2o`0009Oooooo001mooooo`;o0000;Ooo
ool00ol0003oooooooooo`08ooooo`;o00001Oooool2o`0000;ooooo0_l000000ooooooo0000o`00
0002o`0000Kooooo0_l0002Gooooo`00O_ooool2o`0002cooooo00?o0000ooooooooool03?ooool2
o`0000Sooooo1?l0002Oooooo`00O_ooool2o`0002cooooo00?o0000ooooooooool03?ooool2o`00
00[ooooo0_l0002Oooooo`00OOooool2o`0002gooooo00?o0000ooooooooool02?ooool2o`0000Co
oooo0_l00003ooooo`;o0000Y?ooool007gooooo0_l0000]ooooo`03o`000?oooooooooo00Sooooo
0_l00004ooooo`;o00000oooool2o`000:Cooooo002/ooooo`03o`000?oooooooooo00Oooooo0_l0
000?ooooo`;o0000Woooool00:cooooo00?o0000ooooooooool01oooool2o`0000Oooooo0_l00006
ooooo`;o00002?ooool2o`0009Gooooo002/ooooo`?o00004?ooool2o`0000Sooooo0_l00006oooo
o`;o0000UOooool007kooooo0_l0000/ooooo`03o`000?oooooooooo00Cooooo1?l00004ooooo`;o
00003?ooool2o`0009gooooo001nooooo`;o0000;?ooool00ol0003oooooooooo`04ooooo`Co0000
00Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00002Xooooo`00[?ooool00ol0003ooooo
ooooo`09ooooo`;o00001?ooool4o`0000Wooooo0_l0002Kooooo`00[?ooool00ol0003ooooooooo
o`0Aooooo`;o00002Oooool2o`0009_ooooo002/ooooo`03o`000?oooooooooo00Kooooo0_l00009
ooooo`;o00003?ooool4o`0009Kooooo002/ooooo`03o`000?oooooooooo00Kooooo0_l0000?oooo
o`;o00001_ooool4o`0009Kooooo002/ooooo`03o`000?oooooooooo01Gooooo1_l000000ooooooo
0000o`00002Kooooo`00[?ooool3o`00017ooooo0_l00002ooooo`;o00000_ooool2o`000003oooo
ool0003o000000;ooooo0_l0002Gooooo`00[?ooool00ol0003oooooooooo`0:ooooo`;o00001Ooo
ool2o`0000Wooooo0_l00002ooooo`;o0000Uoooool00:cooooo00?o0000ooooooooool01Oooool2
o`0000?ooooo0_l000000ooooooo0000o`00000=ooooo`;o0000Voooool00:cooooo00?o0000oooo
ooooool01Oooool2o`0000Kooooo0_l00004ooooo`;o0000Y?ooool008;ooooo0_l0000Xooooo`03
o`000?oooooooooo01?ooooo0_l0002Tooooo`00POooool3o`0002Sooooo00?o0000ooooooooool0
4Oooool7o`0000Cooooo0_l0002Kooooo`00POooool2o`0000kooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooooooo
ool02?ooool4o`0000Gooooo1ol00003ooooo`?o0000Voooool0097ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00Oo
oooo1Ol00006ooooo`;o00000_ooool2o`0000?ooooo0_l00003ooooo`?o0000U_ooool0097ooooo
00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01oooool2o`0000Oooooo0_l00008ooooo`Co00000_ooool3o`0009Kooooo002Aooooo`05o`00
0?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`?o00000_ooool2o`000003
ooooool0003o000000Wooooo0_l00008ooooo`Co00000_ooool2o`0009Oooooo002Aooooo`05o`00
0?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool00_ooool2o`000003ooooool0003o000000_ooooo0_l0000<ooooo`;o0000Uoooool0097o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool03Oooool2o`0000?ooooo0ol0000;ooooo`;o0000Uoooool0097ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03Oooool2o`00
00Cooooo0_l0002Tooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006oooo
o`03o`000?oooooooooo00?ooooo0_l00006ooooo`;o00003?ooool2o`0009kooooo002/ooooo`03
o`000?oooooooooo00?ooooo0_l00006ooooo`;o00003?ooool2o`0009kooooo002/ooooo`03o`00
0?oooooooooo00Gooooo0ol0000Dooooo`;o000000?oooooo`000?l00000V?ooool00:cooooo00?o
0000ooooooooool01?ooool4o`0000Cooooo0_l0000:ooooo`;o00000_ooool2o`000003ooooool0
003o000009Sooooo0021ooooo`;o0000:Oooool3o`0000Cooooo0ol00002ooooo`;o000000?ooooo
o`000?l000001Oooool2o`0000?ooooo0_l00002ooooo`;o0000Voooool0087ooooo0_l0000Yoooo
o`03o`000?oooooooooo00Gooooo0_l00002ooooo`;o00000oooool2o`0000?ooooo1?l00005oooo
o`;o0000Voooool008Cooooo0_l0000Vooooo`03o`000?oooooooooo00Wooooo0_l00003ooooo`?o
00001?ooool2o`000004ooooool0003o0000o`0009kooooo0024ooooo`;o00009_ooool00ol0003o
ooooooooo`0<ooooo`;o000000?oooooo`000?l000001oooool3o`0000?ooooo0_l000000ooooooo
0000o`00002Fooooo`00Poooool2o`0002Oooooo00?o0000ooooooooool03?ooool2o`00013ooooo
0_l000000ooooooo0000o`00002Fooooo`00Poooool2o`0002Oooooo00?o0000ooooooooool07ooo
ool2o`0009Sooooo002/ooooo`03o`000?oooooooooo01oooooo0_l0002Hooooo`00[?ooool00ol0
003oooooooooo`0Fooooo`;o00001?ooool2o`0009_ooooo0026ooooo`;o00009?ooool3o`0000So
oooo0_l0000<ooooo`;o00001?ooool3o`0009[ooooo0026ooooo`;o00009?ooool00ol0003ooooo
ooooo`08ooooo`;o00000_ooool2o`0000oooooo0ol0002Iooooo`00[?ooool01?l0003oooooo`00
0?l0000;ooooo`Co00003_ooool2o`0009Wooooo002/ooooo`04o`000?oooooo0000o`0000Wooooo
0ol000000ooooooo0000o`00002Yooooo`00R?ooool2o`0002;ooooo00?o0000ooooooooool02_oo
ool5o`000:[ooooo0028ooooo`;o00008_ooool01Ol0003oooooo`000?l0003ooooo00;o000000?o
ooooo`000?l000001_ooool2o`0000Gooooo0_l0002Sooooo`00[?ooool01Ol0003oooooo`000?l0
003ooooo00;o000000?oooooo`000?l000003?ooool3o`000:?ooooo0023ooooo`;o00009oooool0
0ol0003oooooooooo`02ooooo`;o00003oooool2o`0000Kooooo0ol0002Kooooo`00Poooool2o`00
00?ooooo0_l0000Rooooo`?o00002Oooool3o`0000gooooo1Ol0002Kooooo`00R?ooool3o`00027o
oooo0ol00002ooooo`?o00001?ooool3o`0000Sooooo0_l00003ooooo`;o0000W_ooool008Wooooo
0_l0000Qooooo`?o00000_ooool3o`0000Cooooo0ol00005ooooo`;o000000?oooooo`000?l00000
1oooool2o`0009[ooooo0029ooooo`;o00008Oooool00ol0003oooooooooo`02ooooo`;o00001_oo
ool2o`0000Gooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l00000V_oo
ool008Kooooo1?l0000Rooooo`03o`000?oooooooooo00;ooooo0_l00006ooooo`;o00001Oooool2
o`000003ooooool0003o000000Cooooo0_l0002Mooooo`00Q_ooool4o`0002;ooooo0_l00007oooo
o`;o00000_ooool2o`0000Sooooo0_l000000ooooooo0000o`00002Pooooo`00[?ooool2o`0000Oo
oooo0_l0000?ooooo`;o0000X?ooool008Gooooo0_l0000Sooooo`?o00001_ooool4o`0000Gooooo
0_l0002Zooooo`00QOooool2o`000003ooooool0003o000000;ooooo0_l0000Looooo`?o00001?oo
ool4o`0000;ooooo0_l00003ooooo`;o00001Oooool2o`000003ooooool0003o000000;o0000W_oo
ool008Sooooo0_l00002ooooo`;o00007_ooool3o`0000;ooooo0_l00004ooooo`;o000000Cooooo
o`000?l0003ooooo0_l00004ooooo`;o000000?oooooo`000?l000000_l0002Nooooo`00[?ooool0
0ol0003oooooooooo`04ooooo`;o00001Oooool5o`000:Wooooo002;ooooo`;o00007oooool01?l0
003oooooo`000?l00003ooooo`;o00001_ooool2o`0000;ooooo0ol0002Vooooo`00Roooool2o`00
01oooooo1?l00003ooooo`;o00002_ooool3o`000:Kooooo002Yooooo`Go00001Oooool2o`0000Wo
oooo0_l0002Xooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03
o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`Co00002oooool2o`00
00;ooooo1Ol00002ooooo`;o00001_ooool2o`0009_ooooo0029ooooo`04ogMgMonHV9SooooooiRH
V0;o00001?ooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo00Wooooo0_l00002ooooo`Go00000_ooool2o`0000Kooooo0_l0002Koooo
o`00ROooool01?l@413oooooooooooooool2o`0000cooooo00?oZJVYoeEEEOooool02?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00oooooo0_l0002Xooooo`00ROooool00ol0003o
ooooooooo`02o`0000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`?o
00002_ooool2o`0000_ooooo0_l000000ooooooo0000o`00002Mooooo`00Qoooool3o`0000;ooooo
0_l00002ooooo`?o00002Oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool3o`0000;ooooo0_l00006ooooo`Ko00001oooool2o`000003ooooool0003o000009go
oooo0027ooooo`;o000000Go410@oooooooooooooooooa0@4002ooooo`?o00002Oooool00onYZJWo
MgMgooooo`03ooooo`03o`000?oooooooooo00Kooooo0_l00004ooooo`;o00002?ooool6o`0000Go
oooo1Ol0002Mooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooo
oooooooooc8b<P04ooooo`04o`000?oooooo0000o`0000Gooooo0_l00004ooooo`;o00002?ooool2
o`0000;ooooo0_l00005ooooo`Co0000W_ooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02
ooooo`;o00001oooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo00;ooooo0_l00008
ooooo`?o00002?ooool2o`0000;ooooo0_l0002Looooo`00ROooool2o`0000Gooooo0_l000000ooo
oooo0000o`00000Cooooo`;o00000_ooool00ol0003oooooooooo`0=ooooo`;o00001?ooool2o`00
00;ooooo0_l00002ooooo`;o0000W?ooool008Wooooo0_l00003ooooo`;o000000?oooooo`000?l0
00000_l0000Cooooo`;o00000_ooool00ol0003oooooooooo`0?ooooo`;o00000_ooool2o`0000;o
oooo0_l0002Pooooo`00S_ooool2o`000003ooooool0003o000001Kooooo0_l000000ooooooo0000
o`00000@ooooo`;o00000oooool2o`000:?ooooo002>ooooo`;o00003_ooool2o`0000Cooooo0_l0
0003ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`0000?ooooo0_l00004ooooo`?o0000
00Goooooo`000?l0003o0000ooooo`02o`000:3ooooo002:ooooo`;o00003Oooool2o`0000?ooooo
0_l00004ooooo`;o00001_ooool00ol0003oooooooooo`04ooooo`;o00000oooool2o`0000Cooooo
0ol000000ooooooo0000o`000002ooooo`;o0000X?ooool008[ooooo0_l00008ooooo`;o00000ooo
ool2o`0000;ooooo0ol00006ooooo`;o00001?ooool00ol0003oooooooooo`0;ooooo`?o00002Ooo
ool2o`000:3ooooo002Dooooo`;o00001oooool2o`000003ooooool0003o000000Cooooo0_l00004
ooooo`03o`000?oooooooooo00_ooooo0ol0002[ooooo`00X?ooool2o`0000[ooooo00?o0000oooo
ooooool04?ooool2o`000:Oooooo002Looooo`;o00003_ooool00ol0003oooooooooo`02ooooo`;o
00002?ooool2o`0000;ooooo0ol0002Vooooo`00Roooool6o`0000[ooooo0ol000000ooooooo0000
o`00000;ooooo`03o`000?oooooooooo00;ooooo0_l00006ooooo`Co00000oooool2o`000:Kooooo
002;ooooo`Ko00002_ooool2o`0000;ooooo0_l0000;ooooo`03o`000?oooooooooo00Kooooo0_l0
0002ooooo`;o00001Oooool2o`000:Kooooo002/ooooo`?o00001_ooool2o`000;7ooooo002Poooo
o`;o000000?oooooo`000?l000001oooool00ol0003oooooooooo`2iooooo`00X?ooool2o`000003
ooooool0003o000000Oooooo00?o0000ooooooooool00_ooool2o`000003ooooool0003o00000;;o
oooo002Kooooo`;o000000?oooooo`000?l000001?l000000ooooooo0000o`000005ooooo`03o`00
0?oooooooooo00;ooooo0_l000000ooooooo0000o`000003ooooo`;o0000[Oooool009_ooooo0_l0
00000ooooooo0000o`000004o`000003ooooool0003o000000;o00000oooool00ol0003ooooooooo
o`05ooooo`;o00000oooool2o`000:gooooo002Rooooo`;o00000oooool2o`0000?ooooo00?o0000
ooooooooool01Oooool2o`0000;ooooo1?l00003ooooo`;o0000Yoooool009cooooo0_l00003oooo
o`;o00001?ooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00006ooooo`Co00000oooool2
o`000:Oooooo002@ooooo`;o00002?ooool4o`0000?ooooo0_l00005ooooo`;o00000_ooool2o`00
00;ooooo0_l00004ooooo`Go000000?oooooo`000?l00000Z_ooool0093ooooo0_l00008ooooo`;o
00001oooool2o`0000?ooooo0_l00002ooooo`;o00002?ooool5o`000003ooooool0003o00000:[o
oooo002Nooooo`;o00000oooool2o`0000Oooooo0ol00003ooooo`;o0000]?ooool009kooooo0_l0
0003ooooo`;o00001oooool00ol0003oooooooooo`02o`000003ooooool0003o000000;o0000/_oo
ool009[ooooo0ol00006ooooo`;o00001?ooool2o`000003ooooool0003ooooo00?o00000oooool2
o`000003ooooool0003o00000:oooooo002Jooooo`Go00001?ooool2o`0000Cooooo0_l000000ooo
oooo0000o`000002o`000003ooooool0003o000000;o00000_ooool2o`000:oooooo002Cooooo`;o
00002?ooool2o`0000;ooooo0_l00006ooooo`;o000000?oooooo`000?l000000oooool4o`000;?o
oooo002Cooooo`;o00003?ooool2o`0000Kooooo0_l000000ooooooo0000ooooo`02ooooo`;o0000
0oooool2o`000;7ooooo002Wooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo
0_l0002aooooo`00Yoooool2o`0000?ooooo00?o0000ooooooooool00_ooool2o`000;Gooooo002I
ooooo`;o00004Oooool3o`0000;ooooo0_l0002eooooo`00V?ooool3o`0000Oooooo0_l00002oooo
o`;o00001?ooool00ol0003oooooooooo`2iooooo`00V?ooool2o`0000Kooooo1?l00002ooooo`?o
00000oooool00ol0003oooooooooo`02ooooo`;o0000]Oooool00:3ooooo0_l00002ooooo`;o0000
00Coooooo`000?l0003o00000_ooool00ol0003oooooooooo`02ooooo`;o0000]Oooool009Cooooo
0_l0000;ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo00?o0000ooooooooool0
^Oooool009Cooooo0_l0000;ooooo`;o000000?oooooo`000?l000000ol00003ooooo`03o`000?oo
oooooooo00;o0000]oooool009Wooooo0_l00007ooooo`Oo00000oooool00ol0003oooooooooo`02
o`000;Oooooo002Iooooo`;o00002Oooool00ol0003oooooooooo`02o`0000?ooooo00Co0000oooo
ool0003o0000^?ooool00:Cooooo00?o0000ooooooooool00_l00003ooooo`Co0000^?ooool00:Co
oooo00?o0000ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo00?o
0000ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:;ooooo00?oEEEEofIV
I_l00000`oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0:[ooooo00Co410@o`000?l0003o0000^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_o
oooo00?o0000ooooooooool0^_ooool00:_ooooo00Ko0000ogMgMol0003o0000oeEEEOo^k^jgoooo
o`00Zoooool01_l0003oEEEEonk^k_ooooooMgMgoeEEEKOooooo002[ooooo`03o`000?o^k^kooooo
00;ooooo00?o0000ooooooooool0]Oooool00:_ooooo00?o0000onk^k_ooool00_ooool00ol0003o
ooooooooo`2eooooo`00Zoooool01_l0003oEEEEonk^k_ooooooMgMgofIVI[Oooooo002Zooooo`03
oa0@4?l0003oMgMg00;o000000?oIVIVonk^k_ooool0]_ooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.63462 .60566 Mdot
.65097 .57325 Mdot
.456 .60637 Mdot
.53545 .37351 Mdot
.57633 .39173 Mdot
.63176 .55853 Mdot
.44417 .39469 Mdot
.70222 .66651 Mdot
.61156 .8152 Mdot
.54635 .36477 Mdot
.56001 .40624 Mdot
.66136 .76144 Mdot
.66739 .54751 Mdot
.52814 .29765 Mdot
.56667 .89731 Mdot
.53272 .34277 Mdot
.60703 .5742 Mdot
.66842 .54467 Mdot
.56218 .36736 Mdot
.68341 .58376 Mdot
.64349 .65285 Mdot
.63597 .64965 Mdot
.59948 .7402 Mdot
.66453 .57695 Mdot
.58246 .88627 Mdot
.58432 .37184 Mdot
.56942 .49288 Mdot
.57376 .43886 Mdot
.67506 .62565 Mdot
.63604 .63662 Mdot
.60173 .75236 Mdot
.64509 .76116 Mdot
.66026 .75023 Mdot
.59484 .64431 Mdot
.6223 .54282 Mdot
.6134 .75571 Mdot
.63888 .74531 Mdot
.57352 .47405 Mdot
.62702 .74725 Mdot
.68771 .71394 Mdot
.64553 .80067 Mdot
.6151 .57407 Mdot
.62122 .58557 Mdot
.65025 .51537 Mdot
.64535 .52603 Mdot
.57836 .37573 Mdot
.56125 .43415 Mdot
.66859 .70624 Mdot
.59934 .41142 Mdot
.64101 .71362 Mdot
.65661 .73033 Mdot
.66024 .68487 Mdot
.53993 .99192 Mdot
.61188 .61421 Mdot
.62827 .51876 Mdot
.62861 .79591 Mdot
.69086 .69591 Mdot
.61306 .52562 Mdot
.65753 .71963 Mdot
.64453 .52246 Mdot
.58695 .41731 Mdot
.62436 .8546 Mdot
.60393 .78814 Mdot
.47771 .26142 Mdot
.58103 .86866 Mdot
.65163 .75357 Mdot
.55322 .39891 Mdot
.54964 .42753 Mdot
.56666 .40343 Mdot
.65713 .61642 Mdot
.61184 .41778 Mdot
.43428 .45687 Mdot
.55894 .43137 Mdot
.54589 .37342 Mdot
.60327 .78919 Mdot
.44307 .53306 Mdot
.53879 .99305 Mdot
.59135 .54237 Mdot
.6647 .6696 Mdot
.58934 .60447 Mdot
.60559 .75652 Mdot
.62746 .66089 Mdot
.54175 .4114 Mdot
.61953 .54908 Mdot
.69272 .68128 Mdot
.49088 .24024 Mdot
.57628 .38876 Mdot
.58783 .5023 Mdot
.61298 .47512 Mdot
.55178 .44464 Mdot
.56391 .90878 Mdot
.55209 .96344 Mdot
.4716 .25471 Mdot
.58195 .40241 Mdot
.48652 .26293 Mdot
.59127 .9191 Mdot
.52985 .30307 Mdot
.61585 .80171 Mdot
.545 .98829 Mdot
.60801 .41195 Mdot
.63017 .62865 Mdot
.60769 .4286 Mdot
.63187 .80885 Mdot
.64915 .54365 Mdot
.6448 .66675 Mdot
.59695 .64063 Mdot
.6174 .46923 Mdot
.56058 .3547 Mdot
.46965 .25507 Mdot
.64844 .64625 Mdot
.53016 .30718 Mdot
.51691 .31219 Mdot
.63714 .77416 Mdot
.66617 .63631 Mdot
.43604 .38104 Mdot
.59252 .46215 Mdot
.69071 .67508 Mdot
.67905 .69847 Mdot
.59124 .82212 Mdot
.66378 .57013 Mdot
.64727 .81776 Mdot
.59528 .7556 Mdot
.68181 .60248 Mdot
.65358 .63003 Mdot
.54349 .40857 Mdot
.6572 .6666 Mdot
.59547 .91045 Mdot
.60281 .71246 Mdot
.48991 .29693 Mdot
.62716 .67919 Mdot
.62402 .65443 Mdot
.64444 .79358 Mdot
.63743 .50853 Mdot
.62432 .58017 Mdot
.67972 .61961 Mdot
.67959 .64916 Mdot
.66335 .65642 Mdot
.56001 .44393 Mdot
.63548 .79564 Mdot
.58785 .87213 Mdot
.55064 .9479 Mdot
.48955 .25759 Mdot
.56092 .36924 Mdot
.60887 .56343 Mdot
.67827 .59911 Mdot
.6918 .67918 Mdot
.57739 .53084 Mdot
.58896 .4886 Mdot
.693 .73901 Mdot
.60387 .40641 Mdot
.55381 .35535 Mdot
.6685 .55563 Mdot
.43358 .48206 Mdot
.61427 .64723 Mdot
.65824 .69879 Mdot
.62859 .74728 Mdot
.67369 .71402 Mdot
.62366 .77249 Mdot
.66401 .68637 Mdot
.59063 .386 Mdot
.67528 .6396 Mdot
.70589 .68708 Mdot
.59877 .77653 Mdot
.59823 .66611 Mdot
.61071 .68292 Mdot
.68603 .6916 Mdot
.65197 .65088 Mdot
.56761 .41232 Mdot
.68277 .63343 Mdot
.61378 .76202 Mdot
.53179 .38082 Mdot
.57143 .46203 Mdot
.58561 .46472 Mdot
.58016 .48157 Mdot
.62689 .80612 Mdot
.58788 .92166 Mdot
.61034 .65757 Mdot
.47892 .29496 Mdot
.65783 .67778 Mdot
.68468 .62018 Mdot
.6776 .73861 Mdot
.52623 .3131 Mdot
.6469 .79988 Mdot
.49142 .29247 Mdot
.58594 .85022 Mdot
.57406 .93388 Mdot
.67507 .70131 Mdot
.70002 .69879 Mdot
.62765 .55481 Mdot
.6475 .81341 Mdot
.68045 .58961 Mdot
.49107 .27719 Mdot
.59476 .88975 Mdot
.69359 .68334 Mdot
.67651 .75622 Mdot
.64038 .79758 Mdot
.58392 .42063 Mdot
.5954 .92188 Mdot
.61811 .43901 Mdot
.47895 .29965 Mdot
.47868 .29882 Mdot
.4347 .44543 Mdot
.58437 .46179 Mdot
.58539 .93507 Mdot
.61484 .67636 Mdot
.50683 .32153 Mdot
.62932 .58084 Mdot
.48443 .24695 Mdot
.45462 .29229 Mdot
.55207 .36565 Mdot
.66447 .54415 Mdot
.59241 .52612 Mdot
.65035 .65592 Mdot
.54462 .38083 Mdot
.60733 .69235 Mdot
.58961 .5451 Mdot
.69967 .70212 Mdot
.4557 .29375 Mdot
.62876 .60987 Mdot
.69607 .69224 Mdot
.59125 .44817 Mdot
.62115 .787 Mdot
.65661 .63365 Mdot
.59211 .78271 Mdot
.55391 .4521 Mdot
.57725 .41154 Mdot
.65689 .51643 Mdot
.51628 .32577 Mdot
.57084 .89259 Mdot
.66681 .78967 Mdot
.52424 .32137 Mdot
.43822 .49589 Mdot
.53801 .98412 Mdot
.60694 .5135 Mdot
.56521 .42555 Mdot
.63456 .83393 Mdot
.57192 .45698 Mdot
.65068 .53997 Mdot
.62935 .68356 Mdot
.62715 .64302 Mdot
.61062 .87225 Mdot
.6337 .52233 Mdot
.66154 .62925 Mdot
.61192 .41889 Mdot
.66872 .71674 Mdot
.50813 .30835 Mdot
.62206 .76819 Mdot
.59452 .61512 Mdot
.61111 .41485 Mdot
.61887 .76339 Mdot
.6659 .77325 Mdot
.4387 .36643 Mdot
.51484 .33751 Mdot
.6078 .79404 Mdot
.59647 .44893 Mdot
.57154 .47371 Mdot
.62982 .45277 Mdot
.4426 .53029 Mdot
.67258 .73237 Mdot
.66606 .70702 Mdot
.60521 .4526 Mdot
.56473 .42224 Mdot
.5983 .77413 Mdot
.47452 .28844 Mdot
.60866 .45328 Mdot
.62396 .63832 Mdot
.56483 .47665 Mdot
.60472 .65933 Mdot
.60645 .771 Mdot
.59944 .5058 Mdot
.64278 .69847 Mdot
.63005 .49934 Mdot
.53274 .31912 Mdot
.60282 .52968 Mdot
.66603 .67952 Mdot
.51477 .28209 Mdot
.55784 .33521 Mdot
.65113 .74288 Mdot
.53801 .31919 Mdot
.6249 .60781 Mdot
.66398 .66516 Mdot
.43725 .3594 Mdot
.55494 .43227 Mdot
.61356 .78912 Mdot
.6437 .78867 Mdot
.55762 .34302 Mdot
.43573 .45379 Mdot
.57862 .55276 Mdot
.67469 .59797 Mdot
.58901 .45905 Mdot
.59766 .76823 Mdot
.56231 .94641 Mdot
.63668 .75799 Mdot
.5875 .86935 Mdot
.60707 .80696 Mdot
.43717 .52935 Mdot
.67206 .68265 Mdot
.56061 .92703 Mdot
.67576 .58437 Mdot
.57003 .89242 Mdot
.60377 .48731 Mdot
.63238 .45589 Mdot
.63251 .62948 Mdot
.6592 .73567 Mdot
.61716 .84061 Mdot
.55872 .41027 Mdot
.63784 .76635 Mdot
.59637 .43975 Mdot
.47454 .30258 Mdot
.65789 .58233 Mdot
.60986 .56206 Mdot
.6573 .59794 Mdot
.68812 .74581 Mdot
.45054 .31999 Mdot
.62617 .62375 Mdot
.60396 .61823 Mdot
.58066 .8708 Mdot
.45143 .31348 Mdot
.66908 .75518 Mdot
.57266 .90747 Mdot
.60383 .8912 Mdot
.54074 .38532 Mdot
.63824 .47471 Mdot
.62262 .5214 Mdot
.60394 .79101 Mdot
.56604 .35631 Mdot
.44355 .35362 Mdot
.43807 .45085 Mdot
.61681 .48259 Mdot
.69884 .68173 Mdot
.58653 .82545 Mdot
.47361 .25682 Mdot
.65627 .58257 Mdot
.47743 .28456 Mdot
.43623 .42695 Mdot
.65663 .52442 Mdot
.63374 .53812 Mdot
.59942 .66302 Mdot
.59243 .39539 Mdot
.58431 .47444 Mdot
.57109 .95858 Mdot
.59843 .49718 Mdot
.61098 .69928 Mdot
.49736 .28456 Mdot
.63757 .78567 Mdot
.56871 .50174 Mdot
.65867 .66736 Mdot
.60754 .71405 Mdot
.4682 .25228 Mdot
.58538 .56282 Mdot
.56059 .93702 Mdot
.67382 .73799 Mdot
.6848 .64816 Mdot
.62194 .74129 Mdot
.60123 .44594 Mdot
.61966 .49238 Mdot
.62399 .74222 Mdot
.60866 .4781 Mdot
.66987 .74529 Mdot
.64088 .8454 Mdot
.66229 .62843 Mdot
.63787 .80329 Mdot
.66658 .76053 Mdot
.67861 .74645 Mdot
.4378 .40658 Mdot
.60604 .50968 Mdot
.57743 .8853 Mdot
.68332 .71117 Mdot
.43738 .40787 Mdot
.6098 .74308 Mdot
.59175 .56913 Mdot
.63554 .54282 Mdot
.63057 .62531 Mdot
.61202 .80926 Mdot
.64948 .54844 Mdot
.64863 .72994 Mdot
.58237 .82806 Mdot
.59532 .74698 Mdot
.68918 .63047 Mdot
.61911 .69731 Mdot
.58864 .87637 Mdot
.58252 .83678 Mdot
.62727 .60432 Mdot
.44416 .3807 Mdot
.59473 .87777 Mdot
.6107 .44209 Mdot
.43806 .45366 Mdot
.6883 .71865 Mdot
.65675 .61891 Mdot
.43593 .39554 Mdot
.54955 .38689 Mdot
.59097 .4173 Mdot
.56719 .43663 Mdot
.67437 .69532 Mdot
.67265 .57087 Mdot
.57652 .91056 Mdot
.6781 .73855 Mdot
.60953 .5779 Mdot
.53383 .99385 Mdot
.61625 .53853 Mdot
.57926 .46308 Mdot
.57547 .41298 Mdot
.44293 .57158 Mdot
.68987 .70101 Mdot
.65899 .76505 Mdot
.56923 .48775 Mdot
.50103 .28249 Mdot
.52714 .28326 Mdot
.50252 .25868 Mdot
.67443 .76555 Mdot
.57342 .36397 Mdot
.61706 .74357 Mdot
.51722 .31915 Mdot
.5591 .37575 Mdot
.4672 .28916 Mdot
.57676 .38421 Mdot
.5939 .64462 Mdot
.55442 .36285 Mdot
.50685 .32019 Mdot
.6701 .78098 Mdot
.64087 .7867 Mdot
.46336 .61297 Mdot
.62357 .53849 Mdot
.61751 .47268 Mdot
.59646 .69909 Mdot
.59184 .57383 Mdot
.56892 .42778 Mdot
.61754 .84892 Mdot
.61892 .8896 Mdot
.6455 .5792 Mdot
.65206 .49754 Mdot
.48879 .27752 Mdot
.57491 .86733 Mdot
.56948 .89565 Mdot
.56563 .4476 Mdot
.5938 .74206 Mdot
.56064 .96985 Mdot
.50824 .29944 Mdot
.43807 .38563 Mdot
.58075 .50587 Mdot
.61155 .75015 Mdot
.59517 .56989 Mdot
.57637 .94057 Mdot
.48063 .27849 Mdot
.60677 .62661 Mdot
.62045 .53243 Mdot
.46509 .26177 Mdot
.46923 .29304 Mdot
.52542 .30703 Mdot
.69901 .675 Mdot
.43813 .364 Mdot
.67145 .64821 Mdot
.65097 .56391 Mdot
.63824 .57595 Mdot
.65241 .67702 Mdot
.59205 .77539 Mdot
.61183 .55682 Mdot
.63557 .86182 Mdot
.54846 .38002 Mdot
.70002 .67971 Mdot
.67573 .75614 Mdot
.5649 .50265 Mdot
.67839 .66649 Mdot
.5965 .54263 Mdot
.59375 .62677 Mdot
.66176 .65831 Mdot
.63508 .61108 Mdot
.56811 .39159 Mdot
.58692 .55274 Mdot
.60321 .61494 Mdot
.66586 .79529 Mdot
.61097 .63346 Mdot
.44987 .59582 Mdot
.60999 .62775 Mdot
.59541 .57678 Mdot
.4324 .47781 Mdot
.54959 .4378 Mdot
.61486 .60066 Mdot
.63015 .53859 Mdot
.45371 .31702 Mdot
.5968 .4747 Mdot
.65046 .75608 Mdot
.56877 .3597 Mdot
.62097 .64452 Mdot
.54374 .31331 Mdot
.57548 .51585 Mdot
.43824 .39581 Mdot
.44475 .36012 Mdot
.65439 .54889 Mdot
.58697 .83844 Mdot
.60846 .76044 Mdot
.56716 .40304 Mdot
.66135 .66474 Mdot
.67205 .74654 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0^Oooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1Oooool00ol0003oooooooooo`2iooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`2iooooo`00POooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVY
ZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000;Wooooo0029ooooo`05o`000?oo
ooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0^Oooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEE
EOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;Wo
oooo0029ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0^Oooool008Wooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo0;Wooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`00
00Cooooo1?l00006ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Ooo
ool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`00
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:Wooooo0_l000000ooooooo0000ooooo`2jooooo`00TOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
0_ooool2o`000003ooooool0003ooooo0;[ooooo002Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Sooooo00?oMgMgo`000?l000001?ooool00ol0003oooooooooo`2iooooo`00ROoo
ool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`;o00001?ooool00ol0003ooooo
ooooo`2iooooo`00TOooool01Ol0003ooooooooooooooooo000000_ooooo0_l00002ooooo`03ogMg
Molb<S;ooooo00Cooooo0ol0002iooooo`00TOooool01Ol0003ooooooooooooooooo000000_ooooo
1?l000000olb<S;oc<c<ooooo`04ooooo`03o`000?oooooooooo0;Wooooo002Aooooo`05oa0@4?oo
ooooooooooooool@41003?ooool3o`0000?ooooo0_l00002ooooo`;o0000^_ooool0097ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0:ooooo`Ko00000_ooool2o`0000;ooooo0_l0002jooooo`00TOoo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00[ooooo1_l000000ooooooo0000o`000003ooooo`03o`00
0?oooooooooo0;Wooooo002Wooooo`;o00000oooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00ZOooool2o`000004
ooooool0003o0000o`000;Wooooo002Uooooo`;o000000Koooooo`000?l0003o0000ooooool0002k
ooooo`00YOooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o00000oooool2o`00
0;7ooooo002Tooooo`;o00001Oooool3o`0000;ooooo0_l00003ooooo`;o0000/Oooool00:7ooooo
1Ol00005ooooo`;o0000^oooool009gooooo0_l00002ooooo`Co00001?ooool2o`000003ooooool0
003ooooo0;[ooooo002Mooooo`;o00000_ooool2o`0000;ooooo0_l00002ooooo`;o000000?ooooo
o`000?ooool0^_ooool009gooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o0000
00;ooooo00?o0000ooooooooool01_ooool2o`000;7ooooo002Uooooo`;o000000?oooooo`000?l0
00000_ooool4o`0000Gooooo0_l0002aooooo`00Xoooool4o`0000Gooooo00Co0000ooooool0003o
00001Oooool2o`000;7ooooo002Sooooo`;o00001oooool00ol0003oooooooooo`05ooooo`Co0000
/?ooool00:cooooo00Co0000ooooool0003o00001?ooool4o`000;3ooooo002Looooo`;o00003_oo
ool01Ol0003oooooo`000?l0003ooooo00;o000000?oooooo`000?l000001?ooool2o`000:cooooo
002Looooo`;o00003_ooool00ol0003oooooooooo`02ooooo`;o000000?oooooo`000?l000001?oo
ool2o`000:cooooo002Looooo`;o00003_ooool00ol0003oooooooooo`02ooooo`;o00000oooool4
o`000:kooooo002Kooooo`?o00003_ooool01Ol0003oooooo`000?l0003ooooo00;o000000?ooooo
o`000?l000001?l0002^ooooo`00Voooool2o`0000oooooo1?l000001?oooooo0000o`000?ooool2
o`000;;ooooo002/ooooo`03o`000?oooooooooo00;ooooo0_l0002eooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool01?l0003ooooooooo
ooooool2o`0000gooooo0_l0002Wooooo`00[?ooool01?l0003oooooooooooooool2o`0000gooooo
0_l0002Wooooo`00[?ooool00ol0003oooooooooo`07ooooo`;o00001oooool2o`000:Oooooo002/
ooooo`03o`000?oooooooooo00Oooooo0_l00007ooooo`;o0000Yoooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo0ol0002iooooo`00VOooool2o`00017ooooo00?o0000ooooooooool0
3_ooool2o`000003ooooool0003o00000:Kooooo002Iooooo`;o00004Oooool00ol0003ooooooooo
o`0>ooooo`;o000000Coooooo`000?l0003o0000YOooool009Oooooo1?l0000Aooooo`03o`000?oo
oooooooo01;ooooo0ol0002Tooooo`00Uoooool4o`00017ooooo00?o0000ooooooooool03?ooool2
o`000003ooooool0003o000000;ooooo1?l0002Rooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B42ooooo`Oo00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool03?ooool7o`0000;ooooo0_l0002Rooooo`00ROooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B42ooooo`;o000000GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool03_ooool2o`000003ooooool0003o00000:Kooooo
0021ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0
2Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo0_l00002ooooo`;o0000
0oooool2o`0000Gooooo0_l0002Oooooo`00ROooool01Ol0003ooooooooooooooooo000000gooooo
00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o00002?ooool2o`0000;ooooo
0_l00002ooooo`;o00001?ooool4o`0009oooooo0029ooooo`05o`000?ooooooooooooooool00000
3_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003o
ooooooooo`0=ooooo`;o000000?oooooo`000?l000001?ooool2o`000:7ooooo0029ooooo`05oa0@
4?ooooooooooooooool@41002?ooool2o`000003ooooool0003o000000;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo0_l00002ooooo`Co
0000Z_ooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`Go000000?ooooooiRHV?l@
41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo0_l000001?oooooo
0000o`000?l00009ooooo`;o00000_ooool2o`0009gooooo0029ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02Oooool2o`000005oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000
ooooooooool02_ooool2o`000003ooooool0003o000000Oooooo0_l00002ooooo`;o0000WOooool0
0:cooooo00?o0000ooooooooool03Oooool2o`0000Cooooo0_l000000ooooooo0000o`00002Qoooo
o`00VOooool2o`00017ooooo00?o0000ooooooooool04oooool2o`000003ooooool0003o000000?o
oooo0_l0002Looooo`00U_ooool5o`00017ooooo00?o0000ooooooooool06oooool2o`0009cooooo
002Fooooo`?o00004oooool3o`0000kooooo0_l0002Yooooo`00[?ooool00ol0003oooooooooo`0>
ooooo`;o00000oooool2o`0000?ooooo0_l0002Oooooo`00Uoooool2o`0001?ooooo00?o0000oooo
ooooool04?ooool2o`000003ooooool0003o000000?ooooo0_l00005ooooo`;o0000V?ooool009Oo
oooo0_l0000Cooooo`03o`000?oooooooooo00_ooooo0_l00003ooooo`;o00003Oooool2o`0009So
oooo002Gooooo`;o00004oooool00ol0003oooooooooo`0:ooooo`?o00000oooool2o`000003oooo
ool0003o000000?o00001Oooool2o`000003ooooool0003o000009Oooooo002/ooooo`03o`000?oo
oooooooo00[ooooo0_l00007ooooo`Go00001Oooool2o`000004ooooool0003o0000o`0009Kooooo
002/ooooo`03o`000?oooooooooo01Wooooo1?l00004ooooo`?o0000UOooool00:cooooo00?o0000
ooooooooool04_ooool2o`0000Cooooo1Ol00004ooooo`?o0000UOooool00:cooooo0ol0000Boooo
o`;o00001?ooool2o`0009oooooo002Gooooo`;o00004oooool00ol0003oooooooooo`0=ooooo`;o
00000oooool3o`0000_ooooo0_l0002Gooooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool0
3Oooool2o`000004ooooool0003o0000ooooo`;o00002oooool2o`0009Oooooo002/ooooo`03o`00
0?oooooooooo00oooooo1?l0002Vooooo`00[?ooool00ol0003oooooooooo`0=ooooo`So0000Y?oo
ool00:cooooo00?o0000ooooooooool03Oooool2o`0000Cooooo1?l00005ooooo`;o00001_ooool2
o`0009?ooooo002/ooooo`03o`000?oooooooooo013ooooo0_l00003ooooo`;o00001Oooool2o`00
00?ooooo0_l000000ooooooo0000o`00002Cooooo`00U_ooool2o`0001Cooooo00?o0000oooooooo
ool03_ooool4o`0000cooooo0_l000000ooooooo0000o`00002Fooooo`00U_ooool2o`0001Cooooo
00?o0000ooooooooool03_ooool2o`0000;ooooo0_l00007ooooo`Go0000VOooool009Oooooo0_l0
000Cooooo`?o00003_ooool2o`0000;ooooo0_l00007ooooo`?o000000?oooooo`000?l000001_oo
ool2o`00093ooooo002Fooooo`?o00004oooool00ol0003oooooooooo`0>ooooo`;o00003oooool3
o`0000Gooooo0ol0002?ooooo`00U_ooool3o`0001?ooooo00?o0000ooooooooool05?ooool2o`00
00Cooooo0_l00004ooooo`;o00001_ooool2o`0008oooooo0009ooooo`Co000000?o410@oooooooo
ool05_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo
00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_l0000Doooo
o`03o`000?oooooooooo01Cooooo0_l00002ooooo`Co000000?ok^k^ooooooooool00oooool2ob4Q
8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@0Hooooo`Co000000?o410@ooooooooool04_ooool000_ooooo00?o0000oooooooo
ool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo
00Oooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool05Oooool00ol0003ooooo
ooooo`0Dooooo`;o000000?oooooo`000?l000001?l00005ooooo`;o8B4Q1?ooool01OnHV9So8B4Q
onk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo01Wooooo00?o0000
ooooooooool05?ooool000Ko00001Oooool00ol0003oooooooooo`0@ooooo`Ko00000_ooool01Ol@
413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`05
ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool01Ooo
ool6o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Gooooo`Ko00003?ooool00onHV9So8B4Q
onk^kP09ooooo`03o`000?oooooooooo00gooooo00Go410@oooooooooooooooooa0@400@ooooo`03
o`000?oooooooooo00gooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo
00Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003o
ooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06oooo
o`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo00kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o
MgMgoc8b<_ooool05Oooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool00000
1_ooool2o`0000Gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`0>ooooo`05o`00
0?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0>ooooo`05o`000?oooooooooooooo
ool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Wooooo00?o0000oooo
ooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo0000
00kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000
ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooo
oooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
01Kooooo00?o0000ooooooooool05?ooool3o`000003ooooool0003ooooo00;ooooo00?o0000oooo
ooooool01?ooool2o`0000Kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
3oooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<01[ooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000oooooooo
ool06?ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0
003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0A
ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo01Sooooo0ol0000Booooo`Go000000?oooooo`000?l000000_ooool00ol@413o0000o`00
0003ooooo`?o00001Oooool3o`0000Cooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooo
oooooooo410@00cooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00ko
oooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Co
oooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00Co0000oooooooooooooooo0_l0000Eooooo`03
o`000?oooooooooo01;ooooo0_l00004ooooo`;o000000?ooooooiRHV?mgMgL00_l000000ooooooo
0000o`000002o`0000Cooooo00Go0000okZj^_l0003o0000oa0@4004ooooo`03o`000?oooooooooo
017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo01Cooooo0009ooooo`03oeEEEOmVIVKo000001[ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c004ooooo`Oo00005?ooool00ol0003oooooooooo`0Gooooo`;o000000Co<S8b
o`000?lb<S;ok^k^0oooool2o`000003ooooool0003o000000?ooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c004ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000Iooooo`03oeEEEOmVIVKo0000
01Kooooo002Fooooo`;o00005?ooool00ol0003oooooooooo`0Gooooo`;o00002_ooool2o`0009Co
oooo002/ooooo`03o`000?oooooooooo01?ooooo0_l00005ooooo`;o00000oooool2o`0009Sooooo
002/ooooo`03o`000?oooooooooo01?ooooo0_l00005ooooo`;o00000oooool2o`0000?ooooo0_l0
0028ooooo`;o00000_ooool2o`0000Gooooo002/ooooo`03o`000?oooooooooo01?ooooo0_l0000?
ooooo`;o0000R?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Gooooo002Gooooo`;o00004ooo
ool00ol0003oooooooooo`0Cooooo`;o00002?ooool2o`00013ooooo0_l0001nooooo`04omgMgOl0
003o410@olc<c0Kooooo0007oooooooo0000C?l0000<ooooo`04onk^k_lQ8B7o410@onk^kPKooooo
0007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooooooo0ol000000ooooooo0000
ooooo`02ooooo`;o00000_ooool00ol0003oooooooooo`06ooooo`;o00001_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool01?lQ8B7oMgMg
ogMgMolb<S86ooooo`001oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01;ooooo
0ol00002ooooo`;o000000Coooooo`000?l0003ooooo0_l00008ooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Wo
oooo0_l00002ooooo`;o00001Oooool00:cooooo00?o0000ooooooooool05oooool2o`0000Cooooo
0_l000000ooooooo0000o`000008ooooo`;o0000SOooool00:cooooo00?o0000ooooooooool08?oo
ool2o`0000Sooooo0_l0002=ooooo`00[?ooool00ol0003oooooooooo`0Eooooo`;o00002Oooool2
o`0000cooooo1?l00027ooooo`00[?ooool00ol0003oooooooooo`0Eooooo`;o00004?ooool2o`00
00Gooooo1?l00027ooooo`00[?ooool00ol0003oooooooooo`0Uooooo`Ko000000?oooooo`000?l0
0000Roooool00:cooooo0ol0000Rooooo`;o000000?oooooo`000?l000000_ooool2o`000003oooo
ool0003o000000;ooooo0_l00027ooooo`00[?ooool00ol0003oooooooooo`0Kooooo`;o00001Ooo
ool2o`0000Wooooo0_l000000ooooooo0000o`000027ooooo`00Uoooool4o`00017ooooo00?o0000
ooooooooool05_ooool2o`0000?ooooo0_l00002ooooo`;o00003?ooool2o`0008[ooooo002Goooo
o`Co00004Oooool00ol0003oooooooooo`0Fooooo`;o00001oooool2o`0000?ooooo0_l0002Coooo
o`00VOooool2o`00017ooooo00?o0000ooooooooool09?ooool2o`0009?ooooo002/ooooo`03o`00
0?oooooooooo02?ooooo1?l000001?oooooo0000o`000?l00003ooooo`;o0000ROooool00:cooooo
00?o0000ooooooooool06oooool3o`0000Gooooo1?l000001?oooooo0000o`000?l00003ooooo`;o
0000ROooool00:cooooo00?o0000ooooooooool06_ooool4o`0000Oooooo0_l00002ooooo`;o0000
0oooool2o`0000?ooooo0ol00023ooooo`00[?ooool00ol0003oooooooooo`0Jooooo`;o00002?oo
ool2o`0000Sooooo1?l000001?oooooo0000o`000?l00023ooooo`00[?ooool3o`0001Oooooo1?l0
0009ooooo`;o00002?ooool4o`0000;ooooo0_l00023ooooo`00[?ooool00ol0003oooooooooo`0G
ooooo`Co00003?ooool2o`0000_ooooo0_l00023ooooo`00[?ooool00ol0003oooooooooo`0Qoooo
o`;o00001?ooool3o`0000[ooooo0_l00023ooooo`00[?ooool00ol0003oooooooooo`0Qooooo`;o
00001Oooool2o`0008oooooo002/ooooo`03o`000?oooooooooo01Wooooo0_l00006ooooo`;o0000
2oooool2o`0008Wooooo002/ooooo`03o`000?oooooooooo01Wooooo0_l00006ooooo`;o00002ooo
ool2o`0008Wooooo002/ooooo`03o`000?oooooooooo01_ooooo0ol0000Eooooo`;o000000?ooooo
o`000?l00000POooool009Wooooo0_l0000Aooooo`03o`000?oooooooooo01_ooooo0ol00002oooo
o`;o000000?oooooo`000?l000002Oooool2o`0000?ooooo0_l000000ooooooo0000o`000021oooo
o`00VOooool2o`00017ooooo0ol0000Kooooo`?o00000_ooool2o`000003ooooool0003o000000Go
oooo0_l00002ooooo`;o00000oooool2o`0008Cooooo002/ooooo`03o`000?oooooooooo01cooooo
0_l00003ooooo`;o00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`;o0000
Q?ooool00:cooooo00?o0000ooooooooool08Oooool2o`0000?ooooo0ol00004ooooo`;o000000Co
ooooo`000?l0003o0000Q_ooool00:cooooo00?o0000ooooooooool09Oooool4o`0000Oooooo0ol0
0004ooooo`Co0000O_ooool00:cooooo00?o0000ooooooooool09Oooool2o`00013ooooo1?l0001n
ooooo`00[?ooool00ol0003oooooooooo`0hooooo`;o0000Ooooool00:cooooo00?o0000oooooooo
ool0>?ooool2o`0007oooooo002Kooooo`;o00003oooool00ol0003oooooooooo`0`ooooo`;o0000
1?ooool2o`00087ooooo002Kooooo`;o00003oooool3o`0002;ooooo0_l0000<ooooo`;o00001?oo
ool3o`00083ooooo002/ooooo`03o`000?oooooooooo01[ooooo0_l00006ooooo`;o00000oooool2
o`0000kooooo1?l0001nooooo`00WOooool2o`0000gooooo00?o0000ooooooooool06_ooool2o`00
00_ooooo1?l0000>ooooo`;o0000O_ooool009gooooo0_l0000=ooooo`03o`000?oooooooooo02Ko
oooo1Ol0002>ooooo`00Woooool2o`0000_ooooo00?o0000ooooooooool09_ooool5o`0008kooooo
002Oooooo`;o00002oooool00ol0003oooooooooo`0Looooo`;o000000?oooooo`000?l000000_l0
0006ooooo`;o00001Oooool2o`0008Oooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`0Looooo`;o000000?oooooo`000?l000000_l0000=ooooo`;o00001_ooool2o`0007oooooo
0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool07oooool2o`0000oo
oooo0_l00006ooooo`Co0000OOooool008Wooooo00Go410@oooooooooooooooooa0@400<ooooo`03
oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`0002Kooooo1?l0000<ooooo`;o
00000_ooool2o`0007gooooo0029ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So
8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool07?ooool2o`0000;o
oooo0ol00003ooooo`Co00002?ooool2o`0000;ooooo0_l00021ooooo`00ROooool01Ol0003ooooo
oooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool07?ooool2o`0000;ooooo0ol00005ooooo`;o00001Oooool2o`00
0003ooooool0003o000000Oooooo0_l0001looooo`00ROooool01Ol@413ooooooooooooooooo410@
00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
027ooooo0_l00005ooooo`;o00001Oooool5o`0000Gooooo1?l0001looooo`00ROooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool08Oooool2o`0000Kooooo0_l00005ooooo`;o000000?ooooo
o`000?l000001?ooool2o`0007kooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo01gooooo0_l0
0006ooooo`;o00000_ooool2o`0000Sooooo0_l000000ooooooo0000o`000021ooooo`00[?ooool0
0ol0003oooooooooo`0Mooooo`;o00001_ooool4o`0000gooooo0_l00021ooooo`00[?ooool00ol0
003oooooooooo`0Looooo`;o00001_ooool2o`000003ooooool0003o000000Gooooo0_l00029oooo
o`00[?ooool00ol0003oooooooooo`0Looooo`;o00001?ooool4o`0000?ooooo0_l00003ooooo`;o
00001Oooool2o`000003ooooool0003o000000;o0000OOooool00:cooooo0ol0000Rooooo`;o0000
1Oooool2o`000004ooooool0003o0000ooooo`;o00001?ooool2o`000003ooooool0003o000000;o
0000OOooool00:cooooo00?o0000ooooooooool09_ooool2o`0000Cooooo1Ol00028ooooo`00[?oo
ool00ol0003oooooooooo`0Qooooo`;o00000oooool2o`0000Kooooo0_l00002ooooo`;o0000QOoo
ool00:cooooo00?o0000ooooooooool07oooool4o`0000Cooooo0_l00009ooooo`;o0000QOooool0
0:cooooo00?o0000ooooooooool07Oooool4o`0000Kooooo0_l00009ooooo`;o0000QOooool00:co
oooo00?o0000ooooooooool07Oooool2o`0000gooooo0_l00002ooooo`Go00000_ooool2o`0000Ko
oooo0_l0001hooooo`00[?ooool00ol0003oooooooooo`0Mooooo`;o00003Oooool2o`0000;ooooo
1Ol00002ooooo`;o00001_ooool2o`0007Sooooo002/ooooo`03o`000?oooooooooo03?ooooo0_l0
0024ooooo`00[?ooool3o`0002;ooooo0_l0000;ooooo`;o00002oooool4o`0007Wooooo002/oooo
o`03o`000?oooooooooo02;ooooo0_l00003ooooo`;o00001_ooool6o`0000Oooooo1Ol0001hoooo
o`00[?ooool00ol0003oooooooooo`0Qooooo`;o00001?ooool2o`0000Sooooo1_l00005ooooo`Go
0000N?ooool00:cooooo00?o0000ooooooooool08Oooool2o`0000Cooooo0_l00008ooooo`;o0000
0_ooool2o`0000Gooooo1?l0001iooooo`00[?ooool00ol0003oooooooooo`0Wooooo`;o00002?oo
ool4o`0000Oooooo0_l00003ooooo`;o0000M_ooool00:cooooo00?o0000ooooooooool08?ooool2
o`00017ooooo0_l00005ooooo`;o000000?oooooo`000?l000000_ooool2o`0007Kooooo002/oooo
o`03o`000?oooooooooo023ooooo0_l0000Dooooo`;o00000_ooool2o`000003ooooool0003o0000
07[ooooo002/ooooo`03o`000?oooooooooo02Cooooo0_l0000@ooooo`;o00001?ooool2o`0007_o
oooo002/ooooo`?o00007?ooool2o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`;o0000
0oooool2o`0000?ooooo1?l000001Ooooooo0000o`000?l0003ooooo00;o0000N?ooool00:cooooo
00?o0000ooooooooool07?ooool2o`0000?ooooo0_l00009ooooo`;o00000oooool2o`0000?ooooo
1?l000001?oooooo0000o`000?ooool3o`0007Sooooo002/ooooo`03o`000?oooooooooo03?ooooo
0ol00008ooooo`;o0000NOooool00:cooooo00?o0000ooooooooool0<oooool3o`0008?ooooo002/
ooooo`03o`000?oooooooooo01oooooo0_l0000Hooooo`;o0000O_ooool00:cooooo00?o0000oooo
ooooool07oooool3o`0000Wooooo0_l00009ooooo`;o000000?oooooo`000?l000000_l0001loooo
o`00[?ooool00ol0003oooooooooo`0Pooooo`;o00002Oooool2o`0000Oooooo1?l00003ooooo`;o
0000O?ooool00:cooooo00?o0000ooooooooool0<Oooool2o`000003ooooool0003o000000Gooooo
0_l0001looooo`00[?ooool3o`00037ooooo0_l00026ooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`0^ooooo`Co0000Qoooool00:cooooo00?o0000oooooooo
ool0;_ooool4o`0000Cooooo0_l00021ooooo`00[?ooool00ol0003oooooooooo`0aooooo`;o0000
0oooool2o`00087ooooo002/ooooo`03o`000?oooooooooo01gooooo0_l0000Booooo`;o00000ooo
ool3o`0000?ooooo0_l0001kooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Looooo`?o0000
0_ooool6o`0000Oooooo0_l00006ooooo`?o00000oooool2o`0007_ooooo002Aooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`0Looooo`;o00000oooool6o`0000?ooooo0_l00002ooooo`;o00001Oooool2o`000004oooo
ool0003o0000ooooo`;o0000O?ooool0097ooooo00Go410@oooooooooooooooooa0@400@ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool07?ooool2o`0000Sooooo0ol000000ooooooo
0000o`000009ooooo`;o000000Coooooo`000?l0003ooooo0_l0001looooo`00TOooool01Ol0003o
oooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool3o`0001cooooo1?l000000ooo
oooo0000o`000003ooooo`?o00002?ooool2o`0008Kooooo002Aooooo`05o`000?oooooooooooooo
ool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool07?ooool4
o`000004ooooool0003o0000o`0000_ooooo1?l000000ooooooo0000o`000023ooooo`00TOooool0
1Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Looooo`;o000000Coooooo`000?l0003ooooo0_l00006ooooo`;o00000_ooool3o`0000?ooooo
0_l000000ooooooo0000o`000020ooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Oooooo`Go00001_ooool6o`0000;ooooo
1?l000000ooooooo0000o`000020ooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l00006ooooo`03o`000?oooooooooo023ooooo1_l00006ooooo`;o00000oooool5o`0008?ooooo
002/ooooo`03o`000?oooooooooo02Cooooo0_l00004ooooo`;o00001Oooool2o`0000?ooooo0_l0
0021ooooo`00[?ooool00ol0003oooooooooo`0Mooooo`;o000000?oooooo`000?l000000oooool2
o`0000?ooooo0_l0000:ooooo`;o0000POooool00:cooooo00?o0000ooooooooool07Oooool2o`00
0003ooooool0003o000000?ooooo0_l0000<ooooo`;o0000Q?ooool00:cooooo0ol0000Kooooo`Co
00001_ooool2o`0000?ooooo0_l00007ooooo`;o0000Q?ooool00:cooooo00?o0000ooooooooool0
6oooool4o`0000_ooooo0_l0002=ooooo`00[?ooool00ol0003oooooooooo`0Kooooo`;o00006?oo
ool2o`0008;ooooo002/ooooo`03o`000?oooooooooo01_ooooo0_l0000=ooooo`;o00002Oooool2
o`0008;ooooo002/ooooo`03o`000?oooooooooo01oooooo0_l000001?oooooo0000o`000?ooool2
o`0000?ooooo1?l0002;ooooo`00[?ooool00ol0003oooooooooo`0Oooooo`;o000000Coooooo`00
0?l0003ooooo0_l00004ooooo`?o00001_ooool2o`0008?ooooo002/ooooo`03o`000?oooooooooo
01oooooo0ol0000:ooooo`;o00001Oooool3o`0008?ooooo002/ooooo`03o`000?oooooooooo023o
oooo0_l00005ooooo`Oo00001Oooool2o`0008Cooooo002/ooooo`?o00009oooool8o`0008[ooooo
002/ooooo`03o`000?oooooooooo02?ooooo0_l00005ooooo`;o000000?oooooo`000?l00000R_oo
ool00:cooooo00?o0000ooooooooool08?ooool2o`000004ooooool0003o0000ooooo`;o00000_oo
ool2o`0008gooooo002/ooooo`03o`000?oooooooooo023ooooo1?l00002ooooo`Co0000Soooool0
0:cooooo00?o0000ooooooooool08_ooool2o`0000Cooooo0_l00003ooooo`;o0000R_ooool00:co
oooo00?o0000ooooooooool08Oooool2o`0000[ooooo0_l0002:ooooo`00[?ooool00ol0003ooooo
ooooo`0Qooooo`;o00002_ooool2o`0008[ooooo002/ooooo`03o`000?oooooooooo01_ooooo0_l0
000@ooooo`;o0000R_ooool00:cooooo0ol0000Iooooo`Co0000W?ooool00:cooooo00?o0000oooo
ooooool06?ooool3o`0009kooooo002/ooooo`03o`000?oooooooooo01Sooooo0_l0002Oooooo`00
[?ooool00ol0003oooooooooo`0Yooooo`;o0000S_ooool00:cooooo00?o0000ooooooooool06?oo
ool2o`0000oooooo0_l0002>ooooo`00[?ooool00ol0003oooooooooo`0Hooooo`?o00002?ooool2
o`0009Cooooo002/ooooo`03o`000?oooooooooo01Wooooo0_l00008ooooo`;o0000U?ooool00:co
oooo00?o0000ooooooooool0:oooool2o`0008cooooo002/ooooo`03o`000?oooooooooo02?ooooo
0_l00006ooooo`;o0000S?ooool00:cooooo0ol0000Iooooo`;o00002?ooool2o`0009Cooooo002/
ooooo`03o`000?oooooooooo01Wooooo0_l0000;ooooo`;o0000TOooool00:cooooo00?o0000oooo
ooooool09_ooool2o`00097ooooo002/ooooo`03o`000?oooooooooo02Wooooo0_l0002>ooooo`00
[?ooool00ol0003oooooooooo`0Yooooo`;o0000S_ooool008Wooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01Oooool00ol0003oooooooooo`0Eooooo`;o0000X_ooool008Wooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool05Oooool6o`0009kooooo0029ooooo`05oa0@4?ooooooooooooooool@
41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool05oooool5o`0000Gooooo0_l0002Fooooo`00ROooool01Ol0003ooooooooooooooooo000000ko
oooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`?o00006_ooool2o`0000Go
oooo0_l0002Fooooo`00ROooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?oo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool06_ooool4o`00
09_ooooo0029ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07?ooool2o`0009_ooooo0029ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Fooooo`;o0000XOooool008Wooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool05_ooool4
o`0009oooooo002/ooooo`03o`000?oooooooooo01Sooooo0_l00002ooooo`;o000000?oooooo`00
0?l000000oooool2o`0009?ooooo002/ooooo`03o`000?oooooooooo01Cooooo0_l00006ooooo`;o
000000?oooooo`000?l000000oooool2o`0009?ooooo002/ooooo`03o`000?oooooooooo01?ooooo
0ol0002Sooooo`00[?ooool3o`0001?ooooo0_l0002Tooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0Booooo`;o
000000?oooooo`000?l000001Oooool2o`0009_ooooo002/ooooo`03o`000?oooooooooo01;ooooo
0_l000001?oooooo0000o`000?l00004ooooo`;o0000Voooool00:cooooo00?o0000ooooooooool0
5_ooool2o`000:7ooooo002/ooooo`03o`000?oooooooooo01_ooooo0_l0002Looooo`00[?ooool0
0ol0003oooooooooo`0Jooooo`Co0000Voooool00:cooooo0ol0000Jooooo`Co0000Voooool00:co
oooo00?o0000ooooooooool04Oooool2o`000:Kooooo002/ooooo`03o`000?oooooooooo017ooooo
0_l0002Vooooo`00[?ooool00ol0003oooooooooo`0Eooooo`;o0000X_ooool00:cooooo00?o0000
ooooooooool04Oooool2o`0000;ooooo0_l00002ooooo`;o0000W_ooool00:cooooo00?o0000oooo
ooooool04Oooool2o`0000?ooooo0_l000000ooooooo0000o`00002Nooooo`00[?ooool00ol0003o
ooooooooo`0Fooooo`;o0000XOooool00:cooooo00?o0000ooooooooool04Oooool2o`000:Kooooo
002/ooooo`03o`000?oooooooooo00gooooo0_l00002ooooo`;o0000Y_ooool00:cooooo0ol0000=
ooooo`;o0000Z_ooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool05?ooool2o`000:?ooooo002/ooooo`03o`000?oooooooooo01Cooooo0_l0002Sooooo`00[?oo
ool00ol0003oooooooooo`0>ooooo`;o0000ZOooool00:cooooo00?o0000ooooooooool03_ooool2
o`000:Wooooo002/ooooo`03o`000?oooooooooo017ooooo0_l0002Vooooo`00[?ooool00ol0003o
ooooooooo`0Aooooo`;o0000Y_ooool00:cooooo0ol0002iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`09oooo
o`;o0000[_ooool00:cooooo00?o0000ooooooooool02Oooool4o`000:cooooo002/ooooo`03o`00
0?oooooooooo00[ooooo0ol0002/ooooo`00X_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o
0000ooooooooool02?ooool4o`000:gooooo002Tooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02?ooool3o`000:kooooo002Tooooo`03o`000?oooooooooo00Gooooo0ol0002ioooo
o`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?oo
ool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00X_ooool00omE
EEGoIVIVo`000033ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00Z_ooool01?l@413o0000o`000?l0002jooooo`00Zoooool00ol0003oooooooooo`2joooo
o`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool01_l0003oMgMgo`000?l0003oEEEEonk^
k[Oooooo002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoEEEE]oooool00:_ooooo00?o0000onk^
k_ooool00_ooool00ol0003oooooooooo`2eooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03
o`000?oooooooooo0;Gooooo002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoIVIV]oooool00:[o
oooo00?o410@o`000?mgMgL00_l000000omVIVKok^k^ooooo`2fooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.63688 .40566 Mdot
.64027 .37325 Mdot
.50234 .56075 Mdot
.45125 .2705 Mdot
.49303 .19333 Mdot
.61517 .35853 Mdot
.45868 .65741 Mdot
.72883 .46651 Mdot
.69764 .6152 Mdot
.45605 .23552 Mdot
.48273 .21698 Mdot
.72594 .56144 Mdot
.6464 .34751 Mdot
.4272 .31054 Mdot
.68559 .69731 Mdot
.44088 .284 Mdot
.59671 .3742 Mdot
.64629 .34467 Mdot
.47011 .19702 Mdot
.67691 .38376 Mdot
.66463 .45285 Mdot
.65583 .44965 Mdot
.65556 .5402 Mdot
.65531 .37695 Mdot
.69697 .68627 Mdot
.49306 .17332 Mdot
.52657 .29288 Mdot
.5093 .23886 Mdot
.68532 .42565 Mdot
.65069 .43662 Mdot
.66267 .55236 Mdot
.70956 .56116 Mdot
.72035 .55023 Mdot
.61256 .44431 Mdot
.59943 .34282 Mdot
.67568 .55571 Mdot
.69701 .54531 Mdot
.52314 .27405 Mdot
.68592 .54725 Mdot
.73328 .51394 Mdot
.72579 .60067 Mdot
.60472 .37407 Mdot
.61545 .38557 Mdot
.6164 .31537 Mdot
.61576 .32603 Mdot
.4887 .17977 Mdot
.49492 .23513 Mdot
.71109 .50624 Mdot
.52391 .21142 Mdot
.68645 .51362 Mdot
.70875 .53033 Mdot
.69419 .48487 Mdot
.6967 .79192 Mdot
.61757 .41421 Mdot
.59577 .31876 Mdot
.70697 .59591 Mdot
.72922 .49591 Mdot
.58331 .32562 Mdot
.70538 .51963 Mdot
.61352 .32246 Mdot
.51387 .21731 Mdot
.7262 .6546 Mdot
.67919 .58814 Mdot
.42233 .53979 Mdot
.6885 .66866 Mdot
.71306 .55357 Mdot
.47362 .2245 Mdot
.48101 .2418 Mdot
.48811 .20836 Mdot
.6637 .41642 Mdot
.53895 .21778 Mdot
.47439 .68714 Mdot
.49152 .23412 Mdot
.45854 .23734 Mdot
.67894 .58919 Mdot
.48912 .63224 Mdot
.69601 .79305 Mdot
.5683 .34237 Mdot
.69254 .4696 Mdot
.59113 .40447 Mdot
.6682 .55652 Mdot
.65182 .46089 Mdot
.4681 .25273 Mdot
.59916 .34908 Mdot
.72523 .48128 Mdot
.41486 .48684 Mdot
.4918 .19096 Mdot
.54875 .3023 Mdot
.56303 .27512 Mdot
.4897 .24895 Mdot
.68743 .70878 Mdot
.69747 .76344 Mdot
.42218 .56791 Mdot
.50292 .20241 Mdot
.42075 .501 Mdot
.71891 .7191 Mdot
.42915 .30232 Mdot
.69654 .60171 Mdot
.70032 .78829 Mdot
.53279 .21195 Mdot
.64163 .42865 Mdot
.53913 .2286 Mdot
.71541 .60885 Mdot
.62661 .34365 Mdot
.6715 .46675 Mdot
.6132 .44063 Mdot
.5651 .26923 Mdot
.46413 .19697 Mdot
.42269 .57636 Mdot
.66694 .44625 Mdot
.43031 .30027 Mdot
.42808 .35631 Mdot
.7068 .57416 Mdot
.68069 .43631 Mdot
.68688 .83134 Mdot
.45746 .69584 Mdot
.53738 .26215 Mdot
.72074 .47508 Mdot
.71844 .49847 Mdot
.68009 .62212 Mdot
.65184 .37013 Mdot
.73438 .61776 Mdot
.65751 .5556 Mdot
.6828 .40248 Mdot
.66559 .43003 Mdot
.46858 .24795 Mdot
.68384 .4666 Mdot
.71965 .71045 Mdot
.64779 .51246 Mdot
.42744 .47885 Mdot
.65883 .47919 Mdot
.64579 .45443 Mdot
.72187 .59358 Mdot
.60084 .30853 Mdot
.61639 .38017 Mdot
.68756 .41961 Mdot
.69925 .44916 Mdot
.68592 .45642 Mdot
.49758 .24416 Mdot
.71374 .59564 Mdot
.6967 .67213 Mdot
.6898 .7479 Mdot
.41893 .48892 Mdot
.46966 .20009 Mdot
.59424 .36343 Mdot
.67792 .39911 Mdot
.72348 .47918 Mdot
.68792 .8395 Mdot
.54973 .33084 Mdot
.5444 .2886 Mdot
.7486 .53901 Mdot
.52644 .20641 Mdot
.45871 .21377 Mdot
.65075 .35563 Mdot
.48004 .68473 Mdot
.63316 .44723 Mdot
.69776 .49879 Mdot
.6875 .54728 Mdot
.71929 .51402 Mdot
.69265 .57249 Mdot
.69856 .48637 Mdot
.50503 .186 Mdot
.69112 .4396 Mdot
.74072 .48708 Mdot
.66938 .57653 Mdot
.62467 .46611 Mdot
.64388 .48292 Mdot
.72267 .4916 Mdot
.67232 .45088 Mdot
.49256 .21428 Mdot
.69614 .43343 Mdot
.67858 .56202 Mdot
.45118 .28288 Mdot
.51624 .26203 Mdot
.5315 .26472 Mdot
.53279 .28157 Mdot
.70933 .60612 Mdot
.71655 .72166 Mdot
.63336 .45757 Mdot
.42939 .52726 Mdot
.68894 .47778 Mdot
.69275 .42018 Mdot
.73305 .53861 Mdot
.43046 .31562 Mdot
.72685 .59988 Mdot
.42614 .47318 Mdot
.68602 .65022 Mdot
.70761 .73388 Mdot
.71559 .50131 Mdot
.73954 .49879 Mdot
.60958 .35481 Mdot
.73287 .61341 Mdot
.67629 .38961 Mdot
.42288 .47802 Mdot
.71066 .68975 Mdot
.72692 .48334 Mdot
.73899 .55622 Mdot
.71941 .59758 Mdot
.51217 .22063 Mdot
.72415 .72188 Mdot
.55371 .23901 Mdot
.43041 .52609 Mdot
.43028 .52746 Mdot
.47181 .68777 Mdot
.52909 .26179 Mdot
.71942 .73507 Mdot
.64539 .47636 Mdot
.42971 .39923 Mdot
.62166 .38084 Mdot
.41772 .51357 Mdot
.43406 .63391 Mdot
.46082 .21965 Mdot
.64213 .34415 Mdot
.56285 .32612 Mdot
.67272 .45592 Mdot
.46003 .24147 Mdot
.64427 .49235 Mdot
.56765 .3451 Mdot
.74052 .50212 Mdot
.43415 .62889 Mdot
.63271 .40987 Mdot
.73297 .49224 Mdot
.53052 .24817 Mdot
.69595 .587 Mdot
.67006 .43365 Mdot
.6652 .58271 Mdot
.49476 .25322 Mdot
.50186 .21154 Mdot
.62346 .31643 Mdot
.43115 .35619 Mdot
.68788 .69259 Mdot
.74267 .58967 Mdot
.43191 .32246 Mdot
.48206 .66147 Mdot
.69165 .78412 Mdot
.57235 .3135 Mdot
.49544 .22632 Mdot
.72814 .63393 Mdot
.51472 .25698 Mdot
.62666 .33997 Mdot
.66278 .48356 Mdot
.64436 .44302 Mdot
.71952 .67225 Mdot
.60263 .32233 Mdot
.67324 .42925 Mdot
.53947 .21889 Mdot
.71541 .51674 Mdot
.42673 .39629 Mdot
.68934 .56819 Mdot
.60057 .41512 Mdot
.53705 .21485 Mdot
.68423 .56339 Mdot
.7352 .57325 Mdot
.45369 .68739 Mdot
.43368 .36005 Mdot
.68542 .59404 Mdot
.53604 .24893 Mdot
.52102 .27371 Mdot
.57092 .25277 Mdot
.48862 .63492 Mdot
.72553 .53237 Mdot
.70887 .50702 Mdot
.54625 .2526 Mdot
.49364 .22372 Mdot
.66795 .57413 Mdot
.42892 .54789 Mdot
.54998 .25328 Mdot
.63929 .43832 Mdot
.51549 .27665 Mdot
.62845 .45933 Mdot
.67485 .571 Mdot
.56176 .3058 Mdot
.68217 .49847 Mdot
.58979 .29934 Mdot
.43448 .28759 Mdot
.57469 .32968 Mdot
.69784 .47952 Mdot
.42094 .37233 Mdot
.4551 .20072 Mdot
.70828 .54288 Mdot
.43702 .26687 Mdot
.62802 .40781 Mdot
.69005 .46516 Mdot
.45247 .69525 Mdot
.48794 .23793 Mdot
.68921 .58912 Mdot
.71917 .58867 Mdot
.45758 .20219 Mdot
.47341 .68144 Mdot
.55972 .35276 Mdot
.67388 .39797 Mdot
.53263 .25905 Mdot
.66495 .56823 Mdot
.70087 .74641 Mdot
.69987 .55799 Mdot
.69524 .66935 Mdot
.68986 .60696 Mdot
.48959 .65883 Mdot
.70512 .48265 Mdot
.69142 .72703 Mdot
.66951 .38437 Mdot
.687 .69242 Mdot
.68917 .8425 Mdot
.55869 .28731 Mdot
.57473 .25589 Mdot
.6443 .42948 Mdot
.71347 .53567 Mdot
.71341 .64061 Mdot
.48305 .22075 Mdot
.70438 .56635 Mdot
.53227 .23975 Mdot
.432 .54472 Mdot
.65082 .38233 Mdot
.59468 .36206 Mdot
.65648 .39794 Mdot
.74645 .54581 Mdot
.441 .64576 Mdot
.63567 .42375 Mdot
.61125 .41823 Mdot
.68898 .6708 Mdot
.43938 .64325 Mdot
.73116 .55518 Mdot
.69565 .70747 Mdot
.72031 .6912 Mdot
.45856 .25304 Mdot
.58812 .27471 Mdot
.59118 .3214 Mdot
.68034 .59101 Mdot
.46954 .186 Mdot
.44985 .669 Mdot
.47226 .67188 Mdot
.56984 .28259 Mdot
.73153 .48173 Mdot
.67671 .62545 Mdot
.42221 .55866 Mdot
.6493 .38257 Mdot
.42744 .536 Mdot
.46744 .68509 Mdot
.6264 .32442 Mdot
.60899 .33812 Mdot
.62463 .46302 Mdot
.51058 .19539 Mdot
.53409 .27444 Mdot
.71452 .75858 Mdot
.5573 .29718 Mdot
.6507 .49928 Mdot
.42313 .44898 Mdot
.71184 .58567 Mdot
.52941 .30174 Mdot
.68561 .46736 Mdot
.65316 .51405 Mdot
.42239 .5833 Mdot
.5705 .36282 Mdot
.6954 .73702 Mdot
.72902 .53799 Mdot
.70407 .44816 Mdot
.67846 .54129 Mdot
.53961 .24594 Mdot
.57661 .29238 Mdot
.68088 .54222 Mdot
.5599 .2781 Mdot
.72798 .54529 Mdot
.73904 .6454 Mdot
.67367 .42843 Mdot
.71919 .60329 Mdot
.73079 .56053 Mdot
.7372 .54645 Mdot
.46265 .68263 Mdot
.56991 .30968 Mdot
.69154 .6853 Mdot
.72778 .51117 Mdot
.46302 .68418 Mdot
.66703 .54308 Mdot
.5794 .36913 Mdot
.61267 .34282 Mdot
.6407 .42531 Mdot
.69572 .60926 Mdot
.62885 .34844 Mdot
.70061 .52994 Mdot
.6736 .62806 Mdot
.65411 .54698 Mdot
.70137 .43047 Mdot
.65803 .49731 Mdot
.69919 .67637 Mdot
.69705 .82088 Mdot
.67724 .63678 Mdot
.629 .40432 Mdot
.45563 .66045 Mdot
.70584 .67777 Mdot
.54753 .24209 Mdot
.47288 .67132 Mdot
.73576 .51865 Mdot
.66432 .41891 Mdot
.46065 .6932 Mdot
.46609 .22934 Mdot
.51789 .2173 Mdot
.50184 .23663 Mdot
.71249 .49532 Mdot
.661 .37087 Mdot
.70074 .71056 Mdot
.73351 .53855 Mdot
.60069 .3779 Mdot
.69137 .79385 Mdot
.59166 .33853 Mdot
.5245 .26308 Mdot
.50067 .21298 Mdot
.49756 .62452 Mdot
.73027 .50101 Mdot
.72501 .56505 Mdot
.52433 .28775 Mdot
.42189 .43339 Mdot
.42334 .31769 Mdot
.41642 .43198 Mdot
.74065 .56555 Mdot
.47931 .17742 Mdot
.67448 .54357 Mdot
.42975 .35345 Mdot
.47042 .20569 Mdot
.43066 .57969 Mdot
.49047 .18715 Mdot
.61175 .44462 Mdot
.46178 .21323 Mdot
.42941 .39943 Mdot
.74249 .58098 Mdot
.71555 .5867 Mdot
.5022 .52771 Mdot
.59896 .33849 Mdot
.56659 .27268 Mdot
.63609 .49909 Mdot
.58137 .37383 Mdot
.50003 .22778 Mdot
.71711 .64892 Mdot
.73475 .6896 Mdot
.63718 .3792 Mdot
.68955 .82103 Mdot
.61107 .29754 Mdot
.42345 .48794 Mdot
.68184 .66733 Mdot
.68774 .69565 Mdot
.50468 .2476 Mdot
.65062 .54206 Mdot
.70858 .76985 Mdot
.42475 .39772 Mdot
.45802 .68601 Mdot
.5431 .30587 Mdot
.67161 .55015 Mdot
.58313 .36989 Mdot
.7126 .74057 Mdot
.42542 .52333 Mdot
.61742 .42661 Mdot
.59343 .33243 Mdot
.42514 .59479 Mdot
.43106 .56996 Mdot
.42871 .32026 Mdot
.72901 .475 Mdot
.45329 .69042 Mdot
.69074 .44821 Mdot
.63653 .36391 Mdot
.62862 .37595 Mdot
.68322 .47702 Mdot
.66221 .57539 Mdot
.59456 .35682 Mdot
.74029 .66182 Mdot
.4628 .23097 Mdot
.73191 .47971 Mdot
.73818 .55614 Mdot
.52596 .30265 Mdot
.70499 .46649 Mdot
.57355 .34263 Mdot
.60445 .42677 Mdot
.68508 .45831 Mdot
.63951 .41108 Mdot
.48487 .19932 Mdot
.56802 .35274 Mdot
.60919 .41494 Mdot
.74398 .59529 Mdot
.62435 .43346 Mdot
.50135 .58918 Mdot
.62109 .42775 Mdot
.58612 .37678 Mdot
.47937 .69079 Mdot
.4849 .24702 Mdot
.61512 .40066 Mdot
.60559 .33859 Mdot
.43966 .63256 Mdot
.54668 .2747 Mdot
.71289 .55608 Mdot
.47329 .18235 Mdot
.63877 .44452 Mdot
.43849 .24617 Mdot
.54182 .31585 Mdot
.46021 .68305 Mdot
.70427 .80475 Mdot
.45101 .66236 Mdot
.63394 .34889 Mdot
.68235 .63844 Mdot
.67263 .56044 Mdot
.48844 .20769 Mdot
.68725 .46474 Mdot
.73067 .54654 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0^Oooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1Oooool00ol0003oooooooooo`2iooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`2iooooo`00POooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVY
ZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000;Wooooo0029ooooo`05o`000?oo
ooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0^Oooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEE
EOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;Wo
oooo0029ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0^Oooool008Wooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo0;Wooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`00
00Cooooo1?l00006ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Ooo
ool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:Wo
oooo0_l000000ooooooo0000ooooo`2jooooo`00ZOooool2o`000004ooooool0003o0000o`000;Wo
oooo002Uooooo`;o000000?oooooo`000?l000000_ooool00ol0003oooooooooo`2iooooo`00Xooo
ool4o`000003ooooool0003o000000;ooooo00?o0000ooooooooool0^Oooool00:;ooooo0ol00007
ooooo`?o0000^Oooool00:;ooooo0_l00004ooooo`;o00000_ooool3o`000;Wooooo002Xooooo`?o
000000?oooooo`000?ooool0^_ooool00:Wooooo0_l000001?oooooo0000ooooooooool2o`000;Oo
oooo002Pooooo`Co00001Oooool2o`000004ooooool0003oooooooooo`;o0000]oooool009gooooo
0_l000000ooooooo0000o`000002o`0000?ooooo0_l00003ooooo`?o0000^Oooool009gooooo0ol0
0002ooooo`;o00000oooool2o`0000?ooooo0ol0002iooooo`00W_ooool2o`0000;ooooo0_l00004
ooooo`;o00000_ooool3o`0000Gooooo0_l0002booooo`00X_ooool2o`0000Cooooo0_l00002oooo
o`03o`000?oooooooooo00Gooooo0_l0002booooo`00Woooool2o`0000Oooooo0_l00002ooooo`;o
00001Oooool2o`000003ooooool0003o00000;3ooooo002Nooooo`?o00002?ooool2o`000003oooo
ool0003o000000Gooooo0_l000000ooooooo0000o`000002o`000:kooooo002Nooooo`?o00001Ooo
ool2o`000005ooooool0003o0000ooooool000000oooool3o`0000Gooooo0ol0002]ooooo`00Wooo
ool2o`0000Gooooo0_l00004ooooo`04o`000?ooooooooooooooo`?o00001Oooool3o`000:gooooo
002Sooooo`;o000000Coooooo`000?l0003ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o
0000]_ooool00:?ooooo0_l00004ooooo`Go00002_ooool2o`000:kooooo002Oooooo`?o00002?oo
ool4o`0000[ooooo0_l0002^ooooo`00Woooool3o`0000Oooooo0_l000000ooooooo0000ooooo`2j
ooooo`00WOooool3o`0000Sooooo1_l0002jooooo`00WOooool3o`0000Sooooo1_l000000ooooooo
0000o`000005ooooo`;o00001Oooool2o`000:Wooooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@03ooooool0003o000000;ooooo00?oA4A4o`000?l000000_l00005ooooo`03
o`000?oooooooooo00;o00001Oooool2o`0000?ooooo1?l0002Yooooo`00TOooool01_mgMgOoV9RH
oooooonHV9SoMgMgooooo`;o00000_ooool2ob4Q8@03ooooool0003o000000Gooooo1?l00002oooo
o`;o00003?ooool4o`000:_ooooo0029ooooo`Ko00000_ooool01_l@413ooooooooooooooooo410@
ooooo`;o00002?ooool2o`0000?ooooo1?l000000ooooooo0000o`000002o`0000Oooooo1Ol0002]
ooooo`00TOooool01Ol0003ooooooooooooooooo000000Sooooo0_l000000ooooooo0000o`000002
ooooo`03ogMgMolb<S;ooooo00;o00000_ooool3o`0000Oooooo0ol00002ooooo`;o00001_ooool2
o`000:?ooooo002Aooooo`05o`000?ooooooooooooooool000002?ooool2o`000007ooooool0003o
0000ob4Q8Ol0003o<S8bolc<c003ooooo`?o00003_ooool3o`0000Gooooo0ol0002Rooooo`00TOoo
ool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01Oooool3o`0000?ooooo
0_l00004ooooo`;o00001?ooool2o`0000Kooooo0_l0002Rooooo`00TOooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool01?l0003oooooooooooooool3o`0000;o
oooo1Ol0002^ooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`03
o`000?oooooooooo00;ooooo0_l000000ooooooo0000o`000004o`000:kooooo002Gooooo`;o0000
4oooool00ol0003oooooooooo`05ooooo`Co0000/?ooool009Oooooo0_l00002ooooo`;o00003ooo
ool00ol0003oooooooooo`0Booooo`;o0000YOooool009_ooooo0_l0000?ooooo`03o`000?oooooo
oooo00Cooooo0_l0000<ooooo`?o0000Y?ooool00:cooooo0ol00002ooooo`Co00000_ooool2o`00
00;ooooo0_l00003ooooo`Co00001Oooool2o`0009gooooo002/ooooo`03o`000?oooooooooo00;o
oooo0_l00004ooooo`;o00000_ooool2o`0000;ooooo0ol00007ooooo`;o0000WOooool009_ooooo
0_l0000?ooooo`03o`000?oooooooooo00Oooooo0_l00007ooooo`;o00000_ooool2o`000:?ooooo
002Hooooo`;o000000?oooooo`000?l000003oooool00ol0003oooooooooo`07ooooo`;o00002ooo
ool2o`000:?ooooo002Fooooo`Co00004_ooool00ol0003oooooooooo`05ooooo`;o00001?ooool2
o`0000?ooooo0_l0002Wooooo`00U_ooool2o`0001Cooooo00?o0000ooooooooool01Oooool2o`00
00Cooooo0_l00003ooooo`;o00001?ooool2o`000:7ooooo002/ooooo`03o`000?oooooooooo00Go
oooo0_l0000?ooooo`;o0000XOooool00:cooooo00?o0000ooooooooool01Oooool2o`0000Sooooo
0_l0000@ooooo`;o0000U_ooool009Gooooo0_l0000Eooooo`?o00003oooool2o`0000Wooooo0_l0
0005ooooo`;o0000U_ooool009Cooooo0ol0000Eooooo`03o`000?oooooooooo00Gooooo0ol00005
ooooo`;o00002oooool2o`0009gooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`05oooo
o`?o00000oooool4o`0000;ooooo0_l0002Vooooo`00U?ooool2o`0001Kooooo00?o0000oooooooo
ool02oooool2o`0000Cooooo0_l000000ooooooo0000o`000008ooooo`;o0000VOooool009Cooooo
0_l0000Fooooo`03o`000?oooooooooo01Cooooo0_l00008ooooo`;o0000VOooool009Gooooo0_l0
000Eooooo`03o`000?oooooooooo00[ooooo0_l00008ooooo`;o00003Oooool4o`0009;ooooo002B
ooooo`;o000000?oooooo`000?l000005Oooool00ol0003oooooooooo`0:ooooo`;o00004?ooool2
o`0000Gooooo1?l0002Booooo`00T_ooool5o`0001Gooooo00?o0000ooooooooool06oooool5o`00
00;ooooo0_l0002Eooooo`00U?ooool3o`0001Gooooo0ol0000Hooooo`;o000000Coooooo`000?l0
003ooooo0_l00002ooooo`;o00000_ooool2o`00097ooooo002/ooooo`03o`000?oooooooooo017o
oooo0_l00005ooooo`;o00002Oooool2o`000003ooooool0003o0000097ooooo002/ooooo`03o`00
0?oooooooooo00gooooo0_l00002ooooo`;o00000_ooool2o`0000cooooo0_l0002Dooooo`00[?oo
ool00ol0003oooooooooo`0=ooooo`;o00001_ooool2o`0000Cooooo0_l0002Looooo`00[?ooool0
0ol0003oooooooooo`0Kooooo`;o0000W?ooool00:cooooo00?o0000ooooooooool06oooool8o`00
00?ooooo0_l0002Aooooo`00[?ooool00ol0003oooooooooo`0Cooooo`Co00001?ooool9o`0000;o
oooo0_l0002Aooooo`00[?ooool00ol0003oooooooooo`0Cooooo`Co00001_ooool2o`0000?ooooo
0_l00002ooooo`;o00000oooool4o`0008[ooooo002/ooooo`03o`000?oooooooooo01?ooooo0_l0
0008ooooo`;o00002?ooool8o`0008[ooooo002/ooooo`?o00004?ooool2o`000003ooooool0003o
000000Sooooo0_l00008ooooo`Co00000_ooool2o`0008[ooooo002Dooooo`;o00005_ooool00ol0
003oooooooooo`0@ooooo`;o000000?oooooo`000?l000003?ooool2o`0000_ooooo0_l00029oooo
o`00U?ooool3o`0001Gooooo00?o0000ooooooooool07?ooool2o`0000?ooooo1?l00009ooooo`;o
0000ROooool009Cooooo1?l0000Dooooo`03o`000?oooooooooo01cooooo0_l00005ooooo`;o0000
U?ooool009Kooooo0_l0000Dooooo`03o`000?oooooooooo01Cooooo0_l00006ooooo`;o00003?oo
ool2o`0008gooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0
0004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Dooooo`;o0000
1_ooool2o`0000cooooo0_l0002=ooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo01Oooooo0ol0000Eooooo`;o000000?oooooo`000?l00000QOooool0087ooooo
1_l00002ooooo`05oa0@4?ooooooooooooooool@41000oooool2o`0000Oooooo00?oV9RHob4Q8Oo^
k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Oooooo0ol00002ooooo`;o
000000?oooooo`000?l000002_ooool2o`0000;ooooo0_l000000ooooooo0000o`000025ooooo`00
ROooool01Ol0003ooooooooooooooooo000000?ooooo0_l00008ooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo00?oMgMgoc8b<_ooool01?ooool3o`0001Oooooo1?l000001?oooooo0000o`000?ooool2o`00
00Kooooo0_l00002ooooo`;o00000oooool2o`0008Oooooo0029ooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`0Iooooo`;o00000oooool2o`0000?ooooo0_l00002ooooo`;o000000?ooooo
o`000?l000001?ooool2o`0008Oooooo0029ooooo`05oa0@4?ooooooooooooooool@41003oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07_ooool2
o`0000?ooooo1?l00003ooooo`;o00000_ooool2o`0008Wooooo0029ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Sooooo`Co00001oooool2o`0000Gooooo1?l00020ooooo`00ROooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co0000
1_ooool00ol0003oooooooooo`0Sooooo`;o00004?ooool4o`00083ooooo002/ooooo`03o`000?oo
oooooooo03Oooooo0_l00020ooooo`00[?ooool00ol0003oooooooooo`0gooooo`;o0000P?ooool0
09?ooooo0_l0000Gooooo`03o`000?oooooooooo033ooooo0_l00004ooooo`;o0000POooool009?o
oooo0ol0000Fooooo`?o00008oooool2o`0000_ooooo0_l00004ooooo`?o0000P?ooool009Cooooo
0_l0000Fooooo`03o`000?oooooooooo01_ooooo0_l00006ooooo`;o00000_ooool2o`0000kooooo
1?l0001nooooo`00[?ooool00ol0003oooooooooo`0Kooooo`;o00002_ooool2o`000003ooooool0
003o000000gooooo0_l0001nooooo`00[?ooool00ol0003oooooooooo`0Wooooo`Go0000SOooool0
0:cooooo00?o0000ooooooooool09oooool3o`000003ooooool0003o000008cooooo002/ooooo`03
o`000?oooooooooo01kooooo0_l000000ooooooo0000o`000002o`0000Kooooo0_l00006ooooo`;o
0000Q?ooool00:cooooo00?o0000ooooooooool07_ooool2o`000003ooooool0003o000000;o0000
3_ooool2o`0000Gooooo0_l0001mooooo`00[?ooool00ol0003oooooooooo`0Qooooo`;o00004?oo
ool2o`0000Gooooo1?l0001kooooo`00[?ooool3o`0002Wooooo1?l0000=ooooo`Co0000Noooool0
0:cooooo00?o0000ooooooooool07oooool2o`0000;ooooo1?l00002ooooo`Co00002Oooool2o`00
00;ooooo0_l0001mooooo`00[?ooool00ol0003oooooooooo`0Oooooo`;o00000_ooool4o`0000Co
oooo0ol00005ooooo`;o000000?oooooo`000?l000001oooool2o`0007Sooooo002@ooooo`Co0000
6?ooool00ol0003oooooooooo`0Vooooo`;o00001?ooool2o`0000Gooooo1Ol00005ooooo`Co0000
N?ooool0093ooooo1?l0000Hooooo`03o`000?oooooooooo02Kooooo0_l00006ooooo`;o00001Ooo
ool2o`000003ooooool0003o000000?ooooo0_l0001jooooo`00[?ooool00ol0003oooooooooo`0R
ooooo`;o00001oooool2o`000003ooooool0003o000000Sooooo0_l00002ooooo`;o0000Noooool0
0:cooooo00?o0000ooooooooool08_ooool2o`0000Oooooo0ol0000>ooooo`;o0000Noooool00:co
oooo00?o0000ooooooooool08Oooool3o`0000Kooooo1?l00006ooooo`;o0000Poooool009;ooooo
0_l0000Hooooo`03o`000?oooooooooo027ooooo0ol00005ooooo`?o00001?ooool2o`0000;ooooo
0_l00006ooooo`Ko0000Moooool009;ooooo0_l0000Hooooo`?o0000:Oooool2o`0000Gooooo0_l0
00000ooooooo0000o`000002o`0000Gooooo1_l0001gooooo`00[?ooool00ol0003oooooooooo`0]
ooooo`;o00001?ooool5o`00087ooooo002/ooooo`03o`000?oooooooooo02Wooooo0_l00002oooo
o`;o00001oooool2o`0000;ooooo0_l0001mooooo`002Oooool4o`000003oa0@4?oooooooooo01Ko
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04oooo
o`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Kooooo00?o0000oooo
ooooool06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B43ooooo`Ko00000_ooool2
o`000005odA4A?l0003o0000oc8b<_oMgMd01?ooool2o`0000Wooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000
oc8b<_oMgMd06?ooool4o`000003oa0@4?oooooooooo01;ooooo000;ooooo`03o`000?oooooooooo
01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07
ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo
00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo01Gooooo00?o0000oooooooo
ool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B42ooooo`?o000000Co8B4Qonk^
k_ooooooA4A40_ooool2o`0000?ooooo00?oMgMgoc8b<_ooool00oooool3o`0000Sooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8b
ooooo`0Iooooo`03o`000?oooooooooo01Cooooo0006o`0000Gooooo00?o0000ooooooooool04?oo
ool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo
00?o0000ooooooooool01Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03
o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onH
V9So8B4Qonk^kP09ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool06?ooool01Ol@
413ooooooooooooooooo410@00Wooooo0_l000001?ooooooV9RHob4Q8Oo^k^h9ooooo`;o00000_oo
ool4o`0000?ooooo0_l00003ooooo`03oa0@4?oooooooooo00;o00004?ooool00ol0003ooooooooo
o`0=ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?oo
ool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8b
ooooo`0>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0>ooooo`05
o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo
01Gooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000Wooooo0_l00002
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgo`000?l000000_ooool5o`0000;ooooo0_l00003
ooooo`03o`000?oooooooooo00;o00003oooool00omgMgOo<S8booooo`0>ooooo`05o`000?oooooo
ooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Wooooo00?o
0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooo
oooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo
00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0
003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?l0
003oc<c<01Kooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000kooooo
00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Kooooo0_l00007ooooo`05
o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000
ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00Jooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go
410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool0
4Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04Oooool01Ol@413o
oooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool01?l0003oooooo`000?l0000G
ooooo`?o00006?ooool01Ol@413ooooooooooooooooo410@00oooooo0ol00002ooooo`03o`000?oo
oooooooo00Gooooo0_l0000:ooooo`;o000000?oooooo`000?l000003?ooool00ol0003ooooooooo
o`0Aooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03
o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo
017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?oo
ool5o`0001Kooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go0000okZj^_ooooooV9RHoa0@4002o`0000;ooooo0_l00006ooooo`Co000000?oooooo`000?l0
00001Oooool6o`0000_ooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool05?ooool000Wooooo00?oEEEEofIVI_l000006_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00_ooooo1Ol00004ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0
000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Co
oooo1Ol0000Fooooo`03o`000?oooooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`04oiRHV?l@413o0000ob4Q8@;o00000oooool4o`0000Kooooo0_l000000ooooooo0000o`000002
o`0000?ooooo00?ok^k^o`000?l000000ol0000;ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00006Oooool00omEEEGoIVIVo`00000Fooooo`00[?ooool0
0ol0003oooooooooo`0/ooooo`;o00001?ooool2o`0000Wooooo1Ol00005ooooo`Co0000K_ooool0
08oooooo1Ol0000Hooooo`03o`000?oooooooooo03;ooooo0_l00009ooooo`?o00003?ooool2o`00
06_ooooo002?ooooo`Go00006?ooool00ol0003oooooooooo`0/ooooo`;o00006?ooool2o`000004
ooooool0003o0000ooooo`;o0000H?ooool2o`0000;ooooo0_l00005ooooo`00[?ooool00ol0003o
ooooooooo`0/ooooo`;o00005Oooool2o`000004ooooool0003o0000ooooo`;o0000Hoooool01_o^
k^ko8B4QohN7Qonj^[[o0000omgMg@Gooooo002/ooooo`03o`000?oooooooooo037ooooo0_l00006
ooooo`;o00002?ooool4o`000003ooooool0003o000006Gooooo00CogMgMo`000?l@413oc<c<1_oo
ool000Ooooooool0001<o`0000cooooo00Cok^k^ob4Q8Ol@413ok^k^1_ooool000Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`03ooooo`;o000000?oooooo`000?ooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`04o`000?oooooo0000o`0000?ooooo0_l00007ooooo`03o`000?oo
oooooooo00Cooooo0_l00004ooooo`;o00000_ooool3o`000003ooooool0003o000000;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`04ob4Q8OmgMgOoMgMgoc8b<PKooooo
0007ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`0Hooooo`;o00002?ooool2o`0000;ooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo00Wooooo0_l00002ooooo`;o00001Oooool00:cooooo00?o0000
ooooooooool0@_ooool2o`0007Gooooo002@ooooo`;o00006_ooool00ol0003oooooooooo`0]oooo
o`;o00002oooool2o`0000cooooo0_l0001_ooooo`00T?ooool2o`0001[ooooo00?o0000oooooooo
ool0;Oooool4o`0000Wooooo0_l00009ooooo`;o000000?oooooo`000?l000000_l0001]ooooo`00
[?ooool00ol0003oooooooooo`0_ooooo`;o00003oooool2o`0000;ooooo0ol00003ooooo`;o0000
KOooool00:cooooo00?o0000ooooooooool0@?ooool2o`0000;ooooo0_l00004ooooo`;o0000KOoo
ool009?ooooo0_l0000Gooooo`?o0000^Oooool009?ooooo1?l0000Eooooo`;o0000^_ooool009Co
oooo0ol0000Eooooo`;o0000@?ooool4o`0007Kooooo002/ooooo`03o`000?oooooooooo03oooooo
1?l00004ooooo`;o0000L?ooool009Cooooo0_l0000Fooooo`03o`000?oooooooooo04?ooooo0_l0
0002ooooo`;o0000L?ooool009;ooooo1?l0000Fooooo`03o`000?oooooooooo033ooooo0_l0000A
ooooo`;o00000oooool4o`0000?ooooo0_l0001Xooooo`00T_ooool2o`0001Sooooo00?o0000oooo
ooooool0;_ooool4o`0000;ooooo1_l00007ooooo`;o00001Oooool4o`0000?ooooo0_l0001Xoooo
o`00UOooool2o`0001Gooooo00?o0000ooooooooool0;_ooool2o`0000Cooooo1_l00004ooooo`;o
000000?oooooo`000?l000001Oooool5o`000003ooooool0003o000006Wooooo002Dooooo`?o0000
5Oooool00ol0003oooooooooo`0_ooooo`;o00002Oooool2o`0000;ooooo0_l00008ooooo`Go0000
00?oooooo`000?l00000JOooool009Cooooo0_l0000Fooooo`?o0000;oooool2o`000004ooooool0
003o0000ooooo`;o00000oooool2o`0000Wooooo0_l0001booooo`00[?ooool00ol0003ooooooooo
o`0aooooo`?o000000?oooooo`000?l000000_l0000:ooooo`Co00000_ooool2o`0006kooooo002B
ooooo`;o00006?ooool00ol0003oooooooooo`0aooooo`;o000000Coooooo`000?l0003ooooo0_l0
0006ooooo`;o00000_ooool2o`0000Cooooo1?l0001/ooooo`00T_ooool2o`0001Sooooo0_l0000e
ooooo`Ko00001Oooool2o`000004ooooool0003o0000o`0000;ooooo1_l0001/ooooo`00[?ooool2
o`0003Oooooo1Ol00007ooooo`;o00000oooool4o`0006kooooo002Booooo`;o00006?ooool00ol0
003oooooooooo`0iooooo`;o00001Oooool2o`0000Gooooo0_l00003ooooo`;o0000Joooool009;o
oooo0_l000000ooooooo0000o`00000Eooooo`03o`000?oooooooooo03?ooooo0_l000000ooooooo
0000o`000003ooooo`;o00000oooool2o`0000[ooooo0_l0001[ooooo`00UOooool2o`0001Gooooo
00?o0000ooooooooool0<oooool5o`0000?ooooo0ol00003ooooo`;o00001oooool2o`0006gooooo
002Booooo`;o00006?ooool3o`0003;ooooo1?l00006ooooo`;o00000oooool2o`0000Oooooo0_l0
001]ooooo`00T_ooool2o`000003ooooool0003o000001Gooooo00?o0000ooooooooool0<_ooool4
o`0008?ooooo002Booooo`;o000000?oooooo`000?l000005Oooool00ol0003oooooooooo`0coooo
o`;o00006?ooool2o`0006[ooooo002Booooo`;o00006?ooool00ol0003oooooooooo`0cooooo`;o
00003Oooool2o`0000Wooooo0_l0001Zooooo`00[?ooool2o`0003Wooooo0_l000000ooooooo0000
o`000002o`0000?ooooo1Ol0001booooo`00[?ooool2o`0003Wooooo0_l000000ooooooo0000o`00
0002o`0000Gooooo0ol00006ooooo`;o0000J_ooool009?ooooo0_l0000Gooooo`03o`000?oooooo
oooo03Sooooo1?l0000:ooooo`;o00001Oooool2o`0006[ooooo002Cooooo`;o00005oooool00ol0
003oooooooooo`0jooooo`;o00001Oooool7o`0000Gooooo0_l0001Zooooo`00[?ooool3o`00047o
oooo2?l0001`ooooo`00[?ooool00ol0003oooooooooo`0mooooo`;o00001_ooool4o`00073ooooo
002/ooooo`03o`000?oooooooooo03_ooooo1?l00003ooooo`;o000000?oooooo`000?l00000L_oo
ool00:cooooo00?o0000ooooooooool0>oooool4o`0000?ooooo1?l0001cooooo`00[?ooool00ol0
003oooooooooo`0mooooo`;o00001Oooool2o`0000?ooooo0_l0001^ooooo`00[?ooool00ol0003o
ooooooooo`0nooooo`;o00002Oooool2o`0006kooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`0nooooo`;o00002_ooool2o`0006gooooo0029ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0>?ooool2o`00013ooooo0_l0001]ooooo`00ROooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`02
ooooo`Co0000=oooool3o`0007oooooo0029ooooo`05o`000?ooooooooooooooool000003Oooool0
0onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00?ooooo0_l0000hooooo`?o0000P?ooool0
08Wooooo00Go0000ooooooooooooooooo`000008ooooo`;o00001?ooool00omgMgOoIVIVooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0fooooo`;o0000POoo
ool008Wooooo00Go410@oooooooooooooooooa0@4008ooooo`Co00000oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo0_l00002ooooo`03o`000?oooooooooo04Sooooo0_l0
001_ooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo1?l000001?nj^[[ooooooiRH
V?l@4104ooooo`03o`000?oooooooooo00?ooooo0_l00002ooooo`03o`000?oooooooooo03Oooooo
0_l0000?ooooo`;o0000Koooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000;ooooo0_l00002ooooo`03o`000?oooooooooo03Oo
oooo1?l00008ooooo`;o0000M?ooool009Sooooo0_l0000Booooo`03o`000?oooooooooo03Wooooo
0_l00008ooooo`;o0000M?ooool009Sooooo0_l0000Booooo`03o`000?oooooooooo04_ooooo0_l0
001/ooooo`00V?ooool2o`0001;ooooo00?o0000ooooooooool0A?ooool2o`0000Gooooo0_l0001/
ooooo`00[?ooool3o`0003[ooooo0_l00008ooooo`;o0000Loooool00:cooooo00?o0000oooooooo
ool0>_ooool2o`0000_ooooo0_l0001`ooooo`00W_ooool2o`0000Sooooo0_l00002ooooo`03o`00
0?oooooooooo04Oooooo0_l0001`ooooo`00WOooool3o`0000Kooooo1?l00002ooooo`03o`000?oo
oooooooo04cooooo0_l0001[ooooo`00Voooool4o`0000Oooooo0_l00004ooooo`03o`000?oooooo
oooo04cooooo0_l0001[ooooo`00Voooool2o`0000oooooo00?o0000ooooooooool0>Oooool2o`00
07kooooo002Kooooo`;o00003oooool00ol0003oooooooooo`0iooooo`Ko0000N_ooool009_ooooo
0_l00005ooooo`?o00001oooool00ol0003oooooooooo`0kooooo`Co00001_ooool2o`0007;ooooo
002Rooooo`?o00001oooool3o`0003gooooo0ol00005ooooo`;o0000L_ooool00:cooooo00?o0000
ooooooooool0?_ooool2o`000003ooooool0003o000007Kooooo002Nooooo`?o00000_ooool2o`00
00Oooooo00?o0000ooooooooool0@Oooool2o`0007Kooooo002Nooooo`Wo00001Oooool00ol0003o
ooooooooo`0looooo`Co0000NOooool009cooooo2ol00005ooooo`03o`000?oooooooooo03cooooo
1?l0001iooooo`00W?ooool2o`0000Cooooo1Ol00005ooooo`03o`000?oooooooooo04;ooooo0_l0
00000ooooooo0000o`000003ooooo`;o0000KOooool009cooooo0_l000000ooooooo0000o`000004
ooooo`;o00001Oooool00ol0003oooooooooo`0jooooo`?o00001Oooool2o`000003ooooool0003o
000000?ooooo0_l0001]ooooo`00W?ooool5o`0000_ooooo00?o0000ooooooooool0>_ooool3o`00
07cooooo002Nooooo`;o00003?ooool3o`0003[ooooo0ol0001looooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool00ol0003oooooooooo`0mooooo`;o0000N_ooool00:cooooo00?o0000
ooooooooool0>_ooool2o`000003ooooool0003o000000Kooooo0_l0001booooo`00[?ooool00ol0
003oooooooooo`0jooooo`;o00000oooool2o`0000Cooooo0_l0001booooo`00[?ooool00ol0003o
ooooooooo`0oooooo`;o0000N?ooool00:cooooo00?o0000ooooooooool0AOooool2o`0007;ooooo
002/ooooo`03o`000?oooooooooo04Cooooo1Ol0001`ooooo`00[?ooool3o`0004Cooooo0_l00000
0ooooooo0000o`00001`ooooo`00[?ooool00ol0003oooooooooo`0looooo`;o0000Noooool00:co
oooo00?o0000ooooooooool0??ooool2o`0007_ooooo002/ooooo`03o`000?oooooooooo047ooooo
0_l0001fooooo`00[?ooool00ol0003oooooooooo`0mooooo`;o00000_ooool2o`0000;ooooo0_l0
001booooo`00[?ooool00ol0003oooooooooo`0mooooo`;o00001?ooool4o`0007;ooooo002Aoooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@05ooooo`03o`000?oooooooooo04?ooooo0_l0001dooooo`00TOooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0?ooo
ool2o`0007Sooooo002Aooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo03_ooooo0_l00002ooooo`;o0000N?ooool0097ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000kooooo`;o0000O?oo
ool0097ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`2iooooo`00TOooool01Ol@413ooooooooooooooooo410@00cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`13ooooo`;o0000M?ooool0097ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
@oooool2o`0007Cooooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo
00?o0000ooooooooool0?_ooool2o`0007Wooooo002/ooooo`03o`000?oooooooooo03kooooo0_l0
001iooooo`00[?ooool00ol0003oooooooooo`11ooooo`;o0000M_ooool00:cooooo00?o0000oooo
ooooool0@Oooool2o`0007Kooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0??ooool2
o`0007_ooooo002/ooooo`03o`000?oooooooooo03cooooo0_l000000ooooooo0000o`00001hoooo
o`00[?ooool00ol0003oooooooooo`0mooooo`Co0000N?ooool00:cooooo00?o0000ooooooooool0
??ooool3o`0007[ooooo002/ooooo`03o`000?oooooooooo03cooooo0ol0001jooooo`00[?ooool3
o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo043o
oooo0_l0001gooooo`00[?ooool00ol0003oooooooooo`10ooooo`;o0000Moooool00:cooooo00?o
0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0>oooool2o`000003ooooool0003o000007Wo
oooo002/ooooo`?o0000>oooool2o`000003ooooool0003o000007Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo03[ooooo0_l0001mooooo`00[?ooool00ol0
003oooooooooo`0jooooo`;o0000OOooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0>oooool2o`0007cooooo002/ooooo`03o`000?oooooooooo03_ooooo0_l0
001looooo`00[?ooool00ol0003oooooooooo`0kooooo`;o0000O?ooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0;Wooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEE
ojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;Wooooo0029oooo
o`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0^Oooool008Wooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`000;Wooooo0029oooo
o`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2iooooo`00ROooool01Ol@413ooooooooooooo
oooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0;Wooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooo
oooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2iooooo`00ROoo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Ooo
ool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0
002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Rooooo`Co0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`2iooooo`00Y?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`03o`000?oooooooooo00Gooooo0ol0002i
ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00
Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00X_ooool0
0omEEEGoIVIVo`000033ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00Z_ooool01?l@413o0000o`000?l0002jooooo`00Zoooool00ol0003oooooooooo`2j
ooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool01_l0003oMgMgo`000?l0003oEEEE
onk^k[Oooooo002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoEEEE]oooool00:_ooooo00?o0000
onk^k_ooool00_ooool00ol0003oooooooooo`2eooooo`00Zoooool00ol0003ok^k^ooooo`02oooo
o`03o`000?oooooooooo0;Gooooo002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoIVIV]oooool0
0:[ooooo00?o410@o`000?mgMgL00_l000000omVIVKok^k^ooooo`2fooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.55914 .20566 Mdot
.54957 .17325 Mdot
.48721 .3753 Mdot
.43004 .65336 Mdot
.40415 .48762 Mdot
.51858 .15853 Mdot
.51406 .5595 Mdot
.67543 .26651 Mdot
.70372 .4152 Mdot
.42136 .63997 Mdot
.41154 .5275 Mdot
.71051 .36144 Mdot
.5454 .14751 Mdot
.44398 .74968 Mdot
.72451 .49731 Mdot
.43523 .69571 Mdot
.50639 .1742 Mdot
.54416 .14467 Mdot
.40992 .5869 Mdot
.59042 .18376 Mdot
.60577 .25285 Mdot
.59569 .24965 Mdot
.63164 .3402 Mdot
.56609 .17695 Mdot
.73148 .48627 Mdot
.39977 .49181 Mdot
.42554 .31819 Mdot
.41128 .40618 Mdot
.61558 .22565 Mdot
.58534 .23662 Mdot
.64362 .35236 Mdot
.69402 .36116 Mdot
.70044 .35023 Mdot
.55029 .24431 Mdot
.49656 .14315 Mdot
.65796 .35571 Mdot
.67513 .34531 Mdot
.42017 .33699 Mdot
.66482 .34725 Mdot
.69886 .31394 Mdot
.72606 .40067 Mdot
.51435 .17407 Mdot
.52967 .18557 Mdot
.50255 .11537 Mdot
.50617 .12603 Mdot
.40213 .50947 Mdot
.41287 .47033 Mdot
.67358 .30624 Mdot
.40562 .34699 Mdot
.6519 .31362 Mdot
.68088 .33033 Mdot
.64814 .28487 Mdot
.77346 .59192 Mdot
.54325 .21421 Mdot
.48339 .12622 Mdot
.70533 .39591 Mdot
.68758 .29591 Mdot
.47403 .14475 Mdot
.67323 .31963 Mdot
.5025 .12246 Mdot
.40634 .39047 Mdot
.74804 .4546 Mdot
.67444 .38814 Mdot
.49508 .72137 Mdot
.71597 .46866 Mdot
.69448 .35357 Mdot
.41515 .56564 Mdot
.41733 .5296 Mdot
.4085 .50587 Mdot
.59027 .21642 Mdot
.41064 .28035 Mdot
.52199 .52329 Mdot
.41338 .4854 Mdot
.42122 .62869 Mdot
.67462 .38919 Mdot
.50561 .44195 Mdot
.77323 .59305 Mdot
.46646 .17722 Mdot
.64038 .2696 Mdot
.51292 .20447 Mdot
.6508 .35652 Mdot
.59618 .26089 Mdot
.42251 .58362 Mdot
.4988 .14913 Mdot
.67775 .28128 Mdot
.48514 .76545 Mdot
.4039 .49349 Mdot
.43825 .22922 Mdot
.43937 .18265 Mdot
.41701 .49015 Mdot
.73094 .50878 Mdot
.76284 .56344 Mdot
.50125 .71598 Mdot
.40405 .44244 Mdot
.48695 .73663 Mdot
.76655 .5191 Mdot
.44176 .74297 Mdot
.69722 .40171 Mdot
.77564 .58829 Mdot
.40741 .30789 Mdot
.57309 .22865 Mdot
.41344 .27752 Mdot
.71895 .40885 Mdot
.52407 .14365 Mdot
.6182 .26675 Mdot
.54945 .24063 Mdot
.43897 .17614 Mdot
.4112 .61303 Mdot
.50299 .71231 Mdot
.60544 .24625 Mdot
.44107 .73834 Mdot
.45378 .73596 Mdot
.69647 .37416 Mdot
.61522 .23631 Mdot
.77941 .63134 Mdot
.52496 .58396 Mdot
.42141 .27861 Mdot
.67077 .27508 Mdot
.67783 .29847 Mdot
.68894 .42212 Mdot
.55989 .17013 Mdot
.74148 .41776 Mdot
.63975 .3556 Mdot
.6038 .20248 Mdot
.59761 .23003 Mdot
.42136 .58257 Mdot
.63048 .2666 Mdot
.76383 .51045 Mdot
.61278 .31246 Mdot
.48067 .71223 Mdot
.61051 .27919 Mdot
.58756 .25443 Mdot
.7193 .39358 Mdot
.48434 .11496 Mdot
.52846 .18017 Mdot
.6154 .21961 Mdot
.63892 .24916 Mdot
.62848 .25642 Mdot
.41426 .45676 Mdot
.71199 .39564 Mdot
.72555 .47213 Mdot
.74895 .5479 Mdot
.48471 .7472 Mdot
.41068 .5882 Mdot
.49961 .16343 Mdot
.59756 .19911 Mdot
.67515 .27918 Mdot
.78372 .6395 Mdot
.44762 .22458 Mdot
.43178 .24656 Mdot
.72421 .33901 Mdot
.40482 .33687 Mdot
.41604 .63306 Mdot
.553 .15563 Mdot
.52208 .50724 Mdot
.57205 .24723 Mdot
.65727 .29879 Mdot
.66641 .34728 Mdot
.6849 .31402 Mdot
.68165 .37249 Mdot
.65311 .28637 Mdot
.40013 .43667 Mdot
.62696 .2396 Mdot
.69556 .28708 Mdot
.65999 .37653 Mdot
.57111 .26611 Mdot
.59705 .28292 Mdot
.67931 .2916 Mdot
.61267 .25088 Mdot
.40883 .48516 Mdot
.62951 .23343 Mdot
.66339 .36202 Mdot
.43275 .65098 Mdot
.41647 .37012 Mdot
.42002 .30275 Mdot
.4247 .29408 Mdot
.71178 .40612 Mdot
.76521 .52166 Mdot
.57639 .25757 Mdot
.49082 .69324 Mdot
.64005 .27778 Mdot
.62082 .22018 Mdot
.70849 .33861 Mdot
.44438 .73434 Mdot
.7268 .39988 Mdot
.47972 .71913 Mdot
.70611 .45022 Mdot
.76117 .53388 Mdot
.67612 .30131 Mdot
.69906 .29879 Mdot
.5115 .15481 Mdot
.73823 .41341 Mdot
.59214 .18961 Mdot
.48148 .73232 Mdot
.74656 .48975 Mdot
.68026 .28334 Mdot
.72148 .35622 Mdot
.71844 .39758 Mdot
.40711 .39734 Mdot
.7729 .52188 Mdot
.42275 .21764 Mdot
.49034 .68906 Mdot
.49067 .6893 Mdot
.522 .53109 Mdot
.4186 .31366 Mdot
.77345 .53507 Mdot
.59593 .27636 Mdot
.4628 .71955 Mdot
.53399 .18084 Mdot
.49036 .74718 Mdot
.51335 .66 Mdot
.41686 .62258 Mdot
.53979 .14415 Mdot
.45605 .18631 Mdot
.61508 .25592 Mdot
.4218 .62131 Mdot
.60121 .29235 Mdot
.46687 .17934 Mdot
.70137 .30212 Mdot
.51218 .6591 Mdot
.55666 .20987 Mdot
.68986 .29224 Mdot
.41565 .31028 Mdot
.69075 .387 Mdot
.60352 .23365 Mdot
.65828 .38271 Mdot
.41685 .46711 Mdot
.40624 .4451 Mdot
.51003 .11643 Mdot
.45309 .72256 Mdot
.72491 .49259 Mdot
.73854 .38967 Mdot
.44556 .72653 Mdot
.51427 .48265 Mdot
.7653 .58412 Mdot
.45961 .16104 Mdot
.41083 .46998 Mdot
.74171 .43393 Mdot
.41525 .37803 Mdot
.52265 .13997 Mdot
.6162 .28356 Mdot
.58157 .24302 Mdot
.74842 .47225 Mdot
.49158 .12423 Mdot
.60494 .22925 Mdot
.41109 .27795 Mdot
.68211 .31674 Mdot
.4628 .7332 Mdot
.67661 .36819 Mdot
.52662 .21512 Mdot
.4093 .28898 Mdot
.66958 .36339 Mdot
.7245 .37325 Mdot
.52299 .59331 Mdot
.45339 .7107 Mdot
.68303 .39404 Mdot
.41753 .28663 Mdot
.41971 .34637 Mdot
.43791 .1579 Mdot
.50643 .44532 Mdot
.69848 .33237 Mdot
.67168 .30702 Mdot
.42272 .24448 Mdot
.41065 .4784 Mdot
.6576 .37413 Mdot
.49542 .69084 Mdot
.42479 .22996 Mdot
.57461 .23832 Mdot
.41975 .37031 Mdot
.57219 .25933 Mdot
.66325 .371 Mdot
.44835 .18732 Mdot
.64156 .29847 Mdot
.47016 .12306 Mdot
.4374 .72289 Mdot
.46756 .16074 Mdot
.64965 .27952 Mdot
.45882 .76367 Mdot
.41397 .65164 Mdot
.68543 .34288 Mdot
.43232 .71628 Mdot
.55114 .20781 Mdot
.63611 .26516 Mdot
.52535 .60208 Mdot
.41499 .50021 Mdot
.68486 .38912 Mdot
.71464 .38867 Mdot
.41375 .6405 Mdot
.52 .52162 Mdot
.4627 .19854 Mdot
.59307 .19797 Mdot
.41896 .29905 Mdot
.65225 .36823 Mdot
.75944 .54641 Mdot
.68307 .35799 Mdot
.72298 .46935 Mdot
.69265 .40696 Mdot
.51583 .46601 Mdot
.65818 .28265 Mdot
.74223 .52703 Mdot
.58325 .18437 Mdot
.72396 .49242 Mdot
.78617 .6425 Mdot
.44018 .1964 Mdot
.44179 .14678 Mdot
.57609 .22948 Mdot
.68774 .33567 Mdot
.72965 .44061 Mdot
.4123 .52526 Mdot
.69092 .36635 Mdot
.41407 .30443 Mdot
.49406 .67807 Mdot
.56375 .18233 Mdot
.49951 .16207 Mdot
.57565 .19794 Mdot
.72477 .34581 Mdot
.51464 .63126 Mdot
.56517 .22375 Mdot
.53854 .21823 Mdot
.7173 .4708 Mdot
.51439 .63787 Mdot
.71323 .35518 Mdot
.73863 .50747 Mdot
.75679 .4912 Mdot
.42464 .6252 Mdot
.45949 .11716 Mdot
.47995 .13245 Mdot
.67674 .39101 Mdot
.40763 .59178 Mdot
.51865 .60032 Mdot
.51687 .51802 Mdot
.44688 .16267 Mdot
.68422 .28173 Mdot
.68688 .42545 Mdot
.49923 .71779 Mdot
.56233 .18257 Mdot
.49315 .69986 Mdot
.52108 .54267 Mdot
.51617 .12442 Mdot
.50424 .13812 Mdot
.56984 .26302 Mdot
.4016 .40994 Mdot
.42335 .28998 Mdot
.77795 .55858 Mdot
.44231 .20073 Mdot
.61041 .29928 Mdot
.47508 .73751 Mdot
.7061 .38567 Mdot
.42865 .30442 Mdot
.63256 .26736 Mdot
.61878 .31405 Mdot
.50457 .71264 Mdot
.47609 .18094 Mdot
.75021 .53702 Mdot
.70422 .33799 Mdot
.64333 .24816 Mdot
.65497 .34129 Mdot
.41807 .27231 Mdot
.45578 .14669 Mdot
.65777 .34222 Mdot
.43813 .19267 Mdot
.7061 .34529 Mdot
.7572 .4454 Mdot
.60504 .22843 Mdot
.7205 .40329 Mdot
.71501 .36053 Mdot
.71578 .34645 Mdot
.52061 .55744 Mdot
.4562 .16599 Mdot
.72566 .4853 Mdot
.69225 .31117 Mdot
.52103 .55707 Mdot
.64426 .34308 Mdot
.48712 .17429 Mdot
.5098 .14282 Mdot
.57082 .22531 Mdot
.69943 .40926 Mdot
.52823 .14844 Mdot
.67258 .32994 Mdot
.68482 .42806 Mdot
.6329 .34698 Mdot
.63356 .23047 Mdot
.61696 .29731 Mdot
.72974 .47637 Mdot
.7854 .62088 Mdot
.69195 .43678 Mdot
.55072 .20432 Mdot
.51539 .5732 Mdot
.73695 .47777 Mdot
.42047 .24102 Mdot
.51669 .5157 Mdot
.70322 .31865 Mdot
.59188 .21891 Mdot
.52391 .571 Mdot
.41784 .59748 Mdot
.40642 .37251 Mdot
.41172 .43974 Mdot
.67062 .29532 Mdot
.56935 .17087 Mdot
.74497 .51056 Mdot
.70893 .33855 Mdot
.51185 .1779 Mdot
.76891 .59385 Mdot
.48713 .14322 Mdot
.41783 .33336 Mdot
.40679 .45003 Mdot
.50756 .42501 Mdot
.69068 .30101 Mdot
.71102 .36505 Mdot
.42371 .32893 Mdot
.47195 .74628 Mdot
.44638 .76501 Mdot
.47282 .77049 Mdot
.72687 .36555 Mdot
.40365 .55099 Mdot
.65191 .34357 Mdot
.4528 .72927 Mdot
.41174 .58369 Mdot
.50199 .67658 Mdot
.40335 .50014 Mdot
.5496 .24462 Mdot
.41525 .61976 Mdot
.46291 .7208 Mdot
.73489 .38098 Mdot
.71024 .3867 Mdot
.47677 .37586 Mdot
.49436 .13937 Mdot
.44115 .17159 Mdot
.59573 .29909 Mdot
.49092 .1764 Mdot
.41016 .44961 Mdot
.73668 .44892 Mdot
.77059 .4896 Mdot
.54886 .1792 Mdot
.77797 .62103 Mdot
.49011 .10001 Mdot
.48352 .72769 Mdot
.70877 .46733 Mdot
.72599 .49565 Mdot
.41367 .42487 Mdot
.62745 .34206 Mdot
.77652 .56985 Mdot
.46354 .74154 Mdot
.52205 .57624 Mdot
.43597 .24936 Mdot
.65167 .35015 Mdot
.49111 .17233 Mdot
.76882 .54057 Mdot
.49082 .71142 Mdot
.54806 .22661 Mdot
.48647 .13754 Mdot
.5065 .69928 Mdot
.49978 .6767 Mdot
.44578 .741 Mdot
.67901 .275 Mdot
.52389 .59644 Mdot
.63002 .24821 Mdot
.5421 .16391 Mdot
.539 .17595 Mdot
.63403 .27702 Mdot
.65237 .37539 Mdot
.49729 .15704 Mdot
.76502 .46182 Mdot
.41891 .61148 Mdot
.68379 .27971 Mdot
.72064 .35614 Mdot
.42778 .31884 Mdot
.65158 .26649 Mdot
.47133 .16751 Mdot
.53516 .22677 Mdot
.6284 .25831 Mdot
.56395 .21108 Mdot
.40722 .52194 Mdot
.47001 .18109 Mdot
.53517 .21494 Mdot
.74209 .39529 Mdot
.55774 .23346 Mdot
.49704 .39002 Mdot
.55219 .22775 Mdot
.49684 .17709 Mdot
.52409 .51399 Mdot
.41763 .51153 Mdot
.53538 .20066 Mdot
.50102 .13859 Mdot
.51183 .63499 Mdot
.42907 .23972 Mdot
.69533 .35608 Mdot
.40602 .57617 Mdot
.57658 .24452 Mdot
.42749 .71435 Mdot
.43812 .25296 Mdot
.52096 .56651 Mdot
.78617 .60475 Mdot
.51672 .593 Mdot
.5335 .14889 Mdot
.69773 .43844 Mdot
.65681 .36044 Mdot
.40828 .50456 Mdot
.63315 .26474 Mdot
.70928 .34654 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002Xooooo`;o00000_ooool3o`000;Wooooo002Xooooo`;o00000_ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
[?ooool00ol0003oooooooooo`2iooooo`00Y_ooool2o`0000Cooooo0_l000000ooooooo0000o`00
002gooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^
k^kooooo00;o00000_ooool01?m4A4Co0000o`000?lb<S82o`0000Cooooo0_l000000ooooooo0000
o`00002gooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEE
EOnYZJWooooo00;o00001Oooool00omgMgOo<S8booooo`04ooooo`;o0000^_ooool0087ooooo1_l0
0002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`04ooooo`;o0000
0_ooool00ol0003oooooooooo`02o`000004ooooool0003o0000o`0000;ooooo0_l0002eooooo`00
ROooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool00oooool2o`000005
oooooomgMgOo0000o`000?ooool00_l000000ooooooo0000ooooo`02o`000003ooooool0003o0000
0;Gooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03oooo
o`04o`000?lQ8B7o0000oc8b<P;o00001?ooool01?l0003oooooo`000?l0002hooooo`00ROooool0
1Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003ooooooooo
o`02o`0000Gooooo00?o0000ooooooooool0^Oooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`04o`0000?ooooo
00?o0000ooooooooool0^Oooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go0000
1?ooool4o`000004ooooool0003o0000ooooo`Go00001?ooool2o`000;?ooooo002Wooooo`;o0000
00?oooooo`000?l000001Ol00002ooooo`?o0000/_ooool009Sooooo0_l00003ooooo`;o00001?oo
ool2o`0000;ooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00000oooool2o`0000?ooooo
0ol0002/ooooo`00V?ooool2o`0000?ooooo0_l00004ooooo`;o00001_ooool2o`0000Sooooo2?l0
002[ooooo`00Zoooool4o`0000Kooooo1?l00002ooooo`;o0000Zoooool00:cooooo00?o0000oooo
ooooool00_l0000<ooooo`;o0000ZOooool009Oooooo0_l0000Booooo`;o00000_ooool2o`000003
ooooool0003o000000Wooooo0_l0002Yooooo`00Uoooool2o`0000Gooooo0_l000000ooooooo0000
o`000008ooooo`;o00001Oooool2o`000;Cooooo002Jooooo`;o00000_ooool2o`000003ooooool0
003o000000Sooooo0_l0000<ooooo`;o0000[Oooool009[ooooo0_l000000ooooooo0000o`000003
ooooo`;o00001oooool2o`0000cooooo0_l0002]ooooo`00WOooool2o`0000?ooooo0_l00008oooo
o`03o`000?oooooooooo013ooooo0_l000000ooooooo0000o`00002Tooooo`00V?ooool2o`0000go
oooo1?l000000ooooooo0000ooooo`04o`0000[ooooo0_l000001?oooooo0000o`000?ooool2o`00
0:Cooooo002Gooooo`?o00001_ooool2o`0000Gooooo2ol00006ooooo`;o00000_ooool2o`0000?o
oooo0_l0002Uooooo`00Uoooool2o`0000Oooooo0ol00006ooooo`Co00000_ooool2o`0000Cooooo
0_l000000ooooooo0000o`000002ooooo`;o00000oooool2o`000:Gooooo002Hooooo`;o00001ooo
ool5o`0000Kooooo00?o0000ooooooooool00_l00004ooooo`Co00000oooool2o`0000;ooooo0ol0
002Uooooo`00V?ooool2o`0000?ooooo0_l00003ooooo`Co00001_ooool00ol0003oooooooooo`06
ooooo`Co00001oooool3o`0000Cooooo1?l0002Mooooo`00Voooool4o`0000gooooo00?o0000oooo
ooooool01_ooool2o`00013ooooo1?l0002Mooooo`00Voooool2o`0000oooooo00?o0000oooooooo
ool06oooool2o`0009cooooo002Gooooo`;o00004oooool00ol0003oooooooooo`0Kooooo`;o0000
W?ooool009Oooooo0ol00005ooooo`;o00002oooool00ol0003oooooooooo`0Fooooo`;o00000ooo
ool2o`0009cooooo002Hooooo`?o00001?ooool2o`0000_ooooo0ol00008ooooo`;o00003?ooool2
o`0000?ooooo1?l0002Jooooo`00VOooool2o`00017ooooo00Co0000oooooooooooooooo0_l00005
ooooo`;o00000oooool2o`0000kooooo1?l0002Hooooo`00[?ooool01?l0003oooooooooooooool2
o`0000[ooooo0_l000000ooooooo0000o`00000=ooooo`;o0000V?ooool00:cooooo00?o0000oooo
ooooool03Oooool5o`000:Oooooo002/ooooo`03o`000?oooooooooo00gooooo1?l000000ooooooo
0000o`00002Uooooo`00[?ooool00ol0003oooooooooo`05ooooo`;o000000Coooooo`000?l0003o
oooo0_l00005ooooo`;o00001_ooool2o`0009gooooo002Booooo`;o00006?ooool00ol0003ooooo
ooooo`05ooooo`;o000000?oooooo`000?l000000ol0000=ooooo`?o00001_ooool2o`0009Cooooo
002Booooo`;o00006?ooool00ol0003oooooooooo`09ooooo`;o00004?ooool2o`0000Kooooo0ol0
002Cooooo`00V_ooool2o`00013ooooo0ol0000Booooo`Co00003Oooool3o`0009?ooooo002Joooo
o`;o00004?ooool00ol0003oooooooooo`08ooooo`;o00000_ooool4o`0000;ooooo1Ol00008oooo
o`;o00000_ooool2o`0009Cooooo002Cooooo`;o00000_ooool2o`0001?ooooo00?o0000oooooooo
ool02?ooool2o`0000;ooooo1?l00005ooooo`?o00001Oooool4o`0000Sooooo0_l0002>ooooo`00
Toooool2o`0000;ooooo0_l0000Cooooo`03o`000?oooooooooo013ooooo0_l00004ooooo`;o0000
1Oooool4o`0000Kooooo1?l0002>ooooo`00[?ooool00ol0003oooooooooo`0@ooooo`;o00001ooo
ool2o`0000Cooooo0_l00002ooooo`;o00000_ooool2o`00093ooooo002Dooooo`;o00005_ooool0
0ol0003oooooooooo`0=ooooo`;o00001_ooool2o`0000;ooooo0_l00008ooooo`;o000000?ooooo
o`000?l00000TOooool0097ooooo1Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool03Oooool2o`0000Kooooo1?l0000=ooooo`;o0000TOooool0
097ooooo0ol000000onHV9So0000o`000004ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo00gooooo0_l00007ooooo`?o00001_ooool2o`0009Sooooo0029ooooo`Ko
00000_ooool01?l@413o0000o`000?ooool3o`0000kooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0=ooooo`;o00001Oooool4o`0000Cooooo0_l000000ooooooo0000o`000006oooo
o`;o000000?oooooo`000?l000000_l0002;ooooo`00TOooool01?l0003oooooooooooooool4o`00
00cooooo00?oMgMgoc8b<_ooool01?ooool3o`0001Cooooo0_l00006ooooo`;o000000Coooooo`00
0?l0003ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l0002;ooooo`00TOooool01_l0
003ooooooooooooooooo0000ooooo`;o00002Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool06Oooool2o`0000Cooooo0_l000001?oooooo0000o`000?l0002Dooooo`00
TOooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Fooooo`;o000000?oooooo`000?l000002?ooool2o`0000;ooooo0_l0002@ooooo`00
TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Dooooo`Co00001?ooool2o`0000Wooooo0_l0002@ooooo`00TOooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo1?l00006ooooo`03o`000?oooooooooo01Cooooo0_l00006ooooo`;o
00002oooool2o`0008kooooo002/ooooo`03o`000?oooooooooo01Cooooo0_l0000>ooooo`;o0000
0_ooool3o`0000Cooooo0_l00005ooooo`;o0000POooool00:cooooo00?o0000ooooooooool05?oo
ool2o`0000kooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Gooooo0_l0
0021ooooo`00TOooool2o`0001Wooooo00?o0000ooooooooool0:oooool2o`0008cooooo002Aoooo
o`;o00006Oooool3o`0001cooooo0_l0000;ooooo`;o00002_ooool2o`000003ooooool0003o0000
07oooooo002>ooooo`?o000000?oooooo`000?l000006?ooool00ol0003oooooooooo`0Looooo`;o
00000oooool2o`0000Kooooo1?l000000ooooooo0000o`000005ooooo`Ko0000O_ooool008kooooo
0ol000000ooooooo0000o`00000Hooooo`03o`000?oooooooooo01gooooo0_l00002ooooo`;o0000
2?ooool2o`000004ooooool0003o0000ooooo`;o00000oooool5o`0007kooooo002/ooooo`03o`00
0?oooooooooo01gooooo0_l00004ooooo`;o00002?ooool6o`0000Cooooo1?l0001nooooo`00S_oo
ool4o`0001[ooooo00?o0000ooooooooool08oooool2o`0000Sooooo1?l0000<ooooo`;o0000N_oo
ool008kooooo1_l0000Hooooo`03o`000?oooooooooo01kooooo0_l0000Hooooo`;o000000?ooooo
o`000?l000000_l0001jooooo`00T_ooool3o`0001Oooooo00?o0000ooooooooool07_ooool2o`00
01Gooooo0_l000001?oooooo0000o`000?ooool2o`0007cooooo002Cooooo`;o00005oooool00ol0
003oooooooooo`0Sooooo`;o00001_ooool2o`0000Sooooo1?l000000ooooooo0000o`00001moooo
o`00TOooool2o`0001Wooooo0ol0000Looooo`;o00000oooool4o`0000Kooooo0_l00003ooooo`;o
00001Oooool2o`000003ooooool0003o000000Co0000NOooool008oooooo1?l000000ooooooo0000
o`00000Fooooo`03o`000?oooooooooo01cooooo0_l00003ooooo`;o00003Oooool2o`0000Gooooo
0_l00003ooooo`Go0000N?ooool008oooooo1?l000000ooooooo0000o`00000Fooooo`03o`000?oo
oooooooo03Gooooo0ol00007ooooo`;o0000N?ooool008gooooo0_l000000ooooooo0000o`00000J
ooooo`03o`000?oooooooooo03Gooooo0ol00021ooooo`00SOooool2o`000004ooooool0003o0000
o`0001Wooooo00?o0000ooooooooool08_ooool2o`0000_ooooo0_l0000;ooooo`;o0000Noooool0
097ooooo0_l0000Iooooo`03o`000?oooooooooo02;ooooo1?l00009ooooo`;o00002?ooool7o`00
07Wooooo002Cooooo`?o00005_ooool00ol0003oooooooooo`0Tooooo`;o00004?ooool2o`000004
ooooool0003o0000o`0000;ooooo1?l0001gooooo`00Toooool3o`0001Kooooo00?o0000oooooooo
ool0=_ooool2o`0000Sooooo0_l0001gooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002Booooo`;o00006?ooool00ol0003oooooooooo`0fooooo`Co0000Ooooool0
093ooooo1?l0000Hooooo`03o`000?oooooooooo03Kooooo1?l00004ooooo`;o0000NOooool008co
oooo0_l00002ooooo`?o00006Oooool00ol0003oooooooooo`0kooooo`;o000000?oooooo`000?l0
0000NOooool008cooooo0_l00003ooooo`;o00006Oooool00ol0003oooooooooo`0Xooooo`;o0000
4Oooool2o`0000?ooooo1?l00003ooooo`;o0000L?ooool00:cooooo00?o0000ooooooooool09ooo
ool3o`0000;ooooo0_l000000ooooooo0000o`000002o`0000Oooooo0_l00004ooooo`Co00000ooo
ool2o`00073ooooo002<ooooo`;o00000oooool2o`0001Wooooo00?o0000ooooooooool09oooool3
o`0000;ooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l00002ooooo`;o00001Oooool5
o`000003ooooool0003o0000073ooooo002<ooooo`;o00000oooool2o`0001Wooooo00?o0000oooo
ooooool0:?ooool2o`0000Wooooo0_l000000ooooooo0000o`000009ooooo`Go000000?oooooo`00
0?l00000L?ooool00:cooooo0ol0000/ooooo`;o000000?oooooo`000?l000000_ooool2o`0000[o
oooo0_l0001hooooo`00[?ooool00ol0003oooooooooo`0[ooooo`?o000000?oooooo`000?l00000
0_l0000:ooooo`Co00000_ooool2o`0007Cooooo002/ooooo`03o`000?oooooooooo02_ooooo0_l0
00001?oooooo0000o`000?ooool2o`0000Kooooo0_l00002ooooo`;o00001?ooool5o`00077ooooo
002/ooooo`03o`000?oooooooooo02kooooo1?l000000ooooooo0000o`000004ooooo`;o00000_oo
ool2o`0000?ooooo1_l0001aooooo`00[?ooool00ol0003oooooooooo`0`ooooo`;o000000?ooooo
o`000?l000000_l00006ooooo`;o00000oooool4o`0007?ooooo0029ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`0_ooooo`;o00001?ooool4o`0000?ooooo0_l00004ooooo`;o00000ooo
ool2o`00073ooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool3o`0000;o8B4Q1?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`0_ooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo0_l00009ooooo`;o0000
L?ooool0087ooooo1_l00002ooooo`04oa0@4?ooooooooooooooo`;o000000Coooooo`000?l0003o
00001oooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0<Oooool3o`0000Gooooo0_l00002ooooo`;o00002?ooool2o`00073ooooo0029ooooo`04o`00
0?ooooooooooooooo`;o00003?ooool00onHV9So8B4Qonk^kP06ooooo`;o000000?o<S8bo`000?l0
00000oooool3o`0002oooooo1?l00006ooooo`;o00000_ooool2o`0000Sooooo0_l0001`ooooo`00
ROooool01Ol0003ooooooooooooooooo000000;ooooo0_l0000:ooooo`03ogMgMomVIVKooooo00?o
oooo00Go0000ob4Q8Ol0003o0000olc<c002o`0000?ooooo00?o0000ooooooooool0;oooool4o`00
08Kooooo0029ooooo`05oa0@4?ooooooooooooooool@41000_ooool2o`0000_ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo0_l0000Goooo
o`;o0000KOooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo0_l0000>
ooooo`;o00001oooool2o`0006gooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo03Kooooo0_l0
0002ooooo`Co00000oooool4o`0007Cooooo002=ooooo`;o00007?ooool2o`0003Sooooo0ol00000
0ooooooo0000o`000002o`0000Cooooo0ol00006ooooo`;o0000K?ooool008gooooo0_l0000Loooo
o`;o0000>Oooool4o`0000[ooooo0_l00004ooooo`?o0000Joooool008gooooo0_l0000Mooooo`03
o`000?oooooooooo03Wooooo0_l00005ooooo`;o000000?oooooo`000?l000000_l00005ooooo`;o
0000Joooool008gooooo0_l0000Mooooo`?o0000@?ooool2o`000003ooooool0003o000000Co0000
L?ooool00:cooooo00?o0000ooooooooool0?_ooool2o`0000Gooooo1?l0001`ooooo`00S_ooool2
o`0001cooooo00?o0000ooooooooool0??ooool4o`0000;ooooo0_l000000ooooooo0000o`00001b
ooooo`00Roooool2o`000003ooooool0003o000001cooooo00?o0000ooooooooool0??ooool4o`00
00;ooooo0_l000000ooooooo0000o`00001booooo`00Roooool2o`0001oooooo00?o0000oooooooo
ool0?_ooool2o`0000Gooooo0_l00004ooooo`;o0000K?ooool00:cooooo00?o0000ooooooooool0
@?ooool2o`0000Wooooo0_l0001/ooooo`00[?ooool00ol0003oooooooooo`10ooooo`;o00002_oo
ool2o`0006_ooooo002/ooooo`03o`000?oooooooooo03_ooooo0_l0000?ooooo`;o0000Joooool0
08oooooo0_l0000Kooooo`Co0000>Oooool3o`0007cooooo002?ooooo`;o00006oooool01?l0003o
ooooo`000?l0000iooooo`;o0000OOooool00:cooooo00?o0000ooooooooool0>_ooool2o`0007go
oooo002/ooooo`03o`000?oooooooooo04cooooo0_l0001[ooooo`00Roooool2o`0001oooooo00?o
0000ooooooooool0??ooool2o`0000kooooo0_l0001[ooooo`00Roooool2o`000003ooooool0003o
000001cooooo00?o0000ooooooooool0??ooool4o`0000Sooooo0_l0001_ooooo`00S?ooool4o`00
01cooooo0ol0000nooooo`;o00002?ooool2o`0006oooooo002<ooooo`?o00007Oooool4o`00053o
oooo0_l0001Vooooo`00SOooool3o`0001cooooo00Co0000ooooool0003o0000B_ooool2o`0000Co
oooo0_l0001Vooooo`00SOooool3o`0001cooooo0ol00011ooooo`;o00002?ooool2o`0006cooooo
002=ooooo`;o00007Oooool00ol0003oooooooooo`11ooooo`;o00002oooool2o`0006Wooooo002?
ooooo`;o00006oooool00ol0003oooooooooo`1>ooooo`;o0000JOooool000Wooooo1?l000000ol@
413oooooooooo`0Fooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000
onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000;ooooo0_l000001Om4A4Co0000o`000?lb<S;o
gMgM01Kooooo00?o0000ooooooooool06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q0oooool2o`000005odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4
o`000?l0003o<S8bomgMg@0Hooooo`Co000000?o410@ooooooooool04_ooool000_ooooo00?o0000
ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnY
ZJWooooo00Oooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B48ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool05Oooool00ol0
003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q0oooool2o`0000?ooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_oo
ool06Oooool00ol0003oooooooooo`0Dooooo`001_l00005ooooo`03o`000?oooooooooo013ooooo
1_l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03
o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`05ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RH
ob4Q8Oo^k^h01?ooool2o`0000?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`02
ooooo`;o00005?ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Ooo
ool00ol0003oooooooooo`09ooooo`;o00000_ooool01Ol@413ooooooooooooooooo410@013ooooo
00?o0000ooooooooool03Oooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOoo
ool02?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`00
0?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Ko
oooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b
<_ooool03_ooool01Ol0003ooooooooooooooooo000000gooooo00CoV9RHob4Q8Oo^k^kooooo1?l0
0002ooooo`03ogMgMolb<S;ooooo01Gooooo00?o0000ooooooooool00_ooool2o`0001Cooooo00Go
0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0
2_ooool2o`000003ooooool0003o000000;o000000?oooooo`000?ooool03_ooool00omgMgOo<S8b
ooooo`0>ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03
ogMgMolb<S;ooooo01Wooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool0
6?ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool0
1?l000001?lQ8B7o0000oc8b<_o<c<`Fooooo`03o`000?oooooooooo01Sooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00>
ooooo`Ko00001Oooool2o`0000Gooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?oo
ooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`06_ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05oa0@
4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo017o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo017ooooo00Go410@oooo
oooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06?ooool3
o`0001Sooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool04Oooool00ol@413oooooo`000002o`0000Gooooo0_l00005ooooo`03o`000?oo
oooooooo017ooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003ooooooooo
o`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Co
oooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Ko0000okZj^_ooooooV9RHoa0@
4?ooool2o`000003ooooool0003ooooo01Wooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo
017ooooo00?oMgMgoiRHV?ooool00_l000000ooooooo0000o`000009ooooo`03o`000?oooooooooo
017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Cooooo0009ooooo`03oeEEEOmVIVKo
000001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`00013ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00KoV9RHoa0@4?l0003o8B4Qolc<c?ooool2o`000003ooooool0003o000000;o00005oooool0
1?l0003oooooooooooooool2o`0001Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`01?ooool4o`00013ooooo00Kok^k^oc8b<_l0003o<S8bonk^k_ooool2
o`0000Wooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0
000Iooooo`03oeEEEOmVIVKo000001Kooooo002=ooooo`Co00006oooool01?l0003ooooooooooooo
ool2o`0004Cooooo1?l0001^ooooo`00S?ooool5o`0001_ooooo00?o0000ooooooooool0Aoooool4
o`0006kooooo002:ooooo`Co00000_ooool2o`0001[ooooo00?o0000ooooooooool0A_ooool2o`00
00Kooooo0_l000000ooooooo0000o`000003ooooo`;o0000E_ooool2o`0000;ooooo0_l00005oooo
o`00R_ooool4o`0000;ooooo0_l0000Jooooo`03o`000?oooooooooo04Kooooo0ol00005ooooo`;o
000000?oooooo`000?l000000oooool2o`0005Kooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd5
ooooo`00S?ooool2o`0001kooooo00?o0000ooooooooool0Aoooool2o`0006Kooooo00CogMgMo`00
0?l@413oc<c<1_ooool000Ooooooool0001<o`0000cooooo00Cok^k^ob4Q8Ol@413ok^k^1_ooool0
00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool3o`000003ooooool0003o000000?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00Co8B4QogMg
MomgMgOo<S8b1_ooool000Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01oooool2o`0001gooooo00?o0000oooo
ooooool01?ooool2o`00027ooooo00?o0000ooooooooool08Oooool2o`0000?ooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Wooooo0_l00002oooo
o`;o00001Oooool008_ooooo1?l0000Mooooo`03o`000?oooooooooo00Cooooo0_l00013ooooo`Ko
00001Oooool2o`0006?ooooo002;ooooo`;o00000oooool2o`0001[ooooo00?o0000ooooooooool0
BOooool2o`0000;ooooo0_l00005ooooo`;o0000Hoooool0093ooooo0_l0000Jooooo`03o`000?oo
oooooooo00;ooooo0_l000000ooooooo0000o`00002booooo`00[?ooool00ol0003oooooooooo`02
ooooo`;o000000?oooooo`000?l00000C_ooool2o`0006;ooooo002=ooooo`;o00007Oooool00ol0
003oooooooooo`02ooooo`?o0000Coooool5o`00063ooooo002=ooooo`Co00006oooool3o`0000?o
oooo0ol0001>ooooo`;o000000?oooooo`000?l00000H?ooool008kooooo0ol0000Kooooo`03o`00
0?oooooooooo00Cooooo0_l00017ooooo`;o0000J_ooool008kooooo1?l0000Jooooo`03o`000?oo
oooooooo00Cooooo0_l00017ooooo`;o0000J_ooool0093ooooo0_l0000Jooooo`03o`000?oooooo
oooo00Cooooo0_l0001=ooooo`;o0000I?ooool00:cooooo00?o0000ooooooooool0Coooool2o`00
00;ooooo0_l00002ooooo`;o0000H?ooool00:cooooo00?o0000ooooooooool0Coooool2o`0000Co
oooo1?l0001Pooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o0000Coooool2o`0006;ooooo
002/ooooo`03o`000?oooooooooo00Cooooo0_l0001<ooooo`;o0000IOooool00:cooooo00?o0000
ooooooooool0Coooool2o`000003ooooool0003o000006Gooooo002<ooooo`;o00007_ooool3o`00
04oooooo0_l0001Xooooo`00S?ooool2o`0001kooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool00oooool3o`0005;ooooo0_l0001Oooooo`00[?ooool01?l0003ooooooooo
ooooool5o`0005;ooooo0_l0001Oooooo`00[?ooool01?l0003oooooooooooooool2o`00053ooooo
0_l0001Tooooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool00oooool2o`0004kooooo0_l0
001Tooooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool00oooool3o`0005;ooooo0_l0001O
ooooo`00[?ooool00ol0003oooooooooo`02ooooo`Co0000D_ooool2o`0005oooooo002=ooooo`;o
00007Oooool3o`0000;ooooo1?l0002cooooo`00SOooool2o`0001gooooo00?o0000ooooooooool0
1?ooool2o`000;?ooooo002Booooo`;o00006?ooool00ol0003oooooooooo`2iooooo`00S_ooool2
o`0000;ooooo0_l0000Hooooo`03o`000?oooooooooo00Gooooo0_l0001=ooooo`;o0000Hoooool0
08kooooo0_l00002ooooo`;o00006?ooool00ol0003oooooooooo`05ooooo`;o0000COooool2o`00
00;ooooo0_l0001Oooooo`00SOooool3o`0001cooooo00?o0000ooooooooool0Eoooool3o`0005oo
oooo002=ooooo`;o00007Oooool00ol0003oooooooooo`02ooooo`Co0000Coooool4o`00063ooooo
002@ooooo`;o00006_ooool00ol0003oooooooooo`02ooooo`Co0000Coooool4o`00063ooooo002@
ooooo`;o00006_ooool3o`0000?ooooo0ol0002cooooo`00[?ooool00ol0003oooooooooo`03oooo
o`Co0000/_ooool00:cooooo00?o0000ooooooooool01Oooool2o`0005Cooooo0_l0001Looooo`00
[?ooool00ol0003oooooooooo`1Kooooo`;o0000G?ooool008kooooo0_l000000ooooooo0000o`00
000Iooooo`03o`000?oooooooooo0;Wooooo002>ooooo`;o000000?oooooo`000?l000006Oooool0
0ol0003oooooooooo`2iooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0^Ooo
ool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`Co000000?o8B4Qooooooooool00_oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`1Hooooo`;o000000?oooooo`000?l00000G?ooool008Wooooo00Go410@oooooooooooooooo
oa0@4002ooooo`Go00001Oooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo
0ol0001Hooooo`;o000000?oooooo`000?l00000G?ooool008Wooooo00Go0000oooooooooooooooo
o`000004ooooo`?o00001_ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0^Oooool008Wooooo00Go0000ooooooooooooooooo`000004ooooo`;o0000
2?ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool01?l0003o
ooooooooooooool2o`0005Kooooo0_l0001Nooooo`00ROooool01Ol@413ooooooooooooooooo410@
00;ooooo0_l0000;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool01?l0
003oooooooooooooool2o`0005Kooooo0_l0001Nooooo`00ROooool01OmgMgOoV9RHoooooonHV9So
MgMg00;ooooo0_l00007ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00;o0000]oooool008Wooooo00Kok^k^oc8b<_l0003o<S8bonk^
k_ooool2o`000003ooooool0003o000000Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co
00001_ooool00ol0003oooooooooo`03o`0005Oooooo0_l0001Mooooo`00Soooool2o`000003oooo
ool0003o000001Sooooo00Co0000oooooooooooooooo0_l0001Gooooo`?o0000G?ooool00:cooooo
00?o0000ooooooooool0Foooool2o`0005cooooo002/ooooo`03o`000?oooooooooo0;Wooooo002?
ooooo`;o00001?ooool2o`0001Gooooo0ol0002iooooo`00Soooool2o`0000?ooooo0ol0000Eoooo
o`03o`000?oooooooooo0;Wooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`2iooooo`00
[?ooool01?l0003oooooooooooooool2o`000;Kooooo002/ooooo`04o`000?ooooooooooooooo`;o
0000]_ooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Ooo
ool00:cooooo00?o0000ooooooooool0^Oooool00:_ooooo1?l0002iooooo`00Z_ooool4o`000;[o
oooo002Zooooo`?o0000^oooool00:cooooo00?o0000ooooooooool0^Oooool00:Sooooo0_l00002
ooooo`03o`000?oooooooooo0;Wooooo002Xooooo`Go0000^oooool00:Wooooo1?l0002kooooo`00
U_ooool2o`00017ooooo0_l000000ooooooo0000ooooo`2jooooo`00U_ooool2o`00017ooooo0_l0
00000ooooooo0000o`000002o`000;Sooooo002Yooooo`;o000000?oooooo`000?ooool00_l0002h
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
W?ooool2o`0000Oooooo0_l00002ooooo`;o000000Coooooo`000?l0003o0000^Oooool009Cooooo
0ol00005ooooo`;o00001oooool2o`0000;ooooo0_l000001?oooooo0000o`000?l0002iooooo`00
U?ooool3o`0000Sooooo0_l00004ooooo`;o00001?ooool3o`000;[ooooo002Looooo`;o000000?o
ooooo`000?l000001?ooool2o`0000?ooooo0ol0002kooooo`00Uoooool2o`0000?ooooo0_l00000
0ooooooo0000o`000009ooooo`Go0000^Oooool009Oooooo0_l000000ooooooo0000o`00000:oooo
o`;o00001?ooool00ol0003oooooooooo`2iooooo`00V_ooool4o`0000Sooooo0_l00004ooooo`03
o`000?oooooooooo0;Wooooo002Iooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o
00001Oooool00ol0003oooooooooo`2iooooo`00VOooool2o`000004ooooool0003o0000ooooo`;o
00000_ooool6o`0000?ooooo00?o0000ooooooooool0^Oooool009Sooooo0_l00002ooooo`;o0000
1Oooool2o`0000;ooooo0_l00003ooooo`03o`000?oooooooooo0;Wooooo002Aooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00_ooool4o`000004ob4Q8Oooooooooooooooo`;o000000GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;Wooooo002Aooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00_ooool4o`000004ob4Q8Oooooooooooooooo`Co000000?oooooogMgMolb<S801Oooool0
0ol0003oooooooooo`2iooooo`00TOooool01Ol@413ooooooooooooooooo410@00?ooooo0_l00007
ooooo`;o00000_ooool4o`0000;ooooo00?o0000ooooooooool0^Oooool0097ooooo00Go0000oooo
ooooooooooooo`000003ooooo`;o00002_ooool00omgMgOo<S8bo`000002o`0000;ooooo0ol0002i
ooooo`00TOooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo0;Wooooo002Aooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Wooooo002Aooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Wooooo002A
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool2o`0000;ooooo0_l00002ooooo`Co00001_oo
ool00ol0003oooooooooo`2iooooo`00V_ooool2o`0000;ooooo0_l00007ooooo`;o00000oooool0
0ol0003oooooooooo`2iooooo`00Xoooool2o`0000;ooooo0_l00003ooooo`03o`000?oooooooooo
0;Wooooo002Sooooo`;o00001oooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0^Oooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0^Oooool008Wooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo
00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2iooooo`00ROooool01Ol0003o
oooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04oooo
o`?o0000^Oooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;Wooooo0029oooo
o`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0^Oooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0;Wooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0
0006ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000
^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o
0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
^Oooool00:;ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0;Wooooo002T
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000oooo
ooooool01Oooool3o`000;Wooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`00
0?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooo
oooo0<7ooooo002Rooooo`03oeEEEOmVIVKo00000<?ooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo002Zooooo`04oa0@4?l0003o0000o`000;[ooooo002[oooo
o`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`06o`00
0?mgMgOo0000o`000?mEEEGok^k^]oooool00:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomEEEFg
ooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo0;Gooooo002[ooooo`03
o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0]Oooool00:_ooooo00Ko0000oeEEEOo^k^ko
ooooogMgMomVIVJgooooo`00Z_ooool00ol@413o0000ogMgM`02o`000003ofIVI_o^k^kooooo0;Ko
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.41623 .20134 Mdot
.40307 .24436 Mdot
.44514 .47366 Mdot
.51876 .68081 Mdot
.48762 .81202 Mdot
.3932 .38221 Mdot
.49787 .35984 Mdot
.54204 .06651 Mdot
.6298 .2152 Mdot
.51749 .71712 Mdot
.49473 .77112 Mdot
.61509 .16144 Mdot
.39508 .26673 Mdot
.54202 .66451 Mdot
.68344 .29731 Mdot
.52822 .67094 Mdot
.39736 .43321 Mdot
.394 .2726 Mdot
.50808 .76776 Mdot
.42996 .09706 Mdot
.46755 .07781 Mdot
.45711 .09445 Mdot
.52772 .1402 Mdot
.41185 .17875 Mdot
.68599 .28627 Mdot
.48949 .83022 Mdot
.44601 .75527 Mdot
.4683 .79849 Mdot
.46646 .05068 Mdot
.44368 .11583 Mdot
.54456 .15236 Mdot
.59849 .16116 Mdot
.60054 .15023 Mdot
.42244 .22999 Mdot
.39243 .48308 Mdot
.56024 .15571 Mdot
.57326 .14531 Mdot
.45127 .77465 Mdot
.56372 .14725 Mdot
.58444 .11394 Mdot
.64633 .20067 Mdot
.3967 .39775 Mdot
.40046 .32704 Mdot
.38511 .4629 Mdot
.38684 .44459 Mdot
.49283 .81614 Mdot
.48196 .7777 Mdot
.55608 .10624 Mdot
.45661 .83603 Mdot
.53735 .11362 Mdot
.57301 .13033 Mdot
.52208 .08487 Mdot
.77023 .39192 Mdot
.41125 .26303 Mdot
.39158 .54423 Mdot
.62369 .19591 Mdot
.56595 .09591 Mdot
.39766 .58109 Mdot
.56108 .11963 Mdot
.38666 .46157 Mdot
.46594 .82349 Mdot
.68988 .2546 Mdot
.5897 .18814 Mdot
.54406 .52247 Mdot
.66343 .26866 Mdot
.59591 .15357 Mdot
.50228 .74731 Mdot
.49394 .74539 Mdot
.49067 .7891 Mdot
.44078 .1003 Mdot
.44097 .82854 Mdot
.49138 .32777 Mdot
.48514 .7722 Mdot
.51494 .71672 Mdot
.59029 .18919 Mdot
.45669 .37845 Mdot
.77045 .39305 Mdot
.40638 .60714 Mdot
.50822 .0696 Mdot
.4035 .39754 Mdot
.55341 .15652 Mdot
.46168 .09713 Mdot
.50462 .71208 Mdot
.39325 .47201 Mdot
.55026 .08128 Mdot
.55455 .57394 Mdot
.48896 .81186 Mdot
.42384 .71906 Mdot
.41343 .72422 Mdot
.48539 .75531 Mdot
.69445 .30878 Mdot
.74822 .36344 Mdot
.54764 .51598 Mdot
.47778 .82222 Mdot
.54442 .54401 Mdot
.73419 .3191 Mdot
.54025 .66844 Mdot
.61791 .20171 Mdot
.77095 .38829 Mdot
.44768 .83665 Mdot
.43177 .15095 Mdot
.43975 .81691 Mdot
.64249 .20885 Mdot
.39008 .36094 Mdot
.48496 .07208 Mdot
.421 .23372 Mdot
.41209 .72739 Mdot
.51359 .76096 Mdot
.54791 .51231 Mdot
.46475 .07546 Mdot
.53899 .66837 Mdot
.53728 .62206 Mdot
.60613 .17416 Mdot
.47019 .05639 Mdot
.79195 .43134 Mdot
.51854 .38396 Mdot
.43826 .78188 Mdot
.5408 .07508 Mdot
.55722 .09847 Mdot
.61779 .22212 Mdot
.40673 .20337 Mdot
.66858 .21776 Mdot
.54199 .1556 Mdot
.44724 .0648 Mdot
.45171 .0851 Mdot
.50464 .71729 Mdot
.49712 .06679 Mdot
.72802 .31045 Mdot
.49776 .11259 Mdot
.53226 .53041 Mdot
.4823 .08684 Mdot
.45172 .11331 Mdot
.63673 .19358 Mdot
.38892 .54251 Mdot
.39899 .33357 Mdot
.46401 .04822 Mdot
.49858 .0492 Mdot
.49107 .05824 Mdot
.4787 .77455 Mdot
.63025 .19564 Mdot
.6744 .27213 Mdot
.72811 .3479 Mdot
.54726 .55688 Mdot
.50819 .76424 Mdot
.3962 .46537 Mdot
.44078 .07907 Mdot
.54682 .07918 Mdot
.79952 .4395 Mdot
.4208 .67912 Mdot
.42902 .74355 Mdot
.61981 .13901 Mdot
.45457 .84173 Mdot
.51706 .74016 Mdot
.39983 .23339 Mdot
.48534 .31973 Mdot
.43695 .15434 Mdot
.53679 .09879 Mdot
.56532 .14728 Mdot
.57051 .11402 Mdot
.59065 .17249 Mdot
.52766 .08637 Mdot
.47737 .8406 Mdot
.48288 .0461 Mdot
.57039 .08708 Mdot
.57061 .17653 Mdot
.44239 .15787 Mdot
.47076 .10464 Mdot
.55595 .0916 Mdot
.47336 .06736 Mdot
.48608 .79214 Mdot
.48296 .03978 Mdot
.5682 .16202 Mdot
.51762 .66842 Mdot
.45931 .78363 Mdot
.44383 .78271 Mdot
.44093 .76416 Mdot
.63423 .20612 Mdot
.73388 .32166 Mdot
.44364 .14224 Mdot
.52984 .49775 Mdot
.51117 .07778 Mdot
.46935 .04067 Mdot
.60393 .13861 Mdot
.53748 .65391 Mdot
.64675 .19988 Mdot
.53448 .53847 Mdot
.6462 .25022 Mdot
.73472 .33388 Mdot
.55664 .10131 Mdot
.57857 .09879 Mdot
.39258 .41468 Mdot
.6636 .21341 Mdot
.43322 .0925 Mdot
.54006 .5475 Mdot
.70246 .28975 Mdot
.5536 .08334 Mdot
.62397 .15622 Mdot
.63748 .19758 Mdot
.46728 .81863 Mdot
.74165 .32188 Mdot
.42466 .78922 Mdot
.52792 .49416 Mdot
.52821 .49405 Mdot
.49445 .33299 Mdot
.44652 .78655 Mdot
.74748 .33507 Mdot
.46723 .10347 Mdot
.532 .5817 Mdot
.40019 .3091 Mdot
.55071 .55102 Mdot
.53735 .46 Mdot
.5145 .73583 Mdot
.3927 .29154 Mdot
.41062 .65062 Mdot
.47765 .06754 Mdot
.51314 .71373 Mdot
.47837 .10427 Mdot
.40676 .60487 Mdot
.58222 .10212 Mdot
.53582 .4591 Mdot
.41611 .21024 Mdot
.56676 .09224 Mdot
.44642 .80017 Mdot
.60554 .187 Mdot
.45829 .07411 Mdot
.57136 .18271 Mdot
.4804 .76101 Mdot
.47789 .81209 Mdot
.38425 .42958 Mdot
.53324 .61572 Mdot
.68195 .29259 Mdot
.65441 .18967 Mdot
.53509 .64511 Mdot
.47069 .33661 Mdot
.75894 .38412 Mdot
.40433 .64051 Mdot
.48233 .78667 Mdot
.67528 .23393 Mdot
.4613 .78727 Mdot
.38916 .36808 Mdot
.48964 .08617 Mdot
.44283 .12664 Mdot
.69732 .27225 Mdot
.38938 .50893 Mdot
.45796 .06995 Mdot
.44035 .82708 Mdot
.5688 .11674 Mdot
.53643 .59179 Mdot
.58388 .16819 Mdot
.40689 .33419 Mdot
.44315 .83251 Mdot
.57494 .16339 Mdot
.63379 .17325 Mdot
.52031 .39331 Mdot
.5297 .60742 Mdot
.60064 .19404 Mdot
.44085 .79707 Mdot
.45342 .77463 Mdot
.40834 .73596 Mdot
.45758 .37411 Mdot
.59143 .13237 Mdot
.55449 .10702 Mdot
.43053 .78354 Mdot
.4842 .78563 Mdot
.56725 .17413 Mdot
.5322 .49196 Mdot
.42691 .77766 Mdot
.43595 .14631 Mdot
.45864 .7693 Mdot
.44098 .15436 Mdot
.57165 .171 Mdot
.41251 .68402 Mdot
.52094 .09847 Mdot
.39376 .60269 Mdot
.53512 .67418 Mdot
.40255 .60589 Mdot
.52146 .07952 Mdot
.54624 .62654 Mdot
.52179 .7514 Mdot
.58258 .14288 Mdot
.53413 .69125 Mdot
.41286 .23207 Mdot
.50217 .06516 Mdot
.52618 .40208 Mdot
.48803 .76198 Mdot
.60051 .18912 Mdot
.63011 .18867 Mdot
.51926 .751 Mdot
.48883 .32928 Mdot
.41185 .61891 Mdot
.43676 .09068 Mdot
.44325 .78816 Mdot
.55954 .16823 Mdot
.738 .34641 Mdot
.58627 .15799 Mdot
.67072 .26935 Mdot
.61543 .20696 Mdot
.46669 .33236 Mdot
.53125 .08265 Mdot
.71304 .32703 Mdot
.42493 .11891 Mdot
.68093 .29242 Mdot
.80317 .4425 Mdot
.41626 .71773 Mdot
.40507 .72143 Mdot
.43419 .14159 Mdot
.58201 .13567 Mdot
.6659 .24061 Mdot
.49408 .76832 Mdot
.59746 .16635 Mdot
.44549 .80836 Mdot
.52608 .4801 Mdot
.41211 .18686 Mdot
.39592 .4661 Mdot
.42393 .14329 Mdot
.62309 .14581 Mdot
.52715 .43126 Mdot
.42499 .17757 Mdot
.41062 .28198 Mdot
.66562 .2708 Mdot
.52954 .43787 Mdot
.61531 .15518 Mdot
.70162 .30747 Mdot
.71327 .2912 Mdot
.5134 .70122 Mdot
.39478 .65055 Mdot
.39369 .55791 Mdot
.59315 .19101 Mdot
.50965 .77756 Mdot
.51878 .40032 Mdot
.48458 .33309 Mdot
.40744 .69576 Mdot
.55691 .08173 Mdot
.61706 .22545 Mdot
.54635 .51782 Mdot
.41141 .19223 Mdot
.53403 .50227 Mdot
.49815 .34289 Mdot
.38561 .40043 Mdot
.38978 .45055 Mdot
.44043 .16149 Mdot
.47122 .83998 Mdot
.44033 .77096 Mdot
.76139 .35858 Mdot
.41674 .70748 Mdot
.49015 .10174 Mdot
.53979 .56418 Mdot
.62037 .18567 Mdot
.44233 .74467 Mdot
.4995 .06737 Mdot
.5044 .11405 Mdot
.54963 .51264 Mdot
.40511 .56427 Mdot
.72501 .33702 Mdot
.59942 .13799 Mdot
.5026 .04816 Mdot
.55149 .14129 Mdot
.43761 .79782 Mdot
.40203 .66036 Mdot
.55465 .14222 Mdot
.41588 .72747 Mdot
.60422 .14529 Mdot
.69536 .2454 Mdot
.45774 .0695 Mdot
.64182 .20329 Mdot
.61922 .16053 Mdot
.61436 .14645 Mdot
.50358 .35744 Mdot
.40615 .65436 Mdot
.67978 .2853 Mdot
.57672 .11117 Mdot
.50386 .35707 Mdot
.54149 .14308 Mdot
.40127 .51756 Mdot
.39008 .42488 Mdot
.42915 .15835 Mdot
.62313 .20926 Mdot
.39158 .34139 Mdot
.56456 .12994 Mdot
.61604 .22806 Mdot
.5317 .14698 Mdot
.48579 .03484 Mdot
.49588 .09773 Mdot
.68029 .27637 Mdot
.79375 .42088 Mdot
.62667 .23678 Mdot
.41173 .23431 Mdot
.50467 .3732 Mdot
.68806 .27777 Mdot
.43026 .79414 Mdot
.48358 .33276 Mdot
.59068 .11865 Mdot
.44294 .09647 Mdot
.51231 .371 Mdot
.50868 .73164 Mdot
.462 .827 Mdot
.47553 .78931 Mdot
.54875 .09532 Mdot
.41194 .16737 Mdot
.7092 .31056 Mdot
.60435 .13855 Mdot
.39765 .40809 Mdot
.76645 .39385 Mdot
.39449 .52423 Mdot
.45099 .78565 Mdot
.47885 .80862 Mdot
.45301 .37343 Mdot
.57108 .10101 Mdot
.61704 .16505 Mdot
.44875 .76095 Mdot
.54216 .57865 Mdot
.54652 .66612 Mdot
.55113 .59812 Mdot
.63309 .16555 Mdot
.50157 .8006 Mdot
.54934 .14357 Mdot
.53528 .62101 Mdot
.50697 .75994 Mdot
.53262 .47658 Mdot
.49053 .81279 Mdot
.42218 .23258 Mdot
.51422 .74293 Mdot
.53241 .58228 Mdot
.64728 .18098 Mdot
.62492 .1867 Mdot
.44752 .51913 Mdot
.39208 .49348 Mdot
.41063 .71883 Mdot
.4757 .11453 Mdot
.40091 .50049 Mdot
.47803 .79402 Mdot
.67625 .24892 Mdot
.72643 .2896 Mdot
.40434 .24623 Mdot
.78638 .42103 Mdot
.38441 .52057 Mdot
.5392 .53997 Mdot
.6557 .26733 Mdot
.68425 .29565 Mdot
.47187 .78405 Mdot
.52427 .14206 Mdot
.76446 .36985 Mdot
.53924 .59606 Mdot
.51255 .37624 Mdot
.42873 .72463 Mdot
.55173 .15015 Mdot
.39998 .50057 Mdot
.74505 .34057 Mdot
.53696 .51551 Mdot
.41652 .24134 Mdot
.39339 .52836 Mdot
.54621 .49928 Mdot
.53046 .4767 Mdot
.5393 .65284 Mdot
.549 .075 Mdot
.52246 .39644 Mdot
.48933 .05076 Mdot
.39816 .27756 Mdot
.40025 .28844 Mdot
.50484 .07702 Mdot
.56252 .17539 Mdot
.39531 .47688 Mdot
.70975 .26182 Mdot
.51156 .72648 Mdot
.55568 .07971 Mdot
.6231 .15614 Mdot
.44567 .74535 Mdot
.51818 .06649 Mdot
.40321 .58796 Mdot
.41169 .29466 Mdot
.49174 .05987 Mdot
.42049 .18298 Mdot
.49445 .79119 Mdot
.40646 .5908 Mdot
.40877 .29702 Mdot
.66021 .19529 Mdot
.42339 .20332 Mdot
.44622 .42758 Mdot
.4188 .22495 Mdot
.39978 .47453 Mdot
.4898 .32 Mdot
.48993 .74799 Mdot
.40533 .29898 Mdot
.39048 .46457 Mdot
.52583 .43499 Mdot
.42812 .75685 Mdot
.59776 .15608 Mdot
.50656 .78617 Mdot
.43945 .14074 Mdot
.53445 .7101 Mdot
.42905 .71447 Mdot
.50756 .36651 Mdot
.78807 .40475 Mdot
.51393 .393 Mdot
.39249 .31801 Mdot
.6331 .23844 Mdot
.56099 .16044 Mdot
.49043 .79034 Mdot
.49904 .06476 Mdot
.6079 .14654 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:Oooooo0_l00003ooooo`03o`000?oooooooooo0;Wo
oooo002Wooooo`;o00000oooool00ol0003oooooooooo`2iooooo`00XOooool2o`0000?ooooo0_l0
0004ooooo`03o`000?oooooooooo0;Wooooo002Qooooo`;o00000oooool2o`0000Cooooo00?o0000
ooooooooool0^Oooool00:Kooooo0_l00004ooooo`03o`000?oooooooooo0;Wooooo002Pooooo`;o
00001?ooool2o`0000?ooooo0ol0002jooooo`00X?ooool2o`0000Kooooo0_l000000ooooooo0000
o`000002o`000;Wooooo002Pooooo`;o00001_ooool2o`0000;ooooo00?o0000ooooooooool0^Ooo
ool00:;ooooo0_l00005ooooo`;o000000?oooooo`000?ooool0^_ooool00:;ooooo0_l00005oooo
o`;o000000?oooooo`000?ooool0^_ooool009[ooooo0_l0000=ooooo`Go0000^_ooool009[ooooo
0_l00007ooooo`?o00001Oooool3o`0000Cooooo0_l00005ooooo`;o0000[Oooool009kooooo0_l0
0003ooooo`?o00001Oooool2o`000003ooooool0003o000000;ooooo0_l00005ooooo`;o0000[Ooo
ool009kooooo0_l00007ooooo`;o00000oooool01?l0003oooooo`000?l0002hooooo`00W_ooool4
o`0000Gooooo0_l00003ooooo`?o00002_ooool2o`000003ooooool0003o00000:[ooooo002Hoooo
o`;o00001_ooool3o`0000Wooooo1Ol00002ooooo`;o00001?ooool7o`000:Sooooo002Hooooo`;o
00001oooool2o`0000Wooooo00?o0000ooooooooool00_l00002ooooo`;o000000?oooooo`000?l0
00000oooool5o`000:Sooooo002Looooo`;o00002_ooool2o`0000;ooooo00?o0000ooooooooool0
1?ooool5o`0000Cooooo1?l0002Xooooo`00W?ooool2o`0000Sooooo1?l00002ooooo`03o`000?oo
oooooooo00Cooooo1?l0000<ooooo`;o0000Xoooool009Kooooo0ol0000=ooooo`;o00001?ooool0
0ol0003oooooooooo`0?ooooo`;o00000_ooool3o`000:?ooooo002Fooooo`?o00001?ooool2o`00
00gooooo00?o0000ooooooooool03Oooool4o`0000;ooooo0_l0002Tooooo`00U?ooool2o`0000?o
oooo0_l00002ooooo`Co00002Oooool3o`0000Gooooo0_l00008ooooo`Co000000?oooooo`000?l0
0000YOooool009Cooooo0_l00002ooooo`?o00001?ooool2o`0000Wooooo1Ol00003ooooo`;o0000
1?ooool2o`0000Cooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o00000:3ooooo
002Hooooo`;o00001oooool5o`0000;ooooo0_l00002ooooo`03o`000?oooooooooo00Wooooo0_l0
0004ooooo`;o00000oooool2o`000004ooooool0003o0000o`0009oooooo002Qooooo`Go00000_oo
ool2o`0000;ooooo00?o0000ooooooooool03oooool2o`0000Oooooo0_l0002Oooooo`00[?ooool0
0ol0003oooooooooo`0?ooooo`;o0000Z?ooool009cooooo0_l0000=ooooo`;o00002oooool2o`00
00_ooooo0_l0002Qooooo`00VOooool2o`000003ooooool0003o000000Kooooo0_l00005ooooo`Co
00002Oooool2o`0000Sooooo1ol0002Oooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_l00004ooooo`?o000000?ok^k^ooooooooool00oooool01Om4A4Co0000o`000?l0003ogMgM
00Gooooo0ol0000Aooooo`Go00000_ooool4o`0009gooooo0029ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2o`0000Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo017ooooo0_l00007ooooo`;o0000WOooool0087ooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo
00?ooooo0ol0002iooooo`00ROooool01Ol0003ooooooooooooooooo000000_ooooo0_l000000ooo
oooo8B4Qooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0^Oooool008Wo
oooo00Go0000ooooooooooooooooo`00000;ooooo`;o000000?ooooooeEEEOo<c<`01?ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool04_ooool2o`000003ooooool0003o
00000:;ooooo0029ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool2o`000003ooooool0003o
000000Cooooo0_l0002Looooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@
oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06?oo
ool2o`000003ooooool0003o000000;o0000V_ooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0:ooooo`Ko00001?ooool4o`0000Kooooo00?o0000ooooooooool01_ooool2o`00013ooooo0_l0
0003ooooo`Co00000oooool2o`0009?ooooo002Booooo`;o00000_ooool5o`00017ooooo00?o0000
ooooooooool01Oooool3o`0000;ooooo0_l000000ooooooo0000o`000002o`0000Oooooo0_l00005
ooooo`;o00000oooool2o`0009?ooooo002Booooo`;o00000_ooool2o`000003ooooool0003o0000
017ooooo00?o0000ooooooooool01Oooool4o`000004ooooool0003o0000ooooo`Co00001?ooool2
o`000003ooooool0003o000000Gooooo1Ol000000ooooooo0000o`00002Booooo`00U_ooool2o`00
01Cooooo00?o0000ooooooooool01oooool2o`0000Wooooo0_l000000ooooooo0000o`000008oooo
o`Go000000?oooooo`000?l00000T_ooool009Gooooo0_l0000Eooooo`?o00002oooool2o`000003
ooooool0003o000000;ooooo0_l0000:ooooo`;o0000VOooool009Gooooo1Ol0000Booooo`03o`00
0?oooooooooo00[ooooo0ol000000ooooooo0000o`000002o`0000[ooooo1?l00003ooooo`Co0000
T_ooool009Cooooo0_l000000ooooooo0000o`000002o`00017ooooo00?o0000ooooooooool02_oo
ool2o`0000;ooooo1?l00007ooooo`;o000000Coooooo`000?l0003o00001?ooool4o`0009;ooooo
002Dooooo`;o00000_ooool3o`00017ooooo00?o0000ooooooooool03_ooool2o`000003ooooool0
003o000000;o00001?ooool2o`0000;ooooo0_l00004ooooo`Co0000T_ooool009Sooooo0_l0000B
ooooo`03o`000?oooooooooo017ooooo1_l00006ooooo`;o00001?ooool3o`0009?ooooo002>oooo
o`;o00007?ooool00ol0003oooooooooo`0@ooooo`;o00000oooool2o`000003ooooool0003o0000
00?ooooo0_l00004ooooo`;o00000oooool2o`0008oooooo002>ooooo`;o00007?ooool00ol0003o
ooooooooo`0@ooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o00002Oooool2o`0008oo
oooo002/ooooo`03o`000?oooooooooo01?ooooo0ol00004ooooo`;o00001?ooool2o`0000Oooooo
0_l0002>ooooo`00[?ooool3o`00017ooooo1Ol00004ooooo`;o00001?ooool2o`0000Oooooo0_l0
002>ooooo`00S_ooool2o`0000?ooooo0_l0000Gooooo`03o`000?oooooooooo017ooooo0_l00000
0ooooooo0000o`00002Sooooo`00S_ooool2o`000003ooooool0003o000000;o00005oooool00ol0
003oooooooooo`0Dooooo`;o00005oooool2o`0008[ooooo002Aooooo`;o00006Oooool00ol0003o
ooooooooo`0Dooooo`;o00003_ooool2o`0000Oooooo0_l0002:ooooo`00Soooool2o`0001_ooooo
00?o0000ooooooooool06_ooool2o`0000;ooooo0ol00003ooooo`Ko0000Soooool008kooooo0ol0
000Kooooo`03o`000?oooooooooo01[ooooo0ol000001?oooooo0000o`000?l00005ooooo`Co0000
1_ooool2o`0008Oooooo002>ooooo`;o00007?ooool00ol0003oooooooooo`0Kooooo`;o000000?o
ooooo`000?l000002_ooool2o`0000Cooooo0ol00026ooooo`00[?ooool00ol0003oooooooooo`0N
ooooo`;o00001Oooool2o`000003ooooool0003o000000;o00001Oooool2o`0008Kooooo002@oooo
o`;o00006_ooool3o`0002Gooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o0000
08[ooooo002=ooooo`;o000000?oooooo`000?l000000_l0000Hooooo`03o`000?oooooooooo02?o
oooo0_l00006ooooo`Co0000R_ooool008gooooo0_l00003ooooo`;o00006?ooool00ol0003ooooo
ooooo`0Sooooo`;o00001?ooool4o`0008cooooo002@ooooo`;o00006_ooool00ol0003ooooooooo
o`0Sooooo`Co00000_ooool2o`000003ooooool0003o000008_ooooo002@ooooo`;o00006_ooool0
0ol0003oooooooooo`0Uooooo`;o00001Oooool2o`0000Gooooo0_l00024ooooo`00[?ooool00ol0
003oooooooooo`0Wooooo`;o00002_ooool2o`0008Cooooo002/ooooo`03o`000?oooooooooo02Oo
oooo0_l0000;ooooo`;o0000Poooool00:cooooo00?o0000ooooooooool08oooool2o`0000oooooo
0_l00023ooooo`00TOooool2o`0001Wooooo0ol0000Sooooo`;o0000U?ooool0097ooooo0_l0000I
ooooo`03o`000?oooooooooo02?ooooo0_l0002Dooooo`00T_ooool2o`0001Sooooo00?o0000oooo
ooooool08oooool2o`0009Cooooo002:ooooo`;o00000_ooool6o`0001Sooooo00?o0000oooooooo
ool0=_ooool2o`00087ooooo002:ooooo`;o00000_ooool6o`0001Sooooo00?o0000ooooooooool0
9_ooool2o`0000kooooo0_l00021ooooo`00[?ooool00ol0003oooooooooo`0Vooooo`;o000000?o
ooooo`000?l000002?ooool2o`0008Cooooo002@ooooo`;o000000Co<S8bo`000?lb<S;ok^k^1Ooo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo02Wooooo
0_l00008ooooo`;o0000Q?ooool008cooooo0_l00002ooooo`;o000000CoV9RHoooooonHV9SoMgMg
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0mooooo`;o0000
N_ooool008Wooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo03Oooooo0_l00004ooooo`;o0000N_ooool0097ooooo00Go
0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000]ooooo`;o0000
2?ooool2o`00083ooooo002Aooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0;Oooool2o`0000cooooo0_l0001looooo`00
TOooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0kooooo`;o0000O?ooool0097ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0@_ooool2o`0007Gooooo002>ooooo`;o0000
00Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`Co00001_ooool00ol0003oooooooooo`12oooo
o`;o0000MOooool008Wooooo0_l00003ooooo`;o00007?ooool00ol0003oooooooooo`0`ooooo`;o
0000Qoooool008Wooooo0_l0000Qooooo`03o`000?oooooooooo033ooooo0_l000000ooooooo0000
o`000002o`0008;ooooo0029ooooo`;o00008Oooool00ol0003oooooooooo`0cooooo`Go00001_oo
ool2o`0007Wooooo0029ooooo`;o00008Oooool3o`0003Kooooo1?l00004ooooo`;o0000NOooool0
08[ooooo0_l0000Pooooo`03o`000?oooooooooo03Sooooo0_l000000ooooooo0000o`00001loooo
o`00R_ooool2o`0000;ooooo0_l0000Looooo`03o`000?oooooooooo03_ooooo0_l0001looooo`00
S_ooool2o`0001cooooo00?o0000ooooooooool0>?ooool4o`0007gooooo002;ooooo`;o00007ooo
ool00ol0003oooooooooo`0hooooo`Co0000OOooool008Sooooo0_l000000ooooooo0000o`00000O
ooooo`03o`000?oooooooooo03Sooooo0_l00005ooooo`;o00000_ooool2o`0000;ooooo0_l0001`
ooooo`00R?ooool2o`0000Cooooo0_l0000Looooo`03o`000?oooooooooo03Sooooo0ol00004oooo
o`;o00000_ooool2o`0000;ooooo0_l0001`ooooo`00SOooool3o`0001cooooo00?o0000oooooooo
ool0>Oooool2o`0007kooooo002<ooooo`?o00007Oooool3o`0003Wooooo0_l0001nooooo`00S?oo
ool2o`0001kooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0?oooool2
o`0007Sooooo002;ooooo`;o00007oooool00ol0003oooooooooo`0mooooo`Co000000?oooooo`00
0?l000001?ooool2o`0006oooooo002;ooooo`;o00007oooool00ol0003oooooooooo`0mooooo`;o
00000oooool2o`0000Cooooo0_l0001_ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00R?oo
ool2o`0001gooooo0_l00003ooooo`03o`000?oooooooooo04[ooooo0_l0001]ooooo`00R?ooool2
o`0001gooooo0ol00002ooooo`03o`000?oooooooooo04[ooooo1?l0001[ooooo`00Z?ooool2o`00
00;ooooo0ol0001:ooooo`Co0000Joooool008_ooooo0_l0000Looooo`;o000000?oooooo`000?oo
ool0A?ooool2o`0007Cooooo002;ooooo`;o00006oooool3o`000003ooooool0003ooooo04Cooooo
0_l0001dooooo`00R_ooool2o`000003ooooool0003o000001;ooooo0_l00003ooooo`Oo0000C?oo
ool2o`0006gooooo002:ooooo`;o000000?oooooo`000?l000004_ooool3o`0000;ooooo0_l00002
ooooo`?o0000BOooool2o`000003ooooool0003o000000;ooooo0_l0001Yooooo`00X_ooool2o`00
00Sooooo00?o0000ooooooooool0Aoooool2o`0000Cooooo0ol0001Yooooo`00R?ooool2o`00027o
oooo0_l0001?ooooo`;o0000J_ooool008Sooooo0_l0000Qooooo`;o0000COooool2o`0006cooooo
002/ooooo`03o`000?oooooooooo04Sooooo0_l000000ooooooo0000o`00001/ooooo`00[?ooool3
o`0004Sooooo0_l0001_ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`0005?o
oooo0_l0001Tooooo`00Qoooool2o`0002;ooooo1?l0001Cooooo`;o0000I?ooool008Oooooo0_l0
000Rooooo`;o0000DOooool2o`0006Sooooo0027ooooo`;o000000Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`04o`00
0?oooooo0000o`0004kooooo0_l0001Xooooo`00Qoooool2o`000005ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooool000000ol0001Aooooo`;o0000Hoooool0087ooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qo`000003o`0000Kooooo00?o0000oooo
ooooool00oooool3o`000003ooooool0003o0000057ooooo0_l0001Sooooo`00ROooool01Ol0003o
oooooooooooooooo000000gooooo00?oV9RHo`000?l000000_l00005ooooo`03ogMgMolb<S;ooooo
00Cooooo0ol000000ooooooo0000o`00002fooooo`00ROooool01Ol0003ooooooooooooooooo0000
00kooooo00?oMgMgo`000?l000000oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00Co0000
oooooooooooooooo0_l0002fooooo`00R?ooool2o`0000?ooooo00?o410@ooooooooool03Oooool2
o`0000?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2iooooo`00R?ooool2o`00
0004oiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool00oooool2o`0004gooooo0_l0001Uooooo`00ROooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co0000
1_ooool00ol0003oooooooooo`03ooooo`;o0000COooool2o`0000;ooooo0_l0001Qooooo`00[?oo
ool00ol0003oooooooooo`1Fooooo`;o0000HOooool00:cooooo00Co0000oooooooooooooooo1?l0
001@ooooo`?o0000HOooool008Wooooo0_l000000ooooooo0000o`00000Nooooo`04o`000?oooooo
ooooooooo`Go0000Coooool3o`00067ooooo0026ooooo`;o000000Coooooo`000?l0003ooooo0_l0
000Nooooo`?o00000oooool3o`000;?ooooo0026ooooo`;o00009?ooool00ol0003oooooooooo`03
ooooo`Co0000/_ooool00:cooooo00?o0000ooooooooool01Oooool2o`0005Gooooo0_l0001Koooo
o`00R_ooool2o`00023ooooo00?o0000ooooooooool0G?ooool2o`0005_ooooo002:ooooo`;o0000
8?ooool00ol0003oooooooooo`2iooooo`00R?ooool2o`0002;ooooo00?o0000ooooooooool0^Ooo
ool008Sooooo0_l0000Rooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
05_ooooo0_l000000ooooooo0000o`00001Iooooo`00Qoooool2o`0002?ooooo0ol0001Kooooo`;o
000000?oooooo`000?l00000FOooool008Oooooo0_l0000Aooooo`;o00004?ooool00ol0003ooooo
ooooo`2iooooo`00QOooool2o`0001?ooooo0_l0000@ooooo`03o`000?oooooooooo00Kooooo0_l0
001Eooooo`;o0000F_ooool008Gooooo0_l00003ooooo`;o00008?ooool00ol0003oooooooooo`06
ooooo`;o0000EOooool2o`0005[ooooo002:ooooo`;o00008?ooool00ol0003oooooooooo`05oooo
o`?o0000/Oooool00:cooooo00?o0000ooooooooool01Oooool3o`0005Oooooo0_l0001Hooooo`00
[?ooool00ol0003oooooooooo`1Oooooo`Co0000E_ooool008Kooooo0_l0000Tooooo`03o`000?oo
oooooooo067ooooo0_l0001Fooooo`00Q_ooool2o`0002Cooooo00?o0000ooooooooool0^Oooool0
08Oooooo0_l0000Sooooo`?o0000^Oooool008Oooooo0_l0000Sooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo00Sooooo0_l0002_ooooo`002Oooool4o`000003oa0@4?oo
oooooooo01Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^
ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B42ooooo`Oo00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Kooooo
00?o0000ooooooooool02?ooool3o`0000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000
o`000?lb<S;ogMgM01Sooooo1?l000000ol@413oooooooooo`0Booooo`002oooool00ol0003ooooo
ooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOoo
ool01oooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B42
ooooo`?o000000Co8B4Qonk^k_ooooooA4A41oooool00omgMgOo<S8booooo`0Eooooo`03o`000?oo
oooooooo00Wooooo0_l0000=ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo
00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`0I
ooooo`03o`000?oooooooooo01Cooooo0006o`0000Gooooo00?o0000ooooooooool04?ooool6o`00
00;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000
ooooooooool01Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oo
oooooooo00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41002Oooool5o`000003onk^
k_oooooooooo00Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Hooooo`05oa0@
4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00go
oooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00gooooo00Go410@oooo
oooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05o`000?oooooooooo
ooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000oooooooooooooooo
o`00000<ooooo`;o000000?o8B4Qonk^k_ooool01_ooool00omgMgOo<S8booooo`0Eooooo`03o`00
0?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b
<_ooool03_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool0
0omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo
01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000;ooooo`;o000000?oooooogMg
MomVIVH01?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00?ooooo0_l0000Aooooo`03o`000?oooooo
oooo01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<co
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Jooooo`03o`000?oooooooooo01Cooooo000;
ooooo`03o`000?oooooooooo01Sooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmg
MgOooooo00?ooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00cooooo
00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00004ooooo`03
o`000?oooooooooo00Gooooo0_l0000Aooooo`?o00001oooool2o`0000oooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04Oooool01Ol@
413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooo
oooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`0Aooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`05ooooo`Co00003oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000
okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0<ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
01Cooooo0009ooooo`03oeEEEOmVIVKo000001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`Go00001?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00004?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo0ol000000olQ8B7oc<c<ooooo`03ooooo`Co00005ooo
ool00ol0003oooooooooo`05ooooo`;o00004Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000I
ooooo`03oeEEEOmVIVKo000001Kooooo0028ooooo`;o00008_ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`07ooooo`;o0000
YOooool2o`0000;ooooo0_l00005ooooo`00R?ooool2o`0002;ooooo00?o0000ooooooooool01_oo
ool3o`000:Gooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd5ooooo`00R?ooool2o`0002;ooooo
00?o0000ooooooooool01_ooool2o`000:Oooooo00CogMgMo`000?l@413oc<c<1_ooool000Oooooo
ool0001<o`0000cooooo00Cok^k^ob4Q8Ol@413ok^k^1_ooool000Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool2o`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool01?l0003oooooo`000?l00002ooooo`?o
00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool02_ooool01?lQ8B7oMgMgogMgMolb<S86ooooo`001oooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo00Sooooo0_l0000Mooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Wooooo0_l00002ooooo`;o
00001Oooool008Oooooo0_l0000Sooooo`03o`000?oooooooooo0;Wooooo0027ooooo`;o00008ooo
ool00ol0003oooooooooo`0<ooooo`?o0000Z_ooool00:cooooo00?o0000ooooooooool02Oooool2
o`000004ooooool0003o0000o`000:[ooooo002;ooooo`;o00003Oooool2o`00013ooooo00?o0000
ooooooooool02Oooool2o`000003ooooool0003o00000:_ooooo0025ooooo`;o00001?ooool2o`00
00gooooo0_l0000@ooooo`03o`000?oooooooooo00_ooooo0ol0002[ooooo`00QOooool2o`0000;o
oooo0_l0000Qooooo`?o00002oooool2o`000:cooooo0028ooooo`?o00008Oooool00ol0003ooooo
ooooo`2iooooo`00R?ooool2o`0002;ooooo00?o0000ooooooooool01oooool2o`000;3ooooo002/
ooooo`03o`000?oooooooooo00Oooooo0_l0002`ooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`08ooooo`Co0000[Oooool008Oooooo0_l0000Sooooo`03o`00
0?oooooooooo00Sooooo1?l0002]ooooo`00Qoooool3o`0002;ooooo00?o0000ooooooooool02ooo
ool2o`000:cooooo0028ooooo`;o00008_ooool00ol0003oooooooooo`0:ooooo`?o0000[?ooool0
0:cooooo0ol0000:ooooo`;o000000?oooooo`000?l00000Z_ooool00:cooooo00?o0000oooooooo
ool03Oooool2o`000:[ooooo0028ooooo`;o00008_ooool00ol0003oooooooooo`0<ooooo`;o0000
Zoooool008Sooooo0_l0000Rooooo`03o`000?oooooooooo00cooooo0_l0002[ooooo`00S?ooool2
o`0001kooooo00?o0000ooooooooool02_ooool2o`000:gooooo002<ooooo`;o00007_ooool00ol0
003oooooooooo`0:ooooo`;o0000[Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool03oooool2o`000:Sooooo002/ooooo`?o00003oooool2o`000:Sooooo002/
ooooo`03o`000?oooooooooo00[ooooo0_l0002]ooooo`00R_ooool2o`00023ooooo00?o0000oooo
ooooool01oooool2o`000003ooooool0003o00000:gooooo002:ooooo`;o00008?ooool00ol0003o
ooooooooo`07ooooo`;o0000/?ooool008cooooo0_l0000Nooooo`03o`000?oooooooooo0;Wooooo
002<ooooo`?o00007Oooool00ol0003oooooooooo`09ooooo`;o0000[_ooool008gooooo0_l0000M
ooooo`03o`000?oooooooooo00Wooooo0_l0002^ooooo`00[?ooool00ol0003oooooooooo`0:oooo
o`;o000000?oooooo`000?l00000Z_ooool00:cooooo0ol0000:ooooo`;o000000?oooooo`000?l0
0000Z_ooool008Sooooo0_l0000Rooooo`03o`000?oooooooooo0;Wooooo0028ooooo`;o000000?o
ooooo`000?l000000_l0000Mooooo`03o`000?oooooooooo00Kooooo0_l0002aooooo`00Roooool4
o`0001gooooo00?o0000ooooooooool01_ooool2o`000;7ooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo00Sooooo0_l0002_ooooo`00ROooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00;o00000oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`08ooooo`;o0000[oooool008Wooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`02o`0000?ooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00Sooooo0ol0002^ooooo`00ROooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03
ooooo`?o00002?ooool3o`000:kooooo0029ooooo`05o`000?ooooooooooooooool000003Oooool0
0onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool03?ooool2
o`000:_ooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0<ooooo`;o0000Zooo
ool008Wooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2iooooo`00ROooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0^Oooool008Wooooo00?ok^k^oc8b<_l000000_l0000;ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool0^Oooool008cooooo0_l0
000Nooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00Sooooo0_l0002_
ooooo`00[?ooool00ol0003oooooooooo`08ooooo`;o0000[oooool008Wooooo0_l00003ooooo`;o
00007?ooool3o`0000[ooooo0_l0002]ooooo`00ROooool2o`0000;ooooo0ol0000Looooo`03o`00
0?oooooooooo00Wooooo0ol0002]ooooo`00SOooool2o`0001gooooo00?o0000ooooooooool02Ooo
ool2o`000:kooooo002;ooooo`;o00007oooool00ol0003oooooooooo`2iooooo`00Roooool2o`00
01oooooo00?o0000ooooooooool02_ooool2o`000:gooooo002/ooooo`03o`000?oooooooooo00[o
oooo1?l0002[ooooo`00[?ooool00ol0003oooooooooo`02ooooo`;o00000_ooool2o`000003oooo
ool0003o000000?o0000Zoooool00:cooooo00?o0000ooooooooool00_ooool2o`0000;ooooo1_l0
002]ooooo`00[?ooool3o`0000Sooooo0_l0002_ooooo`00TOooool2o`0001Wooooo00?o0000oooo
ooooool0^Oooool0097ooooo0_l0000Iooooo`03o`000?oooooooooo00?ooooo0_l0002dooooo`00
Soooool2o`0001_ooooo00?o0000ooooooooool00oooool2o`000;Cooooo002?ooooo`;o00006ooo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`08ooooo`;o0000[oooool0
0:cooooo00?o0000ooooooooool02?ooool2o`000:oooooo002=ooooo`;o00007Oooool00ol0003o
ooooooooo`2iooooo`00SOooool2o`0001gooooo0ol000000ooooooo0000o`00002fooooo`00[?oo
ool01?l0003oooooooooooooool2o`000;Kooooo002@ooooo`;o00006_ooool00ol0003ooooooooo
o`2iooooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool02?ooool2o`000:oooooo002/oooo
o`?o00002?ooool2o`000:oooooo002Dooooo`;o00005_ooool3o`000003ooooool0003o00000;Ko
oooo002>ooooo`So00005_ooool3o`000004ooooool0003o0000o`000;Gooooo002<ooooo`So0000
6?ooool3o`000004ooooool0003o0000o`000;Gooooo002<ooooo`;o000000?oooooo`000?l00000
0oooool2o`0001Kooooo0ol0002iooooo`00Soooool3o`0000;ooooo0_l0000Fooooo`03o`000?oo
oooooooo00;o0000]oooool008oooooo0ol0000Jooooo`03o`000?oooooo000000;o0000]oooool0
0:cooooo00Co0000ooooool0003o0000^?ooool008gooooo0_l0000Mooooo`04o`000?oooooooooo
ooooo`;o0000]_ooool008gooooo0_l0000Mooooo`04o`000?ooooooooooooooo`?o0000]Oooool0
097ooooo00?ok^k^oc8b<_l000000_l00005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00Co0000oooooooooooooooo0ol0002eooooo`00TOooool00omgMgOoV9RHooooo`02
o`0000?ooooo0ol000000olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00;ooooo0ol00003
ooooo`;o0000]_ooool0097ooooo00Go410@oooooooooooooooooa0@4003ooooo`?o00002_ooool0
0ol0003oooooo`000005o`000;[ooooo002Aooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`02o`0000;ooooo0ol00003ooooo`?o0000/oooool0097ooooo00Go0000oooo
ooooooooooooo`000004ooooo`;o00001_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;o00000ooo
ool00ol0003oooooooooo`03ooooo`?o0000/oooool0097ooooo00?o410@ooooooooool00_l00004
ooooo`;o00001_ooool00ol0003oooooooooo`02ooooo`;o00000oooool00ol0003oooooooooo`2i
ooooo`00TOooool00omgMgOoV9RHooooo`02o`0000Gooooo0_l00005ooooo`03o`000?oooooooooo
00;o000000?oooooo`000?l000000_ooool00ol0003oooooo`000003o`000;Kooooo002Aooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00_ooool2o`000003ooooool0003o000000Gooooo1Ol000000ooo
oooo0000o`000002ooooo`03o`000?oooooo000000?o0000]_ooool009Sooooo0_l0000Booooo`04
o`000?oooooo0000o`000;Sooooo002Hooooo`;o00001?ooool2o`0000[ooooo0ol000000ooooooo
0000o`00002hooooo`00V?ooool2o`0000Cooooo0_l00007ooooo`;o000000Coooooo`000?l0003o
0000^oooool009_ooooo0ol00007ooooo`Co00000oooool3o`000;Wooooo002Cooooo`;o00001_oo
ool3o`0000Oooooo0ol00004ooooo`03o`000?oooooooooo00;o0000]oooool009?ooooo0_l00002
ooooo`Co00002oooool2o`0000Cooooo00?o0000ooooooooool00_l0002gooooo`00UOooool8o`00
0003ooooool0003o000000;ooooo0_l00002ooooo`;o00001?ooool01?l0003oooooo`000?l0002h
ooooo`00Toooool4o`0000;ooooo1?l000001Ooooooo0000o`000?l0003ooooo00;o00000_ooool4
o`0000;ooooo00Co0000ooooool0003o0000^?ooool009?ooooo0_l00004ooooo`?o00000oooool2
o`0000;ooooo0_l000000ooooooo0000o`000005o`000;_ooooo002Eooooo`;o00003?ooool3o`00
0003ooooool0003o000000Co0000^oooool009Gooooo1Ol0000:ooooo`;o00001_ooool00ol0003o
ooooooooo`2iooooo`00Uoooool5o`0000Gooooo0_l00009ooooo`?o0000^Oooool009[ooooo0_l0
0005ooooo`;o00002Oooool2o`000;[ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Joooo
o`;o00002Oooool2o`0000Gooooo00?o0000ooooooooool0^Oooool009[ooooo0_l00008ooooo`Ko
00000_ooool00ol0003oooooooooo`2iooooo`00Y?ooool2o`000003ooooool0003o000000;o0000
00?oooooo`000?ooool0^_ooool009Sooooo0_l00007ooooo`;o00001_ooool2o`000003ooooool0
003ooooo0;[ooooo002Hooooo`;o00001oooool2o`000003ooooool0003o000000Kooooo00?o0000
ooooooooool0^Oooool00:3ooooo0_l00002ooooo`;o00001_ooool3o`000;Wooooo002Hooooo`;o
00001Oooool3o`0000[ooooo00?o0000ooooooooool0^Oooool009Sooooo0_l00005ooooo`;o0000
1oooool2o`0000;ooooo00?o0000ooooooooool0^Oooool009Wooooo0_l0000=ooooo`;o00000_oo
ool00ol0003oooooooooo`2iooooo`00VOooool3o`000003ooooool0003o000000gooooo00?o0000
ooooooooool0^Oooool009[ooooo0_l000000ooooooo0000o`000003ooooo`Co00001_ooool00ol0
003oooooooooo`2iooooo`00WOooool2o`0000?ooooo1?l00006ooooo`03o`000?oooooooooo0;Wo
oooo002Mooooo`;o00003Oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o
0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0
^Oooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVY
ooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0^Oooool008Wooooo00Go
410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`2iooooo`00ROooool01Ol0003ooooooooooooooooo000000kooooo
00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`?o0000^Oooool008Wooooo00Go
0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05oa0@4?ooooooooooooooool@
41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0^Oooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooo
oolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o
0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:;ooooo1?l000000ol@
413oooooooooo`03ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000ooooooooool01Oooool3o`000;Wooooo
002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Toooo
o`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Rooooo`03oeEE
EOmVIVKo00000<?ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo002Zooooo`04oa0@4?l0003o0000o`000;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`06o`000?mgMgOo0000o`000?mEEEGok^k^
]oooool00:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomEEEFgooooo`00Zoooool00ol0003ok^k^
ooooo`02ooooo`03o`000?oooooooooo0;Gooooo002[ooooo`03o`000?o^k^kooooo00;ooooo00?o
0000ooooooooool0]Oooool00:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomVIVJgooooo`00Z_oo
ool00ol@413o0000ogMgM`02o`000003ofIVI_o^k^kooooo0;Kooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.42251 .82122 Mdot
.43475 .86938 Mdot
.47571 .63609 Mdot
.55108 .48081 Mdot
.57436 .617 Mdot
.46698 .88262 Mdot
.43945 .43048 Mdot
.37459 .29796 Mdot
.47609 .02736 Mdot
.56434 .51712 Mdot
.56359 .57216 Mdot
.44238 .02997 Mdot
.44136 .8994 Mdot
.56783 .46451 Mdot
.56236 .09731 Mdot
.5566 .47094 Mdot
.47722 .85346 Mdot
.44288 .90284 Mdot
.57518 .56776 Mdot
.39678 .78381 Mdot
.38444 .62387 Mdot
.39033 .66584 Mdot
.38962 .34544 Mdot
.41853 .84521 Mdot
.5605 .08627 Mdot
.58289 .63361 Mdot
.54356 .66097 Mdot
.56 .63226 Mdot
.37875 .63448 Mdot
.39791 .71986 Mdot
.39603 .26936 Mdot
.42867 .07236 Mdot
.42663 .06575 Mdot
.42743 .78791 Mdot
.48917 .86417 Mdot
.40297 .20418 Mdot
.40678 .15577 Mdot
.5495 .65715 Mdot
.40231 .1918 Mdot
.40418 .11834 Mdot
.48663 .0043 Mdot
.46962 .86401 Mdot
.45337 .86288 Mdot
.48635 .90051 Mdot
.48198 .89693 Mdot
.57993 .61778 Mdot
.55755 .58964 Mdot
.38824 .2297 Mdot
.57069 .69102 Mdot
.38486 .30858 Mdot
.40237 .15844 Mdot
.37673 .38263 Mdot
.687 .19192 Mdot
.43706 .8296 Mdot
.5027 .85485 Mdot
.46281 .02492 Mdot
.38947 .19106 Mdot
.50946 .82289 Mdot
.39368 .20672 Mdot
.48572 .894 Mdot
.56841 .65931 Mdot
.55171 .0546 Mdot
.43086 .09938 Mdot
.51305 .32247 Mdot
.5309 .06866 Mdot
.42422 .07946 Mdot
.5612 .54731 Mdot
.55269 .54691 Mdot
.5675 .59215 Mdot
.39515 .73591 Mdot
.56663 .72797 Mdot
.43386 .46573 Mdot
.55717 .58046 Mdot
.56163 .51672 Mdot
.43165 .09773 Mdot
.45243 .60623 Mdot
.68767 .19305 Mdot
.51333 .78252 Mdot
.37419 .44778 Mdot
.4681 .83437 Mdot
.40022 .23157 Mdot
.38993 .64533 Mdot
.54945 .51208 Mdot
.48657 .86299 Mdot
.38011 .25919 Mdot
.54413 .37394 Mdot
.57524 .61582 Mdot
.53633 .72695 Mdot
.53958 .77207 Mdot
.55077 .56385 Mdot
.57796 .10878 Mdot
.65359 .16344 Mdot
.51404 .31598 Mdot
.57251 .63772 Mdot
.52202 .34401 Mdot
.62183 .1191 Mdot
.56763 .46844 Mdot
.4596 .03671 Mdot
.68627 .18829 Mdot
.56969 .71465 Mdot
.40815 .76429 Mdot
.56289 .72338 Mdot
.48607 .01286 Mdot
.46301 .90085 Mdot
.37942 .5491 Mdot
.42855 .79339 Mdot
.54064 .77877 Mdot
.57798 .56096 Mdot
.51284 .31231 Mdot
.38454 .63659 Mdot
.56633 .46837 Mdot
.5461 .42206 Mdot
.43924 .05364 Mdot
.3792 .61698 Mdot
.72448 .23134 Mdot
.44578 .33438 Mdot
.55208 .70462 Mdot
.37639 .30158 Mdot
.38666 .22639 Mdot
.46721 .04581 Mdot
.42501 .86225 Mdot
.51569 .01776 Mdot
.39608 .27969 Mdot
.386 .71538 Mdot
.38946 .69146 Mdot
.55155 .51729 Mdot
.37564 .49715 Mdot
.6122 .11045 Mdot
.3855 .48443 Mdot
.50442 .33041 Mdot
.38322 .55752 Mdot
.39562 .6853 Mdot
.4744 .00693 Mdot
.5029 .86688 Mdot
.45511 .86788 Mdot
.37875 .64574 Mdot
.37148 .49457 Mdot
.37508 .52542 Mdot
.5548 .59137 Mdot
.46893 .0156 Mdot
.54325 .07213 Mdot
.62727 .1479 Mdot
.53001 .35688 Mdot
.57389 .56424 Mdot
.48449 .85155 Mdot
.39051 .74047 Mdot
.37868 .27445 Mdot
.73532 .2395 Mdot
.52688 .72686 Mdot
.54203 .71695 Mdot
.43847 .01427 Mdot
.57232 .70076 Mdot
.57312 .54016 Mdot
.43306 .88589 Mdot
.43341 .49386 Mdot
.40777 .74094 Mdot
.38126 .3142 Mdot
.40311 .18555 Mdot
.39651 .1702 Mdot
.42646 .09591 Mdot
.3773 .35739 Mdot
.57935 .6558 Mdot
.3742 .56379 Mdot
.38909 .17474 Mdot
.41432 .16224 Mdot
.40736 .7164 Mdot
.38961 .60407 Mdot
.38446 .23299 Mdot
.3809 .60075 Mdot
.56552 .59888 Mdot
.37281 .5648 Mdot
.40876 .17264 Mdot
.54499 .46842 Mdot
.553 .64097 Mdot
.55209 .68647 Mdot
.54657 .68419 Mdot
.47686 .01727 Mdot
.62254 .12166 Mdot
.40368 .71435 Mdot
.48907 .30406 Mdot
.37564 .43292 Mdot
.37594 .62403 Mdot
.42539 .05525 Mdot
.55904 .45391 Mdot
.48673 .00344 Mdot
.50987 .33847 Mdot
.50629 .05022 Mdot
.62827 .13388 Mdot
.38718 .22825 Mdot
.39643 .14141 Mdot
.4742 .87834 Mdot
.50897 .01341 Mdot
.39508 .7706 Mdot
.51906 .3475 Mdot
.57836 .08975 Mdot
.38161 .24451 Mdot
.44829 .00971 Mdot
.47669 .0087 Mdot
.56703 .65228 Mdot
.63041 .12188 Mdot
.55545 .75764 Mdot
.48585 .30482 Mdot
.48608 .30433 Mdot
.43433 .45119 Mdot
.55326 .68049 Mdot
.64151 .13507 Mdot
.39011 .61973 Mdot
.52468 .3817 Mdot
.44951 .86792 Mdot
.53112 .35102 Mdot
.48177 .27521 Mdot
.56884 .53583 Mdot
.4473 .90443 Mdot
.52228 .76611 Mdot
.38002 .58199 Mdot
.55864 .51373 Mdot
.38788 .57091 Mdot
.51274 .7809 Mdot
.39942 .12747 Mdot
.48003 .27755 Mdot
.42448 .81983 Mdot
.38885 .18841 Mdot
.55761 .6906 Mdot
.44325 .05745 Mdot
.38564 .6651 Mdot
.41659 .15897 Mdot
.55043 .57604 Mdot
.56869 .62797 Mdot
.47926 .91145 Mdot
.53953 .41572 Mdot
.55898 .09259 Mdot
.55314 .44511 Mdot
.44026 .55416 Mdot
.67259 .18412 Mdot
.52131 .79295 Mdot
.5612 .59775 Mdot
.52885 .03393 Mdot
.55452 .63877 Mdot
.46477 .90334 Mdot
.38149 .5256 Mdot
.40045 .72126 Mdot
.56622 .07225 Mdot
.49547 .87191 Mdot
.3848 .66745 Mdot
.56614 .72881 Mdot
.39642 .17645 Mdot
.53315 .39179 Mdot
.42028 .11712 Mdot
.45354 .83326 Mdot
.568 .72442 Mdot
.41305 .1479 Mdot
.44885 .32532 Mdot
.53267 .40742 Mdot
.44158 .07055 Mdot
.55663 .70601 Mdot
.54955 .65062 Mdot
.54353 .79752 Mdot
.45128 .60328 Mdot
.41428 .09338 Mdot
.38787 .23617 Mdot
.55319 .73294 Mdot
.56184 .59452 Mdot
.41169 .17475 Mdot
.48909 .29804 Mdot
.55188 .74284 Mdot
.40623 .74702 Mdot
.5481 .63143 Mdot
.4069 .7233 Mdot
.41332 .15898 Mdot
.52978 .764 Mdot
.37977 .38475 Mdot
.51509 .83906 Mdot
.56479 .47418 Mdot
.51388 .7997 Mdot
.37553 .38659 Mdot
.55686 .42654 Mdot
.58235 .5514 Mdot
.41167 .12264 Mdot
.57063 .49125 Mdot
.42995 .82929 Mdot
.37421 .47542 Mdot
.45411 .30114 Mdot
.55497 .56756 Mdot
.43976 .07009 Mdot
.46613 .01219 Mdot
.57966 .551 Mdot
.43474 .47655 Mdot
.51477 .75813 Mdot
.39392 .75553 Mdot
.5538 .69208 Mdot
.40604 .20504 Mdot
.63656 .14641 Mdot
.41873 .1096 Mdot
.53846 .06935 Mdot
.45928 .04299 Mdot
.4402 .57254 Mdot
.37676 .34222 Mdot
.60385 .12703 Mdot
.40264 .80108 Mdot
.5579 .09242 Mdot
.74017 .2425 Mdot
.53739 .75794 Mdot
.54048 .80634 Mdot
.40559 .75575 Mdot
.40915 .12515 Mdot
.52214 .04061 Mdot
.56192 .56964 Mdot
.4296 .07567 Mdot
.56023 .69944 Mdot
.47899 .30338 Mdot
.42024 .84235 Mdot
.48471 .8526 Mdot
.40817 .80014 Mdot
.44374 .00857 Mdot
.46347 .29577 Mdot
.41543 .78813 Mdot
.44133 .82828 Mdot
.53395 .0708 Mdot
.46732 .28854 Mdot
.44034 .02812 Mdot
.58461 .10747 Mdot
.58975 .0912 Mdot
.55389 .50122 Mdot
.52568 .83645 Mdot
.50524 .84329 Mdot
.43447 .08979 Mdot
.58067 .57756 Mdot
.45006 .33037 Mdot
.43649 .4943 Mdot
.53367 .78886 Mdot
.38229 .23082 Mdot
.46779 .04844 Mdot
.51348 .31782 Mdot
.42157 .84421 Mdot
.49495 .3036 Mdot
.43569 .43292 Mdot
.4726 .91184 Mdot
.48264 .88279 Mdot
.40858 .72419 Mdot
.57631 .66448 Mdot
.54865 .69055 Mdot
.66482 .15858 Mdot
.5347 .75245 Mdot
.38478 .52004 Mdot
.52547 .36418 Mdot
.45588 .02633 Mdot
.54069 .66738 Mdot
.37525 .48661 Mdot
.38449 .45504 Mdot
.51469 .31264 Mdot
.50415 .79184 Mdot
.61982 .13702 Mdot
.42176 .0684 Mdot
.37042 .47723 Mdot
.39555 .24229 Mdot
.55697 .71722 Mdot
.52638 .8055 Mdot
.39699 .22901 Mdot
.53995 .76303 Mdot
.42784 .05497 Mdot
.55352 .0454 Mdot
.38475 .66851 Mdot
.48321 .00907 Mdot
.44564 .02071 Mdot
.43647 .02867 Mdot
.43789 .40589 Mdot
.52411 .78641 Mdot
.5539 .0853 Mdot
.39894 .14687 Mdot
.43778 .40472 Mdot
.39287 .28438 Mdot
.49478 .81812 Mdot
.47697 .88703 Mdot
.41033 .77411 Mdot
.46737 .03203 Mdot
.45842 .89853 Mdot
.39799 .19113 Mdot
.46782 .05115 Mdot
.39173 .32636 Mdot
.37112 .55354 Mdot
.38266 .49585 Mdot
.55084 .07637 Mdot
.7221 .22088 Mdot
.48148 .04436 Mdot
.43069 .83373 Mdot
.44126 .39761 Mdot
.55917 .07777 Mdot
.55634 .74025 Mdot
.43663 .49874 Mdot
.40954 .09639 Mdot
.39384 .72727 Mdot
.44111 .36405 Mdot
.56134 .53164 Mdot
.56864 .6708 Mdot
.55904 .61028 Mdot
.38314 .26283 Mdot
.41603 .84731 Mdot
.59342 .11056 Mdot
.42569 .05405 Mdot
.47167 .8576 Mdot
.68399 .19385 Mdot
.49771 .8463 Mdot
.55304 .66609 Mdot
.56784 .62334 Mdot
.45212 .62337 Mdot
.39321 .16986 Mdot
.44536 .02654 Mdot
.54518 .65554 Mdot
.53362 .37865 Mdot
.57297 .46612 Mdot
.55038 .39812 Mdot
.58181 .6006 Mdot
.39537 .25086 Mdot
.54368 .42101 Mdot
.57095 .55994 Mdot
.48361 .28979 Mdot
.57678 .61569 Mdot
.42805 .78849 Mdot
.57139 .54293 Mdot
.52532 .38228 Mdot
.46048 .019 Mdot
.48512 .61586 Mdot
.49151 .86345 Mdot
.53874 .78199 Mdot
.3907 .58036 Mdot
.49114 .82339 Mdot
.56188 .61069 Mdot
.53582 .04892 Mdot
.60227 .0896 Mdot
.43489 .86344 Mdot
.71479 .22103 Mdot
.49909 .89109 Mdot
.51519 .33997 Mdot
.52263 .06733 Mdot
.56251 .09565 Mdot
.5558 .61217 Mdot
.38974 .36039 Mdot
.6724 .16985 Mdot
.53766 .39606 Mdot
.44238 .36186 Mdot
.53695 .70935 Mdot
.39792 .23962 Mdot
.49135 .82743 Mdot
.64128 .14057 Mdot
.50317 .31551 Mdot
.43118 .81129 Mdot
.49885 .85019 Mdot
.50592 .29928 Mdot
.48166 .29357 Mdot
.56044 .45284 Mdot
.37822 .26587 Mdot
.45062 .31614 Mdot
.37383 .53462 Mdot
.44306 .88361 Mdot
.44499 .87214 Mdot
.37633 .46113 Mdot
.40951 .19242 Mdot
.48719 .85297 Mdot
.57447 .06182 Mdot
.56216 .52648 Mdot
.38137 .23642 Mdot
.44749 .01143 Mdot
.5406 .6559 Mdot
.37267 .40408 Mdot
.50977 .79757 Mdot
.44387 .82083 Mdot
.37529 .52215 Mdot
.41758 .80658 Mdot
.57135 .59225 Mdot
.50969 .78287 Mdot
.44502 .83308 Mdot
.4214 .78951 Mdot
.46542 .64132 Mdot
.42711 .80487 Mdot
.48571 .83394 Mdot
.4325 .4743 Mdot
.55074 .55216 Mdot
.44619 .84769 Mdot
.48555 .87671 Mdot
.46372 .29998 Mdot
.54584 .72714 Mdot
.42644 .07412 Mdot
.58103 .58617 Mdot
.40426 .73296 Mdot
.57849 .5101 Mdot
.53421 .70376 Mdot
.4397 .38614 Mdot
.70997 .20475 Mdot
.44666 .35231 Mdot
.45312 .89963 Mdot
.4885 .04134 Mdot
.40461 .20052 Mdot
.56781 .59354 Mdot
.37478 .48919 Mdot
.43118 .04511 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool00_l00003ooooo`03
o`000?oooooooooo0;Wooooo002Sooooo`;o00000_ooool2o`0000?ooooo00?o0000ooooooooool0
^Oooool009Wooooo0ol00007ooooo`Go00001?ooool00ol0003oooooooooo`2iooooo`00VOooool3
o`0000Cooooo0_l00002ooooo`Go00000oooool00ol0003oooooooooo`02o`000;Oooooo002Goooo
o`;o000000?oooooo`000?l000001?ooool3o`000004ofIVI_l0003oooooooooo`;o00000oooool0
0ol0003oooooooooo`02o`000;Oooooo002Gooooo`;o00001_ooool4o`000003ooooool0003o0000
00Kooooo00?o0000ooooooooool00_ooool2o`000;Gooooo002Jooooo`;o00000oooool2o`0000?o
oooo0_l00006ooooo`03o`000?oooooooooo00;ooooo0_l0002eooooo`00V_ooool2o`0000?ooooo
0_l0000;ooooo`?o0000^Oooool009Oooooo1Ol000000ooooooo0000o`000002o`0000?ooooo0_l0
0006ooooo`03o`000?oooooooooo0;Wooooo002Gooooo`Go000000?oooooo`000?l000001Oooool2
o`0000Kooooo00?o0000ooooooooool0^Oooool009Wooooo0_l00006ooooo`;o00002Oooool00ol0
003oooooooooo`06ooooo`;o0000/Oooool009kooooo0_l000000ooooooo0000o`000009ooooo`03
o`000?oooooooooo00Kooooo0_l0002aooooo`00W_ooool2o`0000cooooo00?o0000ooooooooool0
1?ooool2o`000;?ooooo002Nooooo`;o00002?ooool2o`0000;ooooo00?o0000ooooooooool01?oo
ool2o`000;?ooooo002Eooooo`;o00001oooool2o`000003ooooool0003o000000;ooooo0_l00000
0ooooooo0000o`000002ooooo`03o`000?oooooooooo00kooooo0_l0002Yooooo`00UOooool2o`00
00[ooooo0_l00002ooooo`;o00001Oooool00ol0003oooooooooo`08ooooo`;o00001?ooool2o`00
0:Wooooo002Qooooo`;o00002Oooool4o`0000Oooooo0_l0002_ooooo`00Toooool3o`0000;ooooo
0_l00007ooooo`;o00002Oooool01?l0003oooooo`000?l0000=ooooo`;o0000ZOooool009?ooooo
0ol00002ooooo`?o00004Oooool00ol0003oooooooooo`0>ooooo`;o0000ZOooool009Wooooo0_l0
000Aooooo`03o`000?oooooooooo01Gooooo0_l0002Rooooo`00[?ooool00ol0003oooooooooo`0E
ooooo`;o0000X_ooool009?ooooo0_l0000Gooooo`03o`000?oooooooooo00Cooooo0_l0002coooo
o`00T_ooool3o`0000?ooooo0_l0000Booooo`03o`000?oooooooooo00Cooooo0_l000000ooooooo
0000o`000002o`000:kooooo002Booooo`Co00000_ooool2o`0001;ooooo00?o0000ooooooooool0
1oooool6o`0000Gooooo0_l0002Uooooo`00Toooool3o`0001Kooooo0ol0000;ooooo`Co00000ooo
ool2o`000:Gooooo002Cooooo`?o00005_ooool00ol0003oooooooooo`0=ooooo`;o000000?ooooo
o`000?l00000Yoooool009?ooooo0_l0000Gooooo`03o`000?oooooooooo013ooooo0_l0002Woooo
o`00[?ooool00ol0003oooooooooo`0>ooooo`;o000000?oooooo`000?l00000Y_ooool00:cooooo
00?o0000ooooooooool03_ooool2o`000003ooooool0003o00000:Kooooo002Fooooo`;o00005?oo
ool00ol0003oooooooooo`0@ooooo`;o00001?ooool2o`0000;ooooo0_l00002ooooo`;o0000VOoo
ool008oooooo0_l00005ooooo`;o00005?ooool00ol0003oooooooooo`0@ooooo`;o00001?ooool2
o`0000;ooooo0_l00002ooooo`;o0000VOooool008kooooo0ol00002ooooo`Co00005Oooool00ol0
003oooooooooo`0@ooooo`?o0000Y_ooool008kooooo0_l00003ooooo`Co00005Oooool3o`00017o
oooo0_l0002Vooooo`00UOooool2o`0001Gooooo00?o0000ooooooooool0^Oooool00:cooooo00?o
0000ooooooooool06?ooool2o`0009oooooo002Aooooo`;o00006Oooool00ol0003oooooooooo`0F
ooooo`Co000000?oooooo`000?l000001Oooool2o`0009Gooooo002Aooooo`;o00006Oooool00ol0
003oooooooooo`0Fooooo`;o00000oooool2o`0000Gooooo0_l0002Eooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00ROooool00oo^k^ko<S8bo`000002o`0000?ooooo0_l00002ob4Q8@Kooooo
00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooooooo
ool09Oooool2o`0009;ooooo0029ooooo`03ogMgMonHV9Sooooo00Co000000?oooooo`000?l00000
0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`0Uooooo`;o000000?oooooo`000?l00000Soooool0087ooooo1_l00002ooooo`05oa0@4?oo
ooooooooooooool@41000_l0000;ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool0
0oooool3o`0002Gooooo0_l000000ooooooo0000o`00002?ooooo`00ROooool3o`000004ooooool0
003o0000o`0000cooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo01oooooo0_l0002Hooooo`00ROooool3o`000003ooooool0003ooooo00gooooo00?o
EEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
7oooool2o`0009Sooooo0029ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMg
ooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09oooool2o`00093ooooo
0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`;o000000?oooooo`000?l0
00000_ooool2o`0008cooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Co
oooo1?l00006ooooo`03o`000?oooooooooo02Cooooo0_l00005ooooo`;o0000S?ooool008Wooooo
0_l0000Qooooo`03o`000?oooooooooo02_ooooo0_l0002<ooooo`00ROooool3o`00023ooooo00?o
0000ooooooooool0:_ooool2o`0008gooooo002:ooooo`;o00000oooool2o`0001_ooooo00?o0000
ooooooooool09oooool2o`000003ooooool0003o000008gooooo002?ooooo`;o00006oooool3o`00
02Oooooo0_l0002@ooooo`00SOooool2o`0001gooooo00?o0000ooooooooool0^Oooool008_ooooo
1ol0000Jooooo`03o`000?oooooooooo03?ooooo0_l00024ooooo`00Roooool2o`0000;ooooo0ol0
000Jooooo`03o`000?oooooooooo03?ooooo0_l00024ooooo`00Soooool2o`0001_ooooo00?o0000
ooooooooool0;oooool2o`0008Sooooo002/ooooo`03o`000?oooooooooo02oooooo0_l00028oooo
o`00R?ooool3o`00027ooooo00?o0000ooooooooool0=Oooool2o`0008;ooooo0028ooooo`?o0000
0_ooool2o`0001gooooo00?o0000ooooooooool0=Oooool2o`0008;ooooo0027ooooo`Co00000_oo
ool3o`0001cooooo0ol0002iooooo`00Qoooool4o`0000?ooooo0_l0000Looooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002<ooooo`;o00007_ooool00ol0003o
ooooooooo`0fooooo`;o0000POooool008Oooooo0_l00003ooooo`;o00007_ooool00ol0003ooooo
ooooo`0fooooo`;o00000_ooool2o`0007gooooo0027ooooo`;o000000Goooooo`000?l0003o0000
ooooo`02o`0001cooooo00?o0000ooooooooool0>_ooool2o`0007gooooo0027ooooo`;o000000Go
ooooo`000?l0003o0000ooooo`02o`0001cooooo00?o0000ooooooooool0>Oooool4o`0007cooooo
002/ooooo`03o`000?oooooooooo03Wooooo1?l0001looooo`00S?ooool2o`0001kooooo0ol0002i
ooooo`00S?ooool2o`0001kooooo00?o0000ooooooooool0^Oooool008Sooooo0_l00002ooooo`?o
00007Oooool00ol0003oooooooooo`12ooooo`;o0000MOooool008Sooooo0_l00003ooooo`;o0000
7Oooool00ol0003oooooooooo`12ooooo`;o0000MOooool00:cooooo00?o0000ooooooooool0^Ooo
ool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool0@oooool2o`000003ooooool0003o0000077ooooo002/ooooo`?o0000
@oooool2o`000003ooooool0003o0000077ooooo0026ooooo`;o00009?ooool00ol0003ooooooooo
o`2iooooo`00QOooool4o`000004ooooool0003o0000o`0001oooooo00?o0000ooooooooool0Aooo
ool2o`00073ooooo0025ooooo`Co000000Coooooo`000?l0003o00007oooool00ol0003ooooooooo
o`17ooooo`;o0000L?ooool008Cooooo1Ol0000Sooooo`03o`000?oooooooooo0;Wooooo0024oooo
o`;o000000Coooooo`000?l0003ooooo0_l0000Pooooo`03o`000?oooooooooo04[ooooo0_l0001]
ooooo`00ROooool3o`0000Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0B_ooool4o`0006_ooooo0024
ooooo`;o00000oooool2o`0000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo04cooooo0_l0001[ooooo`00Q?ooool2
o`0000?ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`;o00001_ooool01Ol0003ooooooooooooo
oooo000000oooooo00?oMgMgoc8b<_ooool01?ooool3o`000;Wooooo0029ooooo`;o00001_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;Wooooo002Aooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;Wooooo0024ooooo`;o00002oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2iooooo`00Q?oo
ool3o`0000[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003ooooo
ooooo`2iooooo`00Poooool4o`0002Gooooo00?o0000ooooooooool0^Oooool008?ooooo0_l00004
ooooo`;o00008Oooool00ol0003oooooooooo`2iooooo`00ROooool2o`00027ooooo00?o0000oooo
ooooool0^Oooool008Cooooo0_l0000Pooooo`;o00001?ooool3o`000;Wooooo0024ooooo`;o0000
0oooool2o`0001[ooooo0ol00004ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`;o00006_oo
ool2o`0000Gooooo00?o0000ooooooooool0^Oooool008Sooooo0_l0000Rooooo`03o`000?oooooo
oooo0;Wooooo0028ooooo`;o00005oooool2o`0000Wooooo00?o0000ooooooooool0^Oooool00:7o
oooo0_l00003ooooo`;o00001?ooool00ol0003oooooooooo`2iooooo`00Y_ooool2o`0000Cooooo
00?o0000ooooooooool0^Oooool008;ooooo0_l0000Looooo`;o00001?ooool4o`0000;ooooo00?o
0000ooooooooool0^Oooool008;ooooo0ol0000Gooooo`;o00000_ooool2o`0000Kooooo0_l00002
ooooo`Co0000^?ooool008?ooooo0_l0000Gooooo`;o00000_ooool2o`0000?ooooo2?l000000ooo
oooo0000o`00002hooooo`00YOooool8o`000;_ooooo0026ooooo`;o00007oooool2o`0000?ooooo
00?o0000ooooooooool0^Oooool008Kooooo0_l0000Tooooo`04o`000?ooooooooooooooo`;o0000
]_ooool008Cooooo0_l0000Eooooo`;o00003oooool3o`000003ooooool0003o00000;Kooooo0024
ooooo`;o00005Oooool2o`0000oooooo0ol000000ooooooo0000o`00002fooooo`00[?ooool01?l0
003oooooooooooooool2o`000;Kooooo002Kooooo`;o00003oooool3o`000003ooooool0003o0000
0;Kooooo0028ooooo`;o00004Oooool2o`0000oooooo00?o0000ooooooooool0^Oooool008Sooooo
0_l0000Aooooo`;o00003oooool3o`000;Wooooo002Jooooo`?o00003oooool3o`000;Wooooo002J
ooooo`;o00004?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`04o`00
0;Gooooo0023ooooo`;o00009oooool00ol0003oooooooooo`04o`000;Gooooo0023ooooo`;o0000
0_ooool2o`0002?ooooo00?o0000ooooooooool01?ooool2o`000;?ooooo0027ooooo`;o00008ooo
ool00ol0003oooooooooo`03ooooo`?o0000/oooool009[ooooo0_l0000@ooooo`?o00000oooool2
o`0000;ooooo0_l0002`ooooo`00V_ooool2o`00013ooooo00?o0000ooooooooool01oooool2o`00
0;3ooooo0023ooooo`;o00009oooool00ol0003oooooooooo`06ooooo`;o0000/Oooool008?ooooo
0_l00002ooooo`;o00004?ooool2o`00017ooooo00?o0000ooooooooool01_ooool2o`000;7ooooo
0027ooooo`;o00003oooool3o`00017ooooo00?o0000ooooooooool01Oooool2o`000;;ooooo0029
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@?ooooo1_l00004ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`05ooooo`;o0000/_ooool008Wooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oo
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2iooooo`00POooool6o`0000;ooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0;ooooo`;o0000[?ooool008Wooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0000_o
oooo0_l0002/ooooo`00ROooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_oo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool02?ooool2o`00
0:oooooo0023ooooo`;o00001?ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo0_l000000ooo
oooo0000o`00002_ooooo`00Poooool3o`0000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0:oooo
o`;o000000Co^[ZjoooooonHV9So410@1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Gooooo0_l0002booooo`00P_ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0:
ooooo`;o000000Co410@o`000?lQ8B7oc<c<1?ooool4o`0000Kooooo00?o0000ooooooooool0^Ooo
ool008;ooooo0_l0000Xooooo`03o`000?oooooooooo00Sooooo0_l0002_ooooo`00[?ooool00ol0
003oooooooooo`08ooooo`;o0000[oooool009Sooooo0_l0000Booooo`03o`000?oooooooooo00Wo
oooo0_l00002ooooo`;o0000Z_ooool009Sooooo0_l0000Booooo`?o00002Oooool2o`0000;ooooo
0_l0002Zooooo`00P_ooool2o`0002Sooooo00?o0000ooooooooool0^Oooool008;ooooo0_l0000C
ooooo`;o00004oooool00ol0003oooooooooo`07ooooo`;o0000/?ooool009Oooooo0_l0000Coooo
o`03o`000?oooooooooo00Oooooo0_l0002`ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
[?ooool00ol0003oooooooooo`0:ooooo`;o0000[Oooool00:cooooo00?o0000ooooooooool02_oo
ool2o`000:gooooo002/ooooo`03o`000?oooooooooo00_ooooo0ol0002[ooooo`00[?ooool3o`00
00_ooooo0ol0002[ooooo`00[?ooool00ol0003oooooooooo`0?ooooo`;o0000Z?ooool009Sooooo
0_l0000Booooo`03o`000?oooooooooo00oooooo0_l0002Xooooo`00Poooool2o`00017ooooo1?l0
000Booooo`03o`000?oooooooooo0;Wooooo0023ooooo`;o00004Oooool2o`0001Cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool03_ooool2o`000:Wooooo0022ooooo`;o0000:?oo
ool00ol0003oooooooooo`0>ooooo`;o0000ZOooool008;ooooo0_l0000Booooo`;o00005?ooool3
o`00017ooooo0_l0002Vooooo`00QOooool2o`0000oooooo0_l0000Dooooo`03o`000?oooooooooo
013ooooo0ol0002Vooooo`00QOooool2o`0002Gooooo00?o0000ooooooooool04?ooool2o`000:Oo
oooo0009ooooo`Co000000?o410@ooooooooool05_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0?oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00olQ8B7o0000o`000003ooooo`Go0000
1?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Kooooo00?o0000ooooooooool06?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;o
gMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`00
0?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003o
k^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd06?ooool4o`000003oa0@4?oooooooooo
01;ooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool00olQ8B7o0000o`000003ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1oooool00omgMgOo<S8booooo`0Eooooo`03o`000?oooooooooo01?ooooo0_l00003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007oooo
o`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool0
0omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?o
EEEEojVYZOooool01oooool00omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo0006
o`0000Gooooo00?o0000ooooooooool04?ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool01Oooool6o`0000;ooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`?o00005?ooool00ol0003o
ooooooooo`0Cooooo`Co000000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03
oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool03Oooool01Ol@413ooooooooooooooooo410@
013ooooo00?o0000ooooooooool03Oooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVY
oeEEEOooool02?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Cooooo000;oooo
o`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooo
oooo00Kooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000oooooo00?o
MgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool01?mgMgOo<S8bo`000?l0000Dooooo`03o`000?oooooooooo00_ooooo0_l00002ooooo`;o
000000?oooooo`000?l000000ol000000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_o
oooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`0>ooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003_ooool0
0olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Wooooo00?o0000ooooooooool05?ooool0
00_ooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEE
olc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000oooooooooooooooo
o`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo0000
00kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Kooooo00?o0000
ooooooooool02oooool2o`0000;ooooo0_l000001?oooooo0000o`000?l00003ooooo`05o`000?oo
ooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`03oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?
ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`06_ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003ooooooooo
o`0Hooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo017o
oooo00Go410@oooooooooooooooooa0@4004ooooo`?o00002?ooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooooooo`?o00005?ooool3o`0001;ooooo0_l00004ooooo`05oa0@4?oooooo
ooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo00Go
410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooo
oooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool04Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Cooooo0ol00004ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool01?l0003ooooo
ooooooooool3o`0001Cooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo017ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo01Cooooo0009ooooo`03oeEEEOmVIVKo000001[ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`Go00001?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c004ooooo`Co00005oooool00ol0003oooooooooo`0=ooooo`;o00002Oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00004?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5
o`0000Cooooo1?l0000Iooooo`03oeEEEOmVIVKo000001Kooooo0026ooooo`;o00009?ooool00ol0
003oooooooooo`0=ooooo`;o0000Z_ooool008;ooooo0_l00002ooooo`;o00009?ooool00ol0003o
ooooooooo`2iooooo`00P_ooool2o`0002Sooooo00?o0000ooooooooool05?ooool2o`0009Sooooo
0_l00002ooooo`;o00001Oooool0087ooooo0_l0000Cooooo`?o00004oooool00ol0003ooooooooo
o`0Dooooo`;o0000V?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Gooooo0021ooooo`Ko0000
3oooool3o`0001?ooooo00?o0000ooooooooool0[oooool01?oMgMgo0000oa0@4?o<c<`6ooooo`00
1oooooooo`0004co00003?ooool01?o^k^ko8B4Qoa0@4?o^k^h6ooooo`001oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_l00003ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0:ooooo`04ob4Q8OmgMgOoMgMgoc8b<PKooooo0007ooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`09ooooo`;o0000
0_ooool2o`0000Gooooo002/ooooo`03o`000?oooooooooo01Kooooo0_l0002Qooooo`00[?ooool0
0ol0003oooooooooo`0=ooooo`;o00001oooool2o`000:7ooooo002/ooooo`03o`000?oooooooooo
00gooooo0_l000000ooooooo0000o`00002Wooooo`00[?ooool00ol0003oooooooooo`0>ooooo`Ko
0000YOooool008;ooooo0_l00002ooooo`;o00009?ooool00ol0003oooooooooo`0>ooooo`;o0000
00Coooooo`000?l0003o0000YOooool008;ooooo1_l0000Tooooo`?o0000^Oooool008;ooooo1?l0
000Vooooo`03o`000?oooooooooo017ooooo0_l0002Vooooo`00[?ooool00ol0003oooooooooo`0A
ooooo`;o0000Y_ooool008;ooooo0_l0000Xooooo`03o`000?oooooooooo017ooooo0_l0002Voooo
o`00P_ooool2o`0002Sooooo00?o0000ooooooooool04oooool2o`000:Cooooo002/ooooo`03o`00
0?oooooooooo01?ooooo1?l0002Rooooo`00[?ooool00ol0003oooooooooo`0Dooooo`?o0000X_oo
ool00:cooooo00?o0000ooooooooool03_ooool2o`0000Cooooo0_l0002Sooooo`00Q?ooool2o`00
02Kooooo00?o0000ooooooooool03_ooool2o`000003ooooool0003o00000:Kooooo0024ooooo`;o
00009_ooool3o`0000gooooo0_l00002ooooo`;o00001?ooool3o`0009oooooo0021ooooo`;o0000
5Oooool2o`0001;ooooo00?o0000ooooooooool03Oooool2o`0000Sooooo0ol0002Oooooo`00POoo
ool2o`0000;ooooo0_l0000Aooooo`;o00004_ooool00ol0003oooooooooo`2iooooo`00QOooool2
o`0002Gooooo00?o0000ooooooooool05?ooool4o`000:7ooooo0022ooooo`;o0000:?ooool00ol0
003oooooooooo`0=ooooo`;o00001Oooool4o`000:7ooooo0022ooooo`;o0000:?ooool00ol0003o
ooooooooo`0=ooooo`Co00001?ooool2o`000:;ooooo0027ooooo`;o00008oooool00ol0003ooooo
ooooo`0?ooooo`Co00000_ooool2o`000:;ooooo0027ooooo`;o00003oooool2o`0001;ooooo00?o
0000ooooooooool04Oooool3o`000:Gooooo002Hooooo`;o00004_ooool3o`0000gooooo0_l00003
ooooo`;o0000YOooool00:cooooo00?o0000ooooooooool03Oooool2o`0000Sooooo0_l0002Poooo
o`00Q?ooool2o`000003ooooool0003o000002?ooooo00?o0000ooooooooool03oooool2o`0000Ko
oooo0_l0002Pooooo`00Q?ooool2o`000003ooooool0003o000002?ooooo00?o0000ooooooooool0
3oooool2o`0000Kooooo0_l0002Pooooo`00[?ooool00ol0003oooooooooo`0Gooooo`;o0000X?oo
ool00:cooooo00?o0000ooooooooool03oooool3o`000004ooooool0003o0000o`000:?ooooo002/
ooooo`03o`000?oooooooooo00oooooo1ol0002Sooooo`00[?ooool00ol0003oooooooooo`0Aoooo
o`Co0000Y?ooool008Cooooo0_l0000Vooooo`?o00004Oooool3o`0000Cooooo0_l0002Oooooo`00
Q?ooool2o`000003ooooool0003o000001;ooooo0_l0000?ooooo`03o`000?oooooooooo01;ooooo
0_l00004ooooo`;o0000Woooool008Oooooo0_l0000Booooo`?o00003_ooool00ol0003ooooooooo
o`2iooooo`00W?ooool2o`0000kooooo00?o0000ooooooooool04?ooool2o`000:Oooooo002/oooo
o`03o`000?oooooooooo00oooooo1?l0002Vooooo`00Yoooool2o`0000?ooooo00?o0000oooooooo
ool03oooool4o`0000;ooooo0ol0002Qooooo`00Q?ooool2o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@02o`00
00?ooooo00?o0000ooooooooool05Oooool4o`000:3ooooo0024ooooo`;o000000Soooooo`000?l0
003oMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01Gooooo1?l0002Pooooo`00Pooo
ool6o`000005oa0@4?ooooooooooooooool@41003?ooool01?nHV9So8B4Qo`000?l00008ooooo`03
o`000?oooooooooo00?ooooo0ol0000Cooooo`;o0000Y?ooool008?ooooo1?l00002ooooo`05o`00
0?ooooooooooooooool000003Oooool00onHV9So0000o`000007ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool04oooool2o`000:Cooooo0029ooooo`05o`000?ooooooooooooooool0
00003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0
003oooooooooo`0<ooooo`;o00001Oooool2o`000:Cooooo0024ooooo`;o00000oooool01Ol@413o
oooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00cooooo0_l00002ooooo`;o00001_ooool2o`0009oooooo0024ooooo`?o
00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004
ooooo`04o`000?oooooo0000o`0000Kooooo00?o0000ooooooooool04?ooool2o`0000;ooooo0_l0
0002ooooo`;o0000Woooool008Gooooo0_l00002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo00oooooo
0_l00003ooooo`;o0000Xoooool00:3ooooo0_l0000:ooooo`03o`000?oooooooooo00kooooo0ol0
002Xooooo`00Q?ooool2o`000003ooooool0003o000001Oooooo0_l0000:ooooo`03o`000?oooooo
oooo00kooooo0_l0002Yooooo`00Q?ooool2o`000003ooooool0003o000002?ooooo00?o0000oooo
ooooool0^Oooool00:cooooo0ol0000=ooooo`;o00001?ooool2o`000:Cooooo002/ooooo`03o`00
0?oooooooooo00[ooooo1Ol00004ooooo`;o00000_ooool2o`000:3ooooo002/ooooo`03o`000?oo
oooooooo00[ooooo1Ol00008ooooo`;o0000X?ooool00:cooooo00?o0000ooooooooool02oooool4
o`0000Cooooo0_l0002Tooooo`00Q_ooool2o`0002Cooooo00?o0000ooooooooool02oooool2o`00
00Kooooo0_l000000ooooooo0000o`00002Qooooo`00Q_ooool3o`0002?ooooo00?o0000oooooooo
ool02_ooool2o`0000;ooooo0_l00006ooooo`;o0000XOooool008Kooooo0ol0000Sooooo`03o`00
0?oooooooooo00[ooooo0_l00002ooooo`;o00000oooool2o`000:Cooooo0026ooooo`;o00009?oo
ool00ol0003oooooooooo`0Cooooo`;o0000Y?ooool00:cooooo0ol0002iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0>ooooo`;o0000ZOooool008Wooooo
0_l0000Qooooo`03o`000?oooooooooo00cooooo1?l0002Yooooo`00ROooool2o`00027ooooo00?o
0000ooooooooool03?ooool4o`000:Wooooo0027ooooo`;o00008oooool00ol0003oooooooooo`0=
ooooo`Go00000_ooool2o`000:?ooooo0027ooooo`;o00008oooool00ol0003oooooooooo`0=oooo
o`Go00000_ooool2o`000:?ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000
4?ooool2o`0000;ooooo0_l0002Sooooo`00[?ooool00ol0003oooooooooo`08ooooo`;o00001_oo
ool2o`0000;ooooo0_l0002Sooooo`00[?ooool00ol0003oooooooooo`08ooooo`;o00001?ooool3
o`000:Sooooo002/ooooo`03o`000?oooooooooo00Wooooo0_l00003ooooo`?o0000Z?ooool00:co
oooo00?o0000ooooooooool02Oooool2o`000:kooooo0026ooooo`;o00001?ooool3o`0001gooooo
00?o0000ooooooooool05?ooool2o`000:?ooooo0026ooooo`;o00001?ooool3o`0001gooooo00?o
0000ooooooooool02_ooool2o`0000?ooooo0_l00003ooooo`;o0000Xoooool008[ooooo0ol0000O
ooooo`03o`000?oooooooooo00[ooooo0_l00003ooooo`;o0000Z?ooool008[ooooo1Ol0000Moooo
o`?o00004Oooool4o`000:Cooooo0029ooooo`;o00000_ooool2o`0001gooooo00?o0000oooooooo
ool01Oooool2o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`Co0000Y?ooool008Wooooo
0_l0000Qooooo`03o`000?oooooooooo00Gooooo0_l00002ooooo`;o000000?oooooo`000?l00000
1?ooool3o`000:Cooooo002<ooooo`;o00007_ooool00ol0003oooooooooo`0>ooooo`;o00000_oo
ool2o`000:Gooooo0029ooooo`;o000000?oooooo`000?l000007_ooool00ol0003oooooooooo`0>
ooooo`;o0000ZOooool008Oooooo1?l0000Qooooo`03o`000?oooooooooo00oooooo0_l0002Xoooo
o`00Qoooool2o`0000Cooooo0_l00002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00kooooo0ol0002X
ooooo`00SOooool2o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00kooooo0_l0002Yooooo`00SOooool2o`00
00;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0^Oooool008gooooo0_l00002ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`04ooooo`?o00002?ooool2o`000:oooooo0029ooooo`;o000000?oooooo`00
0?l000000oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo00Sooooo0_l0002_ooooo`00ROooool2o`000003ooooool0003o
000000?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00Co
0000oooooooooooooooo0_l00006ooooo`;o00001?ooool2o`000:Sooooo002Aooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooooooo`;o
00001_ooool2o`0000Cooooo0_l0002Xooooo`00SOooool2o`0000;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`06ooooo`;o00000_ooool2o`000:go
oooo002=ooooo`;o00007Oooool00ol0003oooooooooo`04ooooo`Co00000_ooool2o`000:gooooo
0029ooooo`;o00008Oooool00ol0003oooooooooo`04ooooo`;o0000/oooool008Wooooo0_l00003
ooooo`;o00007?ooool00ol0003oooooooooo`0:ooooo`;o0000[Oooool008kooooo0_l0000Loooo
o`?o00002_ooool2o`000:gooooo002/ooooo`03o`000?oooooooooo00[ooooo0_l0002]ooooo`00
[?ooool00ol0003oooooooooo`03o`0000Kooooo0ol0002]ooooo`00ROooool2o`00027ooooo00?o
0000ooooooooool00ol00006ooooo`;o0000[_ooool008Wooooo0_l00005ooooo`;o00000_ooool2
o`0001Kooooo00?o0000ooooooooool01Oooool2o`000003ooooool0003o00000:oooooo002@oooo
o`Ko00005_ooool3o`0000Gooooo0_l000000ooooooo0000o`00002_ooooo`00T_ooool4o`0001Ko
oooo0ol00004ooooo`;o0000/oooool009Cooooo0_l0000Fooooo`03o`000?oooooooooo00;o0000
0_ooool2o`0000Gooooo0_l0002/ooooo`00Roooool4o`0001gooooo1_l00008ooooo`;o0000[?oo
ool008_ooooo1?l0000Mooooo`04o`000?ooooooooooooooo`;o0000]_ooool0093ooooo0_l00002
ooooo`;o00005_ooool00ol0003oooooooooo`05ooooo`;o00000oooool2o`000:gooooo002@oooo
o`;o00000_ooool2o`0001Kooooo00?o0000ooooooooool01Oooool2o`0000?ooooo0_l0002]oooo
o`00UOooool2o`0001Gooooo00?o0000ooooooooool0^Oooool009Gooooo0_l0000Eooooo`03o`00
0?oooooooooo0;Wooooo002Zooooo`?o0000^oooool009;ooooo0ol00004ooooo`;o00003oooool3
o`000;_ooooo002Booooo`?o00001?ooool2o`0000kooooo0_l000000ooooooo0000o`000003o`00
0;Oooooo002Hooooo`;o00003oooool2o`000004ooooool0003oooooooooo`;o0000]oooool009Co
oooo0_l000001?oooooo0000o`000?l0000?ooooo`;o000000?oooooo`000?ooool0^_ooool009Co
oooo1ol000000ooooooo0000o`000003ooooo`;o00001?ooool2o`0000?ooooo00?o0000oooooooo
ool0^Oooool009Gooooo0_l00002ooooo`;o000000?oooooo`000?l000000oooool2o`0000Cooooo
0_l00003ooooo`03o`000?oooooooooo00Gooooo0_l0002booooo`00[?ooool00ol0003ooooooooo
o`02ooooo`;o000000?oooooo`000?l00000/_ooool0097ooooo0_l0000Iooooo`?o00000_ooool2
o`000;Gooooo002Aooooo`?o00005oooool4o`000;Wooooo002@ooooo`Co00001_ooool2o`0000oo
oooo0_l0002kooooo`00T?ooool2o`0000Sooooo0_l0000:ooooo`?o00000_ooool4o`000;Wooooo
002Tooooo`Go00000_ooool3o`000;[ooooo002Rooooo`Co000000?oooooo`000?l000000oooool2
o`000;[ooooo002Rooooo`;o00002?ooool00ol0003oooooooooo`2iooooo`00Toooool2o`000003
ooooool0003o000000Cooooo0_l00004ooooo`;o00000oooool4o`000003ooooool0003ooooo0;[o
oooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2o`000003ooooool0003o000000?o
oooo1?l00003ooooo`?o000000?o<S8bomgMgOl000000ol000001?oooooo0000o`000?l0002ioooo
o`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B400ooooooo0000o`000003oooo
o`Co00001_ooool00omgMgOo<S8booooo`04ooooo`?o0000^Oooool008Wooooo00Go410@oooooooo
oooooooooa0@4008ooooo`;o000000Goooooo`000?l0003oZJVYoeEEE@09ooooo`04o`000?oooooo
ooooooooo`?o0000^oooool008Wooooo00Go0000ooooooooooooooooo`00000;ooooo`;o000000?o
ooooob4Q8Oooool01oooool01OmgMgOo<S8bo`000?l0003ooooo00Go0000^Oooool008Wooooo00Go
0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo0ol000001?lb<S;oc<c<
o`000?l00003ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05oa0@4?ooooooooooooooool@
41003_ooool00onYZJWoMgMgooooo`02ooooo`Co000000?oooooo`000?l000001?ooool00ol0003o
ooooooooo`2iooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo0_l00002ooooo`;o
00000_ooool01?lb<S;oooooooooooooool2o`0000?ooooo0_l00004ooooo`03o`000?oooooooooo
0;Wooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01oooool2o`0000;ooooo1Ol00004oooo
o`Co00001_ooool00ol0003oooooooooo`2iooooo`00Y?ooool2o`0000Gooooo0_l0002kooooo`00
Yoooool2o`0000;ooooo0_l0002kooooo`00Y_ooool3o`0000?ooooo00?o0000ooooooooool0^Ooo
ool009Sooooo0_l00002ooooo`Go00001Oooool3o`0000?ooooo0ol0002iooooo`00V?ooool3o`00
0003ooooool0003o000000Co00001Oooool2o`0000?ooooo00?o0000ooooooooool0^Oooool009Wo
oooo0ol00004ooooo`;o00002_ooool00ol0003oooooooooo`2iooooo`00V_ooool2o`00013ooooo
00?o0000ooooooooool0^Oooool00:?ooooo1?l00005ooooo`03o`000?oooooooooo0;Wooooo002S
ooooo`Co00001Oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002i
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00X_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooo
ooooool0^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00
Y?ooool00ol0003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool0`Ooo
ool00:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:Co
oooo00?o0000ooooooooool0`Oooool00:;ooooo00?oEEEEofIVI_l00000`oooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:[ooooo00Co410@o`000?l0003o
0000^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_oo
ool00:_ooooo00Ko0000ogMgMol0003o0000oeEEEOo^k^jgooooo`00Zoooool01_l0003oEEEEonk^
k_ooooooMgMgoeEEEKOooooo002[ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0
]Oooool00:_ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`2eooooo`00Zoooool0
1_l0003oEEEEonk^k_ooooooMgMgofIVI[Oooooo002Zooooo`03oa0@4?l0003oMgMg00;o000000?o
IVIVonk^k_ooool0]_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.565 .78421 Mdot
.57966 .77689 Mdot
.50574 .48279 Mdot
.50341 .28081 Mdot
.58116 .417 Mdot
.59061 .71114 Mdot
.46751 .67024 Mdot
.45261 .98211 Mdot
.37158 .5975 Mdot
.53119 .31712 Mdot
.55245 .37216 Mdot
.37945 .74413 Mdot
.59024 .78179 Mdot
.51363 .26451 Mdot
.38833 .20538 Mdot
.50497 .27094 Mdot
.58421 .66829 Mdot
.59163 .78068 Mdot
.56228 .36776 Mdot
.55805 .86384 Mdot
.52186 .88078 Mdot
.53017 .85805 Mdot
.45973 .90622 Mdot
.57246 .81304 Mdot
.38474 .21502 Mdot
.59634 .43361 Mdot
.56795 .46097 Mdot
.57291 .43226 Mdot
.52549 .90663 Mdot
.54151 .83644 Mdot
.44173 .89469 Mdot
.39167 .7948 Mdot
.39066 .80516 Mdot
.55478 .74676 Mdot
.5961 .66742 Mdot
.426 .87851 Mdot
.41461 .87232 Mdot
.57236 .45715 Mdot
.42344 .88404 Mdot
.407 .89179 Mdot
.36427 .55646 Mdot
.58469 .68946 Mdot
.5795 .72145 Mdot
.60837 .7052 Mdot
.60392 .70519 Mdot
.58704 .41778 Mdot
.55341 .38964 Mdot
.43476 .93731 Mdot
.6071 .49102 Mdot
.45271 .93498 Mdot
.41615 .89101 Mdot
.47064 .95446 Mdot
.56691 .74085 Mdot
.60464 .65485 Mdot
.37392 .65599 Mdot
.42606 .94026 Mdot
.59862 .62289 Mdot
.42857 .9185 Mdot
.60535 .69923 Mdot
.59213 .45931 Mdot
.37396 .25834 Mdot
.39709 .77939 Mdot
.43001 .37122 Mdot
.37352 .34679 Mdot
.39418 .8127 Mdot
.54012 .34731 Mdot
.53146 .34691 Mdot
.56436 .39215 Mdot
.54605 .85304 Mdot
.61781 .52797 Mdot
.47642 .68705 Mdot
.54936 .38046 Mdot
.52831 .31672 Mdot
.39656 .77629 Mdot
.50309 .57674 Mdot
.58633 .58252 Mdot
.48541 .95143 Mdot
.57307 .66487 Mdot
.43258 .88457 Mdot
.52553 .85752 Mdot
.51428 .31208 Mdot
.59371 .668 Mdot
.44296 .96642 Mdot
.45738 .2425 Mdot
.58157 .41582 Mdot
.58711 .52695 Mdot
.6084 .57207 Mdot
.53631 .36385 Mdot
.39894 .14249 Mdot
.42861 .36824 Mdot
.5876 .43772 Mdot
.43687 .32744 Mdot
.43318 .00559 Mdot
.51501 .26844 Mdot
.37719 .66747 Mdot
.61555 .51465 Mdot
.55094 .80948 Mdot
.61224 .52338 Mdot
.36626 .55705 Mdot
.59591 .73484 Mdot
.5064 .90768 Mdot
.55626 .74589 Mdot
.61214 .57877 Mdot
.56236 .36096 Mdot
.42768 .37439 Mdot
.52471 .88094 Mdot
.51368 .26837 Mdot
.4757 .2457 Mdot
.38529 .75269 Mdot
.52145 .9041 Mdot
.57702 .03134 Mdot
.44517 .66342 Mdot
.59393 .50462 Mdot
.45302 .97349 Mdot
.43438 .9449 Mdot
.37753 .63229 Mdot
.57734 .80226 Mdot
.36203 .42582 Mdot
.44398 .89225 Mdot
.54284 .88661 Mdot
.53638 .8662 Mdot
.51847 .31729 Mdot
.49587 .93444 Mdot
.42242 .02973 Mdot
.49096 .89414 Mdot
.43186 .40802 Mdot
.50742 .88967 Mdot
.53362 .838 Mdot
.36749 .60931 Mdot
.60965 .66688 Mdot
.58162 .72164 Mdot
.52806 .90739 Mdot
.49621 .95315 Mdot
.50217 .93087 Mdot
.55135 .39137 Mdot
.37056 .63131 Mdot
.37617 .29145 Mdot
.44821 .0006 Mdot
.44343 .29248 Mdot
.55959 .36424 Mdot
.58777 .65848 Mdot
.5481 .87416 Mdot
.4466 .96933 Mdot
.59112 .0395 Mdot
.57762 .52686 Mdot
.58881 .51695 Mdot
.37686 .76459 Mdot
.61263 .50076 Mdot
.54919 .34016 Mdot
.58498 .7943 Mdot
.48266 .68292 Mdot
.54492 .80172 Mdot
.45472 .94948 Mdot
.4219 .88191 Mdot
.41998 .91406 Mdot
.39728 .79935 Mdot
.465 .95743 Mdot
.60167 .4558 Mdot
.51075 .92896 Mdot
.42258 .94545 Mdot
.41439 .83804 Mdot
.53877 .79504 Mdot
.5163 .85759 Mdot
.4363 .95308 Mdot
.51746 .89658 Mdot
.56507 .39888 Mdot
.51128 .93508 Mdot
.41786 .86006 Mdot
.49239 .271 Mdot
.56939 .44097 Mdot
.58667 .48647 Mdot
.58025 .48419 Mdot
.36921 .59631 Mdot
.43468 .00436 Mdot
.53899 .81012 Mdot
.42918 .48098 Mdot
.48185 .94833 Mdot
.52375 .91878 Mdot
.38864 .81284 Mdot
.5006 .25391 Mdot
.36406 .5562 Mdot
.43345 .38194 Mdot
.37023 .46054 Mdot
.43467 .94223 Mdot
.41371 .92061 Mdot
.59222 .69605 Mdot
.36178 .45666 Mdot
.55489 .86549 Mdot
.4369 .33945 Mdot
.39377 .14334 Mdot
.43943 .96303 Mdot
.37374 .72268 Mdot
.36738 .59892 Mdot
.58794 .45228 Mdot
.6185 .55764 Mdot
.43004 .49485 Mdot
.42989 .49393 Mdot
.47314 .68813 Mdot
.58545 .48049 Mdot
.51969 .85532 Mdot
.44766 .30966 Mdot
.58058 .73511 Mdot
.44236 .28904 Mdot
.42446 .51905 Mdot
.54317 .33583 Mdot
.59293 .77109 Mdot
.58872 .56611 Mdot
.5135 .90145 Mdot
.52413 .31373 Mdot
.50935 .8674 Mdot
.5851 .5809 Mdot
.41002 .91059 Mdot
.42535 .52616 Mdot
.56443 .77641 Mdot
.42561 .94356 Mdot
.59385 .4906 Mdot
.38526 .73439 Mdot
.53101 .87875 Mdot
.41319 .82881 Mdot
.54084 .37604 Mdot
.57988 .42797 Mdot
.60788 .72199 Mdot
.46777 .25899 Mdot
.3858 .22013 Mdot
.36069 .54324 Mdot
.49121 .24823 Mdot
.49434 .63996 Mdot
.59849 .59295 Mdot
.5603 .39775 Mdot
.36547 .36347 Mdot
.57003 .43877 Mdot
.5975 .73405 Mdot
.50082 .90277 Mdot
.54135 .82597 Mdot
.38334 .19399 Mdot
.60446 .67247 Mdot
.53174 .88277 Mdot
.61767 .52881 Mdot
.42137 .91311 Mdot
.4553 .27729 Mdot
.40325 .82176 Mdot
.56923 .69634 Mdot
.61776 .52442 Mdot
.41154 .84668 Mdot
.36817 .65752 Mdot
.44252 .65198 Mdot
.45982 .27835 Mdot
.38848 .73881 Mdot
.59904 .50601 Mdot
.56979 .45062 Mdot
.62254 .59752 Mdot
.50269 .58203 Mdot
.39937 .85309 Mdot
.43625 .93749 Mdot
.60637 .53294 Mdot
.55965 .39452 Mdot
.41769 .84678 Mdot
.42786 .48216 Mdot
.60901 .54284 Mdot
.54677 .81037 Mdot
.56067 .43143 Mdot
.54059 .79919 Mdot
.4139 .8431 Mdot
.59538 .564 Mdot
.47044 .94074 Mdot
.61071 .63906 Mdot
.51447 .27418 Mdot
.59376 .5997 Mdot
.47176 .95886 Mdot
.48757 .23243 Mdot
.56291 .3514 Mdot
.40632 .85816 Mdot
.52713 .29125 Mdot
.56697 .76372 Mdot
.49144 .94537 Mdot
.43611 .63422 Mdot
.54199 .36756 Mdot
.38877 .74686 Mdot
.37042 .64427 Mdot
.56006 .351 Mdot
.47859 .68087 Mdot
.57802 .55813 Mdot
.55124 .86476 Mdot
.59063 .49208 Mdot
.42552 .8649 Mdot
.40195 .83014 Mdot
.37463 .31309 Mdot
.37863 .66751 Mdot
.49837 .63625 Mdot
.46181 .96308 Mdot
.4215 .05478 Mdot
.56172 .84807 Mdot
.38536 .22469 Mdot
.59717 .0425 Mdot
.60057 .55794 Mdot
.62301 .60634 Mdot
.54915 .81642 Mdot
.40741 .86863 Mdot
.36683 .39201 Mdot
.54978 .36964 Mdot
.39219 .79003 Mdot
.6 .49944 Mdot
.43121 .5251 Mdot
.57148 .80527 Mdot
.58833 .6593 Mdot
.56064 .82597 Mdot
.37448 .7428 Mdot
.43291 .59455 Mdot
.55629 .79188 Mdot
.56655 .72669 Mdot
.37433 .33277 Mdot
.4305 .57928 Mdot
.37948 .75343 Mdot
.40238 .11829 Mdot
.40068 .10139 Mdot
.51438 .30122 Mdot
.62026 .63645 Mdot
.60255 .64329 Mdot
.39421 .76571 Mdot
.5717 .37756 Mdot
.44336 .64558 Mdot
.48209 .66938 Mdot
.60921 .58886 Mdot
.43629 .96303 Mdot
.37798 .62918 Mdot
.42898 .37031 Mdot
.57195 .80188 Mdot
.42781 .4554 Mdot
.46886 .68614 Mdot
.60426 .73016 Mdot
.59881 .69074 Mdot
.54049 .79241 Mdot
.60211 .46448 Mdot
.58487 .49055 Mdot
.59568 .55245 Mdot
.49889 .88959 Mdot
.44331 .30938 Mdot
.37573 .68594 Mdot
.56765 .46738 Mdot
.49366 .93842 Mdot
.48477 .9049 Mdot
.42791 .36606 Mdot
.58089 .59184 Mdot
.43777 .01383 Mdot
.39229 .82582 Mdot
.49265 .96154 Mdot
.43593 .90265 Mdot
.60386 .51722 Mdot
.60858 .6055 Mdot
.43272 .89926 Mdot
.60517 .56303 Mdot
.38805 .8022 Mdot
.37219 .25244 Mdot
.532 .88313 Mdot
.36605 .57038 Mdot
.37672 .73188 Mdot
.38044 .77022 Mdot
.46248 .68241 Mdot
.59867 .58641 Mdot
.3822 .24286 Mdot
.41436 .9085 Mdot
.46225 .68314 Mdot
.44569 .90523 Mdot
.58237 .61898 Mdot
.59704 .70085 Mdot
.55321 .80506 Mdot
.37449 .63457 Mdot
.59352 .74145 Mdot
.42423 .90305 Mdot
.37856 .62845 Mdot
.45511 .90113 Mdot
.50917 .94388 Mdot
.49407 .90406 Mdot
.37906 .25771 Mdot
.57045 .02088 Mdot
.37413 .57027 Mdot
.56832 .76427 Mdot
.45995 .66946 Mdot
.38207 .22212 Mdot
.61244 .54025 Mdot
.48303 .66779 Mdot
.40105 .87314 Mdot
.54416 .856 Mdot
.45265 .67736 Mdot
.534 .33164 Mdot
.59696 .4708 Mdot
.56316 .41028 Mdot
.4431 .95239 Mdot
.57327 .82312 Mdot
.40887 .08754 Mdot
.38831 .81177 Mdot
.58314 .68018 Mdot
.59629 .64645 Mdot
.57948 .46609 Mdot
.57717 .42334 Mdot
.50702 .57855 Mdot
.42062 .92853 Mdot
.37805 .73184 Mdot
.5674 .45554 Mdot
.45164 .27654 Mdot
.51941 .26612 Mdot
.47079 .22999 Mdot
.3684 .67373 Mdot
.58205 .4006 Mdot
.43784 .90157 Mdot
.47316 .25029 Mdot
.55492 .35994 Mdot
.42725 .50787 Mdot
.58306 .41569 Mdot
.55488 .74482 Mdot
.54856 .34293 Mdot
.44812 .30706 Mdot
.36242 .58969 Mdot
.37313 .66746 Mdot
.4991 .4379 Mdot
.59768 .66545 Mdot
.61154 .58199 Mdot
.51081 .85395 Mdot
.58145 .62584 Mdot
.56615 .41069 Mdot
.3695 .3292 Mdot
.40837 .05909 Mdot
.57774 .77209 Mdot
.5632 .02103 Mdot
.61553 .69111 Mdot
.4343 .35796 Mdot
.3728 .384 Mdot
.38796 .20505 Mdot
.56067 .41217 Mdot
.46297 .90248 Mdot
.45976 .26268 Mdot
.4519 .67231 Mdot
.58069 .50935 Mdot
.43483 .89288 Mdot
.58323 .62973 Mdot
.42875 .41683 Mdot
.56141 .74777 Mdot
.59894 .65023 Mdot
.42487 .40811 Mdot
.42849 .51558 Mdot
.50157 .25284 Mdot
.44482 .9732 Mdot
.44014 .64621 Mdot
.50445 .93471 Mdot
.58507 .76455 Mdot
.5814 .75022 Mdot
.48786 .93924 Mdot
.42202 .8525 Mdot
.5902 .65767 Mdot
.38415 .1625 Mdot
.53275 .32648 Mdot
.43771 .96585 Mdot
.37429 .72581 Mdot
.56296 .4559 Mdot
.4762 .96753 Mdot
.5888 .59757 Mdot
.56422 .71354 Mdot
.50141 .93059 Mdot
.56123 .79358 Mdot
.56825 .39225 Mdot
.58283 .58287 Mdot
.56829 .7194 Mdot
.35978 .50734 Mdot
.55591 .76995 Mdot
.50866 .52542 Mdot
.55978 .75794 Mdot
.58167 .64013 Mdot
.47858 .69112 Mdot
.5316 .35216 Mdot
.57325 .72746 Mdot
.5984 .68231 Mdot
.43377 .59252 Mdot
.5967 .52714 Mdot
.39253 .80418 Mdot
.5755 .38617 Mdot
.54354 .81355 Mdot
.54253 .3101 Mdot
.57572 .50376 Mdot
.45778 .67875 Mdot
.55187 .00475 Mdot
.44889 .65568 Mdot
.59248 .75357 Mdot
.37195 .54027 Mdot
.42485 .87213 Mdot
.56522 .39354 Mdot
.49432 .93992 Mdot
.38517 .78974 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool009Kooooo0_l00002ooooo`;o00002?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo002Fooooo`;o00003?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00kooooo0_l0002Yooooo`00U_ooool2o`0000cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0>ooooo`;o0000ZOooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00Uoooool2o`0000Wooooo00?oEEEEofIV
I_l000001oooool00ol0003oooooooooo`2iooooo`00Uoooool2o`0001?ooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool04Oooool2o`000003ooooool0003o00000:?ooooo
002/ooooo`?o00004Oooool2o`000003ooooool0003o00000:?ooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002Booooo`;o00006?ooool00ol0003oooooooooo`0Fooooo`;o0000XOooool009;o
oooo0_l0000Hooooo`03o`000?oooooooooo01Kooooo0_l0002Qooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool00ol0003oooooooooo`0Kooooo`;o0000W?ooool00:cooooo00?o0000
ooooooooool06oooool4o`0009[ooooo002/ooooo`03o`000?oooooooooo01gooooo0_l0002Joooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002Booooo`;o00006?oo
ool00ol0003oooooooooo`2iooooo`00SOooool2o`0000?ooooo0_l0000Hooooo`03o`000?oooooo
oooo0;Wooooo002=ooooo`;o00007Oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002=ooooo`;o00007Oooool00ol0003oooooooooo`2iooooo`00SOooool2o`00
01gooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool008_ooooo0_l0000Oooooo`?o0000^Oooool008_ooooo0_l0000O
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo0029ooooo`05onk^k_lb<S;o0000o`000?o^k^h01Oooool2ob4Q8@Kooooo00?o
0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0
^Oooool008Wooooo00GoMgMgoiRHV?l0003o0000ogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVY
ooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0^Oooool0087ooooo1_l0
0002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`00
0?oooooooooo00?ooooo0ol0002iooooo`00ROooool01Ol0003ooooooooooooooooo000000kooooo
00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;Wooooo
0029ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2iooooo`00ROooool01Ol@413ooooo
oooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0;Wooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413o
oooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2ioooo
o`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool00ol0
003oooooooooo`2iooooo`00R?ooool4o`00023ooooo00?o0000ooooooooool0^Oooool008Sooooo
1?l0000Pooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool008Gooooo0_l0000Uooooo`03o`000?oo
oooooooo0;Wooooo0025ooooo`;o00009Oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo0025ooooo`;o00009Oooool00ol0003oooooooooo`2iooooo`00QOooool2
o`0002Gooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00Qoooool2o`0002?ooooo00?o0000ooooooooool0^Oooool008Oooooo0_l0
000Sooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo0026oooo
o`;o00009?ooool00ol0003oooooooooo`2iooooo`00Q_ooool2o`0002Cooooo00?o0000oooooooo
ool0^Oooool008Gooooo0ol0000Tooooo`03o`000?oooooooooo0;Wooooo0025ooooo`?o00009?oo
ool3o`000;Wooooo0026ooooo`;o00009?ooool00ol0003oooooooooo`2iooooo`00X_ooool2o`00
00Sooooo00?o0000ooooooooool0^Oooool00:;ooooo0_l00003ooooo`;o00000oooool00ol0003o
ooooooooo`2iooooo`00Yoooool2o`0000?ooooo00?o0000ooooooooool0^Oooool00:cooooo00?o
0000ooooooooool0^Oooool008Gooooo0_l0000:ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@;o00000oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0
^Oooool008Gooooo0_l0000:ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@;o0000
1Oooool2o`000003oc8b<_oooooooooo00?ooooo00?o0000ooooooooool0^Oooool008Wooooo1_l0
0002ooooo`05oa0@4?ooooooooooooooool@41003_ooool3o`0000;ooooo0_l000000ooooooo0000
ooooo`2jooooo`00POooool2o`0000kooooo00Go0000ooooooooooooooooo`00000=ooooo`;o0000
00CoMgMgoc8b<_oooooooooo0_l000001?oooooo0000o`000?l0002iooooo`00POooool2o`0000ko
oooo00Go0000ooooooooooooooooo`00000<ooooo`?o000000?o<S8bolc<c?ooool01?ooool2o`00
0;[ooooo0022ooooo`Co00002oooool01Ol@413ooooooooooooooooo410@00_ooooo0_l00009oooo
o`;o0000^_ooool008;ooooo1?l0000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool2o`00
00Wooooo00?o0000ooooooooool0^Oooool0097ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08oooo
o`;o00000_ooool4o`0000Kooooo00Co0000oooooooooooooooo0_l0002fooooo`00W_ooool2o`00
00cooooo00Co0000oooooooooooooooo1?l0002dooooo`00ZOooool2o`000005ooooool0003o0000
o`000?ooool01?l0002dooooo`00ZOooool2o`000005ooooool0003o0000o`000?ooool00ol0002e
ooooo`00W?ooool3o`0000gooooo0ol000000ooooooo0000o`00002fooooo`00W?ooool4o`0000co
oooo00?o0000ooooooooool0^Oooool009kooooo0_l0000<ooooo`?o0000^Oooool00:cooooo0ol0
002iooooo`00VOooool2o`00017ooooo00?o0000ooooooooool0^Oooool008?ooooo0_l0000Doooo
o`;o00004Oooool00ol0003oooooooooo`06ooooo`;o0000/Oooool008?ooooo0_l0000Dooooo`;o
00004Oooool00ol0003oooooooooo`06ooooo`;o0000/Oooool00:cooooo00?o0000ooooooooool0
^Oooool00:cooooo0ol000000ooooooo0000o`00002fooooo`00[?ooool01?l0003ooooooooooooo
ool2o`000;Kooooo002Jooooo`;o00004?ooool00ol0003oooooooooo`2iooooo`00VOooool3o`00
013ooooo00?o0000ooooooooool02oooool2o`000:cooooo0022ooooo`;o00005Oooool3o`00013o
oooo00Co0000oooooooooooooooo0_l00008ooooo`;o0000[?ooool008;ooooo0_l0000Xooooo`04
o`000?ooooooooooooooo`;o00000_ooool3o`000;7ooooo002/ooooo`03o`000?oooooooooo00?o
oooo1_l0002`ooooo`00[?ooool00ol0003oooooooooo`03ooooo`;o00000_ooool2o`000;3ooooo
002/ooooo`?o0000^Oooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo00Oooooo0_l0002`
ooooo`00P?ooool2o`0001Gooooo0_l0000Cooooo`03o`000?oooooooooo00Oooooo0ol0002_oooo
o`00P?ooool4o`0002Sooooo00?o0000ooooooooool02?ooool2o`000:oooooo0022ooooo`;o0000
:?ooool00ol0003oooooooooo`0;ooooo`;o0000[?ooool009Oooooo0_l0000Cooooo`03o`000?oo
oooooooo00_ooooo1?l0002Zooooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool03Oooool2
o`000:[ooooo0022ooooo`;o0000:?ooool00ol0003oooooooooo`07ooooo`;o00001?ooool2o`00
0:[ooooo0022ooooo`;o0000:?ooool00ol0003oooooooooo`07ooooo`;o000000?oooooo`000?l0
0000[Oooool00:cooooo0ol00007ooooo`;o000000?oooooo`000?l000001?ooool3o`000:Kooooo
002/ooooo`03o`000?oooooooooo00Oooooo0_l00007ooooo`?o0000Y_ooool009Kooooo0_l0000D
ooooo`03o`000?oooooooooo0;Wooooo002Fooooo`;o00005?ooool00ol0003oooooooooo`0?oooo
o`Co0000Y_ooool007oooooo0_l0000[ooooo`03o`000?oooooooooo00Wooooo0_l00004ooooo`Co
0000Y_ooool007oooooo0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00olQ8B7o
0000o`000003ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool02Oooool3o`0000Cooooo0ol0002Vooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo00?o8B4Qo`000?l000000oooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`0:ooooo`;o000000?oooooo`000?l000000_ooool2
o`000:Kooooo0021ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00Kooooo0_l00004
ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0=
ooooo`?o0000ZOooool008Wooooo00Go0000ooooooooooooooooo`000006ooooo`;o00001Oooool0
0onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000:ooooo`;o00000_ooool2
o`000:Wooooo0029ooooo`05o`000?ooooooooooooooool000001_ooool2o`0000Kooooo00?oMgMg
ofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool02_oo
ool2o`0000Sooooo0_l0002Sooooo`00ROooool01Ol@413ooooooooooooooooo410@00Sooooo0_l0
0005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0=ooooo`;o00001Oooool2o`000:?ooooo0022ooooo`;o00001Oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Sooooo0_l000001_oooooo0000okZj^_ooooooV9RHoa0@40Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0=ooooo`;o00001_ooool2o`000:;ooooo0022ooooo`;o0000
1Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co00001_ooool00ol0003oooooooooo`0Eooooo`;o0000X_ooool0083ooooo0_l0000Zooooo`03
o`000?oooooooooo00kooooo0_l00002ooooo`?o0000Y?ooool0083ooooo0_l0000Zooooo`03o`00
0?oooooooooo00kooooo1ol0002Tooooo`00[?ooool00ol0003oooooooooo`0@ooooo`Co0000YOoo
ool00:cooooo0ol0000@ooooo`Co00001?ooool2o`0009oooooo002/ooooo`03o`000?oooooooooo
01;ooooo0_l00004ooooo`;o0000Woooool00:cooooo00?o0000ooooooooool0^Oooool009?ooooo
1?l0000Eooooo`03o`000?oooooooooo017ooooo0_l0002Vooooo`00Toooool4o`0001Gooooo00?o
0000ooooooooool04Oooool3o`000:Gooooo002/ooooo`03o`000?oooooooooo017ooooo0ol00003
ooooo`?o0000Woooool009Cooooo0_l0000Fooooo`03o`000?oooooooooo01Oooooo1?l0002Noooo
o`00U?ooool2o`0001Kooooo00?o0000ooooooooool05oooool4o`0009kooooo002/ooooo`?o0000
5_ooool2o`000:7ooooo001nooooo`;o0000;?ooool00ol0003oooooooooo`0Fooooo`?o0000X?oo
ool007kooooo0_l0000/ooooo`03o`000?oooooooooo017ooooo0_l00004ooooo`;o0000X?ooool0
0:cooooo00?o0000ooooooooool04Oooool2o`0000;ooooo0_l00005ooooo`;o0000Voooool00:_o
oooo0_l0000Gooooo`;o00000_ooool2o`000003ooooool0003o000009_ooooo002[ooooo`;o0000
5_ooool2o`0000?ooooo0_l0002Nooooo`00[?ooool00ol0003oooooooooo`0Cooooo`?o0000Xooo
ool00:cooooo00?o0000ooooooooool04oooool2o`000:Cooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`?o00005?ooool2o`0000Cooooo0_l0002Mooooo`00U?ooool2o`0001Kooooo
00?o0000ooooooooool04Oooool5o`0000Cooooo0_l00002ooooo`;o0000VOooool007kooooo0_l0
000Dooooo`;o00005_ooool00ol0003oooooooooo`0Aooooo`Go00002?ooool2o`0009Wooooo0009
ooooo`Co000000?o410@ooooooooool05_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0?oooo
o`06onk^k_lb<S;o0000oc8b<_o^k^kooooo0_l000001?oooooo0000o`000?lQ8B44ooooo`Go0000
1?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Kooooo00?o0000ooooooooool04oooool3o`0000;o
oooo00?ok^k^oc8b<_l000000_l00005ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo
00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1?l000000ol@413o
ooooooooo`0Booooo`002oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`0>ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Cooooo0_l000000olQ8B7oooooooooo`02ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01oooool00omgMgOo<S8booooo`0Eooooo`03o`000?oooooooooo01?ooooo0_l0
0003ooooo`03ogMgMonHV9Sooooo00;o000000?oooooo`000?l000000_ooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`0Ioooo
o`03o`000?oooooooooo01Cooooo0006o`0000Gooooo00?o0000ooooooooool04?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000oooo
ooooool01Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^
kP09ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04oooool2o`0000;ooooo0_l0
0003ooooo`04oa0@4?oooooo0000o`0000Wooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003ooooo
ooooo`0=ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0=ooooo`05
oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol0003o
oooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`0>oooo
o`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0>ooooo`05o`000?oooooo
ooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo01Gooooo00?o
0000ooooooooool04oooool2o`0000;ooooo0_l00003ooooo`?o00002oooool00onHV9So8B4Qonk^
kP07ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMg
Molb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Ko
oooo00?oMgMgoc8b<_ooool06Oooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003ooooo
ooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000
ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIV
ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05_ooool00ol0003oooooooooo`0Hooooo`04
o`000?ooooooooooooooo`?o00003?ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00?ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`06_ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003o
ooooooooo`0Hooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03oooo
o`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooo
oooo017ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool06?ooool3o`0001Sooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00co
oooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Cooooo000;ooooo`03
o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooo
oooooolb<S801?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zj
oooooonHV9So410@00Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Hooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000
ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool05?ooool000Wooooo00?oEEEEofIVI_l00000
6_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00004?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1Ol0000Fooooo`?o00006?ooool01Oo^k^ko0000o`00
0?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00004?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5
o`0000Cooooo1?l0000Iooooo`03oeEEEOmVIVKo000001Kooooo002Dooooo`;o00005_ooool3o`00
01Oooooo1?l0002Nooooo`00[?ooool00ol0003oooooooooo`0Gooooo`Co0000W_ooool00:cooooo
00?o0000ooooooooool06Oooool5o`0000;ooooo0_l0002<ooooo`;o00000_ooool2o`0000Gooooo
002Dooooo`;o00005_ooool00ol0003oooooooooo`0Iooooo`Go00000_ooool2o`0008cooooo00Ko
k^k^ob4Q8On7QhOo^[Zjo`000?oMgMd5ooooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool0
[oooool01?oMgMgo0000oa0@4?o<c<`6ooooo`001oooooooo`0004co00003?ooool01?o^k^ko8B4Q
oa0@4?o^k^h6ooooo`001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
0_l00006ooooo`;o00000_ooool2o`0000?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool01?lQ8B7oMgMg
ogMgMolb<S86ooooo`001oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool08?ooool2o`0000Cooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0Fooooo`;o00001?ooool3o`0000Sooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02Oooool2o`0000;ooooo
0_l00005ooooo`00OOooool2o`0001Gooooo0_l0000Fooooo`03o`000?oooooooooo01Oooooo0_l0
0003ooooo`?o0000V_ooool009Cooooo0_l0000Fooooo`03o`000?oooooooooo01Oooooo0_l0002P
ooooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool08oooool2o`0009Cooooo002Cooooo`?o
00005_ooool00ol0003oooooooooo`0Jooooo`;o00000oooool2o`0000;ooooo0_l0002Dooooo`00
Toooool2o`0001Oooooo00?o0000ooooooooool06_ooool2o`0000?ooooo0_l0002Hooooo`00UOoo
ool2o`0001Gooooo1?l0000Qooooo`?o0000U?ooool009?ooooo1?l0000Eooooo`04o`000?oooooo
0000o`0001Gooooo0_l000001?oooooo0000o`000?ooool2o`0000Cooooo0ol0002Dooooo`00Tooo
ool2o`0001Oooooo00?o0000ooooooooool05_ooool2o`000004ooooool0003o0000ooooo`;o0000
1Oooool2o`0009Cooooo002/ooooo`03o`000?oooooooooo023ooooo0_l000000ooooooo0000o`00
002Dooooo`00[?ooool00ol0003oooooooooo`0Pooooo`;o0000Uoooool0087ooooo0_l0000Yoooo
o`03o`000?oooooooooo02;ooooo0_l0002Eooooo`00O_ooool2o`000003ooooool0003o000002Wo
oooo00?o0000ooooooooool08Oooool3o`0009Gooooo001nooooo`;o0000;?ooool00ol0003ooooo
ooooo`0Qooooo`;o0000U_ooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0000L
ooooo`;o0000Voooool00:cooooo00?o0000ooooooooool07?ooool2o`0009_ooooo001oooooo`;o
0000:oooool00ol0003oooooooooo`0Fooooo`;o00001_ooool2o`0000Cooooo0_l0002Cooooo`00
Ooooool2o`0002_ooooo00?o0000ooooooooool05_ooool2o`0000Kooooo0_l00004ooooo`;o0000
Toooool00:cooooo00?o0000ooooooooool07?ooool2o`000003ooooool0003o000009Sooooo002/
ooooo`03o`000?oooooooooo01[ooooo1?l000000ooooooo0000o`00002Hooooo`00Ooooool2o`00
0003ooooool0003o000002Sooooo00?o0000ooooooooool06_ooool2o`0009gooooo001oooooo`;o
000000?oooooo`000?l00000:?ooool00ol0003oooooooooo`0Pooooo`;o0000Uoooool00:cooooo
0ol0000Pooooo`;o0000Uoooool009Gooooo0_l0000Eooooo`Co00008Oooool2o`0009Gooooo002E
ooooo`;o00005Oooool4o`0001Oooooo0ol00006ooooo`?o0000UOooool00:cooooo0_l0000Ioooo
o`?o00001_ooool2o`0009Kooooo002/ooooo`03o`000?oooooooooo01gooooo0_l00002ooooo`;o
0000U_ooool007kooooo0_l0000/ooooo`03o`000?oooooooooo01Oooooo0_l00004ooooo`;o0000
0_ooool2o`0009Kooooo001nooooo`;o00005Oooool3o`0001Cooooo00?o0000ooooooooool05ooo
ool2o`0000Cooooo0_l0002Jooooo`00P?ooool3o`0001;ooooo0ol0000Dooooo`03o`000?oooooo
oooo01[ooooo0_l000000ooooooo0000o`000006ooooo`;o0000T_ooool0083ooooo0ol0000Yoooo
o`?o00006_ooool4o`0000Oooooo0_l0002Booooo`00P?ooool2o`0002[ooooo00?o0000oooooooo
ool07?ooool2o`0009_ooooo002/ooooo`03o`000?oooooooooo023ooooo0_l00003ooooo`;o0000
T_ooool0083ooooo0_l0000Zooooo`03o`000?oooooooooo023ooooo0_l00003ooooo`;o0000T_oo
ool0083ooooo0_l0000Zooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Hooooo`;o0000Woooool0
08Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Hooooo`;o0000Wooo
ool008Wooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o
0000ooooooooool00oooool3o`0001gooooo0_l0002Jooooo`00Poooool2o`0000Cooooo00Go0000
ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`0Gooooo`;o00001?ooool2o`0009[ooooo0021ooooo`Co00001?ooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool05oooool3o`0009oooooo0021ooooo`Co00001?oo
ool01Ol@413ooooooooooooooooo410@00Sooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Hooooo`;o0000Woooool008;ooooo0ol0
0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool2o`000006ooooool0003o^[ZjoooooonH
V9So410@1?ooool00ol0003oooooooooo`06ooooo`;o00009_ooool2o`0009?ooooo0029ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00004
ooooo`?o00006_ooool2o`0000Oooooo0_l000000ooooooo0000o`00002Cooooo`00Z_ooool3o`00
01[ooooo0_l00004ooooo`;o000000?oooooo`000?l00000U_ooool0087ooooo0_l0000Eooooo`?o
00004Oooool00ol0003oooooooooo`0Looooo`Co0000VOooool0087ooooo0_l0000Eooooo`?o0000
4Oooool00ol0003oooooooooo`0Looooo`;o0000Voooool009Wooooo0_l0000Aooooo`?o00007Ooo
ool2o`0009[ooooo0022ooooo`;o00005Oooool4o`0000oooooo00?o0000ooooooooool07Oooool4
o`0009Sooooo0020ooooo`Co00005oooool2o`0000oooooo00?o0000ooooooooool06_ooool2o`00
00?ooooo0_l0002Hooooo`00P?ooool2o`0002[ooooo00?o0000ooooooooool06_ooool2o`0009go
oooo002Iooooo`;o00004Oooool00ol0003oooooooooo`0Eooooo`;o00000oooool2o`0009gooooo
0022ooooo`?o00005?ooool2o`0000_ooooo0_l00004ooooo`03o`000?oooooooooo01Gooooo0_l0
0004ooooo`Co00000_ooool2o`0009Kooooo0022ooooo`?o00006Oooool2o`000003ooooool0003o
000000?ooooo0_l00004ooooo`03o`000?oooooooooo01Sooooo0_l000000ooooooo0000o`000002
o`0000;ooooo0_l0002Fooooo`00P?ooool2o`0001[ooooo1?l000000ooooooo0000o`000003oooo
o`;o00001?ooool00ol0003oooooooooo`0Hooooo`;o00001Oooool2o`0009Sooooo0020ooooo`;o
00006_ooool2o`0000kooooo0ol0000Oooooo`;o0000V?ooool009cooooo1?l0000<ooooo`03o`00
0?oooooooooo01Sooooo0_l0002Oooooo`00W?ooool5o`0000?ooooo1?l00004ooooo`03o`000?oo
oooooooo01Sooooo0_l00003ooooo`;o0000V_ooool008?ooooo0_l0000Jooooo`Co000000?ooooo
o`000?l000000_l00004ooooo`03o`000?oooooooooo01gooooo0_l0002Jooooo`00Poooool2o`00
01cooooo1Ol00006ooooo`03o`000?oooooooooo0;Wooooo002Sooooo`?o00001_ooool00ol0003o
ooooooooo`0Iooooo`;o00000_ooool2o`0000Cooooo0_l0002Dooooo`00Y?ooool2o`0000Kooooo
00?o0000ooooooooool06Oooool2o`0000;ooooo0_l00004ooooo`;o0000U?ooool00:cooooo00?o
0000ooooooooool04oooool2o`0000Kooooo0_l0002Looooo`00[?ooool3o`0001?ooooo0_l00006
ooooo`Ko0000V?ooool00:cooooo00?o0000ooooooooool07Oooool4o`0009Sooooo002/ooooo`03
o`000?oooooooooo01oooooo0ol0002Gooooo`00[?ooool00ol0003oooooooooo`0Oooooo`?o0000
Uoooool00:cooooo00?o0000ooooooooool04_ooool2o`0000Kooooo0_l0002Mooooo`00[?ooool0
0ol0003oooooooooo`0Booooo`;o00001_ooool2o`0009gooooo002/ooooo`03o`000?oooooooooo
01?ooooo0_l0002Tooooo`00[?ooool00ol0003oooooooooo`0Cooooo`;o00000_ooool3o`0000Ko
oooo0_l0002Gooooo`00P_ooool2o`0002Sooooo0ol0000Gooooo`?o00001_ooool2o`0009Oooooo
0022ooooo`;o0000:?ooool00ol0003oooooooooo`0Cooooo`Co0000X_ooool008;ooooo0_l0000X
ooooo`03o`000?oooooooooo01?ooooo1?l00008ooooo`;o0000V?ooool008?ooooo0_l000000ooo
oooo0000o`00000Tooooo`03o`000?oooooooooo01gooooo1?l0002Hooooo`00Poooool2o`000003
ooooool0003o000002Cooooo00?o0000ooooooooool05oooool2o`0000?ooooo0ol0002Jooooo`00
Qoooool2o`0002?ooooo00?o0000ooooooooool05oooool2o`0000?ooooo0_l0002Kooooo`00P_oo
ool2o`0000?ooooo0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01?ooooo0_l00006ooooo`;o
0000W?ooool008;ooooo1?l000000ooooooo0000o`000008ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0?ooooo`;o
00000_ooool2o`0000Kooooo0_l0002Looooo`00Q?ooool2o`000003ooooool0003o000000Sooooo
00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool03oooool4o`000:Kooooo0026ooooo`;o00002Oooool01Ol0003ooooooooooooooooo000000oo
oooo00?oMgMgoc8b<_ooool01?ooool3o`00017ooooo0_l00004ooooo`;o0000X?ooool008Cooooo
1?l00009ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool05oooool2o`0000;ooooo0_l0002Looooo`00Q?ooool2o`0000_o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool04?ooool2o`0000Wooooo0_l0002Looooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0@ooooo`;o0000Yoooool008?o
oooo0_l0000<ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000oooo
ooooool04oooool2o`0000Cooooo0_l0002Nooooo`00Poooool2o`0000Cooooo0_l0000Qooooo`03
o`000?oooooooooo01?ooooo0_l00004ooooo`;o0000W_ooool008Cooooo0_l00003ooooo`;o0000
8Oooool00ol0003oooooooooo`0?ooooo`;o00002_ooool2o`0009cooooo0024ooooo`;o00009_oo
ool00ol0003oooooooooo`0?ooooo`;o00001Oooool2o`0000?ooooo0_l0002Looooo`00ROooool2
o`00027ooooo0ol0000Booooo`;o00000_ooool3o`000:3ooooo0029ooooo`?o00008?ooool00ol0
003oooooooooo`0Booooo`;o00000oooool2o`000:3ooooo002:ooooo`;o00008?ooool00ol0003o
ooooooooo`0Jooooo`?o0000W?ooool00:cooooo00?o0000ooooooooool04_ooool2o`0000Kooooo
0ol0002Looooo`00[?ooool00ol0003oooooooooo`0Booooo`;o0000YOooool008Kooooo1?l0000R
ooooo`03o`000?oooooooooo00oooooo0_l0002Xooooo`00Q_ooool4o`0002;ooooo00?o0000oooo
ooooool02Oooool3o`0000?ooooo1?l00006ooooo`;o0000W_ooool008Sooooo0_l0000Rooooo`03
o`000?oooooooooo00Wooooo0ol00005ooooo`;o00001_ooool2o`0009kooooo002:ooooo`;o0000
8?ooool3o`0000[ooooo0_l0002]ooooo`00Qoooool5o`00023ooooo00?o0000ooooooooool02_oo
ool3o`0000Oooooo1?l0002Qooooo`00Qoooool3o`0002;ooooo00?o0000ooooooooool02oooool2
o`000003ooooool0003o000000Cooooo1?l0002Qooooo`00Qoooool2o`0002?ooooo00?o0000oooo
ooooool02Oooool2o`000003ooooool0003o000000;o00001?ooool2o`000:?ooooo0027ooooo`Co
00008Oooool00ol0003oooooooooo`09ooooo`;o000000Coooooo`000?l0003o00001Oooool2o`00
0:?ooooo0027ooooo`Co00008Oooool00ol0003oooooooooo`0;ooooo`Co00001Oooool2o`000:?o
oooo002/ooooo`03o`000?oooooooooo00_ooooo1?l0002Zooooo`00S?ooool2o`0001kooooo00?o
0000ooooooooool0^Oooool008cooooo0_l0000Nooooo`?o00005Oooool2o`000:;ooooo0028oooo
o`;o00008_ooool00ol0003oooooooooo`0:ooooo`;o00001Oooool2o`0000;ooooo0_l0002Roooo
o`00R?ooool2o`000003ooooool0003o000000;ooooo0_l0000Kooooo`03o`000?oooooooooo00[o
oooo0_l00005ooooo`;o0000Y_ooool008_ooooo0_l00002ooooo`;o00006oooool00ol0003ooooo
ooooo`2iooooo`00[?ooool00ol0003oooooooooo`0:ooooo`;o0000[Oooool008oooooo0_l0000K
ooooo`03o`000?oooooooooo00Sooooo1?l0002]ooooo`00Soooool2o`0001_ooooo00?o0000oooo
ooooool02?ooool2o`000:oooooo002>ooooo`Co00006_ooool00ol0003oooooooooo`2iooooo`00
S_ooool4o`0001[ooooo00?o0000ooooooooool04Oooool2o`000:Kooooo002Booooo`;o00006?oo
ool3o`00017ooooo0_l0002Vooooo`00R_ooool2o`0000Kooooo0_l0000Hooooo`03o`000?oooooo
oooo00;o000000?oooooo`000?l000001oooool2o`000:_ooooo002:ooooo`;o000000?oooooo`00
0?l000007Oooool00ol0003oooooooooo`09o`0000;ooooo0ol0002[ooooo`00SOooool2o`000003
ooooool0003o000001[ooooo00?o0000ooooooooool00_ooool2o`000003ooooool0003o000000;o
00000_ooool2o`000:cooooo002@ooooo`;o000000?oooooo`000?l000005oooool00ol0003ooooo
ooooo`0=ooooo`;o000000?oooooo`000?l00000Yoooool008Wooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o00001_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01Oooool00ol0003oooooooooo`02o`0000Oooooo0_l00002ooooo`Go0000Yoooool008Wooooo
00CoMgMgoiRHV?ooooooV9RH0_l00004ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool00_l00007ooooo`;o00001?ooool2o`000:So
oooo0029ooooo`03oa0@4?oooooo000000Go00000_ooool2o`0000Kooooo00?oZJVYoeEEEOooool0
2?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`03o`000?oo
oooo000000;o000000?oooooo`000?l000000_ooool2o`0000Oooooo00?o8B4Qooooooooool01_oo
ool00omgMgOo<S8booooo`04ooooo`?o00003?ooool2o`000:_ooooo0029ooooo`05o`000?oooooo
ooooooooool000001Oooool2o`0000Oooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool01oooool2o`0000?ooooo0_l0002[ooooo`00ROoo
ool01Ol@413ooooooooooooooooo410@00Cooooo0ol00007ooooo`03ojVYZOmgMgOooooo00?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`Go0000/?ooool008Wooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`04ooooo`;o000000?oooooo`000?l000000_ooool01Ol@413ooooo
oooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`Go
0000/?ooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`;o000000?oooooo`000?l0
00000_ooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo00_ooooo0_l0002/ooooo`00
SOooool2o`000003ooooool0003o000000Oooooo0_l0000@ooooo`;o000000?oooooo`000?l00000
2_ooool2o`000:cooooo002=ooooo`;o000000?oooooo`000?l000001?ooool5o`0000kooooo1?l0
00000ooooooo0000o`00002hooooo`00U_ooool4o`0000oooooo0_l000000ooooooo0000ooooo`03
ooooo`;o0000]Oooool009Gooooo0_l00006ooooo`;o00003Oooool3o`0000;ooooo0_l0002eoooo
o`00Toooool6o`0000Cooooo1?l00009ooooo`Co00000_ooool2o`000003ooooool0003o00000;?o
oooo002Cooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000;ooooo0ol00006ooooo`;o
000000?oooooo`000?l000000_l00002ooooo`;o000000?oooooo`000?l000000_l0002aooooo`00
Soooool2o`0000Wooooo0_l00002ooooo`;o00001oooool2o`0000?ooooo00Co0000ooooool0003o
00001?ooool3o`000;7ooooo002>ooooo`?o000000?oooooo`000?l000006?ooool01?l0003ooooo
o`000?l0002hooooo`00S_ooool2o`000004ooooool0003o0000o`0001Sooooo00?o0000oooooooo
ool0^Oooool0097ooooo0_l000000ooooooo0000o`00000Fooooo`03o`000?oooooooooo00Cooooo
0_l0002cooooo`00Soooool2o`0000?ooooo0_l0000Fooooo`03o`000?oooooooooo00Cooooo0_l0
002cooooo`00Soooool2o`0001_ooooo0ol0002iooooo`00TOooool2o`0001Wooooo00?o0000oooo
ooooool0^Oooool0097ooooo0_l0000Iooooo`;o000000?oooooo`000?l00000]oooool00:[ooooo
1?l000000ooooooo0000o`00002gooooo`00U_ooool3o`0000?ooooo0_l0000<ooooo`Oo0000]ooo
ool009?ooooo0_l000001?oooooo0000o`000?l00003ooooo`;o00001?ooool2o`0000Cooooo2Ol0
002gooooo`00Toooool2o`000003ooooool0003o000000[ooooo0_l00004ooooo`Go0000^oooool0
09;ooooo0ol000000ooooooo0000o`00000Aooooo`;o000000Coooooo`000?oooooooooo0_l0002g
ooooo`00T_ooool2o`0000;ooooo0_l00005ooooo`;o00001oooool2o`000005ooooool0003o0000
ooooool000000_ooool2o`000;Oooooo002Iooooo`;o00000_ooool2o`0000Oooooo0ol00003oooo
o`?o0000^Oooool009Oooooo1?l00007ooooo`;o00000oooool2o`000004ooooool0003o0000o`00
0;_ooooo002Gooooo`;o00001oooool4o`0000Kooooo0ol0002kooooo`00X?ooool4o`0000Gooooo
0_l000000ooooooo0000ooooo`2jooooo`00Uoooool3o`0000Gooooo0_l00008ooooo`;o000000?o
ooooo`000?ooool0^_ooool009Oooooo1?l00004ooooo`;o00000oooool2o`0000Kooooo00?o0000
ooooooooool0^Oooool009Oooooo1Ol00008ooooo`;o00001_ooool00ol0003oooooooooo`2ioooo
o`00VOooool5o`0000kooooo00?o0000ooooooooool0^Oooool009Wooooo0_l000000ooooooo0000
o`00000>ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool009cooooo0_l0000>
ooooo`03o`000?oooooooooo0;Wooooo002Looooo`;o00003_ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00X_oo
ool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05oooo
o`?o0000^Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0
`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool0
0:;ooooo00?oEEEEofIVI_l00000`oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00:[ooooo00Co410@o`000?l0003o0000^_ooool00:_ooooo00?o0000oooo
ooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00Ko0000ogMgMol0003o
0000oeEEEOo^k^jgooooo`00Zoooool01_l0003oEEEEonk^k_ooooooMgMgoeEEEKOooooo002[oooo
o`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0]Oooool00:_ooooo00?o0000onk^k_oo
ool00_ooool00ol0003oooooooooo`2eooooo`00Zoooool01_l0003oEEEEonk^k_ooooooMgMgofIV
I[Oooooo002Zooooo`03oa0@4?l0003oMgMg00;o000000?oIVIVonk^k_ooool0]_ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.63869 .58421 Mdot
.65042 .57689 Mdot
.46646 .36934 Mdot
.42112 .42329 Mdot
.50796 .217 Mdot
.63507 .51114 Mdot
.51654 .53268 Mdot
.62234 .82803 Mdot
.51877 .93835 Mdot
.43329 .29422 Mdot
.46337 .21966 Mdot
.55121 .92249 Mdot
.66296 .58179 Mdot
.41691 .38127 Mdot
.42943 .94214 Mdot
.41874 .4185 Mdot
.61153 .46829 Mdot
.66391 .58068 Mdot
.47035 .19695 Mdot
.66358 .66384 Mdot
.63417 .68078 Mdot
.63339 .65805 Mdot
.59675 .74581 Mdot
.65767 .61304 Mdot
.43231 .95577 Mdot
.52978 .23361 Mdot
.51233 .26097 Mdot
.50581 .23226 Mdot
.64815 .70663 Mdot
.63609 .63644 Mdot
.58868 .77701 Mdot
.56183 .8892 Mdot
.56474 .89766 Mdot
.61348 .54676 Mdot
.62307 .46742 Mdot
.58243 .8104 Mdot
.58088 .84378 Mdot
.51521 .25715 Mdot
.58419 .82242 Mdot
.58724 .88241 Mdot
.5113 .97394 Mdot
.62047 .48946 Mdot
.62808 .52145 Mdot
.65046 .5052 Mdot
.646 .50519 Mdot
.51415 .21778 Mdot
.4704 .22132 Mdot
.60235 .82981 Mdot
.56351 .29102 Mdot
.60512 .78551 Mdot
.58653 .8509 Mdot
.61962 .77349 Mdot
.35595 .39537 Mdot
.62326 .54085 Mdot
.62658 .45485 Mdot
.53145 .92979 Mdot
.60249 .85602 Mdot
.60777 .42289 Mdot
.59546 .83213 Mdot
.64504 .49923 Mdot
.53585 .25931 Mdot
.4441 .99346 Mdot
.55683 .86073 Mdot
.45662 .7243 Mdot
.46351 .97624 Mdot
.56619 .88696 Mdot
.44633 .25609 Mdot
.4414 .28832 Mdot
.48147 .20394 Mdot
.64727 .65304 Mdot
.589 .32797 Mdot
.52221 .51788 Mdot
.46369 .22873 Mdot
.43208 .30617 Mdot
.55611 .86164 Mdot
.49385 .38011 Mdot
.35619 .3901 Mdot
.57934 .38252 Mdot
.62783 .75618 Mdot
.59902 .46487 Mdot
.58453 .79472 Mdot
.62854 .65752 Mdot
.42774 .36799 Mdot
.62091 .468 Mdot
.61394 .83413 Mdot
.4226 .63266 Mdot
.50789 .21582 Mdot
.55789 .32695 Mdot
.59723 .37207 Mdot
.4489 .26822 Mdot
.41341 .90944 Mdot
.3588 .59646 Mdot
.45627 .73105 Mdot
.52269 .23772 Mdot
.44558 .70381 Mdot
.37611 .78955 Mdot
.41786 .37423 Mdot
.53338 .91653 Mdot
.35519 .40592 Mdot
.58141 .31465 Mdot
.63474 .60948 Mdot
.58159 .32338 Mdot
.511 .96504 Mdot
.64984 .53484 Mdot
.62947 .70768 Mdot
.61462 .54589 Mdot
.60365 .37877 Mdot
.46794 .19472 Mdot
.45782 .73379 Mdot
.63709 .68094 Mdot
.41778 .38019 Mdot
.41933 .55195 Mdot
.55218 .90015 Mdot
.64309 .7041 Mdot
.3771 .15724 Mdot
.51811 .6179 Mdot
.55578 .30462 Mdot
.6193 .81946 Mdot
.60489 .83697 Mdot
.52527 .91199 Mdot
.65824 .60226 Mdot
.58815 .76918 Mdot
.65749 .68661 Mdot
.64286 .6662 Mdot
.42953 .34832 Mdot
.62981 .73484 Mdot
.38371 .8313 Mdot
.60944 .69623 Mdot
.46425 .70826 Mdot
.62329 .68967 Mdot
.62882 .638 Mdot
.52229 .95643 Mdot
.63641 .46688 Mdot
.63028 .52164 Mdot
.65101 .70739 Mdot
.63759 .75347 Mdot
.63451 .73087 Mdot
.46922 .22617 Mdot
.52656 .94308 Mdot
.45085 .97662 Mdot
.37177 .725 Mdot
.43653 .68272 Mdot
.46667 .20145 Mdot
.61116 .45848 Mdot
.65776 .67416 Mdot
.61588 .82868 Mdot
.38642 .10157 Mdot
.54837 .32686 Mdot
.55559 .31695 Mdot
.55681 .93967 Mdot
.57293 .30076 Mdot
.45019 .22627 Mdot
.6627 .5943 Mdot
.52213 .50014 Mdot
.6256 .60172 Mdot
.61103 .7945 Mdot
.58354 .82587 Mdot
.59372 .85463 Mdot
.5621 .86852 Mdot
.61799 .78417 Mdot
.54399 .2558 Mdot
.64234 .72896 Mdot
.60398 .87001 Mdot
.57068 .82336 Mdot
.61679 .59504 Mdot
.61934 .65759 Mdot
.60798 .83876 Mdot
.63609 .69658 Mdot
.48477 .20693 Mdot
.64531 .73508 Mdot
.57697 .82475 Mdot
.42124 .47362 Mdot
.50578 .24097 Mdot
.54126 .28647 Mdot
.53392 .28419 Mdot
.51902 .94898 Mdot
.37552 .7833 Mdot
.62304 .61012 Mdot
.48076 .70417 Mdot
.62404 .75573 Mdot
.65126 .71878 Mdot
.56713 .90915 Mdot
.41574 .44145 Mdot
.51129 .97491 Mdot
.45821 .70695 Mdot
.48905 .96598 Mdot
.37134 .74472 Mdot
.60402 .83403 Mdot
.59582 .87911 Mdot
.63064 .49605 Mdot
.66109 .66549 Mdot
.44819 .7011 Mdot
.41471 .93183 Mdot
.612 .83942 Mdot
.54715 .9416 Mdot
.52 .95709 Mdot
.52886 .25228 Mdot
.37017 .75712 Mdot
.60156 .35764 Mdot
.4836 .69741 Mdot
.48344 .69829 Mdot
.5222 .52754 Mdot
.53765 .28049 Mdot
.36341 .69532 Mdot
.62182 .65532 Mdot
.43936 .66055 Mdot
.63463 .53511 Mdot
.43601 .68815 Mdot
.49009 .71655 Mdot
.4448 .24627 Mdot
.66136 .57109 Mdot
.57516 .36611 Mdot
.63408 .70145 Mdot
.42999 .32447 Mdot
.61631 .6674 Mdot
.57746 .3809 Mdot
.5928 .88435 Mdot
.49145 .71113 Mdot
.63499 .57641 Mdot
.60355 .85983 Mdot
.55009 .2906 Mdot
.54764 .89481 Mdot
.64251 .67875 Mdot
.56811 .82237 Mdot
.45565 .25257 Mdot
.51107 .22797 Mdot
.65667 .52199 Mdot
.42395 .58373 Mdot
.4332 .95002 Mdot
.50918 .99146 Mdot
.41653 .48368 Mdot
.51124 .44235 Mdot
.35578 .47507 Mdot
.59567 .39295 Mdot
.47975 .21225 Mdot
.50553 .23877 Mdot
.65112 .53405 Mdot
.62193 .70277 Mdot
.63174 .62597 Mdot
.42803 .96643 Mdot
.63344 .47247 Mdot
.64485 .68277 Mdot
.58919 .32881 Mdot
.59343 .84965 Mdot
.43064 .63418 Mdot
.56733 .85589 Mdot
.60776 .49634 Mdot
.58753 .32442 Mdot
.57348 .83877 Mdot
.53304 .95554 Mdot
.51582 .62599 Mdot
.4299 .61425 Mdot
.54809 .88232 Mdot
.56144 .30601 Mdot
.51004 .25062 Mdot
.62155 .39752 Mdot
.49552 .38385 Mdot
.57665 .8872 Mdot
.6026 .82607 Mdot
.57954 .33294 Mdot
.4779 .21172 Mdot
.57299 .81695 Mdot
.4813 .70968 Mdot
.58615 .34284 Mdot
.63091 .61037 Mdot
.49326 .23315 Mdot
.62027 .59919 Mdot
.57221 .82815 Mdot
.58098 .364 Mdot
.61425 .76062 Mdot
.62634 .43906 Mdot
.41913 .37542 Mdot
.59364 .3997 Mdot
.62192 .7763 Mdot
.41387 .50301 Mdot
.46496 .19101 Mdot
.57734 .86439 Mdot
.4253 .31613 Mdot
.63246 .56372 Mdot
.63024 .74703 Mdot
.51298 .65096 Mdot
.45378 .24896 Mdot
.55004 .88355 Mdot
.52953 .94442 Mdot
.46237 .19739 Mdot
.52042 .50734 Mdot
.56127 .35813 Mdot
.65714 .66476 Mdot
.54746 .29208 Mdot
.57815 .80241 Mdot
.36627 .69405 Mdot
.56985 .86522 Mdot
.45591 .97868 Mdot
.53308 .91015 Mdot
.51295 .43645 Mdot
.61873 .79444 Mdot
.38938 .8299 Mdot
.66095 .64807 Mdot
.43429 .95097 Mdot
.39078 .07915 Mdot
.58374 .35794 Mdot
.62555 .40634 Mdot
.63572 .61642 Mdot
.58031 .86666 Mdot
.47483 .99566 Mdot
.46033 .2262 Mdot
.56048 .8851 Mdot
.55978 .29944 Mdot
.48995 .68576 Mdot
.65359 .60527 Mdot
.61205 .4593 Mdot
.65103 .62597 Mdot
.55189 .94346 Mdot
.50476 .66466 Mdot
.63304 .59188 Mdot
.61723 .52669 Mdot
.46027 .97573 Mdot
.50194 .67737 Mdot
.55351 .92508 Mdot
.40738 .89967 Mdot
.40406 .91074 Mdot
.42527 .3699 Mdot
.63484 .43645 Mdot
.61986 .44329 Mdot
.55379 .8672 Mdot
.4829 .18704 Mdot
.5141 .62087 Mdot
.51708 .48938 Mdot
.60475 .38886 Mdot
.61143 .84703 Mdot
.52446 .90985 Mdot
.45664 .72898 Mdot
.6527 .60188 Mdot
.47547 .7157 Mdot
.52139 .53885 Mdot
.65632 .53016 Mdot
.63511 .49074 Mdot
.61746 .59241 Mdot
.5479 .26448 Mdot
.54109 .29055 Mdot
.35449 .55863 Mdot
.57666 .35245 Mdot
.61474 .68962 Mdot
.44024 .67958 Mdot
.538 .92565 Mdot
.5146 .26738 Mdot
.62939 .73935 Mdot
.60897 .71069 Mdot
.45595 .73458 Mdot
.57762 .39184 Mdot
.37692 .76771 Mdot
.57004 .90053 Mdot
.63773 .76272 Mdot
.59074 .79903 Mdot
.57075 .31722 Mdot
.61078 .4055 Mdot
.58936 .80545 Mdot
.59038 .36303 Mdot
.5644 .90698 Mdot
.64525 .68313 Mdot
.51398 .96463 Mdot
.54876 .93093 Mdot
.55753 .92641 Mdot
.52055 .5579 Mdot
.59323 .38641 Mdot
.43894 .96083 Mdot
.59201 .86864 Mdot
.52079 .55916 Mdot
.59291 .77563 Mdot
.58996 .41898 Mdot
.63738 .50085 Mdot
.63524 .60506 Mdot
.52644 .9257 Mdot
.65011 .54145 Mdot
.59025 .83354 Mdot
.52417 .90721 Mdot
.59352 .75058 Mdot
.64672 .74388 Mdot
.61604 .70494 Mdot
.44286 .97131 Mdot
.37161 .18578 Mdot
.5122 .92866 Mdot
.63402 .56427 Mdot
.51714 .56012 Mdot
.43444 .96588 Mdot
.58853 .34025 Mdot
.51674 .48594 Mdot
.58223 .89228 Mdot
.64656 .656 Mdot
.52039 .59251 Mdot
.43845 .28064 Mdot
.54528 .2708 Mdot
.48736 .21601 Mdot
.60899 .82175 Mdot
.66252 .62312 Mdot
.39926 .87796 Mdot
.56689 .91001 Mdot
.61521 .48018 Mdot
.35643 .40493 Mdot
.61487 .44645 Mdot
.52591 .26609 Mdot
.50651 .22334 Mdot
.49844 .37876 Mdot
.59838 .86317 Mdot
.54848 .92515 Mdot
.50962 .25554 Mdot
.43127 .65032 Mdot
.41772 .35513 Mdot
.41696 .57678 Mdot
.53673 .95631 Mdot
.50228 .2006 Mdot
.59057 .79294 Mdot
.42088 .56206 Mdot
.46118 .21152 Mdot
.48705 .7068 Mdot
.50933 .21569 Mdot
.61281 .54482 Mdot
.45062 .22825 Mdot
.4387 .65912 Mdot
.51903 .9796 Mdot
.53426 .93453 Mdot
.45623 .40821 Mdot
.62385 .46545 Mdot
.60434 .38199 Mdot
.61239 .65395 Mdot
.59179 .42584 Mdot
.49047 .21391 Mdot
.46054 .9976 Mdot
.39316 .88633 Mdot
.64657 .57209 Mdot
.36906 .21601 Mdot
.65198 .49111 Mdot
.4528 .70841 Mdot
.47178 .97131 Mdot
.42944 .94384 Mdot
.48567 .21964 Mdot
.5965 .73642 Mdot
.35378 .50404 Mdot
.42649 .61787 Mdot
.51916 .59329 Mdot
.54443 .30935 Mdot
.5874 .7945 Mdot
.59512 .42973 Mdot
.36361 .68661 Mdot
.46685 .71994 Mdot
.62052 .54777 Mdot
.61903 .45023 Mdot
.46578 .73878 Mdot
.48846 .69968 Mdot
.41532 .43742 Mdot
.61681 .83588 Mdot
.51493 .63512 Mdot
.63833 .73471 Mdot
.65089 .56455 Mdot
.64149 .55022 Mdot
.62488 .74262 Mdot
.57445 .80569 Mdot
.61327 .45767 Mdot
.42098 .96969 Mdot
.43645 .28637 Mdot
.61267 .84591 Mdot
.54779 .93993 Mdot
.50532 .2559 Mdot
.62787 .77971 Mdot
.58783 .39757 Mdot
.60963 .51354 Mdot
.63364 .73059 Mdot
.63866 .59358 Mdot
.48527 .19959 Mdot
.57598 .38287 Mdot
.61605 .5194 Mdot
.62389 .56995 Mdot
.48027 .35422 Mdot
.62295 .55794 Mdot
.59772 .44013 Mdot
.52402 .51605 Mdot
.44292 .28699 Mdot
.62423 .52746 Mdot
.63133 .48231 Mdot
.50412 .66102 Mdot
.56755 .32714 Mdot
.56417 .88971 Mdot
.49001 .18943 Mdot
.62896 .61355 Mdot
.43687 .25097 Mdot
.53722 .30376 Mdot
.52002 .57321 Mdot
.36191 .26796 Mdot
.51544 .59967 Mdot
.65391 .55357 Mdot
.50609 .94207 Mdot
.58043 .80961 Mdot
.48284 .20364 Mdot
.63058 .74065 Mdot
.56165 .91374 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo0028ooooo`;o
00008_ooool00ol0003oooooooooo`2iooooo`00R?ooool2o`0002;ooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool008Kooooo0_l0000Tooooo`?o0000^Oooool008Kooooo0_l0000T
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o
0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0
^Oooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVY
ooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0^Oooool0087ooooo1_l0
0002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`00
0?oooooooooo00?ooooo0ol0002iooooo`00ROooool01Ol0003ooooooooooooooooo000000kooooo
00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;Wooooo
0029ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2iooooo`00ROooool01Ol@413ooooo
oooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0;Wooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413o
oooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2ioooo
o`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool00ol0
003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/oooo
o`03o`000?oooooooooo0;Wooooo0023ooooo`;o00009oooool00ol0003oooooooooo`2iooooo`00
Poooool2o`0002Oooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Ooo
ool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00POooool2o`0002Wooooo00?o0000oooo
ooooool0^Oooool0087ooooo0_l0000Sooooo`Co00000_ooool00ol0003oooooooooo`2iooooo`00
X?ooool2o`0000Cooooo1?l00002ooooo`03o`000?oooooooooo0;Wooooo002Pooooo`?o00002Ooo
ool00ol0003oooooooooo`2iooooo`00Woooool5o`0000Sooooo00?o0000ooooooooool0^Oooool0
09oooooo1Ol00003ooooo`;o00000oooool3o`000;Wooooo002Qooooo`;o00000_ooool4o`0000?o
oooo0_l0002jooooo`00YOooool4o`0000?ooooo00?o0000ooooooooool0^Oooool00:Oooooo0_l0
0003ooooo`03o`000?oooooooooo0;Wooooo002Oooooo`;o00000oooool3o`0000Gooooo00?o0000
ooooooooool0^Oooool0083ooooo0_l0000Mooooo`;o00000oooool6o`0000;ooooo00?o0000oooo
ool000000_l0002gooooo`00P?ooool2o`0001gooooo0_l00006ooooo`?o00000_ooool00ol0003o
ooooo`000003o`000;Kooooo002Oooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo
00?o0000ooooool000000ol0002fooooo`00X_ooool2o`0000Sooooo1?l0002hooooo`00Voooool2
o`000003ooooool0003o000000?o00002Oooool00ol0003oooooo`000002o`000;Oooooo002Koooo
o`;o000000?oooooo`000?l000000ol00009ooooo`03o`000?oooooooooo00;o0000]oooool00:Wo
oooo0_l000001?oooooo0000o`000?l00006ooooo`;o0000/Oooool00:Wooooo0_l000001?oooooo
0000o`000?l00004ooooo`Co0000/Oooool00:cooooo0ol00004ooooo`;o0000/oooool0097ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo0ol0002iooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0_l00002ob4Q
8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2iooooo`00ROooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@4003ooooo`;o000000?oooooo`000?l000002?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo0;Wooooo002Aooooo`06o`000?oooooooooooooo
ool0003ooooo0_l00003ooooo`?o00001_ooool00omgMgOo<S8booooo`04ooooo`Go00001?ooool2
o`000;7ooooo002Aooooo`06o`000?ooooooooooooooool0003ooooo0_l000001?oooooo0000o`00
0?ooool2o`0000?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`Go00001?ooool2o`0000?o
oooo0_l0002/ooooo`00TOooool01Ol@413ooooooooooooooooo410@00Cooooo0_l00006ooooo`03
o`000?oooooooooo00Oooooo1ol00007ooooo`;o0000[?ooool0097ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooooooo0ol00004oooo
o`;o0000[oooool0097ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool01?l0
003oooooooooooooool2o`0000Gooooo0_l00002ooooo`;o0000Zoooool007kooooo0_l0000Koooo
o`;o00003oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00005ooooo`;o0000Zoooool0
07kooooo0_l0000Kooooo`;o00003oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00005
ooooo`;o0000Zoooool00:cooooo00?o0000ooooooooool03?ooool2o`000:_ooooo002/ooooo`?o
0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool009Oooooo0_l0000Cooooo`03o`000?oo
oooooooo00Wooooo0_l0002^ooooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool02?ooool3
o`000:kooooo002Gooooo`Co00004Oooool00ol0003oooooooooo`08ooooo`Co0000[Oooool009So
oooo0ol0000Aooooo`03o`000?oooooooooo00[ooooo1Ol00003ooooo`;o0000YOooool009Kooooo
0_l0000Dooooo`03o`000?oooooooooo00[ooooo1Ol00003ooooo`;o0000YOooool009Kooooo0_l0
000Dooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o00004?ooool2o`0000?ooooo0_l0002R
ooooo`00[?ooool00ol0003oooooooooo`09ooooo`;o00001?ooool3o`0000?ooooo0_l0002Roooo
o`00UOooool2o`0001Gooooo00?o0000ooooooooool02Oooool2o`0000Cooooo1?l0002Vooooo`00
UOooool2o`0001Gooooo00?o0000ooooooooool02oooool2o`0000Cooooo0_l0002Vooooo`00[?oo
ool00ol0003oooooooooo`0;ooooo`;o0000[?ooool009?ooooo0_l0000Gooooo`03o`000?oooooo
oooo01Oooooo0_l0002Pooooo`00Toooool2o`0001Oooooo00?o0000ooooooooool03oooool2o`00
00?ooooo0_l000000ooooooo0000o`00002Pooooo`00[?ooool00ol0003oooooooooo`0?ooooo`;o
00000oooool2o`000:?ooooo002Dooooo`;o00005_ooool3o`0001Oooooo1?l0002Nooooo`00U?oo
ool2o`0001Kooooo00?o0000ooooooooool03Oooool2o`000004ooooool0003o0000ooooo`;o0000
0_ooool5o`0009gooooo002/ooooo`03o`000?oooooooooo00gooooo0_l000001?oooooo0000o`00
0?ooool2o`0000Gooooo0_l0002Mooooo`00[?ooool00ol0003oooooooooo`0Gooooo`;o0000X?oo
ool00:cooooo00?o0000ooooooooool05oooool2o`000:3ooooo002/ooooo`03o`000?oooooooooo
01[ooooo0_l0002Mooooo`00[?ooool00ol0003oooooooooo`0Iooooo`?o0000WOooool00:cooooo
00?o0000ooooooooool06Oooool2o`0009kooooo002Dooooo`;o00005_ooool00ol0003ooooooooo
o`2iooooo`00U?ooool2o`0001Kooooo0ol0000Fooooo`;o0000XOooool0093ooooo0_l0000Coooo
o`;o00001Oooool00ol0003oooooooooo`0Fooooo`;o0000XOooool0093ooooo0_l0000Cooooo`;o
00001Oooool00ol0003oooooooooo`0Aooooo`;o00001Oooool2o`0000Cooooo0_l0002Iooooo`00
[?ooool00ol0003oooooooooo`0Aooooo`;o00001Oooool2o`0000Cooooo0_l0002Iooooo`00[?oo
ool00ol0003oooooooooo`0Gooooo`;o000000?oooooo`000?l00000WOooool008Wooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`03ob4Q8Ol0003o000000?ooooo1Ol00004ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Eooooo`Co000000?oooooo`000?l00000
WOooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`?o00000oooool01OnHV9So8B4Q
onk^k_ooooooA4A400;ooooo0_l00003ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool05Oooool2o`000:;ooooo0021ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00;o
oooo0_l000000ooooooo0000o`000005ooooo`03oiRHV?lQ8B7ok^k^00?ooooo0_l00004ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool07Oooool2o`0009[ooooo0029ooooo`05o`00
0?ooooooooooooooool000000_ooool3o`0000Sooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo
<S8booooo`04ooooo`?o00007Oooool2o`0009[ooooo0029ooooo`05o`000?ooooooooooooooool0
00000_ooool3o`0000Wooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00?ooooo0ol0000Qooooo`;o0000V?ooool008Wooooo00Go410@oooooooooooooooooa0@4002oooo
o`;o00002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo0ol0000Hoooo
o`?o00001_ooool2o`0009Sooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool2o`00
00Oooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Gooooo0ol0000H
ooooo`?o00000_ooool2o`0000;ooooo0_l0002Hooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001?ooool3o`0001gooooo0_l0
0002ooooo`;o0000V?ooool007cooooo0_l0000^ooooo`03o`000?oooooooooo01Kooooo0_l00007
ooooo`;o0000V?ooool007cooooo0_l0000^ooooo`03o`000?oooooooooo01Kooooo0_l00004oooo
o`;o0000Voooool007cooooo0_l0000^ooooo`03o`000?oooooooooo01[ooooo1?l00007ooooo`;o
0000T_ooool00:cooooo0ol0000Jooooo`?o00002?ooool2o`0009;ooooo002/ooooo`03o`000?oo
oooooooo01_ooooo0_l0002Looooo`00O?ooool2o`0002kooooo00?o0000ooooooooool08Oooool2
o`0000?ooooo0_l0002Aooooo`00O?ooool2o`0001oooooo0_l0000=ooooo`03o`000?oooooooooo
027ooooo0_l00003ooooo`;o0000TOooool009gooooo0_l0000=ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002Aooooo`;o00006Oooool00ol0003ooooooooo
o`0Jooooo`;o0000WOooool0097ooooo0_l0000Iooooo`03o`000?oooooooooo01[ooooo0_l0002M
ooooo`00T_ooool2o`0001Sooooo0ol0000Pooooo`;o0000Uoooool009;ooooo0_l0000Hooooo`03
o`000?oooooooooo01_ooooo0_l00003ooooo`;o0000Uoooool00:cooooo00?o0000ooooooooool0
6oooool3o`0009_ooooo002/ooooo`03o`000?oooooooooo01cooooo0_l0002Kooooo`00T?ooool2
o`0001[ooooo00Co0000oooooooooooooooo0_l0000Vooooo`;o0000S_ooool0093ooooo0_l0000J
ooooo`04o`000?ooooooooooooooo`;o00006_ooool2o`0000Oooooo0_l000000ooooooo0000o`00
002>ooooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool00_l0000Kooooo`;o00001Oooool4
o`00097ooooo002@ooooo`;o00006_ooool00ol0003oooooooooo`02o`00023ooooo1?l0002Coooo
o`00[?ooool00ol0003oooooooooo`0Rooooo`;o0000UOooool00:cooooo0ol0000Tooooo`;o0000
Toooool00:cooooo00?o0000ooooooooool09?ooool4o`00097ooooo002/ooooo`03o`000?oooooo
oooo027ooooo0ol00002ooooo`;o0000TOooool000Wooooo1?l000000ol@413oooooooooo`0Foooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Fooooo`03o`000?oooooo
oooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`?o00001?ooool5o`0000Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Go
oooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1?l0
00000ol@413oooooooooo`0Booooo`002oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8boooo
o`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0
3_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@01oooool00omgMgOo<S8booooo`0Eooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`02o`0000?ooooo0_l00004ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01ooo
ool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03
oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool06Oooool00ol0003oooooooooo`0Dooooo`00
1_l00005ooooo`03o`000?oooooooooo013ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@
41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`05ooooo`Ko00000_ooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo01Sooooo00Go410@oooooooooooooooooa0@4002o`0000Gooooo0ol0
0002ooooo`03oiRHV?l0003o000000Wooooo00?o0000ooooooooool03Oooool01Ol@413ooooooooo
oooooooo410@013ooooo00?o0000ooooooooool03Oooool01Ol@413ooooooooooooooooo410@00go
oooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Co
oooo000;ooooo`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`0Eooooo`03o`000?oooooooooo01Sooooo00Go0000
ooooooooooooooooo`000004ooooo`;o000000Coooooo`000?l0003o00000oooool2o`000003onk^
k_oooooooooo00Gooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000oo
oooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qoooo
ooooool01_ooool00omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo000;ooooo`03
o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003?oo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo00?ooooo0ol000000olb<S;oc<c<ooooo`0Eooooo`03o`000?oooooooooo01So
oooo00Go0000ooooooooooooooooo`000004ooooo`;o00001_ooool2o`000003ogMgMomVIVKooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003?oo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000>ooooo`03
oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Jooooo`03o`000?oooooooooo
01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go410@oooooooooooooooooa0@400>oooo
o`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool04Oooool01?l@413oooooooooooooool2o`0000kooooo00?o
0000ooooooooool00_ooool3o`0001Sooooo0ol0000Hooooo`05oa0@4?ooooooooooooooool@4100
3?ooool2o`000003ooooool0003ooooo00?ooooo00?o0000ooooooooool04Oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@
00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`04ogMgMonHV9SooooooiRHV0;o0000
2_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool2o`0000?ooooo00Go0000okZj
^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Co
oooo0009ooooo`03oeEEEOmVIVKo000001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go
00001?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00004?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00005ooo
ool00ol0003oooooooooo`0Hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool2o`0000?ooooo
0ol000000olQ8B7oc<c<ooooo`03ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000Ioooo
o`03oeEEEOmVIVKo000001Kooooo002@ooooo`;o00006_ooool00ol0003oooooooooo`02ooooo`;o
00009?ooool2o`0008oooooo002@ooooo`;o00006_ooool00ol0003oooooooooo`02ooooo`;o0000
]Oooool00:cooooo00?o0000ooooooooool00_ooool2o`00023ooooo0_l00003ooooo`;o00001?oo
ool2o`0007gooooo0_l00002ooooo`;o00001Oooool00:cooooo00?o0000ooooooooool09?ooool2
o`0000?ooooo0_l00004ooooo`;o0000OOooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Gooooo
002/ooooo`03o`000?oooooooooo023ooooo0_l00006ooooo`;o0000QOooool01?oMgMgo0000oa0@
4?o<c<`6ooooo`001oooooooo`0004co00003?ooool01?o^k^ko8B4Qoa0@4?o^k^h6ooooo`001ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oo
oooooooo00Gooooo00Co0000oooooooooooooooo0_l00003ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
0ol00007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Co000000?oooooo`000?ooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00[ooooo00Co8B4QogMgMomgMgOo<S8b1_ooool000Oooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo
0_l00006ooooo`03o`000?oooooooooo00Wooooo0_l0000Kooooo`03o`000?oooooooooo00?ooooo
0_l0000Rooooo`03o`000?oooooooooo00?ooooo0ol0000Pooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`09ooooo`;o00000_ooool2o`0000Gooooo
002/ooooo`03o`000?oooooooooo00?ooooo0_l0000Xooooo`?o0000ROooool00:cooooo00?o0000
ooooooooool08Oooool2o`0000Kooooo0_l0002>ooooo`00[?ooool00ol0003oooooooooo`04oooo
o`;o00006oooool2o`0000Kooooo0_l0002>ooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o
00007Oooool2o`0009Cooooo002/ooooo`03o`000?oooooooooo00Cooooo0_l0000Mooooo`;o0000
0_ooool3o`0000Kooooo0_l00027ooooo`00[?ooool3o`0002Oooooo0ol00006ooooo`;o0000Qooo
ool00:cooooo00?o0000ooooooooool01?ooool2o`0001gooooo0_l000000ooooooo0000o`00002A
ooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o00007Oooool2o`000003ooooool0003o0000
00Sooooo0_l00027ooooo`00[?ooool00ol0003oooooooooo`02ooooo`;o0000:_ooool4o`0008Oo
oooo002/ooooo`03o`000?oooooooooo00;ooooo0_l0000Uooooo`;o00000oooool2o`0008Wooooo
002/ooooo`03o`000?oooooooooo00Cooooo0_l0000Oooooo`;o00000_ooool2o`0008kooooo002/
ooooo`03o`000?oooooooooo00Cooooo0_l0000Oooooo`;o00001oooool2o`0008Wooooo002/oooo
o`03o`000?oooooooooo02;ooooo0_l0000:ooooo`;o0000ROooool00:cooooo00?o0000oooooooo
ool08_ooool4o`0009?ooooo002Aooooo`;o00006Oooool3o`0002Cooooo0_l00005ooooo`;o0000
S?ooool0097ooooo0_l0000Iooooo`03o`000?oooooooooo02_ooooo0_l00002ooooo`;o0000R?oo
ool007cooooo0_l0000^ooooo`03o`000?oooooooooo00?ooooo0_l0000Pooooo`;o00002?ooool2
o`0008Sooooo001looooo`;o00004oooool2o`0001Wooooo00?o0000ooooooooool00_ooool3o`00
023ooooo0_l0002Booooo`00TOooool2o`0001Wooooo00?o0000ooooooooool00_ooool3o`0002?o
oooo0ol00003ooooo`;o0000ROooool00:cooooo00?o0000ooooooooool0:?ooool3o`0000?ooooo
0_l00029ooooo`00[?ooool00ol0003oooooooooo`0Uooooo`;o00002oooool2o`0008Gooooo002/
ooooo`03o`000?oooooooooo00?ooooo0_l0000Pooooo`;o00001_ooool2o`0000?ooooo0_l00025
ooooo`00T?ooool2o`0001[ooooo0ol00003ooooo`;o00009?ooool2o`0000;ooooo0ol00029oooo
o`00T?ooool2o`0001[ooooo00?o0000ooooooooool0:Oooool2o`0000?ooooo0_l00029ooooo`00
[?ooool00ol0003oooooooooo`0booooo`?o0000Q?ooool009;ooooo0_l0000Hooooo`03o`000?oo
oooooooo02[ooooo0_l00006ooooo`?o0000Q?ooool009;ooooo0_l0000Hooooo`03o`000?oooooo
oooo02[ooooo0_l0002=ooooo`00[?ooool00ol0003oooooooooo`0Xooooo`;o0000Soooool00:co
oooo00?o0000ooooooooool00oooool2o`0001kooooo0_l00003ooooo`Co00001_ooool2o`0008Go
oooo001mooooo`;o0000;Oooool00ol0003oooooooooo`03ooooo`;o00007_ooool2o`0000Gooooo
0_l00006ooooo`;o0000QOooool007gooooo0_l0000]ooooo`?o00000_ooool2o`00023ooooo0_l0
002Cooooo`00[?ooool00ol0003oooooooooo`02ooooo`;o00008?ooool4o`0000Oooooo1?l00026
ooooo`00[?ooool00ol0003oooooooooo`0Vooooo`;o000000?oooooo`000?l000001?ooool4o`00
08Kooooo002/ooooo`03o`000?oooooooooo02Gooooo0_l000001?oooooo0000o`000?l00004oooo
o`;o0000R?ooool00:cooooo00?o0000ooooooooool09Oooool6o`0000Kooooo0_l00026ooooo`00
U?ooool2o`0001Kooooo00?o0000ooooooooool09oooool4o`0000Kooooo0_l00026ooooo`00ROoo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0ol00003ooooo`Go00001?ooool01Om4A4Co0000
o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool00oooool2o`0002Cooooo0_l0002>ooooo`00
ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l00004ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@01oooool00omgMgOo<S8booooo`04ooooo`04o`000?ooooooooooooooo`Co0000]?ooool0
08Wooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000
ooooooooool00oooool3o`000003ooooool0003o000002oooooo0_l00025ooooo`00ROooool01Ol0
003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo00;ooooo0_l0000Tooooo`;o00001?ooool2o`0000;ooooo0_l00025
ooooo`00ROooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool00_ooool2o`0002Cooooo0_l0
0004ooooo`;o0000ROooool008Wooooo00Go410@oooooooooooooooooa0@4004ooooo`;o000000?o
ooooo`000?l000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0^Oooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`;o000000?o
ooooo`000?l000000_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool0
1oooool01?l0003oooooooooooooool2o`0002Kooooo0_l0002>ooooo`00ROooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool01?l0
003oooooooooooooool2o`0002Cooooo1?l0002>ooooo`00[?ooool00ol0003oooooooooo`0Woooo
o`;o0000T?ooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
<_ooool2o`0008Gooooo002Eooooo`;o00005Oooool3o`000003ooooool0003o000002oooooo0_l0
0025ooooo`00UOooool2o`0001Gooooo00Co0000oooooooooooooooo0_l0000Oooooo`;o000000?o
ooooo`000?l000001_ooool2o`0008[ooooo002/ooooo`03o`000?oooooooooo02;ooooo2Ol00002
ooooo`;o0000R_ooool009Oooooo0ol0000Booooo`?o00009?ooool2o`000003ooooool0003o0000
00;o0000S_ooool009Oooooo0ol0000Booooo`?o0000<?ooool2o`000003ooooool0003o000008Co
oooo002/ooooo`?o00008oooool2o`0000Oooooo0_l00002ooooo`Go0000Q?ooool00:cooooo00?o
0000ooooooooool08oooool2o`0000Oooooo0_l00004ooooo`;o0000QOooool00:cooooo00?o0000
ooooooooool0<Oooool2o`0008Kooooo002/ooooo`?o0000<Oooool2o`0008Kooooo002Hooooo`;o
00004_ooool2o`0002gooooo0_l0002;ooooo`00Uoooool3o`0001;ooooo0_l0000Zooooo`Ko0000
R_ooool009Oooooo0_l0000?ooooo`;o00000_ooool00ol0003oooooooooo`0Yooooo`Ko0000R_oo
ool007oooooo0_l0000Eooooo`;o00004?ooool2o`0000;ooooo00?o0000ooooooooool0<Oooool2
o`0008Kooooo001oooooo`;o00005Oooool2o`0001Cooooo00?o0000ooooooooool08_ooool2o`00
0003ooooool0003o000000[ooooo0_l00026ooooo`00O_ooool3o`0002_ooooo00?o0000oooooooo
ool08_ooool2o`000003ooooool0003o000009;ooooo001nooooo`?o00009Oooool2o`0000Cooooo
00?o0000ooooooooool08Oooool2o`0000Kooooo0_l0002>ooooo`00V_ooool2o`0000[ooooo1?l0
0002ooooo`?o00008Oooool2o`0000Kooooo0_l0002>ooooo`00V_ooool2o`0000Wooooo0_l00000
0ooooooo0000o`000002ooooo`03o`000?oooooooooo02Gooooo0_l00002ooooo`;o000000?ooooo
o`000?l00000Roooool009[ooooo0_l00002ooooo`;o00001Oooool4o`0000?ooooo00?o0000oooo
ooooool08oooool4o`0000Gooooo1?l00029ooooo`00W?ooool6o`0000?ooooo1?l00003ooooo`03
o`000?oooooooooo02?ooooo0_l00002ooooo`;o00001?ooool3o`0008Wooooo002Looooo`;o0000
0_ooool2o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?ooool08_ooool2o`0000Cooooo
0_l0002@ooooo`00Xoooool2o`0000?ooooo0ol000000ooooooo0000ooooo`0Rooooo`;o0000U_oo
ool00:?ooooo0_l00003ooooo`;o00000_ooool00ol0003oooooooooo`0^ooooo`;o0000ROooool0
0:7ooooo0_l00009ooooo`03o`000?oooooooooo02kooooo0_l00029ooooo`00POooool2o`0001[o
oooo0_l00002ooooo`;o00002Oooool3o`000;Wooooo0021ooooo`;o00006_ooool2o`0000gooooo
00?o0000ooooooooool0^Oooool009gooooo0_l0000=ooooo`03o`000?oooooooooo02Wooooo0_l0
00000ooooooo0000o`00002;ooooo`00WOooool3o`0000cooooo00?o0000ooooooooool0:Oooool5
o`0008_ooooo002Mooooo`?o00003?ooool00ol0003oooooooooo`0Looooo`;o00002Oooool2o`00
0004ooooool0003o0000ooooo`;o0000R_ooool00:3ooooo0_l0000:ooooo`03o`000?oooooooooo
01cooooo0_l00009ooooo`?o00000oooool2o`0008[ooooo002Aooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@?ooooo0_l000001Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool09_ooool4o`0008oooooo0021ooooo`;o00003_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool07Oooool2
o`0000Oooooo0_l00005ooooo`;o0000R_ooool0087ooooo0_l0000>ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01gooooo0_l00009
ooooo`;o00000oooool2o`0008[ooooo002Aooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`04ooooo`?o00006oooool2o`0000_ooooo0_l0002?ooooo`00TOooool01Ol0
003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oo
oooooooo01_ooooo0_l00009ooooo`;o00000_ooool2o`0008gooooo0021ooooo`;o00003_ooool0
1Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Vooooo`?o000000?oooooo`000?l00000SOooool0087ooooo0_l0000>ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02;ooooo0_l0
0003ooooo`;o0000T?ooool0097ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_oo
ool00ol0003oooooooooo`0Rooooo`;o00001_ooool2o`0008gooooo0023ooooo`;o00009oooool0
0ol0003oooooooooo`0Zooooo`;o0000SOooool008?ooooo0_l0000Wooooo`03o`000?oooooooooo
01[ooooo0_l0002Mooooo`00[?ooool00ol0003oooooooooo`0Jooooo`;o00002?ooool2o`0009?o
oooo002/ooooo`?o00006_ooool3o`0000Oooooo0ol0002Booooo`00[?ooool00ol0003ooooooooo
o`0Jooooo`?o00002?ooool4o`00093ooooo002/ooooo`03o`000?oooooooooo02Oooooo0_l0002@
ooooo`00P_ooool2o`0002Sooooo00?o0000ooooooooool07oooool2o`0000?ooooo0_l0002Coooo
o`00P_ooool2o`0002Sooooo00?o0000ooooooooool07oooool2o`0000?ooooo0_l0002Cooooo`00
Poooool2o`0002Oooooo00?o0000ooooooooool0^Oooool008?ooooo0_l0000Wooooo`03o`000?oo
oooooooo01Sooooo1?l00005ooooo`;o000000?oooooo`000?l00000Toooool00:cooooo00?o0000
ooooooooool06?ooool4o`0000Gooooo0_l000000ooooooo0000o`00002Cooooo`00[?ooool3o`00
01_ooooo0_l0002Looooo`00[?ooool00ol0003oooooooooo`0Fooooo`;o00000oooool2o`0009co
oooo002/ooooo`03o`000?oooooooooo01Gooooo0ol00002ooooo`;o0000WOooool00:cooooo00?o
0000ooooooooool05Oooool7o`0009gooooo002/ooooo`03o`000?oooooooooo01Oooooo0ol0002O
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0Eooooo`;o
00003Oooool2o`0009?ooooo002/ooooo`03o`000?oooooooooo01?ooooo1?l000000ooooooo0000
o`000007ooooo`;o000000?oooooo`000?l00000Toooool00:cooooo0ol0000Cooooo`Oo00001ooo
ool2o`0009Kooooo002/ooooo`03o`000?oooooooooo01Cooooo1_l00004ooooo`;o00000oooool4
o`0009;ooooo0025ooooo`Co00008oooool00ol0003oooooooooo`0Dooooo`;o00000_ooool2o`00
00Cooooo0_l00003ooooo`Co0000T_ooool008Gooooo1?l0000Sooooo`03o`000?oooooooooo01[o
oooo1ol000000ooooooo0000o`00002Eooooo`00[?ooool00ol0003oooooooooo`0Jooooo`Co0000
00Coooooo`000?l0003ooooo0ol0002Dooooo`00[?ooool00ol0003oooooooooo`0Eooooo`;o0000
2?ooool6o`0009Cooooo002/ooooo`03o`000?oooooooooo01Gooooo1?l00007ooooo`Co0000UOoo
ool00:cooooo00?o0000ooooooooool05oooool2o`0000Wooooo0_l0002Eooooo`00[?ooool00ol0
003oooooooooo`0Kooooo`;o00001?ooool3o`0009Gooooo002/ooooo`?o00006Oooool4o`0000Co
oooo0_l0002Fooooo`00[?ooool00ol0003oooooooooo`0Cooooo`;o00001?ooool2o`000003oooo
ool0003o000009_ooooo002/ooooo`03o`000?oooooooooo01?ooooo0_l00007ooooo`Co0000VOoo
ool00:cooooo00?o0000ooooooooool03oooool2o`0000gooooo0ol0002Hooooo`00[?ooool00ol0
003oooooooooo`0?ooooo`;o00001Oooool2o`0000Gooooo1?l0002Hooooo`00ROooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00kooooo0_l00004ooooo`Go00001?ooool2
o`0009[ooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEE
ojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00kooooo0_l00000
1?oooooo0000o`000?ooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o0000V?oo
ool008Wooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`;o00002?ooool2o`0000;ooooo0_l0
002Hooooo`00ROooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_oo
ool00omgMgOo<S8booooo`04ooooo`?o0000^Oooool008Wooooo0ol000000ooooooo0000ooooo`0=
ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oo
oooooooo01cooooo0_l0002Kooooo`00ROooool01Ol@413o0000o`000?oooooo410@00kooooo00?o
ZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo0_l0
000;ooooo`;o000000?oooooo`000?l00000Voooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00cooooo0ol00002ooooo`;o00001_ooool4o`0009cooooo0028ooooo`;o000000Co
<S8bo`000?lb<S;ok^k^2oooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo00gooooo
0_l00002ooooo`?o00000_ooool2o`0000?ooooo0_l0002Looooo`00R?ooool2o`0002;ooooo00?o
0000ooooooooool04Oooool3o`0000;ooooo1?l0002Oooooo`00[?ooool00ol0003oooooooooo`0<
ooooo`;o00001?ooool2o`0000Cooooo0_l0002Oooooo`00[?ooool00ol0003oooooooooo`0<oooo
o`;o00001?ooool2o`000:Gooooo002=ooooo`;o00007Oooool3o`0000kooooo0_l00002ooooo`Co
0000Xoooool008gooooo0_l0000Mooooo`03o`000?oooooooooo00kooooo0_l00004ooooo`;o0000
Xoooool00:cooooo00?o0000ooooooooool01Oooool2o`0000_ooooo0_l0002Uooooo`00Soooool2
o`0001_ooooo00?o0000ooooooooool01Oooool4o`0000Wooooo0ol0002Tooooo`00S?ooool2o`00
0003ooooool0003o000001_ooooo00?o0000ooooooooool01Oooool4o`0000[ooooo0_l0002Toooo
o`00S?ooool2o`0001kooooo00?o0000ooooooooool01Oooool2o`0000[ooooo0_l0002Vooooo`00
[?ooool00ol0003oooooooooo`08ooooo`;o00001oooool2o`000:Kooooo002/ooooo`03o`000?oo
oooooooo00Sooooo0_l00003ooooo`;o0000Z_ooool00:cooooo0ol0000=ooooo`?o0000ZOooool0
0:cooooo00?o0000ooooooooool01Oooool2o`0000;ooooo0_l00002ooooo`Go0000Yoooool00:co
oooo00Co0000oooooooooooooooo0_l00002ooooo`Ko00000_ooool2o`000003ooooool0003o0000
0:Oooooo002?ooooo`;o00006oooool01?l0003oooooooooooooool2o`0000Cooooo0ol00003oooo
o`;o0000Z_ooool008oooooo0_l0000Kooooo`03o`000?oooooooooo00Sooooo0_l0002_ooooo`00
[?ooool00ol0003oooooooooo`03ooooo`;o00001oooool2o`000003ooooool0003o00000:Sooooo
002Dooooo`;o00005_ooool01?l0003oooooo`000?l00002ooooo`Co00001Oooool5o`000:Sooooo
002Dooooo`;o00005_ooool01?l0003oooooo`000?l00004ooooo`?o00001?ooool4o`000:Wooooo
002Dooooo`;o00005_ooool00ol0003oooooooooo`03ooooo`;o000000?oooooo`000?l00000/Ooo
ool009Kooooo0_l0000Dooooo`?o00000oooool2o`000;Cooooo002Eooooo`?o00005?ooool00ol0
003oooooooooo`07ooooo`;o0000/?ooool009Gooooo0_l0000Eooooo`03o`000?oooooooooo00?o
oooo0ol000000ooooooo0000o`000002o`000:kooooo002Gooooo`;o00004oooool00ol0003ooooo
ooooo`03ooooo`?o00000oooool2o`000:kooooo002Gooooo`;o00004oooool01?l0003ooooooooo
ooooool2o`000;Kooooo002Dooooo`Co00004?ooool2o`0000;ooooo00?o0000ooooooooool00ol0
002fooooo`00TOooool2o`000003ooooool0003o000000;o00004?ooool2o`0000;ooooo00?o0000
ooooooooool00_l0002gooooo`00TOooool2o`0000Kooooo0_l00007ooooo`;o00002?ooool00ol0
003oooooooooo`02o`000;Oooooo002Iooooo`Co000000?oooooo`000?l000001?l00008ooooo`Go
0000]oooool009_ooooo1ol0000:ooooo`03o`000?oooooooooo00;o000000?oooooo`000?l00000
]?ooool009gooooo0_l0000=ooooo`03o`000?oooooooooo00?ooooo0_l0002dooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`02o`000;Oooooo002Iooooo`;o00001oooool4o`000003oa0@4?oooooooooo00?ooooo
00?o0000ooooooooool00_l0002gooooo`00VOooool2o`0000Cooooo0_l00002ooooo`;o00001ooo
ool00ol0003oooooooooo`2iooooo`00Woooool2o`0000;ooooo0_l00007ooooo`?o0000^Oooool0
0:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo
00?o0000ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:;ooooo00?oEEEE
ofIVI_l00000`oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00:[ooooo00Co410@o`000?l0003o0000^_ooool00:_ooooo00?o0000ooooooooool0^_ooool0
0:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00Ko0000ogMgMol0003o0000oeEEEOo^k^jg
ooooo`00Zoooool01_l0003oEEEEonk^k_ooooooMgMgoeEEEKOooooo002[ooooo`03o`000?o^k^ko
oooo00;ooooo00?o0000ooooooooool0]Oooool00:_ooooo00?o0000onk^k_ooool00_ooool00ol0
003oooooooooo`2eooooo`00Zoooool01_l0003oEEEEonk^k_ooooooMgMgofIVI[Oooooo002Zoooo
o`03oa0@4?l0003oMgMg00;o000000?oIVIVonk^k_ooool0]_ooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.63237 .38421 Mdot
.64118 .37689 Mdot
.44832 .56556 Mdot
.46991 .75186 Mdot
.40657 .41693 Mdot
.59952 .31114 Mdot
.48976 .33955 Mdot
.71356 .62803 Mdot
.65411 .73835 Mdot
.4391 .72662 Mdot
.41631 .61142 Mdot
.68021 .72249 Mdot
.65568 .38179 Mdot
.46165 .77932 Mdot
.6034 .84803 Mdot
.46938 .76326 Mdot
.55884 .26829 Mdot
.65618 .38068 Mdot
.40985 .58586 Mdot
.68912 .46384 Mdot
.66648 .48078 Mdot
.65661 .45805 Mdot
.65508 .54581 Mdot
.66289 .41304 Mdot
.60834 .85119 Mdot
.41193 .31647 Mdot
.4161 .38782 Mdot
.41016 .42318 Mdot
.6908 .50663 Mdot
.65066 .43644 Mdot
.65948 .57701 Mdot
.6775 .6892 Mdot
.68381 .69766 Mdot
.59219 .34676 Mdot
.57004 .26742 Mdot
.66659 .6104 Mdot
.67839 .64378 Mdot
.41531 .37578 Mdot
.67316 .62242 Mdot
.7002 .68241 Mdot
.66088 .77394 Mdot
.57626 .28946 Mdot
.59666 .32145 Mdot
.61254 .3052 Mdot
.60807 .30519 Mdot
.40644 .3891 Mdot
.41516 .58038 Mdot
.69427 .62981 Mdot
.44483 .18145 Mdot
.67933 .58551 Mdot
.68689 .6509 Mdot
.68902 .57349 Mdot
.5996 .34085 Mdot
.56852 .25485 Mdot
.66336 .72979 Mdot
.70489 .65602 Mdot
.53693 .22289 Mdot
.68831 .63213 Mdot
.60473 .29923 Mdot
.42011 .28544 Mdot
.62392 .85521 Mdot
.66112 .66073 Mdot
.53358 .60484 Mdot
.62445 .80413 Mdot
.68097 .68696 Mdot
.42795 .67797 Mdot
.43606 .69251 Mdot
.40897 .5358 Mdot
.66848 .45304 Mdot
.48038 .13873 Mdot
.4895 .32443 Mdot
.41823 .60808 Mdot
.44197 .72932 Mdot
.66077 .66164 Mdot
.44475 .44365 Mdot
.49236 .18438 Mdot
.6903 .55618 Mdot
.54497 .26487 Mdot
.66242 .59472 Mdot
.65154 .45752 Mdot
.4564 .7349 Mdot
.56811 .268 Mdot
.70759 .63413 Mdot
.51555 .71088 Mdot
.40632 .41748 Mdot
.45238 .19983 Mdot
.50606 .17207 Mdot
.43005 .6641 Mdot
.59233 .87242 Mdot
.52132 .99552 Mdot
.53568 .61055 Mdot
.41156 .34671 Mdot
.52868 .63294 Mdot
.56327 .95127 Mdot
.45991 .77672 Mdot
.66 .71653 Mdot
.46812 .14319 Mdot
.63853 .40948 Mdot
.47157 .14637 Mdot
.65701 .76504 Mdot
.62378 .33484 Mdot
.67254 .50768 Mdot
.59298 .34589 Mdot
.51516 .17877 Mdot
.40988 .59689 Mdot
.53651 .60747 Mdot
.66947 .48094 Mdot
.46122 .77575 Mdot
.49838 .73182 Mdot
.67224 .70015 Mdot
.68473 .5041 Mdot
.52527 .4179 Mdot
.44359 .20552 Mdot
.70709 .61946 Mdot
.69968 .63697 Mdot
.65006 .71199 Mdot
.65915 .40226 Mdot
.64912 .81484 Mdot
.65582 .56918 Mdot
.69213 .48661 Mdot
.66935 .4662 Mdot
.45172 .73134 Mdot
.68374 .53484 Mdot
.57287 .93711 Mdot
.64793 .49623 Mdot
.52841 .56906 Mdot
.65916 .48967 Mdot
.64402 .438 Mdot
.66487 .75643 Mdot
.58316 .26688 Mdot
.59893 .32164 Mdot
.69397 .50739 Mdot
.69898 .55347 Mdot
.68686 .53087 Mdot
.41647 .5845 Mdot
.66379 .74308 Mdot
.61975 .82646 Mdot
.54812 .9507 Mdot
.52465 .66079 Mdot
.41163 .60095 Mdot
.55456 .25848 Mdot
.68743 .47416 Mdot
.70735 .62868 Mdot
.40718 .97296 Mdot
.44545 .22912 Mdot
.44738 .20617 Mdot
.69268 .73967 Mdot
.45562 .15705 Mdot
.42061 .66755 Mdot
.66042 .3943 Mdot
.48276 .31716 Mdot
.62629 .40172 Mdot
.68883 .5945 Mdot
.67389 .62587 Mdot
.69558 .65463 Mdot
.66951 .66852 Mdot
.69166 .58417 Mdot
.42253 .2529 Mdot
.69393 .52896 Mdot
.71199 .67001 Mdot
.66002 .62336 Mdot
.6148 .39504 Mdot
.64237 .45759 Mdot
.70349 .63876 Mdot
.67472 .49658 Mdot
.40891 .52075 Mdot
.69934 .53508 Mdot
.66687 .62475 Mdot
.48087 .74041 Mdot
.41207 .42142 Mdot
.42959 .25895 Mdot
.4258 .28886 Mdot
.65861 .74898 Mdot
.56178 .95155 Mdot
.62709 .41012 Mdot
.52932 .52295 Mdot
.68633 .55573 Mdot
.69877 .51878 Mdot
.69079 .70915 Mdot
.47504 .77141 Mdot
.66125 .77491 Mdot
.5282 .58811 Mdot
.63646 .76857 Mdot
.55299 .95751 Mdot
.69763 .63403 Mdot
.70746 .67911 Mdot
.58906 .29605 Mdot
.65229 .80568 Mdot
.68729 .46549 Mdot
.52756 .62146 Mdot
.59935 .88382 Mdot
.70777 .63942 Mdot
.68379 .7416 Mdot
.66284 .75709 Mdot
.41622 .31662 Mdot
.55628 .96594 Mdot
.50462 .15764 Mdot
.52782 .51157 Mdot
.52808 .51267 Mdot
.49326 .33031 Mdot
.42633 .27427 Mdot
.54283 .98151 Mdot
.64395 .45532 Mdot
.51855 .64187 Mdot
.60867 .33511 Mdot
.52613 .66489 Mdot
.5385 .5212 Mdot
.42614 .68677 Mdot
.6498 .37109 Mdot
.48181 .17648 Mdot
.67466 .50145 Mdot
.44642 .73449 Mdot
.64326 .4674 Mdot
.48985 .1842 Mdot
.70654 .68435 Mdot
.53728 .51468 Mdot
.62556 .37641 Mdot
.70748 .65983 Mdot
.43559 .22546 Mdot
.66556 .69481 Mdot
.67401 .47875 Mdot
.65706 .62237 Mdot
.42517 .63801 Mdot
.40878 .40068 Mdot
.62547 .32199 Mdot
.50433 .70567 Mdot
.60649 .8442 Mdot
.66576 .79146 Mdot
.48409 .75884 Mdot
.45808 .3539 Mdot
.51285 .19295 Mdot
.41115 .54153 Mdot
.63924 .82686 Mdot
.41162 .42298 Mdot
.62473 .33405 Mdot
.66304 .50277 Mdot
.64212 .42597 Mdot
.61145 .87113 Mdot
.58243 .27247 Mdot
.67795 .48277 Mdot
.4809 .13903 Mdot
.69329 .64965 Mdot
.51415 .67523 Mdot
.66969 .65589 Mdot
.5663 .29634 Mdot
.47759 .13844 Mdot
.66899 .63877 Mdot
.67526 .75554 Mdot
.52621 .42599 Mdot
.50979 .67734 Mdot
.66102 .68232 Mdot
.44817 .18827 Mdot
.41385 .40033 Mdot
.54056 .19752 Mdot
.4452 .43552 Mdot
.69153 .6872 Mdot
.69303 .62607 Mdot
.47326 .15375 Mdot
.41144 .54969 Mdot
.65977 .61695 Mdot
.53154 .52692 Mdot
.48341 .15081 Mdot
.63506 .41037 Mdot
.41279 .47803 Mdot
.61994 .39919 Mdot
.66347 .62815 Mdot
.48666 .16946 Mdot
.67849 .56062 Mdot
.56197 .23906 Mdot
.45989 .77091 Mdot
.51352 .1997 Mdot
.69244 .5763 Mdot
.48888 .76627 Mdot
.40971 .61067 Mdot
.6831 .66439 Mdot
.44561 .75677 Mdot
.61795 .36372 Mdot
.68905 .54703 Mdot
.53336 .45096 Mdot
.42479 .64697 Mdot
.66346 .68355 Mdot
.6673 .74442 Mdot
.41167 .62061 Mdot
.48385 .32279 Mdot
.46595 .19625 Mdot
.68305 .46476 Mdot
.43447 .23479 Mdot
.65912 .60241 Mdot
.54192 .96869 Mdot
.67594 .66522 Mdot
.62224 .81888 Mdot
.65714 .71015 Mdot
.45718 .3479 Mdot
.6965 .59444 Mdot
.5716 .91396 Mdot
.68018 .44807 Mdot
.60696 .84214 Mdot
.40134 .95877 Mdot
.48699 .16303 Mdot
.54808 .20634 Mdot
.64229 .41642 Mdot
.68697 .66666 Mdot
.63801 .80849 Mdot
.4184 .62331 Mdot
.67452 .6851 Mdot
.4448 .19297 Mdot
.5264 .49139 Mdot
.65569 .40527 Mdot
.55577 .2593 Mdot
.66142 .42597 Mdot
.68927 .74346 Mdot
.53062 .46466 Mdot
.6298 .39188 Mdot
.5879 .32669 Mdot
.62285 .80872 Mdot
.53288 .47737 Mdot
.68354 .72508 Mdot
.58959 .88613 Mdot
.59314 .90462 Mdot
.45736 .74529 Mdot
.56942 .23645 Mdot
.55718 .24329 Mdot
.66067 .6672 Mdot
.40497 .53322 Mdot
.52245 .42087 Mdot
.47481 .32768 Mdot
.5203 .18886 Mdot
.71025 .64703 Mdot
.64841 .70985 Mdot
.53502 .60792 Mdot
.65346 .40188 Mdot
.53207 .5443 Mdot
.49694 .33945 Mdot
.62838 .33016 Mdot
.5914 .29074 Mdot
.61442 .39241 Mdot
.42684 .23639 Mdot
.43063 .259 Mdot
.47798 .1672 Mdot
.65059 .48962 Mdot
.52314 .64412 Mdot
.66826 .72565 Mdot
.4176 .37628 Mdot
.68513 .53935 Mdot
.65324 .51069 Mdot
.53679 .61402 Mdot
.49437 .19288 Mdot
.55758 .94045 Mdot
.69025 .70053 Mdot
.70282 .56272 Mdot
.67035 .59903 Mdot
.45956 .16551 Mdot
.53298 .2055 Mdot
.67154 .60545 Mdot
.49559 .16361 Mdot
.68719 .70698 Mdot
.62692 .86505 Mdot
.6785 .48313 Mdot
.65983 .76463 Mdot
.68113 .73093 Mdot
.68809 .72641 Mdot
.50371 .3579 Mdot
.5078 .18641 Mdot
.61114 .83873 Mdot
.69947 .66864 Mdot
.50446 .35916 Mdot
.66317 .57563 Mdot
.51755 .21898 Mdot
.59772 .30085 Mdot
.63726 .40506 Mdot
.65672 .7257 Mdot
.62669 .34145 Mdot
.68367 .63354 Mdot
.64706 .70721 Mdot
.65376 .55058 Mdot
.70428 .54388 Mdot
.65801 .50494 Mdot
.61566 .83858 Mdot
.64366 .72866 Mdot
.61973 .36427 Mdot
.50118 .36012 Mdot
.61212 .85401 Mdot
.48473 .14693 Mdot
.47344 .32856 Mdot
.69914 .69228 Mdot
.66896 .456 Mdot
.51739 .39251 Mdot
.43502 .70706 Mdot
.42725 .24561 Mdot
.41033 .50749 Mdot
.69769 .62175 Mdot
.67177 .42312 Mdot
.58381 .90158 Mdot
.6909 .71001 Mdot
.56728 .28018 Mdot
.55345 .24645 Mdot
.41886 .32654 Mdot
.40812 .42201 Mdot
.44346 .4239 Mdot
.70365 .66317 Mdot
.67854 .72515 Mdot
.41496 .40115 Mdot
.51778 .67482 Mdot
.45577 .78145 Mdot
.50432 .73756 Mdot
.67925 .75631 Mdot
.40377 .44561 Mdot
.66774 .59294 Mdot
.50026 .72287 Mdot
.41501 .62274 Mdot
.53294 .51518 Mdot
.40617 .4111 Mdot
.59074 .34482 Mdot
.42095 .66522 Mdot
.51834 .64436 Mdot
.67087 .7796 Mdot
.66807 .73453 Mdot
.45902 .60181 Mdot
.57003 .26545 Mdot
.51713 .18199 Mdot
.63397 .45395 Mdot
.52212 .22584 Mdot
.4092 .49437 Mdot
.63122 .82875 Mdot
.58688 .92874 Mdot
.63541 .37209 Mdot
.60842 .29111 Mdot
.52909 .60822 Mdot
.62675 .78826 Mdot
.60397 .84934 Mdot
.41149 .51409 Mdot
.65106 .53642 Mdot
.51135 .69266 Mdot
.51648 .39329 Mdot
.43774 .24405 Mdot
.66519 .5945 Mdot
.52701 .22973 Mdot
.54075 .97928 Mdot
.53231 .56997 Mdot
.59963 .34777 Mdot
.55912 .25023 Mdot
.53852 .5877 Mdot
.53096 .50658 Mdot
.47425 .77413 Mdot
.71116 .63588 Mdot
.52898 .43512 Mdot
.69221 .53471 Mdot
.63671 .36455 Mdot
.62157 .35022 Mdot
.68192 .54262 Mdot
.65672 .60569 Mdot
.55633 .25767 Mdot
.61189 .89318 Mdot
.4367 .71453 Mdot
.71103 .64591 Mdot
.68376 .73993 Mdot
.4154 .4202 Mdot
.69976 .57971 Mdot
.50686 .19757 Mdot
.57505 .31354 Mdot
.68588 .53059 Mdot
.6361 .39358 Mdot
.40719 .52015 Mdot
.48918 .18666 Mdot
.58381 .3194 Mdot
.66214 .80152 Mdot
.61187 .36995 Mdot
.44203 .50853 Mdot
.60613 .35794 Mdot
.53377 .24013 Mdot
.49054 .32125 Mdot
.43544 .68616 Mdot
.59522 .32746 Mdot
.58425 .28231 Mdot
.52853 .46102 Mdot
.46033 .17499 Mdot
.68005 .68971 Mdot
.40395 .50168 Mdot
.63438 .41355 Mdot
.42888 .72036 Mdot
.43238 .27219 Mdot
.50931 .37321 Mdot
.51531 .39967 Mdot
.63533 .35357 Mdot
.64292 .74207 Mdot
.66427 .60961 Mdot
.40861 .52989 Mdot
.68684 .54065 Mdot
.68714 .71374 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0^Oooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1Oooool00ol0003oooooooooo`2iooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`2iooooo`00POooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVY
ZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000;Wooooo0029ooooo`05o`000?oo
ooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0^Oooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEE
EOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;Wo
oooo0029ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0^Oooool008Wooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo0;Wooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`00
00Cooooo1Ol00005ooooo`03o`000?oooooooooo0;Wooooo002Qooooo`;o000000Coooooo`000?l0
003o00001Oooool00ol0003oooooooooo`2iooooo`00XOooool3o`0000?ooooo0_l00003ooooo`03
o`000?oooooooooo0;Wooooo002Rooooo`;o00000oooool2o`0000?ooooo00?o0000ooooooooool0
^Oooool00:Kooooo0_l00004ooooo`?o0000^Oooool00:?ooooo0_l000000ooooooo0000o`000004
ooooo`03o`000?oooooooooo0;Wooooo002Mooooo`;o00001?ooool2o`0000Oooooo0ol0002ioooo
o`00WOooool2o`0000gooooo0ol0002iooooo`00Yoooool2o`000004ooooool0003o0000o`000;_o
oooo002Nooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`?o0000^oooool009kooooo
0_l00004ooooo`;o000000?oooooo`000?l000000oooool00ol0003oooooooooo`2iooooo`00Yooo
ool2o`0000?ooooo00Co0000ooooool0003o0000^?ooool009kooooo0_l00006ooooo`;o00001?oo
ool4o`000;Sooooo002Nooooo`;o00001_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool2
o`000;Gooooo002Iooooo`;o00004Oooool00ol0003oooooooooo`02ooooo`;o0000]Oooool009Wo
oooo0_l0000=ooooo`?o000000?oooooo`000?ooool00_l000000ooooooo0000o`00002eooooo`00
V_ooool2o`0000cooooo0ol000000ooooooo0000ooooo`02o`0000;ooooo0_l0002dooooo`00V_oo
ool2o`0000cooooo0_l00002ooooo`03o`000?oooooooooo00?ooooo0_l0002dooooo`00VOooool2
o`0000oooooo0ol00003ooooo`;o0000]_ooool009Wooooo0_l00005ooooo`;o00002?ooool3o`00
0003ooooool0003o000000;o00001oooool2o`000:gooooo002Looooo`;o00000_ooool2o`0000[o
oooo1_l00007ooooo`;o0000[Oooool009cooooo0_l0000>ooooo`04o`000?ooooooooooooooo`;o
0000]_ooool009Wooooo0ol0000@ooooo`03o`000?oooooooooo00Oooooo0_l00003ooooo`;o0000
Zoooool009Wooooo0ol0000@ooooo`03o`000?oooooooooo00Oooooo0_l00003ooooo`;o0000Zooo
ool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool00_ooool2o`000;Gooooo002/ooooo`03o`000?oooooooooo00;ooooo
0_l0002eooooo`00U_ooool2o`0001Cooooo0ol00004ooooo`;o00000oooool2o`000:kooooo002F
ooooo`;o00005?ooool00ol0003oooooooooo`04ooooo`;o00000oooool2o`000:kooooo002Joooo
o`;o00004?ooool00ol0003oooooooooo`05ooooo`;o0000/_ooool009Kooooo0_l00002ooooo`;o
00004?ooool00ol0003oooooooooo`05ooooo`;o0000/_ooool009?ooooo0_l000000ooooooo0000
o`00000Dooooo`03o`000?oooooooooo01?ooooo0_l0002Tooooo`00Toooool2o`0001Oooooo00?o
0000ooooooooool02?ooool2o`0000Oooooo1?l0002Tooooo`00TOooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`08ooooo`;o00001Oooool4o`000:Kooooo002Aooooo`03ogMgMonHV9Sooooo00;o000000?o
ooooo`000?l000000_ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`0>ooooo`?o0000Z?ooool008Wooooo1_l00002ooooo`03oa0@4?oooooooooo00;o000000?ooooo
o`000?l000003Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo0_l0002Y
ooooo`00TOooool3o`000003ooooool0003ooooo00kooooo00?oMgMgoc8b<_ooool01?ooool3o`00
013ooooo0_l0002Wooooo`00TOooool3o`000003ooooool0003ooooo00_ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c005ooooo`03o`000?oooooooooo013ooooo0_l000000ooooooo0000o`00002Toooo
o`00TOooool00ol@413oooooooooo`03o`0000_ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0?ooooo`;o00000_ooool2o`000:Cooooo002Aooooo`03ogMgMonHV9Sooooo00?o0000
2oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo0_l0002Xooooo`00TOoo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`03o`000?oooooooooo00_ooooo
0_l00002ooooo`;o0000Z?ooool00:cooooo00?o0000ooooooooool02oooool2o`0000Kooooo0ol0
0002ooooo`;o0000Woooool00:cooooo00?o0000ooooooooool04?ooool2o`000004ooooool0003o
0000o`0000;ooooo0_l0002Oooooo`00Toooool4o`0001Gooooo00?o0000ooooooooool04?ooool2
o`0000Kooooo0_l0002Oooooo`00Toooool4o`0001Gooooo0ol0000Hooooo`;o0000Woooool00:co
oooo00?o0000ooooooooool04oooool2o`000:Cooooo002/ooooo`03o`000?oooooooooo01?ooooo
0_l00003ooooo`;o0000Woooool0097ooooo0_l0000Iooooo`03o`000?oooooooooo01Sooooo0_l0
002Oooooo`00TOooool4o`0001Oooooo00?o0000ooooooooool05_ooool2o`000:7ooooo002Coooo
o`;o00005oooool00ol0003oooooooooo`0Fooooo`;o00000oooool2o`0000?ooooo0_l0002Goooo
o`00[?ooool00ol0003oooooooooo`0Kooooo`;o00000oooool2o`0009Oooooo002/ooooo`03o`00
0?oooooooooo01;ooooo0_l00006ooooo`;o0000WOooool00:cooooo0ol0000Booooo`;o00001_oo
ool2o`000003ooooool0003o000000;o0000V?ooool00:cooooo00?o0000ooooooooool07Oooool4
o`0009Sooooo002/ooooo`03o`000?oooooooooo023ooooo1?l0002Eooooo`00[?ooool00ol0003o
ooooooooo`0Pooooo`Co0000UOooool00:cooooo00?o0000ooooooooool05Oooool2o`0000Kooooo
0_l0002Jooooo`00S_ooool4o`0001[ooooo00?o0000ooooooooool05Oooool2o`0000Kooooo0_l0
002Jooooo`00S_ooool4o`0001Cooooo0_l00004ooooo`03o`000?oooooooooo01Sooooo0_l0002O
ooooo`00Y_ooool4o`0000;ooooo00?o0000ooooooooool06?ooool2o`0000;ooooo0ol00007oooo
o`;o0000TOooool00:Kooooo1?l00002ooooo`?o00007?ooool3o`0000Oooooo0_l0002Aooooo`00
TOooool2o`00013ooooo0_l00003ooooo`;o00000_ooool00ol0003oooooooooo`0Jooooo`Co0000
Voooool0097ooooo0_l0000@ooooo`;o00001?ooool2o`000003ooooool0003ooooo01_ooooo1?l0
0009ooooo`;o0000T?ooool00:Wooooo0_l000000ooooooo0000ooooo`0Vooooo`Co0000T?ooool0
0:cooooo00?o0000ooooooooool08?ooool2o`0000?ooooo0ol0002Aooooo`00Z?ooool2o`000003
ooooool0003o000001oooooo0_l000000ooooooo0000o`00002Gooooo`00Z?ooool2o`000003oooo
ool0003o000001oooooo0_l00007ooooo`;o0000TOooool008kooooo0_l0000Looooo`03o`000?oo
oooooooo01_ooooo0_l00009ooooo`;o0000TOooool008kooooo0_l0000=ooooo`;o00003Oooool0
0ol0003oooooooooo`0Kooooo`Co0000V_ooool009gooooo0_l0000=ooooo`?o00007Oooool2o`00
00Kooooo0_l0002Booooo`00W_ooool2o`0000cooooo00?o0000ooooooooool09Oooool2o`0000;o
oooo0_l0002>ooooo`00W_ooool2o`0000cooooo0ol0000Pooooo`;o00001oooool2o`0008kooooo
002/ooooo`?o00008?ooool2o`0009Oooooo002/ooooo`?o00009?ooool2o`0000Cooooo0_l0002=
ooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool09?ooool2o`0000Cooooo0_l0
002=ooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo027ooooo
0_l0000;ooooo`;o0000ROooool0087ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_l0000Oooooo`;o00001_ooool2o`0000?ooooo0_l00029ooooo`00ROooool01Ol0003ooooooooo
oooooooo000000;ooooo0_l00009ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0
1?ooool5o`0002Cooooo0_l000000ooooooo0000o`000002o`0008cooooo0029ooooo`05o`000?oo
ooooooooooooool000000_ooool2o`0000[ooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool09_ooool2o`0000?ooooo0_l0002<ooooo`00
ROooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo033ooooo0_l00027ooooo`00ROooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0:?ooool2o`0000Kooooo0_l00027ooooo`00ROooool01?o^k^ko
<S8bo`000?lb<S82o`000003ooooool0003o000000Oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004
ooooo`Co00001_ooool00ol0003oooooooooo`0Xooooo`;o0000Soooool008gooooo0_l000000ooo
oooo0000o`00000Jooooo`03o`000?oooooooooo02;ooooo0_l00003ooooo`;o0000T?ooool00:co
oooo00?o0000ooooooooool00_ooool2o`0001kooooo0_l00003ooooo`Co00001oooool2o`0008Go
oooo002/ooooo`03o`000?oooooooooo00;ooooo0_l0000Nooooo`;o00001Oooool2o`0000Oooooo
0_l00025ooooo`00SOooool4o`0001_ooooo0ol00002ooooo`;o00008?ooool2o`0009?ooooo002=
ooooo`Co00006oooool00ol0003oooooooooo`02ooooo`;o00008?ooool4o`0000Oooooo1?l00026
ooooo`00[?ooool00ol0003oooooooooo`0Vooooo`;o00000_ooool2o`0000?ooooo1?l00026oooo
o`00[?ooool00ol0003oooooooooo`0Wooooo`Go00001?ooool2o`0008Oooooo002=ooooo`;o0000
7Oooool00ol0003oooooooooo`0Wooooo`Go00001_ooool2o`0008Gooooo002=ooooo`;o00007Ooo
ool00ol0003oooooooooo`0Yooooo`;o000000?oooooo`000?l000001?ooool2o`0008Gooooo002=
ooooo`;o00007Oooool00ol0003oooooooooo`05ooooo`;o00009Oooool2o`0008_ooooo002=oooo
o`Go00006_ooool00ol0003oooooooooo`04ooooo`?o0000/_ooool008gooooo1Ol00007ooooo`;o
00004Oooool3o`0000Cooooo0_l0000_ooooo`;o0000P_ooool008kooooo0_l00009ooooo`;o0000
4Oooool00ol0003oooooooooo`05ooooo`;o00009?ooool2o`0000Gooooo0_l000000ooooooo0000
o`000022ooooo`00[?ooool00ol0003oooooooooo`05ooooo`;o00009?ooool2o`0000Gooooo0_l0
0025ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00VOooool2o`00017ooooo00?o0000oooo
ooooool01_ooool2o`0002Kooooo0_l00029ooooo`00VOooool2o`00017ooooo00?o0000oooooooo
ool01_ooool2o`0002Cooooo1?l00029ooooo`00VOooool2o`00017ooooo00?o0000ooooooooool0
;?ooool2o`0008_ooooo002<ooooo`;o00002oooool2o`00017ooooo00?o0000ooooooooool0^Ooo
ool008cooooo0_l0000Nooooo`03o`000?oooooooooo03Sooooo0_l0001oooooo`00[?ooool3o`00
00Sooooo0_l0000Zooooo`;o00000_ooool2o`0007oooooo002/ooooo`03o`000?oooooooooo00So
oooo0_l0000Oooooo`;o000000?oooooo`000?l000001_ooool2o`0008?ooooo002/ooooo`03o`00
0?oooooooooo02Wooooo0_l000001?oooooo0000o`000?ooool3o`0000;ooooo0_l00023ooooo`00
2Oooool4o`000003oa0@4?oooooooooo01Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd03ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000
o`000?lb<S;ogMgM01Kooooo00?o0000ooooooooool01_ooool2o`00013ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool6o`000003ooooool0003o000000?o000000?o<S8bomgM
gOooool03_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`00
0?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`Co000000?o410@oooooooo
ool04_ooool000_ooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool05Oooool00ol0003oooooooooo`06ooooo`?o00003oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo
<S8booooo`02ooooo`Co00002?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool0
0omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo01Wooooo00?o0000ooooooooool05?ooool0
00Ko00001Oooool00ol0003oooooooooo`0@ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo
410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`05ooooo`Ko00000_ooool0
1Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool01Oooool6o`0000;ooooo00Go
410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`07ooooo`;o00003oooool01Ol@413ooooooooooooooooo410@00co
oooo00?oV9RHob4Q8Oo^k^h00_l00006ooooo`;o00000oooool4o`0000Sooooo00Go410@oooooooo
oooooooooa0@400@ooooo`03o`000?oooooooooo00gooooo00Go410@oooooooooooooooooa0@400=
ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0D
ooooo`002oooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool0
0olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00
000?ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool05Oooool00ol0003oooooooooo`0Hooooo`05o`00
0?ooooooooooooooool000003Oooool01?nHV9So8B4Qo`000?l00006ooooo`;o00001?ooool2o`00
00Wooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool06Ooo
ool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05o`000?oooooo
ooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
3oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?oooo
o`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`05_ooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool00000
3_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool2o`0000Wo
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<01[ooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?oo
ool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003ooooo
ooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0Aooooo`05
oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01Sooooo0ol0000Hooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Kooooo0_l00009ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMg
ooooo`03ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05?ooool000_ooooo00?o
0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooo
oooooc8b<P04ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@41000_ooool3o`0001[ooooo00?o0000ooooooooool01oooool2o`0000oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003o
ooooooooo`02ooooo`;o00003Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b
<P04ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05?ooool000Wooooo00?oEEEE
ofIVI_l000006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00004?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00;ooooo1_l0000Gooooo`03o`000?oooooooooo
00Oooooo0_l0000?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<00Cooooo2?l0000<ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00013ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0001Wooooo00?oEEEEofIVI_l0
00005_ooool00:cooooo00?o0000ooooooooool0=?ooool5o`00083ooooo002/ooooo`03o`000?oo
oooooooo03cooooo0_l0001kooooo`00[?ooool00ol0003oooooooooo`05ooooo`;o00009oooool2
o`000003ooooool0003o000000Wooooo0_l0001`ooooo`;o00000_ooool2o`0000Gooooo002>oooo
o`;o00007?ooool00ol0003oooooooooo`05ooooo`;o00009oooool2o`000003ooooool0003o0000
07_ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd5ooooo`00S_ooool2o`0001cooooo00?o0000
ooooooooool0;Oooool2o`0000Oooooo0_l0001gooooo`04omgMgOl0003o410@olc<c0Kooooo0007
oooooooo0000C?l0000<ooooo`04onk^k_lQ8B7o410@onk^kPKooooo0007ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo0ol00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000;ooooo0_l00003
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00[ooooo00Co8B4QogMgMomgMgOo<S8b1_ooool000Oooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool01_ooool4o`0001cooooo00?o0000ooooooooool01oooool2o`0001kooooo00?o0000
ooooooooool01oooool3o`0000Kooooo1Ol0000Aooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`09ooooo`;o00000_ooool2o`0000Gooooo002>oooo
o`;o00002?ooool2o`0001;ooooo00?o0000ooooooooool01oooool2o`0002Sooooo0_l00003oooo
o`;o00001?ooool3o`0007[ooooo002Hooooo`;o00004_ooool00ol0003oooooooooo`06ooooo`;o
00009oooool2o`0000Gooooo0_l00021ooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool0
1_ooool5o`0002Cooooo0_l00028ooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool01ooo
ool4o`0003?ooooo0_l0001iooooo`00SOooool2o`0001gooooo00?o0000ooooooooool02Oooool2
o`0003?ooooo0_l0001iooooo`00SOooool2o`0001gooooo0ol00006ooooo`;o000000?oooooo`00
0?l00000[_ooool00:cooooo00?o0000ooooooooool01_ooool3o`000;3ooooo002=ooooo`;o0000
7Oooool00ol0003oooooooooo`07ooooo`;o0000<Oooool2o`000003ooooool0003o000007[ooooo
002<ooooo`?o00007Oooool00ol0003oooooooooo`0iooooo`Ko0000N_ooool008cooooo1?l0000L
ooooo`03o`000?oooooooooo02kooooo0_l00009ooooo`;o000000?oooooo`000?l000000_l0001i
ooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool0;_ooool2o`0000[ooooo0_l00002oooo
o`;o0000NOooool008kooooo0_l0000Looooo`03o`000?oooooooooo03Wooooo0ol00004ooooo`;o
0000Moooool008kooooo0_l0000Looooo`03o`000?oooooooooo00Oooooo0_l0000Wooooo`;o0000
1oooool2o`0000Gooooo0_l0001gooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool01ooo
ool2o`0002Oooooo0_l00009ooooo`;o0000O?ooool008kooooo0_l0000Looooo`?o0000;oooool2
o`0000[ooooo0_l0001looooo`00[?ooool00ol0003oooooooooo`0_ooooo`;o00002Oooool2o`00
00;ooooo0_l0001iooooo`00[?ooool00ol0003oooooooooo`0jooooo`?o000000?oooooo`000?l0
0000NOooool00:cooooo00?o0000ooooooooool0=oooool2o`0000;ooooo0_l0001looooo`00[?oo
ool00ol0003oooooooooo`0gooooo`;o00001oooool2o`0007Oooooo002Kooooo`;o00003oooool0
0ol0003oooooooooo`10ooooo`;o0000Moooool009_ooooo0_l0000?ooooo`03o`000?oooooooooo
00Kooooo0ol0000Wooooo`;o0000Qoooool00:cooooo00?o0000ooooooooool01_ooool3o`0002Oo
oooo0_l00009ooooo`;o0000O?ooool00:cooooo0ol0000aooooo`?o00001oooool3o`0007_ooooo
002/ooooo`03o`000?oooooooooo037ooooo0ol00008ooooo`;o000000?oooooo`000?l00000N?oo
ool0093ooooo0_l0000Jooooo`03o`000?oooooooooo03oooooo0_l0001hooooo`00S_ooool4o`00
01[ooooo00?o0000ooooooooool0>?ooool2o`0000;ooooo0_l0001kooooo`00S_ooool4o`0001[o
oooo00?o0000ooooooooool01_ooool2o`000003ooooool0003o000002gooooo0_l00002ooooo`;o
0000Noooool00:cooooo00?o0000ooooooooool01_ooool2o`000003ooooool0003o00000:kooooo
002/ooooo`03o`000?oooooooooo03;ooooo1?l00005ooooo`Co0000N_ooool008kooooo0_l0000L
ooooo`03o`000?oooooooooo03;ooooo1?l00005ooooo`Co0000N_ooool008kooooo0_l0000Loooo
o`?o0000=Oooool2o`0008;ooooo002>ooooo`;o00003_ooool2o`0000cooooo00?o0000oooooooo
ool0<Oooool2o`0000;ooooo0_l00022ooooo`00W_ooool2o`0000cooooo00?o0000ooooooooool0
2?ooool3o`0002Gooooo0ol00002ooooo`;o0000P_ooool0097ooooo0_l0000Iooooo`03o`000?oo
oooooooo00Kooooo1Ol0000Uooooo`;o000000?oooooo`000?l000000_l00022ooooo`00S_ooool5
o`0001Wooooo00?o0000ooooooooool01_ooool4o`0002Wooooo0ol00023ooooo`00S_ooool4o`00
01[ooooo00?o0000ooooooooool02Oooool2o`000:kooooo0029ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`09ooooo`;o00009_ooool2o`0000kooooo0_l0001fooooo`00ROooool01Omg
MgOoV9RHoooooonHV9SoMgMg00;o00000oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4
A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool01_ooool2o`0002Sooooo0ol0
0003ooooo`;o00001_ooool2o`000003ooooool0003o000007Kooooo0029ooooo`05oa0@4?oooooo
ooooooooool@41001Ol00007ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00ooo
ool3o`0000Kooooo0_l0000Xooooo`?o000000?oooooo`000?l000000_l00006ooooo`;o0000NOoo
ool008Wooooo00Go0000ooooooooooooooooo`000002ooooo`?o00002?ooool00onHV9So8B4Qonk^
kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0<Oooool7o`0000Cooooo0_l0
0003ooooo`Co0000M?ooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo03?ooooo
0_l000000ooooooo0000o`000004ooooo`?o00000_ooool4o`0007Cooooo0029ooooo`05oa0@4?oo
ooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01_ooool2o`00037ooooo1ol000000ooooooo0000o`00001fooooo`00ROoo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool2o`00037ooooo1?l000001?oooooo
0000o`000?ooool3o`0007Gooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2o`00
00Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`0d
ooooo`;o00002?ooool6o`0007Gooooo002Cooooo`;o00005oooool00ol0003oooooooooo`03oooo
o`;o0000;oooool2o`000003ooooool0003o000000Oooooo0ol0001fooooo`00[?ooool00ol0003o
ooooooooo`03ooooo`?o0000<Oooool2o`0000Wooooo0_l0001eooooo`00Toooool2o`0001Oooooo
00?o0000ooooooooool00oooool3o`0003Kooooo0_l00004ooooo`;o0000MOooool009?ooooo0_l0
000Gooooo`?o0000>_ooool4o`0000Cooooo0_l0001eooooo`00[?ooool00ol0003oooooooooo`0e
ooooo`;o00000oooool2o`000003ooooool0003o000007[ooooo002/ooooo`03o`000?oooooooooo
03Gooooo0_l00006ooooo`;o000000?oooooo`000?l00000Moooool00:cooooo00?o0000oooooooo
ool01Oooool2o`0002_ooooo0_l0000<ooooo`?o0000M_ooool009Cooooo0_l0000Fooooo`03o`00
0?oooooooooo00Gooooo0_l0000[ooooo`;o00001Oooool2o`0000Gooooo0ol0001fooooo`00TOoo
ool2o`000003ooooool0003o000001Kooooo00?o0000ooooooooool01Oooool2o`0002_ooooo0_l0
0003ooooo`Go00001?ooool2o`0007Oooooo002Aooooo`;o00006Oooool00ol0003oooooooooo`0b
ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000002ooooo`;o00000oooool2
o`0007Cooooo002/ooooo`03o`000?oooooooooo03Gooooo0_l00007ooooo`;o00000oooool2o`00
07Cooooo002/ooooo`?o000000Coooooo`000?l0003o0000]Oooool009Cooooo0_l0000Fooooo`03
o`000?oooooooooo00Co0000?Oooool2o`0007Kooooo002Dooooo`;o00005_ooool00ol0003ooooo
ooooo`02o`00033ooooo0_l0000;ooooo`Co0000M_ooool009Kooooo0_l0000Dooooo`03o`000?oo
oooooooo03;ooooo0ol000000ooooooo0000o`000007ooooo`Co0000M_ooool009?ooooo0_l00000
0ooooooo0000o`00000Dooooo`03o`000?oooooooooo03?ooooo0_l000000ooooooo0000o`000002
o`0000;ooooo0_l00003ooooo`;o0000M_ooool009?ooooo0_l0000Gooooo`03o`000?oooooooooo
03Oooooo0ol00002ooooo`Co0000NOooool009Kooooo0_l0000Dooooo`03o`000?oooooooooo00;o
0000<Oooool2o`0000?ooooo0_l00004ooooo`;o0000NOooool009Kooooo0_l0000Dooooo`03o`00
0?oooooooooo00;o0000<Oooool2o`0000Cooooo0_l0001nooooo`00[?ooool3o`0003Gooooo0_l0
0002ooooo`Co0000O?ooool00:cooooo00?o0000ooooooooool0=Oooool2o`0000Cooooo0_l0001l
ooooo`00U_ooool2o`0001Cooooo0ol0000]ooooo`;o00002oooool2o`0007gooooo002Fooooo`;o
00005?ooool3o`0002gooooo1Ol00008ooooo`Co0000Noooool00:cooooo00?o0000ooooooooool0
0_ooool2o`0002[ooooo1?l0000:ooooo`;o0000Noooool009Oooooo0_l0000Cooooo`03o`000?oo
oooooooo00;ooooo0_l0000Zooooo`;o000000?oooooo`000?l000001oooool2o`0007gooooo002G
ooooo`;o00004oooool00ol0003oooooooooo`0aooooo`;o00001oooool2o`0007gooooo002Doooo
o`;o00005_ooool00ol0003oooooooooo`0hooooo`;o0000Ooooool009Cooooo0_l0000Fooooo`?o
0000=?ooool2o`0000;ooooo0ol0001nooooo`00Uoooool2o`0001?ooooo0_l0000]ooooo`;o0000
0_ooool2o`0000;ooooo0_l00002ooooo`Go0000O?ooool009Oooooo0ol00002ooooo`;o00003_oo
ool00ol0003oooooooooo`0/ooooo`;o00000_ooool4o`0000Cooooo0_l000000ooooooo0000o`00
001looooo`00V?ooool6o`0000gooooo0_l0000dooooo`Co00000_ooool2o`0007oooooo002Joooo
o`;o000000?oooooo`000?l000003?ooool4o`0003Cooooo0_l00023ooooo`00WOooool2o`0000Ko
oooo0_l00005ooooo`?o0000;oooool2o`0000Sooooo0_l000000ooooooo0000o`00001kooooo`00
TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`03odA4A?l0003o000000;o
00001Oooool00ol0003oooooooooo`0/ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Co
oooo1Ol0001kooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B42o`0000Ko
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0/ooooo`;o00001Oooool3o`0000?o
oooo1?l0001looooo`00TOooool01Ol@413ooooooooooooooooo410@00Oooooo0_l00007ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0<Oooool2o`000003ooooool0003o000008?o
oooo002Aooooo`05o`000?ooooooooooooooool000003?ooool2o`000003oooooomgMgOo<S8b00Go
oooo0ol0000aooooo`;o0000Q_ooool0097ooooo00Go0000ooooooooooooooooo`00000<ooooo`?o
000000?o<S8bolc<c?ooool01?ooool00ol0003oooooooooo`0fooooo`;o0000POooool0097ooooo
00Go410@oooooooooooooooooa0@4004ooooo`;o00001_ooool01?l0003oooooooooooooool2o`00
00Cooooo00?o0000ooooooooool0<_ooool3o`000003ooooool0003o000000;o0000Ooooool0097o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`;o00001_ooool01?l0003oooooooooooooool2
o`0000Cooooo00?o0000ooooooooool0<_ooool3o`0000?ooooo0_l0001oooooo`00TOooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00006ooooo`03o`000?oooooooooo033ooooo0ol00026
ooooo`00XOooool2o`0000Gooooo0_l00002ooooo`03o`000?oooooooooo033ooooo0ol00026oooo
o`00W_ooool2o`0000Sooooo0_l00002ooooo`03o`000?oooooooooo02[ooooo0_l0002=ooooo`00
W_ooool2o`0000?ooooo0_l00007ooooo`03o`000?oooooooooo02[ooooo0_l00006ooooo`;o0000
QOooool009kooooo0ol00002ooooo`;o00001oooool3o`0003;ooooo0_l00025ooooo`00W_ooool3
o`0000_ooooo00?o0000ooooooooool0<_ooool2o`000003ooooool0003o000008;ooooo002Moooo
o`Co00002oooool00ol0003oooooooooo`0eooooo`;o0000P_ooool009gooooo0_l0000=ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo02Kooooo0_l0002Aooooo`00[?oo
ool00ol0003oooooooooo`0Vooooo`;o00002oooool2o`0008Cooooo002/ooooo`03o`000?oooooo
oooo03?ooooo0_l00024ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wo
oooo002/ooooo`03o`000?oooooooooo02Kooooo0_l0000:ooooo`;o0000QOooool00:cooooo00?o
0000ooooooooool09_ooool2o`0000Oooooo0_l000000ooooooo0000o`000025ooooo`00[?ooool0
0ol0003oooooooooo`0Uooooo`;o00000oooool2o`0000?ooooo0_l00028ooooo`00[?ooool00ol0
003oooooooooo`0Uooooo`;o00000oooool2o`0008gooooo002/ooooo`03o`000?oooooooooo02ko
oooo0_l00029ooooo`00[?ooool00ol0003oooooooooo`0Uooooo`;o00001oooool2o`0008Wooooo
002/ooooo`03o`000?oooooooooo02Gooooo0_l0002Booooo`00[?ooool3o`000;Wooooo002/oooo
o`03o`000?oooooooooo02Cooooo0_l00005ooooo`;o0000S?ooool00:cooooo00?o0000oooooooo
ool09?ooool2o`0000;ooooo0_l000000ooooooo0000o`00002<ooooo`00[?ooool00ol0003ooooo
ooooo`0Xooooo`;o0000Soooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool08Oooool4o`0009Cooooo002/ooooo`03o`000?oooooooooo023ooooo1Ol0002Doooo
o`00[?ooool00ol0003oooooooooo`0Pooooo`;o0000Uoooool00:cooooo00?o0000ooooooooool0
7oooool3o`0009Oooooo002/ooooo`?o00007oooool3o`0009Oooooo002/ooooo`03o`000?oooooo
oooo023ooooo1?l000000ooooooo0000o`00002Booooo`00[?ooool00ol0003oooooooooo`0Roooo
o`;o000000?oooooo`000?l00000T_ooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`0Vooooo`;o0000TOooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool09_ooool2o`00097ooooo0029ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06oooool2o`0000Co
oooo0_l0002Fooooo`00ROooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qoooooooo
ool01_ooool00omgMgOo<S8booooo`04ooooo`?o00006oooool2o`0000Cooooo0_l0002Fooooo`00
ROooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0^Oooool008Wooooo00Go410@oooooooo
oooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`2iooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooo
oooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06_ooool2
o`000003ooooool0003o000009[ooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5
o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo01[ooooo0_l000000ooooooo0000o`00002J
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0Qooooo`;o
0000U_ooool00:cooooo00?o0000ooooooooool08Oooool2o`0009Kooooo002/ooooo`?o0000^Ooo
ool00:cooooo00?o0000ooooooooool06?ooool2o`0009oooooo002/ooooo`03o`000?oooooooooo
01Sooooo0_l000000ooooooo0000o`00002Looooo`00[?ooool00ol0003oooooooooo`0Kooooo`;o
0000W?ooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool05?oo
ool2o`000:?ooooo002/ooooo`03o`000?oooooooooo01Cooooo0_l0002Sooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo01Wooooo0_l0002Nooooo`00[?ooool00ol0003oooooooooo`0I
ooooo`;o0000W_ooool00:cooooo00?o0000ooooooooool05Oooool2o`000:;ooooo002/ooooo`03
o`000?oooooooooo013ooooo0_l00003ooooo`;o0000X_ooool00:cooooo00?o0000ooooooooool0
4?ooool2o`000:Oooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`?o00003?ooool2o`0000?ooooo0_l0002Vooooo`00[?ooool00ol0003o
ooooooooo`0<ooooo`;o00000oooool2o`000:Kooooo002;ooooo`;o00007oooool00ol0003ooooo
ooooo`0>ooooo`;o0000ZOooool008_ooooo0_l0000Oooooo`03o`000?oooooooooo00kooooo0_l0
002Yooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0?oooo
o`;o0000Z?ooool00:cooooo00?o0000ooooooooool02_ooool2o`0000?ooooo0_l0002Xooooo`00
SOooool2o`0001gooooo00?o0000ooooooooool02_ooool2o`000:gooooo002=ooooo`;o00007Ooo
ool3o`000;Wooooo002/ooooo`03o`000?oooooooooo00[ooooo0_l0002]ooooo`00[?ooool00ol0
003oooooooooo`0:ooooo`?o0000[?ooool00:cooooo00?o0000ooooooooool02oooool2o`000:co
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002R
ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`2iooooo`00Y?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l0002cooooo`00Y?ooool00ol0003o
ooooooooo`05ooooo`?o00001?ooool2o`000;?ooooo002Tooooo`03o`000?oooooooooo0<7ooooo
002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Toooo
o`03o`000?oooooooooo0<7ooooo002Rooooo`03oeEEEOmVIVKo00000<?ooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo002Zooooo`04oa0@4?l0003o0000o`00
0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo
002[ooooo`06o`000?mgMgOo0000o`000?mEEEGok^k^]oooool00:_ooooo00Ko0000oeEEEOo^k^ko
ooooogMgMomEEEFgooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo0;Go
oooo002[ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0]Oooool00:_ooooo00Ko
0000oeEEEOo^k^koooooogMgMomVIVJgooooo`00Z_ooool00ol@413o0000ogMgM`02o`000003ofIV
I_o^k^kooooo0;Kooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.54606 .18421 Mdot
.55194 .17689 Mdot
.49508 .60229 Mdot
.54369 .5881 Mdot
.47167 .81674 Mdot
.48407 .11784 Mdot
.43678 .47026 Mdot
.72477 .42803 Mdot
.70945 .53835 Mdot
.53591 .66947 Mdot
.51212 .73807 Mdot
.7292 .52249 Mdot
.5684 .18179 Mdot
.55183 .63136 Mdot
.70261 .64803 Mdot
.54762 .59911 Mdot
.4344 .19657 Mdot
.56845 .18068 Mdot
.50786 .76816 Mdot
.63465 .26384 Mdot
.6188 .28078 Mdot
.59983 .25805 Mdot
.6334 .34581 Mdot
.5881 .21304 Mdot
.70881 .65119 Mdot
.44858 .81509 Mdot
.46325 .78145 Mdot
.47226 .79974 Mdot
.65345 .30663 Mdot
.58524 .23644 Mdot
.65029 .37701 Mdot
.71318 .4892 Mdot
.72287 .49766 Mdot
.49091 .14914 Mdot
.44202 .16107 Mdot
.67075 .4104 Mdot
.6959 .44378 Mdot
.46079 .7875 Mdot
.68213 .42242 Mdot
.73317 .48241 Mdot
.73046 .57394 Mdot
.45446 .14695 Mdot
.48531 .1273 Mdot
.49462 .10594 Mdot
.49017 .10767 Mdot
.46562 .82333 Mdot
.5055 .74512 Mdot
.7062 .42981 Mdot
.41199 .70067 Mdot
.67353 .38551 Mdot
.70725 .4509 Mdot
.67841 .37349 Mdot
.65838 .85147 Mdot
.49594 .14132 Mdot
.43684 .16535 Mdot
.71528 .52979 Mdot
.7273 .45602 Mdot
.41127 .28791 Mdot
.70116 .43213 Mdot
.4845 .10537 Mdot
.44003 .78607 Mdot
.726 .65521 Mdot
.68541 .46073 Mdot
.53551 .40484 Mdot
.7061 .60413 Mdot
.71576 .48696 Mdot
.52514 .6957 Mdot
.52724 .66629 Mdot
.4971 .78057 Mdot
.6097 .25304 Mdot
.39497 .55465 Mdot
.43353 .47468 Mdot
.51095 .72955 Mdot
.5363 .66 Mdot
.68542 .46164 Mdot
.46924 .64427 Mdot
.65759 .85256 Mdot
.40234 .49247 Mdot
.67277 .35618 Mdot
.42546 .24766 Mdot
.66031 .39472 Mdot
.59455 .25752 Mdot
.53688 .61276 Mdot
.44077 .16684 Mdot
.72125 .43413 Mdot
.5599 .51088 Mdot
.47184 .81773 Mdot
.41436 .66372 Mdot
.39693 .43514 Mdot
.52133 .68307 Mdot
.7013 .67242 Mdot
.67953 .79552 Mdot
.5399 .41055 Mdot
.45526 .81014 Mdot
.54186 .43294 Mdot
.70378 .75127 Mdot
.55072 .63382 Mdot
.70661 .51653 Mdot
.66053 .85058 Mdot
.39859 .60723 Mdot
.56232 .20948 Mdot
.39854 .59149 Mdot
.72303 .56504 Mdot
.51772 .13484 Mdot
.63561 .30768 Mdot
.49135 .14804 Mdot
.39773 .39313 Mdot
.51029 .76722 Mdot
.5395 .40747 Mdot
.62184 .28094 Mdot
.55055 .62955 Mdot
.55116 .53193 Mdot
.7123 .50015 Mdot
.64637 .3041 Mdot
.62262 .91718 Mdot
.45819 .30289 Mdot
.41751 .70085 Mdot
.71487 .41946 Mdot
.71447 .43697 Mdot
.69486 .51199 Mdot
.58005 .20226 Mdot
.73505 .61484 Mdot
.64349 .36918 Mdot
.64678 .28661 Mdot
.61583 .2662 Mdot
.53597 .62602 Mdot
.65767 .33484 Mdot
.70772 .73711 Mdot
.60642 .29623 Mdot
.51604 .36906 Mdot
.61503 .28967 Mdot
.57922 .238 Mdot
.72744 .55643 Mdot
.45236 .12616 Mdot
.48763 .12577 Mdot
.65692 .30739 Mdot
.68037 .35347 Mdot
.65921 .33087 Mdot
.50612 .73881 Mdot
.72103 .54308 Mdot
.71033 .62646 Mdot
.6884 .7507 Mdot
.54896 .46079 Mdot
.51081 .75925 Mdot
.42882 .21236 Mdot
.63709 .27416 Mdot
.71882 .42868 Mdot
.61241 .93676 Mdot
.42226 .68764 Mdot
.41683 .68417 Mdot
.74855 .53967 Mdot
.40432 .65883 Mdot
.52413 .72496 Mdot
.57814 .1943 Mdot
.43341 .50569 Mdot
.54698 .20172 Mdot
.68662 .3945 Mdot
.68424 .42587 Mdot
.71743 .45463 Mdot
.69691 .46852 Mdot
.68533 .38417 Mdot
.43241 .78256 Mdot
.66551 .32896 Mdot
.73999 .47001 Mdot
.66936 .42336 Mdot
.53282 .19504 Mdot
.58541 .25759 Mdot
.71899 .43876 Mdot
.63335 .29658 Mdot
.49383 .78409 Mdot
.67337 .33508 Mdot
.67677 .42475 Mdot
.54285 .55602 Mdot
.47146 .79176 Mdot
.4322 .75044 Mdot
.43955 .76051 Mdot
.71821 .54898 Mdot
.7024 .75155 Mdot
.55114 .21012 Mdot
.4985 .32308 Mdot
.66862 .35573 Mdot
.66628 .31878 Mdot
.73445 .50915 Mdot
.55219 .59471 Mdot
.73122 .57491 Mdot
.52344 .38811 Mdot
.70389 .56857 Mdot
.696 .75751 Mdot
.71124 .43403 Mdot
.7391 .47911 Mdot
.46824 .12285 Mdot
.73456 .60568 Mdot
.63348 .26549 Mdot
.53615 .42146 Mdot
.71288 .68382 Mdot
.72353 .43942 Mdot
.74043 .5416 Mdot
.72568 .55709 Mdot
.44768 .7963 Mdot
.70266 .76594 Mdot
.39399 .44463 Mdot
.49249 .31471 Mdot
.49318 .31526 Mdot
.434 .45699 Mdot
.43625 .76135 Mdot
.69543 .78151 Mdot
.58608 .25532 Mdot
.5353 .44187 Mdot
.50272 .13511 Mdot
.55208 .46489 Mdot
.50698 .3212 Mdot
.52768 .70602 Mdot
.55823 .17109 Mdot
.4029 .54028 Mdot
.63523 .30145 Mdot
.53732 .64663 Mdot
.59022 .2674 Mdot
.40284 .50348 Mdot
.74028 .48435 Mdot
.50315 .31468 Mdot
.53612 .17641 Mdot
.73141 .45983 Mdot
.42359 .73147 Mdot
.70349 .49481 Mdot
.62551 .27875 Mdot
.66601 .42237 Mdot
.51622 .69997 Mdot
.46764 .81062 Mdot
.51427 .12199 Mdot
.5466 .50567 Mdot
.70417 .6442 Mdot
.74235 .59146 Mdot
.55141 .56884 Mdot
.44677 .60547 Mdot
.66588 .82633 Mdot
.40094 .40036 Mdot
.49788 .76978 Mdot
.72998 .62686 Mdot
.4719 .7934 Mdot
.51835 .13405 Mdot
.62415 .30277 Mdot
.57251 .22597 Mdot
.7199 .67113 Mdot
.45371 .129 Mdot
.63106 .28277 Mdot
.39492 .55235 Mdot
.71315 .44965 Mdot
.54424 .47523 Mdot
.69204 .45589 Mdot
.44871 .17373 Mdot
.39551 .5669 Mdot
.68449 .43877 Mdot
.73748 .55554 Mdot
.46121 .29903 Mdot
.54072 .47734 Mdot
.69395 .48232 Mdot
.41275 .68458 Mdot
.46647 .78858 Mdot
.40607 .27749 Mdot
.46737 .64405 Mdot
.72641 .4872 Mdot
.70346 .42607 Mdot
.39979 .58251 Mdot
.4996 .76678 Mdot
.66655 .41695 Mdot
.50231 .32692 Mdot
.39695 .53883 Mdot
.5592 .21037 Mdot
.48366 .77636 Mdot
.53962 .19919 Mdot
.67473 .42815 Mdot
.40032 .52062 Mdot
.66274 .36062 Mdot
.42757 .18765 Mdot
.54876 .62924 Mdot
.40242 .39588 Mdot
.68296 .3763 Mdot
.55721 .57099 Mdot
.51339 .76759 Mdot
.70885 .46439 Mdot
.54404 .6633 Mdot
.52343 .16372 Mdot
.66786 .34703 Mdot
.4749 .2803 Mdot
.51838 .70285 Mdot
.69688 .48355 Mdot
.72506 .54442 Mdot
.51519 .75898 Mdot
.4344 .49968 Mdot
.41065 .60523 Mdot
.62895 .26476 Mdot
.42587 .73435 Mdot
.66009 .40241 Mdot
.6894 .76869 Mdot
.70203 .46522 Mdot
.70979 .61888 Mdot
.7012 .51015 Mdot
.44565 .6107 Mdot
.69428 .39444 Mdot
.69718 .71396 Mdot
.61941 .24807 Mdot
.70381 .64214 Mdot
.608 .9455 Mdot
.39884 .52056 Mdot
.41112 .24462 Mdot
.56886 .21642 Mdot
.71363 .46666 Mdot
.7214 .60849 Mdot
.51434 .72899 Mdot
.70856 .4851 Mdot
.41451 .69827 Mdot
.48341 .30619 Mdot
.5778 .20527 Mdot
.42979 .2079 Mdot
.5918 .22597 Mdot
.74666 .54346 Mdot
.47742 .28963 Mdot
.54655 .19188 Mdot
.47883 .13924 Mdot
.70633 .60872 Mdot
.48415 .28972 Mdot
.73357 .52508 Mdot
.70404 .68613 Mdot
.71499 .70462 Mdot
.54018 .61713 Mdot
.43167 .16262 Mdot
.42592 .20435 Mdot
.68755 .4672 Mdot
.4974 .79858 Mdot
.45742 .31284 Mdot
.43742 .53812 Mdot
.40011 .36795 Mdot
.72906 .44703 Mdot
.69235 .50985 Mdot
.53819 .40792 Mdot
.57421 .20188 Mdot
.50979 .3443 Mdot
.4352 .43896 Mdot
.52045 .13016 Mdot
.46841 .11682 Mdot
.53138 .19241 Mdot
.42787 .76729 Mdot
.43199 .74589 Mdot
.68078 .81719 Mdot
.4017 .55901 Mdot
.60643 .28962 Mdot
.54079 .44412 Mdot
.71852 .52565 Mdot
.46041 .77741 Mdot
.66087 .33935 Mdot
.61752 .31069 Mdot
.5424 .41402 Mdot
.40376 .48189 Mdot
.69376 .74045 Mdot
.73046 .50053 Mdot
.6879 .36272 Mdot
.66996 .39903 Mdot
.40532 .6398 Mdot
.4059 .30838 Mdot
.67372 .40545 Mdot
.39711 .48287 Mdot
.72999 .50698 Mdot
.73294 .66505 Mdot
.63176 .28313 Mdot
.72568 .56463 Mdot
.7335 .53093 Mdot
.73866 .52641 Mdot
.43797 .4052 Mdot
.39987 .42429 Mdot
.70663 .63873 Mdot
.72692 .46864 Mdot
.43818 .40163 Mdot
.65342 .37563 Mdot
.40679 .37365 Mdot
.47829 .11314 Mdot
.55929 .20506 Mdot
.707 .5257 Mdot
.52327 .14145 Mdot
.69708 .43354 Mdot
.68994 .50721 Mdot
.63399 .35058 Mdot
.68183 .34388 Mdot
.61999 .30494 Mdot
.71109 .63858 Mdot
.62977 .9126 Mdot
.69513 .52866 Mdot
.52544 .16427 Mdot
.43882 .41592 Mdot
.71373 .65401 Mdot
.39581 .53389 Mdot
.43791 .54391 Mdot
.73605 .49228 Mdot
.61136 .256 Mdot
.44755 .33758 Mdot
.53123 .67639 Mdot
.42979 .76351 Mdot
.49063 .78075 Mdot
.70639 .42175 Mdot
.60101 .22312 Mdot
.70445 .70158 Mdot
.7349 .51001 Mdot
.44411 .16983 Mdot
.65813 .84582 Mdot
.42472 .21773 Mdot
.44928 .78265 Mdot
.47244 .8089 Mdot
.46521 .65417 Mdot
.72892 .46317 Mdot
.7286 .52515 Mdot
.46641 .78355 Mdot
.54771 .47482 Mdot
.55192 .64897 Mdot
.55935 .53756 Mdot
.74177 .55631 Mdot
.47854 .82276 Mdot
.66492 .39294 Mdot
.5494 .52287 Mdot
.51494 .74412 Mdot
.49901 .31524 Mdot
.47048 .81977 Mdot
.4887 .14849 Mdot
.5235 .72301 Mdot
.53608 .44436 Mdot
.74271 .5796 Mdot
.72188 .53453 Mdot
.50068 .54783 Mdot
.44136 .161 Mdot
.39845 .38359 Mdot
.57555 .25395 Mdot
.40874 .35178 Mdot
.48801 .78853 Mdot
.72271 .62875 Mdot
.71838 .72874 Mdot
.54424 .17209 Mdot
.63284 .89972 Mdot
.48494 .09679 Mdot
.53237 .40822 Mdot
.70205 .58826 Mdot
.70371 .64934 Mdot
.49182 .77427 Mdot
.62563 .33642 Mdot
.6735 .82848 Mdot
.54841 .49266 Mdot
.44745 .3413 Mdot
.42719 .71807 Mdot
.66299 .3945 Mdot
.41041 .32937 Mdot
.69247 .77928 Mdot
.5203 .36997 Mdot
.49874 .14782 Mdot
.42913 .1968 Mdot
.5336 .3877 Mdot
.49361 .30877 Mdot
.55293 .59865 Mdot
.72552 .43588 Mdot
.46601 .29007 Mdot
.6661 .33471 Mdot
.54253 .16455 Mdot
.52166 .15022 Mdot
.65897 .34262 Mdot
.659 .40569 Mdot
.42964 .20604 Mdot
.72916 .69318 Mdot
.53295 .67294 Mdot
.72939 .44591 Mdot
.73974 .53993 Mdot
.47047 .77748 Mdot
.69164 .37971 Mdot
.40242 .42604 Mdot
.46198 .15514 Mdot
.65812 .33059 Mdot
.55353 .19358 Mdot
.49407 .79169 Mdot
.40353 .50589 Mdot
.47214 .14117 Mdot
.74275 .60152 Mdot
.51985 .16995 Mdot
.48399 .64209 Mdot
.50931 .15794 Mdot
.41459 .29793 Mdot
.43261 .47082 Mdot
.52572 .66653 Mdot
.48627 .13265 Mdot
.45881 .12731 Mdot
.47435 .29374 Mdot
.40722 .63435 Mdot
.71593 .48971 Mdot
.49074 .80985 Mdot
.55979 .21355 Mdot
.53579 .70689 Mdot
.43449 .73539 Mdot
.44129 .37689 Mdot
.64392 .89143 Mdot
.44868 .34502 Mdot
.53676 .15357 Mdot
.69975 .54207 Mdot
.66812 .40961 Mdot
.49589 .78343 Mdot
.6631 .34065 Mdot
.73264 .51374 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Wooooo`;o00000oooool00ol0003ooooo
ooooo`2iooooo`00Yoooool2o`0000?ooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00Y_ooool7o`000;_ooooo002Vooooo`Oo0000^oooool00:Cooooo0_l00006ooooo`03o`00
0?oooooooooo0;Wooooo002Tooooo`;o00001_ooool00ol0003oooooooooo`2iooooo`00ROooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00?ooooo1?l0
00000olb<S;o0000o`000004ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool00oooool2o`0000;ooooo00?o
MgMgo`000?l000001?ooool01?l0003oooooooooooooool2o`000;Kooooo0021ooooo`Ko00000_oo
ool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool00oooool2o`0000?ooooo
0ol00003ooooo`?o000000?oooooo`000?l00000]_ooool008Wooooo00Go0000oooooooooooooooo
o`00000>ooooo`Co00001Oooool01?mgMgOo<S8bo`000?l00003ooooo`03o`000?oooooooooo0;Wo
oooo0029ooooo`05o`000?ooooooooooooooool000003_ooool4o`0000;ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c002o`0000?ooooo00?o0000ooooooooool00oooool2o`000;Cooooo0029ooooo`05
oa0@4?ooooooooooooooool@41003_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool2o`00
00?ooooo00?o0000ooooooooool00_ooool3o`000;Cooooo0029ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool00_ooool2
o`0000?ooooo0_l00003ooooo`?o0000]?ooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`Go00001?ooool5o`0000Gooooo0_l0002jooooo`00X_ooool2o`000003ooooool0003o0000
00?ooooo0ol00006ooooo`;o0000/oooool009gooooo0_l00003ooooo`;o00001_ooool3o`0000Ko
oooo0_l0002cooooo`00WOooool2o`0000Wooooo1Ol0002kooooo`00Z?ooool7o`0000Cooooo0_l0
002cooooo`00Woooool2o`0000_ooooo00?o0000ooooooooool01?ooool2o`0000?ooooo0_l0002^
ooooo`00Woooool2o`0000_ooooo00?o0000ooooooooool00_l00007ooooo`;o0000[_ooool009So
oooo0_l0000Booooo`03o`000?oooooooooo00;o0000]oooool009Gooooo0_l000000ooooooo0000
o`00000Booooo`03o`000?oooooooooo00Cooooo0ol00004ooooo`;o0000[?ooool009Gooooo1Ol0
000Booooo`03o`000?oooooooooo00Cooooo0ol00004ooooo`;o0000[?ooool009Oooooo1?l0000A
ooooo`03o`000?oooooooooo00?ooooo0_l0000;ooooo`;o0000Yoooool009Wooooo1?l0000?oooo
o`03o`000?oooooooooo00?ooooo0_l00006ooooo`;o00000oooool2o`000:Oooooo002Kooooo`;o
00003oooool3o`0000Sooooo0_l000001?oooooo0000o`000?ooool2o`000:Wooooo002/ooooo`03
o`000?oooooooooo00Sooooo0_l00004ooooo`;o0000ZOooool00:cooooo00?o0000ooooooooool0
4oooool2o`000:Cooooo002/ooooo`03o`000?oooooooooo00cooooo0_l00005ooooo`;o0000Y?oo
ool009Cooooo0_l0000Fooooo`03o`000?oooooooooo00cooooo0_l0002[ooooo`00U?ooool2o`00
01Kooooo00?o0000ooooooooool01oooool2o`0000?ooooo0_l0002[ooooo`00[?ooool00ol0003o
ooooooooo`07ooooo`;o00000oooool4o`0000Kooooo0_l0002Qooooo`00U?ooool4o`0001Cooooo
00?o0000ooooooooool01oooool2o`0000Gooooo0_l00006ooooo`;o0000XOooool009Cooooo1?l0
000Dooooo`?o00002_ooool2o`000:gooooo002Cooooo`;o00005oooool00ol0003oooooooooo`0:
ooooo`Co00001oooool4o`000:3ooooo002Cooooo`?o00005_ooool00ol0003oooooooooo`0<oooo
o`;o00000_ooool2o`0000?ooooo1?l0002Pooooo`00U?ooool2o`0001Kooooo00?o0000oooooooo
ool03Oooool2o`000004ooooool0003o0000o`0000?ooooo0_l0002Qooooo`00U?ooool2o`0001Ko
oooo00?o0000ooooooooool03Oooool2o`000004ooooool0003o0000o`0000Oooooo0_l0002Moooo
o`00U?ooool2o`0001Kooooo00?o0000ooooooooool04?ooool2o`000003ooooool0003o000000Go
oooo0_l0002Mooooo`00Toooool2o`0001Oooooo00?o0000ooooooooool04oooool2o`000:Cooooo
002Cooooo`;o00005oooool00ol0003oooooooooo`2iooooo`00[?ooool3o`0001kooooo0_l0002I
ooooo`00[?ooool00ol0003oooooooooo`0Dooooo`;o00001Oooool2o`000003ooooool0003o0000
09Wooooo002/ooooo`03o`000?oooooooooo01Cooooo0_l00005ooooo`;o0000W?ooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool06Oooool2o`0009kooooo002/
ooooo`03o`000?oooooooooo01Oooooo1?l0002Nooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooooooo
o`0Gooooo`;o0000X?ooool008kooooo0_l000001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo
0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0^Oooool008Wooooo1ol0
00000ooooooo410@ooooo`02o`000003oa0@4?oooooooooo00kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Tooooo`;o0000Toooool0097ooooo00?o0000ooooool000000_l0000?
ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Qooooo`;o000000?oooooo`000?l00000Toooool0
097ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`0Fooooo`;o000000?oooooo`000?l000001_ooool2o`0009Kooooo002A
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo01Kooooo0_l000001?oooooo0000o`000?ooool4o`000003ooooool0003o000009Kooooo
002Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01Wooooo0_l000000ooooooo0000o`000002o`0009Wooooo002Aooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool09oooool4o`0008kooooo
002/ooooo`03o`000?oooooooooo01[ooooo0_l00007ooooo`;o00000_ooool4o`0008kooooo002/
ooooo`03o`000?oooooooooo01[ooooo0_l00007ooooo`;o00001?ooool2o`0008kooooo002/oooo
o`03o`000?oooooooooo02[ooooo0_l0002=ooooo`00[?ooool3o`0002[ooooo0_l0002=ooooo`00
SOooool2o`0001Cooooo0_l00007ooooo`03o`000?oooooooooo02Kooooo0_l0002Aooooo`00SOoo
ool2o`0001Cooooo0_l00007ooooo`03o`000?oooooooooo02Cooooo1_l0002?ooooo`00[?ooool0
0ol0003oooooooooo`0Tooooo`?o000000?oooooo`000?l00000Soooool008kooooo0_l0000Loooo
o`03o`000?oooooooooo02gooooo0_l0002:ooooo`00S_ooool2o`00013ooooo0_l00002ooooo`Co
00001?ooool00ol0003oooooooooo`0Pooooo`;o000000?oooooo`000?l000002?ooool2o`0008[o
oooo002Pooooo`;o000000?oooooo`000?l000000ol00004ooooo`03o`000?oooooooooo023ooooo
0_l000000ooooooo0000o`00002Dooooo`00Soooool2o`0001;ooooo0_l00007ooooo`03o`000?oo
oooooooo023ooooo0_l00007ooooo`;o0000S_ooool008oooooo0_l0000>ooooo`;o00002oooool3
o`00023ooooo0_l00007ooooo`;o0000S_ooool009kooooo0ol0000;ooooo`03o`000?oooooooooo
02Kooooo0_l000000ooooooo0000o`000002ooooo`;o0000R_ooool009kooooo0_l00006ooooo`;o
00001?ooool00ol0003oooooooooo`0Tooooo`Co00001Oooool5o`0008Oooooo002<ooooo`;o0000
6?ooool2o`000005ooooool0003o0000ooooool000009_ooool2o`0000?ooooo0_l00004ooooo`?o
0000Qoooool008cooooo0_l0000@ooooo`;o00002Oooool2o`000003ooooool0003ooooo02Cooooo
0_l00004ooooo`;o0000S_ooool009kooooo0_l00009ooooo`Ko00008oooool2o`0009Cooooo002Y
ooooo`Ko0000<oooool2o`0008Cooooo002/ooooo`04o`000?oooooo0000o`0003;ooooo0_l00024
ooooo`00Zoooool5o`000;Sooooo002[ooooo`?o0000^_ooool008kooooo0_l0000Looooo`;o0000
<_ooool4o`0008Cooooo002>ooooo`;o00007?ooool00ol0003oooooooooo`0aooooo`Co0000Q?oo
ool009[ooooo0_l0000@ooooo`03o`000?oooooooooo02Kooooo0_l00009ooooo`Co000000?ooooo
o`000?l00000POooool009[ooooo0_l0000@ooooo`03o`000?oooooooooo02Kooooo0_l0000:oooo
o`;o00000_ooool2o`00087ooooo002Jooooo`;o00004?ooool00ol0003oooooooooo`0aooooo`?o
00001Oooool2o`0007kooooo002Jooooo`?o00003oooool00ol0003oooooooooo`02o`0002Oooooo
0_l00006ooooo`;o000000?oooooo`000?l000000oooool2o`0007kooooo002Kooooo`;o00003ooo
ool00ol0003oooooooooo`02o`0002Oooooo0_l00009ooooo`;o0000Poooool008gooooo0_l0000M
ooooo`?o0000:Oooool2o`0008kooooo002=ooooo`;o00007Oooool00ol0003oooooooooo`0Yoooo
o`;o00002Oooool2o`0000;ooooo0_l0001oooooo`00[?ooool00ol0003oooooooooo`0dooooo`Ko
0000Ooooool00:cooooo00?o0000ooooooooool0<_ooool2o`0000;ooooo0_l00021ooooo`00[?oo
ool00ol0003oooooooooo`0booooo`;o00001oooool2o`0007cooooo0029ooooo`05onk^k_lb<S;o
0000o`000?o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1Oooool00ol0003oooooooooo`0kooooo`;o0000O?ooool008Wooooo00GoMgMgoiRHV?l0003o0000
ogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`02ooooo`?o00009oooool2o`0008_ooooo0021ooooo`Ko0000
0_ooool01?l@413oooooooooooooool2o`0000_ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0ol0000Wooooo`;o00002Oooool2o`00083o
oooo0029ooooo`04o`000?ooooooooooooooo`;o00002Oooool2o`000004oooooonHV9So8B4Qonk^
kPOooooo00?oMgMgoc8b<_ooool01?ooool3o`0002kooooo0ol00006ooooo`Co0000O_ooool008Wo
oooo00Go0000ooooooooooooooooo`00000:ooooo`;o00000_ooool00omgMgOoIVIVooooo`03oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0^ooooo`?o00002?ooool2
o`000003ooooool0003o000007_ooooo0029ooooo`05oa0@4?ooooooooooooooool@41003oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0??ooool2
o`0007_ooooo0029ooooo`05ogMgMol0003o0000oiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonH
V9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0fooooo`;o00000_oo
ool2o`0007gooooo0029ooooo`05onk^k_l0003o0000oc8b<_o^k^h02oooool01OnHV9So410@o`00
0?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo00Cooooo0_l00002ooooo`;o0000
;?ooool2o`0000;ooooo0_l0001mooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o00000_oo
ool2o`000:oooooo002:ooooo`;o00008?ooool00ol0003oooooooooo`0aooooo`Co00001Oooool2
o`000003ooooool0003o000007[ooooo002:ooooo`?o00007oooool00ol0003oooooooooo`0aoooo
o`Co00001Oooool2o`000003ooooool0003o000007[ooooo002;ooooo`;o00007oooool3o`0003Go
oooo0_l00022ooooo`00Roooool2o`0000[ooooo0_l0000Cooooo`03o`000?oooooooooo037ooooo
0_l00002ooooo`;o0000P_ooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo00Sooooo1?l0
000Uooooo`;o00000oooool2o`00087ooooo002Gooooo`;o00004oooool00ol0003oooooooooo`07
ooooo`Go00009Oooool2o`000003ooooool0003o000000;o0000POooool00:cooooo00?o0000oooo
ooooool01oooool5o`0002Sooooo0ol00022ooooo`00Uoooool2o`0001?ooooo00?o0000oooooooo
ool02oooool2o`000:cooooo002Gooooo`;o00004oooool00ol0003oooooooooo`0;ooooo`;o0000
9oooool2o`0000gooooo0_l0001dooooo`00[?ooool00ol0003oooooooooo`08ooooo`;o0000:Ooo
ool3o`0000?ooooo0_l00006ooooo`Co0000M?ooool008_ooooo0_l0000Oooooo`?o00002?ooool2
o`0002Wooooo0ol000000ooooooo0000o`000002o`0000Kooooo0_l0001fooooo`00Roooool2o`00
01oooooo00?o0000ooooooooool0=?ooool7o`0000Gooooo0_l00003ooooo`Co0000L?ooool008_o
oooo0_l0000Oooooo`03o`000?oooooooooo03Kooooo0_l000000ooooooo0000o`000005ooooo`?o
00000_ooool4o`00073ooooo002/ooooo`03o`000?oooooooooo00[ooooo0_l0000booooo`Ko0000
0_ooool2o`00077ooooo002:ooooo`;o00008?ooool00ol0003oooooooooo`0:ooooo`;o0000<_oo
ool3o`000005ooooool0003o0000o`000?ooool00ol0001`ooooo`00R_ooool2o`0000[ooooo0_l0
000Dooooo`03o`000?oooooooooo03Wooooo0_l00008ooooo`Ko0000L?ooool009Kooooo0_l0000D
ooooo`03o`000?oooooooooo00Sooooo0_l0000_ooooo`;o00000_ooool2o`0000Kooooo0ol0001a
ooooo`00ROooool2o`00027ooooo00?o0000ooooooooool02?ooool4o`00037ooooo0_l00009oooo
o`;o0000Koooool008Wooooo0_l0000Qooooo`03o`000?oooooooooo00Sooooo1?l0000gooooo`;o
00000oooool2o`0006oooooo002/ooooo`?o0000@Oooool4o`0000?ooooo0_l0001_ooooo`00[?oo
ool00ol0003oooooooooo`0looooo`;o00000oooool2o`000003ooooool0003o000000;ooooo0_l0
001_ooooo`00U_ooool2o`0001Cooooo00?o0000ooooooooool0??ooool2o`0000Kooooo0_l00002
ooooo`;o0000Koooool000Wooooo1?l000000ol@413oooooooooo`0Fooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`00
00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@02o`0001Cooooo00?o0000ooooooooool03Oooool2
o`0000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@04ooooo`;o00002Oooool01?o^k^ko<S8bo`000?lb<S82o`0000Co
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgM
g@0Hooooo`Co000000?o410@ooooooooool04_ooool000_ooooo00?o0000ooooooooool06?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool05Oooool00ol0003oooooooooo`0=oooo
o`?o00002?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01oooool00omgMgOo<S8booooo`03ooooo`;o00001_ooool2o`000004oooooomg
MgOoV9RHooooo`?o00001?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_oo
ool06Oooool00ol0003oooooooooo`0Dooooo`001_l00005ooooo`03o`000?oooooooooo013ooooo
1_l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03
o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`05ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RH
ob4Q8Oo^k^h02Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00kooooo0_l00008
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oo
oooooooo00;ooooo0_l00003ooooo`;o000000Goooooo`000?l0003o0000oa0@4002ooooo`;o0000
4?ooool00ol0003oooooooooo`0=ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05?ooool000_ooooo
00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qoooooooo
ool01_ooool00omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003oooool00omg
MgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07
ooooo`03ogMgMol0003o000000;o00004oooool00ol0003oooooooooo`0Hooooo`05o`000?oooooo
ooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00?ooooo0_l0
0002ooooo`?o00000_ooool3o`000004ooooool0003o0000o`0000;ooooo0_l0000;ooooo`03ogMg
Molb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Ko
oooo00?oMgMgoc8b<_ooool06Oooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003ooooo
ooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000
ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIV
ooooo`03ooooo`04o`000?lQ8B7o0000oc8b<PCo00004oooool00ol0003oooooooooo`0Hooooo`05
o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`02?ooool2o`0000Gooooo00?o0000ooooool000000_l00002ooooo`;o00002?ooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEE
EOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Jooooo`03o`000?oooooooooo01Co
oooo000;ooooo`03o`000?oooooooooo01Sooooo00Go410@oooooooooooooooooa0@400>ooooo`03
ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`;o00005?ooool3o`0000_ooooo0ol0000:
ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo017ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo017ooooo
00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000oooo
ooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`00
0?oooooooooo00;ooooo0_l0000Dooooo`03o`000?oooooooooo00[ooooo1?l0000:ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooo
ooooool04Oooool01_mgMgOoV9RHoooooonHV9SoMgMgooooo`;o00002Oooool00ol0003ooooooooo
o`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Co
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Dooooo`002Oooool00omEEEGoIVIV
o`00000Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000@ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`03oiRHV?l@413o000000?o00000oooool4o`0001Oooooo00?o0000ooooooooool02_ooool2
o`0000cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
1?ooool4o`0000Sooooo0_l00006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ol00009ooooo`Co
00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00006Oooool00omE
EEGoIVIVo`00000Fooooo`00R_ooool4o`0001kooooo00?o0000ooooooooool0?Oooool3o`000003
ooooool0003o000000Oooooo1?l0001[ooooo`00[?ooool00ol0003oooooooooo`0nooooo`;o0000
00?oooooo`000?l000000ol000000ooooooo0000o`000003ooooo`;o0000Joooool00:cooooo00?o
0000ooooooooool0@oooool3o`000004ooooool0003o0000ooooo`;o0000H_ooool2o`0000;ooooo
0_l00005ooooo`00Roooool2o`0001oooooo00?o0000ooooooooool03Oooool2o`00037ooooo0_l0
0002ooooo`;o00001?ooool2o`0006;ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd5ooooo`00
Roooool2o`0001oooooo00?o0000ooooooooool03Oooool2o`00037ooooo0_l00004ooooo`;o0000
Ioooool01?oMgMgo0000oa0@4?o<c<`6ooooo`001oooooooo`0004co00003?ooool01?o^k^ko8B4Q
oa0@4?o^k^h6ooooo`001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`;o00001oooool01?l0003ooooo
o`000?l00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooooooo0_l00003oooo
o`?o00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00Co8B4QogMg
MomgMgOo<S8b1_ooool000Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01Oooool3o`0000Sooooo0_l0000Doooo
o`03o`000?oooooooooo00cooooo0_l0000Iooooo`03o`000?oooooooooo017ooooo0_l0000;oooo
o`;o00001_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool02Oooool2o`0000;ooooo0_l00005ooooo`00S?ooool2o`0000Sooooo0_l0000Dooooo`03
o`000?oooooooooo00cooooo0_l0000]ooooo`?o000000?oooooo`000?l000001oooool4o`0006go
oooo002/ooooo`03o`000?oooooooooo013ooooo0_l0000Zooooo`Go00002Oooool2o`0006gooooo
002/ooooo`03o`000?oooooooooo013ooooo0_l0000[ooooo`;o00000_ooool2o`0000Kooooo0_l0
001^ooooo`00[?ooool00ol0003oooooooooo`11ooooo`;o00001_ooool2o`0006kooooo002:oooo
o`?o00007oooool00ol0003oooooooooo`18ooooo`;o0000Koooool008[ooooo0ol0000Oooooo`?o
00003Oooool2o`0003;ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l0001]ooooo`00
[?ooool00ol0003oooooooooo`0=ooooo`;o0000;_ooool2o`0000;ooooo0_l00002ooooo`;o0000
00?oooooo`000?l000000ol0001/ooooo`00[?ooool00ol0003oooooooooo`0mooooo`;o00001Ooo
ool2o`0000Cooooo0ol0001/ooooo`00ROooool2o`00027ooooo00?o0000ooooooooool03Oooool2
o`0003Gooooo1?l00002ooooo`;o0000KOooool008Wooooo0_l0000Qooooo`03o`000?oooooooooo
00gooooo0_l000000ooooooo0000o`00000dooooo`;o0000LOooool008[ooooo1?l00009ooooo`;o
00004oooool00ol0003oooooooooo`0@ooooo`;o0000<?ooool2o`0000Sooooo0_l000000ooooooo
0000o`00001Xooooo`00R_ooool4o`0000Wooooo0_l0000Cooooo`03o`000?oooooooooo03oooooo
0_l000000ooooooo0000o`000002ooooo`;o00001?ooool5o`0006Sooooo002Gooooo`;o00004ooo
ool00ol0003oooooooooo`0oooooo`;o00001Oooool3o`0000?ooooo1?l0001Yooooo`00[?ooool2
o`0004Kooooo1?l0001`ooooo`00ROooool2o`00027ooooo0ol00015ooooo`;o0000L_ooool008Wo
oooo0_l0000Qooooo`03o`000?oooooooooo00_ooooo0_l0000nooooo`;o0000K?ooool008Wooooo
1?l0000Oooooo`03o`000?oooooooooo00_ooooo0_l0000jooooo`?o000000Coooooo`000?l0003o
0000Joooool008_ooooo0_l0000Oooooo`03o`000?oooooooooo04Oooooo0ol00002ooooo`;o0000
Joooool00:cooooo00?o0000ooooooooool0A_ooool3o`00073ooooo0029ooooo`;o00008Oooool0
0ol0003oooooooooo`16ooooo`?o0000L?ooool008Wooooo0_l0000Qooooo`03o`000?oooooooooo
00kooooo0ol0000_ooooo`;o0000Moooool00:cooooo00?o0000ooooooooool03_ooool3o`0002oo
oooo0_l00007ooooo`;o0000K_ooool00:cooooo0ol00019ooooo`;o0000K_ooool00:cooooo00?o
0000ooooooooool0BOooool2o`0000;ooooo0_l0001Zooooo`00R_ooool2o`00023ooooo00?o0000
ooooooooool0COooool2o`0006[ooooo002:ooooo`;o00008?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`0;ooooo`;o0000<_ooool2o`0007Sooooo002:ooooo`;o0000
8?ooool00ol0003oooooooooo`0;ooooo`;o0000<_ooool2o`0000cooooo0_l0001Zooooo`00R_oo
ool2o`00023ooooo00?o0000ooooooooool03_ooool2o`0003gooooo0_l0001Zooooo`00[?ooool0
0ol0003oooooooooo`0>ooooo`;o0000ZOooool00:cooooo0ol0000<ooooo`Co0000ZOooool00:[o
oooo0ol0000>ooooo`Co0000<Oooool2o`0000[ooooo0_l0001Zooooo`00R_ooool2o`0000;ooooo
0_l0000:ooooo`;o00003_ooool3o`0004?ooooo0_l00007ooooo`;o000000?oooooo`000?l00000
J_ooool008[ooooo0_l00002ooooo`;o00002_ooool2o`00013ooooo00?o0000ooooooooool0@Ooo
ool2o`0000?ooooo0_l00002ooooo`;o0000KOooool009[ooooo0_l0000@ooooo`03o`000?oooooo
oooo00Wooooo0_l0000fooooo`;o00000oooool2o`00077ooooo002Jooooo`;o00004?ooool00ol0
003oooooooooo`09ooooo`;o0000?oooool2o`0006gooooo0029ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`0:ooooo`;o0000=_ooool2o`0000Kooooo0_l0001]ooooo`00ROooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00[ooooo0_l0000fooooo`;o0000MOoo
ool008Wooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o
0000ooooooooool00oooool3o`000;Wooooo0029ooooo`05o`000?ooooooooooooooool000003Ooo
ool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool02?oo
ool2o`0003Sooooo0_l00002ooooo`Co0000Koooool008Wooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo00Sooooo0_l00003ooooo`?o0000<_ooool2o`0000;ooooo1?l0001_ooooo`00ROoo
ool01?l@413oooooooooooooool2o`0000kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00gooooo0ol0002Yooooo`00ROooool01?mgMgOoV9RHoooo
oonHV9P2o`0000[ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool03Oooool2o`000:[ooooo0029ooooo`03onk^k_lb<S;o000000;o0000
2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo047o
oooo0ol0001eooooo`00S?ooool2o`0001Sooooo0_l00004ooooo`03o`000?oooooooooo043ooooo
1?l0001eooooo`00XOooool2o`0000?ooooo0_l00004ooooo`03o`000?oooooooooo00Wooooo0_l0
000eooooo`;o0000Moooool00:7ooooo0_l00009ooooo`03o`000?oooooooooo00Wooooo0_l00003
ooooo`;o0000;oooool3o`0007Oooooo002/ooooo`?o00003_ooool2o`0002oooooo1?l0001foooo
o`00X?ooool2o`0000[ooooo00?o0000ooooooooool0@Oooool4o`0000;ooooo0_l0001`ooooo`00
S?ooool2o`0001;ooooo0_l0000:ooooo`03o`000?oooooooooo04?ooooo0_l00002ooooo`;o0000
L?ooool008cooooo0_l0000Nooooo`03o`000?oooooooooo00Wooooo0_l0002^ooooo`00Soooool2
o`0001_ooooo00?o0000ooooooooool02Oooool4o`0003cooooo0_l0001^ooooo`00Soooool2o`00
01_ooooo00?o0000ooooooooool01Oooool3o`0000?ooooo0_l0000looooo`;o0000K_ooool00:co
oooo00?o0000ooooooooool01Oooool5o`0003_ooooo0_l0001booooo`00[?ooool00ol0003ooooo
ooooo`07ooooo`?o0000=Oooool2o`0000Cooooo0_l0001booooo`00[?ooool3o`0000Oooooo0_l0
000fooooo`;o0000N?ooool00:cooooo00?o0000ooooooooool01oooool2o`000;3ooooo002/oooo
o`03o`000?oooooooooo00Cooooo0_l0002cooooo`00Soooool3o`0001[ooooo00?o0000oooooooo
ool01?ooool2o`0003[ooooo0_l000000ooooooo0000o`00001dooooo`00Soooool5o`0001Sooooo
00?o0000ooooooooool0@?ooool2o`000003ooooool0003o000007Cooooo002Booooo`;o00006?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`18ooooo`;o0000Koooool0
08oooooo0_l0000Kooooo`03o`000?oooooooooo00Gooooo0_l00011ooooo`;o0000Koooool008oo
oooo0ol0000Jooooo`?o00000_ooool2o`000003ooooool0003o00000;;ooooo002?ooooo`?o0000
6_ooool00ol0003oooooooooo`02ooooo`?o0000>oooool2o`0007Oooooo002/ooooo`03o`000?oo
oooooooo00?ooooo0_l000000ooooooo0000o`000002o`0003Kooooo0_l00002ooooo`;o0000Looo
ool00:cooooo00?o0000ooooooooool01_ooool4o`0003[ooooo0_l0001cooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0nooooo`;o0000NOooool009Cooooo
0_l0000Fooooo`03o`000?oooooooooo03kooooo0_l0001iooooo`00U?ooool2o`0001Kooooo00?o
0000ooooooooool0^Oooool00:cooooo0ol00004ooooo`?o0000/_ooool00:cooooo00?o0000oooo
ooooool01?ooool3o`000;;ooooo002Booooo`;o00006?ooool00ol0003oooooooooo`03o`0004;o
oooo0_l0001booooo`00T_ooool3o`0001Oooooo00?o0000ooooooooool00ol00012ooooo`;o0000
L_ooool009?ooooo0_l000000ooooooo0000o`00000Dooooo`03o`000?oooooooooo047ooooo0_l0
001fooooo`00U_ooool2o`0001Cooooo00?o0000ooooool000000ol0000jooooo`;o00000_ooool2
o`0007Kooooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo000000?o0000>_ooool2o`0007[ooooo002A
ooooo`04ogMgMonHV9SooooooiRHV0;o00001?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool3o`000003ooooool0003o00000;Kooooo002Aooooo`04oa0@4?ooooooooooooooo`;o00003ooo
ool00ol0003oooooooooo`03ooooo`?o000000?oooooo`000?l00000]_ooool0097ooooo00Co0000
oooooooooooooooo0_l0000>ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000kooooo`;o00000_oo
ool3o`0007Oooooo002Aooooo`04o`000?ooooooooooooooo`;o00002oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0>oooool2o`0000;ooooo0ol0001gooooo`00TOoo
ool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`02ooooo`;o0000>Oooool2o`0007[ooooo002Aooooo`06ogMgMonHV9SooooooiRHV?mgMgOo
oooo0ol00008ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?l0000iooooo`;o
0000N_ooool0097ooooo00?ok^k^oc8b<_l000000_l000001?oooooo0000o`000?l00008ooooo`Co
00001_ooool00ol0003oooooooooo`02o`000;Oooooo002Dooooo`;o00005Oooool2o`0000;ooooo
0ol0000looooo`;o0000N?ooool009Cooooo0_l0000Eooooo`;o000000?oooooo`000?l000000_l0
000hooooo`;o00000_ooool2o`0007Sooooo002[ooooo`;o000000?oooooo`000?l00000>_ooool2
o`0007cooooo002Vooooo`;o000000Coooooo`000?l0003ooooo0ol0002iooooo`00W_ooool2o`00
00;ooooo0_l00002ooooo`;o000000Goooooo`000?l0003oooooo`00000nooooo`;o0000Noooool0
09Gooooo0_l00004ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000Cooooo0_l00000
0ooooooo0000o`00000nooooo`?o0000N_ooool009Gooooo0_l000001?oooooo0000o`000?ooool2
o`0000;ooooo0ol00006ooooo`Go0000?oooool2o`0007[ooooo002Hooooo`;o00001Oooool3o`00
00Kooooo1Ol0002kooooo`00Woooool5o`0000Cooooo1Ol0002kooooo`00X_ooool2o`0000Kooooo
0ol0002kooooo`00V_ooool2o`0000Kooooo0_l00008ooooo`03o`000?oooooooooo03Sooooo0_l0
001oooooo`00V_ooool2o`0000Kooooo0_l00007ooooo`Co0000>?ooool2o`0007oooooo002Roooo
o`;o00001oooool2o`000;_ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Mooooo`;o0000
0oooool2o`0000Gooooo0_l000000ooooooo0000ooooo`2jooooo`00WOooool2o`0000;ooooo0ol0
0005ooooo`;o000000?oooooo`000?ooool0^_ooool009_ooooo0_l00004ooooo`;o00002Oooool0
0ol0003oooooooooo`2iooooo`00Voooool2o`0000Gooooo0_l00008ooooo`03o`000?oooooooooo
03Sooooo0_l0001oooooo`00X_ooool2o`0000Sooooo00?o0000ooooooooool0>?ooool2o`0007oo
oooo002Pooooo`Ko00001_ooool3o`000;Wooooo002Pooooo`;o00000_ooool2o`0000Kooooo00?o
0000ooooooooool0<oooool2o`000003ooooool0003o0000087ooooo002/ooooo`03o`000?oooooo
oooo03?ooooo0_l000000ooooooo0000o`000021ooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0aooooo`;o0000Q_ooool0
0:cooooo00?o0000ooooooooool0<Oooool2o`0008Kooooo002/ooooo`?o0000<Oooool3o`0008Go
oooo002/ooooo`03o`000?oooooooooo037ooooo0ol00025ooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo
00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;Wooooo0029oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05oa0@4?oooooooooo
ooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0^Oooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooo
oooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`000;Wooooo0029ooooo`05o`000?oooooooooo
ooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`2iooooo`00ROooool01Ol@413ooooooooooooooooo410@00kooooo00?o
ZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Wooooo0029
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`2iooooo`00ROooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`2iooooo`00[?oo
ool00ol0003oooooooooo`0/ooooo`;o0000Roooool00:cooooo00?o0000ooooooooool0;?ooool2
o`0008_ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000:?ooool2o`0008oo
oooo002/ooooo`03o`000?oooooooooo02Sooooo0_l0002?ooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0Woooo
o`;o0000T?ooool00:cooooo00?o0000ooooooooool09oooool2o`00093ooooo002/ooooo`03o`00
0?oooooooooo02Gooooo0_l0002Booooo`00[?ooool00ol0003oooooooooo`0Uooooo`;o0000T_oo
ool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`0Rooooo`;o0000UOooool00:cooooo00?o0000ooooooooool08_ooool2o`0009Gooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo023ooooo0_l0002Gooooo`00
[?ooool00ol0003oooooooooo`0Pooooo`;o0000Uoooool00:cooooo0ol0002iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Rooooo`Co000000?o410@ooooooooool0
0oooool00ol0003oooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0;Wooooo002Tooooo`03o`000?oooooooooo00Gooooo0ol0002iooooo`00Y?ooool00ol0
003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003ooooo
ooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00X_ooool00omEEEGoIVIVo`000033
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Z_ooool0
1?l@413o0000o`000?l0002jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0
003oooooooooo`2jooooo`00Zoooool01_l0003oMgMgo`000?l0003oEEEEonk^k[Oooooo002[oooo
o`06o`000?mEEEGok^k^oooooomgMgOoEEEE]oooool00:_ooooo00?o0000onk^k_ooool00_ooool0
0ol0003oooooooooo`2eooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo
0;Gooooo002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoIVIV]oooool00:[ooooo00?o410@o`00
0?mgMgL00_l000000omVIVKok^k^ooooo`2fooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.40458 .25691 Mdot
.40497 .23402 Mdot
.49699 .40586 Mdot
.53893 .3881 Mdot
.56781 .64227 Mdot
.38961 .54306 Mdot
.47678 .67332 Mdot
.65598 .22803 Mdot
.68478 .33835 Mdot
.5637 .46947 Mdot
.56734 .53807 Mdot
.6982 .32249 Mdot
.41456 .16972 Mdot
.56437 .43136 Mdot
.72182 .44803 Mdot
.54726 .39911 Mdot
.41754 .7429 Mdot
.41426 .16965 Mdot
.57513 .56816 Mdot
.50019 .06384 Mdot
.49112 .08268 Mdot
.46397 .08959 Mdot
.53172 .14581 Mdot
.4379 .10576 Mdot
.72929 .45119 Mdot
.56257 .69538 Mdot
.55281 .62906 Mdot
.56171 .62565 Mdot
.53611 .10663 Mdot
.44354 .11606 Mdot
.56109 .17701 Mdot
.66886 .2892 Mdot
.68193 .29766 Mdot
.39496 .50643 Mdot
.40814 .71735 Mdot
.59491 .2104 Mdot
.63341 .24378 Mdot
.55452 .64024 Mdot
.6111 .22242 Mdot
.68613 .28241 Mdot
.72004 .37394 Mdot
.40237 .66609 Mdot
.3914 .53561 Mdot
.38473 .49958 Mdot
.38607 .51865 Mdot
.56826 .65983 Mdot
.56355 .54512 Mdot
.63812 .22981 Mdot
.53395 .77062 Mdot
.58774 .18551 Mdot
.64761 .2509 Mdot
.58781 .17349 Mdot
.75897 .65147 Mdot
.39216 .48617 Mdot
.4102 .73903 Mdot
.68719 .32979 Mdot
.66971 .25602 Mdot
.44249 .82416 Mdot
.63401 .23213 Mdot
.38679 .5439 Mdot
.55326 .70131 Mdot
.74809 .45521 Mdot
.62971 .26073 Mdot
.46102 .26944 Mdot
.70776 .40413 Mdot
.67054 .28696 Mdot
.56342 .4957 Mdot
.55375 .46629 Mdot
.56945 .58087 Mdot
.47135 .07231 Mdot
.50425 .83815 Mdot
.47844 .68652 Mdot
.56277 .52955 Mdot
.5603 .46 Mdot
.63008 .26164 Mdot
.50885 .51152 Mdot
.75861 .65256 Mdot
.48908 .81887 Mdot
.57525 .15618 Mdot
.43063 .77088 Mdot
.5782 .19472 Mdot
.45896 .09912 Mdot
.54198 .41276 Mdot
.40967 .72155 Mdot
.6549 .23413 Mdot
.52425 .31088 Mdot
.56824 .64287 Mdot
.52454 .7516 Mdot
.47773 .85489 Mdot
.55456 .48307 Mdot
.73027 .47242 Mdot
.75774 .59552 Mdot
.46629 .25734 Mdot
.56153 .67305 Mdot
.47587 .25744 Mdot
.76428 .55127 Mdot
.56425 .43382 Mdot
.67322 .31653 Mdot
.76076 .65058 Mdot
.51505 .81736 Mdot
.41908 .18907 Mdot
.51156 .81816 Mdot
.70904 .36504 Mdot
.3879 .39125 Mdot
.51869 .10768 Mdot
.39462 .50475 Mdot
.46839 .86052 Mdot
.57718 .56722 Mdot
.46493 .25806 Mdot
.49423 .08174 Mdot
.56237 .42955 Mdot
.52393 .33193 Mdot
.67236 .30015 Mdot
.52801 .1041 Mdot
.74949 .71718 Mdot
.43561 .61605 Mdot
.5329 .74709 Mdot
.64265 .21946 Mdot
.64925 .23697 Mdot
.65966 .31199 Mdot
.42833 .129 Mdot
.74099 .41484 Mdot
.55117 .16918 Mdot
.52142 .08661 Mdot
.48241 .07351 Mdot
.54638 .42602 Mdot
.55161 .13484 Mdot
.76256 .53711 Mdot
.48499 .10194 Mdot
.44138 .34809 Mdot
.49091 .09171 Mdot
.43931 .13273 Mdot
.71001 .35643 Mdot
.39829 .67972 Mdot
.39057 .52581 Mdot
.53988 .10739 Mdot
.58175 .15347 Mdot
.55155 .13087 Mdot
.56164 .53881 Mdot
.69826 .34308 Mdot
.72092 .42646 Mdot
.74868 .5507 Mdot
.49329 .26271 Mdot
.57451 .55925 Mdot
.4222 .76386 Mdot
.50675 .07416 Mdot
.6503 .22868 Mdot
.74712 .73676 Mdot
.52867 .72288 Mdot
.52892 .7453 Mdot
.72442 .33967 Mdot
.52554 .79511 Mdot
.57411 .52496 Mdot
.42449 .13522 Mdot
.48524 .68038 Mdot
.40946 .24991 Mdot
.60442 .1945 Mdot
.61459 .22587 Mdot
.65928 .25463 Mdot
.64432 .26852 Mdot
.599 .18417 Mdot
.55273 .72559 Mdot
.5571 .12896 Mdot
.688 .27001 Mdot
.59871 .22336 Mdot
.40334 .31128 Mdot
.451 .11901 Mdot
.65449 .23876 Mdot
.51198 .09658 Mdot
.568 .58545 Mdot
.5674 .13508 Mdot
.60667 .22475 Mdot
.52526 .35602 Mdot
.55849 .61991 Mdot
.5435 .70821 Mdot
.5456 .68681 Mdot
.6978 .34898 Mdot
.76302 .55155 Mdot
.41348 .23173 Mdot
.43129 .43566 Mdot
.57091 .15573 Mdot
.55379 .11878 Mdot
.69811 .30915 Mdot
.55008 .39471 Mdot
.72118 .37491 Mdot
.44882 .31357 Mdot
.69131 .36857 Mdot
.75901 .55751 Mdot
.64486 .23403 Mdot
.69074 .27911 Mdot
.39413 .61113 Mdot
.73684 .40568 Mdot
.49968 .06549 Mdot
.46699 .26863 Mdot
.74641 .48382 Mdot
.6593 .23942 Mdot
.71706 .3416 Mdot
.70851 .35709 Mdot
.55639 .68393 Mdot
.76903 .56594 Mdot
.48044 .8657 Mdot
.43077 .46373 Mdot
.43073 .46058 Mdot
.47448 .6883 Mdot
.54615 .6992 Mdot
.76804 .58151 Mdot
.45077 .11698 Mdot
.47334 .27389 Mdot
.38939 .45789 Mdot
.49804 .26505 Mdot
.42963 .39862 Mdot
.57009 .50602 Mdot
.4062 .20973 Mdot
.49939 .80609 Mdot
.51581 .10145 Mdot
.55597 .44663 Mdot
.4587 .11075 Mdot
.49137 .8143 Mdot
.69401 .28435 Mdot
.42857 .41708 Mdot
.39962 .30079 Mdot
.67534 .25983 Mdot
.53963 .73302 Mdot
.66141 .29481 Mdot
.49702 .07896 Mdot
.59496 .22237 Mdot
.55621 .49997 Mdot
.56422 .64439 Mdot
.38515 .40947 Mdot
.50887 .30567 Mdot
.72185 .4442 Mdot
.73893 .39146 Mdot
.53895 .36884 Mdot
.50415 .60205 Mdot
.75641 .62633 Mdot
.46927 .84492 Mdot
.56586 .56995 Mdot
.74073 .42686 Mdot
.55924 .62055 Mdot
.38772 .38858 Mdot
.50526 .10277 Mdot
.43051 .15284 Mdot
.74835 .47113 Mdot
.39861 .67321 Mdot
.50417 .08277 Mdot
.50375 .83873 Mdot
.65301 .24965 Mdot
.49435 .27668 Mdot
.6344 .25589 Mdot
.40946 .68538 Mdot
.50681 .83399 Mdot
.62 .23877 Mdot
.7197 .35554 Mdot
.43411 .60369 Mdot
.4917 .28055 Mdot
.64687 .28232 Mdot
.52986 .76308 Mdot
.55597 .62753 Mdot
.44134 .84912 Mdot
.50906 .51874 Mdot
.68129 .2872 Mdot
.63388 .22607 Mdot
.50931 .81328 Mdot
.56631 .56679 Mdot
.59333 .21695 Mdot
.43137 .41816 Mdot
.50036 .83239 Mdot
.4176 .20051 Mdot
.55794 .5862 Mdot
.40619 .28113 Mdot
.60599 .22815 Mdot
.49566 .82162 Mdot
.56699 .16062 Mdot
.41707 .77466 Mdot
.56045 .42924 Mdot
.46797 .83943 Mdot
.59347 .1763 Mdot
.54561 .37099 Mdot
.58042 .56759 Mdot
.65461 .26439 Mdot
.56936 .4633 Mdot
.39461 .35942 Mdot
.56667 .14703 Mdot
.42706 .54796 Mdot
.55952 .50285 Mdot
.6503 .28355 Mdot
.70283 .34442 Mdot
.57878 .55898 Mdot
.48371 .67735 Mdot
.51197 .76349 Mdot
.49486 .06537 Mdot
.54002 .7251 Mdot
.58105 .20241 Mdot
.75687 .56869 Mdot
.64811 .26522 Mdot
.71734 .41888 Mdot
.66526 .31015 Mdot
.50556 .60689 Mdot
.61206 .19444 Mdot
.74276 .51396 Mdot
.4788 .05831 Mdot
.72067 .44214 Mdot
.7462 .7455 Mdot
.49596 .82808 Mdot
.43307 .83415 Mdot
.42512 .16532 Mdot
.6603 .26666 Mdot
.7248 .40849 Mdot
.56593 .52899 Mdot
.6626 .2851 Mdot
.53285 .75914 Mdot
.43087 .50523 Mdot
.42769 .13611 Mdot
.42101 .76061 Mdot
.44532 .09778 Mdot
.72404 .34346 Mdot
.42855 .53496 Mdot
.40673 .25346 Mdot
.39541 .56134 Mdot
.70982 .40872 Mdot
.42711 .50553 Mdot
.70361 .32508 Mdot
.7385 .48613 Mdot
.75684 .50462 Mdot
.54703 .41713 Mdot
.41072 .7622 Mdot
.42107 .77824 Mdot
.63443 .2672 Mdot
.57693 .59881 Mdot
.43794 .61726 Mdot
.49145 .65582 Mdot
.46237 .85555 Mdot
.66787 .24703 Mdot
.65629 .30985 Mdot
.46405 .26173 Mdot
.42419 .14794 Mdot
.43476 .38103 Mdot
.47028 .68696 Mdot
.38687 .38006 Mdot
.39277 .61165 Mdot
.4024 .31808 Mdot
.54881 .73358 Mdot
.54226 .70665 Mdot
.76765 .61719 Mdot
.50374 .80772 Mdot
.4824 .09738 Mdot
.47902 .26317 Mdot
.68877 .32565 Mdot
.55101 .63303 Mdot
.55661 .13935 Mdot
.50179 .11069 Mdot
.46956 .25161 Mdot
.48646 .81496 Mdot
.74994 .54045 Mdot
.69067 .30053 Mdot
.59299 .16272 Mdot
.58957 .19903 Mdot
.52093 .78849 Mdot
.44812 .84316 Mdot
.5959 .20545 Mdot
.48811 .8438 Mdot
.69278 .30698 Mdot
.75896 .46505 Mdot
.50501 .08313 Mdot
.71153 .36463 Mdot
.70587 .33093 Mdot
.70922 .32641 Mdot
.46232 .68218 Mdot
.47473 .84443 Mdot
.72212 .43873 Mdot
.67438 .26864 Mdot
.46149 .68204 Mdot
.56367 .17563 Mdot
.46217 .82517 Mdot
.38983 .56934 Mdot
.41614 .20087 Mdot
.67728 .3257 Mdot
.38953 .36499 Mdot
.6305 .23354 Mdot
.65283 .30721 Mdot
.53422 .15058 Mdot
.57938 .14388 Mdot
.50196 .10494 Mdot
.72652 .43858 Mdot
.75481 .7126 Mdot
.66659 .32866 Mdot
.39492 .35038 Mdot
.46447 .67616 Mdot
.73533 .45401 Mdot
.49953 .83841 Mdot
.49261 .65244 Mdot
.69297 .29228 Mdot
.47408 .07178 Mdot
.44548 .65497 Mdot
.56178 .47639 Mdot
.5475 .72429 Mdot
.56416 .58393 Mdot
.6351 .22175 Mdot
.45221 .07599 Mdot
.74508 .50158 Mdot
.6989 .31001 Mdot
.4096 .70631 Mdot
.75645 .64582 Mdot
.42426 .7806 Mdot
.55203 .6691 Mdot
.56518 .6337 Mdot
.51216 .53209 Mdot
.67419 .26317 Mdot
.69866 .32515 Mdot
.55417 .62333 Mdot
.49763 .27507 Mdot
.57151 .44897 Mdot
.53437 .33756 Mdot
.7243 .35631 Mdot
.5731 .63722 Mdot
.5821 .19294 Mdot
.51855 .32287 Mdot
.57259 .54412 Mdot
.42947 .43512 Mdot
.5685 .64717 Mdot
.3953 .51621 Mdot
.5727 .52301 Mdot
.4749 .27267 Mdot
.73455 .3796 Mdot
.69569 .33453 Mdot
.48171 .37929 Mdot
.40827 .72021 Mdot
.46615 .85943 Mdot
.44177 .14432 Mdot
.45698 .82139 Mdot
.56537 .59359 Mdot
.73421 .42875 Mdot
.76987 .52874 Mdot
.40087 .26685 Mdot
.75273 .69972 Mdot
.38482 .54383 Mdot
.45986 .27929 Mdot
.69735 .38826 Mdot
.72344 .44934 Mdot
.56249 .57674 Mdot
.52019 .13642 Mdot
.76489 .62848 Mdot
.50548 .29266 Mdot
.44631 .65461 Mdot
.53548 .71283 Mdot
.58079 .1945 Mdot
.45172 .81894 Mdot
.76418 .57928 Mdot
.44283 .32968 Mdot
.39298 .47254 Mdot
.41873 .76586 Mdot
.45435 .27597 Mdot
.42922 .46011 Mdot
.55239 .39865 Mdot
.65987 .23588 Mdot
.43112 .58469 Mdot
.55998 .13471 Mdot
.39845 .2756 Mdot
.39143 .37027 Mdot
.55602 .14262 Mdot
.58128 .20569 Mdot
.42064 .76164 Mdot
.76643 .49318 Mdot
.56212 .47294 Mdot
.66776 .24591 Mdot
.71571 .33993 Mdot
.55299 .60915 Mdot
.60353 .17971 Mdot
.47456 .83289 Mdot
.40253 .63144 Mdot
.55036 .13059 Mdot
.41011 .22485 Mdot
.57122 .59291 Mdot
.49175 .81079 Mdot
.39728 .59013 Mdot
.74336 .40152 Mdot
.39581 .37406 Mdot
.50784 .46166 Mdot
.39345 .42375 Mdot
.44395 .80746 Mdot
.4778 .69138 Mdot
.55233 .46653 Mdot
.39236 .53029 Mdot
.39714 .6513 Mdot
.43011 .54748 Mdot
.51927 .77957 Mdot
.67182 .28971 Mdot
.57577 .61265 Mdot
.41883 .19793 Mdot
.57855 .50689 Mdot
.53899 .69168 Mdot
.45542 .67381 Mdot
.76049 .69143 Mdot
.44686 .64844 Mdot
.39426 .30274 Mdot
.67658 .34207 Mdot
.59196 .20961 Mdot
.5695 .58403 Mdot
.55936 .14065 Mdot
.69814 .31374 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00YOooool2
o`0000Gooooo00?o0000ooooooooool0^Oooool00:Gooooo0_l00005ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`;o0000^_ooool00:[ooooo1?l0002jooooo`00Z_ooool3o`000;_ooooo002R
ooooo`?o000000?oooooo`000?l000001?ooool01?l0003oooooo`000?l0002hooooo`00W?ooool2
o`0000Cooooo0ol000000ooooooo0000o`000004ooooo`Co0000^?ooool009cooooo0_l0000=oooo
o`;o0000^oooool00:Wooooo1_l0002iooooo`00ZOooool6o`000;Wooooo002/ooooo`03o`000?oo
oooooooo00Cooooo0_l0002cooooo`00X?ooool2o`0000Oooooo0_l000000ooooooo0000ooooo`05
ooooo`;o0000/oooool00:3ooooo0_l00007ooooo`;o000000?oooooo`000?ooool0^_ooool009[o
oooo0_l0000:ooooo`;o00001?ooool01?l0003oooooooooooooool2o`000;Kooooo002Jooooo`;o
00000_ooool2o`0000Kooooo0_l00004ooooo`?o000000Coooooo`000?l0003o0000]Oooool009ko
oooo0_l00007ooooo`;o00000oooool3o`0000;ooooo0_l00002ooooo`;o0000/Oooool009Oooooo
0_l0000>ooooo`;o00000oooool3o`0000?ooooo0_l000000ooooooo0000o`000004o`000:gooooo
002Gooooo`;o00001Oooool2o`0000cooooo0_l00004ooooo`;o00000oooool4o`000:gooooo002N
ooooo`;o00003?ooool2o`000;[ooooo002Iooooo`;o00004Oooool00ol0003oooooooooo`2ioooo
o`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Co00001Oooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool03_ooool2o`000:Wooooo0029oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo0_l00008ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool03_ooool2o`000:Wooooo0021ooooo`Ko00000_ooool01Ol@
413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03
ooooo`?o0000^Oooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooo
oooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2iooooo`00ROooool01Ol0
003ooooooooooooooooo000000Kooooo0_l00006ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00gooooo1?l0002Xooooo`00ROooool0
1Ol@413ooooooooooooooooo410@00Kooooo0_l00002ooooo`;o00000_ooool00onYZJWoMgMgoooo
o`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03Oooool5o`000:Oooooo0029
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool3o`0000;ooooo0_l00003ooooo`03oc8b<_oo
oooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`;o00002Ooo
ool4o`000003ooooool0003o00000:Cooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool3o`0000?ooooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`03ooooo`;o00002_oo
ool3o`000003ooooool0003o00000:Cooooo002/ooooo`03o`000?oooooooooo00oooooo0ol00005
ooooo`;o0000X?ooool009Sooooo0_l0000Booooo`03o`000?oooooooooo00Oooooo0_l00006oooo
o`;o00000_ooool2o`0000;ooooo0_l0002Pooooo`00Toooool2o`0000?ooooo0_l0000Booooo`03
o`000?oooooooooo00Oooooo0_l0000:ooooo`;o0000Y?ooool009?ooooo1?l0000Eooooo`?o0000
2?ooool2o`000:oooooo002Eooooo`;o00005Oooool00ol0003oooooooooo`08ooooo`;o00002_oo
ool3o`000003ooooool0003o000009oooooo002/ooooo`03o`000?oooooooooo01Cooooo0ol00000
0ooooooo0000o`00002Oooooo`00[?ooool00ol0003oooooooooo`0Cooooo`;o0000Y?ooool00:co
oooo00?o0000ooooooooool04oooool2o`0000Kooooo0_l0002Looooo`00Toooool2o`0001Oooooo
00?o0000ooooooooool06oooool2o`0009cooooo002?ooooo`;o00000_ooool2o`0001Oooooo00?o
0000ooooooooool03Oooool2o`000:[ooooo002?ooooo`;o00006oooool00ol0003oooooooooo`0=
ooooo`;o00002oooool2o`0009gooooo002/ooooo`?o00004Oooool3o`0000Kooooo0ol0002Loooo
o`00[?ooool00ol0003oooooooooo`0Aooooo`?o00001oooool2o`0000;ooooo0_l0002Hooooo`00
[?ooool00ol0003oooooooooo`0Oooooo`;o0000V?ooool00:cooooo00?o0000ooooooooool06_oo
ool2o`000003ooooool0003o000009[ooooo002Aooooo`;o00006Oooool00ol0003oooooooooo`0J
ooooo`;o000000?oooooo`000?l00000V_ooool0097ooooo0_l0000Iooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo01Kooooo1?l00005ooooo`;o000000?oooooo`000?l0
0000UOooool0097ooooo0_l0000Iooooo`03o`000?oooooooooo01Kooooo1?l00005ooooo`;o0000
00?oooooo`000?l00000UOooool0093ooooo0ol0000Iooooo`?o00006_ooool2o`0009gooooo002@
ooooo`;o00006_ooool00ol0003oooooooooo`0Gooooo`;o000000?oooooo`000?l00000WOooool0
0:cooooo00?o0000ooooooooool05oooool2o`0000?ooooo0_l0002Kooooo`00SOooool2o`0001go
oooo00?o0000ooooooooool05oooool2o`0000;ooooo0ol0002Kooooo`00SOooool2o`0001gooooo
00?o0000ooooooooool06oooool3o`0009_ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`03o`000?oooooooooo01_ooooo0_l0000?ooooo`;o0000Roooool00:cooooo00?o0000oooo
ooooool06oooool3o`0000?ooooo0_l00006ooooo`;o000000?oooooo`000?l00000Roooool008ko
oooo0_l0000Looooo`?o00007?ooool3o`000004ooooool0003o0000o`0000Kooooo0_l0002>oooo
o`00S_ooool2o`0001cooooo00?o0000ooooooooool07Oooool2o`000003ooooool0003o000000;o
00001Oooool2o`0000?ooooo1?l00027ooooo`00Soooool2o`0001_ooooo00?o0000ooooooooool0
8?ooool4o`0000Gooooo0ol00002ooooo`Co0000Qoooool008cooooo0_l000000ooooooo0000o`00
000Kooooo`03o`000?oooooooooo02Sooooo1_l00002ooooo`;o0000Qoooool008cooooo0_l0000N
ooooo`03o`000?oooooooooo02Sooooo0ol000000ooooooo0000o`000005o`0008Kooooo002/oooo
o`03o`000?oooooooooo02Cooooo0_l00008ooooo`Go0000Q_ooool0097ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool09?ooool2o`0000?ooooo0_l00005ooooo`?o0000Q_ooool0097ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo02Wooooo0_l00009ooooo`;o0000Poooool008Wooooo1ol000000ooooooo410@ooooo`02oooo
o`03oa0@4?oooooooooo00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0_oooo
o`;o00000oooool2o`0008?ooooo002>ooooo`;o000000?oooooo`000?ooool00_ooool00ol0003o
ooooooooo`0:ooooo`;o000000?oooooogMgMolb<S801Oooool3o`0002gooooo1?l00028ooooo`00
SOooool2o`0000;ooooo00Go0000ooooooooooooooooo`00000<ooooo`?o000000?o<S8bolc<c?oo
ool01?ooool00ol0003oooooooooo`0Yooooo`;o00000_ooool2o`0000;ooooo0_l00002ooooo`;o
0000P_ooool008cooooo0ol00002ooooo`05oa0@4?ooooooooooooooool@41002_ooool3o`000003
ooooool0003o000000Kooooo00?o0000ooooooooool0:Oooool2o`0000Kooooo0_l00002ooooo`;o
0000P_ooool008cooooo0_l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02_ooool3o`000003
ooooool0003o000000Kooooo00?o0000ooooooooool09oooool3o`0000cooooo0_l00021ooooo`00
TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00[ooooo1ol00002ooooo`Co0000:Oooool3o`0000?o
oooo0_l000000ooooooo0000o`000004ooooo`;o0000POooool008_ooooo0_l0000Hooooo`;o0000
0_ooool4o`0002_ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00000oooool2o`00087o
oooo002;ooooo`;o00004_ooool4o`0000Wooooo00?o0000ooooooooool0:Oooool2o`000003oooo
ool0003o000000?ooooo0_l00003ooooo`;o00000oooool2o`0007cooooo002Oooooo`Ko00001ooo
ool00ol0003oooooooooo`0/ooooo`;o00002?ooool2o`0000?ooooo0_l0001looooo`00R_ooool2
o`00013ooooo0_l00005ooooo`;o00001Oooool5o`000;Wooooo002:ooooo`;o00004?ooool4o`00
00[ooooo0ol0000nooooo`;o0000Noooool008gooooo0_l0000?ooooo`;o00002Oooool2o`000003
ooooool0003ooooo02kooooo0_l0000;ooooo`Co0000Noooool008gooooo0_l0000Jooooo`;o0000
00?oooooo`000?ooool0;_ooool3o`0000;ooooo0_l00006ooooo`;o000000?oooooo`000?l00000
N_ooool00:cooooo00?o0000ooooooooool0;_ooool2o`0000;ooooo1Ol000000ooooooo0000o`00
0003ooooo`;o0000N_ooool00:cooooo00?o0000ooooooooool0=?ooool3o`000003ooooool0003o
000000;ooooo0_l0001kooooo`00[?ooool3o`0003;ooooo0_l000000ooooooo0000o`000005oooo
o`;o0000Noooool00:cooooo0ol0000booooo`;o00001Oooool2o`0007kooooo002:ooooo`;o0000
8?ooool3o`0003Gooooo0_l00002ooooo`;o000000?oooooo`000?l00000Noooool008Wooooo0ol0
000Pooooo`03o`000?oooooooooo03Gooooo0_l00005ooooo`;o0000Noooool008Wooooo0_l0000Q
ooooo`04o`000?oooooo0000o`0002kooooo0_l0000;ooooo`;o0000Noooool00:cooooo00Co0000
ooooool0003o0000;_ooool3o`000003ooooool0003o000000Oooooo1?l0001iooooo`00S?ooool2
o`0000gooooo0_l0000?ooooo`03o`000?oooooooooo00Gooooo0_l0000Yooooo`Go00002Oooool2
o`0007Wooooo002<ooooo`;o00003Oooool2o`0000oooooo00?o0000ooooooooool01Oooool2o`00
02[ooooo0_l00003ooooo`;o00001_ooool2o`0007Wooooo002;ooooo`;o00007oooool00ol0003o
ooooooooo`0fooooo`;o00001_ooool2o`0007Wooooo002;ooooo`;o00007oooool00ol0003ooooo
ooooo`0nooooo`;o0000NOooool00:cooooo0ol00003ooooo`;o0000<_ooool2o`0000;ooooo0_l0
00000ooooooo0000o`000002o`0007Oooooo002/ooooo`03o`000?oooooooooo00?ooooo0_l0000_
ooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000Co0000MOooool0
09Wooooo0_l0000Aooooo`03o`000?oooooooooo03Cooooo0_l00004ooooo`;o00001Oooool3o`00
07Gooooo002Iooooo`;o00004Oooool00ol0003oooooooooo`04ooooo`;o0000=?ooool2o`000003
ooooool0003o000000;ooooo0_l0001fooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o0000
0_ooool2o`0003?ooooo0_l0001jooooo`00[?ooool00ol0003oooooooooo`08ooooo`;o0000<?oo
ool2o`0000Sooooo0_l000000ooooooo0000o`00001`ooooo`00[?ooool00ol0003oooooooooo`0g
ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l000000ooooooo0000o`00001`
ooooo`00[?ooool00ol0003oooooooooo`0gooooo`;o00001Oooool4o`0000;ooooo0_l000000ooo
oooo0000o`00001`ooooo`00V?ooool2o`0001;ooooo00?o0000ooooooooool0?_ooool4o`0007Oo
oooo0029ooooo`;o00003Oooool2o`0001;ooooo0ol0000nooooo`;o0000NOooool008Wooooo0_l0
000Qooooo`03o`000?oooooooooo00Gooooo0_l0000nooooo`;o0000L_ooool00:cooooo00?o0000
ooooooooool01Oooool2o`0003[ooooo0ol000000ooooooo0000o`000002o`00073ooooo0029oooo
o`;o00008Oooool00ol0003oooooooooo`11ooooo`?o00000oooool2o`00073ooooo0027ooooo`Co
00008Oooool00ol0003oooooooooo`12ooooo`;o0000MOooool008Oooooo0_l000001Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0@_ooool2o`0007Gooooo0028ooooo`;o000000CoV9RHoooooonH
V9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool02Oooool2o`000003ooooool0003o000002kooooo0_l0001k
ooooo`00POooool6o`000004ooooool0003o0000o`0000;ooooo00?o410@ooooooooool02_ooool0
0onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool2
o`000003ooooool0003o000002kooooo0_l00007ooooo`;o0000L_ooool008Wooooo0_l00002oooo
o`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04oooo
o`?o0000AOooool3o`00077ooooo0026ooooo`;o000000?oooooo`000?ooool00_ooool00ol0003o
ooooooooo`0<ooooo`03ogMgMomVIVKooooo00?ooooo00Co0000ob4Q8Ol0003o<S8b0_l00004oooo
o`03o`000?oooooooooo04Kooooo0_l00002ooooo`;o0000KOooool008Kooooo0_l000000ooooooo
410@ooooo`02ooooo`03oa0@4?oooooooooo00Kooooo0_l00005ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooooooo0_l00004ooooo`03o`000?oooooooooo04[ooooo0_l0001]oooo
o`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo0_l000001_oooooo0000okZj^_oooooo
V9RHoa0@40Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2iooooo`00Q_ooool2
o`000006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Co
oooo1?l00006ooooo`03o`000?oooooooooo00Wooooo0_l0000cooooo`;o0000NOooool008Kooooo
0ol0000Sooooo`03o`000?oooooooooo00Wooooo0_l0000cooooo`;o00002oooool2o`0006cooooo
0027ooooo`;o00008oooool00ol0003oooooooooo`0=ooooo`;o0000??ooool2o`0006cooooo002/
ooooo`03o`000?oooooooooo00gooooo0_l0002Zooooo`00U?ooool2o`0001Kooooo0ol0000<oooo
o`Co0000?Oooool2o`0006[ooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`0<ooooo`Co
0000<Oooool2o`0000[ooooo0_l0001Zooooo`00Zoooool2o`0004?ooooo0_l00008ooooo`;o0000
K?ooool008Kooooo0_l0000Sooooo`;o0000A?ooool2o`0000?ooooo0_l00002ooooo`;o0000K?oo
ool008Kooooo0_l0000Tooooo`03o`000?oooooooooo00[ooooo0_l0000fooooo`;o00000oooool2
o`00073ooooo002/ooooo`03o`000?oooooooooo00[ooooo0_l00010ooooo`;o0000Joooool009Co
oooo0ol0000Eooooo`03o`000?oooooooooo00cooooo0_l0000fooooo`;o00001_ooool2o`0006_o
oooo002Dooooo`?o00005Oooool00ol0003oooooooooo`0<ooooo`;o0000=_ooool2o`0007?ooooo
0028ooooo`;o00008_ooool3o`000;Wooooo0028ooooo`;o00008_ooool00ol0003oooooooooo`0<
ooooo`;o0000=oooool2o`0000?ooooo1?l0001[ooooo`00[?ooool00ol0003oooooooooo`0<oooo
o`;o00000oooool3o`00037ooooo0_l00003ooooo`Co0000Joooool00:cooooo00?o0000oooooooo
ool04Oooool3o`000:Gooooo002Dooooo`?o00005Oooool00ol0003oooooooooo`0Booooo`;o0000
YOooool009Cooooo0ol0000Eooooo`03o`000?oooooooooo04Kooooo0ol0001`ooooo`00[?ooool0
0ol0003oooooooooo`15ooooo`Co0000L?ooool00:cooooo00?o0000ooooooooool03oooool2o`00
03Cooooo0ol0001aooooo`00[?ooool00ol0003oooooooooo`0?ooooo`;o00000oooool2o`00033o
oooo0_l0001aooooo`00[?ooool3o`0001Cooooo0_l0000`ooooo`Co0000Koooool00:cooooo00?o
0000ooooooooool0B?ooool4o`0000;ooooo0_l0001Yooooo`00Qoooool2o`0002?ooooo00?o0000
ooooooooool0B_ooool2o`0000;ooooo0_l0001Yooooo`002Oooool4o`000003oa0@4?oooooooooo
01Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04
ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B43ooooo`Ko00001?ooool00om4A4Co0000o`000003o`0001Gooooo00Co0000oooo
ool0003o00003oooool2o`0000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb
<S;ogMgM01Sooooo1?l000000ol@413oooooooooo`0Booooo`002oooool00ol0003oooooooooo`0H
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01ooo
ool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01oooool3o`0001Gooooo00Co0000ooooool0003o00003oooool2
o`000003ooooool0003o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B400ooooooo0000o`000005ooooo`03ogMgMolb<S;ooooo00ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07oooo
o`03ogMgMolb<S;ooooo01Wooooo00?o0000ooooooooool05?ooool000Ko00001Oooool00ol0003o
ooooooooo`0@ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEE
EOooool02?ooool00ol0003oooooooooo`05ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo
410@013ooooo00?o0000ooooooooool01Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo0_l0000Eooooo`03o`000?oooooooooo00kooooo0_l0
0003ooooo`;o00000oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0
2Oooool00ol0003oooooooooo`0=ooooo`05oa0@4?ooooooooooooooool@41002?ooool2o`0000Ko
oooo00?o0000ooooooooool03Oooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEE
EOooool02?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Cooooo000;ooooo`03
o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo
00Kooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMg
oc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00omgMgOo<S8booooo`0Eooooo`03o`000?oooooooooo00kooooo0_l00002ooooo`;o00001?oo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8b
ooooo`0>ooooo`05o`000?ooooooooooooooool000001Oooool2o`0000Sooooo00?oMgMgoc8b<_oo
ool03_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01So
oooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000;ooooo`;o000000?oooooogMgMomV
IVH01?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Kooooo00?o0000ooooooooool04Oooool3o`00
00Cooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c00?ooooo`04o`000?ooooooooooooooo`;o00001?ooool2o`0000Gooooo
00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003_ooool00omE
EEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06_ooool00ol0003oooooooooo`0D
ooooo`002oooool00ol0003oooooooooo`0Hooooo`05oa0@4?ooooooooooooooool@41003_ooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400;ooooo`;o0000
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Sooooo0ol0000Aooooo`;o0000
1Oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Aooooo`04oa0@4?ooooooooooooooo`;o00002oooool00ol0003oooooooooo`0Aoooo
o`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oo
oooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo017ooooo0_l00005ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool04Ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool05?ooool000Wooooo00?oEEEEofIVI_l000006_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`00
0?lQ8B7oc<c<00Cooooo1?l0000Gooooo`03o`000?oooooooooo00oooooo0_l00007ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0000@oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`Go00001?ooool4o`0001Wooooo00?oEEEEofIVI_l000005_ooool008Sooooo0_l0000R
ooooo`03o`000?oooooooooo00oooooo0_l0000jooooo`;o000000?oooooo`000?l00000JOooool0
08Sooooo0_l0000Rooooo`03o`000?oooooooooo04_ooooo0_l000000ooooooo0000o`00001Yoooo
o`00[?ooool00ol0003oooooooooo`2^ooooo`;o00000_ooool2o`0000Gooooo002/ooooo`03o`00
0?oooooooooo05Gooooo0_l0001Gooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1Oooool00:co
oooo00?o0000ooooooooool04Oooool2o`0004;ooooo0_l0001Hooooo`04omgMgOl0003o410@olc<
c0Kooooo0007oooooooo0000C?l0000<ooooo`04onk^k_lQ8B7o410@onk^kPKooooo0007ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;o00000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool4o`0000Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool2o`000003
ooooool0003ooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool01?lQ8B7oMgMgogMgMolb<S86oooo
o`001oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`03ooooo`;o00002Oooool3o`0001Gooooo00?o0000oooooooo
ool04?ooool2o`0000;ooooo1?l0000?ooooo`03o`000?oooooooooo02?ooooo0_l000001?oooooo
0000o`000?l0000Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02Oooool2o`00
00;ooooo0_l00005ooooo`00ROooool2o`0000Wooooo0ol0000Eooooo`03o`000?oooooooooo01Co
oooo1?l0000iooooo`;o0000I_ooool00:cooooo00Co0000ooooool0003o0000^?ooool008Wooooo
0_l0000Qooooo`04o`000?oooooo0000o`0004cooooo0_l0001Zooooo`00Q_ooool2o`000003oooo
ool0003o0000027ooooo00?o0000ooooooooool00_l0001;ooooo`;o0000J_ooool008Kooooo0_l0
000Tooooo`03o`000?oooooooooo00;o0000]oooool00:cooooo0ol0000Eooooo`;o0000X_ooool0
08Oooooo0_l0000Sooooo`03o`000?oooooooooo01Gooooo0_l0000oooooo`;o0000HOooool008Oo
oooo0ol0000Rooooo`03o`000?oooooooooo017ooooo0ol00012ooooo`;o0000HOooool008Sooooo
0_l0000Rooooo`04o`000?ooooooooooooooo`;o00003_ooool3o`000:Gooooo0028ooooo`;o0000
2_ooool2o`0001Kooooo00Co0000oooooooooooooooo0_l0001@ooooo`;o0000I?ooool008Sooooo
0_l0000:ooooo`;o00005_ooool00ol0003oooooooooo`0Aooooo`Co0000>_ooool2o`0000;ooooo
0_l0001Tooooo`00Q_ooool3o`0002?ooooo00?o0000ooooooooool04Oooool4o`0003[ooooo0_l0
001Xooooo`00Q_ooool3o`0002?ooooo00?o0000ooooooooool04_ooool2o`000003ooooool0003o
00000:;ooooo002Cooooo`?o00005_ooool00ol0003oooooooooo`0Booooo`;o000000?oooooo`00
0?l00000X_ooool009?ooooo0ol0000Fooooo`?o0000Coooool2o`0000;ooooo0ol0001Sooooo`00
[?ooool00ol0003oooooooooo`1?ooooo`;o00000_ooool3o`0006?ooooo002/ooooo`03o`000?oo
oooooooo01Oooooo0_l0000iooooo`;o0000IOooool008Wooooo0_l0000Qooooo`03o`000?oooooo
oooo01Gooooo1?l0000iooooo`;o0000IOooool008Wooooo0_l0000Qooooo`03o`000?oooooooooo
01Gooooo0_l0002Rooooo`00[?ooool00ol0003oooooooooo`0Booooo`;o000000?oooooo`000?l0
00000_l0000looooo`;o0000H_ooool008Oooooo0_l0000Sooooo`03o`000?oooooooooo01;ooooo
0_l000000ooooooo0000o`000002o`0003Sooooo0_l00002ooooo`;o0000H_ooool008Oooooo0_l0
000Sooooo`03o`000?oooooooooo01;ooooo0_l0000mooooo`;o0000I_ooool00:cooooo0ol0000A
ooooo`;o0000Y_ooool00:cooooo00?o0000ooooooooool04Oooool2o`00047ooooo0_l0001Soooo
o`00[?ooool00ol0003oooooooooo`0Cooooo`;o0000?oooool3o`0006;ooooo002Eooooo`;o0000
5Oooool00ol0003oooooooooo`0@ooooo`Ko0000?oooool2o`0006;ooooo002Eooooo`;o00005Ooo
ool00ol0003oooooooooo`0@ooooo`Ko0000Xoooool008[ooooo0_l0000Pooooo`03o`000?oooooo
oooo0;Wooooo002:ooooo`;o00008?ooool00ol0003oooooooooo`0Booooo`Co0000Xoooool00:co
oooo00?o0000ooooooooool04_ooool4o`0003cooooo0_l0001Uooooo`00[?ooool3o`0001Kooooo
0_l0000jooooo`;o0000IOooool009Kooooo0_l0000Dooooo`?o00005_ooool2o`000:7ooooo002F
ooooo`;o00005?ooool3o`000;Wooooo002/ooooo`?o00003_ooool2o`000:Wooooo0028ooooo`?o
00008Oooool00ol0003oooooooooo`0>ooooo`;o00001_ooool2o`000:7ooooo0028ooooo`?o0000
2oooool2o`0001Cooooo00?o0000ooooooooool05_ooool2o`000:7ooooo0029ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@03ooooool0003o000000Ko00001?ooool01Om4A4Co0000
o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0EOooool2o`0006;ooooo0029ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@;ooooo0_l000001OnHV9So8B4Qonk^k_ooooooA4A4
00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0@ooooo`;o0000@oooool2o`00
06;ooooo0029ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09oooo
o`03o`000?oooooooooo00?ooooo0ol0000>ooooo`Go0000Y_ooool008Wooooo00Go0000oooooooo
ooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`0>ooooo`Go0000?_ooool2o`000003ooooool0003o000006?ooooo0029ooooo`03
o`000?oooooo000000;o00003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`0>ooooo`?o0000@?ooool2o`000003ooooool0003o0000
06?ooooo0029ooooo`05oa0@4?oooooo0000o`000?l@41003oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03Oooool3o`0000;ooooo0_l0002Uoooo
o`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03Oooool2o`0000?ooooo0_l00000
0ooooooo0000o`00002Rooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`0?ooooo`;o00001?oo
ool2o`000:;ooooo002/ooooo`03o`000?oooooooooo00oooooo0_l00002ooooo`;o0000Y?ooool0
0:cooooo00?o0000ooooooooool04_ooool3o`0003cooooo0_l0001Vooooo`00V_ooool2o`00013o
oooo00?o0000ooooooooool04_ooool3o`0003cooooo0_l0001Vooooo`00R_ooool2o`0000kooooo
0_l0000=ooooo`;o000000Coooooo`000?l0003o00004oooool2o`0003gooooo0ol0001Tooooo`00
R_ooool2o`0000kooooo0_l0000=ooooo`;o000000?oooooo`000?ooool0Doooool3o`0006Cooooo
002Jooooo`;o00003Oooool2o`000003ooooool0003ooooo0;[ooooo002/ooooo`03o`000?oooooo
oooo01?ooooo0_l0002Tooooo`00[?ooool00ol0003oooooooooo`0Cooooo`;o0000Y?ooool008_o
oooo0_l0000Oooooo`03o`000?oooooooooo0;Wooooo002;ooooo`;o00007oooool00ol0003ooooo
ooooo`0>ooooo`;o0000ZOooool008[ooooo0_l0000Aooooo`;o00001Oooool2o`0000Kooooo00?o
0000ooooooooool03_ooool2o`000003ooooool0003o00000:Kooooo002:ooooo`;o00004Oooool2
o`000003ooooool0003o000000;ooooo0_l00006ooooo`?o00004Oooool2o`000:Kooooo002:oooo
o`;o00005?ooool2o`0000Cooooo0_l00004ooooo`03o`000?oooooooooo0;Wooooo002:ooooo`;o
00004oooool2o`0000Gooooo0ol00003ooooo`03o`000?oooooooooo0;Wooooo002>ooooo`;o0000
3oooool2o`0000Kooooo0_l00003ooooo`03o`000?oooooooooo00oooooo0_l0002Xooooo`00S_oo
ool2o`0001;ooooo1?l00006ooooo`03o`000?oooooooooo00cooooo0_l000000ooooooo0000o`00
002Xooooo`00X_ooool4o`0000Kooooo00?o0000ooooooooool02Oooool2o`000003ooooool0003o
000004Gooooo0_l0001Tooooo`00Y?ooool2o`0000Kooooo00?o0000ooooooooool02Oooool2o`00
00Kooooo0_l00010ooooo`;o0000I?ooool00:cooooo00?o0000ooooooooool04Oooool2o`000:Ko
oooo002/ooooo`?o00003?ooool4o`00043ooooo0_l0001Wooooo`00[?ooool00ol0003ooooooooo
o`0<ooooo`Co0000@?ooool2o`0006Oooooo002>ooooo`;o00007?ooool00ol0003oooooooooo`0;
ooooo`;o0000[?ooool008kooooo0_l0000Looooo`03o`000?oooooooooo00_ooooo0_l0002/oooo
o`00[?ooool00ol0003oooooooooo`08ooooo`;o000000?oooooo`000?l00000A?ooool2o`0006Ko
oooo002/ooooo`03o`000?oooooooooo00Sooooo0_l00017ooooo`;o0000I_ooool008gooooo0_l0
000Mooooo`03o`000?oooooooooo04oooooo0_l0001Xooooo`00SOooool3o`0001cooooo00?o0000
ooooooooool0Coooool2o`0006Sooooo002=ooooo`?o00007?ooool3o`0000Kooooo0_l00002oooo
o`Ko0000ZOooool00:cooooo00?o0000ooooooooool01_ooool2o`0000;ooooo1_l0002Yooooo`00
[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0:ooooo`;o000000?o
ooooo`000?l00000Z_ooool00:cooooo00?o0000ooooooooool02_ooool2o`000003ooooool0003o
000003oooooo0_l0001Yooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool0C_ooool2o`00
06Wooooo002>ooooo`Co000000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;Wooooo002@ooooo`;o000000CoV9RHoooo
oonHV9SoMgMg1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`06
ooooo`;o0000A_ooool2o`0006Wooooo002Aooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo0ol00015ooooo`;o0000JOooool0
097ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00005
ooooo`Co0000/?ooool0097ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`05ooooo`;o0000/_ooool0097ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0^Ooo
ool0097ooooo0_l000000oooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool2o`000;3ooooo002>ooooo`;o000000Koooooo`000?l0003o0000oc8b<_o^
k^h<ooooo`Co00001_ooool01?l0003oooooooooooooool2o`0000?ooooo0ol0002`ooooo`00S_oo
ool2o`000004ooooool0003o0000o`0001Sooooo00Co0000oooooooooooooooo0_l00003ooooo`;o
0000/Oooool0097ooooo0_l00002ooooo`;o00005Oooool00ol0003oooooooooo`08ooooo`;o0000
[oooool009Gooooo0_l0000Eooooo`03o`000?oooooooooo00Sooooo0_l0002_ooooo`00T?ooool2
o`0001[ooooo0ol0002iooooo`00T?ooool4o`0001Sooooo00?o0000ooooooooool00oooool2o`00
0;Cooooo002Booooo`?o00005oooool00ol0003oooooooooo`03ooooo`;o0000]?ooool009?ooooo
0_l0000Gooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00?ooooo0_l0
002dooooo`00[?ooool00ol0003oooooooooo`03ooooo`;o0000]?ooool00:cooooo00?o0000oooo
ooooool01Oooool2o`000;;ooooo002/ooooo`03o`000?oooooooooo00Gooooo0_l0002booooo`00
[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Iooooo`;o00004?ooool2
o`000;_ooooo002Iooooo`;o00004?ooool4o`000;Wooooo002Yooooo`;o000000?oooooo`000?l0
00000ol0002gooooo`00Yoooool4o`000004ooooool0003oooooooooo`;o0000]oooool009cooooo
0_l00009ooooo`Co000000Coooooo`000?oooooooooo1?l0002eooooo`00W?ooool3o`0000Wooooo
1Ol00002ooooo`Co0000]Oooool009Wooooo0_l00002ooooo`Co00002Oooool5o`000;Wooooo002I
ooooo`;o00001?ooool2o`0000Wooooo0ol0002kooooo`00Z_ooool3o`000;_ooooo002Eooooo`;o
00003?ooool2o`0000Oooooo1?l0002hooooo`00UOooool2o`0000cooooo0_l00007ooooo`Co0000
^?ooool00:7ooooo0_l00008ooooo`Co0000^Oooool009[ooooo0_l00005ooooo`;o00001Oooool2
o`000003ooooool0003o000000;o0000^Oooool009[ooooo0_l00005ooooo`Co00000oooool2o`00
00;ooooo00?o0000ooooooooool0^Oooool009Sooooo0_l00007ooooo`Co00001oooool00ol0003o
ooooooooo`2iooooo`00V?ooool2o`0001;ooooo0ol0002iooooo`00Woooool2o`0000?ooooo0_l0
0006ooooo`03o`000?oooooooooo0;Wooooo002Oooooo`;o00000oooool2o`0000Kooooo00?o0000
ooooooooool0^Oooool00:3ooooo0ol00009ooooo`03o`000?oooooooooo0;Wooooo002Pooooo`?o
00002Oooool00ol0003oooooooooo`2iooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00?oA4A4o`000?l000000_l00005ooooo`03
o`000?oooooooooo0;Wooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Ko
oooo00?oEEEEojVYZOooool01oooool2o`0000Gooooo00?o0000ooooooooool0^Oooool008Wooooo
00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`2iooooo`00ROooool01Ol0003ooooooooooooooooo000000ko
oooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`?o0000^Oooool008Wooooo
00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c005ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05oa0@4?oooooooooooooo
ool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0^Oooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooo
oooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Wooooo0029oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Ooo
ool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:co
oooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`00
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:;ooooo1?l00000
0ol@413oooooooooo`03ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000ooooooooool01Oooool3o`000;Wo
oooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002T
ooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Rooooo`03
oeEEEOmVIVKo00000<?ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo002Zooooo`04oa0@4?l0003o0000o`000;[ooooo002[ooooo`03o`000?oooooooooo0;[o
oooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`06o`000?mgMgOo0000o`000?mEEEGo
k^k^]oooool00:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomEEEFgooooo`00Zoooool00ol0003o
k^k^ooooo`02ooooo`03o`000?oooooooooo0;Gooooo002[ooooo`03o`000?o^k^kooooo00;ooooo
00?o0000ooooooooool0]Oooool00:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomVIVJgooooo`00
Z_ooool00ol@413o0000ogMgM`02o`000003ofIVI_o^k^kooooo0;Kooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.43717 .86007 Mdot
.43209 .86332 Mdot
.44969 .42436 Mdot
.45813 .25863 Mdot
.58471 .44227 Mdot
.50287 .86375 Mdot
.51757 .50585 Mdot
.50719 .02803 Mdot
.58012 .13835 Mdot
.51149 .26947 Mdot
.54257 .33807 Mdot
.5872 .12249 Mdot
.41597 .83536 Mdot
.49692 .23171 Mdot
.66103 .24803 Mdot
.46844 .23717 Mdot
.54369 .76238 Mdot
.41602 .83666 Mdot
.56239 .36816 Mdot
.37433 .48439 Mdot
.38041 .51989 Mdot
.38779 .63695 Mdot
.39146 .3265 Mdot
.39696 .74728 Mdot
.66976 .25119 Mdot
.60072 .49538 Mdot
.56444 .42906 Mdot
.57197 .42565 Mdot
.38299 .31552 Mdot
.39799 .72043 Mdot
.40922 .19772 Mdot
.54454 .0892 Mdot
.561 .09766 Mdot
.49372 .84808 Mdot
.53886 .79203 Mdot
.4425 .08751 Mdot
.49093 .0456 Mdot
.57062 .44024 Mdot
.46106 .05642 Mdot
.5591 .08241 Mdot
.62961 .17394 Mdot
.52765 .80485 Mdot
.50086 .85732 Mdot
.49444 .89424 Mdot
.49831 .88426 Mdot
.59219 .45983 Mdot
.5416 .34512 Mdot
.49006 .03193 Mdot
.6022 .57062 Mdot
.42853 .10509 Mdot
.50797 .0509 Mdot
.42471 .10461 Mdot
.77955 .45147 Mdot
.4899 .86467 Mdot
.54398 .79094 Mdot
.57911 .12979 Mdot
.53211 .05602 Mdot
.56525 .72015 Mdot
.48689 .03585 Mdot
.50367 .87599 Mdot
.59378 .50131 Mdot
.69017 .25521 Mdot
.494 .06155 Mdot
.42769 .61091 Mdot
.62941 .20413 Mdot
.54532 .08696 Mdot
.5217 .2957 Mdot
.50027 .26629 Mdot
.5618 .38087 Mdot
.38242 .60846 Mdot
.59951 .63815 Mdot
.52237 .51247 Mdot
.53459 .32955 Mdot
.50431 .26 Mdot
.49474 .06228 Mdot
.47596 .35351 Mdot
.77964 .45256 Mdot
.5781 .62266 Mdot
.4111 .14743 Mdot
.54951 .72527 Mdot
.42466 .13502 Mdot
.39095 .65675 Mdot
.46877 .25237 Mdot
.53962 .78692 Mdot
.50855 .03413 Mdot
.42932 .32452 Mdot
.58539 .44287 Mdot
.58518 .5516 Mdot
.58503 .66901 Mdot
.50778 .28307 Mdot
.67924 .27242 Mdot
.75594 .39552 Mdot
.42391 .59052 Mdot
.59075 .47305 Mdot
.42186 .54869 Mdot
.74479 .35127 Mdot
.49778 .23401 Mdot
.55983 .11653 Mdot
.78099 .45058 Mdot
.60199 .61736 Mdot
.41922 .81143 Mdot
.59883 .61816 Mdot
.61506 .16504 Mdot
.4701 .90383 Mdot
.38183 .39284 Mdot
.49343 .84991 Mdot
.58289 .6883 Mdot
.56406 .36722 Mdot
.42436 .59631 Mdot
.37953 .50655 Mdot
.4942 .23082 Mdot
.43445 .32169 Mdot
.55243 .10015 Mdot
.38137 .35196 Mdot
.79637 .51718 Mdot
.50895 .65185 Mdot
.59173 .54709 Mdot
.49045 .02137 Mdot
.50404 .03697 Mdot
.54445 .11199 Mdot
.4041 .78403 Mdot
.66692 .21484 Mdot
.40263 .23853 Mdot
.37711 .38521 Mdot
.38029 .55992 Mdot
.47741 .24655 Mdot
.39394 .243 Mdot
.73741 .33711 Mdot
.38594 .54251 Mdot
.44911 .67966 Mdot
.38242 .51886 Mdot
.40254 .73528 Mdot
.61259 .15643 Mdot
.53173 .82522 Mdot
.4989 .86307 Mdot
.38389 .29879 Mdot
.41434 .12485 Mdot
.39291 .24397 Mdot
.53717 .33881 Mdot
.59549 .14308 Mdot
.6515 .22646 Mdot
.72896 .3507 Mdot
.41924 .47146 Mdot
.55821 .35925 Mdot
.54861 .75352 Mdot
.3754 .45328 Mdot
.50177 .02868 Mdot
.80182 .53676 Mdot
.57782 .52288 Mdot
.58704 .5453 Mdot
.62029 .13967 Mdot
.60358 .59511 Mdot
.5441 .32496 Mdot
.40629 .79947 Mdot
.52209 .49303 Mdot
.43458 .84026 Mdot
.44494 .06161 Mdot
.46561 .05226 Mdot
.52114 .05463 Mdot
.51173 .06852 Mdot
.43683 .07327 Mdot
.60297 .52559 Mdot
.3945 .22134 Mdot
.556 .07001 Mdot
.45028 .08106 Mdot
.4493 .85371 Mdot
.39702 .68721 Mdot
.50999 .03876 Mdot
.3797 .4252 Mdot
.56218 .38545 Mdot
.40078 .17924 Mdot
.45786 .06519 Mdot
.44108 .31165 Mdot
.56646 .41991 Mdot
.58679 .50821 Mdot
.58032 .48681 Mdot
.59739 .14898 Mdot
.74364 .35155 Mdot
.42974 .82666 Mdot
.47041 .70476 Mdot
.40846 .16329 Mdot
.39062 .23688 Mdot
.58177 .10915 Mdot
.4693 .22979 Mdot
.63114 .17491 Mdot
.43996 .65464 Mdot
.59874 .16857 Mdot
.74201 .35751 Mdot
.49847 .03408 Mdot
.56239 .07911 Mdot
.51689 .83729 Mdot
.65911 .20568 Mdot
.3748 .48626 Mdot
.42622 .58502 Mdot
.69994 .28382 Mdot
.51506 .03942 Mdot
.6137 .1416 Mdot
.61135 .15709 Mdot
.58996 .48393 Mdot
.75541 .36594 Mdot
.59075 .67627 Mdot
.47665 .70098 Mdot
.47597 .7018 Mdot
.52239 .52398 Mdot
.58583 .4992 Mdot
.76064 .38151 Mdot
.39662 .68864 Mdot
.426 .55616 Mdot
.48433 .88291 Mdot
.41872 .45024 Mdot
.46268 .72003 Mdot
.5325 .30602 Mdot
.42652 .86318 Mdot
.58183 .6061 Mdot
.38052 .40704 Mdot
.49463 .24778 Mdot
.39355 .65539 Mdot
.57802 .61669 Mdot
.56775 .08435 Mdot
.46694 .72066 Mdot
.44782 .87223 Mdot
.53927 .05983 Mdot
.59284 .53302 Mdot
.53934 .09481 Mdot
.37832 .49497 Mdot
.44671 .08947 Mdot
.5162 .29997 Mdot
.58198 .44439 Mdot
.47468 .91189 Mdot
.42611 .39357 Mdot
.65953 .2442 Mdot
.65552 .19146 Mdot
.45209 .25885 Mdot
.50497 .40205 Mdot
.76695 .42633 Mdot
.57741 .6724 Mdot
.55384 .36995 Mdot
.67147 .22686 Mdot
.56746 .42055 Mdot
.46956 .90519 Mdot
.38189 .4537 Mdot
.40883 .76935 Mdot
.69681 .27113 Mdot
.53012 .82261 Mdot
.37769 .46284 Mdot
.59925 .63873 Mdot
.51287 .04965 Mdot
.42206 .46384 Mdot
.49675 .05613 Mdot
.53074 .77756 Mdot
.60041 .63399 Mdot
.47575 .05197 Mdot
.62191 .15554 Mdot
.50652 .65867 Mdot
.42348 .47456 Mdot
.5198 .08232 Mdot
.59509 .56308 Mdot
.56698 .42753 Mdot
.57335 .74228 Mdot
.47839 .35274 Mdot
.55617 .0872 Mdot
.48437 .03132 Mdot
.59462 .61328 Mdot
.55303 .36679 Mdot
.44346 .09252 Mdot
.46657 .70818 Mdot
.59332 .63239 Mdot
.42204 .81542 Mdot
.55242 .3862 Mdot
.44211 .8478 Mdot
.4585 .06763 Mdot
.58454 .62221 Mdot
.40771 .17735 Mdot
.55233 .77878 Mdot
.49217 .23156 Mdot
.5749 .66971 Mdot
.42983 .08774 Mdot
.45753 .238 Mdot
.56746 .36759 Mdot
.52036 .06439 Mdot
.51468 .2633 Mdot
.4617 .88142 Mdot
.40372 .18038 Mdot
.49584 .69895 Mdot
.52066 .30285 Mdot
.52372 .08355 Mdot
.6006 .14442 Mdot
.56238 .35898 Mdot
.52042 .49305 Mdot
.57737 .56349 Mdot
.37582 .50732 Mdot
.59006 .5251 Mdot
.42909 .12589 Mdot
.74435 .36869 Mdot
.5142 .06522 Mdot
.64489 .21888 Mdot
.54932 .11015 Mdot
.50831 .40689 Mdot
.4516 .04506 Mdot
.70835 .31396 Mdot
.37775 .57896 Mdot
.65752 .24214 Mdot
.80441 .5455 Mdot
.58739 .62858 Mdot
.56839 .75678 Mdot
.41273 .79019 Mdot
.52696 .06666 Mdot
.6482 .20849 Mdot
.53753 .32899 Mdot
.53664 .0851 Mdot
.5965 .55914 Mdot
.48569 .69155 Mdot
.40579 .78527 Mdot
.54789 .75654 Mdot
.39361 .71661 Mdot
.62143 .14346 Mdot
.49268 .69524 Mdot
.43595 .8514 Mdot
.50561 .83515 Mdot
.63331 .20872 Mdot
.48657 .70789 Mdot
.59364 .12508 Mdot
.69295 .28613 Mdot
.71869 .30462 Mdot
.47472 .24233 Mdot
.54996 .7982 Mdot
.55277 .76517 Mdot
.50131 .0672 Mdot
.57645 .39881 Mdot
.50871 .64143 Mdot
.51565 .46074 Mdot
.57903 .69512 Mdot
.52668 .04703 Mdot
.54023 .10985 Mdot
.42535 .59934 Mdot
.40914 .79803 Mdot
.45773 .70141 Mdot
.52167 .53503 Mdot
.46788 .91075 Mdot
.5173 .84335 Mdot
.45099 .85632 Mdot
.60224 .53358 Mdot
.58492 .50665 Mdot
.77453 .41719 Mdot
.58683 .60772 Mdot
.3855 .55481 Mdot
.42243 .53368 Mdot
.57903 .12565 Mdot
.56423 .43303 Mdot
.39702 .22151 Mdot
.38423 .46724 Mdot
.42195 .57748 Mdot
.57471 .62086 Mdot
.72612 .34045 Mdot
.57088 .10053 Mdot
.42503 .08853 Mdot
.43436 .10046 Mdot
.59632 .58849 Mdot
.57192 .71862 Mdot
.44161 .08424 Mdot
.58725 .64796 Mdot
.57557 .10698 Mdot
.70498 .26505 Mdot
.37763 .45905 Mdot
.61738 .16463 Mdot
.59824 .13093 Mdot
.59978 .12641 Mdot
.5205 .55836 Mdot
.57952 .66314 Mdot
.65761 .23873 Mdot
.54184 .06864 Mdot
.52054 .56126 Mdot
.41017 .18804 Mdot
.56802 .66883 Mdot
.50858 .85888 Mdot
.42243 .82172 Mdot
.56756 .1257 Mdot
.46402 .90238 Mdot
.48398 .03914 Mdot
.53571 .10721 Mdot
.39303 .31448 Mdot
.40997 .13378 Mdot
.38294 .46773 Mdot
.66195 .23858 Mdot
.79985 .5126 Mdot
.55806 .12866 Mdot
.45966 .88203 Mdot
.51854 .54704 Mdot
.67694 .25401 Mdot
.5949 .63842 Mdot
.51502 .45618 Mdot
.56988 .09228 Mdot
.38171 .59668 Mdot
.51595 .61403 Mdot
.51234 .27639 Mdot
.59722 .52429 Mdot
.55773 .38393 Mdot
.48386 .0273 Mdot
.38736 .69125 Mdot
.70571 .30158 Mdot
.58291 .11001 Mdot
.53582 .78245 Mdot
.77478 .44582 Mdot
.55303 .75438 Mdot
.57967 .4691 Mdot
.57865 .4337 Mdot
.4855 .34676 Mdot
.53946 .06317 Mdot
.58873 .12515 Mdot
.5635 .42333 Mdot
.421 .44984 Mdot
.5111 .24897 Mdot
.44027 .27835 Mdot
.62682 .15631 Mdot
.58799 .43722 Mdot
.42682 .12256 Mdot
.43087 .3468 Mdot
.55024 .34412 Mdot
.47069 .71283 Mdot
.58737 .44717 Mdot
.49578 .8445 Mdot
.54191 .32301 Mdot
.42539 .54962 Mdot
.64639 .1796 Mdot
.5895 .13453 Mdot
.4472 .49682 Mdot
.53955 .7924 Mdot
.58166 .6913 Mdot
.40454 .72204 Mdot
.56565 .67786 Mdot
.56281 .39359 Mdot
.66571 .22875 Mdot
.74137 .32874 Mdot
.44014 .87411 Mdot
.79261 .49972 Mdot
.50408 .88468 Mdot
.43009 .61385 Mdot
.61265 .18826 Mdot
.66318 .24934 Mdot
.55319 .37674 Mdot
.38827 .37983 Mdot
.77628 .42848 Mdot
.42345 .41153 Mdot
.51569 .61034 Mdot
.58062 .51283 Mdot
.42639 .12668 Mdot
.56412 .68957 Mdot
.75589 .37928 Mdot
.44478 .67729 Mdot
.48675 .86406 Mdot
.54967 .76801 Mdot
.43056 .63861 Mdot
.47619 .70849 Mdot
.47277 .22603 Mdot
.51423 .03588 Mdot
.50299 .67379 Mdot
.39721 .20862 Mdot
.44257 .88278 Mdot
.46476 .89295 Mdot
.39764 .22334 Mdot
.43031 .12523 Mdot
.54823 .75851 Mdot
.72371 .29318 Mdot
.5113 .27294 Mdot
.52612 .04591 Mdot
.61168 .13993 Mdot
.55665 .40915 Mdot
.43901 .06103 Mdot
.57506 .65252 Mdot
.51963 .80031 Mdot
.39243 .24906 Mdot
.42897 .84285 Mdot
.56839 .39291 Mdot
.57693 .61301 Mdot
.51154 .82386 Mdot
.66397 .20152 Mdot
.46464 .87301 Mdot
.46184 .36457 Mdot
.476 .87255 Mdot
.5599 .70348 Mdot
.52395 .51811 Mdot
.49895 .26658 Mdot
.49949 .85425 Mdot
.52534 .82603 Mdot
.49508 .68572 Mdot
.5911 .57957 Mdot
.5477 .08971 Mdot
.58083 .41265 Mdot
.42121 .81061 Mdot
.5413 .30689 Mdot
.57566 .49168 Mdot
.519 .57992 Mdot
.79706 .49143 Mdot
.51407 .60633 Mdot
.4494 .89518 Mdot
.5734 .14207 Mdot
.43981 .095 Mdot
.56311 .38403 Mdot
.39853 .21011 Mdot
.58363 .11374 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Xooooo`;o0000
0_ooool00ol0003oooooooooo`2iooooo`00Z?ooool2o`0000;ooooo0ol0002iooooo`00Y_ooool2
o`0000Cooooo1?l0002hooooo`00Y_ooool4o`0000;ooooo1?l0002hooooo`00Y_ooool4o`000004
ooooool0003o0000ooooo`;o0000^?ooool00:Oooooo0_l00002ooooo`Oo0000]_ooool00:Kooooo
0ol00003ooooo`Oo0000]Oooool00:Kooooo0_l00004ooooo`03o`000?oooooooooo00Co0000]Ooo
ool009cooooo0_l0000;ooooo`;o000000?oooooo`000?ooool01_ooool2o`000;;ooooo002Loooo
o`;o00002oooool2o`000003ooooool0003ooooo00;ooooo0_l00002ooooo`;o0000/_ooool00:3o
oooo0_l00002ooooo`;o00001_ooool6o`000;Kooooo002Pooooo`;o00000_ooool2o`0000Cooooo
0ol000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l00000/?ooool009oooooo0_l0
0009ooooo`?o00001_ooool2o`000003ooooool0003o00000;3ooooo002Gooooo`Co00001?ooool2
o`0000Wooooo0ol0000<ooooo`;o0000[Oooool009Oooooo1?l00003ooooo`;o00002_ooool3o`00
00?ooooo1?l00005ooooo`;o0000[Oooool009kooooo0_l0000<ooooo`;o00000_ooool6o`0000?o
oooo0_l0002]ooooo`00W_ooool2o`0000cooooo0_l000000ooooooo0000o`000003ooooo`;o0000
0oooool2o`0000?ooooo0_l0002Xooooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool00_l0
0008ooooo`;o00000oooool2o`000:Sooooo002Gooooo`;o00004oooool3o`000;Wooooo002/oooo
o`03o`000?oooooooooo017ooooo0_l0002Vooooo`00Voooool2o`0000oooooo00?o0000oooooooo
ool00oooool2o`0000_ooooo0ol0002Vooooo`00V?ooool2o`000003ooooool0003o000000oooooo
00?o0000ooooooooool00oooool3o`0000?ooooo0_l00005ooooo`;o000000?oooooo`000?l00000
Y?ooool009?ooooo0ol00002ooooo`Co00004?ooool00ol0003oooooooooo`04ooooo`;o00000ooo
ool5o`000003ooooool0003o000000;ooooo0_l0002Tooooo`00Toooool3o`0000?ooooo0ol0000@
ooooo`03o`000?oooooooooo00_ooooo0ol000000ooooooo0000o`000003ooooo`;o0000Xoooool0
09Sooooo0ol0000Aooooo`03o`000?oooooooooo00[ooooo1?l00006ooooo`;o0000Xoooool009So
oooo0_l0000Booooo`03o`000?oooooooooo00[ooooo0_l00005ooooo`;o0000Y_ooool009Kooooo
0_l0000Dooooo`?o00003_ooool2o`000004ooooool0003o0000ooooo`;o0000Xoooool009?ooooo
0_l000000ooooooo0000o`00000Dooooo`03o`000?oooooooooo00kooooo0_l00004ooooo`;o0000
Xoooool009?ooooo0ol0000Fooooo`03o`000?oooooooooo00Sooooo0_l0000<ooooo`;o0000XOoo
ool009Cooooo0_l0000Fooooo`03o`000?oooooooooo00Sooooo1?l000000ooooooo0000o`000007
ooooo`Co0000Woooool00:cooooo00?o0000ooooooooool02_ooool5o`0000Wooooo0_l0002Ooooo
o`00[?ooool00ol0003oooooooooo`0;ooooo`;o00000oooool2o`0000Kooooo0_l0002Oooooo`00
ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo013ooooo0_l0002Woooo
o`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l00006ooooo`03oeEEEOnYZJWooooo
00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Iooooo`;o0000W_ooool0087o
oooo1_l00002ooooo`06oa0@4?ooooooooooooooool@413ooooo0_l00002ooooo`Co00001?ooool0
0onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0000Cooooo`;o00000_ooool6
o`0009cooooo0029ooooo`06o`000?ooooooooooooooool0003ooooo0_l00002ooooo`Co00001Ooo
ool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool04?oo
ool2o`000003ooooool0003o000000;ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o0000
VOooool008Wooooo00Go0000ooooooooooooooooo`000005ooooo`;o00001oooool00omEEEGoc<c<
ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0@ooooo`;o
00001Oooool2o`0000Cooooo0ol0002Iooooo`00ROooool01Ol@413ooooooooooooooooo410@00;o
00003?ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool05oooool2o`000004ooooool0003o0000ooooo`;o0000V_ooool008Wooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`02o`0000?ooooo0_l00004ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo01[ooooo0_l0002Mooooo`00ROooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_l00004ooooo`Go00001?ooool4o`0000Kooooo00?o0000
ooooooooool05oooool2o`0000Sooooo0_l000000ooooooo0000o`00002Cooooo`00[?ooool00ol0
003oooooooooo`0Eooooo`Co00000oooool2o`0000?ooooo1_l0002Booooo`00[?ooool00ol0003o
ooooooooo`0Eooooo`;o00001Oooool4o`0000;ooooo0_l000000ooooooo0000o`00002Booooo`00
S_ooool2o`0001cooooo00?o0000ooooooooool07Oooool3o`0009Wooooo002>ooooo`;o00007?oo
ool3o`0001gooooo0_l0002Jooooo`00[?ooool00ol0003oooooooooo`0Uooooo`;o0000T_ooool0
0:cooooo00?o0000ooooooooool08Oooool3o`000004ooooool0003o0000o`00097ooooo002/oooo
o`03o`000?oooooooooo027ooooo0ol00002ooooo`;o0000TOooool008gooooo0_l0000Mooooo`03
o`000?oooooooooo02?ooooo0_l0002Dooooo`00SOooool2o`0001gooooo00?o0000ooooooooool0
8oooool2o`0009Cooooo002/ooooo`03o`000?oooooooooo01gooooo0_l0002Jooooo`00[?ooool0
0ol0003oooooooooo`0Mooooo`;o00002?ooool2o`00093ooooo002=ooooo`;o00007Oooool3o`00
02Oooooo0ol0002?ooooo`00Roooool4o`0001gooooo00?o0000ooooooooool0:?ooool2o`0000?o
oooo0_l0002:ooooo`00Roooool3o`0001kooooo00?o0000ooooooooool0;Oooool2o`0008[ooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002>ooooo`;o00007?ooool00ol0003oooooooooo`0R
ooooo`;o0000UOooool008kooooo0_l0000Looooo`03o`000?oooooooooo02;ooooo0_l0000<oooo
o`;o0000Qoooool00:cooooo00?o0000ooooooooool0<?ooool2o`0008Oooooo002>ooooo`;o0000
7?ooool00ol0003oooooooooo`2iooooo`00S_ooool2o`0001cooooo0ol0000cooooo`;o0000Q?oo
ool00:cooooo00?o0000ooooooooool09oooool2o`0000[ooooo0_l00024ooooo`00[?ooool00ol0
003oooooooooo`0Wooooo`;o00002?ooool2o`0008Kooooo002:ooooo`;o00008?ooool00ol0003o
ooooooooo`0Yooooo`;o00000_ooool2o`0000;ooooo0_l00026ooooo`00R_ooool2o`00023ooooo
00?o0000ooooooooool0:Oooool2o`0000;ooooo0_l0002:ooooo`00[?ooool00ol0003ooooooooo
o`0dooooo`;o0000Poooool00:cooooo00?o0000ooooooooool0;?ooool2o`0000Kooooo0_l00023
ooooo`00ROooool3o`00023ooooo00?o0000ooooooooool0;?ooool2o`0008_ooooo0029ooooo`?o
00008?ooool3o`000;Wooooo002:ooooo`;o00005oooool2o`0000Oooooo00?o0000ooooooooool0
;oooool2o`0000;ooooo1?l00022ooooo`00XOooool4o`0000Cooooo1?l0000aooooo`;o00000_oo
ool4o`0008;ooooo002Qooooo`;o00001_ooool4o`000;_ooooo0027ooooo`;o00006?ooool2o`00
00Sooooo0_l0002kooooo`00Qoooool2o`0000;ooooo0_l0000Aooooo`;o000000?oooooo`000?l0
00002Oooool00ol0003oooooooooo`0aooooo`?o0000QOooool008Sooooo1Ol00004ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@03ooooool0003o000000;ooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo037ooooo0ol00025ooooo`00R?ooool3o`0000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool3o`000003oc8b<_oooooooooo
00?ooooo00?o0000ooooooooool0<Oooool2o`0008Kooooo0028ooooo`Oo00000_ooool01Ol@413o
oooooooooooooooo410@00kooooo0ol00003ooooo`?o00000_ooool2o`0002oooooo0ol00025oooo
o`00R?ooool2o`0000Oooooo00Go0000ooooooooooooooooo`00000;ooooo`;o00000_ooool00omg
MgOo<S8booooo`02ooooo`Oo0000<?ooool2o`000003ooooool0003o000008;ooooo002Aooooo`05
o`000?ooooooooooooooool000002oooool2o`000004ob4Q8Ol0003o<S8bolc<c0Gooooo00?o0000
ooooooooool0=Oooool4o`0000;ooooo0_l0001looooo`00TOooool01Ol@413ooooooooooooooooo
410@00Kooooo1?l00002ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0=oooool2
o`0000;ooooo0_l0001looooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo1?l00002
ooooo`03o`000?oooooooooo00Oooooo0ol0002iooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo1?l00006ooooo`?o000000?oooooo`000?l00000?Oooool2o`0007Oooooo002[oooo
o`?o00000_ooool2o`0003gooooo0_l0001gooooo`00Zoooool3o`000003ooooool0003o000003co
oooo0_l0001iooooo`00[?ooool00ol0003oooooooooo`02o`0003Kooooo0_l00004ooooo`;o0000
NOooool00:cooooo1_l0000eooooo`;o0000Ooooool009Sooooo0_l0000Booooo`04o`000?oooooo
ooooooooo`;o0000]_ooool009Sooooo0_l0000Booooo`04o`000?oooooo0000o`000;Sooooo002/
ooooo`04o`000?oooooo0000o`0003_ooooo0_l000000ooooooo0000o`00001hooooo`00[?ooool0
0ol0003oooooooooo`0looooo`;o000000?oooooo`000?l00000N?ooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0A_ooool2o`00077ooooo002/ooooo`03o`00
0?oooooooooo00Cooooo0_l00010ooooo`;o0000LOooool008Gooooo0_l0000Uooooo`?o00000_oo
ool4o`0003[ooooo0_l0001gooooo`00QOooool2o`0002Gooooo00?o0000ooooooooool00_ooool3
o`0003_ooooo0_l00003ooooo`;o0000L_ooool00:cooooo00?o0000ooooooooool00oooool2o`00
00;ooooo0_l000000ooooooo0000o`00000iooooo`;o0000L_ooool00:cooooo00?o0000oooooooo
ool01oooool2o`000003ooooool0003o00000:gooooo002Hooooo`;o00004_ooool00ol0003ooooo
ooooo`2iooooo`00QOooool2o`000003ooooool0003o000000kooooo0_l0000Booooo`03o`000?oo
oooooooo047ooooo0_l0001fooooo`00QOooool2o`000003ooooool0003o000002;ooooo00?o0000
ooooooooool0@Oooool2o`0007Kooooo002Fooooo`;o00005?ooool00ol0003oooooooooo`2ioooo
o`00U?ooool4o`0001Cooooo0ol0000:ooooo`?o0000[?ooool008Sooooo0_l0000:ooooo`;o0000
5_ooool00ol0003oooooooooo`0:ooooo`?o0000?oooool2o`0006_ooooo0028ooooo`;o00008_oo
ool00ol0003oooooooooo`08ooooo`?o0000@Oooool2o`0006_ooooo002/ooooo`03o`000?oooooo
oooo00Sooooo0ol0002^ooooo`00[?ooool00ol0003oooooooooo`1;ooooo`;o0000K?ooool00:co
oooo00?o0000ooooooooool02Oooool4o`0003[ooooo0_l00002ooooo`;o0000K?ooool00:cooooo
00?o0000ooooooooool02Oooool4o`0003[ooooo0_l0001`ooooo`00UOooool2o`00013ooooo0_l0
0003ooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo0000o`00002Zooooo`00UOooool2
o`00013ooooo0_l00003ooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo0000o`00002Z
ooooo`00Q?ooool2o`0001kooooo0_l00006ooooo`?o0000B?ooool2o`0000?ooooo0_l0001Zoooo
o`00Q?ooool2o`0001kooooo0_l00006ooooo`03o`000?oooooooooo04Sooooo0_l00003ooooo`;o
0000J_ooool00:Cooooo0_l00006ooooo`03o`000?oooooooooo017ooooo0_l0000iooooo`;o0000
Joooool00:cooooo00?o0000ooooooooool04?ooool3o`0003Wooooo0_l0001[ooooo`00Woooool2
o`0000_ooooo00?o0000ooooooooool04?ooool2o`000:Oooooo0029ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol000001Ooooooo0000o`000?ooooooA4A400;o000000?o
<S8bomgMgOooool01?ooool00ol0003oooooooooo`0>ooooo`;o000000?oooooo`000?l000000_l0
000looooo`;o0000I_ooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`0>ooooo`;o000000?oooooo`000?l000000_l0000hooooo`;o00000_ooool2o`0006Kooooo
0021ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0
2Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo0_l0000mooooo`;o0000
J_ooool008Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo
00?oMgMgoc8b<_ooool01?ooool3o`0000kooooo0_l0002Yooooo`00Qoooool3o`0000?ooooo00?o
0000ooooooooool03?ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`0>ooooo`;o0000@Oooool2o`0006Kooooo0027ooooo`;o000000Go
410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Aooooo`;o0000?_ooool4o`0006Cooooo0023ooooo`;o00001?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool5o`00043ooooo0_l0001Tooooo`00
Poooool2o`0000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool03_ooool5o`000:Kooooo002/ooooo`03
o`000?oooooooooo0;Wooooo0025ooooo`;o00003?ooool2o`0001Oooooo00?o0000ooooooooool0
4Oooool4o`000:Cooooo0025ooooo`;o00003?ooool2o`0001Oooooo00?o0000ooooooooool04Ooo
ool4o`0003cooooo0_l0001Vooooo`00[?ooool3o`0001Kooooo0_l0000iooooo`;o0000I_ooool0
0:cooooo0ol0000Fooooo`;o0000XOooool008Cooooo0_l0000Vooooo`Co0000^?ooool008Cooooo
0_l0000Vooooo`04o`000?oooooo0000o`0000kooooo0_l0002Xooooo`00T_ooool2o`0001Sooooo
00?o0000ooooooooool03oooool2o`0000Kooooo0_l0002Pooooo`00T_ooool2o`0001Sooooo00?o
0000ooooooooool05oooool2o`000:3ooooo002/ooooo`03o`000?oooooooooo05Oooooo0_l0001P
ooooo`00[?ooool00ol0003oooooooooo`0Cooooo`;o0000@_ooool2o`00063ooooo0024ooooo`;o
00005Oooool2o`0000oooooo0ol0000Booooo`Co0000Xoooool008Cooooo0_l0000Eooooo`;o0000
3oooool00ol0003oooooooooo`0Booooo`Co0000?oooool2o`000003ooooool0003o000005oooooo
002/ooooo`03o`000?oooooooooo01;ooooo0ol00010ooooo`;o000000?oooooo`000?l00000Gooo
ool00:cooooo00?o0000ooooooooool04_ooool2o`0000?ooooo0_l0002Pooooo`00[?ooool00ol0
003oooooooooo`0Booooo`;o00000oooool2o`000003ooooool0003o000009gooooo002/ooooo`03
o`000?oooooooooo01Cooooo0_l00004ooooo`;o0000WOooool00:cooooo00?o0000ooooooooool0
5?ooool2o`0000?ooooo0_l0002Nooooo`00[?ooool00ol0003oooooooooo`0Hooooo`?o0000??oo
ool2o`00063ooooo002Aooooo`;o00006Oooool00ol0003oooooooooo`0Hooooo`?o0000??ooool2
o`00063ooooo002Aooooo`;o00006Oooool3o`0001Wooooo0_l0000nooooo`;o0000G_ooool008;o
oooo0_l000000ooooooo0000o`00000:ooooo`;o00006Oooool00ol0003oooooooooo`1Iooooo`;o
0000G_ooool008;ooooo1Ol0000Uooooo`03o`000?oooooooooo00;ooooo0_l0002eooooo`002Ooo
ool4o`000003oa0@4?oooooooooo01Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o8B4Qo`000?l000000oooool5o`0000Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@0Fooooo`03o`000?oooooooooo00;ooooo0_l0000Dooooo`03onk^
k_lb<S;o000000;o00001Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oM
gMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^
k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`Co000000?o410@ooooooooool0
4_ooool000_ooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`03ob4Q8Ol0003o000000?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A005
ooooo`;o000000?oMgMgoc8b<_ooool05Oooool00ol0003oooooooooo`02ooooo`;o00005?ooool0
0omgMgOoV9RHooooo`02o`0000Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01ooo
ool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03
oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool06Oooool00ol0003oooooooooo`0Dooooo`00
1_l00005ooooo`03o`000?oooooooooo013ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@
41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`05ooooo`Ko00000_ooool01Ol@
413ooooooooooooooooo410@00Kooooo1?l00002ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0_l00000
0ooooooo0000ooooo`0Eooooo`03o`000?oooooooooo01Sooooo00Go410@oooooooooooooooooa0@
400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool03Oooool01Ol@413ooooooooo
oooooooo410@013ooooo00?o0000ooooooooool03Oooool01Ol@413ooooooooooooooooo410@00go
oooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Co
oooo000;ooooo`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000Sooooo0_l00003
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool05Oooool00ol0003oooooooooo`0G
ooooo`;o00000oooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMg
oc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool03_oo
ool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8b
ooooo`0Iooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go
0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00oooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo0ol0
00000olb<S;oc<c<ooooo`0Eooooo`03o`000?oooooooooo01Oooooo0_l00002ooooo`;o00003_oo
ool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooo
oooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?oooooooooo
ooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06_oo
ool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05oa0@4?oooooo
ooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo017ooooo00Go
410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooo
oooooa0@400?ooooo`03o`000?oooooooooo00;ooooo0ol0000Hooooo`?o00006?ooool00ol@413o
ooooooooo`02o`0000oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Aooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0Aooooo`05oa0@4?oooooooooo
ooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo017ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool3o`0001Sooooo00?o0000oooo
ooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@
4004ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`00
0?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooo
oolb<S801?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Cooooo0009ooooo`03
oeEEEOmVIVKo000001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`00
013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00005oooool00ol0003ooooo
ooooo`0Hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
00Cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00013ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0001Wooooo00?oEEEEofIVI_l000005_oo
ool008;ooooo0_l0000Xooooo`03o`000?oooooooooo01[ooooo0_l0002Mooooo`00P_ooool2o`00
02Sooooo00?o0000ooooooooool05oooool2o`000003ooooool0003o000009gooooo002/ooooo`03
o`000?oooooooooo01Kooooo0ol00016ooooo`;o0000COooool2o`0000;ooooo0_l00005ooooo`00
Poooool2o`0002Oooooo00?o0000ooooooooool00oooool3o`00013ooooo0_l00006ooooo`;o0000
?oooool2o`0004gooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd5ooooo`00Poooool2o`0001Go
oooo0_l0000@ooooo`03o`000?oooooooooo00?ooooo0ol0000Hooooo`;o0000Soooool01?oMgMgo
0000oa0@4?o<c<`6ooooo`001oooooooo`0004co00003?ooool01?o^k^ko8B4Qoa0@4?o^k^h6oooo
o`001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00_l000001?oooooo0000o`000?l00008ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo0_l000000ooo
oooo0000ooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool01?lQ
8B7oMgMgogMgMolb<S86ooooo`001oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09_ooool3o`0002Kooooo00?o0000ooooooooool00_ooool2o`00
01Gooooo0_l0000<ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo00Wooooo0_l00002ooooo`;o00001Oooool008?o
oooo0ol0000Vooooo`03o`000?oooooooooo00;ooooo0_l0000Eooooo`;o0000W_ooool00:cooooo
00?o0000ooooooooool01?ooool2o`00017ooooo1?l00015ooooo`;o0000Eoooool00:cooooo00?o
0000ooooooooool01?ooool2o`00017ooooo0_l00017ooooo`;o0000Eoooool008Gooooo0_l0000U
ooooo`03o`000?oooooooooo00Cooooo0_l0001Hooooo`;o0000FOooool008Cooooo0ol0000Uoooo
o`03o`000?oooooooooo00Cooooo0_l0001Hooooo`;o0000FOooool008Cooooo0_l0000Vooooo`?o
00001?ooool2o`00013ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l0002Hooooo`00
[?ooool00ol0003oooooooooo`04ooooo`;o00004?ooool2o`0000;ooooo0_l000000ooooooo0000
o`000002o`0009Sooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Booooo`;o00006?ooool0
0ol0003oooooooooo`0Kooooo`;o000000?oooooo`000?l00000VOooool009;ooooo0_l0000Hoooo
o`03o`000?oooooooooo00Cooooo0_l0000Eooooo`;o000000?oooooo`000?l00000@?ooool2o`00
05Oooooo002/ooooo`03o`000?oooooooooo00Cooooo0_l0001Jooooo`;o0000Eoooool008Kooooo
0_l0000Tooooo`03o`000?oooooooooo0;Wooooo0026ooooo`;o00009?ooool00ol0003ooooooooo
o`0Iooooo`;o0000A_ooool2o`0005Kooooo002Booooo`?o00005oooool00ol0003oooooooooo`03
ooooo`;o00005?ooool4o`0004Cooooo0_l0001Fooooo`00T_ooool3o`0001Oooooo0ol00003oooo
o`;o00005?ooool4o`0009cooooo0026ooooo`;o00009?ooool00ol0003oooooooooo`0Iooooo`;o
0000W_ooool008Kooooo0_l0000;ooooo`;o00005oooool00ol0003oooooooooo`03ooooo`;o0000
]?ooool008Cooooo0_l0000=ooooo`;o00005oooool00ol0003oooooooooo`03ooooo`;o00005ooo
ool2o`0009_ooooo0024ooooo`;o00009_ooool00ol0003oooooooooo`03ooooo`;o00004Oooool2
o`0000Cooooo0_l0002Kooooo`00[?ooool00ol0003oooooooooo`0Fooooo`;o00001?ooool2o`00
09_ooooo002/ooooo`03o`000?oooooooooo01kooooo0_l0002Iooooo`00[?ooool00ol0003ooooo
ooooo`0Nooooo`;o0000VOooool00:cooooo0ol0002iooooo`00Poooool2o`0000gooooo0_l0000H
ooooo`03o`000?oooooooooo00?ooooo0_l0000Fooooo`;o0000W?ooool008?ooooo0_l0000=oooo
o`;o00006?ooool00ol0003oooooooooo`03ooooo`;o00005_ooool2o`0009cooooo002Cooooo`;o
00005oooool00ol0003oooooooooo`2iooooo`00Toooool2o`0001Oooooo00?o0000ooooooooool0
7?ooool2o`0009_ooooo002Booooo`;o00006?ooool00ol0003oooooooooo`0Looooo`;o0000Vooo
ool009;ooooo0_l0000Hooooo`03o`000?oooooooooo01oooooo0_l0002Hooooo`00QOooool2o`00
00cooooo0_l0000Gooooo`03o`000?oooooooooo01oooooo0_l0002Hooooo`00QOooool2o`0000co
oooo0_l0000Gooooo`?o0000^Oooool009?ooooo0_l0000Gooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`04o`000?ooooooooooooooo`;o00005Oooool2o`0009oooooo0025ooooo`;o00009Ooo
ool01?l0003oooooooooooooool3o`0001Cooooo0ol0002Nooooo`00QOooool2o`0000gooooo0_l0
000Fooooo`03o`000?oooooooooo00;ooooo0_l0000Booooo`;o000000Coooooo`000?l0003ooooo
0_l0002Kooooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool00_ooool2o`0001;ooooo0_l0
0004ooooo`;o0000Voooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03ob4Q8Ol0
003o000000?ooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`02ooooo`;o00004_ooool2o`0000Gooooo0ol0002Iooooo`00ROooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo01Gooooo1Ol00003ooooo`?o0000VOooool008Wooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000oooooooo
ool00oooool3o`0001Gooooo1Ol0002Oooooo`00ROooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01Wo
oooo0_l0002Nooooo`00ROooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_oo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool06Oooool2o`00
09kooooo0029ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06oooool2o`000003ooooool0003o0000
09Wooooo0027ooooo`;o000000GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01_ooooo0_l00000
0ooooooo0000o`00002Iooooo`00Qoooool2o`000005onk^k_lb<S;o0000oc8b<_o^k^h01oooool2
o`0000;ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003ooooooooo
o`0Looooo`?o0000V_ooool009Gooooo0_l0000Eooooo`04o`000?oooooo0000o`0001_ooooo0ol0
002Jooooo`00[?ooool01?l0003oooooo`000?l0002hooooo`00[?ooool00ol0003oooooooooo`0I
ooooo`;o0000W_ooool00:cooooo1Ol0000Cooooo`;o00000_ooool2o`0009kooooo0028ooooo`;o
00003_ooool2o`0001;ooooo00?o0000ooooooooool00_l0000Cooooo`;o0000X_ooool008Sooooo
0_l0000>ooooo`;o00004_ooool01?l0003oooooo`000?l0002hooooo`00R?ooool2o`0002;ooooo
00Co0000ooooool0003o0000^?ooool00:cooooo00?o0000ooooooooool05oooool2o`000:3ooooo
002/ooooo`03o`000?oooooooooo01Oooooo0_l0002Pooooo`00[?ooool00ol0003oooooooooo`0C
ooooo`Co00000_ooool2o`0009kooooo002/ooooo`?o00004oooool5o`000003ooooool0003o0000
09kooooo002/ooooo`?o00005_ooool2o`0000?ooooo0_l0002Looooo`00VOooool4o`0000oooooo
00?o0000ooooooooool04_ooool2o`0000Oooooo0_l0002Looooo`00VOooool4o`0000oooooo00?o
0000ooooooooool04_ooool2o`000:Gooooo002Zooooo`?o0000^oooool008Wooooo0ol0000Noooo
o`?o00006_ooool2o`0009oooooo0026ooooo`;o000000Coooooo`000?l0003o00006oooool2o`00
00?ooooo00?o0000ooooooooool04_ooool2o`0000Cooooo0_l0002Oooooo`00Q_ooool2o`0001oo
oooo1?l000000ooooooo0000ooooo`0Cooooo`;o00000oooool3o`0009oooooo002Yooooo`;o0000
00?oooooo`000?ooool06?ooool2o`000:3ooooo002Nooooo`;o00001?ooool2o`0000Cooooo1Ol0
002iooooo`00W_ooool2o`0000Cooooo0_l00004ooooo`?o00004_ooool2o`000:Oooooo002Roooo
o`Co00001_ooool00ol0003oooooooooo`0@ooooo`;o0000Yoooool00:7ooooo1Ol000000ooooooo
0000o`000003ooooo`03o`000?oooooooooo0;Wooooo002Qooooo`Go000000?oooooo`000?l00000
0oooool00ol0003oooooooooo`2iooooo`00X_ooool2o`0000Sooooo00?o0000ooooooooool0^Ooo
ool008Sooooo0_l0000Rooooo`03o`000?oooooooooo01Cooooo0_l0002Sooooo`00R?ooool6o`00
017ooooo1?l00009ooooo`03o`000?oooooooooo01;ooooo1?l0002Sooooo`00R_ooool4o`00017o
oooo1?l00009ooooo`?o00003Oooool2o`0000?ooooo0_l0002Uooooo`00[?ooool00ol0003ooooo
ooooo`0=ooooo`;o0000Z_ooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool008_ooooo0_l0000Oooooo`03o`000?oooooooooo0;Wooooo002;ooooo`;o
00007oooool00ol0003oooooooooo`2iooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Eoooo
o`;o0000X_ooool0097ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo01Gooooo0_l0002Rooooo`00R_ooool2o`0000Go
oooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0^Oooool008[ooooo0_l00005ooooo`05o`000?ooooooooooooooool000003oooool00omg
MgOo<S8booooo`04ooooo`?o0000^Oooool0097ooooo00Go0000ooooooooooooooooo`00000<oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0=ooooo`?o0000ZOooool0
097ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool03?ooool4o`0000?ooooo0_l0002Tooooo`00TOooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<ooooo`;o00001Oooool2
o`000:Cooooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000
ooooooooool02oooool2o`000:cooooo002/ooooo`03o`000?oooooooooo00_ooooo1Ol0002Yoooo
o`00SOooool2o`0001gooooo00?o0000ooooooooool03Oooool3o`000:Wooooo002=ooooo`;o0000
7Oooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooo
oooo00Oooooo0_l00005ooooo`;o0000ZOooool00:cooooo00?o0000ooooooooool01oooool3o`00
00Cooooo0_l0002Yooooo`00S?ooool2o`0001kooooo00?o0000ooooooooool02?ooool2o`000:oo
oooo002<ooooo`;o00007_ooool00ol0003oooooooooo`0:ooooo`;o0000[Oooool008oooooo0_l0
000Kooooo`03o`000?oooooooooo00Wooooo1?l0002/ooooo`00Soooool2o`0001_ooooo00?o0000
ooooooooool02Oooool4o`000:cooooo002>ooooo`;o00007?ooool00ol0003oooooooooo`0:oooo
o`;o000000?oooooo`000?l00000Z_ooool008gooooo0ol0000Looooo`?o00000oooool2o`0000So
oooo0_l0002Zooooo`00SOooool2o`0001gooooo00?o0000ooooooooool00oooool2o`000;Cooooo
002/ooooo`03o`000?oooooooooo00Kooooo0_l0002aooooo`00[?ooool00ol0003oooooooooo`06
ooooo`;o0000/Oooool0097ooooo0ol0000Hooooo`03o`000?oooooooooo0;Wooooo002Aooooo`?o
00006?ooool00ol0003oooooooooo`2iooooo`00T_ooool2o`0001Sooooo00?o0000ooooooooool0
^Oooool009;ooooo0_l0000Hooooo`03o`000?oooooooooo00Oooooo0_l0002`ooooo`00T_ooool2
o`0001Sooooo1Ol00005ooooo`;o0000/?ooool009Cooooo0_l0000Fooooo`03o`000?oooooooooo
00;o00000oooool4o`000;3ooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`05ooooo`;o
0000/_ooool00:cooooo00?o0000ooooooooool0^Oooool0093ooooo0_l0000Jooooo`?o00000_oo
ool2o`000;Gooooo002@ooooo`;o00001?ooool2o`0001Cooooo0ol00002ooooo`;o0000]Oooool0
09Cooooo1?l0000Dooooo`03o`000?oooooooooo00;ooooo0_l0002eooooo`00U?ooool2o`0001Co
oooo0ol00004ooooo`;o0000]Oooool009Sooooo0_l0000?ooooo`Co0000^oooool009Kooooo1?l0
000?ooooo`;o000000Coooooo`000?l0003o0000^Oooool009Kooooo0_l00003ooooo`;o00003?oo
ool4o`000;_ooooo002Kooooo`;o00003_ooool5o`000;Sooooo002Gooooo`;o00000_ooool2o`00
00oooooo1?l0002hooooo`00Toooool6o`0000kooooo0ol000000ooooooo0000o`000002o`000;Wo
oooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool4o`0000Cooooo00?o0000onk^k_oo
ool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00?o000000?oooooo`000?l000000_l0002ioooo
o`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo
00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2iooooo`00ROooool01Ol@413o
oooooooooooooooo410@00[ooooo1?l000001?mEEEGoooooooooooooool2o`0000;ooooo0ol00005
ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05o`000?ooooooooooooooool000002_ooool4
o`000004ob4Q8Oooooooooooooooo`;o00000_ooool2o`000003oc8b<_oooooooooo00?ooooo0ol0
002iooooo`00ROooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo0ol0002iooooo`00ROooool01Ol@413ooooooooo
oooooooo410@00_ooooo0_l000000oooooooZJVYogMgM`03o`000003ooooool0003ooooo00;ooooo
0_l00004ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool2o`0000;ooooo00Ko<S8bo`000?l0003o0000ooooool00003ooooo`;o00000oooool4o`00
0;Wooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00005oooo
o`Co0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool009_ooooo0_l00003ooooo`;o0000
2?ooool3o`000;_ooooo002Kooooo`;o00000oooool2o`0000Sooooo0ol0002kooooo`00[?ooool3
o`000;Wooooo002Pooooo`Co00002?ooool00ol0003oooooooooo`2iooooo`00X?ooool4o`0000So
oooo00?o0000ooooooooool0^Oooool00:;ooooo0_l00008ooooo`03o`000?oooooooooo0;Wooooo
002Qooooo`Co00001oooool00ol0003oooooooooo`2iooooo`00XOooool4o`0000Oooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:;ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000ooooooooool0
1Oooool3o`000;Wooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooo
oooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7o
oooo002Rooooo`03oeEEEOmVIVKo00000<?ooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo002Zooooo`04oa0@4?l0003o0000o`000;[ooooo002[ooooo`03o`00
0?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`06o`000?mgMgOo
0000o`000?mEEEGok^k^]oooool00:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomEEEFgooooo`00
Zoooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo0;Gooooo002[ooooo`03o`000?o^
k^kooooo00;ooooo00?o0000ooooooooool0]Oooool00:_ooooo00Ko0000oeEEEOo^k^koooooogMg
MomVIVJgooooo`00Z_ooool00ol@413o0000ogMgM`02o`000003ofIVI_o^k^kooooo0;Kooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000
\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.57673 .76277 Mdot
.57763 .78053 Mdot
.46396 .62686 Mdot
.42596 .62587 Mdot
.52162 .24227 Mdot
.60838 .66375 Mdot
.48081 .32845 Mdot
.36524 .46135 Mdot
.40878 .1316 Mdot
.418 .38975 Mdot
.44509 .2482 Mdot
.40845 .10803 Mdot
.56975 .81608 Mdot
.41169 .46235 Mdot
.52025 .04803 Mdot
.41904 .58549 Mdot
.60864 .56238 Mdot
.57012 .81669 Mdot
.47059 .19688 Mdot
.49337 .94292 Mdot
.49981 .90871 Mdot
.52409 .86645 Mdot
.4552 .90228 Mdot
.54856 .84913 Mdot
.53023 .05119 Mdot
.55887 .29538 Mdot
.49606 .22963 Mdot
.50223 .22565 Mdot
.45463 .94164 Mdot
.54164 .83625 Mdot
.42324 .85261 Mdot
.38055 .28228 Mdot
.38788 .2109 Mdot
.5934 .64922 Mdot
.61567 .59203 Mdot
.39198 .73116 Mdot
.37235 .52875 Mdot
.50672 .24024 Mdot
.38118 .65683 Mdot
.38323 .22155 Mdot
.46005 .00608 Mdot
.60959 .60485 Mdot
.60379 .65732 Mdot
.61245 .69503 Mdot
.61205 .68434 Mdot
.53612 .25983 Mdot
.4466 .2511 Mdot
.36956 .53549 Mdot
.59044 .37062 Mdot
.39884 .78832 Mdot
.37013 .45293 Mdot
.39956 .80512 Mdot
.72014 .25147 Mdot
.59687 .66749 Mdot
.62035 .59094 Mdot
.40566 .136 Mdot
.37073 .34412 Mdot
.61331 .52015 Mdot
.3711 .54849 Mdot
.61406 .67599 Mdot
.55431 .30131 Mdot
.55226 .05521 Mdot
.37517 .51189 Mdot
.50952 .6872 Mdot
.47141 .02126 Mdot
.3802 .27934 Mdot
.42503 .33873 Mdot
.41851 .44023 Mdot
.47477 .20253 Mdot
.51885 .88967 Mdot
.61477 .43815 Mdot
.48758 .3215 Mdot
.43816 .27862 Mdot
.41643 .42382 Mdot
.37517 .50851 Mdot
.44281 .52749 Mdot
.72066 .25256 Mdot
.58716 .42266 Mdot
.41185 .85526 Mdot
.59962 .52527 Mdot
.40621 .79875 Mdot
.52793 .85414 Mdot
.42229 .58076 Mdot
.61438 .58692 Mdot
.36638 .454 Mdot
.44657 .73739 Mdot
.52254 .24287 Mdot
.56581 .3516 Mdot
.61264 .46901 Mdot
.42115 .40334 Mdot
.5482 .07242 Mdot
.67415 .19552 Mdot
.50583 .70511 Mdot
.53997 .27305 Mdot
.49713 .7215 Mdot
.6453 .15127 Mdot
.412 .45809 Mdot
.39235 .21233 Mdot
.72122 .25058 Mdot
.60893 .41736 Mdot
.56245 .7903 Mdot
.60609 .41816 Mdot
.44363 .03088 Mdot
.59997 .72603 Mdot
.47176 .92999 Mdot
.59388 .65116 Mdot
.61821 .4883 Mdot
.47177 .19343 Mdot
.50701 .70263 Mdot
.49708 .91543 Mdot
.41208 .47439 Mdot
.44485 .71562 Mdot
.38545 .24621 Mdot
.46294 .94084 Mdot
.76324 .31718 Mdot
.52969 .45185 Mdot
.57057 .34709 Mdot
.36717 .53609 Mdot
.36771 .47331 Mdot
.38606 .27795 Mdot
.55688 .83439 Mdot
.51286 .01484 Mdot
.43357 .87254 Mdot
.47112 .95223 Mdot
.50858 .90237 Mdot
.41915 .54429 Mdot
.43643 .90951 Mdot
.63226 .13711 Mdot
.50355 .88 Mdot
.52158 .60771 Mdot
.49914 .90013 Mdot
.54446 .82157 Mdot
.43847 .03477 Mdot
.62182 .62522 Mdot
.60414 .6631 Mdot
.45079 .94136 Mdot
.40622 .84603 Mdot
.43686 .9138 Mdot
.44211 .2676 Mdot
.42052 .08044 Mdot
.50208 .02646 Mdot
.62924 .1507 Mdot
.48083 .74963 Mdot
.4637 .20342 Mdot
.61002 .55352 Mdot
.48635 .94499 Mdot
.36633 .48508 Mdot
.77653 .33676 Mdot
.54697 .32288 Mdot
.56516 .3453 Mdot
.43911 .01331 Mdot
.60163 .39511 Mdot
.44213 .24383 Mdot
.56073 .83296 Mdot
.48014 .31533 Mdot
.5703 .75622 Mdot
.3858 .72609 Mdot
.37928 .63787 Mdot
.36997 .39345 Mdot
.37355 .43242 Mdot
.3901 .759 Mdot
.5732 .32559 Mdot
.43158 .91178 Mdot
.37903 .23693 Mdot
.38889 .69859 Mdot
.57565 .72397 Mdot
.53378 .83225 Mdot
.36721 .4466 Mdot
.47929 .93228 Mdot
.47684 .20381 Mdot
.42103 .89346 Mdot
.38378 .66889 Mdot
.44122 .68885 Mdot
.49443 .22104 Mdot
.55008 .30821 Mdot
.53505 .28681 Mdot
.42383 .07487 Mdot
.64426 .15155 Mdot
.56617 .76268 Mdot
.52753 .54815 Mdot
.41589 .86339 Mdot
.43581 .92534 Mdot
.4012 .12838 Mdot
.41724 .58333 Mdot
.46185 .00415 Mdot
.51699 .63774 Mdot
.43134 .07226 Mdot
.64502 .15751 Mdot
.36821 .49833 Mdot
.3836 .20852 Mdot
.61181 .63729 Mdot
.50138 .00568 Mdot
.49368 .94046 Mdot
.50412 .69543 Mdot
.57346 .08382 Mdot
.36685 .42389 Mdot
.43423 .02946 Mdot
.43766 .03789 Mdot
.54353 .28393 Mdot
.66179 .16594 Mdot
.62126 .47627 Mdot
.52711 .52897 Mdot
.52726 .53128 Mdot
.49204 .3278 Mdot
.54551 .2992 Mdot
.67324 .18151 Mdot
.5342 .83428 Mdot
.49786 .70181 Mdot
.59999 .68939 Mdot
.47631 .75648 Mdot
.53216 .5824 Mdot
.43092 .29081 Mdot
.5776 .79802 Mdot
.58427 .4061 Mdot
.47514 .93262 Mdot
.41569 .46885 Mdot
.52706 .84244 Mdot
.5847 .41669 Mdot
.38718 .18571 Mdot
.53255 .57027 Mdot
.58181 .74294 Mdot
.37253 .31155 Mdot
.56605 .33302 Mdot
.38079 .30381 Mdot
.49482 .92322 Mdot
.3915 .71233 Mdot
.42515 .3621 Mdot
.51973 .24439 Mdot
.60537 .72756 Mdot
.46234 .73649 Mdot
.51722 .0442 Mdot
.42731 .65219 Mdot
.44765 .38998 Mdot
.69748 .22633 Mdot
.60636 .4724 Mdot
.46376 .21588 Mdot
.52221 .02686 Mdot
.49569 .22123 Mdot
.60023 .72813 Mdot
.48504 .91657 Mdot
.55218 .80891 Mdot
.56526 .07113 Mdot
.61917 .62261 Mdot
.48794 .9329 Mdot
.61474 .43873 Mdot
.36929 .43142 Mdot
.47856 .73896 Mdot
.37339 .50105 Mdot
.60176 .57756 Mdot
.614 .43399 Mdot
.37703 .59366 Mdot
.44622 .01369 Mdot
.52998 .45867 Mdot
.48059 .73046 Mdot
.37616 .39338 Mdot
.58032 .36308 Mdot
.49799 .22768 Mdot
.63026 .54228 Mdot
.44212 .51704 Mdot
.38342 .2329 Mdot
.37065 .5605 Mdot
.59993 .41328 Mdot
.46199 .21735 Mdot
.39287 .72589 Mdot
.52843 .56189 Mdot
.60628 .43239 Mdot
.56333 .78242 Mdot
.4683 .22256 Mdot
.57296 .73904 Mdot
.38418 .66558 Mdot
.59342 .42221 Mdot
.41912 .86362 Mdot
.62385 .57878 Mdot
.41268 .4831 Mdot
.60278 .46971 Mdot
.39477 .7864 Mdot
.42158 .63297 Mdot
.47504 .18777 Mdot
.37215 .39479 Mdot
.41668 .37682 Mdot
.58828 .71963 Mdot
.42064 .88035 Mdot
.53577 .49984 Mdot
.42653 .34177 Mdot
.37647 .37559 Mdot
.42475 .06522 Mdot
.46723 .19413 Mdot
.47873 .31919 Mdot
.56276 .36349 Mdot
.49805 .93146 Mdot
.5601 .3251 Mdot
.40326 .78137 Mdot
.65182 .16869 Mdot
.37261 .42213 Mdot
.49245 .02007 Mdot
.38697 .25745 Mdot
.44891 .37401 Mdot
.38074 .7006 Mdot
.59393 .11396 Mdot
.51332 .91177 Mdot
.51438 .04214 Mdot
.78261 .3455 Mdot
.59883 .42858 Mdot
.6311 .55678 Mdot
.55724 .80336 Mdot
.37278 .3648 Mdot
.49161 .00994 Mdot
.43951 .26743 Mdot
.37803 .31778 Mdot
.58016 .35914 Mdot
.52647 .50268 Mdot
.55694 .82821 Mdot
.61051 .55654 Mdot
.54158 .854 Mdot
.44144 .01161 Mdot
.53187 .49805 Mdot
.57388 .76002 Mdot
.59967 .63515 Mdot
.47698 .01982 Mdot
.53311 .51686 Mdot
.41352 .08635 Mdot
.5674 .08613 Mdot
.60054 .10462 Mdot
.41881 .55696 Mdot
.62924 .5982 Mdot
.61883 .56517 Mdot
.37483 .47876 Mdot
.49598 .19935 Mdot
.52528 .44143 Mdot
.46505 .33353 Mdot
.61708 .49512 Mdot
.36834 .37032 Mdot
.38455 .29676 Mdot
.50746 .69801 Mdot
.55992 .82119 Mdot
.52658 .58632 Mdot
.4957 .33619 Mdot
.60158 .73589 Mdot
.61464 .64335 Mdot
.5768 .7218 Mdot
.57567 .33358 Mdot
.54758 .30665 Mdot
.7014 .21719 Mdot
.58992 .40772 Mdot
.50633 .87995 Mdot
.49373 .72226 Mdot
.4044 .13669 Mdot
.49744 .23328 Mdot
.43107 .90073 Mdot
.48748 .90341 Mdot
.50339 .7154 Mdot
.58306 .42086 Mdot
.6223 .14045 Mdot
.39298 .17071 Mdot
.39598 .8072 Mdot
.39657 .76387 Mdot
.59172 .38849 Mdot
.61937 .51862 Mdot
.39146 .73576 Mdot
.60643 .44796 Mdot
.39714 .15172 Mdot
.571 .06505 Mdot
.48712 .93399 Mdot
.44551 .0257 Mdot
.41862 .07177 Mdot
.41829 .06696 Mdot
.50384 .35836 Mdot
.60478 .46314 Mdot
.5131 .03873 Mdot
.37506 .29839 Mdot
.50504 .36126 Mdot
.42092 .85056 Mdot
.59555 .46883 Mdot
.61213 .65888 Mdot
.56516 .78481 Mdot
.39827 .17999 Mdot
.59685 .73446 Mdot
.37245 .56051 Mdot
.38306 .31714 Mdot
.45223 .89805 Mdot
.40912 .86317 Mdot
.48787 .90893 Mdot
.51739 .03858 Mdot
.76489 .3126 Mdot
.39481 .21746 Mdot
.58788 .72422 Mdot
.49735 .34751 Mdot
.53854 .05401 Mdot
.61026 .43842 Mdot
.46341 .33644 Mdot
.39026 .17594 Mdot
.51638 .89308 Mdot
.52156 .41403 Mdot
.41955 .38443 Mdot
.56693 .32429 Mdot
.47218 .21096 Mdot
.36989 .56358 Mdot
.53678 .87536 Mdot
.58635 .10158 Mdot
.40211 .12418 Mdot
.6088 .58245 Mdot
.71311 .24582 Mdot
.61478 .55438 Mdot
.52731 .2691 Mdot
.51213 .2337 Mdot
.43928 .48732 Mdot
.37334 .31002 Mdot
.41025 .10266 Mdot
.49285 .22522 Mdot
.47573 .74664 Mdot
.41344 .39597 Mdot
.43412 .6996 Mdot
.4509 .00419 Mdot
.52288 .23722 Mdot
.40302 .79201 Mdot
.4511 .72584 Mdot
.45223 .22311 Mdot
.53028 .55378 Mdot
.52624 .24717 Mdot
.59379 .64502 Mdot
.44024 .25188 Mdot
.49656 .70586 Mdot
.41364 .09965 Mdot
.48032 .62209 Mdot
.61651 .5924 Mdot
.61818 .4913 Mdot
.54074 .8088 Mdot
.59679 .47786 Mdot
.48054 .20671 Mdot
.51721 .02875 Mdot
.63287 .12874 Mdot
.58156 .76497 Mdot
.7525 .29972 Mdot
.61795 .68468 Mdot
.50966 .67646 Mdot
.44988 .04206 Mdot
.52292 .04934 Mdot
.4656 .21873 Mdot
.46753 .90469 Mdot
.70767 .22848 Mdot
.46684 .7442 Mdot
.51982 .41034 Mdot
.54575 .31283 Mdot
.40402 .793 Mdot
.59995 .48957 Mdot
.66761 .17928 Mdot
.52172 .62443 Mdot
.59426 .66893 Mdot
.61688 .56801 Mdot
.51519 .67612 Mdot
.52967 .53645 Mdot
.41567 .56899 Mdot
.36614 .4284 Mdot
.5325 .47379 Mdot
.42822 .90267 Mdot
.58473 .76519 Mdot
.59361 .72449 Mdot
.43134 .89764 Mdot
.40285 .77621 Mdot
.61164 .55851 Mdot
.60098 .09318 Mdot
.41878 .38984 Mdot
.36806 .37307 Mdot
.43199 .03434 Mdot
.48064 .22293 Mdot
.38695 .75213 Mdot
.59607 .45252 Mdot
.59975 .60031 Mdot
.43808 .91479 Mdot
.57119 .77609 Mdot
.48567 .19986 Mdot
.58214 .41301 Mdot
.60108 .62386 Mdot
.50458 .00152 Mdot
.58616 .70645 Mdot
.44828 .58677 Mdot
.59091 .68814 Mdot
.6013 .50348 Mdot
.49127 .32256 Mdot
.41886 .44595 Mdot
.60119 .65426 Mdot
.61576 .62603 Mdot
.52988 .48705 Mdot
.58293 .37957 Mdot
.38147 .2685 Mdot
.50588 .21265 Mdot
.562 .78257 Mdot
.43529 .25597 Mdot
.53233 .29168 Mdot
.51096 .37992 Mdot
.75364 .29143 Mdot
.5166 .40633 Mdot
.59009 .75825 Mdot
.40594 .15559 Mdot
.3942 .74125 Mdot
.47718 .20173 Mdot
.42826 .89661 Mdot
.40364 .12122 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool009_ooooo0_l00002ooooo`;o00000oooool00ol0003o
ooooooooo`05ooooo`?o0000^Oooool009_ooooo0_l000001?oooooo0000o`000?l00003ooooo`03
o`000?oooooooooo00Gooooo0_l0002jooooo`00W_ooool2o`0000Cooooo00?o0000ooooooooool0
0_ooool2o`000003ooooool0003o00000;[ooooo002Gooooo`Go00002?ooool00ol0003ooooooooo
o`02ooooo`;o000000?oooooo`000?ooool0^_ooool009Oooooo1Ol00006ooooo`03oeEEEOmVIVKo
000000Oooooo00Co0000oooooooooooooooo0_l0002fooooo`00Y?ooool2o`0000Kooooo00Co0000
oooooooooooooooo0_l0002fooooo`00X_ooool4o`0000?ooooo0_l000000ooooooo0000ooooo`2j
ooooo`00V_ooool2o`0000Kooooo0_l00005ooooo`;o000000Coooooo`000?l0003o0000^Oooool0
09[ooooo0_l0000@ooooo`;o00000oooool4o`000;?ooooo002Fooooo`;o000000?oooooo`000?l0
00004Oooool2o`0000?ooooo1?l0002cooooo`00UOooool6o`00017ooooo00?o0000ooooooooool0
^Oooool009Gooooo1?l0000Cooooo`03o`000?oooooooooo0;Wooooo002Gooooo`;o00004oooool0
1?l0003oooooooooooooool3o`000;Gooooo002Kooooo`;o00003oooool01?l0003ooooooooooooo
ool3o`000;Gooooo002Kooooo`;o00003oooool01?l0003oooooooooooooool3o`000;Gooooo002/
ooooo`03o`000?oooooooooo00;ooooo1?l0002cooooo`00[?ooool3o`0000?ooooo0ol000000ooo
oooo0000o`00002`ooooo`00[?ooool00ol0003oooooooooo`07ooooo`Co00000oooool2o`000:Wo
oooo002/ooooo`03o`000?oooooooooo00Wooooo0_l00003ooooo`;o0000ZOooool00:cooooo00?o
0000ooooooooool0^Oooool009?ooooo0_l0000Gooooo`03o`000?oooooooooo01Cooooo0_l0002S
ooooo`00TOooool4o`0001Oooooo00?o0000ooooooooool05?ooool2o`000:?ooooo002Aooooo`;o
00006Oooool00ol0003oooooooooo`0Booooo`;o0000YOooool0097ooooo0_l00002ooooo`;o0000
5Oooool00ol0003oooooooooo`0<ooooo`;o00001?ooool2o`000:Gooooo002Aooooo`?o000000?o
ooooo`000?l000005Oooool3o`0000cooooo0_l0002[ooooo`00TOooool3o`0001Sooooo00?o0000
ooooooooool0^Oooool0097ooooo0_l0000Iooooo`03o`000?oooooooooo0;Wooooo002?ooooo`;o
00006oooool00ol0003oooooooooo`0Cooooo`Co0000X_ooool008oooooo0_l0000Kooooo`03o`00
0?oooooooooo01?ooooo1?l0002Rooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`0Nooooo`;o0000VOooool00:cooooo00?o0000ooooooooool07_ooool2o`00
09Wooooo002?ooooo`;o00006oooool3o`0001Wooooo0_l0002Nooooo`00S_ooool3o`0001_ooooo
00?o0000ooooooooool06Oooool2o`0000?ooooo0_l0002Iooooo`00S_ooool2o`0001cooooo00?o
0000ooooooooool07_ooool2o`0009Wooooo002=ooooo`;o00007Oooool00ol0003oooooooooo`2i
ooooo`00SOooool2o`0001gooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool07?ooool2o`0009_ooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool07?ooool2o`0009_ooooo0029ooooo`03ogMgMonHV9Sooooo00;o00001Oooool2ob4Q8@Ko
oooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;Wo
oooo0021ooooo`Ko00000_ooool00ol@413oooooo`000002o`0000gooooo00?oZJVYoeEEEOooool0
2?ooool00ol0003oooooooooo`03ooooo`?o0000^Oooool008Wooooo00?o0000ooooool000000_l0
000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`0Xooooo`;o0000Soooool008Wooooo00?o0000ooooool000000ol0000=ooooo`03oeEEEOo<c<co
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo02Sooooo0_l0
002?ooooo`00ROooool01?l@413oooooooooooooool2o`0000gooooo00?oZJVYogMgMoooool00ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`03ogMgMonHV9So
oooo00;o00002oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Xooooo`;o0000Soooool008Wooooo00?ok^k^oc8b<_l000000_l0000;
ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool09Oooool2o`000003ooooool0003o
000008oooooo002/ooooo`03o`000?oooooooooo02Gooooo0_l0002Booooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00R_ooool2o`00023ooooo0ol0
000Wooooo`;o00000oooool3o`0008[ooooo002:ooooo`;o000000?oooooo`000?l000007Oooool0
0ol0003oooooooooo`0Wooooo`;o00000oooool3o`0008[ooooo002=ooooo`;o00007Oooool00ol0
003oooooooooo`0/ooooo`;o0000Roooool00:cooooo00?o0000ooooooooool0;?ooool2o`0008_o
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo03;ooooo0_l0
0025ooooo`00R?ooool2o`0002;ooooo00?o0000ooooooooool0;oooool2o`000003ooooool0003o
000008Gooooo0028ooooo`;o00008_ooool00ol0003oooooooooo`0_ooooo`;o0000R?ooool008Oo
oooo0_l0000Sooooo`?o0000^Oooool008Oooooo0_l000000ooooooo0000o`00000Pooooo`03o`00
0?oooooooooo03Cooooo0_l00023ooooo`00R_ooool2o`00023ooooo00?o0000ooooooooool0=?oo
ool4o`00087ooooo0026ooooo`;o00009?ooool00ol0003oooooooooo`0fooooo`;o0000POooool0
08Kooooo0_l0000Kooooo`;o00001oooool00ol0003oooooooooo`2iooooo`00Xoooool2o`0000Oo
oooo00?o0000ooooooooool0^Oooool00:7ooooo0ol00008ooooo`03o`000?oooooooooo03Kooooo
0_l00021ooooo`00XOooool3o`0000Sooooo00?o0000ooooooooool0=_ooool2o`00087ooooo002R
ooooo`;o00000oooool2o`000003ooooool0003o000000?o0000^Oooool00:3ooooo0_l000001Ooo
oooo0000o`000?l0003ooooo00;o000000Coooooo`000?l0003o0000^oooool00:3ooooo0_l00000
0ooooooo0000o`000002o`0000Gooooo00?o0000ooooooooool0^Oooool008Gooooo0_l0000Noooo
o`;o00001Oooool00ol0003oooooooooo`2iooooo`00QOooool5o`0001Sooooo0_l00008ooooo`04
o`000?oooooo0000o`000;Sooooo0027ooooo`?o00005_ooool4o`0000Sooooo00Co0000ooooool0
003o0000^?ooool008Wooooo0_l0000Dooooo`?o00002_ooool00ol0003oooooooooo`0oooooo`;o
0000N?ooool008Gooooo0_l00002ooooo`;o00005?ooool4o`0000Oooooo0ol00011ooooo`;o0000
N?ooool008Gooooo0_l0000Eooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`Ko0000^Ooo
ool009cooooo0_l00007ooooo`;o00000_ooool5o`0003oooooo0_l000000ooooooo0000o`00001f
ooooo`00Z_ooool3o`00043ooooo0_l000000ooooooo0000o`00001fooooo`00QOooool2o`0002?o
oooo0ol00003ooooo`;o0000]_ooool008Cooooo0ol0000Tooooo`;o00000oooool2o`000003oooo
ool0003o00000;?ooooo0024ooooo`;o00009_ooool01?l0003oooooo`000?l00003ooooo`;o0000
/oooool0097ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`;o000000?oooooob4Q8OlQ8B40
1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00Co0000ooooool0003o00000oooool2o`00
0;?ooooo0026ooooo`;o00002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo0_l000000ooo
oooo8B4Qob4Q8@08ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool00oooool3o`00
03gooooo0_l0001dooooo`00Q_ooool2o`000003ooooool0003o000000Co00000_ooool01Ol@413o
oooooooooooooooo410@00?ooooo0_l0000;ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool4o`0003cooooo0_l0001dooooo`00TOooool01Ol0003ooooooooooooooooo0000
00;ooooo1?l00009ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00005ooooo`;o0000?_ooool3o`00
077ooooo002Aooooo`04o`000?ooooooooooooooo`Oo00001_ooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool0AOooool3o`00077ooooo0026ooooo`;o00002Oooool01Ol@
413ooooooooooooooooo410@00;o00002_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0;Wooooo0026ooooo`;o00002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`08ooooo`;o0000[oooool0097ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`08ooooo`;o0000[oooool0
09Sooooo0_l0000Booooo`03o`000?oooooooooo0;Wooooo0024ooooo`;o00004_ooool2o`0001;o
oooo00?o0000ooooooooool01_ooool2o`000;7ooooo0024ooooo`;o00009_ooool00ol0003ooooo
ooooo`06ooooo`;o00000_ooool2o`000:gooooo002/ooooo`?o00002_ooool2o`000:gooooo0024
ooooo`Co00003oooool2o`0001?ooooo00?o0000ooooooooool0^Oooool008Cooooo1?l0000?oooo
o`;o00004oooool00ol0003oooooooooo`2iooooo`00Q?ooool2o`0002Kooooo00?o0000oooooooo
ool02oooool2o`000:cooooo002/ooooo`03o`000?oooooooooo00Sooooo0_l000000ooooooo0000
o`00002/ooooo`00UOooool2o`0001Gooooo00?o0000ooooooooool01oooool3o`0004Kooooo0_l0
001Wooooo`00UOooool2o`0001Gooooo00?o0000ooooooooool01oooool2o`0000Oooooo0_l0000n
ooooo`;o0000Ioooool008;ooooo0_l000000ooooooo0000o`00000Uooooo`03o`000?oooooooooo
013ooooo0_l0002Wooooo`00P_ooool2o`000003ooooool0003o000002Gooooo0ol0000<ooooo`Co
0000@?ooool2o`0006Oooooo0024ooooo`;o00009_ooool00ol0003oooooooooo`0<ooooo`Co0000
@?ooool2o`0006Oooooo0024ooooo`;o00009_ooool00ol0003oooooooooo`0<ooooo`;o0000Zooo
ool008;ooooo0_l0000Xooooo`03o`000?oooooooooo00cooooo0ol0002Zooooo`00POooool3o`00
02Sooooo00?o0000ooooooooool03?ooool3o`0004Gooooo0_l0001Sooooo`00POooool2o`0002;o
oooo0_l00005ooooo`03o`000?oooooooooo00cooooo0_l00016ooooo`;o0000Hoooool008?ooooo
1?l0000Nooooo`;o00001Oooool00ol0003oooooooooo`1Cooooo`;o0000I?ooool008?ooooo1?l0
000Nooooo`Ko000000?oooooo`000?ooool0E?ooool2o`0006Cooooo002Wooooo`Co000000Cooooo
o`000?l0003o00003?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`000:;ooooo002U
ooooo`;o00000_ooool2o`000003ooooool0003ooooo00gooooo0_l00002ooooo`;o000000?ooooo
o`000?l000000_l0002Rooooo`00YOooool2o`0000;ooooo0_l000000ooooooo0000ooooo`2joooo
o`00X?ooool2o`0000[ooooo00?o0000ooooooooool04_ooool2o`0000;ooooo0_l0002Qooooo`00
Woooool3o`0000Sooooo0ol0000Dooooo`;o00000_ooool2o`00043ooooo0_l0001Oooooo`00Tooo
ool2o`0000[ooooo0_l00009ooooo`?o0000F_ooool2o`0005oooooo002Cooooo`;o00005oooool0
0ol0003oooooooooo`2iooooo`00POooool2o`00013ooooo0_l0000Gooooo`03o`000?oooooooooo
01;ooooo0_l00016ooooo`;o0000GOooool0087ooooo0_l0000Xooooo`;o00005?ooool4o`0004Co
oooo0_l0001Mooooo`00Zoooool4o`0001;ooooo1?l0002Sooooo`00[?ooool00ol0003ooooooooo
o`0Booooo`;o0000YOooool00:cooooo0ol0000Gooooo`;o0000X?ooool009?ooooo0_l0000Goooo
o`?o00005oooool2o`000:3ooooo0022ooooo`;o00003oooool2o`0001Oooooo0ol0000Aooooo`;o
00001?ooool2o`000:3ooooo0022ooooo`;o00001Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool04Oooool2o`0000Cooooo0_l0002Pooooo`00P?ooool2o`0000Oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`0Jooooo`;o0000WOooool0083ooooo1ol00002oooo
o`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So0000o`000009ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool06_ooool2o`0009gooooo0020ooooo`;o000000?oooooo`00
0?l000001?ooool01Ol0003ooooooooooooooooo000000;ooooo0_l00009ooooo`;o000000?ok^k^
ooooooooool01Oooool00omgMgOo<S8booooo`04ooooo`?o0000^Oooool008?ooooo0_l00004oooo
o`05o`000?ooooooooooooooool000000_ooool2o`0000[ooooo00?oMgMgofIVI_ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool00_l0000Fooooo`;o0000Wooo
ool008Wooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`02o`0001Kooooo0_l0002Oooooo`00ROooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0_l00006ooooo`05o`000?nj^[[ooooooiRHV?l@4100
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool2o`0000Kooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co
00001_ooool00ol0003oooooooooo`0Kooooo`;o0000W?ooool0093ooooo0ol00007ooooo`;o0000
4?ooool00ol0003oooooooooo`0Kooooo`;o0000W?ooool0087ooooo1?l0000;ooooo`?o00001ooo
ool2o`00013ooooo00?o0000ooooooooool07_ooool2o`0009Wooooo0021ooooo`Co00002_ooool2
o`0001_ooooo00?o0000ooooooooool07_ooool2o`0009Wooooo002?ooooo`;o00006oooool3o`00
0;Wooooo002Booooo`;o00006?ooool00ol0003oooooooooo`2iooooo`00T_ooool2o`0001Sooooo
00?o0000ooooooooool00_ooool2o`0001Cooooo0_l0002Oooooo`00[?ooool00ol0003ooooooooo
o`02ooooo`?o00004oooool4o`0009gooooo002/ooooo`03o`000?oooooooooo00?ooooo0_l0000C
ooooo`Co00000_ooool2o`0009Wooooo002/ooooo`03o`000?oooooooooo00Cooooo0_l0000Boooo
o`?o00000oooool2o`0009Wooooo002/ooooo`03o`000?oooooooooo00Cooooo0_l0000Cooooo`;o
00001Oooool3o`0009Kooooo0022ooooo`;o0000:?ooool00ol0003oooooooooo`0Hooooo`Go0000
0oooool3o`0009Kooooo0020ooooo`Co00003?ooool2o`0001[ooooo0ol0000Hooooo`Go0000W?oo
ool007oooooo0ol0000>ooooo`;o00006_ooool00ol0003oooooooooo`0Mooooo`;o0000V_ooool0
07oooooo0ol0000Zooooo`03o`000?oooooooooo01gooooo0_l0002Jooooo`00P?ooool4o`0002So
oooo00?o0000ooooooooool08?ooool4o`0009Gooooo0022ooooo`;o0000:?ooool00ol0003ooooo
ooooo`0Pooooo`Co0000UOooool0097ooooo0_l0000Iooooo`03o`000?oooooooooo027ooooo0ol0
002Eooooo`00TOooool2o`0001Wooooo00?o0000ooooooooool01Oooool2o`0001[ooooo0ol0002E
ooooo`00P?ooool2o`0000oooooo0_l0000Iooooo`03o`000?oooooooooo00Gooooo0_l0002boooo
o`00P?ooool2o`0000oooooo0_l0000Iooooo`03o`000?oooooooooo023ooooo0_l0002Gooooo`00
POooool2o`0002Wooooo0ol00006ooooo`;o00005?ooool2o`0000;ooooo0_l0002Gooooo`00Oooo
ool4o`0002Wooooo00?o0000ooooooooool01_ooool2o`0001Cooooo0_l0002Kooooo`00Ooooool2
o`0000kooooo0_l0000Kooooo`03o`000?oooooooooo00Kooooo0_l0002aooooo`002Oooool4o`00
0003oa0@4?oooooooooo01Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool0
0ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00;ooooo0_l000000ooooooo8B4Qob4Q8@04ooooo`Go00000_ooool2o`00
0005odA4A?l0003o0000oc8b<_oMgMd05_ooool00ol0003oooooooooo`06ooooo`;o00004?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool0
0ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd06?ooool4o`000003oa0@4?oo
oooooooo01;ooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00_ooool2o`000003oooooolQ8B7o8B4Q00Cooooo00KoV9RHob4Q8Oo^
k^koooooodA4A?ooool2o`0000Cooooo00?oMgMgoc8b<_ooool05Oooool00ol0003oooooooooo`0H
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool2o`000003oooooolQ8B7o8B4Q00Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`0Ioooo
o`03o`000?oooooooooo01Cooooo0006o`0000Gooooo00?o0000ooooooooool04?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000oooo
ooooool01Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^
kP02ooooo`;o00001Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Sooooo00Go
410@oooooooooooooooooa0@4002ooooo`;o00002?ooool00onHV9So8B4Qonk^kP09ooooo`03o`00
0?oooooooooo00gooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00go
oooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05
o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo
00kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000
ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00?ooooo0_l00002ooooo`03ogMgMolb
<S;ooooo01Gooooo00?o0000ooooooooool06?ooool01?l0003oooooooooooooool4o`0000;ooooo
0_l00006ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooo
oooooooooooo000000oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo0000
00kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo
01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000>oooo
o`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000oooooooooooo
ooooo`000003ooooo`;o00002Oooool00omgMgOoIVIVooooo`02ooooo`;o000000Co8B4Qo`000?lb
<S;oc<c<5_ooool00ol0003oooooooooo`07ooooo`;o00003oooool01?l0003oooooooooooooool8
o`0000Oooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go
0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003o
oooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<01[ooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol@
413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`0A
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0Aooooo`05oa0@4?oo
ooooooooooooool@41000oooool2o`0000[ooooo00?o0000ooooooooool00ol0000Jooooo`?o0000
1oooool2o`0000oooooo00Go410@oooooooooooooooooa0@4003ooooo`;o00000oooool2o`0000Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Aooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003_ooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05?ooool0
00_ooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@
oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0<ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
00001?ooool01Ol0003o^[ZjoooooonHV9So410@00;ooooo0ol0000Jooooo`03o`000?oooooooooo
01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02o`0000Kooooo0_l000001_oooooo0000okZj^_oo
ooooV9RHoa0@40Cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00co
oooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooo
oooooooooooooc8b<P04ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05?ooool0
00Wooooo00?oEEEEofIVI_l000006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004
ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2o`0000Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c002ooooo`Ko
00005oooool00ol0003oooooooooo`0Hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_l00009oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co0000
6Oooool00omEEEGoIVIVo`00000Fooooo`00Ooooool2o`0000kooooo0_l0000Kooooo`03o`000?oo
oooooooo0;Wooooo001oooooo`;o00005oooool2o`0001;ooooo00?o0000ooooooooool01_ooool2
o`0001cooooo0_l0002Cooooo`00V?ooool2o`0001;ooooo00?o0000ooooooooool01_ooool2o`00
01Kooooo0_l00004ooooo`;o0000R?ooool2o`0000;ooooo0_l00005ooooo`00[?ooool00ol0003o
ooooooooo`0Nooooo`;o00000oooool3o`0008Sooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd5
ooooo`00P?ooool2o`0002[ooooo00?o0000ooooooooool01oooool2o`0001[ooooo0_l0002:oooo
o`04omgMgOl0003o410@olc<c0Kooooo0007oooooooo0000C?l0000<ooooo`04onk^k_lQ8B7o410@
onk^kPKooooo0007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`;o00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo0_l000000ooooooo0000o`000004ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool2o`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool01?lQ8B7oMgMgogMgMolb<S86
ooooo`001oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Gooooo0_l0000Goooo
o`;o00001oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`09ooooo`;o00000_ooool2o`0000Gooooo0022ooooo`;o
0000:?ooool00ol0003oooooooooo`2iooooo`00P_ooool2o`0002Sooooo00?o0000ooooooooool0
^Oooool008;ooooo0_l0000Xooooo`03o`000?oooooooooo0;Wooooo002Hooooo`;o00004_ooool0
0ol0003oooooooooo`07ooooo`;o00006oooool2o`0009?ooooo002Hooooo`;o00004_ooool00ol0
003oooooooooo`07ooooo`;o00006Oooool4o`0009?ooooo002/ooooo`?o00007Oooool2o`0000?o
oooo0_l0002Eooooo`00POooool2o`0001Kooooo0_l0000Aooooo`03o`000?oooooooooo01gooooo
0_l0002Jooooo`00POooool2o`0001Kooooo0_l0000Aooooo`03o`000?oooooooooo00Kooooo0_l0
002aooooo`00[?ooool00ol0003oooooooooo`06ooooo`;o0000/Oooool0083ooooo0ol0000Yoooo
o`03o`000?oooooooooo00Kooooo0_l0002aooooo`00P?ooool3o`0002Wooooo00?o0000oooooooo
ool01_ooool2o`000;7ooooo002/ooooo`03o`000?oooooooooo02Sooooo0_l0002?ooooo`00TOoo
ool2o`0001Wooooo00?o0000ooooooooool0:?ooool2o`0008oooooo0021ooooo`;o00003_ooool2
o`0001Wooooo00?o0000ooooooooool01_ooool2o`000;7ooooo0021ooooo`;o0000:Oooool3o`00
00Kooooo0_l0002aooooo`00[?ooool00ol0003oooooooooo`07ooooo`;o00006?ooool3o`0009Go
oooo002Aooooo`;o00006Oooool00ol0003oooooooooo`07ooooo`;o00006?ooool3o`0000Cooooo
0_l0002?ooooo`00POooool2o`0000kooooo0_l0000Iooooo`03o`000?oooooooooo00Kooooo0_l0
000Iooooo`;o00001Oooool2o`0008oooooo0021ooooo`;o0000:Oooool00ol0003oooooooooo`06
ooooo`;o00006?ooool2o`0009Oooooo0021ooooo`;o0000:Oooool00ol0003oooooooooo`0Poooo
o`;o000000Coooooo`000?l0003o0000Toooool0093ooooo0_l0000Jooooo`03o`000?oooooooooo
00Oooooo0_l0000Jooooo`?o0000Toooool0093ooooo0_l0000Jooooo`03o`000?oooooooooo00Oo
oooo0_l0002`ooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo01kooooo0_l0
0005ooooo`;o0000T_ooool009;ooooo0_l0000Hooooo`03o`000?oooooooooo00Oooooo0_l0000E
ooooo`Co00000oooool2o`0009;ooooo002@ooooo`Co00006?ooool00ol0003oooooooooo`05oooo
o`Co00005oooool2o`0009Oooooo002@ooooo`?o00001oooool2o`00013ooooo00?o0000oooooooo
ool01Oooool2o`0001_ooooo0_l0002Eooooo`00V_ooool2o`00013ooooo00?o0000ooooooooool0
8_ooool4o`0009?ooooo0023ooooo`;o00009oooool00ol0003oooooooooo`0Sooooo`?o0000Tooo
ool008?ooooo0_l0000Wooooo`03o`000?oooooooooo02Oooooo0_l0002@ooooo`00[?ooool3o`00
01gooooo0_l00008ooooo`;o0000T?ooool00:cooooo00?o0000ooooooooool07Oooool2o`0009[o
oooo002/ooooo`03o`000?oooooooooo027ooooo0_l0002Fooooo`00[?ooool00ol0003ooooooooo
o`04ooooo`;o00006oooool2o`0009Kooooo002/ooooo`03o`000?oooooooooo00Cooooo0_l0002c
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool0^Oooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo0_l00005ooooo`03o`000?oooooooooo02Cooooo0_l0
002Cooooo`00ROooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02?oo
ool2o`0000Gooooo0ol00004ooooo`;o00006?ooool2o`0000Cooooo0ol0002Booooo`00ROooool0
1Ol0003ooooooooooooooooo000000Gooooo0_l00006ooooo`03oiRHV?lQ8B7ok^k^00;ooooo0_l0
0003ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool01?ooool2o`0001Sooooo0_l0
0003ooooo`Co0000T_ooool008Wooooo00Go0000ooooooooooooooooo`000005ooooo`;o00001ooo
ool01?mgMgOoIVIVooooooooool3o`000004ob4Q8Ol0003o<S8bolc<c0Gooooo00?o0000oooooooo
ool08oooool2o`0009Cooooo0029ooooo`05oa0@4?ooooooooooooooool@41001?ooool2o`0000Wo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Wo
oooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool2o`0000Gooooo00Go0000okZj^_oo
ooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool2o`00
01Wooooo0_l00002ooooo`;o0000U_ooool008Cooooo0_l00003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooo
oooo00;ooooo0_l0000Iooooo`;o00000_ooool2o`0009Kooooo0024ooooo`;o00009_ooool00ol0
003oooooooooo`0Rooooo`;o0000UOooool00:cooooo00?o0000ooooooooool07?ooool2o`0000Co
oooo0_l0002Eooooo`00[?ooool00ol0003oooooooooo`0Kooooo`?o0000Voooool009Cooooo0_l0
000Fooooo`?o00006oooool3o`0009_ooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`0L
ooooo`Co0000VOooool008Cooooo0_l0000Vooooo`03o`000?oooooooooo01kooooo0ol000000ooo
oooo0000o`00002Eooooo`00Q?ooool2o`0002Kooooo00?o0000ooooooooool07oooool2o`000003
ooooool0003o000009Gooooo002/ooooo`03o`000?oooooooooo01oooooo0ol0002Gooooo`00QOoo
ool2o`0002Gooooo00?o0000ooooooooool07Oooool5o`0009Oooooo0025ooooo`;o00009Oooool0
0ol0003oooooooooo`0Looooo`?o0000V_ooool008Gooooo0_l0000Uooooo`03o`000?oooooooooo
01cooooo0_l0002Kooooo`00[?ooool7o`0001kooooo0_l0002Eooooo`00[?ooool00ol0003ooooo
ooooo`04o`0001kooooo0_l0002Eooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`0Rooooo`Co0000Toooool009Sooooo0_l0000Booooo`03o`000?oooooooooo
00;o00006Oooool2o`0000Gooooo1?l0002Cooooo`00V?ooool2o`0001;ooooo00?o0000oooooooo
ool00_l0000Iooooo`;o000000?oooooo`000?l00000VOooool00:cooooo00?o0000ooooooooool0
7_ooool2o`0000;ooooo0_l0002Eooooo`00[?ooool4o`00027ooooo0_l0002Eooooo`00Q?ooool2
o`000003ooooool0003o000000gooooo0_l0000Dooooo`Co0000^?ooool008Cooooo0_l000000ooo
oooo0000o`00000=ooooo`;o00004oooool2o`000003ooooool0003o00000;Sooooo002Zooooo`Ko
00006?ooool2o`0009kooooo002Zooooo`Go00006Oooool2o`0009kooooo0028ooooo`;o00008_oo
ool00ol0003oooooooooo`2iooooo`00R?ooool2o`0000oooooo0_l0000Aooooo`?o0000^Oooool0
09Wooooo0_l0000Aooooo`?o0000^Oooool00:Wooooo1?l0000Hooooo`;o00000_ooool2o`0009go
oooo002Yooooo`Ko00005_ooool2o`0000;ooooo0ol0002Looooo`00Q_ooool4o`00017ooooo0_l0
000?ooooo`03o`000?oooooooooo01Kooooo0_l00002ooooo`?o000000Coooooo`000?l0003o0000
V?ooool008Kooooo1?l0000Aooooo`;o00002?ooool2o`0000Gooooo00?o0000ooooooooool07_oo
ool3o`0009Sooooo0028ooooo`;o00006oooool2o`0000Gooooo00?o0000ooooooooool07Oooool2
o`0009[ooooo0028ooooo`;o00004?ooool2o`0000?ooooo0_l0000;ooooo`03o`000?oooooooooo
01gooooo0ol0002Iooooo`00R?ooool2o`00013ooooo0_l00003ooooo`;o00000oooool2o`0000Ko
oooo00?o0000ooooooooool05Oooool2o`0000Oooooo0_l0002Iooooo`00ROooool2o`0000Kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?l0003ogMgM
00Gooooo00?o0000ooooooooool05Oooool2o`000003ooooool0003o000009oooooo0029ooooo`;o
00001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`;o000000Coooooo`00
0?l0003o<S8b1Oooool00ol0003oooooooooo`0Hooooo`;o0000Woooool0097ooooo00Go410@oooo
oooooooooooooa0@400;ooooo`;o000000Coooooo`000?l0003o00001Oooool00ol0003ooooooooo
o`2iooooo`00Q_ooool2o`0000Wooooo00Go0000ooooooooooooooooo`00000?ooooo`;o00001Ooo
ool3o`000;Wooooo0026ooooo`;o00002Oooool01Ol0003ooooooooooooooooo000000cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;Wooooo0027ooooo`;o00002?oo
ool01Ol@413ooooooooooooooooo410@00cooooo00Co0000ooooool0003o00001_ooool00ol0003o
ooooooooo`0Dooooo`;o00001?ooool2o`0009gooooo0027ooooo`;o00002?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00cooooo00Co0000ooooool0003o00001_ooool00ol0003oooooooooo`0Doooo
o`?o00000oooool2o`0009gooooo0029ooooo`;o00001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo1?l00006ooooo`03o`000?oooooooooo01;ooooo0_l000000ooooooo0000o`000002o`00
0:3ooooo0029ooooo`;o00008Oooool00ol0003oooooooooo`0Booooo`;o00000_ooool5o`0009ko
oooo002/ooooo`03o`000?oooooooooo01Wooooo0_l0002Nooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00Roooool2o`0001oooooo0ol0000Dooooo`;o0000Xoooool008_ooooo0_l0000Ooooo
o`03o`000?oooooooooo01Cooooo0_l0002Sooooo`00S?ooool2o`0001kooooo00?o0000oooooooo
ool04Oooool2o`0000?ooooo0_l0002Qooooo`00S?ooool2o`0001kooooo00?o0000ooooooooool0
4Oooool3o`0000;ooooo0_l0002Qooooo`00ROooool3o`00023ooooo00?o0000ooooooooool04_oo
ool2o`000:Gooooo0029ooooo`Go00007_ooool00ol0003oooooooooo`0Aooooo`;o0000Y_ooool0
08cooooo0_l0000Nooooo`03o`000?oooooooooo017ooooo0_l0002Vooooo`00S?ooool2o`0001ko
oooo00?o0000ooooooooool05_ooool2o`000:7ooooo002=ooooo`;o00007Oooool3o`0001Kooooo
0_l0002Qooooo`00SOooool2o`0001gooooo00?o0000ooooooooool03oooool2o`000:Sooooo0029
ooooo`?o00008?ooool00ol0003oooooooooo`0?ooooo`;o0000Z?ooool008Wooooo0ol0000Poooo
o`03o`000?oooooooooo00[ooooo0_l00002ooooo`;o0000ZOooool00:cooooo00?o0000oooooooo
ool02_ooool2o`0000;ooooo0_l0002Yooooo`00[?ooool00ol0003oooooooooo`0Dooooo`;o0000
Xoooool00:cooooo00?o0000ooooooooool05?ooool2o`000:?ooooo002/ooooo`03o`000?oooooo
oooo00_ooooo0_l00003ooooo`;o00000_ooool2o`000:?ooooo002/ooooo`?o00002oooool2o`00
00?ooooo0_l0002Wooooo`00[?ooool00ol0003oooooooooo`0?ooooo`;o0000Z?ooool00:cooooo
00?o0000ooooooooool03oooool2o`000:Sooooo002/ooooo`03o`000?oooooooooo00Sooooo0_l0
0005ooooo`Co0000Y_ooool00:cooooo00?o0000ooooooooool02?ooool4o`0000?ooooo1?l0002V
ooooo`00[?ooool00ol0003oooooooooo`0:ooooo`;o0000[Oooool00:cooooo00?o0000oooooooo
ool01Oooool2o`000;;ooooo002=ooooo`;o00007Oooool00ol0003oooooooooo`05ooooo`;o0000
/_ooool008gooooo0_l0000Mooooo`03o`000?oooooooooo00gooooo0_l0002Zooooo`00TOooool3
o`0001Sooooo0ol0000=ooooo`;o0000Z_ooool008kooooo0_l000001?oooooo0000o`000?l0000H
ooooo`03o`000?oooooooooo00Kooooo0_l00002ooooo`;o0000[Oooool008kooooo0_l0000Loooo
o`03o`000?oooooooooo00Kooooo0_l00002ooooo`;o0000[Oooool00:cooooo00?o0000oooooooo
ool0^Oooool008kooooo1Ol0000Iooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Ol00002ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000
o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool01Oooool2o`000;;ooooo0029ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo00Gooooo0_l0002booooo`00ROooool01Ol@413ooooo
oooooooooooo410@00Sooooo0_l00003ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`2iooooo`00ROooool01Ol0003ooooooooooooooooo000000So
oooo0_l00004ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`0000Wo
oooo0_l0002^ooooo`00ROooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?oo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo1?l00008ooooo`;o0000[_ooool008Wo
oooo00Go410@oooooooooooooooooa0@4003ooooo`;o00002Oooool00onYZJWoMgMgooooo`03oooo
o`03o`000?oooooooooo00Oooooo1?l0002hooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo0_l00006ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5
o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
00?ooooo0_l0002dooooo`00TOooool2o`0001Wooooo00?o0000ooooooooool00_ooool3o`000;Co
oooo002Aooooo`;o000000Coooooo`000?l0003o00001Oooool2o`0000kooooo00?o0000oooooooo
ool00_ooool2o`000;Gooooo002Dooooo`?o00001Oooool2o`0000gooooo1?l0002iooooo`00U?oo
ool3o`0000Kooooo0_l00008ooooo`;o00000_ooool2o`000003ooooool0003o00000;Sooooo002D
ooooo`;o00001oooool2o`0000;ooooo0_l00004ooooo`;o00000oooool01?l0003oooooo`000?l0
002hooooo`00Uoooool2o`0000Sooooo0_l00005ooooo`;o00000_ooool2o`000;[ooooo002Eoooo
o`Co00003oooool2o`0000;ooooo0_l00002ooooo`;o0000]_ooool009Gooooo1?l0000Booooo`;o
00000oooool2o`000;Kooooo002Gooooo`;o00003_ooool2o`0000;ooooo0_l0002kooooo`00Yooo
ool2o`0000?ooooo00?o0000ooooooooool0^Oooool009Kooooo0_l0000Booooo`Go0000^Oooool0
09Kooooo0_l0000Booooo`?o0000^oooool00:;ooooo0_l00007ooooo`;o0000^oooool00:;ooooo
2?l000000ooooooo0000o`00002kooooo`00Xoooool7o`0000;ooooo00?o0000ooooooooool0^Ooo
ool00:Wooooo0_l000000ooooooo0000ooooo`2jooooo`00Voooool6o`0000Sooooo0_l000000ooo
oooo0000ooooo`2jooooo`00Voooool6o`0000Kooooo1?l000000ooooooo0000ooooo`2jooooo`00
Yoooool2o`0000?ooooo00?o0000ooooooooool0^Oooool00:;ooooo0_l00008ooooo`?o0000^Ooo
ool00:;ooooo0_l00008ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:;ooooo
1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000ooooooooool01Oooool3
o`000;Wooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7o
oooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002R
ooooo`03oeEEEOmVIVKo00000<?ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo002Zooooo`04oa0@4?l0003o0000o`000;[ooooo002[ooooo`03o`000?oooooo
oooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`06o`000?mgMgOo0000o`00
0?mEEEGok^k^]oooool00:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomEEEFgooooo`00Zoooool0
0ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo0;Gooooo002[ooooo`03o`000?o^k^kooooo
00;ooooo00?o0000ooooooooool0]Oooool00:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomVIVJg
ooooo`00Z_ooool00ol@413o0000ogMgM`02o`000003ofIVI_o^k^kooooo0;Kooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.64184 .56277 Mdot
.64985 .58053 Mdot
.50531 .52688 Mdot
.51327 .6954 Mdot
.41247 .35048 Mdot
.63388 .46375 Mdot
.43629 .51174 Mdot
.49031 .98761 Mdot
.4089 .86883 Mdot
.46326 .77272 Mdot
.4265 .68507 Mdot
.40383 .87536 Mdot
.65618 .61608 Mdot
.48048 .78458 Mdot
.36851 .39886 Mdot
.50578 .72728 Mdot
.59359 .36238 Mdot
.6568 .61669 Mdot
.40978 .58482 Mdot
.63093 .74391 Mdot
.62329 .70871 Mdot
.63067 .66645 Mdot
.59397 .75141 Mdot
.64821 .64913 Mdot
.36947 .35355 Mdot
.44285 .19574 Mdot
.41142 .46652 Mdot
.40926 .44044 Mdot
.60812 .78761 Mdot
.63614 .63625 Mdot
.57442 .80165 Mdot
.4479 .95947 Mdot
.43073 .94292 Mdot
.61309 .44922 Mdot
.61248 .39203 Mdot
.54549 .86508 Mdot
.50348 .94224 Mdot
.41181 .4174 Mdot
.53007 .8976 Mdot
.43407 .96094 Mdot
.37041 .67212 Mdot
.61153 .40485 Mdot
.62671 .45732 Mdot
.65046 .49503 Mdot
.64578 .48434 Mdot
.42034 .28423 Mdot
.42681 .67787 Mdot
.50556 .95339 Mdot
.49869 .17067 Mdot
.55889 .85741 Mdot
.48741 .96806 Mdot
.56329 .86211 Mdot
.58073 .05147 Mdot
.62387 .46749 Mdot
.61673 .39094 Mdot
.41054 .88152 Mdot
.46353 .98898 Mdot
.58137 .32015 Mdot
.50807 .94462 Mdot
.64446 .47599 Mdot
.44154 .21035 Mdot
.37425 .25588 Mdot
.49919 .9333 Mdot
.5444 .4872 Mdot
.37126 .61927 Mdot
.44734 .96165 Mdot
.4506 .75305 Mdot
.47417 .75957 Mdot
.41011 .56537 Mdot
.63471 .68967 Mdot
.55003 .23815 Mdot
.43331 .48368 Mdot
.43464 .70873 Mdot
.47104 .7722 Mdot
.49845 .93404 Mdot
.48796 .6346 Mdot
.58168 .05256 Mdot
.51622 .22266 Mdot
.57597 .84276 Mdot
.56972 .32527 Mdot
.56055 .83293 Mdot
.62959 .65414 Mdot
.50404 .71344 Mdot
.60915 .38692 Mdot
.48846 .98421 Mdot
.53817 .64782 Mdot
.41274 .34628 Mdot
.4676 .18497 Mdot
.56024 .26901 Mdot
.46555 .75604 Mdot
.37739 .26985 Mdot
.54787 .50511 Mdot
.42535 .26615 Mdot
.54587 .52187 Mdot
.47948 .78413 Mdot
.43008 .92311 Mdot
.58145 .05058 Mdot
.53587 .21736 Mdot
.63857 .5903 Mdot
.53335 .21816 Mdot
.37937 .73848 Mdot
.65038 .52603 Mdot
.61079 .74861 Mdot
.61434 .45116 Mdot
.57353 .2883 Mdot
.40877 .58045 Mdot
.54806 .50263 Mdot
.62333 .71563 Mdot
.48302 .78027 Mdot
.53207 .6418 Mdot
.43897 .94591 Mdot
.61082 .77189 Mdot
.65011 .11718 Mdot
.47213 .28942 Mdot
.47025 .17443 Mdot
.50621 .96384 Mdot
.49238 .97423 Mdot
.44576 .93636 Mdot
.65064 .63439 Mdot
.36164 .43905 Mdot
.58065 .78277 Mdot
.61901 .77074 Mdot
.62953 .70237 Mdot
.49675 .73428 Mdot
.5931 .80307 Mdot
.61555 .68 Mdot
.52466 .40771 Mdot
.6192 .70015 Mdot
.63308 .62157 Mdot
.38134 .76015 Mdot
.63191 .42522 Mdot
.62938 .4631 Mdot
.6069 .79517 Mdot
.57384 .85777 Mdot
.5946 .80531 Mdot
.43138 .6939 Mdot
.39519 .82862 Mdot
.36578 .48419 Mdot
.54631 .56469 Mdot
.4127 .61351 Mdot
.59143 .35352 Mdot
.62599 .74921 Mdot
.49525 .97771 Mdot
.67123 .13676 Mdot
.44331 .23399 Mdot
.46474 .18458 Mdot
.37651 .76198 Mdot
.51967 .19511 Mdot
.42619 .69896 Mdot
.65392 .63296 Mdot
.43357 .51749 Mdot
.63279 .55622 Mdot
.54549 .89021 Mdot
.52615 .90446 Mdot
.47446 .98164 Mdot
.48219 .95757 Mdot
.55284 .88197 Mdot
.46472 .16235 Mdot
.59343 .81833 Mdot
.43833 .97592 Mdot
.5382 .87018 Mdot
.62524 .52397 Mdot
.62668 .63225 Mdot
.48666 .9822 Mdot
.61604 .74227 Mdot
.40994 .55604 Mdot
.58719 .83673 Mdot
.53229 .88748 Mdot
.52536 .64361 Mdot
.40989 .47551 Mdot
.44086 .22423 Mdot
.42692 .28376 Mdot
.39326 .81539 Mdot
.63124 .56268 Mdot
.50679 .34815 Mdot
.5781 .83367 Mdot
.5984 .81737 Mdot
.40984 .90263 Mdot
.5057 .73551 Mdot
.36959 .66468 Mdot
.53209 .43774 Mdot
.39106 .78317 Mdot
.49774 .96664 Mdot
.43114 .96213 Mdot
.62672 .43729 Mdot
.36139 .49175 Mdot
.63022 .74137 Mdot
.54229 .49543 Mdot
.38966 .1631 Mdot
.48178 .98865 Mdot
.3811 .77982 Mdot
.38219 .76301 Mdot
.43002 .2505 Mdot
.57177 .27627 Mdot
.4987 .32908 Mdot
.49978 .33129 Mdot
.43372 .46284 Mdot
.43541 .24117 Mdot
.62791 .63428 Mdot
.53867 .50204 Mdot
.63575 .48939 Mdot
.54711 .57876 Mdot
.52512 .3824 Mdot
.43887 .73773 Mdot
.65681 .59802 Mdot
.50671 .2061 Mdot
.61366 .74698 Mdot
.48103 .7657 Mdot
.62404 .64244 Mdot
.51138 .21669 Mdot
.42539 .95143 Mdot
.52066 .37027 Mdot
.63899 .54294 Mdot
.45603 .98819 Mdot
.46113 .17971 Mdot
.45255 .9538 Mdot
.62436 .72385 Mdot
.54097 .86203 Mdot
.45568 .74747 Mdot
.41274 .35841 Mdot
.6564 .52756 Mdot
.53749 .59562 Mdot
.36778 .41324 Mdot
.36055 .53506 Mdot
.51906 .69257 Mdot
.4569 .64322 Mdot
.54801 .02633 Mdot
.55532 .2724 Mdot
.4154 .61053 Mdot
.36376 .3947 Mdot
.40966 .46998 Mdot
.65148 .52813 Mdot
.61377 .72199 Mdot
.63574 .60891 Mdot
.38266 .19811 Mdot
.62821 .42261 Mdot
.62242 .73628 Mdot
.55024 .23873 Mdot
.4829 .97638 Mdot
.54141 .55866 Mdot
.49721 .94342 Mdot
.59278 .37756 Mdot
.5476 .23399 Mdot
.51673 .91414 Mdot
.37506 .73087 Mdot
.47474 .28979 Mdot
.539 .54725 Mdot
.47311 .95463 Mdot
.48565 .16939 Mdot
.41057 .45853 Mdot
.60717 .34228 Mdot
.48583 .63988 Mdot
.4365 .95764 Mdot
.5108 .9451 Mdot
.52524 .21328 Mdot
.41611 .61795 Mdot
.54401 .85977 Mdot
.51319 .36189 Mdot
.53923 .23239 Mdot
.6363 .58242 Mdot
.41588 .58929 Mdot
.62858 .53904 Mdot
.53144 .88529 Mdot
.52231 .22221 Mdot
.57799 .82278 Mdot
.61536 .37878 Mdot
.48479 .77575 Mdot
.55067 .26971 Mdot
.55908 .87307 Mdot
.51584 .71544 Mdot
.40683 .56738 Mdot
.47428 .97181 Mdot
.46073 .7813 Mdot
.63613 .51963 Mdot
.58309 .8289 Mdot
.49571 .30078 Mdot
.45094 .74587 Mdot
.46916 .95713 Mdot
.39095 .81345 Mdot
.40991 .6001 Mdot
.43472 .52283 Mdot
.46922 .19466 Mdot
.63067 .73155 Mdot
.45349 .19351 Mdot
.55631 .8366 Mdot
.48015 .9639 Mdot
.36645 .52764 Mdot
.44109 .93681 Mdot
.45314 .64116 Mdot
.5404 .90624 Mdot
.41026 .08571 Mdot
.63803 .71177 Mdot
.36751 .42635 Mdot
.68081 .1455 Mdot
.53026 .22858 Mdot
.61381 .35678 Mdot
.63859 .60336 Mdot
.4676 .97555 Mdot
.36442 .53352 Mdot
.4319 .70525 Mdot
.4562 .96283 Mdot
.48394 .16698 Mdot
.48773 .31096 Mdot
.64823 .62821 Mdot
.59313 .35654 Mdot
.64318 .654 Mdot
.37564 .75217 Mdot
.49115 .30213 Mdot
.63788 .56002 Mdot
.61373 .43515 Mdot
.36974 .59525 Mdot
.49985 .31686 Mdot
.398 .85793 Mdot
.3875 .18683 Mdot
.41189 .06445 Mdot
.49959 .73303 Mdot
.62852 .3982 Mdot
.6049 .36517 Mdot
.49203 .94195 Mdot
.40483 .47346 Mdot
.46536 .30162 Mdot
.44081 .57946 Mdot
.57513 .29512 Mdot
.46976 .99378 Mdot
.4502 .93891 Mdot
.54667 .49801 Mdot
.6484 .62119 Mdot
.52111 .38632 Mdot
.43476 .44508 Mdot
.65594 .53589 Mdot
.63198 .44335 Mdot
.62552 .5218 Mdot
.4699 .16037 Mdot
.43882 .23302 Mdot
.54828 .01719 Mdot
.51301 .20772 Mdot
.61831 .67995 Mdot
.54333 .52406 Mdot
.41096 .88684 Mdot
.41192 .45974 Mdot
.58975 .81133 Mdot
.61037 .70732 Mdot
.54955 .5154 Mdot
.5114 .22086 Mdot
.44113 .00895 Mdot
.42086 .92934 Mdot
.56442 .87727 Mdot
.55288 .85676 Mdot
.50712 .18849 Mdot
.58681 .31862 Mdot
.54674 .86868 Mdot
.54561 .24796 Mdot
.41581 .91529 Mdot
.38345 .17587 Mdot
.62222 .73783 Mdot
.37784 .73138 Mdot
.39371 .83882 Mdot
.39273 .84131 Mdot
.43806 .40452 Mdot
.55004 .26314 Mdot
.36687 .43279 Mdot
.45261 .97998 Mdot
.4386 .39856 Mdot
.57391 .80817 Mdot
.54308 .26883 Mdot
.63568 .45888 Mdot
.63908 .58481 Mdot
.42174 .90425 Mdot
.65063 .53446 Mdot
.51042 .93713 Mdot
.45497 .94099 Mdot
.59171 .75417 Mdot
.57855 .85729 Mdot
.61286 .71256 Mdot
.36652 .41371 Mdot
.64992 .1126 Mdot
.43067 .91127 Mdot
.63756 .52422 Mdot
.43687 .43539 Mdot
.37105 .31603 Mdot
.54563 .23842 Mdot
.4418 .586 Mdot
.42259 .94008 Mdot
.63361 .69308 Mdot
.45501 .3171 Mdot
.46177 .76709 Mdot
.4588 .17587 Mdot
.41251 .57484 Mdot
.51165 .94819 Mdot
.64692 .67536 Mdot
.40169 .1126 Mdot
.40872 .89956 Mdot
.60178 .38245 Mdot
.57143 .04582 Mdot
.59653 .35438 Mdot
.41992 .31985 Mdot
.41002 .39466 Mdot
.47996 .65872 Mdot
.45552 .98496 Mdot
.40227 .86869 Mdot
.41115 .48152 Mdot
.5433 .57098 Mdot
.46561 .79129 Mdot
.52943 .677 Mdot
.37197 .71251 Mdot
.41147 .346 Mdot
.5592 .84231 Mdot
.53437 .62472 Mdot
.41948 .65933 Mdot
.51179 .35378 Mdot
.4144 .32908 Mdot
.61179 .44502 Mdot
.42835 .70546 Mdot
.53914 .50644 Mdot
.36267 .59591 Mdot
.40087 .85451 Mdot
.5012 .45789 Mdot
.61347 .3924 Mdot
.5747 .2913 Mdot
.62425 .6088 Mdot
.54794 .27786 Mdot
.40977 .53926 Mdot
.36436 .41663 Mdot
.64755 .56497 Mdot
.63239 .09972 Mdot
.65182 .48468 Mdot
.54024 .47646 Mdot
.38046 .70878 Mdot
.36878 .38663 Mdot
.41563 .6019 Mdot
.59914 .73077 Mdot
.55906 .02848 Mdot
.54049 .58928 Mdot
.45316 .32443 Mdot
.43954 .23899 Mdot
.55931 .83884 Mdot
.55578 .28957 Mdot
.53149 .42443 Mdot
.62184 .46893 Mdot
.60408 .36801 Mdot
.54564 .47612 Mdot
.50425 .33645 Mdot
.5029 .74446 Mdot
.48292 .99079 Mdot
.48246 .28887 Mdot
.59025 .8212 Mdot
.6508 .56519 Mdot
.64341 .52449 Mdot
.58875 .80821 Mdot
.555 .836 Mdot
.59504 .35851 Mdot
.4086 .0632 Mdot
.46311 .76932 Mdot
.47042 .99437 Mdot
.38264 .78851 Mdot
.41329 .53533 Mdot
.55171 .89293 Mdot
.53707 .25252 Mdot
.59988 .40031 Mdot
.59508 .80288 Mdot
.64163 .57609 Mdot
.40717 .51836 Mdot
.50734 .21301 Mdot
.61063 .42386 Mdot
.35987 .47861 Mdot
.62874 .50645 Mdot
.49972 .59789 Mdot
.62617 .48814 Mdot
.56269 .30348 Mdot
.43274 .46733 Mdot
.47535 .75681 Mdot
.6229 .45426 Mdot
.62617 .42603 Mdot
.48501 .29863 Mdot
.49477 .18044 Mdot
.44469 .95844 Mdot
.40585 .4271 Mdot
.63503 .58257 Mdot
.43032 .7262 Mdot
.42713 .29409 Mdot
.443 .36808 Mdot
.63021 .09143 Mdot
.45079 .33829 Mdot
.65339 .55825 Mdot
.41475 .87606 Mdot
.54757 .85877 Mdot
.40941 .555 Mdot
.58828 .81657 Mdot
.40775 .89353 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Hooooo`;o00002_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo002H
ooooo`;o00002_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo002Roooo
o`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool03Oooool2o`000:[ooooo002/ooooo`03o`000?oooooooooo00gooooo0_l0002Zooooo`00[?oo
ool3o`000;Wooooo002/ooooo`03o`000?oooooooooo00cooooo0_l00002ooooo`;o0000Yoooool0
0:cooooo00?o0000ooooooooool03?ooool2o`0000;ooooo0_l0002Wooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0Doooo
o`;o0000Xoooool00:cooooo00?o0000ooooooooool05?ooool2o`000:?ooooo002/ooooo`?o0000
5oooool3o`0009oooooo002/ooooo`03o`000?oooooooooo01Oooooo0ol0002Oooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00SOooool3o`0001co
oooo00?o0000ooooooooool0^Oooool008gooooo0ol0000Looooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
^Oooool008kooooo0_l0000Looooo`03o`000?oooooooooo0;Wooooo002>ooooo`;o00007?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0Xooooo`;o0000Soooool00:co
oooo00?o0000ooooooooool0:?ooool2o`0008oooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`?o0000:?ooool2o`0008oooooo002/ooooo`03o`000?oooooooooo02Sooooo0_l0002?
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
Roooool2o`0001oooooo00?o0000ooooooooool0;_ooool2o`0008Wooooo002;ooooo`;o00007ooo
ool00ol0003oooooooooo`0^ooooo`;o0000ROooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1Oooool00ol0003oooooooooo`0^ooooo`;o0000ROooool008Wooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0;_ooool2o`0008Wooooo0021ooooo`Ko00000_ooool01Ol@413ooooooooo
oooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000
^Oooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2iooooo`00ROooool01Ol0003ooooooooo
oooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool0^Oooool008Wooooo00Go410@oooooooooooooooooa0@400>ooooo`03
ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2iooooo`00
ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0=Oooool2o`0008;ooooo0029ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo
03Gooooo0_l00022ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooo
ooooo`0hooooo`;o0000Ooooool00:cooooo00?o0000ooooooooool0>?ooool2o`0007oooooo002/
ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:;ooooo0_l00008ooooo`03o`000?oooooooooo0;Wooooo0027ooooo`;o00005ooo
ool4o`0000Sooooo00?o0000ooooooooool0^Oooool008Oooooo0_l0000Gooooo`;o00001?ooool2
o`0000Cooooo00?o0000ooooooooool0^Oooool00:Kooooo0ol00002ooooo`;o0000^oooool00:Oo
oooo0_l00002ooooo`;o0000^oooool008Gooooo0_l0000Gooooo`;o00000_ooool2o`0000Sooooo
0ol0002iooooo`00QOooool2o`0001Oooooo0ol000000ooooooo0000o`000008ooooo`03o`000?oo
oooooooo0;Wooooo002Oooooo`;o00002Oooool3o`000;_ooooo002Pooooo`?o00001oooool3o`00
0;_ooooo0026ooooo`;o00006?ooool3o`0000Wooooo00Co0000ooooool0003o0000^?ooool008Ko
oooo0_l0000Tooooo`04o`000?oooooo0000o`000;Sooooo002Looooo`;o00000oooool2o`0000Wo
oooo00?o0000ooooooooool00oooool2o`000;Cooooo0025ooooo`;o00004_ooool2o`000003oooo
ool0003o000000?ooooo0_l00009ooooo`03o`000?oooooooooo00?ooooo0_l0002dooooo`00QOoo
ool2o`0001;ooooo0_l0000Aooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00Co0000ooooool0003o0000^?ooool009Sooooo0_l0000Booooo`03o`000?oooooo0000
00?o0000]_ooool009Sooooo0_l0000Booooo`03o`000?oooooo000000?o00000_ooool2o`000;;o
oooo002/ooooo`03o`000?oooooo000000;o00000oooool2o`000;;ooooo002/ooooo`03o`000?oo
oooooooo00;o00001_ooool2o`000:oooooo002/ooooo`03o`000?oooooooooo00Ko00000_ooool2
o`000:oooooo002Hooooo`;o00004_ooool9o`000;?ooooo002Hooooo`;o00004_ooool00ol0003o
ooooooooo`07ooooo`;o0000/?ooool00:cooooo00?o0000ooooooooool01oooool2o`000;3ooooo
002Gooooo`Co00004Oooool00ol0003oooooooooo`0:ooooo`Co0000Zoooool009Oooooo1?l0000A
ooooo`03o`000?oooooooooo00[ooooo1?l0002[ooooo`00V?ooool2o`0001;ooooo00?o0000oooo
ooooool03?ooool3o`000:[ooooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?l000000ooo
oooo8B4Qob4Q8@05ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0<
ooooo`?o0000Z_ooool0097ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02o`0000?ooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0^Oooool008Wooooo1_l00002oooo
o`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00cooooo0_l0002[ooooo`00TOooool00ol0003oooooooooo`02o`0000oooooo00?oMgMgoc8b
<_ooool01?ooool3o`0000Wooooo0_l000000ooooooo0000o`00002[ooooo`00P_ooool2o`0000go
oooo00?o0000ooooooooool00_l0000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0
003oooooooooo`09ooooo`;o0000[_ooool008;ooooo0_l0000=ooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Wooooo002Aooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
0;Wooooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000oooo
ooooool03Oooool2o`000:[ooooo002Cooooo`;o00005oooool00ol0003oooooooooo`0=ooooo`;o
0000Z_ooool008?ooooo0_l0000>ooooo`;o00005oooool00ol0003oooooooooo`0;ooooo`Co0000
00?oooooo`000?l00000Yoooool008?ooooo0_l0000Wooooo`03o`000?oooooooooo00_ooooo1ol0
002Wooooo`00[?ooool3o`0000oooooo0_l00003ooooo`;o0000Xoooool00:cooooo00?o0000oooo
ooooool03?ooool2o`0000Kooooo0_l0002Sooooo`00[?ooool00ol0003oooooooooo`0<ooooo`;o
0000Zoooool0097ooooo1?l0000Gooooo`03o`000?oooooooooo0;Wooooo002Aooooo`Co00003Ooo
ool2o`0000;ooooo0_l00004ooooo`03o`000?oooooooooo01Gooooo0_l0002Rooooo`00X_ooool3
o`000003ooooool0003o000000Cooooo00?o0000ooooooooool03oooool2o`0000Cooooo0_l0002R
ooooo`00U?ooool2o`0000gooooo0_l00007ooooo`03o`000?oooooooooo00oooooo0_l00004oooo
o`;o0000X_ooool009Cooooo0_l0000Fooooo`03o`000?oooooooooo01Gooooo0_l0002Rooooo`00
Yoooool2o`000003ooooool0003o000000?o0000^Oooool00:3ooooo0_l00005ooooo`Ko00004ooo
ool2o`000:Kooooo002Pooooo`;o00001oooool2o`000003ooooool0003ooooo01;ooooo0_l0002V
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00Z?ooool2o`0000;ooooo00?o0000oooooooo
ool0^Oooool0087ooooo0_l0000Uooooo`;o00000_ooool00ol0003oooooooooo`2iooooo`00POoo
ool2o`0001[ooooo0_l0000=ooooo`;o00006_ooool2o`0009kooooo002Aooooo`;o00002_ooool2
o`0000gooooo0_l0000Hooooo`Co0000W_ooool0097ooooo0_l00009ooooo`;o00003_ooool3o`00
01Cooooo0_l000000ooooooo0000o`00002Pooooo`00W?ooool2o`0000kooooo00?o0000oooooooo
ool05?ooool2o`000:?ooooo002?ooooo`;o00006_ooool2o`000;_ooooo002?ooooo`;o00006_oo
ool2o`000;_ooooo002/ooooo`?o0000^Oooool009_ooooo0_l0000?ooooo`?o0000^Oooool009_o
oooo0_l0000?ooooo`03o`000?oooooooooo023ooooo0_l0002Gooooo`00S_ooool3o`0001_ooooo
00?o0000ooooooooool08?ooool2o`0009Oooooo002>ooooo`?o00006oooool01?l0003oooooo`00
0?l0002hooooo`00Soooool2o`0001_ooooo1?l0002hooooo`00P?ooool2o`0000gooooo0_l0000K
ooooo`03o`000?oooooooooo00;o00006Oooool3o`0009_ooooo0020ooooo`;o00003Oooool2o`00
01_ooooo00?o0000ooooooooool00_l0000Iooooo`?o00001?ooool2o`0009Gooooo002?ooooo`;o
00006oooool01?l0003oooooooooooooool2o`0001Sooooo0ol00004ooooo`;o0000UOooool00:co
oooo00Co0000oooooooooooooooo0_l0000Hooooo`;o00000_ooool2o`0009Sooooo0029ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Kooooo`;o00000_ooool2o`0009Sooooo0029oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo0_l000000oo^k^koooooodA4A007
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool00oooool2o`0001[ooooo0_l0002H
ooooo`00POooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7o
k^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`;o0000]?ooool0
08Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMg
oc8b<_ooool01?ooool3o`000;Wooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool0
0omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`0Kooooo`;o00001_ooool2o`0009Cooooo0029ooooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Ooo
ool2o`0001Cooooo0_l000000ooooooo0000o`000003ooooo`;o0000U?ooool008Wooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Cooooo0ol0000Gooooo`;o0000VOooool0083ooooo0_l0
0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Co
oooo1?l00006ooooo`03o`000?oooooooooo00Cooooo0_l0000Kooooo`;o0000U_ooool0083ooooo
0_l0000Zooooo`03o`000?oooooooooo027ooooo1?l0002Dooooo`00Ooooool2o`0000gooooo0_l0
000Looooo`03o`000?oooooooooo02;ooooo0ol0002Dooooo`00Ooooool2o`0000gooooo0_l0000L
ooooo`03o`000?oooooooooo02Oooooo0_l0002@ooooo`00P?ooool2o`0001Gooooo0_l0000Coooo
o`?o00007_ooool2o`0000Oooooo0_l0002@ooooo`00P?ooool2o`0001Gooooo0_l0000Cooooo`03
o`000?oooooooooo01kooooo0_l0002Iooooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool0
8Oooool2o`0009Kooooo002/ooooo`03o`000?oooooooooo00Gooooo0_l0000Jooooo`;o0000U_oo
ool0083ooooo0_l0000Zooooo`03o`000?oooooooooo00Gooooo0_l0002booooo`00Ooooool3o`00
02[ooooo00?o0000ooooooooool0^Oooool007oooooo0_l0000=ooooo`;o00007?ooool00ol0003o
ooooooooo`2iooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool09oooool2o`00093ooooo
002/ooooo`?o00001oooool2o`0001Sooooo0_l00004ooooo`?o0000Soooool0083ooooo0_l0000:
ooooo`;o00007_ooool00ol0003oooooooooo`07ooooo`;o00006?ooool2o`0000?ooooo1?l0002?
ooooo`00P?ooool2o`0000[ooooo0_l0000Nooooo`03o`000?oooooooooo02Kooooo0_l0002Aoooo
o`00P?ooool2o`0002[ooooo00?o0000ooooooooool0^Oooool0083ooooo0_l0000Eooooo`;o0000
4oooool00ol0003oooooooooo`07ooooo`;o00006Oooool2o`0000;ooooo0_l0002Aooooo`00O_oo
ool2o`0000kooooo0_l00007ooooo`;o00004oooool00ol0003oooooooooo`07ooooo`;o00006Ooo
ool2o`0000;ooooo0_l0002Aooooo`00O_ooool2o`0000kooooo0_l0000Looooo`03o`000?oooooo
oooo02Sooooo0_l0002?ooooo`00U_ooool2o`0001Cooooo00?o0000ooooooooool08Oooool2o`00
00Gooooo0_l0002?ooooo`00U_ooool2o`0001Cooooo00?o0000ooooooooool08Oooool3o`0009Go
oooo002/ooooo`?o00008_ooool2o`0009Gooooo002/ooooo`03o`000?oooooooooo02;ooooo0_l0
00000ooooooo0000o`00002Booooo`00S_ooool2o`0001cooooo0_l0000Vooooo`?o000000?ooooo
o`000?l00000S_ooool000Wooooo1?l000000ol@413oooooooooo`0Fooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`00
0005ooooool0003o0000oooooom4A4@00_l000000olb<S;ogMgMooooo`0Eooooo`;o00006Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B42ooooo`Oo00001?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool0
0ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd06?ooool4o`000003oa0@4?oo
oooooooo01;ooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00KoV9RHob4Q8Oo^k^koooooodA4A?ooool2
o`0000Cooooo00CoMgMgoc8b<_l0003o00005?ooool00ol0003oooooooooo`0Hooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@?ooooo1?l000000oooooooA4A4ooooo`06ooooo`03ogMg
Molb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo
<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVY
ZOooool01oooool00omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo0006o`0000Go
oooo00?o0000ooooooooool04?ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=oooo
o`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool01Oooool6o`0000;ooooo00Go410@oooo
oooooooooooooa0@400@ooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP02ooooo`;o00001Oooool3o`0001Cooooo00?o
0000ooooooooool06?ooool01Ol@413ooooooooooooooooo410@00Sooooo1_l000000oo^k^kooooo
ooooo`07ooooo`03o`000?oooooooooo00gooooo00Go410@oooooooooooooooooa0@400@ooooo`03
o`000?oooooooooo00gooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo
00Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003o
ooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06oooo
o`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo00kooooo00Go0000ooooooooooooooooo`00000=ooooo`04oiRHV?lQ8B7ok^k^ooooo`;o0000
1?ooool00omgMgOo0000o`00000Eooooo`03o`000?oooooooooo01Sooooo00Go0000oooooooooooo
ooooo`000008ooooo`;o00000oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool06Oooool0
0ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05o`000?oooooooooo
ooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03ooo
ool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05
o`000?ooooooooooooooool000003_ooool00omgMgOo0000o`000002o`000006ooooool0003o8B4Q
o`000?lb<S;oc<c<5_ooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool00000
2?ooool2o`0000Cooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oo
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<01[ooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?oo
ool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003ooooo
ooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0Aooooo`05
oa0@4?ooooooooooooooool@41003oooool4o`000003ooooool0003ooooo01Wooooo0ol0000:oooo
o`Co00002_ooool01Ol@413ooooooooooooooooo410@00oooooo0_l00003ooooo`03o`000?oooooo
oooo017ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo017ooooo00Go
410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000oooooooo
ool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00;o00002Oooool01_l0003o^[ZjoooooonHV9So410@ooooo`;o0000
00?oooooo`000?ooool06Oooool00ol0003oooooooooo`0:ooooo`Co00002_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Co0000okZj^_ooooooV9RH0_l00003ooooo`03o`000?oooooooooo
017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo01Cooooo0009ooooo`03oeEEEOmVIVKo000001[ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;o00002Oooool01_nH
V9So410@o`000?lQ8B7oc<c<ooooo`;o000000?oooooo`000?l000000_l0000Gooooo`03o`000?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`01?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00004?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00006Oooool00omEEEGoIVIVo`00000F
ooooo`00Ooooool2o`0000gooooo0_l00006ooooo`;o00005?ooool00ol0003oooooooooo`0]oooo
o`Co0000R?ooool007oooooo0_l0000Eooooo`;o00005?ooool00ol0003oooooooooo`0;ooooo`;o
00006Oooool2o`000003ooooool0003o000000;ooooo1?l00028ooooo`00O_ooool2o`0002cooooo
00?o0000ooooooooool02oooool2o`0001Wooooo0_l000000ooooooo0000o`000023ooooo`;o0000
0_ooool2o`0000Gooooo001nooooo`;o0000;?ooool00ol0003oooooooooo`0;ooooo`;o00008Ooo
ool2o`0007kooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd5ooooo`00[?ooool00ol0003ooooo
ooooo`0;ooooo`?o00008?ooool2o`0007oooooo00CogMgMo`000?l@413oc<c<1_ooool000Oooooo
ool0001<o`0000cooooo00Cok^k^ob4Q8Ol@413ok^k^1_ooool000Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
0_l000001?oooooo0000o`000?l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0:ooooo`04ob4Q8OmgMgOoMgMgoc8b<PKooooo0007ooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool02Oooool2o`000003ooooool0003o000001Wo
oooo0_l0000Wooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`09ooooo`;o00000_ooool2o`0000Gooooo002/ooooo`03o`000?oooooooooo00Wooooo
0_l000000ooooooo0000o`00000Iooooo`;o0000T?ooool009Oooooo0_l0000Cooooo`03o`000?oo
oooooooo0;Wooooo002Gooooo`;o00004oooool00ol0003oooooooooo`0=ooooo`;o0000Z_ooool0
08gooooo0_l00007ooooo`;o00005?ooool00ol0003oooooooooo`0=ooooo`;o00006oooool2o`00
08gooooo002=ooooo`;o00001oooool2o`0001Cooooo00?o0000ooooooooool03?ooool2o`0001So
oooo0_l00002ooooo`;o0000SOooool009Kooooo0_l0000Dooooo`?o00002oooool3o`0001Sooooo
0_l00002ooooo`Co0000Roooool007oooooo0_l0000Eooooo`;o00005?ooool3o`0000_ooooo0_l0
000Iooooo`;o00000_ooool8o`0008Oooooo001oooooo`;o0000:oooool3o`0002kooooo1?l00027
ooooo`00Ooooool2o`0002_ooooo00?o0000ooooooooool0;_ooool2o`0008Wooooo001nooooo`?o
00003_ooool2o`0001_ooooo00?o0000ooooooooool0;_ooool4o`0008Oooooo001nooooo`;o0000
3_ooool3o`0001_ooooo00?o0000ooooooooool09oooool2o`0000Oooooo0_l00027ooooo`00S_oo
ool2o`0001cooooo00?o0000ooooooooool09oooool2o`000003ooooool0003o000008gooooo002/
ooooo`03o`000?oooooooooo02[ooooo0_l0002=ooooo`00[?ooool00ol0003oooooooooo`09oooo
o`;o0000[_ooool00:cooooo0ol00009ooooo`;o0000[_ooool008kooooo0_l0000Looooo`03o`00
0?oooooooooo0;Wooooo002>ooooo`;o00007?ooool00ol0003oooooooooo`0:ooooo`;o00007?oo
ool2o`0000Gooooo0_l00028ooooo`00[?ooool00ol0003oooooooooo`0:ooooo`;o00007?ooool4
o`0000?ooooo0_l00028ooooo`00[?ooool00ol0003oooooooooo`0<ooooo`;o00006_ooool7o`00
08[ooooo002=ooooo`?o00007?ooool00ol0003oooooooooo`0<ooooo`;o00006_ooool2o`000003
ooooool0003o000000?o0000ROooool008gooooo0ol0000Looooo`03o`000?oooooooooo00_ooooo
0_l0000Qooooo`;o0000ROooool00:cooooo00?o0000ooooooooool02oooool2o`000:cooooo002?
ooooo`;o00006oooool3o`0002_ooooo0_l0002<ooooo`00Soooool2o`0000Oooooo0_l0000Boooo
o`03o`000?oooooooooo00cooooo0_l0000Mooooo`;o0000S?ooool008gooooo0_l00009ooooo`;o
00004_ooool00ol0003oooooooooo`0<ooooo`;o00006oooool3o`0000;ooooo0_l00029ooooo`00
SOooool3o`0000Sooooo0_l0000Booooo`03o`000?oooooooooo02Wooooo0ol00002ooooo`;o0000
ROooool008kooooo1?l00006ooooo`;o00004_ooool00ol0003oooooooooo`0:ooooo`;o00007_oo
ool2o`0008gooooo002@ooooo`;o00006_ooool00ol0003oooooooooo`0:ooooo`;o00007_ooool2
o`0008gooooo0021ooooo`;o0000:Oooool00ol0003oooooooooo`0Zooooo`;o0000SOooool007ko
oooo0_l000000ooooooo0000o`00000Xooooo`;o00002oooool2o`0002Gooooo0_l00027ooooo`00
O_ooool2o`0000kooooo0_l0000Kooooo`Co00002Oooool2o`0002Gooooo0_l00027ooooo`00S_oo
ool4o`0001[ooooo00?o0000ooooooooool0:_ooool2o`0008gooooo002@ooooo`;o00006_ooool0
0ol0003oooooooooo`0Zooooo`;o0000SOooool0093ooooo0_l0000Jooooo`03o`000?oooooooooo
02Kooooo0_l000000ooooooo0000o`00002>ooooo`00Soooool3o`0001[ooooo00?o0000oooooooo
ool09_ooool2o`000003ooooool0003o000008kooooo002?ooooo`;o00006oooool00ol0003ooooo
ooooo`0`ooooo`;o0000Qoooool0087ooooo0_l00006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0_ooool2o`000003oooooolQ8B7o8B4Q00Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01Oooool00ol0003oooooooooo`0`ooooo`;o0000Qoooool0087ooooo0_l00006ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00_ooool2o`000003oooooolQ8B7o8B4Q00Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0:?ooool2o`00
00Cooooo1?l00027ooooo`00ROooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q
8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o00002?ooool2o`0001kooooo0_l00004oooo
o`;o0000ROooool008Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^
00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`08ooooo`;o00008oooool2o`00
08[ooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0]ooooo`;o0000R_ooool0
08Wooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool2o`0000;ooooo00?o0000ooooooooool09_ooool3o`0000Gooooo0ol00028
ooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@
4004ooooo`03o`000?oooooooooo00?ooooo0_l00002ooooo`03o`000?oooooooooo02Kooooo0ol0
00000ooooooo0000o`000002ooooo`?o0000R?ooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`000003ooooool0003o000000?ooooo
00?o0000ooooooooool0:_ooool2o`0008gooooo002Looooo`?o00002?ooool2o`0000?ooooo00?o
0000ooooooooool01Oooool4o`0001gooooo0_l0002Aooooo`00W?ooool3o`0000gooooo00?o0000
ooooooooool01Oooool4o`0001gooooo0_l0002Aooooo`00[?ooool00ol0003oooooooooo`09oooo
o`;o00008_ooool2o`0008[ooooo002/ooooo`?o00002Oooool2o`0002;ooooo0_l0002:ooooo`00
[?ooool00ol0003oooooooooo`0Wooooo`;o00000oooool2o`0008_ooooo002Uooooo`;o00001Ooo
ool00ol0003oooooooooo`0Wooooo`;o00000oooool2o`0008_ooooo002Aooooo`;o00004_ooool2
o`0000Gooooo00?o0000ooooooooool0^Oooool0087ooooo0_l0000>ooooo`;o00006Oooool00ol0
003oooooooooo`2iooooo`00POooool2o`0002Wooooo00?o0000ooooooooool0:?ooool2o`0008oo
oooo002/ooooo`03o`000?oooooooooo02Sooooo0_l0002?ooooo`00POooool2o`0002Wooooo00?o
0000ooooooooool0^Oooool0087ooooo0_l0000Yooooo`?o00001_ooool2o`0002Gooooo0_l0002:
ooooo`00Toooool2o`0001Oooooo00?o0000ooooooooool01_ooool2o`0001_ooooo0ol00007oooo
o`;o0000R_ooool009?ooooo0_l0000Gooooo`03o`000?oooooooooo02?ooooo0ol0002Cooooo`00
Toooool2o`0001Oooooo00?o0000ooooooooool0^Oooool009?ooooo0_l0000Gooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo02Wooooo0_l0002>ooooo`00UOooool2o`00
01Gooooo00?o0000ooooooooool00oooool2o`0002Cooooo0_l0002>ooooo`00UOooool2o`0001Go
oooo00Co0000oooooooooooooooo1?l0000Tooooo`;o0000S_ooool009?ooooo0_l0000Gooooo`?o
000000?oooooo`000?l000008Oooool2o`0009?ooooo002Cooooo`;o00005oooool00ol0003ooooo
ooooo`0Tooooo`;o000000?oooooo`000?l00000T?ooool009Cooooo0ol0000Eooooo`03o`000?oo
oooooooo027ooooo0_l00004ooooo`;o0000T?ooool008Cooooo0_l0000>ooooo`Co00005?ooool0
0ol0003oooooooooo`0Qooooo`;o00000_ooool2o`0009;ooooo0021ooooo`;o000000?oooooo`00
0?l000004?ooool2o`0001Cooooo0ol0000Rooooo`;o000000?oooooo`000?l000000oooool2o`00
08gooooo0021ooooo`;o0000:Oooool3o`0000;ooooo0_l0000Nooooo`;o000000?oooooo`000?l0
00000oooool2o`0008gooooo002/ooooo`03o`000?oooooooooo00;ooooo0_l0000Qooooo`;o0000
T_ooool00:cooooo00?o0000ooooooooool08_ooool2o`0009Gooooo002/ooooo`?o00008_ooool2
o`0000;ooooo0_l0002Aooooo`00UOooool2o`0001Gooooo0ol0000Vooooo`;o0000TOooool008;o
oooo0ol0000@ooooo`;o00005Oooool3o`0001gooooo0_l00009ooooo`;o0000Soooool008;ooooo
0ol0000Uooooo`?o00007oooool2o`0000Wooooo0_l0002?ooooo`00Uoooool2o`00017ooooo1Ol0
000Uooooo`;o0000T_ooool008Cooooo0_l0000Aooooo`;o00004oooool3o`0002Gooooo0_l0002B
ooooo`00Q?ooool2o`0000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool08oooool4o`000003ooooool0
003o000008oooooo002Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0000Sooooo00?o
MgMgoc8b<_ooool01?ooool3o`0002?ooooo0_l00003ooooo`;o0000Soooool0097ooooo00Go410@
oooooooooooooooooa0@4005ooooo`Co00001oooool00ol0003oooooooooo`03ooooo`?o00008Ooo
ool3o`0000;ooooo1?l0002?ooooo`00Poooool2o`0000cooooo00Go0000ooooooooooooooooo`00
0007ooooo`;o00001_ooool00omgMgOo<S8booooo`04ooooo`?o00007?ooool2o`0000?ooooo0ol0
0002ooooo`;o0000TOooool008?ooooo0_l0000<ooooo`05o`000?ooooooooooooooool000001Ooo
ool2o`0000Gooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo01_ooooo
0ol0002Kooooo`00TOooool01Ol@413ooooooooooooooooo410@00Gooooo0_l00003ooooo`Go0000
1oooool00ol0003oooooooooo`0Kooooo`;o0000W?ooool008?ooooo0ol0000;ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02_ooool5o`0000Oooooo00?o0000ooooooooool0^Oooool008?ooooo1?l0
000:ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0
^Oooool008Gooooo0_l0000Hooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0^Ooo
ool009oooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0Tooooo`;o0000Toooool0
09oooooo0_l000000ooooooo0000o`000008ooooo`03o`000?oooooooooo027ooooo0_l000000ooo
oooo0000o`00002Cooooo`00Woooool2o`000003ooooool0003o000000?ooooo0_l00003ooooo`?o
00008Oooool2o`0009Kooooo0024ooooo`;o00008Oooool2o`0000?ooooo00?o0000ooooooooool0
^Oooool008Cooooo0_l00002ooooo`;o00005Oooool2o`0000Gooooo0_l00004ooooo`03o`000?oo
oooooooo01Oooooo0_l0002Pooooo`00R?ooool2o`0001Gooooo0_l00004ooooo`?o00001?ooool0
0ol0003oooooooooo`0Gooooo`;o0000X?ooool008Gooooo0_l0000Nooooo`;o00001Oooool00ol0
003oooooooooo`0Pooooo`;o0000Uoooool008Gooooo0_l0000Iooooo`;o00002_ooool00ol0003o
ooooooooo`0Pooooo`;o0000Uoooool00:3ooooo0_l0000:ooooo`03o`000?oooooooooo023ooooo
0_l0002Gooooo`00[?ooool00ol0003oooooooooo`0Pooooo`;o0000Uoooool00:cooooo0ol0002i
ooooo`00[?ooool00ol0003oooooooooo`0Eooooo`;o00001?ooool3o`0009_ooooo002/ooooo`03
o`000?oooooooooo01Gooooo0_l00004ooooo`?o0000Voooool00:cooooo00?o0000ooooooooool0
5Oooool2o`0000?ooooo1?l0002Kooooo`00R?ooool2o`0002;ooooo00?o0000ooooooooool05Ooo
ool2o`0000?ooooo0_l0002Mooooo`00R?ooool2o`0002;ooooo00?o0000ooooooooool06_ooool2
o`0009gooooo0028ooooo`;o00008_ooool00ol0003oooooooooo`0Jooooo`Go0000V_ooool00:co
oooo00?o0000ooooooooool06_ooool5o`0009[ooooo002/ooooo`?o00005_ooool2o`0000;ooooo
0_l0002Mooooo`00ROooool2o`00027ooooo00?o0000ooooooooool05_ooool2o`000:7ooooo0029
ooooo`;o00008Oooool00ol0003oooooooooo`0Hooooo`;o0000Woooool00:cooooo00?o0000oooo
ooooool04Oooool2o`0000?ooooo1?l0002Oooooo`00[?ooool00ol0003oooooooooo`0?ooooo`Co
00000oooool2o`000003ooooool0003o000009kooooo0028ooooo`;o00008_ooool00ol0003ooooo
ooooo`0?ooooo`?o00001oooool2o`0009kooooo0028ooooo`;o00008_ooool00ol0003ooooooooo
o`0@ooooo`;o00001?ooool2o`000:7ooooo0028ooooo`;o00008_ooool00ol0003oooooooooo`0@
ooooo`;o00001?ooool2o`000:7ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o
0000^Oooool008_ooooo0_l0000Oooooo`03o`000?oooooooooo0;Wooooo002:ooooo`?o00007ooo
ool00ol0003oooooooooo`0<ooooo`Ko00000oooool3o`000:7ooooo002:ooooo`;o00008?ooool0
0ol0003oooooooooo`0;ooooo`Oo00000oooool3o`000:7ooooo002/ooooo`03o`000?oooooooooo
00[ooooo0ol00004ooooo`;o0000Y_ooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`0:ooooo`Co00000oooool2o`000:Kooooo0029ooooo`03ogMgMonHV9So0000
00?o00001?ooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo00Wooooo0_l000000ooooooo0000o`00002[ooooo`00ROooool00ol@413o
ooooo`000003o`0000cooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Wooooo0_l000000ooooooo0000o`000002ooooo`;o0000Yoooool008Wooooo
00?o0000ooooooooool00_l000000ooooooo0000o`00000;ooooo`03ob4Q8Ooooooooooo00Kooooo
00?oMgMgoc8b<_ooool01?ooool3o`00013ooooo0_l0002Wooooo`00ROooool00ol0003ooooooooo
o`02o`000003ooooool0003o000000_ooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool04_ooool2o`000:Gooooo0029ooooo`05oa0@4?oo
ooooooooooooool@41000_l0000<ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0>ooooo`;o00000_ooool2o`000:Gooooo0029ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00_l00009ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Oooooo0_l00005ooooo`;o0000ZOooool008Wooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP02o`0000Wooooo1Ol00004ooooo`Co00001_ooool00ol0003o
ooooooooo`07ooooo`;o0000/?ooool008kooooo0_l0000Looooo`03o`000?oooooooooo00Oooooo
0_l00003ooooo`;o0000Zoooool008gooooo0_l0000Mooooo`03o`000?oooooooooo00cooooo1?l0
002Yooooo`00SOooool2o`0001gooooo00?o0000ooooooooool01_ooool2o`0000Kooooo0_l0002Y
ooooo`00SOooool2o`0001gooooo0ol00006ooooo`;o0000/Oooool008gooooo0ol00002ooooo`;o
00006?ooool00ol0003oooooooooo`2iooooo`00S_ooool2o`0000;ooooo0_l0000Hooooo`03o`00
0?oooooooooo00Gooooo0_l00003ooooo`;o0000[Oooool00:cooooo00?o0000ooooooooool01Ooo
ool2o`0000?ooooo0_l0002]ooooo`00UOooool2o`0001Gooooo00?o0000ooooooooool0^Oooool0
093ooooo0_l00003ooooo`;o00005Oooool00ol0003oooooooooo`02ooooo`;o0000]Oooool0093o
oooo0_l0000Jooooo`03o`000?oooooooooo00;ooooo0_l0002eooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00U?ooool2o`0001Kooooo0ol0002iooooo`00U?ooool2o`0001Kooooo00?o0000
ooooooooool0^Oooool0097ooooo0_l0000Iooooo`03o`000?oooooooooo0;Wooooo002Aooooo`;o
00006?ooool2o`000;_ooooo002Hooooo`Co00003oooool2o`0000;ooooo0_l0002gooooo`00T_oo
ool2o`0000Cooooo1Ol0000?ooooo`03o`000?oooooooooo00;o0000]oooool009;ooooo0_l00000
0ooooooo0000o`000004ooooo`Co00002_ooool6o`000;Wooooo002Eooooo`Co00001?ooool2o`00
00[ooooo2?l0002gooooo`00Uoooool2o`0001?ooooo00?o0000ooooool000000_l0002gooooo`00
Toooool2o`0001Oooooo1Ol0002gooooo`00Toooool2o`0000Oooooo0_l00005ooooo`;o00001ooo
ool3o`000;Wooooo002Gooooo`Co000000?oooooo`000?l000000oooool4o`000003ooooool0003o
000000Cooooo0ol0002iooooo`00U_ooool6o`0000Gooooo0_l00003ooooo`;o00001?ooool00ol0
003oooooooooo`2iooooo`00UOooool3o`0000;ooooo0_l000000ooooooo0000o`000006ooooo`;o
00001Oooool01?l0003oooooo`000?l0002hooooo`00UOooool2o`0000Kooooo0_l00006ooooo`;o
00001?ooool2o`000003ooooool0003o00000;Sooooo002Wooooo`;o00000_ooool2o`000;_ooooo
002Sooooo`;o00000_ooool2o`0000?ooooo00?o0000ooooooooool0^Oooool009Oooooo0_l00008
ooooo`Co000000Coooooo`000?l0003ooooo0_l000001?oooooo0000o`000?l0002iooooo`00Uooo
ool2o`0000?ooooo0_l00003ooooo`;o00000oooool2o`000003ooooool0003o000000;o0000^ooo
ool009cooooo0_l00005ooooo`;o00000_ooool2o`000004ooooool0003o0000o`000;_ooooo002M
ooooo`;o00001?ooool2o`0000;ooooo0ol00002ooooo`03o`000?oooooooooo0;Wooooo002Moooo
o`;o000000?oooooo`000?l000001?ooool4o`0000;ooooo00?o0000ooooooooool0^Oooool009go
oooo0_l000000ooooooo0000o`000004ooooo`Co00000_ooool00ol0003oooooooooo`2iooooo`00
X_ooool6o`0000Cooooo00?o0000ooooooooool0^Oooool00:;ooooo0ol00007ooooo`03o`000?oo
oooooooo0;Wooooo002Tooooo`03o`000?oooooooooo00Gooooo0ol0002iooooo`00Y?ooool00ol0
003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003ooooo
ooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00X_ooool00omEEEGoIVIVo`000033
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Z_ooool0
1?l@413o0000o`000?l0002jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0
003oooooooooo`2jooooo`00Zoooool01_l0003oMgMgo`000?l0003oEEEEonk^k[Oooooo002[oooo
o`06o`000?mEEEGok^k^oooooomgMgOoEEEE]oooool00:_ooooo00?o0000onk^k_ooool00_ooool0
0ol0003oooooooooo`2eooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo
0;Gooooo002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoIVIV]oooool00:[ooooo00?o410@o`00
0?mgMgL00_l000000omVIVKok^k^ooooo`2fooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.62695 .36277 Mdot
.64206 .38053 Mdot
.47834 .36469 Mdot
.55143 .4954 Mdot
.45589 .80535 Mdot
.57938 .26375 Mdot
.48594 .66647 Mdot
.64611 .78954 Mdot
.58024 .86149 Mdot
.5498 .62181 Mdot
.52719 .70398 Mdot
.58261 .88354 Mdot
.66261 .41608 Mdot
.55944 .5982 Mdot
.47596 .98683 Mdot
.55669 .52728 Mdot
.49854 .16244 Mdot
.66347 .41669 Mdot
.50765 .76856 Mdot
.6885 .54391 Mdot
.66678 .50871 Mdot
.65725 .46645 Mdot
.65453 .55141 Mdot
.66786 .44913 Mdot
.46586 .99244 Mdot
.41553 .7062 Mdot
.48145 .78485 Mdot
.47622 .79994 Mdot
.68317 .58761 Mdot
.65064 .43625 Mdot
.65508 .60165 Mdot
.61266 .81723 Mdot
.60379 .84509 Mdot
.55278 .24922 Mdot
.52929 .19203 Mdot
.65153 .66508 Mdot
.64038 .74224 Mdot
.47064 .79379 Mdot
.64911 .6976 Mdot
.61036 .85088 Mdot
.53592 .94721 Mdot
.53347 .20485 Mdot
.56964 .25732 Mdot
.60847 .29503 Mdot
.59952 .28434 Mdot
.43972 .78532 Mdot
.52535 .7006 Mdot
.64692 .75339 Mdot
.39798 .46781 Mdot
.66186 .65741 Mdot
.63597 .77147 Mdot
.66814 .66211 Mdot
.38432 .1395 Mdot
.57086 .26749 Mdot
.53311 .19094 Mdot
.58391 .86366 Mdot
.6293 .81612 Mdot
.47015 .14539 Mdot
.64592 .74462 Mdot
.59486 .27599 Mdot
.419 .70875 Mdot
.4435 .9927 Mdot
.63252 .73332 Mdot
.49928 .28722 Mdot
.5237 .9396 Mdot
.6133 .82035 Mdot
.54268 .64409 Mdot
.54755 .58566 Mdot
.50331 .76959 Mdot
.67058 .48967 Mdot
.4206 .23184 Mdot
.48046 .68556 Mdot
.53174 .67864 Mdot
.55124 .60329 Mdot
.63209 .7341 Mdot
.50609 .4463 Mdot
.3851 .13566 Mdot
.40757 .37878 Mdot
.67308 .64276 Mdot
.46154 .16965 Mdot
.65372 .63293 Mdot
.65124 .45414 Mdot
.54941 .51344 Mdot
.52392 .18692 Mdot
.64323 .78698 Mdot
.55729 .44782 Mdot
.45491 .80509 Mdot
.40783 .60045 Mdot
.43555 .19184 Mdot
.54438 .60228 Mdot
.44587 .97599 Mdot
.35744 .44549 Mdot
.50992 .30511 Mdot
.43469 .76735 Mdot
.51462 .32187 Mdot
.3618 .65215 Mdot
.55879 .5992 Mdot
.59709 .83135 Mdot
.38444 .13683 Mdot
.40957 .2935 Mdot
.63468 .3903 Mdot
.40907 .30418 Mdot
.54983 .92122 Mdot
.62079 .32603 Mdot
.67024 .54861 Mdot
.55481 .25116 Mdot
.45178 .1535 Mdot
.5069 .77347 Mdot
.50911 .30263 Mdot
.66959 .51563 Mdot
.5591 .59074 Mdot
.54879 .4418 Mdot
.60593 .82615 Mdot
.67958 .57189 Mdot
.42965 .55808 Mdot
.40495 .59119 Mdot
.65174 .76384 Mdot
.64256 .77546 Mdot
.60388 .80186 Mdot
.6644 .43439 Mdot
.65375 .58277 Mdot
.68731 .57074 Mdot
.67048 .50237 Mdot
.55065 .53474 Mdot
.67433 .60307 Mdot
.36879 .72549 Mdot
.64755 .48 Mdot
.45488 .30614 Mdot
.65926 .50015 Mdot
.64171 .42157 Mdot
.55482 .91929 Mdot
.562 .22522 Mdot
.57462 .2631 Mdot
.68496 .59517 Mdot
.67694 .65777 Mdot
.67672 .60531 Mdot
.52846 .68624 Mdot
.57037 .89052 Mdot
.49518 .98029 Mdot
.37054 .71335 Mdot
.53219 .36469 Mdot
.51337 .75425 Mdot
.49285 .15502 Mdot
.68567 .54921 Mdot
.64652 .77818 Mdot
.42378 .69592 Mdot
.40836 .61302 Mdot
.55622 .94034 Mdot
.40149 .36938 Mdot
.53073 .70977 Mdot
.6671 .43296 Mdot
.48778 .6771 Mdot
.61528 .35622 Mdot
.66158 .69021 Mdot
.64793 .70446 Mdot
.63232 .79525 Mdot
.62792 .76455 Mdot
.66563 .68197 Mdot
.40351 .61794 Mdot
.68076 .61833 Mdot
.61632 .85297 Mdot
.64628 .67018 Mdot
.59483 .32397 Mdot
.63958 .43225 Mdot
.64099 .78591 Mdot
.67294 .54227 Mdot
.50131 .77201 Mdot
.68188 .63673 Mdot
.64728 .68748 Mdot
.54281 .44361 Mdot
.48374 .78956 Mdot
.42218 .70872 Mdot
.4382 .75672 Mdot
.56706 .89184 Mdot
.36232 .65573 Mdot
.61632 .36268 Mdot
.43561 .3936 Mdot
.67157 .63367 Mdot
.68535 .61737 Mdot
.59036 .8797 Mdot
.5599 .53551 Mdot
.53438 .94994 Mdot
.46926 .28136 Mdot
.55888 .88692 Mdot
.36216 .64203 Mdot
.64444 .76675 Mdot
.61036 .85941 Mdot
.56164 .23729 Mdot
.49778 .99785 Mdot
.68677 .54137 Mdot
.50046 .29543 Mdot
.41991 .94551 Mdot
.63989 .79549 Mdot
.55985 .92698 Mdot
.55537 .91661 Mdot
.43026 .75038 Mdot
.35613 .55741 Mdot
.44627 .15675 Mdot
.43256 .43351 Mdot
.43281 .42831 Mdot
.47582 .68828 Mdot
.42706 .72884 Mdot
.35528 .47737 Mdot
.64162 .43428 Mdot
.49949 .30205 Mdot
.5915 .28939 Mdot
.53862 .37876 Mdot
.44806 .30783 Mdot
.53907 .67622 Mdot
.65602 .39802 Mdot
.40431 .42483 Mdot
.67245 .54698 Mdot
.5525 .57952 Mdot
.64101 .44244 Mdot
.40627 .40174 Mdot
.60615 .86656 Mdot
.44303 .32809 Mdot
.61616 .34294 Mdot
.62583 .82741 Mdot
.40808 .62984 Mdot
.61193 .80263 Mdot
.6739 .52385 Mdot
.64578 .66203 Mdot
.54085 .62391 Mdot
.45756 .80246 Mdot
.62742 .32756 Mdot
.53574 .39562 Mdot
.47926 .98693 Mdot
.50742 .99325 Mdot
.55609 .49257 Mdot
.51075 .56175 Mdot
.36624 .28027 Mdot
.4334 .20844 Mdot
.51212 .74215 Mdot
.48258 .79176 Mdot
.62274 .32813 Mdot
.66256 .52199 Mdot
.63931 .40891 Mdot
.42907 .96851 Mdot
.55725 .22261 Mdot
.67693 .53628 Mdot
.42086 .23096 Mdot
.63585 .78256 Mdot
.52488 .35866 Mdot
.63465 .74359 Mdot
.50381 .17756 Mdot
.4183 .24201 Mdot
.64239 .71414 Mdot
.54886 .93784 Mdot
.42916 .54661 Mdot
.5179 .34725 Mdot
.62103 .7706 Mdot
.40052 .52505 Mdot
.47988 .79027 Mdot
.50408 .14228 Mdot
.50743 .45545 Mdot
.60959 .84203 Mdot
.64884 .7451 Mdot
.40624 .34068 Mdot
.51362 .73906 Mdot
.64792 .65977 Mdot
.43912 .3621 Mdot
.41444 .27638 Mdot
.62927 .38242 Mdot
.5073 .74097 Mdot
.6042 .33904 Mdot
.64556 .68529 Mdot
.40792 .35176 Mdot
.6671 .62278 Mdot
.52687 .17878 Mdot
.55835 .5843 Mdot
.42984 .22539 Mdot
.6683 .67307 Mdot
.56201 .51544 Mdot
.50446 .78377 Mdot
.62838 .7859 Mdot
.55239 .63535 Mdot
.60399 .31963 Mdot
.67464 .6289 Mdot
.42703 .45268 Mdot
.54045 .63814 Mdot
.61988 .77798 Mdot
.56691 .90015 Mdot
.51099 .76696 Mdot
.4887 .67093 Mdot
.40959 .59131 Mdot
.68329 .53155 Mdot
.41274 .66023 Mdot
.65095 .6366 Mdot
.35983 .59394 Mdot
.62901 .77245 Mdot
.50452 .9684 Mdot
.60313 .81333 Mdot
.51101 .57732 Mdot
.66289 .70624 Mdot
.39856 .8723 Mdot
.68274 .51177 Mdot
.48218 .98527 Mdot
.41083 .31543 Mdot
.51652 .15678 Mdot
.63993 .40336 Mdot
.62615 .79764 Mdot
.50624 .97637 Mdot
.5313 .68835 Mdot
.61646 .80385 Mdot
.40036 .53301 Mdot
.43098 .48532 Mdot
.65951 .42821 Mdot
.49574 .15707 Mdot
.66478 .454 Mdot
.55396 .94112 Mdot
.42831 .47229 Mdot
.62189 .36002 Mdot
.54779 .23515 Mdot
.51867 .94663 Mdot
.42964 .4311 Mdot
.57819 .89498 Mdot
.42556 .94979 Mdot
.39357 .86979 Mdot
.55281 .53303 Mdot
.5478 .1982 Mdot
.51097 .16517 Mdot
.62938 .74339 Mdot
.48439 .81213 Mdot
.43378 .58499 Mdot
.49974 .63209 Mdot
.45549 .15072 Mdot
.63431 .81232 Mdot
.60586 .79426 Mdot
.50587 .29801 Mdot
.65687 .42119 Mdot
.44734 .32329 Mdot
.47172 .68757 Mdot
.6303 .33589 Mdot
.56932 .24335 Mdot
.59424 .3218 Mdot
.40196 .59573 Mdot
.42454 .71574 Mdot
.36411 .28103 Mdot
.40422 .39641 Mdot
.65029 .47995 Mdot
.51296 .32406 Mdot
.58549 .86562 Mdot
.47986 .78415 Mdot
.67428 .61133 Mdot
.6533 .50732 Mdot
.51571 .3154 Mdot
.40719 .40073 Mdot
.37513 .75413 Mdot
.59865 .86306 Mdot
.67533 .67727 Mdot
.65559 .65676 Mdot
.4004 .42687 Mdot
.47468 .13639 Mdot
.65421 .66868 Mdot
.42116 .24768 Mdot
.59412 .86867 Mdot
.42405 .96984 Mdot
.67735 .53783 Mdot
.54841 .92596 Mdot
.5734 .90133 Mdot
.57423 .90636 Mdot
.46215 .68194 Mdot
.42761 .2285 Mdot
.48372 .98667 Mdot
.62156 .82611 Mdot
.46073 .68088 Mdot
.65718 .60817 Mdot
.42564 .25445 Mdot
.57924 .25888 Mdot
.63301 .38481 Mdot
.59061 .84213 Mdot
.62442 .33446 Mdot
.64527 .73713 Mdot
.60799 .78636 Mdot
.65338 .55417 Mdot
.68146 .65729 Mdot
.65788 .51256 Mdot
.47963 .99231 Mdot
.5932 .82054 Mdot
.60725 .32422 Mdot
.46914 .68045 Mdot
.45732 .99365 Mdot
.4186 .24915 Mdot
.50096 .62642 Mdot
.60222 .86592 Mdot
.67084 .49308 Mdot
.4394 .62686 Mdot
.54767 .62113 Mdot
.40774 .64084 Mdot
.50486 .75757 Mdot
.65092 .74819 Mdot
.67707 .47536 Mdot
.40629 .90392 Mdot
.58948 .88147 Mdot
.51477 .18245 Mdot
.37854 .17734 Mdot
.49828 .15446 Mdot
.44759 .77945 Mdot
.46606 .80652 Mdot
.51298 .48562 Mdot
.62443 .82533 Mdot
.58081 .88526 Mdot
.48478 .78278 Mdot
.53169 .37098 Mdot
.55674 .63182 Mdot
.56023 .477 Mdot
.54508 .94706 Mdot
.45512 .81069 Mdot
.65613 .64231 Mdot
.54426 .42472 Mdot
.52241 .72831 Mdot
.43707 .37005 Mdot
.4508 .80157 Mdot
.5498 .24502 Mdot
.53199 .70308 Mdot
.50171 .30644 Mdot
.52036 .97822 Mdot
.57688 .88235 Mdot
.46021 .39467 Mdot
.53043 .1924 Mdot
.45379 .15105 Mdot
.62777 .4088 Mdot
.43065 .23459 Mdot
.49768 .7763 Mdot
.36849 .73734 Mdot
.63353 .36497 Mdot
.60569 .28468 Mdot
.49088 .28034 Mdot
.54241 .90918 Mdot
.47323 .98831 Mdot
.51015 .74131 Mdot
.65144 .53077 Mdot
.36961 .2321 Mdot
.53621 .38928 Mdot
.4414 .63333 Mdot
.42569 .71131 Mdot
.65485 .63884 Mdot
.4389 .2059 Mdot
.35606 .50647 Mdot
.4644 .28216 Mdot
.56941 .26893 Mdot
.51129 .16801 Mdot
.4961 .27681 Mdot
.4332 .40747 Mdot
.56068 .54446 Mdot
.64156 .79677 Mdot
.42729 .51313 Mdot
.67873 .6212 Mdot
.63688 .36519 Mdot
.61321 .32449 Mdot
.67203 .60821 Mdot
.6494 .636 Mdot
.49844 .15858 Mdot
.39401 .88443 Mdot
.5486 .61939 Mdot
.63491 .8121 Mdot
.56179 .92372 Mdot
.49606 .76179 Mdot
.66889 .69293 Mdot
.41882 .28163 Mdot
.52 .20031 Mdot
.67624 .60288 Mdot
.63206 .37609 Mdot
.49368 .79219 Mdot
.40576 .42056 Mdot
.54017 .22386 Mdot
.59132 .30645 Mdot
.49888 .39802 Mdot
.58143 .28814 Mdot
.44829 .1845 Mdot
.47701 .69157 Mdot
.54691 .58089 Mdot
.5646 .25426 Mdot
.55658 .22603 Mdot
.42887 .49988 Mdot
.40096 .48284 Mdot
.6115 .82333 Mdot
.47404 .81771 Mdot
.62806 .38257 Mdot
.53711 .70367 Mdot
.4404 .75356 Mdot
.45312 .66826 Mdot
.44493 .64068 Mdot
.63668 .35825 Mdot
.58201 .8457 Mdot
.65108 .65877 Mdot
.5012 .77452 Mdot
.67491 .61657 Mdot
.58771 .88094 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0^Oooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1Oooool00ol0003oooooooooo`2iooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`2iooooo`00POooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVY
ZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000;Wooooo0029ooooo`05o`000?oo
ooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0^Oooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEE
EOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;Wo
oooo0029ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0^Oooool008Gooooo0ol000001_ooooooMgMg
oiRHV?ooooooV9RHogMgM`_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`?o00001oooool0
0ol0003oooooooooo`2iooooo`00QOooool3o`000006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2ooo
ool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo0;Wooooo0025ooooo`;o00009Oooool3
o`000;Wooooo002Rooooo`;o00002?ooool3o`000;Wooooo002Rooooo`;o00002?ooool00ol0003o
ooooooooo`2iooooo`00W?ooool3o`0000gooooo0ol0002iooooo`00W?ooool3o`0000[ooooo1?l0
002kooooo`00V_ooool4o`0000_ooooo1?l00004ooooo`;o0000]Oooool009[ooooo0_l0000>oooo
o`?o00001?ooool2o`000;Gooooo002[ooooo`;o00000_ooool2o`000;Oooooo002[ooooo`;o0000
0_ooool2o`000;Oooooo002Oooooo`;o00002oooool00ol0003oooooooooo`02o`000;Oooooo002O
ooooo`;o00002oooool00ol0003oooooooooo`2iooooo`00Poooool2o`0002Oooooo0ol0002ioooo
o`00Poooool2o`0002Oooooo0ol00005ooooo`;o0000/_ooool00:cooooo0ol000000ooooooo0000
o`000002ooooo`;o0000/_ooool009[ooooo0_l0000@ooooo`04o`000?ooooooooooooooo`;o0000
]_ooool009[ooooo0_l0000@ooooo`03o`000?oooooooooo00Cooooo0_l0002cooooo`00U_ooool2
o`0001Cooooo00?o0000ooooooooool01?ooool5o`000;3ooooo002Fooooo`;o00005?ooool00ol0
003oooooooooo`06ooooo`?o0000/?ooool00:cooooo00?o0000ooooooooool03?ooool2o`000:_o
oooo002/ooooo`?o00000oooool2o`0000Oooooo0_l0002[ooooo`00[?ooool00ol0003ooooooooo
o`03ooooo`;o0000]?ooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo00Sooooo0_l0002_
ooooo`00U_ooool3o`0001?ooooo00?o0000ooooooooool02?ooool2o`000:oooooo002Fooooo`;o
00005?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0?ooooo`;o0000Z?ooool0
09Cooooo0_l0000Fooooo`?o00002_ooool2o`0000?ooooo1?l0002Vooooo`00U?ooool2o`0001Ko
oooo00?o0000ooooooooool02_ooool2o`0000?ooooo1?l0002Vooooo`00TOooool2o`000003oooo
ool0003o000001Kooooo00?o0000ooooooooool03oooool2o`000:Sooooo0021ooooo`;o00003_oo
ool2o`0000;ooooo0_l0000Eooooo`03o`000?oooooooooo0;Wooooo0021ooooo`;o00004_ooool2
o`0001Gooooo00?o0000ooooooooool03?ooool2o`0000?ooooo0_l0002Vooooo`00[?ooool00ol0
003oooooooooo`0<ooooo`;o00000oooool2o`000:Kooooo002Aooooo`?o000000?o<S8bonk^k_oo
ool01?ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
01?ooooo0_l0002Tooooo`00TOooool2o`000003oooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool03Oooool2o`0000Cooooo0_l0002Tooooo`00
ROooool6o`0000;ooooo0ol000000ooooooo410@ooooo`0?ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool03Oooool3o`000:Wooooo002Aooooo`?o000000?oooooo`000?ooool03_oo
ool00omgMgOo<S8booooo`04ooooo`?o00003_ooool3o`000:Sooooo002Aooooo`03o`000?oooooo
000000;o00003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool03ooo
ool2o`000003ooooool0003o00000:Gooooo002Aooooo`05oa0@4?oooooo0000o`000?l@41003?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo1?l000000ooooooo0000o`00
002Pooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Dooooo`;o000000?oooooo`000?l00000X?ooool0097ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`0Eooooo`Co0000X?oo
ool00:cooooo00?o0000ooooooooool05?ooool5o`000:3ooooo002/ooooo`03o`000?oooooooooo
01?ooooo0ol0002Sooooo`00[?ooool00ol0003oooooooooo`0Cooooo`;o0000Y?ooool008oooooo
0_l0000Iooooo`Go00007?ooool2o`0009_ooooo001oooooo`;o00003_ooool2o`0001Sooooo1?l0
000Nooooo`;o0000Voooool007oooooo0_l0000@ooooo`;o00003Oooool3o`0000Kooooo0_l00000
0ooooooo0000ooooo`2jooooo`00Ooooool2o`00013ooooo0_l0000=ooooo`?o00002Oooool00ol0
003oooooooooo`0Mooooo`Co0000V?ooool00:_ooooo0_l0000Iooooo`;o00000_ooool6o`0009So
oooo002[ooooo`;o00006Oooool2o`0000;ooooo0_l0002Looooo`00S_ooool2o`0001cooooo0_l0
000Qooooo`;o0000Uoooool008kooooo0_l0000Looooo`Co00007oooool2o`0009Oooooo002/oooo
o`Co0000^?ooool008kooooo0_l0000Kooooo`;o00000_ooool2o`000;Oooooo002>ooooo`;o0000
3Oooool2o`0000cooooo0ol000000ooooooo0000o`00000Iooooo`;o0000W?ooool009[ooooo0_l0
00000ooooooo0000o`00000=ooooo`;o000000?oooooo`000?l000006Oooool2o`0009cooooo002J
ooooo`;o00004?ooool00ol0003oooooooooo`2iooooo`00S_ooool2o`0001cooooo00?o0000oooo
ooooool00_ooool2o`000;Gooooo002>ooooo`;o00007?ooool00ol0003oooooooooo`02ooooo`;o
00006oooool2o`0009Sooooo002/ooooo`04o`000?ooooooooooooooo`;o00006Oooool2o`000003
ooooool0003o000009Sooooo002Jooooo`;o00004?ooool3o`000003ooooool0003o000001Wooooo
0_l00002ooooo`Co0000UOooool009Wooooo0ol0000@ooooo`04o`000?ooooooooooooooo`;o0000
6Oooool2o`0000;ooooo2Ol0002@ooooo`00VOooool2o`00017ooooo00?o0000ooooooooool09?oo
ool5o`00093ooooo002/ooooo`03o`000?oooooooooo02Kooooo0_l0002Aooooo`00[?ooool00ol0
003oooooooooo`0Vooooo`Co0000Soooool008gooooo0_l0000Mooooo`03o`000?oooooooooo01oo
oooo0_l00007ooooo`;o0000Soooool008gooooo0_l0000Mooooo`03o`000?oooooooooo01oooooo
0_l00002ooooo`;o0000U?ooool00:cooooo00?o0000ooooooooool08oooool2o`0009Cooooo002/
ooooo`03o`000?oooooooooo00;ooooo0_l0002eooooo`00SOooool2o`0001gooooo0ol00002oooo
o`;o0000]Oooool008gooooo0_l0000Mooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo00Gooooo0_l0000Looooo`;o00001Oooool2o`0008gooooo002Gooooo`;o00004ooo
ool00ol0003oooooooooo`05ooooo`;o00007?ooool4o`0000?ooooo0_l0002=ooooo`00Uoooool2
o`0000_ooooo0_l00006ooooo`03o`000?oooooooooo00Oooooo0_l0000Jooooo`Go000000Cooooo
o`000?l0003o0000SOooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool5o`0000Cooooo00GoA4A4o`000?l0003o0000omgMg@05ooooo`03o`000?oooooooooo00Oooooo
0_l0000Jooooo`;o000000Coooooo`000?l0003ooooo0ol0002=ooooo`00ROooool01OmgMgOoV9RH
o`000?l0003oMgMg00Gooooo0_lQ8B42ooooo`;o000000GoV9RHob4Q8Oo^k^koooooodA4A007oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool01oooool2o`000;3ooooo0021ooooo`Ko
00000_ooool01Ol@413oooooo`000?l0003o410@00Wooooo0_l000001?ooooooV9RHob4Q8Oo^k^h9
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool2o`000;3ooooo0029oooo
o`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;o
oooo00Cooooo0ol0000Xooooo`;o0000Soooool008Wooooo00Co0000oooooooooooooooo0_l0000=
ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oo
oooooooo00Wooooo0_l0000Mooooo`;o0000Soooool008Wooooo00Co410@oooooooooooooooo0_l0
000>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`09ooooo`;o00007?ooool2o`0000;ooooo0_l0002<ooooo`00ROooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool09oooool3o`000003ooooool0003o000008cooooo0029ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03
o`000?oooooooooo00Wooooo0_l0000Mooooo`;o0000Soooool00:cooooo00?o0000ooooooooool0
2Oooool2o`0001kooooo0_l0002>ooooo`00U_ooool2o`0000Kooooo0_l0000<ooooo`03o`000?oo
oooooooo02Wooooo0_l0002>ooooo`00S?ooool2o`0000Sooooo0_l00006ooooo`;o00002oooool2
o`0000[ooooo0_l0000Vooooo`;o0000Qoooool008cooooo0ol0000Looooo`Co00002?ooool2o`00
02Kooooo0_l00027ooooo`00SOooool2o`0001gooooo00?o0000ooooooooool0:oooool2o`0008co
oooo002=ooooo`;o00001oooool2o`0001Cooooo00?o0000ooooooooool0:oooool2o`0008cooooo
002Fooooo`;o00005?ooool00ol0003oooooooooo`0Wooooo`;o00000_ooool2o`0008cooooo002/
ooooo`03o`000?oooooooooo02Oooooo0_l00002ooooo`;o0000S?ooool00:cooooo00?o0000oooo
ooooool0<_ooool3o`0008Cooooo002/ooooo`03o`000?oooooooooo03;ooooo0ol00024ooooo`00
S?ooool2o`0001kooooo00?o0000ooooooooool0:oooool2o`0000?ooooo0_l00027ooooo`00S?oo
ool2o`0001kooooo0ol0000;ooooo`;o00007_ooool2o`0000?ooooo0_l00027ooooo`00Roooool3
o`0000Oooooo0_l0000Eooooo`03o`000?oooooooooo00_ooooo0_l0000Tooooo`;o0000Q_ooool0
08_ooooo0_l00007ooooo`?o00005Oooool00ol0003oooooooooo`0aooooo`;o0000Q_ooool009Co
oooo0ol0000Eooooo`03o`000?oooooooooo02_ooooo0_l00006ooooo`?o0000Poooool009Gooooo
0_l0000Eooooo`03o`000?oooooooooo02_ooooo0_l000000ooooooo0000o`000003ooooo`?o0000
Poooool00:cooooo00?o0000ooooooooool0;_ooool2o`0008Wooooo002/ooooo`03o`000?oooooo
oooo00_ooooo1?l0000Looooo`;o0000S?ooool007gooooo0_l0000]ooooo`04o`000?oooooo0000
o`0000[ooooo1?l0000Looooo`;o0000S?ooool007gooooo0_l0000]ooooo`04o`000?oooooo0000
o`0000kooooo0_l0000Sooooo`;o0000Poooool009?ooooo0_l0000Gooooo`?o00003oooool2o`00
02?ooooo0_l00023ooooo`00Toooool2o`0001Oooooo00Co0000ooooool0003o0000;Oooool2o`00
00?ooooo0_l00024ooooo`00[?ooool01?l0003oooooo`000?l0000]ooooo`;o00000oooool2o`00
08Cooooo0009ooooo`Co000000?o410@ooooooooool05_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0?
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8b
omgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05
odA4A?l0003o0000oc8b<_oMgMd05_ooool00ol0003oooooooooo`0Hooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd03ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oM
gMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo
00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`Co000000?o410@ooooooooool04_ooool0
00_ooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46
ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_oo
ool05Oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8b
ooooo`0Iooooo`03o`000?oooooooooo01Cooooo0006o`0000Gooooo00?o0000ooooooooool04?oo
ool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo
00?o0000ooooooooool01Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03
o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onH
V9So0000o`000009ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool06?ooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01?ooool2o`0000?ooooo00?o0000
ooooooooool03Oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool03Ooo
ool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go
0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool0
3_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003o
oooooooooooooooo000000gooooo0_l000000oo^k^koooooooooo`05ooooo`03ogMgMolb<S;ooooo
01Gooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h00oooool2o`0000;ooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooo
oooo000000oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000kooooo
00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo
000;ooooo`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEE
EOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?oooooooooooooo
ool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ogMgMomVIVKooooo00?ooooo00?o0000ob4Q8Ol000000_l0000Fooooo`03o`000?oo
oooooooo01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<
c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Jooooo`03o`000?oooooooooo01Cooooo
000;ooooo`03o`000?oooooooooo01Sooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVY
ZOmgMgOooooo00?ooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00co
oooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02o`0001Kooooo0ol0000@ooooo`;o00001_ooool01Ol@
413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`;o00003?ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04Ooo
ool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003o
ooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aoooo
o`04ogMgMonHV9SooooooiRHV0;o00002_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0@ooooo`;o00001_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4003o`000003ooooool0003ooooo00Co
oooo0_l0000<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aoooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Dooooo`002Oooool00omEEEGoIVIVo`00000J
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000@ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`00013ooooo00Cok^k^oc8b<_l0003o<S8b0_l0000:ooooo`03
oiRHV?l@413o000000;o00001?ooool4o`0001Oooooo00?o0000ooooooooool06?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003o`000003ooooool0003o
000000;o00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000Iooooo`03oeEEEOmVIVKo000001Kooooo
002;ooooo`;o00002?ooool2o`0001Gooooo00Co0000oooooooooooooooo0_l0002fooooo`00UOoo
ool2o`0001Gooooo00Co0000oooooooooooooooo0_l0002fooooo`00[?ooool00ol0003ooooooooo
o`0eooooo`;o0000Moooool2o`0000;ooooo0_l00005ooooo`00[?ooool00ol0003oooooooooo`0>
ooooo`?o00009?ooool2o`0007Oooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd5ooooo`00[?oo
ool00ol0003oooooooooo`0>ooooo`?o00009?ooool2o`0007Sooooo00CogMgMo`000?l@413oc<c<
1_ooool000Ooooooool0001<o`0000cooooo00Cok^k^ob4Q8Ol@413ok^k^1_ooool000Oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`;o00001_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00Co0000ooooool0003o00000_ooool3o`0000Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool02_ooool01?lQ8B7oMgMgogMgMolb<S86ooooo`001oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07oooool2o`0000Gooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Gooooo
0_l00004ooooo`;o00006Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool02Oooool2o`0000;ooooo0_l00005ooooo`00O?ooool2o`0002kooooo00?o
0000ooooooooool0;oooool2o`0000?ooooo0_l00023ooooo`00U?ooool2o`0001Kooooo00?o0000
ooooooooool03Oooool2o`0002;ooooo0_l000000ooooooo0000o`000003ooooo`;o0000O_ooool0
09Cooooo0_l0000Fooooo`03o`000?oooooooooo00gooooo0_l00002ooooo`;o00007_ooool2o`00
00;ooooo0_l00002ooooo`;o0000O_ooool00:cooooo00?o0000ooooooooool04Oooool2o`0002;o
oooo0_l00022ooooo`00[?ooool00ol0003oooooooooo`0booooo`;o0000QOooool008_ooooo0_l0
000Oooooo`?o0000<_ooool2o`0000;ooooo0_l00021ooooo`00Roooool2o`0001oooooo00?o0000
ooooooooool03oooool2o`0002Gooooo0_l00021ooooo`00[?ooool00ol0003oooooooooo`0?oooo
o`;o00007_ooool2o`0000Sooooo0_l0001nooooo`00Roooool2o`0001oooooo00?o0000oooooooo
ool03Oooool3o`0001oooooo0_l00008ooooo`;o0000O_ooool008_ooooo0_l0000Oooooo`03o`00
0?oooooooooo00gooooo1Ol0000Uooooo`;o0000P?ooool00:cooooo00?o0000ooooooooool04?oo
ool2o`0002Gooooo0_l00020ooooo`00[?ooool00ol0003oooooooooo`0fooooo`;o00000_ooool3
o`0007cooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`0Aooooo`;o00008oooool2o`00
00;ooooo0ol0001looooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool04Oooool2o`0002;o
oooo0_l00003ooooo`;o0000OOooool00:cooooo0ol0000`ooooo`;o00000oooool2o`0000?ooooo
0_l0001mooooo`00[?ooool00ol0003oooooooooo`0_ooooo`?o0000Qoooool007cooooo0_l0000F
ooooo`;o00005_ooool00ol0003oooooooooo`0_ooooo`;o0000R?ooool007cooooo0_l0000Foooo
o`;o00005_ooool00ol0003oooooooooo`02o`000;Oooooo002/ooooo`03o`000?oooooooooo00;o
0000]oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0>_oo
ool2o`0007gooooo002/ooooo`03o`000?oooooooooo03Sooooo1?l0001mooooo`00[?ooool3o`00
03Sooooo0_l0001oooooo`00[?ooool00ol0003oooooooooo`02o`0000cooooo0_l0002Yooooo`00
[?ooool00ol0003oooooooooo`02o`0000[ooooo1?l0000Oooooo`;o0000R?ooool009Kooooo0_l0
000Dooooo`03o`000?oooooooooo00cooooo0_l00002ooooo`;o00007Oooool2o`0008Sooooo002F
ooooo`;o00005?ooool00ol0003oooooooooo`0<ooooo`;o00000_ooool2o`0002Oooooo0_l0001n
ooooo`00S?ooool4o`0001cooooo00?o0000ooooooooool04?ooool2o`0002Oooooo0_l0001noooo
o`00OOooool2o`0000gooooo1?l0000Looooo`03o`000?oooooooooo013ooooo0_l0000Xooooo`;o
0000OOooool007gooooo0_l0000<ooooo`;o00007oooool00ol0003oooooooooo`0@ooooo`;o0000
:?ooool2o`0007gooooo002;ooooo`Co00007Oooool3o`00013ooooo0_l0002Wooooo`00SOooool2
o`0001gooooo00?o0000ooooooooool02oooool4o`000003ooooool0003o000001kooooo0_l00004
ooooo`?o0000P?ooool00:cooooo00?o0000ooooooooool02oooool4o`00027ooooo0_l00004oooo
o`?o0000P?ooool00:cooooo00?o0000ooooooooool0<?ooool2o`0000?ooooo1?l00020ooooo`00
SOooool2o`0001gooooo00?o0000ooooooooool0<?ooool2o`0000?ooooo0ol00021ooooo`00SOoo
ool2o`0001gooooo00?o0000ooooooooool0=_ooool2o`00087ooooo0029ooooo`03onk^k_lb<S;o
000000;o00001Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`0=ooooo`;o00009oooool6o`0007gooooo0029ooooo`03ogMgMonHV9So
oooo00;o00001Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool03?ooool3o`0002Wooooo1?l0001mooooo`00ROooool0
1Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003ooooooooo
o`03ooooo`?o00002_ooool5o`0002Gooooo0_l00002ooooo`;o0000Ooooool008Wooooo00Go0000
ooooooooooooooooo`00000:ooooo`;o000000CooooooiRHV?lQ8B7ok^k^1oooool00omgMgOo<S8b
ooooo`04ooooo`;o00002oooool2o`0002Sooooo0_l00023ooooo`00ROooool01?l0003ooooooooo
ooooool2o`0000Wooooo0_l00002ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`;o0000=oooool2o`00087ooooo0029ooooo`04oa0@4?ooooooooooooooo`;o
00002Oooool2o`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`;o
00004Oooool2o`0001kooooo0_l00004ooooo`?o0000POooool008Wooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0:ooooo`;o000000Co^[ZjoooooonHV9So410@1?ooool00ol0003oooooooooo`06oooo
o`;o00004?ooool3o`0001gooooo0ol00004ooooo`;o00000_ooool2o`0007kooooo0029ooooo`04
onk^k_lb<S;o0000oc8b<P;o00002_ooool3o`000003ob4Q8Oo<c<cooooo00?ooooo1?l00006oooo
o`03o`000?oooooooooo00[ooooo0_l00002ooooo`;o00007_ooool4o`0000Oooooo0_l0001noooo
o`00O_ooool2o`0000gooooo0_l0000:ooooo`;o00004Oooool00ol0003oooooooooo`0:ooooo`;o
00009?ooool2o`0000Cooooo0_l00021ooooo`00O_ooool2o`0002cooooo00?o0000ooooooooool0
2oooool2o`0002?ooooo0_l00004ooooo`;o0000POooool00:cooooo00?o0000ooooooooool02ooo
ool2o`000:cooooo001nooooo`;o0000;?ooool3o`000;Wooooo001nooooo`;o0000;?ooool00ol0
003oooooooooo`2iooooo`00O_ooool2o`0002cooooo00?o0000ooooooooool0;_ooool6o`0000?o
oooo0ol0001oooooo`00Soooool2o`0001_ooooo00?o0000ooooooooool0;Oooool7o`0000?ooooo
0ol0001oooooo`00Soooool2o`0001_ooooo00?o0000ooooooooool0;Oooool4o`0000?ooooo0_l0
0023ooooo`00Yoooool2o`0000?ooooo00?o0000ooooooooool0;oooool2o`0000?ooooo0_l00023
ooooo`00W?ooool2o`0000Wooooo0ol00002ooooo`03o`000?oooooooooo02gooooo1?l00028oooo
o`00W?ooool2o`0000[ooooo0_l00002ooooo`03o`000?oooooooooo02gooooo1?l00003ooooo`;o
0000Poooool00:Sooooo0_l00002ooooo`?o00002Oooool2o`0002Wooooo0_l00023ooooo`00Z?oo
ool2o`0000;ooooo00?o0000ooooooooool01oooool4o`0002_ooooo0_l00021ooooo`00Woooool4
o`0000Wooooo00?o0000ooooooooool01oooool2o`0002[ooooo0_l000000ooooooo0000o`000021
ooooo`00Woooool4o`0000;ooooo0_l00005ooooo`03o`000?oooooooooo00Kooooo0_l0000Uoooo
o`;o00001?ooool2o`0008Cooooo002Rooooo`Go00001Oooool00ol0003oooooooooo`06ooooo`?o
00009?ooool2o`0008[ooooo002Rooooo`Co00001_ooool00ol0003oooooooooo`07ooooo`;o0000
9?ooool2o`0000?ooooo0_l00025ooooo`00Y?ooool2o`0000Kooooo00?o0000ooooooooool0<_oo
ool4o`0008?ooooo002Booooo`;o00006?ooool00ol0003oooooooooo`0^ooooo`;o00001?ooool2
o`0008?ooooo002Booooo`;o00006?ooool3o`0000Gooooo0_l0000Wooooo`;o0000ROooool00:co
oooo00?o0000ooooooooool01Oooool6o`0002;ooooo0_l0002:ooooo`00T?ooool2o`0001[ooooo
00?o0000ooooooooool01_ooool5o`0002;ooooo0_l00003ooooo`;o0000QOooool0093ooooo1?l0
000Hooooo`03o`000?oooooooooo00Oooooo0_l0000Yooooo`;o0000QOooool0087ooooo0_l0000>
ooooo`Co00005oooool00ol0003oooooooooo`07ooooo`;o0000/?ooool0087ooooo0_l0000@oooo
o`;o00005oooool00ol0003oooooooooo`0/ooooo`;o0000Roooool009?ooooo0_l0000Gooooo`03
o`000?oooooooooo02cooooo0_l0002;ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00P?oo
ool2o`0002[ooooo0ol0002iooooo`00P?ooool2o`0002[ooooo00?o0000ooooooooool01?ooool2
o`000;?ooooo002Cooooo`;o00005oooool00ol0003oooooooooo`04ooooo`;o0000/oooool009?o
oooo0_l0000Gooooo`03o`000?oooooooooo02Sooooo0_l0002?ooooo`00P?ooool2o`0002[ooooo
00?o0000ooooooooool0:?ooool2o`0000?ooooo0_l0002:ooooo`00P?ooool2o`0002[ooooo00Co
0000oooooooooooooooo0_l0000Zooooo`;o0000R_ooool0097ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooool0
00000ol0000Tooooo`Ko0000S?ooool0097ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo000000?o00009?ooool9o`0008Wo
oooo002Aooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo02gooooo0ol00029ooooo`00TOooool01?l0003oooooooooooooool2o`0000ko
oooo00?oMgMgoc8b<_ooool01?ooool3o`0002kooooo0_l00029ooooo`00P_ooool2o`0000gooooo
00Co0000oooooooooooooooo0_l000000ooooooo0000o`000008ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool01?l0003oooooooooooooool2o`0002[ooooo0_l0002:ooooo`00P_ooool2o`00
00gooooo00Ko410@oooooooooooooooooa0@4?ooool3o`0000Sooooo00?o0000ooooooooool01ooo
ool3o`000003ooooool0003o000002[ooooo0_l0002:ooooo`00TOooool01_mgMgOoV9RHoooooonH
V9SoMgMgooooo`;o00002Oooool00ol0003oooooooooo`05ooooo`Go0000^Oooool0097ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001?ooool3o`0002Wooooo0_l00006ooooo`;o0000
R?ooool009Kooooo0_l0000Dooooo`03o`000?oooooooooo00;o00009Oooool2o`0000?ooooo0_l0
00000ooooooo0000o`000028ooooo`00U_ooool2o`0001Cooooo1Ol0000Sooooo`;o00001Oooool2
o`0008_ooooo002/ooooo`Co00009?ooool6o`0008kooooo002[ooooo`Go00009_ooool4o`000003
ooooool0003o000008_ooooo002Jooooo`;o00003oooool3o`0002Gooooo0_l00006ooooo`?o0000
R_ooool009[ooooo0_l0000;ooooo`;o00000oooool00ol0003oooooooooo`0Tooooo`;o00000ooo
ool2o`0000;ooooo0_l0002:ooooo`00V?ooool2o`0000_ooooo1?l00003ooooo`?o00009oooool6
o`0008cooooo002Hooooo`;o00002oooool2o`0000Gooooo0ol0000Pooooo`;o00001Oooool2o`00
00;ooooo0ol0002;ooooo`00YOooool3o`000005ooooool0003o0000ooooool000008_ooool2o`00
00[ooooo0ol0002:ooooo`00X_ooool2o`000005ooooool0003o0000o`000?ooool00_l000000ooo
oooo0000ooooo`0Qooooo`;o00001_ooool2o`0000?ooooo0_l0002:ooooo`00X_ooool2o`0000So
oooo00?o0000ooooooooool08?ooool2o`0000Cooooo1?l000000ooooooo0000o`00002<ooooo`00
Y?ooool2o`0000Kooooo0ol0000Vooooo`;o00000oooool2o`0008cooooo002Kooooo`;o000000?o
ooooo`000?l000001?ooool2o`0000Kooooo00?o0000ooooooooool07oooool2o`000004ooooool0
003o0000o`0009Cooooo002Kooooo`Oo00002_ooool00ol0003oooooooooo`0Oooooo`;o000000Co
ooooo`000?l0003o0000U?ooool009gooooo0_l000000ooooooo0000o`00000:ooooo`03o`000?oo
oooooooo0;Wooooo002Mooooo`;o00001oooool2o`0000Cooooo00?o0000ooooooooool07oooool2
o`0000Sooooo0_l0002>ooooo`00WOooool2o`0000Oooooo0_l00004ooooo`03o`000?oooooooooo
01oooooo0_l00006ooooo`Co0000S_ooool00:?ooooo0_l00007ooooo`03o`000?oooooooooo02;o
oooo0_l00003ooooo`;o0000T?ooool00:?ooooo0_l00007ooooo`03o`000?oooooooooo01_ooooo
0_l00005ooooo`;o0000UOooool00:cooooo0ol0000Kooooo`;o00001?ooool3o`0000;ooooo0_l0
002Aooooo`00[?ooool00ol0003oooooooooo`0Pooooo`?o00000_ooool3o`00097ooooo002/oooo
o`03o`000?oooooooooo01gooooo0_l000000ooooooo0000o`000003ooooo`?o0000TOooool00:co
oooo00?o0000ooooooooool07Oooool2o`0009[ooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo01[ooooo0_l00005
ooooo`;o0000U_ooool00:cooooo00?o0000ooooooooool06?ooool4o`0000?ooooo1?l0002Foooo
o`00[?ooool00ol0003oooooooooo`0Hooooo`;o00001Oooool2o`0009Sooooo002/ooooo`?o0000
8Oooool2o`0009Kooooo002/ooooo`03o`000?oooooooooo027ooooo1?l0002Dooooo`00[?ooool0
0ol0003oooooooooo`0Sooooo`;o0000U?ooool00:cooooo00?o0000ooooooooool05oooool2o`00
00Sooooo0_l0002Fooooo`00[?ooool00ol0003oooooooooo`0Gooooo`?o00000oooool2o`0000;o
oooo0_l0002Fooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03
o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
01Sooooo0ol00002ooooo`Go0000Uoooool008Sooooo0_l000001?nHV9SooooooiRHV?mgMgL5oooo
o`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool06Oooool2o`000003ooooool0003o000000Co0000Uoooool008Sooooo1?l000000ooooooo
410@ooooo`0<ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Looooo`;o0000Voooool008Wooooo0ol000000ooooooo0000ooooo`0=ooooo`03ob4Q
8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`000;Wooooo0029ooooo`05o`000?oo
ooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`0Jooooo`;o0000WOooool008Wooooo00Go410@oooooooooooo
oooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Fooooo`;o00000_ooool2o`0009gooooo0029ooooo`;o000000?ooooooiRHV?mgMgL0
2oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Fooooo`Ko0000WOooool008Wooooo0ol000000olb<S;ok^k^ooooo`0:ooooo`Go0000
1?ooool4o`0000Kooooo00?o0000ooooooooool04?ooool2o`0000Gooooo0ol0002Oooooo`00[?oo
ool00ol0003oooooooooo`0@ooooo`;o000000Coooooo`000?l0003o0000Xoooool00:cooooo00?o
0000ooooooooool04oooool5o`000:7ooooo002/ooooo`03o`000?oooooooooo01Kooooo0_l0002Q
ooooo`00[?ooool3o`0001?ooooo1?l0002Rooooo`00SOooool2o`0001gooooo00?o0000oooooooo
ool04oooool4o`000:;ooooo002=ooooo`;o00007Oooool00ol0003oooooooooo`0Eooooo`;o0000
X_ooool00:cooooo00?o0000ooooooooool02oooool2o`0000Sooooo0_l0002Rooooo`00[?ooool0
0ol0003oooooooooo`0;ooooo`;o0000[?ooool00:cooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool03oooool2o`000:Sooooo002/ooooo`03o`000?oooooooooo00gooooo
1?l0002Xooooo`00[?ooool3o`0000gooooo0_l00002ooooo`;o0000Y_ooool00:cooooo00?o0000
ooooooooool03Oooool2o`000004ooooool0003o0000o`000:Kooooo002/ooooo`03o`000?oooooo
oooo00gooooo0_l000000ooooooo0000o`00002Wooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o0000
1oooool4o`000:Sooooo002/ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`Co0000Z?oo
ool0097ooooo0_l0000Iooooo`03o`000?oooooooooo00?ooooo0_l00009ooooo`;o0000ZOooool0
097ooooo1?l0000Gooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`;o000000?oooooo`00
0?l00000[?ooool009?ooooo0_l0000Gooooo`?o00002?ooool2o`000003ooooool0003o00000:co
oooo002/ooooo`03o`000?oooooooooo00Sooooo0_l0002_ooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00T_ooool4o`0001Kooooo0ol0002iooooo`00T_oo
ool4o`0001Kooooo0ol0002iooooo`00V_ooool2o`00013ooooo1?l0002hooooo`00V_ooool2o`00
013ooooo00Co0000ooooool0003o00000_ooool2o`000;Cooooo002Zooooo`?o00001Oooool2o`00
0;Cooooo002Vooooo`;o00000_ooool3o`000;_ooooo002Sooooo`Go00001?ooool00ol0003ooooo
ooooo`2iooooo`00Xoooool5o`0000Cooooo00?o0000ooooooooool0^Oooool009Wooooo0_l00002
ooooo`;o000000?oooooo`000?l000001Ol00005ooooo`04o`000?oooooo0000o`000;Sooooo002I
ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo0ol00004ooooo`;o000000?ooooo
o`000?l00000^?ooool00:Cooooo00?o0000ooooooooool01?ooool4o`000;Wooooo002Tooooo`03
o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oo
oooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Rooooo`03oeEEEOmVIVKo0000
0<?ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Zoooo
o`04oa0@4?l0003o0000o`000;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03
o`000?oooooooooo0;[ooooo002[ooooo`06o`000?mgMgOo0000o`000?mEEEGok^k^]oooool00:_o
oooo00Ko0000oeEEEOo^k^koooooogMgMomEEEFgooooo`00Zoooool00ol0003ok^k^ooooo`02oooo
o`03o`000?oooooooooo0;Gooooo002[ooooo`03o`000?o^k^kooooo00;ooooo00?o0000oooooooo
ool0]Oooool00:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomVIVJgooooo`00Z_ooool00ol@413o
0000ogMgM`02o`000003ofIVI_o^k^kooooo0;Kooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.53206 .16277 Mdot
.55428 .18053 Mdot
.44474 .51469 Mdot
.50959 .2954 Mdot
.55998 .66753 Mdot
.44813 .13497 Mdot
.51716 .47902 Mdot
.72193 .58954 Mdot
.68484 .66149 Mdot
.55852 .42181 Mdot
.56878 .50398 Mdot
.69602 .68354 Mdot
.58904 .21608 Mdot
.55872 .3982 Mdot
.63526 .79876 Mdot
.52761 .32728 Mdot
.39621 .47024 Mdot
.59015 .21669 Mdot
.57507 .56856 Mdot
.66606 .34391 Mdot
.63026 .30871 Mdot
.60383 .26645 Mdot
.6351 .35141 Mdot
.60751 .24913 Mdot
.63175 .8161 Mdot
.53462 .75715 Mdot
.56003 .59715 Mdot
.56332 .61904 Mdot
.67821 .38761 Mdot
.58514 .23625 Mdot
.65574 .40165 Mdot
.69956 .61723 Mdot
.70182 .64509 Mdot
.42514 .21991 Mdot
.40191 .32737 Mdot
.67756 .46508 Mdot
.69727 .54224 Mdot
.55898 .62334 Mdot
.68814 .4976 Mdot
.71071 .65088 Mdot
.67481 .74721 Mdot
.40586 .30641 Mdot
.43844 .16192 Mdot
.48654 .0996 Mdot
.47364 .10189 Mdot
.55305 .70188 Mdot
.56559 .5006 Mdot
.70827 .55339 Mdot
.48464 .84326 Mdot
.68483 .45741 Mdot
.70455 .57147 Mdot
.69298 .46211 Mdot
.41592 .97391 Mdot
.44266 .15868 Mdot
.40242 .31086 Mdot
.68938 .66366 Mdot
.71575 .61612 Mdot
.39863 .5979 Mdot
.70377 .54462 Mdot
.46609 .10509 Mdot
.53459 .74331 Mdot
.62348 .85582 Mdot
.68585 .53332 Mdot
.4233 .44001 Mdot
.65954 .7396 Mdot
.70144 .62035 Mdot
.56031 .44409 Mdot
.54182 .38566 Mdot
.57115 .56959 Mdot
.62645 .28967 Mdot
.42823 .79553 Mdot
.52248 .50705 Mdot
.56319 .47864 Mdot
.55255 .40329 Mdot
.68573 .5341 Mdot
.45776 .37536 Mdot
.41491 .97135 Mdot
.46313 .82066 Mdot
.69018 .44276 Mdot
.40579 .63025 Mdot
.66689 .43293 Mdot
.5929 .25414 Mdot
.51479 .31344 Mdot
.39997 .35223 Mdot
.71802 .58698 Mdot
.49642 .24833 Mdot
.55978 .66992 Mdot
.51153 .77625 Mdot
.41626 .73894 Mdot
.54529 .40228 Mdot
.61809 .83607 Mdot
.42597 .38901 Mdot
.54806 .70837 Mdot
.43003 .36435 Mdot
.5332 .98344 Mdot
.55847 .3992 Mdot
.68963 .63135 Mdot
.41531 .97399 Mdot
.44407 .83035 Mdot
.5508 .1903 Mdot
.44651 .83024 Mdot
.67832 .72122 Mdot
.51121 .12603 Mdot
.64968 .34861 Mdot
.42684 .21219 Mdot
.40438 .67635 Mdot
.57629 .57347 Mdot
.42543 .39317 Mdot
.63584 .31563 Mdot
.5554 .39074 Mdot
.48567 .25021 Mdot
.69639 .62615 Mdot
.66834 .37189 Mdot
.3585 .69423 Mdot
.49749 .68545 Mdot
.5101 .78957 Mdot
.71728 .56384 Mdot
.71274 .57546 Mdot
.68463 .60186 Mdot
.59816 .23439 Mdot
.65095 .81191 Mdot
.64686 .38277 Mdot
.6756 .37074 Mdot
.63143 .30237 Mdot
.52454 .33474 Mdot
.67556 .40307 Mdot
.54886 .96377 Mdot
.59955 .28 Mdot
.43703 .6298 Mdot
.61932 .30015 Mdot
.57034 .22157 Mdot
.68254 .71929 Mdot
.42348 .18868 Mdot
.4441 .14766 Mdot
.68303 .39517 Mdot
.70005 .45777 Mdot
.67885 .40531 Mdot
.56296 .48624 Mdot
.68658 .69052 Mdot
.64749 .78078 Mdot
.54558 .9535 Mdot
.44675 .28313 Mdot
.57507 .55425 Mdot
.39582 .49668 Mdot
.66536 .34921 Mdot
.7178 .57818 Mdot
.35044 .57321 Mdot
.53043 .7189 Mdot
.51421 .77365 Mdot
.69236 .74034 Mdot
.46239 .84921 Mdot
.57464 .50977 Mdot
.60028 .23296 Mdot
.52193 .48592 Mdot
.51777 .15622 Mdot
.69766 .49021 Mdot
.68972 .50446 Mdot
.71042 .59525 Mdot
.69374 .56455 Mdot
.69842 .48197 Mdot
.51637 .79538 Mdot
.68809 .41833 Mdot
.71751 .65297 Mdot
.67435 .47018 Mdot
.48451 .13053 Mdot
.57248 .23225 Mdot
.71536 .58591 Mdot
.64985 .34227 Mdot
.57011 .57201 Mdot
.69657 .43673 Mdot
.68228 .48748 Mdot
.48069 .2595 Mdot
.5631 .59885 Mdot
.53397 .72996 Mdot
.54461 .68943 Mdot
.6838 .69184 Mdot
.5339 .98143 Mdot
.52139 .16268 Mdot
.46029 .69499 Mdot
.68503 .43367 Mdot
.6923 .41737 Mdot
.70224 .6797 Mdot
.53411 .33551 Mdot
.67436 .74994 Mdot
.42851 .57235 Mdot
.67365 .68692 Mdot
.53082 .98114 Mdot
.71114 .56675 Mdot
.71412 .65941 Mdot
.42684 .18894 Mdot
.65696 .79795 Mdot
.66331 .34137 Mdot
.42483 .43307 Mdot
.60387 .87789 Mdot
.71809 .59549 Mdot
.69064 .72698 Mdot
.68202 .71661 Mdot
.54374 .71558 Mdot
.40628 .69969 Mdot
.46967 .69969 Mdot
.46848 .69973 Mdot
.52255 .52043 Mdot
.53835 .7179 Mdot
.57533 .23428 Mdot
.42649 .4359 Mdot
.468 .1161 Mdot
.45495 .25964 Mdot
.43888 .65922 Mdot
.56956 .47622 Mdot
.57523 .19802 Mdot
.47388 .82491 Mdot
.65124 .34698 Mdot
.54431 .37952 Mdot
.57799 .24244 Mdot
.46842 .82136 Mdot
.71278 .66656 Mdot
.44439 .67677 Mdot
.51334 .14294 Mdot
.71679 .62741 Mdot
.51806 .77545 Mdot
.69298 .60263 Mdot
.64344 .32385 Mdot
.67059 .46203 Mdot
.55042 .42391 Mdot
.55921 .66081 Mdot
.51844 .12756 Mdot
.45825 .26866 Mdot
.63746 .79582 Mdot
.66472 .79325 Mdot
.51312 .29257 Mdot
.49547 .3633 Mdot
.42035 .74473 Mdot
.56897 .54215 Mdot
.64381 .81979 Mdot
.5633 .60234 Mdot
.51399 .12813 Mdot
.63136 .32199 Mdot
.56287 .20891 Mdot
.61228 .87002 Mdot
.42001 .20636 Mdot
.65145 .33628 Mdot
.42798 .79457 Mdot
.70887 .58256 Mdot
.44162 .31273 Mdot
.69209 .54359 Mdot
.39847 .4439 Mdot
.43095 .80339 Mdot
.68804 .51414 Mdot
.68399 .73784 Mdot
.49509 .69005 Mdot
.43656 .34452 Mdot
.68927 .5706 Mdot
.49658 .81977 Mdot
.56132 .60444 Mdot
.39071 .45031 Mdot
.4602 .36758 Mdot
.7064 .64203 Mdot
.70688 .5451 Mdot
.45509 .83471 Mdot
.56925 .53906 Mdot
.67183 .45977 Mdot
.45266 .68648 Mdot
.43928 .81278 Mdot
.54223 .18242 Mdot
.56369 .54097 Mdot
.49982 .13905 Mdot
.67967 .48529 Mdot
.45715 .82496 Mdot
.67621 .42278 Mdot
.39844 .34088 Mdot
.55207 .3843 Mdot
.42482 .7566 Mdot
.69753 .47307 Mdot
.52819 .31544 Mdot
.57797 .58377 Mdot
.70274 .5859 Mdot
.56653 .43535 Mdot
.49185 .1214 Mdot
.6862 .4289 Mdot
.47505 .7197 Mdot
.5557 .43814 Mdot
.69107 .57798 Mdot
.68697 .70015 Mdot
.57778 .56696 Mdot
.52002 .47876 Mdot
.50912 .76885 Mdot
.65591 .33155 Mdot
.52406 .75813 Mdot
.66559 .4366 Mdot
.52054 .99097 Mdot
.69798 .57245 Mdot
.65188 .7684 Mdot
.68846 .61333 Mdot
.50194 .37732 Mdot
.70539 .50624 Mdot
.58225 .90089 Mdot
.64744 .31177 Mdot
.63884 .79185 Mdot
.34876 .51512 Mdot
.44859 .82012 Mdot
.39281 .39181 Mdot
.56128 .20336 Mdot
.70521 .59764 Mdot
.65679 .77637 Mdot
.56664 .48835 Mdot
.698 .60385 Mdot
.49836 .81873 Mdot
.48132 .69539 Mdot
.5908 .22821 Mdot
.39565 .48362 Mdot
.60638 .254 Mdot
.69041 .74112 Mdot
.47905 .70986 Mdot
.5259 .16002 Mdot
.4187 .24106 Mdot
.65732 .74663 Mdot
.46977 .71295 Mdot
.69618 .69498 Mdot
.60562 .86479 Mdot
.5821 .91805 Mdot
.52602 .33303 Mdot
.40887 .24719 Mdot
.3949 .4148 Mdot
.68674 .54339 Mdot
.57228 .62006 Mdot
.50247 .66198 Mdot
.51258 .4321 Mdot
.40297 .66073 Mdot
.71924 .61232 Mdot
.68356 .59426 Mdot
.42459 .40862 Mdot
.58535 .22119 Mdot
.44241 .65901 Mdot
.52193 .53121 Mdot
.52466 .13589 Mdot
.43376 .16283 Mdot
.48308 .12961 Mdot
.51176 .80268 Mdot
.53534 .72275 Mdot
.4677 .83146 Mdot
.60227 .27995 Mdot
.43036 .37129 Mdot
.69174 .66562 Mdot
.55898 .59867 Mdot
.67881 .41133 Mdot
.61623 .30732 Mdot
.42866 .36092 Mdot
.468 .81756 Mdot
.55455 .94388 Mdot
.70387 .66306 Mdot
.70623 .47727 Mdot
.67829 .45676 Mdot
.47517 .84155 Mdot
.39569 .58008 Mdot
.68168 .46868 Mdot
.43156 .78966 Mdot
.70158 .66867 Mdot
.61219 .88469 Mdot
.65249 .33783 Mdot
.6788 .72596 Mdot
.69393 .70133 Mdot
.69677 .70636 Mdot
.52045 .55882 Mdot
.42598 .76567 Mdot
.64052 .79215 Mdot
.712 .62611 Mdot
.52028 .56334 Mdot
.66045 .40817 Mdot
.43207 .76865 Mdot
.44634 .13469 Mdot
.54693 .18481 Mdot
.68746 .64213 Mdot
.5182 .13446 Mdot
.70012 .53713 Mdot
.68254 .58636 Mdot
.63505 .35417 Mdot
.70438 .45729 Mdot
.6229 .31256 Mdot
.63982 .80078 Mdot
.35853 .70298 Mdot
.68142 .62054 Mdot
.49694 .12447 Mdot
.5196 .53396 Mdot
.62838 .83025 Mdot
.43244 .80054 Mdot
.51153 .42642 Mdot
.70858 .66592 Mdot
.62808 .29308 Mdot
.51058 .63554 Mdot
.55612 .42113 Mdot
.52064 .77779 Mdot
.56789 .55757 Mdot
.71019 .54819 Mdot
.62721 .27536 Mdot
.59094 .8926 Mdot
.70207 .68147 Mdot
.39855 .39407 Mdot
.42543 .99099 Mdot
.39453 .4731 Mdot
.551 .6721 Mdot
.5623 .64406 Mdot
.47077 .34086 Mdot
.71456 .62533 Mdot
.69491 .68526 Mdot
.56107 .59112 Mdot
.44827 .28424 Mdot
.56946 .43182 Mdot
.51103 .277 Mdot
.6839 .74706 Mdot
.5617 .67385 Mdot
.67305 .44231 Mdot
.47501 .25015 Mdot
.57374 .52831 Mdot
.45484 .69374 Mdot
.55825 .67865 Mdot
.42238 .23177 Mdot
.57322 .50308 Mdot
.427 .42522 Mdot
.67164 .77822 Mdot
.68982 .68235 Mdot
.45521 .58737 Mdot
.40221 .32227 Mdot
.40341 .66809 Mdot
.55129 .2088 Mdot
.42665 .75107 Mdot
.56828 .57649 Mdot
.64407 .80858 Mdot
.55178 .96789 Mdot
.53952 .16497 Mdot
.36938 .78637 Mdot
.47974 .0949 Mdot
.42361 .47817 Mdot
.66608 .70918 Mdot
.63417 .80304 Mdot
.56667 .54131 Mdot
.62375 .33077 Mdot
.45658 .26724 Mdot
.51164 .62737 Mdot
.53399 .71631 Mdot
.67038 .43884 Mdot
.4186 .72124 Mdot
.42974 .59341 Mdot
.44203 .163 Mdot
.3955 .41275 Mdot
.42171 .45618 Mdot
.46384 .7025 Mdot
.53847 .34446 Mdot
.72026 .59677 Mdot
.48819 .70545 Mdot
.68721 .4212 Mdot
.54296 .16519 Mdot
.503 .12449 Mdot
.67531 .40821 Mdot
.6638 .436 Mdot
.39539 .4715 Mdot
.58624 .92454 Mdot
.55636 .41939 Mdot
.71975 .6121 Mdot
.69128 .72372 Mdot
.56101 .56239 Mdot
.70606 .49293 Mdot
.43948 .79256 Mdot
.40269 .36677 Mdot
.67739 .40288 Mdot
.5425 .17609 Mdot
.5711 .59358 Mdot
.47264 .81952 Mdot
.4126 .27406 Mdot
.65834 .80776 Mdot
.47431 .12414 Mdot
.44757 .41779 Mdot
.45843 .13487 Mdot
.4119 .68488 Mdot
.52387 .52016 Mdot
.53927 .38089 Mdot
.43392 .17793 Mdot
.42062 .20846 Mdot
.48495 .70142 Mdot
.48727 .82699 Mdot
.70083 .62333 Mdot
.5691 .63912 Mdot
.54108 .18257 Mdot
.57858 .50367 Mdot
.54348 .67959 Mdot
.51788 .58661 Mdot
.37116 .80654 Mdot
.5126 .61299 Mdot
.53998 .15825 Mdot
.68029 .6457 Mdot
.67459 .45877 Mdot
.57101 .57452 Mdot
.68154 .41657 Mdot
.70009 .68094 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002Uooooo`;o00001Oooool00ol0003oooooooooo`2iooooo`00YOooool2o`0000Gooooo
00?o0000ooooooooool0^Oooool00:Oooooo0_l00003ooooo`?o0000^Oooool00:?ooooo0_l00002
ooooo`;o00000oooool00ol0003oooooooooo`2iooooo`00X?ooool2o`000003ooooool0003o0000
00Oooooo00?o0000ooooooooool0^Oooool00:3ooooo0_l0000:ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002Qooooo`;o00002Oooool00ol0003ooooooooo
o`2iooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^
k^kooooo00?ooooo1?l000000olb<S;ogMgMooooo`04ooooo`03o`000?oooooooooo0;Wooooo0029
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01ooo
ool01?mgMgOo<S8booooooooool2o`000003ooooool0003ooooo0;[ooooo0021ooooo`Ko00000_oo
ool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool01Oooool2o`000004oooo
ool0003oooooooooo`Ko0000^Oooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ob4Q8Ooooooooooo00Cooooo0_l000000omgMgOo<S8booooo`03ooooo`Wo0000]?ooool008Wooooo
00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Co0000ob4Q8Ol0
003o<S8b0_l00004ooooo`03o`000?oooooooooo00Go0000]?ooool008Wooooo00Go410@oooooooo
oooooooooa0@400<ooooo`;o000000CoZJVYogMgMol0003o00000_ooool01?l0003ooooooooooooo
ool2o`0000Cooooo00?o0000ooooooooool00oooool2o`000;Cooooo0029ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol@413o0000o`000?oooooo<S8b00;o00000_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00?ooooo1?l0002booooo`00ROooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`0000Kooooo0_l0002booooo`00[?oo
ool2o`0000;ooooo0_l0002fooooo`00[?ooool01?l0003oooooooooooooool2o`000;Kooooo002I
ooooo`;o00004Oooool00ol0003oooooooooo`2iooooo`00VOooool2o`00017ooooo0ol0002ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00VOooool2o`00017ooooo00?o0000ooooooooool0
0_ooool2o`0000Kooooo0_l0002]ooooo`00Uoooool4o`00017ooooo00?o0000ooooooooool00_oo
ool2o`000003ooooool0003o000000?ooooo0_l0002]ooooo`00U_ooool4o`0001;ooooo00?o0000
ooooooooool01?ooool5o`000004ooooool0003o0000o`000:cooooo002Fooooo`Co00004_ooool0
0ol0003oooooooooo`04ooooo`;o000000Coooooo`000?l0003ooooo0ol0002/ooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`0000_o
oooo0_l0002/ooooo`00U_ooool2o`0001Cooooo00?o0000ooooooooool02oooool2o`000:cooooo
002Fooooo`;o00005?ooool00ol0003oooooooooo`0:ooooo`?o000000?oooooo`000?l00000ZOoo
ool00:cooooo00?o0000ooooooooool02_ooool6o`000:Wooooo002Booooo`?o00005oooool00ol0
003oooooooooo`0<ooooo`;o0000Zoooool009;ooooo0ol0000Gooooo`03o`000?oooooooooo00go
oooo0_l0002Zooooo`00[?ooool00ol0003oooooooooo`0=ooooo`;o0000Z_ooool00:cooooo00?o
0000ooooooooool05Oooool2o`000:;ooooo002/ooooo`?o00005Oooool2o`000:;ooooo002/oooo
o`03o`000?oooooooooo017ooooo0_l0002Vooooo`00TOooool2o`0001Wooooo00?o0000oooooooo
ool04Oooool2o`000:Kooooo002Aooooo`;o00006Oooool00ol0003oooooooooo`0=ooooo`;o0000
0_ooool2o`000:Kooooo002Aooooo`Co00005oooool00ol0003oooooooooo`0=ooooo`;o00000_oo
ool2o`000:Kooooo002Cooooo`;o00005oooool00ol0003oooooooooo`0Jooooo`;o0000WOooool0
0:cooooo00?o0000ooooooooool06_ooool2o`0009gooooo002Cooooo`;o00005oooool00ol0003o
ooooooooo`0Dooooo`;o00000oooool2o`0009kooooo002Cooooo`;o00005oooool3o`0001Cooooo
0_l00003ooooo`;o0000W_ooool00:cooooo00?o0000ooooooooool06oooool2o`0009cooooo002B
ooooo`;o00006?ooool00ol0003oooooooooo`0Kooooo`;o0000W?ooool009;ooooo0_l0000Hoooo
o`03o`000?oooooooooo01Cooooo0ol00006ooooo`?o0000VOooool00:cooooo00?o0000oooooooo
ool05?ooool3o`0000;ooooo0_l00002ooooo`?o0000VOooool00:cooooo00?o0000ooooooooool0
6Oooool2o`0009kooooo002Aooooo`?o000000?o<S8bonk^k_ooool01?ooool2ob4Q8@Gooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01Kooooo0_l0002Qooooo`00TOoo
ool2o`000003oooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool05_ooool2o`000:7ooooo0029ooooo`Ko00000_ooool01Ol@413ooooooooooooo
oooo410@013ooooo00Co0000oooooooooooooooo0ol0000Rooooo`;o0000Uoooool008gooooo0_l0
0002ooooo`05o`000?ooooooooooooooool000003Oooool2o`000005ogMgMolb<S;o0000o`000?oo
ool01Ol0000Pooooo`;o0000Uoooool0097ooooo00Go0000ooooooooooooooooo`00000<ooooo`?o
000000Co<S8bolc<c?l0003o00000oooool00ol0003oooooooooo`0Kooooo`;o00000oooool2o`00
09Oooooo002Aooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo01_ooooo0_l00003ooooo`;o0000Uoooool0097ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`07ooooo`;o00000oooool00ol0003oooooooooo`02o`0000Gooooo00?o0000oooo
ooooool0^Oooool0097ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`;o00000oooool5o`00
00Gooooo00?o0000ooooooooool0^Oooool009gooooo0_l0000=ooooo`03o`000?oooooooooo01oo
oooo0_l0002Hooooo`00WOooool3o`0000cooooo00?o0000ooooooooool07oooool2o`0009Sooooo
002?ooooo`;o00003Oooool2o`0000cooooo00?o0000ooooooooool0^Oooool008oooooo0_l0000K
ooooo`Go00009Oooool2o`00093ooooo002/ooooo`03o`000?oooooooooo00;o00006oooool3o`00
00Oooooo0_l0002@ooooo`00V_ooool2o`00013ooooo00?o0000ooooooooool07Oooool3o`0009Wo
oooo002Jooooo`;o00004?ooool00ol0003oooooooooo`2iooooo`00V_ooool2o`00013ooooo00?o
0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool09_ooool2o`00097ooooo002/oooo
o`03o`000?oooooooooo00?o00008oooool3o`00093ooooo002/ooooo`03o`000?oooooooooo00?o
00009?ooool2o`00093ooooo002/ooooo`?o00009?ooool2o`0009?ooooo002/ooooo`03o`000?oo
oooooooo02Cooooo0_l00002ooooo`;o0000Soooool008cooooo0_l0000Nooooo`03o`000?oooooo
oooo02?ooooo0_l00003ooooo`;o0000Soooool008cooooo0_l0000Nooooo`03o`000?oooooooooo
02?ooooo0_l00003ooooo`;o0000Soooool008_ooooo0_l0000;ooooo`;o00004_ooool01?l0003o
ooooooooooooool2o`0002;ooooo0_l000000ooooooo0000o`000003ooooo`;o0000R_ooool008_o
oooo0_l0000;ooooo`;o00004_ooool01?l0003oooooooooooooool2o`0000?ooooo0_l0000Moooo
o`;o00000_ooool2o`0000;ooooo0_l0002:ooooo`00[?ooool00ol0003oooooooooo`06ooooo`;o
00008Oooool2o`0008kooooo002;ooooo`;o00007oooool00ol0003oooooooooo`0Xooooo`;o0000
Soooool008_ooooo0_l0000Oooooo`?o0000:?ooool2o`0000;ooooo0_l0002;ooooo`00Roooool2
o`0001oooooo00?o0000ooooooooool01_ooool2o`0002Cooooo0_l0002;ooooo`00Roooool2o`00
01oooooo00?o0000ooooooooool01_ooool2o`0001gooooo0_l00009ooooo`;o0000Qoooool00:co
oooo00?o0000ooooooooool01Oooool2o`0001kooooo0_l00009ooooo`;o0000Qoooool00:cooooo
00?o0000ooooooooool01Oooool2o`000003ooooool0003o000002Gooooo0_l00028ooooo`00R_oo
ool2o`0001Kooooo0_l00008ooooo`03o`000?oooooooooo00Sooooo0_l0000Uooooo`;o0000R?oo
ool008[ooooo0_l0000Fooooo`;o00002?ooool00ol0003oooooooooo`0^ooooo`;o00000_ooool3
o`0008Cooooo002Gooooo`;o00004oooool00ol0003oooooooooo`09ooooo`;o00008oooool2o`00
00;ooooo0ol00024ooooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool02Oooool2o`0002?o
oooo0_l00003ooooo`;o0000Q?ooool008_ooooo0_l0000Oooooo`?o0000:Oooool2o`0000?ooooo
0_l00003ooooo`;o0000Q?ooool008_ooooo0_l0000Oooooo`03o`000?oooooooooo02Wooooo0_l0
002>ooooo`00[?ooool00ol0003oooooooooo`0Yooooo`;o0000S_ooool009Cooooo0_l0000Foooo
o`03o`000?oooooooooo0;Wooooo002Dooooo`;o00005?ooool3o`000;_ooooo0029ooooo`05onk^
k_lb<S;o0000o`000?o^k^h01Oooool00olQ8B7o0000o`000003ooooo`Oo00000_ooool01Om4A4Co
0000o`000?lb<S;ogMgM00?ooooo0ol0002kooooo`00ROooool01OmgMgOoV9RHo`000?l0003oMgMg
00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00_l00005ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0=oooool2o`00083ooooo0021ooooo`Ko00000_ooool01Ol@
413ooooooooooooooooo410@00Oooooo0_l00003ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0dooooo`;o000000?oooooo`000?l00000P?ooool0
08Wooooo00Go0000ooooooooooooooooo`000007ooooo`;o00001?ooool00onHV9So8B4Qonk^kP02
o`0000Gooooo00?oMgMgoc8b<_ooool01?ooool3o`0003Cooooo0_l00023ooooo`00ROooool01Ol0
003ooooooooooooooooo000000kooooo00CoMgMgofIVI_l0003o00000_ooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo0_l0000<ooooo`;o0000[?ooool008Wooooo00Go410@oooooooooooooooo
oa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0:ooooo`?o00008?ooool2o`0008[ooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0:ooooo`;o00000_ooool2o`0001gooooo0_l0002:ooooo`00ROooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_l00004ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`00
00Kooooo00?o0000ooooooooool02_ooool2o`0000;ooooo0_l0000Wooooo`;o0000P?ooool008So
oooo0_l00009ooooo`;o00005oooool00ol0003oooooooooo`0?ooooo`;o00009_ooool2o`00083o
oooo0028ooooo`Co00001oooool2o`0001Oooooo00?o0000ooooooooool03oooool2o`0002Sooooo
0_l0001nooooo`00R_ooool2o`0000Oooooo0_l0000Gooooo`03o`000?oooooooooo013ooooo0_l0
000Wooooo`;o0000O_ooool00:cooooo0ol0000@ooooo`;o0000Yoooool00:cooooo00?o0000oooo
ooooool03?ooool6o`0001kooooo0_l00005ooooo`;o0000P?ooool00:cooooo00?o0000oooooooo
ool03?ooool4o`00023ooooo0_l00005ooooo`?o0000Ooooool009?ooooo0_l0000Gooooo`03o`00
0?oooooooooo03;ooooo0_l00002ooooo`Co0000Ooooool008Wooooo0_l00008ooooo`;o00005ooo
ool00ol0003oooooooooo`0booooo`;o00000_ooool4o`0007oooooo0029ooooo`;o00008Oooool0
0ol0003oooooooooo`0hooooo`;o0000Ooooool008Wooooo0_l0000?ooooo`;o00004?ooool00ol0
003oooooooooo`0?ooooo`;o00009oooool2o`000004ooooool0003o0000o`0007_ooooo002Joooo
o`;o00004?ooool00ol0003oooooooooo`0?ooooo`?o0000:?ooool4o`0007_ooooo002Cooooo`;o
00005oooool3o`0000gooooo1Ol0000Uooooo`;o000000?oooooo`000?l00000OOooool009?ooooo
0_l0000Gooooo`03o`000?oooooooooo00;o00002oooool2o`0002Sooooo0_l00020ooooo`00[?oo
ool00ol0003oooooooooo`02o`00017ooooo0_l0000Uooooo`;o0000OOooool009?ooooo0_l0000G
ooooo`04o`000?ooooooooooooooo`;o00004?ooool2o`0001oooooo0_l00004ooooo`;o0000OOoo
ool009?ooooo0_l0000Gooooo`04o`000?ooooooooooooooo`;o00004?ooool2o`0001kooooo0ol0
0004ooooo`;o000000?oooooo`000?l00000N_ooool009;ooooo0ol0000Gooooo`03o`000?oooooo
oooo00oooooo0_l00002ooooo`;o00007_ooool4o`0000Kooooo0_l0001jooooo`00R_ooool2o`00
00Kooooo0_l0000Hooooo`03o`000?oooooooooo00oooooo0_l0000Tooooo`?o00000oooool2o`00
07cooooo002:ooooo`;o00008?ooool00ol0003oooooooooo`0@ooooo`;o00009?ooool2o`0000?o
oooo0_l0001looooo`00[?ooool00ol0003oooooooooo`0@ooooo`;o0000Yoooool008Oooooo0_l0
000Sooooo`?o0000^Oooool008Oooooo0_l0000Sooooo`03o`000?oooooooooo0;Wooooo002Boooo
o`;o00006?ooool00ol0003oooooooooo`0fooooo`?o000000?oooooo`000?l000000oooool3o`00
07Oooooo0009ooooo`Co000000?o410@ooooooooool05_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0?
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8b
omgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05
odA4A?l0003o0000oc8b<_oMgMd05_ooool00ol0003oooooooooo`0Hooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`04odA4A?l0003o0000oc8b<PCo000000?o
ooooo`000?l000000_l000001?oooooo0000o`000?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb
<S;ogMgM01Sooooo1?l000000ol@413oooooooooo`0Booooo`002oooool00ol0003oooooooooo`0H
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01ooo
ool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`0Eooooo`03o`000?oooooooooo
01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Oooooo00?oMgMgo`000?l000000_l00003ooooo`;o00001oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo01Wo
oooo00?o0000ooooooooool05?ooool000Ko00001Oooool00ol0003oooooooooo`0@ooooo`Ko0000
0_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003o
ooooooooo`05ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooo
ooooool01Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7o
k^k^00Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Hooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`04o`000?oooooo0000o`0000cooooo
00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00gooooo00Go410@oooooooo
oooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05o`000?oooooooooooooo
ool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00
000<ooooo`;o000000?o8B4Qonk^k_ooool01_ooool00omgMgOo<S8booooo`0Eooooo`03o`000?oo
oooooooo01Sooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo
00GoMgMgoc8b<_l0003o0000ooooo`02o`0000[ooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooo
oooo00Kooooo00?oMgMgoc8b<_ooool06Oooool00ol0003oooooooooo`0Dooooo`002oooool00ol0
003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000cooooo
00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003?ooool2o`00
0003ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Fooooo`03o`000?oooooo
oooo01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c002o`000003ooooool0003o000000?ooooo0_l00005ooooo`05o`00
0?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Jooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go410@
oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool04Ooo
ool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04Oooool01Ol@413ooooo
oooooooooooo410@00cooooo0_l000000ooooooo0000ooooo`03ooooo`03o`000?oooooooooo01So
oooo0ol0000Dooooo`;o00000_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0:ooooo`;o000000?oooooo`000?l000000_ooool01Ol@
413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooo
oooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`0Aooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo0ol0000Hooooo`03o`000?oooooo
oooo00;ooooo0ol0000<ooooo`;o000000?oooooo`000?l000000_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00gooooo
0_l00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Dooooo`002Oooool00omEEEGoIVIVo`00000Joooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000@ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`01?ooool4o`0001Oooooo00?o0000ooooooooool00_ooool3o`0000co
oooo0_l00005ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7o
c<c<00Cooooo1?l00009ooooo`;o00001Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0
000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000Iooooo`03oeEE
EOmVIVKo000001Kooooo0029ooooo`;o00008Oooool00ol0003oooooooooo`04ooooo`;o00002ooo
ool2o`0002Gooooo0_l00004ooooo`;o0000NOooool008Wooooo0_l0000Qooooo`03o`000?oooooo
oooo00Cooooo0_l0000;ooooo`Co00008oooool3o`0007kooooo002/ooooo`03o`000?oooooooooo
01?ooooo0_l0000Tooooo`;o00000oooool2o`0006kooooo0_l00002ooooo`;o00001Oooool00:co
oooo00?o0000ooooooooool0?_ooool2o`000003ooooool0003o000006_ooooo00Kok^k^ob4Q8On7
QhOo^[Zjo`000?oMgMd5ooooo`00ROooool2o`00027ooooo00?o0000ooooooooool0>oooool2o`00
00Cooooo0_l0001/ooooo`04omgMgOl0003o410@olc<c0Kooooo0007oooooooo0000C?l0000<oooo
o`04onk^k_lQ8B7o410@onk^kPKooooo0007ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00Co0000oooo
oooooooooooo1ol00005ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`04o`000?ooooooooooooooo`;o00000_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0:ooooo`04ob4Q8OmgMgOoMgMgoc8b<PKooooo0007ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool01?ooool2o`0000gooooo1_l0000>ooooo`03o`000?oooooooooo017ooooo0_l0
0003ooooo`;o00003_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool02Oooool2o`0000;ooooo0_l00005ooooo`00[?ooool00ol0003oooooooooo`04
ooooo`;o00003oooool2o`0002Wooooo0_l0001gooooo`00[?ooool00ol0003oooooooooo`0Eoooo
o`;o0000X_ooool007[ooooo0_l0000Mooooo`;o00004Oooool00ol0003oooooooooo`0kooooo`;o
0000O?ooool007[ooooo0_l0000Mooooo`;o00004Oooool00ol0003oooooooooo`0kooooo`;o0000
O?ooool00:cooooo00?o0000ooooooooool01?ooool2o`000;?ooooo002/ooooo`?o00001?ooool2
o`000;?ooooo002/ooooo`03o`000?oooooooooo01Gooooo0_l0002Rooooo`00[?ooool00ol0003o
ooooooooo`04ooooo`;o00003oooool2o`000:;ooooo002/ooooo`03o`000?oooooooooo00?ooooo
0ol0000dooooo`;o0000OOooool00:cooooo00?o0000ooooooooool00oooool2o`0003Gooooo0_l0
0003ooooo`;o0000N?ooool00:cooooo00?o0000ooooooooool04oooool2o`0002[ooooo0_l0001h
ooooo`00[?ooool00ol0003oooooooooo`0Booooo`?o00009Oooool6o`0007Wooooo002/ooooo`03
o`000?oooooooooo01;ooooo0ol0000Uooooo`Wo0000M_ooool00:cooooo00?o0000ooooooooool0
@?ooool4o`0007Gooooo002/ooooo`?o0000@_ooool2o`0007Gooooo002/ooooo`03o`000?oooooo
oooo01Gooooo0_l0000Zooooo`;o0000M_ooool00:cooooo00?o0000ooooooooool00oooool2o`00
00kooooo1?l0000Zooooo`;o0000M_ooool00:cooooo00?o0000ooooooooool00oooool2o`0000ko
oooo0_l0002Tooooo`00[?ooool00ol0003oooooooooo`03ooooo`;o00003?ooool2o`0002[ooooo
0_l00005ooooo`;o0000Loooool00:cooooo00?o0000ooooooooool00oooool2o`0000cooooo0_l0
0003ooooo`;o00009Oooool2o`0000?ooooo1?l0001cooooo`00[?ooool00ol0003oooooooooo`0D
ooooo`Co00008oooool2o`0000Gooooo0_l0001eooooo`00N_ooool2o`0001Sooooo0_l0000Foooo
o`03o`000?oooooooooo01Cooooo1?l0000Sooooo`;o000000?oooooo`000?l000000_l0001goooo
o`00N_ooool2o`0001Sooooo0_l0000Fooooo`?o00004oooool5o`0002Kooooo1?l000000ooooooo
0000o`00001dooooo`00ROooool2o`00027ooooo00?o0000ooooooooool04oooool3o`0002Kooooo
0_l00005ooooo`?o0000Loooool008Wooooo0_l0000Qooooo`03o`000?oooooooooo03cooooo0_l0
0004ooooo`Co0000Loooool00:cooooo00?o0000ooooooooool05_ooool2o`0002Oooooo0_l00000
0ooooooo0000o`000002o`0007?ooooo002Mooooo`;o00003Oooool00ol0003oooooooooo`02oooo
o`;o00004_ooool2o`00027ooooo0_l00004ooooo`;o00000oooool3o`0007;ooooo002Mooooo`;o
00003Oooool00ol0003oooooooooo`02ooooo`;o00003Oooool2o`0002Kooooo0_l0000:ooooo`?o
0000LOooool009Cooooo0_l0000Fooooo`03o`000?oooooooooo017ooooo0_l000000ooooooo0000
o`00000Sooooo`;o00001oooool2o`0000;ooooo0_l0001aooooo`00R_ooool2o`0000Sooooo0_l0
000Fooooo`03o`000?oooooooooo013ooooo0_l00002ooooo`;o00008oooool2o`0000Gooooo1?l0
00000ooooooo0000o`00001booooo`00R_ooool2o`00023ooooo0ol0000@ooooo`?o0000;Oooool2
o`0000?ooooo0_l0001booooo`00[?ooool00ol0003oooooooooo`0@ooooo`?o00009oooool6o`00
07Wooooo002/ooooo`03o`000?oooooooooo017ooooo0_l0000Wooooo`Ko0000NOooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00Co0000oooooooooooooooo0_l0000hooooo`;o0000
2?ooool2o`0007;ooooo002/ooooo`04o`000?ooooooooooooooo`;o0000>?ooool2o`0000Oooooo
0ol0001booooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000
1?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool04Oooool2o`0002_o
oooo0_l00004ooooo`;o0000Loooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`0Aooooo`;o000000?oooooo`000?l000008_ooool2o`0000Cooooo0ol0001hoooo
o`00ROooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0
003oooooooooo`03ooooo`?o00004?ooool2o`0000;ooooo0_l0000Rooooo`;o00001Oooool2o`00
00;ooooo0_l0001dooooo`00ROooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q
8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00;o00003_ooool2o`00
02_ooooo1?l00002ooooo`?o0000Loooool008Wooooo00?o0000ooooooooool00_l00009ooooo`;o
00000oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0
003oooooooooo`02o`0003Wooooo1?l00004ooooo`?o0000Loooool008Wooooo00?o410@oooooooo
ool00_l00009ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0>oooool2o`0007cooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`02o`000;Oooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnH
V9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo00;o00004Oooool2
o`000:Cooooo002/ooooo`03o`000?oooooooooo01?ooooo0_l0000Uooooo`;o00001Oooool2o`00
07Kooooo002/ooooo`03o`000?oooooooooo017ooooo0_l0000Uooooo`Co00000oooool4o`0007Ko
oooo002/ooooo`03o`000?oooooooooo017ooooo0_l0000Uooooo`;o00001Oooool2o`0007Sooooo
002/ooooo`?o0000@_ooool4o`0007?ooooo002/ooooo`03o`000?oooooooooo04;ooooo1?l0001c
ooooo`00VOooool2o`00017ooooo00?o0000ooooooooool0^Oooool008cooooo0_l00009ooooo`Co
00004Oooool2o`00017ooooo0_l0000Xooooo`;o00001oooool2o`0007Cooooo002<ooooo`;o0000
2Oooool2o`0001?ooooo0_l0000Aooooo`;o0000:?ooool3o`0000?ooooo0_l000000ooooooo0000
o`00001dooooo`00S?ooool2o`0001kooooo00?o0000ooooooooool04?ooool2o`0002Wooooo0ol0
0002ooooo`Go0000M?ooool008cooooo0_l0000Nooooo`03o`000?oooooooooo013ooooo0_l0000Z
ooooo`;o000000?oooooo`000?l000001?l0001dooooo`00[?ooool00ol0003oooooooooo`0=oooo
o`;o000000Coooooo`000?l0003o0000;?ooool2o`0007Sooooo002<ooooo`;o00002oooool2o`00
017ooooo0ol0000=ooooo`;o00000_ooool2o`000:Kooooo002<ooooo`;o00002oooool2o`00017o
oooo00?o0000ooooooooool02oooool2o`0000?ooooo0_l0000]ooooo`;o0000N?ooool00:cooooo
00?o0000ooooooooool02oooool2o`0000?ooooo0_l0000Yooooo`;o00000_ooool2o`0007Sooooo
002>ooooo`;o00006oooool2o`0003gooooo1_l0001hooooo`00S_ooool2o`0000cooooo0_l0000=
ooooo`;o0000>?ooool2o`0000Gooooo0_l0001jooooo`00W?ooool2o`0000cooooo0ol0000=oooo
o`;o0000:Oooool2o`000004ooooool0003o0000o`0007gooooo001mooooo`;o00007_ooool3o`00
00Gooooo0_l00003ooooo`?o00003Oooool2o`0002cooooo0ol000000ooooooo0000o`00001joooo
o`00OOooool2o`0001kooooo0ol00005ooooo`;o00001Oooool00ol0003oooooooooo`0mooooo`;o
0000N_ooool008gooooo0_l0000Booooo`?o00000oooool2o`0000?ooooo0ol0000jooooo`;o0000
00?oooooo`000?l00000N_ooool007gooooo0_l0000>ooooo`;o00004Oooool4o`0000?ooooo0_l0
0003ooooo`03o`000?oooooooooo00kooooo0_l0000Zooooo`;o000000?oooooo`000?l00000N_oo
ool007gooooo0_l0000Qooooo`;o00001_ooool2o`0000;ooooo00?o0000ooooooooool03_ooool2
o`0002kooooo0_l0001iooooo`00YOooool2o`000003ooooool0003o000000;ooooo00?o0000oooo
ooooool03?ooool2o`0002Gooooo0_l00009ooooo`;o0000NOooool00:;ooooo0_l000000ooooooo
0000o`000005ooooo`03o`000?oooooooooo00cooooo0_l0000Uooooo`;o0000Q?ooool00:;ooooo
0_l00008ooooo`03o`000?oooooooooo00Sooooo0_l000000ooooooo0000o`00002/ooooo`00[?oo
ool00ol0003oooooooooo`07ooooo`Ko0000;?ooool2o`0007kooooo002Aooooo`;o00004?ooool2
o`0000Oooooo00?o0000ooooooooool01oooool4o`0002cooooo1?l0001nooooo`00TOooool2o`00
013ooooo0_l00007ooooo`?o00002?ooool2o`0002gooooo0_l00003ooooo`;o0000Noooool00:co
oooo00?o0000ooooooooool02?ooool2o`0002kooooo0_l000001?oooooo0000o`000?l0001koooo
o`00[?ooool00ol0003oooooooooo`08ooooo`;o0000;_ooool2o`000003ooooool0003o000007co
oooo002/ooooo`03o`000?oooooooooo00Sooooo0_l0002_ooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool0<Oooool2o`0000Kooooo0_l00000
0ooooooo0000o`00001kooooo`00T?ooool2o`000004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`08ooooo`;o00009ooo
ool2o`0000Kooooo1Ol0001kooooo`00TOooool2o`000003oooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool02?ooool2o`0002Kooooo0_l00009
ooooo`;o0000O?ooool0097ooooo0_l00002ooooo`03oa0@4?oooooooooo00kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0`ooooo`;o00001?ooool2o`000003ooooool0003o0000
07kooooo002Aooooo`03o`000?oooooo000000;o00003oooool00omgMgOo<S8booooo`04ooooo`?o
0000=_ooool2o`000003ooooool0003o000007kooooo002Aooooo`03o`000?oooooo000000;o0000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0=_ooool2o`00087o
oooo002Aooooo`05oa0@4?oooooo0000o`000?l@41003?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Gooooo0_l000000ooooooo0000o`00002_ooooo`00TOooool01OmgMgOoV9RH
o`000?l0003oMgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`;o
000000?oooooo`000?l00000[oooool0097ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co
00001_ooool00ol0003oooooooooo`2iooooo`00Toooool2o`0001Oooooo00?o0000ooooooooool0
^Oooool009?ooooo1?l0000Eooooo`03o`000?oooooooooo00;o0000;Oooool2o`0008Sooooo002E
ooooo`;o00005Oooool00ol0003oooooooooo`03o`0002cooooo0_l00028ooooo`00[?ooool8o`00
02_ooooo0_l00027ooooo`00[?ooool00ol0003oooooooooo`02o`000003ooooool0003o000002_o
oooo0_l00003ooooo`;o0000P_ooool00:cooooo00?o0000ooooooooool00oooool2o`0002Sooooo
0_l00006ooooo`;o0000P_ooool00:cooooo00?o0000ooooooooool0;Oooool2o`0008[ooooo0020
ooooo`;o0000:_ooool00ol0003oooooooooo`2iooooo`00P?ooool2o`0001?ooooo0_l0000Eoooo
o`03o`000?oooooooooo00;o0000:?ooool3o`0008cooooo002Dooooo`?o000000?oooooo`000?l0
00004_ooool00ol0003oooooooooo`02o`0002Sooooo0ol00006ooooo`;o0000Q?ooool009Cooooo
0_l00002ooooo`;o00004_ooool00ol0003oooooooooo`02ooooo`;o00009_ooool2o`0000Cooooo
0_l000000ooooooo0000o`000024ooooo`00U?ooool3o`0001Gooooo0ol00002ooooo`;o00009Ooo
ool4o`0000?ooooo0_l00027ooooo`00UOooool2o`0001Gooooo00?o0000ooooooooool00_l0000W
ooooo`Co0000S?ooool0087ooooo0_l0000Booooo`;o00005Oooool00ol0003oooooooooo`02o`00
02Oooooo0_l0002>ooooo`00POooool2o`0002Wooooo00?o0000ooooooooool0;?ooool2o`0000?o
oooo0_l00026ooooo`00V?ooool2o`0001;ooooo00?o0000ooooooooool0;?ooool4o`000003oooo
ool0003o000008Kooooo002Hooooo`;o00004_ooool00ol0003oooooooooo`0Xooooo`;o00001?oo
ool2o`0008Wooooo002Qooooo`Co00001_ooool2o`0002[ooooo0_l0002?ooooo`00Voooool2o`00
00;ooooo1_l00005ooooo`?o0000;_ooool2o`0008_ooooo002Kooooo`[o00001Oooool5o`0002co
oooo0_l0002;ooooo`00WOooool2o`0000Cooooo0_l00002ooooo`;o00000oooool00ol0003ooooo
ooooo`2iooooo`00VOooool3o`0000Gooooo0_l00004ooooo`;o00000oooool00ol0003ooooooooo
o`0Wooooo`;o0000T?ooool009Wooooo0ol000000ooooooo0000o`000002ooooo`;o00002Oooool0
0ol0003oooooooooo`0Wooooo`;o0000T?ooool009gooooo0_l0000=ooooo`03o`000?oooooooooo
02Cooooo0_l0002Cooooo`00[?ooool00ol0003oooooooooo`0Tooooo`;o0000Toooool00:?ooooo
0_l000000ooooooo0000o`000004ooooo`03o`000?oooooooooo0;Wooooo002Sooooo`;o000000?o
ooooo`000?l000001?ooool00ol0003oooooooooo`2iooooo`00Woooool2o`0000_ooooo00?o0000
ooooooooool0^Oooool009oooooo0_l0000;ooooo`?o0000^Oooool00:cooooo00?o0000oooooooo
ool09Oooool2o`0009;ooooo002/ooooo`03o`000?oooooooooo02Gooooo0_l0002Booooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0Oooooo`;o0000V?ooool0
08Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Oooooo`;o0000V?oo
ool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYoooo
o`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool08_ooool2o`0009Gooooo0029
ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool08_ooool2o`0009Gooooo0029ooooo`05o`000?oooooo
ooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0
002iooooo`00ROooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool07oooool2o`0009Sooooo
0029ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool07oooool2o`0009Sooooo0029ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Rooooo`;o0000UOooool008Wooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool08_ooool2o`0009Go
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo01_ooooo0_l0
002Looooo`00[?ooool00ol0003oooooooooo`0Kooooo`;o0000W?ooool00:cooooo0ol0000Hoooo
o`;o0000Woooool00:cooooo00?o0000ooooooooool06?ooool2o`0009oooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo01So
oooo0_l0002Oooooo`00[?ooool00ol0003oooooooooo`0Hooooo`;o0000Woooool00:cooooo0ol0
000Iooooo`;o0000W_ooool00:cooooo00?o0000ooooooooool06Oooool2o`0009kooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`03o`000?oooooooooo00oooooo0_l0002Xooooo`00[?ooool00ol0003o
ooooooooo`0?ooooo`;o0000Z?ooool00:cooooo0ol0002iooooo`00[?ooool00ol0003ooooooooo
o`0<ooooo`;o0000Zoooool00:cooooo00?o0000ooooooooool03?ooool2o`000:_ooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00gooooo0_l0002Zooooo`00
[?ooool00ol0003oooooooooo`0=ooooo`?o0000ZOooool00:cooooo00?o0000ooooooooool03_oo
ool2o`000:Wooooo002?ooooo`?o00006_ooool00ol0003oooooooooo`2iooooo`00Soooool3o`00
01[ooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooo
ooooo`07ooooo`?o0000[oooool00:cooooo00?o0000ooooooooool01oooool3o`000:oooooo002/
ooooo`03o`000?oooooooooo00Sooooo0_l0002_ooooo`00Toooool2o`0001Oooooo00?o0000oooo
ooooool00oooool2o`000;Cooooo002Cooooo`;o00003Oooool4o`000003oa0@4?oooooooooo00?o
oooo00?o0000ooooooooool00oooool2o`000;Cooooo002Tooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0^Oooool00:Cooooo00?o0000ooooooooool01Oooool3o`000;Wooooo002T
ooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03
o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Rooooo`03oeEEEOmV
IVKo00000<?ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
002Zooooo`04oa0@4?l0003o0000o`000;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[
ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`06o`000?mgMgOo0000o`000?mEEEGok^k^]ooo
ool00:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomEEEFgooooo`00Zoooool00ol0003ok^k^oooo
o`02ooooo`03o`000?oooooooooo0;Gooooo002[ooooo`03o`000?o^k^kooooo00;ooooo00?o0000
ooooooooool0]Oooool00:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomVIVJgooooo`00Z_ooool0
0ol@413o0000ogMgM`02o`000003ofIVI_o^k^kooooo0;Kooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.39551 .3214 Mdot
.40694 .22397 Mdot
.48475 .62895 Mdot
.42381 .39259 Mdot
.58699 .46753 Mdot
.40112 .69631 Mdot
.47153 .3272 Mdot
.71774 .38954 Mdot
.70943 .46149 Mdot
.48734 .22781 Mdot
.53037 .30398 Mdot
.72944 .48354 Mdot
.43967 .10353 Mdot
.47843 .21478 Mdot
.71477 .59876 Mdot
.43453 .30715 Mdot
.48555 .85044 Mdot
.44077 .10066 Mdot
.5625 .36856 Mdot
.56363 .14391 Mdot
.51375 .10871 Mdot
.47089 .08704 Mdot
.53566 .15141 Mdot
.46778 .07349 Mdot
.71819 .6161 Mdot
.59748 .55715 Mdot
.55889 .39715 Mdot
.57094 .41904 Mdot
.59325 .18761 Mdot
.44339 .11631 Mdot
.5764 .20165 Mdot
.70645 .41723 Mdot
.71986 .44509 Mdot
.42464 .77829 Mdot
.45312 .85646 Mdot
.62359 .26508 Mdot
.67417 .34224 Mdot
.56832 .42334 Mdot
.64718 .2976 Mdot
.73106 .45088 Mdot
.73369 .54721 Mdot
.44769 .84376 Mdot
.4091 .73278 Mdot
.38509 .53626 Mdot
.38838 .59207 Mdot
.5938 .50188 Mdot
.52582 .3006 Mdot
.68963 .35339 Mdot
.58462 .65022 Mdot
.62779 .25741 Mdot
.69314 .37147 Mdot
.63782 .26211 Mdot
.61297 .91102 Mdot
.40748 .71506 Mdot
.44941 .85781 Mdot
.71484 .46366 Mdot
.7222 .41612 Mdot
.51296 .81742 Mdot
.68162 .34462 Mdot
.39072 .62435 Mdot
.59191 .54331 Mdot
.72581 .65582 Mdot
.65917 .33332 Mdot
.47309 .73873 Mdot
.71538 .5396 Mdot
.70958 .42035 Mdot
.49795 .24426 Mdot
.45947 .24986 Mdot
.55898 .36959 Mdot
.50232 .08967 Mdot
.55692 .74834 Mdot
.48563 .31898 Mdot
.51465 .27864 Mdot
.47462 .22723 Mdot
.65937 .3341 Mdot
.45152 .60223 Mdot
.61209 .91207 Mdot
.56664 .6628 Mdot
.62729 .24276 Mdot
.51865 .78567 Mdot
.60006 .23293 Mdot
.45626 .10147 Mdot
.4281 .36544 Mdot
.45897 .85958 Mdot
.71281 .38698 Mdot
.41542 .4609 Mdot
.58775 .46992 Mdot
.58202 .57625 Mdot
.54287 .76595 Mdot
.46789 .24245 Mdot
.71251 .63607 Mdot
.65955 .82759 Mdot
.46138 .73809 Mdot
.59141 .50837 Mdot
.45512 .72571 Mdot
.68657 .78344 Mdot
.47857 .21562 Mdot
.70217 .43135 Mdot
.61297 .91287 Mdot
.56733 .72006 Mdot
.40803 .23633 Mdot
.56745 .71293 Mdot
.72681 .52122 Mdot
.38626 .42224 Mdot
.54912 .14861 Mdot
.42259 .77256 Mdot
.52964 .79783 Mdot
.56568 .37347 Mdot
.4624 .73956 Mdot
.52209 .11563 Mdot
.47258 .21766 Mdot
.41816 .50744 Mdot
.70685 .42615 Mdot
.57709 .17189 Mdot
.5318 .48579 Mdot
.58593 .58957 Mdot
.70282 .36384 Mdot
.70293 .37546 Mdot
.68537 .40186 Mdot
.45376 .08505 Mdot
.73572 .61191 Mdot
.55997 .18277 Mdot
.5839 .17074 Mdot
.51238 .10237 Mdot
.43536 .31856 Mdot
.59678 .20307 Mdot
.69436 .76377 Mdot
.47201 .09967 Mdot
.51176 .64635 Mdot
.49939 .10016 Mdot
.42767 .16005 Mdot
.73025 .51929 Mdot
.41818 .79229 Mdot
.40477 .71115 Mdot
.6011 .19517 Mdot
.64316 .25777 Mdot
.60097 .20531 Mdot
.51746 .28624 Mdot
.72279 .49052 Mdot
.7198 .58078 Mdot
.68698 .7535 Mdot
.43377 .67028 Mdot
.55677 .35425 Mdot
.4914 .84642 Mdot
.56504 .14921 Mdot
.70907 .37818 Mdot
.57799 .5189 Mdot
.58367 .57365 Mdot
.7485 .54034 Mdot
.57673 .68946 Mdot
.53855 .30977 Mdot
.45513 .08024 Mdot
.47751 .31424 Mdot
.39268 .38636 Mdot
.65374 .29021 Mdot
.6515 .30446 Mdot
.70852 .39525 Mdot
.67956 .36455 Mdot
.6512 .28197 Mdot
.59452 .59538 Mdot
.61542 .21833 Mdot
.7387 .45297 Mdot
.62242 .27018 Mdot
.39228 .53842 Mdot
.43247 .15287 Mdot
.70972 .38591 Mdot
.54676 .14227 Mdot
.55892 .37201 Mdot
.63127 .23673 Mdot
.63727 .28748 Mdot
.42127 .52717 Mdot
.56264 .39885 Mdot
.58596 .52996 Mdot
.58039 .48943 Mdot
.72054 .49184 Mdot
.68648 .78143 Mdot
.39424 .36876 Mdot
.52447 .57335 Mdot
.6185 .23367 Mdot
.61925 .21737 Mdot
.73412 .4797 Mdot
.43957 .27965 Mdot
.73433 .54994 Mdot
.50085 .68738 Mdot
.70841 .48692 Mdot
.68327 .78114 Mdot
.69784 .36675 Mdot
.73789 .45941 Mdot
.41751 .77759 Mdot
.73614 .59795 Mdot
.55986 .14137 Mdot
.47124 .73352 Mdot
.71503 .67789 Mdot
.71628 .39549 Mdot
.74143 .52698 Mdot
.72866 .51661 Mdot
.58998 .51558 Mdot
.67728 .81 Mdot
.53486 .79489 Mdot
.5258 .54637 Mdot
.52575 .5499 Mdot
.49081 .32546 Mdot
.58551 .5179 Mdot
.66714 .82794 Mdot
.43517 .14402 Mdot
.4715 .72569 Mdot
.3927 .61361 Mdot
.42687 .63956 Mdot
.51833 .6436 Mdot
.52005 .27622 Mdot
.42368 .14471 Mdot
.57175 .64609 Mdot
.55003 .14698 Mdot
.45934 .24228 Mdot
.43984 .13655 Mdot
.56839 .65249 Mdot
.7394 .46656 Mdot
.52165 .62585 Mdot
.38983 .40907 Mdot
.72776 .42741 Mdot
.58824 .57545 Mdot
.69403 .40263 Mdot
.53298 .12385 Mdot
.61541 .26203 Mdot
.48037 .23898 Mdot
.58353 .46081 Mdot
.38627 .38959 Mdot
.42812 .6232 Mdot
.71578 .59582 Mdot
.74202 .59325 Mdot
.42322 .3774 Mdot
.44073 .4402 Mdot
.63655 .86854 Mdot
.5437 .75184 Mdot
.54583 .34215 Mdot
.73173 .61979 Mdot
.56424 .40234 Mdot
.38652 .40939 Mdot
.52015 .12199 Mdot
.41923 .1871 Mdot
.72028 .67002 Mdot
.42279 .80362 Mdot
.54596 .13628 Mdot
.55666 .74866 Mdot
.7019 .38256 Mdot
.44134 .68626 Mdot
.66952 .34359 Mdot
.47931 .84627 Mdot
.55904 .74356 Mdot
.6537 .31414 Mdot
.73913 .53784 Mdot
.53162 .49135 Mdot
.44937 .70149 Mdot
.67751 .3706 Mdot
.58464 .62014 Mdot
.5631 .40444 Mdot
.48239 .87876 Mdot
.44929 .59325 Mdot
.72322 .44203 Mdot
.68493 .3451 Mdot
.56997 .69361 Mdot
.54487 .33906 Mdot
.61573 .25977 Mdot
.52288 .59686 Mdot
.56158 .72195 Mdot
.40281 .27334 Mdot
.54008 .34097 Mdot
.39083 .46973 Mdot
.63379 .28529 Mdot
.56693 .68041 Mdot
.60532 .22278 Mdot
.45683 .86871 Mdot
.46732 .22291 Mdot
.54623 .73973 Mdot
.64676 .27307 Mdot
.43171 .30694 Mdot
.57148 .38377 Mdot
.6971 .3859 Mdot
.50067 .23535 Mdot
.3887 .50833 Mdot
.61776 .2289 Mdot
.5334 .54871 Mdot
.491 .24133 Mdot
.68226 .37798 Mdot
.72703 .50015 Mdot
.56456 .36696 Mdot
.47355 .31854 Mdot
.57666 .56885 Mdot
.54853 .13155 Mdot
.58731 .55813 Mdot
.60022 .2366 Mdot
.67693 .79097 Mdot
.68696 .37245 Mdot
.71924 .5684 Mdot
.69379 .41333 Mdot
.44246 .40888 Mdot
.66788 .30624 Mdot
.7026 .70089 Mdot
.53215 .11177 Mdot
.71558 .59185 Mdot
.56424 .69922 Mdot
.46916 .88228 Mdot
.41674 .19359 Mdot
.70427 .39764 Mdot
.72734 .57637 Mdot
.52198 .28835 Mdot
.69953 .40385 Mdot
.58588 .61882 Mdot
.52628 .51397 Mdot
.44526 .10065 Mdot
.48859 .85002 Mdot
.46856 .07743 Mdot
.74685 .54112 Mdot
.53088 .53145 Mdot
.39399 .34925 Mdot
.43065 .80183 Mdot
.71598 .54663 Mdot
.53022 .55635 Mdot
.73418 .49498 Mdot
.71153 .66479 Mdot
.70932 .71805 Mdot
.43543 .31269 Mdot
.43412 .84344 Mdot
.47373 .86817 Mdot
.6641 .34339 Mdot
.5803 .42006 Mdot
.52727 .46198 Mdot
.45594 .35024 Mdot
.52627 .80139 Mdot
.72417 .41232 Mdot
.68126 .39426 Mdot
.46596 .73986 Mdot
.43847 .11413 Mdot
.51756 .62835 Mdot
.49443 .33312 Mdot
.38836 .36002 Mdot
.41031 .753 Mdot
.39239 .54485 Mdot
.59283 .60268 Mdot
.58444 .52275 Mdot
.64017 .87579 Mdot
.57187 .66299 Mdot
.47459 .09603 Mdot
.45656 .72273 Mdot
.71799 .46562 Mdot
.55844 .39867 Mdot
.60335 .21133 Mdot
.49916 .10734 Mdot
.45466 .73241 Mdot
.56686 .64988 Mdot
.6921 .74388 Mdot
.7291 .46306 Mdot
.65714 .27727 Mdot
.62099 .25676 Mdot
.57863 .65976 Mdot
.50967 .83173 Mdot
.62915 .26868 Mdot
.5549 .73289 Mdot
.72905 .46867 Mdot
.72607 .68469 Mdot
.54762 .13783 Mdot
.72918 .52596 Mdot
.73446 .50133 Mdot
.73931 .50636 Mdot
.50397 .35882 Mdot
.5486 .73987 Mdot
.71738 .59215 Mdot
.72245 .42611 Mdot
.50561 .36334 Mdot
.58372 .20817 Mdot
.54871 .71867 Mdot
.40145 .70415 Mdot
.40505 .25318 Mdot
.70431 .44213 Mdot
.38781 .38916 Mdot
.67497 .33713 Mdot
.67708 .38636 Mdot
.53672 .15417 Mdot
.64729 .25729 Mdot
.50793 .11256 Mdot
.72014 .60078 Mdot
.68963 .42054 Mdot
.38827 .48547 Mdot
.49322 .33688 Mdot
.72048 .63025 Mdot
.55808 .73658 Mdot
.4542 .35584 Mdot
.73495 .46592 Mdot
.50531 .09308 Mdot
.52479 .43554 Mdot
.48474 .22992 Mdot
.59176 .57779 Mdot
.55092 .35757 Mdot
.68947 .34819 Mdot
.49736 .07553 Mdot
.70799 .6926 Mdot
.73466 .48147 Mdot
.46841 .8567 Mdot
.61949 .89778 Mdot
.48654 .85718 Mdot
.57985 .4721 Mdot
.57992 .44406 Mdot
.44117 .55291 Mdot
.7247 .42533 Mdot
.72902 .48526 Mdot
.55752 .39112 Mdot
.43368 .66338 Mdot
.50219 .23182 Mdot
.41969 .39017 Mdot
.74273 .54706 Mdot
.59124 .47385 Mdot
.60998 .24231 Mdot
.42045 .55399 Mdot
.54506 .32831 Mdot
.52463 .59238 Mdot
.5897 .47865 Mdot
.42783 .78776 Mdot
.53445 .30308 Mdot
.46906 .72577 Mdot
.74293 .57822 Mdot
.72276 .48235 Mdot
.49836 .56752 Mdot
.45195 .85625 Mdot
.5279 .8006 Mdot
.41319 .23133 Mdot
.54444 .72987 Mdot
.55888 .37649 Mdot
.7275 .60858 Mdot
.69893 .76789 Mdot
.3977 .28842 Mdot
.56374 .97841 Mdot
.38554 .56695 Mdot
.48135 .7291 Mdot
.70975 .50918 Mdot
.71539 .60304 Mdot
.5432 .34131 Mdot
.51605 .13077 Mdot
.63155 .8871 Mdot
.42817 .6308 Mdot
.52259 .42737 Mdot
.58051 .51631 Mdot
.60592 .23884 Mdot
.53785 .74942 Mdot
.66934 .818 Mdot
.5052 .67889 Mdot
.40856 .71684 Mdot
.47315 .86597 Mdot
.47696 .74215 Mdot
.5266 .56633 Mdot
.44449 .26222 Mdot
.71897 .39677 Mdot
.53303 .51247 Mdot
.61569 .2212 Mdot
.39874 .27365 Mdot
.38702 .45892 Mdot
.59859 .20821 Mdot
.5982 .236 Mdot
.486 .85375 Mdot
.71606 .72454 Mdot
.4843 .22866 Mdot
.72459 .4121 Mdot
.74076 .52372 Mdot
.54597 .36239 Mdot
.66323 .29293 Mdot
.55528 .70746 Mdot
.46156 .84453 Mdot
.59854 .20288 Mdot
.40131 .27345 Mdot
.56853 .39358 Mdot
.56921 .64314 Mdot
.43917 .82133 Mdot
.74144 .60776 Mdot
.3931 .58435 Mdot
.46299 .63755 Mdot
.39887 .65133 Mdot
.53011 .76683 Mdot
.492 .32393 Mdot
.45607 .25753 Mdot
.41358 .74906 Mdot
.42312 .8005 Mdot
.52988 .51308 Mdot
.58001 .63201 Mdot
.71016 .42333 Mdot
.58475 .43912 Mdot
.40249 .27819 Mdot
.54005 .30367 Mdot
.57531 .47959 Mdot
.51252 .38661 Mdot
.56855 .97811 Mdot
.5178 .41299 Mdot
.39618 .2878 Mdot
.69857 .4457 Mdot
.61809 .25877 Mdot
.56081 .37452 Mdot
.60816 .21657 Mdot
.73247 .48094 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00XOooool2o`0000Wooooo00?o0000ooooooooool0^Oooool00:7ooooo0_l00008oooo
o`Co0000^Oooool009gooooo0_l00002ooooo`;o00002?ooool2o`000;_ooooo002Mooooo`;o0000
3Oooool00ol0003oooooooooo`2iooooo`00W?ooool2o`0000kooooo00?o0000ooooooooool0^Ooo
ool009cooooo0_l00004ooooo`;o00002?ooool00ol0003oooooooooo`2iooooo`00X_ooool2o`00
00Sooooo0_l0002jooooo`00[?ooool3o`000;Wooooo002Sooooo`;o00001oooool3o`000;Wooooo
002Hooooo`?o00000_ooool2o`0000?ooooo0ol00006ooooo`Co0000^Oooool009Sooooo0ol00002
ooooo`;o00000oooool2o`0000Oooooo0_l00003ooooo`;o0000]_ooool009Sooooo0_l0000Aoooo
o`;o00000oooool2o`000;Kooooo002[ooooo`;o00000oooool2o`000;Kooooo002/ooooo`03o`00
0?oooooo000000?o00001?ooool2o`000;3ooooo002Gooooo`Co00004Oooool01?l0003oooooo`00
0?l00003ooooo`;o000000?oooooo`000?l00000/?ooool008Wooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q0_ooool5o`000003onk^k_oooooooooo00?ooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo00Cooooo0_l0002cooooo`00ROooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`03ooooo`;o0000]?ooool0087ooooo1_l00002ooooo`05oa0@
4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?o
oooo0ol00003ooooo`;o00000_ooool2o`000;3ooooo0029ooooo`05o`000?ooooooooooooooool0
00003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool01oooool2o`000;3ooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGo
c<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`02oooo
o`;o00002Oooool2o`000:[ooooo0029ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onY
ZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool2o`00
00Wooooo0_l0002Zooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo0_l00003oooo
o`03oc8b<_oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<oooo
o`;o0000Zoooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0:ooooo`Ko00001?ooool4o`00
00Kooooo00?o0000ooooooooool03?ooool2o`000:_ooooo002Fooooo`;o00005?ooool00ol0003o
ooooooooo`0<ooooo`;o00000_ooool4o`000:Gooooo002Booooo`;o00000_ooool2o`0001Cooooo
00?o0000ooooooooool03?ooool3o`000003ooooool0003o000000;o0000YOooool009;ooooo0_l0
000Hooooo`03o`000?oooooooooo00gooooo0_l00003ooooo`;o0000YOooool009Gooooo0_l0000E
ooooo`?o00002?ooool2o`0000?ooooo0_l00003ooooo`;o0000YOooool009Gooooo0_l0000Eoooo
o`03o`000?oooooooooo00Sooooo0ol0002^ooooo`00[?ooool00ol0003oooooooooo`09ooooo`;o
0000[_ooool009Cooooo0_l0000Fooooo`03o`000?oooooooooo0;Wooooo002Dooooo`;o00005_oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`0Hooooo`;o0000Woooool00:cooooo00?o0000ooooooooool05_ooool4o`0009oo
oooo002/ooooo`?o00005_ooool2o`000:7ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`03o`000?oooooooooo013ooooo0_l0002Wooooo`00[?ooool00ol0003oooooooooo`0@oooo
o`;o0000Yoooool0097ooooo0_l0000Iooooo`03o`000?oooooooooo01_ooooo0_l0002Looooo`00
TOooool2o`0001Wooooo00?o0000ooooooooool06oooool2o`0009cooooo002@ooooo`;o00006_oo
ool00ol0003oooooooooo`0Nooooo`;o0000VOooool0093ooooo0_l0000Jooooo`03o`000?oooooo
oooo01kooooo0_l0002Iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo01Ko
oooo0_l00005ooooo`;o0000V_ooool00:cooooo00?o0000ooooooooool05_ooool2o`0000Gooooo
0ol0002Iooooo`00[?ooool00ol0003oooooooooo`0Hooooo`;o00000oooool3o`0009Wooooo002/
ooooo`03o`000?oooooooooo01Sooooo0_l00003ooooo`Co0000V?ooool00:Cooooo0_l00006oooo
o`03o`000?oooooooooo01oooooo0ol0002Gooooo`00Xoooool3o`0000Kooooo00?o0000oooooooo
ool08?ooool2o`000004ooooool0003o0000o`0009?ooooo002Sooooo`;o00001oooool00ol0003o
ooooooooo`0Oooooo`;o00000_ooool3o`0009?ooooo002=ooooo`;o00004_ooool2o`0000Wooooo
0ol0000Oooooo`;o00000_ooool2o`0009Cooooo002=ooooo`;o00004_ooool4o`000004ooooool0
003o0000o`0000?ooooo00?o0000ooooooooool0^Oooool008oooooo0_l0000Booooo`;o000000Co
ooooo`000?l0003o00000oooool2o`0002Cooooo0_l0002Dooooo`00Soooool2o`0001Kooooo0_l0
0003ooooo`;o00007oooool2o`0000?ooooo0ol0002Cooooo`00SOooool2o`0001gooooo0_l0000N
ooooo`?o00001?ooool2o`0000;ooooo0_l0002?ooooo`00SOooool2o`0001Kooooo0_l00005oooo
o`;o00007_ooool5o`0000Kooooo0_l0002?ooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B401?oooooo0000o`000?ooool6o`0000;ooooo0_l000000ooooooo0000ooooo`0Q
ooooo`?o00001?ooool2o`00093ooooo002Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@04ooooool0003o0000ooooo`;o00000_ooool01?mgMgOo<S8booooooooool4o`0002?ooooo
0_l00004ooooo`;o0000T?ooool008Wooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@4100
2?ooool2o`0000Kooooo00?o0000ooooooooool00_ooool2o`000;_ooooo002Aooooo`05o`000?oo
ooooooooooooool000002?ooool2o`0000Gooooo00?oMgMgoc8b<_ooool01?ooool3o`000;Wooooo
002<ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo0;Wooooo002<ooooo`;o00000oooool01Ol@413ooooo
oooooooooooo410@00Oooooo0_l00003ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool09?ooool5o`0000?ooooo0ol0002:ooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oo
oooo0_l00003ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08oooool6o`000003
ooooool0003o000000?o0000R_ooool0097ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`;o
00001oooool4o`0000Kooooo00?o0000ooooooooool08oooool4o`0000?ooooo0_l0002=ooooo`00
VOooool2o`00017ooooo00?o0000ooooooooool09Oooool2o`0009;ooooo002/ooooo`03o`000?oo
oooooooo02Gooooo1?l0002@ooooo`00R_ooool3o`0001oooooo00?o0000ooooooooool09Oooool4
o`0000Cooooo0_l0002:ooooo`00R_ooool3o`0001oooooo0ol00003ooooo`;o0000:?ooool2o`00
0003ooooool0003o000008Oooooo002;ooooo`;o00002oooool2o`0001;ooooo00Co0000oooooooo
oooooooo1?l0000[ooooo`;o0000Qoooool008_ooooo0_l0000;ooooo`;o00004_ooool01?l0003o
ooooooooooooool2o`0002_ooooo0_l00029ooooo`00[?ooool00ol0003oooooooooo`02ooooo`;o
00009Oooool2o`0000?ooooo0_l00029ooooo`00ROooool3o`00023ooooo00?o0000ooooooooool0
0_ooool4o`0002?ooooo0ol0002=ooooo`00ROooool3o`00023ooooo00?o0000ooooooooool01?oo
ool2o`0002Cooooo0_l00003ooooo`;o0000R?ooool00:cooooo00?o0000ooooooooool0;oooool2
o`000003ooooool0003o000008Gooooo002/ooooo`03o`000?oooooooooo02gooooo0_l00003oooo
o`;o0000QOooool00:cooooo0ol00005ooooo`;o00009_ooool2o`0008[ooooo002/ooooo`03o`00
0?oooooooooo00Gooooo1ol0000Sooooo`;o0000R?ooool009Gooooo0ol0000Dooooo`03o`000?oo
oooooooo00Oooooo1Ol0000Sooooo`;o00000oooool2o`0008?ooooo002Eooooo`?o00005?ooool0
0ol0003oooooooooo`09ooooo`;o0000:Oooool2o`0008?ooooo002Fooooo`;o00005?ooool00ol0
003oooooooooo`09ooooo`;o0000[_ooool009Kooooo0_l0000<ooooo`;o00001_ooool00ol0003o
ooooooooo`0_ooooo`;o0000R?ooool009Kooooo0_l0000;ooooo`?o000000?oooooo`000?l00000
0oooool00ol0003oooooooooo`0_ooooo`;o0000R?ooool008Wooooo0_l0000;ooooo`;o00002ooo
ool2o`0000;ooooo0_l00003ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`;o00007_ooool2
o`000004ooooool0003o0000o`000;Wooooo002Rooooo`;o00001Oooool2o`000003ooooool0003o
oooo00cooooo0_l0002/ooooo`00X_ooool2o`0000Sooooo00?o0000ooooooooool02oooool2o`00
0:cooooo002Zooooo`?o0000<oooool2o`0008Kooooo002Yooooo`Co0000<oooool2o`0000?ooooo
0_l00021ooooo`00ZOooool2o`000003ooooool0003ooooo00_ooooo0ol0000Yooooo`;o0000POoo
ool00:cooooo00?o0000ooooooooool02_ooool4o`0002Gooooo1Ol00021ooooo`00[?ooool00ol0
003oooooooooo`0;ooooo`?o00009Oooool5o`000004ooooool0003o0000o`0007gooooo0029oooo
o`;o00008Oooool00ol0003oooooooooo`0iooooo`Co0000O?ooool008Wooooo0_l0000Booooo`;o
00003Oooool3o`0003_ooooo0_l0001looooo`00W?ooool3o`0000gooooo00?o0000ooooooooool0
3oooool2o`0002[ooooo0_l0001looooo`00W?ooool2o`0000kooooo0ol0000=ooooo`Co0000:_oo
ool2o`0007cooooo0027ooooo`;o00008oooool3o`0000gooooo0_l0002Zooooo`00Qoooool2o`00
02?ooooo0ol0000<ooooo`;o0000:_ooool2o`0000Kooooo0_l0001gooooo`00ROooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo00?o8B4Qo`000?l000000oooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`?o00003?ooool2o`0000Cooooo0_l0000Tooooo`;o00001?ooool4
o`0007Oooooo0029ooooo`;o000000?ooooooiRHV?mgMgL01Oooool00olQ8B7o0000o`000003oooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo013ooooo1?l0000Sooooo`;o00001Oooool2o`0007Wooooo0021ooooo`Ko00000_ooool2o`00
00;ooooo00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool04?ooool4o`0002?ooooo0_l000000ooooooo0000o`000002o`00
07_ooooo0029ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07oooo
o`03ogMgMolb<S;ooooo00Cooooo0ol0000@ooooo`Co00009_ooool4o`0000;ooooo0_l0001goooo
o`00ROooool01Ol0003ooooooooooooooooo000000Cooooo0_l00008ooooo`03ogMgMomVIVKooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo013ooooo0ol0000V
ooooo`;o00001Oooool4o`0007Gooooo0029ooooo`05oa0@4?ooooooooooooooool@41001?ooool2
o`0000Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo03Wooooo0_l00004ooooo`;o000000?oooooo`000?l00000MOooool008Sooooo0_l000001?nH
V9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo01Cooooo0_l0000Qooooo`;o00001Oooool3o`000003ooooool0
003o000007Gooooo0027ooooo`?o000000Co<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`00
0?lQ8B7oc<c<00Cooooo1?l00006ooooo`04o`000?ooooooooooooooo`;o00004Oooool2o`00027o
oooo0_l00005ooooo`;o00000_ooool3o`0007Cooooo0026ooooo`?o00002?ooool2o`0001Wooooo
00Co0000oooooooooooooooo0_l0000=ooooo`;o0000<Oooool3o`0007?ooooo0026ooooo`;o0000
2Oooool3o`0001Sooooo00?o0000ooooooooool04?ooool2o`000003ooooool0003o000002?ooooo
0_l00007ooooo`;o000000?oooooo`000?l00000Loooool009;ooooo0_l0000Hooooo`03o`000?oo
oooooooo013ooooo0_l000000ooooooo0000o`00000Sooooo`;o00001_ooool3o`000004ooooool0
003o0000o`0007;ooooo002/ooooo`?o00004?ooool3o`0002gooooo0_l00003ooooo`;o0000L_oo
ool00:cooooo00?o0000ooooooooool04?ooool4o`0002Kooooo0_l000001?oooooo0000o`000?l0
001iooooo`00[?ooool00ol0003oooooooooo`0Aooooo`?o00009_ooool2o`000004ooooool0003o
0000o`0007Wooooo0026ooooo`?o00004?ooool2o`00017ooooo00?o0000ooooooooool0^Oooool0
08Kooooo0ol0000@ooooo`;o00004Oooool00ol0003oooooooooo`02ooooo`;o0000>Oooool2o`00
00Sooooo0_l0001`ooooo`00[?ooool00ol0003oooooooooo`02ooooo`;o0000>Oooool2o`0000Oo
oooo0ol0001`ooooo`00[?ooool00ol0003oooooooooo`0Dooooo`;o0000:oooool2o`0000?ooooo
0_l0001aooooo`00Q_ooool2o`0002Cooooo00?o0000ooooooooool05?ooool2o`000003ooooool0
003o000002;ooooo0_l00004ooooo`?o0000MOooool008Kooooo0_l0000Tooooo`?o00004oooool2
o`0000;ooooo0_l0000Rooooo`;o00001Oooool2o`0000?ooooo0_l0001`ooooo`00[?ooool00ol0
003oooooooooo`04ooooo`;o00003Oooool2o`0002cooooo0ol00002ooooo`Co0000Koooool00:co
oooo00?o0000ooooooooool01?ooool2o`0003Wooooo1?l00003ooooo`Co0000Koooool00:cooooo
00?o0000ooooooooool0?oooool2o`0007Sooooo002/ooooo`03o`000?oooooooooo00Gooooo0_l0
002booooo`00V?ooool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`0001;ooooo0_l0002N
ooooo`00V?ooool2o`0001;ooooo00?o0000ooooooooool06Oooool2o`0002Gooooo0_l00004oooo
o`;o0000LOooool00:cooooo00?o0000ooooooooool05oooool2o`0002Gooooo1?l00003ooooo`?o
0000LOooool00:cooooo00?o0000ooooooooool05oooool2o`0002Gooooo0_l00005ooooo`;o0000
L_ooool00:cooooo0ol00019ooooo`Co0000K?ooool00:cooooo00?o0000ooooooooool0BOooool4
o`0006cooooo0026ooooo`;o00009?ooool00ol0003oooooooooo`2iooooo`002Oooool4o`000003
oa0@4?oooooooooo01Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0
003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B42ooooo`Oo00000oooool4o`000003oc8b<_oMgMgooooo01Go
oooo00?o0000ooooooooool01_ooool2o`00013ooooo0ol000000olb<S;ok^k^ooooo`04ooooo`;o
8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0<ooooo`;o000000Ooooooonk^
k_lb<S;o0000oc8b<_o^k^kooooo00;o00000_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8b
omgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_oo
ool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1?l000000ol@413oooooooooo`0Boooo
o`002oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool2o`0000;ooooo
00?oMgMgoc8b<_ooool05Oooool00ol0003oooooooooo`06ooooo`;o00004?ooool2o`000003oooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo
<S8booooo`0;ooooo`?o000000?oMgMgoiRHV?ooool00_l000000ooooooo0000o`000002ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo
01Cooooo0006o`0000Gooooo00?o0000ooooooooool04?ooool6o`0000;ooooo00Go410@oooooooo
oooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool01Oooool6o`00
00;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00Gooooo1_l00002
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool06?ooool01Ol@413o0000o`000?oooooo410@00cooooo
00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`0;ooooo`Co000000?oooooo`000?l00000
1?l0000<ooooo`03o`000?oooooooooo00gooooo00Go410@oooooooooooooooooa0@400=ooooo`03
ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Dooooo`00
2oooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7o
ooooooooo`06ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000;ooooo`;o000000?oV9RH
ob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`0Eooooo`03o`000?oooooooooo01Sooooo1Ol0000=
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool03_ooool2o`000003ooooool0003o
000000Co00002oooool00omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003_oo
ool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Wooooo00?o0000ooooooooool05?oo
ool000_ooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000kooooo00?o
EEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo
000000_ooooo0_l000000oooooooMgMgofIVIP04ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05_oo
ool00ol0003oooooooooo`0Gooooo`;o000000Coooooo`000?l0003o00003_ooool00omgMgOoIVIV
ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool00ol0003oooooooooo`02o`0000co
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003_ooool0
0omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06_ooool00ol0003ooooooooo
o`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05oa0@4?ooooooooooooooool@41003_oo
ool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool06?ooool3o`0001Oooooo0_l00002ooooo`;o
00003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400>
ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0D
ooooo`002oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool05Oooool2o`000003oooooomgMgOoV9RH00;o000000?oMgMgooooooooool02Oooool01Ol0
003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00;o00002_ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Dooooo`002Oooool00omEEEGoIVIVo`00000Jooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool5o`0000Cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00
013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?oo
ool4o`0001Oooooo00?o0000ooooooooool05Oooool2o`000003ooooooo^k^ko<S8b00;o000000?o
k^k^ooooooooool02Oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0000@ooooo`04onk^
k_l0003o0000oc8b<P?o00002_ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`Go00001?ooool4o`0001Wooooo00?oEEEEofIVI_l000005_ooool008Oooooo0_l0000Sooooo`03
o`000?oooooooooo00Oooooo0_l0000mooooo`Ko0000KOooool008Oooooo0_l0000Sooooo`03o`00
0?oooooooooo00Oooooo0_l0000hooooo`;o00001Oooool2o`0006oooooo002/ooooo`03o`000?oo
oooooooo00Oooooo0_l0000>ooooo`;o0000:?ooool2o`0000;ooooo0ol0001Vooooo`;o00000_oo
ool2o`0000Gooooo002/ooooo`03o`000?oooooooooo00Oooooo0_l0000>ooooo`;o0000;?ooool3
o`0000;ooooo0_l0001Rooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1Oooool00:cooooo00?o
0000ooooooooool0B_ooool2o`0006?ooooo00CogMgMo`000?l@413oc<c<1_ooool000Ooooooool0
001<o`0000cooooo00Cok^k^ob4Q8Ol@413ok^k^1_ooool000Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo0ol00008ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo1?l00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_oo
ool01?lQ8B7oMgMgogMgMolb<S86ooooo`001oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0;ooooo`;o00006Ooo
ool00ol0003oooooooooo`0Looooo`;o00002Oooool00ol0003oooooooooo`0Rooooo`;o00000_oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02Ooo
ool2o`0000;ooooo0_l00005ooooo`00Qoooool2o`0000Sooooo0_l0000Iooooo`03o`000?oooooo
oooo01_ooooo0_l0000Uooooo`;o00002?ooool2o`0006_ooooo0027ooooo`;o00008oooool00ol0
003oooooooooo`06ooooo`?o00004_ooool2o`0002Gooooo0_l0001eooooo`00[?ooool00ol0003o
ooooooooo`05ooooo`Co00003_ooool2o`000003ooooool0003o000002cooooo0_l0001_ooooo`00
[?ooool00ol0003oooooooooo`05ooooo`;o00003oooool6o`0002cooooo0ol0001^ooooo`00[?oo
ool00ol0003oooooooooo`0Fooooo`;o000000?oooooo`000?l00000;?ooool4o`0006kooooo002/
ooooo`?o00006?ooool2o`0002gooooo0_l00003ooooo`;o0000Joooool009;ooooo0_l0000Hoooo
o`03o`000?oooooooooo01Sooooo0_l0000^ooooo`;o00000_ooool2o`0006_ooooo002Booooo`;o
00006?ooool00ol0003oooooooooo`07ooooo`;o00004?ooool2o`0002gooooo0_l00002ooooo`;o
0000Joooool00:cooooo00?o0000ooooooooool01oooool2o`00013ooooo0_l0002Nooooo`00Q_oo
ool2o`0002Cooooo00?o0000ooooooooool0C?ooool2o`0006_ooooo0026ooooo`Co00008_ooool0
0ol0003oooooooooo`14ooooo`;o00001_ooool2o`000003ooooool0003o000006Sooooo0028oooo
o`;o00008_ooool00ol0003oooooooooo`0Kooooo`;o00009oooool2o`0000Sooooo0ol0001Xoooo
o`00R?ooool2o`0002;ooooo00?o0000ooooooooool01Oooool2o`0001Cooooo0_l0000Wooooo`;o
00002?ooool2o`0006Wooooo0028ooooo`;o00008_ooool00ol0003oooooooooo`05ooooo`;o0000
00?oooooo`000?l00000>_ooool2o`0000Cooooo0_l000000ooooooo0000o`00001Zooooo`00V?oo
ool2o`0001;ooooo0ol00005ooooo`;o000000?oooooo`000?l00000@?ooool2o`000003ooooool0
003o000006[ooooo002Aooooo`;o00001Oooool2o`0001;ooooo00?o0000ooooooooool0^Oooool0
097ooooo0_l0000Iooooo`03o`000?oooooooooo00Oooooo0_l0000@ooooo`;o00000_ooool2o`00
09[ooooo002/ooooo`03o`000?oooooooooo00Oooooo0_l0000@ooooo`;o00000_ooool2o`0009[o
oooo002/ooooo`03o`000?oooooooooo0;Wooooo0026ooooo`;o00008oooool2o`0000Oooooo0_l0
002booooo`00Q_ooool2o`0002?ooooo0_l00007ooooo`;o00003oooool2o`0002gooooo0_l0001b
ooooo`00[?ooool00ol0003oooooooooo`05ooooo`;o00003oooool4o`0002_ooooo0_l0001boooo
o`00[?ooool3o`0000Gooooo0_l0000Aooooo`Co0000;?ooool2o`0006oooooo002/ooooo`03o`00
0?oooooooooo01Sooooo1Ol0000[ooooo`;o00000oooool2o`0006[ooooo002/ooooo`03o`000?oo
oooooooo01_ooooo0_l0000Xooooo`;o00001_ooool2o`0006[ooooo0028ooooo`;o00008_ooool0
0ol0003oooooooooo`15ooooo`;o0000L_ooool008Sooooo0_l0000Rooooo`03o`000?oooooooooo
0;Wooooo0027ooooo`;o00008oooool00ol0003oooooooooo`05ooooo`;o00004_ooool2o`0002Wo
oooo0_l0001cooooo`00Qoooool2o`0001;ooooo0_l0000?ooooo`03o`000?oooooooooo00Gooooo
0_l0000Booooo`;o000000?oooooo`000?l000009_ooool2o`0000Kooooo0_l0001[ooooo`00Vooo
ool2o`0000oooooo00?o0000ooooooooool01?ooool2o`0001Kooooo0_l0000Vooooo`;o00001Ooo
ool3o`0006_ooooo002/ooooo`?o00001?ooool2o`0003gooooo1?l00004ooooo`;o0000K?ooool0
09cooooo0_l0000>ooooo`03o`000?oooooooooo01_ooooo0_l0000Vooooo`Co0000L_ooool009co
oooo0_l0000>ooooo`03o`000?oooooooooo01_ooooo0_l0000Wooooo`;o0000Loooool00:cooooo
00?o0000ooooooooool0B?ooool2o`0000;ooooo0_l0001[ooooo`00[?ooool00ol0003ooooooooo
o`18ooooo`Ko0000Joooool008Sooooo0_l0000Rooooo`03o`000?oooooooooo04Gooooo0_l00003
ooooo`;o0000KOooool008Sooooo0_l000001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5
o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01Wooooo0_l0
000Zooooo`;o0000L_ooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`0Iooooo`;o0000;_ooool2o`0006kooooo0027ooooo`;o000000Go410@oooooooooooooooo
oa0@4006ooooo`;o00001?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo
0ol0000Iooooo`;o0000;_ooool2o`0006kooooo0027ooooo`?o00000oooool00ol0003ooooooooo
o`04ooooo`;o00001Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool00_ooool4o`000;?ooooo0029ooooo`05o`000?ooooooooooooooool000001_oo
ool2o`0000Kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;o0000
0oooool00ol0003oooooooooo`02ooooo`Co0000?oooool2o`0007;ooooo0029ooooo`05oa0@4?oo
ooooooooooooool@41001_ooool2o`0000Oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`;o00000oooool00ol0003oooooooooo`0Gooooo`;o0000;?ooool2o`0007;ooooo
0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01_l0003o^[ZjoooooonHV9So410@oooo
o`;o000000?oooooo`000?ooool02?ooool00ol0003oooooooooo`0Gooooo`;o0000:_ooool2o`00
07Cooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2o`0000Cooooo00KoV9RHoa0@
4?l0003o8B4Qolc<c?ooool2o`000003ooooool0003o000000;o00001_ooool00ol0003ooooooooo
o`13ooooo`;o0000M?ooool009?ooooo0_l0000Gooooo`03o`000?oooooooooo00?ooooo0_l0000>
ooooo`;o0000Y?ooool00:cooooo00?o0000ooooooooool00_l000000ooooooo0000o`00000>oooo
o`?o0000Xoooool00:cooooo00?o0000ooooooooool00_l0000Aooooo`?o0000Xoooool008[ooooo
0_l0000Pooooo`?o00004oooool2o`0000?ooooo0_l0002Oooooo`00R_ooool2o`00023ooooo00?o
0000ooooooooool04oooool2o`0000?ooooo0_l0000]ooooo`;o0000L?ooool00:cooooo00?o0000
ooooooooool0Aoooool2o`00073ooooo002/ooooo`03o`000?oooooooooo01Oooooo0_l0002Poooo
o`00U_ooool2o`0001Cooooo00?o0000ooooooooool04oooool3o`000003ooooool0003o000002Wo
oooo0_l0001eooooo`00U_ooool2o`0001Cooooo00?o0000ooooooooool04oooool3o`0002cooooo
0_l0001eooooo`00U_ooool2o`0001Cooooo00?o0000ooooooooool0AOooool2o`0007;ooooo002F
ooooo`;o00005?ooool00ol0003oooooooooo`15ooooo`;o0000L_ooool00:cooooo0ol0002ioooo
o`00[?ooool3o`0004Cooooo0_l0001cooooo`00[?ooool3o`0001?ooooo0_l0000_ooooo`;o0000
Loooool009Sooooo0_l0000Booooo`03o`000?oooooooooo01?ooooo0_l0000booooo`;o0000L?oo
ool009Sooooo0_l0000Booooo`;o0000B?ooool2o`00073ooooo002/ooooo`;o00005oooool2o`00
0:7ooooo002/ooooo`03o`000?oooooooooo01Cooooo1?l0000Yooooo`;o0000M_ooool008_ooooo
0_l0000Oooooo`03o`000?oooooooooo01Cooooo0_l0000[ooooo`;o0000M_ooool008_ooooo0_l0
000Oooooo`?o00004_ooool2o`0002_ooooo0_l0001hooooo`00Roooool2o`0000kooooo0_l0000?
ooooo`03o`000?oooooooooo01;ooooo0_l0000[ooooo`;o0000N?ooool008_ooooo0_l0000>oooo
o`;o00003oooool00ol0003oooooooooo`0?ooooo`;o0000Z?ooool00:cooooo00?o0000oooooooo
ool03oooool2o`000:Sooooo002<ooooo`;o00007_ooool00ol0003oooooooooo`0Cooooo`;o0000
Y?ooool008cooooo0ol0000Mooooo`03o`000?oooooooooo01?ooooo0_l0002Tooooo`00SOooool2
o`0001gooooo00?o0000ooooooooool03Oooool2o`0003?ooooo0_l0001eooooo`00SOooool2o`00
01gooooo00?o0000ooooooooool03Oooool2o`0000;ooooo1?l0000]ooooo`;o0000MOooool009go
oooo0_l0000=ooooo`?o00004Oooool4o`0002oooooo0_l0001cooooo`00WOooool2o`0000;ooooo
0ol00008ooooo`03o`000?oooooooooo04Cooooo0_l0001cooooo`00WOooool2o`0000;ooooo0ol0
00000ooooooo0000o`000005ooooo`03o`000?oooooooooo00_ooooo0_l0002/ooooo`00S_ooool2
o`0000gooooo0_l00003ooooo`;o000000?oooooo`000?l000001Oooool00ol0003oooooooooo`0;
ooooo`;o00000_ooool2o`000:Sooooo002>ooooo`;o00003Oooool2o`0000?ooooo0_l00008oooo
o`03o`000?oooooooooo00oooooo0ol0002Wooooo`00Woooool3o`000003ooooool0003o000000Oo
oooo00?o0000ooooooooool03?ooool3o`000003ooooool0003o00000:Oooooo002Aooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@;ooooo0ol000001Om4A4Co0000o`000?l0003ogMgM
00Gooooo00?o0000ooooooooool03?ooool3o`000003ooooool0003o00000:Oooooo002Aooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo0_l000000olb<S;oooooooooo`03oooo
o`03o`000?oooooooooo013ooooo0_l0000Zooooo`;o0000Noooool008oooooo0_l000001Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09oooo
o`;o00001?ooool2o`0002_ooooo0_l0001kooooo`00Soooool3o`0000?ooooo00?o0000oooooooo
ool03Oooool00omgMgOo<S8booooo`04ooooo`?o00002Oooool4o`0000;ooooo0_l0002Xooooo`00
S_ooool2o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool02_ooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool02oooool2o`0002gooooo0_l0001mooooo`00
S_ooool2o`000003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo03[ooooo0_l0001mooooo`00TOooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2iooooo`00TOoo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`03o`000?oooooooooo03gooooo
0_l0001jooooo`00[?ooool00ol0003oooooooooo`07ooooo`;o00000_ooool2o`00033ooooo0ol0
001iooooo`00[?ooool00ol0003oooooooooo`07ooooo`;o00000_ooool2o`00037ooooo0_l0001i
ooooo`00T_ooool2o`0001Sooooo00?o0000ooooooooool0^Oooool009;ooooo0_l0000Hooooo`?o
0000^Oooool0093ooooo0_l000000ooooooo0000o`00000Gooooo`03o`000?oooooooooo0;Wooooo
002@ooooo`;o000000?oooooo`000?l000005oooool00ol0003oooooooooo`0iooooo`?o0000OOoo
ool00:cooooo00?o0000ooooooooool00oooool2o`0003Cooooo0ol0001mooooo`00U?ooool2o`00
01Kooooo00?o0000ooooooooool00oooool2o`0003Gooooo0_l0001mooooo`00TOooool2o`000003
ooooool0003o000001Kooooo00?o0000ooooooooool0=oooool2o`00083ooooo002Aooooo`;o0000
6Oooool00ol0003oooooooooo`08ooooo`;o0000;Oooool2o`00083ooooo002/ooooo`03o`000?oo
oooooooo00Kooooo1?l0002_ooooo`00T_ooool2o`0001Sooooo0ol00005ooooo`?o0000/Oooool0
09;ooooo0_l000000ooooooo0000o`00000Eooooo`03o`000?oooooooooo00Gooooo0ol0002aoooo
o`00T_ooool2o`000003ooooool0003o000001Gooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0=oooool2o`00083ooooo002/ooooo`03o`000?oooooooooo03Oooooo0_l0
0020ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool01?l0003oooooooooooooool2
o`00037ooooo0_l00023ooooo`00Uoooool2o`0001?ooooo00Co0000oooooooooooooooo0_l0000a
ooooo`;o0000Poooool009Oooooo0_l0000Cooooo`?o0000^Oooool00:cooooo00?o0000oooooooo
ool0<Oooool2o`000003ooooool0003o000008?ooooo002/ooooo`03o`000?oooooooooo037ooooo
0_l000000ooooooo0000o`000023ooooo`00[?ooool00ol0003oooooooooo`02o`000;Oooooo002/
ooooo`03o`000?oooooooooo00;o0000]oooool00:cooooo00?o0000ooooooooool0^Oooool009Ko
oooo0_l00002ooooo`;o00004?ooool00ol0003oooooooooo`2iooooo`00U_ooool2o`0000;ooooo
0_l00003ooooo`;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000ooooo`2jooooo`00Wooo
ool2o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?ooool0^_ooool00:Oooooo0ol00002
ooooo`?o0000^Oooool00:Oooooo0ol00002ooooo`03o`000?oooooooooo0;Wooooo002Kooooo`?o
00000oooool2o`0000Cooooo0_l00003ooooo`03o`000?oooooooooo0;Wooooo002Kooooo`Go0000
00?oooooo`000?l000001?ooool2o`0000?ooooo00?o0000ooooooooool0^Oooool009kooooo0_l0
000<ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo
00?o0000ooooooooool0^Oooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1_ooool01?mEEEGoZJVYo`000?l00004ooooo`;o000000?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`0Zooooo`;o0000SOooool008Wooooo00Go410@oooooooooooooooooa0@400=ooooo`04
ojVYZOmEEEGo0000o`0000Cooooo0_l000000ooooooo0000ooooo`04ooooo`03o`000?oooooooooo
02[ooooo0_l0002=ooooo`00ROooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qoooo
ooooool01_ooool00omgMgOo<S8booooo`04ooooo`?o0000:oooool2o`0008cooooo0029ooooo`05
o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`04o`000?lQ8B7o0000
oc8b<P;o00001?ooool00ol0003oooooooooo`0[ooooo`;o0000S?ooool008Wooooo00Go410@oooo
oooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00;ooooo0_l00003ooooo`;o00001?ooool0
0ol0003oooooooooo`2iooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@
oooooooooooooooooc8b<P03ooooo`;o00002Oooool00ol0003oooooooooo`2iooooo`00ROooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool00ol0003ooooooooo
o`0Xooooo`;o0000Soooool00:cooooo00?o0000ooooooooool0:?ooool2o`0008oooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo02Cooooo0_l0002Cooooo`00
[?ooool3o`0002Cooooo0_l0002Cooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`0Rooooo`;o0000UOooool00:cooooo00?o0000ooooooooool08_ooool2o`0009Gooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002i
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo01;ooooo0ol0
002Tooooo`00[?ooool00ol0003oooooooooo`0Booooo`?o0000Y?ooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
^Oooool00:;ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0;Wooooo002T
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000oooo
ooooool01Oooool3o`000;Wooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`00
0?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooo
oooo0<7ooooo002Rooooo`03oeEEEOmVIVKo00000<?ooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo002Zooooo`04oa0@4?l0003o0000o`000;[ooooo002[oooo
o`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`06o`00
0?mgMgOo0000o`000?mEEEGok^k^]oooool00:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomEEEFg
ooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo0;Gooooo002[ooooo`03
o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0]Oooool00:_ooooo00Ko0000oeEEEOo^k^ko
ooooogMgMomVIVJgooooo`00Z_ooool00ol@413o0000ogMgM`02o`000003ofIVI_o^k^kooooo0;Ko
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.45321 .88572 Mdot
.42946 .85688 Mdot
.50342 .44893 Mdot
.46263 .74675 Mdot
.534 .26753 Mdot
.5351 .81637 Mdot
.43803 .55255 Mdot
.63356 .18954 Mdot
.65403 .26149 Mdot
.41291 .50502 Mdot
.42957 .29998 Mdot
.68285 .28354 Mdot
.39609 .74003 Mdot
.41199 .54673 Mdot
.71427 .39876 Mdot
.44165 .7184 Mdot
.58805 .65647 Mdot
.39523 .73587 Mdot
.47084 .19681 Mdot
.40136 .19266 Mdot
.38224 .41468 Mdot
.38574 .60728 Mdot
.39351 .30799 Mdot
.38345 .6238 Mdot
.72463 .4161 Mdot
.58034 .35715 Mdot
.47819 .21405 Mdot
.49855 .21911 Mdot
.43342 .0892 Mdot
.39807 .72101 Mdot
.42559 .1407 Mdot
.63334 .21723 Mdot
.65789 .24509 Mdot
.55232 .75168 Mdot
.57721 .71663 Mdot
.48965 .06758 Mdot
.57107 .14224 Mdot
.49765 .22354 Mdot
.52622 .0976 Mdot
.67142 .25088 Mdot
.71258 .34721 Mdot
.57208 .72024 Mdot
.54258 .79319 Mdot
.50237 .88486 Mdot
.5139 .86349 Mdot
.55455 .30188 Mdot
.42724 .31984 Mdot
.59098 .15339 Mdot
.6047 .45022 Mdot
.49077 .05936 Mdot
.60172 .17147 Mdot
.50266 .06211 Mdot
.73738 .71102 Mdot
.53841 .79412 Mdot
.57708 .72704 Mdot
.66031 .26366 Mdot
.64865 .21612 Mdot
.59993 .61742 Mdot
.57947 .14462 Mdot
.5206 .85276 Mdot
.56924 .34331 Mdot
.74814 .45582 Mdot
.5525 .13332 Mdot
.53973 .56956 Mdot
.69122 .3396 Mdot
.63772 .22035 Mdot
.4142 .45514 Mdot
.42375 .6219 Mdot
.46807 .20414 Mdot
.37954 .46948 Mdot
.61626 .54834 Mdot
.43318 .49274 Mdot
.42015 .37364 Mdot
.41553 .56065 Mdot
.55301 .1341 Mdot
.5024 .58108 Mdot
.73691 .71207 Mdot
.59176 .4628 Mdot
.48445 .04815 Mdot
.59292 .58567 Mdot
.45492 .08068 Mdot
.39205 .66804 Mdot
.45577 .73388 Mdot
.57957 .70584 Mdot
.6276 .18698 Mdot
.47935 .76858 Mdot
.53572 .26992 Mdot
.57252 .37625 Mdot
.60925 .56595 Mdot
.42031 .58678 Mdot
.72694 .43607 Mdot
.75058 .62759 Mdot
.53796 .59967 Mdot
.55476 .30837 Mdot
.53407 .6108 Mdot
.75995 .58344 Mdot
.41214 .54595 Mdot
.6347 .23135 Mdot
.73811 .71287 Mdot
.61536 .52006 Mdot
.43193 .84944 Mdot
.61262 .51293 Mdot
.69529 .32122 Mdot
.47722 .9043 Mdot
.39658 .25081 Mdot
.55098 .75642 Mdot
.60878 .59783 Mdot
.4756 .1931 Mdot
.5385 .59778 Mdot
.38364 .37589 Mdot
.41388 .57165 Mdot
.48892 .74657 Mdot
.63731 .22615 Mdot
.41692 .13974 Mdot
.70484 .80303 Mdot
.48634 .29522 Mdot
.58175 .38957 Mdot
.60835 .16384 Mdot
.61311 .17546 Mdot
.60612 .20186 Mdot
.38901 .68251 Mdot
.74048 .41191 Mdot
.41025 .20123 Mdot
.42108 .11702 Mdot
.38094 .42217 Mdot
.44397 .71235 Mdot
.44151 .08164 Mdot
.75987 .56377 Mdot
.38825 .59968 Mdot
.5303 .44635 Mdot
.38243 .48003 Mdot
.41102 .78019 Mdot
.69797 .31929 Mdot
.55709 .78356 Mdot
.53798 .80456 Mdot
.44236 .06963 Mdot
.50627 .05777 Mdot
.44581 .0719 Mdot
.42213 .35946 Mdot
.679 .29052 Mdot
.71211 .38078 Mdot
.74839 .5535 Mdot
.52207 .66858 Mdot
.46075 .20597 Mdot
.59081 .64857 Mdot
.40351 .18637 Mdot
.62034 .17818 Mdot
.6916 .83402 Mdot
.54555 .3189 Mdot
.57313 .37365 Mdot
.72463 .34034 Mdot
.61252 .48946 Mdot
.43467 .26611 Mdot
.38766 .67758 Mdot
.4339 .52923 Mdot
.468 .88402 Mdot
.52983 .09021 Mdot
.53328 .10446 Mdot
.62662 .19525 Mdot
.58537 .16455 Mdot
.52399 .08197 Mdot
.59268 .39538 Mdot
.46354 .04763 Mdot
.67988 .25297 Mdot
.49051 .0723 Mdot
.50128 .85289 Mdot
.40842 .76078 Mdot
.62408 .18591 Mdot
.3942 .26199 Mdot
.46889 .20496 Mdot
.486 .04103 Mdot
.51226 .08748 Mdot
.49256 .72874 Mdot
.48241 .2097 Mdot
.55794 .32996 Mdot
.53616 .28943 Mdot
.67728 .29184 Mdot
.75905 .58143 Mdot
.46382 .88102 Mdot
.51381 .37335 Mdot
.47232 .05079 Mdot
.46678 .04145 Mdot
.686 .2797 Mdot
.43456 .70238 Mdot
.7143 .34994 Mdot
.5358 .48738 Mdot
.66318 .28692 Mdot
.75573 .58114 Mdot
.60454 .16675 Mdot
.68166 .25941 Mdot
.55308 .77853 Mdot
.73532 .39795 Mdot
.39894 .20801 Mdot
.5375 .56939 Mdot
.74618 .47789 Mdot
.63448 .19549 Mdot
.71222 .32698 Mdot
.6953 .31661 Mdot
.55621 .31558 Mdot
.76128 .61 Mdot
.61282 .59489 Mdot
.50434 .34637 Mdot
.50571 .3499 Mdot
.43348 .46873 Mdot
.55267 .3179 Mdot
.75831 .62794 Mdot
.4059 .75091 Mdot
.53481 .5622 Mdot
.51776 .84366 Mdot
.51621 .69263 Mdot
.53577 .4436 Mdot
.42015 .35015 Mdot
.40854 .80096 Mdot
.59018 .44609 Mdot
.39648 .24729 Mdot
.42212 .62411 Mdot
.40326 .73217 Mdot
.58938 .45249 Mdot
.68602 .26656 Mdot
.53199 .42585 Mdot
.47357 .89152 Mdot
.65872 .22741 Mdot
.57842 .37545 Mdot
.61509 .20263 Mdot
.38652 .32564 Mdot
.48036 .07109 Mdot
.41686 .53303 Mdot
.52786 .26081 Mdot
.47009 .91131 Mdot
.51219 .68557 Mdot
.71411 .39582 Mdot
.73932 .39325 Mdot
.45944 .75259 Mdot
.46936 .66257 Mdot
.74396 .66854 Mdot
.60444 .55184 Mdot
.44847 .23699 Mdot
.73964 .41979 Mdot
.4853 .20991 Mdot
.47436 .90592 Mdot
.38503 .38316 Mdot
.41876 .81118 Mdot
.74829 .47002 Mdot
.55981 .77274 Mdot
.39246 .26659 Mdot
.61613 .54866 Mdot
.61492 .18256 Mdot
.52467 .64209 Mdot
.56696 .14359 Mdot
.58256 .65877 Mdot
.61646 .54356 Mdot
.53936 .11414 Mdot
.71426 .33784 Mdot
.4883 .29837 Mdot
.52751 .61715 Mdot
.58576 .1706 Mdot
.59269 .42014 Mdot
.48501 .21238 Mdot
.59707 .68703 Mdot
.50092 .59216 Mdot
.66003 .24203 Mdot
.58297 .1451 Mdot
.60741 .49361 Mdot
.44688 .24028 Mdot
.47979 .06932 Mdot
.52162 .39686 Mdot
.61036 .52195 Mdot
.44114 .86422 Mdot
.44442 .25675 Mdot
.4866 .87405 Mdot
.50791 .08529 Mdot
.59909 .48041 Mdot
.45591 .06712 Mdot
.58231 .71849 Mdot
.41617 .59347 Mdot
.60213 .53973 Mdot
.51599 .07307 Mdot
.44222 .73077 Mdot
.48511 .19106 Mdot
.61146 .1859 Mdot
.41168 .44518 Mdot
.49549 .875 Mdot
.46977 .04921 Mdot
.51288 .34871 Mdot
.41507 .48612 Mdot
.59345 .17798 Mdot
.68709 .30015 Mdot
.47213 .19243 Mdot
.4357 .54561 Mdot
.5642 .36885 Mdot
.39207 .25658 Mdot
.57056 .35813 Mdot
.4564 .08145 Mdot
.75331 .59097 Mdot
.59594 .17245 Mdot
.7066 .3684 Mdot
.61912 .21333 Mdot
.46215 .6618 Mdot
.55037 .10624 Mdot
.74296 .50089 Mdot
.38359 .3319 Mdot
.71232 .39185 Mdot
.68502 .84851 Mdot
.60393 .49922 Mdot
.59138 .70722 Mdot
.42071 .82067 Mdot
.62332 .19764 Mdot
.71789 .37637 Mdot
.42334 .33906 Mdot
.62107 .20385 Mdot
.59341 .41882 Mdot
.49192 .31766 Mdot
.39425 .71624 Mdot
.59006 .65378 Mdot
.38414 .61953 Mdot
.7233 .34112 Mdot
.50346 .33145 Mdot
.45961 .88633 Mdot
.55859 .74362 Mdot
.69463 .34663 Mdot
.51276 .35635 Mdot
.69217 .29498 Mdot
.73745 .46479 Mdot
.75654 .51805 Mdot
.44267 .71328 Mdot
.57131 .75995 Mdot
.58809 .68705 Mdot
.56145 .14339 Mdot
.50832 .22006 Mdot
.47363 .29708 Mdot
.44643 .61561 Mdot
.60683 .60139 Mdot
.6491 .21232 Mdot
.59896 .19426 Mdot
.53891 .5881 Mdot
.39866 .74298 Mdot
.5289 .42835 Mdot
.43436 .45127 Mdot
.46318 .90858 Mdot
.5476 .79597 Mdot
.50266 .85119 Mdot
.5939 .40268 Mdot
.55354 .32275 Mdot
.75048 .67579 Mdot
.59706 .46299 Mdot
.3869 .58917 Mdot
.5331 .604 Mdot
.66424 .26562 Mdot
.47835 .21542 Mdot
.45001 .06793 Mdot
.38405 .47946 Mdot
.53615 .61677 Mdot
.58681 .44988 Mdot
.74965 .54388 Mdot
.67432 .26306 Mdot
.52805 .07727 Mdot
.48377 .06283 Mdot
.60254 .45976 Mdot
.60236 .63173 Mdot
.49662 .06894 Mdot
.60806 .53289 Mdot
.67652 .26867 Mdot
.75995 .48469 Mdot
.39336 .25921 Mdot
.69957 .32596 Mdot
.69499 .30133 Mdot
.70185 .30636 Mdot
.43815 .40384 Mdot
.60454 .53987 Mdot
.71424 .39215 Mdot
.65289 .22611 Mdot
.43903 .39554 Mdot
.43291 .11795 Mdot
.59617 .51867 Mdot
.53694 .81691 Mdot
.43625 .85881 Mdot
.64116 .24213 Mdot
.46966 .90466 Mdot
.56983 .13713 Mdot
.59162 .18636 Mdot
.3944 .30281 Mdot
.51021 .05729 Mdot
.38365 .43976 Mdot
.72045 .40078 Mdot
.7074 .80432 Mdot
.61785 .22054 Mdot
.49059 .88182 Mdot
.43545 .45574 Mdot
.73258 .43025 Mdot
.61271 .53658 Mdot
.44803 .62202 Mdot
.68132 .26592 Mdot
.37976 .45556 Mdot
.4632 .30338 Mdot
.41393 .51589 Mdot
.58287 .37779 Mdot
.45717 .22189 Mdot
.58874 .14819 Mdot
.3775 .4942 Mdot
.74503 .4926 Mdot
.68725 .28147 Mdot
.58148 .68474 Mdot
.7386 .69778 Mdot
.59139 .66231 Mdot
.52869 .2721 Mdot
.51754 .24406 Mdot
.49387 .63625 Mdot
.65483 .22533 Mdot
.68312 .28526 Mdot
.47465 .21386 Mdot
.5204 .66714 Mdot
.41061 .43926 Mdot
.46299 .76528 Mdot
.72155 .34706 Mdot
.54078 .27385 Mdot
.46752 .06668 Mdot
.49859 .72649 Mdot
.44373 .24022 Mdot
.52159 .39238 Mdot
.54116 .27865 Mdot
.55469 .74521 Mdot
.43095 .28338 Mdot
.53448 .56851 Mdot
.73422 .37822 Mdot
.6757 .28235 Mdot
.48643 .38661 Mdot
.57693 .71935 Mdot
.60814 .6006 Mdot
.42972 .82799 Mdot
.59639 .52987 Mdot
.47049 .20636 Mdot
.73093 .40858 Mdot
.76609 .56789 Mdot
.44553 .88328 Mdot
.7151 .77841 Mdot
.50899 .87824 Mdot
.53879 .5447 Mdot
.67343 .30918 Mdot
.71661 .40304 Mdot
.44647 .24584 Mdot
.38702 .39957 Mdot
.74639 .6871 Mdot
.51391 .68588 Mdot
.45937 .31165 Mdot
.54704 .31631 Mdot
.46241 .07169 Mdot
.59761 .54942 Mdot
.75654 .618 Mdot
.53676 .47889 Mdot
.53865 .79009 Mdot
.58698 .6858 Mdot
.54205 .56454 Mdot
.51313 .36633 Mdot
.42969 .68467 Mdot
.63768 .19677 Mdot
.49802 .31268 Mdot
.46488 .04848 Mdot
.44208 .88195 Mdot
.48507 .89304 Mdot
.44481 .07808 Mdot
.45438 .0854 Mdot
.58967 .65935 Mdot
.76587 .52454 Mdot
.41375 .5181 Mdot
.64943 .2121 Mdot
.71025 .32372 Mdot
.45499 .23657 Mdot
.54041 .09293 Mdot
.59826 .50746 Mdot
.57482 .68708 Mdot
.44291 .07724 Mdot
.44148 .87074 Mdot
.48607 .20015 Mdot
.58647 .44314 Mdot
.56429 .72832 Mdot
.74455 .40776 Mdot
.51117 .84294 Mdot
.50814 .53413 Mdot
.52497 .81833 Mdot
.59684 .56683 Mdot
.43288 .46388 Mdot
.42616 .63509 Mdot
.54599 .78106 Mdot
.55887 .76975 Mdot
.49512 .31439 Mdot
.59281 .43201 Mdot
.63949 .22333 Mdot
.5204 .23912 Mdot
.44226 .86457 Mdot
.43373 .26119 Mdot
.52715 .27959 Mdot
.44482 .35975 Mdot
.71979 .77811 Mdot
.45299 .33213 Mdot
.44573 .89005 Mdot
.63685 .2457 Mdot
.48171 .06654 Mdot
.47151 .20198 Mdot
.4562 .05963 Mdot
.68484 .28094 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:Oooooo0_l00003ooooo`03o`000?oooooooooo0;Wooooo002Q
ooooo`;o00001?ooool2o`0000?ooooo00?o0000ooooooooool0^Oooool00:7ooooo0_l00009oooo
o`03o`000?oooooooooo0;Wooooo002Pooooo`Co00000_ooool2o`0000Cooooo00?o0000oooooooo
ool0^Oooool00:3ooooo1?l00002ooooo`;o00001?ooool3o`000;Wooooo002Rooooo`;o00002?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooo`000002o`000;Oooooo002Moooo
o`;o00002_ooool2o`000003ooooool0003o000000?o0000]oooool009gooooo0_l00007ooooo`;o
000000Coooooo`000?l0003ooooo0_l0002jooooo`00Voooool4o`0000;ooooo0_l00003ooooo`Co
00000_ooool00ol0003oooooooooo`2iooooo`00VOooool6o`0000;ooooo0_l00002ooooo`So0000
^oooool009Wooooo0ol00003ooooo`;o00001?ooool2o`000003ooooool0003o000000?o00001?oo
ool2o`000;Gooooo002Iooooo`?o00000oooool2o`0000Oooooo0_l00002ooooo`?o00000_ooool2
o`0000;ooooo0_l0002aooooo`00VOooool2o`00017ooooo00?o0000ooooooooool01_ooool2o`00
0;7ooooo002Hooooo`?o00000_ooool2o`0000gooooo00?o0000ooooooooool01?ooool2o`000;?o
oooo002Hooooo`;o00000oooool2o`0000gooooo00Co0000ooooool0003o00000oooool2o`000;?o
oooo002Fooooo`;o00001Oooool2o`0000gooooo00?o0000ooooool000000ol0002fooooo`00U_oo
ool2o`0001Cooooo00Co0000oooooooooooooooo0_l00003ooooo`;o0000/Oooool00:cooooo00?o
0000ooooooooool01_ooool2o`0000;ooooo0_l0002]ooooo`00[?ooool00ol0003oooooooooo`05
ooooo`;o00000oooool2o`000:gooooo002/ooooo`?o00001Oooool2o`000;;ooooo002/ooooo`03
o`000?oooooooooo00Sooooo0_l0002_ooooo`00[?ooool00ol0003oooooooooo`08ooooo`;o0000
0oooool2o`000:[ooooo002/ooooo`03o`000?oooooooooo00gooooo0_l0002Zooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0:ooooo`;o0000[Oooool008Wo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`;o000000?o8B4Qo`000?l000001?ooool00ol0
003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0:
ooooo`;o0000[Oooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`;o000000?o8B4Q
o`000?l000001?ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool0^Oooool0087ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool0
0onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002iooooo`00ROooool01Ol0
003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool0
0omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`2iooooo`00ROooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00kooooo0_l0002Yooooo`00ROooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool03_ooool2o`0000Cooooo0_l0002Sooooo`00ROoo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo0_l000000ooooooo0000o`000004ooooo`Go0000
1?ooool4o`0000Kooooo00?o0000ooooooooool05?ooool2o`000:?ooooo002@ooooo`;o000000?o
ooooo`000?l000005oooool00ol0003oooooooooo`0Aooooo`Go0000Xoooool00:cooooo00?o0000
ooooooooool04Oooool5o`000004ooooool0003o0000o`0009oooooo002/ooooo`03o`000?oooooo
oooo01Oooooo1Ol0002Mooooo`00[?ooool3o`0001[ooooo0_l0002Mooooo`00[?ooool00ol0003o
ooooooooo`0Kooooo`;o0000W?ooool00:cooooo00?o0000ooooooooool06oooool2o`0009cooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo01Wooooo0_l00005
ooooo`;o0000Uoooool00:cooooo00?o0000ooooooooool06Oooool2o`0000Cooooo0ol0002Goooo
o`00[?ooool00ol0003oooooooooo`0Iooooo`;o00001?ooool2o`0009Sooooo002/ooooo`03o`00
0?oooooooooo01Wooooo0_l000000ooooooo0000o`000002o`0009Wooooo002/ooooo`?o00007?oo
ool4o`0000;ooooo0_l0002Eooooo`00[?ooool00ol0003oooooooooo`0Kooooo`;o00001Oooool4
o`0009?ooooo002/ooooo`03o`000?oooooooooo01_ooooo0_l00006ooooo`?o0000Toooool008co
oooo0_l0000Nooooo`03o`000?oooooooooo01_ooooo0_l00004ooooo`Co000000?oooooo`000?l0
0000TOooool008cooooo0_l0000Nooooo`03o`000?oooooooooo01_ooooo0_l00004ooooo`;o0000
0oooool3o`00093ooooo002Rooooo`;o00000oooool2o`0000?ooooo00?o0000ooooooooool09ooo
ool4o`0008kooooo002;ooooo`;o00005Oooool4o`000003ooooool0003o000000?ooooo00?o0000
ooooooooool07Oooool2o`0000Oooooo0_l000000ooooooo0000o`00002>ooooo`00Roooool2o`00
01Gooooo1?l00006ooooo`03o`000?oooooooooo01gooooo0_l00006ooooo`?o000000Coooooo`00
0?l0003o0000SOooool008kooooo0_l0000Booooo`;o00000oooool2o`0000?ooooo0ol0000Uoooo
o`;o00000oooool2o`0008gooooo002>ooooo`;o00004Oooool3o`0000?ooooo0_l00003ooooo`03
o`000?oooooooooo023ooooo0_l000000ooooooo0000o`000002o`0009;ooooo002Oooooo`Go0000
2?ooool00ol0003oooooooooo`0Pooooo`;o000000?oooooo`000?l000000_l0002Booooo`00R_oo
ool2o`0001?ooooo1Ol00002ooooo`?o00000oooool00ol0003oooooooooo`2iooooo`00R_ooool2
o`0001[ooooo0ol00003ooooo`03o`000?oooooooooo02Cooooo0_l00008ooooo`;o0000ROooool0
0:?ooooo0ol000000ooooooo0000o`000003ooooo`03o`000?oooooooooo02Cooooo0_l00008oooo
o`;o0000ROooool00:?ooooo0ol00005ooooo`;o0000:oooool2o`0000?ooooo0_l00029ooooo`00
WOooool2o`0000cooooo0_l000000ooooooo0000o`00000Rooooo`;o00001?ooool3o`0008gooooo
002Mooooo`;o00003?ooool5o`0002;ooooo0_l00005ooooo`?o00000oooool2o`0008Oooooo002[
ooooo`;o0000;?ooool3o`0000;ooooo1?l00026ooooo`00[?ooool00ol0003oooooooooo`0Yoooo
o`?o00000oooool4o`0008Kooooo002/ooooo`03o`000?oooooooooo02Wooooo0_l0002>ooooo`00
Voooool4o`0000gooooo00?o0000ooooooooool0^Oooool009Wooooo1_l0000=ooooo`03o`000?oo
oooooooo00?ooooo0_l0002dooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo0ol0
00000olQ8B7oooooooooo`03ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`03ooooo`;o00009_ooool2o`0000Cooooo0_l00026ooooo`00TOooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Cooooo0_l000000olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool00_ooool2o`0002Kooooo0ol00004ooooo`;o0000Q_ooool008Wooooo1_l0
0002ooooo`05oa0@4?ooooooooooooooool@41001?ooool2o`0000[ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`;o00009_ooool2o`0000Gooooo0_l00026ooooo`00ROoo
ool2o`0000Kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo
0ol0000eooooo`;o000000?oooooo`000?l00000Ooooool008Wooooo0_l00006ooooo`05o`000?oo
ooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool0=Oooool2o`000003ooooool0003o000007oooooo0028ooooo`;o00001oooool01Ol@413ooooo
oooooooooooo410@00?ooooo0_l00007ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0^Oooool008Sooooo0ol00006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_l000000ooooooo
0000o`000007ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool2o`0002Oo
oooo0_l00008ooooo`;o0000O_ooool008Sooooo0ol00006ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00_l0000:ooooo`Co00001_ooool00ol0003oooooooooo`06ooooo`;o00009oooool4o`0000?o
oooo0_l000000ooooooo0000o`00001nooooo`00R?ooool2o`0000cooooo0_l0000Dooooo`03o`00
0?oooooooooo00Sooooo0_l0000Wooooo`Co000000?oooooo`000?l000001?l0001mooooo`00R?oo
ool2o`0000cooooo0_l0000Dooooo`03o`000?oooooooooo00Sooooo0_l0000Yooooo`;o00000_oo
ool5o`0007gooooo002/ooooo`03o`000?oooooooooo00Kooooo1_l0000[ooooo`;o0000P?ooool0
0:cooooo0ol00006ooooo`;o00000_ooool2o`000:gooooo002/ooooo`03o`000?oooooooooo00Ko
oooo0_l00002ooooo`;o0000;_ooool2o`0007gooooo002Eooooo`;o00005Oooool00ol0003ooooo
ooooo`06ooooo`;o00000_ooool2o`0002_ooooo0_l000000ooooooo0000o`00001mooooo`00UOoo
ool2o`0001Gooooo00?o0000ooooooooool0=oooool5o`0007gooooo002/ooooo`03o`000?oooooo
oooo00Wooooo0_l0000Wooooo`;o00001Oooool2o`0007kooooo002/ooooo`03o`000?oooooooooo
00Wooooo0_l0000Wooooo`;o00000oooool3o`0007oooooo002Wooooo`;o00000oooool00ol0003o
ooooooooo`0gooooo`?o00000_ooool2o`0007_ooooo002Sooooo`;o00000_ooool3o`0000;ooooo
00?o0000ooooooooool0??ooool2o`0007_ooooo002Dooooo`;o00003Oooool2o`0000?ooooo0_l0
0002ooooo`?o0000>_ooool2o`000003ooooool0003o000007[ooooo0029ooooo`;o00002Oooool2
o`0000Wooooo0_l0000;ooooo`03o`000?oooooooooo00oooooo0_l0000Yooooo`;o000000?ooooo
o`000?l00000N_ooool008Wooooo0_l0000Dooooo`;o00002oooool00ol0003oooooooooo`0?oooo
o`;o0000;_ooool2o`0007Sooooo0028ooooo`;o00008_ooool00ol0003oooooooooo`0?ooooo`;o
00009Oooool2o`0000Oooooo0_l0001hooooo`00R?ooool2o`0001Cooooo0_l0000;ooooo`;o0000
4Oooool2o`0002Gooooo0_l00021ooooo`00W_ooool2o`0000[ooooo0ol0000>ooooo`;o000000?o
ooooo`000?l00000;?ooool2o`0007[ooooo002Yooooo`Co00003_ooool5o`0002cooooo0ol0001i
ooooo`00U?ooool2o`0001?ooooo0_l000000ooooooo0000ooooo`0=ooooo`Co0000;Oooool3o`00
07Wooooo0026ooooo`;o00003?ooool2o`0001Kooooo0ol0000>ooooo`;o0000;Oooool2o`0000?o
oooo0_l0001eooooo`00Q_ooool2o`0002Cooooo00?o0000ooooooooool0?_ooool2o`0000;ooooo
0ol0001dooooo`00[?ooool3o`00013ooooo0_l0000/ooooo`;o00000oooool2o`0007Cooooo0025
ooooo`;o00005Oooool2o`0000kooooo0ol0000@ooooo`;o0000Yoooool008Gooooo0_l0000Eoooo
o`;o00003_ooool00ol0003oooooooooo`13ooooo`;o0000M?ooool009;ooooo0_l0000Hooooo`03
o`000?oooooooooo03cooooo0_l00005ooooo`;o00000_ooool2o`00073ooooo002Booooo`;o0000
6?ooool00ol0003oooooooooo`0Cooooo`;o00009oooool2o`0000Sooooo0ol0001`ooooo`00[?oo
ool3o`0001?ooooo0_l0000Xooooo`;o00001oooool2o`00077ooooo002/ooooo`?o000000?ooooo
o`000?l00000>_ooool2o`0000Cooooo0_l000000ooooooo0000o`00001aooooo`00TOooool2o`00
01Wooooo0ol000000ooooooo0000o`000010ooooo`;o000000?oooooo`000?l00000LOooool0097o
oooo0_l0000Iooooo`03o`000?oooooooooo0;Wooooo002/ooooo`04o`000?ooooooooooooooo`;o
00004Oooool2o`000003ooooool0003o00000:3ooooo002Booooo`;o00001Oooool2o`00017ooooo
00Co0000oooooooooooooooo0_l0000Aooooo`;o000000?oooooo`000?l00000X?ooool009;ooooo
0_l00005ooooo`;o00004Oooool00ol0003oooooooooo`2iooooo`00ROooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Go
oooo00Co0000oooooooooooooooo0_l0002fooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04
ooooo`04o`000?ooooooooooooooo`;o00003oooool2o`0002gooooo0_l0001fooooo`00POooool6
o`0000;ooooo00Go410@oooooooooooooooooa0@4003ooooo`;o00001oooool00onHV9So8B4Qonk^
kP09ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l0000?ooooo`;o0000
00?oooooo`000?l00000:_ooool2o`0007Kooooo0025ooooo`;o00000_ooool01Ol0003ooooooooo
oooooooo000000?ooooo0_l00008ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0
1?ooool3o`000003ooooool0003o000001;ooooo0ol0000/ooooo`;o0000Loooool008Gooooo0_l0
0002ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Eooooo`Go0000:_ooool2o`0000Co
oooo0_l0001]ooooo`00Q_ooool2o`000003ooooool@413ooooo00;ooooo00?o410@ooooooooool0
3Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
6?ooool2o`0002Wooooo0_l00005ooooo`;o0000KOooool008Kooooo0_l000001_ooooooMgMgoiRH
V?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0@oooool2o`0007Cooooo0029ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l000000ooooooo0000o`000003
ooooo`03o`000?oooooooooo0;Wooooo002Wooooo`;o00000oooool00ol0003oooooooooo`04oooo
o`;o00004_ooool2o`0002Wooooo0_l0001dooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o
00004_ooool2o`000003ooooool0003o000002Kooooo0_l00007ooooo`;o0000Joooool009Oooooo
0_l0000Cooooo`03o`000?oooooooooo00Cooooo0_l0000Eooooo`;o00009_ooool2o`0000Gooooo
1?l0001[ooooo`00Q_ooool2o`0000oooooo0_l0000Cooooo`?o00001?ooool2o`0003gooooo1?l0
0003ooooo`;o0000KOooool008Kooooo0_l0000?ooooo`;o00004oooool00ol0003oooooooooo`0L
ooooo`;o00009Oooool4o`0007;ooooo002Gooooo`;o00004oooool00ol0003oooooooooo`0Loooo
o`;o00009_ooool2o`0007?ooooo002/ooooo`03o`000?oooooooooo04Wooooo0_l00002ooooo`;o
0000J_ooool00:cooooo00?o0000ooooooooool0BOooool2o`000004ooooool0003o0000o`0006[o
oooo0025ooooo`;o00009Oooool00ol0003oooooooooo`17ooooo`;o00000oooool2o`0006_ooooo
0025ooooo`;o00009Oooool00ol0003oooooooooo`0Kooooo`;o0000:_ooool2o`00073ooooo0024
ooooo`;o00009_ooool00ol0003oooooooooo`0Kooooo`;o0000;oooool2o`0006_ooooo0024oooo
o`;o00009_ooool3o`0001_ooooo0_l0000_ooooo`;o0000Joooool00:cooooo00?o0000oooooooo
ool01_ooool3o`000;3ooooo002/ooooo`03o`000?oooooooooo00Kooooo0ol00010ooooo`;o0000
K_ooool00:cooooo00?o0000ooooooooool06oooool2o`0002cooooo0_l0001^ooooo`00[?ooool0
0ol0003oooooooooo`0Kooooo`;o0000:_ooool2o`00073ooooo0025ooooo`;o00001oooool2o`00
01cooooo00?o0000ooooooooool0Aoooool2o`00073ooooo0025ooooo`;o00001oooool2o`0001co
oooo00?o0000ooooooooool02?ooool2o`0000oooooo0_l0002Nooooo`00S_ooool2o`0001cooooo
00?o0000ooooooooool01oooool3o`0000oooooo0ol0002Mooooo`00S_ooool2o`0001cooooo0ol0
0007ooooo`;o00004?ooool3o`0009gooooo002Fooooo`;o00005?ooool3o`0001Wooooo0ol00003
ooooo`;o0000V?ooool008Cooooo0_l00009ooooo`;o00001Oooool2o`0001Cooooo00?o0000oooo
ooooool06_ooool2o`0000?ooooo0_l0000]ooooo`;o0000JOooool008Cooooo0_l00009ooooo`;o
00001Oooool2o`0001Cooooo00?o0000ooooooooool0C_ooool2o`0006Wooooo0009ooooo`Co0000
00?o410@ooooooooool05_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03
o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oM
gMd05_ooool00ol0003oooooooooo`0Hooooo`06onk^k_lb<S;o0000oc8b<_o^k^kooooo0_l00002
ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4
A4Co0000o`000?lb<S;ogMgM01Sooooo1?l000000ol@413oooooooooo`0Booooo`002oooool00ol0
003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEE
ojVYZOooool01oooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo0000o`00000Eooooo`03
o`000?oooooooooo01Sooooo00?oMgMgoiRHV?ooool01Ol00002ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool03_ooool01_mgMgOoV9RHoooooonHV9So
MgMgooooo`;o00000_ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool0
6Oooool00ol0003oooooooooo`0Dooooo`001_l00005ooooo`03o`000?oooooooooo013ooooo1_l0
0002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`00
0?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003o
ooooooooo`05ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q
8Oo^k^h02Oooool2o`0001Gooooo00?o0000ooooooooool06?ooool00ol@413oooooooooo`04o`00
00[ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`0=ooooo`06oa0@4?oooooooooo
ooooool@413ooooo0_l0000=ooooo`03o`000?oooooooooo00gooooo00Go410@oooooooooooooooo
oa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool00000
3_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000oooooooooooo
ooooo`00000?ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`000007oooo
o`;o00001?ooool00onHV9So8B4Qonk^kP07ooooo`04ogMgMolb<S;o0000o`0001Cooooo00?o0000
ooooooooool06?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000001Oooool2o`0000Sooooo
00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qoooooooo
ool01_ooool00omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`00
0?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003?ooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`000007ooooo`;o0000
1Oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_l0000Dooooo`03
o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000001Ooo
ool2o`0000Gooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool0
00003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06_ooool00ol0
003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05oa0@4?oooooooooooooo
ool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo017ooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@
400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06?ooool3o`0001Sooooo00Go
410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
4Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04Oooool01Ol@413o
oooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`0A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02?ooool2o`000006ooooool0003o^[ZjoooooonHV9So410@1?ooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo00Wooooo0_l0000=ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool04Ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo0_l00006ooooo`03o`000?oooooooooo017ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01Cooooo0009ooooo`03oeEEEOmVIVKo000001[o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`00013ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo0_l0
00001_ooooooV9RHoa0@4?l0003o8B4Qolc<c0Cooooo1?l0000Gooooo`03o`000?oooooooooo00Wo
oooo0_l0000=ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_l00009ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`;o00001_oo
ool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0001Wooooo
00?oEEEEofIVI_l000005_ooool0093ooooo0_l0000Jooooo`03o`000?oooooooooo01gooooo0_l0
000cooooo`;o0000IOooool0093ooooo0_l0000Jooooo`03o`000?oooooooooo00Sooooo0_l00018
ooooo`;o0000IOooool00:cooooo00?o0000ooooooooool02?ooool2o`0001Sooooo0_l0002:oooo
o`;o00000_ooool2o`0000Gooooo0023ooooo`;o00004Oooool2o`0001Cooooo00?o0000oooooooo
ool08?ooool4o`0002Wooooo0_l0001Oooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1Oooool0
08?ooooo0_l0000Aooooo`;o00005?ooool00ol0003oooooooooo`0Pooooo`;o0000:oooool2o`00
063ooooo00CogMgMo`000?l@413oc<c<1_ooool000Ooooooool0001<o`0000cooooo00Cok^k^ob4Q
8Ol@413ok^k^1_ooool000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo0ol00006ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool00_ooool2o`000003ooooool0003ooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool01?lQ
8B7oMgMgogMgMolb<S86ooooo`001oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`09ooooo`;o00006oooool00ol0
003oooooooooo`0Mooooo`;o00002?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`09ooooo`;o00000_ooool2o`00
00Gooooo002?ooooo`;o00006oooool00ol0003oooooooooo`0Mooooo`;o0000V_ooool00:cooooo
00?o0000ooooooooool08_ooool2o`0009Gooooo002?ooooo`;o00006oooool00ol0003ooooooooo
o`0Rooooo`;o0000UOooool008oooooo0_l0000Kooooo`03o`000?oooooooooo01cooooo0_l0000c
ooooo`;o0000I_ooool008oooooo0_l0000Kooooo`03o`000?oooooooooo01cooooo0_l00003oooo
o`Co0000;?ooool2o`0006Kooooo002/ooooo`?o00008Oooool4o`0002oooooo0_l0001Sooooo`00
[?ooool00ol0003oooooooooo`1Dooooo`;o0000Hoooool009Kooooo0_l0000Dooooo`03o`000?oo
oooooooo01cooooo0_l0002Kooooo`00T?ooool2o`0000Cooooo0_l0000Dooooo`04o`000?oooooo
0000o`0001_ooooo0_l00002ooooo`;o0000Uoooool0093ooooo0_l0000Jooooo`04o`000?oooooo
0000o`0001oooooo1?l0002Eooooo`00[?ooool00ol0003oooooooooo`0Nooooo`?o000000?ooooo
o`000?l00000UOooool00:cooooo00?o0000ooooooooool07_ooool3o`0000;ooooo0_l0000Zoooo
o`;o0000J?ooool008oooooo0_l00005ooooo`;o00005?ooool00ol0003oooooooooo`09ooooo`;o
00006?ooool2o`0002[ooooo0_l0001Xooooo`00Soooool2o`0000Gooooo0_l0000Dooooo`03o`00
0?oooooooooo00Wooooo0_l0000Booooo`;o00001?ooool2o`0009Cooooo002Gooooo`;o00004ooo
ool3o`0001gooooo1?l00002ooooo`;o0000U?ooool009Oooooo0_l0000Cooooo`03o`000?oooooo
oooo01oooooo0_l0000^ooooo`;o0000J?ooool00:cooooo00?o0000ooooooooool0Coooool2o`00
06Sooooo002@ooooo`;o00006_ooool00ol0003oooooooooo`2iooooo`00T?ooool2o`0001[ooooo
00?o0000ooooooooool02?ooool4o`0004Kooooo0_l0001Uooooo`00[?ooool00ol0003ooooooooo
o`08ooooo`Co00004Oooool2o`0000;ooooo0_l0000_ooooo`Co0000Hoooool00:cooooo00?o0000
ooooooooool02?ooool4o`00017ooooo0_l00002ooooo`;o0000<Oooool2o`0006?ooooo002?oooo
o`;o00006oooool00ol0003oooooooooo`08ooooo`Co0000[Oooool008oooooo0_l0000Kooooo`?o
0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0_l0001Booooo`?o0000IOoo
ool00:cooooo0_l0000Looooo`;o0000=?ooool3o`0006Gooooo0026ooooo`;o00002Oooool2o`00
01Wooooo00?o0000ooooooooool02Oooool2o`00013ooooo0_l0000eooooo`;o0000IOooool008Ko
oooo0_l00009ooooo`;o00006Oooool2o`0000[ooooo0_l00015ooooo`;o0000Ioooool0093ooooo
0_l0000Jooooo`;o00008oooool2o`0002cooooo0_l0001Wooooo`00T?ooool2o`0001[ooooo00?o
0000ooooooooool02Oooool2o`0001Gooooo1?l0002Eooooo`00Qoooool2o`0002?ooooo0ol00009
ooooo`;o00005Oooool2o`0009Oooooo0027ooooo`;o00008oooool00ol0003oooooooooo`07oooo
o`Co00005Oooool2o`0009Oooooo0026ooooo`;o00009?ooool00ol0003oooooooooo`07ooooo`;o
0000/?ooool008Kooooo0_l0000Tooooo`03o`000?oooooooooo05?ooooo0_l0001Tooooo`00[?oo
ool00ol0003oooooooooo`08ooooo`;o0000BOooool2o`0006Cooooo002Jooooo`;o00004?ooool0
0ol0003oooooooooo`08ooooo`;o0000[oooool008Gooooo0_l00002ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`06ooooo`Co00005?ooool2o`00037ooooo0_l0001Vooooo`00QOooool2
o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`;o000000?o8B4Qooooooooool00_oo
ool01OnHV9So0000o`000?ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`06ooooo`Co00005?ooool2o`00037ooooo0_l0001Vooooo`00QOooool2o`0000;ooooo00Go
410@oooooooooooooooooa0@4004ooooo`;o00001_ooool2o`000003onk^k_oooooooooo00Oooooo
00?o0000ooooooooool00oooool3o`000;Wooooo0025ooooo`;o00000_ooool01Ol0003ooooooooo
oooooooo000000Cooooo0_l00007ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`1?ooooo`;o000000?oooooo`000?l00000IOooool008Wooooo00Go
0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo01kooooo0_l0000_ooooo`;o000000?oooooo`000?l0
0000IOooool008Wooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Nooooo`;o0000VOooool008Wooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o00001?ooool01Ol0003o^[ZjoooooonHV9So410@
00Cooooo00?o0000ooooooooool01Oooool3o`000;_ooooo0029ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2o`0000Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001?ooool3
o`000;_ooooo002/ooooo`03o`000?oooooooooo00Gooooo0_l0002booooo`00[?ooool00ol0003o
ooooooooo`05ooooo`;o0000/_ooool00:cooooo00?o0000ooooooooool06oooool2o`0009cooooo
002/ooooo`?o00006oooool2o`0009cooooo002/ooooo`03o`000?oooooooooo01[ooooo0_l0002M
ooooo`00[?ooool00ol0003oooooooooo`0Hooooo`Co0000WOooool009oooooo0_l0000;ooooo`03
o`000?oooooooooo01Sooooo1?l0002Mooooo`00Woooool4o`0000Wooooo00?o0000ooooooooool0
6_ooool3o`0009cooooo0028ooooo`;o00005oooool2o`0000Wooooo00?o0000ooooooooool00ooo
ool2o`0001Kooooo0_l0002Looooo`00R?ooool2o`0002;ooooo00?o0000ooooooooool00oooool3
o`0004Oooooo0_l0001Zooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o0000Aoooool2o`00
06[ooooo002/ooooo`?o0000Coooool2o`0006Sooooo0026ooooo`;o00009?ooool00ol0003ooooo
ooooo`1?ooooo`;o0000J?ooool008Kooooo0ol0000Sooooo`03o`000?oooooooooo0;Wooooo0027
ooooo`;o00002oooool2o`0001Kooooo00Co0000oooooooooooooooo0_l0000Dooooo`Co0000W_oo
ool009Cooooo0_l0000Fooooo`04o`000?ooooooooooooooo`;o00004_ooool7o`000003ooooool0
003o000002oooooo0_l0001Yooooo`00[?ooool00ol0003oooooooooo`0Eooooo`;o00000oooool2
o`000003ooooool0003o000002oooooo0_l0001Yooooo`00[?ooool00ol0003oooooooooo`02oooo
o`;o0000]Oooool00:cooooo00?o0000ooooooooool00_ooool2o`0004Oooooo0_l0001/ooooo`00
[?ooool3o`0004_ooooo0_l0001/ooooo`00U_ooool2o`0001Cooooo00?o0000ooooooooool0^Ooo
ool009Kooooo0_l0000Dooooo`03o`000?oooooooooo01Oooooo0_l00002ooooo`;o0000W?ooool0
0:cooooo00?o0000ooooooooool05oooool2o`0000;ooooo0_l0002Looooo`00VOooool2o`00017o
oooo00?o0000ooooooooool0Boooool2o`0006cooooo0029ooooo`;o00003_ooool2o`00017ooooo
00?o0000ooooooooool0Boooool2o`0006cooooo0029ooooo`;o00003Oooool2o`0001;ooooo00?o
0000ooooooooool05_ooool4o`0009oooooo002:ooooo`;o00003?ooool2o`0001;ooooo00?o0000
ooooooooool05?ooool6o`0009oooooo002:ooooo`;o00008?ooool3o`0001Cooooo0_l0002Soooo
o`00Zoooool2o`0001Cooooo0_l00002ooooo`;o0000XOooool009Sooooo0_l0000?ooooo`Co0000
5?ooool2o`0000;ooooo0_l0002Qooooo`00S?ooool2o`0000[ooooo0_l00003ooooo`;o00002_oo
ool2o`000003ooooool0003ooooo0;[ooooo0029ooooo`;o000000?oooooo`000?l000003oooool2
o`0000gooooo00?o0000ooooooooool0^Oooool008Wooooo0_l0000Qooooo`03o`000?oooooooooo
0;Wooooo0029ooooo`?o00001Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0@ooooo`;o0000Yoooool0
08[ooooo0_l00005ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@;ooooo0_l00004
ooooo`03ogMgMolb<S;ooooo00;o00000_ooool00ol0003oooooooooo`0?ooooo`?o0000Yoooool0
097ooooo00Go410@oooooooooooooooooa0@4009ooooo`;o00001Oooool01?l0003oooooo`000?l0
0002ooooo`03o`000?oooooooooo00oooooo0_l0002Xooooo`00S?ooool2o`0000?ooooo00Go0000
ooooooooooooooooo`000008ooooo`;o00001Oooool00omgMgOo<S8booooo`04ooooo`?o00003_oo
ool2o`000:Wooooo002<ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000Sooooo0_l0
0002ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0>ooooo`;o0000
ZOooool0097ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool03Oooool2o`000:[ooooo002=ooooo`;o00000_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0=ooooo`;o0000
1Oooool2o`000:?ooooo002=ooooo`;o00000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l00006ooooo`03o`000?oooooooooo01Cooooo0_l0002Sooooo`00Woooool2o`0000_ooooo00?o
0000ooooooooool0^Oooool009oooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0@
ooooo`;o0000Yoooool00:Gooooo0_l00005ooooo`03o`000?oooooooooo013ooooo0_l0002Woooo
o`00[?ooool3o`00013ooooo0_l0002Wooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool0
3_ooool2o`0003Cooooo0ol0001booooo`00S_ooool2o`0001cooooo00?o0000ooooooooool03?oo
ool4o`0003Cooooo0ol0001booooo`00[?ooool00ol0003oooooooooo`0<ooooo`;o000000?ooooo
o`000?l00000Z?ooool00:cooooo00?o0000ooooooooool03oooool2o`000:Sooooo002/ooooo`03
o`000?oooooooooo00Wooooo0_l0002^ooooo`00[?ooool00ol0003oooooooooo`09ooooo`Co0000
[?ooool00:cooooo00?o0000ooooooooool02Oooool5o`000:_ooooo002=ooooo`;o00007Oooool3
o`0000cooooo0_l0002[ooooo`00SOooool2o`0001gooooo00?o0000ooooooooool0@?ooool3o`00
07Kooooo002/ooooo`03o`000?oooooooooo00Wooooo0_l0000eooooo`?o0000M_ooool00:cooooo
00?o0000ooooooooool02Oooool2o`000:kooooo002Aooooo`;o00006Oooool00ol0003ooooooooo
o`2iooooo`00TOooool2o`0001Wooooo00?o0000ooooooooool02?ooool2o`000:oooooo002/oooo
o`03o`000?oooooooooo00Gooooo0_l000001?oooooo0000o`000?l0002^ooooo`00TOooool2o`00
01Wooooo00?o0000ooooooooool01Oooool2o`0000;ooooo0_l0002^ooooo`00TOooool2o`0001Wo
oooo0ol0002iooooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool0^Oooool009Cooooo0_l0
000Fooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo03cooooo0_l0001k
ooooo`00[?ooool00ol0003oooooooooo`0looooo`;o0000Noooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool01?l0002eooooo`00[?ooool00ol0003ooooooooo
o`04o`000;Gooooo002Eooooo`;o00005Oooool00ol0003oooooooooo`0jooooo`;o0000OOooool0
09Gooooo0_l0000Eooooo`?o00000oooool2o`0003Gooooo0_l0001mooooo`00[?ooool2o`0000Co
oooo0_l0002dooooo`00U?ooool2o`000003ooooool0003o000001?ooooo00?o0000ooooooooool0
^Oooool009Cooooo0_l000000ooooooo0000o`00000Cooooo`03o`000?oooooooooo0;Wooooo002H
ooooo`?o00004Oooool01?l0003oooooooooooooool2o`000;Kooooo0029ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@?ooooo1?l000000oo^k^koooooooooo`03ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool01?l0003oooooooooooooool2o`000;Kooooo0029ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@?ooooo0_l000000oooooooEEEEojVYZ@08ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0^Oooool008Wooooo00Go410@oooooooooooo
oooooa0@400:ooooo`;o000000?oooooojVYZOmEEED02Oooool3o`0000?ooooo00?o0000oooooooo
ool0^Oooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Ko
oooo00GoMgMgoc8b<_l0003o0000ooooo`05o`000;Wooooo0029ooooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00oooool3
o`0000;ooooo0_l0002gooooo`00ROooool01Ol@413ooooooooooooooooo410@00[ooooo0_l00002
ooooo`04ojVYZOmgMgOoooooooooo`?o00001Oooool2o`0000;ooooo00?o0000ooooooooool00_l0
002gooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo1_l00002ooooo`?o00001Ooo
ool2o`0000;ooooo0_l0002jooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1ol0
00000ooooooo0000o`000003o`0000Kooooo0_l0002jooooo`00V_ooool2o`0000;ooooo0_l00003
ooooo`;o00001oooool00ol0003oooooooooo`2iooooo`00V_ooool2o`0000Oooooo0_l00002oooo
o`;o00000oooool00ol0003oooooooooo`2iooooo`00Yoooool2o`0000?ooooo00?o0000oooooooo
ool0^Oooool00:cooooo0ol0002iooooo`00Y?ooool2o`0000Kooooo00?o0000ooooooooool0^Ooo
ool00:;ooooo1?l00006ooooo`03o`000?oooooooooo0;Wooooo002Oooooo`;o000000Coooooo`00
0?l0003o00001oooool00ol0003oooooooooo`2iooooo`00Woooool2o`000003ooooool0003o0000
00Sooooo00?o0000ooooooooool0^Oooool00:;ooooo0_l00008ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Ooo
ool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0
002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Rooooo`Co0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`2iooooo`00Y?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`03o`000?oooooooooo00Gooooo0ol0002i
ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00
Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00X_ooool0
0omEEEGoIVIVo`000033ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00Z_ooool01?l@413o0000o`000?l0002jooooo`00Zoooool00ol0003oooooooooo`2j
ooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool01_l0003oMgMgo`000?l0003oEEEE
onk^k[Oooooo002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoEEEE]oooool00:_ooooo00?o0000
onk^k_ooool00_ooool00ol0003oooooooooo`2eooooo`00Zoooool00ol0003ok^k^ooooo`02oooo
o`03o`000?oooooooooo0;Gooooo002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoIVIV]oooool0
0:[ooooo00?o410@o`000?mgMgL00_l000000omVIVKok^k^ooooo`2fooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.58754 .74133 Mdot
.57558 .78417 Mdot
.45813 .38669 Mdot
.54091 .60269 Mdot
.42155 .29163 Mdot
.62165 .61637 Mdot
.49447 .65007 Mdot
.46976 .00817 Mdot
.51863 .06149 Mdot
.48953 .77002 Mdot
.44116 .74165 Mdot
.55627 .08354 Mdot
.5469 .85037 Mdot
.49883 .765 Mdot
.63377 .19876 Mdot
.53327 .65545 Mdot
.61064 .45647 Mdot
.54602 .85269 Mdot
.40971 .58378 Mdot
.42384 .88803 Mdot
.47644 .92345 Mdot
.51786 .87485 Mdot
.45071 .89734 Mdot
.52206 .88521 Mdot
.65106 .2161 Mdot
.48334 .16556 Mdot
.41188 .54794 Mdot
.40858 .45793 Mdot
.39431 .77043 Mdot
.54176 .83606 Mdot
.40725 .79345 Mdot
.48034 .02542 Mdot
.51593 .04509 Mdot
.613 .55168 Mdot
.62386 .51663 Mdot
.37743 .5296 Mdot
.40469 .16429 Mdot
.40975 .46091 Mdot
.37976 .36136 Mdot
.53177 .05088 Mdot
.61147 .14721 Mdot
.62017 .52024 Mdot
.61985 .59319 Mdot
.61631 .68486 Mdot
.6193 .66349 Mdot
.44188 .20954 Mdot
.446 .74753 Mdot
.42058 .09455 Mdot
.54479 .25022 Mdot
.37539 .52648 Mdot
.4347 .06449 Mdot
.37345 .47392 Mdot
.78179 .51102 Mdot
.61606 .59412 Mdot
.62789 .52704 Mdot
.52577 .06366 Mdot
.4951 .01662 Mdot
.6069 .41742 Mdot
.41025 .1334 Mdot
.6217 .65276 Mdot
.46764 .17565 Mdot
.69047 .25582 Mdot
.39388 .23955 Mdot
.52755 .36956 Mdot
.58706 .1396 Mdot
.48591 .02455 Mdot
.47836 .77516 Mdot
.51285 .70503 Mdot
.41191 .59427 Mdot
.48899 .92341 Mdot
.59559 .34834 Mdot
.48246 .68416 Mdot
.45928 .76684 Mdot
.50111 .74657 Mdot
.39426 .23729 Mdot
.49487 .38347 Mdot
.78174 .51207 Mdot
.53688 .2628 Mdot
.37431 .5565 Mdot
.58718 .38567 Mdot
.3878 .67839 Mdot
.53032 .85075 Mdot
.53657 .61411 Mdot
.6219 .50584 Mdot
.4631 .01497 Mdot
.55283 .58476 Mdot
.42279 .28405 Mdot
.48319 .18536 Mdot
.59563 .36595 Mdot
.50579 .72148 Mdot
.66137 .23607 Mdot
.76162 .42759 Mdot
.53783 .39967 Mdot
.44406 .20874 Mdot
.5384 .4108 Mdot
.75333 .38344 Mdot
.49863 .7645 Mdot
.48728 .03485 Mdot
.78326 .51287 Mdot
.58339 .32006 Mdot
.57321 .77112 Mdot
.57779 .31293 Mdot
.58378 .12122 Mdot
.60387 .71723 Mdot
.43756 .89632 Mdot
.61354 .55642 Mdot
.60791 .39783 Mdot
.40787 .56376 Mdot
.53761 .39778 Mdot
.46767 .92574 Mdot
.50387 .75193 Mdot
.54951 .55166 Mdot
.4878 .02933 Mdot
.40892 .83152 Mdot
.78605 .60303 Mdot
.42784 .49479 Mdot
.49758 .18976 Mdot
.4375 .04642 Mdot
.44566 .0377 Mdot
.44903 .05953 Mdot
.53436 .86653 Mdot
.66525 .21191 Mdot
.42378 .84734 Mdot
.40306 .81827 Mdot
.47836 .92751 Mdot
.53127 .64346 Mdot
.39091 .73673 Mdot
.74538 .36377 Mdot
.51562 .86376 Mdot
.47076 .28711 Mdot
.49067 .90848 Mdot
.55475 .80514 Mdot
.58568 .11929 Mdot
.63052 .58356 Mdot
.61981 .60456 Mdot
.38811 .73561 Mdot
.37189 .45897 Mdot
.38785 .72006 Mdot
.45576 .76123 Mdot
.55521 .09052 Mdot
.62442 .18078 Mdot
.72979 .3535 Mdot
.54951 .46858 Mdot
.41389 .62583 Mdot
.61024 .44857 Mdot
.422 .88001 Mdot
.45309 .02376 Mdot
.78521 .63402 Mdot
.44121 .2392 Mdot
.48276 .18316 Mdot
.62077 .14034 Mdot
.5683 .28946 Mdot
.43266 .7267 Mdot
.53349 .87163 Mdot
.49027 .67311 Mdot
.59155 .71073 Mdot
.37835 .34689 Mdot
.38205 .32846 Mdot
.46532 .0203 Mdot
.42017 .11236 Mdot
.37612 .37472 Mdot
.51083 .19538 Mdot
.37872 .64791 Mdot
.54107 .05297 Mdot
.37827 .52481 Mdot
.60244 .65289 Mdot
.54997 .80691 Mdot
.45941 .02003 Mdot
.44052 .90429 Mdot
.41191 .59052 Mdot
.37242 .55127 Mdot
.37767 .42594 Mdot
.54501 .53121 Mdot
.41002 .53046 Mdot
.45342 .19992 Mdot
.42806 .27879 Mdot
.55401 .09184 Mdot
.75162 .38143 Mdot
.58884 .71525 Mdot
.44193 .35692 Mdot
.37751 .60888 Mdot
.37667 .6351 Mdot
.55788 .0797 Mdot
.53008 .67632 Mdot
.61428 .14994 Mdot
.49082 .29153 Mdot
.53795 .08692 Mdot
.74818 .38114 Mdot
.43537 .05651 Mdot
.54542 .05941 Mdot
.62449 .57853 Mdot
.6545 .19795 Mdot
.42771 .89529 Mdot
.52525 .36939 Mdot
.69733 .27789 Mdot
.47295 .01049 Mdot
.60301 .12698 Mdot
.58194 .11661 Mdot
.44739 .20424 Mdot
.76528 .41 Mdot
.61078 .39489 Mdot
.43538 .4049 Mdot
.43605 .39802 Mdot
.47716 .68807 Mdot
.4456 .21531 Mdot
.76949 .42794 Mdot
.54783 .81323 Mdot
.51969 .3622 Mdot
.61522 .64366 Mdot
.55326 .49263 Mdot
.47436 .2732 Mdot
.45415 .7719 Mdot
.56082 .82496 Mdot
.52862 .24609 Mdot
.43682 .89749 Mdot
.5137 .71241 Mdot
.54353 .81748 Mdot
.53038 .25249 Mdot
.55265 .06656 Mdot
.46523 .28072 Mdot
.59695 .70947 Mdot
.50969 .02741 Mdot
.48865 .17952 Mdot
.45735 .04198 Mdot
.45608 .92403 Mdot
.38021 .56941 Mdot
.49479 .74673 Mdot
.41805 .31919 Mdot
.60281 .73312 Mdot
.54642 .48557 Mdot
.63244 .19582 Mdot
.65661 .19325 Mdot
.54262 .6163 Mdot
.51411 .52144 Mdot
.77138 .46854 Mdot
.58517 .35184 Mdot
.42332 .67273 Mdot
.66756 .21979 Mdot
.40944 .51777 Mdot
.6029 .72221 Mdot
.46896 .91811 Mdot
.56242 .79185 Mdot
.6963 .27002 Mdot
.62891 .57274 Mdot
.4419 .9109 Mdot
.59559 .34866 Mdot
.44982 .03577 Mdot
.5415 .44209 Mdot
.40292 .17974 Mdot
.60607 .45877 Mdot
.59389 .34356 Mdot
.38539 .29967 Mdot
.6094 .13784 Mdot
.4281 .48556 Mdot
.53437 .41715 Mdot
.42234 .11105 Mdot
.52075 .22014 Mdot
.41004 .51851 Mdot
.63188 .48703 Mdot
.49779 .39263 Mdot
.51684 .04203 Mdot
.41258 .12119 Mdot
.56486 .29361 Mdot
.42438 .67899 Mdot
.37994 .57227 Mdot
.45035 .31941 Mdot
.57914 .32195 Mdot
.57834 .75446 Mdot
.42851 .68614 Mdot
.5981 .6789 Mdot
.37767 .44575 Mdot
.55126 .28041 Mdot
.38463 .67699 Mdot
.62971 .51849 Mdot
.50816 .73937 Mdot
.57802 .33973 Mdot
.37423 .41245 Mdot
.53669 .65988 Mdot
.40537 .5227 Mdot
.44797 .04393 Mdot
.47673 .78835 Mdot
.6057 .67554 Mdot
.37772 .62034 Mdot
.43602 .3663 Mdot
.48493 .76468 Mdot
.43037 .08792 Mdot
.56715 .10015 Mdot
.40848 .57909 Mdot
.49346 .66172 Mdot
.4725 .19377 Mdot
.4398 .91473 Mdot
.47437 .17878 Mdot
.38765 .67177 Mdot
.7497 .39097 Mdot
.43046 .08042 Mdot
.61397 .1684 Mdot
.46512 .03973 Mdot
.5147 .54776 Mdot
.38632 .25372 Mdot
.70331 .30089 Mdot
.45808 .93548 Mdot
.62906 .19185 Mdot
.78442 .64851 Mdot
.56361 .29922 Mdot
.63427 .50722 Mdot
.565 .7903 Mdot
.46312 .02627 Mdot
.62844 .17637 Mdot
.45104 .76037 Mdot
.46336 .03249 Mdot
.52094 .21882 Mdot
.43153 .46556 Mdot
.54136 .85115 Mdot
.61157 .45378 Mdot
.52095 .88203 Mdot
.61975 .14112 Mdot
.4322 .41207 Mdot
.58943 .72815 Mdot
.61604 .54362 Mdot
.59328 .14663 Mdot
.43777 .36519 Mdot
.57016 .09498 Mdot
.68337 .26479 Mdot
.72376 .31805 Mdot
.53171 .64894 Mdot
.63529 .55995 Mdot
.62291 .48705 Mdot
.4002 .20131 Mdot
.40721 .41466 Mdot
.431 .54986 Mdot
.50649 .60345 Mdot
.60738 .40139 Mdot
.49404 .01306 Mdot
.44026 .07478 Mdot
.53415 .3881 Mdot
.54715 .8405 Mdot
.46377 .29022 Mdot
.47315 .68796 Mdot
.59885 .74163 Mdot
.62598 .59597 Mdot
.60314 .65119 Mdot
.51497 .20268 Mdot
.44776 .21256 Mdot
.7808 .47579 Mdot
.54226 .26299 Mdot
.51359 .87029 Mdot
.5347 .404 Mdot
.53049 .06562 Mdot
.41215 .54696 Mdot
.38608 .70259 Mdot
.49019 .90155 Mdot
.54286 .41677 Mdot
.52676 .24988 Mdot
.7272 .34388 Mdot
.53954 .06306 Mdot
.37525 .35764 Mdot
.37766 .55628 Mdot
.54644 .25976 Mdot
.61505 .43173 Mdot
.37622 .49885 Mdot
.58122 .33289 Mdot
.54399 .06867 Mdot
.71383 .28469 Mdot
.44009 .90855 Mdot
.58995 .12596 Mdot
.57552 .10133 Mdot
.5844 .10636 Mdot
.46198 .6817 Mdot
.58049 .33987 Mdot
.6311 .19215 Mdot
.50334 .02611 Mdot
.45998 .67965 Mdot
.4007 .76641 Mdot
.56364 .31867 Mdot
.62371 .61691 Mdot
.57628 .76456 Mdot
.49801 .04221 Mdot
.60008 .72747 Mdot
.40259 .16963 Mdot
.43174 .09371 Mdot
.44939 .89458 Mdot
.37125 .44163 Mdot
.48161 .9119 Mdot
.64076 .20078 Mdot
.78912 .60432 Mdot
.46667 .04496 Mdot
.60423 .68416 Mdot
.47389 .68227 Mdot
.66467 .23025 Mdot
.58735 .33658 Mdot
.5076 .59666 Mdot
.54768 .06592 Mdot
.4859 .92546 Mdot
.43463 .59407 Mdot
.49168 .7632 Mdot
.49399 .17892 Mdot
.41814 .63804 Mdot
.41737 .10176 Mdot
.49483 .92698 Mdot
.70207 .2926 Mdot
.55983 .08147 Mdot
.61537 .48474 Mdot
.77771 .49778 Mdot
.61632 .46231 Mdot
.42102 .3133 Mdot
.41248 .36822 Mdot
.50948 .43915 Mdot
.50496 .02533 Mdot
.55722 .08526 Mdot
.41261 .56342 Mdot
.54726 .46714 Mdot
.47567 .79428 Mdot
.5472 .61643 Mdot
.62038 .14706 Mdot
.42593 .26278 Mdot
.38202 .62643 Mdot
.54922 .52658 Mdot
.42505 .69273 Mdot
.44914 .32031 Mdot
.4274 .26052 Mdot
.61277 .54521 Mdot
.43724 .73919 Mdot
.52189 .36851 Mdot
.6455 .17822 Mdot
.54864 .08235 Mdot
.44777 .47462 Mdot
.62467 .51935 Mdot
.60838 .4006 Mdot
.56658 .76364 Mdot
.56834 .32987 Mdot
.41187 .58324 Mdot
.65436 .20858 Mdot
.75325 .36789 Mdot
.58528 .75784 Mdot
.78647 .57841 Mdot
.62028 .67824 Mdot
.51668 .3447 Mdot
.5571 .10918 Mdot
.63782 .20304 Mdot
.42569 .67956 Mdot
.47211 .90586 Mdot
.78123 .4871 Mdot
.54826 .48588 Mdot
.43726 .60899 Mdot
.44137 .23418 Mdot
.38422 .64764 Mdot
.57738 .34942 Mdot
.76374 .418 Mdot
.48843 .28531 Mdot
.61469 .59009 Mdot
.6213 .4858 Mdot
.52786 .36454 Mdot
.44015 .36141 Mdot
.52646 .69027 Mdot
.47656 .00799 Mdot
.42913 .44001 Mdot
.37862 .64187 Mdot
.58439 .76583 Mdot
.6045 .69877 Mdot
.38942 .72307 Mdot
.38895 .67973 Mdot
.61341 .45935 Mdot
.73569 .32454 Mdot
.4922 .76351 Mdot
.49428 .01278 Mdot
.59974 .12372 Mdot
.42182 .64436 Mdot
.38055 .29952 Mdot
.56125 .30746 Mdot
.60965 .48708 Mdot
.38965 .73157 Mdot
.58055 .75858 Mdot
.40714 .51655 Mdot
.52373 .24314 Mdot
.61562 .52832 Mdot
.66765 .20776 Mdot
.60835 .64294 Mdot
.48279 .3565 Mdot
.61231 .61833 Mdot
.58357 .36683 Mdot
.47622 .6917 Mdot
.51533 .69525 Mdot
.61842 .58106 Mdot
.62677 .56975 Mdot
.43013 .45229 Mdot
.52562 .23201 Mdot
.48884 .02597 Mdot
.4116 .35658 Mdot
.57855 .75158 Mdot
.43179 .73185 Mdot
.42244 .31839 Mdot
.45091 .66209 Mdot
.79104 .57811 Mdot
.44311 .63243 Mdot
.58765 .76292 Mdot
.49513 .04623 Mdot
.37892 .56447 Mdot
.41069 .57972 Mdot
.38293 .67734 Mdot
.55722 .08094 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Rooooo`Co00001_ooool00ol0003oooooooooo`2iooooo`00X_ooool4o`0000Cooooo0ol0002k
ooooo`00Woooool2o`000004oooooomEEEGoIVIVo`0000Gooooo0ol0002kooooo`00Woooool2o`00
00Wooooo0ol0002kooooo`00W_ooool4o`0000[ooooo00?o0000ooooooooool0^Oooool009cooooo
1_l00003ooooo`Co00000oooool3o`000;Wooooo002Looooo`;o000000?oooooo`000?l000001?oo
ool5o`0000;ooooo1Ol0002gooooo`00Woooool2o`0000Oooooo0_l00002ooooo`Go0000]oooool0
09oooooo0_l00006ooooo`?o00000_ooool00ol0003oooooooooo`2iooooo`00V_ooool3o`0000;o
oooo0_l00006ooooo`;o00000oooool00ol0003oooooooooo`2iooooo`00V_ooool3o`0000?ooooo
0_l0000:ooooo`03o`000?oooooooooo0;Wooooo002Jooooo`;o000000Coooooo`000?l0003ooooo
0_l00009ooooo`;o00001?ooool2o`000;Gooooo002Gooooo`;o000000Coooooo`000?l0003ooooo
0_l00002ooooo`;o00001oooool3o`0000Cooooo0_l0002eooooo`00Uoooool2o`0000Sooooo0_l0
0007ooooo`?o00001?ooool2o`000;Gooooo002/ooooo`?o00001oooool2o`000003ooooool0003o
00000:gooooo002/ooooo`03o`000?oooooooooo00Oooooo0_l000000ooooooo0000o`00002]oooo
o`00U_ooool2o`0001Cooooo00?o0000ooooooooool0^Oooool009Kooooo0_l00003ooooo`;o0000
3oooool00ol0003oooooooooo`03ooooo`;o00001oooool2o`000:_ooooo002Fooooo`;o00000ooo
ool2o`0000oooooo00?o0000ooooooooool00oooool4o`0000?ooooo1?l0002[ooooo`00U_ooool2
o`0001Cooooo00?o0000ooooooooool01Oooool4o`000003ooooool0003o000000Co0000ZOooool0
0:cooooo00?o0000ooooooooool01oooool2o`0000;ooooo1Ol0002Yooooo`00[?ooool00ol0003o
ooooooooo`0;ooooo`;o0000[?ooool009Sooooo0_l0000Booooo`?o0000^Oooool009Gooooo0_l0
00000ooooooo0000o`00000Booooo`03o`000?oooooooooo013ooooo0_l0002Wooooo`00UOooool2
o`0001Gooooo00?o0000ooooooooool03Oooool5o`000:Oooooo002/ooooo`03o`000?oooooooooo
00gooooo1Ol0002Wooooo`00UOooool2o`0001Gooooo00?o0000ooooooooool02Oooool2o`0000Co
oooo0_l0002Xooooo`00UOooool2o`0001Gooooo00?o0000ooooooooool02Oooool2o`0000?ooooo
0ol0002Xooooo`00TOooool2o`0000;ooooo0_l0000Eooooo`03o`000?oooooooooo00kooooo0ol0
0003ooooo`;o0000Xoooool0097ooooo0_l00002ooooo`;o00005Oooool00ol0003oooooooooo`0D
ooooo`;o0000Xoooool00:cooooo0ol0000Cooooo`Co0000X_ooool0093ooooo0_l0000Jooooo`03
o`000?oooooooooo01?ooooo1?l0002Rooooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool0
6?ooool2o`0009oooooo002/ooooo`03o`000?oooooooooo00oooooo0_l00007ooooo`;o0000Wooo
ool0097ooooo0ol0000Hooooo`03o`000?oooooooooo00oooooo0_l0002Xooooo`00TOooool3o`00
01Sooooo00?o0000ooooooooool06?ooool2o`0009oooooo0029ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool06?ooool3o`0009kooooo0029ooooo`06ogMgMonHV9Sooooo
oiRHV?mgMgOooooo0_l00002ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool06?ooool3o`0009kooooo0021ooooo`Ko00000_ooool0
1_l@413ooooooooooooooooo410@ooooo`;o00002_ooool00onYZJWoEEEEooooo`08ooooo`03o`00
0?oooooooooo00?ooooo0ol0000Hooooo`;o00000oooool2o`0009[ooooo0029ooooo`05o`000?oo
ooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool06_ooool2o`000003ooooool0003o000000;o0000V?ooool008Wooooo00Go
0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo01[ooooo0_l00003ooooo`;o0000V?ooool008Wooooo
00Go410@oooooooooooooooooa0@4002o`0000cooooo00?oZJVYogMgMoooool00oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00_l00009ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo027ooooo0_l0002Fooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`0Iooooo`;o00001_ooool2o`00
0003ooooool0003o000009?ooooo002/ooooo`03o`000?oooooooooo01Wooooo0_l00009ooooo`;o
0000Toooool00:cooooo00?o0000ooooooooool06oooool2o`0000Oooooo0_l0002Cooooo`00[?oo
ool00ol0003oooooooooo`0Kooooo`;o00001?ooool5o`0009?ooooo002/ooooo`?o00008Oooool3
o`0009Gooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002<ooooo`;o00007_ooool00ol0003ooooooooo
o`2iooooo`00S?ooool2o`0001Sooooo0_l00004ooooo`03o`000?oooooooooo0;Wooooo002;oooo
o`;o00006Oooool2o`0000Cooooo00?o0000ooooooooool08_ooool2o`0009Gooooo002;ooooo`;o
00007oooool00ol0003oooooooooo`0Rooooo`;o0000UOooool00:7ooooo0_l00009ooooo`?o0000
9oooool2o`00093ooooo002<ooooo`;o00004oooool4o`0000?ooooo1Ol0000Yooooo`;o00001?oo
ool2o`0008[ooooo002<ooooo`;o00005Oooool2o`000003ooooool0003o000000Go0000:?ooool2
o`0000Gooooo0_l0002:ooooo`00Y_ooool2o`0000Cooooo00?o0000ooooooooool09_ooool2o`00
097ooooo002Vooooo`;o00001?ooool00ol0003oooooooooo`2iooooo`00Zoooool2o`0002Wooooo
0ol0002?ooooo`00X_ooool2o`0000Oooooo0_l00002ooooo`;o00009Oooool3o`0000Kooooo0_l0
0027ooooo`00X_ooool2o`0000Sooooo00?o0000ooooooooool00_l0000Vooooo`;o00001_ooool2
o`0008Oooooo002;ooooo`;o00003oooool2o`0000kooooo0ol0000Xooooo`Go00000oooool2o`00
08Oooooo002;ooooo`;o00003Oooool4o`0000kooooo00?o0000ooooooooool00_ooool2o`0002Go
oooo1?l0002<ooooo`00V_ooool2o`00013ooooo00?o0000ooooooooool00_ooool2o`0002Kooooo
0_l0002=ooooo`00V?ooool3o`00017ooooo00?o0000ooooooooool0<?ooool2o`0000;ooooo0_l0
0023ooooo`00V?ooool4o`00013ooooo00?o0000ooooooooool0<?ooool2o`000004ooooool0003o
0000o`0008?ooooo002Jooooo`;o00004?ooool00ol0003oooooooooo`0^ooooo`;o00000oooool2
o`0008Cooooo002Jooooo`;o00004?ooool00ol0003oooooooooo`03ooooo`;o0000:Oooool2o`00
00Cooooo0_l00023ooooo`00[?ooool00ol0003oooooooooo`03ooooo`;o0000;oooool2o`0008?o
oooo002/ooooo`?o00000oooool2o`000;Cooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`03o`000?oooooooooo03?ooooo0_l00024ooooo`00V?ooool2o`0001;ooooo00?o0000oooo
ooooool01Oooool2o`0002cooooo0_l00024ooooo`00ROooool2o`0000gooooo0_l0000Booooo`03
o`000?oooooooooo00Gooooo0_l0000[ooooo`;o0000QOooool008Wooooo0_l0000=ooooo`;o0000
4_ooool00ol0003oooooooooo`0booooo`;o0000QOooool008Wooooo0_l00006ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00_ooool2o`000003oooooolQ8B7o8B4Q00Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo00Cooooo0_l0002cooooo`00TOooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool01?ooool4o`000;7ooooo0029ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`?o0000/Oooool0097ooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00005ooooo`Co
00000_ooool2o`000:cooooo0026ooooo`;o00002Oooool01Ol0003ooooooooooooooooo000000co
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00Oooooo0_l00002oooo
o`;o0000;_ooool2o`0007cooooo0026ooooo`;o00002Oooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0kooooo`;o0000O?ooool0097o
oooo00?oMgMgoiRHV?ooool00_l0000<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool03?ooool2o`000:_ooooo002Aooooo`03onk^k_lb<S;o000000;o00003?ooool4o`0000Kooooo
00?o0000ooooooooool02Oooool5o`0002_ooooo0_l0001nooooo`00Toooool2o`0001Oooooo00?o
0000ooooooooool02Oooool4o`0002cooooo0_l0001nooooo`00[?ooool00ol0003oooooooooo`0m
ooooo`;o0000N_ooool00:?ooooo0_l00007ooooo`03o`000?oooooooooo03gooooo0_l0001joooo
o`00Xoooool2o`0000Oooooo0ol0002iooooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool0
?_ooool2o`0007Wooooo002Dooooo`;o00002_ooool2o`0000[ooooo00?o0000ooooooooool03Ooo
ool2o`0002oooooo0_l0001iooooo`00T_ooool2o`0000cooooo0_l00006ooooo`;o00000_ooool0
0ol0003oooooooooo`0=ooooo`;o0000=?ooool2o`0007Cooooo002Booooo`;o00003_ooool2o`00
00Cooooo0_l00002ooooo`03o`000?oooooooooo01?ooooo0_l0000^ooooo`;o0000M?ooool009;o
oooo0_l0000<ooooo`Co00001Oooool2o`000003ooooool0003ooooo01Cooooo0_l0002Tooooo`00
T_ooool2o`0000cooooo0_l00007ooooo`;o000000?oooooo`000?ooool04oooool2o`0002_ooooo
0_l0001hooooo`00[?ooool00ol0003oooooooooo`0Booooo`;o0000:oooool2o`0007Sooooo0024
ooooo`Co00009?ooool3o`0001;ooooo0_l0000/ooooo`;o0000Moooool008Cooooo1?l0000Toooo
o`03o`000?oooooooooo01;ooooo0_l0000/ooooo`;o0000Moooool00:cooooo00?o0000oooooooo
ool04Oooool2o`000:Kooooo002/ooooo`03o`000?oooooooooo017ooooo0_l0002Vooooo`00TOoo
ool2o`0001Wooooo00?o0000ooooooooool05_ooool2o`000:7ooooo002Aooooo`;o00006Oooool0
0ol0003oooooooooo`0Fooooo`;o0000XOooool0097ooooo0ol00007ooooo`;o00003oooool00ol0
003oooooooooo`0Booooo`;o0000<_ooool2o`00077ooooo002Aooooo`?o00001oooool2o`0000oo
oooo00?o0000ooooooooool04_ooool2o`0000?ooooo0ol0000/ooooo`;o0000LOooool009_ooooo
0_l0000?ooooo`?o00005oooool3o`00033ooooo0_l0001]ooooo`00QOooool2o`0002Gooooo00?o
0000ooooooooool0B_ooool2o`0006gooooo0025ooooo`;o00009Oooool00ol0003oooooooooo`0C
ooooo`;o0000Y?ooool00:cooooo00?o0000ooooooooool04oooool2o`0000;ooooo0_l0002Poooo
o`00[?ooool00ol0003oooooooooo`0Gooooo`Co0000W_ooool00:cooooo00?o0000ooooooooool0
5_ooool5o`0009kooooo002/ooooo`03o`000?oooooooooo01Kooooo0ol00003ooooo`;o0000:_oo
ool2o`0006oooooo0023ooooo`;o00009oooool00ol0003oooooooooo`02ooooo`;o00006?ooool2
o`0002[ooooo0_l0001_ooooo`00Poooool2o`0002Oooooo00?o0000ooooooooool00_ooool2o`00
01;ooooo0_l00004ooooo`;o0000Voooool00:cooooo0ol0000Fooooo`;o000000Coooooo`000?l0
003ooooo0_l0002Kooooo`00[?ooool00ol0003oooooooooo`0Iooooo`;o0000;Oooool2o`0006oo
oooo0022ooooo`;o00002_ooool2o`0000Sooooo0_l0000<ooooo`;o00001?ooool00ol0003ooooo
ooooo`18ooooo`;o0000Koooool008;ooooo1?l00008ooooo`;o00002?ooool2o`0000cooooo0_l0
0004ooooo`03o`000?oooooooooo0;Wooooo0024ooooo`;o00004Oooool3o`0001;ooooo00?o0000
ooooooooool00oooool2o`000003ooooool0003o000004Kooooo0_l0001Yooooo`00ROooool01_o^
k^ko<S8bo`000?lb<S;ok^k^ooooo`;o00000_ooool2ob4Q8@03ooooool0003o000000Ko00001?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool00oooool2o`000003oooo
ool0003o0000013ooooo0_l00002ooooo`;o0000<?ooool4o`0006Oooooo0029ooooo`06ogMgMonH
V9SooooooiRHV?mgMgOooooo0_l00002ooooo`;o8B4Q00Woooooo`000?l0003ooooooiRHV?lQ8B7o
k^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00Cooooo1?l0
000@ooooo`;o00000_ooool2o`0003;ooooo0_l0001Wooooo`00POooool6o`0000;ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`Co0000/Oooool008?ooooo0_l00004ooooo`05o`000?oooooo
ooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0
002iooooo`00Poooool2o`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;Wooooo
0029ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0C_ooool4o`0006Oooooo0029ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooooooo
ool01Oooool3o`0001_ooooo0_l0000cooooo`Co0000Ioooool008Wooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00_l00002ooooo`Co00001?ooool3o`00
00[ooooo0_l0000?ooooo`;o0000=Oooool2o`0006Oooooo002Nooooo`;o00003?ooool00ol0003o
ooooooooo`08ooooo`;o0000AOooool2o`0006Sooooo002[ooooo`;o00008oooool2o`0002cooooo
0_l0001Xooooo`00U_ooool2o`0001?ooooo0_l0000;ooooo`;o00005Oooool3o`0009Kooooo002F
ooooo`;o00005?ooool3o`0000Wooooo0_l0000Eooooo`;o0000Uoooool00:cooooo00?o0000oooo
ooooool02?ooool3o`0001Gooooo0_l0002Gooooo`00U_ooool2o`0001Cooooo00?o0000oooooooo
ool02?ooool2o`000:oooooo002Fooooo`;o00005?ooool00ol0003oooooooooo`1Dooooo`;o0000
Hoooool008;ooooo0_l0000Aooooo`;o00005Oooool00ol0003oooooooooo`09ooooo`;o0000BOoo
ool2o`0006?ooooo0022ooooo`;o00002Oooool2o`0000Kooooo0_l0000Eooooo`03o`000?oooooo
oooo00Wooooo0_l0002^ooooo`00SOooool2o`0001gooooo00?o0000ooooooooool02?ooool2o`00
0003ooooool0003o000001?ooooo0_l0000booooo`;o0000Hoooool00:cooooo00?o0000oooooooo
ool02?ooool2o`000003ooooool0003o000001?ooooo0_l0000booooo`;o0000Hoooool00:cooooo
0ol0002iooooo`00Poooool2o`0002Oooooo00?o0000ooooooooool0Doooool2o`000003ooooool0
003o0000067ooooo0023ooooo`;o00009oooool00ol0003oooooooooo`0Sooooo`;o0000;_ooool2
o`000003ooooool0003o0000067ooooo002/ooooo`03o`000?oooooooooo02?ooooo0_l0002Doooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool0
0_l0002gooooo`00POooool2o`00017ooooo0_l0000Fooooo`03o`000?oooooooooo00;o00002?oo
ool2o`000:gooooo0021ooooo`Co00009oooool00ol0003oooooooooo`0:ooooo`;o0000[Oooool0
08?ooooo0_l0000Wooooo`03o`000?oooooooooo027ooooo0_l0002Fooooo`00U?ooool2o`0001Ko
oooo0ol0000Qooooo`;o0000U_ooool009Cooooo0_l0000Fooooo`03o`000?oooooooooo027ooooo
0_l0002Fooooo`00POooool2o`0000[ooooo0_l0000Mooooo`03o`000?oooooooooo023ooooo0ol0
002Fooooo`002Oooool4o`000003oa0@4?oooooooooo01Kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
3oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo0_l000000olQ8B7oooooooooo`02
ooooo`So000000KoooooodA4A?l0003o0000oc8b<_oMgMdFooooo`03o`000?oooooooooo01Sooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`Co00001?ooool5o`0000Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo
00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1?l000000ol@413o
ooooooooo`0Booooo`002oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`0>ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`06oiRHV?lQ8B7ok^k^oooooom4A4Cooooo
0_l00004ooooo`03ogMgMolb<S;ooooo01Gooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0ol00003ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omg
MgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnY
ZJWooooo00Oooooo00?oMgMgoc8b<_ooool06Oooool00ol0003oooooooooo`0Dooooo`001_l00005
ooooo`03o`000?oooooooooo013ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003Ooo
ool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?oo
ooooooooooooool@41004?ooool00ol0003oooooooooo`05ooooo`Ko00000_ooool01Ol@413ooooo
oooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool2o`0001Gooooo00?o0000oooooooo
ool03?ooool2o`0000[ooooo00Go410@oooooooooooooooooa0@4006ooooo`;o00001?ooool00onH
V9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00gooooo00Go410@oooooooooooooooooa0@400@
ooooo`03o`000?oooooooooo00gooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmE
EEGooooo00Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Dooooo`002oooool0
0ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMg
Molb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo00?oMgMgo`000?l000005Oooool00ol0003oooooooooo`0<ooooo`?o00002Oooool01Ol0003o
oooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`0>oooo
o`05o`000?ooooooooooooooool000003?ooool2o`000003oooooomgMgOo<S8b00oooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool06Ooo
ool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05o`000?oooooo
ooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
3oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?oooo
o`05o`000?ooooooooooooooool000001Oooool2o`0000Oooooo00?oMgMgofIVI_ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<01Kooooo00?o0000ooooooooool03Oooool2o`0000Wooooo00Go
0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003?ooool3o`000003oc8b<_o<c<cooooo
00kooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c00Jooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooo
oooo01Sooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o
0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool0
4Oooool01Ol@413ooooooooooooooooo410@00Gooooo0_l00008ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01_ooool2o`00013ooooo0ol0000Hooooo`05oa0@4?oooooooooooooo
ool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00;o00003oooool01Ol@413ooooooooooooo
oooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`0Aooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01_ooool2
o`00013ooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0<ooooo`03o`000?oooooooooo00;o00003oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool05?ooool000Wooooo00?oEEEEofIVI_l000006_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00_ooooo1Ol00004ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0
000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Co
oooo1?l0000Gooooo`03o`000?oooooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co0000
6Oooool00omEEEGoIVIVo`00000Fooooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool03?oo
ool2o`0001Gooooo1?l0002Booooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool03?ooool2
o`0001?ooooo1_l000000ooooooo0000o`00000_ooooo`;o0000G_ooool00:cooooo00?o0000oooo
ooooool08Oooool2o`0000;ooooo0_l000000ooooooo0000o`00000_ooooo`;o0000Doooool2o`00
00;ooooo0_l00005ooooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool03_ooool2o`0009ko
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd5ooooo`00U?ooool2o`0001Kooooo00?o0000oooo
ooooool03_ooool2o`0004Sooooo0_l0001Eooooo`04omgMgOl0003o410@olc<c0Kooooo0007oooo
oooo0000C?l0000<ooooo`04onk^k_lQ8B7o410@onk^kPKooooo0007ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0:ooooo`04ob4Q8OmgMgOoMgMgoc8b<PKooooo0007ooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool3o`000003ooooool0003o000002Gooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Wooooo0_l00002oooo
o`;o00001Oooool00:cooooo00?o0000ooooooooool09Oooool2o`0000;ooooo0_l0002>ooooo`00
[?ooool00ol0003oooooooooo`1Jooooo`;o0000GOooool008gooooo0_l0000Mooooo`03o`000?oo
oooooooo02Gooooo0_l0000cooooo`;o0000GOooool008gooooo0ol0000Looooo`03o`000?oooooo
oooo02Gooooo1?l0002@ooooo`00S?ooool4o`0001cooooo00Co0000oooooooooooooooo0_l0000Q
ooooo`Go0000T?ooool008?ooooo0_l00007ooooo`;o00007_ooool3o`000003ooooool0003o0000
027ooooo0_l0002Cooooo`00P_ooool3o`0002Oooooo00?o0000ooooooooool03Oooool2o`0001Co
oooo0_l00002ooooo`;o0000T?ooool008;ooooo0ol00009ooooo`;o00007?ooool00ol0003ooooo
ooooo`0;ooooo`Co00005?ooool2o`0000;ooooo0_l0002@ooooo`00Poooool2o`0000Wooooo0_l0
000Looooo`03o`000?oooooooooo00_ooooo0_l0002/ooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0Sooooo`;o
0000U?ooool008oooooo0_l0000Kooooo`03o`000?oooooooooo02;ooooo0ol0002Dooooo`00S_oo
ool3o`0000Cooooo0_l0000Eooooo`04o`000?ooooooooooooooo`;o00007oooool2o`0009Gooooo
0021ooooo`;o00002oooool2o`0000Gooooo0_l0000Eooooo`?o000000?oooooo`000?l000002_oo
ool2o`0001?ooooo0_l0002Eooooo`00POooool2o`0002Wooooo00?o0000ooooooooool03Oooool2
o`0001?ooooo0_l0002Eooooo`00P_ooool3o`0002Oooooo00?o0000ooooooooool08_ooool2o`00
09Gooooo0022ooooo`?o00009oooool00ol0003oooooooooo`0Rooooo`;o00001Oooool2o`0008ko
oooo0024ooooo`;o00001oooool4o`0001_ooooo00?o0000ooooooooool0:Oooool2o`0008kooooo
0024ooooo`;o00001oooool4o`0001_ooooo00?o0000ooooooooool0^Oooool008Cooooo0_l0000V
ooooo`03o`000?oooooooooo02Kooooo0_l0002Aooooo`00Q?ooool2o`0002Kooooo00?o0000oooo
ooooool09_ooool3o`00093ooooo0024ooooo`;o00009_ooool3o`0002Oooooo0_l0002@ooooo`00
SOooool3o`0001cooooo00?o0000ooooooooool09_ooool2o`0003?ooooo1?l0001Jooooo`00SOoo
ool3o`0001cooooo00?o0000ooooooooool09?ooool4o`0003?ooooo1?l0001Jooooo`00S_ooool2
o`0001cooooo00?o0000ooooooooool03_ooool2o`0001Cooooo0_l00002ooooo`;o0000Soooool0
08kooooo0_l0000Looooo`03o`000?oooooooooo00kooooo0_l0000Hooooo`;o0000Soooool008ko
oooo0_l0000Looooo`03o`000?oooooooooo02;ooooo0_l0002Eooooo`00S_ooool2o`0000Kooooo
0_l0000Dooooo`03o`000?oooooooooo02;ooooo1?l0002Cooooo`00S_ooool2o`0000Kooooo0_l0
000Dooooo`04o`000?oooooo0000o`0002;ooooo1Ol0002Aooooo`00[?ooool4o`0002Gooooo0_l0
002Aooooo`00[?ooool01?l0003oooooo`000?l00009ooooo`;o0000Coooool3o`0005_ooooo002/
ooooo`04o`000?oooooo0000o`0000Wooooo0_l0000Hooooo`;o0000=Oooool3o`0005_ooooo0023
ooooo`;o00004_ooool2o`0001?ooooo00?o0000ooooooooool09?ooool2o`0009?ooooo0023oooo
o`;o00004_ooool2o`0001?ooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool02Oooool5o`0001Oooooo0_l0002Booooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool02Oooool5o`0001Cooooo0_l000000ooooooo0000o`00002Booooo`00Poooool2o`0000Co
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Rooooo`;o000000?ooooo
o`000?l00000T_ooool008?ooooo0_l00004ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0002iooooo`00QOooool2o`00
00;ooooo00Ko0000ooooooooooooooooo`000?ooool2o`0000[ooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;Wooooo0025ooooo`;o00000_ooool0
1_l0003ooooooooooooooooo0000ooooo`;o00002oooool00omgMgOoIVIVooooo`03ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2iooooo`00ROooool01Ol@413ooooo
oooooooooooo410@00_ooooo0_l00002ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`1Kooooo`;o0000G?ooool008?ooooo0_l00004ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool2o`000003oooooonHV9So410@00Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`1Kooooo`;o0000G?ooool008?ooooo0_l00004ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool2o`0000Kooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co00001_ooool00ol0003oooooooooo`2iooooo`00Poooool2o`0000cooooo0_l0000Iooooo`03
o`000?oooooooooo00Oooooo0_l0000Gooooo`;o000000?oooooo`000?l00000U?ooool008?ooooo
0_l0000=ooooo`;o00006?ooool00ol0003oooooooooo`07ooooo`;o00005oooool2o`000003oooo
ool0003o000009Cooooo0024ooooo`?o00002oooool2o`0001Sooooo00?o0000ooooooooool01ooo
ool2o`00057ooooo0_l0001Mooooo`00Q?ooool3o`0002?ooooo1Ol00007ooooo`;o00005Oooool3
o`0000Cooooo0_l0000cooooo`;o0000GOooool00:[ooooo0ol0000:ooooo`;o00005?ooool3o`00
00Cooooo0_l0002Booooo`00[?ooool00ol0003oooooooooo`08ooooo`;o0000[oooool00:Wooooo
0_l000000ooooooo0000ooooo`0:ooooo`;o0000[_ooool009_ooooo0_l0000<ooooo`;o000000?o
ooooo`000?ooool02_ooool2o`0001Wooooo0_l0002Cooooo`00Voooool2o`0000oooooo00?o0000
ooooooooool09?ooool2o`0009?ooooo002/ooooo`03o`000?oooooooooo0;Wooooo0026ooooo`;o
00002_ooool2o`0001Cooooo0_l00002ooooo`03o`000?oooooooooo0;Wooooo0025ooooo`?o0000
2_ooool2o`0001Cooooo0_l00002ooooo`?o00001_ooool2o`0001Oooooo0_l0002Hooooo`00QOoo
ool4o`0000[ooooo0_l00009ooooo`;o00003?ooool00ol0003oooooooooo`06ooooo`;o00005Ooo
ool4o`0000?ooooo0_l0002Cooooo`00QOooool4o`0000[ooooo0_l00009ooooo`?o00000_ooool2
o`0000Oooooo00?o0000ooooooooool07Oooool2o`0000Gooooo0_l0002Cooooo`00U?ooool2o`00
00Wooooo0_l00002ooooo`;o000000?oooooo`000?l000001?ooool00ol0003oooooooooo`0Ooooo
o`;o00000_ooool2o`0009Cooooo002Dooooo`;o00003Oooool5o`0000Cooooo00?o0000oooooooo
ool07oooool2o`0000;ooooo0_l0002Dooooo`00Xoooool3o`0000Kooooo00?o0000ooooooooool0
1Oooool2o`000;;ooooo002Cooooo`;o00003oooool2o`0000Kooooo00?o0000ooooooooool00_oo
ool2o`000003ooooool0003o00000;;ooooo002Cooooo`;o00005oooool00ol0003oooooooooo`02
ooooo`;o0000]Oooool00:cooooo0ol0000Oooooo`;o0000V?ooool008Kooooo0_l0000Tooooo`03
o`000?oooooooooo01oooooo0_l0002Hooooo`00Q_ooool2o`0002Cooooo00Co0000oooooooooooo
oooo0_l0002fooooo`00[?ooool01?l0003oooooooooooooool2o`0001[ooooo0_l0002Jooooo`00
[?ooool01?l0003oooooooooooooool2o`0001Sooooo1?l0002Jooooo`00[?ooool01?l0003ooooo
ooooooooool2o`0001Oooooo0ol0002Looooo`00[?ooool00ol0003oooooooooo`0Jooooo`;o0000
0oooool2o`0009Sooooo0027ooooo`;o00008oooool3o`0001oooooo0_l0002Hooooo`00Qoooool2
o`0002?ooooo0ol0000Oooooo`;o0000V?ooool008Oooooo0_l0000<ooooo`;o00005Oooool00ol0
003oooooooooo`0Jooooo`;o00000_ooool2o`0009Wooooo0027ooooo`;o00003?ooool2o`0001Go
oooo00?o0000ooooooooool06_ooool2o`0000;ooooo0_l0002Iooooo`00Qoooool2o`0000cooooo
0_l0000Eooooo`03o`000?oooooooooo01oooooo0_l0002Hooooo`00Qoooool3o`0000_ooooo0_l0
000Eooooo`03o`000?oooooooooo01oooooo0_l0002Hooooo`00Qoooool3o`0000gooooo0_l0000C
ooooo`04o`000?oooooo0000o`000;Sooooo002Aooooo`06onk^k_lb<S;o0000oc8b<_o^k^kooooo
0ol000000ooooooo8B4Qob4Q8@05ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool01?l0003o
ooooo`000?l0000Hooooo`;o00000_ooool2o`0009[ooooo002Aooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00_ooool2o`000003oooooolQ8B7o8B4Q00Sooooo00?oMgMgoc8b<_ooool00_ooool4o`00
01[ooooo0_l00002ooooo`;o0000V_ooool0097ooooo00Go410@oooooooooooooooooa0@4004oooo
o`;o00002_ooool01?l0003oooooooooooooool4o`000;[ooooo002Aooooo`05o`000?oooooooooo
ooooool000001?ooool2o`0000Wooooo00?oMgMgoc8b<_ooool01?ooool3o`0001Kooooo0_l0002Q
ooooo`00TOooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`?o00005_ooool2o`000:7ooooo002Aooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo1Ol0002Nooooo`00TOooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo1?l00003ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool05oooool4o`0009kooooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool4o`0000?ooooo1?l000000ooooooo0000o`000004o`0001Gooooo0_l000001?oooooo0000o`00
0?ooool2o`0009kooooo002;ooooo`;o00004Oooool2o`0000Oooooo1_l0000Eooooo`;o000000?o
ooooo`000?l000000ol0002Nooooo`00ROooool4o`00017ooooo0_l00008ooooo`;o00000_ooool0
0ol0003oooooooooo`0Eooooo`;o000000?oooooo`000?l00000Woooool008Wooooo0_l0000Aoooo
o`;o00002_ooool2o`0000;ooooo00?o0000ooooooooool05Oooool2o`000:;ooooo002Looooo`;o
00001_ooool2o`0000Kooooo0ol0002iooooo`00Y?ooool2o`0000Kooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool05_ooool2
o`000:7ooooo002Tooooo`;o00001_ooool00ol0003oooooooooo`0Fooooo`;o0000XOooool00:Co
oooo0_l00006ooooo`03o`000?oooooooooo017ooooo0ol0002Uooooo`00SOooool2o`0001Gooooo
0_l00006ooooo`03o`000?oooooooooo017ooooo0ol0002Uooooo`00SOooool2o`0001Gooooo0_l0
0006ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool03Oooool4o`000:Sooooo002/ooooo`03o`00
0?oooooooooo00gooooo1?l0002Xooooo`00[?ooool00ol0003oooooooooo`0<ooooo`;o0000Zooo
ool00:cooooo00?o0000ooooooooool03?ooool2o`000:_ooooo002<ooooo`;o00007_ooool00ol0
003oooooooooo`0;ooooo`;o0000[?ooool008cooooo0_l0000Nooooo`03o`000?oooooooooo00_o
oooo0_l0002/ooooo`00[?ooool3o`00017ooooo0_l0002Vooooo`00[?ooool00ol0003ooooooooo
o`0Aooooo`;o0000Y_ooool008gooooo0_l0000Mooooo`03o`000?oooooooooo0;Wooooo002=oooo
o`;o00007Oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0:ooooo`;o
0000[Oooool00:cooooo00?o0000ooooooooool02_ooool4o`000:_ooooo002/ooooo`03o`000?oo
oooooooo00cooooo0_l0002[ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00T_ooool2o`00
01Sooooo00?o0000ooooooooool0^Oooool009;ooooo0_l0000Hooooo`?o00001oooool2o`000003
ooooool0003o000000;o0000Zoooool00:cooooo00?o0000ooooooooool01oooool2o`000003oooo
ool0003o000000;o0000Zoooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool00_ooool2o`000;Gooooo0029ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool00_ooool2o`0000Cooooo0_l0002_
ooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWo
oooo00Oooooo00?oMgMgoc8b<_ooool01?ooool01?l0003oooooooooooooool2o`0000Gooooo0_l0
002_ooooo`00ROooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?oo
ool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00001Oooool2o`000:oooooo
0029ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMg
Molb<S;ooooo00Cooooo0ol00002ooooo`;o00001?ooool2o`000:oooooo0029ooooo`05o`000?oo
ooooooooooooool000001?ooool2o`0000Sooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool00_ooool2o`000;Gooooo0029ooooo`05oa0@
4?ooooooooooooooool@41001?ooool2o`0000Sooooo00?oZJVYogMgMoooool00oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00?ooooo0_l0002dooooo`00ROooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool00oooool3o`000;?ooooo0029ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01?ooool2o`0000Gooooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`04oooo
o`;o0000/oooool009;ooooo0_l0000Hooooo`03o`000?oooooooooo0;Wooooo002Dooooo`;o0000
1Oooool2o`0000oooooo00?o0000ooooooooool0^Oooool009Cooooo0_l000000ooooooo0000o`00
0002ooooo`;o00003oooool00ol0003oooooooooo`2iooooo`00Uoooool2o`0000;ooooo0_l0000?
ooooo`?o0000^Oooool009Sooooo0_l0000>ooooo`;o00000_ooool00ol0003oooooooooo`2ioooo
o`00V?ooool2o`0000Sooooo0_l00004ooooo`;o00000_ooool00ol0003oooooooooo`2iooooo`00
V?ooool2o`0000Sooooo0_l00004ooooo`;o00000_ooool00ol0003oooooooooo`2iooooo`00V?oo
ool2o`0000_ooooo0_l000000ooooooo0000o`000002ooooo`03o`000?oooooooooo0;Wooooo002H
ooooo`;o00002oooool2o`0000Gooooo00?o0000ooooooooool0^Oooool009Sooooo0_l00007oooo
o`;o00002Oooool00ol0003oooooooooo`2iooooo`00XOooool2o`0000Wooooo00?o0000oooooooo
ool0^Oooool009gooooo0_l00005ooooo`;o000000Coooooo`000?l0003o00000_ooool3o`000;Wo
oooo002Mooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`Ko0000^oooool00:7ooooo
0_l000000ooooooo0000o`000004ooooo`?o0000^oooool00:cooooo00?o0000ooooooooool0^Ooo
ool009kooooo0_l0000<ooooo`03o`000?oooooooooo0;Wooooo002Nooooo`;o00003?ooool00ol0
003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:;ooooo1?l000000ol@413ooooooooo
o`03ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0^Oooool00:Cooooo00?o0000ooooooooool01Oooool3o`000;Wooooo002Tooooo`03
o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oo
oooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Rooooo`03oeEEEOmVIVKo0000
0<?ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Zoooo
o`04oa0@4?l0003o0000o`000;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03
o`000?oooooooooo0;[ooooo002[ooooo`06o`000?mgMgOo0000o`000?mEEEGok^k^]oooool00:_o
oooo00Ko0000oeEEEOo^k^koooooogMgMomEEEFgooooo`00Zoooool00ol0003ok^k^ooooo`02oooo
o`03o`000?oooooooooo0;Gooooo002[ooooo`03o`000?o^k^kooooo00;ooooo00?o0000oooooooo
ool0]Oooool00:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomVIVJgooooo`00Z_ooool00ol@413o
0000ogMgM`02o`000003ofIVI_o^k^kooooo0;Kooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.64407 .54133 Mdot
.64925 .58417 Mdot
.45391 .59816 Mdot
.54198 .40269 Mdot
.44107 .77844 Mdot
.6282 .41637 Mdot
.51532 .45218 Mdot
.36876 .62928 Mdot
.37155 .40318 Mdot
.55913 .57415 Mdot
.53993 .66989 Mdot
.38253 .2332 Mdot
.64704 .65037 Mdot
.56485 .56505 Mdot
.47354 .0132 Mdot
.55545 .45545 Mdot
.55322 .25647 Mdot
.6471 .65269 Mdot
.50743 .76896 Mdot
.58546 .82399 Mdot
.61085 .73664 Mdot
.6278 .67485 Mdot
.59111 .75702 Mdot
.63614 .68521 Mdot
.4975 .01623 Mdot
.40018 .53595 Mdot
.49912 .7652 Mdot
.48018 .79909 Mdot
.55499 .86858 Mdot
.63619 .63606 Mdot
.55894 .8263 Mdot
.37024 .57934 Mdot
.36805 .41882 Mdot
.59367 .35168 Mdot
.59051 .31663 Mdot
.50257 .91977 Mdot
.41692 .8796 Mdot
.48058 .79337 Mdot
.46534 .94585 Mdot
.36953 .34677 Mdot
.43432 .03596 Mdot
.58827 .32024 Mdot
.61713 .39319 Mdot
.65025 .48486 Mdot
.64469 .46349 Mdot
.41875 .70743 Mdot
.54123 .65607 Mdot
.39826 .82534 Mdot
.42139 .2506 Mdot
.50233 .92931 Mdot
.38864 .77019 Mdot
.49127 .94902 Mdot
.7462 .31102 Mdot
.61371 .39412 Mdot
.59871 .32704 Mdot
.37205 .37075 Mdot
.36513 .51683 Mdot
.53386 .21742 Mdot
.40898 .86205 Mdot
.64281 .45276 Mdot
.40578 .6023 Mdot
.5528 .05582 Mdot
.43569 .91055 Mdot
.44571 .30023 Mdot
.41357 .10759 Mdot
.36885 .55524 Mdot
.55488 .59247 Mdot
.55486 .50503 Mdot
.50927 .75831 Mdot
.61948 .72629 Mdot
.49493 .14907 Mdot
.52252 .50163 Mdot
.54733 .62772 Mdot
.55973 .54657 Mdot
.43511 .90936 Mdot
.44526 .43844 Mdot
.74657 .31207 Mdot
.42139 .28055 Mdot
.50913 .92934 Mdot
.50145 .18567 Mdot
.53365 .87114 Mdot
.63062 .65075 Mdot
.54222 .41411 Mdot
.58424 .30584 Mdot
.37169 .65689 Mdot
.54674 .38476 Mdot
.43915 .77468 Mdot
.40454 .53232 Mdot
.50201 .16595 Mdot
.55438 .52148 Mdot
.5158 .03607 Mdot
.69265 .22759 Mdot
.46106 .26228 Mdot
.41811 .69811 Mdot
.46518 .26141 Mdot
.6667 .18344 Mdot
.56446 .56457 Mdot
.3708 .54704 Mdot
.74841 .31287 Mdot
.47199 .14211 Mdot
.64166 .57112 Mdot
.46419 .14936 Mdot
.40594 .12005 Mdot
.65076 .51723 Mdot
.58877 .78953 Mdot
.59611 .35642 Mdot
.52704 .19783 Mdot
.50344 .77973 Mdot
.46029 .26287 Mdot
.60717 .75032 Mdot
.56464 .55193 Mdot
.53017 .35166 Mdot
.36948 .54596 Mdot
.56937 .83968 Mdot
.78726 .40303 Mdot
.48406 .70703 Mdot
.40238 .46852 Mdot
.38409 .76186 Mdot
.38042 .72811 Mdot
.38446 .70869 Mdot
.64097 .66653 Mdot
.51002 .01191 Mdot
.57278 .79635 Mdot
.56639 .85486 Mdot
.61359 .73854 Mdot
.54866 .44346 Mdot
.54709 .8713 Mdot
.65089 .16377 Mdot
.62112 .66376 Mdot
.42944 .56459 Mdot
.6149 .71063 Mdot
.63681 .60514 Mdot
.40654 .1135 Mdot
.62394 .38356 Mdot
.62163 .40456 Mdot
.54737 .88295 Mdot
.48835 .9591 Mdot
.5436 .87975 Mdot
.54528 .63367 Mdot
.38394 .23631 Mdot
.45779 .0174 Mdot
.63119 .1535 Mdot
.49694 .26899 Mdot
.51589 .74926 Mdot
.54967 .24857 Mdot
.58295 .82426 Mdot
.37577 .69871 Mdot
.79882 .43402 Mdot
.42537 .70394 Mdot
.40415 .53465 Mdot
.43976 .01237 Mdot
.44798 .16755 Mdot
.53688 .69458 Mdot
.64214 .67163 Mdot
.52168 .47881 Mdot
.63584 .51073 Mdot
.46248 .95511 Mdot
.45766 .94297 Mdot
.37237 .64604 Mdot
.40224 .82328 Mdot
.46904 .95884 Mdot
.40158 .40884 Mdot
.52856 .90769 Mdot
.37122 .30508 Mdot
.50134 .91701 Mdot
.6236 .45289 Mdot
.63274 .60691 Mdot
.37359 .67193 Mdot
.59181 .78797 Mdot
.50844 .75857 Mdot
.50839 .93838 Mdot
.47989 .94097 Mdot
.5175 .33121 Mdot
.49571 .77712 Mdot
.41416 .65913 Mdot
.43686 .7528 Mdot
.38387 .2411 Mdot
.6642 .18143 Mdot
.63494 .51525 Mdot
.45092 .67536 Mdot
.52001 .91162 Mdot
.52609 .91597 Mdot
.3821 .22717 Mdot
.5606 .47632 Mdot
.43762 .0295 Mdot
.42607 .47604 Mdot
.37867 .31162 Mdot
.66064 .18114 Mdot
.38676 .76899 Mdot
.3736 .28464 Mdot
.6159 .37853 Mdot
.58783 .81724 Mdot
.44461 .30936 Mdot
.56849 .07789 Mdot
.36858 .61485 Mdot
.42086 .05725 Mdot
.40347 .12703 Mdot
.41641 .68453 Mdot
.68928 .21 Mdot
.52873 .19489 Mdot
.46281 .69358 Mdot
.46116 .69213 Mdot
.52268 .51687 Mdot
.41921 .68994 Mdot
.70066 .22794 Mdot
.63312 .61323 Mdot
.44069 .33376 Mdot
.63269 .44366 Mdot
.51031 .29263 Mdot
.42563 .55188 Mdot
.54869 .64641 Mdot
.6508 .62496 Mdot
.41467 .31891 Mdot
.5891 .79251 Mdot
.55867 .51241 Mdot
.63052 .61748 Mdot
.41667 .31 Mdot
.37716 .25191 Mdot
.42924 .59008 Mdot
.64074 .50947 Mdot
.36476 .45042 Mdot
.40208 .50972 Mdot
.37883 .67616 Mdot
.60213 .76896 Mdot
.51068 .90168 Mdot
.55392 .54784 Mdot
.44785 .78779 Mdot
.65606 .53312 Mdot
.50065 .28557 Mdot
.4711 .01301 Mdot
.54914 .4163 Mdot
.48337 .3398 Mdot
.7188 .26854 Mdot
.48599 .15764 Mdot
.52481 .71434 Mdot
.51547 .01979 Mdot
.49306 .7824 Mdot
.65178 .52221 Mdot
.60487 .7412 Mdot
.63916 .59185 Mdot
.5643 .07002 Mdot
.618 .37274 Mdot
.59427 .7898 Mdot
.49506 .14936 Mdot
.3791 .71036 Mdot
.47892 .26115 Mdot
.42068 .88401 Mdot
.54958 .25877 Mdot
.49133 .1457 Mdot
.45065 .93461 Mdot
.42943 .04008 Mdot
.48199 .70788 Mdot
.46418 .2733 Mdot
.40148 .8141 Mdot
.40728 .35914 Mdot
.49309 .77961 Mdot
.58669 .28703 Mdot
.44663 .42373 Mdot
.36732 .41542 Mdot
.4058 .85448 Mdot
.44669 .17763 Mdot
.52611 .71133 Mdot
.51137 .90258 Mdot
.44091 .64669 Mdot
.46876 .14991 Mdot
.64012 .55446 Mdot
.52706 .69574 Mdot
.62966 .4789 Mdot
.48421 .93668 Mdot
.43329 .22218 Mdot
.534 .88493 Mdot
.59711 .31849 Mdot
.56391 .53937 Mdot
.4744 .15912 Mdot
.47769 .95892 Mdot
.56064 .45988 Mdot
.49502 .79912 Mdot
.38128 .7167 Mdot
.55917 .6074 Mdot
.63592 .47554 Mdot
.52253 .91076 Mdot
.45425 .69913 Mdot
.55414 .57343 Mdot
.39469 .78402 Mdot
.39114 .18553 Mdot
.50667 .77494 Mdot
.51921 .46446 Mdot
.40869 .57718 Mdot
.59528 .79833 Mdot
.40501 .57224 Mdot
.53213 .87078 Mdot
.66609 .19097 Mdot
.39304 .78527 Mdot
.44388 .03411 Mdot
.37666 .64274 Mdot
.49385 .3504 Mdot
.44042 .94046 Mdot
.58367 .10089 Mdot
.60699 .77546 Mdot
.46634 .01522 Mdot
.80382 .44851 Mdot
.44759 .18157 Mdot
.59716 .30722 Mdot
.64112 .5903 Mdot
.37415 .65434 Mdot
.45987 .00898 Mdot
.54495 .6477 Mdot
.37546 .65198 Mdot
.40699 .35859 Mdot
.47688 .69724 Mdot
.64182 .65115 Mdot
.55308 .25378 Mdot
.63376 .68203 Mdot
.43916 .01486 Mdot
.46506 .7059 Mdot
.64069 .52815 Mdot
.59349 .34362 Mdot
.42007 .08732 Mdot
.45362 .69171 Mdot
.39113 .17441 Mdot
.54928 .06479 Mdot
.61098 .11805 Mdot
.55129 .44894 Mdot
.61927 .35995 Mdot
.57773 .28705 Mdot
.42598 .89122 Mdot
.47103 .81444 Mdot
.49541 .68134 Mdot
.50787 .40345 Mdot
.52794 .20139 Mdot
.36458 .52223 Mdot
.38969 .74366 Mdot
.45483 .2741 Mdot
.64335 .6405 Mdot
.43163 .5944 Mdot
.52215 .52738 Mdot
.6555 .54163 Mdot
.62437 .39597 Mdot
.62361 .45119 Mdot
.40307 .38873 Mdot
.41814 .68112 Mdot
.73112 .27579 Mdot
.42368 .25862 Mdot
.6217 .67029 Mdot
.46016 .27194 Mdot
.37279 .34927 Mdot
.49885 .76426 Mdot
.53975 .88331 Mdot
.61176 .70396 Mdot
.47093 .25109 Mdot
.41516 .32621 Mdot
.62476 .14388 Mdot
.37333 .30966 Mdot
.4655 .96631 Mdot
.50835 .91449 Mdot
.42478 .24267 Mdot
.54774 .23173 Mdot
.49612 .93155 Mdot
.47482 .15123 Mdot
.3755 .28897 Mdot
.5877 .08469 Mdot
.59321 .79254 Mdot
.4113 .09849 Mdot
.39553 .15265 Mdot
.40192 .11916 Mdot
.52039 .55928 Mdot
.4768 .15566 Mdot
.4684 .01266 Mdot
.36547 .47876 Mdot
.52001 .56543 Mdot
.5528 .84071 Mdot
.45414 .18327 Mdot
.63047 .41691 Mdot
.64211 .56456 Mdot
.37008 .49858 Mdot
.65106 .52747 Mdot
.41854 .88762 Mdot
.39566 .77677 Mdot
.58987 .75776 Mdot
.4847 .96564 Mdot
.60956 .72018 Mdot
.48117 .00803 Mdot
.79085 .40432 Mdot
.37746 .63484 Mdot
.6379 .48416 Mdot
.52031 .52087 Mdot
.51677 .03025 Mdot
.48213 .14569 Mdot
.50626 .39666 Mdot
.37568 .27344 Mdot
.61792 .73017 Mdot
.50428 .65705 Mdot
.558 .56587 Mdot
.4008 .48653 Mdot
.51774 .73121 Mdot
.40053 .83778 Mdot
.62587 .72761 Mdot
.57911 .0926 Mdot
.38325 .21866 Mdot
.56926 .28474 Mdot
.73682 .29778 Mdot
.56124 .26231 Mdot
.44592 .77606 Mdot
.45976 .8015 Mdot
.45676 .36205 Mdot
.36501 .47177 Mdot
.38329 .22885 Mdot
.50234 .75891 Mdot
.49413 .26865 Mdot
.56096 .61467 Mdot
.55377 .41643 Mdot
.44182 .01479 Mdot
.43383 .76556 Mdot
.52296 .89169 Mdot
.51985 .32658 Mdot
.52938 .7125 Mdot
.44137 .6518 Mdot
.43302 .75963 Mdot
.59085 .34521 Mdot
.53969 .68315 Mdot
.44302 .3233 Mdot
.37993 .26592 Mdot
.47535 .62437 Mdot
.59241 .31935 Mdot
.52861 .2006 Mdot
.63204 .56364 Mdot
.46198 .17381 Mdot
.50684 .7594 Mdot
.49779 .00868 Mdot
.6604 .16789 Mdot
.64842 .55784 Mdot
.77783 .37841 Mdot
.65158 .47824 Mdot
.43569 .3504 Mdot
.38937 .2249 Mdot
.47917 .01198 Mdot
.52599 .70589 Mdot
.60171 .72512 Mdot
.73607 .2871 Mdot
.50262 .28588 Mdot
.50701 .64441 Mdot
.42424 .70434 Mdot
.5273 .88317 Mdot
.4775 .16469 Mdot
.69094 .218 Mdot
.42522 .4878 Mdot
.61072 .39009 Mdot
.57562 .2858 Mdot
.44449 .29976 Mdot
.45228 .68214 Mdot
.56257 .49027 Mdot
.36725 .59962 Mdot
.47183 .71328 Mdot
.5272 .9077 Mdot
.65072 .56583 Mdot
.64401 .49877 Mdot
.54402 .87379 Mdot
.53372 .8663 Mdot
.55715 .25935 Mdot
.62551 .12454 Mdot
.55852 .56585 Mdot
.36446 .52125 Mdot
.41739 .06704 Mdot
.51841 .71563 Mdot
.45167 .95577 Mdot
.44851 .18891 Mdot
.56448 .28708 Mdot
.54606 .87517 Mdot
.64398 .55858 Mdot
.49329 .79269 Mdot
.41299 .34098 Mdot
.58695 .32832 Mdot
.51076 .00776 Mdot
.62552 .44294 Mdot
.44199 .49704 Mdot
.61964 .41833 Mdot
.49033 .16969 Mdot
.52379 .52221 Mdot
.55343 .49525 Mdot
.61084 .38106 Mdot
.61467 .36975 Mdot
.47429 .70625 Mdot
.41069 .33502 Mdot
.36852 .54211 Mdot
.45741 .80784 Mdot
.63919 .55158 Mdot
.53841 .70045 Mdot
.44672 .76877 Mdot
.51667 .59331 Mdot
.78228 .37811 Mdot
.51106 .61965 Mdot
.65282 .56292 Mdot
.37158 .51028 Mdot
.50988 .90793 Mdot
.50633 .76501 Mdot
.53445 .89249 Mdot
.38219 .22969 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o0000
]oooool009kooooo0_l00004ooooo`?o00001?ooool2o`0000;ooooo0_l0002gooooo`00V?ooool2
o`0000Cooooo0_l000000ooooooo0000o`000004o`0000Cooooo0_l00002ooooo`;o0000]oooool0
09Oooooo0ol00006ooooo`Oo00001?ooool2o`0000;ooooo0_l0002gooooo`00Uoooool3o`0000Co
oooo1?l00009ooooo`;o00001?ooool2o`000;Gooooo002Nooooo`;o00003?ooool00ol0003ooooo
ooooo`02ooooo`;o0000]Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool00_ooool2o`000;Gooooo002Gooooo`Co
00004Oooool00ol0003oooooooooo`02ooooo`;o0000]Oooool009Kooooo0_l000000ooooooo0000
o`00000Aooooo`03o`000?oooooooooo00;ooooo0_l0002eooooo`00U?ooool4o`0001Cooooo00?o
0000ooooooooool00_ooool2o`000;Gooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo00kooooo0_l0002Yooooo`00TOooool2
o`0001Wooooo00?o0000ooooooooool03_ooool2o`000:Wooooo002Aooooo`;o00006Oooool00ol0
003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0=ooooo`;o0000Z_ooool0093ooooo
0_l0000Jooooo`03o`000?oooooooooo00gooooo0_l0002Zooooo`00T?ooool2o`0001[ooooo00?o
0000ooooooooool04_ooool2o`000:Gooooo002/ooooo`03o`000?oooooooooo01;ooooo0_l0002U
ooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo01?ooooo0_l0002Tooooo`00
[?ooool00ol0003oooooooooo`0Cooooo`;o0000Y?ooool00:cooooo00?o0000ooooooooool06_oo
ool2o`0009gooooo002Aooooo`;o00006Oooool00ol0003oooooooooo`0Jooooo`;o0000WOooool0
097ooooo0_l0000Iooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo01Oo
oooo0_l0002Pooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool05oooool2o`000:3ooooo
002>ooooo`;o00007?ooool3o`0001Sooooo0_l0002Oooooo`00[?ooool00ol0003oooooooooo`0H
ooooo`;o0000Woooool008oooooo0_l0000Kooooo`03o`000?oooooooooo0;Wooooo002?ooooo`;o
00006oooool00ol0003oooooooooo`2iooooo`00SOooool2o`0001gooooo00?o0000ooooooooool0
^Oooool008gooooo0_l0000Mooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05onk^k_lb<S;o
0000o`000?o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Gooooo00?o0000ooooooooool08Oooool2o`0009Kooooo0029ooooo`03ogMgMonH
V9So000000?o00001?ooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo027ooooo0_l0002Fooooo`00POooool6o`0000;ooooo00Co410@
oooooooooooooooo0_l0000<ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00ooo
ool3o`0002Kooooo0_l0002Aooooo`00ROooool00ol0003oooooooooo`02o`0000kooooo00?o8B4Q
ooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02Kooooo0_l0002A
ooooo`00ROooool00ol0003oooooooooo`02o`0000kooooo00?oEEEEolc<c?ooool00oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0^Oooool008Wooooo00Go410@oooo
oooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`2iooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@
oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0^Ooo
ool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo00?o
0000ooooooooool0^Oooool00:;ooooo0_l00008ooooo`03o`000?oooooooooo02Kooooo0_l0002A
ooooo`00X_ooool2o`0000;ooooo0_l000001Ooooooo0000o`000?oooooo000002Sooooo0_l0002A
ooooo`00X?ooool3o`0000?ooooo0_l000000ooooooo0000o`000002o`000;_ooooo0029ooooo`;o
00005Oooool5o`0000Gooooo1Ol0002iooooo`00ROooool2o`0001Sooooo0ol00006ooooo`03o`00
0?oooooooooo02Sooooo0_l0002?ooooo`00Xoooool3o`000003ooooool0003o000000?ooooo00?o
0000ooooooooool0:?ooool2o`0008oooooo002Sooooo`;o00000_ooool2o`0000?ooooo00?o0000
ooooooooool0^Oooool00:Cooooo0_l00006ooooo`03o`000?oooooooooo02kooooo0_l00029oooo
o`00V_ooool2o`0000Sooooo0_l00006ooooo`;o0000;oooool2o`0000;ooooo0_l00025ooooo`00
V_ooool2o`0000cooooo0_l00002ooooo`;o0000<oooool2o`0008Gooooo002Oooooo`;o00001ooo
ool2o`0000;ooooo00?o0000ooooooooool0^Oooool008Sooooo0_l0000Eooooo`;o00002oooool3
o`000;Wooooo0028ooooo`;o00004?ooool2o`00013ooooo00?o0000ooooooooool0^Oooool009[o
oooo1?l0000>ooooo`03o`000?oooooooooo03;ooooo1?l00023ooooo`00R?ooool2o`00013ooooo
1?l0000>ooooo`;o0000<oooool4o`0008?ooooo0028ooooo`;o00004Oooool2o`0000oooooo0_l0
002jooooo`00Voooool2o`0000oooooo00?o0000ooooooooool0<oooool2o`0008Cooooo002/oooo
o`03o`000?oooooooooo00Kooooo0_l0000[ooooo`;o0000Q?ooool00:cooooo00?o0000oooooooo
ool01Oooool3o`000;7ooooo002/ooooo`?o00001Oooool3o`000;7ooooo002/ooooo`03o`000?oo
oooooooo00Kooooo0_l0002aooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`0kooooo`;o0000O?ooool00:cooooo00?o0000ooooooooool0>oooool2o`0007co
oooo002/ooooo`03o`000?oooooooooo0;Wooooo0025ooooo`;o00009Oooool00ol0003ooooooooo
o`08ooooo`;o0000<_ooool2o`0007_ooooo0025ooooo`;o00003oooool2o`0001Cooooo00?o0000
ooooooooool02?ooool2o`0003;ooooo0_l0001kooooo`00Qoooool2o`0000gooooo0_l0000Doooo
o`?o0000^Oooool008Gooooo1?l0000Sooooo`03o`000?oooooooooo03cooooo0_l000000ooooooo
0000o`00001hooooo`00QOooool2o`0002Gooooo00?o0000ooooooooool03?ooool2o`0002kooooo
0_l000000ooooooo0000o`00001hooooo`00QOooool2o`0002Gooooo00?o0000ooooooooool03?oo
ool2o`000:_ooooo0025ooooo`;o00009Oooool00ol0003oooooooooo`2iooooo`00QOooool2o`00
02Gooooo00?o0000ooooooooool0^Oooool008Gooooo0_l0000:ooooo`05onk^k_lb<S;o0000o`00
0?o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0;Wooooo0025ooooo`;o00002_ooool01OmgMgOoV9RHo`000?l0003oMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0^Oooool008Wooooo1_l00002oooo
o`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00gooooo0_l0002Zooooo`00Poooool2o`0000cooooo0ol000000ooooooo0000ooooo`0;oooo
o`;o000000?oooooogMgMolb<S801Oooool3o`0000gooooo0_l0002Zooooo`00Poooool2o`0000co
oooo0ol000000ooooooo0000ooooo`0;ooooo`?o000000?o<S8bolc<c?ooool01?ooool00ol0003o
ooooooooo`0>ooooo`;o0000ZOooool0097ooooo00Go410@o`000?l0003ooooooa0@400<ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool03Oooool3o`000:Wooooo002Aooooo`05ogMg
Mol0003o0000oiRHV?mgMgL02_ooool3o`0000;ooooo0_l00005ooooo`03o`000?oooooooooo00go
oooo1?l0002Xooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo2Ol00005ooooo`03
o`000?oooooooooo00oooooo1?l0002Vooooo`00Q?ooool2o`0001Sooooo0ol0000;ooooo`03o`00
0?oooooooooo017ooooo0_l0002Vooooo`00Q?ooool2o`0002Cooooo0ol00017ooooo`;o0000L_oo
ool008?ooooo0_l0000Hooooo`Go00002?ooool3o`0004Oooooo0_l0001booooo`00Poooool2o`00
01Sooooo1Ol0000:ooooo`?o0000BOooool2o`0006kooooo002/ooooo`03o`000?oooooooooo04Wo
oooo0_l0001^ooooo`00T_ooool2o`0001Sooooo00?o0000ooooooooool0^Oooool008;ooooo0_l0
000>ooooo`;o00006?ooool2o`0001Cooooo0_l000000ooooooo0000o`00002Qooooo`00P_ooool2
o`0002Sooooo0_l0000Cooooo`?o000000Coooooo`000?l0003ooooo0_l0000_ooooo`;o0000KOoo
ool008;ooooo0_l0000Xooooo`03o`000?oooooooooo01;ooooo0_l00002ooooo`;o000000?ooooo
o`000?l00000;oooool2o`0006gooooo002/ooooo`03o`000?oooooooooo00;o0000]oooool00:co
oooo00?o0000ooooooooool00_l00019ooooo`;o0000K?ooool009Wooooo0ol0000@ooooo`?o0000
Boooool2o`0006cooooo002Iooooo`?o00004?ooool00ol0003oooooooooo`2iooooo`00POooool2
o`0002Wooooo00?o0000ooooooooool06?ooool2o`0000?ooooo0_l0002Jooooo`00POooool3o`00
00cooooo0_l00007ooooo`;o00004Oooool00ol0003oooooooooo`0Hooooo`;o00000oooool2o`00
09[ooooo0022ooooo`Co00002_ooool2o`0000Oooooo0_l0000Aooooo`03o`000?oooooooooo04ko
oooo0ol0001Xooooo`00Q?ooool2o`0002Kooooo00?o0000ooooooooool06_ooool2o`0003;ooooo
0ol0001Xooooo`00Soooool2o`0001_ooooo00?o0000ooooooooool06_ooool5o`0009[ooooo002?
ooooo`;o00006oooool00ol0003oooooooooo`0Jooooo`Go0000V_ooool009Wooooo0_l0000Aoooo
o`?o00006_ooool2o`0009gooooo002@ooooo`;o00001oooool2o`00017ooooo00?o0000oooooooo
ool00oooool2o`0001Cooooo0_l00002ooooo`;o0000V_ooool0093ooooo0_l0000Jooooo`03o`00
0?oooooooooo00;ooooo0ol0000Dooooo`;o00000_ooool2o`0009[ooooo002Hooooo`;o00004_oo
ool00ol0003oooooooooo`02ooooo`;o0000]Oooool008kooooo0_l00008ooooo`;o00004_ooool0
0ol0003oooooooooo`2iooooo`00S_ooool2o`0001Kooooo0_l00004ooooo`03o`000?oooooooooo
0;Wooooo002?ooooo`;o00005Oooool2o`0000Cooooo00?o0000ooooooooool06oooool2o`0009co
oooo0020ooooo`;o00003Oooool2o`0001_ooooo00?o0000ooooooooool06oooool2o`0009cooooo
0020ooooo`Co0000:?ooool00ol0003oooooooooo`0Kooooo`;o0000W?ooool008;ooooo0_l0000B
ooooo`;o00004_ooool5o`0000Oooooo0_l0000Booooo`;o0000W?ooool009Kooooo0_l0000Boooo
o`?o00002Oooool2o`0001;ooooo0_l0002Looooo`00SOooool2o`0001gooooo00?o0000oooooooo
ool07?ooool2o`0009_ooooo002=ooooo`;o00003_ooool2o`0000gooooo00?o0000ooooooooool0
7?ooool2o`0000Kooooo0_l0002Cooooo`00WOooool2o`0000gooooo00?o0000ooooooooool09?oo
ool2o`0009?ooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0
0004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2iooooo`00POoo
ool2o`0000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Q
onk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Rooooo`;o
0000UOooool0087ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08_ooool4o`0009?o
oooo0029ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03
ogMgMolb<S;ooooo00Cooooo0ol0000Tooooo`;o0000Toooool008Wooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005oooo
o`03o`000?oooooooooo02?ooooo0_l0000cooooo`Co0000GOooool008Wooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Qooooo`Co0000<oooool4o`0005gooooo0029ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0<ooooo`;o00004oooool2o`0000;ooooo0_l0002Booooo`00ROooool00oo^
k^ko<S8bo`000002o`0000_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool0
0ol0003oooooooooo`0<ooooo`;o00005oooool2o`0009;ooooo002<ooooo`;o00007_ooool00ol0
003oooooooooo`0Qooooo`;o0000U_ooool00:cooooo00?o0000ooooooooool08Oooool4o`0009Co
oooo002/ooooo`04o`000?oooooo0000o`00027ooooo0ol000000ooooooo0000o`00002Aooooo`00
[?ooool4o`0002Gooooo0_l0002Aooooo`00POooool2o`0002Wooooo00Co0000ooooool0003o0000
2Oooool2o`0001Wooooo0_l0000dooooo`Co0000F_ooool0087ooooo0_l0000Yooooo`04o`000?oo
oooo0000o`0000Wooooo0_l0000Iooooo`;o0000=?ooool4o`0005[ooooo002;ooooo`;o00007ooo
ool00ol0003oooooooooo`2iooooo`00Roooool2o`0001oooooo00?o0000ooooooooool0^Oooool0
083ooooo0_l0000Zooooo`03o`000?oooooooooo00_ooooo1Ol0000Gooooo`;o0000T?ooool0083o
oooo0_l0000Zooooo`03o`000?oooooooooo00_ooooo1Ol0000Dooooo`;o000000Coooooo`000?l0
003o0000Soooool0083ooooo0_l0000Zooooo`03o`000?oooooooooo02Cooooo0_l00002ooooo`;o
0000Soooool009[ooooo0_l0000@ooooo`?o0000^Oooool009[ooooo0_l0000@ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
05oooooo0_l0001Hooooo`00[?ooool00ol0003oooooooooo`1Oooooo`;o0000F?ooool009Wooooo
0_l0000Aooooo`03o`000?oooooooooo0;Wooooo002Iooooo`;o00004Oooool00ol0003ooooooooo
o`0=ooooo`;o00005oooool4o`0008oooooo002/ooooo`03o`000?oooooooooo00gooooo0_l0000G
ooooo`Co0000Soooool00:cooooo00?o0000ooooooooool03Oooool2o`0005;ooooo0_l0001Foooo
o`00Ooooool2o`0002_ooooo0ol00002ooooo`;o00002Oooool2o`0001Kooooo0_l00005ooooo`;o
0000<oooool2o`0005Kooooo001oooooo`;o0000:oooool00ol0003oooooooooo`02ooooo`;o0000
2oooool2o`0001Cooooo0_l00005ooooo`;o0000Roooool00:cooooo00?o0000ooooooooool03ooo
ool2o`000:Sooooo0009ooooo`Co000000?o410@ooooooooool05_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8b
omgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0
003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004
ooooo`05odA4A?l0003o0000oc8b<_oMgMd05_ooool00ol0003oooooooooo`0Aooooo`;o00001Ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000
o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4
A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd06?ooool4o`000003oa0@
4?oooooooooo01;ooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007
ooooo`03ogMgMolb<S;ooooo01Gooooo00?o0000ooooooooool00oooool2o`0000cooooo0_l00005
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00CoV9RHob4Q8Oo^k^kooooo
0_l00006ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo
01Cooooo0006o`0000Gooooo00?o0000ooooooooool04?ooool6o`0000;ooooo00Go410@oooooooo
oooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool01Oooool6o`00
00;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00Gooooo1_l00002
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool00oooool2o`0001?ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00;o00001oooool00ol0003oooooooooo`0=ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0=ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo0000
00kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`0>ooooo`05o`000?oooooooooo
ooooool000003oooool00omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003Ooo
ool00onHV9So0000o`000007ooooo`03ogMgMolb<S;ooooo01Gooooo00?o0000ooooooooool06?oo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8b
ooooo`0>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0>ooooo`05
o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo
01Wooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol0003o
oooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
3oooool01Ol0003ooooooooooooooooo000000;ooooo0_l0000:ooooo`;o00001?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<01Kooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo
000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go
0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003o
oooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<01[ooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol@
413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`0A
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0Aooooo`05oa0@4?oo
ooooooooooooool@41000_ooool2o`0000_ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
o`000?l0000Gooooo`?o00004Oooool2o`0000Gooooo00Go410@oooooooooooooooooa0@400<oooo
o`;o000000?oooooo`000?ooool00oooool00ol0003oooooooooo`0Aooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003_oo
ool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05?oo
ool000_ooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0<ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02oooo
o`;o00001oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00Co0000ooooool0003o00005ooo
ool00ol0003oooooooooo`04ooooo`;o00002oooool2o`0000Gooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0:ooooo`Co000000CoV9RHoa0@4?oooooooooo0ol0000Cooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0Dooooo`002Oooool00omEEEGoIVIVo`00000Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool5o`0000Cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00013ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`;o00001oooool01OnHV9So410@o`000?lQ8B7oc<c<
00Cooooo1?l0000Gooooo`03o`000?oooooooooo00Cooooo0_l0000Booooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02_ooool2o`000004oa0@4?l0003o8B4Qolc<c0;ooooo1_l0000@ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go
00001?ooool4o`0001Wooooo00?oEEEEofIVI_l000005_ooool00:cooooo00?o0000ooooooooool0
:_ooool2o`0000;ooooo0_l00029ooooo`00Roooool2o`0000Kooooo0_l0000Gooooo`03o`000?oo
oooooooo02[ooooo0_l00002ooooo`;o0000ROooool008_ooooo0_l00006ooooo`;o00005oooool0
0ol0003oooooooooo`0Aooooo`;o0000Voooool2o`0000;ooooo0_l00005ooooo`00[?ooool00ol0
003oooooooooo`0>ooooo`;o000000?oooooo`000?l00000Voooool01_o^k^ko8B4QohN7Qonj^[[o
0000omgMg@Gooooo002Hooooo`;o00004_ooool00ol0003oooooooooo`0>ooooo`;o0000Woooool0
1?oMgMgo0000oa0@4?o<c<`6ooooo`001oooooooo`0004co00003?ooool01?o^k^ko8B4Qoa0@4?o^
k^h6ooooo`001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool3o`0000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04
ooooo`?o00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`02ooooo`;o000000?oooooo`000?ooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00Co8B4QogMgMomgMgOo<S8b1_oo
ool000Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`04ooooo`;o00002Oooool2
o`0001Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool02Oooool2o`0000;ooooo0_l00005ooooo`00POooool2o`00
00Sooooo0_l0000Oooooo`03o`000?oooooooooo00oooooo0_l0000Jooooo`;o0000S?ooool0087o
oooo0_l00008ooooo`;o00007oooool00ol0003oooooooooo`0@ooooo`;o00005oooool4o`0008co
oooo002/ooooo`03o`000?oooooooooo013ooooo0_l0000Gooooo`;o0000S_ooool007oooooo0_l0
000[ooooo`03o`000?oooooooooo00Cooooo0_l0000Sooooo`;o00000oooool2o`0008Wooooo001o
ooooo`;o0000:oooool00ol0003oooooooooo`03ooooo`?o00002Oooool2o`0001gooooo0ol00028
ooooo`00Ooooool2o`0002_ooooo0ol00003ooooo`?o00002Oooool2o`0001kooooo0_l00028oooo
o`00[?ooool00ol0003oooooooooo`04ooooo`;o00009Oooool2o`000003ooooool0003o000008Wo
oooo002/ooooo`03o`000?oooooooooo00Cooooo0_l0000Uooooo`;o000000?oooooo`000?l00000
ROooool008cooooo0_l0000Nooooo`03o`000?oooooooooo033ooooo0_l00027ooooo`00Roooool3
o`0001kooooo00?o0000ooooooooool0<?ooool2o`0008Oooooo002;ooooo`;o00007oooool00ol0
003oooooooooo`0Booooo`;o0000YOooool0083ooooo0_l0000Zooooo`03o`000?oooooooooo01;o
oooo0_l0000Hooooo`;o00000_ooool2o`0008Oooooo0020ooooo`;o0000:_ooool00ol0003ooooo
ooooo`0@ooooo`;o00006_ooool2o`0000;ooooo0_l00027ooooo`00P?ooool3o`0002Wooooo00?o
0000ooooooooool03_ooool4o`000:Oooooo0021ooooo`;o00004?ooool2o`0001Oooooo0ol0000>
ooooo`;o00000_ooool2o`0001Oooooo0_l0002<ooooo`00P?ooool2o`00017ooooo0_l0000Goooo
o`03o`000?oooooooooo01;ooooo0_l0000Gooooo`;o0000S?ooool0083ooooo0_l0000Zooooo`03
o`000?oooooooooo02_ooooo1Ol00029ooooo`00[?ooool00ol0003oooooooooo`03ooooo`;o0000
9oooool4o`0008Wooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`03ooooo`;o00003Ooo
ool2o`0001Cooooo0_l000000ooooooo0000o`000002ooooo`;o0000R?ooool009Cooooo0_l0000F
ooooo`03o`000?oooooooooo00?ooooo0_l0000;ooooo`Co00005?ooool2o`000004ooooool0003o
0000ooooo`?o0000R?ooool00:cooooo00?o0000ooooooooool00oooool2o`0000_ooooo0_l0000I
ooooo`;o000000?oooooo`000?l00000ROooool008cooooo0_l0000Nooooo`03o`000?oooooooooo
00kooooo1?l0000Iooooo`;o0000S?ooool008cooooo0ol0000Mooooo`?o00003_ooool4o`000:Oo
oooo0021ooooo`;o00002_ooool2o`0001gooooo00?o0000ooooooooool0^Oooool0087ooooo0_l0
000Yooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo02kooooo0_l00029
ooooo`00[?ooool00ol0003oooooooooo`0^ooooo`;o0000ROooool009Cooooo0_l0000Fooooo`03
o`000?oooooooooo02_ooooo0_l0002<ooooo`00U?ooool3o`0001Gooooo00?o0000ooooooooool0
0_ooool2o`0000_ooooo0_l0000Jooooo`;o0000S?ooool009Gooooo0_l00005ooooo`;o00003_oo
ool00ol0003oooooooooo`02ooooo`;o00002oooool2o`000:Sooooo0020ooooo`;o00006_ooool2
o`0000kooooo0ol0002iooooo`00P?ooool2o`0000[ooooo0_l0000Nooooo`03o`000?oooooooooo
0;Wooooo002<ooooo`;o00007_ooool00ol0003oooooooooo`0@ooooo`;o00005_ooool4o`0008go
oooo002/ooooo`03o`000?oooooooooo013ooooo0_l0000Fooooo`Co0000SOooool00:cooooo00?o
0000ooooooooool0:Oooool2o`0008kooooo0020ooooo`;o0000:_ooool00ol0003oooooooooo`0A
ooooo`;o00005_ooool2o`0008kooooo0020ooooo`;o00001oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool00_l0000?ooooo`;o00005Oooool2o`0008oooooo0029ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool00_l0000Vooooo`;o0000Soooool008Wooooo00Go
410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0_l000000ooooooo0000
ooooo`04ooooo`?o0000;_ooool2o`0008Wooooo0029ooooo`05o`000?ooooooooooooooool00000
3Oooool00onHV9So8B4Qonk^kP05ooooo`;o000000?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`0<ooooo`;o00008?ooool2o`0008Wooooo0020ooooo`;o00001oooool01Ol0003ooooooooo
oooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool03?ooool2o`000:_ooooo0020ooooo`;o00001oooool01Ol@413ooooo
oooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00cooooo0_l0002[ooooo`00Poooool2o`0000Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00cooooo0_l0000Looooo`;o0000SOooool008?ooooo0_l00004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006
ooooo`03o`000?oooooooooo02[ooooo1?l0002;ooooo`00Poooool2o`0002Oooooo00?o0000oooo
ooooool0;?ooool2o`0008_ooooo0021ooooo`Co00004oooool2o`0001;ooooo00Co0000ooooool0
003o00003?ooool2o`000:[ooooo0021ooooo`;o00005Oooool2o`0001;ooooo00Co0000ooooool0
003o00002_ooool4o`000:[ooooo0022ooooo`;o00005?ooool2o`0001;ooooo0ol0000;ooooo`;o
00006oooool2o`000003ooooool0003o000000;o0000R_ooool008;ooooo0_l0000Dooooo`;o0000
4_ooool00ol0003oooooooooo`0Xooooo`;o000000?oooooo`000?l000000_l0002:ooooo`00POoo
ool3o`0002Sooooo0ol0000:ooooo`;o0000[Oooool0087ooooo0_l0000<ooooo`;o00006oooool3
o`0000[ooooo0_l0002]ooooo`00Soooool2o`0001_ooooo00?o0000ooooooooool09Oooool2o`00
09;ooooo002/ooooo`03o`000?oooooooooo02Gooooo0_l00004ooooo`;o0000S?ooool00:cooooo
00?o0000ooooooooool02_ooool2o`0001Wooooo0_l00004ooooo`;o0000S?ooool008;ooooo0_l0
000Xooooo`03o`000?oooooooooo00[ooooo0_l0000Iooooo`;o00001?ooool2o`0008cooooo0022
ooooo`Co00005Oooool2o`0000oooooo0ol0000Wooooo`;o00000_ooool2o`0008cooooo0024oooo
o`;o00005Oooool2o`0000oooooo00?o0000ooooooooool09oooool2o`00093ooooo002Aooooo`;o
00002Oooool2o`0000cooooo0ol0000<ooooo`;o00007Oooool2o`0008kooooo002@ooooo`?o0000
2Oooool2o`0000cooooo0ol0000<ooooo`;o00007Oooool3o`0008gooooo002@ooooo`;o00006_oo
ool00ol0003oooooooooo`0Zooooo`;o0000SOooool0097ooooo0_l00009ooooo`;o000000?ooooo
o`000?l000002oooool00ol0003oooooooooo`2iooooo`00TOooool2o`0000Wooooo0_l000000ooo
oooo0000o`00000;ooooo`03o`000?oooooooooo00Wooooo0_l0002^ooooo`00TOooool2o`0000co
oooo0_l00003ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`;o00000_ooool2o`000:ko
oooo0023ooooo`;o00003?ooool2o`0000Wooooo0_l00006ooooo`;o00001_ooool3o`0000Gooooo
0_l00002ooooo`;o0000[_ooool008?ooooo0_l0000>ooooo`;o00001oooool2o`0000kooooo00?o
0000ooooooooool02Oooool2o`0001Kooooo0_l0002Fooooo`00TOooool4o`0000_ooooo0_l00000
1?oooooo0000o`000?ooool2o`0000Cooooo00?o0000ooooooooool01Oooool2o`0001[ooooo0_l0
002Fooooo`00Q?ooool3o`0000[ooooo0_l0000=ooooo`;o000000Coooooo`000?l0003ooooo0_l0
0004ooooo`03o`000?oooooooooo00Gooooo0_l0002booooo`00Q?ooool3o`0001_ooooo0_l00002
ooooo`;o00001?ooool00ol0003oooooooooo`05ooooo`?o00006_ooool2o`0009Gooooo002Roooo
o`;o00002?ooool00ol0003oooooooooo`03ooooo`Go00006_ooool2o`0009Gooooo0024ooooo`;o
00009_ooool00ol0003oooooooooo`03ooooo`Co0000/_ooool008Cooooo0_l0000Vooooo`03o`00
0?oooooooooo027ooooo0_l0002Fooooo`00[?ooool3o`0001kooooo0_l000000ooooooo0000o`00
002Fooooo`00Q?ooool2o`0002Kooooo00?o0000ooooooooool07_ooool2o`0000Cooooo1?l0002A
ooooo`00Q?ooool2o`0002Kooooo00?o0000ooooooooool00_ooool2o`0001oooooo1Ol0002Aoooo
o`00[?ooool00ol0003oooooooooo`02ooooo`;o00007oooool2o`0009Cooooo002/ooooo`03o`00
0?oooooooooo027ooooo0_l0002Fooooo`00[?ooool00ol0003oooooooooo`0Qooooo`?o0000UOoo
ool008Oooooo0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01oooooo0_l000000ooooooo0000
o`00002Eooooo`00Qoooool2o`0000Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01oooooo0_l0002Hooooo`00TOoo
ool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`;o0000]Oooool0097ooooo00Ko0000ooooooooooooooooo`000?ooool2o`0000co
oooo00?oMgMgoc8b<_ooool01?ooool3o`0000;ooooo0_l0000Looooo`;o0000Uoooool0097ooooo
00Ko0000ooooooooooooooooo`000?ooool2o`0000Wooooo00Go0000ob4Q8Ol0003o<S8bolc<c005
ooooo`03o`000?oooooooooo023ooooo0_l0002Gooooo`00TOooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool01oooool5o`0001Sooooo0ol0002Looooo`00QOooool2o`00
00[ooooo00CoMgMgoiRHV?ooooooV9RH0_l0000;ooooo`03o`000?oooooooooo00Oooooo1Ol0000H
ooooo`?o0000W?ooool008Gooooo0_l0000:ooooo`04onk^k_lb<S;o0000oc8b<P;o00002oooool4
o`0000Gooooo0_l000000ooooooo0000o`00002hooooo`00U_ooool2o`0001?ooooo0_l000000ooo
oooo0000o`00002hooooo`00Q_ooool3o`0000gooooo0_l00002ooooo`;o00003oooool2o`000003
ooooool0003o000001gooooo0_l0002Iooooo`00Q_ooool3o`00017ooooo0_l0000@ooooo`04o`00
0?oooooo0000o`0001gooooo0_l0002Iooooo`00ROooool2o`0000cooooo0_l000000ooooooo0000
o`00000>ooooo`Ko00007oooool2o`0009Oooooo0029ooooo`;o00003?ooool5o`0000gooooo1ol0
000Oooooo`;o0000Uoooool009Sooooo0_l0000?ooooo`;o000000Coooooo`000?l0003o0000^Ooo
ool008Sooooo0ol0000Nooooo`;o000000?oooooo`000?ooool0^_ooool008Sooooo0ol0000?oooo
o`;o00004?ooool00ol0003oooooooooo`0Kooooo`;o0000W?ooool009[ooooo0_l0000@ooooo`03
o`000?oooooooooo01[ooooo1?l0002Kooooo`00YOooool2o`0000;ooooo0_l000000ooooooo0000
ooooo`0Kooooo`Co0000Voooool00:Gooooo0_l00002ooooo`;o000000?oooooo`000?ooool05_oo
ool2o`0000?ooooo1?l0002Kooooo`00YOooool2o`0000?ooooo1Ol0000Eooooo`;o00001Oooool2
o`0009_ooooo002Nooooo`;o00001Oooool2o`0000?ooooo0ol0002kooooo`00W_ooool2o`0000co
oooo00?o0000ooooooooool0^Oooool009kooooo0_l0000<ooooo`03o`000?oooooooooo0;Wooooo
002Nooooo`;o00003?ooool00ol0003oooooooooo`2iooooo`00Roooool2o`0001Gooooo0_l00008
ooooo`03o`000?oooooooooo0;Wooooo002;ooooo`;o00005Oooool2o`0000Sooooo00?o0000oooo
ooooool06_ooool2o`0009gooooo002/ooooo`03o`000?oooooooooo01[ooooo0_l0002Mooooo`00
R_ooool3o`0001oooooo0ol0000Hooooo`?o0000W_ooool008[ooooo0ol0000Oooooo`03o`000?oo
oooooooo013ooooo0_l00006ooooo`?o0000W_ooool00:cooooo00?o0000ooooooooool04?ooool2
o`000:Oooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002;ooooo`;o00007oooool00ol0003oooooooooo`0>ooooo`;o00000oooool2o`000:Cooooo
002;ooooo`;o00007oooool00ol0003oooooooooo`0>ooooo`;o00000oooool2o`000:Cooooo002/
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o
0000^Oooool008cooooo0_l0000Nooooo`03o`000?oooooooooo01;ooooo0_l0002Uooooo`00S?oo
ool2o`0001kooooo00?o0000ooooooooool04_ooool2o`000:Gooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002>ooooo`;o00007?ooool00ol0003oooooooooo`2iooooo`00ROooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00;o00000oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool02?ooool2o`000:oooooo0029oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00Oooooo0ol00005ooooo`;o0000Z?ooool0
08Wooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`07ooooo`?o000000Goooooo`000?l0003o0000oooo
o`02o`000:Sooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00008ooooo`;o000000Coooooo`000?l0003o0000
Zoooool008Wooooo00Go0000ooooooooooooooooo`000002ooooo`;o00002_ooool00omEEEGoc<c<
ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0;ooooo`?o
0000Zoooool008Wooooo00Go410@oooooooooooooooooa0@4002ooooo`;o00002_ooool00onYZJWo
MgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool2o`0000?o
oooo0ol0002[ooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0_l00006ooooo`05
oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Kooooo2?l0002[ooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo0_l00006oooo
o`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool02?ooool4o`000:gooooo002Aooooo`Co
00005oooool00ol0003oooooooooo`04ooooo`;o0000/oooool009?ooooo0_l0000Gooooo`03o`00
0?oooooooooo00Cooooo0_l00002ooooo`;o0000[oooool00:cooooo00?o0000ooooooooool02?oo
ool2o`000:oooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool00_l0002goooo
o`00[?ooool00ol0003oooooooooo`02o`000;Oooooo002Fooooo`;o00005?ooool00ol0003ooooo
ooooo`02o`0000Cooooo0_l0002aooooo`00U_ooool2o`0001Cooooo00?o0000ooooooooool00_l0
00000ooooooo0000o`000003o`000;7ooooo002Fooooo`;o00005?ooool01?l0003oooooo`000?l0
0002ooooo`Co0000/_ooool00:cooooo1?l00004ooooo`;o0000/_ooool00:cooooo0_l0002joooo
o`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Zooooo`Co000000?o
ooooo`000?l00000]oooool009_ooooo0_l0000=ooooo`Co000000?oooooo`000?l00000]oooool0
09_ooooo0_l00009ooooo`;o00001?ooool00ol0003oooooooooo`2iooooo`00V?ooool2o`0000co
oooo0_l00004ooooo`04o`000?oooooo0000o`000;Sooooo002Hooooo`;o00001?ooool2o`0000Go
oooo0_l00005ooooo`04o`000?oooooo0000o`000;Sooooo002Nooooo`Co00000oooool2o`0000Go
oooo00?o0000ooooooooool0^Oooool00:3ooooo0_l00007ooooo`;o000000?oooooo`000?ooool0
^_ooool00:Wooooo0_l000001?oooooo0000o`000?l0002iooooo`00W?ooool2o`000003ooooool0
003o000000_ooooo00?o0000ooooooooool0^Oooool009cooooo0_l000000ooooooo0000o`000002
o`000003ooooool0003o000000Kooooo00?o0000ooooooooool0^Oooool00:7ooooo0_l000000ooo
oooo0000o`000002ooooo`;o00000_ooool00ol0003oooooooooo`2iooooo`00Z?ooool2o`0000;o
oooo00?o0000ooooooooool0^Oooool00:3ooooo0_l00005ooooo`;o00000oooool00ol0003ooooo
ooooo`2iooooo`00X?ooool2o`0000Gooooo0_l00003ooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Ooo
ool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:;o
oooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000ooooooooool01Ooo
ool3o`000;Wooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo
0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo
002Rooooo`03oeEEEOmVIVKo00000<?ooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo002Zooooo`04oa0@4?l0003o0000o`000;[ooooo002[ooooo`03o`000?oo
oooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`06o`000?mgMgOo0000
o`000?mEEEGok^k^]oooool00:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomEEEFgooooo`00Zooo
ool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo0;Gooooo002[ooooo`03o`000?o^k^ko
oooo00;ooooo00?o0000ooooooooool0]Oooool00:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomV
IVJgooooo`00Z_ooool00ol@413o0000ogMgM`02o`000003ofIVI_o^k^kooooo0;Kooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.6206 .34133 Mdot
.64292 .38417 Mdot
.50099 .57097 Mdot
.4653 .25087 Mdot
.55088 .69279 Mdot
.55475 .21637 Mdot
.46244 .33584 Mdot
.5265 .95105 Mdot
.47624 .97264 Mdot
.5488 .37415 Mdot
.56789 .46989 Mdot
.43676 .96148 Mdot
.66719 .45037 Mdot
.55087 .36505 Mdot
.36904 .6117 Mdot
.49763 .25568 Mdot
.42747 .21744 Mdot
.66818 .45269 Mdot
.57502 .56896 Mdot
.67506 .62399 Mdot
.66551 .53664 Mdot
.65774 .47485 Mdot
.65392 .55702 Mdot
.67023 .48521 Mdot
.36452 .50641 Mdot
.49903 .81889 Mdot
.56521 .56523 Mdot
.56485 .61242 Mdot
.66242 .66858 Mdot
.65061 .43606 Mdot
.64946 .6263 Mdot
.51504 .94526 Mdot
.48041 .98455 Mdot
.49434 .15261 Mdot
.47744 .13052 Mdot
.63048 .71977 Mdot
.58298 .8407 Mdot
.56286 .60644 Mdot
.61375 .77277 Mdot
.46437 .99367 Mdot
.3825 .778 Mdot
.47668 .13528 Mdot
.5344 .19319 Mdot
.6042 .28486 Mdot
.59008 .26349 Mdot
.5343 .74394 Mdot
.56366 .45607 Mdot
.56902 .87696 Mdot
.43215 .78803 Mdot
.63405 .72931 Mdot
.55597 .89203 Mdot
.63155 .75072 Mdot
.63061 .11102 Mdot
.53136 .19412 Mdot
.48955 .13002 Mdot
.46905 .97745 Mdot
.50244 .97622 Mdot
.40902 .30212 Mdot
.57823 .85712 Mdot
.58391 .25276 Mdot
.51238 .78531 Mdot
.37455 .25344 Mdot
.59338 .80591 Mdot
.43772 .6711 Mdot
.40262 .85309 Mdot
.51004 .95375 Mdot
.55187 .39247 Mdot
.51688 .30503 Mdot
.57259 .55831 Mdot
.67 .52629 Mdot
.39408 .4889 Mdot
.48366 .3169 Mdot
.55842 .42772 Mdot
.53836 .34657 Mdot
.59292 .80655 Mdot
.468 .64316 Mdot
.63139 .11207 Mdot
.43869 .78155 Mdot
.64086 .72934 Mdot
.40067 .45251 Mdot
.6421 .67114 Mdot
.65092 .45075 Mdot
.46944 .25206 Mdot
.46744 .13491 Mdot
.53214 .93982 Mdot
.46302 .2361 Mdot
.54985 .69697 Mdot
.4973 .80065 Mdot
.39626 .45432 Mdot
.52297 .32148 Mdot
.36606 .42135 Mdot
.54368 .02759 Mdot
.42612 .61229 Mdot
.53209 .7437 Mdot
.42504 .59449 Mdot
.55029 .36457 Mdot
.50782 .94616 Mdot
.63356 .11287 Mdot
.39752 .59056 Mdot
.63011 .37112 Mdot
.40079 .62304 Mdot
.407 .88375 Mdot
.61765 .31723 Mdot
.66458 .58953 Mdot
.49868 .15648 Mdot
.4029 .33602 Mdot
.57534 .57973 Mdot
.42641 .61555 Mdot
.6673 .55032 Mdot
.54541 .35193 Mdot
.44208 .29264 Mdot
.50787 .95214 Mdot
.66524 .63968 Mdot
.70847 .20303 Mdot
.53162 .51973 Mdot
.48384 .82386 Mdot
.55472 .90822 Mdot
.54708 .91395 Mdot
.54155 .89173 Mdot
.66758 .46653 Mdot
.36132 .45233 Mdot
.65132 .59635 Mdot
.66833 .65486 Mdot
.669 .53854 Mdot
.48619 .25131 Mdot
.65561 .6713 Mdot
.64663 .46376 Mdot
.49896 .68494 Mdot
.65915 .51063 Mdot
.63887 .40514 Mdot
.40543 .88254 Mdot
.53736 .18356 Mdot
.54345 .20456 Mdot
.66055 .68295 Mdot
.63315 .76207 Mdot
.6555 .67975 Mdot
.55875 .43367 Mdot
.43713 .95465 Mdot
.37337 .67954 Mdot
.41982 .45417 Mdot
.57559 .54926 Mdot
.42331 .23176 Mdot
.67265 .62426 Mdot
.541 .92768 Mdot
.73243 .23402 Mdot
.53216 .71492 Mdot
.49789 .80185 Mdot
.37617 .75936 Mdot
.40827 .68992 Mdot
.57471 .49458 Mdot
.67079 .47163 Mdot
.47486 .3139 Mdot
.60013 .31073 Mdot
.61601 .78592 Mdot
.60962 .78305 Mdot
.52951 .93586 Mdot
.56789 .86057 Mdot
.62047 .77976 Mdot
.47098 .84029 Mdot
.65163 .70769 Mdot
.4549 .99531 Mdot
.62814 .71701 Mdot
.56475 .25289 Mdot
.6355 .40691 Mdot
.53519 .93306 Mdot
.66699 .58797 Mdot
.57187 .55857 Mdot
.64375 .73838 Mdot
.61983 .75021 Mdot
.43264 .34966 Mdot
.56682 .5778 Mdot
.5235 .75171 Mdot
.54361 .69205 Mdot
.43819 .95388 Mdot
.60104 .31525 Mdot
.52013 .59855 Mdot
.64466 .71162 Mdot
.65248 .71597 Mdot
.43553 .96463 Mdot
.51113 .27632 Mdot
.38037 .76501 Mdot
.48036 .71884 Mdot
.45471 .96136 Mdot
.55602 .89947 Mdot
.44992 .98935 Mdot
.52731 .17853 Mdot
.36153 .52688 Mdot
.67473 .61724 Mdot
.43996 .67393 Mdot
.38578 .18382 Mdot
.52329 .95156 Mdot
.39006 .83219 Mdot
.40905 .89299 Mdot
.5291 .74723 Mdot
.53329 .01 Mdot
.40249 .3292 Mdot
.52388 .56376 Mdot
.52355 .56852 Mdot
.48956 .3233 Mdot
.52985 .73661 Mdot
.55184 .02794 Mdot
.63841 .41323 Mdot
.44613 .68577 Mdot
.57015 .24366 Mdot
.42318 .38996 Mdot
.49701 .70436 Mdot
.56725 .44641 Mdot
.66079 .42496 Mdot
.44852 .8026 Mdot
.6661 .59251 Mdot
.52363 .31241 Mdot
.63752 .41748 Mdot
.44614 .79577 Mdot
.44201 .98088 Mdot
.50457 .68142 Mdot
.60453 .30947 Mdot
.48803 .99207 Mdot
.4929 .81627 Mdot
.53505 .91044 Mdot
.66971 .56896 Mdot
.63136 .70168 Mdot
.53305 .34784 Mdot
.55366 .67723 Mdot
.62931 .33312 Mdot
.42264 .4344 Mdot
.36953 .62237 Mdot
.36044 .52688 Mdot
.47634 .23806 Mdot
.43822 .49811 Mdot
.58622 .06854 Mdot
.39788 .52609 Mdot
.57054 .51434 Mdot
.36249 .42635 Mdot
.5667 .58412 Mdot
.62067 .32221 Mdot
.66135 .5412 Mdot
.6359 .39185 Mdot
.38199 .20225 Mdot
.5271 .17274 Mdot
.67019 .5898 Mdot
.39411 .48829 Mdot
.54307 .91547 Mdot
.42201 .53456 Mdot
.58423 .8313 Mdot
.42612 .23075 Mdot
.39412 .50537 Mdot
.60442 .78951 Mdot
.38445 .79847 Mdot
.53111 .52402 Mdot
.42785 .5963 Mdot
.56546 .85889 Mdot
.4589 .82617 Mdot
.56561 .58134 Mdot
.46272 .12379 Mdot
.46449 .64037 Mdot
.47983 .98847 Mdot
.57632 .86414 Mdot
.41075 .69335 Mdot
.57065 .51133 Mdot
.6324 .70258 Mdot
.51488 .63183 Mdot
.39992 .603 Mdot
.6219 .35446 Mdot
.56535 .49574 Mdot
.58122 .2789 Mdot
.62112 .74244 Mdot
.42337 .74221 Mdot
.64797 .68493 Mdot
.48459 .12489 Mdot
.53966 .33937 Mdot
.40071 .57635 Mdot
.62545 .76985 Mdot
.50459 .25988 Mdot
.575 .59996 Mdot
.54414 .9074 Mdot
.56213 .4074 Mdot
.58614 .27554 Mdot
.64684 .71076 Mdot
.52625 .59758 Mdot
.54351 .37343 Mdot
.55846 .8724 Mdot
.42449 .93417 Mdot
.57665 .57494 Mdot
.46838 .32086 Mdot
.5062 .77422 Mdot
.67462 .59833 Mdot
.50592 .79115 Mdot
.64044 .67078 Mdot
.55908 .87967 Mdot
.38002 .73666 Mdot
.52782 .9165 Mdot
.43826 .45008 Mdot
.60428 .81803 Mdot
.3999 .1223 Mdot
.67718 .57546 Mdot
.37104 .64267 Mdot
.74323 .24851 Mdot
.41141 .68857 Mdot
.48023 .11754 Mdot
.63724 .3903 Mdot
.53102 .92863 Mdot
.37108 .67228 Mdot
.56404 .4477 Mdot
.53019 .92259 Mdot
.45884 .82753 Mdot
.52584 .52524 Mdot
.66228 .45115 Mdot
.42661 .21825 Mdot
.66657 .48203 Mdot
.37684 .76143 Mdot
.52767 .56484 Mdot
.61195 .32815 Mdot
.49095 .14595 Mdot
.39679 .82912 Mdot
.52421 .59584 Mdot
.42207 .93665 Mdot
.37581 .26675 Mdot
.42401 .03377 Mdot
.49091 .25234 Mdot
.52325 .15995 Mdot
.45486 .14297 Mdot
.58649 .81958 Mdot
.56672 .64131 Mdot
.52841 .48253 Mdot
.44808 .37674 Mdot
.40388 .33132 Mdot
.50374 .97762 Mdot
.54906 .87866 Mdot
.43005 .63694 Mdot
.65954 .4405 Mdot
.505 .67037 Mdot
.49314 .33024 Mdot
.63215 .34163 Mdot
.54276 .19597 Mdot
.56409 .25119 Mdot
.46627 .83815 Mdot
.52791 .73885 Mdot
.60143 .07579 Mdot
.43341 .77629 Mdot
.64982 .47029 Mdot
.42842 .61412 Mdot
.46421 .9789 Mdot
.56457 .56431 Mdot
.65307 .68331 Mdot
.65334 .50396 Mdot
.42154 .57163 Mdot
.45001 .79888 Mdot
.44451 .00453 Mdot
.45544 .98509 Mdot
.6216 .79181 Mdot
.63415 .71449 Mdot
.42969 .77493 Mdot
.41775 .24179 Mdot
.62888 .7319 Mdot
.3989 .57624 Mdot
.45046 .98009 Mdot
.39753 .10928 Mdot
.67022 .59254 Mdot
.40113 .86498 Mdot
.41636 .92213 Mdot
.40767 .90147 Mdot
.5041 .35928 Mdot
.39944 .56663 Mdot
.37003 .63423 Mdot
.49406 .98284 Mdot
.50618 .36543 Mdot
.64908 .64071 Mdot
.41037 .65961 Mdot
.55724 .21691 Mdot
.62793 .36456 Mdot
.49739 .9584 Mdot
.62205 .32747 Mdot
.5854 .84073 Mdot
.5564 .86551 Mdot
.65298 .55776 Mdot
.63293 .77069 Mdot
.65763 .52018 Mdot
.36626 .57951 Mdot
.71258 .20432 Mdot
.52586 .91242 Mdot
.59156 .28416 Mdot
.48884 .32848 Mdot
.36471 .41826 Mdot
.39611 .54551 Mdot
.44645 .3854 Mdot
.44703 .98266 Mdot
.66998 .53017 Mdot
.5271 .45705 Mdot
.54435 .36587 Mdot
.48811 .8269 Mdot
.57023 .53121 Mdot
.57218 .87462 Mdot
.67691 .52761 Mdot
.39497 .14015 Mdot
.43343 .96145 Mdot
.44715 .16446 Mdot
.61594 .09778 Mdot
.43415 .18878 Mdot
.54996 .67511 Mdot
.55921 .65442 Mdot
.44883 .60949 Mdot
.49263 .98636 Mdot
.43565 .95908 Mdot
.5659 .55891 Mdot
.42036 .46653 Mdot
.56683 .41467 Mdot
.48069 .23054 Mdot
.37625 .74985 Mdot
.54763 .71047 Mdot
.63964 .69169 Mdot
.43203 .34035 Mdot
.57438 .5125 Mdot
.51601 .63097 Mdot
.54601 .71012 Mdot
.48897 .1487 Mdot
.57295 .48315 Mdot
.44334 .67785 Mdot
.36295 .60212 Mdot
.44447 .96575 Mdot
.50248 .478 Mdot
.48035 .1299 Mdot
.40381 .32851 Mdot
.61749 .36364 Mdot
.40661 .6274 Mdot
.5706 .5594 Mdot
.36281 .50679 Mdot
.63156 .35784 Mdot
.68919 .17841 Mdot
.60288 .27824 Mdot
.45085 .70402 Mdot
.43347 .9334 Mdot
.36756 .58739 Mdot
.56835 .50589 Mdot
.65176 .52512 Mdot
.61091 .0871 Mdot
.42235 .42567 Mdot
.52477 .44441 Mdot
.53247 .7198 Mdot
.64057 .68317 Mdot
.40126 .56165 Mdot
.53813 .018 Mdot
.4831 .71997 Mdot
.52676 .19009 Mdot
.45265 .14784 Mdot
.43789 .67653 Mdot
.52174 .5962 Mdot
.51867 .29027 Mdot
.52018 .95765 Mdot
.53057 .55114 Mdot
.65028 .7077 Mdot
.63705 .36583 Mdot
.60351 .29877 Mdot
.65354 .67379 Mdot
.64024 .6663 Mdot
.43064 .20301 Mdot
.54486 .36585 Mdot
.50355 .9783 Mdot
.39294 .84519 Mdot
.56466 .51563 Mdot
.61238 .80615 Mdot
.41282 .68299 Mdot
.44427 .1784 Mdot
.65613 .67517 Mdot
.62742 .35858 Mdot
.57098 .59424 Mdot
.4537 .80517 Mdot
.47854 .14129 Mdot
.36032 .44994 Mdot
.5627 .24294 Mdot
.48149 .64478 Mdot
.54698 .21833 Mdot
.39957 .50452 Mdot
.49272 .32535 Mdot
.51153 .29525 Mdot
.52326 .18106 Mdot
.52257 .16975 Mdot
.52852 .53911 Mdot
.4529 .81649 Mdot
.50723 .95695 Mdot
.56103 .6656 Mdot
.61982 .35158 Mdot
.57859 .50045 Mdot
.54767 .6675 Mdot
.514 .39331 Mdot
.69353 .17811 Mdot
.51891 .41965 Mdot
.63799 .36292 Mdot
.49962 .94933 Mdot
.63305 .70793 Mdot
.57233 .56501 Mdot
.65144 .69249 Mdot
.43607 .96369 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool009Wooooo0_l00009ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0^Oooool009Wooooo0_l00009ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`08ooooo`;o0000[oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08
ooooo`;o0000[oooool00:;ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`09ooooo`;o0000[_ooool00:cooooo00?o0000ooooooooool0
2Oooool2o`000:kooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool02oooool2
o`000003ooooool0003o00000:Wooooo002/ooooo`03o`000?oooooooooo00_ooooo0_l000000ooo
oooo0000o`00002Yooooo`00T_ooool2o`0001Sooooo00?o0000ooooooooool0^Oooool009;ooooo
0_l0000Hooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Ooo
ool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o
0000ooooooooool06Oooool2o`0009kooooo002/ooooo`03o`000?oooooooooo01Wooooo0_l0002N
ooooo`00[?ooool3o`0001kooooo0_l0002Iooooo`00[?ooool00ol0003oooooooooo`0Nooooo`;o
0000VOooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Ooo
ool00:cooooo00?o0000ooooooooool08Oooool2o`0009Kooooo002/ooooo`03o`000?oooooooooo
027ooooo0_l0002Fooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooo
ooooo`0Sooooo`;o0000U?ooool00:cooooo0ol0000Sooooo`;o0000U?ooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool008[ooooo0_l0000Pooooo`03
o`000?oooooooooo0;Wooooo002:ooooo`;o00008?ooool00ol0003oooooooooo`0Xooooo`?o0000
S_ooool00:cooooo00?o0000ooooooooool0:?ooool3o`0008kooooo0029ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool00om4A4Co0000o`00
0002o`0000Gooooo00?o0000ooooooooool0^Oooool008Wooooo00GoMgMgoiRHV?l0003o0000ogMg
M`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`;o00001Oooool00ol0003ooooooooo
o`2iooooo`00POooool6o`0000;ooooo00Go410@ooooool0003o0000oa0@400=ooooo`04ojVYZOmE
EEGoooooooooo`;o00001Oooool2o`0000Cooooo0ol0002iooooo`00ROooool01Ol0003ooooooooo
oooooooo000000kooooo00?o8B4Qooooooooool00_l00004ooooo`03ogMgMol0003o000000Cooooo
00?o0000ooooooooool0^Oooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEE
EOo<c<cooooo00?ooooo00?o0000ob4Q8Ol000000_l000000ooooooo0000o`000002ooooo`03o`00
0?oooooooooo0;Wooooo0029ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMg
ooooo`02ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000;ooooo00?o0000oooooooo
ool0^Oooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooo
oolb<S800oooool2o`000003ooooool0003o000000Kooooo00?o0000ooooooooool0^Oooool008Wo
oooo0ol000000olb<S;ok^k^ooooo`0:ooooo`Go00001?ooool4o`0000Kooooo00?o0000oooooooo
ool0^Oooool008Wooooo0_l0000Booooo`;o00001Oooool2o`0000Kooooo00?o0000ooooooooool0
^Oooool009gooooo0_l00005ooooo`;o00000oooool2o`000003ooooool0003ooooo0;[ooooo002L
ooooo`;o00002_ooool3o`000003ooooool0003ooooo0;[ooooo002Looooo`;o00002_ooool7o`00
0;Wooooo002Zooooo`?o0000^oooool00:_ooooo0_l0002kooooo`00Zoooool2o`0000Kooooo0_l0
002cooooo`00V_ooool2o`00013ooooo00?o0000ooooooooool01?ooool2o`000;?ooooo002Joooo
o`;o00004?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o
0000/oooool00:cooooo00?o0000ooooooooool01?ooool4o`000;7ooooo002/ooooo`?o00001_oo
ool2o`000;7ooooo002Iooooo`;o00004Oooool00ol0003oooooooooo`06ooooo`;o0000<oooool3
o`0007_ooooo002Iooooo`;o00004Oooool00ol0003oooooooooo`04ooooo`Co0000<oooool3o`00
07_ooooo0026ooooo`;o00009?ooool00ol0003oooooooooo`04ooooo`;o00000oooool2o`000:ko
oooo0026ooooo`;o00003_ooool2o`0001Cooooo00?o0000ooooooooool02Oooool2o`000:kooooo
002Fooooo`;o00005?ooool00ol0003oooooooooo`05ooooo`;o0000/_ooool00:cooooo00?o0000
ooooooooool01Oooool5o`000:oooooo002/ooooo`03o`000?oooooooooo00Oooooo0ol000000ooo
oooo0000o`00002/ooooo`00[?ooool3o`0000_ooooo0_l0002/ooooo`00QOooool2o`0000kooooo
0_l0000Eooooo`03o`000?oooooooooo00_ooooo0_l0000dooooo`Co0000M?ooool008Gooooo0_l0
000>ooooo`;o00005Oooool00ol0003oooooooooo`0;ooooo`;o0000=?ooool4o`0007Cooooo002/
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03
o`000?oooooooooo00oooooo0_l0002Xooooo`00Toooool3o`0001Kooooo00?o0000ooooooooool0
3?ooool2o`000003ooooool0003o00000:Sooooo002Cooooo`?o00005_ooool00ol0003ooooooooo
o`0<ooooo`;o000000?oooooo`000?l00000Z?ooool00:cooooo0ol0002iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00T_ooool3o`00013ooooo0_l00005ooooo`03o`000?oooooooooo0;Wo
oooo002Booooo`?o00004?ooool2o`0000Gooooo00?o0000ooooooooool0BOooool2o`0006kooooo
002Oooooo`;o00002oooool00ol0003oooooooooo`19ooooo`;o0000K_ooool009oooooo0_l00003
ooooo`;o00001_ooool00ol0003oooooooooo`2iooooo`00T?ooool2o`000004oc8b<_l0003o<S8b
onk^kPGooooo0_lQ8B45ooooo`05odA4A?l0003o0000o`000?oMgMd01Oooool00ol0003ooooooooo
o`0Aooooo`;o000000?oooooo`000?l00000Xoooool0093ooooo0_l000001?nHV9SooooooiRHV?mg
MgL5ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo017ooooo0_l0
00000ooooooo0000o`00002Sooooo`00ROooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0COooool2o`0006[ooooo002A
ooooo`05o`000?ooooooooooooooool000002_ooool3o`0000;ooooo00?oMgMgoc8b<_l000000ol0
00001?oooooo0000o`000?l0000Booooo`;o00001?ooool2o`0003?ooooo0_l0001Zooooo`00P_oo
ool2o`0000gooooo00Go0000ooooooooooooooooo`00000:ooooo`?o000000Co8B4Qo`000?lb<S;o
c<c<1_l0000Dooooo`;o00001?ooool2o`0009oooooo0022ooooo`;o00003Oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?o0000ooooooooool01_ooool2o`000;_ooooo002Aooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`?o0000^Oooool0097ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool3o`0001[ooooo0_l0002Mooooo`00
Poooool2o`0002Oooooo00?o0000ooooooooool06_ooool2o`0009gooooo0023ooooo`;o00009ooo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool5o`00
01Oooooo0_l0002Nooooo`00[?ooool00ol0003oooooooooo`02o`0001Gooooo1?l00004ooooo`;o
0000V?ooool00:cooooo00?o0000ooooooooool05oooool2o`0000Kooooo0_l0002Hooooo`00[?oo
ool00ol0003oooooooooo`0Kooooo`;o00000_ooool2o`0009Sooooo002/ooooo`03o`000?oooooo
oooo01_ooooo0_l00002ooooo`;o0000V?ooool00:cooooo00?o0000ooooooooool00oooool2o`00
0;Cooooo002Hooooo`;o00004_ooool00ol0003oooooooooo`02o`000003ooooool0003o00000;Co
oooo002Hooooo`;o00004_ooool00ol0003oooooooooo`02o`000;Oooooo002/ooooo`?o00007ooo
ool2o`0009Sooooo002>ooooo`;o00007?ooool00ol0003oooooooooo`0Oooooo`;o0000V?ooool0
08kooooo0_l0000Looooo`03o`000?oooooooooo00;ooooo0_l0002eooooo`00[?ooool00ol0003o
ooooooooo`02ooooo`;o00006oooool2o`0009Sooooo002/ooooo`03o`000?oooooooooo00Cooooo
0_l0000Hooooo`?o0000V?ooool00:?ooooo0_l00007ooooo`03o`000?oooooooooo00Cooooo0_l0
000Hooooo`;o0000VOooool00:?ooooo0_l000000ooooooo0000o`000004ooooo`03o`000?oooooo
oooo01kooooo0_l00003ooooo`;o0000U?ooool00:7ooooo0_l00003ooooo`;o00001?ooool00ol0
003oooooooooo`04ooooo`;o00007Oooool3o`0009?ooooo002Qooooo`;o00001Oooool3o`000004
ooooool0003o0000o`0000Cooooo0_l0000Nooooo`;o0000Toooool008cooooo0_l0000Jooooo`?o
000000?oooooo`000?ooool08oooool2o`000003ooooool0003o000009;ooooo002;ooooo`?o0000
6_ooool3o`000003ooooool0003ooooo02?ooooo0_l000000ooooooo0000o`00002Booooo`00Rooo
ool3o`0001_ooooo0_l000000ooooooo0000ooooo`0Xooooo`;o0000T?ooool008cooooo0_l0000A
ooooo`;o00002oooool00ol0003oooooooooo`0Wooooo`;o0000T?ooool008cooooo0_l00007oooo
o`;o00002?ooool2o`0000_ooooo00?o0000ooooooooool02_ooool2o`000:gooooo002Eooooo`;o
00005Oooool00ol0003oooooooooo`0:ooooo`;o00006?ooool2o`0000;ooooo0_l0002?ooooo`00
[?ooool00ol0003oooooooooo`09ooooo`;o00006Oooool2o`0000;ooooo0_l0002?ooooo`00UOoo
ool2o`0001Gooooo00?o0000ooooooooool01oooool4o`000:kooooo002Eooooo`;o00005Oooool3
o`0000Oooooo0_l00003ooooo`;o00005_ooool2o`0009?ooooo002/ooooo`03o`000?oooooooooo
00cooooo0_l0000Fooooo`?o0000T_ooool00:cooooo00?o0000ooooooooool09Oooool5o`0008oo
oooo002/ooooo`?o00009oooool3o`0008oooooo002/ooooo`?o00003Oooool2o`0001Cooooo0_l0
0002ooooo`;o000000?oooooo`000?l00000SOooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`04o`00
0?oooooo0000o`0000[ooooo1?l0000Dooooo`;o00000_ooool2o`000003ooooool0003o000008go
oooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00Co0000ooooool0003o00002_ooool2
o`0001_ooooo1?l0002=ooooo`00POooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;
ooooo`Co00006Oooool2o`0008oooooo0029ooooo`05o`000?ooooooooooooooool000003?ooool2
o`000003ob4Q8Oo^k^kooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`0000_ooooo1?l0002Z
ooooo`00ROooool01Ol0003ooooooooooooooooo000000cooooo0_l000000omgMgOoIVIVooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2iooooo`00ROooool0
1Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool3o`000003oiRHV?l@413ooooo00?ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0/ooooo`;o0000Roooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l0
003o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool0;?ooool2o`0008_ooooo
002Booooo`;o00006?ooool00ol0003oooooooooo`0>ooooo`;o00006Oooool3o`0008gooooo002B
ooooo`;o00006?ooool01?l0003oooooooooooooool2o`0000_ooooo0_l0000Iooooo`?o0000SOoo
ool00:cooooo00Co0000oooooooooooooooo0_l0002fooooo`00[?ooool3o`000;Wooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo017ooooo0_l0000Fooooo`?o
0000SOooool00:cooooo00?o0000ooooooooool04Oooool2o`0001Kooooo0ol0002=ooooo`00[?oo
ool00ol0003oooooooooo`0Zooooo`;o0000SOooool00:cooooo00?o0000ooooooooool04oooool2
o`0001Gooooo0_l0002=ooooo`00Ooooool2o`0002_ooooo00?o0000ooooooooool00oooool2o`00
00kooooo0_l0000Eooooo`;o0000SOooool007oooooo0_l0000[ooooo`03o`000?oooooooooo00?o
oooo0_l0000Uooooo`;o0000SOooool007oooooo0_l0000Aooooo`;o00006?ooool3o`0003;ooooo
0_l00025ooooo`00O_ooool2o`0001;ooooo0_l0000Hooooo`03o`000?oooooooooo013ooooo0_l0
000Pooooo`;o0000QOooool007kooooo0_l0000/ooooo`03o`000?oooooooooo013ooooo0_l0002W
ooooo`00T_ooool2o`0001Sooooo00?o0000ooooooooool04?ooool2o`000:Oooooo002Booooo`;o
00006?ooool00ol0003oooooooooo`0@ooooo`;o00007?ooool2o`0008Wooooo002/ooooo`03o`00
0?oooooooooo02kooooo0_l000000ooooooo0000o`000026ooooo`00[?ooool00ol0003ooooooooo
o`0aooooo`;o0000Q_ooool00:cooooo00?o0000ooooooooool01Oooool2o`0000cooooo0_l0002T
ooooo`00OOooool2o`0002gooooo00?o0000ooooooooool01Oooool2o`0000_ooooo0ol0002Toooo
o`00OOooool3o`0000_ooooo0_l0000:ooooo`;o00004oooool3o`0001;ooooo0_l0000Jooooo`;o
00000_ooool4o`0008?ooooo001nooooo`;o00002Oooool4o`0000Cooooo0_l00004ooooo`;o0000
4oooool00ol0003oooooooooo`0Booooo`;o00006_ooool2o`0000;ooooo1?l00023ooooo`00ROoo
ool2o`0000Kooooo0_l0000Iooooo`03o`000?oooooooooo00Kooooo0_l0000:ooooo`;o0000YOoo
ool000Wooooo1?l000000ol@413oooooooooo`0Fooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM
00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4
o`000?l0003o<S8bomgMg@0Fooooo`03o`000?oooooooooo00Kooooo0_l0000@ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oM
gMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^
k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`Co000000?o410@ooooooooool0
4_ooool000_ooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMg
oc8b<_ooool05Oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A002o`0000Gooooo00?oMgMgoc8b<_ooool0
3_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07oooo
o`03ogMgMolb<S;ooooo01Wooooo00?o0000ooooooooool05?ooool000Ko00001Oooool00ol0003o
ooooooooo`0@ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEE
EOooool02?ooool00ol0003oooooooooo`05ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo
410@013ooooo00?o0000ooooooooool01Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03oiRHV?lQ8B7ok^k^00Gooooo0_l00002ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool06?ooool01Ol@413ooooooooooooooooo410@00cooooo00CoV9RHob4Q8Oo^k^ko
oooo0_l00005ooooo`;o00003oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooo
ooooool03Oooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo
01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMg
oc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool03_oo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01?ooool2o`000003oooo
oomgMgOo<S8b01Kooooo00?o0000ooooooooool04oooool2o`0000?ooooo00Go0000oooooooooooo
ooooo`00000=ooooo`04oiRHV?lQ8B7ok^k^ooooo`;o00001?ooool2o`0000oooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool06Oooool00ol0003ooooooooo
o`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_oo
ool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooo
oooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?oooooooooo
ooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05_oo
ool00ol0003oooooooooo`0Cooooo`;o00000oooool01Ol0003ooooooooooooooooo000000kooooo
00?oMgMgofIVI_ooool00_l000001Ooooooo0000ob4Q8Ol0003o<S8b00;o00003_ooool01Ol0003o
oooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?oooooo
ooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
6_ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05oa0@4?oo
ooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo017ooooo
00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06?ooool3o`00
01Sooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo0_l00002
ooooo`;o00003_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04Ooo
ool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003o
ooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aoooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o
0000ooooooooool06?ooool2o`0001Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool2o`0001;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooo
oooooooooolb<S801?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Cooooo0009
ooooo`03oeEEEOmVIVKo000001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?oo
ool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00004?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00005oooool2o`00
00Oooooo0_l0000=ooooo`;o000000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`01?ooool5o`0000oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co
00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00006Oooool00omE
EEGoIVIVo`00000Fooooo`00[?ooool00ol0003oooooooooo`06ooooo`;o00003Oooool2o`0001go
oooo0ol00022ooooo`00ROooool2o`00027ooooo00?o0000ooooooooool0=Oooool2o`0008;ooooo
0029ooooo`;o00008Oooool00ol0003oooooooooo`2^ooooo`;o00000_ooool2o`0000Gooooo002/
ooooo`03o`000?oooooooooo01Gooooo0_l0002Gooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM
1Oooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo01;ooooo0_l000000ooooooo0000o`00
002Hooooo`04omgMgOl0003o410@olc<c0Kooooo0007oooooooo0000C?l0000<ooooo`04onk^k_lQ
8B7o410@onk^kPKooooo0007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l00008ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`?o00001Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool02_ooool01?lQ8B7oMgMgogMgMolb<S86ooooo`001ooo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool08Ooo
ool3o`0000;ooooo00?o0000ooooooooool00oooool3o`00023ooooo00?o0000ooooooooool04ooo
ool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`0001oooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Wooooo0_l00002ooooo`;o00001Ooo
ool007kooooo0ol00008ooooo`;o00008Oooool00ol0003oooooooooo`0Cooooo`;o0000Y?ooool0
0:cooooo00?o0000ooooooooool05?ooool3o`0001[ooooo0_l00026ooooo`00[?ooool00ol0003o
ooooooooo`0Booooo`Go00006_ooool2o`0008Kooooo002/ooooo`03o`000?oooooooooo01;ooooo
1?l0002Sooooo`00[?ooool00ol0003oooooooooo`07ooooo`;o0000:?ooool2o`0008Kooooo002/
ooooo`?o00001Oooool4o`0002Kooooo1?l00026ooooo`00OOooool3o`0000[ooooo0_l0000Poooo
o`03o`000?oooooooooo00Gooooo1?l0000Vooooo`;o00001?ooool4o`00083ooooo001mooooo`?o
00002_ooool2o`00023ooooo00?o0000ooooooooool05?ooool2o`0001oooooo1?l00020ooooo`00
T_ooool2o`0001Sooooo00?o0000ooooooooool05?ooool2o`0001oooooo0_l00022ooooo`00T_oo
ool2o`0001Sooooo00?o0000ooooooooool0<oooool2o`0008Cooooo002/ooooo`03o`000?oooooo
oooo00Kooooo0_l0000[ooooo`?o0000Poooool00:cooooo00?o0000ooooooooool01_ooool2o`00
02[ooooo1?l00023ooooo`00ROooool2o`00027ooooo00?o0000ooooooooool0<_ooool2o`0008Go
oooo0029ooooo`;o00008Oooool00ol0003oooooooooo`0Fooooo`;o0000XOooool00:cooooo0ol0
0007ooooo`;o00003Oooool2o`0001cooooo0_l00023ooooo`00[?ooool00ol0003oooooooooo`07
ooooo`;o0000:oooool2o`0008?ooooo002/ooooo`03o`000?oooooooooo01;ooooo1Ol0000Hoooo
o`;o0000R?ooool008_ooooo0_l0000Oooooo`03o`000?oooooooooo01;ooooo1Ol0000Hooooo`;o
0000R?ooool008_ooooo0_l0000Oooooo`03o`000?oooooooooo00Cooooo1?l0000:ooooo`Co0000
Xoooool008[ooooo0_l0000Pooooo`03o`000?oooooooooo00Cooooo1?l0000:ooooo`Co0000Xooo
ool008[ooooo0_l0000Pooooo`;o00001Oooool2o`0000cooooo0_l000000ooooooo0000o`00000N
ooooo`;o0000P_ooool009;ooooo0_l0000Hooooo`;o00001Oooool2o`0000oooooo0_l0000Noooo
o`;o0000P_ooool008[ooooo0ol00005ooooo`;o00006?ooool3o`0001Kooooo0_l0000Oooooo`;o
0000P?ooool007oooooo0_l00009ooooo`?o00007oooool00ol0003oooooooooo`0Cooooo`Go0000
7oooool2o`00083ooooo001oooooo`;o0000:oooool00ol0003oooooooooo`0Booooo`Go0000X_oo
ool00:cooooo00?o0000ooooooooool04_ooool3o`000:Cooooo0020ooooo`;o0000:_ooool00ol0
003oooooooooo`0Cooooo`;o00007oooool2o`0008?ooooo0020ooooo`;o00002?ooool2o`00023o
oooo00?o0000ooooooooool0<oooool4o`0008;ooooo002:ooooo`;o00001oooool2o`0001Oooooo
00?o0000ooooooooool05?ooool2o`0001gooooo1?l00022ooooo`00Toooool3o`0001Kooooo00?o
0000ooooooooool01?ooool3o`0000gooooo0_l0000Iooooo`;o00000_ooool5o`00087ooooo002D
ooooo`;o00005_ooool3o`0000?ooooo1?l0000>ooooo`;o00006?ooool2o`0000Gooooo0_l00021
ooooo`00O_ooool2o`0000_ooooo0_l0000Oooooo`03o`000?oooooooooo00?ooooo0_l0000@oooo
o`;o0000X_ooool007kooooo0_l0000;ooooo`;o00007oooool00ol0003oooooooooo`0Aooooo`;o
0000Y_ooool009_ooooo0_l0000?ooooo`03o`000?oooooooooo017ooooo0_l0002Vooooo`00P?oo
ool2o`00017ooooo0_l00006ooooo`;o00003oooool00ol0003oooooooooo`0Booooo`;o0000YOoo
ool0083ooooo0_l0000Aooooo`?o00005_ooool00ol0003oooooooooo`0Booooo`;o0000YOooool0
08Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`?o00000oooool5o`0000Cooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo03Kooooo0_l00021ooooo`00P?ooool2
o`0000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^
k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0fooooo`;o0000
POooool0083ooooo0_l00007ooooo`05oa0@4?oooooo0000o`000?l@41003?ooool00onHV9So8B4Q
onk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0000fooooo`;o0000POooool008Wooooo00?o
0000ooooool000000ol0000<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`0^ooooo`;o00001_ooool2o`00087ooooo0029ooooo`04o`000?oooooo
ooooooooo`;o00003Oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`02ooooo`;o0000:_ooool2o`0008Wooooo0021ooooo`;o00001_oo
ool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`04o`000?ooooooooooooooo`?o0000]Oooool0087ooooo0_l00006ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool2o`0000?ooooo00Go0000okZj^_ooooooV9RHoa0@4004oooo
o`03o`000?oooooooooo00Oooooo00Co0000oooooooooooooooo0_l0002fooooo`00ROooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Kooooo0_l00003ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00_oo
ool6o`0000Kooooo00?o0000ooooooooool0;_ooool2o`0000?ooooo0_l00024ooooo`00POooool2
o`0001gooooo0ol00009ooooo`03o`000?oooooooooo01?ooooo0_l0000Iooooo`;o00000oooool2
o`0008Cooooo0021ooooo`;o00007_ooool2o`0000;ooooo0_l00005ooooo`03o`000?oooooooooo
01?ooooo0_l0002Tooooo`00YOooool2o`0000Gooooo00?o0000ooooooooool0^Oooool00:cooooo
0ol0002iooooo`00[?ooool00ol0003oooooooooo`0@ooooo`;o00008_ooool2o`0008?ooooo002/
ooooo`03o`000?oooooooooo013ooooo0_l0000Rooooo`;o0000Poooool008kooooo0_l0000Loooo
o`03o`000?oooooooooo0;Wooooo002>ooooo`;o00007?ooool00ol0003oooooooooo`2iooooo`00
[?ooool00ol0003oooooooooo`0<ooooo`;o00000oooool2o`0001Sooooo0_l0002<ooooo`00Uooo
ool2o`0001?ooooo0ol0000<ooooo`;o00000oooool2o`0001Sooooo0_l00005ooooo`;o0000QOoo
ool0087ooooo0_l0000Dooooo`?o00004_ooool3o`0002_ooooo0_l00002ooooo`Go0000QOooool0
087ooooo0_l0000Dooooo`?o00004_ooool3o`0000gooooo0_l0000Pooooo`?o0000Qoooool008;o
oooo0_l0000Cooooo`Co00004Oooool00ol0003oooooooooo`0=ooooo`?o00008?ooool2o`0008Oo
oooo0022ooooo`;o00002oooool2o`0000Sooooo0_l0000Aooooo`?o00003_ooool2o`0001_ooooo
0_l00003ooooo`Co0000QOooool008oooooo0_l00009ooooo`;o00003oooool4o`0002_ooooo1_l0
00000ooooooo0000o`000025ooooo`00S_ooool2o`0000[ooooo0_l0000?ooooo`;o0000;oooool4
o`0008Sooooo002=ooooo`?o00007?ooool00ol0003oooooooooo`0;ooooo`;o00007_ooool2o`00
08cooooo002=ooooo`?o00007?ooool00ol0003oooooooooo`0;ooooo`Co00007?ooool2o`0000;o
oooo0_l00028ooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool03Oooool2o`00023ooooo
0_l00028ooooo`00[?ooool3o`0000gooooo0_l0002Zooooo`00Voooool2o`0000kooooo0_l0000Z
ooooo`;o0000Soooool009_ooooo0_l0000>ooooo`;o0000:_ooool2o`0008oooooo002/ooooo`03
o`000?oooooooooo00cooooo0_l0000Jooooo`;o00001?ooool3o`0008Sooooo002/ooooo`03o`00
0?oooooooooo00cooooo0_l0000Jooooo`;o00000_ooool5o`0008Sooooo002/ooooo`03o`000?oo
oooooooo00Oooooo0_l0000Pooooo`;o000000?oooooo`000?l000000ol00028ooooo`00YOooool2
o`0000Gooooo00?o0000ooooooooool01oooool2o`0001kooooo1?l00004ooooo`;o0000R?ooool0
0:Gooooo0ol00004ooooo`03o`000?oooooooooo00Oooooo0_l0000Nooooo`?o0000Soooool00:Ko
oooo0_l00004ooooo`?o00001oooool2o`0001oooooo0_l0002?ooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool00ol0003oooooooooo`0Yooooo`Co0000S?ooool00:cooooo00?o0000
ooooooooool09oooool6o`0008cooooo0024ooooo`;o00009_ooool00ol0003oooooooooo`06oooo
o`;o00007oooool2o`00093ooooo0024ooooo`;o00009_ooool00ol0003oooooooooo`06ooooo`;o
00009?ooool2o`0008_ooooo002Aooooo`05onk^k_l0003o0000oc8b<_o^k^h01Oooool2ob4Q8@Go
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00Kooooo0ol0000Loooo
o`;o00001Oooool2o`0008_ooooo002Aooooo`05ogMgMol0003o0000oiRHV?mgMgL01Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`07ooooo`?o00006oooool2o`00
09;ooooo0023ooooo`;o00003?ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`06ooooo`Co0000[oooool008?ooooo0_l0000<ooooo`05
o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`?o00001?ooool4o`00
01cooooo0_l00002ooooo`;o0000Soooool0097ooooo00Go0000ooooooooooooooooo`00000<oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`04ooooo`;o00007_ooool2
o`0000;ooooo0_l0002?ooooo`00TOooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`2iooooo`00Poooool2o`0000cooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0^Oooool0
08?ooooo0ol0000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000
ooooooooool0:Oooool2o`0008kooooo0024ooooo`;o00009_ooool00ol0003oooooooooo`0Yoooo
o`;o0000S_ooool00:cooooo00?o0000ooooooooool09_ooool4o`0008oooooo002/ooooo`03o`00
0?oooooooooo02;ooooo0_l00002ooooo`Co0000Soooool009Cooooo1?l0000Dooooo`Co00008Ooo
ool2o`0009Gooooo0025ooooo`;o00003Oooool4o`0001Cooooo00Co0000ooooool0003o00008ooo
ool2o`0009?ooooo0025ooooo`;o00004?ooool2o`0001?ooooo00?o0000ooooooooool08Oooool2
o`000003ooooool0003o000009?ooooo002Gooooo`;o00004oooool01?l0003oooooooooooooool2
o`0001kooooo1?l0002Dooooo`00UOooool2o`0001Gooooo00Co0000oooooooooooooooo0_l0000P
ooooo`;o0000U?ooool009Gooooo0_l0000Eooooo`04o`000?oooooo0000o`0001kooooo0_l00004
ooooo`;o0000T_ooool00:cooooo00Co0000ooooool0003o00007_ooool2o`0000Cooooo0_l0002B
ooooo`00V_ooool2o`00013ooooo00?o0000ooooooooool0^Oooool008Gooooo0_l0000Cooooo`?o
00003_ooool4o`000;Wooooo0025ooooo`;o00005?ooool2o`0000kooooo0_l0002kooooo`00Vooo
ool3o`0000gooooo0_l0000Mooooo`;o00001Oooool2o`0009Gooooo002Looooo`;o00003_ooool0
0ol0003oooooooooo`0Kooooo`;o00001Oooool2o`0009Gooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002Looooo`;o00002oooool2o`000003ooooool0003ooooo0;[ooooo002Looooo`;o0000
2oooool4o`0001_ooooo0_l00004ooooo`;o0000V?ooool00:_ooooo0_l0000Kooooo`;o00001?oo
ool2o`0009Sooooo002Vooooo`;o00001?ooool3o`000;Wooooo002Nooooo`;o00001_ooool4o`00
00;ooooo00?o0000ooooooooool0^Oooool008Wooooo0_l0000Cooooo`;o00002?ooool2o`0000;o
oooo00?o0000ooooooooool06?ooool2o`0009oooooo0027ooooo`Co00008Oooool00ol0003ooooo
ooooo`0Hooooo`;o0000Woooool008Oooooo0_l0000Sooooo`03o`000?oooooooooo0;Wooooo002P
ooooo`Co00002?ooool00ol0003oooooooooo`0Hooooo`?o0000W_ooool00:3ooooo1?l00008oooo
o`03o`000?oooooooooo01Sooooo0ol0002Nooooo`00R?ooool2o`0002;ooooo00?o0000oooooooo
ool0^Oooool008Sooooo0_l0000Rooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Ooo
ool008_ooooo0_l0000Oooooo`03o`000?oooooooooo0;Wooooo002;ooooo`;o00007oooool00ol0
003oooooooooo`0Booooo`;o00000_ooool2o`000:7ooooo002/ooooo`03o`000?oooooooooo01;o
oooo0ol000000ooooooo0000o`00002Qooooo`00Roooool2o`0001oooooo00?o0000ooooooooool0
4oooool2o`000003ooooool0003o00000:7ooooo0029ooooo`05onk^k_lb<S;o0000o`000?o^k^h0
1Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Go
oooo00?o0000ooooooooool03oooool2o`0000Gooooo0_l0002Qooooo`00ROooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`0?ooooo`;o0000Z?ooool008Wooooo00Go410@oooooooooooo
oooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0@ooooo`;o0000Yoooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`00013ooooo0_l000001?oooooo
0000o`000?l0002Sooooo`00ROooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<
c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool03Oooool2
o`000004ooooool0003o0000ooooo`?o0000Xoooool008Wooooo00?o410@ooooooooool00_l0000>
ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0=
ooooo`;o000000?oooooo`000?l00000Yoooool008Wooooo00?oMgMgoiRHV?ooool00ol0000:oooo
o`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0;Wooooo0029ooooo`04onk^k_lb<S;o0000oc8b<P;o00002_ooool5o`0000Cooooo1?l00006
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00[ooooo0_l00003oooo
o`;o0000Z?ooool008kooooo0_l0000Looooo`03o`000?oooooooooo00[ooooo0_l00003ooooo`;o
0000Z?ooool008kooooo0_l0000Looooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o00003ooo
ool2o`000:Sooooo002=ooooo`;o00007Oooool00ol0003oooooooooo`0?ooooo`;o0000Z?ooool0
08gooooo0_l0000Mooooo`03o`000?oooooooooo00_ooooo0_l0002/ooooo`00[?ooool00ol0003o
ooooooooo`08ooooo`;o000000?oooooo`000?l000000_ooool2o`000:Sooooo002/ooooo`03o`00
0?oooooooooo00Gooooo0_l000000ooooooo0000o`000005ooooo`;o0000Z?ooool00:cooooo00?o
0000ooooooooool01Oooool3o`0000?ooooo0ol0002[ooooo`00[?ooool00ol0003oooooooooo`06
ooooo`;o00000oooool3o`000:_ooooo002@ooooo`;o00006_ooool00ol0003oooooooooo`2ioooo
o`00T?ooool2o`0001[ooooo0ol00007ooooo`;o0000/?ooool00:cooooo00?o0000ooooooooool0
1oooool2o`000003ooooool0003o00000:gooooo002/ooooo`03o`000?oooooooooo00Oooooo0_l0
00000ooooooo0000o`00002]ooooo`00Toooool2o`000003ooooool0003o000001Cooooo00?o0000
ooooooooool02?ooool2o`000:oooooo002Booooo`?o000000?oooooo`000?l000005?ooool00ol0
003oooooooooo`06ooooo`Co0000[oooool009;ooooo0_l0000Hooooo`03o`000?oooooooooo00Ko
oooo0ol0002`ooooo`00[?ooool00ol0003oooooooooo`07ooooo`;o0000/?ooool00:cooooo00Go
0000ooooool0003o0000ooooo`02o`000;Gooooo002[ooooo`;o000000Coooooo`000?l0003ooooo
0_l0002eooooo`00Zoooool5o`0000?ooooo0ol0002booooo`00Uoooool2o`0001?ooooo00?o0000
ooooool000000_l00002ooooo`?o0000/_ooool009Oooooo0_l0000Booooo`;o000000Goooooo`00
0?l0003o0000ooooo`02o`000;Cooooo002Fooooo`?o00001?ooool2o`0000cooooo0_l000000ooo
oooo0000o`000002ooooo`;o0000]?ooool009Kooooo0ol00004ooooo`;o00003Oooool00ol0003o
ooooooooo`2iooooo`00U_ooool2o`000003ooooool0003o0000017ooooo00?o0000ooooooooool0
^Oooool009Wooooo0_l0000Aooooo`03o`000?oooooooooo0;Wooooo002Tooooo`;o00001_ooool0
0ol0003oooooooooo`2iooooo`00Y?ooool2o`0000Kooooo0ol0002iooooo`00Voooool2o`0000?o
oooo0ol00009ooooo`?o0000^Oooool009Sooooo1Ol00003ooooo`?o00001oooool5o`000;Wooooo
002Hooooo`Co000000?oooooo`000?l000001_ooool2o`0000?ooooo0ol0002kooooo`00WOooool2
o`0000Kooooo0_l00002ooooo`;o000000?oooooo`000?ooool0^_ooool009_ooooo0_l00008oooo
o`;o000000Koooooo`000?l0003o0000ooooool0002kooooo`00Voooool2o`0000?ooooo1_l00000
1?l@413oooooo`000?l00002ooooo`03o`000?oooooooooo0;Wooooo002Mooooo`;o000000?ooooo
o`000?l000000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo002Moooo
o`;o00001Oooool00ol0003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000oooooooo
ool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0`Ooo
ool00:Cooooo00?o0000ooooooooool0`Oooool00:;ooooo00?oEEEEofIVI_l00000`oooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:[ooooo00Co410@o`00
0?l0003o0000^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooooooo
ool0^_ooool00:_ooooo00Ko0000ogMgMol0003o0000oeEEEOo^k^jgooooo`00Zoooool01_l0003o
EEEEonk^k_ooooooMgMgoeEEEKOooooo002[ooooo`03o`000?o^k^kooooo00;ooooo00?o0000oooo
ooooool0]Oooool00:_ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`2eooooo`00
Zoooool01_l0003oEEEEonk^k_ooooooMgMgofIVI[Oooooo002Zooooo`03oa0@4?l0003oMgMg00;o
000000?oIVIVonk^k_ooool0]_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.51714 .14133 Mdot
.55659 .18417 Mdot
.48971 .38082 Mdot
.42271 .59626 Mdot
.58799 .49279 Mdot
.41694 .21666 Mdot
.44188 .59035 Mdot
.66692 .75105 Mdot
.6299 .78464 Mdot
.46107 .22935 Mdot
.51584 .26989 Mdot
.61097 .84458 Mdot
.60734 .25037 Mdot
.45964 .22275 Mdot
.52249 .94948 Mdot
.41677 .45404 Mdot
.4236 .76867 Mdot
.60925 .25269 Mdot
.5626 .36896 Mdot
.68465 .42399 Mdot
.64017 .33664 Mdot
.60768 .27485 Mdot
.63673 .35702 Mdot
.62432 .28521 Mdot
.5003 .981 Mdot
.5866 .61892 Mdot
.55131 .36523 Mdot
.56982 .41242 Mdot
.68985 .46858 Mdot
.58503 .23606 Mdot
.65998 .4263 Mdot
.65315 .74526 Mdot
.63731 .79251 Mdot
.39497 .4907 Mdot
.39381 .56927 Mdot
.67839 .51977 Mdot
.67926 .6407 Mdot
.56544 .40644 Mdot
.68286 .57277 Mdot
.63149 .81935 Mdot
.55912 .92048 Mdot
.39501 .57156 Mdot
.40326 .30477 Mdot
.47835 .09657 Mdot
.45716 .10993 Mdot
.59188 .54394 Mdot
.50608 .25607 Mdot
.67981 .67696 Mdot
.55437 .72981 Mdot
.68578 .52931 Mdot
.67278 .69203 Mdot
.69184 .55072 Mdot
.40281 .31782 Mdot
.39108 .5165 Mdot
.62763 .79754 Mdot
.65293 .77622 Mdot
.44607 .83088 Mdot
.68107 .65712 Mdot
.44806 .12182 Mdot
.58651 .58531 Mdot
.4429 .99192 Mdot
.67574 .60591 Mdot
.52149 .65192 Mdot
.57627 .87507 Mdot
.65154 .75375 Mdot
.47007 .22532 Mdot
.42641 .35798 Mdot
.55592 .35831 Mdot
.64051 .32629 Mdot
.49008 .85573 Mdot
.43315 .5018 Mdot
.48956 .23185 Mdot
.44504 .26241 Mdot
.67554 .60655 Mdot
.50873 .51585 Mdot
.55196 .70294 Mdot
.6926 .52934 Mdot
.48071 .83482 Mdot
.67056 .47114 Mdot
.59122 .25075 Mdot
.42207 .57791 Mdot
.39693 .612 Mdot
.66807 .73982 Mdot
.41998 .6094 Mdot
.58864 .49697 Mdot
.57766 .60089 Mdot
.48206 .85369 Mdot
.43158 .32787 Mdot
.4814 .99266 Mdot
.36569 .29898 Mdot
.51017 .69423 Mdot
.58957 .5437 Mdot
.50646 .69973 Mdot
.3568 .50226 Mdot
.45902 .22429 Mdot
.64628 .74616 Mdot
.51158 .82277 Mdot
.53855 .17112 Mdot
.51811 .80769 Mdot
.58483 .87739 Mdot
.50454 .11723 Mdot
.6604 .38953 Mdot
.39488 .47092 Mdot
.4548 .85026 Mdot
.56723 .37973 Mdot
.51084 .69293 Mdot
.64743 .35032 Mdot
.45124 .23819 Mdot
.43685 .68861 Mdot
.64873 .75214 Mdot
.68111 .43968 Mdot
.54968 .00303 Mdot
.49951 .31975 Mdot
.57652 .63204 Mdot
.678 .70822 Mdot
.67266 .71395 Mdot
.65824 .69173 Mdot
.61419 .26653 Mdot
.64986 .39635 Mdot
.69027 .45486 Mdot
.64442 .33854 Mdot
.41829 .50495 Mdot
.68413 .4713 Mdot
.35989 .60694 Mdot
.59213 .26376 Mdot
.53296 .485 Mdot
.6234 .31063 Mdot
.56092 .20514 Mdot
.58459 .88214 Mdot
.40167 .29393 Mdot
.40884 .26398 Mdot
.69373 .48295 Mdot
.69798 .56207 Mdot
.6874 .47975 Mdot
.49224 .23599 Mdot
.60866 .83796 Mdot
.53701 .9351 Mdot
.36938 .70157 Mdot
.47693 .75084 Mdot
.55529 .34926 Mdot
.42762 .78372 Mdot
.68236 .42426 Mdot
.67207 .72768 Mdot
.58603 .03402 Mdot
.57812 .51492 Mdot
.57869 .602 Mdot
.55564 .941 Mdot
.53208 .78381 Mdot
.53254 .29458 Mdot
.61944 .27163 Mdot
.4344 .54086 Mdot
.48451 .11706 Mdot
.69037 .58592 Mdot
.68284 .58305 Mdot
.66385 .73586 Mdot
.67212 .66057 Mdot
.69238 .57976 Mdot
.57634 .66518 Mdot
.6947 .50769 Mdot
.62806 .83594 Mdot
.67495 .51701 Mdot
.4336 .17746 Mdot
.55827 .20691 Mdot
.66842 .73306 Mdot
.66218 .38797 Mdot
.5553 .35857 Mdot
.6991 .53838 Mdot
.67991 .55021 Mdot
.45134 .71747 Mdot
.55794 .3778 Mdot
.58418 .55171 Mdot
.58043 .49205 Mdot
.60857 .83471 Mdot
.35713 .51709 Mdot
.48719 .1196 Mdot
.51956 .39855 Mdot
.6893 .51162 Mdot
.69887 .51597 Mdot
.61186 .85024 Mdot
.41953 .38987 Mdot
.55623 .92496 Mdot
.53459 .53701 Mdot
.6154 .80526 Mdot
.35801 .53303 Mdot
.67581 .69947 Mdot
.62412 .83972 Mdot
.39844 .339 Mdot
.50542 .99022 Mdot
.68163 .41724 Mdot
.52176 .64336 Mdot
.42528 .95795 Mdot
.66392 .75156 Mdot
.57212 .91236 Mdot
.58747 .87611 Mdot
.58799 .54723 Mdot
.36032 .34888 Mdot
.4534 .85354 Mdot
.50939 .36376 Mdot
.51096 .36852 Mdot
.43327 .47465 Mdot
.58449 .53661 Mdot
.3675 .26327 Mdot
.56371 .21323 Mdot
.5237 .62237 Mdot
.43444 .1602 Mdot
.46219 .75006 Mdot
.53892 .5048 Mdot
.50581 .24641 Mdot
.59077 .22496 Mdot
.55846 .68608 Mdot
.6631 .39251 Mdot
.42953 .32687 Mdot
.56451 .21748 Mdot
.55619 .68828 Mdot
.61888 .84877 Mdot
.53714 .48142 Mdot
.48835 .113 Mdot
.646 .795 Mdot
.58004 .61789 Mdot
.65923 .71044 Mdot
.65729 .36896 Mdot
.67203 .50168 Mdot
.44246 .282 Mdot
.58455 .47723 Mdot
.52256 .13312 Mdot
.472 .7428 Mdot
.52477 .94742 Mdot
.50565 .99503 Mdot
.41753 .55084 Mdot
.48254 .66102 Mdot
.39201 .11644 Mdot
.49738 .83107 Mdot
.53628 .31434 Mdot
.56035 .38412 Mdot
.50955 .12221 Mdot
.63783 .3412 Mdot
.55265 .19185 Mdot
.43012 .97054 Mdot
.39707 .34116 Mdot
.6661 .3898 Mdot
.48994 .85571 Mdot
.66926 .71547 Mdot
.49401 .72389 Mdot
.67675 .6313 Mdot
.42679 .77166 Mdot
.49367 .85198 Mdot
.68023 .58951 Mdot
.56405 .92013 Mdot
.50072 .32402 Mdot
.50624 .68705 Mdot
.66901 .65889 Mdot
.56767 .67721 Mdot
.55815 .38134 Mdot
.39553 .63502 Mdot
.50858 .52886 Mdot
.63845 .79685 Mdot
.68198 .66414 Mdot
.5324 .77394 Mdot
.53518 .31133 Mdot
.67344 .50258 Mdot
.52761 .43183 Mdot
.51381 .8115 Mdot
.52369 .15446 Mdot
.52365 .29574 Mdot
.45496 .13316 Mdot
.67809 .54244 Mdot
.54254 .73862 Mdot
.68194 .48493 Mdot
.39103 .53927 Mdot
.44369 .25842 Mdot
.50775 .80976 Mdot
.69339 .56985 Mdot
.41637 .42259 Mdot
.57498 .39996 Mdot
.6671 .7074 Mdot
.48523 .2152 Mdot
.45803 .12151 Mdot
.69114 .51076 Mdot
.52528 .39758 Mdot
.45675 .24433 Mdot
.66743 .6724 Mdot
.60038 .85588 Mdot
.56662 .37494 Mdot
.43732 .56765 Mdot
.57589 .57422 Mdot
.67395 .39833 Mdot
.58238 .59115 Mdot
.66875 .47078 Mdot
.35796 .49015 Mdot
.67095 .67967 Mdot
.54925 .91793 Mdot
.65443 .7165 Mdot
.47205 .6712 Mdot
.69149 .61803 Mdot
.40879 .90962 Mdot
.66736 .37546 Mdot
.52903 .94156 Mdot
.60263 .04851 Mdot
.53111 .76985 Mdot
.39037 .55992 Mdot
.55336 .1903 Mdot
.66247 .72863 Mdot
.53582 .94425 Mdot
.50312 .2477 Mdot
.65923 .72259 Mdot
.56814 .6785 Mdot
.49594 .32621 Mdot
.60274 .25115 Mdot
.42396 .77222 Mdot
.61938 .28203 Mdot
.55602 .93877 Mdot
.5136 .36484 Mdot
.50321 .12815 Mdot
.39425 .50694 Mdot
.57028 .88454 Mdot
.52254 .39584 Mdot
.60107 .86487 Mdot
.44554 .98356 Mdot
.38425 .8235 Mdot
.41749 .48413 Mdot
.39373 .36108 Mdot
.40141 .66518 Mdot
.67432 .61958 Mdot
.58325 .44131 Mdot
.48195 .29939 Mdot
.45391 .64422 Mdot
.45356 .84701 Mdot
.65479 .77762 Mdot
.66052 .67866 Mdot
.51492 .67819 Mdot
.59574 .2405 Mdot
.53315 .47037 Mdot
.43402 .45752 Mdot
.5288 .14163 Mdot
.40641 .26851 Mdot
.43262 .17972 Mdot
.57386 .67178 Mdot
.58345 .53885 Mdot
.4035 .06222 Mdot
.5508 .71826 Mdot
.59793 .27029 Mdot
.51008 .68393 Mdot
.62578 .8056 Mdot
.5503 .36431 Mdot
.6864 .48331 Mdot
.61492 .30396 Mdot
.5022 .71814 Mdot
.55732 .6789 Mdot
.37343 .74031 Mdot
.62445 .82559 Mdot
.69832 .59181 Mdot
.67995 .51449 Mdot
.55078 .73103 Mdot
.43101 .80581 Mdot
.68164 .5319 Mdot
.50813 .81783 Mdot
.6209 .83035 Mdot
.40646 .92276 Mdot
.66724 .39254 Mdot
.57986 .8873 Mdot
.59628 .87173 Mdot
.59012 .8863 Mdot
.43824 .40317 Mdot
.5059 .8166 Mdot
.52734 .94557 Mdot
.64749 .78358 Mdot
.43947 .39257 Mdot
.66537 .44071 Mdot
.52442 .76852 Mdot
.41839 .20712 Mdot
.53376 .16456 Mdot
.64081 .75855 Mdot
.51304 .12747 Mdot
.6817 .64073 Mdot
.6626 .66551 Mdot
.63608 .35776 Mdot
.7012 .57069 Mdot
.6257 .32018 Mdot
.51594 .96298 Mdot
.55431 .00432 Mdot
.65083 .71242 Mdot
.4661 .11391 Mdot
.43456 .4767 Mdot
.48101 .99921 Mdot
.502 .83474 Mdot
.45616 .64946 Mdot
.62082 .83956 Mdot
.64205 .33017 Mdot
.47182 .29692 Mdot
.45493 .24158 Mdot
.58057 .63128 Mdot
.54272 .33121 Mdot
.68203 .67462 Mdot
.64796 .32761 Mdot
.41375 .92727 Mdot
.61044 .85293 Mdot
.40777 .6942 Mdot
.42111 .0182 Mdot
.4159 .74571 Mdot
.58 .47511 Mdot
.58097 .45442 Mdot
.5046 .59267 Mdot
.64762 .78749 Mdot
.60996 .84536 Mdot
.54947 .35891 Mdot
.47952 .74583 Mdot
.49271 .21656 Mdot
.41494 .53344 Mdot
.55326 .93782 Mdot
.59182 .51047 Mdot
.67632 .49169 Mdot
.44944 .72217 Mdot
.53938 .3125 Mdot
.5284 .43097 Mdot
.59006 .51012 Mdot
.39528 .515 Mdot
.52621 .28315 Mdot
.52212 .63058 Mdot
.52168 .97683 Mdot
.61405 .83018 Mdot
.46466 .38454 Mdot
.39305 .55674 Mdot
.45296 .84791 Mdot
.52295 .16364 Mdot
.51783 .78188 Mdot
.55436 .3594 Mdot
.50075 .9884 Mdot
.35675 .55955 Mdot
.5347 .15784 Mdot
.47452 .09435 Mdot
.52804 .61294 Mdot
.60086 .83011 Mdot
.5174 .95673 Mdot
.5307 .30589 Mdot
.62181 .32512 Mdot
.41376 .03215 Mdot
.47016 .74596 Mdot
.46595 .30322 Mdot
.58039 .5198 Mdot
.67384 .48317 Mdot
.50441 .80926 Mdot
.36263 .32558 Mdot
.53609 .53335 Mdot
.40105 .33893 Mdot
.40296 .67378 Mdot
.52282 .65296 Mdot
.52022 .3962 Mdot
.42323 .3532 Mdot
.66324 .75765 Mdot
.51103 .35114 Mdot
.69336 .5077 Mdot
.54338 .16583 Mdot
.48313 .10606 Mdot
.68305 .47379 Mdot
.66676 .4663 Mdot
.41976 .75795 Mdot
.37338 .76913 Mdot
.45529 .24002 Mdot
.65487 .7783 Mdot
.57527 .9075 Mdot
.53091 .31563 Mdot
.69484 .60615 Mdot
.52946 .7624 Mdot
.41144 .70377 Mdot
.6862 .47517 Mdot
.53085 .15858 Mdot
.56868 .39424 Mdot
.55968 .67327 Mdot
.39592 .56214 Mdot
.4292 .18484 Mdot
.50843 .47036 Mdot
.41383 .24707 Mdot
.4923 .82836 Mdot
.43304 .46044 Mdot
.42377 .38393 Mdot
.39856 .35642 Mdot
.39592 .36194 Mdot
.50416 .33911 Mdot
.56342 .68445 Mdot
.65001 .75695 Mdot
.58727 .4656 Mdot
.52045 .15158 Mdot
.53877 .30045 Mdot
.57467 .4675 Mdot
.44676 .35193 Mdot
.45526 .32657 Mdot
.54316 .16292 Mdot
.63935 .74933 Mdot
.67622 .50793 Mdot
.55834 .36501 Mdot
.68844 .49249 Mdot
.61163 .84814 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0=ooooo`?o0000ZOooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0=ooooo`?o0000ZOooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo002Roooo
o`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0^Oooool009;ooooo0_l0000Hooooo`03
o`000?oooooooooo0;Wooooo002Booooo`;o00006?ooool00ol0003oooooooooo`2iooooo`00[?oo
ool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002?ooooo`;o00006oooool00ol0003oooooooooo`0Iooooo`;o0000W_ooool008oooooo
0_l0000Kooooo`03o`000?oooooooooo01Wooooo0_l0002Nooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`0Nooooo`;o0000VOooool00:cooooo0ol0000Nooooo`;o0000
VOooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
08cooooo0_l0000Nooooo`03o`000?oooooooooo0;Wooooo002<ooooo`;o00007_ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002Sooooo`;o00001oooool00ol0003oooooooooo`2iooooo`00Xoooool3o`0000Kooooo
00?o0000ooooooooool0^Oooool00:Cooooo0_l00006ooooo`?o0000^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:Kooooo0_l00004ooooo`03o`000?oooooooooo0;Wooooo002Mooooo`;o
00001oooool2o`0000Cooooo00?o0000ooooooooool0^Oooool009gooooo0_l00009ooooo`;o0000
0_ooool00ol0003oooooooooo`2iooooo`00R?ooool2o`0001Kooooo0_l00006ooooo`;o00000_oo
ool00ol0003oooooooooo`2iooooo`00R?ooool2o`000004oc8b<_l0003o<S8bonk^kPGooooo0_lQ
8B46ooooo`03o`000?o^k^kooooo00;ooooo0_l000001?m4A4Co0000o`000?lb<S83o`0000?ooooo
0ol0002iooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B45ooooo`;o0000
00CoZJVYooooool0003o00001Oooool01?mgMgOo0000o`000?l00003ooooo`Go0000]oooool0087o
oooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool2o`000004oeEEEOoooooo0000
o`0000Kooooo00?o0000ooooooooool00oooool5o`000;Oooooo0029ooooo`05o`000?oooooooooo
ooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00000
0ooooooo0000o`00002fooooo`00ROooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEE
olc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo0ol000000ooooooo0000o`00
002fooooo`00ROooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYo`000?l000000ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo0_l0002cooooo`00ROooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Co410@oooooooooooooooo0_l00003ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01?ooool2o`000;?ooooo0029ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o0000/Oooool00:cooooo00?o0000
ooooooooool00_ooool2o`0000;ooooo0_l0002aooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool3o`0000?ooooo0_l0002dooooo`00[?ooool00ol0003oooooooooo`03ooooo`?o0000
/oooool00:cooooo00?o0000ooooooooool01?ooool2o`000004ooooool0003o0000o`000:oooooo
002Fooooo`;o00005?ooool00ol0003oooooooooo`07ooooo`?o0000[oooool009Kooooo0_l0000D
ooooo`03o`000?oooooooooo00Cooooo0_l00002ooooo`;o000000?oooooo`000?l00000[?ooool0
0:cooooo00?o0000ooooooooool01?ooool2o`0000;ooooo0_l000000ooooooo0000o`00002/oooo
o`00[?ooool00ol0003oooooooooo`09ooooo`Co0000[?ooool00:cooooo00?o0000ooooooooool0
2Oooool2o`000:kooooo002/ooooo`?o0000^Oooool009Gooooo0ol0000Dooooo`03o`000?oooooo
oooo0;Wooooo002Eooooo`?o00005?ooool00ol0003oooooooooo`2iooooo`00U?ooool2o`0001Ko
oooo00?o0000ooooooooool03oooool2o`000:Sooooo002Dooooo`;o00005_ooool00ol0003ooooo
ooooo`0?ooooo`;o0000Z?ooool00:cooooo00?o0000ooooooooool03_ooool2o`000:Wooooo002/
ooooo`03o`000?oooooooooo00kooooo0_l0002Yooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Aooooo`;o00006Ooo
ool00ol0003oooooooooo`0@ooooo`?o0000Y_ooool0097ooooo0_l0000Iooooo`03o`000?oooooo
oooo013ooooo0ol0002Vooooo`00[?ooool00ol0003oooooooooo`0Booooo`;o0000YOooool0093o
oooo0_l0000Eooooo`Co000000?oooooo`000?ooool04oooool2o`000:Gooooo002@ooooo`;o0000
5Oooool4o`000003ooooool0003ooooo01?ooooo0_l0002Uooooo`00W_ooool2o`0000cooooo00?o
0000ooooooooool04_ooool2o`000:Gooooo002Nooooo`;o00000_ooool2o`0000Sooooo0ol0000K
ooooo`;o0000W?ooool009kooooo0_l00002ooooo`;o00002?ooool00ol0003oooooooooo`0Koooo
o`;o0000W?ooool009oooooo0_l00007ooooo`;o00000_ooool00ol0003oooooooooo`2iooooo`00
Woooool2o`0000Oooooo0_l00002ooooo`03o`000?oooooooooo0;Wooooo002Yooooo`;o000000?o
ooooo`000?ooool06_ooool2o`0009kooooo002Kooooo`Co00002_ooool2o`000003ooooool0003o
oooo01[ooooo0_l000000ooooooo0000o`00002Kooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo1?l00003ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooooooo
o`0Looooo`;o0000Voooool008oooooo0_l000001OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B42o`0000Kooooo00?oMgMgoc8b<_ooool01?ooool3o`000;Wooooo0029ooooo`So000000Go410@
oooooooooooooooooa0@4007ooooo`;o00001oooool00ol0003oooooooooo`03ooooo`?o0000^Ooo
ool0097ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0
000Kooooo`;o000000?oooooo`000?l000000ol0002Fooooo`00TOooool01Ol0003ooooooooooooo
oooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`04o`000?oooooo0000o`0001[o
oooo0_l000000ooooooo0000o`000003o`0009Kooooo002Aooooo`05oa0@4?ooooooooooooooool@
41000oooool2o`0000Oooooo00?o0000ooooooooool01oooool01?l0003oooooo`000?l0002hoooo
o`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0_l00007ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0^Oooool0083ooooo0_l0000;ooooo`;o00000_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo0_l00007ooooo`Co00001_ooool00ol0003oooooooooo`0Koooo
o`;o0000W?ooool0083ooooo0_l0000;ooooo`;o00002_ooool2o`00017ooooo00?o0000oooooooo
ool06oooool2o`0000Gooooo0_l0002Eooooo`00SOooool2o`0001gooooo00?o0000ooooooooool0
0_ooool2o`0001Wooooo0_l00003ooooo`;o0000UOooool008gooooo0_l0000Mooooo`03o`000?oo
oooooooo00;ooooo0_l0000Iooooo`;o00001Oooool2o`0009?ooooo002/ooooo`?o00008?ooool2
o`0000;ooooo0_l0002Cooooo`00[?ooool00ol0003oooooooooo`0Pooooo`;o0000Uoooool009Wo
oooo0_l0000Aooooo`03o`000?oooooooooo00Gooooo0_l0000Mooooo`;o0000Toooool009Wooooo
0_l0000Aooooo`03o`000?oooooooooo00Gooooo0_l0000Mooooo`Co0000TOooool00:cooooo00?o
0000ooooooooool09_ooool2o`00097ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002;oooo
o`;o00007oooool00ol0003oooooooooo`07ooooo`;o0000/?ooool008_ooooo0_l0000Eooooo`;o
00002?ooool00ol0003oooooooooo`04ooooo`;o000000?oooooo`000?l00000/?ooool007oooooo
0_l0000Qooooo`;o00000_ooool2o`0000Cooooo0ol00004ooooo`;o00000oooool2o`000:kooooo
001oooooo`;o00007oooool2o`0000Cooooo0_l00004ooooo`03o`000?oooooooooo00Wooooo0_l0
000Hooooo`;o0000U?ooool008cooooo0_l0000Booooo`;o00002_ooool00ol0003oooooooooo`07
ooooo`;o00006_ooool2o`0009Cooooo002<ooooo`;o00007_ooool00ol0003oooooooooo`07oooo
o`;o00007?ooool2o`0009;ooooo002/ooooo`03o`000?oooooooooo00Sooooo1?l0000Iooooo`;o
0000T_ooool00:cooooo00?o0000ooooooooool01oooool5o`000:gooooo002;ooooo`;o00007_oo
ool2o`0000Wooooo1?l0002^ooooo`00Roooool2o`0001kooooo0_l0000Xooooo`;o0000TOooool0
07kooooo0_l0000/ooooo`?o00009Oooool3o`00097ooooo001nooooo`;o00005?ooool3o`0000Ko
oooo0_l0000;ooooo`Co00009_ooool2o`0000Cooooo1?l0002:ooooo`00U?ooool3o`0000Kooooo
0_l0000;ooooo`?o00003Oooool2o`0001kooooo1?l0002:ooooo`00[?ooool00ol0003ooooooooo
o`0;ooooo`;o00007_ooool2o`0008cooooo002/ooooo`03o`000?oooooooooo02_ooooo0_l0002<
ooooo`00R_ooool3o`0001oooooo0ol0000[ooooo`?o0000Roooool008[ooooo0ol0000Oooooo`?o
0000:_ooool4o`0008_ooooo002:ooooo`;o00008?ooool00ol0003oooooooooo`0Zooooo`;o0000
SOooool007gooooo0_l0000]ooooo`03o`000?oooooooooo00oooooo0_l0002Xooooo`00OOooool2
o`0001_ooooo0_l0000@ooooo`Go00003Oooool2o`0001cooooo0_l0002:ooooo`00T_ooool2o`00
00Kooooo0_l0000@ooooo`03o`000?oooooooooo00;o0000:oooool2o`0008[ooooo002:ooooo`;o
00001_ooool3o`0001Oooooo00?o0000ooooooooool03Oooool4o`0001Sooooo0ol0002=ooooo`00
R?ooool4o`0000Oooooo0_l0000Gooooo`03o`000?oooooooooo00gooooo1?l0000Hooooo`?o0000
SOooool008Sooooo0ol0000Qooooo`03o`000?oooooooooo00?o00002_ooool5o`000:Oooooo0029
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`03o`0000[ooooo1Ol0002Wooooo`00ROoo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00;o00003?ooool2o`000003
ooooool0003o000001gooooo0_l00027ooooo`00POooool6o`0000;ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02o`0000oooooo0_l0000Mooooo`;o0000Qoooool008Wooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0001?o
oooo0_l0000Oooooo`;o0000Poooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo
013ooooo0_l000000ooooooo0000o`00000Oooooo`;o0000Poooool008Wooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool2o`00
00;ooooo00?o0000ooooooooool04?ooool2o`000003ooooool0003o00000:Cooooo0029ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01?ooool2o`0000Gooooo00Go0000okZj^_ooooooV9RHoa0@4002
ooooo`?o00001Oooool2o`0000;ooooo00?o0000ooooooooool04?ooool2o`000:Oooooo0029oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool2o`0000Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c002ooooo`Ko00001_ooool00ol0003oooooooooo`0@ooooo`;o00008?ooool2o`0008Gooooo002A
ooooo`;o00006Oooool00ol0003oooooooooo`0booooo`?o0000Q?ooool0097ooooo0_l00005oooo
o`;o00004_ooool00ol0003oooooooooo`0Cooooo`;o00007Oooool4o`0008?ooooo002Hooooo`;o
00004_ooool00ol0003oooooooooo`03ooooo`Co00003?ooool2o`0001Wooooo0_l00002ooooo`Ko
0000POooool00:cooooo0ol00003ooooo`Co00003_ooool2o`0001Oooooo0_l00006ooooo`;o0000
POooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo00?ooooo0_l0000@ooooo`;o0000X_oo
ool009Oooooo0_l0000Cooooo`03o`000?oooooooooo01;ooooo0_l0002Uooooo`00[?ooool00ol0
003oooooooooo`0Booooo`;o0000YOooool00:cooooo00?o0000ooooooooool05?ooool2o`000:?o
oooo002/ooooo`03o`000?oooooooooo01Cooooo0_l0002Sooooo`00[?ooool00ol0003ooooooooo
o`0iooooo`;o0000O_ooool0093ooooo0_l0000Jooooo`03o`000?oooooooooo03Wooooo0_l0001n
ooooo`00T?ooool2o`0001[ooooo0ol0000iooooo`?o0000OOooool00:cooooo00?o0000oooooooo
ool0<Oooool2o`0000Kooooo0ol0001mooooo`00[?ooool00ol0003oooooooooo`06ooooo`;o0000
:Oooool2o`0008Kooooo002/ooooo`03o`000?oooooooooo00Kooooo0_l0002aooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0cooooo`;o00000oooool2o`00
07oooooo002/ooooo`03o`000?oooooooooo01Sooooo0_l0000Iooooo`;o00000oooool2o`0007oo
oooo002/ooooo`03o`000?oooooooooo01Sooooo0_l0002Oooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool3o`000;Wooooo002@ooooo`;o00006_ooool00ol0003oooooooooo`0Goooo
o`;o00008_ooool2o`0007cooooo002@ooooo`;o00001?ooool2o`0001Cooooo00?o0000oooooooo
ool05oooool2o`0002;ooooo0_l0001looooo`002Oooool4o`000003oa0@4?oooooooooo01Kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05
odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`Go00001?ooool01?m4A4Co0000o`000?lb<S83o`0001Cooooo00?o0000oooooooo
ool06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Ooo
ool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd06?ooool4o`00
0003oa0@4?oooooooooo01;ooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A007ooooo`03ogMgMol0003o000001Gooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omg
MgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnY
ZJWooooo00Oooooo00?oMgMgoc8b<_ooool06Oooool00ol0003oooooooooo`0Dooooo`001_l00005
ooooo`03o`000?oooooooooo013ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003Ooo
ool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?oo
ooooooooooooool@41004?ooool00ol0003oooooooooo`05ooooo`Ko00000_ooool01Ol@413ooooo
oooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo01Gooooo0_l000001_oooooo410@o`000?l0003ooooooa0@40cooooo00?oV9RH
ob4Q8Oo^k^h02?ooool2o`0000oooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oo
oooooooo00gooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003ooooooooo
o`0Hooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMg
Molb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00ko
oooo00Go0000ooooooooooooooooo`00000<ooooo`;o000000?o8B4Qonk^k_ooool01_ooool00omg
MgOo<S8booooo`0Eooooo`04o`000?oooooo0000o`0000Oooooo0_l0000;ooooo`;o000000Kooooo
o`000?l0003o0000ooooool0000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol00004ooooo`;o0000
2?ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003o
oooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`0Ioooo
o`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?
ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo
00Go0000ooooooooooooooooo`00000<ooooo`;o000000?oMgMgofIVI_ooool00oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<01Kooooo00Co0000ooooool0003o00001oooool2o`0000kooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00?o0000ob4Q8Ol000000ol0
0002ooooo`Co00002?ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o
<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`06_ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0
003oooooooooo`0Hooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03
ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oo
oooooooo017ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool2o`0001Cooooo0ol0000Gooooo`?o00000_ooool00ol@413ooooo
ooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool3o`0000Wooooo
00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooo
oooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool04Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00;o
oooo0_l0000Dooooo`03o`000?oooooooooo01Oooooo0ol000000oooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`06ooooo`;o00002Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool05?ooool000Wooooo00?oEEEEofIVI_l000006_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7o
c<c<00Cooooo1?l0000Gooooo`03o`000?oooooooooo00Wooooo0_l0000=ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l000000ooooooo0000
o`000002ooooo`;o000000?oooooo`000?l000001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000Ioooo
o`03oeEEEOmVIVKo000001Kooooo002@ooooo`;o00006_ooool00ol0003oooooooooo`07ooooo`Co
0000:oooool2o`000005ooooool0003o0000o`000?ooool00_l0001jooooo`00T?ooool2o`0001[o
oooo00?o0000ooooooooool01oooool2o`00033ooooo0_l0001nooooo`00OOooool2o`0000[ooooo
0_l0000Qooooo`03o`000?oooooooooo01Oooooo0_l0000Nooooo`;o0000MOooool2o`0000;ooooo
0_l00005ooooo`00OOooool2o`0000[ooooo0_l0000Qooooo`03o`000?oooooooooo01Oooooo0_l0
00000ooooooo0000o`00000Kooooo`;o00000_ooool2o`00077ooooo00Kok^k^ob4Q8On7QhOo^[Zj
o`000?oMgMd5ooooo`00[?ooool00ol0003oooooooooo`0Jooooo`;o00007oooool2o`0007;ooooo
00CogMgMo`000?l@413oc<c<1_ooool000Ooooooool0001<o`0000cooooo00Cok^k^ob4Q8Ol@413o
k^k^1_ooool000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`?o0000
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo0ol00005ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`?o0000
1oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0:ooooo`04ob4Q8OmgMgOoMgMgoc8b<PKooooo0007ooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Oooooo`;o0000
1Oooool00ol0003oooooooooo`03ooooo`;o00001_ooool2o`0000;ooooo0_l0000Eooooo`03o`00
0?oooooooooo00Wooooo0_l0000Looooo`03o`000?oooooooooo00_ooooo0ol0000Hooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`09ooooo`;o0000
0_ooool2o`0000Gooooo0029ooooo`;o00001_ooool2o`0001Wooooo00?o0000ooooooooool02Ooo
ool2o`0000oooooo0ol0000Jooooo`;o00000oooool3o`0007[ooooo002/ooooo`03o`000?oooooo
oooo01[ooooo0ol0000Jooooo`;o00000_ooool4o`0007[ooooo0028ooooo`?o00008Oooool01?l0
003oooooo`000?l0000Eooooo`;o00008?ooool2o`000003ooooool0003o000000?o0000NOooool0
07cooooo0_l0000:ooooo`?o00008Oooool01?l0003oooooo`000?l0000Eooooo`;o00007_ooool4
o`0000Cooooo0_l0001iooooo`00O?ooool2o`0002kooooo00?o0000ooooooooool05oooool2o`00
01gooooo0ol00020ooooo`00[?ooool3o`0001Oooooo0_l0000Nooooo`;o0000P?ooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00Co0000ooooool0003o0000>Oooool4o`0007_ooooo
001mooooo`;o00004?ooool2o`0001_ooooo00Co0000ooooool0003o00001oooool2o`0002oooooo
1Ol0001kooooo`00OOooool2o`00013ooooo0_l0000Kooooo`03o`000?oooooooooo00Sooooo0_l0
000>ooooo`;o00007oooool2o`0007kooooo0028ooooo`;o00003?ooool2o`0001Cooooo00?o0000
ooooooooool02?ooool2o`0000kooooo0_l0000Tooooo`;o0000NOooool008Sooooo0_l0000<oooo
o`;o00005?ooool00ol0003oooooooooo`0Hooooo`Co00006oooool2o`0000Gooooo0_l0001ioooo
o`00[?ooool00ol0003oooooooooo`0Jooooo`?o00006_ooool2o`00083ooooo002/ooooo`03o`00
0?oooooooooo01[ooooo0ol0002Looooo`00T?ooool2o`0001[ooooo0ol0000Hooooo`Co00007?oo
ool2o`0000;ooooo0_l0001kooooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool06?ooool2
o`0001kooooo0_l00002ooooo`;o0000Noooool008Sooooo0_l0000Rooooo`03o`000?oooooooooo
0;Wooooo001looooo`;o00002Oooool3o`0002;ooooo00?o0000ooooooooool0?_ooool2o`0007Wo
oooo001looooo`;o00002Oooool4o`00027ooooo00?o0000ooooooooool0?_ooool2o`0007Wooooo
0029ooooo`;o00003?ooool2o`0001?ooooo00?o0000ooooooooool0^Oooool008Wooooo0_l0000<
ooooo`;o00004oooool00ol0003oooooooooo`0looooo`;o000000?oooooo`000?l00000N?ooool0
08Wooooo0_l0000Qooooo`03o`000?oooooooooo01Kooooo0_l0000Qooooo`;o000000Coooooo`00
0?l0003ooooo0_l0001hooooo`00ROooool2o`00027ooooo0ol0000Fooooo`;o00008Oooool2o`00
07kooooo002Booooo`;o00006?ooool00ol0003oooooooooo`0looooo`;o0000Noooool009;ooooo
0_l0000Hooooo`03o`000?oooooooooo03Wooooo0_l000000ooooooo0000o`00001kooooo`00[?oo
ool00ol0003oooooooooo`0Iooooo`;o00007_ooool4o`0007cooooo002/ooooo`03o`000?oooooo
oooo01Wooooo0_l0000Pooooo`;o0000O?ooool009Sooooo0_l0000Booooo`03o`000?oooooooooo
01Sooooo0_l0000Nooooo`;o00001?ooool2o`0007Wooooo002Hooooo`;o00004_ooool3o`0001So
oooo0_l0000Nooooo`;o00001?ooool2o`0007Wooooo002Booooo`;o00006?ooool3o`000;Wooooo
002Booooo`;o00006?ooool3o`0001Kooooo0_l0002Qooooo`00[?ooool00ol0003oooooooooo`0F
ooooo`?o0000X?ooool007gooooo0_l0000]ooooo`03o`000?oooooooooo01Oooooo0_l0000Noooo
o`;o00001?ooool2o`0007[ooooo001mooooo`;o00004_ooool2o`0001Wooooo00?o0000oooooooo
ool0=oooool2o`0000Cooooo0_l0001jooooo`00R_ooool2o`0000Gooooo0_l0000Iooooo`03o`00
0?oooooooooo00Kooooo0_l0002aooooo`00R_ooool2o`00023ooooo00?o0000ooooooooool01_oo
ool2o`000;7ooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0
0004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Gooooo`Co0000
6oooool2o`0000Cooooo0_l0001kooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo00Cooooo0_l0000Aooooo`Co00006oooool2o`0000Cooooo0_l0001kooooo`00
ROooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003o
ooooooooo`03ooooo`?o00001?ooool2o`000;?ooooo0029ooooo`05o`000?ooooooooooooooool0
00003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0^Oooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00Cooooo0_l0000Aoooo
o`;o00007_ooool2o`00083ooooo0029ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool2o`00
013ooooo0ol0000Nooooo`;o0000P?ooool008Wooooo0_l000000oooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
01Kooooo0_l0002Qooooo`00ROooool3o`000003oc8b<_o^k^kooooo00[ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`0hooooo`?o0000O_ooool00:co
oooo00?o0000ooooooooool01?ooool2o`0003;ooooo0ol0001nooooo`00W?ooool2o`0000kooooo
00?o0000ooooooooool01?ooool2o`000;?ooooo002Looooo`?o00003Oooool00ol0003ooooooooo
o`2iooooo`00WOooool2o`0000gooooo0ol00004ooooo`;o0000/oooool00:cooooo00?o0000oooo
ooooool01?ooool2o`000;?ooooo002/ooooo`03o`000?oooooooooo03Cooooo0_l00002ooooo`;o
0000Ooooool00:Kooooo0_l00004ooooo`03o`000?oooooooooo03Cooooo0ol000000ooooooo0000
o`00001oooooo`00Y_ooool2o`0000Cooooo00?o0000ooooooooool0=Oooool2o`0000;ooooo0_l0
001nooooo`00Roooool2o`0001oooooo00?o0000ooooooooool05_ooool2o`0001[ooooo0_l00005
ooooo`;o0000O_ooool008_ooooo0_l0000Oooooo`03o`000?oooooooooo01Kooooo0_l0000Joooo
o`;o0000QOooool008cooooo0_l0000Dooooo`;o00002?ooool00ol0003oooooooooo`0@ooooo`;o
00000oooool2o`0001gooooo0_l00023ooooo`00S?ooool2o`0001Cooooo0_l00008ooooo`?o0000
4?ooool2o`000003ooooool0003o000000;o00007Oooool2o`0000;ooooo0ol0001nooooo`00[?oo
ool01?l0003oooooooooooooool2o`0000cooooo0_l00002ooooo`;o00007Oooool2o`000004oooo
ool0003o0000ooooo`?o0000O_ooool00:cooooo00Co0000oooooooooooooooo0_l0000<ooooo`;o
00000_ooool2o`0001gooooo0_l000000ooooooo0000o`000022ooooo`00[?ooool00ol0003ooooo
ooooo`02o`0000kooooo0ol0002Vooooo`00Uoooool2o`0001?ooooo00?o0000ooooool000000_l0
000=ooooo`Co0000Y_ooool009Oooooo0_l0000Cooooo`04o`000?oooooo0000o`0000kooooo0_l0
000Pooooo`;o00000oooool2o`00087ooooo002=ooooo`;o00007Oooool00ol0003oooooooooo`02
o`0002oooooo0_l00003ooooo`;o0000POooool008gooooo0_l0000Mooooo`03o`000?oooooooooo
00;o0000]oooool00:cooooo1?l0000fooooo`;o0000P?ooool0083ooooo0_l0000<ooooo`;o0000
7?ooool01?l0003oooooo`000?l0000=ooooo`;o00009oooool2o`00083ooooo0020ooooo`;o0000
3?ooool2o`0001cooooo00?o0000ooooooooool03_ooool2o`0002Cooooo0_l00023ooooo`00[?oo
ool00ol0003oooooooooo`0aooooo`;o000000Coooooo`000?l0003ooooo0_l00020ooooo`00[?oo
ool00ol0003oooooooooo`0^ooooo`;o000000?oooooo`000?l000001?ooool2o`00083ooooo002/
ooooo`03o`000?oooooooooo02kooooo1?l00002ooooo`Co0000POooool009_ooooo0_l0000?oooo
o`;o00003_ooool2o`00027ooooo0_l00002ooooo`Co0000POooool009_ooooo0_l0000?ooooo`;o
00003_ooool2o`0002;ooooo0_l00026ooooo`00Voooool2o`0000gooooo1Ol0000aooooo`;o0000
Q_ooool00:[ooooo0ol0000dooooo`;o000000?oooooo`000?l00000P_ooool00:cooooo00?o0000
ooooooooool03Oooool4o`00027ooooo0_l000000ooooooo0000o`000022ooooo`00[?ooool00ol0
003oooooooooo`0=ooooo`Co00008oooool2o`0008?ooooo002/ooooo`03o`000?oooooooooo03?o
oooo0ol00023ooooo`00P_ooool2o`0002Sooooo00?o0000ooooooooool02oooool2o`0002Kooooo
0ol00023ooooo`00P_ooool2o`0000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1Oooool3o`000003oc8b<_oMgMgooooo00Cooooo00?o0000ooooooooool02oooool2o`0002Oooooo
0_l00023ooooo`00T?ooool2o`000004oiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B45ooooo`;o0000
00?oooooo`000?l000001Oooool00ol0003oooooooooo`0]ooooo`Co0000R?ooool0093ooooo0_l0
0003ooooo`03oa0@4?oooooooooo00[ooooo0_l000000ooooooo0000o`000005ooooo`03o`000?oo
oooooooo02_ooooo1_l00028ooooo`00TOooool01Ol0003ooooooooooooooooo000000Wooooo0_l0
0003ooooo`;o000000?o<S8booooooooool00oooool3o`0002_ooooo0_l000000ooooooo0000o`00
0003ooooo`?o0000Poooool0097ooooo00Go0000ooooooooooooooooo`000009ooooo`;o000000?o
ooooo`000?lQ8B400_l000000oo<c<coooooooooo`03ooooo`03o`000?oooooooooo02kooooo0ol0
0002ooooo`?o0000Poooool0097ooooo0_l00002ooooo`03oa0@4?oooooooooo00[ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0[ooooo`;o000000Goooooo`000?l0003o0000oooo
o`02o`0008Gooooo002Aooooo`;o000000?ooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo02_ooooo0_l000000ooooooo0000o`000002ooooo`;o0000QOooool0
097ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`06
ooooo`;o0000/Oooool00:cooooo00?o0000ooooooooool01_ooool2o`000;7ooooo0022ooooo`;o
00003_ooool2o`0001Sooooo00?o0000ooooooooool01Oooool4o`000;3ooooo0022ooooo`;o0000
3_ooool3o`0001Oooooo00?o0000ooooooooool01Oooool4o`000;3ooooo002Booooo`?o00005ooo
ool3o`0000Oooooo0_l0000Vooooo`;o0000R?ooool00:cooooo00?o0000ooooooooool0;oooool3
o`0008Oooooo002/ooooo`03o`000?oooooooooo00;ooooo0_l0000/ooooo`;o0000Qoooool009Co
oooo0_l0000Fooooo`03o`000?oooooooooo00;ooooo0_l00003ooooo`;o00007_ooool2o`0000Co
oooo0_l0002:ooooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool01oooool2o`0001kooooo
0_l00004ooooo`;o0000R_ooool00:cooooo00?o0000ooooooooool0;Oooool2o`0008[ooooo002/
ooooo`03o`000?oooooooooo02[ooooo0_l000000ooooooo0000o`00002:ooooo`00[?ooool00ol0
003oooooooooo`0Wooooo`;o000000Coooooo`000?l0003ooooo0_l0002:ooooo`00[?ooool3o`00
02Oooooo0_l000000ooooooo0000o`00002=ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
UOooool2o`0001Gooooo00?o0000ooooooooool08oooool2o`000003ooooool0003o0000097ooooo
002Eooooo`;o00005Oooool4o`0000;ooooo0_l0000Nooooo`;o000000?oooooo`000?l00000TOoo
ool00:cooooo2?l0002dooooo`00[?ooool01?l0003oooooooooooooool2o`000;Kooooo002/oooo
o`04o`000?oooooo0000o`0002Oooooo0_l0002?ooooo`00[?ooool01?l0003oooooo`000?l0000W
ooooo`;o0000Soooool008Gooooo0_l0000Uooooo`Go00009?ooool2o`00097ooooo0025ooooo`;o
00008_ooool2o`000004ooooool0003oooooooooo`;o00009?ooool2o`00097ooooo002Jooooo`;o
00003Oooool4o`00023ooooo0_l00002ooooo`Co0000Toooool009[ooooo0_l0000?ooooo`;o0000
8?ooool8o`0009?ooooo002Uooooo`;o00001Oooool2o`00027ooooo0_l00005ooooo`;o0000T?oo
ool00:Gooooo0_l00005ooooo`;o00008Oooool2o`0000;ooooo1Ol0002@ooooo`00[?ooool00ol0
003oooooooooo`0Pooooo`;o00000_ooool4o`00097ooooo002/ooooo`03o`000?oooooooooo027o
oooo0_l0002Fooooo`00W?ooool2o`0000kooooo00?o0000ooooooooool08Oooool2o`000003oooo
ool0003o000009?ooooo002Looooo`?o00002_ooool2o`000004ooooool0003o0000o`00027ooooo
0_l000000ooooooo0000o`00002Cooooo`00W?ooool3o`0000Oooooo1Ol000000ooooooo0000oooo
o`0Oooooo`;o000000?oooooo`000?l00000U_ooool009cooooo0_l00008ooooo`Co00000_ooool0
0ol0003oooooooooo`0Nooooo`;o000000?oooooo`000?l00000U_ooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool07_ooool2o`0009Wooooo0029ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool07_ooool2o`0009Wooooo0029ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool07?ooool2o`0009_ooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool00olQ
8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Fooooo`;o000000Coooooo`00
0?l0003ooooo0_l0002Kooooo`00ROooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEE
olc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool05_oo
ool2o`000003ooooool0003o000009kooooo0029ooooo`05oa0@4?ooooooooooooooool@41003_oo
ool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06?oo
ool3o`0009kooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooo
oooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Dooooo`;o0000
0_ooool2o`0009oooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo
1?l00006ooooo`03o`000?oooooooooo01Cooooo0_l000001?oooooo0000o`000?ooool2o`0009go
oooo002/ooooo`03o`000?oooooooooo01Oooooo0_l000000ooooooo0000o`00002Mooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`00
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002=ooooo`;o00007Oooool00ol0003oooooooooo`0Eooooo`;o0000X_ooool008gooooo0_l0000M
ooooo`03o`000?oooooooooo01Cooooo0ol0002Rooooo`00[?ooool00ol0003oooooooooo`0Doooo
o`;o0000Xoooool00:cooooo00?o0000ooooooooool03Oooool2o`000:[ooooo002/ooooo`03o`00
0?oooooooooo00gooooo0_l000000ooooooo0000o`000002o`000:Gooooo002=ooooo`;o00007Ooo
ool3o`0000oooooo1Ol0002Uooooo`00SOooool4o`0001_ooooo00?o0000ooooooooool03oooool2
o`000:Sooooo002?ooooo`;o00006oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`09ooooo`;o0000[_ooool00:cooooo00?o
0000ooooooooool02Oooool2o`0000?ooooo0ol0002Xooooo`00[?ooool00ol0003oooooooooo`06
ooooo`;o00001_ooool3o`000:Sooooo002/ooooo`03o`000?oooooooooo00Kooooo1?l00005oooo
o`;o0000Z?ooool00:cooooo00?o0000ooooooooool01?ooool6o`000:oooooo002/ooooo`?o0000
1?ooool3o`000;;ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Cooooo`;o00005oooool0
0ol0003oooooooooo`02ooooo`;o0000]Oooool009?ooooo0_l0000Gooooo`03o`000?oooooooooo
00;ooooo0_l0002eooooo`00[?ooool00ol0003oooooooooo`02ooooo`;o0000]Oooool00:cooooo
00?o0000ooooooooool00_ooool2o`000;Gooooo002Dooooo`;o00005_ooool00ol0003ooooooooo
o`2iooooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool0^Oooool00:cooooo0ol00004oooo
o`;o0000/oooool00:cooooo00?o0000ooooooooool01?ooool2o`000;?ooooo002/ooooo`;o0000
^_ooool009[ooooo0_l0000@ooooo`;o0000^_ooool009[ooooo0_l0000@ooooo`;o0000^_ooool0
09Wooooo0_l0000Aooooo`?o0000^Oooool009Wooooo0_l00007ooooo`Go00001Oooool3o`000;Wo
oooo002Tooooo`?o00001Oooool3o`000;Wooooo002Tooooo`?o00001Oooool3o`000;Wooooo002T
ooooo`?o0000`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo00?o0000oooooooo
ool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:;ooooo00?oEEEEofIVI_l00000`ooo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:[ooooo00Co
410@o`000?l0003o0000^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000
ooooooooool0^_ooool00:_ooooo00Ko0000ogMgMol0003o0000oeEEEOo^k^jgooooo`00Zoooool0
1_l0003oEEEEonk^k_ooooooMgMgoeEEEKOooooo002[ooooo`03o`000?o^k^kooooo00;ooooo00?o
0000ooooooooool0]Oooool00:_ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`2e
ooooo`00Zoooool01_l0003oEEEEonk^k_ooooooMgMgofIVI[Oooooo002Zooooo`03oa0@4?l0003o
MgMg00;o000000?oIVIVonk^k_ooool0]_ooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.38935 .39243 Mdot
.40898 .21422 Mdot
.4458 .46158 Mdot
.50736 .70999 Mdot
.54511 .29279 Mdot
.4257 .81479 Mdot
.50189 .62534 Mdot
.72734 .55105 Mdot
.70375 .58464 Mdot
.41893 .61938 Mdot
.41823 .3702 Mdot
.7088 .64458 Mdot
.46808 .07433 Mdot
.4178 .62703 Mdot
.66228 .74948 Mdot
.47757 .76421 Mdot
.54975 .75055 Mdot
.47079 .07273 Mdot
.47108 .19675 Mdot
.61425 .22399 Mdot
.53483 .13664 Mdot
.47783 .08683 Mdot
.53954 .15702 Mdot
.4984 .08528 Mdot
.6527 .781 Mdot
.59417 .41892 Mdot
.46005 .22161 Mdot
.4948 .21338 Mdot
.63729 .26858 Mdot
.44324 .11656 Mdot
.5905 .2263 Mdot
.71125 .54526 Mdot
.71431 .59251 Mdot
.49028 .85142 Mdot
.5077 .84122 Mdot
.6463 .31977 Mdot
.69554 .4407 Mdot
.48808 .21144 Mdot
.67196 .37277 Mdot
.71923 .61935 Mdot
.68731 .72048 Mdot
.50794 .83562 Mdot
.4479 .85545 Mdot
.3862 .57266 Mdot
.3937 .66229 Mdot
.56945 .34394 Mdot
.41535 .41678 Mdot
.71059 .47696 Mdot
.60629 .52981 Mdot
.6575 .32931 Mdot
.70959 .49203 Mdot
.67213 .35072 Mdot
.37029 .77406 Mdot
.45084 .85462 Mdot
.49676 .86284 Mdot
.70665 .59754 Mdot
.72342 .57622 Mdot
.56763 .71468 Mdot
.70392 .45712 Mdot
.39827 .69944 Mdot
.58063 .38531 Mdot
.62305 .85642 Mdot
.6781 .40591 Mdot
.54225 .45192 Mdot
.6863 .67507 Mdot
.71304 .55375 Mdot
.4161 .58095 Mdot
.45451 .74288 Mdot
.46145 .20877 Mdot
.53103 .12629 Mdot
.59347 .65852 Mdot
.48445 .68232 Mdot
.41331 .49443 Mdot
.42961 .68222 Mdot
.67816 .40655 Mdot
.47723 .35379 Mdot
.36974 .76977 Mdot
.59313 .50294 Mdot
.66433 .32934 Mdot
.57892 .64606 Mdot
.61901 .27114 Mdot
.45357 .10419 Mdot
.50346 .71478 Mdot
.51647 .82475 Mdot
.724 .53982 Mdot
.51087 .72169 Mdot
.54743 .29697 Mdot
.57801 .40089 Mdot
.58706 .66289 Mdot
.44682 .72683 Mdot
.64119 .79972 Mdot
.54786 .49423 Mdot
.56705 .3437 Mdot
.54635 .49973 Mdot
.41827 .62944 Mdot
.70475 .54616 Mdot
.3683 .76119 Mdot
.60069 .62277 Mdot
.39895 .29133 Mdot
.60119 .60769 Mdot
.69579 .67739 Mdot
.38516 .45372 Mdot
.57621 .18953 Mdot
.48598 .85611 Mdot
.57535 .70737 Mdot
.47944 .19373 Mdot
.54801 .49293 Mdot
.54755 .15032 Mdot
.42298 .66037 Mdot
.52609 .66152 Mdot
.70958 .55214 Mdot
.61698 .23968 Mdot
.36102 .27786 Mdot
.43035 .43198 Mdot
.58933 .43204 Mdot
.72129 .50822 Mdot
.71824 .51395 Mdot
.69493 .49173 Mdot
.48093 .07515 Mdot
.65277 .80899 Mdot
.5684 .19635 Mdot
.63222 .25486 Mdot
.53983 .13854 Mdot
.48835 .74655 Mdot
.63265 .2713 Mdot
.52342 .99043 Mdot
.45908 .10583 Mdot
.48713 .29327 Mdot
.50765 .11063 Mdot
.41705 .19471 Mdot
.69745 .68214 Mdot
.44587 .86474 Mdot
.43779 .83992 Mdot
.64691 .28295 Mdot
.68281 .36207 Mdot
.6393 .27975 Mdot
.41363 .48183 Mdot
.70385 .63796 Mdot
.67105 .7351 Mdot
.54303 .95631 Mdot
.54524 .57248 Mdot
.45783 .20911 Mdot
.55354 .74362 Mdot
.61206 .22426 Mdot
.72314 .52768 Mdot
.38216 .12148 Mdot
.54409 .31492 Mdot
.57949 .402 Mdot
.69204 .741 Mdot
.6056 .58381 Mdot
.42795 .29271 Mdot
.48812 .07497 Mdot
.4927 .66842 Mdot
.38934 .54133 Mdot
.68474 .38592 Mdot
.67606 .38305 Mdot
.7182 .53586 Mdot
.69635 .46057 Mdot
.68428 .37976 Mdot
.60241 .46518 Mdot
.65778 .30769 Mdot
.72243 .63594 Mdot
.64175 .31701 Mdot
.41354 .75055 Mdot
.41612 .20448 Mdot
.72164 .53306 Mdot
.57737 .18797 Mdot
.46102 .21036 Mdot
.67446 .33838 Mdot
.66 .35021 Mdot
.53187 .6188 Mdot
.47012 .20862 Mdot
.56487 .35171 Mdot
.53725 .29205 Mdot
.70246 .63471 Mdot
.38932 .52909 Mdot
.44991 .32749 Mdot
.65395 .31162 Mdot
.66525 .31597 Mdot
.71196 .65024 Mdot
.46296 .76601 Mdot
.68621 .72496 Mdot
.5094 .33701 Mdot
.6975 .60526 Mdot
.71559 .49947 Mdot
.72001 .63972 Mdot
.45642 .86911 Mdot
.66151 .79022 Mdot
.60852 .21724 Mdot
.5391 .44336 Mdot
.60832 .87195 Mdot
.72454 .55156 Mdot
.69706 .71236 Mdot
.69792 .67611 Mdot
.56688 .34723 Mdot
.57624 .71351 Mdot
.43915 .37859 Mdot
.44037 .37056 Mdot
.47849 .68766 Mdot
.55914 .33661 Mdot
.42098 .18364 Mdot
.53265 .42237 Mdot
.40959 .75059 Mdot
.54197 .60649 Mdot
.50084 .3048 Mdot
.41326 .42008 Mdot
.44411 .1002 Mdot
.5929 .48608 Mdot
.58011 .19251 Mdot
.44704 .73598 Mdot
.42272 .18038 Mdot
.5915 .48828 Mdot
.71838 .64877 Mdot
.4898 .28643 Mdot
.38763 .52545 Mdot
.724 .595 Mdot
.58719 .41789 Mdot
.7034 .51044 Mdot
.56488 .16896 Mdot
.63271 .30168 Mdot
.43445 .68926 Mdot
.53544 .27723 Mdot
.38761 .36999 Mdot
.54093 .57551 Mdot
.66374 .74742 Mdot
.66367 .79503 Mdot
.49853 .73994 Mdot
.51421 .48113 Mdot
.40922 .94534 Mdot
.58989 .63128 Mdot
.43481 .27429 Mdot
.64829 .81271 Mdot
.47464 .20628 Mdot
.38557 .43045 Mdot
.53431 .1412 Mdot
.40925 .22865 Mdot
.6131 .8689 Mdot
.45718 .87463 Mdot
.58202 .1898 Mdot
.59335 .65858 Mdot
.71545 .51547 Mdot
.5442 .52552 Mdot
.68926 .4313 Mdot
.55018 .73998 Mdot
.59491 .65313 Mdot
.67603 .38951 Mdot
.6921 .72013 Mdot
.43102 .42576 Mdot
.54107 .48705 Mdot
.69257 .45889 Mdot
.59855 .47721 Mdot
.47161 .20931 Mdot
.52197 .83179 Mdot
.48135 .35472 Mdot
.71719 .59685 Mdot
.70763 .46414 Mdot
.60198 .57394 Mdot
.43348 .2791 Mdot
.63447 .30258 Mdot
.46397 .29426 Mdot
.59841 .6115 Mdot
.39252 .36031 Mdot
.42548 .33022 Mdot
.39925 .66688 Mdot
.65507 .34244 Mdot
.59798 .53862 Mdot
.63591 .28493 Mdot
.50174 .8582 Mdot
.42903 .68895 Mdot
.59166 .60976 Mdot
.68133 .36985 Mdot
.47078 .77275 Mdot
.49497 .20081 Mdot
.71006 .5074 Mdot
.41061 .51695 Mdot
.39604 .65598 Mdot
.65545 .31076 Mdot
.45234 .30507 Mdot
.42313 .635 Mdot
.69639 .4724 Mdot
.70273 .65588 Mdot
.47704 .1923 Mdot
.49792 .64987 Mdot
.56558 .37422 Mdot
.59328 .19833 Mdot
.57884 .39115 Mdot
.61706 .27078 Mdot
.70282 .47967 Mdot
.67643 .71793 Mdot
.70103 .5165 Mdot
.51665 .5182 Mdot
.6987 .41803 Mdot
.59255 .88782 Mdot
.57755 .17546 Mdot
.66566 .74156 Mdot
.39596 .05953 Mdot
.59905 .56985 Mdot
.5064 .85766 Mdot
.40915 .22604 Mdot
.71393 .52863 Mdot
.67352 .74425 Mdot
.41392 .43174 Mdot
.70827 .52259 Mdot
.59954 .4785 Mdot
.43253 .44617 Mdot
.46408 .08193 Mdot
.5507 .75101 Mdot
.4922 .0835 Mdot
.69153 .73877 Mdot
.43988 .35963 Mdot
.38778 .4572 Mdot
.49398 .85105 Mdot
.68409 .68454 Mdot
.4505 .31592 Mdot
.70702 .66487 Mdot
.62073 .84345 Mdot
.57069 .93148 Mdot
.48398 .75453 Mdot
.46225 .88488 Mdot
.52764 .80893 Mdot
.68216 .41958 Mdot
.51977 .24131 Mdot
.4297 .51306 Mdot
.5116 .5748 Mdot
.57399 .70765 Mdot
.72584 .57762 Mdot
.69199 .47866 Mdot
.54619 .47819 Mdot
.45384 .0918 Mdot
.48178 .28643 Mdot
.47459 .68814 Mdot
.39008 .34032 Mdot
.4393 .84958 Mdot
.41425 .75432 Mdot
.60257 .47178 Mdot
.55899 .33885 Mdot
.3949 .90688 Mdot
.5981 .51826 Mdot
.46681 .09769 Mdot
.54365 .48393 Mdot
.70802 .6056 Mdot
.45894 .22422 Mdot
.63972 .28331 Mdot
.49651 .10427 Mdot
.54946 .51814 Mdot
.58888 .4789 Mdot
.55149 .94731 Mdot
.71469 .62559 Mdot
.69504 .39181 Mdot
.64574 .31449 Mdot
.60319 .53103 Mdot
.55976 .74485 Mdot
.6544 .3319 Mdot
.59526 .61783 Mdot
.71304 .63035 Mdot
.59669 .90434 Mdot
.58425 .19254 Mdot
.69478 .6873 Mdot
.70497 .67173 Mdot
.70464 .6863 Mdot
.46181 .68146 Mdot
.59254 .6166 Mdot
.66557 .74557 Mdot
.72092 .58358 Mdot
.45923 .67837 Mdot
.60165 .24071 Mdot
.59183 .56852 Mdot
.42331 .81054 Mdot
.39625 .31356 Mdot
.70423 .55855 Mdot
.38643 .41377 Mdot
.69799 .44073 Mdot
.6888 .46551 Mdot
.53919 .15776 Mdot
.68948 .37069 Mdot
.51377 .12018 Mdot
.66114 .76298 Mdot
.36238 .25745 Mdot
.69579 .51242 Mdot
.39264 .6224 Mdot
.47866 .6816 Mdot
.64351 .80647 Mdot
.5959 .63474 Mdot
.51246 .56689 Mdot
.71664 .63956 Mdot
.53412 .13017 Mdot
.43135 .55782 Mdot
.42293 .64355 Mdot
.59308 .43128 Mdot
.44313 .24822 Mdot
.71187 .47462 Mdot
.539 .12761 Mdot
.59791 .88363 Mdot
.71161 .65293 Mdot
.53322 .78702 Mdot
.38148 .83954 Mdot
.54471 .77023 Mdot
.53005 .27511 Mdot
.52274 .25442 Mdot
.50166 .39267 Mdot
.72261 .58749 Mdot
.7081 .64536 Mdot
.45649 .2261 Mdot
.54433 .56329 Mdot
.40929 .48398 Mdot
.49529 .75499 Mdot
.68839 .73782 Mdot
.55601 .31047 Mdot
.63299 .29169 Mdot
.53343 .62843 Mdot
.43586 .26253 Mdot
.46426 .29177 Mdot
.55411 .31012 Mdot
.49552 .84481 Mdot
.42306 .32174 Mdot
.53436 .43058 Mdot
.67241 .77683 Mdot
.70613 .63018 Mdot
.45203 .57013 Mdot
.50512 .84631 Mdot
.5742 .70989 Mdot
.39455 .3616 Mdot
.59058 .58188 Mdot
.46054 .21287 Mdot
.65611 .7884 Mdot
.39485 .31086 Mdot
.35304 .41265 Mdot
.38655 .58987 Mdot
.53321 .41294 Mdot
.69291 .63011 Mdot
.6601 .75673 Mdot
.43018 .29823 Mdot
.51185 .12512 Mdot
.38611 .86861 Mdot
.54166 .58249 Mdot
.434 .58209 Mdot
.54831 .3198 Mdot
.62711 .28317 Mdot
.58812 .60926 Mdot
.50943 .33335 Mdot
.45583 .85771 Mdot
.52933 .80359 Mdot
.544 .45296 Mdot
.44957 .32519 Mdot
.45415 .75781 Mdot
.7263 .55765 Mdot
.43639 .37401 Mdot
.65644 .3077 Mdot
.39903 .27171 Mdot
.38724 .54975 Mdot
.63257 .27379 Mdot
.61328 .2663 Mdot
.54736 .7602 Mdot
.55863 .9559 Mdot
.42251 .64229 Mdot
.72619 .5783 Mdot
.69827 .7075 Mdot
.43279 .29563 Mdot
.6973 .40615 Mdot
.59442 .5624 Mdot
.53482 .77385 Mdot
.63627 .27517 Mdot
.39432 .32761 Mdot
.48647 .20045 Mdot
.58899 .47327 Mdot
.50568 .83278 Mdot
.65446 .814 Mdot
.41611 .76816 Mdot
.46423 .36041 Mdot
.43302 .8218 Mdot
.58436 .63018 Mdot
.47544 .69177 Mdot
.46074 .74878 Mdot
.46019 .86483 Mdot
.46197 .87515 Mdot
.4338 .40728 Mdot
.59719 .48445 Mdot
.71279 .55695 Mdot
.53351 .2656 Mdot
.39169 .37537 Mdot
.43221 .2666 Mdot
.52167 .2675 Mdot
.44878 .65535 Mdot
.35286 .39389 Mdot
.44141 .62371 Mdot
.39823 .27324 Mdot
.69908 .54933 Mdot
.6394 .30793 Mdot
.46586 .20438 Mdot
.64543 .29249 Mdot
.71088 .64814 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00ROooool2o`00027ooooo00?o0000ooooooooool0^Oooool008Wo
oooo0_l0000Qooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002Qooooo`?o00002?ooool00ol0003oooooooooo`2i
ooooo`00XOooool3o`000004ooooool0003o0000ooooo`;o00000_ooool3o`000;Wooooo002Uoooo
o`;o000000?oooooo`000?l000000_ooool00ol0003oooooooooo`2iooooo`00X?ooool2o`0000[o
oooo00?o0000ooooooooool0^Oooool00:3ooooo0_l00007ooooo`Co0000^oooool00:Cooooo0_l0
0003ooooo`Co0000^oooool009cooooo0_l00006ooooo`;o00001_ooool00ol0003oooooooooo`2i
ooooo`00W?ooool2o`0000kooooo00?o0000ooooooooool0^Oooool00:7ooooo0_l00009ooooo`03
o`000?oooooooooo0;Wooooo002Iooooo`;o00001_ooool2o`0000Wooooo0ol0002iooooo`00VOoo
ool2o`000003ooooool0003o000000cooooo0ol0002kooooo`00W?ooool4o`0000[ooooo0ol0002k
ooooo`00W_ooool2o`0000cooooo00Co0000ooooool0003o0000^?ooool00:cooooo00Co0000oooo
ool0003o0000^?ooool009Wooooo0_l0000Aooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo0ol000000oo^k^koooooooooo`03oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2iooooo`00QOooool2o`00
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07
ooooo`03ogMgMolb<S;ooooo00Cooooo00Co0000oooooooooooooooo0_l0002fooooo`00POooool6
o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o
0000ooooooooool00oooool6o`000;Kooooo0029ooooo`05o`000?ooooooooooooooool000003_oo
ool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool00_l0
0005ooooo`Co0000[_ooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<
c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00Oooooo
1?l0002^ooooo`00ROooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool0
0oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo0_l0002_ooooo`00ROoo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool2o`000:oooooo0029ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo00So
oooo1?l0002]ooooo`00[?ooool00ol0003oooooooooo`08ooooo`Co0000[Oooool00:cooooo00?o
0000ooooooooool02?ooool2o`000:oooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`?o00003?ooool2o`000:_ooooo002/ooooo`03o`000?oooooooooo00cooooo0_l0002[ooooo`00
[?ooool00ol0003oooooooooo`0:ooooo`;o0000[Oooool00:cooooo00?o0000ooooooooool02_oo
ool2o`000:gooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo01;ooooo0_l0002Uooooo`00[?ooool00ol0003ooooo
ooooo`0Booooo`;o0000YOooool00:cooooo0ol0000Fooooo`;o0000XOooool009;ooooo0_l0000H
ooooo`03o`000?oooooooooo01Kooooo0_l0002Qooooo`00T_ooool2o`0001Sooooo00?o0000oooo
ooooool0^Oooool0097ooooo0_l0000Iooooo`03o`000?oooooooooo0;Wooooo002Aooooo`;o0000
6Oooool00ol0003oooooooooo`0Fooooo`;o0000XOooool00:Cooooo0_l00006ooooo`03o`000?oo
oooooooo01Kooooo1?l0002Oooooo`00T?ooool2o`0001;ooooo0ol00005ooooo`03o`000?oooooo
oooo01Kooooo1?l0002Oooooo`00T?ooool2o`00013ooooo0_l000000ooooooo0000o`000005oooo
o`03o`000?oooooooooo01?ooooo0_l00006ooooo`;o0000W?ooool00:;ooooo0_l00003ooooo`;o
000000?oooooo`000?l000000ol0000Cooooo`;o00001_ooool2o`0009cooooo002@ooooo`;o0000
3_ooool2o`0000Gooooo0_l000001?oooooo0000o`000?l0002kooooo`00T?ooool2o`0000kooooo
0_l000000ooooooo0000o`000007ooooo`03o`000?oooooooooo0;Wooooo002Nooooo`?o000000Co
ooooo`000?l0003o00001oooool00ol0003oooooooooo`2iooooo`00W_ooool3o`000003ooooool0
003o000000Cooooo1Ol0002kooooo`00S_ooool2o`0000oooooo0_l00007ooooo`Go0000^oooool0
08kooooo0_l0000Looooo`03o`000?oooooooooo023ooooo0_l0002Gooooo`00W_ooool2o`0000co
oooo00?o0000ooooooooool08?ooool2o`0009Oooooo002Nooooo`;o00003?ooool3o`0002;ooooo
0_l0002Eooooo`00S_ooool2o`0000gooooo0ol0000<ooooo`03o`000?oooooooooo01[ooooo0_l0
0006ooooo`;o0000UOooool008kooooo0_l0000=ooooo`;o00003Oooool00ol0003oooooooooo`0J
ooooo`;o0000WOooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool07_ooool2o`0000?ooooo0_l0002Dooooo`00TOoo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01Oooool00ol0003oooooooooo`03ooooo`;o00006Oooool2o`0000?ooooo0_l0002Dooooo`00
TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool00oooool2o`000;Cooooo0029ooooo`Ko00000_ooool01Ol@413ooooo
oooooooooooo410@00?ooooo0_l0000;ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0^Oooool0097ooooo00Go0000ooooooooooooooooo`000003ooooo`;o00002_ooool00omgMgOo
<S8booooo`04ooooo`?o0000^Oooool0097ooooo00Go0000ooooooooooooooooo`00000<ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`04ooooo`;o00008_ooool2o`00
08oooooo001nooooo`;o00004Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`04ooooo`;o00008_ooool2o`0008oooooo001nooooo`;o
00004Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`2iooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;o00002_ooool4o`00
00Kooooo00?o0000ooooooooool0^Oooool009Gooooo0ol0000Dooooo`03o`000?oooooooooo00Co
oooo0_l00002ooooo`;o00006?ooool2o`0009Gooooo002Eooooo`;o00005Oooool00ol0003ooooo
ooooo`04ooooo`;o00000_ooool2o`0001Sooooo1?l00002ooooo`Co0000SOooool008[ooooo0_l0
000:ooooo`;o00005?ooool00ol0003oooooooooo`0Sooooo`?o00000_ooool4o`0008gooooo002:
ooooo`;o00002_ooool2o`0001Cooooo0ol00006ooooo`Co00007_ooool4o`0008gooooo001noooo
o`;o00005_ooool2o`0001Cooooo00?o0000ooooooooool01_ooool4o`00023ooooo0ol0002<oooo
o`00O_ooool2o`0001Kooooo0_l0000Dooooo`03o`000?oooooooooo02Oooooo0_l00002ooooo`Co
0000R_ooool00:Kooooo1?l00002ooooo`03o`000?oooooooooo02Oooooo2?l0002:ooooo`00Y_oo
ool4o`0000;ooooo00?o0000ooooooooool0:Oooool2o`0008kooooo002:ooooo`;o00005?ooool2
o`0000[ooooo00?o0000ooooooooool02Oooool2o`0001gooooo0_l00003ooooo`;o0000R_ooool0
08[ooooo0_l00008ooooo`;o00002_ooool2o`0000Gooooo0_l00003ooooo`03o`000?oooooooooo
00Wooooo1?l0000Kooooo`;o00000oooool2o`0008[ooooo002Dooooo`?o00002Oooool2o`0000Go
oooo0_l00003ooooo`03o`000?oooooooooo00_ooooo0ol0002[ooooo`00UOooool2o`0001Gooooo
0ol0000<ooooo`;o0000Zoooool00:cooooo00?o0000ooooooooool0:?ooool3o`0008kooooo002L
ooooo`;o00003_ooool2o`0002Wooooo0ol0002>ooooo`00W?ooool2o`0000kooooo0_l0000?oooo
o`?o00006_ooool2o`0000?ooooo0ol00026ooooo`00ROooool2o`00027ooooo00?o0000oooooooo
ool03_ooool3o`0001[ooooo0_l00002ooooo`Co0000Q_ooool008Wooooo0_l0000@ooooo`;o0000
3oooool00ol0003oooooooooo`0;ooooo`;o00008?ooool5o`000003ooooool0003o000008Cooooo
002Kooooo`;o00003oooool00ol0003oooooooooo`0;ooooo`;o00007_ooool4o`0000Cooooo0_l0
0024ooooo`00T_ooool2o`0001Sooooo00?o0000ooooooooool03Oooool2o`0001cooooo1?l0002:
ooooo`00T_ooool2o`0000Oooooo0_l0000?ooooo`?o00003Oooool2o`000:[ooooo0029ooooo`;o
00004?ooool2o`0000oooooo00?o0000ooooooooool0^Oooool008Wooooo0_l00008ooooo`;o0000
1_ooool2o`0000oooooo00?o0000ooooooooool0<Oooool4o`0008Cooooo002Cooooo`;o00005ooo
ool00ol0003oooooooooo`02o`0002kooooo1Ol00024ooooo`00[?ooool00ol0003oooooooooo`02
o`0000kooooo0_l0000Nooooo`;o0000Qoooool008Oooooo0_l0000Sooooo`03o`000?oooooooooo
00;o00003_ooool2o`0002Cooooo0_l00021ooooo`00Qoooool2o`0002?ooooo00?o0000oooooooo
ool04?ooool2o`000003ooooool0003o000001_ooooo0_l00004ooooo`;o0000POooool00:cooooo
00?o0000ooooooooool04oooool2o`0001_ooooo0_l00027ooooo`00[?ooool00ol0003ooooooooo
o`0Cooooo`;o0000Y?ooool00:cooooo0ol0000Booooo`?o00007?ooool2o`0000;ooooo0_l00022
ooooo`00Y?ooool3o`0000Gooooo00?o0000ooooooooool04_ooool2o`0001gooooo0_l00002oooo
o`;o0000P_ooool00:Cooooo0ol00005ooooo`03o`000?oooooooooo0;Wooooo0028ooooo`?o0000
3Oooool2o`0000Kooooo0_l0000:ooooo`03o`000?oooooooooo03Wooooo0_l0001nooooo`00R?oo
ool3o`0000gooooo0_l00006ooooo`;o00002_ooool00ol0003oooooooooo`0iooooo`;o0000O_oo
ool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;Wooooo0026ooooo`;o000000Ko
ooooogMgMonHV9SooooooiRHV?mgMgL3ooooo`;o00000_lQ8B43ooooo`;o000000Co8B4Qonk^k_oo
ooooA4A41oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo03Sooooo0_l000000ooo
oooo0000o`00001looooo`00POooool7o`000003ooooool@413ooooo00;ooooo00Co410@oooooooo
oooooooo0_l00004ooooo`?o000000?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01;ooooo0_l0000Qooooo`;o000000Coooooo`000?l0003ooooo0_l0001l
ooooo`00R?ooool2o`0000?ooooo00?o0000ooooooooool01oooool2o`0000;ooooo00?oV9RHob4Q
8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o00004_ooool2o`00027ooooo0_l00022oooo
o`00R?ooool2o`0000?ooooo00?o0000ooooooooool01oooool2o`0000?ooooo00?oMgMgofIVI_oo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0>Oooool2o`00
07kooooo0029ooooo`05oa0@4?ooooooooooooooool@41002Oooool2o`0000Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Oooooo1?l0001noooo
o`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05oooool2o`0001kooooo0_l00000
0ooooooo0000o`00001mooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`0Gooooo`;o00008Ooo
ool2o`0007gooooo0027ooooo`;o00008oooool00ol0003oooooooooo`0Gooooo`;o00007_ooool2
o`0000Cooooo0_l0001jooooo`00Noooool2o`0000[ooooo0_l0000Sooooo`;o00006?ooool2o`00
01kooooo0_l00004ooooo`;o0000N_ooool007_ooooo0_l0000_ooooo`;o0000^_ooool00:cooooo
0ol0000Fooooo`;o0000XOooool00:cooooo00?o0000ooooooooool05_ooool3o`000:3ooooo002F
ooooo`;o00005?ooool00ol0003oooooooooo`0Gooooo`;o00007_ooool2o`0000Gooooo0_l0001i
ooooo`00U_ooool2o`0001Cooooo00?o0000ooooooooool0=oooool2o`0000Gooooo0_l0001ioooo
o`00Noooool2o`0002oooooo00?o0000ooooooooool02?ooool2o`000:oooooo001kooooo`;o0000
2Oooool2o`0002Cooooo00?o0000ooooooooool02?ooool2o`000:oooooo0026ooooo`;o00002?oo
ool2o`0001[ooooo00?o0000ooooooooool06Oooool2o`000003ooooool0003o000001_ooooo0_l0
0003ooooo`;o0000NOooool008oooooo0ol0000Jooooo`03o`000?oooooooooo00Oooooo0_l0000@
ooooo`;o000000?oooooo`000?l000006oooool2o`0000?ooooo0_l0001iooooo`00Soooool2o`00
00Cooooo0_l0000Eooooo`?o00001oooool2o`000;3ooooo002Eooooo`;o00005Oooool00ol0003o
ooooooooo`2iooooo`00Q_ooool2o`0000Oooooo0_l0000Kooooo`03o`000?oooooooooo00Sooooo
0_l0000Aooooo`;o00007_ooool2o`0007cooooo0026ooooo`;o00001oooool2o`0000Cooooo0_l0
000Eooooo`03o`000?oooooooooo00Sooooo0_l0000@ooooo`?o00007_ooool2o`0007cooooo002E
ooooo`;o00005Oooool00ol0003oooooooooo`0Jooooo`;o0000WOooool00:cooooo00?o0000oooo
ooooool0?Oooool3o`0007Wooooo002/ooooo`03o`000?oooooooooo00Wooooo0_l0000booooo`?o
0000NOooool009Gooooo0_l0000Eooooo`03o`000?oooooooooo00Wooooo0_l0002^ooooo`00UOoo
ool2o`0001Gooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0000;ooooo`;o0000[?ooool0
08Kooooo0_l0000Tooooo`03o`000?oooooooooo00_ooooo0_l0002/ooooo`00Q_ooool3o`0002?o
oooo00?o0000ooooooooool0??ooool2o`0000;ooooo0_l0001gooooo`002Oooool4o`000003oa0@
4?oooooooooo01Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003o
k^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B43ooooo`Ko00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Co
oooo0_l0000@ooooo`03o`000?oooooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@06ooooo`?o000000?ooooo
o`000?l000000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0
003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03
o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`Co000000?o410@oooo
ooooool04_ooool000_ooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool03_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo
00?oMgMgoc8b<_ooool00oooool2o`00013ooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omg
MgOo<S8booooo`06ooooo`;o00000_ooool2o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`0Iooooo`03o`000?oo
oooooooo01Cooooo0006o`0000Gooooo00?o0000ooooooooool04?ooool6o`0000;ooooo00Go410@
oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool01Ooo
ool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00Gooooo
1_l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool06?ooool01_l@413ooooooooooooooooo410@
ooooo`;o00002Oooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0_l00004
ooooo`;o00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool03Ooo
ool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go
0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool0
3_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003o
oooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`0Eoooo
o`03o`000?oooooooooo01Sooooo00Ko0000ooooooooooooooooo`000?ooool2o`0000[ooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`;o00002?ooool01Ol0003ooooooooo
oooooooo000000oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo01Co
oooo000;ooooo`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03
oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?oooooooooo
ooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Fooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooool000000_l000000ooooooo0000o`00000;ooooo`03
ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c007ooooo`;o00001_ooool01Ol0
003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?oo
ooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`06_ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05oa0@
4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo017o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo017ooooo00Go410@oooo
oooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06?ooool3
o`0001Sooooo00Go410@ooooool0003o0000oa0@4003o`0000cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`09ooooo`;o00000oooool3o`000005oa0@4?ooooooooooooooool@4100
3?ooool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWo
MgMgooooo`03ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05?ooool000_ooooo
00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooo
oooooooooc8b<P04ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<
ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj
^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00cooooo
0_l0000:ooooo`05ogMgMonHV9So0000o`000?mgMgL00_l00009ooooo`05o`000?nj^[[ooooooiRH
V?l@41001?ooool00ol0003oooooooooo`08ooooo`;o00000_ooool5o`000005ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Dooooo`002Oooool00omEEEGoIVIVo`00000Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool5o`0000Cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00013o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00_ooool6
o`0001Oooooo00Co0000oooooooooooooooo0_l00009ooooo`;o00002_ooool01Oo^k^ko<S8bo`00
0?l0003ok^k^00;o00002Oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00007ooooo`;o
00000_ooool2o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00004?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00006Oooool00omEEEGoIVIVo`00000F
ooooo`00S_ooool3o`0001_ooooo00Co0000oooooooooooooooo0_l00008ooooo`;o00003_ooool4
o`0009[ooooo002>ooooo`;o00007?ooool00ol0003oooooooooo`0:ooooo`?o00003_ooool4o`00
09[ooooo002/ooooo`03o`000?oooooooooo00[ooooo0_l0000?ooooo`;o00008?ooool2o`0000?o
oooo0_l0001Zooooo`;o00000_ooool2o`0000Gooooo002?ooooo`;o00006oooool00ol0003ooooo
ooooo`0<ooooo`;o0000;oooool2o`0000?ooooo0_l0001Zooooo`06onk^k_lQ8B7oQhN7okZj^_l0
003ogMgM1Oooool008oooooo0_l0000Kooooo`03o`000?oooooooooo00cooooo0_l0002Qooooo`04
omgMgOl0003o410@olc<c0Kooooo0007oooooooo0000C?l0000<ooooo`04onk^k_lQ8B7o410@onk^
kPKooooo0007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00?ooooo0ol00007ooooo`03o`000?oooooooooo00;o
oooo0_l000000ooooooo0000ooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`04
ob4Q8OmgMgOoMgMgoc8b<PKooooo0007ooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool06oooool2o`0000[ooooo00?o0000ooooooooool06?ooool2o`0000cooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Wooooo0_l00002ooooo`;o
00001Oooool00:cooooo00?o0000ooooooooool0@?ooool4o`0000;ooooo0_l0001aooooo`00U?oo
ool2o`0001Kooooo00?o0000ooooooooool0?Oooool2o`000003ooooool0003o000000Cooooo0_l0
001aooooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool0?Oooool4o`0000?ooooo0ol0001b
ooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool00_ooool2o`0000Wooooo0_l0000>oooo
o`;o00008?ooool2o`0000?ooooo0ol0001booooo`00S_ooool2o`0001cooooo00?o0000oooooooo
ool00_ooool2o`0000Wooooo0_l0000>ooooo`;o00008_ooool2o`0007Kooooo0026ooooo`;o0000
9?ooool3o`0000_ooooo0_l0000dooooo`;o0000M_ooool008Kooooo0_l0000Tooooo`03o`000?oo
oooooooo00_ooooo0_l0000fooooo`;o000000?oooooo`000?l00000LOooool008Oooooo0_l0000S
ooooo`03o`000?oooooooooo01oooooo0ol0000Qooooo`;o000000?oooooo`000?l00000LOooool0
08Oooooo0_l0000Sooooo`03o`000?oooooooooo01oooooo0ol0000Tooooo`;o0000LOooool00:co
oooo00?o0000ooooooooool0AOooool3o`00077ooooo002/ooooo`03o`000?oooooooooo01gooooo
0_l0000Vooooo`Co0000L?ooool008Oooooo0_l0000Sooooo`03o`000?oooooooooo01gooooo0_l0
000Xooooo`;o0000L?ooool008Oooooo0_l0000Sooooo`03o`000?oooooooooo043ooooo1?l0001e
ooooo`00Q_ooool2o`0002Cooooo00?o0000ooooooooool0?_ooool6o`0007Gooooo0026ooooo`;o
00009?ooool3o`0003kooooo0_l00002ooooo`;o00000oooool3o`0006oooooo002/ooooo`03o`00
0?oooooooooo04;ooooo0ol00002ooooo`?o0000Koooool009Gooooo0_l0000Eooooo`03o`000?oo
oooooooo043ooooo0_l000000ooooooo0000o`000002ooooo`;o0000L?ooool009Gooooo0_l0000E
ooooo`03o`000?oooooooooo043ooooo0_l000000ooooooo0000o`000002ooooo`;o0000L?ooool0
0:cooooo00?o0000ooooooooool02oooool2o`0000oooooo0_l0002Kooooo`00[?ooool01?l0003o
ooooooooooooool2o`0000Sooooo0_l0000?ooooo`;o0000Voooool009cooooo0_l0000>ooooo`04
o`000?ooooooooooooooo`;o00006?ooool4o`0009[ooooo0026ooooo`;o00005?ooool2o`0000ko
oooo00?o0000ooooooooool02oooool2o`0000kooooo1Ol0002Iooooo`00Q_ooool2o`0002Cooooo
1Ol00008ooooo`?o00004Oooool2o`0002Kooooo0_l0001aooooo`00[?ooool00ol0003ooooooooo
o`02o`0000Sooooo0_l0000jooooo`?o0000L?ooool0093ooooo0_l00004ooooo`;o00005?ooool0
0ol0003oooooooooo`0:ooooo`;o00003_ooool2o`0002_ooooo0_l0001`ooooo`00T?ooool2o`00
00Cooooo0_l0000Dooooo`03o`000?oooooooooo00[ooooo0_l0000>ooooo`;o00000oooool2o`00
01oooooo0_l00003ooooo`;o0000L_ooool00:cooooo00?o0000ooooooooool07oooool2o`0001oo
oooo0_l00003ooooo`?o0000LOooool008Kooooo0_l0000Tooooo`03o`000?oooooooooo04Kooooo
0_l0001aooooo`00Q_ooool2o`0002Cooooo00?o0000ooooooooool0@oooool2o`0000;ooooo0_l0
001`ooooo`00[?ooool00ol0003oooooooooo`11ooooo`Go000000?oooooo`000?l00000L?ooool0
0:cooooo0ol00011ooooo`;o000000?oooooo`000?l00000Loooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool02_ooool2o`0003;ooooo0_l000000ooooooo0000
o`00001fooooo`00[?ooool00ol0003oooooooooo`0:ooooo`;o00003_ooool3o`000003ooooool0
003o000001kooooo0_l000000ooooooo0000o`00001fooooo`00[?ooool00ol0003oooooooooo`0J
ooooo`Ko0000VOooool00:cooooo00?o0000ooooooooool06oooool4o`0009[ooooo0029ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool2o`0000;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00Oooooo0_l0000Booooo`?o00009oooool2
o`0007;ooooo0028ooooo`;o000000CoV9RHoooooonHV9SoMgMg0oooool2o`0000;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`07ooooo`;o00004oooool2o`0002Oooooo0_l0001booooo`00R?ooool2o`0000?ooooo00?o410@
ooooooooool02?ooool2o`000003oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3
o`0001kooooo0_l0000Sooooo`;o0000M?ooool008Wooooo00Go0000ooooooooooooooooo`000002
ooooo`;o00001_ooool2o`000004oooooonHV9So8B4Qonk^kPOooooo00?oMgMgoc8b<_ooool01?oo
ool2o`0000Wooooo0_l0000Dooooo`;o00008oooool2o`0007Cooooo0029ooooo`05o`000?oooooo
ooooooooool000000_ooool3o`0000Wooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool02?ooool2o`0000kooooo1?l0000Pooooo`;o0000
0oooool4o`0007Cooooo0029ooooo`05oa0@4?ooooooooooooooool@41000oooool2o`0000[ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Sooooo
1_l0000Nooooo`;o000000?oooooo`000?l000001?l0001dooooo`00ROooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Cooooo0_l00005ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo01cooooo0_l0000Qooooo`;o00001Oooool2o`00077o
oooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool2o`0000Gooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`10ooooo`;o00000_ooool4o`00
077ooooo002Booooo`;o00006?ooool00ol0003oooooooooo`10ooooo`;o00000_ooool3o`0007;o
oooo002Booooo`;o00006?ooool00ol0003oooooooooo`0Gooooo`;o0000:?ooool2o`0007Kooooo
002[ooooo`;o00006Oooool2o`0002Sooooo0ol000000ooooooo0000o`00001booooo`00Zoooool4
o`0004;ooooo1Ol0001booooo`00ROooool2o`00013ooooo0_l0000?ooooo`03o`000?oooooooooo
01cooooo0_l0000Qooooo`;o000000Coooooo`000?l0003o0000M?ooool008Wooooo0_l0000@oooo
o`;o00003oooool00ol0003oooooooooo`0Kooooo`?o00008Oooool2o`0007Sooooo002Booooo`;o
00006?ooool00ol0003oooooooooo`05ooooo`;o00005?ooool2o`0009cooooo0028ooooo`;o0000
2?ooool2o`0001Sooooo00?o0000ooooooooool01Oooool2o`0001;ooooo0_l0000Vooooo`;o0000
M_ooool008Sooooo1?l0000Pooooo`03o`000?oooooooooo01Wooooo0_l0000Vooooo`;o0000M_oo
ool008[ooooo0_l0000Mooooo`;o000000?oooooo`000?ooool0^_ooool00:Wooooo0_l000000ooo
oooo0000ooooo`11ooooo`;o0000Moooool00:cooooo0ol0000jooooo`;o00000_ooool4o`0007Oo
oooo002Nooooo`;o00003?ooool00ol0003oooooooooo`0jooooo`;o000000Coooooo`000?l0003o
0000NOooool009Cooooo0_l00008ooooo`?o00001?ooool3o`0000Cooooo00?o0000ooooooooool0
?Oooool3o`0007Wooooo002Dooooo`;o00002Oooool2o`0000Cooooo0ol00004ooooo`03o`000?oo
oooooooo03Wooooo0_l00003ooooo`Co0000Moooool009Cooooo1?l0000;ooooo`?o00001_ooool0
0ol0003oooooooooo`0iooooo`;o00000_ooool2o`000003ooooool0003o000007Oooooo002Doooo
o`Co00002oooool3o`0000Kooooo00?o0000ooooooooool0?Oooool2o`0007[ooooo002Sooooo`;o
00001oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00R_oo
ool2o`00023ooooo0ol0002iooooo`00R_ooool2o`00023ooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool05Oooool2o`0002Oooooo0_l0001iooooo`00[?ooool01?l0003o
ooooo`000?l0000Dooooo`;o00009oooool2o`0007Wooooo002/ooooo`04o`000?oooooo0000o`00
01Cooooo0ol0000Vooooo`;o0000NOooool00:cooooo0ol0000Cooooo`;o000000?oooooo`000?l0
00009_ooool2o`0007Wooooo002/ooooo`?o00004oooool2o`0002;ooooo0_l00020ooooo`00[?oo
ool00ol0003oooooooooo`02o`0003Gooooo0_l000000ooooooo0000o`000002o`0007_ooooo002/
ooooo`Go0000>?ooool4o`0007_ooooo002Jooooo`;o00004?ooool00ol0003oooooooooo`0joooo
o`;o0000OOooool009[ooooo0_l0000@ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002Jooooo`;o00004?ooool00ol0003oooooooooo`0eooooo`;o0000P_oo
ool009[ooooo0_l0000?ooooo`;o00003oooool2o`0002Kooooo0_l00004ooooo`?o0000Noooool0
097ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q0_l00003ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01?ooool2o`0000oooooo0ol0000Sooooo`;o00001_ooool3o`0007_ooooo002A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@;o00001_ooool00omgMgOo<S8boooo
o`02o`0000;ooooo00?o0000ooooooooool03_ooool4o`00027ooooo0_l000000ooooooo0000o`00
0004ooooo`;o0000Noooool0097ooooo00Go410@oooooooooooooooooa0@4009ooooo`;o00001Ooo
ool01?l0003oooooo`000?l00002ooooo`03o`000?oooooooooo013ooooo0_l0000Pooooo`?o0000
00?oooooo`000?l00000POooool008kooooo1?l00003ooooo`03o`000?oooooooooo00Oooooo0_l0
0004ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000=ooooo`;o00008oooool3o`0008Cooooo002>
ooooo`Co00000oooool00ol0003oooooooooo`0:ooooo`04o`000?lQ8B7o0000oc8b<P;o00000_oo
ool3o`0000oooooo0_l0002Zooooo`00Soooool2o`000005oa0@4?ooooooooooooooool@41001_oo
ool2o`0000Cooooo00Co0000oooooooooooooooo0_l00002ooooo`?o0000<oooool2o`0008Kooooo
0020ooooo`;o00003oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo0_l00004ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool03?ooool2o`0002?ooooo0_l00026ooooo`00P?oo
ool2o`0000oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003ooooo
ooooo`0<ooooo`;o00009?ooool2o`0008Gooooo002Oooooo`;o00000oooool2o`0000Kooooo00?o
0000ooooooooool0<_ooool2o`0008Gooooo0021ooooo`;o00003Oooool2o`0000gooooo0_l0000;
ooooo`03o`000?oooooooooo00_ooooo0_l0002/ooooo`00POooool2o`0000gooooo0_l0000@oooo
o`;o00002?ooool00ol0003oooooooooo`08ooooo`;o000000?oooooo`000?l00000[?ooool0087o
oooo0_l0000Oooooo`;o00002?ooool3o`0000Sooooo0_l0000[ooooo`;o0000P_ooool00:cooooo
00?o0000ooooooooool0=Oooool2o`0008;ooooo002/ooooo`03o`000?oooooooooo02oooooo0_l0
0028ooooo`00[?ooool00ol0003oooooooooo`0_ooooo`;o0000R?ooool00:cooooo00?o0000oooo
ooooool02?ooool2o`0002Kooooo0_l00027ooooo`00[?ooool00ol0003oooooooooo`08ooooo`;o
00009_ooool4o`0008Gooooo002/ooooo`03o`000?oooooooooo03;ooooo0ol00024ooooo`00[?oo
ool00ol0003oooooooooo`0cooooo`;o0000Q?ooool00:cooooo0ol0000[ooooo`;o0000S?ooool0
0:cooooo00?o0000ooooooooool01_ooool2o`0002?ooooo0_l0002<ooooo`00[?ooool00ol0003o
ooooooooo`06ooooo`;o00009?ooool2o`0008_ooooo002/ooooo`03o`000?oooooooooo00Kooooo
0_l0000Tooooo`;o000000?oooooo`000?l00000R?ooool009;ooooo0_l0000Hooooo`03o`000?oo
oooooooo00Kooooo0_l0000Vooooo`?o0000R?ooool009;ooooo0ol0000Gooooo`03o`000?oooooo
oooo02kooooo1?l00027ooooo`00Toooool2o`0001Oooooo00?o0000ooooooooool0<?ooool2o`00
08Oooooo002Eooooo`;o00005Oooool00ol0003oooooooooo`2iooooo`00UOooool2o`0001Gooooo
0ol00002ooooo`;o0000]Oooool00:cooooo00?o0000ooooooooool00_ooool2o`000;Gooooo002/
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o00001?ooool2o`000;?ooooo002/ooooo`Co
00000oooool2o`000;?ooooo0024ooooo`;o00004Oooool2o`0001?ooooo00Co0000ooooool0003o
0000^?ooool008Cooooo0_l0000Aooooo`;o00004oooool01?l0003oooooo`000?l0000Sooooo`;o
0000Toooool00:[ooooo1_l0000Sooooo`;o0000Toooool009Sooooo0_l0000@ooooo`Go0000^Ooo
ool009Sooooo0_l0000>ooooo`Oo0000^Oooool009[ooooo0ol0000;ooooo`Go0000^oooool009[o
oooo1Ol00008ooooo`;o00000oooool4o`0002Cooooo0_l0002Booooo`00WOooool2o`0000Sooooo
0_l00003ooooo`Co00009?ooool2o`0009;ooooo002Jooooo`;o00000_ooool2o`0000[ooooo0ol0
002kooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`;o000000Co
k^k^ooooool0003o00000_ooool01Om4A4Co0000o`000?lb<S;ogMgM00?ooooo0ol0002kooooo`00
Q_ooool2o`000006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Kooooo00CoEEEEojVY
ZOl0003o00001_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02;ooooo0_l0002E
ooooo`00Q_ooool2o`000003ooooool@413ooooo00;ooooo00?o410@ooooooooool02oooool01?nY
ZJWoEEEEo`000?l00007ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08?ooool4
o`0009Gooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7o0000o`000002
o`0000Cooooo00?oMgMgoc8b<_ooool01?ooool3o`00023ooooo0_l0002Gooooo`00ROooool01Ol0
003ooooooooooooooooo000000kooooo00?oEEEEo`000?l000000_l000001_oooooo0000ob4Q8Ol0
003o<S8bolc<c0Gooooo00?o0000ooooooooool0^Oooool008Wooooo00Go410@oooooooooooooooo
oa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`2iooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Ko410@oooooooooooo
oooooc8b<_ooool2o`000003ooooool0003ooooo00Sooooo00?o0000ooooooooool07Oooool2o`00
09[ooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`000004ooooool0003o0000
ooooo`Co00001_ooool00ol0003oooooooooo`0Kooooo`Co0000V_ooool00:cooooo00?o0000oooo
ooooool06oooool2o`0009cooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool07?ooool2
o`0009_ooooo0029ooooo`;o00008Oooool00ol0003oooooooooo`0Looooo`;o0000Voooool008Wo
oooo0_l0000Qooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool05?ooool2o`000:?ooooo002/ooooo`03o`000?oooooo
oooo01Cooooo0_l0002Sooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00S_ooool2o`0001cooooo00?o
0000ooooooooool0^Oooool008kooooo0_l0000Looooo`03o`000?oooooooooo00kooooo0_l0002Y
ooooo`00[?ooool3o`0000kooooo0_l0002Yooooo`00[?ooool00ol0003oooooooooo`0@ooooo`;o
0000Yoooool00:cooooo00?o0000ooooooooool02oooool2o`0000?ooooo0_l0002Wooooo`00[?oo
ool00ol0003oooooooooo`0;ooooo`;o0000[?ooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o0000/ooo
ool00:;ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo0_l0002c
ooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`03
o`000?oooooooooo00Gooooo0ol0002iooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?oo
ool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0
003oooooooooo`31ooooo`00X_ooool00omEEEGoIVIVo`000033ooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00Z_ooool01?l@413o0000o`000?l0002joooo
o`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zooo
ool01_l0003oMgMgo`000?l0003oEEEEonk^k[Oooooo002[ooooo`06o`000?mEEEGok^k^oooooomg
MgOoEEEE]oooool00:_ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`2eooooo`00
Zoooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo0;Gooooo002[ooooo`06o`000?mE
EEGok^k^oooooomgMgOoIVIV]oooool00:[ooooo00?o410@o`000?mgMgL00_l000000omVIVKok^k^
ooooo`2fooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.47005 .89723 Mdot
.42689 .85007 Mdot
.47293 .63581 Mdot
.55135 .50999 Mdot
.43335 .24338 Mdot
.56284 .769 Mdot
.51203 .42534 Mdot
.70776 .35105 Mdot
.69761 .38464 Mdot
.51333 .7265 Mdot
.45894 .77593 Mdot
.72664 .44458 Mdot
.38357 .62229 Mdot
.51531 .73189 Mdot
.72207 .54948 Mdot
.55045 .58361 Mdot
.60998 .55055 Mdot
.38263 .61083 Mdot
.40964 .58273 Mdot
.46458 .05194 Mdot
.38984 .31478 Mdot
.38419 .57701 Mdot
.39577 .28998 Mdot
.3794 .48755 Mdot
.7251 .581 Mdot
.52174 .21892 Mdot
.41746 .62549 Mdot
.40814 .47558 Mdot
.50472 .06858 Mdot
.39816 .72162 Mdot
.44436 .10108 Mdot
.68935 .34526 Mdot
.71132 .39251 Mdot
.59191 .65413 Mdot
.60419 .64122 Mdot
.53421 .11977 Mdot
.63182 .2407 Mdot
.40917 .50531 Mdot
.58107 .17277 Mdot
.72697 .41935 Mdot
.7355 .52048 Mdot
.60219 .63562 Mdot
.57607 .72906 Mdot
.5101 .87468 Mdot
.52863 .84263 Mdot
.46807 .17543 Mdot
.46974 .77844 Mdot
.66138 .27696 Mdot
.57822 .32981 Mdot
.54923 .12931 Mdot
.6664 .29203 Mdot
.57242 .15072 Mdot
.56047 .97058 Mdot
.57619 .72076 Mdot
.60201 .66313 Mdot
.70566 .39754 Mdot
.71391 .37622 Mdot
.6135 .51468 Mdot
.64677 .25712 Mdot
.53645 .82952 Mdot
.49476 .18619 Mdot
.72562 .65642 Mdot
.60047 .20591 Mdot
.48331 .26403 Mdot
.71633 .47507 Mdot
.69454 .35375 Mdot
.50542 .74086 Mdot
.53941 .62441 Mdot
.41435 .62219 Mdot
.38681 .33376 Mdot
.61687 .45852 Mdot
.52251 .49621 Mdot
.48713 .77056 Mdot
.52586 .68985 Mdot
.60078 .20655 Mdot
.4426 .52188 Mdot
.5595 .97157 Mdot
.55431 .30294 Mdot
.55607 .12934 Mdot
.59734 .44606 Mdot
.48751 .07484 Mdot
.39323 .67918 Mdot
.54937 .51478 Mdot
.60637 .62475 Mdot
.69993 .33982 Mdot
.55954 .52169 Mdot
.43588 .2344 Mdot
.49837 .20098 Mdot
.61222 .46289 Mdot
.53505 .64069 Mdot
.72108 .59972 Mdot
.63751 .85965 Mdot
.50555 .29423 Mdot
.46583 .18016 Mdot
.50624 .29973 Mdot
.66731 .8156 Mdot
.51575 .72994 Mdot
.68321 .34616 Mdot
.55766 .97515 Mdot
.6098 .42277 Mdot
.4459 .8772 Mdot
.60426 .40769 Mdot
.72674 .47739 Mdot
.48433 .90226 Mdot
.42172 .14179 Mdot
.59059 .66169 Mdot
.61829 .50737 Mdot
.40718 .54688 Mdot
.50518 .29293 Mdot
.39648 .25708 Mdot
.52192 .71311 Mdot
.5507 .46152 Mdot
.69044 .35214 Mdot
.47318 .05595 Mdot
.46981 .70968 Mdot
.52215 .23204 Mdot
.68457 .30822 Mdot
.68382 .31395 Mdot
.65162 .29173 Mdot
.38097 .56602 Mdot
.73636 .60899 Mdot
.41883 .16835 Mdot
.49416 .05563 Mdot
.39136 .29249 Mdot
.54913 .55218 Mdot
.50117 .0713 Mdot
.67959 .79043 Mdot
.39239 .65479 Mdot
.42724 .49174 Mdot
.38326 .44139 Mdot
.42089 .81907 Mdot
.73031 .48214 Mdot
.57898 .7419 Mdot
.57022 .74601 Mdot
.52009 .08295 Mdot
.58764 .16207 Mdot
.5112 .07975 Mdot
.48431 .77187 Mdot
.71903 .43796 Mdot
.72509 .5351 Mdot
.68555 .75631 Mdot
.53423 .37248 Mdot
.41521 .63792 Mdot
.61099 .54362 Mdot
.46264 .05555 Mdot
.69421 .32768 Mdot
.41245 .98726 Mdot
.43916 .24475 Mdot
.50029 .202 Mdot
.74844 .541 Mdot
.59913 .38381 Mdot
.43992 .75026 Mdot
.37937 .53466 Mdot
.52133 .47169 Mdot
.50255 .86524 Mdot
.59911 .18592 Mdot
.58928 .18305 Mdot
.69254 .33586 Mdot
.64058 .26057 Mdot
.59619 .17976 Mdot
.54848 .26518 Mdot
.54085 .10769 Mdot
.73681 .43594 Mdot
.52855 .11701 Mdot
.54639 .78182 Mdot
.42322 .82101 Mdot
.69487 .33306 Mdot
.422 .13798 Mdot
.41479 .62369 Mdot
.56981 .13838 Mdot
.56008 .15021 Mdot
.53939 .4188 Mdot
.41244 .58433 Mdot
.4668 .18693 Mdot
.42923 .27393 Mdot
.71634 .43471 Mdot
.66876 .81132 Mdot
.49989 .86781 Mdot
.44277 .64686 Mdot
.5386 .11162 Mdot
.55164 .11597 Mdot
.73205 .45024 Mdot
.54745 .61712 Mdot
.7362 .52496 Mdot
.43311 .38438 Mdot
.69961 .40526 Mdot
.66943 .80476 Mdot
.67538 .29947 Mdot
.7359 .43972 Mdot
.58236 .71976 Mdot
.73759 .59022 Mdot
.45678 .05917 Mdot
.47721 .26609 Mdot
.7171 .67195 Mdot
.70517 .35156 Mdot
.74201 .51236 Mdot
.72836 .47611 Mdot
.46696 .18152 Mdot
.64802 .85406 Mdot
.62164 .51351 Mdot
.45625 .6828 Mdot
.45423 .67921 Mdot
.52278 .51331 Mdot
.45661 .19739 Mdot
.63452 .87437 Mdot
.41762 .8043 Mdot
.46459 .27861 Mdot
.54709 .79794 Mdot
.54457 .40649 Mdot
.4268 .42939 Mdot
.47091 .78686 Mdot
.3944 .72135 Mdot
.54733 .28608 Mdot
.42529 .12888 Mdot
.53771 .6453 Mdot
.41654 .79743 Mdot
.54681 .28828 Mdot
.73789 .44877 Mdot
.42518 .4816 Mdot
.49946 .87598 Mdot
.722 .395 Mdot
.51435 .21789 Mdot
.66758 .31044 Mdot
.40893 .1843 Mdot
.51338 .10168 Mdot
.5267 .67177 Mdot
.42458 .28386 Mdot
.46552 .90971 Mdot
.53113 .37551 Mdot
.72271 .54742 Mdot
.74168 .59503 Mdot
.55455 .54003 Mdot
.4702 .3369 Mdot
.60365 .91075 Mdot
.6024 .43128 Mdot
.43442 .72431 Mdot
.73337 .61271 Mdot
.41095 .5651 Mdot
.47916 .9055 Mdot
.39082 .31608 Mdot
.42999 .8458 Mdot
.72066 .6689 Mdot
.58452 .72288 Mdot
.42577 .12279 Mdot
.61678 .45858 Mdot
.68164 .31547 Mdot
.51441 .32552 Mdot
.62178 .2313 Mdot
.60617 .53998 Mdot
.61616 .45313 Mdot
.59184 .18951 Mdot
.74016 .52013 Mdot
.46831 .70807 Mdot
.49589 .28786 Mdot
.63612 .25889 Mdot
.54943 .27721 Mdot
.41227 .57771 Mdot
.61468 .63179 Mdot
.44191 .50369 Mdot
.71593 .39685 Mdot
.65329 .26414 Mdot
.59156 .37394 Mdot
.43576 .72908 Mdot
.5155 .10258 Mdot
.43247 .59267 Mdot
.60301 .4115 Mdot
.46235 .89037 Mdot
.44865 .75295 Mdot
.5285 .81875 Mdot
.55205 .14244 Mdot
.57343 .33862 Mdot
.50988 .08493 Mdot
.60502 .6582 Mdot
.52766 .69443 Mdot
.59556 .40976 Mdot
.58927 .16985 Mdot
.55137 .60431 Mdot
.40536 .47752 Mdot
.67302 .3074 Mdot
.49263 .77747 Mdot
.52666 .83145 Mdot
.53975 .11076 Mdot
.43735 .64112 Mdot
.51597 .70871 Mdot
.64535 .2724 Mdot
.72509 .45588 Mdot
.40739 .55768 Mdot
.51798 .45016 Mdot
.47578 .19359 Mdot
.43705 .09015 Mdot
.49531 .19187 Mdot
.48543 .07582 Mdot
.66347 .81324 Mdot
.65469 .27967 Mdot
.7236 .51793 Mdot
.66763 .3165 Mdot
.48445 .33357 Mdot
.62591 .21803 Mdot
.70768 .68782 Mdot
.4183 .13797 Mdot
.72228 .54156 Mdot
.39594 .94041 Mdot
.58699 .36985 Mdot
.60946 .65766 Mdot
.42944 .84678 Mdot
.68538 .32863 Mdot
.73122 .54425 Mdot
.47331 .78145 Mdot
.6773 .32259 Mdot
.55094 .2785 Mdot
.47244 .69708 Mdot
.38609 .63814 Mdot
.6111 .55101 Mdot
.38035 .51499 Mdot
.74704 .53877 Mdot
.45195 .68371 Mdot
.48453 .89009 Mdot
.59481 .65209 Mdot
.71791 .48454 Mdot
.44011 .64681 Mdot
.73297 .46487 Mdot
.71811 .64345 Mdot
.70328 .73148 Mdot
.54969 .56484 Mdot
.58973 .72169 Mdot
.61122 .60893 Mdot
.60999 .21958 Mdot
.41204 .3589 Mdot
.48765 .69496 Mdot
.50151 .3748 Mdot
.61705 .50765 Mdot
.71688 .37762 Mdot
.64345 .27866 Mdot
.49747 .27848 Mdot
.39046 .68071 Mdot
.42691 .51662 Mdot
.52234 .52355 Mdot
.45851 .90533 Mdot
.5734 .74858 Mdot
.54727 .78057 Mdot
.55129 .27178 Mdot
.45727 .19806 Mdot
.59269 .93439 Mdot
.56541 .31826 Mdot
.38894 .62282 Mdot
.49723 .28429 Mdot
.71026 .4056 Mdot
.41827 .62978 Mdot
.51305 .08331 Mdot
.38395 .4917 Mdot
.51671 .31814 Mdot
.54044 .2789 Mdot
.69041 .74731 Mdot
.72492 .42559 Mdot
.61177 .19181 Mdot
.53154 .11449 Mdot
.5756 .33103 Mdot
.6177 .54485 Mdot
.54716 .1319 Mdot
.60239 .41783 Mdot
.72518 .43035 Mdot
.71843 .70434 Mdot
.42825 .11586 Mdot
.7297 .4873 Mdot
.73366 .47173 Mdot
.73916 .4863 Mdot
.52034 .55974 Mdot
.59918 .4166 Mdot
.72379 .54557 Mdot
.71435 .38358 Mdot
.51973 .56751 Mdot
.4592 .08001 Mdot
.57924 .36852 Mdot
.56178 .77494 Mdot
.45133 .88415 Mdot
.68765 .35855 Mdot
.47534 .90536 Mdot
.63428 .24073 Mdot
.635 .26551 Mdot
.39586 .29134 Mdot
.59776 .17069 Mdot
.38478 .41207 Mdot
.72633 .56298 Mdot
.66076 .31242 Mdot
.51974 .8441 Mdot
.52069 .50779 Mdot
.7261 .60647 Mdot
.60979 .43474 Mdot
.49922 .36694 Mdot
.73246 .43956 Mdot
.38819 .31928 Mdot
.49706 .67807 Mdot
.51798 .71061 Mdot
.52559 .23128 Mdot
.42693 .69361 Mdot
.66172 .27462 Mdot
.38853 .2984 Mdot
.71136 .68363 Mdot
.73278 .45293 Mdot
.60803 .58702 Mdot
.57545 .94974 Mdot
.6128 .57023 Mdot
.42217 .30689 Mdot
.41547 .3429 Mdot
.44586 .40674 Mdot
.71761 .38749 Mdot
.72625 .44536 Mdot
.41921 .64009 Mdot
.52965 .36329 Mdot
.48572 .79037 Mdot
.55763 .55587 Mdot
.74351 .53782 Mdot
.44561 .20479 Mdot
.50967 .09169 Mdot
.5448 .42843 Mdot
.43163 .72229 Mdot
.43186 .59195 Mdot
.44415 .21081 Mdot
.59367 .6454 Mdot
.44732 .76534 Mdot
.46865 .27446 Mdot
.74315 .57683 Mdot
.7182 .43018 Mdot
.49528 .58511 Mdot
.60364 .64631 Mdot
.61816 .50989 Mdot
.46219 .88119 Mdot
.58333 .38188 Mdot
.41545 .62528 Mdot
.73147 .5884 Mdot
.67643 .80704 Mdot
.45105 .89089 Mdot
.51382 .8718 Mdot
.46195 .27664 Mdot
.70495 .43011 Mdot
.72279 .55673 Mdot
.44065 .73933 Mdot
.386 .41956 Mdot
.58273 .94572 Mdot
.53466 .38249 Mdot
.50179 .66146 Mdot
.44324 .22962 Mdot
.50038 .08317 Mdot
.59182 .40926 Mdot
.64322 .85671 Mdot
.43229 .38503 Mdot
.57817 .71126 Mdot
.61077 .60359 Mdot
.48538 .26218 Mdot
.44234 .64887 Mdot
.54414 .63608 Mdot
.70936 .35765 Mdot
.45585 .69584 Mdot
.53952 .1077 Mdot
.4416 .8811 Mdot
.50485 .87304 Mdot
.50209 .07379 Mdot
.47995 .07585 Mdot
.61144 .5602 Mdot
.70099 .7559 Mdot
.51778 .7123 Mdot
.71751 .3783 Mdot
.74128 .5075 Mdot
.43951 .72852 Mdot
.61977 .20615 Mdot
.57938 .3624 Mdot
.60436 .57385 Mdot
.50634 .07517 Mdot
.45482 .88958 Mdot
.40712 .51474 Mdot
.5383 .27327 Mdot
.59879 .63278 Mdot
.74006 .614 Mdot
.5507 .77943 Mdot
.44686 .57722 Mdot
.56454 .74853 Mdot
.59643 .43018 Mdot
.52369 .52425 Mdot
.54144 .60961 Mdot
.58178 .70785 Mdot
.58607 .71347 Mdot
.46367 .69996 Mdot
.55097 .28445 Mdot
.69557 .35695 Mdot
.42089 .29407 Mdot
.46581 .89071 Mdot
.4333 .73732 Mdot
.41837 .34482 Mdot
.51538 .6 Mdot
.50942 .6263 Mdot
.4421 .88423 Mdot
.67882 .34933 Mdot
.52257 .10793 Mdot
.41244 .60386 Mdot
.52243 .09249 Mdot
.73014 .44814 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:3ooooo0_l0000:ooooo`?o0000^Oooool009oooooo0ol000000ooooooo0000o`00
0005ooooo`?o0000^oooool009gooooo1?l00002ooooo`;o00001Oooool3o`000;_ooooo002Moooo
o`;o00003Oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`?o0000^Oooool0
0:Gooooo1?l00003ooooo`Co0000^?ooool009kooooo0_l00005ooooo`Co00000oooool00ol0003o
ooooo`000002o`000;Oooooo002Nooooo`;o00003?ooool2o`000003ooooool0003o000000?o0000
]?ooool00:cooooo0_l000000ooooooo0000o`000003o`000;Cooooo002/ooooo`03o`000?oooooo
oooo00;o0000]oooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo00;o00000_ooool2o`00
0;?ooooo002Gooooo`;o00004oooool00ol0003oooooooooo`02o`0000;ooooo0_l0002cooooo`00
[?ooool00ol0003oooooooooo`2iooooo`00VOooool2o`00017ooooo0ol0002iooooo`00VOooool2
o`00017ooooo00Co0000oooooooooooooooo0ol0002eooooo`00[?ooool01?l0003ooooooooooooo
ool3o`0000Kooooo0_l0002]ooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o00001?ooool2
o`000:gooooo002/ooooo`03o`000?oooooooooo00Cooooo0_l00003ooooo`?o0000[Oooool009Co
oooo0_l0000Fooooo`03o`000?oooooooooo00Oooooo1Ol00002ooooo`;o0000ZOooool008Wooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03ob4Q8Ol0003o000000Gooooo00?o0000onk^k_oo
ool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool01_ooool4o`00
00Cooooo0_l0002Yooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l00006oooo
o`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`06oooo
o`Co0000[oooool0087ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41001Oooool2o`00
00Kooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000^Oooool008Wo
oooo00Go0000ooooooooooooooooo`000005ooooo`;o00001oooool00olQ8B7oooooooooo`06oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0^Oooool008Wooooo00Go0000oooooooo
ooooooooo`000005ooooo`;o00001oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01Oooool00ol0003oooooooooo`0<ooooo`Go0000Z?ooool008Wooooo00Go410@oooo
oooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0<ooooo`Go0000Z?ooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`?o00001Oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`2iooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo0ol0
0005ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool05?ooool2o`000:?ooooo002B
ooooo`;o00006?ooool00ol0003oooooooooo`0>ooooo`;o00001?ooool2o`000:?ooooo002Boooo
o`;o00006?ooool00ol0003oooooooooo`0>ooooo`;o0000ZOooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo0ol0000@ooooo`;o00000_ooool2o`000:?ooooo002/ooooo`03o`000?oo
oooooooo013ooooo0_l00002ooooo`;o0000Xoooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool06Oooool2o`0009kooooo002/ooooo`03o`000?oooooooooo01Wo
oooo0_l0002Nooooo`00[?ooool00ol0003oooooooooo`2iooooo`00TOooool2o`0001Wooooo00?o
0000ooooooooool06_ooool2o`000003ooooool0003o000009[ooooo002Aooooo`;o00006Oooool0
0ol0003oooooooooo`0Gooooo`;o000000Coooooo`000?l0003ooooo0_l0002Jooooo`00XOooool2
o`0000Wooooo0ol0000Gooooo`;o0000X?ooool00:3ooooo0ol00009ooooo`03o`000?oooooooooo
01cooooo0_l0002Kooooo`00X?ooool3o`0000Wooooo00?o0000ooooooooool06_ooool4o`0009_o
oooo002=ooooo`;o00004_ooool2o`0000Oooooo0ol0000Looooo`;o000000?oooooo`000?l00000
V_ooool008gooooo0_l0000Booooo`;o00001oooool3o`0001gooooo1?l0002Jooooo`00XOooool2
o`0000Oooooo0ol0000Mooooo`;o00001?ooool2o`0009Kooooo002Tooooo`;o00001?ooool3o`00
02?ooooo0_l0002Fooooo`00WOooool2o`0000Gooooo0_l00006ooooo`03o`000?oooooooooo0;Wo
oooo002Mooooo`;o00003?ooool4o`000;Wooooo002[ooooo`?o0000^_ooool009[ooooo0_l0000@
ooooo`;o00007oooool2o`0000Cooooo0_l0002Cooooo`00V_ooool2o`00013ooooo00?o0000oooo
ooooool07_ooool2o`0000Cooooo0_l0002Cooooo`00VOooool2o`00017ooooo00?o0000oooooooo
ool0^Oooool009Wooooo0_l0000Aooooo`03o`000?oooooooooo0;Wooooo002/ooooo`04o`000?oo
ooooooooooooo`;o000000?oooooo`000?l000006oooool2o`0000?ooooo0_l0002Aooooo`00[?oo
ool01?l0003oooooooooooooool2o`000003ooooool0003o000001_ooooo0_l00003ooooo`;o0000
TOooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00VOooool2o`00
017ooooo00?o0000ooooooooool01Oooool2o`0001kooooo0_l0002Booooo`00U_ooool2o`000003
ooooool0003o0000017ooooo00?o0000ooooooooool01?ooool3o`0001kooooo0_l0002Booooo`00
U_ooool2o`0001Cooooo00?o0000ooooooooool01?ooool2o`000;?ooooo002/ooooo`03o`000?oo
oooooooo02Sooooo0ol0002>ooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;o00000ooo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo02Sooooo
0ol0002>ooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o00000_ooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2iooooo`00ROooool6o`0000;ooooo00Ko
410@oooooooooooooooooa0@4?ooool2o`0000gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`2iooooo`00TOooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_oo
ool01?ooool3o`000;Wooooo002Aooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0^Oooool008Wooooo0_l00006ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
02Wooooo0_l00002ooooo`;o0000R_ooool008Wooooo0_l00006ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00ol0003oooooooooo`02ooooo`;o00000oooool00ol0003oooooooooo`0Yoooo
o`Ko0000R_ooool0097ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Oo00000oooool00ol0
003oooooooooo`0=ooooo`;o00007?ooool2o`0000;ooooo0_l00028ooooo`00Y?ooool4o`0000Co
oooo00?o0000ooooooooool03Oooool2o`0001[ooooo0_l00004ooooo`;o0000R?ooool00:Cooooo
0_l00006ooooo`03o`000?oooooooooo02Wooooo0_l0002>ooooo`00U?ooool2o`0001Kooooo00?o
0000ooooooooool02Oooool2o`0000;ooooo0_l0000Nooooo`;o0000R_ooool009Cooooo0_l00009
ooooo`Co00002Oooool3o`0000Wooooo0_l00002ooooo`;o00007_ooool2o`0000?ooooo0_l00025
ooooo`00Woooool4o`0000Sooooo0_l0000<ooooo`;o000000?oooooo`000?l000007Oooool2o`00
00;ooooo1?l00025ooooo`00X?ooool2o`0000Wooooo0_l0000<ooooo`;o000000?oooooo`000?l0
00007Oooool2o`0000;ooooo0_l00027ooooo`00Toooool2o`0001Kooooo0_l0000>ooooo`?o0000
Z_ooool009?ooooo0_l0000Eooooo`?o00003_ooool3o`000:[ooooo0028ooooo`?o00007oooool3
o`0000kooooo0_l0000Qooooo`;o00000_ooool2o`0008Cooooo0028ooooo`?o00001_ooool2o`00
01Wooooo0ol0000_ooooo`;o00000_ooool2o`0008Cooooo0027ooooo`;o00002?ooool2o`0001Wo
oooo0ol0002iooooo`00Qoooool2o`0002?ooooo1?l0000eooooo`;o0000POooool00:cooooo00Co
0000ooooool0003o00003Oooool2o`0002Kooooo0_l00021ooooo`00T_ooool2o`0001Sooooo00?o
0000ooooooooool03_ooool2o`0002Kooooo0_l00021ooooo`00T_ooool2o`0001Sooooo00?o0000
ooooooooool0=?ooool4o`000003ooooool0003o000007kooooo002/ooooo`03o`000?oooooooooo
03;ooooo1?l00003ooooo`;o0000O_ooool008Oooooo0ol0000Rooooo`03o`000?oooooooooo03;o
oooo1?l00003ooooo`;o0000O_ooool008Oooooo0ol0000Rooooo`03o`000?oooooooooo00;ooooo
0_l0000>ooooo`;o00008?ooool2o`0000?ooooo0_l0001nooooo`00Qoooool2o`0002?ooooo00?o
0000ooooooooool00_ooool2o`0000kooooo0_l0000Sooooo`;o0000P?ooool00:cooooo0ol00000
0ooooooo0000o`00000dooooo`;o0000P?ooool00:cooooo00Co0000oooooooooooooooo0_l0000g
ooooo`;o000000?oooooo`000?l00000N_ooool00:cooooo00?o0000ooooooooool05_ooool2o`00
02;ooooo0_l000000ooooooo0000o`00001jooooo`00Q_ooool2o`0001kooooo0_l00004ooooo`03
o`000?oooooooooo01Kooooo0_l0000Uooooo`;o0000N_ooool008Kooooo0_l0000Jooooo`;o0000
0_ooool2o`0000Cooooo00?o0000ooooooooool0??ooool3o`0007[ooooo002Rooooo`;o00002?oo
ool00ol0003oooooooooo`0Eooooo`;o00009Oooool2o`000003ooooool0003o000007Sooooo002@
ooooo`;o00006_ooool00ol0003oooooooooo`0Eooooo`;o0000:?ooool2o`0007Sooooo002@oooo
o`?o00006Oooool00ol0003oooooooooo`0iooooo`Co0000O?ooool0097ooooo0_l0000Iooooo`03
o`000?oooooooooo03Sooooo1Ol0001looooo`00[?ooool3o`0003Sooooo0_l000000ooooooo0000
o`000003ooooo`?o0000M_ooool00:cooooo00?o0000ooooooooool0>oooool4o`000004ooooool0
003o0000o`0007Kooooo002?ooooo`;o00006oooool00ol0003oooooooooo`0kooooo`Co00000ooo
ool2o`0007Gooooo002?ooooo`;o00006oooool00ol0003oooooooooo`0kooooo`Co00000oooool2
o`0007Gooooo002/ooooo`03o`000?oooooooooo00Kooooo0_l0000?ooooo`;o0000X?ooool008Wo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@04ooooo`;o00002?ooool2o`0000oooooo0_l0002Pooooo`00ROooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01ooo
ool00omgMgOo<S8booooo`03ooooo`;o00006Oooool4o`0009kooooo0021ooooo`Ko00000_ooool0
1Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Sooooo0_l0000=ooooo`Ko0000W?ooool008Wooooo00Go0000
ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?oo
ool3o`0000Oooooo0ol0000Aooooo`;o00009_ooool2o`0007Cooooo0029ooooo`05o`000?oooooo
ooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool2o`0000Sooooo0_l0000jooooo`?o0000Loooool008Wooooo00Go410@oooooooooooooooo
oa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`08ooooo`;o00003_ooool2o`0002[ooooo0_l0001cooooo`00ROooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Oooooo0_l00002ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Sooooo0_l0000>ooooo`;o00000oooool2o`0001oo
oooo0_l00003ooooo`;o0000M?ooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`;o
00000_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo
01gooooo0_l0000Oooooo`;o00000oooool3o`0007?ooooo002/ooooo`03o`000?oooooooooo04Co
oooo0_l0001cooooo`00[?ooool00ol0003oooooooooo`12ooooo`;o00000_ooool2o`00077ooooo
002/ooooo`03o`000?oooooooooo043ooooo2?l0001aooooo`00[?ooool3o`00043ooooo0_l00002
ooooo`;o0000Loooool00:cooooo00?o0000ooooooooool0^Oooool009[ooooo0_l0000@ooooo`03
o`000?oooooooooo00_ooooo0_l0000aooooo`;o00000_ooool2o`0007Gooooo002Jooooo`;o0000
4?ooool00ol0003oooooooooo`0;ooooo`;o00003_ooool3o`000003ooooool0003o000001gooooo
0_l00002ooooo`;o0000MOooool008Kooooo0_l0000Tooooo`03o`000?oooooooooo01_ooooo0ol0
00000ooooooo0000o`00002Hooooo`00Q_ooool2o`0002Cooooo00?o0000ooooooooool07Oooool4
o`0009Sooooo0026ooooo`;o00009?ooool00ol0003oooooooooo`0:ooooo`;o00004Oooool3o`00
02Oooooo0_l0001`ooooo`00Q_ooool2o`0002Cooooo00?o0000ooooooooool02_ooool2o`0001;o
oooo0_l0000Wooooo`;o0000L?ooool00:cooooo0ol000000ooooooo0000o`00000Nooooo`;o0000
9?ooool2o`00073ooooo002/ooooo`04o`000?ooooooooooooooo`;o00002?ooool2o`0001Cooooo
0_l0000Tooooo`;o0000L?ooool009?ooooo0_l0000Gooooo`03o`000?oooooooooo00_ooooo0_l0
000?ooooo`Co00008?ooool2o`0000?ooooo1?l0001`ooooo`00Toooool2o`0001Oooooo00?o0000
ooooooooool07?ooool4o`000003ooooool0003o000001gooooo0_l00002ooooo`Go0000L?ooool0
0:cooooo00?o0000ooooooooool08Oooool2o`00027ooooo0_l00005ooooo`;o0000K?ooool00:co
oooo00?o0000ooooooooool0AOooool2o`0000;ooooo1?l0001/ooooo`00QOooool2o`0002Gooooo
00?o0000ooooooooool0AOooool2o`0000;ooooo0ol0001]ooooo`00QOooool2o`0002Gooooo00?o
0000ooooooooool07Oooool2o`0002Sooooo0_l0001`ooooo`00[?ooool00ol0003oooooooooo`0M
ooooo`;o0000:?ooool6o`0006cooooo002/ooooo`?o00000_ooool2o`0004Gooooo1?l0001/oooo
o`00[?ooool00ol0003oooooooooo`02ooooo`;o00007oooool2o`0002;ooooo1?l0001^ooooo`00
[?ooool00ol0003oooooooooo`0Sooooo`;o00008_ooool2o`00073ooooo0009ooooo`Co000000?o
410@ooooooooool05_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`00
0?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
5_ooool00ol0003oooooooooo`0=ooooo`;o00002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo00?o8B4Qo`000?l000000oooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0?oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool0
1?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1?l000000ol@413oooooooooo`0Booooo`00
2oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Ko
oooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8boooo
o`0Eooooo`03o`000?oooooooooo00gooooo0_l00009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2o`0000Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00ko
oooo00CoMgMgoiRHV?ooooooV9RH0_l00004ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool0
0omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo0006o`0000Gooooo00?o0000oooo
ooooool04?ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGo
oooo00Sooooo00?o0000ooooooooool01Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
6?ooool01Ol@413ooooooooooooooooo410@00Gooooo0_l00005ooooo`03oiRHV?lQ8B7ok^k^00Wo
oooo00?o0000ooooooooool03Oooool01?l@413oooooooooooooool2o`0000oooooo00?o0000oooo
ooooool03Oooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo
01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMg
oc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool03_oo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8b
ooooo`0Eooooo`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000=ooooo`03
oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Q
ooooooooool01_ooool00omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo000;oooo
o`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<co
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Fooooo`03o`000?oooooo
oooo00Cooooo0_l0000Booooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01?l0003oooooooooooooool3o`0000[o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003_ooool0
0omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06_ooool00ol0003ooooooooo
o`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05oa0@4?ooooooooooooooool@41003_oo
ool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400?ooooo`?o
00000_ooool00ol0003oooooooooo`0Hooooo`?o00001?ooool2o`0001;ooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool2o`00
00;ooooo1?l0000:ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400>
ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0D
ooooo`002oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Co0000okZj^_ooooooV9RH0ol00002ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@
4004ooooo`03o`000?oooooooooo013ooooo0_l000001?nHV9So0000o`000?l0000<ooooo`03o`00
0?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooo
oolb<S801?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Cooooo0009ooooo`03
oeEEEOmVIVKo000001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`00
013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo00CoV9RHoa0@4?l0003o8B4Q0_l00003ooooo`Co00005oooool00ol0003ooooo
ooooo`0Hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
00Cooooo1?l0000@ooooo`03onk^k_lb<S;o000000?o00002oooool4o`00013ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0001Wooooo00?oEEEEofIVI_l000005_ooool0
09?ooooo0_l0000Gooooo`03o`000?oooooooooo04Cooooo0_l00003ooooo`;o000000?oooooo`00
0?l00000Joooool008Cooooo0_l0000Vooooo`03o`000?oooooooooo04Cooooo0_l00002ooooo`;o
00000_ooool2o`0006_ooooo0024ooooo`?o00003Oooool2o`0001Kooooo00?o0000ooooooooool0
B?ooool2o`0006Cooooo0_l00002ooooo`;o00001Oooool008Gooooo0_l0000=ooooo`;o00005_oo
ool00ol0003oooooooooo`2^ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1Oooool00:cooooo
00?o0000ooooooooool01?ooool2o`000:Wooooo00CogMgMo`000?l@413oc<c<1_ooool000Oooooo
ool0001<o`0000cooooo00Cok^k^ob4Q8Ol@413ok^k^1_ooool000Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooooooo`;o00000_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00Co8B4QogMgMomgMgOo<S8b1_ooool000Oo
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool02?ooool2o`0000Sooooo0_l0000Booooo`03o`000?oooooooooo02Co
oooo0_l000000ooooooo0000ooooo`0Sooooo`;o00000_ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool02Oooool2o`0000;ooooo0_l00005ooooo`00
S_ooool2o`0001cooooo00?o0000ooooooooool00oooool2o`0000Wooooo0_l0000Cooooo`?o0000
9_ooool2o`0006_ooooo002/ooooo`03o`000?oooooooooo00?ooooo0ol00008ooooo`;o00004ooo
ool4o`0002Gooooo0_l0001[ooooo`00Q?ooool2o`0000Oooooo0_l00004ooooo`;o00005oooool0
0ol0003oooooooooo`04ooooo`;o00001oooool2o`0001?ooooo0_l000000ooooooo0000o`00000U
ooooo`;o0000Joooool008Cooooo0_l00007ooooo`;o00001?ooool2o`0001Oooooo00?o0000oooo
ooooool03Oooool2o`0001?ooooo0_l0000Rooooo`;o0000LOooool009Wooooo0_l0000Aooooo`03
o`000?oooooooooo013ooooo0_l0000dooooo`;o00000_ooool4o`0006_ooooo002Iooooo`;o0000
4Oooool3o`0000Cooooo0_l0000:ooooo`;o0000>?ooool4o`0006_ooooo002/ooooo`03o`000?oo
oooooooo00Cooooo0_l00015ooooo`;o0000K?ooool00:cooooo00?o0000ooooooooool0^Oooool0
08Cooooo0_l0000Vooooo`03o`000?oooooooooo0;Wooooo0024ooooo`;o00009_ooool00ol0003o
ooooooooo`17ooooo`;o00001?ooool2o`0006[ooooo002/ooooo`03o`000?oooooooooo00oooooo
0_l0000?ooooo`;o00009Oooool2o`0000Cooooo0ol0001Yooooo`00[?ooool00ol0003ooooooooo
o`0?ooooo`;o00003oooool3o`0002?ooooo0_l00006ooooo`?o0000J?ooool008gooooo0_l0000M
ooooo`03o`000?oooooooooo027ooooo1?l0000Qooooo`;o000000?oooooo`000?l000001?ooool2
o`0006Sooooo002=ooooo`;o00007Oooool00ol0003oooooooooo`0Sooooo`;o00008Oooool2o`00
0003ooooool0003o000006kooooo002/ooooo`?o00003Oooool2o`0001;ooooo0_l0000Sooooo`;o
0000LOooool00:cooooo00?o0000ooooooooool03Oooool2o`000003ooooool0003o000000oooooo
0_l0002Fooooo`00SOooool2o`0001gooooo00?o0000ooooooooool04?ooool2o`0003Cooooo0_l0
001aooooo`00SOooool2o`0001gooooo00?o0000ooooooooool00oooool2o`0001cooooo0_l0000S
ooooo`;o0000LOooool008kooooo0_l0000Looooo`03o`000?oooooooooo00?ooooo0_l00008oooo
o`;o00004_ooool2o`0002Cooooo0_l0001`ooooo`00Q?ooool2o`0000Sooooo0_l0000Looooo`03
o`000?oooooooooo00?ooooo0_l00008ooooo`;o0000>?ooool2o`00073ooooo0024ooooo`;o0000
9_ooool00ol0003oooooooooo`03ooooo`;o00007Oooool2o`0009Gooooo002/ooooo`03o`000?oo
oooooooo01oooooo0_l000000ooooooo0000o`00002Eooooo`00QOooool2o`0001?ooooo0_l0000@
ooooo`?o00007oooool2o`0002cooooo0_l0001Zooooo`00QOooool2o`0000Sooooo0_l00009oooo
o`;o00004?ooool00ol0003oooooooooo`1=ooooo`;o0000J_ooool008kooooo0ol0000Kooooo`03
o`000?oooooooooo04Oooooo0_l0001`ooooo`00S_ooool3o`0001Wooooo0ol0000?ooooo`;o0000
>?ooool2o`00073ooooo002?ooooo`;o00006Oooool3o`0000oooooo0_l0000Aooooo`;o00009ooo
ool2o`0006kooooo002Eooooo`;o00005Oooool00ol0003oooooooooo`0Pooooo`;o00009oooool4
o`0006cooooo002Eooooo`;o00005Oooool00ol0003oooooooooo`1;ooooo`?o0000Joooool009Go
oooo0_l0000Eooooo`03o`000?oooooooooo04cooooo0_l0001[ooooo`00[?ooool3o`0000;ooooo
0_l00012ooooo`;o0000LOooool008oooooo0_l0000Kooooo`03o`000?oooooooooo00;ooooo0_l0
000:ooooo`;o00004Oooool2o`0002?ooooo0_l0001aooooo`00Soooool2o`0001_ooooo00?o0000
ooooooooool03_ooool2o`00017ooooo0_l0000Tooooo`;o0000L?ooool00:cooooo00?o0000oooo
ooooool02_ooool2o`0001Gooooo0_l0000Tooooo`;o00000_ooool2o`0006cooooo0025ooooo`;o
00009Oooool00ol0003oooooooooo`0:ooooo`;o00005Oooool2o`0002Oooooo0ol0001/ooooo`00
QOooool2o`0002Gooooo00?o0000ooooooooool0B_ooool4o`0006_ooooo0029ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01Oooool00ol0003oooooooooo`0<ooooo`;o0000?_ooool2o`0006_ooooo0025ooooo`;o0000
0_ooool01_mgMgOoV9RHoooooonHV9SoMgMgooooo`;o00000_ooool2ob4Q8@Cooooo00GoV9RHob4Q
8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool03?ooool2
o`000:_ooooo0025ooooo`Co000000Ko410@oooooooooooooooooa0@4?ooool3o`0000Sooooo00?o
V9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o00002_ooool2o`0001Cooooo0_l0
002Gooooo`00Qoooool3o`0000?ooooo00?o0000ooooool000000_l00009ooooo`03oiRHV?lQ8B7o
k^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`02o`0000Sooooo0_l0000D
ooooo`;o0000Uoooool008Wooooo00Go0000ooooooooooooooooo`000003ooooo`;o00002Oooool0
0omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`02o`000;Oooooo0029ooooo`05oa0@4?ooooooooooooooool@41000oooool2o`0000[ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01gooooo0_l0
0003ooooo`;o0000UOooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj
^[[ooooooiRHV?l@41001?ooool3o`0000Oooooo00?o0000ooooooooool02oooool2o`00013ooooo
0ol00002ooooo`;o0000UOooool008Kooooo0_l000001_ooooook^k^oc8b<_l0003o<S8bonk^kP;o
oooo0ol00006ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000oooo
ooooool02?ooool2o`000003ooooool0003o0000017ooooo0_l0002Iooooo`00Q_ooool2o`0000So
oooo0ol00004ooooo`;o00004oooool00ol0003oooooooooo`08ooooo`;o00005Oooool2o`0002Co
oooo0_l0001booooo`00Uoooool4o`00017ooooo00?o0000ooooooooool02Oooool2o`00013ooooo
0_l00002ooooo`;o00009?ooool2o`0007;ooooo002Hooooo`?o00004Oooool00ol0003ooooooooo
o`09ooooo`;o00004?ooool2o`0000;ooooo0_l0002Hooooo`00VOooool2o`00017ooooo0ol0000L
ooooo`;o0000Voooool008Sooooo0_l0000Rooooo`03o`000?oooooooooo01_ooooo0ol0002Koooo
o`00R?ooool2o`0002;ooooo00?o0000ooooooooool06oooool2o`0000;ooooo1?l0000Tooooo`;o
0000L?ooool00:cooooo0_l0000Kooooo`;o00000oooool4o`0002Cooooo0_l0001`ooooo`00[?oo
ool2o`0001_ooooo0_l00002ooooo`;o0000VOooool00:cooooo00?o0000ooooooooool07_ooool2
o`0009Wooooo002/ooooo`03o`000?oooooooooo04Gooooo0_l0001booooo`00[?ooool00ol0003o
ooooooooo`05ooooo`;o0000?Oooool3o`0007;ooooo002/ooooo`?o00001Oooool2o`0003gooooo
0_l0001cooooo`00R?ooool2o`0001;ooooo0_l0000=ooooo`;o0000^oooool008Oooooo0ol0000B
ooooo`?o00003?ooool2o`000;_ooooo0027ooooo`;o00004oooool3o`0000gooooo00?o0000oooo
ooooool0@_ooool2o`0007Gooooo002Looooo`;o00003_ooool00ol0003oooooooooo`11ooooo`?o
0000MOooool00:cooooo00?o0000ooooooooool01Oooool2o`0003[ooooo0_l0001fooooo`00Tooo
ool2o`0001;ooooo0_l00003ooooo`03o`000?oooooooooo00Gooooo0ol0002aooooo`00Toooool2
o`0000Sooooo0_l00003ooooo`;o00000oooool2o`0000?ooooo00?o0000ooooooooool01_ooool2
o`000;7ooooo002Mooooo`;o000000?oooooo`000?l000000_l00008ooooo`?o0000^Oooool00:3o
oooo0_l0000:ooooo`03o`000?oooooooooo04Gooooo0_l0001booooo`00[?ooool00ol0003ooooo
ooooo`15ooooo`;o0000L_ooool00:7ooooo0ol00008ooooo`03o`000?oooooooooo00;ooooo0_l0
000Dooooo`;o0000Woooool00:7ooooo0ol00008ooooo`03o`000?oooooooooo00;ooooo1?l0000@
ooooo`Go0000W_ooool00:cooooo00?o0000ooooooooool00_ooool4o`00013ooooo0_l000000ooo
oooo0000o`00002Nooooo`00[?ooool00ol0003oooooooooo`2iooooo`00ROooool3o`0000Wooooo
0_l0000Eooooo`03o`000?oooooooooo01Kooooo1_l0002Mooooo`00ROooool3o`0000Wooooo0ol0
000Dooooo`?o00005_ooool6o`0009gooooo002Fooooo`Co00004_ooool01?l0003ooooooooooooo
ool2o`0001Gooooo0_l0002Oooooo`00U_ooool4o`0001;ooooo00Co0000oooooooooooooooo0ol0
000Booooo`;o0000:?ooool2o`0007Oooooo002Fooooo`;o00005?ooool00ol0003oooooooooo`02
ooooo`;o00004_ooool2o`0002Sooooo0_l0001gooooo`00U_ooool2o`0001Cooooo00?o0000oooo
ooooool00_ooool2o`000;Gooooo002Fooooo`Co00004_ooool00ol0003oooooooooo`2iooooo`00
TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo0_l000000ooooooo8B4Qob4Q8@05ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool3o`0001Oooooo0_l0002Pooooo`00TOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Doooo
o`;o000000?oooooo`000?l00000X?ooool0097ooooo00Go410@oooooooooooooooooa0@400@oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04_ooool5o`0002Cooooo0_l0001loooo
o`00TOooool01Ol0003ooooooooooooooooo000000;ooooo0_l0000;ooooo`03ogMgMolb<S;ooooo
00Cooooo0ol0000Booooo`;o000000?oooooo`000?l000009?ooool2o`0007cooooo002Aooooo`05
o`000?ooooooooooooooool000000_ooool2o`000003ooooool0003o000000Gooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo03oooooo0_l0001hooooo`00TOooool01Ol@
413ooooooooooooooooo410@00Gooooo0_l00005ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0>_ooool2o`0000?ooooo0_l0001hooooo`00TOooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0jooooo`;o0000OOooool0
097ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`2i
ooooo`00V_ooool2o`00013ooooo00?o0000ooooooooool0^Oooool009[ooooo0_l0000;ooooo`;o
00000oooool00ol0003oooooooooo`0Aooooo`;o0000Y_ooool00:Kooooo0ol00003ooooo`03o`00
0?oooooooooo017ooooo0_l0002Vooooo`00W_ooool2o`0000Kooooo0_l00004ooooo`?o00004Ooo
ool2o`000:Kooooo002Nooooo`;o00000_ooool2o`0000Gooooo0_l000000ooooooo0000ooooo`0>
ooooo`;o00000_ooool2o`000:Kooooo002Rooooo`?o00001?ooool2o`000003ooooool0003ooooo
00gooooo0ol0002Zooooo`00Xoooool2o`0000Oooooo00?o0000ooooooooool03?ooool2o`000:_o
oooo002Rooooo`;o00002?ooool00ol0003oooooooooo`2iooooo`00X_ooool2o`0000?ooooo0_l0
0003ooooo`03o`000?oooooooooo03Sooooo0_l0001oooooo`00Yoooool2o`0000?ooooo00?o0000
ooooooooool0>?ooool2o`0007oooooo002@ooooo`;o00006_ooool00ol0003oooooooooo`0<oooo
o`;o0000Zoooool0093ooooo0_l0000Jooooo`?o00003?ooool2o`000:_ooooo002@ooooo`;o0000
6_ooool00ol0003oooooooooo`2iooooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool0=?oo
ool2o`000003ooooool0003o0000083ooooo002/ooooo`03o`000?oooooooooo03Cooooo0_l00000
0ooooooo0000o`000020ooooo`00[?ooool00ol0003oooooooooo`0cooooo`?o0000Poooool00:co
oooo00?o0000ooooooooool0<oooool3o`0008?ooooo002Aooooo`;o00006Oooool00ol0003ooooo
ooooo`06ooooo`;o0000;?ooool2o`0008?ooooo002Aooooo`?o00006?ooool00ol0003ooooooooo
o`06ooooo`;o0000/Oooool009;ooooo0_l0000Hooooo`?o0000^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool01Oooool2o`0000;ooooo0_l0002^ooooo`00
[?ooool00ol0003oooooooooo`05ooooo`;o00000_ooool2o`000:kooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
00Kooooo0_l0002aooooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool00oooool2o`000003
ooooool0003o00000;7ooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`03ooooo`;o0000
]?ooool009?ooooo0_l0000Gooooo`?o0000^Oooool009?ooooo0_l0000Gooooo`03o`000?oooooo
oooo02gooooo0_l0002:ooooo`00[?ooool00ol0003oooooooooo`0/ooooo`?o0000R_ooool00:co
oooo00?o0000ooooooooool0:_ooool4o`0008_ooooo002/ooooo`03o`000?oooooooooo02[ooooo
0_l0002=ooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`00
0?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`;o0000^_ooool008Wooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03
ogMgMolb<S;ooooo00Cooooo0_l0002jooooo`00ROooool01Ol@413ooooooooooooooooo410@00go
oooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o000000?oooooo`000?l0
0000]_ooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Ko
oooo00?oMgMgoc8b<_ooool00oooool7o`0002Kooooo0_l0002>ooooo`00ROooool01Ol0003ooooo
oooooooooooo000000cooooo0_l000000omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01?ooool2o`0000;ooooo0_l0000Wooooo`;o0000S_ooool008Wooooo00Go410@oooooooo
oooooooooa0@400:ooooo`Co000000?oZJVYogMgMoooool00_l000000ooooooo0000ooooo`08oooo
o`03o`000?oooooooooo0;Wooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02_ooool2o`00
0005ooooool0003o0000oc8b<_ooool00_l000000ooooooo0000ooooo`08ooooo`03o`000?oooooo
oooo0;Wooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02_ooool6o`0000Cooooo1?l00006
ooooo`03o`000?oooooooooo0;Wooooo002Kooooo`Oo00001?ooool2o`0000Cooooo00?o0000oooo
ooooool0^Oooool009_ooooo1ol00004ooooo`;o00001?ooool00ol0003oooooooooo`2iooooo`00
X_ooool2o`0000Sooooo00?o0000ooooooooool0^Oooool00:;ooooo0_l00008ooooo`?o0000^Ooo
ool00:Kooooo0_l00004ooooo`03o`000?oooooooooo0;Wooooo002Nooooo`;o00000oooool5o`00
00Cooooo00?o0000ooooooooool0^Oooool009kooooo1?l000000ooooooo0000o`000002o`0000Go
oooo00?o0000ooooooooool0^Oooool00:3ooooo0_l0000:ooooo`03o`000?oooooooooo01oooooo
0_l0002Hooooo`00[?ooool00ol0003oooooooooo`0Oooooo`;o0000V?ooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00
[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`0Kooooo`;o0000W?ooool00:cooooo00?o0000ooooooooool06oooool2o`00
09cooooo0029ooooo`;o00008Oooool00ol0003oooooooooo`2iooooo`00ROooool2o`00027ooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool06?ooool2o`0009oooooo002/
ooooo`03o`000?oooooooooo01Gooooo0_l000000ooooooo0000o`00002Oooooo`00[?ooool3o`00
01Gooooo0_l0002Rooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0Aooooo`;o
0000Y_ooool00:cooooo00?o0000ooooooooool04?ooool3o`000:Kooooo002/ooooo`?o00004?oo
ool2o`000:Oooooo002/ooooo`03o`000?oooooooooo013ooooo0_l0002Wooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00Soooool2o`0001_ooooo
00?o0000ooooooooool0^Oooool008oooooo0_l0000Kooooo`03o`000?oooooooooo0;Wooooo002R
ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`2iooooo`00Y?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`03o`000?oooooooooo00Go
oooo0ol0002iooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003ooooooooo
o`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31oooo
o`00X_ooool00omEEEGoIVIVo`000033ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00Z_ooool01?l@413o0000o`000?l0002jooooo`00Zoooool00ol0003o
ooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool01_l0003oMgMgo`00
0?l0003oEEEEonk^k[Oooooo002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoEEEE]oooool00:_o
oooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`2eooooo`00Zoooool00ol0003ok^k^
ooooo`02ooooo`03o`000?oooooooooo0;Gooooo002[ooooo`06o`000?mEEEGok^k^oooooomgMgOo
IVIV]oooool00:[ooooo00?o410@o`000?mgMgL00_l000000omVIVKok^k^ooooo`2fooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.59743 .71989 Mdot
.5735 .78781 Mdot
.50598 .49301 Mdot
.51535 .30999 Mdot
.42799 .73737 Mdot
.63043 .569 Mdot
.45407 .3539 Mdot
.60818 .15105 Mdot
.61146 .18464 Mdot
.56393 .5265 Mdot
.55035 .63579 Mdot
.66447 .24458 Mdot
.52169 .88466 Mdot
.56807 .53189 Mdot
.70186 .34948 Mdot
.54389 .38361 Mdot
.5902 .35055 Mdot
.51933 .88869 Mdot
.50722 .76936 Mdot
.37944 .64241 Mdot
.45299 .9119 Mdot
.51149 .88325 Mdot
.44629 .89139 Mdot
.49296 .92011 Mdot
.71751 .381 Mdot
.4071 .355 Mdot
.51503 .73331 Mdot
.48413 .79719 Mdot
.3745 .46348 Mdot
.5419 .83586 Mdot
.39454 .72009 Mdot
.58746 .14526 Mdot
.62832 .19251 Mdot
.61356 .45413 Mdot
.62068 .44122 Mdot
.38576 .32109 Mdot
.48813 .04381 Mdot
.4904 .78627 Mdot
.4198 .12623 Mdot
.65472 .21935 Mdot
.70369 .32048 Mdot
.61644 .43562 Mdot
.62769 .52906 Mdot
.61997 .67468 Mdot
.62568 .64263 Mdot
.40564 .60049 Mdot
.55314 .61155 Mdot
.53216 .07696 Mdot
.47084 .15455 Mdot
.39174 .25407 Mdot
.54321 .09203 Mdot
.40787 .15827 Mdot
.7087 .77058 Mdot
.62449 .52076 Mdot
.62726 .46313 Mdot
.62468 .19754 Mdot
.6244 .17622 Mdot
.57937 .31468 Mdot
.50961 .05712 Mdot
.62826 .62952 Mdot
.40222 .4816 Mdot
.74819 .45642 Mdot
.44559 .0732 Mdot
.42169 .51475 Mdot
.66635 .27507 Mdot
.59604 .15375 Mdot
.56177 .54086 Mdot
.54917 .42441 Mdot
.51496 .74704 Mdot
.45779 .92102 Mdot
.56028 .25852 Mdot
.48166 .31523 Mdot
.55775 .5768 Mdot
.5618 .48985 Mdot
.44609 .0726 Mdot
.48679 .63674 Mdot
.70813 .77157 Mdot
.44205 .2103 Mdot
.39419 .22551 Mdot
.53577 .24606 Mdot
.37948 .53738 Mdot
.53268 .84737 Mdot
.51529 .31478 Mdot
.61627 .42475 Mdot
.59586 .13982 Mdot
.52822 .32169 Mdot
.42548 .72827 Mdot
.40466 .46264 Mdot
.55737 .26289 Mdot
.55132 .44069 Mdot
.72097 .39972 Mdot
.74137 .65965 Mdot
.42379 .41085 Mdot
.40716 .60924 Mdot
.42494 .40659 Mdot
.75355 .6156 Mdot
.56773 .52994 Mdot
.58168 .14616 Mdot
.70772 .77515 Mdot
.53891 .22277 Mdot
.58325 .75194 Mdot
.52734 .20769 Mdot
.6777 .27739 Mdot
.60762 .70842 Mdot
.40833 .81014 Mdot
.61526 .46169 Mdot
.58124 .30737 Mdot
.49991 .78598 Mdot
.42354 .41278 Mdot
.43896 .89541 Mdot
.56716 .51311 Mdot
.49531 .26246 Mdot
.5913 .15214 Mdot
.37845 .60401 Mdot
.64544 .88887 Mdot
.52912 .55367 Mdot
.41017 .35035 Mdot
.56786 .10822 Mdot
.5694 .11395 Mdot
.52831 .09173 Mdot
.50977 .89865 Mdot
.73996 .40899 Mdot
.41475 .81702 Mdot
.37384 .51248 Mdot
.44779 .9101 Mdot
.53 .35218 Mdot
.37576 .47848 Mdot
.75576 .59043 Mdot
.52717 .84752 Mdot
.48353 .7103 Mdot
.48205 .91324 Mdot
.56451 .78871 Mdot
.68316 .28214 Mdot
.63574 .5419 Mdot
.62862 .54601 Mdot
.3763 .39194 Mdot
.42096 .10512 Mdot
.37607 .43233 Mdot
.55657 .58111 Mdot
.65422 .23796 Mdot
.69913 .3351 Mdot
.74808 .55631 Mdot
.45019 .27488 Mdot
.51835 .74426 Mdot
.58843 .34362 Mdot
.38065 .65013 Mdot
.58528 .12768 Mdot
.61718 .93128 Mdot
.42703 .71171 Mdot
.40447 .45404 Mdot
.72484 .341 Mdot
.51265 .18381 Mdot
.54256 .67938 Mdot
.50325 .91029 Mdot
.47222 .31432 Mdot
.60865 .66524 Mdot
.43751 .07321 Mdot
.42888 .10039 Mdot
.58688 .13586 Mdot
.5048 .06057 Mdot
.43309 .08034 Mdot
.42734 .23412 Mdot
.38416 .29448 Mdot
.67118 .23594 Mdot
.38438 .34674 Mdot
.61912 .58182 Mdot
.56488 .78158 Mdot
.58809 .13306 Mdot
.40743 .80971 Mdot
.51521 .74513 Mdot
.40294 .16953 Mdot
.40141 .20569 Mdot
.46871 .2598 Mdot
.50696 .75674 Mdot
.40843 .60354 Mdot
.43555 .74873 Mdot
.65022 .23471 Mdot
.75329 .61132 Mdot
.60701 .66781 Mdot
.51453 .62375 Mdot
.38463 .30352 Mdot
.38917 .24645 Mdot
.67215 .25024 Mdot
.55429 .41712 Mdot
.70618 .32496 Mdot
.45882 .70791 Mdot
.62171 .20526 Mdot
.75133 .60476 Mdot
.55517 .09947 Mdot
.67179 .23972 Mdot
.63026 .51976 Mdot
.73368 .39022 Mdot
.3827 .67494 Mdot
.42346 .54097 Mdot
.74588 .47195 Mdot
.6058 .15156 Mdot
.70695 .31236 Mdot
.67881 .27611 Mdot
.40721 .604 Mdot
.74964 .65406 Mdot
.58705 .31351 Mdot
.52136 .58115 Mdot
.52065 .58714 Mdot
.48829 .32132 Mdot
.41291 .64575 Mdot
.74427 .67437 Mdot
.56057 .79218 Mdot
.42892 .59334 Mdot
.62627 .59794 Mdot
.46876 .24498 Mdot
.47001 .72572 Mdot
.55653 .6166 Mdot
.54258 .8519 Mdot
.43266 .23591 Mdot
.40474 .79735 Mdot
.55583 .4453 Mdot
.55875 .79252 Mdot
.43301 .23757 Mdot
.6774 .24877 Mdot
.48176 .72153 Mdot
.60985 .67599 Mdot
.64 .195 Mdot
.40647 .38821 Mdot
.55176 .11044 Mdot
.42037 .85677 Mdot
.38072 .41785 Mdot
.55541 .47177 Mdot
.43872 .76692 Mdot
.60019 .73869 Mdot
.44926 .28581 Mdot
.70168 .34742 Mdot
.73969 .39503 Mdot
.53056 .34003 Mdot
.44043 .55626 Mdot
.72795 .71075 Mdot
.53492 .23128 Mdot
.53596 .68653 Mdot
.73846 .41271 Mdot
.50307 .76591 Mdot
.60549 .71629 Mdot
.45306 .90733 Mdot
.57209 .77479 Mdot
.74822 .4689 Mdot
.63367 .52288 Mdot
.4033 .79654 Mdot
.56021 .25858 Mdot
.56783 .11547 Mdot
.43084 .3645 Mdot
.47457 .0456 Mdot
.58216 .33998 Mdot
.55741 .25313 Mdot
.43295 .09333 Mdot
.70821 .32013 Mdot
.52848 .55669 Mdot
.42417 .45467 Mdot
.49968 .05889 Mdot
.4313 .22913 Mdot
.50554 .75824 Mdot
.6274 .43179 Mdot
.48296 .64368 Mdot
.63467 .19685 Mdot
.51894 .06414 Mdot
.50114 .17394 Mdot
.53706 .6836 Mdot
.38079 .40818 Mdot
.50444 .66679 Mdot
.52761 .2115 Mdot
.59179 .72649 Mdot
.54272 .65051 Mdot
.616 .61875 Mdot
.39605 .23975 Mdot
.46972 .16621 Mdot
.37735 .43707 Mdot
.6283 .4582 Mdot
.56543 .49443 Mdot
.51946 .20976 Mdot
.4246 .10005 Mdot
.55309 .40431 Mdot
.48516 .80891 Mdot
.55598 .1074 Mdot
.56439 .57945 Mdot
.61924 .63145 Mdot
.38466 .29865 Mdot
.51432 .64645 Mdot
.55945 .50871 Mdot
.51431 .0724 Mdot
.66744 .25588 Mdot
.50222 .78292 Mdot
.46333 .3261 Mdot
.40794 .56287 Mdot
.39373 .75437 Mdot
.40334 .47799 Mdot
.38014 .54623 Mdot
.74876 .61324 Mdot
.52656 .07967 Mdot
.69077 .31793 Mdot
.55423 .1165 Mdot
.43662 .49476 Mdot
.47342 .03323 Mdot
.74281 .48782 Mdot
.40823 .82589 Mdot
.69891 .34156 Mdot
.60261 .95151 Mdot
.49493 .17063 Mdot
.63253 .45766 Mdot
.57241 .77725 Mdot
.57683 .12863 Mdot
.70892 .34425 Mdot
.55531 .60705 Mdot
.56634 .12259 Mdot
.43254 .2235 Mdot
.52514 .53652 Mdot
.52473 .87408 Mdot
.59151 .35101 Mdot
.49875 .91002 Mdot
.72255 .33877 Mdot
.52222 .59824 Mdot
.60296 .69628 Mdot
.61565 .45209 Mdot
.67173 .28454 Mdot
.51508 .63533 Mdot
.67891 .26487 Mdot
.73549 .44345 Mdot
.75587 .53148 Mdot
.53563 .36484 Mdot
.63841 .52169 Mdot
.61479 .40893 Mdot
.45898 .05729 Mdot
.45782 .80543 Mdot
.5287 .50308 Mdot
.44197 .41128 Mdot
.58011 .30765 Mdot
.62793 .17762 Mdot
.51491 .07866 Mdot
.42178 .44982 Mdot
.53363 .85981 Mdot
.48903 .70638 Mdot
.49183 .32757 Mdot
.59604 .74737 Mdot
.63283 .54858 Mdot
.6195 .58057 Mdot
.43079 .22291 Mdot
.41292 .64276 Mdot
.72644 .73439 Mdot
.45543 .17863 Mdot
.52064 .86063 Mdot
.4231 .44961 Mdot
.6325 .2056 Mdot
.51583 .72996 Mdot
.37669 .42332 Mdot
.49288 .89932 Mdot
.42944 .35589 Mdot
.42714 .26335 Mdot
.74934 .54731 Mdot
.65516 .22559 Mdot
.45038 .04489 Mdot
.38414 .33403 Mdot
.46889 .15955 Mdot
.59564 .34485 Mdot
.39173 .26231 Mdot
.52952 .21783 Mdot
.65732 .23035 Mdot
.76016 .50434 Mdot
.40125 .78725 Mdot
.68462 .2873 Mdot
.68235 .27173 Mdot
.69368 .2863 Mdot
.50423 .35974 Mdot
.52582 .2166 Mdot
.70202 .34557 Mdot
.62778 .18358 Mdot
.50673 .36751 Mdot
.38673 .65985 Mdot
.48672 .174 Mdot
.63176 .57494 Mdot
.58659 .74431 Mdot
.59107 .15855 Mdot
.60321 .72047 Mdot
.49058 .04268 Mdot
.50121 .06551 Mdot
.44657 .8907 Mdot
.43128 .07517 Mdot
.47532 .91296 Mdot
.71152 .36298 Mdot
.64316 .89603 Mdot
.54573 .11242 Mdot
.61738 .6441 Mdot
.48426 .32243 Mdot
.72869 .40647 Mdot
.54369 .23474 Mdot
.44071 .42304 Mdot
.66828 .23956 Mdot
.45433 .91814 Mdot
.52849 .47856 Mdot
.56223 .51061 Mdot
.41051 .33528 Mdot
.52924 .70485 Mdot
.53157 .07462 Mdot
.44969 .92115 Mdot
.74482 .48363 Mdot
.67395 .25293 Mdot
.60284 .38702 Mdot
.71535 .74974 Mdot
.6009 .37023 Mdot
.44427 .77247 Mdot
.45358 .7939 Mdot
.46095 .64742 Mdot
.6326 .18749 Mdot
.6644 .24536 Mdot
.51799 .72669 Mdot
.44502 .29296 Mdot
.5646 .59751 Mdot
.53998 .35587 Mdot
.71864 .33782 Mdot
.41691 .6922 Mdot
.37886 .43655 Mdot
.47686 .25029 Mdot
.53585 .69669 Mdot
.50442 .66956 Mdot
.41854 .69724 Mdot
.61183 .4454 Mdot
.54659 .66321 Mdot
.42714 .57652 Mdot
.73388 .37683 Mdot
.65027 .23018 Mdot
.49078 .39759 Mdot
.62216 .44631 Mdot
.58212 .30989 Mdot
.58835 .71848 Mdot
.49609 .18237 Mdot
.51542 .74229 Mdot
.72683 .3884 Mdot
.75924 .60704 Mdot
.58891 .75072 Mdot
.66509 .8571 Mdot
.62254 .6718 Mdot
.42906 .60529 Mdot
.63699 .23011 Mdot
.70548 .35673 Mdot
.53932 .67047 Mdot
.47669 .90599 Mdot
.72102 .74572 Mdot
.45345 .27267 Mdot
.52638 .46146 Mdot
.42285 .69718 Mdot
.37851 .47937 Mdot
.51553 .20926 Mdot
.74591 .65671 Mdot
.45914 .71135 Mdot
.62268 .51126 Mdot
.61221 .40359 Mdot
.42084 .50615 Mdot
.5151 .62606 Mdot
.55857 .43608 Mdot
.61242 .15765 Mdot
.52512 .58981 Mdot
.38388 .30032 Mdot
.58405 .76647 Mdot
.61406 .67304 Mdot
.37612 .47392 Mdot
.38133 .57014 Mdot
.59552 .3602 Mdot
.76335 .5559 Mdot
.5627 .5123 Mdot
.62883 .1783 Mdot
.70428 .3075 Mdot
.53639 .66886 Mdot
.46301 .03553 Mdot
.48446 .16981 Mdot
.5939 .37385 Mdot
.37568 .45488 Mdot
.5893 .74108 Mdot
.4929 .79317 Mdot
.42469 .27288 Mdot
.6119 .43278 Mdot
.74566 .414 Mdot
.62247 .57943 Mdot
.49795 .60618 Mdot
.62396 .54853 Mdot
.5285 .23018 Mdot
.49343 .32683 Mdot
.54528 .40961 Mdot
.62493 .50785 Mdot
.63146 .51347 Mdot
.52581 .56513 Mdot
.43431 .22284 Mdot
.59835 .15695 Mdot
.44175 .78079 Mdot
.59318 .7206 Mdot
.53969 .69723 Mdot
.45337 .78085 Mdot
.51538 .4 Mdot
.66406 .86479 Mdot
.51994 .4263 Mdot
.58517 .7676 Mdot
.57855 .14933 Mdot
.38192 .37542 Mdot
.51128 .7555 Mdot
.37845 .37941 Mdot
.66939 .24814 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:?ooooo0_l00007ooooo`03o`000?oooooooooo0;Wo
oooo002Oooooo`;o00000_ooool2o`0000Oooooo00?o0000ooooooooool0^Oooool009oooooo0_l0
000;ooooo`03o`000?oooooooooo0;Wooooo002Xooooo`;o00000_ooool00ol0003oooooooooo`2i
ooooo`00Voooool2o`0000Kooooo0_l00003ooooo`;o00000_ooool00ol0003oooooooooo`2ioooo
o`00Voooool2o`0000Kooooo0_l00007ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000
^Oooool00:cooooo00?o0000ooooooooool0^Oooool009kooooo0_l0000;ooooo`;o00000_ooool2
o`000;Oooooo002Nooooo`;o00002oooool6o`000;Oooooo002/ooooo`?o00000oooool2o`000;Co
oooo002/ooooo`;o00001?ooool2o`000;Cooooo002/ooooo`;o0000^_ooool009Oooooo0_l00000
0ooooooo0000o`00000@ooooo`04o`000?ooooooooooooooo`;o0000]_ooool009Gooooo1?l00000
0ooooooo0000o`00000@ooooo`?o000000?oooooo`000?l000001?ooool2o`000;3ooooo002Eoooo
o`;o00005Oooool01?l0003oooooooooooooool2o`0000;ooooo1?l0002`ooooo`00UOooool2o`00
01Gooooo00Co0000oooooooooooooooo0_l00002ooooo`;o0000/_ooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
1_ooool2o`0000?ooooo0_l0002/ooooo`00UOooool2o`0001Gooooo00?o0000ooooooooool01_oo
ool2o`0000?ooooo0_l0002/ooooo`00UOooool2o`0001Gooooo00?o0000ooooooooool0^Oooool0
09?ooooo0ol0000Fooooo`?o00003oooool2o`000:Sooooo002Cooooo`?o00005_ooool00ol0003o
ooooooooo`0?ooooo`;o0000Z?ooool0097ooooo0_l0000Iooooo`03o`000?oooooooooo00oooooo
0_l0002Xooooo`00TOooool2o`0001Wooooo00?o0000ooooooooool03_ooool3o`0000;ooooo0_l0
002Tooooo`00[?ooool00ol0003oooooooooo`0<ooooo`Co00000oooool2o`000:Cooooo002/oooo
o`03o`000?oooooooooo00cooooo1?l00003ooooo`;o0000Y?ooool008Wooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool00ol0003oooooooooo`0>ooooo`;o00000oooool2o`000:Cooooo0029oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01;ooooo0_l0002Uooooo`00POooool6o`00
00;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000
ooooooooool00oooool3o`0001;ooooo0_l0002Uooooo`00ROooool01Ol0003ooooooooooooooooo
000000?ooooo0_l00009ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`0Fooooo`;o000000?oooooo`000?l00000W_ooool008Wooooo00Go0000oooo
ooooooooooooo`000003ooooo`;o00002Oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Fooooo`;o000000?oooooo`000?l00000W_oo
ool008Wooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Jooooo`;o0000WOooool008Wooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo01Wooooo0ol0002Mooooo`00ROooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`0Iooooo`;o0000
00?oooooo`000?l00000Voooool00:cooooo00?o0000ooooooooool07?ooool2o`0009_ooooo002/
ooooo`03o`000?oooooooooo01Sooooo0ol0002Nooooo`00[?ooool00ol0003oooooooooo`0Foooo
o`Go0000W_ooool00:cooooo0ol0000Fooooo`;o00000oooool2o`0000;ooooo0ol0002Gooooo`00
X_ooool2o`0000Sooooo00?o0000ooooooooool06oooool3o`000004ooooool0003o0000o`0009Oo
oooo002=ooooo`;o00004oooool2o`0000Sooooo00?o0000ooooooooool06oooool4o`0000?ooooo
0_l0002Eooooo`00SOooool2o`0001;ooooo0_l00009ooooo`03o`000?oooooooooo01_ooooo1?l0
0003ooooo`;o0000UOooool00:7ooooo0_l00009ooooo`03o`000?oooooooooo0;Wooooo002Roooo
o`;o00002?ooool00ol0003oooooooooo`2iooooo`00S?ooool2o`0001Cooooo0_l00002ooooo`;o
00000_ooool3o`000;_ooooo002<ooooo`;o00006?ooool3o`000003ooooool0003o000000;o0000
^_ooool00:Oooooo0_l00003ooooo`?o00009_ooool2o`00097ooooo002Mooooo`;o00003Oooool0
0ol0003oooooooooo`0Vooooo`?o0000T?ooool009gooooo0_l0000;ooooo`?o0000:Oooool2o`00
093ooooo002Zooooo`?o00000oooool2o`0001kooooo0_l00004ooooo`;o0000T?ooool00:cooooo
00Co0000oooooooooooooooo0_l0000Nooooo`;o00001?ooool3o`0008oooooo002/ooooo`03o`00
0?oooooooooo02Oooooo0ol0002?ooooo`00[?ooool00ol0003oooooooooo`0Wooooo`;o00000_oo
ool2o`0008cooooo002/ooooo`03o`000?oooooooooo02Kooooo0_l000000ooooooo0000o`000002
o`0008cooooo002/ooooo`?o00009_ooool2o`000003ooooool0003o000008kooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002;ooooo`;o00007oooool00ol0003oooooooooo`06ooooo`;o0000
7Oooool2o`000003ooooool0003o000008oooooo002;ooooo`;o00002oooool2o`0001;ooooo00?o
0000ooooooooool00_ooool3o`000003ooooool0003o000001gooooo0_l000000ooooooo0000o`00
002?ooooo`00V?ooool2o`0001;ooooo00?o0000ooooooooool00_ooool3o`000003ooooool0003o
00000;7ooooo002/ooooo`03o`000?oooooooooo00Gooooo0ol0002aooooo`00[?ooool00ol0003o
ooooooooo`05ooooo`?o0000:?ooool2o`0008Oooooo002/ooooo`03o`000?oooooooooo00Kooooo
0_l000000ooooooo0000o`00000Uooooo`;o0000Qoooool008Wooooo0_l0000:ooooo`?o00005?oo
ool3o`0000Wooooo0_l0000Uooooo`;o0000Qoooool008Wooooo0_l0000:ooooo`?o00005?ooool0
0ol0003oooooooooo`0`ooooo`;o0000Qoooool009Gooooo0_l0000Eooooo`03o`000?oooooooooo
00Kooooo1?l0000Pooooo`;o00000_ooool4o`0008Oooooo002Dooooo`?o00005Oooool00ol0003o
ooooooooo`06ooooo`Co000000?oooooo`000?l000007Oooool2o`0000;ooooo1?l00027ooooo`00
U?ooool3o`0001Gooooo00?o0000ooooooooool02oooool2o`00027ooooo0ol00004ooooo`;o0000
P_ooool008Wooooo0_l0000:ooooo`;o00005Oooool00ol0003oooooooooo`0_ooooo`;o00000ooo
ool3o`0008;ooooo0029ooooo`;o00001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0dooooo`?o0000
P_ooool008Oooooo0_l00008ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo
0_l00002ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool02?ooool2o`0002Wooooo
0_l00024ooooo`00Qoooool8o`0000;ooooo00Go410@oooooooooooooooooa0@400;ooooo`;o0000
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo0_l0000Yooooo`?o0000
00?oooooo`000?l00000P?ooool0097ooooo00Go0000ooooooooooooooooo`00000>ooooo`;o0000
00?o<S8booooooooool00oooool3o`0003Cooooo1Ol00020ooooo`00R?ooool2o`0000Oooooo00Go
0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000o`000?o<c<`01Oooool00ol0003o
ooooooooo`0@ooooo`;o00008_ooool4o`00087ooooo0028ooooo`;o00001oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0@ooooo`;o
00008_ooool2o`0008?ooooo002Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool2o`0000Wo
oooo00?o0000ooooooooool04?ooool2o`000:Oooooo0028ooooo`;o00001oooool00oo^k^ko<S8b
o`000002o`0000_ooooo1Ol00004ooooo`?o00004_ooool2o`0002Kooooo0_l0001oooooo`00R?oo
ool2o`0000[ooooo0_l0000Dooooo`?o00004_ooool2o`0002Kooooo0_l0001oooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00Toooool2o`0000Oooooo0_l0000>ooooo`03o`000?oooooooooo
03Wooooo0_l0001nooooo`00Toooool2o`0000Kooooo0ol0000>ooooo`?o0000<oooool2o`0000?o
oooo0ol0001nooooo`00Voooool2o`0000oooooo00?o0000ooooooooool0<oooool2o`0000;ooooo
0ol0001oooooo`00[?ooool00ol0003oooooooooo`0gooooo`Co0000O_ooool009_ooooo0_l0000?
ooooo`03o`000?oooooooooo03Gooooo0_l00002ooooo`;o00000_ooool2o`0007[ooooo002Koooo
o`;o00003oooool00ol0003oooooooooo`0eooooo`;o00000oooool2o`000003ooooool0003o0000
07[ooooo002/ooooo`03o`000?oooooooooo03[ooooo0_l0001mooooo`00QOooool2o`0001;ooooo
0_l0000Aooooo`03o`000?oooooooooo0;Wooooo0025ooooo`;o00004_ooool2o`00017ooooo00?o
0000ooooooooool0^Oooool008Gooooo0_l0000Uooooo`?o0000^Oooool008Gooooo0_l0000Uoooo
o`03o`000?oooooooooo0;Wooooo0025ooooo`;o00009Oooool00ol0003oooooooooo`0Gooooo`;o
00009oooool2o`0007Oooooo002/ooooo`03o`000?oooooooooo00;ooooo0_l0000Cooooo`?o0000
9_ooool2o`0007Oooooo002/ooooo`03o`000?oooooooooo00;ooooo0_l0000Dooooo`?o00009_oo
ool2o`0007Kooooo002Rooooo`;o00000_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool2
o`0001?ooooo1?l0000Vooooo`;o0000M_ooool00:;ooooo0_l00002ooooo`;o00001?ooool00ol0
003oooooooooo`02ooooo`;o00004oooool2o`0002?ooooo0_l0001kooooo`00Q_ooool2o`0001ko
oooo1?l00002ooooo`03o`000?oooooooooo00Kooooo0_l0000dooooo`;o00000_ooool3o`0007Ko
oooo0026ooooo`;o00007_ooool4o`0000;ooooo0ol00006ooooo`;o0000>?ooool3o`0007Kooooo
002Oooooo`;o00002?ooool2o`000003ooooool0003ooooo04;ooooo0_l0001fooooo`00Woooool2
o`0000Sooooo0_l000000ooooooo0000ooooo`2jooooo`00QOooool2o`0002Gooooo00?o0000oooo
ooooool0^Oooool008Gooooo0_l00007ooooo`;o00007?ooool00ol0003oooooooooo`0nooooo`;o
00001Oooool2o`0007;ooooo002>ooooo`;o00007?ooool00ol0003oooooooooo`07ooooo`;o0000
3oooool2o`0002Cooooo0_l00005ooooo`?o0000LOooool00:cooooo00?o0000ooooooooool01ooo
ool2o`0000oooooo1?l0000Rooooo`;o00001_ooool3o`00073ooooo0025ooooo`;o00009Oooool0
0ol0003oooooooooo`0Jooooo`Co00008?ooool3o`000003ooooool0003o000000?ooooo0_l0001`
ooooo`00QOooool2o`0002Gooooo00?o0000ooooooooool07?ooool2o`00027ooooo0_l000000ooo
oooo0000o`00001eooooo`00S_ooool2o`0001cooooo0ol00006ooooo`;o00004_ooool3o`0002;o
oooo0_l0001hooooo`00SOooool3o`0000Cooooo0_l00006ooooo`;o00003_ooool00ol0003ooooo
ooooo`06ooooo`;o00000_ooool2o`0000kooooo0ol0002Looooo`00SOooool2o`0000Gooooo0_l0
0006ooooo`;o00003_ooool00ol0003oooooooooo`0:ooooo`;o0000=?ooool2o`0007Oooooo002/
ooooo`?o00007?ooool2o`0002;ooooo0_l0001gooooo`00UOooool2o`0001Gooooo0ol00008oooo
o`;o00004_ooool2o`0002Cooooo0_l0001eooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B42o`0000;ooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
1?l0003oooooo`000?l00007ooooo`;o0000>?ooool2o`0007Gooooo0029ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMg
Molb<S;ooooo00Cooooo00Co0000ooooool0003o00007Oooool2o`0009Wooooo0021ooooo`Ko0000
0_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01cooooo1?l0002Iooooo`00QOooool2o`0000;ooooo
00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_oo
ool01?ooool3o`0001cooooo0_l0000/ooooo`;o0000KOooool008?ooooo1?l00002ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`1:ooooo`;o0000KOooool008?ooooo0_l00004ooooo`05
oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0A?ooool2o`0007?ooooo0029ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0;ooooo`;o0000=oooool2o`0007?ooooo0029ooooo`04onk^k_lb<S;o0000
oc8b<P;o00002_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oo
oooooooo00_ooooo0_l0000Booooo`;o00009_ooool2o`00073ooooo0023ooooo`;o00002?ooool2
o`0001gooooo00?o0000ooooooooool07oooool2o`0002Kooooo0_l000000ooooooo0000o`00001]
ooooo`00Poooool2o`0002Oooooo00?o0000ooooooooool0B_ooool4o`0006_ooooo002Yooooo`;o
000000?oooooo`000?ooool0COooool2o`0006_ooooo002Yooooo`;o000000Coooooo`000?l0003o
00000_ooool2o`0004;ooooo0_l0001aooooo`00[?ooool00ol0003oooooooooo`02ooooo`;o0000
2_ooool2o`0001;ooooo0_l0000Rooooo`;o0000LOooool009?ooooo0_l0000Gooooo`03o`000?oo
oooooooo00kooooo0_l0000Booooo`;o00009?ooool2o`0006oooooo0024ooooo`;o00003Oooool2
o`0001Oooooo00?o0000ooooooooool03?ooool2o`0001Cooooo0_l0000Tooooo`;o00000_ooool2
o`0006_ooooo0024ooooo`;o00003?ooool2o`0000Cooooo0_l0000Booooo`03o`000?oooooooooo
00cooooo0_l0000Dooooo`;o00009oooool3o`0006_ooooo002Booooo`;o00001?ooool2o`0001;o
oooo00?o0000ooooooooool0Boooool2o`000003ooooool0003o000006Wooooo0024ooooo`;o0000
9_ooool00ol0003oooooooooo`0>ooooo`;o0000?_ooool2o`0006Wooooo0024ooooo`;o00009_oo
ool00ol0003oooooooooo`0>ooooo`;o0000ZOooool008?ooooo0_l0000Cooooo`;o00004_ooool3
o`0000gooooo0_l0000Dooooo`;o0000U?ooool008?ooooo0_l0000Cooooo`;o00004_ooool00ol0
003oooooooooo`03ooooo`;o00002?ooool2o`0001Cooooo0_l0002Dooooo`00[?ooool00ol0003o
ooooooooo`03ooooo`;o00008_ooool2o`00093ooooo0023ooooo`;o00009oooool00ol0003ooooo
ooooo`0Rooooo`;o00000oooool2o`00093ooooo0023ooooo`?o00009_ooool00ol0003ooooooooo
o`0@ooooo`;o00004?ooool3o`0009Cooooo0023ooooo`?o00009_ooool00ol0003oooooooooo`0>
ooooo`Co00004Oooool2o`0009Cooooo002/ooooo`03o`000?oooooooooo00kooooo0_l0000Doooo
o`;o00009?ooool2o`0006gooooo002/ooooo`03o`000?oooooooooo00oooooo0_l0000@ooooo`;o
000000Coooooo`000?l0003o00008oooool2o`0006gooooo002Booooo`;o00006?ooool00ol0003o
ooooooooo`0?ooooo`;o00004?ooool2o`0000;ooooo0_l0002Booooo`00T_ooool2o`0001Sooooo
0ol0000Sooooo`;o0000U?ooool008?ooooo0_l00007ooooo`;o00001Oooool2o`0001Oooooo00?o
0000ooooooooool08_ooool3o`0009Cooooo0023ooooo`;o00001oooool2o`0000Gooooo0_l0000G
ooooo`03o`000?oooooooooo02;ooooo0_l00003ooooo`?o00009?ooool2o`0006Wooooo0009oooo
o`Co000000?o410@ooooooooool05_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46
ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000
oc8b<_oMgMd05_ooool00ol0003oooooooooo`05ooooo`;o00004Oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo00?o8B4Qo`000?l000000_ooool6o`0000Cooooo00GoA4A4o`000?l0003o<S8b
omgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool2o`000003ob4Q8Ooooooooooo00?o
oooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1?l0
00000ol@413oooooooooo`0Booooo`002oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8boooo
o`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0
3_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l00004ooooo`04oiRHV?lQ8B7ok^k^oooo
o`;o00001_ooool00omgMgOo<S8booooo`0Eooooo`03o`000?oooooooooo00Gooooo0_l0000Aoooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00olQ8B7o0000o`000002ooooo`;o000000Co8B4Q
onk^k_ooooooA4A41oooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool06Oooool00ol0003o
ooooooooo`0Dooooo`001_l00005ooooo`03o`000?oooooooooo013ooooo1_l00002ooooo`05oa0@
4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00Go
oooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`05oooo
o`Ko00000_ooool01Ol@413ooooooooooooooooo410@00Gooooo0_l00005ooooo`03oiRHV?lQ8B7o
k^k^00;o00001oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Sooooo00Go410@
oooooooooooooooooa0@400:ooooo`;o000000?oV9RHob4Q8Oo^k^h02Oooool00ol0003ooooooooo
o`0=ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0=ooooo`05oa0@
4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol0003ooooo
oooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`0>ooooo`05
o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0>ooooo`05o`000?oooooooooo
ooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo01Gooooo00?o0000
ooooooooool06?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000001Oooool2o`0000Sooooo
00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qoooooooo
ool01_ooool00omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`00
0?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003?ooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`000006ooooo`;o0000
1_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05_ooool00ol0003o
ooooooooo`0?ooooo`;o00001oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00
0004ooooo`?o00001Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Joooo
o`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go410@oooooooo
oooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool04Oooool01Ol@
413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooo
oooo410@00Kooooo0_l00007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06?oo
ool3o`0000oooooo0_l00007ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@4004ooooo`;o
00001_ooool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003_ooool00onY
ZJWoMgMgooooo`03ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05?ooool000_o
oooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooo
oooooooooooooc8b<P04ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`;o0000
0oooool01?l0003o^[ZjoooooonHV9P2o`0000?ooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`06ooooo`;o00004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Co
oooo0009ooooo`03oeEEEOmVIVKo000001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go
00001?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00004?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Kooooo0_l00003ooooo`03oiRHV?l@413o000000?o00000oooool4
o`0001Oooooo00?o0000ooooooooool01_ooool2o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004oooo
o`Co00006Oooool00omEEEGoIVIVo`00000Fooooo`00Roooool2o`0001oooooo00?o0000oooooooo
ool0COooool2o`0006[ooooo002/ooooo`03o`000?oooooooooo04gooooo0_l0001Zooooo`00[?oo
ool00ol0003oooooooooo`0Aooooo`;o0000>_ooool2o`0005oooooo0_l00002ooooo`;o00001Ooo
ool009Oooooo0_l0000Cooooo`04o`000?oooooo0000o`00013ooooo0ol0002Jooooo`06onk^k_lQ
8B7oQhN7okZj^_l0003ogMgM1Oooool009Oooooo0_l0000Cooooo`04o`000?oooooo0000o`00017o
oooo0_l0002Kooooo`04omgMgOl0003o410@olc<c0Kooooo0007oooooooo0000C?l0000<ooooo`04
onk^k_lQ8B7o410@onk^kPKooooo0007ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo00Co0000ooooool0003o00001?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:oooo
o`04ob4Q8OmgMgOoMgMgoc8b<PKooooo0007ooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00_ooooo0_l0000Ioooo
o`03o`000?oooooooooo00Kooooo0_l0000Oooooo`03o`000?oooooooooo02Kooooo00Co0000oooo
ool0003o00009Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Wooooo0_l00002
ooooo`;o00001Oooool0097ooooo0_l0000Iooooo`03o`000?oooooooooo013ooooo0ol0000Coooo
o`;o0000TOooool008;ooooo0_l0000Xooooo`03o`000?oooooooooo013ooooo1Ol0000@ooooo`Go
0000Soooool008;ooooo0_l0000>ooooo`;o00006?ooool00ol0003oooooooooo`0Aooooo`Co0000
4?ooool2o`000003ooooool0003o000008oooooo002Booooo`;o00006?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`0Vooooo`Ko0000SOooool00:cooooo0ol0000Voooo
o`Ko0000SOooool00:cooooo00?o0000ooooooooool04_ooool2o`0001Gooooo0_l0002>ooooo`00
[?ooool00ol0003oooooooooo`0Booooo`?o00004_ooool2o`0002Sooooo0_l0001Vooooo`00[?oo
ool00ol0003oooooooooo`0Cooooo`;o00004_ooool2o`0002Sooooo0_l0001Vooooo`00Q?ooool2
o`0002Kooooo00?o0000ooooooooool01Oooool2o`0000cooooo0_l0002Tooooo`00Q?ooool2o`00
02Kooooo00?o0000ooooooooool01Oooool2o`0000[ooooo0_l0002Vooooo`00T_ooool2o`0001So
oooo00?o0000ooooooooool04Oooool2o`0001Kooooo0_l0002>ooooo`00Q?ooool2o`0000cooooo
0_l0000Hooooo`03o`000?oooooooooo02Oooooo1?l0002>ooooo`00Q?ooool2o`0002Kooooo00?o
0000ooooooooool09Oooool5o`0002Gooooo0_l0001Xooooo`00[?ooool3o`0002Gooooo0_l00000
0ooooooo0000o`00000Uooooo`;o0000J?ooool00:cooooo00?o0000ooooooooool01_ooool2o`00
04_ooooo0_l0001Tooooo`00V?ooool2o`0001;ooooo00?o0000ooooooooool01_ooool2o`0004Ko
oooo0_l00003ooooo`;o0000I?ooool009Sooooo0_l0000Booooo`03o`000?oooooooooo00Kooooo
0_l00016ooooo`;o0000JOooool008gooooo0_l0000Mooooo`03o`000?oooooooooo00Gooooo0_l0
002booooo`00SOooool2o`0001gooooo00?o0000ooooooooool01Oooool2o`000;;ooooo0024oooo
o`;o00009_ooool00ol0003oooooooooo`0Xooooo`;o0000Soooool008Cooooo0_l0000Vooooo`03
o`000?oooooooooo02Sooooo0_l0002?ooooo`00U?ooool2o`0001Kooooo0ol0000@ooooo`;o0000
5_ooool2o`0008oooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`0@ooooo`Co00004Ooo
ool2o`000003ooooool0003o000008oooooo002/ooooo`03o`000?oooooooooo00Cooooo0_l00009
ooooo`;o000000?oooooo`000?l000004?ooool3o`0009;ooooo002/ooooo`03o`000?oooooooooo
00Cooooo0_l00009ooooo`;o00004oooool2o`0009?ooooo002/ooooo`03o`000?oooooooooo00?o
oooo0_l0002dooooo`00[?ooool00ol0003oooooooooo`03ooooo`Co0000B_ooool2o`0006Kooooo
002Dooooo`;o00005_ooool00ol0003oooooooooo`05ooooo`;o0000B_ooool2o`0006Kooooo002D
ooooo`;o00005_ooool00ol0003oooooooooo`04ooooo`;o00003?ooool2o`0001;ooooo0_l0002A
ooooo`00S?ooool2o`0001kooooo0ol00004ooooo`;o00003?ooool2o`0001;ooooo0_l0002Aoooo
o`00Poooool2o`0000Oooooo0ol0000Mooooo`03o`000?oooooooooo0;Wooooo0023ooooo`;o0000
2?ooool2o`0000Gooooo0_l0000Eooooo`;o00004Oooool2o`0003oooooo1?l0001Uooooo`00SOoo
ool2o`0000Gooooo0_l0000Eooooo`;o00004Oooool2o`0003oooooo1?l0001Uooooo`00SOooool2
o`0001gooooo00?o0000ooooooooool03_ooool2o`0003oooooo0ol0001Wooooo`00[?ooool00ol0
003oooooooooo`0>ooooo`?o0000?_ooool3o`0006Oooooo0029ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`0?ooooo`;o00004_ooool2o`0002_ooooo0_l0001Wooooo`00ROooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02?ooooo0_l0002Dooooo`00ROooool0
1Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003ooooooooo
o`03ooooo`?o000000?oooooo`000?l00000]_ooool008Wooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool01?l0003ooooooooo
ooooool3o`000;Gooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIV
ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`02ooooo`;o
00008?ooool2o`000003ooooool0003o0000093ooooo0029ooooo`05oa0@4?ooooooooooooooool@
41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool09?ooool2o`000003ooooool0003o0000093ooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool00_ooool2o`00
00?ooooo00?o0000ooooooooool00_ooool2o`0000Wooooo0_l0002Zooooo`00ROooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co000000?ooooo
o`000?l000000oooool00ol0003oooooooooo`02ooooo`;o00002Oooool2o`000:[ooooo0024oooo
o`;o00002Oooool2o`0001Gooooo0_l00004ooooo`03o`000?oooooooooo02Kooooo0_l0002Aoooo
o`00Q?ooool2o`0000Wooooo0_l0000Eooooo`;o00001?ooool01?l0003oooooooooooooool2o`00
023ooooo0_l000000ooooooo0000o`00002Aooooo`00Soooool2o`0000kooooo0_l0000;ooooo`04
o`000?ooooooooooooooo`;o00008?ooool2o`0009Cooooo0024ooooo`;o00006Oooool2o`0000_o
oooo0ol0000;ooooo`;o0000[?ooool008Cooooo0_l0000Vooooo`03o`000?oooooooooo00_ooooo
0_l00012ooooo`;o0000J?ooool00:cooooo00?o0000ooooooooool0C_ooool3o`0006Sooooo0026
ooooo`;o00009?ooool00ol0003oooooooooo`1<ooooo`Co0000JOooool008Kooooo0_l0000Toooo
o`03o`000?oooooooooo00cooooo0_l0000nooooo`;o0000Joooool00:cooooo0ol0000<ooooo`;o
00004_ooool2o`0009Oooooo002/ooooo`?o00002Oooool3o`0001Cooooo0_l0002Gooooo`00[?oo
ool3o`0000Wooooo0ol0000Fooooo`;o000000?oooooo`000?l00000T_ooool008Gooooo0_l0000U
ooooo`?o00008Oooool6o`0002Kooooo0_l0001Zooooo`00QOooool2o`0002Gooooo00?o0000oooo
ooooool02oooool2o`0001Cooooo0_l000000ooooooo0000o`00000Wooooo`;o0000J_ooool00:co
oooo00?o0000ooooooooool02oooool2o`000:cooooo002/ooooo`03o`000?oooooooooo00Wooooo
0_l0002^ooooo`00[?ooool00ol0003oooooooooo`08ooooo`?o0000[_ooool0093ooooo0_l0000J
ooooo`03o`000?oooooooooo00Sooooo0_l0002_ooooo`00T?ooool2o`0001[ooooo00?o0000oooo
ooooool0^Oooool0097ooooo0ol0000Hooooo`03o`000?oooooooooo00Sooooo1?l0000Cooooo`;o
0000V?ooool0097ooooo0ol0000Hooooo`?o00002?ooool4o`0001?ooooo0_l0002Hooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00Z?ooool2o`0000;ooooo00?o0000ooooooooool01_ooool2
o`000;7ooooo002Nooooo`;o00001_ooool4o`0000;ooooo00?o0000ooooooooool01_ooool2o`00
01Sooooo0_l0002Gooooo`00Toooool2o`0000Wooooo0_l00006ooooo`;o00001?ooool00ol0003o
ooooooooo`0Pooooo`;o00009_ooool2o`0006oooooo002Cooooo`;o00002Oooool2o`0000cooooo
00?o0000ooooooooool07oooool2o`0002Oooooo0_l0001_ooooo`00[?ooool00ol0003ooooooooo
o`0Jooooo`;o00000oooool2o`0009Sooooo0029ooooo`;o00006oooool2o`0000Cooooo00?o0000
ooooooooool06_ooool7o`0009Sooooo0029ooooo`;o00006oooool2o`0000Cooooo0ol0000Koooo
o`Ko0000V?ooool009?ooooo0_l0000=ooooo`;o00002?ooool00ol0003oooooooooo`03ooooo`;o
00005_ooool2o`0009cooooo002Cooooo`;o00003Oooool2o`0000Sooooo00?o0000ooooooooool0
0_ooool3o`0001Kooooo0_l0002Looooo`00[?ooool00ol0003oooooooooo`02ooooo`;o0000@ooo
ool2o`00073ooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`02ooooo`;o0000@oooool2
o`00073ooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`0Nooooo`;o0000VOooool0097o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool00_ooool2o`0001Kooooo0_l00002ooooo`;o0000VOooool0
097ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo00;ooooo0ol0000Dooooo`?o0000:_ooool2o`00077ooooo002Aoooo
o`05oa0@4?ooooooooooooooool@41000_l0000>ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool3o`0001Cooooo0_l000000ooooooo0000o`00000Vooooo`Co0000LOooool0
097ooooo00Co0000oooooooooooooooo0ol0000=ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00002
ooooo`;o00005?ooool6o`0002Kooooo0_l0001cooooo`00R?ooool2o`0000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`02o`0001Kooooo1?l0002Mooooo`00R?ooool2o`0000Oooooo00Go410@oooooooooooooooooa0@
400<ooooo`03o`000?oooooooooo00Oooooo1Ol0002gooooo`00TOooool01OmgMgOoV9RHoooooonH
V9SoMgMg00cooooo00?o0000ooooooooool01oooool4o`000;Sooooo002Aooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0^Oooool009Oooooo0_l0000C
ooooo`?o00006?ooool3o`0009kooooo002Gooooo`;o00004oooool4o`0001Oooooo0ol0000Voooo
o`;o0000M_ooool009Wooooo0_l0000Aooooo`04o`000?oooooo0000o`00043ooooo0_l0001foooo
o`00VOooool2o`00017ooooo0ol0000Dooooo`;o0000:oooool2o`0007Kooooo002/ooooo`03o`00
0?oooooooooo01Cooooo0_l0000[ooooo`;o0000M_ooool009Sooooo0_l00002ooooo`;o00003_oo
ool2o`0001?ooooo1?l0002Sooooo`00V?ooool2o`0000;ooooo0_l0000:ooooo`;o00000_ooool2
o`0001?ooooo0_l0002Uooooo`00Roooool2o`0001_ooooo0_l00002ooooo`;o00004oooool2o`00
0003ooooool0003o00000:;ooooo002;ooooo`;o00007oooool00ol0003oooooooooo`0Aooooo`?o
000000?oooooo`000?l00000X_ooool009cooooo0_l0000;ooooo`;o000000?oooooo`000?ooool0
4Oooool3o`000:Kooooo002<ooooo`;o00003_ooool2o`0000Sooooo0_l000001Ooooooo0000o`00
0?oooooo000001;ooooo0_l0002Wooooo`00S?ooool2o`0001Sooooo0_l00004ooooo`?o0000^Ooo
ool00:cooooo00?o0000ooooooooool0^Oooool009kooooo0_l0000<ooooo`03o`000?oooooooooo
0;Wooooo002=ooooo`;o00003oooool2o`0000Oooooo0_l00003ooooo`03o`000?oooooooooo0;Wo
oooo002=ooooo`;o00006?ooool2o`0000?ooooo00?o0000ooooooooool0^Oooool00:cooooo00?o
0000ooooooooool0^Oooool008oooooo0_l0000Kooooo`03o`000?oooooooooo0;Wooooo002?oooo
o`;o00006oooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002=ooooo`;o0000
7Oooool00ol0003oooooooooo`2iooooo`00SOooool2o`0001gooooo00?o0000ooooooooool0^Ooo
ool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool02_ooool2o`00
0:gooooo002/ooooo`03o`000?oooooooooo00[ooooo0_l0002]ooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`06
ooooo`?o0000/?ooool00:cooooo0ol00006ooooo`?o00000_ooool2o`000:cooooo002/ooooo`03
o`000?oooooooooo00_ooooo0_l0002/ooooo`00TOooool2o`0001Wooooo00?o0000ooooooooool0
<oooool2o`0008Cooooo002Aooooo`;o00006Oooool00ol0003oooooooooo`03ooooo`;o00000ooo
ool2o`0002Wooooo0_l00024ooooo`00[?ooool00ol0003oooooooooo`03ooooo`;o00000oooool2
o`0002Wooooo0_l00024ooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46
ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo03?ooooo0_l00024ooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`2iooooo`00ROooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo0_l0002booooo`00ROooool0
1Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8boooo
o`04ooooo`?o00001Oooool2o`000;;ooooo0029ooooo`05o`000?ooooooooooooooool000003_oo
ool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`2iooooo`00ROooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool0
0oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`02o`0000;ooooo0_l0002cooooo`00ROooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`02o`000004
ooooool0003o0000o`0002Oooooo0_l0002:ooooo`00V_ooool2o`00013ooooo00?o0000oooooooo
ool00oooool2o`0002Sooooo0_l0002:ooooo`00V_ooool2o`00013ooooo00?o0000ooooooooool0
^Oooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo02cooooo0_l0002;ooooo`00Uoooool2
o`00013ooooo0_l000000ooooooo0000o`000003o`0002[ooooo0_l0002;ooooo`00ZOooool2o`00
0004ooooool0003oooooooooo`;o0000]oooool009cooooo0_l00006ooooo`;o00001_ooool00ol0
003oooooooooo`2iooooo`00V_ooool4o`0000Kooooo0_l00005ooooo`Co0000^Oooool009[ooooo
1?l00005ooooo`;o000000?oooooo`000?l000000oooool4o`000;Wooooo002Looooo`;o00001Ooo
ool2o`000003ooooool0003o000000Cooooo00?o0000ooooooooool0^Oooool009cooooo0_l0000>
ooooo`03o`000?oooooooooo0;Wooooo002Kooooo`Go00002Oooool2o`000003ooooool0003ooooo
0;[ooooo002Kooooo`;o000000?oooooo`000?l000002Oooool2o`000004ooooool0003o0000o`00
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo02?ooooo
0_l0002Dooooo`00[?ooool00ol0003oooooooooo`0Sooooo`;o0000U?ooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Ooo
ool00:cooooo0ol0000Nooooo`;o0000VOooool00:cooooo00?o0000ooooooooool07_ooool2o`00
09Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000
^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:;ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oo
oooooooo0;Wooooo002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool0
0:Cooooo00?o0000ooooooooool01Oooool3o`000;Wooooo002Tooooo`03o`000?oooooooooo0<7o
oooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002T
ooooo`03o`000?oooooooooo0<7ooooo002Rooooo`03oeEEEOmVIVKo00000<?ooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Zooooo`04oa0@4?l0003o0000
o`000;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[o
oooo002[ooooo`06o`000?mgMgOo0000o`000?mEEEGok^k^]oooool00:_ooooo00Ko0000oeEEEOo^
k^koooooogMgMomEEEFgooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo
0;Gooooo002[ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0]Oooool00:_ooooo
00Ko0000oeEEEOo^k^koooooogMgMomVIVJgooooo`00Z_ooool00ol@413o0000ogMgM`02o`000003
ofIVI_o^k^kooooo0;Kooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.64538 .51989 Mdot
.64862 .58781 Mdot
.46916 .36641 Mdot
.42737 .3637 Mdot
.5405 .71806 Mdot
.61803 .369 Mdot
.44763 .62297 Mdot
.43295 .04494 Mdot
.44752 .04359 Mdot
.53453 .3265 Mdot
.56467 .43579 Mdot
.5223 .04458 Mdot
.63556 .68466 Mdot
.54082 .33189 Mdot
.60165 .14948 Mdot
.46038 .24375 Mdot
.49044 .15321 Mdot
.63481 .68869 Mdot
.57496 .56936 Mdot
.52715 .90408 Mdot
.59685 .76457 Mdot
.62479 .68325 Mdot
.5882 .76262 Mdot
.62148 .7213 Mdot
.62991 .181 Mdot
.45803 .82785 Mdot
.56836 .53331 Mdot
.5663 .6058 Mdot
.48877 .94671 Mdot
.63624 .63586 Mdot
.54225 .85095 Mdot
.41559 .10605 Mdot
.46589 .01656 Mdot
.55521 .25413 Mdot
.55717 .24122 Mdot
.45525 .92834 Mdot
.37257 .54139 Mdot
.56618 .58953 Mdot
.40535 .8219 Mdot
.50246 .01935 Mdot
.59189 .12048 Mdot
.55069 .23562 Mdot
.59931 .32906 Mdot
.64984 .47468 Mdot
.64273 .44263 Mdot
.51201 .786 Mdot
.55776 .41155 Mdot
.37555 .33937 Mdot
.40048 .59288 Mdot
.43932 .91675 Mdot
.38093 .28746 Mdot
.41492 .86704 Mdot
.77693 .57058 Mdot
.5928 .32076 Mdot
.57252 .26313 Mdot
.46436 .02419 Mdot
.45607 .01568 Mdot
.46627 .14688 Mdot
.37128 .44431 Mdot
.64007 .42952 Mdot
.48673 .82177 Mdot
.69076 .25642 Mdot
.38819 .72073 Mdot
.48975 .72959 Mdot
.53638 .07507 Mdot
.42438 .07909 Mdot
.53811 .34086 Mdot
.47939 .24115 Mdot
.57378 .54704 Mdot
.60156 .76291 Mdot
.43237 .1922 Mdot
.43322 .51087 Mdot
.54847 .3768 Mdot
.51774 .28985 Mdot
.38795 .71871 Mdot
.50654 .45063 Mdot
.77676 .57157 Mdot
.41889 .70655 Mdot
.43256 .91223 Mdot
.41671 .28831 Mdot
.50383 .90935 Mdot
.63163 .64737 Mdot
.42847 .36294 Mdot
.54617 .22475 Mdot
.41974 .07927 Mdot
.43333 .30562 Mdot
.53847 .72402 Mdot
.48206 .81518 Mdot
.43183 .20196 Mdot
.4877 .24679 Mdot
.64086 .19972 Mdot
.76523 .45965 Mdot
.46662 .74288 Mdot
.51363 .77902 Mdot
.46544 .73879 Mdot
.75979 .4156 Mdot
.53971 .32994 Mdot
.41208 .12556 Mdot
.77778 .57515 Mdot
.41188 .27956 Mdot
.64402 .55194 Mdot
.40526 .33262 Mdot
.54866 .07739 Mdot
.65099 .50842 Mdot
.5634 .83045 Mdot
.55994 .26169 Mdot
.46527 .1409 Mdot
.5743 .58598 Mdot
.46709 .74353 Mdot
.5886 .785 Mdot
.53241 .31311 Mdot
.41875 .46272 Mdot
.42041 .09356 Mdot
.51872 .90746 Mdot
.76099 .68887 Mdot
.51059 .35367 Mdot
.45635 .81543 Mdot
.39364 .18144 Mdot
.39594 .17453 Mdot
.37857 .35331 Mdot
.62924 .69865 Mdot
.66356 .20899 Mdot
.56455 .80993 Mdot
.49961 .93897 Mdot
.59502 .77471 Mdot
.44214 .29323 Mdot
.49177 .93798 Mdot
.75194 .39043 Mdot
.62618 .64752 Mdot
.53262 .52364 Mdot
.61038 .72111 Mdot
.63999 .58871 Mdot
.55602 .08214 Mdot
.6125 .3419 Mdot
.60703 .34601 Mdot
.47276 .95434 Mdot
.40048 .82137 Mdot
.48163 .94658 Mdot
.54901 .38111 Mdot
.5094 .03796 Mdot
.59318 .1351 Mdot
.7306 .35631 Mdot
.43122 .65704 Mdot
.57606 .54426 Mdot
.48596 .1493 Mdot
.52865 .89931 Mdot
.4088 .11433 Mdot
.74969 .73128 Mdot
.53385 .71094 Mdot
.48022 .81788 Mdot
.62124 .141 Mdot
.39892 .40323 Mdot
.57431 .47938 Mdot
.62737 .71029 Mdot
.43507 .55232 Mdot
.63474 .46524 Mdot
.38994 .75601 Mdot
.39774 .78783 Mdot
.41231 .10835 Mdot
.37273 .46484 Mdot
.39245 .77378 Mdot
.42727 .76561 Mdot
.44978 .94107 Mdot
.52556 .03594 Mdot
.46115 .92884 Mdot
.61185 .38182 Mdot
.63751 .58158 Mdot
.41225 .10442 Mdot
.5634 .83366 Mdot
.57326 .54513 Mdot
.41845 .88614 Mdot
.42667 .88499 Mdot
.42392 .57942 Mdot
.56966 .55674 Mdot
.51208 .77345 Mdot
.5426 .69467 Mdot
.50411 .03471 Mdot
.75781 .41132 Mdot
.63413 .46781 Mdot
.52403 .42375 Mdot
.45166 .93708 Mdot
.43822 .9296 Mdot
.53224 .05024 Mdot
.48145 .23013 Mdot
.59617 .12496 Mdot
.52846 .58664 Mdot
.4645 .03216 Mdot
.75324 .40476 Mdot
.38619 .23477 Mdot
.52768 .03972 Mdot
.59816 .31976 Mdot
.64977 .19022 Mdot
.53393 .89312 Mdot
.49509 .71618 Mdot
.69466 .27195 Mdot
.4312 .0513 Mdot
.59189 .11236 Mdot
.54925 .07611 Mdot
.51245 .77887 Mdot
.77127 .45406 Mdot
.47295 .13361 Mdot
.51382 .38115 Mdot
.5155 .38714 Mdot
.43312 .48061 Mdot
.52065 .75531 Mdot
.77402 .47437 Mdot
.63745 .59218 Mdot
.50536 .68253 Mdot
.62544 .39794 Mdot
.42068 .58243 Mdot
.53459 .56599 Mdot
.56317 .4166 Mdot
.64334 .6519 Mdot
.42651 .74198 Mdot
.56039 .83805 Mdot
.49396 .24676 Mdot
.63576 .59252 Mdot
.42679 .74013 Mdot
.53691 .04877 Mdot
.53612 .537 Mdot
.64025 .47599 Mdot
.47815 .00469 Mdot
.46542 .82342 Mdot
.38782 .24702 Mdot
.57583 .81407 Mdot
.47746 .92943 Mdot
.50412 .27177 Mdot
.54757 .69365 Mdot
.65566 .53869 Mdot
.43381 .65873 Mdot
.60065 .14742 Mdot
.65771 .19503 Mdot
.43911 .29292 Mdot
.49476 .63876 Mdot
.77225 .51075 Mdot
.41274 .29482 Mdot
.57057 .48653 Mdot
.66354 .21271 Mdot
.56943 .56591 Mdot
.65201 .51629 Mdot
.59523 .76042 Mdot
.64201 .57479 Mdot
.69578 .2689 Mdot
.60282 .32288 Mdot
.56039 .84331 Mdot
.43234 .19244 Mdot
.3956 .18045 Mdot
.45497 .72211 Mdot
.37589 .60019 Mdot
.47844 .15354 Mdot
.42895 .20259 Mdot
.39532 .77158 Mdot
.59626 .12013 Mdot
.51115 .35669 Mdot
.4761 .73175 Mdot
.37336 .48769 Mdot
.42532 .74942 Mdot
.56884 .55824 Mdot
.56012 .23179 Mdot
.50823 .46557 Mdot
.47367 .01109 Mdot
.37213 .4012 Mdot
.39817 .45641 Mdot
.57051 .4836 Mdot
.47534 .93121 Mdot
.53116 .46679 Mdot
.40621 .3306 Mdot
.64239 .52649 Mdot
.56292 .45051 Mdot
.6235 .41875 Mdot
.43526 .90102 Mdot
.40327 .59528 Mdot
.48239 .93997 Mdot
.57158 .2582 Mdot
.5232 .29443 Mdot
.4048 .36713 Mdot
.39859 .80659 Mdot
.4755 .22661 Mdot
.5715 .61615 Mdot
.3885 .22987 Mdot
.55617 .37945 Mdot
.63182 .43145 Mdot
.45059 .93799 Mdot
.5329 .44645 Mdot
.52293 .30871 Mdot
.37419 .42008 Mdot
.52979 .05588 Mdot
.57539 .58292 Mdot
.43956 .58859 Mdot
.50324 .77958 Mdot
.55098 .86512 Mdot
.4857 .81765 Mdot
.50562 .90495 Mdot
.75406 .41324 Mdot
.37571 .36374 Mdot
.57794 .11793 Mdot
.3902 .23548 Mdot
.48216 .6687 Mdot
.37344 .6079 Mdot
.69794 .28782 Mdot
.56785 .83915 Mdot
.59554 .14156 Mdot
.74322 .75151 Mdot
.39878 .48425 Mdot
.57559 .25766 Mdot
.64331 .57725 Mdot
.404 .14442 Mdot
.60662 .14425 Mdot
.55813 .40705 Mdot
.39683 .18524 Mdot
.42382 .74519 Mdot
.49975 .33652 Mdot
.63436 .67408 Mdot
.49193 .1529 Mdot
.62277 .71006 Mdot
.61806 .13877 Mdot
.52152 .39824 Mdot
.64147 .49628 Mdot
.55648 .25209 Mdot
.54554 .08454 Mdot
.52921 .43533 Mdot
.54486 .06487 Mdot
.67287 .24345 Mdot
.72846 .33148 Mdot
.44878 .27056 Mdot
.60709 .32169 Mdot
.53836 .20893 Mdot
.38182 .66573 Mdot
.56026 .66256 Mdot
.49003 .30845 Mdot
.46278 .66341 Mdot
.46435 .14315 Mdot
.45986 .01033 Mdot
.37553 .41602 Mdot
.47556 .74323 Mdot
.63755 .65981 Mdot
.53388 .51239 Mdot
.43371 .46383 Mdot
.65499 .54737 Mdot
.61226 .34858 Mdot
.61173 .38057 Mdot
.42407 .75298 Mdot
.51996 .75495 Mdot
.7802 .53439 Mdot
.40907 .65496 Mdot
.62489 .66063 Mdot
.47523 .73751 Mdot
.47497 .01868 Mdot
.56781 .52996 Mdot
.47953 .94583 Mdot
.61312 .7006 Mdot
.4534 .73012 Mdot
.43369 .76018 Mdot
.72826 .34731 Mdot
.5054 .02559 Mdot
.38097 .70595 Mdot
.45842 .93262 Mdot
.402 .60034 Mdot
.49359 .14602 Mdot
.44112 .91498 Mdot
.40808 .32089 Mdot
.50946 .03035 Mdot
.7219 .30434 Mdot
.55821 .84724 Mdot
.55954 .0873 Mdot
.55104 .07173 Mdot
.5682 .0863 Mdot
.43833 .4025 Mdot
.4071 .33741 Mdot
.60025 .14557 Mdot
.46198 .01316 Mdot
.43992 .38963 Mdot
.52956 .87326 Mdot
.40129 .51936 Mdot
.62173 .37494 Mdot
.64431 .54431 Mdot
.42229 .09431 Mdot
.6514 .52047 Mdot
.37179 .5309 Mdot
.37448 .47957 Mdot
.58801 .76135 Mdot
.39171 .78279 Mdot
.60614 .7278 Mdot
.61671 .16298 Mdot
.76157 .69603 Mdot
.38651 .27235 Mdot
.63502 .4441 Mdot
.43423 .49797 Mdot
.65128 .20647 Mdot
.41678 .25758 Mdot
.46562 .66636 Mdot
.52411 .03956 Mdot
.59947 .76725 Mdot
.48056 .29795 Mdot
.52647 .31061 Mdot
.45299 .8172 Mdot
.57118 .50485 Mdot
.37495 .34251 Mdot
.59936 .77985 Mdot
.69827 .28363 Mdot
.53513 .05293 Mdot
.51765 .18702 Mdot
.77524 .54974 Mdot
.50899 .17023 Mdot
.5489 .67811 Mdot
.5559 .66479 Mdot
.51105 .5462 Mdot
.46805 .00827 Mdot
.52254 .04536 Mdot
.56866 .52669 Mdot
.43629 .67568 Mdot
.56361 .39751 Mdot
.44881 .256 Mdot
.61377 .13782 Mdot
.53087 .74709 Mdot
.48195 .93349 Mdot
.42008 .54589 Mdot
.57453 .49669 Mdot
.53224 .46956 Mdot
.53179 .7416 Mdot
.54999 .2454 Mdot
.57188 .46321 Mdot
.50206 .69265 Mdot
.64461 .17683 Mdot
.50234 .03018 Mdot
.44923 .45326 Mdot
.56069 .24631 Mdot
.467 .14017 Mdot
.63574 .51848 Mdot
.40109 .47665 Mdot
.57234 .54229 Mdot
.64219 .1884 Mdot
.76206 .40704 Mdot
.64919 .55072 Mdot
.76793 .6571 Mdot
.65126 .4718 Mdot
.50797 .68116 Mdot
.48906 .03269 Mdot
.60817 .15673 Mdot
.56751 .47047 Mdot
.60422 .71947 Mdot
.7793 .54572 Mdot
.43003 .64326 Mdot
.47273 .29936 Mdot
.53093 .72328 Mdot
.49137 .92575 Mdot
.40454 .38481 Mdot
.76859 .45671 Mdot
.52949 .58781 Mdot
.58718 .31126 Mdot
.53365 .20359 Mdot
.48806 .73516 Mdot
.52553 .42606 Mdot
.49302 .23796 Mdot
.43875 .03541 Mdot
.52104 .38981 Mdot
.45112 .94104 Mdot
.65064 .56647 Mdot
.64328 .47304 Mdot
.4907 .93739 Mdot
.5106 .8966 Mdot
.4996 .1602 Mdot
.74571 .3559 Mdot
.52762 .3123 Mdot
.46096 .00921 Mdot
.58728 .1075 Mdot
.56393 .46886 Mdot
.3762 .65286 Mdot
.40087 .53012 Mdot
.50344 .17385 Mdot
.48664 .94341 Mdot
.64573 .54108 Mdot
.57085 .59491 Mdot
.4363 .76879 Mdot
.54501 .23278 Mdot
.67126 .214 Mdot
.61424 .37943 Mdot
.50058 .40659 Mdot
.60337 .34853 Mdot
.41082 .32275 Mdot
.43321 .45701 Mdot
.47047 .24399 Mdot
.58807 .30785 Mdot
.59684 .31347 Mdot
.51186 .36513 Mdot
.4233 .73763 Mdot
.42717 .07246 Mdot
.55157 .69207 Mdot
.64142 .5206 Mdot
.57858 .49723 Mdot
.55158 .65541 Mdot
.44879 .34464 Mdot
.76998 .66479 Mdot
.4576 .32164 Mdot
.65221 .5676 Mdot
.41108 .13627 Mdot
.46794 .93335 Mdot
.57348 .5555 Mdot
.46956 .94766 Mdot
.52865 .04814 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo0_l00006ooooo`03o`000?oooooooooo0;Wo
oooo002Tooooo`;o00001_ooool00ol0003oooooooooo`2iooooo`00W_ooool5o`000003ooooool0
003ooooo00Kooooo00?o0000ooooooooool0^Oooool009kooooo1ol00007ooooo`03o`000?oooooo
oooo0;Wooooo002Mooooo`Go000000?oEEEEo`000?l000001oooool00ol0003oooooooooo`2ioooo
o`00WOooool2o`000004ooooool0003o0000ooooo`;o00001oooool2o`000;[ooooo002Sooooo`;o
00001oooool2o`000;[ooooo002Pooooo`;o00002_ooool3o`000;Wooooo002Pooooo`;o00002_oo
ool3o`000;Wooooo002/ooooo`;o000000?oooooo`000?l00000]oooool00:3ooooo0_l00006oooo
o`;o00000_ooool5o`000;Oooooo002Gooooo`;o00001oooool2o`0000Kooooo0_l00002ooooo`Go
00000oooool2o`000;;ooooo002Gooooo`;o00004oooool00ol0003oooooooooo`02o`0000?ooooo
0ol0002aooooo`00V_ooool2o`00013ooooo00?o0000ooooooooool01Oooool3o`000;7ooooo002E
ooooo`;o00000oooool2o`00013ooooo00?o0000ooooooooool01?ooool2o`000;?ooooo002Eoooo
o`;o00005Oooool00ol0003oooooooooo`04ooooo`Co000000?oooooo`000?l00000[_ooool009Go
oooo0_l0000Eooooo`?o00001_ooool5o`000:kooooo002Eooooo`;o00005Oooool00ol0003ooooo
ooooo`06ooooo`Co0000[oooool00:cooooo00?o0000ooooooooool01_ooool2o`000;7ooooo002/
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00_ooooo0_l0002/oooo
o`00[?ooool00ol0003oooooooooo`0;ooooo`;o0000[?ooool00:cooooo00?o0000ooooooooool0
^Oooool009Cooooo0_l0000Fooooo`03o`000?oooooooooo00gooooo0_l0002Zooooo`00U?ooool2
o`0001Kooooo0ol00009ooooo`;o00000_ooool2o`000:[ooooo002Aooooo`Co00005oooool00ol0
003oooooooooo`09ooooo`;o00000_ooool2o`000:[ooooo002Aooooo`Co00005oooool00ol0003o
ooooooooo`0?ooooo`;o0000Z?ooool00:cooooo00?o0000ooooooooool03?ooool2o`000003oooo
ool0003o000000;ooooo0_l0002Tooooo`00[?ooool00ol0003oooooooooo`0<ooooo`;o00000_oo
ool2o`000003ooooool0003o00000:Cooooo002/ooooo`03o`000?oooooooooo013ooooo0_l0002W
ooooo`00TOooool3o`0001Sooooo00?o0000ooooooooool0^Oooool0097ooooo0ol0000Hooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool008oooooo0_l0000Kooooo`03o`000?oo
oooooooo0;Wooooo002?ooooo`?o00006_ooool00ol0003oooooooooo`0Iooooo`;o0000W_ooool0
08oooooo0ol0000Jooooo`03o`000?oooooooooo01Wooooo0_l0002Nooooo`00Soooool2o`0001_o
oooo00?o0000ooooooooool06oooool2o`0009cooooo002=ooooo`;o00007Oooool00ol0003ooooo
ooooo`0Kooooo`;o0000W?ooool008Wooooo00Cok^k^oc8b<_l0003o<S8b0_l00004ooooo`;o8B4Q
1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`0Fooooo`;o0000XOooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool05_ooool2o`0000?ooooo0ol0002Kooooo`00POooool6o`0000;ooooo00Ko410@oooooooooooo
oooooa0@4?ooool2o`0000[ooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03oooo
o`?o00006oooool3o`0009_ooooo0029ooooo`06o`000?ooooooooooooooool0003ooooo0_l0000;
ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0L
ooooo`;o0000Voooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<co
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;Wooooo0029
ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`?o00001ooo
ool00ol0003oooooooooo`2iooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00;o00002Ooo
ool01Ol@413ooooooooooooooooo<S8b00Cooooo0ol00007ooooo`03o`000?oooooooooo01_ooooo
0_l00005ooooo`;o0000UOooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02o`0000Wooooo
1Ol00002ooooo`Ko00001_ooool00ol0003oooooooooo`0Kooooo`;o00001Oooool5o`0009;ooooo
002Pooooo`?o00002Oooool00ol0003oooooooooo`0Looooo`;o00001_ooool3o`0009;ooooo002<
ooooo`;o00004_ooool2o`0000Oooooo0_l000000ooooooo0000ooooo`0Mooooo`Ko0000Uoooool0
08cooooo0_l0000Booooo`;o00001Oooool4o`000003ooooool0003ooooo01oooooo1?l0002Goooo
o`00Yoooool4o`000004ooooool0003o0000o`0001kooooo0_l0002Iooooo`00Y?ooool2o`0000;o
oooo0ol000000ooooooo0000ooooo`2jooooo`00Y?ooool2o`0000;ooooo0_l00002ooooo`03o`00
0?oooooooooo023ooooo0_l0002Gooooo`00Zoooool2o`0002;ooooo0_l0002Gooooo`00Zoooool2
o`0002Gooooo0_l0002Dooooo`00[?ooool00ol0003oooooooooo`0Sooooo`;o0000U?ooool00:co
oooo00?o0000ooooooooool00_l0002gooooo`00[?ooool5o`000;Oooooo0029ooooo`;o00008Ooo
ool3o`0002cooooo0_l0002;ooooo`00ROooool2o`00027ooooo00?o0000ooooooooool0;?ooool2
o`0008_ooooo0028ooooo`?o00008Oooool00ol0003oooooooooo`0Wooooo`;o0000T?ooool008So
oooo1?l0000Pooooo`03o`000?oooooooooo02Oooooo0_l0002@ooooo`00R_ooool2o`00023ooooo
00?o0000ooooooooool00_ooool2o`0002Sooooo0_l0002;ooooo`00UOooool2o`0001Gooooo00?o
0000ooooooooool00_ooool2o`0002Sooooo1?l00029ooooo`00UOooool2o`0001Gooooo00?o0000
ooooooooool0;_ooool2o`000003ooooool0003o000008Kooooo002/ooooo`03o`000?oooooooooo
037ooooo0_l00026ooooo`00[?ooool3o`0002_ooooo0_l0002<ooooo`00U?ooool3o`0001Gooooo
00?o0000ooooooooool02?ooool2o`00027ooooo0_l0002<ooooo`00U?ooool3o`0001Gooooo00?o
0000ooooooooool02?ooool2o`0002Gooooo0_l00028ooooo`00[?ooool00ol0003oooooooooo`09
ooooo`;o00009?ooool2o`0000;ooooo0_l00024ooooo`00[?ooool00ol0003oooooooooo`09oooo
o`;o0000:?ooool2o`0008Cooooo002/ooooo`03o`000?oooooooooo03?ooooo1?l00022ooooo`00
[?ooool00ol0003oooooooooo`0eooooo`;o0000P_ooool00:cooooo00?o0000ooooooooool0^Ooo
ool00:cooooo0ol0000<ooooo`;o0000Zoooool00:?ooooo0_l00007ooooo`03o`000?oooooooooo
00cooooo0_l0002[ooooo`00Qoooool2o`0001[ooooo1?l00005ooooo`03o`000?oooooooooo013o
oooo0_l0002Wooooo`00Q_ooool3o`0001cooooo0_l00005ooooo`03o`000?oooooooooo00_ooooo
0_l00003ooooo`;o0000Yoooool008Kooooo0ol0000Pooooo`;o000000?oooooo`000?ooool03?oo
ool4o`000:[ooooo0027ooooo`;o00008?ooool2o`000003ooooool0003ooooo00kooooo0_l0002Z
ooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B400ooooooo0000o`000002
ooooo`Go00001Oooool00ol0003oooooooooo`0?ooooo`;o00009Oooool2o`00087ooooo0027oooo
o`;o00002?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B400ooooooo0000o`000002
ooooo`;o000000Coooooo`000?l0003ooooo1Ol0000?ooooo`Ko00008oooool2o`00087ooooo0027
ooooo`So00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooool000001?l0
000?ooooo`;o00000_ooool2o`000:Kooooo002Aooooo`05o`000?ooooooooooooooool000003ooo
ool00omgMgOo<S8booooo`04ooooo`?o00003oooool2o`000:Sooooo002Aooooo`05o`000?oooooo
ooooooooool000001Oooool2o`0000Gooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo00oooooo0_l0002Xooooo`00T?ooool2o`0000?ooooo00?o410@ooooooooool00ooo
ool2o`0000Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`;o00000ooo
ool4o`0002Cooooo0_l0001kooooo`00T?ooool2o`000004oiRHV?ooooooV9RHogMgM`cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0@ooooo`;o00000_ooool4o`0002Cooooo0_l0
001kooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`03o`000?oo
oooooooo013ooooo0_l00003ooooo`;o0000X_ooool00:cooooo00?o0000ooooooooool05Oooool2
o`000:;ooooo002Kooooo`;o00003oooool00ol0003oooooooooo`0mooooo`;o0000N_ooool008Ko
oooo0_l0000Cooooo`;o00003oooool3o`0003gooooo0_l0001jooooo`00Q_ooool2o`0002Cooooo
0ol0000mooooo`;o0000N_ooool008kooooo0_l0000Looooo`03o`000?oooooooooo0;Wooooo002>
ooooo`;o00007?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0noooo
o`;o0000NOooool008Cooooo0_l0000:ooooo`;o00006_ooool00ol0003oooooooooo`0nooooo`;o
0000NOooool008Cooooo0_l0000:ooooo`;o00006_ooool00ol0003oooooooooo`02ooooo`;o0000
>_ooool2o`0007Wooooo002?ooooo`;o00001_ooool3o`0001;ooooo00?o0000ooooooooool00_oo
ool4o`000;?ooooo002?ooooo`;o00001_ooool3o`0000_ooooo0_l00005ooooo`03o`000?oooooo
oooo00Cooooo0_l0002cooooo`00Xoooool4o`0000Gooooo0ol0002iooooo`00Xoooool2o`0000Oo
oooo00?o0000ooooooooool0A_ooool2o`00077ooooo002Fooooo`;o00005?ooool00ol0003ooooo
ooooo`16ooooo`;o0000LOooool009Kooooo0_l0000@ooooo`;o00000_ooool00ol0003ooooooooo
o`04ooooo`?o00004oooool2o`0009gooooo002Xooooo`;o00000_ooool00ol0003oooooooooo`04
ooooo`Go00004?ooool3o`000003ooooool0003o000009[ooooo002/ooooo`03o`000?oooooooooo
00Kooooo0ol0000@ooooo`;o00000_ooool2o`0009[ooooo002/ooooo`03o`000?oooooooooo01go
oooo0_l0002Jooooo`00SOooool3o`0000kooooo0_l0000<ooooo`03o`000?oooooooooo01_ooooo
1?l000000ooooooo0000o`00002Gooooo`00SOooool3o`0000kooooo0_l0000<ooooo`?o00006ooo
ool2o`0000;ooooo0ol0002Gooooo`00[?ooool00ol0003oooooooooo`08ooooo`;o00005Oooool2
o`0009Sooooo002=ooooo`;o00007Oooool00ol0003oooooooooo`08ooooo`Co00004Oooool2o`00
02Wooooo0_l0001_ooooo`00S?ooool3o`0001gooooo00?o0000ooooooooool02_ooool2o`00017o
oooo0_l0000Yooooo`;o0000Koooool008cooooo0ol0000Looooo`;o00003?ooool2o`000:gooooo
0022ooooo`;o00002Oooool2o`0001cooooo0_l0000;ooooo`;o0000[_ooool008;ooooo0_l0000X
ooooo`03o`000?oooooooooo00Wooooo0_l0000Gooooo`;o0000UOooool008;ooooo0_l0000Goooo
o`;o00003oooool00ol0003oooooooooo`0Pooooo`Co0000UOooool009_ooooo0_l0000?ooooo`03
o`000?oooooooooo01oooooo1Ol0000Tooooo`;o0000Koooool00:cooooo0ol0000Oooooo`;o0000
00?oooooo`000?l000009?ooool2o`0006oooooo0023ooooo`;o00009oooool00ol0003ooooooooo
o`02o`0004cooooo0_l0001Yooooo`00Poooool2o`0002Oooooo00?o0000ooooooooool00_l00017
ooooo`;o00000oooool2o`0006Wooooo002/ooooo`03o`000?oooooooooo00;o0000Aoooool2o`00
06kooooo0023ooooo`;o00003oooool2o`0001Kooooo00?o0000ooooooooool00_l0002gooooo`00
Poooool2o`0000Cooooo00?ok^k^oc8b<_l000000_l00005ooooo`03ob4Q8Ol0003o000000?ooooo
1Ol00003ooooo`Co000000?o<S8bomgMgOooool01?ooool00ol0003oooooooooo`02o`000;Oooooo
0029ooooo`03ogMgMonHV9Sooooo00;o00001Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A003ooooo`;o00000_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02Cooooo
0_l0002Cooooo`00POooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRH
V?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Tooooo`;o0000
Toooool008Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo
00?oMgMgoc8b<_ooool01?ooool3o`0000gooooo0_l0000Fooooo`;o0000T_ooool008Wooooo00Go
0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo00gooooo1?l0000Aooooo`;o000000?oooooo`000?l0
0000T_ooool008Wooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01oooool01?l0003oooooooooooooool2o`0000[ooooo1?l0000@oooo
o`?o0000UOooool008Wooooo00?oMgMgoiRHV?ooool00_l0000;ooooo`05o`000?nj^[[ooooooiRH
V?l@41001?ooool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooooooo`;o00002_ooool2
o`0001;ooooo0_l0002Fooooo`00ROooool00oo^k^ko<S8bo`000002o`0000_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`02ooooo`;o0000]Oooool0
09Sooooo0_l0000Booooo`03o`000?oooooooooo00;ooooo1?l0001:ooooo`;o0000Ioooool009So
oooo0_l0000Booooo`03o`000?oooooooooo00Cooooo0_l0001:ooooo`;o0000Ioooool00:cooooo
00?o0000ooooooooool01?ooool2o`0000cooooo0_l0000Booooo`;o0000TOooool0087ooooo0_l0
000Yooooo`?o00001?ooool2o`0000cooooo0_l0000Booooo`;o0000TOooool0087ooooo0_l00007
ooooo`;o00002oooool2o`0001?ooooo00?o0000ooooooooool0^Oooool008[ooooo0_l0000;oooo
o`;o00004oooool2o`00017ooooo0_l0000nooooo`;o000000?oooooo`000?l00000I?ooool00:co
oooo0_l0000Aooooo`;o0000?_ooool2o`000003ooooool0003o000006Cooooo002/ooooo`03o`00
0?oooooooooo013ooooo0_l0000nooooo`Co0000IOooool008;ooooo0_l0000Xooooo`03o`000?oo
oooooooo013ooooo0ol0000mooooo`Co0000IOooool008;ooooo0_l0000Xooooo`03o`000?oooooo
oooo017ooooo0_l0000Booooo`;o0000:oooool2o`0006Gooooo0022ooooo`;o0000:?ooool00ol0
003oooooooooo`0Uooooo`;o0000T_ooool008;ooooo0_l0000Xooooo`?o00001?ooool2o`000;?o
oooo002/ooooo`03o`000?oooooooooo00Cooooo0ol0002booooo`00[?ooool00ol0003ooooooooo
o`05ooooo`;o00008Oooool2o`000003ooooool0003o000008cooooo002/ooooo`03o`000?oooooo
oooo02Sooooo0_l000000ooooooo0000o`00002<ooooo`00[?ooool00ol0003oooooooooo`06oooo
o`;o00002_ooool2o`000:Gooooo002/ooooo`03o`000?oooooooooo00Kooooo0_l0000:ooooo`;o
0000YOooool00:cooooo00?o0000ooooooooool0;?ooool2o`0008_ooooo0021ooooo`;o0000:Ooo
ool00ol0003oooooooooo`07ooooo`;o00008?ooool2o`000003ooooool0003o000008_ooooo0021
ooooo`;o0000:Oooool00ol0003oooooooooo`07ooooo`;o00008?ooool2o`0008kooooo002/oooo
o`Co00004?ooool2o`000:Kooooo002Kooooo`;o00003oooool01?l0003oooooo`000?l0000@oooo
o`;o0000@oooool2o`00067ooooo002:ooooo`;o00002_ooool2o`0000?ooooo0_l0000?ooooo`03
o`000?oooooooooo05Gooooo0ol0001Qooooo`002Oooool4o`000003oa0@4?oooooooooo01Kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05
odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;o00005?ooool00ol0003o
ooooooooo`0Hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004oooo
o`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B43ooooo`Go000000?o<S8bomgMgOooool03_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`Co
000000?o410@ooooooooool04_ooool000_ooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_oo
ool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o00001?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Cooooo0_l000000oooooooMgMgoc8b<P02o`0001Cooooo00?o0000ooooooooool05?oo
ool2o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Q
onk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B43ooooo`;o00000oooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`0I
ooooo`03o`000?oooooooooo01Cooooo0006o`0000Gooooo00?o0000ooooooooool04?ooool6o`00
00;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000
ooooooooool01Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oo
oooooooo00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41001Oooool2o`0000Gooooo
00?oV9RHob4Q8Oo^k^h01Oooool2o`0000;ooooo0ol0000Dooooo`04o`000?oooooo0000o`0000Ko
oooo0_l0000;ooooo`;o00000_ooool01Ol@413ooooooooooooooooo410@00cooooo0_l000000oo^
k^koooooooooo`07ooooo`03o`000?oooooooooo00gooooo00Go410@oooooooooooooooooa0@400@
ooooo`03o`000?oooooooooo00gooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmE
EEGooooo00Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Dooooo`002oooool0
0ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMg
Molb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo00?oMgMgoc8b<_ooool05Oooool01?l0003oooooo`000?l00006ooooo`;o00002Oooool3o`00
00?ooooo00Go0000ooooooooooooooooo`00000<ooooo`;o000000?o8B4Qonk^k_ooool01_ooool0
0omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8boooo
o`0>ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMg
Molb<S;ooooo01Wooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?oo
ool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<01Kooooo00?o0000ooooooooool01oooool2o`0000Wooooo
0ol00003ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOo0000o`000002o`000006
ooooool0003o8B4Qo`000?lb<S;oc<c<3oooool01Ol0003ooooooooooooooooo000000cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGo
c<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06_ooool00ol0003oooooooooo`0Doooo
o`002oooool00ol0003oooooooooo`0Hooooo`05oa0@4?ooooooooooooooool@41003_ooool00onY
ZJWoMgMgooooo`03ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400>ooooo`;o00001?oo
ool00ol0003oooooooooo`0Hooooo`?o00006?ooool01Ol@413ooooooooooooooooo410@00kooooo
1Ol000000ooooooo0000ooooo`0Booooo`05oa0@4?ooooooooooooooool@41003?ooool3o`00017o
oooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000
ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l00004ooooo`03o`000?nj^[[ooooo00;o0000
1?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Gooooo0_l000001_ooooooMgMg
oiRHV?ooooooV9RHogMgM`_ooooo00?o0000okZj^_ooool00_l000001Ooooooo0000o`000?oooooo
000001?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`?o00004Oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool05?ooool000Wooooo00?oEEEEofIVI_l000006_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2o`0000Cooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c004ooooo`Ko00005Oooool00ol0003oooooooooo`0Eooooo`;o000000Ko
ooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`00
013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00006Oooool00omEEEGoIVIVo`00000Fooooo`00R_ooool2
o`0000Wooooo0_l0000Eooooo`03o`000?oooooooooo01Cooooo0_l0002Sooooo`00P_ooool2o`00
00Kooooo0_l0000Pooooo`03o`000?oooooooooo01Cooooo0_l0002Sooooo`00P_ooool2o`0002So
oooo00?o0000ooooooooool05?ooool2o`0009Sooooo0_l00002ooooo`;o00001Oooool00:cooooo
00?o0000ooooooooool0[_ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Gooooo002Fooooo`;o
00005?ooool00ol0003oooooooooo`0Eooooo`Co00004_ooool2o`0008;ooooo00CogMgMo`000?l@
413oc<c<1_ooool000Ooooooool0001<o`0000cooooo00Cok^k^ob4Q8Ol@413ok^k^1_ooool000Oo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`04ob4Q8OmgMgOoMgMgoc8b
<PKooooo0007ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool05?ooool2o`00017o
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool02Oooool2o`0000;ooooo0_l00005ooooo`00[?ooool00ol0003ooooo
ooooo`0Dooooo`;o00006?ooool2o`0008Wooooo002Fooooo`;o00005?ooool00ol0003ooooooooo
o`08ooooo`;o00009?ooool2o`0002Kooooo0_l0001Qooooo`00U_ooool2o`0001Cooooo00?o0000
ooooooooool02?ooool2o`0002Gooooo0_l0000Uooooo`;o0000HOooool008_ooooo0_l0000Ooooo
o`03o`000?oooooooooo02Wooooo0_l00004ooooo`;o0000R?ooool008_ooooo0_l0000Oooooo`03
o`000?oooooooooo02Wooooo2?l00028ooooo`00[?ooool3o`0000Oooooo0_l0000Rooooo`Ko0000
R?ooool00:cooooo00?o0000ooooooooool01oooool2o`0000[ooooo0_l0000Gooooo`;o0000Rooo
ool0087ooooo0_l00008ooooo`;o00007oooool00ol0003oooooooooo`0Cooooo`;o00005oooool2
o`0008_ooooo0021ooooo`;o00002?ooool2o`0001oooooo00?o0000ooooooooool04oooool2o`00
04Cooooo0_l0001Nooooo`00[?ooool00ol0003oooooooooo`08ooooo`;o00002Oooool2o`0004Co
oooo0_l0001Nooooo`00[?ooool00ol0003oooooooooo`08ooooo`;o00009_ooool2o`0008Oooooo
0021ooooo`;o0000:Oooool00ol0003oooooooooo`0Dooooo`;o00005oooool2o`000003ooooool0
003o000008Oooooo0021ooooo`;o00003_ooool2o`0001Wooooo00?o0000ooooooooool00_l0000B
ooooo`Co00005?ooool3o`0002[ooooo0_l0001Nooooo`00TOooool2o`0001Wooooo00?o0000oooo
ooooool00_l0000Cooooo`?o00005?ooool2o`0000;ooooo0_l0000Uooooo`Co0000G_ooool009Ko
oooo0_l0000Dooooo`?o00005Oooool2o`0001Gooooo1_l0000Uooooo`;o0000H?ooool009Kooooo
0_l0000Dooooo`03o`000?oooooooooo01Gooooo0_l0000Eooooo`Co0000ROooool00:cooooo00?o
0000ooooooooool04oooool4o`000:;ooooo002/ooooo`03o`000?oooooooooo01?ooooo0ol0002S
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`08ooooo`;o
00002Oooool2o`0001Wooooo0ol00028ooooo`00[?ooool00ol0003oooooooooo`08ooooo`;o0000
2Oooool4o`0001Oooooo0ol0000Wooooo`;o0000Goooool00:cooooo00?o0000ooooooooool05Ooo
ool2o`00047ooooo0_l0001Oooooo`00[?ooool3o`0002_ooooo0ol0000Zooooo`;o0000Goooool0
09;ooooo0_l0000Hooooo`03o`000?oooooooooo02_ooooo0ol0000Zooooo`;o0000Goooool0097o
oooo0ol0000Hooooo`03o`000?oooooooooo01Gooooo0_l0000Cooooo`;o0000SOooool0097ooooo
0_l0000Iooooo`03o`000?oooooooooo01Gooooo0_l0000Cooooo`;o0000SOooool009Sooooo0_l0
000Booooo`03o`000?oooooooooo00Kooooo0_l0000=ooooo`;o00005?ooool2o`000003ooooool0
003o000008Wooooo002Hooooo`;o00004_ooool00ol0003oooooooooo`06ooooo`;o00002_ooool2
o`0001Kooooo0ol000000ooooooo0000o`000029ooooo`00Roooool3o`0001kooooo00?o0000oooo
ooooool04_ooool4o`0001?ooooo0ol0002=ooooo`00Roooool3o`0001kooooo00?o0000oooooooo
ool05?ooool2o`0001?ooooo0_l0002>ooooo`00Poooool2o`0000Kooooo0_l0000Oooooo`?o0000
^Oooool008?ooooo0_l00006ooooo`;o00007oooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`0Booooo`;o0000YOooool008;ooooo0_l0000Xooooo`03o`000?oooooooooo
01;ooooo0_l0002Uooooo`00P_ooool2o`0002Sooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool05?ooool2o`000:?ooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`0Dooooo`;o0000Xoooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`2iooooo`00ROooool01Ol@413ooooooooooooooooo410@00cooooo0_l000000oo^
k^koooooooooo`07ooooo`03o`000?oooooooooo00?ooooo0ol0002iooooo`00ROooool01Ol0003o
oooooooooooooooo000000cooooo0_l000000olQ8B7ok^k^ooooo`06ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0^Oooool008Wooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo0;Wooooo0029ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0^Oooool008Wooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo02[ooooo0_l0002=ooooo`00ROooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001?ooool3o`0002cooooo
0_l0002=ooooo`00U?ooool2o`0001Cooooo0ol0002kooooo`00U?ooool2o`0001Kooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool09_ooool4o`0008oooooo0023ooooo`;o
00009oooool3o`0002Kooooo1?l00002ooooo`;o0000Roooool008?ooooo0_l00009ooooo`;o0000
7?ooool00ol0003oooooooooo`0>ooooo`;o00007?ooool2o`0008_ooooo002>ooooo`;o00001Ooo
ool3o`0001Cooooo00?o0000ooooooooool03_ooool2o`0004Gooooo0_l0001Rooooo`00UOooool3
o`0001Cooooo00?o0000ooooooooool09_ooool2o`0000;ooooo0_l0000Yooooo`;o0000H_ooool0
09oooooo0_l0000;ooooo`03o`000?oooooooooo00oooooo0ol0000Dooooo`;o00000_ooool2o`00
02[ooooo0_l0001Qooooo`00QOooool2o`0001Sooooo0ol0000:ooooo`03o`000?oooooooooo00oo
oooo0ol00014ooooo`;o0000HOooool008Gooooo0_l0000Iooooo`;o00001?ooool2o`0000Cooooo
00?o0000ooooooooool0^Oooool00:Kooooo0_l00004ooooo`03o`000?oooooooooo02Wooooo0_l0
002>ooooo`00Uoooool2o`0001?ooooo0ol0000Yooooo`;o0000S_ooool009Oooooo0_l0000Coooo
o`03o`000?oooooooooo00gooooo0_l0002Zooooo`00[?ooool4o`0000cooooo0_l0000Gooooo`;o
0000TOooool00:cooooo1?l0000Uooooo`;o000000?oooooo`000?l00000S_ooool00:cooooo00?o
0000ooooooooool0:Oooool2o`0002Sooooo0_l0001Tooooo`00[?ooool00ol0003oooooooooo`0>
ooooo`;o00006Oooool2o`0002Sooooo0_l0001Tooooo`00[?ooool2o`0000cooooo1Ol0002Yoooo
o`00[?ooool2o`0000cooooo0ol00015ooooo`;o0000I?ooool00:cooooo0ol0000Rooooo`;o0000
0oooool2o`0002[ooooo0_l0001Tooooo`00[?ooool00ol0003oooooooooo`0Rooooo`;o00000ooo
ool2o`00093ooooo0024ooooo`;o00002oooool2o`0001Wooooo00?o0000ooooooooool0^Oooool0
08Cooooo0_l0000;ooooo`;o00006Oooool00ol0003oooooooooo`0Uooooo`Co0000T?ooool00:co
oooo00?o0000ooooooooool02?ooool2o`0001_ooooo1?l0002@ooooo`00Z_ooool3o`0000[ooooo
0_l0002_ooooo`00Qoooool2o`00027ooooo0ol0000<ooooo`;o00004oooool2o`0009Sooooo0027
ooooo`;o00005?ooool2o`0000gooooo00?o0000ooooooooool02_ooool2o`0001?ooooo1?l00002
ooooo`;o0000T_ooool008Oooooo0_l0000Dooooo`;o00003Oooool3o`0000Oooooo1?l0000Foooo
o`;o00000_ooool2o`0009;ooooo002/ooooo`03o`000?oooooooooo00Oooooo1?l0000Eooooo`;o
0000Uoooool009cooooo0_l0000:ooooo`;o00000_ooool00ol0003oooooooooo`0Pooooo`;o0000
;Oooool2o`0006Sooooo002Looooo`;o00001_ooool2o`0000;ooooo0_l00002ooooo`03o`000?oo
oooooooo04oooooo0_l0001Xooooo`00T_ooool2o`0000oooooo0ol00002ooooo`;o00000_ooool0
0ol0003oooooooooo`2iooooo`00T_ooool3o`0000_ooooo0_l000000ooooooo0000o`000003oooo
o`;o00000_ooool00ol0003oooooooooo`2iooooo`00TOooool01Oo^k^ko<S8bo`000?l0003ok^k^
00Gooooo0_lQ8B43ooooo`Go000000?o<S8bomgMgOooool01?ooool00ol0003oooooooooo`07oooo
o`;o0000/?ooool0097ooooo00GoMgMgo`000?l0003o0000ogMgM`05ooooo`;o8B4Q1?ooool4o`00
0003ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool01oooool2o`000;3ooooo002Aooooo`05
oa0@4?l0003o0000o`000?l@41004?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Oooooo0_l0002`ooooo`00TOooool00ol0003oooooo`000002o`0000oooooo00?oMgMgoc8b<_oo
ool01?ooool3o`0000Oooooo0_l00014ooooo`;o0000J_ooool0097ooooo0ol000000ooooooo0000
ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`03ooooo`;o
0000B?ooool2o`0006[ooooo0027ooooo`;o00002?ooool01Ol@413o0000o`000?oooooo410@00co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`;o0000]?ooool008Oooooo
0_l00008ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_l0000:ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool06_ooool4o`0009_ooooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00_l0000:ooooo`Co00001_ooool00ol0003oooooooooo`0Jooooo`Ko0000VOooool009Cooooo
0_l0000Fooooo`03o`000?oooooooooo01[ooooo0_l000001?oooooo0000o`000?l0002Iooooo`00
U?ooool2o`000003ooooool0003o000001?ooooo00?o0000ooooooooool07Oooool2o`0009[ooooo
0028ooooo`?o00003?ooool2o`0001?ooooo00Co0000oooooooooooooooo0_l0002fooooo`00R?oo
ool3o`00027ooooo0ol000000ooooooo0000o`00000Iooooo`;o0000Voooool00:cooooo0ol00000
0ooooooo0000o`00000Iooooo`?o0000V_ooool008Sooooo0_l0000Rooooo`?o000000?oooooo`00
0?l000006_ooool2o`0009[ooooo0028ooooo`;o00008_ooool01?l0003oooooooooooooool2o`00
01Oooooo0_l0002Mooooo`00R_ooool2o`00023ooooo00Co0000oooooooooooooooo0_l0000Goooo
o`;o0000WOooool008[ooooo0_l0000Pooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool008[ooooo0_l0000Pooooo`03o`000?oooooooooo0;Wo
oooo002:ooooo`;o00008?ooool00ol0003oooooooooo`0Booooo`;o0000YOooool00:cooooo00?o
0000ooooooooool04_ooool2o`000:Gooooo002Mooooo`;o00001oooool2o`0000Cooooo00?o0000
ooooooooool05_ooool2o`000:7ooooo002Looooo`?o00001_ooool4o`0000?ooooo00?o0000oooo
ooooool05_ooool2o`000:7ooooo002;ooooo`?o00003_ooool2o`0000Oooooo1?l00003ooooo`03
o`000?oooooooooo0;Wooooo002;ooooo`?o00004_ooool2o`0000Gooooo0_l00003ooooo`?o0000
^Oooool009kooooo1?l0000:ooooo`03o`000?oooooooooo0;Wooooo002Nooooo`;o00003?ooool0
0ol0003oooooooooo`0Aooooo`;o0000Y_ooool00:cooooo00?o0000ooooooooool04Oooool2o`00
0:Kooooo002/ooooo`03o`000?oooooooooo017ooooo0_l0002Vooooo`00[?ooool00ol0003ooooo
ooooo`0@ooooo`;o000000?oooooo`000?l00000Y?ooool00:cooooo00?o0000ooooooooool04?oo
ool2o`000003ooooool0003o00000:Cooooo002/ooooo`03o`000?oooooooooo013ooooo0_l0002W
ooooo`00[?ooool00ol0003oooooooooo`0@ooooo`;o0000Yoooool00:cooooo0ol0000;ooooo`;o
00000oooool2o`000:Oooooo002/ooooo`03o`000?oooooooooo00_ooooo0_l0002/ooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00ROooool01_o^k^ko<S8bo`000?lb<S;ok^k^ooooo`;o00000_ooool2
ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool03Oooool2o`000:[ooooo0029ooooo`06ogMgMonHV9SooooooiRHV?mgMgOooooo
0_l00002ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool03Oooool2o`000:[ooooo0029ooooo`05oa0@4?ooooooooooooooool@4100
3Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1_ooool2o`000;7ooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooo
ooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00006ooooo`;o0000/Oooool008Wooooo00Go
0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05oa0@4?ooooooooooooooool@
41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0^Oooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`Co00001?ooool01Ol@413o
oooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2ioooo
o`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo1?l00004ooooo`Go00001?ooool4o`00
00Kooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool02?ooool2o`000:oooooo002/ooooo`03o`000?oooooooooo00;o00001_oo
ool2o`000:oooooo002Fooooo`;o00005?ooool5o`0000Cooooo0_l0002aooooo`00U_ooool2o`00
01Cooooo00?o0000ooooooooool01_ooool2o`000;7ooooo002/ooooo`?o00001_ooool2o`000;7o
oooo002/ooooo`?o00000oooool2o`000;Cooooo002Eooooo`;o00005Oooool3o`0000?ooooo0_l0
002dooooo`00UOooool2o`000003ooooool0003o000001;ooooo00?o0000ooooooooool0^Oooool0
09Sooooo0_l0000Booooo`03o`000?oooooooooo0;Wooooo002Hooooo`;o00004_ooool00ol0003o
ooooooooo`2iooooo`00[?ooool3o`000;Wooooo002Mooooo`;o00002_ooool2o`000003ooooool0
003ooooo0;[ooooo002Gooooo`;o00001?ooool4o`0000;ooooo0ol00003ooooo`;o000000?ooooo
o`000?ooool0^_ooool009Oooooo0_l00005ooooo`[o00001?ooool00ol0003oooooooooo`2ioooo
o`00W?ooool4o`000003ooooool0003o000000?ooooo1?l00002ooooo`03o`000?oooooooooo0;Wo
oooo002Kooooo`?o00002?ooool7o`000;_ooooo002Kooooo`;o00002Oooool7o`000;_ooooo002K
ooooo`;o00002?ooool5o`0000;ooooo00?o0000ooooooooool0^Oooool00:;ooooo0_l000001?oo
oooo0000o`000?ooool2o`0000;ooooo00?o0000ooooooooool0^Oooool00:;ooooo0_l00008oooo
o`?o0000^Oooool00:?ooooo0_l00007ooooo`03o`000?oooooooooo0;Wooooo002Sooooo`;o0000
1oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002Rooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`2i
ooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`03
o`000?oooooooooo00Gooooo0ol0002iooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?oo
ool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0
003oooooooooo`31ooooo`00X_ooool00omEEEGoIVIVo`000033ooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00Z_ooool01?l@413o0000o`000?l0002joooo
o`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zooo
ool01_l0003oMgMgo`000?l0003oEEEEonk^k[Oooooo002[ooooo`06o`000?mEEEGok^k^oooooomg
MgOoEEEE]oooool00:_ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`2eooooo`00
Zoooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo0;Gooooo002[ooooo`06o`000?mE
EEGok^k^oooooomgMgOoIVIV]oooool00:[ooooo00?o410@o`000?mgMgL00_l000000omVIVKok^k^
ooooo`2fooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.61334 .31989 Mdot
.64375 .38781 Mdot
.4471 .55441 Mdot
.45555 .73745 Mdot
.58772 .51806 Mdot
.52563 .169 Mdot
.5079 .5985 Mdot
.38475 .78205 Mdot
.38131 .71874 Mdot
.43729 .27932 Mdot
.49899 .23583 Mdot
.36771 .39045 Mdot
.66942 .48466 Mdot
.4422 .25492 Mdot
.42724 .06251 Mdot
.42222 .61926 Mdot
.39595 .50761 Mdot
.67028 .48869 Mdot
.5627 .36936 Mdot
.64878 .70408 Mdot
.66268 .56457 Mdot
.65809 .48325 Mdot
.65325 .56262 Mdot
.66999 .5213 Mdot
.46301 .00879 Mdot
.5681 .6807 Mdot
.54168 .33331 Mdot
.56862 .4058 Mdot
.62856 .74955 Mdot
.65059 .43586 Mdot
.64263 .65095 Mdot
.40185 .84464 Mdot
.37143 .64436 Mdot
.42794 .2104 Mdot
.42532 .2046 Mdot
.60345 .77447 Mdot
.5062 .93916 Mdot
.56199 .38953 Mdot
.56709 .84794 Mdot
.36416 .48407 Mdot
.4109 .09226 Mdot
.42023 .22966 Mdot
.49096 .1313 Mdot
.59971 .27468 Mdot
.57978 .24263 Mdot
.58641 .586 Mdot
.48262 .22265 Mdot
.46145 .96899 Mdot
.51145 .80941 Mdot
.59591 .80121 Mdot
.44895 .95671 Mdot
.57926 .83934 Mdot
.76516 .37058 Mdot
.48126 .13035 Mdot
.44248 .15362 Mdot
.37343 .64941 Mdot
.37336 .68743 Mdot
.3998 .6145 Mdot
.48528 .96492 Mdot
.57188 .22952 Mdot
.57758 .62732 Mdot
.55333 .05642 Mdot
.5437 .8785 Mdot
.54339 .53427 Mdot
.37565 .32106 Mdot
.39406 .8121 Mdot
.44323 .26389 Mdot
.41754 .53682 Mdot
.55259 .34704 Mdot
.66673 .56291 Mdot
.41703 .75274 Mdot
.48641 .68006 Mdot
.4617 .23054 Mdot
.423 .35744 Mdot
.54325 .879 Mdot
.45885 .37247 Mdot
.76539 .37157 Mdot
.53406 .74308 Mdot
.59366 .81591 Mdot
.4414 .80028 Mdot
.62756 .70935 Mdot
.65058 .44737 Mdot
.45515 .73283 Mdot
.41519 .24922 Mdot
.3951 .83228 Mdot
.44158 .724 Mdot
.58807 .52402 Mdot
.57208 .62554 Mdot
.41927 .75296 Mdot
.41697 .49934 Mdot
.48084 .00721 Mdot
.70909 .25965 Mdot
.54001 .58878 Mdot
.58524 .57902 Mdot
.53849 .58866 Mdot
.68603 .2156 Mdot
.44099 .25919 Mdot
.40687 .85573 Mdot
.76784 .37515 Mdot
.44053 .82327 Mdot
.62479 .35194 Mdot
.45355 .8407 Mdot
.37872 .26687 Mdot
.61435 .30842 Mdot
.65558 .63045 Mdot
.43311 .1932 Mdot
.39871 .62018 Mdot
.56869 .38598 Mdot
.5403 .58808 Mdot
.66261 .585 Mdot
.43274 .28995 Mdot
.47903 .75367 Mdot
.39808 .8263 Mdot
.64171 .70746 Mdot
.79654 .48887 Mdot
.43693 .3754 Mdot
.5635 .67452 Mdot
.42306 .92414 Mdot
.42105 .9156 Mdot
.46384 .95278 Mdot
.6687 .49865 Mdot
.50715 .00899 Mdot
.64852 .60993 Mdot
.6352 .73898 Mdot
.66491 .57471 Mdot
.43697 .68821 Mdot
.62757 .73953 Mdot
.66811 .19043 Mdot
.64519 .44752 Mdot
.50208 .32364 Mdot
.65882 .52111 Mdot
.63548 .38871 Mdot
.38209 .23451 Mdot
.50926 .1419 Mdot
.50543 .14601 Mdot
.62073 .77073 Mdot
.56761 .86637 Mdot
.6232 .75419 Mdot
.46363 .2297 Mdot
.36711 .44939 Mdot
.41634 .08768 Mdot
.63312 .15631 Mdot
.51939 .67637 Mdot
.55376 .34426 Mdot
.39607 .52804 Mdot
.64837 .69931 Mdot
.40513 .8725 Mdot
.8022 .53128 Mdot
.57823 .51094 Mdot
.5721 .63035 Mdot
.44041 .01144 Mdot
.47033 .85312 Mdot
.52606 .27938 Mdot
.67149 .51029 Mdot
.49506 .66304 Mdot
.58084 .26524 Mdot
.55212 .88163 Mdot
.55895 .86164 Mdot
.40306 .85844 Mdot
.48945 .95412 Mdot
.55619 .87755 Mdot
.54841 .73496 Mdot
.60653 .79705 Mdot
.36581 .37776 Mdot
.60563 .76383 Mdot
.52457 .18182 Mdot
.63014 .38158 Mdot
.40222 .85956 Mdot
.65687 .63366 Mdot
.55131 .34513 Mdot
.58495 .84004 Mdot
.5845 .81294 Mdot
.50339 .70638 Mdot
.55235 .35674 Mdot
.58146 .57345 Mdot
.58047 .49467 Mdot
.3672 .4735 Mdot
.68234 .21132 Mdot
.58126 .26781 Mdot
.45917 .30678 Mdot
.60559 .78957 Mdot
.60017 .81456 Mdot
.36942 .34479 Mdot
.41469 .53024 Mdot
.41524 .07823 Mdot
.52311 .38664 Mdot
.37514 .64708 Mdot
.67514 .20476 Mdot
.43631 .94514 Mdot
.36673 .36745 Mdot
.48613 .12494 Mdot
.65118 .69312 Mdot
.54201 .51731 Mdot
.56345 .07195 Mdot
.38652 .78832 Mdot
.40842 .09258 Mdot
.37856 .26457 Mdot
.584 .57887 Mdot
.7129 .25406 Mdot
.39546 .58823 Mdot
.44379 .35523 Mdot
.44564 .34669 Mdot
.47983 .68707 Mdot
.58277 .55531 Mdot
.72377 .27437 Mdot
.63432 .39218 Mdot
.53837 .48253 Mdot
.54462 .19794 Mdot
.50475 .72036 Mdot
.52099 .36599 Mdot
.48985 .22034 Mdot
.6641 .4519 Mdot
.54198 .72608 Mdot
.6556 .63805 Mdot
.41561 .47199 Mdot
.63277 .39252 Mdot
.54143 .72407 Mdot
.3696 .32437 Mdot
.51092 .337 Mdot
.59065 .27599 Mdot
.36619 .59343 Mdot
.56823 .66032 Mdot
.43863 .93539 Mdot
.66146 .61407 Mdot
.61379 .74134 Mdot
.41904 .4221 Mdot
.58503 .49365 Mdot
.63113 .33869 Mdot
.51925 .66546 Mdot
.42579 .06523 Mdot
.43756 .70151 Mdot
.51106 .44082 Mdot
.73655 .31075 Mdot
.44368 .81623 Mdot
.52518 .28653 Mdot
.50863 .01271 Mdot
.5558 .36591 Mdot
.61853 .31629 Mdot
.6594 .56042 Mdot
.63192 .37479 Mdot
.56334 .0689 Mdot
.49199 .1246 Mdot
.65771 .64331 Mdot
.41709 .75281 Mdot
.42242 .9158 Mdot
.53298 .60895 Mdot
.51843 .91899 Mdot
.39862 .55993 Mdot
.42004 .7654 Mdot
.55511 .86488 Mdot
.41378 .07797 Mdot
.43767 .37225 Mdot
.53799 .55695 Mdot
.4943 .94644 Mdot
.54419 .73426 Mdot
.55213 .35824 Mdot
.42429 .19482 Mdot
.46294 .36214 Mdot
.36855 .61159 Mdot
.47569 .97054 Mdot
.4821 .84488 Mdot
.52395 .2836 Mdot
.61322 .7454 Mdot
.47866 .28907 Mdot
.4529 .83701 Mdot
.61298 .32649 Mdot
.50312 .25051 Mdot
.551 .21875 Mdot
.59014 .79959 Mdot
.51137 .79682 Mdot
.62112 .74707 Mdot
.44016 .15609 Mdot
.42506 .33244 Mdot
.46118 .83523 Mdot
.56384 .86663 Mdot
.41521 .55697 Mdot
.57796 .41615 Mdot
.43474 .93612 Mdot
.46916 .21273 Mdot
.56439 .23145 Mdot
.60563 .79263 Mdot
.47292 .2805 Mdot
.42845 .33064 Mdot
.47936 .95746 Mdot
.37051 .3545 Mdot
.56855 .38292 Mdot
.50201 .63586 Mdot
.57507 .57958 Mdot
.65702 .66512 Mdot
.57527 .62418 Mdot
.6276 .70495 Mdot
.67936 .21324 Mdot
.46673 .963 Mdot
.40155 .14152 Mdot
.4356 .92749 Mdot
.51685 .48863 Mdot
.52068 .92982 Mdot
.57307 .08782 Mdot
.66351 .63915 Mdot
.42007 .08028 Mdot
.80382 .55151 Mdot
.48805 .83619 Mdot
.44304 .14448 Mdot
.63421 .37725 Mdot
.41273 .88691 Mdot
.42938 .04828 Mdot
.48124 .21984 Mdot
.42319 .90939 Mdot
.54327 .73819 Mdot
.43396 .42732 Mdot
.66399 .47408 Mdot
.39556 .50119 Mdot
.66679 .51006 Mdot
.43689 .01833 Mdot
.45067 .31963 Mdot
.59998 .29628 Mdot
.42809 .20601 Mdot
.37967 .27888 Mdot
.46625 .28938 Mdot
.37478 .28595 Mdot
.53025 .04345 Mdot
.62106 .13148 Mdot
.43058 .66413 Mdot
.49576 .12217 Mdot
.40823 .28455 Mdot
.53198 .89577 Mdot
.58529 .46256 Mdot
.42993 .47581 Mdot
.51506 .54614 Mdot
.3994 .6237 Mdot
.37137 .67203 Mdot
.47819 .95248 Mdot
.54201 .56827 Mdot
.66147 .45981 Mdot
.49883 .31246 Mdot
.47603 .68808 Mdot
.63393 .34737 Mdot
.5117 .14858 Mdot
.52396 .18057 Mdot
.54535 .74088 Mdot
.58194 .55495 Mdot
.75396 .33439 Mdot
.52362 .77354 Mdot
.64915 .46063 Mdot
.53983 .56387 Mdot
.36993 .60426 Mdot
.5398 .32996 Mdot
.6215 .75529 Mdot
.65336 .5006 Mdot
.53551 .6195 Mdot
.54609 .70792 Mdot
.62719 .14731 Mdot
.36499 .4698 Mdot
.54162 .90635 Mdot
.60605 .77222 Mdot
.51277 .8023 Mdot
.3937 .49541 Mdot
.59556 .79513 Mdot
.45038 .83093 Mdot
.36543 .45077 Mdot
.60364 .10434 Mdot
.65711 .64724 Mdot
.38464 .21881 Mdot
.37798 .25776 Mdot
.3879 .18358 Mdot
.46165 .68122 Mdot
.45419 .83163 Mdot
.42487 .06628 Mdot
.37154 .66219 Mdot
.45849 .67702 Mdot
.63886 .67326 Mdot
.49517 .81763 Mdot
.53171 .17494 Mdot
.62203 .34431 Mdot
.39784 .81793 Mdot
.61959 .32047 Mdot
.50407 .94433 Mdot
.49228 .9433 Mdot
.65255 .56135 Mdot
.55867 .8841 Mdot
.65726 .5278 Mdot
.44433 .02674 Mdot
.79999 .49603 Mdot
.44445 .93563 Mdot
.57266 .2441 Mdot
.48338 .67845 Mdot
.49387 .00724 Mdot
.43467 .80664 Mdot
.51556 .53712 Mdot
.36659 .38346 Mdot
.66637 .56725 Mdot
.42969 .51943 Mdot
.42992 .3151 Mdot
.56367 .68477 Mdot
.53312 .30485 Mdot
.46226 .97093 Mdot
.6713 .57985 Mdot
.57172 .08363 Mdot
.37034 .3314 Mdot
.39959 .38019 Mdot
.75514 .34974 Mdot
.39619 .4225 Mdot
.58014 .47811 Mdot
.58181 .46479 Mdot
.48972 .35389 Mdot
.36915 .63673 Mdot
.36789 .38919 Mdot
.53934 .32669 Mdot
.52291 .65945 Mdot
.48282 .20779 Mdot
.4274 .66714 Mdot
.43297 .02871 Mdot
.58971 .54709 Mdot
.61827 .74107 Mdot
.4969 .72986 Mdot
.5332 .29669 Mdot
.48065 .2878 Mdot
.58843 .5416 Mdot
.42259 .23097 Mdot
.51716 .26321 Mdot
.53912 .49265 Mdot
.36654 .48225 Mdot
.47037 .62263 Mdot
.42894 .19159 Mdot
.39818 .61277 Mdot
.60313 .31848 Mdot
.48589 .82774 Mdot
.54926 .34229 Mdot
.68487 .20704 Mdot
.62948 .35072 Mdot
.79077 .4571 Mdot
.59998 .2718 Mdot
.54044 .48116 Mdot
.36994 .53972 Mdot
.4349 .04575 Mdot
.5157 .27047 Mdot
.65201 .51947 Mdot
.75759 .34572 Mdot
.51639 .6791 Mdot
.43169 .5533 Mdot
.58024 .52328 Mdot
.62236 .72751 Mdot
.4651 .83256 Mdot
.71127 .25671 Mdot
.52461 .38781 Mdot
.47222 .13238 Mdot
.4056 .30589 Mdot
.5445 .54137 Mdot
.46079 .30137 Mdot
.4139 .478 Mdot
.38142 .75877 Mdot
.44823 .32294 Mdot
.60687 .79418 Mdot
.63722 .36647 Mdot
.59249 .27304 Mdot
.62644 .73938 Mdot
.62924 .6966 Mdot
.3955 .46612 Mdot
.64807 .1559 Mdot
.43072 .30989 Mdot
.37089 .66748 Mdot
.40401 .1088 Mdot
.51148 .26886 Mdot
.53024 .91937 Mdot
.49761 .81716 Mdot
.39772 .44631 Mdot
.62558 .74746 Mdot
.62216 .34108 Mdot
.56881 .39491 Mdot
.54833 .70341 Mdot
.41682 .25256 Mdot
.51686 .014 Mdot
.52602 .17943 Mdot
.44908 .40851 Mdot
.50278 .14853 Mdot
.45019 .81858 Mdot
.47466 .69177 Mdot
.42009 .57517 Mdot
.47176 .12949 Mdot
.48236 .12178 Mdot
.43969 .36729 Mdot
.54132 .73688 Mdot
.39201 .80132 Mdot
.58839 .49207 Mdot
.60966 .3206 Mdot
.53748 .29723 Mdot
.57374 .45541 Mdot
.44675 .64807 Mdot
.79589 .46479 Mdot
.43983 .61456 Mdot
.63925 .3676 Mdot
.40942 .85779 Mdot
.61019 .75709 Mdot
.55568 .3555 Mdot
.61645 .7684 Mdot
.36868 .36129 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool3o`0000?ooooo0ol0002kooooo`00Woooool2o`0000?ooooo0ol0
0003ooooo`?o000000?oooooo`000?l00000^?ooool009Sooooo0_l00005ooooo`;o00000oooool0
0ol0003oooooooooo`05ooooo`04o`000?oooooo0000o`000;Sooooo002Hooooo`;o00002?ooool0
0omEEEGoIVIVo`000007ooooo`05o`000?oooooo0000o`000?ooool00_l0002eooooo`00Uoooool2
o`0001?ooooo00?o0000ooooooooool00_ooool2o`000;Gooooo002Gooooo`;o00004oooool00ol0
003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002Eooooo`;o00000_ooool2o`00017ooooo
00?o0000ooooooooool0^Oooool009Gooooo0_l00002ooooo`;o00004Oooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`07ooooo`;o0000
/?ooool009Kooooo0_l0000Dooooo`03o`000?oooooooooo00Oooooo0_l0002`ooooo`00U?ooool4
o`0001Cooooo00?o0000ooooooooool0^Oooool009Cooooo0_l0000Fooooo`?o0000^Oooool00:co
oooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool03_ooool2o`000:Wooooo
002/ooooo`03o`000?oooooooooo00kooooo0_l0002Yooooo`00Toooool3o`0001Kooooo00?o0000
ooooooooool0^Oooool009?ooooo0ol0000Fooooo`03o`000?oooooooooo0;Wooooo002Cooooo`;o
00005oooool00ol0003oooooooooo`0Aooooo`;o0000Y_ooool00:cooooo00?o0000ooooooooool0
4Oooool3o`000:Gooooo002/ooooo`?o00004_ooool2o`000:Gooooo002?ooooo`Co00006Oooool0
0ol0003oooooooooo`2iooooo`00Soooool4o`0001Wooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool05?ooool2o`000:?ooooo002@ooooo`;o00006_ooool00ol0003ooooo
ooooo`0Dooooo`?o0000X_ooool008gooooo1Ol0000Jooooo`03o`000?oooooooooo01Gooooo0_l0
002Rooooo`00SOooool3o`0001cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`0Oooooo`;o0000
V?ooool00:cooooo00?o0000ooooooooool07oooool2o`0009Sooooo002<ooooo`;o00007_ooool0
0ol0003oooooooooo`2iooooo`00S?ooool2o`0001kooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool0^Oooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`2iooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46oooo
o`03oeEEEOnYZJWooooo00Oooooo00?oMgMgo`000?l000000_ooool3o`000;_ooooo0021ooooo`Ko
00000_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool9o`00
0;Wooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06oooo
o`03ogMgMolb<S;o000000?o000000?oooooo`000?ooool0^_ooool008Wooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo1Ol00002ooooo`;o000000?oooooo`00
0?ooool09_ooool2o`0009;ooooo0029ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onY
ZJWoMgMgooooo`03ooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003ooooo
02Kooooo0_l0002Booooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooo
oooooooooooooc8b<P04ooooo`;o00002?ooool00ol0003oooooooooo`2iooooo`00ROooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`2i
ooooo`00Roooool2o`0001oooooo00?o0000ooooooooool00_l0002gooooo`00Roooool2o`0000co
oooo0_l0000Aooooo`Go0000]oooool009Wooooo0_l0000Aooooo`Go00009Oooool2o`00093ooooo
002/ooooo`Go00009Oooool2o`00093ooooo002Hooooo`?o00004Oooool00ol0003oooooooooo`0]
ooooo`;o0000R_ooool009Sooooo0ol0000Aooooo`03o`000?oooooooooo02Wooooo0_l00002oooo
o`;o0000R_ooool00:cooooo00?o0000ooooooooool0:Oooool2o`0008kooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooo
oooo00Gooooo0_l0002booooo`00[?ooool00ol0003oooooooooo`05ooooo`;o0000/_ooool00:co
oooo0ol00007ooooo`;o0000/?ooool00:cooooo00?o0000ooooooooool01Oooool4o`000;3ooooo
002/ooooo`03o`000?oooooooooo00Cooooo0ol0002booooo`00Qoooool2o`0002?ooooo00?o0000
ooooooooool01?ooool3o`000;;ooooo0027ooooo`;o00008oooool00ol0003oooooooooo`2ioooo
o`00U?ooool2o`0001Kooooo00?o0000ooooooooool0=?ooool2o`0008?ooooo002Cooooo`Co0000
5Oooool00ol0003oooooooooo`0dooooo`;o0000Poooool009?ooooo1?l0000Eooooo`03o`000?oo
oooooooo00_ooooo0_l0002/ooooo`00[?ooool3o`0000_ooooo0_l0002/ooooo`00Toooool2o`00
01Oooooo00?o0000ooooooooool0^Oooool009?ooooo0ol0000Fooooo`03o`000?oooooooooo03Ko
oooo0_l00002ooooo`;o0000OOooool009Cooooo0_l0000@ooooo`;o00001?ooool00ol0003ooooo
ooooo`0fooooo`;o00000_ooool2o`0007gooooo002Dooooo`;o00002oooool2o`0000?ooooo0_l0
0004ooooo`03o`000?oooooooooo03Sooooo0ol0001nooooo`00XOooool2o`0000Wooooo00?o0000
ooooooooool0>?ooool4o`0007gooooo0025ooooo`;o00009Oooool00ol0003oooooooooo`0=oooo
o`;o0000:oooool2o`0007gooooo0025ooooo`;o00007_ooool5o`0000;ooooo00?o0000oooooooo
ool03Oooool2o`000:[ooooo002Uooooo`Go00000_ooool3o`000;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002Aooooo`?o00002oooool3o`0000[ooooo00?o0000ooooooooool04_ooool4
o`000:?ooooo0025ooooo`;o00002_ooool3o`0000_ooooo0ol0000:ooooo`03o`000?oooooooooo
01;ooooo1?l0002Sooooo`00QOooool2o`0002Cooooo0_l0002kooooo`00Zoooool2o`000;_ooooo
002Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo01Oooooo0_l0002Pooooo`00TOooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool05Oooool4o`000:3ooooo0029ooooo`Ko000000?oooooo`000?l000000oooool00ol@413ooooo
ooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05Oooool2o`000:;ooooo
002@ooooo`;o00000oooool00ol0003oooooooooo`0=ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0
002iooooo`00T?ooool2o`0000?ooooo00?o0000ooooooooool00_l00008ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool3o`0004?ooooo0_l0001dooooo`00Poooool2o`0000cooooo00Go410@
oooooooooooooooooa0@4002ooooo`;o00002?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo04;ooooo0ol0001dooooo`00Poooool2o`0000cooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`02ooooo`;o00002?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04;ooooo0_l0
001eooooo`00Poooool2o`0000cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`?o00001ooo
ool4o`0000Kooooo00?o0000ooooooooool00_ooool2o`0001?ooooo0_l0000Yooooo`;o0000MOoo
ool008?ooooo0ol0000Cooooo`;o00004Oooool00ol0003oooooooooo`02ooooo`;o00004oooool2
o`000:3ooooo0024ooooo`;o00009_ooool00ol0003oooooooooo`04o`0001?ooooo0_l0002Poooo
o`00[?ooool00ol0003oooooooooo`04o`0001Oooooo0_l000000ooooooo0000o`00002Iooooo`00
[?ooool3o`0001[ooooo1_l0000Vooooo`;o0000LOooool008Cooooo0_l0000Aooooo`;o00004ooo
ool00ol0003oooooooooo`05ooooo`;o00004oooool2o`000003ooooool0003o000002Oooooo0_l0
001aooooo`00Q?ooool2o`00017ooooo0_l0000:ooooo`;o00001oooool00ol0003oooooooooo`05
ooooo`;o0000/_ooool008;ooooo0_l00009ooooo`;o00005?ooool2o`0000Oooooo00?o0000oooo
ooooool01?ooool2o`000;?ooooo0022ooooo`;o00002Oooool2o`00017ooooo0_l00003ooooo`;o
00001Oooool00ol0003oooooooooo`04ooooo`?o0000/_ooool009Gooooo0_l00009ooooo`;o0000
0oooool2o`0000Gooooo00?o0000ooooooooool01Oooool2o`000;;ooooo002Eooooo`;o00005Ooo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`08ooooo`?o00004oooool2
o`0009Wooooo002Oooooo`;o00002oooool3o`0000Sooooo0ol0000Cooooo`;o0000VOooool009oo
oooo0_l0000;ooooo`03o`000?oooooooooo0;Wooooo002<ooooo`;o00004?ooool2o`0000cooooo
00?o0000ooooooooool01oooool2o`000;3ooooo002<ooooo`;o00001oooool2o`0000Oooooo0_l0
000<ooooo`03o`000?oooooooooo00Oooooo0_l0000Iooooo`;o0000UOooool009Gooooo0_l0000D
ooooo`;o00009?ooool2o`0002Oooooo0_l0001/ooooo`00U?ooool2o`0001Gooooo0_l0000Voooo
o`;o00009Oooool2o`0006cooooo002Dooooo`;o00001Oooool2o`0000oooooo00?o0000oooooooo
ool07oooool2o`0000?ooooo0_l0002Cooooo`00Poooool2o`0001Kooooo0_l0000?ooooo`03o`00
0?oooooooooo01oooooo1ol0002Cooooo`00POooool4o`0001Gooooo0_l0000@ooooo`?o00008Ooo
ool5o`0009?ooooo0021ooooo`;o00005oooool2o`00013ooooo0_l0000;ooooo`;o00005_ooool2
o`0009Gooooo0021ooooo`;o00004Oooool2o`0001Kooooo00?o0000ooooooooool02_ooool2o`00
01Kooooo0_l0002Eooooo`00POooool2o`00013ooooo0ol0000Fooooo`03o`000?oooooooooo00[o
oooo0_l00014ooooo`;o0000Ioooool009?ooooo0_l0000Gooooo`03o`000?oooooooooo00;o0000
2?ooool2o`0004Cooooo0_l0001Wooooo`00[?ooool00ol0003oooooooooo`02o`0002Kooooo0_l0
002?ooooo`00[?ooool00ol0003oooooooooo`0=ooooo`;o00005_ooool2o`000003ooooool0003o
000008oooooo0020ooooo`;o00006?ooool2o`00013ooooo00?o0000ooooooooool03Oooool3o`00
01Gooooo0_l0000[ooooo`;o0000IOooool0083ooooo0_l0000Hooooo`;o00004?ooool00ol0003o
ooooooooo`0>ooooo`;o00005Oooool2o`0000;ooooo0_l0000Vooooo`?o0000IOooool00:cooooo
0ol0000>ooooo`;o00005_ooool5o`0002Kooooo0_l0001Vooooo`00POooool2o`0001Kooooo0_l0
000=ooooo`;o00000_ooool00ol0003oooooooooo`0?ooooo`;o00005Oooool3o`00093ooooo0021
ooooo`;o00003oooool2o`0000Gooooo0_l0000=ooooo`;o00000_ooool00ol0003oooooooooo`0>
ooooo`?o0000Z?ooool0083ooooo0_l0000@ooooo`;o00002oooool2o`0000_ooooo00?o0000oooo
ooooool03_ooool2o`000:Wooooo0020ooooo`;o00007Oooool2o`0000_ooooo00?o0000oooooooo
ool0^Oooool0083ooooo0_l00007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@?o
oooo1_l00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`03oooo
o`;o00002_ooool2o`0001Wooooo0ol0002<ooooo`00P?ooool2o`0000Oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q0oooool2o`000004ob4Q8Oo^k^koooooodA4A0Oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`03ooooo`;o00002_ooool4o`0001Oooooo0ol0000W
ooooo`;o0000Hoooool0087ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41002Oooool2
o`000005oooooonHV9So8B4Qonk^k_ooool00_l00006ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool04Oooool2o`00047ooooo0_l0001Sooooo`00ROooool01Ol0003ooooooooooooo
oooo000000Wooooo0_l00002ooooo`03oiRHV?lQ8B7ok^k^00;o00001Oooool00omgMgOo<S8boooo
o`04ooooo`?o0000:?ooool3o`0002Wooooo0ol0001Rooooo`00Ooooool2o`0000Sooooo0ol00000
0ooooooo0000ooooo`08ooooo`;o00000oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Xooooo`?o0000:_ooool2o`0006;ooooo001o
ooooo`;o00002?ooool01Ol@413o0000o`000?oooooo410@00oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01?ooooo0_l0000Cooooo`;o0000Sooo
ool0083ooooo0_l00007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooo
oonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`;o0000
4oooool2o`0008oooooo0020ooooo`;o00001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`04ooooo`?o
00003?ooool2o`0001Cooooo0_l000000ooooooo0000o`00002;ooooo`00P?ooool2o`0002[ooooo
00?o0000ooooooooool01?ooool3o`0000[ooooo0_l0000Fooooo`;o000000?oooooo`000?l00000
Roooool0083ooooo0_l0000Zooooo`03o`000?oooooooooo017ooooo1?l0000Cooooo`?o0000S_oo
ool00:cooooo00?o0000ooooooooool04oooool2o`0001?ooooo0_l0002?ooooo`00[?ooool3o`00
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo01?ooooo
0_l0002Tooooo`00Voooool2o`0000oooooo00?o0000ooooooooool04oooool2o`000:Cooooo002K
ooooo`;o00003oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0Foooo
o`;o0000XOooool00:cooooo00?o0000ooooooooool05_ooool2o`000:7ooooo0029ooooo`;o0000
1_ooool2o`0001Wooooo00?o0000ooooooooool0^Oooool008Wooooo0_l00006ooooo`;o00006Ooo
ool3o`000;Wooooo002Fooooo`;o00005?ooool00ol0003oooooooooo`2iooooo`00U_ooool2o`00
01Cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0;_ooool2o`0008Wooooo002/ooooo`03o`000?oooooooooo00;o0000;?oo
ool2o`0008Wooooo002/ooooo`03o`000?oooooooooo00;o0000]oooool008[ooooo0_l0000Poooo
o`03o`000?oooooooooo0;Wooooo0020ooooo`;o00002?ooool2o`00023ooooo00?o0000oooooooo
ool0;?ooool4o`0008Wooooo001oooooo`?o0000:_ooool3o`0002cooooo1?l00003ooooo`;o0000
Q?ooool007oooooo0_l0000[ooooo`03o`000?oooooooooo01Gooooo0_l0000Looooo`;o0000Q?oo
ool00:cooooo00?o0000ooooooooool05Oooool2o`0004Kooooo0_l0001Jooooo`002Oooool4o`00
0003oa0@4?oooooooooo01Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool0
0ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;o
gMgM01Kooooo00?o0000ooooooooool06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`Go000000Goooooo`000?l0003oooooodA4A002o`000003oc8b<_oMgMgooooo00kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM
00;ooooo0_l0000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000
onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1?l000000ol@413ooooooooo
o`0Booooo`002oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omg
MgOo<S8booooo`0Eooooo`03o`000?oooooooooo01Sooooo0ol000000onHV9SoMgMgooooo`04oooo
o`;o8B4Q1?ooool01_nHV9So8B4Qonk^k_ooooooA4A4ooooo`;o00000_ooool2o`000003ogMgMolb
<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8b
ooooo`02ooooo`;o00002_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03
oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool06Oooool00ol0003oooooooooo`0Dooooo`00
1_l00005ooooo`03o`000?oooooooooo013ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@
41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`05ooooo`Ko00000_ooool01Ol@
413ooooooooooooooooo410@00cooooo0_l000000oo^k^koooooooooo`07ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool06?ooool3o`000003ooooool@413ooooo00_ooooo00?oV9RH
ob4Q8Oo^k^h02Oooool00ol0003oooooooooo`0=ooooo`05oa0@4?ooooooooooooooool@41004?oo
ool01?l0003oooooooooooooool2o`0000[ooooo00Go410@oooooooooooooooooa0@400=ooooo`03
ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Dooooo`00
2oooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7o
ooooooooo`06ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`000002ooooo`;o00002?ooool2
o`000003ob4Q8Oo^k^kooooo00Kooooo00?oMgMgoc8b<_ooool05Oooool00ol0003oooooooooo`0H
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00kooooo
00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_oo
ool06Oooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05o`00
0?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`03oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00?ooooo`05o`000?ooooooooooooooool000000_ooool3o`0000Wooooo00?oMgMgofIVI_ooool0
0_ooool2o`000004ob4Q8Ol0003o<S8bolc<c1Kooooo00?o0000ooooooooool06?ooool01Ol0003o
oooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?l0003o
c<c<00oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
3oooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<01[ooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000oooooooo
ool06?ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0
003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0A
ooooo`05oa0@4?ooooooooooooooool@41000oooool2o`0000[ooooo00Co0000oooooooooooooooo
0_l00002ooooo`;o00005_ooool3o`0001Sooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00;ooooo00Co0000ooooool0003o00004?ooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o
ZJVYogMgMoooool00oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Cooooo000;
ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oo
oooooooooooooolb<S801?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@00;ooooo0ol00002ooooo`;o00005_ooool00ol0003oooooooooo`0G
ooooo`;o000000CoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo
00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooooooo
ool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05?ooool000Wooooo00?oEEEEofIV
I_l000006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00004?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool2o`0000Kooooo00GoV9RHoa0@4?l0003o8B4Qolc<c002ooooo`Ko00005oooool00ol0003o
ooooooooo`09ooooo`?o00002oooool2o`000004oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c004ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0
000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000Iooooo`03oeEE
EOmVIVKo000001Kooooo001oooooo`?o0000:_ooool00ol0003oooooooooo`09ooooo`?o00009Ooo
ool2o`000003ooooool0003o000008?ooooo001oooooo`;o0000:oooool00ol0003oooooooooo`02
ooooo`;o0000<?ooool3o`0002Oooooo0_l0001Iooooo`00[?ooool00ol0003oooooooooo`02oooo
o`;o00005_ooool2o`0001Wooooo0_l0000Wooooo`;o0000C_ooool2o`0000;ooooo0_l00005oooo
o`00R?ooool2o`0002;ooooo00?o0000ooooooooool02Oooool2o`0000cooooo1Ol0002Booooo`06
onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1Oooool008Sooooo0_l0000Rooooo`03o`000?oooooooooo
00Wooooo0_l0000<ooooo`Co0000AOooool2o`0004gooooo00CogMgMo`000?l@413oc<c<1_ooool0
00Ooooooool0001<o`0000cooooo00Cok^k^ob4Q8Ol@413ok^k^1_ooool000Oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooool3o`0000Cooooo0_l00002ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`;o00000oooool2o`000003ooooool0003ooooo
00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02_ooool01?lQ8B7oMgMgogMgMolb<S86ooooo`001oooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02Oooool2o`00
00;ooooo0_l00005ooooo`00ROooool2o`00027ooooo00?o0000ooooooooool0=?ooool3o`0008;o
oooo0029ooooo`;o00008Oooool00ol0003oooooooooo`0Fooooo`;o00007?ooool3o`0008;ooooo
002/ooooo`03o`000?oooooooooo01Kooooo0_l0002Qooooo`00U?ooool2o`0001Kooooo00?o0000
ooooooooool02_ooool2o`0000kooooo0_l0000Cooooo`;o0000R?ooool009Cooooo0_l0000Foooo
o`03o`000?oooooooooo00[ooooo0_l0000>ooooo`;o00004oooool4o`0000;ooooo0_l00022oooo
o`00[?ooool3o`0001Oooooo0_l000000ooooooo0000o`00000Eooooo`;o00000_ooool2o`0008;o
oooo0029ooooo`;o00008Oooool00ol0003oooooooooo`0Gooooo`;o000000?oooooo`000?l00000
5?ooool2o`0008Oooooo0029ooooo`;o00001?ooool2o`0001_ooooo00?o0000ooooooooool0<?oo
ool2o`0002kooooo0_l0001Gooooo`00Soooool2o`0001_ooooo00?o0000ooooooooool02oooool2
o`0005?ooooo0_l0001Gooooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool00_ooool2o`00
00Oooooo0_l0002/ooooo`00POooool2o`0000gooooo0_l0000Jooooo`03o`000?oooooooooo00;o
oooo0_l0002eooooo`00POooool2o`0002Wooooo00?o0000ooooooooool02oooool2o`0000gooooo
0_l0002Mooooo`00[?ooool00ol0003oooooooooo`02ooooo`;o00001oooool2o`0000gooooo0_l0
002Mooooo`00[?ooool00ol0003oooooooooo`02ooooo`;o00005_ooool2o`0009gooooo002/oooo
o`?o00006_ooool2o`0004Gooooo0_l0001Fooooo`00UOooool2o`0000?ooooo0_l0000@ooooo`03
o`000?oooooooooo01Sooooo0_l00017ooooo`;o0000E_ooool0093ooooo0_l00003ooooo`;o0000
0oooool2o`00013ooooo00?o0000ooooooooool02Oooool2o`0000gooooo0_l0002Oooooo`00R_oo
ool2o`0000Cooooo0_l0000Jooooo`03o`000?oooooooooo00Wooooo0_l0000Tooooo`Co0000Q_oo
ool008[ooooo0_l0000Pooooo`03o`000?oooooooooo00[ooooo0_l0000Sooooo`Oo0000Poooool0
0:cooooo00?o0000ooooooooool02_ooool2o`0002?ooooo0_l000000ooooooo0000o`000002o`00
08?ooooo002/ooooo`03o`000?oooooooooo00[ooooo0_l0000Wooooo`;o0000Q?ooool00:cooooo
00?o0000ooooooooool02_ooool2o`0000_ooooo0_l0002Pooooo`00TOooool2o`0001Wooooo0ol0
000Gooooo`;o00006_ooool2o`0008Cooooo002Aooooo`;o00006Oooool00ol0003oooooooooo`0E
ooooo`;o000000Coooooo`000?l0003o00006?ooool4o`0008;ooooo002/ooooo`03o`000?oooooo
oooo01Gooooo0_l000001?oooooo0000o`000?l0000Jooooo`;o0000P_ooool00:cooooo00?o0000
ooooooooool06Oooool2o`0001Oooooo0_l00025ooooo`00ROooool2o`00027ooooo00?o0000oooo
ooooool02Oooool3o`0000gooooo0_l0000Gooooo`;o0000QOooool008Wooooo0_l0000Qooooo`03
o`000?oooooooooo00Wooooo0ol0002]ooooo`00Ooooool2o`0002_ooooo00?o0000ooooooooool0
^Oooool007oooooo0_l0000[ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`Co0000^?ooool0
087ooooo0_l0000Yooooo`04o`000?oooooo0000o`000;Sooooo0021ooooo`;o0000:Oooool00ol0
003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`07ooooo`;o00009Oooool2o`0008Wo
oooo0020ooooo`;o00002?ooool2o`00023ooooo00?o0000ooooooooool01oooool2o`0002Gooooo
0_l00029ooooo`00P?ooool2o`0000Sooooo0_l0000<ooooo`;o00004_ooool00ol0003ooooooooo
o`0booooo`;o0000QOooool008Wooooo00Gok^k^o`000?l0003o<S8bonk^kP04ooooo`;o000000Co
8B4Qoooooooooooooooo1_l00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`08ooooo`;o0000:?ooool2o`0008Gooooo0029ooooo`05ogMgMol0003o0000oiRHV?mg
MgL01?ooool2o`000003ob4Q8Ooooooooooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A004oooo
o`;o000000?oooooogMgMolb<S801Oooool00ol0003oooooooooo`08ooooo`;o0000[oooool008Wo
oooo00Go410@o`000?l0003ooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Gooooo0_l00002oooo
o`03o`000?oooooooooo00?ooooo0ol0000Dooooo`?o0000X_ooool008Wooooo0ol000000ooooooo
0000ooooo`0<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`0Dooooo`Co0000XOooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo
01Cooooo1?l0000Hooooo`;o0000Qoooool008Wooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Doooo
o`;o00006_ooool2o`0008Oooooo0020ooooo`;o00001oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo0_l0000a
ooooo`;o0000Qoooool0083ooooo0_l00007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000<Oooool2o`000003ooooool0
003o000008Cooooo002/ooooo`03o`000?oooooooooo033ooooo1Ol00024ooooo`00POooool2o`00
02Wooooo00?o0000ooooooooool0<Oooool2o`0008Kooooo0021ooooo`?o00005_ooool2o`00013o
oooo00?o0000ooooooooool0<?ooool2o`0008Oooooo0022ooooo`;o00005_ooool2o`00013ooooo
0ol0000/ooooo`;o00000_ooool2o`0008Oooooo002/ooooo`03o`000?oooooooooo02cooooo0_l0
002;ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`04oooo
o`;o00003Oooool2o`000:Cooooo0021ooooo`;o00004_ooool2o`0001?ooooo0ol00006ooooo`;o
00003Oooool2o`000:Cooooo0021ooooo`;o00004Oooool3o`0001?ooooo0ol00005ooooo`;o0000
:oooool2o`0008Oooooo0021ooooo`;o00004Oooool2o`0001Kooooo00?o0000ooooooooool00ooo
ool2o`0002_ooooo0_l00027ooooo`00POooool2o`0002Wooooo00?o0000ooooooooool0:_ooool2
o`0008gooooo0021ooooo`;o00006oooool2o`0000cooooo0ol00003ooooo`;o00003Oooool2o`00
01Kooooo0_l0002=ooooo`00W_ooool2o`0000Kooooo0ol00003ooooo`03o`000?oooooooooo00;o
oooo0ol0000=ooooo`;o0000YOooool009oooooo0_l00005ooooo`?o00000oooool00ol0003ooooo
ooooo`02ooooo`;o00003oooool2o`000:Cooooo002Oooooo`;o00002oooool00ol0003ooooooooo
o`0Booooo`?o0000Y?ooool008;ooooo0_l0000Cooooo`;o00002oooool3o`0000Gooooo00?o0000
ooooooooool04_ooool2o`000:Gooooo0022ooooo`;o00004oooool2o`0000[ooooo1?l00005oooo
o`03o`000?oooooooooo0;Wooooo002Sooooo`;o00001oooool00ol0003oooooooooo`0^ooooo`;o
0000ROooool00:cooooo00?o0000ooooooooool09oooool2o`0000Gooooo0_l00029ooooo`00[?oo
ool3o`0002Oooooo0_l00005ooooo`;o0000ROooool009Oooooo0_l0000Cooooo`03o`000?oooooo
oooo00gooooo0_l0000Oooooo`;o0000ROooool009Oooooo0_l0000Cooooo`?o00003Oooool2o`00
01Sooooo0_l00002ooooo`;o000000?oooooo`000?l00000ROooool00:cooooo0ol0000<ooooo`;o
00006Oooool2o`0000;ooooo0_l0002<ooooo`00[?ooool00ol0003oooooooooo`0<ooooo`;o0000
6Oooool2o`00093ooooo002/ooooo`03o`000?oooooooooo0;Wooooo0024ooooo`;o00009_ooool0
0ol0003oooooooooo`2iooooo`00Q?ooool2o`0002Kooooo0ol0002iooooo`00V?ooool2o`0001;o
oooo0ol0000:ooooo`;o0000[Oooool009Sooooo0_l0000Booooo`03o`000?oooooooooo00[ooooo
0_l0000Iooooo`;o0000T_ooool00:_ooooo0_l0000<ooooo`;o00006Oooool2o`0009;ooooo002M
ooooo`;o00003?ooool2o`0000gooooo0_l0002/ooooo`00WOooool2o`0000gooooo00?o0000oooo
ooooool02_ooool5o`000:[ooooo002Mooooo`;o00003Oooool00ol0003oooooooooo`0:ooooo`Go
00005oooool5o`0008kooooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Go
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00Sooooo0_l000001?oo
oooo0000o`000?l0000Dooooo`Wo0000S_ooool0097ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00Sooooo0_l00002
ooooo`;o00005?ooool4o`0009?ooooo002Aooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo02;ooooo0_l000000ooooooo0000o`000002
o`00093ooooo002@ooooo`;o00000oooool00ol0003oooooooooo`0=ooooo`03ogMgMolb<S;ooooo
00Cooooo0ol0000Uooooo`Co0000T?ooool0093ooooo0ol00002ooooo`03o`000?oooooooooo00[o
oooo00?o0000ob4Q8Ol000000_l00005ooooo`03o`000?oooooooooo02Gooooo0_l0002Booooo`00
Q?ooool2o`0000_ooooo0_l00002ooooo`03oa0@4?oooooooooo00[ooooo00?o0000ooooooooool0
0_l00005ooooo`03o`000?oooooooooo027ooooo0_l00002ooooo`;o0000T_ooool008Cooooo0_l0
000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo027ooooo0_l0002Fooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l00006ooooo`03o`000?oooooooooo01oooooo0_l0002Hooooo`00TOooool2o`0001Wooooo00?o
0000ooooooooool07oooool2o`0009Sooooo002Aooooo`;o00006Oooool00ol0003oooooooooo`0S
ooooo`?o0000Toooool00:cooooo00?o0000ooooooooool01?ooool2o`0001[ooooo0_l000001?oo
oooo0000o`000?l0002Cooooo`00[?ooool3o`0000Cooooo0_l0000Iooooo`?o0000Uoooool00:co
oooo00?o0000ooooooooool07oooool2o`0009Sooooo0026ooooo`;o00009?ooool00ol0003ooooo
ooooo`2iooooo`00Q_ooool2o`0002Cooooo00?o0000ooooooooool0^Oooool008Kooooo0_l0000T
ooooo`03o`000?oooooooooo0;Wooooo0026ooooo`;o00009?ooool00ol0003oooooooooo`0Ooooo
o`;o0000V?ooool00:cooooo00?o0000ooooooooool07?ooool2o`000004ooooool0003o0000o`00
09Oooooo002/ooooo`03o`000?oooooooooo00;o00006_ooool2o`000004ooooool0003o0000o`00
09Oooooo0028ooooo`;o00003_ooool2o`0001;ooooo1Ol0000Hooooo`Co00000_ooool2o`0009Oo
oooo0028ooooo`;o00003_ooool2o`0001;ooooo00Co0000oooooooooooooooo0_l0000Gooooo`Co
0000Voooool009Kooooo0_l0000Dooooo`04o`000?ooooooooooooooo`;o0000]_ooool009Kooooo
0_l0000Dooooo`03o`000?oooooooooo00;o0000]oooool008Wooooo0_l0000Qooooo`03o`000?oo
oooooooo00;o00005_ooool2o`0009oooooo0029ooooo`;o00003_ooool2o`00017ooooo00?o0000
ooooooooool06?ooool2o`000004ooooool0003o0000ooooo`;o0000VOooool008[ooooo0_l0000=
ooooo`Co00003Oooool3o`0001gooooo0_l000000ooooooo0000o`00002Iooooo`00R_ooool2o`00
00oooooo0_l0000=ooooo`?o0000^oooool009Sooooo0_l0000Booooo`?o0000^Oooool008[ooooo
0_l0000<ooooo`;o00003Oooool2o`0000?ooooo00?o0000ooooooooool0^Oooool008[ooooo0_l0
000?ooooo`?o00002Oooool2o`0000?ooooo00?o0000ooooooooool0^Oooool008Wooooo0_l0000@
ooooo`?o00000_ooool2o`0000[ooooo00?o0000ooooooooool0^Oooool008Wooooo0_l0000Aoooo
o`;o000000Coooooo`000?l0003o00001_ooool2o`0000;ooooo00?o0000ooooooooool0^Oooool0
09cooooo0_l000000ooooooo0000o`000007ooooo`;o00000_ooool00ol0003oooooooooo`0Goooo
o`Co0000W_ooool009cooooo0_l0000>ooooo`03o`000?oooooooooo01Oooooo1?l0002Nooooo`00
Roooool2o`0001Wooooo0_l00004ooooo`03o`000?oooooooooo0;Wooooo002;ooooo`;o00006Ooo
ool2o`0000Cooooo00?o0000ooooooooool04oooool2o`000:Cooooo002/ooooo`?o00004oooool2
o`000:Cooooo002=ooooo`;o00004oooool2o`0000Sooooo00?o0000ooooooooool0^Oooool008co
oooo1?l0000Booooo`;o00002?ooool00ol0003oooooooooo`2iooooo`00Roooool5o`0001cooooo
00?o0000ooooooooool04?ooool2o`000:Oooooo002;ooooo`;o00007oooool00ol0003ooooooooo
o`0?ooooo`?o0000Yoooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`0?ooooo`;o000000Coooooo`000?l0003o0000Y?ooool008Wooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool04_ooool3o`000:Cooooo0029ooooo`03oa0@4?oooooooooo00;o0000
3Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
^Oooool008Wooooo00?o0000ooooooooool00_l0000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?o
MgMgoc8b<_ooool01?ooool3o`000;Wooooo0029ooooo`05o`000?ooooooooooooooool000003_oo
ool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`0;ooooo`;o00000_ooool2o`000:Sooooo0029ooooo`05oa0@4?ooooooooooooooool@4100
3_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2oooool2o`000004ooooool0003o0000o`000:Sooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0>ooooo`Co0000Yoooool008Wooooo00Kok^k^oc8b<_l0003o<S8bonk^k_ooool2
o`0000Sooooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`0@ooooo`;o0000Yoooool0
08oooooo0_l0000Kooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo00Oooooo0_l0002`ooooo`00[?ooool3o`0000Oooooo0_l0
002`ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0:oooo
o`;o0000[Oooool009;ooooo0_l0000Hooooo`03o`000?oooooooooo00[ooooo0_l0002]ooooo`00
T_ooool2o`0001Sooooo00?o0000ooooooooool0^Oooool009;ooooo0_l0000Hooooo`03o`000?oo
oooooooo0;Wooooo002Booooo`;o00006?ooool00ol0003oooooooooo`03ooooo`;o00000_ooool2
o`000;3ooooo002/ooooo`03o`000?oooooooooo00?ooooo0_l00002ooooo`;o0000/?ooool009;o
oooo0_l0000Hooooo`?o0000^Oooool009;ooooo0_l00002ooooo`;o00005?ooool00ol0003ooooo
ooooo`2iooooo`00U_ooool2o`0001Cooooo00?o0000ooooooooool00oooool2o`000;Cooooo002/
ooooo`03o`000?oooooooooo00?ooooo0_l0002dooooo`00U_ooool5o`00017ooooo00?o0000oooo
ooooool0^Oooool009Kooooo1Ol0000Aooooo`04o`000?oooooo0000o`000;Sooooo002Yooooo`;o
000000?oooooo`000?ooool00_l0002hooooo`00Uoooool2o`00013ooooo1_l0002iooooo`00Uooo
ool2o`00017ooooo1Ol0002iooooo`00X?ooool2o`0000;ooooo0_l00006ooooo`?o0000^Oooool0
0:3ooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooooooool0^Oooool009_o
oooo0_l00008ooooo`;o000000?oooooo`000?l000000_ooool00ol0003oooooooooo`2iooooo`00
Voooool2o`0000Sooooo0_l00005ooooo`03o`000?oooooooooo0;Wooooo002Qooooo`;o00001?oo
ool2o`0000?ooooo00?o0000ooooooooool0^Oooool00:7ooooo0_l00004ooooo`;o00000oooool0
0ol0003oooooooooo`2iooooo`00Woooool2o`0000?ooooo0_l00006ooooo`03o`000?oooooooooo
0;Wooooo002Oooooo`;o00000oooool2o`0000Kooooo00?o0000ooooooooool0^Oooool00:cooooo
0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
[?ooool00ol0003oooooooooo`2iooooo`00X_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o
0000ooooooooool0^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2i
ooooo`00Y?ooool00ol0003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000oooooooo
ool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0`Ooo
ool00:Cooooo00?o0000ooooooooool0`Oooool00:;ooooo00?oEEEEofIVI_l00000`oooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:[ooooo00Co410@o`00
0?l0003o0000^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooooooo
ool0^_ooool00:_ooooo00Ko0000ogMgMol0003o0000oeEEEOo^k^jgooooo`00Zoooool01_l0003o
EEEEonk^k_ooooooMgMgoeEEEKOooooo002[ooooo`03o`000?o^k^kooooo00;ooooo00?o0000oooo
ooooool0]Oooool00:_ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`2eooooo`00
Zoooool01_l0003oEEEEonk^k_ooooooMgMgofIVI[Oooooo002Zooooo`03oa0@4?l0003oMgMg00;o
000000?oIVIVonk^k_ooool0]_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.50129 .11989 Mdot
.55887 .18781 Mdot
.49291 .61005 Mdot
.53769 .61729 Mdot
.55494 .31806 Mdot
.39603 .34849 Mdot
.5073 .3985 Mdot
.55974 .91256 Mdot
.54463 .90778 Mdot
.43498 .71237 Mdot
.41214 .45242 Mdot
.47429 .99214 Mdot
.62328 .28466 Mdot
.42859 .69625 Mdot
.38982 .80319 Mdot
.51259 .71177 Mdot
.49376 .8435 Mdot
.62576 .28869 Mdot
.47132 .19669 Mdot
.69041 .50408 Mdot
.64851 .36457 Mdot
.61139 .28325 Mdot
.6383 .36262 Mdot
.63851 .3213 Mdot
.37036 .65864 Mdot
.60037 .4807 Mdot
.44313 .2517 Mdot
.49097 .20864 Mdot
.68838 .54955 Mdot
.58493 .23586 Mdot
.66301 .45095 Mdot
.57395 .8733 Mdot
.52933 .93993 Mdot
.42196 .76814 Mdot
.42126 .78084 Mdot
.67324 .57447 Mdot
.64186 .73916 Mdot
.47821 .20592 Mdot
.66626 .64794 Mdot
.4955 .98741 Mdot
.39985 .86807 Mdot
.42783 .79763 Mdot
.39106 .5101 Mdot
.47014 .09688 Mdot
.44129 .1315 Mdot
.58081 .386 Mdot
.4128 .52674 Mdot
.6208 .80054 Mdot
.59521 .60941 Mdot
.67639 .60121 Mdot
.61195 .81258 Mdot
.675 .63934 Mdot
.67339 .17058 Mdot
.39295 .55263 Mdot
.40642 .71691 Mdot
.53005 .93141 Mdot
.53886 .93632 Mdot
.51641 .81194 Mdot
.63307 .76961 Mdot
.43119 .15482 Mdot
.5885 .42732 Mdot
.37485 .25103 Mdot
.6551 .6785 Mdot
.5171 .33427 Mdot
.45743 .97252 Mdot
.56605 .88714 Mdot
.43033 .68981 Mdot
.49547 .74292 Mdot
.45496 .21635 Mdot
.65189 .36291 Mdot
.54639 .76871 Mdot
.52244 .49079 Mdot
.41905 .61635 Mdot
.45513 .75788 Mdot
.65485 .679 Mdot
.45065 .59809 Mdot
.67402 .17157 Mdot
.59129 .54308 Mdot
.68002 .61591 Mdot
.55763 .70646 Mdot
.6713 .50935 Mdot
.58952 .24737 Mdot
.53626 .61545 Mdot
.43319 .8154 Mdot
.57139 .89267 Mdot
.53485 .65863 Mdot
.55768 .32402 Mdot
.58229 .42554 Mdot
.54609 .75982 Mdot
.48741 .7535 Mdot
.36615 .5811 Mdot
.57296 .05965 Mdot
.53553 .38878 Mdot
.57685 .37902 Mdot
.53395 .38866 Mdot
.53227 .0156 Mdot
.42979 .70061 Mdot
.57658 .86097 Mdot
.6779 .17515 Mdot
.56492 .72548 Mdot
.52557 .15194 Mdot
.5718 .70245 Mdot
.44493 .97082 Mdot
.49772 .10855 Mdot
.66776 .43045 Mdot
.41709 .7493 Mdot
.51792 .8169 Mdot
.48326 .19532 Mdot
.53553 .38808 Mdot
.65661 .385 Mdot
.43829 .72995 Mdot
.54708 .57138 Mdot
.56931 .87814 Mdot
.68469 .50746 Mdot
.75209 .28887 Mdot
.45603 .69316 Mdot
.5933 .47452 Mdot
.59703 .85259 Mdot
.59423 .85243 Mdot
.61571 .78159 Mdot
.62816 .29865 Mdot
.36108 .46564 Mdot
.65249 .40993 Mdot
.69079 .53898 Mdot
.65479 .37471 Mdot
.52597 .66089 Mdot
.68339 .53953 Mdot
.58419 .24752 Mdot
.43069 .41987 Mdot
.62726 .32111 Mdot
.55096 .18871 Mdot
.43714 .96309 Mdot
.38993 .42747 Mdot
.39132 .44356 Mdot
.68902 .57073 Mdot
.67416 .66637 Mdot
.68487 .55419 Mdot
.41845 .60814 Mdot
.48729 .98203 Mdot
.39768 .84533 Mdot
.54993 .47637 Mdot
.45494 .21283 Mdot
.4982 .83856 Mdot
.68809 .49931 Mdot
.58165 .87717 Mdot
.77471 .33128 Mdot
.5426 .31094 Mdot
.58424 .43035 Mdot
.37583 .75673 Mdot
.58089 .67816 Mdot
.42211 .32312 Mdot
.6356 .31029 Mdot
.52088 .46457 Mdot
.44984 .1315 Mdot
.66477 .68163 Mdot
.66361 .66164 Mdot
.57776 .87646 Mdot
.63206 .75659 Mdot
.66721 .67755 Mdot
.6024 .53496 Mdot
.68535 .59705 Mdot
.67116 .56383 Mdot
.39886 .35042 Mdot
.54277 .18158 Mdot
.57817 .88021 Mdot
.67033 .43366 Mdot
.45336 .21995 Mdot
.68096 .64004 Mdot
.66968 .61294 Mdot
.54594 .50638 Mdot
.45801 .21786 Mdot
.57084 .37345 Mdot
.53834 .29467 Mdot
.49253 .9764 Mdot
.52687 .01132 Mdot
.45109 .1309 Mdot
.43624 .61093 Mdot
.68142 .58957 Mdot
.686 .61456 Mdot
.46396 .99456 Mdot
.49465 .75679 Mdot
.39585 .85218 Mdot
.44828 .31513 Mdot
.52915 .9236 Mdot
.51705 .00476 Mdot
.60524 .83218 Mdot
.39071 .53254 Mdot
.36222 .56187 Mdot
.68843 .49312 Mdot
.50894 .31731 Mdot
.38216 .20543 Mdot
.56103 .90764 Mdot
.40046 .87886 Mdot
.44447 .972 Mdot
.57555 .37887 Mdot
.57452 .05406 Mdot
.51151 .83213 Mdot
.45015 .66761 Mdot
.44788 .66134 Mdot
.52287 .50975 Mdot
.5649 .35531 Mdot
.59352 .07437 Mdot
.55119 .19218 Mdot
.49143 .28604 Mdot
.40757 .26035 Mdot
.5529 .52036 Mdot
.44206 .32753 Mdot
.41073 .49565 Mdot
.60486 .2519 Mdot
.59241 .52608 Mdot
.67082 .43805 Mdot
.48173 .76536 Mdot
.54978 .19252 Mdot
.59106 .52407 Mdot
.45946 .99818 Mdot
.43317 .37757 Mdot
.46223 .11261 Mdot
.51904 .96259 Mdot
.59236 .46032 Mdot
.60223 .81825 Mdot
.66709 .41407 Mdot
.67033 .54134 Mdot
.4701 .7612 Mdot
.54249 .29365 Mdot
.52661 .13869 Mdot
.54544 .46546 Mdot
.39073 .80893 Mdot
.36036 .5187 Mdot
.52933 .66376 Mdot
.45764 .35497 Mdot
.62086 .11075 Mdot
.56272 .71072 Mdot
.42362 .32547 Mdot
.36168 .45832 Mdot
.464 .21042 Mdot
.50504 .11629 Mdot
.64356 .36042 Mdot
.54184 .17479 Mdot
.38132 .20643 Mdot
.38937 .50705 Mdot
.67504 .44331 Mdot
.5464 .76851 Mdot
.59432 .84838 Mdot
.53656 .40895 Mdot
.64602 .71899 Mdot
.50461 .82119 Mdot
.54935 .76269 Mdot
.66106 .66488 Mdot
.39611 .85859 Mdot
.45519 .69063 Mdot
.52077 .35695 Mdot
.63316 .74717 Mdot
.59789 .53426 Mdot
.45834 .21861 Mdot
.41935 .78742 Mdot
.44751 .58249 Mdot
.52257 .95167 Mdot
.62873 .78317 Mdot
.58365 .65428 Mdot
.42262 .33144 Mdot
.67138 .5454 Mdot
.42816 .52966 Mdot
.57042 .70105 Mdot
.50358 .12649 Mdot
.41453 .4311 Mdot
.41576 .23091 Mdot
.66998 .59959 Mdot
.5901 .59682 Mdot
.67995 .54707 Mdot
.40746 .72653 Mdot
.44922 .75431 Mdot
.57138 .67977 Mdot
.6705 .66663 Mdot
.50037 .74875 Mdot
.50442 .21615 Mdot
.60194 .82891 Mdot
.41355 .58767 Mdot
.42681 .17973 Mdot
.68268 .59263 Mdot
.42753 .55657 Mdot
.4481 .7399 Mdot
.62595 .76683 Mdot
.46584 .9877 Mdot
.48194 .19373 Mdot
.51635 .43586 Mdot
.5669 .37958 Mdot
.68307 .46512 Mdot
.58494 .42418 Mdot
.66958 .50495 Mdot
.52465 .01324 Mdot
.62092 .7869 Mdot
.41263 .89827 Mdot
.5991 .81968 Mdot
.47439 .32832 Mdot
.65261 .72982 Mdot
.39056 .16405 Mdot
.67916 .43915 Mdot
.39525 .83064 Mdot
.78442 .35151 Mdot
.58419 .64048 Mdot
.4043 .71646 Mdot
.54511 .17725 Mdot
.58542 .85962 Mdot
.38625 .79691 Mdot
.41249 .53335 Mdot
.59227 .84133 Mdot
.59854 .53819 Mdot
.46801 .69493 Mdot
.61363 .27408 Mdot
.49244 .84658 Mdot
.63082 .31006 Mdot
.37809 .77059 Mdot
.44089 .64524 Mdot
.47871 .10794 Mdot
.42097 .76842 Mdot
.44735 .96407 Mdot
.43091 .58378 Mdot
.44995 .98389 Mdot
.36771 .35514 Mdot
.43687 .00981 Mdot
.52123 .68074 Mdot
.38802 .49108 Mdot
.44241 .83815 Mdot
.65029 .69577 Mdot
.53031 .26256 Mdot
.47947 .70202 Mdot
.49356 .349 Mdot
.51856 .81392 Mdot
.53569 .9429 Mdot
.62324 .76306 Mdot
.52931 .36827 Mdot
.60539 .25981 Mdot
.4289 .43652 Mdot
.52251 .51971 Mdot
.53288 .14737 Mdot
.39119 .41517 Mdot
.39851 .35342 Mdot
.6017 .54088 Mdot
.56392 .35495 Mdot
.64771 .13439 Mdot
.59303 .57354 Mdot
.5934 .26063 Mdot
.52538 .36387 Mdot
.52063 .94557 Mdot
.44104 .25887 Mdot
.68362 .55529 Mdot
.6136 .3006 Mdot
.54331 .4195 Mdot
.58926 .50792 Mdot
.44792 .00059 Mdot
.49221 .98687 Mdot
.66417 .70635 Mdot
.67494 .57222 Mdot
.59369 .6023 Mdot
.49159 .85597 Mdot
.67361 .59513 Mdot
.56803 .70276 Mdot
.48796 .98905 Mdot
.414 .05472 Mdot
.676 .44724 Mdot
.43316 .95536 Mdot
.44311 .97604 Mdot
.42476 .94875 Mdot
.52028 .56019 Mdot
.56876 .69333 Mdot
.39116 .81271 Mdot
.53339 .94104 Mdot
.51944 .56959 Mdot
.66817 .47326 Mdot
.58251 .61837 Mdot
.39832 .32034 Mdot
.51976 .14431 Mdot
.56705 .87498 Mdot
.50777 .12047 Mdot
.6418 .74433 Mdot
.63014 .74465 Mdot
.63709 .36135 Mdot
.67231 .6841 Mdot
.62838 .3278 Mdot
.37832 .7363 Mdot
.7584 .29603 Mdot
.60335 .8043 Mdot
.43639 .1524 Mdot
.52072 .4947 Mdot
.36334 .52421 Mdot
.55981 .7329 Mdot
.49054 .34312 Mdot
.47301 .99853 Mdot
.65327 .36725 Mdot
.48904 .69364 Mdot
.44439 .73685 Mdot
.59757 .48477 Mdot
.43086 .28848 Mdot
.62188 .80105 Mdot
.66324 .37985 Mdot
.38878 .17001 Mdot
.46083 .99344 Mdot
.46516 .8552 Mdot
.65504 .14974 Mdot
.47513 .86088 Mdot
.53139 .27811 Mdot
.52773 .26479 Mdot
.43992 .46732 Mdot
.52809 .94963 Mdot
.47398 .99164 Mdot
.43984 .26093 Mdot
.54669 .45945 Mdot
.40951 .52907 Mdot
.52261 .6953 Mdot
.3812 .78547 Mdot
.56855 .34709 Mdot
.6747 .54107 Mdot
.54901 .53029 Mdot
.42876 .28957 Mdot
.42745 .52126 Mdot
.56507 .3416 Mdot
.42761 .78704 Mdot
.41681 .36577 Mdot
.49618 .29337 Mdot
.36324 .6083 Mdot
.49459 .97739 Mdot
.50296 .4981 Mdot
.41764 .76784 Mdot
.51637 .81919 Mdot
.49054 .12085 Mdot
.57936 .63389 Mdot
.45092 .22608 Mdot
.3649 .59674 Mdot
.52769 .00704 Mdot
.52977 .15072 Mdot
.73361 .2571 Mdot
.46929 .09515 Mdot
.49293 .28352 Mdot
.5064 .95103 Mdot
.38451 .77338 Mdot
.41836 .37071 Mdot
.6198 .31947 Mdot
.65588 .14572 Mdot
.54803 .4791 Mdot
.49601 .67758 Mdot
.54955 .32328 Mdot
.67337 .52751 Mdot
.57146 .66911 Mdot
.57395 .05671 Mdot
.44929 .30901 Mdot
.39535 .59169 Mdot
.44764 .84501 Mdot
.52105 .34137 Mdot
.43471 .60503 Mdot
.48342 .77156 Mdot
.55446 .91852 Mdot
.44214 .65521 Mdot
.68455 .59418 Mdot
.54381 .16647 Mdot
.46282 .10816 Mdot
.68219 .53938 Mdot
.66788 .4966 Mdot
.4848 .85446 Mdot
.44308 .73446 Mdot
.53475 .94449 Mdot
.40496 .8946 Mdot
.41787 .38992 Mdot
.65799 .71937 Mdot
.58455 .61734 Mdot
.48 .84902 Mdot
.68457 .54746 Mdot
.51859 .14108 Mdot
.48687 .20076 Mdot
.58969 .50341 Mdot
.43357 .80755 Mdot
.36112 .42143 Mdot
.39848 .34452 Mdot
.46063 .63296 Mdot
.39231 .4547 Mdot
.56386 .69352 Mdot
.52359 .52629 Mdot
.50329 .72397 Mdot
.39481 .5943 Mdot
.39084 .54968 Mdot
.45367 .68288 Mdot
.59608 .53688 Mdot
.56349 .89057 Mdot
.54522 .29207 Mdot
.4979 .12072 Mdot
.43073 .27221 Mdot
.51591 .25541 Mdot
.514 .60669 Mdot
.74181 .26479 Mdot
.50769 .63295 Mdot
.54629 .1676 Mdot
.57693 .85296 Mdot
.67303 .55709 Mdot
.46028 .20893 Mdot
.68381 .5684 Mdot
.46772 .99423 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool009[ooooo0_l00008ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`02ooooo`;o00000_ooool2o`000;7ooooo002Gooooo`;o00002oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o0000/Oooool009Oooooo0_l0000;
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`000;;ooooo002Roooo
o`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool01Oooool4o`000;3ooooo002/ooooo`03
o`000?oooooooooo00Oooooo0_l0002`ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?oo
ool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000
^Oooool008oooooo0_l0000Kooooo`03o`000?oooooooooo01Gooooo0_l0002Rooooo`00Soooool2
o`0001_ooooo00?o0000ooooooooool05Oooool2o`000:;ooooo002/ooooo`03o`000?oooooooooo
01Gooooo0_l0002Rooooo`00[?ooool00ol0003oooooooooo`0Eooooo`;o0000X_ooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool06oooool2o`0009cooooo002/ooooo`?o00006oooool2o`0009cooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002Qooooo`;o00002Oooool00ol0003oooooooooo`2iooooo`00XOooool3o`0000Sooooo
00?o0000ooooooooool0^Oooool00:;ooooo0_l00008ooooo`?o0000^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool009oooooo0_l00004ooooo`;o
00001?ooool2o`0002Kooooo0_l0002Cooooo`00Woooool2o`0000Cooooo0_l00004ooooo`;o0000
9_ooool2o`0009?ooooo002Oooooo`;o00002oooool3o`000;Wooooo0029ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Gooooo0ol0002iooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool00_l000000ooooooo0000
o`000003o`000;Sooooo0021ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00gooooo
00?oZJVYoeEEEOooool02?ooool01Ol0003oooooo`000?l0003ooooo00Go0000^?ooool008Wooooo
00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_oo
ool01?ooool3o`000;Wooooo0029ooooo`05o`000?ooooooooooooooool000002_ooool2o`000004
ooooool0003o0000olc<c0Cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`?o0000^Oooool0
08Wooooo00Go410@oooooooooooooooooa0@400:ooooo`;o000000Coooooo`000?l0003oMgMg1?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02gooooo0_l0002:ooooo`00ROooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0;Oooool2o`0008[ooooo0029ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo00Gooooo
0_l0002booooo`00[?ooool00ol0003oooooooooo`03ooooo`Co0000/_ooool00:cooooo00?o0000
ooooooooool00oooool2o`0002_ooooo0_l00027ooooo`00[?ooool00ol0003oooooooooo`03oooo
o`;o00000_ooool2o`0002Oooooo0_l00027ooooo`00Uoooool2o`0001?ooooo0ol00005ooooo`Co
00009oooool2o`0008Oooooo002Eooooo`Co00004oooool00ol0003oooooooooo`05ooooo`?o0000
/Oooool009Gooooo0_l0000Eooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo0027ooooo`;o00008oooool00ol0003oooooooooo`2iooooo`00Qoooool2o`0002?o
oooo00?o0000ooooooooool02oooool3o`000:_ooooo0027ooooo`;o00008oooool00ol0003ooooo
ooooo`0;ooooo`?o0000:?ooool2o`00087ooooo0027ooooo`;o00008oooool00ol0003ooooooooo
o`0fooooo`;o0000POooool00:cooooo0ol0000:ooooo`?o0000:Oooool3o`00083ooooo002Coooo
o`;o00005oooool00ol0003oooooooooo`0:ooooo`?o0000:_ooool2o`00083ooooo002Cooooo`;o
00005oooool00ol0003oooooooooo`0;ooooo`;o0000[?ooool00:cooooo00?o0000ooooooooool0
2oooool2o`000:cooooo002/ooooo`03o`000?oooooooooo00gooooo0_l000000ooooooo0000o`00
002Wooooo`00[?ooool00ol0003oooooooooo`0=ooooo`;o000000?oooooo`000?l00000Yoooool0
0:Kooooo0_l00004ooooo`03o`000?oooooooooo00gooooo0_l0002Zooooo`00X_ooool2o`0000;o
oooo0_l00004ooooo`03o`000?oooooooooo0;Wooooo002Rooooo`;o00000oooool2o`0000?ooooo
0ol0002iooooo`00Yoooool2o`0000?ooooo00?o0000ooooooooool0^Oooool008Cooooo0ol0000M
ooooo`;o00001_ooool00ol0003oooooooooo`2iooooo`00Q?ooool3o`0001Oooooo1?l00002oooo
o`;o00000oooool2o`000003ooooool0003ooooo0;[ooooo002Mooooo`Go00001oooool2o`000003
ooooool0003ooooo0;[ooooo002Mooooo`;o00003Oooool3o`000;Wooooo002Mooooo`?o00003?oo
ool3o`000;Wooooo002Looooo`Co00003?ooool00ol0003oooooooooo`2iooooo`00W?ooool2o`00
00kooooo0ol0002iooooo`00Voooool2o`0000oooooo00?o0000ooooooooool0^Oooool0093ooooo
0_l00009ooooo`;o00003oooool00ol0003oooooooooo`2iooooo`00T?ooool2o`0001[ooooo00?o
0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool06Oooool2o`0009kooooo002/oooo
o`03o`000?oooooooooo01Wooooo0_l0002Nooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2i
ooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0^Oooool008Wooooo1_l00002ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Sooooo1?l0002M
ooooo`00P_ooool2o`0000gooooo00Go0000ooooooooooooooooo`000003ooooo`;o00002_ooool0
0omgMgOo<S8booooo`04ooooo`?o00006?ooool4o`0000?ooooo0_l0002Hooooo`00P_ooool2o`00
00gooooo00Go0000ooooooooooooooooo`000003ooooo`;o00001oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Gooooo00?o0000ooooooooool00_ooool2o`0001_ooooo0_l0002Hooooo`00TOooool0
1Ol@413ooooooooooooooooo410@00;ooooo0_l00008ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool00_ooool2o`0004Kooooo0_l0001]ooooo`00SOooool2o`0000;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`02ooooo`;o00002?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo01_ooooo0_l00002ooooo`;o0000:Oooool2o`0006gooooo002=ooooo`;o00000_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo0_l00008ooooo`Co00001_ooool00ol0003ooooooooo
o`06ooooo`?o00004_ooool2o`0000;ooooo0_l0000[ooooo`;o0000Joooool00:cooooo00?o0000
ooooooooool01_ooool3o`0004?ooooo0_l0001[ooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00UOooool2o`0001Gooooo00?o0000ooooooooool08_ooool2o`0009Gooooo002Eooooo`;o0000
5Oooool3o`0002;ooooo0_l0002Eooooo`00[?ooool00ol0003oooooooooo`07ooooo`;o0000/?oo
ool00:cooooo00?o0000ooooooooool01oooool2o`0001Sooooo0_l0002Fooooo`00ZOooool2o`00
0003ooooool0003ooooo02;ooooo0_l00002ooooo`;o0000T_ooool009Gooooo0_l0000Booooo`;o
000000?oooooo`000?ooool09_ooool3o`0002Sooooo0_l0001Wooooo`00U?ooool3o`0001Gooooo
00?o0000ooooooooool02oooool2o`0001Wooooo0_l0000Xooooo`;o0000Ioooool009Cooooo0_l0
000Dooooo`?o00002oooool4o`000:cooooo002Zooooo`?o00002oooool4o`0004Gooooo0_l0001U
ooooo`00[?ooool3o`0002;ooooo0_l00003ooooo`;o0000:Oooool2o`0006Gooooo002/ooooo`03
o`000?oooooooooo02;ooooo0_l00003ooooo`;o0000T?ooool00:cooooo00?o0000ooooooooool0
^Oooool009_ooooo0_l0000?ooooo`03o`000?oooooooooo02Sooooo0ol0002>ooooo`00Voooool2
o`0000oooooo00?o0000ooooooooool02oooool2o`0001_ooooo0ol0002>ooooo`00V_ooool2o`00
013ooooo00?o0000ooooooooool02oooool2o`000:cooooo002Jooooo`;o00004?ooool00ol0003o
ooooooooo`02o`0000gooooo0_l0000Cooooo`;o0000Toooool008[ooooo0_l0000Pooooo`03o`00
0?oooooooooo00;o00003Oooool2o`0001?ooooo0_l000001?oooooo0000o`000?ooool2o`0008go
oooo002:ooooo`;o00001_ooool2o`0001Sooooo0ol0000=ooooo`;o000000?oooooo`000?l00000
5Oooool2o`000003ooooool0003o000008gooooo002Booooo`;o00001?ooool2o`0000Wooooo0_l0
0007ooooo`03o`000?oooooooooo00gooooo0_l000000ooooooo0000o`00000Eooooo`;o0000T?oo
ool009;ooooo0_l00004ooooo`;o00002Oooool2o`0000Oooooo00?o0000ooooooooool09oooool2
o`0002kooooo0_l0001Pooooo`00T_ooool2o`0001Sooooo00?o0000ooooooooool00_ooool2o`00
05?ooooo0_l0001Pooooo`00[?ooool00ol0003oooooooooo`02ooooo`;o0000]Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:Sooooo0_l00002ooooo`03o`000?oooooooooo00Cooooo0_l0
000<ooooo`;o0000YOooool008[ooooo0_l0000Looooo`;o00000_ooool00ol0003oooooooooo`04
ooooo`;o00003?ooool2o`000:Gooooo0029ooooo`?o00007Oooool2o`000003ooooool0003ooooo
01Cooooo0_l0002Tooooo`00ROooool3o`0001gooooo0_l000001?oooooo0000o`000?l0000Coooo
o`;o0000AOooool2o`0005gooooo0020ooooo`;o00002?ooool2o`0001;ooooo0_l0000<ooooo`03
o`000?oooooooooo01;ooooo0_l00016ooooo`;o0000GOooool0083ooooo0_l00008ooooo`;o0000
4_ooool2o`0000cooooo00?o0000ooooooooool00oooool2o`0000gooooo0_l0002Uooooo`00[?oo
ool00ol0003oooooooooo`03ooooo`;o00009Oooool4o`0008_ooooo002/ooooo`03o`000?oooooo
oooo00Gooooo0_l0000Sooooo`Oo0000R?ooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02
ooooo`;o000000?oooooob4Q8OlQ8B401?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgM
g@05ooooo`03o`000?oooooooooo00Gooooo0_l0000Sooooo`;o00000_ooool3o`0008Sooooo0029
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool3o`0000;o8B4Q1?ooool01OnHV9So8B4Qonk^
k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`06ooooo`;o0000
9oooool2o`0008Sooooo0021ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00?ooooo
0_l00007ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`06ooooo`;o00003?ooool2o`000:?ooooo0029ooooo`05o`000?ooooooooooooooool00000
3Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Dooooo`;o0000
6_ooool2o`0008Oooooo0029ooooo`05o`000?ooooooooooooooool000002?ooool2o`0000Cooooo
00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool04oooool2o`000003ooooool0003o000001Sooooo1?l00025ooooo`00ROooool01Ol@413ooooo
oooooooooooo410@00Sooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Cooooo`;o000000?oooooo`000?l000006_ooool2o`0008Go
oooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Gooooo`;o00005oooool2o`00
08Oooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7o
c<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo00Sooooo0_l0000=ooooo`;o00005oooool2
o`0008Oooooo002@ooooo`;o00006_ooool00ol0003oooooooooo`08ooooo`;o0000[oooool0093o
oooo0_l0000Jooooo`03o`000?oooooooooo0;Wooooo002/ooooo`04o`000?oooooo0000o`000;So
oooo002/ooooo`Co0000^?ooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool02Oooool2o`0002Cooooo0_l00028oooo
o`00[?ooool00ol0003oooooooooo`09ooooo`;o00009?ooool2o`0008Sooooo0028ooooo`;o0000
8_ooool00ol0003oooooooooo`0dooooo`;o0000Poooool008Sooooo0_l0000Rooooo`03o`000?oo
oooooooo00_ooooo0_l0000Wooooo`;o0000Poooool007kooooo0_l0000Eooooo`;o00005Oooool0
0ol0003oooooooooo`0;ooooo`;o0000[?ooool007kooooo0_l0000Eooooo`;o00005Oooool3o`00
01Sooooo0ol0002Nooooo`00Qoooool2o`0002?ooooo00?o0000ooooooooool06?ooool4o`0009go
oooo0027ooooo`;o00001_ooool2o`0001_ooooo00?o0000ooooooooool06?ooool4o`0001Sooooo
0_l00023ooooo`00Soooool2o`0001_ooooo00?o0000ooooooooool06?ooool2o`0001[ooooo0ol0
0022ooooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool00_ooool2o`00037ooooo0_l00022
ooooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool00_ooool2o`00037ooooo0_l000000ooo
oooo0000o`00001oooooo`00R?ooool2o`0002;ooooo00?o0000ooooooooool0=Oooool5o`0007oo
oooo0028ooooo`;o00008_ooool00ol0003oooooooooo`0fooooo`;o0000POooool00:cooooo00?o
0000ooooooooool0=oooool2o`00083ooooo002?ooooo`;o00006oooool3o`0003;ooooo0_l00003
ooooo`;o0000P?ooool008Sooooo0_l00005ooooo`;o00006oooool00ol0003oooooooooo`0boooo
o`;o0000QOooool007kooooo0_l00008ooooo`;o00008_ooool00ol0003oooooooooo`2iooooo`00
2Oooool4o`000003oa0@4?oooooooooo01Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd03ooo
ool01_o^k^ko<S8bo`000?lb<S;ok^k^ooooo`;o00000_ooool2ob4Q8@Cooooo1Ol00004ooooo`05
odA4A?l0003o0000oc8b<_oMgMd05_ooool00ol0003oooooooooo`0<ooooo`;o00002_ooool00oo^
k^ko<S8bo`000002o`0000Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;o
gMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`00
0?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003o
k^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd06?ooool4o`000003oa0@4?oooooooooo
01;ooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMg
Molb<S;ooooo01Gooooo00?o0000ooooooooool00oooool2o`0000Oooooo0_l0000:ooooo`03ogMg
MonHV9Sooooo00;o00001Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03
ogMgMolb<S;ooooo00;ooooo0_l0000:ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46
ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool06Oooool00ol0003oooooooooo`0D
ooooo`001_l00005ooooo`03o`000?oooooooooo013ooooo1_l00002ooooo`05oa0@4?oooooooooo
ooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00Gooooo1_l00002
ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`05ooooo`Ko00000_oo
ool01_l@413ooooooooooooooooo410@ooooo`;o00002Oooool00onHV9So8B4Qonk^kP09ooooo`03
o`000?oooooooooo00;o00004_ooool00ol0003oooooooooo`03ooooo`;o00001oooool2o`0000[o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00Co0000oooo
oooooooooooo0_l0000:ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`0=ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?oo
ool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8b
ooooo`0>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0>ooooo`06
o`000?ooooooooooooooool0003ooooo0_l0000:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00CoMgMg
oc8b<_oooooooooo0_l0000Booooo`03o`000?oooooooooo00cooooo0_l0000:ooooo`05o`000?oo
ooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00kooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool06Oooool00ol0
003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`05_ooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool0
0omgMgOoIVIVooooo`03ooooo`03o`000?lQ8B7o000000;o00003oooool01Ol0003ooooooooooooo
oooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool0
00003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06_ooool00ol0
003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05oa0@4?oooooooooooooo
ool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo017ooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@
400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06?ooool3o`0000gooooo0_l0
0009ooooo`03oa0@4?oooooooooo00;o00003oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;o00003oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool0
4Oooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0
003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0<ooooo`?o00002Oooool00omgMgOoV9RH
ooooo`02o`0000_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo017o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo01Cooooo0009ooooo`03oeEEEOmVIVKo000001[ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c004ooooo`Co00005oooool00ol0003oooooooooo`0<ooooo`;o00002_ooool01_o^
k^ko<S8bo`000?lb<S;ok^k^ooooo`;o00002?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo
1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00013ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0001Wooooo00?oEEEEofIVI_l000005_ooool00:co
oooo00?o0000ooooooooool07Oooool3o`0009Wooooo002/ooooo`03o`000?oooooooooo01gooooo
0_l0002Jooooo`00Qoooool2o`0002?ooooo00?o0000ooooooooool01?ooool2o`000:Sooooo0_l0
0002ooooo`;o00001Oooool008Oooooo0_l0000Sooooo`03o`000?oooooooooo00?ooooo0ol0000e
ooooo`;o0000LOooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Gooooo002>ooooo`;o00007?oo
ool3o`0000?ooooo0_l0000_ooooo`;o00001Oooool2o`0007;ooooo00CogMgMo`000?l@413oc<c<
1_ooool000Ooooooool0001<o`0000cooooo00Cok^k^ob4Q8Ol@413ok^k^1_ooool000Oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooooooo`;o0000
0_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool01?l0003oooooooooooooool2o`0000;ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool01?lQ8B7o
MgMgogMgMolb<S86ooooo`001oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool09_ooool01?l0003oooooooooooooool2o`0002?ooooo00?o0000oooo
ooooool03?ooool2o`0000cooooo0_l0000;ooooo`03o`000?oooooooooo00_ooooo0_l00003oooo
o`?o00004oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool02Oooool2o`0000;ooooo0_l00005ooooo`00Qoooool3o`0002;ooooo00?o0000oooooooo
ool01?ooool2o`0000Kooooo0_l0000<ooooo`;o00006Oooool2o`0000?ooooo0_l0001mooooo`00
R?ooool2o`0002;ooooo00?o0000ooooooooool01?ooool2o`0001Cooooo0_l0000Iooooo`;o0000
P_ooool00:cooooo00?o0000ooooooooool0^Oooool007gooooo0_l0000]ooooo`03o`000?oooooo
oooo0;Wooooo001mooooo`;o00005Oooool2o`0001Kooooo00?o0000ooooooooool01?ooool2o`00
00Sooooo0_l0002Yooooo`00O_ooool2o`0001Cooooo0_l0000Fooooo`?o00001?ooool2o`0000So
oooo0_l0000;ooooo`;o0000W?ooool007kooooo0_l0000?ooooo`;o00006oooool00ol0003ooooo
ooooo`04ooooo`;o00005Oooool2o`0001Wooooo0_l00021ooooo`00S_ooool3o`0000?ooooo0_l0
000Fooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`;o00003?ooool2o`0001Wooooo0_l0
0021ooooo`00Qoooool2o`0000Gooooo0ol00003ooooo`;o00005_ooool00ol0003oooooooooo`0=
ooooo`;o00003_ooool2o`0009[ooooo0027ooooo`;o00001_ooool2o`0001_ooooo00?o0000oooo
ooooool07?ooool4o`0009Wooooo002/ooooo`03o`000?oooooooooo01cooooo1?l0000Iooooo`;o
000000?oooooo`000?l00000Noooool00:cooooo00?o0000ooooooooool06oooool5o`0001Gooooo
0ol000001?oooooo0000o`000?ooool2o`0007_ooooo002/ooooo`03o`000?oooooooooo01_ooooo
0_l0000Hooooo`?o0000POooool008Sooooo0_l0000Rooooo`03o`000?oooooooooo03Gooooo0_l0
00000ooooooo0000o`000003o`0007cooooo0028ooooo`;o00008_ooool3o`0003Sooooo1Ol0001l
ooooo`00R?ooool2o`0002;ooooo00?o0000ooooooooool0>Oooool3o`0007gooooo002Dooooo`;o
00005_ooool00ol0003oooooooooo`0fooooo`;o000000Coooooo`000?l0003o0000OOooool007ko
oooo0_l0000Dooooo`;o00005_ooool00ol0003oooooooooo`03ooooo`;o0000<Oooool2o`00087o
oooo001nooooo`;o0000;?ooool00ol0003oooooooooo`03ooooo`;o0000<?ooool2o`0008;ooooo
002/ooooo`03o`000?oooooooooo03Gooooo0_l00022ooooo`00[?ooool00ol0003oooooooooo`03
ooooo`;o0000=?ooool4o`0007cooooo002/ooooo`03o`000?oooooooooo00?ooooo0_l00007oooo
o`;o00003Oooool2o`0001Wooooo0_l000000ooooooo0000o`000002o`0007cooooo002/ooooo`?o
00003?ooool2o`0000gooooo0_l0000Iooooo`;o0000POooool00:cooooo00?o0000ooooooooool0
=_ooool2o`00087ooooo001oooooo`;o00006Oooool2o`00013ooooo00?o0000ooooooooool0^Ooo
ool007oooooo0_l0000Dooooo`;o00000oooool2o`00013ooooo00?o0000ooooooooool0^Oooool0
08oooooo0_l00004ooooo`;o00005Oooool00ol0003oooooooooo`2iooooo`00ROooool2o`0000Co
oooo0_l0000Kooooo`03o`000?oooooooooo03Sooooo0_l0001oooooo`00ROooool2o`00027ooooo
00?o0000ooooooooool0=_ooool5o`0007kooooo001oooooo`;o00002?ooool2o`00013ooooo0_l0
000?ooooo`03o`000?oooooooooo01[ooooo0_l0000Jooooo`;o000000Coooooo`000?l0003o0000
OOooool007oooooo0_l0000Jooooo`;o00003oooool3o`0001[ooooo0_l0000Iooooo`Co000000?o
ooooo`000?l00000OOooool00:cooooo00?o0000ooooooooool06oooool2o`0001Sooooo1?l00020
ooooo`00U_ooool2o`0001Cooooo00Co0000oooooooooooooooo0_l0000Hooooo`;o0000W?ooool0
07kooooo0_l0000Aooooo`;o00000oooool2o`00017ooooo0_l000000ooooooo0000ooooo`02oooo
o`;o00006Oooool2o`0009_ooooo001nooooo`;o00004Oooool2o`0000Cooooo0_l0000@ooooo`;o
000000?oooooo`000?ooool07Oooool2o`0001Oooooo0_l00022ooooo`00TOooool2o`0000Cooooo
0_l0000Cooooo`03o`000?oooooooooo00Wooooo0_l0000Zooooo`;o000000?oooooo`000?l00000
0_l0001mooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo0_l00002ob4Q8@Cooooo
1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`09ooooo`;o
00003Oooool2o`0001kooooo1?l0001mooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo00Wooooo0_l0000=ooooo`;o0000Woooool008Wooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`00
0;Wooooo0029ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0^Oooool008Wooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005
ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05oa0@4?ooooooooooooooool@41003oooool0
1_l0003oooooo`000?l0003oooooo`0000Wooooo00Co0000ooooool0003o00005_ooool2o`000:3o
oooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01_l0003o^[ZjoooooonHV9So410@
ooooo`;o000000?oooooo`000?ooool02?ooool01?l0003oooooo`000?l0000Fooooo`;o0000X?oo
ool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
1?ooool4o`0000Kooooo00?o0000ooooooooool06?ooool2o`0001cooooo1?l0001oooooo`00[?oo
ool00ol0003oooooooooo`0Hooooo`;o00007?ooool4o`0007oooooo002Hooooo`;o00004_ooool0
0ol0003oooooooooo`2iooooo`00V?ooool2o`0001;ooooo00?o0000ooooooooool0<oooool2o`00
08Cooooo002/ooooo`?o0000<oooool2o`0008Cooooo002Hooooo`;o00004_ooool00ol0003ooooo
ooooo`0Hooooo`;o0000Woooool0087ooooo0_l0000Eooooo`;o00004_ooool00ol0003ooooooooo
o`08ooooo`;o00003_ooool2o`0009oooooo0021ooooo`;o00005oooool2o`00013ooooo00?o0000
ooooooooool01Oooool2o`000003ooooool0003o000002Wooooo0_l00024ooooo`00V_ooool2o`00
013ooooo00?o0000ooooooooool01Oooool3o`0002[ooooo0ol00024ooooo`00Voooool2o`0000oo
oooo00?o0000ooooooooool01_ooool2o`0002[ooooo0_l000001?oooooo0000o`000?l00021oooo
o`00Voooool2o`0000oooooo00?o0000ooooooooool05?ooool2o`0001oooooo0ol00021ooooo`00
[?ooool00ol0003oooooooooo`0Dooooo`;o0000Xoooool00:cooooo0ol0002iooooo`00Z_ooool3
o`0001Kooooo0_l000000ooooooo0000o`00000Gooooo`;o00000_ooool2o`0008?ooooo002Loooo
o`;o00003?ooool3o`0000Kooooo0_l0000>ooooo`;o000000?oooooo`000?l000005oooool2o`00
0004ooooool0003o0000o`0008?ooooo002Looooo`;o00003_ooool00ol0003oooooooooo`04oooo
o`;o0000;Oooool4o`0008;ooooo002/ooooo`03o`000?oooooooooo03Gooooo0_l00022ooooo`00
UOooool2o`0000Kooooo0_l0000=ooooo`03o`000?oooooooooo0;Wooooo002Eooooo`;o00001_oo
ool2o`0000;ooooo0_l00005ooooo`;o00000_ooool00ol0003oooooooooo`04ooooo`;o00003?oo
ool3o`000:Cooooo002Dooooo`;o00001oooool2o`0000;ooooo0_l00005ooooo`;o00000_ooool0
0ol0003oooooooooo`04ooooo`;o00003?ooool3o`0001Wooooo0_l00029ooooo`00U?ooool2o`00
01Kooooo0ol0000Dooooo`;o00006?ooool2o`0008Wooooo002Dooooo`;o00003oooool2o`0000Go
oooo00?o0000ooooooooool04oooool3o`000:?ooooo002Uooooo`;o00001Oooool00ol0003ooooo
ooooo`0@ooooo`;o000000Coooooo`000?l0003o00007Oooool2o`0008Cooooo002/ooooo`03o`00
0?oooooooooo013ooooo0_l0000Qooooo`;o0000Q?ooool009Kooooo0_l0000Dooooo`04o`000?oo
ooooooooooooo`;o00003_ooool2o`000:Kooooo002<ooooo`;o00002?ooool2o`0001Cooooo00Co
0000oooooooooooooooo0_l0000>ooooo`;o0000Y_ooool008cooooo0ol0000Mooooo`03o`000?oo
oooooooo02gooooo0_l00002ooooo`;o0000Q_ooool008gooooo0_l0000Mooooo`03o`000?oooooo
oooo02gooooo0_l00002ooooo`;o0000Q_ooool00:cooooo0ol0000Booooo`;o0000YOooool008go
oooo0_l0000Mooooo`?o00004_ooool2o`000:Gooooo002=ooooo`;o00002?ooool2o`0001?ooooo
00?o0000ooooooooool0;oooool2o`0008Sooooo002Gooooo`Co00004Oooool00ol0003ooooooooo
o`0@ooooo`;o00007Oooool2o`0008Sooooo0023ooooo`;o00005?ooool2o`00017ooooo00?o0000
ooooooooool04?ooool2o`000:Oooooo0023ooooo`;o00005?ooool3o`00013ooooo00?o0000oooo
ooooool0:oooool2o`0008cooooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool2o`00
0003ob4Q8Ooooooooooo00?ooooo00GoA4A4o`000?l0003o<S8bomgMg@03ooooo`?o0000;Oooool2
o`0008cooooo002Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00_ooool3o`0002[ooooo0_l000000ooooooo0000o`00002<ooooo`00T?ooool2o`00
00?ooooo00?o410@ooooooooool03_ooool00ol0003oooooooooo`03ooooo`;o0000:Oooool5o`00
08cooooo002@ooooo`;o00000oooool00ol0003oooooooooo`0=ooooo`03ogMgMolb<S;ooooo00Co
oooo0ol0000Yooooo`;o0000S_ooool0097ooooo00Go0000ooooooooooooooooo`000005ooooo`;o
00001Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;o00000oooool00ol0003oooooooooo`2ioooo
o`00Poooool2o`0000cooooo00Go410@oooooooooooooooooa0@4005ooooo`Co00000oooool00ol0
003oooooooooo`02ooooo`;o000000Coooooo`000?l0003o0000:_ooool2o`0008oooooo0023oooo
o`;o00003?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo0_l00003ooooo`;o00001_ooool3
o`0000kooooo0_l0000Jooooo`;o0000Soooool0097ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`Co00001_ooool00ol0003oooooooooo`0<ooooo`?o00005_ooool2o`0009;ooooo002@oooo
o`;o00005?ooool2o`0000Cooooo00?o0000ooooooooool03Oooool2o`0001Kooooo0ol0002Aoooo
o`00Poooool2o`0000_ooooo1?l0000Booooo`;o00001?ooool00ol0003oooooooooo`0<ooooo`;o
00006?ooool4o`0008oooooo0023ooooo`Co00002_ooool3o`0001;ooooo0_l00004ooooo`03o`00
0?oooooooooo00cooooo0_l0000Jooooo`;o0000Soooool008Gooooo0_l0000Oooooo`;o00001?oo
ool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Booooo`;o00006?ooool00ol0
003oooooooooo`0Sooooo`;o00000_ooool2o`00093ooooo0024ooooo`;o00003?ooool2o`0001So
oooo00?o0000ooooooooool08oooool2o`0000;ooooo0_l0002@ooooo`00Q?ooool2o`0000_ooooo
0_l000000ooooooo0000o`00000Fooooo`03o`000?oooooooooo02Cooooo0_l0002Cooooo`00TOoo
ool2o`000003ooooool0003o000001Kooooo00?o0000ooooooooool09?ooool2o`0009?ooooo002/
ooooo`03o`000?oooooooooo0;Wooooo0026ooooo`;o00003?ooool2o`0001Kooooo00?o0000oooo
ooooool0^Oooool008Kooooo0_l0000<ooooo`;o00005_ooool3o`0002Cooooo0ol0002Booooo`00
Qoooool2o`0002?ooooo00?o0000ooooooooool07oooool2o`0000?ooooo0ol0002Booooo`00Qooo
ool2o`0002?ooooo00?o0000ooooooooool07oooool2o`0009Sooooo0027ooooo`;o00003Oooool2
o`0001Cooooo00?o0000ooooooooool0^Oooool008Oooooo0ol0000<ooooo`;o00005?ooool00ol0
003oooooooooo`02ooooo`;o00007_ooool2o`0009Gooooo0028ooooo`;o00003?ooool2o`0001Co
oooo00?o0000ooooooooool00_ooool3o`0001gooooo0_l0002Eooooo`00U_ooool2o`0001Cooooo
00?o0000ooooooooool00_ooool3o`0001Wooooo0_l0002Iooooo`00[?ooool3o`0000;ooooo0_l0
000Iooooo`?o0000VOooool00:cooooo0ol0000Mooooo`;o0000V_ooool00:cooooo00?o0000oooo
ooooool0^Oooool008Wooooo0_l0000Qooooo`03o`000?oooooooooo01kooooo0_l0002Iooooo`00
ROooool2o`00027ooooo00?o0000ooooooooool00_l0000Looooo`?o0000V?ooool00:cooooo00?o
0000ooooooooool00_l0000Mooooo`;o0000V?ooool009Wooooo0_l0000@ooooo`;o0000^oooool0
09Wooooo0_l0000?ooooo`?o00007Oooool2o`0009cooooo002:ooooo`;o00003_ooool2o`0000go
oooo1?l0000Mooooo`;o0000W?ooool008[ooooo0_l0000>ooooo`;o00002Oooool2o`0000;ooooo
0_l000000ooooooo0000ooooo`0Mooooo`;o0000Voooool008Wooooo0_l0000Jooooo`;o00001Ooo
ool3o`0001cooooo0ol0002Jooooo`00ROooool2o`0001Gooooo0_l00005ooooo`;o00000oooool0
0ol0003oooooooooo`0Fooooo`;o00001?ooool3o`0009[ooooo0029ooooo`;o00005Oooool2o`00
00Gooooo1?l000000ooooooo0000ooooo`0Gooooo`;o0000XOooool008Wooooo0_l0000Hooooo`;o
00001?ooool2o`000003ooooool0003ooooo01Oooooo0_l000000ooooooo0000o`00002Nooooo`00
Xoooool2o`0000Oooooo00?o0000ooooooooool05_ooool2o`000003ooooool0003o000009kooooo
0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool0
1?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0^Oooool008Wooooo
00GoMgMgoiRHV?l0003o0000ogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0^Oooool008Wooooo00Go410@ooooool0003o
0000oa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Eooooo`;o0000X_ooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`0001?ooooo1Ol0002Qooooo`00
ROooool00ol0003oooooo`000002o`0000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool04oooool2o`000003ooooool0003o000000;o
0000Woooool008Wooooo00Go410@ooooool0003o0000oa0@400>ooooo`03ojVYZOmgMgOooooo00?o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`;o000000?oooooo`000?l0
00000_l0002Oooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooo
oooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05_ooool2o`00
0:7ooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006oooo
o`03o`000?oooooooooo01;ooooo0_l0002Uooooo`00[?ooool00ol0003oooooooooo`0Booooo`;o
0000YOooool008cooooo0_l0000Nooooo`03o`000?oooooooooo01;ooooo1?l0002Sooooo`00S?oo
ool2o`000003ooooool0003o000001_ooooo00?o0000ooooooooool05?ooool2o`000:?ooooo002?
ooooo`;o00006oooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00_ooooo0_l00004ooooo`;o0000
Y_ooool00:cooooo00?o0000ooooooooool02oooool2o`0000?ooooo0ol0002Vooooo`00[?ooool0
0ol0003oooooooooo`0@ooooo`;o0000Yoooool00:cooooo00?o0000ooooooooool03oooool2o`00
0:Sooooo002/ooooo`03o`000?oooooooooo00oooooo0_l0002Xooooo`00[?ooool3o`0000Kooooo
0_l0002aooooo`00[?ooool00ol0003oooooooooo`06ooooo`;o0000/Oooool00:cooooo00?o0000
ooooooooool01_ooool2o`000;7ooooo002/ooooo`03o`000?oooooooooo00Kooooo0_l0002aoooo
o`00[?ooool00ol0003oooooooooo`09ooooo`;o0000[_ooool00:cooooo00?o0000ooooooooool0
1_ooool2o`000003ooooool0003o00000:kooooo002/ooooo`03o`000?oooooooooo00Kooooo1?l0
002_ooooo`00[?ooool00ol0003oooooooooo`03ooooo`;o00000oooool2o`000:oooooo002Coooo
o`;o00005oooool00ol0003oooooooooo`03ooooo`;o000000?oooooo`000?l000000_l0002_oooo
o`00Toooool2o`0001Oooooo1?l00003ooooo`Co0000/Oooool009Gooooo0_l0000Eooooo`04o`00
0?oooooo0000o`0000?ooooo0_l0002cooooo`00UOooool2o`0001Gooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0^Oooool009Oooooo0_l000000ooooooo0000o`00000@
ooooo`03o`000?oooooooooo00?ooooo0_l0002dooooo`00Uoooool2o`000003ooooool0003o0000
013ooooo00?o0000ooooooooool00oooool2o`000;Cooooo002Iooooo`;o00004Oooool00ol0003o
ooooooooo`2iooooo`00VOooool2o`0000?ooooo0_l0000<ooooo`03o`000?oooooooooo0;Wooooo
002Iooooo`;o00000oooool2o`0000Wooooo0_l000001?oooooo0000o`000?l0002iooooo`00VOoo
ool2o`0000kooooo1?l0002kooooo`00Yoooool2o`000004ooooool0003o0000o`000;_ooooo002K
ooooo`;o00002_ooool2o`0000?ooooo00?o0000ooooooooool0^Oooool009_ooooo0_l00003oooo
o`;o00001_ooool5o`000;_ooooo002Pooooo`;o000000?oooooo`000?l000000oooool5o`000;_o
oooo002Oooooo`Oo000000?o410@ooooooooool00oooool00ol0003oooooooooo`2iooooo`00W_oo
ool5o`000003ooooool0003ooooo00Kooooo00?o0000ooooooooool0^Oooool009kooooo0_l00003
ooooo`;o00001oooool3o`000;Wooooo002Sooooo`;o0000`oooool00:Cooooo00?o0000oooooooo
ool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0`Ooo
ool00:;ooooo00?oEEEEofIVI_l00000`oooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00:[ooooo00Co410@o`000?l0003o0000^_ooool00:_ooooo00?o0000
ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00Ko0000ogMgMol0
003o0000oeEEEOo^k^jgooooo`00Zoooool01_l0003oEEEEonk^k_ooooooMgMgoeEEEKOooooo002[
ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0]Oooool00:_ooooo00?o0000onk^
k_ooool00_ooool00ol0003oooooooooo`2eooooo`00Zoooool01_l0003oEEEEonk^k_ooooooMgMg
ofIVI[Oooooo002Zooooo`03oa0@4?l0003oMgMg00;o000000?oIVIVonk^k_ooool0]_ooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001
\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.38634 .46742 Mdot
.4111 .20477 Mdot
.49881 .41522 Mdot
.54461 .41729 Mdot
.44727 .20818 Mdot
.45901 .8776 Mdot
.44691 .38035 Mdot
.68476 .71256 Mdot
.66774 .70778 Mdot
.53265 .67884 Mdot
.47821 .78475 Mdot
.6363 .80562 Mdot
.49714 .08485 Mdot
.52959 .69874 Mdot
.56436 .9002 Mdot
.5573 .51177 Mdot
.59161 .64464 Mdot
.50124 .08869 Mdot
.40958 .5817 Mdot
.65205 .30408 Mdot
.55434 .16457 Mdot
.48476 .08894 Mdot
.54335 .16262 Mdot
.52703 .1213 Mdot
.53283 .94591 Mdot
.55265 .2807 Mdot
.42769 .69288 Mdot
.40794 .49332 Mdot
.6682 .34955 Mdot
.44309 .1168 Mdot
.60339 .25095 Mdot
.68327 .6733 Mdot
.6653 .73993 Mdot
.54983 .75658 Mdot
.55347 .76582 Mdot
.66302 .37447 Mdot
.69752 .53916 Mdot
.4101 .54959 Mdot
.68544 .44794 Mdot
.65063 .78783 Mdot
.58089 .89374 Mdot
.55758 .75101 Mdot
.49536 .86434 Mdot
.38805 .60846 Mdot
.40185 .72691 Mdot
.49522 .18674 Mdot
.49429 .76578 Mdot
.70102 .60054 Mdot
.59897 .40941 Mdot
.67688 .40121 Mdot
.69698 .61258 Mdot
.69073 .43934 Mdot
.50424 .84739 Mdot
.53909 .79923 Mdot
.66261 .73141 Mdot
.67338 .73632 Mdot
.60119 .61194 Mdot
.70091 .56961 Mdot
.40912 .76597 Mdot
.51943 .22732 Mdot
.44231 .99114 Mdot
.68649 .4785 Mdot
.43329 .35076 Mdot
.62051 .81054 Mdot
.6809 .68714 Mdot
.52762 .68924 Mdot
.55297 .54378 Mdot
.41741 .64888 Mdot
.55706 .16291 Mdot
.61387 .56871 Mdot
.47965 .31401 Mdot
.51262 .72587 Mdot
.54418 .63312 Mdot
.68645 .479 Mdot
.50168 .58541 Mdot
.56852 .34308 Mdot
.68639 .41591 Mdot
.60021 .50646 Mdot
.63504 .30935 Mdot
.4509 .10727 Mdot
.54244 .41545 Mdot
.56256 .74366 Mdot
.68846 .69267 Mdot
.5583 .45863 Mdot
.45125 .20022 Mdot
.51251 .22554 Mdot
.61002 .55982 Mdot
.55125 .55989 Mdot
.51632 .96337 Mdot
.38288 .1689 Mdot
.45596 .26947 Mdot
.48851 .18325 Mdot
.45487 .27473 Mdot
.36152 .35218 Mdot
.53048 .69532 Mdot
.68097 .66097 Mdot
.61511 .52548 Mdot
.3921 .35247 Mdot
.61277 .50245 Mdot
.61599 .83357 Mdot
.38463 .48548 Mdot
.59994 .23045 Mdot
.54546 .76696 Mdot
.60468 .6169 Mdot
.4067 .52984 Mdot
.45575 .26946 Mdot
.57061 .185 Mdot
.53695 .6743 Mdot
.53563 .37138 Mdot
.68057 .67814 Mdot
.64768 .30746 Mdot
.62764 .08887 Mdot
.52433 .58761 Mdot
.54311 .27452 Mdot
.69807 .65259 Mdot
.6952 .65243 Mdot
.68834 .58159 Mdot
.50762 .09865 Mdot
.57646 .20993 Mdot
.66638 .33898 Mdot
.56468 .17471 Mdot
.55032 .46089 Mdot
.6592 .33953 Mdot
.3575 .48232 Mdot
.44648 .12029 Mdot
.46709 .71078 Mdot
.51571 .12111 Mdot
.40768 .23596 Mdot
.6116 .845 Mdot
.47757 .88712 Mdot
.48078 .87758 Mdot
.67731 .37073 Mdot
.7007 .46637 Mdot
.66655 .35419 Mdot
.51092 .72854 Mdot
.64142 .7854 Mdot
.57467 .88943 Mdot
.36828 .68965 Mdot
.50048 .27637 Mdot
.41665 .64972 Mdot
.59366 .63866 Mdot
.64781 .29931 Mdot
.69252 .67717 Mdot
.66722 .13128 Mdot
.43715 .25062 Mdot
.51639 .23035 Mdot
.55505 .94167 Mdot
.61215 .47816 Mdot
.44783 .7692 Mdot
.51972 .11029 Mdot
.46958 .31549 Mdot
.39999 .68956 Mdot
.69742 .48163 Mdot
.68826 .46164 Mdot
.68834 .67646 Mdot
.6947 .55659 Mdot
.69823 .47755 Mdot
.57638 .33496 Mdot
.68416 .39705 Mdot
.63921 .81891 Mdot
.6567 .36383 Mdot
.45882 .8648 Mdot
.40278 .27122 Mdot
.69026 .68021 Mdot
.60379 .23366 Mdot
.41855 .65509 Mdot
.69698 .44004 Mdot
.67485 .41294 Mdot
.5085 .30638 Mdot
.41708 .6352 Mdot
.48048 .18575 Mdot
.43043 .26919 Mdot
.64356 .77757 Mdot
.3603 .37728 Mdot
.3996 .68427 Mdot
.50766 .64894 Mdot
.67724 .38957 Mdot
.69182 .41456 Mdot
.63163 .82078 Mdot
.55781 .55792 Mdot
.57683 .89998 Mdot
.44042 .65668 Mdot
.65858 .7236 Mdot
.35907 .42259 Mdot
.69812 .63218 Mdot
.63712 .82003 Mdot
.50034 .86099 Mdot
.51294 .98249 Mdot
.64568 .29312 Mdot
.4287 .39073 Mdot
.43078 .9691 Mdot
.68409 .70764 Mdot
.58395 .89775 Mdot
.61629 .83562 Mdot
.48717 .18416 Mdot
.38208 .16355 Mdot
.60436 .63213 Mdot
.51823 .59854 Mdot
.51706 .60575 Mdot
.48702 .31952 Mdot
.46814 .18792 Mdot
.39799 .08941 Mdot
.4087 .23443 Mdot
.42474 .47453 Mdot
.43727 .84625 Mdot
.52104 .32036 Mdot
.44447 .68113 Mdot
.48795 .78154 Mdot
.46634 .0788 Mdot
.56284 .32608 Mdot
.60604 .23805 Mdot
.55271 .57819 Mdot
.40819 .24008 Mdot
.56068 .32407 Mdot
.63097 .83098 Mdot
.45732 .70914 Mdot
.39319 .63956 Mdot
.66407 .76259 Mdot
.53649 .26032 Mdot
.68953 .61825 Mdot
.59272 .21407 Mdot
.64686 .34134 Mdot
.54705 .5957 Mdot
.43219 .25319 Mdot
.38916 .35071 Mdot
.49166 .26853 Mdot
.56574 .89903 Mdot
.50388 .99681 Mdot
.55483 .46376 Mdot
.44709 .60719 Mdot
.42947 .00664 Mdot
.60701 .51072 Mdot
.44801 .76208 Mdot
.41416 .61067 Mdot
.38488 .45171 Mdot
.54773 .16042 Mdot
.40079 .27651 Mdot
.43118 .97252 Mdot
.49506 .87235 Mdot
.61236 .24331 Mdot
.6138 .56851 Mdot
.69367 .64838 Mdot
.46315 .26645 Mdot
.69362 .51899 Mdot
.59309 .62119 Mdot
.61443 .56269 Mdot
.68701 .46488 Mdot
.57861 .90243 Mdot
.5237 .58936 Mdot
.43971 .33021 Mdot
.69203 .54717 Mdot
.5716 .33426 Mdot
.41717 .6336 Mdot
.55557 .77656 Mdot
.49895 .60216 Mdot
.66324 .75167 Mdot
.702 .58317 Mdot
.60536 .45428 Mdot
.44953 .76515 Mdot
.64954 .3454 Mdot
.49161 .6981 Mdot
.61084 .50105 Mdot
.38735 .45596 Mdot
.47304 .77891 Mdot
.42907 .81689 Mdot
.66981 .39959 Mdot
.58883 .39682 Mdot
.65878 .34707 Mdot
.5413 .79791 Mdot
.54311 .64949 Mdot
.60329 .47977 Mdot
.69715 .46663 Mdot
.55987 .54875 Mdot
.40682 .43282 Mdot
.6935 .62891 Mdot
.50745 .7515 Mdot
.41551 .77969 Mdot
.67973 .39263 Mdot
.49762 .69502 Mdot
.53879 .64399 Mdot
.69268 .56683 Mdot
.62993 .81161 Mdot
.40664 .53597 Mdot
.45846 .33418 Mdot
.47907 .19411 Mdot
.62912 .26512 Mdot
.51461 .22418 Mdot
.63156 .30495 Mdot
.36071 .38676 Mdot
.69568 .5869 Mdot
.5889 .86744 Mdot
.68697 .61968 Mdot
.43765 .5398 Mdot
.70453 .52982 Mdot
.41993 .94136 Mdot
.61482 .23915 Mdot
.57092 .89127 Mdot
.68503 .15151 Mdot
.60038 .44048 Mdot
.53939 .80811 Mdot
.40246 .26221 Mdot
.68927 .65962 Mdot
.56332 .91213 Mdot
.4958 .76573 Mdot
.6888 .64133 Mdot
.57382 .33819 Mdot
.52419 .54779 Mdot
.48335 .08075 Mdot
.59173 .64824 Mdot
.51484 .11006 Mdot
.55808 .93643 Mdot
.51454 .63163 Mdot
.38861 .56861 Mdot
.55005 .76056 Mdot
.61418 .82245 Mdot
.50283 .67482 Mdot
.62213 .83476 Mdot
.46659 .99977 Mdot
.37624 .77254 Mdot
.55352 .48074 Mdot
.49187 .88169 Mdot
.5698 .73082 Mdot
.6886 .49577 Mdot
.41913 .30824 Mdot
.52815 .52363 Mdot
.43802 .45163 Mdot
.60413 .61392 Mdot
.67285 .7429 Mdot
.68846 .56306 Mdot
.44623 .29356 Mdot
.46984 .0816 Mdot
.47111 .715 Mdot
.4905 .32509 Mdot
.39202 .32106 Mdot
.47461 .8843 Mdot
.45955 .86567 Mdot
.57805 .34088 Mdot
.46714 .1898 Mdot
.58245 .37354 Mdot
.45907 .10236 Mdot
.4432 .30979 Mdot
.65886 .74557 Mdot
.42971 .70044 Mdot
.66574 .35529 Mdot
.49384 .10156 Mdot
.47229 .25072 Mdot
.55243 .30792 Mdot
.37183 .72627 Mdot
.64745 .78812 Mdot
.70671 .50635 Mdot
.66383 .37222 Mdot
.59461 .4023 Mdot
.59476 .65797 Mdot
.67166 .39513 Mdot
.60913 .50276 Mdot
.64475 .79204 Mdot
.39099 .86265 Mdot
.6149 .24724 Mdot
.60831 .84864 Mdot
.61741 .84213 Mdot
.60521 .86624 Mdot
.50436 .36019 Mdot
.60609 .49333 Mdot
.56668 .89899 Mdot
.6698 .74104 Mdot
.50728 .36959 Mdot
.61747 .27326 Mdot
.58986 .41837 Mdot
.45237 .87367 Mdot
.39003 .38007 Mdot
.67704 .67498 Mdot
.3854 .43871 Mdot
.69954 .54433 Mdot
.688 .54465 Mdot
.54163 .16135 Mdot
.70595 .4841 Mdot
.5195 .1278 Mdot
.54951 .92518 Mdot
.63682 .09603 Mdot
.68507 .6043 Mdot
.40747 .7438 Mdot
.47956 .31881 Mdot
.50444 .98269 Mdot
.61297 .5329 Mdot
.43739 .46611 Mdot
.63802 .8132 Mdot
.56017 .16725 Mdot
.52894 .50006 Mdot
.53821 .65534 Mdot
.55148 .28477 Mdot
.43837 .73847 Mdot
.7023 .60105 Mdot
.57518 .17985 Mdot
.42161 .94786 Mdot
.62977 .82438 Mdot
.57977 .6893 Mdot
.58599 .67816 Mdot
.42334 .30061 Mdot
.41898 .31893 Mdot
.47546 .66024 Mdot
.66795 .74963 Mdot
.63592 .80547 Mdot
.43042 .70523 Mdot
.49053 .26332 Mdot
.49551 .77964 Mdot
.56073 .4953 Mdot
.56127 .92857 Mdot
.46841 .1782 Mdot
.65112 .34107 Mdot
.52112 .33029 Mdot
.43906 .74741 Mdot
.48993 .70301 Mdot
.46334 .18387 Mdot
.5545 .74559 Mdot
.45828 .78309 Mdot
.42531 .45221 Mdot
.52299 .97545 Mdot
.64579 .778 Mdot
.46944 .37814 Mdot
.55038 .77326 Mdot
.60405 .61919 Mdot
.38887 .51416 Mdot
.59291 .43389 Mdot
.42041 .6644 Mdot
.52005 .96822 Mdot
.35936 .37455 Mdot
.39232 .33406 Mdot
.59645 .0571 Mdot
.38785 .61252 Mdot
.42386 .46855 Mdot
.64682 .75103 Mdot
.55756 .91042 Mdot
.45903 .77528 Mdot
.50759 .11947 Mdot
.49967 .2791 Mdot
.5274 .4785 Mdot
.44513 .22533 Mdot
.64437 .32751 Mdot
.5991 .46911 Mdot
.38253 .16539 Mdot
.43887 .65358 Mdot
.5123 .83242 Mdot
.57249 .72138 Mdot
.43593 .33212 Mdot
.50668 .65592 Mdot
.55595 .58188 Mdot
.68187 .71852 Mdot
.51668 .62847 Mdot
.68222 .39418 Mdot
.39932 .26976 Mdot
.39209 .63797 Mdot
.65794 .33938 Mdot
.62653 .2966 Mdot
.58913 .66105 Mdot
.36069 .63283 Mdot
.53765 .65876 Mdot
.67254 .74449 Mdot
.58822 .89129 Mdot
.46333 .77327 Mdot
.70574 .51937 Mdot
.59148 .41734 Mdot
.58402 .66062 Mdot
.66355 .34746 Mdot
.38929 .38597 Mdot
.40711 .51293 Mdot
.55105 .30341 Mdot
.56014 .73723 Mdot
.45761 .86774 Mdot
.50747 .54281 Mdot
.483 .87085 Mdot
.60127 .49352 Mdot
.49413 .32836 Mdot
.55288 .52397 Mdot
.513 .83465 Mdot
.50405 .85719 Mdot
.52174 .59115 Mdot
.57083 .33688 Mdot
.67972 .69057 Mdot
.43321 .24305 Mdot
.38724 .48207 Mdot
.43485 .74259 Mdot
.41495 .37306 Mdot
.51667 .40669 Mdot
.60773 .06479 Mdot
.52087 .43295 Mdot
.40042 .25909 Mdot
.67812 .65296 Mdot
.65586 .35709 Mdot
.41464 .62725 Mdot
.67117 .3684 Mdot
.63339 .81533 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00U?ooool2o`0000kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`2iooooo`00U?ooool2o`0000kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo002Roooo
o`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo01cooooo0_l0002Kooooo`00[?ooool00ol0
003oooooooooo`0Looooo`;o0000Voooool00:cooooo00?o0000ooooooooool08?ooool2o`0009Oo
oooo002/ooooo`03o`000?oooooooooo023ooooo0_l0002Gooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002Pooooo`;o
00002_ooool00ol0003oooooooooo`2iooooo`00X?ooool4o`0000;ooooo0_l00004ooooo`03o`00
0?oooooooooo0;Wooooo002Rooooo`;o00000_ooool2o`0000?ooooo0_l0002kooooo`00R_ooool2
o`0001_ooooo0_l00002ooooo`?o0000:?ooool2o`00093ooooo002:ooooo`;o00006oooool2o`00
00?ooooo0_l0000Xooooo`;o0000T?ooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0:_ooool2o`0008gooooo002Zooooo`Ko0000:Oooool2o`0008gooooo002N
ooooo`;o00002_ooool3o`000003ooooool0003o00000;Sooooo002Kooooo`;o000000?oooooo`00
0?l000003?ooool00ol0003oooooooooo`2iooooo`00Voooool2o`0000oooooo00Co0000oooooooo
oooooooo1?l0002dooooo`00[?ooool01?l0003oooooooooooooool4o`000;Cooooo002Iooooo`;o
00004Oooool00ol0003oooooooooo`2iooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`?o000000?ok^k^ooooooooool00oooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00Co0000ooooool0003o0000^?ooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1Oooool2o`000003ojVYZOoooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool0
1Ol0003oooooo`000?l0003ooooo00;o000000?oooooo`000?l00000/_ooool0087ooooo1_l00002
ooooo`05oa0@4?ooooooooooooooool@41003?ooool2o`000003oeEEEOoooooooooo00Oooooo00?o
0000ooooooooool00oooool3o`0000;ooooo0_l000000ooooooo0000o`00002booooo`00ROooool0
1Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo00?ooooo0_l0002dooooo`00ROooool01Ol0003ooooooooooooo
oooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool00oooool2o`0002oooooo0_l00023ooooo`00ROooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo03Cooooo0_l00023ooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0^Oooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o
0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0000joooo
o`;o0000OOooool00:cooooo00?o0000ooooooooool0>_ooool2o`0007gooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00[ooooo1?l0002[ooooo`00QOooool2
o`0002Gooooo00?o0000ooooooooool02_ooool4o`000003ooooool0003o00000:Sooooo0025oooo
o`;o00009Oooool00ol0003oooooooooo`0;ooooo`;o00000_ooool3o`000:Oooooo0025ooooo`;o
00009Oooool00ol0003oooooooooo`0@ooooo`;o0000Yoooool008Gooooo0_l0000Uooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o00004_ooool2o`000:Gooooo002Qooooo`;o00002Oooool0
0ol0003oooooooooo`0Booooo`;o000000?oooooo`000?l00000X_ooool00:7ooooo0_l00005oooo
o`;o00000_ooool00ol0003oooooooooo`0Eooooo`;o0000X_ooool009oooooo0_l00004ooooo`Go
00000_ooool00ol0003oooooooooo`0Dooooo`;o0000Xoooool009oooooo1?l00002ooooo`Co0000
00Coooooo`000?l0003o00005_ooool2o`000:?ooooo002Qooooo`;o00001oooool3o`000;_ooooo
002Qooooo`;o00000_ooool2o`0000Gooooo00?o0000ooooooooool0^Oooool00:Gooooo0_l00005
ooooo`03o`000?oooooooooo0;Wooooo002Kooooo`;o00003oooool3o`000;Wooooo002Kooooo`;o
00003oooool00ol0003oooooooooo`2iooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool0
^Oooool008kooooo0_l0000:ooooo`;o00004?ooool00ol0003oooooooooo`0Fooooo`;o0000XOoo
ool009[ooooo0_l0000@ooooo`03o`000?oooooooooo01Kooooo0_l0002Qooooo`00[?ooool00ol0
003oooooooooo`0Kooooo`;o0000W?ooool00:cooooo00?o0000ooooooooool06oooool2o`0009co
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002Iooooo`;o00004Oooool3o`000003ooooool0
003o00000;Kooooo002Iooooo`;o00004Oooool01?l0003oooooooooooooool4o`000;Cooooo002/
ooooo`03o`000?oooooooooo00;ooooo0ol0000Iooooo`;o0000VOooool008gooooo0_l0000Moooo
o`03o`000?oooooooooo00;ooooo0_l0000Jooooo`?o0000V?ooool008gooooo0_l0000Mooooo`03
o`000?oooooooooo01oooooo0_l0002Hooooo`00SOooool2o`0001gooooo00?o0000ooooooooool0
8?ooool4o`0009Gooooo002=ooooo`;o00000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;o0000
0oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo023o
oooo1?l0002Eooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00;o00000oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Rooooo`;o0000UOooool008Wooooo
1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo02;ooooo0_l0002Eooooo`00TOooool01_l0003ooooooooooooooooo0000oooo
o`;o00002Oooool2o`000003oooooomgMgOo<S8b00Gooooo0ol0000Oooooo`;o000000?oooooo`00
0?l00000UOooool0097ooooo00Co0000oooooooooooooooo1?l00009ooooo`?o000000?o<S8bolc<
c?ooool01?ooool00ol0003oooooooooo`0Oooooo`;o0000V?ooool008_ooooo0_l00004ooooo`04
oa0@4?ooooooooooooooo`;o00002oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
0;Wooooo002;ooooo`;o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`09ooooo`;o0000[_ooool008_ooooo0_l00004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000;ooooo0_l00002ooooo`03o`000?oooooooooo
00Wooooo0_l0000Looooo`;o0000T?ooool009oooooo0_l00007ooooo`;o00000_ooool00ol0003o
ooooooooo`0Wooooo`;o0000T?ooool008[ooooo0ol00008ooooo`;o00001_ooool4o`0000Sooooo
0_l000000ooooooo0000ooooo`2jooooo`00R_ooool3o`0000Sooooo0_l00006ooooo`;o00002_oo
ool2o`000003ooooool0003ooooo02Cooooo0_l0002Dooooo`00Roooool2o`00013ooooo0_l0000=
ooooo`?o00002oooool2o`0001Kooooo0_l0002Dooooo`00Roooool2o`00013ooooo0_l0000<oooo
o`?o00003?ooool2o`000:cooooo002[ooooo`;o00004?ooool2o`000:Wooooo002/ooooo`03o`00
0?oooooooooo00kooooo0_l0002Yooooo`00[?ooool00ol0003oooooooooo`0>ooooo`;o0000ZOoo
ool00:cooooo00?o0000ooooooooool0^Oooool009[ooooo0_l0000@ooooo`03o`000?oooooooooo
02gooooo0_l0002:ooooo`00V_ooool2o`00013ooooo00?o0000ooooooooool09_ooool2o`0000Go
oooo0_l0002:ooooo`00T_ooool2o`0001Sooooo0ol0000Vooooo`;o00001Oooool2o`0008[ooooo
002Booooo`;o00006?ooool00ol0003oooooooooo`0=ooooo`;o00007_ooool4o`0008Sooooo002/
ooooo`04o`000?oooooo0000o`0000cooooo0_l0000Iooooo`;o00000oooool4o`0008Sooooo002A
ooooo`;o00001_ooool2o`00017ooooo00Co0000ooooool0003o00003Oooool2o`0001Sooooo0ol0
0002ooooo`;o0000R_ooool0097ooooo0_l00006ooooo`;o00004Oooool00ol0003oooooooooo`0>
ooooo`;o00006Oooool2o`0008kooooo002Rooooo`;o000000?oooooo`000?l000001Oooool00ol0
003oooooooooo`2iooooo`00TOooool2o`0000oooooo0_l000000ooooooo0000o`000002o`0000?o
oooo00?o0000ooooooooool0^Oooool008Sooooo0_l00007ooooo`;o00004_ooool4o`0000?ooooo
00?o0000ooooooooool01?ooool2o`000;?ooooo0028ooooo`;o00007_ooool2o`0000;ooooo0ol0
0004ooooo`;o00002oooool2o`000:Kooooo002Xooooo`Go00004oooool2o`0001Wooooo0_l0002;
ooooo`00V?ooool2o`00013ooooo0ol00006ooooo`;o00002oooool2o`0001Wooooo0_l0002;oooo
o`00R?ooool2o`0000cooooo1?l00004ooooo`;o00003?ooool00ol0003oooooooooo`04ooooo`;o
00003_ooool2o`000:?ooooo0028ooooo`;o00003?ooool2o`0000Kooooo0_l0000<ooooo`03o`00
0?oooooooooo01Cooooo1?l0002Qooooo`00[?ooool00ol0003oooooooooo`0Dooooo`Co00006Ooo
ool4o`0008Cooooo002/ooooo`03o`000?oooooooooo01?ooooo1Ol0000Eooooo`?o000000?ooooo
o`000?l000000_l00024ooooo`00[?ooool00ol0003oooooooooo`0Cooooo`;o00006?ooool3o`00
08Wooooo002/ooooo`03o`000?oooooooooo02kooooo0_l000000ooooooo0000o`000003o`0008?o
oooo001nooooo`;o00001oooool3o`0000cooooo0_l0000Dooooo`?o0000<Oooool5o`0008?ooooo
001nooooo`;o00001oooool3o`0000cooooo0_l0000Dooooo`03o`000?oooooooooo03?ooooo0ol0
0023ooooo`00[?ooool00ol0003oooooooooo`0`ooooo`;o000000Coooooo`000?l0003o0000Pooo
ool00:cooooo0ol0000`ooooo`;o0000Qoooool00:cooooo0ol0000`ooooo`;o0000Qoooool008Wo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo033ooooo0_l00027ooooo`00ROooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01ooo
ool00omgMgOo<S8booooo`04ooooo`04o`000?oooooo0000o`0003Cooooo1?l00020ooooo`00POoo
ool6o`0000;ooooo00Ko410@oooooooooooooooooa0@4?ooool2o`0000Wooooo00?oV9RHob4Q8Oo^
k^h02Oooool00ol0003oooooooooo`03ooooo`04o`000?oooooo0000o`0000Oooooo0_l0000>oooo
o`;o00006Oooool6o`00083ooooo001mooooo`;o00002_ooool01_l0003ooooooooooooooooo0000
ooooo`;o00002_ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00008
ooooo`;o00003_ooool2o`0001Sooooo0ol00024ooooo`00OOooool2o`0000Sooooo0ol00003oooo
o`03o`000?oooooooooo00[ooooo0_l000000omgMgOoIVIVooooo`02ooooo`;o000000Co8B4Qo`00
0?lb<S;oc<c<1Oooool00ol0003oooooooooo`0booooo`;o0000QOooool008Oooooo0_l000001Ol@
413ooooooooooooooooo410@00cooooo0_l000000ooooooo0000ooooo`02ooooo`;o00002Oooool0
0ol0003oooooooooo`2iooooo`00Qoooool2o`000005ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`2iooooo`00O_ooool2o`0000Oooooo0_l000001Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`2iooooo`00O_oo
ool2o`0001Cooooo0_l0000Fooooo`03o`000?oooooooooo03Oooooo0_l00020ooooo`00U?ooool2
o`0001Kooooo00?o0000ooooooooool0=Oooool6o`0007kooooo002/ooooo`03o`000?oooooooooo
01[ooooo0_l0000Iooooo`;o000000Coooooo`000?l0003o0000O_ooool00:cooooo0ol0000Joooo
o`;o00006Oooool6o`0007kooooo002/ooooo`03o`000?oooooooooo01cooooo0_l0000Gooooo`Co
0000P?ooool00:cooooo00?o0000ooooooooool00_ooool2o`0001Sooooo0_l0002Kooooo`00[?oo
ool00ol0003oooooooooo`02ooooo`;o00006Oooool2o`0009[ooooo002/ooooo`03o`000?oooooo
oooo01gooooo0_l0000Gooooo`;o0000POooool00:_ooooo0_l0000=ooooo`;o0000:Oooool2o`00
00;ooooo1?l0001kooooo`00Zoooool2o`0000gooooo0_l0000=ooooo`?o00007Oooool4o`0007_o
oooo001mooooo`;o0000;Oooool00ol0003oooooooooo`0;ooooo`;o00003Oooool3o`0009cooooo
001mooooo`;o0000;Oooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002=ooooo`;o00007Oooool00ol0003oooooooooo`03ooooo`;o
00005_ooool2o`0009cooooo002=ooooo`;o00007Oooool00ol0003oooooooooo`03ooooo`;o0000
5_ooool2o`0009cooooo0026ooooo`;o00009?ooool00ol0003oooooooooo`0Nooooo`;o00007?oo
ool4o`0007Wooooo0026ooooo`;o00009?ooool00ol0003oooooooooo`0Nooooo`;o00007?ooool4
o`0007Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo03[o
oooo0_l0001mooooo`00Q_ooool2o`0000_ooooo0_l00002ooooo`;o00004oooool3o`0003[ooooo
0_l0001mooooo`00Q_ooool2o`0000_ooooo0_l00002ooooo`;o00004oooool00ol0003ooooooooo
o`0Oooooo`;o0000V?ooool008Kooooo0_l0000Tooooo`03o`000?oooooooooo013ooooo0_l0000=
ooooo`;o0000V?ooool000Wooooo1?l000000ol@413oooooooooo`0Fooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`00
00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Fooooo`03o`000?oooooooooo00gooooo0_l00000
0ooooooo0000o`000006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0
0004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool2o`0000Sooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o
0000oc8b<_oMgMd06?ooool4o`000003oa0@4?oooooooooo01;ooooo000;ooooo`03o`000?oooooo
oooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYoooo
o`07ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
2?ooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo01Gooooo00?o0000oooo
ooooool03Oooool4o`0000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool00oooool3o`0000Sooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo
<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo0006o`0000Gooooo00?o0000ooooooooool0
4?ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00So
oooo00?o0000ooooooooool01Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@oooo
o`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41002Oooool2
o`000004oooooonHV9So8B4Qonk^kPWooooo00Co0000ooooool0003o00004oooool00ol0003ooooo
ooooo`0?ooooo`;o00001oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^
k^h02Oooool00ol0003oooooooooo`02ooooo`;o00000_ooool3o`0000Cooooo00Go410@oooooooo
oooooooooa0@400@ooooo`03o`000?oooooooooo00gooooo00Go410@oooooooooooooooooa0@400=
ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0D
ooooo`002oooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool0
0olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00
000?ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`000009ooooo`;o0000
0_ooool00onHV9So8B4Qonk^kP05ooooo`;o000000?oMgMgoc8b<_ooool00_l0000Cooooo`03o`00
0?oooooooooo01Sooooo00Co0000oooooooooooooooo0ol0000;ooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo00?oMgMgoc8b<_ooool01oooool3o`0000Cooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooo
oooo00Kooooo00?oMgMgoc8b<_ooool06Oooool00ol0003oooooooooo`0Dooooo`002oooool00ol0
003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000cooooo
00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003_ooool00omg
MgOoIVIVooooo`03ooooo`?o000000?o<S8bolc<c?ooool05Oooool00ol0003oooooooooo`0Hoooo
o`04o`000?ooooooooooooooo`?o00003?ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o
<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`06_ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0
003oooooooooo`0Hooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03
ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oo
oooooooo017ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo
00Co0000ooooool0003o00005oooool3o`0001Sooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o
ZJVYogMgMoooool00oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Cooooo000;
ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oo
oooooooooooooolb<S801?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@00Cooooo00Co0000ooooool0003o00005oooool00ol0003ooooooooo
o`06ooooo`;o00004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo0_l000000ooooooo0000
o`000004ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`06ooooo`;o
00000_ooool2o`0000Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo
017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Cooooo0009ooooo`03oeEEEOmVIVKo
000001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`00013ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;o
00001oooool2o`000005oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0001Oooooo00?o0000oooo
ooooool01_ooool2o`0000Kooooo0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool2
o`000003ooooool0003o000000Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001Ooo
ool2o`0000;ooooo0_l00005ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00013ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0001Wooooo00?oEEEEofIVI_l0
00005_ooool007gooooo0_l00006ooooo`?o00009?ooool00ol0003oooooooooo`0>ooooo`;o0000
;_ooool2o`000003ooooool0003o000007Kooooo0025ooooo`;o00009Oooool00ol0003ooooooooo
o`11ooooo`;o0000M_ooool00:cooooo00?o0000ooooooooool0[_ooool2o`0000;ooooo0_l00005
ooooo`00SOooool2o`0001gooooo00?o0000ooooooooool04Oooool2o`0000_ooooo1?l0002<oooo
o`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1Oooool008gooooo0_l0000Mooooo`03o`000?oooooo
oooo017ooooo0_l0000;ooooo`Co00006Oooool2o`0007;ooooo00CogMgMo`000?l@413oc<c<1_oo
ool000Ooooooool0001<o`0000cooooo00Cok^k^ob4Q8Ol@413ok^k^1_ooool000Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo0_l00006
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03
o`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02_ooool01?lQ8B7oMgMgogMgMolb<S86ooooo`001oooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo0_l000001?oooooo0000o`000?l0
0003ooooo`03o`000?oooooooooo01Oooooo0_l0000=ooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`09ooooo`;o00000_ooool2o`0000Gooooo002/
ooooo`03o`000?oooooooooo01kooooo0_l0000Qooooo`;o0000M_ooool008gooooo0_l0000Moooo
o`03o`000?oooooooooo00oooooo0_l0000?ooooo`;o0000Uoooool008Oooooo0_l00004ooooo`;o
00007Oooool00ol0003oooooooooo`0?ooooo`;o00003oooool2o`0009Oooooo0027ooooo`;o0000
8oooool00ol0003oooooooooo`0looooo`;o00000_ooool2o`0007Oooooo002/ooooo`03o`000?oo
oooooooo03cooooo0_l00002ooooo`;o0000Moooool00:cooooo0ol00006ooooo`;o00001_ooool2
o`0001?ooooo0_l0002Dooooo`00[?ooool00ol0003oooooooooo`06ooooo`;o00001_ooool2o`00
01?ooooo0_l0002Dooooo`00SOooool2o`0001gooooo00?o0000ooooooooool0@?ooool2o`0007Oo
oooo002=ooooo`;o00007Oooool00ol0003oooooooooo`0Rooooo`;o00007?ooool2o`0007Oooooo
002=ooooo`;o00007Oooool00ol0003oooooooooo`0Rooooo`;o0000UOooool008gooooo0_l00008
ooooo`;o00004oooool00ol0003oooooooooo`0nooooo`;o0000NOooool009Oooooo0_l0000Coooo
o`04o`000?oooooo0000o`0000gooooo0_l0000^ooooo`;o0000NOooool00:cooooo00Co0000oooo
ool0003o00003Oooool2o`0002_ooooo0_l000000ooooooo0000o`00001iooooo`00S_ooool2o`00
01cooooo00?o0000ooooooooool01Oooool2o`0000Wooooo0_l0000Yooooo`Go0000NOooool008ko
oooo0_l0000Looooo`?o00001Oooool2o`0000Wooooo0_l0000Zooooo`;o0000Noooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool04?ooool2o`0002_ooooo0_l0
001jooooo`00[?ooool00ol0003oooooooooo`0=ooooo`;o000000?oooooo`000?l000003oooool2
o`0001[ooooo0_l0001jooooo`00[?ooool00ol0003oooooooooo`0=ooooo`;o00004_ooool3o`00
01Oooooo0_l0001looooo`00[?ooool00ol0003oooooooooo`0Rooooo`;o00005oooool3o`0007_o
oooo0027ooooo`;o00008oooool00ol0003oooooooooo`0Rooooo`;o00006?ooool2o`000003oooo
ool0003o000007Sooooo0027ooooo`;o00008oooool00ol0003oooooooooo`0Rooooo`;o00006ooo
ool2o`0007Sooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool03_ooool2o`00
0:Wooooo002>ooooo`;o00007?ooool00ol0003oooooooooo`0>ooooo`?o0000:_ooool2o`0000;o
oooo0_l0001hooooo`00S_ooool2o`0001cooooo0_l0000@ooooo`;o0000:_ooool2o`0000;ooooo
0_l0001hooooo`00[?ooool2o`0000Gooooo0ol0000fooooo`;o0000N_ooool00:cooooo00?o0000
ooooooooool01?ooool3o`0003Kooooo0_l0001jooooo`00[?ooool00ol0003oooooooooo`04oooo
o`;o0000/oooool00:cooooo00?o0000ooooooooool03?ooool2o`000:_ooooo002/ooooo`?o0000
0oooool2o`0000Oooooo0_l0000aooooo`;o0000N?ooool00:_ooooo0_l00005ooooo`;o0000=Ooo
ool2o`0000?ooooo0_l0001hooooo`00V_ooool2o`0000oooooo0_l00004ooooo`;o0000=_ooool2
o`0007gooooo0027ooooo`;o00004Oooool2o`00013ooooo00?o0000ooooooooool00_ooool2o`00
0;Gooooo0027ooooo`;o00001_ooool2o`0001_ooooo00?o0000ooooooooool07_ooool2o`0001ko
oooo0_l0001iooooo`00Qoooool2o`0000Kooooo0_l0000Kooooo`03o`000?oooooooooo01kooooo
0ol0000Mooooo`;o0000NOooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01oo
oooo0_l0000Jooooo`;o0000O?ooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`0Kooooo`;o00000_ooool2o`0001Wooooo0ol0001looooo`00ROooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03oooo
o`?o00006oooool2o`0001gooooo0_l0001mooooo`00ROooool01_l0003ooooooooooooooooo0000
ooooo`;o00002_ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool00_ooool2o`000;Gooooo0029ooooo`06o`000?ooooooooooooooool0003ooooo0_l0
000;ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`04o`00
0?ooooooooooooooo`?o0000>?ooool2o`0007_ooooo001nooooo`;o00002Oooool01Ol@413ooooo
oooooooooooo410@00;ooooo0_l0000;ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01oooool01?l0003oooooooooooooool2o`0000Sooooo0_l0000Booooo`;o00006oooool4o`00
07Wooooo001nooooo`;o00002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo0_l00007oooo
o`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00_ooooo0_l0000Booooo`;o00007Oooool2o`0007Wooooo0028ooooo`;o000000Co<S8bo`00
0?lb<S;ok^k^0_ooool2o`0000Oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_oo
ool00ol0003oooooooooo`0Kooooo`;o0000W?ooool008Sooooo0_l0000Rooooo`03o`000?oooooo
oooo01_ooooo0_l0000Nooooo`;o0000O?ooool00:cooooo00?o0000ooooooooool02Oooool2o`00
013ooooo0_l0000Nooooo`;o0000O?ooool0093ooooo0_l0000Jooooo`04o`000?oooooo0000o`00
00Sooooo1?l0000>ooooo`;o00007oooool2o`0007_ooooo002@ooooo`;o00006_ooool4o`0000[o
oooo0_l0000>ooooo`;o00006_ooool2o`0000?ooooo1?l0001iooooo`00TOooool2o`0000Cooooo
0_l0000Cooooo`04o`000?oooooo0000o`0000Sooooo0_l0000/ooooo`;o00001?ooool3o`0007Wo
oooo002Aooooo`;o00001?ooool3o`0001;ooooo00Co0000ooooool0003o00002?ooool2o`00017o
oooo0_l0002Kooooo`00V?ooool2o`0000Wooooo0_l00007ooooo`03o`000?oooooooooo00Wooooo
0_l0000=ooooo`Ko00006_ooool2o`000003ooooool0003o000007cooooo002Aooooo`;o00004?oo
ool2o`0000Oooooo00?o0000ooooooooool06?ooool4o`0001cooooo0_l000000ooooooo0000o`00
001looooo`00TOooool2o`0001Wooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0>Oooool2o`0007kooooo002/ooooo`?o0000
2Oooool2o`0002cooooo1ol0001kooooo`00[?ooool2o`0000Sooooo1?l0000>ooooo`;o00007?oo
ool3o`000004ooooool0003o0000o`0007_ooooo002Iooooo`;o00004Oooool00ol0003ooooooooo
o`07ooooo`;o00004?ooool2o`0001gooooo0_l000000ooooooo0000o`00001looooo`00R_ooool2
o`0000gooooo0_l0000Aooooo`03o`000?oooooooooo0;Wooooo002:ooooo`;o00008?ooool00ol0
003oooooooooo`06ooooo`;o00003oooool2o`0001oooooo0_l0001oooooo`00P?ooool2o`0000Wo
oooo0_l0000Oooooo`03o`000?oooooooooo00Kooooo0_l0000?ooooo`;o00007oooool2o`0007oo
oooo0020ooooo`;o00002Oooool2o`0000Oooooo0_l0000Eooooo`;o00002Oooool2o`0002oooooo
0_l000000ooooooo0000o`00001looooo`00U?ooool2o`0001?ooooo1?l00009ooooo`;o0000<_oo
ool2o`0007cooooo002Dooooo`;o00004oooool2o`000004ooooool0003o0000o`0000Kooooo0_l0
002aooooo`00U?ooool2o`0001;ooooo0_l00002ooooo`03o`000?oooooooooo00Kooooo0_l0002a
ooooo`00UOooool2o`00017ooooo0_l00002ooooo`03o`000?oooooooooo0;Wooooo002Eooooo`;o
00001_ooool2o`0000gooooo00?o0000ooooooooool0=?ooool2o`0000?ooooo0_l0001nooooo`00
WOooool2o`0000;ooooo0_l00009ooooo`03o`000?oooooooooo03Cooooo0_l00003ooooo`?o0000
OOooool00:7ooooo0ol00008ooooo`03o`000?oooooooooo03[ooooo0_l0001mooooo`00X_ooool2
o`0000Sooooo00?o0000ooooooooool0>Oooool2o`0007kooooo002/ooooo`03o`000?oooooooooo
01Cooooo0_l0000Sooooo`;o0000O_ooool00:cooooo0ol0000Dooooo`;o00006oooool2o`0008Ko
oooo0021ooooo`;o00002?ooool2o`0001oooooo00?o0000ooooooooool00ol0000^ooooo`;o0000
Q_ooool0087ooooo0_l00008ooooo`;o00007oooool00ol0003oooooooooo`03o`00017ooooo0_l0
000Looooo`;o0000QOooool00:cooooo00?o0000ooooooooool05?ooool2o`0001cooooo0_l00025
ooooo`00[?ooool00ol0003oooooooooo`0@ooooo`;o00009?ooool2o`00087ooooo002Gooooo`;o
00004oooool00ol0003oooooooooo`0@ooooo`;o00008Oooool2o`000003ooooool0003o0000087o
oooo002=ooooo`;o00000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o00000_ooool2ob4Q8@Go
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo017ooooo0_l0000Poooo
o`Go0000POooool008gooooo0_l00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_l00003oooo
o`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00oooooo1?l0000Noooo
o`;o00000_ooool3o`00087ooooo002Aooooo`06oa0@4?ooooooooooooooool@413ooooo0_l0000=
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03oooool2o`00023ooooo0_l00000
0ooooooo0000o`000002o`00087ooooo002Aooooo`06o`000?ooooooooooooooool0003ooooo0_l0
000<ooooo`03ogMgMolb<S;ooooo00Cooooo1?l0000?ooooo`;o00006oooool2o`0000?ooooo1?l0
0023ooooo`00TOooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`04o`000?oooooo0000o`0000oooooo0_l0000Kooooo`;o00000oooool2o`0008Go
oooo002Aooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00gooooo0_l0002Zooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0=ooooo`;o0000Z_ooool0097ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`;o00001_ooool4o`0000Kooooo00?o0000oooooooo
ool03Oooool2o`0002Cooooo0_l00024ooooo`00S_ooool2o`0000[ooooo0ol0000=ooooo`?o0000
3_ooool4o`0002?ooooo0_l00024ooooo`00S_ooool2o`0000[ooooo0ol0000=ooooo`?o00003_oo
ool4o`000:Wooooo0023ooooo`;o00005Oooool2o`0000?ooooo0_l0000;ooooo`03o`000?oooooo
oooo00gooooo0_l0002Zooooo`00Poooool2o`0001Wooooo0ol0000;ooooo`?o00003Oooool4o`00
0:Sooooo002@ooooo`;o00003?ooool2o`0000?ooooo0_l00005ooooo`?o00004Oooool2o`0001_o
oooo0ol0002:ooooo`00T?ooool2o`0000cooooo0_l00003ooooo`;o00000oooool5o`0002kooooo
0ol0002:ooooo`00W_ooool2o`0000Cooooo0_l00002ooooo`;o00000_ooool00ol0003ooooooooo
o`0[ooooo`;o0000S?ooool00:Cooooo0_l00006ooooo`03o`000?oooooooooo02_ooooo1Ol00029
ooooo`00[?ooool00ol0003oooooooooo`0/ooooo`Co0000ROooool00:cooooo00?o0000oooooooo
ool0;?ooool2o`0008_ooooo002/ooooo`03o`000?oooooooooo00[ooooo0_l0002]ooooo`00[?oo
ool3o`0000Wooooo0ol0002]ooooo`00[?ooool00ol0003oooooooooo`09ooooo`;o0000[_ooool0
0:cooooo00?o0000ooooooooool0:Oooool3o`0008gooooo002/ooooo`03o`000?oooooooooo00[o
oooo0_l0000Mooooo`?o0000SOooool00:cooooo00?o0000ooooooooool02_ooool2o`0001Sooooo
0_l000001?oooooo0000o`000?ooool2o`0008gooooo002/ooooo`03o`000?oooooooooo02Cooooo
0_l000000ooooooo0000o`000003o`0008gooooo002Dooooo`;o00005_ooool00ol0003ooooooooo
o`0Yooooo`Co0000S?ooool009Cooooo0_l0000Fooooo`03o`000?oooooooooo02;ooooo0_l00004
ooooo`Go0000S?ooool00:cooooo0ol0000Rooooo`;o00000oooool5o`0008gooooo002/ooooo`03
o`000?oooooooooo02Oooooo0_l0002@ooooo`00[?ooool00ol0003oooooooooo`0Xooooo`;o0000
Soooool00:cooooo00Co0000oooooooooooooooo0_l0000Pooooo`;o00000oooool2o`0008oooooo
002/ooooo`04o`000?ooooooooooooooo`;o00008?ooool4o`0009;ooooo002/ooooo`03o`000?oo
oooooooo02?ooooo1?l0002Booooo`00[?ooool00ol0003oooooooooo`0Sooooo`;o0000U?ooool0
09Oooooo0_l0000Cooooo`03o`000?oooooooooo027ooooo1?l0002Dooooo`00Uoooool2o`0001?o
oooo0ol0000Pooooo`?o0000U_ooool00:cooooo0ol0000Pooooo`;o0000Uoooool00:cooooo00?o
0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00[?ooool3o`000;Wooooo0028ooooo`;o
00005?ooool2o`0000[ooooo1?l0002jooooo`00R?ooool2o`000004oc8b<_l0003o<S8bonk^kPGo
oooo0_lQ8B46ooooo`03o`000?o^k^kooooo00;o00000_ooool01Om4A4Co0000o`000?lb<S;ogMgM
00?ooooo0ol0000Looooo`;o00000oooool2o`0009Sooooo0029ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool00_l00005ooooo`03ogMgMol0003o0000
00Cooooo00?o0000ooooooooool06_ooool2o`0000?ooooo0_l0002Hooooo`00ROooool01Ol@413o
oooooooooooooooo410@00gooooo00?oZJVYo`000?l000002?ooool2o`0000;ooooo0ol0002koooo
o`00ROooool01Ol0003ooooooooooooooooo000000kooooo0_l00007ooooo`03ogMgMolb<S;ooooo
00;ooooo1Ol0002iooooo`00ROooool01Ol0003ooooooooooooooooo000000kooooo00CoEEEEolc<
c?l0003o00000_ooool00ol0003o8B4Qo`000002o`0000Gooooo00?o0000ooooooooool0^Oooool0
08Wooooo00Go410@oooooooooooooooooa0@400>ooooo`04ojVYZOmgMgOo0000o`0000;ooooo00?o
0000ooooooooool00_l00002ooooo`;o000000?oooooo`000?ooool0^_ooool008Wooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool3o`0000Cooooo
0_l000000ooooooo0000ooooo`2jooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`2iooooo`00Y?ooool2o`0000Kooooo00?o
0000ooooooooool05?ooool3o`0000?ooooo0_l0002Mooooo`00[?ooool00ol0003oooooooooo`0D
ooooo`Go000000?oooooo`000?l00000WOooool00:cooooo00?o0000ooooooooool05oooool3o`00
09oooooo002/ooooo`?o00004_ooool3o`000003ooooool0003o000000;o0000Woooool00:cooooo
00?o0000ooooooooool04_ooool3o`000004ooooool0003o0000o`000:3ooooo002/ooooo`03o`00
0?oooooooooo01Oooooo0_l0002Pooooo`00[?ooool00ol0003oooooooooo`0@ooooo`;o0000Yooo
ool00:cooooo00?o0000ooooooooool04?ooool3o`000:Kooooo002/ooooo`03o`000?oooooooooo
017ooooo0_l0002Vooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool3o`0000gooooo0_l0002Zooooo`00[?ooool00ol0003oooooooooo`0=
ooooo`;o00000_ooool2o`000:Kooooo002/ooooo`03o`000?oooooooooo017ooooo0_l0002Voooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0@ooooo`;o0000
Yoooool00:cooooo00?o0000ooooooooool04?ooool2o`000:Oooooo002Aooooo`;o00006Oooool0
0ol0003oooooooooo`0?ooooo`;o0000Z?ooool0097ooooo0_l0000Iooooo`03o`000?oooooooooo
00Oooooo0_l00006ooooo`;o0000Z?ooool009;ooooo0_l0000Hooooo`03o`000?oooooooooo00Oo
oooo0_l0002`ooooo`00T_ooool2o`0001Sooooo0ol0002iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`02ooooo`;o0000]Oooool00:cooooo00?o0000ooooooooool0
0_ooool2o`000;Gooooo002Eooooo`;o00005Oooool00ol0003oooooooooo`03ooooo`;o0000]?oo
ool009Gooooo0_l0000Eooooo`03o`000?oooooooooo00?ooooo0_l0002dooooo`00UOooool2o`00
01Gooooo0ol00004ooooo`;o0000/oooool00:cooooo00?o0000ooooooooool01?ooool2o`000;?o
oooo002/ooooo`?o000000?oooooo`000?l00000]_ooool00:cooooo0ol000000ooooooo0000o`00
002fooooo`00[?ooool00ol0003oooooooooo`2iooooo`00VOooool2o`00017ooooo00?o0000oooo
ooooool0^Oooool009Wooooo0_l00007ooooo`Co000000?o410@ooooooooool00oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`?o0000^Oooool00:7ooooo0_l0
00000ooooooo0000ooooo`06ooooo`?o0000^Oooool00:7ooooo0_l000000ooooooo0000ooooo`32
ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00
Y?ooool00ol0003oooooooooo`31ooooo`00X_ooool00omEEEGoIVIVo`000033ooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Z_ooool01?l@413o0000o`00
0?l0002jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2j
ooooo`00Zoooool01_l0003oMgMgo`000?l0003oEEEEonk^k[Oooooo002[ooooo`06o`000?mEEEGo
k^k^oooooomgMgOoEEEE]oooool00:_ooooo00?o0000onk^k_ooool00_ooool00ol0003ooooooooo
o`2eooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo0;Gooooo002[oooo
o`06o`000?mEEEGok^k^oooooomgMgOoIVIV]oooool00:[ooooo00?o410@o`000?mgMgL00_l00000
0omVIVKok^k^ooooo`2fooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.48707 .89416 Mdot
.42437 .84289 Mdot
.45134 .41437 Mdot
.47263 .24734 Mdot
.41729 .68423 Mdot
.58608 .72162 Mdot
.45496 .64854 Mdot
.72979 .51256 Mdot
.71085 .50778 Mdot
.56419 .47884 Mdot
.55845 .6017 Mdot
.71855 .60562 Mdot
.37958 .49313 Mdot
.56908 .49874 Mdot
.68444 .7002 Mdot
.52201 .31177 Mdot
.60947 .44464 Mdot
.37954 .47441 Mdot
.507 .76975 Mdot
.53368 .10408 Mdot
.40272 .22637 Mdot
.38315 .54631 Mdot
.39822 .2725 Mdot
.38522 .35259 Mdot
.67119 .74591 Mdot
.43422 .21718 Mdot
.52891 .7014 Mdot
.48805 .79425 Mdot
.56802 .14955 Mdot
.39825 .72221 Mdot
.46461 .08077 Mdot
.71259 .4733 Mdot
.72128 .53993 Mdot
.61246 .55658 Mdot
.6198 .56582 Mdot
.57281 .17447 Mdot
.67319 .33916 Mdot
.49987 .77263 Mdot
.62462 .24794 Mdot
.72576 .58783 Mdot
.69838 .69374 Mdot
.61798 .55101 Mdot
.60133 .66493 Mdot
.51762 .8645 Mdot
.54248 .82177 Mdot
.40224 .47949 Mdot
.56109 .56702 Mdot
.70123 .40054 Mdot
.52274 .20941 Mdot
.59736 .20121 Mdot
.70201 .41258 Mdot
.62647 .23934 Mdot
.35367 .49827 Mdot
.6032 .64739 Mdot
.61878 .59923 Mdot
.71517 .53141 Mdot
.72791 .53632 Mdot
.60596 .41194 Mdot
.68876 .36961 Mdot
.55123 .80629 Mdot
.4088 .36346 Mdot
.62262 .85702 Mdot
.63789 .2785 Mdot
.45144 .71439 Mdot
.70473 .61054 Mdot
.71576 .48714 Mdot
.56332 .48924 Mdot
.53048 .34378 Mdot
.52041 .73576 Mdot
.40346 .21571 Mdot
.60136 .36871 Mdot
.43339 .51992 Mdot
.56297 .52587 Mdot
.55743 .43312 Mdot
.63805 .279 Mdot
.49587 .387 Mdot
.35369 .49356 Mdot
.46691 .177 Mdot
.61275 .21591 Mdot
.5628 .30646 Mdot
.51878 .10935 Mdot
.39448 .69017 Mdot
.47011 .25178 Mdot
.62003 .54366 Mdot
.72553 .49267 Mdot
.50175 .25863 Mdot
.41469 .66857 Mdot
.40819 .39476 Mdot
.59395 .35982 Mdot
.53521 .35989 Mdot
.66166 .76337 Mdot
.42265 .97386 Mdot
.42879 .63302 Mdot
.40293 .50955 Mdot
.43018 .63662 Mdot
.5686 .49532 Mdot
.70536 .46097 Mdot
.35355 .46941 Mdot
.58531 .32548 Mdot
.46073 .89388 Mdot
.57375 .30245 Mdot
.70941 .63357 Mdot
.49138 .89773 Mdot
.45391 .08023 Mdot
.61225 .56696 Mdot
.61144 .4169 Mdot
.49629 .79177 Mdot
.42884 .63394 Mdot
.41681 .16146 Mdot
.56667 .4743 Mdot
.45073 .27002 Mdot
.71182 .47814 Mdot
.53066 .10746 Mdot
.51937 .38761 Mdot
.4272 .2535 Mdot
.71911 .45259 Mdot
.71617 .45243 Mdot
.68098 .38159 Mdot
.38064 .44413 Mdot
.65456 .80607 Mdot
.42822 .14036 Mdot
.56197 .13898 Mdot
.41045 .18433 Mdot
.49469 .2621 Mdot
.55501 .13953 Mdot
.39828 .70666 Mdot
.5293 .56229 Mdot
.38489 .40323 Mdot
.43192 .85107 Mdot
.7096 .645 Mdot
.5974 .70023 Mdot
.5956 .68746 Mdot
.58561 .17073 Mdot
.64725 .26637 Mdot
.56823 .15419 Mdot
.56233 .52854 Mdot
.71558 .5854 Mdot
.69044 .68943 Mdot
.54046 .95912 Mdot
.42067 .43713 Mdot
.52077 .73927 Mdot
.60913 .43866 Mdot
.52754 .09931 Mdot
.72338 .47717 Mdot
.42875 .71922 Mdot
.40931 .37638 Mdot
.69172 .74167 Mdot
.56341 .27816 Mdot
.54778 .66419 Mdot
.38241 .38764 Mdot
.43589 .56359 Mdot
.53372 .81975 Mdot
.65007 .28163 Mdot
.63292 .26164 Mdot
.71893 .47646 Mdot
.67734 .35659 Mdot
.64925 .27755 Mdot
.47107 .15969 Mdot
.60298 .19705 Mdot
.72677 .61891 Mdot
.56223 .16383 Mdot
.5814 .71073 Mdot
.44068 .86484 Mdot
.72234 .48021 Mdot
.45854 .0736 Mdot
.52161 .73169 Mdot
.63299 .24004 Mdot
.60003 .21294 Mdot
.42628 .39508 Mdot
.51733 .73569 Mdot
.40521 .54406 Mdot
.43425 .74453 Mdot
.71458 .57757 Mdot
.53253 .82037 Mdot
.52724 .44894 Mdot
.59307 .18957 Mdot
.61764 .21456 Mdot
.71994 .62078 Mdot
.54098 .35792 Mdot
.69683 .69998 Mdot
.51739 .63627 Mdot
.70802 .5236 Mdot
.71099 .43218 Mdot
.72513 .62003 Mdot
.60473 .66099 Mdot
.66593 .78249 Mdot
.52292 .09312 Mdot
.46116 .72579 Mdot
.6127 .86602 Mdot
.72714 .50764 Mdot
.70305 .69775 Mdot
.71054 .63562 Mdot
.40342 .5152 Mdot
.42165 .97849 Mdot
.61722 .43213 Mdot
.51765 .39854 Mdot
.51936 .40575 Mdot
.433 .48659 Mdot
.40836 .59749 Mdot
.40202 .92505 Mdot
.43137 .84694 Mdot
.48031 .72497 Mdot
.57225 .75222 Mdot
.43081 .33644 Mdot
.52277 .62718 Mdot
.56259 .58678 Mdot
.38492 .62895 Mdot
.45602 .18634 Mdot
.46223 .07117 Mdot
.54399 .37819 Mdot
.43271 .84793 Mdot
.4536 .19181 Mdot
.72336 .63098 Mdot
.52892 .59257 Mdot
.52351 .84252 Mdot
.72911 .56259 Mdot
.4206 .28262 Mdot
.69683 .41825 Mdot
.44196 .09363 Mdot
.5434 .14134 Mdot
.54533 .3957 Mdot
.43038 .74031 Mdot
.46098 .90709 Mdot
.42086 .47735 Mdot
.68535 .69903 Mdot
.66261 .79681 Mdot
.50034 .26376 Mdot
.50446 .6005 Mdot
.37714 .80554 Mdot
.5713 .31072 Mdot
.54556 .65873 Mdot
.65266 .80564 Mdot
.51242 .74771 Mdot
.48395 .90394 Mdot
.3991 .25439 Mdot
.44227 .87238 Mdot
.61393 .86778 Mdot
.60426 .67301 Mdot
.47016 .06379 Mdot
.60121 .36851 Mdot
.71302 .44838 Mdot
.42658 .60229 Mdot
.66122 .31899 Mdot
.60156 .42119 Mdot
.59951 .36269 Mdot
.63296 .26488 Mdot
.69958 .70243 Mdot
.51945 .38936 Mdot
.44557 .6908 Mdot
.6709 .34717 Mdot
.46645 .16818 Mdot
.51694 .73513 Mdot
.62619 .57656 Mdot
.49986 .40228 Mdot
.7239 .55167 Mdot
.69527 .38317 Mdot
.54707 .25428 Mdot
.54648 .65587 Mdot
.5477 .1454 Mdot
.53226 .50176 Mdot
.57126 .30105 Mdot
.48435 .89222 Mdot
.55429 .60528 Mdot
.56323 .7586 Mdot
.58965 .19959 Mdot
.50756 .19682 Mdot
.55761 .14707 Mdot
.62046 .59791 Mdot
.56291 .44949 Mdot
.5552 .27977 Mdot
.6438 .26663 Mdot
.53937 .34875 Mdot
.47508 .81224 Mdot
.70506 .42891 Mdot
.56805 .5515 Mdot
.55394 .78735 Mdot
.59678 .19263 Mdot
.53574 .49531 Mdot
.55639 .44399 Mdot
.67941 .36683 Mdot
.71457 .61161 Mdot
.49764 .79071 Mdot
.44238 .60809 Mdot
.40734 .54842 Mdot
.49516 .06566 Mdot
.40788 .38564 Mdot
.51354 .10495 Mdot
.69044 .3869 Mdot
.69588 .66744 Mdot
.69485 .41968 Mdot
.49177 .65446 Mdot
.67646 .32982 Mdot
.60252 .87475 Mdot
.47091 .05837 Mdot
.68743 .69127 Mdot
.53658 .24048 Mdot
.62264 .60811 Mdot
.43878 .86815 Mdot
.71312 .45962 Mdot
.68818 .71213 Mdot
.56236 .5664 Mdot
.70533 .44133 Mdot
.46991 .16537 Mdot
.5033 .34779 Mdot
.38167 .55424 Mdot
.61103 .44824 Mdot
.38248 .40952 Mdot
.69265 .73643 Mdot
.52719 .43163 Mdot
.50869 .86442 Mdot
.61427 .56056 Mdot
.70316 .62245 Mdot
.53276 .47482 Mdot
.71604 .63476 Mdot
.63493 .82211 Mdot
.55893 .9449 Mdot
.50582 .28074 Mdot
.60523 .68344 Mdot
.62213 .53082 Mdot
.64691 .29577 Mdot
.44522 .78541 Mdot
.4976 .32396 Mdot
.47244 .67192 Mdot
.60969 .41392 Mdot
.73002 .5429 Mdot
.67369 .36306 Mdot
.43616 .67027 Mdot
.38478 .61304 Mdot
.53107 .5544 Mdot
.43346 .47018 Mdot
.45389 .90102 Mdot
.59471 .70119 Mdot
.58191 .70995 Mdot
.47487 .1596 Mdot
.40898 .60145 Mdot
.36012 .67297 Mdot
.49188 .17559 Mdot
.39164 .65558 Mdot
.44036 .68002 Mdot
.71709 .54557 Mdot
.53045 .6956 Mdot
.56785 .15529 Mdot
.38394 .50394 Mdot
.42117 .56577 Mdot
.44232 .21634 Mdot
.54841 .95074 Mdot
.7227 .58812 Mdot
.66925 .30635 Mdot
.57272 .17222 Mdot
.51552 .2023 Mdot
.61795 .45797 Mdot
.58972 .19513 Mdot
.57024 .30276 Mdot
.72156 .59204 Mdot
.58041 .92399 Mdot
.4741 .06266 Mdot
.70776 .64864 Mdot
.71426 .64213 Mdot
.71171 .66624 Mdot
.43842 .40183 Mdot
.56342 .29333 Mdot
.68627 .69899 Mdot
.72622 .54104 Mdot
.44039 .38673 Mdot
.48681 .0774 Mdot
.51721 .21837 Mdot
.5831 .73297 Mdot
.4672 .89693 Mdot
.70703 .47498 Mdot
.481 .90447 Mdot
.67727 .34433 Mdot
.66585 .34465 Mdot
.39739 .2801 Mdot
.65959 .2841 Mdot
.38632 .38482 Mdot
.67959 .72518 Mdot
.68679 .4043 Mdot
.54571 .80404 Mdot
.43446 .51928 Mdot
.65752 .78269 Mdot
.58613 .3329 Mdot
.47574 .67154 Mdot
.7233 .6132 Mdot
.40608 .2027 Mdot
.48909 .30643 Mdot
.56034 .45534 Mdot
.43471 .221 Mdot
.53934 .67849 Mdot
.70272 .40105 Mdot
.41811 .14582 Mdot
.60472 .87465 Mdot
.71953 .62438 Mdot
.61548 .4893 Mdot
.35737 .61606 Mdot
.61726 .47816 Mdot
.44265 .76868 Mdot
.44759 .78377 Mdot
.51318 .49972 Mdot
.7278 .54963 Mdot
.71811 .60547 Mdot
.53156 .69447 Mdot
.41997 .48341 Mdot
.56765 .58036 Mdot
.51885 .2953 Mdot
.6927 .72857 Mdot
.40617 .59841 Mdot
.54755 .14107 Mdot
.43324 .33404 Mdot
.54182 .68088 Mdot
.5331 .50816 Mdot
.40851 .61932 Mdot
.61274 .54559 Mdot
.5527 .64328 Mdot
.47532 .72731 Mdot
.67318 .77545 Mdot
.71699 .578 Mdot
.4496 .55063 Mdot
.61968 .57326 Mdot
.61173 .41919 Mdot
.49673 .87302 Mdot
.52647 .23389 Mdot
.52342 .72519 Mdot
.66734 .76822 Mdot
.45666 .89691 Mdot
.39466 .08045 Mdot
.51857 .86536 Mdot
.4792 .73008 Mdot
.70723 .55103 Mdot
.68173 .71042 Mdot
.55014 .63505 Mdot
.38521 .43976 Mdot
.35679 .62009 Mdot
.42144 .44009 Mdot
.47957 .30014 Mdot
.4215 .68982 Mdot
.53537 .12751 Mdot
.54675 .26911 Mdot
.42195 .97611 Mdot
.51696 .64226 Mdot
.60527 .63242 Mdot
.62105 .52138 Mdot
.4468 .7069 Mdot
.52905 .45592 Mdot
.54871 .38188 Mdot
.72928 .51852 Mdot
.52807 .42847 Mdot
.59989 .19418 Mdot
.44111 .88024 Mdot
.52338 .8473 Mdot
.55369 .13938 Mdot
.50517 .0966 Mdot
.61355 .46105 Mdot
.52906 .98725 Mdot
.56115 .45876 Mdot
.73034 .54449 Mdot
.70474 .69129 Mdot
.55 .6221 Mdot
.67348 .31937 Mdot
.51842 .21734 Mdot
.60827 .46062 Mdot
.56254 .14746 Mdot
.46865 .89889 Mdot
.49251 .79364 Mdot
.44003 .22117 Mdot
.61503 .53723 Mdot
.65051 .82023 Mdot
.58216 .71592 Mdot
.48526 .35964 Mdot
.59437 .67873 Mdot
.55867 .29352 Mdot
.43339 .45361 Mdot
.52247 .32397 Mdot
.60686 .63465 Mdot
.60693 .65719 Mdot
.5182 .39115 Mdot
.46672 .17051 Mdot
.71595 .49057 Mdot
.42795 .73807 Mdot
.49007 .88704 Mdot
.54095 .69401 Mdot
.46028 .78965 Mdot
.45091 .33791 Mdot
.40437 .0419 Mdot
.46 .31733 Mdot
.43854 .87774 Mdot
.6993 .45296 Mdot
.5587 .15709 Mdot
.51605 .746 Mdot
.57853 .1684 Mdot
.71953 .61533 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool008cooooo0_l0000N
ooooo`03o`000?oooooooooo0;Wooooo002<ooooo`;o00007_ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002Rooooo`;o00002?ooool00ol0003oooooooooo`2iooooo`00X_ooool2o`00
00Sooooo00?o0000ooooooooool0^Oooool00:;ooooo0ol00007ooooo`03o`000?oooooooooo0;Wo
oooo002Rooooo`?o00001Oooool3o`000;_ooooo002Oooooo`;o00002Oooool3o`000;_ooooo002N
ooooo`?o00002oooool00ol0003oooooooooo`2iooooo`00W_ooool2o`0000Oooooo0_l00003oooo
o`?o0000^Oooool008Wooooo0_l0000Aooooo`;o00002Oooool2o`0000?ooooo00?o0000oooooooo
ool0^Oooool008Wooooo0_l0000Aooooo`;o00000_ooool2o`0000[ooooo00?o0000ooooooooool0
^Oooool00:3ooooo0_l0000:ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Hooooo`;o00004_ooool00ol0003o
ooooooooo`04ooooo`;o0000/oooool009Sooooo0_l0000Booooo`?o00001?ooool2o`000;?ooooo
002/ooooo`?o00001_ooool2o`000;7ooooo002/ooooo`03o`000?oooooooooo00Kooooo1?l0002_
ooooo`00[?ooool01?l0003oooooooooooooool2o`0000Cooooo0ol0002_ooooo`00[?ooool01?l0
003oooooooooooooool4o`0000;ooooo0_l0002`ooooo`00[?ooool00ol0003oooooooooo`03oooo
o`;o0000]?ooool00:cooooo00?o0000ooooooooool0^Oooool008Wooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`2iooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`2iooooo`00POooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=oooo
o`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000;Wooooo0029ooooo`05
o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool02?ooool2o`000:oooooo0029ooooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`08ooooo`;o0000[oooool008Wooooo00Go410@oooooooooooooooooa0@400>
ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2i
ooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b
<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0^Oooool008Wooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP06ooooo`;o00000oooool5o`0000Cooooo1?l00006ooooo`03o`000?oo
oooooooo00kooooo1Ol0002Vooooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool02oooool8
o`000:Kooooo002Aooooo`;o00006Oooool00ol0003oooooooooo`0;ooooo`?o00000_ooool2o`00
0:Oooooo002Aooooo`;o00006Oooool00ol0003oooooooooo`0<ooooo`;o00000_ooool5o`000:Co
oooo002/ooooo`?o00004Oooool4o`000:Cooooo002/ooooo`03o`000?oooooooooo01?ooooo0_l0
002Tooooo`00[?ooool00ol0003oooooooooo`0@ooooo`;o000000?oooooo`000?l00000Y?ooool0
093ooooo0_l0000@ooooo`?o00001oooool00ol0003oooooooooo`0@ooooo`;o0000Yoooool0093o
oooo0_l0000@ooooo`?o00001oooool00ol0003oooooooooo`0Aooooo`;o0000Y_ooool00:3ooooo
1?l00008ooooo`03o`000?oooooooooo017ooooo0_l0002Vooooo`00X?ooool4o`0000Sooooo00?o
0000ooooooooool05_ooool2o`000003ooooool0003o000009kooooo002Qooooo`;o00002Oooool0
0ol0003oooooooooo`0Eooooo`?o000000?oooooo`000?l00000W_ooool00:7ooooo0_l00006oooo
o`;o000000Coooooo`000?l0003o00005Oooool2o`000:;ooooo002Qooooo`;o00001_ooool2o`00
0003ooooool0003ooooo01Kooooo0_l0002Rooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
S_ooool2o`0000gooooo0_l0000=ooooo`03o`000?oooooooooo0;Wooooo002>ooooo`;o00003Ooo
ool2o`0000gooooo00?o0000ooooooooool0^Oooool009cooooo0_l0000>ooooo`03o`000?oooooo
oooo01_ooooo0_l0002Looooo`00W?ooool2o`0000kooooo00?o0000ooooooooool06_ooool6o`00
09Wooooo002/ooooo`04o`000?oooooo0000o`0001Wooooo0_l000000ooooooo0000o`000002o`00
09Sooooo002/ooooo`Co00006Oooool2o`000003ooooool0003o000000;o0000V?ooool008gooooo
0_l0000Mooooo`03o`000?oooooooooo00;ooooo0_l0000Fooooo`;o000000?oooooo`000?l00000
V_ooool008gooooo0_l0000Mooooo`03o`000?oooooooooo00;ooooo0_l0002eooooo`00[?ooool0
0ol0003oooooooooo`04ooooo`;o0000/oooool00:cooooo00?o0000ooooooooool01?ooool2o`00
01Sooooo0_l0002Iooooo`00S?ooool2o`0000_ooooo0_l0000Aooooo`03o`000?oooooooooo01ko
oooo0_l00002ooooo`?o0000U?ooool008cooooo0_l00008ooooo`;o000000?oooooo`000?l00000
4Oooool00ol0003oooooooooo`02ooooo`?o00007Oooool3o`0009Cooooo002Fooooo`Co00004_oo
ool00ol0003oooooooooo`02ooooo`?o0000]?ooool009Kooooo1?l0000Booooo`?o0000^Oooool0
08_ooooo0_l0000Oooooo`03o`000?oooooooooo0;Wooooo002;ooooo`;o00007oooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`05ooooo`;o0000/_ooool00:cooooo00?o
0000ooooooooool01Oooool2o`000;;ooooo002/ooooo`03o`000?oooooooooo00Wooooo0_l0000K
ooooo`Co0000Soooool0097ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool02Oooool2o`0001_ooooo1?l0
002?ooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0^Oooool008Wooooo1_l00002ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool2o`000003ooooool0003ooooo00Cooooo00?o0000ooooooooool09_oo
ool2o`00097ooooo002Aooooo`05o`000?ooooooooooooooool000003?ooool3o`000003ogMgMolb
<S;ooooo00Cooooo0ol0000Vooooo`;o0000TOooool008[ooooo0_l00005ooooo`03o`000?oooooo
oooo00;o00003?ooool3o`000003oc8b<_o<c<cooooo00Cooooo00?o0000ooooooooool03?ooool2
o`000:_ooooo002:ooooo`;o00001Oooool00ol@413oooooooooo`02o`0000cooooo00?o0000oooo
ooooool01oooool2o`0000gooooo0_l0002[ooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool01Oooool4o`0002Wooooo0_l0002?ooooo`00TOooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00cooooo1?l00004ooooo`Co0000:Oooool2o`0008oooooo002/ooooo`;o
0000:Oooool2o`0000;ooooo0ol0002:ooooo`00Voooool2o`0000oooooo00?o0000ooooooooool0
3?ooool2o`0001kooooo0ol0002:ooooo`00R_ooool2o`0000oooooo0_l0000?ooooo`03o`000?oo
oooooooo00cooooo0_l0002[ooooo`00R_ooool2o`00023ooooo0ol0002iooooo`00R_ooool2o`00
023ooooo00?o0000ooooooooool03oooool4o`0001Oooooo0_l00002ooooo`;o0000ROooool008[o
oooo0_l00005ooooo`;o00006Oooool3o`0000oooooo1?l0000Gooooo`;o00000_ooool2o`0008Wo
oooo002Aooooo`;o00006Oooool3o`0002kooooo0_l000000ooooooo0000o`000026ooooo`00[?oo
ool00ol0003oooooooooo`0aooooo`;o0000Q_ooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool00oooool2o`0000_ooooo0ol0002Vooooo`00[?ooool00ol0003o
ooooooooo`03ooooo`;o00002oooool3o`0001[ooooo0_l0002:ooooo`00YOooool2o`0000Gooooo
0ol0000Dooooo`;o00005oooool2o`0008[ooooo002Uooooo`;o00001Oooool00ol0003ooooooooo
o`0Dooooo`?o0000X_ooool00:Sooooo0_l00002ooooo`03o`000?oooooooooo017ooooo0_l00000
1?oooooo0000o`000?l0000Mooooo`;o0000Poooool00:Sooooo0_l00002ooooo`03o`000?oooooo
oooo017ooooo0_l0000Qooooo`;o0000Poooool00:cooooo00?o0000ooooooooool01?ooool2o`00
00kooooo0_l0002Sooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o00003_ooool2o`000:?o
oooo002Nooooo`;o00003?ooool00ol0003oooooooooo`0booooo`;o00000_ooool2o`00087ooooo
002Nooooo`;o00003?ooool00ol0003oooooooooo`0booooo`;o00000_ooool2o`00087ooooo002[
ooooo`Co00001?ooool2o`0001?ooooo0_l0002Nooooo`00Zoooool2o`0000Kooooo0_l0000Coooo
o`;o0000W_ooool00:cooooo00?o0000ooooooooool0=oooool2o`00083ooooo002Fooooo`;o0000
5?ooool00ol0003oooooooooo`0Iooooo`;o00007?ooool2o`00083ooooo002Eooooo`?o00000ooo
ool2o`0000oooooo00?o0000ooooooooool06Oooool2o`0009kooooo002Eooooo`;o00001?ooool2
o`0000oooooo00?o0000ooooooooool0=_ooool2o`00087ooooo002/ooooo`03o`000?oooooooooo
00Oooooo0_l0000]ooooo`;o0000POooool00:cooooo00?o0000ooooooooool01oooool2o`0002[o
oooo0_l00002ooooo`;o0000P?ooool00:cooooo0ol0000:ooooo`;o00009oooool6o`00083ooooo
0026ooooo`;o00009?ooool3o`0000[ooooo0_l0000Yooooo`;o0000P_ooool008Kooooo0_l0000T
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00[ooooo0_l0000[oooo
o`;o0000P?ooool00:Oooooo0_l00003ooooo`03o`000?oooooooooo00Sooooo1?l0000@ooooo`;o
00006Oooool2o`00083ooooo002=ooooo`;o00006?ooool2o`0000?ooooo00?o0000ooooooooool0
2?ooool2o`0001;ooooo0ol0000Gooooo`;o0000POooool008Wooooo00Cok^k^oc8b<_l0003o<S8b
0_l00004ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo01gooooo0_l0000Gooooo`Co0000Ooooool008Wooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`0Nooooo`;o00006?ooool2o`000003ooooool0003o0000
07cooooo0021ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q
8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01kooooo0_l0000Koooo
o`;o0000O?ooool008Wooooo00Co0000oooooooooooooooo0ol0000;ooooo`03oiRHV?lQ8B7ok^k^
00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`000;Wooooo0029ooooo`04o`000?oooooooooooooo
o`?o00003?ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`0;ooooo`;o0000[?ooool008Wooooo00Go410@oooooooooooooooooa0@400?
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0;
ooooo`Co0000:Oooool2o`0000?ooooo0_l0001jooooo`00Q_ooool2o`000005oooooomgMgOoV9RH
oooooonHV9P00_l0000:ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00gooooo0_l0000Yooooo`;o00000oooool2o`0007[ooooo0025
ooooo`?o000000Goooooonk^k_lb<S;o0000oc8b<P02o`0000Wooooo0_l000001?l@413o0000ob4Q
8Oo<c<`4ooooo`Co00001?ooool3o`0000Gooooo0_l0000fooooo`;o0000O?ooool008Gooooo0_l0
000Aooooo`;o00004?ooool3o`0000Gooooo0_l0000fooooo`;o0000O?ooool008gooooo0_l00004
ooooo`;o00005oooool00ol0003oooooooooo`03ooooo`;o0000]?ooool008gooooo0_l00004oooo
o`;o00005oooool00ol0003oooooooooo`0<ooooo`;o0000Zoooool00:cooooo0ol00002ooooo`;o
00002?ooool2o`00037ooooo0_l0001hooooo`00Q_ooool2o`0000oooooo0_l0000Cooooo`;o0000
0oooool2o`0003Kooooo0_l00003ooooo`;o0000N?ooool008Kooooo0_l0000?ooooo`;o00004ooo
ool2o`0000Cooooo0_l0000eooooo`;o0000OOooool008Gooooo0_l0000Uooooo`03o`000?oooooo
oooo00?ooooo0_l0002dooooo`00QOooool2o`0002Gooooo00?o0000ooooooooool08?ooool2o`00
01gooooo0_l0001hooooo`00Voooool2o`0000oooooo00?o0000ooooooooool08?ooool3o`0001co
oooo0_l0001hooooo`00Voooool2o`0000oooooo00?o0000ooooooooool08Oooool2o`0001[ooooo
0ol0001iooooo`00[?ooool00ol0003oooooooooo`0Nooooo`;o000000?oooooo`000?l000006_oo
ool3o`0007Wooooo002/ooooo`?o00007_ooool2o`0009Wooooo002/ooooo`03o`000?oooooooooo
00Kooooo0_l0002aooooo`00[?ooool00ol0003oooooooooo`06ooooo`;o0000>?ooool2o`0007Oo
oooo002/ooooo`03o`000?oooooooooo00Kooooo0_l00008ooooo`;o00004Oooool2o`0001_ooooo
1?l0001eooooo`00TOooool2o`0001Wooooo00?o0000ooooooooool04?ooool2o`00017ooooo0_l0
000Mooooo`;o0000MOooool008Kooooo0_l00009ooooo`?o00006?ooool00ol0003oooooooooo`0Q
ooooo`;o0000U_ooool008Kooooo0_l0000:ooooo`;o00006?ooool00ol0003oooooooooo`0Qoooo
o`;o00007Oooool2o`0007Oooooo0024ooooo`;o00009_ooool00ol0003oooooooooo`0?ooooo`;o
00004?ooool2o`0001gooooo0_l0001gooooo`00Q?ooool2o`0002Kooooo00?o0000ooooooooool0
1_ooool2o`0000Oooooo1?l0000>ooooo`;o00008?ooool2o`0007Cooooo002/ooooo`?o00001_oo
ool2o`0000Wooooo0_l0000>ooooo`;o00006oooool2o`0000?ooooo1?l0001booooo`00U_ooool2
o`0001Cooooo00?o0000ooooooooool01_ooool2o`0000Sooooo0_l0000/ooooo`;o00001?ooool3
o`0007;ooooo002Fooooo`;o00005?ooool00ol0003oooooooooo`06ooooo`;o00002?ooool3o`00
017ooooo0_l0002Cooooo`002Oooool4o`000003oa0@4?oooooooooo01Kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000
oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0
003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go
00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Kooooo00?o0000ooooooooool04Oooool2o`00
00Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`Ko00000_ooool5o`0000Cooooo00GoA4A4
o`000?l0003o<S8bomgMg@0:ooooo`;o000000Soooooo`000?l0003ok^k^oc8b<_l0003o<S8bonk^
kPGooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8b
omgMg@0Hooooo`Co000000?o410@ooooooooool04_ooool000_ooooo00?o0000ooooooooool06?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo
00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03
ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnH
V9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool05Oooool00ol0003oooooooooo`0H
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool4o`0000Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A007ooooo`03ogMgMolb<S;ooooo00Wooooo0_l000002?oooooo0000o`000?mgMgOoV9RHoooo
oonHV9SoMgMg1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool06Ooo
ool00ol0003oooooooooo`0Dooooo`001_l00005ooooo`03o`000?oooooooooo013ooooo1_l00002
ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oo
oooooooo00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooo
ooooo`05ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^
k^h02Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Sooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool03Oooool01Ol@
413ooooooooooooooooo410@013ooooo00?o0000ooooooooool03Oooool01Ol@413ooooooooooooo
oooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooo
oooooooo000000oooooo00?oMgMgoc8b<_ooool03_ooool00ol0003oooooooooo`02o`0000gooooo
00?oV9RHob4Q8Oo^k^h01oooool01?mgMgOo<S8bo`000?l0000Dooooo`03o`000?oooooooooo01So
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b
<_ooool03_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool03_ooool0
1Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8boooo
o`0Iooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go0000
ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00?ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00oooooo00?o0000ooooooooool00_l0000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c002o`0001Cooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooo
oooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00gooooo
0ol00003ooooo`03o`000?oooooooooo00[ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05
o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`06_ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hoooo
o`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooo
oooo017ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo017ooooo00Go
410@oooooooooooooooooa0@4007ooooo`;o00001_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01Sooooo0ol00007ooooo`;o00002_ooool2o`0000?ooooo00Go410@oooooooooooo
oooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool7o`000003
ooooool@413ooooo00_ooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@
00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1oooool2o`0000;ooooo00?o0000okZj^_ooool00_l00004ooooo`;o00006Oooool00ol0003ooooo
ooooo`07ooooo`;o00002Oooool3o`0000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`;o
00000oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool03Oooool3o`00
0006ooooool0003o0000o`000?nHV9SoMgMg3?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Dooooo`002Oooool00omEEEGoIVIVo`00000Jooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`03oiRHV?l@413o
000000;o00001?ooool4o`0001Oooooo00?o0000ooooooooool04_ooool2o`0000Cooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP06ooooo`;o00000oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo
1?l0000=ooooo`;o000000Koooooonk^k_l0003o0000oc8b<_o^k^h<ooooo`Co00004?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00006Oooool00omEEEGoIVIVo`00000F
ooooo`00TOooool2o`0001Wooooo00?o0000ooooooooool0^Oooool0097ooooo0_l00002ooooo`;o
00005Oooool00ol0003oooooooooo`0Aooooo`;o00004?ooool2o`0001oooooo0_l0001cooooo`00
UOooool2o`0001Gooooo00?o0000ooooooooool04Oooool2o`00013ooooo0_l0000Oooooo`;o0000
J?ooool2o`0000;ooooo0_l00005ooooo`00Noooool2o`0000Oooooo0_l0000Vooooo`03o`000?oo
oooooooo00Sooooo0_l00009ooooo`;o0000;oooool2o`000003ooooool0003o000006Gooooo00Ko
k^k^ob4Q8On7QhOo^[Zjo`000?oMgMd5ooooo`00Noooool2o`0000Oooooo0_l0000Vooooo`03o`00
0?oooooooooo00Sooooo0_l00009ooooo`;o0000<_ooool2o`0006Kooooo00CogMgMo`000?l@413o
c<c<1_ooool000Ooooooool0001<o`0000cooooo00Cok^k^ob4Q8Ol@413ok^k^1_ooool000Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00Co0000ooooool0003o00001?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`04o`000?oooooooooooooo
o`;o00000oooool3o`0000Gooooo00?o0000ooooooooool00_ooool2o`000003ooooool0003ooooo
00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`04ob4Q8OmgMgOoMgMg
oc8b<PKooooo0007ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0Vooooo`04o`000?oooooo0000o`0002Gooooo00?o0000ooooooooool01oooool2
o`0001kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool02Oooool2o`0000;ooooo0_l00005ooooo`00S?ooool2o`00
01kooooo00?o0000ooooooooool01oooool2o`0003Wooooo0_l00004ooooo`;o0000Koooool008co
oooo0_l0000Nooooo`03o`000?oooooooooo00Oooooo0_l0000iooooo`;o00001?ooool2o`0006oo
oooo002<ooooo`;o00007_ooool00ol0003oooooooooo`18ooooo`;o0000Koooool008cooooo0_l0
0008ooooo`;o00005?ooool00ol0003oooooooooo`18ooooo`;o0000Koooool009Kooooo0_l0000D
ooooo`03o`000?oooooooooo02Gooooo0_l0000Qooooo`;o0000Koooool009Kooooo0_l0000Doooo
o`?o00009Oooool2o`0001[ooooo0_l0001fooooo`00[?ooool00ol0003oooooooooo`0Aooooo`;o
0000;_ooool2o`0007Kooooo002/ooooo`03o`000?oooooooooo017ooooo0_l0000Booooo`;o0000
7Oooool2o`0007?ooooo002/ooooo`03o`000?oooooooooo02Gooooo0_l0000Mooooo`;o0000Looo
ool00:cooooo00?o0000ooooooooool08oooool2o`0002?ooooo0_l0001_ooooo`00[?ooool00ol0
003oooooooooo`0Sooooo`;o00008Oooool4o`0006oooooo002/ooooo`03o`000?oooooooooo02Co
oooo0_l0000Pooooo`Co0000Koooool008Gooooo0_l00005ooooo`;o00007_ooool00ol0003ooooo
ooooo`0Rooooo`Co00007_ooool2o`000003ooooool0003o000000;o0000K_ooool008Gooooo0_l0
0005ooooo`?o00007Oooool00ol0003oooooooooo`0Rooooo`;o00008?ooool2o`0000;ooooo0ol0
001^ooooo`00SOooool2o`0000cooooo0_l0000?ooooo`?o00004oooool2o`0000oooooo0_l0000K
ooooo`;o00000oooool4o`0006oooooo0025ooooo`;o00005?ooool2o`0000oooooo00?o0000oooo
ooooool01oooool2o`0000[ooooo0_l0000?ooooo`;o00006oooool2o`0000?ooooo0_l0001aoooo
o`00QOooool2o`0002Gooooo00?o0000ooooooooool01oooool2o`0001Wooooo0_l0002Eooooo`00
[?ooool00ol0003oooooooooo`0Rooooo`;o0000UOooool009Kooooo0_l0000Dooooo`03o`000?oo
oooooooo00Kooooo0_l0000Jooooo`;o00009?ooool2o`0006oooooo002Booooo`;o00000_ooool2
o`0001Cooooo00?o0000ooooooooool01_ooool2o`0000Wooooo0_l0000?ooooo`Co00008_ooool2
o`0006oooooo002Booooo`;o00006?ooool00ol0003oooooooooo`0Aooooo`;o00003oooool4o`00
09?ooooo002/ooooo`03o`000?oooooooooo02Cooooo0_l0002Cooooo`00[?ooool3o`0002Cooooo
1?l0002Aooooo`00[?ooool00ol0003oooooooooo`0Vooooo`;o00006oooool3o`0007?ooooo002/
ooooo`03o`000?oooooooooo01?ooooo0_l0000^ooooo`?o0000Loooool00:cooooo00?o0000oooo
ooooool04oooool2o`0002oooooo0_l0001cooooo`00[?ooool00ol0003oooooooooo`0Aooooo`;o
0000<Oooool5o`00073ooooo002/ooooo`03o`000?oooooooooo017ooooo0_l0000cooooo`?o0000
L?ooool00:cooooo00?o0000ooooooooool01_ooool2o`0003kooooo0_l0001aooooo`00SOooool2
o`0001gooooo00?o0000ooooooooool01_ooool2o`0001cooooo0_l0002Cooooo`00SOooool3o`00
01cooooo0ol0000Tooooo`;o0000Toooool008kooooo0_l00003ooooo`;o00005oooool3o`00013o
oooo0_l0000Booooo`;o0000Toooool009?ooooo0_l0000Gooooo`03o`000?oooooooooo00kooooo
1?l0000cooooo`;o0000L_ooool009Wooooo0_l0000Aooooo`03o`000?oooooooooo00kooooo0_l0
000Eooooo`;o00006Oooool2o`0000?ooooo0_l0001booooo`00Q_ooool2o`00017ooooo0_l0000A
ooooo`03o`000?oooooooooo02Gooooo0_l0000Iooooo`;o000000Coooooo`000?l0003ooooo0_l0
001aooooo`00O?ooool2o`0000Sooooo0_l0000Tooooo`03o`000?oooooooooo04?ooooo1Ol0001a
ooooo`00O?ooool2o`0000_ooooo00Cok^k^oc8b<_l0003o<S8b0_l00004ooooo`;o8B4Q1?ooool5
o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo04Gooooo1?l0
001`ooooo`00O?ooool2o`0000_ooooo00CoMgMgoiRHV?ooooooV9RH0_l00004ooooo`;o8B4Q1?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`0=ooooo`;o0000<Oooool2o`0000?ooooo1?l0001`ooooo`00O?ooool2o`0000_ooooo00Go
410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool0
0oooool3o`0000gooooo0_l0000aooooo`;o00000oooool4o`00073ooooo0029ooooo`05o`000?oo
ooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool01?ooool2o`0003oooooo0_l0001booooo`00Q_ooool2o`000003ooooool0
003ooooo00;ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`04ooooo`;o0000@?ooool2o`00077ooooo
0026ooooo`;o000000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`04ooooo`;o00001ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07ooo
ool3o`00023ooooo1_l0001aooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo0ol0
0002ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00;ooooo0_l00009ooooo`;o00004?ooool3o`00023ooooo1?l0001cooooo`00ROoo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo0_l00002ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`01?ooool4o`0000Kooooo00?o0000ooooooooool00_ooool2o`0000Wooooo0_l0000cooooo`;o
0000MOooool00:cooooo00?o0000ooooooooool00_ooool2o`0000[ooooo0_l0000cooooo`;o0000
M?ooool00:cooooo00?o0000ooooooooool00_ooool2o`0000[ooooo0_l0000booooo`?o0000M?oo
ool009gooooo0_l0000=ooooo`03o`000?oooooooooo01oooooo0_l0000Pooooo`?o0000MOooool0
09gooooo0_l0000=ooooo`?o00007oooool2o`00023ooooo0_l0001fooooo`00R?ooool2o`0001oo
oooo0_l000000ooooooo0000ooooo`0=ooooo`;o0000Zoooool008Sooooo0_l0000Oooooo`;o0000
00?oooooo`000?ooool03Oooool2o`0001;ooooo0_l0002Gooooo`00[?ooool00ol0003ooooooooo
o`0<ooooo`;o00004Oooool3o`0009Oooooo002/ooooo`03o`000?oooooooooo00cooooo0_l0000@
ooooo`?o0000V?ooool00:cooooo00?o0000ooooooooool03?ooool2o`00013ooooo0_l0000Moooo
o`;o00000oooool2o`0007Gooooo002?ooooo`;o00001Oooool2o`0001Cooooo00?o0000oooooooo
ool0?Oooool2o`0000?ooooo0_l0001eooooo`00OOooool2o`00013ooooo0_l00005ooooo`;o0000
2_ooool4o`0000Kooooo00?o0000ooooooooool07oooool2o`0009Sooooo001mooooo`;o00008ooo
ool4o`0000Kooooo0ol0000Oooooo`;o0000V?ooool009Sooooo0_l0000Booooo`03o`000?oooooo
oooo00[ooooo0_l0000@ooooo`;o0000Voooool009Sooooo0_l0000Booooo`03o`000?oooooooooo
00[ooooo0_l0000@ooooo`;o0000Voooool0093ooooo0_l0000Jooooo`03o`000?oooooooooo00[o
oooo0_l0000Cooooo`;o0000V?ooool0093ooooo0_l0000Jooooo`03o`000?oooooooooo01cooooo
0_l000000ooooooo0000o`00002Hooooo`00ROooool2o`0000Oooooo0_l00006ooooo`;o00004?oo
ool00ol0003oooooooooo`0Looooo`;o00007?ooool3o`0000?ooooo0_l0001gooooo`00ROooool2
o`0000Oooooo0_l00006ooooo`;o00004?ooool00ol0003oooooooooo`07ooooo`;o000000?ooooo
o`000?l00000;_ooool3o`000003ooooool0003o000000;o0000Moooool00:cooooo00?o0000oooo
ooooool01oooool2o`000003ooooool0003o000003;ooooo1?l0001gooooo`00[?ooool3o`0000Ko
oooo0ol0000Cooooo`?o00006_ooool3o`0000;ooooo1?l0001gooooo`00[?ooool00ol0003ooooo
ooooo`06ooooo`;o00005?ooool3o`0001[ooooo0ol00002ooooo`;o0000NOooool008[ooooo0_l0
000>ooooo`;o00004?ooool00ol0003oooooooooo`0nooooo`;o0000NOooool008[ooooo0_l0000>
ooooo`;o00004?ooool00ol0003oooooooooo`0Hooooo`;o00007oooool2o`0007kooooo002/oooo
o`03o`000?oooooooooo01Oooooo0ol0000Oooooo`Co0000O?ooool009cooooo0_l0000>ooooo`03
o`000?oooooooooo01Oooooo0ol0000Qooooo`;o0000O?ooool009Cooooo0_l00006ooooo`;o0000
3_ooool00ol0003oooooooooo`0Hooooo`;o0000Woooool008[ooooo0_l00008ooooo`;o00005_oo
ool00ol0003oooooooooo`0Iooooo`;o0000W_ooool008[ooooo0_l0000Iooooo`;o00001Oooool3
o`0000Cooooo0_l0000Cooooo`;o00007Oooool2o`0007oooooo002Oooooo`;o00000_ooool4o`00
00Gooooo00?o0000ooooooooool01?ooool2o`0003;ooooo0_l00002ooooo`;o0000Noooool009oo
oooo0_l00002ooooo`Co00001Oooool00ol0003oooooooooo`04ooooo`;o0000=_ooool2o`0007_o
oooo002Uooooo`;o00001Oooool00ol0003oooooooooo`04ooooo`;o00004_ooool2o`0009oooooo
002/ooooo`03o`000?oooooooooo00;ooooo0ol0000Cooooo`;o00008_ooool2o`0007_ooooo002D
ooooo`?o00005Oooool00ol0003oooooooooo`02ooooo`?o0000=oooool2o`0007_ooooo002Aoooo
o`03onk^k_lb<S;o000000?o00001?ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo00?ooooo0_l0000gooooo`;o0000Noooool0097ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`02o`0000?ooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool00_ooool2o`00037ooooo0_l00005ooooo`;o0000Noooool0097ooooo00Go410@oooo
oooooooooooooa0@4002o`0000kooooo00?o0000ooooooooool00oooool01?l0003ooooooooooooo
ool3o`00037ooooo0_l00022ooooo`00TOooool01Ol0003ooooooooooooooooo000000oooooo00?o
MgMgoc8b<_ooool01?ooool3o`000003ooooool0003o0000017ooooo0_l0002Sooooo`00TOooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo01Cooooo0_l0002Sooooo`00TOooool01Ol@413ooooooooooooooooo410@00cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Aooooo`;o0000Y_ooool0097ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
4Oooool2o`000:Kooooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo
00?o0000ooooooooool0<_ooool2o`0008Gooooo002/ooooo`03o`000?oooooooooo03;ooooo0_l0
0025ooooo`00VOooool2o`00017ooooo00Co0000ooooool0003o0000<oooool2o`0008?ooooo002I
ooooo`;o00004Oooool4o`0003?ooooo0_l00023ooooo`00[?ooool3o`0003Kooooo0_l00021oooo
o`00[?ooool00ol0003oooooooooo`0fooooo`;o0000POooool00:cooooo00?o0000ooooooooool0
<Oooool4o`0008Cooooo002Iooooo`?o00004?ooool00ol0003oooooooooo`0aooooo`Co0000Q?oo
ool009Wooooo0ol0000@ooooo`03o`000?oooooooooo00kooooo0_l0002Yooooo`00W_ooool2o`00
00[ooooo0ol0000@ooooo`;o0000ZOooool009kooooo0_l00008ooooo`Go0000^oooool00:Sooooo
0ol000000ooooooo0000ooooo`0cooooo`;o0000QOooool00:cooooo0ol0000booooo`;o0000QOoo
ool00:cooooo00?o0000ooooooooool03?ooool2o`000:_ooooo0023ooooo`;o00009oooool00ol0
003oooooooooo`0<ooooo`?o00008?ooool3o`0008Oooooo0023ooooo`;o00009oooool00ol0003o
ooooooooo`0=ooooo`;o00008?ooool3o`0008Oooooo002Sooooo`;o00001oooool00ol0003ooooo
ooooo`2iooooo`00Xoooool2o`0000Oooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool01oooool3o`000003ooooool0003o0000
01cooooo0_l00003ooooo`;o0000ROooool00:cooooo0ol00007ooooo`?o000000?oooooo`000?l0
00007?ooool2o`0000?ooooo0_l00029ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00Toooool2o`0001Oooooo
00?o0000ooooooooool01?ooool2o`000;?ooooo002Cooooo`;o00005oooool00ol0003ooooooooo
o`04ooooo`;o0000/oooool009Gooooo0_l0000Eooooo`03o`000?oooooooooo00Cooooo0_l0002c
ooooo`00UOooool2o`0001Gooooo0ol00004ooooo`;o0000/oooool009Gooooo0_l0000Eooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo02Gooooo0_l0002Booooo`00[?oo
ool00ol0003oooooooooo`0Uooooo`;o0000T_ooool009Sooooo0_l0000Booooo`05o`000?oooooo
0000o`000?ooool00_l0002eooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B43ooooo`;o000000?oooooo`000?o^k^h01Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo
00Go0000ooooool0003o0000ooooo`03o`0001gooooo0_l0002Eooooo`00ROooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B42ooooo`;o00000_ooool00omEEEGoZJVYooooo`07ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool00oooool2o`0001gooooo0_l0002Eooooo`00
ROooool01Ol@413ooooooooooooooooo410@00Wooooo1?l000000onYZJWoEEEEooooo`08ooooo`04
o`000?ooooooooooooooo`?o0000^oooool008Wooooo00Go0000ooooooooooooooooo`00000;oooo
o`;o000000?oooooob4Q8Oooool01oooool00omgMgOo<S8booooo`02ooooo`Go00007_ooool3o`00
09Sooooo0029ooooo`05o`000?ooooooooooooooool000002Oooool2o`0000?ooooo00?oEEEEolc<
c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool07_ooool3
o`0009Sooooo0029ooooo`05oa0@4?ooooooooooooooool@41002Oooool3o`0000;ooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Wooooo0029oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02_ooool2o`0000?ooooo00?o<S8booooooooool00_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool5o`0000Cooooo1?l00002ooooo`;o00000_ooool00ol0003oooooooooo`2i
ooooo`00Y_ooool4o`0000;ooooo00?o0000ooooooooool0^Oooool009oooooo0_l00005ooooo`?o
00000oooool00ol0003oooooooooo`2iooooo`00WOooool6o`0000Cooooo1?l000000ooooooo0000
ooooo`2jooooo`00W?ooool3o`0000;ooooo0_l00006ooooo`;o000000Coooooo`000?l0003o0000
^Oooool009cooooo0_l00003ooooo`;o00000oooool2o`0000Cooooo00?o0000ooooooooool0^Ooo
ool009oooooo0_l00004ooooo`?o00001?ooool00ol0003oooooooooo`2iooooo`00Woooool2o`00
00Cooooo0_l00005ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`03o`000?oooooooooo0;Wooooo002;ooooo`;o00007oooool3o`0001Oooooo0_l0002Poooo
o`00Roooool2o`0001oooooo00?o0000ooooooooool05oooool2o`000:3ooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo013ooooo0_l0002Wooooo`00[?ooool00ol0003ooooooooo
o`0@ooooo`;o0000Yoooool00:cooooo0ol0000=ooooo`;o0000Z_ooool00:cooooo00?o0000oooo
ooooool03Oooool2o`000:[ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo00[ooooo0_l0002]ooooo`00[?ooool00ol0003oooooooooo`0:ooooo`;o0000[Ooo
ool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool009;o
oooo0_l0000Hooooo`03o`000?oooooooooo0;Wooooo002Booooo`;o00006?ooool3o`000;Wooooo
002Booooo`;o00006?ooool00ol0003oooooooooo`2iooooo`00T_ooool2o`0001Sooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool01_ooool2o`000;7ooooo002/ooooo`03o`000?oooooooooo00Kooooo0_l0002aooooo`00X_oo
ool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05oooo
o`?o0000^Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0
`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool0
0:;ooooo00?oEEEEofIVI_l00000`oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00:[ooooo00Co410@o`000?l0003o0000^_ooool00:_ooooo00?o0000oooo
ooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00Ko0000ogMgMol0003o
0000oeEEEOo^k^jgooooo`00Zoooool01_l0003oEEEEonk^k_ooooooMgMgoeEEEKOooooo002[oooo
o`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0]Oooool00:_ooooo00?o0000onk^k_oo
ool00_ooool00ol0003oooooooooo`2eooooo`00Zoooool01_l0003oEEEEonk^k_ooooooMgMgofIV
I[Oooooo002Zooooo`03oa0@4?l0003oMgMg00;o000000?oIVIVonk^k_ooool0]_ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.6064 .69844 Mdot
.57139 .79144 Mdot
.46142 .62183 Mdot
.42035 .565 Mdot
.52884 .74332 Mdot
.63473 .52162 Mdot
.51247 .57166 Mdot
.69481 .31256 Mdot
.67397 .30778 Mdot
.51572 .27884 Mdot
.55913 .4017 Mdot
.7208 .40562 Mdot
.49414 .91812 Mdot
.52858 .29874 Mdot
.72451 .5002 Mdot
.42896 .33403 Mdot
.54732 .24464 Mdot
.49006 .92234 Mdot
.57491 .56975 Mdot
.38201 .32678 Mdot
.4309 .87478 Mdot
.50498 .89165 Mdot
.44195 .88447 Mdot
.46224 .9239 Mdot
.72956 .54591 Mdot
.42208 .73924 Mdot
.56947 .5014 Mdot
.56765 .59918 Mdot
.40513 .17487 Mdot
.54203 .83567 Mdot
.38573 .63608 Mdot
.6619 .2733 Mdot
.69725 .33993 Mdot
.5951 .35658 Mdot
.60613 .36582 Mdot
.41503 .15453 Mdot
.56885 .13916 Mdot
.56892 .57263 Mdot
.48386 .05382 Mdot
.72089 .38783 Mdot
.73588 .49374 Mdot
.59839 .35101 Mdot
.6273 .46493 Mdot
.62342 .6645 Mdot
.63119 .62177 Mdot
.48626 .82214 Mdot
.5479 .36702 Mdot
.62144 .20054 Mdot
.40502 .35261 Mdot
.44134 .0799 Mdot
.62704 .21258 Mdot
.48229 .04629 Mdot
.62215 .44739 Mdot
.61847 .39923 Mdot
.68774 .33141 Mdot
.70244 .33632 Mdot
.53074 .21194 Mdot
.5966 .16961 Mdot
.63375 .60629 Mdot
.45951 .81857 Mdot
.72543 .65702 Mdot
.50929 .0785 Mdot
.53096 .61662 Mdot
.70894 .41054 Mdot
.67062 .28714 Mdot
.51901 .28924 Mdot
.44008 .29262 Mdot
.57471 .53576 Mdot
.42841 .87387 Mdot
.50884 .16871 Mdot
.48835 .67737 Mdot
.53332 .32587 Mdot
.49072 .23645 Mdot
.50965 .079 Mdot
.44582 .43334 Mdot
.40623 .60521 Mdot
.46015 .05106 Mdot
.44936 .18439 Mdot
.3822 .39206 Mdot
.53502 .84399 Mdot
.42187 .57507 Mdot
.59749 .34366 Mdot
.6826 .29267 Mdot
.41655 .43538 Mdot
.52562 .75106 Mdot
.46648 .81446 Mdot
.49788 .15996 Mdot
.44707 .27253 Mdot
.72701 .56337 Mdot
.61341 .89172 Mdot
.51428 .68334 Mdot
.49268 .81262 Mdot
.51482 .67758 Mdot
.64597 .84777 Mdot
.52673 .29532 Mdot
.64975 .26097 Mdot
.47587 .14188 Mdot
.59254 .73275 Mdot
.4569 .15543 Mdot
.72284 .43357 Mdot
.61121 .69961 Mdot
.38792 .68288 Mdot
.59903 .36696 Mdot
.5382 .2169 Mdot
.57319 .59224 Mdot
.51449 .68323 Mdot
.41368 .82731 Mdot
.51639 .2743 Mdot
.43004 .65574 Mdot
.66308 .27814 Mdot
.38241 .33944 Mdot
.3731 .81855 Mdot
.447 .33021 Mdot
.43153 .76202 Mdot
.66015 .25259 Mdot
.65714 .25243 Mdot
.59361 .18159 Mdot
.48322 .92409 Mdot
.73699 .60607 Mdot
.40661 .78205 Mdot
.39924 .19996 Mdot
.42005 .85014 Mdot
.4188 .4655 Mdot
.39643 .22801 Mdot
.6634 .81709 Mdot
.5382 .83127 Mdot
.51422 .36229 Mdot
.47337 .91438 Mdot
.57373 .77228 Mdot
.7276 .445 Mdot
.6375 .50023 Mdot
.63058 .48746 Mdot
.42227 .11152 Mdot
.5138 .06637 Mdot
.40655 .17351 Mdot
.53375 .32854 Mdot
.70974 .3854 Mdot
.72621 .48943 Mdot
.68411 .75912 Mdot
.47303 .75083 Mdot
.57647 .53927 Mdot
.54459 .23866 Mdot
.38024 .35512 Mdot
.67425 .27717 Mdot
.35139 .60044 Mdot
.53551 .70696 Mdot
.46223 .81358 Mdot
.74839 .54167 Mdot
.44061 .18145 Mdot
.57345 .46419 Mdot
.4705 .92859 Mdot
.49734 .65699 Mdot
.62162 .61975 Mdot
.52272 .08163 Mdot
.49757 .06177 Mdot
.66951 .27646 Mdot
.57997 .15659 Mdot
.52028 .07755 Mdot
.40156 .59077 Mdot
.44461 .0655 Mdot
.73434 .41891 Mdot
.40615 .19517 Mdot
.6257 .51073 Mdot
.57851 .75623 Mdot
.67443 .28021 Mdot
.38547 .66411 Mdot
.57429 .53169 Mdot
.48903 .04268 Mdot
.44771 .0757 Mdot
.46264 .73543 Mdot
.5716 .53569 Mdot
.49972 .79519 Mdot
.54157 .69729 Mdot
.70561 .37757 Mdot
.64926 .8412 Mdot
.62068 .62037 Mdot
.46922 .29585 Mdot
.43393 .08987 Mdot
.4642 .04252 Mdot
.72826 .42078 Mdot
.45008 .25252 Mdot
.73682 .49998 Mdot
.5319 .43627 Mdot
.67746 .3236 Mdot
.65447 .82838 Mdot
.64386 .23218 Mdot
.73314 .42003 Mdot
.62913 .46099 Mdot
.73893 .58249 Mdot
.3786 .37706 Mdot
.53398 .59127 Mdot
.71911 .66602 Mdot
.6902 .30764 Mdot
.74215 .49775 Mdot
.72479 .43562 Mdot
.4938 .80927 Mdot
.61488 .89812 Mdot
.55007 .23213 Mdot
.44918 .33536 Mdot
.45173 .32705 Mdot
.48116 .68629 Mdot
.51075 .77401 Mdot
.5976 .9208 Mdot
.57243 .77114 Mdot
.53686 .5427 Mdot
.63313 .55222 Mdot
.44885 .72834 Mdot
.53364 .42718 Mdot
.5573 .38678 Mdot
.5229 .87883 Mdot
.41063 .65074 Mdot
.38414 .64855 Mdot
.45866 .24313 Mdot
.57273 .76756 Mdot
.41235 .66011 Mdot
.73575 .43098 Mdot
.52595 .39257 Mdot
.62052 .64252 Mdot
.71414 .36259 Mdot
.43931 .78454 Mdot
.62413 .21825 Mdot
.39343 .73218 Mdot
.39297 .27652 Mdot
.46563 .24126 Mdot
.54094 .71007 Mdot
.5975 .74425 Mdot
.48177 .74127 Mdot
.72496 .49903 Mdot
.74134 .59681 Mdot
.41795 .44047 Mdot
.50466 .4005 Mdot
.5672 .95296 Mdot
.45773 .16287 Mdot
.56905 .45873 Mdot
.73491 .60564 Mdot
.5715 .54771 Mdot
.60802 .71038 Mdot
.4378 .88454 Mdot
.58118 .75772 Mdot
.72104 .66778 Mdot
.63347 .47301 Mdot
.38082 .61552 Mdot
.50861 .16851 Mdot
.65238 .24838 Mdot
.50785 .69238 Mdot
.54882 .11899 Mdot
.53004 .22119 Mdot
.50458 .16269 Mdot
.49891 .0649 Mdot
.74056 .50243 Mdot
.44748 .32958 Mdot
.52514 .62684 Mdot
.56977 .14717 Mdot
.40441 .60912 Mdot
.57099 .53513 Mdot
.61682 .37656 Mdot
.44829 .41259 Mdot
.70457 .35167 Mdot
.60853 .18317 Mdot
.42358 .24101 Mdot
.56883 .45587 Mdot
.39529 .2574 Mdot
.49299 .30433 Mdot
.45432 .16119 Mdot
.60367 .69853 Mdot
.5564 .40528 Mdot
.62667 .5586 Mdot
.43461 .10029 Mdot
.40218 .4231 Mdot
.39948 .21612 Mdot
.61963 .39791 Mdot
.50271 .24949 Mdot
.43554 .20835 Mdot
.51046 .06663 Mdot
.44629 .25862 Mdot
.56748 .63234 Mdot
.63663 .22891 Mdot
.54865 .3515 Mdot
.62888 .58735 Mdot
.43792 .08018 Mdot
.49389 .29719 Mdot
.494 .24543 Mdot
.58614 .16683 Mdot
.71922 .41161 Mdot
.574 .5909 Mdot
.50569 .62156 Mdot
.50021 .78494 Mdot
.37582 .50593 Mdot
.46456 .81782 Mdot
.38143 .41641 Mdot
.64902 .83551 Mdot
.6052 .1869 Mdot
.72286 .46744 Mdot
.62272 .21968 Mdot
.51531 .45906 Mdot
.56839 .12982 Mdot
.71242 .67475 Mdot
.37947 .61342 Mdot
.72393 .49127 Mdot
.34876 .4848 Mdot
.41558 .28598 Mdot
.62588 .40811 Mdot
.57948 .76419 Mdot
.65697 .25962 Mdot
.73303 .51213 Mdot
.54892 .3664 Mdot
.64186 .24133 Mdot
.40305 .59462 Mdot
.4358 .40922 Mdot
.50704 .89702 Mdot
.55032 .24824 Mdot
.47526 .92355 Mdot
.74722 .53643 Mdot
.46362 .29561 Mdot
.61445 .66442 Mdot
.5985 .36056 Mdot
.71214 .42245 Mdot
.48307 .28884 Mdot
.72994 .43476 Mdot
.72378 .62211 Mdot
.69689 .7449 Mdot
.4208 .41261 Mdot
.63861 .48344 Mdot
.59446 .33082 Mdot
.52522 .09577 Mdot
.5529 .68382 Mdot
.43168 .43939 Mdot
.51688 .51749 Mdot
.53526 .21392 Mdot
.70718 .3429 Mdot
.57891 .16306 Mdot
.52159 .65835 Mdot
.51936 .87912 Mdot
.51283 .3544 Mdot
.47748 .68782 Mdot
.59317 .7531 Mdot
.63519 .50119 Mdot
.62589 .50995 Mdot
.40072 .57422 Mdot
.51149 .77104 Mdot
.53834 .99299 Mdot
.40053 .49647 Mdot
.52752 .85097 Mdot
.52323 .6438 Mdot
.69532 .34557 Mdot
.56869 .4956 Mdot
.40666 .17477 Mdot
.49556 .89674 Mdot
.501 .72086 Mdot
.42015 .70406 Mdot
.68871 .75074 Mdot
.71795 .38812 Mdot
.55179 .10635 Mdot
.41431 .15505 Mdot
.40298 .38635 Mdot
.56114 .25797 Mdot
.43318 .09977 Mdot
.45406 .16404 Mdot
.71838 .39204 Mdot
.71001 .72399 Mdot
.37972 .59854 Mdot
.72722 .44864 Mdot
.73111 .44213 Mdot
.73821 .46624 Mdot
.46148 .68097 Mdot
.44551 .18182 Mdot
.72587 .49899 Mdot
.70263 .34104 Mdot
.45776 .67562 Mdot
.38019 .53984 Mdot
.40663 .37532 Mdot
.63628 .53297 Mdot
.59607 .72405 Mdot
.65702 .27498 Mdot
.60625 .71347 Mdot
.575 .14433 Mdot
.56371 .14465 Mdot
.44378 .88642 Mdot
.53323 .0841 Mdot
.46904 .9121 Mdot
.72966 .52518 Mdot
.36651 .77764 Mdot
.60851 .2043 Mdot
.62732 .60404 Mdot
.48798 .67285 Mdot
.7306 .58269 Mdot
.47952 .14483 Mdot
.51688 .50735 Mdot
.72858 .4132 Mdot
.42501 .86525 Mdot
.42969 .48034 Mdot
.50248 .25534 Mdot
.42281 .73627 Mdot
.57074 .47849 Mdot
.62315 .20105 Mdot
.40999 .82502 Mdot
.71458 .67465 Mdot
.72928 .42438 Mdot
.5712 .2893 Mdot
.56852 .27816 Mdot
.54782 .68111 Mdot
.55237 .67515 Mdot
.47527 .33975 Mdot
.70765 .34963 Mdot
.7203 .40547 Mdot
.56934 .49447 Mdot
.48328 .74385 Mdot
.5598 .38036 Mdot
.42443 .35132 Mdot
.74413 .52857 Mdot
.51143 .78371 Mdot
.39415 .25887 Mdot
.4478 .71825 Mdot
.57417 .48088 Mdot
.49637 .30886 Mdot
.51559 .77307 Mdot
.59097 .34559 Mdot
.57001 .44328 Mdot
.53618 .55471 Mdot
.74336 .57545 Mdot
.70819 .378 Mdot
.49155 .59995 Mdot
.60898 .37326 Mdot
.5394 .21919 Mdot
.60605 .67331 Mdot
.41129 .33087 Mdot
.57349 .52519 Mdot
.73463 .56822 Mdot
.65086 .84618 Mdot
.59243 .7436 Mdot
.40079 .94155 Mdot
.62471 .66536 Mdot
.53835 .54939 Mdot
.68764 .35103 Mdot
.7259 .51042 Mdot
.56416 .43505 Mdot
.48128 .90509 Mdot
.47351 .74682 Mdot
.43038 .52328 Mdot
.52936 .72676 Mdot
.38778 .3143 Mdot
.42754 .24019 Mdot
.61411 .89541 Mdot
.53386 .44226 Mdot
.61824 .43242 Mdot
.5896 .32138 Mdot
.52937 .62978 Mdot
.47301 .29164 Mdot
.46364 .2306 Mdot
.69669 .31852 Mdot
.46323 .29284 Mdot
.44101 .07244 Mdot
.58371 .76711 Mdot
.62231 .6473 Mdot
.39588 .23348 Mdot
.38055 .45542 Mdot
.55796 .26105 Mdot
.68396 .78725 Mdot
.50466 .25876 Mdot
.70814 .34449 Mdot
.74125 .49129 Mdot
.55883 .4221 Mdot
.56123 .11937 Mdot
.40646 .37014 Mdot
.55251 .26062 Mdot
.40181 .19639 Mdot
.59743 .72358 Mdot
.57072 .59557 Mdot
.42169 .71301 Mdot
.58992 .33723 Mdot
.7386 .62023 Mdot
.62853 .51592 Mdot
.44214 .48559 Mdot
.62586 .47873 Mdot
.44212 .19638 Mdot
.47387 .69171 Mdot
.43205 .32953 Mdot
.62071 .43465 Mdot
.6298 .45719 Mdot
.44749 .33445 Mdot
.40486 .60745 Mdot
.67217 .29057 Mdot
.54069 .71855 Mdot
.60589 .68961 Mdot
.57856 .49401 Mdot
.55519 .64332 Mdot
.44483 .64025 Mdot
.39027 .9075 Mdot
.43837 .60501 Mdot
.58264 .77228 Mdot
.64049 .25296 Mdot
.40263 .21009 Mdot
.57444 .546 Mdot
.41679 .135 Mdot
.72566 .41533 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:3ooooo0_l00006
ooooo`;o00000_ooool00ol0003oooooooooo`2iooooo`00X?ooool2o`0000Cooooo1?l00002oooo
o`03o`000?oooooooooo0;Wooooo002Vooooo`;o00001?ooool00ol0003oooooooooo`2iooooo`00
W_ooool2o`0000cooooo0ol0002iooooo`00W_ooool2o`0000Kooooo0_l00004ooooo`03o`000?oo
oooooooo0;Wooooo002Vooooo`;o00001?ooool00ol0003oooooooooo`2iooooo`00Zoooool2o`00
0;_ooooo002[ooooo`;o0000^oooool009Wooooo0_l0000@ooooo`;o00000_ooool3o`000;Kooooo
002Iooooo`;o00004Oooool00ol0003oooooooooo`03o`000;Kooooo002Hooooo`;o00004_ooool0
0ol0003oooooooooo`2iooooo`00V?ooool4o`00013ooooo0ol0002iooooo`00Uoooool5o`00013o
oooo00?o0000ooooooooool00_l000000ooooooo0000o`00002dooooo`00Uoooool3o`0001;ooooo
00?o0000ooooooooool00_l000001?oooooo0000o`000?l0002cooooo`00[?ooool00ol0003ooooo
ooooo`04ooooo`;o00000_ooool2o`000:oooooo002/ooooo`03o`000?oooooooooo00Sooooo0_l0
002_ooooo`00U_ooool2o`0001Cooooo00?o0000ooooooooool0^Oooool009Kooooo0_l0000Doooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00Gooooo0_l0002booooo`00
U_ooool2o`0001Cooooo0ol00005ooooo`;o0000/_ooool009Kooooo0_l0000Dooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00kooooo0_l0002Yooooo`00[?ooool00ol0
003oooooooooo`0>ooooo`;o0000ZOooool009;ooooo0_l0000Hooooo`03o`000?oooooooooo0;Wo
oooo002Booooo`;o00006?ooool00ol0003oooooooooo`2iooooo`00ROooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo00gooooo0_l00002ooooo`;o0000Y_ooool008Wooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool03Oooool2o`0000;ooooo0_l0002Vooooo`00
POooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00So
oooo00?o0000ooooooooool00oooool3o`000;Wooooo0029ooooo`05o`000?ooooooooooooooool0
00003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0^Oooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo01?ooooo0_l0002Toooo
o`00ROooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo01?ooooo0_l0002Tooooo`00ROooool01OmgMgOo
V9RHoooooonHV9SoMgMg00;ooooo0_l00007ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00_ooool2o`0000Oooooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`0C
ooooo`;o0000Y?ooool00:Cooooo0_l00006ooooo`03o`000?oooooooooo01?ooooo0_l0002Toooo
o`00Y?ooool3o`0000Gooooo00?o0000ooooooooool04_ooool2o`000003ooooool0003o00000:;o
oooo002Uooooo`;o00001Oooool00ol0003oooooooooo`0Booooo`Go0000X_ooool00:cooooo0ol0
000Dooooo`;o0000Xoooool008oooooo0ol0000;ooooo`;o00003Oooool00ol0003oooooooooo`2i
ooooo`00Soooool3o`0000_ooooo0_l0000=ooooo`03o`000?oooooooooo01Oooooo0_l0002Poooo
o`00W?ooool2o`0000gooooo0_l0000Iooooo`;o0000X?ooool009cooooo1?l0000;ooooo`Co0000
5oooool2o`000:3ooooo002Looooo`Co00003?ooool3o`0001Oooooo1?l0002Nooooo`00[?ooool0
1?l0003oooooo`000?l0000Hooooo`;o000000?oooooo`000?l00000Voooool008gooooo0_l0000M
ooooo`04o`000?oooooo0000o`0001_ooooo0_l0002Kooooo`00S?ooool3o`0001gooooo0ol0002i
ooooo`00S?ooool3o`0001gooooo00?o0000ooooooooool0^Oooool009Sooooo1?l0000@ooooo`03
o`000?oooooooooo01_ooooo0_l00003ooooo`;o0000Uoooool009Sooooo1Ol0000?ooooo`03o`00
0?oooooooooo01_ooooo0_l00003ooooo`;o0000Uoooool009_ooooo0_l0000?ooooo`03o`000?oo
oooooooo01oooooo0_l0002Hooooo`00[?ooool00ol0003oooooooooo`0Oooooo`;o0000V?ooool0
08gooooo0_l0000Mooooo`03o`000?oooooooooo0;Wooooo002;ooooo`Co00002Oooool2o`0001;o
oooo00?o0000ooooooooool0^Oooool008[ooooo0ol0000;ooooo`;o00004_ooool3o`0002Gooooo
0_l0002Booooo`00R_ooool2o`00023ooooo00?o0000ooooooooool08?ooool2o`0000?ooooo0_l0
002Booooo`00[?ooool00ol0003oooooooooo`0Pooooo`;o0000Uoooool008_ooooo0_l00009oooo
o`;o00005?ooool00ol0003oooooooooo`2iooooo`00Roooool2o`0000Wooooo0_l0000Dooooo`03
o`000?oooooooooo00Oooooo0_l0000Nooooo`;o0000T?ooool008[ooooo0_l0000Pooooo`03o`00
0?oooooooooo00Oooooo0ol0000Mooooo`;o0000T?ooool008[ooooo0_l0000Pooooo`03o`000?oo
oooooooo00Sooooo1?l0000Iooooo`?o0000TOooool00:cooooo00?o0000ooooooooool01_ooool2
o`000004ooooool0003o0000o`0001Wooooo0ol0002Aooooo`00[?ooool3o`0000Kooooo0_l0002a
ooooo`00ROooool2o`00027ooooo00?o0000ooooooooool0^Oooool008Wooooo0_l0000Eooooo`;o
00002_ooool00ol0003oooooooooo`0Zooooo`;o0000SOooool008Wooooo0_l0000Eooooo`;o0000
2_ooool00ol0003oooooooooo`0=ooooo`;o00006oooool4o`0008_ooooo0029ooooo`;o00007Ooo
ool2o`0000;ooooo00?o0000ooooooooool03Oooool2o`0001gooooo0_l0002;ooooo`00T_ooool4
o`0001;ooooo0_l00002ooooo`03o`000?oooooooooo00_ooooo0_l0002/ooooo`00TOooool00oo^
k^ko0000o`000002o`0000Gooooo0_lQ8B400ooooooo0000o`000002o`000005odA4A?l0003o0000
oc8b<_oMgMd01Oooool00ol0003oooooooooo`0;ooooo`;o00007_ooool2o`0008cooooo002Aoooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@03ooooool0003o000000;o00000oooool0
0omgMgOo<S8booooo`02ooooo`?o00003_ooool2o`0001gooooo0_l0002<ooooo`00ROooool6o`00
00;ooooo00Go410@oooooooooooooooooa0@400@ooooo`04o`000?ooooooooooooooo`Co00003Ooo
ool3o`00023ooooo0_l00028ooooo`00TOooool01Ol0003ooooooooooooooooo000000Gooooo0_l0
0008ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000=ooooo`;o00007?ooool2o`0000;ooooo1?l0
0026ooooo`00TOooool01Ol0003ooooooooooooooooo000000Gooooo0_l00005ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool2o`0002cooooo0_l00003ooooo`?o0000Q_ooool008Wooooo0_l0
0006ooooo`05oa0@4?ooooooooooooooool@41001?ooool2o`0000Kooooo00?o0000ooooooooool0
1oooool3o`00017ooooo0_l0002Vooooo`00ROooool2o`0000Kooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`04ooooo`;o00001_ooool00ol0003oooooooooo`07ooooo`?o00003_ooool5o`0001_ooooo
1?l00027ooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`03o`00
0?oooooooooo00kooooo1?l0000Looooo`Co0000Qoooool00:cooooo00?o0000ooooooooool0^Ooo
ool00:cooooo00?o0000ooooooooool0^Oooool009[ooooo0_l0000@ooooo`03o`000?oooooooooo
00;ooooo0_l0000^ooooo`;o0000QOooool008Sooooo0_l0000@ooooo`;o00004?ooool3o`0000;o
oooo0_l0000/ooooo`Co000000Coooooo`000?l0003o0000POooool008Sooooo0_l0000Rooooo`03
o`000?oooooooooo00;ooooo0_l0000?ooooo`;o00006oooool4o`000004ooooool0003o0000o`00
087ooooo002/ooooo`03o`000?oooooooooo00;ooooo0_l0000?ooooo`;o00007Oooool2o`0000;o
oooo0_l00021ooooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool0^Oooool0093ooooo0_l0
000Dooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00003oooool2o`0001oooooo0_l0
0022ooooo`00Xoooool2o`000003ooooool0003o000000Cooooo00?o0000ooooooooool00oooool2
o`0000oooooo0_l0000Oooooo`;o0000P_ooool009Sooooo0_l00005ooooo`;o00000_ooool2o`00
00Oooooo00?o0000ooooooooool01Oooool2o`0002kooooo0_l00002ooooo`;o0000O_ooool009So
oooo0_l00005ooooo`Co00001oooool3o`0000Oooooo0_l0000booooo`;o0000O_ooool00:3ooooo
0ol00007ooooo`Go00001_ooool2o`000;7ooooo002Yooooo`;o000000?oooooo`000?ooool01ooo
ool2o`000;7ooooo002Yooooo`;o000000?oooooo`000?ooool0??ooool2o`0007cooooo002Zoooo
o`?o0000>?ooool2o`0000?ooooo0_l0001looooo`00Z_ooool3o`0003Sooooo0_l00005ooooo`;o
0000N_ooool008Oooooo0_l0000Sooooo`03o`000?oooooooooo03gooooo0_l0001jooooo`00Qooo
ool2o`0002?ooooo00?o0000ooooooooool0?Oooool2o`0007[ooooo002/ooooo`03o`000?oooooo
oooo01[ooooo0_l0000Qooooo`;o0000N_ooool00:cooooo0ol0000Jooooo`;o00006oooool2o`00
083ooooo0025ooooo`;o00005Oooool2o`0000kooooo00?o0000ooooooooool02?ooool2o`0002go
oooo0_l00020ooooo`00QOooool2o`0000Oooooo0_l00005ooooo`;o00000oooool4o`0000kooooo
00?o0000ooooooooool02?ooool2o`0001;ooooo0_l0000Mooooo`;o0000O?ooool008kooooo0_l0
0004ooooo`?o00000oooool2o`00013ooooo00?o0000ooooooooool07?ooool2o`0001gooooo0_l0
001looooo`00U?ooool2o`0000Cooooo0ol0000?ooooo`03o`000?oooooooooo01[ooooo0_l0000S
ooooo`;o0000N?ooool008Gooooo0_l0000Dooooo`;o00001_ooool2o`0000Oooooo00?o0000oooo
ooooool06_ooool2o`0002;ooooo0ol0001hooooo`00QOooool2o`0001cooooo0_l00007ooooo`03
o`000?oooooooooo01gooooo0_l0000Oooooo`Go0000M_ooool00:cooooo00?o0000ooooooooool0
6oooool4o`0001kooooo1_l0001fooooo`00[?ooool00ol0003oooooooooo`0Kooooo`;o00008?oo
ool2o`0000;ooooo0_l0001fooooo`00S?ooool2o`0000Gooooo0_l0000Gooooo`?o00003Oooool2
o`0000kooooo0_l0000Looooo`;o00000oooool3o`0007Kooooo0024ooooo`;o00001_ooool2o`00
00Gooooo0_l0000Gooooo`04o`000?ooooooooooooooo`;o00002_ooool2o`0000kooooo0_l0000L
ooooo`;o00000oooool2o`0007Oooooo0024ooooo`;o00009_ooool01?l0003oooooooooooooool2
o`0001Wooooo0_l0002Kooooo`00[?ooool00ol0003oooooooooo`0Looooo`?o0000V_ooool00:co
oooo00Co0000oooooooooooooooo0_l0000Jooooo`;o00009?ooool2o`0007Cooooo0029ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool01?l0003oooooooooooooool2o`0000Wooooo0ol0000>ooooo`;o000000?o
ooooo`000?l000008Oooool2o`0007Cooooo0029ooooo`04ogMgMonHV9SooooooiRHV0;o00001?oo
ool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool03?ooool3o`0000kooooo0_l000000ooooooo0000o`00002Gooooo`00POoo
ool6o`0000;ooooo00Co410@oooooooooooooooo0_l0000;ooooo`03oiRHV?lQ8B7ok^k^00Wooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Qooooo`;o0000U_ooool008?ooooo0_l0
0004ooooo`04o`000?ooooooooooooooo`;o00003?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMg
Molb<S;ooooo00Cooooo0ol0000Qooooo`Co0000U?ooool008?ooooo0_l00004ooooo`04o`000?oo
ooooooooooooo`;o00003Oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`0Sooooo`;o00006oooool3o`0007Kooooo0029ooooo`05oa0@
4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool04?ooool2o`0002kooooo0ol0001fooooo`00ROooool00omgMgOoV9RH
ooooo`02o`0000_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool04?ooool2o`00033ooooo0_l0001eooooo`00ROooool00oo^k^ko<S8b
o`000002o`0000_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003o
ooooooooo`0?ooooo`;o0000<Oooool2o`000003ooooool0003o000007;ooooo0025ooooo`;o0000
9Oooool00ol0003oooooooooo`0?ooooo`;o0000=?ooool2o`0007;ooooo0025ooooo`;o00009Ooo
ool00ol0003oooooooooo`05ooooo`;o0000?_ooool2o`0007;ooooo002/ooooo`03o`000?oooooo
oooo00Gooooo0_l0000Mooooo`;o0000Toooool00:cooooo0ol0000Tooooo`;o0000Toooool00:co
oooo0ol0000@ooooo`;o00004_ooool2o`0009?ooooo002/ooooo`03o`000?oooooooooo00oooooo
0ol0000cooooo`;o0000L_ooool009Kooooo0_l0000Dooooo`03o`000?oooooooooo00oooooo0_l0
000Eooooo`;o00006_ooool2o`000003ooooool0003o000007;ooooo002Aooooo`;o00000oooool2
o`0000;ooooo0_l0000@ooooo`03o`000?oooooooooo02Kooooo0_l0000Jooooo`;o000000Cooooo
o`000?l0003ooooo0_l0001_ooooo`00Q?ooool2o`0000_ooooo0_l00007ooooo`;o00004?ooool0
0ol0003oooooooooo`15ooooo`Go0000Koooool008Cooooo0_l0000Vooooo`03o`000?oooooooooo
04Oooooo0_l000000ooooooo0000o`00001]ooooo`00[?ooool00ol0003oooooooooo`0@ooooo`;o
0000<Oooool2o`0000?ooooo1?l0001]ooooo`00Roooool2o`0001oooooo0ol0000@ooooo`;o0000
<Oooool2o`0000?ooooo1?l0001]ooooo`00Roooool2o`0001oooooo00?o0000ooooooooool02?oo
ool2o`0003kooooo0_l0001_ooooo`00[?ooool00ol0003oooooooooo`08ooooo`;o0000@?ooool2
o`0006gooooo002Jooooo`;o00004?ooool00ol0003oooooooooo`0Tooooo`;o00008?ooool6o`00
06gooooo002@ooooo`;o00002?ooool2o`00013ooooo00?o0000ooooooooool01oooool2o`0000Wo
oooo0_l0000@ooooo`;o00008?ooool4o`0006oooooo002@ooooo`;o00000oooool2o`0001Gooooo
00?o0000ooooooooool01oooool2o`0000Wooooo0_l0000cooooo`;o0000L?ooool0093ooooo0_l0
0003ooooo`;o00005Oooool00ol0003oooooooooo`08ooooo`;o00002_ooool2o`0003?ooooo0_l0
001^ooooo`00[?ooool00ol0003oooooooooo`08ooooo`;o00002_ooool2o`0003;ooooo0ol0001^
ooooo`00[?ooool00ol0003oooooooooo`0Uooooo`;o00008Oooool2o`0006oooooo002/ooooo`?o
00009Oooool2o`00027ooooo0_l0001_ooooo`00Q?ooool2o`0002Kooooo00?o0000ooooooooool0
4oooool2o`000:Cooooo0024ooooo`;o00009_ooool00ol0003oooooooooo`02ooooo`;o00003ooo
ool2o`0001;ooooo0_l0002@ooooo`002Oooool4o`000003oa0@4?oooooooooo01Kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0
003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Kooooo00?o0000ooooooooool00_oo
ool2o`0000oooooo0_l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@?ooooo
1_l00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8b
omgMg@0Hooooo`Co000000?o410@ooooooooool04_ooool000_ooooo00?o0000ooooooooool06?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo
00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03
ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnH
V9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool05Oooool00ol0003oooooooooo`0E
ooooo`;o000000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q0oooool2o`000004ob4Q
8Oo^k^koooooodA4A0Oooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo01Wooooo00?o0000
ooooooooool05?ooool000Ko00001Oooool00ol0003oooooooooo`0@ooooo`Ko00000_ooool01Ol@
413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`05
ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool01Ooo
ool6o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Gooooo
0_l00002ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05Oooool2o`000003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02?ooool2o`000003oiRHV?lQ8B7ok^k^00Wooooo
00?o0000ooooooooool03Oooool01_l@413o0000o`000?oooooo410@ooooo`;o00003Oooool00ol0
003oooooooooo`0=ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000oooo
ooooool06?ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool0
0omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8boooo
o`0>ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP04ooooo`;o0000
00?oooooogMgMolb<S805_ooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool0
00003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00kooooo0ol000000ooooooo
0000ooooo`02o`0000cooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo0000
00kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo
01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000>oooo
o`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Foooo
o`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000<ooooo`;o000000?oMgMg
ofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000oooooooooooooooo
o`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo0000
00kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[ooooo00?o0000
ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol@413ooooooooooooooooo
410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`0Aooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@4100
3oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Sooooo0ol0000Hooooo`05oa0@
4?ooooooooooooooool@41003?ooool2o`000003ooooool0003ooooo00?ooooo00?o0000oooooooo
ool04Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04Oooool01Ol@
413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooooooo
o`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0Dooooo`;o00000_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Wooooo0ol000001?nj^[[ooooooiRHV?l@4104ooooo`03o`000?oooooooooo017ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo01Cooooo0009ooooo`03oeEEEOmVIVKo000001[ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`Go00001?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c004ooooo`Go00005_ooool00ol0003oooooooooo`0Dooooo`?o000000Koooooonk^k_lb<S;o
0000oc8b<_o^k^h9ooooo`;o000000GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00004?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool5o`0000Cooooo1?l0000Iooooo`03oeEEEOmVIVKo000001Kooooo001jooooo`;o00006?oo
ool2o`0000;ooooo0_l0000Booooo`03o`000?oooooooooo01Gooooo0_l0000Cooooo`;o0000SOoo
ool007[ooooo0_l0000Looooo`;o00004_ooool00ol0003oooooooooo`0Xooooo`Co0000SOooool0
0:cooooo00?o0000ooooooooool0:?ooool2o`0001cooooo0ol00003ooooo`;o0000H?ooool2o`00
00;ooooo0_l00005ooooo`00[?ooool00ol0003oooooooooo`0Cooooo`;o000000?oooooo`000?l0
0000;_ooool3o`000003ooooool0003o000000;o0000H?ooool01_o^k^ko8B4QohN7Qonj^[[o0000
omgMg@Gooooo002;ooooo`;o00007oooool00ol0003oooooooooo`0Cooooo`;o000000?oooooo`00
0?l00000<_ooool2o`000003ooooool0003o0000063ooooo00CogMgMo`000?l@413oc<c<1_ooool0
00Ooooooool0001<o`0000cooooo00Cok^k^ob4Q8Ol@413ok^k^1_ooool000Oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`02ooooo`;o000000?oooooo`000?ooool01_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooo000000;o00000oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`0000;ooooo0ol00002oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool01?lQ8B7oMgMgogMgMolb<S86
ooooo`001oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool09_ooool2o`0002Oooooo00?o0000ooooooooool00_ooool2o`0002?ooooo00?o0000oooo
ooooool08_ooool2o`0000;ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo00Wooooo0_l00002ooooo`;o00001Oooool008?ooooo0_l0000Wooooo`03
o`000?oooooooooo00;ooooo0_l0000Rooooo`;o00007oooool2o`00073ooooo002/ooooo`03o`00
0?oooooooooo02Kooooo0_l0000Oooooo`Co0000K_ooool00:cooooo00?o0000ooooooooool09_oo
ool3o`00023ooooo0_l0001^ooooo`00[?ooool00ol0003oooooooooo`02ooooo`;o00008oooool2
o`00093ooooo002/ooooo`03o`000?oooooooooo00;ooooo0_l0000Uooooo`;o0000S_ooool009Go
oooo0_l0000Eooooo`?o00005Oooool2o`0001;ooooo0_l0000Mooooo`;o0000Koooool009Gooooo
0_l0000Eooooo`03o`000?oooooooooo01Gooooo0_l0000aooooo`;o00000oooool2o`0006[ooooo
002/ooooo`03o`000?oooooooooo01Gooooo0_l0000fooooo`;o0000J_ooool00:cooooo00?o0000
ooooooooool05Oooool2o`0001?ooooo0_l0002=ooooo`00[?ooool00ol0003oooooooooo`0Doooo
o`?o00004oooool2o`0002;ooooo0_l0001Yooooo`00Q?ooool2o`0002Kooooo00?o0000oooooooo
ool05?ooool4o`0003Kooooo0_l0001Yooooo`00Q?ooool2o`0002Kooooo00?o0000ooooooooool0
2Oooool2o`0000_ooooo0_l0000gooooo`;o0000J?ooool00:cooooo00?o0000ooooooooool02Ooo
ool2o`0000[ooooo0_l0000aooooo`;o00001Oooool2o`0006Sooooo002/ooooo`03o`000?oooooo
oooo00Wooooo0_l00009ooooo`?o0000<Oooool2o`0006oooooo002/ooooo`?o00002Oooool2o`00
00Wooooo0_l0000Cooooo`;o0000S_ooool00:cooooo00?o0000ooooooooool02Oooool2o`0001ko
oooo0_l0002>ooooo`00[?ooool00ol0003oooooooooo`09ooooo`;o00006oooool2o`00097ooooo
002/ooooo`03o`000?oooooooooo02Kooooo0_l0002Aooooo`00TOooool2o`0001Wooooo00?o0000
ooooooooool0B?ooool2o`0006oooooo002Aooooo`;o00006Oooool00ol0003oooooooooo`18oooo
o`;o0000Koooool00:cooooo00?o0000ooooooooool05Oooool2o`0003?ooooo0_l0001]ooooo`00
Roooool2o`0001oooooo00Co0000oooooooooooooooo0_l0000@ooooo`Co0000<oooool2o`0006go
oooo002;ooooo`;o00001Oooool2o`0001Sooooo0ol000000ooooooo0000o`00000@ooooo`;o0000
>?ooool2o`0006[ooooo002Booooo`;o00006?ooool00ol0003oooooooooo`1=ooooo`;o0000J_oo
ool00:cooooo00?o0000ooooooooool0BOooool4o`0006cooooo002/ooooo`03o`000?oooooooooo
04Wooooo1?l0001/ooooo`00[?ooool00ol0003oooooooooo`0Wooooo`;o0000T?ooool008_ooooo
0_l0000Oooooo`03o`000?oooooooooo00Sooooo0_l0000;ooooo`;o00004?ooool2o`00093ooooo
002;ooooo`?o00007_ooool00ol0003oooooooooo`08ooooo`;o00002oooool2o`000:;ooooo002<
ooooo`;o00007_ooool00ol0003oooooooooo`0Dooooo`;o0000=_ooool2o`0006_ooooo001koooo
o`;o00001oooool2o`0002?ooooo0_l000001?oooooo0000o`000?l0000Cooooo`?o0000=_ooool2
o`0006_ooooo001kooooo`;o00001oooool2o`0002?ooooo0_l000000ooooooo0000ooooo`0Doooo
o`;o00004_ooool2o`00093ooooo002<ooooo`?o00002?ooool2o`0001?ooooo00?o0000oooooooo
ool09oooool4o`0001oooooo0ol0001/ooooo`00S?ooool3o`0000Sooooo0_l0000Cooooo`03o`00
0?oooooooooo02Wooooo0_l0000Oooooo`?o0000K?ooool008Cooooo0_l00006ooooo`;o00007_oo
ool00ol0003oooooooooo`2iooooo`00Q?ooool2o`0002Kooooo00?o0000ooooooooool01oooool2
o`000;3ooooo0024ooooo`;o00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool01ooo
ool2o`000;3ooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Ko
V9RHob4Q8Oo^k^koooooodA4A?ooool2o`0000Cooooo00?oMgMgoc8b<_ooool01?ooool3o`0002Co
oooo0ol000000ooooooo0000o`00000Looooo`;o00000oooool2o`0006cooooo0029ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP02ooooo`;o00001Oooool00ol0003o
ooooooooo`03ooooo`?o00009?ooool3o`000003ooooool0003o000001cooooo0_l00003ooooo`;o
0000K?ooool008Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`05ooooo`;o0000/_ooool008Wooooo
00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c005ooooo`03o`000?oooooooooo00Gooooo0ol0002aooooo`00ROooool01Ol@413o
oooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Kooooo0_l0000;ooooo`;o0000Y?ooool008Kooooo0_l000001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool04oooool2o`000:Cooooo0026ooooo`;o000000Kooooo
onk^k_lb<S;o0000oc8b<_o^k^h;ooooo`?o000000?o8B4Qolc<c?ooool00oooool4o`0000Kooooo
00?o0000ooooooooool0^Oooool009Wooooo0_l0000Aooooo`03o`000?oooooooooo00Cooooo0_l0
0009ooooo`;o00004oooool2o`0009?ooooo002/ooooo`03o`000?oooooooooo00Cooooo0_l00009
ooooo`;o00004oooool2o`0009?ooooo0025ooooo`;o00009Oooool00ol0003oooooooooo`0Uoooo
o`;o0000T_ooool008Gooooo0_l00007ooooo`;o00007?ooool3o`0002Gooooo0_l0002Booooo`00
S_ooool2o`0000Cooooo0_l0000Fooooo`03o`000?oooooooooo0;Wooooo002Dooooo`;o00005Ooo
ool2o`0000Kooooo0_l00011ooooo`;o0000L?ooool008oooooo0_l0000Jooooo`;o00001_ooool2
o`00047ooooo0_l0001`ooooo`00Q_ooool2o`0000Oooooo0_l0000Kooooo`03o`000?oooooooooo
02;ooooo0_l000000ooooooo0000o`00002Booooo`00Q_ooool2o`0002Cooooo00?o0000oooooooo
ool08_ooool2o`000004ooooool0003o0000o`0001gooooo0ol0001aooooo`00[?ooool00ol0003o
ooooooooo`0Vooooo`;o00007Oooool3o`00077ooooo002Xooooo`;o00000_ooool00ol0003ooooo
ooooo`0Pooooo`;o0000Uoooool009kooooo0_l00008ooooo`;o00000_ooool3o`0000kooooo0_l0
000@ooooo`;o00008Oooool2o`0007Cooooo002Nooooo`;o00002?ooool2o`0000;ooooo00Co0000
oooooooooooooooo0_l0000;ooooo`;o0000<oooool2o`0007Cooooo0027ooooo`;o00005_ooool2
o`0000Oooooo0_l00002ooooo`04o`000?ooooooooooooooo`;o00002Oooool2o`000:_ooooo0027
ooooo`;o00005_ooool2o`0000Cooooo0_l00005ooooo`04o`000?ooooooooooooooo`;o00002Ooo
ool4o`000:Wooooo002Tooooo`?o00001Oooool01?l0003oooooooooooooool2o`0000_ooooo0_l0
002Yooooo`00Xoooool3o`0000Kooooo00?o0000ooooooooool08?ooool2o`0009Oooooo002Soooo
o`;o00001oooool01?l0003oooooo`000?l0000Oooooo`;o0000Uoooool00:cooooo00Co0000oooo
ool0003o00002Oooool2o`000:gooooo002/ooooo`?o00002_ooool2o`0001?ooooo1?l0002Foooo
o`00TOooool2o`0001Wooooo00?o0000ooooooooool07oooool4o`0009Kooooo002Aooooo`;o0000
6Oooool00ol0003oooooooooo`08ooooo`;o0000[oooool00:cooooo00?o0000ooooooooool02?oo
ool4o`0001Cooooo0_l0002Gooooo`00T_ooool2o`0001Sooooo00?o0000ooooooooool02_ooool2
o`0001Cooooo0_l0002Gooooo`00T_ooool2o`0001Sooooo00?o0000ooooooooool08?ooool2o`00
09Oooooo002Jooooo`;o00004?ooool00ol0003oooooooooo`0:ooooo`;o0000[Oooool009[ooooo
0_l0000@ooooo`;o00002oooool2o`000:gooooo002/ooooo`?o00007?ooool3o`0002?ooooo0_l0
001eooooo`00Voooool2o`0000oooooo00?o0000ooooooooool01_ooool2o`0001Cooooo0ol0000S
ooooo`;o0000MOooool009_ooooo0_l0000?ooooo`03o`000?oooooooooo00Kooooo0_l0002aoooo
o`00R?ooool2o`0002;ooooo00?o0000ooooooooool06oooool2o`0009cooooo0028ooooo`;o0000
2?ooool2o`0000_ooooo0_l0000;ooooo`03o`000?oooooooooo01_ooooo0_l0002Looooo`00T_oo
ool2o`0000_ooooo0_l0000;ooooo`03o`000?oooooooooo0;Wooooo002Aooooo`05onk^k_l0003o
0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00CoA4A4o`000?l0003o<S8b0_l00004ooooo`03o`00
0?oooooooooo00Kooooo0_l0000Cooooo`;o0000W?ooool0097ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1_ooool2o`000003ogMgMol0003o000000Cooooo00?o0000ooooooooool0
1_ooool2o`0001?ooooo1?l0000Oooooo`;o0000NOooool0097ooooo00Go410@oooooooooooooooo
oa0@400=ooooo`;o000000?oooooo`000?ooool01?ooool00ol0003oooooooooo`0Mooooo`;o0000
7oooool2o`0007Wooooo002Aooooo`05o`000?ooooooooooooooool000003Oooool2o`000003ogMg
Molb<S;ooooo00Cooooo0ol00005ooooo`;o0000=?ooool2o`0007cooooo002Aooooo`05o`000?oo
ooooooooooooool000003?ooool3o`000003oc8b<_o<c<cooooo00Cooooo00?o0000ooooooooool0
1Oooool2o`0001Cooooo0_l0000Nooooo`;o0000O?ooool0097ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05_ooool3o`0000;ooooo
0_l0002Looooo`00TOooool01?mgMgOoV9RHoooooonHV9P2o`0000_ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Fooooo`?o00008?ooool2o`0007kooooo002Aooooo`04onk^k_lb
<S;o0000oc8b<P;o00002oooool4o`0000Kooooo00?o0000ooooooooool05oooool2o`00023ooooo
0_l0001nooooo`00[?ooool00ol0003oooooooooo`0Eooooo`Go0000Woooool00:cooooo00?o0000
ooooooooool00_l0000Cooooo`;o000000?oooooo`000?l00000Woooool00:cooooo00?o0000oooo
ooooool01?l0000@ooooo`?o000000?oooooo`000?l00000Woooool00:cooooo1ol0000@ooooo`?o
000000?oooooo`000?l00000Woooool007oooooo0_l0000[ooooo`03o`000?oooooooooo0;Wooooo
001oooooo`;o00003?ooool2o`0001gooooo00?o0000ooooooooool0^Oooool008gooooo0_l00009
ooooo`;o00004_ooool2o`000003ooooool0003o00000;Oooooo002Hooooo`;o00004_ooool2o`00
0003ooooool0003o000003Oooooo0_l0001nooooo`00[?ooool00ol0003oooooooooo`0Dooooo`;o
00008oooool2o`0007kooooo002[ooooo`;o00005_ooool2o`000:?ooooo002[ooooo`;o0000^ooo
ool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00Z_ooool3o`000;_ooooo002Yooooo`Co0000^oooool009oooooo0ol00007
ooooo`;o000000?oooooo`000?ooool0^_ooool008;ooooo0_l0000Jooooo`Co00002_ooool00ol0
003oooooooooo`0cooooo`;o0000Q?ooool008;ooooo0_l0000Jooooo`Co00001Oooool2o`0000?o
oooo00?o0000ooooooooool0<oooool2o`0008Cooooo002>ooooo`;o00005oooool2o`0000?ooooo
0ol0002iooooo`00S_ooool3o`0001_ooooo00?o0000ooooooooool0<?ooool2o`0008Oooooo002?
ooooo`;o00006oooool00ol0003oooooooooo`09ooooo`;o00009Oooool2o`0008Oooooo002/oooo
o`03o`000?oooooooooo00Wooooo0_l0002^ooooo`00[?ooool00ol0003oooooooooo`0:ooooo`;o
00008_ooool2o`0008Wooooo002/ooooo`03o`000?oooooooooo00[ooooo0_l0000Rooooo`;o0000
ROooool00:cooooo00?o0000ooooooooool0;_ooool2o`0008Wooooo002/ooooo`03o`000?oooooo
oooo00Sooooo0_l0000Tooooo`;o0000ROooool00:cooooo00?o0000ooooooooool02?ooool2o`00
02?ooooo0ol00029ooooo`00TOooool2o`0001Wooooo0ol00006ooooo`;o00009Oooool2o`0008[o
oooo002Aooooo`;o00006Oooool00ol0003oooooooooo`06ooooo`;o0000/Oooool00:cooooo00?o
0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o00001_ooool00ol0
003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2i
ooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l00006ooooo`03oeEEEOnYZJWo
oooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2iooooo`00ROooool01Ol@
413ooooooooooooooooo410@00Kooooo0_l00005ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`2iooooo`00ROooool01Ol0003ooooooooooooooooo
000000Kooooo0ol00005ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3
o`000;Wooooo0029ooooo`05o`000?ooooooooooooooool000001oooool2o`0000Gooooo00?oEEEE
olc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool00ooo
ool3o`000;?ooooo0029ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgoooo
o`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool3o`000;?ooooo0029
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02Oooool3o`0000?ooooo00?o<S8booooooooool00_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02Oooool7o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo0;Wooooo002I
ooooo`;o00004Oooool3o`0002;ooooo0_l0002Eooooo`00[?ooool3o`0002;ooooo0_l0002Eoooo
o`00Z_ooool3o`000003ooooool0003o0000027ooooo0_l0002Eooooo`00Z_ooool6o`00027ooooo
0_l0002Eooooo`00[?ooool00ol0003oooooooooo`2iooooo`00YOooool2o`0000Gooooo00?o0000
ooooooooool0^Oooool008Oooooo0_l0000Looooo`;o00001Oooool00ol0003oooooooooo`2ioooo
o`00Qoooool2o`0001Sooooo0_l00009ooooo`03o`000?oooooooooo0;Wooooo002Qooooo`Co0000
1oooool00ol0003oooooooooo`2iooooo`00Xoooool2o`0000Gooooo0ol0002kooooo`00Z?ooool5
o`0001oooooo0_l0002Jooooo`00Woooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`00
00;ooooo0ol0000Mooooo`;o0000V_ooool009oooooo0_l000001Ooooooo0000o`000?l0003ooooo
00;o00001?ooool00ol0003oooooooooo`2iooooo`00X_ooool2o`0000Sooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Ooo
ool00:cooooo00?o0000ooooooooool0^Oooool008_ooooo0_l0000Oooooo`03o`000?oooooooooo
0;Wooooo002;ooooo`;o00007oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo01?ooooo0_l0002T
ooooo`00[?ooool00ol0003oooooooooo`0Cooooo`;o0000Y?ooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Ooo
ool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:co
oooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00X_ooool4o`000003oa0@4?oooooooooo00?ooooo
00?o0000ooooooooool02Oooool2o`000:kooooo002Tooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool02Oooool2o`000:kooooo002Tooooo`03o`000?oooooooooo00Gooooo0ol0002i
ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00
Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00X_ooool0
0omEEEGoIVIVo`000033ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00Z_ooool01?l@413o0000o`000?l0002jooooo`00Zoooool00ol0003oooooooooo`2j
ooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool01_l0003oMgMgo`000?l0003oEEEE
onk^k[Oooooo002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoEEEE]oooool00:_ooooo00?o0000
onk^k_ooool00_ooool00ol0003oooooooooo`2eooooo`00Zoooool00ol0003ok^k^ooooo`02oooo
o`03o`000?oooooooooo0;Gooooo002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoIVIV]oooool0
0:[ooooo00?o410@o`000?mgMgL00_l000000omVIVKok^k^ooooo`2fooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.64577 .49844 Mdot
.64797 .59144 Mdot
.50465 .53708 Mdot
.50101 .72458 Mdot
.58617 .54332 Mdot
.60337 .32162 Mdot
.50113 .37166 Mdot
.57983 .11256 Mdot
.55708 .10778 Mdot
.42027 .36878 Mdot
.48014 .21581 Mdot
.64305 .20562 Mdot
.62172 .71895 Mdot
.42761 .30849 Mdot
.68459 .3002 Mdot
.44873 .73692 Mdot
.42106 .24147 Mdot
.61992 .72469 Mdot
.56281 .36975 Mdot
.4573 .94347 Mdot
.58129 .7925 Mdot
.62164 .69165 Mdot
.58523 .76822 Mdot
.60421 .75739 Mdot
.70792 .34591 Mdot
.54195 .74248 Mdot
.53002 .3014 Mdot
.56732 .39918 Mdot
.41913 .87539 Mdot
.63629 .63567 Mdot
.52434 .8756 Mdot
.53122 .0733 Mdot
.59322 .13993 Mdot
.49773 .15673 Mdot
.51245 .16582 Mdot
.41255 .83659 Mdot
.40265 .17309 Mdot
.55797 .37263 Mdot
.37568 .55783 Mdot
.63603 .18783 Mdot
.69338 .29374 Mdot
.49879 .15105 Mdot
.57327 .26493 Mdot
.64922 .4645 Mdot
.6399 .42177 Mdot
.57741 .62807 Mdot
.45797 .23115 Mdot
.46245 .03045 Mdot
.45796 .83745 Mdot
.39057 .73784 Mdot
.47239 .02881 Mdot
.37437 .56631 Mdot
.67292 .83013 Mdot
.56111 .24739 Mdot
.53816 .19923 Mdot
.5803 .13141 Mdot
.59697 .13632 Mdot
.40694 .3168 Mdot
.43002 .07835 Mdot
.63626 .40629 Mdot
.56512 .66932 Mdot
.74824 .45702 Mdot
.37601 .4411 Mdot
.53761 .41662 Mdot
.63316 .21054 Mdot
.54548 .08714 Mdot
.42304 .35192 Mdot
.43728 .69732 Mdot
.54901 .33576 Mdot
.58097 .79953 Mdot
.39587 .4235 Mdot
.52231 .48536 Mdot
.43655 .28417 Mdot
.41406 .48839 Mdot
.37608 .4394 Mdot
.46676 .64184 Mdot
.67227 .83108 Mdot
.51293 .78322 Mdot
.3802 .66196 Mdot
.41165 .68023 Mdot
.47151 .92854 Mdot
.63261 .64399 Mdot
.50289 .71612 Mdot
.49496 .14438 Mdot
.55966 .09267 Mdot
.47354 .76921 Mdot
.58604 .55106 Mdot
.56528 .65019 Mdot
.39582 .47369 Mdot
.43138 .67114 Mdot
.71236 .36337 Mdot
.7301 .69172 Mdot
.54762 .48334 Mdot
.5784 .61435 Mdot
.54585 .47758 Mdot
.74507 .64777 Mdot
.42619 .31702 Mdot
.51413 .06097 Mdot
.66957 .83743 Mdot
.39663 .57367 Mdot
.64564 .53275 Mdot
.40369 .65357 Mdot
.65627 .23357 Mdot
.65105 .49961 Mdot
.53468 .87137 Mdot
.50581 .16696 Mdot
.41017 .28368 Mdot
.57008 .39224 Mdot
.54778 .48323 Mdot
.56763 .81969 Mdot
.41928 .36679 Mdot
.51933 .68124 Mdot
.53433 .07814 Mdot
.45998 .93901 Mdot
.57131 .97472 Mdot
.44399 .65897 Mdot
.54687 .71699 Mdot
.52119 .05259 Mdot
.51811 .05243 Mdot
.43169 .08771 Mdot
.61544 .73078 Mdot
.73942 .40607 Mdot
.55595 .82351 Mdot
.42589 .89568 Mdot
.57384 .81088 Mdot
.47963 .75283 Mdot
.43262 .9019 Mdot
.75023 .61709 Mdot
.63071 .63127 Mdot
.43939 .35748 Mdot
.60563 .73159 Mdot
.64264 .57228 Mdot
.6656 .245 Mdot
.59759 .30023 Mdot
.58557 .28746 Mdot
.4016 .81426 Mdot
.3729 .42368 Mdot
.41853 .86951 Mdot
.43748 .28208 Mdot
.62391 .1854 Mdot
.68198 .28943 Mdot
.74776 .55912 Mdot
.54405 .58025 Mdot
.55218 .33927 Mdot
.4182 .25328 Mdot
.46387 .9451 Mdot
.54512 .07717 Mdot
.5783 .50696 Mdot
.56391 .65871 Mdot
.72505 .34167 Mdot
.4129 .71908 Mdot
.51913 .26419 Mdot
.60961 .74895 Mdot
.52032 .45745 Mdot
.62952 .41975 Mdot
.37601 .3805 Mdot
.37445 .49625 Mdot
.5401 .07646 Mdot
.41414 .13078 Mdot
.37509 .3923 Mdot
.51075 .80475 Mdot
.38672 .72669 Mdot
.6619 .21891 Mdot
.42335 .86658 Mdot
.58999 .31073 Mdot
.641 .55623 Mdot
.54651 .08021 Mdot
.53082 .87935 Mdot
.54697 .33169 Mdot
.37213 .53768 Mdot
.38827 .71097 Mdot
.53715 .59396 Mdot
.54588 .33569 Mdot
.57779 .59519 Mdot
.58049 .49729 Mdot
.61664 .17757 Mdot
.74574 .6412 Mdot
.62883 .42037 Mdot
.43168 .5694 Mdot
.39435 .76804 Mdot
.37747 .64614 Mdot
.65657 .22078 Mdot
.42636 .66233 Mdot
.69681 .29998 Mdot
.46862 .28171 Mdot
.5669 .1236 Mdot
.74583 .62838 Mdot
.49674 .03241 Mdot
.66115 .22003 Mdot
.57352 .26099 Mdot
.73193 .38249 Mdot
.46902 .9475 Mdot
.53049 .39127 Mdot
.74551 .46602 Mdot
.57325 .10764 Mdot
.70125 .29775 Mdot
.65903 .23562 Mdot
.578 .61052 Mdot
.73413 .69812 Mdot
.41896 .23257 Mdot
.44464 .64837 Mdot
.44228 .63901 Mdot
.52292 .50619 Mdot
.58036 .57401 Mdot
.72592 .7208 Mdot
.64088 .57114 Mdot
.51393 .3427 Mdot
.61402 .35222 Mdot
.5353 .63422 Mdot
.46694 .27606 Mdot
.47285 .21272 Mdot
.63443 .67883 Mdot
.5223 .76607 Mdot
.52752 .88358 Mdot
.42246 .62691 Mdot
.63976 .56756 Mdot
.52412 .75985 Mdot
.66815 .23098 Mdot
.45128 .30318 Mdot
.63753 .44252 Mdot
.61918 .16259 Mdot
.55283 .70275 Mdot
.47178 .03545 Mdot
.54546 .85919 Mdot
.44396 .90653 Mdot
.42054 .5969 Mdot
.58497 .51007 Mdot
.6552 .54425 Mdot
.54356 .5554 Mdot
.68457 .29903 Mdot
.74006 .39681 Mdot
.47435 .76199 Mdot
.44731 .39169 Mdot
.70838 .75296 Mdot
.40514 .64835 Mdot
.51254 .25873 Mdot
.73717 .40564 Mdot
.55058 .34771 Mdot
.65217 .51038 Mdot
.58485 .77964 Mdot
.64427 .55772 Mdot
.74815 .46778 Mdot
.58267 .27301 Mdot
.52077 .89683 Mdot
.39585 .42458 Mdot
.51173 .04838 Mdot
.5448 .49238 Mdot
.38902 .25783 Mdot
.409 .31793 Mdot
.3951 .44368 Mdot
.37484 .48975 Mdot
.70153 .30243 Mdot
.44375 .65702 Mdot
.53588 .42684 Mdot
.40539 .16858 Mdot
.5142 .79132 Mdot
.54505 .33513 Mdot
.52744 .17656 Mdot
.4617 .63555 Mdot
.60524 .15167 Mdot
.44445 .04972 Mdot
.42958 .78053 Mdot
.51118 .25587 Mdot
.43928 .90054 Mdot
.42839 .46378 Mdot
.40551 .66361 Mdot
.64308 .49853 Mdot
.47893 .2215 Mdot
.61011 .3586 Mdot
.39648 .76282 Mdot
.47397 .83459 Mdot
.42936 .89117 Mdot
.53879 .19791 Mdot
.41438 .43316 Mdot
.41987 .73539 Mdot
.37327 .4385 Mdot
.42851 .67757 Mdot
.58041 .43234 Mdot
.48821 .03189 Mdot
.45344 .22814 Mdot
.62382 .38735 Mdot
.39137 .75274 Mdot
.42664 .4614 Mdot
.41531 .47214 Mdot
.42141 .10985 Mdot
.64386 .21161 Mdot
.57036 .3909 Mdot
.51431 .42156 Mdot
.57418 .58494 Mdot
.49775 .93178 Mdot
.56598 .65721 Mdot
.477 .92665 Mdot
.74322 .63551 Mdot
.44292 .05824 Mdot
.66983 .26744 Mdot
.47097 .03797 Mdot
.46438 .335 Mdot
.39982 .17615 Mdot
.74232 .47475 Mdot
.5206 .90283 Mdot
.68044 .29127 Mdot
.44113 .80576 Mdot
.54912 .20811 Mdot
.64515 .56419 Mdot
.52082 .05962 Mdot
.69788 .31213 Mdot
.45855 .22823 Mdot
.4984 .04138 Mdot
.51128 .79786 Mdot
.46366 .69079 Mdot
.62585 .69702 Mdot
.42356 .2293 Mdot
.61021 .73808 Mdot
.72179 .33643 Mdot
.43284 .59393 Mdot
.64022 .46442 Mdot
.50272 .16056 Mdot
.64112 .22245 Mdot
.42716 .51043 Mdot
.66385 .23476 Mdot
.73262 .42211 Mdot
.75485 .5449 Mdot
.46765 .75556 Mdot
.59198 .28344 Mdot
.48685 .13562 Mdot
.37929 .36622 Mdot
.58643 .48382 Mdot
.47114 .70227 Mdot
.48439 .3329 Mdot
.40855 .29682 Mdot
.60434 .1429 Mdot
.41542 .13403 Mdot
.54493 .45835 Mdot
.631 .67912 Mdot
.43733 .36529 Mdot
.52264 .51588 Mdot
.65441 .5531 Mdot
.59566 .30119 Mdot
.58988 .30995 Mdot
.50729 .80998 Mdot
.57991 .57104 Mdot
.69554 .79299 Mdot
.49034 .82593 Mdot
.6279 .65097 Mdot
.54075 .4438 Mdot
.59355 .14557 Mdot
.52693 .2956 Mdot
.41878 .86874 Mdot
.61445 .69724 Mdot
.54935 .52086 Mdot
.53318 .73693 Mdot
.74901 .55074 Mdot
.6332 .18812 Mdot
.3868 .24768 Mdot
.41282 .83962 Mdot
.46577 .83904 Mdot
.43276 .18932 Mdot
.39667 .76918 Mdot
.40619 .66411 Mdot
.63519 .19204 Mdot
.7596 .52399 Mdot
.51723 .90195 Mdot
.66667 .24864 Mdot
.66796 .24213 Mdot
.6847 .26624 Mdot
.52023 .56065 Mdot
.41192 .6976 Mdot
.68547 .29899 Mdot
.59905 .14104 Mdot
.51915 .57167 Mdot
.50421 .9058 Mdot
.46257 .82548 Mdot
.60947 .33297 Mdot
.64569 .52405 Mdot
.52702 .07498 Mdot
.65164 .51347 Mdot
.40749 .14949 Mdot
.4016 .19219 Mdot
.58612 .76493 Mdot
.37732 .3331 Mdot
.60262 .73541 Mdot
.69973 .32518 Mdot
.5621 .98775 Mdot
.45202 .05515 Mdot
.62894 .40404 Mdot
.52041 .48161 Mdot
.72367 .38269 Mdot
.39648 .55709 Mdot
.48076 .33037 Mdot
.65386 .2132 Mdot
.57827 .80433 Mdot
.48051 .70208 Mdot
.4157 .4329 Mdot
.54104 .73825 Mdot
.52214 .27849 Mdot
.46425 .02809 Mdot
.56739 .83209 Mdot
.74444 .47465 Mdot
.65903 .22438 Mdot
.45023 .15967 Mdot
.68669 .80171 Mdot
.44439 .16609 Mdot
.58027 .48111 Mdot
.58243 .47515 Mdot
.43996 .53347 Mdot
.60751 .14963 Mdot
.64249 .20547 Mdot
.52713 .29447 Mdot
.54525 .5556 Mdot
.47274 .20587 Mdot
.45348 .75298 Mdot
.71555 .32857 Mdot
.58492 .58371 Mdot
.43985 .90518 Mdot
.53246 .63215 Mdot
.52652 .28088 Mdot
.42865 .44806 Mdot
.58482 .57307 Mdot
.48924 .14892 Mdot
.50732 .24328 Mdot
.51806 .35471 Mdot
.73354 .37545 Mdot
.61939 .178 Mdot
.49462 .41186 Mdot
.51829 .17326 Mdot
.41115 .27817 Mdot
.63538 .47331 Mdot
.45186 .81476 Mdot
.54357 .32519 Mdot
.72192 .36822 Mdot
.74933 .64618 Mdot
.64987 .5436 Mdot
.6027 .93579 Mdot
.65085 .46536 Mdot
.51811 .34939 Mdot
.58806 .15103 Mdot
.69007 .31042 Mdot
.49819 .23518 Mdot
.60667 .71382 Mdot
.68877 .80434 Mdot
.54273 .57571 Mdot
.48973 .68978 Mdot
.58006 .52676 Mdot
.45333 .92099 Mdot
.42855 .76345 Mdot
.73227 .69541 Mdot
.47227 .2774 Mdot
.5512 .23242 Mdot
.47841 .13425 Mdot
.54128 .42978 Mdot
.42994 .55375 Mdot
.41864 .60788 Mdot
.5841 .11852 Mdot
.43232 .5962 Mdot
.38901 .74091 Mdot
.65055 .56711 Mdot
.64123 .4473 Mdot
.43393 .90312 Mdot
.4857 .92202 Mdot
.43165 .20003 Mdot
.75886 .58725 Mdot
.41611 .42254 Mdot
.60593 .14449 Mdot
.69777 .29129 Mdot
.48776 .2277 Mdot
.39368 .20614 Mdot
.46148 .82735 Mdot
.42826 .21959 Mdot
.42455 .88526 Mdot
.64686 .52358 Mdot
.56895 .39557 Mdot
.53516 .73354 Mdot
.48491 .14369 Mdot
.74669 .42023 Mdot
.5949 .31592 Mdot
.47896 .6466 Mdot
.57735 .27873 Mdot
.41583 .70924 Mdot
.52347 .52833 Mdot
.44708 .72441 Mdot
.55457 .23465 Mdot
.57268 .25719 Mdot
.44481 .65595 Mdot
.51373 .78932 Mdot
.5484 .09057 Mdot
.58811 .51855 Mdot
.64174 .48961 Mdot
.53616 .29401 Mdot
.57252 .44332 Mdot
.51252 .61338 Mdot
.59331 .95146 Mdot
.50588 .63959 Mdot
.65155 .57228 Mdot
.50167 .05296 Mdot
.42737 .87869 Mdot
.55284 .346 Mdot
.40791 .83312 Mdot
.65179 .21533 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:3ooooo1?l00008ooooo`03o`000?oooooo
oooo0;Wooooo002Oooooo`Go00001?ooool2o`0000;ooooo00?o0000ooooooooool0^Oooool009oo
oooo0_l00007ooooo`Go0000^oooool00:;ooooo0_l00006ooooo`?o0000^oooool00:;ooooo0_l0
0008ooooo`03o`000?oooooooooo0;Wooooo002[ooooo`;o0000^oooool00:_ooooo0_l0002koooo
o`00VOooool2o`00017ooooo00?o0000ooooooooool00_l0002gooooo`00VOooool2o`00017ooooo
1Ol000001?oooooo0000o`000?l0002cooooo`00W?ooool2o`0000kooooo0_l00004ooooo`?o0000
/oooool009Wooooo0_l000000ooooooo0000o`00000>ooooo`03o`000?oooooooooo0;Wooooo002I
ooooo`;o00004Oooool01?l0003oooooooooooooool4o`000;Cooooo002/ooooo`04o`000?oooooo
ooooooooo`Co0000]?ooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool01oooool2o`000;3ooooo002/ooooo`?o0000
1Oooool4o`000004ooooool0003o0000o`000:cooooo002Dooooo`;o00005_ooool00ol0003ooooo
ooooo`05ooooo`;o000000?oooooo`000?l000001?l0002[ooooo`00U?ooool2o`0001Kooooo00?o
0000ooooooooool02?ooool2o`0000;ooooo0_l0002[ooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00UOooool2o`0001Gooooo00?o0000ooooooooool03?ooool2o`000:_ooooo002Eooooo`;o
00005Oooool00ol0003oooooooooo`0<ooooo`?o0000Z_ooool00:cooooo00?o0000ooooooooool0
3Oooool2o`000003ooooool0003o00000:Oooooo002/ooooo`03o`000?oooooooooo013ooooo0_l0
002Wooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03
o`000?oooooooooo01Gooooo0_l0002Rooooo`00T_ooool2o`0001Sooooo00?o0000ooooooooool0
3oooool2o`0000Cooooo0_l0002Rooooo`00T_ooool2o`0001Sooooo00?o0000ooooooooool03ooo
ool2o`0000Kooooo0_l0002Pooooo`00[?ooool00ol0003oooooooooo`0Gooooo`;o0000X?ooool0
08Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Hooooo`;o0000Wooo
ool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYoooo
o`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool06?ooool2o`0009oooooo0021
ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?oo
ool00ol0003oooooooooo`03ooooo`?o00004oooool2o`000:Cooooo0029ooooo`05o`000?oooooo
ooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool04oooool2o`000:Cooooo0029ooooo`06o`000?ooooooooooooooool0003ooooo
0_l0000;ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo01Oooooo0_l0002Pooooo`00ROooool01_l@413ooooooooooooooooo410@oooo
o`?o00002_ooool00onYZJWoMgMgooooo`03ooooo`04o`000?oooooo0000o`0000Kooooo00?o0000
ooooooooool05oooool2o`000:3ooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool2
o`0000Oooooo00Go410@oooooooooooooooooc8b<P04ooooo`05o`000?oooooo0000o`000?ooool0
0_l00003ooooo`03o`000?oooooooooo01gooooo0_l0002Jooooo`00ROooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co000000?oooooo`000?l000000oooool00ol0003ooooo
ooooo`0Kooooo`Co0000V_ooool00:Oooooo0_l00003ooooo`03o`000?oooooooooo01_ooooo1_l0
002Hooooo`00Yoooool2o`000004ooooool0003o0000o`0001gooooo0_l00002ooooo`?o0000Uooo
ool008gooooo0_l0000Iooooo`Go00007Oooool2o`0000?ooooo0_l0002Gooooo`00SOooool2o`00
01Wooooo0_l000000ooooooo0000o`000002o`0001[ooooo0_l00003ooooo`?o0000Uoooool00:_o
oooo0_l0000Looooo`;o00000oooool2o`0009Sooooo002[ooooo`;o0000^oooool009_ooooo0_l0
000>ooooo`?o0000^_ooool009_ooooo0_l0000?ooooo`;o00009Oooool2o`0009?ooooo002Ioooo
o`;o00004Oooool3o`000003ooooool0003o0000027ooooo0_l0002Cooooo`00S?ooool2o`0000_o
oooo0_l0000Aooooo`?o000000?oooooo`000?l00000]_ooool008_ooooo0ol0000Nooooo`03o`00
0?oooooooooo00?ooooo0_l0002dooooo`00R_ooool3o`0001oooooo0ol00003ooooo`;o000000?o
ooooo`000?l00000/Oooool008[ooooo0_l0000Pooooo`03o`000?oooooooooo00Kooooo0_l0000K
ooooo`?o0000Toooool00:cooooo00?o0000ooooooooool08oooool3o`0009?ooooo002/ooooo`03
o`000?oooooooooo02Gooooo0_l0002Booooo`00UOooool2o`0001Gooooo00?o0000ooooooooool0
9Oooool2o`0000;ooooo0_l0002>ooooo`00Roooool2o`0000Sooooo0_l0000Eooooo`03o`000?oo
oooooooo02Wooooo0_l0002>ooooo`00Roooool2o`0001oooooo00?o0000ooooooooool0:Oooool2
o`0008kooooo002/ooooo`03o`000?oooooooooo00Wooooo0_l0002^ooooo`00UOooool2o`0001Go
oooo0ol00009ooooo`;o0000[_ooool009Gooooo0_l0000Eooooo`03o`000?oooooooooo00Wooooo
0_l0002^ooooo`00R?ooool2o`0001Wooooo0_l00007ooooo`03o`000?oooooooooo02cooooo0_l0
002;ooooo`00R?ooool2o`0001Wooooo0_l00007ooooo`03o`000?oooooooooo00gooooo0_l0000J
ooooo`;o000000?oooooo`000?l00000Roooool00:?ooooo0_l00007ooooo`03o`000?oooooooooo
00gooooo0_l0000Jooooo`;o000000Coooooo`000?l0003ooooo0_l00028ooooo`00Xoooool4o`00
00Gooooo00?o0000ooooooooool0;?ooool2o`000003ooooool0003o000008Sooooo002Dooooo`;o
00003oooool2o`0000Gooooo00?o0000ooooooooool0;oooool2o`000003ooooool0003o000008Go
oooo002Dooooo`;o00003oooool2o`0000Gooooo00?o0000ooooooooool0:oooool2o`0000?ooooo
1?l00025ooooo`00YOooool2o`0000Gooooo0ol0000[ooooo`;o00000oooool4o`0008Gooooo002L
ooooo`Co00002?ooool2o`0000;ooooo00?o0000ooooooooool0<Oooool2o`0008Kooooo002Boooo
o`;o00002?ooool4o`0000Sooooo0_l00002ooooo`03o`000?oooooooooo03Cooooo0_l00023oooo
o`00TOooool3o`0000[ooooo0_l0000<ooooo`03o`000?oooooooooo00gooooo1?l0000Oooooo`;o
000000Coooooo`000?l0003o0000Poooool0097ooooo0_l0000Hooooo`;o00003oooool4o`0001oo
oooo1Ol00024ooooo`00Zoooool2o`0003?ooooo0_l00026ooooo`00TOooool01Oo^k^ko0000o`00
0?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool01?l0003o
ooooo`000?l0000cooooo`;o0000Poooool0097ooooo00GoMgMgo`000?l0003oV9RHogMgM`05oooo
o`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`04o`000?oooooo0000o`0003;ooooo0ol00023
ooooo`00Q_ooool2o`000003ooooool0003o000000Co00000_ooool01Ol@413ooooooooooooooooo
410@013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`;o00008?ooool3
o`0008?ooooo0026ooooo`;o00002Oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMg
oc8b<_ooool01?ooool3o`00017ooooo0_l0000Qooooo`;o0000Poooool0097ooooo0_l00002oooo
o`03o`000?oooooooooo00[ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo00;o0000]oooool008Oooooo0_l00008ooooo`;o00000_ooool00ol@413oooooooooo`0:oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00ol0000Booooo`;o0000X_ooool008Oo
oooo0_l00008ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07oooo
o`04o`000?ooooooooooooooo`;o00004_ooool2o`000:;ooooo002Aooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool00oooool2o`00013ooooo0_l0002R
ooooo`00[?ooool00ol0003oooooooooo`03ooooo`;o00004?ooool2o`0001kooooo0_l00003oooo
o`;o0000OOooool00:cooooo00?o0000ooooooooool0=Oooool2o`0000?ooooo0_l0001mooooo`00
[?ooool00ol0003oooooooooo`0Hooooo`;o0000Woooool00:7ooooo0_l00009ooooo`?o00006?oo
ool2o`0009oooooo002>ooooo`;o00004Oooool3o`0000Sooooo00?o0000ooooooooool01?ooool2
o`00013ooooo0_l0002Qooooo`00S_ooool2o`0000Oooooo0_l00008ooooo`?o00002?ooool00ol0
003oooooooooo`04ooooo`?o00003oooool2o`000:7ooooo002>ooooo`;o00001oooool2o`0000So
oooo0_l00009ooooo`03o`000?oooooooooo00Gooooo0_l0000Dooooo`;o0000W?ooool008kooooo
0_l00007ooooo`;o00004oooool00ol0003oooooooooo`0Iooooo`Co00007?ooool2o`0007kooooo
002/ooooo`03o`000?oooooooooo01Wooooo0_l0000Mooooo`?o00000oooool2o`0007Wooooo002/
ooooo`03o`000?oooooooooo00Kooooo0_l000000ooooooo0000o`00000]ooooo`;o00000_ooool4
o`0007Wooooo002=ooooo`;o00007Oooool00ol0003oooooooooo`05ooooo`?o000000?oooooo`00
0?l00000<Oooool2o`000003ooooool0003o000007Sooooo002=ooooo`;o00007Oooool3o`0000Go
oooo0ol0000Dooooo`?o00006_ooool3o`0000;ooooo0ol0001hooooo`00Voooool2o`0000oooooo
00?o0000ooooooooool01_ooool2o`0001Cooooo0ol0000Jooooo`?o00000_ooool3o`0007Sooooo
002Kooooo`;o00003oooool00ol0003oooooooooo`0oooooo`;o0000N?ooool009Cooooo0_l0000F
ooooo`03o`000?oooooooooo01[ooooo0_l0000Oooooo`;o0000O?ooool009Cooooo0_l0000Foooo
o`03o`000?oooooooooo01[ooooo0_l0000Oooooo`;o000000?oooooo`000?l00000NOooool00:co
oooo00?o0000ooooooooool06_ooool4o`00023ooooo0_l0001iooooo`00SOooool3o`0000?ooooo
0_l0000Gooooo`03o`000?oooooooooo01cooooo0_l0002Kooooo`00SOooool3o`0000?ooooo0_l0
000Gooooo`03o`000?oooooooooo01oooooo0_l0002Hooooo`00[?ooool3o`0000_ooooo0_l0000B
ooooo`;o00007Oooool2o`0007Wooooo002/ooooo`03o`000?oooooooooo00_ooooo0_l0000aoooo
o`;o00001?ooool2o`0007?ooooo002Uooooo`;o00001Oooool00ol0003oooooooooo`0<ooooo`;o
0000=_ooool2o`0007?ooooo0023ooooo`;o00008?ooool3o`0000Cooooo00?o0000ooooooooool0
3?ooool2o`0001?ooooo0_l0002Fooooo`00Poooool2o`0001_ooooo0_l00004ooooo`;o00001?oo
ool00ol0003oooooooooo`0;ooooo`Co00004_ooool2o`0002?ooooo0_l0001aooooo`00X?ooool2
o`0000[ooooo00?o0000ooooooooool02oooool5o`0003Kooooo0_l0001aooooo`00[?ooool01?l0
003oooooooooooooool2o`0000_ooooo0_l0000gooooo`;o0000L?ooool00:cooooo00Co0000oooo
oooooooooooo0_l0000;ooooo`;o0000<Oooool2o`0000Cooooo0_l0001`ooooo`00[?ooool00ol0
003oooooooooo`03ooooo`;o00002?ooool3o`00037ooooo0_l0001fooooo`00T_ooool2o`0001So
oooo0ol00003ooooo`;o00002?ooool2o`0001?ooooo0_l0002Eooooo`00T_ooool2o`0001Sooooo
00?o0000ooooooooool00oooool2o`0001gooooo0_l0002Eooooo`00V?ooool2o`0001;ooooo00?o
0000ooooooooool00oooool2o`0001cooooo0_l0002Fooooo`00V?ooool2o`0001;ooooo00?o0000
ooooooooool08Oooool2o`0009Kooooo002/ooooo`03o`000?oooooooooo04?ooooo0_l0001doooo
o`00Q?ooool2o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`;o00000_lQ8B42oooo
o`Oo00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0@oooool2
o`000003ooooool0003o0000077ooooo0024ooooo`;o00000oooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo0_l00002ob4Q8@;ooooo0_l000001OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Aooooo`;o0000<oooool2o`00077ooooo0021
ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00?ooooo0_l00007ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool2o`00017ooooo0ol0002Vooooo`00ROooool0
1Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8boooo
o`04ooooo`?o00004?ooool2o`0003Sooooo0_l0001]ooooo`00ROooool01Ol0003ooooooooooooo
oooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool0B_ooool2o`0006gooooo0023ooooo`;o00001?ooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo04Kooooo0_l000000ooooooo0000o`00001^ooooo`00Poooool2o`0000Cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo04Kooooo0_l000000ooooooo0000o`00001^ooooo`00
ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co00001_ooool00ol0003oooooooooo`0Uooooo`;o0000T_ooool008;ooooo0_l0000Fooooo`;o
00004?ooool00ol0003oooooooooo`07ooooo`;o00002oooool2o`0000oooooo0_l0002Booooo`00
P_ooool2o`0001Kooooo0_l0000@ooooo`03o`000?oooooooooo00Oooooo0_l0000;ooooo`;o0000
Xoooool00:cooooo00?o0000ooooooooool04oooool2o`0003Oooooo0_l0001[ooooo`00[?ooool3
o`0001?ooooo0_l0000gooooo`;o0000Joooool00:cooooo00?o0000ooooooooool04oooool2o`00
01;ooooo0_l0002@ooooo`00[?ooool00ol0003oooooooooo`0Wooooo`;o000000?oooooo`000?l0
00007oooool3o`0006_ooooo002/ooooo`03o`000?oooooooooo02[ooooo0_l0000Oooooo`?o0000
Joooool00:[ooooo0ol0002kooooo`00Z_ooool3o`0000_ooooo0_l0002^ooooo`00[?ooool00ol0
003oooooooooo`09ooooo`;o0000[_ooool0093ooooo0_l0000Jooooo`04o`000?oooooooooooooo
o`;o00009?ooool2o`0000;ooooo0_l0000Looooo`;o00000oooool2o`0006Wooooo0022ooooo`;o
00001Oooool2o`0000Gooooo0_l0000Jooooo`?o000000?oooooo`000?l000009?ooool2o`0000;o
oooo0_l0000Looooo`;o00000oooool2o`0006Wooooo0022ooooo`;o00001Oooool2o`00027ooooo
00?o0000ooooooooool02?ooool2o`000:oooooo002/ooooo`03o`000?oooooooooo00Sooooo1?l0
002]ooooo`00Soooool3o`0001[ooooo00?o0000ooooooooool02_ooool2o`0000_ooooo0_l0002P
ooooo`00Soooool3o`0001[ooooo00?o0000ooooooooool05oooool2o`000:3ooooo0022ooooo`?o
00009oooool00ol0003oooooooooo`2iooooo`00P_ooool3o`0000Cooooo0_l0000Qooooo`03o`00
0?oooooooooo00[ooooo0_l00009ooooo`;o00004oooool2o`0008gooooo0023ooooo`;o00001?oo
ool2o`00027ooooo00?o0000ooooooooool02_ooool2o`0000Wooooo0_l0000Cooooo`;o0000SOoo
ool009Cooooo0_l0000Fooooo`03o`000?oooooooooo02_ooooo0_l0002<ooooo`00U?ooool2o`00
01Kooooo0ol0000[ooooo`;o0000S?ooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool00oooool2o`0000Kooooo0_l00012ooooo`;o0000J?ooool000Wooooo1?l0
00000ol@413oooooooooo`0Fooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo
00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o0000
omgMg@0Fooooo`03o`000?oooooooooo00?ooooo0_l00006ooooo`;o00002oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o00001Oooool01Om4A4Co0000o`000?lb
<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^
ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd06?ooool4o`000003oa0@4?oooooooooo01;o
oooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`?o00005_oo
ool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo
00?oV9RHob4Q8Oo^k^h00_l000000ooooooo0000o`000004ooooo`03ogMgMolb<S;ooooo00kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omg
MgOo<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo0006o`0000Gooooo00?o0000oooooooo
ool04?ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo
00Sooooo00?o0000ooooooooool01Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@
ooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00onHV9So8B4Qonk^kP08ooooo`;o00005_ooool00ol0003oooooooooo`0Hooooo`05oa0@4?oo
ooooooooooooool@41003?ooool01OnHV9So8B4Qo`000?l0003ooooo00;o00001Oooool00ol0003o
ooooooooo`0=ooooo`05oa0@4?ooooooooooooooool@41001?ooool2o`0000[ooooo00?o0000oooo
ooooool03Oooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo
01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMg
oc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool03_oo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8b
ooooo`0Eooooo`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000=ooooo`04
oiRHV?lQ8B7ok^k^ooooo`;o00001?ooool00omgMgOo<S8booooo`0>ooooo`05o`000?oooooooooo
ooooool000001?ooool2o`0000Wooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooo
oooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`0Iooooo`03o`000?oo
oooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00
000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`00
0?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`;o000000?oMgMgofIVI_ooool00_ooool2o`000004ob4Q8Ol0003o
<S8bolc<c1Kooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000cooooo
0_l000000omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003o
oooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?oooooo
ooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
6_ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05oa0@4?oo
ooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo017ooooo
00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooo
oooooooooa0@400<ooooo`;o000000?oooooo`000?ooool00_ooool2o`0001[ooooo0ol0000Hoooo
o`;o00000_ooool00ol@413oooooooooo`0:ooooo`;o000000?oooooo`000?ooool00oooool00ol0
003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41000oooool2o`0000Oooooo00?o0000
ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00ooo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooo
oooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S80
1?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003o
ooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@00Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0<ooooo`;o00002_ooool2
o`000003oooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oo
oooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`;o00001oooool00ol0003ooooo
ooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b
00Cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Dooooo`002Oooool00omEEEGo
IVIVo`00000Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000@oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0001Oooooo00?o0000ooooooooool0
0oooool2o`0000Oooooo0_l00009ooooo`;o000000Co<S8bo`000?lb<S;ok^k^2oooool01OnHV9So
410@o`000?lQ8B7oc<c<00Cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0001Wooooo00?o
EEEEofIVI_l000005_ooool00:cooooo00?o0000ooooooooool00oooool3o`0000Kooooo0_l00009
ooooo`Co0000W_ooool008oooooo0_l0000Kooooo`03o`000?oooooooooo00Cooooo0_l0000Coooo
o`;o0000W_ooool008;ooooo0_l0000;ooooo`;o00006oooool00ol0003oooooooooo`0;ooooo`;o
00007_ooool2o`00087ooooo0_l00002ooooo`;o00001Oooool008;ooooo0_l0000Xooooo`03o`00
0?oooooooooo00_ooooo0_l0000Nooooo`;o0000POooool01_o^k^ko8B4QohN7Qonj^[[o0000omgM
g@Gooooo0022ooooo`;o0000:?ooool00ol0003oooooooooo`0Gooooo`;o00005?ooool2o`00083o
oooo00CogMgMo`000?l@413oc<c<1_ooool000Ooooooool0001<o`0000cooooo00Cok^k^ob4Q8Ol@
413ok^k^1_ooool000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`Co
00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00Co8B4QogMgMomg
MgOo<S8b1_ooool000Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`04ooooo`;o
00004?ooool2o`0000oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool02Oooool2o`0000;ooooo0_l00005ooooo`00
U?ooool2o`0001Kooooo00?o0000ooooooooool01?ooool2o`00013ooooo0_l000000ooooooo0000
o`00000Dooooo`;o0000R?ooool009Cooooo0_l0000Fooooo`03o`000?oooooooooo01Wooooo0_l0
000Dooooo`;o0000R?ooool00:cooooo00?o0000ooooooooool01?ooool2o`0002Wooooo0_l00028
ooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o00005?ooool2o`0009gooooo002/ooooo`03
o`000?oooooooooo00gooooo0_l0000;ooooo`;o0000WOooool00:cooooo0ol0000=ooooo`;o0000
7_ooool2o`0002?ooooo0_l0001Uooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o00004Ooo
ool2o`0001Cooooo0_l0000Sooooo`;o0000IOooool00:cooooo00?o0000ooooooooool01?ooool2
o`00017ooooo0_l0002Pooooo`00V?ooool2o`0001;ooooo00?o0000ooooooooool0;Oooool2o`00
08[ooooo0021ooooo`;o00005Oooool2o`0001;ooooo0ol0000]ooooo`;o0000R_ooool0087ooooo
0_l0000Yooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool06Oooool2o`0001?ooooo0_l0
0029ooooo`00[?ooool00ol0003oooooooooo`0Iooooo`;o00004oooool4o`0001oooooo0_l0001V
ooooo`00[?ooool00ol0003oooooooooo`0`ooooo`;o00007oooool2o`0006Kooooo002/ooooo`?o
00006Oooool2o`0003Cooooo0_l0001Xooooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool0
2oooool3o`0000_ooooo0_l0000Eooooo`;o00007Oooool2o`0006Sooooo0023ooooo`;o00001?oo
ool2o`0000Wooooo0_l0000Fooooo`03o`000?oooooooooo00_ooooo0ol0000Mooooo`?o00000_oo
ool2o`0008Oooooo0023ooooo`;o00001?ooool2o`00027ooooo00?o0000ooooooooool00oooool2
o`0002Kooooo0ol0000Pooooo`;o0000JOooool00:cooooo00?o0000ooooooooool00oooool2o`00
02Oooooo0_l0000Pooooo`;o0000JOooool008;ooooo0_l0000Xooooo`03o`000?oooooooooo02_o
oooo1Ol00029ooooo`00P_ooool2o`00017ooooo0_l0000Eooooo`03o`000?oooooooooo01Oooooo
0_l0000Booooo`;o000000?oooooo`000?l00000ROooool008Wooooo0_l0000:ooooo`;o00005Ooo
ool00ol0003oooooooooo`03ooooo`;o00004_ooool4o`00013ooooo0ol000000ooooooo0000o`00
0028ooooo`00ROooool2o`00027ooooo0ol00003ooooo`;o00001_ooool2o`0000[ooooo1?l0000A
ooooo`;o000000?oooooo`000?l00000R?ooool00:cooooo00?o0000ooooooooool02oooool2o`00
0:cooooo002/ooooo`03o`000?oooooooooo00_ooooo0_l0002/ooooo`00[?ooool00ol0003ooooo
ooooo`0Eooooo`;o00000_ooool2o`0009kooooo002/ooooo`03o`000?oooooooooo01Gooooo0_l0
0002ooooo`;o0000=oooool2o`0006Gooooo002/ooooo`03o`000?oooooooooo02gooooo0_l0000S
ooooo`;o0000IOooool009Gooooo0_l0000Eooooo`03o`000?oooooooooo00Wooooo0_l0000;oooo
o`;o00005Oooool2o`0008[ooooo002Aooooo`;o00000_ooool2o`0001Gooooo00?o0000oooooooo
ool02Oooool2o`0000_ooooo0_l0002Qooooo`00TOooool2o`0000;ooooo0_l0000Eooooo`?o0000
^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
097ooooo0_l0000Iooooo`03o`000?oooooooooo01Kooooo0_l0002Qooooo`00TOooool2o`0001Wo
oooo00Co0000oooooooooooooooo0_l0000Cooooo`;o0000XOooool00:cooooo00Co0000oooooooo
oooooooo0_l0000Cooooo`;o0000XOooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo01Kooooo0_l0000gooooo`;o0000J?ooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`1?ooooo`;o0000J?ooool008Wooooo00Go410@oooooooooooooooooa0@
400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`000;Wooooo0029
ooooo`05o`000?ooooooooooooooool000001?ooool2o`0000Oooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01Kooooo0_l0000fooooo`;o0000JOoo
ool008Wooooo00Go0000ooooooooooooooooo`000004ooooo`;o00002?ooool00omgMgOoIVIVoooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Fooooo`;o0000
4?ooool2o`0002Cooooo0_l0001Yooooo`00ROooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
0ol0000Nooooo`;o0000Soooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`06o`00
0?nj^[[ooooooiRHV?l@413ooooo0_l000000ooooooo0000ooooo`08ooooo`03o`000?oooooooooo
00Oooooo0ol0000Pooooo`;o00008Oooool2o`0006[ooooo0029ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool3o`000003ob4Q8Oo<c<cooooo00;o000000?oooooo`000?l000000_l00006oooo
o`04o`000?oooooo0000o`0002Wooooo0_l0000Qooooo`;o0000J_ooool009Wooooo0_l00006oooo
o`;o00002Oooool01?l0003oooooo`000?l0001=ooooo`;o0000JOooool008?ooooo0_l0000Loooo
o`;o00000_ooool2o`0000Gooooo00?o0000ooooooooool0:?ooool2o`0002Cooooo0ol0001Xoooo
o`00Poooool2o`0000Oooooo0_l0000;ooooo`;o00002_ooool2o`0000Gooooo00?o0000oooooooo
ool0:?ooool2o`0002?ooooo1?l0001Xooooo`00S?ooool2o`0000_ooooo0_l0000Aooooo`?o0000
4_ooool2o`0001?ooooo0_l0000Tooooo`;o0000J_ooool008cooooo0_l0000;ooooo`;o00004Ooo
ool00ol0003oooooooooo`0Booooo`;o00004oooool2o`00093ooooo002<ooooo`;o00002oooool2
o`00017ooooo00?o0000ooooooooool04_ooool2o`000:Gooooo0024ooooo`;o00004oooool2o`00
017ooooo00?o0000ooooooooool04_ooool2o`000:Gooooo0024ooooo`;o00001_ooool3o`0000Co
oooo0_l0000Gooooo`03o`000?oooooooooo0;Wooooo002<ooooo`?o00001?ooool2o`0001Oooooo
00?o0000ooooooooool0^Oooool009Gooooo0_l0000Eooooo`03o`000?oooooooooo01;ooooo0_l0
002Uooooo`00UOooool2o`0001Gooooo00?o0000ooooooooool04_ooool2o`000:Gooooo002/oooo
o`?o0000^Oooool008kooooo0_l00004ooooo`;o00005_ooool00ol0003oooooooooo`0Xooooo`?o
0000S_ooool008kooooo0_l00004ooooo`;o00005_ooool00ol0003oooooooooo`03ooooo`;o0000
8oooool3o`0008kooooo002/ooooo`03o`000?oooooooooo00?ooooo0_l0002dooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00X?ooool2o`0000Kooooo0_l00002ooooo`03o`000?oooooooooo
02Gooooo0_l0000Rooooo`;o0000K_ooool00:3ooooo0_l00006ooooo`;o00000_ooool00ol0003o
ooooooooo`0Uooooo`;o00008_ooool2o`0006kooooo002>ooooo`;o00001oooool2o`0001?ooooo
00?o0000ooooooooool08_ooool2o`0000;ooooo0_l0000Qooooo`?o0000KOooool008kooooo0_l0
0007ooooo`;o00004oooool3o`0002;ooooo0_l00002ooooo`;o00008Oooool3o`0006gooooo002R
ooooo`;o000000?oooooo`000?l000001Oooool00ol0003oooooooooo`0>ooooo`;o0000ZOooool0
0:;ooooo0_l000000ooooooo0000o`000005ooooo`03o`000?oooooooooo00kooooo0_l0002Yoooo
o`00T?ooool2o`0001[ooooo00?o0000ooooooooool0^Oooool008Oooooo0_l00007ooooo`;o0000
6_ooool00ol0003oooooooooo`2iooooo`00Qoooool2o`0002?ooooo0ol0000Pooooo`;o0000Uooo
ool008oooooo0_l0000Kooooo`?o00003?ooool2o`0001;ooooo0_l00003ooooo`;o0000T_ooool0
08oooooo0_l0000Kooooo`03o`000?oooooooooo00cooooo0_l0000Gooooo`;o00008?ooool2o`00
073ooooo002Jooooo`;o00004?ooool3o`0002Cooooo0_l0000Qooooo`;o0000L?ooool008Kooooo
0_l0000Booooo`;o00004?ooool2o`0002Gooooo0_l0002Cooooo`00Q_ooool2o`0002Cooooo00?o
0000ooooooooool07oooool2o`0000;ooooo0_l0002Dooooo`00[?ooool00ol0003oooooooooo`08
ooooo`;o00005Oooool2o`0000;ooooo0_l0002Dooooo`00TOooool2o`0000Sooooo0_l0000?oooo
o`03o`000?oooooooooo00Sooooo0_l0000Dooooo`;o0000VOooool008Oooooo0_l00008ooooo`;o
00002?ooool2o`0000oooooo00?o0000ooooooooool02?ooool4o`0001;ooooo0_l000000ooooooo
0000o`00002Fooooo`00Qoooool2o`0000Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool02_ooool2o`00
01Gooooo0_l0002Fooooo`00Qoooool2o`0000Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00[ooooo0_l0002]oooo
o`00TOooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Qooooo`;o0000U_ooool008Sooooo0_l00007ooooo`05o`000?oooooooooooooo
ool000003oooool2o`0000Gooooo0ol0000Qooooo`;o0000U_ooool008Sooooo0_l00007ooooo`05
o`000?ooooooooooooooool000001_ooool2o`0000?ooooo0_l000001?lQ8B7o0000o`000?l00005
ooooo`03o`000?oooooooooo047ooooo0_l0001fooooo`00TOooool01Ol@413ooooooooooooooooo
410@00Kooooo0_l00003ooooo`;o00002Oooool00ol0003oooooooooo`0Oooooo`;o00008?ooool2
o`0007Kooooo002Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool3o`0000Oooooo00?o0000
ooooooooool01Oooool2o`0001Sooooo0_l0002Hooooo`00ROooool2o`0000Kooooo00?ok^k^oc8b
<_l000000_l0000<ooooo`Co00001_ooool00ol0003oooooooooo`05ooooo`;o00004_ooool2o`00
09kooooo0029ooooo`;o00002Oooool2o`0001Kooooo00?o0000ooooooooool01?ooool2o`0001?o
oooo0_l0002Nooooo`00ROooool2o`0001Sooooo0_l00007ooooo`03o`000?oooooooooo00Cooooo
0_l0000Cooooo`;o0000W_ooool008Wooooo0_l0000Hooooo`;o00001oooool00ol0003ooooooooo
o`0Iooooo`;o0000W_ooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`0Ioooo
o`;o0000W_ooool009Cooooo0_l0000Fooooo`04o`000?ooooooooooooooo`;o00005_ooool2o`00
09kooooo002Dooooo`;o00005_ooool01?l0003oooooooooooooool2o`000;Kooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`04o`000?ooooooooooooooo`;o0000]_ooool00:cooooo
00Co0000oooooooooooooooo0_l0000Dooooo`;o00009?ooool2o`0007[ooooo002/ooooo`03o`00
0?oooooooooo00;o00005Oooool2o`0002Cooooo0_l0001jooooo`00[?ooool5o`0001Gooooo0_l0
002Pooooo`00[?ooool00ol0003oooooooooo`0Fooooo`?o00008Oooool3o`0007cooooo002Hoooo
o`;o00004_ooool00ol0003oooooooooo`02o`0001Cooooo0_l0000Rooooo`?o0000O?ooool009So
oooo0_l0000Booooo`03o`000?oooooo000000;o0000]oooool00:cooooo00Co0000ooooool0003o
00005?ooool2o`000:;ooooo002;ooooo`;o00003oooool2o`0000kooooo00?o0000ooooooooool0
5Oooool2o`000:;ooooo002;ooooo`;o00003oooool2o`0000kooooo00?o0000ooooooooool0^Ooo
ool00:cooooo00?o0000ooooooooool04oooool2o`000:Cooooo002Oooooo`;o00002oooool3o`00
00oooooo0_l00002ooooo`;o0000Y?ooool009oooooo0_l00007ooooo`;o00000_ooool00ol0003o
ooooooooo`0?ooooo`;o0000Z?ooool009oooooo0_l00007ooooo`;o00000_ooool00ol0003ooooo
ooooo`0eooooo`?o0000POooool008gooooo0_l0000Dooooo`;o00001oooool00ol0003ooooooooo
o`0Cooooo`;o00008?ooool3o`00087ooooo002=ooooo`Co00003Oooool2o`0000?ooooo0_l00007
ooooo`03o`000?oooooooooo01?ooooo0_l0000Pooooo`;o0000P_ooool008oooooo0_l0000=oooo
o`Co00002_ooool00ol0003oooooooooo`0eooooo`;o0000P_ooool008oooooo0_l0000?ooooo`;o
00002_ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00cooooo
0_l0002[ooooo`00[?ooool00ol0003oooooooooo`0<ooooo`;o0000Zoooool008Wooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP04ooooo`;o000000?o8B4Qooooooooool01?ooool00ol0003ok^k^oooo
o`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2iooooo`00ROoo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0ol000000olQ8B7oooooooooo`04ooooo`03oeEE
EOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2iooooo`00ROoo
ool01Ol@413ooooooooooooooooo410@00?ooooo0_l00008ooooo`03ojVYZOmEEEGooooo00Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`;o0000[oooool008Wooooo00Go
0000ooooooooooooooooo`000003ooooo`;o00002Oooool00olQ8B7oooooooooo`06ooooo`03ogMg
Molb<S;ooooo00Cooooo0ol00005ooooo`;o000000?oooooo`000?l00000[oooool008Wooooo00Go
0000ooooooooooooooooo`000003ooooo`;o000000?oooooo`000?l000001_ooool00omEEEGoc<c<
ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`05ooooo`Co
0000/?ooool008Wooooo00Go410@oooooooooooooooooa0@4006ooooo`;o00001_ooool00onYZJWo
MgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool2o`000;3o
oooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0000Cooooo00Go410@oooooooo
oooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool2o`00
0;7ooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2o`0000Cooooo1Ol00004oooo
o`Co00001_ooool00ol0003oooooooooo`06ooooo`;o0000/Oooool009Cooooo0_l0000Fooooo`03
o`000?oooooooooo0;Wooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`2iooooo`00Tooo
ool2o`0001Oooooo00?o0000ooooooooool00oooool2o`000;Cooooo002Cooooo`;o00000oooool2
o`0001;ooooo0ol00003ooooo`;o0000]?ooool009Gooooo1Ol0000Booooo`03o`000?oooooooooo
00;ooooo0ol0002dooooo`00UOooool6o`00017ooooo0ol00002ooooo`?o0000]?ooool009Sooooo
0ol0000Aooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool009cooooo0_l00009ooooo`;o
00000oooool00ol0003oooooooooo`2iooooo`00W?ooool2o`0000Wooooo0_l00003ooooo`?o0000
^Oooool00:;ooooo1?l00006ooooo`03o`000?oooooooooo0;Wooooo002Rooooo`Co00001_ooool0
0ol0003oooooooooo`2iooooo`00Zoooool2o`000;_ooooo002[ooooo`;o00008?ooool2o`0009Wo
oooo002Nooooo`;o00003?ooool00ol0003oooooooooo`0Nooooo`;o0000VOooool009gooooo0ol0
000<ooooo`03o`000?oooooooooo0;Wooooo002Mooooo`;o000000?oooooo`000?l000002_ooool0
0ol0003oooooooooo`2iooooo`00X?ooool3o`0000Wooooo00?o0000ooooooooool0^Oooool00:7o
oooo0_l00009ooooo`?o00006oooool2o`0009cooooo002/ooooo`03o`000?oooooooooo01_ooooo
0_l0002Looooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3
o`0001Cooooo0_l0002Sooooo`00[?ooool00ol0003oooooooooo`0Dooooo`;o0000Xoooool00:co
oooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o
0000ooooooooool04Oooool2o`000:Kooooo002/ooooo`03o`000?oooooooooo017ooooo0_l0002V
ooooo`00X_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0^Oooool00:Co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00Y?ooool00ol0003ooooo
ooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo00?o0000
ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo00?o0000oooooooo
ool0`Oooool00:;ooooo00?oEEEEofIVI_l00000`oooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00:[ooooo00Co410@o`000?l0003o0000^_ooool00:_ooooo
00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00Ko0000
ogMgMol0003o0000oeEEEOo^k^jgooooo`00Zoooool01_l0003oEEEEonk^k_ooooooMgMgoeEEEKOo
oooo002[ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0]Oooool00:_ooooo00?o
0000onk^k_ooool00_ooool00ol0003oooooooooo`2eooooo`00Zoooool01_l0003oEEEEonk^k_oo
ooooMgMgofIVI[Oooooo002Zooooo`03oa0@4?l0003oMgMg00;o000000?oIVIVonk^k_ooool0]_oo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.60515 .29844 Mdot
.64455 .39144 Mdot
.48108 .36662 Mdot
.55085 .52458 Mdot
.5635 .34332 Mdot
.49203 .12332 Mdot
.44135 .41366 Mdot
.40107 .13512 Mdot
.389 .22524 Mdot
.45819 .76737 Mdot
.41185 .53903 Mdot
.48534 .01003 Mdot
.6693 .51895 Mdot
.44344 .74833 Mdot
.56467 .1002 Mdot
.53785 .63993 Mdot
.43023 .79145 Mdot
.6698 .52469 Mdot
.47156 .19663 Mdot
.60968 .78417 Mdot
.6583 .5925 Mdot
.6583 .49165 Mdot
.65252 .56822 Mdot
.66716 .55739 Mdot
.60629 .14591 Mdot
.59894 .54248 Mdot
.42878 .3019 Mdot
.48708 .20493 Mdot
.5816 .83052 Mdot
.65056 .43567 Mdot
.63458 .6756 Mdot
.37461 .34435 Mdot
.4179 .0875 Mdot
.39514 .47502 Mdot
.39495 .40804 Mdot
.57043 .82916 Mdot
.41928 .88662 Mdot
.46827 .20711 Mdot
.50913 .92311 Mdot
.47147 .00429 Mdot
.57088 .09374 Mdot
.39367 .47163 Mdot
.44366 .15159 Mdot
.59502 .2645 Mdot
.56861 .22177 Mdot
.58863 .42807 Mdot
.41999 .63254 Mdot
.37521 .65637 Mdot
.57146 .689 Mdot
.54743 .8731 Mdot
.3727 .61333 Mdot
.51127 .92795 Mdot
.76498 .63013 Mdot
.42953 .19004 Mdot
.40575 .28735 Mdot
.40684 .13156 Mdot
.41942 .07579 Mdot
.44973 .83682 Mdot
.39268 .78762 Mdot
.55878 .20629 Mdot
.59284 .46932 Mdot
.69105 .25702 Mdot
.48356 .94496 Mdot
.46652 .26415 Mdot
.47754 .02113 Mdot
.38028 .27864 Mdot
.45391 .75892 Mdot
.52827 .66315 Mdot
.44867 .22682 Mdot
.66078 .59953 Mdot
.47542 .86206 Mdot
.47763 .31322 Mdot
.4362 .71456 Mdot
.48565 .76858 Mdot
.48317 .94503 Mdot
.50857 .52019 Mdot
.7647 .63108 Mdot
.58622 .58322 Mdot
.53146 .90249 Mdot
.52904 .76686 Mdot
.61011 .74756 Mdot
.65021 .44399 Mdot
.54933 .51612 Mdot
.39305 .48977 Mdot
.38607 .2173 Mdot
.55088 .59556 Mdot
.56647 .35106 Mdot
.58536 .45019 Mdot
.48639 .85143 Mdot
.52277 .67908 Mdot
.6177 .16337 Mdot
.76679 .49172 Mdot
.50095 .28334 Mdot
.58415 .41435 Mdot
.49688 .27802 Mdot
.76418 .44777 Mdot
.44561 .75269 Mdot
.37168 .42335 Mdot
.76454 .63743 Mdot
.50805 .82819 Mdot
.61875 .33275 Mdot
.52445 .7972 Mdot
.50969 .03357 Mdot
.6109 .29961 Mdot
.64323 .67137 Mdot
.39585 .43732 Mdot
.4418 .82985 Mdot
.48706 .19787 Mdot
.50107 .28323 Mdot
.65551 .61969 Mdot
.45797 .77209 Mdot
.55182 .48124 Mdot
.37608 .32947 Mdot
.60898 .77525 Mdot
.72119 .77472 Mdot
.51723 .62155 Mdot
.59366 .51699 Mdot
.36951 .39367 Mdot
.36956 .40745 Mdot
.39436 .7783 Mdot
.66775 .53078 Mdot
.66184 .20607 Mdot
.64535 .62351 Mdot
.58792 .82309 Mdot
.65819 .61088 Mdot
.54701 .56961 Mdot
.59023 .80776 Mdot
.75707 .41709 Mdot
.64322 .43127 Mdot
.45159 .68633 Mdot
.65827 .53159 Mdot
.63155 .37228 Mdot
.5236 .045 Mdot
.47792 .11293 Mdot
.46186 .12613 Mdot
.56549 .85852 Mdot
.48043 .96232 Mdot
.57981 .82862 Mdot
.43554 .71098 Mdot
.45905 .02012 Mdot
.55775 .08943 Mdot
.7314 .35912 Mdot
.53615 .38025 Mdot
.45209 .21712 Mdot
.43343 .80136 Mdot
.61282 .77435 Mdot
.37779 .28227 Mdot
.69524 .82853 Mdot
.54108 .30696 Mdot
.58739 .45871 Mdot
.62172 .14167 Mdot
.53837 .7725 Mdot
.41724 .3568 Mdot
.6692 .54895 Mdot
.46696 .31741 Mdot
.55742 .21975 Mdot
.47033 .95806 Mdot
.49593 .93985 Mdot
.37658 .30438 Mdot
.40756 .84561 Mdot
.4731 .95953 Mdot
.59265 .60475 Mdot
.54545 .88641 Mdot
.50946 .01891 Mdot
.57873 .81066 Mdot
.47468 .1281 Mdot
.62349 .35623 Mdot
.37886 .27558 Mdot
.64256 .67935 Mdot
.446 .23359 Mdot
.50548 .94169 Mdot
.54131 .87566 Mdot
.53474 .39396 Mdot
.4465 .23707 Mdot
.57587 .39519 Mdot
.53941 .29729 Mdot
.44953 .03082 Mdot
.76222 .4412 Mdot
.55697 .22037 Mdot
.49952 .67412 Mdot
.55436 .86752 Mdot
.52843 .91315 Mdot
.50488 .02078 Mdot
.52167 .69872 Mdot
.57681 .09998 Mdot
.42873 .57508 Mdot
.39738 .18286 Mdot
.75718 .42838 Mdot
.36822 .50624 Mdot
.50916 .02003 Mdot
.44254 .1506 Mdot
.64492 .18249 Mdot
.61612 .769 Mdot
.45348 .28659 Mdot
.69192 .26602 Mdot
.39612 .1605 Mdot
.58035 .09775 Mdot
.51328 .03562 Mdot
.58221 .41052 Mdot
.77338 .49812 Mdot
.42874 .80253 Mdot
.51451 .61592 Mdot
.51277 .62436 Mdot
.48572 .3179 Mdot
.56996 .37401 Mdot
.77424 .5208 Mdot
.62934 .37114 Mdot
.43476 .36292 Mdot
.5149 .15222 Mdot
.54899 .43422 Mdot
.42786 .58363 Mdot
.41275 .57154 Mdot
.66597 .47883 Mdot
.58873 .56607 Mdot
.64096 .68358 Mdot
.51427 .71108 Mdot
.62678 .36756 Mdot
.58806 .55985 Mdot
.52054 .03098 Mdot
.43716 .64614 Mdot
.57454 .24252 Mdot
.44635 .02135 Mdot
.59393 .50275 Mdot
.37428 .61454 Mdot
.64913 .65919 Mdot
.59308 .781 Mdot
.50797 .71963 Mdot
.549 .31007 Mdot
.6329 .34425 Mdot
.52572 .3554 Mdot
.56418 .09903 Mdot
.65879 .19681 Mdot
.54849 .58749 Mdot
.45734 .64432 Mdot
.76957 .55296 Mdot
.52293 .79016 Mdot
.4156 .3874 Mdot
.65942 .20564 Mdot
.45365 .22223 Mdot
.61632 .31038 Mdot
.6567 .57964 Mdot
.62736 .35772 Mdot
.69526 .26778 Mdot
.45411 .12856 Mdot
.63951 .69683 Mdot
.47566 .86192 Mdot
.36912 .4368 Mdot
.50175 .29238 Mdot
.44073 .92778 Mdot
.44953 .82757 Mdot
.47999 .86106 Mdot
.49443 .93953 Mdot
.5825 .10243 Mdot
.5168 .62202 Mdot
.4686 .26998 Mdot
.41771 .87564 Mdot
.59073 .59132 Mdot
.44579 .23988 Mdot
.398 .33883 Mdot
.50789 .53898 Mdot
.43079 .05281 Mdot
.38331 .73081 Mdot
.55241 .73461 Mdot
.41498 .3941 Mdot
.59038 .78821 Mdot
.47718 .71134 Mdot
.5264 .7906 Mdot
.6025 .29853 Mdot
.41335 .54309 Mdot
.51355 .1586 Mdot
.55263 .85674 Mdot
.57544 .65503 Mdot
.58655 .80922 Mdot
.40561 .28492 Mdot
.47352 .77914 Mdot
.54131 .74979 Mdot
.48358 .95748 Mdot
.52493 .69318 Mdot
.51335 .23234 Mdot
.36995 .54358 Mdot
.42031 .65294 Mdot
.53876 .18735 Mdot
.55101 .87449 Mdot
.47704 .71951 Mdot
.48183 .76663 Mdot
.40142 .81838 Mdot
.48853 .01434 Mdot
.48681 .19672 Mdot
.45386 .34498 Mdot
.56816 .38494 Mdot
.63051 .7319 Mdot
.58886 .45721 Mdot
.61242 .73913 Mdot
.75743 .43551 Mdot
.3855 .73563 Mdot
.53681 .06744 Mdot
.37501 .61755 Mdot
.44128 .58208 Mdot
.42056 .89832 Mdot
.69222 .27475 Mdot
.64173 .70283 Mdot
.55695 .09127 Mdot
.68079 .85451 Mdot
.55935 .71112 Mdot
.41204 .24012 Mdot
.63083 .36419 Mdot
.37108 .3938 Mdot
.58273 .11213 Mdot
.41923 .6306 Mdot
.36982 .49707 Mdot
.59042 .59786 Mdot
.52298 .55906 Mdot
.66466 .49702 Mdot
.42703 .78318 Mdot
.66544 .53808 Mdot
.61636 .13643 Mdot
.50464 .66502 Mdot
.58598 .26442 Mdot
.39495 .45234 Mdot
.49011 .02452 Mdot
.48763 .70664 Mdot
.51775 .03476 Mdot
.66147 .22211 Mdot
.73281 .3449 Mdot
.54455 .59663 Mdot
.46621 .11291 Mdot
.39289 .5271 Mdot
.4665 .94685 Mdot
.53996 .28382 Mdot
.52676 .54417 Mdot
.43649 .49514 Mdot
.44502 .83411 Mdot
.42713 .05443 Mdot
.40799 .83933 Mdot
.48837 .26422 Mdot
.66265 .47912 Mdot
.45374 .69362 Mdot
.48915 .32281 Mdot
.63565 .3531 Mdot
.47644 .11575 Mdot
.47428 .12787 Mdot
.59128 .60998 Mdot
.56833 .37104 Mdot
.77273 .59299 Mdot
.58184 .62883 Mdot
.64829 .45097 Mdot
.47886 .26312 Mdot
.41992 .08647 Mdot
.42632 .31611 Mdot
.57957 .82727 Mdot
.65335 .49724 Mdot
.5177 .32086 Mdot
.58796 .53693 Mdot
.7293 .35074 Mdot
.46886 .00785 Mdot
.439 .93969 Mdot
.57129 .82995 Mdot
.57403 .67356 Mdot
.41631 .75166 Mdot
.55424 .85836 Mdot
.52637 .7877 Mdot
.4723 .00767 Mdot
.7292 .32399 Mdot
.63801 .70195 Mdot
.52613 .04864 Mdot
.52481 .04213 Mdot
.5512 .06624 Mdot
.50448 .36065 Mdot
.53321 .77005 Mdot
.56506 .09899 Mdot
.42248 .06961 Mdot
.50782 .37167 Mdot
.62653 .7058 Mdot
.56823 .66821 Mdot
.50266 .13297 Mdot
.61531 .32405 Mdot
.37467 .36273 Mdot
.61702 .31347 Mdot
.41308 .87058 Mdot
.42368 .88706 Mdot
.65209 .56493 Mdot
.4597 .96262 Mdot
.65678 .53541 Mdot
.5898 .12518 Mdot
.7172 .78775 Mdot
.38286 .69656 Mdot
.55055 .20404 Mdot
.4748 .31767 Mdot
.63675 .18269 Mdot
.50445 .83106 Mdot
.43672 .51156 Mdot
.49914 .01321 Mdot
.66001 .60433 Mdot
.52848 .52156 Mdot
.47318 .77344 Mdot
.59634 .53825 Mdot
.42103 .34044 Mdot
.3743 .64904 Mdot
.66022 .63209 Mdot
.6943 .27465 Mdot
.50879 .02438 Mdot
.40606 .68179 Mdot
.76737 .60171 Mdot
.40873 .70589 Mdot
.53271 .28111 Mdot
.5325 .27515 Mdot
.48989 .64577 Mdot
.43192 .04652 Mdot
.48472 .01026 Mdot
.4261 .31549 Mdot
.52749 .3556 Mdot
.41128 .57349 Mdot
.5426 .63473 Mdot
.60698 .12857 Mdot
.5784 .38371 Mdot
.59202 .79045 Mdot
.54532 .43215 Mdot
.42259 .32083 Mdot
.47369 .71362 Mdot
.57405 .37307 Mdot
.39527 .51377 Mdot
.41241 .41406 Mdot
.4384 .34227 Mdot
.64372 .17545 Mdot
.45216 .02552 Mdot
.45151 .43341 Mdot
.39651 .38032 Mdot
.44039 .82679 Mdot
.5847 .27331 Mdot
.56273 .6859 Mdot
.44187 .24569 Mdot
.62921 .16822 Mdot
.7678 .44618 Mdot
.62731 .3436 Mdot
.73702 .73579 Mdot
.597 .26536 Mdot
.43712 .34318 Mdot
.41779 .10393 Mdot
.57424 .11042 Mdot
.41217 .45606 Mdot
.6522 .51382 Mdot
.77051 .60434 Mdot
.53302 .37571 Mdot
.52784 .49554 Mdot
.55077 .32676 Mdot
.60022 .77185 Mdot
.54764 .72895 Mdot
.77044 .49541 Mdot
.427 .5601 Mdot
.4196 .22811 Mdot
.39442 .56424 Mdot
.47421 .25773 Mdot
.49648 .68511 Mdot
.51082 .72769 Mdot
.40533 .11915 Mdot
.50525 .66714 Mdot
.54851 .88067 Mdot
.6374 .36711 Mdot
.58015 .2473 Mdot
.59073 .80497 Mdot
.61641 .72691 Mdot
.41889 .75417 Mdot
.75376 .38725 Mdot
.47083 .77387 Mdot
.42892 .05017 Mdot
.57429 .09129 Mdot
.41279 .50321 Mdot
.42844 .91863 Mdot
.56864 .67227 Mdot
.42389 .76473 Mdot
.58458 .81975 Mdot
.61629 .32358 Mdot
.48726 .20108 Mdot
.58858 .53354 Mdot
.39507 .53382 Mdot
.67479 .22023 Mdot
.48142 .12523 Mdot
.50887 .47904 Mdot
.45163 .14239 Mdot
.53532 .75687 Mdot
.49482 .32995 Mdot
.53432 .63833 Mdot
.42198 .21494 Mdot
.44065 .15282 Mdot
.51632 .61716 Mdot
.58946 .58932 Mdot
.38187 .26531 Mdot
.55553 .31855 Mdot
.59758 .28961 Mdot
.42928 .27801 Mdot
.50985 .24332 Mdot
.51788 .41338 Mdot
.7339 .75146 Mdot
.52172 .43959 Mdot
.64046 .37228 Mdot
.37165 .48025 Mdot
.5825 .80625 Mdot
.4548 .21557 Mdot
.56994 .84431 Mdot
.49792 .01542 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:;ooooo0ol00007ooooo`03o`000?oooooooooo0;Wo
oooo002Rooooo`?o00001oooool00ol0003oooooooooo`2iooooo`00XOooool4o`0000;ooooo0_l0
0003ooooo`03o`000?oooooooooo0;Wooooo002Qooooo`;o000000Coooooo`000?oooooooooo0_l0
0002ooooo`;o0000^oooool00:;ooooo00?oEEEEofIVI_l000000oooool2o`000003ooooool0003o
00000;_ooooo002Xooooo`;o000000?oooooo`000?l000000_ooool2o`000;Oooooo002Jooooo`;o
00000_ooool2o`0000Cooooo0_l00006ooooo`Go0000]oooool009[ooooo1_l00004ooooo`;o0000
0_ooool2o`0000;ooooo1Ol0002gooooo`00W?ooool2o`0000[ooooo0_l00002ooooo`04o`000?oo
oooo0000o`000;Sooooo002Kooooo`;o00003oooool00ol0003oooooooooo`03ooooo`;o0000]?oo
ool009_ooooo0_l0000?ooooo`03o`000?oooooooooo00Go0000]?ooool00:cooooo00?o0000oooo
ooooool01?l0002eooooo`00[?ooool01?l0003oooooooooooooool2o`000;Kooooo002/ooooo`03
o`000?oooooooooo00Gooooo0_l0002booooo`00UOooool2o`0001Gooooo00?o0000ooooooooool0
1?ooool3o`000;;ooooo002Dooooo`?o00005Oooool00ol0003oooooooooo`04ooooo`?o0000/_oo
ool009Cooooo0ol0000Eooooo`?o00001Oooool2o`000;;ooooo002Dooooo`?o00005Oooool00ol0
003oooooooooo`2iooooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool02Oooool2o`0000;ooooo0_l0002Zooooo`00T_ooool2o`0001Sooooo00?o0000oooo
ooooool02Oooool2o`0000;ooooo0_l0002Zooooo`00T_ooool2o`0001Sooooo00?o0000oooooooo
ool0^Oooool0097ooooo0_l0000Iooooo`?o0000^Oooool0097ooooo0_l0000Iooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Aooooo`;o00006Oooool00ol0
003oooooooooo`2iooooo`00T?ooool3o`0001Wooooo00?o0000ooooooooool04?ooool2o`000:Oo
oooo002@ooooo`;o00006_ooool00ol0003oooooooooo`0?ooooo`?o00000oooool2o`000:;ooooo
002/ooooo`03o`000?oooooooooo00oooooo0_l00003ooooo`?o0000X_ooool00:cooooo00?o0000
ooooooooool05?ooool2o`000003ooooool0003o00000:3ooooo002/ooooo`?o00004_ooool2o`00
00;ooooo0ol0002Pooooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool04_ooool2o`0000;o
oooo1?l0002Oooooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool06?ooool2o`0009oooooo
002/ooooo`03o`000?oooooooooo01Gooooo0_l0002Rooooo`00X?ooool2o`0000;ooooo0_l00006
ooooo`03o`000?oooooooooo01Gooooo0_l000000ooooooo0000o`00002Oooooo`00X?ooool2o`00
00;ooooo0_l00006ooooo`03o`000?oooooooooo01Sooooo0_l0002Oooooo`00ROooool00oo^k^ko
<S8bo`000002o`0000Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0
003o0000omgMg@05ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`03ogMgMonHV9Sooooo00;o
00001Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo0;Wooooo0021ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00go
oooo00?oZJVYoeEEEOooool01oooool2o`0000;ooooo0_l000001?oooooo0000o`000?l0000Joooo
o`;o0000WOooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`;o000000?oooooo`00
0?l000000_ooool4o`0000;ooooo0_l000000ooooooo0000ooooo`0Kooooo`;o00001?ooool2o`00
09Oooooo0029ooooo`04o`000?ooooooooooooooo`;o00003Oooool2o`000004ooooool0003o0000
ooooo`?o000000?o<S8bolc<c?ooool01?ooool00ol0003oooooooooo`0Pooooo`;o0000Uoooool0
08Wooooo00Co410@oooooooooooooooo0_l0000=ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000
ooooooooool01oooool2o`000;[ooooo0029ooooo`05ogMgMonHV9So0000o`000?mgMgL02oooool0
1Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool2o`0002Cooooo0_l0
002Dooooo`00ROooool01Oo^k^ko<S8bo`000?l0003ok^k^00_ooooo1Ol00004ooooo`Co00001_oo
ool00ol0003oooooooooo`0Sooooo`;o0000U?ooool009cooooo0_l0000>ooooo`03o`000?oooooo
oooo02Gooooo0_l0002Booooo`00W?ooool2o`0000kooooo00?o0000ooooooooool08?ooool2o`00
00?ooooo0_l0002Booooo`00[?ooool00ol0003oooooooooo`0Pooooo`;o0000Uoooool009Sooooo
0ol0000Aooooo`?o000000?oooooo`000?l00000]_ooool009Sooooo0ol0000Aooooo`04o`000?oo
ooooooooooooo`;o0000]_ooool00:cooooo00Co0000oooooooooooooooo0_l0002fooooo`00ROoo
ool2o`00027ooooo00Co0000oooooooooooooooo0_l0002fooooo`00ROooool2o`00027ooooo00?o
0000ooooooooool08oooool2o`0009Cooooo002/ooooo`03o`000?oooooooooo02?ooooo0_l00002
ooooo`;o0000T?ooool00:cooooo00?o0000ooooooooool09oooool2o`00093ooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`?o0000;?ooool2o`0008_ooooo002/ooooo`03o`000?oo
oooooooo02cooooo0_l0002;ooooo`00R_ooool2o`00023ooooo00?o0000ooooooooool0:_ooool4
o`0008_ooooo002:ooooo`;o00008?ooool00ol0003oooooooooo`0Zooooo`Co0000Roooool00:co
oooo00?o0000ooooooooool02Oooool2o`000:kooooo002Dooooo`;o00005_ooool00ol0003ooooo
ooooo`09ooooo`;o0000[_ooool009Cooooo0_l0000Fooooo`03o`000?oooooooooo0;Wooooo002R
ooooo`;o00000oooool2o`0000?ooooo00?o0000ooooooooool0<Oooool2o`0008Kooooo002Roooo
o`;o00000oooool2o`0000?ooooo0ol0000aooooo`;o0000Q_ooool00:Oooooo0_l00003ooooo`03
o`000?oooooooooo00gooooo0_l0002Zooooo`00XOooool2o`0000Cooooo0_l00003ooooo`03o`00
0?oooooooooo00gooooo0_l000000ooooooo0000o`00000Oooooo`?o0000QOooool00:7ooooo0_l0
0004ooooo`;o00000oooool00ol0003oooooooooo`0@ooooo`;o00007oooool3o`0008Gooooo002/
ooooo`03o`000?oooooooooo0;Wooooo002Booooo`;o00002Oooool2o`0000gooooo00?o0000oooo
ooooool0^Oooool008Kooooo0_l0000:ooooo`;o00002?ooool3o`0000gooooo00?o0000oooooooo
ool04?ooool2o`000:Oooooo0026ooooo`;o00005?ooool2o`0000kooooo00?o0000ooooooooool0
3oooool3o`000003ooooool0003o000001gooooo0_l00002ooooo`;o0000POooool008Oooooo0_l0
000Cooooo`;o00003_ooool3o`0000oooooo0_l00002ooooo`;o00007Oooool2o`0000;ooooo0_l0
0021ooooo`00Qoooool2o`0000Sooooo0_l00008ooooo`;o00003oooool00ol0003oooooooooo`2i
ooooo`00TOooool2o`0000Sooooo0_l0000?ooooo`03o`000?oooooooooo0;Wooooo002Jooooo`;o
00004?ooool01?l0003oooooooooooooool2o`000;Kooooo002Jooooo`;o00004?ooool01?l0003o
ooooooooooooool2o`000;Kooooo002?ooooo`;o00002Oooool2o`00013ooooo00?o0000oooooooo
ool0^Oooool008oooooo0_l000001Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo0_l000000olQ8B7o
ooooooooo`03ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`02o`00
01?ooooo0_l0002Rooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo0_l000000ooo
oooo8B4Qob4Q8@08ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool00_l0000Coooo
o`;o0000X_ooool008Wooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41000_ooool2o`00
00cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Gooooo`;o0000X?ooool0097o
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Goooo
o`;o0000X?ooool0097ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01Oooool00ol0003oooooooooo`2iooooo`00TOooool01Ol@413ooooooooooooooooo
410@00cooooo0ol00007ooooo`03o`000?oooooooooo03cooooo0_l0001kooooo`00TOooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo0ol00007ooooo`03o`000?oooooooooo03cooooo0_l0001k
ooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1_l000000ooooooo0000o`000002
ooooo`03o`000?oooooooooo01Wooooo0_l000000ooooooo0000o`00002Kooooo`00QOooool2o`00
01[ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool00ol0003oooooooooo`0Ioooo
o`;o000000Coooooo`000?l0003o00007Oooool3o`0007[ooooo0025ooooo`;o00006_ooool2o`00
00Wooooo00?o0000ooooooooool07Oooool2o`0001gooooo0ol0001jooooo`00XOooool2o`0000Wo
oooo00?o0000ooooooooool06Oooool2o`0009kooooo0024ooooo`;o00009_ooool3o`0000Oooooo
0_l0000@ooooo`;o00008Oooool3o`0007[ooooo0024ooooo`;o00003_ooool2o`0001Gooooo0_l0
0009ooooo`;o0000<oooool3o`0007[ooooo0023ooooo`?o00003_ooool2o`0001Gooooo0ol00008
ooooo`;o0000/?ooool008?ooooo0_l00007ooooo`;o00007_ooool2o`0000Sooooo0_l000000ooo
oooo0000o`00002]ooooo`00S?ooool2o`0000kooooo0_l0000>ooooo`03o`000?oooooooooo00[o
oooo0_l0002]ooooo`00S?ooool2o`0000kooooo0_l0000>ooooo`;o00007_ooool2o`0009[ooooo
002/ooooo`;o00007_ooool2o`0009[ooooo002/ooooo`03o`000?oooooooooo00[ooooo0_l0000B
ooooo`?o0000V?ooool00:cooooo0ol0000:ooooo`;o00004_ooool5o`0009Kooooo0023ooooo`;o
00003oooool2o`0001Kooooo00?o0000ooooooooool08Oooool2o`0009Kooooo0023ooooo`;o0000
3oooool2o`0001Kooooo00?o0000ooooooooool02_ooool2o`000:gooooo002/ooooo`03o`000?oo
oooooooo00[ooooo0_l000000ooooooo0000o`00000Dooooo`;o0000U?ooool00:Cooooo0_l00006
ooooo`03o`000?oooooooooo00gooooo0_l0000Dooooo`;o0000U?ooool009?ooooo0_l0000?oooo
o`;o00001_ooool00ol0003oooooooooo`0Sooooo`;o0000U?ooool009?ooooo0_l0000<ooooo`Co
00000_ooool2o`0000?ooooo00?o0000ooooooooool03oooool2o`000:Sooooo002Booooo`;o0000
3Oooool4o`0000;ooooo0_l00003ooooo`03o`000?oooooooooo00;ooooo0_l0000;ooooo`;o0000
Z?ooool009;ooooo0_l0000Dooooo`;o00000_ooool3o`0000;ooooo0_l0000Oooooo`;o00008ooo
ool2o`0006oooooo002Xooooo`;o00000_ooool00ol0003oooooooooo`0=ooooo`;o00005?ooool2
o`0002?ooooo0_l0001_ooooo`00Poooool2o`0002Gooooo0ol0000?ooooo`;o0000Z_ooool008?o
oooo0_l0000Uooooo`?o00009_ooool2o`0009?ooooo002/ooooo`03o`000?oooooooooo02Cooooo
0_l0002Cooooo`00R_ooool2o`0000Gooooo0_l0000Iooooo`03o`000?oooooooooo0;Wooooo002:
ooooo`;o00001Oooool2o`0000Cooooo0_l0000Cooooo`03o`000?oooooooooo01;ooooo0_l0000C
ooooo`;o0000T?ooool008;ooooo0_l0000Cooooo`;o00000oooool2o`0000kooooo00?o0000oooo
ooooool04_ooool2o`0001?ooooo0ol0000Oooooo`;o0000K_ooool008;ooooo0_l0000Hooooo`;o
00003_ooool00ol0003oooooooooo`0Xooooo`;o00007oooool2o`0006kooooo002/ooooo`?o0000
4oooool2o`0003?ooooo0_l0001_ooooo`00[?ooool00ol0003oooooooooo`05ooooo`?o00002ooo
ool2o`0001Cooooo0_l0000Mooooo`;o0000Koooool0093ooooo0_l0000Jooooo`03o`000?oooooo
oooo00Gooooo0ol0000Mooooo`Ko00007_ooool2o`0006kooooo002@ooooo`;o00006_ooool3o`00
02Gooooo1?l0000Pooooo`;o0000K_ooool008;ooooo0_l0000Booooo`;o00005?ooool3o`0002So
oooo0_l0002?ooooo`00P_ooool2o`0000Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q00Coooooo`000?l0003ooooo1Ol00004ooooo`03odA4A?l0003o000000;o00001Oooool00ol0
003oooooooooo`0Vooooo`Ko0000SOooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo0_l00005ooooo`03o`000?oooooo
oooo01?ooooo0_l0000Aooooo`?o000000?oooooo`000?l00000SOooool0087ooooo1_l00002oooo
o`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooo
oooo00?ooooo00Co0000ooooool0003o00004_ooool4o`00013ooooo0ol000000ooooooo0000o`00
002<ooooo`00ROooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00omgMgOo<S8booooo`04ooooo`Co00001_ooool2o`0000_ooooo0ol0000Aooooo`;o000000?o
ooooo`000?l00000S?ooool008Wooooo0_l00002ooooo`03o`000?oooooooooo00cooooo00?oMgMg
ofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool01ooo
ool3o`000:oooooo0029ooooo`;o00000_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`;o0000[oooool0
08Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01?ooooo0_l000000ooooooo0000o`00
002Qooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo0_l00007ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool04oooool2o`000003oooo
ool0003o000003Sooooo0_l0001Wooooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool0;?oo
ool2o`0002;ooooo0_l0001Wooooo`00P?ooool3o`0000cooooo0_l0000Kooooo`03o`000?oooooo
oooo00Sooooo0_l0000<ooooo`;o00005?ooool2o`0008_ooooo0020ooooo`?o00003?ooool2o`00
01_ooooo00?o0000ooooooooool02?ooool2o`0000cooooo0_l0002Qooooo`00[?ooool3o`000;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo0021ooooo`;o0000:Oooool00ol0003ooooooooo
o`2iooooo`00POooool2o`0000Kooooo0_l0000Qooooo`03o`000?oooooooooo01Sooooo0_l0002O
ooooo`00ROooool2o`0000gooooo0_l0000Booooo`03o`000?oooooooooo00;ooooo0_l0000Doooo
o`;o0000Woooool008oooooo0_l00007ooooo`;o00004_ooool00ol0003oooooooooo`02ooooo`;o
00005?ooool2o`0009oooooo002?ooooo`;o00006oooool00ol0003oooooooooo`0Hooooo`;o0000
=oooool2o`0006Kooooo002/ooooo`03o`000?oooooooooo057ooooo0_l0001Vooooo`00POooool2
o`0002Wooooo0ol0002iooooo`00POooool2o`0002Wooooo00?o0000ooooooooool06_ooool2o`00
03Gooooo0_l0001Vooooo`00[?ooool00ol0003oooooooooo`0Jooooo`;o00004?ooool2o`0002?o
oooo0_l0001Vooooo`00W?ooool2o`0000kooooo00?o0000ooooooooool03?ooool3o`0001gooooo
0_l0002;ooooo`00P?ooool2o`0000Oooooo0_l0000Aooooo`;o00003_ooool00ol0003ooooooooo
o`0<ooooo`?o00007oooool2o`0002;ooooo0_l0001Uooooo`00P?ooool2o`0000Oooooo0_l0000Q
ooooo`03o`000?oooooooooo00Cooooo0_l0000Xooooo`;o00008_ooool2o`0006Gooooo002/oooo
o`03o`000?oooooooooo00Cooooo0_l0001=ooooo`;o0000I?ooool00:cooooo00?o0000oooooooo
ool0;_ooool2o`0002?ooooo1?l0001Rooooo`00[?ooool00ol0003oooooooooo`0^ooooo`;o0000
9?ooool3o`0006;ooooo0029ooooo`;o00008Oooool3o`0001Wooooo0_l0000Cooooo`;o00009?oo
ool2o`0006?ooooo0029ooooo`;o00001?ooool2o`0001_ooooo00?o0000ooooooooool06Oooool2
o`0001?ooooo0_l00029ooooo`00Soooool2o`0001_ooooo00?o0000ooooooooool06Oooool3o`00
09gooooo0009ooooo`Co000000?o410@ooooooooool05_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0?
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8b
omgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05
odA4A?l0003o0000oc8b<_oMgMd05_ooool00ol0003oooooooooo`0Hooooo`05onk^k_l0003o0000
o`000?o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd03ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oM
gMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo
00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`Co000000?o410@ooooooooool04_ooool0
00_ooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46
ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_oo
ool05Oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8b
ooooo`0Iooooo`03o`000?oooooooooo01Cooooo0006o`0000Gooooo00?o0000ooooooooool04?oo
ool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo
00?o0000ooooooooool01Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03
o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onH
V9So8B4Qonk^kP09ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool06?ooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`0=
ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0=ooooo`05oa0@4?oo
ooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooo
oooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`0>ooooo`05o`00
0?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0>ooooo`05o`000?oooooooooooooo
ool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo01Gooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`02o`0000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omg
MgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0>
ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb
<S;ooooo01Wooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`03oooool01Ol0003ooooooooooooooooo000000_ooooo0_l000000oooooooMgMgofIVIP04
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05_ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo00;o00003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
3oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?oooo
o`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`06_ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0H
ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oo
oooooooo017ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo017ooooo
00Go410@oooooooooooooooooa0@400;ooooo`?o000000?oooooo`000?ooool00oooool00ol0003o
ooooooooo`0Hooooo`?o00006?ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgoooo
o`03ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000
ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooo
oc8b<P04ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`;o00001Oooool3o`00
0003oiRHV?l@413ooooo00?ooooo00?o0000ooooooooool06?ooool01?l0003oooooo`000?l0000G
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo
1?l0000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Dooooo`002Oooool00omEEEGoIVIVo`00000Joooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000@ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`;o0000
1Oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0000Gooooo`04o`000?oooooo0000o`00
00gooooo0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<00Cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00013ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0001Wooooo00?oEEEEofIVI_l0
00005_ooool00:cooooo00?o0000ooooooooool03_ooool2o`000:Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo0028ooooo`;o00008_ooool00ol0003oooooooooo`0aooooo`;o00008_ooool2
o`0005Oooooo0_l00002ooooo`;o00001Oooool008Sooooo0_l0000=ooooo`;o00004oooool00ol0
003oooooooooo`0aooooo`;o00008_ooool3o`0005Kooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oM
gMd5ooooo`00POooool2o`0001Cooooo0_l0000Cooooo`03o`000?oooooooooo00Kooooo0_l0000W
ooooo`;o00000_ooool2o`00027ooooo0ol0001Fooooo`04omgMgOl0003o410@olc<c0Kooooo0007
oooooooo0000C?l0000<ooooo`04onk^k_lQ8B7o410@onk^kPKooooo0007ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00Co0000oooooooooooooooo0_l00003ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo0ol0
0008ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00[ooooo00Co8B4QogMgMomgMgOo<S8b1_ooool000Oooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02?ooooo0_l0
00000ooooooo0000ooooo`0:ooooo`;o00006oooool00ol0003oooooooooo`0Looooo`;o00002Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`09ooooo`;o00000_ooool2o`0000Gooooo0020ooooo`;o0000:_ooool0
0ol0003oooooooooo`2iooooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool0^Oooool008Wo
oooo0_l0000<ooooo`;o00004oooool00ol0003oooooooooo`0=ooooo`;o00008?ooool2o`0008So
oooo0029ooooo`;o00008Oooool00ol0003oooooooooo`0=ooooo`;o00003?ooool2o`0001;ooooo
0_l00003ooooo`;o0000Poooool00:cooooo00Co0000ooooool0003o00001Oooool2o`0001?ooooo
0_l0000Gooooo`;o00008Oooool2o`00063ooooo002/ooooo`Co00001Oooool2o`0000Gooooo0_l0
000Vooooo`;o00008?ooool2o`00063ooooo0028ooooo`;o00008_ooool00ol0003oooooooooo`0=
ooooo`;o00009_ooool2o`0008;ooooo0028ooooo`;o00008_ooool00ol0003oooooooooo`0aoooo
o`;o000000?oooooo`000?l00000Poooool008Wooooo0_l0000Qooooo`03o`000?oooooooooo01[o
oooo0_l0000Eooooo`;o000000?oooooo`000?l00000Poooool008Wooooo0_l0000Qooooo`03o`00
0?oooooooooo01[ooooo0_l0000Dooooo`;o0000Qoooool008kooooo0_l0000Looooo`04o`000?oo
oooo0000o`0001Wooooo1?l0000Booooo`;o000000?oooooo`000?l00000Q?ooool0087ooooo0_l0
000;ooooo`?o00006oooool01?l0003oooooo`000?l0000Kooooo`?o00005?ooool2o`0008Cooooo
0021ooooo`;o00003?ooool2o`0001_ooooo00?o0000ooooooooool01Oooool2o`0001Kooooo0_l0
002Jooooo`00[?ooool00ol0003oooooooooo`05ooooo`;o0000;Oooool2o`0008?ooooo002/oooo
o`?o0000=?ooool2o`00023ooooo0_l0001Qooooo`00[?ooool00ol0003oooooooooo`1Fooooo`;o
0000HOooool00:cooooo00?o0000ooooooooool01?ooool2o`0002kooooo0_l00023ooooo`00Tooo
ool2o`0001Oooooo00?o0000ooooooooool01?ooool2o`0001Cooooo0_l0000Hooooo`;o0000Pooo
ool008Wooooo0_l00008ooooo`;o00005oooool00ol0003oooooooooo`0Jooooo`;o00004oooool2
o`0008Sooooo0029ooooo`;o00008Oooool00ol0003oooooooooo`0Jooooo`;o00004oooool2o`00
08Sooooo002/ooooo`03o`000?oooooooooo00cooooo0_l0000<ooooo`;o00004oooool2o`0008So
oooo002>ooooo`?o00006oooool00ol0003oooooooooo`0<ooooo`;o00008Oooool2o`0008Sooooo
002>ooooo`?o00000oooool2o`0001Kooooo0ol0002iooooo`00U?ooool2o`0001Kooooo00?o0000
ooooooooool0<?ooool2o`0008Oooooo002Hooooo`;o00004_ooool00ol0003oooooooooo`0Ioooo
o`;o00005Oooool2o`0008Oooooo002Dooooo`;o00000_ooool2o`0001;ooooo00?o0000oooooooo
ool06Oooool2o`0009kooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`0=ooooo`;o0000
2oooool2o`0009gooooo002/ooooo`03o`000?oooooooooo00gooooo0_l0000;ooooo`?o0000W?oo
ool00:cooooo00?o0000ooooooooool06oooool2o`0001Cooooo0_l0000Tooooo`;o0000H?ooool0
0:cooooo00?o0000ooooooooool02oooool4o`0000_ooooo0_l0000Eooooo`;o00009?ooool2o`00
063ooooo002/ooooo`?o00002oooool4o`0000_ooooo0_l0000Fooooo`;o0000QOooool00:cooooo
00?o0000ooooooooool0<Oooool3o`00027ooooo0ol0001Qooooo`00[?ooool00ol0003ooooooooo
o`0Kooooo`;o00005?ooool2o`0002;ooooo0ol0001Qooooo`00[?ooool00ol0003oooooooooo`0K
ooooo`;o0000W?ooool008;ooooo0_l0000Xooooo`03o`000?oooooooooo01_ooooo0_l0000Doooo
o`;o0000Q_ooool008;ooooo0_l0000Xooooo`04o`000?ooooooooooooooo`;o0000;_ooool2o`00
08Kooooo0022ooooo`;o00001Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00Co0000oooooooooooooooo0ol0
002eooooo`00P_ooool2o`0000Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`02ooooo`;o0000;?ooool2o`0008Oooooo0029ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol000001?oooooo0000
o`000?l0000Yooooo`;o000000?oooooo`000?l00000Qoooool008Wooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool01?l0003o
ooooooooooooool2o`0002[ooooo0_l0002:ooooo`00ROooool01Ol0003ooooooooooooooooo0000
00?ooooo0_l00009ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005
ooooo`03o`000?oooooooooo01Sooooo0_l0000jooooo`;o0000Hoooool008Wooooo00Go410@oooo
oooooooooooooa0@4003ooooo`;o00002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02oooool2o`0000_ooooo0_l0000Gooooo`;o00008Oooool2
o`0006?ooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool2o`0000Kooooo00Go0000
okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02ooo
ool2o`0002Cooooo0_l0000Qooooo`;o0000Hoooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool0
2?ooool3o`0004Wooooo0_l0001Sooooo`00[?ooool00ol0003oooooooooo`08ooooo`?o0000[_oo
ool009Oooooo0_l00004ooooo`;o00002Oooool2o`0000;ooooo00?o0000ooooooooool0^Oooool0
08;ooooo0_l0000Cooooo`;o00001?ooool2o`0000Wooooo0_l00002ooooo`03o`000?oooooooooo
0;Wooooo0022ooooo`;o00003Oooool2o`0001Wooooo0ol0002iooooo`00TOooool2o`0001Wooooo
00?o0000ooooooooool05Oooool2o`000:;ooooo0022ooooo`;o0000:?ooool00ol0003ooooooooo
o`0Eooooo`;o0000X_ooool008;ooooo0_l0000Xooooo`03o`000?oooooooooo02kooooo0_l00029
ooooo`00[?ooool3o`0000Kooooo0_l0000Vooooo`;o0000ROooool00:cooooo0ol00006ooooo`;o
0000/Oooool00:cooooo0ol0000Cooooo`;o0000Y?ooool00:_ooooo0_l0000Eooooo`Co00005Ooo
ool2o`0008_ooooo002[ooooo`Co00004oooool4o`0001;ooooo0_l000000ooooooo0000o`00002;
ooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o00008oooool2o`000003ooooool0003o0000
08_ooooo002=ooooo`;o00007Oooool00ol0003oooooooooo`04ooooo`;o00009_ooool2o`0008_o
oooo002=ooooo`;o00006oooool3o`0001?ooooo0_l0000Hooooo`;o0000S?ooool009cooooo0_l0
000<ooooo`?o00004oooool2o`000003ooooool0003o000001Gooooo0_l0002<ooooo`00W?ooool2
o`0000kooooo00?o0000ooooooooool05?ooool2o`000:?ooooo002Looooo`;o00003_ooool00ol0
003oooooooooo`05ooooo`;o0000/_ooool008Gooooo0_l0000Eooooo`;o00003_ooool00ol0003o
ooooooooo`05ooooo`;o00009?ooool2o`0008cooooo0025ooooo`;o00009Oooool3o`0000Cooooo
0_l0000Uooooo`;o0000S?ooool00:cooooo00?o0000ooooooooool01?ooool2o`0002Cooooo0ol0
002<ooooo`00SOooool2o`0001Sooooo0_l00003ooooo`03o`000?oooooooooo02Kooooo0_l00002
ooooo`?o0000S?ooool008gooooo0_l0000Hooooo`;o00000oooool00ol0003oooooooooo`0Voooo
o`;o0000TOooool009Kooooo0_l0000<ooooo`;o00001_ooool01?l0003oooooooooooooool2o`00
00gooooo0_l0002Wooooo`00U_ooool3o`0000[ooooo0ol00006ooooo`04o`000?oooooooooooooo
o`;o00003Oooool2o`000:Oooooo002Gooooo`;o00002_ooool3o`0000Kooooo00?o0000oooooooo
ool0^Oooool00:Cooooo0_l00006ooooo`04o`000?oooooo0000o`000;Sooooo002/ooooo`Co0000
^?ooool00:cooooo00?o0000ooooooooool00_l0000Qooooo`;o0000U?ooool008Gooooo0_l0000U
ooooo`03o`000?oooooooooo00;o00002_ooool2o`0001Gooooo0_l0002Dooooo`00QOooool2o`00
02Gooooo00?o0000ooooooooool03?ooool4o`0001Sooooo0_l0002?ooooo`00Q_ooool2o`0002Co
oooo00?o0000ooooooooool03_ooool2o`0001Sooooo0_l0000Qooooo`;o0000K?ooool008Kooooo
0_l0000Tooooo`03o`000?oooooooooo02;ooooo0_l0000Wooooo`;o0000K?ooool0097ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Go
oooo00?o0000ooooooooool08_ooool2o`0009Gooooo002Aooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2iooooo`00
TOooool01Ol@413ooooooooooooooooo410@00?ooooo0_l0000;ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02_ooool2o`0001Gooooo0_l0002Fooooo`00T?ooool2o`0000?ooooo
00Co0000oooooooooooooooo0ol00009ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000:ooooo`;o
00005Oooool2o`0002Oooooo0_l0001]ooooo`00T?ooool3o`0000;ooooo00?o0000ooooooooool0
0_ooool2o`0000Kooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo04[o
oooo0_l0001]ooooo`00TOooool2o`0000;ooooo00?o410@ooooooooool01?ooool2o`0000Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`;o0000[oooool0097ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`;o00001?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Sooooo0_l0002_ooooo`00TOooool01Oo^k^ko0000o`000?lb<S;ok^k^00cooooo
1?l00006ooooo`03o`000?oooooooooo0;Wooooo002Booooo`;o00002_ooool2o`0000Kooooo0_l0
0004ooooo`03o`000?oooooooooo00Kooooo0_l0002aooooo`00W_ooool2o`0000Kooooo0ol00003
ooooo`03o`000?oooooooooo00Kooooo1?l0000Iooooo`;o0000U?ooool009kooooo0_l00002oooo
o`?o00000_ooool2o`0000?ooooo00?o0000ooooooooool02?ooool3o`0001?ooooo0_l00003oooo
o`;o0000U?ooool009kooooo0_l00002ooooo`?o00001oooool3o`0000Wooooo0_l0000Cooooo`;o
000000Coooooo`000?l0003o00008_ooool2o`00077ooooo0029ooooo`;o00006?ooool2o`0000Oo
oooo00?o0000ooooooooool08Oooool3o`0002;ooooo0_l0001aooooo`00ROooool2o`0000Sooooo
0_l0000>ooooo`;o00001oooool00ol0003oooooooooo`0Kooooo`;o0000W?ooool009?ooooo0_l0
000Gooooo`03o`000?oooooooooo01_ooooo0_l00004ooooo`;o0000U_ooool008Sooooo0_l0000R
ooooo`03o`000?oooooooooo00Gooooo0_l0000Cooooo`;o00001Oooool2o`00027ooooo0_l0001c
ooooo`00R?ooool2o`0000_ooooo0_l0000Eooooo`03o`000?oooooooooo00Cooooo0ol0000Coooo
o`?o00009oooool2o`0007?ooooo002Eooooo`;o00005Oooool00ol0003oooooooooo`04ooooo`?o
00005?ooool2o`0009cooooo002/ooooo`03o`000?oooooooooo00Gooooo0_l0002booooo`00U_oo
ool2o`0001Cooooo0ol00005ooooo`;o0000/_ooool009Cooooo1?l0000Dooooo`03o`000?oooooo
oooo0;Wooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`0Hooooo`;o000000?oooooo`00
0?l00000W?ooool00:cooooo00?o0000ooooooooool06?ooool5o`0009cooooo002/ooooo`03o`00
0?oooooooooo01Oooooo1Ol0002Mooooo`00[?ooool00ol0003oooooooooo`0Gooooo`;o0000X?oo
ool008_ooooo0_l0000Oooooo`03o`000?oooooooooo0;Wooooo002;ooooo`;o00007oooool00ol0
003oooooooooo`0Hooooo`;o0000Woooool00:cooooo0ol0000Hooooo`Co0000WOooool009Sooooo
0_l000000ooooooo0000o`00000?ooooo`04o`000?oooooo0000o`0001Kooooo0_l000000ooooooo
0000o`00000Qooooo`;o0000N_ooool009Sooooo0_l000000ooooooo0000o`00000?ooooo`Co0000
4oooool2o`000004ooooool0003o0000o`0002?ooooo0_l0001jooooo`00V?ooool3o`00017ooooo
0ol0000Dooooo`;o00000_ooool2o`0009oooooo002Iooooo`Co00003oooool00ol0003ooooooooo
o`2iooooo`00SOooool2o`0000cooooo0_l0000?ooooo`03o`000?oooooooooo0;Wooooo002=oooo
o`;o00007Oooool00ol0003oooooooooo`2iooooo`00SOooool2o`0001gooooo00?o0000oooooooo
ool05?ooool2o`000:?ooooo002=ooooo`;o00007Oooool00ol0003oooooooooo`0Dooooo`;o0000
Xoooool00:Oooooo0_l00003ooooo`?o0000^Oooool00:Oooooo0_l00003ooooo`03o`000?oooooo
oooo03Sooooo0_l0001oooooo`00[?ooool00ol0003oooooooooo`0>ooooo`;o00000_ooool2o`00
02Cooooo0_l0001oooooo`00Y?ooool3o`0000Gooooo00?o0000ooooooooool03_ooool2o`0000;o
oooo0_l0002Uooooo`00Xoooool4o`0000Gooooo00?o0000ooooooooool0^Oooool008Wooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0?ooooo`;o0000Z?ooool008Wooooo
00KoMgMgoiRHV?ooooooV9RHogMgMoooool2o`0000;ooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo
00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0?ooooo`;o0000Z?ooool008Wo
oooo00Ko410@oooooooooooooooooa0@4?ooool2o`0000[ooooo00?oZJVYoeEEEOooool02?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo0_l0002[ooooo`00ROooool01Ol0
003ooooooooooooooooo000000;ooooo0_l0000:ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMg
oc8b<_ooool01?ooool3o`0000[ooooo1Ol0002Zooooo`00ROooool01Ol0003ooooooooooooooooo
000000;ooooo0_l0000:ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo0000o`00002Zooooo`00ROooool0
1Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00gooooo0_l0002Zooooo`00ROooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool03Oooool2o`000:[ooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool3o`0000Gooooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`0<ooooo`;o0000
Zoooool0097ooooo0ol0000Hooooo`03o`000?oooooooooo00cooooo0_l0002[ooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00TOooool2o`0001Wooooo00?o0000ooooooooool0^Oooool0097o
oooo0_l0000Iooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool01oooool2o`000;3ooooo
002/ooooo`03o`000?oooooooooo00Oooooo0_l0002`ooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`06ooooo`;o0000/Oooool00:cooooo00?o0000oooooooo
ool01_ooool2o`000;7ooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`2iooooo`00U?oo
ool2o`0001Kooooo00?o0000ooooooooool0^Oooool00:cooooo1Ol0002gooooo`00V?ooool2o`00
01;ooooo00?o0000ooooooooool00_l0002gooooo`00V?ooool2o`0001;ooooo00?o0000oooooooo
ool00_l0002gooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00Uoooool2o`00017ooooo0ol0002kooooo`00Uoooool2o`00017ooooo1Ol0002ioooo
o`00Y_ooool2o`0000Cooooo0ol0002iooooo`00XOooool2o`0000?ooooo0_l00004ooooo`03o`00
0?oooooooooo0;Wooooo002Qooooo`;o00002Oooool3o`000;Wooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002Rooooo`;o00000_ooool2o`0000Cooooo00?o0000ooooooooool0^Oooool00:;o
oooo0ol000000ooooooo0000o`000004ooooo`03o`000?oooooooooo0;Wooooo002Nooooo`;o0000
0oooool4o`0000Gooooo00?o0000ooooooooool0^Oooool009kooooo0_l00005ooooo`;o00001Ooo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Rooooo`Co0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`2iooooo`00Y?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`03o`000?oooooooooo00Gooooo0ol0002i
ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00
Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00X_ooool0
0omEEEGoIVIVo`000033ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00Z_ooool01?l@413o0000o`000?l0002jooooo`00Zoooool00ol0003oooooooooo`2j
ooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool01_l0003oMgMgo`000?l0003oEEEE
onk^k[Oooooo002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoEEEE]oooool00:_ooooo00?o0000
onk^k_ooool00_ooool00ol0003oooooooooo`2eooooo`00Zoooool00ol0003ok^k^ooooo`02oooo
o`03o`000?oooooooooo0;Gooooo002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoIVIV]oooool0
0:[ooooo00?o410@o`000?mgMgL00_l000000omVIVKok^k^ooooo`2fooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.48461 .10449 Mdot
.56113 .19144 Mdot
.44457 .50231 Mdot
.52068 .32458 Mdot
.46259 .18781 Mdot
.38908 .50713 Mdot
.46343 .6656 Mdot
.41134 .90172 Mdot
.43362 .93494 Mdot
.54742 .63119 Mdot
.49718 .7673 Mdot
.3658 .56087 Mdot
.63687 .31895 Mdot
.54167 .66558 Mdot
.39006 .19548 Mdot
.55383 .43993 Mdot
.55554 .73872 Mdot
.63968 .32469 Mdot
.40951 .58066 Mdot
.68335 .58417 Mdot
.6553 .3925 Mdot
.61497 .29165 Mdot
.6398 .36822 Mdot
.65012 .35739 Mdot
.42968 .04936 Mdot
.57593 .34248 Mdot
.44175 .74466 Mdot
.40797 .5111 Mdot
.6738 .63052 Mdot
.58483 .23567 Mdot
.66482 .4756 Mdot
.46274 .97201 Mdot
.3973 .83857 Mdot
.48682 .85408 Mdot
.47224 .86943 Mdot
.6621 .62916 Mdot
.58507 .83761 Mdot
.41251 .59274 Mdot
.63837 .72311 Mdot
.36754 .62264 Mdot
.39113 .17176 Mdot
.4864 .86123 Mdot
.40572 .71221 Mdot
.46196 .10052 Mdot
.42659 .16585 Mdot
.51986 .22807 Mdot
.51608 .72249 Mdot
.53125 .92411 Mdot
.60706 .489 Mdot
.65667 .6731 Mdot
.52205 .93313 Mdot
.64245 .72795 Mdot
.77703 .43013 Mdot
.41717 .76558 Mdot
.44356 .84835 Mdot
.40931 .87731 Mdot
.39441 .83443 Mdot
.56995 .7092 Mdot
.55976 .88209 Mdot
.41621 .20263 Mdot
.54057 .26932 Mdot
.55386 .05702 Mdot
.62391 .75108 Mdot
.42535 .58805 Mdot
.36991 .5925 Mdot
.44717 .96144 Mdot
.54449 .63762 Mdot
.55353 .46315 Mdot
.42106 .67406 Mdot
.66059 .39953 Mdot
.58659 .67889 Mdot
.43365 .52892 Mdot
.53304 .67495 Mdot
.55606 .5764 Mdot
.62367 .75144 Mdot
.4785 .35429 Mdot
.77714 .43108 Mdot
.5795 .38322 Mdot
.65246 .70249 Mdot
.59578 .56686 Mdot
.66913 .54756 Mdot
.5878 .24399 Mdot
.51578 .31612 Mdot
.4905 .86004 Mdot
.43252 .94944 Mdot
.54911 .39556 Mdot
.46799 .18351 Mdot
.52543 .25019 Mdot
.58902 .65676 Mdot
.5544 .47908 Mdot
.44533 .02468 Mdot
.72348 .29172 Mdot
.42209 .43355 Mdot
.50989 .21435 Mdot
.42181 .45249 Mdot
.70329 .24777 Mdot
.54281 .66069 Mdot
.48062 .9677 Mdot
.77951 .43743 Mdot
.59933 .62819 Mdot
.51185 .13275 Mdot
.60333 .5972 Mdot
.36611 .44905 Mdot
.49076 .10177 Mdot
.67178 .47137 Mdot
.47844 .85916 Mdot
.56707 .72643 Mdot
.40643 .51271 Mdot
.42205 .43306 Mdot
.66338 .41969 Mdot
.54898 .63548 Mdot
.50432 .28124 Mdot
.45917 .96882 Mdot
.67908 .57525 Mdot
.79108 .57472 Mdot
.52585 .42155 Mdot
.56046 .31699 Mdot
.47461 .98358 Mdot
.47761 .98041 Mdot
.55702 .87145 Mdot
.64006 .33078 Mdot
.50427 .00607 Mdot
.65475 .42351 Mdot
.67715 .62309 Mdot
.66255 .41088 Mdot
.53485 .36961 Mdot
.67334 .60776 Mdot
.6839 .21709 Mdot
.57572 .23127 Mdot
.52299 .60093 Mdot
.63091 .33159 Mdot
.54046 .17228 Mdot
.36781 .38455 Mdot
.38987 .57098 Mdot
.39622 .63827 Mdot
.66889 .65852 Mdot
.62857 .77066 Mdot
.67126 .62862 Mdot
.53218 .67597 Mdot
.37369 .67347 Mdot
.38454 .22584 Mdot
.63505 .15912 Mdot
.45375 .26771 Mdot
.4182 .66123 Mdot
.55827 .73371 Mdot
.68256 .57435 Mdot
.4485 .97155 Mdot
.78665 .62853 Mdot
.43519 .25681 Mdot
.53088 .25871 Mdot
.44106 .01053 Mdot
.60737 .5725 Mdot
.45624 .78319 Mdot
.64878 .34895 Mdot
.43688 .57459 Mdot
.4193 .20606 Mdot
.62084 .77733 Mdot
.63202 .74023 Mdot
.45358 .97203 Mdot
.57357 .85261 Mdot
.62293 .77534 Mdot
.59454 .40475 Mdot
.66001 .68641 Mdot
.36292 .45326 Mdot
.66299 .61066 Mdot
.39388 .58185 Mdot
.52599 .15623 Mdot
.44681 .96833 Mdot
.6743 .47935 Mdot
.42311 .68426 Mdot
.64216 .74169 Mdot
.65157 .67566 Mdot
.45703 .27191 Mdot
.42376 .68131 Mdot
.49396 .19641 Mdot
.43165 .26459 Mdot
.37808 .71269 Mdot
.6987 .2412 Mdot
.41923 .20768 Mdot
.52918 .47414 Mdot
.66137 .66752 Mdot
.65369 .71315 Mdot
.36402 .47312 Mdot
.56116 .49872 Mdot
.39583 .14793 Mdot
.5014 .6859 Mdot
.42256 .90753 Mdot
.68853 .22838 Mdot
.49946 .96488 Mdot
.36321 .45437 Mdot
.40574 .71731 Mdot
.68372 .569 Mdot
.43307 .64015 Mdot
.55833 .06602 Mdot
.41795 .91785 Mdot
.39711 .13489 Mdot
.36617 .43268 Mdot
.50642 .21052 Mdot
.73263 .29812 Mdot
.55895 .75075 Mdot
.52088 .41592 Mdot
.52252 .42436 Mdot
.43293 .49259 Mdot
.47985 .18717 Mdot
.74257 .3208 Mdot
.53779 .17114 Mdot
.45378 .70536 Mdot
.39182 .40004 Mdot
.48295 .24593 Mdot
.50346 .68837 Mdot
.50409 .75697 Mdot
.6175 .27883 Mdot
.57515 .36607 Mdot
.67439 .48358 Mdot
.5587 .51108 Mdot
.53381 .16756 Mdot
.572 .35985 Mdot
.36471 .40127 Mdot
.51554 .64814 Mdot
.43725 .14668 Mdot
.3767 .72865 Mdot
.55503 .30275 Mdot
.52198 .92606 Mdot
.67281 .45919 Mdot
.66548 .581 Mdot
.55582 .51963 Mdot
.44073 .22783 Mdot
.5306 .14425 Mdot
.4411 .30987 Mdot
.38954 .19768 Mdot
.54349 .38749 Mdot
.51094 .56019 Mdot
.75075 .35296 Mdot
.599 .59016 Mdot
.46327 .78372 Mdot
.50168 .00564 Mdot
.41898 .65332 Mdot
.50047 .11038 Mdot
.64856 .37964 Mdot
.53045 .15772 Mdot
.56237 .06778 Mdot
.39843 .67157 Mdot
.67824 .49683 Mdot
.58666 .67843 Mdot
.48411 .97595 Mdot
.42392 .42811 Mdot
.59992 .80669 Mdot
.56681 .70241 Mdot
.58869 .67226 Mdot
.63052 .74024 Mdot
.39967 .12642 Mdot
.52561 .42202 Mdot
.42617 .5777 Mdot
.58173 .83545 Mdot
.58726 .39132 Mdot
.42453 .68382 Mdot
.45647 .87107 Mdot
.48426 .35788 Mdot
.38694 .78978 Mdot
.54715 .90219 Mdot
.60625 .53461 Mdot
.46487 .78499 Mdot
.66566 .58821 Mdot
.53091 .53671 Mdot
.60264 .5906 Mdot
.48203 .10681 Mdot
.49774 .75985 Mdot
.39329 .40471 Mdot
.65533 .65674 Mdot
.59745 .45503 Mdot
.67024 .60922 Mdot
.44306 .84949 Mdot
.55453 .60456 Mdot
.60122 .54979 Mdot
.62888 .76342 Mdot
.5622 .49318 Mdot
.4097 .38952 Mdot
.50725 .95041 Mdot
.52073 .72354 Mdot
.40299 .28715 Mdot
.66081 .67449 Mdot
.53381 .54418 Mdot
.55324 .57927 Mdot
.56665 .86124 Mdot
.36605 .546 Mdot
.40624 .51404 Mdot
.44573 .62582 Mdot
.48234 .19534 Mdot
.68327 .5319 Mdot
.53175 .25721 Mdot
.66807 .53913 Mdot
.69163 .23551 Mdot
.5479 .89413 Mdot
.37393 .3208 Mdot
.5225 .92285 Mdot
.50021 .62949 Mdot
.58872 .84161 Mdot
.56212 .07475 Mdot
.68286 .50283 Mdot
.38472 .22886 Mdot
.7826 .65451 Mdot
.6038 .51112 Mdot
.43189 .83113 Mdot
.53651 .16419 Mdot
.4743 .97669 Mdot
.40263 .1246 Mdot
.51581 .72574 Mdot
.49712 .95988 Mdot
.58957 .39786 Mdot
.50661 .35906 Mdot
.62346 .29702 Mdot
.55345 .74548 Mdot
.64068 .33808 Mdot
.43464 .02202 Mdot
.53065 .46502 Mdot
.45391 .1191 Mdot
.48191 .85984 Mdot
.36793 .53688 Mdot
.53319 .5143 Mdot
.36566 .4129 Mdot
.51031 .02211 Mdot
.63077 .1449 Mdot
.54321 .39663 Mdot
.3924 .62211 Mdot
.49868 .85266 Mdot
.61466 .77196 Mdot
.42824 .26448 Mdot
.50443 .34417 Mdot
.48227 .66921 Mdot
.56863 .72018 Mdot
.38808 .80539 Mdot
.57171 .84745 Mdot
.42063 .49263 Mdot
.6143 .27912 Mdot
.52473 .59642 Mdot
.43326 .47657 Mdot
.53689 .1531 Mdot
.3908 .57685 Mdot
.39392 .58368 Mdot
.59527 .40998 Mdot
.47717 .18797 Mdot
.76993 .39299 Mdot
.59337 .42883 Mdot
.58868 .25097 Mdot
.42245 .53437 Mdot
.39664 .82994 Mdot
.44539 .75233 Mdot
.67048 .62727 Mdot
.61224 .29724 Mdot
.43024 .35098 Mdot
.56273 .33693 Mdot
.6296 .15074 Mdot
.36889 .63328 Mdot
.60377 .8209 Mdot
.66327 .62995 Mdot
.60345 .47356 Mdot
.54622 .7711 Mdot
.65758 .65836 Mdot
.60145 .5877 Mdot
.3681 .61831 Mdot
.6188 .12399 Mdot
.67878 .50195 Mdot
.36868 .37245 Mdot
.36718 .37975 Mdot
.37667 .25818 Mdot
.43851 .40117 Mdot
.60123 .57005 Mdot
.38991 .19411 Mdot
.3924 .82242 Mdot
.44087 .38388 Mdot
.66885 .5058 Mdot
.59551 .46821 Mdot
.38893 .4586 Mdot
.50494 .12405 Mdot
.46674 .96775 Mdot
.50241 .11347 Mdot
.58045 .84792 Mdot
.58515 .82379 Mdot
.63807 .36493 Mdot
.61769 .7975 Mdot
.63094 .33541 Mdot
.41096 .09904 Mdot
.7923 .58775 Mdot
.53899 .89618 Mdot
.41158 .23506 Mdot
.43524 .54033 Mdot
.47018 .00053 Mdot
.59688 .63106 Mdot
.4858 .66463 Mdot
.36351 .49994 Mdot
.66174 .40433 Mdot
.49711 .32204 Mdot
.55232 .60007 Mdot
.57164 .33825 Mdot
.45184 .77014 Mdot
.52977 .92748 Mdot
.67306 .43209 Mdot
.56416 .07465 Mdot
.36421 .45507 Mdot
.53058 .79157 Mdot
.76806 .40171 Mdot
.53589 .78608 Mdot
.42456 .29449 Mdot
.42297 .29651 Mdot
.51099 .45323 Mdot
.38532 .78621 Mdot
.36598 .5635 Mdot
.4453 .75344 Mdot
.44191 .30268 Mdot
.50484 .7632 Mdot
.5565 .43473 Mdot
.42441 .04585 Mdot
.49191 .18582 Mdot
.6682 .59045 Mdot
.47873 .2507 Mdot
.44722 .7676 Mdot
.53098 .54674 Mdot
.48343 .18182 Mdot
.49525 .84512 Mdot
.46978 .79186 Mdot
.44848 .69393 Mdot
.37636 .70239 Mdot
.46554 .61695 Mdot
.46585 .86861 Mdot
.56605 .72849 Mdot
.45597 .12404 Mdot
.59708 .4859 Mdot
.42665 .69968 Mdot
.45752 .00435 Mdot
.70627 .24618 Mdot
.52475 .1436 Mdot
.79133 .53579 Mdot
.46409 .09729 Mdot
.44896 .69932 Mdot
.40091 .83548 Mdot
.39741 .15635 Mdot
.479 .78383 Mdot
.61772 .31382 Mdot
.77224 .40434 Mdot
.45041 .27893 Mdot
.4863 .30557 Mdot
.44706 .22131 Mdot
.66896 .57185 Mdot
.59922 .52895 Mdot
.7286 .29541 Mdot
.4985 .69659 Mdot
.42763 .8007 Mdot
.50647 .83917 Mdot
.42228 .55587 Mdot
.53079 .48578 Mdot
.56189 .52769 Mdot
.40693 .88658 Mdot
.5321 .46714 Mdot
.66077 .68067 Mdot
.54424 .16711 Mdot
.44315 .13093 Mdot
.67272 .60497 Mdot
.66717 .52691 Mdot
.54647 .7619 Mdot
.66866 .18725 Mdot
.55178 .60521 Mdot
.38677 .79853 Mdot
.39211 .15879 Mdot
.48916 .77091 Mdot
.59549 .83259 Mdot
.59754 .47227 Mdot
.54861 .74739 Mdot
.67248 .61975 Mdot
.50572 .12358 Mdot
.40709 .51113 Mdot
.56199 .33354 Mdot
.49968 .84167 Mdot
.52288 .02023 Mdot
.39179 .55304 Mdot
.46668 .35709 Mdot
.40199 .67942 Mdot
.59807 .55687 Mdot
.43359 .45023 Mdot
.54965 .43833 Mdot
.42424 .79318 Mdot
.40664 .7251 Mdot
.52319 .41716 Mdot
.58519 .38932 Mdot
.44391 .95739 Mdot
.44785 .20638 Mdot
.47382 .10717 Mdot
.43643 .74766 Mdot
.41224 .40279 Mdot
.45312 .33176 Mdot
.79448 .55146 Mdot
.46245 .31367 Mdot
.54938 .17228 Mdot
.49305 .95552 Mdot
.66499 .60625 Mdot
.41727 .64972 Mdot
.66766 .64431 Mdot
.36425 .50475 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00000oooool3o`00
00Oooooo0ol0002iooooo`00W_ooool2o`0000;ooooo0ol00007ooooo`03o`000?oooooooooo0;Wo
oooo002Nooooo`;o00001?ooool00ol0003oooooooooo`05ooooo`?o0000^Oooool009Sooooo0_l0
000:ooooo`03o`000?oooooooooo00Gooooo0ol0002iooooo`00V?ooool2o`0000[ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Fooooo`;o0000
5?ooool00ol0003oooooooooo`02o`0000;ooooo0_l0002cooooo`00U_ooool2o`0000;ooooo0_l0
000@ooooo`Go00000_ooool2o`000;?ooooo002Jooooo`;o00004?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00Toooool2o`0001Oooooo00?o0000ooooooooool0^Oooool009?o
oooo0ol0000Fooooo`03o`000?oooooooooo0;Wooooo002Dooooo`;o00005_ooool3o`000;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00kooooo0_l0002Y
ooooo`00[?ooool00ol0003oooooooooo`0>ooooo`;o0000ZOooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool04?ooool3o`000:Kooooo002/ooooo`03o`000?oo
oooooooo013ooooo0ol0002Vooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`00
017ooooo0ol0002Uooooo`00[?ooool00ol0003oooooooooo`0Aooooo`?o0000YOooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:3ooooo0_l0000:ooooo`03o`000?oooooooooo0;Wooooo002>ooooo`;o00003ooo
ool3o`0000[ooooo0ol0002iooooo`00S_ooool2o`0000oooooo0_l00005ooooo`;o000000Gooooo
o`000?l0003oooooo`00002kooooo`00Xoooool2o`000004ooooool0003o0000ooooo`;o000000?o
ooooo`000?ooool0^_ooool00:?ooooo0_l000000ooooooo0000o`000004ooooo`;o0000^_ooool0
0:cooooo0_l0002jooooo`00[?ooool2o`000;[ooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Kooooo0ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`2iooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46oooo
o`03oeEEEOl0003o000000Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2ioooo
o`00POooool6o`0000;ooooo00Go410@ooooool0003o0000oa0@400=ooooo`04ojVYZOmEEEGo0000
o`0000Oooooo00?o0000ooooooooool00oooool3o`0002Cooooo0_l0002Cooooo`00ROooool5o`00
00kooooo00?o8B4Qo`000?l000001_ooool00omgMgOo<S8booooo`04ooooo`?o00009?ooool2o`00
09?ooooo0029ooooo`?o000000?oooooo`000?ooool02_ooool2o`000003oooooomEEEGoc<c<00Co
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05
oa0@4?l0003o0000ooooool@41002oooool2o`000003oooooonYZJWoMgMg00Cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`02o`000;Oooooo0029ooooo`05ogMgMol0003o0000oiRH
V?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`02o`000;Oooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5
o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
00Gooooo0_l0002booooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool01Oooool4o`0001oo
oooo0_l0002?ooooo`00ROooool2o`0000cooooo0_l0000Cooooo`03o`000?oooooooooo00Oooooo
0_l0000Oooooo`;o0000Soooool008Wooooo0_l0000Qooooo`?o00002Oooool2o`0001cooooo0_l0
002@ooooo`00[?ooool00ol0003oooooooooo`09ooooo`;o00007?ooool2o`00093ooooo0028oooo
o`Co00008?ooool00ol0003oooooooooo`05ooooo`Co00008?ooool2o`0008kooooo0028ooooo`Co
00008?ooool00ol0003oooooooooo`05ooooo`Co00008?ooool2o`0008kooooo002/ooooo`03o`00
0?oooooooooo00Wooooo0_l0002^ooooo`00Toooool2o`0001Oooooo00?o0000ooooooooool02?oo
ool5o`000:cooooo002Cooooo`;o00005oooool00ol0003oooooooooo`08ooooo`Go0000[?ooool0
08Sooooo0_l0000Rooooo`03o`000?oooooooooo00Wooooo0ol000000ooooooo0000o`00002Zoooo
o`00R?ooool2o`0002;ooooo0ol0000:ooooo`;o000000?oooooo`000?l00000Z_ooool00:cooooo
00?o0000ooooooooool0^Oooool00:Kooooo0_l00004ooooo`03o`000?oooooooooo0;Wooooo002Q
ooooo`;o00000oooool2o`000005ooooool0003o0000ooooool00000^oooool009oooooo1?l00000
1?oooooo0000o`000?l00002ooooo`;o000000?oooooo`000?ooool0=Oooool2o`0008?ooooo002O
ooooo`;o00000oooool3o`0000Gooooo00?o0000ooooooooool04Oooool2o`00027ooooo0_l00023
ooooo`00Qoooool2o`0001gooooo0_l00004ooooo`03o`000?oooooooooo017ooooo0_l0002Voooo
o`00Qoooool2o`0001gooooo0_l00002ooooo`?o0000^oooool008Oooooo0_l0000Qooooo`Go0000
^Oooool0093ooooo0_l0000Jooooo`03o`000?oooooooooo0;Wooooo002@ooooo`?o00001oooool2
o`00013ooooo00?o0000ooooooooool0^Oooool0097ooooo0_l00007ooooo`;o00004?ooool01?l0
003oooooo`000?l0002hooooo`00[?ooool01?l0003oooooo`000?l0002hooooo`00[?ooool00ol0
003oooooooooo`02o`000;Oooooo002/ooooo`03o`000?oooooooooo00;o0000=oooool2o`0007ko
oooo002Jooooo`;o00004?ooool00ol0003oooooooooo`0iooooo`;o0000O_ooool008Gooooo0_l0
000Cooooo`;o00004?ooool3o`000;Wooooo0025ooooo`?o00004?ooool2o`0001;ooooo00?o0000
ooooooooool00oooool2o`0003Kooooo0_l0001looooo`00Q_ooool2o`00013ooooo0_l0000Boooo
o`03o`000?oooooooooo00?ooooo0_l0000Aooooo`;o00008oooool2o`0007cooooo002/ooooo`03
o`000?oooooooooo01Kooooo0_l0002Qooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool0
6Oooool2o`00027ooooo0_l0001kooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool06Ooo
ool2o`00027ooooo0_l0001kooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Jooooo`;o0000
8_ooool2o`0007Wooooo002Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgo`000?l000001?ooool00ol0003oooooooooo`0Jooooo`;o00008_ooool2o`000003oooo
ool0003o000007Kooooo0029ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@013ooooo
0_l00004ooooo`03o`000?oooooooooo043ooooo0ol0001fooooo`00TOooool01Ol0003ooooooooo
oooooooo000000oooooo0_l00005ooooo`?o00001Oooool2o`0001?ooooo0_l0000Tooooo`;o0000
Moooool0097ooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?lQ8B7o000000;o0000
1Oooool00ol0003oooooooooo`05ooooo`;o00004oooool2o`0009gooooo0023ooooo`;o00003?oo
ool01Ol@413ooooooooooooooooo410@00;o00002_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo0_l0002`ooooo`00Poooool2o`0000cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`02o`0000[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`;o0000
/?ooool0097ooooo00?ok^k^oc8b<_l000000ol0000;ooooo`Co00001_ooool00ol0003ooooooooo
o`2iooooo`00U?ooool3o`0000Gooooo0_l0000>ooooo`03o`000?oooooooooo0;Wooooo002Loooo
o`;o00003_ooool00ol0003oooooooooo`0:ooooo`;o0000[Oooool009gooooo0_l0000=ooooo`03
o`000?oooooooooo00[ooooo0_l0002]ooooo`00WOooool2o`0000gooooo0ol0002iooooo`00Vooo
ool2o`0000oooooo00?o0000ooooooooool08_ooool3o`0009Cooooo002Kooooo`;o00003oooool3
o`0002;ooooo0ol0002Dooooo`00[?ooool3o`000;Wooooo002<ooooo`;o00007_ooool00ol0003o
ooooooooo`2iooooo`00S?ooool2o`0001kooooo00?o0000ooooooooool08oooool2o`00027ooooo
0_l0001aooooo`00Toooool2o`0001Oooooo00?o0000ooooooooool08oooool2o`00027ooooo1?l0
001_ooooo`00T_ooool3o`0001Oooooo00?o0000ooooooooool08_ooool2o`000003ooooool0003o
0000027ooooo0ol0001^ooooo`00T_ooool2o`0001Sooooo0ol0000Rooooo`;o000000?oooooo`00
0?l000008_ooool2o`0006kooooo002Hooooo`;o00004_ooool00ol0003oooooooooo`0?ooooo`;o
0000Z?ooool009Sooooo0_l0000=ooooo`;o00000oooool00ol0003oooooooooo`0?ooooo`;o0000
Z?ooool009Sooooo0_l0000=ooooo`;o00000oooool00ol0003oooooooooo`2iooooo`00V?ooool2
o`0000Gooooo0_l0000;ooooo`03o`000?oooooooooo0;Wooooo002Oooooo`;o00002oooool00ol0
003oooooooooo`02ooooo`;o00007oooool2o`0009Cooooo002/ooooo`03o`000?oooooooooo00;o
oooo0_l0000=ooooo`;o00004?ooool2o`0000Gooooo0_l0002=ooooo`00P_ooool2o`0002Oooooo
0_l0000Cooooo`;o00005oooool2o`00027ooooo0_l0001Zooooo`00P_ooool2o`0002Oooooo1?l0
0003ooooo`;o00009_ooool2o`00023ooooo0_l0001Zooooo`00[?ooool00ol0003oooooooooo`03
ooooo`;o00009_ooool2o`0008cooooo002Looooo`;o00003_ooool00ol0003oooooooooo`0Xoooo
o`;o000000?oooooo`000?l00000S?ooool009cooooo0_l0000>ooooo`03o`000?oooooooooo017o
oooo0_l0000Eooooo`;o000000?oooooo`000?l00000S?ooool00:cooooo00?o0000ooooooooool0
4Oooool2o`0001Gooooo0_l0002?ooooo`00[?ooool00ol0003oooooooooo`0Aooooo`;o000000?o
ooooo`000?l000004_ooool2o`000003ooooool0003o000008cooooo002/ooooo`03o`000?oooooo
oooo01Cooooo1?l0000Cooooo`;o0000S?ooool00:cooooo0ol0000Fooooo`;o0000XOooool00:co
oooo0ol0000^ooooo`;o0000ROooool009Gooooo0_l0000Eooooo`?o0000;_ooool2o`0001oooooo
0_l0001Xooooo`00UOooool2o`0000gooooo0_l00006ooooo`03o`000?oooooooooo04oooooo0_l0
001Xooooo`00XOooool2o`000003ooooool0003o000000;o00001?ooool01?l0003oooooo`000?l0
000]ooooo`;o0000ROooool00:7ooooo0_l00003ooooo`;o00001?ooool01?l0003oooooo`000?l0
000Cooooo`;o00006?ooool2o`0008Wooooo002/ooooo`03o`000?oooooooooo01Cooooo0_l0000D
ooooo`;o0000SOooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01Gooooo0_l0
000Cooooo`?o0000S?ooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`08ooooo`;o00002oooool2o`0001Cooooo0_l0002<ooooo`00P?ooool7o`0000;ooooo00Go
410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`08ooooo`;o0000[oooool0083ooooo0_l00007ooooo`05o`000?oo
ooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo
0ol0002iooooo`00P?ooool2o`0000Oooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMg
MomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo02ko
oooo0_l00029ooooo`00P?ooool2o`0000Oooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Gooooo`;o
00005Oooool2o`0008Wooooo0020ooooo`;o00001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00[o
oooo0_l000001?nj^[[ooooooiRHV?l@4104ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool05oooool2o`000:3ooooo0020ooooo`;o00001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00[ooooo0_l000001?l@413o0000ob4Q8Oo<c<`4ooooo`Co00001_ooool00ol0003oooooooooo`0;
ooooo`;o00003?ooool2o`0009kooooo002>ooooo`;o00007?ooool00ol0003oooooooooo`0;oooo
o`;o00003?ooool2o`0009kooooo002>ooooo`;o00007?ooool00ol0003oooooooooo`0Iooooo`;o
00005Oooool2o`0002Cooooo0_l0001Qooooo`00[?ooool00ol0003oooooooooo`0;ooooo`Co0000
2oooool2o`0001Cooooo0_l0000Tooooo`;o0000HOooool007oooooo0_l00007ooooo`;o00003Ooo
ool2o`0001?ooooo0ol0000;ooooo`Co00002oooool2o`0001Kooooo0_l00025ooooo`00Ooooool2
o`0000Oooooo0_l00005ooooo`;o00001_ooool2o`0001?ooooo00?o0000ooooooooool0<_ooool2
o`00027ooooo0ol0001Qooooo`00R?ooool2o`0000Gooooo0_l0000Kooooo`03o`000?oooooooooo
01cooooo0_l0000Dooooo`;o00008Oooool3o`00067ooooo0028ooooo`;o00008_ooool00ol0003o
ooooooooo`0Looooo`;o0000Voooool007oooooo0_l0000[ooooo`03o`000?oooooooooo01cooooo
0_l0000Dooooo`;o0000QOooool007oooooo0_l0000[ooooo`03o`000?oooooooooo00?ooooo0_l0
000]ooooo`;o0000QOooool00:cooooo00?o0000ooooooooool00oooool3o`0002cooooo0_l00025
ooooo`00[?ooool00ol0003oooooooooo`04ooooo`?o0000:oooool2o`0008Gooooo002/ooooo`?o
00001?ooool3o`0002Wooooo0_l00027ooooo`00T_ooool2o`0001Sooooo00?o0000ooooooooool0
1?ooool2o`0002[ooooo0_l00027ooooo`00T_ooool2o`0001Sooooo00?o0000ooooooooool06ooo
ool2o`0003_ooooo0_l0001Oooooo`00Ooooool2o`00017ooooo0_l0000Hooooo`03o`000?oooooo
oooo00oooooo0_l0000:ooooo`;o00006Oooool2o`00023ooooo0_l0001Oooooo`00Ooooool2o`00
017ooooo0_l0000Hooooo`03o`000?oooooooooo00oooooo0_l0000Uooooo`;o00008Oooool2o`00
05kooooo002/ooooo`03o`000?oooooooooo00gooooo0ol00019ooooo`;o0000G_ooool00:cooooo
00?o0000ooooooooool03Oooool3o`000:Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo001o
ooooo`;o0000:oooool00ol0003oooooooooo`2iooooo`00Ooooool2o`00017ooooo0_l00002oooo
o`;o00005?ooool3o`000;Wooooo001nooooo`?o00004Oooool2o`0000;ooooo0_l0000Dooooo`03
o`000?oooooooooo00;o00006oooool2o`0009[ooooo001nooooo`?o00001_ooool2o`0002?ooooo
00?o0000ooooooooool00_l0000Kooooo`;o0000V_ooool000Wooooo1?l000000ol@413ooooooooo
o`0Fooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool0
1?ooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q0oooool6o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Fooooo`03o`00
0?oooooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@02o`0000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oM
gMd06?ooool4o`000003oa0@4?oooooooooo01;ooooo000;ooooo`03o`000?oooooooooo01Sooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03
ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo01Gooooo00?o0000ooooooooool01ooo
ool2o`0000Gooooo0_l00008ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo
00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`04ogMgMolb<S;o0000o`0000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8boooo
o`0Iooooo`03o`000?oooooooooo01Cooooo0006o`0000Gooooo00?o0000ooooooooool04?ooool6
o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o
0000ooooooooool01Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`00
0?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP09ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01oooool2o`0000Go
oooo0_l00008ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09oooo
o`03o`000?oooooooooo00gooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00gooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0H
ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb
<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00kooooo
00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_oo
ool05Oooool00ol0003oooooooooo`07ooooo`;o00003oooool01?l0003oooooooooooooool2o`00
00cooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`0>ooooo`05o`000?oooooooooo
ooooool000003oooool00omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003_oo
ool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Wooooo00?o0000ooooooooool05?oo
ool000_ooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000kooooo00?o
EEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo
000000;ooooo0_l0000:ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Fooooo`03o`000?oooooooooo00Kooooo0_l0000@ooooo`04o`000?ooooooooooooooo`Go0000
2_ooool00omgMgOoIVIVooooo`03ooooo`04o`000?lQ8B7o0000oc8b<P;o00003_ooool01Ol0003o
oooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?oooooo
ooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
6_ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05oa0@4?oo
ooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo017ooooo
00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooo
oooooooooa0@4002ooooo`;o00002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo0_l0000Dooooo`?o00001_ooool2o`00013ooooo00Go410@oooooooooooooooooa0@4004
o`0000_ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000003o`0000kooooo00Go410@
oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooo
oa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool04Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00;ooooo0_l0
000Dooooo`03o`000?oooooooooo00oooooo0_l00007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00Go0000ooooool0003o0000ooooo`02o`00
00gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo01Cooooo0009ooooo`03oeEEEOmVIVKo000001[ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c004ooooo`Co00005oooool00ol0003oooooooooo`0?ooooo`;o00001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co0000
00?oooooo`000?l000003Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000Iooooo`03oeEEEOmVIVKo0000
01Kooooo002/ooooo`03o`000?oooooooooo00Oooooo0_l0000Dooooo`;o00005oooool2o`00087o
oooo002/ooooo`03o`000?oooooooooo00Oooooo0_l0000Dooooo`;o000000?oooooo`000?l00000
5?ooool2o`00087ooooo002/ooooo`03o`000?oooooooooo023ooooo0_l0002<ooooo`;o00000_oo
ool2o`0000Gooooo002Aooooo`;o00000_ooool2o`0001Gooooo00?o0000ooooooooool04Oooool2
o`0009_ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd5ooooo`00TOooool2o`0000;ooooo0_l0
000Eooooo`03o`000?oooooooooo017ooooo0_l0000Tooooo`;o0000M_ooool01?oMgMgo0000oa0@
4?o<c<`6ooooo`001oooooooo`0004co00003?ooool01?o^k^ko8B4Qoa0@4?o^k^h6ooooo`001ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooooooo
0_l00002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`02ooooo`;o000000?oooooo`000?ooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02o`0000?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool4o`0000Cooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool01?lQ8B7oMgMg
ogMgMolb<S86ooooo`001oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool08_ooool2o`0000;ooooo00Co0000oooooooooooooooo0_l0000@ooooo`;o
00004Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00[ooooo0_l00002ooooo`?o
00005Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool02Oooool2o`0000;ooooo0_l00005ooooo`00Ooooool2o`0000Kooooo0_l0000Sooooo`03o`00
0?oooooooooo03Cooooo0_l00023ooooo`00SOooool2o`0001gooooo00?o0000ooooooooool04?oo
ool2o`0000gooooo0_l0002Hooooo`00SOooool2o`0001gooooo00?o0000ooooooooool02?ooool2
o`0000Kooooo0_l0000=ooooo`;o0000V?ooool008gooooo0_l0000Mooooo`03o`000?oooooooooo
00Sooooo0_l00005ooooo`;o0000Z?ooool00:cooooo00?o0000ooooooooool03oooool2o`000:So
oooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool04Oooool2o`00027ooooo0_l0
0023ooooo`00U_ooool2o`0001Cooooo00?o0000ooooooooool04Oooool2o`0000[ooooo0_l0000E
ooooo`;o0000Poooool009;ooooo0_l00002ooooo`;o00005?ooool00ol0003oooooooooo`0Moooo
o`;o000000?oooooo`000?l000005oooool2o`0007kooooo0020ooooo`;o00004?ooool2o`0001So
oooo00?o0000ooooooooool01oooool2o`0001Oooooo0_l0000Gooooo`;o00008_ooool2o`0005[o
oooo0020ooooo`;o00005?ooool2o`0001Cooooo00?o0000ooooooooool01oooool2o`0002_ooooo
0_l0000Wooooo`;o0000F_ooool009Kooooo0_l0000Dooooo`03o`000?oooooooooo03Cooooo0_l0
0023ooooo`00Ooooool2o`0002_ooooo00?o0000ooooooooool01oooool3o`000:oooooo001ooooo
o`;o0000:oooool00ol0003oooooooooo`07ooooo`?o00005?ooool2o`0001Cooooo0_l00023oooo
o`00[?ooool3o`0001kooooo0_l0000Dooooo`;o0000:?ooool2o`0005Wooooo0028ooooo`;o0000
2?ooool2o`0001Sooooo00?o0000ooooooooool0G_ooool2o`0005Wooooo0028ooooo`;o00002?oo
ool2o`0001Sooooo00?o0000ooooooooool07Oooool2o`0009[ooooo001oooooo`;o0000:oooool0
0ol0003oooooooooo`02o`0001_ooooo0_l0002Jooooo`00Ooooool2o`0002_ooooo00?o0000oooo
ooooool00_l0002gooooo`00Ooooool2o`0002_ooooo00?o0000ooooooooool07?ooool2o`0009_o
oooo0027ooooo`;o00008oooool00ol0003oooooooooo`0Looooo`Co00006Oooool2o`0007kooooo
0027ooooo`;o00008oooool00ol0003oooooooooo`0Nooooo`Co00004_ooool2o`0000?ooooo0_l0
001nooooo`00R?ooool2o`0000gooooo0_l0000Cooooo`?o00003oooool2o`0000oooooo0_l0000B
ooooo`;o00000_ooool3o`0002;ooooo0_l0001Jooooo`00R?ooool2o`0000Wooooo0_l00002oooo
o`;o00004oooool00ol0003oooooooooo`0>ooooo`?o00009oooool3o`0002;ooooo0_l0001Joooo
o`00ROooool2o`0000?ooooo0_l00003ooooo`;o00005oooool00ol0003oooooooooo`0>ooooo`;o
00008oooool2o`0008Cooooo0029ooooo`;o00000oooool2o`0001cooooo00?o0000ooooooooool0
<oooool2o`0000Cooooo0_l0001nooooo`00ROooool2o`0000Sooooo0_l0000Gooooo`03o`000?oo
oooooooo01kooooo0_l0000Cooooo`;o00001?ooool2o`0002;ooooo0_l0001Jooooo`00Toooool2
o`0001Oooooo00?o0000ooooooooool07Oooool3o`0001?ooooo0ol0000Wooooo`;o0000F_ooool0
087ooooo0_l0000<ooooo`;o00006oooool00ol0003oooooooooo`0Mooooo`?o00005?ooool2o`00
08?ooooo0021ooooo`;o00003?ooool2o`0001_ooooo00?o0000ooooooooool01Oooool2o`0001So
oooo0_l0002Hooooo`00[?ooool3o`0000Cooooo0ol00007ooooo`;o00003oooool2o`0009Sooooo
002/ooooo`03o`000?oooooooooo00Cooooo0_l00008ooooo`;o0000ZOooool00:cooooo00?o0000
ooooooooool03_ooool3o`0002;ooooo0_l000000ooooooo0000o`000021ooooo`00[?ooool00ol0
003oooooooooo`0>ooooo`?o00008_ooool5o`00087ooooo002/ooooo`03o`000?oooooooooo03;o
oooo0_l000001?oooooo0000o`000?l00021ooooo`00[?ooool00ol0003oooooooooo`0booooo`;o
0000QOooool0083ooooo0_l00007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo1Ol00002ooooo`;o000000GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
0;Wooooo0020ooooo`;o00001_ooool2o`000004oiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44oooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@00_ooool2o`0000?ooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`0fooooo`;o0000POooool0083ooooo0_l00006ooooo`;o00000oooool00ol@
413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`00
03Kooooo0ol00020ooooo`00ROooool01Ol0003ooooooooooooooooo000000cooooo0_l000000olQ
8B7ok^k^ooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool07Oooool2o`00
01Kooooo1?l0000Rooooo`;o0000G?ooool008Wooooo00Go0000ooooooooooooooooo`00000<oooo
o`;o000000?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo0_l0000=
ooooo`;o00003oooool2o`0001?ooooo0_l000001?oooooo0000o`000?l0000Sooooo`;o0000G?oo
ool0083ooooo0_l00007ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Oooooo0_l0000=ooooo`;o00003oooool2o`0001?ooooo0_l0
0002ooooo`;o0000POooool0083ooooo0_l00007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0;ooooo`Co0000Z_ooool008Wooooo0ol000000olb<S;ok^k^ooooo`06ooooo`;o00000_oo
ool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo00_ooooo
1?l0002Zooooo`00ROooool2o`0000[ooooo0_l0000Eooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`03o`000?oooooooooo03Cooooo0_l00023ooooo`00T?ooool2o`0001[ooooo00?o0000oooo
ooooool00_ooool2o`00033ooooo0_l00023ooooo`00T?ooool2o`0001[ooooo0ol00002ooooo`;o
0000]Oooool0097ooooo0_l0000Iooooo`03o`000?oooooooooo05[ooooo0_l0001Mooooo`00TOoo
ool2o`0001Wooooo00?o0000ooooooooool06_ooool2o`0001Cooooo0ol000000ooooooo0000o`00
000Tooooo`;o0000GOooool0097ooooo0_l0000Iooooo`03o`000?oooooooooo00_ooooo0_l0000=
ooooo`;o00005?ooool3o`000003ooooool0003o000008?ooooo002Aooooo`;o00005?ooool2o`00
00?ooooo00?o0000ooooooooool02oooool2o`000:cooooo002Oooooo`;o00001_ooool2o`0000?o
oooo00?o0000ooooooooool02_ooool2o`0002Kooooo0_l00025ooooo`00Woooool2o`0000Gooooo
0_l00004ooooo`03o`000?oooooooooo00[ooooo0_l0000Vooooo`;o0000QOooool008;ooooo0_l0
0006ooooo`;o00001_ooool2o`0001;ooooo0_l00004ooooo`03o`000?oooooooooo01[ooooo0_l0
000Dooooo`;o0000Qoooool008;ooooo0_l00006ooooo`;o00001_ooool2o`0001Sooooo0ol00007
ooooo`;o00004Oooool2o`0001?ooooo1Ol00025ooooo`00Roooool2o`0001oooooo00?o0000oooo
ooooool01oooool2o`00013ooooo0_l0000Dooooo`;o000000?oooooo`000?l00000QOooool008_o
oooo0_l00005ooooo`;o00006?ooool00ol0003oooooooooo`0Iooooo`;o00005oooool2o`0008Go
oooo002Booooo`?o00005oooool2o`0003?ooooo0_l00025ooooo`00T_ooool3o`0001Oooooo0ol0
000aooooo`;o0000Q_ooool00:cooooo0ol0000aooooo`;o0000Q_ooool009_ooooo0_l0000?oooo
o`03o`000?oooooooooo0;Wooooo002Kooooo`;o00003_ooool2o`000;_ooooo002Cooooo`;o0000
1_ooool2o`0000kooooo1?l0002iooooo`00Poooool2o`0000kooooo0_l00006ooooo`;o00003ooo
ool00ol0003oooooooooo`0Cooooo`;o00006_ooool2o`0008Sooooo0023ooooo`;o00005oooool2
o`0000kooooo00?o0000ooooooooool04oooool2o`0001[ooooo0_l00028ooooo`00W?ooool2o`00
00kooooo00?o0000ooooooooool05?ooool2o`000:?ooooo0023ooooo`;o00001oooool2o`0001ko
oooo00?o0000ooooooooool05?ooool2o`0001Wooooo0_l00028ooooo`00Poooool2o`0000Oooooo
0_l0000Nooooo`03o`000?oooooooooo02oooooo0_l00028ooooo`00S?ooool2o`0001kooooo00?o
0000ooooooooool0^Oooool008cooooo0_l0000Nooooo`03o`000?oooooooooo00;ooooo0_l0000?
ooooo`;o0000Y?ooool008gooooo0_l0000Mooooo`?o00000_ooool3o`0000kooooo0_l0000Eoooo
o`;o0000SOooool008?ooooo0_l00008ooooo`;o00007Oooool00ol0003oooooooooo`02ooooo`?o
00003Oooool3o`0001Gooooo1?l0002;ooooo`00Poooool2o`0002Oooooo00?o0000ooooooooool0
0_ooool2o`0000kooooo0ol0000Gooooo`;o0000Roooool00:cooooo00?o0000ooooooooool04?oo
ool2o`000:Oooooo002/ooooo`03o`000?oooooooooo013ooooo0_l0002Wooooo`00[?ooool00ol0
003oooooooooo`0?ooooo`;o00005oooool2o`0008oooooo002Aooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo00oooooo0_l0000Gooooo`;o000000?oooooo`000?l00000S?ooool0097ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`02ooooo`;o000000?oooooob4Q8OlQ8B402?ooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo00kooooo0_l0000Kooooo`;o0000S?ooool0097ooooo00Ko410@oooo
oooooooooooooa0@4?ooool3o`0000cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0=ooooo`?o0000ZOooool0097ooooo00Ko0000ooooooooooooooooo`000?ooool2o`000003oooo
ool0003o000000Wooooo00?oMgMgoc8b<_ooool01?ooool3o`0000gooooo0_l000000ooooooo0000
o`00000Cooooo`;o0000T_ooool0097ooooo00Go0000ooooooooooooooooo`000004ooooo`;o0000
1_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool04?ooool2o`0001?o
oooo0_l0002Booooo`00TOooool01Ol@413ooooooooooooooooo410@00Cooooo0_l00006ooooo`03
o`000?oooooooooo00Oooooo0ol0002iooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00co
oooo00?o0000ooooooooool01_ooool4o`0000cooooo0_l0002[ooooo`00TOooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo1?l00005ooooo`Co00003?ooool2o`0001Wooooo0_l0002@ooooo`00
T?ooool2o`0000Sooooo0_l0000?ooooo`Co00009oooool2o`00093ooooo002@ooooo`;o00002?oo
ool4o`0000[ooooo0_l000000ooooooo0000o`00000>ooooo`;o00006Oooool2o`00093ooooo002L
ooooo`;o00002_ooool2o`0000;ooooo00?o0000ooooooooool03?ooool2o`0001Cooooo0_l00003
ooooo`;o0000T?ooool00:cooooo0ol0000Rooooo`;o000000?oooooo`000?l00000T_ooool00:co
oooo00?o0000ooooooooool09?ooool3o`0009;ooooo002Mooooo`;o00003Oooool00ol0003ooooo
ooooo`0Tooooo`;o0000Toooool008Kooooo0_l0000Eooooo`Go00000oooool2o`0000Gooooo00?o
0000ooooooooool02?ooool2o`000:oooooo0026ooooo`;o00005oooool3o`0000?ooooo0_l00005
ooooo`03o`000?oooooooooo00Sooooo0_l0002_ooooo`00Q_ooool2o`0001[ooooo0_l00008oooo
o`03o`000?oooooooooo00Oooooo0_l0002`ooooo`00Q_ooool2o`0000_ooooo0_l0000=ooooo`;o
00002?ooool00ol0003oooooooooo`07ooooo`;o0000/?ooool009?ooooo0_l0000Gooooo`03o`00
0?oooooooooo02?ooooo0_l0002Dooooo`00Q_ooool2o`0000cooooo0_l0000Fooooo`?o00008ooo
ool2o`0009Cooooo0026ooooo`;o00003?ooool2o`0001Kooooo00?o0000ooooooooool0^Oooool0
08Oooooo0_l0000Sooooo`03o`000?oooooooooo01kooooo0_l0002Iooooo`00Qoooool2o`0002?o
oooo00?o0000ooooooooool07_ooool2o`0009Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo0028oooo
o`;o00008_ooool00ol0003oooooooooo`0Oooooo`;o0000V?ooool008Sooooo0_l0000Rooooo`?o
00006Oooool2o`0000Cooooo0_l0002Hooooo`00[?ooool00ol0003oooooooooo`0Iooooo`;o0000
W_ooool008Wooooo0_l0000:ooooo`;o00005Oooool00ol0003oooooooooo`2iooooo`00ROooool2
o`0000[ooooo0_l0000Eooooo`03o`000?oooooooooo01cooooo0_l0002Kooooo`00ROooool4o`00
01oooooo00?o0000ooooooooool06?ooool3o`000003ooooool0003o000009_ooooo002:ooooo`?o
00007oooool01?l0003oooooo`000?l0000Gooooo`?o0000W_ooool008[ooooo0_l0000Oooooo`;o
000000?oooooo`000?l000006Oooool2o`0009gooooo002Zooooo`?o00007?ooool2o`0009gooooo
002Iooooo`;o00003oooool3o`0001Kooooo0_l000000ooooooo0000o`00002Pooooo`00VOooool2
o`00013ooooo1?l0000Dooooo`Go0000X?ooool00:Oooooo0_l00002ooooo`;o00005oooool2o`00
0:;ooooo002Wooooo`;o00000oooool00ol0003oooooooooo`2iooooo`00Y?ooool6o`0000;ooooo
00?o0000ooooooooool04oooool2o`000:Cooooo002Tooooo`Ko00000_ooool00ol0003ooooooooo
o`0Cooooo`;o0000Y?ooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`2iooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`05oeEE
EOnYZJWo0000o`000?ooool01?l000000oooooooMgMgoc8b<P05ooooo`03o`000?oooooooooo0;Wo
oooo0029ooooo`05oa0@4?ooooooooooooooool@41003Oooool01OnYZJWoEEEEo`000?l0003ooooo
00Co00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00oooooo0_l0002Xoooo
o`00ROooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`?o00003oooool2o`000:Sooooo0029ooooo`04o`000?oooooooooooooo
o`?o00003?ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2iooooo`00ROooool01Ol@413ooooooooooooooooo410@00;o00003?ooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04?ooool2
o`000:Oooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooo
oooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0@ooooo`;o0000Yooo
ool008Wooooo00Cok^k^oc8b<_l0003o<S8b0_l0000:ooooo`Go00001?ooool4o`0000Kooooo00?o
0000ooooooooool0^Oooool008gooooo0_l0000Mooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo00cooooo0_l0002[ooooo`00[?ooool00ol0003oooooooooo`09ooooo`;o
000000?oooooo`000?l00000Zoooool00:cooooo0ol00009ooooo`;o0000[_ooool008kooooo0_l0
000Looooo`03o`000?oooooooooo00cooooo0_l0002[ooooo`00S_ooool2o`0001cooooo00?o0000
ooooooooool03?ooool2o`000:_ooooo002Booooo`;o00006?ooool00ol0003oooooooooo`2ioooo
o`00T_ooool2o`0001Sooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
^Oooool0093ooooo0_l0000Jooooo`03o`000?oooooooooo0;Wooooo002@ooooo`;o00006_ooool0
0ol0003oooooooooo`2iooooo`00[?ooool3o`0000Cooooo0_l000000ooooooo0000o`00002`oooo
o`00[?ooool00ol0003oooooooooo`04ooooo`Go0000/?ooool00:cooooo00?o0000ooooooooool0
1?ooool4o`000;7ooooo002/ooooo`03o`000?oooooooooo00Cooooo0_l0002cooooo`00U_ooool2
o`0001Cooooo00?o0000ooooooooool01?ooool2o`000;?ooooo002Fooooo`;o00005?ooool00ol0
003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00UOooool2o`0001Gooooo00?o0000ooooooooool0^Oooool009Gooooo0_l0000E
ooooo`Co0000^?ooool00:Wooooo0_l000000ooooooo0000ooooo`02o`000;Sooooo002Iooooo`;o
00003_ooool2o`000003ooooool0003ooooo0;[ooooo002Iooooo`?o00003oooool2o`000;_ooooo
002Jooooo`;o00003oooool2o`000;_ooooo002Qooooo`;o00000_ooool2o`0000Cooooo0_l0002k
ooooo`00V_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00001Oooool00ol0
003oooooooooo`2iooooo`00V_ooool7o`0000_ooooo00?o0000ooooooooool0^Oooool009_ooooo
0ol000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000001?ooool3o`000;Wooooo
002Sooooo`;o000000?oooooo`000?l000001?ooool00ol0003oooooooooo`2iooooo`00Y?ooool2
o`0000Kooooo00?o0000ooooooooool0^Oooool00:?ooooo0ol00006ooooo`03o`000?oooooooooo
0;Wooooo002Sooooo`;o00001oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00X_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0^Ooo
ool00:Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00Y?ooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo
00?o0000ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo00?o0000
ooooooooool0`Oooool00:;ooooo00?oEEEEofIVI_l00000`oooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00:[ooooo00Co410@o`000?l0003o0000^_ooool0
0:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo
00Ko0000ogMgMol0003o0000oeEEEOo^k^jgooooo`00Zoooool01_l0003oEEEEonk^k_ooooooMgMg
oeEEEKOooooo002[ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0]Oooool00:_o
oooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`2eooooo`00Zoooool01_l0003oEEEE
onk^k_ooooooMgMgofIVI[Oooooo002Zooooo`03oa0@4?l0003oMgMg00;o000000?oIVIVonk^k_oo
ool0]_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.38658 .54362 Mdot
.41328 .19564 Mdot
.48209 .63237 Mdot
.43174 .33714 Mdot
.40953 .62174 Mdot
.49514 .8736 Mdot
.51559 .54481 Mdot
.59002 .87407 Mdot
.6014 .83093 Mdot
.5599 .43119 Mdot
.56422 .5676 Mdot
.51194 .96665 Mdot
.52445 .11895 Mdot
.5679 .46558 Mdot
.4269 .93673 Mdot
.48986 .24403 Mdot
.61103 .53872 Mdot
.52956 .12469 Mdot
.50679 .77015 Mdot
.67702 .38417 Mdot
.5723 .1925 Mdot
.49164 .09338 Mdot
.54709 .16822 Mdot
.55307 .15739 Mdot
.38642 .79538 Mdot
.47348 .16354 Mdot
.54075 .66948 Mdot
.49192 .79027 Mdot
.68601 .43052 Mdot
.44295 .11705 Mdot
.61506 .2756 Mdot
.6225 .80133 Mdot
.57283 .88735 Mdot
.59037 .65903 Mdot
.58788 .69041 Mdot
.67376 .42916 Mdot
.68012 .63761 Mdot
.5088 .75572 Mdot
.68761 .52311 Mdot
.52527 .9563 Mdot
.42149 .9372 Mdot
.59289 .6664 Mdot
.53806 .8008 Mdot
.39061 .64335 Mdot
.41252 .78365 Mdot
.40901 .36136 Mdot
.56508 .52249 Mdot
.6609 .72411 Mdot
.56266 .289 Mdot
.68591 .4731 Mdot
.6553 .73313 Mdot
.69363 .52795 Mdot
.70908 .23013 Mdot
.54983 .77402 Mdot
.57325 .73532 Mdot
.58273 .86529 Mdot
.57209 .89641 Mdot
.61363 .5092 Mdot
.6726 .68209 Mdot
.4228 .82101 Mdot
.42462 .26436 Mdot
.37515 .24865 Mdot
.68435 .55108 Mdot
.50497 .69897 Mdot
.51802 .94601 Mdot
.61318 .82054 Mdot
.55954 .43762 Mdot
.49879 .26321 Mdot
.5256 .72448 Mdot
.5804 .19953 Mdot
.61815 .47889 Mdot
.49026 .67427 Mdot
.56302 .47495 Mdot
.54662 .3764 Mdot
.68424 .55144 Mdot
.44243 .51625 Mdot
.70957 .23108 Mdot
.4928 .18488 Mdot
.69345 .50249 Mdot
.58253 .36686 Mdot
.64815 .34756 Mdot
.44826 .11071 Mdot
.42884 .36046 Mdot
.5955 .66257 Mdot
.6062 .84551 Mdot
.46877 .23216 Mdot
.40742 .59907 Mdot
.41496 .33198 Mdot
.61172 .45676 Mdot
.50603 .27908 Mdot
.37765 .73236 Mdot
.60017 .09172 Mdot
.47194 .74537 Mdot
.40583 .40892 Mdot
.47614 .74253 Mdot
.5624 .04777 Mdot
.56708 .46069 Mdot
.63082 .77579 Mdot
.71449 .23743 Mdot
.6106 .42819 Mdot
.38768 .41793 Mdot
.60221 .3972 Mdot
.48744 .98648 Mdot
.38465 .51735 Mdot
.62033 .27137 Mdot
.58707 .67223 Mdot
.61765 .52643 Mdot
.49261 .79664 Mdot
.47184 .74568 Mdot
.59126 .21969 Mdot
.56317 .43548 Mdot
.42108 .41915 Mdot
.61981 .80413 Mdot
.66918 .37525 Mdot
.78097 .37472 Mdot
.45963 .30055 Mdot
.45105 .19181 Mdot
.63316 .79697 Mdot
.63381 .79091 Mdot
.6656 .67145 Mdot
.53237 .13078 Mdot
.36092 .47898 Mdot
.58416 .22351 Mdot
.68639 .42309 Mdot
.5869 .21088 Mdot
.44972 .27291 Mdot
.67644 .40776 Mdot
.53074 .01709 Mdot
.43449 .14276 Mdot
.52337 .40093 Mdot
.52355 .13159 Mdot
.39976 .2829 Mdot
.47299 .99299 Mdot
.50893 .85856 Mdot
.52255 .82891 Mdot
.6923 .45852 Mdot
.69684 .57066 Mdot
.68271 .42862 Mdot
.56257 .47597 Mdot
.53553 .93283 Mdot
.43472 .95428 Mdot
.42889 .64305 Mdot
.52313 .73427 Mdot
.61175 .53371 Mdot
.6723 .37435 Mdot
.6172 .82666 Mdot
.79806 .42853 Mdot
.43052 .72645 Mdot
.41834 .30661 Mdot
.37549 .7541 Mdot
.59637 .3725 Mdot
.55254 .64899 Mdot
.54836 .14895 Mdot
.49953 .65031 Mdot
.42288 .80681 Mdot
.69177 .57733 Mdot
.68811 .54023 Mdot
.61895 .81706 Mdot
.67461 .65261 Mdot
.69306 .57534 Mdot
.51644 .20475 Mdot
.69458 .48641 Mdot
.48904 .99946 Mdot
.66725 .41066 Mdot
.51045 .83965 Mdot
.39313 .34968 Mdot
.61557 .82736 Mdot
.62604 .27935 Mdot
.52766 .71825 Mdot
.69884 .54169 Mdot
.68184 .47566 Mdot
.42909 .6278 Mdot
.52681 .71463 Mdot
.40462 .48292 Mdot
.43299 .74019 Mdot
.54384 .92042 Mdot
.55518 .0412 Mdot
.42325 .80677 Mdot
.47957 .29524 Mdot
.68838 .46752 Mdot
.69895 .51315 Mdot
.49314 .99036 Mdot
.52065 .29872 Mdot
.41527 .92186 Mdot
.53576 .4859 Mdot
.59166 .84193 Mdot
.53988 .02838 Mdot
.64542 .76489 Mdot
.48922 .99798 Mdot
.53932 .80221 Mdot
.36344 .59655 Mdot
.67131 .369 Mdot
.51501 .66522 Mdot
.37879 .22787 Mdot
.59492 .8637 Mdot
.41214 .91909 Mdot
.48385 .98976 Mdot
.40531 .42519 Mdot
.61187 .09812 Mdot
.61925 .55075 Mdot
.45519 .31946 Mdot
.45846 .3122 Mdot
.48248 .68531 Mdot
.40566 .54649 Mdot
.63089 .1208 Mdot
.39876 .29462 Mdot
.5281 .60286 Mdot
.47117 .88479 Mdot
.41782 .52027 Mdot
.53881 .48837 Mdot
.56688 .55697 Mdot
.48906 .08172 Mdot
.48178 .17647 Mdot
.62782 .28358 Mdot
.52313 .31108 Mdot
.39698 .3127 Mdot
.47637 .17735 Mdot
.5348 .44814 Mdot
.40603 .74125 Mdot
.54798 .93017 Mdot
.44248 .20797 Mdot
.65241 .72606 Mdot
.61648 .25919 Mdot
.65787 .381 Mdot
.52367 .31963 Mdot
.423 .70852 Mdot
.39093 .3318 Mdot
.44083 .68913 Mdot
.42749 .93853 Mdot
.3603 .51054 Mdot
.46136 .24519 Mdot
.49504 .36205 Mdot
.65194 .15296 Mdot
.59506 .39016 Mdot
.55361 .63092 Mdot
.36132 .49046 Mdot
.52111 .7295 Mdot
.38443 .47309 Mdot
.56042 .17964 Mdot
.39405 .32958 Mdot
.38067 .21062 Mdot
.52978 .82314 Mdot
.63697 .29683 Mdot
.61803 .47843 Mdot
.63657 .7813 Mdot
.47036 .73858 Mdot
.6826 .60669 Mdot
.60777 .50241 Mdot
.61759 .47226 Mdot
.68662 .54024 Mdot
.40974 .90974 Mdot
.45962 .30136 Mdot
.50253 .69673 Mdot
.67591 .63545 Mdot
.50378 .19132 Mdot
.52727 .71203 Mdot
.58307 .72133 Mdot
.44197 .4903 Mdot
.56134 .90649 Mdot
.66803 .70219 Mdot
.5801 .33461 Mdot
.55435 .62815 Mdot
.66095 .38821 Mdot
.5056 .33671 Mdot
.59888 .3906 Mdot
.38764 .55435 Mdot
.56176 .56005 Mdot
.47187 .87737 Mdot
.67802 .45674 Mdot
.53946 .25503 Mdot
.67392 .40922 Mdot
.57358 .73761 Mdot
.55635 .40456 Mdot
.58114 .34979 Mdot
.69424 .56342 Mdot
.51948 .29318 Mdot
.46501 .80902 Mdot
.64741 .75041 Mdot
.57015 .52354 Mdot
.44411 .86046 Mdot
.6906 .47449 Mdot
.51148 .34418 Mdot
.54495 .37927 Mdot
.67114 .66124 Mdot
.50862 .96734 Mdot
.49294 .7972 Mdot
.50896 .60725 Mdot
.4069 .53386 Mdot
.65603 .3319 Mdot
.41823 .30319 Mdot
.64373 .33913 Mdot
.54584 .03551 Mdot
.66555 .69413 Mdot
.45774 .98006 Mdot
.65163 .72285 Mdot
.51201 .42949 Mdot
.68537 .64161 Mdot
.38238 .21039 Mdot
.64399 .30283 Mdot
.43534 .95282 Mdot
.8044 .45451 Mdot
.56825 .31112 Mdot
.56747 .75855 Mdot
.39676 .30162 Mdot
.63029 .79062 Mdot
.4087 .8972 Mdot
.56611 .52574 Mdot
.64114 .76007 Mdot
.50871 .19786 Mdot
.43804 .39204 Mdot
.50227 .09702 Mdot
.61164 .54548 Mdot
.53591 .13808 Mdot
.37938 .77962 Mdot
.47757 .28968 Mdot
.39641 .67449 Mdot
.58937 .66903 Mdot
.50622 .96036 Mdot
.4989 .31436 Mdot
.47964 .99625 Mdot
.36352 .44881 Mdot
.46422 .24688 Mdot
.51973 .84518 Mdot
.59976 .65271 Mdot
.68344 .57196 Mdot
.4337 .7551 Mdot
.43488 .40501 Mdot
.51706 .48882 Mdot
.6167 .52018 Mdot
.56524 .90819 Mdot
.67069 .64745 Mdot
.48515 .73896 Mdot
.486 .08387 Mdot
.5233 .39642 Mdot
.47892 .68732 Mdot
.39418 .30228 Mdot
.51002 .85379 Mdot
.51084 .83934 Mdot
.51926 .20998 Mdot
.40641 .55805 Mdot
.68713 .19299 Mdot
.52491 .22883 Mdot
.45145 .11 Mdot
.49387 .722 Mdot
.57053 .88554 Mdot
.54271 .66124 Mdot
.68139 .42727 Mdot
.49116 .09921 Mdot
.45215 .72769 Mdot
.45969 .18834 Mdot
.52737 .95065 Mdot
.69213 .6209 Mdot
.67525 .42995 Mdot
.55288 .27356 Mdot
.61466 .5711 Mdot
.68093 .45836 Mdot
.59653 .3877 Mdot
.52417 .95372 Mdot
.43235 .0139 Mdot
.63956 .30195 Mdot
.47016 .99182 Mdot
.47207 .99678 Mdot
.44348 .98164 Mdot
.46132 .68072 Mdot
.58924 .37005 Mdot
.42663 .93769 Mdot
.5691 .8985 Mdot
.45703 .67416 Mdot
.63117 .3058 Mdot
.5428 .26821 Mdot
.48458 .88475 Mdot
.38659 .4505 Mdot
.62274 .79141 Mdot
.38472 .46391 Mdot
.67962 .64792 Mdot
.67467 .62379 Mdot
.54404 .16493 Mdot
.69669 .5975 Mdot
.52511 .13541 Mdot
.40132 .86636 Mdot
.7874 .38775 Mdot
.65746 .69618 Mdot
.43088 .83424 Mdot
.49241 .66488 Mdot
.367 .62909 Mdot
.6093 .43106 Mdot
.51643 .47757 Mdot
.49911 .98682 Mdot
.58347 .20433 Mdot
.43137 .44198 Mdot
.55235 .40007 Mdot
.46796 .16937 Mdot
.54806 .65213 Mdot
.66077 .72748 Mdot
.6059 .23209 Mdot
.38314 .20199 Mdot
.48916 .99344 Mdot
.60721 .59157 Mdot
.68874 .20171 Mdot
.61032 .58608 Mdot
.44105 .7647 Mdot
.44183 .7712 Mdot
.46078 .35291 Mdot
.56071 .91177 Mdot
.51248 .96557 Mdot
.54305 .66224 Mdot
.43908 .68718 Mdot
.57012 .5632 Mdot
.49043 .23829 Mdot
.3868 .81914 Mdot
.40275 .49415 Mdot
.66438 .39045 Mdot
.41977 .53766 Mdot
.54729 .66506 Mdot
.50968 .34674 Mdot
.40371 .53201 Mdot
.59356 .64578 Mdot
.55802 .62334 Mdot
.52554 .61677 Mdot
.36354 .61447 Mdot
.54175 .92582 Mdot
.50263 .51819 Mdot
.58496 .70021 Mdot
.61744 .52849 Mdot
.39704 .66442 Mdot
.55144 .2859 Mdot
.53083 .70809 Mdot
.37058 .68357 Mdot
.56474 .04618 Mdot
.39012 .35792 Mdot
.76565 .33579 Mdot
.38945 .63478 Mdot
.52696 .61761 Mdot
.57148 .87196 Mdot
.41676 .91313 Mdot
.55845 .59963 Mdot
.50325 .11382 Mdot
.69398 .20434 Mdot
.43206 .65519 Mdot
.43011 .49272 Mdot
.4202 .68228 Mdot
.6577 .37185 Mdot
.5708 .32895 Mdot
.60677 .09541 Mdot
.53719 .49671 Mdot
.5585 .75358 Mdot
.60213 .63917 Mdot
.4986 .7181 Mdot
.48538 .29668 Mdot
.53297 .32769 Mdot
.58568 .87939 Mdot
.47963 .28726 Mdot
.69304 .48067 Mdot
.39962 .26782 Mdot
.40132 .71892 Mdot
.67471 .40497 Mdot
.63793 .32691 Mdot
.61123 .5619 Mdot
.55387 .40521 Mdot
.56366 .91068 Mdot
.41844 .93573 Mdot
.55923 .57533 Mdot
.68853 .63259 Mdot
.54645 .27227 Mdot
.60757 .54739 Mdot
.68038 .41975 Mdot
.38637 .44713 Mdot
.49212 .7941 Mdot
.45789 .1896 Mdot
.59635 .64168 Mdot
.36228 .39315 Mdot
.50458 .85242 Mdot
.4456 .56723 Mdot
.53088 .80893 Mdot
.58082 .35687 Mdot
.47309 .69158 Mdot
.48517 .24724 Mdot
.55663 .76144 Mdot
.54109 .8009 Mdot
.45676 .31054 Mdot
.50092 .18932 Mdot
.61094 .82418 Mdot
.41677 .68206 Mdot
.3895 .59016 Mdot
.54219 .69079 Mdot
.46735 .79506 Mdot
.44301 .63193 Mdot
.77507 .35146 Mdot
.43704 .5951 Mdot
.40274 .24535 Mdot
.63568 .75659 Mdot
.66749 .40625 Mdot
.52063 .73649 Mdot
.68539 .44431 Mdot
.49999 .98252 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00UOooool2o`0000_ooooo00?oEEEEofIV
I_l000001oooool00ol0003oooooooooo`2iooooo`00UOooool2o`0001Gooooo00?o0000oooooooo
ool01oooool2o`000;3ooooo002/ooooo`03o`000?oooooooooo00Oooooo0_l0002`ooooo`00[?oo
ool3o`000;Wooooo002/ooooo`03o`000?oooooooooo00[ooooo0_l0002]ooooo`00[?ooool00ol0
003oooooooooo`0:ooooo`;o0000[Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool03?ooool2o`000:_ooooo002/ooooo`03o`000?oooooooooo00cooooo0_l0
002[ooooo`00[?ooool00ol0003oooooooooo`0?ooooo`;o0000Z?ooool00:cooooo00?o0000oooo
ooooool03oooool2o`000003ooooool0003o00000:Gooooo002/ooooo`03o`000?oooooooooo017o
oooo0ol0002Uooooo`00[?ooool3o`00017ooooo0_l0002Vooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`00
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Xooooo`;o00000_ooool00ol0003ooooo
ooooo`2iooooo`00Yoooool3o`0000;ooooo00?o0000ooooooooool0^Oooool00:Oooooo0_l00003
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo01kooooo0_l0002Ioooo
o`00ZOooool2o`000003ooooool0003ooooo01oooooo1?l0002Gooooo`00ZOooool2o`000003oooo
ool0003o0000027ooooo0ol0002Fooooo`00ZOooool2o`000004ooooool0003o0000o`00027ooooo
0_l0002Fooooo`00ZOooool2o`000003ooooool0003ooooo0;[ooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002Jooooo`Co00003_ooool00ol0003oooooooooo`2iooooo`00V_ooool4o`0000ko
oooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00ROooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`?o000000?ok^k^ooooooooool00oooool01Om4A4Co0000
o`000?lb<S;ogMgM00Gooooo0ol00005ooooo`;o0000/_ooool008Wooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool2o`000003oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`05ooooo`;o00008Oooool2o`0008oooooo0021ooooo`Ko0000
0_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003o
ooooooooo`03ooooo`?o00001_ooool2o`00023ooooo0_l0002?ooooo`00ROooool01Ol0003ooooo
oooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo00Kooooo0_l0002aooooo`00ROooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool01?ooool2o`000003ooooool0003o00000;3ooooo0029ooooo`05oa0@4?oooooooooooooo
ool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01?ooool2o`000003ooooool0003o00000;3ooooo0029ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`05ooooo`;o0000/_ooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool01Oooool2o`000003ooooool0003o
00000:oooooo002Fooooo`;o00005?ooool00ol0003oooooooooo`08ooooo`;o0000[oooool009Ko
oooo0_l0000Dooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00gooooo
0_l0002Zooooo`00[?ooool3o`0000gooooo0_l0000Pooooo`;o0000R?ooool00:cooooo00?o0000
ooooooooool0;oooool2o`0008Sooooo002/ooooo`03o`000?oooooooooo00kooooo0_l0002Yoooo
o`00[?ooool00ol0003oooooooooo`0>ooooo`;o0000ZOooool00:?ooooo0_l00007ooooo`03o`00
0?oooooooooo00_ooooo0_l0002/ooooo`00Xoooool2o`0000Oooooo00?o0000ooooooooool02ooo
ool3o`000:_ooooo002Qooooo`;o00002Oooool00ol0003oooooooooo`0<ooooo`;o0000Zoooool0
0:7ooooo0_l00009ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`Co00001?ooool3o`000;Wo
oooo002Tooooo`Co00001?ooool00ol0003oooooooooo`0Aooooo`;o0000Y_ooool00:cooooo00?o
0000ooooooooool04Oooool2o`000:Kooooo002Yooooo`;o000000?oooooo`000?ooool0^_ooool0
09kooooo0_l00009ooooo`;o000000?oooooo`000?l00000^_ooool009_ooooo0_l000000ooooooo
0000o`00000<ooooo`?o00005?ooool2o`000:?ooooo002Kooooo`;o000000?oooooo`000?l00000
3?ooool3o`0001Cooooo0_l0000Tooooo`;o0000OOooool008oooooo0_l0000Kooooo`04o`000?oo
oooo0000o`0003Wooooo0_l0001mooooo`00Soooool2o`0001_ooooo1?l0000Fooooo`;o0000X?oo
ool008Gooooo0_l0000Uooooo`03o`000?oooooooooo01Oooooo0ol0000Qooooo`Co0000N_ooool0
08Gooooo0_l0000Uooooo`03o`000?oooooooooo00;ooooo0_l0000Dooooo`;o00008Oooool4o`00
07[ooooo0024ooooo`?o00004_ooool2o`00017ooooo00?o0000ooooooooool00_ooool3o`000;Co
oooo0024ooooo`?o00004_ooool2o`00017ooooo00?o0000ooooooooool00oooool2o`0001Cooooo
0_l0002Nooooo`00[?ooool00ol0003oooooooooo`0Iooooo`;o0000W_ooool00:cooooo00?o0000
ooooooooool06oooool2o`0009cooooo002/ooooo`03o`000?oooooooooo01_ooooo0_l0002Loooo
o`00[?ooool3o`0001Sooooo0_l0002Oooooo`00Q?ooool2o`0002Kooooo00?o0000ooooooooool0
1Oooool2o`00017ooooo0_l0002Oooooo`00Q?ooool2o`0002Kooooo00?o0000ooooooooool01Ooo
ool2o`0003_ooooo0_l0001eooooo`00XOooool2o`0000Wooooo00?o0000ooooooooool08?ooool2
o`00023ooooo0_l0001eooooo`00XOooool2o`0000Wooooo00?o0000ooooooooool08?ooool2o`00
027ooooo0_l0001dooooo`00Z?ooool2o`0000;ooooo00?o0000ooooooooool0@oooool2o`0007Co
oooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00KoA4A4o`000?l0
003o<S8bomgMgOooool2o`0000;ooooo00?o0000ooooooooool0^Oooool008_ooooo0_l00004oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@;ooooo0ol00003ooooo`03ogMgMolb<S;o
oooo00;o00000_ooool00ol0003oooooooooo`2iooooo`00P_ooool2o`0000Gooooo1_l00002oooo
o`05oa0@4?ooooooooooooooool@41002Oooool3o`0000Cooooo0ol00003ooooo`03o`000?oooooo
oooo0;Wooooo0022ooooo`;o00003Oooool01Ol0003ooooooooooooooooo000000oooooo00CoMgMg
oc8b<_l0003o00000oooool3o`000;Wooooo002Aooooo`05o`000?ooooooooooooooool000003?oo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool02_ooool2o`000:gooooo
002Aooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00[ooooo0_l0002]ooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Sooooo`;o0000U?ooool0097ooooo00Go
k^k^oc8b<_l0003o0000onk^kP0<ooooo`Co00001Oooool2o`0002Gooooo0_l0002Dooooo`00R_oo
ool2o`0000Oooooo0_l0000Fooooo`;o00003Oooool2o`000:cooooo002:ooooo`;o00008?ooool0
0ol0003oooooooooo`0;ooooo`;o0000[?ooool009_ooooo0_l0000?ooooo`03o`000?oooooooooo
00cooooo1?l0000Dooooo`;o0000Toooool009_ooooo0_l0000?ooooo`?o00003?ooool4o`0001?o
oooo0ol0002Cooooo`00[?ooool01?l0003oooooo`000?l0000Rooooo`;o000000?oooooo`000?l0
0000TOooool008[ooooo0_l0000Pooooo`04o`000?oooooo0000o`0002Gooooo0_l0002Aooooo`00
R_ooool2o`00023ooooo00?o0000ooooooooool03_ooool2o`0001Oooooo0_l0002@ooooo`00YOoo
ool2o`0000Gooooo00?o0000ooooooooool03_ooool2o`000003ooooool0003o000001Cooooo0_l0
002@ooooo`00Y?ooool3o`0000Gooooo00?o0000ooooooooool04Oooool2o`000:Kooooo002:oooo
o`;o00006?ooool3o`0000Gooooo00?o0000ooooooooool00oooool2o`000;Cooooo002:ooooo`;o
00006Oooool4o`0000?ooooo00?o0000ooooooooool00oooool2o`0002Gooooo0_l0002=ooooo`00
W_ooool2o`0000Oooooo0_l00003ooooo`?o00000oooool2o`0002Gooooo0_l0002=ooooo`00ROoo
ool2o`0000Kooooo0_l0000;ooooo`;o00003?ooool00ol0003oooooooooo`03ooooo`;o00009_oo
ool3o`0008_ooooo0029ooooo`;o00001_ooool2o`0001Wooooo00?o0000ooooooooool0:?ooool2
o`000004ooooool0003o0000o`0008_ooooo002Aooooo`;o00002_ooool2o`0000gooooo00?o0000
ooooooooool0:?ooool2o`0008oooooo002:ooooo`;o00004Oooool3o`0000cooooo00?o0000oooo
ooooool01?ooool2o`0000gooooo0_l0002Tooooo`00R_ooool2o`0001;ooooo0_l0000;ooooo`;o
00001_ooool2o`0000gooooo0_l0002Tooooo`00WOooool2o`0000cooooo0_l00006ooooo`;o0000
/oooool009gooooo0_l0000=ooooo`03o`000?oooooooooo00Cooooo0_l0002cooooo`00[?ooool3
o`000;Wooooo002/ooooo`03o`000?oooooooooo00Oooooo0_l0000Qooooo`;o0000SOooool008So
oooo0ol0000Qooooo`03o`000?oooooooooo00Oooooo0_l0000;ooooo`;o00005?ooool2o`0008go
oooo0028ooooo`?o00001?ooool2o`0001_ooooo00?o0000ooooooooool05?ooool2o`000003oooo
ool0003o000001Oooooo0_l00027ooooo`00Soooool2o`0000Cooooo0_l0000Eooooo`?o00005ooo
ool2o`0001Oooooo0_l0000Rooooo`;o0000Hoooool009Gooooo0_l0000Eooooo`?o0000;?ooool2
o`0002Kooooo0_l0001Sooooo`00[?ooool00ol0003oooooooooo`0/ooooo`;o0000Roooool00:co
oooo00?o0000ooooooooool00_l0002gooooo`00R?ooool2o`0002;ooooo00?o0000ooooooooool0
0_l0000Eooooo`;o00005?ooool2o`0008[ooooo0028ooooo`;o00005Oooool2o`0000_ooooo0ol0
000Gooooo`;o00005?ooool2o`0002Sooooo0_l0001Pooooo`00Woooool2o`0000_ooooo00?o0000
ooooooooool0Eoooool2o`00063ooooo0027ooooo`;o00008oooool00ol0003oooooooooo`0Goooo
o`;o0000X?ooool008Oooooo0_l00005ooooo`;o00001?ooool2o`0001Cooooo0ol0000Iooooo`;o
0000X?ooool008kooooo0_l00004ooooo`;o00005?ooool3o`000;_ooooo0029ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01Oooool00ol0003oooooooooo`0Hooooo`;o0000Woooool008Wooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`0Hooooo`Co00006Oooool2o`0008;ooooo0021ooooo`Ko
00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo01[ooooo1?l0000Cooooo`;o00000_ooool2o`00
08;ooooo0029ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07oooo
o`03ogMgMolb<S;ooooo00Cooooo0ol0000<ooooo`;o00003_ooool2o`0001?ooooo0_l000001?oo
oooo0000o`000?l0000Rooooo`;o0000G_ooool008Wooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oo
oooooooo00_ooooo0ol0000Vooooo`?o00008_ooool2o`0005kooooo0029ooooo`05oa0@4?oooooo
ooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02oooool2o`0002Cooooo0_l00026ooooo`00ROooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0<Oooool2o`0000Cooooo0_l00020ooooo`00ROooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003o
ooooooooo`0Looooo`;o00005?ooool2o`0000?ooooo0_l0000Rooooo`;o0000G?ooool009Oooooo
0_l0000Cooooo`03o`000?oooooooooo01cooooo0ol0000Cooooo`?o00009_ooool2o`0005cooooo
001nooooo`;o00005oooool2o`0001?ooooo00?o0000ooooooooool07?ooool3o`0001Cooooo0_l0
0024ooooo`00O_ooool2o`0002cooooo00?o0000ooooooooool01?ooool2o`0001Sooooo0_l0002I
ooooo`00[?ooool3o`0000Cooooo0_l00008ooooo`;o00003_ooool2o`0009Wooooo002/ooooo`03
o`000?oooooooooo00Cooooo0_l00008ooooo`?o0000Z?ooool009Kooooo0_l0000Dooooo`03o`00
0?oooooooooo00kooooo0ol0000Sooooo`Co0000POooool008cooooo0_l00008ooooo`;o00005?oo
ool00ol0003oooooooooo`0>ooooo`;o00009?ooool5o`00083ooooo002<ooooo`;o00007_ooool0
0ol0003oooooooooo`0dooooo`Go0000P?ooool00:cooooo00?o0000ooooooooool0=?ooool2o`00
08?ooooo0026ooooo`;o00002_ooool2o`0001Sooooo00?o0000ooooooooool0^Oooool008Kooooo
0_l0000:ooooo`;o00006?ooool00ol0003oooooooooo`0hooooo`;o0000Ooooool008cooooo0_l0
000Nooooo`?o0000>?ooool4o`0007gooooo002<ooooo`;o00007_ooool00ol0003oooooooooo`0Q
ooooo`;o00005Oooool4o`0002?ooooo0_l0001Hooooo`00[?ooool01?l0003oooooooooooooool2
o`0000gooooo0_l0000?ooooo`;o00004oooool6o`0002?ooooo0_l0001Hooooo`00[?ooool01?l0
003oooooooooooooool2o`0000gooooo0_l0000?ooooo`;o00004oooool2o`0000;ooooo0_l0001m
ooooo`00[?ooool00ol0003oooooooooo`0@ooooo`?o0000Y_ooool00:cooooo00?o0000oooooooo
ool04?ooool3o`000:Kooooo002Eooooo`;o00005Oooool00ol0003oooooooooo`2iooooo`00UOoo
ool2o`0001Gooooo00?o0000ooooooooool0>_ooool2o`0007gooooo001oooooo`;o00001Oooool2
o`0002Cooooo00?o0000ooooooooool02?ooool2o`00033ooooo0_l0001mooooo`00Ooooool2o`00
00Gooooo0_l0000Tooooo`?o00002?ooool2o`000:oooooo0026ooooo`;o00009?ooool00ol0003o
ooooooooo`1Qooooo`;o0000E_ooool00:cooooo00?o0000ooooooooool08Oooool2o`0001Cooooo
0ol00002ooooo`;o00008oooool2o`0005Kooooo0009ooooo`Co000000?o410@ooooooooool05_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo
00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd05_ooool00ol0003ooooo
ooooo`0Cooooo`;o00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo0_l000000olQ8B7o
ooooooooo`02ooooo`Go00001?ooool01_m4A4Co0000o`000?lb<S;ogMgMooooo`?o00000_ooool2
o`0000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`00
0?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003o
k^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd06?ooool4o`000003oa0@4?oooooooooo
01;ooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@;ooooo0_l000001OnHV9So8B4Qonk^k_ooooooA4A400Oooooo
00?oMgMgoc8b<_ooool05Oooool00ol0003oooooooooo`0Cooooo`;o00000oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omg
MgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnY
ZJWooooo00Oooooo00?oMgMgoc8b<_ooool06Oooool00ol0003oooooooooo`0Dooooo`001_l00005
ooooo`03o`000?oooooooooo013ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003Ooo
ool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?oo
ooooooooooooool@41004?ooool00ol0003oooooooooo`05ooooo`Ko00000_ooool01Ol@413ooooo
oooooooooooo410@00Wooooo0_l000001?ooooooV9RHob4Q8Oo^k^h9ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool04oooool2o`0000?ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool2o`0000Sooooo00Go410@
oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00gooooo00Go410@oooooooooooooooo
oa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool00000
3_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000oooooooooooo
ooooo`00000?ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000=oooo
o`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool05Oooool00ol0003oooooooooo`0Coooo
o`;o00000oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool0
0omgMgOo<S8booooo`04ooooo`;o00002?ooool01Ol0003ooooooooooooooooo000000oooooo00?o
MgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool0
1_ooool00omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oo
oooooooo01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`000008ooooo`;o00001?oo
ool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05_ooool00ol0003ooooo
ooooo`0Hooooo`05o`000?ooooooooooooooool000001_ooool2o`0000Kooooo00?oMgMgofIVI_oo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo0_l00009ooooo`05o`000?oooooooooo
ooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000oooooooooooooooo
o`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Jooooo`03
o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go410@oooooooooooo
oooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool04Oooool01Ol@413o
oooooooooooooooo410@00cooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo
410@00Sooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06?ooool3
o`00017ooooo0_l00005ooooo`05oa0@4?ooooooooooooooool@41001_ooool2o`0000Oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`Co00002?ooool01Ol@413ooooooooo
oooooooo410@00cooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00ko
oooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Co
oooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`06ogMgMonHV9SooooooiRHV?mgMgOooooo
0_l00008ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo00;ooooo0_l0000=ooooo`;o00001Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Oooooo0_l00002ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`05
ooooo`Co00002?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool05?ooool000Wooooo00?oEEEEofIVI_l00000
6_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00004?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`06onk^k_lb<S;o0000oc8b<_o^k^kooooo0_l0
0008ooooo`04oiRHV?l@413o0000ob4Q8@;o00000oooool4o`0001Oooooo00?o0000ooooooooool0
0_ooool2o`0001Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`;o00000_ooool01OnHV9So
410@o`000?lQ8B7oc<c<00Cooooo1?l00007ooooo`;o00001oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0
000Iooooo`03oeEEEOmVIVKo000001Kooooo002<ooooo`;o00007_ooool00ol0003oooooooooo`08
ooooo`;o0000<_ooool2o`0007_ooooo002/ooooo`03o`000?oooooooooo00;ooooo0_l00004oooo
o`?o0000<_ooool2o`0007[ooooo001nooooo`;o00006?ooool2o`0001;ooooo00?o0000oooooooo
ool00_ooool2o`0000Gooooo0_l0000booooo`;o0000Koooool2o`0000;ooooo0_l00005ooooo`00
O_ooool2o`0000_ooooo0_l00007ooooo`;o00000_ooool2o`0001;ooooo00?o0000ooooooooool0
[_ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Gooooo002;ooooo`;o00001oooool2o`0001Ko
oooo00?o0000ooooooooool02Oooool2o`000:Cooooo00CogMgMo`000?l@413oc<c<1_ooool000Oo
ooooool0001<o`0000cooooo00Cok^k^ob4Q8Ol@413ok^k^1_ooool000Oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000ooooool0
003o00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00_ooool2o`000003ooooool0003ooooo00Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00Co8B4QogMgMomgMgOo<S8b1_ooool0
00Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Pooooo`;o00001Oooool00ol0
003oooooooooo`0Booooo`;o00004_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool02Oooool2o`0000;ooooo0_l00005ooooo`00OOooool2o`0002go
oooo00?o0000ooooooooool08_ooool2o`0009Gooooo001mooooo`;o0000;Oooool00ol0003ooooo
ooooo`0Rooooo`;o00006_ooool2o`0007Wooooo002Iooooo`;o00004Oooool00ol0003ooooooooo
o`0nooooo`;o0000NOooool008Gooooo0_l0000Booooo`;o00004Oooool2o`000;[ooooo0025oooo
o`;o00002Oooool2o`0001[ooooo0_l0000Cooooo`;o00003oooool2o`0009Cooooo002@ooooo`;o
00006_ooool3o`0001;ooooo1?l0000=ooooo`;o00005Oooool2o`0007gooooo002/ooooo`03o`00
0?oooooooooo01;ooooo1?l0000=ooooo`;o00005Oooool4o`0007_ooooo002/ooooo`03o`000?oo
oooooooo02?ooooo0_l0000Gooooo`;o0000Noooool008cooooo0ol0000Mooooo`03o`000?oooooo
oooo027ooooo0_l0002Fooooo`00S?ooool3o`0000;ooooo0_l0000Iooooo`03o`000?oooooooooo
027ooooo0_l0002Fooooo`00TOooool2o`0001Wooooo00?o0000ooooooooool08Oooool2o`0001Oo
oooo0ol0001looooo`00Q_ooool2o`0002Cooooo00?o0000ooooooooool08Oooool2o`0001Oooooo
0ol000000ooooooo0000o`00001iooooo`00Q_ooool2o`0000Cooooo0_l0000Nooooo`03o`000?oo
oooooooo00;ooooo0_l0000Mooooo`;o00006oooool2o`0007Wooooo002<ooooo`;o00007_ooool0
0ol0003oooooooooo`02ooooo`;o00007?ooool3o`0009Kooooo002/ooooo`?o00008?ooool2o`00
00;ooooo0_l0000Cooooo`;o0000O_ooool008Kooooo0_l0000Tooooo`03o`000?oooooooooo02Co
oooo0_l0000Cooooo`;o0000O_ooool008Kooooo0_l00005ooooo`;o00007Oooool00ol0003ooooo
ooooo`0Cooooo`;o0000Y?ooool008gooooo0_l0000Mooooo`03o`000?oooooooooo017ooooo1?l0
000<ooooo`;o0000U_ooool00:cooooo00?o0000ooooooooool04Oooool2o`000003ooooool0003o
000000_ooooo0_l0000Jooooo`;o0000N_ooool009[ooooo0_l0000@ooooo`03o`000?oooooooooo
01;ooooo1?l0000Wooooo`;o0000N_ooool009[ooooo0_l0000@ooooo`03o`000?oooooooooo01;o
oooo0_l0000>ooooo`;o00006_ooool2o`0007Wooooo002/ooooo`03o`000?oooooooooo02;ooooo
0_l0000Eooooo`;o00000oooool2o`0007Wooooo002/ooooo`?o00004?ooool2o`0002Oooooo0_l0
00000ooooooo0000o`00001kooooo`00[?ooool00ol0003oooooooooo`0@ooooo`;o0000:_ooool2
o`0007_ooooo002/ooooo`03o`000?oooooooooo03cooooo0_l0001kooooo`00[?ooool00ol0003o
ooooooooo`0Qooooo`;o0000U_ooool00:cooooo00?o0000ooooooooool08Oooool2o`0009Kooooo
0027ooooo`;o00008oooool00ol0003oooooooooo`0Pooooo`;o0000Uoooool008Oooooo0_l0000>
ooooo`;o00004oooool00ol0003oooooooooo`0Pooooo`;o0000Uoooool007kooooo0_l0000Goooo
o`;o00004oooool00ol0003oooooooooo`0mooooo`;o0000N_ooool007kooooo0_l0000=ooooo`;o
00007Oooool3o`00013ooooo0_l0000[ooooo`;o0000N_ooool008gooooo0_l0000Mooooo`03o`00
0?oooooooooo00Kooooo0_l00008ooooo`;o0000Yoooool00:cooooo00?o0000ooooooooool00_l0
0004ooooo`;o0000<Oooool2o`0007kooooo002/ooooo`03o`000?oooooooooo00;o0000=oooool2
o`0007kooooo002/ooooo`03o`000?oooooooooo0;Wooooo001oooooo`;o0000:oooool00ol0003o
ooooooooo`2iooooo`00Ooooool2o`0000Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
00Gooooo0_l0002booooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00;o00000oooool2ob4Q
8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool01Oooool2o`0003Gooooo0_l0001kooooo`00ROooool01Ol@413ooooooooooooooooo
410@00;o00002_ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0000@
ooooo`;o00009?ooool2o`0000Cooooo0_l0001kooooo`00ROooool01Ol0003ooooooooooooooooo
000000Kooooo0_l00005ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`0?ooooo`?o00009?ooool2o`00087ooooo0020ooooo`;o00001oooool01Ol0
003ooooooooooooooooo000000Kooooo0_l00006ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00kooooo0ol0002Xooooo`00P?ooool2
o`0000Gooooo0_l000001Ol@413ooooooooooooooooo410@00_ooooo0_l00002ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooooooo0_l00004ooooo`03o`000?oooooooooo00kooooo
0_l0000[ooooo`;o0000O?ooool008Oooooo0_l000001OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
0_l000000oooooooV9RHoa0@4004ooooo`04o`000?ooooooooooooooo`;o00001?ooool00ol0003o
ooooooooo`0gooooo`?o000000?oooooo`000?l00000O?ooool008Wooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000oooo
ooooool07_ooool2o`0001Oooooo0ol0001oooooo`00Qoooool2o`0000_ooooo0_l0000Fooooo`03
o`000?oooooooooo01cooooo1?l0000Jooooo`;o0000OOooool008Oooooo0_l0000;ooooo`;o0000
5_ooool00ol0003oooooooooo`0Kooooo`?o00007?ooool2o`0007gooooo002/ooooo`03o`000?oo
oooooooo00kooooo0_l0000;ooooo`;o00006?ooool2o`000003ooooool0003o000007oooooo002[
ooooo`Co00003?ooool4o`0000gooooo0_l0000Fooooo`Go0000Ooooool009Gooooo0_l0000Doooo
o`;o00003_ooool2o`0000oooooo0_l0000Gooooo`;o0000POooool009Gooooo0_l0000Eooooo`03
o`000?oooooooooo01[ooooo0_l0002Mooooo`00[?ooool00ol0003oooooooooo`0;ooooo`;o0000
3Oooool2o`0001Wooooo0_l00022ooooo`00R_ooool2o`0001gooooo0_l000000ooooooo0000oooo
o`0<ooooo`?o00003_ooool2o`0001Oooooo0_l00022ooooo`00R_ooool2o`0001gooooo0_l00000
0ooooooo0000ooooo`03ooooo`;o00001oooool3o`0000gooooo0ol0002Kooooo`00[?ooool00ol0
003oooooooooo`02ooooo`;o00001_ooool2o`0000kooooo0ol0002Looooo`00WOooool2o`0000go
oooo00?o0000ooooooooool02_ooool2o`0000gooooo0ol0000Gooooo`;o0000Q?ooool008Wooooo
0_l0000Booooo`;o00002Oooool2o`0000;ooooo0ol0000Iooooo`;o00006?ooool2o`0008Cooooo
0029ooooo`;o00007Oooool2o`0000;ooooo00?o0000ooooooooool0^Oooool0093ooooo0ol0000<
ooooo`;o00002oooool00ol0003oooooooooo`0fooooo`;o0000POooool0087ooooo0_l0000=oooo
o`?o00003?ooool2o`0000Gooooo0_l00004ooooo`03o`000?oooooooooo03Kooooo0_l00021oooo
o`00POooool2o`0001Cooooo0ol0000;ooooo`?o00001?ooool00ol0003oooooooooo`2iooooo`00
Uoooool3o`0000Wooooo1?l00005ooooo`03o`000?oooooooooo00[ooooo0_l0000>ooooo`;o0000
WOooool00:?ooooo0_l00007ooooo`03o`000?oooooooooo00[ooooo0_l0000>ooooo`;o00005ooo
ool2o`0008Cooooo002/ooooo`;o0000<_ooool4o`0008Cooooo002/ooooo`?o00006Oooool2o`00
01Kooooo0_l00026ooooo`00[?ooool3o`0001Wooooo0_l0000Iooooo`;o0000Poooool00:cooooo
00?o0000ooooooooool0=?ooool2o`0008?ooooo002Booooo`;o00006?ooool00ol0003ooooooooo
o`07ooooo`;o0000/?ooool009;ooooo0_l0000Hooooo`03o`000?oooooooooo00Kooooo0ol0002`
ooooo`00[?ooool00ol0003oooooooooo`05ooooo`?o0000/Oooool008_ooooo0_l0000Nooooo`;o
00001oooool3o`000;7ooooo002;ooooo`;o00007Oooool3o`0000Sooooo0_l0000@ooooo`;o0000
Woooool00:[ooooo1Ol00005ooooo`;o00004Oooool2o`0001Gooooo0_l000000ooooooo0000o`00
0025ooooo`00UOooool2o`0000Gooooo0_l0000>ooooo`03o`000?oooooooooo00Gooooo0_l0000X
ooooo`;o000000?oooooo`000?l00000QOooool009Gooooo0_l00005ooooo`;o00003_ooool00ol0
003oooooooooo`04ooooo`;o0000:Oooool2o`000003ooooool0003o000008Gooooo0023ooooo`;o
00009oooool00ol0003oooooooooo`04ooooo`;o0000:_ooool2o`0008Oooooo0023ooooo`;o0000
9oooool00ol0003oooooooooo`03ooooo`?o00003oooool2o`0001Wooooo0_l00027ooooo`00UOoo
ool2o`0000_ooooo0_l00003ooooo`;o00000oooool00ol0003oooooooooo`03ooooo`;o00004?oo
ool2o`000:;ooooo002=ooooo`;o00000_ooool01?o^k^ko<S8bo`000?lb<S82o`0000Cooooo0_lQ
8B45ooooo`Co000000?ogMgMo`000?l000000oooool00ol0003oooooooooo`2iooooo`00SOooool2
o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1Oooool4o`000003oc8b<_oo
oooooooo00?ooooo00?o0000ooooooooool0^Oooool0097ooooo00Go410@oooooooooooooooooa0@
400<ooooo`;o00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;Wooooo002A
ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`?o0000;Ooo
ool2o`0008[ooooo0022ooooo`;o00003Oooool01?l0003oooooooooooooool3o`0000[ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`04o`000?oooooo0000o`0000oooooo0_l0000Kooooo`;o
0000R_ooool008;ooooo0_l0000=ooooo`05oa0@4?ooooooooooooooool@41000_l0000:ooooo`03
o`000?oooooooooo00Oooooo00Co0000ooooool0003o00003oooool2o`000003ooooool0003o0000
01Cooooo0_l0002>ooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0?ooooo`;o00000_ooool2o`0001Cooooo1?l0002<oooo
o`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo0_l00008ooooo`Co00001_ooool00ol0
003oooooooooo`0?ooooo`;o00006_ooool4o`0008[ooooo002Hooooo`;o00004_ooool00ol0003o
ooooooooo`0]ooooo`;o0000R_ooool00:cooooo00Co0000ooooool0003o0000^?ooool009Sooooo
0_l0000Booooo`04o`000?oooooo0000o`0000cooooo0_l0002Zooooo`00V?ooool2o`0001;ooooo
0ol0000=ooooo`;o00006Oooool2o`0008oooooo0024ooooo`;o00009_ooool00ol0003ooooooooo
o`0Xooooo`;o0000Soooool008Cooooo0_l0000Vooooo`03o`000?oooooooooo02[ooooo0_l0002=
ooooo`00Soooool2o`0001_ooooo00?o0000ooooooooool0:_ooool2o`0008gooooo002?ooooo`;o
00006oooool00ol0003oooooooooo`2iooooo`00ZOooool2o`000003ooooool0003ooooo02Kooooo
0_l000001?oooooo0000o`000?l0002>ooooo`00XOooool2o`0000Kooooo0_l000000ooooooo0000
ooooo`0Vooooo`;o000000Coooooo`000?l0003o0000S_ooool008Kooooo0_l0000Iooooo`;o0000
1_ooool2o`000003ooooool0003ooooo02[ooooo0_l0002>ooooo`00Q_ooool2o`00027ooooo0_l0
00001?oooooo0000o`000?l00009ooooo`?o00006Oooool2o`0000;ooooo0_l0002>ooooo`00[?oo
ool00ol0003oooooooooo`09ooooo`?o00006?ooool3o`0009;ooooo002Booooo`;o00006?ooool0
0ol0003oooooooooo`0:ooooo`;o00006?ooool2o`0009?ooooo002Booooo`;o00003?ooool2o`00
00[ooooo00?o0000ooooooooool01oooool2o`000;3ooooo002Pooooo`;o00002_ooool00ol0003o
ooooooooo`07ooooo`;o0000/?ooool00:cooooo00?o0000ooooooooool0^Oooool008Kooooo0_l0
000Tooooo`03o`000?oooooooooo02Cooooo0_l0002Cooooo`00Q_ooool2o`0000[ooooo0_l0000H
ooooo`03o`000?oooooooooo02;ooooo1?l0002Cooooo`00T_ooool2o`0001Sooooo0ol00006oooo
o`;o00006Oooool3o`0009Gooooo002/ooooo`03o`000?oooooooooo00Kooooo0_l0000Iooooo`Co
0000U?ooool00:cooooo00?o0000ooooooooool01?ooool2o`0001Sooooo0_l00003ooooo`;o0000
U?ooool009Gooooo0_l0000Eooooo`03o`000?oooooooooo00Cooooo0_l0000Hooooo`;o0000VOoo
ool009Gooooo0_l0000Eooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
00;o0000]oooool00:cooooo00?o0000ooooooooool00_l0000Iooooo`;o0000W?ooool00:cooooo
00?o0000ooooooooool00oooool2o`0001Kooooo0_l00003ooooo`;o0000Uoooool00:cooooo00?o
0000ooooooooool00oooool2o`0001_ooooo0_l0002Gooooo`00[?ooool3o`000;Wooooo002/oooo
o`Go0000]oooool00:cooooo00?o0000ooooooooool00_l0002gooooo`00VOooool2o`00017ooooo
00?o0000ooooooooool00_l0002gooooo`00VOooool2o`00017ooooo00?o0000ooooooooool07?oo
ool2o`0009_ooooo0029ooooo`05onk^k_lb<S;o0000o`000?o^k^h01Oooool2ob4Q8@Kooooo00?o
0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0
6?ooool2o`0000;ooooo0_l0002Kooooo`00ROooool01OmgMgOoV9RHo`000?l0003oMgMg00Gooooo
0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`0Hooooo`;o0000Woooool008Wooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVY
ZOmEEEGooooo00Sooooo00Co0000oooooooooooooooo0ol0000Fooooo`;o00001?ooool2o`0009go
oooo0029ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03
ogMgMolb<S;ooooo00;ooooo1Ol0000Dooooo`;o00001?ooool2o`0009gooooo0029ooooo`05o`00
0?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`?o000000?o<S8bolc<c?oo
ool01?ooool00ol0003oooooooooo`0Iooooo`;o0000W_ooool008Wooooo00Go410@oooooooooooo
oooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo0_l00008ooooo`03o`000?oooooooooo01Wo
oooo0_l0002Nooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooo
oooooooooc8b<P04ooooo`;o00000_ooool2o`0000Cooooo00?o0000ooooooooool05?ooool2o`00
0:?ooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1_l00004oooo
o`03o`000?oooooooooo01Cooooo0ol0002Rooooo`00[?ooool00ol0003oooooooooo`0Eooooo`;o
0000X_ooool00:cooooo00?o0000ooooooooool0^Oooool008gooooo0_l0000Mooooo`03o`000?oo
oooooooo01Cooooo0_l0002Sooooo`00SOooool2o`0001gooooo0ol0000Cooooo`?o0000Xoooool0
0:cooooo00?o0000ooooooooool04oooool2o`000:Cooooo002/ooooo`03o`000?oooooooooo017o
oooo0_l0002Vooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool04Oooool3o`000:Gooooo
002>ooooo`Co00006_ooool00ol0003oooooooooo`0Aooooo`?o0000YOooool0093ooooo0_l0000J
ooooo`03o`000?oooooooooo017ooooo0ol0002Uooooo`00Soooool2o`0001_ooooo00?o0000oooo
ooooool0^Oooool008oooooo0ol0000Jooooo`03o`000?oooooooooo00_ooooo0_l0002/ooooo`00
T?ooool2o`0001[ooooo0ol0000;ooooo`;o0000[?ooool00:cooooo00?o0000ooooooooool02_oo
ool2o`000:gooooo002/ooooo`03o`000?oooooooooo00[ooooo1?l0002[ooooo`00[?ooool00ol0
003oooooooooo`08ooooo`;o00000_ooool2o`000:_ooooo002Aooooo`Co00005oooool00ol0003o
ooooooooo`08ooooo`;o0000[oooool0097ooooo1Ol0000Fooooo`03o`000?oooooooooo0;Wooooo
002Dooooo`;o00005_ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`03
ooooo`;o0000]?ooool00:cooooo00?o0000ooooooooool00oooool2o`000;Cooooo002Fooooo`;o
00005?ooool3o`0000Kooooo0_l0002aooooo`00U_ooool2o`0001Cooooo00?o0000ooooooooool0
1Oooool3o`000;7ooooo002Fooooo`;o00005?ooool00ol0003oooooooooo`05ooooo`;o0000/_oo
ool00:cooooo00Co0000ooooool0003o00001?ooool2o`000;;ooooo002/ooooo`04o`000?oooooo
0000o`000;Sooooo002/ooooo`03o`000?oooooo000000?o0000]_ooool00:cooooo00?o0000oooo
ool000000ol0002fooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo
002Nooooo`;o00003?ooool00ol0003oooooooooo`2iooooo`00VOooool2o`0000?ooooo0_l0000<
ooooo`;o0000^_ooool009Wooooo0_l0000Aooooo`;o0000^_ooool00:Oooooo0_l00002ooooo`;o
0000^oooool00:;ooooo0_l00002ooooo`Oo0000^oooool00:;ooooo2Ol000000ooooooo0000oooo
o`2jooooo`00X_ooool5o`000003ooooool0003o000000;ooooo00?o0000ooooooooool0^Oooool0
0:;ooooo1Ol000000ooooooo0000o`000002ooooo`?o0000^Oooool00:Cooooo00Co0000oooooooo
oooooooo0_l0002nooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003ooooo
ooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00X_ooool00omEEEGoIVIVo`000033
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Z_ooool0
1?l@413o0000o`000?l0002jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0
003oooooooooo`2jooooo`00Zoooool01_l0003oMgMgo`000?l0003oEEEEonk^k[Oooooo002[oooo
o`06o`000?mEEEGok^k^oooooomgMgOoEEEE]oooool00:_ooooo00?o0000onk^k_ooool00_ooool0
0ol0003oooooooooo`2eooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo
0;Gooooo002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoIVIV]oooool00:[ooooo00?o410@o`00
0?mgMgL00_l000000omVIVKok^k^ooooo`2fooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.50365 .87699 Mdot
.42191 .83535 Mdot
.50436 .45911 Mdot
.4488 .72411 Mdot
.51591 .76858 Mdot
.60484 .67423 Mdot
.49356 .34765 Mdot
.69964 .67407 Mdot
.69377 .63093 Mdot
.4924 .23339 Mdot
.55126 .3676 Mdot
.6586 .76665 Mdot
.38449 .36461 Mdot
.51413 .26558 Mdot
.60138 .85091 Mdot
.4159 .49052 Mdot
.58652 .33872 Mdot
.38626 .34062 Mdot
.57485 .57015 Mdot
.59069 .18417 Mdot
.42009 .15496 Mdot
.38263 .51532 Mdot
.40086 .2556 Mdot
.40031 .23279 Mdot
.56289 .91082 Mdot
.40188 .57941 Mdot
.56854 .46948 Mdot
.56892 .59255 Mdot
.61822 .23052 Mdot
.39833 .7228 Mdot
.48536 .08075 Mdot
.70303 .60133 Mdot
.68777 .68735 Mdot
.61399 .45903 Mdot
.62404 .49041 Mdot
.60543 .22916 Mdot
.69516 .43761 Mdot
.57109 .55572 Mdot
.65686 .32311 Mdot
.66779 .7563 Mdot
.60123 .86701 Mdot
.61945 .4664 Mdot
.61838 .6008 Mdot
.52493 .85433 Mdot
.55547 .80093 Mdot
.45901 .81811 Mdot
.53407 .32249 Mdot
.71054 .52411 Mdot
.44354 .18395 Mdot
.63516 .2731 Mdot
.70856 .53313 Mdot
.66481 .32795 Mdot
.56114 .03013 Mdot
.61944 .57402 Mdot
.62737 .53532 Mdot
.68885 .66529 Mdot
.69065 .69641 Mdot
.57731 .3092 Mdot
.70544 .48209 Mdot
.56492 .78307 Mdot
.43446 .77095 Mdot
.44173 .99035 Mdot
.66478 .35108 Mdot
.54456 .49897 Mdot
.65643 .74601 Mdot
.7014 .62054 Mdot
.4946 .23875 Mdot
.41816 .44736 Mdot
.57539 .52448 Mdot
.42771 .12789 Mdot
.56971 .27889 Mdot
.52212 .47994 Mdot
.51299 .27495 Mdot
.4601 .23549 Mdot
.66482 .35144 Mdot
.48559 .63868 Mdot
.562 .03108 Mdot
.40235 .49044 Mdot
.65444 .30249 Mdot
.48931 .17037 Mdot
.54718 .14756 Mdot
.3958 .70099 Mdot
.45452 .73175 Mdot
.62053 .46257 Mdot
.70441 .64551 Mdot
.41788 .58517 Mdot
.51131 .77811 Mdot
.45131 .79851 Mdot
.55443 .25676 Mdot
.42041 .41201 Mdot
.54869 .92701 Mdot
.40759 .06587 Mdot
.54183 .57789 Mdot
.47008 .82171 Mdot
.54193 .5665 Mdot
.37556 .21426 Mdot
.51135 .26069 Mdot
.70113 .57579 Mdot
.56946 .03743 Mdot
.54188 .22819 Mdot
.47597 .899 Mdot
.52109 .1972 Mdot
.6433 .78974 Mdot
.49833 .89072 Mdot
.4889 .07429 Mdot
.61596 .47223 Mdot
.58822 .32643 Mdot
.57199 .5985 Mdot
.54192 .57837 Mdot
.4427 .09817 Mdot
.49736 .23574 Mdot
.46901 .7529 Mdot
.70146 .60413 Mdot
.57928 .17525 Mdot
.69085 .17472 Mdot
.43478 .61026 Mdot
.4129 .67123 Mdot
.71195 .59697 Mdot
.71017 .59091 Mdot
.69418 .47145 Mdot
.38805 .32683 Mdot
.43831 .11766 Mdot
.61563 .22309 Mdot
.43624 .10893 Mdot
.43089 .65951 Mdot
.59954 .20776 Mdot
.36176 .3587 Mdot
.40577 .75416 Mdot
.45229 .31195 Mdot
.38731 .3659 Mdot
.44388 .8755 Mdot
.63585 .80785 Mdot
.61235 .65856 Mdot
.61412 .62891 Mdot
.63571 .25852 Mdot
.6851 .37066 Mdot
.61416 .22862 Mdot
.51296 .27597 Mdot
.66866 .73283 Mdot
.60816 .84375 Mdot
.36725 .6776 Mdot
.51658 .68414 Mdot
.57684 .53427 Mdot
.58523 .33371 Mdot
.58205 .17435 Mdot
.70786 .62666 Mdot
.72948 .22853 Mdot
.53715 .70297 Mdot
.44504 .78921 Mdot
.55447 .94233 Mdot
.50537 .1725 Mdot
.57214 .44899 Mdot
.3964 .25394 Mdot
.51966 .45033 Mdot
.56073 .77428 Mdot
.6827 .37733 Mdot
.6642 .34023 Mdot
.70578 .61706 Mdot
.69566 .45261 Mdot
.6832 .37534 Mdot
.40354 .3817 Mdot
.64914 .28641 Mdot
.64978 .80188 Mdot
.59152 .21066 Mdot
.60631 .63965 Mdot
.4599 .89 Mdot
.70652 .62736 Mdot
.49779 .07947 Mdot
.57496 .51825 Mdot
.67551 .34169 Mdot
.6321 .27566 Mdot
.51303 .68154 Mdot
.57266 .51463 Mdot
.4865 .81099 Mdot
.54053 .69991 Mdot
.67201 .72042 Mdot
.37162 .24617 Mdot
.56068 .77292 Mdot
.42931 .52437 Mdot
.63539 .26752 Mdot
.6642 .31315 Mdot
.64966 .79132 Mdot
.42554 .3427 Mdot
.59619 .875 Mdot
.4902 .29062 Mdot
.68843 .64193 Mdot
.36527 .31561 Mdot
.71138 .56489 Mdot
.64934 .80033 Mdot
.6202 .60221 Mdot
.52033 .97477 Mdot
.57891 .169 Mdot
.5411 .46522 Mdot
.4364 .97893 Mdot
.7004 .6637 Mdot
.59537 .88312 Mdot
.64184 .79512 Mdot
.47374 .82045 Mdot
.41809 .02979 Mdot
.59954 .35075 Mdot
.43987 .62556 Mdot
.43758 .61285 Mdot
.52295 .50262 Mdot
.50015 .79271 Mdot
.44666 .87733 Mdot
.52924 .40286 Mdot
.59322 .70649 Mdot
.4918 .7453 Mdot
.49417 .29002 Mdot
.54966 .35697 Mdot
.38064 .52912 Mdot
.4029 .54041 Mdot
.50125 .08358 Mdot
.42907 .3293 Mdot
.45099 .88117 Mdot
.40427 .56382 Mdot
.64243 .81319 Mdot
.47514 .27642 Mdot
.54532 .80905 Mdot
.68005 .73017 Mdot
.41828 .70517 Mdot
.70283 .52606 Mdot
.48029 .06825 Mdot
.57027 .181 Mdot
.43132 .32525 Mdot
.53377 .72649 Mdot
.45647 .90347 Mdot
.5255 .64533 Mdot
.60202 .85062 Mdot
.50211 .9986 Mdot
.42232 .61467 Mdot
.44055 .44234 Mdot
.51112 .19016 Mdot
.56598 .43092 Mdot
.49751 .99843 Mdot
.57291 .5295 Mdot
.48872 .90126 Mdot
.40961 .19995 Mdot
.45531 .89031 Mdot
.43223 .97445 Mdot
.61903 .62314 Mdot
.5157 .09683 Mdot
.5694 .27843 Mdot
.70908 .5813 Mdot
.53911 .5758 Mdot
.68528 .40669 Mdot
.56873 .30241 Mdot
.56649 .27226 Mdot
.66272 .34024 Mdot
.59255 .88473 Mdot
.43496 .61012 Mdot
.54122 .49673 Mdot
.69009 .43545 Mdot
.40149 .44101 Mdot
.57208 .51203 Mdot
.6316 .52133 Mdot
.48003 .64631 Mdot
.68394 .70649 Mdot
.70891 .50219 Mdot
.47441 .15367 Mdot
.56561 .42815 Mdot
.57623 .18821 Mdot
.43314 .40142 Mdot
.51512 .1906 Mdot
.50577 .87056 Mdot
.54578 .36005 Mdot
.59072 .69844 Mdot
.62072 .25674 Mdot
.42038 .2713 Mdot
.59761 .20922 Mdot
.62863 .53761 Mdot
.47861 .22125 Mdot
.48125 .16026 Mdot
.67961 .36342 Mdot
.42403 .34904 Mdot
.56293 .64853 Mdot
.70757 .55041 Mdot
.53956 .32354 Mdot
.57734 .74325 Mdot
.6404 .27449 Mdot
.43484 .37349 Mdot
.45976 .24043 Mdot
.69564 .46124 Mdot
.65556 .76734 Mdot
.57249 .5989 Mdot
.51186 .40725 Mdot
.49712 .79001 Mdot
.54878 .1319 Mdot
.44432 .79045 Mdot
.53938 .13913 Mdot
.36798 .28784 Mdot
.7032 .49413 Mdot
.62345 .81695 Mdot
.70077 .52285 Mdot
.4551 .35316 Mdot
.70201 .44161 Mdot
.43181 .96707 Mdot
.52512 .10283 Mdot
.60775 .84097 Mdot
.7462 .25451 Mdot
.45531 .17034 Mdot
.63089 .55855 Mdot
.44862 .88452 Mdot
.70654 .59062 Mdot
.58877 .88001 Mdot
.5364 .32574 Mdot
.70517 .56007 Mdot
.40229 .41774 Mdot
.45943 .68472 Mdot
.38115 .46808 Mdot
.58983 .34548 Mdot
.39039 .30971 Mdot
.56012 .93408 Mdot
.42853 .5343 Mdot
.5309 .83255 Mdot
.61698 .46903 Mdot
.65036 .76036 Mdot
.4293 .43579 Mdot
.64138 .80465 Mdot
.48794 .99783 Mdot
.36965 .71766 Mdot
.42207 .60182 Mdot
.6178 .64518 Mdot
.62085 .45271 Mdot
.67223 .37196 Mdot
.54464 .70508 Mdot
.46294 .69571 Mdot
.47461 .32771 Mdot
.58477 .32018 Mdot
.68851 .70819 Mdot
.68967 .44745 Mdot
.54432 .54843 Mdot
.38177 .542 Mdot
.45101 .31286 Mdot
.52275 .51204 Mdot
.44932 .89565 Mdot
.61153 .65379 Mdot
.60658 .63934 Mdot
.40484 .36799 Mdot
.50251 .78713 Mdot
.40982 .33883 Mdot
.39495 .68721 Mdot
.54335 .52372 Mdot
.68474 .68554 Mdot
.56721 .46124 Mdot
.6123 .22727 Mdot
.38401 .51618 Mdot
.53485 .62222 Mdot
.41027 .63427 Mdot
.37032 .71199 Mdot
.66763 .75065 Mdot
.70049 .4209 Mdot
.60723 .22995 Mdot
.43225 .21699 Mdot
.6031 .3711 Mdot
.62427 .25836 Mdot
.51161 .1877 Mdot
.66566 .75372 Mdot
.37811 .79139 Mdot
.52034 .10195 Mdot
.63377 .80997 Mdot
.63679 .81252 Mdot
.6195 .84618 Mdot
.52017 .5611 Mdot
.49726 .17028 Mdot
.60168 .85241 Mdot
.6885 .6985 Mdot
.51885 .57374 Mdot
.51349 .1058 Mdot
.42534 .25566 Mdot
.60089 .69099 Mdot
.48332 .89672 Mdot
.6993 .59141 Mdot
.48665 .902 Mdot
.69879 .44792 Mdot
.68418 .42379 Mdot
.39901 .26909 Mdot
.69569 .3975 Mdot
.38828 .3581 Mdot
.58023 .88737 Mdot
.7025 .18775 Mdot
.69593 .49618 Mdot
.56847 .76397 Mdot
.51975 .46851 Mdot
.52684 .95891 Mdot
.54172 .23106 Mdot
.47057 .32958 Mdot
.65384 .78683 Mdot
.43148 .11854 Mdot
.47177 .70306 Mdot
.47326 .22655 Mdot
.40434 .60229 Mdot
.56891 .45213 Mdot
.71176 .52748 Mdot
.45988 .06919 Mdot
.42981 .96556 Mdot
.64748 .79584 Mdot
.60384 .39157 Mdot
.52942 .00171 Mdot
.60475 .38608 Mdot
.54673 .68411 Mdot
.54863 .68552 Mdot
.44597 .59392 Mdot
.68541 .71177 Mdot
.6587 .76557 Mdot
.56795 .46224 Mdot
.52531 .65175 Mdot
.5554 .3632 Mdot
.41453 .48923 Mdot
.56911 .91932 Mdot
.48935 .81671 Mdot
.58056 .19045 Mdot
.49517 .733 Mdot
.57332 .46506 Mdot
.43531 .38099 Mdot
.49741 .80433 Mdot
.61188 .44578 Mdot
.56735 .42334 Mdot
.53225 .41677 Mdot
.52431 .97407 Mdot
.67208 .72582 Mdot
.4744 .37567 Mdot
.62505 .50021 Mdot
.58884 .32849 Mdot
.5284 .82815 Mdot
.43502 .22103 Mdot
.57406 .50809 Mdot
.53855 .94804 Mdot
.376 .20477 Mdot
.46235 .90133 Mdot
.65996 .13579 Mdot
.52323 .85891 Mdot
.534 .41761 Mdot
.68026 .67196 Mdot
.59343 .86411 Mdot
.55831 .39963 Mdot
.38464 .46015 Mdot
.53571 .00434 Mdot
.51877 .67231 Mdot
.48312 .69758 Mdot
.52777 .73023 Mdot
.56644 .17185 Mdot
.46381 .16826 Mdot
.41341 .04493 Mdot
.49588 .29756 Mdot
.61993 .55358 Mdot
.6178 .43917 Mdot
.54588 .51819 Mdot
.42837 .49867 Mdot
.43688 .28529 Mdot
.69744 .67939 Mdot
.42756 .52581 Mdot
.64531 .28067 Mdot
.44062 .87937 Mdot
.5406 .82157 Mdot
.5967 .20497 Mdot
.5287 .12691 Mdot
.59599 .3619 Mdot
.35694 .48619 Mdot
.47654 .22558 Mdot
.68793 .71068 Mdot
.60065 .87508 Mdot
.54936 .37533 Mdot
.70157 .43259 Mdot
.42827 .2409 Mdot
.58653 .34739 Mdot
.60828 .21975 Mdot
.48263 .89843 Mdot
.5706 .59624 Mdot
.41094 .64185 Mdot
.61302 .44168 Mdot
.60555 .65242 Mdot
.49604 .61382 Mdot
.61445 .60893 Mdot
.4837 .1649 Mdot
.52335 .53037 Mdot
.41762 .5103 Mdot
.62121 .56144 Mdot
.62145 .6009 Mdot
.43758 .62062 Mdot
.40157 .45406 Mdot
.70061 .62418 Mdot
.52842 .74502 Mdot
.51324 .85862 Mdot
.57851 .49079 Mdot
.55851 .63123 Mdot
.51096 .62006 Mdot
.67566 .15146 Mdot
.50398 .64623 Mdot
.43504 .87059 Mdot
.69831 .55659 Mdot
.58999 .20625 Mdot
.57523 .53649 Mdot
.62311 .24431 Mdot
.65301 .78253 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`Co0000[oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`06ooooo`Co0000[oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo002Roooo
o`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00TOooool2o`0001Wooooo00?o0000ooooooooool04Oooool2o`00
0:Kooooo002Aooooo`;o00006Oooool00ol0003oooooooooo`0Aooooo`;o0000Y_ooool00:cooooo
00?o0000ooooooooool04oooool2o`000:Cooooo002/ooooo`03o`000?oooooooooo01?ooooo0_l0
002Tooooo`00[?ooool00ol0003oooooooooo`2iooooo`00Soooool2o`0001_ooooo00?o0000oooo
ooooool0^Oooool008oooooo0_l0000Kooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000
^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool008gooooo
0_l0000Fooooo`;o00001Oooool00ol0003oooooooooo`2iooooo`00SOooool2o`0000oooooo0_l0
0005ooooo`;o00001Oooool00ol0003oooooooooo`2iooooo`00W_ooool2o`0000Sooooo0_l00002
ooooo`03o`000?oooooooooo0;Wooooo002Xooooo`;o00000_ooool3o`000;Wooooo002[ooooo`;o
0000^oooool00:Oooooo0_l00002ooooo`;o0000^oooool00:Oooooo0_l00003ooooo`;o0000^_oo
ool00:cooooo0_l0002jooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00VOooool2o`00017ooooo00?o0000ooooooooool00_ooool2o`000;Gooooo
002Iooooo`;o00004Oooool3o`0000;ooooo0_l0002eooooo`00[?ooool00ol0003oooooooooo`03
ooooo`Co0000/_ooool00:cooooo00Co0000oooooooooooooooo1_l0002booooo`00Uoooool2o`00
01?ooooo00Co0000oooooooooooooooo0_l0002fooooo`00Uoooool2o`0001?ooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool008Wooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?l00002ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Co00000_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0^Oooool0087ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002ioooo
o`00ROooool01Ol0003ooooooooooooooooo000000Kooooo0_l00006ooooo`03ob4Q8Ooooooooooo
00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`06ooooo`;o0000/Oooool008Wo
oooo00Go0000ooooooooooooooooo`000006ooooo`;o00001_ooool00omEEEGoc<c<ooooo`03oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`06ooooo`;o00001Oooool2
o`000:[ooooo0029ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03Oooool2o`000:[ooooo0029oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0aooooo`;o0000Q_ooool008Wooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool02_oo
ool2o`0002Gooooo0_l00026ooooo`00[?ooool00ol0003oooooooooo`0:ooooo`;o0000[Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool03?ooool2o`000:_o
oooo002/ooooo`?o00003?ooool2o`0002Wooooo0_l00020ooooo`00TOooool2o`00013ooooo0_l0
0007ooooo`03o`000?oooooooooo03Oooooo0_l00020ooooo`00TOooool2o`00013ooooo0_l00007
ooooo`03o`000?oooooooooo0;Wooooo002Uooooo`;o00001Oooool00ol0003oooooooooo`2ioooo
o`00YOooool3o`0000Cooooo00?o0000ooooooooool0^Oooool00:3ooooo0_l00004ooooo`;o0000
1?ooool00ol0003oooooooooo`2iooooo`00WOooool2o`000003ooooool0003o000000Kooooo0_l0
00000ooooooo0000o`00000Iooooo`;o0000X?ooool009gooooo0_l00009ooooo`;o000000?ooooo
o`000?l000000_l0000Booooo`;o00000oooool3o`0009oooooo002/ooooo`?o00004_ooool2o`00
00?ooooo0ol0000Rooooo`;o0000Noooool00:cooooo00?o0000ooooooooool05oooool2o`0002?o
oooo0_l0001kooooo`00[?ooool00ol0003oooooooooo`0Dooooo`;o0000Xoooool009Wooooo0_l0
000Aooooo`03o`000?oooooooooo01Cooooo0_l00005ooooo`;o0000W?ooool009Wooooo0_l0000A
ooooo`03o`000?oooooooooo00;o00005?ooool2o`0000?ooooo0_l0000Rooooo`;o0000N?ooool0
0:cooooo00?o0000ooooooooool01?l0000Booooo`?o00009_ooool2o`0007Sooooo002/ooooo`03
o`000?oooooooooo00Co00004oooool2o`000:3ooooo002/ooooo`03o`000?oooooooooo00Cooooo
0_l0002cooooo`00S_ooool2o`0001cooooo0ol00004ooooo`;o0000/oooool008kooooo0_l0000L
ooooo`03o`000?oooooooooo0;Wooooo0023ooooo`;o00009oooool00ol0003oooooooooo`0Joooo
o`Co0000Voooool008?ooooo0_l0000Wooooo`03o`000?oooooooooo01[ooooo1Ol0002Jooooo`00
[?ooool00ol0003oooooooooo`0Kooooo`Co0000V_ooool008;ooooo0_l0000Xooooo`03o`000?oo
oooooooo0;Wooooo0022ooooo`;o00004Oooool2o`0001Gooooo00?o0000ooooooooool08?ooool2
o`0009Oooooo002Eooooo`?o00003Oooool2o`0000Gooooo00?o0000ooooooooool08?ooool2o`00
09Oooooo002Fooooo`;o00003?ooool3o`0000Gooooo0ol0000Sooooo`;o0000U?ooool00:?ooooo
0ol00006ooooo`03o`000?oooooooooo00[ooooo0_l0000Fooooo`?o00008oooool2o`0006oooooo
002Sooooo`;o00001oooool00ol0003oooooooooo`0:ooooo`;o00004oooool7o`0002;ooooo0_l0
001_ooooo`00Roooool2o`0001cooooo0_l000000ooooooo0000ooooo`0;ooooo`;o00004oooool3
o`0000;ooooo0_l0002Cooooo`00Roooool2o`00017ooooo0_l00009ooooo`Co0000^oooool009Co
oooo0_l00008ooooo`;o00002_ooool3o`000;_ooooo002Aooooo`03onk^k_lb<S;o000000;o0000
1Oooool2ob4Q8@03ooooool0003o000000;ooooo00GoA4A4o`000?l0003o<S8bomgMg@03ooooo`?o
0000^oooool0087ooooo0_l0000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Uooooo`;o0000T_ooool0087ooooo
0_l00006ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Uooooo`;o0000T_ooool0097ooooo00Go0000oooooooooooo
ooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002iooooo`00ROooool4o`0000Cooooo
00?o0000ooooool000000_l0000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003o
ooooooooo`1>ooooo`;o0000JOooool008Wooooo1?l00004ooooo`05oa0@4?oooooo0000o`000?l@
41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo0_l0000Cooooo`Co
000000?oooooo`000?l000008oooool2o`0006Wooooo002Aooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;o00003Oooool2o`0001?o
oooo1?l000000ooooooo0000o`00002>ooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo1?l00006ooooo`03o`000?oooooooooo00;o0000]oooool00:cooooo00Co0000oooooooooooo
oooo0_l0000Vooooo`;o0000S_ooool008[ooooo0_l00005ooooo`;o00006Oooool01?l0003ooooo
ooooooooool2o`0002Kooooo0_l0002>ooooo`00R_ooool2o`0000Gooooo0_l0000Iooooo`03o`00
0?oooooooooo01?ooooo0_l0000Dooooo`;o0000S_ooool00:?ooooo0_l00007ooooo`?o000000?o
ooooo`000?l000004?ooool2o`0001?ooooo1Ol0002<ooooo`00Xoooool2o`0000Oooooo00Co0000
oooooooooooooooo0_l0000@ooooo`?o00004_ooool2o`000003ooooool0003o000008cooooo002/
ooooo`03o`000?oooooooooo01?ooooo0ol0000Gooooo`;o0000R_ooool009Oooooo0_l0000Coooo
o`03o`000?oooooooooo02gooooo0ol00029ooooo`00P?ooool2o`0001Gooooo0_l0000Cooooo`03
o`000?oooooooooo02kooooo0_l00029ooooo`00P?ooool2o`0002Kooooo1Ol0002kooooo`00Z?oo
ool5o`000;_ooooo002Zooooo`?o0000^oooool00:[ooooo1Ol0002iooooo`00[?ooool00ol0003o
ooooooooo`0Cooooo`;o00006oooool2o`0008Oooooo002/ooooo`03o`000?oooooooooo01?ooooo
0_l0000Kooooo`;o0000Qoooool008Oooooo0_l0000Sooooo`03o`000?oooooooooo01Kooooo0_l0
002Qooooo`00Qoooool2o`0001;ooooo0ol0000>ooooo`03o`000?oooooooooo01Kooooo0_l0000K
ooooo`;o0000Q?ooool007oooooo0_l0000Jooooo`?o00003_ooool00ol0003oooooooooo`0coooo
o`;o0000Q?ooool007oooooo0_l0000[ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo00Sooooo0_l0000?ooooo`;o0000W_ooool009Gooooo0_l0000Eooooo`?o00002?oo
ool4o`0000gooooo0_l0000Eooooo`;o0000Qoooool008Oooooo0_l0000<ooooo`;o00003?ooool2
o`0000Oooooo00?o0000ooooooooool02Oooool3o`0000kooooo0_l0000Dooooo`;o000000?ooooo
o`000?l00000Q?ooool008Oooooo0_l0000;ooooo`;o00003?ooool3o`0000Oooooo00?o0000oooo
ooooool06_ooool2o`0001Oooooo0_l00024ooooo`00U?ooool2o`0000cooooo0_l00008ooooo`03
o`000?oooooooooo01Wooooo0_l0002Nooooo`00[?ooool00ol0003oooooooooo`0Iooooo`;o0000
W_ooool008Kooooo0_l00006ooooo`;o00007?ooool00ol0003oooooooooo`0Iooooo`;o00005ooo
ool3o`0008Cooooo0026ooooo`;o00001_ooool2o`0000?ooooo0_l0000Gooooo`03o`000?oooooo
oooo01Wooooo0_l0000Gooooo`?o00000_ooool2o`00083ooooo002Cooooo`;o00005oooool00ol0
003oooooooooo`0Jooooo`;o00006oooool2o`00083ooooo002Booooo`;o00005Oooool2o`000003
ooooool0003ooooo01[ooooo0ol0002Mooooo`00T_ooool2o`0001Gooooo0_l000001?oooooo0000
o`000?l0000Iooooo`;o00000_ooool2o`0001Cooooo0_l00024ooooo`00WOooool2o`0000gooooo
00?o0000ooooooooool07Oooool2o`0001Cooooo0_l00024ooooo`00O_ooool2o`0000Oooooo0_l0
000Dooooo`;o00003Oooool00ol0003oooooooooo`0=ooooo`;o0000Z_ooool007kooooo0_l00007
ooooo`;o00008oooool00ol0003oooooooooo`0<ooooo`?o00003Oooool2o`0009_ooooo0025oooo
o`;o00009Oooool00ol0003oooooooooo`0<ooooo`;o000000?oooooo`000?l000002oooool2o`00
01[ooooo0_l0001oooooo`00QOooool3o`000003ooooooo^k^ko<S8b00?o00001Oooool2ob4Q8@Co
oooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0=oooo
o`Co00009oooool2o`0007oooooo0026ooooo`;o000000CoooooogMgMonHV9Sooooo0_l00005oooo
o`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`0=ooooo`;o00004?ooool2o`0001Wooooo0_l0001mooooo`00POooool6o`00
00;ooooo00Go410@oooooooooooooooooa0@4008ooooo`;o00000_ooool00onHV9So8B4Qonk^kP09
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool07oooool2o`0001Cooooo0_l00003
ooooo`;o0000OOooool008Wooooo00Go0000ooooooooooooooooo`000008ooooo`;o00000oooool0
0onHV9So8B4Qonk^kP05ooooo`;o000000?oMgMgoc8b<_ooool01?ooool3o`0000gooooo0_l0000V
ooooo`;o00000_ooool2o`0007kooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool0
0omgMgOoIVIVooooo`03ooooo`?o000000?o<S8bolc<c?ooool01?ooool00ol0003oooooooooo`0=
ooooo`;o0000:_ooool2o`0007kooooo0029ooooo`03oa0@4?oooooooooo00;o00002?ooool2o`00
00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
03Wooooo0_l0001nooooo`00ROooool00omgMgOoV9RHooooo`02o`0000Sooooo0_l000001_oooooo
0000okZj^_ooooooV9RHoa0@40Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0O
ooooo`;o0000V?ooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool07oooool2o`0009Sooooo002/
ooooo`03o`000?oooooooooo01oooooo0_l0002Hooooo`00[?ooool00ol0003oooooooooo`0Ooooo
o`;o0000V?ooool00:cooooo00?o0000ooooooooool0?Oooool2o`0007[ooooo002Eooooo`;o0000
5Oooool3o`00013ooooo0_l0000[ooooo`;o0000N_ooool009Gooooo0_l0000Eooooo`03o`000?oo
oooooooo00Kooooo0_l00008ooooo`;o0000Yoooool00:cooooo00?o0000ooooooooool00_l00004
ooooo`;o0000<_ooool2o`0007gooooo002/ooooo`03o`000?oooooooooo00;o0000>?ooool2o`00
07gooooo002Aooooo`;o00006Oooool00ol0003oooooooooo`2iooooo`00TOooool2o`0001Wooooo
00?o0000ooooooooool0^Oooool008_ooooo0_l0000Oooooo`03o`000?oooooooooo00Oooooo0ol0
002_ooooo`00Roooool2o`0001oooooo00?o0000ooooooooool01oooool3o`0003Gooooo0_l0001h
ooooo`00[?ooool3o`0001?ooooo0_l0000Tooooo`;o00001?ooool2o`0007Sooooo002/ooooo`03
o`000?oooooooooo01;ooooo0ol0000Tooooo`;o0000O_ooool00:cooooo00?o0000ooooooooool0
4_ooool2o`000:Gooooo002/ooooo`03o`000?oooooooooo01;ooooo0_l0000[ooooo`;o0000N?oo
ool009Cooooo0_l0000Fooooo`03o`000?oooooooooo03_ooooo1_l0001hooooo`00U?ooool2o`00
01Kooooo00?o0000ooooooooool08oooool2o`0001Kooooo1?l0001jooooo`00Roooool2o`0000_o
oooo0_l0000Booooo`03o`000?oooooooooo02;ooooo0ol0000Jooooo`;o0000N?ooool008_ooooo
0_l0000;ooooo`;o00004_ooool00ol0003oooooooooo`0Qooooo`?o00006oooool2o`0007Sooooo
002Aooooo`;o00006Oooool00ol0003oooooooooo`0Dooooo`;o00002oooool2o`0001Sooooo0_l0
00000ooooooo0000o`00001iooooo`00TOooool2o`0001Wooooo0ol00003ooooo`;o00003_ooool3
o`0000kooooo0_l0000Eooooo`Go0000NOooool008_ooooo0_l0000Oooooo`03o`000?oooooooooo
00?ooooo0_l0000>ooooo`;o00003oooool2o`0001Oooooo0_l0001jooooo`00Roooool2o`0001oo
oooo0ol0000Rooooo`;o0000UOooool000Wooooo1?l000000ol@413oooooooooo`0Fooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool0
1Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
00Coooooo`000?l0003ooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd05_ooool3o`00
01?ooooo0_l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2o`0000Cooooo1Ol00004
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01oooool2o`0000Kooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000
oc8b<_oMgMd06?ooool4o`000003oa0@4?oooooooooo01;ooooo000;ooooo`03o`000?oooooooooo
01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07
ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@09oooo
ool0003o0000oooooonHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool05Oooool0
0ol0003oooooooooo`0Cooooo`Co000000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q
0_l00002ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`06ooooo`;o
00001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07
ooooo`03ogMgMolb<S;ooooo01Wooooo00?o0000ooooooooool05?ooool000Ko00001Oooool00ol0
003oooooooooo`0@ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVY
oeEEEOooool02?ooool00ol0003oooooooooo`05ooooo`Ko00000_ooool01Ol@413ooooooooooooo
oooo410@013ooooo00?o0000ooooooooool01Oooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@4007ooooo`;o00000oooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool02_ooool2o`0000Oooooo1?l000000ooooooo410@ooooo`02ooooo`03oa0@
4?oooooooooo00Gooooo0_l00003ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool0
3Oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool03Oooool01Ol@413o
oooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool03_ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooo
oooo000000Oooooo0_l00004ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool05Ooo
ool00ol0003oooooooooo`03ooooo`;o00001Oooool2o`0000Oooooo0_l00003ooooo`05o`000?oo
ooooooooooooool000001_ooool3o`0000Cooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8b
ooooo`0>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0>ooooo`05
o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo
01Wooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol0003o
oooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
3oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<01Kooooo00?o0000ooooooooool00oooool2o`0000kooooo0_l00003oooo
o`05o`000?ooooooooooooooool000001_ooool2o`0000Kooooo00?oMgMgofIVI_ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Oooooo0_l00006ooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000>oooo
o`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Jooooo`03o`000?oooooo
oooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go410@oooooooooooooooooa0@400>
ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Hooooo`?o00006?ooool01Ol@413ooooo
oooooooooooo410@00Kooooo0_l00007ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool02Oooool2o`0000Kooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo
017ooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hoooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool0
4Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01?ooool2o`0001;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooooooo
o`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0Dooooo`002Oooool00omEEEGoIVIVo`00000Jooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000@ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`01?ooool4o`0001Oooooo00?o0000ooooooooool01?ooool2o`0001;ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`00
00_ooooo0_l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00013ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0001Wooooo00?oEEEEofIVI_l000005_oo
ool007cooooo0_l0000^ooooo`03o`000?oooooooooo043ooooo0_l0001gooooo`00O?ooool2o`00
017ooooo0_l0000Kooooo`03o`000?oooooooooo0;Wooooo002;ooooo`;o00000_ooool3o`0001[o
oooo00?o0000ooooooooool05_ooool2o`0000kooooo0_l00026ooooo`;o00000_ooool2o`0000Go
oooo002;ooooo`;o00000oooool2o`0001[ooooo00?o0000ooooooooool05_ooool2o`0000kooooo
0_l0000Hooooo`;o0000K?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Gooooo002/ooooo`03
o`000?oooooooooo00[ooooo0_l0000aooooo`;o000000?oooooo`000?l00000KOooool01?oMgMgo
0000oa0@4?o<c<`6ooooo`001oooooooo`0004co00003?ooool01?o^k^ko8B4Qoa0@4?o^k^h6oooo
o`001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo0_l00006ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`?o
00001?ooool2o`000003ooooool0003ooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`;o00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00_l00004ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0:ooooo`04ob4Q8OmgMgOoMgMgoc8b<PKooooo0007ooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool01?ooool2o`00027ooooo00?o0000oooooooo
ool06?ooool2o`0000cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo00Wooooo0_l00002ooooo`;o00001Oooool0093ooooo0_l0000Jooooo`03o`00
0?oooooooooo01Gooooo0_l0002Rooooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool01?oo
ool2o`0000kooooo0ol0002Rooooo`00QOooool2o`0002Gooooo00?o0000ooooooooool01?ooool2
o`0000kooooo0ol0002Rooooo`00QOooool2o`0002Gooooo00?o0000ooooooooool03?ooool2o`00
00Oooooo0_l0002Rooooo`00[?ooool00ol0003oooooooooo`0<ooooo`;o00001oooool2o`00017o
oooo0_l0002?ooooo`00U?ooool2o`0001Kooooo0ol0000;ooooo`;o00002?ooool2o`00017ooooo
0_l0000Eooooo`;o000000?oooooo`000?l00000MOooool009Cooooo0_l0000Fooooo`03o`000?oo
oooooooo00_ooooo0_l00008ooooo`;o0000:?ooool5o`0007Gooooo0024ooooo`;o00003_ooool2
o`0001Kooooo00?o0000ooooooooool01?ooool2o`0000oooooo0_l0000Yooooo`Co0000MOooool0
08Cooooo0_l0000>ooooo`;o00005_ooool00ol0003oooooooooo`04ooooo`;o00003oooool3o`00
02Wooooo0_l0001fooooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool05Oooool3o`0000oo
oooo0_l0000Hooooo`;o0000M_ooool008cooooo0_l0000Nooooo`03o`000?oooooooooo01Gooooo
0_l0000@ooooo`;o0000T?ooool008Gooooo0_l00005ooooo`;o00007_ooool00ol0003ooooooooo
o`2iooooo`00QOooool2o`0002Gooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool02oooool2o`000:cooooo002/ooooo`?o00002oooool2o`0003Cooooo0_l0001fooooo`00
[?ooool00ol0003oooooooooo`0Dooooo`;o00003_ooool2o`0001_ooooo0_l0001fooooo`00[?oo
ool00ol0003oooooooooo`0Dooooo`;o00003_ooool2o`0000;ooooo0_l0000Dooooo`;o0000NOoo
ool00:cooooo00?o0000ooooooooool00oooool2o`00023ooooo0_l000000ooooooo0000o`00000D
ooooo`Co0000Moooool008cooooo0_l0000Nooooo`03o`000?oooooooooo00?ooooo0_l0000Poooo
o`;o00006Oooool4o`0007Gooooo002<ooooo`;o00007_ooool00ol0003oooooooooo`0:ooooo`;o
0000=_ooool2o`0007Gooooo002/ooooo`03o`000?oooooooooo00[ooooo0_l00009ooooo`;o0000
X_ooool00:cooooo00?o0000ooooooooool00oooool2o`00013ooooo0_l0000=ooooo`;o0000Tooo
ool00:cooooo0ol00003ooooo`;o00001?ooool2o`0001Wooooo0_l0000Iooooo`;o0000N?ooool0
08_ooooo0_l0000Oooooo`03o`000?oooooooooo00Wooooo0ol0000cooooo`;o0000N?ooool008_o
oooo0_l0000Oooooo`03o`000?oooooooooo00[ooooo0_l0000fooooo`;o0000MOooool0093ooooo
0_l0000Jooooo`03o`000?oooooooooo04;ooooo0_l0001eooooo`00T?ooool2o`0001[ooooo00?o
0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0?_ooool2o`000004ooooool0003o
0000o`0007Gooooo002Jooooo`;o00004?ooool00ol0003oooooooooo`0Cooooo`;o0000:Oooool2
o`000004ooooool0003o0000o`0007Gooooo002Jooooo`;o00004?ooool00ol0003oooooooooo`0C
ooooo`?o0000;Oooool2o`0007Cooooo002/ooooo`?o00005?ooool2o`0000kooooo0ol0000Ioooo
o`;o000000?oooooo`000?l00000M?ooool008cooooo0_l00004ooooo`;o00006?ooool00ol0003o
ooooooooo`0Dooooo`;o00003_ooool3o`0001Sooooo0ol0001gooooo`00S?ooool2o`0000Cooooo
0_l0000Hooooo`03o`000?oooooooooo02Cooooo0_l0000Iooooo`;o0000N?ooool009Kooooo0_l0
000Dooooo`03o`000?oooooooooo02;ooooo0_l0002Eooooo`00U_ooool3o`0001?ooooo00?o0000
ooooooooool08_ooool2o`0009Gooooo002Booooo`;o00000oooool2o`00017ooooo0ol0002koooo
o`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo0_l000000olQ8B7oooooooooo`02oooo
o`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00?ooooo0ol00012ooooo`;o0000Moooool0
08Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q0_ooool2o`000005oiRHV?lQ8B7o
k^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00;o00001_oo
ool2o`0003Gooooo0ol0001gooooo`00ROooool01Ol@413ooooooooooooooooo410@00Wooooo0ol0
00000onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo1Ol00006ooooo`;o00006_oo
ool2o`0001Wooooo0_l0001hooooo`00ROooool01Ol0003ooooooooooooooooo000000[ooooo0_l0
00001?ooooooV9RHob4Q8Oo^k^h7ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
9?ooool2o`0001Wooooo1?l0001fooooo`00ROooool01Ol0003ooooooooooooooooo000000kooooo
00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool04?ooool2o`00013ooooo0_l0000Iooooo`;o00000_ooool2o`0007Kooooo0029ooooo`05oa0@
4?ooooooooooooooool@41000_l0000=ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0@ooooo`;o00004?ooool2o`0001Wooooo0_l0001jooooo`00
ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00;o00002Oooool01Ol0003o^[ZjoooooonHV9So410@
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2iooooo`00ROooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co000000?ooooo
o`000?l000000oooool00ol0003oooooooooo`0Pooooo`;o0000Uoooool008kooooo0_l0000Goooo
o`;o00000oooool00ol0003oooooooooo`0Pooooo`;o00006Oooool2o`0007cooooo002>ooooo`;o
00005Oooool2o`0000Gooooo0ol00005ooooo`;o00007?ooool2o`0001Kooooo0_l00003ooooo`;o
0000Moooool00:Gooooo0_l00005ooooo`?o00001Oooool2o`0000[ooooo0_l0000@ooooo`;o0000
6oooool2o`0007Oooooo002/ooooo`?o00001Oooool2o`0000[ooooo0_l0000<ooooo`;o0000V?oo
ool00:cooooo00?o0000ooooooooool01Oooool2o`0001Sooooo1?l0002Fooooo`00[?ooool00ol0
003oooooooooo`0Qooooo`?o0000UOooool009Gooooo0_l0000Eooooo`03o`000?oooooooooo02;o
oooo0_l0002Eooooo`00UOooool2o`0001Gooooo00?o0000ooooooooool0?oooool2o`0007Sooooo
002/ooooo`03o`000?oooooooooo03_ooooo0_l00002ooooo`;o0000N?ooool00:cooooo00?o0000
ooooooooool0>oooool2o`0007cooooo002?ooooo`;o00006oooool00ol0003oooooooooo`03oooo
o`;o0000<oooool2o`0000Cooooo0_l0001iooooo`00Soooool2o`0001_ooooo0ol00003ooooo`;o
00006_ooool2o`0001Oooooo0_l00004ooooo`;o0000NOooool0083ooooo0_l0000Zooooo`03o`00
0?oooooooooo01oooooo0_l0000Mooooo`;o0000NOooool0083ooooo0_l0000Zooooo`04o`000?oo
ooooooooooooo`;o0000>oooool2o`0007Wooooo002Nooooo`;o00003?ooool01?l0003ooooooooo
ooooool3o`0000Sooooo0ol0000[ooooo`;o0000OOooool008Wooooo0_l0000Cooooo`;o00003?oo
ool00ol0003oooooooooo`02ooooo`;o00002?ooool3o`0002_ooooo0ol0001looooo`00ROooool2
o`00027ooooo00?o0000ooooooooool07_ooool2o`0001_ooooo0_l0001looooo`00[?ooool00ol0
003oooooooooo`0Nooooo`;o0000VOooool009oooooo0_l00005ooooo`;o00001?ooool00ol0003o
ooooooooo`0looooo`;o0000Noooool008Wooooo0_l0000Dooooo`;o00001Oooool2o`0000Cooooo
0ol0000:ooooo`;o00003oooool2o`0001kooooo0ol0001kooooo`00ROooool2o`0001Oooooo0_l0
0008ooooo`03o`000?oooooooooo00Wooooo0ol0000?ooooo`;o00007_ooool2o`0007cooooo002A
ooooo`;o00003oooool2o`0000Sooooo00?o0000ooooooooool02Oooool4o`0000kooooo0_l0000L
ooooo`;o0000O_ooool0097ooooo0_l0000Iooooo`03o`000?oooooooooo00_ooooo0_l0000>oooo
o`;o00007?ooool4o`0007cooooo0021ooooo`;o0000:Oooool00ol0003oooooooooo`0jooooo`?o
0000O?ooool0087ooooo0_l0000Yooooo`03o`000?oooooooooo03[ooooo0ol0001looooo`00POoo
ool2o`0002Wooooo00?o0000ooooooooool0^Oooool0087ooooo0_l0000Yooooo`03o`000?oooooo
oooo03Gooooo0_l00022ooooo`00R_ooool2o`0000oooooo0_l0000?ooooo`?o0000=Oooool2o`00
08;ooooo002:ooooo`;o00003oooool2o`0000oooooo00?o0000ooooooooool02?ooool2o`0002_o
oooo0_l00022ooooo`00[?ooool00ol0003oooooooooo`06ooooo`Co0000:oooool2o`000003oooo
ool0003o000007oooooo002Mooooo`;o00002oooool3o`0000Sooooo0_l0000/ooooo`;o00000_oo
ool2o`0007oooooo002Mooooo`;o00002oooool3o`0003Kooooo0_l00023ooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Fooooo`;o0000XOooool0
097ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool01?mgMgOo<S8boooooooo
ool2o`000003ooooool0003ooooo00Oooooo0_l0000>ooooo`;o00006?ooool2o`0008Oooooo002A
ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02o`000003ooooool0
003ooooo00Oooooo0_l0000Xooooo`;o0000Qoooool0097ooooo00Go0000ooooooooooooooooo`00
000;ooooo`;o00000_ooool00omgMgOo<S8booooo`04ooooo`?o0000=?ooool2o`0008?ooooo002<
ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000_ooooo0_l000001?lQ8B7o0000oc8b
<_o<c<`5ooooo`03o`000?oooooooooo03?ooooo0ol00023ooooo`00S?ooool2o`0000?ooooo00Go
410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
<oooool3o`0008?ooooo002Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo02kooooo0_l00004ooooo`;o0000Poooool0097ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`0Cooooo`;o0000
6Oooool2o`0008Wooooo002/ooooo`03o`000?oooooooooo01?ooooo0_l0000Kooooo`?o0000Q_oo
ool009Kooooo0_l0000Dooooo`03o`000?oooooooooo00;ooooo0_l0000/ooooo`?o0000Q_ooool0
09Kooooo0_l0000Dooooo`03o`000?oooooooooo00;ooooo0_l0000=ooooo`;o0000Y_ooool00:co
oooo0ol0000Aooooo`;o0000Y_ooool00:cooooo00?o0000ooooooooool00_l0000?ooooo`;o0000
Y_ooool00:cooooo00?o0000ooooooooool00_l0000@ooooo`;o00006oooool2o`0008Sooooo002/
ooooo`03o`000?oooooooooo01;ooooo0_l0000Kooooo`;o0000R?ooool009Wooooo0_l0000Aoooo
o`;o0000<?ooool2o`0008Sooooo0023ooooo`;o00005?ooool2o`00013ooooo0ol0000]ooooo`Go
0000R?ooool008?ooooo0_l0000Dooooo`;o00004?ooool3o`0002cooooo1Ol00029ooooo`00[?oo
ool2o`0002cooooo1?l0002:ooooo`00Voooool2o`0000oooooo0ol0000?ooooo`;o00007?ooool3
o`0008Wooooo002Kooooo`;o00003_ooool2o`00017ooooo0_l0000Mooooo`;o0000ROooool00:_o
oooo0_l0000]ooooo`;o000000?oooooo`000?l00000ROooool00:cooooo00?o0000ooooooooool0
3?ooool2o`0001_ooooo1?l0002<ooooo`00Yoooool2o`0000?ooooo00?o0000ooooooooool03?oo
ool2o`0001_ooooo1Ol0002;ooooo`00Yoooool2o`0000?ooooo00?o0000ooooooooool0:_ooool4
o`0008_ooooo002Nooooo`;o00002?ooool2o`0000;ooooo00?o0000ooooooooool09Oooool2o`00
09;ooooo002Nooooo`;o00000_ooool3o`0000?ooooo0_l00002ooooo`03o`000?oooooooooo00[o
oooo0_l0000Iooooo`;o0000T_ooool00:;ooooo0ol00007ooooo`?o00002_ooool2o`000:gooooo
002/ooooo`03o`000?oooooooooo00Kooooo0_l0002aooooo`00[?ooool00ol0003oooooooooo`06
ooooo`;o0000/Oooool00:cooooo00?o0000ooooooooool01oooool2o`000;3ooooo002Booooo`;o
00006?ooool00ol0003oooooooooo`07ooooo`;o0000/?ooool009;ooooo0_l0000Hooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo023ooooo0_l0002Gooooo`00[?ooool0
0ol0003oooooooooo`0Pooooo`;o00000_ooool2o`0009?ooooo002/ooooo`03o`000?oooooooooo
02Cooooo0_l0002Cooooo`00[?ooool3o`0001kooooo0_l0002Iooooo`00[?ooool00ol0003ooooo
ooooo`05ooooo`;o00005oooool2o`0009Wooooo002/ooooo`04o`000?ooooooooooooooo`;o0000
00Coooooo`000?l0003o0000/_ooool00:cooooo00Co0000oooooooooooooooo0_l000000ooooooo
0000o`00002cooooo`00[?ooool00ol0003oooooooooo`0Kooooo`;o0000W?ooool008Wooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Kooooo`;o000000?oooooo`000?l0
0000VOooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q00?oooooo`000?l0
00000oooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Nooooo`;o
0000VOooool008Wooooo00Go410@oooooooooooooooooa0@4008ooooo`;o00000oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002iooooo`00ROooool01Ol0003ooooo
oooooooooooo000000_ooooo0_l000000ooooooo8B4Qooooo`07ooooo`03ogMgMolb<S;ooooo00Co
oooo0ol0000Looooo`Co0000VOooool008Wooooo00Go0000ooooooooooooooooo`00000:ooooo`Co
000000?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo0ol0000Joooo
o`Ko0000VOooool008Wooooo00Go410@oooooooooooooooooa0@400:ooooo`Go000000?oMgMgoooo
ooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01[ooooo1?l0002Koooo
o`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@ooooool0003o0000oc8b<P04
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06oooool3o`0009_ooooo0029oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooo
oooo01Oooooo0_l00002ooooo`;o0000W?ooool009gooooo0ol0000;ooooo`;o00006Oooool2o`00
0:3ooooo002Mooooo`?o00002oooool2o`000;_ooooo002Kooooo`;o00002Oooool2o`0000Cooooo
00?o0000ooooooooool0^Oooool009_ooooo0_l00002ooooo`;o00000oooool6o`0000;ooooo0ol0
002iooooo`00WOooool4o`0000?ooooo1_l00002ooooo`03o`000?oooooooooo0;Wooooo002Moooo
o`;o00002?ooool2o`0000?ooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool04Oooool2o`000:Kooooo002/ooooo`03o`000?oo
oooooooo017ooooo0_l0002Vooooo`00[?ooool00ol0003oooooooooo`0Cooooo`;o0000Y?ooool0
0:cooooo00?o0000ooooooooool04oooool2o`000:Cooooo002/ooooo`?o0000^Oooool00:cooooo
00?o0000ooooooooool03Oooool2o`000:[ooooo002/ooooo`03o`000?oooooooooo00gooooo0_l0
002Zooooo`00[?ooool00ol0003oooooooooo`0@ooooo`;o0000Yoooool00:cooooo00?o0000oooo
ooooool04?ooool2o`000:Oooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo00oooooo0_l0002Xooooo`00[?ooool00ol0003oooooooooo`0?ooooo`;o0000Z?oo
ool00:cooooo00?o0000ooooooooool02Oooool2o`000:kooooo002/ooooo`?o00002Oooool2o`00
0:kooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00Gooooo
0_l0002booooo`00[?ooool00ol0003oooooooooo`05ooooo`;o0000/_ooool00:cooooo00?o0000
ooooooooool0^Oooool009Cooooo0ol0000Eooooo`03o`000?oooooooooo0;Wooooo002Dooooo`?o
00005Oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`05ooooo`;o0000
/_ooool009Gooooo0_l0000Eooooo`?o00000oooool4o`000;;ooooo002Eooooo`Co00004oooool0
0ol0003oooooooooo`03ooooo`;o0000]?ooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002Hooooo`;o00004_ooool00ol0003oooooooooo`2iooooo`00V?ooool2o`0000Sooooo1?l00000
0ol@413oooooooooo`03ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`04o`000?oooooooooo
ooooo`;o00000_ooool00ol0003oooooooooo`2iooooo`00Y?ooool01?l0003oooooooooooooool2
o`000003ooooool0003o000000;o0000^Oooool00:Cooooo00?o0000ooooooooool01?ooool3o`00
0;[ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo
002Tooooo`03o`000?oooooooooo0<7ooooo002Rooooo`03oeEEEOmVIVKo00000<?ooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Zooooo`04oa0@4?l0003o
0000o`000;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo
0;[ooooo002[ooooo`06o`000?mgMgOo0000o`000?mEEEGok^k^]oooool00:_ooooo00Ko0000oeEE
EOo^k^koooooogMgMomEEEFgooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooo
oooo0;Gooooo002[ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0]Oooool00:_o
oooo00Ko0000oeEEEOo^k^koooooogMgMomVIVJgooooo`00Z_ooool00ol@413o0000ogMgM`02o`00
0003ofIVI_o^k^kooooo0;Kooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.61445 .67699 Mdot
.56926 .79508 Mdot
.46051 .38031 Mdot
.53406 .63188 Mdot
.58334 .56858 Mdot
.63453 .47423 Mdot
.43772 .45193 Mdot
.72927 .47407 Mdot
.70614 .43093 Mdot
.41303 .48172 Mdot
.46083 .22202 Mdot
.72526 .56665 Mdot
.46502 .92446 Mdot
.41717 .37879 Mdot
.70174 .65091 Mdot
.48571 .76008 Mdot
.48216 .14786 Mdot
.45941 .92196 Mdot
.56291 .37015 Mdot
.43031 .09629 Mdot
.41155 .81439 Mdot
.49833 .89999 Mdot
.43768 .87659 Mdot
.43282 .8839 Mdot
.68722 .71082 Mdot
.50817 .80426 Mdot
.51633 .26948 Mdot
.56594 .39255 Mdot
.47084 .04945 Mdot
.54215 .83548 Mdot
.38123 .54547 Mdot
.70356 .40133 Mdot
.72271 .48735 Mdot
.5576 .25903 Mdot
.5802 .29041 Mdot
.45836 .06902 Mdot
.63021 .23761 Mdot
.55338 .35572 Mdot
.5461 .12311 Mdot
.73031 .5563 Mdot
.70803 .66701 Mdot
.56602 .2664 Mdot
.61869 .4008 Mdot
.62666 .65433 Mdot
.63584 .60093 Mdot
.56486 .67013 Mdot
.43598 .28174 Mdot
.68018 .32411 Mdot
.41281 .70573 Mdot
.5044 .0731 Mdot
.68181 .33313 Mdot
.55599 .12795 Mdot
.37068 .22297 Mdot
.60905 .37402 Mdot
.6015 .33532 Mdot
.71496 .46529 Mdot
.72922 .49641 Mdot
.46241 .14922 Mdot
.65827 .28209 Mdot
.63814 .58307 Mdot
.54913 .71132 Mdot
.6222 .85762 Mdot
.56521 .15108 Mdot
.50415 .29897 Mdot
.71483 .54601 Mdot
.70961 .42054 Mdot
.41373 .47096 Mdot
.4758 .75957 Mdot
.54518 .32448 Mdot
.404 .78697 Mdot
.44554 .16275 Mdot
.4756 .31287 Mdot
.41924 .38182 Mdot
.42048 .62227 Mdot
.5654 .15144 Mdot
.50695 .45496 Mdot
.3712 .21911 Mdot
.48863 .81926 Mdot
.53544 .10249 Mdot
.39994 .50884 Mdot
.39566 .2592 Mdot
.53734 .8406 Mdot
.53595 .61679 Mdot
.56556 .26257 Mdot
.72261 .44551 Mdot
.50596 .73249 Mdot
.58255 .57811 Mdot
.55727 .67483 Mdot
.42825 .21299 Mdot
.4676 .75738 Mdot
.67949 .72701 Mdot
.39481 .88826 Mdot
.53298 .37789 Mdot
.56908 .64968 Mdot
.52853 .3665 Mdot
.43413 .99599 Mdot
.41604 .39227 Mdot
.69145 .37579 Mdot
.37553 .18687 Mdot
.41434 .26617 Mdot
.60111 .71357 Mdot
.40206 .36258 Mdot
.7192 .58974 Mdot
.61465 .69079 Mdot
.37905 .5314 Mdot
.56485 .27223 Mdot
.47903 .13873 Mdot
.57139 .3985 Mdot
.53327 .37837 Mdot
.39426 .72796 Mdot
.41247 .45953 Mdot
.54388 .5911 Mdot
.70311 .40413 Mdot
.41937 .1321 Mdot
.50783 .65548 Mdot
.52663 .75947 Mdot
.71074 .39697 Mdot
.70653 .39091 Mdot
.64276 .27145 Mdot
.45601 .91711 Mdot
.65635 .80314 Mdot
.39947 .7429 Mdot
.46554 .04943 Mdot
.39801 .75385 Mdot
.52005 .67833 Mdot
.44546 .07574 Mdot
.5487 .81503 Mdot
.43886 .63985 Mdot
.46469 .91188 Mdot
.58241 .75585 Mdot
.71899 .60785 Mdot
.63578 .45856 Mdot
.62568 .42891 Mdot
.49912 .05854 Mdot
.59336 .17066 Mdot
.46626 .05415 Mdot
.41947 .38176 Mdot
.7218 .53283 Mdot
.70566 .64375 Mdot
.53787 .96193 Mdot
.55024 .48414 Mdot
.55055 .33427 Mdot
.47897 .14635 Mdot
.42094 .12297 Mdot
.71852 .42666 Mdot
.58089 .02853 Mdot
.57833 .50297 Mdot
.5541 .68707 Mdot
.6914 .74233 Mdot
.39712 .43807 Mdot
.51173 .24899 Mdot
.43829 .8964 Mdot
.46438 .32007 Mdot
.63045 .57428 Mdot
.59363 .17733 Mdot
.5603 .14023 Mdot
.7126 .41706 Mdot
.6367 .25261 Mdot
.59333 .17534 Mdot
.46463 .83759 Mdot
.5237 .08641 Mdot
.73053 .60188 Mdot
.43982 .09629 Mdot
.62217 .43965 Mdot
.59086 .73088 Mdot
.71746 .42736 Mdot
.37826 .49149 Mdot
.54226 .31825 Mdot
.57219 .14169 Mdot
.50237 .07566 Mdot
.54564 .48154 Mdot
.53851 .31463 Mdot
.57318 .61693 Mdot
.5805 .49991 Mdot
.72018 .52042 Mdot
.62985 .57292 Mdot
.4902 .69422 Mdot
.5024 .06752 Mdot
.54946 .11315 Mdot
.72619 .59132 Mdot
.45136 .74997 Mdot
.70619 .675 Mdot
.426 .47893 Mdot
.70521 .44193 Mdot
.69733 .36489 Mdot
.72947 .60033 Mdot
.62109 .40221 Mdot
.67024 .77477 Mdot
.41722 .13367 Mdot
.48732 .27247 Mdot
.61701 .86009 Mdot
.72588 .4637 Mdot
.70862 .68312 Mdot
.71988 .59512 Mdot
.57001 .64216 Mdot
.38466 .85022 Mdot
.49984 .15075 Mdot
.51017 .6333 Mdot
.5078 .64297 Mdot
.48442 .31646 Mdot
.57724 .59271 Mdot
.36988 .75726 Mdot
.5834 .75009 Mdot
.45616 .29006 Mdot
.63582 .50649 Mdot
.551 .54809 Mdot
.42501 .46171 Mdot
.456 .22541 Mdot
.50177 .90576 Mdot
.49942 .80605 Mdot
.37842 .47546 Mdot
.44767 .73745 Mdot
.58547 .7426 Mdot
.50424 .79563 Mdot
.7277 .61319 Mdot
.42616 .54778 Mdot
.62894 .60905 Mdot
.73212 .53017 Mdot
.53382 .74517 Mdot
.67326 .32606 Mdot
.3796 .5703 Mdot
.41543 .16301 Mdot
.4463 .72854 Mdot
.58437 .52649 Mdot
.59475 .74981 Mdot
.54364 .44533 Mdot
.70227 .65062 Mdot
.66155 .7986 Mdot
.51153 .71122 Mdot
.46987 .6629 Mdot
.35885 .62269 Mdot
.40041 .40866 Mdot
.49835 .23102 Mdot
.65693 .79856 Mdot
.54471 .3295 Mdot
.61047 .70446 Mdot
.42364 .85042 Mdot
.58968 .74066 Mdot
.61475 .86666 Mdot
.62829 .42314 Mdot
.37951 .40853 Mdot
.44516 .16357 Mdot
.7016 .3813 Mdot
.52943 .3758 Mdot
.60795 .20669 Mdot
.45271 .16783 Mdot
.44095 .17186 Mdot
.55881 .14024 Mdot
.70644 .68473 Mdot
.50776 .65469 Mdot
.49991 .29673 Mdot
.62427 .23545 Mdot
.47803 .83374 Mdot
.53689 .31203 Mdot
.60013 .32133 Mdot
.50882 .47568 Mdot
.72653 .50649 Mdot
.66979 .30219 Mdot
.39952 .57749 Mdot
.49687 .22851 Mdot
.42133 .14177 Mdot
.46253 .70409 Mdot
.40037 .3907 Mdot
.61399 .67056 Mdot
.4541 .23707 Mdot
.6301 .49844 Mdot
.4835 .06302 Mdot
.43689 .78797 Mdot
.44434 .08064 Mdot
.60368 .33761 Mdot
.41336 .54453 Mdot
.39948 .54622 Mdot
.58497 .16342 Mdot
.45307 .7552 Mdot
.58234 .44853 Mdot
.68774 .35041 Mdot
.43907 .26045 Mdot
.63464 .54325 Mdot
.5102 .07449 Mdot
.45607 .70273 Mdot
.42163 .62272 Mdot
.64014 .26124 Mdot
.72249 .56734 Mdot
.57205 .3989 Mdot
.44961 .35831 Mdot
.57324 .5903 Mdot
.39224 .25544 Mdot
.5545 .69024 Mdot
.39139 .29435 Mdot
.66085 .29413 Mdot
.71023 .61695 Mdot
.66991 .32285 Mdot
.44725 .61865 Mdot
.63866 .24161 Mdot
.61214 .86168 Mdot
.38088 .36514 Mdot
.70414 .64097 Mdot
.60801 .05451 Mdot
.40729 .65728 Mdot
.61431 .35855 Mdot
.5862 .75114 Mdot
.70278 .39062 Mdot
.70077 .68001 Mdot
.43802 .27216 Mdot
.68919 .36007 Mdot
.47277 .83526 Mdot
.52153 .57032 Mdot
.48833 .91666 Mdot
.48807 .14959 Mdot
.45176 .9106 Mdot
.69375 .73408 Mdot
.49254 .69548 Mdot
.62391 .63255 Mdot
.5646 .26903 Mdot
.71451 .56036 Mdot
.47087 .71342 Mdot
.72325 .60465 Mdot
.64823 .80077 Mdot
.5468 .95833 Mdot
.50872 .71253 Mdot
.63587 .44518 Mdot
.56193 .25271 Mdot
.58101 .17196 Mdot
.58667 .50508 Mdot
.52452 .56471 Mdot
.43747 .53897 Mdot
.47334 .14007 Mdot
.73179 .50819 Mdot
.62866 .24745 Mdot
.52369 .34843 Mdot
.50434 .89843 Mdot
.43933 .64521 Mdot
.48778 .32075 Mdot
.59023 .75883 Mdot
.63305 .45379 Mdot
.62231 .43934 Mdot
.46136 .83489 Mdot
.57737 .58713 Mdot
.35618 .39263 Mdot
.45392 .81945 Mdot
.53421 .84129 Mdot
.51284 .32372 Mdot
.71896 .48554 Mdot
.5117 .26124 Mdot
.46399 .05643 Mdot
.49822 .89379 Mdot
.54374 .42222 Mdot
.51859 .76595 Mdot
.5453 .95417 Mdot
.72789 .55065 Mdot
.62885 .2209 Mdot
.4603 .06603 Mdot
.42247 .7479 Mdot
.51154 .1711 Mdot
.48765 .06187 Mdot
.39983 .40704 Mdot
.72714 .55372 Mdot
.56337 .94363 Mdot
.38054 .3867 Mdot
.71776 .60997 Mdot
.7218 .61252 Mdot
.71798 .64618 Mdot
.50461 .3611 Mdot
.3982 .47412 Mdot
.70264 .65241 Mdot
.7279 .4985 Mdot
.50834 .37374 Mdot
.38162 .41648 Mdot
.4324 .76969 Mdot
.63729 .49099 Mdot
.60474 .7038 Mdot
.69586 .39141 Mdot
.60919 .70647 Mdot
.63796 .24792 Mdot
.6137 .22379 Mdot
.44103 .88174 Mdot
.61469 .1975 Mdot
.46278 .90933 Mdot
.69518 .68737 Mdot
.6544 .29618 Mdot
.63405 .56397 Mdot
.47003 .31903 Mdot
.6704 .75891 Mdot
.41503 .26629 Mdot
.43875 .55621 Mdot
.72857 .58683 Mdot
.40114 .77254 Mdot
.52709 .54306 Mdot
.41568 .56676 Mdot
.51269 .79174 Mdot
.50976 .25213 Mdot
.68276 .32748 Mdot
.38422 .65922 Mdot
.61136 .86568 Mdot
.72581 .59584 Mdot
.52047 .19157 Mdot
.35821 .36795 Mdot
.51918 .18608 Mdot
.58037 .48411 Mdot
.58284 .48552 Mdot
.50179 .60674 Mdot
.73012 .51177 Mdot
.72493 .56557 Mdot
.51284 .26224 Mdot
.54601 .45175 Mdot
.46272 .21087 Mdot
.48573 .76637 Mdot
.69684 .71932 Mdot
.57744 .62033 Mdot
.42495 .12746 Mdot
.54877 .53402 Mdot
.51934 .26506 Mdot
.4576 .69903 Mdot
.57923 .60455 Mdot
.55019 .24578 Mdot
.49669 .22374 Mdot
.46248 .27969 Mdot
.67393 .77407 Mdot
.72241 .52582 Mdot
.44799 .52951 Mdot
.58513 .30021 Mdot
.48043 .13922 Mdot
.61966 .62815 Mdot
.42275 .7349 Mdot
.5373 .30809 Mdot
.67776 .74804 Mdot
.43197 .99615 Mdot
.59584 .73648 Mdot
.6268 .65891 Mdot
.46405 .27441 Mdot
.70905 .47196 Mdot
.69907 .66411 Mdot
.47858 .21606 Mdot
.48585 .90315 Mdot
.35923 .33931 Mdot
.5477 .47231 Mdot
.5277 .51257 Mdot
.57986 .53023 Mdot
.41059 .17806 Mdot
.405 .62064 Mdot
.38898 .86737 Mdot
.42629 .45264 Mdot
.60136 .35358 Mdot
.55347 .23917 Mdot
.51315 .31819 Mdot
.4848 .70389 Mdot
.43637 .71289 Mdot
.7292 .47939 Mdot
.4909 .70157 Mdot
.51758 .08067 Mdot
.58337 .76775 Mdot
.62923 .62157 Mdot
.4421 .08216 Mdot
.38667 .34397 Mdot
.50075 .1619 Mdot
.41476 .55263 Mdot
.7322 .51068 Mdot
.71068 .67508 Mdot
.46192 .228 Mdot
.6346 .23259 Mdot
.42855 .7601 Mdot
.48557 .15347 Mdot
.45748 .06048 Mdot
.60495 .70607 Mdot
.56909 .39624 Mdot
.52018 .76366 Mdot
.54969 .24168 Mdot
.64647 .82647 Mdot
.62652 .45242 Mdot
.50213 .41527 Mdot
.61802 .40893 Mdot
.39996 .5345 Mdot
.49551 .33159 Mdot
.48966 .7483 Mdot
.60579 .36144 Mdot
.62181 .4009 Mdot
.50955 .64318 Mdot
.48086 .83053 Mdot
.71029 .42418 Mdot
.58643 .54502 Mdot
.61668 .65862 Mdot
.53482 .29079 Mdot
.571 .43123 Mdot
.51899 .42006 Mdot
.52248 .44623 Mdot
.58007 .77696 Mdot
.68095 .35659 Mdot
.43711 .09992 Mdot
.54983 .33649 Mdot
.48095 .05247 Mdot
.72602 .58253 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool05oooool2
o`000:3ooooo002/ooooo`03o`000?oooooooooo01Oooooo0_l0002Pooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00X?ooool4o`0000Sooooo00?o0000ooooooooool0^Oooool00:3ooooo1?l000000ooooooo0000
o`000005ooooo`?o0000^Oooool00:3ooooo0_l00003ooooo`;o00001Oooool00ol0003ooooooooo
o`0Pooooo`;o0000Uoooool00:3ooooo0_l00009ooooo`;o00008_ooool2o`0009Oooooo002Noooo
o`Co00001Oooool2o`0000;ooooo0_l0002kooooo`00W_ooool2o`0000Kooooo0ol00003ooooo`03
o`000?oooooooooo0;Wooooo002Nooooo`;o00001_ooool2o`0000Cooooo0_l0002jooooo`00W_oo
ool2o`0000cooooo0_l0002jooooo`00W_ooool2o`0000cooooo0ol0002iooooo`00V_ooool2o`00
013ooooo1Ol0002gooooo`00V_ooool2o`00013ooooo0_l000000ooooooo0000o`00002gooooo`00
V?ooool3o`00017ooooo00?o0000ooooooooool00_ooool2o`000;Gooooo002Hooooo`?o00004Ooo
ool00ol0003oooooooooo`02ooooo`Co0000/oooool00:cooooo00?o0000ooooooooool01?ooool2
o`000;?ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002Eooooo`;o000000?oooooo`000?l000004_ooool00ol0003oooooooooo`2iooooo`00UOoo
ool5o`0001;ooooo0ol0002iooooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool02?ooool2
o`000:oooooo002/ooooo`03o`000?oooooooooo00Sooooo0_l0002_ooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0=ooooo`;o0000Z_ooool00:cooooo00?o
0000ooooooooool03Oooool2o`000:[ooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo
00?o0000ooooooooool0^Oooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
^Oooool0087ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41000oooool2o`0000Sooooo
00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o00003?ooool2o`000:_ooooo
0029ooooo`05o`000?ooooooooooooooool000000oooool4o`0000Oooooo00?o8B4Qooooooooool0
1_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00cooooo0_l000000ooooooo0000
o`00002Xooooo`00ROooool01Ol0003ooooooooooooooooo000000Gooooo0_l00007ooooo`03oeEE
EOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00oo
oooo0_l0002Xooooo`00ROooool01Ol@413ooooooooooooooooo410@00;ooooo0ol00009ooooo`03
ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2iooooo`00
ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo0ol00006ooooo`05oa0@4?oooooooooooooo
oolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1Ol00005ooooo`03o`000?oooooooooo
013ooooo0_l0002Wooooo`00T_ooool2o`0000oooooo1?l00005ooooo`03o`000?oooooooooo013o
oooo0_l00002ooooo`;o0000Xoooool009;ooooo0_l0000Aooooo`;o00001Oooool00ol0003ooooo
ooooo`0Dooooo`;o0000Xoooool009oooooo0_l00004ooooo`Go00000_ooool00ol0003ooooooooo
o`2iooooo`00Woooool2o`0000Gooooo1?l00002ooooo`?o00004_ooool2o`000:Gooooo002Woooo
o`;o00000oooool2o`0001?ooooo0_l0002Uooooo`00Yoooool2o`0000?ooooo00?o0000oooooooo
ool0^Oooool00:cooooo0_l0002jooooo`00T?ooool2o`0000Oooooo0ol0000@ooooo`;o00006_oo
ool2o`0009kooooo002@ooooo`;o00001oooool5o`0000kooooo00?o0000ooooooooool06Oooool2
o`0009kooooo002Looooo`;o00003_ooool00ol0003oooooooooo`02o`0001Wooooo0_l0002Loooo
o`00V?ooool2o`0001;ooooo00?o0000ooooooooool00_l0000Eooooo`;o00000_ooool2o`0009co
oooo002Hooooo`;o00004_ooool3o`0001Oooooo0_l00002ooooo`;o0000W?ooool008kooooo0_l0
000Looooo`03o`000?oooooooooo01_ooooo0_l0002Looooo`00S_ooool2o`0001cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool00oooool2o`000;Cooooo0022ooooo`;o
0000:?ooool00ol0003oooooooooo`03ooooo`;o0000]?ooool008;ooooo0_l0000Xooooo`03o`00
0?oooooooooo00?ooooo0_l0002dooooo`00[?ooool00ol0003oooooooooo`03ooooo`;o0000]?oo
ool00:cooooo00?o0000ooooooooool08_ooool2o`0009Gooooo002/ooooo`?o00008_ooool2o`00
09Gooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo023ooooo
0_l0002Gooooo`00[?ooool00ol0003oooooooooo`0Pooooo`;o0000Uoooool009Cooooo0_l00009
ooooo`;o00002oooool00ol0003oooooooooo`2iooooo`00U?ooool2o`0000Wooooo0_l00003oooo
o`;o00001_ooool00ol0003oooooooooo`2iooooo`00POooool2o`00027ooooo0_l00006ooooo`03
o`000?oooooooooo0;Wooooo0021ooooo`;o00007?ooool2o`0000_ooooo00?o0000ooooooooool0
9oooool2o`00093ooooo0021ooooo`;o00006_ooool4o`0000Wooooo1Ol0000Rooooo`;o00000ooo
ool2o`00093ooooo0021ooooo`;o00006_ooool4o`0000Wooooo0ol0000Tooooo`;o0000UOooool0
09oooooo0_l0000:ooooo`;o0000^oooool00:_ooooo0_l0000[ooooo`;o0000S_ooool009cooooo
0_l0000>ooooo`03o`000?oooooooooo02Kooooo1Ol0002>ooooo`00W?ooool2o`0000kooooo00?o
0000ooooooooool03_ooool2o`0001Kooooo1?l0002?ooooo`00TOooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`0=ooooo`?o00006_ooool2o`0008gooooo002Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0=ooooo`;o0000
6oooool2o`0008gooooo0029ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@013ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02o`0000_ooooo0_l0000Hooooo`;o0000
00?oooooo`000?l00000SOooool0097ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMg
Molb<S;ooooo00Cooooo1Ol0000?ooooo`;o00005?ooool2o`000003ooooool0003o000008gooooo
0028ooooo`;o00001oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo00;o00003oooool2o`0001Oooooo0_l0002=ooooo`00
R?ooool2o`0000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool04?ooool2o`000:Oooooo0029ooooo`;o00001_ooool01_mgMgOoV9RH
oooooonHV9SoMgMgooooo`;o00002Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00;o00003_ooool2o`0001Wooooo0_l0002<ooooo`00ROooool2o`0000Kooooo00Kok^k^oc8b<_l0
003o<S8bonk^k_ooool2o`0000Wooooo1?l00006ooooo`03o`000?oooooooooo00Go00003Oooool2
o`0001Oooooo0_l0002<ooooo`00Soooool3o`0001[ooooo00Co0000oooooooooooooooo1?l0000=
ooooo`;o0000YOooool008oooooo0ol0000Jooooo`03o`000?oooooooooo00;ooooo0_l0000>oooo
o`;o0000YOooool009Oooooo0_l0000>ooooo`;o00000oooool00ol0003oooooooooo`02ooooo`;o
00003_ooool2o`0001Sooooo0_l0002;ooooo`00Uoooool2o`0000Oooooo0_l00005ooooo`;o0000
0oooool3o`0001;ooooo0_l0000Hooooo`;o0000Roooool009oooooo0ol0000:ooooo`03o`000?oo
oooooooo0;Wooooo002Fooooo`;o00001oooool2o`0000_ooooo00?o0000ooooooooool0<Oooool2
o`0008Kooooo002Fooooo`;o00005?ooool00ol0003oooooooooo`0aooooo`;o0000Q_ooool00:co
oooo00?o0000ooooooooool0^Oooool009gooooo0_l0000=ooooo`03o`000?oooooooooo00Sooooo
0_l0000=ooooo`;o0000X?ooool008Sooooo0_l0000Cooooo`;o00003Oooool00ol0003ooooooooo
o`08ooooo`;o00003Oooool2o`0001Wooooo0_l00025ooooo`00R?ooool2o`0002;ooooo0_l0000a
ooooo`Co0000QOooool00:cooooo0ol0000Iooooo`;o00005Oooool2o`0008Oooooo002/ooooo`?o
00006Oooool2o`0001[ooooo0_l00022ooooo`00[?ooool00ol0003oooooooooo`0eooooo`;o0000
P_ooool00:cooooo00?o0000ooooooooool02Oooool2o`000:kooooo002Tooooo`;o00001_ooool0
0ol0003oooooooooo`09ooooo`;o0000[_ooool00:Cooooo1?l00004ooooo`03o`000?oooooooooo
00Wooooo0_l0002^ooooo`00X_ooool2o`0000;ooooo0_l00004ooooo`04o`000?oooooooooooooo
o`;o00001_ooool4o`000:cooooo002Pooooo`Co00001?ooool2o`0000;ooooo00Co0000oooooooo
oooooooo0_l00008ooooo`;o00004Oooool2o`0009Wooooo002Pooooo`;o00001_ooool2o`0000;o
oooo0ol000000ooooooo0000o`000008ooooo`;o00004Oooool2o`0001Gooooo0_l000000ooooooo
0000o`00001oooooo`00[?ooool01?l0003oooooooooooooool2o`0000Sooooo0_l0000Xooooo`Ko
0000O_ooool00:[ooooo0ol0000=ooooo`;o0000:Oooool2o`000003ooooool0003o000007kooooo
002Zooooo`?o00003Oooool4o`0002[ooooo0_l0001nooooo`00[?ooool00ol0003oooooooooo`0=
ooooo`;o00003oooool3o`0001Sooooo0_l0001nooooo`00OOooool2o`0002gooooo00?o0000oooo
ooooool03Oooool2o`0000oooooo0ol0002Hooooo`00OOooool2o`0000Oooooo0_l0000Tooooo`03
o`000?oooooooooo0;Wooooo0026ooooo`;o00009?ooool00ol0003oooooooooo`2iooooo`00[?oo
ool00ol0003oooooooooo`04ooooo`;o0000/oooool00:cooooo0ol00004ooooo`;o0000=Oooool2
o`0007cooooo002/ooooo`03o`000?oooooooooo00kooooo0_l0000>ooooo`;o00006oooool2o`00
07cooooo002Kooooo`;o00003oooool00ol0003oooooooooo`0>ooooo`;o00003_ooool2o`0000;o
oooo0_l0000Dooooo`;o0000Ooooool009_ooooo0_l0000?ooooo`?o00007oooool2o`000003oooo
ool0003o000001Cooooo0_l000000ooooooo0000o`00001looooo`00Q?ooool2o`0000Gooooo0_l0
000Oooooo`?o00007oooool2o`0001[ooooo0_l000000ooooooo0000o`00001iooooo`00OOooool2
o`0000Gooooo0_l00003ooooo`05onk^k_lb<S;o0000o`000?o^k^h01Oooool2ob4Q8@Cooooo1Ol0
0004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`06ooooo`;o0000
=_ooool2o`0007Wooooo001mooooo`;o00002_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo00Kooooo0_l00009ooooo`;o0000Y_ooool0087ooooo1_l00002ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?o
oooo00Co0000ooooool0003o00004?ooool2o`0000kooooo0_l0002Fooooo`00ROooool01Ol0003o
oooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04oooo
o`Co00001Oooool2o`0001Wooooo0_l0000Iooooo`;o0000Noooool008Wooooo00Go0000oooooooo
ooooooooo`000002ooooo`;o00002_ooool00omgMgOoIVIVooooo`02o`000006ooooool0003o8B4Q
o`000?lb<S;oc<c<1Oooool00ol0003oooooooooo`06ooooo`Co0000<_ooool2o`0007_ooooo0029
ooooo`05oa0@4?ooooooooooooooool@41000_ooool3o`0000[ooooo00Ko0000ooooool0003o0000
ooooool00009ooooo`03o`000?oooooooooo00Oooooo0ol0000eooooo`;o0000N?ooool008Wooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`;o00001_ooool01Ol0003o^[ZjoooooonHV9So410@
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0oooooo`;o0000N?ooool008Co
oooo0_l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7o
c<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo0;Wooooo0024ooooo`;o00001Oooool2o`00
00?ooooo0_l0000Jooooo`03o`000?oooooooooo03gooooo0_l000001?oooooo0000o`000?l0001f
ooooo`00O?ooool2o`0000gooooo0_l00003ooooo`;o00006_ooool00ol0003oooooooooo`0Boooo
o`;o0000:Oooool2o`000004ooooool0003o0000o`0007Kooooo001looooo`;o0000;_ooool00ol0
003oooooooooo`0Booooo`Co0000;?ooool2o`0007Gooooo002/ooooo`?o00004oooool3o`0000ko
oooo0ol0000Iooooo`Co0000MOooool00:cooooo00?o0000ooooooooool05?ooool2o`0000kooooo
0ol0000Iooooo`;o0000Moooool008[ooooo0_l0000Pooooo`03o`000?oooooooooo02Gooooo0_l0
000Iooooo`;o0000Moooool008Cooooo0_l00004ooooo`?o00007oooool00ol0003oooooooooo`0T
ooooo`;o0000Toooool008Cooooo0_l00005ooooo`;o00007oooool00ol0003oooooooooo`0Toooo
o`;o0000Toooool008Cooooo0_l0000Vooooo`;o0000^_ooool008Cooooo0_l0000Vooooo`;o0000
A?ooool2o`0007Cooooo002/ooooo`03o`000?oooooooooo00?ooooo0_l00006ooooo`;o0000=Ooo
ool3o`0007Cooooo002/ooooo`?o00000oooool2o`0000Kooooo0_l0000Jooooo`;o00006Oooool2
o`0007Gooooo002/ooooo`03o`000?oooooooooo02Oooooo0_l0000Iooooo`Go0000L_ooool00:co
oooo00?o0000ooooooooool05?ooool2o`00013ooooo0_l0000Iooooo`;o000000Coooooo`000?l0
003o0000L_ooool00:cooooo00?o0000ooooooooool05?ooool2o`00013ooooo0_l0000Iooooo`;o
0000M_ooool00:cooooo00?o0000ooooooooool0^Oooool008[ooooo0_l0000Pooooo`03o`000?oo
oooooooo02Gooooo0_l0002Booooo`00R_ooool2o`00023ooooo00?o0000ooooooooool09Oooool2
o`0001Wooooo0_l0001gooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o00001Oooool2o`00
01cooooo0_l0000Eooooo`;o00001?ooool2o`00077ooooo002/ooooo`03o`000?oooooooooo00Co
oooo0_l00005ooooo`;o00002oooool2o`0000oooooo0_l0000Kooooo`;o0000LOooool009?ooooo
0_l00002ooooo`;o00004oooool3o`0000cooooo0_l0000:ooooo`;o00003?ooool2o`00097ooooo
002Cooooo`;o00000_ooool2o`0001?ooooo00Co0000ooooool0003o00002oooool2o`0001Sooooo
1?l0002?ooooo`00[?ooool01?l0003oooooo`000?l0000Wooooo`?o0000S_ooool000Wooooo1?l0
00000ol@413oooooooooo`0Fooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo
00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000;ooooo0_l000001Om4A4Co0000o`00
0?l0003ogMgM01Kooooo00?o0000ooooooooool06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4
A?l0003o0000oc8b<_oMgMd06?ooool4o`000003oa0@4?oooooooooo01;ooooo000;ooooo`03o`00
0?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGo
ZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A002ooooo`;o00000_ooool2o`000003oc8b<_oo
oooooooo01Cooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`0>ooooo`05
ogMgMonHV9So0000o`000?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMg
oc8b<_ooool06Oooool00ol0003oooooooooo`0Dooooo`001_l00005ooooo`03o`000?oooooooooo
013ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08
ooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?oo
ool00ol0003oooooooooo`05ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo
00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Sooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000oooooooo
ool03?ooool2o`000004ooooool0003o0000oa0@413ooooo00?o0000ooooooooool03Oooool01Ol@
413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool03_ooool0
1Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h00_ooool2o`0000?ooooo00?oMgMgoc8b<_ooool0
5Oooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So
8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00gooooo0_l00003ooooo`03o`000?oooooooooo00go
oooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qoooo
ooooool01_ooool00omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo000;ooooo`03
o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003?oo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000=ooooo`;o
000000?oIVIVooooooooool00ol000001?lQ8B7o0000oc8b<_o<c<`Fooooo`03o`000?oooooooooo
00cooooo0_l0000:ooooo`05o`000?ooooooooooooooool000003?ooool2o`000003ogMgMomVIVKo
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00<ooooo`;o000000Coooooo`000?oooooooooo
0_l0000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo0000
00kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[ooooo00?o0000
ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol@413ooooooooooooooooo
410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`0Aooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@4100
1_ooool2o`0000Gooooo0ol00004ooooo`03o`000?oooooooooo01Sooooo1?l0000;ooooo`;o0000
2_ooool01Ol@413ooooooooooooooooo410@00cooooo0_l000000ooooooo0000ooooo`03ooooo`03
o`000?oooooooooo00kooooo0_l000001?oooooo410@ooooooooool2o`0000cooooo00?o0000oooo
ooooool04Oooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo
01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?oo
ool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooo
ooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool2o`0000?ooooo00Go0000okZj^_oo
ooooV9RHoa0@4004ooooo`04o`000?oooooo0000o`0001Oooooo00Co0000ooooool0003o00005ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03
o`000?oooooooooo017ooooo00?oMgMgoiRHV?ooool00_l0000<ooooo`03o`000?oooooooooo017o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Cooooo0009ooooo`03oeEEEOmVIVKo0000
01[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`00013ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c002ooooo`Ko00005oooool00ol0003oooooooooo`0<ooooo`;o
00002_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004
ooooo`Co00004?ooool00oo^k^ko<S8bo`000002o`0000cooooo1?l0000@ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000Iooooo`03oeEEEOmVIVKo000001Kooooo002?
ooooo`;o00006oooool00ol0003oooooooooo`0<ooooo`?o00002?ooool3o`0002_ooooo0_l0001b
ooooo`00[?ooool00ol0003oooooooooo`0=ooooo`;o00002?ooool3o`0002_ooooo0ol0001aoooo
o`00Poooool2o`0002Oooooo00?o0000ooooooooool0:_ooool2o`0001[ooooo0_l0001Vooooo`;o
00000_ooool2o`0000Gooooo0023ooooo`;o00009oooool00ol0003oooooooooo`0Zooooo`;o0000
P_ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Gooooo002/ooooo`03o`000?oooooooooo02So
oooo0_l0000Nooooo`;o0000IOooool01?oMgMgo0000oa0@4?o<c<`6ooooo`001oooooooo`0004co
00003?ooool01?o^k^ko8B4Qoa0@4?o^k^h6ooooo`001oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo0ol00005ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`04
ob4Q8OmgMgOoMgMgoc8b<PKooooo0007ooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool05_ooool2o`000003ooooool0003o000000cooooo00Co0000ooooool0003o00007?ooool2o`00
00Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
00Wooooo0_l00002ooooo`;o00001Oooool008_ooooo0_l0000Oooooo`03o`000?oooooooooo01Wo
oooo0_l0000>ooooo`;o00007?ooool4o`0006kooooo002;ooooo`;o00007oooool00ol0003ooooo
ooooo`06ooooo`;o0000@Oooool2o`0006kooooo002/ooooo`03o`000?oooooooooo00Kooooo0_l0
0011ooooo`;o0000K_ooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool0AOooool2o`0007;ooooo002/ooooo`?o0000AOooool2o`0007;ooooo002/ooooo`03o`00
0?oooooooooo01Sooooo0_l0000/ooooo`;o0000LOooool008Cooooo0_l0000Dooooo`;o00004?oo
ool00ol0003oooooooooo`0Gooooo`?o0000;?ooool2o`000003ooooool0003o000006kooooo0024
ooooo`;o00001Oooool2o`0000gooooo0_l0000@ooooo`03o`000?oooooooooo00gooooo0_l00008
ooooo`;o0000;Oooool2o`000003ooooool0003o000006kooooo002;ooooo`;o00007oooool00ol0
003oooooooooo`0=ooooo`;o0000=oooool2o`00077ooooo002Gooooo`;o00004oooool00ol0003o
ooooooooo`2iooooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool01_ooool2o`00027ooooo
0_l0002>ooooo`00Q?ooool2o`0000Cooooo0_l00003ooooo`;o00006oooool00ol0003ooooooooo
o`06ooooo`;o00004Oooool2o`0000kooooo0_l0000Hooooo`;o0000M?ooool008Cooooo0_l00004
ooooo`;o00000oooool2o`0000;ooooo0_l0000Gooooo`03o`000?oooooooooo00gooooo0_l0000:
ooooo`;o0000:?ooool2o`0007Cooooo002?ooooo`;o00000_ooool2o`0001Oooooo0ol0000=oooo
o`;o0000>Oooool2o`0006oooooo002?ooooo`;o00006oooool00ol0003oooooooooo`18ooooo`;o
0000Koooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo04Sooooo0ol0001^ooooo`00Uooo
ool2o`0001?ooooo00?o0000ooooooooool0@oooool2o`0000Cooooo0_l0001^ooooo`00[?ooool0
0ol0003oooooooooo`05ooooo`;o00008_ooool2o`0001Sooooo0_l0001dooooo`00T?ooool2o`00
01[ooooo00?o0000ooooooooool01Oooool2o`0002;ooooo0_l0000Kooooo`?o0000L?ooool008Co
oooo0_l0000:ooooo`;o00006_ooool00ol0003oooooooooo`04ooooo`;o00004_ooool2o`0002co
oooo0ol0001`ooooo`00Q?ooool2o`0002Kooooo00?o0000ooooooooool01?ooool2o`0001;ooooo
0_l0000=ooooo`;o0000T?ooool00:cooooo0ol0000Wooooo`?o0000Soooool008[ooooo0_l0000P
ooooo`03o`000?oooooooooo01Sooooo0_l0000>ooooo`;o0000Soooool008[ooooo0_l0000Poooo
o`03o`000?oooooooooo01Sooooo0_l0000@ooooo`;o00006oooool2o`00073ooooo002/ooooo`03
o`000?oooooooooo02[ooooo0_l0000Kooooo`;o0000L?ooool00:cooooo00?o0000ooooooooool0
5_ooool2o`00033ooooo0_l0001_ooooo`00[?ooool00ol0003oooooooooo`0;ooooo`;o00002?oo
ool3o`0002gooooo1Ol0001_ooooo`00[?ooool00ol0003oooooooooo`0;ooooo`;o00002?ooool3
o`0002gooooo1?l0001`ooooo`00[?ooool00ol0003oooooooooo`0Fooooo`;o0000;Oooool4o`00
073ooooo002/ooooo`?o0000:Oooool2o`0001cooooo0ol0001_ooooo`00[?ooool00ol0003ooooo
ooooo`0Yooooo`;o00007Oooool3o`0006kooooo002/ooooo`;o00006?ooool2o`0002gooooo0_l0
00000ooooooo0000o`00001^ooooo`00[?ooool2o`0001Sooooo0_l0000>ooooo`;o00006oooool4
o`00077ooooo002/ooooo`03o`000?oooooooooo02Oooooo0_l0000Kooooo`Ko0000Koooool00:co
oooo00?o0000ooooooooool0A_ooool4o`0006oooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`08ooooo`;o00002oooool2o`0002_ooooo0_l0001eooooo`00OOooool2o`0000[o
oooo00?oMgMgoiRHV?ooool00_l00003ooooo`;o00000_lQ8B44ooooo`05oiRHV?l0003o0000oooo
oom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00Sooooo0_l0000;oooo
o`?o00003oooool2o`0001Wooooo0_l0001eooooo`00OOooool2o`0000[ooooo00?o410@oooooooo
ool00_l00003ooooo`?o00001_ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?o
oooo0ol0000Fooooo`;o00003oooool2o`00093ooooo0029ooooo`05o`000?ooooooooooooooool0
00001?ooool2o`0000Oooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo02Cooooo0_l0002Cooooo`00ROooool01Ol0003ooooooooooooooooo000000ko
oooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool09?ooool2o`0009?ooooo0029ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_l00006oooo
o`;o00006oooool2o`0009;ooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02
o`0000Kooooo0_l0000Kooooo`;o0000T_ooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP09
ooooo`;o000000GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003ooooooooo
o`2iooooo`00Uoooool2o`0001?ooooo00?o0000ooooool000000_l0000Booooo`;o0000:_ooool2
o`0007Oooooo002Hooooo`;o00004_ooool00ol0003oooooo`000002o`0001;ooooo0_l0000Zoooo
o`;o00000oooool2o`0007;ooooo002Hooooo`;o00004_ooool00ol0003oooooooooo`0Cooooo`;o
0000<?ooool2o`0007;ooooo002/ooooo`?o00004oooool2o`0002[ooooo0_l0001hooooo`00[?oo
ool01?l0003oooooo`000?l0000Uooooo`;o00005oooool2o`0007Sooooo002=ooooo`;o00007Ooo
ool01?l0003oooooo`000?l0000Rooooo`;o000000?oooooo`000?l00000TOooool008Gooooo0_l0
0006ooooo`;o00007Oooool00ol0003oooooooooo`0Sooooo`;o000000?oooooo`000?l00000TOoo
ool008Gooooo0_l0000Kooooo`;o00002?ooool00ol0003oooooooooo`0nooooo`;o0000NOooool0
0:;ooooo0_l00008ooooo`03o`000?oooooooooo03kooooo0_l000000ooooooo0000o`00001foooo
o`00[?ooool00ol0003oooooooooo`0Booooo`;o00003_ooool2o`0001gooooo0_l0001fooooo`00
[?ooool00ol0003oooooooooo`0Booooo`;o00003_ooool2o`0009Gooooo002/ooooo`?o00003ooo
ool2o`00017ooooo0_l0000Mooooo`?o0000MOooool00:cooooo00?o0000ooooooooool00oooool2
o`0000[ooooo0_l0000Aooooo`;o00006oooool5o`0007Gooooo002/ooooo`03o`000?oooooooooo
00?ooooo0_l0000jooooo`Co0000M_ooool00:cooooo00?o0000ooooooooool0@Oooool2o`0007Ko
oooo002/ooooo`03o`000?oooooooooo00kooooo0_l0000]ooooo`;o00000_ooool2o`0007Kooooo
002/ooooo`03o`000?oooooooooo00kooooo0ol0000Aooooo`;o00006Oooool2o`0007[ooooo002X
ooooo`;o00000_ooool00ol0003oooooooooo`0?ooooo`;o00004Oooool2o`0009Gooooo002Xoooo
o`?o000000?oooooo`000?ooool0^_ooool009kooooo0_l00009ooooo`;o000000Coooooo`000?l0
003o0000^Oooool009gooooo1?l00006ooooo`Co000000?oooooo`000?ooool08?ooool4o`0009Ko
oooo002?ooooo`;o00003?ooool4o`0000Kooooo1?l000000ooooooo0000ooooo`0Pooooo`Co0000
U_ooool008oooooo0_l0000Kooooo`03o`000?oooooooooo01oooooo1?l0002Fooooo`00Uoooool2
o`0000Wooooo0_l00008ooooo`03o`000?oooooo000000;o00002oooool2o`0002_ooooo0_l0001m
ooooo`00Uoooool2o`0000Wooooo0_l00008ooooo`03o`000?oooooo000000;o00002oooool2o`00
00oooooo0_l0000Jooooo`;o0000OOooool00:cooooo00?o0000ooooooooool07_ooool2o`0001ko
oooo0_l0001iooooo`00[?ooool00ol0003oooooooooo`0nooooo`;o0000NOooool00:cooooo0ol0
002iooooo`00ROooool2o`0000oooooo0_l0000@ooooo`03o`000?oooooooooo03Sooooo0_l0001o
ooooo`00ROooool2o`0000oooooo0_l0000@ooooo`03o`000?oooooooooo01_ooooo0_l0000Koooo
o`;o0000Ooooool00:cooooo00Co0000ooooool0003o00006_ooool2o`00023ooooo0_l0001joooo
o`00T_ooool2o`0000Kooooo0_l0000@ooooo`04o`000?oooooo0000o`0001_ooooo0_l0000Ooooo
o`;o0000N_ooool009;ooooo0_l00006ooooo`;o00004?ooool00ol0003oooooooooo`0Jooooo`Co
0000Voooool008[ooooo0_l00005ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Go
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01Wooooo0ol0000Poooo
o`;o0000Noooool008[ooooo0_l00005ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`08ooooo`;o00003oooool2o`00
027ooooo0_l0001kooooo`00TOooool01Ol@413o0000o`000?oooooo410@013ooooo00Co0000oooo
ool0003o00000_ooool00ol0003oooooooooo`08ooooo`;o00004_ooool2o`0001Wooooo0_l00020
ooooo`00TOooool3o`000003ooooool0003ooooo00Gooooo0_l00007ooooo`03ogMgMolb<S;ooooo
00;o00000_ooool3o`0001Sooooo0ol000000ooooooo0000o`00000Iooooo`;o0000P?ooool008[o
oooo0_l00005ooooo`05o`000?ooooooooooooooool000001_ooool2o`0000Cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo01Sooooo0ol0002Nooooo`00POooool2o`00
00Oooooo0_l00005ooooo`05oa0@4?ooooooooooooooool@41001_ooool2o`0000?ooooo0_l00009
ooooo`03o`000?oooooooooo01Sooooo1?l0000Iooooo`;o0000P_ooool0087ooooo0_l0000>oooo
o`03ogMgMonHV9Sooooo00;o00002oooool2o`000004ooooool0003o0000ooooo`;o00000oooool0
0ol0003oooooooooo`05ooooo`;o00004oooool2o`0001Wooooo0_l00022ooooo`00TOooool00oo^
k^ko<S8bo`000002o`0000cooooo1?l000000ooooooo0000o`000003ooooo`03o`000?oooooooooo
00?ooooo1?l0002booooo`00Yoooool2o`0000?ooooo00?o0000ooooooooool00oooool2o`0001?o
oooo0_l0002Oooooo`00UOooool2o`00013ooooo0_l00003ooooo`03o`000?oooooooooo00?ooooo
0_l0000Cooooo`;o0000Woooool008_ooooo0_l00008ooooo`;o00005Oooool00ol0003ooooooooo
o`0fooooo`;o0000POooool008_ooooo0_l0000Oooooo`?o00005oooool2o`0001cooooo0ol00021
ooooo`00[?ooool00ol0003oooooooooo`0Gooooo`;o00007?ooool2o`0008;ooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002<ooooo`;o00002Ooo
ool2o`0001?ooooo00?o0000ooooooooool0^Oooool008cooooo0_l00009ooooo`;o00004oooool0
1?l0003oooooooooooooool2o`000;Kooooo002/ooooo`04o`000?ooooooooooooooo`;o00004?oo
ool2o`000:Cooooo002/ooooo`?o00004oooool2o`000:Cooooo002/ooooo`?o0000;Oooool2o`00
0003ooooool0003o000000;o0000QOooool00:cooooo00Co0000ooooool0003o0000;?ooool2o`00
0003ooooool0003o000000;o0000QOooool00:_ooooo0_l000000ooooooo0000o`00000_ooooo`;o
0000Qoooool00:_ooooo0_l0002kooooo`00[?ooool00ol0003oooooooooo`2iooooo`00S_ooool2
o`0001cooooo00?o0000ooooooooool03Oooool2o`000:[ooooo002>ooooo`;o00003?ooool2o`00
00[ooooo0_l00002ooooo`03o`000?oooooooooo00gooooo0_l0002Zooooo`00W?ooool2o`0000[o
oooo0_l00002ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o
0000ooooooooool0;Oooool2o`0008[ooooo002Uooooo`;o00001Oooool00ol0003oooooooooo`0]
ooooo`;o0000R_ooool00:Cooooo0ol00005ooooo`03o`000?oooooooooo0;Wooooo002Oooooo`?o
000000Coooooo`000?l0003o00001_ooool00ol0003oooooooooo`0:ooooo`;o0000[Oooool009oo
oooo0ol000000ooooooo0000o`000007ooooo`03o`000?oooooooooo00Wooooo0ol0002]ooooo`00
[?ooool00ol0003oooooooooo`08ooooo`?o0000[_ooool00:cooooo00?o0000ooooooooool02?oo
ool2o`000:oooooo002/ooooo`03o`000?oooooooooo0;Wooooo0025ooooo`;o00002oooool2o`00
01Sooooo0ol0002iooooo`00QOooool2o`0000_ooooo0_l0000Hooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo02Gooooo0_l0002Booooo`00[?ooool00ol0003ooooooooo
o`0Rooooo`Go0000T_ooool00:cooooo00?o0000ooooooooool08_ooool3o`0009Cooooo0027oooo
o`;o000000Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Qooooo`?o0000UOoo
ool008Oooooo0_l000001OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnY
ZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Qooooo`?o0000UOoo
ool008Wooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`2iooooo`00ROooool01Ol0003ooooooooooooo
oooo000000Wooooo0_l00003ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?oo
ool3o`000;Wooooo0029ooooo`05o`000?ooooooooooooooool000002Oooool2o`0000?ooooo00?o
EEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
^Oooool008Wooooo00Go410@oooooooooooooooooa0@400:ooooo`;o00000_ooool00onYZJWoMgMg
ooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0^Oooool008Wooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`07ooooo`;o000000?oooooo`000?l000000oooool00olb<S;ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0^Oooool008Wooooo0ol0
00000olb<S;ok^k^ooooo`06ooooo`;o00000_ooool5o`0000Cooooo1?l00006ooooo`03o`000?oo
oooooooo0;Wooooo0029ooooo`;o00008Oooool00ol0003oooooooooo`2iooooo`00Zoooool2o`00
0;_ooooo002Gooooo`;o00004_ooool2o`000;_ooooo002Gooooo`;o00004_ooool4o`000;Wooooo
002Wooooo`;o00000_ooool4o`000;Wooooo002Wooooo`;o00000oooool2o`000;[ooooo002Ooooo
o`;o00002oooool2o`000;[ooooo002Looooo`;o000000Coooooo`000?l0003o00002_ooool00ol0
003oooooooooo`2iooooo`00W?ooool2o`0000;ooooo0_l0000:ooooo`03o`000?oooooooooo0;Wo
oooo002Mooooo`;o00002Oooool2o`0000;ooooo00?o0000ooooooooool0^Oooool009gooooo0ol0
0008ooooo`;o00000_ooool00ol0003oooooooooo`2iooooo`00W_ooool4o`0000[ooooo0ol0002i
ooooo`00X?ooool2o`0000[ooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Ooo
ool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool04Oooool2o`00
0:Kooooo002/ooooo`03o`000?oooooooooo017ooooo0_l0002Vooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo00cooooo0_l0002[
ooooo`00[?ooool00ol0003oooooooooo`0<ooooo`;o0000Zoooool00:cooooo00?o0000oooooooo
ool02Oooool2o`000003ooooool0003o00000:_ooooo002/ooooo`03o`000?oooooooooo00Wooooo
0_l0002^ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002Rooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`2iooooo`00UOoo
ool3o`0000cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00UOooool3
o`0000cooooo00?o0000ooooooooool01Oooool3o`000;Wooooo002Tooooo`03o`000?oooooooooo
0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo
002Tooooo`03o`000?oooooooooo0<7ooooo002Rooooo`03oeEEEOmVIVKo00000<?ooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Zooooo`04oa0@4?l0003o
0000o`000;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo
0;[ooooo002[ooooo`06o`000?mgMgOo0000o`000?mEEEGok^k^]oooool00:_ooooo00Ko0000oeEE
EOo^k^koooooogMgMomEEEFgooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooo
oooo0;Gooooo002[ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0]Oooool00:_o
oooo00Ko0000oeEEEOo^k^koooooogMgMomVIVJgooooo`00Z_ooool00ol@413o0000ogMgM`02o`00
0003ofIVI_o^k^kooooo0;Kooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.64525 .47699 Mdot
.64729 .59508 Mdot
.45201 .58918 Mdot
.54681 .43188 Mdot
.57077 .36858 Mdot
.58422 .27423 Mdot
.47257 .67315 Mdot
.6789 .27407 Mdot
.63852 .23093 Mdot
.48442 .77452 Mdot
.41738 .62203 Mdot
.71192 .36665 Mdot
.60553 .75323 Mdot
.46105 .77873 Mdot
.7221 .45091 Mdot
.5528 .56809 Mdot
.39657 .54492 Mdot
.60245 .7607 Mdot
.4718 .19658 Mdot
.39654 .78248 Mdot
.56418 .82043 Mdot
.61835 .70006 Mdot
.58219 .77381 Mdot
.58432 .79349 Mdot
.73155 .51082 Mdot
.58988 .60426 Mdot
.41818 .36813 Mdot
.48315 .20224 Mdot
.37754 .61566 Mdot
.63635 .63548 Mdot
.50521 .90025 Mdot
.62409 .20133 Mdot
.67765 .28735 Mdot
.43082 .20145 Mdot
.45818 .1381 Mdot
.38451 .66589 Mdot
.48531 .04236 Mdot
.45849 .21498 Mdot
.38924 .26861 Mdot
.71283 .3563 Mdot
.73483 .46701 Mdot
.43873 .17325 Mdot
.53901 .2008 Mdot
.6484 .45433 Mdot
.63621 .40093 Mdot
.59291 .47013 Mdot
.43579 .71757 Mdot
.56982 .12411 Mdot
.53504 .76859 Mdot
.37554 .4639 Mdot
.57506 .13313 Mdot
.3938 .22606 Mdot
.51866 .17402 Mdot
.49563 .13585 Mdot
.66108 .26529 Mdot
.68778 .29641 Mdot
.40114 .63085 Mdot
.53111 .08209 Mdot
.63137 .38307 Mdot
.59366 .51132 Mdot
.72524 .65762 Mdot
.40411 .18543 Mdot
.42499 .41607 Mdot
.69323 .34601 Mdot
.63783 .22054 Mdot
.48192 .77382 Mdot
.54808 .58251 Mdot
.44265 .24007 Mdot
.55769 .83615 Mdot
.40775 .70158 Mdot
.43402 .53786 Mdot
.46126 .76901 Mdot
.51365 .71967 Mdot
.4043 .18467 Mdot
.45997 .36978 Mdot
.57792 .62336 Mdot
.38191 .31935 Mdot
.49317 .82581 Mdot
.4396 .89853 Mdot
.63358 .6406 Mdot
.54267 .41679 Mdot
.43719 .17466 Mdot
.66082 .24551 Mdot
.55896 .53249 Mdot
.57379 .37811 Mdot
.5872 .47483 Mdot
.42246 .76623 Mdot
.54518 .59827 Mdot
.73029 .52701 Mdot
.58726 .92379 Mdot
.45103 .27885 Mdot
.58895 .44968 Mdot
.44535 .29687 Mdot
.62256 .87994 Mdot
.46424 .78073 Mdot
.60176 .17579 Mdot
.43708 .81543 Mdot
.64653 .51357 Mdot
.46078 .84819 Mdot
.7151 .38974 Mdot
.65097 .49079 Mdot
.50261 .91229 Mdot
.43975 .17692 Mdot
.39526 .56055 Mdot
.49082 .20136 Mdot
.45135 .27781 Mdot
.54424 .85438 Mdot
.47969 .78177 Mdot
.54032 .3911 Mdot
.62476 .20413 Mdot
.40672 .82249 Mdot
.35221 .41264 Mdot
.53002 .45548 Mdot
.59041 .55947 Mdot
.62953 .19697 Mdot
.62289 .19091 Mdot
.51134 .07145 Mdot
.59958 .7629 Mdot
.7376 .60314 Mdot
.54697 .83709 Mdot
.37868 .63879 Mdot
.55004 .84705 Mdot
.55138 .47833 Mdot
.38877 .72076 Mdot
.64578 .84375 Mdot
.63471 .61503 Mdot
.5137 .63957 Mdot
.60067 .74209 Mdot
.64474 .55585 Mdot
.72213 .40785 Mdot
.5792 .25856 Mdot
.55724 .22891 Mdot
.37341 .49021 Mdot
.4279 .08775 Mdot
.37956 .63463 Mdot
.4612 .76803 Mdot
.69493 .33283 Mdot
.72316 .44375 Mdot
.68264 .76193 Mdot
.5039 .28414 Mdot
.44929 .22198 Mdot
.39693 .55918 Mdot
.40438 .81759 Mdot
.64919 .22666 Mdot
.37812 .14229 Mdot
.53952 .30297 Mdot
.58893 .48707 Mdot
.74833 .54233 Mdot
.47833 .85342 Mdot
.41343 .39312 Mdot
.58887 .78761 Mdot
.43802 .5853 Mdot
.62016 .37428 Mdot
.43029 .08735 Mdot
.39882 .20644 Mdot
.63943 .21706 Mdot
.49775 .05272 Mdot
.42941 .0881 Mdot
.57316 .67453 Mdot
.37711 .37506 Mdot
.73128 .40188 Mdot
.39448 .74096 Mdot
.55803 .23965 Mdot
.64321 .53088 Mdot
.6484 .22736 Mdot
.49407 .92421 Mdot
.43906 .25107 Mdot
.40515 .16015 Mdot
.37647 .47228 Mdot
.49826 .28168 Mdot
.436 .26558 Mdot
.57995 .41693 Mdot
.54046 .29991 Mdot
.68835 .32042 Mdot
.62798 .87107 Mdot
.61902 .37292 Mdot
.52984 .49932 Mdot
.37469 .47392 Mdot
.38777 .25623 Mdot
.72272 .39132 Mdot
.5417 .63952 Mdot
.73619 .475 Mdot
.481 .7185 Mdot
.64198 .24193 Mdot
.63841 .85199 Mdot
.60329 .16489 Mdot
.7296 .40033 Mdot
.54197 .20221 Mdot
.74014 .57477 Mdot
.40753 .83155 Mdot
.42266 .49541 Mdot
.72104 .66009 Mdot
.67136 .2637 Mdot
.74187 .48312 Mdot
.71793 .39512 Mdot
.58687 .44216 Mdot
.57786 .94218 Mdot
.39338 .46709 Mdot
.5235 .4333 Mdot
.52499 .44297 Mdot
.43289 .4986 Mdot
.57432 .39271 Mdot
.55637 .96723 Mdot
.64343 .55009 Mdot
.43324 .6277 Mdot
.59841 .30649 Mdot
.53024 .34809 Mdot
.47746 .72655 Mdot
.41917 .64238 Mdot
.62408 .70576 Mdot
.58184 .60606 Mdot
.49054 .927 Mdot
.53809 .64397 Mdot
.64251 .5426 Mdot
.58249 .59563 Mdot
.73298 .41319 Mdot
.496 .7029 Mdot
.63256 .40905 Mdot
.70418 .33017 Mdot
.59189 .54517 Mdot
.56368 .12606 Mdot
.51101 .9043 Mdot
.41432 .83301 Mdot
.5356 .64355 Mdot
.55496 .32649 Mdot
.65467 .54981 Mdot
.48212 .25893 Mdot
.72252 .45062 Mdot
.74099 .5986 Mdot
.55602 .51122 Mdot
.51417 .51988 Mdot
.52717 .99517 Mdot
.4712 .84545 Mdot
.41123 .45626 Mdot
.73636 .59856 Mdot
.44386 .24138 Mdot
.65226 .50446 Mdot
.57373 .79886 Mdot
.64594 .54066 Mdot
.72141 .66666 Mdot
.55754 .22314 Mdot
.47569 .93674 Mdot
.40801 .70308 Mdot
.61412 .1813 Mdot
.4484 .29214 Mdot
.4524 .05698 Mdot
.40731 .66921 Mdot
.41073 .71965 Mdot
.39818 .2124 Mdot
.74033 .48473 Mdot
.52963 .45469 Mdot
.42523 .43522 Mdot
.47861 .04558 Mdot
.57705 .64838 Mdot
.43447 .27223 Mdot
.4887 .12476 Mdot
.46577 .35784 Mdot
.68912 .30649 Mdot
.55067 .10219 Mdot
.50826 .81494 Mdot
.411 .46324 Mdot
.40841 .81184 Mdot
.52712 .57167 Mdot
.46728 .84951 Mdot
.64222 .47056 Mdot
.42212 .64814 Mdot
.58947 .29844 Mdot
.37776 .55743 Mdot
.55401 .71323 Mdot
.39008 .7246 Mdot
.49872 .13766 Mdot
.49805 .75948 Mdot
.50143 .8198 Mdot
.41954 .11368 Mdot
.54331 .63762 Mdot
.52175 .24853 Mdot
.5879 .15041 Mdot
.43048 .70871 Mdot
.61194 .34325 Mdot
.37502 .43795 Mdot
.52711 .59304 Mdot
.5135 .71454 Mdot
.50463 .06124 Mdot
.70943 .36734 Mdot
.49163 .20127 Mdot
.44956 .6415 Mdot
.56936 .3903 Mdot
.43951 .91425 Mdot
.5906 .49024 Mdot
.44819 .90955 Mdot
.63357 .85779 Mdot
.5385 .09413 Mdot
.71701 .41695 Mdot
.55905 .12285 Mdot
.507 .59992 Mdot
.4953 .04209 Mdot
.71682 .66168 Mdot
.46592 .94013 Mdot
.72053 .44097 Mdot
.40135 .04122 Mdot
.52454 .78176 Mdot
.51774 .15855 Mdot
.64666 .55114 Mdot
.61903 .19062 Mdot
.73278 .48001 Mdot
.43326 .71078 Mdot
.59322 .16007 Mdot
.57518 .65754 Mdot
.50965 .37032 Mdot
.61628 .71995 Mdot
.39567 .51876 Mdot
.59608 .76611 Mdot
.74738 .53408 Mdot
.53186 .49841 Mdot
.63693 .43255 Mdot
.43855 .17771 Mdot
.69865 .36036 Mdot
.5305 .55377 Mdot
.72511 .40465 Mdot
.72853 .60077 Mdot
.69013 .75833 Mdot
.55373 .51253 Mdot
.57395 .24518 Mdot
.43167 .18691 Mdot
.41951 .12647 Mdot
.5487 .30508 Mdot
.51041 .36471 Mdot
.49163 .65543 Mdot
.39678 .58513 Mdot
.69507 .30819 Mdot
.48767 .05086 Mdot
.43853 .31953 Mdot
.62371 .69843 Mdot
.51486 .63844 Mdot
.4331 .48299 Mdot
.65377 .55883 Mdot
.57457 .25379 Mdot
.55805 .23934 Mdot
.5713 .67908 Mdot
.57222 .38713 Mdot
.56454 .68411 Mdot
.63073 .64129 Mdot
.43028 .37191 Mdot
.67318 .28554 Mdot
.41616 .3906 Mdot
.38055 .64402 Mdot
.61577 .69388 Mdot
.47364 .2505 Mdot
.58497 .56595 Mdot
.68697 .75417 Mdot
.70816 .35065 Mdot
.47739 .03188 Mdot
.38344 .65808 Mdot
.54421 .74482 Mdot
.39617 .41094 Mdot
.37661 .53956 Mdot
.47097 .8483 Mdot
.70863 .35372 Mdot
.70082 .74363 Mdot
.4707 .93694 Mdot
.72175 .40997 Mdot
.7268 .41252 Mdot
.73645 .44618 Mdot
.4386 .40052 Mdot
.48597 .84092 Mdot
.7236 .45241 Mdot
.6873 .2985 Mdot
.44135 .38107 Mdot
.47697 .9258 Mdot
.54897 .71807 Mdot
.59368 .29099 Mdot
.64626 .5038 Mdot
.61242 .19141 Mdot
.65178 .50647 Mdot
.49713 .04811 Mdot
.46399 .05271 Mdot
.58421 .76852 Mdot
.45509 .0409 Mdot
.59897 .74302 Mdot
.73013 .48737 Mdot
.3556 .33448 Mdot
.53287 .09618 Mdot
.61964 .36397 Mdot
.43657 .56084 Mdot
.73396 .55891 Mdot
.43695 .81241 Mdot
.49511 .6461 Mdot
.72331 .38683 Mdot
.55433 .84141 Mdot
.50431 .34306 Mdot
.50241 .7448 Mdot
.58939 .59174 Mdot
.41419 .40124 Mdot
.57375 .12748 Mdot
.52996 .88433 Mdot
.71764 .66568 Mdot
.72415 .39584 Mdot
.40074 .36658 Mdot
.39942 .37352 Mdot
.53401 .28411 Mdot
.53705 .28552 Mdot
.50448 .40674 Mdot
.69483 .31177 Mdot
.71116 .36557 Mdot
.41639 .38527 Mdot
.48685 .2591 Mdot
.41454 .61619 Mdot
.55526 .57417 Mdot
.74457 .51932 Mdot
.58558 .42033 Mdot
.4045 .79912 Mdot
.52238 .33402 Mdot
.41746 .35568 Mdot
.52588 .58533 Mdot
.58105 .40455 Mdot
.4228 .23017 Mdot
.41 .46507 Mdot
.42961 .60232 Mdot
.74356 .57407 Mdot
.69273 .32582 Mdot
.48729 .61156 Mdot
.46617 .13123 Mdot
.39506 .55435 Mdot
.63092 .42815 Mdot
.54068 .7379 Mdot
.43359 .27124 Mdot
.73698 .54804 Mdot
.62222 .88532 Mdot
.65044 .53648 Mdot
.35453 .62185 Mdot
.65037 .45891 Mdot
.42812 .59661 Mdot
.65783 .27196 Mdot
.72472 .46411 Mdot
.41224 .54579 Mdot
.60905 .70816 Mdot
.49663 .27282 Mdot
.49277 .31549 Mdot
.55196 .33023 Mdot
.41865 .85088 Mdot
.51665 .78879 Mdot
.582 .93412 Mdot
.4752 .72293 Mdot
.50279 .15358 Mdot
.42267 .21853 Mdot
.42904 .37169 Mdot
.53075 .51564 Mdot
.53256 .6735 Mdot
.68095 .27939 Mdot
.53315 .50579 Mdot
.37584 .40367 Mdot
.65046 .56775 Mdot
.63785 .42157 Mdot
.3909 .73406 Mdot
.46005 .91943 Mdot
.39562 .46072 Mdot
.66497 .8186 Mdot
.49952 .75164 Mdot
.69647 .31068 Mdot
.74071 .47508 Mdot
.41845 .61594 Mdot
.48767 .03589 Mdot
.54669 .72719 Mdot
.39706 .52883 Mdot
.38284 .67158 Mdot
.64738 .50607 Mdot
.48766 .20142 Mdot
.58565 .56366 Mdot
.4214 .23267 Mdot
.73706 .62647 Mdot
.56748 .25242 Mdot
.45075 .3998 Mdot
.54159 .20893 Mdot
.49877 .82017 Mdot
.4338 .44687 Mdot
.55068 .5527 Mdot
.51036 .16144 Mdot
.54218 .2009 Mdot
.52682 .44318 Mdot
.57734 .64176 Mdot
.63996 .22418 Mdot
.56444 .34502 Mdot
.64013 .45862 Mdot
.42787 .28399 Mdot
.50349 .23123 Mdot
.45541 .32622 Mdot
.35071 .52587 Mdot
.46495 .31067 Mdot
.65085 .57696 Mdot
.58359 .15659 Mdot
.39586 .75201 Mdot
.44948 .22426 Mdot
.37601 .57084 Mdot
.71903 .38253 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:Cooooo0_l00006ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`;o00001_ooool00ol0003o
ooooooooo`2iooooo`00Yoooool2o`0000?ooooo00?o0000ooooooooool0^Oooool009gooooo0_l0
0008ooooo`;o00000oooool00ol0003oooooooooo`2iooooo`00Roooool2o`00013ooooo0_l00008
ooooo`;o000000Coooooo`000?l0003o0000^oooool008_ooooo0_l0000Hooooo`Co000000Cooooo
o`000?l0003o0000^oooool00:Gooooo0_l00004ooooo`;o0000^oooool00:3ooooo0_l00005oooo
o`;o00000_ooool4o`000;Wooooo002Pooooo`;o00001Oooool2o`0000;ooooo0_l0002kooooo`00
W?ooool2o`0000kooooo00?o0000ooooooooool0^Oooool009cooooo0_l0000>ooooo`?o0000^Ooo
ool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`02o`000;Oooooo002/ooooo`Go0000]ooo
ool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool01oooool2o`00
0;3ooooo002/ooooo`03o`000?oooooooooo00Oooooo0_l0002`ooooo`00U?ooool3o`0001Gooooo
00?o0000ooooooooool0^Oooool009Cooooo0ol0000Eooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`03o`000?oooooooooo00Wooooo0_l0002^ooooo`00[?ooool00ol0003oooooooooo`07oooo
o`Co0000[_ooool00:cooooo0ol00007ooooo`;o0000/?ooool00:cooooo00?o0000ooooooooool0
3Oooool2o`000:[ooooo002/ooooo`03o`000?oooooooooo00gooooo0_l0002Zooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00TOooool2o`0001Wooooo00?o0000ooooooooool0^Oooool0097o
oooo0_l0000Iooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0^Oooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool04?ooool2o`000:Oooooo0021ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@
00gooooo00?oZJVYoeEEEOooool02?ooool01?l0003oooooo`000?l00002ooooo`?o00004?ooool2
o`0000;ooooo0_l0002Sooooo`00ROooool01Ol0003ooooooooooooooooo000000?ooooo0_l00009
ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool00_l00002ooooo`03o`000?oooooo
oooo01;ooooo1Ol0002Rooooo`00ROooool01Ol0003ooooooooooooooooo000000?ooooo0_l00009
ooooo`04oeEEEOo<c<coooooooooo`?o000000Co8B4Qo`000?lb<S;oc<c<1Oooool00ol0003ooooo
ooooo`0Booooo`;o000000?oooooo`000?l00000X_ooool008Wooooo00Go410@oooooooooooooooo
oa0@400>ooooo`04ojVYZOmgMgOoooooooooo`?o00002Oooool00ol0003oooooooooo`0Eooooo`;o
0000X_ooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooo
oolb<S801?ooool00ol0003oooooooooo`05ooooo`?o00005oooool2o`000:;ooooo0029ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool7o`0000;ooooo1?l00004ooooo`?o0000^oooool008?o
oooo0_l0000Iooooo`;o00003?ooool00ol0003oooooooooo`2iooooo`00Poooool2o`0002Oooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0000J
ooooo`;o0000WOooool00:cooooo0_l0000Kooooo`;o0000WOooool00:cooooo0_l00003ooooo`;o
00005?ooool2o`0009oooooo002<ooooo`;o00007_ooool00ol0003oooooooooo`04o`0001Cooooo
0_l000000ooooooo0000o`00002Looooo`00S?ooool2o`0001kooooo00?o0000ooooooooool00_l0
000Iooooo`;o00000_ooool2o`0009Sooooo002/ooooo`03o`000?oooooooooo01oooooo0_l0002H
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00Uoooool2o`0001?ooooo00?o0000oooooooo
ool00oooool2o`000;Cooooo002Gooooo`?o00004_ooool3o`0000?ooooo0_l0000Iooooo`;o0000
VOooool009Oooooo0ol0000Booooo`03o`000?oooooooooo01kooooo0_l0002Iooooo`00Uoooool2
o`0001?ooooo00?o0000ooooooooool08_ooool2o`0009Gooooo002<ooooo`;o00007_ooool00ol0
003oooooooooo`0Rooooo`;o0000UOooool008cooooo0_l00007ooooo`;o00005Oooool00ol0003o
ooooooooo`2iooooo`00UOooool2o`0001Gooooo00?o0000ooooooooool08_ooool5o`0009;ooooo
002/ooooo`03o`000?oooooooooo02;ooooo1Ol0002Booooo`00X_ooool2o`0000Sooooo00?o0000
ooooooooool09oooool2o`00093ooooo002Eooooo`;o00002oooool2o`0000?ooooo1?l000001?oo
oooo0000o`000?l00009ooooo`?o00006_ooool3o`00093ooooo002Eooooo`;o00003oooool5o`00
0003ooooool0003ooooo00[ooooo0ol0000Jooooo`;o0000TOooool008[ooooo0_l0000Jooooo`;o
00001?ooool00ol0003oooooooooo`0:ooooo`;o00006_ooool2o`00097ooooo002:ooooo`;o0000
8?ooool00ol0003oooooooooo`0:ooooo`;o0000[Oooool008[ooooo0_l0000Pooooo`03o`000?oo
oooooooo00[ooooo0_l0002]ooooo`00R_ooool2o`0001;ooooo0_l0000<ooooo`03o`000?oooooo
oooo0;Wooooo002Booooo`;o00002_ooool2o`0000cooooo00?o0000ooooooooool0:oooool2o`00
08cooooo002Booooo`;o00001oooool2o`0000oooooo00?o0000ooooooooool0:_ooool3o`0008co
oooo002Kooooo`;o00003oooool3o`00013ooooo0_l0000Hooooo`?o0000S?ooool008Wooooo0_l0
000@ooooo`;o00003oooool00ol0003oooooooooo`0@ooooo`;o00006Oooool2o`000003ooooool0
003o000008Wooooo0029ooooo`;o00001oooool2o`0001Sooooo0ol0000?ooooo`;o00006Oooool2
o`0000;ooooo0_l00029ooooo`00T_ooool2o`0001Sooooo0ol0000?ooooo`;o00006Oooool2o`00
08gooooo002Booooo`;o00006?ooool00ol0003oooooooooo`2iooooo`00VOooool2o`00017ooooo
00?o0000ooooooooool04?ooool2o`000:Oooooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool2o`0000;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooooooo
ool04?ooool2o`0001Wooooo0_l0002<ooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo0_l00002ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Eooooo`;o
00005?ooool2o`0000Gooooo0_l00025ooooo`00ROooool6o`0000;ooooo00Go410@oooooooooooo
oooooa0@400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool2o`0000oo
oooo0_l0000Kooooo`;o0000QOooool0097ooooo00Ko0000ooooooooooooooooo`000?ooool2o`00
00[ooooo0_l000000omgMgOo<S8booooo`04ooooo`?o00001?ooool2o`0000gooooo0_l0002Toooo
o`00TOooool01_l0003ooooooooooooooooo0000ooooo`;o00002Oooool3o`000003oc8b<_o<c<co
oooo00Cooooo00?o0000ooooooooool04oooool4o`000:;ooooo0027ooooo`;o00002?ooool01Ol@
413ooooooooooooooooo410@00cooooo00Co0000oooooooooooooooo0ol00003ooooo`03o`000?oo
oooooooo01Gooooo1?l0002Pooooo`00Qoooool2o`0000Sooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`04o`000?ooooooooooooooo`?o00000oooool00ol0003oooooooooo`0Gooooo`;o0000
X?ooool0097ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003ooooo
ooooo`0eooooo`;o0000P_ooool009Kooooo0_l0000Dooooo`03o`000?oooooooooo03;ooooo0_l0
00000ooooooo0000o`000022ooooo`00Qoooool2o`0000gooooo0_l0000Dooooo`03o`000?oooooo
oooo03;ooooo0_l00025ooooo`00Qoooool2o`0000gooooo0_l0000Booooo`?o00006_ooool2o`00
01Oooooo0_l00005ooooo`;o0000Ooooool009Kooooo0_l0000Booooo`Go00006?ooool2o`0001Oo
oooo0_l00005ooooo`;o0000Ooooool009_ooooo0ol0000>ooooo`03o`000?oooooooooo03Sooooo
0_l0001oooooo`00Voooool3o`0000gooooo0_l0000jooooo`;o0000Ooooool009Cooooo0_l0000E
ooooo`Co00002?ooool3o`0002_ooooo0_l00021ooooo`00U?ooool2o`0001Kooooo0ol00008oooo
o`?o0000:oooool3o`00083ooooo002Kooooo`;o00003oooool00ol0003oooooooooo`0Kooooo`;o
00006_ooool2o`00083ooooo002Kooooo`;o00003oooool00ol0003oooooooooo`0Kooooo`;o0000
W?ooool009[ooooo0_l0000@ooooo`03o`000?oooooooooo01[ooooo0_l0000Nooooo`?o0000O?oo
ool009[ooooo0_l0000@ooooo`?o00002_ooool2o`0000kooooo0_l0000Nooooo`?o0000O?ooool0
0:cooooo00?o0000ooooooooool02_ooool2o`000:gooooo002/ooooo`03o`000?oooooooooo00[o
oooo0_l000000ooooooo0000o`00000>ooooo`;o00007?ooool2o`0007cooooo002Pooooo`;o0000
2_ooool00ol0003oooooooooo`0=ooooo`;o00003_ooool2o`0001cooooo1?l0001jooooo`00X?oo
ool2o`0000[ooooo00?o0000ooooooooool0?Oooool2o`0007[ooooo002Yooooo`;o000000?ooooo
o`000?ooool0?_ooool2o`0007[ooooo0025ooooo`;o00004?ooool2o`00013ooooo0_l000000ooo
oooo0000ooooo`2jooooo`00QOooool2o`00013ooooo0_l0000Cooooo`03o`000?oooooooooo03_o
oooo0_l0001looooo`00[?ooool3o`0003_ooooo0ol0001kooooo`00WOooool2o`0000gooooo00?o
0000ooooooooool03oooool2o`0002_ooooo0_l0001kooooo`00WOooool2o`0000gooooo00?o0000
ooooooooool03_ooool3o`0002oooooo0_l0001gooooo`00O?ooool2o`0002kooooo00?o0000oooo
ooooool01?ooool2o`0000Sooooo0_l0000]ooooo`;o000000?oooooo`000?l00000Moooool007co
oooo0_l0000^ooooo`03o`000?oooooooooo00Cooooo0_l0000gooooo`;o0000N_ooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo0ol0000Rooooo`;o0000UOooool00:cooooo0ol0000B
ooooo`;o00003_ooool2o`0001Sooooo0_l0001kooooo`00[?ooool00ol0003oooooooooo`07oooo
o`;o00002Oooool2o`0002Sooooo0_l0001kooooo`00[?ooool3o`0000Oooooo0_l0000hooooo`;o
0000M_ooool0093ooooo0_l0000Jooooo`03o`000?oooooooooo047ooooo0_l0001fooooo`00T?oo
ool2o`0000kooooo0_l0000:ooooo`03o`000?oooooooooo047ooooo1?l0001dooooo`00X?ooool2
o`0000[ooooo00?o0000ooooooooool0?_ooool2o`0000?ooooo0_l0001dooooo`00[?ooool00ol0
003oooooooooo`02o`0002;ooooo0_l0000Hooooo`;o0000NOooool008Wooooo00Gok^k^oc8b<_l0
003o0000onk^kP03ooooo`;o00000_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool00_l0000Rooooo`;o00007?ooool3o`0007Cooooo0029oooo
o`05ogMgMonHV9So0000o`000?mgMgL00oooool2o`0000;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400;o00001Oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00;o00004_oo
ool2o`0002cooooo0ol0001dooooo`00POooool6o`0000;ooooo00Go410@o`000?l0003ooooooa0@
4006ooooo`?o00000oooool01?nHV9So8B4Qonk^k_ooool2o`0000Kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02o`0001;ooooo0_l0000>ooooo`;o0000Toooool008?ooooo0_l0
0004ooooo`?o000000?oooooo`000?ooool01Oooool3o`0000Cooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00omgMgOo<S8booooo`04ooooo`?o00009?ooool2o`0009?ooooo0023ooooo`;o00001?ooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool05Oooool2o`000:;ooooo0029ooooo`05oa0@4?oo
ooooooooooooool@41002_ooool2o`0000?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo01Gooooo0_l0000Aooooo`;o00006oooool2o`0007;ooooo
0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool2o`0000Kooooo0_l000001?nj^[[ooooo
oiRHV?l@4104ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0:?ooool2o`0001_o
oooo0_l0001booooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo0_l00007ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool05?ooool2o`00
033ooooo0_l0001aooooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool02_ooool2o`0000Oo
oooo0ol0000^ooooo`Co0000LOooool008oooooo0ol0000Jooooo`03o`000?oooooooooo00[ooooo
0_l00007ooooo`Co0000;Oooool4o`00077ooooo002?ooooo`;o00006oooool00ol0003ooooooooo
o`0Eooooo`;o0000;_ooool4o`00073ooooo002?ooooo`;o00001_ooool2o`0000;ooooo0_l0000?
ooooo`?o0000:_ooool2o`0001_ooooo0ol0001_ooooo`00Poooool2o`0000[ooooo0_l00006oooo
o`;o00000_ooool2o`0000oooooo00?o0000ooooooooool05oooool2o`00017ooooo0_l0000Loooo
o`?o0000K_ooool008?ooooo0_l0000Wooooo`?o00005oooool2o`0002kooooo1?l0001^ooooo`00
[?ooool3o`0002Sooooo0_l0000Looooo`?o0000L?ooool007_ooooo0_l0000<ooooo`;o00008Ooo
ool00ol0003oooooooooo`0Xooooo`;o00007?ooool5o`0006kooooo001kooooo`;o00003?ooool2
o`0000Sooooo0_l0000Gooooo`03o`000?oooooooooo04Oooooo1?l0001^ooooo`00Toooool2o`00
01Oooooo00?o0000ooooooooool02oooool2o`0000[ooooo0_l0000[ooooo`;o0000Loooool00:co
oooo00?o0000ooooooooool02oooool2o`0000[ooooo1?l0000?ooooo`;o00006?ooool2o`0007?o
oooo002/ooooo`?o00006Oooool2o`0000oooooo0_l0002=ooooo`00[?ooool00ol0003ooooooooo
o`0Xooooo`;o0000Soooool00:cooooo00?o0000ooooooooool0:?ooool2o`0008oooooo002/oooo
o`03o`000?oooooooooo00Cooooo0_l00006ooooo`;o00007?ooool2o`0008gooooo002Cooooo`;o
00005oooool00ol0003oooooooooo`04ooooo`;o00001_ooool2o`0001cooooo0_l0002=ooooo`00
P_ooool2o`0000oooooo0_l0000Gooooo`03o`000?oooooooooo0;Wooooo0022ooooo`;o0000:?oo
ool00ol0003oooooooooo`05ooooo`;o00004_ooool2o`0002[ooooo0ol0001aooooo`00U_ooool2
o`0001Cooooo00?o0000ooooooooool01Oooool2o`0001;ooooo0_l0000Zooooo`?o00000oooool2
o`0006cooooo002Fooooo`;o00005?ooool00ol0003oooooooooo`0Jooooo`;o0000;oooool2o`00
06cooooo002/ooooo`?o00006_ooool2o`0002[ooooo0_l0001aooooo`00[?ooool00ol0003ooooo
ooooo`06ooooo`;o00009_ooool2o`0001Kooooo0_l0001aooooo`00S_ooool2o`0001cooooo00?o
0000ooooooooool01_ooool2o`0002?ooooo0_l000000ooooooo0000o`000029ooooo`002Oooool4
o`000003oa0@4?oooooooooo01Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go000000Goooooo`000?l0003oooooodA4
A002o`000003oc8b<_oMgMgooooo01Gooooo00?o0000ooooooooool06?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go000000Goooooo`000?l0003oooooodA4A002o`000003
oc8b<_oMgMgooooo00kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4
A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd06?ooool4o`000003oa0@
4?oooooooooo01;ooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0000Cooooo00KoV9RHo`000?l0003oooooodA4A?oo
ool2o`0000Cooooo00?oMgMgoc8b<_ooool05Oooool00ol0003oooooooooo`0Hooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03
ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?l0003o0000ogMgM`05ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEE
ojVYZOooool01oooool00omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo0006o`00
00Gooooo00?o0000ooooooooool04?ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=
ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool01Oooool6o`0000;ooooo00Go410@
oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?oo
ooooooooooooool@41001Oooool2o`0000Cooooo0_l000001?lQ8B7ok^k^ooooooooool2o`0000Go
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Hooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00gooooo00Go410@oooo
ool0003o0000oa0@4002o`0000kooooo00?o0000ooooooooool03Oooool01Ol@413ooooooooooooo
oooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooo
oooooooo000000oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000_o
oooo0_l000000onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo01Gooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`02o`0000gooooo00CoV9RHob4Q8Ol0003o00001_ooool00omg
MgOo<S8booooo`0>ooooo`04o`000?ooooooooooooooo`?o00003Oooool00omgMgOo<S8booooo`0>
ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb
<S;ooooo01Wooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`03oooool01Ol0003ooooooooooooooooo000000Gooooo0ol00006ooooo`03ogMgMomVIVKo
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Fooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool00_l0000>ooooo`03ogMgMol0003o000000?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00?ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00oooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c00Jooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooo
oooo01Sooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o
0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool0
4Oooool01Ol@413ooooooooooooooooo410@00Gooooo0ol00007ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool06?ooool3o`0001Sooooo00Go410@o`000?l0003ooooooa0@400?oooo
o`?o00000_ooool00ol0003oooooooooo`0Aooooo`06oa0@4?ooooooooooooooool@413ooooo0ol0
0008ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVY
ZOmgMgOooooo00?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Dooooo`002ooo
ool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooo
oooooooooooo<S8b00Cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000
okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool03_oo
ool2o`0000Sooooo00GoMgMgo`000?l0003oV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@
41000_l00002ooooo`03o`000?oooooooooo017ooooo00CoMgMgoiRHV?ooooooV9RH1Ol00008oooo
o`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooo
oooooooooolb<S801?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Cooooo0009
ooooo`03oeEEEOmVIVKo000001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?oo
ool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00004?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Ko00005Oooool00ol0
003oooooooooo`0>ooooo`;o00002?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c004ooooo`Co00004?ooool01?o^k^ko<S8bo`000?lb<S82o`000003oooo
ool0003o000000Sooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Co
oooo1?l0000Iooooo`03oeEEEOmVIVKo000001Kooooo002Eooooo`;o00005Oooool00ol0003ooooo
ooooo`1<ooooo`;o0000Joooool00:cooooo00?o0000ooooooooool06_ooool2o`0002gooooo0_l0
00000ooooooo0000o`00001[ooooo`00P_ooool2o`0002Sooooo00?o0000ooooooooool06_ooool2
o`0001;ooooo0_l0000Iooooo`;o0000Hoooool2o`0000;ooooo0_l00005ooooo`00P_ooool2o`00
00kooooo0_l0000Hooooo`03o`000?oooooooooo01[ooooo0_l0000Booooo`;o0000O_ooool01_o^
k^ko8B4QohN7Qonj^[[o0000omgMg@Gooooo002Booooo`;o00006?ooool00ol0003oooooooooo`07
ooooo`;o0000Y_ooool01?oMgMgo0000oa0@4?o<c<`6ooooo`001oooooooo`0004co00003?ooool0
1?o^k^ko8B4Qoa0@4?o^k^h6ooooo`001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo0ol00005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`Co00001_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00Co8B4QogMgMomgMgOo<S8b1_oo
ool000Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`08ooooo`;o00007Oooool0
0ol0003oooooooooo`03ooooo`Co00007oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool02Oooool2o`0000;ooooo0_l00005ooooo`00[?ooool00ol0
003oooooooooo`08ooooo`;o00008oooool4o`0008Sooooo002/ooooo`03o`000?oooooooooo00ko
oooo0ol0000:ooooo`;o00004?ooool2o`0001[ooooo0_l0001^ooooo`00[?ooool00ol0003ooooo
ooooo`07ooooo`;o00001Oooool3o`0000[ooooo0_l0000@ooooo`;o00006_ooool2o`0006kooooo
0029ooooo`;o00008Oooool00ol0003oooooooooo`07ooooo`;o0000A?ooool2o`0006[ooooo0029
ooooo`;o00008Oooool01?l0003oooooooooooooool2o`0004[ooooo0_l0001Zooooo`00[?ooool3
o`000003ooooool0003o00000;Kooooo001jooooo`;o0000<?ooool00ol0003oooooooooo`19oooo
o`;o0000K_ooool007[ooooo0_l0000>ooooo`;o00008?ooool00ol0003oooooooooo`0/ooooo`;o
00006oooool2o`0006kooooo002:ooooo`;o00008?ooool00ol0003oooooooooo`0@ooooo`;o0000
6_ooool2o`00023ooooo0_l0001Yooooo`00U_ooool2o`0001Cooooo00?o0000ooooooooool04?oo
ool2o`0001cooooo0_l0000Nooooo`;o0000JOooool008?ooooo0_l0000Aooooo`;o00005?ooool0
0ol0003oooooooooo`0]ooooo`?o0000ROooool008?ooooo0_l0000Wooooo`03o`000?oooooooooo
02cooooo0ol0000Pooooo`;o0000J?ooool008Wooooo0_l00004ooooo`;o00006oooool00ol0003o
ooooooooo`0Kooooo`;o00003oooool2o`00027ooooo0_l0001Xooooo`00ROooool2o`0000Cooooo
0_l0000Kooooo`03o`000?oooooooooo01_ooooo0_l0000Cooooo`;o00006Oooool2o`0006cooooo
002/ooooo`?o00003Oooool2o`0001gooooo0ol000000ooooooo0000o`00000Iooooo`;o0000K?oo
ool008Wooooo0_l0000Qooooo`03o`000?oooooooooo00Oooooo0_l00004ooooo`;o00007Oooool3
o`0008[ooooo0023ooooo`;o00001?ooool2o`00027ooooo00?o0000ooooooooool01oooool2o`00
02?ooooo0_l000000ooooooo0000o`00000Iooooo`;o0000KOooool008?ooooo0_l00004ooooo`?o
00002oooool2o`0001?ooooo00?o0000ooooooooool06_ooool2o`0001?ooooo0_l0000Iooooo`;o
0000KOooool008Wooooo0ol0000;ooooo`;o00004oooool00ol0003oooooooooo`0Iooooo`?o0000
WOooool00:cooooo00?o0000ooooooooool03_ooool2o`0000Wooooo0_l0000Cooooo`;o0000ROoo
ool008?ooooo0_l0000Wooooo`03o`000?oooooooooo00kooooo0_l00009ooooo`;o00004oooool2
o`0008Wooooo0023ooooo`;o00009oooool00ol0003oooooooooo`06ooooo`;o00001oooool2o`00
03cooooo0_l0001Zooooo`00[?ooool3o`0000Kooooo0_l00007ooooo`;o00007Oooool2o`0001co
oooo0ol0001Zooooo`00[?ooool00ol0003oooooooooo`0^ooooo`;o00007?ooool2o`0006_ooooo
002/ooooo`03o`000?oooooooooo00cooooo0_l0002[ooooo`00ROooool2o`0000cooooo0_l0000C
ooooo`03o`000?oooooooooo00Gooooo0_l00005ooooo`;o0000Zoooool008Wooooo0_l0000<oooo
o`;o00000oooool2o`0000kooooo00?o0000ooooooooool01Oooool2o`000;;ooooo002Looooo`;o
00003_ooool00ol0003oooooooooo`0Jooooo`;o0000WOooool00:cooooo00?o0000ooooooooool0
1_ooool2o`0001;ooooo0_l0000Aooooo`;o0000R_ooool009Cooooo0_l0000Fooooo`03o`000?oo
oooooooo00Kooooo0_l00003ooooo`;o00002oooool2o`0001?ooooo0_l0002:ooooo`00U?ooool2
o`0001Kooooo1?l0000:ooooo`;o00002oooool2o`0002kooooo0_l000001?oooooo0000o`000?l0
001[ooooo`00U?ooool2o`0001Kooooo00Co0000ooooool0003o00006Oooool2o`0002cooooo0_l0
00001?oooooo0000o`000?l0001[ooooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool06?oo
ool4o`0002oooooo0_l0001/ooooo`00[?ooool00ol0003oooooooooo`0Hooooo`;o0000Woooool0
0:Oooooo0_l00003ooooo`03o`000?oooooooooo0;Wooooo0023ooooo`;o00002_ooool4o`0001Co
oooo0_l00003ooooo`03o`000?oooooooooo02Wooooo0_l0002>ooooo`00Poooool2o`0000Cooooo
00Kok^k^oc8b<_l0003o<S8bonk^k_ooool4o`0000;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo02Wooooo0_l0002>ooooo`00O?ooool2o`00
00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`;o000000?oooooob4Q8OlQ8B401?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`2iooooo`00O?ooool2o`0000_ooooo00Go410@oooooooooooooooooa0@4002ooooo`;o00002?oo
ool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0000Fooooo`;o0000XOoo
ool008Wooooo00Go0000ooooooooooooooooo`000008ooooo`;o00000oooool00onHV9So8B4Qonk^
kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool05_ooool2o`0003?ooooo0_l0
001/ooooo`00ROooool00ol0003oooooo`000002o`0000Sooooo0_l00004ooooo`03ogMgMomVIVKo
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo04_ooooo0_l0
001/ooooo`00Q?ooool2o`0000?ooooo00Go410@ooooool0003o0000oa0@400?ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2iooooo`00Q?ooool2
o`0000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo0_l0000Mooooo`;o0000
SOooool008Cooooo0_l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@
o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`04o`000?ooooooooooooooo`;o00001oooool3o`00
01cooooo0ol0002=ooooo`00Q?ooool2o`0000_ooooo0_l00008ooooo`;o00003oooool01?l0003o
ooooooooooooool2o`0000Gooooo1?l0000:ooooo`;o00004?ooool3o`0008kooooo0024ooooo`;o
00002oooool2o`0000Sooooo0_l0000=ooooo`?o00002_ooool3o`0000_ooooo0_l0000@ooooo`;o
0000Soooool008Cooooo0_l0000<ooooo`;o00005_ooool3o`0000_ooooo0_l0000;ooooo`;o0000
XOooool009;ooooo0_l0000Hooooo`?o00005_ooool2o`000:7ooooo002Yooooo`;o000000?ooooo
o`000?ooool0^_ooool008Gooooo0_l0000Rooooo`;o000000?oooooo`000?ooool05_ooool2o`00
033ooooo0_l0001`ooooo`00QOooool2o`0002Gooooo00?o0000ooooooooool05Oooool2o`0002go
oooo1Ol0001`ooooo`00[?ooool00ol0003oooooooooo`14ooooo`Co0000LOooool008Gooooo0_l0
000Uooooo`03o`000?oooooooooo04Cooooo1?l0001aooooo`00QOooool2o`0000Kooooo0_l0000M
ooooo`03o`000?oooooooooo04Cooooo1?l0001aooooo`00QOooool2o`0000Kooooo0_l0000Doooo
o`;o00001oooool00ol0003oooooooooo`07ooooo`;o0000/?ooool008Gooooo0_l0000Looooo`;o
00001oooool3o`0000Oooooo0_l0000<ooooo`;o0000X_ooool00:cooooo00?o0000ooooooooool0
5?ooool3o`000:;ooooo002/ooooo`03o`000?oooooooooo01Cooooo0_l0002Sooooo`00[?ooool0
0ol0003oooooooooo`0Booooo`;o0000YOooool00:cooooo00?o0000ooooooooool04_ooool2o`00
0:Gooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo02?ooooo
0_l0002Dooooo`00[?ooool00ol0003oooooooooo`0Sooooo`;o0000U?ooool00:cooooo0ol0000T
ooooo`?o0000T_ooool008gooooo0_l0000Kooooo`?o00009_ooool3o`0009;ooooo002=ooooo`;o
00006oooool3o`0002Sooooo0_l0002Aooooo`00UOooool2o`0001Gooooo00?o0000ooooooooool0
8Oooool2o`0000?ooooo0_l0002Aooooo`00UOooool3o`0001Cooooo00?o0000ooooooooool03_oo
ool2o`00017ooooo0_l0002Fooooo`00U_ooool2o`0001Cooooo00Co0000oooooooooooooooo0_l0
000;ooooo`;o0000ZOooool009Kooooo0_l0000=ooooo`;o00001Oooool01?l0003ooooooooooooo
ool2o`0000[ooooo0_l0002Zooooo`00Qoooool2o`0000Gooooo0_l00006ooooo`;o00003Oooool2
o`0000Gooooo00Co0000oooooooooooooooo0_l0000:ooooo`;o00005?ooool2o`0009Cooooo0027
ooooo`;o00001Oooool2o`0001?ooooo0_l00007ooooo`?o000000?oooooo`000?l000008?ooool2
o`0009Cooooo0027ooooo`;o00006_ooool3o`0000Kooooo00?o0000ooooooooool03?ooool2o`00
0:_ooooo002Tooooo`;o00001_ooool00ol0003oooooooooo`0<ooooo`;o0000Zoooool008Sooooo
0_l0000Rooooo`03o`000?oooooooooo0;Wooooo0028ooooo`;o00008_ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`0:ooooo`;o0000[Oooool008Wooooo0_l00006oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@05ooooo`03o`000?oooooooooo00[ooooo0_l0000Aooooo`?o00007oooool2o`0007Sooooo0029
ooooo`;o00001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo00Cooooo0_l0000<ooooo`;o00004?ooool3o`0001oooooo0_l0001hooooo`00TOooool0
1Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool2o`0000cooooo0_l0
002/ooooo`00ROooool2o`0000Kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo00?ooooo1?l0002iooooo`00ROooool2o`0000Kooooo00Go0000ooooooooooooooooo`00
000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool2o`00027ooooo0_l0000Iooooo`;o0000
OOooool0097ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool07oooool2o`0001Wooooo0ol0001looooo`00TOooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool2o`00023ooooo0_l0000Iooooo`Co0000
O?ooool0097ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool2o`0001oooooo
0ol0000Iooooo`;o0000O_ooool009;ooooo0_l0000;ooooo`;o00002oooool00ol0003ooooooooo
o`0Looooo`?o0000V_ooool009;ooooo0_l0000;ooooo`;o00002oooool00ol0003oooooooooo`08
ooooo`;o00003_ooool2o`0000;ooooo0_l0002Kooooo`00Woooool2o`0000Gooooo0_l00004oooo
o`03o`000?oooooooooo00Sooooo0_l0000>ooooo`;o0000Woooool00:Kooooo0_l00004ooooo`?o
00006?ooool2o`0009oooooo002Oooooo`;o00001Oooool2o`0000Cooooo00?o0000ooooooooool0
^Oooool008Wooooo0_l0000Dooooo`?o00000oooool2o`0000Gooooo00?o0000ooooooooool01Ooo
ool2o`000;;ooooo0029ooooo`;o00005Oooool2o`0000?ooooo0_l00005ooooo`03o`000?oooooo
oooo00Gooooo0_l0002booooo`00[?ooool00ol0003oooooooooo`02ooooo`;o00005_ooool2o`00
09gooooo002/ooooo`03o`000?oooooooooo00;ooooo0_l0000Fooooo`;o0000WOooool00:cooooo
00?o0000ooooooooool06?ooool2o`0009oooooo002/ooooo`03o`000?oooooooooo01Sooooo0_l0
002Oooooo`00S?ooool2o`0001kooooo0ol0000Eooooo`;o0000X_ooool008cooooo0_l0000Noooo
o`03o`000?oooooooooo01Gooooo0_l0002Rooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
[?ooool00ol0003oooooooooo`2iooooo`00SOooool2o`0000Sooooo0_l0000Cooooo`03o`000?oo
oooooooo0;Wooooo002=ooooo`;o00002?ooool2o`0001?ooooo00Co0000ooooool0003o0000^?oo
ool008cooooo0_l00009ooooo`;o00004oooool01?l0003oooooo`000?l0000booooo`;o0000Q?oo
ool008cooooo0ol0000Looooo`?o00004oooool2o`0001oooooo0_l00024ooooo`00SOooool2o`00
01cooooo1?l0000Booooo`;o0000YOooool00:Wooooo0_l000000ooooooo0000ooooo`2jooooo`00
SOooool2o`0001[ooooo0_l000000ooooooo0000ooooo`2jooooo`00SOooool4o`0001_ooooo00?o
0000ooooooooool0^Oooool008oooooo0_l0000Kooooo`03o`000?oooooooooo00cooooo0_l00002
ooooo`;o0000Yoooool00:cooooo00?o0000ooooooooool03?ooool2o`0000;ooooo0_l0002Woooo
o`00Yoooool2o`0000?ooooo00?o0000ooooooooool03_ooool2o`0001gooooo0_l0002:ooooo`00
X_ooool2o`0000?ooooo0_l00003ooooo`03o`000?oooooooooo00kooooo0_l0000Mooooo`;o0000
R_ooool009oooooo1Ol00008ooooo`03o`000?oooooooooo00gooooo0_l0002Zooooo`00TOooool2
o`0000cooooo1Ol00008ooooo`?o00003Oooool2o`0001_ooooo0_l0002=ooooo`00TOooool2o`00
017ooooo0_l00006ooooo`03o`000?oooooooooo00_ooooo0_l0000Mooooo`;o0000SOooool00:Co
oooo0_l00006ooooo`03o`000?oooooooooo00_ooooo0_l0000Looooo`;o0000S_ooool00:cooooo
00?o0000ooooooooool0:Oooool2o`0008kooooo002/ooooo`03o`000?oooooooooo0;Wooooo0029
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0^Oooool008Wooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool09oooool2o`00093ooooo0029ooooo`05oa0@4?oo
ooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool09oooool2o`00093ooooo0029ooooo`05o`000?ooooooooooooooool00000
3_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002iooooo`00ROoo
ool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool09Oooool2o`0009;ooooo0029ooooo`05oa0@
4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool09Oooool2o`0009;ooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`06ooooo`;o00007Oooool2o`0009;ooooo0029ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo00Kooooo0_l0000Moooo
o`;o0000T_ooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0^Oooool009Sooooo0_l0000Booooo`?o0000^Oooool0
09Sooooo0_l0000Booooo`Go0000]oooool00:cooooo00?o0000ooooooooool00_l0002gooooo`00
V_ooool2o`00013ooooo00?o0000ooooooooool0^Oooool009[ooooo0_l0000@ooooo`;o0000^_oo
ool009Sooooo0_l0000Booooo`;o0000^_ooool009Sooooo0_l00004ooooo`;o00003?ooool00ol0
003oooooooooo`2iooooo`00W_ooool2o`0000cooooo00?o0000ooooooooool0^Oooool00:[ooooo
1Ol0000Iooooo`;o0000W_ooool00:Cooooo0_l00002ooooo`Go00006oooool2o`0009kooooo002T
ooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool06?ooool2o`0009oooooo002Rooooo`Co00001_ooool00ol0003oooooooooo`0Hooooo`;o
0000Woooool00:3ooooo1_l00006ooooo`03o`000?oooooooooo0;Wooooo002Pooooo`;o00002_oo
ool00ol0003oooooooooo`0Fooooo`;o0000XOooool00:cooooo00?o0000ooooooooool05_ooool2
o`000:7ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool03oooool2o`000:Sooooo002/ooooo`03o`000?oooooooooo00oooooo0_l0002Xooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Roooo
o`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`06ooooo`;o0000/Oooool00:Co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`;o0000/Oooool00:Cooooo
00?o0000ooooooooool01Oooool3o`000;Wooooo002Tooooo`03o`000?oooooooooo0<7ooooo002T
ooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03
o`000?oooooooooo0<7ooooo002Rooooo`03oeEEEOmVIVKo00000<?ooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo002Zooooo`04oa0@4?l0003o0000o`000;[o
oooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[
ooooo`06o`000?mgMgOo0000o`000?mEEEGok^k^]oooool00:_ooooo00Ko0000oeEEEOo^k^kooooo
ogMgMomEEEFgooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo0;Gooooo
002[ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0]Oooool00:_ooooo00Ko0000
oeEEEOo^k^koooooogMgMomVIVJgooooo`00Z_ooool00ol@413o0000ogMgM`02o`000003ofIVI_o^
k^kooooo0;Kooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.59604 .27699 Mdot
.64532 .39508 Mdot
.49944 .5811 Mdot
.48 .24811 Mdot
.47854 .18331 Mdot
.45589 .12532 Mdot
.51728 .51796 Mdot
.54852 .07407 Mdot
.4909 .03271 Mdot
.55766 .58354 Mdot
.51427 .73351 Mdot
.61859 .16665 Mdot
.66682 .55323 Mdot
.55155 .63242 Mdot
.66247 .25091 Mdot
.54004 .36809 Mdot
.50177 .8328 Mdot
.66673 .5607 Mdot
.40945 .57961 Mdot
.55774 .86427 Mdot
.65235 .62043 Mdot
.65837 .50006 Mdot
.65172 .57381 Mdot
.66172 .59349 Mdot
.69587 .31082 Mdot
.59158 .40426 Mdot
.4585 .77663 Mdot
.40823 .52885 Mdot
.52152 .91149 Mdot
.65054 .43548 Mdot
.62531 .70025 Mdot
.46525 .02683 Mdot
.55259 .08735 Mdot
.41938 .75748 Mdot
.39963 .65174 Mdot
.53144 .88385 Mdot
.37286 .55401 Mdot
.41635 .63377 Mdot
.44304 .92452 Mdot
.61535 .1563 Mdot
.68163 .26701 Mdot
.41151 .72908 Mdot
.4064 .2834 Mdot
.59013 .25433 Mdot
.55658 .20093 Mdot
.54097 .27013 Mdot
.53391 .67795 Mdot
.39896 .17141 Mdot
.60247 .56859 Mdot
.48864 .94206 Mdot
.40429 .15048 Mdot
.43276 .9138 Mdot
.63006 .88969 Mdot
.39669 .37851 Mdot
.39104 .4887 Mdot
.52719 .06529 Mdot
.56635 .09641 Mdot
.5198 .80646 Mdot
.37662 .34293 Mdot
.5446 .18307 Mdot
.55818 .31132 Mdot
.74829 .45762 Mdot
.42166 .87757 Mdot
.4675 .7365 Mdot
.59164 .14601 Mdot
.48608 .02464 Mdot
.55604 .58599 Mdot
.54108 .38251 Mdot
.42525 .69747 Mdot
.65215 .63615 Mdot
.53503 .78907 Mdot
.49213 .67075 Mdot
.54826 .62401 Mdot
.56151 .51967 Mdot
.42145 .87689 Mdot
.44982 .59379 Mdot
.62932 .89059 Mdot
.58727 .42336 Mdot
.4557 .94554 Mdot
.58406 .62725 Mdot
.58973 .78576 Mdot
.64982 .4406 Mdot
.47077 .25154 Mdot
.41216 .73548 Mdot
.51902 .04551 Mdot
.53195 .33249 Mdot
.48515 .18521 Mdot
.53714 .27483 Mdot
.54923 .75369 Mdot
.54449 .39827 Mdot
.7011 .32701 Mdot
.71678 .72379 Mdot
.4319 .65249 Mdot
.52882 .24968 Mdot
.43707 .67341 Mdot
.73454 .67994 Mdot
.55274 .62605 Mdot
.4362 .06495 Mdot
.62365 .89971 Mdot
.56245 .73089 Mdot
.61196 .31357 Mdot
.57593 .69195 Mdot
.63099 .18974 Mdot
.60729 .29079 Mdot
.62753 .71229 Mdot
.41209 .72381 Mdot
.50547 .83596 Mdot
.40638 .49553 Mdot
.43161 .65134 Mdot
.646 .65438 Mdot
.55799 .59666 Mdot
.46013 .25454 Mdot
.46695 .02724 Mdot
.56707 .84303 Mdot
.47366 .28913 Mdot
.5742 .35947 Mdot
.46876 .01722 Mdot
.46018 .02404 Mdot
.37423 .43352 Mdot
.66474 .5629 Mdot
.73886 .40314 Mdot
.64181 .63709 Mdot
.52649 .90721 Mdot
.64886 .64705 Mdot
.50271 .27833 Mdot
.54358 .87599 Mdot
.74327 .64375 Mdot
.64072 .41503 Mdot
.52953 .43957 Mdot
.6575 .54209 Mdot
.62708 .35585 Mdot
.64527 .20785 Mdot
.4462 .13475 Mdot
.42181 .20565 Mdot
.49484 .9457 Mdot
.39519 .79486 Mdot
.52535 .90306 Mdot
.54792 .6234 Mdot
.58806 .13283 Mdot
.66066 .24375 Mdot
.74742 .56193 Mdot
.42178 .4204 Mdot
.41987 .67241 Mdot
.50481 .82875 Mdot
.56601 .8494 Mdot
.49985 .02666 Mdot
.43327 .26331 Mdot
.54376 .28707 Mdot
.72526 .34233 Mdot
.58479 .66685 Mdot
.46499 .79194 Mdot
.66392 .58761 Mdot
.50162 .6432 Mdot
.52987 .17428 Mdot
.39459 .78447 Mdot
.42739 .89611 Mdot
.48629 .02101 Mdot
.37243 .49746 Mdot
.39494 .78819 Mdot
.60297 .47453 Mdot
.4689 .95444 Mdot
.65203 .20188 Mdot
.54744 .85748 Mdot
.42536 .20162 Mdot
.61556 .33088 Mdot
.49935 .02737 Mdot
.62408 .72504 Mdot
.42843 .71076 Mdot
.41592 .8785 Mdot
.49026 .9362 Mdot
.42231 .44568 Mdot
.43226 .721 Mdot
.50673 .21693 Mdot
.4329 .26012 Mdot
.57652 .12042 Mdot
.73641 .67107 Mdot
.52819 .17292 Mdot
.48968 .30497 Mdot
.49101 .94363 Mdot
.44065 .93362 Mdot
.63925 .19132 Mdot
.5575 .43952 Mdot
.68619 .275 Mdot
.5347 .53553 Mdot
.49875 .04197 Mdot
.7392 .65199 Mdot
.43372 .05954 Mdot
.64973 .20033 Mdot
.40772 .27062 Mdot
.73005 .37477 Mdot
.56954 .84487 Mdot
.48532 .72951 Mdot
.74508 .46009 Mdot
.53685 .0637 Mdot
.69512 .28312 Mdot
.63598 .19512 Mdot
.52374 .24216 Mdot
.71473 .74218 Mdot
.48547 .86349 Mdot
.46168 .30792 Mdot
.46564 .30254 Mdot
.4838 .68414 Mdot
.49143 .19515 Mdot
.70326 .76723 Mdot
.62347 .35009 Mdot
.5121 .66302 Mdot
.48116 .11581 Mdot
.44114 .29293 Mdot
.53649 .54956 Mdot
.51852 .72715 Mdot
.66638 .50576 Mdot
.58427 .40606 Mdot
.62217 .72913 Mdot
.55568 .44397 Mdot
.61955 .3426 Mdot
.58075 .39563 Mdot
.65826 .21319 Mdot
.53747 .50371 Mdot
.55618 .20905 Mdot
.59625 .13017 Mdot
.56996 .34517 Mdot
.39654 .19519 Mdot
.63273 .7043 Mdot
.56922 .82066 Mdot
.55302 .44355 Mdot
.45 .20833 Mdot
.6346 .34981 Mdot
.42083 .52107 Mdot
.66277 .25062 Mdot
.74043 .3986 Mdot
.52051 .31122 Mdot
.48287 .3393 Mdot
.68524 .79517 Mdot
.57836 .6696 Mdot
.47925 .7879 Mdot
.73578 .39856 Mdot
.42528 .69191 Mdot
.61404 .30446 Mdot
.65327 .59886 Mdot
.62221 .34066 Mdot
.74808 .46666 Mdot
.42032 .20521 Mdot
.61558 .75035 Mdot
.53534 .78836 Mdot
.44865 .03707 Mdot
.43538 .6611 Mdot
.38317 .69454 Mdot
.52733 .78363 Mdot
.53893 .78183 Mdot
.42883 .89763 Mdot
.69422 .28473 Mdot
.47307 .28997 Mdot
.47162 .7313 Mdot
.37502 .58256 Mdot
.5964 .44838 Mdot
.43404 .72622 Mdot
.39012 .52138 Mdot
.44596 .57105 Mdot
.57172 .10649 Mdot
.38541 .25328 Mdot
.59424 .61494 Mdot
.48082 .7874 Mdot
.56386 .83103 Mdot
.51579 .37167 Mdot
.57839 .68017 Mdot
.59044 .27056 Mdot
.51922 .71481 Mdot
.46952 .12317 Mdot
.50859 .91389 Mdot
.5993 .51323 Mdot
.54426 .87136 Mdot
.39076 .47482 Mdot
.56191 .55963 Mdot
.58935 .6198 Mdot
.40266 .82574 Mdot
.55836 .43762 Mdot
.41395 .34854 Mdot
.41749 .10444 Mdot
.53245 .69558 Mdot
.50924 .14325 Mdot
.48308 .94994 Mdot
.52433 .39304 Mdot
.55931 .51454 Mdot
.37291 .46543 Mdot
.61637 .16734 Mdot
.40619 .49203 Mdot
.51183 .59294 Mdot
.4856 .19726 Mdot
.59508 .79867 Mdot
.54669 .29024 Mdot
.59491 .77331 Mdot
.73669 .65779 Mdot
.38047 .30765 Mdot
.6438 .21695 Mdot
.39369 .21442 Mdot
.50697 .39992 Mdot
.37064 .51042 Mdot
.74149 .46168 Mdot
.61184 .76651 Mdot
.65691 .24097 Mdot
.39078 .92083 Mdot
.59724 .58176 Mdot
.3932 .386 Mdot
.62711 .35114 Mdot
.4565 .03053 Mdot
.68478 .28001 Mdot
.53251 .68509 Mdot
.42434 .08777 Mdot
.5982 .45754 Mdot
.44066 .37597 Mdot
.66427 .51995 Mdot
.49626 .8423 Mdot
.66252 .56611 Mdot
.72102 .33408 Mdot
.49129 .30236 Mdot
.56995 .23255 Mdot
.41253 .72887 Mdot
.60279 .16036 Mdot
.51201 .35377 Mdot
.64697 .20465 Mdot
.72884 .40077 Mdot
.75346 .55833 Mdot
.51874 .31253 Mdot
.43768 .14854 Mdot
.41602 .75694 Mdot
.40546 .82311 Mdot
.43904 .2292 Mdot
.43944 .37383 Mdot
.5156 .46016 Mdot
.51054 .82644 Mdot
.57834 .10819 Mdot
.37421 .54186 Mdot
.44349 .69826 Mdot
.66308 .49843 Mdot
.53024 .43844 Mdot
.48035 .68661 Mdot
.6373 .35883 Mdot
.44097 .14712 Mdot
.42528 .20157 Mdot
.60293 .47908 Mdot
.48715 .19258 Mdot
.65777 .85159 Mdot
.59819 .48411 Mdot
.64725 .44129 Mdot
.45671 .72298 Mdot
.5474 .08554 Mdot
.46385 .78057 Mdot
.52727 .89925 Mdot
.65332 .49388 Mdot
.42083 .5599 Mdot
.57135 .36595 Mdot
.74864 .55417 Mdot
.60842 .15065 Mdot
.37229 .59086 Mdot
.52987 .88767 Mdot
.60214 .54482 Mdot
.47261 .86346 Mdot
.50492 .92159 Mdot
.57934 .67263 Mdot
.61012 .15372 Mdot
.75827 .54363 Mdot
.61292 .75665 Mdot
.64574 .20997 Mdot
.65181 .21252 Mdot
.67492 .24618 Mdot
.46116 .68047 Mdot
.58459 .64677 Mdot
.66457 .25241 Mdot
.5667 .0985 Mdot
.45632 .67264 Mdot
.61208 .73834 Mdot
.5962 .51807 Mdot
.47065 .11336 Mdot
.60778 .3038 Mdot
.45082 .04343 Mdot
.61436 .30647 Mdot
.37156 .50116 Mdot
.37974 .64486 Mdot
.65161 .56852 Mdot
.37908 .68626 Mdot
.65618 .54302 Mdot
.68508 .28737 Mdot
.38007 .33205 Mdot
.52522 .16397 Mdot
.4966 .65465 Mdot
.71753 .35891 Mdot
.56151 .72922 Mdot
.51421 .44779 Mdot
.63804 .18683 Mdot
.65089 .64141 Mdot
.43465 .40576 Mdot
.56033 .5448 Mdot
.58609 .39174 Mdot
.46659 .78686 Mdot
.40196 .15602 Mdot
.64369 .68433 Mdot
.74391 .46568 Mdot
.64248 .19584 Mdot
.46194 .85311 Mdot
.65264 .85367 Mdot
.46374 .85734 Mdot
.42581 .28851 Mdot
.42741 .27584 Mdot
.4487 .39114 Mdot
.57954 .11177 Mdot
.61739 .16557 Mdot
.46263 .78074 Mdot
.41985 .5004 Mdot
.51357 .74605 Mdot
.54492 .37417 Mdot
.7123 .31932 Mdot
.51371 .22033 Mdot
.5609 .83982 Mdot
.4345 .3279 Mdot
.45594 .78244 Mdot
.52002 .38533 Mdot
.50287 .20455 Mdot
.42739 .78631 Mdot
.48144 .79137 Mdot
.50719 .67883 Mdot
.73319 .37407 Mdot
.58306 .12582 Mdot
.49782 .42896 Mdot
.3964 .61834 Mdot
.50416 .83778 Mdot
.56219 .22815 Mdot
.59585 .5379 Mdot
.43402 .7303 Mdot
.71619 .34804 Mdot
.73635 .68532 Mdot
.62503 .33648 Mdot
.59393 .25891 Mdot
.50625 .68583 Mdot
.52661 .07196 Mdot
.67036 .26411 Mdot
.49857 .76413 Mdot
.65232 .50816 Mdot
.64966 .86296 Mdot
.42073 .45473 Mdot
.43087 .46234 Mdot
.44901 .21757 Mdot
.57415 .81618 Mdot
.59217 .58879 Mdot
.71565 .73412 Mdot
.53458 .55116 Mdot
.39341 .45355 Mdot
.42487 .7894 Mdot
.45693 .72843 Mdot
.49701 .31613 Mdot
.56196 .4735 Mdot
.55271 .07939 Mdot
.49548 .30687 Mdot
.47542 .95378 Mdot
.63756 .36775 Mdot
.56648 .22157 Mdot
.54643 .87056 Mdot
.60174 .75721 Mdot
.4836 .85508 Mdot
.7524 .6186 Mdot
.56018 .55165 Mdot
.58075 .11068 Mdot
.69074 .27508 Mdot
.51266 .72856 Mdot
.37094 .54509 Mdot
.59757 .52719 Mdot
.49815 .83406 Mdot
.53312 .89204 Mdot
.60981 .30607 Mdot
.40708 .50933 Mdot
.57111 .36366 Mdot
.42823 .79185 Mdot
.74764 .42647 Mdot
.43533 .16863 Mdot
.45837 .62758 Mdot
.40929 .27094 Mdot
.58685 .62022 Mdot
.47232 .69139 Mdot
.53176 .3527 Mdot
.39413 .41831 Mdot
.40746 .27001 Mdot
.46702 .29684 Mdot
.59404 .44176 Mdot
.48965 .02646 Mdot
.46401 .18609 Mdot
.58358 .25862 Mdot
.43804 .75253 Mdot
.41026 .43365 Mdot
.4413 .62315 Mdot
.43584 .58486 Mdot
.64164 .37696 Mdot
.41649 .1185 Mdot
.54997 .8554 Mdot
.42033 .67109 Mdot
.51191 .92021 Mdot
.63204 .18253 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002Qooooo`;o00002Oooool00ol0003oooooooooo`2iooooo`00
XOooool2o`0000Cooooo0_l00003ooooo`03o`000?oooooooooo0;Wooooo002Nooooo`;o00001ooo
ool2o`0000?ooooo0ol0002iooooo`00W_ooool5o`0000Cooooo0ol000001?oooooo0000o`000?l0
002jooooo`00WOooool2o`000004ooooool0003o0000o`0000Gooooo0_l000001?oooooo0000o`00
0?l0002jooooo`00WOooool2o`0000[ooooo0_l000000ooooooo0000ooooo`2jooooo`00Voooool2
o`0000cooooo0_l000000ooooooo0000ooooo`2jooooo`00Voooool2o`0000oooooo00?o0000oooo
ooooool0^Oooool009_ooooo0_l0000>ooooo`;o0000^oooool009_ooooo0_l0000>ooooo`;o0000
1Oooool2o`000;Cooooo002/ooooo`03o`000?oooooooooo00?ooooo0_l0002dooooo`00[?ooool3
o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002Fooooo`;o00005?ooool00ol0003oooooooooo`2iooooo`00U_ooool3o`0001?ooooo00?o
0000ooooooooool01_ooool2o`000003ooooool0003o00000:kooooo002Gooooo`;o00004oooool0
0ol0003oooooooooo`06ooooo`;o000000?oooooo`000?l00000[_ooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool01Oooool2o`0000Kooooo0_l0002Zooooo`00
[?ooool3o`0000Gooooo0_l00006ooooo`;o0000Z_ooool00:cooooo00?o0000ooooooooool03_oo
ool2o`000:Wooooo002/ooooo`03o`000?oooooooooo00kooooo0_l0002Yooooo`00[?ooool00ol0
003oooooooooo`0<ooooo`;o0000Zoooool009?ooooo0_l0000Gooooo`03o`000?oooooooooo00co
oooo1?l0002Yooooo`00Toooool2o`0001Oooooo00?o0000ooooooooool03_ooool2o`000:Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo01;ooooo0ol0002T
ooooo`00[?ooool3o`0001;ooooo0ol0002Tooooo`00T?ooool2o`0001[ooooo00?o0000oooooooo
ool0^Oooool0093ooooo0_l0000Jooooo`03o`000?oooooooooo01Cooooo0_l0002Sooooo`00[?oo
ool00ol0003oooooooooo`0Dooooo`Go0000X?ooool00:;ooooo0_l00008ooooo`03o`000?oooooo
oooo01Kooooo0ol0002Pooooo`00X_ooool2o`000003ooooool0003o000000Gooooo00?o0000oooo
ooooool05oooool2o`000:3ooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool2o`00
0003oooooolQ8B7o8B4Q00Kooooo00?o0000onk^k_ooool01?ooool00om4A4Co0000o`000002o`00
00Gooooo00?o0000ooooooooool0^Oooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02oooo
o`;o000000?oooooob4Q8OlQ8B401_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool05_ooool2o`000:7ooooo0021ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@00gooooo00CoZJVYoeEEEOl0003o00000oooool2o`0000;ooooo00?o0000
ooooooooool00oooool3o`0001Kooooo1?l0002Oooooo`00ROooool01Ol0003ooooooooooooooooo
000000kooooo00?o8B4Qo`000?l000000oooool2o`000003oooooomgMgOo<S8b00Gooooo00?o0000
ooooooooool06?ooool2o`0009oooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool0
0omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`0Looooo`;o0000Voooool008Wooooo00Go410@oooooooooooooooooa0@400<ooooo`;o000000?o
ZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01[ooooo1?l0
002Kooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@o`000?l0003ooooo
oc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06_ooool2o`0009gooooo
0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00;o0000]oooool00:cooooo00?o0000
ooooooooool00_l0000Iooooo`;o0000W?ooool009Oooooo0ol0000Booooo`03o`000?oooooooooo
01_ooooo0_l0002Looooo`00S?ooool2o`0000Wooooo0ol0000Booooo`?o00008?ooool2o`0009Oo
oooo002;ooooo`?o00007_ooool00ol0003oooooooooo`0Pooooo`?o0000U_ooool008_ooooo0_l0
000Oooooo`03o`000?oooooooooo027ooooo1?l0002Dooooo`00[?ooool00ol0003oooooooooo`0N
ooooo`;o00000oooool2o`0009Cooooo002/ooooo`03o`000?oooooooooo00Gooooo0_l0000Goooo
o`;o0000VOooool00:cooooo00?o0000ooooooooool01Oooool2o`0001cooooo0ol0002Cooooo`00
U_ooool2o`0001Cooooo00?o0000ooooooooool08oooool3o`0009?ooooo002:ooooo`;o00002_oo
ool2o`0001Cooooo00?o0000ooooooooool01_ooool2o`000;7ooooo002:ooooo`;o00008?ooool3
o`0000Kooooo0_l0002aooooo`00[?ooool00ol0003oooooooooo`2iooooo`00Y?ooool2o`0000Ko
oooo00?o0000ooooooooool02oooool2o`0001_ooooo0_l0002?ooooo`00X?ooool2o`0000;ooooo
0_l000000ooooooo0000o`000003ooooo`03o`000?oooooooooo00_ooooo0_l0000Kooooo`;o0000
Soooool00:3ooooo0_l00005ooooo`;o00000oooool00ol0003oooooooooo`0Zooooo`;o0000SOoo
ool00:cooooo00?o0000ooooooooool0:?ooool5o`0008cooooo0029ooooo`;o00007?ooool4o`00
0003ooooool0003ooooo02Wooooo1Ol0002<ooooo`00ROooool2o`0001cooooo1?l000000ooooooo
0000ooooo`0Zooooo`;o000000?oooooo`000?l00000Roooool009?ooooo0_l0000Booooo`;o0000
0oooool3o`0000oooooo0_l0000Kooooo`Co0000ROooool009?ooooo0_l0000Gooooo`?o00003ooo
ool2o`0001cooooo1?l00028ooooo`00TOooool3o`0001Sooooo0ol0000]ooooo`Co0000R?ooool0
097ooooo0ol00007ooooo`;o00003oooool00ol0003oooooooooo`0?ooooo`;o00007?ooool2o`00
08[ooooo002Kooooo`;o00003oooool00ol0003oooooooooo`0?ooooo`;o00007?ooool6o`0008Ko
oooo0028ooooo`;o00008_ooool00ol0003oooooooooo`0_ooooo`Co0000Q_ooool008Sooooo0_l0
000Aooooo`;o00003oooool01?l0003oooooo`000?l0000[ooooo`;o0000Roooool009_ooooo0_l0
000?ooooo`03o`000?oooooo000000?o00004?ooool2o`0001Oooooo0_l0002;ooooo`00[?ooool3
o`000003ooooool0003o0000013ooooo0_l0002Tooooo`00[?ooool00ol0003oooooooooo`0Aoooo
o`;o0000Y_ooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo017ooooo0_l0002Vooooo`00
Uoooool2o`0001?ooooo00?o0000ooooooooool05?ooool2o`000:?ooooo002/ooooo`03o`000?oo
oooooooo01Cooooo0_l0002Sooooo`00[?ooool00ol0003oooooooooo`0`ooooo`;o0000Qoooool0
097ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool01?ooool2o`0002[ooooo1?l00025ooooo`00TOooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool01?ooool2o`0002cooooo0_l00002ooooo`;o0000POooool008Wooooo1_l00002
ooooo`05oa0@4?ooooooooooooooool@41003oooool2o`0000Gooooo00?o0000ooooooooool01_oo
ool2o`0002kooooo0_l00021ooooo`00TOooool01Ol0003ooooooooooooooooo000000cooooo0_l0
00000ooooooo0000o`000005ooooo`?o00001_ooool2o`0002[ooooo0ol00024ooooo`00Q_ooool2
o`0000Wooooo00Go0000ooooooooooooooooo`000008ooooo`;o00000_ooool3o`000003oc8b<_o<
c<cooooo00Cooooo00?o0000ooooooooool06_ooool2o`0001Kooooo0ol00024ooooo`00Q_ooool2
o`0000Wooooo00Go410@oooooooooooooooooa0@4008ooooo`;o00000_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo01Sooooo1_l0002Kooooo`00TOooool01?mgMgOoV9RHoooooonH
V9P2o`0000_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Hooooo`;o00000_oo
ool2o`0009_ooooo002Aooooo`04onk^k_lb<S;o0000oc8b<P?o00002_ooool4o`0000Kooooo00?o
0000ooooooooool0=Oooool2o`0008;ooooo002Fooooo`;o00005?ooool00ol0003oooooooooo`0e
ooooo`;o00000_ooool2o`0007kooooo002=ooooo`?o00007?ooool00ol0003oooooooooo`0:oooo
o`;o00003_ooool2o`0001gooooo0_l0001nooooo`00SOooool3o`0001cooooo00?o0000oooooooo
ool02_ooool2o`0000kooooo0_l0002Mooooo`00U?ooool2o`0001Kooooo0ol00009ooooo`;o0000
4Oooool2o`0001cooooo1?l0001kooooo`00U?ooool2o`0001Kooooo0_l0000:ooooo`;o00004Ooo
ool2o`0001cooooo1?l0001kooooo`00SOooool2o`0001gooooo0_l0000kooooo`;o000000?ooooo
o`000?l00000N_ooool008gooooo0_l0000Mooooo`03o`000?oooooooooo03gooooo0_l0001joooo
o`00Toooool2o`0000kooooo0_l00007ooooo`03o`000?oooooooooo00_ooooo0_l0000]ooooo`;o
000000?oooooo`000?l00000N_ooool009?ooooo0_l0000>ooooo`;o00001oooool00ol0003ooooo
ooooo`0;ooooo`?o00004_ooool2o`0001Sooooo0_l0001mooooo`00V?ooool2o`0000Wooooo0_l0
0007ooooo`03o`000?oooooooooo00cooooo0_l0000Booooo`;o0000Uoooool009Sooooo0_l00007
ooooo`;o00002Oooool00ol0003oooooooooo`2iooooo`00XOooool2o`0000Wooooo0ol0002ioooo
o`00X?ooool2o`0000Oooooo0_l000000ooooooo0000ooooo`0Qooooo`Co0000UOooool008Cooooo
0_l0000Jooooo`;o00001_ooool5o`0002;ooooo1?l0002Eooooo`00Q?ooool2o`0001Wooooo0_l0
0007ooooo`Go00008oooool3o`0009Gooooo002Oooooo`;o00002oooool00ol0003oooooooooo`03
ooooo`;o00002oooool2o`00013ooooo0_l0000Iooooo`;o0000N_ooool00:_ooooo0_l00005oooo
o`;o00002oooool2o`00013ooooo0_l0000Iooooo`;o0000N_ooool00:_ooooo0_l00015ooooo`;o
0000M?ooool00:cooooo00?o0000ooooooooool0@oooool2o`0007Cooooo002/ooooo`?o0000^Ooo
ool009Kooooo0_l0000Dooooo`03o`000?oooooooooo03oooooo0_l0001hooooo`00U_ooool2o`00
01Cooooo00?o0000ooooooooool08oooool2o`0001[ooooo0_l0001hooooo`00Q?ooool2o`0002Ko
oooo00?o0000ooooooooool01oooool2o`0001[ooooo0_l0000Qooooo`;o0000LOooool008Cooooo
0_l0000Vooooo`03o`000?oooooooooo00Oooooo0_l0000Mooooo`;o00007_ooool2o`00077ooooo
002Vooooo`;o00001?ooool00ol0003oooooooooo`0Uooooo`?o0000TOooool008?ooooo0_l0000Q
ooooo`;o00001?ooool00ol0003oooooooooo`0Tooooo`?o00008?ooool2o`00073ooooo0023oooo
o`;o00009oooool00ol0003oooooooooo`0Dooooo`;o00003_ooool2o`00027ooooo0_l0001`oooo
o`00Soooool2o`0001_ooooo00?o0000ooooooooool05?ooool2o`0001?ooooo0_l0000Iooooo`;o
0000Loooool008oooooo0_l0000Kooooo`?o00001oooool2o`0001cooooo1_l0000Iooooo`;o0000
Loooool00:cooooo00Co0000oooooooooooooooo0_l00004ooooo`;o00007?ooool4o`00093ooooo
002/ooooo`04o`000?ooooooooooooooo`;o00009?ooool2o`000003ooooool0003o000001Sooooo
0_l0001cooooo`00[?ooool00ol0003oooooooooo`0Eooooo`;o00004oooool2o`0001Sooooo0_l0
001cooooo`00[?ooool00ol0003oooooooooo`0Dooooo`?o0000X_ooool008Wooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgM
g@05ooooo`03o`000?oooooooooo00[ooooo0_l00008ooooo`;o00005?ooool2o`0008gooooo0029
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool02_ooool2o`0000Sooooo
0_l0000Dooooo`;o0000SOooool0087ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@4100
2_ooool2o`000003oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`;o00001oooool2o`0003gooooo0_l0001]ooooo`00ROooool01Ol0003ooooooooo
oooooooo000000[ooooo0_l000001?ooooooV9RHob4Q8Oo^k^h7ooooo`03ogMgMolb<S;ooooo00Co
oooo0ol00002ooooo`;o00001oooool2o`0001kooooo0_l0000Looooo`?o0000KOooool008Wooooo
0_l00002ooooo`03o`000?oooooooooo00Sooooo0_l00002ooooo`03ogMgMomVIVKooooo00?ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo02_ooooo0_l0000Looooo`;o
0000K_ooool008Wooooo0_l00002ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo0_l0002]ooooo`00R?oo
ool2o`000004oiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool2o`0000Gooooo0_l0002]ooooo`00
R?ooool2o`000004oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co00001_ooool00ol0003oooooooooo`03ooooo`;o0000]?ooool009_ooooo0_l0000?ooooo`03
o`000?oooooooooo01Wooooo0_l0002Nooooo`00Voooool2o`0000oooooo00?o0000ooooooooool0
1Oooool2o`0001;ooooo0_l0000Booooo`;o0000R_ooool00:cooooo00?o0000ooooooooool01Ooo
ool2o`0000Cooooo0_l0000:ooooo`;o00005?ooool2o`0008[ooooo002/ooooo`Co00002_ooool2
o`0000[ooooo0_l0000_ooooo`Ko0000Joooool00:cooooo00Co0000ooooool0003o00006_ooool2
o`0002_ooooo1_l0001[ooooo`00U_ooool2o`0001Cooooo00?o0000ooooooooool06?ooool2o`00
0003ooooool0003o000002kooooo0_l0001/ooooo`00U_ooool2o`0001Cooooo00?o0000oooooooo
ool06?ooool2o`0009oooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo02_ooooo0_l0002<ooooo`00ROooool2o`00027ooooo00?o0000ooooooooool0:oooool2
o`0008cooooo0029ooooo`;o00001oooool2o`0001Sooooo00?o0000ooooooooool0^Oooool009;o
oooo0_l0000Hooooo`?o00006Oooool2o`0009kooooo002/ooooo`03o`000?oooooooooo01Wooooo
0_l0000cooooo`;o0000JOooool00:_ooooo0_l0001@ooooo`;o0000JOooool008;ooooo0_l0000:
ooooo`;o00006oooool2o`000;_ooooo0022ooooo`;o00002_ooool2o`0001cooooo00?o0000oooo
ooooool04?ooool2o`0001cooooo0_l00029ooooo`00[?ooool00ol0003oooooooooo`06ooooo`?o
00001oooool2o`0001cooooo0_l00029ooooo`00[?ooool00ol0003oooooooooo`06ooooo`?o0000
1Oooool4o`0000[ooooo0_l0000?ooooo`?o0000ROooool009;ooooo0_l0000Hooooo`03o`000?oo
oooooooo00kooooo0ol0000;ooooo`;o00003oooool2o`0008[ooooo002Booooo`;o00006?ooool0
1?l0003oooooooooooooool2o`0000cooooo0_l0000;ooooo`;o0000Voooool00:cooooo0ol00000
0ooooooo0000o`00000Iooooo`;o0000Voooool008Sooooo0_l00007ooooo`;o00006Oooool00ol0
003oooooooooo`2iooooo`00R?ooool2o`0000Oooooo0_l0000Iooooo`03o`000?oooooooooo01go
oooo0_l0000`ooooo`;o0000J?ooool000Wooooo1?l000000ol@413oooooooooo`0Fooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool0
1Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Fooooo`03o`000?oooooooooo00;o
oooo0_l0000Dooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_l00003ooooo`;o8B4Q1?ooool5o`00
00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_oo
ool5o`0000Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM
01Sooooo1?l000000ol@413oooooooooo`0Booooo`002oooool00ol0003oooooooooo`0Hooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omg
MgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01oooool00omgMgOo0000o`00000Eooooo`03o`000?oooooooooo00;ooooo
0_l0000Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02
ooooo`?o00000_lQ8B48ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo01Wooooo00?o
0000ooooooooool05?ooool000Ko00001Oooool00ol0003oooooooooo`0@ooooo`Ko00000_ooool0
1Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003ooooooooo
o`05ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool0
1Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@4005ooooo`;o00001Oooool00onHV9So
8B4Qonk^kP09ooooo`;o00005Oooool00ol0003oooooooooo`0Hooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00gooooo00Go410@oooo
oooooooooooooa0@4003ooooo`?o00002_ooool00ol0003oooooooooo`0=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooo
oooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`0>ooooo`05o`000?oo
ooooooooooooool000003oooool00omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool0
00001Oooool2o`0000Kooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`0Eooooo`03
o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^
00Oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000?ooooo0ol00009
ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooo
oooooooo00Kooooo00?oMgMgoc8b<_ooool06Oooool00ol0003oooooooooo`0Dooooo`002oooool0
0ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<oooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000co
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003_ooool0
0omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05_ooool00ol0003ooooooooo
o`0Aooooo`;o00001Oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool0
0oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000<oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000kooooo00?o
EEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[ooooo00?o0000ooooooooool0
5?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol@413ooooooooooooooooo410@00kooooo
00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@
41003?ooool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41002oooool2o`00
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Hooooo`?o00004Oooool2o`00
00Gooooo00Go410@oooooooooooooooooa0@4002ooooo`;o00002oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oo
oooooooo017ooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003ooooooooo
o`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Co
oooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo0_l000000oooooooV9RHoa0@4004
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00;ooooo0_l00007ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooo
ooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Dooooo`002Oooool00omEEEGoIVIVo`00000Joooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000@ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`01?ooool4o`0001Oooooo00?o0000ooooooooool06?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00;ooooo0_l00007ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4
o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00004?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00006Oooool00omEEEGoIVIVo`00000Fooooo`00[?oo
ool00ol0003oooooooooo`0Mooooo`;o0000V_ooool008Sooooo0_l0000Rooooo`03o`000?oooooo
oooo01gooooo0_l0002Jooooo`00R?ooool2o`0000?ooooo0_l0000Mooooo`03o`000?oooooooooo
0:kooooo0_l00002ooooo`;o00001Oooool008gooooo0_l0000Mooooo`03o`000?oooooooooo02oo
oooo0_l0001mooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1Oooool0087ooooo0_l0000:oooo
o`;o00007Oooool00ol0003oooooooooo`0_ooooo`;o000000?oooooo`000?l00000Noooool01?oM
gMgo0000oa0@4?o<c<`6ooooo`001oooooooo`0004co00003?ooool01?o^k^ko8B4Qoa0@4?o^k^h6
ooooo`001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooool3o`0000Oooooo00?o0000ooooooooool00oooool2o`000003ooooool0003ooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool00_l00003ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00Co0000oooo
ool0003o00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00Co8B4Q
ogMgMomgMgOo<S8b1_ooool000Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`09
ooooo`;o00007?ooool00ol0003oooooooooo`09ooooo`;o00006oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02Oooool2o`0000;ooooo0_l00005
ooooo`00POooool2o`0000[ooooo0_l0000Mooooo`03o`000?oooooooooo02oooooo0_l00002oooo
o`;o0000Q?ooool0087ooooo0_l0000:ooooo`;o00007Oooool00ol0003oooooooooo`0Mooooo`;o
00004?ooool2o`0008Sooooo002/ooooo`03o`000?oooooooooo013ooooo0_l0000;ooooo`;o0000
V_ooool00:cooooo00?o0000ooooooooool00_ooool2o`0000cooooo0ol00009ooooo`;o0000Vooo
ool008Oooooo0_l00008ooooo`;o00006Oooool00ol0003oooooooooo`02ooooo`;o00003Oooool2
o`0000Wooooo0_l0000Eooooo`;o0000Q?ooool008Oooooo0_l00008ooooo`;o00006Oooool3o`00
03?ooooo0_l00024ooooo`00[?ooool00ol0003oooooooooo`0Mooooo`;o0000V_ooool008gooooo
0_l0000Mooooo`03o`000?oooooooooo01gooooo0_l0002Jooooo`00SOooool2o`0001gooooo00?o
0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool02?ooool2o`000:oooooo002/oooo
o`03o`000?oooooooooo00Sooooo0_l0000Booooo`;o0000Voooool008;ooooo0_l0000Xooooo`03
o`000?oooooooooo01cooooo0_l0000Booooo`?o00007oooool2o`0006Gooooo0021ooooo`?o0000
:?ooool00ol0003oooooooooo`0@ooooo`;o00003?ooool2o`00013ooooo0ol0000Oooooo`;o0000
IOooool0087ooooo0_l0000Yooooo`03o`000?oooooooooo00Wooooo0_l00005ooooo`;o00003?oo
ool2o`0009Wooooo002/ooooo`?o00002?ooool3o`0000Gooooo0_l0002Wooooo`00P_ooool2o`00
02Sooooo00?o0000ooooooooool02?ooool2o`0000Kooooo0_l0000Rooooo`;o00006Oooool2o`00
06Sooooo0022ooooo`;o0000:?ooool00ol0003oooooooooo`0dooooo`;o00006Oooool3o`0006Oo
oooo002Aooooo`;o00006Oooool00ol0003oooooooooo`0Aooooo`;o00008Oooool2o`0001Sooooo
1?l0001Wooooo`00TOooool2o`0001Wooooo00?o0000ooooooooool04Oooool2o`00023ooooo0ol0
000Hooooo`;o0000JOooool00:cooooo00?o0000ooooooooool0<_ooool3o`0008Cooooo002Joooo
o`;o00004?ooool00ol0003oooooooooo`0Nooooo`;o00003oooool2o`000003ooooool0003o0000
08Gooooo002Jooooo`;o00004?ooool00ol0003oooooooooo`0Nooooo`;o00003oooool2o`0008So
oooo002/ooooo`?o0000;oooool2o`0008Sooooo002>ooooo`;o00007?ooool00ol0003ooooooooo
o`2iooooo`00P_ooool2o`0000[ooooo0_l0000Kooooo`;o00007oooool2o`0009[ooooo0022oooo
o`;o00004_ooool2o`0001?ooooo0_l0000Aooooo`?o00002oooool2o`0009[ooooo002Fooooo`;o
00005?ooool00ol0003oooooooooo`0?ooooo`?o00002Oooool2o`0001Kooooo0_l00024ooooo`00
POooool2o`0002Wooooo00?o0000ooooooooool06oooool2o`0001Kooooo0_l00024ooooo`00POoo
ool2o`0001Sooooo0_l0000?ooooo`03o`000?oooooooooo00;o0000<?ooool2o`0008Gooooo002K
ooooo`;o00003oooool00ol0003oooooooooo`02o`0000kooooo0_l0000Pooooo`;o0000QOooool0
0:cooooo0ol0000@ooooo`;o00007Oooool2o`0008Sooooo002/ooooo`03o`000?oooooooooo02oo
oooo0_l00028ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0Loooo
o`;o0000Voooool008Wooooo0ol000000olb<S;ok^k^ooooo`04ooooo`;o8B4Q1?ooool5o`0000Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01cooooo0_l0000boooo
o`;o0000Ioooool008Wooooo0_l000000oooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Ioooo
o`?o00004oooool2o`0001oooooo0_l0001Wooooo`00ROooool01Ol@413ooooooooooooooooo410@
00[ooooo0_l000000onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0000<oooo
o`;o00002oooool3o`0001?ooooo0_l00028ooooo`00ROooool01Ol0003ooooooooooooooooo0000
00[ooooo0_l000001?ooooooV9RHob4Q8Oo^k^h2o`0000Gooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`0<ooooo`Co00002?ooool2o`0009oooooo0029ooooo`05o`000?oooooooooo
ooooool000003_ooool01?mgMgOoIVIVo`000?l00002ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`0>ooooo`;o00002?ooool2o`0009oooooo0029ooooo`05oa0@4?oo
ooooooooooooool@41000_ooool2o`0000_ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00kooooo0_l0002Yooooo`00ROooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00;ooooo0_l00007ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00kooooo0_l0000Kooooo`;o00000_ooool2o`0008So
oooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
00Cooooo1?l00006ooooo`03o`000?oooooooooo02_ooooo0_l00002ooooo`;o0000R?ooool00:co
oooo0_l0000_ooooo`;o00007Oooool2o`0006[ooooo0024ooooo`;o00009_ooool2o`0001Wooooo
0_l0000Dooooo`;o00007Oooool2o`0006[ooooo0024ooooo`;o00009_ooool00ol0003ooooooooo
o`0Hooooo`;o00005?ooool2o`0008Wooooo002:ooooo`;o00002Oooool2o`0001Gooooo0ol0000^
ooooo`;o00007?ooool2o`0006_ooooo002:ooooo`;o00002Oooool2o`0001?ooooo0ol0000_oooo
o`;o00007Oooool2o`0006_ooooo002Zooooo`?o0000;oooool2o`0001cooooo0_l0001/ooooo`00
U_ooool2o`0001Cooooo00?o0000ooooooooool0Boooool2o`0006cooooo002Fooooo`;o00005?oo
ool01?l0003oooooooooooooool2o`000;Kooooo002/ooooo`04o`000?ooooooooooooooo`;o0000
5_ooool2o`0009kooooo002Aooooo`;o00005_ooool2o`000003ooooool0003ooooo01Oooooo0_l0
00000ooooooo0000o`00000`ooooo`;o0000K?ooool0097ooooo0_l00004ooooo`;o00001?ooool2
o`0000[ooooo0_l000000ooooooo0000ooooo`0Gooooo`?o0000<_ooool2o`0006cooooo002Aoooo
o`;o00001?ooool2o`0000Cooooo0_l0000=ooooo`?o00005oooool2o`000:3ooooo002/ooooo`04
o`000?oooooo0000o`0000Oooooo0_l0000<ooooo`;o0000<_ooool2o`0006gooooo002Oooooo`;o
00002oooool01?l0003oooooo`000?l00007ooooo`;o00003?ooool2o`0003;ooooo0_l0001]oooo
o`00Q?ooool2o`0001Wooooo0_l00005ooooo`;o00001?ooool01?l0003oooooo`000?l00006oooo
o`;o00008oooool2o`0001gooooo0_l0001/ooooo`00Q?ooool2o`0001oooooo0ol00004ooooo`04
o`000?oooooo0000o`0000Kooooo0_l0000Sooooo`;o00007Oooool2o`0006cooooo002Cooooo`;o
00003Oooool2o`000003ooooool0003o000000Gooooo00?o0000ooooooooool05_ooool2o`000:7o
oooo0025ooooo`;o00003?ooool2o`0000gooooo0_l00008ooooo`03o`000?oooooooooo01Kooooo
0_l0002Qooooo`00QOooool2o`0000cooooo0_l00004ooooo`;o00004Oooool00ol0003ooooooooo
o`07ooooo`;o0000/?ooool009?ooooo0_l00004ooooo`;o00004Oooool3o`0000Oooooo0_l0000M
ooooo`;o0000TOooool00:cooooo00?o0000ooooooooool09_ooool4o`0008oooooo002/ooooo`03
o`000?oooooooooo02Sooooo0_l0002?ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00U?oo
ool2o`0001Kooooo00?o0000ooooooooool09oooool2o`00093ooooo002Dooooo`;o00005_ooool0
0ol0003oooooooooo`03ooooo`;o00008_ooool2o`00093ooooo002/ooooo`03o`000?oooooooooo
00?ooooo0_l0002dooooo`00UOooool2o`0001Gooooo00?o0000ooooooooool0^Oooool008oooooo
0_l00004ooooo`;o00001_ooool2o`0000gooooo0ol0000Vooooo`;o00007?ooool2o`0007?ooooo
002?ooooo`;o00001Oooool2o`0000Gooooo0_l0000=ooooo`04o`000?ooooooooooooooo`Co0000
8Oooool2o`0001cooooo0_l0001cooooo`00S_ooool3o`0000Gooooo0_l00005ooooo`;o00000ooo
ool2o`0000?ooooo0_l00003ooooo`04o`000?ooooooooooooooo`Co00003?ooool2o`0001;ooooo
0_l0002Booooo`00S_ooool3o`0000Gooooo0_l0000:ooooo`;o00000oooool2o`0000?ooooo00Co
0000oooooooooooooooo0_l0000>ooooo`;o00004_ooool2o`0001gooooo0_l0001cooooo`00Sooo
ool2o`00013ooooo0_l00009ooooo`04o`000?ooooooooooooooo`;o0000@Oooool2o`0007?ooooo
002?ooooo`;o00004?ooool2o`0000Wooooo00?o0000ooooooooool08_ooool2o`0009Gooooo002A
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8b
omgMg@05ooooo`03o`000?oooooooooo02;ooooo0_l0000Oooooo`;o0000M?ooool0097ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`04o`00
0?ooooooooooooooo`;o0000@?ooool2o`0007Cooooo002Aooooo`05oa0@4?ooooooooooooooool@
41004?ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o0000]_ooool0097o
oooo00Ko0000ooooooooooooooooo`000?ooool2o`0000cooooo00?oMgMgoc8b<_ooool01?ooool3
o`0002?ooooo0_l0002Dooooo`00TOooool01_l0003ooooooooooooooooo0000ooooo`;o00002Ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool03Oooool2o`0001Cooooo
0_l0002Dooooo`00T?ooool3o`0000;ooooo00?o410@ooooooooool02_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00gooooo0_l0000?ooooo`;o00000_ooool2o`0009Gooooo002@
ooooo`?o000000?ooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01kooooo0_l00002ooooo`;o0000UOooool0097ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`Co00001Oooool2o`000;_ooooo002[ooooo`;o00008oooool2o`0001gooooo0_l0001goooo
o`00[?ooool00ol0003oooooooooo`0Qooooo`;o00007Oooool2o`0007Oooooo002/ooooo`03o`00
0?oooooooooo01cooooo0_l0002Kooooo`00W_ooool2o`0000cooooo0ol0000Looooo`;o0000Vooo
ool009kooooo0_l0000<ooooo`03o`000?oooooooooo0;Wooooo002Mooooo`Go00002_ooool00ol0
003oooooooooo`09ooooo`;o0000[_ooool008Wooooo0_l0000Booooo`Go00002_ooool00ol0003o
ooooooooo`06ooooo`;o000000?oooooo`000?l000003oooool2o`0009gooooo0029ooooo`;o0000
2Oooool2o`0000_ooooo0_l00002ooooo`;o00001Oooool00ol0003oooooooooo`06ooooo`Co0000
4?ooool2o`0009gooooo0029ooooo`;o00002?ooool3o`0000[ooooo0ol00002ooooo`;o00001Ooo
ool00ol0003oooooooooo`08ooooo`;o0000[oooool008Wooooo0_l00008ooooo`?o00002_ooool2
o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo03[ooooo0_l0001mooooo`00ROooool2o`00
027ooooo00?o0000ooooooooool0>_ooool2o`0007gooooo002/ooooo`?o00007?ooool2o`0009_o
oooo002/ooooo`03o`000?oooooooooo01cooooo0_l0002Kooooo`00[?ooool00ol0003ooooooooo
o`03ooooo`;o0000]?ooool00:cooooo00?o0000ooooooooool00oooool2o`000;Cooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo01Gooooo0_l0002Rooooo`00
[?ooool00ol0003oooooooooo`0Eooooo`;o0000X_ooool00:cooooo00?o0000ooooooooool04ooo
ool2o`000:Cooooo002<ooooo`;o00007_ooool3o`0001?ooooo0_l0002Tooooo`00Roooool3o`00
01kooooo00?o0000ooooooooool00_l0002gooooo`00Roooool2o`0001oooooo1Ol0000@ooooo`;o
0000YOooool00:_ooooo1?l0000Booooo`;o0000YOooool00:_ooooo1?l0002iooooo`00[?ooool3
o`00017ooooo0_l0002Vooooo`00Z_ooool5o`00017ooooo1?l0002Tooooo`00Z_ooool3o`0001Go
oooo0ol0002Sooooo`00[?ooool00ol0003oooooooooo`0Booooo`Co0000Xoooool00:cooooo0ol0
000Booooo`;o00007Oooool2o`0008Kooooo002Oooooo`;o00001Oooool2o`0000Cooooo00?o0000
ooooooooool03Oooool2o`00023ooooo1?l00026ooooo`00Woooool3o`0000Cooooo0_l00004oooo
o`03o`000?oooooooooo00cooooo0ol0000Pooooo`;o0000R?ooool00:3ooooo0_l0000:ooooo`03
o`000?oooooooooo00cooooo0_l0002[ooooo`00Xoooool2o`0000;ooooo0_l00003ooooo`03o`00
0?oooooooooo013ooooo0_l0000Looooo`;o0000ROooool008Wooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oM
gMd00_l00003ooooo`03o`000?oooooooooo013ooooo0_l0000Looooo`;o0000ROooool008Wooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool03?ooool2o`000:_ooooo0029ooooo`05oa0@
4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02oooool3o`000:_ooooo0029ooooo`05o`000?ooooooooooooooool0
00001?ooool2o`0000Sooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`?o
00002oooool2o`000:cooooo0029ooooo`05o`000?ooooooooooooooool000000_ooool4o`0000So
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool02oooool2o`000:cooooo0029ooooo`05oa0@4?ooooooooooooooool@41000_ooool4o`00
00Sooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
0;Wooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo
<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`;o0000/?ooool0
08Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo00?o0000
ooooooooool01_ooool3o`000;3ooooo002/ooooo`03o`000?oooooooooo00Kooooo0ol0000Noooo
o`;o0000T?ooool00:cooooo00?o0000ooooooooool01oooool2o`0001kooooo0_l0002@ooooo`00
U?ooool2o`0001Kooooo00?o0000ooooooooool0^Oooool009Cooooo0_l0000Fooooo`?o00001_oo
ool2o`0001gooooo0_l0002Booooo`00[?ooool00ol0003oooooooooo`05ooooo`?o00007Oooool2
o`0009;ooooo002/ooooo`03o`000?oooooooooo00Gooooo0_l0002booooo`00[?ooool00ol0003o
ooooooooo`05ooooo`;o0000/_ooool00:cooooo00?o0000ooooooooool01?ooool2o`000;?ooooo
002Eooooo`;o00005Oooool01?l0003oooooo`000?l00003ooooo`;o0000/oooool009Gooooo0_l0
000Eooooo`04o`000?oooooo0000o`000;Sooooo0028ooooo`;o00008_ooool5o`000;Oooooo0028
ooooo`;o00003oooool2o`00017ooooo1Ol0002gooooo`00VOooool2o`00017ooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool009Sooooo0_l0000Booooo`03o`00
0?oooooooooo0;Wooooo002Hooooo`;o00003_ooool2o`0000;ooooo00?o0000ooooooooool0^Ooo
ool00:Sooooo0_l00002ooooo`03o`000?oooooooooo0;Wooooo002Xooooo`?o000000?oooooo`00
0?ooool0^_ooool009gooooo0_l00009ooooo`Go0000^oooool009gooooo0_l0000;ooooo`?o0000
^oooool00:Kooooo0_l00004ooooo`?o0000^Oooool00:7ooooo1?l000000ooooooo0000o`000004
ooooo`03o`000?oooooooooo0;Wooooo002Qooooo`Co00001oooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Rooooo`Co0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`2iooooo`00Y?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`03o`000?oooooooooo00Gooooo0ol0002i
ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00
Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00X_ooool0
0omEEEGoIVIVo`000033ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00Z_ooool01?l@413o0000o`000?l0002jooooo`00Zoooool00ol0003oooooooooo`2j
ooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool01_l0003oMgMgo`000?l0003oEEEE
onk^k[Oooooo002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoEEEE]oooool00:_ooooo00?o0000
onk^k_ooool00_ooool00ol0003oooooooooo`2eooooo`00Zoooool00ol0003ok^k^ooooo`02oooo
o`03o`000?oooooooooo0;Gooooo002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoIVIV]oooool0
0:[ooooo00?o410@o`000?mgMgL00_l000000omVIVKok^k^ooooo`2fooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.46756 .10355 Mdot
.56335 .19508 Mdot
.49206 .38729 Mdot
.41893 .53265 Mdot
.4051 .55305 Mdot
.39734 .66452 Mdot
.48492 .33228 Mdot
.37787 .26814 Mdot
.36955 .53168 Mdot
.55107 .38354 Mdot
.56767 .53351 Mdot
.4473 .0237 Mdot
.64811 .35323 Mdot
.56451 .43242 Mdot
.52283 .05091 Mdot
.45259 .25527 Mdot
.59489 .6328 Mdot
.65101 .3607 Mdot
.50657 .77055 Mdot
.66345 .66427 Mdot
.66052 .42043 Mdot
.6184 .30006 Mdot
.64124 .37381 Mdot
.65911 .39349 Mdot
.5802 .11082 Mdot
.51329 .20426 Mdot
.55055 .63756 Mdot
.49574 .78527 Mdot
.64612 .71149 Mdot
.58473 .23548 Mdot
.66541 .50025 Mdot
.37381 .64496 Mdot
.3823 .248 Mdot
.54729 .76148 Mdot
.5249 .815 Mdot
.64498 .68385 Mdot
.5089 .93607 Mdot
.51716 .73882 Mdot
.59918 .79828 Mdot
.44077 .02826 Mdot
.54844 .06701 Mdot
.54118 .78179 Mdot
.44255 .84638 Mdot
.4539 .10747 Mdot
.41358 .21176 Mdot
.42502 .26265 Mdot
.5651 .47795 Mdot
.41972 .90311 Mdot
.58991 .36859 Mdot
.62661 .745 Mdot
.41399 .88434 Mdot
.5942 .81657 Mdot
.74593 .68969 Mdot
.46542 .86822 Mdot
.4907 .86904 Mdot
.37248 .36406 Mdot
.38978 .18937 Mdot
.60238 .60646 Mdot
.46199 .96355 Mdot
.40377 .26324 Mdot
.44747 .19813 Mdot
.69134 .25762 Mdot
.58219 .82367 Mdot
.53795 .58131 Mdot
.4187 .0925 Mdot
.36883 .55446 Mdot
.55043 .38599 Mdot
.4579 .25192 Mdot
.53054 .7132 Mdot
.66661 .43615 Mdot
.61066 .58907 Mdot
.52187 .47451 Mdot
.55787 .42401 Mdot
.52938 .31967 Mdot
.58199 .82388 Mdot
.50092 .58973 Mdot
.74556 .69059 Mdot
.51661 .22336 Mdot
.6099 .78906 Mdot
.59496 .42725 Mdot
.66404 .58576 Mdot
.58606 .2406 Mdot
.42167 .57223 Mdot
.5427 .78149 Mdot
.36799 .40489 Mdot
.43771 .28858 Mdot
.40408 .52378 Mdot
.42462 .27733 Mdot
.61071 .55369 Mdot
.46583 .24377 Mdot
.5919 .12701 Mdot
.76629 .52379 Mdot
.51816 .67244 Mdot
.41559 .3173 Mdot
.52219 .65542 Mdot
.76651 .47994 Mdot
.56316 .42605 Mdot
.38842 .76353 Mdot
.74354 .69971 Mdot
.6148 .53089 Mdot
.49739 .11375 Mdot
.61271 .49195 Mdot
.46738 .01154 Mdot
.4837 .09746 Mdot
.67244 .51229 Mdot
.53972 .7775 Mdot
.59986 .63596 Mdot
.48887 .80058 Mdot
.51795 .67352 Mdot
.66775 .45438 Mdot
.55665 .39666 Mdot
.42463 .61805 Mdot
.37353 .63744 Mdot
.66429 .64303 Mdot
.66666 .86056 Mdot
.42925 .55147 Mdot
.47832 .17407 Mdot
.37095 .63169 Mdot
.3743 .66769 Mdot
.48229 .95435 Mdot
.6499 .3629 Mdot
.66012 .20314 Mdot
.65665 .43709 Mdot
.64937 .70721 Mdot
.66768 .44705 Mdot
.42068 .42689 Mdot
.65398 .67599 Mdot
.76077 .44375 Mdot
.56673 .21503 Mdot
.46788 .28866 Mdot
.63434 .34209 Mdot
.52942 .15585 Mdot
.48843 .0106 Mdot
.40149 .70475 Mdot
.42225 .79594 Mdot
.63336 .7463 Mdot
.56124 .87494 Mdot
.64658 .70306 Mdot
.55728 .4234 Mdot
.41216 .10453 Mdot
.51815 .04375 Mdot
.73219 .36193 Mdot
.46914 .74961 Mdot
.52545 .72928 Mdot
.59631 .62875 Mdot
.66577 .6494 Mdot
.36629 .49392 Mdot
.62187 .92579 Mdot
.43236 .73339 Mdot
.43101 .24922 Mdot
.62219 .14233 Mdot
.61153 .46685 Mdot
.55683 .6338 Mdot
.65896 .38761 Mdot
.5189 .4432 Mdot
.39784 .32857 Mdot
.5586 .87302 Mdot
.58809 .81881 Mdot
.36799 .55433 Mdot
.49663 .94838 Mdot
.55952 .87312 Mdot
.55278 .27453 Mdot
.61872 .77576 Mdot
.49279 .00293 Mdot
.65044 .65748 Mdot
.4206 .78129 Mdot
.50792 .13088 Mdot
.36655 .49595 Mdot
.6741 .52504 Mdot
.53335 .7048 Mdot
.58269 .84334 Mdot
.6256 .73838 Mdot
.47454 .74182 Mdot
.5354 .69358 Mdot
.40669 .42242 Mdot
.43174 .73573 Mdot
.40147 .14652 Mdot
.76484 .47107 Mdot
.39726 .3363 Mdot
.42925 .47811 Mdot
.62918 .74546 Mdot
.60194 .81174 Mdot
.47597 .003 Mdot
.49333 .24126 Mdot
.55619 .075 Mdot
.50891 .33553 Mdot
.36987 .49539 Mdot
.76 .45199 Mdot
.38777 .77554 Mdot
.48987 .0024 Mdot
.43948 .84339 Mdot
.63996 .17477 Mdot
.66749 .64487 Mdot
.54077 .53916 Mdot
.68911 .26009 Mdot
.37306 .32145 Mdot
.56837 .08312 Mdot
.47426 .00865 Mdot
.41276 .34114 Mdot
.7716 .54218 Mdot
.59314 .66936 Mdot
.43595 .59972 Mdot
.43392 .58357 Mdot
.52296 .49905 Mdot
.40489 .49422 Mdot
.77015 .56723 Mdot
.5235 .15009 Mdot
.53731 .46302 Mdot
.3898 .55623 Mdot
.43712 .69265 Mdot
.51631 .34956 Mdot
.56939 .52715 Mdot
.62869 .30576 Mdot
.50669 .20606 Mdot
.67382 .52913 Mdot
.49329 .24577 Mdot
.51659 .1426 Mdot
.499 .19567 Mdot
.50354 .01319 Mdot
.49896 .30376 Mdot
.41563 .21217 Mdot
.41695 .07795 Mdot
.46898 .17487 Mdot
.42543 .9085 Mdot
.67445 .5043 Mdot
.65748 .62066 Mdot
.49049 .2472 Mdot
.41673 .67224 Mdot
.53452 .14981 Mdot
.49132 .73195 Mdot
.52302 .05062 Mdot
.65987 .1986 Mdot
.42849 .34068 Mdot
.43821 .50041 Mdot
.76331 .59517 Mdot
.6062 .4696 Mdot
.56012 .60311 Mdot
.6552 .19856 Mdot
.52913 .71129 Mdot
.49582 .1049 Mdot
.65281 .39886 Mdot
.51847 .14066 Mdot
.69474 .26666 Mdot
.42247 .80251 Mdot
.67572 .55035 Mdot
.61069 .58836 Mdot
.37964 .71519 Mdot
.5195 .65922 Mdot
.53844 .89439 Mdot
.60078 .58363 Mdot
.61166 .58183 Mdot
.58863 .81561 Mdot
.56811 .08473 Mdot
.42957 .55388 Mdot
.53679 .56661 Mdot
.51471 .92373 Mdot
.53575 .24838 Mdot
.53653 .68892 Mdot
.49803 .86598 Mdot
.49679 .61142 Mdot
.39503 .16658 Mdot
.44052 .94457 Mdot
.60022 .41494 Mdot
.56069 .60042 Mdot
.65627 .63103 Mdot
.44195 .34862 Mdot
.61046 .48017 Mdot
.46005 .11127 Mdot
.56515 .51481 Mdot
.39392 .60545 Mdot
.63414 .71389 Mdot
.56459 .31323 Mdot
.6528 .67136 Mdot
.48773 .87324 Mdot
.54576 .35963 Mdot
.59727 .4198 Mdot
.56852 .8602 Mdot
.49342 .2393 Mdot
.45514 .79934 Mdot
.40109 .83668 Mdot
.57068 .49558 Mdot
.39023 .42726 Mdot
.62554 .75635 Mdot
.45059 .30936 Mdot
.52513 .31454 Mdot
.48954 .95323 Mdot
.44559 .02858 Mdot
.48815 .80217 Mdot
.509 .39294 Mdot
.40662 .51924 Mdot
.67455 .59867 Mdot
.4335 .2378 Mdot
.66423 .57331 Mdot
.75981 .45779 Mdot
.45346 .95437 Mdot
.49059 .01881 Mdot
.43025 .91682 Mdot
.44721 .38153 Mdot
.49985 .9534 Mdot
.68616 .26168 Mdot
.67844 .56651 Mdot
.5133 .04097 Mdot
.59716 .9575 Mdot
.58995 .38176 Mdot
.46781 .88182 Mdot
.52757 .15114 Mdot
.37651 .68236 Mdot
.55679 .08001 Mdot
.56655 .48509 Mdot
.39597 .81039 Mdot
.54121 .25754 Mdot
.45535 .67678 Mdot
.63225 .31995 Mdot
.59334 .64271 Mdot
.64897 .36611 Mdot
.61465 .13408 Mdot
.42833 .47164 Mdot
.43081 .161 Mdot
.54093 .7775 Mdot
.43178 .06035 Mdot
.43709 .36908 Mdot
.48885 .00719 Mdot
.64915 .20077 Mdot
.73679 .35833 Mdot
.42846 .34813 Mdot
.40635 .73899 Mdot
.54768 .7746 Mdot
.56741 .84814 Mdot
.42366 .71559 Mdot
.45515 .68256 Mdot
.46486 .33378 Mdot
.60112 .62644 Mdot
.39898 .14114 Mdot
.50595 .93184 Mdot
.52748 .6385 Mdot
.62246 .29843 Mdot
.46805 .28655 Mdot
.52283 .5082 Mdot
.54083 .15883 Mdot
.40533 .72494 Mdot
.42061 .78164 Mdot
.55456 .27908 Mdot
.40526 .51346 Mdot
.7584 .65159 Mdot
.55183 .28411 Mdot
.58377 .24129 Mdot
.53316 .60364 Mdot
.38038 .27065 Mdot
.55261 .62687 Mdot
.64697 .69925 Mdot
.61087 .29388 Mdot
.4998 .72358 Mdot
.47809 .18121 Mdot
.73031 .35417 Mdot
.43301 .04427 Mdot
.51714 .93544 Mdot
.64493 .68767 Mdot
.58007 .34482 Mdot
.58578 .68423 Mdot
.63356 .72159 Mdot
.60839 .47263 Mdot
.43546 .04037 Mdot
.73573 .34363 Mdot
.67558 .55665 Mdot
.48974 .01214 Mdot
.49682 .01273 Mdot
.53339 .04618 Mdot
.52011 .56155 Mdot
.6033 .44677 Mdot
.52553 .05241 Mdot
.3905 .1876 Mdot
.51854 .57581 Mdot
.66741 .53834 Mdot
.56343 .31807 Mdot
.39153 .60265 Mdot
.48932 .10672 Mdot
.38056 .70437 Mdot
.49695 .10671 Mdot
.49763 .95139 Mdot
.52764 .90293 Mdot
.63902 .36852 Mdot
.53736 .9109 Mdot
.63339 .34302 Mdot
.56003 .08737 Mdot
.65601 .87946 Mdot
.45887 .95083 Mdot
.39483 .35139 Mdot
.51876 .45541 Mdot
.62109 .15891 Mdot
.6132 .52922 Mdot
.4607 .34081 Mdot
.47304 .00147 Mdot
.66746 .44141 Mdot
.46316 .69656 Mdot
.53825 .3448 Mdot
.50278 .19174 Mdot
.55538 .62576 Mdot
.41571 .89332 Mdot
.67743 .48433 Mdot
.69018 .26568 Mdot
.48091 .00321 Mdot
.57802 .69384 Mdot
.7541 .65367 Mdot
.5801 .69399 Mdot
.43947 .76053 Mdot
.43636 .7563 Mdot
.45692 .63837 Mdot
.40068 .13627 Mdot
.44585 .02593 Mdot
.55247 .63001 Mdot
.48702 .74072 Mdot
.57199 .54605 Mdot
.45805 .24017 Mdot
.60003 .11932 Mdot
.40701 .39053 Mdot
.65683 .63982 Mdot
.44619 .71407 Mdot
.55226 .64924 Mdot
.44666 .32796 Mdot
.40453 .44219 Mdot
.55431 .74597 Mdot
.56254 .6034 Mdot
.53872 .47883 Mdot
.64282 .17407 Mdot
.40686 .12221 Mdot
.45455 .41573 Mdot
.51801 .82717 Mdot
.59927 .63778 Mdot
.42446 .18774 Mdot
.57101 .3379 Mdot
.53765 .69098 Mdot
.6154 .14804 Mdot
.77048 .48532 Mdot
.51962 .13648 Mdot
.69372 .81448 Mdot
.45892 .10077 Mdot
.54059 .48583 Mdot
.37396 .3652 Mdot
.536 .06411 Mdot
.56426 .56421 Mdot
.61559 .30816 Mdot
.75484 .66296 Mdot
.47686 .74677 Mdot
.47632 .70081 Mdot
.41897 .67459 Mdot
.66062 .61618 Mdot
.58769 .38879 Mdot
.7693 .53412 Mdot
.51505 .35116 Mdot
.48251 .8663 Mdot
.55547 .75696 Mdot
.53485 .6066 Mdot
.4301 .44369 Mdot
.51136 .2735 Mdot
.38035 .24907 Mdot
.42841 .45237 Mdot
.62204 .76716 Mdot
.54466 .16775 Mdot
.42516 .17317 Mdot
.65465 .67056 Mdot
.66462 .55721 Mdot
.58858 .66275 Mdot
.75984 .4186 Mdot
.54085 .35165 Mdot
.40105 .13197 Mdot
.56077 .07508 Mdot
.56409 .52856 Mdot
.50736 .94581 Mdot
.56845 .32719 Mdot
.59182 .63417 Mdot
.64994 .69204 Mdot
.49225 .10762 Mdot
.49173 .79455 Mdot
.47699 .18044 Mdot
.55584 .74612 Mdot
.67823 .22647 Mdot
.41124 .7449 Mdot
.50665 .55149 Mdot
.43921 .83644 Mdot
.59494 .42022 Mdot
.52323 .5324 Mdot
.44315 .28632 Mdot
.47466 .87079 Mdot
.4394 .84466 Mdot
.43237 .57878 Mdot
.53075 .24176 Mdot
.36845 .5385 Mdot
.40885 .61589 Mdot
.44982 .12362 Mdot
.54341 .68757 Mdot
.47452 .79703 Mdot
.50931 .62675 Mdot
.6828 .83814 Mdot
.502 .65287 Mdot
.55242 .17696 Mdot
.40437 .83801 Mdot
.65213 .6554 Mdot
.52504 .72699 Mdot
.64 .72021 Mdot
.4656 .00648 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001?ooool2o`00
00Oooooo0ol0002iooooo`00Xoooool4o`000006ooooool0003o0000o`000?oooooo0000^oooool0
0:3ooooo0_l00002ooooo`?o000000Koooooo`000?l0003o0000ooooool0002kooooo`00X?ooool2
o`000003ooooool0003o000000?ooooo0_l00002ooooo`03o`000?oooooooooo0;Wooooo002Qoooo
o`Co00000oooool2o`000003ooooool0003o000000;o0000^Oooool00:7ooooo0_l000000omVIVKo
0000ooooo`02ooooo`;o000000?oooooo`000?l000000_l0002iooooo`00Z?ooool2o`0000;ooooo
00?o0000ooooooooool0^Oooool00:Sooooo0_l00002ooooo`03o`000?oooooooooo0;Wooooo002J
ooooo`;o00004?ooool3o`000;Wooooo002Hooooo`Co00004?ooool00ol0003oooooooooo`2ioooo
o`00V?ooool4o`00013ooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0^Oooool009Kooooo0_l0000Dooooo`04o`000?oooooo
ooooooooo`;o0000]_ooool009Kooooo0_l0000Dooooo`04o`000?ooooooooooooooo`Co0000]?oo
ool009Gooooo0_l0000Eooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`;o0000[oooool0
09Gooooo0_l0000Eooooo`03o`000?oooooooooo00Sooooo0_l0002_ooooo`00[?ooool3o`0000Co
oooo0ol0002booooo`00[?ooool00ol0003oooooooooo`04ooooo`?o0000/_ooool00:cooooo00?o
0000ooooooooool0^Oooool009Gooooo0_l0000Eooooo`03o`000?oooooooooo0;Wooooo002Eoooo
o`;o00005Oooool00ol0003oooooooooo`08ooooo`;o0000[oooool00:cooooo00?o0000oooooooo
ool02?ooool2o`0000?ooooo0_l0002Zooooo`00[?ooool00ol0003oooooooooo`0=ooooo`;o0000
Z_ooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0000?ooooo`Co0000Y_ooool0
093ooooo0_l0000Jooooo`03o`000?oooooooooo00oooooo1?l0002Vooooo`00T?ooool2o`0001[o
oooo00?o0000ooooooooool03oooool2o`0000;ooooo0_l0002Tooooo`00[?ooool00ol0003ooooo
ooooo`0Cooooo`;o0000Y?ooool00:cooooo00?o0000ooooooooool04?ooool2o`000003ooooool0
003o00000:Cooooo002Aooooo`;o00006Oooool00ol0003oooooooooo`0@ooooo`;o0000Yoooool0
097ooooo0_l0000Iooooo`03o`000?oooooooooo0;Wooooo002Vooooo`;o00001?ooool00ol0003o
ooooooooo`2iooooo`00W_ooool2o`0000Kooooo0_l00004ooooo`?o0000^Oooool008oooooo0_l0
000=ooooo`;o000000?oooooo`000?l000002Oooool00ol0003oooooooooo`2iooooo`00Soooool2
o`0000_ooooo0_l00003ooooo`;o00001Oooool5o`000;_ooooo002Looooo`;o00002_ooool5o`00
0;_ooooo002Nooooo`;o00002oooool2o`0001Wooooo0_l0002Pooooo`00W_ooool2o`0000_ooooo
0_l0000Iooooo`;o0000X?ooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`0Nooooo`;o0000VOooool008Wooooo00CoMgMgoiRHV?ooooooV9RH0_l00004ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool07_ooool2o`0009Wooooo0021ooooo`Ko00000_ooool01?l@413oooooooooooooool2o`0000co
oooo0_l00009ooooo`03o`000?oooooooooo00?ooooo0ol0002iooooo`00ROooool01Ol0003ooooo
oooooooooooo000000gooooo0_l00008ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool06oooool2o`0009cooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGo
c<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool01?l0003oooooo`000?l0000J
ooooo`;o0000W?ooool008Wooooo00Go410@ooooool0003o0000oa0@400>ooooo`03ojVYZOmgMgOo
oooo00?ooooo00?o0000ooooooooool01oooool01?l0003oooooo`000?l0000Qooooo`;o0000UOoo
ool008Wooooo00GoMgMgoiRHV?l0003o0000ogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S80
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo0_l0000Mooooo`;o0000
UOooool008Wooooo00Gok^k^oc8b<_l0003o0000onk^kP0;ooooo`Go00001?ooool4o`0000Kooooo
00?o0000ooooooooool00oooool2o`000;Cooooo002:ooooo`;o00008?ooool00ol0003ooooooooo
o`02ooooo`?o00008?ooool2o`0009;ooooo002:ooooo`?o00007oooool00ol0003oooooooooo`02
ooooo`;o00008Oooool2o`0009;ooooo002;ooooo`;o00007oooool00ol0003oooooooooo`04oooo
o`;o00000_ooool2o`0001Wooooo0_l0002Dooooo`00[?ooool3o`0000Cooooo1_l0000Iooooo`;o
0000U?ooool00:cooooo00?o0000ooooooooool01_ooool2o`000;7ooooo002/ooooo`03o`000?oo
oooooooo00Kooooo0_l00002ooooo`;o00006Oooool2o`0009;ooooo002Eooooo`;o00005Oooool0
0ol0003oooooooooo`0:ooooo`;o00006Oooool2o`0009;ooooo002Eooooo`;o00005Oooool00ol0
003oooooooooo`2iooooo`00ROooool2o`00027ooooo00?o0000ooooooooool02oooool2o`000:co
oooo0029ooooo`;o00008Oooool00ol0003oooooooooo`0;ooooo`;o0000[?ooool009?ooooo0_l0
000?ooooo`;o00001_ooool00ol0003oooooooooo`0/ooooo`;o0000Roooool009?ooooo0_l0000<
ooooo`;o000000?oooooo`000?l000001_ooool3o`0000kooooo0_l0000Kooooo`?o0000Roooool0
0:7ooooo0_l00009ooooo`03o`000?oooooooooo00kooooo0_l0000Kooooo`;o0000S?ooool00:Co
oooo0_l00006ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`;o00001_ooool00ol0003ooooo
ooooo`2iooooo`00Qoooool2o`0000[ooooo0_l0000Gooooo`03o`000?oooooooooo0;Wooooo0027
ooooo`;o00002_ooool2o`0001Oooooo0_l0002jooooo`00[?ooool2o`0001;ooooo0_l0002Voooo
o`00V_ooool2o`0000oooooo0_l0000Cooooo`;o00007Oooool3o`0008Kooooo002Jooooo`;o0000
3oooool4o`0002kooooo1Ol00026ooooo`00[?ooool01?l0003oooooooooooooool2o`0002_ooooo
0_l000000ooooooo0000o`000026ooooo`00[?ooool00ol0003oooooo`000003o`0002kooooo0_l0
0026ooooo`00[?ooool01?l0003oooooo`000?l0002hooooo`00Soooool3o`0001[ooooo00?o0000
ooooooooool0^Oooool008oooooo0ol0000Jooooo`03o`000?oooooooooo01?ooooo0_l0002Toooo
o`00[?ooool00ol0003oooooooooo`0Cooooo`;o0000Y?ooool00:cooooo00?o0000ooooooooool0
^Oooool00:cooooo0ol00002ooooo`;o0000]Oooool00:cooooo00?o0000ooooooooool00_ooool2
o`0003?ooooo0_l00020ooooo`00[?ooool00ol0003oooooooooo`0gooooo`;o0000P?ooool00:co
oooo00?o0000ooooooooool0^Oooool009Kooooo0_l0000Dooooo`03o`000?oooooooooo01Wooooo
0_l0002Nooooo`00U_ooool2o`0000Kooooo0_l00009ooooo`;o000000?oooooo`000?ooool06_oo
ool2o`0009kooooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@03ooooool0
003o000000;o000000GoA4A4o`000?l0003o<S8bomgMg@02ooooo`;o000000?oooooo`000?ooool0
2?ooool2o`0000oooooo0ol0002Nooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B43ooooo`;o00000oooool01?mgMgOo<S8booooooooool2o`000003ooooool0003ooooo00So
oooo0_l0000?ooooo`;o0000Woooool008Cooooo0ol00002ooooo`Ko00000_ooool01?l@413ooooo
ooooooooool2o`0000oooooo00?o0000ooooool000000_l000000ooooooo0000ooooo`09ooooo`;o
0000[oooool008Cooooo0ol0000:ooooo`04o`000?ooooooooooooooo`;o00001oooool2o`0000Go
oooo00?oMgMgoc8b<_ooool00_l00002ooooo`?o00002?ooool2o`000:oooooo002Aooooo`05o`00
0?ooooooooooooooool000001_ooool4o`0000;ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005oooo
o`03o`000?oooooooooo0;Wooooo002Aooooo`05oa0@4?ooooooooooooooool@41001_ooool2o`00
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`;o0000<?ooool2o`00
07_ooooo002Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00[ooooo0_l0000^ooooo`Co0000Noooool008cooooo0_l00003ooooo`05
onk^k_lb<S;o0000o`000?o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0>_ooool3o`00
07cooooo0023ooooo`;o00001oooool2o`0000Gooooo0_l0000Gooooo`03o`000?oooooooooo03_o
oooo1?l0001jooooo`00Poooool3o`0002Kooooo00?o0000ooooooooool0>oooool4o`0007[ooooo
0024ooooo`;o00009_ooool00ol0003oooooooooo`02o`000;Oooooo002Cooooo`;o00005oooool5
o`0000cooooo0_l0002Yooooo`00Toooool2o`0001Oooooo00?o0000ooooooooool03_ooool3o`00
0:Sooooo002/ooooo`03o`000?oooooooooo00oooooo0_l0002Xooooo`00VOooool2o`00017ooooo
00?o0000ooooooooool03_ooool2o`000:Wooooo002Gooooo`Co00001_ooool2o`0000Wooooo00?o
0000ooooooooool03_ooool2o`000:Wooooo002Gooooo`;o00002?ooool2o`0000Wooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool08Oooool2o`0009Kooooo002/ooooo`03
o`000?oooooooooo027ooooo0_l00002ooooo`;o0000T_ooool00:cooooo0ol0000Tooooo`?o0000
T_ooool00:_ooooo0_l0000Vooooo`;o0000Toooool00:_ooooo0_l0000Yooooo`;o0000T?ooool0
09_ooooo0_l0000?ooooo`03o`000?oooooooooo02?ooooo0_l00002ooooo`;o0000T?ooool009_o
oooo0_l0000?ooooo`03o`000?oooooooooo01;ooooo0_l0000?ooooo`;o0000U?ooool00:cooooo
00?o0000ooooooooool01Oooool2o`0000_ooooo0_l0002Uooooo`00T?ooool2o`0001[ooooo00?o
0000ooooooooool01Oooool3o`0000[ooooo0_l0002Uooooo`00P_ooool2o`0000cooooo0_l0000J
ooooo`03o`000?oooooooooo00Kooooo0_l0000:ooooo`;o00005?ooool2o`0008oooooo0022oooo
o`;o0000:?ooool3o`0002Sooooo0_l0002?ooooo`00R_ooool2o`0000kooooo0_l0000@ooooo`03
o`000?oooooooooo01?ooooo0_l0002Tooooo`00R_ooool2o`0000kooooo0_l0000@ooooo`03o`00
0?oooooooooo01?ooooo0_l0002Tooooo`00X?ooool2o`0000Gooooo0_l00003ooooo`03o`000?oo
oooooooo0;Wooooo002:ooooo`;o00005?ooool2o`0000Gooooo0_l00003ooooo`03o`000?oooooo
oooo00;o00004_ooool2o`000:?ooooo002:ooooo`;o00002?ooool2o`0000Wooooo0_l0000;oooo
o`03o`000?oooooooooo00;o00004_ooool2o`000:?ooooo002?ooooo`;o00000oooool2o`0000Wo
oooo0_l0000;ooooo`03o`000?oooooooooo02Wooooo0_l0000Oooooo`;o0000KOooool008oooooo
0_l0000Kooooo`03o`000?oooooooooo00Wooooo0_l0000<ooooo`;o00004?ooool2o`0001oooooo
0_l0001]ooooo`00U?ooool2o`0000;ooooo0_l0000Booooo`03o`000?oooooooooo00;ooooo0_l0
0005ooooo`;o00003?ooool2o`000:3ooooo0029ooooo`;o00002Oooool2o`0000;ooooo0_l0000B
ooooo`?o00000_ooool2o`0000Kooooo0_l0002]ooooo`00ROooool2o`00027ooooo00?o0000oooo
ooooool00_ooool2o`0000Kooooo0_l0000Qooooo`;o00006_ooool2o`0006kooooo002/ooooo`03
o`000?oooooooooo02gooooo0_l0000Jooooo`Co0000K?ooool00:cooooo00?o0000ooooooooool0
3?ooool2o`00023ooooo0_l0000Iooooo`Co0000K?ooool0087ooooo0ol0000Xooooo`03o`000?oo
oooooooo00cooooo0_l0000Pooooo`;o00006Oooool2o`0006kooooo0021ooooo`?o00001Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Gooooo00?o0000ooooooooool0;_ooool2o`0008Wooooo0029ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@;ooooo0_l000001OnHV9So8B4Qonk^k_ooooooA4A400Oo
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Jooooo`;o00003_ooool2o`0000;o
oooo0_l00029ooooo`00POooool6o`0000;ooooo00Go410@oooooooooooooooooa0@4009ooooo`;o
000000CooooooiRHV?lQ8B7ok^k^2Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01[ooooo0_l0000>ooooo`?o0000S?ooool008Wooooo00Go0000ooooooooooooooooo`00000=oooo
o`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0002_ooooo0_l0002<oooo
o`00ROooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0^Oooool008Wooooo00Go410@oooo
oooooooooooooa0@400<ooooo`;o000000?oooooo`000?ooool00oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo01[ooooo0_l0002Mooooo`00ROooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo0ol000000onHV9So410@ooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool03Oooool2o`0000_ooooo0_l0002Mooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00000oooool2o`000003ooooool0
003ooooo00kooooo0_l0000;ooooo`;o00005Oooool2o`0008Kooooo002=ooooo`;o00006_ooool2
o`000003ooooool0003ooooo01_ooooo0_l0000Eooooo`;o0000Q_ooool008gooooo0_l0000Moooo
o`03o`000?oooooooooo00;o0000;oooool2o`0008Kooooo002/ooooo`03o`000?oooooooooo00;o
00003Oooool2o`00023ooooo0_l00026ooooo`00[?ooool3o`0000oooooo0_l0000Nooooo`;o0000
R?ooool00:cooooo00?o0000ooooooooool0;oooool2o`0008Sooooo0020ooooo`;o0000:_ooool0
0ol0003oooooooooo`2iooooo`00P?ooool2o`0002[ooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool0^Oooool009gooooo0_l0000=ooooo`03o`000?oooooooooo01kooooo
0_l0002Iooooo`00WOooool2o`0000gooooo00?o0000ooooooooool07_ooool2o`0003;ooooo0_l0
001Uooooo`00SOooool2o`0001gooooo00?o0000ooooooooool07?ooool3o`0001?ooooo0_l0000N
ooooo`;o0000IOooool008gooooo0_l0000Mooooo`?o00003oooool3o`0000[ooooo0ol0000Coooo
o`;o0000QOooool008Oooooo0_l00008ooooo`;o00006Oooool00ol0003oooooooooo`0?ooooo`Co
00002Oooool2o`0009_ooooo0027ooooo`;o00002?ooool2o`0001Wooooo00?o0000ooooooooool0
4Oooool2o`0000Wooooo0_l0002Kooooo`00[?ooool00ol0003oooooooooo`0Booooo`;o0000YOoo
ool00:cooooo00?o0000ooooooooool04_ooool2o`0001cooooo0_l00002ooooo`;o0000Poooool0
0:cooooo00?o0000ooooooooool0<?ooool2o`0000;ooooo0_l00023ooooo`00S?ooool2o`0000Ko
oooo0_l0000Fooooo`03o`000?oooooooooo00?ooooo0_l0000_ooooo`;o00007Oooool2o`0006Co
oooo002<ooooo`;o00001_ooool2o`0001Kooooo00?o0000ooooooooool00oooool2o`0001[ooooo
0_l0000Cooooo`;o00007Oooool2o`0006Cooooo002/ooooo`03o`000?oooooooooo01oooooo0_l0
000Cooooo`;o0000Poooool009Cooooo0_l0000Fooooo`?o0000=?ooool2o`0001cooooo0_l0001U
ooooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool00oooool2o`0002oooooo0_l0000Loooo
o`;o0000IOooool00:cooooo00?o0000ooooooooool00oooool2o`0002oooooo0_l0000Looooo`;o
0000IOooool000Wooooo1?l000000ol@413oooooooooo`0Fooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo
00GoA4A4o`000?l0003o<S8bomgMg@0Fooooo`03o`000?oooooooooo01Sooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0?
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@03ooooool0003o000000;ooooo00Go
A4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1?l000000ol@
413oooooooooo`0Booooo`002oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`0>oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1oooool00omgMgOo<S8booooo`0Eooooo`03o`000?oooooooooo00Wooooo0_l0000=ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007oooo
o`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool0
0omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?o
EEEEojVYZOooool01oooool00omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo0006
o`0000Gooooo00?o0000ooooooooool04?ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool01Oooool6o`0000;ooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool02Oooool2o`0000gooooo00Go410@oooooooooooooooooa0@4004oooo
o`;o00001_ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00gooooo00Go410@oooo
oooooooooooooa0@400@ooooo`03o`000?oooooooooo00gooooo00Go410@oooooooooooooooooa0@
400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_oo
ool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000oooooooooooooooo
o`00000?ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000=ooooo`03
oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool05Oooool00ol0003oooooooooo`0Hooooo`05
o`000?ooooooooooooooool000000oooool3o`0000Oooooo00?oV9RHob4Q8Oo^k^h01oooool00omg
MgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000002_ooool2o`0000?ooooo00?oMgMg
oc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_oo
ool00omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooo
oooo01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKo
oooo00?ooooo00?o0000ob4Q8Ol000000_l0000Fooooo`03o`000?oooooooooo01Sooooo00Go0000
ooooooooooooooooo`000003ooooo`;o00002Oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000[ooooo0ol000001?lQ8B7o
0000oc8b<_o<c<`?ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06_ooool00ol0003oooooooooo`0Dooooo`002oooool0
0ol0003oooooooooo`0Hooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgoooo
o`03ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`00
0?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_l0000Fooooo`?o00001?ooool2o`0001;ooooo00Go410@oooooooo
oooooooooa0@4003ooooo`;o00002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
017ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo017ooooo00Go410@
oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool0
4Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooo
oooo00;o00005_ooool00ol0003oooooooooo`04ooooo`;o00000oooool2o`0000Oooooo0_l00004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool2o`0000Gooooo00Go0000okZj^_ooooooV9RH
oa0@4004ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`;o
00004oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05?ooool000Wooooo00?oEEEEofIV
I_l000006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00004?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1Ol0000Fooooo`03o`000?oooooooooo00Wo
oooo0_l00007ooooo`;o00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo0_l00005oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`Go00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co0000
6Oooool00omEEEGoIVIVo`00000Fooooo`00[?ooool00ol0003oooooooooo`0:ooooo`;o00001ooo
ool2o`0002;ooooo0_l0000Mooooo`;o0000HOooool00:cooooo00?o0000ooooooooool02_ooool2
o`0000Oooooo0_l0000Rooooo`;o00007Oooool2o`00067ooooo002/ooooo`03o`000?oooooooooo
02;ooooo0_l0002:ooooo`;o00000_ooool2o`0000Gooooo001oooooo`Co00002Oooool2o`0001ko
oooo00?o0000ooooooooool08_ooool2o`0008[ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd5
ooooo`00Ooooool4o`0000Wooooo0_l0000Nooooo`03o`000?oooooooooo01Cooooo0_l0002Ioooo
o`04omgMgOl0003o410@olc<c0Kooooo0007oooooooo0000C?l0000<ooooo`04onk^k_lQ8B7o410@
onk^kPKooooo0007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`02o`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Cooooo0ol00007ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00Co0000oooo
oooooooooooo0_l000000ooooooo0000o`000007ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00Co8B4Q
ogMgMomgMgOo<S8b1_ooool000Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo00cooooo0_l0000Hooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`09ooooo`;o00000_ooool2o`0000Gooooo002/oooo
o`03o`000?oooooooooo00Cooooo0_l0002cooooo`00S?ooool2o`0001kooooo00?o0000oooooooo
ool01?ooool2o`0002oooooo0_l00022ooooo`00S?ooool2o`0001kooooo00?o0000ooooooooool0
4_ooool2o`00027ooooo0_l00022ooooo`00SOooool2o`0001gooooo00?o0000ooooooooool04_oo
ool2o`000:Gooooo002=ooooo`;o00007Oooool00ol0003oooooooooo`2iooooo`00S?ooool2o`00
01kooooo0ol0000fooooo`;o00007?ooool2o`0006?ooooo002<ooooo`;o00007_ooool00ol0003o
ooooooooo`0Booooo`?o00008Oooool2o`0001cooooo0_l0001Sooooo`00P?ooool2o`0002[ooooo
00?o0000ooooooooool04_ooool3o`0000gooooo0_l0000Booooo`;o0000POooool0083ooooo0_l0
000?ooooo`;o00006Oooool00ol0003oooooooooo`04ooooo`;o00003Oooool2o`0000gooooo0_l0
000Booooo`;o00007Oooool2o`0006;ooooo002Aooooo`;o00006Oooool00ol0003oooooooooo`04
ooooo`;o00003Oooool2o`00043ooooo0_l0001Rooooo`00P?ooool2o`0002[ooooo00?o0000oooo
ooooool02_ooool2o`0002Sooooo0_l00023ooooo`00P?ooool2o`0002[ooooo00?o0000oooooooo
ool02_ooool2o`0002Sooooo0_l0000Pooooo`;o0000HOooool00:cooooo00?o0000ooooooooool0
5?ooool2o`00043ooooo0_l0001Qooooo`00[?ooool00ol0003oooooooooo`0Dooooo`;o0000Xooo
ool009Cooooo0_l0000Fooooo`Co0000=_ooool2o`00083ooooo0020ooooo`;o00002_ooool2o`00
00Kooooo0_l0000Fooooo`04o`000?oooooo0000o`00023ooooo0_l0000Dooooo`;o0000P?ooool0
083ooooo0_l00005ooooo`;o00000oooool2o`0000Kooooo0_l0000Fooooo`03o`000?oooooooooo
027ooooo0_l0000@ooooo`;o00000_ooool2o`00083ooooo0027ooooo`;o00008oooool00ol0003o
ooooooooo`03ooooo`;o0000;_ooool2o`0000;ooooo0_l00020ooooo`00[?ooool00ol0003ooooo
ooooo`03ooooo`;o00003Oooool2o`000:Gooooo002/ooooo`03o`000?oooooooooo00Wooooo0_l0
0007ooooo`;o00008oooool2o`0001gooooo0_l0001Qooooo`00[?ooool00ol0003oooooooooo`09
ooooo`;o0000;?ooool2o`0001gooooo0_l0001Qooooo`00T_ooool2o`0001Sooooo00?o0000oooo
ooooool0<oooool2o`0008Cooooo002Booooo`;o00006?ooool3o`0000?ooooo0_l0000^ooooo`;o
0000Q?ooool009Gooooo0_l0000Eooooo`03o`000?oooooooooo00?ooooo0_l0002dooooo`00UOoo
ool2o`0001Gooooo00?o0000ooooooooool02Oooool2o`0001Kooooo0_l0002Fooooo`00U_ooool2
o`0001Cooooo00?o0000ooooooooool02Oooool2o`0001?ooooo0_l000000ooooooo0000o`00000@
ooooo`;o0000Q?ooool009Kooooo0_l0000Dooooo`03o`000?oooooooooo01kooooo0_l000000ooo
oooo0000o`00000@ooooo`;o0000Q?ooool00:cooooo0_l0000Rooooo`;o0000U_ooool00:cooooo
0_l0001Dooooo`;o0000I?ooool00:cooooo00?o0000ooooooooool0Doooool2o`0006Cooooo002F
ooooo`;o00005?ooool3o`00017ooooo0_l0000Sooooo`;o0000POooool008Sooooo0_l0000<oooo
o`;o00005?ooool00ol0003oooooooooo`08ooooo`;o00001_ooool3o`0002?ooooo0_l00021oooo
o`00R?ooool3o`00027ooooo00?o0000ooooooooool02?ooool2o`0000Kooooo0ol0000;ooooo`;o
0000VOooool008Wooooo0_l0000Qooooo`03o`000?oooooooooo00Sooooo0_l0000Dooooo`;o0000
VOooool00:_ooooo0_l0002kooooo`00SOooool2o`0001cooooo0_l0000dooooo`;o0000QOooool0
08Wooooo00Cok^k^oc8b<_l0003o<S8b0_l00004ooooo`;o00001?ooool5o`0000Cooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo03;ooooo0_l00025ooooo`00ROooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l00004ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo037ooooo0_l00026ooooo`00ROoo
ool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003ooooo
ooooo`03ooooo`?o0000<Oooool2o`0008Kooooo0029ooooo`05o`000?ooooooooooooooool00000
3Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
0_l0000<ooooo`?o00002oooool4o`0009Wooooo0021ooooo`;o00001_ooool01Ol0003ooooooooo
oooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool00_l0000<ooooo`?o00002oooool4o`00013ooooo0_l00027ooooo`00
POooool2o`0000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0>ooooo`?o00002_ooool3o`0001;o
oooo0_l00027ooooo`00P_ooool2o`0000Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00gooooo1?l0000:ooooo`Go0000VOooool008;ooooo0_l00005ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01?nHV9So410@o`000?lQ8B42o`0000?ooooo1?l00006ooooo`03o`000?oooooo
oooo00Kooooo0_l00005ooooo`;o00003_ooool3o`00013ooooo0_l00027ooooo`00WOooool2o`00
00gooooo00?o0000ooooooooool01_ooool2o`0001?ooooo0_l0000Cooooo`;o000000?oooooo`00
0?l00000Q?ooool008;ooooo0_l0000Xooooo`03o`000?oooooooooo01_ooooo0_l0000Fooooo`?o
0000Poooool008;ooooo0_l0000Xooooo`03o`000?oooooooooo00kooooo0_l0000Sooooo`?o0000
Poooool00:cooooo0ol0000>ooooo`;o00008oooool2o`0001gooooo0_l0001Uooooo`00[?ooool2
o`0000Gooooo0_l0000Yooooo`;o00007oooool4o`0006Gooooo002/ooooo`03o`000?oooooooooo
00Cooooo0_l0000Xooooo`?o00007oooool2o`0006Oooooo002/ooooo`03o`000?oooooooooo00?o
oooo0_l0000Yooooo`;o0000ROooool008[ooooo0_l0000Pooooo`03o`000?oooooooooo00?ooooo
0_l0000Eooooo`;o00005oooool2o`0001cooooo0_l0001Vooooo`00P_ooool2o`0000Kooooo0_l0
000Pooooo`03o`000?oooooooooo01[ooooo0_l0000Gooooo`;o00007?ooool2o`0006Kooooo0022
ooooo`;o0000:?ooool00ol0003oooooooooo`0Kooooo`;o00004oooool2o`0008Oooooo002@oooo
o`;o00006_ooool00ol0003oooooooooo`02ooooo`?o00005_ooool2o`0001;ooooo0ol00027oooo
o`00T?ooool3o`0000[ooooo0_l0000=ooooo`?o00000_ooool3o`0002[ooooo0_l00028ooooo`00
TOooool2o`0000[ooooo0_l0000=ooooo`03o`000?oooooooooo02oooooo0_l00028ooooo`00Pooo
ool2o`0001Sooooo0_l0000=ooooo`03o`000?oooooooooo0;Wooooo0023ooooo`;o00006?ooool2
o`0000gooooo00?o0000ooooooooool06Oooool2o`00017ooooo0_l0002;ooooo`00[?ooool00ol0
003oooooooooo`09ooooo`Co00003?ooool2o`00017ooooo0_l0002;ooooo`00[?ooool00ol0003o
ooooooooo`09ooooo`Co00007oooool4o`0001kooooo0_l0001Yooooo`00Uoooool2o`0001?ooooo
00?o0000ooooooooool02?ooool3o`0000_ooooo0ol0000Eooooo`;o00007_ooool2o`0006Wooooo
002Gooooo`;o00001_ooool2o`0000_ooooo00?o0000ooooooooool02?ooool2o`0000cooooo0ol0
002Pooooo`00Woooool2o`0000?ooooo0_l00006ooooo`?o0000;Oooool2o`0001kooooo0_l0001Z
ooooo`00Q?ooool2o`0001kooooo0_l00006ooooo`03o`000?oooooooooo02gooooo0_l0000Noooo
o`;o0000J_ooool008Cooooo0_l00005ooooo`;o00007oooool00ol0003oooooooooo`08ooooo`;o
00008oooool3o`0008Wooooo002;ooooo`;o00007oooool00ol0003oooooooooo`08ooooo`;o0000
9?ooool2o`0008Wooooo002/ooooo`03o`000?oooooooooo00Kooooo0ol0000Tooooo`;o0000R_oo
ool008Cooooo0_l0000<ooooo`;o00001_ooool2o`00013ooooo00?o0000ooooooooool01_ooool3
o`00023ooooo0_l00002ooooo`;o0000R_ooool008Cooooo0_l0000<ooooo`;o00001_ooool2o`00
013ooooo00?o0000ooooooooool0:Oooool2o`0008kooooo002/ooooo`03o`000?oooooooooo02Wo
oooo1?l0002<ooooo`00S?ooool2o`0001gooooo1?l0000Yooooo`Co0000S?ooool008cooooo0_l0
000Mooooo`;o00001oooool2o`000;;ooooo002/ooooo`03o`000?oooooooooo00Gooooo0_l0002b
ooooo`00UOooool2o`0001;ooooo0_l000000ooooooo0000ooooo`06ooooo`;o0000/_ooool009Go
oooo0_l0000Booooo`;o000000?oooooo`000?ooool0^_ooool008gooooo0_l00006ooooo`;o0000
4?ooool2o`0000?ooooo00?o0000ooooooooool00_ooool2o`0002;ooooo0_l0002Aooooo`00SOoo
ool2o`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM00;o00000oooool00ol0003oooooooooo`02ooooo`;o00008_ooool2o`00097o
oooo002>ooooo`;o000000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1_ooool3o`00
0003oc8b<_oooooooooo00?ooooo00?o0000ooooooooool03_ooool3o`0001Gooooo1Ol0002>oooo
o`00S_ooool2o`000003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool2o`000004
ooooool0003o0000o`0000Gooooo00?o0000ooooooooool03_ooool3o`0001Gooooo1Ol0002>oooo
o`00TOooool01Ol0003ooooooooooooooooo000000_ooooo0_l00002ooooo`03ogMgMolb<S;ooooo
00Cooooo0ol0002iooooo`00TOooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;Wooooo002Aooooo`06oa0@4?oooooooooo
ooooool@413ooooo0_l00009ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03ooo
ool2o`0001Gooooo0_l0002Aooooo`00TOooool01_mgMgOoV9RHoooooonHV9SoMgMgooooo`?o0000
2?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo0_l000000ooooooo0000
o`00000Eooooo`;o0000TOooool008Oooooo0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0_ooool2o`0000Sooooo1?l00006ooooo`03o`000?oooooooooo00cooooo0_l0002[ooooo`00Qooo
ool2o`0002?ooooo00?o0000ooooooooool09Oooool2o`0009;ooooo002/ooooo`04o`000?oooooo
0000o`0002Cooooo0_l0002Booooo`00[?ooool01?l0003oooooo`000?l0002hooooo`00Qoooool2
o`0002?ooooo0ol0000<ooooo`;o00005_ooool2o`0009?ooooo0027ooooo`;o00008oooool00ol0
003oooooooooo`0:ooooo`Co00005_ooool2o`0009?ooooo002Aooooo`;o00006Oooool00ol0003o
ooooooooo`0:ooooo`?o0000[?ooool0097ooooo0_l0000Gooooo`?o00003?ooool3o`000:cooooo
002Zooooo`?o00008oooool2o`0009Kooooo002/ooooo`03o`000?oooooooooo027ooooo0_l0002F
ooooo`00ZOooool2o`000003ooooool0003ooooo0;[ooooo002Booooo`;o00003oooool2o`0000Co
oooo0_l000000ooooooo0000ooooo`0Nooooo`;o0000V_ooool009;ooooo0_l00009ooooo`;o0000
1?ooool2o`0000?ooooo0_l00002ooooo`?o00007Oooool2o`0009[ooooo002Booooo`;o00002Ooo
ool2o`0000Wooooo0_l00002ooooo`03o`000?oooooooooo0;Wooooo002Booooo`;o00005?ooool2
o`0000;ooooo00?o0000ooooooooool0^Oooool008Wooooo0_l0000Qooooo`03o`000?oooooooooo
0;Wooooo0029ooooo`;o00008Oooool00ol0003oooooooooo`0Nooooo`;o0000VOooool00:cooooo
00?o0000ooooooooool01Oooool2o`0001?ooooo0_l00002ooooo`;o00007Oooool2o`0007[ooooo
002/ooooo`03o`000?oooooooooo00Gooooo0_l0000Cooooo`Co00007oooool2o`0007[ooooo002/
ooooo`03o`000?oooooooooo01[ooooo1?l0002Kooooo`00[?ooool3o`0001Sooooo0_l0002Ooooo
o`00[?ooool00ol0003oooooooooo`03ooooo`;o00004oooool2o`0009oooooo002/ooooo`03o`00
0?oooooooooo00?ooooo0_l0002dooooo`00[?ooool00ol0003oooooooooo`2iooooo`00Roooool2
o`0000[ooooo0_l0000Cooooo`03o`000?oooooooooo0;Wooooo002;ooooo`?o00002Oooool2o`00
01?ooooo00?o0000ooooooooool0>Oooool2o`0007kooooo002<ooooo`;o00002_ooool2o`0001;o
oooo00?o0000ooooooooool06?ooool2o`0001oooooo0_l0001nooooo`00V?ooool3o`00017ooooo
00?o0000ooooooooool06?ooool2o`0009oooooo002Hooooo`?o00004Oooool00ol0003ooooooooo
o`0Cooooo`;o0000Y?ooool00:cooooo0ol0000Cooooo`;o0000Y?ooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
4oooool2o`0001oooooo0_l00023ooooo`00[?ooool00ol0003oooooooooo`0Cooooo`;o00007ooo
ool2o`0008?ooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o
0000onk^k_ooool01?ooool01?m4A4Co0000o`000?lb<S82o`0000?ooooo0_l0002kooooo`00ROoo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00;ooooo
0_l000001?oooooo0000o`000?mgMgL4o`000003ooooool0003o00000;_ooooo0029ooooo`05oa0@
4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`02ooooo`;o000000Koooooo`000?l0
003oooooo`000?ooool2o`0000;ooooo00?o0000ooooooooool04?ooool2o`000:Oooooo0029oooo
o`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;o
oooo00;o00000_ooool3o`00013ooooo0ol0002Vooooo`00ROooool01Ol0003ooooooooooooooooo
000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool04Oooool2o`0001gooooo0_l00027ooooo`00ROooool01Ol@413ooooooooooooo
oooo410@00kooooo00?oZJVYogMgMoooool00_ooool2o`0000Wooooo00?o0000ooooooooool0<?oo
ool2o`0008Oooooo0029ooooo`06ogMgMonHV9SooooooiRHV?mgMgOooooo0_l00008ooooo`05oa0@
4?oooooooooooooooolb<S800oooool2o`0000Wooooo00?o0000ooooooooool0^Oooool008Wooooo
00Kok^k^oc8b<_l0003o<S8bonk^k_ooool2o`0000Sooooo1Ol00004ooooo`Co00001_ooool00ol0
003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00T?ooool2o`0001[ooooo
00?o0000ooooooooool02Oooool2o`000:kooooo002@ooooo`;o00006_ooool00ol0003ooooooooo
o`09ooooo`;o0000[_ooool00:cooooo0ol0002iooooo`00TOooool2o`0001Wooooo00?o0000oooo
ooooool01_ooool2o`000;7ooooo002Aooooo`;o00006Oooool00ol0003oooooooooo`06ooooo`;o
0000/Oooool009?ooooo0_l0000Gooooo`03o`000?oooooooooo0;Wooooo002Cooooo`;o00005ooo
ool00ol0003oooooooooo`09ooooo`;o0000[_ooool00:cooooo00?o0000ooooooooool02Oooool2
o`000:kooooo002Eooooo`;o00005Oooool00ol0003oooooooooo`2iooooo`00UOooool2o`0001Go
oooo00?o0000ooooooooool0^Oooool00:cooooo0ol000000ooooooo0000o`00002fooooo`00[?oo
ool01?l0003oooooooooooooool2o`0002;ooooo0_l0002Booooo`00[?ooool00ol0003ooooooooo
o`0Uooooo`;o0000T_ooool00:cooooo00Co0000ooooool0003o0000^?ooool00:cooooo00?o0000
ooooool000001?l0002eooooo`00[?ooool00ol0003oooooooooo`04o`000;Gooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002Hooooo`;o00004_ooool01?l0003oooooo`000?l0002hooooo`00
V?ooool2o`00013ooooo0ol000000ooooooo0000o`00002hooooo`00W_ooool2o`0000[ooooo1Ol0
002iooooo`00W?ooool4o`0000Kooooo1?l000001?oooooo0000o`000?l0002jooooo`00W?ooool2
o`0000Sooooo1?l00002ooooo`;o00007_ooool2o`0009[ooooo002/ooooo`03o`000?oooooooooo
01gooooo0_l0002Jooooo`00Woooool2o`0000_ooooo00?o0000ooooooooool0^Oooool009oooooo
0_l0000;ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Ooo
ool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:;o
oooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000ooooooooool01Ooo
ool3o`000;Wooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo
0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo
002Rooooo`03oeEEEOmVIVKo00000<?ooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo002Zooooo`04oa0@4?l0003o0000o`000;[ooooo002[ooooo`03o`000?oo
oooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`06o`000?mgMgOo0000
o`000?mEEEGok^k^]oooool00:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomEEEFgooooo`00Zooo
ool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo0;Gooooo002[ooooo`03o`000?o^k^ko
oooo00;ooooo00?o0000ooooooooool0]Oooool00:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomV
IVJgooooo`00Z_ooool00ol@413o0000ogMgM`02o`000003ofIVI_o^k^kooooo0;Kooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.39006 .61824 Mdot
.41552 .18683 Mdot
.4467 .44988 Mdot
.49426 .73776 Mdot
.5017 .79383 Mdot
.52836 .82685 Mdot
.43624 .49296 Mdot
.4454 .97425 Mdot
.50473 .95407 Mdot
.46619 .22508 Mdot
.54107 .33351 Mdot
.37701 .72398 Mdot
.54941 .15323 Mdot
.49748 .23266 Mdot
.36913 .38668 Mdot
.42642 .65078 Mdot
.60801 .4328 Mdot
.55529 .1607 Mdot
.57479 .57055 Mdot
.68916 .46427 Mdot
.58869 .22043 Mdot
.49842 .10012 Mdot
.55077 .17381 Mdot
.57651 .19349 Mdot
.40078 .13397 Mdot
.40344 .39593 Mdot
.56557 .43756 Mdot
.5701 .58591 Mdot
.69071 .51149 Mdot
.4428 .11729 Mdot
.62551 .30025 Mdot
.52895 .92936 Mdot
.44004 .95927 Mdot
.61188 .56148 Mdot
.61091 .615 Mdot
.67852 .48385 Mdot
.64333 .73607 Mdot
.57268 .53882 Mdot
.67849 .59828 Mdot
.37942 .75153 Mdot
.37613 .26996 Mdot
.61389 .58179 Mdot
.57252 .73667 Mdot
.39387 .67705 Mdot
.42536 .83053 Mdot
.434 .76959 Mdot
.51628 .27795 Mdot
.59024 .84768 Mdot
.49734 .1688 Mdot
.68461 .545 Mdot
.58457 .85367 Mdot
.68083 .61657 Mdot
.78181 .48969 Mdot
.58466 .70064 Mdot
.59924 .6714 Mdot
.4675 .97701 Mdot
.42562 .93928 Mdot
.60497 .40646 Mdot
.61898 .79458 Mdot
.43872 .86225 Mdot
.41506 .68552 Mdot
.55438 .05762 Mdot
.67166 .62367 Mdot
.53047 .38131 Mdot
.39822 .83397 Mdot
.50987 .95393 Mdot
.46652 .22707 Mdot
.42454 .62831 Mdot
.57582 .5132 Mdot
.60107 .23615 Mdot
.60629 .38907 Mdot
.47357 .31296 Mdot
.48757 .22984 Mdot
.43324 .30119 Mdot
.67154 .62388 Mdot
.49683 .3907 Mdot
.78179 .49059 Mdot
.40774 .3769 Mdot
.68552 .58906 Mdot
.52586 .22725 Mdot
.65834 .38576 Mdot
.44563 .11452 Mdot
.50231 .71745 Mdot
.6153 .58149 Mdot
.47739 .98782 Mdot
.43691 .70856 Mdot
.49553 .8045 Mdot
.43729 .76813 Mdot
.59219 .35369 Mdot
.42105 .59549 Mdot
.41293 .09199 Mdot
.73581 .32379 Mdot
.54714 .47244 Mdot
.44797 .79894 Mdot
.54436 .45542 Mdot
.71849 .27994 Mdot
.49359 .22758 Mdot
.55431 .89059 Mdot
.78342 .49971 Mdot
.58716 .33089 Mdot
.38583 .48581 Mdot
.56949 .29195 Mdot
.37001 .63896 Mdot
.38524 .54912 Mdot
.63736 .31229 Mdot
.61072 .5775 Mdot
.61424 .43596 Mdot
.57072 .60476 Mdot
.54736 .47352 Mdot
.6095 .25438 Mdot
.47592 .21748 Mdot
.51179 .70096 Mdot
.5273 .93011 Mdot
.6815 .44303 Mdot
.77088 .66056 Mdot
.49613 .6886 Mdot
.40313 .55603 Mdot
.52656 .94135 Mdot
.53406 .92939 Mdot
.62672 .7613 Mdot
.55506 .1629 Mdot
.50137 .00314 Mdot
.59148 .23709 Mdot
.69226 .50721 Mdot
.6065 .24705 Mdot
.47079 .75297 Mdot
.68437 .47599 Mdot
.69827 .24375 Mdot
.42335 .17274 Mdot
.4304 .57683 Mdot
.53117 .14209 Mdot
.39346 .33452 Mdot
.36525 .54724 Mdot
.53708 .81688 Mdot
.55765 .77034 Mdot
.69188 .5463 Mdot
.67122 .67494 Mdot
.6878 .50306 Mdot
.48675 .23003 Mdot
.40226 .85993 Mdot
.36763 .40915 Mdot
.63696 .16193 Mdot
.54274 .58802 Mdot
.57716 .52928 Mdot
.60781 .42875 Mdot
.68553 .4494 Mdot
.49719 .97598 Mdot
.75219 .72579 Mdot
.53875 .69898 Mdot
.42977 .74633 Mdot
.4417 .00965 Mdot
.55827 .26685 Mdot
.57035 .4338 Mdot
.57401 .18761 Mdot
.46184 .32347 Mdot
.45427 .87399 Mdot
.66781 .67302 Mdot
.67562 .61881 Mdot
.51003 .95766 Mdot
.63609 .74863 Mdot
.66877 .67312 Mdot
.43247 .21724 Mdot
.68902 .57576 Mdot
.36264 .52986 Mdot
.67343 .45748 Mdot
.55369 .76856 Mdot
.38767 .43583 Mdot
.49758 .97438 Mdot
.64412 .32504 Mdot
.57527 .5048 Mdot
.68003 .64334 Mdot
.68095 .53838 Mdot
.54121 .56912 Mdot
.57283 .49358 Mdot
.47284 .81506 Mdot
.53948 .70253 Mdot
.41374 .89754 Mdot
.71326 .27107 Mdot
.45608 .87485 Mdot
.48012 .7045 Mdot
.68737 .54546 Mdot
.68663 .61174 Mdot
.36629 .6033 Mdot
.41455 .47596 Mdot
.38035 .23516 Mdot
.43277 .38686 Mdot
.49674 .96003 Mdot
.7008 .25199 Mdot
.55751 .89759 Mdot
.36315 .54271 Mdot
.57139 .74343 Mdot
.68544 .44487 Mdot
.51644 .33916 Mdot
.55315 .06009 Mdot
.45807 .9837 Mdot
.38712 .18344 Mdot
.36789 .60952 Mdot
.45379 .80613 Mdot
.74847 .34218 Mdot
.62088 .46936 Mdot
.50524 .65068 Mdot
.50213 .66157 Mdot
.4831 .31521 Mdot
.4889 .80735 Mdot
.75705 .36723 Mdot
.39151 .36207 Mdot
.48288 .27653 Mdot
.50571 .86076 Mdot
.52708 .66195 Mdot
.43677 .35097 Mdot
.54025 .32715 Mdot
.51099 .10576 Mdot
.4043 .42495 Mdot
.64547 .32913 Mdot
.41554 .47516 Mdot
.38964 .39462 Mdot
.40337 .46105 Mdot
.36261 .48067 Mdot
.42698 .43786 Mdot
.42501 .82147 Mdot
.39542 .84477 Mdot
.40532 .59662 Mdot
.59204 .83387 Mdot
.63617 .3043 Mdot
.66574 .42066 Mdot
.41646 .48707 Mdot
.52606 .74291 Mdot
.3929 .31332 Mdot
.54538 .53527 Mdot
.36907 .38591 Mdot
.45028 .73754 Mdot
.48305 .66052 Mdot
.76138 .39517 Mdot
.55404 .2696 Mdot
.56136 .40311 Mdot
.57365 .51129 Mdot
.38424 .49456 Mdot
.57236 .19886 Mdot
.3892 .38662 Mdot
.56141 .06666 Mdot
.55952 .77326 Mdot
.65586 .35035 Mdot
.60603 .38836 Mdot
.54412 .91421 Mdot
.54319 .45922 Mdot
.6562 .69439 Mdot
.59424 .38363 Mdot
.60439 .38183 Mdot
.67487 .61561 Mdot
.38744 .18421 Mdot
.49659 .68672 Mdot
.52343 .36661 Mdot
.6442 .72373 Mdot
.41729 .28795 Mdot
.5721 .48892 Mdot
.60447 .66609 Mdot
.50174 .41238 Mdot
.41951 .9213 Mdot
.60573 .82122 Mdot
.52619 .21494 Mdot
.56086 .40042 Mdot
.66868 .43103 Mdot
.4491 .67704 Mdot
.56252 .28017 Mdot
.39337 .64937 Mdot
.53108 .31481 Mdot
.51567 .83828 Mdot
.6797 .51389 Mdot
.45305 .1801 Mdot
.68134 .47136 Mdot
.5986 .67731 Mdot
.45394 .23714 Mdot
.52519 .2198 Mdot
.6726 .6602 Mdot
.4141 .47599 Mdot
.55786 .66471 Mdot
.5718 .87191 Mdot
.52892 .29558 Mdot
.47746 .88586 Mdot
.68808 .55635 Mdot
.43866 .64784 Mdot
.43048 .32003 Mdot
.63178 .75566 Mdot
.37845 .73039 Mdot
.57084 .60689 Mdot
.44578 .37396 Mdot
.49399 .79442 Mdot
.67402 .39867 Mdot
.42674 .73792 Mdot
.65355 .37331 Mdot
.70292 .25779 Mdot
.61242 .80135 Mdot
.36658 .53604 Mdot
.59501 .82602 Mdot
.45515 .64697 Mdot
.64121 .7534 Mdot
.55083 .06168 Mdot
.66505 .36651 Mdot
.36734 .4314 Mdot
.74016 .7575 Mdot
.50265 .18176 Mdot
.59064 .709 Mdot
.39213 .34373 Mdot
.53699 .92161 Mdot
.38181 .23169 Mdot
.52058 .28509 Mdot
.56528 .8788 Mdot
.42176 .26375 Mdot
.51981 .58159 Mdot
.52023 .11995 Mdot
.61042 .44271 Mdot
.55541 .16611 Mdot
.43241 .02591 Mdot
.47891 .70991 Mdot
.41055 .76629 Mdot
.61193 .5775 Mdot
.38837 .78381 Mdot
.45462 .69386 Mdot
.36442 .54616 Mdot
.48947 .00301 Mdot
.64012 .15833 Mdot
.45192 .73608 Mdot
.54468 .80692 Mdot
.61752 .5746 Mdot
.66667 .64814 Mdot
.53547 .72633 Mdot
.52144 .58525 Mdot
.44091 .58025 Mdot
.61169 .42644 Mdot
.4131 .90955 Mdot
.63868 .73184 Mdot
.54288 .4385 Mdot
.50183 .09843 Mdot
.42991 .57654 Mdot
.48639 .31889 Mdot
.39655 .28401 Mdot
.54131 .80639 Mdot
.55378 .76872 Mdot
.43492 .2106 Mdot
.49303 .80159 Mdot
.77904 .45159 Mdot
.43473 .21981 Mdot
.444 .12056 Mdot
.53462 .40364 Mdot
.4454 .96276 Mdot
.56336 .42687 Mdot
.68668 .49925 Mdot
.48845 .09722 Mdot
.54923 .52358 Mdot
.40474 .5555 Mdot
.63198 .15417 Mdot
.38459 .78194 Mdot
.65132 .73544 Mdot
.68 .48767 Mdot
.4783 .15878 Mdot
.61947 .48423 Mdot
.68219 .52159 Mdot
.55744 .27263 Mdot
.38321 .77209 Mdot
.63318 .14363 Mdot
.65824 .35665 Mdot
.36531 .54119 Mdot
.3639 .51013 Mdot
.3686 .34058 Mdot
.50473 .36155 Mdot
.542 .24677 Mdot
.36951 .37429 Mdot
.42508 .93654 Mdot
.50886 .37581 Mdot
.64275 .33834 Mdot
.45376 .18377 Mdot
.51556 .84901 Mdot
.38604 .52255 Mdot
.54133 .90782 Mdot
.38439 .48925 Mdot
.63824 .75152 Mdot
.64881 .70293 Mdot
.54643 .16852 Mdot
.66172 .7109 Mdot
.5306 .14302 Mdot
.38484 .21677 Mdot
.76779 .67946 Mdot
.61297 .78805 Mdot
.4599 .88221 Mdot
.46534 .32287 Mdot
.44671 .01634 Mdot
.58488 .32922 Mdot
.44334 .59689 Mdot
.36659 .61642 Mdot
.60402 .24141 Mdot
.52477 .56456 Mdot
.44446 .26298 Mdot
.40175 .44533 Mdot
.56569 .42576 Mdot
.58726 .85392 Mdot
.63116 .28433 Mdot
.55645 .06568 Mdot
.36527 .58166 Mdot
.61556 .49384 Mdot
.77557 .45367 Mdot
.6177 .49399 Mdot
.54561 .68711 Mdot
.54468 .69589 Mdot
.50955 .56025 Mdot
.41167 .90318 Mdot
.37781 .72982 Mdot
.56447 .43001 Mdot
.54604 .54789 Mdot
.55041 .34605 Mdot
.42194 .63022 Mdot
.41619 .0661 Mdot
.46581 .82052 Mdot
.67276 .43982 Mdot
.53146 .63589 Mdot
.57196 .44924 Mdot
.44357 .66098 Mdot
.47762 .82019 Mdot
.6127 .54597 Mdot
.56389 .4034 Mdot
.49032 .28326 Mdot
.40727 .87923 Mdot
.46103 .60751 Mdot
.60888 .62717 Mdot
.61438 .43778 Mdot
.41776 .78822 Mdot
.46725 .17048 Mdot
.57405 .49098 Mdot
.4379 .02644 Mdot
.72461 .28532 Mdot
.38827 .38236 Mdot
.77951 .61448 Mdot
.39132 .65658 Mdot
.49493 .28706 Mdot
.46743 .9703 Mdot
.37304 .3251 Mdot
.54994 .36421 Mdot
.49885 .1082 Mdot
.78002 .46296 Mdot
.54371 .56892 Mdot
.52698 .5296 Mdot
.52616 .7337 Mdot
.6671 .41618 Mdot
.5032 .18879 Mdot
.74295 .33412 Mdot
.43691 .3562 Mdot
.59227 .67474 Mdot
.61826 .55696 Mdot
.53749 .4066 Mdot
.47242 .70823 Mdot
.4189 .38946 Mdot
.4407 .96753 Mdot
.47468 .71373 Mdot
.68891 .56716 Mdot
.39992 .26591 Mdot
.41443 .78833 Mdot
.68287 .47056 Mdot
.6475 .35721 Mdot
.61368 .46275 Mdot
.68728 .2186 Mdot
.44809 .25329 Mdot
.41065 .9025 Mdot
.38196 .21595 Mdot
.53551 .32856 Mdot
.64569 .74581 Mdot
.46112 .17295 Mdot
.60549 .43417 Mdot
.68675 .49204 Mdot
.38561 .50958 Mdot
.57047 .5969 Mdot
.40481 .56046 Mdot
.61429 .54612 Mdot
.52882 .02647 Mdot
.54531 .78891 Mdot
.48766 .36362 Mdot
.56913 .73913 Mdot
.52303 .22022 Mdot
.49619 .33329 Mdot
.43524 .68531 Mdot
.58955 .68823 Mdot
.5718 .74461 Mdot
.50142 .6692 Mdot
.41415 .31058 Mdot
.50646 .95779 Mdot
.51475 .77149 Mdot
.39828 .69136 Mdot
.57844 .48757 Mdot
.56153 .61914 Mdot
.52001 .42675 Mdot
.77805 .63814 Mdot
.52315 .45287 Mdot
.40519 .23205 Mdot
.57176 .86022 Mdot
.67429 .4554 Mdot
.57583 .52699 Mdot
.68808 .52021 Mdot
.36929 .64779 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00Co0000oooooooooooooooo0_l00002oooo
o`;o0000^_ooool00:Cooooo00Co0000oooooooooooooooo0_l00002ooooo`;o0000^_ooool009So
oooo0_l0000:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool009Sooooo
0_l0000:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool009[ooooo0_l0
0006ooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0^Oooool009[ooooo0_l0000@
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Eooooo`;o
00005Oooool3o`000;Wooooo002Eooooo`Co00004oooool00ol0003oooooooooo`06ooooo`;o0000
/Oooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo00Kooooo0_l0002aooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00oooooo0_l0002Xooooo`00[?oo
ool00ol0003oooooooooo`0=ooooo`Co0000Z?ooool00:cooooo00?o0000ooooooooool03Oooool3
o`000:Wooooo002@ooooo`;o00006_ooool00ol0003oooooooooo`0?ooooo`Co0000Y_ooool0093o
oooo0_l0000Jooooo`03o`000?oooooooooo00oooooo1?l0002Vooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002?ooooo`;o00006oooool00ol0003oooooooooo`2iooooo`00Soooool2
o`0001_ooooo00?o0000ooooooooool0^Oooool00:Sooooo0_l00002ooooo`;o0000^_ooool00:So
oooo0_l000000ooooooo0000o`000002o`000;Wooooo002[ooooo`;o0000^oooool00:cooooo00?o
0000ooooooooool00_l0002gooooo`00Zoooool2o`0000;ooooo0_l0002gooooo`00Zoooool2o`00
0;_ooooo002Jooooo`;o00004?ooool00ol0003oooooooooo`2iooooo`00ROooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`?o000000?ok^k^ooooooooool00oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0^Oooool008Wooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool2o`000003oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`03ooooo`;o0000]?ooool0087ooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41002oooool2o`000003ojVYZOmEEEGooooo00Sooooo00?o0000oooo
ooooool00oooool3o`0000?ooooo0_l0002dooooo`00ROooool01Ol0003ooooooooooooooooo0000
00kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
0;Wooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2iooooo`00ROooool01Ol@
413oooooo`000?l0003o410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05ogMgMonHV9So0000o`000?mgMgL02oooool0
1Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`2iooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`07ooooo`;o00008?ooool2
o`0008kooooo002/ooooo`03o`000?oooooooooo00Oooooo0_l0000Pooooo`;o0000S_ooool00:co
oooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003ooooooooo
o`0=ooooo`;o00006Oooool2o`0008oooooo002Tooooo`;o00001_ooool00ol0003oooooooooo`0=
ooooo`;o00006Oooool2o`000003ooooool0003o000008cooooo002Tooooo`;o00001_ooool00ol0
003oooooooooo`0?ooooo`;o00006Oooool3o`0008cooooo002/ooooo`03o`000?oooooooooo00oo
oooo0_l0000Iooooo`;o0000SOooool00:cooooo00?o0000ooooooooool03oooool2o`000:Sooooo
002Qooooo`;o00002?ooool2o`0000kooooo0_l000000ooooooo0000o`00002Xooooo`00T_ooool2
o`0000_ooooo1?l00008ooooo`;o00003_ooool3o`000:[ooooo002Booooo`;o00002oooool2o`00
00_ooooo0ol0000=ooooo`;o0000Z_ooool009cooooo0_l0000>ooooo`03o`000?oooooooooo0;Wo
oooo0026ooooo`;o00005?ooool2o`0000kooooo0_l0002jooooo`00Q_ooool2o`0001Cooooo0_l0
000>ooooo`;o0000^_ooool008Kooooo0_l00008ooooo`;o00002_ooool2o`0000kooooo0ol0000E
ooooo`;o0000X_ooool0093ooooo0_l0000Jooooo`?o00005Oooool2o`000:;ooooo002/ooooo`03
o`000?oooooooooo01Kooooo0_l0002Qooooo`00[?ooool00ol0003oooooooooo`0Fooooo`;o0000
XOooool00:cooooo0ol0000Dooooo`;o0000Xoooool00:cooooo00?o0000ooooooooool05?ooool2
o`000:?ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Fooooo`;o00005?ooool00ol0003o
ooooooooo`2iooooo`00U_ooool2o`0001Cooooo00?o0000ooooooooool0^Oooool008Gooooo0ol0
000Tooooo`03o`000?oooooooooo00Gooooo0_l0002booooo`00QOooool3o`0000gooooo0_l0000=
ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`;o0000<oooool2o`0007gooooo002Eoooo
o`?o00003?ooool2o`0000Kooooo00?o0000ooooooooool01?ooool3o`0001?ooooo0_l0000Noooo
o`;o0000OOooool009Kooooo0_l00008ooooo`;o00002_ooool3o`0000Cooooo0_l0000Dooooo`;o
0000WOooool00:3ooooo0ol00006ooooo`;o000000?oooooo`000?ooool01_ooool2o`000;;ooooo
0025ooooo`;o00006_ooool2o`0000Cooooo1?l000000ooooooo0000ooooo`06ooooo`;o0000/_oo
ool008Gooooo0_l00005ooooo`;o00006Oooool2o`0000;ooooo0_l0002kooooo`00Q?ooool2o`00
00Kooooo0_l0000>ooooo`;o00003Oooool2o`0001gooooo0_l000000ooooooo0000o`00002Ioooo
o`00Q?ooool2o`0001Kooooo0_l0000>ooooo`03o`000?oooooooooo01_ooooo0_l000000ooooooo
0000o`00002Iooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Oooooo`;o00007Oooool2o`00
07Wooooo002Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`0:ooooo`;o00004oooool3o`0001cooooo0_l0001ioooo
o`00ROooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool02_ooool2o`0001Cooooo0_l0002Gooooo`00TOooool01Ol0003o
oooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool3o`0003oooooo0_l0001hoooo
o`00TOooool01Ol0003ooooooooooooooooo000000Cooooo0_l00006ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Qooooo`;o00007?ooool2o`0007Sooooo002Aoooo
o`05oa0@4?ooooooooooooooool@41001?ooool2o`0000Kooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Qooooo`;o00007Oooool2o`0007Oooooo002Aooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo043ooooo0_l0001g
ooooo`00TOooool01Oo^k^ko0000o`000?lb<S;ok^k^00?ooooo0_l00007ooooo`Co00001_ooool0
0ol0003oooooooooo`2iooooo`00Roooool2o`0000Gooooo0_l00005ooooo`;o00004Oooool00ol0
003oooooooooo`0@ooooo`;o0000Yoooool008?ooooo0_l00006ooooo`;o00007oooool00ol0003o
ooooooooo`0>ooooo`Co0000<Oooool2o`0007Cooooo0023ooooo`;o00009oooool00ol0003ooooo
ooooo`0>ooooo`Co0000<Oooool2o`0007Cooooo002Vooooo`;o00001?ooool3o`00013ooooo0_l0
002Wooooo`00Y_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool2o`0000gooooo0_l0000b
ooooo`;o0000L_ooool00:Sooooo0_l00002ooooo`03o`000?oooooooooo00;ooooo0_l0000=oooo
o`;o0000<_ooool2o`0007;ooooo0029ooooo`;o00007Oooool2o`0000;ooooo00?o0000oooooooo
ool00oooool2o`0002?ooooo0_l0000Mooooo`;o0000L?ooool008Wooooo0_l00005ooooo`;o0000
6?ooool3o`0000Gooooo0_l0000Sooooo`;o00007Oooool2o`00073ooooo002@ooooo`;o00006?oo
ool3o`0001Kooooo0_l0002Sooooo`00[?ooool00ol0003oooooooooo`0Dooooo`;o0000Xoooool0
0:cooooo00?o0000ooooooooool01_ooool2o`000;7ooooo002Fooooo`;o00005?ooool3o`0000Ko
oooo0_l0000Nooooo`;o0000TOooool009Kooooo0_l0000Dooooo`03o`000?oooooooooo02Kooooo
0_l00002ooooo`;o0000SOooool00:cooooo00?o0000ooooooooool0:_ooool2o`0008gooooo002?
ooooo`;o00006oooool00ol0003oooooooooo`2iooooo`00R?ooool2o`0000Gooooo0_l0000Boooo
o`;o00001oooool00ol0003oooooooooo`0Zooooo`;o0000SOooool008Sooooo0_l0000Iooooo`;o
000000?oooooo`000?l000001?ooool00ol0003oooooooooo`07ooooo`;o00008Oooool2o`0008go
oooo002Vooooo`?o00000oooool00ol0003oooooooooo`07ooooo`;o0000/?ooool009Gooooo0_l0
000@ooooo`;o00000oooool00ol0003oooooooooo`2iooooo`00P_ooool2o`00017ooooo0_l00008
ooooo`?o00002_ooool3o`0002cooooo0_l0000Looooo`;o0000KOooool008;ooooo0_l0000Koooo
o`?o00002_ooool00ol0003oooooooooo`08ooooo`Co00008?ooool2o`0001cooooo0_l0001]oooo
o`00[?ooool00ol0003oooooooooo`08ooooo`Co00003Oooool2o`0001;ooooo0_l0002:ooooo`00
R?ooool2o`00023ooooo0ol0000<ooooo`;o00003Oooool2o`0001;ooooo0_l0000Nooooo`;o0000
J_ooool008Sooooo0_l0000Pooooo`?o00003?ooool2o`00047ooooo0_l0001Zooooo`00P?ooool2
o`0002[ooooo00?o0000ooooooooool00_ooool2o`0002Sooooo0_l0002;ooooo`00P?ooool2o`00
00Kooooo0_l0000Rooooo`03o`000?oooooooooo00;ooooo0_l0000Xooooo`;o00008Oooool2o`00
06Sooooo0028ooooo`;o00008_ooool00ol0003oooooooooo`0=ooooo`;o0000@?ooool2o`0006So
oooo002/ooooo`03o`000?oooooooooo00gooooo0_l0002Zooooo`00Uoooool2o`0001?ooooo0ol0
000`ooooo`;o0000Qoooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo01_ooooo0_l0000C
ooooo`;o0000Qoooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo01_ooooo0_l0000@oooo
o`;o00000_ooool2o`0008Kooooo0028ooooo`;o00003Oooool2o`0001?ooooo0ol0000]ooooo`;o
00000_ooool2o`0008Kooooo0028ooooo`;o00007Oooool2o`0000?ooooo0ol0000=ooooo`;o0000
Z_ooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo
00GoA4A4o`000?l0003o<S8bomgMg@02o`0000?ooooo00?o0000ooooooooool01?ooool2o`0000Oo
oooo0_l0000Tooooo`;o00007?ooool2o`0006Kooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool01?ooool2o`0002gooooo0_l0000Looooo`;o0000I_ooool0083o
oooo1ol00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool2o`000003onk^k_oooooooooo
00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0_ooooo`;o0000R?ooool0083o
oooo0_l00007ooooo`04o`000?ooooooooooooooo`;o00002oooool2o`000003ob4Q8Oo^k^kooooo
00Kooooo00?oMgMgoc8b<_ooool01?ooool4o`0002kooooo0_l00028ooooo`00ROooool01?l0003o
ooooooooooooool2o`0000gooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00Co0000ooooool0003o0000^?ooool008Oooooo0_l000001Ol@413ooooooooooooo
oooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo0_l0000Fooooo`;o0000V?ooool0083ooooo0_l00005ooooo`;o000000GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo0_l0000Cooooo`;o000000?oooooo`000?l00000
4?ooool2o`0008Kooooo0020ooooo`;o00001Oooool2o`000005onk^k_lb<S;o0000oc8b<_o^k^h0
1oooool2o`0000;ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003o
ooooooooo`0Looooo`;o00000_ooool2o`0000oooooo0_l00026ooooo`00P?ooool2o`0000Gooooo
0_l00008ooooo`;o00000_ooool2o`0001Cooooo0_l0000Rooooo`;o0000Uoooool008Oooooo0_l0
0008ooooo`;o00006?ooool2o`0005Gooooo0_l0001Tooooo`00Qoooool2o`0000?ooooo0_l0000N
ooooo`03o`000?oooooooooo05?ooooo0_l0001Tooooo`00S?ooool2o`0001kooooo0ol0000Aoooo
o`;o00008oooool2o`00087ooooo002/ooooo`03o`000?oooooooooo00Sooooo0_l00007ooooo`?o
00008_ooool2o`00087ooooo002/ooooo`03o`000?oooooooooo00Sooooo0ol00006ooooo`?o0000
2oooool2o`0009Sooooo0020ooooo`;o0000:_ooool00ol0003oooooooooo`09ooooo`;o00005?oo
ool2o`0009Sooooo0020ooooo`;o0000:_ooool2o`000;[ooooo002/ooooo`;o0000=Oooool2o`00
08?ooooo002/ooooo`03o`000?oooooooooo03Cooooo0_l00023ooooo`00[?ooool00ol0003ooooo
ooooo`0cooooo`;o0000Q?ooool008cooooo0_l0000Nooooo`?o00004_ooool2o`0001oooooo0_l0
0024ooooo`00S?ooool2o`0001kooooo00?o0000ooooooooool00oooool2o`0000cooooo0ol0000<
ooooo`?o0000U_ooool0083ooooo0_l0000Zooooo`03o`000?oooooooooo00?ooooo0_l0000<oooo
o`?o00003?ooool3o`00017ooooo0_l00023ooooo`00P?ooool2o`0002[ooooo00?o0000oooooooo
ool04_ooool4o`0000Wooooo0ol0000Booooo`;o0000Poooool008Kooooo0_l0000;ooooo`;o0000
5oooool00ol0003oooooooooo`0Booooo`Co00002Oooool5o`0009Gooooo0026ooooo`;o00002ooo
ool2o`0001Oooooo00?o0000ooooooooool02oooool2o`0000Gooooo0_l0000>ooooo`;o00004_oo
ool2o`00087ooooo002/ooooo`03o`000?oooooooooo00_ooooo0_l0000Dooooo`;o00004oooool4
o`0007oooooo002;ooooo`;o00007oooool00ol0003oooooooooo`0Qooooo`;o00005Oooool4o`00
07gooooo002;ooooo`;o00003Oooool2o`00013ooooo00?o0000ooooooooool05?ooool2o`0002Co
oooo0_l0001mooooo`00V_ooool2o`00013ooooo0ol00004ooooo`;o00003_ooool2o`0002Cooooo
0_l0000Mooooo`;o0000G_ooool00:cooooo00?o0000ooooooooool01?ooool2o`0000Gooooo0_l0
000Yooooo`;o00008?ooool3o`0005kooooo002/ooooo`03o`000?oooooooooo00_ooooo0_l0000Y
ooooo`;o00008?ooool2o`0005oooooo0009ooooo`Co000000?o410@ooooooooool05_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4
o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo1_l00003ooooo`05odA4A?l0003o0000oc8b<_oMgMd05_ooool00ol0003oooooooooo`0;
ooooo`;o00002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00;o00003Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgM
g@0Hooooo`Co000000?o410@ooooooooool04_ooool000_ooooo00?o0000ooooooooool06?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01?nHV9So
8B4Qonk^k_ooool2o`0000Kooooo00?oMgMgoc8b<_ooool05Oooool00ol0003oooooooooo`0;oooo
o`;o00002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l00004ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`;o00002?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B48ooooo`;o00003oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool06Oooool00ol0003o
ooooooooo`0Dooooo`001_l00005ooooo`03o`000?oooooooooo013ooooo1_l00002ooooo`05oa0@
4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00Go
oooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`05oooo
o`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Sooooo00Go410@oooooooooooooooooa0@
4005ooooo`;o00001Oooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0_l0
0008ooooo`05oa0@4?ooooooooooooooool@41003oooool2o`0000oooooo00Go410@oooooooooooo
oooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool0
00003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000oooooooo
ooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000=
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool05Oooool00ol0003oooooooooo`0H
ooooo`05o`000?ooooooooooooooool000001oooool2o`0000Cooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00omgMgOo<S8booooo`02ooooo`;o00002_ooool01Ol0003ooooooooooooooooo000000oooooo
00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qoooooooo
ool01_ooool00omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`00
0?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003?ooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMg
MomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Fooooo`03o`000?oooooooooo00co
oooo0_l0000:ooooo`05o`000?ooooooooooooooool000001oooool2o`0000Gooooo00?oMgMgofIV
I_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo0ol0000:ooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Joooo
o`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go410@oooooooo
oooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool04Oooool01Ol@
413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooo
oooo410@00oooooo00?o0000ooooooooool00ol0000Jooooo`?o00003?ooool2o`0000[ooooo00Go
410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool3o`0000[ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo017o
oooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000
ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4002ooooo`?o
00006_ooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01Oooool2o`0000[ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo01Cooooo0009ooooo`03oeEEEOmVIVKo000001[ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`Go00001?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`Co00004?ooool01_o^k^ko<S8bo`000?lb<S;ok^k^ooooo`;o00002?ooool01OnHV9So410@o`00
0?lQ8B7oc<c<00Cooooo1?l0000Gooooo`03o`000?oooooooooo01Sooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`00013ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol0
0004ooooo`Co00006Oooool00omEEEGoIVIVo`00000Fooooo`00O_ooool2o`0000Kooooo0_l0000T
ooooo`03o`000?oooooooooo02Cooooo0_l0000Aooooo`;o0000P?ooool008Gooooo0ol00008oooo
o`;o00006_ooool00ol0003oooooooooo`0Dooooo`Co00003?ooool2o`00017ooooo0ol0001ooooo
o`00QOooool2o`0000Wooooo0_l0000Jooooo`03o`000?oooooooooo01Cooooo1?l0000Pooooo`Co
00007_ooool2o`0005;ooooo0_l00002ooooo`;o00001Oooool008Gooooo0_l0000@ooooo`;o0000
4oooool00ol0003oooooooooo`0Eooooo`;o00003?ooool2o`0001Gooooo0_l0000Nooooo`;o0000
D_ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Gooooo0025ooooo`;o00004?ooool2o`0001?o
oooo00?o0000ooooooooool05Oooool2o`0000cooooo0_l0002:ooooo`04omgMgOl0003o410@olc<
c0Kooooo0007oooooooo0000C?l0000<ooooo`04onk^k_lQ8B7o410@onk^kPKooooo0007ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?o00000_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool01?l0003oooooo`000?l00004ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`04ob4Q8OmgMgOoMgMg
oc8b<PKooooo0007ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool05Oooool2o`00
013ooooo00?o0000ooooooooool04Oooool3o`0001;ooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo00Wooooo0_l00002ooooo`;o00001Oooool007oo
oooo0_l00005ooooo`;o00009?ooool00ol0003oooooooooo`0Eooooo`;o00009Oooool2o`0007_o
oooo001oooooo`;o00001Oooool2o`0002Cooooo00?o0000ooooooooool05Oooool3o`0002Cooooo
0_l0001kooooo`00[?ooool00ol0003oooooooooo`0Eooooo`?o00008?ooool2o`0000;ooooo0_l0
001kooooo`00[?ooool00ol0003oooooooooo`0hooooo`;o0000Ooooool008Kooooo0_l0000Toooo
o`03o`000?oooooooooo03Wooooo1?l0001looooo`00Q_ooool2o`0002Cooooo0ol0000=ooooo`;o
0000:_ooool4o`0007cooooo002/ooooo`03o`000?oooooooooo00gooooo0_l00007ooooo`;o0000
XOooool007kooooo0_l0000/ooooo`03o`000?oooooooooo00Gooooo0_l0000?ooooo`;o0000XOoo
ool007kooooo0_l0000/ooooo`03o`000?oooooooooo00Gooooo0_l0000?ooooo`;o0000XOooool0
083ooooo0_l0000Zooooo`03o`000?oooooooooo00cooooo0_l0002[ooooo`00P?ooool2o`0002[o
oooo00?o0000ooooooooool03?ooool2o`0000Oooooo0_l0000Qooooo`;o0000Ooooool007kooooo
0ol0000[ooooo`03o`000?oooooooooo01Gooooo0_l0000Qooooo`;o0000Ooooool007kooooo0ol0
000[ooooo`03o`000?oooooooooo02;ooooo0_l0000Fooooo`Co0000Noooool007oooooo0_l00005
ooooo`;o00009?ooool00ol0003oooooooooo`0<ooooo`;o00005?ooool2o`0001Kooooo1?l0001k
ooooo`00Ooooool2o`0000Gooooo0_l0000Tooooo`?o00003?ooool2o`000:_ooooo002<ooooo`;o
00007_ooool00ol0003oooooooooo`2iooooo`00S?ooool2o`0001kooooo00?o0000ooooooooool0
9?ooool2o`0001Gooooo0_l0001looooo`00S?ooool2o`0001kooooo00?o0000ooooooooool00_l0
000Oooooo`;o000000?oooooo`000?l000005Oooool2o`0007cooooo002<ooooo`;o00007_ooool0
0ol0003oooooooooo`02o`0000?ooooo0_l0000Jooooo`;o0000U_ooool00:cooooo00?o0000oooo
ooooool01Oooool2o`0003Cooooo0_l0001looooo`00[?ooool00ol0003oooooooooo`0:ooooo`?o
00002?ooool2o`0002Cooooo0_l0001looooo`00[?ooool00ol0003oooooooooo`0:ooooo`?o0000
2?ooool2o`000:;ooooo002Dooooo`?o00005Oooool3o`0002?ooooo0_l0000Fooooo`;o0000O?oo
ool009Cooooo0ol000000ooooooo0000o`00000Booooo`03o`000?oooooooooo027ooooo1?l0000F
ooooo`;o0000O?ooool007oooooo0_l0000Gooooo`;o00004_ooool00ol0003oooooooooo`03oooo
o`;o00007?ooool4o`0009Cooooo001oooooo`;o0000:oooool00ol0003oooooooooo`03ooooo`?o
00003_ooool2o`0000cooooo0ol0002Dooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o0000
1Oooool2o`0000Oooooo0_l0000Tooooo`;o0000OOooool00:cooooo00?o0000ooooooooool02ooo
ool2o`0002gooooo0_l0001mooooo`00[?ooool00ol0003oooooooooo`2iooooo`00S?ooool2o`00
00Cooooo0_l00005ooooo`;o00004Oooool00ol0003oooooooooo`0Dooooo`;o00008Oooool2o`00
083ooooo002<ooooo`;o00001?ooool2o`0000Gooooo0_l0000Aooooo`?o00005?ooool2o`00027o
oooo0_l00020ooooo`00Ooooool2o`0002_ooooo00?o0000ooooooooool0^Oooool007oooooo0_l0
000Nooooo`;o00002oooool00ol0003oooooooooo`0Dooooo`;o0000Xoooool0083ooooo0_l0000M
ooooo`;o00002oooool00ol0003oooooooooo`0Dooooo`;o0000Xoooool0083ooooo0_l0000Zoooo
o`03o`000?oooooooooo03[ooooo0_l0001mooooo`00P?ooool2o`0002[ooooo00?o0000oooooooo
ool08Oooool2o`0001?ooooo1_l0000Mooooo`;o0000G_ooool0083ooooo0_l00005ooooo`;o0000
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo017ooooo0_l0000>ooooo`;o00004oooool4o`00
01oooooo0_l0001Nooooo`00Qoooool2o`000005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool04Oooool2o`0002Cooooo0_l00020ooooo`00ROooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000=Oooool2
o`0008;ooooo0029ooooo`05o`000?ooooooooooooooool000001Oooool2o`0000Kooooo00?oV9RH
ob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo027ooooo0_l0000B
ooooo`;o0000P_ooool008Wooooo00Go0000ooooooooooooooooo`000004ooooo`?o00001oooool0
0omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`0Qooooo`;o0000U_ooool008Wooooo00Go410@oooooooooooooooooa0@4004ooooo`;o00002Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0^Ooo
ool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo0_l0002`ooooo`00POoo
ool2o`0000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`01?ooool4o`0000Kooooo00?o0000ooooooooool01oooool2o`0004oooooo0_l0001Oooooo`00
POooool2o`0002Wooooo00?o0000ooooooooool0>?ooool2o`0001kooooo0_l0001Oooooo`00[?oo
ool00ol0003oooooooooo`0hooooo`;o0000Ooooool0083ooooo0_l00006ooooo`;o00003Oooool2
o`0000Cooooo0_l0000=ooooo`03o`000?oooooooooo03Cooooo0_l00023ooooo`00P?ooool2o`00
00Kooooo0_l00009ooooo`;o00000_ooool2o`0000Cooooo0_l0000=ooooo`?o0000=?ooool2o`00
08?ooooo002Cooooo`;o00005oooool3o`000;Wooooo0028ooooo`;o00008_ooool00ol0003ooooo
ooooo`2iooooo`00R?ooool2o`0000oooooo0_l0000;ooooo`;o00001?ooool2o`0000Oooooo0_l0
000^ooooo`;o00007_ooool2o`00067ooooo002Iooooo`;o00002oooool2o`0000Cooooo0_l00007
ooooo`;o00002?ooool2o`0002Cooooo0_l0000Nooooo`;o0000HOooool00:cooooo00?o0000oooo
ooooool04?ooool2o`0000gooooo0_l0002Hooooo`00[?ooool2o`00023ooooo0_l0002Hooooo`00
[?ooool2o`0001kooooo0_l0000Eooooo`;o0000Poooool008Wooooo0_l0000@ooooo`;o00003ooo
ool3o`0001_ooooo1?l0000Eooooo`?o0000P_ooool008Wooooo0_l0000@ooooo`;o00003oooool0
0ol0003oooooooooo`0Kooooo`Co00005_ooool2o`0001kooooo0_l0001Rooooo`00[?ooool00ol0
003oooooooooo`0Mooooo`;o0000=_ooool2o`0006;ooooo002@ooooo`;o00001?ooool2o`0001Co
oooo00?o0000ooooooooool0^Oooool0093ooooo0_l00004ooooo`;o00004_ooool3o`0000kooooo
0_l0000<ooooo`;o0000WOooool008[ooooo0_l0000Nooooo`?o00003_ooool2o`0000cooooo0_l0
002Mooooo`00R_ooool2o`00017ooooo0_l0000=ooooo`03o`000?oooooooooo033ooooo0_l00027
ooooo`00WOooool2o`0000gooooo00?o0000ooooooooool02oooool2o`0002?ooooo0_l00027oooo
o`00[?ooool5o`0000Oooooo1?l0000<ooooo`;o0000W_ooool00:cooooo00?o0000ooooooooool0
0_l00007ooooo`?o00003Oooool2o`0001?ooooo0_l00029ooooo`00YOooool2o`0000Gooooo00?o
0000ooooooooool02_ooool2o`0002;ooooo0_l00029ooooo`00Uoooool2o`0000Wooooo0_l00000
0ooooooo0000o`000005ooooo`03o`000?oooooooooo01[ooooo0_l0002Mooooo`00Uoooool2o`00
00Wooooo0_l000000ooooooo0000o`000005ooooo`03o`000?oooooooooo01[ooooo0_l0000Foooo
o`;o0000QOooool00:?ooooo0_l00007ooooo`03o`000?oooooooooo03;ooooo0_l00025ooooo`00
Xoooool2o`0000Oooooo0_l0002jooooo`00[?ooool2o`000;[ooooo0023ooooo`;o00009oooool3
o`0002cooooo0_l0002;ooooo`00Poooool2o`0002Oooooo00?o0000ooooooooool02?ooool2o`00
02;ooooo0_l0000Rooooo`;o0000Ioooool008?ooooo0_l0000Wooooo`03o`000?oooooooooo00So
oooo0_l00016ooooo`;o0000Ioooool008?ooooo0_l0000Wooooo`03o`000?oooooooooo00Gooooo
0_l0000Sooooo`;o0000SOooool009_ooooo0ol0000<ooooo`?o00001oooool2o`0000kooooo0_l0
000Cooooo`Co000000?oooooo`000?l00000R?ooool009?ooooo0_l00006ooooo`?o00003?ooool3
o`0001Gooooo1?l0000Eooooo`;o000000?oooooo`000?l00000R?ooool0097ooooo00Gok^k^oc8b
<_l0003o0000onk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool01Oooool2o`0000cooooo0ol0002Sooooo`00TOooool00omgMgOoV9RHooooo`02
o`0000Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool01Oooool2
o`0000gooooo0_l0000Gooooo`;o0000R_ooool0097ooooo00?o410@ooooooooool00_l0000@oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05?ooool2o`0001?ooooo0_l00002oooo
o`;o0000R_ooool008Cooooo0_l0000;ooooo`05o`000?ooooooooooooooool000003oooool00omg
MgOo<S8booooo`04ooooo`?o0000:Oooool3o`0008gooooo0024ooooo`;o00002oooool01Ol0003o
oooooooooooooooo000000cooooo0ol000000olb<S;oc<c<ooooo`04ooooo`03o`000?oooooooooo
02Sooooo1Ol0002<ooooo`00TOooool01Ol@413ooooooooooooooooo410@00cooooo0_l00008oooo
o`03o`000?oooooooooo02Sooooo0_l000000ooooooo0000o`00000Oooooo`;o0000Joooool0097o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool09_ooool2o`0002Cooooo0_l0001[ooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo1?l00006ooooo`03o`000?oooooooooo02Kooooo0_l0002Aooooo`00S_ooool2o`0001co
oooo00?o0000ooooooooool0^Oooool008kooooo0_l00006ooooo`?o00004oooool00ol0003ooooo
ooooo`0>ooooo`Co0000Yoooool008Gooooo0_l0000?ooooo`?o00004oooool01?l0003ooooooooo
ooooool2o`0000_ooooo1?l0002Wooooo`00QOooool2o`0002Gooooo0ol000000ooooooo0000o`00
000=ooooo`;o0000Yoooool00:cooooo00?o0000ooooooooool0^Oooool008Gooooo0_l0000Uoooo
o`03o`000?oooooooooo0;Wooooo0025ooooo`Co00008oooool00ol0003oooooooooo`2iooooo`00
Qoooool2o`0000Kooooo0ol0000Jooooo`03o`000?oooooooooo00cooooo0_l0000Dooooo`;o0000
UOooool008oooooo0ol0000Jooooo`03o`000?oooooooooo00cooooo0_l0000Dooooo`;o0000UOoo
ool00:[ooooo1?l0000Uooooo`;o0000Toooool00:[ooooo1?l0000Uooooo`;o0000Toooool009[o
oooo0_l0000@ooooo`?o00008_ooool2o`0009Gooooo002Jooooo`;o00003Oooool2o`000003oooo
ool0003ooooo02?ooooo0_l0002Eooooo`00W?ooool2o`0000[ooooo1Ol0000<ooooo`?o0000[?oo
ool009cooooo0_l0000:ooooo`Go00003?ooool3o`000:cooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002Sooooo`;o00001oooool00ol0003oooooooooo`2iooooo`00Xoooool2o`0000Oooooo
00?o0000ooooooooool02Oooool2o`000:kooooo002Cooooo`;o00002oooool2o`0000;ooooo0_l0
0006ooooo`03o`000?oooooooooo00Wooooo0_l0000Dooooo`;o0000V?ooool009?ooooo0_l0000;
ooooo`;o00000_ooool2o`0000Kooooo0ol0000Oooooo`;o0000V?ooool00:cooooo00?o0000oooo
ooooool01_ooool2o`0001Cooooo0_l0002Kooooo`00Toooool2o`0001Oooooo00?o0000oooooooo
ool01_ooool2o`0001Cooooo0_l0002Kooooo`00R_ooool2o`0000Oooooo0_l0000Gooooo`03o`00
0?oooooooooo01_ooooo0_l0002Looooo`00R_ooool2o`00023ooooo00?o0000ooooooooool06ooo
ool2o`0009cooooo002/ooooo`03o`000?oooooooooo00;ooooo0_l0002eooooo`00[?ooool00ol0
003oooooooooo`02ooooo`;o0000]Oooool008Wooooo0_l0000Qooooo`03o`000?oooooooooo0;Wo
oooo0029ooooo`;o00008Oooool00ol0003oooooooooo`02ooooo`;o00005_ooool2o`0009gooooo
002/ooooo`?o00000_ooool2o`0001Kooooo0_l0002Mooooo`00[?ooool00ol0003oooooooooo`0H
ooooo`?o0000W_ooool00:cooooo00?o0000ooooooooool06?ooool3o`0009kooooo002;ooooo`;o
00007oooool3o`0001Cooooo0_l0002Sooooo`00Roooool2o`0000[ooooo0_l0000Cooooo`?o0000
5?ooool2o`000:?ooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@;ooooo
0_l00002ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0;Wooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Ko
oooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;Wo
oooo0029ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo0000o`000008ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool05?ooool2o`000:?ooooo0029ooooo`05o`00
0?ooooooooooooooool000003_ooool3o`0000Kooooo00?oMgMgoc8b<_ooool01?ooool3o`0001Co
oooo0_l0002Sooooo`00ROooool01?l0003oooooooooooooool2o`0000gooooo00?oEEEEo`000?l0
00000oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool04_ooool2o`00
0:Gooooo0029ooooo`04oa0@4?ooooooooooooooo`;o00003Oooool01?nYZJWoMgMgo`000?l00002
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool2o`000:Gooooo0029oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00;o00000_oo
ool01?l0003oooooo`000?l00006ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo00kooooo0_l0002Yooooo`00[?ooool00ol0003oooooooooo`0>
ooooo`;o0000ZOooool008oooooo0_l0000Kooooo`03o`000?oooooooooo013ooooo0_l0002Woooo
o`00Soooool2o`0001_ooooo0ol0000@ooooo`;o0000Yoooool008kooooo0_l0000Looooo`03o`00
0?oooooooooo0;Wooooo002>ooooo`;o00007?ooool00ol0003oooooooooo`2iooooo`00Soooool2
o`0001_ooooo00?o0000ooooooooool02_ooool2o`000:gooooo002?ooooo`;o00006oooool00ol0
003oooooooooo`0:ooooo`;o0000[Oooool00:cooooo00?o0000ooooooooool02oooool2o`000:co
oooo002/ooooo`03o`000?oooooooooo00_ooooo0_l0002/ooooo`00TOooool2o`0001Wooooo00?o
0000ooooooooool02Oooool2o`000:kooooo002Aooooo`;o00006Oooool3o`0000Wooooo0_l0002^
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`06ooooo`Co
0000[oooool00:cooooo00?o0000ooooooooool01_ooool4o`000:oooooo002Cooooo`;o00005ooo
ool00ol0003oooooooooo`2iooooo`00Toooool2o`0001Oooooo00?o0000ooooooooool0^Oooool0
09?ooooo0_l0000Gooooo`03o`000?oooooooooo00Gooooo0_l0002booooo`00[?ooool00ol0003o
ooooooooo`05ooooo`;o0000/_ooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0
002iooooo`00[?ooool5o`000;Oooooo002/ooooo`Go0000]oooool009Sooooo0_l0000@ooooo`?o
000000Coooooo`000?l0003o0000]oooool009Sooooo1?l0000>ooooo`?o0000^oooool009Sooooo
1?l0000@ooooo`03o`000?oooooooooo0;Wooooo002Hooooo`;o00001oooool2o`0000Wooooo00?o
0000ooooooooool0^Oooool00:7ooooo0_l00009ooooo`03o`000?oooooooooo0;Wooooo002Joooo
o`;o00001Oooool2o`0000Sooooo1?l0002iooooo`00V_ooool2o`0000Gooooo0_l00008ooooo`;o
0000^oooool00:cooooo00?o0000ooooooooool0^Oooool009kooooo0_l0000<ooooo`03o`000?oo
oooooooo0;Wooooo002Nooooo`;o00001?ooool2o`0000Kooooo00?o0000ooooooooool0^Oooool0
0:Cooooo0_l00006ooooo`03o`000?oooooooooo0;Wooooo002Rooooo`Co000000?o410@oooooooo
ool00oooool00ol0003oooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;Wooooo002Tooooo`03o`000?oooooooooo00Gooooo0ol0002iooooo`00Y?ooool0
0ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003o
ooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00X_ooool00omEEEGoIVIVo`00
0033ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Z_oo
ool01?l@413o0000o`000?l0002jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool0
0ol0003oooooooooo`2jooooo`00Zoooool01_l0003oMgMgo`000?l0003oEEEEonk^k[Oooooo002[
ooooo`06o`000?mEEEGok^k^oooooomgMgOoEEEE]oooool00:_ooooo00?o0000onk^k_ooool00_oo
ool00ol0003oooooooooo`2eooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooo
oooo0;Gooooo002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoIVIV]oooool00:[ooooo00?o410@
o`000?mgMgL00_l000000omVIVKok^k^ooooo`2fooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.51937 .85554 Mdot
.4195 .82745 Mdot
.47018 .6344 Mdot
.54991 .53917 Mdot
.57924 .59383 Mdot
.6191 .62685 Mdot
.48185 .67076 Mdot
.61733 .83557 Mdot
.64636 .75407 Mdot
.41689 .59793 Mdot
.44282 .25388 Mdot
.54679 .92769 Mdot
.39786 .24873 Mdot
.41177 .45968 Mdot
.47316 .98677 Mdot
.51892 .69625 Mdot
.54113 .2328 Mdot
.4021 .22321 Mdot
.56301 .37055 Mdot
.63486 .26427 Mdot
.44087 .10496 Mdot
.38263 .48425 Mdot
.40368 .23933 Mdot
.42313 .14062 Mdot
.41115 .90327 Mdot
.46776 .83496 Mdot
.50059 .23756 Mdot
.56447 .38591 Mdot
.65531 .31149 Mdot
.39842 .72339 Mdot
.50561 .10025 Mdot
.66069 .72936 Mdot
.6108 .83477 Mdot
.59648 .36148 Mdot
.61691 .415 Mdot
.63206 .28385 Mdot
.69775 .53607 Mdot
.54821 .33882 Mdot
.6778 .39828 Mdot
.55305 .92477 Mdot
.44617 .98145 Mdot
.60661 .38179 Mdot
.62719 .53667 Mdot
.53204 .84417 Mdot
.56758 .78008 Mdot
.54878 .71219 Mdot
.42011 .3665 Mdot
.68931 .64768 Mdot
.39786 .4741 Mdot
.66261 .345 Mdot
.68604 .65367 Mdot
.68745 .41657 Mdot
.73768 .28969 Mdot
.62492 .50064 Mdot
.6278 .4714 Mdot
.62667 .79917 Mdot
.60213 .8565 Mdot
.52755 .20646 Mdot
.69681 .59458 Mdot
.57752 .75985 Mdot
.52962 .75332 Mdot
.37545 .24628 Mdot
.68113 .42367 Mdot
.45056 .2876 Mdot
.57142 .88148 Mdot
.65145 .75393 Mdot
.41725 .59609 Mdot
.51413 .70188 Mdot
.5411 .3132 Mdot
.457 .07964 Mdot
.52192 .18907 Mdot
.43448 .54672 Mdot
.4133 .50358 Mdot
.44063 .72533 Mdot
.68109 .42388 Mdot
.44642 .42835 Mdot
.73803 .29059 Mdot
.46268 .82032 Mdot
.68115 .38906 Mdot
.40961 .33495 Mdot
.57265 .18576 Mdot
.3972 .71162 Mdot
.54929 .51745 Mdot
.60789 .38149 Mdot
.63656 .79836 Mdot
.53131 .66941 Mdot
.57759 .60515 Mdot
.54804 .69948 Mdot
.49367 .15486 Mdot
.50755 .71746 Mdot
.39935 .85927 Mdot
.62532 .12379 Mdot
.49612 .27311 Mdot
.55725 .68501 Mdot
.48668 .2631 Mdot
.59046 .07994 Mdot
.41151 .47777 Mdot
.67055 .69059 Mdot
.74331 .29971 Mdot
.47973 .1425 Mdot
.49119 .89239 Mdot
.44976 .16454 Mdot
.52841 .94591 Mdot
.50515 .88198 Mdot
.52228 .11229 Mdot
.60173 .3775 Mdot
.54863 .23596 Mdot
.57262 .40476 Mdot
.49677 .27398 Mdot
.47167 .07326 Mdot
.41312 .5571 Mdot
.55217 .50096 Mdot
.65935 .73011 Mdot
.61871 .24303 Mdot
.79511 .46056 Mdot
.53189 .48941 Mdot
.50278 .80194 Mdot
.6631 .74135 Mdot
.66581 .72939 Mdot
.69124 .5613 Mdot
.40259 .22373 Mdot
.36083 .49234 Mdot
.44895 .10059 Mdot
.65514 .30721 Mdot
.46605 .07411 Mdot
.54428 .58704 Mdot
.63477 .27599 Mdot
.55577 .04375 Mdot
.41473 .7963 Mdot
.50142 .67821 Mdot
.39051 .32973 Mdot
.45651 .89183 Mdot
.50907 .9707 Mdot
.62383 .61688 Mdot
.62579 .57034 Mdot
.6704 .3463 Mdot
.7012 .47494 Mdot
.64902 .30306 Mdot
.41352 .50711 Mdot
.57828 .88026 Mdot
.47839 .98846 Mdot
.53795 .38802 Mdot
.54887 .32928 Mdot
.53931 .22875 Mdot
.62529 .2494 Mdot
.64765 .77614 Mdot
.80251 .52579 Mdot
.57834 .49898 Mdot
.54269 .71542 Mdot
.37515 .75147 Mdot
.43359 .1986 Mdot
.50387 .2338 Mdot
.4197 .14937 Mdot
.43931 .59566 Mdot
.58361 .72881 Mdot
.69702 .47302 Mdot
.68314 .41881 Mdot
.65309 .75766 Mdot
.69554 .54863 Mdot
.69801 .47312 Mdot
.42247 .74685 Mdot
.67933 .37576 Mdot
.50583 .98485 Mdot
.61642 .25748 Mdot
.62111 .56856 Mdot
.47988 .8952 Mdot
.64738 .77451 Mdot
.53413 .12504 Mdot
.53719 .3048 Mdot
.69736 .44334 Mdot
.6563 .33838 Mdot
.52885 .36912 Mdot
.53026 .29358 Mdot
.56762 .63867 Mdot
.58049 .50253 Mdot
.58863 .86327 Mdot
.58169 .07107 Mdot
.58433 .72548 Mdot
.52924 .52451 Mdot
.66555 .34546 Mdot
.69133 .41174 Mdot
.52121 .96186 Mdot
.48283 .76914 Mdot
.43766 .97057 Mdot
.45944 .70884 Mdot
.64084 .76026 Mdot
.5616 .05199 Mdot
.67654 .69759 Mdot
.50853 .98062 Mdot
.62876 .54343 Mdot
.3652 .63077 Mdot
.62338 .24487 Mdot
.43433 .35261 Mdot
.3757 .25108 Mdot
.62495 .81977 Mdot
.4249 .95217 Mdot
.52225 .95462 Mdot
.56001 .6738 Mdot
.64534 .14218 Mdot
.56863 .26936 Mdot
.52551 .45068 Mdot
.52676 .46157 Mdot
.43291 .50462 Mdot
.57342 .61141 Mdot
.66394 .16723 Mdot
.46295 .89438 Mdot
.42451 .51396 Mdot
.61002 .66076 Mdot
.55187 .46195 Mdot
.45074 .69917 Mdot
.44049 .25752 Mdot
.38181 .42761 Mdot
.47391 .82491 Mdot
.53712 .12913 Mdot
.48244 .76498 Mdot
.47046 .89549 Mdot
.48199 .82119 Mdot
.4951 .99491 Mdot
.47182 .72312 Mdot
.56488 .77559 Mdot
.57482 .89776 Mdot
.51122 .7876 Mdot
.68559 .63387 Mdot
.51789 .1043 Mdot
.594 .22066 Mdot
.48484 .75839 Mdot
.58323 .54291 Mdot
.45201 .89885 Mdot
.51949 .33527 Mdot
.47301 .98721 Mdot
.36028 .50231 Mdot
.53794 .63494 Mdot
.51414 .47956 Mdot
.67945 .19517 Mdot
.43178 .21319 Mdot
.48282 .2136 Mdot
.36141 .52265 Mdot
.53816 .31129 Mdot
.49345 .89745 Mdot
.42205 .15436 Mdot
.46881 .89916 Mdot
.38003 .21485 Mdot
.62883 .57326 Mdot
.556 .15035 Mdot
.52138 .18836 Mdot
.6698 .71421 Mdot
.48702 .26663 Mdot
.69395 .49439 Mdot
.50769 .18363 Mdot
.51713 .18183 Mdot
.68112 .41561 Mdot
.425 .95063 Mdot
.53153 .48735 Mdot
.44312 .31725 Mdot
.69369 .52373 Mdot
.44119 .79783 Mdot
.52767 .28892 Mdot
.6309 .46609 Mdot
.45016 .40215 Mdot
.59603 .8613 Mdot
.69422 .62122 Mdot
.40677 .33612 Mdot
.4813 .2128 Mdot
.6011 .23103 Mdot
.52089 .60663 Mdot
.44061 .18425 Mdot
.52571 .84259 Mdot
.43264 .29509 Mdot
.61098 .63828 Mdot
.64526 .31389 Mdot
.40991 .66506 Mdot
.62989 .27136 Mdot
.62953 .47731 Mdot
.42217 .6488 Mdot
.40775 .3395 Mdot
.69668 .4602 Mdot
.48293 .77109 Mdot
.58374 .46471 Mdot
.68056 .67191 Mdot
.42693 .30767 Mdot
.59685 .69914 Mdot
.67062 .35635 Mdot
.51563 .6419 Mdot
.44534 .7333 Mdot
.69405 .55566 Mdot
.54804 .92307 Mdot
.5736 .40689 Mdot
.45381 .65486 Mdot
.57225 .59566 Mdot
.59349 .19867 Mdot
.54084 .72327 Mdot
.56287 .17331 Mdot
.56604 .05779 Mdot
.69296 .60135 Mdot
.50633 .96646 Mdot
.68542 .62602 Mdot
.51203 .57034 Mdot
.70257 .5534 Mdot
.37545 .26069 Mdot
.57165 .16651 Mdot
.48331 .9849 Mdot
.80317 .5575 Mdot
.39959 .44806 Mdot
.63424 .509 Mdot
.45881 .89565 Mdot
.66564 .72161 Mdot
.43659 .96493 Mdot
.42231 .3459 Mdot
.6768 .6788 Mdot
.43494 .78355 Mdot
.51245 .38159 Mdot
.38457 .38326 Mdot
.54751 .24271 Mdot
.40359 .22179 Mdot
.38071 .78853 Mdot
.53086 .53179 Mdot
.55108 .80067 Mdot
.60294 .3775 Mdot
.55953 .89827 Mdot
.52469 .59325 Mdot
.50901 .97454 Mdot
.36337 .54433 Mdot
.5374 .62842 Mdot
.62745 .60692 Mdot
.60736 .3746 Mdot
.68593 .44814 Mdot
.586 .52633 Mdot
.51554 .38525 Mdot
.4999 .6315 Mdot
.54227 .22644 Mdot
.59238 .87348 Mdot
.69142 .53184 Mdot
.47885 .25737 Mdot
.38155 .46972 Mdot
.50147 .68045 Mdot
.433 .48944 Mdot
.44482 .88924 Mdot
.62387 .60639 Mdot
.62127 .56872 Mdot
.42049 .73759 Mdot
.5743 .60322 Mdot
.71967 .25159 Mdot
.42254 .73644 Mdot
.39887 .71743 Mdot
.46 .27217 Mdot
.61321 .82551 Mdot
.49412 .22816 Mdot
.64638 .29925 Mdot
.38416 .52842 Mdot
.51866 .32358 Mdot
.50232 .79496 Mdot
.55974 .91318 Mdot
.70549 .53544 Mdot
.63507 .28767 Mdot
.39979 .55942 Mdot
.57316 .28423 Mdot
.65083 .32159 Mdot
.43482 .20109 Mdot
.55748 .91539 Mdot
.5609 .15665 Mdot
.50773 .9713 Mdot
.50125 .98292 Mdot
.46321 .99906 Mdot
.43869 .39987 Mdot
.41925 .26237 Mdot
.47038 .98779 Mdot
.60119 .85597 Mdot
.44185 .37831 Mdot
.53808 .13834 Mdot
.41056 .66116 Mdot
.61517 .64901 Mdot
.49917 .88352 Mdot
.66446 .70782 Mdot
.49225 .89795 Mdot
.69884 .55152 Mdot
.68998 .50293 Mdot
.4007 .25832 Mdot
.70608 .5109 Mdot
.39064 .33205 Mdot
.43267 .95492 Mdot
.79958 .47946 Mdot
.68819 .58805 Mdot
.58801 .72389 Mdot
.43842 .58052 Mdot
.37553 .72815 Mdot
.4769 .14436 Mdot
.50301 .61801 Mdot
.52408 .96047 Mdot
.46162 .07596 Mdot
.5106 .36456 Mdot
.42986 .68464 Mdot
.47891 .83166 Mdot
.496 .22635 Mdot
.68883 .65392 Mdot
.50489 .08433 Mdot
.37809 .23587 Mdot
.51663 .96729 Mdot
.5731 .29384 Mdot
.71704 .25367 Mdot
.57529 .29399 Mdot
.58046 .48711 Mdot
.58304 .49589 Mdot
.4937 .3633 Mdot
.59045 .87391 Mdot
.54804 .92567 Mdot
.49648 .23048 Mdot
.5252 .34789 Mdot
.45298 .22267 Mdot
.51513 .71359 Mdot
.393 .85064 Mdot
.56729 .65695 Mdot
.60869 .23982 Mdot
.54582 .43589 Mdot
.51166 .24924 Mdot
.51781 .62392 Mdot
.57166 .63602 Mdot
.59109 .34597 Mdot
.48538 .21091 Mdot
.42437 .48 Mdot
.36387 .62062 Mdot
.58346 .87365 Mdot
.5015 .53827 Mdot
.61974 .42717 Mdot
.54949 .23778 Mdot
.556 .78299 Mdot
.40474 .60512 Mdot
.53044 .29098 Mdot
.37964 .76444 Mdot
.59873 .08532 Mdot
.46808 .90412 Mdot
.7853 .41448 Mdot
.52782 .85247 Mdot
.4242 .45906 Mdot
.62406 .79288 Mdot
.45887 .98301 Mdot
.45862 .2252 Mdot
.38431 .48063 Mdot
.7252 .26296 Mdot
.53128 .36892 Mdot
.49882 .32968 Mdot
.57964 .5337 Mdot
.59357 .21618 Mdot
.40103 .44412 Mdot
.63659 .13412 Mdot
.45185 .69743 Mdot
.62216 .47474 Mdot
.60104 .35696 Mdot
.46307 .26365 Mdot
.52892 .54549 Mdot
.463 .76885 Mdot
.61384 .84026 Mdot
.53121 .54446 Mdot
.67577 .36716 Mdot
.44014 .87848 Mdot
.55649 .79583 Mdot
.6311 .27056 Mdot
.55039 .15721 Mdot
.55878 .26275 Mdot
.53472 .0186 Mdot
.42696 .67088 Mdot
.59028 .87687 Mdot
.43312 .9677 Mdot
.43834 .27521 Mdot
.70401 .54581 Mdot
.4066 .63135 Mdot
.53916 .23417 Mdot
.64357 .29204 Mdot
.49643 .88824 Mdot
.56923 .3969 Mdot
.50339 .79379 Mdot
.59274 .34612 Mdot
.36378 .36525 Mdot
.62088 .58891 Mdot
.44249 .47424 Mdot
.62478 .53913 Mdot
.40755 .34897 Mdot
.43402 .44354 Mdot
.52554 .66706 Mdot
.62485 .48823 Mdot
.62964 .54461 Mdot
.5291 .4692 Mdot
.44681 .80667 Mdot
.64958 .75779 Mdot
.58334 .57149 Mdot
.53451 .82762 Mdot
.53347 .28757 Mdot
.56919 .41914 Mdot
.45776 .3213 Mdot
.79331 .43814 Mdot
.46748 .30834 Mdot
.43161 .8628 Mdot
.67584 .66022 Mdot
.61645 .2554 Mdot
.54663 .32699 Mdot
.65616 .32021 Mdot
.53058 .94972 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00Sooooo0_l0002_ooooo`00
[?ooool00ol0003oooooooooo`08ooooo`;o0000[oooool00:cooooo0ol0002iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`0?ooooo`;o0000Z?ooool00:cooooo00?o0000oooo
ooooool03oooool2o`000:Sooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000
4Oooool2o`000:Kooooo002/ooooo`03o`000?oooooooooo017ooooo0_l0002Vooooo`00[?ooool0
0ol0003oooooooooo`0Booooo`;o0000YOooool00:cooooo00?o0000ooooooooool04_ooool2o`00
0:Gooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo01Sooooo0_l0002Oooooo`00X?ooool4o`0000Sooooo00?o0000
ooooooooool06?ooool2o`0009oooooo002Oooooo`Go00002?ooool3o`000;Wooooo002Mooooo`Co
00002oooool00ol0003oooooooooo`0Jooooo`;o0000WOooool009gooooo0_l0000=ooooo`03o`00
0?oooooooooo01[ooooo0_l0002Mooooo`00[?ooool3o`0001gooooo0_l0002Jooooo`00[?ooool3
o`0001gooooo0_l0002Jooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00Voooool2o`0000oooooo0ol0
002iooooo`00Voooool2o`0000oooooo0ol00002ooooo`;o0000]Oooool009Sooooo0_l0000Boooo
o`03o`000?oooooooooo00;ooooo0_l0002eooooo`00V?ooool2o`0001;ooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool01?ooool2o`000;?ooooo002/ooooo`03o`000?oo
oooooooo00Cooooo0_l0002cooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`00
0?oooooooooo0;Wooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo
00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;Wooooo
0021ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool0
2?ooool00ol0003oooooooooo`03ooooo`?o00002?ooool2o`0001cooooo0_l0002Aooooo`00ROoo
ool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo00Sooooo0_l0000Looooo`;o0000TOooool008Wooooo00Go
0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo00Wooooo0_l0002^ooooo`00ROooool01Ol@413ooooo
oooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Wooooo0_l0000Oooooo`;o0000SOooool008Wooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo02[ooooo0_l0002=ooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Cooooo0_l00005ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool02Oooool2o`00
0:kooooo002Booooo`;o00004Oooool2o`0000Gooooo00?o0000ooooooooool02Oooool2o`0002;o
oooo0_l0002:ooooo`00Y?ooool3o`0000Gooooo00?o0000ooooooooool0;Oooool2o`0008[ooooo
002Aooooo`;o00004Oooool2o`0000Kooooo00?o0000ooooooooool0^Oooool0097ooooo0_l0000I
ooooo`?o00003oooool2o`000:Sooooo002Booooo`;o00005Oooool2o`000003ooooool0003ooooo
013ooooo0_l0002Xooooo`00T_ooool2o`0001Gooooo0_l000000ooooooo0000ooooo`0>ooooo`;o
00000_ooool2o`000:Kooooo002/ooooo`03o`000?oooooooooo00gooooo0_l00002ooooo`;o0000
Y_ooool009_ooooo0_l0000?ooooo`03o`000?oooooooooo0;Wooooo002Kooooo`;o00003oooool0
0ol0003oooooooooo`0Dooooo`;o00007Oooool2o`0008Cooooo002/ooooo`03o`000?oooooooooo
01Cooooo0_l0000Mooooo`;o0000Q?ooool00:cooooo00?o0000ooooooooool04Oooool2o`000:Ko
oooo002/ooooo`?o00004Oooool2o`000:Kooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`03o`000?oooooooooo00;ooooo0_l0002eooooo`00V?ooool2o`0001;ooooo00Go0000oooo
ool0003o0000ooooo`02o`00017ooooo0_l0002Rooooo`00V?ooool2o`0001;ooooo00Co0000oooo
ool0003o00000oooool2o`0000oooooo0_l0002Rooooo`00[?ooool00ol0003oooooooooo`04oooo
o`;o0000/oooool00:cooooo00?o0000ooooooooool0>?ooool2o`0007oooooo002Fooooo`;o0000
5?ooool00ol0003oooooooooo`0hooooo`;o0000Ooooool009Kooooo0_l0000Dooooo`?o00006ooo
ool2o`0009cooooo002Fooooo`;o00005?ooool00ol0003oooooooooo`0Kooooo`;o0000W?ooool0
0:cooooo00?o0000ooooooooool01_ooool2o`000;7ooooo002/ooooo`03o`000?oooooooooo00Ko
oooo0_l0002aooooo`00UOooool2o`0000kooooo1?l00003ooooo`03o`000?oooooooooo0;Wooooo
0024ooooo`;o00003oooool2o`0000kooooo1?l00003ooooo`03o`000?oooooooooo01_ooooo0_l0
002Looooo`00Q?ooool2o`0002Kooooo00?o0000ooooooooool06oooool2o`0009cooooo002<oooo
o`;o00003_ooool2o`0000kooooo00?o0000ooooooooool07?ooool2o`0009_ooooo002;ooooo`?o
00003_ooool4o`0000cooooo0ol0000Looooo`;o0000Voooool008_ooooo0_l0000Aooooo`;o0000
2_ooool3o`0000cooooo0ol0002/ooooo`00Z_ooool3o`0000cooooo0ol0000Aooooo`;o0000VOoo
ool00:[ooooo1Ol00009ooooo`?o00004_ooool2o`0009Wooooo0023ooooo`;o00009oooool3o`00
00Wooooo0ol000000ooooooo0000o`00002Zooooo`00Poooool2o`0000Oooooo0_l0000Nooooo`;o
00003_ooool2o`00017ooooo0_l0002Gooooo`00S?ooool2o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool03?ooool2o`0001;ooooo0_l00002ooooo`;o0000Toooool008;ooooo0_l0000=ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`0<ooooo`;o00005_ooool3o`0009;ooooo0022ooooo`;o00001Oooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_l0000Sooooo`?o0000TOooool008?ooooo0_l00005ooooo`;o00001Oooool01Ol0003o
oooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool5o`0002Cooooo0_l0000Moooo
o`;o0000L_ooool008?ooooo0_l0000<ooooo`05o`000?ooooooooooooooool000000oooool2o`00
00Oooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo02?ooooo0_l0000O
ooooo`?o0000L_ooool008_ooooo0_l00004ooooo`05oa0@4?ooooooooooooooool@41000_ooool3
o`0000Oooooo00?o0000ooooooooool00_l00005ooooo`03o`000?oooooooooo02?ooooo0_l0000O
ooooo`;o0000Loooool008;ooooo0_l00007ooooo`;o00001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00;ooooo0_l00008ooooo`03o`000?oooooooooo00;o00001Oooool00ol0003oooooooooo`0S
ooooo`;o0000U?ooool008;ooooo0_l0000=ooooo`?o000000?o<S8bonk^k_ooool02?ooool2o`00
0003ooooool0003o000000;o000000?oooooo`000?l000000oooool00ol0003oooooooooo`0@oooo
o`;o00005oooool2o`0001cooooo0_l0001`ooooo`00TOooool2o`0000cooooo0_l00006ooooo`;o
00000oooool00ol0003oooooooooo`0@ooooo`;o00005oooool2o`0001cooooo0_l0001`ooooo`00
Yoooool2o`0000?ooooo00?o0000ooooooooool04oooool2o`0001?ooooo0_l0002?ooooo`00W_oo
ool2o`0000[ooooo0ol0000Eooooo`;o00004_ooool3o`0008oooooo002Gooooo`;o00001Oooool2
o`0000[ooooo1Ol0000Wooooo`Co0000S_ooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo
02Wooooo0_l0002>ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooo
ooooo`0Eooooo`;o00004Oooool2o`0008oooooo002Kooooo`;o00003oooool00ol0003ooooooooo
o`06ooooo`Co00002oooool2o`00017ooooo0ol0002>ooooo`00Voooool2o`0000oooooo00?o0000
ooooooooool01_ooool4o`0001oooooo0_l000000ooooooo0000o`00000Mooooo`;o0000K?ooool0
09Gooooo0_l0000Eooooo`03o`000?oooooooooo00Oooooo0_l0000<ooooo`;o00005Oooool2o`00
01gooooo0_l0001/ooooo`00UOooool2o`0001Gooooo00?o0000ooooooooool01oooool2o`0000co
oooo0_l0002Rooooo`00[?ooool3o`0002gooooo0_l0000Nooooo`;o0000J_ooool00:cooooo00?o
0000ooooooooool0;Oooool3o`0001gooooo0_l0001Zooooo`00[?ooool00ol0003oooooooooo`09
ooooo`;o00008oooool4o`0008Oooooo002Cooooo`;o00003?ooool2o`0000Wooooo00?o0000oooo
ooooool02Oooool2o`0002Gooooo0_l00027ooooo`00Toooool2o`0000cooooo0_l00009ooooo`03
o`000?oooooooooo00Wooooo0ol0000Tooooo`;o0000Qoooool00:cooooo00?o0000ooooooooool0
2Oooool3o`00027ooooo0_l000000ooooooo0000o`000027ooooo`00VOooool2o`00017ooooo00?o
0000ooooooooool0;Oooool2o`0008[ooooo002Iooooo`;o00000oooool2o`0000cooooo00?o0000
ooooooooool0;_ooool4o`0008Oooooo002Nooooo`;o00003?ooool3o`0000?ooooo0_l0000Yoooo
o`Co0000Qoooool00:cooooo00?o0000ooooooooool00oooool2o`0000Oooooo0_l0002[ooooo`00
Qoooool2o`0002;ooooo0_l0000>ooooo`?o0000Z_ooool008Oooooo0_l0000Rooooo`;o00003ooo
ool2o`000:[ooooo0027ooooo`;o00001?ooool3o`0001cooooo00?o0000ooooooooool00oooool2
o`000;Cooooo002=ooooo`?o00007?ooool00ol0003oooooooooo`03ooooo`;o00001oooool2o`00
02;ooooo0_l00027ooooo`00SOooool2o`0001gooooo00?o0000ooooooooool03?ooool2o`0002;o
oooo0_l00027ooooo`00T_ooool2o`0001Sooooo00?o0000ooooooooool06oooool2o`0001Gooooo
1Ol00022ooooo`00SOooool2o`0000?ooooo0_l0000Hooooo`03o`000?oooooooooo00Gooooo0_l0
000Dooooo`;o00005Oooool5o`0008;ooooo002=ooooo`;o00001oooool2o`0001Cooooo0ol00005
ooooo`;o0000/_ooool009Kooooo0_l0000Dooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03
o`000?oooooooooo01kooooo0_l0000Eooooo`;o0000P_ooool00:cooooo00?o0000ooooooooool0
7?ooool4o`0001Gooooo0_l00022ooooo`00ZOooool2o`000004ooooool0003oooooooooo`;o0000
6_ooool2o`0009_ooooo001oooooo`;o00002?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
0_l00002ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool2o`000004
ooooool0003oooooooooo`;o0000=Oooool2o`00083ooooo001oooooo`;o00002?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo0_l00002ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool01_ooool3o`0000Sooooo0_l0000T
ooooo`;o0000P?ooool0087ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool3
o`0000Sooooo0_l0002Vooooo`00ROooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o00008?ooool2o`0001Kooooo0_l0001o
ooooo`00ROooool01Ol0003ooooooooooooooooo000000[ooooo0_l00002ooooo`03ogMgMomVIVKo
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo01kooooo1?l0
000Fooooo`;o0000Ooooool008Gooooo0_l00002ooooo`05oa0@4?ooooooooooooooool@41002_oo
ool2o`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`04o`000?oo
ooooooooooooo`;o00006oooool4o`0009Oooooo0025ooooo`;o00000_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oo
oooo00Co0000oooooooooooooooo0ol0000>ooooo`;o00003?ooool2o`0009Oooooo0029ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006
ooooo`03o`000?oooooooooo00;ooooo0_l00005ooooo`;o00001oooool2o`0002Cooooo0_l0001o
ooooo`00[?ooool00ol0003oooooooooo`09ooooo`;o0000;Oooool2o`0007oooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo01?ooooo0_l0000Rooooo`;o0000
P?ooool009Oooooo0_l0000Cooooo`?o00004oooool2o`0002;ooooo0_l00020ooooo`00Uoooool2
o`0000;ooooo0_l0000?ooooo`03o`000?oooooooooo0;Wooooo002Kooooo`;o00003oooool00ol0
003oooooooooo`0Eooooo`;o0000X_ooool00:cooooo00?o0000ooooooooool05Oooool2o`000:;o
oooo002/ooooo`03o`000?oooooooooo03cooooo0_l0001kooooo`00[?ooool00ol0003ooooooooo
o`0Sooooo`;o00004oooool6o`0001gooooo0_l0001Looooo`00[?ooool00ol0003oooooooooo`0C
ooooo`;o00003_ooool2o`0001?ooooo1?l0000Oooooo`;o0000G?ooool00:cooooo00?o0000oooo
ooooool04oooool2o`0002Cooooo0_l0001nooooo`00[?ooool3o`0003Sooooo0_l0001oooooo`00
QOooool2o`0001?ooooo0_l0000@ooooo`03o`000?oooooooooo02Cooooo0_l0000Booooo`;o0000
Ooooool008Gooooo0_l0000Cooooo`;o00004?ooool00ol0003oooooooooo`0Tooooo`;o0000Tooo
ool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool03?ooool2o`00
0:_ooooo002/ooooo`03o`000?oooooooooo00cooooo0_l0001?ooooo`;o0000F_ooool009Kooooo
0_l0000Dooooo`03o`000?oooooooooo03kooooo0_l0000Mooooo`;o0000F_ooool008_ooooo0_l0
0009ooooo`;o00005?ooool00ol0003oooooooooo`0nooooo`;o0000NOooool008[ooooo0ol0000O
ooooo`03o`000?oooooooooo03[ooooo0_l0001mooooo`00R_ooool2o`00023ooooo0ol00005oooo
o`;o0000<oooool2o`0007gooooo002/ooooo`03o`000?oooooooooo00Gooooo0_l0002booooo`00
Toooool2o`0001Oooooo00?o0000ooooooooool0^Oooool000Wooooo1?l000000ol@413ooooooooo
o`0Fooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool0
1?ooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`000005ooooool0003o0000oooooom4A4@00ol000000ooMgMgooooo
ooooo`0Dooooo`03o`000?oooooooooo00Gooooo0_l00007ooooo`;o00002?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Oooooo0_l00006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@03ooooo`;o00002_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`Co
000000?o410@ooooooooool04_ooool000_ooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_oo
ool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01_nHV9So8B4Qonk^k_oo
ooooA4A4ooooo`;o00001?ooool00omgMgOo<S8booooo`0Eooooo`03o`000?oooooooooo00Gooooo
0_l00007ooooo`;o00002?ooool2o`000003oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`06ooooo`;o00001_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00;ooooo0_l0000:oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool0
0omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo0006o`0000Gooooo00?o0000oooo
ooooool04?ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGo
oooo00Sooooo00?o0000ooooooooool01Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
6?ooool2o`0000;ooooo00?o410@ooooooooool02Oooool2o`000003ob4Q8Oo^k^kooooo00Sooooo
00?o0000ooooooooool03Oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooooooo
ool03Oooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01So
oooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b
<_ooool03_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool03_ooool0
1Ol0003ooooooooooooooooo000000Oooooo0_l00004ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o
MgMgoc8b<_ooool05Oooool00ol0003oooooooooo`06ooooo`;o00004?ooool01Ol0003ooooooooo
oooooooo000000_ooooo0_l000000onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00kooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool06Oooool00ol0
003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`00
0?ooooooooooooooool000001oooool2o`0000Cooooo0_l000000omVIVKoooooooooo`02ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`00oooool2o`00017ooooo00?o0000ooooooooool01_ooool2o`00
013ooooo00Go0000ooooooooooooooooo`00000:ooooo`;o00000_ooool00omgMgOoIVIVooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`02?ooool2o`0000Gooooo00Go0000oooooooooooooooo
o`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo0000
00kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[ooooo00?o0000
ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol@413ooooooooooooooooo
410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`0Aooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@4100
3Oooool3o`0000Cooooo00?o0000ooooooooool01Oooool2o`00017ooooo0ol0000Hooooo`05oa0@
4?ooooooooooooooool@41002?ooool4o`0000?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0:ooooo`?o00001?ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooo
ooooool04Oooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo
01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?oo
ool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooo
ooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01_l0003o^[ZjoooooonHV9So410@
ooooo`;o000000?oooooo`000?ooool00_l0000Gooooo`04o`000?ooooooooooooooo`;o00005Ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo1?l000001?nj^[[ooooooiRHV?l@4104ooooo`03
o`000?oooooooooo00_ooooo0_l00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0
003oooooooooo`06ooooo`;o00002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@
oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05?oo
ool000Wooooo00?oEEEEofIVI_l000006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol0
0004ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02?ooool2o`000007oooooonHV9So410@o`000?lQ8B7oc<c<ooooo`02
o`000003ooooool0003o000000;o00005oooool01?l0003oooooooooooooool2o`0001Gooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0:ooooo`;o000000Co410@o`000?lQ8B7oc<c<1?ooool4o`00013o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool2o`0000Wooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0001Wooooo00?oEEEEofIVI_l000005_ooool0
08Gooooo0_l0000Uooooo`03o`000?oooooooooo0;Wooooo0025ooooo`;o00009Oooool00ol0003o
ooooooooo`07ooooo`;o00003_ooool2o`0000gooooo0_l0002Aooooo`00O_ooool2o`0001Gooooo
0_l0000Eooooo`03o`000?oooooooooo00Oooooo0_l0000>ooooo`;o00003Oooool2o`0008Kooooo
0_l00002ooooo`;o00001Oooool007kooooo0_l0000Eooooo`;o00005Oooool00ol0003ooooooooo
o`07ooooo`;o0000=?ooool2o`0006oooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd5ooooo`00
[?ooool00ol0003oooooooooo`0Hooooo`;o00008oooool2o`00073ooooo00CogMgMo`000?l@413o
c<c<1_ooool000Ooooooool0001<o`0000cooooo00Cok^k^ob4Q8Ol@413ok^k^1_ooool000Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`04o`000?oooooo0000o`0000Co
oooo00?o0000ooooooooool01Oooool01?l0003oooooooooooooool2o`0000?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`;o00001_ooool3o`0000Gooooo00?o0000oooo
ooooool01Oooool2o`0000Oooooo00?o0000ooooooooool01Oooool01?l0003oooooooooooooool2
o`0000;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02_ooool01?lQ8B7oMgMgogMgMolb<S86ooooo`001oooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool08?ooool2
o`0000Cooooo00?o0000ooooooooool02Oooool2o`0000Cooooo0_l0000Eooooo`03o`000?oooooo
oooo01Oooooo0_l0000>ooooo`03o`000?oooooooooo017ooooo0_l0000Cooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`09ooooo`;o00000_ooool2
o`0000Gooooo002?ooooo`;o00001?ooool2o`0001Gooooo00?o0000ooooooooool0:Oooool2o`00
08kooooo002/ooooo`03o`000?oooooooooo02Wooooo0_l0000Fooooo`;o0000M_ooool009?ooooo
0_l0000Gooooo`03o`000?oooooooooo047ooooo0_l0001fooooo`00Toooool2o`0001Oooooo00?o
0000ooooooooool03Oooool2o`000:[ooooo001nooooo`;o0000;?ooool00ol0003oooooooooo`0=
ooooo`;o0000Z_ooool007kooooo0_l0000/ooooo`?o00001_ooool2o`0003Gooooo0_l0001joooo
o`00QOooool2o`0002Gooooo00?o0000ooooooooool01_ooool2o`00017ooooo0_l0000Rooooo`;o
00008Oooool2o`0005Oooooo0025ooooo`;o00009Oooool00ol0003oooooooooo`07ooooo`;o0000
4?ooool2o`0004Gooooo0_l0001Gooooo`00[?ooool00ol0003oooooooooo`07ooooo`;o00003_oo
ool2o`0002?ooooo0_l0001kooooo`00[?ooool00ol0003oooooooooo`0Gooooo`;o00003_ooool2
o`0001?ooooo1_l0001gooooo`00[?ooool2o`0000kooooo0_l0000Gooooo`?o00005Oooool4o`00
07Oooooo002/ooooo`;o00003_ooool2o`0000Wooooo0_l0000<ooooo`?o0000T?ooool007kooooo
0_l0000Fooooo`;o00005?ooool00ol0003oooooooooo`06ooooo`?o00003oooool2o`0000gooooo
0_l0000Gooooo`;o0000Moooool007kooooo0_l0000Fooooo`;o00005?ooool00ol0003ooooooooo
o`06ooooo`?o00007_ooool2o`0001Cooooo0_l000000ooooooo0000o`00001gooooo`00[?ooool3
o`0003gooooo0ol0001iooooo`00[?ooool00ol0003oooooooooo`0mooooo`Co0000N?ooool008oo
oooo0_l0000Kooooo`03o`000?oooooooooo03gooooo1?l0000Pooooo`;o0000E_ooool008[ooooo
0_l00003ooooo`;o00006oooool00ol0003oooooooooo`0looooo`;o00008oooool2o`0005Kooooo
002:ooooo`;o00008?ooool00ol0003oooooooooo`0looooo`;o0000Noooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00Co0000oooooooooooooooo0_l0000Rooooo`?o0000TOooool0
0:cooooo00Co0000oooooooooooooooo0_l0000Eooooo`;o00002oooool4o`00093ooooo002/oooo
o`?o00006?ooool2o`0000gooooo0_l0002@ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
Uoooool2o`0001?ooooo00?o0000ooooooooool0^Oooool009Oooooo0_l0000Cooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00_ooooo0_l0000Gooooo`;o00005Oooool2
o`0007cooooo002/ooooo`03o`000?oooooooooo00_ooooo0_l0000Gooooo`;o00005Oooool2o`00
07cooooo002/ooooo`03o`000?oooooooooo00Gooooo0_l0000@ooooo`;o00009Oooool2o`0007Wo
oooo002@ooooo`;o00001_ooool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`0000gooooo
0_l000000ooooooo0000o`00000Uooooo`;o0000NOooool0093ooooo0_l00006ooooo`;o00004_oo
ool3o`0001Cooooo0_l0000Vooooo`;o0000Noooool00:cooooo00?o0000ooooooooool05Oooool2
o`0002Gooooo0_l0001kooooo`00S?ooool2o`0001kooooo00?o0000ooooooooool00oooool2o`00
013ooooo0ol0000=ooooo`Co0000T?ooool008cooooo0_l0000Nooooo`03o`000?oooooooooo00?o
oooo0_l0000Aooooo`;o00003Oooool4o`00093ooooo002/ooooo`03o`000?oooooooooo01Gooooo
0_l0002Rooooo`00[?ooool00ol0003oooooooooo`0Eooooo`;o0000X_ooool008Wooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8b
omgMg@05ooooo`?o00009Oooool2o`0009;ooooo001oooooo`;o00002?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo
<S8booooo`04ooooo`?o00009Oooool2o`0001Kooooo0_l0001jooooo`00Ooooool2o`0000Sooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000oooooooo
ool00oooool3o`0000;ooooo0_l0000iooooo`;o0000N_ooool008Wooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`02ooooo`;o00001Oooool2o`0001Wooooo0_l0000Dooooo`;o0000OOooool007oooooo
0_l00008ooooo`04o`000?ooooooooooooooo`;o00003Oooool00omgMgOoIVIVooooo`03ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01Oooool2o`0000[ooooo0_l0000Iooooo`;o00005?ooool2o`00
07gooooo001oooooo`;o00002?ooool01?l@413oooooooooooooool2o`0000kooooo00?o0000oooo
ooooool00_ooool2o`0000Sooooo0_l0000kooooo`;o0000OOooool008Wooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool2o`0000Sooooo00?o0000
ooooooooool02Oooool2o`0000Wooooo0_l0000Tooooo`;o0000OOooool008Wooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o
0000ooooooooool02Oooool2o`0000Sooooo0ol0000;ooooo`;o0000U_ooool00:cooooo00?o0000
ooooooooool00_ooool2o`0000oooooo0_l0000<ooooo`;o0000U_ooool00:cooooo00?o0000oooo
ooooool00_ooool2o`000;Gooooo002Booooo`;o00006?ooool00ol0003oooooooooo`0Sooooo`;o
00005_ooool2o`0007cooooo002Booooo`;o00006?ooool3o`0002?ooooo0_l0000Fooooo`;o0000
O?ooool009cooooo0_l0000>ooooo`03o`000?oooooooooo03[ooooo0ol0001looooo`00W?ooool2
o`0000kooooo00?o0000ooooooooool04oooool2o`0002Gooooo0ol0001looooo`00S_ooool2o`00
01cooooo00?o0000ooooooooool04oooool2o`0000cooooo0_l0000Dooooo`;o0000P?ooool008ko
oooo0_l0000Looooo`03o`000?oooooooooo027ooooo0_l0000Dooooo`;o0000P?ooool008kooooo
0_l0000Looooo`03o`000?oooooooooo00Gooooo0_l0002booooo`00Toooool2o`00017ooooo0_l0
0004ooooo`03o`000?oooooooooo00Gooooo1?l0002`ooooo`00Toooool2o`00017ooooo0_l00004
ooooo`03o`000?oooooooooo00Oooooo0_l00007ooooo`;o00009_ooool2o`0007oooooo002/oooo
o`?o00004?ooool2o`0002Kooooo0_l0001oooooo`00[?ooool2o`0003Sooooo0_l00020ooooo`00
[?ooool2o`0003Sooooo0_l00020ooooo`00U?ooool2o`0001Kooooo0_l0000@ooooo`;o0000Z?oo
ool009Cooooo0_l0000Fooooo`03o`000?oooooooooo00oooooo0_l0002Xooooo`00[?ooool00ol0
003oooooooooo`0eooooo`;o0000P_ooool00:cooooo00?o0000ooooooooool0=Oooool2o`0008;o
oooo002Looooo`;o00003_ooool00ol0003oooooooooo`03ooooo`;o0000<_ooool2o`00083ooooo
002Kooooo`?o00003_ooool3o`0000?ooooo0_l00007ooooo`;o00003oooool2o`0001Sooooo0_l0
0020ooooo`00Voooool2o`0000oooooo00Co0000oooooooooooooooo0_l00009ooooo`;o00003ooo
ool2o`0009[ooooo002/ooooo`04o`000?ooooooooooooooo`;o0000]_ooool009kooooo0_l0000<
ooooo`03o`000?oooooooooo03?ooooo0_l00024ooooo`00R_ooool2o`0001;ooooo0_l0000<oooo
o`03o`000?oooooooooo00gooooo0_l0000Tooooo`;o0000Q?ooool008[ooooo0_l0000Pooooo`03
o`000?oooooooooo00;ooooo0_l00007ooooo`Co00009_ooool2o`0008;ooooo002:ooooo`;o0000
8?ooool01Ol0003oooooo`000?l0003ooooo00;o00001oooool2o`0002Sooooo0_l00022ooooo`00
R_ooool2o`00023ooooo00Co0000ooooool0003o0000<_ooool2o`0008Cooooo002:ooooo`;o0000
3?ooool2o`0000Sooooo0_l00008ooooo`?o00002_ooool2o`0000cooooo1?l0000Gooooo`;o0000
Q?ooool008;ooooo0_l00006ooooo`;o00003?ooool2o`0000Sooooo0_l00008ooooo`03o`000?oo
oooooooo00[ooooo0_l0000<ooooo`Co0000WOooool008;ooooo0_l0000Xooooo`03o`000?oooooo
oooo01Sooooo0_l0000Gooooo`Co0000Q?ooool009[ooooo0_l0000@ooooo`03o`000?oooooooooo
01Sooooo0_l0000Gooooo`Co0000Q?ooool0097ooooo0ol00006ooooo`;o00004?ooool00ol0003o
ooooooooo`2iooooo`00TOooool3o`0001Sooooo00?o0000ooooooooool0^Oooool0097ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Go
oooo00?o0000ooooooooool0<_ooool2o`0008Gooooo002Aooooo`05ogMgMol0003o0000oiRHV?mg
MgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0booooo`;o
0000QOooool0097ooooo00Go410@o`000?l0003ooooooa0@400@ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0^Oooool008;ooooo0_l0000=ooooo`05o`000?ooooooooooooooool0
00003oooool00omgMgOo<S8booooo`04ooooo`?o0000^Oooool008;ooooo0_l0000=ooooo`05o`00
0?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool01_ooool2o`0002Gooooo1?l00028ooooo`00TOooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool00_ooool2o`0000?ooooo00?o0000ooooooooool01_ooool2o`00
02Gooooo1?l00028ooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool00_ooool2o`0000?ooooo00?o0000ooooooooool05_ooool2o`0001?ooooo0_l000001?oo
oooo0000o`000?l00028ooooo`00Q?ooool2o`0000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`Ko00001?ooool00ol0003oooooooooo`0Fooooo`;o00004oooool2o`0008cooooo0024oooo
o`;o00008?ooool2o`0000Cooooo00?o0000ooooooooool0^Oooool009oooooo0_l00005ooooo`;o
00001?ooool00ol0003oooooooooo`2iooooo`00Woooool2o`0000Gooooo0_l00004ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o00004_ooool2o`0001Wooooo0_l0002:ooooo`00[?ooool0
0ol0003oooooooooo`0Booooo`?o00006?ooool2o`0008[ooooo002/ooooo`03o`000?oooooooooo
00oooooo0_l00002ooooo`;o0000Y?ooool009Kooooo0_l0000Dooooo`03o`000?oooooooooo00oo
oooo0_l0002Xooooo`00Q?ooool2o`00013ooooo0_l0000Dooooo`03o`000?oooooooooo00;o0000
]oooool008Cooooo0_l0000Vooooo`03o`000?oooooooooo00;o0000]oooool00:cooooo0ol0000V
ooooo`;o0000TOooool008oooooo0_l00007ooooo`;o00004_ooool3o`0000oooooo0_l0000Eoooo
o`;o00000_ooool2o`0008gooooo002?ooooo`;o00001oooool2o`0001;ooooo0ol0000=ooooo`Co
00005Oooool2o`0000;ooooo0_l0002=ooooo`00[?ooool2o`0000kooooo0_l0000Gooooo`;o0000
TOooool009[ooooo0_l0000@ooooo`;o0000^_ooool009[ooooo0_l0000@ooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002Oooooo`;o00001Oooool2o`0000Cooooo00?o
0000ooooooooool09_ooool2o`00097ooooo002Oooooo`;o00000_ooool2o`000003ooooool0003o
000000Cooooo0ol0000Rooooo`;o00000_ooool2o`00097ooooo002Aooooo`;o00004?ooool2o`00
00Oooooo00?o0000ooooooooool02?ooool2o`0001Sooooo0_l0002Eooooo`00TOooool2o`0001;o
oooo0_l00005ooooo`03o`000?oooooooooo00Sooooo0_l0002_ooooo`00YOooool2o`0000Gooooo
00?o0000ooooooooool0^Oooool00:7ooooo0_l00009ooooo`03o`000?oooooooooo027ooooo1?l0
002Dooooo`00XOooool2o`0000Wooooo00?o0000ooooooooool08Oooool4o`0009Cooooo002/oooo
o`03o`000?oooooooooo00Gooooo0_l0000Kooooo`;o0000UOooool00:cooooo00?o0000oooooooo
ool01Oooool4o`000;3ooooo002/ooooo`03o`000?oooooooooo00Oooooo0_l0002`ooooo`00R?oo
ool2o`0002;ooooo0ol00006ooooo`;o0000/Oooool008Sooooo0_l0000Rooooo`03o`000?oooooo
oooo00?ooooo0_l000000ooooooo0000o`00002aooooo`00[?ooool00ol0003oooooooooo`03oooo
o`;o00006Oooool2o`0009Wooooo002:ooooo`;o00008?ooool00ol0003oooooooooo`0Looooo`Co
0000VOooool008[ooooo0_l00009ooooo`;o00005Oooool00ol0003oooooooooo`0Jooooo`Co0000
Voooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q0_l00004ooooo`03o`00
0?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01[o
oooo0_l0002Mooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03
oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2iooooo`00
ROooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01Sooooo1Ol0002Looooo`00ROooool01Ol0003ooooo
oooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`?o
00006?ooool5o`0009cooooo0029ooooo`05o`000?ooooooooooooooool000002_ooool2o`0000;o
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool06_ooool2o`0009gooooo0029ooooo`05oa0@4?ooooooooooooooool@41002_ooool2o`00
00;ooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`?o00005?ooool4o`00
0:7ooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo
<S8b00Cooooo00?o0000ooooooooool01_ooool4o`0001Cooooo1?l0002Qooooo`00ROooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001?ooool3o`000;_ooooo002Ioooo
o`;o00000_ooool2o`0000_ooooo0ol0002kooooo`00WOooool4o`0000Cooooo0_l00002ooooo`;o
000000?oooooo`000?ooool0^_ooool009kooooo0ol000001?oooooo0000o`000?ooool2o`0000;o
oooo0_l000000ooooooo0000ooooo`0Aooooo`;o00000oooool2o`000:;ooooo002Looooo`Co0000
00Coooooo`000?l0003o00001Oooool2o`000004ooooool0003o0000o`00013ooooo0_l00003oooo
o`;o0000X_ooool008kooooo0_l0000<ooooo`;o00000oooool2o`0000Wooooo00?o0000oooooooo
ool0^Oooool008kooooo0_l0000Aooooo`;o00002Oooool00ol0003oooooooooo`2iooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0@ooooo`;o0000Yoooool0
0:cooooo00?o0000ooooooooool04?ooool2o`000:Oooooo002/ooooo`03o`000?oooooooooo013o
oooo0_l0002Wooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`0000cooooo1?l0
002Yooooo`00[?ooool00ol0003oooooooooo`0<ooooo`Co0000ZOooool00:cooooo00?o0000oooo
ooooool03?ooool2o`000:_ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`03o`000?oooooooooo00Kooooo0_l0002aooooo`00[?ooool00ol0003o
ooooooooo`06ooooo`?o0000/?ooool009?ooooo0_l0000Gooooo`?o00001oooool2o`000;3ooooo
002Cooooo`Co00005Oooool00ol0003oooooooooo`04ooooo`;o0000/oooool009Gooooo0_l0000E
ooooo`03o`000?oooooooooo00Cooooo0_l0002cooooo`00[?ooool00ol0003oooooooooo`04oooo
o`?o0000/_ooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo00Cooooo0ol0002booooo`00
UOooool4o`0001?ooooo00Go0000ooooool0003o0000ooooo`02o`000;Gooooo002Eooooo`Co0000
4oooool00ol0003oooooo`000004o`000;Gooooo002Gooooo`;o00004oooool00ol0003oooooo`00
0002o`000;Oooooo002/ooooo`Go0000]oooool00:cooooo00?o0000ooooooooool00_l0002goooo
o`00V_ooool2o`0000;ooooo0_l0000<ooooo`Co0000^?ooool009[ooooo0_l00002ooooo`;o0000
1_ooool2o`0000Cooooo1?l0002hooooo`00X_ooool6o`0000Cooooo0ol0002iooooo`00X_ooool4
o`0000Kooooo00?o0000ooooooooool0^Oooool00:;ooooo1?l000001?l@413oooooooooooooool3
o`000;_ooooo002Tooooo`03o`000?oooooooooo00?ooooo0ol0002kooooo`00Woooool2o`0000?o
oooo00?o0000ooooooooool01Oooool3o`000;Wooooo002Oooooo`;o00000oooool00ol0003ooooo
ooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31
ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00X_ooool00omEEEGoIVIVo`000033ooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Z_ooool01?l@413o
0000o`000?l0002jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooo
ooooo`2jooooo`00Zoooool01_l0003oMgMgo`000?l0003oEEEEonk^k[Oooooo002[ooooo`06o`00
0?mEEEGok^k^oooooomgMgOoEEEE]oooool00:_ooooo00?o0000onk^k_ooool00_ooool00ol0003o
ooooooooo`2eooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo0;Gooooo
002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoIVIV]oooool00:[ooooo00?o410@o`000?mgMgL0
0_l000000omVIVKok^k^ooooo`2fooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.62158 .65554 Mdot
.5671 .79871 Mdot
.50602 .50317 Mdot
.52558 .33917 Mdot
.57677 .39383 Mdot
.62984 .42685 Mdot
.51752 .49111 Mdot
.71156 .63557 Mdot
.70799 .55407 Mdot
.50899 .73588 Mdot
.42823 .69377 Mdot
.67786 .72769 Mdot
.43683 .89118 Mdot
.47988 .78479 Mdot
.63354 .80162 Mdot
.55742 .49625 Mdot
.41525 .26842 Mdot
.43035 .8782 Mdot
.47204 .19653 Mdot
.50057 .06427 Mdot
.39614 .73448 Mdot
.49154 .90669 Mdot
.43352 .86778 Mdot
.40776 .80421 Mdot
.5905 .87572 Mdot
.57318 .66604 Mdot
.41217 .44504 Mdot
.47918 .20061 Mdot
.5399 .11149 Mdot
.54228 .83529 Mdot
.38128 .45267 Mdot
.71243 .52936 Mdot
.70471 .63477 Mdot
.50107 .16148 Mdot
.54291 .215 Mdot
.5056 .08385 Mdot
.67218 .33607 Mdot
.44907 .22936 Mdot
.59711 .19828 Mdot
.68295 .72477 Mdot
.62014 .84027 Mdot
.51933 .18179 Mdot
.60186 .33667 Mdot
.62971 .64417 Mdot
.63961 .58008 Mdot
.59366 .51219 Mdot
.45773 .76855 Mdot
.70838 .44768 Mdot
.48603 .84241 Mdot
.56061 .145 Mdot
.7075 .45367 Mdot
.61408 .21657 Mdot
.61355 .08969 Mdot
.58518 .30064 Mdot
.57636 .2714 Mdot
.70633 .59917 Mdot
.70473 .6565 Mdot
.40501 .33194 Mdot
.69464 .39458 Mdot
.64146 .55985 Mdot
.59094 .55332 Mdot
.44115 .98956 Mdot
.61059 .22367 Mdot
.43392 .65267 Mdot
.68402 .68148 Mdot
.71302 .55393 Mdot
.50851 .73436 Mdot
.55488 .50188 Mdot
.43696 .25597 Mdot
.38712 .66955 Mdot
.40027 .36068 Mdot
.49397 .66682 Mdot
.48913 .76861 Mdot
.53535 .66294 Mdot
.61065 .22388 Mdot
.46554 .64031 Mdot
.61426 .09059 Mdot
.56641 .6635 Mdot
.59677 .18906 Mdot
.45312 .82121 Mdot
.41829 .15421 Mdot
.53963 .83721 Mdot
.51627 .31745 Mdot
.52048 .18149 Mdot
.71591 .59836 Mdot
.55908 .46941 Mdot
.57965 .40515 Mdot
.58784 .49948 Mdot
.39561 .49315 Mdot
.55453 .51746 Mdot
.57842 .89065 Mdot
.4209 .45689 Mdot
.59126 .48501 Mdot
.42076 .50027 Mdot
.39778 .09981 Mdot
.48388 .78204 Mdot
.70679 .49059 Mdot
.62319 .09971 Mdot
.39593 .55668 Mdot
.60893 .69439 Mdot
.40723 .68279 Mdot
.66678 .74591 Mdot
.61794 .68198 Mdot
.3829 .37578 Mdot
.51273 .1775 Mdot
.41932 .23764 Mdot
.49453 .20578 Mdot
.42095 .45386 Mdot
.38256 .60686 Mdot
.50085 .75784 Mdot
.51256 .30096 Mdot
.71139 .53011 Mdot
.47616 .05591 Mdot
.73933 .26056 Mdot
.48781 .29697 Mdot
.58356 .60194 Mdot
.71965 .54135 Mdot
.71757 .52939 Mdot
.67576 .3613 Mdot
.43035 .87594 Mdot
.39344 .70017 Mdot
.53803 .10721 Mdot
.38396 .63124 Mdot
.53909 .38704 Mdot
.50516 .07599 Mdot
.37242 .24313 Mdot
.55867 .79879 Mdot
.5327 .47821 Mdot
.45611 .90575 Mdot
.59054 .73941 Mdot
.65734 .7707 Mdot
.63058 .41688 Mdot
.61392 .37034 Mdot
.56892 .1463 Mdot
.65118 .27494 Mdot
.53025 .10306 Mdot
.48985 .7669 Mdot
.69038 .68026 Mdot
.63748 .79806 Mdot
.36628 .66544 Mdot
.4574 .26167 Mdot
.44654 .2274 Mdot
.41354 .27674 Mdot
.48511 .05441 Mdot
.7181 .57614 Mdot
.77282 .32579 Mdot
.53793 .29898 Mdot
.58886 .51542 Mdot
.55388 .94299 Mdot
.41816 .74599 Mdot
.41076 .43142 Mdot
.41042 .81729 Mdot
.50361 .63607 Mdot
.63513 .52881 Mdot
.64623 .27302 Mdot
.61067 .21881 Mdot
.71616 .55766 Mdot
.67499 .34863 Mdot
.64726 .27312 Mdot
.54393 .74431 Mdot
.58964 .17576 Mdot
.65977 .78485 Mdot
.47957 .0672 Mdot
.60853 .36856 Mdot
.60192 .70554 Mdot
.71718 .57451 Mdot
.38698 .3203 Mdot
.43264 .27215 Mdot
.6347 .24334 Mdot
.55166 .13838 Mdot
.44623 .29523 Mdot
.42687 .30238 Mdot
.58309 .43867 Mdot
.5415 .30253 Mdot
.69394 .66327 Mdot
.39027 .13311 Mdot
.63452 .52548 Mdot
.49905 .32456 Mdot
.56374 .14546 Mdot
.61602 .21174 Mdot
.66596 .76186 Mdot
.55471 .58031 Mdot
.61431 .85001 Mdot
.52871 .58516 Mdot
.70494 .56026 Mdot
.37636 .21682 Mdot
.71558 .49759 Mdot
.66078 .78062 Mdot
.60613 .34343 Mdot
.52761 .96704 Mdot
.48144 .05262 Mdot
.45162 .70947 Mdot
.44214 .98741 Mdot
.71286 .61977 Mdot
.60636 .8685 Mdot
.6641 .75462 Mdot
.58953 .4738 Mdot
.44159 .16534 Mdot
.46849 .30102 Mdot
.47308 .29834 Mdot
.48511 .68279 Mdot
.57798 .41141 Mdot
.59348 .72904 Mdot
.48897 .71743 Mdot
.63432 .46076 Mdot
.49665 .26243 Mdot
.52668 .61074 Mdot
.42953 .70315 Mdot
.47936 .92253 Mdot
.57176 .64606 Mdot
.3885 .30629 Mdot
.55291 .57686 Mdot
.59696 .71763 Mdot
.57437 .63142 Mdot
.65325 .7954 Mdot
.53397 .55927 Mdot
.63512 .57559 Mdot
.69392 .69776 Mdot
.58626 .5876 Mdot
.69914 .43387 Mdot
.38109 .39715 Mdot
.44531 .09146 Mdot
.55165 .56748 Mdot
.56039 .34291 Mdot
.59194 .75537 Mdot
.43404 .3401 Mdot
.63362 .80222 Mdot
.55191 .43494 Mdot
.46968 .33722 Mdot
.42174 .75077 Mdot
.41078 .52782 Mdot
.50452 .99148 Mdot
.43489 .2674 Mdot
.61286 .69854 Mdot
.411 .80597 Mdot
.59761 .72359 Mdot
.4333 .97634 Mdot
.61813 .37326 Mdot
.39966 .2221 Mdot
.40007 .36323 Mdot
.71549 .51421 Mdot
.42145 .49802 Mdot
.6517 .29439 Mdot
.39927 .42538 Mdot
.39841 .38365 Mdot
.60736 .21561 Mdot
.60586 .86703 Mdot
.48667 .29638 Mdot
.442 .67874 Mdot
.66318 .32373 Mdot
.55687 .70543 Mdot
.42488 .31427 Mdot
.57734 .26609 Mdot
.45901 .62962 Mdot
.70055 .6613 Mdot
.70271 .42122 Mdot
.45398 .83334 Mdot
.41094 .53463 Mdot
.45515 .07803 Mdot
.52354 .40663 Mdot
.41351 .71846 Mdot
.62275 .64259 Mdot
.43943 .72927 Mdot
.62629 .43828 Mdot
.53082 .11389 Mdot
.5258 .77143 Mdot
.49843 .07142 Mdot
.58045 .27731 Mdot
.51937 .71469 Mdot
.45451 .82834 Mdot
.64076 .2602 Mdot
.55551 .58204 Mdot
.52963 .26471 Mdot
.70933 .47191 Mdot
.44341 .75149 Mdot
.63651 .49914 Mdot
.57316 .15635 Mdot
.53239 .4419 Mdot
.53708 .64981 Mdot
.67631 .35566 Mdot
.67727 .72307 Mdot
.49636 .20735 Mdot
.51428 .57863 Mdot
.57051 .39566 Mdot
.43733 .08964 Mdot
.59015 .52327 Mdot
.4091 .19137 Mdot
.37948 .19731 Mdot
.6935 .40135 Mdot
.65291 .76646 Mdot
.69582 .42602 Mdot
.50017 .37034 Mdot
.68393 .3534 Mdot
.44429 .98641 Mdot
.412 .15943 Mdot
.63952 .79067 Mdot
.78617 .3575 Mdot
.47998 .84049 Mdot
.59784 .309 Mdot
.59259 .73808 Mdot
.71428 .52161 Mdot
.61215 .84789 Mdot
.45276 .76339 Mdot
.70832 .4788 Mdot
.55281 .71722 Mdot
.44362 .36115 Mdot
.46908 .92007 Mdot
.42062 .24102 Mdot
.42971 .87199 Mdot
.56215 .93174 Mdot
.50357 .33179 Mdot
.63135 .60067 Mdot
.51394 .1775 Mdot
.67884 .69827 Mdot
.52199 .39325 Mdot
.65883 .77454 Mdot
.50884 .97943 Mdot
.36458 .65967 Mdot
.54877 .42842 Mdot
.63021 .40692 Mdot
.5172 .1746 Mdot
.62519 .24814 Mdot
.55653 .32633 Mdot
.44519 .34691 Mdot
.51249 .4315 Mdot
.41404 .26486 Mdot
.70177 .67348 Mdot
.66416 .33184 Mdot
.4212 .53568 Mdot
.48861 .91459 Mdot
.53365 .48045 Mdot
.48178 .68567 Mdot
.58723 .76457 Mdot
.62642 .40639 Mdot
.60876 .36872 Mdot
.54178 .74818 Mdot
.57559 .40322 Mdot
.58031 .05159 Mdot
.54113 .73939 Mdot
.54072 .83162 Mdot
.42851 .61479 Mdot
.70342 .62551 Mdot
.41152 .47534 Mdot
.52608 .09925 Mdot
.50086 .89051 Mdot
.43106 .34617 Mdot
.5803 .59496 Mdot
.36892 .69753 Mdot
.68501 .71318 Mdot
.67967 .33544 Mdot
.51014 .08767 Mdot
.50424 .81608 Mdot
.45008 .15389 Mdot
.53946 .12159 Mdot
.41844 .74012 Mdot
.68363 .71539 Mdot
.36821 .71117 Mdot
.40353 .20144 Mdot
.65625 .7713 Mdot
.65441 .78292 Mdot
.633 .82611 Mdot
.461 .68022 Mdot
.43518 .79483 Mdot
.63234 .80582 Mdot
.70358 .65597 Mdot
.4556 .67106 Mdot
.3909 .30016 Mdot
.52475 .76792 Mdot
.63477 .44901 Mdot
.61258 .68354 Mdot
.70759 .50782 Mdot
.61203 .69946 Mdot
.67945 .35152 Mdot
.65115 .30293 Mdot
.43831 .87668 Mdot
.67044 .3109 Mdot
.45659 .90466 Mdot
.6081 .84956 Mdot
.75136 .27946 Mdot
.68341 .38805 Mdot
.63757 .52389 Mdot
.50049 .64231 Mdot
.5481 .93512 Mdot
.39695 .56863 Mdot
.51021 .41801 Mdot
.66827 .76047 Mdot
.38532 .65015 Mdot
.43942 .37302 Mdot
.52641 .68953 Mdot
.57671 .64523 Mdot
.41072 .46752 Mdot
.7104 .45392 Mdot
.37791 .45929 Mdot
.4383 .98026 Mdot
.66355 .76729 Mdot
.45334 .15545 Mdot
.57851 .05367 Mdot
.45523 .15012 Mdot
.5353 .28711 Mdot
.54139 .29589 Mdot
.44111 .44793 Mdot
.70002 .67391 Mdot
.6783 .72567 Mdot
.41151 .46452 Mdot
.43895 .31335 Mdot
.41922 .65616 Mdot
.56057 .51359 Mdot
.57678 .91007 Mdot
.59007 .45695 Mdot
.46536 .06754 Mdot
.48059 .2514 Mdot
.41349 .39341 Mdot
.52738 .42392 Mdot
.58607 .43602 Mdot
.48951 .14914 Mdot
.40964 .51721 Mdot
.48159 .72539 Mdot
.52561 .97269 Mdot
.69292 .67365 Mdot
.47938 .3772 Mdot
.55061 .22717 Mdot
.42023 .23398 Mdot
.6292 .58299 Mdot
.51324 .78991 Mdot
.42628 .30215 Mdot
.55623 .92785 Mdot
.40464 .07083 Mdot
.59916 .72937 Mdot
.71109 .21448 Mdot
.62881 .65247 Mdot
.47705 .73066 Mdot
.70121 .59288 Mdot
.62501 .81779 Mdot
.41855 .63096 Mdot
.49039 .90018 Mdot
.59039 .06296 Mdot
.44745 .28602 Mdot
.43266 .43283 Mdot
.55312 .3337 Mdot
.44339 .09178 Mdot
.4788 .83506 Mdot
.52605 .60561 Mdot
.57206 .27474 Mdot
.50382 .15696 Mdot
.42598 .60322 Mdot
.50712 .34549 Mdot
.54843 .6193 Mdot
.70995 .64026 Mdot
.50899 .34446 Mdot
.58263 .16716 Mdot
.58302 .76838 Mdot
.63482 .59583 Mdot
.49932 .07057 Mdot
.39923 .24392 Mdot
.43268 .19711 Mdot
.3624 .34063 Mdot
.52361 .6981 Mdot
.70103 .67687 Mdot
.61255 .85886 Mdot
.43386 .70868 Mdot
.68234 .34581 Mdot
.51872 .78211 Mdot
.41487 .27636 Mdot
.52039 .09204 Mdot
.61186 .68857 Mdot
.48805 .20176 Mdot
.5809 .59379 Mdot
.4912 .14834 Mdot
.61644 .38891 Mdot
.47641 .64753 Mdot
.60043 .33913 Mdot
.45662 .82719 Mdot
.47154 .69114 Mdot
.55237 .46706 Mdot
.58014 .28823 Mdot
.60749 .34461 Mdot
.47771 .29409 Mdot
.55972 .6942 Mdot
.71269 .55779 Mdot
.57194 .37149 Mdot
.62555 .62762 Mdot
.42649 .29015 Mdot
.49685 .2195 Mdot
.43972 .61392 Mdot
.72856 .23814 Mdot
.43479 .57432 Mdot
.57746 .78163 Mdot
.69993 .46022 Mdot
.47878 .06584 Mdot
.44433 .23495 Mdot
.54425 .12021 Mdot
.67046 .74972 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:Gooooo0_l00005ooooo`?o00005oooool2o`000:3ooooo002Tooooo`Go00000ooo
ool00ol0003oooooooooo`0Fooooo`?o0000X?ooool00:Cooooo0_l000000ooooooo0000o`000003
ooooo`03o`000?oooooooooo01Kooooo0_l0002Qooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool2o`0001_ooooo0_l0002Mooooo`00X?ooool2o`0000?ooooo0_l00005ooooo`;o0000
6oooool2o`0009gooooo002<ooooo`;o00004_ooool2o`0000?ooooo0_l00004ooooo`;o0000^ooo
ool008cooooo0_l0000Mooooo`;o0000^oooool00:_ooooo1?l0002iooooo`00WOooool2o`0000go
oooo0ol0002iooooo`00WOooool2o`0000gooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0
002iooooo`00[?ooool5o`000;Oooooo002Gooooo`Go00004?ooool00ol0003oooooooooo`02o`00
0003ooooool0003o000001gooooo0_l0002Eooooo`00Uoooool5o`00013ooooo00?o0000oooooooo
ool00oooool2o`0001gooooo0_l0002Eooooo`00[?ooool00ol0003oooooooooo`2iooooo`00R_oo
ool2o`00023ooooo0ol00005ooooo`;o00007_ooool2o`0009;ooooo002:ooooo`;o00008?ooool0
0ol0003oooooooooo`05ooooo`Co00007?ooool2o`0009;ooooo002/ooooo`03o`000?oooooooooo
00Oooooo1?l0002^ooooo`00[?ooool00ol0003oooooooooo`09ooooo`;o0000[_ooool00:cooooo
00?o0000ooooooooool02_ooool2o`000:gooooo002/ooooo`03o`000?oooooooooo00Oooooo0_l0
00000ooooooo0000o`00002]ooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`00
0?oooooooooo00Oooooo0_l0002`ooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`0:ooooo`?o0000[?ooool0087ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@4100
3Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0000:ooooo`?o0000
[?ooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2iooooo`00ROooool01Ol0003ooooooooo
oooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool0^Oooool008Oooooo0_l000001Ol@413ooooooooooooooooo410@00ko
oooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Wo
oooo0027ooooo`;o000000GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooo
oolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo
00kooooo0_l0002Yooooo`00[?ooool00ol0003oooooooooo`0>ooooo`;o0000ZOooool00:cooooo
00?o0000ooooooooool04Oooool4o`000:Cooooo002Mooooo`;o00002Oooool3o`000003ooooool0
003ooooo01;ooooo1?l0002Tooooo`00WOooool2o`0000Wooooo0ol000001?oooooo0000o`000?l0
002iooooo`00TOooool2o`0000Sooooo0ol0000>ooooo`03o`000?oooooooooo0;Wooooo002Aoooo
o`;o00002?ooool3o`0000kooooo0ol0000Eooooo`;o0000X_ooool008oooooo0_l0000Kooooo`?o
00005Oooool2o`000:;ooooo002?ooooo`;o00006oooool2o`000;[ooooo002Hooooo`;o00004_oo
ool00ol0003oooooooooo`0Hooooo`;o0000Woooool009Sooooo0_l0000Booooo`03o`000?oooooo
oooo01Sooooo0_l0002Oooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`0000;o
oooo0_l0000Fooooo`;o0000WOooool00:cooooo00Co0000oooooooooooooooo0ol0000Fooooo`;o
0000WOooool00:cooooo00Co0000oooooooooooooooo1?l0002dooooo`00[?ooool00ol0003ooooo
ooooo`03ooooo`;o0000]?ooool00:cooooo00?o0000ooooooooool07Oooool2o`0009[ooooo002>
ooooo`;o00007?ooool00ol0003oooooooooo`0Mooooo`;o0000V_ooool008kooooo0_l0000Loooo
o`03o`000?oooooooooo0;Wooooo0024ooooo`;o00003oooool2o`0000_ooooo0_l00008ooooo`03
o`000?oooooooooo01gooooo0_l0002Jooooo`00Q?ooool2o`0000Kooooo0_l00007ooooo`;o0000
2oooool2o`000003ooooool0003o000000Gooooo0ol0000Mooooo`;o0000V_ooool008cooooo0_l0
000Gooooo`;o000000?oooooo`000?l000000_ooool00ol0003oooooooooo`2iooooo`00Z?ooool5
o`000;_ooooo002Zooooo`?o0000^oooool00:cooooo00?o0000ooooooooool08oooool2o`0009Co
oooo002/ooooo`03o`000?oooooooooo00_ooooo0_l0000Cooooo`Go00007Oooool2o`0007Gooooo
0023ooooo`;o00009_ooool2o`0000gooooo0_l0000Cooooo`Co00007_ooool2o`0007Gooooo0023
ooooo`;o00001Oooool2o`0001oooooo0_l0000Sooooo`;o0000U_ooool008[ooooo0_l0000Poooo
o`?o00008Oooool2o`0009Kooooo002Jooooo`;o00004?ooool00ol0003oooooooooo`0=ooooo`;o
00004_ooool2o`0009Kooooo002Jooooo`?o00003oooool00ol0003oooooooooo`0=ooooo`;o0000
Z_ooool0097ooooo0_l00006ooooo`Co00003oooool00ol0003oooooooooo`2iooooo`00TOooool2
o`0000Kooooo0_l0000Aooooo`03o`000?oooooooooo0;Wooooo002Aooooo`;o00006Oooool00ol0
003oooooooooo`18ooooo`;o0000Koooool0087ooooo0_l00007ooooo`;o00001Oooool3o`000003
oc8b<_o^k^kooooo00Cooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`0Yooooo`;o00007Oooool2o`0006oooooo0021ooooo`;o00001oooool2o`0000Go
oooo0_l000000oooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo02Wooooo0_l0002>ooooo`00ROooool6o`0000;ooooo00Go410@oooooooooooo
oooooa0@400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09_ooool2o`00097o
oooo002Aooooo`05o`000?ooooooooooooooool000003oooool2o`0000Gooooo0ol0000Vooooo`;o
0000TOooool0097ooooo00Ko0000ooooooooooooooooo`000?ooool2o`0000Wooooo00?o0000ob4Q
8Ol000000_l00005ooooo`03o`000?oooooooooo0;Wooooo002Aooooo`06oa0@4?oooooooooooooo
ool@413ooooo0_l00009ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0^Oooool0
097ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`;o00000oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo02_ooooo0_l0000Oooooo`;o0000Joooool008oooooo0_l000001Oo^
k^ko<S8bo`000?lb<S;ok^k^00Oooooo0_l00003ooooo`Co00001?ooool3o`0000Sooooo0_l0000S
ooooo`;o00007oooool2o`0006_ooooo002?ooooo`;o00001Oooool2o`0001;ooooo0ol00008oooo
o`;o00003_ooool2o`000:7ooooo002@ooooo`;o00001?ooool2o`0001Cooooo00?o0000oooooooo
ool05_ooool2o`000:7ooooo002@ooooo`;o00000oooool2o`0001Gooooo00?o0000ooooooooool0
5_ooool2o`0001Gooooo0_l0002:ooooo`00Soooool2o`0000Cooooo0_l0000Eooooo`?o00005?oo
ool5o`0001Cooooo0ol00029ooooo`00Soooool2o`0001_ooooo00?o0000ooooooooool05?ooool2
o`000003ooooool0003o000001Gooooo0_l0000Pooooo`;o0000Ioooool00:cooooo00?o0000oooo
ooooool0D?ooool2o`0006Oooooo002Jooooo`;o00004?ooool00ol0003oooooooooo`2iooooo`00
V_ooool2o`00013ooooo00?o0000ooooooooool02?ooool2o`0000gooooo0_l0002Pooooo`00Tooo
ool2o`0001Oooooo00?o0000ooooooooool02?ooool2o`0000gooooo0_l0002Pooooo`00Toooool2
o`0000Gooooo0_l00008ooooo`;o00001_ooool00ol0003oooooooooo`0_ooooo`;o0000R?ooool0
09[ooooo0_l00007ooooo`?o000000Coooooo`000?l0003o00000_ooool00ol0003oooooooooo`0:
ooooo`;o00008oooool2o`0008Sooooo0028ooooo`;o00005oooool4o`0000;ooooo0ol00002oooo
o`?o000000?oooooo`000?l000001_ooool3o`0000gooooo0_l0002Nooooo`00R?ooool2o`0000Wo
oooo0_l0000<ooooo`;o00002Oooool01?l0003oooooooooooooool2o`0000Kooooo0ol0000=oooo
o`;o00004oooool2o`0008Wooooo0027ooooo`;o00002_ooool2o`0001Oooooo00?o0000oooooooo
ool02_ooool2o`0002;ooooo0_l00029ooooo`00Qoooool2o`0002?ooooo00?o0000ooooooooool0
7Oooool2o`0009[ooooo002Gooooo`;o00004oooool00ol0003oooooooooo`0Mooooo`;o00005_oo
ool2o`0008;ooooo002Cooooo`;o00000_ooool2o`0001?ooooo00?o0000ooooooooool0=Oooool2
o`0008;ooooo002Cooooo`;o00005oooool00ol0003oooooooooo`02ooooo`;o0000]Oooool008Ko
oooo0_l0000Tooooo`03o`000?oooooooooo00;ooooo0_l0002eooooo`00Q_ooool2o`0002?ooooo
1?l0000booooo`;o00008oooool2o`00063ooooo002[ooooo`;o00004Oooool2o`00027ooooo0_l0
000Sooooo`;o0000H?ooool00:cooooo0ol0000?ooooo`;o00008_ooool2o`0008Cooooo002<oooo
o`;o00007_ooool3o`0000kooooo0_l0000Sooooo`;o0000Q?ooool008cooooo0_l0000Dooooo`;o
00002?ooool00ol0003oooooooooo`0>ooooo`;o00003_ooool2o`0001Gooooo0_l000000ooooooo
0000o`00001oooooo`00O_ooool2o`0001Kooooo0_l0000:ooooo`;o00002?ooool00ol0003ooooo
ooooo`05ooooo`;o00005oooool2o`0001Gooooo0_l000000ooooooo0000o`00001oooooo`00O_oo
ool2o`0001Kooooo0_l0000Dooooo`03o`000?oooooooooo00Gooooo0_l00009ooooo`;o00003?oo
ool4o`0009Oooooo002Eooooo`;o00000_ooool2o`00017ooooo00?o0000ooooool000000_l0000>
ooooo`;o00003_ooool2o`0001Oooooo0_l0001nooooo`00UOooool2o`0000;ooooo0_l0000Aoooo
o`03o`000?oooooo000000;o00007_ooool2o`0001Cooooo0_l000000ooooooo0000o`00001noooo
o`00[?ooool3o`0003Kooooo1?l0001oooooo`00[?ooool00ol0003oooooooooo`0gooooo`Co0000
O_ooool00:cooooo00?o0000ooooooooool0=oooool4o`00023ooooo0_l0001Looooo`00Roooool2
o`0000cooooo0_l0000Aooooo`03o`000?oooooooooo03Oooooo0_l0000Rooooo`;o0000G?ooool0
08_ooooo0_l0000<ooooo`;o00004Oooool00ol0003oooooooooo`0gooooo`;o0000P?ooool008Wo
oooo00Gok^k^oc8b<_l0003o0000onk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb
<S;ooooo00Cooooo0_l0000Qooooo`Co0000UOooool0087ooooo1_l00002ooooo`05oa0@4?oooooo
ooooooooool@41002_ooool2o`000003oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00ooo
ool2o`0001Gooooo0_l0000:ooooo`Ko0000Toooool008Gooooo0_l00002ooooo`05o`000?oooooo
ooooooooool000002_ooool2o`000004oooooonHV9So8B4Qonk^kPOooooo0_l00005ooooo`?o0000
5?ooool2o`0000kooooo0_l0002Cooooo`00QOooool2o`0000;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00?o0000ob4Q8Ol000000_l00005ooooo`03o`00
0?oooooooooo0;Wooooo0029ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0^Oooool008Wooooo00Go
MgMgo`000?l0003oV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05onk^k_l0003o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo
00Wooooo0_l0000Hooooo`;o00005?ooool2o`0007kooooo002/ooooo`03o`000?oooooooooo00Wo
oooo0_l0000Hooooo`;o00005?ooool2o`0007kooooo002?ooooo`;o00006oooool00ol0003ooooo
ooooo`04ooooo`;o00004?ooool2o`0002Gooooo0_l0001jooooo`00Q?ooool2o`0000Wooooo0_l0
000Kooooo`03o`000?oooooooooo00Cooooo0_l0000>ooooo`Co00009Oooool2o`0007[ooooo0024
ooooo`;o00009_ooool3o`0001Cooooo0_l0000Vooooo`;o0000Noooool00:cooooo00?o0000oooo
ooooool05_ooool2o`0002Cooooo0_l0001kooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o
00004?ooool3o`0000gooooo1?l0002?ooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o0000
4Oooool2o`0000gooooo1?l0002?ooooo`00[?ooool00ol0003oooooooooo`0Fooooo`;o0000XOoo
ool00:cooooo00?o0000ooooooooool05_ooool2o`000:7ooooo002/ooooo`03o`000?oooooooooo
00;o00009_ooool2o`0008oooooo002/ooooo`03o`000?oooooooooo00;o00009_ooool2o`0001Go
oooo0_l0001hooooo`00R_ooool2o`00023ooooo0ol00006ooooo`;o0000=oooool2o`0007Sooooo
002:ooooo`;o00008?ooool00ol0003oooooooooo`06ooooo`;o00001Oooool2o`0001Sooooo0_l0
000Dooooo`;o0000N_ooool008kooooo0_l0000Looooo`04o`000?ooooooooooooooo`;o00002_oo
ool2o`0001Sooooo0_l0000Dooooo`;o0000N_ooool008kooooo0_l00005ooooo`;o00005Oooool0
1?l0003oooooooooooooool2o`0003_ooooo0_l0001iooooo`00UOooool2o`0001Gooooo00?o0000
ooooooooool03_ooool2o`0000Wooooo0_l0000Sooooo`;o0000NOooool00:cooooo00?o0000oooo
ooooool03_ooool2o`0000Sooooo0ol0000;ooooo`;o0000TOooool00:cooooo00?o0000oooooooo
ool01oooool2o`0000oooooo0_l0000<ooooo`;o0000TOooool008oooooo0_l0000Kooooo`03o`00
0?oooooooooo00Oooooo0_l0002`ooooo`00Soooool2o`0000Oooooo0_l0000Booooo`03o`000?oo
oooooooo02Wooooo0_l0000Fooooo`;o0000M_ooool008Cooooo0_l0000Booooo`;o00004_ooool3
o`0002Wooooo0_l0000Fooooo`;o0000M_ooool008Cooooo0_l0000;ooooo`;o00006Oooool00ol0
003oooooooooo`11ooooo`?o0000MOooool0097ooooo0_l0000Iooooo`03o`000?oooooooooo01[o
oooo0_l0000Uooooo`?o0000MOooool000Wooooo1?l000000ol@413oooooooooo`0Fooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool0
1Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03ob4Q
8Ol0003o000000?ooooo1Ol00004ooooo`?o000000?o<S8bomgMgOooool05Oooool00ol0003ooooo
ooooo`0Hooooo`05onk^k_lb<S;o0000o`000?o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05
odA4A?l0003o0000oc8b<_oMgMd02Oooool2o`0000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oM
gMd06?ooool4o`000003oa0@4?oooooooooo01;ooooo000;ooooo`03o`000?oooooooooo01Sooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03
ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00olQ8B7o0000o`000003
ooooo`06oiRHV?lQ8B7ok^k^oooooom4A4Cooooo0_l00004ooooo`03ogMgMolb<S;ooooo01Gooooo
00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
oiRHV?l0003o0000oooooom4A4@01oooool00omgMgOo<S8booooo`08ooooo`;o00001?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb
<S;ooooo01Wooooo00?o0000ooooooooool05?ooool000Ko00001Oooool00ol0003oooooooooo`0@
ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?oo
ool00ol0003oooooooooo`05ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@013ooooo
00?o0000ooooooooool01Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03
oiRHV?lQ8B7ok^k^00;ooooo0_l00005ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool03_ooool2o`0000Sooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^
00Wooooo00?o0000ooooooooool03Oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000
ooooooooool03Oooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?oo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooo
oooo01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?o
MgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool0
3_ooool01Ol0003ooooooooooooooooo000000gooooo00CoV9RHob4Q8Oo^k^kooooo0_l00004oooo
o`03ogMgMolb<S;ooooo01Gooooo00?o0000ooooooooool03_ooool4o`0000Kooooo00Go0000oooo
ooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool03_ooool0
1Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooo
oooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`0Iooooo`03o`00
0?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go0000oooooooooooooooo
o`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05
o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00Fooooo`03o`000?oooooooooo013ooooo0_l00006ooooo`03o`000?oooooo000000;o0000
3_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03?ooool2o`000003
ooooool0003ooooo00;ooooo00?o0000ooooooooool02_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00oooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c00Jooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooo
oooo01Sooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o
0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool0
4Oooool01Ol@413ooooooooooooooooo410@00oooooo00Ko0000ooooool0003o0000ooooool0000J
ooooo`?o00006?ooool01Ol@413oooooo`000?l0003o410@00oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0>ooooo`;o000000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`0:ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVY
ZOmgMgOooooo00?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Dooooo`002ooo
ool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooo
oooooooooooo<S8b00Cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Ko0000
okZj^_ooooooV9RHoa0@4?ooool2o`000003ooooool0003ooooo01Wooooo00?o0000ooooooooool0
1oooool2o`0000oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRH
V?l@41001?ooool00ol0003oooooooooo`0=ooooo`;o00000_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
5?ooool000Wooooo00?oEEEEofIVI_l000006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
1Ol00004ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0000G
ooooo`03o`000?oooooooooo00Oooooo0ol0000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0000<ooooo`;o00000_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`00
00Cooooo1?l0000Iooooo`03oeEEEOmVIVKo000001Kooooo002/ooooo`03o`000?oooooooooo00So
oooo0_l0000Aooooo`;o0000W?ooool00:cooooo00?o0000ooooooooool06oooool2o`0009cooooo
002/ooooo`03o`000?oooooooooo00;ooooo0_l0000mooooo`;o0000Joooool2o`0000;ooooo0_l0
0005ooooo`00ROooool2o`00027ooooo00?o0000ooooooooool00_ooool2o`0003gooooo0_l0001[
ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1Oooool008Wooooo0_l00007ooooo`;o00006?oo
ool00ol0003oooooooooo`0@ooooo`;o0000<_ooool2o`0006Wooooo00CogMgMo`000?l@413oc<c<
1_ooool000Ooooooool0001<o`0000cooooo00Cok^k^ob4Q8Ol@413ok^k^1_ooool000Oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`;o000000?oooooo`000?ooool01_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000ooooool0003o0000
1Oooool00ol0003oooooooooo`05ooooo`?o00001Oooool01?l0003oooooooooooooool2o`0000;o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02o`0000?ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00Co8B4QogMgMomg
MgOo<S8b1_ooool000Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool01?l0003oooooo`000?l0000>oooo
o`;o00005_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`09ooooo`;o00000_ooool2o`0000Gooooo002/ooooo`03
o`000?oooooooooo047ooooo0_l0001fooooo`00[?ooool00ol0003oooooooooo`0Aooooo`;o0000
2?ooool2o`0002Cooooo0_l0001fooooo`00[?ooool00ol0003oooooooooo`0Aooooo`;o00001ooo
ool3o`0002Oooooo0_l0001cooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool03oooool2
o`0000Wooooo0_l0000Xooooo`;o0000Loooool008kooooo0_l0000Looooo`03o`000?oooooooooo
00oooooo0_l0000booooo`;o0000M?ooool00:cooooo0ol0000Jooooo`;o00003Oooool3o`0001Oo
oooo0_l0001dooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool06_ooool2o`0000gooooo
0ol0002=ooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool0:Oooool2o`0001Oooooo1?l0
001cooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool0:Oooool2o`0001Oooooo1?l0001c
ooooo`00S_ooool2o`0000;ooooo0_l0000Hooooo`03o`000?oooooooooo0;Wooooo002Booooo`;o
00006?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`15ooooo`;o0000
L_ooool00:cooooo00?o0000ooooooooool0AOooool2o`0007;ooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool06oooool2o`0002Co
oooo1?l0001dooooo`00ROooool2o`00027ooooo00?o0000ooooooooool06oooool2o`0002Cooooo
1Ol0001cooooo`00ROooool2o`00027ooooo00?o0000ooooooooool02?ooool2o`00027ooooo0_l0
000Cooooo`;o000000Coooooo`000?l0003o0000Loooool00:cooooo00?o0000ooooooooool02?oo
ool2o`00027ooooo0_l0000Cooooo`;o0000Moooool00:cooooo00?o0000ooooooooool03_ooool2
o`000:Wooooo002:ooooo`;o00008?ooool00ol0003oooooooooo`0>ooooo`;o0000ZOooool008[o
oooo0_l0000Pooooo`03o`000?oooooooooo0;Wooooo002Fooooo`;o00005?ooool3o`0000kooooo
0_l0000Iooooo`;o00006Oooool3o`0007;ooooo002Fooooo`;o00005?ooool01?l0003ooooooooo
ooooool2o`0000_ooooo0_l0000Iooooo`Co00005oooool3o`0007;ooooo002/ooooo`04o`000?oo
ooooooooooooo`;o00003?ooool2o`0001Kooooo0_l00002ooooo`;o0000S?ooool00:cooooo00?o
0000ooooooooool01_ooool2o`0000Oooooo0_l0000Fooooo`;o0000T?ooool00:cooooo00?o0000
ooooooooool01_ooool2o`00017ooooo0_l0002Nooooo`00[?ooool00ol0003oooooooooo`0Ioooo
o`;o0000W_ooool00:cooooo00?o0000ooooooooool05oooool2o`0002Kooooo0_l0001hooooo`00
[?ooool00ol0003oooooooooo`0Gooooo`;o00004?ooool2o`0001Cooooo0_l00003ooooo`;o0000
Loooool00:cooooo0ol0000Xooooo`?o00005_ooool2o`000003ooooool0003o000007?ooooo002C
ooooo`;o00005oooool00ol0003oooooooooo`0Hooooo`;o00003_ooool2o`0001Oooooo0_l0001f
ooooo`00QOooool2o`0000cooooo0_l0000Gooooo`03o`000?oooooooooo00Gooooo0_l0000Aoooo
o`;o0000Woooool008Gooooo0_l0000Uooooo`03o`000?oooooooooo00Gooooo0_l0002booooo`00
[?ooool00ol0003oooooooooo`05ooooo`;o0000/_ooool009Cooooo0_l00002ooooo`;o00004_oo
ool00ol0003oooooooooo`05ooooo`;o0000/_ooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`03ob4Q8Ol0003o000000;ooooo1_l00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1Oooool00ol0003oooooooooo`0=ooooo`;o0000Z_ooool008Wooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`0=ooooo`;o0000=?ooool2o`0007Cooooo0029ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?o
oooo0ol00010ooooo`;o000000?oooooo`000?l00000M?ooool008Wooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`0Vooooo`;o00006?ooool2o`0007Oooooo0025ooooo`;o00000_ooool01Ol0003ooooo
oooooooooooo000000?ooooo0_l00009ooooo`04ogMgMomVIVKo0000o`0000;ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo01Gooooo0_l0000?ooooo`;o0000TOooool0
08Gooooo0_l00002ooooo`05oa0@4?ooooooooooooooool@41000oooool2o`0000[ooooo0ol00002
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05Oooool2o`0002Wooooo0_l0001g
ooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@
4004ooooo`03o`000?oooooooooo00Oooooo0ol00010ooooo`Co0000MOooool008Wooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00_ooool6o`0000Kooooo
0ol00012ooooo`;o0000MOooool00:3ooooo0_l0000:ooooo`;o00009_ooool2o`0001_ooooo0_l0
001eooooo`00[?ooool2o`0001Gooooo1?l0000=ooooo`Co0000T?ooool00:Cooooo0_l00006oooo
o`03o`000?oooooooooo00Wooooo0_l00009ooooo`Co00003oooool2o`00093ooooo0026ooooo`;o
00003_ooool2o`0000cooooo0_l00006ooooo`?o00002Oooool2o`0001cooooo0_l0002@ooooo`00
Q_ooool2o`0000kooooo0_l0000Dooooo`03o`000?oooooooooo02Gooooo1?l0000Gooooo`;o0000
Moooool0097ooooo0_l0000Iooooo`03o`000?oooooooooo02Gooooo0_l0000Iooooo`;o0000Mooo
ool007oooooo0_l0000@ooooo`;o00006Oooool00ol0003oooooooooo`0oooooo`?o0000Moooool0
07oooooo0_l0000[ooooo`03o`000?oooooooooo00Sooooo0_l00008ooooo`;o0000:Oooool4o`00
07Sooooo001oooooo`;o0000:Oooool3o`0000[ooooo0_l00008ooooo`;o000000?oooooo`000?l0
00009_ooool2o`0007[ooooo001oooooo`;o00001Oooool2o`0001Gooooo0_l0000;ooooo`?o0000
5oooool2o`000:;ooooo0026ooooo`;o00005Oooool2o`0000gooooo00?o0000ooooooooool0??oo
ool2o`000003ooooool0003o000007Sooooo002/ooooo`?o0000??ooool2o`000003ooooool0003o
000007Sooooo002Hooooo`;o00001Oooool2o`0000_ooooo00?o0000ooooooooool0?oooool2o`00
07Sooooo002=ooooo`;o00002Oooool2o`0000Gooooo0_l00006ooooo`;o00000oooool00ol0003o
ooooooooo`0Sooooo`;o00005?ooool4o`0007cooooo002=ooooo`;o00005oooool3o`0000?ooooo
00?o0000ooooooooool08_ooool3o`0001Cooooo1?l0001looooo`00Y_ooool2o`0000Cooooo00?o
0000ooooooooool08Oooool3o`0009Gooooo002Rooooo`;o00002?ooool00ol0003oooooooooo`05
ooooo`;o00006_ooool2o`0009Kooooo002Dooooo`;o00003?ooool2o`0000Sooooo00?o0000oooo
ooooool01Oooool2o`0000Wooooo0_l0000?ooooo`;o0000U_ooool0083ooooo0_l0000Booooo`;o
00005_ooool00ol0003oooooooooo`04ooooo`;o00002_ooool2o`0000oooooo0_l0000Eooooo`;o
00000oooool2o`0007[ooooo0020ooooo`;o00001_ooool2o`0002;ooooo0ol00004ooooo`;o0000
7?ooool2o`0001Cooooo0_l00003ooooo`;o0000N_ooool008Sooooo0_l0000:ooooo`;o00005_oo
ool00ol0003oooooooooo`0Rooooo`;o0000UOooool009Cooooo0_l0000Fooooo`03o`000?oooooo
oooo00oooooo0_l0000=ooooo`;o0000VOooool009Kooooo0_l00004ooooo`;o00003_ooool00ol0
003oooooooooo`0?ooooo`;o00003Oooool2o`0009Wooooo0020ooooo`;o00005?ooool2o`0000Co
oooo0_l0000>ooooo`03o`000?oooooooooo03[ooooo0_l0001mooooo`00P?ooool2o`0002[ooooo
00?o0000ooooooooool00oooool2o`0003Cooooo0ol0001mooooo`00Soooool2o`0001Oooooo0_l0
0002ooooo`03o`000?oooooooooo00?ooooo0_l00009ooooo`;o00003Oooool2o`0001[ooooo0_l0
001nooooo`00Soooool2o`0001Oooooo0_l00002ooooo`03o`000?oooooooooo00kooooo0_l0000=
ooooo`;o0000V_ooool00:Gooooo0_l00005ooooo`?o00007Oooool2o`0001Sooooo1?l0001noooo
o`00YOooool2o`0000Gooooo00?o0000ooooooooool07Oooool2o`0001Sooooo1?l0001nooooo`00
V?ooool2o`0000[ooooo0_l00006ooooo`03o`000?oooooooooo01_ooooo1?l0000Hooooo`;o0000
P?ooool008Wooooo0_l0000=ooooo`;o00002_ooool2o`0000Kooooo00Co0000ooooool0003o0000
6_ooool4o`0009[ooooo0029ooooo`;o00008Oooool00ol0003oooooo`000002o`000;Oooooo002A
ooooo`;o00006Oooool00ol0003oooooooooo`02o`0000Sooooo0_l0000>ooooo`?o0000W?ooool0
097ooooo0ol000000olb<S;ok^k^ooooo`04ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool02_ooool2o`0000kooooo0ol0002Looooo`00TOooool2o`00
0003oooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool02oooool2o`0002Oooooo0_l00023ooooo`00TOooool2o`0000;ooooo00?o410@oooooooo
ool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo0ol0000Wooooo`?o
0000P_ooool0097ooooo0ol000000ooooooo0000ooooo`02ooooo`;o00002_ooool00omgMgOo<S8b
ooooo`04ooooo`?o00002_ooool2o`0002Wooooo0_l00022ooooo`00TOooool3o`000003ooooool0
003ooooo00;ooooo0_l00007ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`0Kooooo`;o00005_ooool2o`0008Cooooo002Aooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00ol0003oooooooooo`07ooooo`;o00007?ooool2o`0001Kooooo0_l00024ooooo`00TOoo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool2o`0003Cooooo
0ol00023ooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo0_l00004ooooo`Co0000
1_ooool00ol0003oooooooooo`0Iooooo`;o00006?ooool3o`0008?ooooo002Looooo`;o00002_oo
ool2o`0000;ooooo00?o0000ooooooooool01Oooool2o`0001;ooooo0_l0000Dooooo`;o00000_oo
ool2o`0008Cooooo002Nooooo`;o00002?ooool2o`0000;ooooo00?o0000ooooooooool01Oooool2
o`00017ooooo0_l0000Eooooo`Ko0000Q?ooool009kooooo0_l00008ooooo`;o00000_ooool00ol0
003oooooooooo`05ooooo`;o00004Oooool2o`0001Kooooo0ol00026ooooo`00[?ooool3o`0000Go
oooo0_l0000Yooooo`?o0000Q_ooool00:cooooo00?o0000ooooooooool0<Oooool2o`0008Kooooo
002Vooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00004Oooool2o`0001Sooooo1?l0
0025ooooo`00YOooool3o`0000Cooooo00?o0000ooooooooool00oooool2o`00017ooooo0_l0000H
ooooo`Co0000QOooool00:Gooooo0_l00005ooooo`03o`000?oooooooooo037ooooo0_l00026oooo
o`00[?ooool01?l0003oooooooooooooool2o`0002Sooooo0_l0002<ooooo`00U_ooool2o`0001Co
oooo00Co0000oooooooooooooooo0_l0000Xooooo`;o0000S?ooool009Kooooo0_l0000Dooooo`03
o`000?oooooooooo02[ooooo0_l00003ooooo`;o0000R?ooool00:cooooo0ol0000@ooooo`;o0000
00?oooooo`000?l000005Oooool2o`0000?ooooo0_l00028ooooo`00SOooool2o`0001gooooo00?o
0000ooooooooool04?ooool2o`000003ooooool0003o000001Cooooo0_l0002>ooooo`00SOooool3
o`0001cooooo00?o0000ooooooooool0:?ooool3o`0008kooooo002>ooooo`;o00007?ooool00ol0
003oooooooooo`0Xooooo`;o0000Soooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
0ol0002iooooo`00S_ooool2o`0001cooooo0ol0000Vooooo`;o0000TOooool008kooooo0_l0000<
ooooo`;o00003_ooool00ol0003oooooooooo`0Vooooo`;o0000TOooool009cooooo0_l0000>oooo
o`?o0000^Oooool009gooooo0_l0000=ooooo`03o`000?oooooooooo02Sooooo0_l0002?ooooo`00
WOooool2o`0000gooooo00?o0000ooooooooool02_ooool2o`0001cooooo0_l0002?ooooo`00W?oo
ool2o`0000kooooo00?o0000ooooooooool02_ooool2o`000:gooooo002Looooo`;o00001oooool2
o`0000Gooooo00?o0000ooooooooool02_ooool3o`000:cooooo002Uooooo`;o00001Oooool00ol0
003oooooooooo`0:ooooo`?o00005oooool2o`0009?ooooo002Uooooo`Co00000oooool00ol0003o
ooooooooo`0Tooooo`;o0000Toooool00:Oooooo0_l00003ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo023ooooo1?l0002Eooooo`00[?ooool3o`00023ooooo1?l0002E
ooooo`00[?ooool00ol0003oooooooooo`0Rooooo`;o0000UOooool00:cooooo00?o0000oooooooo
ool08_ooool2o`0009Gooooo002/ooooo`03o`000?oooooooooo02;ooooo0_l0002Eooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B400ooooooo0000o`000003ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8b
omgMg@05ooooo`03o`000?oooooooooo023ooooo0_l0002Gooooo`00ROooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B400ooooooo0000o`000003ooooo`03oeEEEOnYZJWooooo00Oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Pooooo`;o0000Uoooool008Wooooo00Go
410@oooooooooooooooooa0@4006ooooo`;o00001Oooool00onYZJWoEEEEooooo`08ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool08?ooool2o`0009Oooooo0029ooooo`05o`000?oo
ooooooooooooool000001_ooool5o`0000?ooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8b
ooooo`04ooooo`?o00006_ooool2o`0009gooooo0029ooooo`05o`000?ooooooooooooooool00000
1oooool4o`0000?ooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool06_ooool2o`0009gooooo0029ooooo`05oa0@4?ooooooooooooooool@
41001oooool2o`0000Gooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0;Wooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413o
oooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2ioooo
o`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool00ol0
003oooooooooo`2iooooo`00Uoooool2o`0001?ooooo0_l0000Gooooo`;o0000XOooool009Oooooo
0_l0000Cooooo`;o00005oooool2o`000:7ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002X
ooooo`;o00000_ooool3o`000;Wooooo002Xooooo`;o00000_ooool00ol0003oooooooooo`2ioooo
o`00WOooool2o`0000[ooooo0_l000000ooooooo0000ooooo`2jooooo`00WOooool2o`0000[ooooo
0_l000000ooooooo0000ooooo`0Gooooo`;o0000XOooool00:cooooo00?o0000ooooooooool05_oo
ool2o`000:7ooooo002Xooooo`;o00000_ooool00ol0003oooooooooo`2iooooo`00Z?ooool2o`00
00;ooooo00?o0000ooooooooool0^Oooool00:7ooooo0_l00002ooooo`;o00001Oooool00ol0003o
ooooooooo`2iooooo`00XOooool2o`0000;ooooo0_l00005ooooo`?o0000^Oooool00:cooooo00?o
0000ooooooooool03oooool2o`000:Sooooo002/ooooo`03o`000?oooooooooo00oooooo0_l0002X
ooooo`00[?ooool00ol0003oooooooooo`0Aooooo`;o0000Y_ooool00:cooooo00?o0000oooooooo
ool03?ooool2o`0000?ooooo0_l0002Vooooo`00[?ooool00ol0003oooooooooo`0<ooooo`;o0000
Zoooool00:cooooo00?o0000ooooooooool03_ooool2o`000:Wooooo002/ooooo`03o`000?oooooo
oooo00kooooo0_l0002Yooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03
o`000?oooooooooo00Kooooo0_l0002aooooo`00[?ooool00ol0003oooooooooo`06ooooo`;o0000
/Oooool00:cooooo00?o0000ooooooooool01Oooool2o`000;;ooooo002Fooooo`;o00005?ooool3
o`0000Gooooo0_l0002booooo`00U_ooool2o`0001Cooooo00Co0000ooooool0003o0000^?ooool0
09Oooooo0_l0000Cooooo`04o`000?oooooo0000o`000;Sooooo002Gooooo`;o00004oooool00ol0
003oooooooooo`2iooooo`00V?ooool3o`00017ooooo00?o0000ooooooooool0^Oooool009Sooooo
0ol0000Aooooo`?o0000^Oooool009Sooooo0_l00008ooooo`Co000000?o410@ooooooooool00ooo
ool3o`000;Wooooo002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool0
0:Cooooo00?o0000ooooooooool01Oooool3o`000;Wooooo002Tooooo`03o`000?oooooooooo0<7o
oooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002T
ooooo`03o`000?oooooooooo0<7ooooo002Rooooo`03oeEEEOmVIVKo00000<?ooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Zooooo`04oa0@4?l0003o0000
o`000;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[o
oooo002[ooooo`06o`000?mgMgOo0000o`000?mEEEGok^k^]oooool00:_ooooo00Ko0000oeEEEOo^
k^koooooogMgMomEEEFgooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo
0;Gooooo002[ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0]Oooool00:_ooooo
00Ko0000oeEEEOo^k^koooooogMgMomVIVJgooooo`00Z_ooool00ol@413o0000ogMgM`02o`000003
ofIVI_o^k^kooooo0;Kooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.6438 .45554 Mdot
.64659 .59871 Mdot
.47189 .3646 Mdot
.43684 .31337 Mdot
.49431 .1949 Mdot
.56058 .22685 Mdot
.47572 .32654 Mdot
.72579 .43557 Mdot
.68962 .35407 Mdot
.56334 .53588 Mdot
.52903 .69941 Mdot
.72894 .52769 Mdot
.58698 .78752 Mdot
.55923 .59925 Mdot
.71419 .60162 Mdot
.51592 .29625 Mdot
.43737 .81098 Mdot
.58238 .7967 Mdot
.40939 .57857 Mdot
.37434 .48263 Mdot
.54549 .84836 Mdot
.61492 .70846 Mdot
.5791 .7794 Mdot
.56183 .82959 Mdot
.70079 .67572 Mdot
.59959 .46604 Mdot
.47659 .78621 Mdot
.40873 .54651 Mdot
.38487 .29784 Mdot
.6364 .63529 Mdot
.48494 .91945 Mdot
.68418 .32936 Mdot
.71861 .43477 Mdot
.39546 .45939 Mdot
.41133 .26431 Mdot
.37769 .45629 Mdot
.56661 .13607 Mdot
.42153 .67176 Mdot
.44013 .08009 Mdot
.73286 .52477 Mdot
.71625 .64027 Mdot
.39846 .37381 Mdot
.49653 .137 Mdot
.64737 .44417 Mdot
.63165 .38008 Mdot
.55853 .31219 Mdot
.54778 .63342 Mdot
.64745 .24768 Mdot
.58522 .64817 Mdot
.40025 .2044 Mdot
.64897 .25367 Mdot
.46162 .04907 Mdot
.41659 .02442 Mdot
.46637 .13131 Mdot
.44829 .14384 Mdot
.706 .39917 Mdot
.72733 .4565 Mdot
.45345 .84195 Mdot
.61247 .19458 Mdot
.6254 .35985 Mdot
.57227 .35332 Mdot
.62177 .85821 Mdot
.46106 .05777 Mdot
.51778 .66365 Mdot
.71661 .48148 Mdot
.69459 .35393 Mdot
.56225 .53436 Mdot
.51563 .30188 Mdot
.42995 .71887 Mdot
.53173 .87277 Mdot
.46075 .85641 Mdot
.52157 .46908 Mdot
.5583 .57308 Mdot
.56053 .46294 Mdot
.46119 .05777 Mdot
.50837 .5245 Mdot
.41742 .02242 Mdot
.59181 .4635 Mdot
.43669 .07975 Mdot
.56504 .68765 Mdot
.41178 .82242 Mdot
.63452 .63721 Mdot
.42921 .35801 Mdot
.39845 .36872 Mdot
.71525 .39836 Mdot
.50684 .26941 Mdot
.50172 .20515 Mdot
.54763 .29948 Mdot
.49068 .8481 Mdot
.52152 .31746 Mdot
.69468 .69065 Mdot
.37353 .77095 Mdot
.47729 .74554 Mdot
.54526 .28501 Mdot
.48679 .73678 Mdot
.40434 .92374 Mdot
.56027 .59142 Mdot
.66302 .29059 Mdot
.50448 .83358 Mdot
.64669 .49439 Mdot
.53058 .7867 Mdot
.72514 .54591 Mdot
.65073 .48198 Mdot
.46781 .92902 Mdot
.39752 .40425 Mdot
.42977 .79988 Mdot
.40654 .47836 Mdot
.47662 .74598 Mdot
.51846 .88906 Mdot
.56399 .55784 Mdot
.42509 .3781 Mdot
.68344 .33011 Mdot
.3778 .59103 Mdot
.60355 .06056 Mdot
.42791 .48799 Mdot
.58434 .40194 Mdot
.69619 .34135 Mdot
.68932 .32939 Mdot
.58028 .1613 Mdot
.58166 .79502 Mdot
.65811 .80021 Mdot
.53763 .85068 Mdot
.38347 .30694 Mdot
.52363 .88322 Mdot
.45791 .25811 Mdot
.37604 .45992 Mdot
.63818 .59879 Mdot
.4843 .29036 Mdot
.59547 .75258 Mdot
.64631 .53941 Mdot
.72562 .5707 Mdot
.55734 .21688 Mdot
.52206 .17034 Mdot
.40469 .17189 Mdot
.52115 .07494 Mdot
.38135 .34224 Mdot
.55813 .57082 Mdot
.72248 .48026 Mdot
.7167 .59806 Mdot
.53527 .96473 Mdot
.42678 .62839 Mdot
.42165 .68326 Mdot
.43956 .81664 Mdot
.37554 .55227 Mdot
.70856 .37614 Mdot
.66314 .12579 Mdot
.43141 .27013 Mdot
.55503 .31542 Mdot
.69108 .74299 Mdot
.5444 .7612 Mdot
.47392 .79532 Mdot
.56514 .82627 Mdot
.51804 .43607 Mdot
.60666 .32881 Mdot
.51544 .07302 Mdot
.45931 .0558 Mdot
.69922 .35766 Mdot
.57444 .14863 Mdot
.51651 .07312 Mdot
.60166 .54431 Mdot
.42678 .09906 Mdot
.73371 .58485 Mdot
.37953 .5737 Mdot
.51596 .16856 Mdot
.64414 .50554 Mdot
.70699 .37451 Mdot
.45481 .92317 Mdot
.43442 .73423 Mdot
.49205 .04474 Mdot
.39487 .24213 Mdot
.43652 .6699 Mdot
.44227 .75288 Mdot
.51856 .23867 Mdot
.43416 .25578 Mdot
.71925 .46327 Mdot
.41323 .94931 Mdot
.60471 .32548 Mdot
.4315 .43295 Mdot
.40184 .19198 Mdot
.46162 .04389 Mdot
.73071 .56186 Mdot
.54684 .38031 Mdot
.71431 .65001 Mdot
.52277 .38516 Mdot
.68905 .36026 Mdot
.43452 .99197 Mdot
.67462 .29759 Mdot
.73303 .58062 Mdot
.50351 .14343 Mdot
.67442 .76704 Mdot
.37594 .56867 Mdot
.52951 .61311 Mdot
.62124 .85415 Mdot
.72076 .41977 Mdot
.71376 .6685 Mdot
.72595 .55462 Mdot
.53905 .2738 Mdot
.36152 .66826 Mdot
.40917 .71829 Mdot
.43297 .57148 Mdot
.43139 .55199 Mdot
.52294 .49547 Mdot
.50255 .21141 Mdot
.35561 .54576 Mdot
.6451 .52904 Mdot
.53814 .52318 Mdot
.57863 .26076 Mdot
.41845 .45687 Mdot
.53098 .41074 Mdot
.53118 .69734 Mdot
.61227 .7327 Mdot
.59018 .44606 Mdot
.45143 .91959 Mdot
.54366 .37686 Mdot
.64401 .51763 Mdot
.58694 .43142 Mdot
.73141 .5954 Mdot
.51768 .35927 Mdot
.62535 .37559 Mdot
.73302 .49776 Mdot
.5813 .3876 Mdot
.63269 .23387 Mdot
.47286 .93229 Mdot
.39223 .71802 Mdot
.53864 .36748 Mdot
.45982 .19511 Mdot
.65409 .55537 Mdot
.44895 .71344 Mdot
.71451 .60222 Mdot
.66048 .80039 Mdot
.48603 .24269 Mdot
.44061 .55843 Mdot
.35692 .42257 Mdot
.5451 .74903 Mdot
.49496 .77437 Mdot
.66111 .79148 Mdot
.4329 .72543 Mdot
.65228 .49854 Mdot
.56188 .81807 Mdot
.64704 .52359 Mdot
.61556 .86555 Mdot
.52744 .17326 Mdot
.43063 .88907 Mdot
.46135 .85675 Mdot
.68117 .31421 Mdot
.48615 .73423 Mdot
.52946 .09439 Mdot
.47509 .84681 Mdot
.46617 .85958 Mdot
.45512 .06087 Mdot
.71267 .66703 Mdot
.42802 .4931 Mdot
.5226 .63648 Mdot
.55267 .12373 Mdot
.59904 .50543 Mdot
.4453 .75899 Mdot
.44727 .14059 Mdot
.507 .54909 Mdot
.72507 .4613 Mdot
.6312 .22122 Mdot
.56932 .69527 Mdot
.49642 .77221 Mdot
.38717 .67798 Mdot
.45397 .3105 Mdot
.5381 .76973 Mdot
.63978 .44259 Mdot
.53661 .66958 Mdot
.5616 .23828 Mdot
.38391 .33737 Mdot
.59437 .57143 Mdot
.37637 .49043 Mdot
.45374 .13462 Mdot
.56524 .51469 Mdot
.56767 .68982 Mdot
.50484 .0602 Mdot
.54833 .38204 Mdot
.41947 .31074 Mdot
.65809 .27191 Mdot
.54261 .66762 Mdot
.59617 .29914 Mdot
.40992 .15497 Mdot
.47092 .28106 Mdot
.557 .44981 Mdot
.57857 .15566 Mdot
.7265 .52307 Mdot
.40649 .47007 Mdot
.50573 .37863 Mdot
.48883 .19988 Mdot
.39356 .75327 Mdot
.55946 .32327 Mdot
.42188 .85449 Mdot
.42958 .98253 Mdot
.61404 .20135 Mdot
.71949 .56646 Mdot
.62623 .22602 Mdot
.44125 .41815 Mdot
.58529 .1534 Mdot
.62143 .84862 Mdot
.41428 .84875 Mdot
.71579 .59067 Mdot
.68917 .1575 Mdot
.5807 .65241 Mdot
.48159 .11796 Mdot
.64782 .53808 Mdot
.68292 .32161 Mdot
.7113 .64789 Mdot
.54591 .64443 Mdot
.65984 .2788 Mdot
.5997 .51722 Mdot
.45148 .66704 Mdot
.60567 .74289 Mdot
.43023 .79345 Mdot
.58038 .79413 Mdot
.69484 .73174 Mdot
.43226 .41151 Mdot
.63161 .40067 Mdot
.39747 .39886 Mdot
.71815 .49827 Mdot
.44955 .31853 Mdot
.72864 .57454 Mdot
.66061 .77943 Mdot
.53432 .97175 Mdot
.48053 .24352 Mdot
.55298 .20692 Mdot
.39679 .38491 Mdot
.48451 .05356 Mdot
.45113 .20369 Mdot
.44803 .66327 Mdot
.45576 .35072 Mdot
.43685 .81702 Mdot
.73116 .47348 Mdot
.5569 .13184 Mdot
.49443 .72719 Mdot
.61567 .71774 Mdot
.48605 .29003 Mdot
.52288 .50436 Mdot
.65306 .56457 Mdot
.54898 .20639 Mdot
.51625 .16872 Mdot
.60105 .54818 Mdot
.49688 .20355 Mdot
.38415 .14112 Mdot
.59689 .53939 Mdot
.63337 .63162 Mdot
.51021 .68356 Mdot
.71362 .42551 Mdot
.48335 .78251 Mdot
.38012 .36164 Mdot
.61706 .69051 Mdot
.45092 .72514 Mdot
.57829 .39496 Mdot
.54218 .9576 Mdot
.73028 .51318 Mdot
.57384 .13544 Mdot
.37792 .43533 Mdot
.59068 .61608 Mdot
.40483 .6837 Mdot
.38719 .29763 Mdot
.5428 .75756 Mdot
.72979 .51539 Mdot
.54555 .96328 Mdot
.42528 .87663 Mdot
.72477 .5713 Mdot
.72758 .58292 Mdot
.72344 .62611 Mdot
.52006 .562 Mdot
.55619 .72348 Mdot
.71467 .60582 Mdot
.72597 .45597 Mdot
.51822 .57788 Mdot
.44957 .91042 Mdot
.59191 .56792 Mdot
.57437 .24901 Mdot
.646 .48354 Mdot
.67072 .30782 Mdot
.65182 .49946 Mdot
.58006 .15152 Mdot
.53232 .10293 Mdot
.58227 .7721 Mdot
.5548 .1109 Mdot
.59522 .75063 Mdot
.70792 .64956 Mdot
.62315 .07946 Mdot
.59863 .18805 Mdot
.60713 .32389 Mdot
.51742 .44231 Mdot
.68215 .73512 Mdot
.50688 .82737 Mdot
.45183 .36327 Mdot
.73246 .56047 Mdot
.52764 .87849 Mdot
.45498 .68282 Mdot
.56223 .48953 Mdot
.59481 .44523 Mdot
.48182 .7877 Mdot
.65196 .25392 Mdot
.48712 .93271 Mdot
.61784 .85671 Mdot
.73047 .56729 Mdot
.40447 .66912 Mdot
.38384 .14786 Mdot
.40289 .662 Mdot
.4271 .28268 Mdot
.43225 .25709 Mdot
.47096 .65923 Mdot
.72958 .47391 Mdot
.72857 .52567 Mdot
.48099 .78488 Mdot
.44205 .6978 Mdot
.52172 .72889 Mdot
.52601 .31359 Mdot
.70081 .71007 Mdot
.53285 .25695 Mdot
.38267 .63566 Mdot
.41952 .52939 Mdot
.46504 .79164 Mdot
.46134 .29522 Mdot
.52047 .23602 Mdot
.39526 .51256 Mdot
.4929 .78164 Mdot
.5375 .54088 Mdot
.67469 .77269 Mdot
.72238 .47365 Mdot
.44724 .50746 Mdot
.41787 .23118 Mdot
.42877 .79668 Mdot
.62239 .38299 Mdot
.5892 .58991 Mdot
.44235 .75554 Mdot
.68737 .72785 Mdot
.39653 .90005 Mdot
.65091 .52937 Mdot
.55688 .01448 Mdot
.6498 .45247 Mdot
.53787 .55404 Mdot
.69836 .39288 Mdot
.71213 .61779 Mdot
.51604 .72878 Mdot
.61137 .70251 Mdot
.39277 .10169 Mdot
.43425 .66656 Mdot
.4695 .69938 Mdot
.45098 .2141 Mdot
.39272 .72633 Mdot
.57796 .64863 Mdot
.3662 .71502 Mdot
.52829 .40561 Mdot
.44599 .15581 Mdot
.39397 .44828 Mdot
.50818 .69501 Mdot
.43501 .39271 Mdot
.55615 .4193 Mdot
.72605 .44026 Mdot
.43478 .38456 Mdot
.41911 .12126 Mdot
.65038 .56838 Mdot
.63315 .39583 Mdot
.37599 .48672 Mdot
.43549 .88622 Mdot
.41803 .75031 Mdot
.56285 .4981 Mdot
.73178 .47687 Mdot
.71609 .65886 Mdot
.53186 .68179 Mdot
.58066 .14581 Mdot
.59157 .58211 Mdot
.43919 .81092 Mdot
.37833 .38865 Mdot
.64729 .48857 Mdot
.40707 .50754 Mdot
.57842 .39379 Mdot
.39472 .50535 Mdot
.64237 .83269 Mdot
.532 .18891 Mdot
.50915 .48771 Mdot
.49609 .13956 Mdot
.56761 .68357 Mdot
.52309 .53442 Mdot
.49919 .26709 Mdot
.45735 .13771 Mdot
.50533 .14461 Mdot
.42946 .5327 Mdot
.5974 .4942 Mdot
.69581 .35779 Mdot
.48078 .18332 Mdot
.6366 .42762 Mdot
.43968 .75718 Mdot
.40904 .46528 Mdot
.50757 .63343 Mdot
.58382 .03814 Mdot
.49992 .6595 Mdot
.65011 .58163 Mdot
.64402 .26022 Mdot
.3794 .57742 Mdot
.42377 .69124 Mdot
.38801 .27717 Mdot
.73035 .54972 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo00oooooo0_l0002Xooooo`00[?ooool00ol0003oooooooooo`0?ooooo`;o
0000Z?ooool0093ooooo0_l0000Jooooo`03o`000?oooooooooo0;Wooooo002@ooooo`;o00006_oo
ool3o`000;Wooooo002@ooooo`;o00006_ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool00ol0003oooooooooo`0Hooooo`;o0000Woooool009oooooo0_l0000;
ooooo`03o`000?oooooooooo01Sooooo0_l0002Oooooo`00Woooool2o`0000Sooooo0_l000000ooo
oooo0000ooooo`2jooooo`00Woooool2o`0000Sooooo0_l000000ooooooo0000ooooo`2jooooo`00
Woooool2o`0000_ooooo0ol0002iooooo`00W_ooool2o`0000Kooooo0_l00004ooooo`03o`000?oo
oooooooo0;Wooooo002Nooooo`?o00001Oooool2o`0000Cooooo00?o0000ooooooooool0^Oooool0
09gooooo1?l0000;ooooo`?o00007oooool2o`0009Sooooo002Mooooo`;o00003Oooool3o`0001oo
oooo0_l0002Hooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`02ooooo`;o0000]Oooool00:cooooo0ol00002oooo
o`Co0000/oooool009Oooooo0ol0000Booooo`03o`000?oooooooooo00Cooooo0_l0000Oooooo`;o
0000T_ooool009Oooooo0ol0000Booooo`03o`000?oooooooooo02Gooooo0_l0002Booooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`06ooooo`;o0000/Oooool00:cooooo
00?o0000ooooooooool01_ooool2o`000;7ooooo002Cooooo`;o00005oooool3o`000;Wooooo0028
ooooo`;o00002Oooool2o`0001Oooooo00?o0000ooooooooool01oooool2o`000;3ooooo0028oooo
o`;o00008_ooool00ol0003oooooooooo`07ooooo`;o0000/?ooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool03oooool2o`000:Sooooo002/ooooo`03o`000?oo
oooooooo00oooooo0_l0002Xooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B46ooooo`03o`000?o^k^kooooo00Cooooo00?oA4A4o`000?l000000_l00005ooooo`03o`000?oo
oooooooo0;Wooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool2o`0000;o8B4Q1_oo
ool00omEEEGoZJVYooooo`07ooooo`;o00001Oooool00ol0003oooooooooo`2iooooo`00POooool6
o`0000;ooooo00Go410@oooooooooooooooooa0@4003ooooo`;o00002?ooool00onYZJWoEEEEoooo
o`08ooooo`03o`000?oooooooooo00?ooooo0ol0000>ooooo`;o00008_ooool2o`0008Gooooo0029
ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool03_ooool2o`0002;ooooo0_l00025ooooo`00ROooool0
1Ol0003ooooooooooooooooo000000kooooo00CoEEEEolc<c?oooooooooo0ol000001?lQ8B7o0000
oc8b<_o<c<`5ooooo`03o`000?oooooooooo00oooooo0_l0002Xooooo`00ROooool01Ol@413ooooo
oooooooooooo410@00kooooo0_l00002ooooo`?o00002Oooool00ol0003oooooooooo`0?ooooo`;o
0000Z?ooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03oa0@4?oooooooooo00?o
00000oooool00ol0003oooooooooo`05ooooo`?o00005Oooool4o`000:;ooooo0029ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool6o`0000?ooooo1?l00004ooooo`?o00005Oooool4o`000:;o
oooo0025ooooo`;o00004oooool2o`0000kooooo1Ol0002iooooo`00QOooool2o`0001?ooooo0_l0
000@ooooo`?o00005oooool2o`000:3ooooo0025ooooo`;o00009Oooool3o`0001Gooooo1?l0002P
ooooo`00QOooool2o`0002Gooooo0ol0000Eooooo`Co0000X?ooool008kooooo0_l0000:ooooo`;o
00004?ooool00ol0003oooooooooo`0Gooooo`Co0000W_ooool008kooooo0_l0000:ooooo`;o0000
4?ooool00ol0003oooooooooo`0Gooooo`Co00008?ooool2o`0007cooooo002/ooooo`03o`000?oo
oooooooo01Oooooo0_l0000Rooooo`;o0000O?ooool00:cooooo00?o0000ooooooooool05oooool2
o`000:3ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00;o
oooo1?l0002cooooo`00S?ooool2o`0001kooooo00?o0000ooooooooool00_ooool6o`000;7ooooo
002<ooooo`;o00007_ooool3o`0000Kooooo0_l0002aooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00YOooool2o`0000Gooooo00?o0000ooooooooool0^Oooool00:Gooooo0_l00005ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00Oooooo0_l0000Dooooo`;o0000
V_ooool008_ooooo0_l0000Oooooo`03o`000?oooooooooo00Oooooo0_l0000Dooooo`;o0000V_oo
ool008_ooooo0_l0000Aooooo`;o00002_ooool3o`0002Cooooo0_l0002Eooooo`00W_ooool2o`00
00[ooooo0ol0000Tooooo`;o0000UOooool00:Sooooo0_l00002ooooo`?o00008_ooool2o`0009Go
oooo002;ooooo`;o00003_ooool2o`0000_ooooo0_l000000ooooooo0000o`00000Tooooo`;o0000
UOooool008_ooooo0_l0000>ooooo`;o00003_ooool3o`0000kooooo0ol0002Yooooo`00[?ooool2
o`0000kooooo0ol0002Yooooo`00[?ooool2o`000;[ooooo002Kooooo`;o00003oooool2o`000;[o
oooo002Kooooo`;o00003oooool00ol0003oooooooooo`0?ooooo`;o0000Z?ooool00:cooooo00?o
0000ooooooooool03oooool2o`0001Oooooo0_l0002?ooooo`00[?ooool3o`0002Sooooo0_l0002?
ooooo`00[?ooool00ol0003oooooooooo`0Aooooo`;o00004oooool2o`00097ooooo002@ooooo`;o
00006_ooool00ol0003oooooooooo`0Aooooo`;o00004oooool2o`00097ooooo002@ooooo`;o0000
6_ooool00ol0003oooooooooo`0Xooooo`;o0000Soooool00:cooooo00?o0000ooooooooool00ooo
ool2o`0002?ooooo0_l0002?ooooo`00[?ooool00ol0003oooooooooo`03ooooo`;o00003?ooool2
o`000:Kooooo0029ooooo`;o00001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45
ooooo`03odA4A?l0003o000000Co00000oooool00ol0003oooooooooo`03ooooo`;o00003?ooool2
o`000:Kooooo0029ooooo`;o00001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`Co00000oooool00ol0003oooooooooo`2iooooo`00ROooool6o`0000;ooooo00Go410@oooo
oooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05Oooool2
o`0001Kooooo0_l0002:ooooo`00TOooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMg
oc8b<_ooool01?ooool3o`0001Gooooo0_l0000Fooooo`;o0000R_ooool0097ooooo00Co0000oooo
oooooooooooo0ol0000:ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`0^ooooo`?o0000R?ooool0097ooooo00Co410@oooooooooooooooo0ol00006ooooo`;o00000_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo0_l0000Uooooo`?o0000R?oo
ool0097ooooo00CoMgMgoiRHV?ooooooV9RH0_l00007ooooo`;o00000_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo0_l0000>ooooo`;o00004oooool2o`0008_ooooo002>
ooooo`;o000000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`Co00001_ooool00ol0003ooooo
ooooo`0Gooooo`;o00004oooool2o`0008_ooooo002>ooooo`;o00006oooool2o`000;_ooooo002E
ooooo`;o00005?ooool2o`000003ooooool0003o00000;Sooooo002Eooooo`;o00005Oooool01?l0
003oooooo`000?l00008ooooo`;o00009_ooool2o`0008Kooooo0027ooooo`;o00008oooool3o`00
00Wooooo0_l0000Vooooo`;o0000Q_ooool008Oooooo0_l0000Sooooo`03o`000?oooooooooo037o
oooo0_l00026ooooo`00Toooool2o`0000gooooo0_l00008ooooo`03o`000?oooooooooo037ooooo
0_l00026ooooo`00Toooool2o`0000gooooo0_l00008ooooo`03o`000?oooooooooo00cooooo0_l0
002[ooooo`00[?ooool00ol0003oooooooooo`0<ooooo`;o0000Zoooool00:Kooooo0ol00003oooo
o`03o`000?oooooooooo03;ooooo0_l00025ooooo`00Woooool2o`0000Gooooo0ol00003ooooo`03
o`000?oooooooooo03;ooooo0_l00025ooooo`00Q_ooool2o`0001Oooooo0_l0000;ooooo`03o`00
0?oooooooooo00;ooooo0_l0000booooo`;o0000POooool008Kooooo0_l0000Tooooo`?o00000_oo
ool2o`0000Sooooo0_l0000>ooooo`;o00006?ooool2o`00087ooooo002/ooooo`03o`000?oooooo
oooo00;ooooo0_l00008ooooo`;o00003_ooool2o`0009_ooooo0025ooooo`;o00009Oooool00ol0
003oooooooooo`02ooooo`;o0000]Oooool008Gooooo0_l0000Eooooo`;o00003_ooool00ol0003o
ooooooooo`0eooooo`;o0000P_ooool0097ooooo0_l00004ooooo`;o00000oooool2o`0000kooooo
00?o0000ooooooooool01Oooool2o`0000Wooooo0_l0000Sooooo`;o0000P_ooool0097ooooo0_l0
0004ooooo`;o00004oooool00ol0003oooooooooo`05ooooo`;o00002?ooool3o`0002Kooooo0_l0
001oooooo`00Voooool2o`0000oooooo00?o0000ooooooooool01?ooool2o`0000Wooooo0_l0000W
ooooo`;o0000Ooooool009_ooooo0_l0000?ooooo`03o`000?oooooooooo00Cooooo0_l0000coooo
o`;o0000O_ooool00:cooooo0ol0000@ooooo`;o00003Oooool3o`0001Oooooo0_l0001nooooo`00
Y?ooool2o`0000Kooooo00?o0000ooooooooool04?ooool2o`0000gooooo0ol0002Gooooo`00Y?oo
ool2o`0000Kooooo00?o0000ooooooooool08?ooool2o`0001Oooooo1?l0001looooo`00[?ooool0
0ol0003oooooooooo`0iooooo`Co0000O?ooool008Gooooo0_l0000Uooooo`03o`000?oooooooooo
0;Wooooo0025ooooo`;o00009Oooool00ol0003oooooooooo`2iooooo`00Q?ooool2o`0002Kooooo
00?o0000ooooooooool0?Oooool2o`0007[ooooo0024ooooo`;o00009_ooool00ol0003ooooooooo
o`0mooooo`;o0000N_ooool00:cooooo00?o0000ooooooooool0^Oooool009gooooo0_l0000=oooo
o`?o0000^Oooool009gooooo0_l0000=ooooo`03o`000?oooooooooo01Cooooo0_l0000Uooooo`Co
0000N_ooool009Cooooo0_l0000Fooooo`03o`000?oooooooooo01Cooooo0_l0000Uooooo`Go0000
NOooool008Cooooo0_l0000>ooooo`;o00005_ooool00ol0003oooooooooo`02ooooo`;o00008_oo
ool2o`0001?ooooo1Ol0001iooooo`00Q?ooool2o`0001Kooooo0_l00004ooooo`;o00002?ooool0
0ol0003oooooooooo`02ooooo`;o00008_ooool2o`0001?ooooo0_l0001looooo`00ROooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool3o`000003oc8b<_oMgMgo
oooo00Cooooo00?o0000ooooooooool02Oooool2o`000:kooooo0029ooooo`05ogMgMol0003o0000
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool02Oooool2o`000:kooooo0021ooooo`Ko00000_ooool0
1Ol@413o0000o`000?oooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`?o000000?oooooo`000?ooool03?ooool0
0onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000;ooooo`;o00006Oooool2
o`0001Wooooo0_l0001fooooo`00ROooool01Ol0003ooooooooooooooooo000000Gooooo0_l00007
ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`?o00002ooo
ool3o`0001Sooooo1?l0000Gooooo`;o0000M_ooool008Wooooo00Go410@oooooooooooooooooa0@
4005ooooo`;o00002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo0ol0
000<ooooo`?o00005_ooool2o`000003ooooool0003o000008oooooo0029ooooo`;o000000?ooooo
oiRHV?mgMgL02?ooool2o`000006ooooool0003o^[ZjoooooonHV9So410@1?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`;o00005_ooool2o`0009;ooooo
0023ooooo`;o00001?ooool3o`000003oc8b<_o^k^kooooo00Oooooo0_l000001_ooooooV9RHoa0@
4?l0003o8B4Qolc<c0Cooooo1?l00006ooooo`03o`000?oooooooooo00Cooooo0_l0000Aooooo`;o
0000X?ooool008?ooooo0_l0000Wooooo`03o`000?oooooooooo01Oooooo0_l0002Pooooo`00U_oo
ool2o`0001Cooooo00?o0000ooooooooool05_ooool2o`0002Kooooo0_l0001iooooo`00U_ooool2
o`0001Cooooo00?o0000ooooooooool05_ooool2o`00017ooooo0_l0000Cooooo`;o00001?ooool2
o`0007?ooooo002:ooooo`;o00008?ooool3o`0002Sooooo0ol0000Fooooo`;o000000?oooooo`00
0?l00000Loooool008[ooooo0_l0000Pooooo`03o`000?oooooooooo01Sooooo0_l0000>ooooo`;o
00005oooool2o`0007Kooooo002:ooooo`;o00008?ooool00ol0003oooooooooo`06ooooo`;o0000
4?ooool2o`0009oooooo002/ooooo`03o`000?oooooooooo00Kooooo0_l0002aooooo`00UOooool2
o`0001Gooooo00?o0000ooooooooool01oooool2o`000;3ooooo002Eooooo`;o00005Oooool00ol0
003oooooooooo`07ooooo`;o0000/?ooool009Sooooo0_l0000Booooo`03o`000?oooooooooo00oo
oooo0_l0002Xooooo`00O?ooool2o`0001[ooooo0_l0000Booooo`03o`000?oooooooooo00oooooo
0_l0000dooooo`;o0000L_ooool007cooooo0_l0000^ooooo`?o0000@oooool4o`0007;ooooo002/
ooooo`03o`000?oooooooooo02[ooooo0_l0000Gooooo`;o0000M?ooool00:cooooo00?o0000oooo
ooooool06Oooool2o`0000oooooo0_l0002=ooooo`00UOooool2o`0001Gooooo00?o0000oooooooo
ool06Oooool2o`0002[ooooo0_l0001booooo`00Poooool2o`00013ooooo0_l0000Eooooo`03o`00
0?oooooooooo00?ooooo0_l00010ooooo`Co0000L?ooool008?ooooo0_l0000Wooooo`03o`000?oo
oooooooo00?ooooo0_l00012ooooo`;o0000L?ooool00:cooooo00?o0000ooooooooool00_ooool2
o`0002Oooooo0_l0000Jooooo`;o0000L?ooool00:cooooo00?o0000ooooooooool00_ooool2o`00
01Kooooo1?l0000=ooooo`Co0000R_ooool008Wooooo0_l0000Qooooo`03o`000?oooooooooo00oo
oooo0_l00009ooooo`Co00003oooool2o`0008[ooooo0029ooooo`;o00008Oooool3o`0000oooooo
0_l0000Mooooo`;o0000ROooool00:cooooo00?o0000ooooooooool0;?ooool4o`0001Oooooo0_l0
001`ooooo`00Poooool2o`0000cooooo0_l0000Iooooo`03o`000?oooooooooo02cooooo0_l0000I
ooooo`?o0000Koooool000Wooooo1?l000000ol@413oooooooooo`0Fooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03ob4Q8Ol0003o0000
00?ooooo1Ol00004ooooo`?o000000?o<S8bomgMgOooool05Oooool00ol0003oooooooooo`0Hoooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o
0000oc8b<_oMgMd03oooool00oo^k^ko<S8bo`000002o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0
003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03
o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`Co000000?o410@oooo
ooooool04_ooool000_ooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool03_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`03ob4Q8Ol0003o000000?ooooo00GoV9RHo`000?l0003ooooo
odA4A007ooooo`03ogMgMolb<S;ooooo01Gooooo00?o0000ooooooooool04Oooool2o`0000Gooooo
00?oMgMgoiRHV?ooool00_l00005ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oo
oooo00?oMgMgoc8b<_ooool03_ooool4o`000003ogMgMooooooooooo00?ooooo0_lQ8B48ooooo`03
ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omE
EEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo01Wooooo00?o0000ooooooooool05?ooool000Ko
00001Oooool00ol0003oooooooooo`0@ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@
00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`05ooooo`Ko00000_ooool01Ol@
413ooooooooooooooooo410@013ooooo00?o0000ooooooooool01Oooool6o`0000;ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00;ooooo0_l00005ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool04Oooool2o`0000Gooooo00?o410@ooooooooool01?l0
000:ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool03Oooool2o`0000;ooooo00?o
410@ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`05oa0@4?ooooooooooooooool@4100
3Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
5?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000kooooo
00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool0
00003oooool00omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003Oooool00onH
V9So8B4Qonk^kP03o`0000Cooooo00?oMgMgoc8b<_ooool05Oooool00ol0003oooooooooo`04oooo
o`;o00004_ooool01?l0003oooooooooooooool3o`0000_ooooo00?oV9RHob4Q8Oo^k^h01oooool0
0omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8boooo
o`0>ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMg
Molb<S;ooooo01Wooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?oo
ool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000kooooo00CoMgMgofIVI_l0003o0000
0_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Kooooo00?o0000ooooooooool01?ooool2o`0001;o
oooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c00?ooooo`Ko00002oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go
0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c00Jooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo
00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000oooooooo
ool04Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04Oooool01Ol@
413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0H
ooooo`?o00006?ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0Aooooo`03oa0@4?l0003o000000?o00002oooool00ol0003ooooooooo
o`0Aooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03
o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo
017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41000_l0
0002ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo017o
oooo00CoMgMgo`000?l0003oV9RH0_l0000;ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo01Cooooo0009ooooo`03oeEEEOmVIVKo000001[ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_l00004ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`00_l00002ooooo`Co00005oooool00ol0003oooooooooo`0Hoooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01_nHV9So410@o`000?lQ8B7oc<c<ooooo`;o0000
00?oooooo`000?l000000_l0000?ooooo`Co000000?o<S8bonk^k_ooool02oooool4o`00013ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0001Wooooo00?oEEEEofIVI_l0
00005_ooool008;ooooo0_l0000Xooooo`03o`000?oooooooooo02gooooo0ol0000Dooooo`;o0000
Loooool008?ooooo0_l0000?ooooo`;o00005_ooool00ol0003oooooooooo`02o`0002_ooooo0_l0
002:ooooo`00Poooool2o`0000oooooo0_l0000Fooooo`03o`000?oooooooooo00;o00003oooool2
o`0001[ooooo0_l0001oooooo`;o00000_ooool2o`0000Gooooo0023ooooo`;o00003oooool2o`00
01Kooooo00?o0000ooooooooool04Oooool2o`0000[ooooo0_l0000>ooooo`;o0000Ooooool01_o^
k^ko8B4QohN7Qonj^[[o0000omgMg@Gooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`04
ooooo`;o00002oooool2o`0000[ooooo0_l0000>ooooo`;o00005_ooool2o`0000;ooooo0_l0001T
ooooo`04omgMgOl0003o410@olc<c0Kooooo0007oooooooo0000C?l0000<ooooo`04onk^k_lQ8B7o
410@onk^kPKooooo0007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`04ooooo`?o00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`;o00001_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00Co8B4QogMgMomgMgOo<S8b1_oo
ool000Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool00oooool2o`0000;ooooo0_l0000;ooooo`;o00004?ooool0
0ol0003oooooooooo`04ooooo`;o00005oooool2o`0000Sooooo00?o0000ooooooooool00_ooool2
o`0002;ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo00Wooooo0_l00002ooooo`;o00001Oooool008Wooooo0_l00002ooooo`;o00002oooool2o`00
013ooooo00?o0000ooooooooool07Oooool2o`0000gooooo0_l0002;ooooo`00ROooool2o`00027o
oooo00?o0000ooooooooool0BOooool2o`0006kooooo0029ooooo`;o00008Oooool00ol0003ooooo
ooooo`0Booooo`;o0000=?ooool3o`0006kooooo002/ooooo`03o`000?oooooooooo01;ooooo0_l0
0009ooooo`;o00003Oooool2o`0001[ooooo0_l0001_ooooo`00[?ooool00ol0003oooooooooo`0M
ooooo`;o00003Oooool2o`0008_ooooo002/ooooo`Co00002?ooool2o`0002;ooooo0_l0000Hoooo
o`Co0000K_ooool00:cooooo00Co0000ooooool0003o00002?ooool2o`0002;ooooo0_l0000Hoooo
o`Co0000K_ooool0097ooooo0_l0000Iooooo`03o`000?oooooooooo02cooooo1?l0000Hooooo`;o
0000Koooool0097ooooo0_l000000ooooooo0000o`00000Fooooo`03o`000?oooooooooo00Cooooo
0_l0000;ooooo`;o00006Oooool4o`0008Wooooo002Dooooo`;o00005_ooool00ol0003ooooooooo
o`04ooooo`;o00002oooool2o`000:Kooooo002/ooooo`03o`000?oooooooooo00Wooooo0_l00006
ooooo`;o00002_ooool2o`0000kooooo0_l0002:ooooo`00[?ooool00ol0003oooooooooo`09oooo
o`;o00004_ooool2o`0000kooooo0_l0002:ooooo`00O?ooool2o`0000oooooo0_l0000Mooooo`03
o`000?oooooooooo01kooooo0_l0000Wooooo`;o0000L?ooool007cooooo0_l0000?ooooo`;o0000
7Oooool01?l0003oooooo`000?l0000Mooooo`;o00009oooool4o`0006kooooo0022ooooo`;o0000
4Oooool2o`0001Gooooo1?l0000Mooooo`;o0000:Oooool2o`0006kooooo0022ooooo`;o00004Ooo
ool2o`0001Gooooo00?o0000ooooooooool02Oooool2o`0002Cooooo0_l0000Fooooo`;o0000L?oo
ool009Sooooo0_l0000Booooo`03o`000?oooooooooo00Wooooo0_l00007ooooo`;o00006oooool2
o`0001Kooooo0_l0001`ooooo`00V?ooool2o`0001;ooooo00?o0000ooooooooool00oooool2o`00
00gooooo0_l0000eooooo`;o0000K_ooool00:cooooo00?o0000ooooooooool00oooool2o`0002[o
oooo0_l0000Hooooo`;o0000K_ooool00:cooooo00?o0000ooooooooool06oooool2o`0001;ooooo
0_l0000Dooooo`;o00000_ooool2o`0006kooooo0023ooooo`;o00009oooool00ol0003ooooooooo
o`0@ooooo`;o00002Oooool2o`00017ooooo0_l0000Eooooo`Ko0000K_ooool008?ooooo0ol0000?
ooooo`;o00005Oooool00ol0003oooooooooo`0@ooooo`;o00002_ooool2o`00013ooooo0_l0000G
ooooo`;o0000L?ooool008Cooooo0_l0000?ooooo`;o00005Oooool3o`00013ooooo0_l0000:oooo
o`;o0000:Oooool3o`0006oooooo0024ooooo`;o00002?ooool2o`0001cooooo00?o0000oooooooo
ool00oooool2o`0004?ooooo0_l0001_ooooo`00Q?ooool2o`0000Sooooo0_l0000Looooo`03o`00
0?oooooooooo00?ooooo0_l0000Fooooo`;o00004Oooool2o`0001Sooooo0ol0001^ooooo`00[?oo
ool00ol0003oooooooooo`0Kooooo`;o00004Oooool2o`0001Sooooo1?l0001]ooooo`00[?ooool0
0ol0003oooooooooo`1:ooooo`;o0000KOooool008?ooooo0_l0000Wooooo`03o`000?oooooooooo
013ooooo0_l00008ooooo`;o0000:?ooool2o`0007?ooooo0023ooooo`;o00009oooool00ol0003o
ooooooooo`0@ooooo`;o00002?ooool2o`0002Sooooo0_l00003ooooo`;o0000K_ooool00:cooooo
00?o0000ooooooooool0A?ooool2o`0000?ooooo0_l0001^ooooo`00[?ooool3o`00013ooooo0_l0
000Hooooo`;o000000?oooooo`000?l000005Oooool2o`0007?ooooo002/ooooo`03o`000?oooooo
oooo013ooooo0_l0000Hooooo`;o000000?oooooo`000?l000005?ooool2o`0007Cooooo002/oooo
o`03o`000?oooooooooo04?ooooo0_l0001dooooo`00[?ooool00ol0003oooooooooo`13ooooo`;o
0000M?ooool00:cooooo00?o0000ooooooooool01_ooool2o`000;7ooooo002/ooooo`03o`000?oo
oooooooo00Kooooo0_l0000Booooo`;o0000WOooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`00
0?oooooooooo01[ooooo0_l0000Wooooo`;o0000M?ooool008Wooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`13ooooo`;o0000M?ooool008Wooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`000;Wo
oooo0029ooooo`05o`000?ooooooooooooooool000001Oooool2o`0000Kooooo00?oV9RHob4Q8Oo^
k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo04Kooooo0_l0001aooooo`00
ROooool01Ol0003ooooooooooooooooo000000Gooooo0_l00007ooooo`03ogMgMomVIVKooooo00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo02Wooooo0_l0000Koooo
o`;o0000LOooool008Wooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01oooool01?l0003oooooo`000?l0000;ooooo`;o00006oooool2
o`0008kooooo0025ooooo`;o00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000
okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00Co0000ooooool0003o0000
0oooool2o`0000Kooooo0_l0000Kooooo`?o0000SOooool008Gooooo0_l00002ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03
o`000?oooooooooo00Cooooo0_l0000Sooooo`?o00006?ooool2o`0007?ooooo002/ooooo`03o`00
0?oooooooooo04Cooooo0_l0001cooooo`00[?ooool00ol0003oooooooooo`0<ooooo`;o0000Zooo
ool00:cooooo00?o0000ooooooooool03?ooool2o`0000Sooooo0_l000000ooooooo0000o`00000V
ooooo`?o0000MOooool00:cooooo0ol0000Fooooo`Go00009_ooool4o`0007Cooooo002/ooooo`03
o`000?oooooooooo01Oooooo0_l0000Zooooo`;o0000M?ooool00:cooooo00?o0000ooooooooool0
A?ooool2o`0007?ooooo002<ooooo`;o00005?ooool2o`0000Sooooo0_l00015ooooo`;o0000Looo
ool008cooooo0_l0000<ooooo`;o00001_ooool2o`0000Sooooo0_l00003ooooo`;o0000]Oooool0
09Kooooo0_l00002ooooo`Co00003_ooool00ol0003oooooooooo`02ooooo`;o00001oooool2o`00
03Kooooo0_l0001dooooo`00O_ooool2o`0000cooooo0_l00008ooooo`?o00000oooool2o`0000ko
oooo00?o0000ooooooooool02Oooool4o`0003Kooooo0_l0001dooooo`00O_ooool2o`0000cooooo
0_l00004ooooo`;o00000oooool2o`0001?ooooo00?o0000ooooooooool02Oooool2o`0003Sooooo
0_l0001dooooo`00T_ooool2o`0001Sooooo0ol0000oooooo`;o0000N?ooool008Kooooo0_l0000T
ooooo`03o`000?oooooooooo03oooooo0_l0001hooooo`00Q_ooool2o`0000[ooooo0_l00009oooo
o`;o00003Oooool00ol0003oooooooooo`07ooooo`;o0000/?ooool008cooooo0_l00004ooooo`;o
00002Oooool2o`0000gooooo00?o0000ooooooooool00_l00005ooooo`;o00002_ooool2o`000:Co
oooo002<ooooo`;o00007_ooool00ol0003oooooooooo`02o`00013ooooo0ol0002Tooooo`00T_oo
ool2o`0001Sooooo00?o0000ooooooooool04_ooool3o`0000kooooo0_l0000Hooooo`;o0000N_oo
ool009;ooooo0_l0000Hooooo`04o`000?oooooo0000o`0001;ooooo0_l0000>ooooo`;o00006?oo
ool2o`0007[ooooo002Hooooo`;o00004_ooool01?l0003oooooo`000?l00006ooooo`;o00002_oo
ool2o`000:Cooooo002Hooooo`;o00001oooool2o`0000Wooooo0ol00006ooooo`?o0000/?ooool0
0:7ooooo0_l00009ooooo`03o`000?oooooooooo00Kooooo0_l0000Iooooo`;o0000U_ooool00:co
oooo00?o0000ooooooooool08Oooool2o`0009Kooooo002/ooooo`03o`000?oooooooooo02?ooooo
0_l0000Jooooo`;o0000N?ooool009_ooooo0_l0000?ooooo`03o`000?oooooooooo02?ooooo0_l0
000Jooooo`;o0000N?ooool007oooooo0_l0000Jooooo`;o00003oooool00ol0003oooooooooo`2i
ooooo`00Ooooool2o`0000Oooooo0_l00004ooooo`;o00001?ooool2o`0001Kooooo00?o0000oooo
ooooool08oooool2o`0009Cooooo0028ooooo`;o00001?ooool2o`0000Cooooo0_l0000Fooooo`03
o`000?oooooooooo02?ooooo0_l0002Dooooo`00UOooool2o`0000Cooooo0_l0000?ooooo`?o0000
3oooool2o`000:Sooooo0028ooooo`;o00002oooool2o`0000Cooooo0_l0000=ooooo`?o00004Ooo
ool2o`0002Wooooo0_l0001mooooo`00R?ooool2o`00023ooooo0ol00004ooooo`Co0000=?ooool2
o`000003ooooool0003o000007[ooooo002Fooooo`;o00003oooool2o`0000?ooooo00?o0000oooo
ooooool00_ooool4o`0001cooooo0_l0000Iooooo`;o0000N_ooool009Kooooo0_l0000?ooooo`;o
00000oooool00ol0003oooooooooo`0Rooooo`;o00005Oooool2o`0007kooooo002Wooooo`;o0000
0oooool00ol0003oooooooooo`0iooooo`;o0000O_ooool0097ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooooooo
ool07oooool2o`0001_ooooo0_l0001kooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`;o000000?o<S8booooooooool00oooool00ol0003oooooooooo`0Oooooo`;o
00006oooool2o`0007_ooooo002Aooooo`05oa0@4?ooooooooooooooool@41003_ooool3o`0000Go
oooo00?o0000ooooooooool02oooool2o`000:cooooo002Aooooo`;o00000_ooool01?l0003ooooo
ooooooooool2o`0000[ooooo00?oMgMgoc8b<_ooool01?ooool3o`0000_ooooo0_l0000?ooooo`;o
0000Voooool008Sooooo0_l00007ooooo`;o00000_ooool01?l0003oooooooooooooool2o`0000Oo
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo01cooooo0_l0002Koooo
o`00R?ooool2o`0000Oooooo00Go410@oooooooooooooooooa0@4002ooooo`Co00001_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo0_l0002/ooooo`00TOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00;ooooo1?l00006ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02oooool2o`000:cooooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00
00Kooooo00?o0000ooooooooool02oooool2o`000:cooooo002/ooooo`03o`000?oooooooooo03Ko
oooo0_l00021ooooo`00P_ooool2o`0002Sooooo00?o0000ooooooooool02Oooool2o`0002_ooooo
0_l00021ooooo`00P_ooool2o`0002Kooooo0ol0000;ooooo`;o00003Oooool2o`0001cooooo0_l0
0021ooooo`00Z_ooool5o`0001Sooooo0_l0000Looooo`;o0000POooool00:[ooooo0ol0000Ioooo
o`;o00006Oooool2o`0008Gooooo002Vooooo`;o000000Goooooo`000?l0003oooooo`00000Ioooo
o`;o00006Oooool2o`0008Gooooo002Tooooo`Co000000Goooooo`000?l0003oooooo`00002koooo
o`00Y?ooool4o`0000Cooooo00?o0000ooooooooool01oooool2o`00013ooooo0_l0002Nooooo`00
X?ooool2o`0000Cooooo0_l00004ooooo`03o`000?oooooooooo00Oooooo0_l0000@ooooo`;o0000
5oooool2o`0008Gooooo002Eooooo`;o00002Oooool2o`000003ooooool0003o000000Oooooo00?o
0000ooooooooool05oooool3o`0001Sooooo0_l00025ooooo`00U?ooool3o`0000cooooo0_l00007
ooooo`03o`000?oooooooooo01Oooooo0ol0002Oooooo`00U?ooool2o`0001Kooooo0ol0000Hoooo
o`;o00005oooool3o`0008Gooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`0aooooo`?o
0000QOooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Ooo
ool009Oooooo0_l0000Cooooo`03o`000?oooooooooo0;Wooooo002Gooooo`;o00004oooool00ol0
003oooooooooo`2iooooo`00Uoooool3o`0001;ooooo00?o0000ooooooooool04Oooool2o`000:Ko
oooo002>ooooo`;o00001oooool3o`0001;ooooo00?o0000ooooooooool04Oooool2o`000:Kooooo
002>ooooo`;o00007?ooool3o`000;Wooooo002/ooooo`04o`000?oooooo0000o`00017ooooo0_l0
002Uooooo`00[?ooool01?l0003oooooo`000?l0000@ooooo`?o0000YOooool00:cooooo0ol0000A
ooooo`;o00006Oooool2o`0008_ooooo002/ooooo`?o0000;?ooool2o`0008_ooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002Looooo`;o00003_ooool00ol0003oooooooooo`2iooooo`00W?oo
ool2o`0000Gooooo0_l00007ooooo`03o`000?oooooooooo0;Wooooo002?ooooo`;o00004_ooool2
o`0000?ooooo0_l00002ooooo`03o`000?oooooooooo00cooooo0_l0000Gooooo`;o0000T_ooool0
08oooooo0_l0000Gooooo`;o00000_ooool3o`0000Wooooo0_l000000ooooooo0000o`00000Goooo
o`;o0000T_ooool009;ooooo0_l0000Hooooo`03o`000?oooooooooo00Wooooo0_l0000Jooooo`;o
0000T_ooool009;ooooo0_l0000;ooooo`;o00002oooool00ol0003oooooooooo`0Sooooo`Co0000
T_ooool009oooooo0ol0000:ooooo`03o`000?oooooooooo02?ooooo1?l0002Booooo`00X?ooool2
o`0000[ooooo00?o0000ooooooooool0^Oooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`0Sooooo`;o0000U?ooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool08oooool2o`0009Cooooo0029ooooo`05oa0@4?ooooooooooooooool@41003Ooo
ool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01ooo
ool2o`000;3ooooo0029ooooo`05o`000?ooooooooooooooool000001Oooool2o`0000Oooooo00?o
8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`?o00001oooool2o`000;3ooooo0029
ooooo`05o`000?ooooooooooooooool000001Oooool2o`0000Oooooo00?oEEEEolc<c?ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool01_ooool2o`000;7ooooo
0029ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01_ooool2o`000;7ooooo0029ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02?ooool2o`000003ooooool@413ooooo00;ooooo00?o<S8booooooooool0
0_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo0_l0002cooooo`00ROoo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo0ol000000ooooooo0000o`000003o`0000Cooooo
1?l00006ooooo`03o`000?oooooooooo00?ooooo0ol0002cooooo`00UOooool2o`0001Gooooo00?o
0000ooooooooool00oooool2o`000;Cooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo0;Wooooo0029ooooo`;o00008Oooool3o`000;Wooooo0029ooooo`;o0000
8Oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00Voooool2
o`0000oooooo00?o0000ooooooooool0^Oooool009_ooooo0_l0000?ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Wooooo`;o00000oooool00ol0003ooooo
ooooo`2iooooo`00W?ooool2o`0000Wooooo0_l00003ooooo`03o`000?oooooooooo0;Wooooo002<
ooooo`;o00003_ooool3o`0000gooooo0ol0002iooooo`00S?ooool2o`0000oooooo0_l0000=oooo
o`03o`000?oooooooooo0;Wooooo002Qooooo`;o00002Oooool00ol0003oooooooooo`2iooooo`00
XOooool4o`0000;ooooo0_l00003ooooo`03o`000?oooooooooo0;Wooooo002Sooooo`;o00000_oo
ool2o`0000?ooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool008oooooo
0_l0000Kooooo`03o`000?oooooooooo0;Wooooo002?ooooo`;o00006oooool3o`000;Wooooo002/
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00[ooooo0_l0002]oooo
o`00[?ooool00ol0003oooooooooo`0:ooooo`;o0000[Oooool00:cooooo00?o0000ooooooooool0
2?ooool2o`0000;ooooo0_l0002[ooooo`00[?ooool00ol0003oooooooooo`08ooooo`;o00000_oo
ool2o`000:_ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
00Sooooo0_l0002_ooooo`00[?ooool3o`0000Sooooo0_l0002_ooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool0^Oooool009Cooooo0_l0000F
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Fooooo`;o
00005?ooool00ol0003oooooooooo`2iooooo`00U_ooool2o`0000[ooooo1?l000000ol@413ooooo
ooooo`03ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0^Oooool00:Cooooo00?o0000ooooooooool01Oooool3o`000;Wooooo002Toooo
o`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`00
0?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Rooooo`03oeEEEOmVIVKo
00000<?ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Z
ooooo`04oa0@4?l0003o0000o`000;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`03o`000?oooooooooo0;[ooooo002[ooooo`06o`000?mgMgOo0000o`000?mEEEGok^k^]oooool0
0:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomEEEFgooooo`00Zoooool00ol0003ok^k^ooooo`02
ooooo`03o`000?oooooooooo0;Gooooo002[ooooo`03o`000?o^k^kooooo00;ooooo00?o0000oooo
ooooool0]Oooool00:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomVIVJgooooo`00Z_ooool00ol@
413o0000ogMgM`02o`000003ofIVI_o^k^kooooo0;Kooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.58601 .25554 Mdot
.64607 .39871 Mdot
.44611 .54286 Mdot
.44251 .70697 Mdot
.40422 .48168 Mdot
.42312 .19361 Mdot
.43698 .5344 Mdot
.66002 .23557 Mdot
.59125 .15407 Mdot
.5377 .33588 Mdot
.56879 .49941 Mdot
.70002 .32769 Mdot
.66199 .58752 Mdot
.55893 .39925 Mdot
.71484 .40162 Mdot
.42427 .36413 Mdot
.56105 .72688 Mdot
.66106 .5967 Mdot
.50636 .77095 Mdot
.49298 .94324 Mdot
.64484 .64836 Mdot
.6583 .50846 Mdot
.65086 .5794 Mdot
.65366 .62959 Mdot
.73107 .47572 Mdot
.54601 .26604 Mdot
.55831 .60563 Mdot
.49949 .77927 Mdot
.45037 .93727 Mdot
.65051 .43529 Mdot
.61483 .7249 Mdot
.57592 .12936 Mdot
.65252 .23477 Mdot
.48334 .85605 Mdot
.43732 .829 Mdot
.48651 .93432 Mdot
.40066 .18216 Mdot
.52495 .72191 Mdot
.39087 .74311 Mdot
.70277 .32477 Mdot
.73235 .44027 Mdot
.46401 .86148 Mdot
.3911 .48453 Mdot
.58504 .24417 Mdot
.54368 .18008 Mdot
.44801 .19712 Mdot
.56115 .43342 Mdot
.50652 .04768 Mdot
.60449 .44817 Mdot
.42664 .89034 Mdot
.51044 .05367 Mdot
.37945 .65597 Mdot
.38381 .85793 Mdot
.39638 .61746 Mdot
.40303 .69367 Mdot
.62567 .19917 Mdot
.66994 .2565 Mdot
.57221 .70372 Mdot
.45202 .04427 Mdot
.52934 .15985 Mdot
.47416 .174 Mdot
.72506 .65821 Mdot
.38147 .65655 Mdot
.54324 .46365 Mdot
.6692 .28148 Mdot
.59616 .15393 Mdot
.53599 .33436 Mdot
.42553 .36419 Mdot
.53522 .70192 Mdot
.64084 .67277 Mdot
.57889 .69925 Mdot
.47154 .3135 Mdot
.54753 .37308 Mdot
.5057 .26294 Mdot
.38144 .65599 Mdot
.47975 .35501 Mdot
.38319 .85471 Mdot
.53721 .2635 Mdot
.39154 .75817 Mdot
.6001 .48765 Mdot
.56643 .82397 Mdot
.6494 .43721 Mdot
.45391 .73064 Mdot
.4629 .86264 Mdot
.63459 .19836 Mdot
.41821 .41051 Mdot
.40487 .44712 Mdot
.43673 .23346 Mdot
.5909 .65062 Mdot
.43022 .33497 Mdot
.73094 .49065 Mdot
.55905 .95585 Mdot
.54341 .56699 Mdot
.43123 .24376 Mdot
.54438 .54433 Mdot
.59708 .9121 Mdot
.55683 .39142 Mdot
.53926 .09059 Mdot
.3759 .81542 Mdot
.59791 .63358 Mdot
.60444 .29439 Mdot
.60526 .5867 Mdot
.70351 .34591 Mdot
.60352 .28198 Mdot
.60848 .7532 Mdot
.47086 .85901 Mdot
.55808 .74549 Mdot
.48509 .80358 Mdot
.54335 .56866 Mdot
.63408 .68906 Mdot
.54712 .35784 Mdot
.45918 .74428 Mdot
.57548 .13011 Mdot
.51598 .91081 Mdot
.40023 .05576 Mdot
.48257 .70822 Mdot
.50511 .20194 Mdot
.59273 .14135 Mdot
.58108 .12939 Mdot
.41577 .12943 Mdot
.65967 .59502 Mdot
.7382 .60021 Mdot
.6379 .65068 Mdot
.45265 .94139 Mdot
.63691 .68322 Mdot
.42589 .62696 Mdot
.48766 .94073 Mdot
.62674 .87039 Mdot
.6377 .39879 Mdot
.42722 .50473 Mdot
.65651 .55258 Mdot
.62207 .33941 Mdot
.7139 .3707 Mdot
.41844 .20674 Mdot
.39602 .3641 Mdot
.41858 .87797 Mdot
.3745 .38895 Mdot
.46082 .94304 Mdot
.54646 .37082 Mdot
.67459 .28026 Mdot
.71593 .39806 Mdot
.68116 .76473 Mdot
.51366 .69191 Mdot
.52772 .72428 Mdot
.5628 .72379 Mdot
.50794 .92445 Mdot
.61901 .17614 Mdot
.43425 .74005 Mdot
.44649 .20788 Mdot
.74827 .54299 Mdot
.60888 .5612 Mdot
.56067 .6186 Mdot
.65565 .62627 Mdot
.45935 .32758 Mdot
.49818 .1289 Mdot
.37425 .41492 Mdot
.38142 .66459 Mdot
.60229 .15766 Mdot
.40842 .15106 Mdot
.37421 .41012 Mdot
.57938 .34431 Mdot
.3979 .7973 Mdot
.72765 .38485 Mdot
.51178 .9043 Mdot
.39544 .39176 Mdot
.60635 .30554 Mdot
.61679 .17451 Mdot
.60143 .77072 Mdot
.53868 .69135 Mdot
.37192 .52406 Mdot
.43604 .90567 Mdot
.52143 .65669 Mdot
.54311 .67252 Mdot
.41133 .36484 Mdot
.43052 .73114 Mdot
.66455 .26327 Mdot
.60492 .90094 Mdot
.49491 .12618 Mdot
.46977 .70445 Mdot
.42358 .88609 Mdot
.37832 .65712 Mdot
.71545 .36186 Mdot
.46159 .2353 Mdot
.73432 .45001 Mdot
.44773 .31673 Mdot
.59315 .16026 Mdot
.62122 .87561 Mdot
.55366 .09759 Mdot
.72528 .38062 Mdot
.39106 .45261 Mdot
.74124 .56704 Mdot
.51145 .92074 Mdot
.53476 .41311 Mdot
.7229 .65415 Mdot
.64867 .21977 Mdot
.74116 .4685 Mdot
.70779 .35462 Mdot
.42515 .26974 Mdot
.53695 .98624 Mdot
.53889 .78798 Mdot
.4997 .66806 Mdot
.49578 .67916 Mdot
.48177 .31415 Mdot
.40609 .44211 Mdot
.61671 .32904 Mdot
.50741 .32318 Mdot
.44649 .13653 Mdot
.47782 .75623 Mdot
.45969 .28377 Mdot
.57011 .49734 Mdot
.66535 .5327 Mdot
.52861 .24606 Mdot
.59922 .77468 Mdot
.45798 .24402 Mdot
.61106 .31763 Mdot
.5195 .23142 Mdot
.72957 .3954 Mdot
.43941 .34299 Mdot
.53559 .17559 Mdot
.69213 .29776 Mdot
.49634 .18803 Mdot
.48628 .03797 Mdot
.61226 .7494 Mdot
.54221 .86032 Mdot
.45148 .25992 Mdot
.41173 .63226 Mdot
.63624 .35537 Mdot
.53095 .6252 Mdot
.71539 .40222 Mdot
.74064 .60039 Mdot
.41644 .50749 Mdot
.4952 .63749 Mdot
.60472 .54903 Mdot
.56508 .5753 Mdot
.7377 .59148 Mdot
.5365 .69307 Mdot
.61169 .29854 Mdot
.6491 .61807 Mdot
.61647 .32359 Mdot
.72178 .66555 Mdot
.39723 .33956 Mdot
.58591 .80387 Mdot
.57918 .69829 Mdot
.56686 .11421 Mdot
.54303 .54263 Mdot
.37928 .34762 Mdot
.5806 .66486 Mdot
.58173 .69139 Mdot
.38343 .6818 Mdot
.73948 .46703 Mdot
.48366 .70661 Mdot
.53719 .43648 Mdot
.39149 .24064 Mdot
.56121 .30543 Mdot
.54473 .66581 Mdot
.40254 .69884 Mdot
.48709 .3622 Mdot
.66959 .2613 Mdot
.47981 .02995 Mdot
.60743 .49527 Mdot
.56549 .57268 Mdot
.53369 .87384 Mdot
.43818 .63284 Mdot
.60599 .56973 Mdot
.57682 .24259 Mdot
.56444 .46958 Mdot
.42711 .18898 Mdot
.4592 .9329 Mdot
.58294 .37143 Mdot
.49425 .93273 Mdot
.39983 .67188 Mdot
.53112 .31469 Mdot
.6036 .48982 Mdot
.37265 .46478 Mdot
.46339 .23158 Mdot
.4457 .7834 Mdot
.52686 .07191 Mdot
.56965 .46762 Mdot
.47613 .11402 Mdot
.41376 .8588 Mdot
.42809 .56516 Mdot
.49693 .25019 Mdot
.41298 .13571 Mdot
.69573 .32307 Mdot
.48329 .8056 Mdot
.44242 .39169 Mdot
.40649 .50457 Mdot
.55073 .86545 Mdot
.45237 .19513 Mdot
.57506 .80748 Mdot
.61714 .88006 Mdot
.45592 .04344 Mdot
.70608 .36646 Mdot
.47683 .03769 Mdot
.46443 .66507 Mdot
.41664 .11295 Mdot
.72088 .64862 Mdot
.57384 .83019 Mdot
.71206 .39067 Mdot
.60166 .45241 Mdot
.39017 .55389 Mdot
.62306 .33808 Mdot
.57156 .12161 Mdot
.73046 .44789 Mdot
.56368 .44443 Mdot
.53136 .0788 Mdot
.56659 .31722 Mdot
.51785 .59284 Mdot
.66283 .54289 Mdot
.55613 .73994 Mdot
.65803 .59413 Mdot
.74754 .53174 Mdot
.46493 .70576 Mdot
.55188 .20067 Mdot
.46969 .86039 Mdot
.67745 .29827 Mdot
.44089 .6504 Mdot
.71846 .37454 Mdot
.73238 .57943 Mdot
.68302 .77175 Mdot
.41781 .53134 Mdot
.41347 .22493 Mdot
.46679 .86638 Mdot
.37548 .55508 Mdot
.41548 .66831 Mdot
.51752 .60579 Mdot
.44657 .6163 Mdot
.56295 .73271 Mdot
.68055 .27348 Mdot
.39517 .22165 Mdot
.54585 .52858 Mdot
.66277 .51774 Mdot
.42677 .4972 Mdot
.48499 .31725 Mdot
.63889 .36457 Mdot
.41152 .24097 Mdot
.39547 .39042 Mdot
.58032 .34818 Mdot
.40555 .4686 Mdot
.41631 .97433 Mdot
.57264 .33939 Mdot
.64602 .43162 Mdot
.54364 .48356 Mdot
.64383 .22551 Mdot
.56015 .5925 Mdot
.46532 .94419 Mdot
.65326 .49051 Mdot
.53418 .62494 Mdot
.49628 .19543 Mdot
.68522 .7576 Mdot
.69555 .31318 Mdot
.40428 .15472 Mdot
.48188 .93784 Mdot
.59711 .41608 Mdot
.5313 .79735 Mdot
.44982 .92717 Mdot
.60582 .55756 Mdot
.69595 .31539 Mdot
.69086 .76328 Mdot
.58184 .81136 Mdot
.71329 .3713 Mdot
.72075 .38292 Mdot
.73388 .42611 Mdot
.50486 .362 Mdot
.60558 .52348 Mdot
.717 .40582 Mdot
.66835 .25597 Mdot
.50937 .37788 Mdot
.59551 .77088 Mdot
.57908 .36792 Mdot
.43925 .14743 Mdot
.59942 .28354 Mdot
.55385 .10782 Mdot
.6116 .29946 Mdot
.41267 .13082 Mdot
.38156 .33305 Mdot
.65111 .5721 Mdot
.38897 .23416 Mdot
.65547 .55063 Mdot
.72775 .44956 Mdot
.43786 .07473 Mdot
.49669 .12419 Mdot
.46077 .32914 Mdot
.7362 .53512 Mdot
.59783 .62737 Mdot
.45016 .63075 Mdot
.71665 .36047 Mdot
.63903 .67849 Mdot
.52154 .58605 Mdot
.51804 .28953 Mdot
.5329 .24523 Mdot
.56132 .59939 Mdot
.51353 .05392 Mdot
.62171 .73657 Mdot
.72053 .65671 Mdot
.71738 .36729 Mdot
.52791 .79611 Mdot
.41785 .97422 Mdot
.52658 .80191 Mdot
.43792 .75617 Mdot
.43122 .7392 Mdot
.51299 .51375 Mdot
.67915 .27391 Mdot
.69884 .32567 Mdot
.55981 .59779 Mdot
.52759 .64403 Mdot
.57328 .52889 Mdot
.43052 .31648 Mdot
.74484 .51007 Mdot
.4185 .29853 Mdot
.52491 .8892 Mdot
.49342 .73588 Mdot
.55674 .63342 Mdot
.43325 .60393 Mdot
.4109 .35692 Mdot
.49499 .84543 Mdot
.56626 .58345 Mdot
.51385 .34088 Mdot
.74376 .57269 Mdot
.67184 .27365 Mdot
.48263 .61957 Mdot
.42867 .80761 Mdot
.55721 .74707 Mdot
.53559 .18299 Mdot
.58516 .38991 Mdot
.5439 .67387 Mdot
.73851 .52785 Mdot
.59053 .92445 Mdot
.62265 .32937 Mdot
.36552 .24425 Mdot
.59078 .25247 Mdot
.51948 .35404 Mdot
.61551 .19288 Mdot
.71924 .41779 Mdot
.56755 .52878 Mdot
.65238 .50251 Mdot
.40584 .94522 Mdot
.52107 .66552 Mdot
.52568 .54663 Mdot
.41778 .66673 Mdot
.54415 .86052 Mdot
.59742 .44863 Mdot
.54689 .97283 Mdot
.45639 .29319 Mdot
.40614 .70114 Mdot
.48124 .865 Mdot
.54618 .49501 Mdot
.46023 .69781 Mdot
.48406 .22886 Mdot
.66216 .24026 Mdot
.4585 .7006 Mdot
.40441 .82596 Mdot
.63773 .36838 Mdot
.55148 .19583 Mdot
.49352 .93518 Mdot
.58523 .7875 Mdot
.54558 .76361 Mdot
.64401 .84994 Mdot
.52209 .2981 Mdot
.68253 .27687 Mdot
.73964 .45886 Mdot
.56457 .48179 Mdot
.41134 .12912 Mdot
.58441 .38211 Mdot
.561 .72096 Mdot
.47161 .94619 Mdot
.60271 .28857 Mdot
.49134 .79498 Mdot
.49594 .19434 Mdot
.49353 .84935 Mdot
.73544 .63269 Mdot
.4017 .31611 Mdot
.46918 .35465 Mdot
.39175 .48591 Mdot
.60104 .48357 Mdot
.49686 .33503 Mdot
.41892 .44477 Mdot
.39973 .65546 Mdot
.39103 .44429 Mdot
.49199 .69176 Mdot
.55509 .2942 Mdot
.59893 .15779 Mdot
.40461 .54327 Mdot
.56765 .22762 Mdot
.54461 .68435 Mdot
.48169 .79552 Mdot
.52095 .43343 Mdot
.38218 .12943 Mdot
.52373 .4595 Mdot
.64277 .38163 Mdot
.5081 .06022 Mdot
.51262 .90455 Mdot
.52926 .71748 Mdot
.44517 .92801 Mdot
.71024 .34972 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:Gooooo0_l00005ooooo`03o`000?oooooooooo0;Wooooo002Uooooo`;o00001Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool2o`000003ooooool0003o000000?ooooo00?o0000ooooooooool0
^Oooool00:Cooooo0_l000000ooooooo0000o`000003ooooo`03o`000?oooooooooo0;Wooooo002M
ooooo`;o00003Oooool00ol0003oooooooooo`2iooooo`00W?ooool3o`0000gooooo00?o0000oooo
ooooool0^Oooool009cooooo0_l0000>ooooo`04o`000?oooooo0000o`000;Sooooo002/ooooo`Co
0000^?ooool008_ooooo0_l0000Oooooo`03o`000?oooooooooo00?o0000]_ooool008_ooooo0_l0
000Oooooo`03o`000?oooooooooo00?o0000]_ooool00:cooooo00Co0000ooooool0003o0000^?oo
ool00:cooooo00Co0000ooooool0003o0000^?ooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool01Oooool2o`000;;o
oooo002Gooooo`;o00004oooool3o`0000Gooooo0_l0002booooo`00Uoooool2o`0001?ooooo00?o
0000ooooooooool01oooool2o`000;3ooooo002/ooooo`03o`000?oooooooooo00Oooooo0_l0002`
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
[?ooool00ol0003oooooooooo`0:ooooo`;o0000[Oooool00:cooooo00?o0000ooooooooool02_oo
ool2o`000:gooooo002/ooooo`03o`000?oooooooooo00kooooo0_l0002Yooooo`00[?ooool3o`00
00kooooo0_l0002Yooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool00ol0003oooooooooo`0>ooooo`;o0000ZOooool0093ooooo0_l0000J
ooooo`03o`000?oooooooooo00kooooo0_l0002Yooooo`00T?ooool2o`0001;ooooo0_l00006oooo
o`03o`000?oooooooooo01?ooooo0_l0002Tooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o0000omgMg@05
ooooo`03o`000?oooooooooo01?ooooo0_l0002Tooooo`00ROooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`0Dooooo`;o0000Xoooool0087ooooo1_l00002ooooo`05oa0@4?oooooooooo
ooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`04o`000?ooooooooooooooo`Go00005?oo
ool2o`000:?ooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00;ooooo0ol0002kooooo`00QOooool2o`0000;ooooo00Co0000
oooooooooooooooo1Ol0000:ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c003ooooo`?o00005oooool4o`000:3ooooo0025ooooo`;o00000_ooool01Ol@413ooooooooo
oooooooo410@00Co00002_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool05Oooool4o`000:3ooooo0029ooooo`06ogMgMonHV9SooooooiRHV?mgMgOo
oooo0_l00008ooooo`05oa0@4?l0003o0000oooooolb<S801?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo0;Wooooo0029ooooo`06onk^k_lb<S;o0000oc8b<_o^k^kooooo0_l00008
ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool06oooool2o`0009cooooo002/ooooo`03o`000?oooooooooo01_ooooo0_l0002Looooo`00
V?ooool2o`0001;ooooo00?o0000ooooooooool0^Oooool008gooooo0_l00009ooooo`;o00004_oo
ool3o`000;Wooooo002<ooooo`?o00007Oooool00ol0003oooooooooo`0Kooooo`?o0000Voooool0
08cooooo0_l0000Nooooo`03o`000?oooooooooo01_ooooo1Ol0002Iooooo`00[?ooool00ol0003o
ooooooooo`06ooooo`;o00004oooool5o`0009Wooooo002/ooooo`03o`000?oooooooooo00Kooooo
0_l0000Cooooo`;o0000W?ooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:?ooooo0_l00007ooooo`03o`000?oooooooooo0;Wooooo002Sooooo`;o
00001oooool3o`0000Sooooo0_l0000Iooooo`?o0000Toooool00:cooooo00?o0000ooooooooool0
2?ooool2o`000003ooooool0003o000001Kooooo0ol0002Cooooo`00Roooool2o`0001oooooo00?o
0000ooooooooool02?ooool2o`000003ooooool0003o00000:cooooo002;ooooo`;o00007oooool0
0ol0003oooooooooo`08ooooo`;o0000[oooool009Cooooo0_l0000Dooooo`?o0000^oooool009Co
oooo0_l0000Dooooo`?o0000^oooool009;ooooo0_l00008ooooo`;o00003?ooool3o`0002Gooooo
0_l0002Dooooo`00T_ooool2o`0000Kooooo1?l0000<ooooo`?o00004?ooool2o`0001?ooooo0_l0
0004ooooo`;o0000S_ooool009[ooooo0_l0000@ooooo`?o00003_ooool2o`0001Kooooo0_l00000
0ooooooo0000o`00002>ooooo`00[?ooool3o`0000kooooo0_l0000Fooooo`;o0000TOooool0097o
oooo0_l0000Iooooo`?o0000^Oooool0097ooooo0_l00007ooooo`;o00004?ooool00ol0003ooooo
ooooo`2iooooo`00V_ooool2o`00013ooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0;_ooool2o`0008Wooooo0029ooooo`;o
00008Oooool00ol0003oooooooooo`0^ooooo`;o0000ROooool008Wooooo0_l00004ooooo`;o0000
6oooool3o`0002cooooo0_l0002;ooooo`00Soooool2o`0001Gooooo0_l00004ooooo`03o`000?oo
oooooooo01?ooooo0_l0000Gooooo`;o0000Roooool009oooooo0_l00005ooooo`;o00001?ooool0
0ol0003oooooooooo`03ooooo`;o00003_ooool2o`000:Cooooo0027ooooo`;o00003_ooool2o`00
00Kooooo0_l0000;ooooo`03o`000?oooooooooo00?ooooo0_l0000Zooooo`;o0000R?ooool008Oo
oooo0_l0000>ooooo`;o00001_ooool2o`0000_ooooo00?o0000ooooooooool0;oooool4o`0008Ko
oooo0028ooooo`;o00001?ooool2o`0000oooooo0_l0000;ooooo`03o`000?oooooooooo037ooooo
0ol00025ooooo`00R?ooool2o`0000Cooooo0_l000001Oooooook^k^oc8b<_l0003o<S8b00;o0000
1?ooool2ob4Q8@03ooooool0003o000000;ooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo01Kooooo0_l0000Jooooo`;o0000QOooool007oooooo0_l0000@ooooo`04ogMg
MonHV9SooooooiRHV0;o00001?ooool2ob4Q8@03ooooool0003o000000Gooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`06ooooo`?o00003Oooool2o`000003ooooool0003o000009ko
oooo001oooooo`;o00002?ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool3o`00013ooooo0_l0002Nooooo`00
TOooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool4o`0001_o
oooo0_l0002Looooo`00TOooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0
003o<S8bolc<c004ooooo`;o00006oooool4o`0001Oooooo0_l00023ooooo`00TOooool01Ol@413o
oooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Ioooo
o`;o00006Oooool3o`0008;ooooo002Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool2o`00
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0eooooo`;o0000P_ooool0097o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`;o00001?ooool4o`0000Kooooo0ol00009oooo
o`;o0000:?ooool4o`0008;ooooo002/ooooo`?o00002Oooool2o`000003ooooool0003o000002Go
oooo0_l00024ooooo`00Toooool2o`0001Oooooo00?o0000ooooooooool03?ooool2o`000:_ooooo
002Cooooo`;o00005oooool00ol0003oooooooooo`0eooooo`;o000000?oooooo`000?l00000Oooo
ool00:cooooo0ol0000eooooo`;o000000Coooooo`000?l0003o0000O_ooool00:cooooo00?o0000
ooooooooool0=_ooool2o`000003ooooool0003o000007kooooo002/ooooo`03o`000?oooooooooo
01oooooo0_l0000Cooooo`Co0000POooool009kooooo0_l0000<ooooo`03o`000?oooooooooo01go
oooo1?l0000Cooooo`;o0000Poooool009kooooo0_l0000<ooooo`03o`000?oooooooooo01gooooo
0ol0002Iooooo`00[?ooool00ol0003oooooooooo`03ooooo`;o00006Oooool2o`0009Wooooo002M
ooooo`;o00003Oooool00ol0003oooooooooo`03ooooo`;o00002_ooool2o`0000kooooo0_l0002H
ooooo`00TOooool2o`0000[ooooo0_l0000=ooooo`03o`000?oooooooooo00Cooooo0_l00009oooo
o`;o00003_ooool4o`0001Cooooo0_l00003ooooo`;o0000Noooool0097ooooo0_l0000Iooooo`?o
00001?ooool2o`0001_ooooo0_l0000Dooooo`;o00000oooool2o`0007_ooooo002/ooooo`03o`00
0?oooooooooo027ooooo0_l0002Fooooo`00[?ooool00ol0003oooooooooo`0Aooooo`;o00003Ooo
ool2o`0009Oooooo002/ooooo`03o`000?oooooooooo017ooooo0_l0000=ooooo`;o0000Uoooool0
0:;ooooo0_l00008ooooo`03o`000?oooooooooo03gooooo0_l0001jooooo`00Roooool2o`0000So
oooo0_l00003ooooo`;o00001_ooool2o`0000;ooooo0_l00004ooooo`03o`000?oooooooooo00Oo
oooo0_l0000dooooo`;o0000N_ooool008_ooooo0_l00008ooooo`;o00000oooool2o`0000[ooooo
0ol00003ooooo`03o`000?oooooooooo00Oooooo0_l0000:ooooo`;o00003?ooool2o`0001[ooooo
0_l0001jooooo`00Yoooool2o`0000?ooooo00?o0000ooooooooool04oooool2o`0000cooooo0_l0
002Fooooo`00[?ooool4o`0002;ooooo0_l0000Hooooo`Go0000Moooool009kooooo0_l0000<oooo
o`04o`000?oooooo0000o`0002;ooooo0_l0000Hooooo`Go0000Moooool009kooooo0ol0000;oooo
o`03o`000?oooooooooo02?ooooo1?l0000Hooooo`;o0000N?ooool008Cooooo0_l0000Iooooo`;o
00002oooool00ol0003oooooooooo`08ooooo`;o00006Oooool4o`0009;ooooo0024ooooo`;o0000
3oooool2o`0001Cooooo0_l0000:ooooo`?o0000[_ooool008[ooooo0_l00009ooooo`;o00005?oo
ool2o`0000?ooooo0_l00006ooooo`;o00002_ooool2o`0000kooooo0_l0002Booooo`00R_ooool2
o`0000cooooo0_l0000Booooo`04o`000?ooooooooooooooo`;o00004_ooool2o`0000kooooo0_l0
002Booooo`00V?ooool2o`0001;ooooo00?o0000ooooooooool05oooool2o`0002Oooooo0_l0001g
ooooo`00Q?ooool2o`0002Kooooo00?o0000ooooooooool05oooool2o`0002Oooooo1?l0001eoooo
o`00Q?ooool2o`0002Kooooo0ol0000Gooooo`;o0000:Oooool2o`0007Gooooo002Qooooo`;o0000
0_ooool2o`0000Gooooo00?o0000ooooooooool00oooool2o`0002Gooooo0_l0000Eooooo`;o0000
M_ooool008kooooo0_l0000Aooooo`;o00000_ooool2o`0000Gooooo00?o0000ooooooooool00ooo
ool2o`0000Oooooo0_l0000Looooo`;o00005Oooool2o`0007Kooooo002>ooooo`;o00007?ooool3
o`0000cooooo0_l0000fooooo`;o0000Loooool008Wooooo0_l00003ooooo`;o00000oooool2o`00
01;ooooo0_l00003ooooo`?o0000:_ooool2o`0001Sooooo0_l0001cooooo`00ROooool3o`000004
oc8b<_o^k^ko0000o`0000?ooooo0_l00004ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;o
gMgM00;o00000oooool00ol0003oooooooooo`0Gooooo`;o00004Oooool2o`0001Gooooo0_l00000
0ooooooo0000o`00001cooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo00cooooo0_l00009ooooo`;o00004Oooool2o`0001Gooooo1Ol0001cooooo`00POooool6
o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`;o00002_ooool2o`00013ooooo0_l0
000Gooooo`;o0000M?ooool008Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ
8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0000cooooo0_l0000:ooooo`;o0000:Ooo
ool4o`0007;ooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`02o`0004?ooooo
0_l0001booooo`00ROooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;o00005_ooool2o`0001;ooooo
0_l0000Gooooo`Co0000L?ooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01So
oooo0_l0000Booooo`;o00005oooool5o`0006oooooo0022ooooo`;o00001Oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0
003oooooooooo`18ooooo`;o0000Koooool008;ooooo0_l00005ooooo`;o00003_ooool2o`00017o
oooo00?o0000ooooooooool03oooool2o`0000Sooooo0_l0000Xooooo`;o0000M?ooool008Wooooo
0_l0000>ooooo`;o00004Oooool00ol0003oooooooooo`0?ooooo`;o00002?ooool2o`0002Sooooo
0_l00003ooooo`;o0000Koooool00:cooooo00?o0000ooooooooool0A?ooool2o`0000;ooooo0_l0
001_ooooo`00[?ooool3o`00013ooooo0_l0000Hooooo`;o000000?oooooo`000?l000005Oooool2
o`0007?ooooo002/ooooo`03o`000?oooooooooo013ooooo0_l0000Hooooo`;o000000?oooooo`00
0?l000005?ooool3o`0007?ooooo002/ooooo`03o`000?oooooooooo04?ooooo0ol0001cooooo`00
P_ooool2o`0000gooooo0_l0000Iooooo`03o`000?oooooooooo04Cooooo0_l0001cooooo`00P_oo
ool2o`0000gooooo0_l0000Iooooo`03o`000?oooooooooo00Sooooo0_l0002_ooooo`00P_ooool2
o`0002Sooooo00?o0000ooooooooool02?ooool2o`0001?ooooo0_l0002Jooooo`00P_ooool2o`00
02Sooooo00?o0000ooooooooool07Oooool2o`0002Kooooo0_l0001booooo`00[?ooool00ol0003o
ooooooooo`15ooooo`;o0000L_ooool00:cooooo0ol0002iooooo`00[?ooool00ol0003ooooooooo
o`1:ooooo`;o0000KOooool00:cooooo00?o0000ooooooooool0;Oooool2o`0001_ooooo0_l0001]
ooooo`00[?ooool00ol0003oooooooooo`03ooooo`;o00003?ooool2o`0001[ooooo0_l0002:oooo
o`00[?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`0000Kooooo0_l0000Kooooo`;o
0000ROooool00:cooooo00?o0000ooooooooool02Oooool2o`0002?ooooo0_l0000Iooooo`;o0000
K_ooool008gooooo0_l0000Mooooo`03o`000?oooooooooo04Wooooo0_l0001^ooooo`00R?ooool2
o`0000?ooooo0_l00002ooooo`;o00006Oooool00ol0003oooooooooo`0Booooo`;o0000YOooool0
08Sooooo0_l00002ooooo`;o00000oooool2o`0001Wooooo00?o0000ooooooooool04_ooool2o`00
00Wooooo1?l0000Wooooo`Co0000KOooool008Sooooo0_l00002ooooo`;o00007_ooool3o`0001go
oooo1?l0000Wooooo`Co0000KOooool008Sooooo0_l0000Rooooo`03o`000?oooooooooo01kooooo
0_l0002Iooooo`00[?ooool00ol0003oooooooooo`1<ooooo`;o0000Joooool000Wooooo1?l00000
0ol@413oooooooooo`0Fooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o
0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgM
g@0Fooooo`03o`000?oooooooooo00Cooooo0_l0000Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00;ooooo0_l000000ooooooo8B4Qob4Q8@05ooooo`05odA4A?l0003o0000
oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^
k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`Co000000?o410@ooooooooool0
4_ooool000_ooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o00001?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMg
oc8b<_ooool05Oooool00ol0003oooooooooo`04ooooo`;o00001Oooool2o`0000_ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo
00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03
ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omE
EEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo01Wooooo00?o0000ooooooooool05?ooool000Ko
00001Oooool00ol0003oooooooooo`0@ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@
00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`05ooooo`Ko00000_ooool01Ol@
413ooooooooooooooooo410@013ooooo00?o0000ooooooooool01Oooool6o`0000;ooooo00Go410@
oooooooooooooooooa0@4005ooooo`;o00001Oooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool02oooool2o`0000Oooooo0_l00002ooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00gooooo
00Go410@oooooooooooooooooa0@4002ooooo`;o00003?ooool00ol0003oooooooooo`0=ooooo`05
oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol0003o
oooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`0>oooo
o`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0>ooooo`05o`000?oooooo
ooooooooool000003Oooool01?nHV9So8B4Qo`000?l00006ooooo`03ogMgMolb<S;ooooo01Gooooo
00?o0000ooooooooool04_ooool4o`0000;ooooo00Go0000ooooooooooooooooo`00000=ooooo`03
oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo0000
00;ooooo0_l0000;ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool06Oooool00ol0003oooooooooo`0D
ooooo`002oooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool0
0omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooo
oooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOo0000o`000003ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05_ooool0
0ol0003oooooooooo`0Booooo`;o00001?ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000oooooooooooo
ooooo`000002ooooo`;o00002?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Jooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go410@
oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool04Ooo
ool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04Oooool01Ol@413ooooo
oooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Hooooo`?o
00006?ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Aooooo`04oa0@4?ooooooooooooooo`;o00002oooool00ol0003oooooooooo`0A
ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`00
0?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`0Aooooo`04ogMg
MonHV9SooooooiRHV0;o00002oooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Dooooo`002Oooool00omEEEGoIVIVo`00000Jooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?oo
ool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`04oiRHV?l@413o0000ob4Q8@;o
00000oooool4o`0001Oooooo00?o0000ooooooooool04_ooool2o`0000Cooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`00013ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
1Ol00004ooooo`Co00006Oooool00omEEEGoIVIVo`00000Fooooo`00R?ooool2o`0000;ooooo0_l0
000Nooooo`03o`000?oooooooooo00_ooooo0_l00005ooooo`;o00002_ooool2o`0009Wooooo0028
ooooo`;o00008_ooool00ol0003oooooooooo`0;ooooo`;o00004Oooool2o`0009Wooooo002/oooo
o`03o`000?oooooooooo01kooooo0ol0000>ooooo`;o00006?ooool2o`0006?ooooo0_l00002oooo
o`;o00001Oooool00:cooooo00?o0000ooooooooool03?ooool2o`00017ooooo0ol0000=ooooo`;o
00006?ooool2o`0006?ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd5ooooo`00Toooool2o`00
01Oooooo00?o0000ooooooooool03?ooool2o`0000Kooooo0_l0000:ooooo`;o0000SOooool01?oM
gMgo0000oa0@4?o<c<`6ooooo`001oooooooo`0004co00003?ooool01?o^k^ko8B4Qoa0@4?o^k^h6
ooooo`001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo0_l000000ooo
oooo0000ooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool2o`00
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`04ob4Q8OmgMgOoMgMg
oc8b<PKooooo0007ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo00Oooooo0_l000000ooooooo0000o`000002oooo
o`;o00005_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Gooooo0_l0000Ooooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`09oooo
o`;o00000_ooool2o`0000Gooooo002=ooooo`;o000000?oooooo`000?l000000_ooool2o`0001Ko
oooo00?o0000ooooooooool0<Oooool2o`0001[ooooo0_l0001Zooooo`00[?ooool00ol0003ooooo
ooooo`0aooooo`;o00006_ooool2o`0006[ooooo002/ooooo`04o`000?ooooooooooooooo`;o0000
]_ooool00:cooooo00Co0000oooooooooooooooo0_l0000_ooooo`;o0000QOooool00:cooooo00?o
0000ooooooooool0<_ooool2o`0008Gooooo0021ooooo`;o0000:Oooool3o`0001oooooo0_l0002H
ooooo`00POooool2o`0002Wooooo00?o0000ooooooooool03?ooool2o`0000Gooooo0_l0000:oooo
o`;o0000:_ooool2o`0006cooooo002@ooooo`;o00006_ooool00ol0003oooooooooo`0<ooooo`;o
00001Oooool4o`0003Cooooo0_l000000ooooooo0000o`00001Yooooo`00T?ooool2o`0000Gooooo
0_l0000Cooooo`03o`000?oooooooooo01Gooooo0_l0000Looooo`;o00006Oooool2o`0006Wooooo
002Gooooo`;o00004oooool00ol0003oooooooooo`0cooooo`;o00005_ooool2o`0006cooooo002/
ooooo`03o`000?oooooooooo04_ooooo0_l0001/ooooo`00S?ooool2o`0000cooooo0_l0000@oooo
o`03o`000?oooooooooo00_ooooo0_l0000Uooooo`;o00006oooool2o`0006Sooooo002<ooooo`;o
00003?ooool2o`00013ooooo00?o0000ooooooooool01Oooool2o`0000Cooooo0_l0000Uooooo`;o
00006oooool2o`0006Sooooo002/ooooo`03o`000?oooooooooo00Gooooo0_l00004ooooo`;o0000
4_ooool2o`0009Sooooo002/ooooo`?o00007oooool2o`0000oooooo0_l00027ooooo`00P_ooool2
o`0000?ooooo0_l0000Sooooo`03o`000?oooooooooo033ooooo0_l00027ooooo`00P_ooool2o`00
00?ooooo0_l0000Sooooo`03o`000?oooooooooo01oooooo0_l0002Hooooo`00[?ooool00ol0003o
ooooooooo`0Oooooo`Co0000U_ooool00:cooooo00?o0000ooooooooool08Oooool2o`0009Kooooo
002Dooooo`;o00005_ooool00ol0003oooooooooo`0;ooooo`;o0000?oooool2o`0006_ooooo002D
ooooo`;o00005_ooool00ol0003oooooooooo`0;ooooo`;o00004oooool2o`0002[ooooo0_l0001[
ooooo`00[?ooool00ol0003oooooooooo`0;ooooo`;o00001Oooool2o`0000cooooo0_l0000<oooo
o`;o00007Oooool2o`0006[ooooo002/ooooo`?o00004_ooool2o`0001[ooooo0_l0000Mooooo`;o
0000J_ooool00:cooooo00?o0000ooooooooool04_ooool2o`0001[ooooo0_l0000Iooooo`;o0000
K_ooool00:cooooo00?o0000ooooooooool0;_ooool2o`0001Wooooo0_l0001^ooooo`00[?ooool0
0ol0003oooooooooo`04ooooo`;o00003?ooool2o`000:Gooooo002/ooooo`03o`000?oooooooooo
00Cooooo0_l0000<ooooo`;o00002oooool2o`00017ooooo0_l00025ooooo`00[?ooool00ol0003o
ooooooooo`0Oooooo`;o00004Oooool2o`0001Oooooo0_l0001/ooooo`00[?ooool00ol0003ooooo
ooooo`02ooooo`;o00003?ooool2o`0001oooooo0_l0000Hooooo`;o0000K?ooool00:cooooo00?o
0000ooooooooool00_ooool2o`0000cooooo0_l0000Oooooo`?o0000QOooool00:cooooo0ol0000@
ooooo`?o00007oooool2o`0001Oooooo0ol0001[ooooo`00U_ooool2o`0001Cooooo00?o0000oooo
ooooool04Oooool2o`0003Sooooo0ol0001[ooooo`00U_ooool2o`0001Cooooo00?o0000oooooooo
ool00_ooool2o`0000cooooo0_l0002Wooooo`00[?ooool00ol0003oooooooooo`02ooooo`;o0000
3?ooool2o`000:Oooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Jooooo`;o00004?ooool0
0ol0003oooooooooo`2iooooo`00ROooool3o`000003oc8b<_o^k^kooooo00Cooooo0_lQ8B44oooo
o`Go00001?ooool01?m4A4Co0000o`000?lb<S82o`0000Cooooo00?o0000ooooooooool04Oooool2
o`0001_ooooo0_l00029ooooo`00ROooool2o`000003oooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo0000o`000004ooooo`03o`000?oooooo
oooo017ooooo0_l0000Kooooo`;o0000ROooool008Wooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`0000Oooooo0ol0002_
ooooo`00ROooool01Ol0003ooooooooooooooooo000000Gooooo0_l00006ooooo`03oiRHV?lQ8B7o
k^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`07ooooo`?o00004oooool2
o`00017ooooo0_l00027ooooo`00ROooool01Ol0003ooooooooooooooooo000000Gooooo0_l00006
ooooo`;o000000?oIVIVooooooooool00_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool07Oooool2o`00013ooooo0ol00027ooooo`00ROooool01Ol@413ooooooooooooo
oooo410@00;o00001oooool2o`0000;ooooo0ol00004ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool03oooool2o`0000cooooo0_l0000@ooooo`;o00006Oooool2o`0006gooooo0029
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_l00007ooooo`?o000000Co^[ZjoooooonHV9So410@
1?ooool00ol0003oooooooooo`05ooooo`?o00004Oooool2o`0000cooooo0_l0000[ooooo`;o0000
KOooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`01?ooool4o`0000Cooooo0ol0002kooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?oo
ool00ol0003oooooooooo`06ooooo`;o0000/Oooool00:cooooo00?o0000ooooooooool01_ooool2
o`0002Cooooo0_l0000Gooooo`;o0000L_ooool009Sooooo0_l0000Booooo`?o00006oooool2o`00
00gooooo1?l0000Gooooo`;o0000L_ooool008Cooooo0_l00004ooooo`;o00003?ooool2o`0001;o
oooo00?o0000ooooooooool06oooool2o`0000gooooo0_l0000Jooooo`;o0000LOooool008?ooooo
0ol00004ooooo`;o00008?ooool00ol0003oooooooooo`04ooooo`;o0000?oooool4o`00073ooooo
0023ooooo`?o00009_ooool00ol0003oooooooooo`04ooooo`;o0000?oooool4o`00073ooooo0024
ooooo`;o00006_ooool2o`0000[ooooo00?o0000ooooooooool05oooool2o`000:3ooooo0024oooo
o`;o00002_ooool2o`0000kooooo0_l00009ooooo`;o00001_ooool2o`0000Gooooo0_l0000:oooo
o`;o0000;Oooool2o`00077ooooo002@ooooo`;o00006Oooool2o`0000Kooooo0_l00005ooooo`;o
0000>Oooool2o`00077ooooo002:ooooo`;o00001?ooool2o`0001[ooooo00?o0000ooooooooool0
2oooool2o`0001kooooo0_l0002<ooooo`00R_ooool2o`00023ooooo0ol0000;ooooo`;o00007_oo
ool2o`0008cooooo002Zooooo`?o0000;?ooool2o`0008gooooo0025ooooo`;o00008oooool3o`00
02cooooo0_l0002=ooooo`00QOooool2o`0002Gooooo00?o0000ooooooooool02oooool2o`0001go
oooo0_l0002=ooooo`00[?ooool00ol0003oooooooooo`0;ooooo`;o00007?ooool2o`0008kooooo
002Yooooo`;o000000?oooooo`000?ooool00_ooool2o`0000Kooooo0_l0000=ooooo`;o00003ooo
ool2o`0008kooooo002<ooooo`;o00006oooool2o`000003ooooool0003ooooo00;ooooo0_l00006
ooooo`;o00003Oooool2o`0009oooooo002<ooooo`;o00004?ooool2o`0000cooooo00?o0000oooo
ooooool02Oooool2o`0000cooooo0_l0002Pooooo`00Roooool4o`0000oooooo0_l0000<ooooo`?o
00005oooool2o`000:3ooooo002;ooooo`Co00003oooool2o`0000;ooooo0_l00008ooooo`03o`00
0?oooooooooo00Sooooo0_l0000:ooooo`;o000000?oooooo`000?l00000X?ooool009Wooooo0_l0
0005ooooo`Co00000_ooool2o`0000Cooooo00?o0000ooooooooool02?ooool2o`0000[ooooo0_l0
002Sooooo`00VOooool2o`0000Gooooo0_l00004ooooo`;o00001?ooool00ol0003oooooooooo`2i
ooooo`00Y_ooool2o`0000Cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool01_ooool2o`000;7ooooo002/ooooo`03o`000?oo
oooooooo00Gooooo0ol00009ooooo`;o0000Y_ooool00:cooooo0ol00005ooooo`?o00002Oooool2
o`0000oooooo0_l0002Eooooo`00[?ooool00ol0003oooooooooo`06ooooo`;o00002Oooool2o`00
00oooooo0_l0002Eooooo`00UOooool2o`0000Gooooo0_l0000>ooooo`03o`000?oooooooooo017o
oooo0_l0002Vooooo`00UOooool2o`0000Gooooo0_l0000>ooooo`03o`000?oooooooooo017ooooo
0_l0002Vooooo`00ZOooool2o`000003ooooool0003ooooo01;ooooo0_l0000Booooo`;o0000T_oo
ool009Gooooo0ol0000Aooooo`;o000000?oooooo`000?ooool04?ooool2o`0001Cooooo0_l0002B
ooooo`00R?ooool2o`0000Oooooo00Cok^k^oc8b<_l0003o<S8b0ol00003ooooo`;o8B4Q1Oooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool03oooool2o`000:Sooooo0028
ooooo`;o00001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B400ooooooo0000o`00
0005ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool04?ooool2o`000:Oooooo002A
ooooo`05oa0@4?ooooooooooooooool@41002?ooool2o`0000Kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0?ooooo`?o00004?ooool2o`0009Gooooo002Aooooo`05o`000?oooooo
ooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`?o00003oooool2o`00017ooooo0_l0
002Eooooo`00TOooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`03o`000?oooooooooo023ooooo0_l0002Gooooo`00R?ooool2o`0000Oooooo00Ko
410@oooooooooooooooooa0@4?ooool2o`0000Wooooo00Co0000ooooool0003o00001_ooool00ol0
003oooooooooo`0Pooooo`;o00006?ooool2o`0007gooooo0028ooooo`;o00001oooool01_mgMgOo
V9RHoooooonHV9SoMgMgooooo`;o00002Oooool01?l0003oooooo`000?l00006ooooo`03o`000?oo
oooooooo03[ooooo0_l0001mooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0
0006ooooo`03o`000?oooooooooo00cooooo0_l0000Zooooo`;o00000_ooool2o`0007_ooooo002/
ooooo`03o`000?oooooooooo00cooooo0_l0000Zooooo`;o00000_ooool2o`0007_ooooo002/oooo
o`04o`000?oooooo0000o`0001_ooooo1?l0002Iooooo`00[?ooool01?l0003oooooo`000?l0000K
ooooo`Co00006Oooool2o`0007kooooo002/ooooo`?o00007Oooool2o`0001[ooooo0_l0001noooo
o`00Zoooool2o`0001oooooo0_l0002Jooooo`00Zoooool2o`000;_ooooo002Jooooo`;o00004?oo
ool00ol0003oooooooooo`2iooooo`00V_ooool2o`00013ooooo00?o0000ooooooooool02Oooool2
o`0000kooooo0_l0002Nooooo`00[?ooool00ol0003oooooooooo`09ooooo`;o00003_ooool2o`00
09kooooo002Yooooo`;o000000?oooooo`000?ooool0^_ooool008[ooooo0_l0000Jooooo`;o0000
00Goooooo`000?l0003oooooo`000008ooooo`?o0000/?ooool008[ooooo0_l0000Jooooo`;o0000
1?ooool3o`0000Kooooo0ol0002`ooooo`00Yoooool2o`0000?ooooo00?o0000ooooooooool01Ooo
ool2o`0001;ooooo0_l0002Nooooo`00Y_ooool3o`0000?ooooo00?o0000ooooooooool01Oooool2
o`0001;ooooo0_l0002Nooooo`00U?ooool2o`00013ooooo0_l00004ooooo`03o`000?oooooooooo
01Gooooo0_l0002Rooooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool05Oooool2o`000003
ooooool0003o000009oooooo0023ooooo`;o00009oooool00ol0003oooooooooo`0Hooooo`;o0000
Woooool008?ooooo0_l0000Wooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`?o00004_ooool2o`000:Gooooo002<ooooo`;o00007_ooool00ol0003o
ooooooooo`0Booooo`;o0000YOooool008cooooo0_l00009ooooo`;o00004oooool00ol0003ooooo
ooooo`0Eooooo`;o0000X_ooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo01Gooooo0_l0
002Rooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00Z_ooool3o`000;_ooooo002Yooooo`Co0000^ooo
ool00:Wooooo0_l000001?oooooo0000o`000?l0000/ooooo`;o0000Roooool008Gooooo0_l0000U
ooooo`03o`000?oooooooooo02cooooo0_l0002;ooooo`00QOooool2o`0000Sooooo0_l0000Eoooo
o`;o00001?ooool00ol0003oooooooooo`2iooooo`00QOooool2o`0000Sooooo0_l0000?ooooo`Co
00000_ooool2o`0000Cooooo00?o0000ooooooooool02_ooool3o`000:cooooo002Oooooo`Go0000
00?oooooo`000?l000001Oooool00ol0003oooooooooo`0:ooooo`?o0000[?ooool008Wooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool01?l0003ok^k^ooooooooool8o`0000Go
oooo00?o0000ooooooooool03Oooool2o`000:[ooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool00oooool2o`0000;ooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`0=ooooo`;o00005oooool2o`00097ooooo0029ooooo`05oa0@
4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02?ooool2o`0001cooooo0_l0002Aooooo`00ROooool01Ol0003ooooo
oooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`?o
00002?ooool2o`0001_ooooo0_l0002Booooo`00ROooool01Ol0003ooooooooooooooooo000000?o
oooo0_l00009ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005oooo
o`03o`000?oooooooooo02?ooooo1?l0002Booooo`00ROooool01Ol@413ooooooooooooooooo410@
00?ooooo0_l00009ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Sooooo`;o0000U?ooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04oooo
o`;o00001Oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`2iooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo0_l00005
ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool01Oooool2o`000;;ooooo002Coooo
o`;o00005oooool00ol0003oooooooooo`05ooooo`;o0000/_ooool009?ooooo0_l0000Gooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o00007ooo
ool2o`0009Sooooo002/ooooo`03o`000?oooooooooo00;o00007Oooool2o`0009Sooooo002Foooo
o`;o00005?ooool00ol0003oooooooooo`03o`000;Kooooo002Fooooo`;o00005?ooool01?l0003o
ooooooooooooool2o`000;Kooooo002/ooooo`03o`000?oooooooooo00;ooooo0_l0000Iooooo`;o
0000V_ooool00:cooooo00?o0000ooooooooool00_ooool2o`0001Wooooo0_l0002Jooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`02o`000;Oooooo002/oooo
o`Go00006?ooool2o`0009gooooo002Iooooo`Co00003oooool01?l0003oooooo`000?l0000Ioooo
o`;o0000WOooool009Wooooo1?l0000?ooooo`03o`000?oooooooooo0;Wooooo002Nooooo`;o0000
1oooool2o`000004ooooool0003o0000o`000;_ooooo002Kooooo`;o000000?oooooo`000?l00000
1oooool6o`000;_ooooo002Kooooo`;o00002Oooool5o`000003ooooool0003ooooo0;[ooooo002L
ooooo`;o000000?oooooo`000?l000001Oooool5o`000003ooooool0003ooooo0;[ooooo002<oooo
o`;o00003_ooool2o`000003ooooool0003o000000?o00001Oooool2o`000003ooooool0003ooooo
0;[ooooo002<ooooo`;o00004_ooool4o`0000Sooooo00?o0000ooooooooool0^Oooool00:cooooo
0ol0002iooooo`00[?ooool00ol0003oooooooooo`0@ooooo`;o0000Yoooool00:cooooo00?o0000
ooooooooool04?ooool2o`000:Oooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00cooooo0_l0002[ooooo`00T?ooool2o`00
01[ooooo0ol0000<ooooo`;o0000Zoooool0093ooooo0_l0000Jooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`03o`000?oooooooooo00Wooooo0_l0002^ooooo`00[?ooool00ol0003oooooooooo`09oooo
o`;o0000[_ooool00:;ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0;Wo
oooo002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o
0000ooooooooool01Oooool3o`000;Wooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Toooo
o`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`00
0?oooooooooo0<7ooooo002Rooooo`03oeEEEOmVIVKo00000<?ooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo002Zooooo`04oa0@4?l0003o0000o`000;[ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`06o`000?mgMgOo0000o`000?mEEEGok^k^]oooool00:_ooooo00Ko0000oeEEEOo^k^koooooogMg
MomEEEFgooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo0;Gooooo002[
ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0]Oooool00:_ooooo00Ko0000oeEE
EOo^k^koooooogMgMomVIVJgooooo`00Z_ooool00ol@413o0000ogMgM`02o`000003ofIVI_o^k^ko
oooo0;Kooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.45079 .11717 Mdot
.56556 .19871 Mdot
.49061 .61685 Mdot
.53 .64645 Mdot
.48632 .81302 Mdot
.41934 .79278 Mdot
.49074 .65857 Mdot
.51424 .03557 Mdot
.42099 .09372 Mdot
.44156 .26597 Mdot
.52855 .29941 Mdot
.59109 .12769 Mdot
.657 .38752 Mdot
.47903 .21495 Mdot
.63548 .20162 Mdot
.45631 .7509 Mdot
.6118 .52688 Mdot
.65974 .3967 Mdot
.57474 .57095 Mdot
.63072 .74436 Mdot
.66418 .44836 Mdot
.62169 .30846 Mdot
.64262 .3794 Mdot
.6655 .42959 Mdot
.68136 .27572 Mdot
.4263 .24345 Mdot
.56056 .40563 Mdot
.5712 .57927 Mdot
.60531 .79246 Mdot
.58463 .23529 Mdot
.66479 .5249 Mdot
.4037 .1477 Mdot
.50643 .03477 Mdot
.58879 .66393 Mdot
.56672 .7396 Mdot
.62188 .73854 Mdot
.4217 .89336 Mdot
.57371 .52191 Mdot
.54869 .87344 Mdot
.59267 .12477 Mdot
.66846 .24027 Mdot
.5817 .69719 Mdot
.48977 .86969 Mdot
.44602 .11764 Mdot
.4027 .26767 Mdot
.41472 .68338 Mdot
.49453 .23456 Mdot
.36964 .46003 Mdot
.54376 .24817 Mdot
.58621 .8169 Mdot
.37043 .44137 Mdot
.53024 .90518 Mdot
.5801 .94924 Mdot
.51782 .82726 Mdot
.53407 .80748 Mdot
.46592 .02353 Mdot
.53254 .0565 Mdot
.6137 .50372 Mdot
.38048 .69894 Mdot
.39438 .33402 Mdot
.40401 .57422 Mdot
.74834 .45821 Mdot
.52994 .89625 Mdot
.4888 .26923 Mdot
.54179 .08148 Mdot
.42452 .07873 Mdot
.44021 .27257 Mdot
.45605 .74537 Mdot
.57598 .50192 Mdot
.66995 .47277 Mdot
.61859 .49925 Mdot
.43503 .55547 Mdot
.45971 .23267 Mdot
.4169 .41698 Mdot
.52982 .89632 Mdot
.44232 .51063 Mdot
.5793 .95009 Mdot
.4217 .27906 Mdot
.55236 .87563 Mdot
.55516 .28765 Mdot
.65602 .62397 Mdot
.58429 .23721 Mdot
.53564 .61812 Mdot
.58178 .7004 Mdot
.47418 .01208 Mdot
.46775 .76732 Mdot
.47863 .81763 Mdot
.42509 .72476 Mdot
.61115 .45062 Mdot
.44866 .73122 Mdot
.6872 .29065 Mdot
.7014 .75585 Mdot
.5302 .36699 Mdot
.42853 .74657 Mdot
.52211 .34433 Mdot
.72192 .7121 Mdot
.47413 .2152 Mdot
.37977 .30506 Mdot
.56999 .96198 Mdot
.61134 .43358 Mdot
.48231 .10232 Mdot
.59994 .3867 Mdot
.60188 .14591 Mdot
.47658 .09565 Mdot
.66976 .5532 Mdot
.58332 .68278 Mdot
.61627 .54549 Mdot
.56937 .61102 Mdot
.53081 .36866 Mdot
.66971 .48906 Mdot
.45437 .23294 Mdot
.53989 .61082 Mdot
.40367 .14925 Mdot
.6403 .71081 Mdot
.39419 .92257 Mdot
.53146 .52333 Mdot
.40361 .43284 Mdot
.418 .08906 Mdot
.40671 .12897 Mdot
.40691 .8388 Mdot
.65768 .39502 Mdot
.73828 .40021 Mdot
.65817 .45068 Mdot
.60743 .79133 Mdot
.6702 .48322 Mdot
.51353 .69575 Mdot
.62531 .74421 Mdot
.7349 .67039 Mdot
.55721 .19879 Mdot
.48637 .70759 Mdot
.63754 .35258 Mdot
.51784 .13941 Mdot
.62218 .1707 Mdot
.42321 .81042 Mdot
.46242 .87426 Mdot
.58241 .83408 Mdot
.4725 .96282 Mdot
.61081 .77749 Mdot
.45812 .23552 Mdot
.54669 .08026 Mdot
.63515 .19806 Mdot
.74706 .56473 Mdot
.55043 .49191 Mdot
.57743 .52428 Mdot
.61232 .52379 Mdot
.63772 .72445 Mdot
.45114 .02565 Mdot
.35264 .62744 Mdot
.54032 .69499 Mdot
.4174 .6877 Mdot
.72547 .34299 Mdot
.59336 .3612 Mdot
.56811 .4186 Mdot
.66616 .42627 Mdot
.44075 .60565 Mdot
.38897 .47906 Mdot
.47822 .9583 Mdot
.53181 .8974 Mdot
.43047 .06145 Mdot
.41323 .86618 Mdot
.47718 .9595 Mdot
.47744 .15942 Mdot
.56145 .86513 Mdot
.64159 .18485 Mdot
.6335 .7043 Mdot
.46858 .87079 Mdot
.4886 .10889 Mdot
.44856 .02963 Mdot
.66972 .57072 Mdot
.57522 .49135 Mdot
.50255 .945 Mdot
.59177 .80109 Mdot
.54411 .45669 Mdot
.57212 .47252 Mdot
.45927 .80725 Mdot
.53841 .70514 Mdot
.52986 .06327 Mdot
.7253 .70094 Mdot
.38908 .49396 Mdot
.52737 .5497 Mdot
.58484 .82341 Mdot
.53075 .91032 Mdot
.6202 .16186 Mdot
.42011 .61581 Mdot
.67432 .25001 Mdot
.44089 .65871 Mdot
.42435 .08797 Mdot
.73147 .67561 Mdot
.38521 .2415 Mdot
.63753 .18062 Mdot
.48281 .87673 Mdot
.72806 .36704 Mdot
.63975 .72074 Mdot
.46315 .27197 Mdot
.74457 .45415 Mdot
.49658 .02002 Mdot
.68856 .2685 Mdot
.60964 .15462 Mdot
.43552 .76746 Mdot
.69145 .78624 Mdot
.61408 .58798 Mdot
.52692 .46806 Mdot
.52785 .48017 Mdot
.43296 .51064 Mdot
.47727 .81341 Mdot
.6763 .81367 Mdot
.50833 .12904 Mdot
.43005 .39627 Mdot
.40182 .7031 Mdot
.54756 .57582 Mdot
.43111 .61363 Mdot
.52905 .29734 Mdot
.63842 .3327 Mdot
.41466 .31899 Mdot
.66909 .57468 Mdot
.4228 .62971 Mdot
.49811 .11772 Mdot
.40975 .36223 Mdot
.64773 .1954 Mdot
.44842 .68936 Mdot
.3993 .30326 Mdot
.57123 .09776 Mdot
.40228 .47432 Mdot
.37169 .5507 Mdot
.67202 .5494 Mdot
.64633 .66032 Mdot
.42768 .65465 Mdot
.51782 .75933 Mdot
.53838 .15537 Mdot
.54103 .4252 Mdot
.63628 .20222 Mdot
.74079 .40039 Mdot
.4893 .75407 Mdot
.51087 .43924 Mdot
.65854 .83738 Mdot
.58433 .34903 Mdot
.5552 .3753 Mdot
.73429 .39148 Mdot
.57372 .49307 Mdot
.49113 .10053 Mdot
.65633 .41807 Mdot
.50591 .12359 Mdot
.748 .46555 Mdot
.4568 .87426 Mdot
.66746 .60387 Mdot
.61849 .49829 Mdot
.3948 .18447 Mdot
.52009 .34263 Mdot
.46244 .95092 Mdot
.60654 .46486 Mdot
.61828 .49139 Mdot
.53538 .89097 Mdot
.68629 .26703 Mdot
.53129 .52 Mdot
.47305 .26838 Mdot
.43645 .92074 Mdot
.44781 .18891 Mdot
.57106 .46581 Mdot
.53542 .81085 Mdot
.4423 .477 Mdot
.53411 .0613 Mdot
.37134 .5807 Mdot
.56554 .29527 Mdot
.55456 .37268 Mdot
.64322 .67384 Mdot
.51221 .64158 Mdot
.59388 .36973 Mdot
.43899 .13994 Mdot
.51228 .26958 Mdot
.41746 .77639 Mdot
.60643 .77104 Mdot
.49154 .17365 Mdot
.62764 .73349 Mdot
.52955 .817 Mdot
.43263 .29493 Mdot
.55952 .28982 Mdot
.48945 .95451 Mdot
.41891 .60876 Mdot
.55227 .6809 Mdot
.37397 .36411 Mdot
.5167 .26762 Mdot
.39049 .57856 Mdot
.57687 .8382 Mdot
.49937 .69074 Mdot
.41572 .45829 Mdot
.40889 .84962 Mdot
.58495 .12307 Mdot
.56907 .61488 Mdot
.4584 .66569 Mdot
.49082 .79815 Mdot
.65691 .66545 Mdot
.41334 .66478 Mdot
.65805 .60748 Mdot
.72917 .68006 Mdot
.37946 .68208 Mdot
.61266 .16646 Mdot
.37368 .59202 Mdot
.51532 .54076 Mdot
.40313 .83854 Mdot
.74032 .44862 Mdot
.66592 .63019 Mdot
.62833 .19067 Mdot
.34912 .45457 Mdot
.54262 .25241 Mdot
.50512 .85945 Mdot
.51829 .13808 Mdot
.39915 .16506 Mdot
.66962 .24789 Mdot
.50145 .24443 Mdot
.37588 .34254 Mdot
.45605 .17548 Mdot
.51499 .39284 Mdot
.63998 .34289 Mdot
.61211 .53994 Mdot
.65569 .39413 Mdot
.72023 .33174 Mdot
.52762 .56516 Mdot
.41127 .23027 Mdot
.58336 .68597 Mdot
.55676 .09827 Mdot
.51577 .63272 Mdot
.62827 .17454 Mdot
.72415 .37943 Mdot
.75171 .57175 Mdot
.49421 .74292 Mdot
.42826 .82816 Mdot
.58448 .69648 Mdot
.50856 .92432 Mdot
.52539 .74759 Mdot
.51983 .40579 Mdot
.50661 .60283 Mdot
.61604 .53271 Mdot
.54994 .07348 Mdot
.4315 .90877 Mdot
.51728 .32858 Mdot
.62987 .31774 Mdot
.48482 .71118 Mdot
.43294 .49591 Mdot
.54471 .16457 Mdot
.43218 .8332 Mdot
.46828 .87093 Mdot
.47984 .16029 Mdot
.48317 .81004 Mdot
.61313 .91019 Mdot
.46929 .16791 Mdot
.57867 .23162 Mdot
.49706 .28397 Mdot
.49404 .02627 Mdot
.55715 .3925 Mdot
.61311 .77123 Mdot
.60947 .29051 Mdot
.54415 .42494 Mdot
.4039 .473 Mdot
.74826 .5576 Mdot
.58083 .11318 Mdot
.41492 .88348 Mdot
.61994 .74539 Mdot
.52354 .21608 Mdot
.61024 .59735 Mdot
.60154 .78481 Mdot
.58885 .35756 Mdot
.58211 .11539 Mdot
.75617 .56328 Mdot
.66639 .61136 Mdot
.62181 .1713 Mdot
.63391 .18292 Mdot
.66433 .22611 Mdot
.43877 .39922 Mdot
.57497 .32348 Mdot
.63933 .20582 Mdot
.53074 .05597 Mdot
.44236 .37558 Mdot
.66386 .57088 Mdot
.48633 .17372 Mdot
.40577 .73239 Mdot
.47324 .10162 Mdot
.38785 .23872 Mdot
.4914 .10133 Mdot
.40789 .85202 Mdot
.45877 .94409 Mdot
.63995 .3721 Mdot
.43558 .93314 Mdot
.63572 .35063 Mdot
.66757 .24956 Mdot
.37687 .84626 Mdot
.39019 .75417 Mdot
.38826 .48661 Mdot
.44078 .59909 Mdot
.71025 .33512 Mdot
.60877 .42737 Mdot
.50915 .58822 Mdot
.62084 .16047 Mdot
.67043 .47849 Mdot
.51596 .38605 Mdot
.42297 .35618 Mdot
.4156 .30065 Mdot
.56108 .39939 Mdot
.37017 .42757 Mdot
.67633 .53657 Mdot
.74321 .45671 Mdot
.6243 .16729 Mdot
.60636 .59611 Mdot
.61318 .90563 Mdot
.60735 .60191 Mdot
.54448 .69011 Mdot
.54051 .70625 Mdot
.47976 .34117 Mdot
.54871 .07391 Mdot
.58911 .12567 Mdot
.55892 .39779 Mdot
.5452 .44403 Mdot
.54483 .32889 Mdot
.44456 .73392 Mdot
.70887 .31007 Mdot
.44324 .79026 Mdot
.64059 .6892 Mdot
.5485 .53775 Mdot
.5701 .43342 Mdot
.50676 .6625 Mdot
.45763 .81085 Mdot
.59345 .64616 Mdot
.55964 .38345 Mdot
.43433 .36368 Mdot
.73284 .37269 Mdot
.5413 .07365 Mdot
.50029 .4483 Mdot
.56047 .75413 Mdot
.61604 .54707 Mdot
.40108 .30173 Mdot
.50113 .18991 Mdot
.57344 .47387 Mdot
.70965 .32785 Mdot
.72031 .72445 Mdot
.5144 .12937 Mdot
.45381 .10558 Mdot
.43861 .33628 Mdot
.45412 .03781 Mdot
.64636 .21779 Mdot
.53906 .32878 Mdot
.61338 .30251 Mdot
.60367 .92158 Mdot
.54727 .46552 Mdot
.50434 .34663 Mdot
.52453 .73717 Mdot
.64836 .66052 Mdot
.53687 .24863 Mdot
.69603 .77283 Mdot
.43388 .62601 Mdot
.53525 .79589 Mdot
.59097 .67474 Mdot
.50419 .29501 Mdot
.52531 .57534 Mdot
.41385 .5191 Mdot
.51826 .04026 Mdot
.52628 .58312 Mdot
.56835 .85365 Mdot
.54508 .16838 Mdot
.4098 .23265 Mdot
.62798 .73615 Mdot
.66023 .5875 Mdot
.61102 .56361 Mdot
.74399 .64994 Mdot
.42569 .33653 Mdot
.55328 .07687 Mdot
.68318 .25886 Mdot
.51728 .28179 Mdot
.40781 .8582 Mdot
.49726 .18235 Mdot
.60938 .52096 Mdot
.61695 .76432 Mdot
.47836 .10039 Mdot
.57034 .59755 Mdot
.40374 .47471 Mdot
.59375 .65056 Mdot
.74852 .43269 Mdot
.45071 .85984 Mdot
.44453 .55684 Mdot
.48994 .86654 Mdot
.55447 .28357 Mdot
.43426 .44024 Mdot
.47508 .75681 Mdot
.52574 .81503 Mdot
.481 .8787 Mdot
.53002 .49521 Mdot
.43987 .20802 Mdot
.42789 .07087 Mdot
.49967 .79796 Mdot
.42775 .16881 Mdot
.57835 .48435 Mdot
.56427 .60706 Mdot
.46018 .31701 Mdot
.41418 .98544 Mdot
.47003 .30668 Mdot
.55542 .18163 Mdot
.37215 .45032 Mdot
.63444 .70455 Mdot
.57625 .51748 Mdot
.60081 .79611 Mdot
.61012 .14972 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:?ooooo0_l00007
ooooo`03o`000?oooooooooo0;Wooooo002Rooooo`03oeEEEOl0003o000000Oooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:[ooooo0ol0002kooooo`00Vooo
ool2o`0000?ooooo0_l00008ooooo`Go0000^Oooool009_ooooo0_l00003ooooo`;o00002?ooool3
o`000;_ooooo002Kooooo`;o00003Oooool3o`000;_ooooo002Kooooo`;o00003oooool01?l0003o
ooooo`000?l0002hooooo`00W?ooool2o`0000kooooo00?o0000ooooool000000ol0002fooooo`00
W?ooool2o`0000kooooo00Co0000oooooooooooooooo1?l0002dooooo`00[?ooool00ol0003ooooo
ooooo`03ooooo`;o0000]?ooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`07ooooo`;o
0000/?ooool00:cooooo00?o0000ooooooooool01oooool2o`000;3ooooo002Eooooo`;o00005Ooo
ool00ol0003oooooooooo`07ooooo`?o0000[oooool009Gooooo0_l0000Eooooo`03o`000?oooooo
oooo00Kooooo1?l0002_ooooo`00[?ooool00ol0003oooooooooo`06ooooo`;o0000/Oooool009Co
oooo0_l0000Fooooo`03o`000?oooooooooo0;Wooooo002Dooooo`;o00005_ooool00ol0003ooooo
ooooo`0:ooooo`;o000000?oooooo`000?l00000Z_ooool00:cooooo0ol0000:ooooo`;o000000Co
ooooo`000?l0003o0000ZOooool009?ooooo0_l0000Gooooo`03o`000?oooooooooo00cooooo1?l0
002Yooooo`00Toooool2o`0001Oooooo00?o0000ooooooooool02_ooool4o`000:_ooooo002/oooo
o`03o`000?oooooooooo00[ooooo0_l0002]ooooo`00T?ooool2o`000003ooooool0003o000001Oo
oooo00?o0000ooooooooool0^Oooool0093ooooo0_l000000ooooooo0000o`00000Gooooo`03o`00
0?oooooooooo0;Wooooo002Aooooo`;o00006Oooool00ol0003oooooooooo`2iooooo`00TOooool2
o`00017ooooo0_l00006ooooo`03o`000?oooooooooo00oooooo0_l00003ooooo`;o0000Xoooool0
0:?ooooo0ol00003ooooo`;o000000Coooooo`000?l0003o00003oooool2o`0000?ooooo0_l0002S
ooooo`00Xoooool5o`000005ooooool0003o0000ooooool00000^oooool009cooooo0_l00008oooo
o`;o00001?ooool00ol0003oooooooooo`2iooooo`00W?ooool2o`0000[ooooo0_l00002ooooo`03
o`000?oooooooooo0;Wooooo002Xooooo`;o00000_ooool00ol0003oooooooooo`0Gooooo`;o0000
X?ooool00:cooooo00?o0000ooooooooool05oooool3o`0009oooooo0029ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo0ol00005ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1?ooool2o`0001[ooooo0_l0002Oooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B45ooooo`?o00002?ooool00omgMgOo<S8booooo`03ooooo`;o0000^oooool0087ooooo1_l0
0002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`00
0?oooooooooo00?ooooo1?l0000Hooooo`Co0000W?ooool008Wooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool01?l0003ooooo
o`000?l0000Hooooo`Co0000W?ooool008Wooooo00Co0000oooooooooooooooo0_l0000=ooooo`03
oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo0000
00?o00006?ooool2o`0009cooooo0029ooooo`04oa0@4?ooooooooooooooo`;o00003Oooool00onY
ZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000000ol0002foooo
o`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0^Oooool008Wooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP09ooooo`Oo00001?ooool4o`0000Kooooo00?o0000ooooooooool00_ooool3
o`000;Cooooo002Gooooo`;o00004oooool00ol0003oooooooooo`02ooooo`?o0000]?ooool00:co
oooo00?o0000ooooooooool07_ooool2o`0009Wooooo002<ooooo`;o00007_ooool00ol0003ooooo
ooooo`0Nooooo`;o000000?oooooo`000?l00000U_ooool008cooooo0_l0000Nooooo`?o00008Ooo
ool2o`0009Kooooo002/ooooo`03o`000?oooooooooo00Wooooo0_l0000Fooooo`;o0000U_ooool0
0:cooooo00?o0000ooooooooool02Oooool2o`0001Kooooo0_l0002Fooooo`00Y?ooool3o`0000Go
oooo00?o0000ooooooooool09?ooool2o`0009?ooooo002:ooooo`;o00006?ooool3o`0000Gooooo
00?o0000ooooooooool02oooool2o`0001Oooooo0_l0002Cooooo`00R_ooool2o`0001Gooooo0_l0
0009ooooo`03o`000?oooooooooo00_ooooo0_l0000Eooooo`;o00000_ooool2o`00097ooooo002D
ooooo`;o00002oooool2o`0000Wooooo00?o0000ooooooooool02oooool2o`0001Gooooo0_l00000
1?oooooo0000o`000?l0002Aooooo`00U?ooool2o`00017ooooo1?l000000ooooooo0000ooooo`0<
ooooo`;o00006?ooool2o`0009;ooooo002Mooooo`;o00002?ooool4o`000004ooooool0003o0000
o`0002Oooooo0_l0002@ooooo`00WOooool2o`0000gooooo00?o0000ooooooooool09oooool2o`00
093ooooo002[ooooo`;o00004Oooool2o`0001Sooooo0ol0002=ooooo`00ROooool2o`00023ooooo
0_l0000Aooooo`;o00006?ooool4o`0008cooooo0029ooooo`;o00003oooool2o`00013ooooo00?o
0000ooooooooool0:oooool2o`0008cooooo002Jooooo`;o00004?ooool2o`0002Sooooo0_l0002@
ooooo`00[?ooool2o`0002Sooooo0_l00004ooooo`;o0000R_ooool00:cooooo00?o0000oooooooo
ool0:Oooool2o`0000;ooooo0_l0002:ooooo`00[?ooool3o`0000oooooo0_l000000ooooooo0000
o`00000Eooooo`;o0000S_ooool00:cooooo00?o0000ooooooooool03oooool2o`000003ooooool0
003o000001Gooooo0ol0002=ooooo`00[?ooool00ol0003oooooooooo`0Zooooo`?o0000S?ooool0
09Sooooo0_l0000Booooo`03o`000?oooooooooo02_ooooo0_l0002<ooooo`00V?ooool2o`0001;o
oooo00?o0000ooooooooool0^Oooool00:?ooooo1?l00005ooooo`03o`000?oooooooooo00Cooooo
0_l0002cooooo`00Xoooool4o`0000Gooooo00?o0000ooooooooool01?ooool2o`0002Oooooo0_l0
002:ooooo`00[?ooool00ol0003oooooooooo`0]ooooo`;o0000R_ooool00:cooooo0ol0002ioooo
o`00[?ooool00ol0003oooooooooo`0cooooo`;o0000Q?ooool008kooooo0_l0000Looooo`03o`00
0?oooooooooo01Oooooo0_l0000Jooooo`;o0000Q?ooool008kooooo0_l0000<ooooo`Co00002_oo
ool3o`0001Wooooo0_l0002Pooooo`00S_ooool2o`0000cooooo1?l0000:ooooo`?o00006_ooool3
o`0009kooooo0027ooooo`;o00005Oooool2o`0000cooooo00?o0000ooooooooool06?ooool3o`00
01Wooooo0_l00023ooooo`00Q_ooool3o`0000Sooooo00Gok^k^oc8b<_l0003o0000onk^kP05oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0=?ooool2
o`0008?ooooo0026ooooo`;o00002Oooool01OmgMgOoV9RHo`000?l0003oMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00Cooooo0_l0002jooooo`00ROooool6o`0000;ooooo00Go410@oooo
oooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0_l0000:ooooo`Co00009oooool4
o`00087ooooo002Aooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04
ooooo`?o00002Oooool4o`0002Oooooo1?l00021ooooo`00TOooool01Ol0003ooooooooooooooooo
000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00_ooooo0_l0
002/ooooo`00TOooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0iooooo`;o0000O_ooool0097ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>Oooool2o`0007kooooo002A
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0^Ooo
ool008_ooooo0_l0000;ooooo`;o00004_ooool00ol0003oooooooooo`02ooooo`;o0000=_ooool2
o`0007gooooo002;ooooo`;o00002oooool2o`0000Wooooo0_l00003ooooo`;o00000_ooool01?l0
003oooooooooooooool3o`0003Kooooo0ol0001looooo`00V?ooool2o`0000Gooooo0_l00002oooo
o`;o00000oooool2o`0000;ooooo00Co0000oooooooooooooooo0_l0000hooooo`;o0000O?ooool0
09Sooooo0_l00005ooooo`;o00002oooool3o`0003Sooooo0_l0001oooooo`00T_ooool2o`0001So
oooo00?o0000ooooooooool0>?ooool2o`0007oooooo002Booooo`;o00006?ooool00ol0003ooooo
ooooo`02ooooo`;o0000]Oooool00:_ooooo0_l00004ooooo`;o00002oooool2o`000:Sooooo002[
ooooo`;o00004Oooool2o`000:Sooooo002/ooooo`03o`000?oooooooooo00oooooo0ol0000?oooo
o`;o00005oooool2o`0007gooooo002Eooooo`;o00005Oooool3o`00013ooooo1?l0000=ooooo`;o
00005oooool2o`0007gooooo002Eooooo`;o00005Oooool3o`0000Kooooo0_l0000:ooooo`;o0000
YOooool0093ooooo0_l0000Jooooo`?o00001_ooool2o`000;7ooooo002:ooooo`?o00000oooool2
o`0001[ooooo00?o0000ooooooooool01_ooool2o`0001[ooooo0_l0002Eooooo`00Q?ooool2o`00
00Cooooo0ol0000Eooooo`;o00002?ooool00ol0003oooooooooo`0Rooooo`;o0000UOooool008Co
oooo0_l0000Looooo`;o00002?ooool00ol0003oooooooooo`0Uooooo`;o00006oooool2o`0007Go
oooo002/ooooo`03o`000?oooooooooo02Gooooo0_l0000Kooooo`;o0000MOooool00:cooooo00?o
0000ooooooooool0^Oooool008oooooo0_l0000=ooooo`;o00003?ooool00ol0003oooooooooo`0W
ooooo`;o0000T?ooool008oooooo0_l0000=ooooo`;o00003?ooool00ol0003oooooooooo`0Woooo
o`;o0000T?ooool00:cooooo0ol0000Eooooo`;o0000X_ooool00:cooooo00?o0000ooooooooool0
0_ooool2o`0000Gooooo0_l0000:ooooo`;o0000:oooool2o`0007Gooooo002/ooooo`03o`000?oo
oooooooo00;ooooo0_l00005ooooo`Co0000=Oooool2o`000003ooooool0003o000007;ooooo0029
ooooo`;o00008Oooool00ol0003oooooooooo`0;ooooo`;o00007Oooool2o`0001Wooooo0_l0001b
ooooo`00ROooool2o`0000Sooooo0_l00002ooooo`;o00004oooool00ol0003oooooooooo`0Zoooo
o`;o00005_ooool2o`0007Gooooo002Cooooo`;o00000_ooool2o`0001?ooooo00?o0000oooooooo
ool0@_ooool2o`0007Gooooo0023ooooo`;o00008?ooool2o`0000Gooooo00?o0000ooooooooool0
0oooool2o`0002Kooooo0_l0000Jooooo`;o0000L?ooool008?ooooo0_l0000Pooooo`;o00001Ooo
ool3o`0000?ooooo0ol0000Uooooo`;o00006_ooool2o`00073ooooo002/ooooo`?o00001?ooool2
o`0001;ooooo0_l0002Oooooo`00[?ooool3o`0001Sooooo0_l0000?ooooo`?o0000SOooool00:co
oooo00?o0000ooooooooool0:Oooool3o`0008gooooo002Booooo`;o00006?ooool00ol0003ooooo
ooooo`0Jooooo`;o0000WOooool009;ooooo0_l0000Hooooo`03o`000?oooooooooo01[ooooo0ol0
002Looooo`00P_ooool2o`0000[ooooo0_l00006ooooo`;o00005?ooool00ol0003oooooooooo`0K
ooooo`;o0000W?ooool008;ooooo0_l00005ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_l00003
ooooo`;o8B4Q00Coooooo`000?l0003ooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1Oooool00ol0003oooooooooo`07ooooo`;o0000?oooool2o`0006oooooo0029ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool01oooool2o`0001?ooooo0_l0000Zooooo`;o
0000Koooool0087ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool2o`0000Ko
oooo0_l0000;ooooo`;o00003Oooool2o`0001cooooo0_l0001^ooooo`00ROooool01Ol0003ooooo
oooooooooooo000000_ooooo0_l000000onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Co
oooo0ol0000?ooooo`;o00006_ooool2o`0001cooooo0_l0001^ooooo`00ROooool01Ol0003ooooo
oooooooooooo000000_ooooo0_l000000oooooooMgMgofIVIP04ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`0?ooooo`;o00006oooool2o`0001Wooooo0_l0001`oooo
o`00ROooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo02cooooo0_l0000Iooooo`;o0000L?ooool008Wo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo0_l0000<ooooo`;o0000Yoooool0
08Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?oo
ool4o`0000Kooooo00?o0000ooooooooool00_ooool2o`0000cooooo0_l0000<ooooo`;o00004?oo
ool2o`0008Oooooo002/ooooo`03o`000?oooooooooo01kooooo0_l0000@ooooo`;o00006?ooool2
o`0006gooooo002/ooooo`03o`000?oooooooooo00;ooooo0_l0000;ooooo`;o00007oooool3o`00
01Oooooo0_l0001]ooooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool00_ooool2o`0000_o
oooo0ol0000Nooooo`?o0000Q_ooool009Cooooo0_l000000ooooooo0000o`00000Cooooo`?o0000
4?ooool3o`0001kooooo0_l0000Hooooo`?o0000Joooool009Oooooo0_l0000Cooooo`03o`000?oo
oooooooo017ooooo0_l0000hooooo`?o0000Joooool00:cooooo00?o0000ooooooooool00oooool2
o`0000cooooo0_l0002Vooooo`00[?ooool00ol0003oooooooooo`03ooooo`;o00003?ooool2o`00
0:Kooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002@ooooo`;o00006_ooool00ol0003oooooooooo`0Cooooo`;o00006oooool2o`0008Oooooo002@
ooooo`;o00006_ooool00ol0003oooooooooo`0Cooooo`;o00006oooool2o`0008Oooooo002/oooo
o`?o00002_ooool3o`000:cooooo0021ooooo`;o0000:Oooool00ol0003oooooooooo`0:ooooo`?o
00004oooool2o`00017ooooo0_l00024ooooo`00POooool2o`0002Wooooo00?o0000ooooooooool0
8?ooool2o`00017ooooo0_l00024ooooo`00S?ooool2o`0001kooooo00?o0000ooooooooool05?oo
ool2o`0000_ooooo0_l0000@ooooo`;o00006_ooool2o`0006Sooooo002<ooooo`;o00007_ooool0
0ol0003oooooooooo`0Dooooo`;o00002oooool2o`0002cooooo0_l0001Xooooo`00U_ooool2o`00
01Cooooo00?o0000ooooooooool00_l0002gooooo`00POooool2o`0001?ooooo0_l0000Dooooo`03
o`000?oooooooooo00;o0000]oooool0087ooooo0_l0000Yooooo`03o`000?oooooooooo00_ooooo
0_l0002/ooooo`00[?ooool2o`0000cooooo0_l0000Vooooo`;o00005oooool2o`0006_ooooo0021
ooooo`;o0000:Oooool3o`00027ooooo0_l0000>ooooo`Co00005oooool2o`0006_ooooo001joooo
o`;o00001Oooool2o`0002Wooooo00?o0000ooooooooool08Oooool2o`0000kooooo0_l0000Joooo
o`;o0000J_ooool007[ooooo0_l0000Dooooo`;o00006_ooool00ol0003oooooooooo`0;ooooo`;o
0000@?ooool4o`0006Sooooo0009ooooo`Co000000?o410@ooooooooool05_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool2o`000003ob4Q
8Ooooooooooo00;ooooo1Ol00003ooooo`Co000000?o<S8bomgMgOooool05Oooool00ol0003ooooo
ooooo`0;ooooo`;o00002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go
00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`Co00001Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oM
gMd06?ooool4o`000003oa0@4?oooooooooo01;ooooo000;ooooo`03o`000?oooooooooo01Sooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03
ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool2o`000003ob4Q8Ooooooo
oooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo01Gooooo00?o
0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0_l00002ob4Q8@Cooooo
00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`0I
ooooo`03o`000?oooooooooo01Cooooo0006o`0000Gooooo00?o0000ooooooooool04?ooool6o`00
00;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000
ooooooooool01Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oo
oooooooo00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Q
onk^kP09ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01Oooool2o`0000Gooooo
0_l00006ooooo`;o00000_ooool01Ol@413ooooooooooooooooo410@00?ooooo0_l00007ooooo`03
oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool03Oooool01Ol@413ooooooooooooooooo410@
00Cooooo0_l0000:ooooo`03o`000?oooooooooo00gooooo00Go410@oooooooooooooooooa0@400=
ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0D
ooooo`002oooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool0
0olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00
000?ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool05Oooool00ol0003oooooooooo`05ooooo`;o0000
1Oooool2o`0000Kooooo0_l00002ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So
8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`000004oooo
o`;o00002Oooool00omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003_ooool0
0olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Wooooo00?o0000ooooooooool05?ooool0
00_ooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEE
olc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000oooooooooooooooo
o`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo0000
00kooooo00?oMgMgo`000?l000000oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Kooooo00?o0000
ooooooooool05?ooool3o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool0
0omgMgOoIVIVooooo`03ooooo`04o`000?lQ8B7o0000oc8b<P;o00003_ooool01Ol0003ooooooooo
oooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06_ooool0
0ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05oa0@4?oooooooooo
ooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo017ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooo
oa0@400>ooooo`?o00000oooool00ol0003oooooooooo`05ooooo`;o00004Oooool3o`0001Cooooo
0ol000000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooooooool2o`0000kooooo00Go410@oooooooooooooooooa0@400<oooo
o`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOo
oooo00?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0
003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooo
oooo<S8b00Cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo
00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo0_l000000onj^[[o
ooooo`000002o`0000?ooooo00?o0000ooooooooool01Oooool2o`00017ooooo00?o0000oooooooo
ool01_ooool2o`00013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001?ooool01?l0003oooooooooooooool2o`0000kooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0<ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
01Cooooo0009ooooo`03oeEEEOmVIVKo000001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`Go00001?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00004?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00[ooooo0_l000001?l@413o0000ob4Q8Oo<c<`4ooooo`Co0000
5oooool00ol0003oooooooooo`06ooooo`;o00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Ko00003_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0
000Iooooo`03oeEEEOmVIVKo000001Kooooo002/ooooo`03o`000?oooooooooo01Kooooo0_l0000M
ooooo`;o0000P_ooool008Oooooo0_l0000Sooooo`03o`000?oooooooooo01Kooooo0_l0000Moooo
o`;o0000P_ooool008Oooooo0_l0000Sooooo`03o`000?oooooooooo00gooooo0_l00006ooooo`;o
00003Oooool2o`0000oooooo0_l0001gooooo`;o00000_ooool2o`0000Gooooo0027ooooo`;o0000
8oooool00ol0003oooooooooo`06ooooo`;o00001Oooool2o`0000Kooooo0_l0000=ooooo`;o0000
R?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Gooooo0027ooooo`;o00003?ooool2o`0001Go
oooo00?o0000ooooooooool01_ooool2o`0000gooooo0_l0000=ooooo`;o0000ROooool01?oMgMgo
0000oa0@4?o<c<`6ooooo`001oooooooo`0004co00003?ooool01?o^k^ko8B4Qoa0@4?o^k^h6oooo
o`001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`04
o`000?ooooooooooooooo`Co000000?oooooo`000?ooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool01?lQ8B7oMgMgogMgMolb<S86
ooooo`001oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01Kooooo0_l0000:oooo
o`;o00000oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`09ooooo`;o00000_ooool2o`0000Gooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002Eooooo`;o00000_ooool2o`00017ooooo00?o0000ooooooooool0
^Oooool009Gooooo0_l00002ooooo`;o00004Oooool00ol0003oooooooooo`2iooooo`00Soooool2
o`0001_ooooo00?o0000ooooooooool05_ooool2o`000:7ooooo002?ooooo`;o00006oooool00ol0
003oooooooooo`07ooooo`;o00003?ooool3o`0000Wooooo0_l0002Fooooo`00[?ooool3o`0000Oo
oooo0_l0000<ooooo`?o00002Oooool3o`0000oooooo0_l00024ooooo`00[?ooool00ol0003ooooo
ooooo`07ooooo`;o00003Oooool2o`0000Wooooo0ol0000?ooooo`;o0000Q?ooool00:cooooo00?o
0000ooooooooool08Oooool2o`0009Kooooo002/ooooo`03o`000?oooooooooo02?ooooo0_l0002D
ooooo`00[?ooool00ol0003oooooooooo`0=ooooo`;o00005?ooool2o`0001;ooooo0_l00020oooo
o`00[?ooool00ol0003oooooooooo`02ooooo`;o00002Oooool2o`0001?ooooo0_l0000Cooooo`;o
0000P?ooool00:cooooo00?o0000ooooooooool00_ooool2o`0001kooooo0_l0002Eooooo`00[?oo
ool00ol0003oooooooooo`0Sooooo`;o0000U?ooool00:cooooo00?o0000ooooooooool01_ooool2
o`0001_ooooo0_l0000@ooooo`;o0000P_ooool0087ooooo0_l0000Yooooo`?o00001_ooool2o`00
01_ooooo0_l0000@ooooo`;o0000P_ooool0087ooooo0_l0000Cooooo`;o00005?ooool00ol0003o
ooooooooo`0eooooo`;o0000P_ooool009Kooooo0_l000000ooooooo0000o`00000Aooooo`03o`00
0?oooooooooo03Gooooo0_l0000Hooooo`;o0000J?ooool009Wooooo0_l0000Aooooo`03o`000?oo
oooooooo04oooooo0_l0001Xooooo`00[?ooool00ol0003oooooooooo`0Qooooo`;o0000:oooool2
o`000003ooooool0003o000006Kooooo002/ooooo`03o`000?oooooooooo00Kooooo0_l0000Ioooo
o`;o0000:oooool2o`000003ooooool0003o000006Kooooo002/ooooo`03o`000?oooooooooo00Ko
oooo0_l0000=ooooo`;o00007?ooool4o`0008;ooooo002<ooooo`;o00007_ooool00ol0003ooooo
ooooo`0Eooooo`;o00007?ooool4o`0001Wooooo0_l0001Wooooo`00S?ooool2o`0001kooooo0ol0
0005ooooo`;o00001Oooool2o`0002Kooooo0_l0000Jooooo`;o0000Ioooool008Oooooo0_l0000S
ooooo`03o`000?oooooooooo00Gooooo0_l00005ooooo`;o00001_ooool2o`0001kooooo0_l00023
ooooo`00POooool2o`0000Cooooo0_l0000Sooooo`03o`000?oooooooooo00Gooooo0_l0000=oooo
o`;o0000Xoooool0087ooooo0_l0000Yooooo`03o`000?oooooooooo00Gooooo0_l0002booooo`00
[?ooool00ol0003oooooooooo`02o`00023ooooo0_l0000=ooooo`;o0000Q_ooool008;ooooo0_l0
000Xooooo`03o`000?oooooooooo00;o00008?ooool2o`0000gooooo0_l00026ooooo`00P_ooool2
o`0002Sooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool05?ooool2o`00
00[ooooo0ol0002Fooooo`00V?ooool2o`0001;ooooo0ol0000Dooooo`;o00002_ooool3o`0009Ko
oooo002Hooooo`;o00004_ooool01?l0003oooooo`000?l0000Oooooo`;o00004_ooool2o`0008?o
oooo002Hooooo`;o00004_ooool01?l0003oooooo`000?l0000Aooooo`;o00003?ooool2o`0000oo
oooo0_l000000ooooooo0000o`000023ooooo`00TOooool2o`0000Gooooo0_l0000Booooo`03o`00
0?oooooooooo01;ooooo0_l0000Mooooo`;o0000Q_ooool0097ooooo0_l0000Iooooo`03o`000?oo
oooooooo00[ooooo0_l00007ooooo`;o00007_ooool2o`0008Cooooo002Aooooo`;o00000_ooool2
o`0001Gooooo00?o0000ooooooooool02_ooool2o`0000Oooooo0_l0000Nooooo`;o0000Q?ooool0
08Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`;o00000_lQ8B42o`0000;ooooo1Ol00004
ooooo`06odA4A?l0003o0000oc8b<_oMgMgooooo0_l00002ooooo`03o`000?oooooooooo00Sooooo
0_l00009ooooo`;o0000Y?ooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool00_l00002ooooo`03
o`000?oooooooooo00Sooooo0_l0002_ooooo`00ROooool01Ol@413ooooooooooooooooo410@00co
oooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000<?ooool2o`0008Oo
oooo001kooooo`;o00003?ooool01Ol0003ooooooooooooooooo000000Sooooo0_l00003ooooo`03
oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0`ooooo`;o
0000Qoooool007_ooooo0_l0000<ooooo`05o`000?ooooooooooooooool000001?ooool2o`0000;o
oooo0_l00004ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005oooo
o`03o`000?oooooooooo03?ooooo0_l00024ooooo`00ROooool01Ol@413ooooooooooooooooo410@
00Cooooo0_l00009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`02ooooo`;o0000;oooool2o`0008Cooooo0029ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`02ooooo`;o0000]Oooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool0^Ooo
ool00:cooooo00Co0000oooooooooooooooo0_l0002fooooo`00[?ooool01?l0003ooooooooooooo
ool2o`0000?ooooo0_l0000Cooooo`;o0000W?ooool00:cooooo00?o0000ooooooooool01_ooool2
o`0001?ooooo0_l0000`ooooo`;o0000J_ooool00:cooooo0ol0000Looooo`;o0000;oooool2o`00
06[ooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`0Looooo`;o0000Voooool009Cooooo
0_l00002ooooo`;o00003oooool2o`000003ooooool0003ooooo0;[ooooo002Hooooo`;o00003ooo
ool2o`000003ooooool0003ooooo02kooooo0ol00029ooooo`00Soooool2o`0001_ooooo00Co0000
ooooool0003o00006Oooool2o`00017ooooo0ol00029ooooo`00Soooool2o`0000gooooo0_l0000<
ooooo`04o`000?oooooo0000o`0001Wooooo0_l0000Dooooo`;o0000Qoooool009kooooo0_l0000<
ooooo`03o`000?oooooooooo033ooooo0_l0000Hooooo`;o0000KOooool00:cooooo00?o0000oooo
ooooool0;?ooool2o`0001cooooo0_l0001]ooooo`00[?ooool3o`0001_ooooo0_l0000?ooooo`;o
00006oooool2o`0006kooooo002/ooooo`03o`000?oooooooooo01_ooooo0_l0000[ooooo`?o0000
K_ooool008Cooooo0_l0000Vooooo`03o`000?oooooooooo00kooooo0_l00008ooooo`;o0000;_oo
ool2o`0006oooooo0024ooooo`;o00002Oooool2o`0001_ooooo00?o0000ooooooooool03_ooool2
o`0000Sooooo0_l0002Oooooo`00Soooool3o`0001[ooooo00?o0000ooooooooool06?ooool2o`00
017ooooo0_l0002<ooooo`00T?ooool2o`0000Wooooo0_l0000>ooooo`;o00003Oooool2o`0001ko
oooo0_l0002<ooooo`00Voooool2o`0000kooooo0_l0000<ooooo`?o0000[?ooool00:cooooo00Co
0000oooooooooooooooo0_l00007ooooo`;o00003?ooool2o`0009oooooo0024ooooo`;o00009_oo
ool3o`000003ooooool0003o000001Gooooo0_l0000]ooooo`;o0000L?ooool008Cooooo0_l00005
ooooo`;o00007oooool00ol0003oooooooooo`0Hooooo`;o00003oooool2o`0001cooooo0_l0001`
ooooo`00Roooool2o`0001oooooo00?o0000ooooooooool02Oooool3o`0001gooooo0_l0002>oooo
o`00Yoooool2o`0000?ooooo00?o0000ooooooooool02Oooool3o`0001gooooo0_l0002>ooooo`00
Yoooool2o`0000?ooooo00?o0000ooooooooool0:oooool2o`0001Wooooo0_l0001aooooo`00Yooo
ool2o`0000?ooooo00?o0000ooooooooool0:oooool2o`0001Wooooo0_l0001aooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0[ooooo`;o0000S?ooool009?o
oooo0_l0000Gooooo`?o0000:_ooool3o`0001Sooooo0_l0001booooo`00Toooool2o`0001Oooooo
00?o0000ooooooooool0:_ooool2o`0001Wooooo0_l0001booooo`00Voooool2o`0000oooooo00?o
0000ooooooooool0^Oooool008cooooo0_l0000;ooooo`Co00003oooool00ol0003oooooooooo`0W
ooooo`;o0000T?ooool008cooooo0_l0000;ooooo`;o00004Oooool00ol0003oooooooooo`05oooo
o`;o00008?ooool2o`00093ooooo002/ooooo`03o`000?oooooooooo00Gooooo0_l0000<ooooo`;o
00004?ooool4o`00093ooooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Go
oooo00GoA4A4o`000?l0003o<S8bomgMg@03ooooo`?o00005Oooool2o`00013ooooo0_l0002Boooo
o`00TOooool00omgMgOoV9RHooooo`02o`0000Gooooo0_lQ8B42o`0000Kooooo00?oMgMgoc8b<_oo
ool00_ooool3o`0002Kooooo1_l0002?ooooo`00TOooool00ol@413oooooooooo`02o`0000Oooooo
0_l00007ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool2o`0001gooooo
1_l0002?ooooo`00TOooool01Ol0003ooooooooooooooooo000000Oooooo0_l00006ooooo`03ogMg
Molb<S;ooooo00Cooooo0ol00005ooooo`;o0000/_ooool008Oooooo0_l00008ooooo`05o`000?oo
ooooooooooooool000001oooool2o`0000?ooooo00Ko0000ob4Q8Ol0003o<S8bolc<c?ooool2o`00
00;ooooo00?o0000ooooooooool04Oooool2o`0002cooooo0_l0001hooooo`00Qoooool2o`0000So
oooo00Go410@oooooooooooooooooa0@400<ooooo`?o00000oooool2o`0000;ooooo00?o0000oooo
ooooool04Oooool2o`0002cooooo0_l0001hooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo0ol00007ooooo`03o`000?oooooooooo00;ooooo0_l0002eooooo`00TOooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`03o`000?oooooooooo00;ooooo0_l0000Ooooo
o`;o0000U?ooool009Kooooo0_l00009ooooo`;o00002Oooool00ol0003oooooooooo`0Sooooo`;o
0000U?ooool009Kooooo0_l00009ooooo`;o00002Oooool00ol0003oooooooooo`0Pooooo`;o0000
Uoooool00:cooooo00?o0000ooooooooool08?ooool4o`0001Wooooo0_l0001jooooo`00T?ooool2
o`0001[ooooo0ol0000Rooooo`;o00006Oooool2o`0007[ooooo002@ooooo`;o00006_ooool00ol0
003oooooooooo`0Qooooo`;o0000U_ooool00:cooooo00?o0000ooooooooool08Oooool2o`0009Ko
oooo002/ooooo`03o`000?oooooooooo01kooooo0_l0000Looooo`;o0000Noooool00:cooooo00?o
0000ooooooooool07_ooool2o`0001cooooo0_l0001kooooo`00VOooool2o`00017ooooo00?o0000
ooooooooool08?ooool2o`0009Oooooo002Aooooo`;o00001_ooool2o`00017ooooo00?o0000oooo
ooooool07oooool3o`0009Oooooo002Aooooo`;o00005_ooool4o`0000[ooooo0_l0000Dooooo`?o
0000V?ooool00:Wooooo1_l00008ooooo`;o00004Oooool2o`000003ooooool0003o000009Wooooo
002/ooooo`03o`000?oooooooooo01_ooooo0_l0002Looooo`00W_ooool2o`0000cooooo00?o0000
ooooooooool0^Oooool009;ooooo0_l0000:ooooo`;o00001_ooool2o`0000Cooooo00?o0000oooo
ooooool02?ooool2o`000:oooooo002Booooo`;o00002_ooool2o`0000Cooooo1Ol00003ooooo`03
o`000?oooooooooo00Sooooo0_l0002_ooooo`00W_ooool2o`0000Cooooo0_l000000ooooooo0000
o`000003ooooo`03o`000?oooooooooo00Gooooo0_l000000ooooooo0000o`00000]ooooo`;o0000
P?ooool00:Gooooo0_l00005ooooo`03o`000?oooooooooo00Gooooo0ol0000Aooooo`;o00007?oo
ool2o`00083ooooo002Uooooo`;o00001Oooool00ol0003oooooooooo`06ooooo`;o00004Oooool2
o`0009kooooo002/ooooo`?o00006Oooool2o`0009kooooo002Dooooo`;o00005_ooool00ol0003o
ooooooooo`02ooooo`;o00005Oooool2o`0009kooooo002Dooooo`;o00005_ooool00ol0003ooooo
ooooo`02ooooo`;o0000]Oooool009Gooooo0_l0000Eooooo`03o`000?oooooooooo01Sooooo0_l0
002Oooooo`00UOooool2o`0001Gooooo00?o0000ooooooooool06?ooool2o`0001Oooooo0_l00026
ooooo`00S?ooool3o`0001gooooo00?o0000ooooooooool05_ooool2o`0001Wooooo0_l00026oooo
o`00S?ooool3o`0001gooooo00?o0000ooooooooool05_ooool2o`000:7ooooo0023ooooo`;o0000
9oooool00ol0003oooooooooo`2iooooo`00Poooool2o`0000Sooooo0_l0000Mooooo`03o`000?oo
oooooooo0;Wooooo002=ooooo`;o00007Oooool3o`000;Wooooo002=ooooo`;o00007Oooool00ol0
003oooooooooo`0Cooooo`;o0000Y?ooool008gooooo0_l0000Mooooo`03o`000?oooooooooo01?o
oooo0_l0002Tooooo`00SOooool2o`0000cooooo0_l0000?ooooo`?o0000^Oooool009_ooooo0_l0
000?ooooo`?o0000^Oooool008Wooooo00Kok^k^oc8b<_l0003o<S8bonk^k_ooool2o`0000;ooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00KoA4A4o`000?l0003o<S8bomgMgOooool2o`00
00;ooooo00?o0000ooooooooool04Oooool2o`000:Kooooo0029ooooo`06ogMgMonHV9SooooooiRH
V?mgMgOooooo0_l00002ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`03ooooo`;o00000_ooool0
0omgMgOo<S8booooo`02o`0000;ooooo00?o0000ooooooooool04Oooool2o`000:Kooooo0029oooo
o`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`03ooooo`;o00000oooool0
1?l0003oooooo`000?l00002ooooo`03o`000?oooooooooo00gooooo0_l0002Zooooo`00ROooool0
1Ol0003ooooooooooooooooo000000kooooo00?o8B4Qo`000?l000000_l00004ooooo`03ogMgMol0
003o000000Cooooo0ol0000=ooooo`?o0000ZOooool008Wooooo00Go0000ooooooooooooooooo`00
000>ooooo`03oeEEEOl0003o000000;o000000?oooooo`000?lQ8B401?l00004ooooo`03o`000?oo
oooooooo00kooooo0_l0002Yooooo`00ROooool01Ol@413ooooooooooooooooo410@00kooooo00?o
ZJVYogMgMoooool00oooool00ol0003oooooooooo`02o`0000Gooooo00?o0000ooooooooool0^Ooo
ool008Wooooo00KoMgMgoiRHV?ooooooV9RHogMgMoooool2o`0000Sooooo00Go410@oooooooooooo
oooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0^Oooool008Wooooo
00Kok^k^oc8b<_l0003o<S8bonk^k_ooool2o`0000Sooooo1Ol00004ooooo`Co00001_ooool00ol0
003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`08ooooo`;o0000[oooool009;ooooo
0_l0000Hooooo`03o`000?oooooooooo00Sooooo0_l0002_ooooo`00T_ooool2o`0001Sooooo00?o
0000ooooooooool01_ooool3o`000;3ooooo002/ooooo`?o00001_ooool3o`000;3ooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00Oooooo0_l0000Iooooo`;o
0000UOooool009Gooooo0_l0000Eooooo`03o`000?oooooooooo00Oooooo0_l0000Iooooo`;o0000
UOooool009Gooooo0_l0000Eooooo`03o`000?oooooooooo00Oooooo0_l0000Iooooo`;o0000UOoo
ool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool008Wo
oooo0_l0000<ooooo`;o00004oooool00ol0003oooooooooo`0Oooooo`;o0000V?ooool008Wooooo
0_l0000<ooooo`;o00004oooool4o`0001kooooo0_l0002Hooooo`00[?ooool01?l0003oooooo`00
0?l0002hooooo`00[?ooool00ol0003oooooooooo`2iooooo`00U_ooool2o`0001Cooooo00?o0000
ooooooooool0^Oooool009Kooooo0_l0000Dooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Nooooo`;o00003?oo
ool2o`000;[ooooo002Nooooo`;o00003?ooool2o`0001Sooooo0_l0002Pooooo`00Woooool2o`00
00_ooooo0ol0000Gooooo`;o0000X?ooool009oooooo0_l00007ooooo`;o00000_ooool00ol0003o
ooooooooo`0Gooooo`;o0000X?ooool00:Cooooo0_l00002ooooo`;o00000_ooool00ol0003ooooo
ooooo`2iooooo`00Y?ooool2o`0000Kooooo00?o0000ooooooooool0^Oooool00:;ooooo1?l00006
ooooo`03o`000?oooooooooo01Cooooo0_l0002Sooooo`00X_ooool2o`0000Sooooo00?o0000oooo
ooooool05?ooool2o`000:?ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool008oooooo0_l0000Kooooo`03o`000?oooooooooo0;Wo
oooo002?ooooo`;o00006oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00X_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0^Oooool0
0:Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00Y?ooool00ol0003o
ooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo00?o
0000ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo00?o0000oooo
ooooool0`Oooool00:;ooooo00?oEEEEofIVI_l00000`oooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00:[ooooo00Co410@o`000?l0003o0000^_ooool00:_o
oooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00Ko
0000ogMgMol0003o0000oeEEEOo^k^jgooooo`00Zoooool01_l0003oEEEEonk^k_ooooooMgMgoeEE
EKOooooo002[ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0]Oooool00:_ooooo
00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`2eooooo`00Zoooool01_l0003oEEEEonk^
k_ooooooMgMgofIVI[Oooooo002Zooooo`03oa0@4?l0003oMgMg00;o000000?oIVIVonk^k_ooool0
]_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.39666 .68851 Mdot
.41783 .17835 Mdot
.50043 .4252 Mdot
.54858 .44645 Mdot
.57386 .61909 Mdot
.55709 .77948 Mdot
.51632 .46425 Mdot
.36607 .42839 Mdot
.39799 .82374 Mdot
.43114 .69663 Mdot
.42778 .30846 Mdot
.4126 .09463 Mdot
.57201 .18752 Mdot
.4119 .54409 Mdot
.47632 .01319 Mdot
.54196 .6244 Mdot
.58255 .32688 Mdot
.57842 .1967 Mdot
.56312 .37095 Mdot
.68846 .54436 Mdot
.60353 .24836 Mdot
.50507 .10846 Mdot
.55439 .1794 Mdot
.59734 .22959 Mdot
.55165 .07572 Mdot
.42953 .76812 Mdot
.48302 .21596 Mdot
.56291 .37927 Mdot
.68229 .59246 Mdot
.44266 .11753 Mdot
.63475 .3249 Mdot
.41352 .88755 Mdot
.36683 .46323 Mdot
.61436 .46393 Mdot
.62256 .5396 Mdot
.67729 .53854 Mdot
.58715 .83452 Mdot
.54247 .32191 Mdot
.65806 .67344 Mdot
.41276 .08951 Mdot
.52456 .04027 Mdot
.62058 .49719 Mdot
.59877 .67254 Mdot
.3978 .70924 Mdot
.43992 .86595 Mdot
.52916 .75425 Mdot
.41283 .47216 Mdot
.48907 .96868 Mdot
.42038 .25505 Mdot
.67297 .6169 Mdot
.48482 .96928 Mdot
.65231 .70518 Mdot
.71979 .74924 Mdot
.60872 .62726 Mdot
.61706 .60748 Mdot
.37295 .64273 Mdot
.37088 .34213 Mdot
.57519 .30372 Mdot
.54006 .90706 Mdot
.45621 .88791 Mdot
.50657 .79533 Mdot
.69162 .25821 Mdot
.64844 .69625 Mdot
.42164 .48969 Mdot
.3781 .29587 Mdot
.39395 .81153 Mdot
.43288 .7011 Mdot
.54019 .62124 Mdot
.53675 .30192 Mdot
.61906 .27277 Mdot
.57829 .29925 Mdot
.49576 .6625 Mdot
.41995 .62461 Mdot
.46944 .77163 Mdot
.64835 .69632 Mdot
.48439 .64039 Mdot
.71934 .75009 Mdot
.4383 .78053 Mdot
.66261 .67563 Mdot
.4379 .20806 Mdot
.66561 .42397 Mdot
.44303 .11868 Mdot
.54289 .41812 Mdot
.62194 .5004 Mdot
.36866 .60916 Mdot
.5487 .60634 Mdot
.57117 .6322 Mdot
.53761 .72412 Mdot
.5514 .25062 Mdot
.53616 .63665 Mdot
.56346 .09065 Mdot
.76374 .55585 Mdot
.44633 .29033 Mdot
.54293 .72034 Mdot
.43698 .32697 Mdot
.76676 .5121 Mdot
.41301 .5654 Mdot
.45305 .95797 Mdot
.71478 .76198 Mdot
.54477 .23358 Mdot
.3866 .5541 Mdot
.51462 .1867 Mdot
.42623 .06162 Mdot
.38638 .5806 Mdot
.65104 .3532 Mdot
.61643 .48278 Mdot
.59447 .34549 Mdot
.57378 .41102 Mdot
.44712 .28782 Mdot
.62533 .28906 Mdot
.42116 .64786 Mdot
.54422 .41082 Mdot
.41386 .88734 Mdot
.68463 .51081 Mdot
.59739 .9464 Mdot
.50079 .32333 Mdot
.47578 .82625 Mdot
.39762 .83778 Mdot
.40878 .87844 Mdot
.57168 .85116 Mdot
.57569 .19502 Mdot
.65837 .20021 Mdot
.59844 .25068 Mdot
.68397 .59133 Mdot
.62349 .28322 Mdot
.55183 .49575 Mdot
.68299 .54421 Mdot
.76306 .47039 Mdot
.41331 .20963 Mdot
.53289 .51684 Mdot
.53857 .15258 Mdot
.38892 .38971 Mdot
.452 .01778 Mdot
.56175 .7752 Mdot
.58588 .71179 Mdot
.67604 .63408 Mdot
.62386 .77922 Mdot
.6818 .57749 Mdot
.42091 .63092 Mdot
.37891 .27478 Mdot
.47461 .01131 Mdot
.73295 .36473 Mdot
.50719 .29191 Mdot
.54714 .32428 Mdot
.58184 .32379 Mdot
.6875 .52445 Mdot
.37661 .70681 Mdot
.57832 .49499 Mdot
.52967 .74378 Mdot
.62266 .14299 Mdot
.49785 .16134 Mdot
.49556 .21931 Mdot
.59667 .22627 Mdot
.5055 .62893 Mdot
.48904 .88016 Mdot
.62554 .76871 Mdot
.65077 .6974 Mdot
.38889 .78929 Mdot
.57912 .84465 Mdot
.62535 .77089 Mdot
.40012 .56301 Mdot
.6675 .66513 Mdot
.67522 .5043 Mdot
.58681 .69747 Mdot
.38667 .52525 Mdot
.37803 .71723 Mdot
.65801 .37072 Mdot
.53176 .29135 Mdot
.64055 .745 Mdot
.6722 .60109 Mdot
.48693 .26412 Mdot
.52112 .27252 Mdot
.56112 .66042 Mdot
.58047 .50514 Mdot
.3722 .35259 Mdot
.76567 .50094 Mdot
.49227 .87643 Mdot
.50725 .3497 Mdot
.6742 .62341 Mdot
.65488 .71032 Mdot
.44699 .01902 Mdot
.51227 .72111 Mdot
.53433 .05001 Mdot
.51779 .63479 Mdot
.39601 .81029 Mdot
.76171 .47561 Mdot
.43799 .94799 Mdot
.59655 .68465 Mdot
.63487 .16704 Mdot
.68804 .52074 Mdot
.42778 .60109 Mdot
.68623 .25415 Mdot
.36554 .50961 Mdot
.55597 .0685 Mdot
.43537 .04172 Mdot
.54801 .70544 Mdot
.76594 .58624 Mdot
.60927 .38798 Mdot
.47545 .29891 Mdot
.48058 .29971 Mdot
.48642 .68125 Mdot
.5689 .63011 Mdot
.76177 .61367 Mdot
.38721 .4344 Mdot
.46208 .71872 Mdot
.53661 .81504 Mdot
.53789 .37582 Mdot
.50939 .67193 Mdot
.42742 .30677 Mdot
.5315 .1327 Mdot
.44854 .80263 Mdot
.65897 .37468 Mdot
.51483 .70974 Mdot
.38654 .48178 Mdot
.45904 .81471 Mdot
.5243 .61483 Mdot
.44843 .87311 Mdot
.3924 .16976 Mdot
.48513 .82308 Mdot
.50843 .94169 Mdot
.65178 .3494 Mdot
.67046 .46032 Mdot
.51957 .69141 Mdot
.58155 .55933 Mdot
.39508 .29531 Mdot
.47235 .25713 Mdot
.47733 .01282 Mdot
.66095 .20039 Mdot
.5527 .55866 Mdot
.45718 .35609 Mdot
.75349 .63738 Mdot
.48406 .15652 Mdot
.46681 .2138 Mdot
.65088 .19148 Mdot
.53095 .29307 Mdot
.3843 .51601 Mdot
.58356 .21807 Mdot
.38634 .44631 Mdot
.69422 .26555 Mdot
.58429 .72339 Mdot
.66901 .40387 Mdot
.57781 .29829 Mdot
.42347 .91842 Mdot
.43598 .33601 Mdot
.61441 .78208 Mdot
.55249 .26486 Mdot
.57484 .29139 Mdot
.65177 .69097 Mdot
.5531 .06703 Mdot
.49929 .32003 Mdot
.42486 .55862 Mdot
.59691 .812 Mdot
.41297 .68604 Mdot
.51738 .26581 Mdot
.61976 .61085 Mdot
.47705 .64775 Mdot
.37215 .33409 Mdot
.5151 .94024 Mdot
.44776 .17579 Mdot
.46534 .21468 Mdot
.67276 .47384 Mdot
.52884 .44158 Mdot
.50177 .16973 Mdot
.40418 .73512 Mdot
.41803 .38621 Mdot
.55275 .77812 Mdot
.67485 .57104 Mdot
.40018 .49841 Mdot
.68104 .53349 Mdot
.61635 .617 Mdot
.4394 .72937 Mdot
.44155 .1937 Mdot
.63222 .75698 Mdot
.51096 .72647 Mdot
.58462 .4809 Mdot
.46719 .97053 Mdot
.41778 .36687 Mdot
.51046 .85503 Mdot
.67215 .6382 Mdot
.53568 .49076 Mdot
.47872 .76786 Mdot
.57459 .85007 Mdot
.40721 .11578 Mdot
.57502 .41488 Mdot
.51633 .56431 Mdot
.57119 .60101 Mdot
.68309 .46545 Mdot
.525 .7563 Mdot
.66104 .40748 Mdot
.76119 .48006 Mdot
.5363 .90857 Mdot
.44206 .03663 Mdot
.5171 .92918 Mdot
.49171 .34542 Mdot
.57206 .86519 Mdot
.67977 .24862 Mdot
.67799 .43019 Mdot
.46519 .01566 Mdot
.42101 .25891 Mdot
.6089 .65945 Mdot
.38862 .38798 Mdot
.41829 .90364 Mdot
.52877 .04789 Mdot
.4135 .43979 Mdot
.46207 .96683 Mdot
.40825 .65295 Mdot
.4469 .34775 Mdot
.53714 .14289 Mdot
.58809 .33994 Mdot
.57334 .19413 Mdot
.61293 .13174 Mdot
.51369 .36516 Mdot
.4299 .83661 Mdot
.61775 .48597 Mdot
.38644 .22835 Mdot
.52886 .43272 Mdot
.45903 .00848 Mdot
.63592 .17943 Mdot
.74041 .37175 Mdot
.55193 .54432 Mdot
.5667 .76866 Mdot
.62307 .49648 Mdot
.63829 .72432 Mdot
.58443 .54759 Mdot
.45195 .32513 Mdot
.50774 .40283 Mdot
.58912 .33271 Mdot
.3781 .26214 Mdot
.59243 .81623 Mdot
.43198 .35117 Mdot
.51697 .11774 Mdot
.53352 .52246 Mdot
.48321 .68452 Mdot
.39913 .26631 Mdot
.56811 .75899 Mdot
.58675 .69811 Mdot
.39979 .55239 Mdot
.57072 .61931 Mdot
.7372 .71019 Mdot
.40374 .5968 Mdot
.43679 .13395 Mdot
.42306 .45041 Mdot
.36746 .51937 Mdot
.47483 .21503 Mdot
.6816 .57123 Mdot
.48573 .09559 Mdot
.475 .25043 Mdot
.48449 .81626 Mdot
.7313 .3576 Mdot
.40182 .13142 Mdot
.58426 .84998 Mdot
.67809 .54539 Mdot
.40665 .3476 Mdot
.60918 .39735 Mdot
.67547 .58481 Mdot
.49189 .15951 Mdot
.40321 .12655 Mdot
.74148 .36328 Mdot
.67093 .41136 Mdot
.45188 .01868 Mdot
.46755 .00417 Mdot
.51477 .02611 Mdot
.46084 .67997 Mdot
.46553 .15818 Mdot
.48175 .0127 Mdot
.3706 .35025 Mdot
.4549 .66942 Mdot
.65221 .37088 Mdot
.40132 .52113 Mdot
.54311 .80702 Mdot
.38841 .59387 Mdot
.43681 .93702 Mdot
.38442 .51464 Mdot
.57539 .85511 Mdot
.61043 .78206 Mdot
.54879 .1721 Mdot
.60103 .8243 Mdot
.53597 .15063 Mdot
.5274 .04956 Mdot
.578 .97117 Mdot
.5516 .87993 Mdot
.49084 .8816 Mdot
.50405 .6292 Mdot
.6043 .13512 Mdot
.53972 .22737 Mdot
.50444 .38822 Mdot
.44705 .0173 Mdot
.62182 .27849 Mdot
.4455 .34497 Mdot
.45486 .75831 Mdot
.44433 .80248 Mdot
.48112 .21199 Mdot
.48187 .97337 Mdot
.65096 .33657 Mdot
.68589 .25671 Mdot
.45266 .01264 Mdot
.6048 .39611 Mdot
.73543 .70563 Mdot
.60811 .40191 Mdot
.58053 .49011 Mdot
.58301 .50625 Mdot
.4393 .5136 Mdot
.37788 .26736 Mdot
.41065 .10135 Mdot
.47846 .21429 Mdot
.4831 .25603 Mdot
.44376 .24099 Mdot
.53734 .65302 Mdot
.5929 .11007 Mdot
.55446 .69357 Mdot
.67627 .4892 Mdot
.5236 .33775 Mdot
.50347 .23342 Mdot
.53176 .4625 Mdot
.56211 .66749 Mdot
.61192 .44616 Mdot
.47375 .20726 Mdot
.45404 .70708 Mdot
.64192 .17269 Mdot
.37614 .29971 Mdot
.45825 .40076 Mdot
.62212 .55413 Mdot
.59487 .34707 Mdot
.44771 .86563 Mdot
.40166 .453 Mdot
.52299 .27387 Mdot
.60079 .12785 Mdot
.77009 .52445 Mdot
.38678 .40727 Mdot
.63803 .89316 Mdot
.39348 .67787 Mdot
.44713 .6943 Mdot
.37862 .69115 Mdot
.49348 .01868 Mdot
.44029 .26172 Mdot
.49438 .1033 Mdot
.7323 .72158 Mdot
.4935 .26737 Mdot
.43543 .40489 Mdot
.57939 .53717 Mdot
.67256 .46052 Mdot
.41775 .28322 Mdot
.76516 .57283 Mdot
.51158 .66006 Mdot
.61361 .59589 Mdot
.62086 .47474 Mdot
.42412 .41676 Mdot
.51545 .37534 Mdot
.4924 .76288 Mdot
.36685 .40944 Mdot
.51952 .38312 Mdot
.66981 .65365 Mdot
.40021 .26401 Mdot
.43074 .84253 Mdot
.68243 .53615 Mdot
.65523 .3875 Mdot
.59646 .36361 Mdot
.76396 .44994 Mdot
.44998 .75066 Mdot
.3799 .24715 Mdot
.54673 .05886 Mdot
.42109 .36119 Mdot
.57721 .85903 Mdot
.40084 .47154 Mdot
.57777 .32096 Mdot
.68268 .56432 Mdot
.38703 .5718 Mdot
.56936 .39755 Mdot
.48489 .81661 Mdot
.61397 .45056 Mdot
.6816 .23269 Mdot
.57797 .7254 Mdot
.494 .62076 Mdot
.59764 .66933 Mdot
.43622 .21065 Mdot
.47077 .69083 Mdot
.54683 .58142 Mdot
.61175 .61503 Mdot
.59617 .68832 Mdot
.48826 .30244 Mdot
.41886 .71657 Mdot
.39151 .79852 Mdot
.57886 .59797 Mdot
.41292 .77796 Mdot
.53209 .28435 Mdot
.56709 .40706 Mdot
.43826 .6043 Mdot
.61666 .92482 Mdot
.43387 .56353 Mdot
.40775 .21923 Mdot
.4864 .9598 Mdot
.67626 .50455 Mdot
.54325 .31748 Mdot
.67925 .59611 Mdot
.43408 .03974 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:7ooooo0_l000000ooooooo0000ooooo`06ooooo`03
o`000?oooooooooo0;Wooooo002Qooooo`;o000000?oooooo`000?ooool01_ooool00ol0003ooooo
ooooo`2iooooo`00W_ooool2o`0000Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`2iooooo`00W?ooool4o`0000?ooooo1Ol00004ooooo`03o`000?oooooooooo0;Wooooo002Loooo
o`;o00000_ooool2o`000003oeEEEOl0003o000000?o00001?ooool00ol0003oooooooooo`2ioooo
o`00V_ooool4o`0000;ooooo0_l00007ooooo`;o000000?oooooo`000?ooool0^_ooool009[ooooo
1?l0000;ooooo`;o000000?oooooo`000?ooool0^_ooool00:cooooo0ol0002iooooo`00[?ooool0
1?l0003oooooooooooooool2o`000;Kooooo002/ooooo`04o`000?ooooooooooooooo`;o0000]_oo
ool00:cooooo00?o0000ooooooooool0^Oooool009Sooooo0_l0000Booooo`03o`000?oooooooooo
0;Wooooo002Fooooo`Co00004_ooool00ol0003oooooooooo`05ooooo`;o0000/_ooool009Kooooo
0_l0000Dooooo`03o`000?oooooooooo00Gooooo0_l0002booooo`00U_ooool2o`0001Cooooo00?o
0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool01_ooool4o`000:oooooo002/oooo
o`?o00001_ooool4o`000:oooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo00cooooo0_l0002[ooooo`00Toooool2o`0001Oooooo00?o0000ooooooooool03?oo
ool2o`000:_ooooo002Cooooo`;o00005oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`0>ooooo`;o0000ZOooool00:cooooo00?o0000ooooooooool03_ooool3o`000:So
oooo002/ooooo`03o`000?oooooooooo00oooooo0_l0002Xooooo`00[?ooool3o`0000kooooo0_l0
002Yooooo`00[?ooool00ol0003oooooooooo`0>ooooo`;o0000ZOooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool008oooooo0_l0000Kooooo`03o`00
0?oooooooooo0;Wooooo002?ooooo`;o00006oooool00ol0003oooooooooo`0Booooo`;o0000YOoo
ool008oooooo0_l0000Fooooo`;o00000oooool00ol0003oooooooooo`0Booooo`;o0000YOooool0
08oooooo0_l0000Fooooo`;o00000oooool00ol0003oooooooooo`2iooooo`00S_ooool2o`0001co
oooo0ol0002iooooo`00S_ooool2o`0001[ooooo0ol0002kooooo`00Z_ooool3o`000;_ooooo002/
ooooo`?o00006oooool2o`0009cooooo002/ooooo`?o00006oooool2o`0009cooooo002=ooooo`;o
00007Oooool00ol0003oooooooooo`2iooooo`00ROooool01?o^k^ko<S8bo`000?lb<S82o`0000Co
oooo0_lQ8B44ooooo`?o000000?ok^k^ooooooooool00oooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool00_ooool2o`000;Gooooo0029ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo0_l000000omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool00_ooool2o`000;Gooooo0021ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03oooo
o`?o0000^Oooool008Wooooo00?o0000ooooooooool00_l0000>ooooo`03ob4Q8Ooooooooooo00Ko
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Nooooo`;o0000VOooool008Wooooo
00?o0000ooooool000000_l0000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo01kooooo0_l00002ooooo`;o0000UOooool008Wooooo
00Go410@ooooool0003o0000oa0@4009ooooo`;o00000oooool00onYZJWoMgMgooooo`03ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool2o`0001Wooooo0_l0002Eooooo`00
ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Wooooo0_l000001Ol@413ooooooooooooooooo<S8b
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`;o00005_ooool2o`00
09Sooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006oooo
o`03o`000?oooooooooo01oooooo0_l0002Hooooo`00[?ooool00ol0003oooooooooo`09ooooo`;o
00006_ooool2o`0009;ooooo002/ooooo`03o`000?oooooooooo00Wooooo0_l0000Jooooo`;o0000
T_ooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol00008ooooo`?o0000[_ooool0
0:cooooo00?o0000ooooooooool02?ooool3o`000:kooooo002Pooooo`;o00001?ooool2o`0000Co
oooo00?o0000ooooooooool0^Oooool00:3ooooo0_l00004ooooo`;o000000?oooooo`000?l00000
0_l0002kooooo`00ZOooool4o`000;_ooooo002/ooooo`03o`000?oooooooooo02Wooooo0_l0002>
ooooo`00R?ooool2o`0002;ooooo0_l0000Zooooo`;o0000S_ooool008Sooooo0_l0000Rooooo`;o
00003_ooool2o`0001cooooo0_l0002<ooooo`00V_ooool2o`00013ooooo0ol0000=ooooo`;o0000
7?ooool2o`0008cooooo002@ooooo`;o00002?ooool2o`00013ooooo00?o0000ooooooooool03ooo
ool2o`0001Sooooo0_l0002>ooooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool03oooool2
o`0001Sooooo0_l0002>ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool01?l0003o
ooooooooooooool2o`00017ooooo0_l0002Sooooo`00[?ooool01?l0003oooooooooooooool2o`00
017ooooo0_l0000Hooooo`;o0000ROooool009Sooooo0_l0000Booooo`03o`000?oooooooooo01Go
oooo0ol0000Fooooo`;o0000ROooool009Sooooo0_l0000Booooo`03o`000?oooooooooo01Gooooo
0ol0002Qooooo`00[?ooool3o`0001Kooooo0_l0000Iooooo`?o0000QOooool00:cooooo00?o0000
ooooooooool0<Oooool3o`0008Gooooo002Sooooo`;o00001oooool00ol0003oooooooooo`2ioooo
o`00Soooool2o`0000Kooooo0_l0000:ooooo`;o00001oooool00ol0003oooooooooo`2iooooo`00
Soooool2o`0000Kooooo0_l0000<ooooo`;o00001Oooool00ol0003oooooooooo`2iooooo`00X?oo
ool8o`0000Cooooo00?o0000ooooooooool0^Oooool008gooooo0_l0000Aooooo`So00000_ooool3
o`0001[ooooo0_l0002Oooooo`00SOooool2o`0001_ooooo0ol0000Jooooo`;o0000Woooool00:co
oooo0ol0002iooooo`00Q_ooool2o`0002Cooooo00?o0000ooooooooool02_ooool2o`00013ooooo
0_l0002Kooooo`00Q_ooool2o`0002Cooooo00?o0000ooooooooool02_ooool2o`00013ooooo0ol0
002Jooooo`00[?ooool3o`0000_ooooo0_l0000@ooooo`;o00006_ooool2o`0007kooooo002/oooo
o`?o00002oooool2o`0002cooooo0_l0001nooooo`00VOooool2o`00017ooooo00?o0000oooooooo
ool0^Oooool0097ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`;o00000_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2iooooo`00TOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0^Oooool008Cooooo0_l00003ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@
013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Oooooo`;o00005oooool2o`00
07oooooo0024ooooo`;o00002oooool01Ol0003ooooooooooooooooo000000gooooo0_l000000omg
MgOo<S8booooo`04ooooo`?o00003_ooool2o`0000gooooo1?l0000Gooooo`;o0000Ooooool0097o
oooo0_l00002ooooo`03o`000?oooooooooo00[ooooo0ol000000olb<S;o0000o`000004ooooo`03
o`000?oooooooooo00kooooo0_l0000=ooooo`;o00006oooool2o`0007gooooo002Aooooo`;o0000
0_ooool00ol@413oooooooooo`0:ooooo`;o00000_ooool2o`0000Cooooo00?o0000ooooooooool0
>_ooool4o`0007_ooooo0023ooooo`;o00003?ooool2o`000003oooooonHV9SoMgMg00;ooooo0_l0
0008ooooo`;o00002?ooool00ol0003oooooooooo`0jooooo`Co0000Noooool008?ooooo0_l00006
ooooo`;o00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo0_l00008ooooo`Co000000?o
ooooo`000?l000000oooool00ol0003oooooooooo`0>ooooo`;o0000ZOooool008?ooooo0_l00005
ooooo`?o00006_ooool4o`000003ooooool0003ooooo00?ooooo0_l0000:ooooo`;o0000;Oooool2
o`0007[ooooo0023ooooo`;o00001Oooool2o`0001gooooo0_l000000ooooooo0000ooooo`03oooo
o`;o0000>Oooool2o`0007[ooooo002/ooooo`03o`000?oooooooooo00Cooooo0_l0000Nooooo`;o
0000Toooool008Cooooo0_l0000Vooooo`?o00001?ooool2o`0001kooooo0_l0002Cooooo`00Q?oo
ool2o`0002Kooooo00?o0000ooooooooool09Oooool2o`0009;ooooo002@ooooo`;o00006_ooool0
0ol0003oooooooooo`0Uooooo`;o0000T_ooool0093ooooo0_l0000Jooooo`03o`000?oooooooooo
00Oooooo0_l0000Looooo`;o0000T_ooool009[ooooo0_l0000@ooooo`03o`000?oooooooooo00Oo
oooo0_l0000Mooooo`;o0000TOooool009[ooooo0_l0000@ooooo`04o`000?oooooo0000o`0000Ko
oooo0_l0000<ooooo`;o00003oooool2o`00097ooooo0029ooooo`;o00003oooool2o`00013ooooo
00Co0000ooooool0003o00001_ooool2o`0000cooooo0_l0002Rooooo`00Poooool2o`0000Cooooo
0_l0000Qooooo`03o`000?oooooooooo00Oooooo0_l0000=ooooo`;o0000XOooool008?ooooo0_l0
000Nooooo`Co00001Oooool3o`0001Kooooo0_l0002Qooooo`00Poooool2o`0001kooooo1?l00000
0ooooooo0000o`000002ooooo`03o`000?oooooooooo00Wooooo0_l0000:ooooo`?o0000XOooool0
09Cooooo0_l0000Booooo`;o00000_ooool00ol0003oooooooooo`09ooooo`;o00002_ooool2o`00
0:;ooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`2iooooo`00U?ooool2o`0001Kooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool02oooool2o`000:cooooo002[ooooo`;o00003Oooool2o`0000Wooooo0_l0002Qoooo
o`00W?ooool2o`0000gooooo1?l0000;ooooo`?o00002?ooool4o`0000oooooo0_l0002>ooooo`00
Uoooool2o`0000?ooooo0_l0000>ooooo`;o00003Oooool2o`0000[ooooo0_l0000?ooooo`;o0000
S_ooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo01Sooooo0_l0002Oooooo`00POooool2
o`0002Wooooo00?o0000ooooooooool06_ooool2o`0009gooooo0021ooooo`;o00004oooool2o`00
01Cooooo00?o0000ooooooooool01?ooool2o`0001Cooooo0_l0000Booooo`;o0000ROooool009Ko
oooo0_l0000Dooooo`03o`000?oooooooooo00Cooooo0_l0000Dooooo`;o00004_ooool2o`0008Wo
oooo0021ooooo`;o0000:Oooool00ol0003oooooooooo`0Jooooo`;o0000WOooool0087ooooo0_l0
000Gooooo`;o00003Oooool2o`000003ooooool0003ooooo01gooooo0_l0002Kooooo`00SOooool2
o`0000_ooooo0_l0000=ooooo`;o000000?oooooo`000?ooool00_l0000Kooooo`;o00004Oooool2
o`0008Sooooo0021ooooo`;o00002_ooool2o`0000Kooooo0_l00003ooooo`;o00004?ooool4o`00
01_ooooo0_l0000Aooooo`;o0000R?ooool0087ooooo0_l0000Booooo`;o00001_ooool2o`0000go
oooo00?o0000ooooooooool0;_ooool2o`0008Wooooo002Mooooo`;o00003Oooool00ol0003ooooo
ooooo`0^ooooo`;o00006Oooool2o`0006kooooo002Booooo`;o00006?ooool00ol0003ooooooooo
o`19ooooo`;o0000K_ooool009;ooooo0_l0000Hooooo`04o`000?ooooooooooooooo`;o00006Ooo
ool2o`0002_ooooo0_l000000ooooooo0000o`00001[ooooo`00ROooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00;ooooo0_l000000ooooooo8B4Qob4Q8@04ooooo`Go00001?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Gooooo00Co0000oooooooooooooooo0_l0000Iooooo`;o0000:oooool2o`000003
ooooool0003o000006_ooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool2o`000003
oooooolQ8B7o8B4Q00Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool04Oooool2o`0001cooooo1?l00026ooooo`00POooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Aooooo`;o00007?ooool4o`0001Wooooo0_l0001[oooo
o`00ROooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omg
MgOo<S8booooo`04ooooo`?o00000_ooool2o`0000Gooooo0_l0000Vooooo`;o00006Oooool2o`00
06_ooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`02ooooo`;o00001Oooool2
o`0000Kooooo0_l0000Nooooo`;o0000Q_ooool008Wooooo00Go410@oooooooooooooooooa0@400?
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03
ooooo`;o00003?ooool2o`000:Kooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool2
o`0000Kooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool00oooool2o`000;Cooooo0027ooooo`;o000000Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`;o00001_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`?o0000
8Oooool2o`0000gooooo0_l00027ooooo`00Qoooool2o`0002?ooooo0ol0000Qooooo`;o00003Ooo
ool2o`0008Oooooo0027ooooo`;o00008oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`0Cooooo`;o00002_ooool4o`0009Kooooo002Nooooo`;o00003?ooool3o`0001?o
oooo0_l0000:ooooo`Co0000U_ooool009kooooo0_l0000<ooooo`04o`000?oooooo0000o`0001oo
oooo0_l0000Booooo`;o0000Poooool008Kooooo0_l0000>ooooo`;o00005?ooool01?l0003ooooo
o`000?l0000Booooo`;o00002oooool2o`00013ooooo1?l00023ooooo`00P?ooool2o`0000Cooooo
0_l0000>ooooo`;o00005?ooool00ol0003oooooooooo`0Cooooo`;o00007Oooool2o`0008Gooooo
0020ooooo`;o0000:_ooool00ol0003oooooooooo`0;ooooo`;o00002?ooool2o`0001kooooo0_l0
0022ooooo`00[?ooool00ol0003oooooooooo`0;ooooo`;o00002?ooool2o`0001kooooo0_l00022
ooooo`00Toooool2o`0001Oooooo00?o0000ooooooooool02oooool2o`0000Sooooo0_l0002Roooo
o`00Toooool2o`0001Oooooo00?o0000ooooooooool02oooool2o`000:cooooo002/ooooo`?o0000
<oooool2o`0008Cooooo001oooooo`;o0000:oooool2o`0003Cooooo0_l00024ooooo`00Ooooool2
o`0002_ooooo00?o0000ooooooooool0=oooool2o`00083ooooo0026ooooo`;o00009?ooool00ol0
003oooooooooo`06ooooo`;o0000;oooool2o`00083ooooo0026ooooo`;o00009?ooool00ol0003o
ooooooooo`06ooooo`;o0000/Oooool008oooooo0_l0000Kooooo`03o`000?oooooooooo0;Wooooo
002?ooooo`;o00006oooool00ol0003oooooooooo`06ooooo`;o0000/Oooool008Kooooo0_l0000T
ooooo`03o`000?oooooooooo00Kooooo0_l00005ooooo`;o00004oooool2o`0009Gooooo0026oooo
o`;o00009?ooool00ol0003oooooooooo`0=ooooo`;o00004oooool2o`00033ooooo0_l0001Soooo
o`00Roooool2o`0000Gooooo0_l0000Hooooo`?o00008_ooool2o`00033ooooo0_l0001Sooooo`00
Roooool2o`0000Gooooo0_l0000Hooooo`03o`000?oooooooooo02;ooooo0_l0002Eooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`002Oooool4o`000003oa0@4?oooooooooo01Kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0
003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Kooooo00?o0000ooooooooool06?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01?m4A4Co0000
o`000?lb<S83o`0000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4
A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd06?ooool4o`000003oa0@
4?oooooooooo01;ooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool2o`0000;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400Oooooo00?oMgMgoc8b<_ooool05Oooool00ol0003oooooooooo`02ooooo`;o00000oooool2
o`0000oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o00001?ooool01OnHV9So8B4Qonk^
k_ooooooA4A400Oooooo00CoMgMgo`000?l0003o00003Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo01Wooooo00?o0000
ooooooooool05?ooool000Ko00001Oooool00ol0003oooooooooo`0@ooooo`Ko00000_ooool01Ol@
413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`05
ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool01Ooo
ool6o`0000;ooooo00Go410@oooooooooooooooooa0@4003ooooo`;o00001oooool00onHV9So8B4Q
onk^kP09ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00_ooool2o`0000?ooooo
0_l0000?ooooo`05oa0@4?ooooooooooooooool@41001Oooool2o`0000Gooooo00?oV9RHob4Q8Oo^
k^h02Oooool01?l0003oooooooooooooool2o`0000[ooooo00Go410@oooooooooooooooooa0@400@
ooooo`03o`000?oooooooooo00gooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmE
EEGooooo00Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Dooooo`002oooool0
0ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMg
Molb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo00?oMgMgoc8b<_ooool05Oooool00ol0003oooooooooo`0Hooooo`05o`000?oooooooooooooo
ool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00;ooooo0_l0000:oooo
o`05o`000?ooooooooooooooool000002Oooool2o`0000Cooooo00?oMgMgoc8b<_ooool03_ooool0
1Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8boooo
o`0Iooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go0000
ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00?ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00oooooo00Go0000ooooooooooooooooo`00000>ooooo`;o00000_ooool3o`000004ob4Q8Ol0003o
<S8bolc<c1Kooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000kooooo
00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;o00003Oooool01Ol0003o
oooooooooooooooo000000Wooooo0_l000001_oooooo0000ob4Q8Ol0003o<S8bolc<c0oooooo00Go
0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c00Jooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo
00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000oooooooo
ool04Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04Oooool01Ol@
413ooooooooooooooooo410@00kooooo0_l00002ooooo`?o00006_ooool3o`0001Sooooo00Go410@
oooooooooooooooooa0@4007ooooo`;o00001_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo0_l0000=ooooo`05oa0@4?ooooooooooooooool@41002Oooool2o`000003oooo
ool0003ooooo01;ooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?o
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003ooooo
ooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b
00Cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000
ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RH
oa0@4004ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Oooooo0_l00002ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL02Oooool2o`000003ooooool0003o
oooo01;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S80
1?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Cooooo0009ooooo`03oeEEEOmV
IVKo000001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`00013ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Wooooo0_l000001OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0000Gooooo`03o`000?oooooo
oooo01Sooooo0ol000000olb<S;ok^k^ooooo`05ooooo`;o00000oooool01OnHV9So410@o`000?lQ
8B7oc<c<00Cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02Oooool2o`000003oooo
ool0003o000000;o00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co
00006Oooool00omEEEGoIVIVo`00000Fooooo`00Q_ooool2o`0002Cooooo00?o0000ooooooooool0
6?ooool2o`0000Wooooo0_l0002Dooooo`00[?ooool00ol0003oooooooooo`0Sooooo`;o00004_oo
ool2o`00083ooooo002Booooo`;o00006?ooool00ol0003oooooooooo`08ooooo`;o00003Oooool2
o`0001kooooo0_l0001eooooo`;o00000_ooool2o`0000Gooooo002Booooo`;o00006?ooool00ol0
003oooooooooo`08ooooo`;o00003?ooool3o`0009Gooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oM
gMd5ooooo`00Roooool2o`0001oooooo00?o0000ooooooooool03_ooool2o`0000Kooooo0_l0000<
ooooo`?o0000R?ooool01?oMgMgo0000oa0@4?o<c<`6ooooo`001oooooooo`0004co00003?ooool0
1?o^k^ko8B4Qoa0@4?o^k^h6ooooo`001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`?o00001oooool0
0ol0003oooooooooo`04ooooo`?o00001_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00Co0000oooooooooooooooo0_l00002ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00Co
8B4QogMgMomgMgOo<S8b1_ooool000Oooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0Gooooo`?o00003Oooool00ol0003oooooooooo`0<ooooo`?o00005oooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02Oooool2o`0000;ooooo0_l0
0005ooooo`00Ooooool2o`0002_ooooo00?o0000ooooooooool05oooool3o`0009oooooo001ooooo
o`;o00005oooool2o`0001;ooooo00?o0000ooooooooool0>_ooool2o`0001Wooooo0_l0001Roooo
o`00QOooool2o`00017ooooo0_l0000Booooo`03o`000?oooooooooo03[ooooo0_l0000Iooooo`;o
0000H_ooool0083ooooo0_l00003ooooo`;o00009Oooool00ol0003oooooooooo`07ooooo`;o0000
/?ooool0083ooooo0_l00009ooooo`;o00007oooool00ol0003oooooooooo`07ooooo`?o0000<Ooo
ool2o`0007cooooo0026ooooo`;o00000oooool2o`0001oooooo0ol00008ooooo`;o0000<?ooool3
o`0001Wooooo0_l0001Qooooo`00Q_ooool2o`0002Cooooo00?o0000ooooooooool0>_ooool2o`00
01[ooooo0_l0001Qooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooo
ooooo`0hooooo`;o0000Ooooool00:cooooo00?o0000ooooooooool05oooool2o`0001oooooo0ol0
001nooooo`00[?ooool00ol0003oooooooooo`0Gooooo`;o00003?ooool2o`00013ooooo1?l0001n
ooooo`00[?ooool00ol0003oooooooooo`0Uooooo`;o00004?ooool2o`00083ooooo002>ooooo`;o
00007?ooool00ol0003oooooooooo`0>ooooo`;o00009oooool6o`0007cooooo002>ooooo`;o0000
7?ooool00ol0003oooooooooo`0>ooooo`;o00002?ooool2o`0001gooooo1_l0001looooo`00R_oo
ool2o`00023ooooo0ol0000Hooooo`;o0000Woooool008Kooooo0_l00002ooooo`;o00008?ooool0
0ol0003oooooooooo`0Uooooo`;o0000;Oooool2o`0006?ooooo0026ooooo`;o00002oooool2o`00
01Oooooo00?o0000ooooooooool03_ooool2o`0001Gooooo0_l0000]ooooo`;o0000Hoooool009?o
oooo0_l0000Gooooo`03o`000?oooooooooo00kooooo0_l00007ooooo`;o0000X?ooool008_ooooo
0_l00009ooooo`;o00005?ooool00ol0003oooooooooo`02ooooo`;o00004oooool2o`00023ooooo
0_l0001nooooo`00Roooool2o`0000;ooooo0_l00005ooooo`;o00005?ooool00ol0003ooooooooo
o`02ooooo`;o0000=Oooool2o`0007kooooo002?ooooo`;o00006oooool00ol0003oooooooooo`0f
ooooo`;o0000POooool008Kooooo0_l0000Tooooo`03o`000?oooooooooo03Kooooo0_l000000ooo
oooo0000o`00000Iooooo`;o0000Hoooool008Kooooo0_l0000Tooooo`?o0000>Oooool2o`0001Wo
oooo0_l0001Sooooo`00[?ooool00ol0003oooooooooo`0iooooo`;o0000O_ooool008Kooooo0_l0
000Tooooo`03o`000?oooooooooo00cooooo0_l0000[ooooo`;o0000O_ooool008Kooooo0_l0000T
ooooo`03o`000?oooooooooo00cooooo0_l0000Xooooo`;o00007?ooool2o`0006?ooooo002/oooo
o`03o`000?oooooooooo03Kooooo0_l0000Looooo`;o0000Hoooool00:cooooo00?o0000oooooooo
ool0>Oooool2o`0007kooooo0027ooooo`;o00008oooool00ol0003oooooooooo`0iooooo`;o0000
O_ooool008Oooooo0_l00003ooooo`;o00007_ooool00ol0003oooooooooo`0Gooooo`;o00002Ooo
ool2o`0001Cooooo0ol0001nooooo`00S?ooool2o`0000Kooooo0_l0000Fooooo`?o00005?ooool2
o`000003ooooool0003o000000Wooooo0_l0000Aooooo`;o000000?oooooo`000?l00000Ooooool0
09Cooooo0_l000000ooooooo0000o`00000Cooooo`03o`000?oooooooooo01Cooooo0_l0000Ooooo
o`;o0000P_ooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo00gooooo0_l0000Dooooo`;o
0000U?ooool0083ooooo0_l0000Zooooo`03o`000?oooooooooo00gooooo0_l0000Dooooo`;o0000
U?ooool0083ooooo0_l0000Zooooo`03o`000?oooooooooo02Cooooo0_l0002Cooooo`00[?ooool0
0ol0003oooooooooo`05ooooo`;o00006_ooool2o`000003ooooool0003o000002gooooo0_l0001T
ooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool01Oooool2o`0000gooooo0ol0
000:ooooo`Co00004Oooool2o`0001_ooooo0_l0001Tooooo`00ROooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8b
ooooo`02ooooo`?o00003?ooool2o`0000Sooooo0ol0000<ooooo`;o00004Oooool2o`00087ooooo
0029ooooo`05oa0@4?ooooooooooooooool@41000oooool2o`0000Oooooo00?oV9RHob4Q8Oo^k^h0
2Oooool01?l0003oooooooooooooool5o`0000[ooooo0_l0000Zooooo`;o0000POooool008Wooooo
00Go0000ooooooooooooooooo`000003ooooo`;o00002?ooool00onHV9So8B4Qonk^kP07ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool02_ooool2o`0001Cooooo0_l0000Dooooo`;o
0000POooool008Wooooo00Go0000ooooooooooooooooo`000003ooooo`;o00002Oooool00omgMgOo
IVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool3o`0001?ooooo0_l0000;oooo
o`;o0000Uoooool008Wooooo00Go410@oooooooooooooooooa0@4003ooooo`;o00002_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo0ol00002ooooo`;o00003oooool3o`00
027ooooo0_l00020ooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool2
o`0000Gooooo0_l00009ooooo`;o00008Oooool2o`0001Oooooo0_l0001Wooooo`00ROooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Ko00001?oo
ool00ol0003oooooooooo`09ooooo`;o0000:_ooool2o`0001Wooooo0_l0001Wooooo`00P_ooool2
o`0002;ooooo0_l00004ooooo`03o`000?oooooooooo03Gooooo0_l00022ooooo`00P_ooool2o`00
02Sooooo00?o0000ooooooooool0^Oooool009;ooooo0_l0000@ooooo`;o00001_ooool00ol0003o
ooooooooo`2iooooo`00SOooool2o`0000?ooooo0_l0000@ooooo`;o00001_ooool3o`000;Wooooo
002=ooooo`;o00007Oooool00ol0003oooooooooo`09ooooo`;o0000:_ooool2o`0008;ooooo002/
ooooo`03o`000?oooooooooo00Wooooo0_l0000Zooooo`;o0000P_ooool00:cooooo00?o0000oooo
ooooool00_l0000?ooooo`;o00003_ooool2o`0009Kooooo002Zooooo`?o00000_ooool2o`0000oo
oooo0_l0000>ooooo`;o0000U_ooool00:[ooooo0ol0000Cooooo`;o00008Oooool2o`0008?ooooo
002Mooooo`;o00003Oooool00ol0003oooooooooo`0Aooooo`;o00002_ooool2o`0001Gooooo0_l0
0023ooooo`00WOooool2o`0000gooooo00?o0000ooooooooool00_l0000Kooooo`;o00004_ooool2
o`0008Kooooo002/ooooo`Go00006oooool2o`0001;ooooo0ol00025ooooo`00R?ooool2o`0001Go
oooo0_l0000;ooooo`03o`000?oooooooooo03;ooooo0_l00025ooooo`00R?ooool2o`0001Gooooo
0_l00006ooooo`;o00000oooool00ol0003oooooooooo`2iooooo`00Soooool2o`0001Gooooo0ol0
0003ooooo`03o`000?oooooooooo01cooooo0_l0002Kooooo`00ROooool2o`0000Cooooo0_l0000E
ooooo`;o00001?ooool00ol0003oooooooooo`0Looooo`;o0000Voooool008?ooooo0_l00004oooo
o`;o00005oooool2o`0000Sooooo00?o0000ooooooooool00oooool2o`0001Oooooo0_l0000Aoooo
o`;o0000R?ooool008?ooooo0_l0000Eooooo`;o00001_ooool2o`0000Sooooo00?o0000oooooooo
ool00oooool2o`0000[ooooo0_l0000Nooooo`;o0000R?ooool009Gooooo0_l00003ooooo`;o0000
4?ooool00ol0003oooooooooo`0?ooooo`;o00002?ooool2o`0001?ooooo0_l00029ooooo`00UOoo
ool2o`0001Gooooo0ol0000Iooooo`;o00004oooool2o`0008Wooooo002Eooooo`;o00005Oooool0
0ol0003oooooooooo`2iooooo`00Poooool2o`0001Oooooo0_l0000>ooooo`03o`000?oooooooooo
00cooooo0_l0000Qooooo`;o00006Oooool2o`0006gooooo0023ooooo`;o00001Oooool2o`00013o
oooo0_l0000>ooooo`04o`000?ooooooooooooooo`;o00002Oooool2o`00027ooooo0ol0000Hoooo
o`?o0000K?ooool008[ooooo0_l0000Pooooo`04o`000?ooooooooooooooo`;o00005_ooool2o`00
01Gooooo0_l0000Iooooo`;o0000K?ooool0097ooooo0_l0000Iooooo`03o`000?oooooooooo01Wo
oooo0_l0002Nooooo`00Poooool2o`0000cooooo0_l0000<ooooo`;o00002oooool00ol0003ooooo
ooooo`2iooooo`00Poooool2o`0001[ooooo0_l0000;ooooo`04o`000?ooooooooooooooo`;o0000
2?ooool2o`0003cooooo0_l0001^ooooo`00[?ooool3o`000003ooooool0003o000000Kooooo1?l0
0009ooooo`Co00004?ooool2o`0001gooooo0_l0001^ooooo`00[?ooool00ol0003oooooooooo`02
o`0000Oooooo0_l0000;ooooo`Co00004?ooool2o`0008gooooo002Hooooo`;o00004_ooool00ol0
003oooooooooo`02o`000;Oooooo002Hooooo`;o00004_ooool00ol0003oooooooooo`2iooooo`00
S?ooool2o`0001kooooo00?o0000ooooooooool0^Oooool008cooooo0_l0000Nooooo`03o`000?oo
oooooooo0;Wooooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00Kooooo0_l0002aooooo`00TOoo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool01_ooool2o`0002?ooooo0_l0002<ooooo`00TOooool01Ol@413ooooooooo
oooooooo410@013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`;o0000
6?ooool2o`0007;ooooo002Aooooo`05o`000?ooooooooooooooool000001Oooool2o`0000Sooooo
00?oMgMgoc8b<_ooool01?ooool3o`0004Gooooo0_l0001booooo`00TOooool01Ol0003ooooooooo
oooooooo000000Gooooo0_l00005ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003o
ooooooooo`06ooooo`;o0000?Oooool2o`0007;ooooo002Aooooo`05oa0@4?ooooooooooooooool@
41001oooool2o`0000?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`?o
00002oooool2o`0001?ooooo0_l0002?ooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oo
oooo0_l00003ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool2o`0000co
oooo0_l0000Cooooo`;o00006Oooool2o`0007Cooooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03?ooool4o`0000?ooooo0_l000000ooooooo0000ooooo`14ooooo`;o0000M?ooool00:Gooooo
0_l00002ooooo`;o000000?oooooo`000?ooool0^_ooool009Cooooo0_l0000?ooooo`;o00001Ooo
ool00ol0003oooooooooo`0Cooooo`;o00004Oooool2o`00097ooooo002Dooooo`;o00002oooool2
o`0000Wooooo00?o0000ooooooooool04oooool2o`00017ooooo0_l0002Aooooo`00XOooool2o`00
00Wooooo0ol0000Aooooo`;o0000Y_ooool008oooooo0_l0000Kooooo`03o`000?oooooooooo00ko
oooo1Ol0000Booooo`;o0000T_ooool008oooooo0_l00006ooooo`;o00004oooool00ol0003ooooo
ooooo`0>ooooo`?o00004?ooool3o`000003ooooool0003o000009;ooooo002Gooooo`;o00004ooo
ool00ol0003oooooooooo`0Qooooo`?o0000UOooool008Oooooo0_l0000Sooooo`03o`000?oooooo
oooo0;Wooooo0027ooooo`;o00008oooool00ol0003oooooooooo`2iooooo`00[?ooool01?l0003o
ooooo`000?l0002hooooo`00[?ooool01?l0003oooooo`000?l0002hooooo`00R?ooool2o`0002;o
oooo0ol0002iooooo`00R?ooool2o`0000oooooo1?l0000?ooooo`03o`000?oooooooooo0;Wooooo
002Iooooo`Co00003oooool00ol0003oooooooooo`0;ooooo`;o0000[?ooool008Wooooo0_l0000Q
ooooo`03o`000?oooooooooo00_ooooo0_l0002/ooooo`00ROooool2o`00027ooooo00?o0000oooo
ooooool07Oooool2o`0009[ooooo0029ooooo`;o00004oooool2o`0000Kooooo0_l00004ooooo`03
o`000?oooooooooo00Wooooo0_l0000@ooooo`Co0000V_ooool009kooooo0_l00006ooooo`?o0000
0oooool00ol0003oooooooooo`09ooooo`;o00004?ooool2o`0009cooooo002Wooooo`;o00000ooo
ool00ol0003oooooooooo`2iooooo`00R_ooool2o`0001_ooooo0_l00003ooooo`?o00007_ooool2
o`0009Wooooo002:ooooo`;o00006?ooool2o`000003ooooool0003o000000?ooooo00?o0000oooo
ooooool07_ooool2o`0009Wooooo002Tooooo`;o00001_ooool00ol0003oooooooooo`2iooooo`00
[?ooool00ol0003oooooooooo`0Iooooo`;o0000W_ooool009Cooooo0_l0000Fooooo`03o`000?oo
oooooooo01Wooooo0_l0002Nooooo`00R_ooool2o`0000Sooooo0_l0000Fooooo`03o`000?oooooo
oooo0;Wooooo002:ooooo`;o00002Oooool2o`0001Gooooo00?o0000ooooooooool0^Oooool009Go
oooo0_l0000Eooooo`03o`000?oooooooooo01Oooooo0_l0002Pooooo`00[?ooool00ol0003ooooo
ooooo`0Gooooo`;o0000X?ooool00:cooooo0ol0000Dooooo`?o000000?oooooo`000?l00000Wooo
ool00:cooooo00?o0000ooooooooool00_l0000Booooo`?o000000?oooooo`000?l00000Woooool0
0:cooooo00?o0000ooooooooool00_l0000Cooooo`;o0000X_ooool00:cooooo00?o0000oooooooo
ool05_ooool2o`000:7ooooo002/ooooo`03o`000?oooooooooo01Kooooo0_l0002Qooooo`00ROoo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B43ooooo`Co000000?ok^k^ooooooooool0
0oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool05?ooool2o`000:?o
oooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@?ooooo1?l000000onYZJWo
ooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool05?ooool2o`000:?o
oooo0029ooooo`05oa0@4?ooooooooooooooool@41003Oooool2o`0000Wooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`2iooooo`00ROooool01Ol0003ooooooooooooooooo000000go
oooo0_l00008ooooo`04ogMgMolb<S;oooooooooo`;o000000Coooooo`000?l0003o0000^Oooool0
08Wooooo00Co0000oooooooooooooooo0_l0000=ooooo`03oeEEEOo<c<cooooo00?ooooo00Ko0000
ob4Q8Ol0003o<S8bolc<c?ooool3o`000003ooooool0003ooooo00oooooo0_l0002Yooooo`00ROoo
ool01?l@413oooooooooooooool2o`0000gooooo00?oZJVYogMgMoooool00oooool00ol0003ooooo
ooooo`03ooooo`?o000000?oooooo`000?ooool03oooool2o`000:Wooooo0029ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000oooooooo
ool01?ooool2o`000003ooooool0003ooooo0;[ooooo0029ooooo`06onk^k_lb<S;o0000oc8b<_o^
k^kooooo0_l00008ooooo`Ko00000oooool4o`0000Kooooo00?o0000ooooooooool0^Oooool008oo
oooo0_l0000<ooooo`;o00003Oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooo
ooooo`0Zooooo`;o0000SOooool00:cooooo00?o0000ooooooooool0:_ooool2o`0008gooooo002/
ooooo`?o0000^Oooool0097ooooo0_l0000Iooooo`03o`000?oooooooooo0;Wooooo002Aooooo`;o
00006Oooool00ol0003oooooooooo`0:ooooo`;o0000[Oooool00:cooooo00?o0000ooooooooool0
2Oooool3o`000:gooooo002/ooooo`03o`000?oooooooooo00Wooooo0_l0002^ooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00T_ooool2o`0001Sooooo00?o0000ooooooooool0^Oooool009;o
oooo0_l0000Hooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o00008oooool2o`0009Cooooo
002/ooooo`03o`000?oooooooooo02?ooooo0_l0002Dooooo`00[?ooool00ol0003oooooooooo`02
ooooo`;o0000]Oooool00:cooooo00?o0000ooooooooool00_ooool2o`000;Gooooo002Gooooo`;o
00004oooool00ol0003oooooooooo`2iooooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool0
0_ooool2o`000;Gooooo002/ooooo`05o`000?oooooo0000o`000?ooool00_l0002eooooo`00[?oo
ool01?l0003oooooo`000?l0000Looooo`;o0000V_ooool009Oooooo0_l0000Cooooo`03o`000?oo
oooooooo01gooooo0_l0002Jooooo`00Uoooool2o`0001?ooooo0ol0002iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00W?ooool2o`0000kooooo00?o0000ooooooooool0^Oooool009cooooo
0_l00009ooooo`;o00000oooool00ol0003oooooooooo`2iooooo`00Yoooool2o`0000?ooooo00?o
0000ooooooooool0^Oooool009oooooo0_l0000;ooooo`03o`000?oooooooooo0;Wooooo002Ooooo
o`Co00001?ooool3o`0000;ooooo00?o0000ooooooooool0^Oooool00:7ooooo0_l00003ooooo`Co
00000_ooool00ol0003oooooooooo`0Fooooo`;o0000XOooool00:Kooooo0_l00004ooooo`?o0000
5_ooool2o`000:7ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002Rooooo`Co000000?o410@ooooooooool00ooo
ool00ol0003oooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0;Wooooo002Tooooo`03o`000?oooooooooo00Gooooo0ol0002iooooo`00Y?ooool00ol0003o
ooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003ooooooooo
o`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00X_ooool00omEEEGoIVIVo`000033oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Z_ooool01?l@
413o0000o`000?l0002jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003o
ooooooooo`2jooooo`00Zoooool01_l0003oMgMgo`000?l0003oEEEEonk^k[Oooooo002[ooooo`06
o`000?mEEEGok^k^oooooomgMgOoEEEE]oooool00:_ooooo00?o0000onk^k_ooool00_ooool00ol0
003oooooooooo`2eooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo0;Go
oooo002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoIVIV]oooool00:[ooooo00?o410@o`000?mg
MgL00_l000000omVIVKok^k^ooooo`2fooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.53416 .83408 Mdot
.41715 .81921 Mdot
.45317 .40514 Mdot
.48728 .25316 Mdot
.5815 .41909 Mdot
.62888 .57948 Mdot
.46647 .33076 Mdot
.48293 .9911 Mdot
.56862 .87722 Mdot
.52921 .68822 Mdot
.4434 .74763 Mdot
.4 .86016 Mdot
.41842 .1563 Mdot
.49828 .76597 Mdot
.36844 .59955 Mdot
.55172 .4244 Mdot
.47379 .14645 Mdot
.42543 .13425 Mdot
.47228 .19648 Mdot
.66621 .34436 Mdot
.46376 .07949 Mdot
.38316 .45328 Mdot
.40669 .22371 Mdot
.45132 .08559 Mdot
.37913 .25435 Mdot
.54884 .72781 Mdot
.41126 .52642 Mdot
.4752 .20003 Mdot
.67928 .39246 Mdot
.3985 .72397 Mdot
.52471 .1249 Mdot
.58557 .85739 Mdot
.49037 .98025 Mdot
.55994 .26393 Mdot
.5984 .3396 Mdot
.65271 .33854 Mdot
.68096 .63452 Mdot
.44025 .24992 Mdot
.68744 .47344 Mdot
.39885 .86056 Mdot
.36676 .38126 Mdot
.57945 .29719 Mdot
.62778 .47254 Mdot
.53893 .83401 Mdot
.57882 .75924 Mdot
.59086 .55425 Mdot
.48237 .77748 Mdot
.63755 .77124 Mdot
.43334 .79149 Mdot
.67973 .4169 Mdot
.63446 .77421 Mdot
.69439 .50518 Mdot
.77949 .54924 Mdot
.61963 .42726 Mdot
.62005 .40748 Mdot
.52863 .93306 Mdot
.46306 .98875 Mdot
.45859 .1524 Mdot
.66288 .70706 Mdot
.58905 .73662 Mdot
.5847 .59533 Mdot
.55491 .05821 Mdot
.68694 .49625 Mdot
.48429 .73523 Mdot
.4514 .96724 Mdot
.56591 .88732 Mdot
.53004 .68272 Mdot
.54868 .42124 Mdot
.43166 .27435 Mdot
.4882 .07608 Mdot
.45968 .14448 Mdot
.5212 .46364 Mdot
.51429 .72215 Mdot
.55062 .60622 Mdot
.68687 .49632 Mdot
.50731 .45927 Mdot
.77937 .55009 Mdot
.55167 .70364 Mdot
.69286 .47563 Mdot
.41929 .72514 Mdot
.5952 .22397 Mdot
.39867 .72207 Mdot
.47143 .25133 Mdot
.5821 .3004 Mdot
.522 .95119 Mdot
.55124 .40634 Mdot
.58405 .4322 Mdot
.58725 .52412 Mdot
.42479 .2249 Mdot
.55082 .43665 Mdot
.38704 .20206 Mdot
.74608 .35585 Mdot
.43543 .67052 Mdot
.59107 .52034 Mdot
.44545 .70343 Mdot
.7316 .3121 Mdot
.50269 .75678 Mdot
.61361 .80539 Mdot
.77958 .56198 Mdot
.41693 .25339 Mdot
.50594 .8752 Mdot
.3995 .39379 Mdot
.38985 .80779 Mdot
.5118 .87316 Mdot
.55233 .1532 Mdot
.56955 .28278 Mdot
.49268 .14702 Mdot
.49818 .21113 Mdot
.43471 .66761 Mdot
.50096 .08906 Mdot
.51937 .71901 Mdot
.46999 .24668 Mdot
.58549 .8561 Mdot
.64895 .31081 Mdot
.73595 .7464 Mdot
.43086 .42561 Mdot
.57309 .64442 Mdot
.57257 .88573 Mdot
.58311 .86786 Mdot
.67215 .65116 Mdot
.42306 .14329 Mdot
.49845 .00026 Mdot
.45997 .08941 Mdot
.6805 .39133 Mdot
.49678 .08347 Mdot
.51013 .29575 Mdot
.66068 .34421 Mdot
.71121 .27039 Mdot
.42496 .83219 Mdot
.49963 .31685 Mdot
.39445 .29508 Mdot
.46954 .89971 Mdot
.3747 .70476 Mdot
.63184 .5752 Mdot
.6306 .51179 Mdot
.68968 .43408 Mdot
.69555 .57922 Mdot
.6728 .37749 Mdot
.51552 .71825 Mdot
.44662 .96826 Mdot
.3684 .60744 Mdot
.63885 .16473 Mdot
.42314 .40407 Mdot
.44384 .23335 Mdot
.47195 .14616 Mdot
.65728 .32445 Mdot
.54275 .92562 Mdot
.69882 .82305 Mdot
.53631 .29499 Mdot
.58718 .54378 Mdot
.44235 .00878 Mdot
.39612 .47352 Mdot
.40928 .47097 Mdot
.44955 .08631 Mdot
.51708 .42893 Mdot
.60235 .68334 Mdot
.69303 .56871 Mdot
.68973 .4974 Mdot
.56087 .89827 Mdot
.67698 .64465 Mdot
.69371 .57089 Mdot
.50496 .8141 Mdot
.69355 .46513 Mdot
.36495 .60576 Mdot
.63694 .3043 Mdot
.6258 .49747 Mdot
.49962 .88019 Mdot
.54494 .92165 Mdot
.5663 .17072 Mdot
.42684 .29653 Mdot
.69855 .545 Mdot
.67264 .40109 Mdot
.42093 .49896 Mdot
.41945 .34618 Mdot
.58529 .46042 Mdot
.54253 .30514 Mdot
.46506 .98075 Mdot
.72605 .30094 Mdot
.60347 .67803 Mdot
.43595 .39119 Mdot
.68357 .42341 Mdot
.69901 .51032 Mdot
.37606 .72635 Mdot
.56072 .52111 Mdot
.36958 .33557 Mdot
.53171 .43479 Mdot
.56525 .87858 Mdot
.71196 .27561 Mdot
.60649 .8303 Mdot
.36656 .62976 Mdot
.63041 .48465 Mdot
.65634 .32074 Mdot
.50732 .68705 Mdot
.54789 .05415 Mdot
.50078 .97585 Mdot
.37864 .23739 Mdot
.38352 .77216 Mdot
.59019 .50544 Mdot
.76044 .38624 Mdot
.52446 .18798 Mdot
.431 .54152 Mdot
.43007 .51897 Mdot
.52289 .49189 Mdot
.58095 .43011 Mdot
.76724 .41367 Mdot
.47967 .8975 Mdot
.53173 .58334 Mdot
.62263 .61504 Mdot
.45354 .26209 Mdot
.53816 .47193 Mdot
.44311 .74956 Mdot
.38837 .33027 Mdot
.55848 .68606 Mdot
.56884 .17468 Mdot
.55873 .50974 Mdot
.49016 .89016 Mdot
.56368 .66721 Mdot
.36334 .56058 Mdot
.53023 .41483 Mdot
.58221 .74212 Mdot
.42077 .93211 Mdot
.57703 .63002 Mdot
.6451 .74169 Mdot
.55155 .1494 Mdot
.61459 .26032 Mdot
.55613 .49141 Mdot
.56528 .35933 Mdot
.4476 .89325 Mdot
.42255 .56413 Mdot
.36814 .59521 Mdot
.50111 .00039 Mdot
.53617 .35866 Mdot
.44744 .60894 Mdot
.76845 .43738 Mdot
.39805 .53476 Mdot
.41429 .59766 Mdot
.42699 .29958 Mdot
.49812 .89254 Mdot
.43605 .11895 Mdot
.48246 .89872 Mdot
.56044 .06555 Mdot
.63365 .52339 Mdot
.59056 .20387 Mdot
.45892 .14528 Mdot
.59519 .84713 Mdot
.44764 .70586 Mdot
.68724 .58208 Mdot
.42947 .21924 Mdot
.45394 .15073 Mdot
.68816 .49097 Mdot
.3774 .24988 Mdot
.43046 .4329 Mdot
.49865 .70626 Mdot
.68171 .612 Mdot
.53017 .76248 Mdot
.41743 .36423 Mdot
.6241 .41085 Mdot
.50921 .48579 Mdot
.46103 .98494 Mdot
.6512 .74024 Mdot
.41012 .68907 Mdot
.4148 .60391 Mdot
.6223 .27384 Mdot
.46802 .29076 Mdot
.39713 .45453 Mdot
.5441 .81461 Mdot
.46248 .77338 Mdot
.624 .57812 Mdot
.66326 .37104 Mdot
.49084 .82704 Mdot
.65444 .33349 Mdot
.62316 .417 Mdot
.53664 .66976 Mdot
.41537 .71233 Mdot
.69502 .55698 Mdot
.56155 .52647 Mdot
.53698 .2809 Mdot
.62402 .79341 Mdot
.45831 .77863 Mdot
.61247 .65503 Mdot
.68743 .4382 Mdot
.49203 .29393 Mdot
.55228 .58508 Mdot
.67462 .65007 Mdot
.40579 .8791 Mdot
.50098 .21488 Mdot
.50205 .36431 Mdot
.5716 .40101 Mdot
.62927 .26545 Mdot
.58752 .5563 Mdot
.58403 .20748 Mdot
.71322 .28006 Mdot
.65973 .70857 Mdot
.38097 .74406 Mdot
.64877 .72918 Mdot
.43764 .46047 Mdot
.67814 .66519 Mdot
.53922 .04862 Mdot
.61007 .23019 Mdot
.37138 .6476 Mdot
.67651 .8605 Mdot
.43405 .7879 Mdot
.63268 .45945 Mdot
.46923 .90138 Mdot
.59042 .8526 Mdot
.36863 .36079 Mdot
.47516 .78154 Mdot
.62025 .79753 Mdot
.52332 .7769 Mdot
.44784 .65562 Mdot
.39179 .30334 Mdot
.48417 .14712 Mdot
.42125 .15127 Mdot
.43019 .03001 Mdot
.43997 .3592 Mdot
.56923 .76879 Mdot
.57213 .28597 Mdot
.43485 .94544 Mdot
.46514 .29037 Mdot
.37115 .67609 Mdot
.64911 .17175 Mdot
.52966 .34432 Mdot
.63416 .56866 Mdot
.58166 .29648 Mdot
.68802 .52432 Mdot
.56346 .34759 Mdot
.44181 .63849 Mdot
.44792 .37743 Mdot
.48235 .14149 Mdot
.44403 .97454 Mdot
.67892 .61623 Mdot
.45181 .72003 Mdot
.3841 .39834 Mdot
.50251 .32246 Mdot
.52289 .50051 Mdot
.4404 .88181 Mdot
.63171 .55899 Mdot
.62599 .49811 Mdot
.50271 .81728 Mdot
.57845 .41931 Mdot
.78128 .51019 Mdot
.51161 .79467 Mdot
.40335 .74603 Mdot
.47541 .73749 Mdot
.50249 .96548 Mdot
.41283 .56241 Mdot
.6701 .37123 Mdot
.38439 .54064 Mdot
.42052 .55399 Mdot
.57395 .62398 Mdot
.63433 .1576 Mdot
.41037 .89926 Mdot
.68425 .64998 Mdot
.65625 .34539 Mdot
.45652 .83139 Mdot
.52812 .19735 Mdot
.66939 .38481 Mdot
.39701 .49992 Mdot
.409 .89423 Mdot
.64679 .16328 Mdot
.59547 .21136 Mdot
.37492 .70506 Mdot
.36837 .63981 Mdot
.36394 .42809 Mdot
.52 .56244 Mdot
.40243 .61529 Mdot
.36716 .57597 Mdot
.46489 .98822 Mdot
.51789 .57995 Mdot
.56056 .17088 Mdot
.49555 .81714 Mdot
.62592 .60702 Mdot
.5143 .86329 Mdot
.60252 .82424 Mdot
.49779 .89233 Mdot
.67744 .65511 Mdot
.68325 .58206 Mdot
.40247 .24781 Mdot
.69075 .6243 Mdot
.39339 .30678 Mdot
.36894 .36656 Mdot
.72646 .77117 Mdot
.66357 .67993 Mdot
.60435 .68382 Mdot
.51573 .4292 Mdot
.42451 .05395 Mdot
.41334 .27527 Mdot
.4446 .39538 Mdot
.37567 .72645 Mdot
.49322 .07959 Mdot
.44754 .66234 Mdot
.54431 .63426 Mdot
.55832 .69873 Mdot
.4108 .5356 Mdot
.63392 .78036 Mdot
.54559 .13657 Mdot
.54858 .05671 Mdot
.37344 .70296 Mdot
.52325 .19611 Mdot
.77768 .50563 Mdot
.52887 .20191 Mdot
.53657 .29011 Mdot
.54551 .30625 Mdot
.48569 .65294 Mdot
.44522 .97437 Mdot
.40189 .86719 Mdot
.41188 .54669 Mdot
.41999 .51741 Mdot
.42521 .69245 Mdot
.55855 .45302 Mdot
.40838 .0893 Mdot
.59188 .49357 Mdot
.63194 .2892 Mdot
.4358 .32196 Mdot
.41074 .43327 Mdot
.47764 .28663 Mdot
.5891 .46749 Mdot
.55038 .24616 Mdot
.41136 .5688 Mdot
.52858 .60293 Mdot
.45266 .97496 Mdot
.45696 .59462 Mdot
.60377 .35413 Mdot
.4937 .1482 Mdot
.57953 .73783 Mdot
.48061 .83039 Mdot
.4201 .33768 Mdot
.41949 .06394 Mdot
.73988 .32445 Mdot
.47384 .90527 Mdot
.7553 .69316 Mdot
.53232 .84603 Mdot
.52584 .62225 Mdot
.53861 .91379 Mdot
.36592 .52344 Mdot
.43049 .70311 Mdot
.3842 .50119 Mdot
.78093 .52158 Mdot
.42021 .46956 Mdot
.4628 .69334 Mdot
.55426 .33717 Mdot
.61677 .26052 Mdot
.44006 .79688 Mdot
.75429 .37283 Mdot
.5356 .46006 Mdot
.61196 .39589 Mdot
.57076 .27474 Mdot
.46784 .74017 Mdot
.44276 .34933 Mdot
.55842 .56511 Mdot
.47863 .99179 Mdot
.44591 .33043 Mdot
.69127 .45365 Mdot
.43966 .87759 Mdot
.57105 .77009 Mdot
.65689 .33615 Mdot
.57024 .1875 Mdot
.50191 .16361 Mdot
.70394 .24994 Mdot
.54196 .64454 Mdot
.44037 .96993 Mdot
.37375 .27905 Mdot
.45636 .76543 Mdot
.68082 .65903 Mdot
.48483 .82997 Mdot
.46713 .15203 Mdot
.66841 .36432 Mdot
.50973 .87106 Mdot
.48844 .20211 Mdot
.57434 .62392 Mdot
.5542 .25056 Mdot
.53468 .03269 Mdot
.62814 .5254 Mdot
.50352 .42393 Mdot
.62537 .46933 Mdot
.42022 .73194 Mdot
.52295 .53644 Mdot
.53939 .38142 Mdot
.61776 .41503 Mdot
.6315 .48832 Mdot
.429 .48486 Mdot
.5366 .74665 Mdot
.56284 .8914 Mdot
.57804 .39797 Mdot
.55385 .79662 Mdot
.42516 .29648 Mdot
.48996 .21059 Mdot
.50575 .64011 Mdot
.74659 .72482 Mdot
.49777 .66583 Mdot
.42825 .85436 Mdot
.6319 .76384 Mdot
.63808 .30455 Mdot
.43941 .24756 Mdot
.67769 .39611 Mdot
.38337 .77824 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`04ooooo`Co0000^Oooool00:Cooooo00?o0000ooooooooool01?ooool3o`000;[o
oooo002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool009Wooooo0_l0
0009ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool009Wooooo0_l00009
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:;ooooo00?oEEEEofIV
I_l000001oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002Eooooo`;o00005Oooool00ol0003oooooooooo`2iooooo`00UOooool2o`0001Go
oooo00?o0000ooooooooool02?ooool2o`000:oooooo002/ooooo`03o`000?oooooooooo00Sooooo
0_l0002_ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0:ooooo`;o
0000[Oooool00:cooooo0ol0000:ooooo`;o0000[Oooool009?ooooo0_l0000Gooooo`03o`000?oo
oooooooo00cooooo0_l0002[ooooo`00Toooool2o`0001Oooooo00?o0000ooooooooool03?ooool5
o`000:Sooooo002/ooooo`03o`000?oooooooooo00gooooo1?l0002Xooooo`00TOooool2o`0001Wo
oooo00?o0000ooooooooool0^Oooool0097ooooo0_l0000Iooooo`03o`000?oooooooooo017ooooo
0_l0002Vooooo`00[?ooool00ol0003oooooooooo`0Aooooo`;o0000Y_ooool00:cooooo00?o0000
ooooooooool0^Oooool00:Sooooo0_l00002ooooo`?o0000^Oooool00:3ooooo0_l00006ooooo`?o
000000?oooooo`000?ooool0^_ooool00:3ooooo0_l00007ooooo`Co0000^oooool009_ooooo0_l0
000=ooooo`?o0000^oooool008gooooo0_l0000<ooooo`;o000000?oooooo`000?l000003?ooool2
o`000;[ooooo002=ooooo`;o00003oooool2o`0000cooooo0_l0002jooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@03ooooool0
003o000000?ooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo
00?o0000ooooooooool0^Oooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
00?oooooo`000?l000000oooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0^Oooool0087ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@4100
3Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol00005ooooo`;o0000
/_ooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`05ooooo`;o0000/_ooool008Wooooo00Go
0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05oa0@4?ooooooooooooooool@
41001Oooool2o`0000Oooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0;Wooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0000Co
oooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool03?ooool2o`000:_ooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`00
00Cooooo1?l00006ooooo`03o`000?oooooooooo00cooooo0_l0002[ooooo`00T_ooool2o`0001;o
oooo0_l00004ooooo`03o`000?oooooooooo0;Wooooo002Booooo`;o00002_ooool2o`0000;ooooo
0ol000001?oooooo0000o`000?ooool2o`000003ooooool0003ooooo0;[ooooo002Nooooo`;o0000
0_ooool3o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?ooool03oooool2o`000:Wo
oooo002Booooo`;o00002?ooool4o`000003ooooool0003o000000?ooooo0_l000001?oooooo0000
o`000?ooool3o`0000kooooo0_l0002Yooooo`00T_ooool2o`0000Sooooo1?l000000ooooooo0000
o`000009ooooo`03o`000?oooooooooo00kooooo0_l0002Yooooo`00TOooool2o`0001Wooooo00?o
0000ooooooooool03_ooool2o`0001Wooooo0_l0002>ooooo`00TOooool2o`0001Wooooo00?o0000
ooooooooool0:Oooool2o`0008kooooo002/ooooo`;o0000:oooool2o`000003ooooool0003o0000
08[ooooo002/ooooo`;o0000:oooool2o`000003ooooool0003o000008[ooooo002/ooooo`03o`00
0?oooooooooo017ooooo0ol0002Uooooo`00[?ooool00ol0003oooooooooo`0Aooooo`?o00006_oo
ool2o`0008Wooooo002/ooooo`?o00004oooool2o`0001Wooooo0_l00029ooooo`00[?ooool00ol0
003oooooooooo`0Cooooo`;o0000Y?ooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool01Oooool2o`0000gooooo0_l0
002Sooooo`00[?ooool00ol0003oooooooooo`05ooooo`;o00003Oooool2o`000:?ooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002Rooooo`;o00002?ooool00ol0003oooooooooo`04ooooo`Co
0000/Oooool00:;ooooo0ol00007ooooo`?o00001?ooool4o`000;7ooooo0026ooooo`;o00006ooo
ool2o`0000?ooooo0_l00002ooooo`03o`000?oooooooooo00Kooooo0_l0000Booooo`;o0000WOoo
ool008Kooooo0_l0000Pooooo`;o00000_ooool00ol0003oooooooooo`06ooooo`;o00004?ooool4
o`0009gooooo002Xooooo`;o00000_ooool00ol0003oooooooooo`0Hooooo`;o0000Woooool00:So
oooo0_l000000ooooooo0000o`00000Nooooo`;o0000Voooool00:_ooooo0ol0000Mooooo`;o0000
Voooool009Cooooo0_l0000Fooooo`;o0000^_ooool009Cooooo0_l0000Fooooo`03o`000?oooooo
oooo0;Wooooo002=ooooo`;o00001?ooool2o`0001Oooooo0ol0000Looooo`;o0000Voooool008go
oooo0_l00004ooooo`;o00005oooool00ol0003oooooooooo`0Looooo`;o0000Voooool00:cooooo
00?o0000ooooooooool08Oooool2o`0009Kooooo002Iooooo`;o00004Oooool00ol0003ooooooooo
o`0Qooooo`;o0000U_ooool008?ooooo0_l0000Dooooo`;o00004Oooool00ol0003oooooooooo`2i
ooooo`00Poooool2o`0002Oooooo00?o0000ooooooooool0^Oooool0097ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool0^Oooool0097ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1Oooool2
o`000003oooooomgMgOo<S8b00Gooooo00?o0000ooooooooool03Oooool2o`000:[ooooo0023oooo
o`;o00001?ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@4002ooooo`;o00002?ooool2
o`0000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0=ooooo`;o0000<Oooool2
o`0007Oooooo0023ooooo`;o00001_ooool2o`0000Cooooo00Go0000ooooooooooooooooo`000002
ooooo`;o00002?ooool2o`000003oooooomgMgOo<S8b00Gooooo0ol0000>ooooo`;o0000<?ooool2
o`0007Oooooo0024ooooo`;o00002_ooool2o`0000?ooooo00?o0000ooooooooool02_ooool3o`00
0004oc8b<_o<c<co0000o`0000?ooooo00?o0000ooooooooool03_ooool2o`000:Wooooo0024oooo
o`;o00002_ooool2o`0000?ooooo00?o410@ooooooooool02_ooool00ol0003oooooooooo`02oooo
o`;o00000oooool00ol0003oooooooooo`2iooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Kooooo0_l00004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08_ooool3o`00
09Cooooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool2o`0000Cooooo1?l00006oooo
o`03o`000?oooooooooo013ooooo0_l0000@ooooo`?o0000U?ooool00:cooooo00?o0000oooooooo
ool04?ooool2o`0001Gooooo0_l0002@ooooo`00[?ooool00ol0003oooooooooo`0Wooooo`;o0000
6Oooool2o`0007Gooooo002/ooooo`03o`000?oooooooooo02Gooooo0_l0000Kooooo`;o0000MOoo
ool008oooooo0_l00004ooooo`;o00005Oooool3o`0001Cooooo0_l0000?ooooo`;o00007?ooool2
o`0007Cooooo0022ooooo`;o00002oooool2o`0000Cooooo0_l0000Eooooo`03o`000?oooooooooo
01Cooooo0_l0000]ooooo`;o0000M?ooool008;ooooo0_l0000Xooooo`03o`000?oooooooooo00Wo
oooo0_l00009ooooo`;o0000;Oooool2o`0007Cooooo002/ooooo`03o`000?oooooooooo00Wooooo
0_l00009ooooo`;o0000Xoooool00:Cooooo0_l00006ooooo`03o`000?oooooooooo01Cooooo0_l0
000Booooo`;o0000Soooool00:3ooooo0ol000000ooooooo0000o`000006ooooo`03o`000?oooooo
oooo00Wooooo0_l0000Mooooo`;o0000Soooool008Wooooo0_l0000Eooooo`?o00001_ooool2o`00
0003ooooool0003ooooo00[ooooo0_l0002^ooooo`00ROooool2o`0000Sooooo0_l0000Dooooo`;o
000000Coooooo`000?oooooooooo0_l00007ooooo`;o00003?ooool3o`0009oooooo002Cooooo`;o
00005oooool5o`0001Gooooo0ol0000]ooooo`;o0000L?ooool008Sooooo0_l00009ooooo`;o0000
5oooool00ol0003oooooooooo`0Hooooo`;o00004?ooool2o`0001_ooooo0_l0001`ooooo`00R?oo
ool2o`0002;ooooo00?o0000ooooooooool02oooool3o`0001cooooo0_l0002=ooooo`00R?ooool2
o`0002;ooooo00?o0000ooooooooool02oooool3o`000:_ooooo002/ooooo`03o`000?oooooooooo
02kooooo0_l0000Iooooo`;o0000K_ooool00:cooooo00?o0000ooooooooool0;_ooool2o`0001Wo
oooo0_l0001^ooooo`00Zoooool2o`000;_ooooo002Fooooo`;o00004oooool3o`00037ooooo0_l0
0027ooooo`00U_ooool2o`0001Cooooo0ol0000`ooooo`;o00006_ooool2o`0006_ooooo002/oooo
o`03o`000?oooooooooo033ooooo0_l0000Jooooo`;o0000Joooool008Oooooo0_l0000Aooooo`;o
00001?ooool2o`0000[ooooo00?o0000ooooooooool0^Oooool008Oooooo0_l0000Aooooo`;o0000
1?ooool2o`0000[ooooo00?o0000ooooooooool0<?ooool2o`0008Oooooo0021ooooo`;o00003_oo
ool2o`0001Wooooo00?o0000ooooooooool03_ooool2o`00023ooooo0_l00027ooooo`00POooool2
o`0000kooooo0_l0000Iooooo`03o`000?oooooooooo00kooooo0_l0000=ooooo`;o00004?ooool3
o`0008Oooooo002/ooooo`03o`000?oooooooooo01gooooo0_l0000@ooooo`;o0000R?ooool0097o
oooo0_l0000Iooooo`03o`000?oooooooooo00Kooooo0_l0000Xooooo`Go0000Q?ooool0097ooooo
0_l00006ooooo`;o00004Oooool00ol0003oooooooooo`06ooooo`;o00002_ooool2o`0001cooooo
1Ol00024ooooo`00VOooool2o`00017ooooo0ol0000Booooo`;o0000YOooool00:cooooo00?o0000
ooooooooool07oooool2o`0002gooooo0_l0001Yooooo`00[?ooool00ol0003oooooooooo`09oooo
o`;o00005?ooool2o`0002gooooo0_l0001Yooooo`00P?ooool2o`0001Kooooo0_l0000Booooo`03
o`000?oooooooooo00Wooooo0_l00007ooooo`;o0000YOooool0083ooooo0_l0000>ooooo`;o0000
1_ooool2o`0001;ooooo0_l0000Cooooo`;o00008?ooool2o`0008?ooooo0020ooooo`;o00001ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo0_l000000ooooooo8B4Qob4Q8@04ooooo`Go0000
1?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo0_l0000eooooo`;o0000Poooool0083ooooo
0_l00007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0<_ooool2o`00
0003ooooool0003o000008;ooooo0021ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@
00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
03;ooooo0_l000000ooooooo0000o`00000Jooooo`;o0000I_ooool008Wooooo00Go0000oooooooo
ooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`00
057ooooo0_l0001Vooooo`00ROooool01Ol0003ooooooooooooooooo000000cooooo0_l000000omg
MgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0f
ooooo`;o0000POooool0083ooooo0_l00007ooooo`05oa0@4?ooooooooooooooool@41003?ooool2
o`000003ooooool0003ooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:
ooooo`;o0000:_ooool2o`00087ooooo0020ooooo`;o00001oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02_ooool2o`0002Sooooo0_l0000Mooooo`;o0000I?ooool008Wooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo
00?o0000ooooooooool0=?ooool2o`0001gooooo0_l0001Tooooo`00U_ooool2o`0001Cooooo00?o
0000ooooooooool0>?ooool2o`0007oooooo002:ooooo`;o00002_ooool2o`000003ooooool0003o
0000017ooooo00?o0000ooooooooool0>?ooool2o`0007oooooo0025ooooo`;o00000oooool2o`00
00gooooo0_l0000Aooooo`03o`000?oooooooooo01Kooooo0_l0000:ooooo`;o00004oooool2o`00
083ooooo0025ooooo`;o00009Oooool3o`0001Cooooo1?l0000:ooooo`;o00004_ooool3o`00083o
oooo002Booooo`;o00006?ooool00ol0003oooooooooo`0Dooooo`;o00008?ooool2o`00087ooooo
002Booooo`;o00002?ooool2o`0000kooooo00?o0000ooooooooool03Oooool2o`0001Gooooo0_l0
002Cooooo`00W?ooool2o`0000kooooo00?o0000ooooooooool03Oooool2o`0001Gooooo0_l0002C
ooooo`00[?ooool00ol0003oooooooooo`0Vooooo`;o0000;Oooool2o`0006;ooooo002/ooooo`03
o`000?oooooooooo00Oooooo0_l0000Jooooo`;o000000?oooooo`000?l00000;Oooool2o`0006;o
oooo002/ooooo`03o`000?oooooooooo00Oooooo0_l0000=ooooo`?o00002_ooool4o`00017ooooo
0_l0001oooooo`00[?ooool00ol0003oooooooooo`0=ooooo`;o00001oooool3o`0000cooooo0_l0
000Aooooo`;o0000Ooooool009Gooooo0_l0000Eooooo`?o00003Oooool3o`0002Wooooo0_l0001n
ooooo`00Ooooool2o`0001Cooooo0_l0000Eooooo`?o00003_ooool2o`0001Cooooo0_l0000Coooo
o`;o0000O_ooool007oooooo0_l0000[ooooo`03o`000?oooooooooo00;ooooo0_l0000Cooooo`;o
00002oooool2o`0009?ooooo002>ooooo`;o00001Oooool2o`0001Gooooo00?o0000ooooooooool0
0_ooool2o`0000?ooooo0_l0000>ooooo`?o00008Oooool2o`0007cooooo002>ooooo`;o00001Ooo
ool2o`0001Gooooo00?o0000ooooooooool01oooool2o`0000Cooooo0_l00009ooooo`;o00008Ooo
ool2o`0001Sooooo0_l0001Rooooo`00[?ooool00ol0003oooooooooo`0=ooooo`;o0000:oooool2
o`0001Wooooo0_l0001Rooooo`00[?ooool00ol0003oooooooooo`0jooooo`;o0000OOooool00:co
oooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0
000@ooooo`;o0000Yoooool008Gooooo0_l00003ooooo`;o00008?ooool00ol0003oooooooooo`0@
ooooo`;o0000:_ooool2o`0007_ooooo0025ooooo`;o00000oooool2o`00023ooooo00?o0000oooo
ooooool0??ooool2o`0007_ooooo0009ooooo`Co000000?o410@ooooooooool05_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00Go
A4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo1Ol00004ooooo`06odA4A?l0003o0000oc8b<_oMgMgooooo0_l0000Cooooo`04o`000?oooooo
0000o`0000Oooooo0_l0000>ooooo`05onk^k_l0003o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8b
omgMg@0Hooooo`Co000000?o410@ooooooooool04_ooool000_ooooo00?o0000ooooooooool06?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo
00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03
ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnH
V9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool00_l0000Cooooo`04o`000?oooooo
0000o`0000?ooooo0_l00002ooooo`;o00003_ooool01OmgMgOo0000o`000?nHV9SoMgMg00Gooooo
0_lQ8B44ooooo`;o000000?ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`05ooooo`;o0000
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07oooo
o`03ogMgMolb<S;ooooo01Wooooo00?o0000ooooooooool05?ooool000Ko00001Oooool00ol0003o
ooooooooo`0@ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEE
EOooool02?ooool00ol0003oooooooooo`05ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo
410@013ooooo00?o0000ooooooooool01Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`04ooooo`;o00004_ooool01Ol@413oooooo`000?l0003o410@00cooooo00?oV9RHob4Q8Oo^k^h0
2Oooool00ol0003oooooooooo`04ooooo`;o00001oooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool03Oooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEE
EOooool02?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Cooooo000;ooooo`03
o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo
00Kooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMg
oc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000gooooo00CoV9RHob4Q8Oo^k^kooooo
0_l000001_oooooo0000o`000?ooooooMgMgoc8b<QKooooo00?o0000ooooooooool06?ooool00ol0
003oooooo`000002o`0000Wooooo0_l00002ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b
<_ooool03_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool03_ooool0
1Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8boooo
o`0Iooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go0000
ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00?ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00oooooo00Go0000ooooooooooooooooo`00000<ooooo`;o000000?oMgMgofIVI_ooool00_l00000
1_oooooo0000o`000?l0003o<S8bolc<c1Kooooo00?o0000ooooooooool02Oooool2o`0000gooooo
00Go0000ooooooooooooooooo`000009ooooo`?o00000_ooool00omgMgOoIVIVooooo`03ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01?ooool2o`0000Wooooo00Go0000ooooooooooooooooo`00000<
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000kooooo
00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[ooooo00?o0000oooooooo
ool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol@413ooooooooooooooooo410@00ko
oooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`0Aooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003?ooool2
o`000003ooooool0003ooooo00?ooooo00?o0000ooooooooool06?ooool3o`0000Wooooo0_l0000=
ooooo`05oa0@4?ooooooooooooooool@41002_ooool2o`0000?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`06ooooo`Co00001oooool01Ol@413ooooooooooooooooo410@00cooooo
00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMooo
ool00oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`00
0?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooo
oolb<S801?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooo
oonHV9So410@00Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Hooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooo
ooooool02?ooool2o`0000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooo
oooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S80
1?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Cooooo0009ooooo`03oeEEEOmV
IVKo000001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`00013ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00005oooool00ol0003oooooooooo`0H
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo
1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00013ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0001Wooooo00?oEEEEofIVI_l000005_ooool009Co
oooo0_l0000Fooooo`03o`000?oooooooooo00;o00009_ooool2o`0008oooooo002Dooooo`;o0000
5_ooool00ol0003oooooooooo`02o`0002Kooooo0_l0002?ooooo`00[?ooool00ol0003ooooooooo
o`04ooooo`;o00002Oooool2o`0001Oooooo0_l0000Aooooo`;o0000LOooool2o`0000;ooooo0_l0
0005ooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o00002Oooool2o`0000[ooooo0_l0000N
ooooo`;o0000LOooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Gooooo002/ooooo`03o`000?oo
oooooooo01_ooooo0_l00009ooooo`;o00004_ooool3o`0007;ooooo00CogMgMo`000?l@413oc<c<
1_ooool000Ooooooool0001<o`0000cooooo00Cok^k^ob4Q8Ol@413ok^k^1_ooool000Oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co
0000ooooool0003o00000oooool2o`0000Gooooo0_l000000ooooooo0000ooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`?o0000
1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0:ooooo`04ob4Q8OmgMgOoMgMgoc8b<PKooooo0007ooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool06_ooool2o`0000_ooooo00?o0000ooooooooool0
4oooool2o`00017ooooo00?o0000ooooooooool01Oooool2o`0001oooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`09ooooo`;o00000_ooool2o`0000Gooooo002/ooooo`03o`000?oo
oooooooo013ooooo0_l00008ooooo`;o00008Oooool3o`0001Sooooo0ol0001Nooooo`00[?ooool0
0ol0003oooooooooo`0@ooooo`;o00005_ooool2o`0001Cooooo0_l0000Iooooo`;o0000G_ooool0
0:cooooo00?o0000ooooooooool0:?ooool2o`0008oooooo002Aooooo`;o000000?oooooo`000?l0
00005_ooool00ol0003oooooooooo`2iooooo`00TOooool2o`000003ooooool0003o000001Kooooo
00?o0000ooooooooool04Oooool2o`0000Sooooo0_l0000looooo`;o0000G_ooool007oooooo0_l0
000[ooooo`?o00004Oooool2o`0000Kooooo1?l0000:ooooo`Co00004?ooool2o`0001cooooo0_l0
001Nooooo`00Ooooool2o`0000gooooo0_l0000Looooo`03o`000?oooooooooo017ooooo0_l00006
ooooo`;o00003?ooool4o`00013ooooo0_l0001looooo`00S_ooool2o`0001cooooo00?o0000oooo
ooooool04Oooool2o`000:Kooooo002:ooooo`;o00008?ooool00ol0003oooooooooo`2iooooo`00
R_ooool2o`0000;ooooo0_l0000Looooo`03o`000?oooooooooo00Cooooo0_l0002cooooo`00QOoo
ool2o`0000Oooooo0_l0000Looooo`03o`000?oooooooooo00Cooooo0_l0002cooooo`00QOooool2
o`0000kooooo0_l0000Eooooo`03o`000?oooooooooo01Wooooo0_l0002Nooooo`00S_ooool2o`00
00Gooooo0_l0000Eooooo`03o`000?oooooooooo01Wooooo0_l0000Sooooo`;o0000NOooool008ko
oooo0_l0000Looooo`03o`000?oooooooooo03kooooo0_l0000Iooooo`;o0000G_ooool00:cooooo
0ol0001Iooooo`;o0000G_ooool0097ooooo0_l0000Iooooo`03o`000?oooooooooo01_ooooo0_l0
000looooo`;o0000G_ooool0097ooooo0_l0000Iooooo`03o`000?oooooooooo01Wooooo1?l0000;
ooooo`;o00004oooool2o`0007[ooooo001nooooo`;o0000;?ooool00ol0003oooooooooo`0Ioooo
o`;o00003Oooool2o`0001?ooooo0_l0000Jooooo`;o0000G_ooool007kooooo0_l0000?ooooo`;o
000000?oooooo`000?l000006?ooool00ol0003oooooooooo`03ooooo`;o00002oooool2o`0004Oo
oooo0_l0001Nooooo`00Soooool2o`000003ooooool0003o000001Sooooo00?o0000ooooooooool0
0oooool2o`0000_ooooo0_l0002Wooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool0:Ooo
ool2o`00017ooooo0ol0001jooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool0:Oooool2
o`00017ooooo0ol0001jooooo`00P?ooool2o`0002[ooooo0ol0000Xooooo`;o0000Soooool0083o
oooo0_l0000Zooooo`03o`000?oooooooooo00;ooooo0_l0000Qooooo`Go00004oooool2o`0007[o
oooo002/ooooo`03o`000?oooooooooo00;ooooo0_l0000Qooooo`Co00004?ooool3o`000003oooo
ool0003o000007[ooooo002/ooooo`03o`000?oooooooooo00Oooooo0_l00005ooooo`;o0000:Ooo
ool3o`0007gooooo002/ooooo`03o`000?oooooooooo00Oooooo0_l00005ooooo`;o0000ZOooool0
0:cooooo00?o0000ooooooooool0^Oooool0083ooooo0_l0000Kooooo`;o00003Oooool00ol0003o
ooooooooo`0Iooooo`;o0000W_ooool0083ooooo0_l0000=ooooo`;o00003?ooool2o`0000gooooo
00?o0000ooooooooool06Oooool2o`0009kooooo0020ooooo`;o00003Oooool2o`0001_ooooo0ol0
002iooooo`00P?ooool2o`0000gooooo0_l0000Kooooo`03o`000?oooooooooo00Kooooo0_l0002a
ooooo`00Ooooool3o`0000gooooo0_l0000Kooooo`03o`000?oooooooooo00Kooooo0_l00005oooo
o`;o00005oooool2o`00097ooooo001oooooo`?o00006?ooool2o`00013ooooo00?o0000oooooooo
ool03Oooool2o`0001Oooooo0_l0002Aooooo`00V_ooool2o`00013ooooo00?o0000ooooooooool0
>Oooool2o`0007kooooo002;ooooo`;o00007oooool00ol0003oooooooooo`0Uooooo`;o00004Ooo
ool3o`0007kooooo0029ooooo`05onk^k_lb<S;o0000o`000?o^k^h01Oooool2ob4Q8@Cooooo1Ol0
0004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Uooooo`;o0000
4Oooool2o`0007oooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo
00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool01Oooool2o`000;;ooooo0029ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol00005ooooo`;o00003_ooool2o`0002Go
oooo0_l0001kooooo`00ROooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^
k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01Gooooo0_l0000Uooooo`;o
0000Noooool0083ooooo0_l00007ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOo
IVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Foooo
o`;o0000XOooool0083ooooo0_l00007ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02oooool2o`00
00Wooooo0_l0000Pooooo`;o0000Ooooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00_ooooo0_l0000[ooooo`;o0000Ooooool0083ooooo0_l00007ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02_ooool2o`000004oa0@4?l0003o8B4Qolc<c0Cooooo1?l00006ooooo`?o0000^Ooo
ool0083ooooo0_l0000Fooooo`;o00004_ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo
00[ooooo0_l00009ooooo`;o00008?ooool2o`00083ooooo0021ooooo`;o0000:Oooool00ol0003o
ooooooooo`0:ooooo`;o00002Oooool2o`00023ooooo0_l00020ooooo`00POooool2o`0002Cooooo
0_l00003ooooo`?o0000=Oooool3o`000003ooooool0003o000007kooooo002Jooooo`;o00002ooo
ool2o`0000?ooooo00?o0000ooooooooool08_ooool2o`00017ooooo1_l0001nooooo`00V_ooool2
o`00013ooooo00?o0000ooooooooool08_ooool2o`0001?ooooo0ol0001oooooo`00[?ooool00ol0
003oooooooooo`0hooooo`;o0000Ooooool009[ooooo0_l0000@ooooo`03o`000?oooooooooo0;Wo
oooo002Fooooo`;o00000_ooool2o`0000oooooo0_l0000Dooooo`;o00008oooool2o`00083ooooo
002Fooooo`;o00004oooool2o`0000_ooooo0_l00007ooooo`;o00008oooool2o`00083ooooo002F
ooooo`;o00005?ooool00ol0003oooooooooo`09ooooo`;o0000[_ooool0087ooooo0_l0000Yoooo
o`?o0000^Oooool0087ooooo0_l0000Yooooo`03o`000?oooooooooo01oooooo0_l0000Booooo`;o
0000Q?ooool00:cooooo00?o0000ooooooooool01_ooool2o`0001Oooooo0_l0000Booooo`;o0000
Q?ooool00:cooooo00?o0000ooooooooool01_ooool2o`0000Sooooo0_l0000<ooooo`?o0000V?oo
ool008kooooo0_l0000Looooo`04o`000?oooooo0000o`0000Gooooo0_l00008ooooo`;o00003?oo
ool3o`0009Sooooo002>ooooo`;o00007?ooool01?l0003oooooo`000?l00005ooooo`;o0000/Ooo
ool009?ooooo0_l0000:ooooo`;o00002oooool00ol0003oooooooooo`1Aooooo`;o0000I_ooool0
09?ooooo0_l0000:ooooo`;o00002oooool00ol0003oooooooooo`1Aooooo`;o0000I_ooool00:co
oooo0ol0000@ooooo`;o0000Yoooool008;ooooo0_l0000Aooooo`;o00000oooool2o`00013ooooo
00?o0000ooooooooool03_ooool4o`000:Oooooo0022ooooo`;o00004Oooool2o`0000?ooooo0_l0
000?ooooo`;o00004?ooool2o`0002;ooooo0_l00025ooooo`00P_ooool2o`0001Kooooo0_l0000?
ooooo`;o0000<oooool3o`0008Gooooo002@ooooo`;o00006_ooool00ol0003oooooooooo`0aoooo
o`;o0000Q_ooool0093ooooo0_l0000Jooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo00;ooooo0ol0002dooooo`00R_ooool2o`00013ooooo0_l0000>ooooo`04o`000?oo
ooooooooooooo`Co0000]?ooool008[ooooo0_l00005ooooo`;o00002Oooool2o`0000kooooo0ol0
00000ooooooo0000o`00001;ooooo`;o0000JOooool008?ooooo0_l00005ooooo`;o00001Oooool2
o`0001Wooooo00?o0000ooooooooool03Oooool2o`0003oooooo0_l0001Yooooo`00Poooool2o`00
02Oooooo00?o0000ooooooooool03Oooool2o`0001oooooo0_l00029ooooo`00TOooool2o`0001Wo
oooo00?o0000ooooooooool0;_ooool2o`0008Wooooo002Aooooo`;o00004?ooool2o`000003oooo
ool0003o000000Cooooo00?o0000ooooooooool06_ooool2o`0009gooooo002Qooooo`Co000000?o
ooooo`000?l000001?ooool00ol0003oooooooooo`0Gooooo`;o000000?oooooo`000?l000004_oo
ool2o`0008Wooooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1?l0
00000olb<S;ogMgMooooo`04ooooo`03o`000?oooooooooo01Oooooo0ol0000Booooo`Co0000ROoo
ool008Cooooo0_l00006ooooo`;o00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool02Oooool2o`0000gooooo0_l0
000Booooo`;o00007?ooool2o`0006gooooo0024ooooo`;o00001_ooool2o`0000?ooooo00Go410@
oooooooooooooooooa0@4003ooooo`;o00002oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Wooooo0_l0000oooooo`;o0000KOooool0097ooooo00Go0000ooooooooooooooooo`00
0003ooooo`;o00002_ooool00omgMgOo<S8booooo`04ooooo`?o0000^Oooool0097ooooo00Go0000
ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`2iooooo`00TOooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool0
1oooool2o`000;[ooooo002Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooo
ooooo`07ooooo`;o00006?ooool2o`000:3ooooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool4o`0000Kooooo00?o0000ooooooooool01oooool2o`0000kooooo0_l0000?ooooo`;o0000
Soooool009gooooo0_l0000<ooooo`;o00002Oooool2o`0001oooooo0_l0002?ooooo`00WOooool2
o`0000cooooo0_l0000Eooooo`?o0000Xoooool008Gooooo0_l0000Hooooo`;o00002oooool00ol0
003oooooooooo`0Cooooo`?o00005?ooool2o`0001_ooooo0_l0001`ooooo`00QOooool2o`0001So
oooo0_l0000;ooooo`?o00001?ooool2o`0002?ooooo0ol0000Kooooo`;o0000L?ooool008Gooooo
0_l0000Gooooo`;o00001_ooool2o`0000Cooooo00?o0000ooooooooool01?ooool2o`0002?ooooo
0_l0002>ooooo`00QOooool2o`0001Oooooo0_l00003ooooo`;o000000?oooooo`000?l000001?oo
ool00ol0003oooooooooo`0Yooooo`;o0000S_ooool00:?ooooo0_l00007ooooo`03o`000?oooooo
oooo02Wooooo0_l0002>ooooo`00U_ooool2o`0001Cooooo00?o0000ooooooooool0^Oooool009Ko
oooo0_l0000Dooooo`03o`000?oooooooooo0;Wooooo002Fooooo`;o00005?ooool00ol0003ooooo
ooooo`02o`0002Cooooo0_l0002Aooooo`00V?ooool2o`0001;ooooo00?o0000ooooooooool00_l0
000<ooooo`;o00005?ooool4o`00097ooooo002Hooooo`;o00004_ooool3o`0000kooooo0_l0000D
ooooo`;o0000Toooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool08_ooool2o`0009Gooooo0027ooooo`;o00008oooool00ol0003oooooooooo`0Rooooo`;o0000
UOooool008Oooooo0_l0000Sooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o00002oooool2
o`000:cooooo002@ooooo`;o00006?ooool5o`0000_ooooo0_l0002/ooooo`00T?ooool2o`0001So
oooo1?l0002jooooo`00[?ooool3o`0001kooooo0_l0000Nooooo`;o0000NOooool00:Wooooo0_l0
00000ooooooo0000ooooo`0Oooooo`;o00007_ooool2o`0007Wooooo002Mooooo`;o00001_ooool6
o`000003ooooool0003ooooo027ooooo0_l0002Gooooo`00Toooool2o`0000Sooooo0_l00006oooo
o`Co00000oooool00ol0003oooooooooo`08ooooo`?o00005Oooool2o`0009Oooooo002Cooooo`;o
00005oooool00ol0003oooooooooo`08ooooo`?o0000[_ooool00:cooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool01oooool2
o`000;3ooooo002/ooooo`03o`000?oooooooooo00Oooooo0_l0000Cooooo`;o0000Voooool00:co
oooo0ol0000Jooooo`Co0000Voooool009Cooooo0_l0000Fooooo`03o`000?oooooooooo01[ooooo
0_l0002Mooooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool06Oooool2o`0009kooooo002:
ooooo`?o00007oooool00ol0003oooooooooo`0Iooooo`;o00007?ooool2o`00083ooooo002:oooo
o`?o00007oooool01?l0003oooooooooooooool2o`0003Cooooo0_l00020ooooo`00ROooool01Oo^
k^ko<S8bo`000?l0003ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`04o`000?ooooooooooooooo`;o00005Oooool2o`0009oooooo
0029ooooo`05ogMgMonHV9So0000o`000?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool0
1oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00;o00005_ooool2o`0009oooooo
0029ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_l0002gooooo`00ROooool01Ol0003ooooooooo
oooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`Go0000
]oooool008Wooooo00?o0000ooooooooool00_l0000:ooooo`;o00000_ooool00omEEEGoc<c<oooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool01?l0003oooooo`000?l0000Aooooo`?o
0000Y?ooool008Wooooo00?o410@ooooooooool00_l0000:ooooo`;o00000_ooool00onYZJWoMgMg
ooooo`03ooooo`03o`000?oooooooooo00Kooooo0_l0000Dooooo`?o0000Y?ooool008Wooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0:ooooo`;o00000oooool00olb<S;oooooooooo`02ooooo`03o`00
0?oooooooooo00Kooooo0_l0000Gooooo`;o0000X_ooool008Wooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool04_ooool2o`000003oooo
ool0003o00000:;ooooo002Xooooo`;o00000_ooool00ol0003oooooooooo`0Aooooo`?o0000YOoo
ool008kooooo0_l0000:ooooo`;o00003?ooool2o`000003ooooool0003o000001?ooooo0_l0002V
ooooo`00S_ooool2o`0000[ooooo0_l00009ooooo`;o00001?ooool2o`0001?ooooo0_l0002Voooo
o`00S_ooool2o`00017ooooo0ol000001?oooooo0000o`000?l00004ooooo`?o00004Oooool2o`00
0:Kooooo002>ooooo`;o00004Oooool3o`0000;ooooo0_l00004ooooo`03o`000?oooooooooo0;Wo
oooo002Sooooo`;o00001oooool00ol0003oooooooooo`2iooooo`00Xoooool2o`0000Oooooo00?o
0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool02Oooool2o`000:kooooo002/ooooo`03o`000?oooooooooo00Wooooo0_l0002^ooooo`00
[?ooool00ol0003oooooooooo`0;ooooo`;o0000[?ooool00:cooooo0ol0000;ooooo`;o0000[?oo
ool00:cooooo00?o0000ooooooooool02oooool2o`000:cooooo002/ooooo`03o`000?oooooooooo
00_ooooo0_l0002/ooooo`00TOooool2o`0001Wooooo00?o0000ooooooooool01_ooool2o`000;7o
oooo002Aooooo`;o00006Oooool00ol0003oooooooooo`06ooooo`;o0000/Oooool00:cooooo00?o
0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool009Kooooo0_l0000Doooo
o`03o`000?oooooooooo0;Wooooo002Fooooo`;o00005?ooool00ol0003oooooooooo`2iooooo`00
[?ooool3o`0000Cooooo0_l0002cooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o0000/ooo
ool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool0^Oooool009cooooo0_l0000>ooooo`;o0000^_ooool009Sooooo1_l0
000>ooooo`;o0000^_ooool009Sooooo1?l0000@ooooo`03o`000?oooooooooo0;Wooooo002Ioooo
o`;o000000?oooooo`000?l000003_ooool3o`000;Wooooo002Iooooo`;o000000?oooooo`000?l0
00003_ooool2o`000;[ooooo002Pooooo`;o00001_ooool2o`0000;ooooo00?o0000ooooooooool0
^Oooool009oooooo0ol00006ooooo`;o00000_ooool00ol0003oooooooooo`2iooooo`00Woooool3
o`0000[ooooo00?o0000ooooooooool0^Oooool009oooooo0ol00003ooooo`?o00001?ooool00ol0
003oooooooooo`2iooooo`00X_ooool6o`0000Cooooo00?o0000ooooooooool0^Oooool00:Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00Y?ooool00ol0003ooooooooo
o`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo00?o0000oooo
ooooool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0
`Oooool00:;ooooo00?oEEEEofIVI_l00000`oooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00:[ooooo00Co410@o`000?l0003o0000^_ooool00:_ooooo00?o
0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00Ko0000ogMg
Mol0003o0000oeEEEOo^k^jgooooo`00Zoooool01_l0003oEEEEonk^k_ooooooMgMgoeEEEKOooooo
002[ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0]Oooool00:_ooooo00?o0000
onk^k_ooool00_ooool00ol0003oooooooooo`2eooooo`00Zoooool01_l0003oEEEEonk^k_oooooo
MgMgofIVI[Oooooo002Zooooo`03oa0@4?l0003oMgMg00;o000000?oIVIVonk^k_ooool0]_ooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.6278 .63408 Mdot
.56492 .80235 Mdot
.45901 .61582 Mdot
.41845 .49979 Mdot
.50913 .21909 Mdot
.62067 .37948 Mdot
.4399 .57387 Mdot
.64169 .79707 Mdot
.67951 .67722 Mdot
.56449 .48822 Mdot
.54147 .66531 Mdot
.57859 .88873 Mdot
.41221 .8214 Mdot
.56471 .56609 Mdot
.51991 .95233 Mdot
.48179 .2373 Mdot
.39808 .58176 Mdot
.40588 .79556 Mdot
.40933 .57753 Mdot
.56395 .14436 Mdot
.38563 .64004 Mdot
.48467 .9111 Mdot
.42946 .85804 Mdot
.38965 .69307 Mdot
.44211 .97173 Mdot
.59997 .52781 Mdot
.49456 .77261 Mdot
.40947 .56402 Mdot
.59626 .19246 Mdot
.54241 .8351 Mdot
.38586 .36215 Mdot
.68853 .65739 Mdot
.64324 .78219 Mdot
.43379 .19309 Mdot
.49425 .14053 Mdot
.54812 .13854 Mdot
.69477 .43452 Mdot
.42792 .70583 Mdot
.63682 .27344 Mdot
.57884 .89323 Mdot
.47249 .99829 Mdot
.45996 .14145 Mdot
.5768 .27254 Mdot
.63253 .63401 Mdot
.64252 .55924 Mdot
.57256 .35425 Mdot
.55768 .58889 Mdot
.70604 .57124 Mdot
.5553 .72775 Mdot
.60649 .2169 Mdot
.70414 .57421 Mdot
.65646 .30518 Mdot
.75918 .34924 Mdot
.55053 .22726 Mdot
.54305 .20748 Mdot
.66185 .73306 Mdot
.62899 .81659 Mdot
.40267 .64687 Mdot
.70571 .50706 Mdot
.6437 .53662 Mdot
.58283 .39533 Mdot
.37575 .24392 Mdot
.64544 .29625 Mdot
.54244 .546 Mdot
.61649 .81696 Mdot
.68084 .68732 Mdot
.56313 .48272 Mdot
.47775 .2407 Mdot
.43511 .73806 Mdot
.3796 .53409 Mdot
.4007 .64381 Mdot
.46951 .31447 Mdot
.56315 .52215 Mdot
.55311 .40622 Mdot
.6454 .29632 Mdot
.4611 .36729 Mdot
.75941 .35009 Mdot
.59313 .50364 Mdot
.64311 .27563 Mdot
.53873 .74803 Mdot
.44748 .08921 Mdot
.54191 .83382 Mdot
.42149 .56939 Mdot
.46348 .13698 Mdot
.66248 .75119 Mdot
.47456 .23073 Mdot
.51693 .2322 Mdot
.5569 .32412 Mdot
.42581 .77873 Mdot
.48565 .24491 Mdot
.42899 .94853 Mdot
.64842 .15585 Mdot
.5218 .66154 Mdot
.55921 .32034 Mdot
.52859 .63324 Mdot
.61644 .1121 Mdot
.5654 .55678 Mdot
.69576 .60539 Mdot
.76437 .36198 Mdot
.43373 .80689 Mdot
.61602 .6752 Mdot
.46815 .85261 Mdot
.56558 .90208 Mdot
.62107 .67316 Mdot
.39893 .23662 Mdot
.44671 .16351 Mdot
.39412 .49919 Mdot
.40692 .46127 Mdot
.52123 .6638 Mdot
.37968 .47555 Mdot
.56697 .51901 Mdot
.42078 .5767 Mdot
.68793 .6561 Mdot
.53328 .11081 Mdot
.79451 .5464 Mdot
.46831 .70882 Mdot
.59086 .44442 Mdot
.68686 .68573 Mdot
.69025 .66786 Mdot
.69261 .45116 Mdot
.40836 .80396 Mdot
.36083 .5057 Mdot
.38862 .65448 Mdot
.59703 .19133 Mdot
.37936 .49503 Mdot
.42388 .39007 Mdot
.55836 .14421 Mdot
.57937 .07039 Mdot
.56811 .78255 Mdot
.42969 .43208 Mdot
.44769 .89605 Mdot
.59814 .72298 Mdot
.54266 .93354 Mdot
.62192 .3752 Mdot
.59531 .31179 Mdot
.62331 .23408 Mdot
.68724 .37922 Mdot
.5838 .17749 Mdot
.56281 .51825 Mdot
.61549 .82769 Mdot
.52168 .95237 Mdot
.46528 .74718 Mdot
.42353 .69373 Mdot
.39841 .58986 Mdot
.54706 .12445 Mdot
.67299 .72562 Mdot
.78804 .62305 Mdot
.42961 .27723 Mdot
.56469 .34378 Mdot
.37483 .74884 Mdot
.48628 .85012 Mdot
.48288 .79325 Mdot
.39019 .70062 Mdot
.45692 .3324 Mdot
.63568 .48334 Mdot
.68051 .36871 Mdot
.64869 .2974 Mdot
.68017 .69827 Mdot
.69484 .44465 Mdot
.68207 .37089 Mdot
.5906 .6141 Mdot
.6396 .26513 Mdot
.52205 .96782 Mdot
.51866 .1043 Mdot
.58479 .29747 Mdot
.6117 .68019 Mdot
.6736 .72165 Mdot
.41019 .17871 Mdot
.441 .75431 Mdot
.67655 .345 Mdot
.59308 .20109 Mdot
.48647 .73633 Mdot
.45344 .77581 Mdot
.52946 .26042 Mdot
.43545 .25156 Mdot
.62689 .80611 Mdot
.60643 .10094 Mdot
.63468 .47803 Mdot
.4597 .69406 Mdot
.61293 .22341 Mdot
.66314 .31032 Mdot
.54756 .93241 Mdot
.52916 .32111 Mdot
.46191 .99587 Mdot
.46797 .28212 Mdot
.67668 .67858 Mdot
.5822 .07561 Mdot
.69861 .6303 Mdot
.52708 .96092 Mdot
.58427 .28465 Mdot
.36748 .66437 Mdot
.54464 .12074 Mdot
.54214 .48705 Mdot
.37289 .275 Mdot
.65111 .77585 Mdot
.43851 .97753 Mdot
.55744 .91413 Mdot
.55236 .30544 Mdot
.67493 .18624 Mdot
.40027 .34958 Mdot
.49358 .68313 Mdot
.48886 .69208 Mdot
.48044 .31328 Mdot
.51299 .23011 Mdot
.6927 .21367 Mdot
.60268 .70798 Mdot
.52507 .38334 Mdot
.62864 .41504 Mdot
.4277 .64518 Mdot
.48708 .27972 Mdot
.54206 .66751 Mdot
.45669 .91498 Mdot
.5929 .48606 Mdot
.41275 .16885 Mdot
.52262 .30974 Mdot
.6072 .69266 Mdot
.59056 .46721 Mdot
.51241 .97761 Mdot
.46045 .28611 Mdot
.63906 .54212 Mdot
.59955 .86536 Mdot
.58904 .43002 Mdot
.70178 .54169 Mdot
.39765 .24055 Mdot
.47889 .07078 Mdot
.5127 .29141 Mdot
.46995 .18846 Mdot
.58907 .76093 Mdot
.50035 .71513 Mdot
.51901 .95381 Mdot
.36029 .49408 Mdot
.44728 .26917 Mdot
.50478 .59892 Mdot
.7034 .23738 Mdot
.49923 .82844 Mdot
.5095 .74749 Mdot
.36196 .55478 Mdot
.44163 .753 Mdot
.61517 .69263 Mdot
.40024 .75252 Mdot
.60495 .70651 Mdot
.3794 .21911 Mdot
.603 .32339 Mdot
.43675 .09814 Mdot
.40104 .64695 Mdot
.69404 .64713 Mdot
.52896 .62604 Mdot
.68007 .38208 Mdot
.42356 .75952 Mdot
.40331 .66751 Mdot
.64454 .29097 Mdot
.44151 .98024 Mdot
.46999 .70901 Mdot
.54118 .50635 Mdot
.68651 .412 Mdot
.59516 .56248 Mdot
.45781 .78075 Mdot
.54844 .21085 Mdot
.46868 .35469 Mdot
.62664 .81611 Mdot
.70729 .54024 Mdot
.53149 .7756 Mdot
.51077 .74495 Mdot
.49184 .07542 Mdot
.43083 .57576 Mdot
.48192 .84985 Mdot
.62994 .61461 Mdot
.54991 .62434 Mdot
.61524 .37812 Mdot
.57168 .17104 Mdot
.58267 .62963 Mdot
.54784 .13349 Mdot
.54996 .217 Mdot
.56455 .46976 Mdot
.53619 .75983 Mdot
.67781 .35698 Mdot
.53213 .32647 Mdot
.42616 .2769 Mdot
.70139 .59341 Mdot
.5512 .63966 Mdot
.63449 .45503 Mdot
.62272 .2382 Mdot
.42633 .47024 Mdot
.54632 .38508 Mdot
.69465 .45007 Mdot
.58354 .8788 Mdot
.40714 .44826 Mdot
.43959 .41119 Mdot
.49202 .20318 Mdot
.49545 .06593 Mdot
.57004 .3563 Mdot
.43292 .11699 Mdot
.58524 .08006 Mdot
.70316 .50857 Mdot
.55089 .91596 Mdot
.70044 .52918 Mdot
.47445 .67168 Mdot
.70421 .46519 Mdot
.36989 .3142 Mdot
.46301 .06126 Mdot
.53008 .94037 Mdot
.78071 .6605 Mdot
.55418 .72305 Mdot
.57647 .25945 Mdot
.59864 .72503 Mdot
.69146 .6526 Mdot
.46762 .99456 Mdot
.556 .60376 Mdot
.69926 .59753 Mdot
.59408 .5769 Mdot
.51563 .6041 Mdot
.45007 .90587 Mdot
.39598 .53629 Mdot
.4105 .81013 Mdot
.38209 .79731 Mdot
.45184 .68341 Mdot
.63675 .56879 Mdot
.44984 .1568 Mdot
.60514 .83617 Mdot
.43137 .58838 Mdot
.53668 .94442 Mdot
.36728 .63825 Mdot
.43985 .29583 Mdot
.62163 .36866 Mdot
.46166 .13665 Mdot
.65775 .32432 Mdot
.46409 .18886 Mdot
.51275 .62632 Mdot
.4541 .64474 Mdot
.39514 .54548 Mdot
.6171 .83878 Mdot
.68542 .41623 Mdot
.53259 .61865 Mdot
.47247 .91887 Mdot
.43037 .41825 Mdot
.48358 .31582 Mdot
.58417 .7703 Mdot
.6153 .35899 Mdot
.58524 .29811 Mdot
.58962 .61728 Mdot
.50617 .21931 Mdot
.74535 .31019 Mdot
.58948 .59467 Mdot
.54704 .82195 Mdot
.53988 .56347 Mdot
.64869 .76548 Mdot
.50207 .75813 Mdot
.57859 .17123 Mdot
.50348 .88714 Mdot
.49857 .72621 Mdot
.58354 .42398 Mdot
.5893 .8757 Mdot
.70424 .44998 Mdot
.55441 .14539 Mdot
.56905 .68734 Mdot
.40296 .33138 Mdot
.58332 .18481 Mdot
.49185 .84052 Mdot
.58785 .87707 Mdot
.4433 .08626 Mdot
.54268 .93263 Mdot
.52896 .95331 Mdot
.50498 .36244 Mdot
.51601 .8002 Mdot
.51497 .95924 Mdot
.62966 .81343 Mdot
.50987 .37995 Mdot
.40726 .20064 Mdot
.58266 .61777 Mdot
.62873 .40702 Mdot
.61961 .66329 Mdot
.69222 .62424 Mdot
.61478 .69246 Mdot
.69948 .45511 Mdot
.67608 .38206 Mdot
.43564 .87124 Mdot
.70046 .4243 Mdot
.45047 .89812 Mdot
.46881 .99196 Mdot
.79493 .57117 Mdot
.69554 .47993 Mdot
.63788 .48382 Mdot
.4564 .33776 Mdot
.38855 .81693 Mdot
.43928 .81785 Mdot
.45874 .65538 Mdot
.54766 .93411 Mdot
.37928 .51139 Mdot
.51738 .60753 Mdot
.55801 .43426 Mdot
.59781 .49873 Mdot
.49666 .77261 Mdot
.70606 .58036 Mdot
.39242 .2681 Mdot
.37367 .27148 Mdot
.5425 .93875 Mdot
.40201 .35323 Mdot
.73994 .30563 Mdot
.40417 .3271 Mdot
.42842 .277 Mdot
.43746 .24044 Mdot
.51211 .46725 Mdot
.61733 .83604 Mdot
.58041 .88576 Mdot
.49885 .76551 Mdot
.4907 .73644 Mdot
.52928 .71173 Mdot
.49975 .25302 Mdot
.39975 .87974 Mdot
.54931 .29357 Mdot
.50762 .0892 Mdot
.44461 .70966 Mdot
.47433 .795 Mdot
.42785 .53464 Mdot
.5361 .26749 Mdot
.423 .22938 Mdot
.50379 .76351 Mdot
.52975 .40293 Mdot
.36421 .62676 Mdot
.61973 .82147 Mdot
.49956 .55829 Mdot
.50542 .15413 Mdot
.39415 .49446 Mdot
.63466 .53783 Mdot
.57714 .64192 Mdot
.45144 .77482 Mdot
.39181 .83672 Mdot
.62966 .12445 Mdot
.60237 .72225 Mdot
.79256 .49316 Mdot
.63073 .64603 Mdot
.53474 .42225 Mdot
.66412 .71379 Mdot
.50372 .97147 Mdot
.531 .69334 Mdot
.4949 .89618 Mdot
.74956 .32158 Mdot
.48021 .7458 Mdot
.52381 .56365 Mdot
.45298 .21091 Mdot
.4811 .06886 Mdot
.5566 .70847 Mdot
.66342 .17283 Mdot
.48019 .27828 Mdot
.53032 .19589 Mdot
.44498 .15944 Mdot
.53925 .58341 Mdot
.44908 .67337 Mdot
.54446 .36511 Mdot
.63894 .80113 Mdot
.44428 .66372 Mdot
.63273 .25365 Mdot
.58268 .76902 Mdot
.63909 .57009 Mdot
.55135 .13615 Mdot
.41732 .16258 Mdot
.39576 .45528 Mdot
.56391 .04994 Mdot
.55978 .44454 Mdot
.61462 .84307 Mdot
.44867 .98986 Mdot
.54667 .63501 Mdot
.70443 .45903 Mdot
.57953 .63703 Mdot
.40074 .60965 Mdot
.57414 .16432 Mdot
.61815 .67106 Mdot
.40706 .50576 Mdot
.58391 .42392 Mdot
.42632 .21449 Mdot
.36563 .33777 Mdot
.5983 .3254 Mdot
.45255 .39171 Mdot
.57311 .26933 Mdot
.54034 .74692 Mdot
.49753 .33683 Mdot
.45633 .25713 Mdot
.54377 .21503 Mdot
.58683 .28832 Mdot
.48165 .70412 Mdot
.59526 .54665 Mdot
.6794 .6914 Mdot
.49723 .19822 Mdot
.6325 .59662 Mdot
.44135 .76163 Mdot
.40858 .49731 Mdot
.52179 .44011 Mdot
.79652 .52482 Mdot
.52422 .46613 Mdot
.5748 .78631 Mdot
.69744 .56384 Mdot
.5199 .10455 Mdot
.42759 .71001 Mdot
.59614 .19611 Mdot
.55901 .9169 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool04_ooool2o`000:Gooooo002/ooooo`?o00004_ooool2o`000:Gooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Oooooo`;o00002oooool00ol0
003oooooooooo`2iooooo`00Woooool2o`0000_ooooo00?o0000ooooooooool0^Oooool00:[ooooo
0ol0002kooooo`00YOooool2o`0000?ooooo0ol0000Iooooo`;o0000X?ooool00:Gooooo0_l00005
ooooo`03o`000?oooooooooo01Oooooo0_l0002Pooooo`00ZOooool2o`000004ooooool0003o0000
o`0001Sooooo0_l0002Oooooo`00ZOooool2o`000003ooooool0003ooooo01Wooooo0ol0002Noooo
o`00[?ooool00ol0003oooooooooo`0Iooooo`;o0000W_ooool009Wooooo0_l0000Aooooo`03o`00
0?oooooooooo0;Wooooo002Iooooo`?o00004?ooool01?l0003oooooo`000?l0002hooooo`00V_oo
ool2o`00013ooooo00Co0000ooooool0003o0000^?ooool00:cooooo00?o0000ooooooooool0^Ooo
ool009Oooooo0_l0000Cooooo`03o`000?oooooooooo0;Wooooo002Gooooo`;o00004oooool3o`00
023ooooo0_l0002Gooooo`00[?ooool00ol0003oooooooooo`03ooooo`;o00006oooool2o`0009Oo
oooo002/ooooo`03o`000?oooooooooo00?ooooo0_l0002dooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`08ooooo`;o00006Oooool2o`0009Cooooo002/oooo
o`03o`000?oooooooooo00Sooooo0_l0000Iooooo`;o0000U?ooool008Wooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q0_l00004ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@;o00001?ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool02oooool2o`000:cooooo0021ooooo`Ko00000_ooool01Ol@
413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03
ooooo`?o00002oooool3o`0001Wooooo0_l0002@ooooo`00ROooool01Ol0003ooooooooooooooooo
000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo00cooooo0_l0000Iooooo`;o0000T?ooool008Wooooo00Go0000ooooooooooooooooo`00000>
ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oo
oooooooo0;Wooooo0029ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgoooo
o`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool2o`000:_ooooo0029
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01_l@413ooooooooooooooooo<S8booooo`Co
00002Oooool00ol0003oooooooooo`0<ooooo`Co0000ZOooool008Wooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`Go000000?oooooo`000?l000001Ol00004ooooo`?o00003_ooool4o`000:Wo
oooo002Nooooo`;o00002_ooool3o`0000kooooo0_l0002[ooooo`00W_ooool2o`0000cooooo00?o
0000ooooooooool03oooool5o`000:Gooooo002/ooooo`03o`000?oooooooooo00oooooo1Ol0002U
ooooo`00[?ooool3o`000;Wooooo002/ooooo`?o0000;_ooool2o`0008Wooooo002Kooooo`;o0000
3oooool3o`0002kooooo0_l00029ooooo`00VOooool4o`0000oooooo00?o0000ooooooooool0^Ooo
ool0093ooooo0_l00007ooooo`?o00004?ooool00ol0003oooooooooo`0Eooooo`;o0000X_ooool0
093ooooo0_l00008ooooo`;o00004?ooool00ol0003oooooooooo`0Eooooo`;o0000X_ooool008oo
oooo0_l0000Kooooo`03o`000?oooooooooo01Cooooo0_l000000ooooooo0000o`00002Pooooo`00
Soooool2o`0001_ooooo00?o0000ooooooooool05?ooool2o`000003ooooool0003o000001[ooooo
0_l00024ooooo`00[?ooool3o`0003?ooooo0_l00024ooooo`00S_ooool2o`0001cooooo00?o0000
ooooooooool06?ooool2o`0009oooooo002>ooooo`;o00007?ooool00ol0003oooooooooo`0Hoooo
o`;o0000Woooool00:cooooo00?o0000ooooooooool06?ooool2o`0001cooooo0_l00021ooooo`00
X?ooool4o`0000Sooooo00?o0000ooooooooool06?ooool2o`0001cooooo0_l00021ooooo`00X?oo
ool4o`0000Sooooo00?o0000ooooooooool07?ooool3o`0009[ooooo002Fooooo`;o00005?ooool0
0ol0003oooooooooo`0Looooo`?o0000V_ooool009Kooooo0_l0000Cooooo`;o00002Oooool2o`00
01?ooooo0_l0002Kooooo`00SOooool2o`0001cooooo1?l00007ooooo`;o00004_ooool3o`0009_o
oooo002=ooooo`;o00006_ooool2o`000003ooooool0003ooooo01cooooo0_l0002Looooo`00ZOoo
ool2o`000003ooooool0003ooooo00cooooo0_l0002/ooooo`00[?ooool00ol0003oooooooooo`0;
ooooo`;o0000[?ooool009cooooo0_l0000>ooooo`03o`000?oooooooooo00gooooo0_l0000]oooo
o`;o0000Noooool009?ooooo0_l00007ooooo`;o00003_ooool00ol0003oooooooooo`0;ooooo`Co
0000;Oooool2o`0007_ooooo0024ooooo`;o00003Oooool2o`0001Oooooo00?o0000ooooool00000
0_l00009ooooo`Co00004Oooool2o`0009Oooooo0024ooooo`;o00009_ooool00ol0003oooooo`00
0002o`0000_ooooo0_l0000Aooooo`;o0000Uoooool00:cooooo0ol0000Rooooo`;o0000UOooool0
0:cooooo00?o0000ooooooooool03Oooool2o`0001?ooooo0_l0002Eooooo`00T_ooool2o`0000oo
oooo0_l00007ooooo`04o`000?ooooooooooooooo`;o00002_ooool2o`000:[ooooo002Booooo`;o
00003oooool2o`0000Oooooo00Co0000oooooooooooooooo0ol0000Qooooo`;o0000T_ooool008[o
oooo0_l0000Jooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`;o00008Oooool2o`0001Wo
oooo0_l0001gooooo`00R_ooool2o`0000_ooooo0_l0000;ooooo`Co00001?ooool00ol0003ooooo
ooooo`0Uooooo`;o00006Oooool2o`0007Oooooo0023ooooo`;o00001Oooool2o`0000Gooooo00Ko
k^k^oc8b<_l0003o<S8bonk^k_ooool2o`0000;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000o`00
0?oMgMd01Oooool00ol0003oooooooooo`0Uooooo`;o0000T_ooool008?ooooo0_l0000<ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00CoMgMgoc8b<_l0003o00000oooool0
0ol0003oooooooooo`2iooooo`00ROooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@
ooooo`?o00000oooool00ol0003oooooooooo`2iooooo`00TOooool01?l0003oooooooooooooool3
o`0000gooooo00?oMgMgoc8b<_ooool00oooool4o`000;Wooooo002Aooooo`04o`000?oooooooooo
ooooo`?o00002_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo0_l0000Zooooo`;o0000Sooo
ool0097ooooo00Go410@oooooooooooooooooa0@4007ooooo`;o00000oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo02Sooooo0_l0002?ooooo`00TOooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Oooooo0_l00003ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool2o`0000kooooo0_l0002Qooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0
0006ooooo`03o`000?oooooooooo00Kooooo0_l0000>ooooo`;o00004oooool2o`0008cooooo0028
ooooo`;o00008_ooool00ol0003oooooooooo`08ooooo`;o00008Oooool2o`0008cooooo0028oooo
o`;o00004?ooool2o`00013ooooo00?o0000ooooooooool02?ooool2o`0000_ooooo0_l0002Roooo
o`00P_ooool2o`0001Kooooo0_l0000@ooooo`03o`000?oooooooooo01Gooooo0ol0000Booooo`;o
0000SOooool008;ooooo0_l0000?ooooo`?o00005_ooool3o`0001Kooooo0_l0000Booooo`Co0000
Roooool008;ooooo0_l0000?ooooo`?o00003oooool4o`0000?ooooo00?o0000ooooooooool0;?oo
ool2o`0008_ooooo002Qooooo`;o00000_ooool4o`0000?ooooo00?o0000ooooooooool0^Oooool0
09oooooo1?l00009ooooo`03o`000?oooooooooo01Sooooo0_l0002Oooooo`00Woooool2o`0000_o
oooo00?o0000ooooooooool06?ooool3o`0009kooooo002/ooooo`04o`000?ooooooooooooooo`;o
00005_ooool2o`00017ooooo0_l0002;ooooo`00[?ooool01?l0003oooooooooooooool2o`0000[o
oooo0_l0000Mooooo`;o0000Roooool009Sooooo0_l0000Booooo`03o`000?oooooooooo00gooooo
0_l0000:ooooo`;o00004_ooool3o`0008Wooooo002Hooooo`;o00004_ooool3o`0001Wooooo0_l0
000Booooo`?o0000ROooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool03_ooool2o`00023ooooo0_l0000Jooooo`;o0000Joooool00:cooooo00?o0000oooooooo
ool01?ooool2o`0000Sooooo0_l0000Pooooo`Co00006?ooool4o`0006Wooooo002Uooooo`;o0000
1Oooool00ol0003oooooooooo`04ooooo`;o00005_ooool2o`0001Cooooo0_l0000Jooooo`;o0000
JOooool0087ooooo0_l0000Nooooo`;o00000_ooool3o`0000Cooooo00?o0000ooooooooool07?oo
ool2o`0009_ooooo0021ooooo`;o00007_ooool2o`0000?ooooo0_l00004ooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`03o`000?oooooooooo00Kooooo0_l00008ooooo`;o0000?Oooool2o`00
06Sooooo002/ooooo`?o00001_ooool2o`0000Oooooo0ol0000;ooooo`Co00004?ooool2o`0001co
oooo0_l0001Xooooo`00S?ooool2o`0001kooooo00?o0000ooooooooool01oooool2o`0000Kooooo
0_l0000<ooooo`Co00004?ooool2o`0008Kooooo002<ooooo`;o00007_ooool00ol0003ooooooooo
o`07ooooo`;o0000/?ooool008cooooo0_l0000?ooooo`;o00003Oooool00ol0003oooooooooo`2i
ooooo`00Ooooool2o`0001cooooo0_l0000<ooooo`;o0000^oooool007oooooo0_l0000Looooo`;o
00003?ooool2o`000;_ooooo002/ooooo`03o`000?oooooooooo01;ooooo0_l0002Uooooo`00[?oo
ool00ol0003oooooooooo`0Booooo`;o00008oooool2o`00083ooooo002;ooooo`;o00007oooool0
0ol0003oooooooooo`0gooooo`;o00006Oooool2o`0006Gooooo002;ooooo`;o00007oooool3o`00
05;ooooo0_l0001Uooooo`00Roooool2o`0001Cooooo0_l00009ooooo`03o`000?oooooooooo01Go
oooo0_l0000kooooo`;o0000IOooool008_ooooo0_l0000Dooooo`;o00002Oooool00ol0003ooooo
ooooo`0Dooooo`?o00003?ooool2o`0001;ooooo0_l00020ooooo`00Q_ooool2o`0002Cooooo00?o
0000ooooooooool05?ooool2o`0000gooooo0_l0000Booooo`;o00006oooool2o`0006?ooooo0026
ooooo`;o00009?ooool3o`0000_ooooo0_l00017ooooo`;o0000Hoooool008Wooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`000005ooooool0003o0000oooooom4A4@00_l0
00000olb<S;ogMgMooooo`04ooooo`?o00002oooool2o`000:cooooo0029ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00KoV9RHob4Q8Oo^k^koooooodA4A?ooool2o`0000Co
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Uooooo`;o00004Oooool3o`0007ko
oooo0021ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^
k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Gooooo0_l0000Aooooo`?o
0000O_ooool008Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo00?oMgMgoc8b<_ooool01?ooool3o`0002Gooooo0_l0002Booooo`00ROooool01Ol0003ooooo
oooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool00_l0000Qooooo`Co00004oooool2o`0007gooooo0029ooooo`05
oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool00_l00003ooooo`;o00007?ooool3o`00017ooooo1Ol0001moooo
o`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool2o`0000Gooooo0_l0000Y
ooooo`?o0000Ooooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool03?ooool2o`000:_ooooo002B
ooooo`;o00002?ooool2o`0000kooooo00?o0000ooooooooool0^Oooool009;ooooo0_l00008oooo
o`;o00003_ooool00ol0003oooooooooo`0Hooooo`;o0000Woooool00:cooooo00?o0000oooooooo
ool06?ooool2o`0009oooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool01_oo
ool2o`000;7ooooo002/ooooo`03o`000?oooooooooo00Kooooo0_l00006ooooo`;o00005oooool2
o`00093ooooo002/ooooo`03o`000?oooooooooo00kooooo0_l0000Gooooo`;o0000T?ooool009So
oooo0_l0000Booooo`03o`000?oooooooooo03[ooooo0_l0001mooooo`00V?ooool2o`0001;ooooo
00?o0000ooooooooool09oooool2o`00017ooooo0_l0001mooooo`00UOooool2o`0001Gooooo00?o
0000ooooooooool09oooool2o`00017ooooo0_l0001mooooo`00UOooool2o`0001Gooooo00?o0000
ooooooooool02?ooool2o`000:oooooo002/ooooo`?o00002?ooool2o`0000kooooo0_l0000Uoooo
o`;o0000N?ooool00:cooooo00?o0000ooooooooool06?ooool2o`0002Gooooo0_l0001hooooo`00
[?ooool00ol0003oooooooooo`0Jooooo`;o0000WOooool009Cooooo0_l0000Fooooo`03o`000?oo
oooooooo013ooooo0_l00008ooooo`;o00008Oooool2o`0007[ooooo002Dooooo`;o00005_ooool0
0ol0003oooooooooo`0@ooooo`;o0000:oooool2o`0007[ooooo002/ooooo`03o`000?oooooooooo
00Cooooo0_l0002cooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o0000/oooool00:cooooo
00?o0000ooooooooool04?ooool2o`0000Wooooo0_l0000Pooooo`;o0000N_ooool008gooooo0_l0
000Mooooo`03o`000?oooooooooo013ooooo0_l00009ooooo`;o00008?ooool2o`000003ooooool0
003o000007Oooooo002=ooooo`;o00007Oooool3o`0003cooooo0ol000000ooooooo0000o`00001g
ooooo`00ROooool2o`00027ooooo00?o0000ooooooooool0:Oooool2o`00017ooooo1?l0001ioooo
o`00ROooool2o`00027ooooo00?o0000ooooooooool0:Oooool2o`0001?ooooo1?l0001gooooo`00
2Oooool4o`000003oa0@4?oooooooooo01Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd03ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Oo00000_ooool01Om4A4Co0000
o`000?lb<S;ogMgM01Kooooo00?o0000ooooooooool06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00[ooooo0_l00003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8b
omgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_oo
ool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1?l000000ol@413oooooooooo`0Boooo
o`002oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00_l00005ooooo`03ogMg
Molb<S;ooooo01Gooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`0>oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool06Oooool00ol0003oooooooooo`0Dooooo`001_l00005ooooo`03o`000?oooooo
oooo013ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEoooo
o`08ooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@4100
4?ooool00ol0003oooooooooo`05ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00co
oooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`0Dooooo`04o`000?oooooooooooooo
o`;o00000_ooool2o`00017ooooo00Go410@ooooool0003o0000oa0@400<ooooo`03oiRHV?lQ8B7o
k^k^00Wooooo00?o0000ooooooooool02?ooool2o`0000?ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00gooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVY
ZOmEEEGooooo00Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Dooooo`002ooo
ool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooo
ooooo`06ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000?ooooo`03
ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^
00Kooooo0_l000000olb<S;oooooooooo`0Dooooo`04o`000?ooooooooooooooo`;o00000_ooool2
o`0000_ooooo0_l00004ooooo`03o`000?oooooo000000;o00003Oooool00onHV9So8B4Qonk^kP07
ooooo`03ogMgMolb<S;ooooo00Wooooo0_l00003ooooo`05o`000?ooooooooooooooool000003ooo
ool00omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooo
ooooo`06ooooo`03ogMgMolb<S;ooooo01Wooooo00?o0000ooooooooool05?ooool000_ooooo00?o
0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool0
0oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000<oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?l0003oc<c<01Kooooo00?o0000ooooooooool0
4_ooool2o`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003?ooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEE
EOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Jooooo`03o`000?oooooooooo01Co
oooo000;ooooo`03o`000?oooooooooo01Sooooo00Go410@oooooooooooooooooa0@400>ooooo`03
ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00Oooooo0_l00006
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06?ooool3o`0001Sooooo00Go410@
oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04Ooo
ool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04Oooool01Ol@413ooooo
oooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`0Aoooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01oooool2o`0000;ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo0ol000000onHV9So410@ooooo`03ooooo`03o`000?oooooooooo00Wooooo0_l00006ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Dooooo`002Oooool00omEEEGoIVIVo`00000Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0001Oooooo00?o0000ooooooooool04Oooool2o`0000Gooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l0003o0000ob4Q8Oo<c<`01?ooool4o`0000Sooooo0_l0
0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`Go00001?ooool4o`0001Wooooo00?oEEEEofIVI_l000005_ooool00:cooooo
00?o0000ooooooooool04Oooool2o`0000Sooooo0_l0000<ooooo`?o0000SOooool00:cooooo00?o
0000ooooooooool02_ooool2o`0000Kooooo0_l00007ooooo`;o00003Oooool2o`0008gooooo002/
ooooo`03o`000?oooooooooo00[ooooo0_l00006ooooo`;o0000V_ooool2o`0000;ooooo0_l00005
ooooo`00OOooool2o`0000Gooooo0_l00003ooooo`;o00008Oooool00ol0003oooooooooo`1Moooo
o`;o0000Coooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Gooooo001mooooo`;o00001Oooool2
o`0000?ooooo0_l00002ooooo`;o00007Oooool00ol0003oooooooooo`1Mooooo`;o0000D?ooool0
1?oMgMgo0000oa0@4?o<c<`6ooooo`001oooooooo`0004co00003?ooool01?o^k^ko8B4Qoa0@4?o^
k^h6ooooo`001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`03ooooo`?o00001Oooool2o`000003ooooool0003o
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00;ooooo1?l00008ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00Co8B4QogMgMomgMgOo<S8b1_oo
ool000Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo027ooooo0_l00003ooooo`03o`000?oooooooooo00Oooooo0_l0000Mooooo`03o`000?oooooo
oooo00[ooooo0_l0000?ooooo`;o00002_ooool00ol0003oooooooooo`0Fooooo`;o00003_ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02Oooool2
o`0000;ooooo0_l00005ooooo`00O_ooool2o`0000gooooo0_l0000Mooooo`03o`000?oooooooooo
00[ooooo0_l0000dooooo`;o0000Moooool008Cooooo0_l0000Vooooo`03o`000?oooooooooo043o
oooo0_l0001gooooo`00Q?ooool2o`0002Kooooo00?o0000ooooooooool0^Oooool00:cooooo00?o
0000ooooooooool04Oooool4o`000:Cooooo002/ooooo`03o`000?oooooooooo017ooooo1?l0002T
ooooo`00[?ooool3o`00017ooooo0_l0001;ooooo`;o0000FOooool00:cooooo00?o0000oooooooo
ool07_ooool2o`0003kooooo0_l0001Iooooo`00[?ooool00ol0003oooooooooo`0Nooooo`;o0000
7oooool2o`0007Sooooo0024ooooo`;o00003_ooool2o`0001Kooooo00?o0000ooooooooool0?ooo
ool2o`0007Sooooo0024ooooo`;o00000oooool2o`0000Wooooo0_l0000Fooooo`03o`000?oooooo
oooo02Wooooo0_l000000ooooooo0000o`00002;ooooo`00ROooool2o`00027ooooo00?o0000oooo
ooooool0:Oooool2o`000003ooooool0003o000001?ooooo0_l0001fooooo`00[?ooool00ol0003o
ooooooooo`0Zooooo`;o00004oooool4o`0007Kooooo0029ooooo`;o00008Oooool00ol0003ooooo
ooooo`0;ooooo`;o00003oooool2o`0000cooooo0_l0000Cooooo`;o00007Oooool2o`0005Wooooo
0029ooooo`;o00008Oooool00ol0003oooooooooo`0;ooooo`;o00003oooool2o`00043ooooo0_l0
001Iooooo`00[?ooool3o`000;Wooooo001nooooo`;o0000;?ooool00ol0003oooooooooo`2ioooo
o`00O_ooool2o`0002_ooooo0_l0000Dooooo`;o0000YOooool00:_ooooo0_l0000Dooooo`;o0000
6?ooool2o`0008_ooooo002>ooooo`;o00007?ooool00ol0003oooooooooo`04ooooo`;o00001?oo
ool2o`00013ooooo0_l0000>ooooo`;o00004?ooool2o`0007Wooooo002>ooooo`;o00007?ooool0
0ol0003oooooooooo`04ooooo`;o00001?ooool2o`0000Kooooo0_l00008ooooo`;o00008?ooool2
o`0007Wooooo002Booooo`;o00006?ooool00ol0003oooooooooo`0Booooo`;o00005_ooool2o`00
03;ooooo0_l0001Iooooo`00T_ooool2o`0000Cooooo0_l0000Booooo`03o`000?oooooooooo02[o
oooo0_l0000Dooooo`?o00006oooool2o`0005Wooooo002Aooooo`;o00000_ooool2o`000003oooo
ool0003o000001;ooooo0ol0000Looooo`;o00008_ooool3o`0007Kooooo002>ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0001Gooooo00?o0000ooooooooool07?ooool2o`0009_ooooo002:
ooooo`;o00000_ooool2o`0001cooooo00?o0000ooooooooool0@Oooool2o`0007Kooooo002:oooo
o`;o00008?ooool00ol0003oooooooooo`0:ooooo`;o0000=Oooool2o`0007Kooooo002Eooooo`;o
00005Oooool00ol0003oooooooooo`0:ooooo`;o00001?ooool2o`000:Oooooo002:ooooo`;o0000
2Oooool2o`0001Gooooo00?o0000ooooooooool04?ooool2o`000:Oooooo002:ooooo`;o00008?oo
ool00ol0003oooooooooo`0Jooooo`;o00008oooool2o`0007Sooooo002/ooooo`03o`000?oooooo
oooo01[ooooo0_l0000<ooooo`;o00005?ooool3o`0007Sooooo002/ooooo`?o0000:?ooool2o`00
01Cooooo0_l0001iooooo`00[?ooool3o`0000;ooooo0_l0000;ooooo`;o0000Z?ooool00:cooooo
00?o0000ooooooooool00_ooool2o`0000_ooooo0_l0000/ooooo`;o0000N_ooool008_ooooo0_l0
000Oooooo`03o`000?oooooooooo00;ooooo0_l0000iooooo`;o0000N_ooool008_ooooo0_l0000O
ooooo`03o`000?oooooooooo0;Wooooo002Nooooo`;o00003?ooool00ol0003oooooooooo`0Joooo
o`;o00002oooool2o`00093ooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo1ol00002ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`07
ooooo`;o00003oooool4o`0000_ooooo0_l0002@ooooo`00ROooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo00Oooooo0_l0000?ooooo`Co0000WOooool008Wooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00ooo
ool3o`0000gooooo0_l0000]ooooo`;o00007_ooool2o`0005_ooooo001oooooo`;o00002?ooool0
1Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8boooo
o`04ooooo`04o`000?ooooooooooooooo`;o00000oooool2o`0000Gooooo0_l0000]ooooo`;o0000
7_ooool2o`0005_ooooo001oooooo`;o00002?ooool01Ol0003ooooooooooooooooo000000kooooo
00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00Co0000oooooooo
oooooooo0_l00003ooooo`;o00004?ooool2o`0002Cooooo0_l0001iooooo`00ROooool01Ol@413o
oooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Kooooo0_l0000@ooooo`;o00003Oooool3o`0001Cooooo0_l0001ioooo
o`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool2o`0000Cooooo0_l00009
ooooo`;o00003_ooool3o`0008oooooo0020ooooo`;o00001?ooool2o`000006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`00
0?oooooooooo00cooooo0ol00008ooooo`;o0000X?ooool0083ooooo0_l00004ooooo`;o00000ooo
ool2o`0001oooooo00?o0000ooooooooool03Oooool2o`0000Oooooo0_l0002Qooooo`00Roooool2
o`0000Oooooo0_l00006ooooo`;o00003_ooool00ol0003oooooooooo`0Fooooo`;o00004?ooool2
o`0008oooooo002;ooooo`;o00001oooool2o`0000Kooooo0_l0000>ooooo`03o`000?oooooooooo
02Sooooo0_l0000Cooooo`;o0000N_ooool008_ooooo0_l0000Oooooo`?o0000??ooool3o`0007[o
oooo0027ooooo`;o00005Oooool2o`0000cooooo00?o0000ooooooooool0??ooool2o`0007_ooooo
0027ooooo`;o00005Oooool2o`0000cooooo00?o0000ooooooooool0>oooool2o`0007cooooo002/
ooooo`03o`000?oooooooooo00Cooooo0_l0000eooooo`;o00007?ooool2o`0005kooooo0020oooo
o`;o00005oooool2o`00017ooooo00?o0000ooooooooool01?ooool2o`0001kooooo0_l0000coooo
o`;o0000G_ooool0083ooooo0_l0000:ooooo`;o00002oooool2o`00017ooooo00?o0000oooooooo
ool01?ooool2o`0000Cooooo0_l0000Hooooo`;o00005Oooool2o`0007cooooo002<ooooo`;o0000
7_ooool00ol0003oooooooooo`0:ooooo`;o00006?ooool2o`0001Gooooo0_l0001looooo`00Vooo
ool2o`0000Kooooo0_l00007ooooo`03o`000?oooooooooo02Cooooo0ol0002Booooo`00Voooool2
o`0000Kooooo0_l00007ooooo`?o00008oooool4o`0009;ooooo002/ooooo`03o`000?oooooooooo
027ooooo1?l0000Booooo`?o0000Ooooool00:Wooooo0_l000000ooooooo0000ooooo`0Rooooo`;o
00005?ooool3o`0007oooooo002Looooo`;o00002oooool2o`000003ooooool0003ooooo03_ooooo
0_l0001mooooo`00W?ooool2o`0000kooooo00?o0000ooooooooool04oooool2o`0002?ooooo1?l0
001mooooo`00Z?ooool2o`0000;ooooo00?o0000ooooooooool04oooool2o`0002?ooooo0_l0001o
ooooo`00Qoooool2o`0000Wooooo0_l0000:ooooo`;o00002?ooool2o`0000;ooooo00?o0000oooo
ooooool01oooool2o`0001Oooooo1Ol0000Cooooo`;o0000Ooooool008Oooooo0_l00009ooooo`;o
00002_ooool2o`0000cooooo00?o0000ooooooooool01oooool2o`0001Oooooo1Ol0000Cooooo`;o
0000Ooooool008Oooooo0_l0000Sooooo`?o0000>?ooool2o`0007oooooo0027ooooo`;o00007Ooo
ool2o`0000Cooooo00?o0000ooooooooool0^Oooool009Cooooo0_l0000@ooooo`;o00001?ooool0
0ol0003oooooooooo`0Oooooo`;o0000V?ooool009Cooooo0_l00003ooooo`;o00001_ooool3o`00
00Sooooo00?o0000ooooooooool03oooool2o`0000gooooo0ol0002Hooooo`00U?ooool2o`0000?o
oooo0_l00006ooooo`?o00002?ooool00ol0003oooooooooo`06ooooo`;o00001oooool2o`0000go
oooo0_l0002Iooooo`00[?ooool2o`0000Oooooo0_l0000[ooooo`;o0000Q?ooool00:cooooo0_l0
000dooooo`;o0000Q?ooool00:cooooo00?o0000ooooooooool07_ooool2o`0001Kooooo0_l00021
ooooo`00[?ooool3o`0000kooooo0_l0000=ooooo`?o00005_ooool2o`00087ooooo002[ooooo`;o
00004?ooool3o`0000cooooo0_l0000Gooooo`;o0000POooool00:_ooooo0_l0000Aooooo`;o0000
Z?ooool00:cooooo00?o0000ooooooooool0<_ooool2o`0008Gooooo002Wooooo`?o00000_ooool0
0ol0003oooooooooo`0booooo`;o0000QOooool009Kooooo0_l0000?ooooo`?o00000_ooool00ol0
003oooooooooo`2iooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;o00000oooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;Wooooo002Aoooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo0_l00005ooooo`03o`000?oooooo
oooo00;o0000]oooool008;ooooo0_l0000=ooooo`05oa0@4?ooooooooooooooool@41002_ooool2
o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo00;o00001oooool3o`000:gooooo0022oooo
o`;o00001oooool2o`0000Cooooo00Go0000ooooooooooooooooo`00000:ooooo`;o00000oooool0
0omgMgOo<S8booooo`04ooooo`Go00001oooool3o`0002Kooooo0_l00025ooooo`00Roooool2o`00
00Cooooo00Go0000ooooooooooooooooo`000002ooooo`;o00002?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Gooooo00?o0000ooooooooool0<_ooool2o`0008Gooooo002Aooooo`05oa0@4?oooooo
ooooooooool@41000_ooool2o`0000Sooooo00?o0000ooooooooool01oooool2o`000;[ooooo002A
ooooo`05ogMgMol0003o0000oiRHV?mgMgL00_ooool2o`0000Sooooo00?o0000ooooooooool01ooo
ool2o`0000[ooooo0_l0000?ooooo`;o0000WOooool0097ooooo00Gok^k^o`000?l0003o<S8bonk^
kP02ooooo`;o00002?ooool4o`0000Kooooo0ol00009ooooo`;o00003oooool2o`0009gooooo002[
ooooo`Co0000;_ooool2o`0008Wooooo002[ooooo`;o00006_ooool2o`0001Cooooo0_l00029oooo
o`00Z_ooool3o`0001[ooooo0_l0002Oooooo`00W?ooool2o`0000cooooo1Ol00007ooooo`;o0000
9Oooool2o`0008Wooooo002Cooooo`;o00001oooool2o`0000kooooo00?o0000ooooooooool01ooo
ool2o`0002Gooooo0_l00029ooooo`00Toooool2o`0000Wooooo0_l0000<ooooo`03o`000?oooooo
oooo01?ooooo0_l0000Gooooo`;o0000Roooool009kooooo0_l0000<ooooo`03o`000?oooooooooo
01?ooooo0_l0000Gooooo`;o0000Roooool00:cooooo00?o0000ooooooooool05Oooool2o`000:;o
oooo002/ooooo`03o`000?oooooooooo01Gooooo0_l0002Rooooo`00Xoooool2o`000003ooooool0
003o000000Cooooo00?o0000ooooooooool0^Oooool008Gooooo0_l00005ooooo`;o00005Oooool2
o`000003ooooool0003o000000Cooooo00?o0000ooooooooool0:oooool2o`0008cooooo0025oooo
o`;o00001Oooool2o`0001kooooo0ol00002ooooo`;o00009_ooool3o`0008cooooo002=ooooo`;o
00007Oooool00ol0003oooooooooo`02ooooo`;o00003_ooool2o`0001Kooooo0_l0002=ooooo`00
SOooool2o`0000Oooooo0_l0000Dooooo`03o`000?oooooooooo01;ooooo0_l0000Booooo`;o0000
TOooool008kooooo0_l00006ooooo`;o00005?ooool00ol0003oooooooooo`0Vooooo`;o0000TOoo
ool008kooooo0_l0000Looooo`03o`000?oooooooooo02Oooooo0_l0002@ooooo`00[?ooool00ol0
003oooooooooo`0Vooooo`?o0000T?ooool008Oooooo0_l0000?ooooo`;o00004_ooool00ol0003o
ooooooooo`0Sooooo`;o000000Coooooo`000?l0003o0000T?ooool008Oooooo0_l00006ooooo`;o
00001oooool2o`0001;ooooo00?o0000ooooooooool03?ooool2o`0001Gooooo0ol000000ooooooo
0000o`00002@ooooo`00Soooool2o`0001_ooooo0ol0000<ooooo`;o00005_ooool2o`0009?ooooo
002[ooooo`;o00009Oooool2o`0009Cooooo002[ooooo`;o00009Oooool2o`0009Cooooo002/oooo
o`03o`000?oooooooooo00[ooooo0_l0002]ooooo`00R?ooool2o`0002;ooooo00?o0000oooooooo
ool02_ooool3o`0001;ooooo0_l00002ooooo`;o0000U?ooool008Sooooo0_l0000Oooooo`;o0000
00?oooooo`000?ooool03?ooool2o`0001;ooooo0_l00002ooooo`;o0000U?ooool00:Wooooo0_l0
00000ooooooo0000ooooo`0Sooooo`?o0000U?ooool00:cooooo00?o0000ooooooooool08_ooool2
o`0009Gooooo002Vooooo`;o00001?ooool00ol0003oooooooooo`2iooooo`00XOooool2o`0000?o
oooo0ol00003ooooo`?o0000^Oooool00:7ooooo0_l00004ooooo`;o00000oooool00ol0003ooooo
ooooo`2iooooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool0^Oooool009Cooooo0_l0000F
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool07Oooool2o`0009[ooooo0029oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01gooooo0_l0002Jooooo`00ROooool01Ol@
413ooooooooooooooooo410@00Sooooo0_l00003ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`2iooooo`00ROooool01Ol0003ooooooooooooooooo
000000Sooooo0_l00004ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3
o`0001[ooooo0_l0002Mooooo`00ROooool3o`000003ooooool0003ooooo00gooooo00?oEEEEolc<
c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool06?ooool4
o`0009gooooo0029ooooo`05oa0@4?l0003o0000ooooool@41003_ooool00onYZJWoMgMgooooo`03
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06?ooool2o`0009oooooo0029oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Gooooo`;o0000X?ooool008Wooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0ol0000Gooooo`;o0000X?oo
ool00:cooooo0ol0000Gooooo`;o0000X?ooool00:cooooo00?o0000ooooooooool05oooool2o`00
0:3ooooo002Jooooo`?o00003Oooool3o`0001Wooooo0_l0002Pooooo`00V_ooool3o`0000gooooo
1Ol0002iooooo`00[?ooool00ol0003oooooooooo`0Booooo`;o0000YOooool009_ooooo0_l0000?
ooooo`03o`000?oooooooooo01;ooooo0_l0002Uooooo`00Voooool2o`0000oooooo00?o0000oooo
ooooool0^Oooool00:Oooooo0_l00003ooooo`03o`000?oooooooooo0;Wooooo002Mooooo`;o0000
2?ooool2o`0000?ooooo00?o0000ooooooooool03Oooool2o`000003ooooool0003o00000:Oooooo
002Mooooo`;o00000oooool2o`0000Sooooo00?o0000ooooooooool03Oooool2o`000003ooooool0
003o00000:Oooooo002Rooooo`;o00002?ooool00ol0003oooooooooo`0@ooooo`;o0000Yoooool0
0:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool00ol0003oooooooooo`0;ooooo`?o0000Zoooool00:cooooo00?o0000
ooooooooool02oooool3o`000:_ooooo002/ooooo`03o`000?oooooooooo00Kooooo0_l00003oooo
o`;o0000[?ooool00:cooooo00?o0000ooooooooool01_ooool2o`0000?ooooo0_l0002/ooooo`00
[?ooool00ol0003oooooooooo`09ooooo`;o0000[_ooool009Cooooo0_l0000Fooooo`03o`000?oo
oooooooo00Wooooo0_l0002^ooooo`00U?ooool2o`0001Kooooo0ol00003ooooo`?o0000/oooool0
0:cooooo00?o0000ooooooooool00oooool5o`000;7ooooo002/ooooo`03o`000?oooooooooo00?o
oooo0_l000000ooooooo0000o`00002aooooo`00[?ooool00ol0003oooooooooo`02ooooo`;o0000
0_ooool2o`000;7ooooo002/ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o0000/Ooo
ool00:cooooo00?o0000ooooooooool01?ooool2o`000;?ooooo002/ooooo`03o`000?oooooooooo
00Cooooo0_l0002cooooo`00V?ooool2o`0001;ooooo0ol0002iooooo`00V?ooool2o`0001;ooooo
0ol0002iooooo`00Uoooool2o`0001?ooooo00Co0000oooooooooooooooo0_l0002fooooo`00Uooo
ool3o`0001;ooooo00Co0000oooooooooooooooo0_l0002fooooo`00V?ooool2o`0001;ooooo00?o
0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool009_ooooo0_l00004oooo
o`;o00002Oooool00ol0003oooooooooo`2iooooo`00Voooool2o`0000Cooooo1Ol000000ol@413o
ooooooooo`03ooooo`03o`000?oooooooooo0;Wooooo002Oooooo`Ko00001oooool00ol0003ooooo
ooooo`2iooooo`00Woooool2o`000004ooooool0003o0000o`0000Oooooo0ol0002iooooo`00Y?oo
ool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0
003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00X_ooool00omEEEGoIVIV
o`000033ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
Z_ooool01?l@413o0000o`000?l0002jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zooo
ool00ol0003oooooooooo`2jooooo`00Zoooool01_l0003oMgMgo`000?l0003oEEEEonk^k[Oooooo
002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoEEEE]oooool00:_ooooo00?o0000onk^k_ooool0
0_ooool00ol0003oooooooooo`2eooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03o`000?oo
oooooooo0;Gooooo002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoIVIV]oooool00:[ooooo00?o
410@o`000?mgMgL00_l000000omVIVKok^k^ooooo`2fooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.64143 .43408 Mdot
.64586 .60235 Mdot
.5038 .54722 Mdot
.48719 .74694 Mdot
.40693 .41125 Mdot
.53246 .17948 Mdot
.49872 .63727 Mdot
.72052 .59707 Mdot
.7104 .47722 Mdot
.51978 .28822 Mdot
.56759 .46531 Mdot
.69409 .68873 Mdot
.56609 .82181 Mdot
.55115 .36609 Mdot
.66084 .75233 Mdot
.41618 .52721 Mdot
.50952 .82095 Mdot
.55972 .8327 Mdot
.50614 .77135 Mdot
.40164 .19132 Mdot
.52526 .87629 Mdot
.61134 .71687 Mdot
.57595 .785 Mdot
.53673 .8657 Mdot
.61564 .84062 Mdot
.57109 .32781 Mdot
.56403 .5737 Mdot
.50315 .77263 Mdot
.43744 .08151 Mdot
.63645 .6351 Mdot
.46419 .91902 Mdot
.71148 .45739 Mdot
.71611 .58219 Mdot
.41691 .74634 Mdot
.39236 .49374 Mdot
.3937 .25695 Mdot
.62857 .23452 Mdot
.53216 .705 Mdot
.50619 .07344 Mdot
.69613 .69323 Mdot
.63762 .81353 Mdot
.39998 .64326 Mdot
.44904 .14285 Mdot
.64613 .43401 Mdot
.62621 .35924 Mdot
.47478 .17396 Mdot
.55324 .38889 Mdot
.69454 .37124 Mdot
.6064 .52775 Mdot
.45481 .06298 Mdot
.69383 .37421 Mdot
.53853 .10518 Mdot
.65888 .14924 Mdot
.41785 .23148 Mdot
.40944 .26513 Mdot
.71507 .53306 Mdot
.71563 .61659 Mdot
.52313 .80098 Mdot
.66853 .30706 Mdot
.61835 .33662 Mdot
.50096 .19533 Mdot
.44057 .98874 Mdot
.52394 .09625 Mdot
.52084 .346 Mdot
.70327 .61696 Mdot
.71576 .48732 Mdot
.51622 .28272 Mdot
.4178 .5441 Mdot
.53965 .69063 Mdot
.50308 .9094 Mdot
.52285 .80942 Mdot
.43568 .56409 Mdot
.53201 .32215 Mdot
.47622 .22729 Mdot
.52393 .09632 Mdot
.44904 .58939 Mdot
.65944 .15009 Mdot
.55458 .30364 Mdot
.51336 .07563 Mdot
.59794 .54803 Mdot
.39127 .70902 Mdot
.63543 .63382 Mdot
.50173 .71878 Mdot
.39824 .62884 Mdot
.72296 .55119 Mdot
.41631 .56019 Mdot
.40975 .37353 Mdot
.45069 .20249 Mdot
.55231 .74755 Mdot
.41701 .50871 Mdot
.6055 .85429 Mdot
.54642 .46154 Mdot
.4512 .19561 Mdot
.54189 .43324 Mdot
.42634 .01828 Mdot
.54811 .35678 Mdot
.69792 .40539 Mdot
.66916 .16198 Mdot
.55993 .73627 Mdot
.6461 .4752 Mdot
.57985 .68144 Mdot
.68641 .70208 Mdot
.65033 .47316 Mdot
.43396 .88911 Mdot
.40766 .6963 Mdot
.49232 .85333 Mdot
.48127 .80563 Mdot
.54675 .4638 Mdot
.49028 .92149 Mdot
.53457 .31901 Mdot
.50348 .72068 Mdot
.71037 .4561 Mdot
.38352 .32713 Mdot
.77307 .3464 Mdot
.52872 .55726 Mdot
.52863 .24442 Mdot
.72115 .48573 Mdot
.7174 .46786 Mdot
.63307 .25116 Mdot
.56167 .82715 Mdot
.50094 .99728 Mdot
.52792 .86427 Mdot
.43768 .07934 Mdot
.49461 .91868 Mdot
.46206 .74699 Mdot
.39904 .21356 Mdot
.38888 .14209 Mdot
.64113 .58255 Mdot
.46997 .71254 Mdot
.59007 .76307 Mdot
.64733 .52298 Mdot
.67608 .73354 Mdot
.532 .1752 Mdot
.48021 .12225 Mdot
.47714 .04565 Mdot
.59893 .17922 Mdot
.42313 .11724 Mdot
.53011 .31825 Mdot
.70657 .62769 Mdot
.66263 .75237 Mdot
.36539 .65318 Mdot
.54131 .59579 Mdot
.52993 .71928 Mdot
.51123 .81884 Mdot
.38985 .26424 Mdot
.72324 .52562 Mdot
.79726 .42305 Mdot
.43619 .7464 Mdot
.46379 .18523 Mdot
.5533 .94364 Mdot
.58843 .65555 Mdot
.56404 .60341 Mdot
.53842 .86493 Mdot
.44232 .6152 Mdot
.58902 .28334 Mdot
.588 .16871 Mdot
.52765 .0974 Mdot
.71948 .49827 Mdot
.6327 .24465 Mdot
.59042 .17089 Mdot
.59624 .4141 Mdot
.50565 .06513 Mdot
.66918 .76782 Mdot
.38107 .39371 Mdot
.46484 .13088 Mdot
.64377 .48019 Mdot
.72226 .52165 Mdot
.41888 .85246 Mdot
.54364 .67791 Mdot
.57455 .145 Mdot
.43782 .09101 Mdot
.54402 .54427 Mdot
.54993 .65146 Mdot
.41837 .31236 Mdot
.42932 .72641 Mdot
.70933 .60611 Mdot
.41494 .04609 Mdot
.5859 .27803 Mdot
.52424 .57488 Mdot
.46313 .05378 Mdot
.54727 .11032 Mdot
.68052 .73241 Mdot
.43353 .30185 Mdot
.63118 .82502 Mdot
.42895 .57782 Mdot
.70812 .47858 Mdot
.39182 .13063 Mdot
.71073 .4303 Mdot
.67145 .76092 Mdot
.45968 .12791 Mdot
.53477 .95931 Mdot
.38825 .27537 Mdot
.49696 .28749 Mdot
.44797 .99453 Mdot
.72145 .57585 Mdot
.61692 .85388 Mdot
.68309 .71413 Mdot
.44151 .21666 Mdot
.45833 .85884 Mdot
.52773 .48544 Mdot
.52824 .49878 Mdot
.43306 .51665 Mdot
.4092 .39161 Mdot
.53817 .01367 Mdot
.64588 .50798 Mdot
.44828 .3079 Mdot
.55466 .21504 Mdot
.51733 .68968 Mdot
.4243 .49489 Mdot
.56907 .46751 Mdot
.59901 .75964 Mdot
.54732 .28606 Mdot
.41617 .84345 Mdot
.42862 .33178 Mdot
.64427 .49266 Mdot
.53745 .26721 Mdot
.66345 .77761 Mdot
.43145 .6098 Mdot
.61591 .34212 Mdot
.70569 .66536 Mdot
.52105 .23002 Mdot
.67845 .34169 Mdot
.43509 .89384 Mdot
.38045 .57589 Mdot
.42294 .37956 Mdot
.40808 .58944 Mdot
.65344 .56093 Mdot
.5464 .51513 Mdot
.66053 .75381 Mdot
.4306 .67095 Mdot
.50434 .39892 Mdot
.55835 .03738 Mdot
.59062 .62846 Mdot
.56849 .54749 Mdot
.51143 .98439 Mdot
.5432 .67485 Mdot
.65222 .49263 Mdot
.54928 .83729 Mdot
.64755 .50651 Mdot
.43436 .97818 Mdot
.49236 .12495 Mdot
.39555 .75395 Mdot
.5235 .80822 Mdot
.71289 .44713 Mdot
.53938 .42604 Mdot
.5929 .18208 Mdot
.54722 .74609 Mdot
.52778 .80095 Mdot
.52093 .09097 Mdot
.61853 .84933 Mdot
.52891 .55265 Mdot
.50372 .30635 Mdot
.61131 .212 Mdot
.58015 .36248 Mdot
.55186 .6427 Mdot
.41247 .24239 Mdot
.44465 .55903 Mdot
.71309 .61611 Mdot
.68339 .34024 Mdot
.60173 .5756 Mdot
.56875 .54495 Mdot
.37867 .51832 Mdot
.50109 .67653 Mdot
.58547 .6593 Mdot
.63579 .41461 Mdot
.55964 .42434 Mdot
.52649 .17812 Mdot
.41335 .15888 Mdot
.59452 .42963 Mdot
.39234 .25915 Mdot
.41479 .23533 Mdot
.51245 .26976 Mdot
.60012 .55983 Mdot
.5806 .15698 Mdot
.43617 .28882 Mdot
.43686 .76153 Mdot
.69875 .39341 Mdot
.56706 .43966 Mdot
.5765 .25503 Mdot
.47817 .04883 Mdot
.47903 .71895 Mdot
.46279 .23724 Mdot
.63468 .25007 Mdot
.69506 .6788 Mdot
.47839 .80747 Mdot
.46327 .67382 Mdot
.40652 .4899 Mdot
.37581 .5046 Mdot
.4732 .17887 Mdot
.40049 .76657 Mdot
.39477 .11874 Mdot
.66659 .30857 Mdot
.67727 .71596 Mdot
.67212 .32918 Mdot
.51685 .51118 Mdot
.65028 .26519 Mdot
.45718 .99911 Mdot
.38181 .64726 Mdot
.66623 .74037 Mdot
.80491 .4605 Mdot
.6034 .52305 Mdot
.44433 .14222 Mdot
.64865 .52503 Mdot
.7125 .4526 Mdot
.63346 .81577 Mdot
.5575 .40376 Mdot
.69827 .39753 Mdot
.58484 .3769 Mdot
.51727 .4041 Mdot
.594 .76582 Mdot
.50002 .83718 Mdot
.56311 .82216 Mdot
.56417 .92939 Mdot
.52215 .59854 Mdot
.62427 .36879 Mdot
.40552 .68409 Mdot
.69961 .63617 Mdot
.50374 .67218 Mdot
.67445 .74442 Mdot
.52885 .95809 Mdot
.3611 .59937 Mdot
.43803 .69764 Mdot
.52909 .16866 Mdot
.39856 .63686 Mdot
.54748 .12432 Mdot
.40944 .61497 Mdot
.52328 .42632 Mdot
.51169 .57415 Mdot
.5022 .83897 Mdot
.71261 .63878 Mdot
.61191 .21623 Mdot
.54005 .41865 Mdot
.60689 .73705 Mdot
.46681 .71257 Mdot
.43293 .50238 Mdot
.65229 .5703 Mdot
.5189 .15899 Mdot
.46548 .13029 Mdot
.59653 .41728 Mdot
.40727 .42438 Mdot
.62942 .11019 Mdot
.58735 .39467 Mdot
.63582 .62195 Mdot
.52526 .36347 Mdot
.71488 .56548 Mdot
.56533 .55813 Mdot
.41769 .13465 Mdot
.61833 .68714 Mdot
.54909 .5263 Mdot
.51313 .22398 Mdot
.36762 .68292 Mdot
.69958 .6757 Mdot
.64424 .24998 Mdot
.39772 .22945 Mdot
.60399 .48734 Mdot
.45377 .851 Mdot
.42511 .11871 Mdot
.58883 .64249 Mdot
.69867 .67707 Mdot
.3616 .62446 Mdot
.39153 .72794 Mdot
.67574 .73263 Mdot
.67029 .75331 Mdot
.64568 .80604 Mdot
.43886 .39858 Mdot
.59609 .6002 Mdot
.65866 .75924 Mdot
.71504 .61343 Mdot
.44288 .37292 Mdot
.4243 .86052 Mdot
.58976 .41777 Mdot
.55154 .20702 Mdot
.64492 .46329 Mdot
.70191 .42424 Mdot
.65176 .49246 Mdot
.64153 .25511 Mdot
.58891 .18206 Mdot
.58031 .77567 Mdot
.63018 .2243 Mdot
.59134 .75824 Mdot
.6331 .81176 Mdot
.7834 .37117 Mdot
.64751 .27993 Mdot
.59141 .28382 Mdot
.44361 .61632 Mdot
.56823 .91134 Mdot
.56319 .72553 Mdot
.51352 .55843 Mdot
.68131 .73411 Mdot
.4982 .91548 Mdot
.52039 .40753 Mdot
.49174 .23689 Mdot
.5573 .29873 Mdot
.56587 .57302 Mdot
.6982 .38036 Mdot
.44224 .91074 Mdot
.44703 .99187 Mdot
.678 .73875 Mdot
.45875 .85045 Mdot
.62219 .10563 Mdot
.45258 .84666 Mdot
.43639 .75162 Mdot
.42646 .72005 Mdot
.465 .34612 Mdot
.71175 .63604 Mdot
.69472 .68576 Mdot
.56507 .56556 Mdot
.54672 .54017 Mdot
.57397 .51173 Mdot
.41573 .44535 Mdot
.58428 .90083 Mdot
.436 .22796 Mdot
.37857 .44617 Mdot
.53043 .63961 Mdot
.56071 .6176 Mdot
.49276 .69838 Mdot
.42231 .28291 Mdot
.42717 .78559 Mdot
.56919 .56351 Mdot
.45649 .2883 Mdot
.52692 .97131 Mdot
.70832 .62147 Mdot
.4842 .38267 Mdot
.3931 .44185 Mdot
.49128 .85419 Mdot
.60979 .33783 Mdot
.59391 .44192 Mdot
.54955 .65676 Mdot
.57309 .90767 Mdot
.65127 .52225 Mdot
.74982 .29316 Mdot
.64914 .44603 Mdot
.46615 .27258 Mdot
.70964 .51379 Mdot
.6523 .77147 Mdot
.56833 .49334 Mdot
.61364 .69684 Mdot
.63819 .12158 Mdot
.5446 .56212 Mdot
.50927 .36365 Mdot
.41665 .65871 Mdot
.37956 .56664 Mdot
.59998 .50847 Mdot
.42547 .5253 Mdot
.40302 .32201 Mdot
.40715 .70475 Mdot
.53262 .38341 Mdot
.51993 .60519 Mdot
.45477 .24121 Mdot
.71939 .60113 Mdot
.51835 .62177 Mdot
.49419 .05441 Mdot
.65029 .56902 Mdot
.62713 .37009 Mdot
.39419 .24382 Mdot
.41382 .82483 Mdot
.48238 .85564 Mdot
.37666 .20752 Mdot
.49759 .24477 Mdot
.71185 .64307 Mdot
.62392 .84265 Mdot
.56068 .43501 Mdot
.64804 .25903 Mdot
.59435 .43703 Mdot
.51512 .80774 Mdot
.41284 .15067 Mdot
.64658 .47106 Mdot
.49096 .7954 Mdot
.51348 .22392 Mdot
.4232 .77433 Mdot
.4885 .129 Mdot
.45622 .62143 Mdot
.445 .15242 Mdot
.5991 .54692 Mdot
.4345 .43695 Mdot
.42602 .63406 Mdot
.41166 .26073 Mdot
.46331 .12397 Mdot
.5296 .52122 Mdot
.57392 .34665 Mdot
.71596 .4914 Mdot
.40431 .46822 Mdot
.63115 .39662 Mdot
.54579 .68113 Mdot
.48878 .79057 Mdot
.46265 .31338 Mdot
.76644 .32482 Mdot
.4726 .30571 Mdot
.64933 .58631 Mdot
.68297 .36384 Mdot
.38112 .38808 Mdot
.53331 .70797 Mdot
.43859 .08231 Mdot
.68578 .7169 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`09ooooo`;o0000[_ooool00:;ooooo00?oEEEEofIV
I_l000001oooool00ol0003oooooooooo`09ooooo`;o0000[_ooool009?ooooo0_l0000Gooooo`03
o`000?oooooooooo0;Wooooo002Cooooo`;o00005oooool00ol0003oooooooooo`2iooooo`00[?oo
ool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo013ooooo
0_l0002Wooooo`00[?ooool00ol0003oooooooooo`0@ooooo`;o0000Yoooool00:cooooo00?o0000
ooooooooool0^Oooool008oooooo0_l0000Cooooo`;o00001_ooool00ol0003oooooooooo`2ioooo
o`00Soooool2o`0001?ooooo0_l00006ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`;o0000
1_ooool3o`000;Wooooo002Oooooo`;o00002Oooool3o`000;_ooooo002Oooooo`;o00002Oooool3
o`000;_ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Mooooo`;o00003Oooool3o`000;Wo
oooo002Mooooo`;o00003Oooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`04o`000?oooooo0000o`000;Sooooo002/ooooo`Ko0000]_ooool009Oooooo0_l0000Coooo
o`04o`000?ooooooooooooooo`;o0000]_ooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo
0;Wooooo002Gooooo`;o00004oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool00oooool2o`000;Cooooo002G
ooooo`;o00004oooool00ol0003oooooooooo`03ooooo`;o0000]?ooool00:cooooo00?o0000oooo
ooooool01?ooool4o`000;7ooooo002/ooooo`?o00001?ooool4o`000;7ooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00Wooooo0_l0000Jooooo`;o0000T_oo
ool00:cooooo00?o0000ooooooooool02Oooool2o`000003ooooool0003o000001Oooooo1?l0002@
ooooo`00[?ooool00ol0003oooooooooo`0<ooooo`;o00006Oooool2o`00093ooooo002/ooooo`03
o`000?oooooooooo0;Wooooo0029ooooo`?o000000?o<S8bonk^k_ooool00oooool3o`0000Kooooo
00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooooooo
ool0^Oooool008Wooooo0_l000000oooooooV9RHogMgM`04ooooo`?o00001_ooool00omEEEGoZJVY
ooooo`07ooooo`;o00001Oooool00ol0003oooooooooo`0Zooooo`;o0000SOooool0087ooooo1_l0
0002ooooo`05oa0@4?ooooooooooooooool@41003Oooool01?nYZJWoEEEEooooooooool2o`0000Co
oooo0_l00002ooooo`;o000000Coooooo`000?l0003o00003?ooool2o`0001cooooo0_l0002=oooo
o`00ROooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooool000000_l00004oooo
o`04ogMgMolb<S;oooooooooo`;o000000?oooooo`000?ooool03Oooool2o`000:_ooooo0028oooo
o`;o00000oooool00ol0003oooooooooo`0<ooooo`03oeEEEOo<c<co000000Co000000Go8B4Qo`00
0?lb<S;oc<c<ooooo`02o`0000;ooooo00?o0000ooooooooool0^Oooool008Sooooo0_l00003oooo
o`03oa0@4?oooooooooo00;o00002_ooool01?nYZJWoMgMgooooooooool3o`0000Gooooo0_l00002
ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool2
o`0000Oooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0^Oooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?oo
ool4o`0000Kooooo00?o0000ooooooooool0^Oooool008Oooooo0_l0000@ooooo`Co00003oooool0
0ol0003oooooooooo`2iooooo`00Qoooool2o`00013ooooo1?l0000?ooooo`03o`000?oooooooooo
01Gooooo0_l0002Rooooo`00[?ooool00ol0003oooooooooo`0Eooooo`;o00006_ooool2o`0008Ko
oooo002?ooooo`;o00002?ooool2o`00017ooooo0ol0000aooooo`;o0000Q_ooool008oooooo0_l0
0008ooooo`;o00004Oooool00ol0003oooooooooo`2iooooo`00Soooool2o`0001_ooooo00?o0000
ooooooooool00oooool2o`0001;ooooo0_l0002Pooooo`00Soooool2o`0001_ooooo00?o0000oooo
ooooool00oooool2o`0001;ooooo0_l0000Kooooo`;o0000Poooool00:cooooo00?o0000oooooooo
ool0=?ooool2o`0008?ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo00Kooooo0_l0000Booooo`;o0000WOooool00:?ooooo0_l00007ooooo`03o`000?oooooo
oooo00Kooooo0_l0000Booooo`;o0000WOooool00:?ooooo0_l00007ooooo`?o00001oooool2o`00
0;3ooooo002Sooooo`;o00001oooool00ol0003oooooooooo`05ooooo`Co00005?ooool2o`0009[o
oooo002Sooooo`;o00001oooool00ol0003oooooooooo`05ooooo`Co00004Oooool5o`0009[ooooo
002Pooooo`;o00002_ooool00ol0003oooooooooo`0Jooooo`?o0000W?ooool00:3ooooo0_l0000:
ooooo`03o`000?oooooooooo0;Wooooo002;ooooo`;o00007oooool00ol0003oooooooooo`2ioooo
o`00Roooool2o`0001oooooo0_l0002jooooo`00Voooool2o`0000oooooo0_l0002jooooo`00Vooo
ool2o`0000oooooo0ol0002iooooo`00Voooool2o`0000oooooo00?o0000ooooooooool0^Oooool0
08?ooooo0_l0000Fooooo`;o00003oooool00ol0003oooooooooo`0>ooooo`;o0000ZOooool008?o
oooo0_l0000Wooooo`03o`000?oooooooooo00kooooo0_l0002Yooooo`00R_ooool2o`00023ooooo
00?o0000ooooooooool08Oooool2o`0009Kooooo002:ooooo`;o00003?ooool2o`0001;ooooo00?o
0000ooooooooool03oooool2o`00013ooooo0ol0002Eooooo`00V?ooool2o`0001;ooooo00?o0000
ooooooooool03oooool2o`00017ooooo0_l0002Eooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool3o`000003ooooool0003o000002Gooooo0_l0002?ooooo`00U_ooool2o`0000cooooo
0_l00006ooooo`04o`000?ooooooooooooooo`;o00009Oooool2o`0008oooooo002:ooooo`;o0000
1?ooool2o`0000Cooooo0_l0000<ooooo`;o00001_ooool00ol0003oooooooooo`04ooooo`;o0000
/oooool008[ooooo0_l00004ooooo`;o00006_ooool00ol0003oooooooooo`04ooooo`;o00008Ooo
ool2o`00093ooooo002?ooooo`;o00003_ooool2o`0000Sooooo0_l000000ooooooo0000ooooo`0X
ooooo`;o0000T?ooool008oooooo0_l0000>ooooo`;o00002?ooool2o`000003ooooool0003ooooo
0;[ooooo0029ooooo`;o00001?ooool2o`000005onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@;o00000oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0^Oooool0
08Wooooo0_l00004ooooo`;o000000GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q0_l00006
ooooo`03ogMgMolb<S;ooooo00?ooooo0_l00008ooooo`;o00008?ooool2o`0008oooooo0029oooo
o`Ko00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool2
o`0000Sooooo0_l0000Pooooo`?o000000?oooooo`000?l00000Roooool0097ooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Xooooo`?o000000?ooooo
o`000?l00000Roooool0097ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Fooooo`;o00004?ooool2o`000003ooooool0
003o000008cooooo0028ooooo`;o00001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Fooooo`;o00004oooool4o`0008[ooooo0028
ooooo`;o00001?ooool2o`000006oooooomgMgOoV9RHoooooonHV9SoMgMg3?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo02gooooo0_l0002:ooooo`00Qoooool2o`0000Gooooo0_l0
00001_ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo1?l00006ooooo`03o`000?oooooooooo02ko
oooo0_l00029ooooo`00Qoooool2o`0000Gooooo0_l0000Looooo`03o`000?oooooooooo00Wooooo
0_l0000Sooooo`;o0000ROooool00:cooooo00Co0000oooooooooooooooo0_l00006ooooo`;o0000
[_ooool00:3ooooo0_l0000:ooooo`04o`000?ooooooooooooooo`;o0000]_ooool008Oooooo0_l0
000Gooooo`;o00002_ooool3o`000;Wooooo0027ooooo`;o00008oooool00ol0003oooooooooo`0I
ooooo`;o00004_ooool2o`0008[ooooo002Booooo`;o00006?ooool00ol0003oooooooooo`02oooo
o`;o00005Oooool3o`00017ooooo0_l0002:ooooo`00T_ooool2o`0001Sooooo00?o0000oooooooo
ool00_ooool2o`0000Sooooo0_l0000<ooooo`?o0000W?ooool009Kooooo0_l00005ooooo`;o0000
3?ooool2o`0000Gooooo0_l00007ooooo`;o00003Oooool2o`0009cooooo002Fooooo`;o00001Ooo
ool2o`0000cooooo0_l00005ooooo`;o0000]?ooool00:cooooo00?o0000ooooooooool0Coooool2
o`0006Sooooo002/ooooo`03o`000?oooooooooo04oooooo0_l0001Xooooo`00[?ooool3o`0000oo
oooo0_l0002Xooooo`00U_ooool2o`0001Cooooo00?o0000ooooooooool03oooool2o`000:Sooooo
002Fooooo`;o00002oooool2o`0000Oooooo0ol0000?ooooo`;o00008oooool2o`0008?ooooo002J
ooooo`;o00001oooool2o`0000Oooooo0ol0000dooooo`;o0000Poooool0097ooooo0_l00007oooo
o`;o00000oooool2o`0000_ooooo00?o0000ooooooooool0=?ooool2o`0008?ooooo002Aooooo`;o
00003?ooool2o`0000_ooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
1oooool3o`000:oooooo002<ooooo`;o00007_ooool00ol0003oooooooooo`07ooooo`?o0000[ooo
ool008cooooo0_l0000Nooooo`?o00001oooool2o`0004cooooo0_l0001Rooooo`00QOooool2o`00
02Gooooo00?o0000ooooooooool05?ooool2o`0003oooooo0_l0001Rooooo`00QOooool2o`0000go
oooo0_l0000Fooooo`03o`000?oooooooooo01Cooooo0_l0000Oooooo`;o0000P_ooool009Cooooo
0_l0000Fooooo`03o`000?oooooooooo03Gooooo0_l00022ooooo`00[?ooool00ol0003ooooooooo
o`0Qooooo`;o000000?oooooo`000?l00000Toooool00:cooooo00?o0000ooooooooool08Oooool2
o`000003ooooool0003o000001?ooooo0_l0001nooooo`00[?ooool00ol0003oooooooooo`0Soooo
o`;o00004_ooool4o`0007kooooo002Pooooo`;o00002_ooool00ol0003oooooooooo`03ooooo`;o
00004?ooool2o`0000cooooo0_l0000Booooo`;o00007_ooool2o`00063ooooo002Pooooo`;o0000
2_ooool00ol0003oooooooooo`03ooooo`;o00004?ooool2o`00043ooooo0_l0001Pooooo`00[?oo
ool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
00cooooo0_l0002[ooooo`00[?ooool00ol0003oooooooooo`0<ooooo`;o00006?ooool2o`00097o
oooo002/ooooo`03o`000?oooooooooo00;o00000oooool2o`00013ooooo0_l0000=ooooo`;o0000
4Oooool2o`0007kooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`02o`0000?o
oooo0_l00006ooooo`;o00002?ooool2o`00023ooooo0_l0001nooooo`00ROooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo00gooooo0_l0000Gooooo`?o00005?ooool2o`00
01_ooooo0_l0001Mooooo`00POooool6o`0000;ooooo00Go410@oooooooooooooooooa0@4002o`00
00Wooooo0_l000000olQ8B7ok^k^ooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool09_ooool3o`0001Cooooo0_l0000Kooooo`;o0000GOooool008Wooooo00Co0000oooooooo
oooooooo0ol00009ooooo`;o000000?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04oooo
o`?o00006Oooool2o`0002;ooooo0_l0001jooooo`00ROooool01Ol0003ooooooooooooooooo0000
00Cooooo0_l00008ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005
ooooo`03o`000?oooooooooo01Wooooo0_l0002Nooooo`00ROooool01Ol@413ooooooooooooooooo
410@00Cooooo0_l00009ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0_l0
0004ooooo`03o`000?oooooooooo03kooooo0_l0001iooooo`00ROooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`04o`000?ooooooooooooooo`;o
00001?ooool00ol0003oooooooooo`07ooooo`;o0000=Oooool2o`0007Wooooo0024ooooo`;o0000
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co00001_ooool00ol0003oooooooooo`07ooooo`;o00001Oooool2o`000:Wooooo0024ooooo`;o
00002?ooool2o`0001cooooo00?o0000ooooooooool03_ooool2o`000:Wooooo0024ooooo`;o0000
2?ooool2o`0001cooooo00?o0000ooooooooool06Oooool2o`0002?ooooo0_l0001iooooo`00Q?oo
ool2o`0002Kooooo00?o0000ooooooooool06Oooool2o`0000gooooo0_l0000Dooooo`;o0000NOoo
ool009Oooooo0_l0000Cooooo`?o0000:?ooool2o`0001Cooooo0_l0001iooooo`00Uoooool2o`00
01?ooooo0ol00002ooooo`;o00003?ooool2o`000:Oooooo002/ooooo`03o`000?oooooooooo00;o
oooo0ol0000;ooooo`;o0000;?ooool2o`0007Wooooo002/ooooo`03o`000?oooooooooo00?ooooo
0_l0000iooooo`;o0000NOooool008gooooo0_l0000Mooooo`03o`000?oooooooooo0;Wooooo002=
ooooo`;o00007Oooool00ol0003oooooooooo`0Looooo`;o00002oooool2o`0008kooooo002/oooo
o`03o`000?oooooooooo00[ooooo0_l0000>ooooo`Co00002oooool2o`0008kooooo002/ooooo`03
o`000?oooooooooo00[ooooo0_l0000>ooooo`Co0000Voooool008gooooo0_l0000Mooooo`?o0000
4?ooool2o`0002gooooo0_l0000Nooooo`;o0000F?ooool008gooooo0_l0000Mooooo`03o`000?oo
oooooooo00Cooooo0_l00004ooooo`;o00001?ooool2o`0002gooooo0_l0000Nooooo`;o0000F?oo
ool00:cooooo00?o0000ooooooooool01?ooool2o`0000Cooooo0_l0000@ooooo`;o00009?ooool2
o`0007Gooooo002/ooooo`03o`000?oooooooooo00[ooooo0_l0000@ooooo`;o00003Oooool4o`00
01?ooooo0_l0001eooooo`00U_ooool2o`0001Cooooo00?o0000ooooooooool02_ooool2o`0000Go
oooo0_l00009ooooo`;o00003Oooool4o`0008[ooooo002Fooooo`;o00005?ooool00ol0003ooooo
ooooo`0Aooooo`Co00001oooool2o`0009_ooooo0028ooooo`;o00008_ooool00ol0003ooooooooo
o`0Cooooo`;o00001oooool2o`0009_ooooo0023ooooo`;o00000oooool2o`0000Kooooo0_l0000J
ooooo`03o`000?oooooooooo01cooooo0_l0000@ooooo`;o0000ROooool008?ooooo0_l0000;oooo
o`;o00006_ooool00ol0003oooooooooo`0^ooooo`;o00004oooool2o`0007Cooooo002/ooooo`?o
0000@oooool2o`0007Cooooo002/ooooo`03o`000?oooooooooo04?ooooo0_l0001dooooo`00[?oo
ool00ol0003oooooooooo`12ooooo`;o0000MOooool000Wooooo1?l000000ol@413oooooooooo`0F
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Fooooo`03o`000?oo
oooooooo00cooooo0_l0000:ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd03?ooool2o`000006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@06ooooo`;o00001ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo
00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`Co000000?o410@ooooooooool04_ooool000_ooooo
00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03
oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool05Ooo
ool00ol0003oooooooooo`0<ooooo`;o00002_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`04oiRHV?lQ8B7ok^k^ooooo`;o00001_ooool00omgMgOo<S8booooo`0>ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01Oooool2o`00
00Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07
ooooo`03ogMgMolb<S;ooooo01Wooooo00?o0000ooooooooool05?ooool000Ko00001Oooool00ol0
003oooooooooo`0@ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVY
oeEEEOooool02?ooool00ol0003oooooooooo`05ooooo`Ko00000_ooool01Ol@413ooooooooooooo
oooo410@013ooooo00?o0000ooooooooool01Oooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0<ooooo`;o00001Oooool2o`0000?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03
oiRHV?lQ8B7ok^k^00;o00001oooool00ol0003oooooooooo`0<ooooo`;o00000oooool00ol@413o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00Go410@oooooooooooooooooa0@400=oooo
o`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Doooo
o`002oooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool00olQ
8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000?
ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000=ooooo`04oiRHV?lQ
8B7o0000o`0000Kooooo00?oMgMgoc8b<_ooool05Oooool00ol0003oooooooooo`0Cooooo`;o0000
0oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h00_l00005ooooo`03
ogMgMolb<S;ooooo00gooooo0_l00003ooooo`03o`000?oooooooooo00gooooo00?oMgMgoc8b<_oo
ool03_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01So
oooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMol0003o000000?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00Fooooo`03o`000?oooooooooo01Sooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ogMgMomVIVKo000000;o000000Koooooo`000?lQ8B7o0000oc8b
<_o<c<`?ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00oooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c00Jooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooo
oooo01Sooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o
0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool0
4Oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Hooooo`?o00006?ooool01Ol@413ooooooooooooooooo410@00oooooo1?l000000ooo
oooo0000ooooo`0?ooooo`;o000000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:oooo
o`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOo
oooo00?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0
003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooo
oooo<S8b00Cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo
00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oo
ooooV9RHoa0@4004ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00Co0000okZj^_ooooooV9RH0ol00002ooooo`03o`000?oo
oooooooo00gooooo0ol000001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?o0000oooooooo
ool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05?ooool000Wooooo00?oEEEEofIV
I_l000006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00004?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0000Gooooo`03o`000?oooooooooo01So
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`04oiRHV?l@413o0000ob4Q8@;o00000oooool4
o`0000cooooo0_l00002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00013ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0001Wooooo00?oEEEEofIVI_l00000
5_ooool00:cooooo00?o0000ooooooooool01_ooool2o`0003kooooo0_l0001aooooo`00[?ooool0
0ol0003oooooooooo`06ooooo`;o00005oooool2o`0002?ooooo1?l0001aooooo`00SOooool2o`00
01gooooo00?o0000ooooooooool07oooool2o`0002?ooooo0_l0001Xooooo`;o00000_ooool2o`00
00Gooooo0028ooooo`;o00000oooool2o`0000Cooooo0_l0000Gooooo`03o`000?oooooooooo01?o
oooo0_l0000Gooooo`;o000000?oooooo`000?l000004oooool2o`0006Sooooo00Kok^k^ob4Q8On7
QhOo^[Zjo`000?oMgMd5ooooo`00R?ooool2o`0000Wooooo0_l0000Gooooo`03o`000?oooooooooo
01?ooooo0_l0000Gooooo`;o000000?oooooo`000?l000005?ooool2o`0006Sooooo00CogMgMo`00
0?l@413oc<c<1_ooool000Ooooooool0001<o`0000cooooo00Cok^k^ob4Q8Ol@413ok^k^1_ooool0
00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`?o00001Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool2o`00
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02_ooool01?lQ8B7oMgMgogMgMolb<S86ooooo`001oooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool2o`00
013ooooo0_l0000Eooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool00oooool2o`00
027ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
00Wooooo0_l00002ooooo`;o00001Oooool008?ooooo0_l0000;ooooo`;o00006_ooool00ol0003o
ooooooooo`0Nooooo`;o00003Oooool2o`0008[ooooo002@ooooo`;o00006_ooool00ol0003ooooo
ooooo`02ooooo`;o00004Oooool2o`0000Oooooo0_l0000=ooooo`;o0000R_ooool009Gooooo0_l0
000Eooooo`03o`000?oooooooooo00;ooooo0_l00008ooooo`;o00001oooool2o`0002_ooooo0_l0
001eooooo`00Q?ooool2o`0000oooooo0_l0000Eooooo`03o`000?oooooooooo00cooooo0_l0000d
ooooo`;o0000MOooool008Cooooo0_l0000Vooooo`03o`000?oooooooooo00Kooooo0_l0000Woooo
o`;o00005Oooool2o`00077ooooo002Cooooo`;o00005oooool3o`0000Kooooo0_l0000Gooooo`;o
00003?ooool4o`0001Gooooo0_l0001aooooo`00T?ooool2o`000003ooooool0003o000001Oooooo
00?o0000ooooooooool03Oooool2o`00013ooooo0ol0000;ooooo`?o00005_ooool2o`00077ooooo
002@ooooo`;o00006_ooool00ol0003oooooooooo`0=ooooo`;o00004Oooool2o`0009Oooooo002/
ooooo`03o`000?oooooooooo04Cooooo0_l0001cooooo`00[?ooool00ol0003oooooooooo`14oooo
o`;o0000Loooool00:cooooo00?o0000ooooooooool03?ooool2o`000:_ooooo002/ooooo`03o`00
0?oooooooooo00cooooo0_l0002[ooooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool02ooo
ool2o`0000Kooooo0_l00008ooooo`;o0000V_ooool0093ooooo0_l0000Jooooo`?o00002oooool2
o`0000Kooooo0_l00008ooooo`;o0000V_ooool00:cooooo0ol00006ooooo`;o00002oooool2o`00
00Sooooo0_l0000Wooooo`;o0000LOooool00:cooooo00?o0000ooooooooool01_ooool2o`0003ko
oooo0_l0001aooooo`00VOooool2o`00017ooooo00Co0000oooooooooooooooo0_l00003ooooo`;o
00002_ooool2o`000:Gooooo002@ooooo`;o00001oooool2o`00017ooooo00Co0000oooooooooooo
oooo0_l00003ooooo`;o00002_ooool2o`0000[ooooo0_l0000?ooooo`;o0000R?ooool0093ooooo
0_l00004ooooo`;o00005?ooool00ol0003oooooooooo`0;ooooo`;o00001_ooool2o`0000Wooooo
0_l0000?ooooo`;o0000R?ooool008Cooooo0_l0000@ooooo`;o00005?ooool00ol0003ooooooooo
o`0;ooooo`;o00001Oooool3o`0002kooooo0_l0001dooooo`00Q?ooool2o`0002Kooooo00?o0000
ooooooooool04_ooool2o`0001[ooooo0ol0000Booooo`;o0000M?ooool00:cooooo00?o0000oooo
ooooool00_l0000@ooooo`;o00006_ooool3o`0008Sooooo0024ooooo`;o00009_ooool5o`0000?o
oooo0_l0000;ooooo`;o00002_ooool2o`0002Kooooo0_l0001aooooo`00Q?ooool2o`0000kooooo
0_l0000Fooooo`03o`000?oooooooooo00Gooooo0_l0000Gooooo`;o00009_ooool2o`00077ooooo
002Dooooo`;o00005_ooool00ol0003oooooooooo`0[ooooo`;o00005oooool2o`0007?ooooo002/
ooooo`03o`000?oooooooooo02_ooooo0_l000000ooooooo0000o`00000Dooooo`;o0000Loooool0
0:cooooo00?o0000ooooooooool0;_ooool2o`0008Wooooo002=ooooo`;o00003?ooool2o`0000oo
oooo00?o0000ooooooooool0^Oooool008gooooo0_l0000<ooooo`;o00003oooool00ol0003ooooo
ooooo`2iooooo`00[?ooool00ol0003oooooooooo`0:ooooo`;o0000>Oooool2o`0007;ooooo001n
ooooo`;o0000;?ooool3o`0000Cooooo0_l00004ooooo`;o00004?ooool2o`0002Oooooo0_l0001b
ooooo`00O_ooool2o`0002cooooo00?o0000ooooooooool01?ooool2o`0000cooooo0_l00008oooo
o`;o00003oooool2o`0001Kooooo0_l0001booooo`00[?ooool00ol0003oooooooooo`03ooooo`;o
00003Oooool2o`0001Wooooo0_l0000Cooooo`;o0000MOooool009Gooooo0_l0000Eooooo`03o`00
0?oooooooooo00?ooooo0_l0000mooooo`;o0000MOooool009Gooooo0_l0000Eooooo`03o`000?oo
oooooooo04Cooooo0_l0001cooooo`00S_ooool2o`0000Wooooo0_l0000Aooooo`03o`000?oooooo
oooo04?ooooo0ol0001cooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;o00000oooool2
ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooooooo
o`0Aooooo`;o0000;Oooool2o`000004ooooool0003o0000o`0007?ooooo0029ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00CoV9RHob4Q8Oo^k^kooooo0_l00006ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool00oooool2o`0000cooooo0_l0000Fooooo`;o
00005Oooool3o`0007Kooooo001nooooo`;o00002Oooool01Ol@413ooooooooooooooooo410@00co
oooo00?oV9RHob4Q8Oo^k^h00_l00007ooooo`03o`000?oooooooooo00?ooooo0ol00003ooooo`;o
00009?ooool2o`0001Kooooo0_l0001fooooo`00O_ooool2o`0000Wooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`0Jooooo`;o00009Oooool2o`0007Kooooo0029ooooo`?o000000?oooooo`000?ooool0
3Oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003o
ooooooooo`0Jooooo`;o00009Oooool2o`0007Kooooo0029ooooo`05oa0@4?l0003o0000ooooool@
41001Oooool2o`0000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo02Wooooo0_l0002>ooooo`00ROooool01OmgMgOo0000o`000?nHV9SoMgMg00Go
oooo0_l00004ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`06oooo
o`;o0000:oooool3o`0001;ooooo0_l00002ooooo`;o0000MOooool008Wooooo00Gok^k^o`000?l0
003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Gooooo0_l00009
ooooo`;o00008Oooool2o`0001;ooooo0_l00002ooooo`?o0000M?ooool008_ooooo0_l0000Ooooo
o`03o`000?oooooooooo00Oooooo0_l00005ooooo`;o00002_ooool2o`0002Kooooo0ol0001doooo
o`00Roooool2o`0001oooooo00?o0000ooooooooool03_ooool2o`0000[ooooo0_l0000Vooooo`;o
0000MOooool008Gooooo0_l0000Uooooo`03o`000?oooooooooo0;Wooooo0025ooooo`;o00009Ooo
ool3o`0000gooooo0_l0002Zooooo`00Ooooool2o`0002_ooooo00?o0000ooooooooool03Oooool2
o`0000_ooooo0_l0002Mooooo`00Ooooool2o`0000oooooo0_l0000Jooooo`03o`000?oooooooooo
00gooooo0_l0000;ooooo`;o0000WOooool0093ooooo0_l0000Jooooo`03o`000?oooooooooo00go
oooo0_l0000:ooooo`;o0000W_ooool00:cooooo00?o0000ooooooooool06Oooool2o`0009kooooo
002/ooooo`03o`000?oooooooooo043ooooo0_l0001gooooo`00UOooool2o`0001Gooooo00?o0000
ooooooooool0@?ooool2o`0007Oooooo002Eooooo`;o00002?ooool2o`0000_ooooo0ol0002ioooo
o`00Woooool2o`0000_ooooo0ol0000;ooooo`;o0000<Oooool2o`0007Wooooo002/ooooo`;o0000
3?ooool2o`00033ooooo0ol0001iooooo`00P?ooool2o`0002[ooooo00?o0000ooooooooool02ooo
ool3o`0000Wooooo0_l0000Tooooo`;o0000N_ooool0083ooooo0_l0000:ooooo`;o00007_ooool0
0ol0003oooooooooo`0<ooooo`;o00002Oooool2o`0002Cooooo0_l0001jooooo`00S?ooool2o`00
01kooooo00?o0000ooooooooool09?ooool2o`0001Oooooo0_l0001jooooo`00[?ooool00ol0003o
ooooooooo`02ooooo`;o00001_ooool2o`0001Sooooo0_l0000Gooooo`;o0000N_ooool00:cooooo
00?o0000ooooooooool00_ooool2o`0000Kooooo0_l0000aooooo`;o0000N_ooool008gooooo0_l0
0008ooooo`;o00004?ooool2o`000003ooooool0003ooooo02?ooooo0_l0000Iooooo`;o0000N_oo
ool008gooooo0_l00008ooooo`;o00004?ooool2o`000004ooooool0003o0000o`0002;ooooo0_l0
002Eooooo`00[?ooool00ol0003oooooooooo`0jooooo`;o0000OOooool008gooooo0_l0000Moooo
o`03o`000?oooooooooo00Oooooo0_l0000aooooo`;o0000OOooool008Sooooo0_l00003ooooo`;o
00007Oooool00ol0003oooooooooo`07ooooo`?o0000[oooool008Sooooo0_l0000Gooooo`?o0000
2?ooool00ol0003oooooooooo`08ooooo`;o0000[oooool00:7ooooo0ol00008ooooo`03o`000?oo
oooooooo03Oooooo1?l0001nooooo`00YOooool2o`0000Gooooo0_l00007ooooo`;o00006Oooool2
o`0001Cooooo1Ol0001mooooo`00Toooool2o`00013ooooo0_l00005ooooo`?o00001_ooool2o`00
01Wooooo0_l0000Gooooo`;o0000OOooool009?ooooo0_l0000Gooooo`?o00004Oooool2o`000:Ko
oooo0028ooooo`;o00002_ooool2o`0001Kooooo00?o0000ooooooooool04Oooool2o`000:Kooooo
0028ooooo`;o00002_ooool2o`0001Kooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0=oooool3o`0007oooooo002/ooooo`03o`000?oooooooooo013ooooo0_l0000>oooo
o`;o00005Oooool3o`0007oooooo002/ooooo`03o`000?oooooooooo013ooooo0_l0000>ooooo`;o
00004Oooool2o`0000;ooooo0_l00020ooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0coooo
o`;o00000_ooool2o`00083ooooo002@ooooo`;o000000CoV9RHoooooonHV9SoMgMg0_l00003oooo
o`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00cooooo0_l0000Xoooo
o`;o0000POooool0093ooooo0_l00003ooooo`03oa0@4?l0003o000000Oooooo0_l00005ooooo`?o
00000oooool00ol0003oooooooooo`0<ooooo`Co00009_ooool2o`00087ooooo002Aooooo`06o`00
0?ooooooooooooooool0003ooooo0_l00006ooooo`;o00001?ooool01?mgMgOo<S8bo`000?l00003
ooooo`?o00003_ooool2o`0002;ooooo0_l00025ooooo`00ROooool2o`0000Kooooo00Ko0000oooo
ooooooooooooo`000?ooool2o`0000Wooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo03;ooooo0_l000000ooooooo0000o`000022ooooo`00ROooool2o`0000Kooooo00Go
410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
6oooool2o`0001Gooooo0_l000000ooooooo0000o`000022ooooo`00TOooool01_mgMgOoV9RHoooo
oonHV9SoMgMgooooo`;o00002Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01_o
oooo1?l0000Booooo`;o00000_ooool2o`0008;ooooo002Aooooo`06onk^k_lb<S;o0000oc8b<_o^
k^kooooo0_l00009ooooo`Co00001_ooool00ol0003oooooooooo`0Jooooo`;o000000?oooooo`00
0?l000004_ooool2o`0000;ooooo0_l00022ooooo`00Roooool2o`0001oooooo00?o0000oooooooo
ool06_ooool4o`0001Kooooo0_l00023ooooo`00Roooool2o`0001oooooo00?o0000ooooooooool0
7?ooool2o`0001Kooooo0_l00023ooooo`00[?ooool4o`0002kooooo0_l00028ooooo`00T_ooool2
o`0001Sooooo1?l0000Fooooo`;o00005_ooool2o`0008Sooooo002Booooo`;o00006?ooool00ol0
003oooooooooo`0Gooooo`;o00006_ooool2o`0008Cooooo002/ooooo`03o`000?oooooooooo03?o
oooo0_l00024ooooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool05_ooool2o`000:7ooooo
002Dooooo`;o00005_ooool00ol0003oooooooooo`0Fooooo`;o0000XOooool00:Sooooo0_l00002
ooooo`03o`000?oooooooooo0;Wooooo002Xooooo`;o00000_ooool00ol0003oooooooooo`2ioooo
o`00ZOooool2o`000003ooooool0003ooooo0;[ooooo002Yooooo`;o000000Coooooo`000?l0003o
00001?ooool4o`000;7ooooo002/ooooo`03o`000?oooooooooo00Cooooo1?l0002aooooo`00Y?oo
ool3o`0000Gooooo00?o0000ooooooooool0;Oooool2o`0008[ooooo002Tooooo`?o00001Oooool0
0ol0003oooooooooo`02ooooo`Co00009oooool2o`0008[ooooo002/ooooo`03o`000?oooooooooo
00;ooooo1?l0000Sooooo`?o0000SOooool00:cooooo00?o0000ooooooooool0:Oooool3o`0008go
oooo002/ooooo`03o`000?oooooooooo00;o00009oooool2o`0008kooooo002/ooooo`03o`000?oo
oooooooo00;o00003oooool3o`000:Gooooo002?ooooo`;o00006oooool5o`0000oooooo0ol0000D
ooooo`;o0000Soooool008oooooo0_l0000Kooooo`03o`000?oooooooooo017ooooo0_l0000Eoooo
o`;o0000Soooool00:cooooo00?o0000ooooooooool04Oooool2o`000:Kooooo002/ooooo`03o`00
0?oooooooooo013ooooo0_l0002Wooooo`00[?ooool2o`0000kooooo0_l000000ooooooo0000o`00
002Wooooo`00[?ooool2o`0000kooooo0_l0000Dooooo`;o0000U?ooool0093ooooo0_l0000Joooo
o`;o00009?ooool4o`0009;ooooo002@ooooo`;o00002_ooool2o`0000kooooo00?o0000oooooooo
ool09Oooool2o`0009;ooooo002Looooo`;o00003_ooool00ol0003oooooooooo`0Tooooo`;o0000
Toooool0097ooooo0_l00009ooooo`Co00003?ooool3o`0002Cooooo0_l0002Cooooo`00TOooool2
o`0000Wooooo1?l00006ooooo`;o000000Goooooo`000?l0003oooooo`00000Qooooo`;o00000_oo
ool2o`0009Cooooo002Nooooo`;o00001_ooool2o`000005ooooool0003o0000ooooool000008Ooo
ool2o`0000;ooooo0_l0002Dooooo`00Toooool2o`0000Wooooo0_l0000<ooooo`03o`000?oooooo
oooo0;Wooooo002Cooooo`;o00005oooool00ol0003oooooooooo`06ooooo`;o000000?oooooo`00
0?l00000[_ooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0
003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`06
ooooo`;o000000?oooooo`000?l00000[_ooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool02Oooool2o`000:kooooo0029ooooo`05oa0@4?ooooooooooooooool@41003Oooool0
0onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0^Oooool0
08Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMg
oc8b<_ooool01?ooool3o`0000Gooooo0_l0002booooo`00ROooool01Ol0003ooooooooooooooooo
000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool01Oooool2o`000;;ooooo0029ooooo`05oa0@4?ooooooooooooooool@41003_oo
ool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0^Ooo
ool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S80
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02?ooool2o`000003ooooool0003o000000?o00001?ooool4o`0000Kooooo
00?o0000ooooooooool0^Oooool009Kooooo0_l0000Dooooo`03o`000?oooooooooo0;Wooooo002F
ooooo`;o00005?ooool00ol0003oooooooooo`2iooooo`00U_ooool2o`0001Cooooo00?o0000oooo
ooooool0^Oooool00:cooooo0ol0000Hooooo`;o0000Woooool00:cooooo00?o0000ooooooooool0
6?ooool2o`0009oooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o00005Oooool2
o`000:;ooooo002Hooooo`;o00004_ooool3o`0001?ooooo1?l0002Rooooo`00V?ooool2o`00017o
oooo0_l0000Eooooo`;o0000Y?ooool00:3ooooo0_l00008ooooo`?o0000^oooool00:3ooooo0_l0
0006ooooo`Go0000^oooool00:Sooooo0_l00002ooooo`?o0000^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool04_ooool2o`000:Gooooo002/ooooo`03o`00
0?oooooooooo01;ooooo0_l0002Uooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0>ooooo`;o0000ZOooool00:co
oooo00?o0000ooooooooool03_ooool2o`000:Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool01_ooool2o`000;7ooooo002/ooooo`03o`000?oooooooooo00Kooooo1?l0002_ooooo`00
[?ooool00ol0003oooooooooo`08ooooo`;o0000[oooool00:cooooo00?o0000ooooooooool0^Ooo
ool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool01Oooool2o`00
0;;ooooo002/ooooo`?o00001Oooool2o`000;;ooooo002Fooooo`;o00005?ooool00ol0003ooooo
ooooo`2iooooo`00U_ooool2o`0001Cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool00_l0002gooooo`00V?ooool2o`0001;ooooo00?o0000ooooooooool00_l0002goooo
o`00V?ooool4o`00013ooooo00?o0000ooooooooool0^Oooool009[ooooo0_l00006ooooo`Co0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`2iooooo`00V_ooool2o`0000Sooooo00?o
0000ooooooooool01Oooool2o`000;[ooooo002Mooooo`;o00001Oooool00ol0003oooooooooo`05
ooooo`?o0000^Oooool009gooooo0_l00005ooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03
o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oo
oooooooo0<7ooooo002Rooooo`03oeEEEOmVIVKo00000<?ooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo002Zooooo`04oa0@4?l0003o0000o`000;[ooooo002[
ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`06
o`000?mgMgOo0000o`000?mEEEGok^k^]oooool00:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomE
EEFgooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo0;Gooooo002[oooo
o`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0]Oooool00:_ooooo00Ko0000oeEEEOo^
k^koooooogMgMomVIVJgooooo`00Z_ooool00ol@413o0000ogMgM`02o`000003ofIVI_o^k^kooooo
0;Kooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.57506 .23408 Mdot
.6468 .40235 Mdot
.48375 .36964 Mdot
.54856 .55374 Mdot
.47035 .8164 Mdot
.39954 .31609 Mdot
.51368 .4374 Mdot
.71934 .39707 Mdot
.66128 .27722 Mdot
.42292 .34875 Mdot
.51371 .26531 Mdot
.72958 .48873 Mdot
.65482 .62181 Mdot
.46022 .22214 Mdot
.72178 .55233 Mdot
.49366 .75093 Mdot
.5979 .62095 Mdot
.6528 .6327 Mdot
.57468 .57135 Mdot
.42348 .8871 Mdot
.63577 .67629 Mdot
.65809 .51687 Mdot
.64994 .585 Mdot
.643 .6657 Mdot
.71189 .64062 Mdot
.46365 .16733 Mdot
.55351 .3737 Mdot
.57221 .57263 Mdot
.39176 .75452 Mdot
.65049 .4351 Mdot
.60314 .74955 Mdot
.65444 .25739 Mdot
.70899 .38219 Mdot
.54471 .76638 Mdot
.49151 .86218 Mdot
.43953 .90757 Mdot
.48247 .04127 Mdot
.57417 .505 Mdot
.37532 .45592 Mdot
.73343 .49323 Mdot
.72303 .61353 Mdot
.52288 .81258 Mdot
.40265 .69062 Mdot
.57974 .23401 Mdot
.52991 .15924 Mdot
.40387 .57152 Mdot
.46998 .22147 Mdot
.60304 .17124 Mdot
.5775 .32775 Mdot
.38396 .68269 Mdot
.60351 .17421 Mdot
.38309 .30518 Mdot
.42874 .80761 Mdot
.43791 .83705 Mdot
.6883 .33306 Mdot
.72227 .41659 Mdot
.60352 .60098 Mdot
.55136 .10706 Mdot
.513 .13662 Mdot
.40288 .45256 Mdot
.62135 .8588 Mdot
.37934 .37186 Mdot
.43701 .33207 Mdot
.71005 .41696 Mdot
.67069 .28732 Mdot
.4212 .36572 Mdot
.497 .74022 Mdot
.5759 .49063 Mdot
.62684 .7094 Mdot
.60662 .60942 Mdot
.4975 .65779 Mdot
.43497 .29003 Mdot
.4152 .55368 Mdot
.37935 .37186 Mdot
.50013 .59403 Mdot
.44245 .20939 Mdot
.37497 .42362 Mdot
.57716 .34803 Mdot
.54022 .86218 Mdot
.64896 .43382 Mdot
.54924 .51878 Mdot
.51997 .81932 Mdot
.70344 .35119 Mdot
.50084 .74326 Mdot
.46151 .81227 Mdot
.41531 .67053 Mdot
.61133 .54755 Mdot
.48945 .75132 Mdot
.70721 .65429 Mdot
.36053 .63154 Mdot
.49108 .265 Mdot
.4137 .66977 Mdot
.47601 .25746 Mdot
.38036 .81668 Mdot
.45476 .22994 Mdot
.62008 .20539 Mdot
.61444 .53627 Mdot
.59618 .2752 Mdot
.61243 .48144 Mdot
.72725 .50208 Mdot
.5996 .27316 Mdot
.58609 .79411 Mdot
.53376 .78806 Mdot
.59431 .65501 Mdot
.56794 .61728 Mdot
.4923 .26639 Mdot
.61977 .72375 Mdot
.43528 .2803 Mdot
.55175 .52068 Mdot
.65281 .2561 Mdot
.45705 .93681 Mdot
.67163 .1464 Mdot
.51163 .35726 Mdot
.41427 .31923 Mdot
.67544 .28573 Mdot
.66454 .26786 Mdot
.49354 .05209 Mdot
.65253 .62715 Mdot
.65986 .79728 Mdot
.63362 .66427 Mdot
.39124 .75394 Mdot
.62236 .71938 Mdot
.54094 .60447 Mdot
.4289 .89363 Mdot
.4155 .95345 Mdot
.63415 .38255 Mdot
.5301 .55548 Mdot
.65529 .56307 Mdot
.61652 .32298 Mdot
.72949 .53354 Mdot
.39844 .31901 Mdot
.39141 .55898 Mdot
.37535 .58897 Mdot
.43509 .07284 Mdot
.40266 .80927 Mdot
.43316 .29844 Mdot
.71764 .42769 Mdot
.72358 .55237 Mdot
.53266 .96754 Mdot
.53963 .39579 Mdot
.57764 .51928 Mdot
.59877 .61884 Mdot
.44195 .92279 Mdot
.69349 .32562 Mdot
.72648 .22305 Mdot
.54186 .691 Mdot
.40871 .61706 Mdot
.69076 .74364 Mdot
.61065 .45555 Mdot
.56541 .40341 Mdot
.64439 .66493 Mdot
.50729 .62179 Mdot
.46347 .11816 Mdot
.42332 .10398 Mdot
.37981 .35503 Mdot
.67878 .29827 Mdot
.49058 .04662 Mdot
.42578 .09653 Mdot
.52188 .2141 Mdot
.37359 .46012 Mdot
.73631 .56782 Mdot
.47211 .93309 Mdot
.39662 .62421 Mdot
.59585 .28019 Mdot
.69093 .32165 Mdot
.57461 .8164 Mdot
.57481 .47791 Mdot
.40743 .15107 Mdot
.39376 .75082 Mdot
.52173 .34427 Mdot
.57052 .45146 Mdot
.44629 .78787 Mdot
.53733 .70776 Mdot
.71178 .40611 Mdot
.3889 .86042 Mdot
.45872 .12269 Mdot
.51419 .37488 Mdot
.38015 .64838 Mdot
.38642 .26617 Mdot
.73348 .53241 Mdot
.44071 .72394 Mdot
.72119 .62502 Mdot
.50195 .68442 Mdot
.65955 .27858 Mdot
.41236 .94308 Mdot
.64285 .2303 Mdot
.73582 .56092 Mdot
.39708 .6474 Mdot
.67849 .75931 Mdot
.44473 .92737 Mdot
.42386 .45009 Mdot
.62541 .84821 Mdot
.71179 .37585 Mdot
.71848 .65388 Mdot
.72874 .51413 Mdot
.42039 .70753 Mdot
.35577 .4605 Mdot
.57914 .70659 Mdot
.48241 .30165 Mdot
.48792 .30661 Mdot
.48771 .67952 Mdot
.46557 .81073 Mdot
.36163 .32636 Mdot
.60907 .30798 Mdot
.43884 .6582 Mdot
.41653 .21719 Mdot
.55321 .48968 Mdot
.48485 .72249 Mdot
.51607 .26751 Mdot
.66286 .55964 Mdot
.43265 .23595 Mdot
.57211 .82024 Mdot
.44831 .7389 Mdot
.60133 .29266 Mdot
.42275 .27741 Mdot
.73449 .57761 Mdot
.50845 .67038 Mdot
.51275 .14212 Mdot
.73183 .46536 Mdot
.40958 .35567 Mdot
.57512 .14169 Mdot
.58773 .7945 Mdot
.51206 .89997 Mdot
.45997 .75335 Mdot
.50903 .77574 Mdot
.63781 .36093 Mdot
.51245 .31513 Mdot
.72206 .55381 Mdot
.6594 .80218 Mdot
.52288 .68239 Mdot
.44697 .39347 Mdot
.37161 .23337 Mdot
.602 .42846 Mdot
.54749 .34749 Mdot
.66519 .78439 Mdot
.57314 .47485 Mdot
.60927 .29263 Mdot
.6442 .63729 Mdot
.61016 .30651 Mdot
.61638 .86443 Mdot
.38937 .50532 Mdot
.55053 .85738 Mdot
.60678 .60822 Mdot
.65174 .24713 Mdot
.47123 .26112 Mdot
.4313 .08977 Mdot
.60565 .54609 Mdot
.60817 .60095 Mdot
.37809 .38644 Mdot
.71827 .64933 Mdot
.50997 .35265 Mdot
.42666 .41635 Mdot
.45737 .05218 Mdot
.48525 .16914 Mdot
.56894 .4427 Mdot
.43229 .82873 Mdot
.49445 .61977 Mdot
.71953 .41611 Mdot
.57949 .14024 Mdot
.59197 .3756 Mdot
.54673 .34495 Mdot
.49984 .91666 Mdot
.53171 .47653 Mdot
.60919 .4593 Mdot
.56163 .21461 Mdot
.48944 .22852 Mdot
.39823 .3427 Mdot
.41387 .843 Mdot
.52638 .22963 Mdot
.4403 .91301 Mdot
.43024 .82013 Mdot
.41807 .38539 Mdot
.58405 .35983 Mdot
.41466 .1286 Mdot
.4373 .71521 Mdot
.54615 .69708 Mdot
.61612 .19341 Mdot
.50292 .23966 Mdot
.44287 .14173 Mdot
.37582 .58377 Mdot
.5342 .53962 Mdot
.42028 .61015 Mdot
.49471 .05069 Mdot
.72658 .4788 Mdot
.56717 .62287 Mdot
.51796 .54999 Mdot
.48761 .80119 Mdot
.49746 .93208 Mdot
.40528 .57735 Mdot
.55288 .84165 Mdot
.40912 .93278 Mdot
.55002 .10857 Mdot
.72365 .51596 Mdot
.56379 .12918 Mdot
.48209 .33126 Mdot
.51636 .06519 Mdot
.63037 .83556 Mdot
.52774 .89386 Mdot
.72238 .54037 Mdot
.74911 .2605 Mdot
.57262 .32305 Mdot
.40353 .71134 Mdot
.61866 .32503 Mdot
.65354 .2526 Mdot
.71977 .61577 Mdot
.4794 .21915 Mdot
.61728 .19753 Mdot
.49561 .1775 Mdot
.45047 .33589 Mdot
.66033 .56582 Mdot
.59489 .63718 Mdot
.65197 .62216 Mdot
.69592 .72939 Mdot
.52157 .39854 Mdot
.53178 .16879 Mdot
.53125 .79444 Mdot
.71407 .43617 Mdot
.53261 .47218 Mdot
.73222 .54442 Mdot
.67208 .75809 Mdot
.52147 .98517 Mdot
.52823 .66021 Mdot
.3964 .33324 Mdot
.52173 .81837 Mdot
.38995 .26245 Mdot
.51441 .76885 Mdot
.45947 .30924 Mdot
.50135 .37415 Mdot
.59779 .63897 Mdot
.72812 .43878 Mdot
.4595 .05265 Mdot
.46921 .25815 Mdot
.66171 .53705 Mdot
.52987 .56446 Mdot
.48462 .68315 Mdot
.64041 .3703 Mdot
.39331 .38069 Mdot
.39635 .62155 Mdot
.52345 .21728 Mdot
.47314 .81207 Mdot
.50521 .19467 Mdot
.6446 .42195 Mdot
.44304 .31032 Mdot
.70108 .36548 Mdot
.54858 .35813 Mdot
.40764 .82928 Mdot
.65319 .48714 Mdot
.51961 .3263 Mdot
.40783 .39233 Mdot
.53903 .96103 Mdot
.72986 .4757 Mdot
.50423 .04998 Mdot
.43265 .89597 Mdot
.55893 .28734 Mdot
.57542 .71047 Mdot
.40255 .80032 Mdot
.60583 .44249 Mdot
.7295 .47707 Mdot
.52697 .98291 Mdot
.54479 .86606 Mdot
.72879 .53263 Mdot
.73161 .55331 Mdot
.7281 .60604 Mdot
.46068 .67972 Mdot
.59617 .4002 Mdot
.72236 .55924 Mdot
.72041 .41343 Mdot
.4542 .66773 Mdot
.57682 .80342 Mdot
.51687 .21777 Mdot
.41283 .23064 Mdot
.59024 .26329 Mdot
.63161 .22424 Mdot
.60874 .29246 Mdot
.50357 .05511 Mdot
.42828 .10146 Mdot
.65058 .57567 Mdot
.48003 .03289 Mdot
.65464 .55824 Mdot
.7178 .61176 Mdot
.69187 .17117 Mdot
.51948 .07993 Mdot
.46583 .11405 Mdot
.50726 .61609 Mdot
.69277 .71134 Mdot
.6134 .52553 Mdot
.4969 .35913 Mdot
.73495 .53411 Mdot
.62442 .71556 Mdot
.45266 .32263 Mdot
.41394 .48382 Mdot
.4428 .20073 Mdot
.55508 .37302 Mdot
.61035 .18036 Mdot
.59426 .78881 Mdot
.62417 .84773 Mdot
.7335 .53875 Mdot
.57624 .69837 Mdot
.4288 .00248 Mdot
.57371 .70982 Mdot
.54333 .69312 Mdot
.53613 .71662 Mdot
.44357 .57695 Mdot
.72617 .43604 Mdot
.72902 .48576 Mdot
.5513 .36556 Mdot
.52279 .34017 Mdot
.53867 .31173 Mdot
.47589 .77062 Mdot
.70461 .70083 Mdot
.42405 .72914 Mdot
.48411 .93269 Mdot
.54628 .43961 Mdot
.56775 .4176 Mdot
.53316 .50108 Mdot
.43901 .77703 Mdot
.55413 .74635 Mdot
.5546 .36351 Mdot
.43279 .62661 Mdot
.67544 .77131 Mdot
.7169 .42147 Mdot
.44739 .4852 Mdot
.48002 .87019 Mdot
.59381 .65636 Mdot
.50492 .13783 Mdot
.53068 .24192 Mdot
.57226 .45676 Mdot
.69616 .70767 Mdot
.37061 .75546 Mdot
.62018 .32225 Mdot
.62708 .09316 Mdot
.58756 .24603 Mdot
.42727 .58785 Mdot
.67516 .31379 Mdot
.72089 .57147 Mdot
.52567 .29334 Mdot
.65237 .49684 Mdot
.52945 .36212 Mdot
.43912 .37915 Mdot
.52287 .74064 Mdot
.51022 .90486 Mdot
.56337 .30847 Mdot
.35634 .53715 Mdot
.49124 .71077 Mdot
.45171 .85278 Mdot
.53593 .79253 Mdot
.45245 .27969 Mdot
.522 .40519 Mdot
.42288 .64434 Mdot
.71985 .40113 Mdot
.52706 .42177 Mdot
.37357 .51263 Mdot
.63789 .36902 Mdot
.53516 .17009 Mdot
.43656 .90827 Mdot
.5669 .81779 Mdot
.58802 .66447 Mdot
.43242 .99266 Mdot
.41439 .45657 Mdot
.72908 .44307 Mdot
.72098 .64265 Mdot
.49469 .23609 Mdot
.51165 .05903 Mdot
.52916 .23703 Mdot
.59821 .60774 Mdot
.41219 .847 Mdot
.595 .27106 Mdot
.57021 .59821 Mdot
.40782 .39079 Mdot
.55139 .755 Mdot
.63818 .83892 Mdot
.39109 .52134 Mdot
.50568 .56015 Mdot
.40561 .70619 Mdot
.57787 .34692 Mdot
.47 .69045 Mdot
.51512 .69578 Mdot
.43647 .82831 Mdot
.39544 .6324 Mdot
.49808 .32143 Mdot
.47318 .16853 Mdot
.67252 .2914 Mdot
.48336 .81553 Mdot
.5498 .19662 Mdot
.57824 .48113 Mdot
.56671 .59497 Mdot
.43693 .59429 Mdot
.65637 .12482 Mdot
.4331 .55252 Mdot
.64385 .38631 Mdot
.58851 .16384 Mdot
.47088 .9341 Mdot
.5765 .50797 Mdot
.39169 .74935 Mdot
.73254 .5169 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool009Cooooo0_l0000>ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0^Oooool009Cooooo0_l0000>ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo002Roooo
o`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00YOooool2o`0000Go
oooo00?o0000ooooooooool0^Oooool00:Gooooo0_l00005ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002Vooooo`;o00001?ooool00ol0003oooooooooo`2i
ooooo`00Y_ooool4o`0000;ooooo00?o0000ooooooooool0^Oooool00:Sooooo0_l00002ooooo`?o
0000^Oooool009gooooo0ol00009ooooo`Ko0000^Oooool009gooooo0ol00009ooooo`Ko0000^Ooo
ool00:cooooo1Ol0002gooooo`00[?ooool00ol0003oooooooooo`02o`000;Oooooo002/ooooo`03
o`000?oooooooooo00;ooooo0_l0002eooooo`00[?ooool00ol0003oooooooooo`02ooooo`;o0000
]Oooool00:cooooo00?o0000ooooooooool0^Oooool009Kooooo0_l0000Dooooo`03o`000?oooooo
oooo0;Wooooo002Fooooo`;o00005?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo00?o
oooo0_l0002dooooo`00[?ooool00ol0003oooooooooo`03ooooo`;o0000]?ooool00:cooooo00?o
0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool009Gooooo0_l0000Eoooo
o`03o`000?oooooooooo0;Wooooo002Eooooo`;o00005Oooool00ol0003oooooooooo`0Wooooo`;o
0000T?ooool009?ooooo0_l0000Gooooo`03o`000?oooooooooo02Oooooo0_l0002@ooooo`00Tooo
ool3o`0001Kooooo0ol0002iooooo`00T_ooool4o`0001Kooooo00?o0000ooooooooool0^Oooool0
09;ooooo0_l0000Hooooo`03o`000?oooooooooo00kooooo0_l0002Yooooo`00[?ooool00ol0003o
ooooooooo`0=ooooo`?o0000ZOooool00:cooooo00?o0000ooooooooool03Oooool2o`000:[ooooo
002Pooooo`;o00002_ooool00ol0003oooooooooo`2iooooo`00ROooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00;ooooo0_l000001Om4A4Co0000o`00
0?lb<S;ogMgM00Gooooo00?o0000ooooooooool0^Oooool008Wooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`04o`0000?ooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2iooooo`00POooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400=ooooo`03ojVYZOmEEEGooooo00;o00001_ooool00ol0003oooooooooo`03ooooo`?o0000
<?ooool2o`0008Oooooo0029ooooo`06o`000?ooooooooooooooool0003ooooo0_l0000;ooooo`03
ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0`ooooo`;o
0000Qoooool008Wooooo00Ko0000ooooooooooooooooo`000?ooool2o`0000_ooooo00?oEEEEolc<
c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool04_ooool2
o`000:Gooooo0029ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool2o`000:Gooooo0029oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool3o`000003ooooool0003o00000;Kooooo0029ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`?o000000?oooooo`000?l000005?oo
ool2o`000:3ooooo002Iooooo`;o00004Oooool01?l0003oooooooooooooool2o`0001;ooooo1?l0
002Pooooo`00VOooool2o`00017ooooo00Co0000oooooooooooooooo0_l0000Booooo`;o00007_oo
ool2o`0008;ooooo002/ooooo`03o`000?oooooooooo03Gooooo0_l00022ooooo`00SOooool2o`00
01gooooo0ol0002iooooo`00SOooool2o`0001gooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool01_ooool2o`000;7ooooo002/
ooooo`03o`000?oooooooooo00Kooooo0_l0000Booooo`;o0000WOooool00:3ooooo0_l0000:oooo
o`03o`000?oooooooooo01[ooooo0_l0002Mooooo`00X?ooool2o`000003ooooool0003o000000;o
oooo0_l00003ooooo`03o`000?oooooooooo00Oooooo0ol0000Eooooo`;o00006oooool2o`0007_o
oooo002Sooooo`;o00000_ooool2o`0000?ooooo00?o0000ooooooooool01oooool3o`0001Gooooo
0_l0000Kooooo`;o0000Noooool00:cooooo0ol0000Oooooo`;o0000V?ooool00:[ooooo0ol0000S
ooooo`;o0000U_ooool00:[ooooo0ol0000Sooooo`;o0000U_ooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Ooo
ool00:cooooo0ol0000Sooooo`;o0000U?ooool00:cooooo0ol0000=ooooo`;o00005?ooool2o`00
09Cooooo002Iooooo`;o00004Oooool3o`0000gooooo0_l0000Dooooo`;o0000U?ooool009Wooooo
0_l0000Aooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo02Cooooo0_l0
002Cooooo`00VOooool2o`00017ooooo00?o0000ooooooooool09?ooool2o`0009?ooooo002Ioooo
o`;o00004Oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o
00002oooool2o`000:Kooooo002@ooooo`;o00004oooool2o`0000Gooooo00?o0000ooooooooool0
0_ooool4o`0000_ooooo0_l0002Vooooo`00T?ooool2o`0000cooooo0_l00002ooooo`;o000000?o
ooooo`000?l000001Oooool00ol0003oooooooooo`02ooooo`Co0000/oooool009kooooo0_l00002
ooooo`;o00002?ooool3o`0002Sooooo0_l0000Mooooo`;o0000L?ooool00:Sooooo0_l00002oooo
o`03o`000?oooooooooo02Sooooo0_l0000Mooooo`;o0000L?ooool008oooooo0_l0000<ooooo`;o
00002Oooool2o`0000;ooooo00?o0000ooooooooool01Oooool2o`0002Gooooo0_l0002;ooooo`00
POooool2o`0000cooooo0_l0000<ooooo`;o00003Oooool00ol0003oooooooooo`05ooooo`;o0000
3_ooool4o`0001?ooooo0_l0002;ooooo`00POooool2o`0001;ooooo0_l0000Cooooo`?o00002?oo
ool2o`0000gooooo1?l0002Pooooo`00UOooool2o`0001?ooooo1Ol00006ooooo`;o0000/Oooool0
097ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo0ol00007ooooo`;o0000/?ooool0097ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00Oooooo0_l0
000@ooooo`;o0000W_ooool008Wooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Wooooo0_l0000Dooooo`;o0000R?oo
ool0097ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0
000_ooooo`;o0000R?ooool0097ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0_ooooo`;o0000R?ooool0097ooooo00Go
410@oooooooooooooooooa0@400;ooooo`;o000000?oooooo`000?l000001_ooool00ol0003ooooo
ooooo`0_ooooo`?o0000Qoooool0097ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`Go0000
1_ooool00ol0003oooooooooo`0`ooooo`;o00007Oooool2o`0006Sooooo0027ooooo`;o00002?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00003ooooo`;o000000?oooooo`000?ooool0
6oooool2o`0003?ooooo0_l0001Xooooo`00Q_ooool3o`00023ooooo0_l000000ooooooo0000oooo
o`02ooooo`?o00005_ooool2o`0001Oooooo0_l00024ooooo`00Q_ooool2o`00027ooooo0_l00000
0ooooooo0000ooooo`02ooooo`?o00006?ooool2o`0001Gooooo0_l00024ooooo`00[?ooool00ol0
003oooooooooo`0Looooo`?o0000V_ooool00:cooooo0ol0000Looooo`?o00004oooool2o`0008Go
oooo002Booooo`;o00000_ooool2o`0000Cooooo0_l0000>ooooo`03o`000?oooooooooo01cooooo
0_l0000Cooooo`?o0000QOooool009;ooooo0_l00002ooooo`;o00001?ooool2o`0000kooooo00?o
0000ooooooooool07?ooool2o`0001?ooooo0_l00026ooooo`00[?ooool00ol0003oooooooooo`0f
ooooo`;o0000POooool00:cooooo00?o0000ooooooooool04?ooool2o`0002?ooooo0ol00021oooo
o`00U_ooool2o`0001Cooooo00?o0000ooooooooool04?ooool2o`0000kooooo0_l0000Cooooo`?o
0000POooool009Kooooo0_l0000Dooooo`03o`000?oooooooooo00Gooooo0_l0000Gooooo`Go0000
4oooool2o`00087ooooo002Eooooo`;o00005Oooool00ol0003oooooooooo`05ooooo`;o00005ooo
ool2o`000003ooooool0003o000001Gooooo0_l0001oooooo`00UOooool2o`0001Gooooo0ol0000h
ooooo`;o0000Ooooool00:Kooooo0_l00004ooooo`03o`000?oooooooooo0;Wooooo0025ooooo`;o
00007oooool4o`0000;ooooo00?o0000ooooooooool08Oooool2o`0009Kooooo0025ooooo`;o0000
4_ooool2o`0000?ooooo0_l00008ooooo`;o00000_ooool00ol0003oooooooooo`0Aooooo`;o0000
3_ooool2o`0009Kooooo002Iooooo`;o00000oooool2o`0000cooooo00?o0000ooooooooool02Ooo
ool2o`0000Kooooo0_l0000>ooooo`;o0000U_ooool008[ooooo0_l0000Pooooo`04o`000?oooooo
ooooooooo`;o00001_ooool2o`0002_ooooo0_l00021ooooo`00R_ooool2o`0000?ooooo0_l0000K
ooooo`04o`000?ooooooooooooooo`;o0000<oooool2o`00087ooooo002:ooooo`;o00000oooool2
o`0000_ooooo0_l0000=ooooo`;o00009_ooool2o`0001Kooooo0_l0001kooooo`00W?ooool2o`00
00gooooo1?l0000Eooooo`;o00003?ooool3o`0001Kooooo0_l0001kooooo`00O_ooool2o`0002co
oooo00?o0000ooooooooool00oooool2o`00013ooooo0ol0000;ooooo`?o00005_ooool2o`0007_o
oooo001nooooo`;o00009_ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`00017ooooo
0_l0002Qooooo`00ROooool2o`0000cooooo0_l0000=ooooo`;o00001?ooool00ol0003ooooooooo
o`0kooooo`;o0000O?ooool008Wooooo0_l0000<ooooo`;o00000_ooool2o`0000oooooo00?o0000
ooooooooool0>oooool2o`0007cooooo002Kooooo`;o00003oooool00ol0003oooooooooo`04oooo
o`;o0000/oooool008[ooooo0_l0000Pooooo`03o`000?oooooooooo00Cooooo0_l0002cooooo`00
R_ooool2o`00023ooooo00?o0000ooooooooool01?ooool2o`0000Kooooo0_l00008ooooo`;o0000
XOooool009;ooooo0_l0000Hooooo`03o`000?oooooooooo00Cooooo0_l00006ooooo`;o00002?oo
ool2o`000:7ooooo002Booooo`;o00006?ooool5o`0000[ooooo0_l00008ooooo`;o0000:?ooool2
o`0007Oooooo0024ooooo`;o00002?ooool2o`0001cooooo00?o0000ooooooooool00_l0000noooo
o`;o0000Moooool008Cooooo0_l00008ooooo`;o00006oooool2o`0000;ooooo0_l0000;ooooo`;o
0000Z_ooool00:_ooooo0_l00002ooooo`;o00001?ooool2o`0000Gooooo0_l00009ooooo`;o0000
4?ooool2o`0008gooooo002/ooooo`03o`000?oooooooooo00Kooooo0_l00007ooooo`;o00001ooo
ool2o`00013ooooo0_l0002=ooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo0_l0
00000olQ8B7oooooooooo`02ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo
00?o0000ooooooooool03Oooool4o`0002kooooo0_l0001hooooo`00ROooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Cooooo0_l000000olQ8B7oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01oooool00omgMgOo0000o`000004ooooo`03o`000?oooooooooo00gooooo0_l0000Kooooo`?o
00004_ooool2o`0007Sooooo0021ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00co
oooo00?oV9RHob4Q8Oo^k^h02Oooool2o`0000Cooooo0_l0000?ooooo`?o00006Oooool3o`0008co
oooo0024ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^
k^h01oooool00omgMgOo<S8booooo`04ooooo`?o000000?oooooo`000?l000002oooool3o`0000[o
oooo0_l0000Uooooo`;o0000MOooool008Wooooo00Go0000ooooooooooooooooo`000009ooooo`;o
00000oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool01?l0
003oooooooooooooool2o`0001Sooooo0_l0000Uooooo`;o0000MOooool008Sooooo0_l00003oooo
o`03oa0@4?oooooooooo00Oooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Yooooo`;o00005oooool2o`0007Gooooo0028ooooo`;o
000000CoV9RHoooooonHV9SoMgMg0oooool2o`0000Kooooo00Go0000okZj^_ooooooV9RHoa0@4004
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0:Oooool2o`000003ooooool0003o
000001Cooooo0_l0001eooooo`00Poooool2o`0000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`;o00001_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oo
oooooooo02cooooo0_l0002;ooooo`00Poooool2o`0000Sooooo0_l0000Mooooo`03o`000?oooooo
oooo0;Wooooo002=ooooo`;o00002oooool2o`00013ooooo00?o0000ooooooooool0^Oooool009[o
oooo0_l0000@ooooo`03o`000?oooooooooo00[ooooo0_l0000iooooo`;o0000L_ooool00:cooooo
0ol00004ooooo`;o00001?ooool2o`00013ooooo0_l0000Wooooo`;o0000L_ooool00:cooooo00?o
0000ooooooooool01?ooool2o`0000cooooo0_l00008ooooo`;o00003oooool2o`0001Kooooo0_l0
001booooo`00[?ooool00ol0003oooooooooo`04ooooo`;o00003?ooool2o`0001Wooooo0_l0000C
ooooo`;o0000MOooool00:cooooo00?o0000ooooooooool01?ooool2o`0003cooooo0_l0001eoooo
o`00[?ooool00ol0003oooooooooo`15ooooo`;o0000L_ooool009?ooooo0_l0000Gooooo`03o`00
0?oooooooooo04Gooooo0ol0001aooooo`00Toooool2o`0001Oooooo00?o0000ooooooooool04ooo
ool2o`0002gooooo0_l000001?oooooo0000o`000?l0001aooooo`00[?ooool00ol0003ooooooooo
o`05ooooo`;o00003?ooool2o`0001Oooooo0_l0000Dooooo`Co0000Loooool008;ooooo0_l0000X
ooooo`?o00001Oooool2o`0002Gooooo0_l0000Fooooo`;o0000Loooool008;ooooo0_l0000Xoooo
o`03o`000?oooooooooo01kooooo0_l0000Tooooo`;o0000Loooool00:cooooo00?o0000oooooooo
ool07_ooool2o`0002Cooooo0_l0001cooooo`00[?ooool00ol0003oooooooooo`0^ooooo`;o0000
ROooool00:cooooo00Co0000oooooooooooooooo0_l0000[ooooo`;o00004oooool2o`0000;ooooo
0_l0001`ooooo`00[?ooool01?l0003oooooooooooooool2o`0000Wooooo0_l0000Pooooo`;o0000
4oooool2o`0000;ooooo0ol0001_ooooo`00[?ooool00ol0003oooooooooo`0<ooooo`;o00001Ooo
ool2o`0000[ooooo0_l0000Wooooo`;o0000Koooool00:cooooo00?o0000ooooooooool04oooool2
o`0000[ooooo0_l0000Wooooo`;o0000Koooool00:cooooo00?o0000ooooooooool0^Oooool008co
oooo0_l00004ooooo`;o00006?ooool3o`0001Cooooo0_l0002Sooooo`00P_ooool2o`0000Sooooo
0_l00004ooooo`;o00006?ooool00ol0003oooooooooo`0Dooooo`;o00002oooool2o`0009Kooooo
0022ooooo`;o00002oooool2o`0001_ooooo00?o0000ooooooooool05?ooool2o`0000_ooooo0_l0
002Fooooo`002Oooool4o`000003oa0@4?oooooooooo01Kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
3oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd03oooool01?o^k^ko<S8bo`000?lb<S82o`0000Cooooo0_l00004ooooo`Go00000_ooool2
o`000005odA4A?l0003o0000oc8b<_oMgMd05_ooool00ol0003oooooooooo`0Dooooo`;o00000_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo0_l000000olQ8B7oooooooooo`02ooooo`Go0000
1?ooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
6?ooool4o`000003oa0@4?oooooooooo01;ooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMg
Molb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo
<S8booooo`0>ooooo`04ogMgMonHV9SooooooiRHV0;o00001?ooool2o`0000Cooooo00GoV9RHob4Q
8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo01Gooooo00?o0000ooooooooool06?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo0_l000000olQ8B7oooooooooo`02ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool06Oooool00ol0
003oooooooooo`0Dooooo`001_l00005ooooo`03o`000?oooooooooo013ooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo
00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`05
ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Sooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool03Oooool01?l@413ooooo
ooooooooool2o`0000oooooo00?o0000ooooooooool03Oooool01Ol@413ooooooooooooooooo410@
00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo
000000oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`0Eooooo`03o`000?oooooooooo01Sooooo00Go
0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0
3_ooool01?l0003oooooooooooooool2o`0000kooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003o
oooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`0Ioooo
o`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?
ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo
00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c00Fooooo`03o`000?oooooooooo00Oooooo0_l0000?ooooo`05o`000?oooooooooo
ooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03ooo
ool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05
o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`06_ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hoooo
o`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooo
oooo017ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo017ooooo00Go
410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
6?ooool3o`0000Oooooo0_l0000<ooooo`;o000000?ooooooa0@4?ooool00_ooool00ol@413ooooo
ooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04Oooool00ol@413ooooo
ooooo`02o`0000cooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00ko
oooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Co
oooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`07ooooo`;o00003?ooool2o`000006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0
003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool04Oooool00omgMgOoV9RHo`000002
o`0000cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
5?ooool000Wooooo00?oEEEEofIVI_l000006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
1Ol00004ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0000G
ooooo`03o`000?oooooooooo01Gooooo0ol000001Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_l0
0004ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o
0000onk^kP0<ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004oooo
o`Co00006Oooool00omEEEGoIVIVo`00000Fooooo`00Soooool2o`0000Wooooo0_l0000@ooooo`03
o`000?oooooooooo01Kooooo0_l0000:ooooo`;o00009?ooool2o`0006oooooo002?ooooo`;o0000
2Oooool2o`00013ooooo00?o0000ooooooooool0;oooool2o`0001Oooooo0_l0001_ooooo`00[?oo
ool00ol0003oooooooooo`0>ooooo`;o00001_ooool2o`0001Oooooo0_l0000Gooooo`;o0000I?oo
ool2o`0000;ooooo0_l00005ooooo`00[?ooool00ol0003oooooooooo`0>ooooo`;o00001_ooool2
o`0003;ooooo0_l0001Rooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1Oooool00:cooooo00?o
0000ooooooooool0;oooool2o`0001Wooooo0_l0001Sooooo`04omgMgOl0003o410@olc<c0Kooooo
0007oooooooo0000C?l0000<ooooo`04onk^k_lQ8B7o410@onk^kPKooooo0007ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`04o`000?oo
oooo0000o`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool2o`0000Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0:ooooo`04ob4Q8OmgMgOoMgMgoc8b<PKooooo0007ooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`04o`00
0?ooooooooooooooo`;o00008oooool00ol0003oooooooooo`0Eooooo`;o00004?ooool00ol0003o
ooooooooo`0Nooooo`;o00001_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool02Oooool2o`0000;ooooo0_l00005ooooo`00Qoooool2o`0002?ooooo
00?o0000ooooooooool05Oooool3o`000:7ooooo0022ooooo`;o0000:?ooool00ol0003ooooooooo
o`0Fooooo`;o0000XOooool008;ooooo0_l0000Xooooo`03o`000?oooooooooo04Kooooo1?l0001_
ooooo`00[?ooool00ol0003oooooooooo`0=ooooo`;o00001oooool2o`0001Wooooo0_l0000Coooo
o`Go0000K_ooool008Sooooo0_l0000Rooooo`03o`000?oooooooooo00gooooo0ol00006ooooo`;o
00006Oooool2o`0001Kooooo0_l0001^ooooo`00R?ooool2o`0002;ooooo0ol0000>ooooo`;o0000
4_ooool2o`0009Gooooo002/ooooo`03o`000?oooooooooo02;ooooo0_l0002Eooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`18ooooo`Co0000KOooool007co
oooo0_l0000^ooooo`03o`000?oooooooooo02;ooooo0_l0000>ooooo`;o00005?ooool4o`0006go
oooo001looooo`;o0000;_ooool00ol0003oooooooooo`08ooooo`;o00006?ooool2o`0000kooooo
0_l0000Booooo`;o00000_ooool2o`0006gooooo002/ooooo`03o`000?oooooooooo00Sooooo0_l0
000looooo`;o00000_ooool2o`0006gooooo002/ooooo`03o`000?oooooooooo01oooooo0_l0000X
ooooo`;o0000K_ooool00:cooooo00?o0000ooooooooool00_ooool2o`0001_ooooo1?l0000Voooo
o`;o0000K_ooool009Gooooo0_l0000Eooooo`?o00000_ooool2o`0001gooooo0_l0000Sooooo`;o
0000LOooool0093ooooo0_l00003ooooo`;o00005Oooool00ol0003oooooooooo`06ooooo`;o0000
1Oooool2o`0003Oooooo0_l000000ooooooo0000o`00001^ooooo`00R?ooool2o`0000Kooooo0_l0
000Jooooo`03o`000?oooooooooo00Kooooo0_l00005ooooo`;o00008Oooool2o`0001Cooooo0_l0
00000ooooooo0000o`00001^ooooo`00R?ooool2o`0002;ooooo0ol0000`ooooo`Co00004_ooool2
o`0000;ooooo0_l0001]ooooo`00[?ooool3o`0000Kooooo0_l0000Xooooo`Co00004_ooool2o`00
00;ooooo0_l0001]ooooo`00[?ooool00ol0003oooooooooo`06ooooo`;o0000:?ooool3o`0001So
oooo0_l0001/ooooo`00[?ooool00ol0003oooooooooo`0aooooo`;o00006?ooool2o`0006cooooo
002<ooooo`;o00007_ooool00ol0003oooooooooo`0Dooooo`?o0000;_ooool2o`0007;ooooo002<
ooooo`;o00002oooool2o`00017ooooo0ol0000Dooooo`?o00005oooool2o`0001Gooooo0_l0001b
ooooo`00S?ooool2o`0000_ooooo0_l0000Aooooo`03o`000?oooooooooo02kooooo0_l0000Joooo
o`;o0000KOooool008cooooo0_l0000Nooooo`03o`000?oooooooooo04[ooooo0_l0001]ooooo`00
Poooool2o`0002Oooooo00?o0000ooooooooool0;_ooool2o`0008Wooooo0022ooooo`?o00003ooo
ool2o`0001Kooooo00?o0000ooooooooool0;_ooool2o`0008Wooooo0022ooooo`;o00004?ooool2
o`0001Kooooo00?o0000ooooooooool0^Oooool009Oooooo0_l0000Cooooo`;o00005?ooool2o`00
0:Cooooo002Gooooo`;o00004oooool2o`0001Cooooo0ol0002Sooooo`00[?ooool3o`0001Cooooo
0_l00009ooooo`?o0000Uoooool00:cooooo00?o0000ooooooooool02_ooool2o`0001?ooooo0ol0
002Gooooo`00[?ooool00ol0003oooooooooo`0:ooooo`;o0000??ooool2o`0006oooooo002Aoooo
o`;o00006Oooool00ol0003oooooooooo`0Mooooo`;o000000?oooooo`000?l000009_ooool2o`00
06oooooo002Aooooo`;o00006Oooool00ol0003oooooooooo`0Mooooo`;o000000?oooooo`000?l0
00008_ooool4o`00077ooooo002/ooooo`04o`000?oooooo0000o`0004?ooooo1?l0001aooooo`00
ROooool01?o^k^ko<S8bo`000?lb<S82o`0000Cooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00Co0000ooooool0003o00004_ooool2o`0000Sooooo0_l0000V
ooooo`;o0000L_ooool008Wooooo0_l000001?ooooooV9RHo`000?l00004ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool00_ooool3o`000003ooooool0
003o000001;ooooo0_l00008ooooo`;o00004?ooool3o`0008Oooooo0029ooooo`;o00000_ooool0
0ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00Co0000oooooooooooooooo1_l0
000Booooo`;o00002?ooool2o`00013ooooo0ol0000Dooooo`;o0000LOooool008Wooooo0_l00002
ooooo`03o`000?oooooooooo00Gooooo0_l00004ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`0Cooooo`;o00006_ooool2o`0001Gooooo0_l0001a
ooooo`00O_ooool2o`0000Wooooo00Go0000ooooooooooooooooo`000007ooooo`;o00001Oooool0
0omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`0_ooooo`;o0000R?ooool007kooooo0_l00009ooooo`;o00000_ooool00ol@413oooooooooo`0=
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0_
ooooo`;o0000R?ooool008Wooooo0_l000000oooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01cooooo0_l0000>
ooooo`;o000000?oooooo`000?l00000R?ooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool07?oo
ool3o`0000gooooo0_l0000Eooooo`;o0000M?ooool00:cooooo00?o0000ooooooooool07Oooool2
o`0002Cooooo0_l000000ooooooo0000o`00001aooooo`00T_ooool2o`0001Sooooo00?o0000oooo
ooooool0A_ooool2o`00077ooooo0024ooooo`;o00001?ooool2o`0000Kooooo0_l0000Hooooo`03
o`000?oooooooooo04Gooooo0_l0001booooo`00Q?ooool2o`0000Cooooo0_l0000Pooooo`?o0000
AOooool2o`0007;ooooo002/ooooo`03o`000?oooooooooo01cooooo0_l0000Sooooo`;o00000_oo
ool2o`0007;ooooo002Gooooo`;o00004_ooool2o`0001kooooo0_l0000Sooooo`;o00000_ooool2
o`0007;ooooo002Gooooo`;o00004_ooool2o`0000Sooooo0_l0000Dooooo`;o0000Voooool00:co
oooo00?o0000ooooooooool01_ooool2o`0001;ooooo0_l0000=ooooo`;o000000?oooooo`000?l0
0000Roooool009cooooo0_l0000>ooooo`03o`000?oooooooooo01[ooooo0_l0000=ooooo`;o0000
00?oooooo`000?l00000Roooool008oooooo0ol0000:ooooo`;o00003_ooool01?l0003oooooo`00
0?l0000[ooooo`;o0000Roooool008oooooo0ol0000Jooooo`04o`000?oooooo0000o`000;Sooooo
002/ooooo`?o0000:Oooool2o`0008kooooo002Oooooo`;o00001oooool2o`0000;ooooo00?o0000
ooooooooool0:Oooool2o`0008kooooo0025ooooo`;o00006?ooool2o`0000Gooooo1?l00002oooo
o`03o`000?oooooooooo00Cooooo0_l0002cooooo`00QOooool2o`0001oooooo0_l00004ooooo`;o
00001Oooool2o`000;?ooooo002/ooooo`;o0000^_ooool008_ooooo0_l0000Eooooo`;o00002?oo
ool00ol0003oooooooooo`0:ooooo`;o0000[Oooool008_ooooo0_l0000Eooooo`;o00002?ooool0
0ol0003oooooooooo`0:ooooo`?o0000[?ooool00:cooooo00?o0000ooooooooool00_ooool2o`00
00Oooooo0ol00008ooooo`;o0000XOooool00:cooooo0ol00002ooooo`;o00002?ooool2o`0000So
oooo0_l0000Xooooo`;o0000Moooool00:cooooo00?o0000ooooooooool0@?ooool2o`0007Oooooo
002<ooooo`;o00007_ooool00ol0003oooooooooo`0Gooooo`;o0000X?ooool008cooooo0_l00003
ooooo`;o00006Oooool00ol0003oooooooooo`09ooooo`;o00002_ooool4o`0000gooooo0_l0000E
ooooo`;o0000N_ooool008cooooo0_l00003ooooo`;o00005_ooool2o`000003ooooool0003ooooo
00[ooooo0_l0000:ooooo`;o00003oooool2o`0001Cooooo0ol0001jooooo`00S?ooool2o`0000Wo
oooo0_l0000@ooooo`;o000000?oooooo`000?ooool09oooool2o`0001Cooooo0_l0001kooooo`00
Uoooool2o`0001?ooooo00?o0000ooooooooool02?ooool2o`0001_ooooo0ol0002Aooooo`00Yooo
ool2o`0000?ooooo00?o0000ooooooooool02?ooool2o`0001_ooooo0_l0002Booooo`00V?ooool2
o`0000gooooo0_l00003ooooo`?o00009?ooool2o`0009?ooooo002Hooooo`;o00004_ooool00ol0
003oooooooooo`0Tooooo`;o0000Toooool009;ooooo0_l0000Hooooo`03o`000?oooooooooo03go
oooo0_l0001jooooo`00T_ooool2o`0001Sooooo00?o0000ooooooooool0?Oooool2o`0007[ooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002Jooooo`;o00003oooool2o`0000Kooooo0_l0002c
ooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo0_l000000olQ8B7oooooooooo`03
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool3o`0000Gooooo0_l0000fooooo`;o0000Nooo
ool0097ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8boooo
o`04ooooo`;o00003oooool2o`0002cooooo0_l0001kooooo`00R?ooool2o`0000Oooooo00Go410@
oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03_oo
ool2o`0000oooooo0_l0002Hooooo`00R?ooool2o`0000Oooooo00Go0000ooooooooooooooooo`00
000?ooooo`03ogMgMolb<S;ooooo00?o000000Coooooo`000?l0003o00007oooool2o`0009Sooooo
0021ooooo`;o00001Oooool2o`0000Oooooo00Go0000ooooooooooooooooo`000008ooooo`;o0000
0_ooool01_l0003o8B4Qo`000?lb<S;oc<c<ooooo`?o000000?oooooo`000?ooool03oooool2o`00
0:Wooooo0021ooooo`;o00001Oooool2o`0000Oooooo00Go410@oooooooooooooooooa0@4008oooo
o`;o00000_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00kooooo0_l0000Uoooo
o`;o0000P_ooool0097ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0=Oooool4o`00083ooooo002Aooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0=oooool2o`00083ooooo002/ooooo`03
o`000?oooooooooo00_ooooo0_l0002/ooooo`00Y?ooool2o`0000Kooooo00Co0000oooooooooooo
oooo0_l00008ooooo`;o0000[?ooool00:Cooooo0_l00006ooooo`04o`000?ooooooooooooooo`;o
0000<oooool2o`00087ooooo002Gooooo`;o00004oooool5o`0003Cooooo0_l00021ooooo`00Uooo
ool2o`0001?ooooo00?o0000ooooooooool00_l0002gooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`0cooooo`;o0000Q?ooool009[ooooo0_l0000@ooooo`03
o`000?oooooooooo00Sooooo0_l0000Booooo`;o00005Oooool2o`0008Cooooo002Jooooo`;o0000
4?ooool00ol0003oooooooooo`08ooooo`;o00004_ooool2o`0009_ooooo002/ooooo`03o`000?oo
oooooooo00Oooooo0ol0000?ooooo`?o0000WOooool00:cooooo00?o0000ooooooooool01oooool3
o`0000oooooo0ol0000Eooooo`;o0000Q_ooool008_ooooo0_l0000Jooooo`;o00000oooool3o`00
037ooooo0_l00026ooooo`00Roooool2o`0001[ooooo0_l00003ooooo`03o`000?oooooooooo01Ko
oooo0_l0000Iooooo`;o0000Q_ooool00:cooooo00?o0000ooooooooool05_ooool2o`0001Wooooo
0_l00026ooooo`00Roooool2o`0000Oooooo0_l0000Fooooo`03o`000?oooooooooo0;Wooooo002;
ooooo`;o00001oooool2o`0000Wooooo0ol000000ooooooo0000o`000007ooooo`03o`000?oooooo
oooo00Cooooo0_l0002cooooo`00Woooool6o`000003ooooool0003o000000Cooooo00?o0000oooo
ooooool01?ooool2o`0000oooooo0_l0002Rooooo`00Q?ooool2o`0001cooooo0_l00002ooooo`;o
00001?ooool00ol0003oooooooooo`03ooooo`?o00003Oooool4o`000:;ooooo0024ooooo`;o0000
3oooool2o`0001Gooooo00?o0000ooooooooool00oooool3o`0000gooooo0ol0002Sooooo`00UOoo
ool2o`0001Gooooo0ol0000Dooooo`;o0000Xoooool009Oooooo0_l0000Cooooo`03o`000?oooooo
oooo0;Wooooo002=ooooo`;o00001_ooool4o`0001?ooooo00?o0000ooooooooool0^Oooool008go
oooo0_l00006ooooo`;o00005Oooool00ol0003oooooooooo`2iooooo`00Uoooool2o`0001?ooooo
00?o0000ooooooooool0:?ooool2o`0008oooooo002Gooooo`;o00004oooool00ol0003ooooooooo
o`0Xooooo`Co0000SOooool008oooooo0_l0000Kooooo`03o`000?oooooooooo00kooooo0_l0000J
ooooo`;o0000SOooool008oooooo0_l0000Kooooo`03o`000?oooooooooo00kooooo0_l0002Yoooo
o`00Soooool2o`0001_ooooo00?o0000ooooooooool09_ooool2o`00097ooooo002?ooooo`;o0000
2oooool2o`0000kooooo0ol0000Vooooo`;o0000TOooool009cooooo0_l0000>ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00gooooo0_l0000Fooooo`;o0000T_ooool0
08Oooooo0_l0000Sooooo`03o`000?oooooooooo00gooooo0_l0000Fooooo`;o0000T_ooool008Oo
oooo0_l0000Pooooo`;o000000?oooooo`000?ooool02oooool2o`0001Oooooo0_l0002Dooooo`00
ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`;o000000?oooooo`000?ooool02oooool3o`00
01Kooooo0_l0002Dooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46oooo
o`03oeEEEOnYZJWooooo00Oooooo0_l00005ooooo`03o`000?oooooooooo00_ooooo0_l0002/oooo
o`00ROooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool01oooool2o`00
00Gooooo00?o0000ooooooooool0^Oooool008Wooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`000;Wooooo0029ooooo`05
o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01Oooool00ol0003oooooooooo`2iooooo`00ROooool01Ol@413ooooooooooooooooo
410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0;Wooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooo
oooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2iooooo`00ROooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo0_l00005ooooo`Go00001?ooool4o`0000Kooooo00?o
0000ooooooooool0^Oooool009;ooooo0_l0000Hooooo`03o`000?oooooooooo0;Wooooo002Doooo
o`;o00005_ooool00ol0003oooooooooo`06ooooo`;o0000/Oooool009Cooooo0ol0000Eooooo`03
o`000?oooooooooo00Kooooo0_l0002aooooo`00UOooool2o`0001Gooooo0ol000000ooooooo0000
o`00002fooooo`00[?ooool01?l0003oooooooooooooool2o`000;Kooooo002/ooooo`03o`000?oo
oooooooo00;o0000]oooool009Oooooo0ol0000Booooo`03o`000?oooooooooo00;o0000]oooool0
09Oooooo0ol0000Booooo`03o`000?oooooooooo0;Wooooo002Hooooo`;o00004_ooool00ol0003o
ooooooooo`2iooooo`00[?ooool2o`000;[ooooo002/ooooo`;o0000^_ooool009Sooooo0_l0000B
ooooo`?o0000^Oooool009Sooooo0ol0000Aooooo`03o`000?oooooooooo0;Wooooo002Iooooo`;o
00004Oooool00ol0003oooooooooo`2iooooo`00S_ooool2o`0001;ooooo0_l00002ooooo`;o0000
0oooool2o`000;_ooooo002>ooooo`;o00003Oooool2o`0000?ooooo0_l00002ooooo`;o00000ooo
ool2o`000;_ooooo002Mooooo`;o00003Oooool00ol0003oooooooooo`2iooooo`00Soooool2o`00
01_ooooo00?o0000ooooooooool0^Oooool008oooooo0_l0000Kooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool0093ooooo0_l0000J
ooooo`03o`000?oooooooooo0;Wooooo002@ooooo`;o00006_ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`09ooooo`;o0000[_ooool00:cooooo00?o0000ooooooooool0
2Oooool2o`000:kooooo002/ooooo`03o`000?oooooooooo00Oooooo0_l0002`ooooo`00[?ooool0
0ol0003oooooooooo`07ooooo`;o0000/?ooool00:cooooo00?o0000ooooooooool0^Oooool00:co
oooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`05ooooo`;o0000/_ooool00:cooooo00?o0000ooooooooool01?ooool3o`000;;ooooo002/oooo
o`03o`000?oooooooooo00Cooooo0_l0002cooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
UOooool2o`0000_ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0;Wooooo
002Eooooo`;o00003Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo002T
ooooo`03o`000?oooooooooo00Gooooo0ol0002iooooo`00Y?ooool00ol0003oooooooooo`31oooo
o`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?oo
ool00ol0003oooooooooo`31ooooo`00X_ooool00omEEEGoIVIVo`000033ooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Z_ooool01?l@413o0000o`000?l0
002jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2joooo
o`00Zoooool01_l0003oMgMgo`000?l0003oEEEEonk^k[Oooooo002[ooooo`06o`000?mEEEGok^k^
oooooomgMgOoEEEE]oooool00:_ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`2e
ooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo0;Gooooo002[ooooo`06
o`000?mEEEGok^k^oooooomgMgOoIVIV]oooool00:[ooooo00?o410@o`000?mgMgL00_l000000omV
IVKok^k^ooooo`2fooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.43491 .14485 Mdot
.56774 .20235 Mdot
.44465 .48999 Mdot
.53005 .35374 Mdot
.56721 .64435 Mdot
.45117 .86925 Mdot
.45771 .3447 Mdot
.63817 .19707 Mdot
.53217 .07722 Mdot
.45325 .76013 Mdot
.41709 .38071 Mdot
.68507 .28873 Mdot
.66354 .42181 Mdot
.41754 .62467 Mdot
.70271 .35233 Mdot
.55467 .55256 Mdot
.60628 .42095 Mdot
.66588 .4327 Mdot
.56322 .37135 Mdot
.58516 .82445 Mdot
.66629 .47629 Mdot
.62483 .31687 Mdot
.64394 .385 Mdot
.66928 .4657 Mdot
.72814 .44062 Mdot
.40483 .62151 Mdot
.46481 .21736 Mdot
.56126 .37263 Mdot
.55139 .87343 Mdot
.58453 .2351 Mdot
.66296 .54955 Mdot
.51739 .05739 Mdot
.62187 .18219 Mdot
.61126 .56638 Mdot
.59717 .66419 Mdot
.5928 .79322 Mdot
.37324 .56663 Mdot
.53617 .305 Mdot
.48694 .94474 Mdot
.69072 .29323 Mdot
.72844 .41353 Mdot
.60791 .61258 Mdot
.53342 .80842 Mdot
.43839 .13098 Mdot
.39432 .33164 Mdot
.50601 .7963 Mdot
.41528 .58219 Mdot
.43568 .06102 Mdot
.46941 .15497 Mdot
.53548 .88879 Mdot
.43709 .06021 Mdot
.45235 .94346 Mdot
.3558 .60125 Mdot
.56046 .75388 Mdot
.5693 .74355 Mdot
.58152 .13306 Mdot
.6489 .21659 Mdot
.60391 .40098 Mdot
.38684 .24937 Mdot
.38846 .41195 Mdot
.48025 .82517 Mdot
.72487 .6588 Mdot
.46772 .94541 Mdot
.44656 .70219 Mdot
.63683 .21696 Mdot
.54562 .08732 Mdot
.45733 .76397 Mdot
.55324 .5406 Mdot
.53215 .29063 Mdot
.6706 .5094 Mdot
.61039 .40942 Mdot
.52077 .4582 Mdot
.43782 .72022 Mdot
.49966 .74948 Mdot
.46772 .94534 Mdot
.49775 .39452 Mdot
.35565 .59733 Mdot
.4186 .70498 Mdot
.47996 .95327 Mdot
.47675 .16431 Mdot
.64509 .66218 Mdot
.58249 .23382 Mdot
.51675 .31878 Mdot
.6077 .61932 Mdot
.60391 .15119 Mdot
.55814 .54326 Mdot
.56329 .65924 Mdot
.52595 .74876 Mdot
.59035 .34755 Mdot
.55172 .55584 Mdot
.72893 .45429 Mdot
.5288 .98791 Mdot
.42022 .48065 Mdot
.52611 .75568 Mdot
.42183 .54807 Mdot
.56954 .94426 Mdot
.42042 .6468 Mdot
.46301 .03471 Mdot
.35359 .53346 Mdot
.58895 .33627 Mdot
.46702 .10258 Mdot
.56501 .28144 Mdot
.68808 .30208 Mdot
.46945 .09635 Mdot
.66374 .59411 Mdot
.60898 .58806 Mdot
.61632 .45501 Mdot
.57485 .41728 Mdot
.42026 .47502 Mdot
.66927 .52375 Mdot
.43563 .72098 Mdot
.52002 .32068 Mdot
.51525 .0561 Mdot
.60713 .77859 Mdot
.43785 .37002 Mdot
.44868 .80429 Mdot
.54973 .08573 Mdot
.53168 .06786 Mdot
.37321 .51595 Mdot
.66339 .42715 Mdot
.73877 .59728 Mdot
.65933 .46427 Mdot
.55134 .87545 Mdot
.67011 .51938 Mdot
.54272 .40447 Mdot
.58733 .81244 Mdot
.6063 .89703 Mdot
.54716 .18255 Mdot
.51229 .35548 Mdot
.64052 .36307 Mdot
.50571 .12298 Mdot
.70291 .33354 Mdot
.45205 .87344 Mdot
.50597 .85323 Mdot
.51606 .92186 Mdot
.39038 .76669 Mdot
.56396 .85192 Mdot
.44005 .72631 Mdot
.64872 .22769 Mdot
.70452 .35237 Mdot
.67967 .76754 Mdot
.46114 .25679 Mdot
.54536 .31928 Mdot
.6063 .41884 Mdot
.59839 .79951 Mdot
.58373 .12562 Mdot
.5757 .02305 Mdot
.57826 .491 Mdot
.51504 .77213 Mdot
.74821 .54364 Mdot
.55287 .25555 Mdot
.48686 .20945 Mdot
.67036 .46493 Mdot
.51601 .42179 Mdot
.39414 .63297 Mdot
.39972 .81132 Mdot
.46394 .94698 Mdot
.55809 .09827 Mdot
.37265 .53008 Mdot
.39757 .80219 Mdot
.406 .35542 Mdot
.48823 .9514 Mdot
.72343 .36782 Mdot
.61217 .75112 Mdot
.51928 .82638 Mdot
.46859 .10523 Mdot
.57959 .12165 Mdot
.66117 .6164 Mdot
.52597 .27791 Mdot
.41344 .87052 Mdot
.55007 .8638 Mdot
.43685 .32862 Mdot
.5111 .25146 Mdot
.55367 .68216 Mdot
.58044 .50776 Mdot
.63422 .20611 Mdot
.58007 .93082 Mdot
.39615 .65272 Mdot
.44237 .35494 Mdot
.52835 .90135 Mdot
.44312 .93736 Mdot
.70644 .33241 Mdot
.53495 .6619 Mdot
.7312 .42502 Mdot
.53572 .48442 Mdot
.53098 .07858 Mdot
.60293 .89923 Mdot
.49497 .03084 Mdot
.72018 .36092 Mdot
.52446 .82586 Mdot
.74221 .55931 Mdot
.60049 .79661 Mdot
.47517 .73411 Mdot
.7247 .64821 Mdot
.62213 .17585 Mdot
.74003 .45388 Mdot
.69439 .31413 Mdot
.53401 .73707 Mdot
.62178 .50659 Mdot
.43009 .51057 Mdot
.42999 .48543 Mdot
.52282 .48831 Mdot
.56369 .64881 Mdot
.49227 .10952 Mdot
.51809 .64349 Mdot
.42591 .81649 Mdot
.50908 .28968 Mdot
.53785 .53311 Mdot
.41771 .36969 Mdot
.64672 .35964 Mdot
.42652 .74203 Mdot
.66021 .62024 Mdot
.53848 .64262 Mdot
.47861 .10432 Mdot
.43771 .77627 Mdot
.72553 .37761 Mdot
.53661 .47038 Mdot
.38969 .41184 Mdot
.67797 .26536 Mdot
.45765 .81687 Mdot
.4068 .14929 Mdot
.66553 .5945 Mdot
.63205 .69997 Mdot
.5429 .61534 Mdot
.57933 .57574 Mdot
.54218 .16093 Mdot
.42829 .37552 Mdot
.70358 .35381 Mdot
.74027 .60218 Mdot
.55584 .48239 Mdot
.45781 .64543 Mdot
.53339 .22846 Mdot
.45131 .23163 Mdot
.73895 .58439 Mdot
.52308 .27485 Mdot
.48638 .09728 Mdot
.65911 .43729 Mdot
.49277 .10785 Mdot
.72215 .66443 Mdot
.49469 .87275 Mdot
.65348 .65738 Mdot
.61007 .40822 Mdot
.51059 .04713 Mdot
.42366 .56814 Mdot
.3949 .77954 Mdot
.58409 .34609 Mdot
.60855 .40095 Mdot
.47117 .94771 Mdot
.738 .44933 Mdot
.43666 .37839 Mdot
.46719 .72914 Mdot
.38105 .67385 Mdot
.40055 .52684 Mdot
.50602 .2427 Mdot
.56671 .75561 Mdot
.50341 .42249 Mdot
.64598 .21611 Mdot
.40896 .1337 Mdot
.50221 .1756 Mdot
.44997 .23402 Mdot
.6265 .71666 Mdot
.48274 .2913 Mdot
.55291 .2593 Mdot
.42017 .19105 Mdot
.41261 .4957 Mdot
.45727 .8692 Mdot
.57218 .82819 Mdot
.41027 .33218 Mdot
.59476 .79563 Mdot
.56415 .7567 Mdot
.4623 .77337 Mdot
.48804 .16414 Mdot
.40697 .84382 Mdot
.53304 .6709 Mdot
.58498 .49708 Mdot
.45488 .03684 Mdot
.41219 .43434 Mdot
.40374 .71781 Mdot
.5148 .92006 Mdot
.51004 .33962 Mdot
.51097 .72035 Mdot
.37265 .51116 Mdot
.6781 .2788 Mdot
.57632 .42287 Mdot
.49796 .35027 Mdot
.57008 .60636 Mdot
.63035 .73223 Mdot
.50698 .78933 Mdot
.64954 .64165 Mdot
.59971 .90234 Mdot
.3868 .25478 Mdot
.69004 .31596 Mdot
.39743 .19429 Mdot
.43663 .50555 Mdot
.37247 .41251 Mdot
.72459 .63556 Mdot
.64528 .69386 Mdot
.69853 .34037 Mdot
.61331 .0605 Mdot
.46328 .16283 Mdot
.53828 .80991 Mdot
.50867 .12503 Mdot
.51457 .0526 Mdot
.72608 .41577 Mdot
.41274 .54157 Mdot
.45746 .03619 Mdot
.40014 .4798 Mdot
.44448 .64262 Mdot
.64666 .36582 Mdot
.60976 .43718 Mdot
.66083 .42216 Mdot
.74768 .52939 Mdot
.45078 .31936 Mdot
.39688 .32133 Mdot
.60902 .59444 Mdot
.64854 .23617 Mdot
.48196 .28806 Mdot
.70999 .34442 Mdot
.73532 .55809 Mdot
.67554 .78517 Mdot
.55231 .46021 Mdot
.4556 .87927 Mdot
.60907 .61837 Mdot
.44154 .92276 Mdot
.58195 .56885 Mdot
.43671 .60905 Mdot
.44186 .41216 Mdot
.61338 .43897 Mdot
.66363 .23878 Mdot
.38069 .66448 Mdot
.42345 .57762 Mdot
.63653 .33705 Mdot
.51566 .36446 Mdot
.52288 .49666 Mdot
.54853 .1703 Mdot
.46662 .88247 Mdot
.51874 .8275 Mdot
.40692 .34776 Mdot
.56662 .6354 Mdot
.37111 .77932 Mdot
.402 .43396 Mdot
.57338 .22195 Mdot
.4405 .68057 Mdot
.60727 .16548 Mdot
.45555 .22863 Mdot
.56888 .84321 Mdot
.60804 .28714 Mdot
.43191 .34142 Mdot
.46602 .81656 Mdot
.68344 .76103 Mdot
.68014 .2757 Mdot
.37052 .46967 Mdot
.58827 .80312 Mdot
.44035 .19563 Mdot
.61961 .51047 Mdot
.56153 .84804 Mdot
.54283 .24249 Mdot
.68033 .27707 Mdot
.68013 .78291 Mdot
.65121 .66606 Mdot
.70184 .33263 Mdot
.71294 .35331 Mdot
.73052 .40604 Mdot
.51995 .56289 Mdot
.51625 .2002 Mdot
.70605 .35924 Mdot
.64578 .21343 Mdot
.51756 .58201 Mdot
.65819 .60342 Mdot
.40648 .37697 Mdot
.42965 .82974 Mdot
.45722 .10955 Mdot
.4814 .03167 Mdot
.48579 .09752 Mdot
.37176 .47145 Mdot
.3981 .79021 Mdot
.64085 .37567 Mdot
.37194 .57912 Mdot
.63794 .35824 Mdot
.7225 .41176 Mdot
.37563 .39533 Mdot
.39273 .62355 Mdot
.5137 .41609 Mdot
.7373 .51134 Mdot
.58361 .32553 Mdot
.43951 .43488 Mdot
.7086 .33411 Mdot
.67065 .51556 Mdot
.44111 .6359 Mdot
.48468 .77011 Mdot
.41663 .70536 Mdot
.4659 .21357 Mdot
.44501 .04499 Mdot
.66978 .58881 Mdot
.72326 .64773 Mdot
.709 .33875 Mdot
.61559 .49837 Mdot
.37638 .80936 Mdot
.61763 .50982 Mdot
.58058 .49312 Mdot
.58278 .51662 Mdot
.4986 .62058 Mdot
.66058 .23604 Mdot
.68333 .28576 Mdot
.46016 .22167 Mdot
.43615 .32493 Mdot
.43527 .26539 Mdot
.55221 .59244 Mdot
.74494 .50083 Mdot
.53894 .73019 Mdot
.61947 .73857 Mdot
.48243 .25237 Mdot
.49479 .21857 Mdot
.49362 .3032 Mdot
.55057 .69897 Mdot
.61267 .54635 Mdot
.46215 .2129 Mdot
.51195 .66497 Mdot
.74397 .57131 Mdot
.64549 .22147 Mdot
.47774 .62373 Mdot
.59226 .68108 Mdot
.61635 .45636 Mdot
.38961 .44757 Mdot
.41417 .31086 Mdot
.51496 .25676 Mdot
.73923 .50767 Mdot
.55578 .96359 Mdot
.50908 .12225 Mdot
.44876 .11169 Mdot
.50451 .69045 Mdot
.56068 .11379 Mdot
.70948 .37147 Mdot
.42541 .32198 Mdot
.61111 .29684 Mdot
.36529 .73056 Mdot
.4446 .29391 Mdot
.45638 .68282 Mdot
.57912 .54064 Mdot
.63216 .70486 Mdot
.45048 .18294 Mdot
.53699 .51451 Mdot
.57569 .71704 Mdot
.61294 .59253 Mdot
.43178 .64614 Mdot
.45279 .31664 Mdot
.51818 .71091 Mdot
.6403 .20113 Mdot
.46048 .29637 Mdot
.4997 .94013 Mdot
.5455 .16902 Mdot
.39788 .30625 Mdot
.59269 .80174 Mdot
.65401 .61779 Mdot
.6138 .46447 Mdot
.62109 .88128 Mdot
.47863 .77402 Mdot
.6663 .24307 Mdot
.73804 .44265 Mdot
.41313 .47113 Mdot
.37147 .43484 Mdot
.41261 .31846 Mdot
.60131 .40774 Mdot
.57351 .83661 Mdot
.46438 .10294 Mdot
.56949 .39821 Mdot
.46569 .81696 Mdot
.61339 .555 Mdot
.73375 .63892 Mdot
.49781 .86176 Mdot
.48998 .36841 Mdot
.53659 .79953 Mdot
.47701 .16277 Mdot
.52279 .53846 Mdot
.55344 .49578 Mdot
.56651 .74182 Mdot
.52139 .83203 Mdot
.43102 .43784 Mdot
.40303 .57967 Mdot
.54908 .0914 Mdot
.57297 .62443 Mdot
.40928 .23931 Mdot
.53069 .28113 Mdot
.5647 .39497 Mdot
.50383 .64679 Mdot
.49553 .67157 Mdot
.55838 .18631 Mdot
.42214 .10235 Mdot
.61192 .7537 Mdot
.53969 .30797 Mdot
.5501 .872 Mdot
.6993 .3169 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o00005_ooool2o`000:7ooooo002/ooooo`03o`000?oooooo
oooo01Kooooo0_l0002Qooooo`00YOooool2o`0000?ooooo0ol0002kooooo`00Woooool2o`0000Co
oooo0_l00003ooooo`?o0000^oooool009gooooo1?l0000;ooooo`03o`000?oooooooooo0;Wooooo
002Mooooo`?o00003?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00VOooool2o`00017ooooo00?o0000ooooooooool00_l0002gooooo`00VOooool2o`00017o
oooo00?o0000ooooooooool00_l0002gooooo`00[?ooool3o`000003ooooool0003o00000;Kooooo
002/ooooo`04o`000?ooooooooooooooo`?o0000]Oooool00:cooooo00?o0000ooooooooool00_oo
ool2o`000;Gooooo002Fooooo`?o00004oooool00ol0003oooooooooo`02ooooo`;o00007_ooool2
o`0009Gooooo002Fooooo`?o00004oooool00ol0003oooooooooo`0Rooooo`;o0000UOooool00:co
oooo00?o0000ooooooooool01oooool2o`000;3ooooo002/ooooo`03o`000?oooooooooo00Oooooo
0_l0002`ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`0000Oooooo0_l0002`
ooooo`00[?ooool00ol0003oooooooooo`07ooooo`;o0000/?ooool00:cooooo00?o0000oooooooo
ool01oooool2o`000;3ooooo002/ooooo`03o`000?oooooooooo00gooooo0_l0002Zooooo`00[?oo
ool00ol0003oooooooooo`0<ooooo`?o0000Z_ooool00:cooooo00?o0000ooooooooool03?ooool3
o`000:[ooooo002/ooooo`03o`000?oooooooooo00gooooo0_l0002Zooooo`00XOooool2o`0000Co
oooo0_l00003ooooo`03o`000?oooooooooo013ooooo0_l0002Wooooo`00XOooool2o`0000Cooooo
0_l00003ooooo`?o00004?ooool2o`000:Oooooo002Booooo`;o00003?ooool3o`0000;ooooo0_l0
0005ooooo`03o`000?oooooooooo0;Wooooo002Booooo`;o00003?ooool3o`0000;ooooo0_l00005
ooooo`03o`000?oooooooooo0;Wooooo002Mooooo`;o00000_ooool2o`0000Kooooo0_l000000ooo
oooo0000ooooo`2jooooo`00Voooool4o`0000[ooooo0_l000000ooooooo0000ooooo`2jooooo`00
Voooool2o`0000oooooo00?o0000ooooooooool04Oooool2o`000:Kooooo0029ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000
o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool04Oooool2o`000:Kooooo0029ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo00;o00005Oooool2o`000:3ooooo0021ooooo`Ko0000
0_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003o
ooooooooo`03ooooo`Go00005Oooool3o`0009oooooo0029ooooo`05o`000?ooooooooooooooool0
00003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo1?l0000Gooooo`;o
0000Woooool008Wooooo00Go0000ooooooooooooooooo`000009ooooo`;o00000oooool00omEEEGo
c<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2ioooo
o`00ROooool01Ol@413ooooooooooooooooo410@00;o00001oooool2o`0000?ooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Oooooo0_l0002Poooo
o`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00;o00002Oooool01Ol@413ooooooooooooooooo
<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Gooooo`;o0000X?ooool0
08Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool009Kooooo0_l0000Dooooo`03
o`000?oooooooooo0;Wooooo002=ooooo`;o00001oooool2o`0001Cooooo00?o0000ooooooooool0
^Oooool008gooooo0_l0000Mooooo`?o00007oooool2o`0009Sooooo002Qooooo`;o00002Oooool0
0ol0003oooooooooo`0Oooooo`;o0000V?ooool00:7ooooo0_l00009ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo00[ooooo0_l0002]ooooo`00Woooool2o`0000?ooooo
0_l00002ooooo`;o00000_ooool00ol0003oooooooooo`0:ooooo`;o0000[Oooool009oooooo0_l0
0003ooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooooooool08?ooool2o`0009Oooooo002/
ooooo`03o`000?oooooooooo00cooooo0ol0000Aooooo`;o0000Uoooool00:cooooo00?o0000oooo
ooooool03?ooool3o`000:[ooooo002/ooooo`?o00009Oooool2o`0009;ooooo002/ooooo`;o0000
9_ooool2o`0009;ooooo002Kooooo`;o00003oooool00ol0003oooooooooo`0<ooooo`;o00005ooo
ool2o`0009;ooooo002Kooooo`;o00003oooool00ol0003oooooooooo`0<ooooo`;o00000_ooool2
o`0001?ooooo0_l0002Booooo`00[?ooool00ol0003oooooooooo`0@ooooo`;o0000Yoooool0097o
oooo0_l0000Iooooo`03o`000?oooooooooo0;Wooooo002:ooooo`;o00001Oooool2o`0001Wooooo
00?o0000ooooooooool0^Oooool008[ooooo0_l0000<ooooo`;o00004_ooool00ol0003ooooooooo
o`0Zooooo`;o0000SOooool009Sooooo0_l0000Booooo`?o00000_ooool2o`0002Kooooo0ol0002<
ooooo`00[?ooool00ol0003oooooooooo`02ooooo`;o00003oooool2o`0001Kooooo0_l0002<oooo
o`00[?ooool00ol0003oooooooooo`0Cooooo`;o00005?ooool2o`0008kooooo002Wooooo`;o0000
0oooool00ol0003oooooooooo`0Yooooo`;o0000S_ooool009oooooo0ol00005ooooo`;o00000ooo
ool00ol0003oooooooooo`0]ooooo`;o0000R_ooool009oooooo0ol0000:ooooo`03o`000?oooooo
oooo02gooooo0ol00029ooooo`00X?ooool2o`0000Sooooo0ol0000/ooooo`;o000000Coooooo`00
0?l0003o0000ROooool009kooooo1?l00008ooooo`?o00005oooool2o`0001?ooooo0_l000000ooo
oooo0000o`00002:ooooo`00W_ooool2o`0000cooooo0ol0000Eooooo`;o00005_ooool2o`0008[o
oooo002Mooooo`;o00003Oooool00ol0003oooooooooo`08ooooo`;o00009?ooool2o`0008Wooooo
002Kooooo`Co00003Oooool00ol0003oooooooooo`08ooooo`;o00009?ooool2o`0008Wooooo002K
ooooo`;o00003oooool00ol0003oooooooooo`0Hooooo`;o0000Woooool009_ooooo0_l0000?oooo
o`03o`000?oooooooooo01Sooooo0_l0000Dooooo`;o00000_ooool2o`0008Gooooo002>ooooo`;o
00007?ooool00ol0003oooooooooo`0Hooooo`;o00005?ooool2o`0000;ooooo0ol00024ooooo`00
S_ooool2o`000006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`04o`000?oooooo0000o`0000[ooooo0_l0000Vooooo`;o0000Q?oo
ool0097ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8boooo
o`04ooooo`04o`000?oooooo0000o`0000[ooooo0_l0000Vooooo`;o0000Q?ooool008Kooooo0_l0
00000ooooooo0000o`000004o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0^Oooool008Kooooo0_l00009ooooo`05o`000?oo
ooooooooooooool000003oooool00omgMgOo0000o`000004ooooo`Go0000]oooool008Kooooo0_l0
0009ooooo`05o`000?ooooooooooooooool000003?ooool01?l0003o8B4Qo`000?lb<S82o`0000Co
oooo00?o0000ooooooooool00_l0000<ooooo`;o0000ZOooool008Kooooo0_l00009ooooo`05oa0@
4?ooooooooooooooool@41002Oooool2o`000003ooooool0003ooooo00Sooooo00?o0000oooooooo
ool00_ooool2o`0000[ooooo0_l0002Yooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00Wo
oooo0_l000000ooooooo0000ooooo`08ooooo`03o`000?oooooooooo00;ooooo0_l0000:ooooo`;o
0000ZOooool0097ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003o
ooooooooo`0>ooooo`;o0000ZOooool009Kooooo0_l0000Dooooo`03o`000?oooooooooo03Oooooo
0_l00020ooooo`00U_ooool2o`0001Cooooo00?o0000ooooooooool0=oooool2o`00083ooooo002/
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o00001?ooool2o`0003;ooooo0_l0001ooooo
o`00[?ooool00ol0003oooooooooo`04ooooo`?o0000<?ooool3o`0007oooooo002/ooooo`03o`00
0?oooooooooo00Gooooo1?l00009ooooo`;o00008oooool2o`00083ooooo002/ooooo`03o`000?oo
oooooooo00Oooooo0_l00009ooooo`;o00009Oooool2o`0007kooooo002Vooooo`;o00001?ooool0
0ol0003oooooooooo`0Pooooo`;o00005oooool3o`0007gooooo002Vooooo`;o00001?ooool00ol0
003oooooooooo`02o`0000Gooooo0_l0000Gooooo`;o00006?ooool2o`0007gooooo002Iooooo`;o
00002oooool2o`0000Cooooo00?o0000ooooooooool00_l00005ooooo`;o0000<oooool2o`0007_o
oooo002Iooooo`;o00001?ooool2o`0000_ooooo00?o0000ooooooooool08Oooool2o`0001Wooooo
0_l0001kooooo`00Woooool2o`0000_ooooo0ol0000Qooooo`;o0000U_ooool00:Wooooo0_l00000
0ooooooo0000ooooo`0looooo`;o0000O?ooool008[ooooo0_l0000Mooooo`;o000000?oooooo`00
0?ooool02_ooool2o`00033ooooo0_l0001looooo`00R_ooool2o`00023ooooo00?o0000oooooooo
ool02Oooool3o`000:gooooo002?ooooo`;o00006oooool00ol0003oooooooooo`0:ooooo`;o0000
[Oooool008oooooo0_l0000;ooooo`;o00003_ooool00ol0003oooooooooo`0kooooo`Co0000N_oo
ool008oooooo0_l0000:ooooo`?o00003_ooool00ol0003oooooooooo`02ooooo`;o00002?ooool2
o`0001Sooooo0_l0000Cooooo`Go0000NOooool008[ooooo0_l00003ooooo`;o00000_ooool2o`00
00Kooooo0_l0000?ooooo`03o`000?oooooooooo00;ooooo0ol00007ooooo`;o00006?ooool2o`00
01Kooooo0_l0001iooooo`00R_ooool2o`0000Oooooo0_l000000ooooooo0000o`00000Dooooo`?o
00000oooool2o`0001?ooooo0_l0002Oooooo`00U_ooool3o`0001?ooooo00?o0000ooooooooool0
6?ooool2o`0009oooooo0029ooooo`;o00003?ooool2o`0001?ooooo00?o0000ooooooooool0^Ooo
ool008Wooooo0_l00003ooooo`;o00007?ooool00ol0003oooooooooo`0oooooo`Co0000M_ooool0
08kooooo0_l0000Looooo`03o`000?oooooooooo01[ooooo0_l0000>ooooo`;o00004oooool4o`00
07Kooooo002/ooooo`03o`000?oooooooooo00;o00006?ooool2o`0000kooooo0_l0000Booooo`;o
00000_ooool2o`0007Gooooo002Eooooo`;o00005Oooool00ol0003oooooooooo`02o`0003cooooo
0_l00002ooooo`;o0000MOooool009Gooooo0_l00007ooooo`;o00003?ooool00ol0003ooooooooo
o`0Hooooo`;o0000:?ooool2o`0007Gooooo002=ooooo`;o00003oooool2o`0000cooooo00?o0000
ooooooooool06?ooool4o`0002Kooooo0_l0001eooooo`00SOooool2o`0001cooooo1?l0000Joooo
o`;o00008oooool3o`0007Oooooo002=ooooo`;o00002_ooool2o`00013ooooo0_l00003ooooo`;o
00000oooool2o`0003Oooooo0ol000000ooooooo0000o`00001dooooo`00SOooool2o`0000[ooooo
0_l0000Aooooo`04o`000?ooooooooooooooo`;o00000oooool2o`0002;ooooo0_l0000Dooooo`;o
000000?oooooo`000?l00000M?ooool00:cooooo00?o0000ooooooooool0:_ooool2o`000003oooo
ool0003o000001;ooooo0_l00002ooooo`;o0000L_ooool00:cooooo00?o0000ooooooooool00_oo
ool2o`0002Oooooo1?l0000Booooo`;o00000_ooool2o`0007;ooooo0029ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1Oooool00ol0003oooooooooo`02ooooo`;o00009oooool4o`0001Oooooo0_l0001aooooo`00ROoo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo0_l000000ooooooo8B4Qob4Q8@02ooooo`;o0000
00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00;o00000_ooool00ol0003o
ooooooooo`0]ooooo`;o00005oooool2o`00077ooooo0021ooooo`Ko00000_ooool01Ol@413ooooo
oooooooooooo410@00;ooooo0_l00005ooooo`;o000000CooooooiRHV?lQ8B7ok^k^2Oooool01?l0
003oooooo`000?l00002ooooo`03o`000?oooooooooo017ooooo0_l0000_ooooo`;o0000MOooool0
08Wooooo00Co0000oooooooooooooooo0_l00005ooooo`;o00001Oooool00onHV9So8B4Qonk^kP07
ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Aooooo`;o00006?ooool2o`0001Gooooo0_l0001e
ooooo`00ROooool01?l0003oooooooooooooool2o`0000Gooooo0_l000000ooooooo0000o`000003
ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oo
oooooooo02_ooooo0_l0000Jooooo`;o0000L?ooool008Wooooo00Go410@oooooooooooooooooa0@
4002ooooo`;o00001Oooool2o`0000Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo04Oooooo0_l0001`ooooo`00ROooool01OmgMgOoV9RHoooooonH
V9SoMgMg00;ooooo0_l00007ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo02cooooo0_l0002;ooooo`00ROooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003o
ooooooooo`0/ooooo`;o0000Roooool00:cooooo00?o0000ooooooooool0^Oooool008?ooooo0_l0
000Vooooo`;o00005?ooool2o`000:Gooooo0023ooooo`;o00009_ooool2o`0001Cooooo1?l0002S
ooooo`00[?ooool3o`0001Cooooo0_l00009ooooo`?o0000Uoooool00:cooooo00?o0000oooooooo
ool02oooool2o`0001;ooooo0ol0002Gooooo`00[?ooool00ol0003oooooooooo`0;ooooo`;o0000
??ooool2o`0006kooooo002/ooooo`03o`000?oooooooooo01kooooo0_l000000ooooooo0000o`00
000Vooooo`;o0000K_ooool0087ooooo0_l00004ooooo`;o00003oooool2o`0001;ooooo00?o0000
ooooooooool07_ooool2o`000003ooooool0003o000002?ooooo1?l0001_ooooo`00POooool2o`00
00Cooooo0_l0000?ooooo`;o00004_ooool01?l0003oooooooooooooool2o`0004?ooooo1?l0001_
ooooo`00[?ooool01?l0003oooooooooooooool2o`0001;ooooo0_l00009ooooo`;o00009Oooool2
o`00073ooooo002/ooooo`?o00000_ooool2o`00017ooooo0_l00009ooooo`;o00004?ooool3o`00
08Cooooo002/ooooo`?o00000_ooool2o`0001;ooooo0_l00008ooooo`;o00004?ooool3o`0001Co
oooo0_l0001^ooooo`00[?ooool00ol0003oooooooooo`0Fooooo`;o00006oooool2o`0001Cooooo
0_l0001^ooooo`00[?ooool00ol0003oooooooooo`0cooooo`;o0000Q?ooool0087ooooo0_l00008
ooooo`;o00000_ooool2o`0000Oooooo0_l0000Booooo`03o`000?oooooooooo03?ooooo0_l00024
ooooo`00POooool2o`0000Sooooo0_l00002ooooo`;o00001?ooool2o`000003ooooool0003o0000
01;ooooo00?o0000ooooooooool08Oooool2o`0000kooooo1?l00024ooooo`00UOooool2o`0001Go
oooo00?o0000ooooooooool08Oooool3o`0000gooooo0_l0000Eooooo`;o0000Koooool00:cooooo
00?o0000ooooooooool08_ooool2o`0002Cooooo0_l000000ooooooo0000o`00001/ooooo`00[?oo
ool00ol0003oooooooooo`1;ooooo`;o0000K?ooool008Oooooo0_l0000Sooooo`03o`000?oooooo
oooo04_ooooo0_l0001/ooooo`00Qoooool2o`0002?ooooo0ol0001;ooooo`;o0000K?ooool00:co
oooo00?o0000ooooooooool08oooool2o`0002?ooooo0_l00002ooooo`;o0000Joooool00:cooooo
00?o0000ooooooooool00oooool2o`0001kooooo0_l0000Sooooo`;o00000_ooool2o`0006_ooooo
0009ooooo`Co000000?o410@ooooooooool05_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0?
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0
003o0000oc8b<_oMgMd05_ooool00ol0003oooooooooo`03ooooo`;o00002Oooool2o`0000Sooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03ob4Q8Ol0003o000000?ooooo1Ol00004ooooo`05
odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`Co
000000?o410@ooooooooool04_ooool000_ooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_oo
ool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Oooooo00?oMgMgoc8b<_ooool05Oooool00ol0003oooooooooo`0>ooooo`;o00002?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l00004ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01?ooool2o`000004oooooomgMgOo0000o`0000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`0Iooooo`03o`000?oo
oooooooo01Cooooo0006o`0000Gooooo00?o0000ooooooooool04?ooool6o`0000;ooooo00Go410@
oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool01Ooo
ool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00Gooooo
1_l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool06?ooool01Ol@413ooooooooooooooooo410@
00Gooooo0_l00005ooooo`03oiRHV?lQ8B7ok^k^00Gooooo0_l000001?oooooo0000o`000?l0000>
ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0=ooooo`05oa0@4?oo
ooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooo
oooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`0>ooooo`05o`00
0?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0>ooooo`05o`000?oooooooooooooo
ool000001?ooool2o`0000Oooooo00?oV9RHob4Q8Oo^k^h00_ooool2o`0000?ooooo00?oMgMgoc8b
<_ooool05Oooool00ol0003oooooooooo`09ooooo`;o00003Oooool01Ol0003ooooooooooooooooo
000000gooooo00?oV9RHob4Q8Oo^k^h01oooool2o`0000oooooo00Go0000ooooooooooooooooo`00
000?ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q
8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool06Oooool00ol0003oooooooooo`0Dooooo`002ooo
ool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<
ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo0000
00cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000001?oo
ool2o`0000Sooooo00CoMgMgofIVI_oooooooooo0ol000001?lQ8B7o0000oc8b<_o<c<`Fooooo`03
o`000?oooooooooo00Wooooo0_l0000=ooooo`05o`000?ooooooooooooooool000003_ooool00omg
MgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooo
oooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool0
00003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06_ooool00ol0
003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05oa0@4?oooooooooooooo
ool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo017ooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@
4004ooooo`;o00002Oooool00ol0003oooooooooo`02ooooo`;o00006Oooool3o`0001Sooooo00Go
410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00Co0000ooooool0003o
00004?ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04Oooool01Ol@
413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooooooo
o`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool00ol0003o^[Zjooooo`02o`0000Cooooo0_l0000Iooooo`03
o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001?ooool01?l0003oooooo`000?l0000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413o
oooooooooooooooo<S8b00Cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Doooo
o`002Oooool00omEEEGoIVIVo`00000Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`00
00Cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00013ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`03oiRHV?l@413o000000;o00001?ooool4o`0001Oooooo00?o
0000ooooooooool03oooool2o`0000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`01?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00006Oooool0
0omEEEGoIVIVo`00000Fooooo`00TOooool2o`000003ooooool0003o000001Kooooo00?o0000oooo
ooooool02?ooool2o`0000Gooooo0_l0002Xooooo`00U?ooool2o`0001Kooooo00?o0000oooooooo
ool01?ooool2o`0000;ooooo0_l0002_ooooo`00VOooool2o`00017ooooo00?o0000ooooooooool0
1?ooool2o`00013ooooo0_l0002Fooooo`;o00000_ooool2o`0000Gooooo002Iooooo`;o00004Ooo
ool00ol0003oooooooooo`0Fooooo`?o0000UOooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Go
oooo002?ooooo`;o00006oooool00ol0003oooooooooo`04ooooo`;o00002?ooool2o`0000Oooooo
1?l00008ooooo`;o0000R_ooool01?oMgMgo0000oa0@4?o<c<`6ooooo`001oooooooo`0004co0000
3?ooool01?o^k^ko8B4Qoa0@4?o^k^h6ooooo`001oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool00_ooool2o`000003ooooool0003ooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool02_ooool01?lQ8B7oMgMgogMgMolb<S86ooooo`001oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0Aooooo`;o00004oooool00ol0003oooooooooo`0Uooooo`?o0000:?ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02Oooool2o`0000;ooooo
0_l00005ooooo`00U?ooool2o`000003ooooool0003o000001?ooooo00?o0000ooooooooool05ooo
ool2o`0000[ooooo1?l0000>ooooo`;o00005Oooool2o`0006_ooooo0022ooooo`;o00004?ooool2
o`0001Kooooo00?o0000ooooooooool05oooool2o`0000[ooooo0ol0000?ooooo`;o00005?ooool3
o`0006_ooooo0022ooooo`;o0000:?ooool00ol0003oooooooooo`09ooooo`;o00003Oooool2o`00
01_ooooo0_l0000Dooooo`;o0000K?ooool008;ooooo0_l0000Xooooo`03o`000?oooooooooo00Wo
oooo0_l0000=ooooo`;o00006oooool2o`0008;ooooo002/ooooo`03o`000?oooooooooo03Gooooo
0_l00022ooooo`00[?ooool3o`0003Cooooo0_l00023ooooo`00Roooool2o`0001oooooo00?o0000
ooooooooool0=?ooool2o`0008?ooooo0022ooooo`;o00001oooool2o`0001oooooo00?o0000oooo
ooooool0C_ooool2o`0006Wooooo001kooooo`;o00001Oooool2o`0002Sooooo00?o0000oooooooo
ool02Oooool2o`0004?ooooo0_l0001Yooooo`00Noooool2o`0002oooooo00?o0000ooooooooool0
2Oooool2o`000:kooooo002/ooooo`03o`000?oooooooooo00Cooooo0_l00008ooooo`;o00001ooo
ool2o`000:3ooooo002?ooooo`;o00006oooool00ol0003oooooooooo`04ooooo`;o00002?ooool4
o`0000Gooooo0_l0000fooooo`;o0000J?ooool008oooooo0_l0000Kooooo`03o`000?oooooooooo
013ooooo0_l0000@ooooo`;o0000:oooool2o`0006Sooooo002Booooo`;o00006?ooool00ol0003o
ooooooooo`0Rooooo`;o00003_ooool2o`0008Gooooo002Booooo`;o00006?ooool3o`0000oooooo
0_l0000Qooooo`;o0000QOooool00:cooooo00?o0000ooooooooool03_ooool3o`00017ooooo0_l0
002Eooooo`00[?ooool00ol0003oooooooooo`0>ooooo`;o00004_ooool2o`0002Kooooo0_l0001]
ooooo`00[?ooool00ol0003oooooooooo`1:ooooo`;o000000?oooooo`000?l00000J_ooool00:co
oooo00?o0000ooooooooool00oooool2o`0004Sooooo0_l0001Zooooo`00P_ooool2o`0000kooooo
0_l0000Hooooo`03o`000?oooooooooo00?ooooo0_l0000Looooo`;o0000U_ooool008;ooooo0_l0
000>ooooo`;o00006?ooool00ol0003oooooooooo`0Hooooo`;o00001oooool2o`0009Kooooo002/
ooooo`03o`000?oooooooooo01Sooooo0_l0000cooooo`;o0000J_ooool00:cooooo0ol0000Goooo
o`;o0000=?ooool2o`0006[ooooo0021ooooo`;o00002Oooool2o`0000Cooooo0_l0000Hooooo`03
o`000?oooooooooo01Oooooo0_l0002Pooooo`00POooool2o`0000Wooooo0_l00002ooooo`Co0000
6?ooool00ol0003oooooooooo`02ooooo`;o0000]Oooool0093ooooo0_l0000Jooooo`03o`000?oo
oooooooo00;ooooo0_l00017ooooo`;o0000K?ooool00:cooooo00?o0000ooooooooool08Oooool2
o`0001;ooooo0_l0000Dooooo`;o0000K?ooool00:cooooo00?o0000ooooooooool08Oooool2o`00
01;ooooo0_l00022ooooo`00[?ooool00ol0003oooooooooo`0>ooooo`;o00004Oooool3o`0000oo
oooo0_l00024ooooo`00O?ooool2o`0002kooooo00?o0000ooooooooool03_ooool2o`00017ooooo
0ol0000?ooooo`;o00005_ooool2o`0006cooooo001looooo`;o0000;_ooool3o`0004_ooooo0_l0
001/ooooo`00O?ooool2o`0002kooooo00?o0000ooooooooool0<Oooool2o`0001Wooooo0_l0001[
ooooo`00[?ooool00ol0003oooooooooo`0Dooooo`;o00006oooool2o`0001Wooooo0_l0001[oooo
o`00Uoooool2o`0001?ooooo00?o0000ooooooooool05?ooool2o`000:?ooooo002Gooooo`;o0000
4oooool00ol0003oooooooooo`0Pooooo`;o0000Uoooool00:cooooo00?o0000ooooooooool02ooo
ool2o`0001?ooooo0_l0000@ooooo`;o0000QOooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`00
0?oooooooooo00_ooooo0_l0000Cooooo`?o00003?ooool2o`000003ooooool0003o000008Gooooo
0029ooooo`03ogMgMonHV9Sooooo00;o00001Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A007ooooo`03ogMgMolb<S;ooooo00?ooooo0_l0000Rooooo`?o00003?ooool4o`0008Kooooo
0028ooooo`;o00000_ooool2o`0000;ooooo0_l00008ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0
0004ooooo`Co00005Oooool2o`0001[ooooo0_l00026ooooo`00R?ooool2o`0000?ooooo00?o0000
ooooooooool00_l00009ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0_l000000olb<S;oooooooooo`03
ooooo`03o`000?oooooooooo01Gooooo0_l0002Rooooo`00ROooool01Ol0003ooooooooooooooooo
000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool0^Oooool008Wooooo0_l00002ooooo`03oa0@4?oooooooooo00gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Wooooo0029oooo
o`;o000000?ooooooiRHV?mgMgL02_ooool2o`000004okZj^_ooooooV9RHoa0@40Cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Cooooo`;o0000<_ooool2o`00073ooooo0029oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02_ooool2o`000004oa0@4?l0003o8B4Qolc<c0Cooooo1?l0
0006ooooo`03o`000?oooooooooo01?ooooo0_l0000booooo`;o000000?oooooo`000?l00000KOoo
ool009Wooooo0_l0000Aooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o00008oooool2
o`0001[ooooo0_l0001]ooooo`00TOooool2o`0000;ooooo0_l00002ooooo`;o00000oooool2o`00
00cooooo0ol00003ooooo`;o00001?ooool2o`0000Sooooo0_l0000Iooooo`;o0000ROooool0097o
oooo0_l00002ooooo`;o00001oooool2o`0000cooooo0ol0000Booooo`?o0000<Oooool3o`00073o
oooo0029ooooo`;o00008Oooool3o`0001;ooooo0_l0000booooo`?o0000L?ooool008Wooooo0_l0
000Qooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo02oooooo0_l0000F
ooooo`;o0000L?ooool00:cooooo00?o0000ooooooooool02?ooool2o`0000Oooooo0_l0000Loooo
o`;o00005_ooool2o`00073ooooo0024ooooo`;o00009_ooool01?l0003oooooooooooooool2o`00
00Gooooo0_l00007ooooo`;o00002_ooool2o`0000gooooo0_l0000Hooooo`;o0000LOooool008Co
oooo0_l0000Vooooo`04o`000?ooooooooooooooo`;o00006_ooool2o`0000gooooo1?l0000Foooo
o`;o0000LOooool00:cooooo00?o0000ooooooooool01oooool2o`0002Gooooo0_l00029ooooo`00
Q?ooool2o`0002Cooooo0ol00009ooooo`;o0000/?ooool008Cooooo0_l0000Tooooo`Go0000^Ooo
ool00:cooooo00?o0000ooooooooool0^Oooool009Sooooo0_l00003ooooo`;o00003Oooool00ol0
003oooooooooo`0>ooooo`;o00002oooool2o`0009cooooo002Hooooo`;o00000oooool2o`0000go
oooo00?o0000ooooooooool03_ooool2o`0000_ooooo0_l0002Looooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`?o0000;Oooool2o`0008[ooooo002/oooo
o`03o`000?oooooooooo02gooooo0_l0002:ooooo`00[?ooool3o`0000gooooo0_l0000Iooooo`;o
0000Soooool009[ooooo0_l0000@ooooo`03o`000?oooooooooo00gooooo0_l0000Iooooo`;o0000
Soooool0093ooooo0ol00007ooooo`;o00004?ooool00ol0003oooooooooo`0Xooooo`;o0000Sooo
ool0093ooooo0ol0000Iooooo`03o`000?oooooooooo02Sooooo0_l0002?ooooo`00[?ooool00ol0
003oooooooooo`03ooooo`;o0000]?ooool00:cooooo00?o0000ooooooooool00oooool2o`000;Co
oooo002<ooooo`;o00007_ooool00ol0003oooooooooo`0Fooooo`;o00003_ooool2o`00097ooooo
002<ooooo`;o00002?ooool3o`0001?ooooo00?o0000ooooooooool00_l0000Dooooo`;o00003_oo
ool2o`00097ooooo002Fooooo`?o00004oooool5o`000;Oooooo002Hooooo`;o00004_ooool00ol0
003oooooooooo`2iooooo`00Ooooool2o`0001Oooooo0_l00007ooooo`;o00002Oooool00ol0003o
ooooooooo`09ooooo`;o0000[_ooool007oooooo0_l0000Pooooo`Co00001oooool00ol0003ooooo
ooooo`09ooooo`;o00007Oooool2o`0008oooooo002Sooooo`;o00001oooool00ol0003ooooooooo
o`08ooooo`;o00007_ooool2o`0008oooooo002/ooooo`03o`000?oooooooooo00Sooooo0_l0000J
ooooo`;o0000Toooool0097ooooo00Gok^k^oc8b<_l0003o0000onk^kP05ooooo`;o8B4Q1Oooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool04oooool2o`0000oooooo0_l0
002Cooooo`00TOooool01OmgMgOoV9RHo`000?l0003oMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool04oooool2o`000:Cooooo002Aooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`;o00001oooool2o`000;;ooooo002A
ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`Co00001Ooo
ool2o`0001_ooooo0_l0002Eooooo`00TOooool01Ol0003ooooooooooooooooo000000cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00Gooooo0_l0000:ooooo`Co0000
3Oooool2o`0009Gooooo002Aooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Gooooo0_l0000:ooooo`Co00003Oooool2o`0009Gooooo
002Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool2o`0000Cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Booooo`;o00009Oooool2o`0007kooooo002Aooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01_ooool3o`0000?ooooo1?l00006ooooo`03o`000?oooooooooo03Wooooo
0_l0001nooooo`00Qoooool2o`0001Cooooo0_l0000=ooooo`03o`000?oooooooooo03Sooooo0_l0
001oooooo`00Qoooool2o`0001kooooo0_l00003ooooo`03o`000?oooooooooo03Sooooo0_l0001o
ooooo`00Woooool2o`0000Cooooo1?l00003ooooo`03o`000?oooooooooo00;ooooo0_l0002eoooo
o`00Uoooool2o`0000Kooooo0_l00004ooooo`;o00001Oooool3o`0000;ooooo0_l0002eooooo`00
POooool2o`0000Kooooo0_l0000<ooooo`;o00004oooool00ol0003oooooooooo`0Pooooo`;o0000
Uoooool0087ooooo0_l00006ooooo`;o00008Oooool00ol0003oooooooooo`0Pooooo`;o00005_oo
ool2o`0007oooooo002/ooooo`03o`000?oooooooooo03Oooooo0ol0001oooooo`00[?ooool00ol0
003oooooooooo`0gooooo`;o0000P?ooool008[ooooo0_l0000Pooooo`04o`000?oooooo0000o`00
0;Sooooo002:ooooo`;o00008?ooool01?l0003oooooo`000?l0000Jooooo`;o0000W?ooool00:co
oooo00Co0000ooooool0003o00006_ooool5o`0009Wooooo002/ooooo`Co00002?ooool2o`00017o
oooo1?l0002Iooooo`00R_ooool2o`0000oooooo0_l0000?ooooo`03o`000?oooooooooo00Wooooo
0_l0000?ooooo`Go0000V_ooool008[ooooo0_l0000?ooooo`;o00003oooool00ol0003ooooooooo
o`0Jooooo`?o0000W?ooool008?ooooo0_l0000Wooooo`03o`000?oooooooooo00Sooooo0ol0002^
ooooo`00Poooool2o`0000Gooooo0_l0000Pooooo`03o`000?oooooooooo00Sooooo0ol0000>oooo
o`;o0000W_ooool008[ooooo0_l00007ooooo`;o00002oooool2o`0000[ooooo00?o0000oooooooo
ool06Oooool2o`0009kooooo002Cooooo`;o00002Oooool4o`0000[ooooo00?o0000ooooooooool0
^Oooool009kooooo1?l0000:ooooo`03o`000?oooooooooo0;Wooooo002Uooooo`;o00001Oooool3
o`0001Wooooo0_l0002Nooooo`00YOooool2o`0000Gooooo00?o0000ooooooooool00oooool4o`00
00gooooo0_l00003ooooo`;o0000W_ooool009Cooooo0_l0000Fooooo`03o`000?oooooooooo00?o
oooo1?l0000=ooooo`;o0000Xoooool009Cooooo0_l0000Fooooo`03o`000?oooooooooo00Cooooo
0_l0002cooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o00003oooool2o`000:;ooooo002/
ooooo`03o`000?oooooooooo01Gooooo0_l0002Rooooo`00SOooool2o`0001gooooo00?o0000oooo
ooooool04oooool2o`000:Cooooo002=ooooo`;o00007Oooool00ol0003oooooooooo`0Cooooo`;o
0000Y?ooool00:cooooo00?o0000ooooooooool04Oooool2o`000:Kooooo002/ooooo`?o00004Ooo
ool3o`000:Gooooo002/ooooo`04o`000?oooooo0000o`00017ooooo0_l0002Uooooo`00[?ooool0
1?l0003oooooo`000?l0002hooooo`00Zoooool2o`000;_ooooo002[ooooo`;o00003oooool2o`00
0:[ooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^
k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool03Oooool2
o`000:[ooooo0029ooooo`06ogMgMonHV9SooooooiRHV?mgMgOooooo0_l00002ooooo`;o8B4Q1_oo
ool4o`0000Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2iooooo`00ROooool0
1_l@413ooooooooooooooooo410@ooooo`;o00002_ooool4o`0000Oooooo00Co0000oooooooooooo
oooo0ol0000?ooooo`?o0000ZOooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`;o
00001oooool00omgMgOo<S8booooo`02ooooo`Go00003Oooool3o`000:Wooooo0029ooooo`05o`00
0?ooooooooooooooool000003_ooool00omEEEGo0000o`000003ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`0>ooooo`;o0000ZOooool008Wooooo00Go410@oooooooo
oooooooooa0@400>ooooo`03ojVYZOl0003o000000;ooooo0_l00009ooooo`03o`000?oooooooooo
02Gooooo0_l0002Booooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooo
oooooooooooooc8b<P03ooooo`;o00002Oooool00ol0003oooooooooo`0Uooooo`;o0000T_ooool0
08Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo00?o0000
ooooooooool02?ooool2o`000:oooooo002/ooooo`03o`000?oooooooooo00Sooooo0_l0002_oooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0Pooooo`;o0000
Uoooool00:cooooo0ol00006ooooo`;o00005oooool3o`0009Oooooo002/ooooo`03o`000?oooooo
oooo00Kooooo0_l0000Eooooo`Co0000V?ooool00:cooooo00?o0000ooooooooool07Oooool2o`00
09[ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`04o`000?ooooooooooooooo`?o0000]Oooool009Sooooo0_l0000Booooo`?o000000Coooooo`00
0?l0003o0000]Oooool009Sooooo0_l0000Booooo`03o`000?oooooooooo0;Wooooo002/ooooo`03
o`000?oooooooooo01Oooooo0_l0002Pooooo`00[?ooool00ol0003oooooooooo`0Gooooo`;o0000
X?ooool009Wooooo0_l0000Aooooo`03o`000?oooooooooo0;Wooooo002Iooooo`;o00004?ooool2
o`000;_ooooo002Looooo`;o00003Oooool2o`000;_ooooo002Looooo`;o00000oooool2o`0000Co
oooo0_l00003ooooo`03o`000?oooooooooo01Cooooo0_l0002Sooooo`00X?ooool4o`0000?ooooo
0_l00003ooooo`03o`000?oooooooooo01Cooooo0_l0002Sooooo`00X?ooool4o`0000Cooooo0_l0
0002ooooo`?o0000^Oooool00:Gooooo0_l000000ooooooo0000o`000002ooooo`03o`000?oooooo
oooo0;Wooooo002Uooooo`;o00001Oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0?ooooo`;o0000Z?ooool00:cooooo00?o
0000ooooooooool03oooool2o`000:Sooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool01_ooool2o`000;7ooooo002/ooooo`03o`000?oooooooooo00Ko
oooo0_l0002aooooo`00X_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0
^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00Y?ooool0
0ol0003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:Co
oooo00?o0000ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo00?o
0000ooooooooool0`Oooool00:;ooooo00?oEEEEofIVI_l00000`oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00:[ooooo00Co410@o`000?l0003o0000^_oo
ool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_o
oooo00Ko0000ogMgMol0003o0000oeEEEOo^k^jgooooo`00Zoooool01_l0003oEEEEonk^k_oooooo
MgMgoeEEEKOooooo002[ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0]Oooool0
0:_ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`2eooooo`00Zoooool01_l0003o
EEEEonk^k_ooooooMgMgofIVI[Oooooo002Zooooo`03oa0@4?l0003oMgMg00;o000000?oIVIVonk^
k_ooool0]_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.40614 .75187 Mdot
.4202 .1702 Mdot
.47938 .63469 Mdot
.44259 .29278 Mdot
.58495 .44435 Mdot
.58133 .73211 Mdot
.44484 .6091 Mdot
.47717 .00771 Mdot
.37561 .33927 Mdot
.54487 .64056 Mdot
.46149 .77864 Mdot
.56056 .08873 Mdot
.59227 .22181 Mdot
.51483 .73291 Mdot
.60364 .15233 Mdot
.53569 .35256 Mdot
.53466 .22095 Mdot
.59896 .2327 Mdot
.47252 .19644 Mdot
.67494 .62445 Mdot
.6168 .27629 Mdot
.51158 .11687 Mdot
.55794 .185 Mdot
.61556 .2657 Mdot
.66439 .24062 Mdot
.51689 .78958 Mdot
.4155 .60566 Mdot
.47122 .20051 Mdot
.66076 .67343 Mdot
.44251 .11778 Mdot
.64278 .34955 Mdot
.37069 .4096 Mdot
.45596 .02238 Mdot
.59781 .36638 Mdot
.62285 .46419 Mdot
.67009 .59322 Mdot
.51159 .93297 Mdot
.43222 .27619 Mdot
.62634 .7486 Mdot
.56802 .09323 Mdot
.65385 .21353 Mdot
.61294 .41258 Mdot
.61678 .60842 Mdot
.40236 .7397 Mdot
.4557 .88868 Mdot
.58453 .5963 Mdot
.50587 .74435 Mdot
.38767 .76664 Mdot
.40088 .59905 Mdot
.65099 .68879 Mdot
.38719 .76066 Mdot
.6081 .79379 Mdot
.62201 .55388 Mdot
.62672 .54355 Mdot
.40807 .12709 Mdot
.49554 .017 Mdot
.5243 .20098 Mdot
.43936 .93915 Mdot
.4745 .89691 Mdot
.57493 .63733 Mdot
.74839 .4588 Mdot
.61468 .76882 Mdot
.52809 .62834 Mdot
.48368 .02257 Mdot
.38036 .278 Mdot
.54624 .63109 Mdot
.52948 .3406 Mdot
.42679 .29503 Mdot
.63436 .3094 Mdot
.53415 .20942 Mdot
.4675 .31589 Mdot
.53433 .67121 Mdot
.55945 .54949 Mdot
.61466 .76876 Mdot
.44705 .4235 Mdot
.53371 .74378 Mdot
.62471 .76219 Mdot
.40133 .56498 Mdot
.66996 .46218 Mdot
.44046 .1232 Mdot
.42959 .3556 Mdot
.61543 .41932 Mdot
.42958 .05636 Mdot
.53544 .34326 Mdot
.58699 .45924 Mdot
.58546 .54876 Mdot
.48941 .1508 Mdot
.53406 .35584 Mdot
.67064 .25429 Mdot
.68396 .78791 Mdot
.48263 .74337 Mdot
.58838 .55568 Mdot
.497 .72174 Mdot
.70724 .74426 Mdot
.51928 .72214 Mdot
.37602 .65301 Mdot
.48357 .14393 Mdot
.38997 .62083 Mdot
.44283 .17662 Mdot
.56891 .10208 Mdot
.38808 .61157 Mdot
.66138 .39411 Mdot
.6042 .38806 Mdot
.55832 .25501 Mdot
.50176 .21728 Mdot
.48139 .74442 Mdot
.63876 .32375 Mdot
.53486 .68018 Mdot
.43065 .34084 Mdot
.37052 .41945 Mdot
.67857 .57859 Mdot
.35124 .55302 Mdot
.45466 .69034 Mdot
.55902 .68689 Mdot
.38105 .26055 Mdot
.37341 .34347 Mdot
.5005 .94101 Mdot
.59425 .22715 Mdot
.73769 .39728 Mdot
.60504 .26427 Mdot
.66152 .67545 Mdot
.63786 .31938 Mdot
.46651 .24918 Mdot
.67231 .61244 Mdot
.72511 .69703 Mdot
.40456 .25262 Mdot
.43751 .36746 Mdot
.54575 .16307 Mdot
.38624 .4473 Mdot
.59633 .13354 Mdot
.58296 .73353 Mdot
.60726 .65323 Mdot
.6448 .72186 Mdot
.55475 .8835 Mdot
.66473 .65192 Mdot
.5357 .66567 Mdot
.49979 .02769 Mdot
.60547 .15237 Mdot
.74669 .56754 Mdot
.4249 .61312 Mdot
.44121 .23985 Mdot
.53383 .21884 Mdot
.67819 .59951 Mdot
.40722 .11986 Mdot
.37432 .16394 Mdot
.53466 .291 Mdot
.58389 .57213 Mdot
.72567 .34364 Mdot
.42701 .21882 Mdot
.409 .51107 Mdot
.61633 .26493 Mdot
.45456 .33791 Mdot
.5218 .83787 Mdot
.56496 .8644 Mdot
.61356 .77599 Mdot
.38693 .22279 Mdot
.50371 .94067 Mdot
.56282 .86867 Mdot
.45836 .83254 Mdot
.63 .75449 Mdot
.63056 .16782 Mdot
.67262 .55112 Mdot
.60984 .62638 Mdot
.3902 .61339 Mdot
.40356 .13507 Mdot
.66773 .4164 Mdot
.42173 .32384 Mdot
.58041 .84665 Mdot
.65559 .6638 Mdot
.44584 .70365 Mdot
.41399 .39542 Mdot
.58654 .48216 Mdot
.54354 .30776 Mdot
.47684 .01728 Mdot
.7124 .73082 Mdot
.52588 .83058 Mdot
.45039 .67387 Mdot
.64889 .70135 Mdot
.60369 .80891 Mdot
.5994 .13241 Mdot
.55971 .4619 Mdot
.66121 .22502 Mdot
.48957 .28973 Mdot
.3758 .34427 Mdot
.72262 .69923 Mdot
.36826 .51432 Mdot
.62455 .16092 Mdot
.6148 .62586 Mdot
.72594 .35931 Mdot
.67914 .59661 Mdot
.53859 .56099 Mdot
.74398 .44821 Mdot
.45385 .01963 Mdot
.68158 .25388 Mdot
.58004 .11413 Mdot
.58884 .53707 Mdot
.66428 .8303 Mdot
.58442 .30659 Mdot
.48702 .69378 Mdot
.48156 .6997 Mdot
.4791 .31259 Mdot
.58321 .44881 Mdot
.645 .86012 Mdot
.38602 .50907 Mdot
.53548 .44349 Mdot
.56333 .76932 Mdot
.42255 .39613 Mdot
.51109 .33311 Mdot
.45895 .77833 Mdot
.55057 .15964 Mdot
.54199 .72605 Mdot
.66831 .42024 Mdot
.55553 .44262 Mdot
.38784 .56986 Mdot
.55043 .703 Mdot
.63658 .17761 Mdot
.48501 .28096 Mdot
.47421 .89156 Mdot
.54411 .06536 Mdot
.56419 .67245 Mdot
.41319 .87364 Mdot
.66333 .3945 Mdot
.67203 .49997 Mdot
.54904 .41534 Mdot
.56963 .37574 Mdot
.39745 .27781 Mdot
.45793 .73086 Mdot
.60511 .15381 Mdot
.74114 .40218 Mdot
.50879 .28239 Mdot
.51113 .55859 Mdot
.62828 .87958 Mdot
.4116 .30193 Mdot
.42154 .6615 Mdot
.7327 .38439 Mdot
.42035 .33709 Mdot
.38462 .53744 Mdot
.59402 .23729 Mdot
.38555 .50725 Mdot
.74792 .46443 Mdot
.60409 .67351 Mdot
.67643 .45738 Mdot
.53336 .20822 Mdot
.36897 .44211 Mdot
.50098 .70945 Mdot
.55725 .86976 Mdot
.48267 .15489 Mdot
.52893 .20095 Mdot
.6173 .76633 Mdot
.67773 .24933 Mdot
.45674 .6937 Mdot
.53541 .57621 Mdot
.53403 .90028 Mdot
.49697 .81924 Mdot
.41242 .41997 Mdot
.62896 .55561 Mdot
.45224 .39253 Mdot
.49243 .01731 Mdot
.40932 .86761 Mdot
.39832 .45134 Mdot
.42235 .66682 Mdot
.67317 .51666 Mdot
.42776 .51134 Mdot
.42811 .21826 Mdot
.41941 .80624 Mdot
.48756 .77334 Mdot
.5826 .71795 Mdot
.66346 .62819 Mdot
.45237 .81895 Mdot
.67302 .59563 Mdot
.62683 .5567 Mdot
.54988 .62482 Mdot
.39886 .51575 Mdot
.57312 .85376 Mdot
.5614 .4709 Mdot
.54381 .29708 Mdot
.37824 .68805 Mdot
.47425 .78843 Mdot
.53984 .81093 Mdot
.64283 .72006 Mdot
.43372 .38091 Mdot
.55911 .52035 Mdot
.49958 .94448 Mdot
.54962 .0788 Mdot
.50547 .22287 Mdot
.43735 .43214 Mdot
.57263 .40636 Mdot
.68324 .53223 Mdot
.58271 .58933 Mdot
.6662 .44165 Mdot
.72065 .70234 Mdot
.44055 .93817 Mdot
.57642 .11596 Mdot
.42504 .90481 Mdot
.48451 .66634 Mdot
.47808 .96662 Mdot
.73881 .43556 Mdot
.68283 .49386 Mdot
.59468 .14037 Mdot
.40695 .02423 Mdot
.40393 .62413 Mdot
.62224 .60991 Mdot
.38629 .43374 Mdot
.3698 .42321 Mdot
.65239 .21577 Mdot
.49755 .76287 Mdot
.37754 .67692 Mdot
.48679 .83124 Mdot
.51316 .61536 Mdot
.55299 .16582 Mdot
.54463 .23718 Mdot
.5897 .22216 Mdot
.71944 .32939 Mdot
.44081 .64484 Mdot
.45289 .87975 Mdot
.6068 .39444 Mdot
.50301 .03617 Mdot
.42723 .51548 Mdot
.60776 .14442 Mdot
.71855 .35809 Mdot
.74961 .58517 Mdot
.4964 .26076 Mdot
.5858 .73039 Mdot
.61642 .41837 Mdot
.59831 .8005 Mdot
.56949 .36885 Mdot
.50714 .64686 Mdot
.46299 .66371 Mdot
.54897 .23897 Mdot
.51914 .03878 Mdot
.53194 .90062 Mdot
.5031 .70872 Mdot
.53135 .13705 Mdot
.44019 .35071 Mdot
.48216 .31461 Mdot
.40191 .24921 Mdot
.59041 .71159 Mdot
.60974 .6275 Mdot
.45649 .83019 Mdot
.58078 .4354 Mdot
.56163 .96878 Mdot
.47638 .83302 Mdot
.42986 .15009 Mdot
.52335 .64338 Mdot
.43718 .04938 Mdot
.41996 .64361 Mdot
.66617 .64321 Mdot
.483 .09432 Mdot
.4497 .72246 Mdot
.56591 .65299 Mdot
.74785 .56103 Mdot
.55042 .0757 Mdot
.49098 .96275 Mdot
.66952 .60312 Mdot
.41605 .71713 Mdot
.5838 .31047 Mdot
.66074 .64804 Mdot
.41846 .25977 Mdot
.55116 .07707 Mdot
.7533 .58291 Mdot
.67764 .46606 Mdot
.5949 .13263 Mdot
.61426 .15331 Mdot
.65293 .20604 Mdot
.5051 .36289 Mdot
.40252 .38358 Mdot
.60975 .15924 Mdot
.49116 .01505 Mdot
.51036 .38201 Mdot
.65955 .40342 Mdot
.46296 .82577 Mdot
.56712 .76504 Mdot
.39361 .66211 Mdot
.37137 .57338 Mdot
.3848 .53998 Mdot
.4911 .95696 Mdot
.55952 .8612 Mdot
.55112 .17567 Mdot
.51462 .93769 Mdot
.54123 .15824 Mdot
.6472 .21176 Mdot
.35145 .41522 Mdot
.47365 .95652 Mdot
.51998 .84374 Mdot
.45228 .3486 Mdot
.70184 .31134 Mdot
.47428 .14427 Mdot
.46846 .66905 Mdot
.60224 .13411 Mdot
.63687 .31556 Mdot
.51229 .62902 Mdot
.5561 .57898 Mdot
.53419 .75222 Mdot
.41444 .60171 Mdot
.38215 .72937 Mdot
.66531 .38881 Mdot
.74235 .44773 Mdot
.6045 .13875 Mdot
.57494 .29837 Mdot
.56832 .95759 Mdot
.58156 .30982 Mdot
.53782 .29312 Mdot
.54943 .31662 Mdot
.5069 .42075 Mdot
.515 .03604 Mdot
.55763 .08576 Mdot
.41745 .62502 Mdot
.44518 .7075 Mdot
.43238 .72423 Mdot
.54918 .39244 Mdot
.70527 .30083 Mdot
.59101 .53019 Mdot
.67489 .53857 Mdot
.41933 .52113 Mdot
.40928 .47448 Mdot
.42801 .46127 Mdot
.59016 .49897 Mdot
.59121 .34635 Mdot
.4151 .61821 Mdot
.53794 .46497 Mdot
.73249 .37131 Mdot
.49408 .02221 Mdot
.50196 .46835 Mdot
.62469 .48108 Mdot
.5589 .25636 Mdot
.48203 .88419 Mdot
.44687 .80652 Mdot
.41521 .377 Mdot
.70229 .30767 Mdot
.70122 .76359 Mdot
.38564 .43255 Mdot
.37333 .81361 Mdot
.3959 .69856 Mdot
.54069 .49045 Mdot
.39198 .20937 Mdot
.61807 .17147 Mdot
.44686 .75504 Mdot
.48987 .09942 Mdot
.5508 .9802 Mdot
.43659 .67734 Mdot
.52135 .58068 Mdot
.55538 .34064 Mdot
.6741 .50486 Mdot
.41109 .67568 Mdot
.6734 .81154 Mdot
.50279 .31451 Mdot
.62251 .51704 Mdot
.60995 .39253 Mdot
.51669 .67182 Mdot
.43978 .63666 Mdot
.56254 .51091 Mdot
.48085 .00864 Mdot
.43369 .60747 Mdot
.63575 .74013 Mdot
.40051 .26213 Mdot
.44939 .87866 Mdot
.67339 .60174 Mdot
.66113 .41779 Mdot
.55959 .26447 Mdot
.7336 .68128 Mdot
.55457 .59098 Mdot
.52353 .04307 Mdot
.6751 .24265 Mdot
.48208 .7764 Mdot
.48317 .96612 Mdot
.44887 .81169 Mdot
.5244 .20774 Mdot
.66815 .63661 Mdot
.39062 .63228 Mdot
.48883 .20246 Mdot
.56597 .65404 Mdot
.59539 .355 Mdot
.74932 .43892 Mdot
.60257 .6619 Mdot
.44303 .46307 Mdot
.61641 .59953 Mdot
.40094 .5642 Mdot
.49818 .33867 Mdot
.51175 .29578 Mdot
.62324 .54182 Mdot
.6142 .63203 Mdot
.47094 .70547 Mdot
.50798 .79909 Mdot
.38227 .26223 Mdot
.58274 .42443 Mdot
.43231 .84334 Mdot
.42387 .30299 Mdot
.48289 .20507 Mdot
.52255 .44679 Mdot
.35559 .65637 Mdot
.52462 .47276 Mdot
.41044 .2069 Mdot
.39962 .81683 Mdot
.6734 .5537 Mdot
.43474 .26199 Mdot
.6589 .672 Mdot
.58606 .1169 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool2o`0000Kooooo00?o0000ooooooooool0^Oooool00:Cooooo0ol0
0005ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`?o00001Oooool00ol0003oooooooooo`2i
ooooo`00X_ooool00omEEEGoIVIVo`000004ooooo`;o000000?oooooo`000?ooool0^_ooool009co
oooo0_l00006ooooo`;o00000oooool4o`000;_ooooo002Looooo`?o00001Oooool4o`000003oooo
ool0003o000000;o0000^oooool008gooooo0_l0000>ooooo`;o00001oooool2o`0000;ooooo1Ol0
002iooooo`00SOooool2o`0001cooooo0_l0002kooooo`00Zoooool2o`000;_ooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`?o00000_ooool2o`000;Gooooo002/ooooo`?o00000_oo
ool3o`000;Cooooo002/ooooo`03o`000?oooooooooo00?ooooo0ol0002cooooo`00[?ooool00ol0
003oooooooooo`04ooooo`;o0000/oooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo0;Wo
oooo002Gooooo`;o00004oooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002D
ooooo`;o00005_ooool00ol0003oooooooooo`2iooooo`00U?ooool2o`0001Kooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
2oooool2o`000:cooooo002/ooooo`03o`000?oooooooooo00_ooooo0_l0002/ooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool3o`0000gooooo0_l0002Zooooo`00[?ooool00ol0003o
ooooooooo`0=ooooo`;o0000Z_ooool00:cooooo00?o0000ooooooooool03Oooool2o`000:[ooooo
002/ooooo`03o`000?oooooooooo013ooooo0_l0002Wooooo`00[?ooool00ol0003oooooooooo`0@
ooooo`?o0000Y_ooool00:cooooo00?o0000ooooooooool04Oooool2o`000:Kooooo002Vooooo`;o
00001?ooool00ol0003oooooooooo`0Cooooo`;o0000Y?ooool00:Kooooo0_l00004ooooo`03o`00
0?oooooooooo01?ooooo0_l0002Tooooo`00Z?ooool2o`0000;ooooo0ol0002iooooo`00Z?ooool2
o`0000;ooooo00?o0000ooooooooool04oooool2o`000:Cooooo002/ooooo`03o`000?oooooooooo
01?ooooo0_l0002Tooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool00ol0003oooooooooo`0Fooooo`?o0000X?ooool008Wooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool3o`000003onk^k_oooooooooo00?ooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00;o00005?ooool5o`0009kooooo
0029ooooo`04ogMgMonHV9SooooooiRHV0;o00001?ooool2ob4Q8@Cooooo0_l000000omEEEGoZJVY
ooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool00_l0000Gooooo`;o0000
W_ooool0087ooooo1_l00002ooooo`04oa0@4?ooooooooooooooo`;o00002Oooool2o`000003oooo
oonYZJWoEEEE00Wooooo00?o0000ooooooooool00oooool3o`000;Wooooo0029ooooo`04o`000?oo
ooooooooooooo`;o00002Oooool2o`0000;ooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`04o`000?ooooooooooooooo`;o0000
3Oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003o
ooooooooo`2iooooo`00ROooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMooo
ool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01cooooo1?l0002Iooooo`00
ROooool00omgMgOoV9RHooooo`02o`0000_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool2o`0001?ooooo1?l0002Iooooo`00
ROooool00oo^k^ko<S8bo`000002o`0000_ooooo1Ol00004ooooo`Co00001_ooool00ol0003ooooo
ooooo`07ooooo`;o00004oooool2o`000003ooooool0003o000009Sooooo002Vooooo`;o00001?oo
ool00ol0003oooooooooo`0Looooo`;o000000?oooooo`000?l00000V?ooool00:?ooooo0_l00000
0ooooooo0000o`000004ooooo`03o`000?oooooooooo023ooooo0_l0002Gooooo`00U?ooool2o`00
00gooooo0_l00007ooooo`03o`000?oooooooooo023ooooo0_l0002Gooooo`00U?ooool2o`0001;o
oooo0_l00002ooooo`?o00007oooool2o`0009Sooooo002Vooooo`Co00000_ooool00ol0003ooooo
ooooo`0Oooooo`;o000000?oooooo`000?l00000UOooool00:Kooooo0_l00004ooooo`03o`000?oo
oooooooo00[ooooo0_l0000Cooooo`;o000000?oooooo`000?l00000UOooool00:cooooo00?o0000
ooooooooool02_ooool2o`000003ooooool0003o000001;ooooo0_l00003ooooo`;o0000TOooool0
08;ooooo0_l0000Xooooo`03o`000?oooooooooo00cooooo0ol0000Booooo`;o00000oooool2o`00
097ooooo0022ooooo`;o0000:?ooool00ol0003oooooooooo`0<ooooo`Co00006?ooool2o`0008oo
oooo002Aooooo`;o00006Oooool00ol0003oooooooooo`0>ooooo`;o00006?ooool2o`0008oooooo
002Aooooo`;o00006Oooool00ol0003oooooooooo`0Tooooo`;o0000Toooool009Wooooo0_l0000A
ooooo`?o00003Oooool2o`0001Gooooo0_l0002Cooooo`00VOooool2o`00017ooooo00?o0000oooo
ooooool03Oooool2o`0001_ooooo0_l0002=ooooo`00[?ooool00ol0003oooooooooo`0Zooooo`;o
0000SOooool00:cooooo00?o0000ooooooooool04?ooool2o`000:Oooooo002/ooooo`03o`000?oo
oooooooo013ooooo0_l0002Wooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00X_ooool2o`0000Sooooo00?o0000ooooooooool0^Oooool00:;ooooo
0_l00008ooooo`?o00001Oooool3o`000;7ooooo002Rooooo`;o00001?ooool2o`0000;ooooo00?o
0000ooooooooool01Oooool3o`000;7ooooo002>ooooo`;o00005_ooool4o`0000;ooooo00?o0000
ooooooooool0;oooool2o`0008Sooooo0028ooooo`;o00001?ooool2o`0001Kooooo0_l00004oooo
o`03o`000?oooooooooo00Gooooo0_l000000ooooooo0000o`00000Uooooo`;o0000R?ooool008So
oooo0_l0000Rooooo`03o`000?oooooooooo00Gooooo0_l000000ooooooo0000o`00000Sooooo`Co
0000R?ooool00:cooooo00?o0000ooooooooool0;Oooool4o`0008Sooooo002Cooooo`?o00005_oo
ool2o`0000Wooooo0_l0000Uooooo`;o0000R?ooool008Kooooo0_l0000;ooooo`?o00005_ooool2
o`0000Wooooo0_l0000@ooooo`?o0000W?ooool008Kooooo0_l0000Tooooo`?o00002?ooool2o`00
013ooooo0ol0000Eooooo`;o0000QOooool00:cooooo0ol0000Looooo`;o00005?ooool2o`0008Go
oooo002/ooooo`03o`000?oooooooooo01cooooo0_l0002Kooooo`00[?ooool00ol0003ooooooooo
o`0Mooooo`;o0000V_ooool00:cooooo00?o0000ooooooooool02oooool2o`0000oooooo0ol0002J
ooooo`00V?ooool2o`0001;ooooo00?o0000ooooooooool02oooool4o`0000gooooo0_l0000Eoooo
o`;o0000Q?ooool0097ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`;o000000?oooooob4Q
8OlQ8B401Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool03Oooool2
o`0002Cooooo0_l000000ooooooo0000o`000021ooooo`00TOooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0=_ooool2
o`00087ooooo0029ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00_ooooo0_l00003
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0=oooool2o`00083ooooo002;oooo
o`?o00000oooool01Ol0003ooooooooooooooooo000000_ooooo0_l00002ooooo`03ogMgMolb<S;o
oooo00Cooooo0ol0000gooooo`;o0000P?ooool008cooooo0_l00003ooooo`05o`000?oooooooooo
ooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool04?oo
ool2o`0002?ooooo0_l00002ooooo`;o0000O_ooool0097ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04?ooool2o`0002?ooooo0_l0
0002ooooo`;o0000O_ooool008Cooooo0_l00005ooooo`;o00001?ooool2o`000003oooooonHV9So
MgMg00;o00002_ooool00ol0003oooooooooo`05ooooo`?o00004_ooool2o`000:Oooooo0024oooo
o`?o00001?ooool2o`0000Cooooo0ol000001?lb<S;ok^k^o`000?l0000:ooooo`Co00001?ooool3
o`0001;ooooo0_l0000=ooooo`;o00000_ooool2o`0009Cooooo0025ooooo`;o00009Oooool00ol0
003oooooooooo`0@ooooo`;o00003Oooool2o`0000;ooooo0_l0002Dooooo`00[?ooool00ol0003o
ooooooooo`0Sooooo`;o0000U?ooool00:cooooo00?o0000ooooooooool0^Oooool009Gooooo0_l0
000Eooooo`?o00008oooool2o`0009Cooooo0024ooooo`;o00001?ooool2o`0000Wooooo0_l0000E
ooooo`03o`000?oooooooooo02?ooooo0_l0002Dooooo`00Q?ooool2o`0000Cooooo0_l0000Koooo
o`;o00000oooool01?l0003oooooo`000?l0002hooooo`00Yoooool2o`0000?ooooo00Co0000oooo
ool0003o0000^?ooool00:cooooo00?o0000ooooooooool0^Oooool00:Sooooo0_l00002ooooo`03
o`000?oooooooooo00Sooooo0_l0002_ooooo`00Toooool2o`0000Cooooo0_l0000=ooooo`;o0000
0_ooool00ol0003oooooooooo`08ooooo`?o0000[_ooool009?ooooo0_l00004ooooo`;o00004Ooo
ool00ol0003oooooooooo`02o`0000Oooooo1?l00008ooooo`;o0000X_ooool00:cooooo1Ol00009
ooooo`;o00002?ooool2o`0002Wooooo0_l0001gooooo`00S_ooool2o`0000;ooooo0_l0000Hoooo
o`03o`000?oooooooooo043ooooo0_l0001gooooo`00S_ooool2o`0000;ooooo0_l0000Hooooo`03
o`000?oooooooooo01Sooooo0_l0002Oooooo`00[?ooool00ol0003oooooooooo`0;ooooo`;o0000
2_ooool3o`0000oooooo0_l0000Dooooo`;o0000N?ooool00:Gooooo0_l00005ooooo`03o`000?oo
oooooooo00_ooooo0_l0000:ooooo`?o00003oooool2o`0001Cooooo0_l0001hooooo`00XOooool2
o`0000;ooooo0ol00004ooooo`;o00003_ooool2o`0001_ooooo0_l0000Cooooo`;o0000N?ooool0
0:7ooooo0_l00003ooooo`;o00001?ooool2o`0000kooooo0_l0000Kooooo`;o0000SOooool00:co
oooo00?o0000ooooooooool0:_ooool2o`0008gooooo002Booooo`;o00006?ooool3o`0002[ooooo
0_l0002=ooooo`00T_ooool2o`0001Sooooo00?o0000ooooooooool0:_ooool2o`0008gooooo002/
ooooo`03o`000?oooooooooo04Gooooo0_l0001booooo`00[?ooool00ol0003oooooooooo`02o`00
04?ooooo0_l0001booooo`00TOooool2o`0000[ooooo0_l0000=ooooo`03o`000?oooooooooo00;o
0000]oooool008;ooooo0_l0000=ooooo`;o00000_ooool2o`0000Kooooo0_l0000<ooooo`;o0000
2?ooool2o`0000Oooooo0_l0002Xooooo`00P_ooool2o`00017ooooo0_l0000Dooooo`;o00002?oo
ool4o`0000Gooooo0_l0000fooooo`;o0000L?ooool008;ooooo0ol0000Wooooo`03o`000?oooooo
oooo00Sooooo0_l0000Aooooo`;o0000:_ooool2o`00073ooooo0023ooooo`;o00005oooool2o`00
00kooooo00?o0000ooooooooool06oooool2o`0000oooooo0_l0002;ooooo`00V?ooool2o`0000;o
oooo0_l0000>ooooo`?o00002?ooool2o`0002;ooooo0_l0002;ooooo`00U?ooool2o`0000;ooooo
0_l0000Booooo`03o`000?oooooooooo00Sooooo0_l0000Booooo`;o0000Voooool009Cooooo0_l0
000Fooooo`03o`000?oooooooooo00Sooooo0_l0000Booooo`;o00009oooool2o`0007;ooooo002/
ooooo`03o`000?oooooooooo04Gooooo1?l0001`ooooo`00[?ooool3o`0004Oooooo0_l0001`oooo
o`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B42ooooo`Oo00001?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo0ol0000Mooooo`;o0000V_ooool008Wooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q0_ooool2o`000005oiRHV?lQ8B7ok^k^oooooom4A4@01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01Cooooo0_l00007ooooo`;o0000V_oo
ool0087ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^
kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05?ooool2o`0003?ooooo0_l0
001^ooooo`00ROooool01Ol0003ooooooooooooooooo000000;ooooo0_l00009ooooo`03oiRHV?lQ
8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0001Cooooo0_l0000cooooo`;o0000K_oo
ool008Wooooo00Go0000ooooooooooooooooo`000002ooooo`;o00002_ooool00omgMgOoIVIVoooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Dooooo`;o0000
Xoooool008Wooooo00Go410@oooooooooooooooooa0@4008ooooo`;o00001Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_l0002gooooo`00ROoo
ool01OmgMgOoV9RHo`000?l0003oMgMg00Sooooo0_l000001_oooooo0000okZj^_ooooooV9RHoa0@
40Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02o`0004Oooooo0_l0001^oooo
o`00ROooool01Oo^k^ko<S8bo`000?l0003ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004
ooooo`Co00001_ooool00ol0003oooooooooo`0Oooooo`;o00004_ooool2o`0001Cooooo0_l0001^
ooooo`00[?ooool00ol0003oooooooooo`0=ooooo`;o00004?ooool2o`0001;ooooo0_l00024oooo
o`00Soooool2o`0000_ooooo0_l0000>ooooo`03o`000?oooooooooo00gooooo0_l0000Aooooo`?o
00003oooool2o`0008Gooooo002?ooooo`;o000000?oooooo`000?l000002?ooool2o`0000kooooo
00?o0000ooooooooool08?ooool3o`0000oooooo0_l0000Gooooo`;o0000K?ooool009;ooooo0_l0
000Hooooo`?o0000Boooool2o`0006cooooo002/ooooo`03o`000?oooooooooo037ooooo0_l0000I
ooooo`;o0000Joooool00:cooooo00?o0000ooooooooool05Oooool2o`0001[ooooo0_l0000Ioooo
o`;o0000Joooool0087ooooo0_l0000Yooooo`03o`000?oooooooooo01Gooooo0_l0002Rooooo`00
POooool2o`0002Wooooo00?o0000ooooooooool08_ooool2o`0009Gooooo001kooooo`;o0000;ooo
ool00ol0003oooooooooo`0=ooooo`;o00004oooool2o`00013ooooo0_l00023ooooo`00Noooool2
o`0000Cooooo0_l0000Yooooo`03o`000?oooooooooo00gooooo0_l0000Dooooo`;o00003Oooool4
o`0008?ooooo0021ooooo`;o00003?ooool2o`0001_ooooo00Co0000ooooool0003o00008_ooool2
o`0000gooooo1?l00023ooooo`00POooool2o`0000cooooo0_l00009ooooo`;o00004?ooool4o`00
01Oooooo0_l0000Jooooo`;o0000Poooool0087ooooo0_l0000Gooooo`;o00004?ooool00ol0003o
ooooooooo`0Hooooo`;o0000Woooool00:cooooo00?o0000ooooooooool0^Oooool008Kooooo0_l0
000?ooooo`;o00004oooool00ol0003oooooooooo`2iooooo`00Q_ooool2o`0000oooooo0_l0000C
ooooo`03o`000?oooooooooo01Oooooo0_l0000booooo`;o0000K?ooool00:cooooo00?o0000oooo
ooooool05oooool2o`0003;ooooo0_l00002ooooo`;o0000J?ooool0083ooooo0_l0000Zooooo`03
o`000?oooooooooo00Sooooo0_l00005ooooo`;o00008_ooool2o`0001[ooooo0_l0001Xooooo`00
P?ooool2o`0002[ooooo00?o0000ooooooooool01?ooool2o`0000;ooooo0_l00005ooooo`;o0000
2?ooool2o`0001Sooooo0_l00024ooooo`00Q_ooool2o`0002Cooooo00?o0000ooooooooool01?oo
ool2o`0001;ooooo0ol0000booooo`;o0000J_ooool008Kooooo0_l00002ooooo`;o00008?ooool3
o`0001Sooooo0_l0000cooooo`;o0000J_ooool008[ooooo0_l0000Pooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo03Oooooo0_l0000Fooooo`;o0000J?ooool000Wooooo
1?l000000ol@413oooooooooo`0Fooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00?oA4A4o`000?l00000
0_l0000Fooooo`03o`000?oooooooooo013ooooo0_l00006ooooo`05onk^k_l0003o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`06odA4A?l0003o0000oc8b<_oMgMgooooo0_l0000<
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2o`0000Gooooo00GoA4A4o`000?l0003o<S8b
omgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_oo
ool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1?l000000ol@413oooooooooo`0Boooo
o`002oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool2o`0000?ooooo
0_l0000Aooooo`03o`000?oooooooooo00Wooooo0_l00005ooooo`;o00001_ooool01OmgMgOo0000
o`000?nHV9SoMgMg00Gooooo0_lQ8B402Ooooooo0000o`000?ooooooV9RHob4Q8Oo^k^koooooodA4
A007ooooo`03ogMgMol0003o000000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`;o0000
00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`0Iooooo`03
o`000?oooooooooo01Cooooo0006o`0000Gooooo00?o0000ooooooooool04?ooool6o`0000;ooooo
00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000oooooooo
ool01Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo
00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09
ooooo`04o`000?ooooooooooooooo`;o00004Oooool00ol0003oooooooooo`09ooooo`;o00003Ooo
ool01Ol@413ooooooooooooooooo410@00Sooooo0_l00002ooooo`03oiRHV?lQ8B7ok^k^00Wooooo
1?l0000<ooooo`05oa0@4?ooooooooooooooool@41001?ooool2o`0000[ooooo00?o0000oooooooo
ool03Oooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01So
oooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b
<_ooool03_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool03_ooool0
1Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8boooo
o`0Eooooo`;o00004_ooool2o`0000Gooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool00_l0000<ooooo`05o`000?ooooooooooooooool0
00003oooool00omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003_ooool00olQ
8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Wooooo00?o0000ooooooooool05?ooool000_o
oooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<
c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00
000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000ko
oooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Kooooo0_l00006oooo
o`;o00002_ooool2o`0000Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKo
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000>oooo
o`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Jooooo`03o`000?oooooo
oooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go410@oooooooooooooooooa0@400>
ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00oooooo
00Ko0000ooooool0003o0000ooooool0000Jooooo`?o00001Oooool2o`00017ooooo00Go410@oooo
oooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04Oooool0
1Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`0Aooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01_l0003o^[ZjoooooonHV9So410@ooooo`;o000000?oooooo`000?ooool0
6Oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o
^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
5?ooool000Wooooo00?oEEEEofIVI_l000006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
1Ol00004ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0000G
ooooo`03o`000?oooooooooo01Sooooo00Gok^k^o`000?l0003o<S8bonk^kP09ooooo`;o000000Go
V9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000Ioooo
o`03oeEEEOmVIVKo000001Kooooo002/ooooo`03o`000?oooooooooo01Wooooo0_l0000;ooooo`;o
0000TOooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool02_oo
ool2o`000:;ooooo0_l00002ooooo`;o00001Oooool00:cooooo00?o0000ooooooooool02_ooool2
o`0002gooooo0_l0001cooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1Oooool00:cooooo00?o
0000ooooooooool0>Oooool2o`0007Cooooo00CogMgMo`000?l@413oc<c<1_ooool000Ooooooool0
001<o`0000cooooo00Cok^k^ob4Q8Ol@413ok^k^1_ooool000Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooooooo`;o00000_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool3o`0000Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool02_ooool01?lQ8B7oMgMgogMgMolb<S86ooooo`001oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`02o`0002Cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0<ooooo`;o0000
6?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
2Oooool2o`0000;ooooo0_l00005ooooo`00Q_ooool2o`0002Cooooo00?o0000ooooooooool0=_oo
ool2o`00087ooooo0026ooooo`;o00001_ooool2o`0000Cooooo0_l0000Fooooo`03o`000?oooooo
oooo017ooooo0_l0002Vooooo`00P?ooool2o`0000Sooooo0_l00002ooooo`;o00001?ooool2o`00
01Kooooo00?o0000ooooooooool04Oooool2o`0002?ooooo0_l00021ooooo`00P?ooool2o`0000So
oooo0_l00008ooooo`;o00005_ooool00ol0003oooooooooo`0Uooooo`;o00003oooool2o`00087o
oooo002Aooooo`;o00006Oooool00ol0003oooooooooo`0@ooooo`;o00004oooool2o`0009;ooooo
002Aooooo`;o00006Oooool3o`00013ooooo0_l0002Wooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`0Kooooo`;o0000W?ooool00:cooooo00?o0000oooooooo
ool06oooool2o`0001cooooo0_l0001nooooo`00QOooool2o`0002Gooooo00?o0000ooooooooool0
6_ooool2o`0001gooooo0_l0001nooooo`00QOooool3o`0002Cooooo00?o0000ooooooooool06_oo
ool2o`0001[ooooo0_l00021ooooo`00Q_ooool2o`0002Cooooo00?o0000ooooooooool09Oooool3
o`0000kooooo0_l00021ooooo`00[?ooool00ol0003oooooooooo`0Uooooo`?o0000TOooool00:co
oooo00?o0000ooooooooool04?ooool2o`0000Oooooo0_l0002Nooooo`00N_ooool2o`00033ooooo
0ol0000@ooooo`;o00001oooool2o`0001_ooooo0_l00021ooooo`00N_ooool2o`00033ooooo00?o
0000ooooooooool06_ooool2o`0000Wooooo1?l0000=ooooo`;o0000POooool00:cooooo00?o0000
ooooooooool00_l0000Hooooo`;o00002Oooool4o`0000gooooo0_l00021ooooo`00[?ooool00ol0
003oooooooooo`02o`0000Oooooo0_l0000Kooooo`;o00009_ooool2o`0006Wooooo002;ooooo`;o
00007oooool00ol0003oooooooooo`09ooooo`;o0000@oooool2o`0006Wooooo002;ooooo`;o0000
7oooool00ol0003oooooooooo`1>ooooo`;o0000JOooool008Oooooo0_l0000Sooooo`03o`000?oo
oooooooo04kooooo0_l0001Yooooo`00POooool2o`0000Cooooo0_l0000Sooooo`03o`000?oooooo
oooo01Sooooo0_l0002Oooooo`00POooool2o`0002Wooooo0ol00008ooooo`;o00003_ooool2o`00
09oooooo002/ooooo`03o`000?oooooooooo00Sooooo0_l00005ooooo`;o00009oooool2o`0007oo
oooo002/ooooo`03o`000?oooooooooo00Cooooo0_l00009ooooo`;o00009oooool2o`0001Kooooo
0_l0001Wooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o0000BOooool3o`0006Oooooo002/
ooooo`03o`000?oooooooooo01Sooooo0_l0000eooooo`;o0000J?ooool00:cooooo00?o0000oooo
ooooool03oooool2o`0000Oooooo0_l0002Oooooo`00[?ooool00ol0003oooooooooo`0?ooooo`;o
00009?ooool2o`0008;ooooo002/ooooo`03o`000?oooooooooo01Sooooo0_l0000Kooooo`Go0000
Ooooool008_ooooo0_l0000Oooooo`?o00006?ooool2o`0000Wooooo0_l0000Aooooo`Co0000Oooo
ool008_ooooo0_l00002ooooo`;o00006oooool00ol0003oooooooooo`0Sooooo`;o00004?ooool4
o`00083ooooo002?ooooo`?o00001?ooool2o`0001Cooooo00?o0000ooooooooool0=Oooool3o`00
087ooooo002@ooooo`;o00001?ooool2o`000003ooooool0003o0000017ooooo00?o0000oooooooo
ool08oooool4o`0009;ooooo0027ooooo`;o00002_ooool2o`0000Cooooo0_l0000Aooooo`03o`00
0?oooooooooo02?ooooo1?l0000>ooooo`;o0000P_ooool008Oooooo0_l0000:ooooo`;o00005ooo
ool01?l0003oooooooooooooool2o`0003;ooooo0_l00022ooooo`00ROooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00;ooooo0_l000000ooooooo8B4Qob4Q8@04ooooo`Go00001?ooool01Om4A4Co0000
o`000?lb<S;ogMgM00Gooooo00Co0000oooooooooooooooo0_l0002fooooo`00Qoooool2o`000005
ogMgMonHV9SooooooiRHV?mgMgL00_ooool2o`000003oooooolQ8B7o8B4Q00Cooooo00GoV9RHob4Q
8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0^Oooool0
08Oooooo0_l000000ol@413oooooooooo`02o`0000;ooooo0_l00008ooooo`03oiRHV?lQ8B7ok^k^
00Wooooo00?o0000ooooooooool00oooool3o`0000gooooo0_l0000Wooooo`;o0000POooool008Wo
oooo00?o0000ooooooooool00_l00002ooooo`;o00002Oooool00onHV9So8B4Qonk^kP07ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool01_ooool2o`0000Gooooo0_l0000Booooo`?o
00003oooool2o`000003ooooool0003o0000087ooooo0029ooooo`05o`000?ooooooooooooooool0
00003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool01?l0
003oooooooooooooool2o`0000?ooooo0_l00004ooooo`;o00004oooool3o`0000oooooo0_l00024
ooooo`00Qoooool2o`000005oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;o00001Oooool01?l0003oooooooooooooool2o`0000Wooooo0_l0
000Dooooo`;o0000UOooool008Oooooo0_l000001OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo0_l0
00001?nj^[[ooooooiRHV?l@4104ooooo`03o`000?oooooooooo00;o00001Oooool00ol0003ooooo
ooooo`0Eooooo`;o00002oooool2o`00013ooooo0_l00023ooooo`00ROooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00[ooooo0_l000001?l@413o0000ob4Q8Oo<c<`4ooooo`Co00001_ooool00ol0003o
ooooooooo`0;ooooo`;o00002?ooool2o`0001gooooo0_l00023ooooo`00TOooool2o`0001Wooooo
00?o0000ooooooooool01?ooool2o`0000Gooooo0_l0000Vooooo`;o0000Q?ooool0097ooooo0_l0
0005ooooo`;o00004_ooool01?l0003oooooo`000?l00003ooooo`;o0000;Oooool2o`0008Cooooo
002Hooooo`;o00004_ooool01?l0003oooooo`000?l0000aooooo`;o0000QOooool00:cooooo0ol0
000booooo`?o0000Q?ooool008?ooooo0_l0000Wooooo`03o`000?oooooooooo01;ooooo0_l0000<
ooooo`;o00004Oooool2o`0008Cooooo001looooo`;o00001Oooool2o`0002Oooooo00?o0000oooo
ooooool04_ooool2o`0000cooooo0_l0002Gooooo`00O?ooool2o`0001Cooooo0_l0000Hooooo`03
o`000?oooooooooo01kooooo0_l0002Iooooo`00R?ooool2o`0000Sooooo0_l0000;ooooo`;o0000
2oooool00ol0003oooooooooo`0Nooooo`;o00004?ooool2o`0008Oooooo0028ooooo`;o00002?oo
ool2o`0000_ooooo0_l00005ooooo`;o00001?ooool00ol0003oooooooooo`08ooooo`;o00009_oo
ool2o`0008Oooooo002Booooo`;o00003Oooool2o`0000?ooooo0_l00004ooooo`03o`000?oooooo
oooo00Sooooo0_l0002_ooooo`00Voooool2o`0000Cooooo0_l00009ooooo`03o`000?oooooooooo
00;ooooo0_l00004ooooo`;o00002?ooool2o`0000_ooooo0_l0000@ooooo`?o0000QOooool008?o
oooo0_l00009ooooo`;o00002oooool2o`0000oooooo0ol00002ooooo`;o00001?ooool2o`0000So
oooo0_l0000;ooooo`;o00004?ooool3o`0008Gooooo0023ooooo`;o00002Oooool2o`0000Oooooo
0_l0000Cooooo`03o`000?oooooooooo00Sooooo0_l0000Xooooo`;o0000QOooool009Oooooo0_l0
000Cooooo`03o`000?oooooooooo00Sooooo0_l00010ooooo`;o0000KOooool00:cooooo00?o0000
ooooooooool0B_ooool2o`0006gooooo0023ooooo`;o00009oooool00ol0003oooooooooo`0@oooo
o`;o00007?ooool2o`0008Wooooo0023ooooo`;o00006?ooool2o`0000gooooo00?o0000oooooooo
ool04?ooool2o`0001cooooo0_l00029ooooo`00WOooool2o`0000Sooooo0_l00003ooooo`03o`00
0?oooooooooo0;Wooooo002Mooooo`;o00002?ooool2o`0000?ooooo00?o0000ooooooooool0Aooo
ool2o`00073ooooo0029ooooo`;o00006_ooool2o`0000Gooooo0ol0000^ooooo`;o00005_ooool3
o`00073ooooo0029ooooo`;o00003oooool2o`0000Wooooo0_l00005ooooo`03o`000?oooooooooo
00gooooo0_l0000Oooooo`;o00005Oooool3o`00077ooooo002Iooooo`?o00001_ooool2o`0000So
oooo00?o0000ooooooooool03Oooool2o`0003Kooooo0_l0001booooo`00VOooool2o`0000Oooooo
0_l00008ooooo`?o0000^Oooool00:cooooo0ol0000Jooooo`;o0000WOooool00:cooooo00?o0000
ooooooooool06_ooool2o`0009gooooo002@ooooo`;o00006_ooool00ol0003oooooooooo`0Hoooo
o`;o0000Woooool0093ooooo0_l00009ooooo`;o00003_ooool2o`0000Gooooo0_l0000Cooooo`;o
00004_ooool2o`0008_ooooo002Eooooo`;o00001?ooool2o`0000kooooo1?l00003ooooo`;o0000
9oooool2o`0008_ooooo002Eooooo`;o00005Oooool00ol0003oooooooooo`0:ooooo`;o0000[Ooo
ool008Gooooo0_l0000Gooooo`;o00003?ooool00ol0003oooooooooo`0:ooooo`;o00003Oooool2
o`0002Sooooo0_l0001dooooo`00QOooool2o`0001Oooooo0_l0000<ooooo`04o`000?oooooooooo
ooooo`;o00005?ooool4o`0002Sooooo0_l0001dooooo`00[?ooool01?l0003oooooooooooooool2
o`0001Cooooo0ol0002Oooooo`00Roooool2o`0001oooooo00?o0000ooooooooool0:Oooool2o`00
08kooooo002;ooooo`;o00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`04odA4A?l0003o0000oc8b<P;o00001?ooool00ol0003oooooooooo`08ooooo`;o00007oooool2
o`0008kooooo002Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo0ol00004
ooooo`04o`000?oooooo0000o`0000Oooooo0_l0000gooooo`;o0000M_ooool0097ooooo00Go410@
oooooooooooooooooa0@400?ooooo`;o00001Oooool01?l0003oooooo`000?l0000Uooooo`;o0000
6Oooool2o`0007Kooooo002=ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000oooooo
00?oMgMgoc8b<_ooool01?ooool3o`0000Sooooo0_l0000Looooo`;o0000TOooool008gooooo0_l0
0002ooooo`05o`000?ooooooooooooooool000001?ooool2o`0000Kooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo00Sooooo0_l0000Mooooo`;o0000T?ooool0097ooooo
00Go410@oooooooooooooooooa0@4004ooooo`;o00001_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo02Oooooo0_l0002@ooooo`00Q_ooool2o`0000Wooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0^Oooool008Kooooo
0_l00009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo0_l0000Eooooo`;o
00004Oooool2o`0001Oooooo0_l0001hooooo`00Q_ooool2o`0002?ooooo0_l0000Eooooo`;o0000
3_ooool2o`000003ooooool0003o000001Oooooo0_l0001hooooo`00Q_ooool2o`0002Cooooo00?o
0000ooooooooool04Oooool2o`0000oooooo0ol0002Dooooo`00Yoooool2o`0000?ooooo00?o0000
ooooooooool04Oooool2o`0000oooooo0_l0002Eooooo`00Y_ooool3o`0000?ooooo0ol0000Roooo
o`;o0000UOooool009kooooo0ol00005ooooo`;o00001?ooool00ol0003oooooooooo`0Rooooo`;o
0000UOooool009kooooo0ol0000;ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002Sooooo`;o00001oooool00ol0003oooooooooo`0iooooo`;o0000O_ooool0
0:?ooooo0_l00007ooooo`03o`000?oooooooooo00;ooooo0_l0000eooooo`;o0000O_ooool00:co
oooo00?o0000ooooooooool00_ooool2o`0001cooooo0_l0002Gooooo`00[?ooool00ol0003ooooo
ooooo`0Pooooo`;o0000Uoooool00:cooooo1?l0000Looooo`;o0000V_ooool00:cooooo00Co0000
ooooool0003o00007?ooool2o`0009[ooooo002Aooooo`;o00001oooool2o`00013ooooo00?o0000
ooooooooool0^Oooool0097ooooo0_l00007ooooo`;o00004?ooool00ol0003oooooooooo`0Ooooo
o`;o0000V?ooool009_ooooo0_l0000?ooooo`03o`000?oooooooooo00[ooooo0_l0000Cooooo`;o
00005Oooool2o`00087ooooo0022ooooo`;o00005oooool2o`0000oooooo00?o0000ooooooooool0
2_ooool2o`0002[ooooo0_l00021ooooo`00P_ooool2o`0000Kooooo0_l0000@ooooo`;o00003Ooo
ool2o`000;_ooooo002:ooooo`;o00004?ooool2o`0000gooooo0_l0002kooooo`00[?ooool3o`00
0;Wooooo002Oooooo`;o00002oooool00ol0003oooooooooo`2iooooo`00WOooool4o`0000Kooooo
0_l00003ooooo`03o`000?oooooooooo00Gooooo0_l0000/ooooo`;o0000Q?ooool009gooooo0ol0
0004ooooo`;o000000?oooooo`000?l000000oooool00ol0003oooooooooo`05ooooo`;o0000;?oo
ool2o`0008Cooooo002Nooooo`;o00001?ooool2o`0000Kooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool01?ooool2o`000;?ooooo002Eooooo`;o00005Oooool00ol0003o
ooooooooo`03ooooo`?o0000/oooool009Gooooo0_l0000Eooooo`03o`000?oooooooooo00?ooooo
0_l0000Booooo`;o0000X?ooool00:cooooo00?o0000ooooooooool05oooool2o`000:3ooooo002/
ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool05Oooool2o`000:;ooooo002/ooooo`03
o`000?oooooooooo01Gooooo0_l0002Rooooo`00[?ooool00ol0003oooooooooo`0@ooooo`;o0000
6_ooool2o`0008_ooooo002/ooooo`03o`000?oooooooooo013ooooo1?l0000Hooooo`;o0000Rooo
ool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02o`0000?ooooo0_lQ8B46ooooo`03o`000?o^
k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01;ooooo
0_l0002Uooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00;o00000oooool2ob4Q8@Kooooo
00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00oooooo
1?l0002Vooooo`00ROooool01_l@413ooooooooooooooooo410@ooooo`;o00002_ooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03oooool4o`000:Ko
oooo0029ooooo`06o`000?ooooooooooooooool0003ooooo0_l0000;ooooo`03ob4Q8Ooooooooooo
00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`000;Wooooo0029ooooo`05o`000?oooooooooooooo
ool000003Oooool3o`0000Cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo02Oooooo0_l0002@ooooo`00ROooool01Ol@413ooooooooooooooooo410@00gooooo0ol00004
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09oooool2o`00093ooooo0029oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00Co
0000oooooooooooooooo0_l00004ooooo`03o`000?oooooooooo00oooooo0_l0002Xooooo`00ROoo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1_l00003ooooo`Ko00001?ooool00ol0003ooooo
ooooo`0?ooooo`;o0000Z?ooool009gooooo0_l00004ooooo`;o00001oooool00ol0003ooooooooo
o`2iooooo`00Xoooool2o`0000Oooooo00?o0000ooooooooool0^Oooool00:?ooooo0_l00007oooo
o`03o`000?oooooooooo0;Wooooo002Sooooo`;o00001oooool3o`0000Oooooo0ol0002_ooooo`00
[?ooool00ol0003oooooooooo`07ooooo`?o0000[oooool009?ooooo0_l0000Gooooo`03o`000?oo
oooooooo0;Wooooo002Cooooo`;o00005oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo00;o0000]oooool00:cooooo00?o0000ooooooooool00ol0002fooooo`00V?ooool2
o`0001;ooooo0ol000000ooooooo0000o`00002fooooo`00V?ooool2o`0001;ooooo0ol0002ioooo
o`00Zoooool3o`000;[ooooo002[ooooo`;o0000^oooool00:cooooo0ol0002iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00Xoooool2o`0000Cooooo0_l000000ooooooo0000ooooo`0Doooo
o`;o0000Y?ooool00:?ooooo0_l00004ooooo`;o000000?oooooo`000?ooool05?ooool2o`000:Co
oooo002Yooooo`;o000000?oooooo`000?ooool0^_ooool00:Cooooo1?l000001Ooooooo0000o`00
0?oooooo00000;_ooooo002Tooooo`Co00001?ooool00ol0003oooooooooo`0Aooooo`;o0000Y_oo
ool00:cooooo00?o0000ooooooooool04Oooool2o`000:Kooooo002/ooooo`?o0000^Oooool00:co
oooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool03Oooool2o`000:[ooooo
002/ooooo`03o`000?oooooooooo00gooooo0_l0002Zooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00X_ooool4o`000003oa0@4?oooooooooo00?o
oooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000
ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo00?o0000oooooooo
ool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:;ooooo00?oEEEEofIVI_l00000`ooo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:[ooooo00Co
410@o`000?l0003o0000^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000
ooooooooool0^_ooool00:_ooooo00Ko0000ogMgMol0003o0000oeEEEOo^k^jgooooo`00Zoooool0
1_l0003oEEEEonk^k_ooooooMgMgoeEEEKOooooo002[ooooo`03o`000?o^k^kooooo00;ooooo00?o
0000ooooooooool0]Oooool00:_ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`2e
ooooo`00Zoooool01_l0003oEEEEonk^k_ooooooMgMgofIVI[Oooooo002Zooooo`03oa0@4?l0003o
MgMg00;o000000?oIVIVonk^k_ooool0]_ooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.54804 .81262 Mdot
.41486 .81063 Mdot
.50508 .46924 Mdot
.43677 .68634 Mdot
.52268 .24435 Mdot
.63417 .53211 Mdot
.50538 .61053 Mdot
.36706 .59705 Mdot
.46141 .96875 Mdot
.5611 .44056 Mdot
.55157 .63121 Mdot
.3854 .21429 Mdot
.44426 .09595 Mdot
.56799 .53291 Mdot
.42975 .05721 Mdot
.44523 .27151 Mdot
.41011 .29797 Mdot
.45386 .0829 Mdot
.40926 .57648 Mdot
.68472 .42445 Mdot
.48736 .08012 Mdot
.3842 .42257 Mdot
.40986 .20879 Mdot
.48195 .07339 Mdot
.52064 .04062 Mdot
.59272 .58958 Mdot
.51101 .74178 Mdot
.41044 .58131 Mdot
.69013 .47343 Mdot
.39859 .72455 Mdot
.54259 .14955 Mdot
.47783 .97501 Mdot
.37485 .68644 Mdot
.50436 .16638 Mdot
.56852 .26419 Mdot
.66738 .39322 Mdot
.64478 .73297 Mdot
.43539 .7352 Mdot
.68578 .5486 Mdot
.38967 .1832 Mdot
.49927 .01354 Mdot
.53797 .21258 Mdot
.62015 .40842 Mdot
.54561 .82385 Mdot
.5892 .73839 Mdot
.58305 .3963 Mdot
.56361 .54435 Mdot
.55525 .89481 Mdot
.51273 .80733 Mdot
.68651 .48879 Mdot
.55382 .89475 Mdot
.68562 .59379 Mdot
.68656 .80879 Mdot
.60356 .35388 Mdot
.60414 .34355 Mdot
.40807 .87293 Mdot
.36511 .51481 Mdot
.40325 .34748 Mdot
.60364 .81955 Mdot
.5995 .7134 Mdot
.58986 .43733 Mdot
.69191 .2588 Mdot
.68221 .56882 Mdot
.53942 .42834 Mdot
.36889 .56539 Mdot
.44701 .96125 Mdot
.55868 .43109 Mdot
.43878 .29716 Mdot
.44068 .75482 Mdot
.51812 .1094 Mdot
.40715 .3025 Mdot
.43643 .57257 Mdot
.56281 .47121 Mdot
.53925 .34949 Mdot
.68216 .56876 Mdot
.46435 .63858 Mdot
.68604 .80959 Mdot
.59122 .54378 Mdot
.68958 .56219 Mdot
.50513 .80843 Mdot
.61483 .26218 Mdot
.40021 .73234 Mdot
.4533 .7295 Mdot
.54315 .21932 Mdot
.38798 .7943 Mdot
.44243 .27352 Mdot
.53069 .25924 Mdot
.56496 .34876 Mdot
.39565 .51265 Mdot
.44525 .2772 Mdot
.53236 .05429 Mdot
.75913 .58791 Mdot
.54475 .55609 Mdot
.57066 .35568 Mdot
.54585 .52215 Mdot
.76495 .54426 Mdot
.56813 .52214 Mdot
.53031 .92019 Mdot
.67828 .82425 Mdot
.39541 .53961 Mdot
.51997 .85601 Mdot
.41136 .71044 Mdot
.39247 .17823 Mdot
.51831 .86434 Mdot
.57903 .19411 Mdot
.51942 .18806 Mdot
.43007 .19922 Mdot
.40751 .44429 Mdot
.54458 .55894 Mdot
.52826 .12375 Mdot
.56694 .48018 Mdot
.44985 .72808 Mdot
.48002 .9736 Mdot
.67 .37859 Mdot
.52369 .59118 Mdot
.59378 .48689 Mdot
.44305 .96199 Mdot
.46281 .97745 Mdot
.63691 .74101 Mdot
.44779 .09209 Mdot
.6566 .19728 Mdot
.47121 .08429 Mdot
.69171 .47545 Mdot
.52561 .11938 Mdot
.42208 .59133 Mdot
.67728 .41244 Mdot
.76392 .49703 Mdot
.43624 .86109 Mdot
.45418 .69236 Mdot
.3991 .26221 Mdot
.4827 .89897 Mdot
.41808 .07772 Mdot
.63637 .53353 Mdot
.62855 .45323 Mdot
.69354 .52186 Mdot
.66815 .6835 Mdot
.6855 .45192 Mdot
.56197 .46567 Mdot
.36653 .49394 Mdot
.43122 .05225 Mdot
.7337 .36754 Mdot
.51062 .69966 Mdot
.42552 .70382 Mdot
.40936 .30196 Mdot
.678 .39951 Mdot
.40668 .8782 Mdot
.42786 .28462 Mdot
.57275 .37213 Mdot
.62313 .14364 Mdot
.424 .77038 Mdot
.49169 .78576 Mdot
.48241 .07222 Mdot
.44403 .62429 Mdot
.61695 .63787 Mdot
.67072 .6644 Mdot
.68396 .57599 Mdot
.43354 .94452 Mdot
.63998 .74067 Mdot
.67028 .66867 Mdot
.56981 .68389 Mdot
.69179 .55449 Mdot
.45863 .00196 Mdot
.65307 .35112 Mdot
.62039 .42638 Mdot
.51825 .85484 Mdot
.41079 .89086 Mdot
.5943 .2164 Mdot
.44807 .77072 Mdot
.67907 .64665 Mdot
.68111 .4638 Mdot
.5286 .63185 Mdot
.46537 .78899 Mdot
.5394 .28216 Mdot
.43677 .24749 Mdot
.36922 .59639 Mdot
.76472 .53082 Mdot
.61811 .63058 Mdot
.51983 .60006 Mdot
.68943 .50135 Mdot
.68726 .60891 Mdot
.41995 .06825 Mdot
.50447 .2619 Mdot
.51122 .02502 Mdot
.42594 .48186 Mdot
.46246 .96683 Mdot
.76231 .49923 Mdot
.50122 .963 Mdot
.45054 .01004 Mdot
.62515 .42586 Mdot
.62966 .15931 Mdot
.67778 .39661 Mdot
.52298 .36099 Mdot
.68327 .24821 Mdot
.3747 .69627 Mdot
.54314 .05388 Mdot
.40164 .1342 Mdot
.56367 .33707 Mdot
.7564 .6303 Mdot
.46789 .13489 Mdot
.52793 .50281 Mdot
.52794 .51738 Mdot
.4332 .52264 Mdot
.52273 .24881 Mdot
.74905 .66012 Mdot
.49623 .88655 Mdot
.47407 .27382 Mdot
.63106 .56932 Mdot
.46367 .75148 Mdot
.43229 .37765 Mdot
.55116 .63769 Mdot
.39993 .2427 Mdot
.59241 .52605 Mdot
.5964 .22024 Mdot
.4926 .2448 Mdot
.50912 .86769 Mdot
.59163 .503 Mdot
.42502 .50369 Mdot
.59729 .70866 Mdot
.37474 .2891 Mdot
.59317 .47245 Mdot
.58136 .8495 Mdot
.58113 .1945 Mdot
.63202 .29997 Mdot
.47588 .23791 Mdot
.4802 .18851 Mdot
.44327 .88667 Mdot
.53559 .60505 Mdot
.43141 .0534 Mdot
.66202 .20218 Mdot
.42094 .39899 Mdot
.4946 .36078 Mdot
.74012 .67958 Mdot
.44547 .81966 Mdot
.52249 .71968 Mdot
.64646 .18439 Mdot
.45126 .77386 Mdot
.50273 .88671 Mdot
.45119 .09478 Mdot
.49593 .88901 Mdot
.69369 .26443 Mdot
.63349 .47351 Mdot
.61939 .25738 Mdot
.40665 .30617 Mdot
.4853 .97546 Mdot
.54476 .50945 Mdot
.66516 .66976 Mdot
.398 .54116 Mdot
.40396 .32705 Mdot
.68384 .56633 Mdot
.53746 .04933 Mdot
.52441 .5853 Mdot
.5259 .37621 Mdot
.65414 .70028 Mdot
.58478 .61953 Mdot
.47107 .79054 Mdot
.6112 .35561 Mdot
.45646 .62264 Mdot
.36585 .52834 Mdot
.57984 .85926 Mdot
.48096 .84531 Mdot
.52359 .71722 Mdot
.63983 .31666 Mdot
.48769 .7038 Mdot
.42364 .76568 Mdot
.56093 .78662 Mdot
.55911 .5791 Mdot
.62978 .51795 Mdot
.67474 .42819 Mdot
.56419 .68784 Mdot
.67127 .39563 Mdot
.60951 .3567 Mdot
.55981 .42482 Mdot
.49491 .82905 Mdot
.67462 .65376 Mdot
.50976 .2709 Mdot
.43386 .24772 Mdot
.53796 .91492 Mdot
.55823 .61169 Mdot
.62421 .61093 Mdot
.69085 .52006 Mdot
.45793 .70601 Mdot
.52725 .32035 Mdot
.63737 .74448 Mdot
.37932 .26243 Mdot
.40814 .42673 Mdot
.46833 .67909 Mdot
.49518 .20716 Mdot
.65613 .33223 Mdot
.57844 .38933 Mdot
.60286 .24165 Mdot
.76158 .50234 Mdot
.60351 .81579 Mdot
.40014 .1474 Mdot
.59084 .83234 Mdot
.51664 .4816 Mdot
.62871 .77697 Mdot
.67303 .23556 Mdot
.64037 .29386 Mdot
.41907 .08293 Mdot
.38586 .90005 Mdot
.51767 .7937 Mdot
.62621 .40991 Mdot
.47973 .90166 Mdot
.481 .97594 Mdot
.4987 .01581 Mdot
.56278 .5631 Mdot
.5355 .91625 Mdot
.58134 .63658 Mdot
.5193 .41536 Mdot
.40249 .23167 Mdot
.41783 .25336 Mdot
.44227 .10255 Mdot
.61119 .12939 Mdot
.51446 .63191 Mdot
.58535 .73691 Mdot
.52457 .19444 Mdot
.36772 .47802 Mdot
.48871 .70524 Mdot
.43035 .04521 Mdot
.62179 .15809 Mdot
.74367 .38517 Mdot
.41814 .45833 Mdot
.63795 .53039 Mdot
.54376 .21837 Mdot
.67852 .6005 Mdot
.47743 .18524 Mdot
.52588 .44686 Mdot
.51512 .54548 Mdot
.4203 .23585 Mdot
.36649 .40584 Mdot
.65218 .70062 Mdot
.54659 .50872 Mdot
.38936 .33 Mdot
.44994 .6843 Mdot
.43298 .50885 Mdot
.43606 .87337 Mdot
.63505 .51159 Mdot
.62074 .4275 Mdot
.56863 .6864 Mdot
.51494 .2354 Mdot
.70914 .76878 Mdot
.57595 .64996 Mdot
.40838 .7728 Mdot
.5407 .44338 Mdot
.38481 .76264 Mdot
.51864 .72376 Mdot
.68345 .44321 Mdot
.38471 .55285 Mdot
.53349 .62766 Mdot
.58711 .45299 Mdot
.73226 .36103 Mdot
.37878 .25961 Mdot
.63678 .76452 Mdot
.67077 .40312 Mdot
.53728 .7586 Mdot
.46877 .13745 Mdot
.67996 .44804 Mdot
.43479 .79882 Mdot
.37932 .2562 Mdot
.74646 .38291 Mdot
.62406 .26606 Mdot
.41677 .08223 Mdot
.43879 .03018 Mdot
.49535 .00648 Mdot
.43896 .39794 Mdot
.46526 .84166 Mdot
.43707 .04219 Mdot
.36563 .53434 Mdot
.44341 .37029 Mdot
.58092 .20342 Mdot
.56843 .66761 Mdot
.63314 .56504 Mdot
.5286 .84303 Mdot
.51348 .94065 Mdot
.50324 .88545 Mdot
.63457 .7587 Mdot
.664 .6612 Mdot
.40431 .23758 Mdot
.6497 .73769 Mdot
.39652 .28241 Mdot
.49191 .01311 Mdot
.62207 .7718 Mdot
.61748 .64374 Mdot
.44686 .63194 Mdot
.58637 .11134 Mdot
.3975 .58012 Mdot
.51611 .52863 Mdot
.42261 .05985 Mdot
.5231 .11556 Mdot
.5239 .42902 Mdot
.54769 .37898 Mdot
.59508 .55222 Mdot
.51036 .74665 Mdot
.54704 .90679 Mdot
.58083 .18881 Mdot
.68145 .24773 Mdot
.42587 .05365 Mdot
.45648 .15181 Mdot
.71136 .75759 Mdot
.46646 .14115 Mdot
.42978 .27148 Mdot
.443 .22601 Mdot
.45195 .37731 Mdot
.36612 .42491 Mdot
.38356 .22704 Mdot
.51493 .73333 Mdot
.52975 .6363 Mdot
.53625 .69457 Mdot
.46773 .23131 Mdot
.5856 .10083 Mdot
.56309 .33019 Mdot
.65032 .33857 Mdot
.49166 .73849 Mdot
.48365 .79247 Mdot
.47671 .71356 Mdot
.54974 .29897 Mdot
.48978 .14936 Mdot
.5139 .74356 Mdot
.48421 .27646 Mdot
.64101 .17131 Mdot
.36656 .52005 Mdot
.46247 .389 Mdot
.57712 .28108 Mdot
.43083 .19712 Mdot
.59897 .69268 Mdot
.55968 .69393 Mdot
.46108 .78766 Mdot
.58536 .10767 Mdot
.76665 .56359 Mdot
.47961 .90478 Mdot
.56998 .97183 Mdot
.53673 .83959 Mdot
.49688 .29093 Mdot
.42951 .92538 Mdot
.44859 .02613 Mdot
.54344 .6579 Mdot
.38433 .52175 Mdot
.70288 .7802 Mdot
.52327 .65871 Mdot
.51362 .38068 Mdot
.45499 .20799 Mdot
.63605 .30486 Mdot
.52807 .7683 Mdot
.75802 .61154 Mdot
.42858 .4187 Mdot
.58932 .31704 Mdot
.52696 .19253 Mdot
.54541 .47182 Mdot
.51276 .63503 Mdot
.5269 .31091 Mdot
.36647 .58078 Mdot
.50745 .66042 Mdot
.6918 .54013 Mdot
.43919 .87669 Mdot
.58429 .74435 Mdot
.67408 .40174 Mdot
.58825 .21779 Mdot
.43373 .19423 Mdot
.76612 .48128 Mdot
.55097 .39098 Mdot
.36738 .38527 Mdot
.53216 .04265 Mdot
.55711 .58824 Mdot
.63199 .77224 Mdot
.56146 .69195 Mdot
.40483 .34558 Mdot
.6828 .43661 Mdot
.52241 .85355 Mdot
.40705 .50399 Mdot
.58759 .45404 Mdot
.49739 .1552 Mdot
.68489 .23892 Mdot
.62733 .4619 Mdot
.47385 .64757 Mdot
.61622 .39953 Mdot
.50504 .81026 Mdot
.43477 .4337 Mdot
.4239 .38284 Mdot
.59997 .34182 Mdot
.62701 .43203 Mdot
.52782 .54723 Mdot
.58762 .59909 Mdot
.44315 .95634 Mdot
.51252 .22443 Mdot
.57128 .76562 Mdot
.44305 .76585 Mdot
.40891 .52937 Mdot
.46517 .31041 Mdot
.47518 .30541 Mdot
.42498 .84531 Mdot
.56648 .86747 Mdot
.65488 .3537 Mdot
.43175 .72726 Mdot
.6877 .472 Mdot
.40606 .11237 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool009kooooo0_l00004ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0^Oooool009kooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo
0ol0002kooooo`00Voooool2o`0000Oooooo00?o0000ooooooooool00oooool3o`000;_ooooo002K
ooooo`;o00001oooool00ol0003oooooooooo`02ooooo`Co0000^oooool00:;ooooo00?oEEEEofIV
I_l000001?ooool4o`000;_ooooo002[ooooo`;o0000^oooool00:cooooo00?o0000ooooooooool0
^Oooool00:cooooo1Ol0002gooooo`00Voooool2o`0000oooooo00?o0000ooooooooool00_l0002g
ooooo`00Uoooool2o`0000;ooooo0_l0000?ooooo`03o`000?oooooooooo0;Wooooo002Gooooo`;o
00004oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?oo
ool00ol0003oooooooooo`03ooooo`;o0000]?ooool009Oooooo0_l0000Cooooo`03o`000?oooooo
oooo00?ooooo0_l00002ooooo`;o0000/?ooool009Gooooo1?l0000Cooooo`03o`000?oooooooooo
00Oooooo0_l0002`ooooo`00UOooool2o`0001Gooooo00?o0000ooooooooool02Oooool2o`000:ko
oooo002Eooooo`;o00005Oooool3o`0000Wooooo0_l0002^ooooo`00Toooool4o`0001Gooooo00?o
0000ooooooooool01oooool2o`0000;ooooo0_l0002/ooooo`00Toooool4o`0001Gooooo00?o0000
ooooooooool01oooool2o`0000;ooooo0_l0002/ooooo`00T_ooool4o`0001Kooooo00?o0000oooo
ooooool0^Oooool009;ooooo0_l0000Hooooo`03o`000?oooooooooo0;Wooooo002Aooooo`;o0000
6Oooool00ol0003oooooooooo`2iooooo`00TOooool2o`0001Wooooo00?o0000ooooooooool0^Ooo
ool00:Kooooo0_l00004ooooo`03o`000?oooooooooo0;Wooooo002Vooooo`;o00001?ooool3o`00
0;Wooooo002Aooooo`;o00005?ooool2o`0000?ooooo00?o0000ooooooooool0^Oooool0093ooooo
0ol00009ooooo`;o00002Oooool2o`0000?ooooo00?o0000ooooooooool0^Oooool0093ooooo0ol0
0009ooooo`;o00001?ooool2o`0000Sooooo00?o0000ooooooooool0^Oooool00:;ooooo0_l00008
ooooo`03o`000?oooooooooo0;Wooooo002Jooooo`;o00004?ooool00ol0003oooooooooo`2ioooo
o`00V_ooool3o`0000oooooo00?o0000ooooooooool0^Oooool009Wooooo1?l0000?ooooo`03o`00
0?oooooooooo0;Wooooo002Iooooo`;o00004Oooool3o`0001Wooooo0_l0002Nooooo`00VOooool2
o`00017ooooo00?o0000ooooooooool06Oooool2o`0009kooooo002Iooooo`;o00004Oooool00ol0
003oooooooooo`0Iooooo`;o0000W_ooool00:cooooo00?o0000ooooooooool00oooool2o`0001Co
oooo0_l0002Nooooo`00SOooool2o`0001gooooo00?o0000ooooooooool00oooool2o`0001Cooooo
0_l0002Nooooo`00SOooool2o`0001gooooo00?o0000ooooooooool01?ooool2o`0001?ooooo0_l0
002Nooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^
k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00Cooooo
0ol0002booooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEE
EOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`05ooooo`;o0000
/_ooool0087ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEE
ooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol00006ooooo`;o0000/Oooool008Wooooo00Go
0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`06ooooo`;o0000/Oooool008Wooooo00Go0000oooooooooooooooo
o`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo027ooooo0_l0002Fooooo`00ROooool01Ol@413oooooo`000?l0003o410@00ko
oooo00?oZJVYogMgMoooool00_ooool2o`0000Wooooo00?o0000ooooooooool08Oooool2o`0009Ko
oooo0029ooooo`05ogMgMonHV9So0000o`000?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b
00?ooooo0_l00009ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool5o`0000?ooooo1Ol00006ooooo`03o`000?oooooooooo0;Wooooo002Pooooo`;o
00002_ooool00ol0003oooooooooo`0Uooooo`;o0000T_ooool00:3ooooo0_l0000:ooooo`03o`00
0?oooooooooo02Gooooo0_l0002Booooo`00Roooool2o`0001_ooooo0_l00002ooooo`03o`000?oo
oooooooo00_ooooo0_l0002/ooooo`00Roooool2o`00013ooooo0_l00009ooooo`;o00000_ooool3
o`0000_ooooo0_l0002/ooooo`00WOooool2o`0000cooooo0_l0002kooooo`00Zoooool2o`0002Oo
oooo0_l0002Booooo`00[?ooool00ol0003oooooooooo`0Uooooo`Co0000T?ooool00:cooooo00?o
0000ooooooooool09oooool2o`00093ooooo002/ooooo`?o0000^Oooool00:cooooo0ol0000[oooo
o`;o0000S?ooool00:cooooo00?o0000ooooooooool0:oooool2o`0008cooooo002/ooooo`?o0000
^Oooool008Sooooo0_l0000Rooooo`03o`000?oooooooooo0;Wooooo0027ooooo`?o00008_ooool0
0ol0003oooooooooo`2iooooo`00Qoooool2o`0001_ooooo0_l00006ooooo`03o`000?oooooooooo
02gooooo0_l0002:ooooo`00Y?ooool3o`0000Gooooo00?o0000ooooooooool00oooool2o`0001;o
oooo0_l0000Dooooo`;o0000R_ooool00:Gooooo0_l00005ooooo`03o`000?oooooooooo00?ooooo
1?l0000@ooooo`;o0000X?ooool009Kooooo0_l0000Dooooo`03o`000?oooooooooo00Gooooo0_l0
000@ooooo`;o0000X?ooool009Gooooo0ol0000Dooooo`03o`000?oooooooooo00Gooooo0_l0000@
ooooo`;o00005oooool2o`0008Oooooo002Dooooo`?o00005Oooool3o`00033ooooo0_l00027oooo
o`00U?ooool2o`0001Kooooo00?o0000ooooooooool05oooool2o`0001Wooooo0_l00025ooooo`00
Z_ooool3o`0001Wooooo0_l0000Iooooo`;o0000QOooool008kooooo0_l0000=ooooo`;o00002ooo
ool3o`000;_ooooo002>ooooo`;o00003Oooool2o`0000gooooo00?o0000ooooooooool02Oooool2
o`000:kooooo0026ooooo`;o00009?ooool00ol0003oooooooooo`09ooooo`;o00004Oooool2o`00
09_ooooo0026ooooo`;o00009?ooool00ol0003oooooooooo`0;ooooo`;o00003Oooool4o`0009_o
oooo002/ooooo`03o`000?oooooooooo00_ooooo0_l0000=ooooo`Co0000Voooool00:cooooo0ol0
00000ooooooo0000o`00000Iooooo`;o0000Voooool008Gooooo0_l0000Booooo`;o00004Oooool0
1?l0003oooooooooooooool2o`000;Kooooo0025ooooo`;o00001?ooool2o`0000cooooo0_l00006
ooooo`;o00002Oooool00ol0003oooooooooo`2iooooo`00Roooool2o`0001Cooooo0_l00009oooo
o`03o`000?oooooooooo0;Wooooo002<ooooo`;o00000oooool2o`00017ooooo0_l00006ooooo`04
o`000?ooooooooooooooo`;o0000<oooool2o`00087ooooo002<ooooo`;o00000oooool2o`00017o
oooo0_l00006ooooo`04o`000?ooooooooooooooo`;o0000<oooool2o`0000;ooooo0_l0001moooo
o`00Roooool2o`0000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool07oooool2o`0001Wooooo0_l0001m
ooooo`00Roooool2o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool0
1?mgMgOo<S8booooooooool2o`000003ooooool0003ooooo00Gooooo0_l0000Iooooo`;o0000V?oo
ool008Wooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41000ol0000=ooooo`03o`000?oo
oooooooo00;o000000?oooooo`000?ooool01Oooool2o`0003;ooooo0ol0001nooooo`00TOooool0
1?l0003oooooooooooooool4o`0000cooooo00?oMgMgoc8b<_ooool01?ooool3o`0000Cooooo0_l0
000booooo`?o0000O_ooool0093ooooo0_l00003ooooo`03o`000?oooooooooo00[ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;Wooooo0024ooooo`;o00002_ooool2
o`0000?ooooo00?o410@ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo02Cooooo0_l0000Fooooo`;o0000Noooool008Cooooo0_l00004ooooo`;o00001Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool3o`0000Oooooo0_l0000I
ooooo`Co00005_ooool2o`0007_ooooo0024ooooo`;o00001?ooool2o`0000Gooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool3o`0000Oooooo0_l0000:ooooo`;o00003Oooool2
o`0001Wooooo0_l0001jooooo`00Q?ooool2o`0002Kooooo00?o0000ooooooooool04oooool2o`00
017ooooo0_l0000Eooooo`;o0000N_ooool00:cooooo00?o0000ooooooooool00_l0000Tooooo`;o
0000TOooool009Cooooo0_l00003ooooo`;o00002?ooool2o`0000Oooooo00?o0000ooooooooool0
0_l0002gooooo`00U?ooool2o`0000?ooooo0_l00008ooooo`;o000000?oooooo`000?l000001?oo
ool3o`000;Wooooo002Iooooo`;o00002oooool2o`0000Cooooo00?o0000ooooooooool0^Oooool0
08Wooooo0_l0000Qooooo`03o`000?oooooooooo00[ooooo0_l0000:ooooo`;o0000XOooool008Wo
oooo0_l00009ooooo`;o00005_ooool00ol0003oooooooooo`0:ooooo`;o00002_ooool2o`000:7o
oooo0022ooooo`;o00004?ooool2o`0001Kooooo00?o0000ooooooooool0^Oooool008;ooooo0_l0
000Wooooo`;o0000^oooool00:_ooooo0_l0000]ooooo`;o0000S?ooool008kooooo0_l00007oooo
o`;o00004oooool00ol0003oooooooooo`0[ooooo`;o0000S?ooool008kooooo0_l00007ooooo`;o
00004oooool3o`0000gooooo0_l0000Iooooo`;o0000Soooool008gooooo0ol0000Looooo`03o`00
0?oooooooooo00gooooo0_l0000Iooooo`;o0000Soooool008gooooo0ol0000Cooooo`;o00001ooo
ool00ol0003oooooooooo`0Yooooo`;o0000S_ooool008gooooo0_l0000Aooooo`;o000000?ooooo
o`000?l000001oooool00ol0003oooooooooo`0Yooooo`;o0000S_ooool00:3ooooo0_l0000:oooo
o`03o`000?oooooooooo00Gooooo0_l0002booooo`00[?ooool00ol0003oooooooooo`05ooooo`;o
00009?ooool2o`0008cooooo002/ooooo`03o`000?oooooooooo01[ooooo0_l0000?ooooo`;o0000
S?ooool00:cooooo00?o0000ooooooooool01_ooool2o`0001;ooooo0_l0002Mooooo`00[?ooool3
o`0000Kooooo0_l0002aooooo`00S?ooool2o`0001kooooo00?o0000ooooooooool0^Oooool008Oo
oooo0_l00003ooooo`;o00007_ooool00ol0003oooooooooo`0Aooooo`;o0000Y_ooool008Oooooo
0_l0000Sooooo`03o`000?oooooooooo017ooooo0_l0000Mooooo`;o0000Qoooool00:cooooo00?o
0000ooooooooool04_ooool2o`0001cooooo0_l00027ooooo`00[?ooool00ol0003oooooooooo`0B
ooooo`;o00006_ooool2o`0008Wooooo002/ooooo`03o`000?oooooooooo01kooooo0ol0000=oooo
o`;o0000ROooool008cooooo0_l0000Nooooo`03o`000?oooooooooo01kooooo0ol0002Hooooo`00
S?ooool2o`0001kooooo00?o0000ooooooooool02_ooool2o`0000Kooooo0_l0002Uooooo`00S?oo
ool2o`0001kooooo0ol0000:ooooo`;o00001_ooool2o`0001_ooooo0_l00028ooooo`00[?ooool0
0ol0003oooooooooo`0Dooooo`;o00002Oooool4o`0000cooooo0ol00027ooooo`00[?ooool00ol0
003oooooooooo`0Dooooo`;o00002Oooool4o`0000gooooo0_l00027ooooo`00Z_ooool3o`0000Ko
oooo0_l0000Kooooo`;o00009_ooool2o`0006kooooo002Zooooo`?o00001_ooool2o`0004?ooooo
0_l0001^ooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000
1?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0B_ooool2o`0006go
oooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo0_l000000oo^k^ko
ooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0B_ooool2o`0006go
oooo0021ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00_ooooo0_l000000olQ8B7o
k^k^ooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05Oooool2o`000:;o
oooo0029ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So0000o`000007ooooo`03
ogMgMolb<S;ooooo00Cooooo0ol00005ooooo`;o00003_ooool2o`000:;ooooo0029ooooo`05o`00
0?ooooooooooooooool000001oooool2o`0000Gooooo0_l00004ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`05ooooo`;o00001Oooool2o`0002Oooooo0_l00022oooo
o`00ROooool01Ol@413ooooooooooooooooo410@00Cooooo0_l000000ooooooo0000o`000006oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool01?l0003oooooooooooooool2
o`0000Wooooo0_l0000Wooooo`;o00005oooool2o`0006Wooooo0020ooooo`;o00001oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Cooooo0_l00005ooooo`05o`000?nj^[[ooooooiRHV?l@41001?oo
ool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooooooo`;o0000B_ooool3o`0006Wooooo
0020ooooo`;o00001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00KoV9RHoa0@4?l0003o
8B4Qolc<c?ooool2o`000003ooooool0003o000000;o00001_ooool00ol0003oooooooooo`0Foooo
o`;o0000=Oooool2o`0006[ooooo002Oooooo`;o00002oooool00ol0003oooooooooo`0=ooooo`;o
00001oooool2o`000:7ooooo002/ooooo`03o`000?oooooooooo00gooooo0_l0000Uooooo`;o0000
Poooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo01Sooooo0_l0000Jooooo`Go0000P?oo
ool0097ooooo0_l00004ooooo`;o00004oooool3o`0001Sooooo0_l00009ooooo`;o00004?ooool4
o`00083ooooo002Aooooo`;o00006Oooool00ol0003oooooooooo`0Sooooo`;o00004?ooool4o`00
083ooooo001oooooo`;o0000:oooool00ol0003oooooooooo`0eooooo`?o0000POooool007oooooo
0_l0000[ooooo`03o`000?oooooooooo02Cooooo1?l0002Aooooo`00[?ooool00ol0003ooooooooo
o`0Tooooo`Co00003oooool2o`00083ooooo002/ooooo`03o`000?oooooooooo00?ooooo0_l0000b
ooooo`;o0000P?ooool009Cooooo0_l0000Fooooo`03o`000?oooooooooo00?ooooo0_l0002doooo
o`00QOooool2o`0000gooooo0_l0000Fooooo`03o`000?oooooooooo0;Wooooo001oooooo`;o0000
1?ooool2o`0002Gooooo0ol0000@ooooo`;o0000:?ooool2o`0007gooooo001oooooo`;o00003?oo
ool2o`0001gooooo00?o0000ooooooooool02_ooool2o`0000Cooooo0_l0000Booooo`Co00003_oo
ool2o`0000;ooooo0_l0001mooooo`00SOooool2o`0001gooooo00?o0000ooooooooool01?ooool2
o`0000Cooooo0_l00004ooooo`;o00004_ooool4o`0000kooooo0_l00021ooooo`00U_ooool2o`00
01Cooooo00?o0000ooooooooool01?ooool2o`0000[ooooo0_l0000Dooooo`;o0000TOooool009Ko
oooo0_l0000Dooooo`03o`000?oooooooooo01[ooooo0_l0000:ooooo`;o00004Oooool2o`0007ko
oooo002/ooooo`03o`000?oooooooooo017ooooo0_l00007ooooo`;o00007Oooool2o`0007kooooo
002/ooooo`03o`000?oooooooooo00[ooooo0_l00005ooooo`;o00009_ooool2o`0007kooooo002=
ooooo`;o00007Oooool00ol0003oooooooooo`05ooooo`;o00000oooool2o`0002gooooo0_l0001n
ooooo`00SOooool2o`0001gooooo00?o0000ooooooooool01Oooool2o`00037ooooo0_l0001ooooo
o`00[?ooool3o`0001Wooooo0_l0000Mooooo`Co0000OOooool00:cooooo00?o0000ooooooooool0
6Oooool2o`0000cooooo0_l0000Aooooo`;o0000OOooool0097ooooo0_l0000Iooooo`03o`000?oo
oooooooo01Wooooo0_l0000<ooooo`;o0000T?ooool000Wooooo1?l000000ol@413oooooooooo`0F
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool5o`0000Cooooo0ol000000olb<S;ogMgMooooo`0Eooooo`03o`000?oooooo
oooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q0oooool6o`0000Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Go
oooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1?l0
00000ol@413oooooooooo`0Booooo`002oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8boooo
o`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0
3_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@01oooool00omgMgOo<S8booooo`0Eooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q0oooool2o`000004ob4Q8Oo^k^koooooodA4A0Oooooo00Co
MgMgoc8b<_oooooooooo0_l0000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46oooo
o`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool06Oooool00ol0003oooooooooo`0Doooo
o`001_l00005ooooo`03o`000?oooooooooo013ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00Gooooo1_l00002oooo
o`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`05ooooo`Ko00000_ooool0
1Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo017ooooo0_l00005ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00;o00002oooool01Ol@413ooooo
oooooooooooo410@013ooooo00?o0000ooooooooool03Oooool01Ol@413ooooooooooooooooo410@
00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo
000000oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`0Eooooo`?o00004Oooool2o`0000Gooooo00Go
0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0
3_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003o
oooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`0Ioooo
o`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?
ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo
00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c00Fooooo`?o00003?ooool2o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo
00;o00003?ooool2o`000003ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005
ooooo`;o00002?ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00?ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`06_ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003o
ooooooooo`0Hooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03oooo
o`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooo
oooo017ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool06?ooool3o`0000cooooo0_l0000:ooooo`03oa0@4?oooooooooo00;o00003?oo
ool2o`000003ooooool0003ooooo00?ooooo00?o0000ooooooooool01oooool3o`0000Oooooo00Go
410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooo
oooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool04Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo0_l00006ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo01?ooooo0_l00003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool02?ooool2o`00
00Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo01Cooooo0009ooooo`03oeEEEOmVIVKo000001[ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo0_l00006oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0001Oooooo00?o0000ooooooooool00_ooool2
o`0000oooooo0_l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`00
0?lQ8B7oc<c<00Cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02_ooool6o`00013o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0001Wooooo00?oEEEEofIV
I_l000005_ooool009?ooooo0_l0000Gooooo`03o`000?oooooooooo00;ooooo0_l0001@ooooo`;o
0000Hoooool00:cooooo00?o0000ooooooooool07?ooool2o`0001cooooo0_l0001mooooo`00[?oo
ool00ol0003oooooooooo`0Looooo`;o00007?ooool2o`0007;ooooo0_l00002ooooo`;o00001Ooo
ool0083ooooo0_l0000Zooooo`03o`000?oooooooooo0:kooooo00Kok^k^ob4Q8On7QhOo^[Zjo`00
0?oMgMd5ooooo`00P?ooool2o`0002[ooooo00?o0000ooooooooool0E?ooool2o`0005Wooooo00Co
gMgMo`000?l@413oc<c<1_ooool000Ooooooool0001<o`0000cooooo00Cok^k^ob4Q8Ol@413ok^k^
1_ooool000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool01?l0003oooooo`000?l00004ooooo`;o0000
1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o0000
00?oooooo`000?ooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooooooo0_l00002ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`02o`0000?ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool01?lQ8B7o
MgMgogMgMolb<S86ooooo`001oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`07ooooo`;o00001?ooool2o`0001Oo
oooo00?o0000ooooooooool01_ooool2o`0001?ooooo0_l0000:ooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool00_l0000Tooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool02Oooool2o`0000;ooooo0_l00005ooooo`00UOooool2o`0001Gooooo00?o0000ooooooooool0
2oooool3o`000:_ooooo0029ooooo`;o00002_ooool2o`0001Gooooo00?o0000ooooooooool02ooo
ool3o`0001_ooooo0_l0002>ooooo`00Ooooool2o`0000Sooooo0_l0000Qooooo`03o`000?oooooo
oooo02Wooooo0_l0002>ooooo`00Ooooool2o`0002_ooooo00?o0000ooooooooool01_ooool2o`00
01oooooo0_l0002@ooooo`00P?ooool2o`0000?ooooo0_l0000?ooooo`;o00005?ooool00ol0003o
ooooooooo`06ooooo`;o00001?ooool2o`0000Gooooo0_l0000Booooo`;o00004oooool2o`0007_o
oooo0020ooooo`;o00000oooool2o`0000oooooo0_l0000Dooooo`?o00003?ooool2o`0000Gooooo
0_l0000Wooooo`;o0000Noooool007oooooo0_l0000[ooooo`03o`000?oooooooooo00;ooooo0_l0
000Gooooo`;o0000W?ooool007oooooo0_l0000<ooooo`;o00007Oooool00ol0003oooooooooo`02
ooooo`;o00005oooool2o`0000gooooo0_l0000Xooooo`;o0000Hoooool007oooooo0_l0000<oooo
o`;o00007Oooool00ol0003oooooooooo`0Cooooo`;o00005?ooool3o`0002Sooooo0_l0001Soooo
o`00Ooooool2o`0002_ooooo00?o0000ooooooooool04oooool2o`0001Cooooo0ol0002=ooooo`00
ROooool2o`00027ooooo00?o0000ooooooooool0??ooool2o`0007_ooooo0029ooooo`?o00008?oo
ool00ol0003oooooooooo`0Kooooo`;o00007oooool2o`0007_ooooo002:ooooo`;o00008?ooool0
0ol0003oooooooooo`02ooooo`;o00003_ooool2o`0000Oooooo0_l0000gooooo`;o0000Hoooool0
0:cooooo00?o0000ooooooooool00_ooool2o`0000;ooooo0_l0000:ooooo`;o00009_ooool2o`00
01Sooooo0_l0001Sooooo`00Q_ooool2o`0002Cooooo0ol00006ooooo`;o00005?ooool2o`0001co
oooo0_l0001mooooo`00Q_ooool2o`0002Cooooo00?o0000ooooooooool07?ooool2o`0001kooooo
0_l0001kooooo`00[?ooool00ol0003oooooooooo`0;ooooo`;o0000;oooool2o`0007_ooooo002/
ooooo`03o`000?oooooooooo00_ooooo0_l0002/ooooo`00[?ooool00ol0003oooooooooo`0Aoooo
o`;o00005_ooool2o`00013ooooo0_l0000Hooooo`;o0000H_ooool0083ooooo0_l0000Zooooo`03
o`000?oooooooooo017ooooo0_l0000Fooooo`;o00003_ooool4o`0001Sooooo0_l0001Rooooo`00
P?ooool2o`0002[ooooo00?o0000ooooooooool0:?ooool2o`0000oooooo0_l0001nooooo`00Uooo
ool2o`0001?ooooo00?o0000ooooooooool0:?ooool2o`0000oooooo0_l0001nooooo`00S_ooool2
o`0000Oooooo0_l0000Cooooo`?o0000>Oooool2o`0007kooooo002:ooooo`;o00000_ooool2o`00
01cooooo00?o0000ooooooooool04?ooool2o`0002Oooooo0_l0001nooooo`00Ooooool2o`0000Wo
oooo0_l00002ooooo`;o00007?ooool00ol0003oooooooooo`0@ooooo`;o0000Yoooool007oooooo
0_l0000=ooooo`;o00007?ooool00ol0003oooooooooo`05ooooo`;o0000/_ooool00:cooooo00?o
0000ooooooooool01Oooool2o`0000Sooooo0_l00011ooooo`;o0000IOooool009;ooooo0_l0000H
ooooo`03o`000?oooooooooo00Cooooo0_l00009ooooo`;o00002_ooool2o`0003Gooooo0_l0001U
ooooo`00T_ooool2o`0001Sooooo00?o0000ooooooooool01?ooool2o`0001Gooooo0_l0000Moooo
o`;o0000OOooool0083ooooo0_l0000Zooooo`03o`000?oooooooooo03[ooooo0_l0001mooooo`00
P?ooool2o`0002[ooooo0ol00003ooooo`;o00005?ooool2o`0001cooooo0_l00020ooooo`00[?oo
ool00ol0003oooooooooo`03ooooo`;o00005?ooool2o`0001cooooo0_l00020ooooo`00[?ooool0
0ol0003oooooooooo`08ooooo`;o0000[oooool00:cooooo0ol00008ooooo`;o0000<?ooool2o`00
07gooooo002/ooooo`?o00004?ooool2o`0001Cooooo0_l0000Booooo`;o00005_ooool2o`0006Go
oooo002/ooooo`03o`000?oooooooooo013ooooo0_l0000Dooooo`;o0000:_ooool2o`0006Gooooo
0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Iooooo`;o0000W_ooool008Wooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01?nHV9So8B4Qonk^k_ooool2o`00
00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Iooooo`;o0000W_ooool008Wo
oooo00Go410@oooooooooooooooooa0@400;ooooo`;o000000Co8B4Qonk^k_l0003o00001oooool0
0ol0003oooooooooo`03ooooo`?o0000^Oooool008Wooooo00Go0000ooooooooooooooooo`00000;
ooooo`;o000000?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo00Sooooo0_l0002_ooooo`00ROooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMg
ofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool02?oo
ool2o`0000Cooooo0_l0000Dooooo`;o0000:oooool2o`0006Kooooo0029ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool2o`000003ooooool0003ooooo00?ooooo00?o0000ooooooooool01ooo
ool01?l0003oooooooooooooool2o`0000?ooooo0_l00006ooooo`;o00005?ooool2o`0002_ooooo
0_l0001Vooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo0ol000000onHV9So410@
ooooo`03ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooooooo0_l00003ooooo`;o
00001Oooool2o`0000Sooooo0_l0002Pooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c002ooooo`Ko00001_ooool01?l0003oooooooooooooool2
o`0000?ooooo0_l00005ooooo`;o00002?ooool2o`0000[ooooo0_l0002Dooooo`00X?ooool2o`00
00[ooooo00?o0000ooooooooool08oooool2o`0009Cooooo002/ooooo`03o`000?oooooooooo02?o
oooo0_l0000Cooooo`;o0000Ooooool00:?ooooo0_l00007ooooo`03o`000?oooooooooo03Sooooo
0_l0001oooooo`00Xoooool2o`0000Oooooo0ol0000Fooooo`;o0000XOooool00:cooooo00?o0000
ooooooooool05_ooool2o`0001kooooo0_l00021ooooo`00[?ooool00ol0003oooooooooo`04oooo
o`;o00001Oooool2o`0002Wooooo0_l00021ooooo`00[?ooool01?l0003oooooo`000?l00003oooo
o`;o00001Oooool2o`0002Kooooo0_l0000Jooooo`;o0000J?ooool00:cooooo00Co0000ooooool0
003o0000<_ooool4o`0001Sooooo0_l0001Xooooo`00[?ooool00ol0003oooooooooo`0Cooooo`;o
00008?ooool2o`0008;ooooo002/ooooo`03o`000?oooooooooo01?ooooo0_l0000Nooooo`Co0000
P_ooool00:cooooo00?o0000ooooooooool0<oooool4o`0008;ooooo002/ooooo`?o0000^Oooool0
0:7ooooo0_l00009ooooo`03o`000?oooooooooo04cooooo0_l0001[ooooo`00XOooool2o`0000Wo
oooo00?o0000ooooooooool0C?ooool2o`0006_ooooo002Kooooo`;o00003oooool00ol0003ooooo
ooooo`0Dooooo`;o00007_ooool2o`0008?ooooo0022ooooo`;o00004oooool2o`0000;ooooo0_l0
000?ooooo`03o`000?oooooooooo01;ooooo1?l0000Nooooo`;o0000Poooool008;ooooo0_l0000C
ooooo`;o00000oooool2o`0000kooooo00?o0000ooooooooool04Oooool4o`000:Cooooo002Loooo
o`;o00003_ooool00ol0003oooooooooo`09ooooo`;o00001Oooool3o`0000[ooooo0_l0002Joooo
o`00P_ooool2o`0002Sooooo00?o0000ooooooooool02Oooool2o`0000Gooooo0_l0000;ooooo`;o
0000V_ooool008;ooooo0_l0000Xooooo`Go0000;Oooool2o`0008Sooooo002Cooooo`;o00004_oo
ool2o`0000?ooooo00?o0000ooooooooool00_l0000]ooooo`;o0000R?ooool009?ooooo0_l00009
ooooo`;o00001oooool3o`0000;ooooo00?o0000ooooooooool0^Oooool008kooooo0_l0000>oooo
o`;o00002?ooool2o`0000;ooooo00?o0000ooooooooool07Oooool2o`0009[ooooo002>ooooo`;o
00005?ooool2o`0000Kooooo00?o0000ooooooooool07Oooool2o`0009[ooooo002Tooooo`;o0000
1_ooool00ol0003oooooooooo`0Mooooo`;o0000V_ooool00:cooooo00?o0000ooooooooool01?oo
ool2o`000;?ooooo002/ooooo`03o`000?oooooooooo00Cooooo0_l0002cooooo`00R_ooool2o`00
023ooooo0ol00003ooooo`?o0000/oooool008[ooooo0_l00009ooooo`;o00001?ooool2o`0000oo
oooo00?o0000ooooooooool00oooool2o`000;Cooooo002Eooooo`;o00001?ooool3o`0000kooooo
00?o0000ooooooooool0^Oooool008_ooooo0_l0000?ooooo`;o00003_ooool01?l0003ooooooooo
ooooool2o`0002Wooooo0_l0002;ooooo`00Roooool2o`0000Wooooo0_l0000Dooooo`04o`000?oo
ooooooooooooo`;o00005_ooool2o`00017ooooo1?l00029ooooo`00U_ooool2o`00017ooooo0_l0
00000ooooooo0000ooooo`0Jooooo`?o00003oooool2o`000003ooooool0003o000008Wooooo002A
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8b
omgMg@02ooooo`;o000000Coooooo`000?oooooooooo0ol0000Gooooo`;o00003_ooool3o`0008co
oooo002Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`03o`0001Gooooo0_l0000@ooooo`;o0000SOooool0097ooooo
00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_l0000Fooooo`;o00004?ooool2o`0008gooooo002Aooooo`05o`000?ooooooooooooooool0
00002_ooool2o`0000?ooooo00?oMgMgoc8b<_ooool01?ooool3o`000;Wooooo002Aooooo`05o`00
0?ooooooooooooooool000000_ooool2o`0000Kooooo0ol000001?lQ8B7o0000oc8b<_o<c<`5oooo
o`03o`000?oooooooooo0;Wooooo002Aooooo`05oa0@4?ooooooooooooooool@41000_ooool2o`00
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`;o00007_ooool2o`00
01Oooooo0_l0001eooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`09ooooo`;o00007_ooool2o`0001Oooooo0_l0001eoooo
o`00Q_ooool2o`0000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0
003oooooooooo`0Zooooo`;o0000SOooool008Kooooo0_l0000:ooooo`;o00001Oooool2o`00017o
oooo00?o0000ooooooooool05?ooool2o`0001Cooooo0_l0002=ooooo`00T_ooool2o`0000Gooooo
0ol0000@ooooo`03o`000?oooooooooo00Kooooo0_l0000<ooooo`;o0000;?ooool2o`0007Gooooo
002=ooooo`;o00000oooool2o`0000Kooooo0ol0000?ooooo`03o`000?oooooooooo00Kooooo0_l0
000Mooooo`;o000000?oooooo`000?l000006?ooool2o`0007Gooooo002=ooooo`;o00003?ooool2
o`0000oooooo0ol0000Uooooo`Go0000Soooool00:cooooo00?o0000ooooooooool09oooool2o`00
01Oooooo0_l0001gooooo`00[?ooool00ol0003oooooooooo`10ooooo`;o0000Moooool00:Wooooo
0_l000000ooooooo0000ooooo`2jooooo`00Woooool3o`0000Oooooo0_l000000ooooooo0000oooo
o`0Booooo`;o0000Y_ooool009oooooo1Ol00008ooooo`03o`000?oooooooooo017ooooo0_l0002V
ooooo`00Qoooool2o`0001Wooooo0_l00002ooooo`;o00001?ooool00ol0003oooooooooo`02oooo
o`;o0000]Oooool008Oooooo0_l0000Mooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`;o
0000]Oooool009Kooooo0_l0000Dooooo`?o0000^Oooool009Kooooo0_l0000Dooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`04o`000?ooooooooooooooo`;o0000]_ooool00:cooooo0ol00000
0ooooooo0000o`00000gooooo`;o0000OOooool008oooooo0_l0000Kooooo`?o00003?ooool2o`00
02cooooo0_l0001mooooo`00Soooool2o`0001_ooooo00?o0000ooooooooool03?ooool2o`00017o
oooo0_l0002Hooooo`00[?ooool00ol0003oooooooooo`0Oooooo`;o0000V?ooool009[ooooo0_l0
000@ooooo`03o`000?oooooooooo01oooooo0_l0002Hooooo`00V_ooool2o`00013ooooo0ol0000<
ooooo`;o0000:Oooool2o`00083ooooo002/ooooo`03o`000?oooooooooo00cooooo0_l0000Yoooo
o`;o0000P?ooool00:[ooooo0ol0002kooooo`00Z_ooool3o`0001gooooo0_l0002Looooo`00[?oo
ool00ol0003oooooooooo`0Kooooo`;o0000W?ooool00:cooooo00?o0000ooooooooool02Oooool2
o`000:kooooo002Pooooo`;o00002_ooool00ol0003oooooooooo`06ooooo`;o000000?oooooo`00
0?l00000[_ooool009?ooooo0_l0000;ooooo`;o00000oooool2o`0000Gooooo00?o0000oooooooo
ool01_ooool2o`000;7ooooo002Cooooo`;o00004?ooool2o`0000Gooooo00?o0000ooooooooool0
5oooool2o`000:3ooooo002/ooooo`?o00005oooool2o`000:3ooooo002/ooooo`03o`000?oooooo
oooo00?ooooo0ol0002cooooo`00[?ooool00ol0003oooooooooo`03ooooo`?o0000/oooool009Oo
oooo0_l0000Cooooo`03o`000?oooooooooo00?ooooo0_l0000Booooo`;o0000X?ooool009Oooooo
0_l0000Cooooo`03o`000?oooooooooo00?ooooo0_l0000Booooo`;o0000X?ooool008Wooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`02o`000003ooooool0003o000000ko
oooo0_l0002Tooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03
oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`02o`00017o
oooo0_l0002Tooooo`00ROooool01?l@413oooooooooooooool2o`0000Oooooo0_l00003ooooo`03
ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2iooooo`00
ROooool01?l0003oooooooooooooool2o`0000Oooooo0ol00003ooooo`03ob4Q8Ooooooooooo00Ko
oooo00?oMgMgoc8b<_ooool01?ooool3o`000;Wooooo0029ooooo`04o`000?ooooooooooooooo`;o
00002?ooool2o`0000?ooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool0^Oooool008Wooooo00Co410@oooooooooooooooo0_l0000=oooo
o`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2ioooo
o`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04
ooooo`03o`000?oooooooooo00Oooooo0ol0002iooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00_ooooo1Ol00004ooooo`Co00001?ooool5o`000;Wooooo002>ooooo`;o00002Oooool2o`00
00oooooo1?l0002jooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool03_ooool3o`000:So
oooo002/ooooo`03o`000?oooooooooo00kooooo0ol0002Xooooo`00Q_ooool2o`0001kooooo0_l0
0004ooooo`?o0000^Oooool008Kooooo0_l0000Mooooo`?o00001?ooool00ol0003oooooooooo`2i
ooooo`00YOooool2o`0000Gooooo00?o0000ooooooooool03?ooool2o`000:_ooooo002Uooooo`;o
00001Oooool00ol0003oooooooooo`0<ooooo`;o0000Zoooool00:cooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool02?ooool3o`000:kooooo002/ooooo`03o`000?oooooo
oooo00Sooooo0ol0002^ooooo`00[?ooool00ol0003oooooooooo`07ooooo`;o0000/?ooool009Co
oooo0_l0000Fooooo`?o00001oooool2o`000;3ooooo002Dooooo`;o00005_ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool01?l0003oooooooooooooool2o`00
0;Kooooo002/ooooo`04o`000?ooooooooooooooo`;o0000]_ooool009Kooooo0_l0000Dooooo`03
o`000?oooooooooo0;Wooooo002Fooooo`;o00005?ooool00ol0003oooooooooo`2iooooo`00[?oo
ool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Iooooo`;o00004Oooool00ol0
003oooooooooo`2iooooo`00VOooool3o`00013ooooo00?o0000ooooooooool0^Oooool009Wooooo
0ol0000@ooooo`;o0000^_ooool009Wooooo0_l00004ooooo`;o00002oooool2o`000;[ooooo002O
ooooo`;o00002oooool00ol0003oooooooooo`2iooooo`00Woooool2o`0000Cooooo0_l00005oooo
o`03o`000?oooooooooo01Cooooo0_l0002Sooooo`00Y?ooool5o`0000?ooooo0ol0000Dooooo`;o
0000Xoooool009oooooo0_l00003ooooo`Go00000oooool00ol0003oooooooooo`2iooooo`00Wooo
ool2o`0000_ooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:;ooooo
1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000ooooooooool01Oooool3
o`000;Wooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7o
oooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002R
ooooo`03oeEEEOmVIVKo00000<?ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo002Zooooo`04oa0@4?l0003o0000o`000;[ooooo002[ooooo`03o`000?oooooo
oooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`06o`000?mgMgOo0000o`00
0?mEEEGok^k^]oooool00:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomEEEFgooooo`00Zoooool0
0ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo0;Gooooo002[ooooo`03o`000?o^k^kooooo
00;ooooo00?o0000ooooooooool0]Oooool00:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomVIVJg
ooooo`00Z_ooool00ol@413o0000ogMgM`02o`000003ofIVI_o^k^kooooo0;Kooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.63309 .61262 Mdot
.5627 .80599 Mdot
.46299 .37495 Mdot
.52552 .66102 Mdot
.41311 .34532 Mdot
.60701 .33211 Mdot
.50959 .41053 Mdot
.51965 .95857 Mdot
.6207 .80036 Mdot
.49732 .24084 Mdot
.56406 .43121 Mdot
.43201 .95304 Mdot
.39344 .72162 Mdot
.54116 .33291 Mdot
.38812 .79338 Mdot
.43156 .67942 Mdot
.44493 .82703 Mdot
.38852 .68254 Mdot
.50593 .77174 Mdot
.6145 .22445 Mdot
.38066 .53688 Mdot
.47774 .91319 Mdot
.42552 .84742 Mdot
.38036 .56197 Mdot
.36685 .39873 Mdot
.58855 .38958 Mdot
.56772 .54178 Mdot
.50673 .76599 Mdot
.63951 .27343 Mdot
.54254 .83491 Mdot
.39476 .27833 Mdot
.63183 .78541 Mdot
.53831 .92961 Mdot
.39594 .44388 Mdot
.43983 .1655 Mdot
.58466 .19322 Mdot
.69797 .53297 Mdot
.53881 .68809 Mdot
.66522 .3486 Mdot
.4243 .94109 Mdot
.36355 .4993 Mdot
.40902 .28551 Mdot
.54352 .20842 Mdot
.63515 .62385 Mdot
.64455 .53839 Mdot
.50157 .1963 Mdot
.54136 .34435 Mdot
.67317 .69481 Mdot
.59566 .60733 Mdot
.64203 .28879 Mdot
.67172 .69475 Mdot
.68313 .39379 Mdot
.77007 .60879 Mdot
.50511 .15388 Mdot
.50156 .14355 Mdot
.58152 .86694 Mdot
.502 .97668 Mdot
.45722 .84626 Mdot
.69146 .61955 Mdot
.64486 .5134 Mdot
.52479 .23733 Mdot
.55543 .0588 Mdot
.66974 .36882 Mdot
.47208 .26148 Mdot
.51226 .95242 Mdot
.61307 .8207 Mdot
.49115 .23408 Mdot
.43855 .70204 Mdot
.54382 .67935 Mdot
.38222 .395 Mdot
.44656 .83899 Mdot
.49919 .65271 Mdot
.5113 .27121 Mdot
.44643 .259 Mdot
.66967 .36876 Mdot
.50814 .52879 Mdot
.76987 .60959 Mdot
.56874 .34378 Mdot
.67446 .36219 Mdot
.5885 .60843 Mdot
.47986 .07173 Mdot
.54416 .83042 Mdot
.53532 .61944 Mdot
.41254 .26251 Mdot
.56234 .90403 Mdot
.4326 .69121 Mdot
.41842 .30732 Mdot
.46582 .18592 Mdot
.49493 .84373 Mdot
.4328 .67809 Mdot
.37036 .34341 Mdot
.75429 .38791 Mdot
.52718 .35609 Mdot
.47354 .1776 Mdot
.51472 .32215 Mdot
.74265 .34426 Mdot
.53699 .32214 Mdot
.65839 .72019 Mdot
.76798 .62425 Mdot
.50086 .83896 Mdot
.62237 .65601 Mdot
.5365 .77618 Mdot
.42261 .92994 Mdot
.62404 .66434 Mdot
.42504 .13234 Mdot
.39988 .37203 Mdot
.41906 .76125 Mdot
.47744 .80672 Mdot
.52816 .35894 Mdot
.3859 .34658 Mdot
.51901 .28018 Mdot
.53514 .63053 Mdot
.63273 .78208 Mdot
.58144 .17859 Mdot
.68627 .83224 Mdot
.52016 .39118 Mdot
.54853 .28689 Mdot
.61239 .8301 Mdot
.62459 .80633 Mdot
.69331 .54101 Mdot
.39183 .70705 Mdot
.38507 .6065 Mdot
.64189 .27545 Mdot
.38467 .35933 Mdot
.50641 .71318 Mdot
.60226 .21244 Mdot
.72274 .29703 Mdot
.57702 .7663 Mdot
.52432 .5941 Mdot
.43951 .88286 Mdot
.6052 .70654 Mdot
.39513 .83989 Mdot
.60978 .33353 Mdot
.56984 .25323 Mdot
.66229 .32186 Mdot
.70155 .4835 Mdot
.62627 .25192 Mdot
.50824 .26567 Mdot
.49714 .97494 Mdot
.38672 .78804 Mdot
.64072 .16754 Mdot
.55049 .49966 Mdot
.5321 .71429 Mdot
.44597 .82944 Mdot
.5978 .19951 Mdot
.5832 .87509 Mdot
.62651 .92031 Mdot
.43818 .75244 Mdot
.4818 .18272 Mdot
.44299 .00793 Mdot
.55018 .7499 Mdot
.56695 .58821 Mdot
.38001 .5602 Mdot
.50898 .61465 Mdot
.6321 .43787 Mdot
.69648 .4644 Mdot
.67435 .37599 Mdot
.60465 .83886 Mdot
.69625 .54067 Mdot
.69775 .46867 Mdot
.60337 .48389 Mdot
.67359 .35449 Mdot
.36981 .67924 Mdot
.55352 .15112 Mdot
.55094 .22638 Mdot
.62019 .65484 Mdot
.58672 .8688 Mdot
.44407 .09001 Mdot
.54825 .66446 Mdot
.69773 .44665 Mdot
.62664 .2638 Mdot
.54134 .43185 Mdot
.55587 .63039 Mdot
.42754 .26696 Mdot
.42815 .72157 Mdot
.51904 .94894 Mdot
.73705 .33082 Mdot
.63035 .43058 Mdot
.51985 .40006 Mdot
.64997 .30135 Mdot
.69082 .40891 Mdot
.39265 .83379 Mdot
.41683 .42269 Mdot
.36405 .44415 Mdot
.48165 .71812 Mdot
.62042 .7969 Mdot
.722 .29923 Mdot
.64642 .763 Mdot
.37333 .71279 Mdot
.55549 .22586 Mdot
.45461 9e-05 Mdot
.59643 .19661 Mdot
.44149 .32013 Mdot
.54256 .04821 Mdot
.54065 .93192 Mdot
.37181 .29581 Mdot
.41101 .89943 Mdot
.46053 .18611 Mdot
.76852 .4303 Mdot
.39683 .61005 Mdot
.48918 .30916 Mdot
.4949 .31884 Mdot
.48899 .67761 Mdot
.41416 .34415 Mdot
.7731 .46012 Mdot
.611 .68693 Mdot
.42582 .55299 Mdot
.61878 .36932 Mdot
.54259 .60354 Mdot
.45753 .71293 Mdot
.56624 .43769 Mdot
.43507 .88345 Mdot
.56283 .32605 Mdot
.44719 .08563 Mdot
.41548 .47837 Mdot
.6162 .66769 Mdot
.55283 .303 Mdot
.3669 .63896 Mdot
.48662 .71744 Mdot
.64076 .50866 Mdot
.45065 .98339 Mdot
.54215 .27245 Mdot
.68116 .6495 Mdot
.42663 .1256 Mdot
.51201 .09997 Mdot
.41759 .55284 Mdot
.40587 .54469 Mdot
.58614 .76648 Mdot
.53761 .40505 Mdot
.38693 .78695 Mdot
.50289 .00218 Mdot
.46464 .75788 Mdot
.44037 .44456 Mdot
.77195 .47958 Mdot
.5639 .70789 Mdot
.57036 .51968 Mdot
.54924 .65662 Mdot
.61741 .68671 Mdot
.39169 .69162 Mdot
.61171 .68944 Mdot
.55946 .06443 Mdot
.58289 .27351 Mdot
.48244 .06452 Mdot
.44747 .84035 Mdot
.63727 .78004 Mdot
.50854 .30945 Mdot
.69306 .46976 Mdot
.50064 .82731 Mdot
.45261 .84761 Mdot
.67037 .36633 Mdot
.36981 .32181 Mdot
.51853 .3853 Mdot
.44674 .3057 Mdot
.69425 .50028 Mdot
.59259 .41953 Mdot
.55792 .61958 Mdot
.51345 .15561 Mdot
.50591 .55919 Mdot
.5048 .97092 Mdot
.68355 .65926 Mdot
.58314 .65593 Mdot
.57048 .51722 Mdot
.52649 .11666 Mdot
.53212 .51148 Mdot
.54892 .74887 Mdot
.63557 .58662 Mdot
.55075 .3791 Mdot
.59696 .31795 Mdot
.60601 .22819 Mdot
.59933 .48784 Mdot
.58952 .19563 Mdot
.51219 .1567 Mdot
.48979 .22873 Mdot
.58684 .62984 Mdot
.69612 .45376 Mdot
.41836 .39717 Mdot
.42883 .7342 Mdot
.66393 .71492 Mdot
.5629 .41169 Mdot
.62858 .41093 Mdot
.65887 .32006 Mdot
.52794 .58848 Mdot
.43263 .30994 Mdot
.69516 .54448 Mdot
.44384 .96916 Mdot
.47347 .80776 Mdot
.51919 .53566 Mdot
.40671 .47525 Mdot
.54902 .13223 Mdot
.49418 .19043 Mdot
.46065 .07812 Mdot
.72252 .30234 Mdot
.68982 .61579 Mdot
.41422 .90314 Mdot
.68378 .63234 Mdot
.47198 .32884 Mdot
.6995 .57697 Mdot
.52726 .03556 Mdot
.51792 .09386 Mdot
.39605 .83442 Mdot
.59164 .96349 Mdot
.59515 .5937 Mdot
.55017 .20991 Mdot
.60434 .71198 Mdot
.63432 .78358 Mdot
.36417 .50128 Mdot
.54802 .3631 Mdot
.662 .71625 Mdot
.59598 .43658 Mdot
.45428 .3257 Mdot
.43211 .87466 Mdot
.43353 .80299 Mdot
.39531 .72889 Mdot
.428 .03431 Mdot
.52723 .43191 Mdot
.64012 .53691 Mdot
.40177 .3477 Mdot
.49341 .97315 Mdot
.53325 .51165 Mdot
.38537 .79333 Mdot
.44703 .01467 Mdot
.65774 .18517 Mdot
.4782 .75727 Mdot
.61011 .33039 Mdot
.41253 .26017 Mdot
.67872 .4005 Mdot
.40576 .55749 Mdot
.46753 .29977 Mdot
.49335 .34852 Mdot
.42917 .79596 Mdot
.47792 .99416 Mdot
.69243 .50062 Mdot
.51008 .30872 Mdot
.45641 .9107 Mdot
.52269 .60647 Mdot
.48602 .68156 Mdot
.58103 .77604 Mdot
.59969 .31159 Mdot
.55174 .2275 Mdot
.60319 .4864 Mdot
.4104 .38172 Mdot
.77665 .56878 Mdot
.59593 .44996 Mdot
.55318 .81228 Mdot
.47866 .26307 Mdot
.55478 .90545 Mdot
.56814 .52376 Mdot
.62074 .24321 Mdot
.50608 .88377 Mdot
.54455 .42766 Mdot
.5283 .25299 Mdot
.63667 .16103 Mdot
.44334 .97212 Mdot
.70259 .56452 Mdot
.59202 .20312 Mdot
.60072 .5586 Mdot
.3972 .60566 Mdot
.61918 .24804 Mdot
.55742 .72741 Mdot
.44247 .9705 Mdot
.65963 .18291 Mdot
.4905 .06817 Mdot
.39639 .84463 Mdot
.38027 .75975 Mdot
.36286 .51791 Mdot
.46052 .67946 Mdot
.57483 .6769 Mdot
.38326 .76466 Mdot
.50616 .97089 Mdot
.45352 .66599 Mdot
.42932 .1263 Mdot
.59548 .46761 Mdot
.61915 .36504 Mdot
.62581 .64303 Mdot
.64974 .74065 Mdot
.61742 .68545 Mdot
.69805 .5587 Mdot
.68848 .4612 Mdot
.433 .86542 Mdot
.70477 .53769 Mdot
.44448 .88974 Mdot
.36505 .53148 Mdot
.66832 .86287 Mdot
.69079 .5718 Mdot
.63497 .44374 Mdot
.51014 .60299 Mdot
.40459 .1117 Mdot
.50928 .82368 Mdot
.48783 .33832 Mdot
.39024 .82395 Mdot
.38366 .37141 Mdot
.46065 .30682 Mdot
.46182 .23287 Mdot
.57597 .35222 Mdot
.56902 .54665 Mdot
.66975 .70679 Mdot
.42462 .12662 Mdot
.54054 .04773 Mdot
.38819 .81107 Mdot
.40299 .65621 Mdot
.7744 .55759 Mdot
.39851 .61491 Mdot
.4349 .74689 Mdot
.42211 .699 Mdot
.4532 .62718 Mdot
.48216 .99166 Mdot
.43519 .95829 Mdot
.56826 .53333 Mdot
.54428 .4363 Mdot
.57408 .49457 Mdot
.41792 .58988 Mdot
.40102 .11533 Mdot
.45764 .18632 Mdot
.54575 .13857 Mdot
.5482 .54146 Mdot
.56418 .60177 Mdot
.53159 .53966 Mdot
.43787 .22599 Mdot
.39525 .51135 Mdot
.57133 .54356 Mdot
.42421 .50814 Mdot
.50284 .96929 Mdot
.45348 .57871 Mdot
.45226 .14335 Mdot
.41843 .75838 Mdot
.63604 .49268 Mdot
.59725 .49393 Mdot
.55462 .63965 Mdot
.40289 .11558 Mdot
.75209 .36359 Mdot
.60549 .71514 Mdot
.71871 .77183 Mdot
.63257 .63959 Mdot
.42462 .44971 Mdot
.5978 .83471 Mdot
.37726 .71783 Mdot
.5666 .4579 Mdot
.49936 .89117 Mdot
.77496 .5802 Mdot
.54676 .45871 Mdot
.44363 .35621 Mdot
.41558 .65054 Mdot
.51799 .10486 Mdot
.59539 .5683 Mdot
.76264 .41154 Mdot
.46729 .72025 Mdot
.47647 .13223 Mdot
.40165 .33751 Mdot
.49416 .27335 Mdot
.52677 .43503 Mdot
.43013 .31321 Mdot
.51618 .962 Mdot
.53162 .46042 Mdot
.66785 .34013 Mdot
.58234 .76964 Mdot
.64204 .54435 Mdot
.59478 .20174 Mdot
.43962 .10586 Mdot
.41718 .74637 Mdot
.71863 .28128 Mdot
.46874 .22693 Mdot
.47324 .99473 Mdot
.36768 .3468 Mdot
.55241 .38824 Mdot
.70089 .57224 Mdot
.59824 .49195 Mdot
.45647 .83978 Mdot
.61744 .23661 Mdot
.62383 .65355 Mdot
.49057 .79581 Mdot
.5292 .25404 Mdot
.39488 .47682 Mdot
.54045 .03892 Mdot
.57209 .2619 Mdot
.50929 .49637 Mdot
.53603 .19953 Mdot
.58915 .61026 Mdot
.46923 .69002 Mdot
.46048 .74847 Mdot
.4967 .14213 Mdot
.55982 .23203 Mdot
.50671 .34723 Mdot
.58726 .39909 Mdot
.6104 .825 Mdot
.40795 .39497 Mdot
.63753 .56562 Mdot
.54694 .6779 Mdot
.49571 .78223 Mdot
.43574 .58396 Mdot
.70011 .81149 Mdot
.43248 .54132 Mdot
.5721 .79099 Mdot
.67347 .66747 Mdot
.55636 .1537 Mdot
.53717 .69847 Mdot
.6365 .272 Mdot
.40529 .88489 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool009gooooo0_l00005ooooo`03o`000?oooooooooo00Go
oooo0ol0002iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`?o0000^Oooool009Wooooo0_l0
0009ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool009Wooooo0_l00009
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool009[ooooo0_l00006oooo
o`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0^Oooool009[ooooo0_l0000@ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Ooo
ool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool009Co
oooo0_l0000Fooooo`03o`000?oooooooooo0;Wooooo002Dooooo`;o00005_ooool00ol0003ooooo
ooooo`06ooooo`;o0000/Oooool00:cooooo00?o0000ooooooooool01_ooool2o`0000;ooooo0_l0
002]ooooo`00[?ooool00ol0003oooooooooo`0:ooooo`;o0000[Oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool02_ooool3o`000:cooooo002/ooooo`?o0000
2_ooool3o`000:cooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooo
oooo00oooooo0_l0002Xooooo`00[?ooool00ol0003oooooooooo`0?ooooo`;o0000Z?ooool00:Ko
oooo0_l00004ooooo`03o`000?oooooooooo013ooooo0_l0002Wooooo`00Y_ooool4o`0000;ooooo
00?o0000ooooooooool04?ooool2o`000:Oooooo002Xooooo`;o00000_ooool00ol0003ooooooooo
o`2iooooo`00YOooool2o`0000Gooooo00?o0000ooooooooool0^Oooool00:Gooooo0_l00005oooo
o`?o0000^Oooool009oooooo0_l0000;ooooo`03o`000?oooooooooo0;Wooooo002Oooooo`;o0000
2oooool00ol0003oooooooooo`2iooooo`00V_ooool2o`00013ooooo00?o0000ooooooooool0^Ooo
ool009[ooooo0_l0000@ooooo`03o`000?oooooooooo0;Wooooo002Iooooo`;o00004Oooool00ol0
003oooooooooo`2iooooo`00VOooool2o`00017ooooo00?o0000ooooooooool00_ooool2o`000;Go
oooo002/ooooo`03o`000?oooooooooo00;ooooo0_l0002eooooo`00[?ooool3o`000003ooooool0
003o00000;Kooooo002/ooooo`04o`000?ooooooooooooooo`;o0000]_ooool009Sooooo0_l0000B
ooooo`03o`000?oooooooooo00?ooooo0_l0002dooooo`00V?ooool2o`0001;ooooo00?o0000oooo
ooooool00oooool2o`000;Cooooo002<ooooo`;o00007_ooool00ol0003oooooooooo`2iooooo`00
Roooool3o`0001kooooo00?o0000ooooooooool01Oooool2o`000;;ooooo0029ooooo`03onk^k_lb
<S;o000000;o00001Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Gooooo00?o0000ooooooooool01Oooool2o`000;;ooooo0029ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo0;Wooooo0021ooooo`Ko00000_ooool01Ol@413ooooooooo
oooooooo410@00Gooooo0_l00006ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool0
0oooool3o`000;Wooooo0029ooooo`05o`000?ooooooooooooooool000001Oooool3o`0000Kooooo
00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;Wooooo
0029ooooo`05o`000?ooooooooooooooool000001Oooool3o`0000Kooooo00?oEEEEolc<c?ooool0
0oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0^Oooool008Wooooo
00Go410@oooooooooooooooooa0@4005ooooo`;o00001oooool00onYZJWoMgMgooooo`03ooooo`04
o`000?oooooo0000o`0000Kooooo00?o0000ooooooooool03Oooool2o`000:[ooooo0029ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0000Cooooo00Go410@oooooooooooooooooc8b<P04
ooooo`04o`000?oooooo0000o`0000Kooooo00?o0000ooooooooool03Oooool2o`000:[ooooo0029
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`03o`000?oo
oooooooo00cooooo0_l0002[ooooo`00W?ooool2o`0000cooooo1?l0000=ooooo`;o0000Zoooool0
09cooooo0_l0000<ooooo`Co0000^_ooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
0ol0000>ooooo`;o0000ZOooool00:cooooo0ol000000ooooooo0000o`00000;ooooo`?o0000Z?oo
ool00:cooooo0ol000000ooooooo0000o`00000<ooooo`;o0000Z?ooool00:cooooo00Co0000oooo
oooooooooooo0_l0000Wooooo`;o0000SOooool00:cooooo00?o0000ooooooooool0:_ooool2o`00
08gooooo002Hooooo`;o00004_ooool00ol0003oooooooooo`0[ooooo`;o0000S?ooool009Sooooo
0_l0000Booooo`03o`000?oooooooooo02_ooooo0_l0002<ooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool3o`000;Wooooo002Sooooo`;o00001oooool00ol0003oooooooooo`0Goooo
o`;o0000X?ooool00:?ooooo0_l000000ooooooo0000o`000004ooooo`03o`000?oooooooooo01Oo
oooo0_l0000Hooooo`;o0000Q_ooool009kooooo1?l00004ooooo`;o00001?ooool00ol0003ooooo
ooooo`0aooooo`;o0000Q_ooool009kooooo1?l0000:ooooo`03o`000?oooooooooo037ooooo0_l0
0026ooooo`00Z_ooool3o`000;_ooooo002Zooooo`?o00006oooool2o`0009kooooo002/ooooo`;o
00006_ooool5o`0009_ooooo002/ooooo`?o00002?ooool2o`00013ooooo1Ol0002Jooooo`00[?oo
ool00ol0003oooooooooo`08ooooo`;o00004Oooool4o`0009[ooooo002/ooooo`03o`000?oooooo
oooo01_ooooo0ol0002Kooooo`00[?ooool00ol0003oooooooooo`0;ooooo`Co0000Z_ooool00:co
oooo00?o0000ooooooooool02oooool4o`0000oooooo0_l0002Iooooo`00[?ooool00ol0003ooooo
ooooo`0Nooooo`;o0000VOooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo0ol0000?ooooo`;o00004Oooool2o`0009Gooooo002Gooooo`;o
00002?ooool2o`0000Gooooo0_l00002ooooo`03o`000?oooooooooo00gooooo1?l0000?ooooo`Co
0000UOooool009Oooooo0_l00008ooooo`;o00001Oooool2o`0000;ooooo00?o0000ooooooooool0
3Oooool3o`00013ooooo0_l0002Gooooo`00Woooool2o`0000Sooooo0_l000000ooooooo0000oooo
o`0Aooooo`;o0000Yoooool009oooooo0_l00008ooooo`;o000000?oooooo`000?ooool01_ooool2
o`0000Wooooo0_l0000Aooooo`;o0000U?ooool00:_ooooo0_l00007ooooo`;o00007?ooool2o`00
09Cooooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@04ooooo`;o00009_ooool2o`0009?ooooo002Aooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0T
ooooo`;o0000Toooool008Wooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Cooooo0_l0002Cooooo`00TOooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool3o`0000Kooooo0_l0000L
ooooo`Co0000TOooool0097ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`06ooooo`;o00003?ooool2o`00013ooooo0_l0
002Aooooo`00TOooool01Ol@413ooooooooooooooooo410@00Cooooo0_l00006ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01_ooool2o`0000cooooo0_l0002Sooooo`00Soooool2
o`000005ogMgMonHV9SooooooiRHV?mgMgL01?ooool2o`0000Kooooo0_l00008ooooo`03o`000?oo
oooooooo01Cooooo0_l0002Sooooo`00Soooool2o`000005onk^k_lb<S;o0000oc8b<_o^k^h03?oo
ool5o`0000Gooooo00?o0000ooooooooool05?ooool2o`00013ooooo0_l0002Aooooo`00Soooool2
o`0000?ooooo0_l0000?ooooo`;o00001Oooool01?l0003oooooo`000?l0000Uooooo`;o0000TOoo
ool009Cooooo0_l0000Fooooo`03o`000?oooooo000000;o0000]oooool00:[ooooo0ol00002oooo
o`;o00002?ooool2o`0000cooooo0_l0000@ooooo`?o0000S?ooool00:[ooooo1Ol0000:ooooo`;o
00003?ooool2o`00013ooooo0ol0002<ooooo`00ROooool2o`00027ooooo00?o0000ooooooooool0
0oooool2o`0002Kooooo0_l0002<ooooo`00ROooool2o`00027ooooo00?o0000ooooooooool00ooo
ool2o`00043ooooo0_l0001booooo`00S_ooool2o`0001cooooo00?o0000ooooooooool0AOooool2
o`0007;ooooo002>ooooo`;o00007?ooool00ol0003oooooooooo`0=ooooo`;o00007?ooool2o`00
08cooooo002/ooooo`03o`000?oooooooooo00gooooo0_l0000Looooo`;o0000S?ooool00:cooooo
00?o0000ooooooooool0^Oooool0087ooooo0_l0000Yooooo`03o`000?oooooooooo04Kooooo0_l0
001aooooo`00POooool2o`0001kooooo0_l00009ooooo`?o0000;_ooool2o`0001Kooooo0_l0001a
ooooo`00XOooool2o`0000Wooooo00?o0000ooooooooool03_ooool2o`0001kooooo0_l0000Foooo
o`;o0000LOooool0097ooooo0_l00007ooooo`;o00000oooool2o`0000_ooooo00?o0000oooooooo
ool03_ooool2o`0003Kooooo0_l0001aooooo`00TOooool2o`0000;ooooo0_l00003ooooo`;o0000
0oooool2o`0000Oooooo0_l00002ooooo`03o`000?oooooo000000;o0000]oooool009Cooooo0ol0
000Aooooo`;o00000_ooool00ol0003oooooo`000002o`0001_ooooo0_l0002Jooooo`00U?ooool2
o`0001Kooooo00?o0000ooooooooool07Oooool2o`0009[ooooo002Zooooo`?o00007oooool2o`00
09[ooooo0021ooooo`;o00005Oooool2o`00013ooooo0ol00003ooooo`;o00001_ooool2o`0001;o
oooo0_l0000Booooo`?o0000QOooool0087ooooo0_l0000Eooooo`;o00000_ooool2o`0000kooooo
0ol000000ooooooo0000o`000006ooooo`;o00009_ooool3o`0008Gooooo002Looooo`;o00001?oo
ool2o`0000Sooooo00?o0000ooooooooool04Oooool2o`000:Kooooo002Rooooo`;o00002?ooool0
0ol0003oooooooooo`0Aooooo`;o00003_ooool2o`0002Sooooo0_l0001/ooooo`00[?ooool00ol0
003oooooooooo`0:ooooo`;o00005?ooool3o`0002Sooooo0_l0001/ooooo`00Roooool2o`0001oo
oooo00?o0000ooooooooool02_ooool2o`0001Cooooo0ol0002Fooooo`00Roooool2o`0001_ooooo
0_l00002ooooo`03o`000?oooooooooo03Cooooo0_l00023ooooo`00POooool2o`0002Gooooo0_l0
0002ooooo`03o`000?oooooooooo01?ooooo0_l0000Oooooo`;o0000Poooool0083ooooo0ol00003
ooooo`;o00001oooool2o`0001_ooooo00?o0000ooooooooool02_ooool2o`0000Oooooo0_l0000h
ooooo`;o0000J_ooool0083ooooo0_l00004ooooo`;o00000oooool2o`0000;ooooo0_l0000Hoooo
o`;o000000?oooooo`000?ooool00_l00009ooooo`;o00009oooool2o`0001Sooooo0_l0001Zoooo
o`00Roooool2o`0001cooooo0_l000000ooooooo0000o`000002o`0001Gooooo0_l0000Kooooo`;o
0000Q?ooool00:cooooo00?o0000ooooooooool01_ooool2o`0000kooooo0_l0000Nooooo`;o0000
POooool009Wooooo0_l0000Aooooo`03o`000?oooooooooo00Kooooo0_l0000^ooooo`;o0000POoo
ool008Gooooo0_l0000Booooo`;o00004Oooool00ol0003oooooooooo`06ooooo`;o0000/Oooool0
08Gooooo0_l0000Uooooo`03o`000?oooooooooo00cooooo0_l0000Fooooo`;o00004?ooool2o`00
01Sooooo0_l0001Wooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool03?ooool2
o`0001Kooooo0_l0000?ooooo`?o00006?ooool2o`0006Oooooo0029ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool09?ooool2o`0000oooooo0_l00022ooooo`00POooool6
o`0000;ooooo00Go410@ooooool0003o0000oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Tooooo`;o00003oooool2o`0008;ooooo0025
ooooo`;o00000_ooool00ol0003oooooo`000002o`0000gooooo00CoV9RHob4Q8Oo^k^kooooo0_l0
0004ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000fooooo`;o0000POooool008Wooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00;o000000Koooooo`000?lQ8B7o0000
oc8b<_o<c<`5ooooo`03o`000?oooooooooo00gooooo0_l0000Wooooo`;o0000POooool008Wooooo
00Go410@oooooooooooooooooa0@4002o`0000gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00gooooo0_l0002Zooooo`00ROooool01OmgMgOoV9RH
oooooonHV9SoMgMg00;o00002Oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`03ooooo`;o0000]?ooool008Wooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000
ooooooooool00oooool2o`0000Wooooo0_l00011ooooo`;o0000I_ooool00:cooooo00?o0000oooo
ooooool00oooool2o`0000Wooooo0_l0000:ooooo`;o0000=Oooool2o`0006Kooooo0025ooooo`;o
00001_ooool2o`0001gooooo00?o0000ooooooooool00oooool2o`0001Gooooo0_l0000Mooooo`;o
0000O_ooool008Gooooo0_l00006ooooo`;o00000_ooool2o`0001Wooooo00?o0000ooooooooool0
>Oooool2o`0007kooooo0020ooooo`;o00003oooool2o`0001Wooooo0ol00003ooooo`;o00005?oo
ool2o`0001gooooo0_l0001oooooo`00P?ooool2o`0002[ooooo00?o0000ooooooooool00oooool2
o`0001Cooooo0_l0000Mooooo`;o0000Ooooool00:cooooo00?o0000ooooooooool02Oooool2o`00
0:kooooo002/ooooo`03o`000?oooooooooo00;o00001oooool2o`00037ooooo0_l0001kooooo`00
[?ooool00ol0003oooooooooo`02o`0000oooooo0_l0000Dooooo`;o00004oooool2o`0001Gooooo
0_l0001Tooooo`00[?ooool00ol0003oooooooooo`0Aooooo`;o00005?ooool2o`0002[ooooo0_l0
001Tooooo`00[?ooool00ol0003oooooooooo`0Kooooo`;o0000W?ooool0093ooooo0_l0000Joooo
o`03o`000?oooooooooo01_ooooo0_l0002Looooo`00T?ooool2o`0001[ooooo0ol0002iooooo`00
[?ooool00ol0003oooooooooo`0;ooooo`;o0000[?ooool00:cooooo00?o0000ooooooooool02_oo
ool3o`0000Gooooo0_l0000Dooooo`;o0000:oooool2o`0006;ooooo002/ooooo`03o`000?oooooo
oooo00Kooooo0_l00002ooooo`;o00001_ooool2o`0001Cooooo0_l0000[ooooo`;o0000H_ooool0
0:cooooo00?o0000ooooooooool01Oooool3o`0000?ooooo0_l00005ooooo`;o00002?ooool2o`00
00[ooooo0_l0002?ooooo`00[?ooool00ol0003oooooooooo`05ooooo`;o00001?ooool2o`0000Go
oooo0_l00008ooooo`;o00002_ooool2o`0008oooooo0029ooooo`;o00008Oooool00ol0003ooooo
ooooo`0Yooooo`;o0000S_ooool007oooooo0_l00008ooooo`;o00003Oooool2o`0001;ooooo00?o
0000ooooooooool0:Oooool2o`0001?ooooo0_l0001iooooo`00Ooooool2o`0001;ooooo0_l00003
ooooo`;o00004_ooool00ol0003oooooooooo`0Looooo`;o00008?ooool2o`0007Wooooo002Coooo
o`;o00005oooool3o`0001cooooo0_l0002Kooooo`00[?ooool00ol0003oooooooooo`0mooooo`;o
0000N_ooool00:cooooo00?o0000ooooooooool03?ooool2o`0000Gooooo0_l0000Xooooo`;o0000
N_ooool000Wooooo1?l000000ol@413oooooooooo`0Fooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@0Fooooo`03o`000?oooooooooo00Oooooo0_l00003ooooo`;o0000
1Oooool2o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`;o00002?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o
<S8bomgMg@0Hooooo`Co000000?o410@ooooooooool04_ooool000_ooooo00?o0000ooooooooool0
6?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oo
oooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool05Oooool00ol0003ooooooooo
o`07ooooo`;o00003oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`Co00001_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`;o000000?oMgMgoc8b<_ooool03_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMg
oc8b<_ooool06Oooool00ol0003oooooooooo`0Dooooo`001_l00005ooooo`03o`000?oooooooooo
013ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08
ooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?oo
ool00ol0003oooooooooo`05ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo
00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Sooooo
00Co410@oooooooooooooooo0_l0000;ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000oooooooo
ool01Oooool2o`0000Kooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo
00gooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hoooo
o`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;o
oooo00kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00kooooo00Go
0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0
5Oooool00ol0003oooooooooo`0Hooooo`04o`000?ooooooooooooooo`;o00003?ooool00onHV9So
8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Gooooo1?l00005ooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003_ooool0
0olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Wooooo00?o0000ooooooooool05?ooool0
00_ooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEE
olc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000oooooooooooooooo
o`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo0000
00kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Kooooo00?o0000
ooooooooool06?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Kooooo1?l00005ooooo`05o`000?ooooooooooooooool0
00003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000>
ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Jooooo`03o`000?oo
oooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go410@oooooooooooooooooa0@
400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooo
oooooooo410@00cooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00co
oooo0_l000001?oooooo0000o`000?l00002ooooo`03o`000?oooooooooo01Sooooo0ol0000Hoooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo017ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo017ooooo00Go
410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000oooooooo
ool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo0ol000001OnHV9So410@o`000?l0003ooooo00;o00006_oo
ool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zj
oooooonHV9So410@00Cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo0_l0000Booooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooo
oooo<S8b00Cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Dooooo`002Oooool0
0omEEEGoIVIVo`00000Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0
000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool5o`0001Oooooo00?o0000oooo
ooooool06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c004ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000Iooooo`03oeEEEOmVIVKo000001Ko
oooo002/ooooo`03o`000?oooooooooo01oooooo0_l0000Nooooo`;o0000N?ooool00:cooooo00?o
0000ooooooooool07Oooool4o`0001kooooo0_l0001hooooo`00[?ooool00ol0003oooooooooo`0M
ooooo`Co0000SOooool2o`0000;ooooo0_l00005ooooo`00[?ooool00ol0003oooooooooo`0Eoooo
o`;o00001_ooool2o`0000[ooooo0_l00023ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1Ooo
ool00:cooooo00?o0000ooooooooool00_l0000Cooooo`;o00001_ooool2o`0000[ooooo0_l00024
ooooo`04omgMgOl0003o410@olc<c0Kooooo0007oooooooo0000C?l0000<ooooo`04onk^k_lQ8B7o
410@onk^kPKooooo0007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
1?l0003oooooooooooooool2o`0000;ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`Co00002?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool01?lQ8B7oMgMgogMg
Molb<S86ooooo`001oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool02Oooool2o`0000;ooooo0_l00005ooooo`00Toooool2o`0001Oooooo00?o0000
ooooooooool0:oooool2o`0008cooooo0029ooooo`;o00002?ooool2o`0001Oooooo00?o0000oooo
ooooool01oooool3o`00027ooooo0ol0002;ooooo`00ROooool2o`00027ooooo00?o0000oooooooo
ool01oooool3o`0002;ooooo0_l0002;ooooo`00O_ooool2o`0002cooooo00?o0000ooooooooool0
5?ooool2o`000:?ooooo001nooooo`;o0000;?ooool00ol0003oooooooooo`0Dooooo`;o0000Xooo
ool00:cooooo0ol0000Cooooo`;o0000Y?ooool00:cooooo00?o0000ooooooooool04oooool2o`00
0:Cooooo001oooooo`;o0000:oooool01?l0003oooooo`000?l0002hooooo`00Ooooool2o`0002_o
oooo00Co0000ooooool0003o00004_ooool2o`0002Wooooo0_l0001iooooo`00Q?ooool2o`0002Ko
oooo00?o0000ooooooooool00oooool2o`0000kooooo0_l0000Fooooo`;o00004Oooool4o`0007Oo
oooo0024ooooo`;o00009_ooool00ol0003oooooooooo`03ooooo`;o00000_ooool2o`0002;ooooo
0ol0000?ooooo`;o000000?oooooo`000?l00000Moooool009Gooooo0_l0000Eooooo`03o`000?oo
oooooooo00Oooooo0_l00003ooooo`;o00001Oooool3o`0001Kooooo0_l0000>ooooo`?o0000N_oo
ool008cooooo0_l00007ooooo`;o00005Oooool00ol0003oooooooooo`0<ooooo`;o00001Oooool3
o`0001Gooooo0_l0000?ooooo`?o0000N_ooool008cooooo0_l0000Nooooo`03o`000?oooooooooo
01?ooooo0_l0000Fooooo`;o00004?ooool2o`0007[ooooo002@ooooo`;o000000?oooooo`000?l0
00005oooool3o`000;Wooooo002@ooooo`;o000000?oooooo`000?l000005oooool00ol0003ooooo
ooooo`2iooooo`00S?ooool2o`0001kooooo00?o0000ooooooooool07_ooool2o`0001kooooo0_l0
000Gooooo`;o0000H?ooool008Cooooo0_l00006ooooo`;o00007_ooool01?l0003oooooo`000?l0
000Mooooo`;o00007_ooool2o`0001Oooooo0_l0001Pooooo`00Q?ooool2o`0002Kooooo00Co0000
ooooool0003o0000?_ooool2o`0007Sooooo002/ooooo`03o`000?oooooooooo02[ooooo0_l0000C
ooooo`;o0000N?ooool00:cooooo00?o0000ooooooooool07?ooool2o`0000cooooo0_l0000/oooo
o`;o0000Goooool00:cooooo00?o0000ooooooooool07?ooool2o`0001kooooo0_l000000ooooooo
0000o`00000Gooooo`;o0000Goooool00:cooooo0ol0000looooo`Go0000N?ooool009cooooo0_l0
000>ooooo`03o`000?oooooooooo03kooooo0_l0000Gooooo`;o0000H?ooool009cooooo0_l0000>
ooooo`03o`000?oooooooooo05Oooooo0_l0001Pooooo`00U_ooool2o`0001Cooooo00?o0000oooo
ooooool0^Oooool009Kooooo0_l0000Dooooo`03o`000?oooooooooo00Kooooo0_l0000;ooooo`;o
00005?ooool2o`0008kooooo002@ooooo`;o00006_ooool00ol0003oooooooooo`06ooooo`;o0000
2oooool2o`0001Cooooo0_l0002>ooooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool01Ooo
ool2o`0001Gooooo0_l0002Kooooo`00[?ooool00ol0003oooooooooo`05ooooo`;o00005Oooool2
o`0009_ooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool00_l00009ooooo`;o
00001Oooool2o`000:Gooooo0026ooooo`;o00000_ooool2o`00023ooooo00?o0000ooooooooool0
0_l00002ooooo`;o00001Oooool2o`0000Gooooo0_l00008ooooo`;o0000Voooool008Kooooo0_l0
0002ooooo`;o00008?ooool00ol0003oooooooooo`04ooooo`;o00005?ooool4o`0003Sooooo0_l0
001Qooooo`00R_ooool2o`00023ooooo00?o0000ooooooooool06_ooool2o`0000cooooo0_l0000/
ooooo`;o0000HOooool008[ooooo0_l0000Pooooo`03o`000?oooooooooo00;o00009_ooool2o`00
017ooooo0_l0001looooo`00ROooool01Oo^k^ko0000o`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool00_l00006
ooooo`;o00001_ooool2o`0002Wooooo0ol0001kooooo`00ROooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo00Sooooo0_l00006ooooo`;o0000:_ooool2o`0007_ooooo0029
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oo
oooooooo00?ooooo0ol0000Yooooo`;o0000:_ooool2o`0006;ooooo0029ooooo`05o`000?oooooo
ooooooooool000003Oooool00onHV9So0000o`000007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0:Oooool2o`0002[ooooo0_l0001Rooooo`00ROooool01Ol0003ooooooooooooo
oooo000000kooooo0_l00004ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`08ooooo`;o00001Oooool2o`0000Sooooo0_l0002Nooooo`00ROooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Sooooo0_l00005ooooo`;o00002?ooool2o`0001kooooo0_l0001nooooo`00ROoo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0>Oooool2o`0007kooooo0020ooooo`;o0000
1oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co00001_ooool00ol0003oooooooooo`0?ooooo`;o00005oooool2o`0008oooooo0020ooooo`;o
0000:_ooool00ol0003oooooooooo`0?ooooo`;o00005Oooool4o`0008oooooo002/ooooo`03o`00
0?oooooooooo02Kooooo0_l0002Aooooo`00[?ooool00ol0003oooooooooo`0hooooo`;o0000Oooo
ool0093ooooo0_l0000Iooooo`Co0000>?ooool2o`0007oooooo002@ooooo`;o00006Oooool2o`00
01[ooooo0_l0000:ooooo`?o0000T_ooool008cooooo0_l0000Nooooo`03o`000?oooooooooo00go
oooo0_l00009ooooo`;o00002_ooool3o`0009;ooooo002<ooooo`;o00007_ooool00ol0003ooooo
ooooo`05ooooo`;o00001_ooool2o`0002[ooooo0_l0001nooooo`00[?ooool00ol0003ooooooooo
o`05ooooo`;o00001Oooool2o`0001Sooooo0_l0000Aooooo`;o0000O_ooool009cooooo0_l0000>
ooooo`03o`000?oooooooooo00cooooo0_l0000Eooooo`;o000000?oooooo`000?l000003_ooool2
o`00087ooooo002Looooo`;o00003_ooool00ol0003oooooooooo`0Sooooo`;o00004Oooool2o`00
087ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o00005Oooool2o`000:;ooooo
0021ooooo`;o00004_ooool2o`0000Sooooo0_l00007ooooo`;o00000_ooool00ol0003ooooooooo
o`0;ooooo`?o00001oooool2o`000:;ooooo0021ooooo`;o00001?ooool2o`0000cooooo0_l00008
ooooo`;o00001_ooool3o`0000;ooooo00?o0000ooooooooool02oooool3o`000:_ooooo0027oooo
o`;o00007_ooool2o`0000?ooooo00?o0000ooooooooool08oooool2o`0009Cooooo002/ooooo`03
o`000?oooooooooo00Wooooo0_l0000Fooooo`Co0000U?ooool008Sooooo0_l0000;ooooo`;o0000
2_ooool2o`0000Wooooo00?o0000ooooooooool02Oooool2o`0001Kooooo1?l0002Dooooo`00R?oo
ool2o`0000_ooooo0_l0000:ooooo`;o00002Oooool00ol0003oooooooooo`0Qooooo`;o00004_oo
ool3o`00087ooooo002/ooooo`03o`000?oooooooooo03Gooooo0ol00021ooooo`00T_ooool2o`00
01Sooooo0ol00009ooooo`;o0000[_ooool009;ooooo0_l00003ooooo`;o00004oooool00ol0003o
ooooooooo`09ooooo`;o0000[_ooool008Sooooo0_l0000=ooooo`;o00004oooool00ol0003ooooo
ooooo`0Oooooo`;o00005?ooool2o`0008;ooooo0028ooooo`;o00008_ooool00ol0003ooooooooo
o`0Booooo`;o00002oooool2o`0001Cooooo0_l00022ooooo`00P_ooool2o`0001[ooooo0_l0000<
ooooo`04o`000?oooooo0000o`00017ooooo0_l0000;ooooo`;o0000V?ooool008;ooooo0_l0000J
ooooo`;o00003?ooool01?l0003oooooo`000?l00006ooooo`;o00005_ooool2o`00017ooooo0ol0
0024ooooo`00Poooool2o`00027ooooo0ol00003ooooo`03o`000?oooooooooo00Oooooo0_l0000F
ooooo`;o00004Oooool3o`0008Cooooo0023ooooo`;o00000oooool2o`0000[ooooo0_l0000;oooo
o`;o00000oooool3o`0000?ooooo00?o0000ooooooooool0<Oooool2o`0008Kooooo0028ooooo`;o
00002_ooool2o`0000_ooooo0_l00009ooooo`?o0000<Oooool2o`0008Kooooo002/ooooo`03o`00
0?oooooooooo013ooooo0_l0002Wooooo`00ROooool2o`00027ooooo00?o0000ooooooooool04?oo
ool2o`000:Oooooo0029ooooo`;o00002Oooool2o`0001Kooooo00?o0000ooooooooool0^Oooool0
09Cooooo0_l0000Fooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo02ko
oooo0_l00029ooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0^ooooo`;o0000ROooool0093o
oooo0_l000001?nHV9SooooooiRHV?mgMgL2o`0000?ooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0^Oooool0093ooooo0_l00003ooooo`03oa0@4?l0003o000000Oo
oooo0_l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03Oooool2o`000:[o
oooo002Aooooo`06o`000?ooooooooooooooool0003ooooo0_l00006ooooo`;o00001?ooool00omg
MgOo<S8booooo`04ooooo`?o00003Oooool2o`000:[ooooo002Aooooo`06o`000?oooooooooooooo
ool0003ooooo0_l00009ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`2iooooo`00TOooool2o`0000;ooooo00?o410@ooooooooool02?ooool3o`000003ooooool0003o
000000Kooooo00?o0000ooooooooool0^Oooool008Cooooo0_l0000;ooooo`;o000000?ooooooiRH
V?mgMgL02_ooool3o`000003ooooool0003o000000Kooooo00?o0000ooooooooool0^Oooool008Co
oooo0ol0000:ooooo`?o000000?o<S8bonk^k_ooool02oooool4o`0000Kooooo00?o0000oooooooo
ool0;Oooool2o`0008[ooooo0025ooooo`;o00009Oooool01?l0003oooooo`000?l0000Eooooo`;o
000000?oooooo`000?l000004_ooool2o`0008[ooooo002/ooooo`04o`000?oooooo0000o`0001Go
oooo1Ol0002Nooooo`00[?ooool01?l0003oooooo`000?l0000Gooooo`;o0000:oooool2o`0007;o
oooo002/ooooo`Co00002?ooool2o`0000cooooo0_l0000/ooooo`;o0000L_ooool00:cooooo00?o
0000ooooooooool02Oooool2o`0000cooooo0_l0000Aooooo`;o0000SOooool00:[ooooo0ol0000Z
ooooo`Co0000SOooool00:[ooooo0ol0000Zooooo`?o0000S_ooool008Kooooo0_l0000Tooooo`03
o`000?oooooooooo02Sooooo0ol0002>ooooo`00Q_ooool2o`0002Cooooo00?o0000ooooooooool0
5?ooool2o`000:?ooooo0026ooooo`?o00008oooool00ol0003oooooooooo`0Dooooo`;o0000Xooo
ool008Kooooo0ol0000;ooooo`;o00004_ooool2o`0000;ooooo00?o0000ooooooooool09?ooool2
o`0009?ooooo002Dooooo`;o00004_ooool2o`0000;ooooo0ol0000Tooooo`;o0000Toooool009Ko
oooo0_l0000Dooooo`03o`000?oooooooooo02Cooooo0_l0002Cooooo`00U_ooool2o`0000cooooo
0_l00006ooooo`03o`000?oooooooooo017ooooo0_l0000Cooooo`;o0000TOooool00:?ooooo0ol0
0006ooooo`03o`000?oooooooooo017ooooo0_l0000Cooooo`;o0000TOooool008Oooooo0_l0000J
ooooo`;o00001oooool00ol0003oooooooooo`0>ooooo`;o0000;oooool2o`0007Sooooo0027oooo
o`;o00008oooool00ol0003oooooooooo`0>ooooo`;o0000;oooool2o`0007Sooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo02;ooooo0_l0002Eooooo`00Qooo
ool2o`0002?ooooo1Ol0000Oooooo`?o0000UOooool008Oooooo0_l0000@ooooo`;o00004Oooool2
o`000003ooooool0003o000001oooooo0_l0002Fooooo`00VOooool3o`00013ooooo0_l0000<oooo
o`;o00005Oooool2o`0009Gooooo0028ooooo`?o00003oooool2o`00013ooooo00?o0000oooooooo
ool02oooool2o`00013ooooo0_l00003ooooo`;o00005_ooool2o`0007gooooo0028ooooo`?o0000
8Oooool00ol0003oooooooooo`0;ooooo`;o00004?ooool2o`0001_ooooo0_l0001mooooo`00ROoo
ool2o`0000oooooo0_l000000ooooooo0000o`00000=ooooo`;o00003?ooool2o`0001;ooooo0_l0
002Hooooo`00ROooool2o`0000oooooo0_l000000ooooooo0000o`00000;ooooo`Co00008?ooool2
o`0009Sooooo0029ooooo`;o00004_ooool2o`0000_ooooo0ol0002kooooo`00ROooool2o`0000So
oooo0_l00007ooooo`?o00003Oooool00ol0003oooooooooo`2iooooo`00Toooool2o`0000Oooooo
0_l0000>ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0=?ooool2o`0008?ooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@;o
00001?ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`0Gooooo`;o00006oooool2o`0008?ooooo0029ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@;o00001?ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool05oooool4o`0009kooooo0029ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool06Oooool2o`0009kooooo0029ooooo`05o`000?ooooooooooooooool000001oooool2o`00
00Gooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`?o00006?ooool2o`00
09oooooo0029ooooo`05o`000?ooooooooooooooool000001oooool2o`0000Gooooo00?oEEEEolc<
c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool06?ooool2
o`0009oooooo0029ooooo`05oa0@4?ooooooooooooooool@41002_ooool2o`0000;ooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Wooooo0029oooo
o`03ogMgMonHV9Sooooo00;o00002?ooool4o`0000?ooooo00?o<S8booooooooool00_ooool00ol0
003oooooooooo`07ooooo`04o`000?oooooo0000o`000;Sooooo0029ooooo`03onk^k_lb<S;o0000
00;o00002?ooool2o`000003ooooool0003o000000?o00001?ooool4o`0000Kooooo00Co0000oooo
ool0003o0000^?ooool009Wooooo0_l0000@ooooo`;o0000^oooool009Wooooo0_l0000@ooooo`;o
0000^oooool00:cooooo00?o0000ooooooooool0^Oooool008kooooo0_l0000Looooo`?o0000^Ooo
ool008kooooo0ol0000Kooooo`03o`000?oooooooooo017ooooo0_l0002Vooooo`00Soooool2o`00
01_ooooo00?o0000ooooooooool03oooool4o`000:Kooooo002/ooooo`03o`000?oooooooooo00oo
oooo0_l0002Xooooo`00WOooool2o`0000Gooooo0_l00006ooooo`03o`000?oooooooooo0;Wooooo
002Mooooo`;o00001Oooool2o`0000Kooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool09_ooool2o`00097ooooo002/ooooo`?o
00009_ooool2o`00097ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Booooo`;o00006?oo
ool00ol0003oooooooooo`09ooooo`;o0000[_ooool009;ooooo0_l0000Hooooo`03o`000?oooooo
oooo00Wooooo0ol0002]ooooo`00[?ooool00ol0003oooooooooo`0:ooooo`;o0000[Oooool00:co
oooo00?o0000ooooooooool0^Oooool009?ooooo0_l0000Gooooo`03o`000?oooooooooo0;Wooooo
002Cooooo`;o00005oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`03
ooooo`;o0000]?ooool00:cooooo0ol000000ooooooo0000o`000002o`000;Cooooo002Eooooo`;o
00005Oooool01?l0003oooooooooooooool2o`000;Kooooo002Eooooo`?o00005?ooool00ol0003o
ooooooooo`03ooooo`;o0000]?ooool009Kooooo0_l0000Dooooo`03o`000?oooooooooo00?ooooo
0_l0002dooooo`00[?ooool00ol0003oooooooooo`02ooooo`;o00005oooool2o`0009cooooo002/
ooooo`03o`000?oooooooooo00;ooooo0_l0000Gooooo`;o0000W?ooool009Wooooo0_l0000Aoooo
o`Co0000^?ooool009Wooooo0_l0000>ooooo`;o000000?oooooo`000?l000000_l0002hooooo`00
VOooool2o`0000kooooo1_l0002iooooo`00Zoooool3o`000;[ooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002Kooooo`;o00003oooool00ol0003oooooooooo`2iooooo`00Voooool2o`0000oo
oooo00?o0000ooooooooool0^Oooool00:Kooooo0_l00004ooooo`03o`000?oooooooooo0;Wooooo
002Rooooo`Ko00001?ooool00ol0003oooooooooo`2iooooo`00Xoooool3o`0000Kooooo00?o0000
ooooooooool0^Oooool00:Cooooo00?o0000ooooooooool01Oooool3o`000;Wooooo002Tooooo`03
o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oo
oooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Rooooo`03oeEEEOmVIVKo0000
0<?ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Zoooo
o`04oa0@4?l0003o0000o`000;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03
o`000?oooooooooo0;[ooooo002[ooooo`06o`000?mgMgOo0000o`000?mEEEGok^k^]oooool00:_o
oooo00Ko0000oeEEEOo^k^koooooogMgMomEEEFgooooo`00Zoooool00ol0003ok^k^ooooo`02oooo
o`03o`000?oooooooooo0;Gooooo002[ooooo`03o`000?o^k^kooooo00;ooooo00?o0000oooooooo
ool0]Oooool00:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomVIVJgooooo`00Z_ooool00ol@413o
0000ogMgM`02o`000003ofIVI_o^k^kooooo0;Kooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.63814 .41262 Mdot
.6451 .60599 Mdot
.4503 .57951 Mdot
.54993 .46102 Mdot
.45462 .80371 Mdot
.49985 .13211 Mdot
.44994 .36757 Mdot
.66308 .75857 Mdot
.70084 .60036 Mdot
.41359 .4586 Mdot
.49655 .23166 Mdot
.60737 .84977 Mdot
.54284 .8561 Mdot
.44269 .25362 Mdot
.56207 .90305 Mdot
.52478 .68071 Mdot
.56629 .71503 Mdot
.53447 .8687 Mdot
.57462 .57174 Mdot
.46499 .05175 Mdot
.50346 .90422 Mdot
.60763 .72527 Mdot
.57273 .79059 Mdot
.50902 .9018 Mdot
.47629 .9941 Mdot
.50438 .18958 Mdot
.54443 .34178 Mdot
.57313 .56599 Mdot
.50888 .07343 Mdot
.6365 .63491 Mdot
.44397 .89831 Mdot
.706 .58541 Mdot
.67015 .72961 Mdot
.47985 .85734 Mdot
.40958 .72592 Mdot
.42876 .11462 Mdot
.67115 .33297 Mdot
.57405 .48809 Mdot
.56466 .1486 Mdot
.60265 .8617 Mdot
.49896 .98677 Mdot
.44245 .8345 Mdot
.40986 .26301 Mdot
.64469 .42385 Mdot
.61991 .33839 Mdot
.40297 .44966 Mdot
.44621 .252 Mdot
.71109 .49481 Mdot
.59859 .40733 Mdot
.51755 .08879 Mdot
.70962 .49475 Mdot
.60065 .19379 Mdot
.77359 .40879 Mdot
.39309 .44324 Mdot
.39145 .46115 Mdot
.6883 .66694 Mdot
.65267 .77668 Mdot
.57442 .69824 Mdot
.69929 .41955 Mdot
.61022 .3134 Mdot
.4118 .33753 Mdot
.37606 .24157 Mdot
.57727 .16882 Mdot
.42356 .56435 Mdot
.65323 .75242 Mdot
.70135 .6207 Mdot
.41345 .48703 Mdot
.5293 .65995 Mdot
.57556 .47935 Mdot
.47215 .92782 Mdot
.57037 .71959 Mdot
.52029 .45275 Mdot
.41839 .39022 Mdot
.42857 .67686 Mdot
.57717 .16876 Mdot
.48099 .35593 Mdot
.77371 .40959 Mdot
.46736 .17678 Mdot
.57933 .16219 Mdot
.59187 .40843 Mdot
.38045 .57144 Mdot
.63633 .63042 Mdot
.5431 .41944 Mdot
.43667 .82411 Mdot
.68395 .70403 Mdot
.52755 .68018 Mdot
.44518 .78872 Mdot
.40842 .60804 Mdot
.59272 .64448 Mdot
.5242 .67503 Mdot
.46345 .99076 Mdot
.66945 .18791 Mdot
.44191 .30381 Mdot
.40493 .57614 Mdot
.4301 .36389 Mdot
.64036 .14426 Mdot
.43731 .27041 Mdot
.70646 .52019 Mdot
.77768 .42425 Mdot
.59645 .63896 Mdot
.64478 .45601 Mdot
.60697 .57618 Mdot
.59891 .85825 Mdot
.64978 .46434 Mdot
.40554 .79767 Mdot
.46331 .85567 Mdot
.54836 .76453 Mdot
.56643 .62354 Mdot
.44311 .29945 Mdot
.46078 .92224 Mdot
.42093 .35388 Mdot
.54735 .43053 Mdot
.70556 .58208 Mdot
.42185 .12484 Mdot
.77917 .63224 Mdot
.44823 .32632 Mdot
.43359 .23139 Mdot
.70443 .6301 Mdot
.70712 .60633 Mdot
.66972 .34101 Mdot
.53962 .85927 Mdot
.3609 .51911 Mdot
.51783 .87786 Mdot
.51207 .07545 Mdot
.46383 .92484 Mdot
.55168 .51318 Mdot
.44946 .07058 Mdot
.60155 .09703 Mdot
.64355 .5663 Mdot
.52196 .3941 Mdot
.58443 .77357 Mdot
.64782 .50654 Mdot
.5735 .89639 Mdot
.50319 .13353 Mdot
.43727 .16123 Mdot
.55103 .12186 Mdot
.65495 .2835 Mdot
.48707 .05571 Mdot
.41728 .40511 Mdot
.64719 .77511 Mdot
.56093 .90668 Mdot
.51035 .29966 Mdot
.57781 .51429 Mdot
.56714 .71388 Mdot
.44112 .07853 Mdot
.69324 .67509 Mdot
.75464 .72031 Mdot
.54337 .68701 Mdot
.40426 .53893 Mdot
.3745 .7462 Mdot
.61014 .5499 Mdot
.56224 .38821 Mdot
.50871 .90359 Mdot
.51484 .41465 Mdot
.56725 .23787 Mdot
.64224 .2644 Mdot
.58475 .17599 Mdot
.7002 .63886 Mdot
.67252 .34067 Mdot
.64522 .26867 Mdot
.55692 .28389 Mdot
.57538 .15449 Mdot
.5377 .95078 Mdot
.39886 .23209 Mdot
.41781 .23 Mdot
.64213 .45484 Mdot
.69424 .6688 Mdot
.39219 .72374 Mdot
.57403 .46446 Mdot
.63639 .24665 Mdot
.49217 .06522 Mdot
.47501 .25817 Mdot
.56803 .43039 Mdot
.43439 .75763 Mdot
.53624 .71038 Mdot
.65862 .74894 Mdot
.62938 .13082 Mdot
.56258 .23058 Mdot
.45043 .32602 Mdot
.53051 .10135 Mdot
.61438 .20891 Mdot
.57216 .90294 Mdot
.47071 .77072 Mdot
.48681 .99651 Mdot
.5348 .53404 Mdot
.69918 .5969 Mdot
.60169 .09923 Mdot
.71162 .563 Mdot
.54486 .94121 Mdot
.41999 .21257 Mdot
.37028 .6972 Mdot
.439 .08161 Mdot
.44298 .68521 Mdot
.37036 .29957 Mdot
.67342 .73192 Mdot
.45275 .99472 Mdot
.58933 .87364 Mdot
.4096 .63109 Mdot
.70064 .2303 Mdot
.51606 .82521 Mdot
.43027 .47937 Mdot
.43115 .4523 Mdot
.52272 .48473 Mdot
.45414 .79938 Mdot
.71714 .26012 Mdot
.64577 .48693 Mdot
.49721 .70325 Mdot
.52651 .16932 Mdot
.54401 .40354 Mdot
.53005 .59429 Mdot
.50131 .23769 Mdot
.58429 .78658 Mdot
.45601 .18635 Mdot
.39056 .71108 Mdot
.48315 .76456 Mdot
.64327 .46769 Mdot
.44107 .21519 Mdot
.52909 .95981 Mdot
.53681 .52593 Mdot
.60422 .30866 Mdot
.62217 .83295 Mdot
.42619 .25756 Mdot
.70096 .4495 Mdot
.40373 .79218 Mdot
.38045 .42433 Mdot
.49896 .73922 Mdot
.49971 .79215 Mdot
.65273 .56648 Mdot
.46265 .2632 Mdot
.56061 .9054 Mdot
.36032 .4859 Mdot
.54489 .60611 Mdot
.47039 .6632 Mdot
.72378 .27958 Mdot
.60706 .50789 Mdot
.53823 .31968 Mdot
.36296 .58668 Mdot
.57189 .45662 Mdot
.6521 .48671 Mdot
.53595 .8565 Mdot
.64748 .48944 Mdot
.37877 .22342 Mdot
.45448 .12816 Mdot
.37832 .56174 Mdot
.57091 .71815 Mdot
.70928 .58004 Mdot
.42696 .39422 Mdot
.64097 .26976 Mdot
.59157 .62731 Mdot
.57404 .71051 Mdot
.5769 .16633 Mdot
.45886 .99785 Mdot
.44611 .33418 Mdot
.4387 .66542 Mdot
.65436 .30028 Mdot
.5204 .21953 Mdot
.56576 .41958 Mdot
.39263 .40582 Mdot
.48983 .36765 Mdot
.65317 .77092 Mdot
.70725 .45926 Mdot
.60551 .45593 Mdot
.53736 .31722 Mdot
.38411 .35602 Mdot
.49672 .31206 Mdot
.60846 .54887 Mdot
.63022 .38662 Mdot
.46437 .22503 Mdot
.48423 .12464 Mdot
.45854 .0676 Mdot
.55446 .28784 Mdot
.43319 .10037 Mdot
.39295 .41121 Mdot
.41258 .49413 Mdot
.59878 .42984 Mdot
.63763 .25376 Mdot
.46481 .76957 Mdot
.53951 .71327 Mdot
.70989 .51492 Mdot
.48766 .21717 Mdot
.55295 .21093 Mdot
.54689 .12006 Mdot
.52333 .38848 Mdot
.44267 .7261 Mdot
.67296 .34448 Mdot
.61512 .83453 Mdot
.56514 .63086 Mdot
.49349 .33838 Mdot
.48437 .80354 Mdot
.3924 .25436 Mdot
.40327 .48323 Mdot
.386 .65394 Mdot
.60345 .10234 Mdot
.69614 .41579 Mdot
.59035 .86545 Mdot
.69671 .43234 Mdot
.43829 .55024 Mdot
.69029 .37697 Mdot
.36577 .37025 Mdot
.37877 .3993 Mdot
.57185 .89007 Mdot
.73704 .76349 Mdot
.59263 .3937 Mdot
.41298 .2356 Mdot
.64913 .51198 Mdot
.70776 .58358 Mdot
.49926 .98364 Mdot
.45676 .23053 Mdot
.70851 .51625 Mdot
.53061 .23658 Mdot
.44143 .62819 Mdot
.58129 .78875 Mdot
.55876 .73441 Mdot
.54427 .85018 Mdot
.3835 .80597 Mdot
.46373 .2955 Mdot
.61488 .33691 Mdot
.45759 .85268 Mdot
.64303 .77407 Mdot
.49791 .31188 Mdot
.56254 .91431 Mdot
.3751 .72712 Mdot
.5481 .57611 Mdot
.50227 .13039 Mdot
.43616 .82467 Mdot
.59892 .2005 Mdot
.50253 .79011 Mdot
.43291 .57596 Mdot
.43796 .45264 Mdot
.55697 .74524 Mdot
.6394 .80407 Mdot
.65268 .30062 Mdot
.42678 .38751 Mdot
.59736 .75636 Mdot
.52528 .40647 Mdot
.52284 .49281 Mdot
.65145 .57604 Mdot
.48441 .11802 Mdot
.41851 .22674 Mdot
.55775 .2864 Mdot
.46315 .80765 Mdot
.76416 .36878 Mdot
.53592 .24996 Mdot
.63809 .61228 Mdot
.42248 .53528 Mdot
.67696 .70545 Mdot
.53765 .32376 Mdot
.4782 .05394 Mdot
.61958 .68377 Mdot
.47636 .2505 Mdot
.41626 .31886 Mdot
.61606 .83822 Mdot
.68839 .36452 Mdot
.43766 .09409 Mdot
.58415 .3586 Mdot
.515 .8236 Mdot
.47857 .05852 Mdot
.60838 .52741 Mdot
.61528 .83874 Mdot
.37737 .52574 Mdot
.57465 .89396 Mdot
.55493 .9237 Mdot
.50317 .98598 Mdot
.51989 .56333 Mdot
.60559 .4769 Mdot
.55558 .91265 Mdot
.65452 .77089 Mdot
.51721 .58407 Mdot
.4033 .78029 Mdot
.54252 .26761 Mdot
.52517 .16504 Mdot
.64303 .44303 Mdot
.706 .54065 Mdot
.65161 .48545 Mdot
.68153 .3587 Mdot
.63297 .2612 Mdot
.57833 .77925 Mdot
.67985 .33769 Mdot
.58736 .76585 Mdot
.50566 .97395 Mdot
.77347 .66287 Mdot
.67951 .3718 Mdot
.57247 .24374 Mdot
.51133 .40299 Mdot
.40546 .89144 Mdot
.59875 .62368 Mdot
.43693 .47897 Mdot
.56985 .90775 Mdot
.46669 .92662 Mdot
.43593 .60445 Mdot
.41953 .61534 Mdot
.47723 .16802 Mdot
.54768 .34665 Mdot
.71247 .50679 Mdot
.40439 .80073 Mdot
.3699 .30854 Mdot
.56673 .91021 Mdot
.52521 .80064 Mdot
.75743 .35759 Mdot
.51678 .81772 Mdot
.54216 .69612 Mdot
.53153 .72699 Mdot
.50766 .57425 Mdot
.64135 .79817 Mdot
.60961 .84585 Mdot
.54159 .33333 Mdot
.47931 .25411 Mdot
.53191 .29457 Mdot
.50699 .73186 Mdot
.40703 .90625 Mdot
.41028 .64366 Mdot
.39296 .26703 Mdot
.52479 .34146 Mdot
.56489 .40177 Mdot
.50746 .33966 Mdot
.42321 .72142 Mdot
.49473 .84573 Mdot
.54875 .34356 Mdot
.48777 .72002 Mdot
.36457 .63288 Mdot
.65055 .76929 Mdot
.49684 .57694 Mdot
.40206 .67647 Mdot
.54768 .76566 Mdot
.59311 .29268 Mdot
.55482 .29393 Mdot
.57048 .43965 Mdot
.40668 .89803 Mdot
.65752 .16359 Mdot
.65154 .51514 Mdot
.78744 .57183 Mdot
.64841 .43959 Mdot
.47492 .73084 Mdot
.69168 .63471 Mdot
.54525 .92515 Mdot
.50977 .2579 Mdot
.61583 .69118 Mdot
.76704 .3802 Mdot
.4903 .26276 Mdot
.4504 .66808 Mdot
.52119 .74411 Mdot
.38121 .39656 Mdot
.58271 .3683 Mdot
.68725 .21154 Mdot
.53244 .56896 Mdot
.39439 .57315 Mdot
.4554 .85541 Mdot
.42138 .4654 Mdot
.46439 .29693 Mdot
.44393 .73632 Mdot
.66098 .762 Mdot
.47676 .28641 Mdot
.56391 .14013 Mdot
.6502 .56964 Mdot
.61978 .34435 Mdot
.43941 .08659 Mdot
.39661 .73977 Mdot
.54467 .76533 Mdot
.59114 .08128 Mdot
.41674 .5864 Mdot
.63668 .80926 Mdot
.46902 .22308 Mdot
.68978 .37224 Mdot
.55502 .29195 Mdot
.57198 .69452 Mdot
.47244 .0537 Mdot
.64525 .45355 Mdot
.57008 .59886 Mdot
.41674 .31476 Mdot
.48727 .85483 Mdot
.36782 .31081 Mdot
.44175 .1548 Mdot
.47171 .35307 Mdot
.40523 .2964 Mdot
.59325 .41026 Mdot
.52263 .54048 Mdot
.54132 .61014 Mdot
.39218 .4827 Mdot
.42419 .19587 Mdot
.43541 .39418 Mdot
.50689 .19909 Mdot
.7004 .625 Mdot
.46658 .81549 Mdot
.62378 .36562 Mdot
.5781 .4779 Mdot
.56886 .58288 Mdot
.50182 .65347 Mdot
.7847 .61149 Mdot
.49322 .67671 Mdot
.6485 .59099 Mdot
.70045 .46747 Mdot
.4007 .22003 Mdot
.57656 .49847 Mdot
.5053 .072 Mdot
.5853 .88409 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:3ooooo0_l0000:ooooo`?o0000^Oooool00:3ooooo1_l000000ooooooo0000o`00
0003ooooo`03o`000?oooooooooo0;Wooooo002Rooooo`Co000000?oooooo`000?l000000oooool0
0ol0003oooooooooo`2iooooo`00Y?ooool2o`0000Kooooo00?o0000ooooooooool0^Oooool00:Wo
oooo0_l000000ooooooo0000ooooo`2jooooo`00W_ooool2o`0000Wooooo0_l000000ooooooo0000
ooooo`2jooooo`00Voooool2o`000003ooooool0003o000000cooooo00?o0000ooooooooool0^Ooo
ool009_ooooo0_l0000?ooooo`Co0000^?ooool00:cooooo1_l0002fooooo`00V?ooool2o`0001;o
oooo00Co0000oooooooooooooooo0_l0002fooooo`00Uoooool3o`0001;ooooo00?o0000oooooooo
ool06oooool2o`0009cooooo002Gooooo`;o00004oooool00ol0003oooooooooo`0Kooooo`;o0000
W?ooool009Sooooo0_l0000Booooo`03o`000?oooooooooo00;ooooo0_l0002eooooo`00V?ooool2
o`0001;ooooo00?o0000ooooooooool00_ooool2o`000;Gooooo002Gooooo`;o00004oooool00ol0
003oooooooooo`2iooooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool07_ooool2o`0009Wo
oooo002Fooooo`;o00005?ooool3o`0000Oooooo0_l0000Eooooo`;o0000VOooool009Kooooo0_l0
000Dooooo`03o`000?oooooooooo00Oooooo0_l0000Eooooo`?o0000V?ooool00:cooooo00?o0000
ooooooooool07oooool2o`0009Sooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`2iooooo`00ROoo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o8B4Qo`000?l000001Oooool00ol0003ok^k^
ooooo`04ooooo`04odA4A?l0003o0000oc8b<P;o00001?ooool00ol0003oooooooooo`2iooooo`00
ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oo
oooo00?oMgMgo`000?l000001?ooool00ol0003oooooooooo`0<ooooo`?o0000Z_ooool0087ooooo
1_l00002ooooo`05oa0@4?ooooooooooooooool@41001?ooool2o`0000Oooooo00?oZJVYoeEEEOoo
ool02?ooool2o`0000Cooooo0ol0000<ooooo`?o0000Z_ooool008Wooooo00Go0000oooooooooooo
ooooo`000004ooooo`;o00002?ooool00olQ8B7o0000o`000006ooooo`03ogMgMol0003o000000Co
oooo00?o0000ooooooooool0^Oooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
oeEEEOl0003o000000?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`;o0000:?ooool2o`00
093ooooo0029ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03oooo
o`03o`000?oooooooooo00Oooooo0ol0000Wooooo`;o0000T?ooool008Wooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07
ooooo`?o0000^Oooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4
o`0000Kooooo00?o0000ooooooooool04_ooool2o`000:Gooooo002/ooooo`03o`000?oooooooooo
01;ooooo0_l0002Uooooo`00[?ooool00ol0003oooooooooo`0[ooooo`;o0000S?ooool00:cooooo
00?o0000ooooooooool04_ooool2o`0001Oooooo0_l0002<ooooo`00[?ooool3o`0001;ooooo0_l0
002Uooooo`00V?ooool2o`0001;ooooo00?o0000ooooooooool05Oooool2o`000:;ooooo002Hoooo
o`;o00004_ooool00ol0003oooooooooo`0Eooooo`;o0000X_ooool009Oooooo0_l0000Cooooo`03
o`000?oooooooooo01Oooooo0_l0002Pooooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool0
1Oooool2o`00013ooooo0_l0000Hooooo`;o0000Q_ooool00:Cooooo0_l00006ooooo`03o`000?oo
oooooooo00Gooooo0_l0000?ooooo`;o00006Oooool2o`0008Kooooo002Tooooo`;o00001_ooool0
0ol0003oooooooooo`05ooooo`;o00003oooool2o`000:7ooooo002/ooooo`03o`000?oooooooooo
00Gooooo0_l0000?ooooo`;o0000XOooool00:7ooooo0_l00009ooooo`?o00006Oooool2o`0009ko
oooo002Qooooo`;o00002Oooool00ol0003oooooooooo`0Iooooo`;o0000W_ooool00:cooooo00?o
0000ooooooooool0^Oooool009gooooo0_l0000=ooooo`03o`000?oooooooooo0;Wooooo002Moooo
o`;o00003Oooool00ol0003oooooooooo`0eooooo`;o0000P_ooool00:cooooo0ol0000eooooo`;o
0000P_ooool00:cooooo0ol0000Nooooo`;o0000VOooool009?ooooo0_l0000Gooooo`03o`000?oo
oooooooo01kooooo0_l0002Iooooo`00Toooool2o`0001Oooooo1?l0000Looooo`;o0000V_ooool0
0:cooooo00Co0000ooooool0003o00007?ooool2o`0009[ooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo02;ooooo0_l0002Eooooo`00TOooool2o`0001Wooooo
00?o0000ooooooooool03_ooool2o`0001;ooooo0_l0000Fooooo`;o0000OOooool0097ooooo0_l0
0005ooooo`;o00004_ooool00ol0003oooooooooo`0>ooooo`;o0000:_ooool2o`0007gooooo002H
ooooo`;o00003Oooool2o`0000?ooooo00?o0000ooooooooool00oooool2o`000;Cooooo002;oooo
o`;o00006_ooool2o`0000?ooooo00?o0000ooooooooool00oooool2o`000;Cooooo0024ooooo`;o
00001Oooool2o`0001?ooooo0ol00009ooooo`?o0000^Oooool008Cooooo0_l0000;ooooo`;o0000
3Oooool3o`0000Wooooo00?o0000ooooooooool0^Oooool0093ooooo0ol00003ooooo`;o00001Ooo
ool2o`0000_ooooo0ol0000Cooooo`;o0000;?ooool2o`0007Sooooo002:ooooo`;o00001?ooool2
o`0000Cooooo0_l00005ooooo`;o00002oooool3o`0001?ooooo0_l0000/ooooo`;o0000N?ooool0
08[ooooo0_l00003ooooo`;o00006oooool2o`0000Sooooo0_l0000:ooooo`;o0000Y?ooool008oo
oooo0_l0000Kooooo`;o00002?ooool2o`0000[ooooo0_l0002Tooooo`00Poooool2o`0000cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool05?ooool2o`000:?ooooo0023ooooo`;o00003?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool05?ooool2o`0001Cooooo0_l0002=ooooo`00ROooool6o`0000;ooooo00Go410@oooooooo
oooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool2o`00
023ooooo0_l0002=ooooo`00TOooool01Ol0003ooooooooooooooooo000000Cooooo0_l00008oooo
o`;o000000?o<S8booooooooool00oooool3o`0000Sooooo0_l0002_ooooo`00R?ooool2o`0000Oo
oooo00Go0000ooooooooooooooooo`000003ooooo`?o00001_ooool00ol0003o8B4Qo`000002o`00
00Gooooo00?o0000ooooooooool0:_ooool2o`0008gooooo0028ooooo`;o00001oooool01Ol@413o
ooooo`000?l0003o410@00?ooooo0_l00007ooooo`Go00001Oooool00ol0003oooooooooo`02o`00
02Sooooo0_l0002=ooooo`00TOooool01OmgMgOoV9RHo`000?l0003oMgMg00cooooo0ol00007oooo
o`03o`000?oooooooooo00;o00009_ooool2o`0001[ooooo0_l0001cooooo`00S_ooool2o`000006
ooooooo^k^ko<S8bo`000?lb<S;ok^k^2Oooool2o`000003ooooool0003o000000;o00000_ooool2
o`0000;ooooo00?o0000ooooooooool0:?ooool2o`0000;ooooo0_l0000Fooooo`;o0000Loooool0
08Sooooo0_l00004ooooo`;o00003oooool2o`0000Oooooo0_l00002ooooo`03o`000?oooooooooo
00_ooooo0_l0000Oooooo`;o0000Roooool008Sooooo0_l0000=ooooo`;o00004oooool00ol0003o
ooooooooo`0;ooooo`;o00007_ooool4o`0008[ooooo002Gooooo`;o00004oooool00ol0003ooooo
ooooo`0[ooooo`Co0000R_ooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`16
ooooo`;o0000LOooool00:cooooo00?o0000ooooooooool0A_ooool2o`00077ooooo002Tooooo`;o
00001_ooool00ol0003oooooooooo`0?ooooo`?o00007_ooool2o`0008Oooooo002Tooooo`;o0000
1_ooool00ol0003oooooooooo`0?ooooo`?o00007_ooool2o`0008Oooooo002/ooooo`03o`000?oo
oooooooo00oooooo0_l0002Xooooo`00X?ooool2o`0000[ooooo00?o0000ooooooooool01oooool2
o`0000Kooooo0_l0000:ooooo`;o0000W?ooool008cooooo0_l0000Booooo`;o00002_ooool00ol0
003oooooooooo`07ooooo`;o00001_ooool2o`0000[ooooo0_l0002Looooo`00POooool2o`0000Wo
oooo0_l0000;ooooo`;o00001Oooool2o`0000[ooooo1Ol0000]ooooo`?o0000Qoooool0087ooooo
0_l0000Eooooo`?o00004Oooool00ol0003oooooooooo`02o`0002gooooo0ol00027ooooo`00V?oo
ool2o`0001;ooooo00?o0000ooooooooool0^Oooool0087ooooo0_l0000Yooooo`03o`000?oooooo
oooo01oooooo0_l0002Hooooo`00P?ooool3o`0002Oooooo0ol0000Qooooo`Co0000U_ooool0083o
oooo0_l0000>ooooo`;o00006?ooool3o`0002?ooooo0_l0002Fooooo`00T?ooool2o`0001[ooooo
00?o0000ooooooooool02Oooool2o`000:kooooo002@ooooo`;o00006_ooool00ol0003ooooooooo
o`09ooooo`;o0000[_ooool00:cooooo0ol00009ooooo`;o0000[_ooool009[ooooo0ol0000?oooo
o`03o`000?oooooooooo00Wooooo0_l0002^ooooo`00V_ooool3o`0000oooooo00?o0000oooooooo
ool0^Oooool009[ooooo0_l0000@ooooo`03o`000?oooooooooo00[ooooo0_l0000Yooooo`;o0000
P_ooool008kooooo0_l0000:ooooo`;o00004?ooool00ol0003oooooooooo`0:ooooo`;o00005_oo
ool2o`00017ooooo0_l000000ooooooo0000o`00001oooooo`00S_ooool2o`0001Wooooo0_l00000
0ooooooo0000ooooo`02o`00027ooooo1?l0000@ooooo`Co0000Ooooool00:Wooooo0_l000000ooo
oooo0000ooooo`02o`0000Cooooo0_l00004ooooo`Co00005Oooool2o`0000oooooo0ol00021oooo
o`00[?ooool00ol0003oooooooooo`05ooooo`;o00001?ooool4o`0001Gooooo0_l0000?ooooo`?o
0000POooool00:cooooo00?o0000ooooooooool03?ooool2o`0001Kooooo0_l0000@ooooo`;o0000
POooool00:;ooooo0_l00008ooooo`?o0000^Oooool008Gooooo0_l0000:ooooo`;o00003oooool2
o`000003ooooool0003o000000Gooooo00?o0000ooooooooool0^Oooool008Gooooo0_l0000:oooo
o`;o00004_ooool2o`0000Gooooo00?o0000ooooooooool06?ooool2o`0001kooooo0_l0000Hoooo
o`;o0000IOooool00:cooooo00?o0000ooooooooool06?ooool2o`0001kooooo0_l0000Hooooo`;o
0000IOooool009Cooooo0_l0000Fooooo`03o`000?oooooooooo03_ooooo0_l0001looooo`00ROoo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o8B4Qo`000?l000000oooool5o`0000Cooooo
00KoA4A4o`000?l0003o<S8bomgMgOooool2o`0000;ooooo00?o0000ooooooooool09Oooool2o`00
01Cooooo0_l0001looooo`00Ooooool2o`0000Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01OnHV9So8B4Qo`000?l0003oA4A400Oooooo00?oMgMgoc8b<_ooool00_l00002
ooooo`03o`000?oooooooooo01Sooooo0_l0000;ooooo`;o0000;Oooool2o`0006?ooooo001ooooo
o`So00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Sooooo0_l0000Nooooo`;o000000?ooooo
o`000?l000005oooool2o`0006?ooooo0029ooooo`05o`000?ooooooooooooooool000003Oooool0
0onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000hooooo`;o000000?ooooo
o`000?l00000O?ooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKo
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo03_ooooo0_l0
000Hooooo`;o0000H_ooool008Wooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Eooooo`;o0000H_oo
ool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2o`0000Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co
00001_ooool00ol0003oooooooooo`04ooooo`;o00002oooool2o`0001Gooooo0_l0002?ooooo`00
TOooool4o`0001Oooooo00?o0000ooooooooool01?ooool2o`0000_ooooo0_l0000Eooooo`;o0000
Soooool0097ooooo1?l000000ooooooo0000o`00000Dooooo`03o`000?oooooooooo00Cooooo0_l0
000Eooooo`;o0000W?ooool008Cooooo0_l0000=ooooo`;o000000?oooooo`000?l000005?ooool0
0ol0003oooooooooo`04ooooo`;o00005Oooool2o`0009cooooo0024ooooo`;o00009_ooool3o`00
0;Wooooo0024ooooo`;o00009_ooool00ol0003oooooooooo`02o`0000Wooooo0_l00005ooooo`;o
0000YOooool008Sooooo0_l00006ooooo`;o00006_ooool00ol0003oooooooooo`02o`0000?ooooo
0_l00004ooooo`;o00001Oooool2o`0000Wooooo0_l0002Jooooo`00R?ooool2o`0000Kooooo0_l0
000Jooooo`03o`000?oooooooooo00Gooooo0_l0000Dooooo`Co0000>?ooool2o`00063ooooo0028
ooooo`;o00008_ooool00ol0003oooooooooo`0Kooooo`;o00003Oooool2o`0002_ooooo0_l0001P
ooooo`00R?ooool2o`0002;ooooo00Co0000oooooooooooooooo0_l0000Wooooo`;o00004Oooool2
o`0007[ooooo002/ooooo`04o`000?ooooooooooooooo`;o00002?ooool2o`0000Gooooo0_l0000Y
ooooo`?o0000NOooool00:cooooo00?o0000ooooooooool02oooool2o`0000Gooooo0_l0000Zoooo
o`;o0000NOooool008Cooooo0_l0000Vooooo`?o0000;?ooool2o`0002[ooooo0_l0001Oooooo`00
Q?ooool2o`0002Kooooo00?o0000ooooooooool0;?ooool2o`0002[ooooo0_l0001Oooooo`00[?oo
ool00ol0003oooooooooo`0<ooooo`;o00001Oooool2o`0000Sooooo0_l0002Jooooo`00[?ooool0
0ol0003oooooooooo`0<ooooo`;o00001Oooool2o`0000Sooooo0_l0000Oooooo`;o0000NOooool0
0:cooooo00?o0000ooooooooool0?_ooool2o`0007Wooooo002/ooooo`03o`000?oooooooooo01Co
oooo0_l0000Hooooo`;o0000ROooool008Sooooo0_l0000Rooooo`03o`000?oooooooooo01Cooooo
0_l0000Fooooo`Co0000ROooool008Sooooo0_l0000Rooooo`03o`000?oooooooooo02cooooo0_l0
002;ooooo`00S?ooool2o`0001kooooo00?o0000ooooooooool0?oooool2o`0007Sooooo002<oooo
o`;o00001oooool4o`0001?ooooo0ol00003ooooo`;o0000>_ooool2o`0007Sooooo002Eooooo`Co
00004oooool00ol0003oooooooooo`03ooooo`;o00006_ooool2o`0000[ooooo1?l0002:ooooo`00
Soooool2o`0001_ooooo00?o0000ooooooooool05?ooool2o`0000Wooooo0_l0000:ooooo`Co0000
R_ooool000Wooooo1?l000000ol@413oooooooooo`0Fooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000;ooooo0_l0
00001Om4A4Co0000o`000?lb<S;ogMgM01Kooooo00?o0000ooooooooool03Oooool2o`0000Gooooo
0_l00002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05
odA4A?l0003o0000oc8b<_oMgMd02oooool2o`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oM
gMd06?ooool4o`000003oa0@4?oooooooooo01;ooooo000;ooooo`03o`000?oooooooooo01Sooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03
ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo0_l00000
0oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo01Gooooo00?o0000ooooooooool03Oooool2
o`0000Kooooo0_l000001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`06oiRH
V?lQ8B7ok^k^oooooom4A4Cooooo0_l00004ooooo`03ogMgMolb<S;ooooo00[ooooo0_l00002oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool06Oooool00ol0003oooooooooo`0Dooooo`001_l00005ooooo`03o`000?oooooo
oooo013ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEoooo
o`08ooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@4100
4?ooool00ol0003oooooooooo`05ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00co
oooo00?oV9RHob4Q8Oo^k^h01_ooool2o`000003ooooool0003ooooo01Gooooo00?o0000oooooooo
ool05Oooool2o`000003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00onHV9So
8B4Qonk^kP04o`0000Gooooo00?o0000ooooooooool01oooool2o`0000Cooooo00Go410@oooooooo
oooooooooa0@400@ooooo`03o`000?oooooooooo00gooooo00Go410@oooooooooooooooooa0@400=
ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0D
ooooo`002oooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool0
0olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00
000?ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Gooooo0_l000000omgMgOo<S8booooo`0Eooooo`03o`000?oooooooooo01Sooooo
00Go0000ooooooooooooooooo`00000=ooooo`04oiRHV?lQ8B7o0000o`0000Kooooo00?oMgMgoc8b
<_ooool02?ooool2o`0000Cooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo00kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?o
MgMgoc8b<_ooool06Oooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0H
ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0
003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05_ooool00ol0003oooooooooo`0Hooooo`05o`000?oo
ooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`03oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?
ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`06_ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003ooooooooo
o`0Hooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo017o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool06?ooool3o`0001Sooooo00Go410@oooooooooooooooooa0@4002ooooo`;o00002oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVY
ZOmgMgOooooo00?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Dooooo`002ooo
ool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooo
oooooooooooo<S8b00Cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000
okZj^_ooooooV9RHoa0@4004ooooo`04o`000?ooooooooooooooo`Co00004oooool00ol0003ooooo
ooooo`0Fooooo`;o000000GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`;o00001oooool01Ol0003o
^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
5?ooool000Wooooo00?oEEEEofIVI_l000006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
1Ol00004ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool3o`000003ob4Q8Ol0003o000000?ooooo2?l0000Coooo
o`03o`000?oooooooooo01Kooooo0_l000001Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c004ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000Iooooo`03
oeEEEOmVIVKo000001Kooooo001mooooo`;o00002Oooool2o`0000;ooooo0_l0000Nooooo`03o`00
0?oooooooooo00Cooooo0_l0000Yooooo`;o0000R?ooool007gooooo0_l0000@ooooo`;o00006ooo
ool00ol0003oooooooooo`04ooooo`;o00003oooool2o`0001Kooooo1?l00028ooooo`00Soooool2
o`0001_ooooo00?o0000ooooooooool05Oooool2o`0001Kooooo1?l0001mooooo`;o00000_ooool2
o`0000Gooooo002?ooooo`;o00006oooool00ol0003oooooooooo`04ooooo`;o00009oooool2o`00
01?ooooo0_l0001Zooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1Oooool008oooooo0_l0000K
ooooo`03o`000?oooooooooo00Cooooo0_l0000@ooooo`;o0000:_ooool2o`0006_ooooo00CogMgM
o`000?l@413oc<c<1_ooool000Ooooooool0001<o`0000cooooo00Cok^k^ob4Q8Ol@413ok^k^1_oo
ool000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`04ob4Q8OmgMgOo
MgMgoc8b<PKooooo0007ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`03ooooo`;o00005?ooool2o`0000_ooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Wooooo0_l00002ooooo`;o00001Oooool0
0:cooooo00?o0000ooooooooool08?ooool2o`0000_ooooo0_l0000Dooooo`;o0000M?ooool00:co
oooo00?o0000ooooooooool03_ooool2o`00013ooooo0_l0000<ooooo`;o0000ROooool00:cooooo
00?o0000ooooooooool03_ooool2o`0000Kooooo0_l0000Fooooo`?o00004?ooool3o`0007Gooooo
001nooooo`;o0000;?ooool00ol0003oooooooooo`0Fooooo`;o00005oooool2o`00013ooooo0ol0
001eooooo`00O_ooool2o`0002cooooo00?o0000ooooooooool0@Oooool2o`0007Kooooo0023oooo
o`;o00009oooool3o`00047ooooo0_l0001fooooo`00Poooool2o`0002Oooooo00?o0000oooooooo
ool02Oooool2o`0001Gooooo0_l0002Gooooo`00[?ooool00ol0003oooooooooo`09ooooo`;o0000
5Oooool2o`0009Oooooo002/ooooo`03o`000?oooooooooo00Sooooo0_l0002_ooooo`00T_ooool2
o`0001Sooooo00?o0000ooooooooool02?ooool2o`000:oooooo002<ooooo`;o00001?ooool2o`00
01Sooooo00?o0000ooooooooool01?ooool2o`0003_ooooo0_l0001fooooo`00S?ooool2o`0001ko
oooo00?o0000ooooooooool01?ooool2o`0003_ooooo0_l0001fooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool00ol0003oooooooooo`0Pooooo`?o0000U_ooool009Oooooo0_l0000C
ooooo`?o00008?ooool3o`0009Kooooo002Gooooo`;o00004oooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00Poooool2o`0002Oooooo00?o0000ooooooooool0
^Oooool008?ooooo0_l0000=ooooo`;o00006?ooool00ol0003oooooooooo`03ooooo`;o0000?Ooo
ool2o`0007Gooooo002Booooo`;o00006?ooool00ol0003oooooooooo`03ooooo`;o00004?ooool2
o`0001Gooooo0_l000000ooooooo0000o`00000Aooooo`;o0000MOooool00:cooooo00?o0000oooo
ooooool01oooool2o`0000cooooo0_l0000Eooooo`Go0000R?ooool008Cooooo0_l00003ooooo`;o
00008Oooool00ol0003oooooooooo`07ooooo`;o00003?ooool2o`0001Oooooo0_l0000[ooooo`;o
0000G?ooool008Cooooo0_l00003ooooo`;o000000?oooooo`000?l000001oooool2o`0001Cooooo
1Ol0000;ooooo`;o00001oooool2o`0000Wooooo0_l0000=ooooo`;o0000:_ooool2o`0005cooooo
002<ooooo`;o00001oooool2o`0000Cooooo0_l0000>ooooo`;o000000?oooooo`000?l000002ooo
ool2o`0001;ooooo0_l0000=ooooo`;o00004Oooool2o`0007Gooooo002Kooooo`;o00003oooool0
0ol0003oooooooooo`0Cooooo`;o0000:oooool4o`0007Gooooo002/ooooo`03o`000?oooooooooo
00;ooooo0_l0000?ooooo`;o0000:oooool3o`0007Kooooo001nooooo`;o00004?ooool2o`0001[o
oooo00?o0000ooooooooool00_ooool2o`0003gooooo0_l0001fooooo`00O_ooool2o`00013ooooo
0_l0000Jooooo`03o`000?oooooooooo02kooooo0_l00029ooooo`00[?ooool00ol0003ooooooooo
o`06ooooo`;o00009_ooool2o`0008Wooooo002/ooooo`03o`000?oooooooooo00Kooooo0_l0000f
ooooo`;o0000NOooool00:cooooo0ol0000Dooooo`;o0000:?ooool3o`0007Sooooo002Fooooo`;o
00005?ooool00ol0003oooooooooo`0Dooooo`;o0000:Oooool2o`0007Sooooo002Fooooo`;o0000
5?ooool00ol0003oooooooooo`0;ooooo`;o00007oooool2o`0001?ooooo0_l0001fooooo`00SOoo
ool2o`0001gooooo00?o0000ooooooooool02_ooool3o`0001oooooo0_l0000Cooooo`;o0000M_oo
ool008gooooo0_l0000Mooooo`03o`000?oooooooooo00[ooooo0_l0000Nooooo`;o0000;oooool2
o`0005cooooo002Aooooo`;o00006Oooool00ol0003oooooooooo`0Zooooo`;o0000;oooool2o`00
05cooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool2o`0000;o8B4Q1?ooool5o`00
00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;Wooooo0029oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4
A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0?oooool2o`0007Sooooo0029
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oo
oooooooo00?ooooo0ol0000Booooo`;o00002Oooool2o`00023ooooo0_l0001hooooo`00ROooool0
1Ol0003ooooooooooooooooo000000[ooooo0_l000001?ooooooV9RHob4Q8Oo^k^h7ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool04_ooool2o`0000Oooooo1?l0000Pooooo`;o0000
N?ooool008Wooooo00Co0000oooooooooooooooo0ol00008ooooo`;o00000_ooool00omgMgOoIVIV
ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Booooo`;o
00001oooool2o`0000gooooo0_l0000Dooooo`;o0000Moooool007oooooo0_l00008ooooo`05oa0@
4?ooooooooooooooool@41000_l0000=ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Booooo`;o00005_ooool2o`00013ooooo0_l00002ooooo`;o
00005oooool2o`0005kooooo001oooooo`;o00002?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0:_ooool2o`00013ooooo0_l0000Kooooo`;o0000G_ooool008Wooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000
ooooooooool07?ooool2o`0000cooooo0_l0000Cooooo`;o0000N?ooool008kooooo0_l0000Loooo
o`03o`000?oooooooooo01cooooo0_l0000Qooooo`;o0000N?ooool008kooooo0_l0000Looooo`03
o`000?oooooooooo01_ooooo0_l0002Looooo`00[?ooool00ol0003oooooooooo`0Kooooo`;o0000
W?ooool00:cooooo0ol0002iooooo`00Q_ooool2o`0002Cooooo0_l0002jooooo`00Q_ooool2o`00
02Cooooo0_l0002jooooo`00[?ooool00ol0003oooooooooo`06ooooo`;o0000/Oooool00:;ooooo
0_l00008ooooo`03o`000?oooooooooo00Kooooo0_l0001?ooooo`;o0000H?ooool009Oooooo0_l0
0002ooooo`;o00001Oooool2o`0000Sooooo00?o0000ooooooooool0>oooool2o`0001[ooooo0_l0
001Pooooo`00Uoooool2o`0000;ooooo0_l0000?ooooo`03o`000?oooooooooo03_ooooo1?l0001j
ooooo`00[?ooool00ol0003oooooooooo`0mooooo`;o0000N_ooool008_ooooo0_l00007ooooo`;o
00004oooool2o`000004ooooool0003o0000o`0000Gooooo0_l0000eooooo`;o0000Noooool008_o
oooo0_l00007ooooo`;o00004oooool2o`000003ooooool0003ooooo00Kooooo0ol0000dooooo`;o
0000Noooool00:cooooo00?o0000ooooooooool01Oooool3o`000;7ooooo002Iooooo`;o00004Ooo
ool00ol0003oooooooooo`05ooooo`;o00007Oooool2o`0009?ooooo002Iooooo`;o00004Oooool0
0ol0003oooooooooo`0;ooooo`;o00005oooool2o`0009?ooooo002/ooooo`03o`000?oooooooooo
00_ooooo0_l0000Fooooo`;o0000U?ooool00:cooooo00?o0000ooooooooool05?ooool2o`0000go
oooo0_l0002Dooooo`00POooool2o`0002Wooooo00?o0000ooooooooool02_ooool2o`0000Sooooo
0ol0002Rooooo`00POooool2o`0002Wooooo0ol0000:ooooo`;o00002Oooool2o`000:;ooooo002[
ooooo`;o0000>oooool2o`0007kooooo002[ooooo`;o0000>Oooool4o`0007kooooo002/ooooo`03
o`000?oooooooooo00Wooooo0_l0000:ooooo`;o00008?ooool2o`00083ooooo0027ooooo`;o0000
8oooool00ol0003oooooooooo`09ooooo`?o00002Oooool2o`000:;ooooo0027ooooo`;o00008ooo
ool00ol0003oooooooooo`0:ooooo`;o00001_ooool3o`000:Cooooo002/ooooo`03o`000?oooooo
oooo01;ooooo1?l0002Sooooo`00T_ooool2o`0001Cooooo0_l00002ooooo`03o`000?oooooooooo
01Cooooo0_l0000kooooo`;o0000I_ooool008Sooooo0_l00008ooooo`;o00005?ooool2o`0000;o
oooo0ol0000Pooooo`;o0000;oooool2o`0006Kooooo0022ooooo`;o00001?ooool2o`0000Cooooo
0_l00009ooooo`;o00004Oooool00ol0003oooooooooo`07ooooo`;o00005oooool2o`0009Oooooo
0022ooooo`;o00002_ooool2o`0000Wooooo0_l00008ooooo`;o00001oooool00ol0003ooooooooo
o`07ooooo`;o0000;?ooool2o`0008;ooooo002Sooooo`;o00001oooool01?l0003oooooo`000?l0
000?ooooo`;o00008oooool3o`00087ooooo002Iooooo`;o00004Oooool01?l0003oooooo`000?l0
000?ooooo`;o00009?ooool2o`00087ooooo0029ooooo`;o00003_ooool2o`00013ooooo0_l0002k
ooooo`00ROooool2o`0000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Cooooo0_l0002kooooo`00P_ooool2o`0000gooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo00Cooooo0_l00009ooooo`;o0000Z?ooool008;ooooo0_l0000=ooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo0_l0
0009ooooo`;o00008?ooool2o`0008Kooooo002Aooooo`05o`000?ooooooooooooooool000003ooo
ool00omgMgOo<S8booooo`04ooooo`?o0000;oooool4o`0008Kooooo002Aooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
;oooool2o`0008Sooooo002Aooooo`05oa0@4?ooooooooooooooool@41000_l0000:ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool07Oooool2o`0001?ooooo0_l00025ooooo`00TOoo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00;o00002_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01gooooo0_l0000Cooooo`;o0000QOooool0097ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`Ko00001?ooool00ol0003oooooooooo`0=ooooo`;o00008oooool2o`0001Oooooo
0_l0001/ooooo`00Y_ooool2o`0000Cooooo00?o0000ooooooooool02oooool4o`0000[ooooo0_l0
000`ooooo`;o0000K?ooool00:3ooooo1?l00008ooooo`03o`000?oooooooooo00_ooooo0ol0000;
ooooo`;o00004oooool4o`0008Oooooo002Pooooo`Co00002?ooool00ol0003oooooooooo`0Hoooo
o`;o00004_ooool6o`0008Oooooo002/ooooo`?o00006?ooool2o`0001;ooooo1Ol00028ooooo`00
[?ooool00ol0003oooooooooo`0Fooooo`;o00005Oooool4o`0008Sooooo002<ooooo`;o00007_oo
ool00ol0003oooooooooo`0Fooooo`;o0000XOooool008cooooo0_l0000Nooooo`03o`000?oooooo
oooo0;Wooooo002Iooooo`;o00004Oooool00ol0003oooooooooo`0Gooooo`?o0000Woooool008co
oooo0_l0000;ooooo`;o00004?ooool3o`0001Kooooo1Ol0002Oooooo`00S?ooool2o`0001gooooo
0ol0000Fooooo`;o0000X_ooool008cooooo0_l0000Nooooo`03o`000?oooooooooo02_ooooo0_l0
002<ooooo`00S?ooool2o`0000kooooo0_l0000>ooooo`?o00001Oooool2o`0002Cooooo0_l0002<
ooooo`00S?ooool2o`0000kooooo0ol00007ooooo`;o00001?ooool00ol0003oooooooooo`05oooo
o`;o00009?ooool2o`0008cooooo0025ooooo`;o00005_ooool2o`0000Oooooo0_l00004ooooo`03
o`000?oooooooooo02_ooooo0_l0002<ooooo`00QOooool2o`0001Sooooo0_l0000;ooooo`03o`00
0?oooooooooo02[ooooo0_l0002=ooooo`00Woooool2o`0000_ooooo00?o0000ooooooooool0:_oo
ool2o`0008gooooo002Qooooo`;o00002Oooool00ol0003oooooooooo`2iooooo`00XOooool2o`00
00Wooooo00?o0000ooooooooool00_ooool2o`000;Gooooo002/ooooo`03o`000?oooooooooo00;o
oooo0_l0002eooooo`00U_ooool3o`0001?ooooo0ol00002ooooo`;o0000]Oooool009Kooooo0ol0
000Cooooo`03o`000?oooooooooo00;ooooo0_l0002eooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00VOooool2o`00017ooooo00?o0000ooooooooool08oooool4o`0009;ooooo002Iooooo`;o
00004Oooool00ol0003oooooooooo`0Sooooo`Co0000T_ooool00:cooooo00?o0000ooooooooool0
8oooool2o`0009Cooooo002/ooooo`03o`000?oooooooooo02?ooooo0_l0002Dooooo`00Z_ooool3
o`0002?ooooo0_l0002Fooooo`00Z_ooool3o`0002;ooooo0ol0002Fooooo`00W_ooool2o`0000co
oooo0ol0000;ooooo`;o00004oooool2o`0009Oooooo002Mooooo`Co00001_ooool2o`0000?ooooo
00?o0000ooooooooool02oooool2o`000:cooooo002Mooooo`Co00001?ooool4o`0000?ooooo00?o
0000ooooooooool02?ooool2o`000003ooooool0003o0000013ooooo0_l0002Jooooo`00YOooool2
o`0000Gooooo00?o0000ooooooooool02?ooool5o`00013ooooo0ol0002Iooooo`00[?ooool00ol0
003oooooooooo`0:ooooo`;o00004_ooool2o`0009Wooooo0029ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool06_ooool2o`0009gooooo0029ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo00Sooooo0_l0000@ooooo`;o0000WOooool008Wooooo00Go410@oooo
oooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`08ooooo`;o00004?ooool2o`0009gooooo0029ooooo`05o`000?oooooooooo
ooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000J
ooooo`;o0000WOooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<co
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00;ooooo0_l0
002eooooo`00ROooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo0_l0002eooooo`00ROooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool06Oooool2o`0009kooooo0029ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo01Wooooo
0_l0002Nooooo`00S?ooool2o`0001kooooo00?o0000ooooooooool05?ooool2o`000:?ooooo002<
ooooo`;o00007_ooool00ol0003oooooooooo`0Dooooo`?o0000X_ooool008gooooo0_l0000:oooo
o`;o00004Oooool00ol0003oooooooooo`0Eooooo`;o0000X_ooool008gooooo0_l0000:ooooo`;o
00004Oooool3o`0001Gooooo0_l0002Rooooo`00[?ooool5o`0000oooooo0_l000000ooooooo0000
o`00002Sooooo`00SOooool2o`0001gooooo1Ol0000?ooooo`;o000000?oooooo`000?l00000Xooo
ool008gooooo0_l0000Mooooo`03o`000?oooooooooo017ooooo1Ol0002Sooooo`00[?ooool00ol0
003oooooooooo`0?ooooo`;o00000_ooool3o`000:?ooooo002/ooooo`03o`000?oooooooooo00oo
oooo1?l0002Vooooo`00[?ooool00ol0003oooooooooo`0Aooooo`;o0000Y_ooool009oooooo0_l0
000;ooooo`03o`000?oooooooooo0;Wooooo002Oooooo`?o00002_ooool3o`0000cooooo0_l00000
0ooooooo0000o`00002Xooooo`00X?ooool4o`0000Sooooo00?o0000ooooooooool03?ooool2o`00
0003ooooool0003o00000:Sooooo002Qooooo`?o00002?ooool00ol0003oooooooooo`2iooooo`00
[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0;ooooo`;o0000[?ooool00:co
oooo00?o0000ooooooooool02oooool2o`000:cooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`?o00002Oooool2o`000:kooooo002/ooooo`03o`000?oooooooooo00Wooooo0_l0002^
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`06ooooo`;o
0000/Oooool00:cooooo00?o0000ooooooooool01_ooool2o`000;7ooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:co
oooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00Zoooool4o`000;Wooooo002[ooooo`Co0000^Oooool009oooooo0_l0000:ooooo`;o
0000^oooool009cooooo0_l000001?oooooo0000o`000?ooool4o`000003oa0@4?oooooooooo00?o
oooo00?o0000ooooooooool0^Oooool009cooooo1?l00004ooooo`;o000000?oooooo`000?l00000
0oooool00ol0003oooooooooo`2iooooo`00W_ooool2o`0000Cooooo00?o0000ooooooooool00_l0
0003ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo00?o0000oooo
ooooool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0
`Oooool00:;ooooo00?oEEEEofIVI_l00000`oooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00:[ooooo00Co410@o`000?l0003o0000^_ooool00:_ooooo00?o
0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00Ko0000ogMg
Mol0003o0000oeEEEOo^k^jgooooo`00Zoooool01_l0003oEEEEonk^k_ooooooMgMgoeEEEKOooooo
002[ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0]Oooool00:_ooooo00?o0000
onk^k_ooool00_ooool00ol0003oooooooooo`2eooooo`00Zoooool01_l0003oEEEEonk^k_oooooo
MgMgofIVI[Oooooo002Zooooo`03oa0@4?l0003oMgMg00;o000000?oIVIVonk^k_ooool0]_ooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.56319 .21262 Mdot
.64749 .40599 Mdot
.4977 .59065 Mdot
.49435 .26239 Mdot
.55928 .6696 Mdot
.38931 .47108 Mdot
.45151 .63806 Mdot
.72651 .55857 Mdot
.70099 .40036 Mdot
.47925 .77708 Mdot
.41176 .46398 Mdot
.70727 .64977 Mdot
.64528 .6561 Mdot
.4282 .69436 Mdot
.68329 .70305 Mdot
.55706 .48071 Mdot
.6123 .51503 Mdot
.64195 .6687 Mdot
.56332 .37174 Mdot
.37931 .64068 Mdot
.62515 .70422 Mdot
.65773 .52527 Mdot
.64896 .59059 Mdot
.62973 .7018 Mdot
.63831 .80553 Mdot
.40101 .43875 Mdot
.44741 .24165 Mdot
.55952 .36599 Mdot
.37495 .44402 Mdot
.65046 .43491 Mdot
.59023 .77419 Mdot
.70017 .38541 Mdot
.72199 .52961 Mdot
.58716 .66883 Mdot
.54074 .78877 Mdot
.40087 .78525 Mdot
.56434 .13297 Mdot
.52928 .28809 Mdot
.40315 .18791 Mdot
.70733 .6617 Mdot
.65367 .78679 Mdot
.56861 .72796 Mdot
.43736 .8357 Mdot
.57423 .22385 Mdot
.51526 .13839 Mdot
.47959 .8254 Mdot
.42709 .67935 Mdot
.66901 .29481 Mdot
.52152 .20733 Mdot
.37765 .40206 Mdot
.66752 .29475 Mdot
.4415 .0705 Mdot
.69711 .20879 Mdot
.48033 .86992 Mdot
.48459 .87319 Mdot
.71507 .46694 Mdot
.72335 .57668 Mdot
.61371 .49824 Mdot
.62711 .21955 Mdot
.49558 .11391 Mdot
.4532 .81111 Mdot
.43999 .98792 Mdot
.41611 .13931 Mdot
.50018 .71067 Mdot
.7142 .55242 Mdot
.70963 .4207 Mdot
.48548 .77153 Mdot
.55328 .45995 Mdot
.5273 .27935 Mdot
.61016 .74602 Mdot
.61821 .51959 Mdot
.4655 .31774 Mdot
.46328 .77091 Mdot
.52474 .69276 Mdot
.41603 .13966 Mdot
.44225 .50502 Mdot
.69754 .20959 Mdot
.40609 .60328 Mdot
.41542 .13263 Mdot
.51524 .20843 Mdot
.51108 .90039 Mdot
.6485 .43042 Mdot
.47208 .25116 Mdot
.56518 .73823 Mdot
.72556 .50403 Mdot
.55962 .48018 Mdot
.55395 .68629 Mdot
.51308 .7734 Mdot
.61051 .44448 Mdot
.55421 .47503 Mdot
.62995 .81792 Mdot
.43933 .68694 Mdot
.50679 .79102 Mdot
.455 .72549 Mdot
.43303 .71423 Mdot
.67454 .32019 Mdot
.70738 .22425 Mdot
.61203 .43896 Mdot
.58718 .25601 Mdot
.59744 .37618 Mdot
.70221 .65825 Mdot
.59552 .26434 Mdot
.56035 .83503 Mdot
.57936 .69333 Mdot
.61418 .56453 Mdot
.57585 .42354 Mdot
.43812 .68262 Mdot
.60304 .75843 Mdot
.4548 .76771 Mdot
.47999 .24668 Mdot
.69839 .38208 Mdot
.4046 .81323 Mdot
.79207 .43224 Mdot
.44288 .65447 Mdot
.42532 .73893 Mdot
.71647 .4301 Mdot
.70965 .40633 Mdot
.56612 .14101 Mdot
.64333 .65927 Mdot
.50386 .99435 Mdot
.62898 .67786 Mdot
.37504 .4294 Mdot
.60518 .75555 Mdot
.51695 .31318 Mdot
.38678 .70444 Mdot
.4102 .0613 Mdot
.63007 .3663 Mdot
.44976 .31851 Mdot
.65386 .57357 Mdot
.61043 .30654 Mdot
.69205 .69639 Mdot
.38896 .45616 Mdot
.40921 .73804 Mdot
.39045 .24789 Mdot
.52835 .0835 Mdot
.37539 .54341 Mdot
.46677 .77257 Mdot
.71723 .57511 Mdot
.6836 .70668 Mdot
.36457 .64083 Mdot
.42475 .38824 Mdot
.54353 .31429 Mdot
.6127 .51388 Mdot
.39032 .73911 Mdot
.72327 .47509 Mdot
.80276 .52031 Mdot
.57817 .48701 Mdot
.4988 .80044 Mdot
.55272 .9443 Mdot
.5901 .3499 Mdot
.47795 .20494 Mdot
.63014 .70359 Mdot
.45229 .34408 Mdot
.43063 .16972 Mdot
.508 .0644 Mdot
.42333 .11421 Mdot
.71574 .43886 Mdot
.56879 .14067 Mdot
.51269 .06867 Mdot
.43792 .2023 Mdot
.41069 .1471 Mdot
.67801 .75078 Mdot
.43298 .89042 Mdot
.42843 .80811 Mdot
.58406 .25484 Mdot
.72176 .4688 Mdot
.54362 .86208 Mdot
.51982 .26446 Mdot
.49505 .04719 Mdot
.37637 .51912 Mdot
.4222 .55229 Mdot
.50018 .23039 Mdot
.54528 .7039 Mdot
.58039 .51038 Mdot
.71819 .54894 Mdot
.42542 .18615 Mdot
.44233 .64491 Mdot
.38098 .34145 Mdot
.45904 .04556 Mdot
.69334 .70294 Mdot
.55062 .60269 Mdot
.64679 .80004 Mdot
.50842 .33404 Mdot
.69794 .3969 Mdot
.41099 .06084 Mdot
.69682 .363 Mdot
.68135 .74121 Mdot
.42415 .80238 Mdot
.54181 .95158 Mdot
.39145 .74771 Mdot
.5241 .63493 Mdot
.72618 .53192 Mdot
.62706 .83927 Mdot
.69879 .67364 Mdot
.51801 .76871 Mdot
.55276 .0303 Mdot
.60614 .62521 Mdot
.48017 .69976 Mdot
.47407 .7018 Mdot
.47776 .31211 Mdot
.55777 .6675 Mdot
.58119 .06012 Mdot
.60054 .28693 Mdot
.53866 .50364 Mdot
.3962 .3445 Mdot
.46725 .24582 Mdot
.52777 .39429 Mdot
.41206 .44184 Mdot
.65893 .58658 Mdot
.41064 .65078 Mdot
.54086 .86579 Mdot
.55312 .57551 Mdot
.59035 .26769 Mdot
.42016 .70975 Mdot
.67301 .75981 Mdot
.50718 .32593 Mdot
.48773 .11258 Mdot
.71535 .63295 Mdot
.43263 .76559 Mdot
.64076 .2495 Mdot
.55914 .83961 Mdot
.47894 .92921 Mdot
.55466 .53927 Mdot
.57657 .59216 Mdot
.63933 .36648 Mdot
.42597 .60513 Mdot
.68276 .7054 Mdot
.54733 .40611 Mdot
.51423 .51827 Mdot
.59562 .07958 Mdot
.57021 .30789 Mdot
.43726 .26598 Mdot
.51825 .97731 Mdot
.51454 .25662 Mdot
.60678 .28671 Mdot
.63855 .6565 Mdot
.60326 .28944 Mdot
.43544 .97997 Mdot
.39826 .67005 Mdot
.50941 .9109 Mdot
.61817 .51815 Mdot
.7013 .38004 Mdot
.4623 .73264 Mdot
.50887 .06976 Mdot
.6025 .42731 Mdot
.61824 .51051 Mdot
.41513 .14076 Mdot
.63058 .83163 Mdot
.44505 .662 Mdot
.51988 .64608 Mdot
.53447 .10028 Mdot
.40711 .36081 Mdot
.4936 .22107 Mdot
.47226 .88 Mdot
.4429 .4639 Mdot
.72154 .57092 Mdot
.65096 .25926 Mdot
.54788 .25593 Mdot
.43613 .26965 Mdot
.46323 .92799 Mdot
.42927 .44583 Mdot
.58801 .34887 Mdot
.54487 .18662 Mdot
.41727 .6059 Mdot
.39106 .54089 Mdot
.38416 .66543 Mdot
.43751 .21042 Mdot
.3968 .769 Mdot
.47337 .87748 Mdot
.48722 .77381 Mdot
.53071 .22984 Mdot
.49913 .05377 Mdot
.54895 .61532 Mdot
.58481 .51327 Mdot
.67586 .31492 Mdot
.41051 .50591 Mdot
.41455 .22444 Mdot
.38871 .26582 Mdot
.44887 .31398 Mdot
.53531 .65561 Mdot
.57075 .14448 Mdot
.70893 .63453 Mdot
.57749 .43086 Mdot
.43572 .45422 Mdot
.56892 .61172 Mdot
.43924 .91377 Mdot
.48686 .81683 Mdot
.52836 .87583 Mdot
.41323 .05528 Mdot
.62246 .21579 Mdot
.69653 .66545 Mdot
.62965 .23234 Mdot
.49391 .64942 Mdot
.60107 .17697 Mdot
.47383 .94197 Mdot
.68788 .69007 Mdot
.80244 .56349 Mdot
.51011 .1937 Mdot
.4307 .82797 Mdot
.61392 .31198 Mdot
.70119 .38358 Mdot
.65272 .78365 Mdot
.42012 .63792 Mdot
.67501 .31625 Mdot
.41285 .31227 Mdot
.51044 .62661 Mdot
.65679 .58875 Mdot
.61252 .53441 Mdot
.64434 .65018 Mdot
.56618 .92704 Mdot
.43279 .59347 Mdot
.50965 .13691 Mdot
.57677 .7029 Mdot
.71266 .57407 Mdot
.42898 .44067 Mdot
.68827 .71431 Mdot
.54794 .93675 Mdot
.35925 .53768 Mdot
.53854 .37611 Mdot
.38844 .46089 Mdot
.56536 .74025 Mdot
.44239 .07591 Mdot
.57857 .59011 Mdot
.50069 .66739 Mdot
.47267 .67198 Mdot
.61506 .54524 Mdot
.72103 .60407 Mdot
.53292 .10062 Mdot
.46087 .73489 Mdot
.65991 .55636 Mdot
.45486 .304 Mdot
.48073 .31362 Mdot
.64186 .37604 Mdot
.38957 .54154 Mdot
.42757 .80577 Mdot
.43925 .19947 Mdot
.56201 .65149 Mdot
.67167 .16878 Mdot
.41775 .28694 Mdot
.643 .41228 Mdot
.49406 .72167 Mdot
.71914 .50545 Mdot
.4381 .26767 Mdot
.37693 .58254 Mdot
.65309 .48377 Mdot
.42024 .54806 Mdot
.44816 .79566 Mdot
.36641 .6681 Mdot
.71135 .63822 Mdot
.5942 .16452 Mdot
.39446 .75087 Mdot
.48765 .16318 Mdot
.60444 .6236 Mdot
.37785 .57994 Mdot
.57935 .32741 Mdot
.71078 .63874 Mdot
.35848 .53396 Mdot
.50174 .92077 Mdot
.69223 .69396 Mdot
.68441 .7237 Mdot
.65756 .78598 Mdot
.50522 .36333 Mdot
.55636 .2769 Mdot
.68065 .71265 Mdot
.72287 .57089 Mdot
.51084 .38407 Mdot
.55601 .83596 Mdot
.42505 .25686 Mdot
.39507 .35142 Mdot
.58024 .24303 Mdot
.68226 .34065 Mdot
.60579 .28545 Mdot
.58501 .1587 Mdot
.49745 .06135 Mdot
.65003 .57925 Mdot
.57493 .13769 Mdot
.6537 .56585 Mdot
.65524 .77395 Mdot
.79862 .46287 Mdot
.58823 .1718 Mdot
.43613 .15299 Mdot
.44848 .36153 Mdot
.58724 .88754 Mdot
.60823 .42368 Mdot
.47865 .67078 Mdot
.69295 .70775 Mdot
.60706 .75264 Mdot
.50629 .6505 Mdot
.51229 .7237 Mdot
.40204 .56211 Mdot
.45118 .23102 Mdot
.67519 .30679 Mdot
.56136 .84104 Mdot
.69081 .71021 Mdot
.60547 .60064 Mdot
.66047 .15759 Mdot
.60387 .61772 Mdot
.58061 .49612 Mdot
.58232 .52699 Mdot
.49737 .37482 Mdot
.72062 .59817 Mdot
.70795 .64585 Mdot
.44308 .25202 Mdot
.42039 .53437 Mdot
.42772 .29531 Mdot
.55974 .53186 Mdot
.59161 .89158 Mdot
.52074 .7668 Mdot
.44189 .9086 Mdot
.43715 .31625 Mdot
.48571 .2089 Mdot
.43371 .39247 Mdot
.53706 .73044 Mdot
.59334 .64654 Mdot
.45096 .22766 Mdot
.53844 .52702 Mdot
.52822 .96993 Mdot
.71827 .56929 Mdot
.48873 .39189 Mdot
.53016 .80803 Mdot
.61394 .56566 Mdot
.47075 .11499 Mdot
.4396 .20893 Mdot
.50634 .23965 Mdot
.58914 .88749 Mdot
.6176 .31514 Mdot
.77617 .37183 Mdot
.58424 .23959 Mdot
.53734 .55866 Mdot
.70557 .43471 Mdot
.67531 .72515 Mdot
.41547 .39997 Mdot
.6523 .49118 Mdot
.67912 .1802 Mdot
.4199 .48453 Mdot
.51831 .5977 Mdot
.57883 .54411 Mdot
.47271 .93188 Mdot
.49006 .17134 Mdot
.53187 .01154 Mdot
.52003 .36896 Mdot
.50842 .83819 Mdot
.57727 .71031 Mdot
.47905 .74162 Mdot
.43296 .59027 Mdot
.5381 .65671 Mdot
.72577 .562 Mdot
.42799 .53851 Mdot
.40046 .19212 Mdot
.63806 .36964 Mdot
.51752 .14435 Mdot
.39245 .74483 Mdot
.54673 .84807 Mdot
.6108 .56533 Mdot
.39859 .09726 Mdot
.50648 .73742 Mdot
.72038 .60926 Mdot
.63477 .82644 Mdot
.41584 .58604 Mdot
.59868 .17224 Mdot
.43913 .20832 Mdot
.60979 .49452 Mdot
.37812 .60775 Mdot
.58667 .25355 Mdot
.56962 .39886 Mdot
.44716 .79445 Mdot
.59099 .65944 Mdot
.40683 .71987 Mdot
.44364 .54613 Mdot
.44565 .84869 Mdot
.51736 .21026 Mdot
.49882 .34057 Mdot
.54538 .41014 Mdot
.48914 .86536 Mdot
.4196 .78765 Mdot
.46046 .69575 Mdot
.40275 .42557 Mdot
.71041 .425 Mdot
.56568 .6509 Mdot
.53003 .16562 Mdot
.52926 .2779 Mdot
.56201 .38288 Mdot
.52321 .45347 Mdot
.7893 .41149 Mdot
.52494 .47939 Mdot
.64489 .39099 Mdot
.64744 .26747 Mdot
.42995 .88497 Mdot
.53594 .29847 Mdot
.37515 .46016 Mdot
.69893 .68409 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`07ooooo`;o0000/?ooool00:;ooooo00?oEEEEofIV
I_l000001oooool00ol0003oooooooooo`07ooooo`;o0000/?ooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0>ooooo`;o0000ZOooool00:co
oooo00?o0000ooooooooool03_ooool2o`000:Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Noooo
o`;o00003?ooool00ol0003oooooooooo`2iooooo`00W_ooool2o`0000[ooooo0ol0002kooooo`00
Z_ooool5o`000;Wooooo002?ooooo`;o00006_ooool2o`000;_ooooo002?ooooo`;o00006_ooool2
o`000;_ooooo002>ooooo`;o00006oooool2o`0001Wooooo0_l0002Pooooo`00S_ooool2o`0001_o
oooo0_l000000ooooooo0000o`00000Fooooo`;o0000X?ooool00:cooooo00Co0000ooooool0003o
0000^?ooool009Sooooo0_l0000Booooo`03o`000?oooooo000000?o0000]_ooool009Sooooo0_l0
000Booooo`03o`000?oooooo000000?o0000]_ooool009Wooooo0_l0000Aooooo`?o0000^Oooool0
09Wooooo0_l0000Aooooo`03o`000?oooooooooo01cooooo0_l0002Kooooo`00[?ooool00ol0003o
ooooooooo`0Looooo`;o0000Voooool00:cooooo00?o0000ooooooooool01_ooool2o`000;7ooooo
002/ooooo`03o`000?oooooooooo00Kooooo0_l0002aooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00R_ooool2o`00023ooooo00?o0000oooooooo
ool0^Oooool008[ooooo0_l0000Pooooo`?o00001oooool3o`000:oooooo002/ooooo`03o`000?oo
oooooooo00Oooooo0ol0002_ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00Z?ooool2o`0000;ooooo00?o0000ooooooooool0^Oooool009;ooooo
0_l0000>ooooo`;o00001?ooool5o`000;_ooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1?ooool2o`000003ob4Q8Ooooooooooo00Cooooo00?o0000onk^k_ooool01?ooool3o`000003oc8b
<_oMgMgooooo00;ooooo0ol0002kooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`2iooooo`00POooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVY
ZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000;Wooooo0029ooooo`05o`000?oo
ooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0^Oooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEE
EOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;Wo
oooo0029ooooo`05oa0@4?ooooooooooooooool@41000_ooool2o`0000[ooooo00?oZJVYogMgMooo
ool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo0_l0002Uooooo`00
ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo0_l00007ooooo`05oa0@4?oooooooooooooo
oolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;o00004?ooool2o`00
0003ooooool0003o00000:;ooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool2o`00
00Oooooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`04o`0000kooooo1Ol0002Roooo
o`00T?ooool2o`0001[ooooo00?o0000ooooooooool00_ooool2o`0000kooooo0ol0002Tooooo`00
S_ooool2o`0001cooooo00?o0000ooooooooool00_ooool2o`00013ooooo0_l0002Sooooo`00S_oo
ool2o`0001cooooo00?o0000ooooooooool00_ooool2o`00013ooooo0_l0002Sooooo`00U_ooool2
o`0001Cooooo0ol0002iooooo`00U_ooool2o`0001Cooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool06Oooool2o`0001Oooooo0_l00025ooooo`00[?ooool00ol0003ooooo
ooooo`0Iooooo`;o00005oooool2o`0008Gooooo002Wooooo`;o00000oooool00ol0003ooooooooo
o`0Looooo`;o0000Voooool00:Oooooo0_l00003ooooo`03o`000?oooooooooo00Kooooo0_l0000D
ooooo`;o0000Voooool009Gooooo0_l0000Aooooo`;o00000_ooool00ol0003oooooooooo`06oooo
o`;o0000;Oooool2o`0008;ooooo002Eooooo`;o00004Oooool2o`0000;ooooo00?o0000oooooooo
ool06_ooool2o`000003ooooool0003o000001Kooooo0_l00022ooooo`00[?ooool3o`0001[ooooo
0_l000001?oooooo0000o`000?l0002Iooooo`00[?ooool00ol0003oooooooooo`0Nooooo`;o0000
6?ooool2o`0007oooooo002/ooooo`03o`000?oooooooooo03Sooooo0_l0001oooooo`00Toooool2
o`0001Oooooo00?o0000ooooooooool0^Oooool008cooooo0_l00005ooooo`;o00005oooool00ol0
003oooooooooo`0;ooooo`;o0000[?ooool008_ooooo0ol0000Nooooo`03o`000?oooooooooo00_o
oooo0_l0002/ooooo`00Roooool2o`0001oooooo00?o0000ooooooooool00_l0002gooooo`00[?oo
ool00ol0003oooooooooo`02o`000;Oooooo002Hooooo`;o00004_ooool3o`000;Wooooo002Goooo
o`?o00004_ooool00ol0003oooooooooo`2iooooo`00Uoooool2o`0000_ooooo0_l00006ooooo`03
o`000?oooooooooo00Cooooo0_l0002cooooo`00Uoooool3o`0000[ooooo0_l000000ooooooo0000
o`000003ooooo`03o`000?oooooooooo00;ooooo1?l0000hooooo`;o0000NOooool009Oooooo0ol0
000=ooooo`;o00000oooool00ol0003oooooooooo`02ooooo`;o00003Oooool2o`0002_ooooo0_l0
001iooooo`00[?ooool00ol0003oooooooooo`0Aooooo`;o00004_ooool2o`0009;ooooo002/oooo
o`03o`000?oooooooooo02Gooooo1?l0002@ooooo`00ZOooool2o`000003ooooool0003ooooo02So
oooo0_l0002@ooooo`00Soooool2o`0001Sooooo0_l000001?oooooo0000o`000?l0000Eooooo`;o
0000:_ooool2o`0007Kooooo002?ooooo`;o00002_ooool2o`0000oooooo00?o0000ooooooooool0
5Oooool2o`0002[ooooo0_l0001fooooo`00Voooool2o`0000oooooo0_l00008ooooo`;o0000/?oo
ool009_ooooo0_l0000?ooooo`;o00002?ooool2o`0001kooooo0_l0002@ooooo`00[?ooool00ol0
003oooooooooo`0Wooooo`;o0000T?ooool00:cooooo00Co0000ooooool0003o00005oooool2o`00
09oooooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool2o`000003ob4Q8Ooooooooooo
00?ooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`04o`000?oooooo0000o`0001Kooooo0ol0
002Oooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo0_l000000olQ8B7ooooooooo
o`02ooooo`;o00000_ooool2o`0000Gooooo00?o0000ooooooooool05oooool2o`000:3ooooo0027
ooooo`So00000_ooool01Ol@413ooooooooooooooooo410@00_ooooo0_l00002ooooo`;o00001Ooo
ool00ol0003oooooooooo`0[ooooo`;o0000S?ooool008Oooooo0_l00008ooooo`05o`000?oooooo
ooooooooool000000oooool2o`0000Oooooo0_l000000oooooooMgMgoc8b<P05ooooo`?o0000:ooo
ool2o`0008cooooo002Aooooo`05o`000?ooooooooooooooool000000oooool2o`0000Oooooo0ol0
00000olb<S;oc<c<ooooo`04ooooo`03o`000?oooooooooo00cooooo0_l0000:ooooo`?o0000W_oo
ool0097ooooo00Go410@ooooool0003o0000oa0@400<ooooo`03o`000?oooooooooo00Oooooo00Co
0000oooooooooooooooo0_l00009ooooo`;o00002_ooool3o`0009kooooo002Aooooo`05ogMgMonH
V9So0000o`000?mgMgL03?ooool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooooooo`;o
0000:oooool2o`0008Wooooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Co
oooo0ol00005ooooo`;o00005oooool2o`00013ooooo0_l00029ooooo`00Qoooool2o`0000kooooo
0_l0000Aooooo`?o00001Oooool2o`0001Gooooo1?l0000?ooooo`;o0000R_ooool008Oooooo0_l0
000=ooooo`?o00004oooool00ol0003oooooooooo`0Jooooo`;o00004Oooool2o`0008[ooooo002F
ooooo`;o00005?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`0000oooooo0_l0002Xoooo
o`00[?ooool00ol0003oooooooooo`06ooooo`;o00001oooool2o`000:Sooooo002/ooooo`03o`00
0?oooooooooo00Kooooo0_l0002aooooo`00[?ooool00ol0003oooooooooo`0Oooooo`;o0000V?oo
ool0093ooooo0_l0000Jooooo`03o`000?oooooooooo00Kooooo0_l0000Fooooo`Co0000Uoooool0
093ooooo0_l0000Jooooo`03o`000?oooooooooo00Kooooo0_l0000Fooooo`Co0000Uoooool009Co
oooo0_l0000Fooooo`03o`000?oooooooooo03Cooooo0_l00023ooooo`00U?ooool2o`0001Kooooo
00?o0000ooooooooool02?ooool2o`0002[ooooo0_l00023ooooo`00[?ooool3o`0000Sooooo0_l0
002_ooooo`00WOooool2o`0000gooooo00?o0000ooooooooool0^Oooool009gooooo0_l0000=oooo
o`03o`000?oooooooooo027ooooo0_l0000Cooooo`;o0000POooool00:cooooo00?o0000oooooooo
ool05?ooool2o`0000_ooooo0_l0000Cooooo`;o0000POooool008oooooo0_l0000Cooooo`?o0000
1Oooool00ol0003oooooooooo`02ooooo`;o00004?ooool2o`0000cooooo0_l0002Eooooo`00Sooo
ool2o`0000Kooooo0_l00002ooooo`;o00001oooool3o`0000Gooooo00?o0000ooooooooool00_oo
ool2o`0000Oooooo0_l0000Eooooo`?o00004Oooool3o`00083ooooo002Gooooo`;o00000_ooool2
o`0000?ooooo0_l0000:ooooo`03o`000?oooooooooo00_ooooo0_l0000Fooooo`;o00004Oooool3
o`00083ooooo002Kooooo`;o00000oooool2o`0000[ooooo00?o0000ooooooooool0=_ooool2o`00
087ooooo002/ooooo`?o0000=_ooool2o`00087ooooo002/ooooo`04o`000?oooooo0000o`0001Ko
oooo0_l0002Pooooo`00[?ooool01?l0003oooooo`000?l0000Fooooo`;o0000X?ooool00:cooooo
00Co0000ooooool0003o0000^?ooool00:cooooo00Co0000ooooool0003o0000^?ooool00:_ooooo
0_l0000kooooo`;o0000O_ooool008Cooooo0_l0000Uooooo`;o0000>oooool2o`0007kooooo0024
ooooo`;o00000oooool2o`00017ooooo0_l0000>ooooo`03o`000?oooooooooo0;Wooooo0029oooo
o`;o00004Oooool2o`0000kooooo00?o0000ooooooooool06_ooool2o`0009gooooo0029ooooo`;o
00008Oooool3o`0001[ooooo0_l0002Mooooo`00ROooool2o`00027ooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0^Oooool008gooooo0_l0000<ooooo`;o00003oooool0
0ol0003oooooooooo`2iooooo`00SOooool2o`0000cooooo0_l0000?ooooo`?o0000?_ooool2o`00
07Wooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool3o`00013ooooo0_l0000Fooooo`;o000000?ooooo
o`000?l000004Oooool2o`0007Wooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool00oooool2o`0000_ooooo0_l0000Fooooo`Go0000S?ooool0087ooooo1_l00002
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool2o`0000cooooo0_l0000Gooooo`;o0000;?oo
ool2o`0005oooooo0029ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^
kP07ooooo`03ogMgMolb<S;ooooo00?ooooo1?l00009ooooo`;o00001_ooool2o`0000[ooooo0_l0
000<ooooo`;o0000:oooool2o`0005oooooo0029ooooo`05o`000?ooooooooooooooool000003_oo
ool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool2o`0000_ooooo
0_l0000Booooo`;o00003?ooool2o`0001;ooooo0_l0001hooooo`00ROooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo017ooooo0_l0000[ooooo`?o0000N?ooool008Wooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00;o00003oooool2o`0002_ooooo0ol0001hooooo`00ROooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_l00004ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`00
00Kooooo00?o0000ooooooooool00_l0000mooooo`;o0000N?ooool009?ooooo0_l000000ooooooo
0000o`00000@ooooo`;o00000_ooool00ol0003oooooooooo`0/ooooo`;o0000Roooool009Kooooo
0_l0000@ooooo`;o00000_ooool00ol0003oooooooooo`06ooooo`;o00009?ooool2o`0008_ooooo
002/ooooo`03o`000?oooooooooo00Kooooo0_l0000fooooo`;o0000NOooool0093ooooo0_l0000J
ooooo`?o00005?ooool2o`0002Sooooo0ol0001hooooo`00Poooool2o`0000_ooooo0_l0000Joooo
o`03o`000?oooooooooo01Cooooo0_l0000Yooooo`;o0000N?ooool008?ooooo0_l0000Wooooo`03
o`000?oooooooooo00cooooo0_l0000Oooooo`;o00004oooool2o`0007Gooooo002/ooooo`03o`00
0?oooooooooo00cooooo0_l0000Oooooo`;o00004oooool2o`0007Gooooo002/ooooo`03o`000?oo
oooooooo00cooooo0_l0000Nooooo`;o0000;_ooool2o`0005_ooooo002/ooooo`03o`000?oooooo
oooo02cooooo0_l0000^ooooo`;o0000Foooool00:cooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool0@_ooool2o`0007Gooooo002;ooooo`;o00007oooool3o`0001Kooooo
0_l00008ooooo`;o00008?ooool2o`0007Gooooo002;ooooo`;o00007oooool00ol0003ooooooooo
o`0Fooooo`;o00001_ooool4o`00023ooooo0_l0001eooooo`00P_ooool2o`0002Sooooo00?o0000
ooooooooool05_ooool2o`0000Kooooo0_l0000>ooooo`;o00005?ooool2o`0007?ooooo0022oooo
o`;o0000:?ooool00ol0003oooooooooo`0Fooooo`;o00005_ooool2o`00013ooooo0_l00002oooo
o`;o00005oooool2o`0005[ooooo002/ooooo`03o`000?oooooooooo02kooooo0_l0000@ooooo`;o
00006oooool2o`0005[ooooo002;ooooo`;o00001oooool2o`0001Kooooo00?o0000ooooooooool0
8_ooool2o`0000[ooooo0_l0000Dooooo`;o0000Loooool008_ooooo0_l00002ooooo`;o00000ooo
ool2o`0001Kooooo00?o0000ooooooooool08_ooool2o`00023ooooo0_l0001cooooo`00P_ooool2
o`0000_ooooo0_l00003ooooo`;o00005_ooool00ol0003oooooooooo`0Qooooo`;o0000U_ooool0
08;ooooo0_l0000@ooooo`;o00005_ooool00ol0003oooooooooo`0Qooooo`;o0000U_ooool00:co
oooo0ol0002iooooo`00U_ooool2o`0001Cooooo00?o0000ooooooooool01?ooool2o`000;?ooooo
0027ooooo`;o00003Oooool2o`0001Cooooo00?o0000ooooooooool01?ooool2o`000;?ooooo0009
ooooo`Co000000?o410@ooooooooool05_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0?oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2o`0000?ooooo1_l00004ooooo`05odA4A?l0003o
0000oc8b<_oMgMd05_ooool00ol0003oooooooooo`0>ooooo`;o00002?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^oooo
o`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd06?ooool4o`000003oa0@4?oooooooooo01;ooooo
000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2o`0000?ooooo0_l000001OlQ8B7ok^k^oooooom4A4Cooooo00;o00001?ooool0
0omgMgOo<S8booooo`02ooooo`;o00004Oooool00ol0003oooooooooo`0>ooooo`;o00002?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1oooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool00oooool2o`0000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo01Wooooo00?o0000oooo
ooooool05?ooool000Ko00001Oooool00ol0003oooooooooo`0@ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`05oooo
o`Ko00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool01Oooool6
o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00;ooooo0_l0
0005ooooo`04o`000?ooooooooooooooo`;o00004Oooool00ol0003oooooooooo`0Hooooo`05oa0@
4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00co
oooo0_l00003ooooo`03oa0@4?oooooooooo00kooooo00?o0000ooooooooool00_ooool2o`0000Wo
oooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05
o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo
00kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000
ooooooooooooooooo`00000:ooooo`;o000000CooooooiRHV?lQ8B7ok^k^1oooool00omgMgOo<S8b
ooooo`0Eooooo`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000=ooooo`03
oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool03Oooool4o`000003ooooool0003ooooo00ko
oooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qoooo
ooooool01_ooool00omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo000;ooooo`03
o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003?oo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000:ooooo`;o
00000_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05_ooool00ol0
003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool3o`000003ooooool0003ooooo00_ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGo
c<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06_ooool00ol0003oooooooooo`0Doooo
o`002oooool00ol0003oooooooooo`0Hooooo`05oa0@4?ooooooooooooooool@41003_ooool00onY
ZJWoMgMgooooo`03ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool06?ooool3o`0000kooooo0_l00008ooooo`05oa0@4?oo
ooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo
00Go410@o`000?l0003ooooooa0@400<ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooo
oooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool04Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool01Oooool2o`0000Oooooo1?l00006ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool04Oooool0
1OmgMgOo0000o`000?nHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool05?ooool000Wooooo00?oEEEEofIVI_l000006_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<00Cooooo1?l0000Gooooo`03o`000?oooooooooo00Gooooo0_l00008ooooo`?o00001_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co
00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000Iooooo`03oeEEEOmVIVKo000001Kooooo002Aoooo
o`;o00006Oooool00ol0003oooooooooo`0?ooooo`;o00007_ooool2o`0008Sooooo002Aooooo`;o
00006Oooool00ol0003oooooooooo`0Fooooo`;o00005oooool2o`0008Sooooo002/ooooo`03o`00
0?oooooooooo01Kooooo0_l0000Gooooo`;o0000OOooool2o`0000;ooooo0_l00005ooooo`00[?oo
ool00ol0003oooooooooo`0Qooooo`;o00003?ooool2o`0007gooooo00Kok^k^ob4Q8On7QhOo^[Zj
o`000?oMgMd5ooooo`00[?ooool00ol0003oooooooooo`0Gooooo`;o00002?ooool3o`0008_ooooo
00CogMgMo`000?l@413oc<c<1_ooool000Ooooooool0001<o`0000cooooo00Cok^k^ob4Q8Ol@413o
k^k^1_ooool000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool00_l00003ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool01?lQ8B7oMgMg
ogMgMolb<S86ooooo`001oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`08ooooo`;o00002?ooool2o`0001;ooooo
00?o0000ooooooooool02Oooool2o`0001cooooo00?o0000ooooooooool06oooool4o`0000Oooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Wooooo
0_l00002ooooo`;o00001Oooool008kooooo0_l00008ooooo`;o00004_ooool00ol0003ooooooooo
o`0Gooooo`;o00002oooool2o`0001oooooo0_l0001booooo`00[?ooool00ol0003oooooooooo`0G
ooooo`Co00002Oooool2o`0009?ooooo002/ooooo`03o`000?oooooooooo01Wooooo0_l00007oooo
o`;o0000UOooool008?ooooo0_l0000Wooooo`04o`000?ooooooooooooooo`;o00007oooool4o`00
09?ooooo0023ooooo`;o00009oooool01?l0003oooooooooooooool2o`00027ooooo0_l0000koooo
o`;o0000E_ooool00:cooooo0ol0000aooooo`;o0000;_ooool2o`0005Kooooo002/ooooo`03o`00
0?oooooooooo00Wooooo0_l0000=ooooo`;o00005oooool2o`0008Kooooo002/ooooo`03o`000?oo
oooooooo00Wooooo0_l0000=ooooo`;o0000;?ooool2o`00077ooooo001mooooo`;o00004_ooool2
o`0001Wooooo00?o0000ooooooooool04?ooool2o`00013ooooo0_l0000Rooooo`?o0000L?ooool0
07gooooo0_l0000Booooo`;o00006Oooool00ol0003oooooooooo`0@ooooo`;o00004?ooool2o`00
02?ooooo0_l0001`ooooo`00OOooool2o`0000Wooooo0_l0000:ooooo`;o00005_ooool00ol0003o
ooooooooo`0?ooooo`;o0000Z?ooool008;ooooo0_l00003ooooo`?o00002_ooool2o`0001Kooooo
00?o0000ooooooooool03oooool2o`000:Sooooo0022ooooo`;o00000oooool2o`00013ooooo0_l0
000Aooooo`03o`000?oooooooooo01Oooooo0_l0000:ooooo`;o0000U?ooool0097ooooo0_l00006
ooooo`;o00004Oooool00ol0003oooooooooo`0Gooooo`;o00002_ooool2o`00023ooooo0_l0001b
ooooo`00TOooool3o`0001Sooooo0ol00013ooooo`Co0000L_ooool009;ooooo0_l0000Hooooo`03
o`000?oooooooooo04?ooooo0_l0001dooooo`00[?ooool00ol0003oooooooooo`09ooooo`;o0000
9_ooool2o`0001Cooooo0_l0001`ooooo`00[?ooool00ol0003oooooooooo`09ooooo`;o00009_oo
ool2o`0001Cooooo0_l0001`ooooo`00Roooool2o`0001oooooo00?o0000ooooooooool08_ooool2
o`0002?ooooo0_l0000Gooooo`;o0000Eoooool008_ooooo0_l0000Oooooo`03o`000?oooooooooo
027ooooo0ol0000;ooooo`;o0000;oooool2o`0005Oooooo002/ooooo`03o`000?oooooooooo027o
oooo0ol0000;ooooo`;o00005?ooool3o`00077ooooo002/ooooo`03o`000?oooooooooo02oooooo
0_l0000Booooo`Go0000LOooool00:cooooo0ol0000>ooooo`;o00007oooool2o`0001;ooooo1Ol0
001aooooo`00Poooool2o`0002Oooooo00?o0000ooooooooool03_ooool2o`0001kooooo0_l0000D
ooooo`Co0000LOooool008?ooooo0_l0000Wooooo`03o`000?oooooooooo02kooooo0_l00029oooo
o`00Poooool2o`0000_ooooo0_l0000Jooooo`03o`000?oooooooooo0;Wooooo002@ooooo`;o0000
6_ooool00ol0003oooooooooo`0`ooooo`?o0000Q_ooool009Gooooo0_l0000Dooooo`;o00006?oo
ool3o`0001Gooooo1Ol00026ooooo`00UOooool2o`0001Cooooo0_l0000Hooooo`?o00005Oooool2
o`0008Wooooo002Eooooo`;o00005Oooool00ol0003oooooooooo`03ooooo`;o0000@?ooool2o`00
07;ooooo002/ooooo`?o00000oooool2o`0001[ooooo0_l0000Tooooo`;o0000L_ooool008gooooo
0_l0000Mooooo`03o`000?oooooooooo00gooooo0_l0000@ooooo`;o00009Oooool2o`00077ooooo
002=ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Gooooo`03o`000?oooooooooo00gooooo
0_l0000gooooo`;o0000LOooool008?ooooo0_l0000;ooooo`;o000000?oooooo`000?l000005ooo
ool00ol0003oooooooooo`15ooooo`;o0000L_ooool008?ooooo0_l0000Wooooo`03o`000?oooooo
oooo01?ooooo0_l0000`ooooo`;o0000L_ooool00:cooooo00?o0000ooooooooool03Oooool2o`00
00Cooooo0_l0002Tooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool03Oooool2
o`00013ooooo0_l0002Hooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo01oooooo0_l0002Hooooo`00ROooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o00007oooool3o`0009Oooooo0029
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool00_l0000Mooooo`?o0000Uoooool008Wooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`03o`000?oooooooooo00;o0000]oooool008Wooooo00Go410@oooooooooooooooo
oa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`12ooooo`Co0000Loooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Go
oooo0_l0000kooooo`Co0000Loooool007oooooo0_l00003ooooo`;o00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo0_l00006ooooo`03oiRHV?l@413o000000;o00001?ooool4o`0000Ko
oooo00?o0000ooooooooool01Oooool2o`0003_ooooo0_l0001eooooo`00Ooooool2o`0000?ooooo
0_l0000;ooooo`;o00002Oooool2o`0000kooooo00?o0000ooooooooool0@_ooool2o`0007Gooooo
002Iooooo`;o00004Oooool00ol0003oooooooooo`03ooooo`;o00005_ooool2o`0002Cooooo0_l0
001fooooo`00VOooool2o`0000oooooo0ol00005ooooo`;o00005_ooool2o`0002Cooooo0_l0001f
ooooo`00S_ooool2o`0001[ooooo1_l0000@ooooo`?o00006?ooool2o`0001?ooooo0_l0001foooo
o`00S_ooool2o`0000Wooooo0_l0000Aooooo`04o`000?oooooo0000o`0000Oooooo0_l00007oooo
o`?o00006?ooool2o`0008_ooooo002Iooooo`;o00004Oooool00ol0003oooooooooo`08ooooo`?o
00007oooool2o`000003ooooool0003o0000013ooooo0_l0001hooooo`00VOooool2o`00017ooooo
00?o0000ooooooooool02Oooool2o`00013ooooo0_l0000=ooooo`Go00004?ooool4o`0007Kooooo
002Iooooo`;o00004Oooool00ol0003oooooooooo`0Kooooo`;o00003oooool2o`0001?ooooo0_l0
001fooooo`00Ooooool2o`0000Cooooo0_l0000Uooooo`;o00004Oooool2o`0002_ooooo0_l0001j
ooooo`00Ooooool2o`0000Cooooo0_l00003ooooo`;o00006Oooool2o`0000Gooooo0_l0000Aoooo
o`;o00001oooool2o`00013ooooo0_l0000@ooooo`;o0000N_ooool008[ooooo0_l0000Gooooo`Co
00001Oooool00ol0003oooooooooo`0@ooooo`;o00001oooool2o`00013ooooo0_l0000Aooooo`;o
0000NOooool00:?ooooo0_l00007ooooo`?o0000?_ooool2o`0007Wooooo002Cooooo`;o00005ooo
ool00ol0003oooooooooo`0Wooooo`;o0000T?ooool009?ooooo0_l00002ooooo`;o00004oooool0
0ol0003oooooooooo`0Wooooo`;o0000T?ooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo
00kooooo0_l0000^ooooo`;o0000NOooool009Sooooo0_l0000Booooo`03o`000?oooooooooo00ko
oooo0_l0000^ooooo`;o0000NOooool009Sooooo0_l0000Booooo`03o`000?oooooooooo03_ooooo
0_l0001looooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool01Oooool2o`00013ooooo0_l0
000Rooooo`?o0000Noooool009Cooooo0_l00009ooooo`;o00002oooool00ol0003oooooooooo`05
ooooo`;o00004?ooool2o`0002?ooooo0_l0001kooooo`00Woooool2o`0000Cooooo0_l00005oooo
o`?o0000??ooool2o`0007_ooooo0026ooooo`;o00006oooool4o`0000Gooooo00?o0000oooooooo
ool03?ooool2o`0000Sooooo0_l0000>ooooo`Co00003oooool2o`000003ooooool0003o000007_o
oooo0026ooooo`;o00006oooool2o`0000Oooooo00?o0000ooooooooool03?ooool2o`0000Sooooo
0_l0000>ooooo`Co00003oooool2o`000003ooooool0003o000007_ooooo002Aooooo`;o00006Ooo
ool00ol0003oooooooooo`0Fooooo`;o00008Oooool2o`000003ooooool0003o000007_ooooo002A
ooooo`;o00006Oooool2o`0001Oooooo0_l0000Pooooo`;o00000_ooool2o`0007_ooooo002Eoooo
o`;o00005Oooool2o`0003Wooooo0_l000000ooooooo0000o`00001looooo`00UOooool2o`0001Go
oooo00?o0000ooooooooool0>oooool2o`0007cooooo002=ooooo`;o00006oooool3o`000;_ooooo
002=ooooo`;o00003_ooool2o`0000_ooooo1Ol000000ooooooo0000o`00000cooooo`;o000000?o
ooooo`000?l00000O_ooool009gooooo0_l0000=ooooo`04o`000?ooooooooooooooo`;o00004?oo
ool2o`00027ooooo0_l000000ooooooo0000o`00001nooooo`00[?ooool00ol0003oooooooooo`09
ooooo`;o00002?ooool2o`000:Cooooo002Oooooo`;o00002oooool00ol0003oooooooooo`09oooo
o`;o0000[_ooool009oooooo0_l0000;ooooo`04o`000?oooooo0000o`000;Sooooo0027ooooo`;o
00001Oooool2o`0000?ooooo0_l0000:ooooo`;o00002oooool01?l0003oooooo`000?l0000Aoooo
o`;o0000YOooool008Oooooo0_l00005ooooo`;o000000?oooooonk^k_lb<S800_l000000oo^k^ko
ooooooooo`03ooooo`;o8B4Q1Oooool00om4A4Co0000o`000002o`0000Gooooo00?o0000oooooooo
ool04_ooool2o`0002Cooooo0_l0001oooooo`00R?ooool2o`0000Oooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q2?ooool2o`0000Gooooo00?o0000ooooooooool08Oooool2o`0001Go
oooo0_l0001oooooo`00R?ooool2o`0000Oooooo00Go410@oooooooooooooooooa0@400@ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool08Oooool2o`0009Kooooo0028ooooo`?o0000
1_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool3o`00023o
oooo0_l0000Eooooo`;o0000P?ooool008Wooooo0_l00006ooooo`05o`000?ooooooooooooooool0
00003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool07oooool3o`00
01Gooooo0_l00020ooooo`00TOooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Oooooo`;o0000V?ooool0097ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07oooool2o`00
01Gooooo0_l00021ooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006oooo
o`03o`000?oooooooooo03Kooooo0_l00021ooooo`00UOooool2o`0000Kooooo0_l0000=ooooo`03
o`000?oooooooooo00?ooooo0_l0002dooooo`00ROooool2o`0000[ooooo0_l00006ooooo`Co0000
2oooool00ol0003oooooooooo`03ooooo`;o0000]?ooool008Wooooo0_l0000Dooooo`Co00001?oo
ool2o`0000?ooooo00Co0000oooooooooooooooo1?l0000[ooooo`;o0000Qoooool00:7ooooo0_l0
0002ooooo`Co00000oooool3o`000003ooooool0003o000001Oooooo0_l0000Dooooo`;o0000Qooo
ool00:Gooooo0_l00005ooooo`03o`000?oooooooooo01[ooooo0_l0002Mooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00Roooool2o`0001oooooo00?o0000ooooooooool0;oooool4o`0008Ko
oooo002;ooooo`;o00001?ooool2o`0001Wooooo00?o0000ooooooooool02_ooool2o`0002?ooooo
1?l00026ooooo`00TOooool2o`0001Wooooo00Co0000ooooool0003o00002Oooool2o`0002?ooooo
0_l00028ooooo`00V_ooool2o`00013ooooo00Co0000ooooool0003o0000^?ooool009[ooooo0_l0
000@ooooo`03o`000?oooooooooo0;Wooooo002Jooooo`;o00003oooool4o`0002gooooo0_l0002:
ooooo`00Toooool2o`0001Kooooo0_l0000_ooooo`;o0000R_ooool009?ooooo0ol0000Fooooo`03
o`000?oooooooooo02[ooooo0_l0002=ooooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool0
1oooool2o`00027ooooo0_l0002=ooooo`00S?ooool2o`0000Kooooo0_l00006ooooo`;o00003_oo
ool00ol0003oooooooooo`07ooooo`;o0000/?ooool008cooooo0_l0000>ooooo`;o00003_ooool0
0ol0003oooooooooo`2iooooo`00Yoooool2o`0000?ooooo00?o0000ooooooooool09oooool2o`00
093ooooo002Wooooo`;o00000oooool00ol0003oooooooooo`0Wooooo`;o0000T?ooool00:Gooooo
0_l00005ooooo`?o0000^Oooool009Gooooo0_l0000>ooooo`;o00001Oooool00ol0003ooooooooo
o`0Yooooo`;o0000S_ooool009Gooooo0_l0000Eooooo`03o`000?oooooooooo02Sooooo0ol0002>
ooooo`00[?ooool00ol0003oooooooooo`0Xooooo`;o0000Soooool009Oooooo0_l0000Cooooo`03
o`000?oooooooooo00oooooo0ol0002Wooooo`00Uoooool2o`0001?ooooo00Co0000ooooool0003o
00003_ooool3o`0001Gooooo0_l0002@ooooo`00[?ooool01?l0003oooooo`000?l0000?ooooo`?o
00005?ooool2o`00093ooooo002/ooooo`03o`000?oooooooooo017ooooo0_l0002Vooooo`00V_oo
ool2o`00013ooooo00?o0000ooooooooool03?ooool2o`000:_ooooo002Jooooo`;o00004?ooool3
o`0000cooooo0_l0002[ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`0;ooooo`;o0000[?ooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool00ol0003ok^k^ooooo`04ooooo`06odA4A?l0003o0000oc8b<_oMgMgooooo0_l00002ooooo`03
o`000?oooooooooo00[ooooo0ol0002/ooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo0_l000000ooooooo0000o`000002ooooo`03
o`000?oooooooooo00[ooooo0_l0002]ooooo`00ROooool01Ol@413ooooooooooooooooo410@00go
oooo00?oZJVYoeEEEOooool01oooool3o`0000Cooooo00?o0000ooooooooool0^Oooool008Wooooo
00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgo`000?l0
00001?ooool3o`0000Kooooo0_l0002aooooo`00ROooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool3o`000003oc8b<_o<c<cooooo00Cooooo00?o0000oooooooo
ool01_ooool2o`000;7ooooo0029ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWo
MgMgooooo`03ooooo`?o00001oooool00ol0003oooooooooo`2iooooo`00ROooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo0_l00003ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01_ooool2o`0000?ooooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`0Ioooo
o`?o0000WOooool009Gooooo0_l0000Eooooo`03o`000?oooooooooo01Wooooo1?l0002Looooo`00
UOooool2o`0001Gooooo00?o0000ooooooooool06oooool2o`0009cooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`Go0000]oooool00:cooooo00?o0000ooooooooool00_l0002goooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00V?ooool2o`0001;ooooo00?o0000ooooooooool0
^Oooool009Sooooo0_l0000Booooo`03o`000?oooooooooo00;o0000]oooool009Sooooo0_l0000B
ooooo`03o`000?oooooooooo00;o0000]oooool009Sooooo0_l0000Booooo`03o`000?oooooooooo
0;Wooooo002/ooooo`;o0000^_ooool00:cooooo0ol0002iooooo`00Woooool2o`0000_ooooo00?o
0000ooooooooool04_ooool2o`000:Gooooo002Oooooo`;o00001?ooool2o`0000Gooooo00?o0000
ooooooooool04_ooool2o`000:Gooooo002Sooooo`Co00001Oooool00ol0003oooooooooo`2ioooo
o`00Xoooool2o`0000Oooooo00?o0000ooooooooool03?ooool2o`000:_ooooo002/ooooo`03o`00
0?oooooooooo00cooooo0_l0002[ooooo`00Xoooool2o`0000Oooooo00?o0000ooooooooool0^Ooo
ool00:?ooooo0_l00007ooooo`03o`000?oooooooooo00kooooo0_l0002Yooooo`00[?ooool00ol0
003oooooooooo`0>ooooo`;o0000ZOooool00:cooooo0ol0000:ooooo`;o0000[Oooool00:cooooo
00?o0000ooooooooool02_ooool2o`000:gooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00Kooooo0_l0002aooooo`00[?oo
ool00ol0003oooooooooo`06ooooo`;o0000/Oooool00:cooooo0ol0002iooooo`00U_ooool2o`00
01Cooooo00?o0000ooooooooool00oooool2o`000;Cooooo002Fooooo`;o00005?ooool00ol0003o
ooooooooo`03ooooo`;o0000]?ooool00:cooooo00?o0000ooooooooool0^Oooool009Sooooo0_l0
000Booooo`03o`000?oooooooooo0;Wooooo002Hooooo`;o00004_ooool00ol0003oooooooooo`2i
ooooo`00X_ooool4o`000003oa0@4?oooooooooo00?ooooo0ol0002iooooo`00Y?ooool00ol0003o
ooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool3o`000;Wooooo
002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Toooo
o`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Rooooo`03oeEE
EOmVIVKo00000<?ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo002Zooooo`04oa0@4?l0003o0000o`000;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`06o`000?mgMgOo0000o`000?mEEEGok^k^
]oooool00:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomEEEFgooooo`00Zoooool00ol0003ok^k^
ooooo`02ooooo`03o`000?oooooooooo0;Gooooo002[ooooo`03o`000?o^k^kooooo00;ooooo00?o
0000ooooooooool0]Oooool00:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomVIVJgooooo`00Z_oo
ool00ol@413o0000ogMgM`02o`000003ofIVI_o^k^kooooo0;Kooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.4205 .18557 Mdot
.56989 .20599 Mdot
.49427 .39465 Mdot
.41894 .46693 Mdot
.58712 .4696 Mdot
.48722 .88041 Mdot
.51059 .58367 Mdot
.70994 .35857 Mdot
.62113 .20036 Mdot
.556 .5929 Mdot
.48082 .78393 Mdot
.72718 .44977 Mdot
.66772 .4561 Mdot
.52918 .69974 Mdot
.7245 .50305 Mdot
.50935 .28071 Mdot
.57831 .31503 Mdot
.66943 .4687 Mdot
.47277 .1964 Mdot
.52678 .90454 Mdot
.66683 .50422 Mdot
.62784 .32527 Mdot
.6452 .39059 Mdot
.67045 .5018 Mdot
.72053 .60553 Mdot
.47763 .83631 Mdot
.42457 .67634 Mdot
.46724 .20205 Mdot
.48442 .94896 Mdot
.58443 .23491 Mdot
.65991 .57419 Mdot
.61433 .18541 Mdot
.69383 .32961 Mdot
.61469 .46883 Mdot
.61625 .58877 Mdot
.55774 .8479 Mdot
.39872 .1915 Mdot
.42517 .30757 Mdot
.42241 .88123 Mdot
.732 .4617 Mdot
.72839 .58679 Mdot
.6198 .52796 Mdot
.56886 .74429 Mdot
.43105 .14736 Mdot
.38874 .40145 Mdot
.57466 .63836 Mdot
.52566 .69981 Mdot
.54693 .09481 Mdot
.40441 .35848 Mdot
.47468 .94624 Mdot
.54542 .09475 Mdot
.38848 .73918 Mdot
.54062 .00879 Mdot
.59234 .68049 Mdot
.59635 .67962 Mdot
.66185 .26694 Mdot
.71402 .37668 Mdot
.57301 .29824 Mdot
.47516 .03282 Mdot
.38626 .49367 Mdot
.56163 .67933 Mdot
.62092 .85939 Mdot
.409 .83514 Mdot
.54445 .51067 Mdot
.69517 .35242 Mdot
.63792 .2207 Mdot
.55712 .57944 Mdot
.49726 .26027 Mdot
.42242 .3178 Mdot
.66857 .54602 Mdot
.58604 .31959 Mdot
.43727 .58089 Mdot
.54917 .62028 Mdot
.56185 .49276 Mdot
.40909 .83543 Mdot
.48318 .64189 Mdot
.54138 .00959 Mdot
.51253 .78392 Mdot
.40769 .83961 Mdot
.40435 .3863 Mdot
.63123 .70039 Mdot
.58067 .23042 Mdot
.42131 .56656 Mdot
.62047 .53823 Mdot
.68717 .30403 Mdot
.51169 .28018 Mdot
.58846 .48629 Mdot
.58245 .5734 Mdot
.5483 .24448 Mdot
.50423 .27503 Mdot
.71711 .61792 Mdot
.35689 .48138 Mdot
.5252 .65063 Mdot
.5832 .59102 Mdot
.53401 .61106 Mdot
.36416 .68361 Mdot
.53347 .6875 Mdot
.56262 .12019 Mdot
.55709 .02425 Mdot
.54761 .23896 Mdot
.45196 .11452 Mdot
.50792 .17618 Mdot
.7255 .45825 Mdot
.46236 .09956 Mdot
.65436 .63503 Mdot
.61669 .49333 Mdot
.59999 .36453 Mdot
.50526 .22354 Mdot
.52432 .65408 Mdot
.66642 .55843 Mdot
.54735 .64136 Mdot
.41862 .53301 Mdot
.61122 .18208 Mdot
.56477 .84637 Mdot
.72496 .23224 Mdot
.51635 .6251 Mdot
.54134 .72937 Mdot
.64851 .2301 Mdot
.63219 .20633 Mdot
.40178 .18334 Mdot
.66704 .45927 Mdot
.66159 .79435 Mdot
.66012 .47786 Mdot
.48121 .9517 Mdot
.6674 .55555 Mdot
.42832 .3559 Mdot
.54005 .88066 Mdot
.39325 .87783 Mdot
.53659 .1663 Mdot
.44084 .64946 Mdot
.64329 .37357 Mdot
.49305 .10778 Mdot
.7306 .49639 Mdot
.48404 .88517 Mdot
.5439 .79467 Mdot
.43825 .92369 Mdot
.3767 .35491 Mdot
.50603 .92636 Mdot
.55036 .61309 Mdot
.70728 .37511 Mdot
.72627 .50668 Mdot
.53002 .97035 Mdot
.46147 .74358 Mdot
.43865 .24685 Mdot
.57825 .31388 Mdot
.5478 .87456 Mdot
.67331 .27509 Mdot
.77089 .32031 Mdot
.53297 .28701 Mdot
.579 .60049 Mdot
.69044 .7443 Mdot
.49008 .15276 Mdot
.40995 .55098 Mdot
.67158 .50359 Mdot
.44587 .63288 Mdot
.4125 .76519 Mdot
.37309 .44988 Mdot
.40196 .80908 Mdot
.65128 .23886 Mdot
.40304 .17312 Mdot
.37349 .42811 Mdot
.41803 .72632 Mdot
.41187 .85716 Mdot
.73833 .55078 Mdot
.58647 .79794 Mdot
.56063 .7553 Mdot
.44891 .12177 Mdot
.66928 .2688 Mdot
.64845 .66208 Mdot
.41739 .3537 Mdot
.37181 .51043 Mdot
.50051 .92651 Mdot
.49784 .71921 Mdot
.41069 .44837 Mdot
.58684 .5039 Mdot
.54454 .31038 Mdot
.69777 .34894 Mdot
.37068 .74598 Mdot
.41721 .78437 Mdot
.51416 .62523 Mdot
.46073 .94481 Mdot
.37924 .66802 Mdot
.73452 .50294 Mdot
.55169 .40269 Mdot
.72681 .60004 Mdot
.43244 .3894 Mdot
.6167 .1969 Mdot
.39298 .87449 Mdot
.60202 .163 Mdot
.73783 .54121 Mdot
.55931 .76708 Mdot
.68244 .75158 Mdot
.54973 .87248 Mdot
.53807 .43493 Mdot
.62951 .84227 Mdot
.69895 .33192 Mdot
.72277 .63927 Mdot
.72824 .47364 Mdot
.5855 .56871 Mdot
.3683 .2588 Mdot
.61623 .42521 Mdot
.52753 .52017 Mdot
.52694 .53597 Mdot
.43338 .52862 Mdot
.58477 .4675 Mdot
.38695 .13651 Mdot
.47562 .10196 Mdot
.50012 .30364 Mdot
.4581 .87769 Mdot
.42119 .58884 Mdot
.45277 .29615 Mdot
.47592 .78741 Mdot
.65356 .38658 Mdot
.52231 .76605 Mdot
.64718 .66579 Mdot
.54332 .37551 Mdot
.45892 .11058 Mdot
.53462 .73879 Mdot
.73694 .55981 Mdot
.43067 .39669 Mdot
.38767 .52825 Mdot
.72853 .43295 Mdot
.54776 .71487 Mdot
.50056 .0495 Mdot
.65498 .63961 Mdot
.61461 .73963 Mdot
.53037 .33927 Mdot
.57344 .39216 Mdot
.54592 .16648 Mdot
.50861 .69497 Mdot
.72492 .5054 Mdot
.65832 .80396 Mdot
.47099 .23861 Mdot
.48235 .33881 Mdot
.40087 .08173 Mdot
.45582 .16494 Mdot
.43207 .7154 Mdot
.66917 .77731 Mdot
.41516 .37891 Mdot
.4816 .09515 Mdot
.66115 .4565 Mdot
.47923 .10033 Mdot
.61719 .8633 Mdot
.52946 .82362 Mdot
.63377 .7109 Mdot
.58542 .31815 Mdot
.61331 .18004 Mdot
.53623 .59285 Mdot
.37414 .44485 Mdot
.53342 .22731 Mdot
.58245 .31051 Mdot
.40953 .83912 Mdot
.72324 .63163 Mdot
.51777 .61795 Mdot
.53832 .44608 Mdot
.38124 .32409 Mdot
.4593 .82655 Mdot
.41008 .47913 Mdot
.5919 .70036 Mdot
.47406 .64797 Mdot
.70991 .37092 Mdot
.51466 .05926 Mdot
.42444 .23766 Mdot
.43312 .71953 Mdot
.60612 .75947 Mdot
.47307 .71138 Mdot
.48761 .15334 Mdot
.40477 .26142 Mdot
.51068 .73386 Mdot
.50209 .85778 Mdot
.53141 .88534 Mdot
.41989 .72636 Mdot
.55417 .85776 Mdot
.59147 .69639 Mdot
.55908 .57988 Mdot
.41124 .3132 Mdot
.37236 .49119 Mdot
.55508 .41532 Mdot
.55012 .31327 Mdot
.56182 .11492 Mdot
.49024 .78028 Mdot
.42792 .82355 Mdot
.44254 .92741 Mdot
.44004 .65435 Mdot
.55755 .45561 Mdot
.40516 .1652 Mdot
.72274 .43453 Mdot
.50983 .23086 Mdot
.4735 .68143 Mdot
.5736 .41172 Mdot
.59488 .799 Mdot
.57572 .62236 Mdot
.63869 .67583 Mdot
.39128 .86591 Mdot
.46923 .03625 Mdot
.72271 .46545 Mdot
.48267 .0389 Mdot
.51468 .45201 Mdot
.43605 .0669 Mdot
.63896 .8225 Mdot
.61654 .75753 Mdot
.72391 .49007 Mdot
.78784 .36349 Mdot
.40126 .41242 Mdot
.56653 .76036 Mdot
.49871 .11202 Mdot
.61462 .18358 Mdot
.72618 .58365 Mdot
.51729 .72243 Mdot
.56151 .11625 Mdot
.44746 .81198 Mdot
.52108 .42661 Mdot
.65229 .38875 Mdot
.58629 .33441 Mdot
.66441 .45018 Mdot
.697 .72704 Mdot
.50455 .66528 Mdot
.3888 .42682 Mdot
.61793 .5029 Mdot
.70229 .37407 Mdot
.472 .71379 Mdot
.73399 .51431 Mdot
.68264 .73675 Mdot
.50827 .99859 Mdot
.45407 .25994 Mdot
.48519 .88639 Mdot
.62146 .54025 Mdot
.38947 .73411 Mdot
.57462 .39011 Mdot
.52764 .46739 Mdot
.5169 .5168 Mdot
.59316 .34524 Mdot
.72266 .40407 Mdot
.3811 .33088 Mdot
.5369 .59879 Mdot
.64245 .35636 Mdot
.43657 .63032 Mdot
.43307 .51531 Mdot
.55228 .17604 Mdot
.50255 .86419 Mdot
.56001 .75688 Mdot
.41712 .72111 Mdot
.5826 .45149 Mdot
.44087 .79605 Mdot
.56791 .21228 Mdot
.54336 .52329 Mdot
.68132 .30545 Mdot
.43226 .71136 Mdot
.51429 .91519 Mdot
.60659 .28377 Mdot
.49734 .7287 Mdot
.5562 .682 Mdot
.53586 .96445 Mdot
.72664 .43822 Mdot
.42652 .08499 Mdot
.54995 .86084 Mdot
.39873 .51764 Mdot
.61388 .4236 Mdot
.51352 .91127 Mdot
.47099 .1517 Mdot
.72627 .43874 Mdot
.63005 .72077 Mdot
.72981 .49396 Mdot
.73389 .5237 Mdot
.73195 .58598 Mdot
.43905 .3973 Mdot
.43541 .20456 Mdot
.72571 .51265 Mdot
.71123 .37089 Mdot
.44395 .36772 Mdot
.6504 .63596 Mdot
.43273 .77071 Mdot
.45986 .88115 Mdot
.44178 .13028 Mdot
.57852 .14065 Mdot
.48013 .09529 Mdot
.4181 .11369 Mdot
.37438 .49689 Mdot
.64172 .37925 Mdot
.40553 .15045 Mdot
.64004 .36585 Mdot
.72482 .57395 Mdot
.74377 .26287 Mdot
.42447 .10329 Mdot
.40765 .74479 Mdot
.45051 .64576 Mdot
.70225 .68754 Mdot
.5377 .22368 Mdot
.51693 .49884 Mdot
.73605 .50775 Mdot
.66812 .55264 Mdot
.52649 .4505 Mdot
.56177 .5237 Mdot
.50434 .80572 Mdot
.42143 .66219 Mdot
.5579 .10679 Mdot
.65778 .64104 Mdot
.63033 .83876 Mdot
.7349 .51021 Mdot
.60572 .40064 Mdot
.61096 .41772 Mdot
.53906 .29612 Mdot
.55312 .32699 Mdot
.44283 .42942 Mdot
.71988 .39817 Mdot
.72629 .44585 Mdot
.42777 .69302 Mdot
.49432 .73102 Mdot
.44054 .75073 Mdot
.53248 .33186 Mdot
.70824 .69158 Mdot
.58746 .5668 Mdot
.59347 .78794 Mdot
.44307 .70503 Mdot
.40913 .5162 Mdot
.46046 .70356 Mdot
.58924 .53044 Mdot
.61196 .44654 Mdot
.42075 .66387 Mdot
.50924 .32702 Mdot
.67619 .76993 Mdot
.70598 .36929 Mdot
.44843 .46342 Mdot
.61337 .60803 Mdot
.60021 .36566 Mdot
.39187 .60186 Mdot
.41911 .71753 Mdot
.41172 .41921 Mdot
.70413 .68749 Mdot
.35735 .57987 Mdot
.50365 .11514 Mdot
.6849 .17183 Mdot
.44381 .11909 Mdot
.52081 .35866 Mdot
.63945 .23471 Mdot
.72537 .52515 Mdot
.46604 .78155 Mdot
.60877 .29118 Mdot
.48354 .74393 Mdot
.51739 .3977 Mdot
.55647 .34411 Mdot
.61202 .74921 Mdot
.39999 .50534 Mdot
.36057 .35488 Mdot
.44249 .331 Mdot
.6037 .63819 Mdot
.6214 .51031 Mdot
.54258 .56022 Mdot
.50381 .66487 Mdot
.56078 .45671 Mdot
.71057 .362 Mdot
.49358 .69692 Mdot
.42391 .89207 Mdot
.54591 .16964 Mdot
.39002 .39007 Mdot
.54881 .86733 Mdot
.64596 .64807 Mdot
.59693 .36533 Mdot
.40361 .92075 Mdot
.56145 .53742 Mdot
.72408 .40926 Mdot
.72534 .62644 Mdot
.5066 .74146 Mdot
.43252 .07278 Mdot
.41908 .71972 Mdot
.5676 .29452 Mdot
.51963 .90889 Mdot
.45066 .11521 Mdot
.48921 .20283 Mdot
.55578 .68416 Mdot
.61477 .45944 Mdot
.63393 .84514 Mdot
.53975 .79839 Mdot
.49186 .62696 Mdot
.57353 .72974 Mdot
.40481 .37641 Mdot
.43504 .43047 Mdot
.47074 .24389 Mdot
.59656 .66862 Mdot
.55561 .77573 Mdot
.52468 .57323 Mdot
.47438 .83156 Mdot
.64041 .225 Mdot
.58604 .4509 Mdot
.39583 .32973 Mdot
.42262 .30966 Mdot
.47572 .20298 Mdot
.46772 .30813 Mdot
.7139 .21149 Mdot
.47775 .3058 Mdot
.56129 .19099 Mdot
.51443 .06747 Mdot
.58456 .80286 Mdot
.43037 .27814 Mdot
.4879 .94458 Mdot
.73257 .48409 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool2o`000:gooooo002T
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool2o`000:gooooo002Roooo
o`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0000?ooooo`;o0000Z?oo
ool00:cooooo00?o0000ooooooooool03oooool2o`000:Sooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002Sooooo`;o00001oooool00ol0003oooooooooo`2iooooo`00XOooool4o`0000Oooooo
00?o0000ooooooooool0^Oooool00:7ooooo0_l00003ooooo`;o00001?ooool00ol0003ooooooooo
o`2iooooo`00Y_ooool2o`0000Cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo0_l0002jooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`04o`000?oooooooooo
ooooo`;o0000]_ooool00:cooooo00Co0000oooooooooooooooo0_l0002fooooo`00U_ooool2o`00
01Cooooo00Co0000oooooooooooooooo0_l0002fooooo`00U_ooool2o`0001Cooooo00Co0000oooo
oooooooooooo0_l0002fooooo`00UOooool2o`0001Gooooo00?o0000ooooooooool0^Oooool009Go
oooo0_l0000Eooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool008_ooooo0_l0
000Oooooo`03o`000?oooooooooo0;Wooooo002;ooooo`;o00001_ooool2o`0001Oooooo00?o0000
ooooooooool0^Oooool009?ooooo0_l0000Gooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002Uooooo`;o00001Oooool00ol0003oooooooooo`0<ooooo`;o0000
Zoooool00:Gooooo0_l00005ooooo`03o`000?oooooooooo00cooooo0_l0002[ooooo`00Woooool2
o`0000Cooooo0_l00005ooooo`?o0000^Oooool009?ooooo0_l0000:ooooo`;o00000oooool3o`00
00Gooooo00?o0000ooooooooool0^Oooool009?ooooo0_l0000?ooooo`;o00001_ooool00ol0003o
ooooooooo`0@ooooo`;o0000Yoooool009kooooo0_l00009ooooo`;o000000?oooooo`000?ooool0
4Oooool2o`000:Oooooo002Aooooo`;o00002oooool2o`0000Wooooo1?l0002kooooo`00TOooool2
o`0000Sooooo0ol0000=ooooo`Co00004Oooool2o`000:Kooooo0029ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool3o`00017ooooo0_l0002Vooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`Co00002?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo017ooooo0_l0
002Vooooo`00POooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`;o00002Ooo
ool00ol0003oooooooooo`03ooooo`?o00004Oooool2o`000:Kooooo0029ooooo`05o`000?oooooo
ooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0^Oooool008Wooooo00Go0000ooooooooooooooooo`00000:ooooo`;o00000_oo
ool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`2iooooo`00ROooool01Ol@413ooooooooooooooooo410@00[ooooo0_l00002ooooo`03ojVY
ZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2iooooo`00Q_oo
ool2o`000006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol@413ooooooooooooooooo<S8b
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2iooooo`00Q_ooool2o`000006
ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooo
oooo01Kooooo0_l0002Qooooo`00[?ooool00ol0003oooooooooo`0Fooooo`;o0000XOooool00:co
oooo00?o0000ooooooooool0^Oooool009Gooooo0_l0000Eooooo`03o`000?oooooooooo0;Wooooo
002<ooooo`;o00001oooool2o`0000_ooooo0_l00004ooooo`;o00000_ooool3o`000;Wooooo002<
ooooo`;o00005?ooool2o`0000?ooooo0ol00002ooooo`03o`000?oooooooooo0;Wooooo002Woooo
o`;o00000oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
S?ooool2o`0000oooooo0_l0000=ooooo`03o`000?oooooooooo01kooooo0_l0002Iooooo`00S?oo
ool2o`0000oooooo0_l0000=ooooo`03o`000?oooooooooo00Wooooo0_l000000ooooooo0000o`00
000@ooooo`;o0000VOooool00:cooooo00?o0000ooooooooool02Oooool2o`000003ooooool0003o
00000:_ooooo002<ooooo`;o00007_ooool00ol0003oooooooooo`0<ooooo`;o0000;?ooool2o`00
07gooooo002<ooooo`;o00007_ooool4o`0000gooooo0_l0000Zooooo`;o0000OOooool00:cooooo
00Co0000ooooool0003o00003Oooool2o`0001;ooooo0_l0002Eooooo`00Roooool2o`0001oooooo
00?o0000ooooooooool08Oooool3o`0009Gooooo002;ooooo`;o00001?ooool2o`0001Wooooo00?o
0000ooooooooool08Oooool3o`0009Gooooo002Aooooo`;o00006Oooool00ol0003oooooooooo`0R
ooooo`;o0000UOooool008[ooooo0_l0000Pooooo`03o`000?oooooooooo017ooooo0_l0002Voooo
o`00R_ooool2o`00023ooooo00?o0000ooooooooool04Oooool2o`000:Kooooo002Sooooo`;o0000
1oooool00ol0003oooooooooo`0Sooooo`;o0000U?ooool00:?ooooo0_l00007ooooo`?o00008ooo
ool4o`0009;ooooo002Fooooo`;o00002Oooool2o`000003ooooool0003o000000;ooooo0_l00002
ooooo`03o`000?oooooooooo02Gooooo0_l0002Booooo`00U_ooool2o`0000Wooooo0_l000000ooo
oooo0000o`000002ooooo`;o00000_ooool00ol0003oooooooooo`0Dooooo`;o00004_ooool2o`00
08oooooo002/ooooo`03o`000?oooooooooo01Cooooo0_l0000Booooo`;o0000Soooool00:cooooo
00?o0000ooooooooool04oooool2o`0002kooooo0_l0001dooooo`00[?ooool00ol0003ooooooooo
o`0Cooooo`;o0000;_ooool2o`0007Cooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo02[ooooo0_l0002=ooooo`00[?ooool3o`0000Wooooo0_l0000Oooooo`?o
0000S?ooool00:cooooo0ol00008ooooo`?o00008?ooool2o`0008cooooo002/ooooo`03o`000?oo
oooooooo00;o00001_ooool2o`0000gooooo0_l0000Eooooo`;o0000ROooool00:cooooo00?o0000
ooooooooool00_l0000Eooooo`?o00004Oooool2o`000003ooooool0003o000001Oooooo0_l0001`
ooooo`00Toooool2o`0001Oooooo00?o0000ooooooooool06?ooool2o`00017ooooo0_l0000Joooo
o`;o0000L?ooool009?ooooo0_l0000=ooooo`;o00002?ooool00ol0003oooooooooo`0<ooooo`;o
00008Oooool2o`0008Sooooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Go
oooo0ol000000olb<S;ogMgMooooo`04ooooo`03o`000?oooooooooo00cooooo0_l0000Qooooo`;o
0000R?ooool0097ooooo00KoMgMgoiRHV?ooooooV9RHogMgMoooool2o`0000;ooooo0_lQ8B45oooo
o`;o000000?oooooogMgMolb<S801Oooool00ol0003oooooooooo`0=ooooo`;o0000Z_ooool008Wo
oooo1_l00002ooooo`06oa0@4?ooooooooooooooool@413ooooo0_l0000=ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool03Oooool2o`000:[ooooo002Aooooo`05o`000?oooooooooo
ooooool000003oooool00omgMgOo<S8booooo`04ooooo`?o0000^Oooool0097ooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`2iooooo`00P?ooool2o`0000oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0^Oooool0083ooooo0_l0000:ooooo`;o00000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo0_l00004ooooo`03o`000?oooooooooo00Kooooo0_l0
002kooooo`00S?ooool2o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`;o00001?oo
ool4o`0000Gooooo0_l0001?ooooo`;o0000J_ooool00:cooooo00?o0000ooooooooool0<_ooool2
o`0001Wooooo0_l0001Zooooo`00[?ooool00ol0003oooooooooo`0booooo`Co0000Poooool00:co
oooo00?o0000ooooooooool0=?ooool2o`0008?ooooo002/ooooo`?o0000=_ooool2o`00087ooooo
002Eooooo`;o00005Oooool5o`0003Cooooo0_l00021ooooo`00UOooool2o`0001Gooooo00?o0000
ooooooooool00_l0002gooooo`00[?ooool00ol0003oooooooooo`02o`0001kooooo0_l0002Goooo
o`00[?ooool00ol0003oooooooooo`07ooooo`;o00005oooool2o`0009Oooooo002/ooooo`03o`00
0?oooooooooo00Oooooo0_l0000Gooooo`;o0000Uoooool00:cooooo00?o0000ooooooooool04ooo
ool2o`0000_ooooo0_l0002Gooooo`00W?ooool2o`0000kooooo00?o0000ooooooooool02Oooool2
o`0000Sooooo1?l0002Rooooo`00W?ooool2o`0000kooooo0ol00009ooooo`;o00002_ooool2o`00
0:;ooooo002/ooooo`;o0000>oooool2o`0007gooooo002Cooooo`;o00003oooool2o`0000Kooooo
0_l0000iooooo`Co0000OOooool009;ooooo0ol0000<ooooo`;o000000?oooooo`000?l000001_oo
ool00ol0003oooooooooo`0;ooooo`;o00002oooool2o`0001kooooo0_l0001oooooo`00S_ooool2
o`0000;ooooo0_l0000=ooooo`;o00002Oooool00ol0003oooooooooo`0;ooooo`Co00002Oooool2
o`0009oooooo002>ooooo`;o00007?ooool00ol0003oooooooooo`0=ooooo`;o00001oooool2o`00
0:7ooooo002Booooo`;o00006?ooool00ol0003oooooooooo`0Fooooo`;o000000?oooooo`000?l0
0000W_ooool009;ooooo0_l0000Hooooo`03o`000?oooooooooo01Wooooo0_l0000kooooo`;o0000
HOooool008Cooooo0_l0000Vooooo`?o00009oooool2o`0002gooooo0_l0001Qooooo`00Q?ooool2
o`0002Kooooo00?o0000ooooooooool00_l0000<ooooo`;o00005oooool2o`00093ooooo0024oooo
o`;o00000oooool2o`0000kooooo0_l0000Aooooo`03o`000?oooooooooo00;o00001Oooool2o`00
00Gooooo0_l0000]ooooo`;o0000N_ooool008Cooooo0_l00003ooooo`;o00003_ooool2o`00017o
oooo00?o0000ooooooooool01oooool2o`00013ooooo0_l0000Rooooo`?o0000NOooool00:cooooo
00?o0000ooooooooool06Oooool2o`0002?ooooo0_l0001iooooo`00Y_ooool2o`0000Cooooo00?o
0000ooooooooool01oooool2o`000;3ooooo002Vooooo`;o00001?ooool00ol0003oooooooooo`07
ooooo`;o0000/?ooool00:cooooo00?o0000ooooooooool03oooool2o`0000[ooooo0_l0002Loooo
o`00[?ooool00ol0003oooooooooo`0?ooooo`;o00002_ooool2o`00027ooooo0_l0001iooooo`00
[?ooool3o`0003gooooo0ol0001iooooo`00O_ooool2o`0000?ooooo0_l0000;ooooo`;o00000_oo
ool2o`0001Kooooo00?o0000ooooooooool0?Oooool2o`0007[ooooo001nooooo`;o00000oooool2
o`0000Oooooo0_l00002ooooo`;o00000_ooool2o`0001Kooooo00?o0000ooooooooool00oooool2
o`0002Oooooo0_l0000Dooooo`;o0000MOooool008cooooo0_l0000Nooooo`03o`000?oooooooooo
00?ooooo0_l0000Wooooo`;o00005?ooool2o`0007Gooooo002/ooooo`03o`000?oooooooooo01ko
oooo0_l0000Rooooo`;o00006?ooool2o`0005_ooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`0Mooooo`?o00002oooool2o`0002oooooo0_l0001Kooooo`00ROooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`;o000000?ok^k^oooooom4A4@01oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo01gooooo0ol0000;ooooo`;o00005?ooool3o`00
07Gooooo0021ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q
8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02cooooo0_l0000Aoooo
o`Go0000MOooool008Wooooo00?o0000ooooooooool00_l0000=ooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo00?oMgMgoc8b<_ooool01?ooool3o`0000_ooooo0_l0000Oooooo`;o00004Oooool6o`0007Co
oooo0029ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000[ooooo00?oMgMgofIVI_ooool0
0oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool02oooool2o`0001ko
oooo0_l0000Dooooo`Co0000M?ooool008Wooooo00Go410@oooooooooooooooooa0@4002ooooo`;o
00002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0:oooool2o`0008cooooo0029ooooo`03ogMgMonHV9Sooooo00;o00002oooool01Ol0003o^[Zj
oooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2iooooo`00
ROooool00oo^k^ko<S8bo`000002o`0000Oooooo0_l00002ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`01?ooool4o`0000Kooooo00?o0000ooooooooool0;oooool2o`0008Sooooo0027ooooo`;o0000
3?ooool2o`0001Gooooo00?o0000ooooooooool05Oooool2o`0001Gooooo0_l000000ooooooo0000
o`000028ooooo`00Qoooool2o`00027ooooo0ol0000Gooooo`;o00005Oooool2o`0008_ooooo002E
ooooo`Co00004Oooool3o`0000Cooooo0_l00011ooooo`;o0000L_ooool008Oooooo0_l0000<oooo
o`Co00004oooool3o`0000;ooooo0_l0000Kooooo`;o00009?ooool2o`0007;ooooo0027ooooo`;o
00008oooool00ol0003oooooooooo`0>ooooo`;o00003oooool2o`0002Gooooo0_l0001aooooo`00
[?ooool00ol0003oooooooooo`0>ooooo`;o0000=_ooool2o`00077ooooo002/ooooo`03o`000?oo
oooooooo04Oooooo0_l0001`ooooo`00Roooool2o`0001oooooo00?o0000ooooooooool05Oooool2
o`00033ooooo0_l0001`ooooo`00Roooool2o`0001oooooo00?o0000ooooooooool03oooool2o`00
00Cooooo0_l0002Rooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool03oooool2o`00013o
oooo0_l0002Fooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool08Oooool2o`0009Kooooo
002/ooooo`?o00008_ooool3o`0009Cooooo0022ooooo`;o00000oooool2o`0002?ooooo00?o0000
ooooooooool01?ooool2o`0001cooooo0ol0002Dooooo`00P_ooool2o`0000?ooooo0_l0000=oooo
o`;o000000?oooooo`000?l000004Oooool00ol0003oooooooooo`04ooooo`;o0000/oooool009Ko
oooo0_l000000ooooooo0000o`00000Aooooo`03o`000?oooooooooo04Kooooo1?l0001_ooooo`00
[?ooool00ol0003oooooooooo`09ooooo`;o0000>oooool4o`0006oooooo002/ooooo`03o`000?oo
oooooooo00Wooooo0_l0000looooo`;o0000L?ooool00:cooooo00?o0000ooooooooool0Aoooool2
o`00073ooooo0022ooooo`;o0000:?ooool00ol0003oooooooooo`09ooooo`;o00005oooool2o`00
02?ooooo0_l0001`ooooo`00P_ooool2o`0000[ooooo0_l0000Looooo`03o`000?oooooooooo00Wo
oooo0_l0000Gooooo`;o00008oooool3o`0006oooooo0022ooooo`;o00002_ooool2o`0001cooooo
0ol000000ooooooo0000o`000002ooooo`;o00004Oooool3o`0001Sooooo0_l0000Cooooo`;o0000
Koooool00:cooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00002Oooool2o`0000Kooooo
0ol0000Hooooo`;o0000Q?ooool00:cooooo00?o0000ooooooooool04?ooool3o`0001oooooo1?l0
000Aooooo`;o0000L?ooool000Wooooo1?l000000ol@413oooooooooo`0Fooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Fooooo`03o`000?oooooooooo017ooooo0_l0
0005ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2o`0000Cooooo1Ol00004ooooo`03odA4
A?l0003o000000;o00003oooool00oo^k^ko<S8bo`000003o`0000Cooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`Co000000?o410@
ooooooooool04_ooool000_ooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool03_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oo
oooo00?oMgMgoc8b<_ooool01?ooool2o`0000oooooo00?o0000ooooooooool06?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_l00004ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool2
o`0000oooooo00CoMgMgoiRHV?ooooooV9RH0_l00004ooooo`;o8B4Q2?ooool00omgMgOo<S8boooo
o`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool0
1oooool00omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo0006o`0000Gooooo00?o
0000ooooooooool04?ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVY
ZOmEEEGooooo00Sooooo00?o0000ooooooooool01Oooool6o`0000;ooooo00Go410@oooooooooooo
oooooa0@400@ooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00onHV9So8B4Qonk^kP05ooooo`;o00000_ooool00ol0003oooooooooo`03oooo
o`;o00003oooool00ol0003oooooooooo`06ooooo`;o00004?ooool01Ol@413o0000o`000?oooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`0=ooooo`05oa0@4?l0003o
0000ooooool@41004?ooool00ol0003oooooooooo`0=ooooo`05oa0@4?ooooooooooooooool@4100
3Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
5?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000kooooo
00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool0
00003oooool00omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003Oooool00onH
V9So8B4Qonk^kP04ooooo`;o000000?oooooogMgMolb<S805_ooool00ol0003oooooooooo`06oooo
o`;o00004?ooool3o`000003ooooool0003ooooo00Cooooo0_l00006ooooo`03oiRHV?lQ8B7ok^k^
00Oooooo0_l0000?ooooo`?o000000?oooooo`000?ooool03_ooool00omgMgOo<S8booooo`0>oooo
o`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;o
oooo01Wooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol0
003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`03oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<01Kooooo00?o0000ooooooooool06?ooool3o`000003ooooool0003o
oooo00Cooooo0_l00007ooooo`03ogMgMomVIVKooooo00?ooooo00?o0000ob4Q8Ol000000_l0000?
ooooo`03o`000?oooooooooo00;o00003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go
0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c00Jooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo
00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000oooooooo
ool04Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04Oooool01Ol@
413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0H
ooooo`?o00006?ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0Aooooo`03oa0@4?oooooooooo00;o00003?ooool00ol0003ooooooooo
o`0Aooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03
o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo
017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`06o`000?nj^[[ooooooiRHV?l@413ooooo
0_l000000ooooooo0000ooooo`0Iooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool2o`0001;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo01Cooooo0009ooooo`03oeEEEOmVIVKo000001[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`Go00001?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co
00004?ooool01?o^k^ko<S8bo`000?lb<S82o`0000[ooooo00KoV9RHoa0@4?l0003o8B4Qolc<c?oo
ool2o`000003ooooool0003o000000;o00005oooool00ol0003oooooooooo`0Hooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0000@ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`Go00001?ooool4o`0001Wooooo00?oEEEEofIVI_l000005_ooool007cooooo0_l0000^oooo
o`03o`000?oooooooooo01[ooooo0_l0000]ooooo`;o0000K_ooool00:cooooo00?o0000oooooooo
ool06_ooool2o`0002gooooo0_l0001^ooooo`00POooool2o`0002Wooooo00?o0000ooooooooool0
A_ooool2o`0006Kooooo0_l00002ooooo`;o00001Oooool0087ooooo0_l00003ooooo`;o00009?oo
ool00ol0003oooooooooo`0Aooooo`;o00004?ooool2o`00027ooooo1?l0001Tooooo`06onk^k_lQ
8B7oQhN7okZj^_l0003ogMgM1Oooool008;ooooo0_l00002ooooo`;o00009?ooool00ol0003ooooo
ooooo`0Aooooo`;o00004?ooool2o`0002?ooooo0ol0001Tooooo`04omgMgOl0003o410@olc<c0Ko
oooo0007oooooooo0000C?l0000<ooooo`04onk^k_lQ8B7o410@onk^kPKooooo0007ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o0000
0_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_l00003ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00_ooool4o`0000Oooooo00?o0000ooooooooool01Oooool2o`000003oooo
ool0003o000000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`04ob4Q
8OmgMgOoMgMgoc8b<PKooooo0007ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Gooooo0_l0000Oooooo`03o`00
0?oooooooooo01Wooooo0_l00008ooooo`;o00000_ooool00ol0003oooooooooo`0:ooooo`?o0000
4?ooool2o`000003ooooool0003o000000Cooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo00Wooooo0_l00002ooooo`;o00001Oooool0087ooooo0_l0
0008ooooo`;o00007oooool00ol0003oooooooooo`0Uooooo`;o00008?ooool2o`000003ooooool0
003o000006gooooo0021ooooo`;o0000:Oooool00ol0003oooooooooo`0;ooooo`;o00006?ooool2
o`00023ooooo0_l000000ooooooo0000o`00001]ooooo`00S_ooool2o`0000Gooooo0_l0000Eoooo
o`03o`000?oooooooooo00_ooooo0_l0000jooooo`;o000000?oooooo`000?l00000KOooool008[o
oooo0_l00002ooooo`;o00001Oooool2o`0001Gooooo00?o0000ooooooooool00_ooool2o`0004Ko
oooo0_l0001]ooooo`00R_ooool2o`00023ooooo00?o0000ooooooooool00_ooool2o`0000;ooooo
0_l0002aooooo`00[?ooool3o`0000Kooooo0_l00003ooooo`;o00001?ooool2o`0003Cooooo0_l0
00000ooooooo0000o`00001]ooooo`00Q_ooool2o`0000kooooo0_l0000Dooooo`03o`000?oooooo
oooo00_ooooo0_l00004ooooo`;o00004Oooool2o`00027ooooo0_l000000ooooooo0000o`00001]
ooooo`00Q_ooool2o`0000kooooo0_l0000Dooooo`03o`000?oooooooooo01[ooooo0_l00008oooo
o`;o0000Toooool0097ooooo0_l0000Iooooo`03o`000?oooooooooo01[ooooo0_l0002Mooooo`00
TOooool2o`0001Wooooo00?o0000ooooooooool01Oooool2o`0000[ooooo0_l0002Vooooo`00[?oo
ool00ol0003oooooooooo`05ooooo`;o00002_ooool2o`00017ooooo0ol0002Booooo`00[?ooool0
0ol0003oooooooooo`0Tooooo`?o00009?ooool2o`0006cooooo002/ooooo`03o`000?oooooooooo
03Cooooo0_l0000Eooooo`;o0000K?ooool00:cooooo00?o0000ooooooooool0=?ooool2o`0008?o
oooo002>ooooo`;o00007?ooool3o`0003Cooooo0_l0000Eooooo`;o0000K?ooool008kooooo0_l0
000Looooo`03o`000?oooooooooo03Cooooo0_l0000Eooooo`;o0000K?ooool00:cooooo00?o0000
ooooooooool0=?ooool2o`0008?ooooo002/ooooo`03o`000?oooooooooo00_ooooo0_l0000Woooo
o`;o00005Oooool2o`0006cooooo002/ooooo`03o`000?oooooooooo00_ooooo0_l0000nooooo`;o
0000K?ooool009;ooooo0_l0000Hooooo`03o`000?oooooooooo01Wooooo0_l0002Nooooo`00T_oo
ool2o`0001Sooooo00?o0000ooooooooool06Oooool2o`0009kooooo002/ooooo`03o`000?oooooo
oooo00Gooooo0_l0000Aooooo`?o00005_ooool2o`0001Cooooo0_l0001`ooooo`00[?ooool3o`00
00Gooooo0_l0000Aooooo`;o00005oooool2o`0001Cooooo0_l0001`ooooo`00O?ooool2o`0002ko
oooo00?o0000ooooooooool03oooool3o`000:Oooooo001looooo`;o00006Oooool2o`0001?ooooo
00?o0000ooooooooool03oooool3o`000:Oooooo002Gooooo`;o00004oooool00ol0003ooooooooo
o`02o`0004Gooooo1?l0001^ooooo`00T_ooool2o`0001Sooooo00?o0000ooooooooool00_l0000Q
ooooo`;o00008_ooool4o`0006kooooo002Booooo`;o00006?ooool00ol0003oooooooooo`0Hoooo
o`;o00002Oooool2o`0002?ooooo0_l0001_ooooo`00[?ooool00ol0003oooooooooo`09ooooo`;o
00001?ooool2o`0000Oooooo0_l0002Oooooo`00[?ooool00ol0003oooooooooo`09ooooo`;o0000
1?ooool2o`000:Sooooo002/ooooo`?o00002Oooool2o`0000cooooo0_l0000^ooooo`;o0000L?oo
ool008Sooooo0_l0000Rooooo`03o`000?oooooooooo00Wooooo0_l0000<ooooo`;o0000;_ooool2
o`00073ooooo0028ooooo`;o00008_ooool00ol0003oooooooooo`15ooooo`;o0000L_ooool00:co
oooo00?o0000ooooooooool08_ooool2o`00027ooooo0_l0001booooo`00[?ooool00ol0003ooooo
ooooo`08ooooo`;o00000oooool2o`0001?ooooo0_l0002Eooooo`00[?ooool00ol0003ooooooooo
o`08ooooo`;o00000oooool2o`000:[ooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`02ooooo`;o0000@?ooool2o`0007?ooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool00_ooool2o`0000Wooooo0_l00007ooooo`;o0000;?ooool2o`0007?o
oooo0029ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03
o`000?oooooooooo00?ooooo0ol000001?oooooo0000o`000?l00009ooooo`;o00001oooool2o`00
0:7ooooo0029ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07oooo
o`04ogMgMolb<S;oooooooooo`;o000000?oooooo`000?ooool00_ooool3o`0004?ooooo0_l0001`
ooooo`00ROooool01Ol0003ooooooooooooooooo000000Wooooo0_l00003ooooo`03ogMgMomVIVKo
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`;o000000?oooooo`000?ooool0Aooo
ool3o`00073ooooo0029ooooo`05oa0@4?ooooooooooooooool@41002Oooool2o`000005ooooool0
003o0000ooooool000001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Kooooo
0_l0001aooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo0ol000000onHV9So410@
ooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0;_ooool4o`0008Oooooo
0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Co
oooo1?l00006ooooo`03o`000?oooooooooo01Gooooo0_l00008ooooo`;o00003Oooool4o`0001Co
oooo0_l0001aooooo`00Y_ooool2o`0000Cooooo00?o0000ooooooooool03?ooool2o`0000Oooooo
0_l00008ooooo`;o00003oooool3o`0001?ooooo0_l0001aooooo`00Voooool2o`0000Wooooo0_l0
0004ooooo`03o`000?oooooooooo00cooooo0_l0000Sooooo`;o0000Q_ooool009Sooooo0_l00000
0ooooooo0000o`000006ooooo`;o00001oooool00ol0003oooooooooo`0]ooooo`;o0000R_ooool0
09Sooooo0_l00009ooooo`;o00001oooool3o`0000Gooooo0_l0000Vooooo`;o0000R_ooool009So
oooo0_l0000Booooo`03o`000?oooooooooo00Gooooo0_l0002booooo`00V?ooool2o`0001;ooooo
00?o0000ooooooooool01Oooool2o`000;;ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002A
ooooo`?o00006?ooool3o`0002kooooo0_l00029ooooo`00Q?ooool2o`0000_ooooo0ol0000Hoooo
o`?o0000;Oooool3o`0008Wooooo0024ooooo`;o00009_ooool3o`0001cooooo0_l0000?ooooo`;o
0000R_ooool00:cooooo00?o0000ooooooooool07?ooool2o`0009_ooooo002Cooooo`;o00005ooo
ool3o`0002[ooooo0_l0002=ooooo`00Toooool2o`0001Oooooo00?o0000ooooooooool04Oooool2
o`0000Wooooo0_l0000<ooooo`;o0000SOooool00:?ooooo0_l00007ooooo`03o`000?oooooooooo
00oooooo1?l00008ooooo`?o0000Voooool007oooooo0_l0000Rooooo`;o00001oooool00ol0003o
ooooooooo`0?ooooo`;o00002_ooool2o`0009cooooo001oooooo`;o0000:oooool00ol0003ooooo
ooooo`08ooooo`;o00001Oooool2o`0002kooooo0ol0001gooooo`00[?ooool00ol0003ooooooooo
o`08ooooo`;o0000=Oooool4o`0007Kooooo002Dooooo`;o00005_ooool01?l0003oooooo`000?l0
0010ooooo`;o0000M_ooool009Cooooo0_l0000Cooooo`;o000000?oooooo`000?ooool00_l0000J
ooooo`;o0000W?ooool00:Wooooo0_l000001?oooooo0000o`000?l00005ooooo`?o00004oooool2
o`0000_ooooo0_l0002?ooooo`00Woooool2o`0000_ooooo00?o0000ooooooooool01Oooool3o`00
01?ooooo0_l0000;ooooo`;o0000Soooool009Wooooo0_l00004ooooo`;o00002oooool00ol0003o
ooooooooo`2iooooo`00VOooool2o`00017ooooo00?o0000ooooooooool0^Oooool009Gooooo0_l0
000<ooooo`;o00001oooool00ol0003oooooooooo`0Yooooo`;o0000S_ooool009Gooooo0_l0000;
ooooo`?o00001oooool00ol0003oooooooooo`0<ooooo`;o00006oooool2o`0008kooooo002Aoooo
o`;o00000_ooool2o`0000_ooooo0_l00007ooooo`;o00003_ooool2o`000:_ooooo002@ooooo`?o
00000_ooool2o`0001Cooooo0_l00004ooooo`;o00008oooool2o`00093ooooo002@ooooo`?o0000
6Oooool3o`0000;ooooo0_l0000Sooooo`;o0000T?ooool0097ooooo0_l0000Hooooo`;o0000@?oo
ool2o`0007Wooooo002Aooooo`;o00005oooool3o`0000cooooo0_l00009ooooo`;o00009oooool2
o`0007Wooooo0027ooooo`;o00008Oooool3o`0000;ooooo0_l00008ooooo`;o00002Oooool2o`00
0:;ooooo0027ooooo`;o00008oooool00ol0003oooooooooo`02o`0003Oooooo0_l0001nooooo`00
Qoooool2o`0002?ooooo00?o0000ooooooooool02?ooool2o`0001Sooooo0_l0000Eooooo`;o0000
O_ooool008Oooooo0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@;ooooo
0_l000001_ooooooA4A4o`000?l0003o<S8bomgMg@Gooooo00Co0000ooooool0003o00001oooool2
o`0001Sooooo0_l0002Eooooo`00POooool2o`0000[ooooo0_l00002ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@;ooooo0_l00004ooooo`03ogMgMol0003o000000Cooooo00Co0000
ooooool0003o00004_ooool2o`0002Kooooo0_l0001looooo`00POooool2o`0000[ooooo0_l00002
ooooo`05oa0@4?ooooooooooooooool@41004?ooool2o`0000Cooooo00?o0000ooooooooool04ooo
ool2o`0000gooooo0_l0000Gooooo`;o0000O?ooool0097ooooo00Go0000ooooooooooooooooo`00
0002ooooo`;o00002oooool00omgMgOo<S8booooo`04ooooo`?o00008_ooool2o`0001Gooooo0_l0
001nooooo`00TOooool01Ol0003ooooooooooooooooo000000;ooooo0_l00008ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Aooooo`;o00009_ooool2o`0007kooooo
002Aooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo013ooooo0ol0000@ooooo`;o0000U?ooool0097ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04?ooool2o`000003oooo
ool0003o000000_ooooo0_l000000ooooooo0000o`00002Dooooo`00TOooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00cooooo1?l00006ooooo`03o`000?oooooooooo01?ooooo0_l0000;ooooo`;o0000
Uoooool008oooooo0_l0000Kooooo`03o`000?oooooooooo00Cooooo0_l0000:ooooo`;o0000Yooo
ool008oooooo0_l00004ooooo`;o00005Oooool00ol0003oooooooooo`04ooooo`;o00002_ooool2
o`0002Gooooo0_l00020ooooo`00UOooool2o`0001Gooooo00?o0000ooooooooool0=oooool2o`00
083ooooo002/ooooo`?o00003oooool2o`000:Sooooo002/ooooo`03o`000?oooooooooo00oooooo
0_l0000Sooooo`;o0000Poooool00:3ooooo0_l00006ooooo`;o00000_ooool00ol0003ooooooooo
o`0dooooo`;o0000Poooool0093ooooo0_l0000>ooooo`;o00000oooool2o`000003ooooool0003o
000000;ooooo00Co0000oooooooooooooooo0_l0002fooooo`00T?ooool2o`0001;ooooo0ol00005
ooooo`04o`000?ooooooooooooooo`;o00006?ooool2o`0009cooooo002Tooooo`;o00001_ooool0
0ol0003oooooooooo`0Kooooo`;o0000W?ooool00:cooooo00?o0000ooooooooool02oooool2o`00
02Gooooo0_l00025ooooo`00V?ooool2o`0001;ooooo00?o0000ooooooooool02oooool2o`0000co
oooo0_l0000Gooooo`;o0000QOooool009Sooooo0_l0000Booooo`?o00002_ooool2o`0000gooooo
0_l000000ooooooo0000o`00002Kooooo`00[?ooool00ol0003oooooooooo`0:ooooo`;o00003?oo
ool2o`0000;ooooo0_l0000Cooooo`;o0000Q_ooool00:cooooo0ol0000Hooooo`;o00005oooool2
o`0008Kooooo002;ooooo`;o00007oooool3o`000;Wooooo002;ooooo`;o00003Oooool2o`00013o
oooo00?o0000ooooooooool0^Oooool009[ooooo0_l0000@ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo02[ooooo0_l0002=
ooooo`00U?ooool2o`0001Kooooo0ol00006ooooo`;o00008_ooool2o`0008gooooo002Dooooo`;o
00002?ooool2o`0000cooooo00?o0000ooooooooool01_ooool2o`000;7ooooo002Nooooo`;o0000
0oooool2o`0000Oooooo00?o0000ooooooooool0^Oooool00:?ooooo0_l00007ooooo`03o`000?oo
oooooooo0;Wooooo002>ooooo`;o00005?ooool2o`0000Kooooo00?o0000ooooooooool0^Oooool0
08gooooo0ol0000Dooooo`;o00001_ooool00ol0003oooooooooo`0Xooooo`;o0000Soooool008go
oooo0ol0000Looooo`03o`000?oooooooooo02Oooooo0ol0002?ooooo`00[?ooool00ol0003ooooo
ooooo`0Booooo`;o00004oooool4o`0008kooooo002/ooooo`03o`000?oooooooooo013ooooo1?l0
000Eooooo`;o0000S_ooool00:cooooo0ol0000@ooooo`;o0000Yoooool00:cooooo00?o0000oooo
ooooool0^Oooool008kooooo0_l0000Looooo`;o00003oooool2o`000:Wooooo002>ooooo`;o0000
7?ooool2o`0000kooooo0ol0000Dooooo`;o0000Toooool00:cooooo0_l0000>ooooo`;o00005?oo
ool3o`0009?ooooo0028ooooo`;o000000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo00?o
0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo0_l0000>ooooo`;o0000
5?ooool2o`0009Cooooo0028ooooo`;o000000CoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Kooooo
00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00gooooo
0_l0002Zooooo`00ROooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool0
2?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo0_l0002Zooooo`00R?oo
ool2o`0000?ooooo00?o0000ooooooooool03?ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol0000<ooooo`?o0000Z_ooool008Sooooo0_l00003ooooo`03o`000?oooooo
oooo00cooooo00CoEEEEolc<c?l0003o00000_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool03?ooool2o`000:_ooooo0028ooooo`;o00000oooool00ol@413ooooooooo
o`02ooooo`;o00002?ooool01?nYZJWoMgMgo`000?l00002ooooo`03o`000?oooooooooo00;ooooo
0_l00003ooooo`03o`000?oooooooooo00[ooooo0_l0002]ooooo`00ROooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Cooooo0_l00005ooooo`05oa0@4?oooooooooooooooolb<S800_l00002ooooo`04
o`000?ooooooooooooooo`?o00000oooool00ol0003oooooooooo`07ooooo`;o000000?oooooo`00
0?l00000[Oooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool7o`00
00?ooooo00?o0000ooooooooool01oooool2o`000;3ooooo002Booooo`;o00004oooool2o`0000?o
oooo00?o0000ooooooooool0^Oooool009;ooooo0_l0000Hooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool01Oooool2o`000;;ooooo002/ooooo`03o`00
0?oooooooooo00?ooooo1?l0002booooo`00[?ooool01?l0003oooooooooooooool4o`000;Cooooo
002/ooooo`04o`000?ooooooooooooooo`;o0000]_ooool00:cooooo00Co0000oooooooooooooooo
0_l0002fooooo`00S?ooool2o`0001kooooo00?o0000ooooooooool0^Oooool008cooooo0_l00009
ooooo`;o00004oooool3o`000;Wooooo002Gooooo`Co00004Oooool4o`000;Sooooo002Iooooo`;o
00004Oooool4o`000;Sooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002Oooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`03o`000?oooooooooo0;Wo
oooo002Oooooo`;o00000_ooool2o`000003ooooool0003o000000;o00000_ooool00ol0003ooooo
ooooo`2iooooo`00YOooool3o`0000Cooooo0ol0002iooooo`00YOooool2o`0000Gooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool02?ooool2o`000:oooooo002/ooooo`03o`000?oo
oooooooo00Sooooo0_l0002_ooooo`00[?ooool00ol0003oooooooooo`06ooooo`;o0000/Oooool0
0:cooooo00?o0000ooooooooool01_ooool2o`000;7ooooo002/ooooo`?o0000^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:;ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool4o`000;Sooooo002Tooooo`03o`000?oooooooooo00Oooooo0_l0002hoooo
o`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?oo
ool00ol0003oooooooooo`31ooooo`00X_ooool00omEEEGoIVIVo`000033ooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Z_ooool01?l@413o0000o`000?l0
002jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2joooo
o`00Zoooool01_l0003oMgMgo`000?l0003oEEEEonk^k[Oooooo002[ooooo`06o`000?mEEEGok^k^
oooooomgMgOoEEEE]oooool00:_ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`2e
ooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo0;Gooooo002[ooooo`06
o`000?mEEEGok^k^oooooomgMgOoIVIV]oooool00:[ooooo00?o410@o`000?mgMgL00_l000000omV
IVKok^k^ooooo`2fooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.41815 .80599 Mdot
.42263 .1624 Mdot
.44783 .43867 Mdot
.47991 .75192 Mdot
.53496 .2696 Mdot
.60107 .68474 Mdot
.50406 .38367 Mdot
.61336 .15857 Mdot
.4621 .03087 Mdot
.55316 .3929 Mdot
.55936 .59711 Mdot
.66709 .24977 Mdot
.61017 .2561 Mdot
.56908 .49974 Mdot
.68572 .30305 Mdot
.42055 .39688 Mdot
.46544 .149 Mdot
.61691 .2687 Mdot
.4092 .57544 Mdot
.6486 .70454 Mdot
.62852 .30422 Mdot
.51795 .12527 Mdot
.56143 .19059 Mdot
.63117 .3018 Mdot
.72274 .40553 Mdot
.57784 .65135 Mdot
.52543 .70984 Mdot
.41163 .59833 Mdot
.62612 .7544 Mdot
.44236 .11803 Mdot
.64958 .37419 Mdot
.45034 .0378 Mdot
.58568 .12961 Mdot
.56222 .26883 Mdot
.61176 .38877 Mdot
.6569 .6479 Mdot
.42415 .89981 Mdot
.44377 .7592 Mdot
.58332 .82376 Mdot
.67668 .2617 Mdot
.72311 .38679 Mdot
.59098 .32796 Mdot
.62658 .54429 Mdot
.40752 .76819 Mdot
.47215 .89795 Mdot
.59001 .43836 Mdot
.56558 .49981 Mdot
.38252 .27075 Mdot
.45938 .83881 Mdot
.61868 .76069 Mdot
.38212 .27729 Mdot
.54818 .8824 Mdot
.36082 .31653 Mdot
.62453 .48049 Mdot
.6282 .47962 Mdot
.52862 .06694 Mdot
.62469 .17668 Mdot
.4548 .15641 Mdot
.37297 .60037 Mdot
.49282 .88883 Mdot
.59336 .47933 Mdot
.72468 .65939 Mdot
.5704 .8414 Mdot
.50872 .31067 Mdot
.59614 .15242 Mdot
.48624 .02471 Mdot
.54889 .37944 Mdot
.41785 .45467 Mdot
.4466 .76899 Mdot
.64698 .34602 Mdot
.47432 .13795 Mdot
.50082 .6473 Mdot
.55728 .42028 Mdot
.51895 .29276 Mdot
.57047 .8412 Mdot
.50764 .46354 Mdot
.36111 .31302 Mdot
.5861 .58392 Mdot
.57183 .84874 Mdot
.46546 .83306 Mdot
.67139 .50039 Mdot
.43791 .12807 Mdot
.50115 .7201 Mdot
.59577 .33823 Mdot
.56878 .10403 Mdot
.4204 .38653 Mdot
.54298 .28629 Mdot
.57181 .3734 Mdot
.42149 .23765 Mdot
.41974 .42091 Mdot
.72428 .41792 Mdot
.54546 .45063 Mdot
.57961 .39102 Mdot
.53843 .41106 Mdot
.53993 .97641 Mdot
.56847 .4875 Mdot
.39449 .20043 Mdot
.36799 .24139 Mdot
.41965 .24118 Mdot
.39583 .68402 Mdot
.39761 .426 Mdot
.6688 .25825 Mdot
.39031 .64184 Mdot
.66837 .43503 Mdot
.57402 .29333 Mdot
.50581 .16453 Mdot
.40832 .42749 Mdot
.54595 .45408 Mdot
.64979 .35843 Mdot
.56389 .44136 Mdot
.4944 .73904 Mdot
.44639 .04346 Mdot
.66332 .64637 Mdot
.57786 .03224 Mdot
.52639 .4251 Mdot
.59309 .52937 Mdot
.50055 .0301 Mdot
.47495 .01945 Mdot
.42171 .8882 Mdot
.61075 .25927 Mdot
.73933 .59435 Mdot
.61126 .27786 Mdot
.62493 .75957 Mdot
.64962 .35555 Mdot
.45364 .73501 Mdot
.65231 .68066 Mdot
.58443 .92367 Mdot
.39729 .30085 Mdot
.51556 .63273 Mdot
.55271 .17357 Mdot
.38547 .50603 Mdot
.68916 .29639 Mdot
.60069 .69184 Mdot
.62177 .59467 Mdot
.59814 .80964 Mdot
.46459 .96061 Mdot
.63657 .72636 Mdot
.55559 .41309 Mdot
.61732 .17511 Mdot
.68894 .30668 Mdot
.67816 .77035 Mdot
.53977 .60353 Mdot
.4276 .7135 Mdot
.46496 .14876 Mdot
.65762 .67456 Mdot
.54335 .07509 Mdot
.65901 .12031 Mdot
.42617 .29229 Mdot
.57919 .40049 Mdot
.74816 .5443 Mdot
.39593 .50927 Mdot
.5002 .77301 Mdot
.63302 .30359 Mdot
.51057 .6075 Mdot
.55047 .7924 Mdot
.48611 .95583 Mdot
.56401 .85457 Mdot
.50683 .03886 Mdot
.41921 .8849 Mdot
.48127 .95875 Mdot
.53926 .75369 Mdot
.57653 .84384 Mdot
.71864 .35078 Mdot
.66564 .59794 Mdot
.62275 .5553 Mdot
.39807 .69572 Mdot
.5368 .0688 Mdot
.67329 .46208 Mdot
.45552 .78321 Mdot
.4996 .9483 Mdot
.63112 .72651 Mdot
.5456 .51942 Mdot
.47764 .79194 Mdot
.5484 .3039 Mdot
.4381 .24356 Mdot
.59735 .14894 Mdot
.55344 .96069 Mdot
.555 .78313 Mdot
.52425 .42523 Mdot
.61143 .77929 Mdot
.53307 .90749 Mdot
.69569 .30294 Mdot
.47363 .22866 Mdot
.72682 .40004 Mdot
.46006 .70976 Mdot
.4567 .037 Mdot
.58351 .92284 Mdot
.43205 .06274 Mdot
.71431 .34121 Mdot
.62614 .56708 Mdot
.74307 .55158 Mdot
.65872 .67248 Mdot
.47326 .26602 Mdot
.72642 .64227 Mdot
.59172 .13192 Mdot
.73848 .43927 Mdot
.6777 .27364 Mdot
.57298 .36871 Mdot
.54631 .22521 Mdot
.49561 .32127 Mdot
.50133 .33597 Mdot
.49025 .67551 Mdot
.53177 .2675 Mdot
.41469 .96309 Mdot
.38797 .58341 Mdot
.4267 .43281 Mdot
.58586 .7236 Mdot
.50605 .71739 Mdot
.43531 .64118 Mdot
.55848 .60787 Mdot
.56819 .18658 Mdot
.58873 .56605 Mdot
.6735 .46579 Mdot
.45729 .24496 Mdot
.39346 .65447 Mdot
.59014 .53879 Mdot
.72086 .35981 Mdot
.46204 .71592 Mdot
.50006 .8752 Mdot
.66171 .23295 Mdot
.59371 .51487 Mdot
.37112 .48586 Mdot
.67083 .43961 Mdot
.67046 .53963 Mdot
.43882 .2938 Mdot
.49033 .19526 Mdot
.40001 .26085 Mdot
.5466 .49497 Mdot
.68708 .3054 Mdot
.7399 .60396 Mdot
.4188 .57404 Mdot
.43822 .50279 Mdot
.39972 .91417 Mdot
.406 .65622 Mdot
.53394 .69186 Mdot
.74009 .57731 Mdot
.46151 .78746 Mdot
.38519 .55879 Mdot
.60375 .2565 Mdot
.38683 .56802 Mdot
.72251 .6633 Mdot
.61891 .62362 Mdot
.67813 .5109 Mdot
.47318 .13816 Mdot
.44749 .03843 Mdot
.53337 .39285 Mdot
.48478 .95229 Mdot
.41133 .30201 Mdot
.46754 .13981 Mdot
.57148 .84169 Mdot
.73589 .43163 Mdot
.52495 .41795 Mdot
.4775 .26849 Mdot
.45688 .94742 Mdot
.56789 .67659 Mdot
.48449 .78796 Mdot
.63205 .50036 Mdot
.5094 .4959 Mdot
.61828 .17092 Mdot
.37126 .42137 Mdot
.42867 .77751 Mdot
.53487 .68948 Mdot
.66991 .55947 Mdot
.5301 .54642 Mdot
.39659 .51994 Mdot
.43811 .85827 Mdot
.56422 .53386 Mdot
.6052 .65778 Mdot
.64554 .68534 Mdot
.53894 .74604 Mdot
.65727 .65776 Mdot
.63003 .49639 Mdot
.55103 .37988 Mdot
.44801 .8188 Mdot
.49528 .95004 Mdot
.4815 .22816 Mdot
.44243 .22382 Mdot
.39275 .2045 Mdot
.56369 .58373 Mdot
.56532 .76683 Mdot
.6001 .80191 Mdot
.5169 .63733 Mdot
.4998 .25562 Mdot
.41702 .87737 Mdot
.65656 .23453 Mdot
.40948 .40557 Mdot
.52001 .52134 Mdot
.49829 .21182 Mdot
.67448 .599 Mdot
.58466 .42236 Mdot
.66902 .47583 Mdot
.58129 .92461 Mdot
.37501 .62553 Mdot
.66889 .26545 Mdot
.37268 .56626 Mdot
.46207 .33834 Mdot
.38888 .76376 Mdot
.72796 .6225 Mdot
.67955 .55753 Mdot
.67994 .29007 Mdot
.69323 .16349 Mdot
.47183 .84092 Mdot
.63068 .56036 Mdot
.38517 .4804 Mdot
.44992 .03668 Mdot
.71964 .38365 Mdot
.56626 .52243 Mdot
.39297 .20556 Mdot
.56148 .69625 Mdot
.4583 .31728 Mdot
.56779 .18875 Mdot
.48026 .14552 Mdot
.60449 .25018 Mdot
.74781 .52704 Mdot
.53066 .46528 Mdot
.47767 .89222 Mdot
.57909 .3029 Mdot
.61192 .17407 Mdot
.53077 .55111 Mdot
.69972 .31431 Mdot
.73734 .53675 Mdot
.66771 .79859 Mdot
.42712 .64332 Mdot
.60196 .69212 Mdot
.59756 .34025 Mdot
.54673 .87668 Mdot
.49069 .19297 Mdot
.47583 .29704 Mdot
.48416 .33265 Mdot
.49127 .14742 Mdot
.64428 .20407 Mdot
.45839 .94656 Mdot
.53642 .39879 Mdot
.545 .15636 Mdot
.51198 .64847 Mdot
.48741 .67975 Mdot
.40489 .23278 Mdot
.60822 .66419 Mdot
.62276 .55688 Mdot
.53809 .75552 Mdot
.5232 .25149 Mdot
.3538 .50935 Mdot
.55632 .70524 Mdot
.42327 .16884 Mdot
.51268 .32329 Mdot
.5635 .10545 Mdot
.53284 .68939 Mdot
.64037 .71519 Mdot
.48026 .09343 Mdot
.54894 .52901 Mdot
.58899 .482 Mdot
.68164 .76445 Mdot
.66192 .23822 Mdot
.39489 .80148 Mdot
.65428 .66084 Mdot
.49535 .82919 Mdot
.54332 .2236 Mdot
.63802 .71127 Mdot
.39983 .59285 Mdot
.66177 .23874 Mdot
.66864 .80254 Mdot
.67836 .52077 Mdot
.6874 .29396 Mdot
.70337 .3237 Mdot
.72634 .38598 Mdot
.46036 .6792 Mdot
.41907 .73677 Mdot
.69077 .31265 Mdot
.61959 .17089 Mdot
.45284 .66419 Mdot
.66478 .43596 Mdot
.54924 .71746 Mdot
.58761 .72304 Mdot
.40147 .72505 Mdot
.40849 .13712 Mdot
.38554 .56515 Mdot
.40297 .83203 Mdot
.49609 .93999 Mdot
.55342 .17925 Mdot
.41372 .87893 Mdot
.54638 .16585 Mdot
.7144 .37395 Mdot
.60891 .06287 Mdot
.39933 .80645 Mdot
.54593 .80366 Mdot
.51266 .58987 Mdot
.73727 .48754 Mdot
.41171 .28449 Mdot
.47785 .32892 Mdot
.69916 .30775 Mdot
.64917 .35264 Mdot
.46916 .29812 Mdot
.53125 .3237 Mdot
.58663 .60572 Mdot
.52268 .72028 Mdot
.38905 .222 Mdot
.67419 .44104 Mdot
.72583 .63876 Mdot
.69898 .31021 Mdot
.52598 .20064 Mdot
.35584 .57891 Mdot
.53805 .21772 Mdot
.43117 .26613 Mdot
.44881 .21393 Mdot
.46655 .65572 Mdot
.63915 .19817 Mdot
.66463 .24585 Mdot
.52893 .7011 Mdot
.54728 .53243 Mdot
.54263 .67742 Mdot
.43778 .28658 Mdot
.74487 .49158 Mdot
.57418 .3668 Mdot
.66865 .58794 Mdot
.52938 .64331 Mdot
.49279 .78409 Mdot
.52704 .57824 Mdot
.56141 .33044 Mdot
.55057 .24654 Mdot
.52322 .72361 Mdot
.43087 .38724 Mdot
.74416 .56993 Mdot
.6137 .16929 Mdot
.47276 .62394 Mdot
.61659 .40803 Mdot
.50647 .16566 Mdot
.51532 .84753 Mdot
.5368 .74593 Mdot
.47105 .79379 Mdot
.73913 .48749 Mdot
.38486 .45809 Mdot
.39859 .7186 Mdot
.44015 .32971 Mdot
.49334 .03567 Mdot
.69542 .32515 Mdot
.55338 .62247 Mdot
.48531 .09657 Mdot
.35422 .45395 Mdot
.5454 .55531 Mdot
.44887 .3366 Mdot
.45703 .20536 Mdot
.67171 .54921 Mdot
.49239 .82635 Mdot
.44514 .67851 Mdot
.61898 .43819 Mdot
.58552 .31031 Mdot
.52667 .36022 Mdot
.52976 .46487 Mdot
.50347 .25671 Mdot
.61537 .162 Mdot
.53318 .49907 Mdot
.58674 .82661 Mdot
.40081 .26027 Mdot
.46938 .89481 Mdot
.65574 .66733 Mdot
.66519 .44807 Mdot
.50306 .16533 Mdot
.59621 .91262 Mdot
.53642 .33742 Mdot
.64779 .20926 Mdot
.73592 .42644 Mdot
.56318 .54146 Mdot
.39092 .7779 Mdot
.53737 .74686 Mdot
.44912 .16997 Mdot
.64318 .70889 Mdot
.39626 .68954 Mdot
.40705 .50223 Mdot
.58945 .48416 Mdot
.55855 .25944 Mdot
.73198 .64514 Mdot
.6191 .59839 Mdot
.50476 .43258 Mdot
.62543 .52974 Mdot
.4632 .8332 Mdot
.46847 .68952 Mdot
.42001 .574 Mdot
.624 .46862 Mdot
.6259 .57573 Mdot
.51398 .37323 Mdot
.57447 .65154 Mdot
.49042 .02695 Mdot
.5264 .2509 Mdot
.45496 .88249 Mdot
.44478 .76986 Mdot
.41 .5611 Mdot
.43469 .57332 Mdot
.55849 .01149 Mdot
.43201 .52999 Mdot
.41323 .19509 Mdot
.37309 .42064 Mdot
.66571 .60286 Mdot
.43622 .74286 Mdot
.62703 .7479 Mdot
.6862 .28409 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0@ooooo`;o0000Yoooool00:;ooooo00?oEEEEofIV
I_l000001oooool00ol0003oooooooooo`0@ooooo`;o0000Yoooool00:?ooooo0_l00007ooooo`03
o`000?oooooooooo0;Wooooo002Sooooo`;o00001oooool00ol0003oooooooooo`2iooooo`00Yooo
ool2o`0000?ooooo0ol0002iooooo`00Yoooool3o`0000;ooooo00?o0000ooooooooool0^Oooool0
09oooooo0_l00007ooooo`;o00000_ooool2o`000;[ooooo002Oooooo`;o00002oooool2o`0001Oo
oooo0_l0002Qooooo`00Voooool4o`0000[ooooo0_l000000ooooooo0000ooooo`0Gooooo`;o0000
XOooool009[ooooo1Ol0000:ooooo`;o000000?oooooo`000?ooool00_l0002hooooo`00V_ooool2
o`00013ooooo00Co0000ooooool0003o0000^?ooool009[ooooo0_l0000@ooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool009Gooooo0_l0000Eooooo`03o`000?oooooooooo027ooooo0_l0002Foooo
o`00UOooool2o`0001Gooooo00?o0000ooooooooool01_ooool2o`0001Wooooo0_l0002Fooooo`00
[?ooool00ol0003oooooooooo`06ooooo`;o000000?oooooo`000?l00000[_ooool00:cooooo00?o
0000ooooooooool02Oooool2o`000:kooooo002/ooooo`?o00002oooool2o`000:cooooo002/oooo
o`03o`000?oooooooooo00_ooooo0_l0002/ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00YOooool2o`0000Gooooo00?o0000ooooooooool0^Oooool00:Go
oooo1?l00003ooooo`03o`000?oooooooooo0;Wooooo002Wooooo`;o00000oooool3o`000;Wooooo
002/ooooo`03o`000?oooooooooo01?ooooo0_l0002Tooooo`00[?ooool00ol0003oooooooooo`0B
ooooo`?o0000Y?ooool00:cooooo00?o0000ooooooooool04_ooool2o`000:Gooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo0ol000000oo^k^koooooooooo`03ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2iooooo`00ROooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`;o000000?oEEEEojVYZOooool01oooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo037ooooo0_l00026ooooo`00POooool6o`0000;ooooo
00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000oooooooo
ool00oooool3o`0000;ooooo0_l0000]ooooo`;o0000Q_ooool008Wooooo00Go0000oooooooooooo
ooooo`000009ooooo`;o00000oooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool00_ooool2o`000;Gooooo0029ooooo`05o`000?ooooooooooooooool0
00002Oooool2o`0000?ooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool06Oooool4o`0009cooooo0029ooooo`05oa0@4?oooooooooooooo
ool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool06Oooool4o`0009cooooo0029ooooo`04ogMgMonHV9SooooooiRHV0;o00002_ooool01Ol@
413ooooooooooooooooo<S8b00Cooooo0ol00007ooooo`03o`000?oooooooooo0;Wooooo0029oooo
o`04onk^k_lb<S;o0000oc8b<P;o00002_ooool5o`0000?ooooo1Ol00006ooooo`03o`000?oooooo
oooo0;Wooooo002Qooooo`Co00001oooool00ol0003oooooooooo`2iooooo`00YOooool2o`0000Go
oooo00?o0000ooooooooool0^Oooool00:3ooooo0_l00003ooooo`;o00000_ooool2o`000003oooo
ool0003ooooo01kooooo0_l0002Jooooo`00X?ooool2o`0000Oooooo0_l000001?oooooo0000o`00
0?l0000Looooo`?o0000V_ooool00:cooooo00?o0000ooooooooool07?ooool2o`0009_ooooo002M
ooooo`;o00003Oooool00ol0003oooooooooo`0;ooooo`;o00005Oooool2o`0009Gooooo002Moooo
o`;o00003Oooool00ol0003oooooooooo`0;ooooo`;o00005Oooool3o`0009Cooooo002Booooo`;o
00006?ooool3o`0002?ooooo0_l0000Gooooo`;o0000Noooool009;ooooo0_l0000Hooooo`Co0000
2oooool2o`0002kooooo0_l0001kooooo`00T_ooool2o`0000Oooooo0_l0000?ooooo`Co00002ooo
ool2o`0001Cooooo1?l0002Cooooo`00T_ooool2o`0000Oooooo0_l0000?ooooo`03o`000?oooooo
oooo00kooooo0_l0000Booooo`Co0000Toooool00:cooooo0ol0000>ooooo`;o00004_ooool3o`00
0003ooooool0003o0000097ooooo002/ooooo`03o`000?oooooooooo00kooooo0_l0000Cooooo`;o
000000?oooooo`000?l00000TOooool00:cooooo00?o0000ooooooooool03_ooool2o`000:Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo01?ooooo0_l0002T
ooooo`00[?ooool00ol0003oooooooooo`0Aooooo`Co0000Y?ooool008oooooo0_l0000Gooooo`;o
00000_ooool00ol0003oooooooooo`0Aooooo`;o0000Y_ooool008oooooo0_l0000Gooooo`;o0000
0_ooool00ol0003oooooooooo`0Zooooo`;o0000SOooool008Wooooo0_l0000Qooooo`?o00001Ooo
ool2o`0002?ooooo0_l0002=ooooo`00R?ooool3o`00027ooooo00?o0000ooooooooool01Oooool2
o`0002Gooooo0_l0002;ooooo`00R?ooool2o`0001?ooooo0_l0000=ooooo`03o`000?oooooooooo
02cooooo0_l0002;ooooo`00R?ooool2o`0001?ooooo0_l0000=ooooo`03o`000?oooooooooo02go
oooo0_l0002:ooooo`00Zoooool2o`0002oooooo0_l0002:ooooo`00Voooool2o`0000kooooo0_l0
002kooooo`00Voooool2o`0000oooooo00?o0000ooooooooool02Oooool2o`000:kooooo0027oooo
o`;o00008oooool00ol0003oooooooooo`09ooooo`;o0000[_ooool008Oooooo0_l0000@ooooo`;o
00004Oooool3o`0000_ooooo0ol0002[ooooo`00VOooool2o`0000Sooooo1?l00005ooooo`03o`00
0?oooooooooo00_ooooo0ol0002[ooooo`00Xoooool4o`0000Gooooo00?o0000ooooooooool0^Ooo
ool008cooooo0_l0000Nooooo`03o`000?oooooooooo033ooooo1?l00025ooooo`00S?ooool2o`00
00Cooooo0_l0000Hooooo`03o`000?oooooooooo033ooooo1?l00025ooooo`00T_ooool2o`0001So
oooo00?o0000ooooooooool0<_ooool2o`0008Gooooo0020ooooo`;o00003oooool3o`000003oc8b
<_o^k^kooooo00;o00000_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo03;ooooo0_l00025ooooo`00P?ooool2o`0000oooooo0_l000001?ooooooV9RH
ogMgMoooool2o`0000;ooooo0_lQ8B42o`0000Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`0=ooooo`;o00009?ooool2o`0008Cooooo0029ooooo`Ko00000_ooool01Ol@413ooooo
oooooooooooo410@00Oooooo0_l00007ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool03Oooool2o`0002Cooooo0ol00023ooooo`00TOooool01Ol0003ooooooooooooooooo000000oo
oooo00?oMgMgoc8b<_ooool01?ooool3o`0000Cooooo0ol0000Hooooo`;o00004oooool2o`0008?o
oooo002Aooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Cooooo0_l00006ooooo`?o00006?ooool4o`0009Kooooo002Aooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00ol0003oooooooooo`06ooooo`Co00007oooool4o`00017ooooo0_l00023oooo
o`00Roooool2o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo
00Oooooo0ol0000@ooooo`;o00003Oooool4o`00017ooooo0_l000000ooooooo0000o`000020oooo
o`00Roooool2o`0000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0
003oooooooooo`0@ooooo`;o00003oooool2o`0001Cooooo0_l00020ooooo`00UOooool2o`0000co
oooo0_l00007ooooo`03o`000?oooooooooo00Oooooo0_l0000[ooooo`;o0000Poooool008Gooooo
0_l0000>ooooo`;o00003?ooool3o`0000Kooooo00?o0000ooooooooool01oooool3o`0000Oooooo
0_l0000@ooooo`;o00003oooool2o`0008?ooooo0025ooooo`;o00007Oooool2o`0000Kooooo00?o
0000ooooooooool02?ooool2o`0000Oooooo0_l0000@ooooo`;o00004_ooool2o`00083ooooo0025
ooooo`;o00009Oooool3o`0003Oooooo0_l00020ooooo`00QOooool2o`0002Gooooo00?o0000oooo
ooooool08Oooool2o`0009Kooooo002/ooooo`03o`000?oooooooooo027ooooo0_l0002Fooooo`00
S_ooool2o`0001cooooo00?o0000ooooooooool02oooool2o`0002gooooo0_l0001mooooo`00S_oo
ool2o`0000Oooooo0_l0000Cooooo`03o`000?oooooooooo00_ooooo0_l0000]ooooo`;o0000OOoo
ool009?ooooo0_l00002ooooo`;o00004oooool00ol0003oooooooooo`0hooooo`;o0000Ooooool0
09?ooooo0_l00002ooooo`;o00004oooool00ol0003oooooooooo`03ooooo`;o00004?ooool2o`00
027ooooo1?l0001mooooo`00Uoooool2o`0000Sooooo0_l000000ooooooo0000o`000006ooooo`03
o`000?oooooooooo00?ooooo0_l0000@ooooo`;o00008oooool3o`0007cooooo002:ooooo`;o0000
5Oooool2o`000003ooooool0003o000000Kooooo0ol0000kooooo`;o0000O?ooool008[ooooo0_l0
0002ooooo`;o00007?ooool00ol0003oooooooooo`0=ooooo`;o00002?ooool2o`0000kooooo0ol0
000@ooooo`;o000000?oooooo`000?l00000N_ooool008kooooo0_l0000Looooo`03o`000?oooooo
oooo00gooooo0_l00008ooooo`;o00003_ooool3o`00013ooooo1Ol0001jooooo`00[?ooool01?l0
003oooooo`000?l0000Hooooo`;o00007oooool3o`000003ooooool0003o000007Wooooo001noooo
o`;o0000;?ooool01?l0003oooooo`000?l0000Hooooo`;o00008Oooool4o`0007Wooooo001noooo
o`;o0000;?ooool00ol0003oooooooooo`0looooo`Co0000NOooool007kooooo0_l0000Nooooo`;o
00003?ooool00ol0003oooooooooo`0nooooo`;o0000NOooool009kooooo0_l0000:ooooo`?o0000
^oooool00:[ooooo1Ol000000ooooooo0000o`000004ooooo`;o0000=?ooool2o`000003ooooool0
003o000007Oooooo002/ooooo`04o`000?ooooooooooooooo`;o00001?ooool2o`0001;ooooo0_l0
000Pooooo`;o000000?oooooo`000?l00000Moooool009Sooooo0_l0000:ooooo`;o00001_ooool0
0ol0003oooooooooo`0Aooooo`;o00002?ooool2o`0009cooooo002Hooooo`;o00002_ooool4o`00
00Cooooo00?o0000ooooooooool04Oooool2o`000:Kooooo002Kooooo`;o00002Oooool2o`0000Co
oooo0_l0000:ooooo`;o0000[_ooool009_ooooo0_l00002ooooo`;o00002oooool2o`0000[ooooo
0_l0000Aooooo`?o0000V_ooool009oooooo0_l0000;ooooo`03o`000?oooooooooo01cooooo0ol0
000Tooooo`;o0000M?ooool00:cooooo00?o0000ooooooooool0;Oooool2o`0001Cooooo0_l0001d
ooooo`00[?ooool00ol0003oooooooooo`0]ooooo`;o0000R_ooool00:cooooo0ol0000^ooooo`;o
00005Oooool2o`0007;ooooo002/ooooo`03o`000?oooooooooo02kooooo0_l0000Eooooo`;o0000
L_ooool00:cooooo00?o0000ooooooooool0;_ooool2o`0008Wooooo002/ooooo`03o`000?oooooo
oooo00Gooooo0_l0000Wooooo`;o00005Oooool2o`0007;ooooo002/ooooo`03o`000?oooooooooo
00Gooooo0_l0000nooooo`;o0000L_ooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo01Gooooo0_l0002Rooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo01Gooooo0_l0002Rooooo`00POooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool01?l0003ooooooooo
ooooool2o`00017ooooo0ol0000Gooooo`;o00004oooool2o`0007Cooooo0029ooooo`05o`000?oo
ooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo
0ol000000ooooooo0000o`00000Aooooo`;o00006?ooool2o`0001?ooooo0_l0001dooooo`00ROoo
ool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool03Oooool2o`000:[ooooo0029ooooo`05oa0@
4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool03Oooool2o`000:[ooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool3o`00
04Gooooo1?l0001`ooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo0_l00002oooo
o`;o00000_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`?o00008Oooool2
o`0002;ooooo1?l0001`ooooo`00TOooool2o`0000;ooooo0_l0000Eooooo`03o`000?oooooooooo
01Oooooo0_l00008ooooo`;o00008oooool2o`00077ooooo002/ooooo`03o`000?oooooooooo00So
oooo0_l00004ooooo`;o00001oooool2o`000:3ooooo002Aooooo`;o00006Oooool00ol0003ooooo
ooooo`08ooooo`;o00001?ooool2o`000:Wooooo002Aooooo`;o00006Oooool3o`0000Wooooo0_l0
000<ooooo`;o0000;_ooool2o`00073ooooo002/ooooo`03o`000?oooooooooo00Wooooo0_l0000<
ooooo`;o0000;_ooool2o`00073ooooo002>ooooo`;o00007?ooool00ol0003oooooooooo`16oooo
o`;o0000LOooool008kooooo0_l0000Looooo`03o`000?oooooooooo02?ooooo0_l0000Qooooo`;o
0000LOooool00:cooooo00?o0000ooooooooool02Oooool2o`0000Cooooo0_l0000Booooo`;o0000
U?ooool00:cooooo00?o0000ooooooooool02Oooool2o`0000Cooooo0_l0002Xooooo`00[?ooool0
0ol0003oooooooooo`05ooooo`;o0000@?ooool2o`00073ooooo0021ooooo`?o00003Oooool2o`00
01Wooooo00?o0000ooooooooool01Oooool2o`0000Sooooo0_l00008ooooo`;o0000;?ooool2o`00
073ooooo0021ooooo`?o00003Oooool2o`0001Wooooo0ol00005ooooo`;o00002?ooool2o`0000So
oooo0_l0002Nooooo`00R_ooool2o`000003ooooool0003o000001gooooo00?o0000ooooooooool0
1Oooool2o`0004?ooooo0_l0001]ooooo`00R_ooool2o`000003ooooool0003o000001gooooo00?o
0000ooooooooool0B_ooool2o`0006gooooo002Cooooo`;o00005oooool3o`0004[ooooo0_l0001]
ooooo`00Toooool2o`0001Oooooo0ol0000cooooo`?o0000Poooool009[ooooo0_l0000@ooooo`03
o`000?oooooooooo01[ooooo0_l00008ooooo`;o00003Oooool4o`0001Cooooo0_l0001/ooooo`00
V_ooool2o`00013ooooo00?o0000ooooooooool04_ooool2o`0000Kooooo0_l00008ooooo`;o0000
3oooool3o`0001?ooooo0_l0001/ooooo`00[?ooool00ol0003oooooooooo`0Booooo`;o00008_oo
ool2o`00087ooooo002/ooooo`03o`000?oooooooooo03?ooooo0_l00024ooooo`00[?ooool3o`00
00cooooo0_l0000Uooooo`;o0000Q?ooool007_ooooo0_l0000Cooooo`;o00006_ooool00ol0003o
ooooooooo`0<ooooo`;o0000Zoooool007_ooooo0_l00009ooooo`;o00002?ooool2o`0001[ooooo
00?o0000ooooooooool03?ooool2o`000:_ooooo0009ooooo`Co000000?o410@ooooooooool05_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo
00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@;ooooo1ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd05_ooool00ol0003ooooo
ooooo`0Hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05
odA4A?l0003o0000oc8b<_oMgMd00_l0000=ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM01So
oooo1?l000000ol@413oooooooooo`0Booooo`002oooool00ol0003oooooooooo`0Hooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo
<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01oooool00omgMgOo<S8booooo`0Eooooo`04o`000?oooooo0000o`0000Gooooo
0_l0000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A007ooooo`04ogMgMolb<S;o0000o`0000gooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`0Iooooo`03o`00
0?oooooooooo01Cooooo0006o`0000Gooooo00?o0000ooooooooool04?ooool6o`0000;ooooo00Go
410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool0
1Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00Go
oooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09oooo
o`03o`000?oooooooooo01Cooooo00Co0000ooooool0003o00001Oooool3o`0000oooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo0ol0000=ooooo`05oa0@4?oo
ooooooooooooool@41004?ooool00ol0003oooooooooo`0=ooooo`05oa0@4?ooooooooooooooool@
41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000ko
oooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`0>ooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003Oooool0
0onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo01Gooooo00?o0000ooooooooool01oooool2
o`0000oooooo00Go0000ooooooooooooooooo`000008ooooo`;o00000oooool00onHV9So8B4Qonk^
kP07ooooo`04ogMgMolb<S;o0000o`0000gooooo00Go0000ooooooooooooooooo`00000?ooooo`03
ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo
00Kooooo00?oMgMgoc8b<_ooool06Oooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003o
ooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOo
IVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05_ooool00ol0003oooooooooo`0Hoooo
o`05o`000?ooooooooooooooool000002?ooool2o`0000Cooooo00?oMgMgofIVI_ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<
c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[ooooo00?o0000ooooooooool05?ooool0
00_ooooo00?o0000ooooooooool06?ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo01Sooooo0ol0000Hooooo`05oa0@4?ooooooooooooooool@
41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o00003oooool01Ol@413o
oooooooooooooooo410@00cooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo
410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0Hooooo`03ogMgMonHV9Sooooo00;o00002_ooool2o`000004okZj^_ooooooV9RH
oa0@40Cooooo00?o0000ooooooooool00_l0000?ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooo
oooooooooooo<S8b00Cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Dooooo`00
2Oooool00omEEEGoIVIVo`00000Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Co
oooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00013ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP09ooooo`;o000000GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00005ooo
ool00ol0003oooooooooo`0Hooooo`03onk^k_lb<S;o000000;o00002Oooool3o`000004oa0@4?l0
003o8B4Qolc<c0Cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00013o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0001Wooooo00?oEEEEofIV
I_l000005_ooool0087ooooo0_l00003ooooo`;o00009?ooool00ol0003oooooooooo`0Jooooo`;o
00002_ooool2o`00097ooooo0021ooooo`;o0000:Oooool00ol0003oooooooooo`0Cooooo`;o0000
1Oooool2o`0002oooooo0ol0001[ooooo`00[?ooool00ol0003oooooooooo`0Cooooo`;o0000=_oo
ool4o`0005oooooo0_l00002ooooo`;o00001Oooool00:cooooo00?o0000ooooooooool03?ooool2
o`0003oooooo0_l0001Oooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1Oooool00:cooooo00?o
0000ooooooooool00_l0000:ooooo`;o00006Oooool2o`0008Kooooo00CogMgMo`000?l@413oc<c<
1_ooool000Ooooooool0001<o`0000cooooo00Cok^k^ob4Q8Ol@413ok^k^1_ooool000Oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool01?l0003oooooo`000?l00005ooooo`03o`000?oooooooooo00;o0000
0oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool01?l0003oooooo`000?l00004ooooo`04o`000?ooooooooooooooo`?o000000?oooooo`00
0?ooool01_ooool00ol0003oooooooooo`06ooooo`?o00001Oooool00ol0003oooooooooo`03oooo
o`?o00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0:ooooo`04ob4Q8OmgMgOoMgMgoc8b<PKooooo0007oooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo00;o00001Oooool2o`0000Sooooo0_l0000Cooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool02Oooool2o`0000;ooooo0_l00005ooooo`00Noooool2o`0000Wo
oooo0_l000000ooooooo0000o`00000Qooooo`03o`000?oooooooooo0;Wooooo001kooooo`;o0000
3?ooool2o`00027ooooo00?o0000ooooooooool0=oooool2o`00083ooooo002/ooooo`03o`000?oo
oooooooo01_ooooo0_l0000Jooooo`;o0000P?ooool00:cooooo00?o0000ooooooooool03?ooool2
o`0000gooooo0_l0002Looooo`00ROooool2o`00027ooooo00?o0000ooooooooool00oooool2o`00
00Oooooo0_l00004ooooo`;o00008oooool2o`00083ooooo0029ooooo`;o00008Oooool3o`0000?o
oooo0_l0000=ooooo`;o00008oooool2o`00083ooooo002/ooooo`03o`000?oooooooooo04kooooo
0_l0001Yooooo`00UOooool2o`0001Gooooo00?o0000ooooooooool03Oooool2o`0000cooooo0_l0
0009ooooo`;o00009_ooool2o`0006Wooooo002Eooooo`;o00005Oooool00ol0003oooooooooo`0<
ooooo`?o00000oooool2o`0000Oooooo0_l00009ooooo`;o0000TOooool00:cooooo00?o0000oooo
ooooool03?ooool2o`0000Cooooo0_l0000gooooo`;o0000K?ooool00:cooooo00?o0000oooooooo
ool06_ooool2o`0001Wooooo0_l0000Dooooo`;o0000K?ooool00:cooooo00?o0000ooooooooool0
4Oooool2o`0000Oooooo0_l0000Iooooo`;o0000P_ooool00:cooooo00?o0000ooooooooool01_oo
ool2o`0000Wooooo0_l0000Cooooo`;o00009_ooool2o`0006Wooooo002/ooooo`03o`000?oooooo
oooo00Kooooo0_l0000Nooooo`;o00003Oooool2o`0001Oooooo0_l0001Yooooo`00[?ooool3o`00
00Oooooo0_l0000/ooooo`;o00005_ooool2o`0006[ooooo002/ooooo`03o`000?oooooooooo00Oo
oooo0_l00003ooooo`;o00005oooool2o`0002Kooooo0_l0001Zooooo`00Q_ooool2o`0002Cooooo
00?o0000ooooooooool03?ooool2o`0001Oooooo0_l0000Aooooo`;o0000Ooooool008Kooooo0_l0
0006ooooo`;o00007?ooool00ol0003oooooooooo`0Uooooo`;o000000?oooooo`000?l000002ooo
ool2o`000003ooooool0003o000007oooooo002>ooooo`;o00007?ooool00ol0003oooooooooo`0X
ooooo`;o00002oooool2o`0008;ooooo0022ooooo`;o00000_ooool2o`0002Cooooo00?o0000oooo
ooooool06_ooool2o`0000[ooooo0_l0002Aooooo`00P_ooool2o`0000;ooooo0_l0000Tooooo`03
o`000?oooooooooo01[ooooo0_l0000:ooooo`;o00009Oooool2o`0006[ooooo002Aooooo`;o0000
0oooool2o`0001Cooooo00?o0000ooooooooool0COooool2o`0006[ooooo002>ooooo`;o000000?o
ooooo`000?l000000oooool2o`0001Cooooo0ol0000Vooooo`;o0000TOooool007cooooo0_l0000@
ooooo`;o00007?ooool00ol0003oooooooooo`05ooooo`;o00007oooool2o`0002Cooooo0_l0001[
ooooo`00O?ooool2o`0002kooooo00?o0000ooooooooool01Oooool2o`0004Gooooo0_l0001[oooo
o`00Qoooool2o`0002?ooooo00?o0000ooooooooool04_ooool2o`0000Gooooo0_l0002Nooooo`00
Qoooool2o`0002?ooooo00?o0000ooooooooool04_ooool2o`0000Gooooo0_l0000Iooooo`;o0000
Poooool00:cooooo00Co0000oooooooooooooooo0_l0000aooooo`;o0000Poooool008[ooooo0_l0
000Pooooo`04o`000?ooooooooooooooo`;o00008_ooool2o`0002Gooooo0_l0001[ooooo`00R_oo
ool2o`0000;ooooo0_l0000Looooo`03o`000?oooooooooo013ooooo0_l0000Booooo`?o00003?oo
ool2o`0001Oooooo0_l0001[ooooo`00P_ooool2o`0000[ooooo0_l0000Looooo`?o00004?ooool2
o`0001;ooooo0_l0000=ooooo`;o000000?oooooo`000?l00000POooool008;ooooo0_l0000Xoooo
o`03o`000?oooooooooo00[ooooo0_l0000Wooooo`;o000000?oooooo`000?l000005?ooool2o`00
06_ooooo002/ooooo`03o`000?oooooooooo00;o00002?ooool2o`0000gooooo0_l0000Hooooo`;o
00005oooool2o`0006_ooooo002/ooooo`03o`000?oooooooooo00;o00003_ooool2o`0000Oooooo
0_l0002Nooooo`00[?ooool00ol0003oooooooooo`0@ooooo`;o0000Yoooool00:cooooo00?o0000
ooooooooool0^Oooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;Wooooo0029
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool03_ooool2o`0003Sooooo
0_l0001_ooooo`00P_ooool2o`0000Gooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRH
V?lQ8B7ok^k^00Kooooo0_l000000ooooooo0000ooooo`04ooooo`?o00003_ooool2o`0001Cooooo
0_l0000Rooooo`;o0000Koooool008;ooooo0_l00005ooooo`05o`000?ooooooooooooooool00000
3Oooool00onHV9So8B4Qonk^kP05ooooo`;o000000?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`0Tooooo`;o0000Toooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMg
MomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;Wo
oooo0029ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool2o`000;Gooooo0029ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`02ooooo`;o0000]Oooool008Wooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000
ooooooooool00_ooool2o`0004?ooooo0_l0001`ooooo`00Qoooool2o`0000_ooooo1?l0000Doooo
o`03o`000?oooooooooo00Kooooo0_l0000oooooo`;o0000L?ooool008Oooooo0_l0000;ooooo`Co
00005?ooool00ol0003oooooooooo`06ooooo`;o0000:_ooool2o`0001?ooooo1?l0001^ooooo`00
[?ooool2o`0000;ooooo0_l0000]ooooo`Co00005Oooool2o`0006kooooo002/ooooo`?o000000?o
ooooo`000?l000004_ooool3o`0001Sooooo0_l00027ooooo`00R?ooool2o`0001Oooooo0_l00009
ooooo`03o`000?oooooooooo01Gooooo0ol0002Qooooo`00R?ooool2o`0000?ooooo0_l0000Boooo
o`;o00002Oooool00ol0003oooooooooo`0Oooooo`;o00003oooool2o`0008Oooooo002=ooooo`;o
00007Oooool00ol0003oooooooooo`0Oooooo`;o00003_ooool3o`0001Gooooo0_l0001`ooooo`00
W?ooool2o`0000kooooo00?o0000ooooooooool08?ooool2o`0000gooooo0_l0000Eooooo`?o0000
L?ooool009cooooo0_l0000>ooooo`03o`000?oooooooooo023ooooo0_l0000>ooooo`;o00005?oo
ool2o`00077ooooo002/ooooo`03o`000?oooooooooo033ooooo0_l00027ooooo`00[?ooool00ol0
003oooooooooo`0aooooo`;o0000Q_ooool00:Sooooo0_l00002ooooo`?o00004oooool2o`0001co
oooo0_l00026ooooo`00VOooool2o`0000?ooooo0_l00007ooooo`?o00000_ooool00ol0003ooooo
ooooo`0;ooooo`;o00001_ooool2o`0001cooooo0_l00026ooooo`00VOooool2o`0000?ooooo0_l0
0007ooooo`;o00000oooool00ol0003oooooooooo`0;ooooo`;o00008_ooool2o`0008Sooooo0029
ooooo`;o00008Oooool00ol0003oooooooooo`0Nooooo`;o00003Oooool4o`0008Sooooo0029oooo
o`;o00008Oooool00ol0003oooooooooo`0Nooooo`;o00003Oooool2o`0008[ooooo0029ooooo`;o
00005_ooool2o`0000Wooooo00?o0000ooooooooool01oooool3o`0001Cooooo0_l0002Iooooo`00
ROooool2o`0001Kooooo0_l00009ooooo`03o`000?oooooooooo00Oooooo0ol0000Dooooo`;o0000
VOooool008[ooooo0_l0000Pooooo`03o`000?oooooooooo017ooooo0_l0002Vooooo`00R_ooool2
o`00023ooooo0ol00006ooooo`;o00002Oooool2o`000:Kooooo002/ooooo`03o`000?oooooooooo
00Kooooo0_l0002aooooo`00[?ooool00ol0003oooooooooo`0?ooooo`;o00007Oooool2o`0008Wo
oooo002Nooooo`;o00003?ooool00ol0003oooooooooo`05ooooo`;o00002?ooool2o`0001_ooooo
1?l00029ooooo`00U?ooool2o`0000Sooooo0_l0000<ooooo`03o`000?oooooooooo00Gooooo0_l0
000Sooooo`Co0000Roooool009Cooooo0_l00009ooooo`;o00002oooool00ol0003oooooooooo`0Z
ooooo`?o0000S?ooool008[ooooo0_l0000Cooooo`;o00002oooool01?l0003oooooo`000?l0000<
ooooo`;o00007?ooool2o`0008cooooo002:ooooo`;o00008?ooool4o`0000?ooooo0_l00007oooo
o`;o0000Z_ooool008_ooooo0_l0000Oooooo`?o00001?ooool2o`0001?ooooo0_l0002Nooooo`00
Roooool2o`0001oooooo00?o0000ooooooooool01?ooool2o`0001?ooooo0_l0000=ooooo`Co0000
SOooool00:cooooo00?o0000ooooooooool0:?ooool4o`0008gooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002Aooooo`;o00002Oooool2o`0000kooooo00?o0000ooooooooool0^Oooool0097o
oooo0_l00009ooooo`;o00003?ooool3o`000;_ooooo002Aooooo`06onk^k_lb<S;o0000oc8b<_o^
k^kooooo0_l00002ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00?ooooo0ol0002k
ooooo`00TOooool01_mgMgOoV9RHoooooonHV9SoMgMgooooo`;o00000_ooool2ob4Q8@Sooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`09ooooo`;o0000[_ooool0097ooooo00Go410@
oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Ooo
ool2o`0001_ooooo0_l0002Aooooo`00TOooool01Ol0003ooooooooooooooooo000000oooooo0_l0
0005ooooo`?o00009_ooool2o`00097ooooo002Aooooo`05o`000?ooooooooooooooool000003?oo
ool00ol0003o8B4Qo`000002o`0000Gooooo00?o0000ooooooooool02Oooool3o`0001[ooooo0_l0
002Aooooo`00TOooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`09ooooo`?o00006_ooool2o`00097ooooo002Aooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool2o`0000Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Tooooo`Co0000TOooool008Oooooo0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool2o`0000Oooooo1?l00006ooooo`03o`000?oooooooooo02Cooooo1?l0000Aooooo`;o0000O_oo
ool008Oooooo0_l0000Sooooo`03o`000?oooooooooo01;ooooo0_l0000Uooooo`;o0000O_ooool0
08gooooo0_l0000:ooooo`?o00004?ooool00ol0003oooooooooo`0Booooo`;o00008oooool2o`00
083ooooo002=ooooo`;o00002_ooool3o`00013ooooo0_l0000hooooo`;o0000P?ooool00:cooooo
0ol0002iooooo`00R?ooool2o`0000[ooooo0_l0000Fooooo`03o`000?oooooooooo027ooooo0_l0
002Fooooo`00R?ooool2o`0000[ooooo0_l00007ooooo`;o00003Oooool00ol0003oooooooooo`0?
ooooo`;o00004?ooool2o`0009Kooooo002Mooooo`;o00002_ooool2o`000003ooooool0003ooooo
013ooooo0_l0002Xooooo`00Woooool2o`0000Gooooo0_l000001Ooooooo0000o`000?oooooo0000
0;_ooooo002Oooooo`;o00000oooool4o`0000Cooooo00?o0000ooooooooool0^Oooool00:;ooooo
1?l00006ooooo`03o`000?oooooooooo00gooooo0_l0002Zooooo`00X_ooool2o`0000Sooooo00?o
0000ooooooooool03Oooool2o`000:[ooooo002/ooooo`?o0000=?ooool2o`0008?ooooo0029oooo
o`;o00008Oooool00ol0003oooooooooo`0<ooooo`;o00004?ooool2o`0001Cooooo0_l00023oooo
o`00ROooool3o`0000Gooooo0_l0000Iooooo`03o`000?oooooooooo00cooooo0_l0000@ooooo`;o
00005?ooool2o`0008?ooooo002:ooooo`;o00001Oooool2o`0001Wooooo00?o0000ooooooooool0
7Oooool2o`0009[ooooo002/ooooo`03o`000?oooooooooo01gooooo0_l0002Jooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00V_ooool2o`00013ooooo00?o0000ooooooooool0^Oooool009[o
oooo0_l0000@ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o00006?ooool2o`0009oooooo
002Yooooo`;o000000?oooooo`000?ooool06Oooool3o`0009kooooo002Yooooo`Co00006oooool2
o`0009kooooo002<ooooo`;o00004Oooool3o`0000Sooooo0ol0002kooooo`00S?ooool2o`00017o
oooo0ol0000:ooooo`03o`000?oooooooooo0;Wooooo002Nooooo`;o00003?ooool00ol0003ooooo
ooooo`2iooooo`00W_ooool2o`0000;ooooo0_l00008ooooo`03o`000?oooooooooo01Cooooo0_l0
002Sooooo`00X_ooool2o`0000Sooooo00?o0000ooooooooool05?ooool4o`000:7ooooo002/oooo
o`03o`000?oooooooooo00;ooooo0_l0000@ooooo`Co0000XOooool00:cooooo0ol00002ooooo`;o
00004?ooool2o`000:?ooooo002/ooooo`03o`000?oooooooooo01;ooooo0_l0002Uooooo`00Uooo
ool2o`0001?ooooo00?o0000ooooooooool04_ooool2o`000:Gooooo002Gooooo`;o00004oooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00ROooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05oa0@4?ooooooooooooooool@41003Oooool0
0onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0^Oooool0
08Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMg
oc8b<_ooool01?ooool3o`0000cooooo0_l0002[ooooo`00ROooool01_l0003ooooooooooooooooo
0000ooooo`?o00002_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool2o`0000gooooo0_l0002[ooooo`00ROooool01_l@413ooooooooooooooooo410@ooooo`?o
00002_ooool00onYZJWo0000o`000003ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool03?ooool2o`000:_ooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool2o`0000Ko
oooo00Co410@oooooooooooooooo0_l00003ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool03?ooool2o`000:_ooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool3o`00
00Gooooo1Ol00004ooooo`Co00000oooool2o`000003ooooool0003ooooo0;[ooooo002Booooo`;o
00004?ooool2o`0000?ooooo0_l000000ooooooo0000ooooo`2jooooo`00XOooool2o`000003oooo
ool0003o000000Kooooo00?o0000ooooooooool0^Oooool00:7ooooo0ol00008ooooo`03o`000?oo
oooooooo0;Wooooo002Cooooo`;o00003Oooool2o`0000Sooooo0ol0002iooooo`00Toooool2o`00
01Oooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool01oooool2o`000;3ooooo002/ooooo`03o`000?oooooooooo00Oooooo0_l0
000Cooooo`;o0000Voooool008[ooooo0_l0000Pooooo`03o`000?oooooooooo01cooooo0_l0002K
ooooo`00R_ooool2o`00023ooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo0ol0000Gooooo`?o0000Woooool00:cooooo00?o0000ooooooooool05ooo
ool3o`0009oooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Zooooo`?o0000^oooool00:[ooooo0ol0
002kooooo`00W_ooool2o`0000cooooo00?o0000ooooooooool0^Oooool009gooooo0ol0000;oooo
o`;o0000^oooool009gooooo0_l00008ooooo`;o000000?oooooo`000?l000000ol0002iooooo`00
Yoooool2o`000004ooooool0003o0000o`000;_ooooo002Uooooo`Co00000oooool00ol0003ooooo
ooooo`2iooooo`00X?ooool2o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo00kooooo0_l0
002Yooooo`00Soooool2o`0000oooooo0_l0000:ooooo`03o`000?oooooooooo00kooooo0_l0002Y
ooooo`00Soooool2o`0001_ooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0000:ooooo`;o0000[Ooo
ool00:cooooo00?o0000ooooooooool02_ooool2o`000:gooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002Rooooo`Co000000?o410@ooooooooool00oooool0
0ol0003oooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0;Wooooo002Tooooo`03o`000?oooooooooo00Gooooo0ol0002iooooo`00Y?ooool00ol0003ooooo
ooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31
ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00X_ooool00omEEEGoIVIVo`000033ooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Z_ooool01?l@413o
0000o`000?l0002jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooo
ooooo`2jooooo`00Zoooool01_l0003oMgMgo`000?l0003oEEEEonk^k[Oooooo002[ooooo`06o`00
0?mEEEGok^k^oooooomgMgOoEEEE]oooool00:_ooooo00?o0000onk^k_ooool00_ooool00ol0003o
ooooooooo`2eooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo0;Gooooo
002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoIVIV]oooool00:[ooooo00?o410@o`000?mgMgL0
0_l000000omVIVKok^k^ooooo`2fooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.56099 .79117 Mdot
.41263 .80172 Mdot
.46749 .63189 Mdot
.54678 .5683 Mdot
.42242 .28726 Mdot
.63496 .48474 Mdot
.44362 .39804 Mdot
.43988 .03335 Mdot
.37538 .65784 Mdot
.47136 .22275 Mdot
.55821 .39711 Mdot
.52699 .04977 Mdot
.47297 .0733 Mdot
.52897 .29974 Mdot
.56694 .10305 Mdot
.46427 .76006 Mdot
.40044 .61767 Mdot
.48446 .07442 Mdot
.50571 .77214 Mdot
.69041 .50454 Mdot
.51021 .10422 Mdot
.38576 .39232 Mdot
.4132 .19459 Mdot
.51189 .1018 Mdot
.64495 .20553 Mdot
.59838 .45135 Mdot
.56937 .50984 Mdot
.51023 .75934 Mdot
.68788 .5544 Mdot
.39867 .72513 Mdot
.55926 .17419 Mdot
.37943 .70768 Mdot
.40963 .11282 Mdot
.43683 .18531 Mdot
.52727 .18877 Mdot
.67606 .4479 Mdot
.58921 .83142 Mdot
.54489 .67118 Mdot
.67283 .62376 Mdot
.54136 .0617 Mdot
.63782 .18679 Mdot
.48231 .13667 Mdot
.60429 .34429 Mdot
.55209 .81369 Mdot
.5987 .71754 Mdot
.52535 .23836 Mdot
.52551 .29981 Mdot
.44496 .9534 Mdot
.57224 .68691 Mdot
.68295 .56069 Mdot
.44647 .95373 Mdot
.66114 .6824 Mdot
.57673 .28049 Mdot
.58005 .27962 Mdot
.37294 .35731 Mdot
.4565 .01535 Mdot
.40436 .66253 Mdot
.5191 .93203 Mdot
.60887 .69017 Mdot
.54509 .27933 Mdot
.74844 .45939 Mdot
.66696 .6414 Mdot
.42723 .39316 Mdot
.42402 .07873 Mdot
.36881 .55376 Mdot
.46295 .22977 Mdot
.47747 .75935 Mdot
.54774 .66806 Mdot
.54539 .14602 Mdot
.39611 .58129 Mdot
.51974 .4473 Mdot
.48554 .22812 Mdot
.42385 .35145 Mdot
.66695 .6412 Mdot
.46225 .36502 Mdot
.57967 .38392 Mdot
.67132 .64874 Mdot
.57175 .66882 Mdot
.63155 .30039 Mdot
.40183 .74239 Mdot
.54919 .5201 Mdot
.49108 .14046 Mdot
.39294 .17843 Mdot
.46204 .76296 Mdot
.43039 .25232 Mdot
.48139 .18454 Mdot
.4293 .79039 Mdot
.46969 .75841 Mdot
.65145 .21792 Mdot
.66447 .81997 Mdot
.48588 .25911 Mdot
.49602 .19154 Mdot
.4653 .26134 Mdot
.6905 .77641 Mdot
.52347 .2875 Mdot
.42702 .91632 Mdot
.43047 .79766 Mdot
.53327 .83682 Mdot
.47559 .85393 Mdot
.5321 .05825 Mdot
.52465 .85553 Mdot
.60238 .23503 Mdot
.45393 .15308 Mdot
.39532 .43788 Mdot
.4736 .80685 Mdot
.48769 .26055 Mdot
.55316 .15843 Mdot
.50043 .24136 Mdot
.55054 .54037 Mdot
.38152 .72369 Mdot
.68186 .44637 Mdot
.37772 .15373 Mdot
.46105 .29848 Mdot
.56484 .32937 Mdot
.36689 .49011 Mdot
.3701 .60419 Mdot
.58552 .83086 Mdot
.47475 .07433 Mdot
.73707 .39435 Mdot
.48251 .0853 Mdot
.68876 .55957 Mdot
.55183 .15555 Mdot
.53699 .6219 Mdot
.68458 .48066 Mdot
.7139 .72367 Mdot
.44833 .88238 Mdot
.52865 .43273 Mdot
.40441 .23145 Mdot
.49569 .88962 Mdot
.56771 .09639 Mdot
.63743 .49184 Mdot
.61964 .39467 Mdot
.682 .60964 Mdot
.61901 .78778 Mdot
.68711 .52636 Mdot
.48114 .22634 Mdot
.44925 .02872 Mdot
.57161 .10668 Mdot
.7463 .57035 Mdot
.54118 .40353 Mdot
.53421 .70929 Mdot
.40049 .61983 Mdot
.68745 .47456 Mdot
.3769 .29041 Mdot
.44022 .75816 Mdot
.49939 .2005 Mdot
.72588 .3443 Mdot
.49413 .84323 Mdot
.5694 .57301 Mdot
.51445 .10359 Mdot
.51357 .4075 Mdot
.62742 .5924 Mdot
.6301 .76009 Mdot
.66584 .65457 Mdot
.36766 .4606 Mdot
.58454 .8367 Mdot
.62774 .76645 Mdot
.60074 .55369 Mdot
.67407 .64384 Mdot
.61895 .15078 Mdot
.66482 .39794 Mdot
.60487 .3553 Mdot
.5356 .82949 Mdot
.37424 .32057 Mdot
.61812 .26208 Mdot
.55249 .65102 Mdot
.63892 .7483 Mdot
.68172 .52651 Mdot
.51337 .31942 Mdot
.56092 .60932 Mdot
.4385 .23035 Mdot
.427 .7166 Mdot
.42379 .07499 Mdot
.69771 .76069 Mdot
.62825 .58313 Mdot
.45974 .30588 Mdot
.68315 .57929 Mdot
.65606 .70749 Mdot
.57687 .10294 Mdot
.41606 .5647 Mdot
.64684 .20004 Mdot
.52896 .58366 Mdot
.37788 .68007 Mdot
.71265 .72284 Mdot
.38883 .78211 Mdot
.6108 .14121 Mdot
.61297 .36708 Mdot
.7237 .35158 Mdot
.68772 .47248 Mdot
.4243 .55822 Mdot
.74333 .44227 Mdot
.41434 .09244 Mdot
.67418 .23927 Mdot
.54716 .07364 Mdot
.4807 .18052 Mdot
.63324 .87435 Mdot
.41537 .2486 Mdot
.43152 .44867 Mdot
.43352 .42048 Mdot
.5226 .48115 Mdot
.4208 .30104 Mdot
.60939 .90656 Mdot
.51208 .86587 Mdot
.47078 .72543 Mdot
.6353 .5236 Mdot
.55301 .51739 Mdot
.51477 .65547 Mdot
.56163 .40787 Mdot
.41583 .16999 Mdot
.57515 .36605 Mdot
.61981 .26579 Mdot
.42316 .63252 Mdot
.52687 .84271 Mdot
.56565 .33879 Mdot
.62478 .15981 Mdot
.53084 .58148 Mdot
.61014 .6752 Mdot
.51489 .03295 Mdot
.55966 .31487 Mdot
.49439 .95661 Mdot
.60667 .23961 Mdot
.64631 .33963 Mdot
.43781 .7026 Mdot
.40516 .49899 Mdot
.43901 .87915 Mdot
.50459 .29497 Mdot
.56924 .1054 Mdot
.74149 .40396 Mdot
.50332 .72983 Mdot
.48357 .65998 Mdot
.59446 .92179 Mdot
.52457 .78732 Mdot
.57068 .49186 Mdot
.73102 .37731 Mdot
.55462 .6384 Mdot
.50727 .88079 Mdot
.46703 .08254 Mdot
.50894 .87236 Mdot
.74784 .4633 Mdot
.62836 .42362 Mdot
.64249 .3109 Mdot
.3964 .58622 Mdot
.38019 .72 Mdot
.45577 .2765 Mdot
.6277 .75744 Mdot
.44555 .82083 Mdot
.39798 .61052 Mdot
.66816 .64169 Mdot
.66855 .23163 Mdot
.45801 .30401 Mdot
.42392 .53919 Mdot
.61099 .78855 Mdot
.59852 .47659 Mdot
.56292 .59646 Mdot
.5922 .30036 Mdot
.47164 .35274 Mdot
.44858 .02555 Mdot
.48028 .96995 Mdot
.55163 .73625 Mdot
.57066 .48948 Mdot
.65369 .35947 Mdot
.50867 .34642 Mdot
.49631 .83803 Mdot
.57619 .75864 Mdot
.53777 .33386 Mdot
.62832 .45778 Mdot
.67968 .48534 Mdot
.59735 .54604 Mdot
.68037 .45776 Mdot
.58858 .29639 Mdot
.46488 .22448 Mdot
.56376 .69985 Mdot
.63549 .75054 Mdot
.41425 .53042 Mdot
.42175 .70196 Mdot
.42828 .92305 Mdot
.55718 .38373 Mdot
.63205 .56683 Mdot
.68087 .60191 Mdot
.53184 .43733 Mdot
.41628 .44461 Mdot
.58229 .8389 Mdot
.51037 .03453 Mdot
.46856 .80649 Mdot
.48872 .32914 Mdot
.40705 .46067 Mdot
.67408 .399 Mdot
.51361 .22236 Mdot
.61935 .27583 Mdot
.71113 .72461 Mdot
.52429 .92301 Mdot
.53507 .06545 Mdot
.51163 .93551 Mdot
.44251 .59143 Mdot
.55429 .88876 Mdot
.73695 .4225 Mdot
.66256 .35753 Mdot
.55596 .09007 Mdot
.57692 .66435 Mdot
.61483 .36036 Mdot
.49016 .89646 Mdot
.37928 .70973 Mdot
.6331 .18365 Mdot
.53523 .32243 Mdot
.42847 .92185 Mdot
.59998 .49625 Mdot
.43872 .61245 Mdot
.41623 .17123 Mdot
.39648 .55372 Mdot
.46534 .07866 Mdot
.71863 .32704 Mdot
.47767 .28971 Mdot
.59944 .70503 Mdot
.46171 .14376 Mdot
.44413 .04002 Mdot
.51122 .35111 Mdot
.58544 .11431 Mdot
.71204 .33675 Mdot
.74714 .59859 Mdot
.51703 .692 Mdot
.63881 .49212 Mdot
.49367 .14138 Mdot
.6574 .67668 Mdot
.40458 .49793 Mdot
.43051 .5403 Mdot
.43648 .49621 Mdot
.39451 .50524 Mdot
.48595 .00811 Mdot
.61121 .785 Mdot
.45974 .26654 Mdot
.39717 .26671 Mdot
.53137 .44847 Mdot
.52277 .48897 Mdot
.43183 .86395 Mdot
.6339 .46419 Mdot
.60551 .35688 Mdot
.6003 .55552 Mdot
.41486 .34152 Mdot
.59841 .50524 Mdot
.4139 .79753 Mdot
.43017 .37272 Mdot
.39096 .19934 Mdot
.56859 .48939 Mdot
.68644 .51519 Mdot
.3851 .565 Mdot
.52055 .32901 Mdot
.54179 .282 Mdot
.74742 .56445 Mdot
.51721 .03822 Mdot
.56306 .87906 Mdot
.67862 .46084 Mdot
.58729 .62985 Mdot
.41371 .26106 Mdot
.68253 .51127 Mdot
.51158 .81233 Mdot
.51726 .03874 Mdot
.74966 .60254 Mdot
.64666 .32077 Mdot
.56498 .09396 Mdot
.59286 .1237 Mdot
.64073 .18598 Mdot
.51983 .56377 Mdot
.54181 .75361 Mdot
.57583 .11265 Mdot
.44973 .02289 Mdot
.51686 .58612 Mdot
.59916 .23596 Mdot
.59622 .51746 Mdot
.63683 .52304 Mdot
.54209 .82277 Mdot
.41017 .86889 Mdot
.50859 .87845 Mdot
.57024 .86229 Mdot
.63222 .74034 Mdot
.40622 .2276 Mdot
.58293 .85108 Mdot
.40001 .25905 Mdot
.62398 .17395 Mdot
.40459 .03811 Mdot
.56369 .86366 Mdot
.62739 .60366 Mdot
.50861 .38987 Mdot
.69229 .28754 Mdot
.44164 .82295 Mdot
.43703 .52456 Mdot
.58226 .10775 Mdot
.55022 .15264 Mdot
.43219 .56917 Mdot
.43505 .29283 Mdot
.58892 .40572 Mdot
.57079 .52028 Mdot
.4329 .9354 Mdot
.61061 .24104 Mdot
.74133 .43876 Mdot
.58307 .11021 Mdot
.4034 .34013 Mdot
.41033 .28417 Mdot
.43343 .74199 Mdot
.41821 .67624 Mdot
.51241 .52773 Mdot
.47856 .00756 Mdot
.52297 .04585 Mdot
.56937 .5011 Mdot
.52025 .33243 Mdot
.5736 .47742 Mdot
.43646 .70867 Mdot
.7015 .29158 Mdot
.48113 .17802 Mdot
.66382 .38794 Mdot
.54671 .44331 Mdot
.56715 .58595 Mdot
.51834 .37824 Mdot
.45635 .19064 Mdot
.42321 .22858 Mdot
.57267 .52361 Mdot
.45993 .71708 Mdot
.73213 .36993 Mdot
.44397 .03491 Mdot
.50283 .48839 Mdot
.5398 .20803 Mdot
.39547 .4347 Mdot
.61433 .64753 Mdot
.59517 .54593 Mdot
.55911 .62253 Mdot
.69412 .28749 Mdot
.67905 .80273 Mdot
.48535 .90265 Mdot
.3521 .44495 Mdot
.54106 .83315 Mdot
.44536 .68899 Mdot
.36966 .52039 Mdot
.58548 .12515 Mdot
.56237 .42247 Mdot
.3847 .54226 Mdot
.52752 .35531 Mdot
.44498 .64945 Mdot
.41457 .64223 Mdot
.65139 .34921 Mdot
.58363 .62814 Mdot
.64779 .85024 Mdot
.52197 .62341 Mdot
.55425 .23819 Mdot
.47031 .13454 Mdot
.44278 .30519 Mdot
.47674 .2916 Mdot
.41584 .42825 Mdot
.44281 .02947 Mdot
.49284 .30172 Mdot
.67738 .62661 Mdot
.43871 .87579 Mdot
.59621 .71861 Mdot
.68267 .46733 Mdot
.60442 .24807 Mdot
.39593 .44983 Mdot
.72126 .71262 Mdot
.4413 .27057 Mdot
.4915 .01074 Mdot
.66649 .22644 Mdot
.53976 .34146 Mdot
.55754 .88544 Mdot
.59611 .54686 Mdot
.40855 .68441 Mdot
.68674 .50889 Mdot
.53449 .83603 Mdot
.49019 .79621 Mdot
.54311 .28416 Mdot
.43154 .19811 Mdot
.75004 .44514 Mdot
.61845 .39839 Mdot
.45449 .38428 Mdot
.59732 .32974 Mdot
.57117 .67361 Mdot
.52247 .54249 Mdot
.50305 .7245 Mdot
.57145 .26862 Mdot
.61619 .37573 Mdot
.44193 .35622 Mdot
.59509 .45154 Mdot
.36839 .53501 Mdot
.41532 .32758 Mdot
.58679 .73461 Mdot
.54808 .67468 Mdot
.5024 .77079 Mdot
.49973 .66015 Mdot
.36524 .23793 Mdot
.49085 .68122 Mdot
.4218 .83566 Mdot
.47972 .96213 Mdot
.66685 .40286 Mdot
.54085 .68896 Mdot
.68619 .5479 Mdot
.55984 .08409 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool2o`0000Kooooo00?o0000ooooooooool0^Oooool00:Cooooo0_l0
00000ooooooo0000o`000002o`000003ooooool0003ooooo0;[ooooo002Tooooo`03o`000?oooooo
oooo00Co000000?oooooo`000?ooool0^_ooool009gooooo0_l00003ooooo`03oeEEEOmVIVKo0000
00Oooooo00?o0000ooooooooool0^Oooool009gooooo0_l0000=ooooo`03o`000?oooooooooo0;Wo
oooo002Kooooo`;o00003oooool00ol0003oooooooooo`2iooooo`00Voooool2o`0000oooooo0ol0
002iooooo`00Voooool2o`0000oooooo00?o0000ooooooooool0^Oooool009Wooooo1?l0000?oooo
o`03o`000?oooooooooo0;Wooooo002Hooooo`?o00004Oooool00ol0003oooooooooo`03o`000;Ko
oooo002Hooooo`?o00004Oooool00ol0003oooooooooo`03o`000;Kooooo002<ooooo`;o00002ooo
ool2o`00017ooooo00?o0000ooooooooool00_ooool2o`000;Gooooo002<ooooo`;o00002oooool2
o`00017ooooo00?o0000ooooooooool00_ooool2o`000;Gooooo002/ooooo`03o`000?oooooooooo
00Cooooo0_l0002cooooo`00[?ooool00ol0003oooooooooo`04ooooo`?o0000/_ooool00:cooooo
0ol00005ooooo`;o0000/_ooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool01oooool2o`000;3ooooo002/ooooo`03o`000?oooooooooo00Oooooo0_l000000ooo
oooo0000o`00002]ooooo`00[?ooool00ol0003oooooooooo`0:ooooo`;o0000[Oooool00:cooooo
00?o0000ooooooooool02?ooool2o`000:oooooo002/ooooo`03o`000?oooooooooo00Sooooo0_l0
002_ooooo`00Xoooool2o`0000Oooooo00?o0000ooooooooool03?ooool2o`000:_ooooo002Boooo
o`;o00003oooool2o`000003ooooool0003o000000Cooooo0ol0000<ooooo`;o0000Zoooool009;o
oooo0_l0000<ooooo`;o00001?ooool2o`0000Cooooo00?o0000ooooooooool0^Oooool009;ooooo
0_l0000<ooooo`?o00002Oooool00ol0003oooooooooo`2iooooo`00XOooool2o`0000?ooooo0_l0
0004ooooo`03o`000?oooooooooo013ooooo0_l0002Wooooo`00Y_ooool2o`0000Cooooo00?o0000
ooooooooool04?ooool2o`000:Oooooo002?ooooo`;o00006oooool00ol0003oooooooooo`0?oooo
o`;o0000Z?ooool008oooooo0_l0000Kooooo`03o`000?oooooooooo00oooooo0_l000000ooooooo
0000o`00002Uooooo`00[?ooool00ol0003oooooooooo`0Booooo`?o0000Y?ooool00:cooooo0ol0
000Cooooo`;o0000Y?ooool00:cooooo00?o0000ooooooooool00ol0000@ooooo`;o000000?ooooo
o`000?l00000XOooool00:cooooo00?o0000ooooooooool00ol0000@ooooo`Go0000XOooool00:co
oooo00?o0000ooooooooool04oooool3o`0000;ooooo0_l0002Oooooo`00S_ooool2o`0001cooooo
00?o0000ooooooooool05_ooool4o`0009oooooo002>ooooo`;o00007?ooool00ol0003ooooooooo
o`0Fooooo`;o000000?oooooo`000?l00000W_ooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1Oooool00ol0003oooooooooo`0Iooooo`;o0000W_ooool008Wooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0^Oooool0087ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@4100
3Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0000Iooooo`Co0000
W?ooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Iooooo`Co0000W?ooool008Wooooo00Go
0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05oa0@4?ooooooooooooooool@
41003_ooool00onYZJWoMgMgooooo`03ooooo`;o00002?ooool00ol0003oooooooooo`2iooooo`00
ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04oooo
o`;o00000_ooool2o`0000Cooooo00?o0000ooooooooool0^Oooool008Wooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`Go00001?ooool6o`000005ooooool0003o0000ooooool00000^oooool0
09oooooo0_l00008ooooo`;o000000?oooooo`000?ooool08_ooool2o`0009Kooooo002Oooooo`;o
00002?ooool2o`000003ooooool0003ooooo00gooooo0_l0000Cooooo`;o0000U_ooool00:cooooo
00?o0000ooooooooool03?ooool2o`000:_ooooo002Looooo`;o00003_ooool3o`0000gooooo0_l0
000Eooooo`;o0000Toooool008?ooooo0_l0000Gooooo`;o00003_ooool00ol0003oooooooooo`0=
ooooo`?o00005?ooool2o`0009?ooooo0023ooooo`;o00009oooool00ol0003oooooooooo`0>oooo
o`;o0000ZOooool00:cooooo00?o0000ooooooooool03_ooool2o`0001Kooooo0_l0002Aooooo`00
[?ooool00ol0003oooooooooo`0Vooooo`;o0000TOooool00:cooooo00?o0000ooooooooool0^Ooo
ool0093ooooo0_l0000Jooooo`03o`000?oooooooooo0;Wooooo002@ooooo`;o00006_ooool00ol0
003oooooooooo`0@ooooo`;o00004oooool2o`0009;ooooo002/ooooo`?o00004?ooool2o`0001?o
oooo0_l0002Booooo`00R?ooool2o`0001_ooooo0_l00005ooooo`03o`000?oooooooooo0;Wooooo
0028ooooo`;o00006oooool2o`0000Gooooo00?o0000ooooooooool0^Oooool009Oooooo0_l0000<
ooooo`;o00001Oooool00ol0003oooooooooo`0Yooooo`Co0000S?ooool009Oooooo0_l0000<oooo
o`;o00001Oooool00ol0003oooooooooo`06ooooo`;o00008Oooool4o`0008cooooo002Mooooo`;o
00002oooool3o`0000Sooooo0_l0000Rooooo`;o0000SOooool008oooooo0_l0000<ooooo`;o0000
2oooool3o`000;_ooooo002?ooooo`;o00001?ooool2o`0001Gooooo00?o0000ooooooooool0^Ooo
ool008Sooooo0_l0000;ooooo`;o00005?ooool4o`0002gooooo0_l0002:ooooo`00R?ooool2o`00
027ooooo0_l0000_ooooo`;o0000R_ooool00:cooooo00?o0000ooooooooool0;?ooool2o`0008_o
oooo002/ooooo`03o`000?oooooooooo00[ooooo0_l0000Pooooo`;o0000Roooool00:cooooo00?o
0000ooooooooool02_ooool2o`000:gooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo02oooooo0_l00028ooooo`00X_ooool2o`0000Sooooo00Co0000oooooooo
oooooooo0_l0000/ooooo`;o0000R?ooool00:3ooooo1?l00008ooooo`?o000000?oooooo`000?l0
0000]_ooool008gooooo0_l00003ooooo`;o00003?ooool2o`0000?ooooo1?l00003ooooo`03o`00
0?oooooooooo03Cooooo0_l00023ooooo`00S?ooool3o`0000?ooooo0_l00003ooooo`;o00001_oo
ool2o`0000Cooooo1?l00003ooooo`03o`000?oooooooooo03Cooooo0_l00023ooooo`00S?ooool2
o`0000Wooooo0_l00006ooooo`;o00002oooool00ol0003oooooooooo`0dooooo`;o0000Poooool0
07oooooo0_l0000[ooooo`03o`000?oooooooooo01gooooo0ol0002Iooooo`00Ooooool2o`0002_o
oooo00?o0000ooooooooool01Oooool2o`0000Oooooo0_l0000=ooooo`Go00005?ooool2o`00087o
oooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`;o00001_ooool2o`0000Oooooo0_l0000@ooooo`?o00004oooool2o`00
087ooooo002Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool2o`0002;ooooo0_l0002Fooooo`00ROooool6o`000003ooooool0003o000000?o
oooo00?o410@ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01oo
oooo0_l0002Hooooo`00T?ooool2o`0000?ooooo0_l0000>ooooo`03ogMgMolb<S;ooooo00Cooooo
0ol0000Oooooo`;o0000V?ooool0097ooooo00Co0000oooooooooooooooo0_l0000;ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2iooooo`00Roooool2o`0000Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00;ooooo0_l00003ooooo`03
o`000?oooooooooo0;Wooooo002;ooooo`;o00000_ooool2o`000005ogMgMonHV9SooooooiRHV?mg
MgL02_ooool3o`0000Cooooo0_l00003ooooo`03o`000?oooooooooo02Cooooo0_l0002Cooooo`00
Soooool2o`000005onk^k_lb<S;o0000oc8b<_o^k^h02_ooool6o`000003ooooool0003o000000?o
oooo00?o0000ooooooooool09?ooool2o`0009?ooooo002:ooooo`;o00004_ooool2o`0000cooooo
00?o0000ooooooooool09?ooool2o`0009?ooooo002:ooooo`;o00003?ooool2o`0000Cooooo0_l0
000<ooooo`03o`000?oooooooooo01Cooooo0_l0000>ooooo`;o0000Toooool009Sooooo0_l0000B
ooooo`03o`000?oooooooooo01Cooooo0_l0002Sooooo`00WOooool2o`0000gooooo0ol0000Toooo
o`;o0000Toooool009gooooo0_l0000=ooooo`03o`000?oooooooooo00_ooooo0_l0000:ooooo`;o
00002oooool2o`0009?ooooo002/ooooo`03o`000?oooooooooo00[ooooo0ol00009ooooo`?o0000
X?ooool008kooooo0_l0000Looooo`03o`000?oooooooooo00[ooooo0ol00009ooooo`;o0000XOoo
ool008kooooo0_l00002ooooo`;o00006?ooool00ol0003oooooooooo`04ooooo`;o00001Oooool2
o`0002oooooo0ol0001jooooo`00Poooool2o`0000gooooo0_l0000@ooooo`;o00001_ooool00ol0
003oooooooooo`04ooooo`;o0000=_ooool5o`0007Sooooo0023ooooo`;o00004Oooool2o`0000co
oooo0_l00006ooooo`?o0000?oooool2o`0007Sooooo002Fooooo`;o00001oooool2o`0000_ooooo
0ol0000Jooooo`;o0000WOooool0097ooooo0_l0000<ooooo`;o00002oooool3o`0000Gooooo0ol0
000Booooo`?o00002oooool2o`0008oooooo002Aooooo`;o00002oooool2o`0000Wooooo0_l00000
0ooooooo0000ooooo`06ooooo`?o00004oooool2o`0000_ooooo0_l0002?ooooo`00VOooool2o`00
00?ooooo0_l00009ooooo`;o000000?oooooo`000?ooool0^_ooool009Wooooo0_l00003ooooo`;o
00003?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0/ooooo`;o0000
Roooool00:cooooo00?o0000ooooooooool04?ooool2o`0001[ooooo0_l0002;ooooo`00[?ooool0
1?l0003oooooooooooooool2o`0000gooooo0_l0002Wooooo`00P_ooool2o`0002Sooooo00Co0000
oooooooooooooooo0_l00005ooooo`;o00008oooool2o`0008[ooooo0022ooooo`;o0000:?ooool3
o`0000Sooooo0_l0000Sooooo`;o0000R_ooool0093ooooo0_l0000Jooooo`03o`000?oooooooooo
04Gooooo0_l0001booooo`00T?ooool2o`0001Kooooo0_l00002ooooo`03o`000?oooooooooo00?o
oooo0_l0000=ooooo`;o00002Oooool2o`0002Kooooo0_l0001booooo`00Z?ooool2o`0000;ooooo
00?o0000ooooooooool00oooool2o`0000Cooooo0_l00007ooooo`;o00002Oooool2o`0009[ooooo
002/ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o0000>?ooool2o`0007Cooooo002<
ooooo`;o00007_ooool00ol0003oooooooooo`0Booooo`;o00006Oooool2o`0001Cooooo0_l0001d
ooooo`00S?ooool2o`000003ooooool0003o000001_ooooo00?o0000ooooooooool02_ooool2o`00
00Kooooo0_l0000Iooooo`;o0000R_ooool008oooooo0_l0000Kooooo`04o`000?oooooo0000o`00
00Wooooo0_l0000Cooooo`;o00009_ooool2o`00073ooooo002/ooooo`04o`000?oooooo0000o`00
01kooooo0_l0000>ooooo`;o00005_ooool2o`00073ooooo002Booooo`;o00003_ooool2o`0000So
oooo1Ol0000]ooooo`;o00005Oooool2o`00077ooooo002Booooo`;o00003_ooool2o`0000Sooooo
00?o0000ooooooooool00_l00004ooooo`;o00005oooool2o`0002Gooooo0_l0001aooooo`00P_oo
ool2o`0001Cooooo0_l0000Booooo`03o`000?oooooooooo00Kooooo0_l0000Gooooo`;o00004Ooo
ool2o`0008Gooooo0022ooooo`;o00005?ooool2o`0001;ooooo00?o0000ooooooooool07oooool2
o`000003ooooool0003o000000_ooooo0_l000000ooooooo0000o`000025ooooo`00Woooool2o`00
00_ooooo00?o0000ooooooooool08_ooool2o`0000_ooooo0_l00028ooooo`00ROooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go000000Goooooo`000?l0003oooooodA4A002
o`000003oc8b<_oMgMgooooo00Cooooo00?o0000ooooooooool05Oooool2o`0000_ooooo0_l0002E
ooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01Gooooo0_l0
000;ooooo`;o00009Oooool2o`0006kooooo0021ooooo`Ko00000_ooool01Ol@413ooooooooooooo
oooo410@00Oooooo0_l00003ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`19ooooo`;o0000K_ooool008Wooooo00Go0000ooooooooooooooooo`00
0007ooooo`;o00001?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0
000Sooooo`;o00009?ooool2o`0006kooooo0029ooooo`05o`000?ooooooooooooooool000003_oo
ool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`03ooooo`;o00007_ooool2o`0002Cooooo0_l0001^ooooo`00ROooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00?ooooo0_l0002dooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Co0000okZj^_ooooooV9RH0_l00003ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool03oooool2o`0000Kooooo0_l0002Pooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00CoV9RHoa0@4?l0003o8B4Q0_l00003ooooo`Co00001_ooool00ol0003oooooooooo`0?oooo
o`;o00001_ooool2o`0001[ooooo0_l00024ooooo`00Q_ooool2o`0002Cooooo00Co0000ooooool0
003o0000<_ooool2o`0008Cooooo0026ooooo`;o00003?ooool2o`0001Kooooo00Co0000ooooool0
003o00008oooool2o`0002Gooooo0_l0001/ooooo`00U?ooool2o`0000?ooooo0_l0000Aooooo`03
o`000?oooooooooo013ooooo0_l0000Booooo`;o00003Oooool2o`0001Kooooo0_l0001/ooooo`00
VOooool2o`00017ooooo0ol0000@ooooo`;o00004_ooool2o`0000gooooo0_l000000ooooooo0000
o`000021ooooo`00[?ooool00ol0003oooooooooo`0:ooooo`;o0000:?ooool4o`0001Cooooo0_l0
001[ooooo`00[?ooool01?l0003oooooooooooooool2o`0000Oooooo0_l0000>ooooo`;o00006?oo
ool2o`0001Kooooo0_l0001[ooooo`00[?ooool01?l0003oooooooooooooool2o`0000kooooo0_l0
0007ooooo`;o0000WOooool00:cooooo00?o0000ooooooooool04Oooool2o`000:Kooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Fooooo`;o0000
5?ooool00ol0003oooooooooo`0Aooooo`;o0000>?ooool2o`0006cooooo002Fooooo`;o00005?oo
ool3o`00017ooooo0_l0000Dooooo`;o00008_ooool2o`0006cooooo002@ooooo`;o00006_ooool0
0ol0003oooooooooo`0Wooooo`;o0000T?ooool0093ooooo0_l0000Jooooo`03o`000?oooooooooo
0;Wooooo0029ooooo`;o00008Oooool00ol0003oooooooooo`06ooooo`;o0000/Oooool008Wooooo
0_l0000Qooooo`03o`000?oooooooooo00Kooooo0ol0002`ooooo`00ROooool2o`00027ooooo00?o
0000ooooooooool01oooool2o`0004?ooooo0_l0001[ooooo`00[?ooool00ol0003oooooooooo`0<
ooooo`;o0000?_ooool3o`0006[ooooo001kooooo`;o00004oooool2o`0001[ooooo00?o0000oooo
ooooool03?ooool2o`0002_ooooo0_l0000Booooo`Co0000J?ooool007_ooooo0_l0000<ooooo`;o
00001Oooool2o`0000?ooooo0_l0000Eooooo`03o`000?oooooooooo00?ooooo0_l00002ooooo`;o
0000;_ooool4o`0001Cooooo0_l0001Xooooo`00ROooool2o`0000[ooooo0_l0000Eooooo`?o0000
0oooool2o`0000;ooooo0_l0000Cooooo`?o00006?ooool2o`00083ooooo002/ooooo`03o`000?oo
oooooooo01cooooo0ol0002Jooooo`00[?ooool00ol0003oooooooooo`0Wooooo`;o00003oooool2
o`0007oooooo0009ooooo`Co000000?o410@ooooooooool05_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgM
g@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool2o`0000;o8B4Q1?ooool7o`00
00;ooooo00GoA4A4o`000?l0003o<S8bomgMg@0Fooooo`03o`000?oooooooooo01Sooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q0oooool6o`0000Cooooo00GoA4A4o`000?l0003o<S8b
omgMg@02ooooo`;o00002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_l00005ooooo`05
odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46
ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`Co000000?o
410@ooooooooool04_ooool000_ooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool03_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`;o00000_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@00_l00005ooooo`03ogMgMolb<S;ooooo01Gooooo00?o0000ooooooooool06?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?l0003o0000oooooom4A4@01ooo
ool01?mgMgOo<S8booooooooool2o`0000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`?o
00002?ooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo
01Cooooo0006o`0000Gooooo00?o0000ooooooooool04?ooool6o`0000;ooooo00Go410@oooooooo
oooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool01Oooool6o`00
00;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00Gooooo1_l00002
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool06?ooool01Ol@413ooooooooooooooooo410@00cooooo
0_l000000oo^k^koooooooooo`07ooooo`04o`000?ooooooooooooooo`;o00002_ooool01Ol@413o
oooooooooooooooo410@00Cooooo0_l0000:ooooo`03o`000?oooooooooo00gooooo00Go410@oooo
oooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05o`000?oooooooooo
ooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000oooooooooooooooo
o`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool05Oooool00ol0003ooooo
ooooo`0Hooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03
ogMgMolb<S;ooooo00;ooooo0_l0000:ooooo`05o`000?ooooooooooooooool000003oooool00omg
MgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06
ooooo`03ogMgMolb<S;ooooo01Wooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000oooo
ooooool06?ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Kooooo00?o0000ooooooooool06?ooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo0_l00008ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<co
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Jooooo`03o`000?oooooooooo01Cooooo000;
ooooo`03o`000?oooooooooo01Sooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmg
MgOooooo00?ooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00cooooo
00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Hooooo`?o00006?ooool01Ol@413ooooooooooooooooo410@
00;o00003Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo0ol00008oooo
o`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0Aooooo`05oa0@4?oooooo
ooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo017ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo01Gooooo0_l000001_ooooooMgMgoiRHV?ooooooV9RHogMgM`;o0000
2Oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01_ooool2o`0000Wo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo01Cooooo0009ooooo`03oeEEEOmVIVKo000001[ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c004ooooo`Co00005oooool00ol0003oooooooooo`04ooooo`;o00003oooool2o`00
0006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo
1?l00004ooooo`;o00002_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000Iooooo`03oeEEEOmVIVKo0000
01Kooooo002/ooooo`03o`000?oooooooooo00Cooooo0_l0000Sooooo`;o00003Oooool3o`0007ko
oooo002/ooooo`;o00001Oooool2o`0000gooooo0_l0000Dooooo`;o00003Oooool2o`0007oooooo
0020ooooo`;o0000:_ooool2o`0000Gooooo0_l0000=ooooo`?o00005?ooool2o`0008;ooooo0_l0
0002ooooo`;o00001Oooool0083ooooo0_l0000Zooooo`03o`000?oooooooooo01Cooooo0_l0000D
ooooo`;o0000P_ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Gooooo002<ooooo`;o00002Ooo
ool2o`0001?ooooo00?o0000ooooooooool07_ooool2o`0008oooooo00CogMgMo`000?l@413oc<c<
1_ooool000Ooooooool0001<o`0000cooooo00Cok^k^ob4Q8Ol@413ok^k^1_ooool000Oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool3o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00;ooooo0_l000000ooooooo0000ooooo`06ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`04o`000?oo
ooooooooooooo`;o00000_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`04ob4Q8OmgMgOoMgMgoc8b<PKo
oooo0007ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo00?ooooo0_l0000Qooooo`03o`000?oooooooooo01gooooo
0_l00008ooooo`03o`000?oooooooooo017ooooo0_l0000Cooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`09ooooo`;o00000_ooool2o`0000Gooooo
0029ooooo`;o00008Oooool00ol0003oooooooooo`0Cooooo`;o00002?ooool2o`0001_ooooo0_l0
001mooooo`00[?ooool00ol0003oooooooooo`0Cooooo`;o00009?ooool3o`0007gooooo002/oooo
o`03o`000?oooooooooo03Wooooo0ol0001mooooo`00[?ooool00ol0003oooooooooo`0>ooooo`;o
00003?ooool2o`0001cooooo0_l0001mooooo`00POooool2o`0002Wooooo00?o0000ooooooooool0
3Oooool3o`0000Cooooo0_l00006ooooo`;o0000Voooool0087ooooo0_l0000Dooooo`;o00004ooo
ool3o`0000gooooo0_l00005ooooo`?o00004_ooool3o`0008gooooo002Gooooo`;o00004oooool0
1?l0003oooooooooooooool2o`0001;ooooo0_l0000Booooo`?o00003Oooool3o`0007gooooo002?
ooooo`;o00006oooool01?l0003oooooooooooooool2o`0003Kooooo0ol0001mooooo`00Soooool2
o`0001_ooooo00?o0000ooooooooool0^Oooool0083ooooo0_l0000Zooooo`03o`000?oooooooooo
0;Wooooo0020ooooo`;o00004?ooool2o`000003ooooool0003o000001Gooooo00?o0000oooooooo
ool03Oooool2o`000:[ooooo0026ooooo`;o00002_ooool2o`000003ooooool0003o000001Gooooo
00?o0000ooooooooool01?ooool2o`0000Oooooo0_l0002Zooooo`00Q_ooool2o`0002Cooooo00?o
0000ooooooooool01?ooool2o`0001Kooooo0ol0002Jooooo`00[?ooool00ol0003oooooooooo`0L
ooooo`?o00006oooool2o`0007gooooo002/ooooo`?o0000>_ooool2o`0007gooooo0020ooooo`;o
00001oooool2o`00027ooooo00?o0000ooooooooool07_ooool2o`0001_ooooo0_l0001looooo`00
P?ooool2o`0000Oooooo0_l00008ooooo`;o00005oooool00ol0003oooooooooo`0Nooooo`;o0000
6oooool2o`0007cooooo002Cooooo`;o00005oooool00ol0003oooooooooo`0iooooo`Co0000O?oo
ool008Kooooo0_l00008ooooo`;o00006_ooool00ol0003oooooooooo`03ooooo`;o0000=?ooool4
o`00017ooooo0_l0001Yooooo`00Q_ooool2o`0000Sooooo0_l0000Jooooo`03o`000?oooooooooo
00?ooooo0_l0000Sooooo`;o00009?ooool2o`0006Wooooo002Eooooo`;o00005Oooool00ol0003o
ooooooooo`0<ooooo`;o00006_ooool2o`0002Cooooo0_l0001Yooooo`00UOooool2o`0001Gooooo
00?o0000ooooooooool03?ooool2o`0000Gooooo0_l0000iooooo`;o0000JOooool00:cooooo0ol0
000Cooooo`;o0000Y?ooool00:cooooo00?o0000ooooooooool0>Oooool2o`0007kooooo0029oooo
o`;o00008Oooool00ol0003oooooooooo`07ooooo`;o00007_ooool2o`00013ooooo0_l0001noooo
o`00ROooool2o`00027ooooo00?o0000ooooooooool00_ooool2o`0000;ooooo0ol0000:ooooo`;o
00004_ooool2o`00093ooooo0029ooooo`;o00008Oooool00ol0003oooooooooo`02ooooo`;o0000
0_ooool2o`0000_ooooo0_l0002Tooooo`00VOooool2o`00017ooooo00?o0000ooooooooool09ooo
ool2o`00093ooooo002Iooooo`;o00004Oooool00ol0003oooooooooo`0Wooooo`;o0000T?ooool0
0:cooooo00?o0000ooooooooool04Oooool2o`000:Kooooo002/ooooo`?o00004Oooool2o`0003_o
oooo0_l0001Yooooo`00POooool2o`0002Wooooo00?o0000ooooooooool09oooool2o`0000oooooo
0_l0000Dooooo`?o0000J?ooool0087ooooo0_l0000Yooooo`03o`000?oooooooooo02Oooooo0_l0
000?ooooo`;o00005Oooool2o`0006Sooooo002:ooooo`;o00008?ooool00ol0003oooooooooo`0A
ooooo`;o00009_ooool2o`0007kooooo002:ooooo`;o00002oooool2o`0001?ooooo00?o0000oooo
ooooool04Oooool2o`0002Kooooo0_l0001nooooo`00Uoooool2o`0001?ooooo00?o0000oooooooo
ool0^Oooool008Wooooo00Gok^k^oc8b<_l0003o0000onk^kP05ooooo`;o8B4Q1?ooool5o`0000Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05
ogMgMonHV9So0000o`000?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool02Oooool2o`0000Gooooo0_l0002W
ooooo`00ROooool01Ol@413oooooo`000?l0003o410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool0
0ol0003oooooooooo`03ooooo`?o00001?ooool2o`0000?ooooo0_l00005ooooo`;o00009?ooool2
o`00087ooooo0029ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool01?ooool2o`0001;ooooo0_l0000L
ooooo`?o0000P?ooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKo
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo01Sooooo0ol0
000Looooo`;o0000P?ooool008Wooooo00Go410@oooooooooooooooooa0@4004ooooo`;o00002Ooo
ool01?l0003oooooooooooooool2o`0000Wooooo00?o0000ooooooooool06Oooool2o`0009kooooo
0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool2o`0000Gooooo00Go0000okZj^_oooooo
V9RHoa0@4003ooooo`;o00002Oooool00ol0003oooooooooo`2iooooo`00ROooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0
003oooooooooo`0?ooooo`;o0000Z?ooool008oooooo0_l0000Kooooo`03o`000?oooooooooo00oo
oooo0_l0000Sooooo`Co0000POooool008oooooo0_l0000Kooooo`03o`000?oooooooooo03Cooooo
1?l00021ooooo`00VOooool2o`00017ooooo00?o0000ooooooooool08_ooool2o`00017ooooo0_l0
0022ooooo`00VOooool2o`00017ooooo0ol0000>ooooo`;o00004_ooool2o`00017ooooo0_l00022
ooooo`00[?ooool01?l0003oooooooooooooool2o`0000_ooooo0_l0000Sooooo`;o0000Q?ooool0
08;ooooo0_l0000Xooooo`04o`000?ooooooooooooooo`;o0000<?ooool2o`0008Cooooo0022oooo
o`;o00008_ooool2o`0000?ooooo0_l0002kooooo`00S?ooool2o`0001Sooooo0_l00003ooooo`;o
00006?ooool2o`000:7ooooo002<ooooo`;o00007_ooool00ol0003oooooooooo`0<ooooo`;o0000
2?ooool2o`000:7ooooo002/ooooo`03o`000?oooooooooo00cooooo0_l00006ooooo`;o0000Xooo
ool00:cooooo00?o0000ooooooooool02oooool2o`0000Oooooo0_l0002Sooooo`00TOooool2o`00
01Wooooo0ol0000;ooooo`?o00001_ooool2o`0000_ooooo0_l0000>ooooo`;o0000Q_ooool008?o
oooo0_l0000<ooooo`;o00006Oooool00ol0003oooooooooo`0<ooooo`;o00004oooool2o`0000ko
oooo0_l00026ooooo`00Poooool2o`0002Cooooo0_l000000ooooooo0000ooooo`0cooooo`;o0000
QOooool008gooooo0_l0000Jooooo`;o000000?oooooo`000?ooool0<oooool2o`0008Gooooo002=
ooooo`;o00002oooool2o`00013ooooo00?o0000ooooooooool02_ooool2o`0000Sooooo0_l0002S
ooooo`00V_ooool2o`00013ooooo00?o0000ooooooooool00_ooool2o`0000Kooooo0_l00008oooo
o`;o00002oooool2o`0009Kooooo002/ooooo`03o`000?oooooooooo00;ooooo0_l0000Mooooo`;o
0000U_ooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0000Booooo`;o0000YOoo
ool009;ooooo0_l00003ooooo`;o00004oooool00ol0003oooooooooo`0Booooo`;o0000YOooool0
09;ooooo0_l00003ooooo`;o00004oooool00ol0003oooooooooo`0Mooooo`;o00004Oooool2o`00
08Oooooo0024ooooo`;o00004Oooool2o`0001?ooooo00?o0000ooooooooool02?ooool2o`0001?o
oooo0_l0000Aooooo`;o0000Qoooool008Cooooo0_l0000Aooooo`;o00004oooool00ol0003ooooo
ooooo`08ooooo`;o0000??ooool2o`00077ooooo002/ooooo`03o`000?oooooooooo04Kooooo0_l0
001aooooo`00Toooool2o`0000Wooooo0_l0000<ooooo`03o`000?oooooooooo01cooooo0ol0002J
ooooo`00Q?ooool2o`0000gooooo0_l00009ooooo`;o00003?ooool00ol0003oooooooooo`0Loooo
o`?o0000V_ooool008Cooooo0_l00004ooooo`;o00005_ooool2o`0000Sooooo0ol00012ooooo`?o
0000M?ooool008Cooooo0_l00004ooooo`;o00005_ooool2o`0000Sooooo0ol00012ooooo`?o0000
M?ooool00:cooooo0ol0002iooooo`00[?ooool3o`0001Wooooo0_l0002Nooooo`00[?ooool00ol0
003oooooooooo`0>ooooo`;o00002Oooool2o`0009kooooo002/ooooo`03o`000?oooooooooo00ko
oooo0_l0000Hooooo`;o0000Soooool008_ooooo0_l00004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00_l00003ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0:?ooool2o`0008oooooo002;ooooo`;o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00;o00000oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2ioooo
o`00TOooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Zooooo`;o0000SOooool0097ooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo00Cooooo0ol0000Yooooo`?o0000SOooool0097ooooo00Go0000oooooooo
ooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0:
ooooo`;o00007Oooool2o`0008kooooo002Aooooo`05oa0@4?ooooooooooooooool@41000_ooool2
o`0000Sooooo0_l00008ooooo`03o`000?oooooooooo00[ooooo0_l0000:ooooo`;o00003oooool2
o`00093ooooo002Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool2o`0000Kooooo1_l00006
ooooo`03o`000?oooooooooo00;o00005?ooool2o`0000oooooo0ol0000Dooooo`;o0000NOooool0
097ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP09ooooo`Oo00001_ooool00ol0003oooooooooo`02
o`0002Kooooo0_l0000Dooooo`;o0000NOooool009oooooo0_l0000;ooooo`03o`000?oooooooooo
02Oooooo0_l0002@ooooo`00[?ooool2o`0002Sooooo0_l0002@ooooo`00[?ooool3o`000;Wooooo
002/ooooo`?o0000>oooool2o`0007cooooo002/ooooo`03o`000?oooooooooo03_ooooo0_l0001l
ooooo`00Qoooool2o`0002?ooooo00?o0000ooooooooool0^Oooool008Oooooo0_l0000Sooooo`03
o`000?oooooooooo027ooooo0_l0002Fooooo`00[?ooool00ol0003oooooooooo`05ooooo`;o0000
6_ooool2o`000003ooooool0003o000009?ooooo002Dooooo`;o00005_ooool00ol0003ooooooooo
o`05ooooo`;o00002_ooool2o`0000kooooo0_l000000ooooooo0000o`00002Cooooo`00U?ooool2
o`0001Kooooo00?o0000ooooooooool04Oooool2o`000:Kooooo002?ooooo`;o00001?ooool2o`00
017ooooo0_l00002ooooo`03o`000?oooooooooo0;Wooooo002?ooooo`;o00001?ooool2o`00017o
oooo0_l00002ooooo`?o0000^Oooool008oooooo0_l0000Kooooo`03o`000?oooooooooo03Sooooo
0_l0001oooooo`00Soooool2o`00013ooooo1?l00007ooooo`03o`000?oooooooooo03Sooooo0_l0
001oooooo`00XOooool4o`0000Oooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool00_l0002gooooo`00[?ooool00ol0003oooooooooo`02o`0000cooooo0_l0002Yooooo`00
[?ooool00ol0003oooooooooo`0>ooooo`;o0000ZOooool009[ooooo0_l0000@ooooo`03o`000?oo
oooooooo03?ooooo0_l00024ooooo`00V?ooool4o`00013ooooo0ol0000:ooooo`;o00009oooool2
o`0008Cooooo002Hooooo`;o00004_ooool00ol0003oooooooooo`0:ooooo`;o0000[Oooool00:co
oooo00?o0000ooooooooool02?ooool2o`0000oooooo0ol0002Mooooo`00[?ooool00ol0003ooooo
ooooo`08ooooo`Co00003Oooool3o`0009gooooo002Booooo`;o00006?ooool00ol0003ooooooooo
o`08ooooo`Co00003?ooool2o`0009oooooo002Booooo`;o00005_ooool3o`0000[ooooo0_l0000>
ooooo`;o0000Woooool00:[ooooo0ol00007ooooo`;o00004Oooool2o`0009oooooo002Zooooo`?o
00001oooool2o`000;;ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o00006?oo
ool2o`0001?ooooo0_l0002:ooooo`00Y?ooool2o`0000Kooooo00?o0000ooooooooool01Oooool2
o`00017ooooo0_l0000Cooooo`;o0000R_ooool00:Cooooo0_l00006ooooo`03o`000?oooooooooo
00Gooooo0_l0002booooo`00[?ooool00ol0003oooooooooo`2iooooo`00UOooool2o`0001Gooooo
00?o0000ooooooooool04_ooool4o`000:?ooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@;o00001?ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01Oooool01?l0003oooooooooooooool2o`0000oooooo1?l0002Sooooo`00ROooool01OmgMgOo
V9RHoooooonHV9SoMgMg00;o00000oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omg
MgOo<S8booooo`04ooooo`04o`000?ooooooooooooooo`;o0000]_ooool008Wooooo00Go410@oooo
oooooooooooooa0@4002o`0000_ooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;o0000]oooool008Wooooo00Go0000ooooooooooooooooo`000009
ooooo`;o00000oooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo1Ol0000W
ooooo`;o0000S_ooool008Wooooo00Go0000ooooooooooooooooo`000009ooooo`;o00000oooool0
0omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool01?l0003oooooo`00
0?l0000@ooooo`;o00005_ooool2o`0008kooooo0029ooooo`05oa0@4?ooooooooooooooool@4100
2Oooool2o`0000;ooooo0_l000000omgMgOoooooooooo`02ooooo`03o`000?oooooooooo00Oooooo
00Co0000ooooool0003o00004?ooool2o`000:Kooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol@413oooooo`000?l0003o<S8b00Cooooo00?o0000ooooooooool01oooool01?l0
003oooooo`000?l0000?ooooo`;o0000Yoooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool03_ooool4o`000:Oooooo002Zoooo
o`?o00004?ooool2o`000:Wooooo002Zooooo`?o0000^oooool00:Sooooo0_l00002ooooo`03o`00
0?oooooooooo0;Wooooo002Xooooo`;o00000_ooool3o`000;Wooooo002Wooooo`;o00000oooool0
0ol0003oooooooooo`2iooooo`00Yoooool2o`0000?ooooo00?o0000ooooooooool08Oooool2o`00
09Kooooo002/ooooo`03o`000?oooooooooo027ooooo0_l0002Fooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00Toooool2o`0001Oooooo00?o0000ooooooooool0^Oooool009?ooooo0_l0000G
ooooo`03o`000?oooooooooo0;Wooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`0Loooo
o`;o0000Voooool009Cooooo0_l0000Fooooo`?o00001Oooool2o`0001Gooooo0_l0002Kooooo`00
U?ooool2o`0001Kooooo00?o0000ooooooooool01Oooool2o`000;;ooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00?ooooo0_l0002dooooo`00UOooool2o`00
01Gooooo00?o0000ooooooooool00_l000000ooooooo0000o`00002dooooo`00UOooool2o`0001Go
oooo00?o0000ooooooooool00_l0002gooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`00
0;Wooooo002Iooooo`?o00004?ooool00ol0003oooooooooo`2iooooo`00VOooool3o`0000kooooo
0ol0002kooooo`00Z_ooool3o`000;_ooooo002Uooooo`;o00001Oooool00ol0003oooooooooo`2i
ooooo`00YOooool2o`0000Gooooo00?o0000ooooooooool0^Oooool00:Gooooo0_l00005ooooo`03
o`000?oooooooooo0;Wooooo002Uooooo`;o00001Oooool00ol0003oooooooooo`2iooooo`00[?oo
ool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002Rooooo`Co000000?o410@ooooooooool00oooool0
0ol0003oooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0;Wooooo002Tooooo`03o`000?oooooooooo00Gooooo0ol0002iooooo`00Y?ooool00ol0003ooooo
ooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31
ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00X_ooool00omEEEGoIVIVo`000033ooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Z_ooool01?l@413o
0000o`000?l0002jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooo
ooooo`2jooooo`00Zoooool01_l0003oMgMgo`000?l0003oEEEEonk^k[Oooooo002[ooooo`06o`00
0?mEEEGok^k^oooooomgMgOoEEEE]oooool00:_ooooo00?o0000onk^k_ooool00_ooool00ol0003o
ooooooooo`2eooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo0;Gooooo
002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoIVIV]oooool00:[ooooo00?o410@o`000?mgMgL0
0_l000000omVIVKok^k^ooooo`2fooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.63746 .59117 Mdot
.56047 .80962 Mdot
.50585 .51327 Mdot
.5341 .3683 Mdot
.43993 .77558 Mdot
.58886 .28474 Mdot
.45953 .65909 Mdot
.38072 .75432 Mdot
.53156 .9235 Mdot
.41526 .57587 Mdot
.47754 .21511 Mdot
.36897 .36832 Mdot
.38229 .60118 Mdot
.428 .30663 Mdot
.39183 .18591 Mdot
.54558 .60886 Mdot
.51698 .80911 Mdot
.38004 .55076 Mdot
.57457 .57214 Mdot
.65223 .30454 Mdot
.38155 .43144 Mdot
.4708 .91294 Mdot
.4217 .83592 Mdot
.38086 .42446 Mdot
.48719 .00889 Mdot
.53892 .25135 Mdot
.5333 .30984 Mdot
.57396 .55934 Mdot
.66964 .3544 Mdot
.54266 .83472 Mdot
.40754 .20523 Mdot
.54236 .91344 Mdot
.40462 .86918 Mdot
.41456 .73474 Mdot
.40082 .33698 Mdot
.61522 .2479 Mdot
.68178 .63142 Mdot
.57336 .47118 Mdot
.68233 .42376 Mdot
.37333 .30194 Mdot
.47281 .00168 Mdot
.3941 .54669 Mdot
.50201 .14429 Mdot
.63756 .61369 Mdot
.64572 .51754 Mdot
.41214 .33484 Mdot
.42695 .32136 Mdot
.60976 .81837 Mdot
.60701 .48691 Mdot
.66723 .36069 Mdot
.61024 .81529 Mdot
.6941 .4824 Mdot
.64623 .86834 Mdot
.45172 .14423 Mdot
.45421 .13604 Mdot
.46593 .97647 Mdot
.3732 .68562 Mdot
.52639 .79551 Mdot
.65192 .73203 Mdot
.64494 .49017 Mdot
.42954 .24515 Mdot
.69219 .25939 Mdot
.68352 .4414 Mdot
.46201 .7317 Mdot
.39406 .81373 Mdot
.50972 .95409 Mdot
.41861 .61106 Mdot
.54859 .5793 Mdot
.57497 .46806 Mdot
.39471 .26708 Mdot
.50984 .82977 Mdot
.46353 .32003 Mdot
.41337 .51282 Mdot
.45364 .75548 Mdot
.68343 .4412 Mdot
.44829 .58488 Mdot
.64566 .86909 Mdot
.49325 .18538 Mdot
.69082 .44874 Mdot
.59928 .46882 Mdot
.5117 .10039 Mdot
.5464 .82702 Mdot
.51722 .3201 Mdot
.39303 .50758 Mdot
.42255 .92785 Mdot
.5463 .61709 Mdot
.43058 .74837 Mdot
.40475 .54034 Mdot
.55531 .74141 Mdot
.54596 .59422 Mdot
.49862 .01796 Mdot
.75246 .61997 Mdot
.42006 .5046 Mdot
.40311 .47496 Mdot
.425 .59401 Mdot
.76106 .57641 Mdot
.42345 .33273 Mdot
.59465 .83498 Mdot
.63402 .88652 Mdot
.55736 .74165 Mdot
.628 .63682 Mdot
.58356 .67092 Mdot
.37124 .34368 Mdot
.62686 .65553 Mdot
.45777 .07673 Mdot
.40382 .66704 Mdot
.47868 .86135 Mdot
.56485 .6298 Mdot
.41998 .49638 Mdot
.40062 .23225 Mdot
.41303 .44491 Mdot
.52669 .34037 Mdot
.54578 .90807 Mdot
.62041 .24637 Mdot
.42045 .99965 Mdot
.43402 .6045 Mdot
.45882 .18186 Mdot
.49623 .97417 Mdot
.52058 .9448 Mdot
.67787 .63086 Mdot
.38212 .59317 Mdot
.65481 .19435 Mdot
.38284 .55693 Mdot
.67259 .35957 Mdot
.39935 .23823 Mdot
.54575 .4219 Mdot
.63684 .28066 Mdot
.76337 .52367 Mdot
.58541 .75005 Mdot
.465 .29102 Mdot
.43164 .8663 Mdot
.61172 .69009 Mdot
.39038 .1839 Mdot
.59416 .29184 Mdot
.53751 .19467 Mdot
.68585 .40964 Mdot
.69412 .58778 Mdot
.65766 .32636 Mdot
.41393 .53239 Mdot
.37769 .71441 Mdot
.39503 .16696 Mdot
.73444 .37035 Mdot
.46494 .25309 Mdot
.57793 .50929 Mdot
.51745 .80892 Mdot
.63728 .27456 Mdot
.45047 .97366 Mdot
.35418 .65407 Mdot
.54485 .68302 Mdot
.40434 .45831 Mdot
.6236 .1443 Mdot
.59182 .64424 Mdot
.55861 .37301 Mdot
.38107 .41265 Mdot
.45011 .35089 Mdot
.62438 .3924 Mdot
.69413 .56009 Mdot
.68767 .45457 Mdot
.48962 .97718 Mdot
.67922 .6367 Mdot
.69432 .56645 Mdot
.58222 .35369 Mdot
.69161 .44384 Mdot
.44191 .01885 Mdot
.58399 .19794 Mdot
.50699 .1553 Mdot
.62739 .62949 Mdot
.45763 .97874 Mdot
.48304 .06881 Mdot
.5729 .45102 Mdot
.69824 .5483 Mdot
.65233 .32651 Mdot
.42934 .37045 Mdot
.56465 .40932 Mdot
.42403 .71769 Mdot
.53513 .713 Mdot
.39329 .81555 Mdot
.76199 .56069 Mdot
.6215 .38313 Mdot
.43592 .60863 Mdot
.67486 .37929 Mdot
.69906 .50749 Mdot
.39669 .14731 Mdot
.50188 .74349 Mdot
.48688 .00352 Mdot
.52242 .38366 Mdot
.53617 .91522 Mdot
.76179 .52284 Mdot
.55901 .89569 Mdot
.43171 .03682 Mdot
.5198 .16708 Mdot
.62433 .15158 Mdot
.63671 .27248 Mdot
.49868 .70879 Mdot
.68024 .24227 Mdot
.39915 .85303 Mdot
.52989 .03927 Mdot
.37742 .27413 Mdot
.40402 .54421 Mdot
.74298 .67435 Mdot
.43302 .81476 Mdot
.4732 .70093 Mdot
.46662 .69832 Mdot
.47641 .31181 Mdot
.44329 .77968 Mdot
.73202 .70656 Mdot
.61843 .66587 Mdot
.53461 .56379 Mdot
.60474 .3236 Mdot
.51996 .31739 Mdot
.53696 .45547 Mdot
.48492 .21601 Mdot
.41575 .82973 Mdot
.48177 .17646 Mdot
.48618 .07027 Mdot
.51539 .70839 Mdot
.62395 .64271 Mdot
.46284 .18191 Mdot
.45034 .00923 Mdot
.52343 .38148 Mdot
.64022 .4752 Mdot
.36544 .42606 Mdot
.44974 .19394 Mdot
.63731 .75731 Mdot
.4634 .07072 Mdot
.54216 .13963 Mdot
.52957 .66319 Mdot
.48989 .80518 Mdot
.58315 .77204 Mdot
.42406 .41499 Mdot
.39353 .17643 Mdot
.66307 .20396 Mdot
.55525 .52983 Mdot
.51407 .47794 Mdot
.72318 .72179 Mdot
.59949 .58732 Mdot
.52743 .29186 Mdot
.64194 .17731 Mdot
.56998 .4384 Mdot
.61959 .68079 Mdot
.38559 .6251 Mdot
.61789 .67236 Mdot
.69316 .2633 Mdot
.55781 .22362 Mdot
.52685 .1109 Mdot
.51087 .82807 Mdot
.54516 .91295 Mdot
.43037 .63232 Mdot
.69068 .55744 Mdot
.56429 .70855 Mdot
.51591 .82006 Mdot
.68484 .44169 Mdot
.5212 .03163 Mdot
.43589 .61658 Mdot
.49461 .71456 Mdot
.68641 .58855 Mdot
.54916 .27659 Mdot
.5615 .39646 Mdot
.47281 .11993 Mdot
.44358 .54654 Mdot
.37714 .71801 Mdot
.63147 .77828 Mdot
.60613 .53625 Mdot
.52646 .28948 Mdot
.55748 .15947 Mdot
.43521 .38558 Mdot
.59169 .63844 Mdot
.63964 .55864 Mdot
.44102 .26595 Mdot
.57143 .25778 Mdot
.63381 .28534 Mdot
.57577 .34604 Mdot
.62348 .25776 Mdot
.46792 .12378 Mdot
.41704 .6038 Mdot
.6037 .49985 Mdot
.69571 .55054 Mdot
.49478 .75868 Mdot
.53234 .72945 Mdot
.59694 .83642 Mdot
.47161 .21195 Mdot
.61878 .36683 Mdot
.68163 .40191 Mdot
.46892 .282 Mdot
.47561 .76835 Mdot
.67785 .6389 Mdot
.36623 .44585 Mdot
.56299 .63885 Mdot
.43473 .47705 Mdot
.48111 .8052 Mdot
.59368 .199 Mdot
.40747 .39054 Mdot
.4897 .07836 Mdot
.76098 .52461 Mdot
.6535 .72301 Mdot
.37323 .32893 Mdot
.64583 .73551 Mdot
.50199 .62242 Mdot
.66979 .68876 Mdot
.66595 .2225 Mdot
.56558 .15753 Mdot
.38408 .23322 Mdot
.34985 .42451 Mdot
.60266 .46435 Mdot
.51897 .16036 Mdot
.6097 .69892 Mdot
.54288 .91456 Mdot
.46705 .00563 Mdot
.43652 .27717 Mdot
.59656 .83498 Mdot
.55848 .29625 Mdot
.50746 .63786 Mdot
.41594 .82773 Mdot
.50372 .83165 Mdot
.38511 .63334 Mdot
.60945 .12704 Mdot
.42851 .53384 Mdot
.64145 .50503 Mdot
.4001 .63511 Mdot
.38126 .73431 Mdot
.4364 .37318 Mdot
.4049 .11474 Mdot
.60674 .13675 Mdot
.74658 .39859 Mdot
.55383 .492 Mdot
.59566 .29212 Mdot
.39267 .49608 Mdot
.68807 .47668 Mdot
.48978 .80793 Mdot
.49342 .68552 Mdot
.48251 .66899 Mdot
.49356 .85031 Mdot
.36525 .5586 Mdot
.68521 .585 Mdot
.42733 .61714 Mdot
.44091 .89031 Mdot
.47235 .28463 Mdot
.47929 .31285 Mdot
.57783 .78178 Mdot
.57958 .26419 Mdot
.50827 .15688 Mdot
.5825 .35552 Mdot
.45341 .79688 Mdot
.67421 .82736 Mdot
.56051 .30524 Mdot
.55912 .8026 Mdot
.45691 .72329 Mdot
.42754 .932 Mdot
.52435 .28939 Mdot
.65252 .31519 Mdot
.50865 .88039 Mdot
.43278 .3368 Mdot
.42862 .25752 Mdot
.7332 .36445 Mdot
.36645 .41458 Mdot
.67468 .67906 Mdot
.62296 .26084 Mdot
.59923 .42985 Mdot
.4361 .81929 Mdot
.64704 .31127 Mdot
.59651 .61233 Mdot
.36656 .41422 Mdot
.75067 .40254 Mdot
.53497 .12077 Mdot
.38854 .19529 Mdot
.41255 .08895 Mdot
.50534 .36377 Mdot
.60325 .55361 Mdot
.39888 .15003 Mdot
.37631 .71354 Mdot
.51131 .38612 Mdot
.45522 .0834 Mdot
.5632 .31746 Mdot
.60605 .32304 Mdot
.6312 .62277 Mdot
.58016 .85706 Mdot
.61997 .67845 Mdot
.67516 .66229 Mdot
.68836 .54034 Mdot
.43041 .85923 Mdot
.68337 .65108 Mdot
.43862 .87956 Mdot
.45483 .01559 Mdot
.3894 .90735 Mdot
.66916 .66366 Mdot
.62886 .40366 Mdot
.44504 .37636 Mdot
.5673 .08754 Mdot
.56484 .72183 Mdot
.48857 .66046 Mdot
.40107 .12675 Mdot
.398 .24544 Mdot
.49936 .67195 Mdot
.43841 .71924 Mdot
.51121 .20572 Mdot
.5389 .32028 Mdot
.60148 .83322 Mdot
.46763 .06516 Mdot
.67684 .23876 Mdot
.40226 .12358 Mdot
.45559 .84722 Mdot
.6819 .80954 Mdot
.44187 .82906 Mdot
.54097 .69912 Mdot
.52671 .73736 Mdot
.48415 .34507 Mdot
.36672 .59101 Mdot
.368 .38718 Mdot
.52981 .3011 Mdot
.43354 .33737 Mdot
.52457 .27742 Mdot
.53141 .67128 Mdot
.57813 .09158 Mdot
.40338 .54291 Mdot
.579 .18794 Mdot
.48426 .25361 Mdot
.56153 .38595 Mdot
.44427 .33635 Mdot
.4115 .64835 Mdot
.42695 .78485 Mdot
.54211 .32361 Mdot
.53124 .58905 Mdot
.6401 .16993 Mdot
.38018 .73611 Mdot
.4671 .38078 Mdot
.40846 .27864 Mdot
.47795 .86136 Mdot
.63334 .44753 Mdot
.57355 .34593 Mdot
.56812 .42253 Mdot
.56912 .08749 Mdot
.76015 .60273 Mdot
.6085 .70803 Mdot
.63432 .63315 Mdot
.52469 .62686 Mdot
.50224 .95562 Mdot
.40817 .11378 Mdot
.49138 .22521 Mdot
.50376 .88551 Mdot
.6666 .83882 Mdot
.44185 .30257 Mdot
.5147 .61472 Mdot
.51948 .74758 Mdot
.55107 .14921 Mdot
.59489 .42814 Mdot
.74789 .65024 Mdot
.53133 .42341 Mdot
.42281 .21571 Mdot
.39623 .59955 Mdot
.43944 .68281 Mdot
.42913 .53748 Mdot
.47214 .77385 Mdot
.37924 .74233 Mdot
.42785 .465 Mdot
.68803 .42661 Mdot
.582 .77027 Mdot
.64366 .51861 Mdot
.6296 .26733 Mdot
.46448 .0779 Mdot
.48115 .8561 Mdot
.7663 .51262 Mdot
.4322 .69677 Mdot
.36462 .5338 Mdot
.51707 .02644 Mdot
.44437 .25785 Mdot
.67171 .68544 Mdot
.57485 .34686 Mdot
.53069 .78129 Mdot
.65029 .30889 Mdot
.62891 .63603 Mdot
.56995 .5995 Mdot
.42987 .2521 Mdot
.4185 .75508 Mdot
.68809 .24514 Mdot
.53781 .19839 Mdot
.45417 .61458 Mdot
.48925 .13291 Mdot
.60061 .47361 Mdot
.49946 .34251 Mdot
.55285 .5245 Mdot
.44348 .15704 Mdot
.52648 .17573 Mdot
.45076 .67549 Mdot
.5357 .25154 Mdot
.50571 .95861 Mdot
.45027 .79786 Mdot
.64064 .53461 Mdot
.57795 .47468 Mdot
.57072 .57079 Mdot
.52379 .46015 Mdot
.52517 .48602 Mdot
.56936 .79566 Mdot
.62802 .77109 Mdot
.58799 .20286 Mdot
.57644 .48896 Mdot
.66535 .3479 Mdot
.38393 .21817 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001?ooool2o`00
00Oooooo0ol0002iooooo`00Xoooool2o`0000;ooooo0_l00003ooooo`03o`000?oooooooooo0;Wo
oooo002Qooooo`;o000000Coooooo`000?oooooooooo0_l00003ooooo`03o`000?oooooooooo0;Wo
oooo002Kooooo`;o00001?ooool2o`000004ooooool0003oooooooooo`;o00000oooool00ol0003o
ooooooooo`2iooooo`00Voooool2o`0000Oooooo00?o0000ooooooooool00_l00003ooooo`03o`00
0?oooooooooo0;Wooooo002Mooooo`;o00000oooool00omEEEGoIVIVo`000007ooooo`03o`000?oo
oooooooo0;Wooooo002Hooooo`;o00000oooool2o`0000cooooo0_l0002kooooo`00V?ooool2o`00
017ooooo0_l0002kooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo00;ooooo
0_l0002eooooo`00[?ooool00ol0003oooooooooo`02ooooo`Co0000/oooool00:cooooo00?o0000
ooooooooool01?ooool2o`000;?ooooo002Eooooo`;o00005Oooool00ol0003oooooooooo`2ioooo
o`00UOooool2o`0001Gooooo00?o0000ooooooooool01_ooool2o`000;7ooooo002/ooooo`03o`00
0?oooooooooo00Kooooo0_l0002aooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Q
ooooo`;o00002Oooool00ol0003oooooooooo`2iooooo`00XOooool2o`0000Wooooo00?o0000oooo
ooooool0^Oooool009oooooo0_l00005ooooo`?o00000oooool00ol0003oooooooooo`2iooooo`00
Woooool2o`0000Gooooo0ol00003ooooo`03o`000?oooooooooo0;Wooooo002Nooooo`;o00003?oo
ool3o`000;Wooooo002Nooooo`Co00001_ooool2o`0000;ooooo00?o0000ooooooooool0^Oooool0
09gooooo0_l000000ooooooo0000o`000006ooooo`;o00000_ooool00ol0003oooooooooo`2ioooo
o`00WOooool2o`0000gooooo00?o0000ooooooooool0^Oooool008oooooo0_l0000Kooooo`03o`00
0?oooooooooo01?ooooo0_l0002Tooooo`00Soooool2o`0001_ooooo00?o0000ooooooooool04ooo
ool2o`000003ooooool0003o00000:7ooooo002/ooooo`03o`000?oooooooooo01Kooooo0_l0002Q
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool5o`000;Oooooo002/ooooo`03o`00
0?oooooooooo00;o0000]oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool008gooooo0_l0000Mooooo`03o`000?oooooooooo00Gooooo0_l0002boooo
o`00S?ooool3o`0001gooooo00?o0000ooooooooool01Oooool2o`000;;ooooo0029ooooo`03onk^
k_lb<S;o000000;o00001Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000
o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0^Oooool008Wooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`05ooooo`;o000000?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`08ooooo`;o0000[oooool0087ooooo1_l00002ooooo`05oa0@
4?oooooo0000o`000?l@41003Oooool00onYZJWoEEEEooooo`03ooooo`Co000000?oooooo`000?oo
ool01?ooool3o`0000Sooooo0_l0002_ooooo`00ROooool00ol0003oooooo`000002o`0000kooooo
00?o8B4Qooooooooool00_ooool2o`0000;ooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`0Qooooo`;o0000U_ooool008Wooooo00?o0000ooooool000000_l0000>ooooo`03oeEEEOo<
c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo027ooooo
0_l0002Fooooo`00ROooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool0
0oooool00ol0003oooooooooo`03ooooo`;o00000_ooool00ol0003oooooooooo`2iooooo`00ROoo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o410@ooooooooool00_l00004ooooo`03o`00
0?oooooooooo00?ooooo0_l00002ooooo`03o`000?oooooooooo023ooooo0_l0002Gooooo`00ROoo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool00ol0003ooooo
ooooo`0:ooooo`;o00005?ooool2o`0009Oooooo002/ooooo`03o`000?oooooooooo00[ooooo0_l0
002]ooooo`00W?ooool2o`0000kooooo0_l0000Vooooo`;o0000T_ooool008Wooooo0ol0000@oooo
o`;o00003_ooool2o`0000kooooo0_l0000Fooooo`;o0000T_ooool008Wooooo0ol0000Pooooo`?o
00003Oooool2o`0001Oooooo0_l0002Aooooo`00[?ooool01?l0003oooooo`000?l0000Uooooo`;o
0000TOooool009Wooooo0_l0000Aooooo`04o`000?oooooo0000o`00017ooooo0_l0002Uooooo`00
VOooool2o`00017ooooo00Co0000ooooool0003o00000_ooool2o`0000_ooooo1?l0002Uooooo`00
[?ooool00ol0003oooooooooo`03ooooo`;o00002oooool2o`000:Oooooo0029ooooo`;o00008Ooo
ool00ol0003oooooooooo`03ooooo`;o0000]?ooool008Wooooo0_l0000Qooooo`03o`000?oooooo
oooo00?ooooo0_l0000Vooooo`;o0000S?ooool00:cooooo00?o0000ooooooooool0:oooool2o`00
08cooooo0028ooooo`;o00007?ooool2o`0000Cooooo0ol00005ooooo`;o00009?ooool2o`0008co
oooo0028ooooo`;o00007?ooool2o`0000Cooooo00?o0000ooooooooool01Oooool2o`0002Cooooo
0_l0002<ooooo`00W_ooool3o`0000_ooooo00?o0000ooooooooool0^Oooool008Oooooo0ol0000D
ooooo`?o00002?ooool2o`000003ooooool0003ooooo0;[ooooo0027ooooo`?o00007oooool2o`00
0003ooooool0003ooooo01Sooooo0_l0002Pooooo`00[?ooool00ol0003oooooooooo`0Gooooo`;o
0000X?ooool008Oooooo0_l0000Booooo`;o00003oooool00ol0003oooooooooo`09ooooo`;o0000
9Oooool2o`0008Oooooo0027ooooo`;o00004_ooool2o`0000oooooo00?o0000ooooooooool02Ooo
ool2o`0000gooooo0_l0000Fooooo`;o0000Qoooool00:cooooo0ol00009ooooo`;o00003Oooool2
o`000003ooooool0003o000009cooooo002/ooooo`03o`000?oooooooooo01[ooooo0ol0000Eoooo
o`;o0000QOooool008gooooo0_l0000Mooooo`03o`000?oooooooooo00;o00006?ooool2o`0001Ko
oooo0_l00025ooooo`00SOooool2o`0001gooooo00?o0000ooooooooool00_l0002gooooo`00X_oo
ool2o`0000Sooooo00?o0000ooooooooool0^Oooool009;ooooo0_l0000>ooooo`Co000000?ooooo
o`000?l000000oooool00ol0003oooooooooo`2iooooo`00QOooool2o`0000_ooooo0_l0000@oooo
o`;o000000?oooooo`000?l000000oooool00ol0003oooooooooo`2iooooo`00QOooool2o`0002Go
oooo00?o0000ooooooooool0<oooool2o`0008Cooooo002Yooooo`;o000000Coooooo`000?l0003o
00004?ooool2o`00027ooooo0_l00024ooooo`00ZOooool2o`000003ooooool0003ooooo017ooooo
0_l0002Wooooo`00[?ooool00ol0003oooooooooo`2iooooo`00QOooool2o`0000Cooooo0_l0000O
ooooo`03o`000?oooooooooo0;Wooooo0025ooooo`;o00001?ooool2o`0001oooooo00?o0000oooo
ooooool0^Oooool008[ooooo0_l0000Pooooo`03o`000?oooooooooo03Oooooo0_l00020ooooo`00
R_ooool2o`0000Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0=oooool3o`0007oooooo002:ooooo`;o
00001Oooool00omgMgOoV9RHooooo`02o`0000Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool09?ooool2o`0001;ooooo0_l000000ooooooo0000o`00001looooo`00
ROooool6o`0000;ooooo00?o410@ooooooooool00_l0000@ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool08oooool3o`0001Gooooo0_l0001looooo`00TOooool00ol0003ooooooooo
o`02o`0000[ooooo0_l00003ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00008ooooo`?o00006?oo
ool2o`0009Cooooo002Aooooo`03o`000?oooooooooo00;o00002_ooool3o`000003ob4Q8Ol0003o
<S8b00;o00001?ooool00ol0003oooooooooo`08ooooo`?o0000[_ooool0097ooooo00?o410@oooo
ooooool00_l00003ooooo`;o00001oooool01?l0003oooooooooooooool2o`0000Cooooo00?o0000
ooooooooool05?ooool2o`0000oooooo0_l0002Booooo`00TOooool00omgMgOoV9RHooooo`02o`00
00?ooooo0_l00007ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05?ooool2o`00
00oooooo0_l0000Eooooo`;o0000Noooool0097ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`Co00001_ooool00ol0003oooooooooo`0Gooooo`;o00003?ooool2o`0001Gooooo0_l0001koooo
o`00ROooool2o`0000gooooo0_l0000Booooo`03o`000?oooooooooo01Oooooo0_l0000>ooooo`;o
00004oooool2o`0007_ooooo0029ooooo`;o00003Oooool2o`0001;ooooo00?o0000ooooooooool0
9oooool2o`00093ooooo0023ooooo`;o00009oooool00ol0003oooooooooo`0Zooooo`;o0000SOoo
ool008?ooooo0_l0000Booooo`;o00004oooool3o`0000gooooo0_l0000Kooooo`;o0000SOooool0
08gooooo0_l00008ooooo`;o00004oooool00ol0003oooooooooo`05ooooo`;o00001_ooool2o`00
01_ooooo0_l0002=ooooo`00SOooool2o`0001;ooooo0_l00009ooooo`03o`000?oooooooooo00Go
oooo0_l0000Sooooo`;o0000SOooool00:7ooooo0ol00008ooooo`03o`000?oooooooooo01[ooooo
0_l0000=ooooo`?o0000SOooool00:;ooooo0_l00008ooooo`03o`000?oooooooooo00Gooooo0_l0
000Cooooo`;o00003Oooool2o`0008kooooo002Pooooo`;o00002_ooool00ol0003oooooooooo`05
ooooo`?o00005?ooool2o`0009_ooooo002Pooooo`;o00002_ooool00ol0003oooooooooo`06oooo
o`;o00005?ooool2o`0009_ooooo002/ooooo`03o`000?oooooooooo013ooooo0_l0002Wooooo`00
[?ooool3o`0000Kooooo0_l00008ooooo`;o0000Yoooool008;ooooo0_l0000Dooooo`;o00004_oo
ool00ol0003oooooooooo`06ooooo`;o00009oooool2o`0008Sooooo0022ooooo`;o00004?ooool2
o`0000;ooooo0_l0000Booooo`03o`000?oooooooooo017ooooo0_l0000Looooo`;o0000R?ooool0
09Cooooo0_l0000Fooooo`03o`000?oooooooooo00Sooooo0_l00007ooooo`;o00006oooool2o`00
08Wooooo002Tooooo`?o00001Oooool00ol0003oooooooooo`08ooooo`;o00008oooool3o`0008Wo
oooo002Tooooo`?o00001Oooool00ol0003oooooooooo`0]ooooo`Co0000R?ooool00:cooooo00?o
0000ooooooooool00oooool2o`0000cooooo0_l0000Looooo`;o0000R?ooool009?ooooo0_l0000;
ooooo`;o00002_ooool00ol0003oooooooooo`02ooooo`?o00001?ooool2o`0000Kooooo0_l0002V
ooooo`00Toooool2o`0000_ooooo0_l0000:ooooo`?o00000_ooool2o`0000Gooooo0ol0000Coooo
o`?o0000Uoooool00:cooooo00?o0000ooooooooool02_ooool2o`0001?ooooo0ol0000=ooooo`Co
0000Q_ooool008;ooooo0_l0000Xooooo`03o`000?oooooooooo02oooooo1?l00026ooooo`00P_oo
ool2o`0000_ooooo0_l000000ooooooo0000o`00000Hooooo`03o`000?oooooooooo0;Wooooo002;
ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`?o000000?oooooo`000?l000004Ooo
ool00ol0003oooooooooo`2iooooo`00Roooool2o`0000Sooooo0ol000000ooooooo0000o`00000A
ooooo`03o`000?oooooooooo00Gooooo0_l0002booooo`00POooool2o`0002Sooooo0_l00007oooo
o`;o0000/_ooool0087ooooo0_l0000Sooooo`;o00000oooool2o`0001Oooooo0ol0002Qooooo`00
Y_ooool2o`0000Cooooo00?o0000ooooooooool05Oooool3o`0001_ooooo0_l00024ooooo`00Vooo
ool2o`0000oooooo0ol0000cooooo`;o0000Q?ooool009_ooooo0_l0000?ooooo`03o`000?oooooo
oooo01Sooooo0_l0000Kooooo`;o0000P_ooool00:cooooo00?o0000ooooooooool06?ooool2o`00
01_ooooo0_l00022ooooo`00[?ooool00ol0003oooooooooo`0dooooo`Co0000POooool00:cooooo
0ol0000dooooo`Co00004_ooool2o`0006gooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool3o`0002Co
oooo0_l0000Tooooo`;o0000KOooool0083ooooo0_l00007ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool00olQ8B7o0000o`000003ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo00Sooooo0_l0000Jooooo`;o00009?ooool2o`00
06gooooo0020ooooo`Oo00000_ooool01Ol@413ooooooooooooooooo410@00Kooooo0_l000001ooo
oooo0000o`000?ooooooV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Sooooo0_l00006ooooo`;o0000>?ooool2o`0006gooooo0029ooooo`05o`000?oooooo
ooooooooool000002Oooool4o`000003oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?oo
ool3o`00013ooooo0_l0002Wooooo`00ROooool01Ol0003ooooooooooooooooo000000_ooooo0_l0
00000oooooooMgMgofIVIP04ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`0fooooo`;o0000POooool008Wooooo00Go410@oooooooooooooooooa0@400?ooooo`04o`00
0?ooooooooooooooo`;o00002Oooool00ol0003oooooooooo`04ooooo`;o00007oooool2o`0000oo
oooo0_l00021ooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo0_l000001_oooooo
0000okZj^_ooooooV9RHoa0@40?ooooo0_l00009ooooo`03o`000?oooooooooo00;o00000_ooool2
o`0000_ooooo0_l0000Booooo`;o0000T_ooool0083ooooo0_l00007ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02?ooool2o`000006oooooonHV9So410@o`000?lQ8B7oc<c<1?ooool4o`0000Kooooo
00?o0000ooooooooool00_l00002ooooo`;o00002oooool2o`000:Kooooo0020ooooo`;o00002ooo
ool2o`0001gooooo00?o0000ooooooooool09_ooool2o`00097ooooo002=ooooo`;o00007Oooool0
0ol0003oooooooooo`0Vooooo`;o0000TOooool00:cooooo00?o0000ooooooooool04Oooool2o`00
0:Kooooo002/ooooo`?o00004Oooool2o`0003_ooooo0_l0001Yooooo`00[?ooool00ol0003ooooo
ooooo`0Wooooo`;o00004?ooool2o`0001?ooooo0ol0001Xooooo`00[?ooool00ol0003ooooooooo
o`0Wooooo`;o00004?ooool2o`0001Cooooo0_l0001Xooooo`00[?ooool00ol0003oooooooooo`0B
ooooo`;o00009_ooool2o`0007gooooo0024ooooo`;o00009_ooool00ol0003oooooooooo`0Boooo
o`;o00009_ooool2o`0007gooooo001oooooo`?o00000_ooool2o`0000cooooo0_l0000Hooooo`03
o`000?oooooooooo0;Wooooo001oooooo`?o00004?ooool2o`0001Sooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool03?ooool2o`0000Gooooo0_l0002Tooooo`00N_ooool2
o`0000Sooooo0_l0000Vooooo`?o00001oooool2o`0000?ooooo0_l00005ooooo`;o00009?ooool2
o`0007kooooo001jooooo`;o00000oooool2o`0000?ooooo0_l0000Vooooo`03o`000?oooooooooo
00Oooooo0_l0000Cooooo`;o00006oooool4o`0007cooooo001oooooo`;o00000oooool2o`0002Ko
oooo00?o0000ooooooooool07?ooool3o`0001cooooo0_l0001looooo`00Q?ooool2o`0002Kooooo
00?o0000ooooooooool07Oooool2o`0009[ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`03o`000?oooooooooo01Cooooo0_l0002Sooooo`00[?ooool00ol0003oooooooooo`0Doooo
o`;o00008oooool5o`0007_ooooo001oooooo`;o00003_ooool2o`0001_ooooo00?o0000oooooooo
ool0>Oooool5o`0007_ooooo001oooooo`;o00003_ooool2o`0001_ooooo00?o0000ooooooooool0
:Oooool2o`00017ooooo0_l0001kooooo`00[?ooool3o`0001Gooooo0_l0000Booooo`;o00004Ooo
ool2o`0007_ooooo002/ooooo`03o`000?oooooooooo00Wooooo0_l0000:ooooo`;o00009?ooool2
o`0007cooooo002<ooooo`;o00007_ooool00ol0003oooooooooo`09ooooo`;o0000<?ooool2o`00
07cooooo0009ooooo`Co000000?o410@ooooooooool05_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0?
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8b
omgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1_l00003ooooo`05
odA4A?l0003o0000oc8b<_oMgMd05_ooool00ol0003oooooooooo`04ooooo`;o00004_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0
003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd06?ooool4o`000003oa0@4?oooooo
oooo01;ooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`;o
00005_ooool00ol0003oooooooooo`04ooooo`;o00004_ooool01_mgMgOoV9RHoooooonHV9SoMgMg
ooooo`;o00000_ooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb
<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8b
ooooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOoo
ool01oooool00omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo0006o`0000Gooooo
00?o0000ooooooooool04?ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03
ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool01Oooool6o`0000;ooooo00Go410@oooooooo
oooooooooa0@400@ooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP08ooooo`;o00005_ooool00ol0003oooooooooo`0E
ooooo`;o000000?ooooooa0@4?ooool00_ooool01?l@413oooooo`000?l00009ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool03Oooool01Ol@413ooooooooooooooooo410@013ooooo
00?o0000ooooooooool03Oooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOoo
ool02?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`00
0?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Ko
oooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b
<_ooool03_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool0
0omgMgOo<S8booooo`0Eooooo`03o`000?oooooooooo01Gooooo0_l000000ooooooo0000ooooo`02
ooooo`?o00002oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool06Oooool00ol0003ooooo
ooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool00000
3_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003o
oooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?oooooo
ooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
5_ooool00ol0003oooooooooo`0Eooooo`;o000000?oooooo`000?ooool00_ooool4o`0000_ooooo
00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000oooooooo
ooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooo
oooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[ooooo
00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`0Aooooo`05oa0@
4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0Aooooo`05oa0@4?oooooooooooooo
ool@41003oooool2o`0000?ooooo00?o0000ooooooooool00_ooool2o`0001Cooooo0ol0000Foooo
o`;o000000Ko410@oooooooooooooooooa0@4?ooool2o`0000_ooooo0_l00004ooooo`03o`000?oo
oooooooo00Oooooo0_l00008ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool0
6?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04oooo
o`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooo
oooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`04o`000?nj^[[ooooooiRHV0;o0000
0oooool00ol0003oooooooooo`02ooooo`;o00005?ooool01?l0003oooooooooooooool2o`0001?o
oooo0_l000001OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000okZj^_ooool00_l00004oooo
o`03o`000?oooooooooo00Oooooo0_l00008ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooo
oooooooo<S8b00Cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Dooooo`002Ooo
ool00omEEEGoIVIVo`00000Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo
1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00013ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0001Oooooo00Co0000
oooooooooooooooo0_l0000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@
o`000?lQ8B7oc<c<00Cooooo1?l00008ooooo`;o00001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000I
ooooo`03oeEEEOmVIVKo000001Kooooo002/ooooo`03o`000?oooooooooo00Gooooo0_l0000foooo
o`;o0000N_ooool00:cooooo00?o0000ooooooooool01Oooool2o`0000oooooo0_l00008ooooo`;o
0000Uoooool00:cooooo00?o0000ooooooooool03_ooool2o`0000Kooooo0_l00008ooooo`;o0000
2_ooool2o`00083ooooo0_l00002ooooo`;o00001Oooool00:cooooo00?o0000ooooooooool03_oo
ool2o`0001cooooo0_l00020ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1Oooool008Sooooo
0_l00007ooooo`;o00006Oooool00ol0003oooooooooo`2_ooooo`04omgMgOl0003o410@olc<c0Ko
oooo0007oooooooo0000C?l0000<ooooo`04onk^k_lQ8B7o410@onk^kPKooooo0007ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`?o0000
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0:ooooo`04ob4Q8OmgMgOoMgMgoc8b<PKooooo0007ooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo00;ooooo0_l00007ooooo`;o00006Oooool00ol0003oooooooooo`0Wooooo`04o`00
0?ooooooooooooooo`;o00004Oooool2o`00013ooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo00Wooooo0_l00002ooooo`;o00001Oooool008Sooooo
0_l00007ooooo`;o00006Oooool00ol0003oooooooooo`0Fooooo`;o00004oooool2o`00017ooooo
0_l0001iooooo`00Soooool2o`0001_ooooo0ol0000Fooooo`;o0000??ooool2o`0006?ooooo002?
ooooo`;o00006oooool3o`0005Cooooo0_l0001Sooooo`00[?ooool00ol0003oooooooooo`0/oooo
o`?o0000R_ooool00:cooooo00?o0000ooooooooool0;?ooool3o`0008[ooooo002/ooooo`?o0000
3_ooool2o`0004?ooooo0ol0001Sooooo`00[?ooool00ol0003oooooooooo`0>ooooo`;o0000@ooo
ool3o`0006?ooooo002/ooooo`03o`000?oooooooooo00oooooo0_l0002Xooooo`00Ooooool2o`00
00kooooo0_l00003ooooo`;o00005_ooool00ol0003oooooooooo`0?ooooo`;o00006_ooool2o`00
08cooooo001oooooo`;o00003_ooool2o`0000?ooooo0_l0000Fooooo`03o`000?oooooooooo023o
oooo0_l00009ooooo`;o0000S?ooool008cooooo0_l00006ooooo`;o00005_ooool00ol0003ooooo
ooooo`0Pooooo`;o00006Oooool2o`0007cooooo002<ooooo`;o00007_ooool00ol0003ooooooooo
o`0kooooo`;o0000O?ooool008Wooooo0_l000000ooooooo0000o`00000;ooooo`;o00004Oooool0
0ol0003oooooooooo`2iooooo`00ROooool2o`000003ooooool0003o000000_ooooo0_l0000Aoooo
o`03o`000?oooooooooo03kooooo0_l0001iooooo`00Q?ooool2o`0002Kooooo0ol0000mooooo`?o
0000NOooool008Cooooo0_l0000Vooooo`03o`000?oooooooooo01oooooo0_l0000Looooo`;o0000
N_ooool007oooooo0_l00004ooooo`;o00009Oooool00ol0003oooooooooo`0Oooooo`;o00002_oo
ool2o`0000oooooo0_l0001kooooo`00Ooooool2o`0000Cooooo0_l0000Uooooo`03o`000?oooooo
oooo01Gooooo0_l0000Dooooo`;o00003oooool3o`0001Cooooo0_l0001Tooooo`00[?ooool00ol0
003oooooooooo`08ooooo`;o00002oooool2o`0002Kooooo0_l0000Dooooo`;o0000I?ooool00:co
oooo00?o0000ooooooooool02?ooool2o`0003?ooooo0_l0001jooooo`00[?ooool00ol0003ooooo
ooooo`0Dooooo`;o00009oooool2o`0007[ooooo002/ooooo`03o`000?oooooooooo01Cooooo0ol0
002Rooooo`00T?ooool2o`0001[ooooo0ol0000Eooooo`;o0000??ooool2o`0006Cooooo002@oooo
o`;o00006_ooool00ol0003oooooooooo`0=ooooo`;o0000A?ooool2o`0006Cooooo002/ooooo`03
o`000?oooooooooo00gooooo0_l0002Zooooo`00V_ooool2o`00013ooooo00?o0000ooooooooool0
>_ooool2o`0007gooooo002Jooooo`;o00004?ooool00ol0003oooooooooo`07ooooo`;o00005?oo
ool2o`0001_ooooo0_l000000ooooooo0000o`00001jooooo`00P?ooool2o`0002[ooooo00?o0000
ooooooooool01oooool2o`0001Cooooo0_l0000;ooooo`;o00003_ooool2o`000003ooooool0003o
000007[ooooo0020ooooo`;o00000oooool2o`0000cooooo0_l0000Gooooo`03o`000?oooooooooo
00cooooo0_l0000Looooo`;o0000SOooool008Gooooo0_l0000<ooooo`;o00005oooool00ol0003o
ooooooooo`0<ooooo`;o0000Zoooool008Gooooo0_l00002ooooo`;o00008Oooool3o`0001Cooooo
0_l0002Sooooo`00QOooool2o`0000;ooooo0_l00005ooooo`;o00001?ooool2o`0001Cooooo00?o
0000ooooooooool05?ooool2o`0003cooooo0_l0001Uooooo`00T?ooool2o`0000Cooooo0_l0000D
ooooo`03o`000?oooooooooo05;ooooo0_l0001Uooooo`00U_ooool2o`0001Cooooo00?o0000oooo
ooooool03?ooool2o`000:_ooooo002Aooooo`;o00000oooool2o`0001Cooooo00?o0000oooooooo
ool03?ooool2o`0000kooooo0_l0002Kooooo`00TOooool2o`0000?ooooo0_l00004ooooo`;o0000
3_ooool01?l0003oooooooooooooool2o`0001Wooooo0_l0000<ooooo`;o0000SOooool008Wooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03ob4Q8Ol0003o000000;o000000?oooooo`000?l0
00000ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool01?l0003oooooooooooooool2
o`0000Wooooo0_l0000Looooo`;o0000SOooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`03ob4Q8Ol0003o000000?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb
<S;ooooo00Cooooo0_l0000=ooooo`;o0000@_ooool2o`0006Oooooo0026ooooo`;o000000?ooooo
oa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000
ooooooooool00oooool3o`0002Sooooo0_l0000Vooooo`;o0000Ioooool008Kooooo0_l000000ooo
oooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo00Gooooo0_l0000Qooooo`;o0000Soooool008Wo
oooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00Gooooo0_l0000;ooooo`;o00004oooool2
o`0000kooooo1?l0001nooooo`00Q_ooool2o`000003ooooool@413ooooo00;ooooo00?o410@oooo
ooooool01Oooool2o`0000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo01;ooooo0_l0000Cooooo`Co00003?ooool4o`0007kooooo0026ooooo`;o
000000?oooooogMgMonHV9P00_l000000omgMgOoooooooooo`05ooooo`;o00000_ooool01Ol0003o
^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Woooo
o`Co00003Oooool2o`0007oooooo0029ooooo`05onk^k_lb<S;o0000o`000?o^k^h02oooool01OnH
V9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`04o`000?oooooo0000o`00013ooooo0_l0
0008ooooo`;o00002_ooool2o`0000kooooo0ol0001oooooo`00[?ooool01?l0003oooooo`000?l0
000@ooooo`;o00002?ooool2o`0000Sooooo0_l0000@ooooo`;o0000P?ooool00:cooooo00?o0000
ooooooooool06oooool2o`0000Sooooo0_l0002Booooo`00S_ooool2o`0001cooooo00?o0000oooo
ooooool06oooool2o`0009cooooo002>ooooo`;o00007?ooool3o`0003Wooooo0_l0000Cooooo`;o
0000JOooool007_ooooo0_l0000_ooooo`03o`000?oooooooooo02Kooooo0_l0000Aooooo`;o0000
4oooool2o`0006Wooooo001kooooo`;o0000;oooool00ol0003oooooooooo`0Vooooo`;o0000TOoo
ool009kooooo0_l00008ooooo`;o00000_ooool00ol0003oooooooooo`2iooooo`00W_ooool2o`00
00Sooooo0_l00002ooooo`03o`000?oooooooooo00Kooooo0_l0000/ooooo`Co0000POooool008co
oooo0_l0000Nooooo`03o`000?oooooooooo00Kooooo0_l0000Looooo`;o00003_ooool4o`00087o
oooo002<ooooo`;o00006?ooool2o`0000Cooooo00?o0000ooooooooool06?ooool2o`0000[ooooo
0_l0002Cooooo`00Y_ooool2o`0000?ooooo0_l00009ooooo`;o00003oooool2o`0000Wooooo0_l0
002Dooooo`00Voooool2o`0000kooooo1?l00007ooooo`;o00006_ooool2o`0002Sooooo0_l0001Z
ooooo`00Voooool2o`0000oooooo00?o0000ooooooooool09?ooool2o`00013ooooo0_l0000Eoooo
o`;o0000J_ooool009Sooooo0_l0000Booooo`03o`000?oooooooooo00_ooooo0_l0000Gooooo`;o
00004?ooool2o`00087ooooo0022ooooo`;o00005?ooool2o`0000oooooo0_l000000ooooooo0000
ooooo`0<ooooo`;o00005oooool2o`0000oooooo0_l00022ooooo`00P_ooool2o`0002Gooooo0_l0
00000ooooooo0000ooooo`0fooooo`;o0000P_ooool00:cooooo00?o0000ooooooooool08Oooool2
o`0001;ooooo0_l00022ooooo`00[?ooool00ol0003oooooooooo`0Qooooo`;o0000U_ooool009Go
oooo0_l0000:ooooo`;o00002Oooool00ol0003oooooooooo`2iooooo`00UOooool2o`0000[ooooo
1?l00007ooooo`?o00002_ooool2o`0001Gooooo0_l0002Fooooo`00Xoooool2o`0000Oooooo00?o
0000ooooooooool02_ooool2o`0001Gooooo0_l0002Fooooo`00[?ooool00ol0003oooooooooo`19
ooooo`;o0000K_ooool00:_ooooo0_l00004ooooo`;o00003_ooool2o`0000cooooo0_l0000Woooo
o`;o0000K_ooool008?ooooo0_l0000Vooooo`;o00001?ooool2o`0000Cooooo0_l00008ooooo`;o
00003?ooool2o`0009Oooooo0023ooooo`;o00009Oooool3o`0000[ooooo0_l0002_ooooo`00Pooo
ool2o`0000gooooo0_l00003ooooo`;o00004Oooool3o`000;_ooooo0023ooooo`;o00003Oooool2
o`0000?ooooo0_l0000Cooooo`03o`000?oooooooooo01;ooooo0_l0000booooo`;o0000LOooool0
09gooooo0_l0000=ooooo`?o00004_ooool2o`0001_ooooo0_l0000Eooooo`;o0000LOooool009go
oooo0_l0000=ooooo`03o`000?oooooooooo02oooooo0_l00028ooooo`00Woooool2o`0000_ooooo
00?o0000ooooooooool01oooool2o`000;3ooooo0024ooooo`;o00002Oooool2o`0000kooooo0_l0
000;ooooo`03o`000?oooooooooo00Oooooo0_l0000Vooooo`;o0000R?ooool008Cooooo0_l00009
ooooo`;o00006oooool00ol0003oooooooooo`05ooooo`;o00009_ooool4o`0008Sooooo0024oooo
o`;o00009_ooool00ol0003oooooooooo`05ooooo`;o00009_ooool2o`0008[ooooo0024ooooo`;o
00002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool2o`00013ooooo0_l0002Xooooo`00Q?ooool2o`0000_ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`;o00004?ooool2
o`000:Sooooo002Aooooo`04oa0@4?ooooooooooooooo`;o00003oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo0_l0002dooooo`00TOooool01?l0003oooooooooooooool2
o`0000kooooo00?oMgMgoc8b<_ooool01?ooool3o`0000?ooooo0_l0000Dooooo`;o0000W_ooool0
08Cooooo0_l0000;ooooo`;o00000_ooool00ol0003oooooooooo`04ooooo`;o00001?ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool06Oooool2o`0009kooooo0024oooo
o`;o00002oooool2o`0000;ooooo00?o410@ooooooooool01?ooool2o`0000Cooooo00?o0000oooo
ooooool01Oooool3o`0002cooooo0_l0002=ooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool01Oooool3o`0002cooooo0_l0002=ooooo`00TOooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002Tooooo`;o00001_ooool00ol0003oooooooooo`0Hooooo`;o0000
3Oooool2o`00093ooooo002Rooooo`Co00001_ooool00ol0003oooooooooo`0Hooooo`;o00003Ooo
ool2o`00093ooooo002Hooooo`;o00002?ooool2o`0000Sooooo0ol0000Hooooo`;o0000Woooool0
09Sooooo0ol0000Aooooo`03o`000?oooooooooo02Sooooo0_l0002?ooooo`00VOooool2o`00017o
oooo00?o0000ooooooooool01oooool2o`0000gooooo0_l0000@ooooo`;o0000Soooool009?ooooo
0_l0000Gooooo`03o`000?oooooooooo00Oooooo0_l0000=ooooo`;o0000XOooool009?ooooo0_l0
000Gooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002Kooooo`?o00003_ooool00ol0003oooooooooo`05ooooo`;o
00003?ooool2o`000:Cooooo002Kooooo`?o00003_ooool3o`0000Gooooo0_l0000<ooooo`;o0000
Y?ooool00:cooooo00?o0000ooooooooool04?ooool2o`000:Oooooo002Uooooo`;o000000?ooooo
o`000?l000000_ooool00ol0003oooooooooo`0@ooooo`;o0000Yoooool00:Gooooo0_l000000ooo
oooo0000o`000002ooooo`03o`000?oooooooooo00;ooooo0_l0000=ooooo`;o00009_ooool2o`00
07kooooo002Xooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`;o00003Oooool2o`0002Ko
oooo0_l0001nooooo`00R?ooool3o`0000[ooooo0_l0000Eooooo`03o`000?oooooooooo027ooooo
0_l0002Fooooo`00R?ooool3o`0000[ooooo0ol0000Dooooo`03o`000?oooooooooo027ooooo0_l0
002Fooooo`00U_ooool2o`0001Cooooo00?o0000ooooooooool00_ooool2o`0001gooooo0_l0002F
ooooo`00[?ooool3o`0000;ooooo0_l0002eooooo`00T?ooool2o`0001[ooooo00?o0000oooooooo
ool00_l0000:ooooo`;o0000:?ooool2o`00087ooooo002@ooooo`;o00001_ooool2o`0001;ooooo
1Ol0000:ooooo`;o0000:?ooool2o`00087ooooo002@ooooo`;o00001_ooool2o`0001;ooooo1Ol0
0009ooooo`;o00004Oooool2o`0009Wooooo002Booooo`;o00006?ooool00ol0003oooooooooo`0;
ooooo`;o00003oooool4o`0009Wooooo002Booooo`;o00006?ooool00ol0003oooooooooo`0Loooo
o`?o00005Oooool2o`0008?ooooo002/ooooo`03o`000?oooooooooo03Cooooo0_l00023ooooo`00
[?ooool00ol0003oooooooooo`2iooooo`00WOooool2o`0000gooooo00?o0000ooooooooool0^Ooo
ool009gooooo0_l0000:ooooo`;o000000Coooooo`000?l0003o0000^Oooool008[ooooo0_l0000M
ooooo`;o000000?oooooo`000?ooool0^_ooool008[ooooo0_l0000Iooooo`;o00001Oooool00ol0
003oooooooooo`0Gooooo`;o0000X?ooool009Gooooo0_l0000=ooooo`?o00001Oooool00ol0003o
ooooooooo`0Gooooo`;o0000X?ooool009Gooooo0_l0000=ooooo`?o00001Oooool00ol0003ooooo
ooooo`2iooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B42o`0000Cooooo
00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooooooo
ool0^Oooool008Wooooo00?oMgMgoiRHV?ooool00_l00005ooooo`;o8B4Q0_l00004ooooo`03oeEE
EOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0]ooooo`;o0000
R_ooool008Wooooo00?o410@ooooooooool00_l0000=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0]ooooo`;o0000R_ooool008Wooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?oo
ool3o`000;Wooooo0029ooooo`05o`000?ooooooooooooooool000002Oooool2o`0000?ooooo00?o
EEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
^Oooool008Wooooo00Go410@oooooooooooooooooa0@4009ooooo`;o00000oooool00onYZJWoMgMg
ooooo`03ooooo`03o`000?oooooooooo00Oooooo00Co0000ooooool0003o0000^?ooool008Wooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0
003oooooooooo`07ooooo`Co0000^?ooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`Go00001?ooool4o`0000Kooooo0ol0000Yooooo`;o0000S_ooool009Sooooo0_l0000Booooo`03
o`000?oooooooooo02Wooooo0_l0002>ooooo`00V?ooool2o`0001;ooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool04?ooool2o`000:Oooooo002/ooooo`?o00004?ooool2
o`000:Oooooo002/ooooo`03o`000?oooooooooo0;Wooooo0027ooooo`;o00008oooool00ol0003o
ooooooooo`2iooooo`00Qoooool2o`0002?ooooo00?o0000ooooooooool03?ooool2o`000:_ooooo
002Rooooo`;o00002?ooool00ol0003oooooooooo`0;ooooo`?o0000Zoooool00:;ooooo0_l00008
ooooo`03o`000?oooooooooo00Wooooo1?l0002/ooooo`00[?ooool00ol0003oooooooooo`09oooo
o`Co0000[?ooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol00007ooooo`;o0000
/?ooool009;ooooo0_l0000Hooooo`03o`000?oooooooooo00Oooooo0_l0002`ooooo`00T_ooool2
o`0001Sooooo00?o0000ooooooooool0^Oooool009Cooooo0_l0000Fooooo`03o`000?oooooooooo
0;Wooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`03
ooooo`;o0000]?ooool00:cooooo00?o0000ooooooooool00oooool2o`000;Cooooo002/ooooo`?o
0000^Oooool00:cooooo0_l000000ooooooo0000o`00002gooooo`00[?ooool5o`000;Oooooo002/
ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool009_ooooo0_l0000?ooooo`03o`000?oo
oooooooo0;Wooooo002Kooooo`;o00000oooool2o`0000Sooooo1Ol0002iooooo`00W_ooool4o`00
00Kooooo1Ol0002kooooo`00W_ooool2o`0000Sooooo0_l00002ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`03o`000?oooooooooo0;Wooooo002Rooooo`Co000000?o410@ooooooooool00oooool00ol0
003oooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wo
oooo002Aooooo`;o00004Oooool00ol0003oooooooooo`05ooooo`?o0000^Oooool0097ooooo0_l0
000Aooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Toooo
o`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Rooooo`03oeEE
EOmVIVKo00000<?ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo002Zooooo`04oa0@4?l0003o0000o`000;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`06o`000?mgMgOo0000o`000?mEEEGok^k^
]oooool00:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomEEEFgooooo`00Zoooool00ol0003ok^k^
ooooo`02ooooo`03o`000?oooooooooo0;Gooooo002[ooooo`03o`000?o^k^kooooo00;ooooo00?o
0000ooooooooool0]Oooool00:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomVIVJgooooo`00Z_oo
ool00ol@413o0000ogMgM`02o`000003ofIVI_o^k^kooooo0;Kooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.63393 .39117 Mdot
.64431 .60962 Mdot
.47463 .36391 Mdot
.44888 .27571 Mdot
.55007 .69485 Mdot
.46383 .11894 Mdot
.51437 .5568 Mdot
.55348 .92007 Mdot
.66096 .7235 Mdot
.50449 .74523 Mdot
.41226 .55056 Mdot
.46919 .99146 Mdot
.51725 .89038 Mdot
.44296 .74706 Mdot
.42442 .93111 Mdot
.54913 .40886 Mdot
.60062 .60911 Mdot
.50663 .9047 Mdot
.56342 .37214 Mdot
.53404 .10454 Mdot
.48025 .92284 Mdot
.60377 .73367 Mdot
.56945 .79618 Mdot
.47888 .92738 Mdot
.36515 .55302 Mdot
.41921 .2742 Mdot
.43226 .28688 Mdot
.55769 .35934 Mdot
.5714 .1544 Mdot
.63655 .63472 Mdot
.42524 .85832 Mdot
.66774 .71344 Mdot
.58072 .87702 Mdot
.54208 .77129 Mdot
.45546 .85915 Mdot
.47467 .06265 Mdot
.69435 .43142 Mdot
.52183 .27118 Mdot
.61183 .22376 Mdot
.45376 .98677 Mdot
.36668 .61738 Mdot
.50269 .84334 Mdot
.39153 .45901 Mdot
.64304 .41369 Mdot
.61273 .31754 Mdot
.45254 .81019 Mdot
.4464 .74843 Mdot
.69711 .61837 Mdot
.56177 .28691 Mdot
.57151 .16069 Mdot
.69636 .61529 Mdot
.64706 .2824 Mdot
.75357 .66834 Mdot
.40237 .67861 Mdot
.40004 .66952 Mdot
.62568 .80083 Mdot
.53847 .93676 Mdot
.6046 .59551 Mdot
.70473 .53203 Mdot
.60101 .29017 Mdot
.4292 .75364 Mdot
.55595 .05939 Mdot
.62008 .2414 Mdot
.53591 .59301 Mdot
.56649 .88789 Mdot
.65136 .75409 Mdot
.51154 .7278 Mdot
.54031 .3793 Mdot
.52219 .26806 Mdot
.44152 .90096 Mdot
.60175 .62977 Mdot
.43819 .58902 Mdot
.49113 .76634 Mdot
.5434 .63602 Mdot
.61991 .2412 Mdot
.49931 .59825 Mdot
.75329 .66909 Mdot
.40237 .4884 Mdot
.63032 .24874 Mdot
.54681 .26882 Mdot
.38057 .42561 Mdot
.63721 .62702 Mdot
.42998 .35322 Mdot
.49439 .85625 Mdot
.59823 .85686 Mdot
.55314 .41709 Mdot
.54314 .71333 Mdot
.499 .79801 Mdot
.61188 .54141 Mdot
.54365 .39422 Mdot
.36466 .50118 Mdot
.76045 .41997 Mdot
.48789 .73889 Mdot
.48509 .8193 Mdot
.50636 .69996 Mdot
.75163 .37641 Mdot
.44964 .76126 Mdot
.68865 .63498 Mdot
.74863 .68652 Mdot
.61402 .54165 Mdot
.64272 .43682 Mdot
.61193 .47092 Mdot
.46332 .98684 Mdot
.64907 .45553 Mdot
.38632 .66682 Mdot
.52756 .79861 Mdot
.58805 .67406 Mdot
.57677 .4298 Mdot
.48611 .74101 Mdot
.43264 .88267 Mdot
.47638 .78248 Mdot
.43757 .30855 Mdot
.66901 .70807 Mdot
.47911 .05626 Mdot
.62187 .91808 Mdot
.50671 .65902 Mdot
.40905 .6395 Mdot
.64602 .77447 Mdot
.6585 .7448 Mdot
.69021 .43086 Mdot
.51551 .89139 Mdot
.50738 .89145 Mdot
.57642 .15957 Mdot
.43422 .88694 Mdot
.47532 .24633 Mdot
.50911 .08066 Mdot
.73284 .32367 Mdot
.64543 .55005 Mdot
.43154 .5889 Mdot
.57858 .78406 Mdot
.64776 .49009 Mdot
.4243 .93784 Mdot
.47143 .11304 Mdot
.40444 .29104 Mdot
.60971 .20964 Mdot
.68923 .38778 Mdot
.5482 .12636 Mdot
.49528 .75965 Mdot
.54434 .92253 Mdot
.41959 .92121 Mdot
.64258 .17035 Mdot
.42327 .59734 Mdot
.54165 .30929 Mdot
.60102 .60892 Mdot
.5071 .07456 Mdot
.61855 .82456 Mdot
.57805 .48302 Mdot
.48118 .81754 Mdot
.44364 .0071 Mdot
.60952 .44424 Mdot
.46898 .20587 Mdot
.47625 .92902 Mdot
.44783 .64093 Mdot
.54134 .1924 Mdot
.67817 .36009 Mdot
.6295 .25457 Mdot
.64138 .77945 Mdot
.6939 .4367 Mdot
.6809 .36645 Mdot
.48382 .16152 Mdot
.62915 .24384 Mdot
.37712 .74857 Mdot
.42979 .11677 Mdot
.39313 .43464 Mdot
.63919 .42949 Mdot
.62291 .81594 Mdot
.37913 .55818 Mdot
.5133 .25102 Mdot
.67756 .3483 Mdot
.54293 .12651 Mdot
.4566 .72739 Mdot
.48844 .21407 Mdot
.53594 .72563 Mdot
.58033 .513 Mdot
.5671 .89178 Mdot
.74627 .36069 Mdot
.53475 .18313 Mdot
.50722 .6504 Mdot
.58657 .17929 Mdot
.66205 .30749 Mdot
.41494 .9182 Mdot
.55927 .54349 Mdot
.36404 .55553 Mdot
.44718 .31839 Mdot
.66225 .71522 Mdot
.73092 .32284 Mdot
.67729 .69569 Mdot
.38325 .78924 Mdot
.39516 .37489 Mdot
.44693 .00758 Mdot
.5057 .07248 Mdot
.54223 .50887 Mdot
.53715 .04227 Mdot
.57666 .888 Mdot
.36674 .35765 Mdot
.4468 .9749 Mdot
.50001 .80035 Mdot
.77272 .47435 Mdot
.56237 .74382 Mdot
.52653 .53754 Mdot
.52526 .55457 Mdot
.43361 .53457 Mdot
.55116 .68619 Mdot
.77464 .50656 Mdot
.64478 .46587 Mdot
.52012 .36379 Mdot
.49419 .12451 Mdot
.42985 .34176 Mdot
.47973 .27418 Mdot
.41086 .51811 Mdot
.56812 .81353 Mdot
.4029 .54043 Mdot
.37877 .54416 Mdot
.55875 .50839 Mdot
.64104 .44271 Mdot
.40819 .62193 Mdot
.37319 .71382 Mdot
.44704 .31469 Mdot
.5903 .2752 Mdot
.48256 .99435 Mdot
.41365 .67652 Mdot
.70023 .55731 Mdot
.38379 .64354 Mdot
.39221 .28218 Mdot
.55485 .46319 Mdot
.57328 .60857 Mdot
.65196 .57204 Mdot
.46746 .7408 Mdot
.42199 .92573 Mdot
.50466 .00396 Mdot
.52719 .32983 Mdot
.46915 .33759 Mdot
.77189 .52179 Mdot
.59442 .38732 Mdot
.42554 .31473 Mdot
.50534 .2384 Mdot
.6519 .48079 Mdot
.52189 .87571 Mdot
.64683 .47236 Mdot
.55848 .0633 Mdot
.42061 .20417 Mdot
.38283 .35564 Mdot
.60209 .62807 Mdot
.67034 .71295 Mdot
.51378 .67625 Mdot
.67366 .35744 Mdot
.60771 .50855 Mdot
.60394 .62006 Mdot
.62151 .24169 Mdot
.36484 .39818 Mdot
.50901 .65059 Mdot
.54097 .51594 Mdot
.68183 .38855 Mdot
.43096 .23021 Mdot
.4804 .20993 Mdot
.3925 .59179 Mdot
.49196 .62713 Mdot
.54532 .92573 Mdot
.70278 .57828 Mdot
.58063 .33625 Mdot
.42468 .31937 Mdot
.40273 .21457 Mdot
.45863 .69848 Mdot
.60706 .43844 Mdot
.6231 .35864 Mdot
.43126 .69899 Mdot
.43991 .15653 Mdot
.50794 .08534 Mdot
.47468 .16538 Mdot
.48662 .06187 Mdot
.3944 .61231 Mdot
.51026 .73494 Mdot
.56364 .29985 Mdot
.67592 .35054 Mdot
.55867 .55975 Mdot
.58412 .52945 Mdot
.69151 .63642 Mdot
.41285 .57711 Mdot
.52551 .16683 Mdot
.60239 .20191 Mdot
.42872 .57369 Mdot
.55126 .59087 Mdot
.69341 .4389 Mdot
.48671 .98661 Mdot
.57853 .43885 Mdot
.4787 .68079 Mdot
.56769 .61707 Mdot
.43759 .08916 Mdot
.46571 .81854 Mdot
.37977 .52702 Mdot
.73082 .32461 Mdot
.7027 .52301 Mdot
.45967 .98136 Mdot
.70003 .53551 Mdot
.51096 .42242 Mdot
.70529 .48876 Mdot
.51495 .0225 Mdot
.40609 .18314 Mdot
.43643 .9547 Mdot
.5484 .26435 Mdot
.39362 .38008 Mdot
.64927 .49892 Mdot
.66871 .71456 Mdot
.36879 .64169 Mdot
.43468 .71622 Mdot
.69055 .63498 Mdot
.44285 .19698 Mdot
.5226 .43786 Mdot
.56751 .81169 Mdot
.59638 .63165 Mdot
.52385 .87821 Mdot
.42583 .03883 Mdot
.49244 .69565 Mdot
.60347 .30503 Mdot
.52099 .81137 Mdot
.54843 .91197 Mdot
.45567 .69598 Mdot
.40606 .88941 Mdot
.42695 .04721 Mdot
.66601 .19859 Mdot
.51063 .292 Mdot
.47295 .11104 Mdot
.49196 .86032 Mdot
.63875 .27668 Mdot
.57429 .61136 Mdot
.52856 .48792 Mdot
.51704 .48812 Mdot
.59415 .65151 Mdot
.51156 .96935 Mdot
.67921 .385 Mdot
.511 .68885 Mdot
.58709 .77567 Mdot
.42856 .55818 Mdot
.43321 .52175 Mdot
.65054 .58178 Mdot
.44844 .13453 Mdot
.39333 .42863 Mdot
.48482 .16243 Mdot
.55687 .66758 Mdot
.76515 .62736 Mdot
.44722 .19096 Mdot
.64017 .6026 Mdot
.53326 .60319 Mdot
.59985 .84542 Mdot
.42411 .32849 Mdot
.5386 .11519 Mdot
.62081 .68039 Mdot
.44851 .71965 Mdot
.4321 .75497 Mdot
.63898 .16445 Mdot
.47983 .99243 Mdot
.70631 .47906 Mdot
.48733 .06455 Mdot
.53117 .22985 Mdot
.56368 .73673 Mdot
.53155 .11127 Mdot
.60145 .41233 Mdot
.47973 .99201 Mdot
.67169 .20254 Mdot
.38612 .3175 Mdot
.42718 .94341 Mdot
.39877 .86158 Mdot
.36537 .60715 Mdot
.43914 .39667 Mdot
.5847 .35361 Mdot
.41506 .90807 Mdot
.54442 .92835 Mdot
.4445 .3652 Mdot
.38833 .6765 Mdot
.45337 .18429 Mdot
.49527 .12364 Mdot
.64031 .42277 Mdot
.68298 .65706 Mdot
.65135 .47845 Mdot
.70007 .46229 Mdot
.6645 .34034 Mdot
.57632 .78282 Mdot
.7038 .45108 Mdot
.58325 .77346 Mdot
.37361 .69286 Mdot
.59336 .95457 Mdot
.69462 .46366 Mdot
.55032 .20366 Mdot
.45449 .65757 Mdot
.38784 .18699 Mdot
.61357 .52183 Mdot
.51597 .46905 Mdot
.40951 .90352 Mdot
.43608 .89128 Mdot
.52815 .47198 Mdot
.53397 .66842 Mdot
.40384 .4049 Mdot
.43779 .26335 Mdot
.69477 .63322 Mdot
.38167 .62627 Mdot
.53234 .03876 Mdot
.40856 .89902 Mdot
.57443 .7029 Mdot
.76571 .60954 Mdot
.56682 .72563 Mdot
.58062 .49912 Mdot
.58166 .53736 Mdot
.4392 .49359 Mdot
.51839 .96029 Mdot
.47352 .99161 Mdot
.42863 .30285 Mdot
.44847 .71622 Mdot
.42128 .33003 Mdot
.55993 .47128 Mdot
.39416 .144 Mdot
.49986 .80342 Mdot
.42309 .13259 Mdot
.41921 .51287 Mdot
.47642 .20505 Mdot
.44592 .66957 Mdot
.52156 .76192 Mdot
.55394 .74674 Mdot
.44053 .25107 Mdot
.52686 .38905 Mdot
.54909 .91711 Mdot
.45068 .56029 Mdot
.44107 .83841 Mdot
.58765 .67495 Mdot
.57235 .24753 Mdot
.47256 .16884 Mdot
.49714 .22283 Mdot
.38863 .17972 Mdot
.76124 .40273 Mdot
.65171 .50803 Mdot
.66975 .8505 Mdot
.64758 .43315 Mdot
.53543 .42686 Mdot
.64449 .75562 Mdot
.40514 .87537 Mdot
.41147 .48792 Mdot
.61797 .68551 Mdot
.76212 .63882 Mdot
.43907 .68747 Mdot
.52058 .41472 Mdot
.57851 .54758 Mdot
.39743 .24254 Mdot
.52615 .22814 Mdot
.76798 .45024 Mdot
.46396 .28261 Mdot
.42423 .78938 Mdot
.51385 .8281 Mdot
.52412 .64862 Mdot
.49311 .69218 Mdot
.55215 .6025 Mdot
.55081 .92286 Mdot
.47756 .71342 Mdot
.61867 .22661 Mdot
.65011 .57027 Mdot
.6111 .31861 Mdot
.49653 .06761 Mdot
.38513 .63724 Mdot
.58745 .66619 Mdot
.73135 .31262 Mdot
.52904 .68386 Mdot
.50626 .97546 Mdot
.36385 .41778 Mdot
.42876 .68612 Mdot
.70589 .48544 Mdot
.47413 .16714 Mdot
.60321 .58129 Mdot
.53385 .10889 Mdot
.64332 .43603 Mdot
.56975 .3995 Mdot
.43064 .7507 Mdot
.54678 .76388 Mdot
.54615 .04514 Mdot
.40544 .28901 Mdot
.50457 .5688 Mdot
.39178 .5172 Mdot
.55005 .27361 Mdot
.43533 .42727 Mdot
.52266 .3245 Mdot
.40695 .71181 Mdot
.39768 .34326 Mdot
.5202 .59924 Mdot
.41808 .28754 Mdot
.64915 .75861 Mdot
.557 .67736 Mdot
.61448 .33461 Mdot
.52782 .27468 Mdot
.55904 .37079 Mdot
.47029 .30652 Mdot
.6386 .89816 Mdot
.48033 .30687 Mdot
.64762 .59566 Mdot
.69646 .57109 Mdot
.43442 .10523 Mdot
.53202 .28896 Mdot
.56451 .1479 Mdot
.43318 .95862 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool3o`000;Wo
oooo002Iooooo`?o00002?ooool00ol0003oooooooooo`05ooooo`?o0000^Oooool009Wooooo0ol0
0008ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`04o`00
0?ooooooooooooooo`;o0000]_ooool00:cooooo0ol000000ooooooo0000o`00002fooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00Toooool2o`0001Oooooo
00?o0000ooooooooool01oooool2o`000;3ooooo002Cooooo`;o00005oooool00ol0003ooooooooo
o`07ooooo`Co0000[_ooool00:cooooo00?o0000ooooooooool02Oooool2o`000003ooooool0003o
00000:_ooooo002Cooooo`;o00005oooool00ol0003oooooooooo`0<ooooo`;o0000Zoooool009?o
oooo0_l0000Gooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:Gooooo0_l0
0005ooooo`03o`000?oooooooooo0;Wooooo002Uooooo`Co00000oooool00ol0003oooooooooo`0?
ooooo`;o0000Z?ooool00:?ooooo0_l00002ooooo`;o00000oooool00ol0003oooooooooo`0?oooo
o`?o0000Yoooool00:?ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00004_ooool2o`00
0:Oooooo002Zooooo`?o0000^oooool00:cooooo0ol0002iooooo`00[?ooool4o`000;Sooooo002/
ooooo`04o`000?oooooo0000o`000;Sooooo002/ooooo`03o`000?oooooooooo00;o0000]oooool0
0:cooooo00?o0000ooooool000000_l0002gooooo`00Uoooool2o`0001?ooooo00Co0000ooooool0
003o0000^?ooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool0
0:cooooo00?o0000ooooooooool02?ooool2o`000:oooooo002Fooooo`;o00005?ooool00ol0003o
ooooooooo`08ooooo`;o0000[oooool009Kooooo0_l0000Dooooo`03o`000?oooooooooo00Sooooo
0_l0002_ooooo`00X_ooool3o`0000Oooooo00?o0000ooooooooool01oooool3o`000:oooooo002D
ooooo`;o00003?ooool3o`0000Oooooo00?o0000ooooooooool01oooool4o`000:kooooo0029oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00olQ8B7o0000o`000005ooooo`03o`000?o^k^ko
oooo00;ooooo0_l000001Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool02Ooo
ool2o`000:kooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?o
EEEEojVYZOooool00_ooool2o`0000?ooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`2iooooo`00POooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmE
EEGooooo00Sooooo00Co0000oooooooooooooooo1Ol0002iooooo`00ROooool01Ol0003ooooooooo
oooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`02ooooo`?o0000
3Oooool3o`000:_ooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<
ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0;ooooo`?o
0000Zoooool008Wooooo00Go410@oooooooooooooooooa0@4004ooooo`;o00001oooool2o`000003
ogMgMooooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2iooooo`00
ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo0_l00005ooooo`05oa0@4?oooooo0000o`00
0?lb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo
0;Wooooo0029ooooo`;o00008Oooool00ol0003oooooooooo`2iooooo`00ROooool2o`00027ooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool04_ooool2o`000:Gooooo002/
ooooo`?o00004_ooool2o`000:Gooooo002/ooooo`03o`000?oooooooooo01Cooooo0_l0002Soooo
o`00V?ooool2o`0001;ooooo00?o0000ooooooooool05?ooool2o`000:?ooooo002Hooooo`;o0000
3?ooool2o`0000Cooooo00?o0000ooooooooool05?ooool4o`000:7ooooo002Vooooo`?o00000ooo
ool00ol0003oooooooooo`0Dooooo`Co00004_ooool2o`0008gooooo002Sooooo`;o00000_ooool2
o`0000?ooooo00?o0000ooooooooool01Oooool2o`0002?ooooo0_l0002=ooooo`00Xoooool2o`00
00Oooooo00?o0000ooooooooool01Oooool2o`0002Gooooo0_l0002;ooooo`00Xoooool2o`0000Oo
oooo00?o0000ooooooooool0;?ooool2o`0008_ooooo002/ooooo`?o0000^Oooool008Oooooo0_l0
000Sooooo`03o`000?oooooooooo01Wooooo0_l0002Nooooo`00Qoooool2o`0000Cooooo0_l0000M
ooooo`03o`000?oooooooooo00Sooooo0_l0000?ooooo`;o0000W_ooool008gooooo0_l0000=oooo
o`;o00003_ooool00ol0003oooooooooo`08ooooo`;o0000[oooool008Oooooo0_l0000Cooooo`;o
00003_ooool00ol0003oooooooooo`2iooooo`00Qoooool2o`00017ooooo0_l0000@ooooo`03o`00
0?oooooooooo00[ooooo0_l0002]ooooo`00V_ooool2o`00013ooooo00?o0000ooooooooool02_oo
ool2o`000:gooooo002Iooooo`;o00004Oooool00ol0003oooooooooo`0cooooo`;o0000Q?ooool0
09Wooooo0_l0000Aooooo`?o0000<oooool2o`0008Cooooo002Aooooo`;o00006Oooool00ol0003o
ooooooooo`0=ooooo`;o00003oooool2o`0001Gooooo0_l00022ooooo`00TOooool2o`0000kooooo
0_l000000ooooooo0000o`000006ooooo`03o`000?oooooooooo00gooooo0_l0000?ooooo`;o0000
5Oooool2o`0008;ooooo002Qooooo`;o000000Coooooo`000?l0003o00001Oooool00ol0003ooooo
ooooo`0Qooooo`;o0000U_ooool00:Gooooo0_l00005ooooo`03o`000?oooooooooo027ooooo0_l0
002Fooooo`00Roooool2o`0001_ooooo0_l00002ooooo`03o`000?oooooooooo0;Wooooo002;oooo
o`;o00006oooool2o`0000;ooooo00?o0000ooooooooool0^Oooool00:_ooooo0_l0002kooooo`00
Zoooool4o`00027ooooo0_l0002Fooooo`00[?ooool00ol0003oooooooooo`05ooooo`;o00006_oo
ool2o`000003ooooool0003o000009?ooooo002Eooooo`;o00005Oooool00ol0003oooooooooo`05
ooooo`Co00006oooool2o`0009?ooooo002Eooooo`;o00005Oooool00ol0003oooooooooo`07oooo
o`;o0000/?ooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00R_oo
ool2o`0000Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM00Gooooo0ol0000Tooooo`Go0000T?ooool008[ooooo0_l00005ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo0_l000000omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo02Cooooo1Ol0002@ooooo`00ROooool6o`0000;ooooo00Go410@oooooooooooo
oooooa0@400=ooooo`;o000000?oooooo`000?ooool01?ooool00ol0003oooooooooo`0Dooooo`;o
00004_ooool2o`0008oooooo002Aooooo`05o`000?ooooooooooooooool000000_ooool2o`0000_o
oooo00?oMgMgoc8b<_ooool01?ooool3o`000003ooooool0003o0000017ooooo0_l0000Booooo`;o
0000Soooool0097ooooo00Go0000ooooooooooooooooo`000002ooooo`;o00002?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00Co0000oooooooooooooooo0_l0000Tooooo`;o0000T?ooool0
097ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool09oooool2o`00093ooooo002Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Wooooo002Aooooo`06onk^k_lb<S;o0000
oc8b<_o^k^kooooo0_l00009ooooo`Co00001_ooool00ol0003oooooooooo`0=ooooo`;o0000Z_oo
ool009Oooooo0_l0000Cooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`;o0000Z_ooool0
0:cooooo00?o0000ooooooooool01?ooool2o`0000Kooooo0_l0002[ooooo`00TOooool2o`0001;o
oooo0_l00005ooooo`03o`000?oooooooooo00Cooooo0_l00006ooooo`?o0000Z_ooool0097ooooo
0_l00008ooooo`;o00002?ooool2o`0000Gooooo0ol00006ooooo`;o00001Oooool2o`0000_ooooo
0_l0000>ooooo`;o0000SOooool009_ooooo0_l0000?ooooo`03o`000?oooooooooo00Kooooo0_l0
000Booooo`;o00003_ooool2o`0008gooooo0028ooooo`;o00005_ooool2o`0000[ooooo00?o0000
ooooooooool0;Oooool2o`0008[ooooo0028ooooo`;o00005_ooool2o`0000[ooooo00?o0000oooo
ooooool0;Oooool2o`0008[ooooo002<ooooo`;o00000oooool2o`0000;ooooo0_l0000Eooooo`03
o`000?oooooooooo00Oooooo0_l00008ooooo`;o0000Y_ooool008cooooo0_l00003ooooo`;o0000
0_ooool2o`0001Gooooo00?o0000ooooooooool00_l00005ooooo`;o00002?ooool2o`0000_ooooo
0_l0002Iooooo`00S?ooool2o`0001kooooo00?o0000ooooooooool00_l0000Looooo`;o0000VOoo
ool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0000Booooo`;o0000YOooool009Co
oooo0_l0000Fooooo`03o`000?oooooooooo01;ooooo0_l0002Uooooo`00U?ooool2o`0000cooooo
0_l000000ooooooo0000o`000005ooooo`03o`000?oooooooooo01oooooo0_l0000Aooooo`;o0000
QOooool009Oooooo0_l00009ooooo`;o000000?oooooo`000?l000001Oooool00ol0003ooooooooo
o`0:ooooo`;o00004oooool2o`00017ooooo0_l00025ooooo`00Uoooool2o`0001?ooooo00?o0000
ooooooooool02_ooool2o`0003gooooo0_l0001^ooooo`00Toooool2o`0000Gooooo0_l0000@oooo
o`03o`000?oooooooooo04Wooooo0_l0001^ooooo`00Q_ooool2o`0000_ooooo0_l00005ooooo`;o
00004?ooool00ol0003oooooooooo`0Qooooo`?o0000UOooool008Kooooo0_l0000;ooooo`;o0000
1Oooool2o`00013ooooo00?o0000ooooooooool08Oooool3o`0009Gooooo002/ooooo`?o00001?oo
ool2o`0004?ooooo0_l0001^ooooo`00Toooool2o`0001Oooooo00?o0000ooooooooool01?ooool2
o`0004?ooooo0_l0001^ooooo`00T_ooool3o`0001Oooooo00?o0000ooooooooool01_ooool2o`00
0;7ooooo002Booooo`;o00006?ooool00ol0003oooooooooo`06ooooo`;o00006_ooool2o`0009Go
oooo002Qooooo`;o00002Oooool00ol0003oooooooooo`0Gooooo`;o00002Oooool2o`0009Gooooo
002Qooooo`;o00002Oooool00ol0003oooooooooo`0Gooooo`;o00006_ooool2o`0008Cooooo002:
ooooo`;o00002?ooool2o`0001Kooooo00?o0000ooooooooool0<oooool2o`0008Cooooo002:oooo
o`;o00002?ooool2o`0001Kooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0=oooool2o`00083ooooo002/ooooo`?o0000=oooool2o`00083ooooo0025ooooo`;o00003Ooo
ool2o`0001Kooooo00?o0000ooooooooool06Oooool2o`0001cooooo0_l00020ooooo`00P?ooool2
o`0000?ooooo0_l0000=ooooo`;o00005_ooool00ol0003oooooooooo`0Iooooo`;o00002_ooool2
o`0000oooooo0_l00021ooooo`00P?ooool2o`0002[ooooo00?o0000ooooooooool04?ooool2o`00
01?ooooo0_l0000?ooooo`?o00005Oooool2o`0006Wooooo002Iooooo`;o00002?ooool2o`0000Oo
oooo00?o0000ooooooooool00oooool2o`0000_ooooo0_l0000Uooooo`;o00005Oooool2o`0006Wo
oooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`03ooooo`;o0000<oooool2o`00
07oooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q
8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool04?ooool2
o`0002Kooooo0_l0001oooooo`00POooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0@
ooooo`?o0000Y_ooool008Wooooo0_l00002ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q
8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o00004Oooool2o`0003gooooo0_l0001Woooo
o`00R?ooool3o`0000;ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`03ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0:ooooo`;o0000A?ooool2o`00
06Oooooo0028ooooo`;o00000oooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`;o0000[Oooool008Wooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo03Sooooo0_l0001oooooo`00ROooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool0
0ol0003oooooooooo`05ooooo`;o00005Oooool2o`0001[ooooo1Ol0001looooo`00[?ooool00ol0
003oooooooooo`05ooooo`;o00005Oooool2o`0000_ooooo0_l0000>ooooo`Co0000O?ooool00:co
oooo00?o0000ooooooooool02oooool2o`0001cooooo0_l0002>ooooo`00Ooooool2o`0001Kooooo
0_l0000Cooooo`03o`000?oooooooooo00_ooooo0_l0002/ooooo`00Ooooool2o`0001Kooooo0_l0
000Cooooo`?o00005?ooool2o`000:?ooooo002/ooooo`03o`000?oooooooooo01Cooooo0_l0000m
ooooo`;o0000I?ooool008cooooo0_l0000Nooooo`03o`000?oooooooooo05?ooooo0_l0001Toooo
o`00S?ooool2o`0001kooooo00?o0000ooooooooool03Oooool2o`000:[ooooo002/ooooo`03o`00
0?oooooooooo00gooooo0_l0000?ooooo`;o0000VOooool00:cooooo00?o0000ooooooooool00ooo
ool2o`0001Wooooo0_l0000<ooooo`;o0000Roooool007oooooo0_l0000[ooooo`03o`000?oooooo
oooo00?ooooo0_l00009ooooo`;o00007?ooool2o`0008_ooooo001oooooo`;o0000:oooool00ol0
003oooooooooo`02o`0000cooooo0_l00013ooooo`;o0000I?ooool008Cooooo0_l0000Vooooo`Go
0000:Oooool2o`0002Kooooo0_l0001Tooooo`00Q?ooool2o`0000;ooooo0_l0000<ooooo`;o0000
5?ooool00ol0003oooooooooo`08ooooo`;o00008Oooool2o`0008cooooo0028ooooo`;o00003?oo
ool2o`0001Cooooo00?o0000ooooooooool02?ooool2o`0000cooooo0_l0000Cooooo`;o00003_oo
ool4o`0007[ooooo0028ooooo`;o00008_ooool00ol0003oooooooooo`0Fooooo`;o00004oooool4
o`0000cooooo1?l0001jooooo`00R?ooool2o`0002;ooooo00?o0000ooooooooool01?ooool2o`00
02Kooooo0ol0000>ooooo`;o0000N_ooool00:cooooo00?o0000ooooooooool01?ooool2o`00013o
oooo0_l00008ooooo`;o00002_ooool2o`0000kooooo0ol0001jooooo`00[?ooool00ol0003ooooo
ooooo`0Fooooo`;o00002?ooool2o`0000Wooooo0_l0000?ooooo`;o0000Noooool00:cooooo00?o
0000ooooooooool08Oooool2o`0000Sooooo0_l0002<ooooo`00[?ooool00ol0003oooooooooo`0Q
ooooo`;o0000U_ooool00:cooooo0ol00010ooooo`;o00004oooool2o`0006;ooooo002/ooooo`03
o`000?oooooooooo02kooooo0_l0000@ooooo`;o00004oooool2o`0006;ooooo0028ooooo`;o0000
8_ooool00ol0003oooooooooo`0^ooooo`;o0000ROooool000Wooooo1?l000000ol@413ooooooooo
o`0Fooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool0
1?ooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Fooooo`03o`00
0?oooooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM01So
oooo1?l000000ol@413oooooooooo`0Booooo`002oooool00ol0003oooooooooo`0Hooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo
<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01oooool00omgMgOo<S8booooo`0Eooooo`03o`000?oooooooooo00oooooo0_l0
0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A007ooooo`03ogMgMolb<S;ooooo00Kooooo1?l00004ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool06Oooool0
0ol0003oooooooooo`0Dooooo`001_l00005ooooo`03o`000?oooooooooo013ooooo1_l00002oooo
o`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooo
oooo00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`05ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0
2Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00oooooo0_l00007ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP02o`0000Oooooo00?o0000oooooooo
ool01Oooool4o`0000Cooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo
00gooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hoooo
o`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;o
oooo00kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00kooooo00Go
0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0
5Oooool00ol0003oooooooooo`02ooooo`;o00005?ooool01Ol0003ooooooooooooooooo000000Go
oooo0_l00006ooooo`04oiRHV?lQ8B7o0000o`0000Kooooo00?oMgMgoc8b<_ooool03_ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooo
oooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`0Iooooo`03o`000?oo
oooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00
000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`00
0?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Fooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o00002?ooool2o`0000Kooooo00Go
0000ooooooooooooooooo`000005ooooo`;o00001oooool01?mgMgOoIVIVo`000?l00002ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000
ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<
ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06_ooool00ol0003oooooooooo`0Dooooo`00
2oooool00ol0003oooooooooo`0Hooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWo
MgMgooooo`03ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400<oooo
o`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool06?ooool3o`0000Kooooo0_l00008ooooo`;o00001_ooool0
1Ol@413ooooooooooooooooo410@00oooooo0ol00002ooooo`03o`000?oooooooooo017ooooo00Go
410@oooooooooooooooooa0@400<ooooo`?o00004Oooool01Ol@413ooooooooooooooooo410@00ko
oooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Co
oooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@
00;ooooo0ol0000?ooooo`;o00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo0ol0000A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Dooooo`002Oooool00omEEEGoIVIVo`00
000Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000@ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0001Oooooo00?o0000ooooooooool05_ooool2
o`000005onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00;ooooo
1_l0000<ooooo`;o00000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000Iooooo`03oeEEEOmVIVKo0000
01Kooooo002/ooooo`03o`000?oooooooooo01Kooooo0_l0000Gooooo`;o00004?ooool2o`0007Ko
oooo002;ooooo`;o000000?oooooo`000?l000007?ooool00ol0003oooooooooo`02ooooo`;o0000
0_ooool2o`0003Sooooo0ol0001fooooo`00Roooool2o`000003ooooool0003o000001cooooo00?o
0000ooooooooool00_ooool2o`0000;ooooo0_l0000Uooooo`;o00004Oooool2o`0006cooooo0_l0
0002ooooo`;o00001Oooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo02gooooo0_l0001o
ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1Oooool009Oooooo0_l0000Cooooo`03o`000?oo
oooooooo0:oooooo00CogMgMo`000?l@413oc<c<1_ooool000Ooooooool0001<o`0000cooooo00Co
k^k^ob4Q8Ol@413ok^k^1_ooool000Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`04o`000?ooooooooooooooo`;o00000_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo0ol00005ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1?ooool2o`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`04ob4Q
8OmgMgOoMgMgoc8b<PKooooo0007ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Cooooo0_l0000Pooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool02Oooool2o`0000;ooooo0_l00005ooooo`00[?oo
ool00ol0003oooooooooo`0;ooooo`;o00000oooool2o`0000kooooo0_l0000=ooooo`;o00009_oo
ool2o`00063ooooo002Aooooo`;o00006Oooool00ol0003oooooooooo`0;ooooo`;o00000oooool2
o`0000Gooooo0_l00007ooooo`;o00003Oooool2o`0008Sooooo002Aooooo`;o00006Oooool00ol0
003oooooooooo`0:ooooo`;o00002oooool2o`000:3ooooo0028ooooo`;o00001?ooool2o`0001co
oooo00?o0000ooooooooool02_ooool2o`000:gooooo0028ooooo`;o00001?ooool2o`0000Kooooo
0_l0000Dooooo`03o`000?oooooooooo02;ooooo0_l0000booooo`;o0000HOooool009Kooooo0_l0
000Dooooo`?o00008_ooool2o`0001_ooooo0_l0000Eooooo`;o0000HOooool008Cooooo0_l0000V
ooooo`03o`000?oooooooooo03oooooo0_l0001hooooo`00Q?ooool2o`0002Kooooo00?o0000oooo
ooooool06?ooool2o`0009oooooo002Fooooo`;o00005?ooool00ol0003oooooooooo`0Hooooo`;o
00009_ooool2o`0007Oooooo002Fooooo`;o00005?ooool00ol0003oooooooooo`05ooooo`;o0000
4Oooool2o`0002Gooooo0ol0001gooooo`00S?ooool2o`0001kooooo00?o0000ooooooooool01Ooo
ool2o`00017ooooo0_l0000Uooooo`;o0000N?ooool008cooooo0_l0000Nooooo`03o`000?oooooo
oooo013ooooo0_l0000?ooooo`?o0000UOooool008Cooooo0_l0000Vooooo`03o`000?oooooooooo
013ooooo0_l0000?ooooo`?o0000UOooool008Cooooo0_l0000Vooooo`03o`000?oooooooooo01Ko
oooo0_l0002Qooooo`00Ooooool2o`0000kooooo0_l0000Kooooo`?o00005_ooool2o`0001Gooooo
0_l0002:ooooo`00Ooooool2o`0000kooooo0_l0000Kooooo`03o`000?oooooooooo00Gooooo0_l0
000Vooooo`;o0000R_ooool007oooooo0_l00003ooooo`;o00003_ooool2o`0001Kooooo00Co0000
oooooooooooooooo0_l00002ooooo`;o0000>?ooool2o`0007Sooooo0024ooooo`;o00003_ooool2
o`0000Gooooo0_l0000?ooooo`04o`000?ooooooooooooooo`;o00003Oooool2o`0002gooooo0_l0
001hooooo`00Voooool2o`0000oooooo00?o0000ooooooooool04?ooool2o`000:Oooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000;_ooool2o`0000gooooo0_l0001jooooo`00
U?ooool2o`0001Kooooo0ol0000^ooooo`?o00003?ooool2o`0007[ooooo002?ooooo`;o00000ooo
ool2o`0001Kooooo0ol0000_ooooo`;o0000R?ooool008oooooo0_l0000Kooooo`03o`000?oooooo
oooo043ooooo0_l0001gooooo`00[?ooool00ol0003oooooooooo`0Oooooo`;o00003Oooool2o`00
013ooooo0_l0001gooooo`00[?ooool00ol0003oooooooooo`0Oooooo`;o00003Oooool2o`0008Wo
oooo002Eooooo`Co00004oooool00ol0003oooooooooo`2iooooo`00R?ooool2o`0000_ooooo1?l0
000Cooooo`03o`000?oooooooooo00gooooo0_l0002Zooooo`00R?ooool2o`0002;ooooo00?o0000
ooooooooool02?ooool2o`0000?ooooo0_l0002Zooooo`00T_ooool2o`0001Oooooo0_l0000:oooo
o`;o00005Oooool2o`0000cooooo0_l0002:ooooo`00T_ooool2o`0001Oooooo1?l00003ooooo`;o
00006_ooool2o`0000cooooo0_l0002:ooooo`00[?ooool00ol0003oooooooooo`03ooooo`;o0000
0oooool2o`0000Cooooo0_l0000Kooooo`;o0000S?ooool007oooooo0_l0000[ooooo`03o`000?oo
oooooooo00Sooooo0_l00004ooooo`;o00006oooool2o`0008cooooo001oooooo`;o0000:oooool0
0ol0003oooooooooo`0Eooooo`;o00001oooool2o`0000cooooo0_l0000Vooooo`;o0000Hoooool0
08Wooooo0_l0000Qooooo`03o`000?oooooooooo01Gooooo0_l00007ooooo`;o00003?ooool2o`00
02Kooooo0_l0001Sooooo`00ROooool2o`00027ooooo00?o0000ooooooooool05Oooool2o`0002Ko
oooo0_l0001jooooo`00P?ooool2o`0000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
01?ooooo0_l0000Xooooo`?o0000NOooool0083ooooo0_l00007ooooo`04ogMgMonHV9SooooooiRH
V0;o00001?ooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool04oooool2o`0000[ooooo0_l0000Mooooo`;o0000NOooool0
08Wooooo00Co410@oooooooooooooooo0_l0000;ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000
ooooooooool00oooool3o`0001oooooo0_l0002Hooooo`00QOooool2o`0000;ooooo00Go0000oooo
ooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00CoMgMgoc8b<_oooooooooo0_l0
00000ooooooo0000ooooo`0Oooooo`;o00002_ooool2o`0002Sooooo0_l0001Sooooo`00QOooool2
o`0000;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c002ooooo`;o000000?oooooo`000?ooool07Oooool4o`0000[ooooo
0_l0000Xooooo`;o0000Hoooool008Wooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Looooo`Co0000
2_ooool2o`00017ooooo0_l0001jooooo`00Q_ooool2o`000006oooooomgMgOoV9RHoooooonHV9So
MgMg2oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0;ooooo`;o00007Oooool2o`0000oooooo1?l0001jooooo`00Q_ooool2o`000006
ooooooo^k^ko<S8bo`000?lb<S;ok^k^0_l00009ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?oo
ool4o`0000Kooooo00?o0000ooooooooool02oooool2o`0002kooooo0ol0000Eooooo`;o0000I?oo
ool0083ooooo0_l00003ooooo`;o00001oooool2o`0000[ooooo0_l0000@ooooo`03o`000?oooooo
oooo05?ooooo0_l0001Tooooo`00P?ooool2o`0000?ooooo0_l0000Cooooo`;o00004?ooool00ol0
003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`05ooooo`;o0000/_ooool00:cooooo
1Ol00003ooooo`;o00005Oooool2o`0009_ooooo002/ooooo`03o`000?oooooo000000;o00006_oo
ool2o`0009_ooooo002Mooooo`;o00003Oooool01?l0003oooooo`000?l0000hooooo`;o0000O_oo
ool009gooooo0_l0000=ooooo`04o`000?oooooo0000o`0003Sooooo0_l0001nooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00Q_ooool2o`0002Cooooo00?o0000ooooooooool03oooool2o`00
00Sooooo0_l0002Nooooo`00Q_ooool2o`0000?ooooo0_l0000=ooooo`;o00004?ooool00ol0003o
ooooooooo`08ooooo`;o00001Oooool2o`0000Sooooo0_l0000eooooo`;o0000Ioooool008_ooooo
0_l0000=ooooo`;o00004?ooool00ol0003oooooooooo`08ooooo`;o00004?ooool2o`0003Cooooo
0_l0001Wooooo`00Qoooool2o`0000Kooooo0_l0000Kooooo`?o000000?oooooo`000?l000005_oo
ool3o`0009gooooo0027ooooo`;o00000_ooool2o`0000;ooooo0_l0000Kooooo`04o`000?oooooo
ooooooooo`;o00003?ooool2o`0000Sooooo0_l0002Nooooo`00Roooool2o`0001Sooooo0_l00005
ooooo`03o`000?oooooooooo00oooooo0_l0000Cooooo`;o0000Toooool009Cooooo0_l0000?oooo
o`;o00001Oooool00ol0003oooooooooo`06ooooo`;o00001Oooool2o`0001Gooooo0_l0002Coooo
o`00U?ooool2o`000003ooooool0003o000001?ooooo00?o0000ooooooooool00_l00004ooooo`;o
00001Oooool2o`0001Gooooo0_l0000Yooooo`;o0000J?ooool009Oooooo0_l0000@ooooo`;o0000
00Coooooo`000?oooooooooo0_l0001=ooooo`;o0000J?ooool008;ooooo0_l0000Uooooo`;o0000
00?oooooo`000?ooool03_ooool2o`000:[ooooo0022ooooo`;o00006Oooool2o`0000[ooooo0_l0
00000ooooooo0000ooooo`0>ooooo`;o0000:?ooool2o`00083ooooo002Eooooo`;o00001_ooool3
o`0000Wooooo0_l000000ooooooo0000o`000002o`0003Kooooo0_l00020ooooo`00UOooool2o`00
00Oooooo0_l0000<ooooo`04o`000?oooooo0000o`0001Cooooo0_l0002Rooooo`00[?ooool00ol0
003oooooooooo`0Eooooo`;o0000X_ooool00:cooooo00?o0000ooooooooool0=?ooool2o`0008?o
oooo002=ooooo`;o00005Oooool2o`0000Kooooo00?o0000ooooooooool02oooool2o`0002Oooooo
0ol00022ooooo`00P_ooool2o`0000Wooooo0_l00007ooooo`;o00000oooool2o`0000Oooooo0_l0
0006ooooo`03o`000?oooooooooo00_ooooo0_l0000Uooooo`Go0000P_ooool008;ooooo0_l0000B
ooooo`;o00000oooool2o`0000oooooo00?o0000ooooooooool0<_ooool4o`0008?ooooo002Koooo
o`;o00003oooool00ol0003oooooooooo`2iooooo`00Voooool2o`0000oooooo0ol00008ooooo`;o
00002Oooool2o`0001gooooo0_l00025ooooo`00WOooool2o`0000gooooo00?o0000ooooooooool0
0_l00006ooooo`;o00002Oooool2o`0001gooooo0_l00025ooooo`00WOooool2o`0000gooooo00?o
0000ooooooooool00_l0002gooooo`00[?ooool00ol0003oooooooooo`0Oooooo`;o0000V?ooool0
0:cooooo00?o0000ooooooooool00_l0000@ooooo`;o00002oooool2o`0009Sooooo002Qooooo`;o
00001Oooool2o`0000;ooooo00?o0000ooooooooool00_l0000@ooooo`;o0000YOooool0097ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool4o`000003oc8b<_oMgMgo000000;o
00000_ooool00ol0003oooooooooo`0Aooooo`;o0000Y_ooool0097ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q2?ooool01?mgMgOo<S8bo`000?l00003ooooo`?o00003_ooool2o`00
0003ooooool0003o000001kooooo0_l00026ooooo`00Poooool2o`0000cooooo00Go410@oooooooo
oooooooooa0@4003ooooo`?o00002_ooool00ol0003oooooooooo`03ooooo`?o00003_ooool2o`00
027ooooo0_l00026ooooo`00Poooool2o`0000cooooo00Co0000oooooooooooooooo0_l00002oooo
o`?o00002Oooool00omgMgOo<S8booooo`04ooooo`?o0000^Oooool0097ooooo00?o0000oooooooo
ool00ol0000;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0/oooo
o`;o000000?oooooo`000?l00000R?ooool0097ooooo00?o410@ooooooooool00ol0000;ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0;?ooool5o`0008Sooooo002Aooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2o`0000Gooooo00?o0000ooooooooool01Oooool3o`0000Ko
oooo0_l0000Xooooo`;o0000ROooool0097ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
00001Oooool4o`0000Cooooo0ol00006ooooo`;o00001_ooool2o`000:_ooooo002Yooooo`;o0000
00?oooooo`000?ooool03Oooool2o`000:_ooooo002Yooooo`;o000000?oooooo`000?ooool0^_oo
ool00:cooooo00?o0000ooooooooool02_ooool2o`0000cooooo0_l0002Oooooo`00[?ooool3o`00
00[ooooo0_l0000<ooooo`?o00004_ooool2o`0008[ooooo002/ooooo`03o`000?oooooooooo01Wo
oooo0_l0000@ooooo`Co0000R_ooool00:Cooooo0_l00006ooooo`03o`000?oooooooooo01Kooooo
0_l0000Cooooo`;o0000S?ooool00:Cooooo0_l00006ooooo`03o`000?oooooooooo01Kooooo0ol0
002Pooooo`00QOooool2o`0002Gooooo00?o0000ooooooooool05oooool2o`000:3ooooo0025oooo
o`;o00003?ooool2o`0001Oooooo00?o0000ooooooooool0^Oooool009?ooooo0_l0000Gooooo`03
o`000?oooooooooo0;Wooooo002[ooooo`;o00005Oooool2o`000:Cooooo002[ooooo`Co00001_oo
ool2o`0000_ooooo0_l0000Aooooo`;o0000TOooool00:cooooo0_l00007ooooo`;o00007_ooool2
o`00097ooooo002/ooooo`;o0000^_ooool009cooooo0_l0000>ooooo`03o`000?oooooooooo0;Wo
oooo002Looooo`;o00003_ooool00ol0003oooooooooo`03ooooo`;o00003_ooool2o`000:Cooooo
002/ooooo`03o`000?oooooooooo00?ooooo0_l0000>ooooo`;o00004?ooool2o`0009;ooooo002P
ooooo`;o00000oooool4o`0000?ooooo00?o0000ooooooooool09Oooool2o`0009;ooooo002Poooo
o`;o00000oooool4o`0000?ooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0000Tooooo`;o
0000Toooool00:cooooo00Co0000oooooooooooooooo0_l0000Qooooo`;o0000Toooool00:cooooo
00Co0000oooooooooooooooo0_l0002fooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00V?ooool2o`0001;ooooo00?o0000ooooooooool0^Oooool0
09Sooooo0_l0000Booooo`;o0000^_ooool00:cooooo0_l0000Oooooo`;o0000VOooool00:cooooo
00?o0000ooooooooool07_ooool2o`0009Wooooo002/ooooo`?o0000=Oooool2o`0008;ooooo002/
ooooo`03o`000?oooooooooo03Gooooo0_l00022ooooo`00Toooool2o`0001Gooooo0ol0000Ooooo
o`;o0000V_ooool008[ooooo0_l00007ooooo`;o00002?ooool2o`0000[ooooo1?l0000Oooooo`;o
0000V_ooool008[ooooo0_l0000Aooooo`;o00002_ooool2o`000003ooooool0003ooooo0;[ooooo
0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool0
1?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0^Oooool008Wooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0^Oooool008Wooooo00Go410@oooooooooooo
oooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`2iooooo`00ROooool00ol0003oooooooooo`02o`0000kooooo00?o8B4Qooooooooool0
1_ooool00omgMgOo<S8booooo`04ooooo`?o00001?ooool2o`00017ooooo0_l0002Pooooo`00ROoo
ool00ol0003oooooooooo`02o`0000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool01?ooool2o`00017ooooo0_l0002Pooooo`00ROoo
ool01Ol@413ooooooooooooooooo410@00Oooooo0_l00005ooooo`03ojVYZOmgMgOooooo00?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`;o0000/oooool008Wooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`07ooooo`;o00000_ooool01Ol@413ooooooooooooooooo<S8b00Co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2iooooo`00ROooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Sooooo0_l000000ooooooo0000o`000003o`0000Cooooo1?l00006ooooo`03
o`000?oooooooooo01?ooooo0_l000000ooooooo0000o`00002Qooooo`00SOooool2o`0000Oooooo
0_l0000Dooooo`05o`000?oooooo0000o`000?ooool00_l0000?ooooo`;o000000?oooooo`000?l0
0000XOooool008gooooo0_l00007ooooo`;o00005?ooool01Ol0003oooooo`000?l0003ooooo00;o
00003oooool2o`000:Cooooo002/ooooo`03o`000?oooooooooo02[ooooo0_l0002=ooooo`00SOoo
ool2o`0000Wooooo0_l0000Booooo`?o0000:_ooool2o`0008gooooo002=ooooo`?o00002?ooool2
o`0001;ooooo00?o0000ooooooooool0^Oooool008kooooo0_l0000Looooo`04o`000?oooooo0000
o`000;Sooooo002@ooooo`;o00006_ooool01?l0003oooooo`000?l0002hooooo`00T?ooool2o`00
01[ooooo00?o0000ooooooooool03Oooool2o`000:[ooooo002/ooooo`03o`000?oooooooooo00go
oooo0_l0002Zooooo`00Soooool2o`0001_ooooo00?o0000ooooooooool03Oooool2o`0001Kooooo
0_l0002Booooo`00Soooool4o`0001Wooooo00?o0000ooooooooool02oooool5o`0001Gooooo0_l0
002Booooo`00TOooool2o`0001;ooooo0_l00005ooooo`?o00002oooool5o`000:Wooooo002Boooo
o`;o00004Oooool2o`0000Gooooo00?o0000ooooooooool02oooool4o`000:[ooooo002Booooo`?o
00003oooool3o`0000Gooooo00?o0000ooooooooool02oooool3o`000:_ooooo002Cooooo`;o0000
3oooool2o`0000Kooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool02Ooo
ool2o`000:kooooo002Cooooo`;o00005oooool00ol0003oooooooooo`09ooooo`;o0000[_ooool0
09?ooooo0ol0000Fooooo`03o`000?oooooooooo0;Wooooo002Dooooo`;o00005_ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002G
ooooo`;o00004oooool00ol0003oooooooooo`0Kooooo`;o0000W?ooool009Kooooo0ol0000Coooo
o`03o`000?oooooooooo01_ooooo0_l0002Looooo`00U_ooool2o`0001Cooooo00?o0000oooooooo
ool00oooool2o`000;Cooooo002/ooooo`03o`000?oooooooooo00?ooooo0_l0002dooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`02o`000;Oooooo002/oooo
o`03o`000?oooooooooo00;o0000]oooool009[ooooo0_l0000@ooooo`Co0000^?ooool009[ooooo
0_l0000@ooooo`04o`000?oooooo0000o`000;Sooooo002Nooooo`;o00003?ooool00ol0003ooooo
ooooo`2iooooo`00W_ooool2o`0000cooooo00?o0000ooooooooool0^Oooool009cooooo0_l00000
0ooooooo0000o`000006ooooo`;o00000oooool00ol0003oooooooooo`2iooooo`00W?ooool2o`00
0003ooooool0003o000000So00000oooool00ol0003oooooooooo`2iooooo`00XOooool7o`0000Co
oooo00?o0000ooooooooool0^Oooool00:Cooooo1?l00004ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo0ol0002iooooo`00Y?ooool00ol0003oooooooooo`31
ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00
Y?ooool00ol0003oooooooooo`31ooooo`00X_ooool00omEEEGoIVIVo`000033ooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Z_ooool01?l@413o0000o`00
0?l0002jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2j
ooooo`00Zoooool01_l0003oMgMgo`000?l0003oEEEEonk^k[Oooooo002[ooooo`06o`000?mEEEGo
k^k^oooooomgMgOoEEEE]oooool00:_ooooo00?o0000onk^k_ooool00_ooool00ol0003ooooooooo
o`2eooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo0;Gooooo002[oooo
o`06o`000?mEEEGok^k^oooooomgMgOoIVIV]oooool00:[ooooo00?o410@o`000?mgMgL00_l00000
0omVIVKok^k^ooooo`2fooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.55039 .19117 Mdot
.64816 .40962 Mdot
.44537 .53104 Mdot
.43169 .66255 Mdot
.58802 .49485 Mdot
.39423 .6312 Mdot
.49709 .35741 Mdot
.68151 .72007 Mdot
.71036 .5235 Mdot
.56258 .54523 Mdot
.49961 .76302 Mdot
.63311 .8108 Mdot
.63341 .69038 Mdot
.54133 .66656 Mdot
.59937 .85375 Mdot
.47358 .23563 Mdot
.60427 .40911 Mdot
.62851 .7047 Mdot
.47301 .19637 Mdot
.38217 .32509 Mdot
.61296 .73214 Mdot
.65724 .53367 Mdot
.64792 .59618 Mdot
.61386 .7379 Mdot
.51036 .97043 Mdot
.43778 .79246 Mdot
.43772 .73274 Mdot
.4633 .20464 Mdot
.40835 .16162 Mdot
.65044 .43472 Mdot
.57611 .79883 Mdot
.71312 .51344 Mdot
.69153 .67702 Mdot
.61059 .57129 Mdot
.57861 .71336 Mdot
.37959 .59606 Mdot
.62692 .23142 Mdot
.41926 .34335 Mdot
.46224 .05572 Mdot
.62447 .83016 Mdot
.52427 .96005 Mdot
.60003 .64334 Mdot
.48411 .87333 Mdot
.56851 .21369 Mdot
.49975 .11754 Mdot
.56126 .68041 Mdot
.54147 .65527 Mdot
.70445 .41837 Mdot
.44223 .18664 Mdot
.41023 .16055 Mdot
.70247 .41529 Mdot
.52002 .0824 Mdot
.7809 .46834 Mdot
.53061 .80709 Mdot
.52895 .81569 Mdot
.70601 .60083 Mdot
.67317 .73676 Mdot
.6028 .39551 Mdot
.67754 .33203 Mdot
.47733 .10323 Mdot
.5448 .72133 Mdot
.37636 .23923 Mdot
.47685 .05348 Mdot
.53311 .39301 Mdot
.68164 .68789 Mdot
.713 .55409 Mdot
.56265 .5278 Mdot
.45631 .25424 Mdot
.41858 .34242 Mdot
.5908 .78265 Mdot
.61366 .42977 Mdot
.5024 .64185 Mdot
.55883 .56934 Mdot
.5578 .43602 Mdot
.47661 .05353 Mdot
.49863 .39849 Mdot
.78093 .46909 Mdot
.48818 .81963 Mdot
.48983 .05106 Mdot
.42749 .24 Mdot
.47919 .92842 Mdot
.64801 .42702 Mdot
.4527 .72834 Mdot
.59724 .65714 Mdot
.70097 .65686 Mdot
.48034 .23179 Mdot
.58847 .51333 Mdot
.57822 .59804 Mdot
.58844 .34141 Mdot
.46376 .24542 Mdot
.49913 .98153 Mdot
.68844 .21997 Mdot
.54585 .54518 Mdot
.57552 .62636 Mdot
.54634 .49996 Mdot
.66219 .17641 Mdot
.54526 .65286 Mdot
.70264 .43498 Mdot
.78324 .48652 Mdot
.59068 .34165 Mdot
.57745 .23682 Mdot
.56029 .27092 Mdot
.62839 .81441 Mdot
.59128 .25553 Mdot
.53127 .87594 Mdot
.60701 .59861 Mdot
.61767 .47406 Mdot
.50868 .2298 Mdot
.54563 .54921 Mdot
.58391 .79312 Mdot
.55682 .60253 Mdot
.4413 .70484 Mdot
.71223 .50807 Mdot
.37724 .57804 Mdot
.7491 .71808 Mdot
.53032 .45902 Mdot
.52005 .77185 Mdot
.71581 .57447 Mdot
.71642 .5448 Mdot
.62256 .23086 Mdot
.63207 .69139 Mdot
.36105 .53251 Mdot
.62396 .69145 Mdot
.41281 .14298 Mdot
.58539 .7917 Mdot
.41955 .55346 Mdot
.37651 .44144 Mdot
.6223 .12367 Mdot
.62545 .35005 Mdot
.50381 .67135 Mdot
.6522 .58406 Mdot
.6038 .29009 Mdot
.60157 .85922 Mdot
.3913 .59932 Mdot
.44465 .85328 Mdot
.45505 .0544 Mdot
.60434 .18778 Mdot
.39067 .25901 Mdot
.55948 .56051 Mdot
.67335 .72253 Mdot
.596 .86098 Mdot
.50747 .7074 Mdot
.43615 .25437 Mdot
.60459 .40892 Mdot
.37544 .45165 Mdot
.70838 .62456 Mdot
.70232 .81757 Mdot
.53126 .28302 Mdot
.5725 .62885 Mdot
.37418 .74356 Mdot
.54722 .24424 Mdot
.41209 .58993 Mdot
.61291 .74225 Mdot
.51205 .60035 Mdot
.40503 .27517 Mdot
.58221 .16009 Mdot
.49134 .05628 Mdot
.71316 .57945 Mdot
.62857 .2367 Mdot
.58747 .16645 Mdot
.3992 .53471 Mdot
.48672 .04777 Mdot
.55277 .93374 Mdot
.40112 .78029 Mdot
.47844 .87158 Mdot
.57099 .22949 Mdot
.70929 .61594 Mdot
.50845 .90776 Mdot
.41388 .38565 Mdot
.57688 .1483 Mdot
.38921 .28154 Mdot
.53453 .60699 Mdot
.40967 .50316 Mdot
.5862 .52563 Mdot
.54553 .313 Mdot
.68381 .69178 Mdot
.65054 .16069 Mdot
.40092 .30532 Mdot
.52738 .4504 Mdot
.42568 .10849 Mdot
.54505 .10749 Mdot
.59504 .87347 Mdot
.53667 .34349 Mdot
.51115 .97505 Mdot
.44137 .66075 Mdot
.70834 .51522 Mdot
.62006 .12284 Mdot
.71556 .49569 Mdot
.56187 .9215 Mdot
.46496 .87567 Mdot
.37357 .72909 Mdot
.37519 .45829 Mdot
.50577 .30887 Mdot
.36813 .32472 Mdot
.69186 .688 Mdot
.61794 .83316 Mdot
.58015 .60035 Mdot
.72246 .27435 Mdot
.6199 .54382 Mdot
.50155 .33754 Mdot
.50709 .35457 Mdot
.4915 .67323 Mdot
.58564 .48619 Mdot
.73727 .30656 Mdot
.59112 .26587 Mdot
.44122 .33161 Mdot
.38887 .49746 Mdot
.45022 .73137 Mdot
.42468 .52822 Mdot
.49283 .77615 Mdot
.65353 .61353 Mdot
.49942 .80604 Mdot
.50546 .91134 Mdot
.5221 .30839 Mdot
.57812 .24271 Mdot
.51625 .77458 Mdot
.54514 .94202 Mdot
.44059 .66219 Mdot
.46162 .11302 Mdot
.6427 .80054 Mdot
.52773 .75729 Mdot
.68315 .35731 Mdot
.52646 .88473 Mdot
.44536 .90861 Mdot
.50012 .26319 Mdot
.57671 .40857 Mdot
.64078 .37204 Mdot
.53942 .58489 Mdot
.59751 .85698 Mdot
.36039 .47773 Mdot
.43504 .30843 Mdot
.44081 .56066 Mdot
.74061 .32179 Mdot
.50935 .18732 Mdot
.44525 .75603 Mdot
.36441 .61822 Mdot
.41156 .42391 Mdot
.60422 .28079 Mdot
.63217 .67571 Mdot
.59578 .27236 Mdot
.37816 .22777 Mdot
.42218 .80149 Mdot
.46342 .93367 Mdot
.61332 .42807 Mdot
.71552 .51295 Mdot
.54428 .47625 Mdot
.57663 .15744 Mdot
.57113 .30855 Mdot
.61196 .42006 Mdot
.47836 .05222 Mdot
.52924 .45059 Mdot
.50734 .31594 Mdot
.59725 .18855 Mdot
.42563 .75064 Mdot
.41051 .53918 Mdot
.51294 .84512 Mdot
.50487 .4326 Mdot
.67561 .72573 Mdot
.69409 .37828 Mdot
.47555 .15367 Mdot
.44645 .7588 Mdot
.42832 .87732 Mdot
.52563 .58136 Mdot
.54244 .23844 Mdot
.52655 .15864 Mdot
.52979 .68862 Mdot
.40761 .72753 Mdot
.37768 .44558 Mdot
.40202 .57379 Mdot
.37684 .54405 Mdot
.51709 .83607 Mdot
.56424 .53494 Mdot
.44782 .18153 Mdot
.57614 .15054 Mdot
.54257 .35975 Mdot
.5559 .32945 Mdot
.70607 .43642 Mdot
.50529 .75576 Mdot
.39551 .34948 Mdot
.44582 .06788 Mdot
.5011 .68618 Mdot
.54761 .39087 Mdot
.62897 .2389 Mdot
.64278 .79026 Mdot
.51407 .23885 Mdot
.52041 .507 Mdot
.57452 .41707 Mdot
.3934 .75222 Mdot
.56655 .65539 Mdot
.5015 .91001 Mdot
.62066 .12461 Mdot
.67191 .32301 Mdot
.62471 .81494 Mdot
.67423 .33551 Mdot
.45306 .35909 Mdot
.6608 .28876 Mdot
.36313 .42808 Mdot
.42073 .86941 Mdot
.60856 .83977 Mdot
.67216 .86648 Mdot
.42706 .23454 Mdot
.46643 .88125 Mdot
.60884 .29892 Mdot
.71453 .51456 Mdot
.5293 .95153 Mdot
.53373 .68176 Mdot
.70454 .43498 Mdot
.4158 .70594 Mdot
.46249 .3107 Mdot
.65219 .61169 Mdot
.60904 .43165 Mdot
.63514 .67821 Mdot
.38496 .81448 Mdot
.53186 .49864 Mdot
.48555 .11045 Mdot
.60554 .61137 Mdot
.67322 .71197 Mdot
.52518 .59056 Mdot
.58659 .88419 Mdot
.38655 .80775 Mdot
.42304 .38868 Mdot
.39053 .59309 Mdot
.5968 .66214 Mdot
.50942 .07668 Mdot
.57883 .41136 Mdot
.4841 .30113 Mdot
.47437 .32773 Mdot
.61476 .45151 Mdot
.6593 .76935 Mdot
.59321 .185 Mdot
.54654 .48885 Mdot
.65736 .57567 Mdot
.49775 .6902 Mdot
.48879 .67774 Mdot
.64325 .38178 Mdot
.40096 .69505 Mdot
.47709 .87203 Mdot
.39918 .53016 Mdot
.5839 .46758 Mdot
.7761 .42736 Mdot
.41354 .68815 Mdot
.64121 .4026 Mdot
.53453 .40319 Mdot
.69802 .64542 Mdot
.44857 .75929 Mdot
.38548 .30277 Mdot
.65297 .48039 Mdot
.53279 .63037 Mdot
.54479 .71101 Mdot
.64001 .80073 Mdot
.65794 .27906 Mdot
.37727 .54037 Mdot
.41136 .31122 Mdot
.61837 .53673 Mdot
.3834 .33467 Mdot
.52638 .21233 Mdot
.63978 .80041 Mdot
.5127 .00254 Mdot
.45439 .92754 Mdot
.60362 .85528 Mdot
.57914 .89409 Mdot
.52227 .96591 Mdot
.4602 .67894 Mdot
.48622 .15925 Mdot
.59186 .86606 Mdot
.67576 .72835 Mdot
.45217 .66235 Mdot
.53309 .8685 Mdot
.41076 .66273 Mdot
.38845 .49293 Mdot
.56941 .22277 Mdot
.7058 .45706 Mdot
.60273 .27845 Mdot
.64499 .26229 Mdot
.56063 .14034 Mdot
.64945 .58282 Mdot
.64423 .25108 Mdot
.65264 .57346 Mdot
.54008 .93613 Mdot
.73518 .75457 Mdot
.64009 .26366 Mdot
.41137 .23605 Mdot
.51485 .57676 Mdot
.42552 .94829 Mdot
.58231 .32183 Mdot
.46768 .3316 Mdot
.59065 .8814 Mdot
.58696 .7897 Mdot
.47789 .29685 Mdot
.56134 .46842 Mdot
.46963 .83126 Mdot
.43139 .71368 Mdot
.70806 .43322 Mdot
.52301 .89328 Mdot
.3668 .34685 Mdot
.58933 .88167 Mdot
.61559 .5029 Mdot
.76953 .40954 Mdot
.61707 .52563 Mdot
.54027 .29912 Mdot
.5566 .33736 Mdot
.48135 .6577 Mdot
.6625 .76029 Mdot
.63563 .80593 Mdot
.44199 .74511 Mdot
.5318 .62856 Mdot
.44952 .77134 Mdot
.50844 .27128 Mdot
.41477 .92998 Mdot
.58123 .60342 Mdot
.40602 .80613 Mdot
.48988 .74082 Mdot
.4103 .5576 Mdot
.51952 .61681 Mdot
.58633 .56192 Mdot
.61263 .54674 Mdot
.42811 .70434 Mdot
.45077 .30018 Mdot
.36494 .63895 Mdot
.67593 .71711 Mdot
.49342 .59313 Mdot
.56983 .73498 Mdot
.61763 .47495 Mdot
.43726 .15344 Mdot
.40323 .5823 Mdot
.4097 .46332 Mdot
.42377 .94642 Mdot
.68233 .20273 Mdot
.61492 .30803 Mdot
.76995 .6505 Mdot
.58084 .23315 Mdot
.46825 .27115 Mdot
.70674 .55562 Mdot
.58249 .87882 Mdot
.48611 .78002 Mdot
.65217 .48551 Mdot
.77765 .43882 Mdot
.52539 .6519 Mdot
.45471 .32077 Mdot
.55754 .34758 Mdot
.43558 .89439 Mdot
.40987 .3335 Mdot
.70808 .25024 Mdot
.42993 .59526 Mdot
.55554 .75934 Mdot
.60509 .6281 Mdot
.54357 .44862 Mdot
.53096 .49471 Mdot
.55315 .4025 Mdot
.67995 .72286 Mdot
.53176 .53771 Mdot
.46976 .04683 Mdot
.63822 .37027 Mdot
.49855 .11867 Mdot
.37594 .49952 Mdot
.52473 .87835 Mdot
.61393 .46619 Mdot
.6164 .11262 Mdot
.56259 .48386 Mdot
.65645 .77546 Mdot
.527 .69467 Mdot
.66007 .28544 Mdot
.40252 .57582 Mdot
.59573 .38129 Mdot
.38316 .32502 Mdot
.57773 .23603 Mdot
.4896 .2032 Mdot
.54378 .71428 Mdot
.61234 .56388 Mdot
.37034 .28445 Mdot
.44399 .84935 Mdot
.4922 .37398 Mdot
.49676 .85964 Mdot
.43061 .22724 Mdot
.46771 .68896 Mdot
.43223 .32862 Mdot
.53771 .79542 Mdot
.45751 .8715 Mdot
.51989 .39924 Mdot
.44093 .79449 Mdot
.71259 .55861 Mdot
.58794 .47736 Mdot
.50833 .13461 Mdot
.42142 .31649 Mdot
.46855 .20437 Mdot
.43378 .56243 Mdot
.75786 .69816 Mdot
.43168 .51852 Mdot
.64589 .39566 Mdot
.68489 .37109 Mdot
.3976 .7626 Mdot
.42632 .2959 Mdot
.40288 .18862 Mdot
.60943 .85127 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool01?l0003o
ooooooooooooool2o`000;Kooooo002Tooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooo
oooooooo0_l0002fooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wo
oooo002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:;ooooo00?o
EEEEofIVI_l000001oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002Rooooo`;o00002?ooool00ol0003ooooooooo
o`2iooooo`00X_ooool2o`0000?ooooo0_l00003ooooo`03o`000?oooooooooo0;Wooooo002Toooo
o`;o000000Coooooo`000?l0003o00000_ooool3o`000;Wooooo002Mooooo`Co00000oooool2o`00
00;ooooo0_l00002ooooo`03o`000?oooooooooo0;Wooooo002Mooooo`Co00000oooool2o`0000?o
oooo0_l000000ooooooo0000ooooo`2jooooo`00ZOooool2o`000003ooooool0003ooooo0;[ooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002Jooooo`;o00004?ooool00ol0003oooooooooo`2i
ooooo`00V_ooool2o`00013ooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo1Ol0002gooooo`00[?ooool00ol0003oooooooooo`02o`000;Oooooo002/
ooooo`03o`000?oooooooooo00?ooooo0_l0002dooooo`00[?ooool00ol0003oooooooooo`03oooo
o`;o0000]?ooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo0ol0002iooooo`00Y?ooool2o`0000Kooooo00?o0000ooooooooool0^Oooool00:Cooooo
0_l00006ooooo`03o`000?oooooooooo00_ooooo0_l0002/ooooo`00Toooool2o`0001;ooooo0_l0
0003ooooo`03o`000?oooooooooo00_ooooo0_l0002/ooooo`00Toooool2o`0000[ooooo0_l00006
ooooo`;o00000oooool00ol0003oooooooooo`0Sooooo`;o0000U?ooool009oooooo0_l0000;oooo
o`03o`000?oooooooooo02?ooooo0_l0002Dooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@04
ooooo`;o0000^oooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool0
0omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00?ooooo0_l0000Vooooo`;o0000Toooool0
087ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08
ooooo`03o`000?oooooooooo00?ooooo0ol0000Tooooo`?o0000T_ooool008Wooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`0Tooooo`?o0000T_ooool008Wooooo00Go0000ooooooooooooooooo`00000>
ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oo
oooooooo0;Wooooo0029ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgoooo
o`03ooooo`03o`000?oooooooooo00Oooooo00Co0000ooooool0003o0000^?ooool008Wooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003o
ooooooooo`07ooooo`04o`000?oooooo0000o`000;Sooooo0029ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo017ooooo0_l0002Voooo
o`00Soooool2o`0001_ooooo00?o0000ooooooooool04Oooool2o`000:Kooooo002?ooooo`;o0000
6oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0Fooooo`;o0000XOoo
ool00:cooooo0ol0000Fooooo`;o0000XOooool009Oooooo0_l0000:ooooo`;o00001oooool00ol0
003oooooooooo`0Fooooo`;o0000XOooool009Oooooo0_l0000:ooooo`;o00001oooool00ol0003o
ooooooooo`05ooooo`;o00003oooool2o`000:7ooooo002=ooooo`?o00005oooool2o`0000?ooooo
00?o0000ooooooooool01Oooool2o`0000oooooo1?l0000Dooooo`;o0000ROooool008gooooo0ol0
000Gooooo`;o00000oooool00ol0003oooooooooo`0Hooooo`;o00005?ooool2o`0008Wooooo002/
ooooo`03o`000?oooooooooo01Wooooo0_l0002Nooooo`00[?ooool00ol0003oooooooooo`0Ioooo
o`;o0000W_ooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0000booooo`;o0000
QOooool00:cooooo00?o0000ooooooooool0<_ooool2o`0008Gooooo002Jooooo`;o00004?ooool0
0ol0003oooooooooo`2iooooo`00V_ooool2o`00013ooooo00?o0000ooooooooool06oooool2o`00
09cooooo002<ooooo`;o00002_ooool2o`0001;ooooo00?o0000ooooooooool00_l0000Iooooo`Ko
0000V?ooool008cooooo0_l0000:ooooo`;o00004_ooool00ol0003oooooooooo`02o`0000_ooooo
0_l0000>ooooo`Co0000V?ooool00:cooooo00?o0000ooooooooool03Oooool2o`000:[ooooo002S
ooooo`;o00001oooool00ol0003oooooooooo`2iooooo`00Xoooool2o`0000Oooooo0ol0002ioooo
o`00Woooool4o`0000Gooooo0_l00002ooooo`03o`000?oooooooooo03Wooooo0_l0001nooooo`00
Woooool4o`0000Gooooo0_l00002ooooo`03o`000?oooooooooo03Wooooo0_l0001nooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`05ooooo`;o00003?ooool2
o`000:Cooooo002/ooooo`03o`000?oooooooooo00Gooooo0_l0000<ooooo`;o0000Y?ooool00:co
oooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool04oooool2o`0002Kooooo
0_l0001looooo`00[?ooool3o`0001?ooooo0_l0000Vooooo`;o0000O?ooool008?ooooo0_l0000@
ooooo`;o00005Oooool00ol0003oooooooooo`2iooooo`00Poooool2o`00013ooooo0_l0000>oooo
o`;o00001Oooool01?l0003oooooo`000?l0000Cooooo`;o00003oooool3o`00097ooooo002Coooo
o`;o00004?ooool2o`0000Gooooo00Co0000ooooool0003o00004oooool2o`000003ooooool0003o
000000cooooo0ol0002Aooooo`00S_ooool2o`0000?ooooo0_l0000>ooooo`;o00001oooool00ol0
003oooooooooo`0Fooooo`?o00003_ooool2o`00093ooooo0023ooooo`;o00002Oooool2o`0000Co
oooo0_l0000=ooooo`;o00001oooool01?l0003oooooooooooooool2o`0000Sooooo0_l00009oooo
o`;o00003oooool2o`00093ooooo0023ooooo`;o00003?ooool00oo^k^ko<S8bo`000002o`0000Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool01?l0003oooooooooooooool2
o`0000Sooooo0_l00009ooooo`;o00003oooool2o`00093ooooo002Aooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@?ooooo0_l00003ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool03?ooool2o`0000Sooooo0_l0002Qooooo`00ROooool6o`0000;ooooo00Go410@oooo
oooooooooooooa0@400:ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00cooooo0_l0002[ooooo`00TOooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMg
oc8b<_ooool01?ooool3o`0002cooooo0_l0000Cooooo`;o0000M_ooool0097ooooo00Co0000oooo
oooooooooooo0ol00005ooooo`;o00000oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool06oooool2o`0000oooooo0_l0000Cooooo`;o0000M_ooool008Oooooo0_l00008
ooooo`05oa0@4?ooooooooooooooool@41000_l00005ooooo`;o00000oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo01_ooooo0_l0002Looooo`00Qoooool2o`0000Sooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0^Ooo
ool0097ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`0002cooooo0ol0
002;ooooo`00[?ooool2o`0001cooooo0_l0000>ooooo`?o0000Roooool00:7ooooo0_l00009oooo
o`04o`000?oooooo0000o`0000oooooo0_l00009ooooo`;o0000W?ooool00:7ooooo0_l00009oooo
o`04o`000?oooooo0000o`0000oooooo0_l0000:ooooo`;o0000Voooool008cooooo0_l0000Noooo
o`?o00007?ooool2o`0002Sooooo0_l0001aooooo`00S?ooool2o`0001kooooo00?o0000oooooooo
ool07_ooool2o`00017ooooo0_l0000Cooooo`;o0000LOooool008Oooooo0_l0000Sooooo`03o`00
0?oooooooooo00Oooooo0_l0000Eooooo`?o00004?ooool2o`0008Kooooo0021ooooo`;o00001?oo
ool2o`0002?ooooo00?o0000ooooooooool01oooool2o`0001Kooooo0_l0000@ooooo`;o0000Q_oo
ool0087ooooo0_l0000Yooooo`03o`000?oooooooooo037ooooo0ol00025ooooo`00[?ooool00ol0
003oooooooooo`0Oooooo`;o00004Oooool2o`0008Gooooo002/ooooo`03o`000?oooooooooo01oo
oooo0_l0002Hooooo`00Toooool2o`0000oooooo0_l00006ooooo`03o`000?oooooooooo0;Wooooo
002Cooooo`;o00001_ooool2o`0000Oooooo1?l00004ooooo`?o00002_ooool2o`0001Cooooo0_l0
002Gooooo`00Q_ooool2o`0001?ooooo0_l00009ooooo`;o00001?ooool00ol0003oooooooooo`0:
ooooo`;o00005?ooool2o`0009Oooooo0026ooooo`;o00000oooool2o`0001oooooo00?o0000oooo
ooooool0Boooool2o`0006cooooo002;ooooo`;o00002Oooool2o`0001Cooooo0ol00004ooooo`;o
00003_ooool2o`0000gooooo0_l0000Vooooo`;o0000K?ooool008kooooo0_l00006ooooo`;o0000
1oooool2o`0000_ooooo0ol00004ooooo`;o00001_ooool2o`0000Kooooo0_l0000=ooooo`;o0000
U?ooool008kooooo0_l00002ooooo`;o00002oooool2o`0000_ooooo00Co0000ooooool0003o0000
2oooool2o`000:_ooooo002Booooo`;o00006?ooool01?l0003oooooo`000?l0002hooooo`00WOoo
ool2o`0000gooooo00?o0000ooooooooool06?ooool2o`0003;ooooo0_l0001[ooooo`00P?ooool2
o`0000?ooooo0_l0000Fooooo`;o00003Oooool3o`0001Sooooo0_l0000Kooooo`;o00005Oooool2
o`0006_ooooo0020ooooo`;o00000oooool2o`0000kooooo0_l0000<ooooo`;o00001oooool00ol0
003oooooooooo`0eooooo`;o0000P_ooool009Gooooo0_l000000ooooooo0000o`000007ooooo`Co
00001oooool00ol0003oooooooooo`0?ooooo`;o0000Z?ooool008Gooooo0_l00007ooooo`;o0000
2?ooool2o`0000Oooooo0_l00009ooooo`03o`000?oooooooooo00oooooo0_l0000Vooooo`;o0000
P?ooool008Gooooo0_l00007ooooo`;o00007?ooool2o`00013ooooo0_l0000Uooooo`?o0000P?oo
ool00:cooooo0_l0000@ooooo`;o00009Oooool2o`00087ooooo002Aooooo`;o00006Oooool00ol0
003oooooooooo`09ooooo`;o00003oooool2o`0009gooooo0020ooooo`;o00003oooool2o`0001Wo
oooo00?o0000ooooooooool02Oooool2o`0000oooooo0_l0002Mooooo`00P?ooool2o`0000Oooooo
0_l0000Qooooo`03o`000?oooooooooo013ooooo0_l0000Dooooo`;o0000TOooool008Wooooo0_l0
000Qooooo`?o00004?ooool2o`0001Cooooo0_l0002Aooooo`00[?ooool01?l0003oooooo`000?l0
002hooooo`00W?ooool2o`0000gooooo0_l000000ooooooo0000o`00000hooooo`;o0000O_ooool0
09cooooo0_l0000=ooooo`;o00003Oooool2o`0002cooooo0_l0001nooooo`00[?ooool00ol0003o
ooooooooo`0;ooooo`;o0000[?ooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
0;Wooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q
8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0:_ooool2
o`0000kooooo0_l0001mooooo`00POooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00_l000000ooooooo0000ooooo`0[
ooooo`?o00003Oooool2o`0007gooooo0029ooooo`05o`000?ooooooooooooooool000003Oooool0
0onHV9So8B4Qonk^kP07ooooo`04ogMgMolb<S;oooooooooo`;o000000Coooooo`000?l0003o0000
:oooool2o`0008cooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIV
ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0mooooo`;o
0000N_ooool008Wooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Looooo`;o00003_ooool2o`0000oo
oooo0_l0001jooooo`00ROooool01_mgMgOoV9RHoooooonHV9SoMgMgooooo`;o00002?ooool01Ol0
003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0L
ooooo`;o00003_ooool2o`0008_ooooo0029ooooo`06onk^k_lb<S;o0000oc8b<_o^k^kooooo0_l0
00000ooooooo0000o`000005ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo
00?o0000ooooooooool0^Oooool009;ooooo0_l0000Hooooo`03o`000?oooooooooo00cooooo0_l0
002[ooooo`00[?ooool00ol0003oooooooooo`07ooooo`;o00000oooool2o`000:_ooooo002[oooo
o`;o00002Oooool2o`0001Gooooo0_l0000=ooooo`;o0000R_ooool00:_ooooo1?l00003ooooo`;o
00006Oooool2o`0000gooooo0_l0002:ooooo`00[?ooool00ol0003oooooooooo`03ooooo`;o0000
0oooool2o`0000Cooooo0_l0000Kooooo`;o0000S?ooool00:cooooo00?o0000ooooooooool02?oo
ool2o`0000Cooooo0_l0000Kooooo`;o0000S?ooool00:cooooo00?o0000ooooooooool05_ooool2
o`0000Oooooo0_l0000<ooooo`;o00009oooool2o`00067ooooo002/ooooo`03o`000?oooooooooo
01Kooooo0ol00006ooooo`;o00003?ooool2o`0002Oooooo0_l0001Qooooo`00[?ooool00ol0003o
ooooooooo`0Gooooo`;o00009_ooool2o`0007Sooooo002/ooooo`03o`000?oooooooooo01Gooooo
0_l0000Xooooo`?o0000Moooool00:cooooo00?o0000ooooooooool05Oooool2o`0000_ooooo0_l0
000Looooo`;o0000Moooool008kooooo0_l0000Looooo`?o00008_ooool2o`0009Gooooo001noooo
o`;o00003_ooool2o`0001cooooo00?o0000ooooooooool08_ooool2o`0000Wooooo0_l0000Yoooo
o`;o0000Goooool007kooooo0_l0000/ooooo`03o`000?oooooooooo027ooooo0ol00009ooooo`;o
0000:Oooool2o`0005oooooo002/ooooo`?o00008Oooool3o`0000[ooooo0_l0000Aooooo`;o0000
M_ooool00:cooooo0ol0000@ooooo`;o00007?ooool2o`0000oooooo1?l0001fooooo`00[?ooool0
0ol0003oooooooooo`0@ooooo`;o0000;Oooool4o`0001Gooooo0_l0001Oooooo`00Poooool2o`00
02Oooooo00?o0000ooooooooool0F?ooool2o`0005oooooo0023ooooo`;o00009oooool00ol0003o
ooooooooo`2iooooo`00Poooool2o`0002Oooooo00?o0000ooooooooool02oooool2o`000:cooooo
0022ooooo`;o0000:?ooool3o`0000Kooooo0_l00003ooooo`;o00005Oooool2o`0009Gooooo0022
ooooo`;o0000:?ooool00ol0003oooooooooo`06ooooo`;o00006_ooool2o`0009Gooooo0022oooo
o`;o0000:?ooool00ol0003oooooooooo`07ooooo`;o0000>?ooool2o`0007Kooooo0009ooooo`Co
000000?o410@ooooooooool05_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2o`0000Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b
<_oMgMd05_ooool00ol0003oooooooooo`07ooooo`;o00003oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00_ooooo0_l0
0002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^
k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1?l000000ol@413oooooooooo`0B
ooooo`002oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`06oiRHV?lQ8B7ok^k^oooooom4A4Cooooo0_l00004oooo
o`03ogMgMolb<S;ooooo01Gooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8boooo
o`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0
3_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oo
oooo00?oMgMgoc8b<_ooool06Oooool00ol0003oooooooooo`0Dooooo`001_l00005ooooo`03o`00
0?oooooooooo013ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol0003oooooooooo`05ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h00_ooool2o`0000Gooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0Hooooo`;o00000_ooool00ol@413oooooooooo`03ooooo`;o00001Oooool0
0onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00gooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00gooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVY
ZOmEEEGooooo00Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Dooooo`002ooo
ool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooo
ooooo`06ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000?ooooo`03
ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^
00Oooooo00?oMgMgoc8b<_ooool05Oooool00ol0003oooooooooo`0Aooooo`;o00001Oooool2o`00
00;ooooo00?o0000ooooooooool00oooool2o`0000Kooooo00?oV9RHob4Q8Oo^k^h01oooool00omg
MgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003oooool2o`0000oooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool06Ooo
ool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05o`000?oooooo
ooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
3oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?oooo
o`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`05_ooool00ol0003oooooooooo`0Aooooo`;o00001Oooool01Ol0003ooooooooo
oooooooo000000Kooooo0_l00006ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003o8B4Qo`000002o`00
00oooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c00Jooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooo
oooo01Sooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o
0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool0
4Oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Hooooo`?o00002oooool2o`0000_ooooo00Go410@oooooooooooooooooa0@4006oooo
o`;o00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@
400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00;o00002Oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0;ooooo`;o00002oooool01OmgMgOoV9RHo`000?l0003oMgMg00Kooooo0_l0
0003ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`0Aooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Dooooo`002Oooool00omEEEGoIVIVo`00000Jooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?oo
ool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02o`0000Wooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c004ooooo`Co00005oooool00ol0003oooooooooo`0Hooooo`05onk^k_lb<S;o0000o`00
0?o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00;ooooo1_l0000@ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go0000
1?ooool4o`0001Wooooo00?oEEEEofIVI_l000005_ooool00:cooooo00?o0000ooooooooool04Ooo
ool2o`0000Kooooo0_l0000Dooooo`;o0000R?ooool00:cooooo00?o0000ooooooooool03?ooool2
o`0000?ooooo0_l00006ooooo`;o00005?ooool2o`0002Wooooo0_l0001Mooooo`00[?ooool00ol0
003oooooooooo`0<ooooo`;o0000C?ooool2o`0005;ooooo0_l00002ooooo`;o00001Oooool008Oo
oooo0_l0000Sooooo`03o`000?oooooooooo00Oooooo0_l0000Aooooo`;o0000T_ooool01_o^k^ko
8B4QohN7Qonj^[[o0000omgMg@Gooooo0027ooooo`;o00008oooool00ol0003oooooooooo`07oooo
o`;o00004Oooool2o`0002Sooooo0_l0001Yooooo`04omgMgOl0003o410@olc<c0Kooooo0007oooo
oooo0000C?l0000<ooooo`04onk^k_lQ8B7o410@onk^kPKooooo0007ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0
003oooooooooo`02o`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool3o`0000?ooooo0ol00007oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool2o`0000;ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool02_ooool01?lQ8B7oMgMgogMgMolb<S86ooooo`001oooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`08oooo
o`;o00007?ooool00ol0003oooooooooo`03ooooo`;o00007_ooool2o`0000;ooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool02Oooool2o`0000;ooooo0_l00005ooooo`00[?ooool00ol0003oooooooooo`03ooooo`;o
0000?_ooool2o`0007Cooooo002/ooooo`03o`000?oooooooooo01[ooooo0_l0000Wooooo`?o0000
Loooool00:cooooo00?o0000ooooooooool06_ooool2o`0002Gooooo1Ol0001cooooo`00UOooool2
o`0001Gooooo00?o0000ooooooooool0@Oooool4o`0007Cooooo002Eooooo`;o00005Oooool00ol0
003oooooooooo`2iooooo`00[?ooool3o`0001Wooooo0_l00008ooooo`;o00007Oooool2o`0007Go
oooo002Cooooo`;o00005oooool00ol0003oooooooooo`0Aooooo`;o00001_ooool2o`0000Sooooo
0_l0000Mooooo`;o0000MOooool008[ooooo0_l00007ooooo`;o00001Oooool2o`00013ooooo00?o
0000ooooooooool04Oooool2o`000:Kooooo001nooooo`;o00002_ooool2o`0000kooooo0_l0000@
ooooo`03o`000?oooooooooo033ooooo0_l00027ooooo`00O_ooool2o`0000[ooooo0_l0000Poooo
o`03o`000?oooooooooo00Oooooo0_l00009ooooo`;o00004?ooool2o`0000[ooooo0_l00027oooo
o`00Poooool2o`0000Wooooo0_l0000Looooo`03o`000?oooooooooo00Oooooo0_l00009ooooo`;o
00004?ooool2o`0009?ooooo0023ooooo`;o00002Oooool2o`0001cooooo00?o0000ooooooooool0
9?ooool2o`0009?ooooo0023ooooo`;o00009oooool00ol0003oooooooooo`0<ooooo`;o00000ooo
ool2o`0000oooooo1?l0000Nooooo`;o0000Loooool008?ooooo0_l0000Wooooo`03o`000?oooooo
oooo00cooooo0_l00003ooooo`;o00003oooool2o`00023ooooo0_l0001cooooo`00[?ooool3o`00
00cooooo0_l0002[ooooo`00TOooool2o`0001Wooooo00?o0000ooooooooool0@Oooool4o`0007Co
oooo002>ooooo`;o000000?oooooo`000?l000006Oooool00ol0003oooooooooo`11ooooo`Co0000
M?ooool008kooooo0_l00008ooooo`;o00004_ooool00ol0003oooooooooo`0@ooooo`;o00001ooo
ool2o`0002Sooooo0_l0001dooooo`00U_ooool4o`0001;ooooo00?o0000ooooooooool04?ooool2
o`0000Oooooo0_l00007ooooo`;o0000UOooool009Kooooo0_l0000Dooooo`03o`000?oooooooooo
02;ooooo0_l0002Eooooo`00[?ooool00ol0003oooooooooo`0@ooooo`;o0000Yoooool008_ooooo
0_l0000Oooooo`03o`000?oooooooooo013ooooo0_l0000?ooooo`;o00003?ooool2o`0008Sooooo
002;ooooo`;o00007oooool3o`000003ooooool0003o000001kooooo0_l0000<ooooo`Co00004Ooo
ool2o`0007?ooooo0023ooooo`;o00001_ooool2o`0001oooooo00Co0000oooooooooooooooo0_l0
000^ooooo`;o00004?ooool3o`0007?ooooo0023ooooo`;o00001oooool2o`0001kooooo00?o0000
ooooooooool01Oooool2o`0002Oooooo0_l0000Cooooo`;o0000M?ooool008cooooo0_l0000Noooo
o`03o`000?oooooooooo00Gooooo0_l00003ooooo`;o00008_ooool3o`0008Sooooo002/ooooo`03
o`000?oooooooooo00[ooooo0_l0000Sooooo`;o0000R?ooool008oooooo0_l0000Kooooo`03o`00
0?oooooooooo00Gooooo0_l0002booooo`00Qoooool2o`0000Kooooo0_l00003ooooo`;o00004ooo
ool2o`000003ooooool0003ooooo00Kooooo0_l0002booooo`00Q?ooool2o`000003ooooool0003o
000000_ooooo0_l0000Cooooo`;o000000?oooooo`000?ooool05oooool2o`0001Gooooo0_l0002:
ooooo`00Q?ooool2o`0000;ooooo0_l0000Rooooo`?o000000?oooooo`000?l000004oooool3o`00
00Oooooo0_l0000;ooooo`;o00004_ooool2o`0007Kooooo0028ooooo`;o00008_ooool01?l0003o
ooooooooooooool2o`0000cooooo0_l00006ooooo`;o00001oooool2o`0001oooooo0_l0001foooo
o`00[?ooool00ol0003oooooooooo`08ooooo`;o00001Oooool2o`0000Kooooo0_l0002Pooooo`00
[?ooool00ol0003oooooooooo`08ooooo`;o0000[oooool00:cooooo00?o0000ooooooooool07ooo
ool2o`0000kooooo0_l00028ooooo`00[?ooool00ol0003oooooooooo`0Oooooo`;o00003_ooool2
o`00017ooooo0_l0001eooooo`00Ooooool2o`0000Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo00?ooooo0_l0000mooooo`;o0000MOooool007oooooo0_l00008ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool00oooool2o`000;Cooooo0029ooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo
0ol00011ooooo`;o0000M_ooool008Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`07ooooo`;o0000
3?ooool2o`0000Sooooo0_l0000Pooooo`;o0000M_ooool008Wooooo0_l00002ooooo`03o`000?oo
oooooooo00cooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool01oooool2o`0000_ooooo0ol00008ooooo`;o0000V?ooool008Wooooo0_l0
0002ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo0_l0000;ooooo`;o0000Xoooool008Wooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;Wooooo001oooooo`;o00002?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003o
ooooooooo`2iooooo`00Ooooool2o`0002_ooooo0_l0000Oooooo`;o0000VOooool00:cooooo0_l0
000Oooooo`;o00007_ooool2o`0007Wooooo002/ooooo`03o`000?oooooooooo03kooooo0_l0001i
ooooo`00[?ooool3o`0000Gooooo0_l00005ooooo`;o0000B?ooool2o`00067ooooo002/ooooo`03
o`000?oooooooooo00Gooooo0_l00003ooooo`Co00001Oooool2o`00047ooooo0_l0001Qooooo`00
YOooool2o`0000Gooooo00?o0000ooooooooool02_ooool2o`0000Oooooo0_l00008ooooo`;o0000
8?ooool2o`0007Sooooo002Hooooo`;o00002oooool2o`0000Gooooo00?o0000ooooooooool07Ooo
ool2o`00023ooooo0_l0001hooooo`00S_ooool2o`0000Gooooo0_l000000ooooooo0000o`000002
ooooo`;o00003_ooool00ol0003oooooooooo`0Mooooo`;o0000V_ooool008kooooo0_l00005oooo
o`;o000000?oooooo`000?l000000_ooool2o`0000kooooo00?o0000ooooooooool02_ooool2o`00
017ooooo0_l0002Jooooo`00[?ooool00ol0003oooooooooo`0:ooooo`;o0000[Oooool00:Wooooo
0_l000001?oooooo0000o`000?l0002iooooo`00ZOooool2o`000004ooooool0003o0000o`0002So
oooo0_l0000Booooo`;o0000Noooool009kooooo0_l00008ooooo`;o00000_ooool00ol0003ooooo
ooooo`0Xooooo`?o00004Oooool2o`0007_ooooo002Nooooo`;o00002?ooool2o`0000;ooooo00?o
0000ooooooooool02?ooool2o`0000Oooooo0_l0000Fooooo`;o0000S_ooool00:cooooo0_l00009
ooooo`;o00001oooool2o`000:Kooooo002?ooooo`;o00004?ooool2o`0000Wooooo0_l00007oooo
o`;o0000<Oooool2o`000003ooooool0003o000007_ooooo002?ooooo`;o00004?ooool2o`0000So
oooo0_l00008ooooo`;o00007Oooool2o`000004ooooool0003o0000o`0000kooooo0_l000000ooo
oooo0000o`00001kooooo`00Roooool2o`0001kooooo0_l00007ooooo`;o00007_ooool2o`000004
ooooool0003o0000o`0000kooooo0_l0001nooooo`00Roooool2o`0001oooooo00?o0000oooooooo
ool01Oooool2o`0004_ooooo0_l0001Uooooo`00[?ooool3o`0005;ooooo0_l0001Uooooo`00U?oo
ool2o`0001Kooooo00?o0000ooooooooool0^Oooool0093ooooo0_l00002ooooo`;o00000_ooool2
o`0001;ooooo00Co0000ooooool0003o00009_ooool2o`00093ooooo002@ooooo`;o00001_ooool2
o`0001;ooooo00Co0000ooooool0003o00009_ooool2o`00093ooooo002/ooooo`03o`000?oooooo
oooo00_ooooo0_l0000:ooooo`;o00007Oooool2o`00087ooooo002Eooooo`;o00005Oooool00ol0
003oooooooooo`0;ooooo`;o00002_ooool2o`0001gooooo0_l00021ooooo`00UOooool2o`0001Go
oooo00?o0000ooooooooool02oooool2o`0002[ooooo0_l0000Fooooo`;o0000J?ooool00:cooooo
00?o0000ooooooooool02oooool2o`0002Wooooo1?l0000Eooooo`;o0000J?ooool00:cooooo0ol0
000;ooooo`;o0000:Oooool4o`0007oooooo002=ooooo`;o00003Oooool2o`0000kooooo00?o0000
ooooooooool0=oooool3o`0007oooooo0022ooooo`;o00002Oooool2o`0000cooooo0ol0000>oooo
o`03o`000?oooooooooo03Oooooo0_l00020ooooo`00P_ooool2o`0001?ooooo0_l00002ooooo`;o
00003oooool00ol0003oooooooooo`0Rooooo`;o0000UOooool009Oooooo0_l0000Cooooo`03o`00
0?oooooooooo01Cooooo0_l0000<ooooo`;o00004_ooool2o`00087ooooo002Xooooo`;o00000_oo
ool00ol0003oooooooooo`0Dooooo`;o00003?ooool2o`0001;ooooo0_l00021ooooo`00P_ooool2
o`0000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01_m4A4Co0000o`00
0?lb<S;ogMgMooooo`;o00000_ooool00ol0003oooooooooo`0Rooooo`;o0000UOooool008;ooooo
0_l0000=ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool2o`000003oooooolQ8B7o8B4Q00So
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Rooooo`;o0000UOooool0097ooooo
00Go410@oooooooooooooooooa0@4002ooooo`;o00003?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo0;Wooooo0028ooooo`;o00001oooool00ol0003oooooo`000002o`0000oooooo
00?oMgMgoc8b<_ooool01?ooool3o`000;Wooooo0028ooooo`;o00001oooool00ol0003oooooo`00
0002o`0000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`?o0000B_ooool2o`0006gooooo
002Aooooo`05oa0@4?ooooooooooooooool@41000oooool3o`0000Kooooo00?o0000ooooooooool0
1oooool3o`0000Kooooo0_l00012ooooo`;o0000KOooool0097ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`Co00001Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
0_l00007ooooo`;o00008Oooool2o`0008Gooooo002:ooooo`;o00001Oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_l00005ooooo`Co00001Oooool2o`00017ooooo0_l0000Qooooo`;o0000
QOooool008[ooooo0_l0000Oooooo`;o0000^oooool00:cooooo00?o0000ooooooooool0<Oooool2
o`0008Kooooo002Kooooo`;o00003oooool00ol0003oooooooooo`03ooooo`;o0000;?ooool2o`00
08Kooooo002Kooooo`;o00003?ooool2o`000004ooooool0003o0000o`0000;ooooo0ol0000[oooo
o`;o0000Qoooool00:Oooooo1?l000000ooooooo0000ooooo`03ooooo`;o0000;?ooool2o`0008Oo
oooo002;ooooo`;o00006_ooool2o`0000?ooooo00?o0000ooooooooool06oooool2o`0009cooooo
002;ooooo`;o00007oooool00ol0003oooooooooo`0Kooooo`;o0000W?ooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool06Oooool2o`00017ooooo0_l0002;oooo
o`00Uoooool3o`0001;ooooo00?o0000ooooooooool06?ooool3o`00017ooooo0_l0002;ooooo`00
Uoooool3o`0001;ooooo00?o0000ooooooooool02Oooool2o`0000gooooo0_l0002Oooooo`00[?oo
ool3o`0000Wooooo0_l0000;ooooo`;o00004oooool3o`0008_ooooo002Booooo`;o00006?ooool0
0ol0003oooooooooo`0Fooooo`;o00004oooool3o`0008_ooooo002=ooooo`;o00000oooool2o`00
01Oooooo0_l00009ooooo`;o00008?ooool2o`0008kooooo0026ooooo`;o00001Oooool2o`0001co
oooo0_l00009ooooo`;o00008?ooool2o`0008kooooo0026ooooo`;o00009?ooool00ol0003ooooo
ooooo`0Yooooo`;o0000S_ooool008Kooooo0_l0000Tooooo`03o`000?oooooooooo00Kooooo0_l0
000Nooooo`Go0000S_ooool008Kooooo0_l0000Tooooo`03o`000?oooooooooo00Kooooo0_l0000N
ooooo`?o00005_ooool2o`0007Sooooo002Xooooo`;o00000_ooool00ol0003oooooooooo`0ooooo
o`;o0000N?ooool00:Sooooo0_l00002ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0
^Oooool00:;ooooo0_l00008ooooo`03o`000?oooooooooo02Kooooo0_l0002Aooooo`00X_ooool2
o`0000Sooooo00?o0000ooooooooool08oooool2o`000003ooooool0003o0000097ooooo002/oooo
o`03o`000?oooooooooo00;ooooo0_l0000Oooooo`;o0000U?ooool00:cooooo00?o0000oooooooo
ool00_ooool2o`0001cooooo0_l0002Gooooo`00[?ooool00ol0003oooooooooo`0Pooooo`;o0000
Uoooool00:cooooo00Co0000oooooooooooooooo0_l0002fooooo`00VOooool2o`00017ooooo00Co
0000oooooooooooooooo0_l0002fooooo`00VOooool2o`00017ooooo0ol0000Qooooo`;o0000U_oo
ool009Wooooo0_l0000Aooooo`03o`000?oooooooooo01gooooo1_l0002Fooooo`00VOooool2o`00
017ooooo00?o0000ooooooooool07Oooool4o`0009Sooooo002Zooooo`?o00007_ooool4o`0009Wo
oooo002Zooooo`?o00007_ooool4o`0009Wooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Go
oooo00?o0000ooooooooool06oooool2o`0001Sooooo0_l00022ooooo`00ROooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo0_l00002ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo00Oooooo0_l0000Booooo`;o00006?ooool2o`0008;o
oooo0029ooooo`05oa0@4?ooooooooooooooool@41000oooool2o`0000Sooooo00?oZJVYoeEEEOoo
ool00_l00004ooooo`Co00001?ooool00ol0003oooooooooo`07ooooo`;o00004oooool2o`0009_o
oooo0029ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooo`000003o`0000;o
oooo1?l00004ooooo`?o00001oooool2o`0001?ooooo0_l0002Kooooo`00ROooool01Ol0003ooooo
oooooooooooo000000Kooooo0_l00006ooooo`04oeEEEOo<c<coooooooooo`?o000000Co8B4Qo`00
0?lb<S;oc<c<1Oooool00ol0003oooooooooo`05ooooo`Co00003oooool2o`0009oooooo0029oooo
o`05oa0@4?ooooooooooooooool@41001_ooool2o`0000Kooooo00CoZJVYogMgMooooooooooo0ol0
0009ooooo`03o`000?oooooooooo00Gooooo0_l0000Aooooo`Co0000WOooool008Wooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S800_ooool3o`0000Wooooo
00?o0000ooooooooool01Oooool2o`0001;ooooo0ol0002Mooooo`00ROooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`05ooooo`;o0000
4_ooool2o`0009kooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Fooooo`;o00005?ooool0
0ol0003oooooooooo`04ooooo`;o00004Oooool2o`000:3ooooo002Fooooo`;o00005?ooool00ol0
003oooooooooo`04ooooo`;o00004Oooool2o`000:3ooooo002/ooooo`?o0000^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool009[ooooo0_l0000@
ooooo`Co0000^?ooool009[ooooo0_l0000@ooooo`Co0000^?ooool00:cooooo0ol0002iooooo`00
[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0Aooooo`;o0000Y_oo
ool00:cooooo0ol0000Aooooo`;o0000Y_ooool009gooooo0_l00006ooooo`;o00001Oooool00ol0
003oooooooooo`2iooooo`00Soooool2o`0000cooooo0_l00006ooooo`;o00001Oooool00ol0003o
ooooooooo`2iooooo`00Soooool2o`0000kooooo0_l0000;ooooo`03o`000?oooooooooo00kooooo
0_l0002Yooooo`00Woooool2o`0000_ooooo00?o0000ooooooooool02_ooool2o`0000;ooooo0_l0
002Yooooo`00[?ooool00ol0003oooooooooo`0:ooooo`;o0000[Oooool00:cooooo00?o0000oooo
ooooool02oooool2o`000:cooooo002Booooo`;o00006?ooool00ol0003oooooooooo`0;ooooo`;o
0000[?ooool009;ooooo0ol0000Gooooo`03o`000?oooooooooo0;Wooooo002Cooooo`;o00005ooo
ool3o`0000Kooooo0_l0002aooooo`00[?ooool00ol0003oooooooooo`06ooooo`;o0000/Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool01Oooool2o`000;;o
oooo002/ooooo`03o`000?oooooooooo00Gooooo0_l0002booooo`00[?ooool00ol0003ooooooooo
o`04ooooo`;o0000/oooool00:cooooo00?o0000ooooooooool00_l00002ooooo`;o0000/oooool0
0:cooooo00?o0000ooooooooool00_l0002gooooo`00[?ooool5o`000;Oooooo002/ooooo`03o`00
0?oooooooooo00;o0000]oooool00:_ooooo0_l0002kooooo`00Zoooool2o`000;_ooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Rooooo`Co0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`2iooooo`00Y?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`03o`000?oooooooooo00Gooooo0ol0002i
ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00
Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00X_ooool0
0omEEEGoIVIVo`000033ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00Z_ooool01?l@413o0000o`000?l0002jooooo`00Zoooool00ol0003oooooooooo`2j
ooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool01_l0003oMgMgo`000?l0003oEEEE
onk^k[Oooooo002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoEEEE]oooool00:_ooooo00?o0000
onk^k_ooool00_ooool00ol0003oooooooooo`2eooooo`00Zoooool00ol0003ok^k^ooooo`02oooo
o`03o`000?oooooooooo0;Gooooo002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoIVIV]oooool0
0:[ooooo00?o410@o`000?mgMgL00_l000000omVIVKok^k^ooooo`2fooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.40809 .23784 Mdot
.57201 .20962 Mdot
.48819 .62266 Mdot
.52062 .67559 Mdot
.54596 .29485 Mdot
.52138 .83737 Mdot
.43909 .43438 Mdot
.72954 .52007 Mdot
.67976 .3235 Mdot
.54068 .34523 Mdot
.56482 .56302 Mdot
.71743 .6108 Mdot
.66956 .49038 Mdot
.56796 .46656 Mdot
.70087 .65375 Mdot
.41759 .56339 Mdot
.52791 .20911 Mdot
.67039 .5047 Mdot
.40915 .5744 Mdot
.4569 .94315 Mdot
.66582 .53214 Mdot
.63071 .33367 Mdot
.64639 .39618 Mdot
.66902 .5379 Mdot
.65853 .77043 Mdot
.55532 .71312 Mdot
.53781 .67791 Mdot
.41305 .61501 Mdot
.41555 .86421 Mdot
.58433 .23472 Mdot
.65564 .59883 Mdot
.67849 .31344 Mdot
.72234 .47702 Mdot
.5991 .37129 Mdot
.62395 .51336 Mdot
.5167 .90258 Mdot
.47962 .04052 Mdot
.45286 .77728 Mdot
.38077 .65184 Mdot
.71653 .63016 Mdot
.66829 .76005 Mdot
.61737 .44334 Mdot
.59608 .68016 Mdot
.42408 .16665 Mdot
.38615 .47468 Mdot
.59342 .48041 Mdot
.56358 .45527 Mdot
.6318 .21837 Mdot
.41368 .71089 Mdot
.41491 .85625 Mdot
.62859 .21529 Mdot
.37618 .39237 Mdot
.72824 .26834 Mdot
.61344 .60709 Mdot
.61523 .61569 Mdot
.70634 .40083 Mdot
.72787 .53676 Mdot
.521 .19551 Mdot
.57036 .13203 Mdot
.38788 .57568 Mdot
.59333 .52133 Mdot
.43941 .98709 Mdot
.37712 .58854 Mdot
.45565 .27734 Mdot
.7168 .48789 Mdot
.69464 .35409 Mdot
.53377 .3278 Mdot
.42539 .63476 Mdot
.4528 .78042 Mdot
.66386 .58265 Mdot
.54557 .22977 Mdot
.51914 .44185 Mdot
.54657 .36934 Mdot
.49224 .23836 Mdot
.37718 .58956 Mdot
.44773 .41879 Mdot
.72856 .26909 Mdot
.57775 .62406 Mdot
.37378 .53237 Mdot
.42852 .76371 Mdot
.61446 .7386 Mdot
.57882 .22702 Mdot
.53501 .62075 Mdot
.6201 .45714 Mdot
.72372 .45686 Mdot
.41529 .53471 Mdot
.5538 .31333 Mdot
.57744 .39804 Mdot
.48509 .14779 Mdot
.42186 .60417 Mdot
.65175 .78155 Mdot
.53643 .01997 Mdot
.52393 .34518 Mdot
.58606 .42636 Mdot
.50633 .29996 Mdot
.5664 .45286 Mdot
.63663 .23498 Mdot
.73784 .28652 Mdot
.4874 .14619 Mdot
.43757 .13779 Mdot
.43617 .19159 Mdot
.71416 .61441 Mdot
.45534 .10526 Mdot
.64164 .67594 Mdot
.60645 .39861 Mdot
.5673 .27406 Mdot
.40933 .41092 Mdot
.52532 .34921 Mdot
.66116 .59312 Mdot
.55783 .40253 Mdot
.52961 .65022 Mdot
.67546 .30807 Mdot
.51323 .91414 Mdot
.79633 .51808 Mdot
.47515 .28905 Mdot
.58879 .57185 Mdot
.70559 .37447 Mdot
.69434 .3448 Mdot
.47515 .04449 Mdot
.66862 .49139 Mdot
.50675 .99141 Mdot
.66054 .49145 Mdot
.41051 .84876 Mdot
.66207 .5917 Mdot
.49867 .73054 Mdot
.48352 .94272 Mdot
.43518 .00532 Mdot
.52548 .15005 Mdot
.53235 .47135 Mdot
.64583 .38406 Mdot
.48001 .10018 Mdot
.70526 .65922 Mdot
.51488 .85016 Mdot
.57499 .73612 Mdot
.38204 .68353 Mdot
.4425 .06046 Mdot
.44063 .92034 Mdot
.54369 .36051 Mdot
.72236 .52253 Mdot
.7004 .66098 Mdot
.36381 .62839 Mdot
.55043 .5074 Mdot
.42978 .72276 Mdot
.52816 .20892 Mdot
.48598 .94518 Mdot
.7182 .42456 Mdot
.78935 .61757 Mdot
.42454 .30021 Mdot
.58403 .42885 Mdot
.55213 .94496 Mdot
.4209 .24194 Mdot
.50827 .75781 Mdot
.66981 .54225 Mdot
.51219 .40035 Mdot
.44105 .85414 Mdot
.41665 .12297 Mdot
.3746 .52467 Mdot
.70494 .37945 Mdot
.48333 .04282 Mdot
.42223 .10561 Mdot
.49898 .82346 Mdot
.37374 .54666 Mdot
.68627 .73374 Mdot
.55638 .84476 Mdot
.59188 .68421 Mdot
.43057 .15768 Mdot
.71567 .41594 Mdot
.63156 .70776 Mdot
.46326 .79162 Mdot
.40976 .14229 Mdot
.44587 .92184 Mdot
.53733 .40699 Mdot
.48982 .78456 Mdot
.55645 .32563 Mdot
.43945 .23977 Mdot
.72052 .49178 Mdot
.44853 .86558 Mdot
.46981 .29555 Mdot
.4002 .80006 Mdot
.38512 .2763 Mdot
.70443 .67347 Mdot
.44317 .26892 Mdot
.66117 .77505 Mdot
.5182 .63328 Mdot
.67442 .31522 Mdot
.433 .01058 Mdot
.67384 .29569 Mdot
.69047 .7215 Mdot
.58726 .70828 Mdot
.54873 .94385 Mdot
.48749 .94481 Mdot
.42699 .40669 Mdot
.72706 .488 Mdot
.63675 .82467 Mdot
.71121 .63316 Mdot
.58028 .40035 Mdot
.5922 .07435 Mdot
.59743 .34382 Mdot
.43382 .41921 Mdot
.43703 .39086 Mdot
.52245 .47756 Mdot
.54012 .28619 Mdot
.61989 .10656 Mdot
.45895 .10848 Mdot
.44555 .68392 Mdot
.49308 .87659 Mdot
.53608 .63124 Mdot
.49205 .71361 Mdot
.56403 .57804 Mdot
.65894 .41353 Mdot
.58185 .60605 Mdot
.63 .71134 Mdot
.42817 .33431 Mdot
.44003 .13619 Mdot
.58608 .57458 Mdot
.68194 .74202 Mdot
.51871 .63702 Mdot
.39341 .64215 Mdot
.72292 .60054 Mdot
.59065 .55729 Mdot
.58607 .15731 Mdot
.64035 .68473 Mdot
.59404 .77928 Mdot
.41787 .44155 Mdot
.50013 .20857 Mdot
.54959 .17204 Mdot
.53337 .38489 Mdot
.70031 .65698 Mdot
.44182 .71594 Mdot
.49564 .63616 Mdot
.62932 .12179 Mdot
.39991 .41721 Mdot
.54384 .66405 Mdot
.52496 .97023 Mdot
.47211 .79344 Mdot
.47679 .09416 Mdot
.66245 .47571 Mdot
.46558 .1021 Mdot
.43652 .98174 Mdot
.55926 .77373 Mdot
.60833 .76442 Mdot
.54455 .22807 Mdot
.6807 .31295 Mdot
.49479 .27749 Mdot
.41231 .14239 Mdot
.45682 .16285 Mdot
.53999 .22006 Mdot
.37652 .5822 Mdot
.64201 .81394 Mdot
.47134 .29044 Mdot
.42844 .39815 Mdot
.43691 .07841 Mdot
.54447 .73365 Mdot
.49751 .77311 Mdot
.61099 .64512 Mdot
.4545 .38378 Mdot
.7259 .52573 Mdot
.6054 .17828 Mdot
.39927 .57253 Mdot
.54461 .66175 Mdot
.58207 .80228 Mdot
.51818 .38136 Mdot
.41724 .26206 Mdot
.39374 .34664 Mdot
.56524 .48862 Mdot
.54152 .79762 Mdot
.48417 .9367 Mdot
.50691 .80425 Mdot
.50586 .91988 Mdot
.61152 .63607 Mdot
.53822 .33494 Mdot
.41135 .68758 Mdot
.40997 .14476 Mdot
.45173 .24719 Mdot
.45168 .20571 Mdot
.64064 .23642 Mdot
.56759 .55576 Mdot
.45934 .87962 Mdot
.38698 .72088 Mdot
.53557 .48618 Mdot
.46585 .23477 Mdot
.48459 .04414 Mdot
.71888 .59026 Mdot
.41116 .38489 Mdot
.48372 .32269 Mdot
.50135 .21707 Mdot
.55049 .86577 Mdot
.5887 .45539 Mdot
.6255 .71001 Mdot
.43412 .00942 Mdot
.56111 .12301 Mdot
.71069 .61494 Mdot
.56844 .13551 Mdot
.44898 .62626 Mdot
.5363 .08876 Mdot
.57969 .8212 Mdot
.70447 .63977 Mdot
.77875 .66648 Mdot
.42742 .76673 Mdot
.58988 .71081 Mdot
.48844 .10231 Mdot
.68035 .31456 Mdot
.66991 .75153 Mdot
.56643 .48176 Mdot
.63853 .23498 Mdot
.5345 .75592 Mdot
.43638 .5956 Mdot
.65687 .41169 Mdot
.5417 .23165 Mdot
.66642 .47821 Mdot
.56818 .9247 Mdot
.49138 .30252 Mdot
.38767 .53823 Mdot
.61008 .41137 Mdot
.718 .51197 Mdot
.52141 .39056 Mdot
.70027 .68419 Mdot
.56613 .91542 Mdot
.35908 .47544 Mdot
.46194 .75096 Mdot
.51366 .85385 Mdot
.62165 .46214 Mdot
.3756 .44092 Mdot
.50338 .21136 Mdot
.42962 .50331 Mdot
.43753 .54004 Mdot
.55536 .25151 Mdot
.72704 .56935 Mdot
.43251 .08912 Mdot
.50208 .28885 Mdot
.64762 .37567 Mdot
.53393 .49047 Mdot
.52267 .48512 Mdot
.55596 .18178 Mdot
.53483 .81678 Mdot
.5913 .68627 Mdot
.49799 .82452 Mdot
.53094 .26758 Mdot
.70704 .22736 Mdot
.53056 .76053 Mdot
.56225 .2026 Mdot
.45979 .27246 Mdot
.71619 .44542 Mdot
.54467 .65501 Mdot
.45131 .93353 Mdot
.60512 .28039 Mdot
.54494 .43037 Mdot
.5892 .51101 Mdot
.36531 .65316 Mdot
.7203 .60073 Mdot
.52956 .07906 Mdot
.50496 .91856 Mdot
.44756 .81872 Mdot
.59306 .33673 Mdot
.45872 .93573 Mdot
.40619 .33586 Mdot
.71994 .60041 Mdot
.35895 .44242 Mdot
.6029 .77548 Mdot
.70574 .65528 Mdot
.69678 .69409 Mdot
.66863 .76591 Mdot
.51978 .56421 Mdot
.39818 .52474 Mdot
.69829 .66606 Mdot
.7271 .52835 Mdot
.51651 .58816 Mdot
.64049 .6685 Mdot
.52507 .76731 Mdot
.49218 .87942 Mdot
.42742 .1631 Mdot
.64863 .25706 Mdot
.47445 .09465 Mdot
.50991 .06229 Mdot
.39901 .20507 Mdot
.64258 .38282 Mdot
.50467 .05108 Mdot
.64202 .37346 Mdot
.67453 .73613 Mdot
.79701 .55457 Mdot
.50555 .06366 Mdot
.43114 .83491 Mdot
.50555 .37676 Mdot
.60512 .86374 Mdot
.47165 .14458 Mdot
.43982 .5684 Mdot
.70321 .6814 Mdot
.66284 .5897 Mdot
.43002 .53135 Mdot
.5087 .26842 Mdot
.57246 .65922 Mdot
.5336 .69391 Mdot
.64135 .23322 Mdot
.64032 .69328 Mdot
.70199 .68167 Mdot
.57675 .3029 Mdot
.69335 .20954 Mdot
.58733 .32563 Mdot
.43258 .26095 Mdot
.45485 .20432 Mdot
.51282 .48122 Mdot
.72662 .56029 Mdot
.718 .60593 Mdot
.54085 .66887 Mdot
.54323 .42856 Mdot
.54843 .66026 Mdot
.4185 .403 Mdot
.59877 .88232 Mdot
.5826 .40342 Mdot
.56261 .83731 Mdot
.54788 .54517 Mdot
.50157 .77012 Mdot
.52624 .41681 Mdot
.57109 .36192 Mdot
.59133 .34674 Mdot
.53175 .70366 Mdot
.43662 .649 Mdot
.52951 .96855 Mdot
.72278 .51711 Mdot
.49282 .40457 Mdot
.62382 .53498 Mdot
.56761 .27495 Mdot
.40751 .73975 Mdot
.50851 .79794 Mdot
.48112 .79304 Mdot
.60437 .86731 Mdot
.52342 .00273 Mdot
.49813 .10812 Mdot
.79015 .4505 Mdot
.43895 .12776 Mdot
.4265 .57898 Mdot
.68898 .35562 Mdot
.69402 .67882 Mdot
.5608 .58704 Mdot
.60637 .28551 Mdot
.71318 .23882 Mdot
.54615 .4519 Mdot
.44026 .62736 Mdot
.45908 .20301 Mdot
.58795 .79356 Mdot
.45274 .82038 Mdot
.56818 .05024 Mdot
.50556 .67787 Mdot
.61928 .55934 Mdot
.61633 .4281 Mdot
.4833 .26057 Mdot
.48897 .30104 Mdot
.47488 .22585 Mdot
.72909 .52286 Mdot
.50684 .33771 Mdot
.3772 .6209 Mdot
.54633 .17027 Mdot
.38666 .47969 Mdot
.49633 .9326 Mdot
.63608 .67835 Mdot
.5604 .26619 Mdot
.42648 .01845 Mdot
.51613 .28386 Mdot
.72663 .57546 Mdot
.64509 .81022 Mdot
.56487 .49467 Mdot
.53425 .08544 Mdot
.50724 .80177 Mdot
.50824 .18129 Mdot
.45667 .93885 Mdot
.43753 .13691 Mdot
.40705 .50048 Mdot
.58949 .51428 Mdot
.59789 .36388 Mdot
.57361 .73488 Mdot
.44377 .45215 Mdot
.60073 .65994 Mdot
.42506 .75283 Mdot
.52229 .5445 Mdot
.44684 .72382 Mdot
.61588 .59542 Mdot
.58348 .71943 Mdot
.45023 .326 Mdot
.55583 .70398 Mdot
.69604 .35861 Mdot
.53888 .27736 Mdot
.38843 .43318 Mdot
.44653 .77364 Mdot
.41186 .59211 Mdot
.49755 .66646 Mdot
.79713 .49816 Mdot
.48841 .68512 Mdot
.56415 .19566 Mdot
.59333 .17109 Mdot
.55237 .85202 Mdot
.44097 .75672 Mdot
.42262 .88226 Mdot
.70994 .65127 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`;o0000/oooool009Kooooo0_l0000<ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool2o`000;?ooooo002Eooooo`?o00003?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0;Wooooo002Eooooo`?o00003?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0;Wooooo002Rooooo`03oeEEEOmVIVKo000000Oooooo00?o0000oooo
ooooool0^Oooool009?ooooo0_l0000Gooooo`03o`000?oooooooooo0;Wooooo002Cooooo`;o0000
5oooool00ol0003oooooooooo`09ooooo`;o0000[_ooool00:cooooo0ol00009ooooo`;o0000[_oo
ool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:Gooooo0_l0
0005ooooo`03o`000?oooooooooo0;Wooooo002Uooooo`?o00001?ooool00ol0003oooooooooo`2i
ooooo`00Xoooool2o`000003ooooool0003o000000Cooooo00?o0000ooooooooool0^Oooool00:?o
oooo0_l000000ooooooo0000o`000004ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000
4oooool2o`000:Cooooo002/ooooo`?o00004oooool2o`000:Cooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002Iooooo`;o00004Oooool00ol0003oooooooooo`2iooooo`00VOooool2o`00017o
oooo1Ol0002gooooo`00[?ooool5o`000;Oooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`03o`000?oooooooooo01_ooooo0_l0002Looooo`00[?ooool3o`0001_ooooo0_l0002Loooo
o`00Uoooool2o`0001?ooooo00?o0000ooooooooool01_ooool2o`000;7ooooo002Gooooo`;o0000
4oooool00ol0003oooooooooo`06ooooo`;o0000/Oooool00:cooooo00?o0000ooooooooool02?oo
ool2o`000:oooooo002Eooooo`;o00005Oooool00ol0003oooooooooo`08ooooo`?o0000[_ooool0
09Gooooo0_l0000Eooooo`03o`000?oooooooooo00Wooooo0_l0002^ooooo`00Xoooool3o`0000Ko
oooo00?o0000ooooooooool0^Oooool00:?ooooo0ol00006ooooo`03o`000?oooooooooo0;Wooooo
002Uooooo`;o00001Oooool3o`000;Wooooo002Pooooo`;o00000oooool2o`000003ooooool0003o
000000;ooooo00?o0000ooooooooool0^Oooool009;ooooo0_l00009ooooo`;o000000?oooooo`00
0?l000001_ooool2o`0000;ooooo00?o0000ooooooooool09?ooool2o`0009?ooooo002Booooo`;o
00002Oooool3o`0000_ooooo0_l0000Vooooo`;o0000Toooool009kooooo0_l0000;ooooo`;o0000
^oooool00:cooooo00?o0000ooooooooool0^Oooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1Oooool00ol0003oooooooooo`2iooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`0Wooooo`;o0000T?ooool0087ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@4100
0_ooool2o`0000Wooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000
4Oooool2o`0001Cooooo0_l0002@ooooo`00ROooool01Ol0003ooooooooooooooooo000000;ooooo
0_l00005ooooo`;o00000oooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool04Oooool2o`000:Kooooo0029ooooo`05o`000?ooooooooooooooool00000
2Oooool2o`0000?ooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool0^Oooool008Wooooo00Go410@oooooooooooooooooa0@400>ooooo`03
ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Dooooo`;o
0000Xoooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`09ooooo`?o00000oooool00olb<S;o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04oooool3o`000:?o
oooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02Oooool7o`0000Cooooo1?l00006ooooo`03
o`000?oooooooooo01?ooooo0_l0002Tooooo`00S_ooool3o`0001_ooooo00?o0000ooooooooool0
^Oooool008kooooo0ol0000Aooooo`;o00000oooool2o`0000?ooooo00?o0000ooooooooool0^Ooo
ool008kooooo0_l0000Booooo`;o00000oooool2o`0000?ooooo00?o0000ooooooooool01Oooool2
o`000;;ooooo002Wooooo`;o00000oooool3o`0000Gooooo0_l0002booooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00UOooool2o`0001Gooooo00?o0000ooooooooool06Oooool2o`0009kooooo
002Eooooo`;o00005Oooool00ol0003oooooooooo`0Iooooo`;o0000W_ooool009Cooooo0_l00007
ooooo`;o00003Oooool00ol0003oooooooooo`2iooooo`00Toooool3o`0000Oooooo0_l0000=oooo
o`03o`000?oooooooooo0;Wooooo002Cooooo`;o00005oooool00ol0003oooooooooo`0<ooooo`;o
00003Oooool2o`0009cooooo002/ooooo`03o`000?oooooooooo00cooooo0ol0000<ooooo`;o0000
W?ooool00:cooooo0ol0000=ooooo`;o0000Z_ooool00:cooooo00?o0000ooooooooool07oooool2
o`0009Sooooo002/ooooo`04o`000?oooooo0000o`0000kooooo0_l0000>ooooo`;o0000V?ooool0
0:cooooo00Co0000ooooool0003o00003_ooool2o`000:Sooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002Fooooo`;o00005?ooool00ol0003oooooooooo`2iooooo`00U_ooool2o`0001Cooooo
00?o0000ooooooooool00oooool2o`000;Cooooo002/ooooo`03o`000?oooooooooo00?ooooo0_l0
000=ooooo`;o0000YOooool00:cooooo0ol0000Booooo`;o0000YOooool009gooooo0ol0000<oooo
o`03o`000?oooooooooo017ooooo0_l0002Vooooo`00R_ooool2o`00013ooooo1?l0000<ooooo`03
o`000?oooooooooo017ooooo0_l0002Vooooo`00R_ooool2o`00013ooooo0_l0000>ooooo`;o0000
1oooool2o`0000cooooo0_l0000Vooooo`;o0000Noooool00:cooooo0ol00006ooooo`;o00003?oo
ool2o`0002Kooooo0_l0001kooooo`00[?ooool3o`0002Oooooo0_l0002@ooooo`00[?ooool2o`00
02Sooooo0ol0002?ooooo`00[?ooool2o`0000_ooooo0_l0000Looooo`;o0000Soooool00:?ooooo
0_l00007ooooo`?o00002_ooool2o`000:gooooo002Sooooo`;o00001oooool00ol0003ooooooooo
o`0;ooooo`;o00002_ooool2o`0002Sooooo0_l0001fooooo`00[?ooool00ol0003oooooooooo`0:
ooooo`Co00002Oooool2o`0002Sooooo0_l0001fooooo`00X?ooool2o`0000[ooooo00?o0000oooo
ooooool02_ooool4o`0000[ooooo0_l0000Aooooo`;o0000S?ooool008gooooo0_l0000Aooooo`;o
00002_ooool00ol0003oooooooooo`0Hooooo`;o00004?ooool3o`0008cooooo002=ooooo`;o0000
2Oooool2o`0000oooooo0_l000000ooooooo0000ooooo`0[ooooo`?o00005_ooool2o`0007Cooooo
002Aooooo`?o000000Co<S8bonk^k_oooooooooo0_l000000ooooooo8B4Qob4Q8@05ooooo`05odA4
A?l0003o0000oc8b<_oMgMd00_ooool2o`000003ooooool0003ooooo04Cooooo0_l0001dooooo`00
TOooool2o`000003oooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0^Oooool008Wooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@4100
1_ooool2o`0000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2iooooo`00TOoo
ool01Ol0003ooooooooooooooooo000000Kooooo0_l00007ooooo`03ogMgMolb<S;ooooo00Cooooo
0ol0000?ooooo`;o0000Z?ooool0097ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0?ooooo`;o0000Z?ooool0097ooooo
00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0;_ooool2o`0008Wooooo002@ooooo`;o000000?oV9RHoooooonHV9P00_l0000;ooooo`04o`00
0?ooooooooooooooo`;o00001?ooool00ol0003oooooooooo`0^ooooo`;o0000ROooool0093ooooo
0_l000000olb<S;o0000oc8b<P02o`0000_ooooo1_l00004ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo00Oooooo0_l00008ooooo`;o0000Y_ooool009Wooooo0_l0000A
ooooo`04o`000?oooooo0000o`0000Kooooo0_l00008ooooo`;o0000=Oooool2o`0006oooooo002I
ooooo`;o00000oooool2o`0000cooooo00Co0000ooooool0003o00004_ooool2o`0003?ooooo0_l0
001_ooooo`00Q_ooool2o`0001Gooooo0ol0000<ooooo`?o00002Oooool2o`0000Sooooo0_l0002T
ooooo`00Q_ooool2o`0001Gooooo0_l0000;ooooo`?o00002oooool2o`0000Sooooo0_l0000:oooo
o`;o0000V?ooool00:[ooooo0ol0000Qooooo`;o0000V?ooool00:cooooo00?o0000ooooooooool0
0_ooool2o`0000Kooooo0_l0000Dooooo`;o0000Uoooool00:?ooooo0_l00007ooooo`;o00000ooo
ool2o`0000Kooooo0_l0000Dooooo`;o0000:Oooool2o`0006cooooo002Rooooo`?o00001oooool2
o`0004cooooo0_l0001/ooooo`00X_ooool2o`0000Sooooo00?o0000ooooooooool03?ooool2o`00
0:_ooooo002Rooooo`;o00002?ooool00ol0003oooooooooo`0<ooooo`;o0000:?ooool2o`00087o
oooo002Cooooo`;o00003Oooool2o`0000Cooooo0_l00002ooooo`Co0000=Oooool2o`00087ooooo
002Cooooo`;o00004oooool3o`000003ooooool0003ooooo00;o00005Oooool2o`000:7ooooo002Y
ooooo`;o000000?oooooo`000?ooool05oooool2o`000:7ooooo002/ooooo`03o`000?oooooooooo
03Kooooo0_l00021ooooo`00[?ooool00ol0003oooooooooo`0>ooooo`;o00009_ooool4o`0007oo
oooo002/ooooo`03o`000?oooooooooo00kooooo0_l0000Vooooo`Co0000Ooooool00:cooooo00?o
0000ooooooooool0=_ooool4o`0007oooooo002Vooooo`;o00001?ooool00ol0003oooooooooo`2i
ooooo`00Y_ooool2o`0000Cooooo0ol0000?ooooo`;o00002?ooool2o`0001gooooo0_l0001ooooo
o`00Voooool2o`0000oooooo00?o0000ooooooooool02?ooool2o`0000Gooooo0_l00008ooooo`;o
00007Oooool2o`0007oooooo002Kooooo`;o00003oooool00ol0003oooooooooo`08ooooo`;o0000
[oooool009Cooooo0_l0000Fooooo`03o`000?oooooooooo02Sooooo0_l0002?ooooo`00SOooool2
o`0000Gooooo0_l0000Fooooo`04o`000?oooooo0000o`0000Sooooo0_l0000@ooooo`;o00002ooo
ool2o`0008oooooo002=ooooo`;o00007Oooool01?l0003oooooo`000?l00008ooooo`;o00004?oo
ool2o`0009cooooo002/ooooo`03o`000?oooooooooo01gooooo0_l0002Jooooo`00R?ooool2o`00
02;ooooo00?o0000ooooooooool01?ooool2o`0000Cooooo0_l0000?ooooo`Co00007_ooool2o`00
07[ooooo0028ooooo`;o00008_ooool00ol0003oooooooooo`04ooooo`?o00000oooool2o`0000oo
oooo0_l0000Pooooo`;o0000N_ooool00:cooooo0ol00005ooooo`;o0000/_ooool00:cooooo00?o
0000ooooooooool0>oooool4o`0007[ooooo002/ooooo`03o`000?oooooooooo03_ooooo1?l0001j
ooooo`00[?ooool00ol0003oooooooooo`0;ooooo`;o00001oooool2o`0002Oooooo0_l0001joooo
o`00[?ooool00ol0003oooooooooo`0;ooooo`;o00001oooool2o`0000Oooooo0_l0002Jooooo`00
ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool07Oooool2o`0009[ooooo0029ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool03?ooool2o`000:_ooooo0021oooo
o`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo0_l0000?ooooo`;o00003?ooool2
o`0008cooooo0029ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07
ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Mooooo`;o00003?ooool4o`00017ooooo0_l0001g
ooooo`00ROooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo0ol0000]ooooo`;o00004Oooool2o`0007Oooooo0029
ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool00oooool2o`0002Oooooo0_l0000Booooo`;o0000Mooo
ool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02o`0000Wooooo00Co0000okZj^_ooooooV9RH
0_l00003ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool2o`0000?ooooo
0_l0000Rooooo`?o0000R_ooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02o`0000Wooooo
00CoV9RHoa0@4?l0003o8B4Q0_l00003ooooo`Co00001_ooool00ol0003oooooooooo`08ooooo`;o
00008oooool2o`0008[ooooo0023ooooo`;o00004_ooool2o`0001?ooooo00?o0000ooooooooool0
1?ooool2o`000;?ooooo0023ooooo`;o00004_ooool2o`0001?ooooo00?o0000ooooooooool01?oo
ool2o`000;?ooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`0Fooooo`;o00005Oooool2
o`0008[ooooo002Dooooo`;o00005_ooool3o`000003ooooool0003o000001?ooooo0ol00007oooo
o`;o00002oooool2o`0001;ooooo0_l0001fooooo`00TOooool2o`0001Kooooo0_l000000ooooooo
0000ooooo`02ooooo`;o00003Oooool2o`0000Gooooo0ol00006ooooo`;o00007oooool2o`0007Ko
oooo002Aooooo`Co00005?ooool2o`000003ooooool0003ooooo00[ooooo0_l00005ooooo`;o0000
1_ooool2o`0009oooooo002Cooooo`;o00005oooool00ol0003oooooooooo`09ooooo`;o0000[_oo
ool008kooooo0_l0000Looooo`03o`000?oooooooooo027ooooo0_l0000=ooooo`?o0000Q_ooool0
08kooooo0_l0000Looooo`03o`000?oooooooooo027ooooo0_l0000=ooooo`?o00004Oooool2o`00
07?ooooo002;ooooo`;o00002Oooool2o`0000;ooooo0_l0000@ooooo`03o`000?oooooooooo00Go
oooo0_l0000mooooo`;o0000Loooool008_ooooo0_l00009ooooo`;o00000_ooool2o`00013ooooo
00?o0000ooooooooool01Oooool2o`000;;ooooo002/ooooo`?o0000AOooool2o`0007;ooooo002/
ooooo`03o`000?oooooooooo00_ooooo0_l0000<ooooo`;o00002?ooool2o`00023ooooo0_l0001b
ooooo`00[?ooool00ol0003oooooooooo`0;ooooo`;o00002oooool3o`0000Sooooo0_l0002Doooo
o`00Qoooool2o`0000kooooo0_l0000Cooooo`03o`000?oooooooooo00_ooooo0_l0000;ooooo`;o
0000Woooool008Oooooo0_l0000>ooooo`;o00004oooool00ol0003oooooooooo`2iooooo`00P_oo
ool2o`0002Sooooo00?o0000ooooooooool0^Oooool007gooooo0_l00003ooooo`;o00003?ooool2
o`0001[ooooo00?o0000ooooooooool00oooool2o`0001kooooo0_l0002Dooooo`00OOooool2o`00
017ooooo0_l0000Jooooo`03o`000?oooooooooo00?ooooo0_l0000Nooooo`;o00007oooool2o`00
07?ooooo002/ooooo`03o`000?oooooooooo04Cooooo0_l0001cooooo`00VOooool2o`00017ooooo
0ol0000<ooooo`;o00001?ooool2o`0004Sooooo0_l0001Kooooo`00VOooool2o`00017ooooo00?o
0000ooooooooool03?ooool2o`0000Cooooo0_l00006ooooo`;o0000@?ooool2o`0005_ooooo002/
ooooo`03o`000?oooooooooo01;ooooo0_l00006ooooo`;o00002?ooool2o`00023ooooo0_l0001a
ooooo`002Oooool4o`000003oa0@4?oooooooooo01Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd03ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oM
gMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4
A4Co0000o`000?lb<S;ogMgM01Kooooo00?o0000ooooooooool06?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B43o`000003ooooool0003o000000?o00001?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00oooooo00Gok^k^o`000?l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool0
0ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd06?ooool4o`000003oa0@4?oo
oooooooo01;ooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007oooo
o`03ogMgMolb<S;ooooo01Gooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B402Ooooooo0000o`000?ooooooV9RHob4Q8Oo^k^koooooodA4A007ooooo`03
ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEE
ojVYZOooool01oooool00omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo0006o`00
00Gooooo00?o0000ooooooooool04?ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=
ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool01Oooool6o`0000;ooooo00Go410@
oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool04oooool2o`0000?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03
oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool03Oooool01Ol@413ooooooooooooooooo410@
013ooooo00?o0000ooooooooool03Oooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVY
oeEEEOooool02?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Cooooo000;oooo
o`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooo
oooo00Kooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000oooooo00?o
MgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`0Eooooo`03o`000?oooooooooo01?ooooo0_l00003ooooo`05o`00
0?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool06Oooool0
0ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05o`000?oooooooooo
ooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03ooo
ool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05
o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`05_ooool00ol0003oooooooooo`07ooooo`;o00003oooool01Ol0003ooooooooooooo
oooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo
00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0
003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<01[ooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool0
1Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003ooooooooo
o`0Aooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0Aooooo`05oa0@
4?ooooooooooooooool@41000_l00007ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo01Sooooo0ol00007ooooo`;o00003oooool01Ol@413ooooooooooooooooo410@
00oooooo00?o0000ooooooooool00_ooool3o`00017ooooo00Go410@o`000?l0003ooooooa0@400<
ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmg
MgOooooo00?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Dooooo`002oooool0
0ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooo
oooooooo<S8b00Cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00co
oooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00;o00001oooool3o`00
0004okZj^_ooooooV9RHoa0@40Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`04
ooooo`;o00004_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RH
oa0@4004ooooo`Go00003oooool01OmgMgOo0000o`000?nHV9SoMgMg00cooooo00?o0000oooooooo
ool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05?ooool000Wooooo00?oEEEEofIV
I_l000006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00004?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2Oooool2o`000005oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0001Oooooo00Co0000oooooooo
oooooooo0_l000000ooooooo0000o`00000<ooooo`;o00001?ooool00oo^k^ko<S8bo`000002o`00
00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Go00003oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo
1?l0000Iooooo`03oeEEEOmVIVKo000001Kooooo002/ooooo`04o`000?ooooooooooooooo`;o0000
00?oooooo`000?l000000_ooool2o`0000Sooooo0_l00007ooooo`;o0000W?ooool00:cooooo00?o
0000ooooooooool01?ooool2o`0000;ooooo0_l00008ooooo`;o0000<?ooool2o`0000;ooooo0_l0
001_ooooo`00[?ooool00ol0003oooooooooo`08ooooo`;o00002?ooool2o`0001kooooo1Ol0000=
ooooo`?o000000?oooooo`000?l00000I?ooool2o`0000;ooooo0_l00005ooooo`00[?ooool00ol0
003oooooooooo`08ooooo`;o00002?ooool2o`0001kooooo1Ol0000>ooooo`;o0000Ioooool01_o^
k^ko8B4QohN7Qonj^[[o0000omgMg@Gooooo002/ooooo`03o`000?oooooooooo01;ooooo0_l0001;
ooooo`;o0000C_ooool01?oMgMgo0000oa0@4?o<c<`6ooooo`001oooooooo`0004co00003?ooool0
1?o^k^ko8B4Qoa0@4?o^k^h6ooooo`001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`04o`000?oooooo
0000o`0000Gooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_oo
ool01?lQ8B7oMgMgogMgMolb<S86ooooo`001oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0>ooooo`;o00005_oo
ool00ol0003oooooooooo`0=ooooo`;o00006?ooool00ol0003oooooooooo`0;ooooo`;o00006Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02Ooo
ool2o`0000;ooooo0_l00005ooooo`00[?ooool00ol0003oooooooooo`0=ooooo`;o00009_ooool2
o`0008;ooooo002/ooooo`03o`000?oooooooooo01[ooooo0_l00009ooooo`;o00007_ooool2o`00
07;ooooo002/ooooo`03o`000?oooooooooo01[ooooo0_l00009ooooo`;o00007_ooool2o`0007;o
oooo002/ooooo`03o`000?oooooooooo01[ooooo0_l0000Zooooo`;o00005_ooool2o`0005Wooooo
002/ooooo`03o`000?oooooooooo01_ooooo0_l0000Yooooo`Co00005?ooool2o`0005Wooooo0022
ooooo`;o00001_ooool2o`00023ooooo0ol0000Kooooo`;o0000:Oooool4o`0006oooooo0022oooo
o`;o00001_ooool2o`00023ooooo00?o0000ooooooooool0Aoooool3o`0006oooooo002Dooooo`;o
00005_ooool00ol0003oooooooooo`18ooooo`;o0000Koooool008;ooooo0_l0000<ooooo`;o0000
0_ooool2o`0001Kooooo00?o0000ooooooooool0<oooool2o`0008Cooooo0022ooooo`;o00003?oo
ool2o`0001[ooooo00?o0000ooooooooool09Oooool2o`0000cooooo0_l0000Cooooo`;o0000Kooo
ool008Kooooo0_l0000?ooooo`;o00004oooool00ol0003oooooooooo`0Uooooo`;o00003Oooool2
o`0001;ooooo0_l0001_ooooo`00Q_ooool2o`0000oooooo0_l0000Cooooo`03o`000?oooooooooo
03Cooooo0ol00022ooooo`00P_ooool2o`0002Sooooo00?o0000ooooooooool01?ooool2o`0000Ko
oooo0_l0000Wooooo`;o0000P_ooool008;ooooo0_l0000Xooooo`03o`000?oooooooooo00Cooooo
0_l00006ooooo`;o0000Zoooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`0C
ooooo`;o0000B_ooool2o`0005Sooooo002/ooooo`03o`000?oooooooooo01?ooooo0_l00005oooo
o`;o0000@oooool2o`0005Sooooo002/ooooo`03o`000?oooooooooo01[ooooo0_l00008ooooo`;o
00008Oooool2o`00073ooooo002@ooooo`;o00006_ooool00ol0003oooooooooo`03ooooo`;o0000
3Oooool2o`00013ooooo0_l0000Qooooo`;o0000L?ooool0093ooooo0_l0000Jooooo`03o`000?oo
oooooooo00?ooooo0_l0000=ooooo`;o0000YOooool009Sooooo0_l0000Booooo`03o`000?oooooo
oooo04Sooooo0_l0001_ooooo`00R_ooool2o`0000cooooo0_l0000Booooo`03o`000?oooooooooo
01[ooooo0_l0000/ooooo`;o0000Koooool008Oooooo0_l000000ooooooo0000o`000002ooooo`;o
00007?ooool3o`0001Wooooo0ol0000[ooooo`;o0000L?ooool008Oooooo0_l00005ooooo`;o0000
0oooool2o`0001Oooooo00?o0000ooooooooool04_ooool2o`0000Gooooo0_l0000/ooooo`;o0000
L?ooool008?ooooo0_l0000>ooooo`;o00005oooool00ol0003oooooooooo`0Booooo`;o00007ooo
ool2o`0008Cooooo0023ooooo`;o00009oooool00ol0003oooooooooo`0cooooo`;o0000Q?ooool0
08?ooooo0_l0000Wooooo`03o`000?oooooooooo00;ooooo0_l0000=ooooo`;o0000Y_ooool008?o
oooo0_l00009ooooo`;o00007?ooool00ol0003oooooooooo`02ooooo`;o00003Oooool2o`0001oo
oooo0_l0000Aooooo`;o0000L_ooool008?ooooo0_l00009ooooo`;o00007?ooool00ol0003ooooo
ooooo`0Sooooo`;o00003Oooool2o`00017ooooo0_l0001booooo`00Uoooool2o`0001?ooooo00?o
0000ooooooooool08oooool2o`0000gooooo0_l00025ooooo`00Uoooool2o`0001?ooooo0ol0000`
ooooo`;o00004oooool3o`00077ooooo002Booooo`;o00006?ooool00ol0003oooooooooo`0`oooo
o`;o00004oooool3o`00077ooooo002Booooo`;o00006?ooool00ol0003oooooooooo`0Hooooo`;o
00002?ooool2o`00027ooooo0_l0001booooo`00[?ooool00ol0003oooooooooo`0Hooooo`;o0000
2?ooool2o`00027ooooo0_l0001booooo`00[?ooool00ol0003oooooooooo`14ooooo`;o0000Looo
ool008oooooo0_l0000Kooooo`03o`000?oooooooooo02?ooooo0_l0000Mooooo`Co0000Loooool0
08Wooooo00Kok^k^oc8b<_l0003o<S8bonk^k_ooool2o`0000;ooooo0_lQ8B44ooooo`Go00001?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool08oooool2o`0001gooooo
0ol0000Gooooo`;o0000Foooool008?ooooo0_l00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00;o
00000_ooool00ol0003oooooooooo`08ooooo`;o0000D_ooool2o`0005_ooooo0023ooooo`;o0000
1?ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool01?l0003o
ooooo`000?l00002ooooo`?o00002?ooool2o`0000cooooo0_l0002Qooooo`00Ooooool2o`0000So
oooo00Go0000ooooooooooooooooo`00000:ooooo`;o000000Coooooo`000?l0003ok^k^1oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01Kooooo0_l0002Qooooo`00Ooooool2o`00
00Sooooo00Go0000ooooooooooooooooo`00000:ooooo`;o000000Coooooo`000?l0003oIVIV1?oo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool02?ooool2o`0003[ooooo
0_l0001cooooo`00ROooool01Ol@413ooooooooooooooooo410@00Gooooo0_l00008ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`;o0000
0oooool2o`0003Sooooo1?l0001cooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_l00004ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`05ooooo`?o
00001Oooool2o`0001cooooo0_l0000Oooooo`;o0000MOooool008Wooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Cooooo0ol00005oooo
o`;o00007?ooool2o`0001gooooo0_l0001gooooo`00R?ooool2o`0002;ooooo00?o0000oooooooo
ool0@?ooool2o`0007Oooooo0028ooooo`;o00008_ooool00ol0003oooooooooo`0Qooooo`;o0000
U_ooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo027ooooo0_l0002Fooooo`00Q?ooool2
o`00017ooooo0_l0000Cooooo`?o00001_ooool2o`0003[ooooo0_l0001eooooo`00Ooooool2o`00
00?ooooo0_l0000Vooooo`03o`000?oooooooooo00Kooooo0_l00003ooooo`;o0000<_ooool5o`00
07Gooooo001oooooo`;o0000:oooool00ol0003oooooooooo`0;ooooo`;o0000<_ooool3o`0007Oo
oooo002/ooooo`03o`000?oooooooooo00_ooooo1?l00005ooooo`;o00002?ooool2o`0001oooooo
0ol0001gooooo`00[?ooool00ol0003oooooooooo`0;ooooo`Co00001Oooool2o`0000Sooooo0_l0
000Oooooo`?o0000Moooool00:_ooooo0_l0000=ooooo`;o0000<Oooool2o`0001Wooooo0_l0001N
ooooo`00Zoooool2o`0000cooooo0_l0000Oooooo`;o00004Oooool2o`0001Wooooo0_l0001Noooo
o`00[?ooool00ol0003oooooooooo`0:ooooo`;o00007oooool2o`0001?ooooo0_l0001gooooo`00
[?ooool3o`0000?ooooo0_l0000Vooooo`;o00004oooool2o`0007Oooooo002/ooooo`?o00000ooo
ool2o`0000Cooooo0_l0000Aooooo`;o00002oooool4o`00013ooooo0_l0001jooooo`00[?ooool3
o`0000Wooooo0_l0000Aooooo`;o00002oooool2o`0001;ooooo1Ol0001gooooo`00QOooool2o`00
01?ooooo0_l0000<ooooo`;o00000_ooool00ol0003oooooooooo`0Kooooo`;o00003_ooool2o`00
01;ooooo0ol0001gooooo`00QOooool2o`0000Oooooo0_l0000:ooooo`;o00003?ooool2o`0000;o
oooo00?o0000ooooooooool06oooool2o`0000kooooo0_l0000Booooo`;o0000N?ooool008kooooo
0_l0000Looooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00Sooooo0_l0
000Qooooo`;o00004Oooool2o`0007Wooooo002/ooooo`03o`000?oooooooooo00Sooooo0_l0000Q
ooooo`;o00004Oooool2o`0007Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000oooooooo
ool01oooool2o`0000Kooooo0_l0002Xooooo`00[?ooool00ol0003oooooooooo`07ooooo`;o0000
1_ooool2o`000:Sooooo002/ooooo`03o`000?oooooooooo01Wooooo0_l0000;ooooo`Co0000Sooo
ool008oooooo0_l0000Kooooo`03o`000?oooooooooo00oooooo0_l00008ooooo`?o00002_ooool4
o`0008oooooo002?ooooo`;o00001oooool2o`0000oooooo0_l000000ooooooo0000ooooo`0@oooo
o`;o00002Oooool2o`0000_ooooo0_l0002@ooooo`00V?ooool2o`0000oooooo0_l000000ooooooo
0000ooooo`0Iooooo`;o0000Woooool008Kooooo0_l0000Tooooo`03o`000?oooooooooo01Sooooo
0_l0000Qooooo`;o0000O?ooool008Kooooo0_l0000<ooooo`;o00001?ooool2o`00013ooooo0ol0
000kooooo`;o0000O?ooool009Cooooo0_l00004ooooo`;o00004?ooool00ol0003oooooooooo`2i
ooooo`00Zoooool2o`000;_ooooo002[ooooo`;o00003Oooool2o`0002gooooo0_l0001mooooo`00
[?ooool00ol0003oooooooooo`0;ooooo`;o00002?ooool2o`0001oooooo0_l00002ooooo`;o0000
OOooool008gooooo0_l0000Mooooo`03o`000?oooooooooo01Gooooo0_l0000;ooooo`;o00004_oo
ool2o`00087ooooo002=ooooo`;o00000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Rooooo`;o0000
5Oooool2o`0007kooooo002Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0iooooo`;o0000O_ooool0097ooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
^Oooool0097ooooo00?o0000ooooool000000_l00009ooooo`;o00001?ooool00omgMgOo<S8boooo
o`04ooooo`?o0000=Oooool2o`0008;ooooo002Aooooo`03o`000?oooooo000000;o00002Oooool2
o`000006ooooool0003o8B4Qo`000?lb<S;oc<c<1Oooool00ol0003oooooooooo`08ooooo`;o0000
:oooool2o`0008;ooooo002Aooooo`05oa0@4?ooooooooooooooool@41000_ooool2o`0000Sooooo
00?o0000ooooooooool01oooool01?l0003oooooo`000?l00007ooooo`;o0000[oooool0097ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`;o00002?ooool00ol0003oooooooooo`07ooooo`04
o`000?oooooo0000o`0000Kooooo0_l0000[ooooo`;o0000Poooool0097ooooo00?ok^k^oc8b<_l0
00000_l0000<ooooo`Co00001_ooool00ol0003oooooooooo`07ooooo`;o00005oooool2o`0001;o
oooo0_l00023ooooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool01Oooool2o`0001Wooooo
0_l0000Booooo`;o0000Poooool009Cooooo0_l0000Fooooo`;o00001_ooool2o`0002[ooooo0_l0
00000ooooooo0000o`000023ooooo`00V_ooool2o`0000oooooo0ol0000Aooooo`;o00007oooool2
o`0008Kooooo002Jooooo`;o00003oooool4o`00013ooooo0_l0000=ooooo`;o00004Oooool2o`00
08Gooooo002Looooo`;o00003_ooool00ol0003oooooooooo`0Looooo`;o000000?oooooo`000?l0
00004Oooool2o`0008Gooooo002Looooo`;o00003_ooool00ol0003oooooooooo`0Looooo`;o0000
4Oooool2o`0008Sooooo002Looooo`;o00002_ooool2o`0000;ooooo00?o0000ooooooooool0;ooo
ool2o`0008Sooooo002Xooooo`;o00000_ooool00ol0003oooooooooo`2iooooo`00Woooool2o`00
00_ooooo00?o0000ooooooooool0^Oooool009oooooo0_l000001?oooooo0000o`000?ooool2o`00
00Gooooo00?o0000ooooooooool06_ooool2o`0009gooooo002Rooooo`;o000000?oooooo`000?l0
00001Oooool01?l0003oooooo`000?l00009ooooo`;o00003_ooool2o`0009gooooo002;ooooo`;o
00007oooool4o`0000Wooooo0_l0002]ooooo`00Roooool2o`0001oooooo00Co0000ooooool0003o
00005oooool2o`0009oooooo002/ooooo`04o`000?oooooo0000o`0001Oooooo0_l0002Oooooo`00
[?ooool00ol0003oooooooooo`0/ooooo`;o0000Roooool00:cooooo00?o0000ooooooooool0;?oo
ool2o`0008_ooooo002/ooooo`03o`000?oooooooooo02_ooooo0_l0002<ooooo`00V_ooool2o`00
013ooooo00?o0000ooooooooool02?ooool2o`00027ooooo0_l0002<ooooo`00V_ooool4o`0000ko
oooo00?o0000ooooooooool02?ooool2o`0000gooooo0_l0002Pooooo`00W?ooool2o`0000gooooo
1?l0000Gooooo`;o00004Oooool2o`0008gooooo002[ooooo`;o0000;?ooool2o`0008gooooo002/
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Eooooo`;o
00005Oooool00ol0003oooooooooo`04ooooo`;o00002oooool2o`000:Kooooo002Eooooo`;o0000
5Oooool00ol0003oooooooooo`04ooooo`;o00002oooool2o`000:Kooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00oooooo0_l0002Xooooo`00S_ooool2o`00
01cooooo00?o0000ooooooooool03oooool2o`000:Sooooo002>ooooo`;o00007?ooool3o`000003
ooooool0003o000000_ooooo0_l0002Yooooo`00V?ooool2o`0001;ooooo00Co0000oooooooooooo
oooo0_l0000;ooooo`;o0000ZOooool008oooooo0_l00007ooooo`;o00004_ooool01?l0003ooooo
ooooooooool2o`000;Kooooo002?ooooo`;o00006oooool00ol0003oooooooooo`2iooooo`00T?oo
ool2o`0001[ooooo00?o0000ooooooooool07oooool2o`0009Sooooo0029ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00_ooool2o`000003oooooolQ8B7o8B4Q00Kooooo0_l00005ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0=ooooo`;o00004?ooool2o`0009Sooooo
0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo0_l00008ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool03Oooool2o`00013ooooo0_l0002Hooooo`00ROoo
ool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05o`000?ooooooooooooooool00000
3_ooool00olQ8B7oooooooooo`06ooooo`04ogMgMolb<S;oooooooooo`;o000000Coooooo`000?l0
003o0000^Oooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`04oeEEEOo<c<co0000
o`0000;ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`;o000000?oooooo`000?ooool0^_oo
ool008Wooooo00Go410@oooooooooooooooooa0@4004ooooo`;o00002?ooool01?nYZJWoMgMgo`00
0?l00002ooooo`03o`000?oooooooooo00Cooooo0_l000000ooooooo0000ooooo`0Nooooo`;o0000
V_ooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`;o00001Oooool01Ol@413ooooo
oooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Mooooo`;o
0000V_ooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o
0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002ioooo
o`00[?ooool00ol0003oooooooooo`02ooooo`;o0000]Oooool00:cooooo00?o0000ooooooooool0
0_ooool2o`000;Gooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`04o`000?ooooooooooooooo`;o00003oooool2o`000:Gooooo002/oooo
o`?o000000?oooooo`000?l000003oooool2o`000:Gooooo002Hooooo`Co00004?ooool3o`000;Wo
oooo002Hooooo`Co00004?ooool3o`0001?ooooo0_l0002Tooooo`00[?ooool00ol0003ooooooooo
o`0Cooooo`;o0000Y?ooool00:cooooo00?o0000ooooooooool0^Oooool009_ooooo0_l0000=oooo
o`?o0000^oooool009_ooooo0_l000000ooooooo0000o`000006ooooo`;o00000_ooool3o`000;_o
oooo002Mooooo`?o00001_ooool2o`0000Cooooo00?o0000ooooooooool0^Oooool009gooooo0_l0
0007ooooo`;o00001?ooool00ol0003oooooooooo`2iooooo`00WOooool2o`0000Oooooo0ol00003
ooooo`03o`000?oooooooooo00gooooo0ol0002Yooooo`00Yoooool2o`0000?ooooo00?o0000oooo
ooooool03Oooool3o`000:Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool01Oooool3o`000;7ooooo002/ooooo`03o`000?oooooooooo00Gooooo0ol0
002aooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Gooooo`;o
00004oooool00ol0003oooooooooo`2iooooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool0
^Oooool009Sooooo0_l0000Booooo`03o`000?oooooooooo0;Wooooo002Hooooo`;o00004_ooool0
1?l0003oooooo`000?l0002hooooo`00X_ooool4o`000003oa0@4?oooooooooo00?ooooo00Co0000
ooooool0003o0000^?ooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2i
ooooo`00Y?ooool00ol0003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000oooooooo
ool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0`Ooo
ool00:Cooooo00?o0000ooooooooool0`Oooool00:;ooooo00?oEEEEofIVI_l00000`oooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:[ooooo00Co410@o`00
0?l0003o0000^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooooooo
ool0^_ooool00:_ooooo00Ko0000ogMgMol0003o0000oeEEEOo^k^jgooooo`00Zoooool01_l0003o
EEEEonk^k_ooooooMgMgoeEEEKOooooo002[ooooo`03o`000?o^k^kooooo00;ooooo00?o0000oooo
ooooool0]Oooool00:_ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`2eooooo`00
Zoooool01_l0003oEEEEonk^k_ooooooMgMgofIVI[Oooooo002Zooooo`03oa0@4?l0003oMgMg00;o
000000?oIVIVonk^k_ooool0]_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.43224 .84887 Mdot
.42511 .15497 Mdot
.50183 .43528 Mdot
.55085 .47559 Mdot
.43441 .24001 Mdot
.61633 .63737 Mdot
.46844 .67098 Mdot
.69756 .32007 Mdot
.56916 .1235 Mdot
.44605 .2543 Mdot
.55003 .36302 Mdot
.72175 .4108 Mdot
.62571 .29038 Mdot
.51458 .26656 Mdot
.72237 .45375 Mdot
.50126 .73701 Mdot
.4057 .3298 Mdot
.63227 .3047 Mdot
.5055 .77254 Mdot
.60942 .78463 Mdot
.63867 .33214 Mdot
.52417 .13367 Mdot
.56486 .19618 Mdot
.64418 .3379 Mdot
.7267 .57043 Mdot
.60057 .51312 Mdot
.56897 .47791 Mdot
.51363 .75268 Mdot
.57837 .83536 Mdot
.44222 .11829 Mdot
.65518 .39883 Mdot
.56387 .11344 Mdot
.67315 .27702 Mdot
.50762 .17129 Mdot
.58929 .31336 Mdot
.63773 .70258 Mdot
.37369 .57922 Mdot
.55039 .65427 Mdot
.52901 .89891 Mdot
.7286 .43016 Mdot
.73231 .56005 Mdot
.55471 .24334 Mdot
.62814 .48016 Mdot
.41324 .79446 Mdot
.48869 .89341 Mdot
.54559 .28041 Mdot
.50569 .25527 Mdot
.47928 .02751 Mdot
.53616 .7665 Mdot
.57602 .83258 Mdot
.47495 .02867 Mdot
.47288 .95478 Mdot
.59557 .06834 Mdot
.61628 .40709 Mdot
.62151 .41569 Mdot
.62667 .20083 Mdot
.70257 .33676 Mdot
.40167 .36335 Mdot
.40144 .16828 Mdot
.5104 .86693 Mdot
.56187 .32133 Mdot
.62049 .85999 Mdot
.51558 .91397 Mdot
.43058 .63264 Mdot
.67196 .28789 Mdot
.59627 .15409 Mdot
.43729 .2821 Mdot
.51542 .69865 Mdot
.55141 .65678 Mdot
.65692 .38265 Mdot
.41626 .25084 Mdot
.46158 .32275 Mdot
.45771 .23512 Mdot
.41415 .48135 Mdot
.51579 .91364 Mdot
.46317 .63665 Mdot
.59619 .06909 Mdot
.58737 .42406 Mdot
.50396 .9353 Mdot
.54771 .72921 Mdot
.6699 .5386 Mdot
.4354 .13328 Mdot
.54331 .42075 Mdot
.56296 .25714 Mdot
.66646 .25686 Mdot
.4955 .75319 Mdot
.44495 .21175 Mdot
.49666 .19841 Mdot
.39592 .53214 Mdot
.50929 .71341 Mdot
.72437 .58155 Mdot
.36289 .33274 Mdot
.43779 .31916 Mdot
.51661 .22636 Mdot
.42498 .40616 Mdot
.35707 .53551 Mdot
.50755 .25286 Mdot
.49064 .03689 Mdot
.61245 .08652 Mdot
.39508 .52241 Mdot
.40402 .74179 Mdot
.41607 .73627 Mdot
.71992 .41441 Mdot
.39308 .67125 Mdot
.67201 .47594 Mdot
.5259 .19861 Mdot
.44213 .1695 Mdot
.46976 .80601 Mdot
.43933 .31261 Mdot
.65841 .39312 Mdot
.47923 .21809 Mdot
.54969 .45022 Mdot
.55869 .10807 Mdot
.63888 .71414 Mdot
.76356 .31808 Mdot
.42892 .54499 Mdot
.57753 .37185 Mdot
.61538 .17447 Mdot
.59226 .1448 Mdot
.37552 .59789 Mdot
.62518 .29139 Mdot
.66331 .79141 Mdot
.61712 .29145 Mdot
.57419 .84369 Mdot
.65875 .3917 Mdot
.55091 .53062 Mdot
.623 .7489 Mdot
.37562 .78089 Mdot
.39166 .35329 Mdot
.48141 .28821 Mdot
.55945 .18406 Mdot
.38663 .56465 Mdot
.72895 .45922 Mdot
.61494 .65016 Mdot
.62943 .53612 Mdot
.53608 .89741 Mdot
.38607 .737 Mdot
.59733 .80078 Mdot
.45275 .2436 Mdot
.69138 .32253 Mdot
.72479 .46098 Mdot
.52737 .97315 Mdot
.51339 .3074 Mdot
.53628 .7043 Mdot
.4057 .32873 Mdot
.62579 .74962 Mdot
.64803 .22456 Mdot
.79638 .41757 Mdot
.4423 .76355 Mdot
.51557 .22885 Mdot
.69012 .74496 Mdot
.43037 .79203 Mdot
.57139 .55781 Mdot
.64671 .34225 Mdot
.44803 .35831 Mdot
.57499 .74692 Mdot
.40531 .83634 Mdot
.50211 .93315 Mdot
.61672 .17945 Mdot
.37339 .56255 Mdot
.40032 .81572 Mdot
.58837 .62349 Mdot
.5071 .9332 Mdot
.73976 .53374 Mdot
.65428 .64476 Mdot
.62556 .48421 Mdot
.40988 .76806 Mdot
.64204 .21594 Mdot
.67466 .50776 Mdot
.55637 .63757 Mdot
.41102 .86223 Mdot
.59877 .78923 Mdot
.46308 .26412 Mdot
.56508 .58826 Mdot
.45084 .2039 Mdot
.42588 .71152 Mdot
.67723 .29178 Mdot
.35986 .61408 Mdot
.57962 .73567 Mdot
.43149 .56688 Mdot
.56182 .85722 Mdot
.44561 .94084 Mdot
.73382 .47347 Mdot
.43144 .68898 Mdot
.73118 .57505 Mdot
.53151 .43328 Mdot
.56051 .11522 Mdot
.37724 .78926 Mdot
.55212 .09569 Mdot
.73906 .5215 Mdot
.63057 .50828 Mdot
.68627 .74385 Mdot
.62679 .74835 Mdot
.46502 .72981 Mdot
.63355 .83632 Mdot
.68226 .288 Mdot
.72662 .62467 Mdot
.72447 .43316 Mdot
.50042 .20035 Mdot
.39718 .09408 Mdot
.49496 .14454 Mdot
.46627 .69727 Mdot
.45939 .68938 Mdot
.47506 .31171 Mdot
.42896 .26348 Mdot
.42724 .0085 Mdot
.393 .6548 Mdot
.52331 .62394 Mdot
.60422 .67787 Mdot
.54858 .43124 Mdot
.53866 .51664 Mdot
.55524 .37804 Mdot
.58436 .21353 Mdot
.58427 .40605 Mdot
.67454 .51134 Mdot
.44896 .74033 Mdot
.40314 .73141 Mdot
.57591 .37458 Mdot
.73875 .54202 Mdot
.53351 .43702 Mdot
.52405 .84173 Mdot
.72314 .40054 Mdot
.57357 .35729 Mdot
.41839 .11024 Mdot
.67424 .48473 Mdot
.66575 .57928 Mdot
.4746 .7621 Mdot
.40594 .45331 Mdot
.40276 .24449 Mdot
.45336 .27694 Mdot
.7231 .45698 Mdot
.65723 .80575 Mdot
.53257 .65354 Mdot
.51067 .43761 Mdot
.47317 .84576 Mdot
.56946 .46405 Mdot
.67305 .77023 Mdot
.55933 .6202 Mdot
.38601 .57999 Mdot
.61274 .27571 Mdot
.39017 .62721 Mdot
.61801 .86217 Mdot
.62875 .57373 Mdot
.6741 .56442 Mdot
.41538 .25524 Mdot
.56588 .11295 Mdot
.42214 .46171 Mdot
.41049 .85107 Mdot
.40533 .65232 Mdot
.41157 .27553 Mdot
.51431 .91705 Mdot
.72758 .61394 Mdot
.43004 .5613 Mdot
.46284 .72531 Mdot
.3912 .75752 Mdot
.59794 .53365 Mdot
.56684 .57335 Mdot
.62904 .44512 Mdot
.45406 .61465 Mdot
.6962 .32573 Mdot
.44007 .05615 Mdot
.50723 .81658 Mdot
.56931 .46175 Mdot
.66298 .60228 Mdot
.445 .33641 Mdot
.43555 .80369 Mdot
.4591 .88797 Mdot
.52068 .28862 Mdot
.62057 .59762 Mdot
.6211 .74248 Mdot
.58861 .60425 Mdot
.63381 .71988 Mdot
.62595 .43607 Mdot
.44158 .26415 Mdot
.53088 .76988 Mdot
.41152 .86077 Mdot
.42484 .65631 Mdot
.4158 .6655 Mdot
.49521 .03691 Mdot
.54989 .35576 Mdot
.5869 .72273 Mdot
.54398 .88376 Mdot
.49012 .29098 Mdot
.41908 .59733 Mdot
.37341 .55677 Mdot
.71499 .39026 Mdot
.46368 .80365 Mdot
.4344 .50027 Mdot
.40755 .44617 Mdot
.6568 .66577 Mdot
.53086 .25539 Mdot
.66951 .51001 Mdot
.37675 .78461 Mdot
.39459 .20601 Mdot
.71667 .41494 Mdot
.40142 .17518 Mdot
.50836 .59283 Mdot
.37883 .31848 Mdot
.64721 .80943 Mdot
.66817 .6212 Mdot
.72038 .43977 Mdot
.80535 .46648 Mdot
.54871 .73499 Mdot
.63421 .51081 Mdot
.38527 .52735 Mdot
.56617 .11456 Mdot
.73052 .55153 Mdot
.51914 .28176 Mdot
.49253 .03619 Mdot
.59687 .55592 Mdot
.50424 .6491 Mdot
.58154 .21169 Mdot
.41517 .2663 Mdot
.6177 .27821 Mdot
.69805 .7247 Mdot
.42834 .47122 Mdot
.50224 .87315 Mdot
.53463 .21137 Mdot
.68279 .31197 Mdot
.44858 .32133 Mdot
.73394 .48419 Mdot
.69229 .71542 Mdot
.54225 .60789 Mdot
.6152 .65385 Mdot
.5665 .26214 Mdot
.48361 .9468 Mdot
.40593 .43846 Mdot
.48554 .69744 Mdot
.49185 .65494 Mdot
.42726 .21014 Mdot
.71479 .36935 Mdot
.39449 .77441 Mdot
.42309 .42741 Mdot
.55789 .17567 Mdot
.4902 .2953 Mdot
.47785 .3123 Mdot
.40804 .21705 Mdot
.62154 .61678 Mdot
.62581 .48627 Mdot
.58784 .62464 Mdot
.42056 .30459 Mdot
.55799 .02736 Mdot
.59477 .56053 Mdot
.41706 .19008 Mdot
.42862 .61564 Mdot
.65435 .24542 Mdot
.56668 .45501 Mdot
.60421 .78717 Mdot
.47752 .09291 Mdot
.47771 .25073 Mdot
.5536 .31101 Mdot
.53266 .96788 Mdot
.7206 .40073 Mdot
.37578 .35049 Mdot
.63238 .71856 Mdot
.56371 .7011 Mdot
.4878 .14092 Mdot
.60731 .7745 Mdot
.45405 .83594 Mdot
.72011 .40041 Mdot
.67309 .57548 Mdot
.72785 .45528 Mdot
.73442 .49409 Mdot
.735 .56591 Mdot
.50546 .36421 Mdot
.49702 .83005 Mdot
.72471 .46606 Mdot
.69843 .32835 Mdot
.51177 .38816 Mdot
.66789 .4685 Mdot
.59199 .56731 Mdot
.60459 .68104 Mdot
.41175 .78062 Mdot
.51145 .05706 Mdot
.38663 .59008 Mdot
.37238 .44188 Mdot
.42705 .89562 Mdot
.55571 .18282 Mdot
.37068 .46749 Mdot
.55141 .17346 Mdot
.72898 .53613 Mdot
.77884 .35457 Mdot
.37329 .46087 Mdot
.56867 .76357 Mdot
.44201 .3929 Mdot
.71061 .66374 Mdot
.39813 .59152 Mdot
.49754 .6388 Mdot
.73577 .4814 Mdot
.65872 .3897 Mdot
.49157 .68959 Mdot
.41785 .40242 Mdot
.59615 .45922 Mdot
.57116 .49391 Mdot
.49464 .03384 Mdot
.67763 .49328 Mdot
.63633 .82979 Mdot
.73466 .48167 Mdot
.45965 .14874 Mdot
.53716 .00954 Mdot
.47786 .13936 Mdot
.43199 .73691 Mdot
.41481 .65196 Mdot
.46936 .34176 Mdot
.71073 .36029 Mdot
.72038 .40593 Mdot
.5684 .46887 Mdot
.47549 .25337 Mdot
.57253 .46026 Mdot
.46605 .76767 Mdot
.7117 .68232 Mdot
.50396 .20342 Mdot
.65753 .63731 Mdot
.52595 .34517 Mdot
.56962 .57012 Mdot
.45846 .29953 Mdot
.4763 .17965 Mdot
.49005 .14959 Mdot
.57321 .50366 Mdot
.51634 .65109 Mdot
.67693 .76855 Mdot
.68962 .31711 Mdot
.45031 .44282 Mdot
.59782 .33498 Mdot
.44265 .1686 Mdot
.54466 .80238 Mdot
.58769 .59794 Mdot
.56301 .60541 Mdot
.71129 .66731 Mdot
.35836 .39455 Mdot
.38444 .4838 Mdot
.73035 .2505 Mdot
.40154 .73793 Mdot
.50274 .69505 Mdot
.59123 .15562 Mdot
.72555 .47882 Mdot
.55562 .38704 Mdot
.48073 .09475 Mdot
.56871 .03882 Mdot
.48704 .25904 Mdot
.5105 .63173 Mdot
.41361 .63378 Mdot
.66537 .59356 Mdot
.56472 .68798 Mdot
.37837 .18985 Mdot
.53671 .47787 Mdot
.60301 .35934 Mdot
.54757 .2281 Mdot
.42093 .51554 Mdot
.42854 .48205 Mdot
.41518 .55984 Mdot
.69824 .32286 Mdot
.43329 .39564 Mdot
.52277 .91309 Mdot
.40111 .25841 Mdot
.48968 .89012 Mdot
.62949 .73291 Mdot
.66742 .47835 Mdot
.43479 .19141 Mdot
.38037 .81601 Mdot
.42145 .36586 Mdot
.71681 .37546 Mdot
.72918 .61022 Mdot
.52274 .29467 Mdot
.37776 .32829 Mdot
.58795 .60177 Mdot
.39869 .42342 Mdot
.60776 .78117 Mdot
.40384 .74216 Mdot
.4898 .79659 Mdot
.5552 .31428 Mdot
.50344 .16388 Mdot
.62959 .85136 Mdot
.62756 .53488 Mdot
.47131 .64673 Mdot
.62471 .45994 Mdot
.54516 .73695 Mdot
.50009 .3445 Mdot
.53417 .63887 Mdot
.61405 .39542 Mdot
.63125 .51943 Mdot
.44237 .64579 Mdot
.59742 .50398 Mdot
.59948 .15861 Mdot
.42603 .26981 Mdot
.47914 .89242 Mdot
.54919 .67146 Mdot
.5088 .75871 Mdot
.52428 .46683 Mdot
.7564 .29816 Mdot
.52531 .49266 Mdot
.41613 .18382 Mdot
.42801 .08788 Mdot
.65317 .65202 Mdot
.54436 .67945 Mdot
.58364 .82379 Mdot
.73044 .45127 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Dooooo`;o00003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo0_l0
002^ooooo`00U?ooool2o`0000kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09
ooooo`;o0000[_ooool00:;ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?oo
ool3o`000;Wooooo002Sooooo`Co00001Oooool00ol0003oooooooooo`0@ooooo`;o0000Yoooool0
0:?ooooo1?l00005ooooo`03o`000?oooooooooo013ooooo0_l0002Wooooo`00Z_ooool3o`000;_o
oooo002Xooooo`Go0000^oooool00:Sooooo1Ol0000Eooooo`;o0000Y?ooool00:cooooo00?o0000
ooooooooool04oooool2o`000:Cooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool009Sooooo0_l0000Booooo`03o`000?oo
oooooooo0;Wooooo002Hooooo`;o00004_ooool00ol0003oooooooooo`02o`000;Oooooo002/oooo
o`03o`000?oooooooooo00;o0000]oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool07?ooool2o`0009_ooooo002/ooooo`03o`000?oooooooooo01cooooo0_l0
002Kooooo`00[?ooool00ol0003oooooooooo`0Looooo`;o0000Voooool00:cooooo0ol0002ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?oo
ool00ol0003oooooooooo`0Rooooo`;o0000UOooool009Cooooo0_l0000Fooooo`03o`000?oooooo
oooo02;ooooo0_l0002Eooooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool0^Oooool008[o
oooo0_l0000Hooooo`?o00001Oooool00ol0003oooooooooo`2iooooo`00R_ooool2o`0001Sooooo
0ol00005ooooo`03o`000?oooooooooo00kooooo0_l0002Yooooo`00[?ooool3o`0000kooooo0_l0
002Yooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00TOooool2o`0001Wooooo00?o0000ooooooooool04?ooool2o`000:Oooooo002Aooooo`;o0000
6Oooool00ol0003oooooooooo`0@ooooo`Co0000YOooool00:cooooo00?o0000ooooooooool04Ooo
ool3o`000:Gooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@?ooooo0_l0
00000ooooooo0000onk^kP05ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`0Aooooo`?o0000YOooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
0oooool2o`000003oooooomEEEGoZJVY00Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`2iooooo`00POooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVY
ZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`0001?ooooo0_l0002Tooooo`00ROoo
ool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo01?ooooo0_l0002Tooooo`00ROooool01Ol0003ooooooooo
oooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool0^Oooool008Wooooo00Go410@oooooooooooooooooa0@4008ooooo`;o
00001?ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01Oooool2o`000;;ooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool2o`000003
ooooool@413ooooo00;ooooo00?o<S8booooooooool00_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Gooooo0_l0002booooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo1Ol00004ooooo`Co00000_ooool2o`0000;ooooo00?o0000ooooooooool0^Oooool00:Cooooo
0_l00002ooooo`;o00000_ooool00ol0003oooooooooo`2iooooo`00Z_ooool3o`0001gooooo0_l0
002Looooo`00W_ooool2o`0000Sooooo1Ol0000Mooooo`;o0000W?ooool009kooooo0_l00008oooo
o`;o00000_ooool3o`000;Wooooo002Cooooo`;o00005oooool00ol0003oooooooooo`0Kooooo`?o
0000Voooool009?ooooo0_l0000Gooooo`03o`000?oooooooooo01_ooooo1?l0002Jooooo`00[?oo
ool00ol0003oooooooooo`0Mooooo`;o0000V_ooool00:cooooo0ol0002iooooo`00Roooool2o`00
01oooooo0ol0002iooooo`00Roooool2o`0000_ooooo0ol0000Aooooo`04o`000?oooooo0000o`00
0;Sooooo002Hooooo`?o00004Oooool01?l0003oooooo`000?l0000=ooooo`;o0000ZOooool008_o
oooo0_l0000Oooooo`?o00003_ooool4o`00017ooooo0_l0002Dooooo`00Roooool2o`0001Oooooo
0_l00006ooooo`03o`000?oooooooooo013ooooo0_l0000Aooooo`;o0000U?ooool00:Cooooo0_l0
0006ooooo`03o`000?oooooooooo00oooooo0_l0000Booooo`;o0000U?ooool0093ooooo0_l0000J
ooooo`03o`000?oooooooooo00oooooo0ol0002Wooooo`00T?ooool2o`0001[ooooo00?o0000oooo
ooooool04?ooool2o`000:Oooooo0023ooooo`;o00002oooool2o`0000Cooooo0_l0000Dooooo`03
o`000?oooooooooo0;Wooooo0023ooooo`;o00002oooool2o`0000Cooooo0_l0000Dooooo`03o`00
0?oooooooooo0;Wooooo002Zooooo`?o00005?ooool2o`000:Gooooo002Zooooo`Go00001Oooool2
o`0000_ooooo0_l0000Booooo`;o0000TOooool009_ooooo0_l0000?ooooo`?o00001Oooool2o`00
01oooooo0_l0002Aooooo`00ROooool2o`00013ooooo0_l0000?ooooo`?o0000^Oooool008Wooooo
0_l00009ooooo`;o00005_ooool00ol0003oooooooooo`2iooooo`00U?ooool2o`0000?ooooo0_l0
000Aooooo`03o`000?oooooooooo00Sooooo0_l0000=ooooo`?o0000Woooool009Wooooo0_l0000A
ooooo`03o`000?oooooooooo00Sooooo0_l0000=ooooo`?o00004Oooool2o`0008cooooo002=oooo
o`;o00005_ooool2o`0000Gooooo00?o0000ooooooooool0:oooool2o`0008cooooo002=ooooo`;o
00005_ooool2o`0000Gooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0000]ooooo`;o0000
R_ooool00:cooooo00?o0000ooooooooool00_ooool2o`0000Sooooo0_l0000Oooooo`;o0000R_oo
ool00:cooooo00?o0000ooooooooool00_ooool2o`0000Sooooo0_l0002[ooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00W_ooool2o`0000cooooo00?o0000ooooooooool0^Oooool009Kooooo
0_l00006ooooo`;o00003?ooool00ol0003oooooooooo`2iooooo`00TOooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00;o00000oooool00olQ8B7o0000o`000004ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01Oooool00ol0003oooooooooo`0?ooooo`;o0000Z?ooool008_ooooo0_l00004ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool00olQ8B7o0000o`000007ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool03oooool2o`0001oooooo0_l00027ooooo`00ROooool6o`0000;ooooo
00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0<?ooool2o`0008Oooooo002@ooooo`;o00000oooool00ol0003oooooooooo`0<ooooo`;o0000
00?o<S8booooooooool00oooool4o`0004Sooooo0_l0001^ooooo`00T?ooool2o`0000?ooooo00?o
0000ooooooooool00_ooool2o`0000Kooooo1?l000000oo<c<coooooooooo`03ooooo`Co00001_oo
ool2o`00043ooooo0_l0001^ooooo`00Roooool2o`0000?ooooo0_l00003ooooo`03oa0@4?oooooo
oooo00;ooooo0_l00006ooooo`?o00000_ooool2o`0000?ooooo0ol00007ooooo`;o00002?ooool2
o`00027ooooo0_l00023ooooo`00Roooool2o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<
ooooo`03o`000?oooooooooo00;ooooo0_l00003ooooo`03o`000?oooooooooo017ooooo1?l0000O
ooooo`;o0000Poooool0097ooooo00?ok^k^oc8b<_l000000_l00002ooooo`;o00001Oooool2o`00
0003ooooool0003o000000;o00001_ooool00ol0003oooooooooo`0Cooooo`;o0000Y?ooool0093o
oooo0_l00002ooooo`;o00000_ooool2o`0000Gooooo0_l0000;ooooo`04o`000?oooooooooooooo
o`;o0000]_ooool0093ooooo0_l000000ooooooo0000o`00000Gooooo`04o`000?oooooooooooooo
o`;o0000]_ooool009?ooooo0_l0000Gooooo`03o`000?oooooooooo0;Wooooo002>ooooo`;o0000
3?ooool2o`0000kooooo0ol0000Rooooo`;o00004_ooool2o`00087ooooo002>ooooo`;o00003?oo
ool2o`0000kooooo00?o0000ooooooooool08_ooool3o`00017ooooo0_l00021ooooo`00Uoooool2
o`0001?ooooo00?o0000ooooooooool00oooool2o`0000Oooooo0_l0000Eooooo`;o0000U?ooool0
09Oooooo0_l0000Cooooo`03o`000?oooooooooo00?ooooo0_l00007ooooo`;o0000Zoooool00:Go
oooo0_l00005ooooo`03o`000?oooooooooo00?ooooo0_l0000`ooooo`;o00000_ooool2o`0007ko
oooo002Uooooo`;o000000?oooooo`000?l000000_ooool00ol0003oooooooooo`03ooooo`;o0000
7_ooool2o`000003ooooool0003o000000gooooo1_l0001nooooo`00Z?ooool2o`0000;ooooo00?o
0000ooooooooool01?ooool2o`0001gooooo0_l000000ooooooo0000o`00000?ooooo`;o0000P?oo
ool00:Sooooo0_l00002ooooo`03o`000?oooooooooo00Cooooo0_l0001;ooooo`;o0000I_ooool0
09kooooo0_l0000<ooooo`?o0000DOooool2o`0006Kooooo002Aooooo`;o00002oooool2o`0000co
oooo00?o0000ooooooooool0^Oooool0097ooooo0_l0000Iooooo`04o`000?ooooooooooooooo`;o
00009Oooool2o`0008oooooo002/ooooo`04o`000?ooooooooooooooo`;o00009Oooool2o`0008oo
oooo002Hooooo`;o00002Oooool3o`0000Kooooo00?o0000ooooooooool03_ooool2o`0000[ooooo
0_l0000Mooooo`;o0000O_ooool009Sooooo0_l00009ooooo`?o00001_ooool00ol0003ooooooooo
o`0>ooooo`?o00002Oooool2o`0001gooooo0_l0001nooooo`00Q?ooool2o`00017ooooo0_l0000C
ooooo`03o`000?oooooooooo00oooooo0_l0000Zooooo`;o00005oooool2o`0006?ooooo0024oooo
o`;o00004Oooool2o`0000;ooooo0_l00002ooooo`;o00002oooool00ol0003oooooooooo`0Aoooo
o`;o0000:?ooool5o`0001Cooooo0_l0001Sooooo`00Voooool2o`0000;ooooo0_l0000;ooooo`?o
00004Oooool2o`0002Wooooo1?l0001iooooo`00Poooool2o`0000Oooooo0_l0000Nooooo`03o`00
0?oooooooooo03gooooo0ol0001iooooo`00Poooool2o`0000Oooooo0_l0000Nooooo`03o`000?oo
oooooooo03kooooo0_l0001iooooo`00O_ooool2o`0000cooooo0_l0000Nooooo`03o`000?oooooo
oooo02[ooooo0_l0002=ooooo`00O_ooool2o`0001Wooooo0_l0000Aooooo`03o`000?oooooooooo
01gooooo0_l0000;ooooo`Co00004Oooool2o`0007Sooooo002Iooooo`;o00004Oooool00ol0003o
ooooooooo`0Mooooo`;o00003Oooool2o`00017ooooo0_l0001hooooo`00XOooool2o`0000Wooooo
00?o0000ooooooooool0;Oooool2o`0008[ooooo002Qooooo`;o00002Oooool2o`0000Kooooo0_l0
000Vooooo`;o0000R_ooool00:cooooo0_l00006ooooo`;o0000/_ooool008?ooooo0_l0000Woooo
o`?o0000^Oooool008?ooooo0_l00003ooooo`;o00008_ooool00ol0003oooooooooo`0=ooooo`;o
0000B_ooool2o`0005kooooo0028ooooo`;o00004?ooool2o`00013ooooo00?o0000ooooooooool0
3Oooool2o`0000Kooooo0_l00012ooooo`;o0000G_ooool009[ooooo0_l0000@ooooo`03o`000?oo
oooooooo01Gooooo0_l00008ooooo`;o00008Oooool2o`0007Gooooo002;ooooo`;o00007oooool3
o`0000gooooo0_l0000@ooooo`;o00008Oooool2o`0007Gooooo0029ooooo`05onk^k_lb<S;o0000
o`000?o^k^h01?ooool2o`000003ob4Q8Ooooooooooo00;ooooo1Ol00004ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01Oooool3o`0000gooooo0_l0002Zooooo`00ROooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Cooooo0_l000000olQ8B7oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo04?ooooo0_l0001dooooo`00POoo
ool6o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Fooooo`;o0000:oooool2o`0007Cooooo
0029ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMg
Molb<S;ooooo00Cooooo0ol0000Fooooo`;o0000;?ooool2o`0007?ooooo0029ooooo`05o`000?oo
ooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`0?ooooo`;o00001Oooool2o`0002cooooo0_l0001cooooo`00
ROooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00oooooo0_l0000Oooooo`;o0000Qoooool008Wooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo033ooooo0_l00027ooooo`00ROooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool0
0ol0003oooooooooo`02o`0000gooooo0_l0002Xooooo`00[?ooool00ol0003oooooooooo`02o`00
00gooooo0_l0000Pooooo`;o00004Oooool2o`0007?ooooo001mooooo`;o00006Oooool2o`0001;o
oooo00?o0000ooooooooool08_ooool2o`0000gooooo0_l0000Aooooo`;o0000Loooool007gooooo
0_l0000Gooooo`Co00004_ooool00ol0003oooooooooo`0Rooooo`;o00003Oooool2o`0008Kooooo
002Fooooo`;o00005?ooool3o`00033ooooo0_l0000Cooooo`?o0000LOooool0093ooooo0_l0000J
ooooo`03o`000?oooooooooo033ooooo0_l0000Cooooo`?o0000LOooool0093ooooo0_l000000ooo
oooo0000o`00000Gooooo`03o`000?oooooooooo01Sooooo0_l00009ooooo`;o00008?ooool2o`00
07;ooooo002Cooooo`;o00005oooool00ol0003oooooooooo`0Hooooo`;o00002Oooool2o`00023o
oooo0_l0001booooo`00[?ooool00ol0003oooooooooo`16ooooo`;o0000LOooool00:cooooo00?o
0000ooooooooool09Oooool2o`0001gooooo1?l0001aooooo`00[?ooool00ol0003oooooooooo`0U
ooooo`;o00007Oooool3o`0001Oooooo0_l0001Iooooo`00[?ooool00ol0003oooooooooo`0;oooo
o`;o0000DOooool2o`0005Wooooo002:ooooo`;o00008?ooool3o`0000_ooooo0_l0000<ooooo`;o
0000W_ooool008[ooooo0_l00006ooooo`;o00006?ooool00ol0003oooooooooo`0Iooooo`;o0000
W_ooool009;ooooo0_l0000Hooooo`03o`000?oooooooooo00gooooo0_l0000iooooo`;o0000Kooo
ool00:cooooo00?o0000ooooooooool01oooool2o`0000Cooooo0_l0000hooooo`?o0000Koooool0
0:cooooo0_l000000ooooooo0000o`000005ooooo`?o00007?ooool2o`0001oooooo0_l0001`oooo
o`00SOooool2o`0001gooooo0_l000000ooooooo0000o`000006ooooo`;o00007?ooool2o`0001go
oooo0_l0001booooo`00POooool2o`0000[ooooo0_l0000<ooooo`;o00003oooool00ol0003ooooo
ooooo`15ooooo`;o0000L_ooool0087ooooo0_l0000:ooooo`;o00003?ooool2o`0000oooooo00?o
0000ooooooooool09oooool2o`00093ooooo002=ooooo`;o00007Oooool00ol0003oooooooooo`0W
ooooo`;o0000T?ooool00:cooooo0ol0000=ooooo`;o0000>_ooool2o`0006kooooo002=ooooo`;o
00007Oooool00ol0003oooooooooo`0=ooooo`;o00001?ooool2o`00037ooooo1Ol0001^ooooo`00
SOooool2o`0001gooooo00?o0000ooooooooool04oooool2o`00037ooooo1?l0001_ooooo`002Ooo
ool4o`000003oa0@4?oooooooooo01Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_l00004ooooo`Go00001?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM01Kooooo00?o0000ooooooooool04oooool4o`000005ooooooo^k^ko<S8bo`000?lb
<S800_l00004ooooo`;o8B4Q0_ooool7o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0?oooo
o`03onk^k_l0003o000000;o00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0?
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1?l000000ol@413oooooooooo`0Booooo`002ooo
ool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo
00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_l00004ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2o`000003ogMgMolb<S;o
oooo01Gooooo00?o0000ooooooooool04oooool4o`000005oooooomgMgOoV9RHoooooonHV9P00_l0
0004ooooo`;o8B4Q0_ooool2o`000005oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8b
ooooo`0>ooooo`03ogMgMonHV9So000000;o00001Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0
3_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oo
oooo00?oMgMgoc8b<_ooool06Oooool00ol0003oooooooooo`0Dooooo`001_l00005ooooo`03o`00
0?oooooooooo013ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol0003oooooooooo`05ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo
410@00Cooooo0_l00006ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`05ooooo`;o00003?ooool2o`0000?ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool03Oooool01Ol@413oooooo`00
0?l0003o410@013ooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00Go410@oooooooooooo
oooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool0
00003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000oooooooo
ooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`000004
ooooo`;o00001oooool00onHV9So8B4Qonk^kP07ooooo`;o00005_ooool00ol0003oooooooooo`05
ooooo`;o00003?ooool2o`0000?ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ
8B7ok^k^00Oooooo0_l0000?ooooo`03o`000?oooooo000000;o00003oooool00omgMgOo<S8boooo
o`05ooooo`;o00001oooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool0
1_ooool00omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oo
oooooooo01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo00?ooooo00?o0000ob4Q8Ol000000_l0000Fooooo`03o`000?oooooooooo01?ooooo0_l0
0003ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`03o`00
0?lQ8B7o000000;o00003oooool01?l0003oooooooooooooool3o`0000[ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06_ooool00ol0003oooooooooo`0Dooooo`002oooool0
0ol0003oooooooooo`0Hooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgoooo
o`03ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`00
0?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool06?ooool3o`0000gooooo0_l00009ooooo`05oa0@4?oooooooooooooo
ool@41003oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`;o00003_ooool0
1Ol@413ooooooooooooooooo410@00;o00002_ooool00ol0003oooooooooo`0Aooooo`05oa0@4?oo
ooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo017o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo00Wooooo0_l00002ooooo`;o00001?ooool2o`0000?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0:ooooo`;o000000Co^[ZjoooooonHV9So410@1?ooool00ol0003o
ooooooooo`03o`0000kooooo00GoMgMgoiRHV?l0003o0000ogMgM`0<ooooo`03o`000?oooooooooo
017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Cooooo0009ooooo`03oeEEEOmVIVKo
000001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`00013ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c002ooooo`Oo00005_ooool00ol0003oooooooooo`09oooo
o`;o00002?ooool2o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0:ooooo`;o000000Co410@
o`000?lQ8B7oc<c<1?ooool5o`0000oooooo00Gok^k^oc8b<_l0003o0000onk^kP02o`0000[ooooo
1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000Iooooo`03
oeEEEOmVIVKo000001Kooooo0025ooooo`;o00002?ooool2o`0000?ooooo0_l0000Fooooo`03o`00
0?oooooooooo02Kooooo0_l0000>ooooo`;o00004_ooool2o`0006gooooo0025ooooo`;o00009Ooo
ool00ol0003oooooooooo`0Vooooo`;o00003_ooool2o`0001;ooooo0_l0001]ooooo`00[?ooool0
0ol0003oooooooooo`2^ooooo`;o00000_ooool2o`0000Gooooo002/ooooo`03o`000?oooooooooo
00Gooooo0_l0000=ooooo`;o00008Oooool2o`00017ooooo0_l0001Rooooo`06onk^k_lQ8B7oQhN7
okZj^_l0003ogMgM1Oooool00:cooooo00?o0000ooooooooool01Oooool2o`0000gooooo0_l0000Q
ooooo`;o00004Oooool2o`0006?ooooo00CogMgMo`000?l@413oc<c<1_ooool000Ooooooool0001<
o`0000cooooo00Cok^k^ob4Q8Ol@413ok^k^1_ooool000Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`04o`000?oooooo0000o`0000Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`;o00001_ooool2o`0000Sooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_oo
ool01?lQ8B7oMgMgogMgMolb<S86ooooo`001oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo01Gooooo0_l00006ooooo`;o00002?ooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`09ooooo`;o00000_oo
ool2o`0000Gooooo002/ooooo`03o`000?oooooooooo02Sooooo0_l0000;ooooo`?o0000POooool0
0:cooooo00?o0000ooooooooool07_ooool2o`0000Sooooo0ol0000:ooooo`?o0000POooool0097o
oooo0_l0000Iooooo`03o`000?oooooooooo00Wooooo0_l0000Cooooo`;o00002Oooool2o`0000_o
oooo0_l00021ooooo`00TOooool2o`0001Wooooo00?o0000ooooooooool02Oooool2o`0001gooooo
0_l0002?ooooo`00ROooool2o`00027ooooo00?o0000ooooooooool0:?ooool2o`00027ooooo0_l0
001/ooooo`00ROooool2o`00027ooooo0ol0001;ooooo`;o0000K?ooool008Kooooo0_l0000Toooo
o`03o`000?oooooooooo0;Wooooo0026ooooo`;o00009?ooool00ol0003oooooooooo`0=ooooo`;o
0000Z_ooool008Wooooo0_l0000Qooooo`03o`000?oooooooooo00gooooo0_l0000>ooooo`;o0000
;Oooool2o`0006_ooooo001looooo`;o00002oooool2o`00027ooooo00?o0000ooooooooool07Ooo
ool2o`0000Sooooo0_l0000Oooooo`;o00000_ooool2o`0006_ooooo001looooo`;o0000;_ooool0
0ol0003oooooooooo`0Wooooo`;o00003?ooool2o`00017ooooo0_l0001_ooooo`00[?ooool00ol0
003oooooooooo`0eooooo`;o00005?ooool2o`0006cooooo002Dooooo`;o00005_ooool00ol0003o
ooooooooo`1;ooooo`;o0000K?ooool009Cooooo0_l0000Fooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`?o0000BOooool2o`0006kooooo002/ooooo`03o`000?oooooooooo01gooooo0_l0000Z
ooooo`;o0000K_ooool008;ooooo0_l0000Xooooo`03o`000?oooooooooo01Cooooo0_l00007oooo
o`;o0000V_ooool008;ooooo0_l0000<ooooo`;o00000_ooool2o`0001Kooooo00?o0000oooooooo
ool05?ooool2o`0000Kooooo0_l0000[ooooo`;o0000K_ooool008;ooooo0_l00002ooooo`;o0000
2?ooool2o`0000;ooooo0_l0000Fooooo`03o`000?oooooooooo01cooooo0_l0000Hooooo`;o0000
4Oooool2o`0006kooooo0022ooooo`;o00000_ooool2o`0000gooooo0_l0000Eooooo`03o`000?oo
oooooooo01_ooooo0_l0000Iooooo`;o00004_ooool2o`0006gooooo002Eooooo`;o00005Oooool0
0ol0003oooooooooo`0Dooooo`;o00001Oooool2o`0002[ooooo0_l000000ooooooo0000o`00001]
ooooo`00[?ooool00ol0003oooooooooo`0Cooooo`?o00004Oooool2o`0001kooooo0_l0001`oooo
o`00[?ooool3o`0001?ooooo0_l0000Booooo`;o00003Oooool2o`00017ooooo0_l0001^ooooo`00
P_ooool2o`0000;ooooo0_l0000Tooooo`03o`000?oooooooooo03?ooooo0_l000000ooooooo0000
o`00000Aooooo`;o0000K_ooool008;ooooo0_l00002ooooo`;o00009?ooool00ol0003ooooooooo
o`0cooooo`;o00004_ooool2o`00073ooooo002/ooooo`03o`000?oooooooooo04Oooooo0_l0001`
ooooo`00[?ooool00ol0003oooooooooo`0Booooo`;o0000YOooool008Kooooo0_l00002ooooo`;o
00008?ooool00ol0003oooooooooo`0Booooo`;o0000YOooool008Kooooo0_l00002ooooo`;o0000
8?ooool01?l0003oooooo`000?l0000booooo`;o0000Q?ooool008;ooooo0_l0000=ooooo`;o0000
6Oooool01?l0003oooooo`000?l0000Iooooo`;o00002?ooool2o`0000gooooo0_l00024ooooo`00
P_ooool2o`0000gooooo0_l0000Iooooo`?o00006_ooool2o`0000Sooooo0_l0002Cooooo`00[?oo
ool00ol0003oooooooooo`0Jooooo`;o00005_ooool2o`0008Gooooo002/ooooo`03o`000?oooooo
oooo017ooooo0_l00007ooooo`;o00005_ooool2o`0008Gooooo002/ooooo`03o`000?oooooooooo
00_ooooo0_l00004ooooo`;o0000=Oooool2o`0006oooooo002/ooooo`03o`000?oooooooooo00_o
oooo0_l0000kooooo`;o0000Koooool007gooooo0_l0000Eooooo`;o00001_ooool2o`0000kooooo
00?o0000ooooooooool0B?ooool2o`0006oooooo001mooooo`;o00002_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo00?o8B4Qo`000?l000000oooool5o`0000Cooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo02Gooooo0_l0000Qooooo`;o0000Koooool008Wooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A4
00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0@ooooo`;o00004oooool2o`00
00gooooo0_l00023ooooo`00ROooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q
8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o00001?ooool2o`0000[ooooo0_l00008oooo
o`;o00006?ooool2o`00017ooooo0_l0001`ooooo`00Qoooool3o`0000?ooooo00?o0000oooooooo
ool02oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool01?ooool2o`0001Cooooo0_l0000[ooooo`;o0000L?ooool008Oooooo0ol00003ooooo`03o`00
0?oooooooooo00cooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool00_l0002gooooo`00ROooool01_l@413ooooooooooooooooo410@oooo
o`;o00001?ooool2o`0000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00;o0000]oooool008Wooooo00KoMgMgoiRHV?ooooooV9RHogMgMoooool2
o`0000Cooooo0_l00002ooooo`06o`000?nj^[[ooooooiRHV?l@413ooooo0_l000000ooooooo0000
ooooo`08ooooo`03o`000?oooooooooo00oooooo0_l0000Booooo`;o00003?ooool2o`0008Kooooo
0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01_nHV9So410@o`000?lQ8B7oc<c<oooo
o`;o000000?oooooo`000?l000000_l00005ooooo`;o00002_ooool2o`0000Gooooo0_l0000Boooo
o`;o00003?ooool2o`0008Kooooo002[ooooo`;o00002_ooool2o`000:oooooo002Iooooo`;o0000
1oooool2o`0000Sooooo00?o0000ooooooooool0;oooool2o`0008Sooooo002Iooooo`;o00001ooo
ool2o`0000Sooooo0ol0000_ooooo`;o0000R?ooool008cooooo0_l000000ooooooo0000o`00000K
ooooo`?o00000_ooool2o`0001oooooo0_l0000:ooooo`;o0000R?ooool008Sooooo0_l00002oooo
o`;o000000?oooooo`000?l000006?ooool2o`000003ooooool0003ooooo00?ooooo0_l00003oooo
o`;o00001?ooool2o`0001Cooooo0_l0000:ooooo`;o0000R?ooool008Sooooo0_l00009ooooo`;o
00005?ooool2o`000003ooooool0003ooooo00Sooooo0_l00004ooooo`?o00004oooool2o`0009Co
oooo002Cooooo`;o00005oooool00ol0003oooooooooo`0>ooooo`;o0000ZOooool00:cooooo00?o
0000ooooooooool0@_ooool2o`0007Gooooo002@ooooo`;o00006_ooool00ol0003oooooooooo`0`
ooooo`;o00004?ooool2o`0007Gooooo002@ooooo`;o00003oooool2o`0000Wooooo00?o0000oooo
ooooool0<?ooool2o`00013ooooo0_l0001eooooo`00R?ooool2o`0001Oooooo0_l00009ooooo`03
o`000?oooooooooo00gooooo0_l0002Zooooo`00R?ooool2o`0002;ooooo0ol0000=ooooo`;o0000
Z_ooool00:cooooo00?o0000ooooooooool02oooool2o`0001;ooooo0_l0002Hooooo`00[?ooool0
0ol0003oooooooooo`0;ooooo`;o00004_ooool2o`00027ooooo0_l0001eooooo`00[?ooool00ol0
003oooooooooo`0Oooooo`;o00008Oooool2o`0007Gooooo002Eooooo`;o00005Oooool00ol0003o
ooooooooo`0Booooo`;o0000YOooool009Gooooo0_l00007ooooo`;o00002Oooool2o`000003oooo
ool0003ooooo01?ooooo0_l0002Uooooo`00W_ooool2o`0000Wooooo0_l000000ooooooo0000o`00
002jooooo`00X?ooool2o`0000Gooooo0_l00003ooooo`;o0000^_ooool00:3ooooo0_l00005oooo
o`;o00000oooool3o`0000;ooooo0_l0000>ooooo`;o0000YOooool00:cooooo00?o0000oooooooo
ool00_ooool2o`0000Gooooo0_l00007ooooo`;o00005_ooool2o`0008gooooo002/ooooo`03o`00
0?oooooooooo00Wooooo0_l0000Oooooo`;o0000SOooool00:cooooo00?o0000ooooooooool0^Ooo
ool009?ooooo0_l0000Gooooo`03o`000?oooooooooo00;o0000]oooool009?ooooo0_l0000Goooo
o`03o`000?oooooooooo00;o0000:?ooool2o`00013ooooo0_l0001kooooo`00[?ooool00ol0003o
ooooooooo`0Xooooo`Co00004?ooool2o`0007_ooooo002/ooooo`03o`000?oooooooooo02Sooooo
0ol0002>ooooo`00Woooool2o`0000_ooooo0ol0000Iooooo`;o00003_ooool2o`0001?ooooo0_l0
001iooooo`00Woooool2o`0000_ooooo00?o0000ooooooooool06Oooool2o`0002?ooooo0_l0001i
ooooo`00S?ooool2o`0001;ooooo0_l0000:ooooo`03o`000?oooooooooo00cooooo0_l0002[oooo
o`00S?ooool2o`0001;ooooo0_l0000:ooooo`03o`000?oooooooooo00cooooo0_l0000Iooooo`;o
0000T?ooool008Kooooo0_l00008ooooo`;o00000oooool2o`0001Gooooo0_l0000<ooooo`Co0000
2?ooool2o`0000kooooo0_l0002@ooooo`00Q_ooool2o`0000?ooooo0_l00003ooooo`;o00000ooo
ool2o`0000Cooooo0_l0000?ooooo`;o00003?ooool4o`0000Sooooo0_l0002Pooooo`00Roooool3
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o00001Oooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Gooooo00?o0000ooooooooool09Oooool2o`0001?ooooo0_l0001mooooo`00S?oo
ool2o`0000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo02Gooooo0_l0000Cooooo`?o0000O?ooool0097ooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
5Oooool2o`0000kooooo0ol0000Cooooo`;o0000O?ooool0097ooooo00Go0000oooooooooooooooo
o`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol000000ooooooo0000o`00000Booooo`;o0000
3_ooool3o`00097ooooo002Aooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00?ooooo0ol00003ooooo`;o0000]_ooool008Sooooo0_l00007ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`05ooooo`?o000000?oooooo`000?l0
0000^?ooool008Sooooo0_l00007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003o
ooooooooo`07ooooo`04o`000?oooooo0000o`000;Sooooo002Aooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool2o`0000Oooooo1?l00006ooooo`03o`000?oooooooooo01?ooooo0_l0002Toooo
o`00S_ooool2o`0000Wooooo0_l00005ooooo`;o000000?oooooo`000?l000001oooool00ol0003o
ooooooooo`09ooooo`;o00002?ooool2o`000:Cooooo002>ooooo`;o00004?ooool2o`0000[ooooo
00?o0000ooooooooool01oooool4o`0002_ooooo0ol00020ooooo`00[?ooool3o`0000Oooooo0_l0
000]ooooo`?o0000P?ooool008Wooooo0_l0000Qooooo`?o00008?ooool2o`0009Oooooo0029oooo
o`;o00008Oooool00ol0003oooooooooo`0Pooooo`;o0000Uoooool008?ooooo0_l00009ooooo`;o
00007?ooool00ol0003oooooooooo`0Pooooo`;o0000Uoooool008?ooooo0_l00009ooooo`;o0000
7?ooool00ol0003oooooooooo`0Pooooo`?o0000U_ooool008?ooooo0_l0000Wooooo`03o`000?oo
oooooooo01gooooo1_l0002Fooooo`00Poooool2o`00013ooooo0_l0000Eooooo`03o`000?oooooo
oooo01gooooo1?l0000Aooooo`;o0000QOooool008oooooo0_l00004ooooo`;o00005Oooool00ol0
003oooooooooo`0booooo`;o0000QOooool008oooooo0_l0000Gooooo`;o00000_ooool00ol0003o
ooooooooo`2iooooo`00Z?ooool2o`0000;ooooo0ol0000Mooooo`;o0000V_ooool009Kooooo0_l0
0008ooooo`;o00002_ooool00ol0003oooooooooo`0;ooooo`;o00004?ooool2o`0009[ooooo002F
ooooo`;o00002?ooool4o`0000Sooooo00?o0000ooooooooool02oooool2o`0002?ooooo0_l00027
ooooo`00X_ooool2o`0000Sooooo00?o0000ooooooooool0;Oooool2o`000003ooooool0003o0000
08Oooooo002/ooooo`03o`000?oooooooooo02gooooo0_l0002:ooooo`00Q?ooool2o`0000Gooooo
0_l0000Oooooo`03o`000?oooooooooo0;Wooooo0024ooooo`;o00001Oooool2o`0001oooooo00Co
0000ooooool0003o0000^?ooool00:cooooo00Co0000ooooool0003o0000^?ooool00:cooooo0ol0
000Hooooo`;o0000Woooool00:cooooo00?o0000ooooooooool06?ooool2o`0009oooooo002[oooo
o`;o0000;?ooool2o`0008gooooo002[ooooo`;o00006?ooool2o`0001;ooooo0_l0002=ooooo`00
S?ooool2o`0000kooooo0_l0000>ooooo`03o`000?oooooooooo01Kooooo0_l0000Aooooo`;o0000
S_ooool008cooooo0_l0000>ooooo`;o00003_ooool00ol0003oooooooooo`0Fooooo`;o00004Ooo
ool2o`0008kooooo002/ooooo`03o`000?oooooooooo00Gooooo0_l0000>ooooo`;o0000X_ooool0
0:?ooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo0_l0000>ooooo`;o0000X_ooool009Go
oooo0_l0000<ooooo`;o00001oooool00ol0003oooooooooo`2iooooo`00S_ooool2o`0000Gooooo
0_l0000Eooooo`?o00009oooool2o`00093ooooo002>ooooo`;o00007?ooool00ol0003ooooooooo
o`0Wooooo`;o0000T?ooool00:cooooo00?o0000ooooooooool04Oooool2o`000:Kooooo002>oooo
o`;o00007?ooool00ol0003oooooooooo`0Aooooo`;o00004Oooool2o`0009?ooooo002>ooooo`;o
00007?ooool00ol0003oooooooooo`0Tooooo`;o0000Toooool008Wooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP02o`0000?ooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo00;o00008_ooool2o`0009?ooooo0029ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo00;o0000]oooool008Wooooo00Go410@oooooooo
oooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool2o`00
0;[ooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06oooo
o`03ogMgMolb<S;ooooo00Cooooo0ol0002iooooo`00ROooool01Ol0003ooooooooooooooooo0000
00kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000
ooooooooool0^Oooool008Wooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOo
oooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2iooooo`00ROooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02oooool2o`000:cooooo0029ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool7o`0000;ooooo1?l00006ooooo`03o`000?oooooooooo00_ooooo0_l0
002/ooooo`00W_ooool2o`0000Sooooo0_l00002ooooo`03o`000?oooooooooo0;Wooooo002Uoooo
o`;o000000?oooooo`000?l000000_ooool00ol0003oooooooooo`2iooooo`00Toooool2o`00013o
oooo0_l000000ooooooo0000o`000002ooooo`03o`000?oooooooooo00Sooooo0_l0002_ooooo`00
Toooool2o`0001Oooooo0ol00006ooooo`Co0000[oooool00:cooooo00?o0000ooooooooool01_oo
ool2o`000;7ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo00Cooooo0_l0002cooooo`00[?ooool00ol0003ooooo
ooooo`02ooooo`Co0000/oooool00:cooooo00Co0000oooooooooooooooo0ol0002eooooo`00[?oo
ool01?l0003oooooooooooooool2o`000;Kooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo1?l0002hooooo`00
[?ooool4o`000;Sooooo002/ooooo`?o0000^Oooool009[ooooo0_l0000@ooooo`03o`000?oooooo
oooo0;Wooooo002Jooooo`;o00002_ooool2o`0000Cooooo00?o0000ooooooooool0^Oooool00:Ko
oooo0_l00004ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:?ooooo0_l0
0007ooooo`03o`000?oooooooooo0;Wooooo002Sooooo`;o00001oooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
[?ooool00ol0003oooooooooo`07ooooo`;o0000/?ooool00:cooooo00?o0000ooooooooool01ooo
ool2o`000;3ooooo002/ooooo`03o`000?oooooooooo00Kooooo0_l0002aooooo`00[?ooool3o`00
00Kooooo0_l0002aooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00X_ooool4o`000003oa0@4?oooooooooo00?o
oooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000
ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo00?o0000oooooooo
ool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:;ooooo00?oEEEEofIVI_l00000`ooo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:[ooooo00Co
410@o`000?l0003o0000^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000
ooooooooool0^_ooool00:_ooooo00Ko0000ogMgMol0003o0000oeEEEOo^k^jgooooo`00Zoooool0
1_l0003oEEEEonk^k_ooooooMgMgoeEEEKOooooo002[ooooo`03o`000?o^k^kooooo00;ooooo00?o
0000ooooooooool0]Oooool00:_ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`2e
ooooo`00Zoooool01_l0003oEEEEonk^k_ooooooMgMgofIVI[Oooooo002Zooooo`03oa0@4?l0003o
MgMg00;o000000?oIVIVonk^k_ooool0]_ooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.57303 .76971 Mdot
.41047 .79249 Mdot
.45517 .39675 Mdot
.50109 .27559 Mdot
.42702 .73346 Mdot
.63128 .43737 Mdot
.5167 .52993 Mdot
.58559 .12007 Mdot
.39846 .17405 Mdot
.42762 .67956 Mdot
.45829 .22485 Mdot
.64606 .2108 Mdot
.50187 .09038 Mdot
.41741 .37657 Mdot
.66387 .25375 Mdot
.55606 .53701 Mdot
.45284 .83942 Mdot
.51415 .1047 Mdot
.57451 .57254 Mdot
.68327 .58463 Mdot
.53153 .13214 Mdot
.38782 .36265 Mdot
.41669 .18114 Mdot
.53934 .1379 Mdot
.71487 .37043 Mdot
.56582 .31312 Mdot
.52014 .27791 Mdot
.5747 .55268 Mdot
.67251 .63536 Mdot
.39876 .72572 Mdot
.57471 .19883 Mdot
.39324 .1965 Mdot
.54396 .07702 Mdot
.39656 .42838 Mdot
.47503 .13037 Mdot
.67877 .50258 Mdot
.51426 .92987 Mdot
.5721 .45427 Mdot
.64857 .69891 Mdot
.66066 .23016 Mdot
.71634 .36005 Mdot
.42453 .21341 Mdot
.58021 .28016 Mdot
.55836 .80353 Mdot
.60734 .69669 Mdot
.4301 .24312 Mdot
.41522 .41871 Mdot
.37092 .58353 Mdot
.60276 .5665 Mdot
.66906 .63258 Mdot
.37212 .60221 Mdot
.62096 .77101 Mdot
.39746 .08268 Mdot
.53912 .20709 Mdot
.54778 .21569 Mdot
.4675 .02298 Mdot
.59728 .13676 Mdot
.46103 .84974 Mdot
.4185 .89294 Mdot
.61717 .66693 Mdot
.45362 .18832 Mdot
.72449 .65999 Mdot
.64117 .71397 Mdot
.51381 .67536 Mdot
.54711 .08789 Mdot
.42466 .07839 Mdot
.43559 .71181 Mdot
.55488 .49865 Mdot
.57412 .45678 Mdot
.56998 .18265 Mdot
.43331 .81038 Mdot
.43921 .59694 Mdot
.42092 .6328 Mdot
.48409 .76971 Mdot
.64124 .71364 Mdot
.50788 .53305 Mdot
.39808 .08044 Mdot
.517 .22406 Mdot
.63808 .7353 Mdot
.5994 .52921 Mdot
.64534 .3386 Mdot
.40351 .75223 Mdot
.47274 .25103 Mdot
.4337 .18326 Mdot
.52921 .05686 Mdot
.55709 .554 Mdot
.41857 .69356 Mdot
.40448 .47069 Mdot
.49912 .83831 Mdot
.55466 .51341 Mdot
.71699 .38155 Mdot
.44357 .70159 Mdot
.40841 .37626 Mdot
.46534 .73869 Mdot
.4145 .41097 Mdot
.37051 .53191 Mdot
.41472 .02751 Mdot
.49718 .84412 Mdot
.54583 .81762 Mdot
.5422 .76565 Mdot
.64568 .21441 Mdot
.53085 .84671 Mdot
.62239 .27594 Mdot
.40292 .34091 Mdot
.40996 .71504 Mdot
.56318 .63606 Mdot
.44181 .69626 Mdot
.57565 .19312 Mdot
.41254 .54252 Mdot
.48984 .25451 Mdot
.38968 .21854 Mdot
.68454 .51414 Mdot
.6508 .11808 Mdot
.49479 .69148 Mdot
.48635 .1777 Mdot
.4473 .03255 Mdot
.41876 .09053 Mdot
.518 .92071 Mdot
.50174 .09139 Mdot
.73988 .59141 Mdot
.4937 .09243 Mdot
.67166 .64369 Mdot
.57544 .1917 Mdot
.52316 .33062 Mdot
.68256 .5489 Mdot
.56116 .95031 Mdot
.461 .89562 Mdot
.42738 .51783 Mdot
.41035 .20305 Mdot
.50824 .87365 Mdot
.67264 .25922 Mdot
.63501 .45016 Mdot
.60388 .33612 Mdot
.65505 .69741 Mdot
.54812 .89205 Mdot
.67765 .60078 Mdot
.42384 .65264 Mdot
.58039 .12253 Mdot
.66918 .26098 Mdot
.67663 .77315 Mdot
.4266 .37297 Mdot
.578 .5043 Mdot
.4526 .83964 Mdot
.68564 .54962 Mdot
.49785 .02466 Mdot
.72341 .21757 Mdot
.54629 .67903 Mdot
.40894 .38034 Mdot
.7481 .54496 Mdot
.5557 .73859 Mdot
.55452 .35781 Mdot
.54361 .14225 Mdot
.4499 .64841 Mdot
.63376 .54692 Mdot
.57117 .85578 Mdot
.63537 .73315 Mdot
.4503 .0312 Mdot
.51066 .93271 Mdot
.56608 .86422 Mdot
.59777 .42349 Mdot
.64038 .7332 Mdot
.71326 .33374 Mdot
.67218 .44476 Mdot
.57924 .28421 Mdot
.55166 .80414 Mdot
.48844 .01873 Mdot
.63776 .30776 Mdot
.5714 .43757 Mdot
.57811 .84995 Mdot
.67446 .58923 Mdot
.42608 .60306 Mdot
.56038 .38826 Mdot
.41558 .66956 Mdot
.53401 .71562 Mdot
.55395 .09178 Mdot
.52502 .99056 Mdot
.63389 .53567 Mdot
.49901 .67551 Mdot
.66471 .65722 Mdot
.60544 .80607 Mdot
.68321 .27347 Mdot
.5272 .68429 Mdot
.7212 .37505 Mdot
.46731 .28257 Mdot
.39228 .2098 Mdot
.56298 .94646 Mdot
.38423 .24838 Mdot
.70766 .3215 Mdot
.59389 .30828 Mdot
.74381 .54385 Mdot
.68613 .54835 Mdot
.53545 .5828 Mdot
.72808 .63632 Mdot
.55746 .088 Mdot
.73649 .42467 Mdot
.65773 .23316 Mdot
.40408 .45383 Mdot
.40322 .92758 Mdot
.39308 .48976 Mdot
.52492 .5549 Mdot
.52288 .57317 Mdot
.43388 .54049 Mdot
.43332 .75217 Mdot
.37803 .81486 Mdot
.52704 .84481 Mdot
.53289 .42394 Mdot
.63537 .47787 Mdot
.48143 .24508 Mdot
.50532 .31664 Mdot
.46783 .21436 Mdot
.43516 .11637 Mdot
.50669 .20605 Mdot
.63907 .31134 Mdot
.53886 .64127 Mdot
.54336 .81774 Mdot
.48584 .18095 Mdot
.71556 .34202 Mdot
.47017 .27748 Mdot
.62074 .64173 Mdot
.64335 .20054 Mdot
.47688 .17387 Mdot
.40216 .83151 Mdot
.62813 .28473 Mdot
.65746 .37928 Mdot
.54862 .5871 Mdot
.47975 .81163 Mdot
.43485 .87069 Mdot
.43099 .64275 Mdot
.66589 .25698 Mdot
.73953 .60575 Mdot
.55399 .45354 Mdot
.45671 .35727 Mdot
.37089 .76094 Mdot
.57932 .66674 Mdot
.51507 .26405 Mdot
.74114 .57023 Mdot
.56741 .4202 Mdot
.51175 .87486 Mdot
.48311 .0826 Mdot
.52136 .85529 Mdot
.72288 .66217 Mdot
.61824 .37373 Mdot
.65987 .36442 Mdot
.43446 .81326 Mdot
.39401 .18856 Mdot
.47808 .73908 Mdot
.57486 .84513 Mdot
.52381 .78978 Mdot
.43972 .82552 Mdot
.64113 .71705 Mdot
.73316 .41394 Mdot
.49811 .68304 Mdot
.53386 .58579 Mdot
.55226 .87683 Mdot
.5714 .33365 Mdot
.55618 .37335 Mdot
.56708 .24512 Mdot
.50461 .5693 Mdot
.58649 .12573 Mdot
.38566 .74854 Mdot
.59386 .61658 Mdot
.51401 .26175 Mdot
.66389 .40228 Mdot
.44578 .66636 Mdot
.55886 .728 Mdot
.58988 .73066 Mdot
.42316 .34468 Mdot
.61962 .39762 Mdot
.67809 .54248 Mdot
.59031 .40425 Mdot
.68176 .51988 Mdot
.56038 .23607 Mdot
.43074 .69693 Mdot
.59883 .56988 Mdot
.57763 .84731 Mdot
.52056 .70416 Mdot
.52465 .74563 Mdot
.36953 .51196 Mdot
.45577 .22467 Mdot
.636 .52273 Mdot
.65748 .68376 Mdot
.4261 .4792 Mdot
.50838 .72613 Mdot
.50939 .93331 Mdot
.63109 .19026 Mdot
.5607 .64684 Mdot
.48384 .67719 Mdot
.47784 .80616 Mdot
.68311 .46577 Mdot
.41752 .30734 Mdot
.63351 .31001 Mdot
.56189 .94687 Mdot
.42821 .91467 Mdot
.64265 .21494 Mdot
.42001 .89154 Mdot
.50549 .39283 Mdot
.45618 .95917 Mdot
.73098 .60943 Mdot
.67665 .4212 Mdot
.65628 .23977 Mdot
.75194 .26648 Mdot
.6027 .53499 Mdot
.59853 .31081 Mdot
.50038 .88587 Mdot
.39458 .18714 Mdot
.71113 .35153 Mdot
.42131 .35298 Mdot
.36995 .52382 Mdot
.57924 .35592 Mdot
.52387 .4491 Mdot
.43244 .12458 Mdot
.43692 .81179 Mdot
.48901 .08111 Mdot
.74793 .5247 Mdot
.47881 .70993 Mdot
.6115 .67315 Mdot
.40775 .30005 Mdot
.56758 .11197 Mdot
.44171 .65402 Mdot
.68762 .28419 Mdot
.73846 .51542 Mdot
.65951 .812 Mdot
.54541 .40789 Mdot
.63674 .45385 Mdot
.43772 .1717 Mdot
.62468 .75286 Mdot
.47651 .81487 Mdot
.52863 .50844 Mdot
.51554 .45944 Mdot
.42205 .77116 Mdot
.62253 .16935 Mdot
.55599 .86938 Mdot
.47038 .74235 Mdot
.40729 .21038 Mdot
.42702 .47792 Mdot
.43341 .52817 Mdot
.42772 .85357 Mdot
.62826 .41678 Mdot
.58031 .28627 Mdot
.5977 .42464 Mdot
.44412 .77997 Mdot
.36901 .23691 Mdot
.57899 .36053 Mdot
.41987 .82003 Mdot
.51038 .6831 Mdot
.51252 .04542 Mdot
.50869 .25501 Mdot
.67908 .58717 Mdot
.38558 .57709 Mdot
.41999 .54211 Mdot
.44408 .21243 Mdot
.67982 .76788 Mdot
.64089 .20073 Mdot
.46383 .96556 Mdot
.67981 .51856 Mdot
.60415 .5011 Mdot
.39384 .52181 Mdot
.67711 .5745 Mdot
.57023 .69724 Mdot
.64027 .20041 Mdot
.65638 .82217 Mdot
.66328 .37548 Mdot
.66996 .25528 Mdot
.69206 .29409 Mdot
.72136 .36591 Mdot
.43923 .39604 Mdot
.58914 .63031 Mdot
.67114 .26606 Mdot
.58977 .12835 Mdot
.44505 .36273 Mdot
.61529 .2685 Mdot
.57892 .36731 Mdot
.637 .48104 Mdot
.55476 .80251 Mdot
.37106 .43615 Mdot
.51385 .87144 Mdot
.48451 .96064 Mdot
.58792 .81948 Mdot
.40821 .2179 Mdot
.49047 .9625 Mdot
.40385 .23679 Mdot
.70344 .33613 Mdot
.68067 .15457 Mdot
.48846 .95257 Mdot
.6341 .56357 Mdot
.45876 .66722 Mdot
.73611 .46374 Mdot
.51166 .81999 Mdot
.51324 .43925 Mdot
.68833 .2814 Mdot
.5746 .1897 Mdot
.5289 .49346 Mdot
.46606 .77062 Mdot
.53983 .25922 Mdot
.52873 .29391 Mdot
.36898 .5151 Mdot
.63494 .29328 Mdot
.72824 .62979 Mdot
.68733 .28167 Mdot
.40164 .64303 Mdot
.36057 .33173 Mdot
.39565 .56552 Mdot
.53977 .70213 Mdot
.52168 .74772 Mdot
.44167 .55884 Mdot
.61485 .16029 Mdot
.64275 .20593 Mdot
.51595 .26887 Mdot
.42105 .5512 Mdot
.51663 .26026 Mdot
.5485 .61069 Mdot
.74463 .48232 Mdot
.4041 .4376 Mdot
.67245 .43731 Mdot
.43853 .31074 Mdot
.55766 .37012 Mdot
.43481 .6156 Mdot
.40478 .56361 Mdot
.39525 .51011 Mdot
.53467 .30366 Mdot
.53678 .45109 Mdot
.74435 .56855 Mdot
.57646 .11711 Mdot
.46786 .62017 Mdot
.49182 .13684 Mdot
.40965 .71295 Mdot
.62561 .60238 Mdot
.58687 .39794 Mdot
.56518 .40541 Mdot
.73822 .46731 Mdot
.49105 .89889 Mdot
.59055 .0505 Mdot
.54532 .8267 Mdot
.54076 .49505 Mdot
.42147 .09379 Mdot
.67708 .27882 Mdot
.47142 .21606 Mdot
.38529 .56268 Mdot
.3756 .18971 Mdot
.41979 .49956 Mdot
.5232 .43173 Mdot
.51775 .75104 Mdot
.6628 .39356 Mdot
.59991 .48798 Mdot
.4282 .98903 Mdot
.48799 .28477 Mdot
.50674 .15934 Mdot
.4167 .24306 Mdot
.49009 .73271 Mdot
.48113 .70673 Mdot
.50101 .7483 Mdot
.58738 .12286 Mdot
.46124 .70468 Mdot
.64801 .71309 Mdot
.43824 .87487 Mdot
.6068 .69287 Mdot
.68266 .53291 Mdot
.61876 .27835 Mdot
.41633 .74234 Mdot
.56936 .94396 Mdot
.4573 .76284 Mdot
.62699 .17546 Mdot
.73327 .41022 Mdot
.42501 .33439 Mdot
.45855 .96173 Mdot
.58866 .40177 Mdot
.47479 .84974 Mdot
.68023 .58117 Mdot
.54596 .81852 Mdot
.56982 .60015 Mdot
.44625 .20732 Mdot
.39555 .44845 Mdot
.73014 .65136 Mdot
.60152 .33488 Mdot
.50928 .50501 Mdot
.56868 .25994 Mdot
.59994 .53695 Mdot
.43562 .42409 Mdot
.54972 .43887 Mdot
.53222 .19542 Mdot
.59903 .31943 Mdot
.51436 .62524 Mdot
.55902 .30398 Mdot
.42859 .06936 Mdot
.43534 .76362 Mdot
.60038 .7036 Mdot
.57778 .47146 Mdot
.57228 .55871 Mdot
.47288 .30561 Mdot
.63566 .09816 Mdot
.48288 .30862 Mdot
.41871 .82543 Mdot
.3952 .79434 Mdot
.67398 .45202 Mdot
.57614 .47945 Mdot
.67316 .62379 Mdot
.67095 .25127 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002Xooooo`;o00000_ooool00ol0003oooooooooo`2iooooo`00
Z?ooool2o`0000;ooooo00?o0000ooooooooool0^Oooool00:7ooooo0_l00008ooooo`Co0000^Ooo
ool008oooooo0_l0000@ooooo`;o00002?ooool2o`000;_ooooo002?ooooo`;o00002_ooool2o`00
00oooooo00?o0000ooooooooool0^Oooool009[ooooo0ol0000?ooooo`03o`000?oooooooooo0;Wo
oooo002Jooooo`;o00004?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool01?l0003oooooooooooooool2
o`000;Kooooo002/ooooo`04o`000?ooooooooooooooo`;o0000]_ooool00:cooooo0ol0000Joooo
o`;o0000WOooool00:cooooo00?o0000ooooooooool06_ooool2o`0009gooooo002/ooooo`03o`00
0?oooooooooo00Kooooo0_l0002aooooo`00[?ooool00ol0003oooooooooo`06ooooo`;o0000/Ooo
ool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool009Co
oooo0_l0000Fooooo`03o`000?oooooooooo0;Wooooo002Dooooo`;o00005_ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool3o`0000_ooooo0_l0002/ooooo`00R_ooool2o`0000Oooooo0_l0000G
ooooo`03o`000?oooooooooo00_ooooo0_l0002/ooooo`00R_ooool2o`0000Oooooo0_l0000Aoooo
o`Co00000_ooool00ol0003oooooooooo`2iooooo`00R_ooool2o`0001[ooooo1?l00002ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00cooooo0_l00002ooooo`;o0000
Yoooool0097ooooo0_l0000Fooooo`;o000000?oooooo`000?l000003Oooool6o`000:Oooooo002A
ooooo`?o00005Oooool2o`000003ooooool0003o000000oooooo0_l0002Yooooo`00T_ooool2o`00
01Sooooo00?o0000ooooooooool0:Oooool2o`0008kooooo002/ooooo`?o0000:Oooool2o`0008ko
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`04o`000?ooooooooooooooo`;o0000
]_ooool00:cooooo00Co0000oooooooooooooooo0_l0002fooooo`00[?ooool00ol0003ooooooooo
o`0Cooooo`;o0000Y?ooool009Kooooo0_l0000Dooooo`03o`000?oooooooooo01?ooooo0_l0002T
ooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B400ooooooo0000o`000003
ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo01Kooooo0_l0000Fooooo`;o0000ROooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool05_ooool5o`0001?ooooo0_l00029ooooo`00POooool6o`0000;ooooo00Go410@
oooooooooooooooooa0@4007ooooo`;o00001?ooool00onYZJWoEEEEooooo`08ooooo`03o`000?oo
oooooooo00?ooooo0ol0000Gooooo`Co0000W_ooool008Wooooo00Go0000ooooooooooooooooo`00
0007ooooo`;o00001Oooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool06Oooool3o`0009gooooo0029ooooo`05o`000?ooooooooooooooool000003_oo
ool00omEEEGoc<c<ooooo`03ooooo`?o000000?o<S8bolc<c?ooool01?ooool00ol0003ooooooooo
o`0Jooooo`;o0000WOooool008Wooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmg
MgOooooo00?ooooo0ol00007ooooo`03o`000?oooooooooo00Oooooo0_l0002`ooooo`00ROooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`00
0?oooooooooo00Cooooo0_l000000ooooooo0000ooooo`08ooooo`;o000000?oooooo`000?l00000
4Oooool2o`0009[ooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo
1?l00003ooooo`;o000000?oooooo`000?ooool02oooool2o`00017ooooo0_l0002Jooooo`00[?oo
ool00ol0003oooooooooo`0;ooooo`;o0000[?ooool00:cooooo00?o0000ooooooooool02oooool2
o`000:cooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo
00?o0000ooooooooool0>?ooool2o`0007oooooo002/ooooo`03o`000?oooooooooo03Sooooo0_l0
001oooooo`00[?ooool01?l0003oooooo`000?l0000Qooooo`;o0000UOooool00:cooooo00Co0000
ooooool0003o00008Oooool2o`0009Gooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo02Gooooo0_l0002Booooo`00R_ooool2o`0000_ooooo0_l0000;ooooo`;o
00001_ooool00ol0003oooooooooo`0Uooooo`;o0000T_ooool008[ooooo0_l0000;ooooo`;o0000
2oooool2o`0000Kooooo0ol0000Vooooo`;o0000TOooool00:Oooooo0_l00003ooooo`03o`000?oo
oooooooo02Kooooo0_l0002Aooooo`00T?ooool2o`0000Cooooo0_l0000?ooooo`;o00000oooool0
0ol0003oooooooooo`0Dooooo`;o0000Xoooool0093ooooo0_l00004ooooo`;o00003oooool2o`00
00?ooooo00?o0000ooooooooool05?ooool2o`000:?ooooo0029ooooo`;o00004Oooool2o`0000ko
oooo00?o0000ooooooooool0^Oooool008;ooooo0_l00005ooooo`;o00004Oooool2o`0000kooooo
00?o0000ooooooooool05Oooool2o`00017ooooo0_l0002?ooooo`00P_ooool2o`0002Sooooo00?o
0000ooooooooool01oooool2o`0000cooooo0ol0000@ooooo`;o0000Soooool008Sooooo0_l0000R
ooooo`03o`000?oooooooooo00Oooooo0_l0000=ooooo`;o0000XOooool008Sooooo0_l0000Roooo
o`?o00005Oooool2o`0001Cooooo0ol0002;ooooo`00S_ooool2o`0001cooooo00?o0000oooooooo
ool05Oooool2o`0001Cooooo0ol0002;ooooo`00S_ooool2o`0000[ooooo0_l0000@ooooo`04o`00
0?oooooo0000o`0000Sooooo0_l0000Qooooo`;o0000Roooool008Sooooo0_l00003ooooo`;o0000
2oooool2o`00013ooooo00Co0000ooooool0003o00002?ooool2o`00027ooooo0_l0002;ooooo`00
R?ooool2o`0000?ooooo0_l00004ooooo`;o00001?ooool2o`00017ooooo00?o0000ooooooooool0
;Oooool2o`0008[ooooo002Cooooo`;o00001?ooool2o`0000Kooooo0ol00008ooooo`03o`000?oo
oooooooo00cooooo0_l0000Nooooo`?o0000R_ooool008Oooooo0_l00004ooooo`;o00004_ooool3
o`0000Sooooo00?o0000ooooooooool03?ooool2o`0001kooooo0ol0000Gooooo`;o0000LOooool0
08Oooooo0_l00004ooooo`;o00007Oooool00ol0003oooooooooo`16ooooo`;o0000LOooool009go
oooo0ol0000<ooooo`?o00000_ooool2o`000;Gooooo002Mooooo`?o00003?ooool00ol0003ooooo
ooooo`02ooooo`;o0000]Oooool00:cooooo00?o0000ooooooooool0<_ooool2o`0008Gooooo002/
ooooo`03o`000?oooooooooo037ooooo0ol00025ooooo`00P?ooool2o`0000[ooooo0_l0000Noooo
o`03o`000?oooooooooo013ooooo0_l0000Oooooo`;o0000Q_ooool0083ooooo0_l0000:ooooo`;o
00007_ooool00ol0003oooooooooo`0@ooooo`;o00007_ooool2o`0008Oooooo002@ooooo`;o0000
00Co<S8bo`000?l0003o00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo033ooooo0_l00027ooooo`00T?ooool2o`000004oiRHV?oooooo0000o`00
00Gooooo0_lQ8B48ooooo`;o00001Oooool00ol0003oooooooooo`0Cooooo`;o0000Y?ooool008Go
oooo0_l00002ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00oooooo0_l00005oooo
o`03o`000?oooooooooo01?ooooo0_l0002Tooooo`00QOooool2o`0000[ooooo00Go0000oooooooo
ooooooooo`00000=ooooo`;o000000?oMgMgoc8b<_ooool01?ooool3o`0003Gooooo0_l00022oooo
o`00TOooool01Ol0003ooooooooooooooooo000000cooooo0ol000000olb<S;oc<c<ooooo`02o`00
00;ooooo00Co0000ooooool0003o0000<_ooool4o`0008;ooooo002Aooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00ol0003oooooooooo`03ooooo`;o00000_ooool01?l0003oooooo`000?l0
000booooo`Co0000P_ooool0097ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oo
oooooooo00Oooooo00Co0000oooooooooooooooo0ol00006ooooo`;o00001oooool2o`0001kooooo
1Ol00021ooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`04o`00
0?ooooooooooooooo`?o00001_ooool2o`0000Oooooo0_l0000Oooooo`Co0000POooool00:cooooo
00?o0000ooooooooool00_ooool2o`00037ooooo0_l0000Iooooo`;o0000Ioooool00:cooooo00?o
0000ooooooooool00_ooool2o`0001oooooo0_l0000@ooooo`;o00006Oooool2o`0006Oooooo002/
ooooo`03o`000?oooooooooo00;ooooo0_l0000Oooooo`;o00005?ooool2o`0007kooooo002/oooo
o`?o00009Oooool2o`0001;ooooo0_l0001nooooo`00X_ooool2o`0000Sooooo0_l00004ooooo`;o
00004_ooool2o`0000_ooooo0ol0000@ooooo`;o0000P?ooool00:7ooooo0ol00008ooooo`03o`00
0?oooooooooo00?ooooo0_l0000Booooo`;o00002oooool2o`00017ooooo0_l000001?oooooo0000
o`000?l0001looooo`00XOooool2o`0000Gooooo0_l00002ooooo`03o`000?oooooooooo01Oooooo
0_l0000>ooooo`;o00004Oooool3o`0007cooooo002Xooooo`;o00000_ooool00ol0003ooooooooo
o`0Gooooo`;o00003_ooool2o`00017ooooo0_l0001mooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`06ooooo`;o00008Oooool2o`00017ooooo0_l0001koooo
o`00[?ooool00ol0003oooooooooo`06ooooo`;o00008Oooool2o`00017ooooo0_l0001kooooo`00
SOooool2o`0001gooooo0ol0002iooooo`00SOooool2o`0001gooooo00?o0000ooooooooool02?oo
ool2o`0000Kooooo0_l0002Wooooo`00T?ooool2o`00017ooooo0_l00007ooooo`03o`000?oooooo
oooo00Sooooo0_l00006ooooo`;o0000Yoooool0093ooooo0_l0000Aooooo`;o000000?oooooo`00
0?l000001?ooool00ol0003oooooooooo`0Looooo`;o00002oooool3o`0008gooooo002Gooooo`;o
00003Oooool2o`0000Cooooo00?o0000ooooooooool04_ooool2o`0000Sooooo0ol0000:ooooo`?o
0000SOooool009Oooooo0_l0000Cooooo`?o00004_ooool2o`0000Wooooo0_l0000;ooooo`;o0000
SOooool00:cooooo0ol0000Mooooo`;o0000V_ooool00:cooooo00?o0000ooooooooool07Oooool2
o`0002;ooooo0_l0001fooooo`00[?ooool3o`00047ooooo0_l0001fooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00O_ooool2o`0002cooooo00?o0000ooooooooool01?ooool2o`000;?ooooo
001nooooo`;o00004oooool2o`0001Oooooo00?o0000ooooooooool01?ooool2o`0000kooooo0_l0
0008ooooo`;o00008oooool2o`0007Cooooo002Cooooo`;o00005oooool00ol0003oooooooooo`0D
ooooo`;o00002?ooool3o`0001oooooo0_l000000ooooooo0000o`00001dooooo`00S?ooool2o`00
01kooooo00?o0000ooooooooool07oooool2o`0000cooooo0_l0000Aooooo`;o0000Moooool008co
oooo0_l0000Nooooo`03o`000?oooooooooo02gooooo0_l0000Eooooo`;o0000Loooool009;ooooo
0_l0000Hooooo`03o`000?oooooooooo04Cooooo0_l0001cooooo`00T_ooool2o`0001Sooooo00?o
0000ooooooooool0^Oooool009;ooooo0_l0000Hooooo`?o0000@_ooool2o`0007Gooooo002Boooo
o`;o00006?ooool00ol0003oooooooooo`0Gooooo`;o0000:Oooool2o`0007Gooooo002Mooooo`;o
00003Oooool00ol0003oooooooooo`0?ooooo`;o00001_ooool2o`000:3ooooo002Mooooo`;o0000
3Oooool00ol0003oooooooooo`0?ooooo`;o00001_ooool2o`0002_ooooo0_l0001cooooo`00Qooo
ool2o`00013ooooo0_l0000Aooooo`03o`000?oooooooooo01Oooooo0_l0000Hooooo`;o00004Ooo
ool2o`0007?ooooo0027ooooo`;o000000Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01Oooooo
0_l0000Hooooo`;o00004oooool2o`00077ooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool04?ooool2o`0000Gooooo0_l0000Zooooo`;o000000?oooooo`000?l0
0000LOooool0087ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41001Oooool2o`0000Go
oooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00oo
oooo0ol0000Booooo`;o00007Oooool2o`0007Cooooo0029ooooo`04o`000?ooooooooooooooo`;o
000000Coooooo`000?l0003ooooo0_l00006ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b
<_ooool01?ooool3o`0000oooooo0_l0000Cooooo`;o00003?ooool2o`0001;ooooo0_l0001aoooo
o`00ROooool01?l0003oooooooooooooool5o`0000[ooooo00?oMgMgofIVI_ooool00oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0<Oooool3o`0001;ooooo0_l0001a
ooooo`00ROooool01Ol@413ooooooooooooooooo410@00;o00003Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<Oooool2o`00017ooooo0_l0001c
ooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@
4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0A?ooool2o`0007?ooooo0029
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo
1?l00006ooooo`03o`000?oooooooooo013ooooo0_l0002Wooooo`00[?ooool00ol0003ooooooooo
o`0@ooooo`;o0000Yoooool00:cooooo0ol0000booooo`;o0000QOooool009Sooooo0_l00003oooo
o`;o00003Oooool3o`0001Wooooo0_l00009ooooo`;o00003?ooool2o`0008Gooooo002Hooooo`;o
00000oooool2o`0000gooooo0ol0000Iooooo`;o00002Oooool2o`0009?ooooo002/ooooo`03o`00
0?oooooooooo01[ooooo0_l0000Gooooo`;o0000Q?ooool00:cooooo00?o0000ooooooooool04_oo
ool2o`0000Kooooo0_l0000Gooooo`;o0000Q?ooool00:cooooo00?o0000ooooooooool03?ooool2
o`0000Cooooo0_l0000fooooo`;o0000KOooool008oooooo0_l0000Kooooo`03o`000?oooooooooo
00cooooo0_l0000looooo`;o0000KOooool008oooooo0_l0000Kooooo`03o`000?oooooooooo04[o
oooo0_l0001]ooooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool09oooool2o`00027ooooo
0_l0001]ooooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool04oooool2o`0001;ooooo0_l0
000>ooooo`;o0000P?ooool009Kooooo0_l0000Dooooo`?o00001oooool2o`0000[ooooo0_l00008
ooooo`;o00006?ooool2o`0001;ooooo0_l0001/ooooo`00ROooool2o`0000_ooooo0_l0000Doooo
o`03o`000?oooooooooo00Oooooo0_l0000Dooooo`;o0000;?ooool2o`0006cooooo0029ooooo`;o
00008Oooool00ol0003oooooooooo`04ooooo`;o0000/oooool00:cooooo00?o0000ooooooooool0
1?ooool2o`000;?ooooo0021ooooo`;o00002Oooool2o`0001kooooo00?o0000ooooooooool05?oo
ool2o`0001;ooooo0_l0000;ooooo`;o0000P_ooool0087ooooo0_l00009ooooo`;o00007_ooool0
1?l0003oooooooooooooool2o`0000[ooooo0_l00005ooooo`;o00004_ooool2o`0000_ooooo0_l0
0022ooooo`00[?ooool01?l0003oooooooooooooool2o`0000[ooooo0_l0002Zooooo`00[?ooool0
0ol0003oooooooooo`0eooooo`;o0000P_ooool008Wooooo0_l0000Qooooo`03o`000?oooooooooo
00Cooooo0_l0000_ooooo`;o0000P_ooool008Wooooo0_l0000Qooooo`?o00001?ooool2o`0000?o
oooo0_l0000Nooooo`;o00002oooool2o`00087ooooo002<ooooo`;o00007_ooool00ol0003ooooo
ooooo`09ooooo`;o00000oooool2o`0000Cooooo0_l0000Cooooo`?o00002_ooool2o`00087ooooo
002<ooooo`;o00007_ooool00ol0003oooooooooo`0>ooooo`;o00001?ooool3o`0001?ooooo0_l0
002=ooooo`002Oooool4o`000003oa0@4?oooooooooo01Kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
3oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM01Kooooo00?o0000ooooooooool00_ooool2o`00017ooooo0_l0
00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool0
1Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd06?ooool4o`000003
oa0@4?oooooooooo01;ooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4
A007ooooo`03ogMgMolb<S;ooooo01Gooooo00?o0000ooooooooool00_ooool2o`0001Cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oo
oooo00?oMgMgoc8b<_ooool03_ooool01_mgMgOoV9RHoooooonHV9SoMgMgooooo`;o00000_ooool2
ob4Q8@Sooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool06Oooool00ol0003ooooooooo
o`0Dooooo`001_l00005ooooo`03o`000?oooooooooo013ooooo1_l00002ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00Gooooo1_l0
0002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`05ooooo`Ko0000
0_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo01Sooooo00Go410@oooooooooooooooooa0@400<oooo
o`03oiRHV?lQ8B7ok^k^00Wooooo00Co0000oooooooooooooooo0_l0000:ooooo`06oa0@4?oooooo
ooooooooool@413ooooo0_l0000=ooooo`03o`000?oooooooooo00gooooo00Go410@oooooooooooo
oooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool0
00003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000oooooooo
ooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000=
ooooo`04oiRHV?lQ8B7o0000o`0000Kooooo00?oMgMgoc8b<_ooool05Oooool00ol0003ooooooooo
o`0Hooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMg
Molb<S;ooooo00;ooooo0_l0000:ooooo`06o`000?ooooooooooooooool0003ooooo0_l0000<oooo
o`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooo
oooo00Kooooo00?oMgMgoc8b<_ooool06Oooool00ol0003oooooooooo`0Dooooo`002oooool00ol0
003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000cooooo
00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003_ooool00omg
MgOo0000o`000003ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05_ooool00ol0003oooooooooo`0F
ooooo`?o00000oooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Jooooo`03o`000?oooooooooo01Cooooo000;oooo
o`03o`000?oooooooooo01Sooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOo
oooo00?ooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o
0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Hooooo`?o00005_ooool2o`000005oa0@4?ooooooooooooooool@
41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400>
ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0D
ooooo`002oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`04o`000?oooooo0000o`0001Oooooo00?o0000
ooooooooool05_ooool2o`000005ogMgMonHV9SooooooiRHV?mgMgL02oooool3o`000003oiRHV?l@
413ooooo00?ooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo
00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooo
oooooooooc8b<P04ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05?ooool000Wo
oooo00?oEEEEofIVI_l000006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004oooo
o`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0000Gooooo`03o`00
0?oooooooooo01Kooooo0_l000001Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHo`000?l0
003o0000olc<c004ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo0_l00007
ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00006Ooo
ool00omEEEGoIVIVo`00000Fooooo`00[?ooool00ol0003oooooooooo`0Zooooo`;o00008Oooool2
o`0006[ooooo002/ooooo`03o`000?oooooooooo01kooooo0_l0002Iooooo`00R?ooool2o`0002;o
oooo00?o0000ooooooooool07_ooool2o`0008kooooo0_l00002ooooo`;o00001Oooool008Sooooo
0_l0000Rooooo`03o`000?oooooooooo00Kooooo0_l00002ooooo`;o0000X_ooool01_o^k^ko8B4Q
ohN7Qonj^[[o0000omgMg@Gooooo002/ooooo`03o`000?oooooooooo00Kooooo0_l00002ooooo`;o
0000Xoooool01?oMgMgo0000oa0@4?o<c<`6ooooo`001oooooooo`0004co00003?ooool01?o^k^ko
8B4Qoa0@4?o^k^h6ooooo`001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?o
oooo0_l000000ooooooo0000ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo0ol00005ooooo`;o
00001_ooool3o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`?o
00001Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0:ooooo`04ob4Q8OmgMgOoMgMgoc8b<PKooooo0007ooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool00_l0000Dooooo`;o00003oooool00ol0003o
ooooooooo`0>ooooo`;o00005_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool02Oooool2o`0000;ooooo0_l00005ooooo`00ROooool2o`00027ooooo
00?o0000ooooooooool00_l00004ooooo`;o0000/Oooool0083ooooo0_l00007ooooo`;o00008Ooo
ool00ol0003oooooooooo`06ooooo`;o00001oooool2o`000:Sooooo0020ooooo`;o0000:_ooool0
0ol0003oooooooooo`0?ooooo`;o0000:?ooool2o`00013ooooo0_l0001/ooooo`00P?ooool2o`00
01;ooooo0_l0000Fooooo`03o`000?oooooooooo03Sooooo0ol0000@ooooo`;o0000K?ooool008Wo
oooo0_l00009ooooo`;o00005_ooool00ol0003oooooooooo`0hooooo`?o0000O_ooool0087ooooo
0_l00006ooooo`;o00008Oooool3o`0002Wooooo0_l0000>ooooo`;o00004oooool2o`0006Wooooo
0021ooooo`;o00004oooool2o`0001Cooooo00?o0000ooooooooool0:Oooool2o`0002?ooooo0_l0
001Yooooo`00U_ooool2o`0001Cooooo00?o0000ooooooooool00_ooool2o`0001Wooooo0_l0002J
ooooo`00POooool2o`0002Wooooo00Go0000ooooool0003o0000ooooo`02o`0001Wooooo0_l0000J
ooooo`;o0000O_ooool0087ooooo0_l0000Yooooo`04o`000?oooooo0000o`0000kooooo0_l0000=
ooooo`;o00002Oooool2o`0000kooooo0_l0001nooooo`00U_ooool2o`0001Cooooo00?o0000oooo
ooooool03oooool2o`0000gooooo0_l00009ooooo`;o0000S_ooool008oooooo1?l00003ooooo`;o
00005?ooool00ol0003oooooooooo`0gooooo`;o00005?ooool2o`0006[ooooo002?ooooo`Co0000
6Oooool00ol0003oooooooooo`0Yooooo`;o00003?ooool2o`0001Cooooo0ol0001Yooooo`00[?oo
ool00ol0003oooooooooo`0Yooooo`;o00003_ooool3o`0001;ooooo0_l0001Yooooo`00T_ooool2
o`0001Sooooo0ol0000Eooooo`;o00008_ooool3o`0007gooooo002Booooo`;o00006?ooool00ol0
003oooooooooo`05ooooo`;o00002?ooool2o`0000Cooooo0_l0002Rooooo`00V?ooool2o`0001;o
oooo00?o0000ooooooooool01Oooool2o`0000Sooooo0_l00003ooooo`;o0000Xoooool009Sooooo
0_l0000Booooo`03o`000?oooooooooo01Cooooo0_l0002Sooooo`00Q_ooool2o`0000Cooooo0_l0
000Nooooo`03o`000?oooooooooo02Wooooo0_l0002>ooooo`00Q_ooool2o`000004ooooool0003o
0000ooooo`;o00007_ooool00ol0003oooooooooo`0Nooooo`;o00002Oooool2o`0008kooooo0029
ooooo`;o00008Oooool3o`0001gooooo0ol0000/ooooo`?o0000J_ooool00:cooooo0ol00004oooo
o`;o00003oooool2o`0000Kooooo0_l0000]ooooo`?o0000J_ooool008Kooooo0_l0000Tooooo`?o
00001?ooool2o`0000oooooo0_l0000Pooooo`;o0000P?ooool008Kooooo0_l0000Tooooo`03o`00
0?oooooooooo03Oooooo0_l00020ooooo`00[?ooool00ol0003oooooooooo`08ooooo`;o0000;_oo
ool2o`0007oooooo0021ooooo`;o0000:Oooool00ol0003oooooooooo`08ooooo`;o0000;_ooool3
o`0007kooooo0021ooooo`;o0000:Oooool00ol0003oooooooooo`08ooooo`;o00000oooool2o`00
02Oooooo1Ol0001nooooo`00[?ooool00ol0003oooooooooo`0=ooooo`;o00009oooool4o`0001;o
oooo0_l0001[ooooo`00[?ooool00ol0003oooooooooo`1<ooooo`;o0000Joooool009Oooooo0_l0
000Cooooo`03o`000?oooooooooo0;Wooooo002Gooooo`;o00004oooool3o`0001Cooooo0_l0000Q
ooooo`;o0000P?ooool0087ooooo0_l0000@ooooo`;o00005oooool00ol0003oooooooooo`0Doooo
o`;o00004?ooool2o`0000oooooo0_l00020ooooo`00POooool2o`00013ooooo0_l0000Gooooo`03
o`000?oooooooooo02Kooooo0_l0000Tooooo`;o0000Joooool00:cooooo00?o0000ooooooooool0
BOooool2o`000003ooooool0003o000006_ooooo002/ooooo`03o`000?oooooooooo00gooooo0_l0
000jooooo`;o0000K_ooool009Kooooo0_l0000Dooooo`03o`000?oooooooooo00gooooo0_l0000=
ooooo`;o0000Voooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q00Cooooo
o`000?l0003ooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`0Looooo`;o0000Voooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo0_l00002ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0^Oooool008Wooooo00Go410@oooooooooooooooooa0@400<ooooo`03
oiRHV?lQ8B7ok^k^00Cooooo0_l00003ooooo`03o`000?oooooooooo00?ooooo0ol000000ooooooo
0000o`00000cooooo`;o0000POooool008Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03
oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool01?l0003oooooooooooooool2o`00
03?ooooo0_l00021ooooo`00ROooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool06_ooool2
o`0002cooooo0_l0001_ooooo`00ROooool01Ol@413ooooooooooooooooo410@00?ooooo0_l0000:
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0J
ooooo`;o00006?ooool2o`0001;ooooo0_l0001_ooooo`00ROooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo0_l00006ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo017ooooo0_l0000Qooooo`Co00004?ooool2o`0006oooooo0029
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo
1?l00006ooooo`03o`000?oooooooooo017ooooo0_l0000Sooooo`;o00004?ooool2o`0006oooooo
002;ooooo`;o00002?ooool2o`0001Gooooo00?o0000ooooooooool02Oooool2o`0001Wooooo0_l0
000?ooooo`;o0000P_ooool008_ooooo0_l00008ooooo`;o00005Oooool00ol0003oooooooooo`09
ooooo`;o00001_ooool2o`00017ooooo0_l0000?ooooo`;o0000P_ooool009_ooooo0_l0000?oooo
o`03o`000?oooooooooo017ooooo0_l0002Vooooo`00T_ooool2o`0000Oooooo0_l0000?ooooo`?o
0000BOooool2o`0006kooooo002Booooo`;o00001?ooool2o`0001;ooooo00?o0000ooooooooool0
BOooool2o`0006kooooo002Hooooo`;o00004_ooool00ol0003oooooooooo`0cooooo`;o0000Q?oo
ool00:cooooo00?o0000ooooooooool0<oooool2o`0001;ooooo0_l0001`ooooo`00[?ooool00ol0
003oooooooooo`16ooooo`?o0000L?ooool009[ooooo0_l00002ooooo`;o00003?ooool00ol0003o
ooooooooo`0Gooooo`;o00002_ooool2o`00027ooooo0_l0001aooooo`00T?ooool2o`0000Sooooo
0_l00002ooooo`;o00003?ooool00ol0003oooooooooo`0Gooooo`;o00002_ooool2o`0009Cooooo
002@ooooo`;o00006_ooool00ol0003oooooooooo`0Qooooo`;o0000U_ooool00:Kooooo0_l00003
ooooo`Co000000?oooooo`000?l000007_ooool2o`0009Kooooo002Dooooo`;o00004?ooool2o`00
00?ooooo0_l00003ooooo`;o00002Oooool2o`000:_ooooo002Dooooo`;o00005Oooool2o`0000;o
oooo0_l0000:ooooo`;o0000Zoooool00:_ooooo0_l00002ooooo`;o00001?ooool2o`0002Wooooo
0_l00026ooooo`00[?ooool00ol0003oooooooooo`06ooooo`;o0000:Oooool2o`0008Kooooo002Z
ooooo`?o0000^oooool0097ooooo0_l0000Gooooo`?o00008_ooool2o`0009Oooooo002Aooooo`;o
00000_ooool2o`000003ooooool0003o000001;ooooo00?o0000ooooooooool05?ooool2o`0000[o
oooo0_l0000>ooooo`;o0000Qoooool009Gooooo0_l000000ooooooo0000o`00000Booooo`?o0000
5?ooool2o`0000[ooooo0_l0000<ooooo`Co0000Qoooool009Wooooo0_l0000Aooooo`03o`000?oo
oooooooo00?ooooo0_l00005ooooo`;o00004_ooool2o`0000kooooo0_l00029ooooo`00VOooool2
o`0000Cooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`03ooooo`;o00001Oooool2
o`0001;ooooo0_l0002Iooooo`00Woooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo
0;Wooooo002>ooooo`;o00001_ooool2o`0000gooooo0_l00005ooooo`03o`000?oooooooooo02go
oooo0_l0002:ooooo`00S_ooool2o`0000Kooooo0_l0000Dooooo`03o`000?oooooooooo00Sooooo
0_l0000Qooooo`Co0000R_ooool008kooooo0_l0000Looooo`03o`000?oooooooooo00Sooooo0_l0
000Qooooo`;o0000S?ooool00:cooooo00?o0000ooooooooool0:oooool2o`0008cooooo002/oooo
o`?o0000^Oooool008[ooooo0_l0000Pooooo`04o`000?oooooo0000o`0000oooooo0_l0002Woooo
o`00R_ooool2o`00023ooooo00Co0000ooooool0003o00003oooool2o`0000Sooooo0_l0002Moooo
o`00Toooool2o`0001?ooooo0_l00002ooooo`03o`000?oooooooooo01[ooooo0_l0000=ooooo`Co
0000S?ooool009?ooooo0_l0000Cooooo`;o00000_ooool00ol0003oooooooooo`0Yooooo`Co0000
S?ooool00:3ooooo0_l00002ooooo`;o00001_ooool00ol0003oooooooooo`0?ooooo`;o00006Ooo
ool2o`0008gooooo002@ooooo`;o000000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@?ooooo1_l0
00000ooMgMgoooooooooo`03ooooo`03o`000?oooooooooo00oooooo0_l0002Xooooo`00T?ooool2
o`000004oiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B45ooooo`;o000000?oooooogMgMolb<S801Ooo
ool00ol0003oooooooooo`05ooooo`;o0000/_ooool008Kooooo0_l00009ooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`;o00001Oooool3o`000;;ooooo0026
ooooo`;o00001?ooool2o`0000?ooooo00Co0000oooooooooooooooo0ol0000=ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol00002ooooo`Co00008?ooool2o`00097ooooo002<ooooo`;o00000oooool0
1?l0003oooooooooooooool3o`0000[ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo00;ooooo0_l0000Rooooo`;o0000TOooool0097ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0^Oooool0087ooooo0_l0
000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0;Wooooo0021ooooo`;o00003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;o0000
1Oooool2o`0000?ooooo1?l00006ooooo`03o`000?oooooooooo0;Wooooo002Fooooo`;o00001Ooo
ool2o`0000gooooo00?o0000ooooooooool02_ooool2o`0002cooooo0_l0001oooooo`00X?ooool2
o`0000Cooooo0_l00004ooooo`03o`000?oooooooooo00[ooooo0_l00009ooooo`;o00003Oooool2
o`0001;ooooo0_l0001oooooo`00T_ooool2o`0000cooooo0_l00004ooooo`;o00001?ooool00ol0
003oooooooooo`0Eooooo`;o00003Oooool2o`00017ooooo0_l00020ooooo`00T_ooool2o`0001So
oooo0ol0000gooooo`;o0000P?ooool009Wooooo0_l0000Aooooo`03o`000?oooooooooo0;Wooooo
002Iooooo`;o00004Oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o
0000/oooool008Wooooo0_l00003ooooo`;o00007?ooool00ol0003oooooooooo`04ooooo`;o0000
/oooool008Wooooo0_l00003ooooo`;o00007?ooool00ol0003oooooooooo`2iooooo`00[?ooool3
o`000;Wooooo002/ooooo`03o`000?oooooooooo00kooooo1?l0002Wooooo`00Y?ooool2o`0000Ko
oooo00?o0000ooooooooool03_ooool4o`0000gooooo0_l0002Hooooo`00U_ooool2o`0000cooooo
0_l00006ooooo`03o`000?oooooooooo01oooooo0_l0002Hooooo`00U_ooool3o`0000cooooo0_l0
0005ooooo`03o`000?oooooooooo037ooooo0_l00026ooooo`00Poooool2o`00017ooooo0ol0000;
ooooo`?o00001Oooool00ol0003oooooooooo`0aooooo`;o0000Q_ooool008?ooooo0_l0000Ooooo
o`;o00001_ooool00ol0003oooooooooo`0;ooooo`?o00003?ooool2o`0009gooooo002Aooooo`;o
00006Oooool00ol0003oooooooooo`02o`0000Wooooo0ol0000<ooooo`;o00005?ooool2o`0008Oo
oooo002Aooooo`;o00001Oooool2o`0001;ooooo1Ol0000^ooooo`;o0000Qoooool0097ooooo0_l0
0005ooooo`;o00004_ooool00ol0003oooooooooo`0<ooooo`;o0000Zoooool008_ooooo0_l0000O
ooooo`03o`000?oooooooooo00cooooo0_l0002[ooooo`00Roooool2o`0001oooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool009cooooo0_l0000=ooooo`;o0000
^oooool009cooooo0_l0000=ooooo`;o0000^oooool00:_ooooo0_l00007ooooo`Co00003?ooool2
o`000:;ooooo002Oooooo`;o00000_ooool2o`0000Kooooo0_l00007ooooo`Co00003?ooool3o`00
0:7ooooo002Oooooo`;o00000_ooool2o`0000Oooooo0ol0000Fooooo`;o0000XOooool009Cooooo
0_l0000Fooooo`03o`000?oooooooooo00Cooooo0_l0000>ooooo`Co0000XOooool009Cooooo0_l0
000Fooooo`03o`000?oooooooooo00Cooooo0_l0000>ooooo`;o0000Xoooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool04_ooool2o`000:Gooooo0029ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool04_ooool2o`000:Gooooo0029oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@03ooooool0003o000000?ooooo00?oEEEE
ojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00oooooo0_l0002X
ooooo`00ROooool01Ol@413ooooooooooooooooo410@00Sooooo0_l00003ooooo`03ojVYZOmEEEGo
oooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooo`000003o`0000cooooo0_l0002X
ooooo`00ROooool01Ol0003ooooooooooooooooo000000Wooooo0_l00003ooooo`03ob4Q8Ooooooo
oooo00Kooooo00?oMgMgoc8b<_ooool01?ooool6o`0000_ooooo0_l0002Yooooo`00ROooool01Ol0
003ooooooooooooooooo000000Wooooo0_l00003ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00;o00003?ooool2o`000:Wooooo0029
ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0^Oooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`;o0000
^_ooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo
0_l0002jooooo`00TOooool2o`0001Wooooo00?o0000ooooooooool03?ooool2o`000:_ooooo002A
ooooo`;o00006Oooool00ol0003oooooooooo`0<ooooo`;o0000Zoooool0097ooooo0_l0000<oooo
o`;o00002oooool00ol0003oooooooooo`2iooooo`00Woooool2o`0000Sooooo0_l000001?oooooo
0000o`000?l0002iooooo`00ZOooool2o`000003ooooool0003ooooo0;[ooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`2iooooo`00U?ooool2o`0001Ko
oooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool00oooool2o`000;Cooooo
002/ooooo`?o00000oooool2o`000;Cooooo002<ooooo`;o00007_ooool00ol0003oooooooooo`2i
ooooo`00S?ooool2o`0001kooooo00Co0000oooooooooooooooo0_l0002fooooo`00[?ooool00ol0
003oooooooooo`03o`000;Kooooo002/ooooo`03o`000?oooooooooo00;o0000]oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool04Oooool4o`000:Cooooo002/ooooo`03o`000?oooooooooo017ooooo1?l0002Toooo
o`00Z?ooool2o`0000;ooooo0ol0000Aooooo`;o0000Y_ooool00:Sooooo0_l00002ooooo`03o`00
0?oooooooooo017ooooo0_l0002Vooooo`00[?ooool00ol0003oooooooooo`2iooooo`00WOooool3
o`0000Kooooo0_l00004ooooo`03o`000?oooooooooo0;Wooooo002Mooooo`?o00001_ooool4o`00
00;ooooo00?o0000ooooooooool0^Oooool00:3ooooo0_l00006ooooo`;o00000_ooool00ol0003o
ooooooooo`2iooooo`00X?ooool2o`0000[ooooo00?o0000ooooooooool0^Oooool00:cooooo00?o
0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00U?oo
ool2o`0001Kooooo00?o0000ooooooooool0^Oooool009Cooooo0_l0000Fooooo`03o`000?oooooo
oooo00Gooooo0_l0002booooo`00X_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooo
ooooool01Oooool2o`000;;ooooo002Tooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0^Oooool00:Cooooo00?o0000ooooooooool01Oooool3o`000;Wooooo002Tooooo`03o`000?oo
oooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo
0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Rooooo`03oeEEEOmVIVKo00000<?ooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Zooooo`04oa0@
4?l0003o0000o`000;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oo
oooooooo0;[ooooo002[ooooo`06o`000?mgMgOo0000o`000?mEEEGok^k^]oooool00:_ooooo00Ko
0000oeEEEOo^k^koooooogMgMomEEEFgooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03o`00
0?oooooooooo0;Gooooo002[ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0]Ooo
ool00:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomVIVJgooooo`00Z_ooool00ol@413o0000ogMg
M`02o`000003ofIVI_o^k^kooooo0;Kooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.64091 .56971 Mdot
.5582 .81326 Mdot
.45675 .6089 Mdot
.42038 .43464 Mdot
.5396 .72011 Mdot
.56622 .23737 Mdot
.48887 .33799 Mdot
.40671 .11378 Mdot
.4204 .90471 Mdot
.5256 .69756 Mdot
.41855 .63248 Mdot
.4904 .0127 Mdot
.37978 .4713 Mdot
.46051 .77817 Mdot
.52537 .05375 Mdot
.53087 .33701 Mdot
.57124 .70318 Mdot
.38133 .41375 Mdot
.56352 .37254 Mdot
.67712 .38463 Mdot
.38824 .33027 Mdot
.46388 .91036 Mdot
.418 .82357 Mdot
.39108 .29479 Mdot
.62305 .17043 Mdot
.454 .17685 Mdot
.42056 .34939 Mdot
.55577 .35268 Mdot
.68666 .43536 Mdot
.54279 .83452 Mdot
.42358 .1464 Mdot
.42643 .92263 Mdot
.37749 .28735 Mdot
.47633 .85796 Mdot
.3943 .57986 Mdot
.6398 .30258 Mdot
.64621 .72987 Mdot
.51381 .25427 Mdot
.68814 .49891 Mdot
.51273 .03016 Mdot
.62036 .16005 Mdot
.42335 .78237 Mdot
.45454 .13577 Mdot
.63977 .60353 Mdot
.64601 .49669 Mdot
.42863 .75161 Mdot
.47019 .7786 Mdot
.51582 .94193 Mdot
.58936 .3665 Mdot
.68209 .43258 Mdot
.5197 .93583 Mdot
.68937 .57101 Mdot
.40067 .92884 Mdot
.408 .28173 Mdot
.41348 .24424 Mdot
.37248 .63594 Mdot
.41979 .07484 Mdot
.57656 .69277 Mdot
.58707 .84452 Mdot
.64394 .46693 Mdot
.41158 .66079 Mdot
.74848 .45999 Mdot
.68675 .51397 Mdot
.54395 .47536 Mdot
.38088 .27139 Mdot
.39385 .81099 Mdot
.5324 .67615 Mdot
.51434 .29865 Mdot
.51683 .25678 Mdot
.41574 .16392 Mdot
.56102 .73994 Mdot
.50392 .63639 Mdot
.51594 .71839 Mdot
.55561 .57928 Mdot
.6867 .51364 Mdot
.48221 .35706 Mdot
.40005 .92664 Mdot
.40791 .37501 Mdot
.6922 .5353 Mdot
.57108 .32921 Mdot
.54078 .1386 Mdot
.54861 .82362 Mdot
.42114 .56375 Mdot
.41479 .74884 Mdot
.37069 .35689 Mdot
.53869 .354 Mdot
.53087 .74037 Mdot
.48386 .81427 Mdot
.59446 .63833 Mdot
.52002 .31341 Mdot
.62961 .18155 Mdot
.64293 .85203 Mdot
.52837 .63972 Mdot
.46239 .8175 Mdot
.53845 .58886 Mdot
.67169 .80856 Mdot
.46865 .78341 Mdot
.50457 .94977 Mdot
.38489 .8654 Mdot
.59492 .64435 Mdot
.63288 .61762 Mdot
.60846 .56565 Mdot
.49146 .01592 Mdot
.62953 .64671 Mdot
.49277 .07718 Mdot
.45586 .84915 Mdot
.53792 .78359 Mdot
.57761 .43606 Mdot
.52722 .64434 Mdot
.42245 .14349 Mdot
.4978 .76351 Mdot
.4182 .4883 Mdot
.43201 .9334 Mdot
.65019 .31414 Mdot
.53195 .49293 Mdot
.40218 .52018 Mdot
.37894 .72207 Mdot
.39777 .83414 Mdot
.64628 .72071 Mdot
.38003 .47163 Mdot
.73644 .39141 Mdot
.38198 .50652 Mdot
.68913 .44369 Mdot
.42187 .14428 Mdot
.43389 .32522 Mdot
.66212 .3489 Mdot
.70128 .75031 Mdot
.59328 .7338 Mdot
.4892 .70407 Mdot
.42416 .84652 Mdot
.6177 .67365 Mdot
.53633 .05922 Mdot
.57507 .25016 Mdot
.49833 .1362 Mdot
.69401 .49741 Mdot
.66494 .69205 Mdot
.67796 .40078 Mdot
.51991 .70793 Mdot
.40429 .13207 Mdot
.53358 .06098 Mdot
.74589 .57315 Mdot
.45774 .7388 Mdot
.53972 .3043 Mdot
.57129 .70397 Mdot
.66549 .34962 Mdot
.36628 .50307 Mdot
.57044 .01757 Mdot
.5779 .47903 Mdot
.46317 .81432 Mdot
.72608 .34496 Mdot
.61114 .53859 Mdot
.46012 .21224 Mdot
.39325 .27545 Mdot
.51344 .5932 Mdot
.61253 .34692 Mdot
.67348 .65578 Mdot
.68863 .53315 Mdot
.378 .70929 Mdot
.64374 .73271 Mdot
.67176 .66422 Mdot
.52717 .22349 Mdot
.69366 .5332 Mdot
.60675 .13374 Mdot
.61009 .24476 Mdot
.45514 .13886 Mdot
.63332 .60414 Mdot
.36703 .54543 Mdot
.52087 .10776 Mdot
.50643 .23757 Mdot
.67809 .64995 Mdot
.67015 .38923 Mdot
.50813 .69456 Mdot
.47623 .20787 Mdot
.52566 .74737 Mdot
.58026 .51562 Mdot
.38384 .2414 Mdot
.68125 .79056 Mdot
.60816 .33567 Mdot
.52924 .47557 Mdot
.6876 .45722 Mdot
.68786 .60607 Mdot
.5526 .07347 Mdot
.56092 .48429 Mdot
.63122 .17505 Mdot
.4292 .58061 Mdot
.42954 .92395 Mdot
.70156 .74646 Mdot
.43971 .95074 Mdot
.59626 .1215 Mdot
.47747 .12182 Mdot
.72135 .34385 Mdot
.66548 .34835 Mdot
.52857 .3828 Mdot
.74261 .43632 Mdot
.38407 .22736 Mdot
.66636 .22467 Mdot
.511 .03316 Mdot
.48026 .81963 Mdot
.59831 .91841 Mdot
.49049 .85989 Mdot
.50688 .3549 Mdot
.51215 .37317 Mdot
.49273 .67077 Mdot
.54385 .70489 Mdot
.56947 .95301 Mdot
.62497 .64481 Mdot
.46529 .27799 Mdot
.58652 .27787 Mdot
.41796 .5271 Mdot
.42874 .40701 Mdot
.41419 .59311 Mdot
.39987 .75696 Mdot
.4043 .42497 Mdot
.52361 .11134 Mdot
.55537 .44127 Mdot
.63046 .61774 Mdot
.403 .52171 Mdot
.61236 .14202 Mdot
.42747 .56925 Mdot
.63744 .44173 Mdot
.48363 .006 Mdot
.4034 .56234 Mdot
.5702 .86512 Mdot
.50202 .08473 Mdot
.56917 .17928 Mdot
.54346 .3871 Mdot
.56945 .62498 Mdot
.58009 .77759 Mdot
.51606 .67481 Mdot
.52869 .05698 Mdot
.74183 .40575 Mdot
.49541 .25441 Mdot
.4478 .61073 Mdot
.55708 .96399 Mdot
.60601 .46674 Mdot
.41686 .3749 Mdot
.72923 .37023 Mdot
.49549 .22093 Mdot
.6217 .67486 Mdot
.38212 .55487 Mdot
.62348 .65529 Mdot
.74775 .46217 Mdot
.52774 .17373 Mdot
.56564 .16442 Mdot
.56185 .73799 Mdot
.42453 .92101 Mdot
.54129 .55965 Mdot
.67291 .64513 Mdot
.59972 .58978 Mdot
.56563 .72962 Mdot
.68795 .51705 Mdot
.65874 .21394 Mdot
.5314 .48323 Mdot
.52818 .38579 Mdot
.66299 .67683 Mdot
.46604 .16839 Mdot
.46697 .21115 Mdot
.43276 .17004 Mdot
.49244 .37417 Mdot
.40898 .11027 Mdot
.55107 .89729 Mdot
.60049 .41658 Mdot
.4163 .38017 Mdot
.58481 .20228 Mdot
.51873 .6163 Mdot
.61007 .528 Mdot
.64214 .53066 Mdot
.45231 .75994 Mdot
.53866 .19762 Mdot
.65508 .34248 Mdot
.512 .20425 Mdot
.64971 .31988 Mdot
.42571 .19348 Mdot
.52936 .69 Mdot
.58678 .36988 Mdot
.67656 .64731 Mdot
.56223 .50416 Mdot
.58291 .54563 Mdot
.50043 .95792 Mdot
.41905 .64352 Mdot
.60509 .32273 Mdot
.69098 .48376 Mdot
.48104 .71802 Mdot
.55884 .52613 Mdot
.64271 .73331 Mdot
.46767 .01168 Mdot
.57944 .44684 Mdot
.52041 .49267 Mdot
.56641 .62242 Mdot
.62942 .26577 Mdot
.44538 .79265 Mdot
.51751 .11001 Mdot
.70063 .74687 Mdot
.59418 .83024 Mdot
.48864 .01763 Mdot
.5866 .83867 Mdot
.44559 .38967 Mdot
.61509 .80054 Mdot
.73476 .40943 Mdot
.60513 .2212 Mdot
.51219 .03977 Mdot
.61853 .06648 Mdot
.5767 .33499 Mdot
.48297 .11849 Mdot
.61473 .68587 Mdot
.4241 .91883 Mdot
.61174 .15153 Mdot
.45452 .76622 Mdot
.50293 .9537 Mdot
.48179 .16597 Mdot
.4668 .30604 Mdot
.40225 .76705 Mdot
.56132 .72889 Mdot
.38052 .52945 Mdot
.71781 .3247 Mdot
.53084 .53201 Mdot
.64076 .47315 Mdot
.4459 .8369 Mdot
.39453 .18196 Mdot
.51648 .63002 Mdot
.5613 .08419 Mdot
.70463 .31542 Mdot
.74431 .612 Mdot
.46996 .24332 Mdot
.57828 .25385 Mdot
.41139 .73381 Mdot
.68582 .55286 Mdot
.5691 .63261 Mdot
.49206 .3119 Mdot
.46461 .33409 Mdot
.55066 .75777 Mdot
.45182 .01668 Mdot
.66374 .66938 Mdot
.54043 .57892 Mdot
.42642 .85831 Mdot
.48056 .71426 Mdot
.49015 .67551 Mdot
.57457 .78751 Mdot
.55497 .21678 Mdot
.4568 .13687 Mdot
.52756 .22464 Mdot
.55123 .68366 Mdot
.48334 .16902 Mdot
.56488 .79293 Mdot
.54362 .4831 Mdot
.36839 .43393 Mdot
.41489 .40542 Mdot
.67394 .38717 Mdot
.51121 .87702 Mdot
.49609 .73105 Mdot
.41891 .69721 Mdot
.74697 .56788 Mdot
.48127 .0079 Mdot
.62054 .79361 Mdot
.64723 .31856 Mdot
.56459 .3011 Mdot
.49732 .84965 Mdot
.66691 .3745 Mdot
.60913 .49724 Mdot
.48053 .00816 Mdot
.74525 .62217 Mdot
.57347 .17548 Mdot
.53207 .05528 Mdot
.5697 .09409 Mdot
.62772 .16591 Mdot
.46004 .67868 Mdot
.60127 .43031 Mdot
.53756 .06606 Mdot
.41192 .09899 Mdot
.45151 .66045 Mdot
.48278 .07554 Mdot
.48593 .17345 Mdot
.58942 .28104 Mdot
.63576 .60251 Mdot
.48355 .96764 Mdot
.62242 .67144 Mdot
.6308 .76588 Mdot
.67571 .61948 Mdot
.42787 .85267 Mdot
.63625 .76447 Mdot
.43293 .86761 Mdot
.59789 .13613 Mdot
.63065 .75553 Mdot
.61952 .36357 Mdot
.51669 .56364 Mdot
.68161 .26374 Mdot
.59965 .61999 Mdot
.45802 .34617 Mdot
.56088 .0814 Mdot
.42072 .14721 Mdot
.48651 .30305 Mdot
.54953 .61314 Mdot
.42163 .26906 Mdot
.42645 .30879 Mdot
.50123 .95966 Mdot
.51225 .09328 Mdot
.74016 .42979 Mdot
.56 .08167 Mdot
.52247 .80517 Mdot
.50648 .83354 Mdot
.58062 .50213 Mdot
.58077 .54772 Mdot
.49506 .63278 Mdot
.44175 .03027 Mdot
.48517 .01045 Mdot
.41801 .36995 Mdot
.49785 .72447 Mdot
.4161 .36876 Mdot
.55277 .41069 Mdot
.69756 .28232 Mdot
.47672 .82306 Mdot
.60737 .23731 Mdot
.44157 .70019 Mdot
.4671 .20711 Mdot
.50902 .65538 Mdot
.50408 .79339 Mdot
.49446 .84603 Mdot
.4312 .28239 Mdot
.47795 .27308 Mdot
.73177 .36855 Mdot
.40049 .1471 Mdot
.50289 .50844 Mdot
.39208 .50512 Mdot
.53746 .78424 Mdot
.62656 .40238 Mdot
.50605 .19794 Mdot
.48742 .21097 Mdot
.68514 .26731 Mdot
.65382 .84187 Mdot
.6114 .70091 Mdot
.38926 .10243 Mdot
.636 .6267 Mdot
.49878 .29513 Mdot
.3979 .82163 Mdot
.5486 .07882 Mdot
.41379 .57706 Mdot
.5081 .87984 Mdot
.48685 .74115 Mdot
.46102 .30909 Mdot
.57817 .55104 Mdot
.58022 .19356 Mdot
.5551 .28798 Mdot
.61918 .88895 Mdot
.4252 .48985 Mdot
.39405 .43485 Mdot
.43152 .81015 Mdot
.54484 .53702 Mdot
.53039 .52455 Mdot
.56032 .5483 Mdot
.40868 .10739 Mdot
.52735 .57635 Mdot
.69324 .51309 Mdot
.58166 .7709 Mdot
.64395 .49287 Mdot
.65582 .33291 Mdot
.49012 .0807 Mdot
.54375 .76707 Mdot
.70695 .74396 Mdot
.54587 .6303 Mdot
.45818 .01095 Mdot
.65736 .21022 Mdot
.44966 .75408 Mdot
.61691 .79865 Mdot
.50937 .20177 Mdot
.58157 .66808 Mdot
.67269 .38117 Mdot
.63336 .61852 Mdot
.56988 .40015 Mdot
.41733 .68886 Mdot
.48094 .85807 Mdot
.75068 .45136 Mdot
.49547 .13545 Mdot
.47426 .35238 Mdot
.43858 .1649 Mdot
.57472 .33695 Mdot
.46695 .68834 Mdot
.48543 .24746 Mdot
.4033 .31379 Mdot
.48685 .12407 Mdot
.52445 .42524 Mdot
.44571 .19541 Mdot
.39103 .7958 Mdot
.54691 .70382 Mdot
.64182 .5036 Mdot
.52636 .27146 Mdot
.55577 .35871 Mdot
.43302 .55132 Mdot
.43152 .507 Mdot
.56658 .80032 Mdot
.56111 .87471 Mdot
.61479 .25202 Mdot
.52792 .27945 Mdot
.68267 .42379 Mdot
.53146 .05127 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool01?l0003oooooo`000?l00004ooooo`03o`000?oooooooooo0;Wo
oooo002Tooooo`Go00000oooool00ol0003oooooooooo`2iooooo`00W_ooool2o`000004ooooool0
003o0000ooooo`Ko00000_ooool00ol0003oooooooooo`2iooooo`00W?ooool4o`000005ooooool0
003o0000ofIVI_l000000oooool3o`000003ooooool0003ooooo0;[ooooo002Looooo`;o00002_oo
ool3o`000003ooooool0003ooooo01Gooooo0_l0002Sooooo`00Z?ooool2o`0000;ooooo00?o0000
ooooooooool05?ooool2o`000:?ooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool009Sooooo0_l0000Booooo`04o`000?ooooooooooooooo`;o0000]_ooool009Sooooo
0_l0000Booooo`03o`000?oooooooooo00?o0000]_ooool00:cooooo00?o0000ooooooooool00_l0
002gooooo`00[?ooool01?l0003oooooooooooooool2o`000;Kooooo002/ooooo`04o`000?oooooo
ooooooooo`;o0000]_ooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo0ol00007ooooo`;o0000/?ooool00:cooooo00?o0000ooooooooool0
1Oooool4o`000;3ooooo002/ooooo`03o`000?oooooooooo00Gooooo1_l0002^ooooo`00[?ooool0
0ol0003oooooooooo`06ooooo`Go0000[_ooool00:cooooo00?o0000ooooooooool02?ooool2o`00
0:oooooo002/ooooo`03o`000?oooooooooo00Wooooo0_l0000Iooooo`;o0000Toooool00:cooooo
00?o0000ooooooooool02Oooool2o`0001Wooooo0_l0002Cooooo`00[?ooool00ol0003ooooooooo
o`0>ooooo`;o0000ZOooool0097ooooo0_l0000Cooooo`;o000000Coooooo`000?l0003ooooo0ol0
000>ooooo`;o0000ZOooool0097ooooo0_l0000Cooooo`;o000000Goooooo`000?l0003oooooo`00
000?ooooo`;o0000Z_ooool00:Sooooo0_l00002ooooo`03o`000?oooooooooo00gooooo0_l00000
1?oooooo0000o`000?l0002Vooooo`00Z?ooool2o`0000;ooooo0_l0000Aooooo`?o0000Y_ooool0
0:cooooo0_l0000Booooo`;o0000Y_ooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00Co0000oooooooooooooooo0_l0000Aooooo`;o0000Xoooool00:cooooo00Co0000oooooooooooo
oooo0_l0000Aooooo`;o0000Xoooool008kooooo0_l0000Looooo`?o0000^Oooool008Oooooo0_l0
0005ooooo`;o00007?ooool00ol0003oooooooooo`2iooooo`00Qoooool2o`0000Cooooo0_l0000M
ooooo`03o`000?oooooooooo0;Wooooo002=ooooo`?o00007?ooool00ol0003oooooooooo`02oooo
o`?o0000]?ooool008gooooo0ol0000Looooo`03o`000?oooooooooo00;ooooo1?l0002cooooo`00
SOooool2o`0001gooooo00?o0000ooooooooool01?ooool2o`000;?ooooo0029ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01?m4A4Co0000
o`000?lb<S82o`0000Cooooo00?o0000ooooooooool0^Oooool008Wooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`06ooooo`Co00001?ooool00ol0003o
ooooooooo`0Looooo`;o0000Voooool0087ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@
41003Oooool00onYZJWoEEEEooooo`06ooooo`Go00000oooool3o`0001cooooo0_l0002Kooooo`00
ROooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool01?mgMgOo
<S8bo`000?l00003ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2iooooo`00ROooool00ol@413oooooooooo`02o`0000kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo023ooooo0_l0002Goooo
o`00ROooool00omgMgOoV9RHooooo`02o`0000_ooooo00Co410@oooooooooooooooo0_l00003oooo
o`03o`000?oooooooooo00Gooooo0ol0000Oooooo`;o000000?oooooo`000?l00000Uoooool008Wo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Ko00000oooool4o`0000Cooooo0ol0000<oooo
o`;o00004Oooool2o`0009[ooooo002Booooo`;o00002Oooool2o`0000gooooo00?o0000oooooooo
ool02_ooool2o`0001Kooooo0_l0002Eooooo`00Roooool2o`0000Gooooo0_l0000Hooooo`03o`00
0?oooooooooo02;ooooo0_l0002Eooooo`00Roooool2o`0000Cooooo0ol0000Hooooo`03o`000?oo
oooooooo0;Wooooo002Aooooo`;o00006Oooool3o`00027ooooo0_l0002Fooooo`00[?ooool00ol0
003oooooooooo`0Qooooo`;o0000U_ooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool09?ooool2o`0009?ooooo002@ooooo`;o00001Oooool2o`0001?ooooo00?o
0000ooooooooool04_ooool2o`00013ooooo0_l0002Cooooo`00T?ooool2o`0000Gooooo0_l0000=
ooooo`;o00001?ooool00ol0003oooooooooo`0Booooo`;o00004oooool2o`00093ooooo002Eoooo
o`;o00002Oooool2o`0000Cooooo0_l00004ooooo`03o`000?oooooooooo02Gooooo1?l0002@oooo
o`00UOooool2o`0000Wooooo0_l00004ooooo`?o00000oooool00ol0003oooooooooo`06ooooo`;o
00007Oooool2o`0009;ooooo002Looooo`;o00002Oooool2o`0000?ooooo0ol00006ooooo`;o0000
3Oooool2o`00017ooooo0_l0002?ooooo`00W?ooool2o`0000kooooo00?o0000ooooooooool04ooo
ool4o`00017ooooo0_l0002?ooooo`00ROooool2o`00027ooooo00?o0000ooooooooool04oooool2
o`0001;ooooo0_l0002@ooooo`00ROooool2o`00027ooooo00?o0000ooooooooool09oooool2o`00
093ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002Cooooo`;o00001Oooool2o`00013ooooo00?o0000ooooooooool05oooool2o`000:3ooooo002C
ooooo`;o00001Oooool2o`00013ooooo00Co0000ooooool0003o00002?ooool2o`0000cooooo0_l0
002Pooooo`00[?ooool4o`0000Sooooo0_l0002^ooooo`00[?ooool00ol0003oooooooooo`03o`00
01Kooooo0_l0002Nooooo`00XOooool2o`0000Wooooo00?o0000ooooooooool00ol0000Fooooo`;o
0000W_ooool00:7ooooo0_l000000ooooooo0000o`000006ooooo`03o`000?oooooooooo037ooooo
0_l00026ooooo`00W_ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l00000
0oooool00ol0003oooooooooo`0aooooo`;o0000Q_ooool009kooooo0_l000000ooooooo0000o`00
0004ooooo`;o00000oooool00ol0003oooooooooo`0aooooo`;o0000Q_ooool00:cooooo00?o0000
ooooooooool03oooool2o`00023ooooo0_l00026ooooo`00Z_ooool3o`00017ooooo0_l0000>oooo
o`;o0000V?ooool00:[ooooo1Ol00006ooooo`;o00005oooool2o`0001;ooooo0_l00024ooooo`00
QOooool2o`0002Gooooo00?o0000ooooooooool01_ooool2o`0002_ooooo0_l00024ooooo`00QOoo
ool2o`0002Gooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00Co0000ooooool0003o00004Oooool2o`0000cooooo0_l0002Gooooo`00[?ooool01?l0
003oooooo`000?l0000Aooooo`;o00003?ooool2o`0009Oooooo0025ooooo`;o00002_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`?o000000?o<S8bomgMgOooool01?ooool0
0ol0003oooooooooo`2iooooo`00QOooool2o`0000Sooooo0_l000001OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B45ooooo`;o000000?oooooogMgMolb<S801Oooool00ol0003oooooooooo`0Q
ooooo`;o0000U_ooool008Wooooo2?l000001Ol@413ooooooooooooooooo410@013ooooo0ol00003
ooooo`03o`000?oooooooooo027ooooo0_l0002Fooooo`00TOooool01Ol0003ooooooooooooooooo
000000oooooo00CoMgMgoc8b<_l0003o00000oooool3o`0001Gooooo0_l0000;ooooo`;o0000UOoo
ool0097ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
0oooool3o`0000?ooooo0_l0000Booooo`?o00002_ooool2o`0009Gooooo002Aooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00ol0003oooooooooo`05ooooo`?o00000oooool3o`0001;ooooo
0_l0002Qooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`02ooooo`;o0000]Oooool0097ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`0iooooo`;o0000O_ooool00:cooooo00?o
0000ooooooooool09oooool2o`00013ooooo0ol0001mooooo`00T_ooool2o`0001Sooooo00?o0000
ooooooooool09oooool2o`00017ooooo0_l0001mooooo`00Q?ooool2o`0000cooooo0_l0000@oooo
o`;o00001_ooool00ol0003oooooooooo`05ooooo`;o0000/_ooool008Cooooo0_l00002ooooo`;o
00006_ooool2o`0000Kooooo0ol00005ooooo`;o0000/_ooool008Sooooo0_l0000Fooooo`;o0000
2_ooool00ol0003oooooooooo`06ooooo`;o00004Oooool2o`0009kooooo002=ooooo`;o00001_oo
ool2o`0000Wooooo0_l0000:ooooo`03o`000?oooooooooo00Kooooo0_l0000Aooooo`?o00008_oo
ool2o`0007Wooooo002=ooooo`;o00001_ooool2o`0001Gooooo00?o0000ooooooooool06_ooool2
o`0002;ooooo0_l0001iooooo`00Poooool2o`0002Oooooo00?o0000ooooooooool03oooool2o`00
0:Sooooo0023ooooo`;o00009oooool00ol0003oooooooooo`0?ooooo`;o0000Z?ooool008Sooooo
0_l0000Qooooo`;o0000^oooool008Sooooo0_l0000Qooooo`;o0000^oooool00:cooooo0ol00000
0ooooooo0000o`00000?ooooo`;o0000YOooool00:Oooooo0_l00003ooooo`04o`000?oooooooooo
ooooo`;o00001oooool2o`0000Kooooo0_l0000Gooooo`;o0000S?ooool00:7ooooo0_l00004oooo
o`;o00000oooool00ol0003oooooooooo`0:ooooo`;o00007oooool2o`0008cooooo002Cooooo`;o
00002_ooool4o`0000Wooooo00?o0000ooooooooool0^Oooool009?ooooo0_l0000:ooooo`;o0000
2?ooool2o`000003ooooool0003ooooo00Cooooo0_l0002dooooo`00S?ooool2o`0001_ooooo0_l0
00000ooooooo0000ooooo`04ooooo`;o0000:Oooool2o`00013ooooo0_l0001gooooo`00S?ooool2
o`0001kooooo00?o0000ooooooooool0;Oooool3o`00013ooooo0_l0001gooooo`00[?ooool00ol0
003oooooooooo`0Oooooo`;o00003?ooool3o`0008Wooooo002Fooooo`;o00005?ooool3o`0001oo
oooo0_l0000=ooooo`;o00005?ooool2o`0007?ooooo002Fooooo`;o00005?ooool00ol0003ooooo
ooooo`14ooooo`;o0000Loooool008Oooooo0_l0000Sooooo`03o`000?oooooooooo01Cooooo0_l0
002Sooooo`00Qoooool2o`0001Oooooo0_l0000:ooooo`03o`000?oooooooooo01Cooooo0_l0000J
ooooo`;o0000Qoooool00:3ooooo0_l0000:ooooo`03o`000?oooooooooo00Oooooo0_l0000<oooo
o`?o00002?ooool2o`0000kooooo0_l00027ooooo`00Z?ooool2o`0000;ooooo00?o0000oooooooo
ool01oooool2o`0000cooooo0ol00008ooooo`;o0000Uoooool00:Sooooo0_l00002ooooo`03o`00
0?oooooooooo033ooooo0_l0000Dooooo`;o0000LOooool009kooooo0_l0000<ooooo`03o`000?oo
oooooooo02;ooooo0_l0000<ooooo`;o00005?ooool3o`00073ooooo002Aooooo`;o00002oooool2
o`0000cooooo00?o0000ooooooooool08_ooool2o`0000kooooo0ol0000Booooo`;o0000L?ooool0
097ooooo0_l0000@ooooo`;o00001oooool3o`0000oooooo0_l0000Qooooo`?o0000Q?ooool00:?o
oooo0_l00007ooooo`04o`000?oooooo0000o`0000Sooooo0_l00004ooooo`;o0000Z?ooool0087o
oooo0_l0000Sooooo`;o00001?ooool01?l0003oooooo`000?l00008ooooo`;o00001?ooool2o`00
0:Sooooo0021ooooo`;o00008oooool2o`0000Cooooo00?o0000ooooooooool03oooool2o`000:So
oooo002/ooooo`03o`000?oooooooooo02Cooooo0_l0002Cooooo`00ROooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Go
oooo00?o0000ooooooooool06_ooool2o`0000Sooooo0_l0002Cooooo`00ROooool01OmgMgOoV9RH
oooooonHV9SoMgMg00;ooooo0_l000000ooooooo8B4Qob4Q8@04ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01Wooooo0ol0000/oooo
o`?o0000K_ooool0087ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41000_ooool2o`00
00Sooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`02o`000003ooooool0003ooooo
00;ooooo0_l0000?ooooo`;o00001Oooool2o`0002gooooo0ol0001^ooooo`00ROooool01?l0003o
ooooooooooooool2o`000003ooooool0003o000000Wooooo00?oV9RHob4Q8Oo^k^h01oooool01?mg
MgOo<S8booooooooool2o`000005ooooool0003o0000o`000?ooool00_l0000?ooooo`;o00008?oo
ool2o`0008?ooooo0029ooooo`04o`000?ooooooooooooooo`;o000000?oooooo`000?l000002_oo
ool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`0dooooo`;o0000Poooool008Wooooo00Go410@oooooooooooooooooa0@4002ooooo`;o0000
2oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1_ooool2o`0002kooooo0_l00021ooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01_ooool2o`0002kooooo0ol00020ooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`06oooo
o`;o00000oooool2o`0002Sooooo1?l00020ooooo`00V_ooool2o`00013ooooo00?o0000oooooooo
ool02oooool2o`0002Sooooo0ol0000Cooooo`;o0000K?ooool009[ooooo0_l0000@ooooo`03o`00
0?oooooooooo04_ooooo0_l0001/ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3
o`0001Cooooo0_l0000Qooooo`;o0000P?ooool00:cooooo00?o0000ooooooooool05?ooool2o`00
013ooooo0_l0000?ooooo`;o0000P?ooool008oooooo0_l00003ooooo`;o00005_ooool00ol0003o
ooooooooo`0Vooooo`;o00009?ooool2o`0006_ooooo002?ooooo`;o00000oooool2o`0001Kooooo
00?o0000ooooooooool0B_ooool4o`0006_ooooo002/ooooo`03o`000?oooooooooo00kooooo0_l0
000jooooo`;o0000KOooool008Cooooo0_l0000Vooooo`03o`000?oooooooooo00kooooo0_l0000>
ooooo`;o0000VOooool008Cooooo0_l0000Vooooo`03o`000?oooooooooo01kooooo0_l0002Ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00S?ooool2o`0001kooooo0ol00005ooooo`;o0000
<_ooool2o`0007kooooo002<ooooo`;o00007_ooool00ol0003oooooooooo`05ooooo`;o0000<_oo
ool2o`0007kooooo002/ooooo`03o`000?oooooooooo01kooooo0_l0000/ooooo`;o0000Joooool0
083ooooo0_l00007ooooo`;o00001_ooool2o`0001Wooooo00?o0000ooooooooool07_ooool2o`00
01Wooooo0_l0000Aooooo`;o0000Joooool0083ooooo0_l00007ooooo`;o00001_ooool2o`0001Wo
oooo00?o0000ooooooooool05_ooool2o`00027ooooo0ol0000Aooooo`;o0000J_ooool00:cooooo
00?o0000ooooooooool05_ooool2o`0002;ooooo0_l0000Aooooo`;o0000J_ooool00:cooooo00?o
0000ooooooooool03oooool2o`0001Wooooo0_l0000?ooooo`;o0000O?ooool00:cooooo00?o0000
ooooooooool03oooool2o`0000Kooooo0_l0000Aooooo`;o00003oooool2o`0007cooooo002/oooo
o`03o`000?oooooooooo01Oooooo0_l0002Pooooo`00[?ooool3o`0004oooooo0_l0001Xooooo`00
[?ooool00ol0003oooooooooo`1?ooooo`;o0000J?ooool00:cooooo00?o0000ooooooooool0>_oo
ool2o`0007gooooo0009ooooo`Co000000?o410@ooooooooool05_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8b
omgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0
003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004
ooooo`05odA4A?l0003o0000oc8b<_oMgMd05_ooool00ol0003oooooooooo`0Hooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01?ooool2o`0000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o00001Oooool01Om4
A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd06?ooool4o`000003oa0@
4?oooooooooo01;ooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007
ooooo`03ogMgMolb<S;ooooo01Gooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8b
ooooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool3o`0000Sooooo00?oMgMgoc8b<_oo
ool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo
00Oooooo00?oMgMgoc8b<_ooool06Oooool00ol0003oooooooooo`0Dooooo`001_l00005ooooo`03
o`000?oooooooooo013ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onY
ZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`05ooooo`Ko00000_ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo01Sooooo00Go410@oooooooooooooooooa0@4003ooooo`;o00001oooool00onHV9So8B4Q
onk^kP02o`0000Oooooo00?o0000ooooooooool03Oooool01Ol@413ooooooooooooooooo410@00Co
oooo0_l0000:ooooo`03o`000?oooooooooo00gooooo00Go410@oooooooooooooooooa0@400=oooo
o`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Doooo
o`002oooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool00olQ
8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000?
ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ
8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool05Oooool00ol0003oooooooooo`0Hooooo`05o`000?oo
ooooooooooooool000000oooool2o`0000Sooooo00CoV9RHob4Q8Ol0003o00001_ooool00omgMgOo
<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0>oooo
o`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;o
oooo01Wooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol0
003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`03oooool01Ol0003ooooooooooooooooo000000Oooooo0_l00005ooooo`03ogMgMomVIVKooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Fooooo`03o`000?oooooooooo01Sooooo00Go0000
ooooooooooooooooo`00000>ooooo`;o00001?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo
00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0
003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<01[ooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool0
1Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003ooooooooo
o`0Aooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0Aooooo`05oa0@
4?ooooooooooooooool@41001oooool2o`0000Kooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Hooooo`?o00001_ooool2o`0000?ooooo0_l0000;ooooo`05oa0@4?oooooooooooooo
ool@41003_ooool2o`0000Cooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o
ZJVYogMgMoooool00oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Cooooo000;
ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oo
oooooooooooooolb<S801?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`06
ooooo`;o00000oooool2o`0000Wooooo0_l000001OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0<ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo01Cooooo0009ooooo`03oeEEEOmVIVKo000001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`Go00001?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00004?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co
00005oooool00ol0003oooooooooo`07ooooo`;o00000_ooool2o`0000Wooooo0_l000001Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00004?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool5o`0000Cooooo1?l0000Iooooo`03oeEEEOmVIVKo000001Kooooo002/ooooo`03o`000?oo
oooooooo00Oooooo0_l00002ooooo`;o00001?ooool2o`0002Wooooo0_l0001kooooo`00TOooool2
o`0001Wooooo00?o0000ooooooooool04Oooool2o`0002Wooooo0_l0001kooooo`00TOooool4o`00
01Oooooo00?o0000ooooooooool0[_ooool2o`0000;ooooo0_l00005ooooo`00Toooool2o`0001Oo
oooo00?o0000ooooooooool00oooool2o`0000;ooooo0_l0000Sooooo`;o0000P?ooool01_o^k^ko
8B4QohN7Qonj^[[o0000omgMg@Gooooo002/ooooo`03o`000?oooooooooo00?ooooo0_l00002oooo
o`;o00006?ooool2o`0000Wooooo0ol0000>ooooo`;o0000L?ooool01?oMgMgo0000oa0@4?o<c<`6
ooooo`001oooooooo`0004co00003?ooool01?o^k^ko8B4Qoa0@4?o^k^h6ooooo`001oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooooooo0_l00002
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_l00003ooooo`?o00001Oooool0
0ol0003oooooooooo`06ooooo`04o`000?ooooooooooooooo`;o00000_ooool00ol0003ooooooooo
o`05ooooo`04o`000?ooooooooooooooo`;o00000_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`04ob4Q
8OmgMgOoMgMgoc8b<PKooooo0007ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0Rooooo`;o00000_ooool01Ol0003oooooo`000?l0003ooooo00;o
00002oooool2o`0001Gooooo00?o0000ooooooooool04Oooool2o`0000Cooooo0_l0000>ooooo`04
o`000?ooooooooooooooo`;o00008oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool02Oooool2o`0000;ooooo0_l00005ooooo`00QOooool2o`000003
ooooool0003o000000_ooooo0_l0000Eooooo`?o0000^Oooool00:cooooo0ol0000jooooo`Co0000
Noooool00:cooooo00?o0000ooooooooool05oooool2o`00027ooooo1?l0001kooooo`00[?ooool0
0ol0003oooooooooo`0Gooooo`;o00008Oooool3o`0007cooooo002;ooooo`?o00007_ooool00ol0
003oooooooooo`0kooooo`;o0000O?ooool008_ooooo0ol0000Nooooo`?o00001oooool2o`000;3o
oooo002@ooooo`;o00006_ooool00ol0003oooooooooo`07ooooo`;o00001oooool2o`0000oooooo
0_l0002Fooooo`00Q?ooool2o`0000[ooooo0_l0000Jooooo`03o`000?oooooooooo013ooooo0_l0
000?ooooo`;o00002?ooool2o`0008cooooo0024ooooo`;o00009_ooool00ol0003oooooooooo`07
ooooo`;o00008_ooool2o`0000kooooo0ol0001kooooo`00[?ooool00ol0003oooooooooo`07oooo
o`;o00000_ooool2o`0002kooooo0ol0001kooooo`00[?ooool00ol0003oooooooooo`0;ooooo`;o
00005?ooool2o`0001Wooooo0_l0001kooooo`00[?ooool00ol0003oooooooooo`0Qooooo`;o0000
U_ooool0083ooooo0_l0000Zooooo`03o`000?oooooooooo01Sooooo0_l0002Oooooo`00P?ooool2
o`0002[ooooo00?o0000ooooooooool04?ooool2o`0000Gooooo0ol0002Oooooo`00UOooool2o`00
01Gooooo0ol0000@ooooo`;o00001?ooool3o`00027ooooo0_l0001mooooo`00QOooool2o`0000ko
oooo0_l0000Eooooo`03o`000?oooooooooo01Kooooo0_l0000Rooooo`;o0000OOooool008Gooooo
0_l0000Uooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00[ooooo0_l0
002]ooooo`00S?ooool2o`0000Cooooo0_l0000Hooooo`03o`000?oooooooooo00;ooooo0_l00006
ooooo`;o0000[Oooool008cooooo0_l00004ooooo`;o00006?ooool00ol0003oooooooooo`02oooo
o`;o00007?ooool2o`0002cooooo0_l0001Yooooo`00U?ooool2o`0001Kooooo00?o0000oooooooo
ool08?ooool2o`0000Wooooo0_l0000>ooooo`;o00004Oooool2o`0006Wooooo002Dooooo`;o0000
5_ooool00ol0003oooooooooo`0[ooooo`;o00003_ooool2o`00017ooooo0_l0001Yooooo`00Sooo
ool2o`0001_ooooo0ol00006ooooo`;o0000A_ooool2o`0006Wooooo0029ooooo`;o00001?ooool2
o`0001_ooooo00?o0000ooooooooool01_ooool2o`0000;ooooo0_l00003ooooo`;o0000Z?ooool0
08Wooooo0_l00009ooooo`;o00005_ooool00ol0003oooooooooo`0:ooooo`;o00000oooool2o`00
0:Sooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooo
ooooo`09ooooo`;o0000[_ooool00:cooooo00?o0000ooooooooool02Oooool2o`0001;ooooo0_l0
002Jooooo`00Soooool2o`0001_ooooo00Co0000oooooooooooooooo0_l0000Jooooo`;o0000V_oo
ool008oooooo0_l0000Kooooo`04o`000?ooooooooooooooo`;o0000]_ooool00:cooooo0ol0002i
ooooo`00[?ooool00ol0003oooooooooo`0Yooooo`Co0000S?ooool00:cooooo00?o0000oooooooo
ool0:Oooool4o`0000kooooo0_l0001looooo`00WOooool2o`0000gooooo00?o0000ooooooooool0
>oooool2o`0007cooooo002Jooooo`;o000000?oooooo`000?l000003Oooool00ol0003ooooooooo
o`0=ooooo`;o0000?_ooool2o`0006[ooooo002Jooooo`;o00004?ooool00ol0003oooooooooo`03
ooooo`;o00002?ooool2o`0003kooooo0_l0001Zooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool00oooool2o`0002?ooooo0ol0000<ooooo`;o0000P?ooool008Wooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Booooo`;o00002Oooool2o`0000Wooooo
0ol0000<ooooo`;o00005Oooool2o`0006Wooooo0029ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0000Booooo`?o0000
2?ooool2o`0002oooooo0_l0001Yooooo`00ROooool01Ol0003ooooooooooooooooo000000gooooo
00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01?ooooo
0_l0000Dooooo`;o0000S_ooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMg
MomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00;o
oooo0_l00008ooooo`;o00006oooool2o`0008kooooo0029ooooo`05oa0@4?ooooooooooooooool@
41000oooool2o`0000[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`?o
00001?ooool2o`0000Sooooo0_l00005ooooo`;o0000Y?ooool0087ooooo0_l00006ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool2o`0000Kooooo00Go0000okZj^_ooooooV9RHoa0@4004oooo
o`03o`000?oooooooooo00Gooooo1Ol0000Cooooo`;o0000Y?ooool0087ooooo0_l00006ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006
ooooo`?o00001_ooool2o`0001Cooooo0_l0002Kooooo`00TOooool2o`0001Wooooo00?o0000oooo
ooooool01_ooool2o`0001Cooooo0_l0002Kooooo`00TOooool2o`0001Wooooo00?o0000oooooooo
ool01_ooool2o`0001Cooooo0_l00008ooooo`?o00003Oooool2o`00087ooooo002/ooooo`03o`00
0?oooooooooo00Kooooo0_l0000Dooooo`;o00002?ooool3o`0000gooooo0ol00020ooooo`00[?oo
ool3o`0003Oooooo0_l00020ooooo`00[?ooool00ol0003oooooooooo`02o`0002?ooooo0_l0000?
ooooo`;o0000POooool00:cooooo00?o0000ooooooooool00_l0000Sooooo`;o00003oooool2o`00
087ooooo002>ooooo`;o00003?ooool2o`0000kooooo00?o0000ooooooooool0^Oooool008kooooo
0_l0000<ooooo`;o00003_ooool00ol0003oooooooooo`0eooooo`;o0000P_ooool00:cooooo00?o
0000ooooooooool05oooool2o`0001cooooo0_l00022ooooo`00ZOooool2o`000003ooooool0003o
oooo01Sooooo0_l0000Jooooo`;o0000Q?ooool00:Wooooo0_l000000ooooooo0000ooooo`0Toooo
o`Co00003?ooool2o`0008Cooooo002Xooooo`;o00000_ooool3o`0000;ooooo0_l00003ooooo`;o
00006_ooool4o`0000_ooooo0_l00025ooooo`00W_ooool2o`0000Sooooo0_l00002ooooo`03o`00
0?oooooooooo00;ooooo0_l00003ooooo`;o00007?ooool2o`0000_ooooo0_l00025ooooo`00W_oo
ool2o`0000cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool03Oooool2
o`0001?ooooo0_l0002Eooooo`00T?ooool2o`0000oooooo0_l00009ooooo`03o`000?oooooooooo
00gooooo0_l0000Cooooo`;o0000UOooool0093ooooo0_l0000?ooooo`;o00002Oooool00ol0003o
ooooooooo`06ooooo`;o0000:oooool2o`0008Cooooo002/ooooo`04o`000?oooooo0000o`0000Go
oooo0_l0000>ooooo`;o00006oooool2o`0008Cooooo002Aooooo`;o00006Oooool01?l0003ooooo
o`000?l00004ooooo`;o00003oooool2o`000:7ooooo002Aooooo`;o00001Oooool2o`0001;ooooo
0ol00005ooooo`;o00006_ooool2o`0009Kooooo002Hooooo`;o00003_ooool2o`0000;ooooo00?o
0000ooooooooool03?ooool2o`0000Kooooo0_l0000;ooooo`;o0000U_ooool00:Sooooo0_l00002
ooooo`03o`000?oooooooooo00_ooooo0ol00006ooooo`;o0000Xoooool008?ooooo0_l0000Woooo
o`03o`000?oooooooooo00?ooooo0_l00006ooooo`;o0000[?ooool008?ooooo0_l0000Wooooo`03
o`000?oooooooooo00?ooooo0_l0002dooooo`00YOooool2o`0000Gooooo00?o0000ooooooooool0
^Oooool00:Gooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo0_l0002eooooo`00Q?ooool2
o`0001oooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo0_l00006ooooo`;o00008Oooool2
o`0008[ooooo0024ooooo`;o00009Oooool4o`0000[ooooo0_l0000Qooooo`;o0000R_ooool00:_o
oooo0_l0002kooooo`00Z_ooool3o`0001?ooooo0ol0000Iooooo`;o0000R_ooool008kooooo0_l0
000Jooooo`?o00004oooool3o`0000Oooooo0_l0000?ooooo`?o0000R_ooool008kooooo0_l0000L
ooooo`03o`000?oooooooooo01_ooooo0_l0000?ooooo`;o0000Roooool009kooooo0_l0000<oooo
o`03o`000?oooooooooo00Oooooo0_l00008ooooo`;o0000Y_ooool0097ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q00?oooooo`000?l000000_ooool01Om4A4Co0000o`000?lb<S;o
gMgM00;o00000oooool00ol0003oooooooooo`07ooooo`;o00002?ooool2o`000:Kooooo002Aoooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00CoMgMgoc8b<_l0003o00000ooo
ool00ol0003oooooooooo`0oooooo`Co0000M_ooool008oooooo0_l000001Ol@413ooooooooooooo
oooo410@013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`;o0000>?oo
ool4o`0007Kooooo002?ooooo`?o00000_ooool2o`0000oooooo00?oMgMgoc8b<_ooool01?ooool3
o`0000Gooooo0_l0000hooooo`;o0000N?ooool0097ooooo00?o0000ooooooooool00_l00005oooo
o`;o00001Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0:?ooool2
o`0001Gooooo0_l0001hooooo`00Roooool2o`0000Cooooo00Go410@oooooooooooooooooa0@4005
ooooo`;o00001Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo0_l0000I
ooooo`;o0000Soooool008_ooooo0_l00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool2
o`0000Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0=ooooo`;o0000Z_ooool0
097ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`;o00001?ooool4o`0000Gooooo0_l0000/
ooooo`;o0000SOooool008_ooooo0_l0000@ooooo`;o00003?ooool2o`0000gooooo0_l0000Koooo
o`Co0000SOooool008_ooooo0_l0000@ooooo`;o00003Oooool00ol0003oooooooooo`0;ooooo`;o
00002oooool2o`0000kooooo0_l0002?ooooo`00[?ooool00ol0003oooooooooo`0Hooooo`;o0000
Woooool00:cooooo0ol0002iooooo`00Woooool2o`000003ooooool0003o000000Sooooo00?o0000
ooooooooool05oooool2o`000:3ooooo002Booooo`;o00002oooool2o`000003ooooool0003o0000
00Sooooo00?o0000ooooooooool05oooool2o`000:3ooooo002Booooo`;o00003Oooool2o`0000Wo
oooo00?o0000ooooooooool02Oooool2o`000:kooooo002Qooooo`;o00002Oooool00ol0003ooooo
ooooo`09ooooo`;o00002_ooool2o`000:;ooooo002/ooooo`03o`000?oooooooooo01Gooooo0_l0
000Qooooo`;o0000Ooooool009[ooooo0_l0000@ooooo`?o00004_ooool2o`00013ooooo0_l0000B
ooooo`;o0000Ooooool008Sooooo0_l0000@ooooo`;o00004?ooool3o`0001;ooooo0_l0000@oooo
o`;o0000Toooool008Sooooo0_l0000Rooooo`?o00004oooool2o`0000kooooo0_l0002Dooooo`00
[?ooool00ol0003oooooooooo`0Cooooo`;o00003_ooool2o`0009Cooooo002/ooooo`03o`000?oo
oooooooo00Cooooo0_l0002cooooo`00UOooool2o`0001Gooooo00?o0000ooooooooool01?ooool2
o`0002oooooo0_l00022ooooo`00ROooool2o`0000[ooooo0_l0000Eooooo`03o`000?oooooooooo
013ooooo0_l0000Sooooo`;o0000P_ooool008Wooooo0_l0000Dooooo`;o00001Oooool2o`0000Co
oooo00?o0000ooooooooool04?ooool2o`000:Oooooo002Oooooo`;o00001Oooool2o`0000Cooooo
00?o0000ooooooooool0^Oooool008[ooooo0_l0000Cooooo`;o00001?ooool2o`0000Gooooo00?o
0000ooooooooool0^Oooool008[ooooo0_l00004ooooo`;o00004_ooool3o`0000Gooooo0ol0000=
ooooo`;o0000Z_ooool0093ooooo0_l0000Booooo`;o00001_ooool00ol0003oooooooooo`0=oooo
o`;o0000Z_ooool00:cooooo00?o0000ooooooooool07?ooool2o`0009_ooooo002:ooooo`;o0000
8?ooool01?l0003oooooo`000?l0000:ooooo`;o00003oooool2o`0009_ooooo002:ooooo`;o0000
3_ooool2o`00013ooooo00Co0000ooooool0003o00002_ooool2o`000:cooooo002Jooooo`;o0000
4?ooool00ol0003oooooooooo`0Iooooo`;o0000W_ooool00:cooooo00?o0000ooooooooool06Ooo
ool2o`0001Cooooo0_l00028ooooo`00Toooool2o`0001Gooooo0ol0000Kooooo`;o00005?ooool2
o`0008Sooooo002Cooooo`;o00002?ooool2o`0000_ooooo0ol0000Kooooo`;o0000W_ooool009Co
oooo0_l00007ooooo`;o00003?ooool4o`0002cooooo0_l0002;ooooo`00U?ooool2o`0001Kooooo
00?o0000ooooooooool0;?ooool2o`0008_ooooo002Cooooo`;o00003oooool3o`0000Gooooo00?o
0000ooooooooool0^Oooool009?ooooo0_l0000?ooooo`?o000000?oooooo`000?l000000_ooool0
0ol0003oooooooooo`2iooooo`00Z?ooool2o`0000;ooooo00?o0000ooooooooool0^Oooool008Ko
oooo0_l000001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B42o`0000Cooooo00?o0000
onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool05?oo
ool2o`000:?ooooo0026ooooo`;o000000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q
0_l00004ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`0Dooooo`;o0000Xoooool008Wooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVY
ZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2iooooo`00ROoo
ool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8b
ooooo`04ooooo`Go00003oooool2o`000:Kooooo0029ooooo`05o`000?ooooooooooooooool00000
3_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003o
ooooo`000002o`0000oooooo0_l0002Vooooo`00ROooool01Ol@413ooooooooooooooooo410@00ko
oooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`04o`000?oooooo0000o`00
0;Sooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo
<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2iooooo`00ROooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`0T
ooooo`;o0000Toooool00:cooooo00?o0000ooooooooool09?ooool2o`0009?ooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00gooooo0_l0002Zooooo`00[?oo
ool3o`0000gooooo0_l0002Zooooo`00[?ooool00ol0003oooooooooo`2iooooo`00TOooool2o`00
01Wooooo00?o0000ooooooooool0^Oooool0097ooooo0_l0000=ooooo`;o00002_ooool00ol0003o
ooooooooo`2iooooo`00X?ooool2o`0000[ooooo00?o0000ooooooooool0^Oooool00:cooooo00?o
0000ooooooooool0^Oooool009?ooooo0_l0000Gooooo`03o`000?oooooooooo01gooooo0_l0002J
ooooo`00Toooool2o`0001Oooooo00?o0000ooooooooool07Oooool2o`0009[ooooo002Cooooo`?o
00005_ooool3o`000;Wooooo002;ooooo`;o00001_ooool3o`0001Kooooo00?o0000ooooooooool0
^Oooool008_ooooo0_l0000Oooooo`03o`000?oooooooooo0;Wooooo002;ooooo`;o00002?ooool2
o`0001Gooooo00?o0000ooooooooool0^Oooool009Gooooo0_l0000Eooooo`03o`000?oooooooooo
00?ooooo0_l0002dooooo`00[?ooool00ol0003oooooooooo`03ooooo`;o0000]?ooool00:cooooo
00?o0000ooooooooool00_ooool2o`000;Gooooo002/ooooo`03o`000?oooooooooo00;ooooo0_l0
002eooooo`00[?ooool3o`000;Wooooo002Hooooo`;o00004_ooool3o`000;Wooooo002Hooooo`;o
00004_ooool3o`0001?ooooo0_l0002Tooooo`00[?ooool3o`0001?ooooo0_l0002Tooooo`00[?oo
ool2o`000;[ooooo002/ooooo`;o00004?ooool2o`000:Sooooo002Vooooo`;o00001?ooool00ol0
003oooooooooo`0?ooooo`;o0000Z?ooool00:Kooooo0_l00004ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Ooo
ool00:;ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0;Wooooo002Toooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000oooooooo
ool01Oooool3o`000;Wooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oo
oooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo
0<7ooooo002Rooooo`03oeEEEOmVIVKo00000<?ooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo002Zooooo`04oa0@4?l0003o0000o`000;[ooooo002[ooooo`03
o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`06o`000?mg
MgOo0000o`000?mEEEGok^k^]oooool00:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomEEEFgoooo
o`00Zoooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo0;Gooooo002[ooooo`03o`00
0?o^k^kooooo00;ooooo00?o0000ooooooooool0]Oooool00:_ooooo00Ko0000oeEEEOo^k^kooooo
ogMgMomVIVJgooooo`00Z_ooool00ol@413o0000ogMgM`02o`000003ofIVI_o^k^kooooo0;Kooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.6288 .36971 Mdot
.6435 .61326 Mdot
.50274 .55729 Mdot
.47255 .75264 Mdot
.58764 .52011 Mdot
.42979 .17317 Mdot
.43663 .4745 Mdot
.40546 .88172 Mdot
.59075 .84664 Mdot
.56462 .49756 Mdot
.51639 .72893 Mdot
.36529 .5382 Mdot
.48933 .92195 Mdot
.55129 .63337 Mdot
.36981 .37469 Mdot
.43843 .29217 Mdot
.61252 .50318 Mdot
.47643 .92763 Mdot
.47325 .19634 Mdot
.59097 .18463 Mdot
.45672 .91553 Mdot
.59978 .74207 Mdot
.5661 .80177 Mdot
.44835 .9108 Mdot
.45268 .01605 Mdot
.40899 .66159 Mdot
.4539 .77029 Mdot
.45939 .20828 Mdot
.62081 .23536 Mdot
.6366 .63452 Mdot
.40893 .80101 Mdot
.59669 .84147 Mdot
.44967 .97174 Mdot
.58548 .67375 Mdot
.50992 .83795 Mdot
.52083 .10258 Mdot
.69816 .52987 Mdot
.41461 .3827 Mdot
.6477 .29891 Mdot
.36502 .43632 Mdot
.44648 .01818 Mdot
.55364 .75872 Mdot
.39991 .66814 Mdot
.64118 .40353 Mdot
.60469 .29669 Mdot
.54431 .72247 Mdot
.55332 .61073 Mdot
.65259 .74193 Mdot
.49596 .167 Mdot
.61513 .23258 Mdot
.65403 .73583 Mdot
.67777 .37101 Mdot
.59883 .92787 Mdot
.44184 .83974 Mdot
.43248 .82396 Mdot
.52719 .93472 Mdot
.39413 .83304 Mdot
.61366 .49277 Mdot
.68487 .64452 Mdot
.59072 .26693 Mdot
.52444 .76334 Mdot
.69248 .25999 Mdot
.65234 .31397 Mdot
.49411 .27694 Mdot
.44545 .96042 Mdot
.56578 .88749 Mdot
.56286 .47615 Mdot
.42467 .37065 Mdot
.41532 .36864 Mdot
.41445 .83146 Mdot
.61699 .53994 Mdot
.51847 .43639 Mdot
.5633 .51839 Mdot
.54732 .37928 Mdot
.65216 .31364 Mdot
.44223 .49944 Mdot
.5982 .92858 Mdot
.46223 .81997 Mdot
.66632 .3353 Mdot
.46415 .16774 Mdot
.3916 .28838 Mdot
.63806 .62362 Mdot
.50057 .7214 Mdot
.54573 .77605 Mdot
.46632 .98639 Mdot
.44744 .2606 Mdot
.58702 .54037 Mdot
.57278 .62268 Mdot
.60979 .43833 Mdot
.42891 .34234 Mdot
.46293 .00948 Mdot
.74374 .65203 Mdot
.54426 .43972 Mdot
.56534 .6617 Mdot
.53399 .38886 Mdot
.75512 .60856 Mdot
.55465 .61823 Mdot
.64448 .74977 Mdot
.58201 .94879 Mdot
.61266 .44435 Mdot
.63993 .41762 Mdot
.59472 .36565 Mdot
.36576 .53288 Mdot
.64821 .44671 Mdot
.37885 .51388 Mdot
.57516 .7039 Mdot
.61136 .58359 Mdot
.51203 .23606 Mdot
.54496 .44434 Mdot
.40854 .80657 Mdot
.56327 .5637 Mdot
.48473 .75055 Mdot
.60071 .83405 Mdot
.53585 .11414 Mdot
.35816 .69005 Mdot
.48923 .29889 Mdot
.49516 .81356 Mdot
.54592 .91884 Mdot
.57153 .88327 Mdot
.69456 .52071 Mdot
.48935 .92081 Mdot
.653 .19141 Mdot
.49655 .90475 Mdot
.62661 .24369 Mdot
.40884 .80891 Mdot
.44574 .71732 Mdot
.56168 .1489 Mdot
.76141 .55031 Mdot
.6468 .5338 Mdot
.53308 .50997 Mdot
.57251 .79455 Mdot
.64716 .47365 Mdot
.37195 .3247 Mdot
.44016 .14545 Mdot
.39053 .47684 Mdot
.65297 .29741 Mdot
.70176 .49205 Mdot
.59827 .20078 Mdot
.56308 .50793 Mdot
.40997 .88834 Mdot
.37202 .33654 Mdot
.73515 .37315 Mdot
.53811 .61127 Mdot
.43374 .26238 Mdot
.61287 .50397 Mdot
.56533 .14962 Mdot
.49919 .97401 Mdot
.37076 .18641 Mdot
.52951 .27903 Mdot
.56438 .6572 Mdot
.62406 .14496 Mdot
.58657 .33859 Mdot
.4154 .62723 Mdot
.44366 .90553 Mdot
.51072 .3932 Mdot
.51129 .14692 Mdot
.69579 .45578 Mdot
.66189 .33315 Mdot
.54304 .92004 Mdot
.69683 .53271 Mdot
.69745 .46422 Mdot
.40896 .33001 Mdot
.66694 .3332 Mdot
.42595 .04691 Mdot
.46855 .06768 Mdot
.40046 .66484 Mdot
.63497 .40414 Mdot
.50828 .96308 Mdot
.38185 .38307 Mdot
.41125 .41927 Mdot
.69806 .44995 Mdot
.58585 .18923 Mdot
.54595 .49456 Mdot
.41096 .55784 Mdot
.58461 .54737 Mdot
.5465 .31562 Mdot
.43827 .95399 Mdot
.75747 .59056 Mdot
.50243 .13567 Mdot
.48015 .29553 Mdot
.63049 .25722 Mdot
.69029 .40607 Mdot
.37885 .25074 Mdot
.51463 .28429 Mdot
.46198 .00409 Mdot
.50251 .68289 Mdot
.59733 .83352 Mdot
.76015 .54646 Mdot
.60774 .82839 Mdot
.41421 .07796 Mdot
.3919 .57103 Mdot
.61889 .14385 Mdot
.56482 .14835 Mdot
.44992 .29451 Mdot
.67713 .23632 Mdot
.43515 .95601 Mdot
.51622 .02467 Mdot
.36586 .44337 Mdot
.5728 .63198 Mdot
.72568 .71841 Mdot
.59544 .66243 Mdot
.43711 .39171 Mdot
.4416 .36426 Mdot
.52228 .47397 Mdot
.58581 .50489 Mdot
.71067 .75301 Mdot
.64289 .44481 Mdot
.42863 .59044 Mdot
.45921 .12135 Mdot
.49326 .7432 Mdot
.46471 .72209 Mdot
.50851 .7482 Mdot
.55049 .84048 Mdot
.47391 .82491 Mdot
.38273 .37002 Mdot
.4919 .24387 Mdot
.63755 .41774 Mdot
.49532 .80965 Mdot
.43327 .0329 Mdot
.5004 .69256 Mdot
.57413 .24173 Mdot
.36529 .56918 Mdot
.5041 .79971 Mdot
.67625 .66512 Mdot
.37852 .47184 Mdot
.41427 .16717 Mdot
.46121 .24525 Mdot
.57944 .42498 Mdot
.65113 .57759 Mdot
.54599 .47481 Mdot
.37069 .35919 Mdot
.66413 .20575 Mdot
.41697 .46403 Mdot
.5051 .59727 Mdot
.70267 .76399 Mdot
.55271 .26674 Mdot
.46027 .7809 Mdot
.63732 .17023 Mdot
.40964 .4709 Mdot
.65164 .47486 Mdot
.50708 .89492 Mdot
.6456 .45529 Mdot
.69262 .26217 Mdot
.39738 .33812 Mdot
.40806 .182 Mdot
.61705 .53799 Mdot
.59607 .84585 Mdot
.52515 .35965 Mdot
.69097 .44513 Mdot
.59563 .38978 Mdot
.61748 .52962 Mdot
.65477 .31705 Mdot
.50431 .01394 Mdot
.48499 .2946 Mdot
.45056 .29561 Mdot
.69372 .47683 Mdot
.40454 .61085 Mdot
.41368 .59756 Mdot
.4121 .7558 Mdot
.44376 .45109 Mdot
.4042 .87257 Mdot
.66998 .69729 Mdot
.52712 .21658 Mdot
.46154 .78222 Mdot
.43181 .11447 Mdot
.52525 .4163 Mdot
.58127 .328 Mdot
.6144 .33066 Mdot
.54481 .64337 Mdot
.4055 .28552 Mdot
.55207 .14248 Mdot
.40348 .40167 Mdot
.53767 .11988 Mdot
.41875 .78152 Mdot
.56536 .49 Mdot
.49473 .17073 Mdot
.69548 .44731 Mdot
.52389 .30416 Mdot
.56116 .34563 Mdot
.64359 .75792 Mdot
.51881 .72779 Mdot
.49419 .12364 Mdot
.64449 .28376 Mdot
.53454 .53503 Mdot
.52929 .32613 Mdot
.69603 .53331 Mdot
.36998 .63765 Mdot
.51818 .24684 Mdot
.47858 .31916 Mdot
.57538 .42242 Mdot
.49573 .06619 Mdot
.55519 .68842 Mdot
.38237 .39759 Mdot
.75938 .54687 Mdot
.68627 .63024 Mdot
.36674 .54478 Mdot
.68206 .63867 Mdot
.45728 .6523 Mdot
.69531 .60054 Mdot
.65853 .20943 Mdot
.45517 .06699 Mdot
.36718 .43662 Mdot
.41274 .00863 Mdot
.47138 .15917 Mdot
.38999 .54774 Mdot
.64907 .48587 Mdot
.59535 .84553 Mdot
.43604 .03598 Mdot
.54686 .6411 Mdot
.6444 .7537 Mdot
.40061 .54262 Mdot
.43443 .57778 Mdot
.55269 .83463 Mdot
.61287 .52889 Mdot
.50187 .90623 Mdot
.60769 .1247 Mdot
.50364 .33201 Mdot
.59002 .27315 Mdot
.56962 .71983 Mdot
.42298 .92014 Mdot
.52849 .43002 Mdot
.3845 .21207 Mdot
.5908 .11542 Mdot
.74912 .412 Mdot
.42005 .57752 Mdot
.44388 .13668 Mdot
.54241 .78403 Mdot
.66697 .35286 Mdot
.58215 .43261 Mdot
.43024 .46621 Mdot
.44103 .58125 Mdot
.61377 .55777 Mdot
.3745 .70579 Mdot
.69149 .46938 Mdot
.532 .37892 Mdot
.57607 .79497 Mdot
.53297 .53247 Mdot
.52254 .48127 Mdot
.64957 .58751 Mdot
.41716 .21578 Mdot
.39966 .65805 Mdot
.40931 .32806 Mdot
.58469 .48366 Mdot
.63242 .88594 Mdot
.40094 .53519 Mdot
.64206 .59293 Mdot
.49686 .28356 Mdot
.48364 .97976 Mdot
.46736 .78291 Mdot
.58881 .18717 Mdot
.62202 .67702 Mdot
.54878 .53172 Mdot
.53171 .74001 Mdot
.73412 .36788 Mdot
.36621 .57908 Mdot
.69799 .59361 Mdot
.53466 .11856 Mdot
.44897 .17892 Mdot
.59726 .64985 Mdot
.57671 .1745 Mdot
.56802 .29724 Mdot
.36643 .58225 Mdot
.75411 .42217 Mdot
.41573 .15211 Mdot
.37056 .34448 Mdot
.39067 .17638 Mdot
.45528 .00597 Mdot
.51972 .56465 Mdot
.5334 .23031 Mdot
.37372 .31776 Mdot
.4011 .86219 Mdot
.51614 .59021 Mdot
.38065 .55786 Mdot
.40135 .52292 Mdot
.46297 .11664 Mdot
.63677 .40251 Mdot
.63286 .77347 Mdot
.651 .47144 Mdot
.69715 .56588 Mdot
.6835 .41948 Mdot
.57428 .7864 Mdot
.70204 .56447 Mdot
.57903 .78107 Mdot
.42004 .07295 Mdot
.35 .49794 Mdot
.69286 .55553 Mdot
.52495 .16357 Mdot
.50215 .36364 Mdot
.5471 .06374 Mdot
.60765 .41999 Mdot
.44509 .60743 Mdot
.38362 .21431 Mdot
.40973 .81332 Mdot
.42951 .49236 Mdot
.55479 .41314 Mdot
.43613 .783 Mdot
.44376 .75334 Mdot
.64509 .75966 Mdot
.37895 .42474 Mdot
.67207 .22979 Mdot
.38337 .21792 Mdot
.60454 .60517 Mdot
.64703 .86149 Mdot
.5999 .63354 Mdot
.54147 .30213 Mdot
.55986 .34772 Mdot
.50891 .4347 Mdot
.37965 .74679 Mdot
.36593 .56153 Mdot
.45894 .77696 Mdot
.54772 .52468 Mdot
.45909 .78557 Mdot
.47758 .2296 Mdot
.57049 .08232 Mdot
.57232 .64003 Mdot
.46319 .06862 Mdot
.52831 .64702 Mdot
.41277 .59785 Mdot
.53117 .45538 Mdot
.58144 .59339 Mdot
.59323 .64693 Mdot
.43697 .73832 Mdot
.42482 .53621 Mdot
.63919 .16855 Mdot
.41408 .90167 Mdot
.47198 .3764 Mdot
.49406 .86095 Mdot
.61116 .58424 Mdot
.54751 .20238 Mdot
.4026 .42957 Mdot
.40921 .50829 Mdot
.55207 .06731 Mdot
.75057 .64187 Mdot
.65177 .50091 Mdot
.40676 .96039 Mdot
.64668 .4267 Mdot
.42513 .44049 Mdot
.56805 .87653 Mdot
.37905 .26682 Mdot
.50507 .75161 Mdot
.62004 .67984 Mdot
.62343 .89744 Mdot
.54611 .54849 Mdot
.43635 .60233 Mdot
.55859 .35104 Mdot
.42569 .12851 Mdot
.43797 .20824 Mdot
.73476 .68895 Mdot
.48356 .71962 Mdot
.47829 .86753 Mdot
.56104 .74588 Mdot
.51964 .33702 Mdot
.50021 .32455 Mdot
.53964 .3483 Mdot
.40364 .87452 Mdot
.51789 .37635 Mdot
.65848 .31309 Mdot
.65002 .5709 Mdot
.6011 .29287 Mdot
.54899 .13291 Mdot
.38019 .52472 Mdot
.61057 .56707 Mdot
.76453 .54396 Mdot
.55799 .4303 Mdot
.37187 .67923 Mdot
.50145 .01022 Mdot
.54303 .64789 Mdot
.69637 .59865 Mdot
.40309 .41396 Mdot
.60881 .46808 Mdot
.58516 .18117 Mdot
.64077 .41852 Mdot
.48998 .20358 Mdot
.52997 .7444 Mdot
.58808 .66833 Mdot
.69122 .25136 Mdot
.39098 .4895 Mdot
.44293 .53517 Mdot
.40972 .7315 Mdot
.47028 .16331 Mdot
.52211 .54651 Mdot
.41761 .50908 Mdot
.44986 .85334 Mdot
.39037 .52957 Mdot
.45986 .30516 Mdot
.41484 .6938 Mdot
.5622 .89222 Mdot
.58844 .50382 Mdot
.60326 .3036 Mdot
.42026 .32348 Mdot
.46146 .2092 Mdot
.49528 .67218 Mdot
.36722 .77805 Mdot
.48593 .68835 Mdot
.64671 .60032 Mdot
.67099 .67471 Mdot
.47585 .06552 Mdot
.42262 .31513 Mdot
.61219 .22379 Mdot
.36959 .34807 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool009oooooo0_l00003ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0^Oooool009gooooo1?l00003ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0^Oooool008oooooo0_l0000<ooooo`Co00000oooool00ol0003ooooooooo
o`05ooooo`;o0000^_ooool008oooooo0_l0000>ooooo`;o00000oooool00ol0003oooooooooo`05
ooooo`;o0000^_ooool009cooooo0_l00004ooooo`03oeEEEOmVIVKo000000Oooooo0ol0002ioooo
o`00V_ooool4o`0000kooooo0ol0002iooooo`00V_ooool2o`00013ooooo00?o0000ooooooooool0
^Oooool00:cooooo0ol00002ooooo`;o0000]Oooool00:cooooo00?o0000ooooooooool00_ooool2
o`000;Gooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Fooooo`;o00005?ooool00ol0003o
ooooooooo`2iooooo`00U_ooool2o`0001Cooooo00?o0000ooooooooool0^Oooool009Kooooo0_l0
000Dooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Coooo
o`;o00005oooool00ol0003oooooooooo`2iooooo`00Toooool2o`0001Oooooo00?o0000oooooooo
ool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`0<ooooo`;o0000Zoooool009gooooo0_l00002ooooo`;o000000?oooooo`000?l00000
1?ooool3o`0000kooooo1?l0002Yooooo`00WOooool6o`000003ooooool0003o000000Cooooo0ol0
000@ooooo`;o0000ZOooool0097ooooo0_l0000<ooooo`;o00002oooool00ol0003oooooooooo`2i
ooooo`00TOooool2o`0001Wooooo0ol0002iooooo`00Soooool2o`0001_ooooo00?o0000oooooooo
ool0^Oooool008oooooo0_l0000Kooooo`03o`000?oooooooooo01Cooooo0_l0002Sooooo`00[?oo
ool00ol0003oooooooooo`0Dooooo`;o0000Xoooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`03
ooooo`;o0000]?ooool00:cooooo00?o0000ooooooooool00oooool2o`000;Cooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Eooooo`;o00002?oo
ool2o`0000_ooooo00?o0000ooooooooool02?ooool2o`00017ooooo0_l0002Looooo`00ROooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B42o`0000Cooooo00Co0000onk^k_oooooooooo
0_l000001_ooooooA4A4o`000?l0003o<S8bomgMg@Gooooo00?o0000ooooooooool02?ooool2o`00
017ooooo0_l0002Looooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46oooo
o`03oeEEEOnYZJWooooo00;o00001Oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
00Sooooo0ol0002^ooooo`00POooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=oooo
o`03ojVYZOmEEEGooooo00;o00001_ooool01?l0003oooooooooooooool5o`0000Wooooo0_l0000E
ooooo`;o0000Uoooool008Wooooo00Go0000ooooooooooooooooo`000005ooooo`;o00001oooool0
0olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00;ooooo0ol0000Rooooo`;o0000Uoooool0
08Wooooo00Go0000ooooooooooooooooo`000005ooooo`;o00001oooool00omEEEGoc<c<ooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2iooooo`00ROooool0
1Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00gooooo0_l0002Zooooo`00ROooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo0_l00002ooooo`03oc8b<_oooooooooo00;ooooo00?o0000ooooooooool01ooo
ool2o`0000kooooo0_l0002Zooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol0
0004ooooo`Co00001_ooool2o`000;[ooooo002/ooooo`03o`000?oooooooooo00kooooo0_l0000D
ooooo`;o0000Toooool009Sooooo0_l0000Booooo`03o`000?oooooooooo00;o00003?ooool2o`00
01Cooooo1?l0002Aooooo`00V?ooool2o`0001;ooooo00?o0000ooooooooool00_l0000?ooooo`?o
00004_ooool2o`00097ooooo002@ooooo`;o00006_ooool3o`00017ooooo0ol0002Uooooo`00T?oo
ool2o`0001[ooooo00?o0000ooooooooool0^Oooool00:;ooooo0_l00008ooooo`03o`000?oooooo
oooo0;Wooooo002Rooooo`;o00002?ooool00ol0003oooooooooo`2iooooo`00X_ooool2o`0000So
oooo00?o0000ooooooooool01Oooool2o`000;;ooooo002?ooooo`;o00003oooool4o`0000Kooooo
0ol00007ooooo`;o0000/_ooool008oooooo0_l0000?ooooo`;o00002?ooool3o`0002cooooo0ol0
002<ooooo`00U?ooool2o`0001Cooooo0ol0000/ooooo`?o0000S?ooool008Oooooo0_l0000;oooo
o`;o00005_ooool3o`0001Kooooo0_l0002Qooooo`00Qoooool2o`0001;ooooo0_l0000?ooooo`03
o`000?oooooooooo01Kooooo0_l0002Qooooo`00SOooool2o`0000cooooo0_l0000?ooooo`03o`00
0?oooooooooo01Wooooo0_l0002Nooooo`00POooool2o`0000[ooooo0_l0000Mooooo`03o`000?oo
oooooooo01Wooooo1?l0002Looooo`00POooool2o`0002Wooooo00?o0000ooooooooool06Oooool4
o`0009cooooo002/ooooo`03o`000?oooooooooo01Wooooo0ol0000Cooooo`;o0000R?ooool00:co
oooo00?o0000ooooooooool0;oooool2o`0008Sooooo002Sooooo`;o00001oooool00ol0003ooooo
ooooo`2iooooo`00Xoooool2o`0000Oooooo0ol0000Mooooo`;o0000V_ooool00:Sooooo0_l00002
ooooo`03o`000?oooooooooo00cooooo0_l0000?ooooo`;o0000V_ooool00:Sooooo0_l00002oooo
o`03o`000?oooooooooo00cooooo0_l0000Uooooo`;o0000Q?ooool009Oooooo0_l00005ooooo`?o
00002oooool00ol0003oooooooooo`0aooooo`Co0000Q?ooool008Gooooo0_l0000@ooooo`;o0000
1Oooool3o`0000_ooooo00?o0000ooooooooool0<Oooool2o`0008Kooooo0025ooooo`;o00002Ooo
ool2o`0001[ooooo00?o0000ooooooooool01_ooool2o`000;7ooooo0025ooooo`;o00002Oooool2
o`0001[ooooo00?o0000ooooooooool01_ooool2o`000;7ooooo0025ooooo`;o00009Oooool00ol0
003oooooooooo`2iooooo`00[?ooool3o`0002;ooooo0_l0002Eooooo`00[?ooool00ol0003ooooo
ooooo`0Rooooo`;o0000UOooool00:Cooooo0_l00006ooooo`03o`000?oooooooooo00Sooooo0_l0
000[ooooo`;o0000P_ooool00:Cooooo0_l00006ooooo`03o`000?oooooooooo00Sooooo0_l0000I
ooooo`;o00004?ooool2o`0008;ooooo002/ooooo`04o`000?ooooooooooooooo`;o00008?ooool3
o`00017ooooo0_l00020ooooo`00[?ooool01?l0003oooooooooooooool2o`00027ooooo0_l0000A
ooooo`;o0000P?ooool0097ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool0
1Om4A4Co0000o`000?lb<S;ogMgM00;ooooo0_l000000ooooooo0000ooooo`0Fooooo`;o00003ooo
ool2o`00097ooooo002Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@;ooooo0_l0
0004ooooo`04ogMgMolb<S;oooooooooo`;o000000?oooooo`000?ooool01?ooool2o`00013ooooo
0_l0000?ooooo`;o0000TOooool008Wooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@4100
2Oooool2o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`;o0000
]?ooool008Cooooo0_l0000;ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8b
ooooo`04ooooo`?o0000??ooool2o`0007_ooooo0024ooooo`;o00002oooool01Ol0003ooooooooo
oooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo03co
oooo0_l0001kooooo`00TOooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Xooooo`;o0000Soooool0097ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`04ooooo`;o00001_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02So
oooo0_l0000Booooo`;o0000Noooool0097ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02o`0000;o
oooo0_l00006ooooo`Co00001_ooool00ol0003oooooooooo`0looooo`;o0000Noooool008Cooooo
0_l0000@ooooo`;o00005?ooool00ol0003oooooooooo`0>ooooo`;o00002oooool2o`0009cooooo
0024ooooo`;o00009_ooool00ol0003oooooooooo`0>ooooo`;o00002oooool2o`0009cooooo002/
ooooo`03o`000?oooooooooo01[ooooo0_l0002Mooooo`00Z_ooool5o`0001[ooooo0_l0002Moooo
o`00Z_ooool3o`0000Sooooo0_l0002aooooo`00[?ooool00ol0003oooooooooo`06ooooo`;o0000
/Oooool008cooooo0_l0000Mooooo`;o00000oooool2o`0002Wooooo0_l0002;ooooo`00R?ooool2
o`0000;ooooo0_l0000Mooooo`;o00000oooool2o`0002Wooooo0_l0002;ooooo`00R?ooool2o`00
00gooooo0_l0000Cooooo`03o`000?oooooooooo0;Wooooo002Gooooo`;o00000_ooool2o`0000So
oooo1?l00003ooooo`03o`000?oooooooooo01kooooo0_l0002Iooooo`00Voooool2o`0000Sooooo
1?l00003ooooo`03o`000?oooooooooo01?ooooo0_l00009ooooo`?o00003_ooool2o`0008Sooooo
002Kooooo`;o00002oooool2o`0000;ooooo0ol0000Cooooo`;o00002_ooool2o`0000cooooo1?l0
0028ooooo`00Z?ooool2o`0000;ooooo00?o0000ooooooooool01?ooool2o`0000Cooooo0_l0000C
ooooo`;o00003?ooool2o`0008[ooooo002Nooooo`;o00003?ooool00ol0003oooooooooo`04oooo
o`;o00001?ooool2o`0001?ooooo0_l0002Hooooo`00W_ooool2o`0000cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0;oooool4o`0008Kooooo002Booooo`;o00006?oo
ool00ol0003oooooooooo`0<ooooo`;o00008Oooool4o`0008Kooooo0022ooooo`;o00003_ooool2
o`00013ooooo0_l00006ooooo`03o`000?oooooooooo00cooooo0_l0000Qooooo`?o0000Qoooool0
08;ooooo0_l0000Pooooo`;o00001_ooool00ol0003oooooooooo`0`ooooo`;o0000Qoooool0087o
oooo0_l0000>ooooo`;o00006Oooool3o`000;Wooooo0021ooooo`;o00002oooool2o`000003oooo
ool0003o000001Wooooo0_l00007ooooo`;o00003oooool2o`000:3ooooo002>ooooo`;o00007?oo
ool00ol0003oooooooooo`06ooooo`;o00003oooool2o`0000Wooooo0_l0002Eooooo`00S_ooool2
o`0001cooooo0ol0000Rooooo`;o00003_ooool4o`0008?ooooo0021ooooo`;o0000:Oooool3o`00
00?ooooo0_l0000]ooooo`Co0000Poooool0087ooooo0_l00007ooooo`;o00008?ooool00ol0003o
ooooooooo`03ooooo`;o00005?ooool2o`0001Sooooo0_l00024ooooo`00R_ooool2o`0000Sooooo
0_l0000Fooooo`03o`000?oooooooooo01Wooooo0_l0002Nooooo`00POooool2o`00017ooooo0_l0
000Fooooo`03o`000?oooooooooo017ooooo0_l0002Vooooo`00POooool2o`0002Wooooo00?o0000
ooooooooool02_ooool2o`0000Cooooo0ol0002Vooooo`00POooool2o`0002Wooooo0ol0000:oooo
o`;o00001?ooool2o`0002;ooooo0_l00023ooooo`00[?ooool00ol0003oooooooooo`0@ooooo`;o
00008_ooool2o`0008?ooooo002/ooooo`03o`000?oooooooooo0;Wooooo0021ooooo`;o0000:Ooo
ool00ol0003oooooooooo`05ooooo`;o0000/_ooool0087ooooo0_l0000Eooooo`;o00004_ooool2
o`0000Kooooo0_l0002booooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B43
ooooo`Ko00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo0_l0000Mooooo`;o0000;?oo
ool2o`0006gooooo0025ooooo`;o00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo0_l0
00000ooooooo0000o`000004ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo01cooooo0_l00009ooooo`;o00003_ooool2o`00017ooooo
0_l0001]ooooo`00POooool6o`0000;ooooo00Go410@oooooooooooooooooa0@4002ooooo`;o0000
00?oooooo`000?l000001Oooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool09oooool2o`0000kooooo0_l0000Aooooo`;o0000KOooool0087ooooo0_l0
0006ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP04ooooo`;o0000
00?oooooogMgMolb<S801Oooool3o`0000;ooooo0_l00016ooooo`;o0000KOooool0087ooooo0_l0
0006ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`?o0000
00?o<S8bolc<c?ooool01?ooool00ol0003oooooooooo`02ooooo`;o00000oooool2o`0000?ooooo
0_l0002[ooooo`00QOooool2o`0000;ooooo00Ko410@oooooooooooooooooa0@4?ooool2o`0000co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oo
oooo0_l00003ooooo`;o0000Zoooool008Gooooo0_l00002ooooo`06ogMgMonHV9SooooooiRHV?mg
MgOooooo0_l00008ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo00Sooooo0_l0
002_ooooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool02?ooool2o`0001;ooooo0_l0002K
ooooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool00_l0000Jooooo`;o0000Voooool008Go
oooo0_l0000Uooooo`03o`000?oooooooooo00;o0000]oooool008Gooooo0_l0000Uooooo`?o0000
^Oooool008cooooo0_l0000Nooooo`03o`000?oooooooooo02Wooooo1?l0002<ooooo`00S?ooool2
o`0001kooooo00?o0000ooooooooool0:Oooool4o`0000kooooo0_l0001looooo`00[?ooool00ol0
003oooooooooo`0kooooo`;o0000O?ooool00:cooooo00?o0000ooooooooool03oooool2o`0003ko
oooo0_l0001Xooooo`00S?ooool2o`0001kooooo00?o0000ooooooooool01Oooool2o`0000Sooooo
0_l0000nooooo`;o0000J?ooool008cooooo1?l0000Looooo`03o`000?oooooooooo00Gooooo0_l0
000Sooooo`?o00003?ooool2o`0007kooooo002>ooooo`;o00007?ooool00ol0003oooooooooo`0E
ooooo`;o00002Oooool2o`0000Sooooo0ol0000<ooooo`;o00005Oooool2o`0006Oooooo0024oooo
o`;o00009_ooool3o`0001Gooooo1?l00007ooooo`;o0000;_ooool2o`0006Oooooo0024ooooo`;o
00009_ooool00ol0003oooooooooo`0Gooooo`;o00005?ooool2o`0008[ooooo002;ooooo`;o0000
7oooool00ol0003oooooooooo`06ooooo`;o00002?ooool2o`0001_ooooo0_l0002:ooooo`00Rooo
ool2o`0001oooooo00?o0000ooooooooool00_l00004ooooo`;o00002?ooool2o`0000Kooooo0_l0
002Oooooo`00Ooooool3o`0002[ooooo00?o0000ooooooooool00_l000000ooooooo0000o`00000C
ooooo`;o0000Woooool007oooooo0ol0000Aooooo`;o00005oooool00ol0003oooooooooo`03oooo
o`;o00001_ooool2o`0001Cooooo0_l0002Fooooo`00Ooooool2o`0001;ooooo0_l0000Gooooo`03
o`000?oooooooooo00_ooooo0_l0000Dooooo`;o0000U_ooool007oooooo0_l0000[ooooo`03o`00
0?oooooooooo00_ooooo0_l0000Eooooo`;o00002?ooool3o`0000gooooo0_l0001kooooo`00[?oo
ool00ol0003oooooooooo`0;ooooo`;o00005Oooool2o`0000Sooooo0ol0000=ooooo`Co0000NOoo
ool009Wooooo0_l0000Aooooo`?o0000?Oooool3o`0007Wooooo002Iooooo`;o00004Oooool00ol0
003oooooooooo`07ooooo`;o00009?ooool2o`0000kooooo0_l0001jooooo`00[?ooool00ol0003o
ooooooooo`07ooooo`;o00009?ooool2o`0000kooooo0_l0001jooooo`002Oooool4o`000003oa0@
4?oooooooooo01Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003o
k^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Ko
oooo00?o0000ooooooooool06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b
<_oMgMd06?ooool4o`000003oa0@4?oooooooooo01;ooooo000;ooooo`03o`000?oooooooooo01So
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07oooo
o`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool0
0omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A003ooooo`;o00000_ooool00omgMgOo<S8booooo`0Eooooo`03o`00
0?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01oooool2o`0000Gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8boooo
o`0Iooooo`03o`000?oooooooooo01Cooooo0006o`0000Gooooo00?o0000ooooooooool04?ooool6
o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o
0000ooooooooool01Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`00
0?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP04ooooo`;o00000oooool2o`0001Gooooo00?o0000ooooooooool06?ooool01Ol@413o
oooooooooooooooo410@00?ooooo0_l00007ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000oooo
ooooool01_ooool2o`0000Gooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00gooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0H
ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb
<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00kooooo
00Go0000ooooooooooooooooo`00000=ooooo`04oiRHV?lQ8B7ok^k^ooooo`;o00001?ooool00omg
MgOo0000o`00000Eooooo`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`000003
ooooo`;o00002?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Gooooo0_l00007
ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0>ooooo`05o`000?oo
ooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Wooooo
00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooo
oooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oo
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool0
1Ol0003ooooooooooooooooo000000Kooooo0_l00006ooooo`03ogMgMomVIVKooooo00;o000000Ko
ooooo`000?lQ8B7o0000oc8b<_o<c<`Fooooo`03o`000?oooooooooo00Cooooo0_l0000Booooo`05
o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVo`000002o`000006ooooool0003o8B4Q
o`000?lb<S;oc<c<1_ooool2o`0000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<
c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[ooooo00?o0000ooooooooool05?ooool0
00_ooooo00?o0000ooooooooool06?ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41001_ooool2o`0000;ooooo
0_l00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool2o`0001?ooooo
0ol00004ooooo`;o00001_ooool2o`0000?ooooo0_l00005ooooo`05oa0@4?ooooooooooooooool@
41003oooool6o`0000_ooooo0_l00006ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0
003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000oooo
ooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b
<P04ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`00
0?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0:ooooo`;o000000Co^[ZjoooooonH
V9So410@1?ooool00ol0003oooooooooo`03ooooo`;o00004oooool00ol0003oooooooooo`0<oooo
o`;o00000oooool2o`0000Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@41000_ooool3o`0000_ooooo0_l00006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413o
oooooooooooooooo<S8b00Cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Doooo
o`002Oooool00omEEEGoIVIVo`00000Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`00
00Cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00013ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0001Oooooo
00?o0000ooooooooool01?ooool2o`0001;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00006Ooo
ool00omEEEGoIVIVo`00000Fooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o00004oooool2
o`0001?ooooo0_l00029ooooo`00[?ooool00ol0003oooooooooo`0Iooooo`;o00004oooool2o`00
08Wooooo0028ooooo`;o00002_ooool2o`0001Kooooo00?o0000ooooooooool04_ooool2o`0002_o
oooo0_l0001]ooooo`;o00000_ooool2o`0000Gooooo0028ooooo`;o00002_ooool2o`0001Kooooo
00?o0000ooooooooool03?ooool2o`0000Cooooo0_l0000>ooooo`;o00006oooool2o`0006gooooo
00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd5ooooo`00N_ooool2o`00033ooooo00?o0000oooooooo
ool03?ooool2o`0000Cooooo0_l0000>ooooo`;o0000Roooool01?oMgMgo0000oa0@4?o<c<`6oooo
o`001oooooooo`0004co00003?ooool01?o^k^ko8B4Qoa0@4?o^k^h6ooooo`001oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooooooo0_l00002oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01?l0003oooooooooooooool2
o`0000;ooooo00Co0000oooooooooooooooo0_l00003ooooo`03o`000?oooooooooo00Gooooo0_l0
0006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool01?lQ8B7oMgMgogMg
Molb<S86ooooo`001oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01Wooooo0ol0
0006ooooo`;o00000oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`09ooooo`;o00000_ooool2o`0000Gooooo002>
ooooo`Co00006_ooool00ol0003oooooooooo`07ooooo`;o00002?ooool2o`0000Kooooo0_l0002N
ooooo`00S_ooool4o`0001[ooooo00?o0000ooooooooool01oooool2o`0000Sooooo0_l0002Voooo
o`00Q?ooool2o`0002Kooooo00?o0000ooooooooool0^Oooool008Cooooo0_l0000Vooooo`03o`00
0?oooooooooo017ooooo0_l0002Vooooo`00[?ooool00ol0003oooooooooo`0Aooooo`;o00001_oo
ool2o`0002;ooooo0_l0001jooooo`00Q?ooool2o`0000Gooooo0_l0000Oooooo`?o00003?ooool2
o`0000_ooooo0_l0000Rooooo`;o0000N_ooool008Cooooo0_l00005ooooo`;o00007oooool00ol0
003oooooooooo`0<ooooo`;o0000Zoooool008Oooooo0_l0000Sooooo`03o`000?oooooooooo00go
oooo0_l0000Cooooo`?o00006Oooool2o`0007Wooooo001oooooo`;o00001_ooool2o`0002?ooooo
00?o0000ooooooooool01oooool2o`0000Cooooo0_l0000Cooooo`?o00002?ooool2o`0000kooooo
0ol0001iooooo`00Ooooool2o`0000[ooooo0_l00006ooooo`;o00001?ooool2o`00017ooooo00?o
0000ooooooooool01oooool3o`0002?ooooo0_l0000>ooooo`?o0000NOooool007oooooo0_l0000:
ooooo`;o00001_ooool2o`0000Cooooo0_l0000Aooooo`03o`000?oooooooooo00Sooooo0_l0000?
ooooo`;o00002?ooool2o`0009Cooooo001oooooo`;o00002_ooool2o`0001oooooo00?o0000oooo
ooooool06Oooool2o`0000Sooooo0_l0002Dooooo`00P?ooool2o`0000Wooooo0_l0000Oooooo`03
o`000?oooooooooo00Cooooo0_l0001<ooooo`Co0000Hoooool0083ooooo0_l00005ooooo`;o0000
8oooool00ol0003oooooooooo`04ooooo`;o00001_ooool2o`0000[ooooo0_l0000hooooo`Co0000
Hoooool008Oooooo0_l0000Sooooo`?o00003?ooool2o`0000[ooooo0_l0000iooooo`;o0000I?oo
ool00:cooooo00?o0000ooooooooool0??ooool2o`0001Gooooo0_l0001Tooooo`00Q?ooool2o`00
00Sooooo0_l0000Looooo`;o00008oooool2o`0001Sooooo0_l0001kooooo`00Ooooool2o`0000?o
oooo0_l00008ooooo`;o00007?ooool2o`0002?ooooo0_l0002Eooooo`00Ooooool2o`0002_ooooo
00?o0000ooooooooool00oooool2o`0000cooooo0_l0000/ooooo`;o0000N?ooool00:cooooo00?o
0000ooooooooool00oooool2o`0000cooooo0_l0000>ooooo`;o00006oooool3o`0007Sooooo001o
ooooo`;o00001oooool2o`0002;ooooo00?o0000ooooooooool08Oooool2o`0000_ooooo0_l0000>
ooooo`;o0000NOooool007oooooo0_l00007ooooo`;o00008_ooool00ol0003oooooooooo`0^oooo
o`;o0000ROooool00:cooooo0ol0002iooooo`00Ooooool2o`00013ooooo0_l00003ooooo`;o0000
5?ooool00ol0003oooooooooo`0^ooooo`;o0000ROooool007oooooo0_l0000@ooooo`;o00000ooo
ool4o`0001;ooooo00?o0000ooooooooool0;_ooool2o`0008Wooooo001oooooo`;o00005oooool2
o`0001;ooooo00?o0000ooooooooool08Oooool2o`0009Kooooo002/ooooo`03o`000?oooooooooo
027ooooo0_l0000;ooooo`;o0000ROooool009Cooooo0_l0000Fooooo`03o`000?oooooooooo00;o
oooo0_l0000Zooooo`;o00008_ooool2o`0006Gooooo002Dooooo`;o00005_ooool00ol0003ooooo
ooooo`02ooooo`;o00004oooool2o`0001;ooooo0_l0000Aooooo`;o00004_ooool2o`0006Gooooo
002?ooooo`;o00006oooool3o`0001Oooooo0_l0000Booooo`;o00004Oooool2o`0007Wooooo002?
ooooo`;o00006oooool3o`0002gooooo0_l0000>ooooo`;o0000N_ooool009Oooooo0_l0000Coooo
o`03o`000?oooooooooo02gooooo0_l0000>ooooo`;o0000N_ooool009Oooooo1?l0000Aooooo`03
o`000?oooooooooo01oooooo0_l0002Hooooo`00VOooool2o`00017ooooo00?o0000ooooooooool0
7oooool2o`00033ooooo0_l0001Vooooo`00S?ooool2o`0001kooooo00?o0000ooooooooool02Ooo
ool2o`0000?ooooo0_l0000Looooo`;o00008oooool2o`0006Kooooo002<ooooo`;o00007_ooool0
0ol0003oooooooooo`09ooooo`;o00000oooool2o`0001cooooo0_l0002;ooooo`00ROooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool03oooool2o`000:Sooooo0029ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool03oooool2o`0000Cooooo0_l0002Rooooo`00ROoo
ool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003ooooo
ooooo`03ooooo`?o00005Oooool2o`0001?ooooo0_l0002=ooooo`00ROooool01Ol0003ooooooooo
oooooooo000000;ooooo0_l00009ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`0Zooooo`;o0000SOooool008Wooooo00Go0000oooooooooooooooo
o`000002ooooo`;o00002_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`0jooooo`;o0000OOooool008Wooooo00Go410@oooooooooooo
oooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0=ooooo`;o00001_ooool2o`0000Oooooo0_l0000:ooooo`;o00003_ooool2o`0007go
oooo0021ooooo`;o00001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oo
ooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03Oooool2o`00
00Kooooo0_l00007ooooo`;o00002_ooool2o`0008gooooo0021ooooo`;o00001_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool0
0ol0003oooooooooo`0Dooooo`;o00008oooool2o`0007kooooo002/ooooo`03o`000?oooooooooo
00_ooooo0ol00006ooooo`;o00008oooool2o`0001Cooooo0_l0001Xooooo`00[?ooool00ol0003o
ooooooooo`0;ooooo`?o0000;?ooool2o`0001?ooooo0_l0001Xooooo`00[?ooool00ol0003ooooo
ooooo`06ooooo`;o00000oooool2o`0000kooooo1?l0000Kooooo`;o0000OOooool009gooooo0_l0
000=ooooo`?o00001_ooool2o`0000?ooooo0_l0000>ooooo`Co0000;_ooool2o`0006[ooooo002M
ooooo`;o00003Oooool00ol0003oooooooooo`1=ooooo`;o0000J_ooool008[ooooo0_l0000Poooo
o`03o`000?oooooooooo01;ooooo0_l0002Uooooo`00R_ooool2o`0000;ooooo0_l0000Looooo`03
o`000?oooooooooo01;ooooo0_l0002Uooooo`00Roooool2o`000003ooooool0003o000001cooooo
00?o0000ooooooooool04_ooool2o`0000Sooooo0_l0002Kooooo`00Roooool2o`0001oooooo00?o
0000ooooooooool07?ooool2o`0001Wooooo0_l00020ooooo`00Roooool2o`0001oooooo00?o0000
ooooooooool06_ooool2o`0001_ooooo0_l00020ooooo`00Roooool2o`0001gooooo0ol0000Koooo
o`?o0000WOooool00:[ooooo1Ol0000Iooooo`;o00002_ooool2o`0000kooooo0_l00022ooooo`00
POooool2o`0002Wooooo00?o0000ooooooooool09?ooool3o`0000kooooo0_l00022ooooo`00POoo
ool2o`0002Wooooo0_l0000Uooooo`;o0000Toooool00:cooooo0_l0002jooooo`00Yoooool2o`00
00?ooooo00?o0000ooooooooool03oooool2o`0003Wooooo0_l0001]ooooo`00OOooool2o`0002So
oooo0_l00003ooooo`03o`000?oooooooooo00oooooo0_l0000iooooo`;o0000KOooool007gooooo
0_l0000@ooooo`;o00006oooool2o`000;[ooooo002?ooooo`;o00006oooool2o`0003Kooooo0_l0
0022ooooo`00[?ooool3o`0003Gooooo0_l00022ooooo`00[?ooool00ol0003oooooooooo`0Eoooo
o`;o0000X_ooool008;ooooo0_l0000Xooooo`03o`000?oooooooooo01Gooooo0_l0002Rooooo`00
P_ooool2o`0002Sooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Ooo
ool00:cooooo00?o0000ooooooooool0^Oooool009[ooooo0_l0000:ooooo`;o00001?ooool00ol0
003oooooooooo`17ooooo`;o0000L?ooool009[ooooo0_l00004ooooo`;o00001?ooool2o`0000Co
oooo0_l0000<ooooo`;o00001oooool2o`00037ooooo0_l0001`ooooo`00X?ooool2o`0000[ooooo
0ol0000;ooooo`;o00001oooool2o`000:?ooooo002/ooooo`03o`000?oooooooooo00?ooooo0_l0
002dooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool00_ooool3o`000;Cooooo002>oooo
o`;o00007?ooool00ol0003oooooooooo`02ooooo`;o0000]Oooool00:cooooo00?o0000oooooooo
ool0;oooool2o`0008Sooooo002Gooooo`;o00004oooool00ol0003oooooooooo`07ooooo`;o0000
9_ooool2o`0008Sooooo002Aooooo`06onk^k_lb<S;o0000oc8b<_o^k^kooooo0_l00002ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo0_l000000ooooooo0000ooooo`08oooo
o`;o00005Oooool2o`0000oooooo0_l00028ooooo`00Q?ooool2o`0000_ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool01?mgMgOo<S8booooooooool2o`000003ooooool0003o
oooo00Oooooo0_l00009ooooo`;o00002oooool2o`0000oooooo0_l00028ooooo`00Q?ooool2o`00
00_ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo00Co0000
ooooool0003o00001Oooool2o`0000Wooooo0_l0000Iooooo`;o0000Roooool0097ooooo00Go0000
ooooooooooooooooo`00000=ooooo`;o000000CoMgMgoc8b<_l0003o00000oooool4o`0002_ooooo
0_l0002;ooooo`00Soooool3o`0000?ooooo00Co0000oooooooooooooooo0_l00007ooooo`?o0000
00Co<S8bolc<c?l0003o00000oooool3o`0002cooooo0_l0000Dooooo`;o0000MOooool008oooooo
0_l000001Ol@413ooooooooooooooooo410@00?ooooo0_l00007ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool03_ooool2o`0001cooooo0_l0000Dooooo`;o0000MOooool0097ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool03_ooool2o`0001cooooo0_l0002;ooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo1?l00006ooooo`03o`000?oooooooooo00Gooooo0_l0000Uooooo`;o00004Oooool2o`0007So
oooo002/ooooo`03o`000?oooooooooo00Gooooo0_l0000hooooo`;o0000N?ooool009cooooo0_l0
000>ooooo`03o`000?oooooooooo0;Wooooo002Looooo`;o00003_ooool00ol0003oooooooooo`0X
ooooo`;o0000Soooool009kooooo0_l0000<ooooo`?o00003?ooool2o`0001[ooooo0_l0002?oooo
o`00P?ooool2o`0001cooooo0_l0000<ooooo`03o`000?oooooooooo00cooooo0_l0002[ooooo`00
P?ooool2o`0000oooooo0_l00003ooooo`;o00001_ooool5o`0000Wooooo00?o0000ooooooooool0
5oooool2o`000:3ooooo002Aooooo`;o00000oooool2o`0000Kooooo1Ol00009ooooo`03o`000?oo
oooooooo00_ooooo0_l0000:ooooo`;o0000X?ooool009kooooo0_l0000<ooooo`03o`000?oooooo
oooo00_ooooo0_l00008ooooo`;o0000X_ooool00:cooooo00?o0000ooooooooool05Oooool2o`00
0:;ooooo002/ooooo`03o`000?oooooooooo01Cooooo1?l0002Qooooo`00[?ooool00ol0003ooooo
ooooo`0Dooooo`Co0000XOooool008gooooo0_l0000Mooooo`?o0000^Oooool008gooooo0_l0000M
ooooo`?o00004_ooool2o`000:Gooooo002=ooooo`;o00007Oooool00ol0003oooooooooo`0Boooo
o`;o0000YOooool008gooooo0_l0000Kooooo`?o0000^oooool008gooooo0ol0000Jooooo`?o0000
^oooool008kooooo0_l0000Jooooo`?o0000^oooool00:[ooooo0ol0002kooooo`00Woooool2o`00
00_ooooo00?o0000ooooooooool0^Oooool009Gooooo0_l00008ooooo`;o00000_ooool2o`0000Oo
oooo0ol0002iooooo`00UOooool2o`0000cooooo0_l00007ooooo`03o`000?oooooooooo023ooooo
0_l0002Gooooo`00Soooool2o`0001_ooooo00?o0000ooooooooool08?ooool2o`0009Oooooo0029
ooooo`;o00001?ooool2o`0001_ooooo00?o0000ooooooooool03_ooool2o`0000gooooo0ol0002I
ooooo`00ROooool2o`00027ooooo00?o0000ooooooooool03_ooool2o`0000gooooo0ol0002Ioooo
o`00V?ooool2o`0001;ooooo00?o0000ooooooooool00_l0000;ooooo`;o0000Z_ooool009Sooooo
0_l0000Booooo`03o`000?oooooooooo00;o00002oooool2o`0000gooooo0_l0002Kooooo`00[?oo
ool00ol0003oooooooooo`0Kooooo`?o0000Voooool00:cooooo00?o0000ooooooooool06oooool3
o`0009_ooooo002/ooooo`?o0000^Oooool009_ooooo0_l0000?ooooo`03o`000?oooooooooo0;Wo
oooo002Kooooo`;o00003oooool00ol0003oooooooooo`2iooooo`00Z_ooool3o`0002oooooo0_l0
002:ooooo`00Roooool2o`0001gooooo0ol0000_ooooo`;o0000R_ooool008Wooooo00Gok^k^oc8b
<_l0003o0000onk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o
0000o`000?oMgMd01Oooool00ol0003oooooooooo`2iooooo`00ROooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Kooooo0_l000000olb<S;ooooooooo
o`03ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`03oa0@4?oooooooooo00;o00003Oooool0
0onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0^Oooool0
08Wooooo00?o0000ooooooooool00_l0000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b
<_ooool01?ooool3o`0001?ooooo0_l0002Tooooo`00ROooool00ol0003oooooooooo`02o`0000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool04oooool2o`000:Cooooo0029ooooo`03oa0@4?oooooooooo00;o00003_ooool00onYZJWo
MgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0^Oooool008Wooooo
00?oMgMgoiRHV?ooool00_l0000;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo01Cooooo0_l0000Booooo`;o0000Soooool008Wooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP02o`0000Wooooo1Ol00004ooooo`Co00001_ooool00ol0003o
ooooooooo`0Booooo`Co00004_ooool2o`0008oooooo002>ooooo`;o00007?ooool00ol0003ooooo
ooooo`0Aooooo`?o0000YOooool00:cooooo00Co0000ooooool0003o00004?ooool2o`000:Kooooo
002/ooooo`04o`000?oooooo0000o`0002Cooooo0_l0002Booooo`00[?ooool3o`0002Gooooo0_l0
002Booooo`00Soooool2o`0001_ooooo00?o0000ooooooooool0^Oooool008oooooo0_l00008oooo
o`;o00003oooool4o`000;[ooooo002Iooooo`;o00003oooool4o`000;[ooooo002Kooooo`;o0000
3oooool00ol0003oooooooooo`2iooooo`00Voooool4o`0000gooooo00?o0000ooooooooool0^Ooo
ool009gooooo0_l0000=ooooo`03o`000?oooooooooo00cooooo0_l0002[ooooo`00T_ooool2o`00
01Cooooo0_l00002ooooo`03o`000?oooooooooo00_ooooo0ol0002[ooooo`00T_ooool2o`0001Co
oooo0_l00002ooooo`?o00002oooool2o`000:cooooo002Tooooo`;o00001_ooool00ol0003ooooo
ooooo`0Mooooo`;o0000V_ooool00:Cooooo0_l00006ooooo`03o`000?oooooooooo01gooooo0_l0
002Jooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`06oooo
o`;o0000/Oooool00:cooooo00?o0000ooooooooool01_ooool2o`000;7ooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooo
oooo01Sooooo0_l0002Oooooo`00[?ooool3o`0001Sooooo0_l0002Oooooo`00Uoooool2o`0001?o
oooo00?o0000ooooooooool0^Oooool009Kooooo0ol0000Cooooo`03o`000?oooooooooo0;Wooooo
002=ooooo`;o00001oooool2o`0000;ooooo0_l0000@ooooo`03o`000?oooooooooo0;Wooooo002=
ooooo`;o00002oooool2o`00013ooooo00Co0000ooooool0003o0000^?ooool00:cooooo00Co0000
ooooool0003o0000^?ooool00:cooooo00?o0000ooooooooool0^Oooool009_ooooo0_l0000>oooo
o`;o0000^oooool009_ooooo0_l0000>ooooo`Co0000^Oooool00:Kooooo0_l00004ooooo`03o`00
0?oooooooooo0;Wooooo002Vooooo`;o00001?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00X?ooool2o`0000[ooooo00?o0000ooooooooool0^Oooool00:3o
oooo0_l0000:ooooo`03o`000?oooooooooo0;Wooooo002Rooooo`Co000000?o410@ooooooooool0
0oooool00ol0003oooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0;Wooooo002Tooooo`03o`000?oooooooooo00Gooooo0ol0002iooooo`00Y?ooool00ol0
003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003ooooo
ooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00X_ooool00omEEEGoIVIVo`000033
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Z_ooool0
1?l@413o0000o`000?l0002jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0
003oooooooooo`2jooooo`00Zoooool01_l0003oMgMgo`000?l0003oEEEEonk^k[Oooooo002[oooo
o`06o`000?mEEEGok^k^oooooomgMgOoEEEE]oooool00:_ooooo00?o0000onk^k_ooool00_ooool0
0ol0003oooooooooo`2eooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo
0;Gooooo002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoIVIV]oooool00:[ooooo00?o410@o`00
0?mgMgL00_l000000omVIVKok^k^ooooo`2fooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.53668 .16971 Mdot
.64881 .41326 Mdot
.48634 .3737 Mdot
.54458 .58287 Mdot
.55568 .32011 Mdot
.41343 .76811 Mdot
.47773 .67304 Mdot
.58435 .88156 Mdot
.68941 .64664 Mdot
.52365 .29756 Mdot
.56796 .52893 Mdot
.50708 .97183 Mdot
.61918 .72467 Mdot
.56463 .43337 Mdot
.4704 .9864 Mdot
.43754 .70461 Mdot
.57379 .30318 Mdot
.61247 .74071 Mdot
.40909 .57335 Mdot
.43067 .09549 Mdot
.59922 .76007 Mdot
.6566 .54207 Mdot
.64681 .60177 Mdot
.59538 .77399 Mdot
.37418 .70213 Mdot
.52518 .77489 Mdot
.54815 .64597 Mdot
.41469 .63129 Mdot
.47521 .04907 Mdot
.65041 .43452 Mdot
.56078 .82347 Mdot
.69328 .64147 Mdot
.61761 .82444 Mdot
.61498 .47375 Mdot
.6051 .63795 Mdot
.38069 .38435 Mdot
.67011 .32987 Mdot
.46246 .78904 Mdot
.52727 .09891 Mdot
.48489 .99398 Mdot
.37598 .72878 Mdot
.61713 .55872 Mdot
.52866 .81604 Mdot
.56259 .20353 Mdot
.48346 .10365 Mdot
.5933 .52247 Mdot
.55761 .41073 Mdot
.70936 .54193 Mdot
.39777 .48052 Mdot
.46868 .05465 Mdot
.70836 .53583 Mdot
.58618 .17101 Mdot
.72998 .72787 Mdot
.5703 .73369 Mdot
.56523 .75177 Mdot
.66108 .73472 Mdot
.57174 .89684 Mdot
.57077 .29277 Mdot
.70268 .44452 Mdot
.45897 .10962 Mdot
.58978 .56334 Mdot
.55647 .05999 Mdot
.53793 .11397 Mdot
.42217 .46482 Mdot
.61239 .82336 Mdot
.68077 .68749 Mdot
.51332 .27615 Mdot
.45765 .74771 Mdot
.45923 .78899 Mdot
.56875 .81927 Mdot
.59297 .33994 Mdot
.45966 .32589 Mdot
.53066 .31839 Mdot
.46163 .23388 Mdot
.53762 .11364 Mdot
.48197 .64318 Mdot
.72963 .72858 Mdot
.56618 .6642 Mdot
.56044 .1353 Mdot
.40481 .61926 Mdot
.44684 .90992 Mdot
.64751 .42362 Mdot
.54913 .5214 Mdot
.61615 .57605 Mdot
.62966 .8097 Mdot
.4287 .67214 Mdot
.56317 .34037 Mdot
.58185 .42268 Mdot
.54512 .23833 Mdot
.45055 .73534 Mdot
.37052 .6588 Mdot
.76455 .45203 Mdot
.48058 .25552 Mdot
.59002 .4617 Mdot
.45496 .27459 Mdot
.75854 .40856 Mdot
.56194 .41823 Mdot
.70439 .54977 Mdot
.72152 .74879 Mdot
.5504 .24435 Mdot
.56698 .21762 Mdot
.50098 .16565 Mdot
.50581 .97057 Mdot
.58689 .24671 Mdot
.49883 .91681 Mdot
.61672 .5039 Mdot
.60479 .38359 Mdot
.41054 .39462 Mdot
.48299 .25653 Mdot
.56237 .8278 Mdot
.54875 .3637 Mdot
.54856 .56007 Mdot
.69433 .63405 Mdot
.38471 .31506 Mdot
.42801 .48136 Mdot
.58088 .61432 Mdot
.67346 .71884 Mdot
.68484 .68327 Mdot
.66285 .32071 Mdot
.61874 .72352 Mdot
.61856 .70504 Mdot
.48415 .0493 Mdot
.56299 .82786 Mdot
.53244 .63933 Mdot
.4018 .19954 Mdot
.74153 .35031 Mdot
.62032 .3338 Mdot
.49707 .31043 Mdot
.65033 .59455 Mdot
.59662 .27365 Mdot
.45902 .98786 Mdot
.40514 .72884 Mdot
.48822 .87382 Mdot
.53194 .09741 Mdot
.65858 .29205 Mdot
.44195 .07755 Mdot
.52625 .30793 Mdot
.58601 .86995 Mdot
.46159 .98499 Mdot
.64441 .17315 Mdot
.54261 .41127 Mdot
.43205 .73157 Mdot
.57446 .30397 Mdot
.40377 .18517 Mdot
.6488 .77403 Mdot
.42298 .30838 Mdot
.58726 .4572 Mdot
.44429 .00628 Mdot
.48217 .14772 Mdot
.51588 .74261 Mdot
.59268 .78091 Mdot
.44606 .36632 Mdot
.39085 .41731 Mdot
.6381 .25578 Mdot
.55515 .13315 Mdot
.67106 .72004 Mdot
.66992 .33271 Mdot
.64314 .26422 Mdot
.45218 .82512 Mdot
.56022 .1332 Mdot
.3867 .81217 Mdot
.38202 .62171 Mdot
.52777 .81312 Mdot
.55663 .20414 Mdot
.65352 .76308 Mdot
.46962 .93202 Mdot
.47117 .79581 Mdot
.63804 .24995 Mdot
.42834 .11092 Mdot
.50377 .29456 Mdot
.50148 .76719 Mdot
.56356 .34737 Mdot
.44082 .23611 Mdot
.60862 .83461 Mdot
.75369 .39056 Mdot
.38956 .45903 Mdot
.42925 .52176 Mdot
.49338 .05822 Mdot
.61272 .20607 Mdot
.44138 .97373 Mdot
.42143 .37247 Mdot
.36955 .66413 Mdot
.53567 .48289 Mdot
.69074 .63352 Mdot
.73873 .34646 Mdot
.6991 .62839 Mdot
.39601 .85673 Mdot
.5085 .84949 Mdot
.43939 .01743 Mdot
.40316 .18736 Mdot
.43556 .65395 Mdot
.53166 .03632 Mdot
.60882 .84407 Mdot
.36352 .42193 Mdot
.48625 .98878 Mdot
.58559 .43198 Mdot
.77304 .51841 Mdot
.62041 .46243 Mdot
.45956 .68886 Mdot
.45259 .6752 Mdot
.4737 .3118 Mdot
.54776 .30489 Mdot
.77188 .55301 Mdot
.58082 .24481 Mdot
.50478 .68409 Mdot
.39575 .65085 Mdot
.55128 .5451 Mdot
.53289 .57782 Mdot
.56779 .5482 Mdot
.64669 .64048 Mdot
.57176 .64605 Mdot
.46658 .93099 Mdot
.41543 .48162 Mdot
.56464 .21774 Mdot
.57946 .61037 Mdot
.38206 .78327 Mdot
.53742 .49256 Mdot
.4367 .14788 Mdot
.51388 .96813 Mdot
.58399 .59971 Mdot
.7023 .46512 Mdot
.48973 .92736 Mdot
.41548 .83716 Mdot
.42237 .61534 Mdot
.50943 .22498 Mdot
.64217 .37759 Mdot
.49591 .27556 Mdot
.46683 .98592 Mdot
.50643 .00575 Mdot
.4797 .76115 Mdot
.50401 .39727 Mdot
.76827 .56399 Mdot
.43015 .21825 Mdot
.55219 .63623 Mdot
.48279 .79166 Mdot
.60159 .27486 Mdot
.62505 .69492 Mdot
.58771 .25529 Mdot
.55749 .06217 Mdot
.45645 .87391 Mdot
.42006 .86108 Mdot
.59225 .33799 Mdot
.69441 .64585 Mdot
.44199 .31145 Mdot
.62902 .24513 Mdot
.51154 .18978 Mdot
.58933 .32962 Mdot
.54159 .11705 Mdot
.36263 .4771 Mdot
.428 .50084 Mdot
.43567 .65092 Mdot
.64445 .27683 Mdot
.51455 .79071 Mdot
.50961 .75023 Mdot
.54803 .78987 Mdot
.47108 .64699 Mdot
.58176 .88053 Mdot
.7089 .49729 Mdot
.40732 .33168 Mdot
.55281 .63401 Mdot
.40018 .77199 Mdot
.4577 .3031 Mdot
.47301 .1489 Mdot
.50667 .13066 Mdot
.56216 .44337 Mdot
.44321 .84984 Mdot
.39607 .23963 Mdot
.46901 .83355 Mdot
.38641 .30585 Mdot
.554 .77576 Mdot
.52136 .29 Mdot
.39885 .48508 Mdot
.63441 .24731 Mdot
.42758 .32743 Mdot
.46141 .19374 Mdot
.70676 .55792 Mdot
.56993 .52779 Mdot
.38868 .49765 Mdot
.51799 .08376 Mdot
.50855 .33503 Mdot
.43489 .30041 Mdot
.66936 .33331 Mdot
.52812 .94599 Mdot
.41316 .36479 Mdot
.43475 .52348 Mdot
.50435 .22242 Mdot
.37581 .50336 Mdot
.59056 .48842 Mdot
.47268 .92661 Mdot
.73813 .34687 Mdot
.69837 .43024 Mdot
.50821 .96443 Mdot
.69753 .43867 Mdot
.51298 .56323 Mdot
.69553 .40054 Mdot
.5023 .00943 Mdot
.38476 .68026 Mdot
.48449 .98446 Mdot
.3812 .87815 Mdot
.40138 .58955 Mdot
.50381 .86126 Mdot
.60342 .28587 Mdot
.69356 .64553 Mdot
.38213 .77048 Mdot
.5633 .4411 Mdot
.70588 .5537 Mdot
.5004 .81559 Mdot
.50076 .66033 Mdot
.64654 .63463 Mdot
.58443 .32889 Mdot
.62436 .70623 Mdot
.42367 .04355 Mdot
.4323 .41115 Mdot
.46062 .1129 Mdot
.61755 .51983 Mdot
.59574 .84987 Mdot
.46401 .29151 Mdot
.43172 .95742 Mdot
.40863 .09613 Mdot
.67392 .212 Mdot
.50381 .72378 Mdot
.40242 .71449 Mdot
.61602 .58403 Mdot
.56811 .15286 Mdot
.5152 .23261 Mdot
.4773 .70273 Mdot
.50009 .63075 Mdot
.59688 .35777 Mdot
.54295 .93463 Mdot
.63924 .26938 Mdot
.45075 .28229 Mdot
.65406 .59497 Mdot
.50596 .33247 Mdot
.4764 .31197 Mdot
.64457 .38751 Mdot
.42546 .81402 Mdot
.52636 .81565 Mdot
.45168 .82403 Mdot
.53815 .28366 Mdot
.7468 .68594 Mdot
.49871 .81575 Mdot
.63923 .39293 Mdot
.42302 .45139 Mdot
.63773 .78538 Mdot
.55415 .62063 Mdot
.42987 .10195 Mdot
.65282 .47702 Mdot
.52147 .33172 Mdot
.58772 .54001 Mdot
.64127 .16788 Mdot
.51586 .96324 Mdot
.69543 .39361 Mdot
.38555 .31936 Mdot
.41054 .68314 Mdot
.6172 .44985 Mdot
.41747 .14088 Mdot
.45038 .16908 Mdot
.51651 .96207 Mdot
.68298 .22217 Mdot
.41187 .83405 Mdot
.46364 .98966 Mdot
.42259 .93821 Mdot
.37141 .69298 Mdot
.50558 .36465 Mdot
.41206 .30152 Mdot
.45713 .98164 Mdot
.57905 .8858 Mdot
.51222 .39021 Mdot
.50805 .90103 Mdot
.49594 .81663 Mdot
.39391 .63545 Mdot
.55777 .20251 Mdot
.70225 .57347 Mdot
.59958 .27144 Mdot
.68351 .36588 Mdot
.61129 .21948 Mdot
.64884 .5864 Mdot
.68782 .36447 Mdot
.65146 .58107 Mdot
.39366 .83237 Mdot
.67507 .35553 Mdot
.39471 .35269 Mdot
.43943 .41091 Mdot
.37502 .27642 Mdot
.53564 .21999 Mdot
.50495 .60945 Mdot
.4324 .96078 Mdot
.56411 .82677 Mdot
.48317 .70026 Mdot
.4804 .22751 Mdot
.55256 .71271 Mdot
.54313 .66754 Mdot
.70896 .55966 Mdot
.47935 .93565 Mdot
.52398 .02979 Mdot
.43324 .96111 Mdot
.60661 .40517 Mdot
.75163 .66149 Mdot
.61331 .43354 Mdot
.43404 .25595 Mdot
.46105 .19725 Mdot
.45554 .36545 Mdot
.55183 .9224 Mdot
.51205 .96601 Mdot
.5507 .63663 Mdot
.51759 .32468 Mdot
.55363 .6431 Mdot
.41541 .54722 Mdot
.38786 .17509 Mdot
.58833 .44003 Mdot
.38338 .64491 Mdot
.54711 .44702 Mdot
.50987 .75429 Mdot
.47459 .28632 Mdot
.57879 .39339 Mdot
.612 .44693 Mdot
.53948 .6837 Mdot
.49376 .71125 Mdot
.5899 .86492 Mdot
.44867 .53993 Mdot
.59882 .66193 Mdot
.60485 .38424 Mdot
.40984 .24764 Mdot
.47529 .83134 Mdot
.49104 .78544 Mdot
.37717 .25426 Mdot
.76732 .44187 Mdot
.61214 .30091 Mdot
.60842 .92916 Mdot
.57735 .2267 Mdot
.4728 .73062 Mdot
.67867 .67653 Mdot
.44485 .96938 Mdot
.56571 .55161 Mdot
.65197 .47984 Mdot
.74241 .69744 Mdot
.52551 .34849 Mdot
.50573 .64875 Mdot
.46114 .20094 Mdot
.40457 .79565 Mdot
.41932 .72482 Mdot
.77034 .48895 Mdot
.53615 .53232 Mdot
.59022 .68048 Mdot
.6194 .54588 Mdot
.4345 .33906 Mdot
.43125 .42789 Mdot
.44632 .2577 Mdot
.58238 .88372 Mdot
.44367 .33862 Mdot
.54371 .11309 Mdot
.63838 .3709 Mdot
.47847 .1047 Mdot
.39256 .25438 Mdot
.50091 .90863 Mdot
.5974 .36707 Mdot
.74211 .34396 Mdot
.49016 .234 Mdot
.53726 .94166 Mdot
.36236 .49047 Mdot
.56218 .44789 Mdot
.69583 .39865 Mdot
.47177 .83257 Mdot
.55604 .26808 Mdot
.42526 .11291 Mdot
.56818 .21852 Mdot
.40705 .49872 Mdot
.58772 .5444 Mdot
.61541 .46833 Mdot
.55177 .05136 Mdot
.49088 .8691 Mdot
.48962 .6324 Mdot
.54213 .79014 Mdot
.40252 .59344 Mdot
.50071 .34651 Mdot
.4894 .74861 Mdot
.5756 .72222 Mdot
.49977 .86313 Mdot
.43574 .60824 Mdot
.53168 .75643 Mdot
.67909 .69222 Mdot
.54997 .30382 Mdot
.48478 .10959 Mdot
.44831 .7772 Mdot
.41445 .62204 Mdot
.52467 .4735 Mdot
.56207 .98484 Mdot
.52537 .4993 Mdot
.64684 .40032 Mdot
.70087 .47471 Mdot
.37996 .59028 Mdot
.44597 .76872 Mdot
.46258 .05514 Mdot
.46464 .99312 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00VOooool2o`0000Wooooo00?o0000ooooooooool01Oooool01?l0003ooooo
o`000?l0002hooooo`00VOooool2o`0000Wooooo00?o0000ooooooooool01Oooool4o`000;Sooooo
002Tooooo`03o`000?oooooooooo00Gooooo0_l0002jooooo`00X_ooool00omEEEGoIVIVo`000007
ooooo`03o`000?oooooooooo0;Wooooo002Hooooo`;o00004_ooool00ol0003oooooooooo`2ioooo
o`00V?ooool2o`0001;ooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o0000/oooool0
0:cooooo00?o0000ooooooooool01?ooool2o`000;?ooooo002/ooooo`03o`000?oooooooooo00Oo
oooo0_l0002`ooooo`00[?ooool00ol0003oooooooooo`07ooooo`;o0000/?ooool009;ooooo0_l0
000Hooooo`03o`000?oooooooooo0;Wooooo002Booooo`;o00006?ooool00ol0003oooooooooo`2i
ooooo`00Xoooool2o`000003ooooool0003o000000Cooooo00?o0000ooooooooool0^Oooool00:?o
oooo0_l000000ooooooo0000o`000004ooooo`?o00003_ooool2o`000:Wooooo002Oooooo`Co0000
2Oooool00ol0003oooooooooo`0>ooooo`;o0000ZOooool009oooooo1?l00006ooooo`;o000000?o
ooooo`000?ooool0^_ooool00:Wooooo0_l000000ooooooo0000ooooo`0@ooooo`?o0000Yoooool0
0:cooooo00?o0000ooooooooool03oooool3o`000:Oooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`?o0000^Oooool009Sooooo0_l0000Booooo`03o`000?oooooooooo0;Wooooo002Hooooo`;o
00004_ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`03ooooo`;o0000
]?ooool00:cooooo00?o0000ooooooooool00oooool2o`000;Cooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002Eooooo`;o00005Oooool00ol0003oooooooooo`2iooooo`00SOooool2o`0000Ko
oooo0_l0000Eooooo`03o`000?oooooooooo00Oooooo0_l0002`ooooo`00SOooool2o`0001gooooo
0ol00006ooooo`?o0000/?ooool009Cooooo0_l0000@ooooo`;o00001?ooool00ol0003ooooooooo
o`06ooooo`;o0000/Oooool009Cooooo0_l0000>ooooo`Co00001?ooool00ol0003oooooooooo`2i
ooooo`00W_ooool2o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`03o`000?oooooooooo
0;Wooooo002Cooooo`?o00002?ooool3o`0000Kooooo0_l00003ooooo`03o`000?oooooooooo00Wo
oooo1?l0002/ooooo`00Toooool3o`0000Wooooo0_l0000;ooooo`03o`000?oooooooooo00Wooooo
1?l0002/ooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`00
0?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00Wo
oooo0ol0002]ooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03
oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0:ooooo`;o
0000[Oooool0087ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002iooooo`00ROooool01Ol0003ooooo
oooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo0;Wooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGo
c<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool01?l0003oooooo`000?l0002h
ooooo`00ROooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool0
0ol0003oooooooooo`07ooooo`04o`000?oooooo0000o`0000kooooo0ol0002Wooooo`00ROooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool03oooool4o`000:Kooooo0029ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00_ooool2o`0000Oooooo1Ol00004ooooo`Co00001_ooool00ol0003ooooo
ooooo`0Aooooo`;o0000Y_ooool0093ooooo0_l0000Jooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`03o`000?oooooooooo0;Wooooo002Gooooo`;o00002_ooool2o`000003ooooool0003o0000
00Cooooo00?o0000ooooooooool0^Oooool009Oooooo0_l0000:ooooo`;o000000?oooooo`000?l0
00001?ooool3o`0001?ooooo0_l0002Tooooo`00[?ooool00ol0003oooooooooo`0Cooooo`;o0000
Y?ooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo0_l0000/ooooo`;o0000S?ooool009_ooooo
0_l0000?ooooo`;o00002_ooool2o`0000kooooo0_l0000@ooooo`;o0000S?ooool009_ooooo0_l0
000?ooooo`03o`000?oooooooooo00Wooooo0_l0000>ooooo`;o00004Oooool2o`0008_ooooo0027
ooooo`;o00008oooool3o`0002cooooo0_l0002;ooooo`00Qoooool2o`0002?ooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool008cooooo0_l0000Nooooo`03o`00
0?oooooooooo0;Wooooo002<ooooo`;o00007_ooool00ol0003oooooooooo`2iooooo`00S?ooool2
o`0001kooooo00?o0000ooooooooool00_l0002gooooo`00Woooool2o`0000_ooooo00?o0000oooo
ooooool00_l0002gooooo`00Woooool2o`0000_ooooo00?o0000ooooooooool0^Oooool008_ooooo
0_l0000Booooo`;o00002oooool3o`000;Wooooo002;ooooo`;o00004_ooool2o`0000_ooooo00?o
0000ooooooooool03oooool4o`000:Kooooo002/ooooo`03o`000?oooooooooo00oooooo1?l0000?
ooooo`;o0000UOooool00:cooooo00?o0000ooooooooool08_ooool2o`0009Gooooo002/ooooo`03
o`000?oooooooooo03Kooooo0_l00021ooooo`00[?ooool00ol0003oooooooooo`0fooooo`;o0000
POooool009Gooooo0_l0000Eooooo`03o`000?oooooooooo01;ooooo0ol0000<ooooo`;o0000U_oo
ool009Gooooo0_l0000Eooooo`?o00002?ooool2o`0000Sooooo0ol0000<ooooo`;o00005_ooool2
o`0007kooooo002/ooooo`Go00001_ooool2o`0002oooooo0_l0001nooooo`00YOooool2o`0000Go
oooo00?o0000ooooooooool00_l0000Dooooo`;o0000XOooool00:Gooooo0_l00005ooooo`03o`00
0?oooooooooo01Kooooo0_l0002Qooooo`00Woooool2o`0000Oooooo0_l00002ooooo`03o`000?oo
oooooooo00;ooooo0_l0002eooooo`00V?ooool2o`0000Gooooo0_l00007ooooo`;o00000_ooool0
0ol0003oooooooooo`02ooooo`;o0000]Oooool008Wooooo0_l0000=ooooo`;o00004_ooool00ol0
003oooooooooo`0;ooooo`;o0000[?ooool008Wooooo0_l00006ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo00_ooooo0_l0002/ooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool03Oooool2o`0000Sooooo1?l0000<
ooooo`;o0000T?ooool008Wooooo1ol000000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo
00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0=ooooo`;o00002?ooool4o`00
00cooooo1Ol0002=ooooo`00S_ooool2o`000003ooooool0003ooooo00;ooooo00?o0000oooooooo
ool03Oooool00omgMgOo<S8booooo`04ooooo`?o0000:Oooool3o`0008gooooo0023ooooo`;o0000
0oooool2o`0000Oooooo00Co0000oooooooooooooooo0ol0000:ooooo`03o`000?lQ8B7o000000;o
00001Oooool00ol0003oooooooooo`0Jooooo`;o00003_ooool2o`0008gooooo0023ooooo`;o0000
0oooool2o`0000Oooooo00Go410@oooooooooooooooooa0@4002o`0000;ooooo0_l00006ooooo`03
o`000?oooooooooo00?o00001?ooool00ol0003oooooooooo`0Jooooo`;o00003_ooool2o`0008go
oooo002Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool2o`0000Kooooo00Co0000oooooooo
oooooooo0_l00004ooooo`03o`000?oooooooooo0;Wooooo002Aooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0;?ooool2o`0008_ooooo002/ooooo`03
o`000?oooooooooo00oooooo0_l0000Kooooo`;o0000Roooool00:cooooo00?o0000ooooooooool0
3oooool2o`0001[ooooo0_l0002<ooooo`00[?ooool00ol0003oooooooooo`0Looooo`?o00003?oo
ool2o`0008cooooo0022ooooo`;o00006Oooool2o`0000_ooooo1Ol000000ooooooo0000o`00000I
ooooo`Co00003?ooool2o`0008_ooooo0022ooooo`;o00006Oooool2o`0000_ooooo0ol00003oooo
o`;o00006oooool2o`0000cooooo0_l0002;ooooo`00Voooool2o`0000oooooo00?o0000oooooooo
ool0^Oooool009_ooooo0_l00006ooooo`;o00001oooool00ol0003oooooooooo`09ooooo`;o0000
5?ooool2o`0009Sooooo002Sooooo`;o00001oooool00ol0003oooooooooo`09ooooo`;o00005?oo
ool2o`0009Sooooo002Pooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`;o0000:oooool2
o`0008Kooooo002Pooooo`;o00002_ooool3o`0000Cooooo0_l0000>ooooo`;o00006oooool2o`00
08Kooooo002/ooooo`?o00001?ooool2o`0000kooooo0_l0002Sooooo`00Soooool2o`0000Gooooo
0_l0000Dooooo`?o00001?ooool2o`0001cooooo0_l0002Eooooo`00Soooool2o`0000Gooooo0_l0
0006ooooo`;o00003?ooool00ol0003oooooooooo`0=ooooo`;o00001_ooool2o`0000_ooooo0_l0
002Eooooo`00Q_ooool2o`0001Kooooo0_l0000<ooooo`03o`000?oooooooooo00cooooo0ol00006
ooooo`;o0000X_ooool008Kooooo0_l0000:ooooo`;o00005oooool2o`0000Oooooo0_l00005oooo
o`;o0000Zoooool009;ooooo0_l00004ooooo`;o00002Oooool3o`0000Gooooo0_l00007ooooo`;o
0000/_ooool008Kooooo0_l0000@ooooo`;o00002Oooool3o`0000Kooooo00?o0000ooooooooool0
^Oooool008Kooooo0_l0000Tooooo`03o`000?oooooooooo00Oooooo0_l0002`ooooo`00Q_ooool2
o`0002Cooooo00?o0000ooooooooool01oooool2o`0000Kooooo0_l0000Qooooo`;o0000QOooool0
0:cooooo0ol00002ooooo`;o00002oooool2o`00027ooooo0_l00025ooooo`00U?ooool2o`0000So
oooo0_l0000<ooooo`03o`000?oooooooooo00;ooooo0_l0002eooooo`00SOooool2o`0000Gooooo
0_l00008ooooo`;o00003?ooool00ol0003oooooooooo`04ooooo`;o00004_ooool4o`0001Wooooo
0_l00022ooooo`00SOooool2o`0001gooooo00Co0000ooooool0003o00000oooool2o`0001;ooooo
1?l00008ooooo`;o00003_ooool3o`0008;ooooo002/ooooo`04o`000?oooooo0000o`0002?ooooo
0_l0000>ooooo`?o0000P_ooool009Kooooo0_l000000ooooooo0000o`00000Aooooo`04o`000?oo
oooo0000o`00013ooooo0_l00008ooooo`;o0000W?ooool009Kooooo0_l000000ooooooo0000o`00
000Aooooo`03o`000?oooooooooo017ooooo0_l00008ooooo`;o0000;oooool2o`0006_ooooo002/
ooooo`;o0000C?ooool3o`0006_ooooo002/ooooo`;o00001_ooool2o`0000_ooooo0_l0000goooo
o`;o0000K?ooool008Wooooo0_l0000Qooooo`?o00001Oooool2o`0000_ooooo0_l0000hooooo`;o
0000Joooool008Wooooo0_l0000Qooooo`03o`000?oooooooooo03Kooooo0_l0000Dooooo`;o0000
Joooool00:cooooo00?o0000ooooooooool07Oooool2o`0001Oooooo0_l00021ooooo`00[?ooool0
0ol0003oooooooooo`0Mooooo`;o0000V_ooool008oooooo0_l0000Kooooo`?o00003Oooool2o`00
02cooooo0_l0001looooo`00ROooool01_o^k^ko<S8bo`000?lb<S;ok^k^ooooo`;o00000_ooool2
ob4Q8@Cooooo1_l00003ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool3o`0000gooooo0_l0
000>ooooo`;o00006_ooool4o`0007cooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Cooooo00CoV9RHo`000?l0003ooooo0_l00006ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool07Oooool2o`0000_ooooo0_l0000=ooooo`;o0000O_ooool0087ooooo1_l0
0002ooooo`05oa0@4?ooooooooooooooool@41001?ooool2o`0000Kooooo00?oV9RHob4Q8Oo^k^h0
2Oooool3o`0000?ooooo00?o0000ooooooooool0:_ooool2o`0008gooooo0029ooooo`05o`000?oo
ooooooooooooool000001?ooool2o`0000Oooooo00?oV9RHob4Q8Oo^k^h01oooool01?mgMgOo<S8b
o`000?l00003ooooo`?o0000^Oooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo
02_ooooo0_l0002<ooooo`00ROooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02_ooooo0_l0002<oooo
o`00Q?ooool2o`0000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01oooooo0_l0002H
ooooo`00Q?ooool2o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool07oooool2o`0000_ooooo0_l0
002;ooooo`00[?ooool01?l0003oooooooooooooool2o`0002Wooooo0_l0000Rooooo`;o0000Iooo
ool008kooooo0_l0000Looooo`04o`000?ooooooooooooooo`;o00005?ooool2o`0001;ooooo0_l0
000@ooooo`;o00004Oooool2o`0006Oooooo002>ooooo`;o00007?ooool3o`0001Oooooo0_l0000B
ooooo`;o00004?ooool2o`0007[ooooo002/ooooo`?o0000;Oooool2o`0000kooooo0_l0001joooo
o`00[?ooool00ol0003oooooooooo`0]ooooo`;o00003_ooool2o`0007[ooooo002/ooooo`03o`00
0?oooooooooo023ooooo0_l0002Gooooo`00[?ooool00ol0003oooooooooo`0Pooooo`;o0000<?oo
ool2o`0006Gooooo002Eooooo`;o000000?oooooo`000?l000004_ooool00ol0003oooooooooo`0;
ooooo`;o00000oooool2o`0001cooooo0_l0000Rooooo`;o0000IOooool009Gooooo0_l000000ooo
oooo0000o`00000Booooo`03o`000?oooooooooo00_ooooo0_l00003ooooo`;o00007?ooool2o`00
08Wooooo0028ooooo`;o00008_ooool00ol0003oooooooooo`0Aooooo`;o0000Y_ooool007oooooo
0_l00007ooooo`;o00008_ooool00ol0003oooooooooo`0Aooooo`;o00001Oooool2o`0009oooooo
001oooooo`;o0000:oooool3o`0001Sooooo0_l0000Cooooo`;o0000R_ooool009Gooooo0_l0000E
ooooo`03o`000?oooooooooo02gooooo0_l0002:ooooo`00UOooool2o`0001Gooooo00?o0000oooo
ooooool0?_ooool2o`0007Wooooo002/ooooo`03o`000?oooooooooo01;ooooo0_l00005ooooo`;o
00001oooool2o`0000[ooooo0_l0000>ooooo`;o0000NOooool00:cooooo00?o0000ooooooooool0
4_ooool2o`0000Gooooo0_l00007ooooo`;o00002_ooool2o`0008Wooooo002/ooooo`03o`000?oo
oooooooo01[ooooo0_l0000Rooooo`;o0000NOooool00:cooooo00?o0000ooooooooool04Oooool2
o`0000Oooooo0_l0000Rooooo`;o00005Oooool2o`0006;ooooo002/ooooo`03o`000?oooooooooo
017ooooo0_l0000?ooooo`;o00006oooool2o`0001Cooooo0_l0001Rooooo`00[?ooool00ol0003o
ooooooooo`0<ooooo`;o00000oooool2o`0000oooooo0ol0000Jooooo`;o0000N?ooool009;ooooo
0_l0000Hooooo`?o00003?ooool2o`0000?ooooo0_l0000@ooooo`;o0000;oooool2o`0006?ooooo
002Booooo`;o00006?ooool00ol0003oooooooooo`1Dooooo`;o0000Hoooool008Oooooo0_l0000S
ooooo`03o`000?oooooooooo01Wooooo0_l0002Nooooo`002Oooool4o`000003oa0@4?oooooooooo
01Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04
ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B43ooooo`Ko00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Kooooo00?o0000
ooooooooool06?ooool01Oo^k^ko0000o`000?l0003ok^k^00Gooooo0_lQ8B44ooooo`Go00001?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd06?oo
ool4o`000003oa0@4?oooooooooo01;ooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb
<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8b
ooooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A005ooooo`;o000000?oMgMgoc8b<_ooool05Oooool00ol0003oooooooooo`0Hoooo
o`05ogMgMonHV9So0000o`000?mgMgL01Oooool2ob4Q8@;o00000_ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Oooooo00?oMgMgoc8b<_ooool02?ooool2o`0000Cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`0Iooooo`03
o`000?oooooooooo01Cooooo0006o`0000Gooooo00?o0000ooooooooool04?ooool6o`0000;ooooo
00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000oooooooo
ool01Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo
00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP06
ooooo`;o000000?oooooo`000?ooool05Oooool00ol0003oooooooooo`0Hooooo`05oa0@4?oooooo
ooooooooool@41001oooool2o`0000?ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003ooooooooo
o`07ooooo`;o00001?ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool0
3Oooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo
00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_oo
ool03_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0
003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`0E
ooooo`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`000006ooooo`;o00001Ooo
ool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000oooooooooooooooo
o`00000?ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool06Oooool00ol0003oooooooooo`0Dooooo`00
2oooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGo
c<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo
000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool00000
3_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05_ooool00ol0003o
ooooooooo`05ooooo`;o00004Oooool01Ol0003ooooooooooooooooo000000Kooooo0_l00006oooo
o`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Joooo
o`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go410@oooooooo
oooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool04Oooool01Ol@
413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04Oooool01_l@413ooooooooooooo
oooo410@ooooo`;o00003?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Sooooo
0ol00005ooooo`;o00004Oooool01Ol@413ooooooooooooooooo410@00Kooooo0_l00007ooooo`03
o`000?oooooooooo00?o00003Oooool2o`0000Cooooo00Go410@oooooooooooooooooa0@400<oooo
o`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOo
oooo00?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0
003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooo
oooo<S8b00Cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo
00?o0000ooooooooool04Oooool01_mgMgOoV9RHoooooonHV9SoMgMgooooo`;o00002?ooool01Ol0
003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0H
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00;ooooo
0ol0000=ooooo`;o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooooooo
ool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05?ooool000Wooooo00?oEEEEofIV
I_l000006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00004?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool01OnHV9So410@o`000?l0003oc<c<00?ooooo1_l0000Fooooo`03o`000?oooooooooo00So
oooo0_l0000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7o
c<c<00;ooooo1_l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00013ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0001Wooooo00?oEEEEofIVI_l00000
5_ooool008[ooooo0_l00004ooooo`;o00000_ooool2o`0001Kooooo00?o0000ooooooooool02?oo
ool2o`000:oooooo002:ooooo`;o00008?ooool00ol0003oooooooooo`0Jooooo`;o0000>_ooool2
o`00067ooooo001nooooo`;o0000;?ooool00ol0003oooooooooo`0Jooooo`;o0000>_ooool2o`00
05Kooooo0_l00002ooooo`;o00001Oooool007kooooo0_l0000/ooooo`03o`000?oooooooooo00Wo
oooo0_l0002Sooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1Oooool008Oooooo0_l0000Soooo
o`03o`000?oooooooooo00Wooooo0_l0000gooooo`;o0000Joooool01?oMgMgo0000oa0@4?o<c<`6
ooooo`001oooooooo`0004co00003?ooool01?o^k^ko8B4Qoa0@4?o^k^h6ooooo`001oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`00
00Kooooo00Co0000ooooool0003o00001Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l00007ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o00000_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0:ooooo`04ob4Q8OmgMgOoMgMgoc8b<PKooooo0007ooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`;o00009oooool0
0ol0003oooooooooo`0Sooooo`;o00000_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`09ooooo`;o00000_ooool2
o`0000Gooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo05Oooooo0_l0
001Pooooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool03Oooool2o`0000cooooo0_l00006
ooooo`;o0000<_ooool2o`00063ooooo002Dooooo`Co00005?ooool3o`0000gooooo0_l0000<oooo
o`;o00001_ooool2o`0009Cooooo002Fooooo`;o00005?ooool00ol0003oooooooooo`0Dooooo`;o
0000Xoooool00:cooooo00?o0000ooooooooool04oooool3o`000:?ooooo002/ooooo`03o`000?oo
oooooooo00Sooooo0_l00009ooooo`;o0000Y?ooool00:cooooo00?o0000ooooooooool02?ooool2
o`0003Oooooo0_l0001fooooo`00Voooool2o`0000oooooo00?o0000ooooooooool06_ooool2o`00
02Gooooo0_l0001fooooo`00Voooool2o`0000oooooo00?o0000ooooooooool06_ooool2o`0001Co
oooo0_l0000@ooooo`;o0000MOooool00:cooooo00?o0000ooooooooool03Oooool2o`0000_ooooo
0_l00008ooooo`;o00002_ooool2o`00013ooooo0_l0001eooooo`00T?ooool2o`0001[ooooo00?o
0000ooooooooool03Oooool2o`0000Cooooo0_l00005ooooo`;o00002?ooool2o`0001[ooooo0_l0
001gooooo`00T?ooool2o`0001[ooooo0ol0000Booooo`?o0000:oooool2o`0001Cooooo0_l0001Q
ooooo`00[?ooool00ol0003oooooooooo`0Booooo`;o0000;Oooool2o`0001?ooooo0_l0001Qoooo
o`00[?ooool00ol0003oooooooooo`0Sooooo`;o00007?ooool2o`0007Kooooo002/ooooo`03o`00
0?oooooooooo00gooooo0_l0000Dooooo`;o00007?ooool3o`0007Gooooo002/ooooo`04o`000?oo
ooooooooooooo`;o00002_ooool2o`0000_ooooo0_l0000Vooooo`;o00004Oooool2o`0006;ooooo
002/ooooo`04o`000?ooooooooooooooo`;o00005oooool2o`0003Wooooo0_l0001Rooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool0?oooool2
o`0007Sooooo002>ooooo`;o00007?ooool3o`0002?ooooo0_l0000Jooooo`;o0000N?ooool00:co
oooo00?o0000ooooooooool01oooool2o`0001[ooooo0_l0002Dooooo`00[?ooool00ol0003ooooo
ooooo`07ooooo`;o00000_ooool2o`0002;ooooo0_l00028ooooo`00[?ooool00ol0003ooooooooo
o`0;ooooo`;o00005_ooool2o`0000[ooooo0_l00028ooooo`00[?ooool00ol0003oooooooooo`0S
ooooo`;o00002Oooool2o`0008Wooooo0024ooooo`;o00001Oooool2o`0001oooooo00?o0000oooo
ooooool0;_ooool2o`0008Wooooo0024ooooo`;o00001Oooool2o`0001oooooo00?o0000oooooooo
ool0;_ooool3o`0008Sooooo002;ooooo`;o00007oooool00ol0003oooooooooo`0^ooooo`?o0000
R?ooool00:cooooo0ol0000Hooooo`;o0000Woooool00:cooooo00?o0000ooooooooool06?ooool2
o`0001?ooooo0_l0002:ooooo`00[?ooool00ol0003oooooooooo`0]ooooo`;o0000R_ooool009Ko
oooo0_l0000Dooooo`?o00005oooool2o`000:3ooooo002Fooooo`;o00005?ooool3o`0001Oooooo
0_l0002Pooooo`00T_ooool2o`0001Sooooo00?o0000ooooooooool05oooool2o`000:3ooooo0029
ooooo`03onk^k_lb<S;o000000;o00001?ooool2o`000003ob4Q8Ooooooooooo00;ooooo1Ol00004
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Gooooo`;o0000X?oo
ool008Gooooo0_l00002ooooo`03ogMgMonHV9Sooooo00;o000000?oooooo`000?l000000_ooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool03_ooool2o`000:Wooooo0025ooooo`;o00000_ooool01_l@413ooooooooooooo
oooo410@ooooo`;o00002Oooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo
0ol0000>ooooo`;o0000ZOooool008Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0nooooo`;o0000
NOooool008Wooooo00Ko0000ooooooooooooooooo`000?ooool2o`0000_ooooo00?oMgMgofIVI_oo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo0_l0000oooooo`;o0000NOooool008Wo
oooo00Ko410@oooooooooooooooooa0@4?ooool2o`0000cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`;o00000_ooool2o`0000oooooo0_l0000Mooooo`;o00003Oooool3
o`0007[ooooo0029ooooo`;o000000?ooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@00Cooooo00?o0000ooooooooool00oooool2o`0000;ooooo00?o0000ooooooooool03Oooool3
o`0001gooooo0_l0000=ooooo`?o0000N_ooool008Wooooo0ol000000olb<S;ok^k^ooooo`0:oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool01oooool2
o`0000Cooooo0ol0000?ooooo`;o00003?ooool2o`0008[ooooo002Vooooo`;o00001?ooool00ol0
003oooooooooo`07ooooo`;o00001Oooool2o`0000oooooo0_l0000<ooooo`;o00003Oooool2o`00
07_ooooo0025ooooo`;o00007oooool2o`0000Cooooo00?o0000ooooooooool03?ooool4o`0000Co
oooo0_l0000Uooooo`Co0000N_ooool008Gooooo0_l0000Kooooo`;o00002?ooool3o`0000cooooo
0_l00006ooooo`;o00009Oooool4o`0007[ooooo0029ooooo`;o00002oooool2o`0000[ooooo0_l0
0008ooooo`?o0000^Oooool008Wooooo0_l0000;ooooo`;o00005?ooool00ol0003oooooooooo`2i
ooooo`00POooool2o`0001?ooooo0_l0000Dooooo`03o`000?oooooooooo0;Wooooo0021ooooo`;o
0000:Oooool2o`0001kooooo0_l0000aooooo`;o0000Ioooool0083ooooo0_l0000Zooooo`;o0000
4oooool2o`0000Wooooo0_l0000aooooo`;o0000Ioooool0083ooooo0_l0000Zooooo`03o`000?oo
oooooooo00_ooooo0_l00005ooooo`;o0000YOooool00:cooooo00?o0000ooooooooool02oooool2
o`000:cooooo002Dooooo`;o00003_ooool2o`0000Kooooo00?o0000ooooooooool0^Oooool009Co
oooo0_l00006ooooo`;o00001_ooool2o`0000Kooooo0ol0000hooooo`;o0000Ooooool009cooooo
0_l0000>ooooo`03o`000?oooooooooo03Sooooo0_l0001oooooo`00Q_ooool2o`0000Kooooo0_l0
000Looooo`03o`000?oooooooooo01[ooooo0_l0000Nooooo`;o0000OOooool008Kooooo0_l00006
ooooo`;o00007?ooool3o`0000[ooooo0_l0000>ooooo`;o00007_ooool2o`0001;ooooo0_l0001Y
ooooo`00W_ooool2o`0000cooooo0ol0000:ooooo`;o0000;?ooool2o`0001Cooooo0_l0001Yoooo
o`00W_ooool2o`0000cooooo00?o0000ooooooooool0>?ooool2o`0007oooooo0021ooooo`;o0000
:Oooool00ol0003oooooooooo`0Vooooo`;o00004?ooool2o`0007oooooo0021ooooo`;o0000:Ooo
ool00ol0003oooooooooo`0Vooooo`;o00009Oooool2o`0006[ooooo002Vooooo`;o00001?ooool3
o`0004gooooo0_l0001Zooooo`00P_ooool2o`00023ooooo1?l00004ooooo`03o`000?oooooooooo
0;Wooooo0022ooooo`;o00004oooool2o`0000_ooooo0_l00006ooooo`03o`000?oooooooooo02Co
oooo1?l0002Aooooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool09?ooool4o`00097ooooo
002Zooooo`?o00004?ooool2o`000:Wooooo002;ooooo`;o00007Oooool3o`00013ooooo0_l0002Y
ooooo`00Roooool2o`0001oooooo00?o0000ooooooooool0=_ooool2o`00087ooooo002/ooooo`03
o`000?oooooooooo01Kooooo0_l0000Mooooo`?o0000POooool0097ooooo0_l0000Iooooo`?o0000
5_ooool2o`0000cooooo0_l0000?ooooo`;o0000P_ooool0097ooooo0_l0000Iooooo`?o00009?oo
ool2o`0002;ooooo0_l0001_ooooo`00Poooool2o`0000Oooooo0_l00007ooooo`;o00003?ooool2
o`0000Oooooo00?o0000ooooooooool0B?ooool2o`0006oooooo0023ooooo`;o00001oooool2o`00
00Oooooo0_l0000<ooooo`;o00001oooool00ol0003oooooooooo`0Dooooo`;o00007?ooool2o`00
08Gooooo002Kooooo`;o00003oooool00ol0003oooooooooo`0Dooooo`;o00007?ooool2o`0008Go
oooo002Kooooo`;o00003oooool00ol0003oooooooooo`0Rooooo`;o0000UOooool0097ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Go
oooo00?o0000ooooooooool00_ooool2o`0001kooooo0_l0002Eooooo`00TOooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool00_ooool2o`000;Gooooo002Aooooo`05oa0@4?ooooooooooooooool@41002?ooool2o`0000Ko
oooo00Co0000ooooool0003o00000_ooool00ol0003oooooooooo`16ooooo`;o0000LOooool0097o
oooo00Go0000ooooooooooooooooo`000008ooooo`;o00001Oooool00omgMgOo<S8booooo`02o`00
00;ooooo1Ol0000@ooooo`;o0000<_ooool2o`00077ooooo002Aooooo`05o`000?oooooooooooooo
ool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool00_l0000@
ooooo`;o0000YOooool0097ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool00_l00005ooooo`;o0000/?ooool0097ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00;o00001Oooool00ol0003oooooooooo`07
ooooo`;o00005?ooool2o`0009[ooooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool5
o`0000Gooooo00?o0000ooooooooool07Oooool2o`00013ooooo0_l00028ooooo`00[?ooool2o`00
033ooooo0_l00028ooooo`00QOooool2o`0000Sooooo0_l00009ooooo`;o00004?ooool2o`000;[o
oooo0025ooooo`;o00001?ooool2o`0000;ooooo0_l00009ooooo`;o00004?ooool00ol0003ooooo
ooooo`0Looooo`;o00004?ooool2o`0008Wooooo002;ooooo`;o00007oooool3o`0000Gooooo0_l0
0007ooooo`;o00003?ooool2o`00013ooooo0_l00029ooooo`00V_ooool2o`00013ooooo00?o0000
ooooooooool01Oooool2o`0000Oooooo0_l0002Yooooo`00V_ooool2o`00013ooooo00?o0000oooo
ooooool06oooool2o`0009cooooo0025ooooo`;o00008_ooool2o`000003ooooool0003ooooo01co
oooo0_l0000=ooooo`;o0000SOooool008Gooooo0_l0000Gooooo`?o00002?ooool2o`000003oooo
ool0003ooooo02_ooooo0_l0002=ooooo`00W_ooool3o`0000Gooooo0_l00004ooooo`04o`000?oo
ooooooooooooo`;o00001oooool4o`000:_ooooo002Vooooo`;o00001?ooool01?l0003ooooooooo
ooooool2o`0000Oooooo1?l0002[ooooo`00S?ooool2o`0001Cooooo0_l00008ooooo`03o`000?oo
oooooooo0;Wooooo002<ooooo`;o00005?ooool2o`0000Sooooo0ol0002iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooo
ooooo`0Wooooo`;o0000T?ooool008Kooooo0_l0000Tooooo`03o`000?oooooooooo00Kooooo0_l0
000Oooooo`;o0000T?ooool008Kooooo0_l0000;ooooo`;o00005_ooool3o`0000Kooooo0ol0002a
ooooo`00Toooool2o`0001Gooooo1?l00006ooooo`?o00002oooool2o`000:Cooooo002Zooooo`?o
00005Oooool2o`000:Cooooo002Looooo`;o00003_ooool3o`00017ooooo0_l0000?ooooo`?o0000
U?ooool009cooooo0_l0000>ooooo`03o`000?oooooooooo017ooooo0ol0000>ooooo`?o0000U?oo
ool00:?ooooo0_l00007ooooo`03o`000?oooooooooo017ooooo0ol0002Uooooo`00R?ooool2o`00
00Cooooo0_l0000Aooooo`Co00001oooool00ol0003oooooooooo`0Pooooo`;o0000Uoooool008So
oooo0_l00004ooooo`Co00003oooool3o`0000Sooooo00?o0000ooooooooool08?ooool2o`0009Oo
oooo002@ooooo`;o00006_ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`0Pooooo`;o0000Uoooool009Wooooo0_l0000Aoooo
o`04o`000?oooooo0000o`0001_ooooo0_l00002ooooo`;o0000Uoooool009Wooooo0_l0000Aoooo
o`Co00006oooool2o`0009_ooooo002/ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`;o0000
8Oooool00ol0003oooooooooo`2iooooo`00ROooool2o`0000Kooooo0_l0000Iooooo`?o0000^Ooo
ool0097ooooo0_l0000Hooooo`Co00006_ooool2o`0009gooooo0029ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Cooooo0_l0000Looooo`;o0000WOooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`04ogMgMolb<S;oooooooooo`;o0000
00?oooooo`000?ooool06_ooool2o`0009kooooo0029ooooo`05oa0@4?ooooooooooooooool@4100
3Oooool01?nYZJWoEEEEo`000?l00007ooooo`03o`000?oooooo000000;o000000?oooooo`000?oo
ool06_ooool2o`0009kooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7o
0000o`000006ooooo`03ogMgMolb<S;ooooo00;o00000_ooool3o`000;Wooooo0024ooooo`;o0000
0oooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0^Oooool008Cooooo0_l00003ooooo`05
oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool06?ooool2o`0009oooooo0029ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Gooooo`?o0000Woooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool05oooool3o`0009oooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo01Cooooo0_l0002Sooooo`00[?ooool4o`0001?ooooo0_l0002Sooooo`00[?ooool0
1?l0003oooooo`000?l0002hooooo`00[?ooool00ol0003oooooooooo`2iooooo`00V_ooool2o`00
013ooooo0_l0002jooooo`00V_ooool2o`00013ooooo0_l0002jooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00Zoooool2o`000;_ooooo002[ooooo`;o00004?ooool2o`000:Wooooo002/oooo
o`?o00003_ooool2o`000:Wooooo002Sooooo`;o00000oooool2o`0000;ooooo00?o0000oooooooo
ool0^Oooool00:7ooooo1?l00003ooooo`;o00000_ooool00ol0003oooooooooo`0Pooooo`;o0000
Uoooool00:7ooooo0ol00008ooooo`03o`000?oooooooooo00_ooooo0_l0000Cooooo`;o0000Uooo
ool00:;ooooo0_l000000ooooooo0000o`000005ooooo`03o`000?oooooooooo00_ooooo0_l0002/
ooooo`00T_ooool2o`00017ooooo0_l00005ooooo`03o`000?oooooooooo0;Wooooo002Booooo`;o
00006?ooool00ol0003oooooooooo`09ooooo`;o0000[_ooool00:cooooo00?o0000ooooooooool0
1_ooool2o`000003ooooool0003o00000:kooooo002/ooooo`03o`000?oooooooooo00Kooooo0_l0
002aooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Eooooo`;o
00005Oooool00ol0003oooooooooo`2iooooo`00UOooool3o`0001Cooooo00?o0000ooooooooool0
^Oooool009Gooooo0ol0000Dooooo`05o`000?oooooo0000o`000?ooool00_l0002eooooo`00[?oo
ool00ol0003oooooo`000004o`000;Gooooo002Iooooo`;o00004Oooool3o`000003ooooool0003o
00000;Kooooo002Hooooo`?o00004Oooool6o`000;Kooooo002Hooooo`;o00004_ooool4o`000;So
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002Mooooo`;o00003Oooool00ol0003ooooooooo
o`2iooooo`00WOooool6o`0000?ooooo0_l00004ooooo`03o`000?oooooooooo017ooooo0_l0002V
ooooo`00W_ooool6o`0000;ooooo0ol00003ooooo`03o`000?oooooooooo017ooooo0_l0002Voooo
o`00W_ooool6o`0000?ooooo0_l00003ooooo`03o`000?oooooooooo0;Wooooo002Pooooo`Ko0000
00?o410@o`000?l000000oooool00ol0003oooooooooo`2iooooo`00X?ooool2o`0000;ooooo00?o
0000ooooooooool00_l00003ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`03o`000?oooooo
oooo00Gooooo0ol0002iooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003o
ooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003ooooooooo
o`31ooooo`00X_ooool00omEEEGoIVIVo`000033ooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00Z_ooool01?l@413o0000o`000?l0002jooooo`00Zoooool0
0ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool01_l0003o
MgMgo`000?l0003oEEEEonk^k[Oooooo002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoEEEE]ooo
ool00:_ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`2eooooo`00Zoooool00ol0
003ok^k^ooooo`02ooooo`03o`000?oooooooooo0;Gooooo002[ooooo`06o`000?mEEEGok^k^oooo
oomgMgOoIVIV]oooool00:[ooooo00?o410@o`000?mgMgL00_l000000omVIVKok^k^ooooo`2foooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.39813 .29975 Mdot
.57411 .21326 Mdot
.44497 .47782 Mdot
.53773 .38287 Mdot
.44846 .20596 Mdot
.5511 .79 Mdot
.51758 .50306 Mdot
.69697 .68156 Mdot
.70806 .44664 Mdot
.42592 .32984 Mdot
.53953 .32893 Mdot
.65581 .77183 Mdot
.66904 .52467 Mdot
.49798 .23353 Mdot
.63182 .80446 Mdot
.53015 .66516 Mdot
.45719 .15549 Mdot
.66876 .54071 Mdot
.50528 .77293 Mdot
.39628 .78106 Mdot
.66324 .56007 Mdot
.63343 .34207 Mdot
.64752 .40177 Mdot
.66498 .57399 Mdot
.54215 .93533 Mdot
.59514 .57489 Mdot
.56654 .44597 Mdot
.51695 .74602 Mdot
.37651 .59666 Mdot
.58422 .23452 Mdot
.65017 .62347 Mdot
.70987 .44147 Mdot
.70738 .62444 Mdot
.56448 .27375 Mdot
.62028 .43795 Mdot
.47016 .93681 Mdot
.56206 .12987 Mdot
.55532 .63736 Mdot
.38013 .3564 Mdot
.64429 .79863 Mdot
.54816 .93331 Mdot
.60062 .35872 Mdot
.61507 .61604 Mdot
.41752 .18869 Mdot
.38664 .5488 Mdot
.56229 .32247 Mdot
.48216 .22241 Mdot
.68613 .34193 Mdot
.48746 .84143 Mdot
.37914 .62394 Mdot
.6827 .33583 Mdot
.42276 .1097 Mdot
.78113 .52787 Mdot
.62377 .53369 Mdot
.62594 .55177 Mdot
.71497 .53472 Mdot
.69048 .69684 Mdot
.45106 .16124 Mdot
.64049 .24452 Mdot
.39324 .65444 Mdot
.57511 .36334 Mdot
.37667 .2369 Mdot
.38506 .30593 Mdot
.47875 .73828 Mdot
.70173 .62336 Mdot
.71577 .48749 Mdot
.41952 .38011 Mdot
.54096 .61799 Mdot
.55482 .64549 Mdot
.65646 .61927 Mdot
.48898 .14338 Mdot
.44031 .60463 Mdot
.43341 .29618 Mdot
.41979 .61595 Mdot
.38492 .3074 Mdot
.50793 .4678 Mdot
.78106 .52858 Mdot
.59186 .4642 Mdot
.39757 .20667 Mdot
.51638 .7896 Mdot
.59477 .7768 Mdot
.57696 .22362 Mdot
.51769 .3214 Mdot
.60657 .37605 Mdot
.71354 .6097 Mdot
.52356 .69091 Mdot
.46126 .18795 Mdot
.51092 .22268 Mdot
.41835 .25119 Mdot
.53725 .6326 Mdot
.53283 .94519 Mdot
.70536 .25203 Mdot
.42042 .52852 Mdot
.5347 .2617 Mdot
.43013 .63627 Mdot
.68196 .20856 Mdot
.48929 .22243 Mdot
.6843 .34977 Mdot
.78104 .54879 Mdot
.42251 .22954 Mdot
.42428 .17172 Mdot
.39639 .4589 Mdot
.65404 .77057 Mdot
.44844 .11342 Mdot
.62557 .71685 Mdot
.57828 .3039 Mdot
.51823 .18359 Mdot
.46594 .80423 Mdot
.42012 .5178 Mdot
.6535 .6278 Mdot
.45752 .22848 Mdot
.53259 .36007 Mdot
.70795 .43405 Mdot
.45416 .93423 Mdot
.70429 .80392 Mdot
.4811 .70918 Mdot
.58661 .41432 Mdot
.721 .51884 Mdot
.71815 .48327 Mdot
.55113 .12071 Mdot
.66815 .52352 Mdot
.36128 .54591 Mdot
.66058 .50504 Mdot
.37463 .55756 Mdot
.65413 .62786 Mdot
.54817 .43933 Mdot
.42524 .88463 Mdot
.64165 .15031 Mdot
.51384 .1338 Mdot
.42884 .44467 Mdot
.64815 .39455 Mdot
.46685 .10122 Mdot
.62689 .82206 Mdot
.54233 .80848 Mdot
.59921 .67757 Mdot
.38024 .33595 Mdot
.5354 .09205 Mdot
.38992 .73568 Mdot
.42918 .31654 Mdot
.69399 .66995 Mdot
.62691 .81528 Mdot
.46878 .25057 Mdot
.5383 .6993 Mdot
.45804 .15411 Mdot
.42168 .87913 Mdot
.71841 .57403 Mdot
.63109 .91483 Mdot
.44442 .76859 Mdot
.53015 .2572 Mdot
.37386 .7409 Mdot
.39654 .54492 Mdot
.57292 .54261 Mdot
.66505 .58091 Mdot
.45208 .65528 Mdot
.47515 .8853 Mdot
.50041 .05578 Mdot
.39482 .22859 Mdot
.71907 .52004 Mdot
.563 .13271 Mdot
.50883 .06422 Mdot
.56626 .69329 Mdot
.39692 .20791 Mdot
.56727 .91669 Mdot
.5219 .89157 Mdot
.61301 .61312 Mdot
.4145 .21113 Mdot
.71875 .56308 Mdot
.61049 .75343 Mdot
.55989 .62413 Mdot
.49802 .05003 Mdot
.40015 .7879 Mdot
.42408 .41868 Mdot
.56836 .56719 Mdot
.46409 .1886 Mdot
.42478 .70631 Mdot
.70247 .63461 Mdot
.66992 .19056 Mdot
.48454 .88189 Mdot
.48965 .69506 Mdot
.37458 .51531 Mdot
.45646 .04752 Mdot
.61619 .844 Mdot
.45875 .7615 Mdot
.53426 .95006 Mdot
.48893 .28887 Mdot
.70415 .43352 Mdot
.63732 .14646 Mdot
.71045 .42839 Mdot
.5781 .90178 Mdot
.60829 .64949 Mdot
.37735 .75988 Mdot
.42229 .88132 Mdot
.51774 .65673 Mdot
.36619 .3504 Mdot
.70645 .64407 Mdot
.64328 .79267 Mdot
.51838 .23198 Mdot
.74041 .31841 Mdot
.56538 .26243 Mdot
.52272 .57226 Mdot
.51982 .59176 Mdot
.43419 .54637 Mdot
.43841 .23251 Mdot
.75308 .35301 Mdot
.44284 .12886 Mdot
.53842 .48409 Mdot
.52554 .83215 Mdot
.52932 .3451 Mdot
.52401 .37782 Mdot
.54708 .3482 Mdot
.66288 .44048 Mdot
.59018 .44605 Mdot
.60867 .75689 Mdot
.48387 .76409 Mdot
.42287 .17989 Mdot
.58361 .41037 Mdot
.56055 .92422 Mdot
.49446 .29408 Mdot
.40641 .74342 Mdot
.66113 .76813 Mdot
.58387 .39971 Mdot
.64834 .26512 Mdot
.62164 .72985 Mdot
.57032 .81892 Mdot
.51167 .71101 Mdot
.40821 .40864 Mdot
.55321 .17759 Mdot
.42148 .45724 Mdot
.62974 .80857 Mdot
.36048 .46955 Mdot
.55017 .57726 Mdot
.44662 .39533 Mdot
.75386 .36399 Mdot
.42319 .75679 Mdot
.56668 .43623 Mdot
.36631 .64928 Mdot
.56338 .60199 Mdot
.47198 .0943 Mdot
.66302 .49492 Mdot
.45216 .11314 Mdot
.37755 .23216 Mdot
.58408 .72384 Mdot
.57716 .81794 Mdot
.4875 .14241 Mdot
.71275 .44585 Mdot
.44098 .68493 Mdot
.4871 .04884 Mdot
.4003 .40689 Mdot
.48134 .13937 Mdot
.38658 .28934 Mdot
.49431 .99559 Mdot
.48535 .70504 Mdot
.51699 .65565 Mdot
.51518 .07683 Mdot
.59084 .59071 Mdot
.5697 .55023 Mdot
.62397 .58987 Mdot
.50938 .506 Mdot
.69397 .68053 Mdot
.66781 .29729 Mdot
.4529 .83193 Mdot
.56642 .43401 Mdot
.55435 .84509 Mdot
.43576 .61812 Mdot
.39878 .58465 Mdot
.38778 .44142 Mdot
.49951 .24338 Mdot
.57371 .73745 Mdot
.43523 .90096 Mdot
.57308 .66245 Mdot
.45178 .92881 Mdot
.6243 .57576 Mdot
.42361 .34142 Mdot
.48822 .83573 Mdot
.49334 .0483 Mdot
.44758 .74436 Mdot
.41108 .62559 Mdot
.68993 .35792 Mdot
.54104 .32779 Mdot
.49316 .87738 Mdot
.37652 .40117 Mdot
.43266 .38861 Mdot
.4401 .71832 Mdot
.56268 .13331 Mdot
.66652 .74599 Mdot
.45886 .79926 Mdot
.48883 .67068 Mdot
.4082 .43178 Mdot
.49719 .93235 Mdot
.54593 .28842 Mdot
.60998 .74419 Mdot
.63688 .14687 Mdot
.63046 .23024 Mdot
.65398 .76443 Mdot
.633 .23867 Mdot
.49827 .36346 Mdot
.61574 .20054 Mdot
.36202 .48691 Mdot
.53474 .88487 Mdot
.64022 .78946 Mdot
.58606 .96948 Mdot
.51052 .80563 Mdot
.60832 .66126 Mdot
.47799 .09801 Mdot
.71177 .44553 Mdot
.55728 .9194 Mdot
.49973 .2411 Mdot
.68736 .3537 Mdot
.58663 .61559 Mdot
.52489 .46033 Mdot
.66039 .43463 Mdot
.47634 .1448 Mdot
.66685 .50623 Mdot
.38646 .82287 Mdot
.46484 .70566 Mdot
.3936 .64653 Mdot
.58548 .31983 Mdot
.69569 .64987 Mdot
.43186 .59308 Mdot
.60883 .85408 Mdot
.40119 .87715 Mdot
.51872 .012 Mdot
.55332 .52378 Mdot
.53928 .81558 Mdot
.60963 .38403 Mdot
.40611 .17411 Mdot
.40978 .38121 Mdot
.52787 .52896 Mdot
.51239 .43075 Mdot
.49999 .15778 Mdot
.6768 .73463 Mdot
.507 .06938 Mdot
.43272 .65299 Mdot
.65205 .39497 Mdot
.43218 .40074 Mdot
.43365 .53456 Mdot
.55958 .18751 Mdot
.56262 .76936 Mdot
.61262 .61565 Mdot
.56584 .69377 Mdot
.42739 .27171 Mdot
.78118 .48594 Mdot
.58503 .61581 Mdot
.5564 .19293 Mdot
.47563 .73747 Mdot
.71188 .58538 Mdot
.56241 .42063 Mdot
.39786 .78316 Mdot
.60363 .27702 Mdot
.43368 .33227 Mdot
.56372 .34001 Mdot
.66115 .76324 Mdot
.61287 .19361 Mdot
.45491 .92963 Mdot
.52997 .77235 Mdot
.55714 .24985 Mdot
.40905 .82888 Mdot
.40808 .67911 Mdot
.66134 .76207 Mdot
.53185 .02217 Mdot
.56977 .83018 Mdot
.62961 .81659 Mdot
.6016 .86448 Mdot
.54057 .94583 Mdot
.43932 .39542 Mdot
.44529 .81775 Mdot
.6238 .81947 Mdot
.69338 .6858 Mdot
.44562 .36031 Mdot
.62847 .70103 Mdot
.5828 .61716 Mdot
.52242 .83903 Mdot
.41462 .20697 Mdot
.69164 .37347 Mdot
.46878 .0956 Mdot
.58986 .16588 Mdot
.46013 .05495 Mdot
.6434 .3864 Mdot
.59361 .16447 Mdot
.64389 .38107 Mdot
.57163 .89832 Mdot
.68009 .84625 Mdot
.57728 .15553 Mdot
.46021 .88244 Mdot
.46324 .67457 Mdot
.44782 .98492 Mdot
.41015 .29397 Mdot
.50873 .40945 Mdot
.61006 .85503 Mdot
.65481 .62677 Mdot
.52872 .51494 Mdot
.41434 .53539 Mdot
.59765 .51271 Mdot
.57015 .46754 Mdot
.69282 .35966 Mdot
.61739 .74551 Mdot
.36441 .38614 Mdot
.6103 .85313 Mdot
.52867 .20517 Mdot
.77623 .46149 Mdot
.54673 .23354 Mdot
.43058 .73166 Mdot
.41192 .6264 Mdot
.44984 .61406 Mdot
.68079 .7224 Mdot
.65846 .76601 Mdot
.56535 .43663 Mdot
.43112 .35062 Mdot
.57087 .4431 Mdot
.4982 .74997 Mdot
.42292 .95078 Mdot
.52434 .24003 Mdot
.52686 .88668 Mdot
.48608 .25512 Mdot
.57159 .55429 Mdot
.42844 .54801 Mdot
.49615 .19388 Mdot
.55077 .24693 Mdot
.57296 .4837 Mdot
.539 .51313 Mdot
.36534 .645 Mdot
.69587 .66492 Mdot
.48941 .60632 Mdot
.6236 .46193 Mdot
.51855 .18424 Mdot
.434 .83908 Mdot
.5748 .64995 Mdot
.56633 .58829 Mdot
.44252 .98029 Mdot
.70407 .24187 Mdot
.49251 .10233 Mdot
.74008 .72916 Mdot
.43421 .13769 Mdot
.53678 .56325 Mdot
.70928 .47653 Mdot
.61545 .83249 Mdot
.54636 .35161 Mdot
.60391 .27984 Mdot
.78139 .49744 Mdot
.43922 .31197 Mdot
.52523 .44875 Mdot
.41271 .6252 Mdot
.55995 .8379 Mdot
.53864 .74782 Mdot
.72592 .28895 Mdot
.50908 .33232 Mdot
.62241 .48048 Mdot
.59775 .34588 Mdot
.44863 .71165 Mdot
.46872 .70664 Mdot
.42831 .67763 Mdot
.69587 .68372 Mdot
.44655 .67173 Mdot
.38614 .28094 Mdot
.54674 .1709 Mdot
.38795 .57039 Mdot
.43921 .91307 Mdot
.62436 .70863 Mdot
.50423 .16707 Mdot
.6397 .14396 Mdot
.41365 .49136 Mdot
.67392 .74166 Mdot
.49729 .99386 Mdot
.50134 .24789 Mdot
.61529 .19865 Mdot
.57376 .65669 Mdot
.43255 .20625 Mdot
.40126 .80091 Mdot
.42532 .16751 Mdot
.48942 .79697 Mdot
.56548 .3444 Mdot
.56274 .26833 Mdot
.37318 .25878 Mdot
.59941 .67137 Mdot
.50584 .44121 Mdot
.61819 .59014 Mdot
.51113 .80029 Mdot
.43594 .42095 Mdot
.55062 .55323 Mdot
.62449 .52222 Mdot
.60502 .66313 Mdot
.50717 .65124 Mdot
.59425 .55643 Mdot
.71597 .49222 Mdot
.43946 .22487 Mdot
.38765 .54176 Mdot
.55029 .66824 Mdot
.51491 .74662 Mdot
.47548 .30539 Mdot
.716 .78484 Mdot
.4854 .31105 Mdot
.56697 .20032 Mdot
.65075 .27471 Mdot
.51534 .90118 Mdot
.54768 .66994 Mdot
.38057 .65046 Mdot
.63141 .81844 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`03ooooo`;o0000]?ooool00:;ooooo00?oEEEEofIV
I_l000001oooool00ol0003oooooooooo`03ooooo`;o0000]?ooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool01oooool2o`000;3ooooo002/ooooo`?o00001ooo
ool2o`000;3ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002Mooooo`;o00002?ooool6o`000;_ooooo002Mooooo`;o0000
2?ooool8o`000;Wooooo002Nooooo`;o00003?ooool2o`000;[ooooo002Nooooo`;o00003?ooool2
o`000;[ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`04o`000?oooooo0000o`00
0;Sooooo002/ooooo`04o`000?oooooo0000o`000;Sooooo002/ooooo`04o`000?oooooo0000o`00
0;Sooooo002/ooooo`04o`000?oooooo0000o`000;Sooooo002/ooooo`?o00000_ooool2o`000;Go
oooo002/ooooo`03o`000?oooooooooo00;ooooo0_l0002eooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`08ooooo`;o0000[oooool00:7ooooo0ol00008ooooo`03o`00
0?oooooooooo00Sooooo0_l0002_ooooo`00XOooool5o`0000Kooooo00?o0000ooooooooool0^Ooo
ool00:7ooooo0_l000000ooooooo0000o`000006ooooo`?o0000^Oooool00:7ooooo0_l00006oooo
o`;o000000?oooooo`000?ooool0^_ooool00:Wooooo0_l000000ooooooo0000ooooo`2jooooo`00
T_ooool2o`0001Sooooo00?o0000ooooooooool0^Oooool009;ooooo0_l00007ooooo`?o00003_oo
ool00ol0003oooooooooo`2iooooo`00Voooool3o`0000kooooo00?o0000ooooooooool0^Oooool0
08Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2iooooo`00ROooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0=ooooo`;o0000Z_ooool0087ooooo1_l00002
ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oo
oooooooo00?ooooo0ol0000=ooooo`;o0000Z_ooool008Wooooo00Go0000ooooooooooooooooo`00
000;ooooo`;o000000?oooooob4Q8Oooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0;Wooooo0029ooooo`05o`000?ooooooooooooooool000002oooool2o`000003oooooomE
EEGoc<c<00Cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo017ooooo
0_l0002Vooooo`00ROooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool0
0oooool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooooooo`;o00003_ooool2o`000:Ko
oooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool2o`000003ooooool@413ooooo00;o
oooo00?o<S8booooooooool00_ooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooooooo
o`;o00003_ooool2o`000:Kooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool2o`00
0003ooooool0003o000000?o00001?ooool5o`0000Gooooo00?o0000ooooooooool0^Oooool00:Go
oooo1Ol00002ooooo`03o`000?oooooooooo02_ooooo0_l0002<ooooo`00Y?ooool2o`000004oooo
ool0003o0000o`0000;ooooo00?o0000ooooooooool0:_ooool3o`0008cooooo002Tooooo`;o0000
1_ooool00ol0003oooooooooo`0Zooooo`;o0000SOooool00:cooooo0ol0000[ooooo`;o0000S?oo
ool009gooooo0ol0000<ooooo`03o`000?oooooooooo01Kooooo0_l0000Cooooo`;o0000S?ooool0
09gooooo0ol0000<ooooo`;o00005oooool2o`000:7ooooo002Kooooo`;o00003oooool2o`000;[o
oooo002Kooooo`;o00003oooool00ol0003oooooooooo`0Kooooo`;o0000W?ooool009?ooooo0_l0
000Gooooo`?o00006_ooool3o`0009cooooo002Cooooo`;o00005oooool3o`0000cooooo0_l0000<
ooooo`;o0000WOooool008gooooo0_l00004ooooo`;o00005oooool00ol0003oooooooooo`0<oooo
o`;o0000Zoooool008gooooo0_l00004ooooo`;o00005oooool3o`000;Wooooo002Booooo`;o0000
6?ooool00ol0003oooooooooo`0>ooooo`;o0000ZOooool009;ooooo0_l0000Hooooo`03o`000?oo
oooooooo00kooooo0_l0002Yooooo`00[?ooool00ol0003oooooooooo`03ooooo`;o0000]?ooool0
093ooooo0_l0000=ooooo`?o00002_ooool00ol0003oooooooooo`03ooooo`;o00002oooool2o`00
0:Oooooo002@ooooo`;o00003Oooool3o`0000[ooooo00?o0000ooooooooool04?ooool2o`0002?o
oooo0_l00022ooooo`00Z_ooool3o`00017ooooo0_l0000Aooooo`;o00004Oooool2o`0008;ooooo
002Zooooo`?o00004Oooool2o`00017ooooo0_l0002Eooooo`00[?ooool3o`0001?ooooo0_l0000>
ooooo`;o0000U?ooool00:cooooo00?o0000ooooooooool04oooool2o`0000kooooo0_l0002Doooo
o`00R_ooool2o`0000?ooooo0_l00004ooooo`;o00001?ooool2o`0000oooooo00?o0000oooooooo
ool01_ooool2o`000;7ooooo002:ooooo`;o00000oooool2o`0000Cooooo0_l00004ooooo`;o0000
3oooool00ol0003oooooooooo`06ooooo`;o0000<Oooool2o`0007kooooo002:ooooo`;o00000ooo
ool2o`0001_ooooo00?o0000ooooooooool05Oooool2o`0002;ooooo0_l0001nooooo`00Soooool2
o`0001_ooooo00?o0000ooooooooool05Oooool2o`000:;ooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002Vooooo`Co00000_ooool00ol0003oooooooooo`02o`000;Oooooo002Hooooo`;o0000
3?ooool4o`0000;ooooo1Ol0000Dooooo`;o0000XOooool008Wooooo0_l0000=ooooo`;o00001?oo
ool2o`0000cooooo00?o0000ooooooooool05_ooool2o`000:7ooooo0029ooooo`;o00001oooool2
o`0000[ooooo0_l0000<ooooo`03o`000?oooooooooo02Sooooo0_l0002?ooooo`00Poooool2o`00
00gooooo0_l00003ooooo`;o00004_ooool2o`0000Gooooo0_l00007ooooo`;o00002_ooool2o`00
00kooooo0_l0002?ooooo`00Poooool2o`0001;ooooo0_l0000Booooo`;o00001Oooool2o`0000Oo
oooo0_l0000:ooooo`;o0000Woooool008?ooooo0_l0000Wooooo`03o`000?oooooooooo00Gooooo
0_l0000Qooooo`;o0000Soooool0097ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo0_l00007ooooo`;o00008Oooool2o`0001Ko
oooo0_l0001gooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03
ogMgMolb<S;ooooo00?ooooo0_l0000?ooooo`;o00007?ooool2o`0001?ooooo0_l0001gooooo`00
ROooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?o
oooo0_l0000>ooooo`Co00006_ooool2o`0008cooooo002Aooooo`;o00000_ooool00ol0003ooooo
ooooo`09ooooo`;o00000_ooool00omgMgOo<S8booooo`04ooooo`?o00003oooool2o`0002oooooo
0_l0001gooooo`00TOooool2o`0000;ooooo00?o0000ooooooooool02Oooool2o`000004ob4Q8Ol0
003o<S8bolc<c0;o00000oooool00ol0003oooooooooo`10ooooo`;o0000Moooool008;ooooo0_l0
000=ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`02ooooo`;o0000
0oooool00ol0003oooooooooo`07ooooo`;o0000/?ooool008;ooooo0_l0000=ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
0ol0002_ooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`03o`00
0?oooooooooo00Sooooo0_l00008ooooo`;o00006_ooool2o`0008Wooooo002/ooooo`03o`000?oo
oooooooo01;ooooo0_l0000Jooooo`;o0000ROooool00:cooooo00?o0000ooooooooool04Oooool2
o`000:Kooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`0Aooooo`?o0000YOooool009Co
oooo0_l0000Fooooo`?o00004_ooool2o`0000_ooooo0_l0000=ooooo`;o0000ROooool00:cooooo
00?o0000ooooooooool07oooool2o`0000gooooo0_l00029ooooo`00Q_ooool2o`0002Cooooo00?o
0000ooooooooool07oooool2o`0009Sooooo0026ooooo`;o00009?ooool00ol0003oooooooooo`2i
ooooo`00Q_ooool2o`00023ooooo0_l00002ooooo`03o`000?oooooooooo00cooooo0_l0000ioooo
o`;o0000L?ooool008Kooooo0_l0000Pooooo`;o00000_ooool00ol0003oooooooooo`0<ooooo`;o
0000>Oooool2o`00073ooooo002>ooooo`;o00006_ooool3o`000;_ooooo002>ooooo`;o00001_oo
ool2o`0001;ooooo0ol0000fooooo`;o0000Poooool008[ooooo0_l0000:ooooo`;o00005?ooool3
o`0003Cooooo0_l00023ooooo`00R_ooool2o`00023ooooo00?o0000ooooooooool05_ooool2o`00
0:7ooooo0026ooooo`;o00006oooool2o`0000Oooooo00?o0000ooooooooool05_ooool2o`000:7o
oooo0026ooooo`;o00006oooool2o`0000Oooooo00?o0000ooooooooool0^Oooool009Oooooo0_l0
000>ooooo`;o00000oooool00ol0003oooooooooo`2iooooo`00U?ooool2o`000003ooooool0003o
000000kooooo0_l00003ooooo`03o`000?oooooooooo0;Wooooo002Dooooo`;o00005_ooool00ol0
003oooooooooo`1<ooooo`;o0000Joooool00:cooooo00?o0000ooooooooool00_ooool2o`0000go
oooo0_l00006ooooo`;o0000<Oooool2o`0006_ooooo002/ooooo`?o00000_ooool2o`0000gooooo
0_l00006ooooo`;o0000W_ooool00:cooooo00?o0000ooooooooool02_ooool2o`000:gooooo002C
ooooo`;o00005oooool00ol0003oooooooooo`0:ooooo`;o0000[Oooool009?ooooo0_l000000ooo
oooo0000o`00000Dooooo`03o`000?oooooooooo00;o00002?ooool2o`000:gooooo0024ooooo`;o
00004?ooool2o`0001Cooooo00?o0000ooooooooool00_l0000gooooo`;o0000O_ooool008Cooooo
0_l0000Vooooo`03o`000?oooooooooo01;ooooo0_l0000Uooooo`;o0000O_ooool009;ooooo0_l0
000Hooooo`03o`000?oooooooooo01;ooooo0_l0000Eooooo`;o00003oooool2o`0007gooooo002B
ooooo`;o00006?ooool00ol0003oooooooooo`06ooooo`;o00002_ooool2o`0000Wooooo0_l0000:
ooooo`;o00003oooool2o`0007gooooo002/ooooo`03o`000?oooooooooo00Kooooo0_l00004oooo
o`;o00001?ooool2o`0000Wooooo0_l0000Jooooo`;o0000O_ooool007oooooo0_l0000Dooooo`;o
00005Oooool3o`0000cooooo0_l0000[ooooo`;o00005Oooool2o`0006Oooooo001oooooo`;o0000
5?ooool2o`0001Gooooo00?o0000ooooooooool03?ooool2o`0002cooooo0_l0000Dooooo`;o0000
Ioooool008Cooooo0_l0000Vooooo`03o`000?oooooooooo01kooooo0_l0000Jooooo`?o0000O?oo
ool008Cooooo0_l0000Dooooo`;o00004?ooool00ol0003oooooooooo`07ooooo`;o00005Oooool2
o`0001_ooooo0ol0001kooooo`00V_ooool2o`0000oooooo0_l00009ooooo`;o00003?ooool2o`00
02Gooooo0_l0000Booooo`;o0000Ioooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`;o00005oooool2
o`0003Wooooo0_l0001Wooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0;Wooooo0021ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03cooooo0_l0
001kooooo`00ROooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00omgMgOo<S8booooo`04ooooo`?o00008?ooool2o`0001[ooooo0_l0001kooooo`00ROooool0
1Ol0003ooooooooooooooooo000000?ooooo0_l00009ooooo`03ogMgMomVIVKooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00Cooooo0_l0000Jooooo`;o0000
Uoooool008Wooooo00Go410@oooooooooooooooooa0@4002o`000003ooooool0003o000000[ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo
0_l00003ooooo`;o00008Oooool2o`0008_ooooo001oooooo`;o00002?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00;o00002Oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`09ooooo`;o00005_ooool2o`0000Wooooo0_l0002;ooooo`00
Ooooool2o`0000Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`;o00000_ooool01OnHV9So
410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo027ooooo0_l00009oooo
o`;o0000Roooool009Gooooo0_l0000Eooooo`03o`000?oooooooooo0;Wooooo002Hooooo`Co0000
4?ooool00ol0003oooooooooo`0]ooooo`Co0000R?ooool009Sooooo1?l0000@ooooo`03o`000?oo
oooooooo02gooooo1?l00028ooooo`00Poooool2o`00013ooooo0_l0000Eooooo`?o00006?ooool2
o`0009oooooo0023ooooo`;o00004?ooool2o`0001Gooooo00?o0000ooooooooool06?ooool2o`00
01?ooooo0_l0002:ooooo`00Roooool2o`0001oooooo00?o0000ooooooooool0;Oooool2o`0008[o
oooo002;ooooo`Co00007Oooool01?l0003oooooo`000?l0000Gooooo`;o0000Woooool008gooooo
0_l0000Mooooo`04o`000?oooooo0000o`0001Oooooo0_l0002Oooooo`00[?ooool00ol0003ooooo
ooooo`0Iooooo`;o0000W_ooool009?ooooo0_l0000Gooooo`03o`000?oooooooooo01Wooooo0_l0
002Nooooo`00Toooool2o`000003ooooool0003o000001Cooooo00?o0000ooooooooool04Oooool2
o`000:Kooooo002Fooooo`;o00005?ooool3o`00017ooooo0_l0002Vooooo`00[?ooool00ol0003o
ooooooooo`12ooooo`;o0000MOooool008gooooo0_l0000Mooooo`04o`000?ooooooooooooooo`;o
0000?oooool2o`0007Gooooo002=ooooo`;o00007Oooool01?l0003oooooooooooooool2o`0000oo
oooo0_l0000Nooooo`;o00003?ooool3o`0007Kooooo002/ooooo`03o`000?oooooooooo01;ooooo
0ol0000Mooooo`;o00003?ooool3o`0007Kooooo002/ooooo`03o`000?oooooooooo00cooooo0_l0
0004ooooo`?o00003oooool2o`0000cooooo0_l00025ooooo`00Qoooool2o`0002?ooooo0ol0000<
ooooo`;o00001_ooool2o`0000kooooo0_l0000<ooooo`;o00003_ooool2o`0007Gooooo0027oooo
o`;o00002oooool2o`0001Kooooo0ol0000Cooooo`?o00001?ooool2o`0002Gooooo1?l0001doooo
o`00U?ooool2o`0001Kooooo00?o0000ooooooooool01Oooool2o`0000cooooo0_l00005ooooo`;o
00009Oooool4o`0007Cooooo002/ooooo`?o00001Oooool2o`000;;ooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo0029ooooo`;o00001oooool2o`0001Sooooo00?o0000ooooooooool0^Oooool0
00Wooooo1?l000000ol@413oooooooooo`0Fooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@0Fooooo`03o`000?oooooooooo00Gooooo0_l0000Aooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@04ooooool0003o0000ooooo`Go00001?ooool01Om4A4Co0000
o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4
A4Co0000o`000?l0003ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd06?ooool4o`000003oa0@
4?oooooooooo01;ooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007
ooooo`03ogMgMolb<S;ooooo01Gooooo00?o0000ooooooooool01Oooool2o`00017ooooo00?oMgMg
oiRHV?ooool00_l00005ooooo`;o8B4Q00Woooooo`000?l0003ooooooiRHV?lQ8B7ok^k^oooooom4
A4@01oooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Oooooo0_l000000olb<S;oooooooooo`0=ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`0Iooooo`03o`000?oooooo
oooo01Cooooo0006o`0000Gooooo00?o0000ooooooooool04?ooool6o`0000;ooooo00Go410@oooo
oooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool01Oooool6
o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00Gooooo1_l0
0002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`00
0?oooooooooo01Cooooo00Co0000ooooool0003o00004oooool2o`0000;ooooo00?o410@oooooooo
ool00_l0000<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool03Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool03Oooool01Ol@413ooooooooooooooooo
410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooo
oooo000000oooooo00?oMgMgoc8b<_ooool03_ooool01_l0003ooooooooooooooooo0000ooooo`;o
00002_ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo01Gooooo00Co0000ooooool0
003o00004oooool2o`0000;ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^00Oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000oooooo00?o
MgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool0
1_ooool00omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oo
oooooooo01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00oooooo00Ko0000ooooooooooooooooo`000?ooool2o`0000_ooooo
00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Kooooo00?o0000oooooooo
ool06?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?oo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[ooooo00?o0000ooooooooool05?ooool000_o
oooo00?o0000ooooooooool06?ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo01Sooooo0ol0000Hooooo`05oa0@4?ooooooooooooooool@4100
3oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo0_l000000ooooooo410@
ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?o0000ooooooooool04Oooool01Ol@413ooooo
oooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`0Aoooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool0
1Oooool2o`00017ooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00kooooo0_l000001_oo
ooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool05?ooool000Wooooo00?oEEEEofIVI_l000006_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<00Cooooo1?l00004ooooo`;o00004Oooool00ol0003oooooooooo`0Hooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02?ooool2o`000006oooooonHV9So410@o`000?lQ8B7oc<c<1?ooool4o`00
013ooooo0ol000000olb<S;ok^k^ooooo`0;ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00_ooooo1Ol00004ooooo`Co00006Oooool00omEEEGoIVIVo`00000Fooooo`00[?ooool00ol0
003oooooooooo`09ooooo`;o00002_ooool2o`0000kooooo0_l0000Nooooo`;o00004_ooool2o`00
05kooooo001nooooo`;o0000;?ooool00ol0003oooooooooo`09ooooo`;o00002_ooool2o`0002go
oooo0_l0000Cooooo`;o0000G_ooool007kooooo0_l0000?ooooo`;o00006oooool00ol0003ooooo
ooooo`14ooooo`;o0000J?ooool2o`0000;ooooo0_l00005ooooo`00Soooool2o`0001_ooooo00?o
0000ooooooooool0<_ooool2o`00013ooooo0_l0001Xooooo`06onk^k_lQ8B7oQhN7okZj^_l0003o
gMgM1Oooool00:cooooo00?o0000ooooooooool0<_ooool2o`0002Gooooo0_l0001Dooooo`04omgM
gOl0003o410@olc<c0Kooooo0007oooooooo0000C?l0000<ooooo`04onk^k_lQ8B7o410@onk^kPKo
oooo0007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`02ooooo`;o00000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo
00Co8B4QogMgMomgMgOo<S8b1_ooool000Oooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`04o`0002?ooooo00?o0000ooooooooool02?ooool4o`0001[ooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Wooooo0_l00002ooooo`;o0000
1Oooool00:cooooo00?o0000ooooooooool00_l0000`ooooo`Co0000Poooool00:cooooo00?o0000
ooooooooool02Oooool2o`0001;ooooo0_l0002Jooooo`00P_ooool2o`0002Sooooo00?o0000oooo
ooooool01_ooool2o`000003ooooool0003o000001;ooooo0_l0002Jooooo`00P_ooool2o`0000go
oooo0_l0000Iooooo`03o`000?oooooooooo00Kooooo0_l0000nooooo`;o0000LOooool0097ooooo
0_l0000Iooooo`03o`000?oooooooooo02Kooooo0_l0000Mooooo`?o0000LOooool00:cooooo0ol0
000>ooooo`;o00005_ooool2o`0000cooooo0_l0000?ooooo`;o0000L_ooool0097ooooo0_l0000I
ooooo`03o`000?oooooooooo00kooooo0_l0000Tooooo`;o00008oooool2o`0005kooooo002Aoooo
o`;o00006Oooool00ol0003oooooooooo`06ooooo`;o0000DOooool2o`0005kooooo002Fooooo`;o
00005?ooool00ol0003oooooooooo`06ooooo`;o00007Oooool2o`0001gooooo0_l0001cooooo`00
Soooool2o`0000Gooooo0_l0000Dooooo`03o`000?oooooooooo02Gooooo0_l0000Mooooo`;o0000
Loooool008oooooo0_l0000Kooooo`03o`000?oooooooooo03Cooooo0_l00023ooooo`00Q_ooool2
o`0002Cooooo00?o0000ooooooooool05Oooool2o`0001gooooo0_l00023ooooo`00O_ooool2o`00
00Kooooo0_l000000ooooooo0000o`00000;ooooo`;o00005?ooool00ol0003oooooooooo`0Eoooo
o`;o0000X_ooool007kooooo0_l00006ooooo`;o000000?oooooo`000?l000002Oooool4o`0001Co
oooo00?o0000ooooooooool0FOooool2o`0005kooooo0026ooooo`;o00003?ooool2o`0001Kooooo
0ol0000Dooooo`;o00004?ooool2o`00037ooooo0_l0001Nooooo`00[?ooool00ol0003ooooooooo
o`0=ooooo`;o00001Oooool2o`00013ooooo0_l0002Aooooo`00P_ooool2o`0002Sooooo00?o0000
ooooooooool03Oooool2o`0000Gooooo0_l00006ooooo`;o0000Voooool008;ooooo0_l0000Xoooo
o`03o`000?oooooooooo01cooooo0_l0000Dooooo`;o0000QOooool00:cooooo00?o0000oooooooo
ool02Oooool2o`0002Oooooo0_l0000Aooooo`;o0000L_ooool00:cooooo00?o0000ooooooooool0
2Oooool2o`0000Sooooo0_l0000`ooooo`;o0000L_ooool008Oooooo0_l0000Sooooo`03o`000?oo
oooooooo01?ooooo0_l0002Tooooo`00Qoooool2o`0002?ooooo00?o0000ooooooooool01?ooool2
o`0002gooooo0_l0000@ooooo`;o0000L_ooool00:cooooo0ol00004ooooo`;o00005_ooool2o`00
00Sooooo0_l0000;ooooo`;o00004?ooool2o`0007;ooooo002/ooooo`03o`000?oooooooooo00go
oooo0_l0000=ooooo`;o00002?ooool2o`00097ooooo002/ooooo`03o`000?oooooooooo00gooooo
0_l0000Tooooo`;o0000Q?ooool008[ooooo0_l0000Pooooo`03o`000?oooooooooo03?ooooo0_l0
000>ooooo`;o0000M?ooool008[ooooo0_l0000Pooooo`03o`000?oooooooooo01;ooooo0_l0000_
ooooo`;o0000M?ooool00:cooooo00?o0000ooooooooool00oooool2o`0000gooooo0_l00007oooo
o`;o00001oooool3o`0009;ooooo002Eooooo`;o00005Oooool00ol0003oooooooooo`03ooooo`;o
00005_ooool2o`0000Oooooo0ol0002Booooo`00Poooool2o`00013ooooo0_l0000Eooooo`03o`00
0?oooooooooo0;Wooooo0023ooooo`;o00009oooool3o`000;Wooooo002/ooooo`03o`000?oooooo
oooo017ooooo0_l0002Vooooo`00V?ooool2o`0000kooooo0_l00002ooooo`03o`000?oooooooooo
017ooooo0_l0002Vooooo`00V?ooool2o`0000kooooo0_l00002ooooo`03o`000?oooooooooo04?o
oooo0_l0001dooooo`00[?ooool00ol0003oooooooooo`0Rooooo`;o00007oooool2o`0007Cooooo
002Aooooo`;o00002?ooool2o`0000oooooo00?o0000ooooooooool06Oooool2o`0000Oooooo0ol0
002Dooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo0_l00002ob4Q8@04ooooool0
003o0000ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooooooo
ool02_ooool2o`0000cooooo0ol00007ooooo`?o00002oooool2o`0008Oooooo0029ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@09ooooool0003o0000oooooonHV9So8B4Qonk^k_oo
ooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0:ooooo`;o00003?oo
ool2o`0001Kooooo0_l00027ooooo`00Q?ooool2o`0000?ooooo00Go410@oooooooooooooooooa0@
4003o`0000Wooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o00004?oo
ool2o`0001cooooo0_l0000?ooooo`Co0000M_ooool008Cooooo0_l00003ooooo`04o`000?oooooo
ooooooooo`Co00002_ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool04?ooool2o`0001cooooo1?l0000=ooooo`Co0000M_ooool008Wooooo00Co0000
oooooooooooooooo0ol0000<ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`03o`000?oooooooooo02oooooo0ol00027ooooo`00ROooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Wooooo0_l0000dooooo`;o0000N?ooool008Wooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`06ooooo`;o00000oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`09ooooo`;o00001?ooool2o`0002kooooo0_l0001hooooo`00
ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo0_l00003ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool03oooool2o`000:Sooooo002/ooooo`03
o`000?oooooooooo0;Wooooo001oooooo`;o00001oooool2o`0002;ooooo00?o0000ooooooooool0
3oooool2o`00033ooooo0_l0001fooooo`00Ooooool2o`0000Oooooo0_l0000Rooooo`03o`000?oo
oooooooo00oooooo0_l00004ooooo`;o00002Oooool2o`0001_ooooo0_l00002ooooo`;o0000M_oo
ool007oooooo0_l00003ooooo`;o00009_ooool4o`0001Cooooo0_l00009ooooo`;o00006oooool2
o`0007[ooooo0024ooooo`;o00000_ooool2o`0000_ooooo0_l00005ooooo`;o00003_ooool01Ol0
003oooooo`000?l0003ooooo00;o0000]Oooool008Sooooo0_l0000;ooooo`;o00001Oooool2o`00
00kooooo00?o0000ooooooooool00_ooool2o`00017ooooo0_l0002Rooooo`00[?ooool00ol0003o
ooooooooo`02ooooo`;o00004Oooool2o`0000Wooooo0_l0002Gooooo`00[?ooool00ol0003ooooo
ooooo`0Eooooo`;o00002?ooool3o`0001_ooooo0_l0001jooooo`00[?ooool00ol0003ooooooooo
o`07ooooo`;o00003?ooool2o`0000Sooooo0_l0000Looooo`;o0000N_ooool00:Sooooo0_l00002
ooooo`03o`000?oooooooooo00Oooooo0_l00003ooooo`?o0000;_ooool2o`0007[ooooo002Joooo
o`;o00003?ooool2o`0000;ooooo00?o0000ooooooooool03?ooool3o`0000kooooo0_l0000Noooo
o`;o0000N_ooool009[ooooo0_l00003ooooo`;o00002oooool3o`0001gooooo0_l0002Jooooo`00
SOooool2o`0000Gooooo0_l00009ooooo`;o00002oooool00ol0003oooooooooo`0Mooooo`;o0000
V_ooool008gooooo0_l00005ooooo`;o00005_ooool00ol0003oooooooooo`0Mooooo`;o00007_oo
ool3o`0007Wooooo002Hooooo`;o00004_ooool00ol0003oooooooooo`0looooo`Co0000NOooool0
09Sooooo0_l0000Booooo`03o`000?oooooooooo03cooooo0ol0001jooooo`00[?ooool00ol0003o
ooooooooo`04ooooo`;o0000/oooool00:Sooooo0_l00002ooooo`03o`000?oooooooooo00Cooooo
0_l0000<ooooo`;o0000YOooool00:Sooooo0_l00002ooooo`03o`000?oooooooooo01;ooooo0_l0
000Wooooo`;o0000O?ooool00:cooooo0ol00009ooooo`;o00007?ooool2o`0001;ooooo0_l0001l
ooooo`00[?ooool00ol0003oooooooooo`09ooooo`;o00007?ooool2o`00093ooooo002Cooooo`;o
00002oooool3o`0000Cooooo0_l00003ooooo`03o`000?oooooooooo0;Wooooo002Cooooo`;o0000
2oooool3o`0000;ooooo1?l00003ooooo`03o`000?oooooooooo02Kooooo0_l0002Aooooo`00Vooo
ool2o`0000Sooooo0_l00005ooooo`03o`000?oooooooooo00;o00009?ooool2o`00097ooooo002K
ooooo`;o00003oooool00ol0003oooooooooo`02o`000;Oooooo002Hooooo`;o00004_ooool00ol0
003oooooooooo`0Vooooo`;o0000TOooool009Sooooo0_l0000Booooo`03o`000?oooooooooo02Ko
oooo0_l0000@ooooo`;o0000Ooooool00:cooooo0ol0000Hooooo`;o00007_ooool2o`0007oooooo
002/ooooo`03o`000?oooooooooo01Sooooo0_l0002Oooooo`00UOooool2o`0001Gooooo00?o0000
ooooooooool09Oooool2o`0002Gooooo0_l0001[ooooo`00UOooool2o`0001Gooooo00?o0000oooo
ooooool09Oooool2o`00013ooooo0_l0000Cooooo`;o0000Joooool008Oooooo0_l0000Kooooo`;o
00001_ooool00ol0003oooooooooo`0Eooooo`;o00008?ooool2o`00083ooooo0027ooooo`;o0000
6oooool3o`0000Gooooo00?o0000ooooooooool05Oooool2o`000:;ooooo0022ooooo`;o00002Ooo
ool2o`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool00om4A4Co0000
o`000002o`0000Gooooo00?o0000ooooooooool0=_ooool2o`00087ooooo0022ooooo`;o00002Ooo
ool2o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`;o000000?o8B4Qooooooooool0
1_ooool00omgMgOo<S8booooo`04ooooo`04o`000?ooooooooooooooo`?o00007Oooool4o`0000oo
oooo1?l00021ooooo`00TOooool01Ol@413ooooooooooooooooo410@00Cooooo0_l0000:ooooo`03
o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo0ol00005ooooo`;o00005_ooool4o`00
00oooooo0_l00023ooooo`00TOooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b
<_ooool00oooool4o`0000Wooooo0_l0002^ooooo`00TOooool01Ol0003ooooooooooooooooo0000
00cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`;o00008oooool2o`0009Kooooo002Aoooo
o`05oa0@4?l0003o0000ooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo023ooooo0ol0002Fooooo`00Poooool2o`0000cooooo00GoMgMgo`000?l0003oV9RHogMgM`08
ooooo`;o00000_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo023ooooo0_l0002G
ooooo`00Poooool2o`0000cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`;o00000_ooool6
o`0000Cooooo00?o0000ooooooooool0;oooool2o`000003ooooool0003o000008Gooooo002Voooo
o`;o00001?ooool00ol0003oooooooooo`0_ooooo`Go0000QOooool009Wooooo0_l0000Aooooo`03
o`000?oooooooooo017ooooo0_l0000Looooo`Go0000QOooool009Wooooo0_l0000Aooooo`?o0000
1_ooool2o`0000Wooooo0_l0000Looooo`Go0000QOooool00:cooooo0ol00006ooooo`;o00005?oo
ool2o`0001;ooooo0_l00027ooooo`00[?ooool00ol0003oooooooooo`0Looooo`;o0000Voooool0
08Wooooo0ol0000Pooooo`03o`000?oooooooooo0;Wooooo0029ooooo`?o00008?ooool00ol0003o
ooooooooo`14ooooo`;o0000Loooool008_ooooo0_l0000Oooooo`03o`000?oooooooooo04Cooooo
0_l0001cooooo`00Roooool2o`0001oooooo00?o0000ooooooooool00_ooool2o`0000Wooooo0_l0
000Looooo`;o0000S?ooool00:cooooo00?o0000ooooooooool00_ooool2o`0000Wooooo0_l0000L
ooooo`?o0000Roooool00:Sooooo0_l00002ooooo`03o`000?oooooooooo02cooooo0_l0002;oooo
o`00Roooool2o`00017ooooo0_l00008ooooo`;o00000_ooool5o`0002[ooooo0_l0002;ooooo`00
Roooool2o`00017ooooo1?l0000:ooooo`03o`000?oooooooooo00;o0000:_ooool2o`0001;ooooo
0_l0001gooooo`00X?ooool2o`0000[ooooo00?o0000ooooooooool00_l0000Vooooo`;o00005_oo
ool2o`0007Oooooo002/ooooo`03o`000?oooooooooo00;o00002Oooool2o`0001[ooooo0ol0002?
ooooo`00[?ooool00ol0003oooooooooo`0;ooooo`;o00006_ooool2o`00093ooooo002/ooooo`03
o`000?oooooooooo00[ooooo0_l0000Jooooo`;o0000TOooool009[ooooo0_l0000@ooooo`03o`00
0?oooooooooo00[ooooo0_l00008ooooo`Co00003Oooool5o`0008oooooo002Jooooo`;o00004?oo
ool00ol0003oooooooooo`0Dooooo`Co00003Oooool5o`0008oooooo0026ooooo`;o00009?ooool3
o`0002Kooooo0_l0002Aooooo`00Q_ooool2o`0002Cooooo00?o0000ooooooooool0^Oooool008ko
oooo0_l0000Looooo`03o`000?oooooooooo01Cooooo0_l0002Sooooo`00S_ooool2o`0000cooooo
0_l0000>ooooo`03o`000?oooooooooo00Gooooo0_l0000=ooooo`;o00003Oooool2o`0009Cooooo
002Looooo`;o00002_ooool2o`0000;ooooo00?o0000ooooooooool01Oooool2o`0001cooooo0_l0
002Dooooo`00U_ooool2o`00013ooooo0_l00002ooooo`03o`000?oooooooooo00Cooooo0_l0000:
ooooo`;o0000Yoooool009Kooooo0_l0000?ooooo`;o00000oooool00ol0003oooooooooo`04oooo
o`;o00002_ooool2o`000:Oooooo002Wooooo`;o00000oooool00ol0003oooooooooo`0?ooooo`;o
00004_ooool2o`0001?ooooo0_l0001oooooo`00[?ooool00ol0003oooooooooo`0?ooooo`;o0000
4_ooool2o`0001?ooooo0_l0001oooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooo
oooo023ooooo0ol0002Fooooo`00[?ooool00ol0003oooooooooo`0Pooooo`?o0000U_ooool00:co
oooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool07_ooool2o`0009Wooooo
0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool0
1?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool07_ooool2o`0009Wo
oooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOoo
ool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05oa0@
4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0^Oooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`000;Wooooo0029ooooo`03o`00
0?oooooo000000;o00001?ooool2o`0000Sooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00;ooooo0_l000000ooooooo0000ooooo`2jooooo`00ROooool01Ol@413ooooo
o`000?l0003o410@00Cooooo0_l00008ooooo`04ojVYZOmgMgOo0000o`0000;ooooo00Co0000oooo
oooooooooooo0_l000001Ooooooo0000o`000?oooooo00000;_ooooo0029ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01?ooool3o`0000Cooooo00Go410@oooooooooooooooooc8b<P02o`0000;ooooo
0ol000000ooooooo0000o`000004ooooo`03o`000?oooooooooo00Sooooo0_l0002_ooooo`00ROoo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_l00004ooooo`Go00001?ooool4o`0000Kooooo
00?o0000ooooooooool01Oooool2o`000003ooooool0003o00000:oooooo002/ooooo`03o`000?oo
oooooooo00Cooooo0ol0002booooo`00[?ooool00ol0003oooooooooo`04ooooo`;o0000/oooool0
0:cooooo00?o0000ooooooooool05?ooool2o`000:?ooooo002Fooooo`;o00005?ooool3o`0000;o
oooo0_l0000@ooooo`;o0000Xoooool009Kooooo0_l0000Dooooo`03o`000?oooooooooo00;ooooo
0_l0000Booooo`;o0000XOooool00:cooooo00?o0000ooooooooool05_ooool2o`000:7ooooo002/
ooooo`03o`000?oooooooooo0;Wooooo002Gooooo`;o00004oooool00ol0003oooooooooo`2ioooo
o`00Uoooool2o`0001?ooooo00?o0000ooooooooool0:?ooool2o`0008oooooo002/ooooo`03o`00
0?oooooooooo00oooooo0_l00002ooooo`;o00004oooool2o`0008oooooo002/ooooo`03o`000?oo
oooooooo00oooooo0_l00002ooooo`;o0000Y?ooool00:cooooo0ol0000Aooooo`;o0000Y_ooool0
0:cooooo00?o0000ooooooooool04Oooool2o`000:Kooooo002Looooo`?o00003Oooool00ol0003o
ooooooooo`2iooooo`00W?ooool3o`0000cooooo0_l0000>ooooo`;o0000Zoooool009cooooo0_l0
0004ooooo`;o00001oooool2o`0000cooooo1?l0002[ooooo`00X_ooool2o`0000Sooooo00?o0000
ooooooooool02_ooool2o`000:gooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03
o`000?oooooooooo00Oooooo0_l000000ooooooo0000o`00002]ooooo`00[?ooool00ol0003ooooo
ooooo`07ooooo`;o000000?oooooo`000?l00000[Oooool009;ooooo0_l0000Hooooo`?o00002?oo
ool2o`000:oooooo002Booooo`;o00006?ooool00ol0003oooooooooo`08ooooo`;o0000[oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool06Oooool2o`0009kooooo002/ooooo`03o`000?oooooooooo01Wooooo0_l0002Noooo
o`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Iooooo`;o00004Ooo
ool00ol0003oooooooooo`2iooooo`00VOooool3o`00013ooooo00?o0000ooooooooool0^Oooool0
09[ooooo0_l0000@ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002Rooooo`Co000000?o410@ooooooooool00_ooool2o`000;_ooooo002Tooooo`03o`000?oo
oooooooo00?ooooo0ol0002kooooo`00Y?ooool00ol0003oooooooooo`03ooooo`Go0000^Oooool0
0:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo
00?o0000ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:;ooooo00?oEEEE
ofIVI_l00000`oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00:[ooooo00Co410@o`000?l0003o0000^_ooool00:_ooooo00?o0000ooooooooool0^_ooool0
0:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00Ko0000ogMgMol0003o0000oeEEEOo^k^jg
ooooo`00Zoooool01_l0003oEEEEonk^k_ooooooMgMgoeEEEKOooooo002[ooooo`03o`000?o^k^ko
oooo00;ooooo00?o0000ooooooooool0]Oooool00:_ooooo00?o0000onk^k_ooool00_ooool00ol0
003oooooooooo`2eooooo`00Zoooool01_l0003oEEEEonk^k_ooooooMgMgofIVI[Oooooo002Zoooo
o`03oa0@4?l0003oMgMg00;o000000?oIVIVonk^k_ooool0]_ooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.44791 .87894 Mdot
.42764 .14791 Mdot
.47665 .6359 Mdot
.45562 .26243 Mdot
.41655 .67948 Mdot
.6271 .59 Mdot
.47985 .32788 Mdot
.7296 .48156 Mdot
.64672 .24664 Mdot
.44847 .7511 Mdot
.44059 .25997 Mdot
.72454 .57183 Mdot
.63891 .32467 Mdot
.41185 .4573 Mdot
.7136 .60446 Mdot
.55622 .46516 Mdot
.40364 .65228 Mdot
.64504 .34071 Mdot
.57445 .57293 Mdot
.55741 .86472 Mdot
.64727 .36007 Mdot
.53026 .14207 Mdot
.56823 .20177 Mdot
.65458 .37399 Mdot
.67628 .73533 Mdot
.58509 .37489 Mdot
.50493 .24597 Mdot
.57536 .54602 Mdot
.51751 .91633 Mdot
.44207 .11854 Mdot
.65956 .42347 Mdot
.64646 .24147 Mdot
.71716 .42444 Mdot
.43997 .17808 Mdot
.55546 .23795 Mdot
.61259 .75726 Mdot
.39683 .20108 Mdot
.57027 .43736 Mdot
.46417 .9453 Mdot
.72375 .59863 Mdot
.68148 .73331 Mdot
.50411 .15872 Mdot
.62149 .41604 Mdot
.41947 .81831 Mdot
.50477 .87584 Mdot
.45434 .18732 Mdot
.41285 .52879 Mdot
.5829 .14193 Mdot
.58584 .6461 Mdot
.52303 .90448 Mdot
.57703 .13583 Mdot
.40109 .81252 Mdot
.75227 .32787 Mdot
.59725 .33369 Mdot
.60664 .35177 Mdot
.68886 .33472 Mdot
.72921 .49684 Mdot
.40622 .6778 Mdot
.4983 .04459 Mdot
.52691 .8437 Mdot
.48068 .17497 Mdot
.43883 .98624 Mdot
.45209 .93469 Mdot
.54123 .5577 Mdot
.71107 .42336 Mdot
.67076 .28749 Mdot
.46083 .76816 Mdot
.54816 .41799 Mdot
.57302 .44549 Mdot
.66417 .41927 Mdot
.39412 .5161 Mdot
.50537 .63093 Mdot
.4395 .72569 Mdot
.51237 .72254 Mdot
.45244 .93498 Mdot
.46341 .36295 Mdot
.7525 .32858 Mdot
.53754 .2642 Mdot
.42772 .90154 Mdot
.59222 .5896 Mdot
.66549 .5768 Mdot
.43293 .13884 Mdot
.43036 .35088 Mdot
.51699 .17605 Mdot
.71742 .4097 Mdot
.55993 .49091 Mdot
.40985 .62748 Mdot
.40761 .40248 Mdot
.43294 .80118 Mdot
.55029 .4326 Mdot
.6709 .74519 Mdot
.56617 .05203 Mdot
.49303 .73214 Mdot
.42031 .28982 Mdot
.51475 .67775 Mdot
.52538 .00856 Mdot
.41131 .49768 Mdot
.5842 .14977 Mdot
.76055 .34879 Mdot
.42731 .78771 Mdot
.4143 .79246 Mdot
.48303 .85211 Mdot
.72227 .57057 Mdot
.39635 .69958 Mdot
.67231 .51685 Mdot
.46135 .14573 Mdot
.39883 .37833 Mdot
.56144 .64231 Mdot
.49076 .73577 Mdot
.66462 .4278 Mdot
.41951 .63505 Mdot
.44565 .28219 Mdot
.64157 .23405 Mdot
.60527 .7819 Mdot
.78586 .60392 Mdot
.53128 .52685 Mdot
.51233 .21432 Mdot
.68853 .31884 Mdot
.67145 .28327 Mdot
.3902 .24768 Mdot
.63755 .32352 Mdot
.50964 .98846 Mdot
.6226 .30504 Mdot
.50929 .9278 Mdot
.66528 .42786 Mdot
.48413 .24963 Mdot
.58438 .81714 Mdot
.38779 .4088 Mdot
.47291 .71351 Mdot
.56597 .19455 Mdot
.3897 .62186 Mdot
.71572 .62206 Mdot
.62572 .60848 Mdot
.63023 .47757 Mdot
.45969 .94925 Mdot
.37946 .32175 Mdot
.54702 .87521 Mdot
.44486 .73975 Mdot
.72197 .46995 Mdot
.71302 .61528 Mdot
.36313 .6159 Mdot
.42189 .58112 Mdot
.57802 .4993 Mdot
.40316 .64886 Mdot
.58268 .82468 Mdot
.70802 .37403 Mdot
.75702 .71483 Mdot
.54771 .67503 Mdot
.41777 .31005 Mdot
.55155 .94562 Mdot
.50178 .83294 Mdot
.54996 .34261 Mdot
.65741 .38091 Mdot
.51472 .58604 Mdot
.59538 .70144 Mdot
.37252 .48515 Mdot
.43309 .90878 Mdot
.68709 .32004 Mdot
.39802 .19686 Mdot
.37294 .44625 Mdot
.60358 .49329 Mdot
.42813 .90413 Mdot
.69395 .71669 Mdot
.63853 .69157 Mdot
.61826 .41312 Mdot
.42503 .82667 Mdot
.70399 .36308 Mdot
.67186 .55343 Mdot
.56954 .42413 Mdot
.37179 .49683 Mdot
.55856 .85194 Mdot
.46826 .73994 Mdot
.55523 .36719 Mdot
.40938 .61503 Mdot
.53287 .71824 Mdot
.71631 .43461 Mdot
.59974 .68821 Mdot
.52984 .50074 Mdot
.50007 .93516 Mdot
.38023 .67885 Mdot
.71379 .644 Mdot
.54551 .62509 Mdot
.67429 .75006 Mdot
.42589 .48485 Mdot
.63756 .23352 Mdot
.64181 .22839 Mdot
.69881 .70178 Mdot
.62809 .44949 Mdot
.55553 .93612 Mdot
.58335 .82422 Mdot
.54043 .45673 Mdot
.72407 .44407 Mdot
.64602 .81006 Mdot
.72035 .59267 Mdot
.40979 .36712 Mdot
.62777 .11841 Mdot
.43701 .17526 Mdot
.51162 .37226 Mdot
.51652 .39176 Mdot
.49395 .66814 Mdot
.42452 .71764 Mdot
.65428 .15301 Mdot
.40093 .72073 Mdot
.49209 .28709 Mdot
.6184 .63215 Mdot
.43991 .29707 Mdot
.44631 .31296 Mdot
.45124 .23293 Mdot
.59907 .24048 Mdot
.5286 .24605 Mdot
.67143 .55689 Mdot
.55332 .57414 Mdot
.41639 .79685 Mdot
.50775 .21037 Mdot
.69024 .72422 Mdot
.42583 .45957 Mdot
.5458 .80827 Mdot
.72838 .56813 Mdot
.50376 .19971 Mdot
.51439 .06512 Mdot
.67358 .52985 Mdot
.65789 .61892 Mdot
.55608 .51101 Mdot
.4695 .81139 Mdot
.40569 .22876 Mdot
.47724 .74294 Mdot
.71316 .60857 Mdot
.54108 .37726 Mdot
.45829 .64654 Mdot
.65946 .16399 Mdot
.54652 .74616 Mdot
.50117 .23623 Mdot
.53157 .96315 Mdot
.56417 .40199 Mdot
.38708 .60095 Mdot
.62099 .29492 Mdot
.39549 .68344 Mdot
.43761 .98345 Mdot
.63362 .52384 Mdot
.66434 .61794 Mdot
.39423 .5228 Mdot
.6511 .24585 Mdot
.52438 .64305 Mdot
.37389 .54476 Mdot
.47083 .84631 Mdot
.3949 .55032 Mdot
.44814 .93163 Mdot
.65281 .79624 Mdot
.53143 .51587 Mdot
.53925 .45565 Mdot
.37511 .41524 Mdot
.58712 .39071 Mdot
.54979 .35023 Mdot
.61992 .38987 Mdot
.47462 .35198 Mdot
.72618 .48053 Mdot
.54673 .09729 Mdot
.56868 .69691 Mdot
.50002 .23401 Mdot
.65239 .64509 Mdot
.50938 .65123 Mdot
.51 .81757 Mdot
.48108 .8935 Mdot
.41368 .44851 Mdot
.62869 .53745 Mdot
.59012 .79963 Mdot
.59806 .46245 Mdot
.60263 .782 Mdot
.6146 .37576 Mdot
.4515 .75867 Mdot
.58413 .63991 Mdot
.37242 .51765 Mdot
.54017 .64858 Mdot
.51644 .76181 Mdot
.59309 .15792 Mdot
.44113 .25454 Mdot
.6046 .67863 Mdot
.47473 .95138 Mdot
.45984 .70897 Mdot
.53347 .66139 Mdot
.39804 .19803 Mdot
.72491 .54599 Mdot
.55829 .65483 Mdot
.51999 .47833 Mdot
.47456 .80642 Mdot
.63021 .73254 Mdot
.43256 .24084 Mdot
.66765 .54419 Mdot
.48264 .03679 Mdot
.71975 .56443 Mdot
.48849 .04158 Mdot
.44016 .42793 Mdot
.45718 .04004 Mdot
.49658 .99613 Mdot
.64868 .68487 Mdot
.716 .58946 Mdot
.73385 .76948 Mdot
.59277 .60563 Mdot
.63282 .46126 Mdot
.38659 .5739 Mdot
.64998 .24553 Mdot
.68503 .7194 Mdot
.41313 .44802 Mdot
.58884 .1537 Mdot
.59287 .41559 Mdot
.47119 .30334 Mdot
.59424 .23463 Mdot
.39717 .571 Mdot
.62935 .30623 Mdot
.57017 .92235 Mdot
.52759 .56537 Mdot
.52501 .84128 Mdot
.47387 .13887 Mdot
.71563 .44987 Mdot
.50466 .66947 Mdot
.71046 .65408 Mdot
.58338 .8941 Mdot
.36057 .41356 Mdot
.52284 .32378 Mdot
.62552 .61558 Mdot
.52324 .18403 Mdot
.41876 .87128 Mdot
.46318 .81048 Mdot
.49945 .32898 Mdot
.45554 .35132 Mdot
.39488 .46493 Mdot
.73065 .53463 Mdot
.37432 .45324 Mdot
.51811 .66898 Mdot
.57003 .19497 Mdot
.46259 .70844 Mdot
.49149 .67307 Mdot
.41137 .20208 Mdot
.63037 .56936 Mdot
.61888 .41565 Mdot
.60334 .49377 Mdot
.43546 .75728 Mdot
.73555 .28594 Mdot
.59135 .41581 Mdot
.41129 .21362 Mdot
.53993 .563 Mdot
.70603 .38538 Mdot
.4907 .22382 Mdot
.55769 .85914 Mdot
.47477 .09275 Mdot
.44732 .71671 Mdot
.46161 .18658 Mdot
.36432 .63808 Mdot
.72645 .56324 Mdot
.45202 .04318 Mdot
.60382 .77628 Mdot
.59891 .57235 Mdot
.42783 .20385 Mdot
.5686 .83773 Mdot
.52952 .78216 Mdot
.72617 .56207 Mdot
.36298 .35265 Mdot
.66184 .63018 Mdot
.71625 .61659 Mdot
.7074 .66448 Mdot
.67891 .74583 Mdot
.45989 .67841 Mdot
.56327 .70701 Mdot
.71159 .61947 Mdot
.7277 .4858 Mdot
.45086 .6585 Mdot
.66888 .50103 Mdot
.58966 .41716 Mdot
.61803 .63903 Mdot
.42409 .82701 Mdot
.60102 .17347 Mdot
.38806 .61466 Mdot
.42376 .09816 Mdot
.38106 .66119 Mdot
.55796 .1864 Mdot
.42606 .08673 Mdot
.55632 .18107 Mdot
.69096 .69832 Mdot
.77859 .64625 Mdot
.41215 .14024 Mdot
.58819 .72348 Mdot
.51819 .55052 Mdot
.62187 .83994 Mdot
.44405 .82771 Mdot
.44956 .37161 Mdot
.71208 .65503 Mdot
.66552 .42677 Mdot
.49471 .3165 Mdot
.49585 .75718 Mdot
.56273 .31271 Mdot
.51716 .26754 Mdot
.59668 .15966 Mdot
.6756 .54551 Mdot
.71155 .65313 Mdot
.40491 .32727 Mdot
.72083 .26149 Mdot
.41778 .24554 Mdot
.53855 .70513 Mdot
.51644 .75808 Mdot
.5054 .58818 Mdot
.72975 .5224 Mdot
.72486 .56601 Mdot
.50001 .23663 Mdot
.45188 .72392 Mdot
.50811 .2431 Mdot
.55824 .5501 Mdot
.60576 .87307 Mdot
.41236 .33892 Mdot
.64153 .68668 Mdot
.41914 .5046 Mdot
.5533 .35429 Mdot
.49555 .6929 Mdot
.40359 .47388 Mdot
.42342 .22778 Mdot
.52644 .2837 Mdot
.50425 .31313 Mdot
.5308 .96717 Mdot
.72184 .46492 Mdot
.49634 .42032 Mdot
.56837 .26193 Mdot
.39899 .37674 Mdot
.56993 .75722 Mdot
.59478 .44995 Mdot
.56164 .38829 Mdot
.61879 .84713 Mdot
.56082 .04187 Mdot
.3844 .50958 Mdot
.79175 .52916 Mdot
.40473 .75649 Mdot
.52208 .36325 Mdot
.65989 .27653 Mdot
.70844 .63249 Mdot
.45181 .23519 Mdot
.47613 .09398 Mdot
.74037 .29744 Mdot
.44169 .6969 Mdot
.46766 .30182 Mdot
.516 .75451 Mdot
.65511 .6379 Mdot
.59777 .54782 Mdot
.6015 .08895 Mdot
.43205 .38681 Mdot
.57461 .28048 Mdot
.4961 .14631 Mdot
.53048 .62542 Mdot
.52803 .55439 Mdot
.52499 .69409 Mdot
.72935 .48372 Mdot
.51996 .61499 Mdot
.4464 .93538 Mdot
.40142 .25656 Mdot
.50922 .86713 Mdot
.59464 .7985 Mdot
.66781 .50863 Mdot
.39611 .44431 Mdot
.48639 .76974 Mdot
.73059 .54166 Mdot
.65489 .79401 Mdot
.41428 .43952 Mdot
.45606 .04019 Mdot
.59643 .45669 Mdot
.42006 .74889 Mdot
.56189 .85345 Mdot
.41316 .78885 Mdot
.56969 .60079 Mdot
.4647 .18365 Mdot
.43703 .18364 Mdot
.44437 .99677 Mdot
.62796 .47137 Mdot
.45655 .37756 Mdot
.61425 .39014 Mdot
.59125 .60029 Mdot
.46619 .68767 Mdot
.53191 .35323 Mdot
.59338 .32222 Mdot
.63027 .46313 Mdot
.52767 .45124 Mdot
.57683 .35643 Mdot
.67286 .29222 Mdot
.42262 .71468 Mdot
.50301 .87259 Mdot
.57759 .46824 Mdot
.57356 .54662 Mdot
.43241 .54002 Mdot
.78994 .58484 Mdot
.4315 .49545 Mdot
.41913 .17312 Mdot
.52064 .07471 Mdot
.63581 .70118 Mdot
.57565 .46994 Mdot
.52874 .89968 Mdot
.71879 .61844 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`000;;ooooo002T
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`000;;ooooo002Roooo
o`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00Y_ooool2o`0000Cooooo00?o0000ooooooooool0^Oooool009gooooo0_l0
0007ooooo`;o00001?ooool00ol0003oooooooooo`2iooooo`00W?ooool3o`0000Wooooo0_l00002
ooooo`03o`000?oooooooooo017ooooo0_l0002Vooooo`00W?ooool2o`0000[ooooo0_l000000ooo
oooo0000o`00000Cooooo`;o0000Y_ooool00:_ooooo0_l0002kooooo`00[?ooool3o`0001;ooooo
0_l0002Uooooo`00[?ooool00ol0003oooooooooo`0Booooo`;o0000YOooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00Co0000oooooooo
oooooooo0_l0002fooooo`00[?ooool01?l0003oooooooooooooool2o`000;Kooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o00000ooo
ool2o`000;Cooooo002/ooooo`03o`000?oooooooooo00?ooooo0_l0002dooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00Toooool2o`0001Oooooo
00?o0000ooooooooool07_ooool2o`0009Wooooo002Cooooo`;o00005oooool00ol0003ooooooooo
o`0Nooooo`;o0000VOooool00:?ooooo0ol00006ooooo`03o`000?oooooooooo0;Wooooo002Boooo
o`;o00003oooool3o`0000Kooooo00?o0000ooooooooool03?ooool2o`000:_ooooo002Booooo`;o
00006?ooool3o`0000cooooo0_l0002[ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00ROooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B43ooooo`;o000000?oooooo`000?o^k^h01Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool09oooool2o`00093ooooo0029ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@?ooooo0_l000000oooooooEEEEojVYZ@08oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool09oooool2o`00093ooooo0021ooooo`Ko
00000_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0
003oooooooooo`03ooooo`?o0000^Oooool008Wooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2ioooo
o`00ROooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0^Oooool008Wooooo00Go410@oooo
oooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`2iooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@
oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05_oo
ool2o`000:7ooooo0029ooooo`06onk^k_lb<S;o0000oc8b<_o^k^kooooo0_l00004ooooo`;o0000
0_ooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo01Kooooo0_l0002Qooooo`00Sooo
ool2o`0000Cooooo0_l0000<ooooo`;o00001oooool00ol0003oooooooooo`07ooooo`;o00003ooo
ool2o`0009oooooo002Oooooo`;o00002Oooool3o`0000Wooooo0_l0000?ooooo`;o0000Woooool0
09Cooooo0_l00009ooooo`;o00002Oooool3o`0001[ooooo0_l0002Oooooo`00U?ooool2o`0001Ko
oooo0ol0000Hooooo`;o00005Oooool2o`0008Sooooo002/ooooo`03o`000?oooooooooo01[ooooo
0_l0000Cooooo`;o0000R?ooool00:cooooo0ol0000Jooooo`?o0000W?ooool00:cooooo0ol0000K
ooooo`?o0000Voooool00:cooooo00?o0000ooooooooool07?ooool2o`0001?ooooo0_l00026oooo
o`00[?ooool00ol0003oooooooooo`0aooooo`;o0000Q_ooool00:cooooo00?o0000ooooooooool0
^Oooool0097ooooo0_l0000Iooooo`03o`000?oooooooooo01kooooo0_l0002Iooooo`00TOooool2
o`0000Cooooo0_l0000<ooooo`;o00001Oooool3o`0000;ooooo0_l0000Jooooo`;o0000VOooool0
09Oooooo0ol0000;ooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`;o0000]Oooool009So
oooo0_l0000Booooo`03o`000?oooooooooo00oooooo0_l0002Xooooo`00Uoooool2o`0000Oooooo
0_l0000:ooooo`03o`000?oooooooooo00Cooooo0_l00009ooooo`?o0000Yoooool009Oooooo0_l0
0003ooooo`;o000000Coooooo`000?l0003o00002_ooool00ol0003oooooooooo`04ooooo`;o0000
2_ooool2o`000:Oooooo002Looooo`;o000000?oooooo`000?l000002oooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`0Booooo`Co0000Xoooool008[ooooo0_l0000Poooo
o`03o`000?oooooooooo01;ooooo1?l0002Sooooo`00R_ooool2o`00023ooooo0ol0002iooooo`00
R_ooool2o`0000;ooooo0_l00004ooooo`;o00005_ooool3o`0001?ooooo0_l0002Tooooo`00S_oo
ool2o`0000Cooooo0_l0000Fooooo`03o`000?oooooooooo01?ooooo0_l0002Tooooo`00[?ooool0
1?l0003oooooo`000?l0002hooooo`00S_ooool2o`0001cooooo00Co0000ooooool0003o0000^?oo
ool008kooooo0_l0000Looooo`04o`000?ooooooooooooooo`;o0000]_ooool00:cooooo00Co0000
oooooooooooooooo0_l0002fooooo`00[?ooool00ol0003oooooooooo`2iooooo`00Z?ooool2o`00
00;ooooo0ol0002iooooo`00S?ooool2o`0000Cooooo0_l0000Dooooo`;o00000_ooool00ol0003o
ooooooooo`0[ooooo`;o0000S?ooool008cooooo0_l00004ooooo`;o00006?ooool00ol0003ooooo
ooooo`0[ooooo`;o0000S?ooool009_ooooo0_l0000?ooooo`;o00007Oooool2o`0000cooooo0ol0
002<ooooo`00Voooool3o`0000kooooo0_l0000@ooooo`;o00002oooool2o`0000cooooo0ol0002<
ooooo`00UOooool2o`0000Gooooo0_l0000>ooooo`;o00004?ooool2o`0000cooooo0_l0002Joooo
o`00TOooool01?o^k^ko<S8bo`000?lb<S82o`0000Cooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool01?l0003oooooo`000?l0000Looooo`;o00003_ooool2o`0008[ooooo002@
ooooo`;o000000CoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool4o`0000Gooooo0_l0000Uooooo`?o0000ROooool008Oooooo2?l000000ooooooo0000o`000003
ooooo`03oa0@4?oooooooooo00kooooo0_l00004ooooo`?o00001_ooool2o`0002Gooooo0ol00029
ooooo`00Qoooool2o`0000Sooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMol0003o
000000Cooooo0ol0002iooooo`00TOooool01Ol0003ooooooooooooooooo000000;ooooo0_l00008
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2iooooo`00Roooool2
o`0000Cooooo00Go410@oooooooooooooooooa0@4002ooooo`;o00002?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0;Wooooo002;ooooo`;o00001?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00;ooooo0_l00008ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04ooo
ool2o`00033ooooo0_l0001booooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo0_l0
0003ooooo`;o00000oooool4o`0000Kooooo00?o0000ooooooooool02Oooool2o`0000Sooooo0_l0
000`ooooo`;o0000L_ooool009gooooo0_l0000=ooooo`03o`000?oooooooooo00;ooooo0_l00005
ooooo`;o0000[_ooool00:cooooo00?o0000ooooooooool00_ooool2o`000;Gooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`?o0000<Oooool2o`0008Kooooo002/ooooo`03o`000?oo
oooooooo037ooooo0_l00026ooooo`00V_ooool2o`00013ooooo00?o0000ooooooooool05Oooool2
o`0001kooooo0_l00022ooooo`00V_ooool2o`00013ooooo00?o0000ooooooooool01Oooool2o`00
00kooooo0_l0000Nooooo`;o00004oooool2o`0006gooooo002Yooooo`;o000000?oooooo`000?oo
ool01_ooool2o`0002kooooo0_l0000Cooooo`;o0000KOooool0097ooooo0_l0000Fooooo`;o0000
00?oooooo`000?ooool0=_ooool3o`00087ooooo002Aooooo`;o00006Oooool00ol0003ooooooooo
o`0Uooooo`;o00003oooool2o`00087ooooo002Hooooo`;o00004_ooool00ol0003oooooooooo`0U
ooooo`;o00009Oooool2o`0006_ooooo002Hooooo`;o00004_ooool3o`0004cooooo0_l0001[oooo
o`00XOooool3o`0000Sooooo00?o0000ooooooooool0^Oooool00:7ooooo0ol00008ooooo`03o`00
0?oooooooooo02Gooooo1?l0002@ooooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool09Ooo
ool4o`00093ooooo002@ooooo`;o00002?ooool2o`00013ooooo0ol0000Aooooo`;o0000Y_ooool0
09[ooooo0_l0000>ooooo`Go00004Oooool2o`000:Kooooo002Zooooo`?o0000?Oooool2o`0007co
oooo0024ooooo`;o00009_ooool00ol0003oooooooooo`0Kooooo`;o00007Oooool3o`0007cooooo
0024ooooo`;o00009_ooool3o`0000Cooooo0_l0000Eooooo`;o00003Oooool2o`0000kooooo0_l0
001mooooo`00S?ooool2o`0001Oooooo0_l00005ooooo`03o`000?oooooooooo00Cooooo0_l0000T
ooooo`;o00009?ooool2o`0006Oooooo002<ooooo`;o00005oooool2o`0000Cooooo0_l0001Boooo
o`;o0000Ioooool00:_ooooo0_l0000Oooooo`;o00007?ooool2o`0007cooooo002/ooooo`03o`00
0?oooooooooo01gooooo0_l0000Looooo`;o0000O?ooool008oooooo0_l0000Kooooo`03o`000?oo
oooooooo02cooooo0_l0002;ooooo`00Soooool2o`0001_ooooo00?o0000ooooooooool03Oooool2
o`0001gooooo0_l0002;ooooo`00[?ooool00ol0003oooooooooo`0=ooooo`;o0000Z_ooool00:co
oooo00?o0000ooooooooool0Doooool2o`0006Cooooo001nooooo`;o00005Oooool2o`0000Kooooo
0_l00004ooooo`;o00001oooool3o`0000gooooo0_l0000Aooooo`;o0000<Oooool2o`0006Cooooo
001nooooo`;o00005Oooool2o`0000Kooooo0_l00004ooooo`;o00001oooool00ol0003ooooooooo
o`07ooooo`;o00001?ooool3o`00013ooooo0_l0002Gooooo`00[?ooool00ol0003oooooooooo`07
ooooo`;o00001Oooool2o`0000Kooooo0_l0002Qooooo`00[?ooool00ol0003oooooooooo`0Foooo
o`;o00005Oooool2o`0008[ooooo002Oooooo`;o00002oooool00ol0003oooooooooo`04ooooo`;o
00009oooool2o`00017ooooo0_l0001gooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;o
00000oooool2ob4Q8@Cooooo1Ol000001Ooooooo0000o`000?ooooooA4A400;o000000?o<S8bomgM
gOooool01?ooool00ol0003oooooooooo`04ooooo`;o00002Oooool2o`0002oooooo0_l0001goooo
o`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00;o00000oooool2ob4Q8@Cooooo00GoV9RHob4Q
8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool03oooool2
o`000:Sooooo0021ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RH
o`000?l000002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o0000;_ooool2
o`0000oooooo0_l0001fooooo`00ROooool3o`000003ooooool0003ooooo00cooooo0_l000000oo^
k^koooooooooo`05ooooo`03ogMgMolb<S;ooooo00Cooooo1Ol00008ooooo`;o00003Oooool2o`00
00Oooooo0_l0000<ooooo`;o00003oooool2o`0007Kooooo0029ooooo`?o000000?oooooo`000?oo
ool03Oooool00omgMgOo0000o`000003ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0
003oooooooooo`0:ooooo`;o00003Oooool2o`0000Oooooo0_l0002Eooooo`00ROooool01Ol@413o
0000o`000?oooooo410@00oooooo0_l00003ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0<Oooool2o`0008Kooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0a
ooooo`;o00003_ooool2o`0007Kooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01oooool2
o`0000;ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003ooooooooo
o`0Aooooo`;o0000;_ooool2o`0007Kooooo002Eooooo`;o00005Oooool00ol0003oooooooooo`02
ooooo`;o00003Oooool2o`0000Kooooo0_l00007ooooo`Co0000Toooool00:cooooo00?o0000oooo
ooooool00_ooool2o`0001Gooooo0_l00007ooooo`Co0000Toooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo0ol0002iooooo`00SOooool2o`0001gooooo00?o0000ooooooooool04_oo
ool2o`000:Gooooo002=ooooo`;o00007Oooool00ol0003oooooooooo`0Booooo`;o0000YOooool0
08Oooooo0_l0000Sooooo`03o`000?oooooooooo04Cooooo0_l0001cooooo`00O_ooool2o`0000Oo
oooo0_l0000Sooooo`03o`000?oooooooooo02Cooooo0_l0000Nooooo`;o0000Loooool007kooooo
0_l00002ooooo`;o0000:?ooool00ol0003oooooooooo`0Kooooo`;o00001oooool3o`0009;ooooo
0022ooooo`;o0000:?ooool00ol0003oooooooooo`0<ooooo`;o00003?ooool3o`0000Oooooo0ol0
000<ooooo`;o0000Q?ooool00:[ooooo0ol0000>ooooo`;o00003?ooool2o`0001Oooooo0_l00024
ooooo`00Z_ooool5o`0001Cooooo0_l0000Kooooo`;o00003oooool4o`0007?ooooo002Hooooo`;o
00004_ooool00ol0003oooooooooo`0Dooooo`;o00006oooool4o`0000gooooo1?l0001cooooo`00
V?ooool2o`0001;ooooo00?o0000ooooooooool0<oooool2o`0008Cooooo002/ooooo`03o`000?oo
oooooooo00gooooo0_l0000eooooo`;o0000Loooool00:cooooo00?o0000ooooooooool03Oooool2
o`0000Gooooo0_l0000^ooooo`;o0000Loooool008oooooo0_l0000Kooooo`03o`000?oooooooooo
01Cooooo0_l0002Sooooo`00Soooool2o`0001_ooooo00?o0000ooooooooool0^Oooool008;ooooo
0_l00005ooooo`;o00008Oooool00ol0003oooooooooo`0Eooooo`;o0000<?ooool2o`00073ooooo
0022ooooo`;o00001Oooool2o`0000Cooooo0_l0000Kooooo`03o`000?oooooooooo01Gooooo0_l0
0005ooooo`;o00002Oooool2o`0001_ooooo0_l000000ooooooo0000o`00001`ooooo`00Soooool2
o`0001_ooooo0ol00006ooooo`;o00005?ooool2o`0000Wooooo0_l0000Kooooo`;o0000Loooool0
08;ooooo0_l0000Xooooo`03o`000?oooooooooo00Kooooo0_l00002ooooo`;o0000[Oooool008;o
oooo0_l0000:ooooo`;o00007?ooool00ol0003oooooooooo`0:ooooo`;o00004?ooool2o`0009_o
oooo0009ooooo`Co000000?o410@ooooooooool05_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0?oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol000001Ooooooo0000
o`000?ooooooA4A400?o000000?ogMgMooooooooool05?ooool00ol0003oooooooooo`0:ooooo`;o
00003?ooool01?o^k^ko<S8bo`000?lb<S82o`0000Cooooo0_lQ8B44ooooo`Go00001?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Ooo
ool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd06?ooool4o`00
0003oa0@4?oooooooooo01;ooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHo`000?l0003ooooo
odA4A006ooooo`;o000000?o<S8booooooooool05?ooool00ol0003oooooooooo`0?ooooo`;o0000
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg00;o00000oooool2ob4Q8@Cooooo0_l000000oo^k^ko
ooooodA4A007ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgo`000?l0003oV9RHogMgM`05oooo
o`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`0Iooooo`03o`000?oooooo
oooo01Cooooo0006o`0000Gooooo00?o0000ooooooooool04?ooool6o`0000;ooooo00Go410@oooo
oooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool01Oooool6
o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00Gooooo1_l0
0002ooooo`05oa0@4?ooooooooooooooool@41003?ooool2o`000003onk^k_oooooooooo00Oooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0?ooooo`;o00001oooool01Ol@413ooooo
oooooooooooo410@00;o00002Oooool2o`000003ob4Q8Oo^k^kooooo00Sooooo00?o0000oooooooo
ool03Oooool01Ol@413o0000o`000?oooooo410@013ooooo00?o0000ooooooooool03Oooool01Ol@
413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool03_ooool0
1Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`0Eooooo`03o`00
0?oooooooooo01Kooooo0ol00003ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`0>ooooo`?o000000?oooooo`000?ooool03_ooool00omgMgOo<S8b
ooooo`0>ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03
ogMgMolb<S;ooooo01Wooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool0
6?ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgo`000?l00000
0oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Kooooo00?o0000ooooooooool05_ooool3o`0000?o
oooo00?o0000ooooooooool02?ooool2o`0000;ooooo00?oMgMgofIVI_ooool00oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00oooooo0ol000000ooooooo0000ooooo`0;ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<01[ooooo00?o0000ooooooooool05?ooool000_ooooo00?o
0000ooooooooool06?ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool0
0oooool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003o
ooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003oooool2o`0000?ooooo00?o0000oooo
ooooool06?ooool3o`0001Sooooo00Go410@oooooooooooooooooa0@400:ooooo`;o00000oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVY
ZOmgMgOooooo00?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Dooooo`002ooo
ool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooo
oooooooooooo<S8b00Cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000
okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00ooo
ool2o`0001?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`;o000000?ooooooiRHV?l@4100
1?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003o
ooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo
<S8b00Cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Dooooo`002Oooool00omE
EEGoIVIVo`00000Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000@
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0001Oooooo00?o0000oooooooo
ool00oooool2o`0001?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`?o000000?o8B4Qolc<
c?ooool00oooool4o`00013ooooo00?ok^k^oc8b<_l000000_l0000<ooooo`Co00004?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00006Oooool00omEEEGoIVIVo`00000F
ooooo`00POooool2o`00013ooooo0_l0000Gooooo`03o`000?oooooooooo04Oooooo0ol0001_oooo
o`00POooool2o`00013ooooo0_l0000Gooooo`03o`000?oooooooooo04Sooooo0_l0001_ooooo`00
[?ooool00ol0003oooooooooo`0@ooooo`;o0000W?ooool2o`0000;ooooo0_l00005ooooo`00UOoo
ool2o`0001Gooooo00?o0000ooooooooool04?ooool2o`0000gooooo0_l0002=ooooo`06onk^k_lQ
8B7oQhN7okZj^_l0003ogMgM1Oooool0087ooooo0_l0000;ooooo`;o00001Oooool2o`0001Gooooo
00?o0000ooooooooool07oooool2o`0002Oooooo0_l0001Uooooo`04omgMgOl0003o410@olc<c0Ko
oooo0007oooooooo0000C?l0000<ooooo`04onk^k_lQ8B7o410@onk^kPKooooo0007ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`;o0000
1_ooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00_ooool2o`000003ooooool0003ooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool02_ooool01?lQ8B7oMgMgogMgMolb<S86ooooo`001oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0;ooooo`;o00006Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Wooooo
0_l00002ooooo`;o00001Oooool008Gooooo0_l0000:ooooo`;o00006Oooool00ol0003ooooooooo
o`0dooooo`;o0000Poooool008Gooooo0_l0000Uooooo`03o`000?oooooooooo00oooooo0_l0000S
ooooo`;o0000Poooool008Wooooo0_l0000Qooooo`03o`000?oooooooooo00Oooooo0_l00006oooo
o`;o0000Z?ooool0087ooooo0_l00006ooooo`;o00008Oooool00ol0003oooooooooo`07ooooo`;o
0000;?ooool2o`0008;ooooo0021ooooo`;o0000:Oooool00ol0003oooooooooo`0eooooo`;o0000
4Oooool2o`0006oooooo0029ooooo`;o00008Oooool3o`0002Wooooo0_l0000Mooooo`;o0000Kooo
ool008Wooooo0_l0000Qooooo`03o`000?oooooooooo00Oooooo0_l0000Pooooo`;o0000S_ooool0
08oooooo0_l0000Kooooo`03o`000?oooooooooo00Oooooo0_l0000]ooooo`;o00009Oooool2o`00
05[ooooo002?ooooo`;o00006oooool00ol0003oooooooooo`0fooooo`;o00004Oooool2o`0001;o
oooo0_l0001Jooooo`00[?ooool00ol0003oooooooooo`0Wooooo`;o00008?ooool2o`0006kooooo
002Eooooo`;o00005Oooool00ol0003oooooooooo`0Wooooo`;o0000T?ooool009Gooooo0_l0000E
ooooo`03o`000?oooooooooo04Wooooo0_l0001^ooooo`00P_ooool2o`0002Sooooo00?o0000oooo
ooooool05Oooool2o`0001gooooo0_l000000ooooooo0000o`00000>ooooo`Co0000K_ooool008;o
oooo0_l0000Xooooo`03o`000?oooooooooo01Gooooo0_l00006ooooo`;o00005Oooool2o`000003
ooooool0003o000000kooooo0_l0001`ooooo`00ROooool2o`00027ooooo0ol00003ooooo`;o0000
2oooool2o`0000_ooooo0_l0002Jooooo`00ROooool2o`00027ooooo00?o0000ooooooooool00ooo
ool2o`000003ooooool0003o000000Sooooo0_l0000Sooooo`;o0000P_ooool00:cooooo00?o0000
ooooooooool01_ooool2o`0000;ooooo0_l0000Yooooo`;o0000P_ooool00:cooooo00?o0000oooo
ooooool02_ooool2o`0002Wooooo0_l0000@ooooo`;o0000L?ooool00:cooooo00?o0000oooooooo
ool02_ooool2o`0003Wooooo1?l0001`ooooo`00[?ooool00ol0003oooooooooo`06ooooo`;o0000
0_ooool2o`0003Wooooo1Ol0001_ooooo`00R_ooool2o`00023ooooo00?o0000ooooooooool01_oo
ool2o`00023ooooo0_l0000Looooo`Co0000Koooool008Kooooo0_l00002ooooo`;o00008?ooool0
0ol0003oooooooooo`0>ooooo`;o00001Oooool2o`0000Kooooo0_l00009ooooo`;o00007?ooool3
o`00073ooooo0026ooooo`;o00009?ooool3o`0000kooooo0_l00005ooooo`;o00001_ooool2o`00
01Cooooo0_l0000Booooo`;o0000L?ooool00:cooooo00?o0000ooooooooool0<oooool2o`0008Co
oooo002Booooo`;o00006?ooool00ol0003oooooooooo`2iooooo`00T_ooool2o`0001Sooooo00Co
0000oooooooooooooooo0_l0001Iooooo`;o0000Foooool00:cooooo0ol000000ooooooo0000o`00
001Iooooo`;o0000Foooool00:cooooo0ol0000Kooooo`;o00002_ooool2o`0001_ooooo0_l0001c
ooooo`00[?ooool00ol0003oooooooooo`0Kooooo`;o00002_ooool2o`0001_ooooo0ol0001boooo
o`00[?ooool00ol0003oooooooooo`15ooooo`;o0000L_ooool008Kooooo0_l0000Tooooo`?o0000
5?ooool2o`0000Gooooo0_l0000Yooooo`;o0000LOooool008Kooooo0_l0000Tooooo`03o`000?oo
oooooooo01Cooooo0_l00005ooooo`;o00009_ooool2o`000003ooooool0003o000001?ooooo0_l0
001Looooo`00[?ooool00ol0003oooooooooo`0Kooooo`;o00009_ooool2o`0001Kooooo0_l0001L
ooooo`00[?ooool00ol0003oooooooooo`0Kooooo`;o00002Oooool2o`0001_ooooo0_l0001doooo
o`00[?ooool00ol0003oooooooooo`0Vooooo`;o00006oooool2o`0007Cooooo001nooooo`;o0000
1oooool2o`0000Gooooo0_l0000Looooo`03o`000?oooooooooo00?ooooo0_l0000Qooooo`;o0000
6oooool3o`0007?ooooo001nooooo`;o00001oooool2o`000005onk^k_lb<S;o0000oc8b<_o^k^h0
0_l00003ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo00?ooooo0_l0000Qooooo`;o00002Oooool4o`0000gooooo1Ol0001booooo`00
Qoooool2o`000005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0<Oooool4o`00
00gooooo1Ol0001booooo`00Qoooool2o`000005oa0@4?ooooooooooooooool@41003?ooool00onH
V9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol00007ooooo`;o00000oooool2o`00
03Kooooo0_l0001cooooo`00ROooool01?l0003oooooooooooooool3o`0000_ooooo00?oV9RHob4Q
8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00Oooooo0_l00003oooo
o`;o0000Zoooool008Wooooo00Co0000oooooooooooooooo0ol0000<ooooo`03ogMgMomVIVKooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`?o0000<_ooool2o`0008Gooooo0029oooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Oooooo0ol0000Tooooo`;o00003?ooool2o`0000gooooo0_l0001fooooo`00ROooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo0_l00006ooooo`05o`000?nj^[[ooooooiRHV?l@41001?oo
ool01?l0003oooooo`000?l00006ooooo`03o`000?oooooooooo02Cooooo0_l0000Kooooo`;o0000
M_ooool007oooooo0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool2o`0000Kooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`0Hooooo`;o
00002_ooool2o`0000[ooooo0_l00027ooooo`00Ooooool2o`0002_ooooo00?o0000ooooooooool0
1Oooool2o`0000[ooooo0_l00005ooooo`;o00002_ooool2o`0000[ooooo0_l00027ooooo`00W_oo
ool2o`0000cooooo00?o0000ooooooooool01Oooool2o`0000[ooooo0_l00006ooooo`;o00005?oo
ool2o`0001;ooooo0_l0000Dooooo`;o0000G_ooool008cooooo0_l0000@ooooo`;o00003?ooool0
0ol0003oooooooooo`0:ooooo`;o00003Oooool2o`0001Cooooo0_l0000Booooo`;o00005?ooool2
o`0005kooooo002<ooooo`;o00007_ooool5o`0000Sooooo0_l0002]ooooo`00S?ooool2o`0001ko
oooo00?o0000ooooooooool00_l0000>ooooo`;o0000<?ooool3o`0007Cooooo002Kooooo`;o0000
3oooool00ol0003oooooooooo`0@ooooo`;o0000<?ooool3o`0007Cooooo0024ooooo`;o00005Ooo
ool2o`0000oooooo00?o0000ooooooooool02?ooool2o`000:oooooo0024ooooo`;o00009_ooool0
0ol0003oooooooooo`08ooooo`;o0000=oooool2o`0007Kooooo002/ooooo`03o`000?oooooooooo
047ooooo0_l0001fooooo`00Z_ooool5o`0000?ooooo0_l0002dooooo`00ZOooool6o`0000?ooooo
0_l0002dooooo`00ZOooool2o`000004ooooool0003o0000o`0000cooooo0_l0002[ooooo`00Q?oo
ool2o`0000Oooooo0_l000000ooooooo0000o`00000<ooooo`;o00003?ooool01?l0003ooooooooo
ooooool2o`0000Wooooo0_l0000Aooooo`;o0000V?ooool008Cooooo0_l00007ooooo`;o000000?o
ooooo`000?l000003?ooool2o`0000cooooo00Co0000oooooooooooooooo0_l0000Looooo`;o0000
V?ooool008Wooooo0_l0000Qooooo`03o`000?oooooooooo02kooooo0_l00029ooooo`00ROooool2
o`0001Gooooo0_l0000:ooooo`03o`000?oooooooooo01gooooo0_l0000<ooooo`;o000000?ooooo
o`000?l00000ROooool00:3ooooo0_l0000:ooooo`03o`000?oooooooooo01gooooo0_l0000;oooo
o`?o0000S?ooool00:[ooooo0ol00007ooooo`;o00008oooool2o`0008gooooo002Hooooo`;o0000
4?ooool3o`0000Oooooo0_l0000<ooooo`;o00009oooool2o`0007_ooooo0029ooooo`;o00003Ooo
ool2o`0001;ooooo0ol0000Cooooo`;o00001oooool2o`0000_ooooo0_l0000Aooooo`;o0000Nooo
ool008Wooooo0_l0000Qooooo`03o`000?oooooooooo01cooooo0_l0000;ooooo`;o00004oooool2
o`0007Wooooo002/ooooo`03o`000?oooooooooo00Wooooo0_l00006ooooo`;o0000:oooool2o`00
07Wooooo002Nooooo`?o00002oooool00ol0003oooooooooo`09ooooo`;o00001_ooool2o`000:Ko
oooo002Nooooo`?o00000_ooool2o`0000Oooooo00?o0000ooooooooool0^Oooool009;ooooo0_l0
000?ooooo`;o00001oooool00ol0003oooooooooo`1Aooooo`;o0000I_ooool009;ooooo0ol00005
ooooo`;o00004?ooool00ol0003oooooooooo`07ooooo`;o0000<Oooool2o`000003ooooool0003o
000001;ooooo0_l0001Vooooo`00Roooool2o`0000Kooooo0_l00005ooooo`;o00004?ooool01?l0
003oooooooooooooool2o`0000Cooooo0_l0000aooooo`;o000000?oooooo`000?l00000N_ooool0
08_ooooo0_l0000?ooooo`;o00003_ooool3o`000003ooooool0003o000001Oooooo0_l0000Ooooo
o`;o0000O?ooool009Sooooo0_l00002ooooo`;o00003_ooool00ol0003oooooooooo`0Jooooo`;o
00007oooool2o`0007cooooo002Hooooo`;o00004_ooool00ol0003oooooooooo`2iooooo`00ZOoo
ool2o`000003ooooool0003ooooo02Wooooo0_l0000>ooooo`;o0000Ooooool00:Wooooo0_l00000
0ooooooo0000ooooo`0Yooooo`;o00003Oooool3o`0007oooooo002Iooooo`;o00001_ooool2o`00
00Kooooo0_l000000ooooooo0000ooooo`0hooooo`;o0000P?ooool0097ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`;o00000_lQ8B44ooooo`Go000000?ogMgMooooooooool00oooool00ol0
003oooooooooo`2iooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`;o000000?o<S8booooooooool00oooool00ol0003oooooooooo`0<ooooo`;o00009oooool2o`00
0003ooooool0003o000007oooooo002Aooooo`;o00000_ooool00ol@413oooooooooo`0>ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool2o`0002Oooooo0_l000000ooooooo
0000o`00001oooooo`00TOooool2o`0000;ooooo00?o0000ooooooooool00oooool2o`0000Sooooo
00?oMgMgoc8b<_ooool01?ooool3o`0003Kooooo0_l00021ooooo`00TOooool01Ol0003ooooooooo
oooooooo000000Gooooo0_l00005ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003o
ooooooooo`02ooooo`;o0000<_ooool2o`00087ooooo002<ooooo`;o00000oooool01Ol@413ooooo
oooooooooooo410@00;o00001?ooool2o`0000Cooooo00?o0000ooooooooool01Oooool3o`0000Co
oooo0_l0000@ooooo`;o00003?ooool2o`0009Gooooo002<ooooo`;o00000oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00;o00001?ooool2o`0000Cooooo00?o0000ooooooooool01Oooool3o`0000Co
oooo0_l0000@ooooo`;o00003?ooool2o`0009Gooooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03?ooool4o`0000Kooooo00?o0000ooooooooool00_ooool2o`000;Gooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002Oooooo`;o00001_ooool2o`0000?ooooo00?o0000ooooooooool0B_oo
ool2o`0006gooooo002Oooooo`;o00001_ooool2o`0000?ooooo00?o0000ooooooooool0B_ooool2
o`0006gooooo002/ooooo`?o00007oooool2o`0009Sooooo002/ooooo`03o`000?oooooooooo01oo
oooo0_l0002Hooooo`00[?ooool00ol0003oooooooooo`06ooooo`;o00005_ooool3o`0009Sooooo
002/ooooo`03o`000?oooooooooo00Kooooo0_l0000Fooooo`?o0000V?ooool008oooooo0_l00003
ooooo`;o00005_ooool00ol0003oooooooooo`2iooooo`00Soooool2o`0000?ooooo0_l0000Foooo
o`03o`000?oooooooooo0;Wooooo002?ooooo`;o00006oooool00ol0003oooooooooo`0`ooooo`;o
0000Qoooool008oooooo0ol0000Jooooo`03o`000?oooooooooo02oooooo0ol00027ooooo`00T?oo
ool2o`0000?ooooo0_l0000Eooooo`?o00006_ooool4o`00017ooooo0_l00028ooooo`00UOooool2
o`0001Gooooo00?o0000ooooooooool06_ooool4o`0009_ooooo002Sooooo`;o00001oooool00ol0
003oooooooooo`2iooooo`00Woooool2o`0000;ooooo0_l00007ooooo`03o`000?oooooooooo00co
oooo0_l0000Oooooo`;o0000R_ooool008_ooooo0_l0000Booooo`Co00002Oooool00ol0003ooooo
ooooo`0<ooooo`;o00007oooool2o`0008[ooooo002;ooooo`;o00005?ooool2o`0000Wooooo00?o
0000ooooooooool0^Oooool0097ooooo0_l0000Iooooo`03o`000?oooooooooo00;o00005_ooool2
o`0009oooooo002Aooooo`;o00006Oooool00ol0003oooooooooo`02o`0001Kooooo0_l0002Ooooo
o`00[?ooool3o`0001Sooooo0_l0002Oooooo`00Toooool2o`0000Cooooo0_l0000Aooooo`03o`00
0?oooooooooo01Sooooo0_l0002Oooooo`00Toooool2o`0000Cooooo0_l0000Aooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`;o0000^_ooool00:cooooo0_l0000Dooooo`;o0000Y?ooool00:co
oooo00?o0000ooooooooool04oooool2o`00013ooooo0_l0002Booooo`00[?ooool00ol0003ooooo
ooooo`05ooooo`;o00007_ooool2o`0009;ooooo002Rooooo`;o00002?ooool00ol0003ooooooooo
o`05ooooo`;o0000/_ooool00:;ooooo0_l00008ooooo`03o`000?oooooooooo02Cooooo0_l0002C
ooooo`00Y_ooool2o`0000Cooooo0ol0000@ooooo`;o00004_ooool2o`0009?ooooo002Vooooo`;o
00001?ooool00ol0003oooooooooo`0@ooooo`?o0000Y_ooool00:cooooo00?o0000ooooooooool0
4Oooool2o`000:Kooooo002/ooooo`03o`000?oooooooooo013ooooo0_l0002Wooooo`00[?ooool0
0ol0003oooooooooo`0@ooooo`;o0000Yoooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`02o`0000kooooo0_l0002Wooooo`00ROooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`02o`000;Oooooo0029ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool2o`0000Sooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o00007ooo
ool2o`0009Sooooo0029ooooo`05o`000?ooooooooooooooool000000oooool2o`0000Wooooo00?o
8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`?o00003?ooool2o`00017ooooo0_l0
002Hooooo`00ROooool01Ol0003ooooooooooooooooo000000cooooo0_l000000omEEEGoc<c<oooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool3o`0000cooooo0_l0002[ooooo`00ROoo
ool01Ol@413ooooooooooooooooo410@00cooooo0_l000000onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0^Oooool008Wooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0;Wooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Co
oooo1?l00006ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002Uooooo`;o00001Oooool00ol0003oooooooooo`0Hooooo`;o0000Woooool00:Gooooo0_l00005
ooooo`03o`000?oooooooooo01Sooooo0_l0002Oooooo`00[?ooool3o`0000Kooooo0_l0002aoooo
o`00U?ooool2o`0001Kooooo00?o0000ooooooooool01_ooool2o`000;7ooooo002Dooooo`;o0000
5_ooool00ol0003oooooooooo`04ooooo`;o0000/oooool009Gooooo0_l0000Eooooo`03o`000?oo
oooooooo00Cooooo0_l0002cooooo`00UOooool2o`0001Gooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool00_ooool2o`000;Gooooo002/ooooo`03o`000?oooooooooo00;o
oooo0_l0002eooooo`00[?ooool00ol0003oooooooooo`0Dooooo`;o0000Xoooool00:cooooo0ol0
000Dooooo`;o0000Xoooool00:cooooo00?o0000ooooooooool00_l0002gooooo`00V_ooool2o`00
013ooooo00?o0000ooooooooool00_l0002gooooo`00V_ooool4o`0000kooooo00?o0000oooooooo
ool0^Oooool009[ooooo1?l0000>ooooo`;o00004?ooool2o`000:Sooooo002Jooooo`Co00003_oo
ool2o`00013ooooo0_l0002Xooooo`00[?ooool00ol0003oooooooooo`2iooooo`00X?ooool2o`00
00[ooooo00?o0000ooooooooool03_ooool2o`000:Wooooo002Nooooo`Co00002_ooool00ol0003o
ooooooooo`0>ooooo`;o0000ZOooool009kooooo0_l00003ooooo`;o00001oooool3o`000;Wooooo
002Sooooo`;o00001oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`07ooooo`;o
0000/?ooool00:cooooo00?o0000ooooooooool01oooool2o`000;3ooooo002/ooooo`03o`000?oo
oooooooo00Oooooo0_l0002`ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`00
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002Gooooo`;o00004oooool00ol0003oooooooooo`2iooooo`00Uoooool2o`0001?ooooo00?o0000
ooooooooool00_l0002gooooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool00_l0002goooo
o`00X_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0^Oooool009Wooooo
0_l00009ooooo`03o`000?oooooooooo00?ooooo0ol0002kooooo`00VOooool2o`0000Wooooo00?o
0000ooooooooool00oooool5o`000;Wooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Toooo
o`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`00
0?oooooooooo0<7ooooo002Rooooo`03oeEEEOmVIVKo00000<?ooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo002Zooooo`04oa0@4?l0003o0000o`000;[ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`06o`000?mgMgOo0000o`000?mEEEGok^k^]oooool00:_ooooo00Ko0000oeEEEOo^k^koooooogMg
MomEEEFgooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo0;Gooooo002[
ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0]Oooool00:_ooooo00Ko0000oeEE
EOo^k^koooooogMgMomVIVJgooooo`00Z_ooool00ol@413o0000ogMgM`02o`000003ofIVI_o^k^ko
oooo0;Kooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.58415 .74824 Mdot
.40838 .78296 Mdot
.50559 .4793 Mdot
.42733 .636 Mdot
.52784 .74536 Mdot
.6231 .39 Mdot
.43638 .51608 Mdot
.68222 .28156 Mdot
.50538 .04664 Mdot
.54216 .6499 Mdot
.43004 .70217 Mdot
.71327 .37183 Mdot
.52878 .12467 Mdot
.47934 .78495 Mdot
.71538 .40446 Mdot
.50228 .26516 Mdot
.52416 .79726 Mdot
.54132 .14071 Mdot
.56362 .37293 Mdot
.6633 .66472 Mdot
.5513 .16007 Mdot
.39037 .33375 Mdot
.42033 .16851 Mdot
.56417 .17399 Mdot
.73041 .53533 Mdot
.49505 .17565 Mdot
.41327 .42411 Mdot
.55377 .34602 Mdot
.64404 .71633 Mdot
.39885 .72631 Mdot
.58895 .22347 Mdot
.50305 .04147 Mdot
.64693 .22444 Mdot
.4123 .72258 Mdot
.4234 .21125 Mdot
.6755 .55726 Mdot
.42665 .90596 Mdot
.50521 .23736 Mdot
.61303 .77406 Mdot
.7232 .39863 Mdot
.73481 .53331 Mdot
.39431 .44663 Mdot
.54791 .21604 Mdot
.56442 .79337 Mdot
.61511 .67584 Mdot
.41121 .65785 Mdot
.49473 .76513 Mdot
.41158 .1216 Mdot
.60427 .4461 Mdot
.64482 .70448 Mdot
.4062 .14296 Mdot
.56508 .85962 Mdot
.64342 .12787 Mdot
.49075 .13606 Mdot
.50735 .15177 Mdot
.58275 .13472 Mdot
.68795 .29684 Mdot
.5296 .79003 Mdot
.37054 .49679 Mdot
.62439 .6437 Mdot
.40281 .54551 Mdot
.62007 .86058 Mdot
.60484 .78655 Mdot
.52431 .3577 Mdot
.64042 .22336 Mdot
.54576 .08749 Mdot
.54792 .62451 Mdot
.47606 .24046 Mdot
.51121 .24549 Mdot
.59188 .21927 Mdot
.49601 .84965 Mdot
.51775 .43093 Mdot
.5356 .66745 Mdot
.56139 .52254 Mdot
.60504 .78608 Mdot
.44759 .58027 Mdot
.64393 .12858 Mdot
.42201 .27755 Mdot
.58986 .82185 Mdot
.58806 .3896 Mdot
.65621 .3768 Mdot
.40526 .76183 Mdot
.4521 .72716 Mdot
.39711 .3855 Mdot
.6413 .2097 Mdot
.51629 .29091 Mdot
.51714 .76741 Mdot
.46829 .81533 Mdot
.55824 .73526 Mdot
.48357 .24335 Mdot
.72898 .54519 Mdot
.37804 .19779 Mdot
.54672 .53427 Mdot
.44095 .78424 Mdot
.54585 .47775 Mdot
.35966 .38451 Mdot
.48827 .77857 Mdot
.41481 .11673 Mdot
.66006 .14879 Mdot
.55472 .74705 Mdot
.55765 .79843 Mdot
.58705 .66037 Mdot
.71049 .37057 Mdot
.53688 .83788 Mdot
.63905 .31685 Mdot
.40061 .63625 Mdot
.46492 .8589 Mdot
.57837 .44231 Mdot
.5465 .53947 Mdot
.59574 .2278 Mdot
.51677 .72487 Mdot
.4338 .67527 Mdot
.49519 .03455 Mdot
.67803 .5819 Mdot
.78743 .40392 Mdot
.50202 .32685 Mdot
.4057 .39799 Mdot
.57607 .11884 Mdot
.54476 .08327 Mdot
.43826 .92485 Mdot
.52696 .12352 Mdot
.66502 .78846 Mdot
.50462 .10504 Mdot
.64041 .7278 Mdot
.59642 .22786 Mdot
.41837 .5143 Mdot
.67123 .61714 Mdot
.3636 .66801 Mdot
.47396 .90052 Mdot
.53081 .54859 Mdot
.41686 .17726 Mdot
.52026 .85721 Mdot
.72454 .42206 Mdot
.62911 .40848 Mdot
.58126 .27757 Mdot
.61269 .78517 Mdot
.45675 .9557 Mdot
.65711 .67521 Mdot
.53901 .65535 Mdot
.66995 .26995 Mdot
.71914 .41528 Mdot
.52472 .97595 Mdot
.5042 .71514 Mdot
.53774 .2993 Mdot
.52348 .79902 Mdot
.67255 .62468 Mdot
.61763 .17403 Mdot
.80295 .51483 Mdot
.57772 .47503 Mdot
.44591 .79099 Mdot
.68979 .74562 Mdot
.59496 .63294 Mdot
.45154 .22392 Mdot
.56977 .18091 Mdot
.50913 .38604 Mdot
.63596 .50144 Mdot
.49393 .95065 Mdot
.59255 .81173 Mdot
.5751 .12004 Mdot
.42547 .90168 Mdot
.48535 .95726 Mdot
.56089 .29329 Mdot
.59072 .82256 Mdot
.74062 .51669 Mdot
.67516 .49157 Mdot
.54351 .21312 Mdot
.56644 .77879 Mdot
.60922 .16308 Mdot
.65324 .35343 Mdot
.49919 .22415 Mdot
.49664 .95134 Mdot
.65934 .65194 Mdot
.53923 .58213 Mdot
.46397 .21201 Mdot
.51444 .76911 Mdot
.58017 .51824 Mdot
.65016 .23461 Mdot
.35721 .4741 Mdot
.63502 .48821 Mdot
.49022 .30582 Mdot
.63413 .73516 Mdot
.53538 .90464 Mdot
.73139 .444 Mdot
.55555 .42509 Mdot
.73431 .55006 Mdot
.48232 .71769 Mdot
.49098 .03528 Mdot
.36585 .69117 Mdot
.49317 .02938 Mdot
.73952 .50178 Mdot
.56788 .24949 Mdot
.68998 .73612 Mdot
.67304 .62422 Mdot
.48343 .26895 Mdot
.63751 .83037 Mdot
.6617 .24407 Mdot
.73005 .61006 Mdot
.71741 .39267 Mdot
.4601 .81349 Mdot
.41232 .73612 Mdot
.44131 .36681 Mdot
.44708 .34141 Mdot
.52208 .47038 Mdot
.53584 .72359 Mdot
.54112 .82375 Mdot
.42482 .47142 Mdot
.63126 .43215 Mdot
.43829 .69712 Mdot
.44037 .66572 Mdot
.42184 .66152 Mdot
.45678 .08493 Mdot
.41465 .31901 Mdot
.65418 .35689 Mdot
.54298 .37414 Mdot
.55861 .79276 Mdot
.40513 .4193 Mdot
.73993 .52422 Mdot
.47681 .72341 Mdot
.62911 .60827 Mdot
.71564 .36813 Mdot
.40332 .43932 Mdot
.37257 .42132 Mdot
.64552 .32985 Mdot
.66545 .41892 Mdot
.52048 .31101 Mdot
.56507 .64139 Mdot
.43078 .86131 Mdot
.54243 .56472 Mdot
.71659 .40857 Mdot
.65614 .80754 Mdot
.45621 .25184 Mdot
.51132 .55694 Mdot
.60499 .54616 Mdot
.41176 .44278 Mdot
.67683 .76315 Mdot
.4851 .20977 Mdot
.51616 .86894 Mdot
.49895 .09495 Mdot
.53321 .83822 Mdot
.61883 .86105 Mdot
.60315 .32384 Mdot
.67152 .41794 Mdot
.49745 .84773 Mdot
.50944 .04585 Mdot
.5416 .44305 Mdot
.50665 .93281 Mdot
.57854 .671 Mdot
.50332 .83918 Mdot
.60273 .7924 Mdot
.7313 .59624 Mdot
.49778 .31614 Mdot
.48191 .27029 Mdot
.47811 .95449 Mdot
.50341 .19071 Mdot
.45388 .22468 Mdot
.53586 .18987 Mdot
.44277 .53367 Mdot
.6784 .28053 Mdot
.38307 .27115 Mdot
.60744 .49691 Mdot
.41152 .44831 Mdot
.67042 .44509 Mdot
.52987 .45123 Mdot
.59703 .61757 Mdot
.602 .70268 Mdot
.47703 .77889 Mdot
.60367 .33745 Mdot
.66997 .59963 Mdot
.54304 .26245 Mdot
.67543 .582 Mdot
.52491 .17576 Mdot
.54442 .64506 Mdot
.6001 .43991 Mdot
.50104 .94409 Mdot
.5596 .44858 Mdot
.58117 .56181 Mdot
.42355 .08808 Mdot
.42874 .701 Mdot
.63605 .47863 Mdot
.6207 .7656 Mdot
.52873 .58388 Mdot
.55803 .46139 Mdot
.42573 .90135 Mdot
.70331 .34599 Mdot
.58022 .45483 Mdot
.47338 .3186 Mdot
.56507 .62778 Mdot
.68322 .53254 Mdot
.42761 .74139 Mdot
.64533 .34419 Mdot
.3661 .69208 Mdot
.37222 .56687 Mdot
.70552 .36443 Mdot
.372 .54029 Mdot
.4668 .66773 Mdot
.37844 .67734 Mdot
.65513 .79636 Mdot
.68263 .48487 Mdot
.71178 .38946 Mdot
.80164 .56948 Mdot
.59502 .40563 Mdot
.57732 .26126 Mdot
.51028 .87281 Mdot
.5082 .04553 Mdot
.73279 .5194 Mdot
.47704 .78139 Mdot
.41917 .10136 Mdot
.5191 .21559 Mdot
.43289 .55919 Mdot
.45043 .09368 Mdot
.50735 .82612 Mdot
.51184 .10623 Mdot
.6991 .72235 Mdot
.51374 .36537 Mdot
.62152 .64128 Mdot
.3964 .58305 Mdot
.65558 .24987 Mdot
.53245 .46947 Mdot
.73209 .45408 Mdot
.70102 .6941 Mdot
.4321 .328 Mdot
.63175 .41558 Mdot
.39924 .35585 Mdot
.58035 .82904 Mdot
.56302 .65387 Mdot
.43237 .43025 Mdot
.44675 .61714 Mdot
.48468 .8574 Mdot
.7045 .33463 Mdot
.48657 .94972 Mdot
.5457 .46898 Mdot
.41941 .16268 Mdot
.52848 .57446 Mdot
.52238 .47741 Mdot
.42373 .84227 Mdot
.61811 .36936 Mdot
.54514 .21565 Mdot
.56085 .29377 Mdot
.54506 .69975 Mdot
.60993 .08594 Mdot
.51767 .21581 Mdot
.42626 .84013 Mdot
.52513 .363 Mdot
.62018 .18538 Mdot
.41131 .49122 Mdot
.66135 .65914 Mdot
.38614 .58911 Mdot
.53208 .63309 Mdot
.40947 .62626 Mdot
.52945 .9713 Mdot
.71175 .36324 Mdot
.38024 .69916 Mdot
.67433 .57628 Mdot
.58785 .37235 Mdot
.42055 .77005 Mdot
.66369 .63773 Mdot
.60238 .58216 Mdot
.711 .36207 Mdot
.67391 .43018 Mdot
.72289 .41659 Mdot
.73319 .46448 Mdot
.73724 .54583 Mdot
.51966 .56508 Mdot
.60608 .50701 Mdot
.71938 .41947 Mdot
.68202 .2858 Mdot
.51577 .59225 Mdot
.62929 .30103 Mdot
.51653 .21716 Mdot
.63364 .43903 Mdot
.56661 .78225 Mdot
.43481 .06659 Mdot
.519 .86444 Mdot
.39836 .81068 Mdot
.5311 .89861 Mdot
.41026 .20849 Mdot
.39537 .80308 Mdot
.40802 .21574 Mdot
.73029 .49832 Mdot
.7971 .44625 Mdot
.41006 .85227 Mdot
.63759 .52348 Mdot
.4984 .3507 Mdot
.71784 .63994 Mdot
.56646 .71814 Mdot
.45248 .63886 Mdot
.73409 .45503 Mdot
.59623 .22677 Mdot
.43068 .45366 Mdot
.55898 .55785 Mdot
.4514 .18509 Mdot
.4178 .36482 Mdot
.42679 .07746 Mdot
.6538 .34551 Mdot
.64216 .82081 Mdot
.7328 .45313 Mdot
.45245 .84341 Mdot
.58542 .06149 Mdot
.43183 .80488 Mdot
.5806 .50513 Mdot
.57968 .55808 Mdot
.50067 .38818 Mdot
.69871 .3224 Mdot
.71127 .36601 Mdot
.41209 .4478 Mdot
.53374 .6208 Mdot
.4123 .41058 Mdot
.53828 .3501 Mdot
.71499 .67307 Mdot
.45339 .80835 Mdot
.6762 .48668 Mdot
.48809 .74289 Mdot
.45794 .21502 Mdot
.53313 .49395 Mdot
.48475 .81743 Mdot
.42673 .78411 Mdot
.42326 .32063 Mdot
.42809 .41255 Mdot
.67767 .76717 Mdot
.66781 .26492 Mdot
.45299 .42406 Mdot
.439 .1659 Mdot
.46454 .85856 Mdot
.63281 .55722 Mdot
.53476 .24995 Mdot
.47742 .20588 Mdot
.71764 .64713 Mdot
.37353 .22203 Mdot
.49669 .89352 Mdot
.76341 .32916 Mdot
.54949 .82024 Mdot
.44174 .32347 Mdot
.5305 .07653 Mdot
.72144 .43249 Mdot
.4222 .65853 Mdot
.38612 .58293 Mdot
.61935 .09744 Mdot
.52741 .64509 Mdot
.43332 .57494 Mdot
.57781 .55451 Mdot
.67027 .4379 Mdot
.5769 .34782 Mdot
.40763 .06161 Mdot
.45958 .712 Mdot
.44997 .14962 Mdot
.39322 .48439 Mdot
.54064 .42542 Mdot
.50979 .35439 Mdot
.56262 .49409 Mdot
.68284 .28372 Mdot
.52595 .41499 Mdot
.60367 .79956 Mdot
.43777 .87394 Mdot
.61607 .66713 Mdot
.67403 .5985 Mdot
.63126 .30863 Mdot
.47991 .8565 Mdot
.36452 .68662 Mdot
.55696 .57674 Mdot
.70725 .34166 Mdot
.73249 .59401 Mdot
.47493 .77821 Mdot
.37872 .68219 Mdot
.53911 .25669 Mdot
.54487 .75487 Mdot
.66327 .65345 Mdot
.55681 .801 Mdot
.57001 .40079 Mdot
.40817 .61341 Mdot
.41415 .73422 Mdot
.62519 .85757 Mdot
.57651 .27137 Mdot
.45226 .60705 Mdot
.5303 .19014 Mdot
.59136 .40029 Mdot
.52192 .54851 Mdot
.44337 .28565 Mdot
.48241 .13069 Mdot
.57552 .26313 Mdot
.47031 .2948 Mdot
.47966 .16909 Mdot
.54975 .09222 Mdot
.53542 .73029 Mdot
.61205 .67259 Mdot
.52488 .26824 Mdot
.55221 .34662 Mdot
.49295 .67729 Mdot
.78387 .38484 Mdot
.48342 .69092 Mdot
.41572 .81464 Mdot
.37445 .39131 Mdot
.67629 .50118 Mdot
.52363 .26994 Mdot
.64861 .69968 Mdot
.72617 .41844 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:Wooooo0_l000000ooooooo0000ooooo`2jooooo`00ZOooool4o`000;_ooooo002Yooooo`Co0000
^oooool00:Wooooo0_l000000ooooooo0000ooooo`2jooooo`00[?ooool3o`000;Wooooo002/oooo
o`Go0000]oooool00:cooooo1Ol0002gooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002=ooooo`;o00007Oooool00ol0
003oooooooooo`0Iooooo`;o0000W_ooool008gooooo0_l0000Mooooo`03o`000?oooooooooo01Wo
oooo0_l0002Nooooo`00U_ooool2o`0001Cooooo00?o0000ooooooooool0^Oooool009Kooooo0_l0
000Dooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`?o00001oooool2o`000;3ooooo002Cooooo`;o00005oooool00ol0003oooooooooo`07ooooo`;o
0000/?ooool009?ooooo0_l0000Gooooo`03o`000?oooooooooo00_ooooo0_l0002/ooooo`00WOoo
ool2o`0000gooooo00?o0000ooooooooool02oooool2o`0001Cooooo0_l0002Fooooo`00T_ooool2
o`0000Wooooo0_l0000=ooooo`03o`000?oooooooooo00cooooo0_l0000Cooooo`;o0000U_ooool0
09;ooooo0_l0000Hooooo`03o`000?oooooooooo00cooooo0ol0002Zooooo`00Voooool2o`0000ko
oooo0_l0000?ooooo`;o0000Z_ooool009_ooooo0_l0000>ooooo`;o00009_ooool2o`0009?ooooo
002Aooooo`;o00006Oooool3o`0002Cooooo0_l0002Cooooo`00TOooool2o`0001Wooooo00?o0000
ooooooooool0^Oooool00:cooooo1Ol0002gooooo`00[?ooool5o`000;Oooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002?ooooo`;o00006oooool00ol0003oooooooooo`2iooooo`00ROooool0
1_o^k^ko<S8bo`000?lb<S;ok^k^ooooo`;o00000_ooool2ob4Q8@Kooooo00?o0000onk^k_ooool0
1?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool05_ooool2o`000:7o
oooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_l00003ooooo`;o8B4Q1_ooool00omEEEGo
ZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool05Oooool3o`000:7o
oooo0021ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00;o00002oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol00005ooooo`?o00003Oooool2o`000:;o
oooo0029ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool01Oooool3o`0002Cooooo0_l0002;ooooo`00
ROooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01?l0003o
8B4Qo`000?lb<S82o`0000Cooooo00?o0000ooooooooool0;?ooool2o`0008_ooooo0029ooooo`05
oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`04o`000?oooooooooo
ooooo`;o00001?ooool00ol0003oooooooooo`0Hooooo`;o0000Woooool008Wooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooooooo
o`04ooooo`;o000000?oooooo`000?ooool06Oooool2o`0009oooooo0029ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00003ooooo`;o000000?oooooo`000?ooool02ooo
ool2o`000:gooooo002=ooooo`;o00007Oooool00ol0003oooooooooo`0:ooooo`;o0000[Oooool0
08gooooo0_l0000Mooooo`03o`000?oooooooooo0;Wooooo002Kooooo`;o00003oooool00ol0003o
ooooooooo`0aooooo`;o0000Q_ooool009_ooooo0_l0000?ooooo`Co0000<?ooool2o`0008Kooooo
002/ooooo`04o`000?oooooo0000o`000;Sooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`03o`000?oooooooooo00gooooo0_l0002Zooooo`00TOooool2o`0001Wooooo00?o0000oooo
ooooool03Oooool2o`0001;ooooo0_l0002Fooooo`00TOooool2o`0000Cooooo0_l0000Cooooo`03
o`000?oooooooooo027ooooo0_l0002Fooooo`00TOooool2o`0000Cooooo0_l0000<ooooo`;o0000
1Oooool00ol0003oooooooooo`2iooooo`00TOooool2o`0001;ooooo0_l00005ooooo`03o`000?oo
oooooooo01;ooooo0_l0000?ooooo`;o0000U?ooool0093ooooo0_l0000Hooooo`Go00001Oooool2
o`0000_ooooo0_l0000?ooooo`;o0000U?ooool0093ooooo0_l0000Hooooo`?o00001oooool2o`00
0;;ooooo002/ooooo`03o`000?oooooooooo01Cooooo0_l0002Sooooo`00W?ooool2o`0000kooooo
00?o0000ooooooooool05?ooool2o`0000kooooo0_l0002Cooooo`00W?ooool2o`0000kooooo00?o
0000ooooooooool09?ooool2o`0009?ooooo002/ooooo`?o00001oooool3o`000:oooooo002/oooo
o`?o00001oooool3o`000:oooooo0023ooooo`;o00009oooool00ol0003oooooooooo`2iooooo`00
Poooool2o`0002Oooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00Y?ooool2
o`0000Kooooo00?o0000ooooooooool0^Oooool008kooooo0_l0000Dooooo`;o000000?oooooo`00
0?l000000oooool00ol0003oooooooooo`0[ooooo`;o0000S?ooool008kooooo0_l00002ooooo`;o
00003?ooool2o`0000Gooooo0_l00003ooooo`03o`000?oooooooooo00_ooooo0_l0000Nooooo`;o
0000S?ooool008gooooo0_l00003ooooo`;o00002_ooool4o`0000[ooooo00?o0000ooooooooool0
0_ooool3o`0000Kooooo0ol0002[ooooo`00SOooool2o`0000oooooo0_l0000<ooooo`03o`000?oo
oooooooo00;ooooo0ol00006ooooo`?o00003Oooool2o`0009cooooo0022ooooo`;o0000:?ooool0
0ol0003oooooooooo`02ooooo`;o00005oooool2o`0009cooooo0022ooooo`;o00006?ooool2o`00
00gooooo1?l0000Jooooo`;o00003oooool4o`0008[ooooo002Looooo`;o00003Oooool2o`0001co
oooo1?l0000=ooooo`Co0000R_ooool00:cooooo00?o0000ooooooooool07?ooool2o`0009_ooooo
002/ooooo`03o`000?oooooooooo02kooooo0_l00029ooooo`00[?ooool3o`0002kooooo0_l00029
ooooo`00Y?ooool2o`0000Kooooo0ol0002iooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`03odA4A?l0003o000000?o00001?ooool00ol0003oooooooooo`2ioooo
o`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMol0003o0000
00Cooooo00?o0000ooooooooool00_l0000`ooooo`;o0000QOooool008Wooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;o00001_ooool2o`0000Wooooo0_l0000Kooooo`Co0000QOooool0097ooooo00Go0000oooooooo
ooooooooo`000007ooooo`;o00001_ooool00omgMgOo<S8booooo`04ooooo`?o00002?ooool2o`00
00Wooooo0_l0000Kooooo`;o0000Qoooool0097ooooo00Go0000ooooooooooooooooo`000007oooo
o`;o00000oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0^Oooool0
097ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02Oooool2o`000:kooooo002Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo0_l0000;ooooo`;o0000XOooool0
097ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`0000cooooo0_l00008
ooooo`?o00007?ooool2o`0008?ooooo002/ooooo`;o00001_ooool2o`0000Cooooo0_l00008oooo
o`;o00007Oooool2o`0008?ooooo0025ooooo`;o00007oooool2o`0000Cooooo00?o0000oooooooo
ool01?ooool3o`0002kooooo0_l00022ooooo`00QOooool2o`0001oooooo0_l00004ooooo`03o`00
0?oooooooooo00Cooooo0_l0000@ooooo`;o00007Oooool2o`0008;ooooo002/ooooo`?o00005_oo
ool2o`000:7ooooo002Booooo`;o00006?ooool00ol0003oooooooooo`0Gooooo`;o0000X?ooool0
09;ooooo0_l0000Hooooo`03o`000?oooooooooo01Oooooo0_l0000Nooooo`Co0000O_ooool009Wo
oooo0_l0000Aooooo`03o`000?oooooooooo03Oooooo1?l0001nooooo`00VOooool2o`00017ooooo
00?o0000ooooooooool0>Oooool2o`0007kooooo002/ooooo`03o`000?oooooooooo00;ooooo0_l0
002eooooo`00X_ooool2o`0000Sooooo00?o0000ooooooooool00_ooool2o`0000gooooo0_l0002V
ooooo`00X_ooool2o`0000Sooooo00?o0000ooooooooool04Oooool2o`0002Sooooo0_l0001loooo
o`00[?ooool3o`0000Wooooo0_l0000Looooo`;o00004_ooool2o`0007cooooo002/ooooo`03o`00
0?oooooooooo00Wooooo0_l0000Looooo`;o0000T?ooool00:Sooooo0_l00002ooooo`03o`000?oo
oooooooo0;Wooooo002Xooooo`;o00000_ooool00ol0003oooooooooo`0Xooooo`;o0000Soooool0
0:cooooo00?o0000ooooooooool00oooool2o`0002?ooooo0_l0002?ooooo`00Zoooool2o`0000Go
oooo0_l0002dooooo`00Soooool2o`0001;ooooo0_l00006ooooo`;o0000;?ooool2o`0008gooooo
002?ooooo`;o000000?oooooo`000?l000003oooool2o`0000Oooooo00?o0000ooooooooool0:_oo
ool2o`0001;ooooo0_l0001iooooo`00T_ooool2o`0000Cooooo0_l0000Booooo`?o00007oooool2
o`0001gooooo0_l0001iooooo`00UOooool2o`000003ooooool0003o000001;ooooo0_l0000Poooo
o`;o0000V?ooool009Gooooo0_l0000Eooooo`;o0000;_ooool2o`0002Gooooo0_l0001Sooooo`00
Qoooool2o`0002?ooooo00?o0000ooooooooool0;Oooool2o`00017ooooo0_l0000Booooo`;o0000
Hoooool008Oooooo0_l0000Sooooo`03o`000?oooooooooo01oooooo0_l0000Oooooo`;o0000Mooo
ool00:cooooo00?o0000ooooooooool07oooool2o`0009Sooooo002Jooooo`;o00004?ooool00ol0
003oooooooooo`11ooooo`;o0000M_ooool009[ooooo0_l0000@ooooo`03o`000?oooooooooo00ko
oooo0_l0000Mooooo`Co00003oooool3o`0007Kooooo002/ooooo`03o`000?oooooooooo00kooooo
0_l00006ooooo`;o00005Oooool4o`0000oooooo0_l0001gooooo`00Zoooool4o`0000Wooooo0_l0
000;ooooo`;o0000XOooool008[ooooo0_l0000Oooooo`;o00000_ooool2o`0000Oooooo0_l0000T
ooooo`;o0000R?ooool008[ooooo0_l0000Pooooo`03o`000?oooooooooo00;o00000oooool2o`00
02Sooooo0_l00028ooooo`00[?ooool00ol0003oooooooooo`05ooooo`;o0000:?ooool2o`00017o
oooo0_l0001eooooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool01Oooool2o`0003Wooooo
1?l0001eooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo0_l000000ooooooo8B4Q
ob4Q8@03ooooo`Ko00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00Co0000oooooooo
oooooooo0_l00002ooooo`;o0000>Oooool6o`0007?ooooo0029ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@?ooooo0_l000001?lQ8B7ok^k^oooooom4A4@7ooooo`03ogMgMolb<S;o
oooo00Cooooo00Co0000oooooooooooooooo0_l0000Qooooo`;o00007?ooool4o`0007?ooooo0021
ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo0_l00005ooooo`;o00001_oo
ool2o`0000Sooooo0_l0000Looooo`?o0000M?ooool008Wooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0000_ooooo0_l0
0005ooooo`;o00001_ooool2o`0001Cooooo0_l0000Aooooo`;o0000M?ooool008Wooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`03o`000?oooooooooo033ooooo0_l00027ooooo`00ROooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0;Wooooo001mooooo`;o00002_ooool01OmgMgOo0000o`000?nHV9SoMgMg00_ooooo
00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool00_l0001Hooooo`;o0000GOooool007gooooo0_l0000:ooooo`05onk^k_l0003o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o000000?oooooo`00
0?l00000F?ooool2o`0005gooooo0022ooooo`;o0000:?ooool2o`0001_ooooo0_l00009ooooo`;o
00006oooool2o`0007Gooooo0022ooooo`;o0000:?ooool00ol0003oooooooooo`0Jooooo`;o0000
2Oooool2o`0001_ooooo1?l0001cooooo`00S?ooool2o`0001kooooo00?o0000ooooooooool0A?oo
ool2o`0007?ooooo002<ooooo`;o00007_ooool3o`0001Cooooo0_l00005ooooo`;o0000:Oooool2
o`00077ooooo002/ooooo`03o`000?oooooooooo01Cooooo0_l00005ooooo`;o00009oooool4o`00
01?ooooo0_l0001Looooo`00[?ooool00ol0003oooooooooo`0Looooo`;o00009_ooool2o`0001Go
oooo0_l0001Looooo`00Soooool2o`0001_ooooo00?o0000ooooooooool07?ooool2o`0000Wooooo
0_l0000Kooooo`;o0000Loooool008oooooo0_l00003ooooo`;o00005_ooool00ol0003ooooooooo
o`0Wooooo`;o00006oooool2o`0007?ooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`05
ooooo`;o00008Oooool2o`0001_ooooo0ol0001aooooo`00S?ooool2o`0001kooooo00?o0000oooo
ooooool01Oooool2o`00027ooooo0_l00009ooooo`Co00003_ooool4o`00073ooooo0021ooooo`;o
00002Oooool2o`0001kooooo00?o0000ooooooooool0<oooool4o`0000kooooo1?l0001`ooooo`00
POooool2o`0000cooooo0_l0000;ooooo`;o00003_ooool3o`0000[ooooo0_l00003ooooo`;o0000
=_ooool2o`00073ooooo002?ooooo`;o00002oooool2o`0000kooooo00?o0000ooooooooool02_oo
ool2o`0000?ooooo0_l0002Xooooo`00UOooool2o`0001Gooooo00?o0000ooooooooool00_ooool2
o`0003;ooooo0_l00021ooooo`00UOooool2o`0001Gooooo00?o0000ooooooooool00_ooool2o`00
02Cooooo0_l0000<ooooo`;o00003_ooool2o`00077ooooo002/ooooo`03o`000?oooooooooo02So
oooo0_l0000;ooooo`;o00003oooool2o`00077ooooo002<ooooo`;o00007_ooool00ol0003ooooo
ooooo`0Nooooo`;o00002Oooool2o`0000[ooooo0_l00022ooooo`00S?ooool4o`0001cooooo00?o
0000ooooooooool02_ooool2o`0000[ooooo0_l00006ooooo`;o00002Oooool2o`0008kooooo0029
ooooo`;o00000oooool2o`0001cooooo00?o0000ooooooooool02_ooool2o`0000[ooooo0_l00007
ooooo`;o00005?ooool2o`0001;ooooo0_l0000Dooooo`;o0000F?ooool008Wooooo0_l00003oooo
o`?o00006oooool00ol0003oooooooooo`0@ooooo`;o00003Oooool2o`0001Cooooo0_l0000Boooo
o`;o00005?ooool2o`0005Sooooo002>ooooo`?o00006oooool3o`0000Kooooo0_l00008ooooo`;o
0000Yoooool009Gooooo0_l0000Eooooo`03o`000?oooooooooo00Kooooo0_l0000?ooooo`;o0000
<?ooool3o`0006gooooo002Eooooo`;o00005Oooool00ol0003oooooooooo`0Gooooo`;o0000<?oo
ool3o`0006gooooo0009ooooo`Co000000?o410@ooooooooool05_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8b
omgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0
003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004
ooooo`05odA4A?l0003o0000oc8b<_oMgMd05_ooool00ol0003oooooooooo`0@ooooo`;o00001_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000
o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4
A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd06?ooool4o`000003oa0@
4?oooooooooo01;ooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007
ooooo`03ogMgMolb<S;ooooo01Gooooo00?o0000ooooooooool04?ooool2o`0000Kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo
00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00;o00000oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46oooo
o`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool06Oooool00ol0003oooooooooo`0Doooo
o`001_l00005ooooo`03o`000?oooooooooo013ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00Gooooo1_l00002oooo
o`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`05ooooo`Ko00000_ooool0
1Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo01Sooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRH
V?lQ8B7ok^k^00Wooooo00?o0000ooooooooool03Oooool01Ol@413ooooooooooooooooo410@00;o
00003_ooool00ol0003oooooooooo`0=ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onY
ZJWoEEEEooooo`08ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05?ooool000_o
oooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qoooo
ooooool01_ooool00omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^
kP07ooooo`03ogMgMolb<S;ooooo01Gooooo00?o0000ooooooooool01?ooool2o`000003ooooool0
003o000000?ooooo0_l0000:ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Q
onk^kP07ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000?ooooo`03
ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo
00Kooooo00?oMgMgoc8b<_ooool06Oooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003o
ooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c00?ooooo`04o`000?ooooooooooooooo`;o00003Oooool00omgMgOo
IVIVooooo`03ooooo`05o`000?lQ8B7o0000o`000?o<c<`05_ooool00ol0003oooooooooo`04oooo
o`;o000000?oooooo`000?l000000oooool2o`0000[ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?oo
ooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00J
ooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go410@oooo
oooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool04Oooool0
1Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04Oooool01?l@413ooooooooo
ooooool2o`0000kooooo00?o0000ooooooooool00_ooool01?l0003oooooo`000?l0000Gooooo`?o
00005_ooool2o`000005oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooo
oooo017ooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0H
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo
00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooooooo
ool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004
ooooo`03o`000?oooooooooo01Sooooo0ol00004ooooo`;o00001_ooool2o`0000Sooooo0_l00000
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo0ol000000onHV9So410@ooooo`03ooooo`03o`000?oo
oooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01Cooooo0009ooooo`03oeEEEOmVIVKo000001[o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`00013ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00005oooool3o`0000Cooooo0_l00006ooooo`;o0000
2_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHo`000?l0003o8B4Qolc<c004oooo
o`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000Iooooo`03oeEEEOmVIVKo000001Kooooo0028
ooooo`;o00008_ooool00ol0003oooooooooo`0iooooo`;o0000O_ooool008Sooooo0_l0000Roooo
o`03o`000?oooooooooo02Wooooo0_l0000<ooooo`Co0000O_ooool008kooooo0_l0000Looooo`03
o`000?oooooooooo02Wooooo0_l0000;ooooo`?o0000MOooool2o`0000;ooooo0_l00005ooooo`00
S_ooool2o`0001cooooo00?o0000ooooooooool01oooool2o`0000Sooooo0_l0000Sooooo`;o0000
M_ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Gooooo0021ooooo`;o0000:Oooool00ol0003o
ooooooooo`07ooooo`;o00002?ooool2o`0000gooooo0_l0000Wooooo`;o0000I?ooool01?oMgMgo
0000oa0@4?o<c<`6ooooo`001oooooooo`0004co00003?ooool01?o^k^ko8B4Qoa0@4?o^k^h6oooo
o`001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`04o`000?oooooo0000o`0000Cooooo00?o0000oooo
ooooool01Oooool2o`0000Kooooo00?o0000ooooooooool01_ooool01?l0003oooooooooooooool2
o`0000;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`04ob4Q8OmgMgOo
MgMgoc8b<PKooooo0007ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool05oooool2
o`0000Oooooo0_l00005ooooo`03o`000?oooooooooo02;ooooo0_l00002ooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`09ooooo`;o00000_ooool2
o`0000Gooooo002/ooooo`03o`000?oooooooooo01Oooooo0_l00007ooooo`;o0000Uoooool00:co
oooo00?o0000ooooooooool0^Oooool0097ooooo0_l00004ooooo`;o00004oooool00ol0003ooooo
ooooo`1Qooooo`;o0000E_ooool0097ooooo0_l00004ooooo`;o00004oooool00ol0003ooooooooo
o`0Gooooo`;o0000<?ooool2o`000003ooooool0003o000001?ooooo0_l0001Fooooo`00[?ooool0
0ol0003oooooooooo`0Aooooo`;o00001?ooool2o`00033ooooo0_l000000ooooooo0000o`00001[
ooooo`00[?ooool3o`00017ooooo0_l0000Gooooo`;o00008?ooool2o`0006_ooooo002/ooooo`03
o`000?oooooooooo02[ooooo0_l0000Pooooo`;o0000Joooool00:cooooo00?o0000ooooooooool0
^Oooool009Wooooo0_l0000Aooooo`03o`000?oooooooooo00cooooo0_l0000[ooooo`;o00003ooo
ool2o`0006gooooo002Iooooo`;o00004Oooool00ol0003oooooooooo`0<ooooo`;o0000:oooool2
o`0000kooooo0ol0001]ooooo`00POooool2o`0002Wooooo00?o0000ooooooooool03?ooool2o`00
03_ooooo0_l0001^ooooo`00POooool2o`0002Wooooo00?o0000ooooooooool03?ooool2o`000:_o
oooo002;ooooo`;o00007oooool00ol0003oooooooooo`0Oooooo`;o00009oooool2o`000003oooo
ool0003o000006cooooo002;ooooo`;o00007oooool00ol0003oooooooooo`04ooooo`;o000000?o
ooooo`000?l000005_ooool2o`0002Oooooo0_l000000ooooooo0000o`00001/ooooo`00[?ooool3
o`0000Cooooo0_l000000ooooooo0000o`000011ooooo`;o0000KOooool00:cooooo00?o0000oooo
ooooool05_ooool2o`0003;ooooo0_l0001]ooooo`00[?ooool00ol0003oooooooooo`02o`0000ko
oooo0_l00004ooooo`?o00003oooool2o`0000cooooo0_l00021ooooo`00UOooool2o`0001Gooooo
00?o0000ooooooooool00_l0000>ooooo`;o00001Oooool2o`0000oooooo0_l0000<ooooo`;o0000
POooool009Gooooo0_l0000Eooooo`03o`000?oooooooooo00?ooooo0_l00006ooooo`;o00002_oo
ool2o`000:3ooooo0021ooooo`;o0000:Oooool00ol0003oooooooooo`03ooooo`;o00001_ooool2
o`000:cooooo0021ooooo`;o0000:Oooool00ol0003oooooooooo`1Pooooo`;o0000Eoooool00:co
oooo00?o0000ooooooooool0H?ooool2o`0005Oooooo002Fooooo`;o00005?ooool3o`0000Kooooo
0_l00007ooooo`;o00009Oooool2o`00087ooooo002Fooooo`;o00000_ooool2o`00013ooooo00?o
0000ooooooooool01_ooool2o`0000Oooooo0_l0000Uooooo`;o0000POooool008Kooooo0_l00000
0ooooooo0000o`00000?ooooo`;o00004?ooool00ol0003oooooooooo`0:ooooo`;o00004_ooool2
o`0001Kooooo0ol00020ooooo`00Q_ooool2o`000003ooooool0003o0000027ooooo00?o0000oooo
ooooool01_ooool2o`0000;ooooo0_l0000Booooo`;o00005_ooool3o`00083ooooo0026ooooo`;o
00009?ooool00ol0003oooooooooo`06ooooo`;o0000/Oooool008Kooooo0_l0000Tooooo`03o`00
0?oooooooooo00;ooooo0_l0002eooooo`00[?ooool00ol0003oooooooooo`02ooooo`;o0000AOoo
ool2o`0006kooooo002/ooooo`03o`000?oooooooooo04Wooooo0_l0001^ooooo`00[?ooool3o`00
03Gooooo0ol0000Aooooo`;o0000K_ooool00:cooooo00?o0000ooooooooool0=Oooool3o`00087o
oooo002Looooo`;o00003_ooool00ol0003oooooooooo`2iooooo`00W?ooool2o`0000kooooo00?o
0000ooooooooool09oooool2o`00023ooooo0_l0001^ooooo`00SOooool2o`0001gooooo00?o0000
ooooooooool09oooool2o`00023ooooo0_l0001^ooooo`00SOooool2o`0001gooooo00?o0000oooo
ooooool0^Oooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`00
00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01gooooo0_l0000F
ooooo`;o0000P_ooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So0000o`000?ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`08ooooo`;o00004oooool2o`0001Kooooo0_l00022ooooo`00ROooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o00002?oo
ool2o`0000;ooooo0_l0000Xooooo`;o0000POooool008Wooooo00Co0000oooooooooooooooo0ol0
000;ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`0<ooooo`;o00001?ooool2o`0002;ooooo0_l00021ooooo`00ROooool01?l0003ooooooooooooo
ool3o`0000cooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool04_ooool2o`000:Gooooo0029ooooo`05oa0@4?ooooooooooooooool@4100
3oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool2o`0001?ooooo0_l0002Kooooo`00ROooool01OmgMgOoV9RHo`000?l0003oMgMg00Kooooo
0_l00003ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo0_l0000Cooooo`;o00005Oooool2o`0008Cooooo0029ooooo`05onk^
k_lb<S;o0000o`000?o^k^h01_ooool2o`0000?ooooo00?oV9RHoa0@4?l000000_l00004ooooo`Co
00001_ooool00ol0003oooooooooo`0cooooo`;o00003oooool2o`0007?ooooo002Looooo`;o0000
3_ooool00ol0003oooooooooo`0Booooo`;o00004Oooool3o`0001cooooo0_l0001cooooo`00[?oo
ool00ol0003oooooooooo`06ooooo`;o00000oooool2o`0000Gooooo0_l0000Aooooo`?o0000TOoo
ool00:cooooo00?o0000ooooooooool01_ooool2o`0000;ooooo0ol0000gooooo`;o0000Loooool0
0:cooooo0ol0000:ooooo`;o00009Oooool2o`00017ooooo0_l0001cooooo`00[?ooool00ol0003o
ooooooooo`09ooooo`;o00001_ooool2o`0001kooooo0ol00025ooooo`00S_ooool2o`0000;ooooo
0_l0000Hooooo`03o`000?oooooooooo00Wooooo0_l00006ooooo`;o00007oooool2o`0008Gooooo
002>ooooo`;o00000_ooool2o`0001Sooooo00?o0000ooooooooool06Oooool2o`0001Oooooo0_l0
0025ooooo`00T_ooool2o`0001Sooooo00?o0000ooooooooool06Oooool2o`0001Oooooo0_l00025
ooooo`00Ooooool2o`0001Oooooo0_l00007ooooo`;o00002Oooool00ol0003oooooooooo`08oooo
o`;o00006Oooool2o`0000gooooo0_l00025ooooo`00Ooooool2o`0001Oooooo0_l00007ooooo`;o
00002Oooool00ol0003oooooooooo`08ooooo`;o00003?ooool2o`0000_ooooo0_l0002Dooooo`00
[?ooool00ol0003oooooooooo`0Fooooo`;o00002_ooool2o`00023ooooo0_l0001cooooo`00U_oo
ool2o`0001Cooooo0ol0000Rooooo`?o00002oooool2o`0001;ooooo0_l0001cooooo`00Poooool2
o`00017ooooo0_l0000Aooooo`;o000000?oooooo`000?ooool09?ooool2o`0000_ooooo0_l00027
ooooo`00Poooool3o`0002?ooooo0_l000000ooooooo0000ooooo`2jooooo`00Q?ooool2o`0002Ko
oooo00?o0000ooooooooool0^Oooool007oooooo0_l0000[ooooo`03o`000?oooooooooo0;Wooooo
001oooooo`;o00009Oooool2o`0000Cooooo00?o0000ooooooooool0^Oooool007oooooo0_l0000U
ooooo`;o00001?ooool00ol0003oooooooooo`0oooooo`;o0000N?ooool009Oooooo0_l0000Coooo
o`03o`000?oooooooooo03oooooo0_l0001hooooo`00Q?ooool2o`0000kooooo0_l000000ooooooo
0000o`00000Cooooo`?o00002oooool2o`00027ooooo0_l00029ooooo`00Q?ooool2o`0000kooooo
0_l0000Fooooo`03o`000?oooooooooo00_ooooo0_l0000Aooooo`;o00003?ooool4o`0008Wooooo
002Dooooo`;o00005_ooool00ol0003oooooooooo`0Nooooo`;o00003?ooool2o`0008_ooooo002/
ooooo`03o`000?oooooooooo0;Wooooo002Nooooo`;o00003?ooool00ol0003oooooooooo`2ioooo
o`00W_ooool2o`0000cooooo0ol0000/ooooo`;o0000Roooool00:Kooooo0_l00004ooooo`?o0000
4oooool2o`0001Oooooo0_l0002;ooooo`00Soooool2o`0001Gooooo0_l00004ooooo`03o`000?oo
oooooooo01?ooooo0_l0000Yooooo`;o0000NOooool008oooooo0_l0000Cooooo`;o00001_ooool3
o`0000;ooooo0_l00004ooooo`;o0000=?ooool2o`0007Wooooo002:ooooo`;o00004?ooool2o`00
00Kooooo0_l00006ooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`;o00008Oooool2o`00
08cooooo002:ooooo`;o00004?ooool2o`0000kooooo00?o0000ooooooooool02?ooool2o`00027o
oooo0_l0002<ooooo`00Soooool2o`0001_ooooo00?o0000ooooooooool02?ooool2o`000:oooooo
002?ooooo`;o00006oooool00ol0003oooooooooo`0@ooooo`;o00005oooool2o`00013ooooo0_l0
001looooo`00Soooool2o`0001_ooooo00?o0000ooooooooool04?ooool2o`0001Oooooo0_l0000@
ooooo`;o0000O?ooool0097ooooo00?ok^k^oc8b<_l000000_l00005ooooo`;o8B4Q1Oooool01_m4
A4Co0000o`000?lb<S;ogMgMooooo`;o00000_ooool00ol0003oooooooooo`2iooooo`00TOooool0
0omgMgOoV9RHooooo`02o`0000Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00;o00000_ooool0
0ol0003oooooooooo`06ooooo`;o0000<oooool2o`0007cooooo002Aooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo0_l00007
ooooo`;o00001oooool2o`00027ooooo0_l0001looooo`00TOooool01Ol0003ooooooooooooooooo
000000oooooo00?oMgMgoc8b<_ooool01?ooool3o`0000oooooo0_l00007ooooo`;o0000Woooool0
097ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`0;ooooo`;o0000[?ooool0097ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02oooool2o`000:cooooo002<
ooooo`;o00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`2iooooo`00S?ooool2o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`Co00001_ooool00ol0003oooooooooo`0gooooo`;o0000P?ooool00:[ooooo0ol00004
ooooo`;o00008?ooool2o`00017ooooo0_l00020ooooo`00TOooool2o`0001Oooooo0ol00003oooo
o`?o00008?ooool2o`00017ooooo0_l00020ooooo`00TOooool2o`0001Wooooo00Co0000oooooooo
oooooooo0_l0000Oooooo`;o0000UOooool00:cooooo0ol0000Rooooo`;o0000UOooool00:?ooooo
0ol00002ooooo`;o00000_ooool00ol0003oooooooooo`0Booooo`;o0000YOooool008gooooo0_l0
000Dooooo`?o00000_ooool2o`0000;ooooo00?o0000ooooooooool04_ooool3o`000:Cooooo002=
ooooo`;o00001?ooool2o`0000?ooooo0_l0000:ooooo`?o00001Oooool00ol0003oooooooooo`0C
ooooo`;o00002_ooool2o`000003ooooool0003o000009Gooooo002Cooooo`;o00000oooool2o`00
00_ooooo0_l00005ooooo`03o`000?oooooooooo01oooooo0_l000000ooooooo0000o`00000?oooo
o`;o0000Q?ooool009[ooooo0_l0000@ooooo`03o`000?oooooooooo00Kooooo0_l0000Gooooo`;o
00004_ooool2o`0008Cooooo002Jooooo`;o00004?ooool00ol0003oooooooooo`06ooooo`;o0000
2?ooool4o`0000[ooooo0_l0002Iooooo`00[?ooool00ol0003oooooooooo`05ooooo`;o00002Ooo
ool4o`0000[ooooo0_l0000@ooooo`;o0000Qoooool00:cooooo0ol00004ooooo`?o00002?ooool3
o`0000gooooo0_l0000?ooooo`;o0000Qoooool008Wooooo0_l0000Qooooo`03o`000?oooooooooo
00Cooooo0_l00009ooooo`?o00003Oooool2o`0009Sooooo0029ooooo`;o00002_ooool2o`0001Go
oooo00?o0000ooooooooool0^Oooool009Gooooo0_l00005ooooo`;o00003_ooool00ol0003ooooo
ooooo`0`ooooo`;o0000Qoooool008[ooooo0_l0000@ooooo`Co00003?ooool00ol0003ooooooooo
o`0Kooooo`;o00004oooool2o`0008Oooooo002:ooooo`;o00001?ooool2o`0000cooooo0_l00000
0ooooooo0000o`000009ooooo`03o`000?oooooooooo01_ooooo0_l0002Looooo`00T?ooool2o`00
00oooooo0_l00004ooooo`;o00000oooool00ol0003oooooooooo`2iooooo`00Yoooool2o`0000?o
oooo00?o0000ooooooooool03Oooool2o`0000_ooooo0ol0000>ooooo`;o0000S?ooool00:cooooo
0ol0000:ooooo`;o000000?oooooo`000?l000002oooool3o`0000kooooo0_l0002<ooooo`00[?oo
ool01?l0003oooooo`000?l00009ooooo`;o0000[Oooool00:cooooo00Co0000ooooool0003o0000
5_ooool2o`00017ooooo0_l0002=ooooo`00[?ooool00ol0003oooooooooo`0Gooooo`;o00004Ooo
ool2o`0008gooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Cooooo`;o00005oooool3o`00
00Sooooo0ol0002^ooooo`00T_ooool3o`0000Oooooo0_l0000>ooooo`?o00002?ooool3o`000:ko
oooo002Booooo`;o00002?ooool2o`0000kooooo00?o0000ooooooooool0^Oooool00:[ooooo0ol0
002kooooo`00S_ooool2o`0001[ooooo1Ol0002iooooo`00S_ooool2o`0001cooooo00?o0000oooo
ooooool0^Oooool00:3ooooo0_l00003ooooo`Co00000oooool00ol0003oooooooooo`03ooooo`;o
00008Oooool2o`00097ooooo002Eooooo`;o00002Oooool2o`0000?ooooo1?l00003ooooo`03o`00
0?oooooooooo00?ooooo0_l0000=ooooo`;o00004?ooool4o`00097ooooo002Eooooo`;o00005Ooo
ool00ol0003oooooooooo`03ooooo`;o00003Oooool2o`00013ooooo0_l0002Cooooo`00ROooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00?ooooo0_l0002dooooo`00ROoo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`02ooooo`;o0000]Oooool008Wooooo00Go
410@oooooooooooooooooa0@4009ooooo`;o00000_ooool00onYZJWoEEEEooooo`08ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?l0002eooooo`00ROooool01Ol0003ooooooooo
oooooooo000000Wooooo0_l00003ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool0
1?ooool5o`000;Oooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<
ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2iooooo`00
ROooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`2iooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004oooo
o`Co00001_ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
Z_ooool3o`000;_ooooo002Zooooo`?o0000^oooool009?ooooo0_l0000>ooooo`;o00001oooool3
o`0000Oooooo0_l0002`ooooo`00Toooool2o`0000kooooo0_l00007ooooo`03o`000?oooooooooo
00Oooooo0_l0002`ooooo`00Toooool2o`0001Oooooo00?o0000ooooooooool02?ooool2o`000:oo
oooo002Cooooo`;o00005oooool00ol0003oooooooooo`08ooooo`;o0000[oooool00:cooooo00?o
0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool009Oooooo0_l0000Cooooo`?o0000
^Oooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`04o`000?oooooo0000o`000;Sooooo002/ooooo`04o`000?oooooo0000
o`000;Sooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`;o0000^_ooool00:Oooooo0_l00003ooooo`;o0000^_ooool00:Oooooo0_l00000
0ooooooo0000o`000003o`000;Wooooo002Mooooo`;o00001Oooool2o`0000Cooooo0ol0002koooo
o`00WOooool2o`0000Gooooo0_l000000ooooooo0000o`000003ooooo`03o`000?oooooooooo0;Wo
oooo002Wooooo`;o00000oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`06ooooo`;o0000/Oooool00:cooooo0ol00005ooooo`?o0000
/Oooool00:cooooo00?o0000ooooooooool01Oooool2o`000;;ooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002Rooooo`Co000000?o410@ooooooooool00ooo
ool00ol0003oooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0;Wooooo002Tooooo`03o`000?oooooooooo00Gooooo0ol0002iooooo`00Y?ooool00ol0003o
ooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003ooooooooo
o`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00X_ooool00omEEEGoIVIVo`000033oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Z_ooool01?l@
413o0000o`000?l0002jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003o
ooooooooo`2jooooo`00Zoooool01_l0003oMgMgo`000?l0003oEEEEonk^k[Oooooo002[ooooo`06
o`000?mEEEGok^k^oooooomgMgOoEEEE]oooool00:_ooooo00?o0000onk^k_ooool00_ooool00ol0
003oooooooooo`2eooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo0;Go
oooo002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoIVIV]oooool00:[ooooo00?o410@o`000?mg
MgL00_l000000omVIVKok^k^ooooo`2fooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.64344 .54824 Mdot
.55591 .81689 Mdot
.46555 .37064 Mdot
.51529 .69016 Mdot
.58598 .54536 Mdot
.5391 .19 Mdot
.48687 .66516 Mdot
.55485 .08156 Mdot
.36959 .46531 Mdot
.56212 .4499 Mdot
.53083 .69484 Mdot
.622 .17183 Mdot
.38616 .34409 Mdot
.55904 .60018 Mdot
.63717 .20446 Mdot
.41788 .43165 Mdot
.60307 .59726 Mdot
.39225 .28561 Mdot
.47349 .19631 Mdot
.68919 .46472 Mdot
.40032 .23962 Mdot
.45701 .90547 Mdot
.41446 .81043 Mdot
.40998 .18633 Mdot
.70455 .33533 Mdot
.39985 .48262 Mdot
.47179 .78593 Mdot
.45553 .21295 Mdot
.69057 .51633 Mdot
.54292 .83433 Mdot
.44211 .10468 Mdot
.36887 .4767 Mdot
.4967 .02466 Mdot
.53937 .77622 Mdot
.42313 .78776 Mdot
.6584 .35726 Mdot
.59126 .82832 Mdot
.41135 .42474 Mdot
.68265 .57406 Mdot
.64265 .19863 Mdot
.70813 .33331 Mdot
.48081 .86387 Mdot
.41362 .2437 Mdot
.64177 .59337 Mdot
.64544 .47584 Mdot
.52383 .76453 Mdot
.5612 .56619 Mdot
.40611 .85875 Mdot
.54271 .2461 Mdot
.68662 .50448 Mdot
.41194 .87764 Mdot
.66893 .65962 Mdot
.39214 .50999 Mdot
.39232 .43381 Mdot
.40932 .12264 Mdot
.56668 .09684 Mdot
.60561 .59003 Mdot
.4969 .9568 Mdot
.64187 .4437 Mdot
.50055 .80535 Mdot
.7243 .66058 Mdot
.67946 .58655 Mdot
.44114 .31524 Mdot
.48978 .02557 Mdot
.38043 .27735 Mdot
.55773 .42451 Mdot
.41811 .55152 Mdot
.41266 .3962 Mdot
.44307 .09652 Mdot
.59606 .65011 Mdot
.45778 .32945 Mdot
.56258 .46745 Mdot
.5304 .32254 Mdot
.67948 .58608 Mdot
.49845 .60232 Mdot
.4379 .77949 Mdot
.6786 .62185 Mdot
.50391 .1896 Mdot
.56693 .1768 Mdot
.5508 .82022 Mdot
.53469 .62206 Mdot
.46685 .86484 Mdot
.48523 .01422 Mdot
.42308 .36364 Mdot
.58411 .56741 Mdot
.56613 .6473 Mdot
.61235 .53526 Mdot
.41712 .51811 Mdot
.70705 .34519 Mdot
.43 .98872 Mdot
.52043 .33427 Mdot
.55266 .69705 Mdot
.49695 .27818 Mdot
.56164 .5836 Mdot
.40435 .84574 Mdot
.61354 .54705 Mdot
.63703 .59843 Mdot
.6112 .46037 Mdot
.61872 .17057 Mdot
.63204 .63788 Mdot
.52579 .11685 Mdot
.52114 .80919 Mdot
.58105 .69312 Mdot
.51529 .24231 Mdot
.52228 .33947 Mdot
.4493 .08876 Mdot
.56671 .52487 Mdot
.5233 .6699 Mdot
.36902 .51253 Mdot
.67079 .3819 Mdot
.70899 .20392 Mdot
.4314 .41945 Mdot
.46772 .82464 Mdot
.40077 .14837 Mdot
.37918 .28254 Mdot
.59855 .81056 Mdot
.38572 .35242 Mdot
.7404 .58846 Mdot
.38249 .45602 Mdot
.69153 .5278 Mdot
.44991 .08722 Mdot
.49037 .74418 Mdot
.67809 .41714 Mdot
.53645 .97696 Mdot
.60061 .71756 Mdot
.51025 .34859 Mdot
.41712 .82369 Mdot
.62314 .65721 Mdot
.65336 .22206 Mdot
.5525 .20848 Mdot
.45452 .13278 Mdot
.68676 .58517 Mdot
.61401 .79633 Mdot
.68719 .47521 Mdot
.56115 .45535 Mdot
.53793 .06995 Mdot
.64525 .21528 Mdot
.6751 .77595 Mdot
.55026 .51514 Mdot
.43141 .27085 Mdot
.60309 .59902 Mdot
.68243 .42468 Mdot
.44913 .02776 Mdot
.76888 .31483 Mdot
.52773 .27503 Mdot
.55466 .68556 Mdot
.74804 .54562 Mdot
.60813 .43294 Mdot
.4198 .66218 Mdot
.4151 .16483 Mdot
.44421 .37487 Mdot
.59654 .30144 Mdot
.63451 .75147 Mdot
.67724 .61173 Mdot
.40058 .15185 Mdot
.58984 .82873 Mdot
.63009 .76199 Mdot
.44363 .18945 Mdot
.67974 .62256 Mdot
.7073 .31669 Mdot
.63179 .29157 Mdot
.41107 .26218 Mdot
.63795 .57879 Mdot
.43796 .04415 Mdot
.55461 .15343 Mdot
.40955 .45406 Mdot
.63727 .75159 Mdot
.68011 .45194 Mdot
.53209 .38213 Mdot
.41452 .61047 Mdot
.58208 .56911 Mdot
.54746 .31824 Mdot
.50401 .03461 Mdot
.59031 .28821 Mdot
.42932 .47555 Mdot
.68819 .53516 Mdot
.65723 .70464 Mdot
.66899 .244 Mdot
.48573 .23287 Mdot
.71434 .35006 Mdot
.5349 .53251 Mdot
.37009 .53078 Mdot
.54134 .97008 Mdot
.36833 .5225 Mdot
.70024 .30178 Mdot
.43469 .16738 Mdot
.74443 .53612 Mdot
.68273 .42422 Mdot
.42274 .51319 Mdot
.72966 .63037 Mdot
.51933 .04407 Mdot
.73407 .41006 Mdot
.63448 .19267 Mdot
.56344 .66362 Mdot
.37201 .77154 Mdot
.54284 .78103 Mdot
.45321 .67591 Mdot
.44642 .6562 Mdot
.47235 .31208 Mdot
.58527 .52359 Mdot
.35787 .61307 Mdot
.63062 .62375 Mdot
.47962 .72527 Mdot
.56412 .23215 Mdot
.52804 .65895 Mdot
.51962 .63899 Mdot
.52243 .71837 Mdot
.38833 .66933 Mdot
.44854 .80264 Mdot
.55694 .15689 Mdot
.45659 .24596 Mdot
.63571 .59276 Mdot
.4725 .82251 Mdot
.70962 .32422 Mdot
.53517 .5481 Mdot
.63242 .40827 Mdot
.62289 .16813 Mdot
.47726 .82608 Mdot
.47998 .96424 Mdot
.53746 .12985 Mdot
.59302 .21892 Mdot
.42844 .34083 Mdot
.58163 .44139 Mdot
.57698 .78314 Mdot
.52832 .36472 Mdot
.64002 .20857 Mdot
.73915 .60754 Mdot
.42489 .63573 Mdot
.49413 .3595 Mdot
.35672 .57099 Mdot
.58345 .34616 Mdot
.47619 .78848 Mdot
.74208 .56315 Mdot
.40945 .51867 Mdot
.62373 .66894 Mdot
.38139 .48304 Mdot
.62849 .63822 Mdot
.72325 .66105 Mdot
.4927 .12527 Mdot
.59869 .21794 Mdot
.59661 .64791 Mdot
.36883 .44753 Mdot
.47937 .26133 Mdot
.63978 .73281 Mdot
.60694 .471 Mdot
.59899 .63918 Mdot
.67969 .5924 Mdot
.7298 .39624 Mdot
.42993 .44031 Mdot
.42336 .51952 Mdot
.62398 .7651 Mdot
.40141 .44282 Mdot
.41946 .65179 Mdot
.40282 .29911 Mdot
.48932 .63345 Mdot
.55061 .08053 Mdot
.44493 .95091 Mdot
.5662 .29691 Mdot
.47745 .78836 Mdot
.60846 .24509 Mdot
.47207 .28886 Mdot
.60406 .41757 Mdot
.64307 .50268 Mdot
.55574 .59812 Mdot
.49865 .1375 Mdot
.66982 .39963 Mdot
.42389 .25561 Mdot
.66823 .382 Mdot
.3975 .35024 Mdot
.56244 .44506 Mdot
.53606 .23991 Mdot
.63868 .74409 Mdot
.49903 .24862 Mdot
.56589 .36181 Mdot
.3962 .81375 Mdot
.53077 .69981 Mdot
.58751 .27863 Mdot
.68694 .5656 Mdot
.52228 .38388 Mdot
.50259 .26139 Mdot
.58974 .82772 Mdot
.6017 .14599 Mdot
.52216 .25483 Mdot
.43575 .54632 Mdot
.57618 .42778 Mdot
.65624 .33254 Mdot
.54165 .72146 Mdot
.543 .14419 Mdot
.5415 .96912 Mdot
.51186 .93747 Mdot
.61129 .16443 Mdot
.50608 .94183 Mdot
.51585 .53364 Mdot
.53541 .91233 Mdot
.73367 .59636 Mdot
.63658 .28487 Mdot
.62756 .18946 Mdot
.78943 .36948 Mdot
.51727 .20563 Mdot
.44561 .14007 Mdot
.61941 .67281 Mdot
.36892 .45311 Mdot
.70055 .3194 Mdot
.55668 .60043 Mdot
.40005 .83003 Mdot
.40611 .36746 Mdot
.49703 .67105 Mdot
.39161 .69517 Mdot
.5978 .62612 Mdot
.38184 .42374 Mdot
.74804 .52235 Mdot
.44003 .35894 Mdot
.63803 .44128 Mdot
.51016 .82829 Mdot
.51553 .04987 Mdot
.4808 .28737 Mdot
.67372 .25408 Mdot
.73866 .4941 Mdot
.65096 .82541 Mdot
.44673 .72451 Mdot
.55798 .21558 Mdot
.45992 .86199 Mdot
.67196 .62904 Mdot
.58456 .45387 Mdot
.46899 .7012 Mdot
.50677 .60206 Mdot
.5902 .66404 Mdot
.59835 .13463 Mdot
.62804 .75376 Mdot
.49331 .27097 Mdot
.41338 .81568 Mdot
.51826 .37446 Mdot
.47495 .31187 Mdot
.57124 .79324 Mdot
.52586 .16936 Mdot
.41236 .255 Mdot
.44376 .18958 Mdot
.58496 .49975 Mdot
.41267 .03506 Mdot
.40608 .37381 Mdot
.57046 .78326 Mdot
.44286 .31093 Mdot
.4556 .02657 Mdot
.48686 .77998 Mdot
.685 .45914 Mdot
.51374 .87365 Mdot
.54531 .43309 Mdot
.51695 .76902 Mdot
.67797 .7713 Mdot
.61704 .16324 Mdot
.54016 .90815 Mdot
.66485 .37628 Mdot
.4968 .17267 Mdot
.55056 .76298 Mdot
.67878 .43773 Mdot
.59525 .38216 Mdot
.61583 .16207 Mdot
.64334 .8418 Mdot
.60598 .23018 Mdot
.64953 .21659 Mdot
.67898 .26448 Mdot
.71557 .34583 Mdot
.5057 .36508 Mdot
.56888 .30701 Mdot
.64717 .21947 Mdot
.55634 .0858 Mdot
.51267 .39225 Mdot
.50971 .10103 Mdot
.40634 .37864 Mdot
.56926 .23903 Mdot
.6395 .58225 Mdot
.38908 .76924 Mdot
.62478 .66444 Mdot
.56499 .86946 Mdot
.65054 .69861 Mdot
.42537 .84574 Mdot
.56341 .87786 Mdot
.42744 .85396 Mdot
.68961 .29832 Mdot
.7356 .24625 Mdot
.57526 .8474 Mdot
.60698 .32348 Mdot
.43734 .43015 Mdot
.73382 .43994 Mdot
.61372 .51814 Mdot
.51059 .57964 Mdot
.6761 .25503 Mdot
.44935 .08742 Mdot
.47447 .70355 Mdot
.54213 .35785 Mdot
.41136 .67118 Mdot
.45786 .77898 Mdot
.39318 .8019 Mdot
.55201 .14551 Mdot
.73049 .62081 Mdot
.67406 .25313 Mdot
.57256 .70744 Mdot
.38956 .12023 Mdot
.55943 .74145 Mdot
.54265 .30513 Mdot
.56291 .35808 Mdot
.44504 .41211 Mdot
.58767 .1224 Mdot
.61767 .16601 Mdot
.47721 .78595 Mdot
.54206 .4208 Mdot
.46904 .79309 Mdot
.44603 .26239 Mdot
.74422 .47307 Mdot
.56072 .67665 Mdot
.63087 .28668 Mdot
.54753 .54886 Mdot
.41648 .63615 Mdot
.49077 .29829 Mdot
.57457 .62486 Mdot
.55375 .74712 Mdot
.44704 .76473 Mdot
.46606 .72376 Mdot
.74454 .56717 Mdot
.53378 .06492 Mdot
.46318 .61254 Mdot
.40985 .72948 Mdot
.5808 .69354 Mdot
.6157 .35722 Mdot
.41736 .29182 Mdot
.41027 .55306 Mdot
.73649 .44713 Mdot
.61421 .6938 Mdot
.65508 .12916 Mdot
.63759 .62024 Mdot
.44366 .68339 Mdot
.37528 .34684 Mdot
.65443 .23249 Mdot
.52165 .71618 Mdot
.51238 .87417 Mdot
.42369 .00884 Mdot
.54544 .44509 Mdot
.50038 .66577 Mdot
.55961 .35451 Mdot
.60543 .2379 Mdot
.47642 .16457 Mdot
.39387 .88899 Mdot
.52967 .58677 Mdot
.40392 .68509 Mdot
.48928 .86044 Mdot
.47209 .25806 Mdot
.43705 .37885 Mdot
.52026 .29409 Mdot
.55632 .08372 Mdot
.45774 .30069 Mdot
.6835 .59956 Mdot
.58132 .77152 Mdot
.64292 .46713 Mdot
.67343 .3985 Mdot
.51471 .10863 Mdot
.58687 .66794 Mdot
.54056 .97529 Mdot
.54766 .37674 Mdot
.60391 .14166 Mdot
.7301 .39401 Mdot
.55467 .60111 Mdot
.53648 .91185 Mdot
.42067 .27245 Mdot
.60681 .55487 Mdot
.68465 .45345 Mdot
.63721 .601 Mdot
.49036 .20397 Mdot
.51434 .77451 Mdot
.54201 .77277 Mdot
.72822 .65757 Mdot
.4484 .14344 Mdot
.50331 .57742 Mdot
.40165 .3233 Mdot
.51148 .20029 Mdot
.50132 .34851 Mdot
.43505 .68447 Mdot
.39277 .54755 Mdot
.44482 .14516 Mdot
.43122 .56485 Mdot
.40175 .55123 Mdot
.38266 .25919 Mdot
.58754 .53029 Mdot
.64108 .47259 Mdot
.41915 .33057 Mdot
.45452 .21743 Mdot
.52498 .48018 Mdot
.69781 .18484 Mdot
.52533 .50593 Mdot
.56375 .80499 Mdot
.47302 .96253 Mdot
.63676 .30118 Mdot
.41929 .33572 Mdot
.68848 .49968 Mdot
.65354 .21844 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Booooo`;o00004?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo002B
ooooo`;o00004?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo002Roooo
o`03oeEEEOmVIVKo000000;ooooo0_l00003ooooo`03o`000?oooooooooo0;Wooooo002Wooooo`;o
00000oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00Z?oo
ool7o`000;Wooooo002Kooooo`Co00002Oooool5o`000;_ooooo002Kooooo`Co00003Oooool00ol0
003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002?ooooo`;o00006oooool3o`000;Wooooo
002?ooooo`;o00006oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`03
ooooo`;o0000]?ooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo00?ooooo0_l0002doooo
o`00Uoooool2o`0001?ooooo00?o0000ooooooooool00_ooool2o`000;Gooooo002/ooooo`?o0000
0_ooool2o`000;Gooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00So
oooo0_l0002_ooooo`00[?ooool00ol0003oooooooooo`08ooooo`;o0000[oooool00:cooooo00?o
0000ooooooooool02Oooool2o`000:kooooo002/ooooo`03o`000?oooooooooo00Wooooo0_l0002^
ooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo00gooooo1?l0002Xooooo`00[?ooool00ol0003oooooooooo`0=ooooo`Co0000Z?oo
ool009_ooooo0_l0000?ooooo`03o`000?oooooooooo00oooooo0_l0002Xooooo`00Voooool2o`00
00oooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool009Wooooo
0_l0000Aooooo`03o`000?oooooooooo01?ooooo0_l0002Tooooo`00VOooool2o`00017ooooo1Ol0
000Aooooo`;o0000Y?ooool009Sooooo0_l0000Booooo`03o`000?oooooooooo00;o0000]oooool0
09Sooooo0_l0000Booooo`03o`000?oooooooooo0;Wooooo002/ooooo`04o`000?oooooooooooooo
o`;o0000]_ooool00:cooooo00Co0000oooooooooooooooo0_l0002fooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03
o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
00Gooooo0_l0002booooo`00Qoooool2o`000005ogMgMonHV9SooooooiRHV?mgMgL00_l00003oooo
o`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool01Oooool2o`0001?ooooo0_l0002Mooooo`00POooool8o`000005oa0@4?oooooooooooooo
ool@41000_l0000;ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00_l000001?oo
oooo0000o`000?l0000Jooooo`;o0000WOooool008Wooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ob4Q8Ooooooooooo00Kooooo00CoMgMgoc8b<_oooooooooo0_l000000ooooooo0000oooo
o`2jooooo`00ROooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool02Oooool2o`0002Gooooo
0_l00027ooooo`00ROooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYo`000?l00000
0oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo0_l0000Booooo`;o0000
4Oooool2o`0008Oooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01?l@413ooooo
ooooooooool2o`0000?ooooo00?o0000ooooooooool01_ooool2o`0001oooooo0_l0002Jooooo`00
ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001Oooool2o`000;_o
oooo002Jooooo`?o00003oooool00ol0003oooooooooo`0Oooooo`;o0000V?ooool009Wooooo1?l0
000?ooooo`03o`000?oooooooooo00_ooooo0_l000000ooooooo0000o`00000>ooooo`?o0000V?oo
ool008_ooooo0_l0000<ooooo`;o00004Oooool00ol0003oooooooooo`0;ooooo`;o000000?ooooo
o`000?l000003_ooool2o`0009Wooooo002;ooooo`;o00007oooool3o`000;Wooooo002;ooooo`;o
00007oooool00ol0003oooooooooo`0?ooooo`;o0000Z?ooool00:cooooo00?o0000ooooooooool0
3oooool2o`000:Sooooo002/ooooo`03o`000?oooooooooo00oooooo0_l0000Booooo`;o0000U?oo
ool0093ooooo0_l0000Booooo`;o00001_ooool00ol0003oooooooooo`0Qooooo`Co0000U?ooool0
093ooooo0_l00004ooooo`;o00003?ooool2o`0000Kooooo00?o0000ooooooooool08Oooool6o`00
09;ooooo002Fooooo`;o00005?ooool00ol0003oooooooooo`05ooooo`;o00007?ooool4o`0009;o
oooo002[ooooo`;o00001oooool2o`0001gooooo0ol0002Booooo`00Zoooool4o`0001?ooooo0_l0
000@ooooo`;o0000T_ooool00:cooooo00?o0000ooooooooool04oooool2o`000:Cooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002>ooooo`;o00007?ooool00ol0003oooooooooo`0nooooo`;o
0000NOooool008kooooo0_l00009ooooo`;o00004Oooool00ol0003oooooooooo`0Wooooo`;o0000
5Oooool2o`0007Wooooo002Iooooo`;o00004Oooool3o`0000Wooooo0_l0000Looooo`;o0000T?oo
ool009Wooooo0_l0000Aooooo`?o00002Oooool2o`0001kooooo0_l0002>ooooo`00Xoooool2o`00
00Oooooo00?o0000ooooooooool0:Oooool2o`0008kooooo002Sooooo`;o00001oooool5o`0002[o
oooo0_l0002;ooooo`00Z?ooool2o`0000;ooooo00?o0000ooooooooool00_l0000Xooooo`Co0000
5?ooool2o`0007Gooooo002Xooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`;o00009_oo
ool2o`0001Kooooo0_l0001eooooo`00[?ooool00ol0003oooooooooo`02ooooo`;o00002_ooool2
o`0001_ooooo0_l0002<ooooo`00WOooool2o`0000gooooo00?o0000ooooooooool03_ooool2o`00
01_ooooo0_l0002<ooooo`00WOooool2o`0000gooooo00?o0000ooooooooool04?ooool2o`0001_o
oooo0ol00029ooooo`00WOooool2o`0000gooooo00?o0000ooooooooool04?ooool2o`0000Wooooo
1?l0000>ooooo`Co0000R?ooool009gooooo0_l0000=ooooo`03o`000?oooooooooo01_ooooo1?l0
000>ooooo`Co0000R?ooool00:cooooo0ol0000_ooooo`;o0000R?ooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool08?ooool2o`0009Oooooo002Wooooo`;o0000
0oooool00ol0003oooooooooo`0Booooo`;o00003?ooool2o`0000kooooo0_l00027ooooo`00Yooo
ool2o`0000?ooooo00?o0000ooooooooool04_ooool2o`0000_ooooo0_l0000?ooooo`;o0000Qooo
ool008_ooooo0_l0000Oooooo`03o`000?oooooooooo00Sooooo0_l00009ooooo`;o00002_ooool2
o`0009Sooooo002;ooooo`;o00000_ooool2o`000005onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00;ooooo0_l0
0004ooooo`;o00002Oooool2o`0001oooooo0_l00023ooooo`00Soooool2o`000005ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@;o00001_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo00;ooooo0_l00007ooooo`;o00004oooool2o`0001;ooooo0_l0000Dooooo`;o0000KOoo
ool008Wooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41001oooool2o`0000Oooooo00?o
0000ooooooooool00_ooool2o`0000gooooo0_l0000Cooooo`;o0000:?ooool2o`0006gooooo002A
ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`Co0000^Ooo
ool008oooooo1Ol000000ooooooo0000ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`04ooooo`;o0000<?ooool3o`00083ooooo002?ooooo`;o000000Go410@
o`000?l0003ooooooa0@400<ooooo`;o00002?ooool00ol0003oooooooooo`04ooooo`;o0000<?oo
ool3o`00083ooooo0025ooooo`;o00001oooool2o`000006oooooomgMgOoV9RHoooooonHV9SoMgMg
3?ooool2o`000003ooooool0003o000000Gooooo0_l0002jooooo`00QOooool2o`0000Oooooo0_l0
00001_ooooook^k^oc8b<_l0003o<S8bonk^kPCooooo0_l00006ooooo`Go00001Oooool2o`0003Wo
oooo0_l0001oooooo`00V_ooool2o`00013ooooo00?o0000ooooooooool0>?ooool2o`0007oooooo
002Eooooo`;o00004_ooool2o`000003ooooool0003ooooo0;[ooooo002Aooooo`;o00000_ooool2
o`0001;ooooo0_l000000ooooooo0000ooooo`2jooooo`00Q?ooool2o`0000_ooooo0_l0000Ioooo
o`?o00001_ooool2o`000;7ooooo0024ooooo`;o00009Oooool2o`0000Sooooo0_l0000Aooooo`;o
0000W_ooool008Cooooo0_l0000Uooooo`;o00006oooool2o`0009kooooo0024ooooo`;o00000_oo
ool2o`0002;ooooo00?o0000ooooooooool0:_ooool2o`0008gooooo0028ooooo`;o00006?ooool2
o`000003ooooool0003o000000Gooooo00?o0000ooooooooool06_ooool2o`0000cooooo1?l0002=
ooooo`00T?ooool2o`00013ooooo0_l000000ooooooo0000o`000005ooooo`03o`000?oooooooooo
01[ooooo0_l0000<ooooo`;o0000Soooool0093ooooo0_l0000Jooooo`03o`000?oooooooooo00?o
oooo0_l0000Sooooo`;o0000Soooool00:Wooooo0_l000000ooooooo0000ooooo`04ooooo`;o0000
3Oooool2o`0002Oooooo0_l0001looooo`00Roooool2o`00017ooooo0_l00009ooooo`;o000000Co
ooooo`000?l0003o00004_ooool2o`0000Sooooo0_l0000<ooooo`;o00003oooool2o`0007cooooo
002;ooooo`;o00004Oooool2o`0000cooooo00?o0000ooooooooool07?ooool2o`0000cooooo0_l0
000Cooooo`;o0000N?ooool00:cooooo00?o0000ooooooooool02oooool2o`0000Kooooo0_l0000Z
ooooo`;o0000N?ooool00:cooooo00?o0000ooooooooool02oooool2o`0000Kooooo0_l0002Toooo
o`00VOooool2o`0000Oooooo0ol00007ooooo`03o`000?oooooooooo0;Wooooo002Hooooo`?o0000
1oooool3o`0000Oooooo00?o0000ooooooooool0@Oooool2o`0001;ooooo0_l0001Rooooo`00V?oo
ool2o`0001;ooooo00?o0000ooooooooool03?ooool2o`00037ooooo1?l0000Booooo`;o0000H_oo
ool00:cooooo00?o0000ooooooooool01oooool2o`0000?ooooo0_l0000aooooo`;o0000N?ooool0
08_ooooo0_l0000Oooooo`?o00001oooool2o`0001Oooooo0_l0000Pooooo`;o0000MOooool008_o
oooo0_l0000Oooooo`03o`000?oooooooooo023ooooo0_l0000Pooooo`;o0000MOooool0097ooooo
0_l0000;ooooo`;o00003?ooool00ol0003oooooooooo`2iooooo`00TOooool2o`0000_ooooo0_l0
000<ooooo`03o`000?oooooooooo00?ooooo0_l0000[ooooo`;o00003oooool2o`0007Kooooo002A
ooooo`;o00006Oooool00ol0003oooooooooo`03ooooo`;o0000:oooool2o`0000kooooo0ol0001f
ooooo`00TOooool2o`000003ooooool0003o000001Kooooo00?o0000ooooooooool01?ooool2o`00
03[ooooo0_l0001gooooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool01?ooool2o`000;?o
oooo0022ooooo`;o00000_ooool2o`0002Cooooo00?o0000ooooooooool06?ooool2o`0002Oooooo
0_l000000ooooooo0000o`00001cooooo`00P_ooool2o`0000;ooooo0_l0000Tooooo`;o000000?o
ooooo`000?l000005_ooool2o`0002Oooooo1Ol0001cooooo`00Q_ooool2o`0000;ooooo0_l0000P
ooooo`Go0000@Oooool2o`0007Cooooo0026ooooo`;o00000_ooool2o`00023ooooo00?o0000oooo
ooooool04?ooool2o`000:Oooooo002Hooooo`;o00004_ooool00ol0003oooooooooo`0:ooooo`;o
00001?ooool3o`00013ooooo0_l0000<ooooo`;o0000Q_ooool009Sooooo0_l0000@ooooo`?o0000
3?ooool2o`0000Gooooo0ol0000?ooooo`;o00003?ooool2o`0008Kooooo002Booooo`;o00005_oo
ool5o`0000Kooooo0_l0000:ooooo`;o0000YOooool008Wooooo00Cok^k^oc8b<_l0003o<S8b0_l0
0003ooooo`;o000000?o8B4Qooooooooool00_ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8b
omgMg@05ooooo`?o00001_ooool2o`000;7ooooo0029ooooo`04ogMgMonHV9SooooooiRHV0;o0000
1?ooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A002ooooo`;o00000oooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo05cooooo0_l0001Kooooo`00POooool6o`0000;ooooo
00Co410@oooooooooooooooo0_l0000;ooooo`03oiRHV?lQ8B7ok^k^00?ooooo0_l00004ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0G?ooool2o`0005_ooooo0029ooooo`04o`00
0?ooooooooooooooo`;o00002_ooool2o`000003oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_oo
ool01?ooool3o`0000?ooooo0_l00007ooooo`;o00009Oooool2o`0008Cooooo0029ooooo`04o`00
0?ooooooooooooooo`;o00002?ooool4o`000003oooooomgMgOoIVIV00Cooooo00Go0000ob4Q8Ol0
003o<S8bolc<c005ooooo`03o`000?oooooooooo00?ooooo0_l00007ooooo`;o00009Oooool2o`00
08Cooooo0029ooooo`04oa0@4?ooooooooooooooo`;o00002?ooool2o`0000Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo0_l0000Coooo
o`;o00005_ooool3o`0008;ooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04
ooooo`;o000000?oooooo`000?l000004oooool2o`0001Kooooo0ol00022ooooo`00ROooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_oo
ool00ol0003oooooooooo`04ooooo`;o0000/oooool00:cooooo00Co0000oooooooooooooooo0_l0
002fooooo`00[?ooool01?l0003oooooooooooooool2o`0004Kooooo0_l0001^ooooo`00Soooool2
o`0001_ooooo00?o0000ooooooooool0=_ooool2o`00013ooooo0ol0001^ooooo`00Soooool2o`00
01_ooooo0ol0000eooooo`?o00004?ooool2o`0006oooooo002/ooooo`03o`000?oooooooooo03Go
oooo0_l00022ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`0Xooooo`;o00008?ooool2o`0006gooooo002Iooooo`;o00004Oooool00ol0003oooooooooo`0X
ooooo`;o00008?ooool2o`0006gooooo002Iooooo`;o00004Oooool00ol0003oooooooooo`2ioooo
o`00UOooool2o`0001Gooooo00?o0000ooooooooool07oooool2o`0001Kooooo0_l00020ooooo`00
UOooool2o`0001Gooooo00?o0000ooooooooool02_ooool2o`0001?ooooo0_l0000Fooooo`;o0000
P?ooool008Gooooo0_l00007ooooo`;o00007?ooool3o`0000[ooooo0_l00004ooooo`;o00009ooo
ool2o`0007kooooo0025ooooo`;o00001oooool2o`0001cooooo00?o0000ooooooooool04?ooool2
o`0000Cooooo0_l0000Qooooo`;o0000O_ooool0093ooooo0_l00005ooooo`;o00004oooool00ol0
003oooooooooo`0Fooooo`;o0000XOooool008Sooooo0_l00006ooooo`;o00001Oooool2o`0001?o
oooo00?o0000ooooooooool03?ooool2o`0001;ooooo0_l0002Gooooo`00R?ooool2o`0002;ooooo
00?o0000ooooooooool03?ooool2o`0001;ooooo0_l0000Fooooo`;o0000Ooooool009Cooooo0_l0
000Fooooo`03o`000?oooooooooo03Sooooo0_l0000@ooooo`;o0000KOooool008_ooooo0_l00007
ooooo`;o00005_ooool00ol0003oooooooooo`0Hooooo`;o00004?ooool3o`0001gooooo0_l0001]
ooooo`00Roooool2o`0001oooooo00?o0000ooooooooool03?ooool2o`0000?ooooo0_l00005oooo
o`;o00004?ooool3o`0008cooooo0020ooooo`;o0000:_ooool00ol0003oooooooooo`0<ooooo`;o
00000oooool2o`0003Sooooo0_l0001/ooooo`00P?ooool2o`0002[ooooo0ol0000Aooooo`;o0000
9Oooool2o`00017ooooo0_l0001/ooooo`00P?ooool2o`0000?ooooo0_l00007ooooo`;o00007?oo
ool00ol0003oooooooooo`0Aooooo`;o00001Oooool2o`0001kooooo1?l0001mooooo`00P?ooool2
o`0000?ooooo0_l00007ooooo`;o00007?ooool00ol0003oooooooooo`0Aooooo`;o00001Oooool2
o`00023ooooo0_l0001mooooo`002Oooool4o`000003oa0@4?oooooooooo01Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o
0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Kooooo00?o0000ooooooooool06?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo0_l000000olQ8B7oooooooooo`02ooooo`Go00001?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo0_l00009ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb
<S;ogMgM01Sooooo1?l000000ol@413oooooooooo`0Booooo`002oooool00ol0003oooooooooo`0H
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01ooo
ool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`0Eooooo`03o`000?oooooooooo
01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`;o000000?o8B4Qooooooooool00_ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool00oooool3o`0000Sooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo
<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo0006o`0000Gooooo00?o0000ooooooooool0
4?ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00So
oooo00?o0000ooooooooool01Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@oooo
o`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41001?ooool2
o`0000Kooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo017ooooo0_l00005ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^
kP02o`0000Oooooo00?o0000ooooooooool00oooool2o`0000Sooooo00Go410@oooooooooooooooo
oa0@400@ooooo`03o`000?oooooooooo00gooooo00Go410@oooooooooooooooooa0@400=ooooo`03
ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Dooooo`00
2oooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7o
ooooooooo`06ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`000004ooooo`;o00001oooool0
0onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo01Gooooo00?o0000ooooooooool04Oooool2
o`0000Gooooo00Go0000ooooooooooooooooo`000003ooooo`;o00002?ooool01?nHV9So8B4Qo`00
0?l00006ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000?ooooo`03
ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo
00Kooooo00?oMgMgoc8b<_ooool06Oooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003o
ooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOo
IVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05_ooool00ol0003oooooooooo`0Hoooo
o`05o`000?ooooooooooooooool000000oooool2o`0000Wooooo0_l00004ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000?ooooo0_l00007ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<
c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[ooooo00?o0000ooooooooool05?ooool0
00_ooooo00?o0000ooooooooool06?ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41000oooool2o`0000[ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02o`0001Kooooo0ol0000Hooooo`05oa0@
4?ooooooooooooooool@41003_ooool4o`0000;ooooo00?o0000ooooooooool01_ooool2o`0000Wo
oooo00Go410@oooooooooooooooooa0@4003ooooo`;o00001oooool00ol0003oooooooooo`0Aoooo
o`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oo
oooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`;o00001_ooool01Ol0003o^[ZjoooooonHV9So410@
00Cooooo00?o0000ooooooooool00_l0000Fooooo`03o`000?oooooooooo00Gooooo0_l0000Aoooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00;o00000_oo
ool00ol0003oooooooooo`06ooooo`;o00002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo
00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooo
oooooooooc8b<P04ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05?ooool000Wo
oooo00?oEEEEofIVI_l000006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004oooo
o`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01oooool2o`0000;ooooo00?oV9RHoa0@4?l000000_l00004ooooo`Co00005ooo
ool00ol0003oooooooooo`05ooooo`;o00004Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000I
ooooo`03oeEEEOmVIVKo000001Kooooo0024ooooo`;o00001Oooool2o`0001oooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
[_ooool2o`0000;ooooo0_l00005ooooo`00[?ooool00ol0003oooooooooo`1;ooooo`;o0000HOoo
ool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Gooooo002/ooooo`03o`000?oooooooooo04_ooooo
0_l0001Rooooo`04omgMgOl0003o410@olc<c0Kooooo0007oooooooo0000C?l0000<ooooo`04onk^
k_lQ8B7o410@onk^kPKooooo0007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`02o`0000?ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`02ooooo`;o000000?oooooo`000?ooool01_ooool00ol0003oooooooooo`03o`0000;ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool02_ooool01?lQ8B7oMgMgogMgMolb<S86ooooo`001oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo00Gooooo0_l0000Pooooo`03o`000?oooooooooo00;ooooo
0_l0000<ooooo`;o00005?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool02Oooool2o`0000;ooooo0_l00005ooooo`00R?ooool2o`0002;ooooo00?o
0000ooooooooool01Oooool2o`000;;ooooo0020ooooo`;o00001_ooool2o`0000Sooooo0_l0000H
ooooo`03o`000?oooooooooo0;Wooooo0020ooooo`;o00004?ooool2o`0001Sooooo00?o0000oooo
ooooool03Oooool2o`0002cooooo0_l0001looooo`00S_ooool6o`0001Sooooo00?o0000oooooooo
ool03Oooool2o`0001?ooooo0_l0000Gooooo`;o0000O?ooool0083ooooo0_l0000<ooooo`Ko0000
6?ooool00ol0003oooooooooo`0Rooooo`;o0000:_ooool2o`0006Wooooo0020ooooo`;o0000:_oo
ool3o`0001?ooooo0_l00004ooooo`;o0000<oooool2o`0006Wooooo002/ooooo`03o`000?oooooo
oooo01?ooooo0_l00004ooooo`;o00008Oooool2o`0007_ooooo0021ooooo`;o0000:Oooool00ol0
003oooooooooo`0Iooooo`;o00008Oooool2o`0007_ooooo0021ooooo`;o0000:Oooool00ol0003o
ooooooooo`02ooooo`;o00001?ooool2o`0000oooooo0_l0002Nooooo`00[?ooool00ol0003ooooo
ooooo`02ooooo`;o00001?ooool2o`0001Sooooo0_l0000Gooooo`;o00004?ooool2o`0006[ooooo
002/ooooo`03o`000?oooooooooo02;ooooo0_l0000Gooooo`;o00004?ooool2o`0006[ooooo002/
ooooo`03o`000?oooooooooo0;Wooooo002Fooooo`;o00005?ooool00ol0003oooooooooo`0Ioooo
o`;o0000<oooool2o`0006Wooooo0028ooooo`;o00003?ooool2o`0001Cooooo00?o0000oooooooo
ool02?ooool2o`0000;ooooo0_l0000;ooooo`;o00001oooool2o`0000Sooooo0_l0000Pooooo`;o
0000JOooool008Sooooo0_l000000ooooooo0000o`000004ooooo`;o00006Oooool3o`0000Sooooo
0_l00002ooooo`;o00005?ooool2o`0000Sooooo0_l0002;ooooo`00Roooool2o`000004ooooool0
003o0000ooooo`;o00006Oooool00ol0003oooooooooo`0Pooooo`;o0000Uoooool008kooooo0_l0
000Looooo`03o`000?oooooooooo023ooooo0_l0002Gooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00UOooool2o`0001Gooooo00?o0000ooooooooool0C?ooool2o`0006_ooooo002Eooooo`;o
00005Oooool00ol0003oooooooooo`0Aooooo`;o00001Oooool2o`00023ooooo0_l0000@ooooo`?o
0000J_ooool007cooooo0_l0000^ooooo`03o`000?oooooooooo017ooooo0_l00005ooooo`;o0000
8?ooool2o`00017ooooo0_l0001Zooooo`00O?ooool2o`0002kooooo00?o0000ooooooooool06?oo
ool2o`0001oooooo0_l0001nooooo`00[?ooool3o`0003Wooooo0_l0001nooooo`00[?ooool5o`00
02Sooooo0_l0002=ooooo`00[?ooool5o`0002Sooooo0ol0002<ooooo`00[?ooool00ol0003ooooo
ooooo`0Aooooo`;o00006?ooool2o`0000_ooooo1?l0001mooooo`00[?ooool00ol0003ooooooooo
o`06ooooo`;o00002Oooool2o`0002Gooooo1?l0000@ooooo`;o0000Joooool00:cooooo00?o0000
ooooooooool01_ooool2o`0001Oooooo0_l0000Gooooo`;o00004_ooool2o`0006_ooooo002/oooo
o`03o`000?oooooooooo01oooooo0_l00008ooooo`Co00002oooool2o`0007oooooo002/ooooo`03
o`000?oooooooooo00oooooo0_l0000>ooooo`;o00002?ooool4o`0001gooooo0_l0001]ooooo`00
[?ooool3o`0000oooooo0ol0000=ooooo`;o00002Oooool2o`0000gooooo0_l0000?ooooo`;o0000
KOooool00:_ooooo0_l000000ooooooo0000o`00000>ooooo`?o00003Oooool2o`0000Wooooo0_l0
000=ooooo`;o0000O_ooool00:_ooooo0_l000000ooooooo0000o`00001;ooooo`;o0000Joooool0
08oooooo0_l0000Kooooo`03o`000?oooooooooo04cooooo0_l0001[ooooo`00OOooool2o`00013o
oooo0_l0000>ooooo`;o00002oooool00ol0003oooooooooo`0gooooo`;o0000P?ooool007gooooo
0_l0000Pooooo`;o00002oooool00ol0003oooooooooo`0gooooo`;o0000P?ooool008Wooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool02?ooool2o`00023ooooo0_l0000<ooooo`;o00003oooool2o`00
06kooooo0029ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09oooo
o`03o`000?oooooooooo00?ooooo0ol00008ooooo`;o00002oooool2o`00017ooooo1?l0000<oooo
o`;o00003oooool2o`0006kooooo0029ooooo`05o`000?ooooooooooooooool000003Oooool00onH
V9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool05Oooool2o`00
00Kooooo0_l00009ooooo`;o0000Soooool008Wooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo01gooooo0_l0000Fooooo`;o00004Oooool2o`0006oooooo0029ooooo`05oa0@4?oooooooooo
ooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo0_l00002
ooooo`03o`000?oooooooooo03Gooooo0_l0000Aooooo`;o0000Koooool008Wooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`02ooooo`;o000000?oooooo`000?l000001?ooool01Ol0003o^[ZjoooooonH
V9So410@00Cooooo00?o0000ooooooooool00oooool2o`0000;ooooo00?o0000ooooooooool0^Ooo
ool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`;o000000?oooooo`000?l000001?oo
ool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo00?ooooo
0_l0000Hooooo`;o00002?ooool3o`0008oooooo002/ooooo`03o`000?oooooooooo00?ooooo0_l0
000Hooooo`;o00002?ooool3o`0008oooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo01;ooooo0_l00008ooooo`;o0000Voooool0097ooooo0_l0000Iooooo`?o
00004_ooool2o`0000Sooooo0_l0002Kooooo`00TOooool2o`0001Wooooo00?o0000ooooooooool0
7?ooool2o`0009_ooooo002Jooooo`;o00004?ooool00ol0003oooooooooo`06ooooo`;o00007Ooo
ool2o`00027ooooo0_l0001_ooooo`00V_ooool2o`00013ooooo00?o0000ooooooooool01_ooool2
o`0001gooooo0_l0000=ooooo`;o00004?ooool4o`0006oooooo002Aooooo`;o00006Oooool00ol0
003oooooooooo`0Booooo`;o00001_ooool2o`0000[ooooo0_l0000<ooooo`;o00004?ooool3o`00
073ooooo002Aooooo`;o00005?ooool2o`0000?ooooo0_l0000Cooooo`;o00001Oooool3o`0000[o
oooo0_l0002Aooooo`00Qoooool2o`0001kooooo0_l00002ooooo`?o00001Oooool2o`0001?ooooo
0_l0000:ooooo`;o0000T_ooool008Oooooo0_l00005ooooo`;o00006oooool2o`0000Kooooo0_l0
000Nooooo`?o0000T_ooool008kooooo0_l0000<ooooo`;o00003_ooool3o`00017ooooo0_l0000A
ooooo`;o0000Toooool009cooooo0_l0000>ooooo`03o`000?oooooooooo017ooooo0_l0002Voooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00S?ooool2o`0000Sooooo0_l000000ooooooo0000
o`00000Aooooo`03o`000?oooooooooo00oooooo0_l0002Xooooo`00S?ooool2o`0000Sooooo0_l0
00000ooooooo0000o`00000Aooooo`03o`000?oooooooooo00oooooo0_l0002Xooooo`00[?ooool0
0ol0003oooooooooo`02ooooo`;o0000]Oooool008Sooooo0_l0000Rooooo`03o`000?oooooooooo
00;ooooo0_l00003ooooo`;o00003_ooool2o`0000Wooooo0_l0002Eooooo`00R?ooool2o`0002;o
oooo00?o0000ooooooooool01oooool2o`0000Gooooo0_l00007ooooo`;o00002Oooool2o`0009Go
oooo002Qooooo`;o00002Oooool3o`0000Oooooo0_l00005ooooo`;o00007_ooool2o`0008Wooooo
002Qooooo`Co00001oooool00ol0003oooooooooo`07ooooo`;o00009Oooool2o`0008Wooooo002S
ooooo`;o00001oooool00ol0003oooooooooo`0Eooooo`;o00006Oooool2o`0008Oooooo002/oooo
o`03o`000?oooooooooo01Gooooo0_l0000Iooooo`;o0000Qoooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool01?ooool2o`000;?ooooo002/ooooo`03o`000?oo
oooooooo00Cooooo0_l0000Hooooo`;o0000VOooool00:cooooo00?o0000ooooooooool01?ooool2
o`0000Cooooo0_l0000Booooo`;o0000VOooool009[ooooo0_l00004ooooo`;o00000oooool2o`00
00Gooooo0ol0000:ooooo`;o0000[Oooool009[ooooo0_l00004ooooo`;o00000oooool2o`0000Go
oooo00?o0000ooooooooool0^Oooool008kooooo0_l0000Looooo`03o`000?oooooooooo0;Wooooo
002>ooooo`;o00007?ooool00ol0003oooooooooo`0[ooooo`;o0000S?ooool00:cooooo00?o0000
ooooooooool0:oooool2o`0008cooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Aooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo013ooooo0_l0002Wooooo`00TOooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00;o00000_ooool00ol0003oooooooooo`0@
ooooo`;o00006?ooool2o`0008gooooo002Aooooo`05oa0@4?ooooooooooooooool@41004?ooool0
1?l0003oooooo`000?l00002ooooo`03o`000?oooooooooo00kooooo0_l0000Jooooo`;o0000SOoo
ool0097ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0
000>ooooo`;o00006Oooool3o`0008gooooo002Aooooo`05o`000?ooooooooooooooool000003?oo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool09oooool5o`0008gooooo
002Aooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo02Oooooo0_l0002@ooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Xooooo`;o0000Soooool0097ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP04ooooo`;o00001_ooool4o`0000Kooooo00?o0000ooooooooool0
1?ooool2o`0000Oooooo0_l0000Iooooo`;o0000Soooool009[ooooo0_l0000@ooooo`03o`000?oo
oooooooo00Cooooo0_l00007ooooo`;o00005_ooool2o`0009;ooooo0027ooooo`;o00008oooool0
0ol0003oooooooooo`02ooooo`;o00008Oooool2o`0009;ooooo0021ooooo`;o00001?ooool2o`00
02?ooooo00?o0000ooooooooool00_ooool2o`0000Kooooo0_l0000;ooooo`;o00007_ooool2o`00
083ooooo0021ooooo`;o0000:Oooool3o`000003ooooool0003o000000Oooooo0_l0000;ooooo`;o
00007Oooool3o`00083ooooo002Gooooo`;o00001Oooool2o`0000Oooooo0_l00003ooooo`04o`00
0?ooooooooooooooo`;o00001oooool2o`0002[ooooo0_l00021ooooo`00Uoooool2o`0000Gooooo
0_l00007ooooo`;o00000oooool00ol0003oooooooooo`0;ooooo`;o00002Oooool2o`000:7ooooo
002Rooooo`Co00001_ooool00ol0003oooooooooo`0;ooooo`;o00001oooool4o`000:7ooooo002B
ooooo`;o00003_ooool4o`0000Kooooo00?o0000ooooooooool05?ooool2o`000:?ooooo002Boooo
o`;o00004?ooool2o`0000Kooooo00?o0000ooooooooool0^Oooool00:7ooooo0_l00009ooooo`03
o`000?oooooooooo01Cooooo0_l0002Sooooo`00XOooool2o`0000Wooooo00?o0000ooooooooool0
5?ooool2o`0000cooooo0_l0002Eooooo`00[?ooool3o`0002;ooooo0_l0002Eooooo`00R?ooool2
o`00017ooooo0_l0000?ooooo`03o`000?oooooooooo0;Wooooo0028ooooo`;o00004Oooool2o`00
00oooooo0_l0000Cooooo`;o0000YOooool008oooooo0_l0000Kooooo`;o00001Oooool2o`0000co
oooo0_l0002Uooooo`00Soooool2o`0001_ooooo00?o0000ooooooooool01?ooool2o`0001Oooooo
0_l0002Jooooo`00ROooool2o`0000Cooooo0_l0000Kooooo`03o`000?oooooooooo01gooooo0_l0
002Jooooo`00ROooool2o`0000Cooooo0_l0000Kooooo`03o`000?oooooooooo00oooooo0_l0002X
ooooo`00X_ooool2o`0000Sooooo00?o0000ooooooooool03Oooool4o`000:Sooooo002@ooooo`;o
00003oooool3o`0000Sooooo0ol0000=ooooo`;o00007oooool2o`0008Wooooo002@ooooo`;o0000
3oooool2o`000003ooooool0003o000000Kooooo00?o0000ooooooooool00_l0000Hooooo`?o0000
4Oooool2o`0008Wooooo002;ooooo`;o00005oooool2o`0000Kooooo00?o0000ooooooooool00_l0
000Hooooo`?o0000W?ooool008_ooooo0_l0000Oooooo`03o`000?oooooooooo00_ooooo0_l0000=
ooooo`;o0000WOooool00:cooooo00?o0000ooooooooool02oooool2o`000:cooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo02cooooo0_l0002;ooooo`00S?oo
ool2o`0000Gooooo0_l0000Gooooo`03o`000?oooooooooo02cooooo0_l0002;ooooo`00S?ooool2
o`0000Gooooo0_l0000Gooooo`03o`000?oooooooooo01Gooooo0_l0002Rooooo`00[?ooool3o`00
01Gooooo0_l0002Rooooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool0^Oooool008gooooo
0_l00005ooooo`;o00005_ooool00ol0003oooooooooo`2iooooo`00SOooool2o`0000oooooo0_l0
0008ooooo`;o00000_ooool00ol0003oooooooooo`2iooooo`00W_ooool2o`000003ooooool0003o
000000;ooooo0_l000000ooooooo0000o`000002ooooo`03o`000?oooooooooo0;Wooooo0029oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool00oooool6
o`0000Gooooo00?o0000ooooooooool0^Oooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool04_ooool2o`000:Gooooo0029ooooo`05oa0@4?ooooooooooooooool@41003Oooool0
0onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l0
000?ooooo`;o0000YOooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooo
oooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`000003ooooool0003o00000;Kooooo0029
ooooo`04o`000?ooooooooooooooo`?o00003?ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool01?l0003oooooooooooooool2o`0000kooooo0_l0002Vooooo`00
ROooool01Ol@413ooooooooooooooooo410@00;o00003?ooool00onYZJWoMgMgooooo`03ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool04Oooool2o`000:Kooooo0029ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`2iooooo`00ROooool3o`000003oc8b<_o^k^kooooo00[o
oooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`2iooooo`00ROooool2o`00027ooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
WOooool2o`0000gooooo00?o0000ooooooooool0^Oooool009gooooo0_l0000=ooooo`03o`000?oo
oooooooo00[ooooo0_l0002]ooooo`00[?ooool00ol0003oooooooooo`08ooooo`Co0000[Oooool0
0:cooooo00?o0000ooooooooool02?ooool3o`000:kooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool00_l0002gooooo`00[?ooool00ol0003ooooooooo
o`02o`000;Oooooo002/ooooo`04o`000?oooooo0000o`000;Sooooo002/ooooo`04o`000?oooooo
0000o`000;Sooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Iooooo`;o00004Oooool3o`00
0;Wooooo002Iooooo`;o00004Oooool00ol0003oooooooooo`2iooooo`00Zoooool2o`000;_ooooo
002[ooooo`;o0000^oooool00:?ooooo1?l00005ooooo`03o`000?oooooooooo0;Wooooo002Soooo
o`Co00001Oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0:ooooo`;o
0000[Oooool00:cooooo00?o0000ooooooooool02_ooool2o`000:gooooo002/ooooo`?o00002Ooo
ool3o`000:gooooo002/ooooo`03o`000?oooooooooo00Wooooo0ol0002]ooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00U?ooool2o`0001Kooooo
00?o0000ooooooooool0^Oooool009Cooooo0_l0000Fooooo`03o`000?oooooooooo0;Wooooo002R
ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`2iooooo`00Y?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`03o`000?oooooooooo00Go
oooo0ol0002iooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003ooooooooo
o`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31oooo
o`00X_ooool00omEEEGoIVIVo`000033ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00Z_ooool01?l@413o0000o`000?l0002jooooo`00Zoooool00ol0003o
ooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool01_l0003oMgMgo`00
0?l0003oEEEEonk^k[Oooooo002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoEEEE]oooool00:_o
oooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`2eooooo`00Zoooool00ol0003ok^k^
ooooo`02ooooo`03o`000?oooooooooo0;Gooooo002[ooooo`06o`000?mEEEGok^k^oooooomgMgOo
IVIV]oooool00:[ooooo00?o410@o`000?mgMgL00_l000000omVIVKok^k^ooooo`2fooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.62274 .34824 Mdot
.64267 .61689 Mdot
.4488 .56926 Mdot
.55135 .49016 Mdot
.56413 .34536 Mdot
.40374 .28518 Mdot
.51703 .47619 Mdot
.38156 .23957 Mdot
.49023 .96773 Mdot
.50208 .2499 Mdot
.56877 .49484 Mdot
.45225 .01849 Mdot
.46018 .92162 Mdot
.55911 .40018 Mdot
.47908 .01351 Mdot
.47244 .7642 Mdot
.60197 .39726 Mdot
.4461 .90768 Mdot
.40903 .57231 Mdot
.63507 .26472 Mdot
.43431 .88242 Mdot
.59563 .75048 Mdot
.5627 .80736 Mdot
.42059 .85177 Mdot
.59868 .13533 Mdot
.48746 .83187 Mdot
.55646 .61403 Mdot
.41655 .64712 Mdot
.6571 .31633 Mdot
.63666 .63433 Mdot
.39581 .72913 Mdot
.49287 .96841 Mdot
.36653 .50807 Mdot
.60986 .57622 Mdot
.5552 .76253 Mdot
.5613 .15726 Mdot
.68259 .62832 Mdot
.47234 .79419 Mdot
.67228 .37406 Mdot
.48218 .00508 Mdot
.60146 .13331 Mdot
.59027 .6741 Mdot
.43233 .82344 Mdot
.63912 .39337 Mdot
.59578 .27584 Mdot
.58964 .56453 Mdot
.54767 .36619 Mdot
.57753 .86549 Mdot
.41937 .25961 Mdot
.64841 .30448 Mdot
.58265 .85637 Mdot
.69278 .45962 Mdot
.36228 .70069 Mdot
.49511 .85961 Mdot
.47844 .87534 Mdot
.40683 .86841 Mdot
.39004 .18797 Mdot
.60162 .39003 Mdot
.6397 .75701 Mdot
.57934 .2437 Mdot
.58269 .60535 Mdot
.74853 .46058 Mdot
.67408 .38655 Mdot
.44199 .68779 Mdot
.36823 .53812 Mdot
.44685 .96106 Mdot
.48762 .23029 Mdot
.49856 .73724 Mdot
.46582 .79462 Mdot
.39383 .72672 Mdot
.6161 .45011 Mdot
.44149 .61208 Mdot
.50956 .26745 Mdot
.4344 .29648 Mdot
.67391 .38608 Mdot
.49948 .40258 Mdot
.36201 .69756 Mdot
.55138 .70435 Mdot
.68734 .42185 Mdot
.40109 .44085 Mdot
.41228 .17565 Mdot
.63889 .62022 Mdot
.54351 .42206 Mdot
.58392 .69496 Mdot
.36674 .56045 Mdot
.45646 .7562 Mdot
.57107 .36741 Mdot
.58505 .4473 Mdot
.58645 .33526 Mdot
.49148 .74881 Mdot
.60513 .14519 Mdot
.61933 .88408 Mdot
.43403 .33624 Mdot
.59148 .49705 Mdot
.42182 .45215 Mdot
.65082 .8407 Mdot
.55507 .3836 Mdot
.57396 .86455 Mdot
.35532 .5972 Mdot
.59236 .34705 Mdot
.6364 .39843 Mdot
.55535 .26037 Mdot
.44884 .02454 Mdot
.64719 .43788 Mdot
.3841 .35911 Mdot
.60482 .60919 Mdot
.6183 .49312 Mdot
.41196 .37865 Mdot
.43582 .32721 Mdot
.39078 .7012 Mdot
.53666 .32487 Mdot
.55126 .4699 Mdot
.50066 .96004 Mdot
.58355 .1819 Mdot
.55056 .00392 Mdot
.46685 .70777 Mdot
.56937 .65679 Mdot
.41429 .90018 Mdot
.44826 .96542 Mdot
.68277 .61056 Mdot
.4621 .92175 Mdot
.73579 .38846 Mdot
.48541 .91345 Mdot
.66265 .3278 Mdot
.39031 .69886 Mdot
.54954 .54805 Mdot
.60495 .21714 Mdot
.68723 .77696 Mdot
.64763 .51756 Mdot
.43576 .37805 Mdot
.56622 .80504 Mdot
.64603 .45721 Mdot
.50219 .02206 Mdot
.41367 .22658 Mdot
.39926 .66886 Mdot
.68083 .38517 Mdot
.69254 .59633 Mdot
.63727 .27521 Mdot
.50329 .25535 Mdot
.37469 .31531 Mdot
.49137 .01683 Mdot
.74548 .57595 Mdot
.51631 .31514 Mdot
.43441 .73991 Mdot
.60269 .39902 Mdot
.6123 .22468 Mdot
.3775 .71512 Mdot
.65481 .11483 Mdot
.42148 .31681 Mdot
.58889 .48556 Mdot
.72628 .34562 Mdot
.54131 .23294 Mdot
.52302 .72741 Mdot
.41479 .83403 Mdot
.45435 .66152 Mdot
.47738 .11484 Mdot
.6951 .55147 Mdot
.68194 .41173 Mdot
.4151 .90025 Mdot
.68133 .62873 Mdot
.69489 .56199 Mdot
.41399 .70415 Mdot
.68876 .42256 Mdot
.59397 .11669 Mdot
.50842 .09157 Mdot
.43691 .8306 Mdot
.62947 .37879 Mdot
.3835 .76033 Mdot
.3999 .22721 Mdot
.47913 .79573 Mdot
.69791 .55159 Mdot
.62089 .25194 Mdot
.45174 .28169 Mdot
.5123 .74611 Mdot
.56972 .36911 Mdot
.44222 .2326 Mdot
.3672 .47397 Mdot
.663 .82043 Mdot
.46646 .11764 Mdot
.47955 .70476 Mdot
.66225 .33516 Mdot
.69909 .50464 Mdot
.52659 .044 Mdot
.41436 .51095 Mdot
.61436 .15006 Mdot
.5079 .33251 Mdot
.50442 .95183 Mdot
.68937 .77008 Mdot
.50299 .96108 Mdot
.58095 .10178 Mdot
.41111 .74798 Mdot
.71887 .33612 Mdot
.61242 .22422 Mdot
.48919 .72534 Mdot
.74181 .43037 Mdot
.36766 .40383 Mdot
.6581 .21006 Mdot
.47186 .00884 Mdot
.58889 .46362 Mdot
.5595 .96248 Mdot
.61525 .58103 Mdot
.51991 .58962 Mdot
.51606 .61036 Mdot
.43455 .55222 Mdot
.55471 .32359 Mdot
.52523 .99945 Mdot
.64012 .42375 Mdot
.53672 .54423 Mdot
.42685 .18064 Mdot
.55162 .45895 Mdot
.53522 .43899 Mdot
.56978 .51837 Mdot
.53142 .86743 Mdot
.55848 .68605 Mdot
.4018 .21717 Mdot
.42352 .63535 Mdot
.63282 .39276 Mdot
.57028 .64616 Mdot
.59931 .12422 Mdot
.51441 .3481 Mdot
.55572 .20827 Mdot
.45169 .01558 Mdot
.57373 .64213 Mdot
.62902 .77292 Mdot
.38874 .30466 Mdot
.44389 .09359 Mdot
.45032 .73774 Mdot
.51819 .24139 Mdot
.65024 .58314 Mdot
.44476 .29793 Mdot
.48351 .0142 Mdot
.74217 .40754 Mdot
.51575 .70098 Mdot
.44019 .44687 Mdot
.48208 .1556 Mdot
.55899 .60841 Mdot
.72734 .36315 Mdot
.49326 .78215 Mdot
.65131 .46894 Mdot
.49155 .91239 Mdot
.64378 .43822 Mdot
.74767 .46105 Mdot
.38936 .50379 Mdot
.44833 .07985 Mdot
.61578 .44791 Mdot
.48651 .9749 Mdot
.42195 .53257 Mdot
.6929 .53281 Mdot
.55534 .271 Mdot
.61466 .43918 Mdot
.67666 .3924 Mdot
.6483 .19624 Mdot
.47172 .70968 Mdot
.49043 .72126 Mdot
.69002 .5651 Mdot
.47844 .83366 Mdot
.52065 .72711 Mdot
.44676 .8586 Mdot
.50613 .4427 Mdot
.38002 .25783 Mdot
.60886 .81629 Mdot
.44882 .17405 Mdot
.55948 .60627 Mdot
.46714 .07023 Mdot
.42954 .55846 Mdot
.53108 .21757 Mdot
.60414 .30268 Mdot
.55499 .39812 Mdot
.39074 .47515 Mdot
.58967 .19963 Mdot
.4327 .77603 Mdot
.58103 .182 Mdot
.45907 .87076 Mdot
.50046 .24506 Mdot
.41526 .28827 Mdot
.69631 .54409 Mdot
.41492 .44946 Mdot
.47143 .18818 Mdot
.56616 .87942 Mdot
.5707 .49981 Mdot
.46037 .11957 Mdot
.67319 .3656 Mdot
.44718 .31895 Mdot
.417 .43112 Mdot
.68083 .62772 Mdot
.42612 .06212 Mdot
.41548 .3454 Mdot
.4936 .66136 Mdot
.50729 .22778 Mdot
.54925 .13254 Mdot
.59023 .52146 Mdot
.39355 .27766 Mdot
.68915 .76912 Mdot
.64685 .73747 Mdot
.44018 .0394 Mdot
.64281 .74183 Mdot
.48947 .34098 Mdot
.66034 .71233 Mdot
.73222 .39636 Mdot
.51052 .08487 Mdot
.46401 .01618 Mdot
.69722 .16948 Mdot
.40376 .3778 Mdot
.40278 .70618 Mdot
.64853 .47281 Mdot
.48771 .97329 Mdot
.58831 .1194 Mdot
.55685 .40043 Mdot
.57007 .87241 Mdot
.46097 .82948 Mdot
.52566 .47157 Mdot
.53682 .85756 Mdot
.60825 .42612 Mdot
.4785 .92326 Mdot
.71698 .32235 Mdot
.45177 .68322 Mdot
.57455 .24128 Mdot
.60148 .62829 Mdot
.36913 .41954 Mdot
.42733 .52067 Mdot
.53535 .05408 Mdot
.6963 .2941 Mdot
.74113 .62541 Mdot
.53438 .63966 Mdot
.41842 .20446 Mdot
.58068 .70592 Mdot
.68358 .42904 Mdot
.52611 .25387 Mdot
.52626 .54948 Mdot
.50759 .40206 Mdot
.61581 .46404 Mdot
.41989 .0715 Mdot
.68954 .55376 Mdot
.42104 .46962 Mdot
.56432 .81426 Mdot
.44331 .33741 Mdot
.43394 .54092 Mdot
.64853 .59324 Mdot
.39614 .34739 Mdot
.43506 .82649 Mdot
.41399 .70357 Mdot
.54486 .29975 Mdot
.38698 .87275 Mdot
.46236 .82824 Mdot
.64376 .58326 Mdot
.44068 .68122 Mdot
.37584 .68712 Mdot
.56126 .58626 Mdot
.62866 .25914 Mdot
.6232 .67365 Mdot
.47907 .25109 Mdot
.58455 .56902 Mdot
.74649 .5713 Mdot
.44471 .02608 Mdot
.66342 .70815 Mdot
.57536 .17628 Mdot
.39882 .47565 Mdot
.61575 .56298 Mdot
.61388 .23773 Mdot
.50811 .18216 Mdot
.44324 .02847 Mdot
.74006 .6418 Mdot
.45924 .06835 Mdot
.49617 .0169 Mdot
.54478 .06448 Mdot
.61391 .14583 Mdot
.43941 .3948 Mdot
.45441 .16812 Mdot
.49496 .02 Mdot
.38312 .23248 Mdot
.44619 .35794 Mdot
.38091 .43435 Mdot
.46336 .82606 Mdot
.43236 .16312 Mdot
.6324 .38225 Mdot
.55565 .88987 Mdot
.65055 .46444 Mdot
.67278 .66946 Mdot
.68999 .49861 Mdot
.57222 .78998 Mdot
.67456 .67786 Mdot
.57469 .78869 Mdot
.56894 .09832 Mdot
.5941 .04625 Mdot
.67422 .6474 Mdot
.49637 .12384 Mdot
.4679 .67953 Mdot
.66979 .23994 Mdot
.58097 .31814 Mdot
.50244 .37964 Mdot
.53812 .05503 Mdot
.39048 .70125 Mdot
.52761 .53641 Mdot
.45083 .2487 Mdot
.52694 .76621 Mdot
.55127 .64118 Mdot
.56345 .88609 Mdot
.39682 .23935 Mdot
.73881 .42081 Mdot
.53531 .05313 Mdot
.61554 .50744 Mdot
.41058 .95519 Mdot
.61601 .54145 Mdot
.43552 .25111 Mdot
.46737 .19278 Mdot
.46229 .64981 Mdot
.40873 .10641 Mdot
.44626 .02544 Mdot
.55847 .60439 Mdot
.47167 .25382 Mdot
.55825 .62594 Mdot
.4294 .67791 Mdot
.69345 .27307 Mdot
.59138 .47665 Mdot
.50555 .08668 Mdot
.52708 .34886 Mdot
.51767 .73846 Mdot
.42755 .47477 Mdot
.58451 .42486 Mdot
.61259 .54712 Mdot
.54641 .66374 Mdot
.53352 .57518 Mdot
.73141 .36717 Mdot
.37295 .3348 Mdot
.50215 .52846 Mdot
.54159 .78888 Mdot
.61821 .49354 Mdot
.51859 .15722 Mdot
.44202 .7967 Mdot
.50059 .77117 Mdot
.67535 .24713 Mdot
.62552 .88102 Mdot
.65173 .4938 Mdot
.64569 .42024 Mdot
.52351 .63144 Mdot
.46314 .96852 Mdot
.50743 .03249 Mdot
.56812 .51618 Mdot
.62204 .67417 Mdot
.37887 .83029 Mdot
.48373 .25621 Mdot
.52668 .46576 Mdot
.46323 .19916 Mdot
.46161 .07216 Mdot
.40146 .56637 Mdot
.58757 .92765 Mdot
.52438 .38677 Mdot
.53182 .80162 Mdot
.59471 .66366 Mdot
.42281 .56504 Mdot
.45676 .69193 Mdot
.42438 .3454 Mdot
.38259 .23292 Mdot
.43522 .61847 Mdot
.68332 .39956 Mdot
.64993 .57152 Mdot
.58977 .26713 Mdot
.59283 .1985 Mdot
.38217 .4104 Mdot
.61405 .46794 Mdot
.69068 .77529 Mdot
.46103 .2327 Mdot
.42639 .05553 Mdot
.6477 .19401 Mdot
.55512 .40111 Mdot
.66122 .71185 Mdot
.43708 .78644 Mdot
.58876 .35487 Mdot
.62602 .25345 Mdot
.63761 .401 Mdot
.40705 .49698 Mdot
.58414 .57451 Mdot
.61112 .57277 Mdot
.75125 .45757 Mdot
.40291 .69328 Mdot
.49432 .38028 Mdot
.45229 .85847 Mdot
.40263 .40486 Mdot
.43626 .41783 Mdot
.52537 .66759 Mdot
.50317 .84902 Mdot
.40406 .70855 Mdot
.49863 .67714 Mdot
.50203 .80888 Mdot
.4424 .95529 Mdot
.55965 .33029 Mdot
.59012 .27259 Mdot
.4501 .78052 Mdot
.41774 .65054 Mdot
.47807 .30587 Mdot
.48789 .31414 Mdot
.64575 .60499 Mdot
.62405 .77834 Mdot
.51723 .10118 Mdot
.45119 .77877 Mdot
.64835 .29968 Mdot
.50092 .01844 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0=ooooo`;o0000Z_ooool00:Cooooo00Co0000ooooool0003o00001?ooool00ol0003o
ooooooooo`0=ooooo`;o0000Z_ooool00:;ooooo0ol000000ooooooo0000o`000004ooooo`03o`00
0?oooooooooo0;Wooooo002Rooooo`Go00001Oooool00ol0003oooooooooo`2iooooo`00W?ooool2
o`0000;ooooo0_l000000omEEEGoIVIVo`000003o`000005ooooool0003o0000ooooool00000^ooo
ool009cooooo0_l00002ooooo`;o00001?ooool2o`000003ooooool0003o000000?o0000^_ooool0
09cooooo0_l0000<ooooo`Co0000^_ooool009[ooooo0ol0000=ooooo`Go0000^Oooool009Wooooo
1?l0000?ooooo`03o`000?oooooooooo0;Wooooo002Iooooo`;o00004Oooool00ol0003ooooooooo
o`2iooooo`00[?ooool01?l0003oooooo`000?l0002hooooo`00[?ooool01?l0003oooooo`000?l0
002hooooo`00V?ooool2o`0001;ooooo00?o0000ooooooooool0^Oooool009Sooooo0_l0000Boooo
o`03o`000?oooooooooo00Gooooo0_l0002booooo`00[?ooool00ol0003oooooooooo`05ooooo`;o
00005Oooool2o`0009_ooooo002/ooooo`03o`000?oooooooooo01cooooo0_l0002Kooooo`00[?oo
ool3o`0000Sooooo0_l0002_ooooo`00Toooool2o`0001Oooooo00?o0000ooooooooool02?ooool3
o`000:kooooo002Cooooo`;o00005oooool00ol0003oooooooooo`08ooooo`?o0000[_ooool009?o
oooo0_l0000Gooooo`03o`000?oooooooooo0;Wooooo002Cooooo`;o00005oooool00ol0003ooooo
ooooo`0;ooooo`;o0000[?ooool00:cooooo00?o0000ooooooooool02oooool2o`000:cooooo002N
ooooo`;o000000?oooooo`000?l000002Oooool00ol0003oooooooooo`2iooooo`00TOooool2o`00
00_ooooo1Ol00009ooooo`03o`000?oooooooooo0;Wooooo002Aooooo`;o00003?ooool2o`0000_o
oooo0ol0002iooooo`00Voooool2o`0000oooooo00?o0000ooooooooool0^Oooool009_ooooo0_l0
000?ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00;o0000]oooool0
0:cooooo1Ol0002gooooo`00[?ooool4o`000;Sooooo002Iooooo`;o00004Oooool01?l0003ooooo
o`000?l0002hooooo`00VOooool2o`00017ooooo00?o0000ooooooooool04oooool2o`000:Cooooo
002/ooooo`?o00000_ooool2o`0000oooooo0_l0002Tooooo`00[?ooool00ol0003oooooooooo`02
ooooo`;o00004oooool2o`000:3ooooo002=ooooo`;o00007Oooool00ol0003oooooooooo`0Goooo
o`;o0000X?ooool008gooooo0_l0000Mooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002Tooooo`;o00001_ooool00ol0003oooooooooo`0Looooo`;o00004_oo
ool2o`0008Oooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o
0000onk^k_ooool01?l000001Om4A4Co0000o`000?l0003ogMgM00Gooooo00?o0000ooooooooool0
6_ooool4o`0001;ooooo0_l00027ooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Co00000oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo01[ooooo0_l0002Mooooo`00POooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00Co0000oooooooooooooooo1Ol0000Mooooo`;o
0000V_ooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Ko
oooo00?oMgMgoc8b<_ooool00_ooool3o`0001oooooo0_l0002Jooooo`00ROooool01Ol0003ooooo
oooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool0^Oooool008Wooooo00Go410@oooooooooooooooooa0@400>oooo
o`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0=oooo
o`;o00003oooool2o`0009Wooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@
413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0=
ooooo`;o00003_ooool3o`0009Wooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5
o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo01gooooo0_l0002Jooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0Oooooo`;o000000?oooooo`000?l0
0000UOooool00:cooooo00?o0000ooooooooool07oooool2o`000003ooooool0003o000009Gooooo
002/ooooo`?o00008_ooool2o`0009Gooooo002Vooooo`;o00001?ooool00ol0003oooooooooo`2i
ooooo`00Y_ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000cooooo0_l0002Voooo
o`00[?ooool00ol0003oooooooooo`03ooooo`;o00003?ooool2o`000:Kooooo002Eooooo`;o0000
5Oooool00ol0003oooooooooo`2iooooo`00UOooool2o`0000Kooooo0_l0000=ooooo`03o`000?oo
oooooooo0;Wooooo002Mooooo`;o00003Oooool00ol0003oooooooooo`0nooooo`;o0000NOooool0
09_ooooo0_l0000?ooooo`03o`000?oooooooooo03kooooo0_l0001iooooo`00Soooool2o`0000[o
oooo0_l0000?ooooo`?o00005Oooool2o`000:;ooooo002?ooooo`;o00006oooool00ol0003ooooo
ooooo`0Eooooo`;o0000X_ooool009?ooooo0_l0000Gooooo`04o`000?oooooo0000o`0001Kooooo
0ol0002Oooooo`00Toooool2o`0001Oooooo00Co0000ooooool0003o00005_ooool3o`0009oooooo
0027ooooo`;o00006Oooool2o`0000Sooooo00?o0000ooooooooool0^Oooool008Oooooo0_l0000I
ooooo`;o00002?ooool00ol0003oooooooooo`2iooooo`00XOooool2o`0000Wooooo00?o0000oooo
ooooool0;Oooool2o`0008[ooooo002Qooooo`;o00002Oooool00ol0003oooooooooo`0Kooooo`;o
00004?ooool3o`0008Wooooo002Oooooo`;o00002oooool3o`0001[ooooo0ol0000Aooooo`;o0000
ROooool0097ooooo0_l0000<ooooo`;o00002oooool00ol0003oooooooooo`0Jooooo`;o0000WOoo
ool0097ooooo0_l0000Iooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
00oooooo0_l0000Pooooo`;o0000Q_ooool00:cooooo00?o0000ooooooooool03oooool2o`00023o
oooo0_l00026ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00Roooool2o`0001oooooo00?o
0000ooooooooool01oooool2o`0001Kooooo0_l0002Hooooo`00Roooool2o`0001oooooo00?o0000
ooooooooool01oooool2o`0001Kooooo0_l0002Hooooo`00[?ooool3o`0002;ooooo0_l0002Eoooo
o`00Roooool2o`0000;ooooo0_l0000Kooooo`04o`000?oooooo0000o`00027ooooo0_l0002Eoooo
o`00Roooool2o`0000;ooooo0_l0000Fooooo`;o00000oooool01?l0003oooooo`000?l0002hoooo
o`00QOooool2o`00017ooooo0_l00005ooooo`;o00001_ooool2o`0000?ooooo00?o0000oooooooo
ool02_ooool2o`000:gooooo0025ooooo`;o00004Oooool2o`0000Gooooo0_l0000;ooooo`03o`00
0?oooooooooo00[ooooo0_l0000Fooooo`;o0000UOooool008Cooooo0_l00004ooooo`;o00008?oo
ool00ol0003oooooooooo`0Rooooo`;o00004Oooool2o`0008;ooooo0024ooooo`;o00001?ooool2
o`0000Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Gooooo00?o0000ooooooooool00oooool2o`00013ooooo1?l0000Looooo`;o0000
P_ooool0097ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8b
ooooo`04ooooo`;o00001?ooool2o`00013ooooo1?l0002Pooooo`00ROooool6o`0000;ooooo00Go
410@oooooooooooooooooa0@4005ooooo`;o00002Oooool00ol0003oooooooooo`03ooooo`;o0000
=oooool2o`00087ooooo002Aooooo`04o`000?ooooooooooooooo`?o00000oooool2o`0000Sooooo
0_l00005ooooo`?o00009?ooool2o`00013ooooo0_l00021ooooo`00TOooool01?l0003ooooooooo
ooooool3o`0000[ooooo1Ol00005ooooo`?o00001Oooool2o`0001gooooo1?l0002Aooooo`00Q?oo
ool2o`0000_ooooo00Go410@oooooooooooooooooa0@400<ooooo`;o00000_ooool2o`0000Cooooo
0ol00005ooooo`;o00007oooool3o`00093ooooo0024ooooo`;o00002oooool2o`000003oooooonH
V9SoMgMg00cooooo00Co0000oooooooooooooooo0_l00004ooooo`03o`000?oooooooooo00oooooo
0_l0000Fooooo`;o0000T?ooool0097ooooo0ol000000olb<S;ok^k^ooooo`0;ooooo`Co00001_oo
ool00ol0003oooooooooo`0?ooooo`;o00006?ooool2o`0008kooooo002/ooooo`03o`000?oooooo
oooo00;o00006?ooool2o`0000gooooo0_l0002>ooooo`00[?ooool00ol0003oooooooooo`02o`00
00gooooo0_l00009ooooo`;o0000WOooool00:cooooo00?o0000ooooooooool03oooool2o`0000Wo
oooo0_l0000Pooooo`;o0000Noooool00:cooooo0ol0000Jooooo`Co00003?ooool2o`00013ooooo
0_l0001kooooo`00R?ooool2o`0002;ooooo00?o0000ooooooooool07?ooool2o`0000cooooo0_l0
002=ooooo`00R?ooool2o`0001;ooooo0_l0000>ooooo`03o`000?oooooooooo0;Wooooo002<oooo
o`;o00003_ooool2o`0000kooooo00?o0000ooooooooool0^Oooool008cooooo0_l00002ooooo`;o
00006_ooool00ol0003oooooooooo`2iooooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0?Oooool2o`0007[ooooo002Fooooo`;o000000?ooooo
o`000?l000004Oooool00ol0003oooooooooo`0mooooo`;o0000N_ooool009Kooooo0_l000000ooo
oooo0000o`00000Aooooo`?o00002oooool2o`00027ooooo0_l00029ooooo`00[?ooool00ol0003o
ooooooooo`0;ooooo`;o00004_ooool2o`0000gooooo0_l00029ooooo`00Qoooool2o`0001_ooooo
0_l00006ooooo`03o`000?oooooooooo01oooooo0_l0000=ooooo`;o0000ROooool008Oooooo0_l0
000Kooooo`;o00001_ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00P_ooool2o`0002Cooooo0_l00002ooooo`03o`000?oooooooooo00;ooooo0_l0000/oooo
o`;o0000Qoooool008;ooooo0_l0000>ooooo`;o00001_ooool2o`0000cooooo0_l00002ooooo`03
o`000?oooooooooo00;ooooo0_l0000Cooooo`;o00005oooool2o`0008Oooooo002Booooo`;o0000
1_ooool2o`00013ooooo00?o0000ooooooooool05oooool2o`0002_ooooo0_l0001cooooo`00[?oo
ool3o`0000Wooooo0_l00004ooooo`;o0000<oooool2o`0007?ooooo002Fooooo`;o00005?ooool0
0ol0003oooooooooo`09ooooo`;o00001?ooool2o`00027ooooo0_l00025ooooo`00U_ooool2o`00
01Cooooo00?o0000ooooooooool04?ooool2o`00023ooooo0_l00025ooooo`00P_ooool2o`0002So
oooo00Co0000ooooool0003o00003oooool2o`000:Oooooo0022ooooo`;o00004_ooool2o`000003
ooooool0003o0000017ooooo00Co0000ooooool0003o00006?ooool2o`0001Oooooo0_l0000Aoooo
o`;o0000L_ooool009Kooooo0_l000000ooooooo0000o`00000Aooooo`03o`000?oooooooooo01Wo
oooo0_l0000Gooooo`;o00004Oooool2o`0007;ooooo002Xooooo`;o00000_ooool00ol0003ooooo
ooooo`2iooooo`00T?ooool2o`000003ooooool0003o000001?ooooo0_l00002ooooo`03o`000?oo
oooooooo01;ooooo0_l0000cooooo`;o0000L?ooool008Wooooo0_l00005ooooo`;o000000?ooooo
o`000?l000005oooool01?l0003oooooooooooooool2o`0000?ooooo0_l0000:ooooo`;o00001ooo
ool2o`0000Sooooo0_l0000Pooooo`;o0000L?ooool008Wooooo0_l0000Qooooo`?o000000?ooooo
o`000?l000000oooool2o`0001?ooooo0_l00008ooooo`;o0000T_ooool00:cooooo00?o0000oooo
ooooool06_ooool2o`0009gooooo0025ooooo`;o00004oooool2o`00013ooooo00?o0000oooooooo
ool06_ooool2o`0009gooooo0025ooooo`;o00004oooool2o`00013ooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0B?ooool2o`0006oooooo0029ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1Oooool00ol0003oooooooooo`0<ooooo`;o00001_ooool2o`00023ooooo0_l0000@ooooo`?o0000
K_ooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Q
onk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0<ooooo`;o
00001_ooool2o`00023ooooo0_l0000Aooooo`;o0000K_ooool0087ooooo1_l00002ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool05?ooool2o`0001oooooo0_l00022ooooo`00ROooool01Ol0003ooooo
oooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o
0000=Oooool2o`0008;ooooo0029ooooo`03o`000?oooooooooo00Co00001_ooool2o`0000Cooooo
00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00?ooooo1?l0000Xooooo`;o
0000T?ooool008Wooooo00?o410@ooooooooool01?l00006ooooo`;o00001Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Gooooo1?l0000Xooooo`?o0000Soooool008Wooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00oooooo0_l0000Gooooo`;o00003?ooool4o`0007oo
oooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
00Cooooo1?l00006ooooo`03o`000?oooooooooo00Gooooo0_l00008ooooo`;o00009Oooool4o`00
013ooooo0_l0001]ooooo`00[?ooool00ol0003oooooooooo`05ooooo`;o00005oooool2o`0001Ko
oooo0ol0000Aooooo`;o0000KOooool009Sooooo0_l0000Booooo`03o`000?oooooooooo01kooooo
0_l00008ooooo`Co00002oooool2o`00083ooooo002Hooooo`;o00004_ooool00ol0003ooooooooo
o`0?ooooo`;o00003Oooool2o`0000Sooooo1?l0000Mooooo`;o0000K_ooool00:cooooo0ol0000?
ooooo`?o00003?ooool2o`0000[ooooo0_l0000=ooooo`;o00003_ooool2o`0006kooooo0020oooo
o`;o0000:Oooool2o`000003ooooool0003o000000kooooo0ol0000<ooooo`;o00002_ooool2o`00
00gooooo0_l0001nooooo`00P?ooool2o`0000Wooooo0_l0000Nooooo`;o000000?oooooo`000?l0
0000C?ooool2o`0006[ooooo0025ooooo`;o00001?ooool2o`0001oooooo00?o0000ooooooooool0
COooool2o`0006[ooooo0025ooooo`;o00009Oooool00ol0003oooooooooo`0iooooo`;o0000O_oo
ool00:cooooo00?o0000ooooooooool0>Oooool2o`0007kooooo0020ooooo`;o00005Oooool2o`00
01?ooooo00?o0000ooooooooool0^Oooool0083ooooo0_l0000Eooooo`;o00004oooool00ol0003o
ooooooooo`0;ooooo`;o00008?ooool2o`0000_ooooo0ol0000>ooooo`;o0000K?ooool00:cooooo
0ol0000;ooooo`;o00002oooool2o`00017ooooo1?l0000;ooooo`?o00003_ooool2o`0006cooooo
002/ooooo`03o`000?oooooooooo01Sooooo0_l00006ooooo`;o00002Oooool2o`0008cooooo002@
ooooo`;o00006_ooool00ol0003oooooooooo`0Pooooo`;o00005oooool2o`00017ooooo0_l0001[
ooooo`00Q?ooool2o`0000[ooooo0_l0000Jooooo`03o`000?oooooooooo03Wooooo0_l0000Aoooo
o`;o0000Joooool008Cooooo0_l0000Vooooo`03o`000?oooooooooo02gooooo0_l0002:ooooo`00
Roooool2o`0001oooooo00?o0000ooooooooool02?ooool2o`0001Sooooo0_l00008ooooo`?o0000
R_ooool008_ooooo0_l0000Oooooo`04o`000?oooooo0000o`0000Oooooo0_l0000Hooooo`;o0000
2?ooool2o`0008_ooooo002Hooooo`;o00004_ooool01?l0003oooooo`000?l0002hooooo`00Sooo
ool2o`0000Oooooo0_l0000Booooo`03o`000?oooooooooo01Wooooo0_l00008ooooo`;o0000U?oo
ool008oooooo0_l000000ooooooo0000o`00000Hooooo`?o00006Oooool2o`0000Sooooo0_l0002D
ooooo`00T_ooool2o`0001Sooooo00?o0000ooooooooool08oooool2o`0009Cooooo002/ooooo`03
o`000?oooooooooo00kooooo0_l0000Mooooo`;o00008Oooool2o`0006Oooooo0009ooooo`Co0000
00?o410@ooooooooool05_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03
o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oM
gMd05_ooool00ol0003oooooooooo`0>ooooo`;o00002?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Oo00000_ooool01Om4A4Co0000o`000?lb<S;ogMgM00Kooooo0_l00007
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool4o`0000Cooooo00GoA4A4o`000?l0003o<S8b
omgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_oo
ool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1?l000000ol@413oooooooooo`0Boooo
o`002oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8b
ooooo`0Eooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?l0003o0000ogMgM`05ooooo`03
ob4Q8Ol0003o000000?ooooo00KoV9RHob4Q8Oo^k^koooooodA4A?ooool2o`0000Cooooo00?oMgMg
oc8b<_ooool01Oooool2o`0000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`?o00002?oo
ool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo
00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo
0006o`0000Gooooo00?o0000ooooooooool04?ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool01Oooool6o`0000;ooooo
00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool01Oooool2o`00017ooooo00Go410@ooooool0003o0000oa0@4005
ooooo`?o00001?ooool00onHV9So8B4Qonk^kP02ooooo`;o00001Oooool00ol0003oooooooooo`0=
ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0=ooooo`05oa0@4?oo
ooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooo
oooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`0>ooooo`05o`00
0?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0>ooooo`05o`000?oooooooooooooo
ool000003Oooool00onHV9So8B4Qonk^kP04ooooo`;o000000?oooooogMgMolb<S805_ooool00ol0
003oooooooooo`05ooooo`;o00001_ooool2o`0000Wooooo00Go0000ooooooooooooooooo`000005
ooooo`;o00001_ooool00onHV9So8B4Qonk^kP02ooooo`;o00000oooool00omgMgOo<S8booooo`0>
ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0>ooooo`05o`000?oo
ooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Wooooo
00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooo
oooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oo
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool0
1Ol0003ooooooooooooooooo000000?ooooo0_l00009ooooo`03ogMgMomVIVKooooo00?ooooo0ol0
00000olb<S;oc<c<ooooo`0Eooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`;o00002Ooo
ool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01?l000001?lQ8B7o0000
oc8b<_o<c<`?ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00oooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c00Jooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oo
oooooooo01Sooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo
00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooooooo
ool04Oooool01Ol@413ooooooooooooooooo410@00?ooooo0_l00005ooooo`;o000000Coooooo`00
0?l0003o00001?ooool00ol0003oooooooooo`02o`0001Kooooo0ol00002ooooo`;o000000?ooooo
o`000?l000004Oooool00ol@413oooooooooo`02o`0000oooooo00Ko0000ooooool0003o0000oooo
ool0000Cooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0Aooooo`05
oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooo
oooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0:ooooo`;o000000Co^[Zjo`000?l0003o410@1?ooool00ol0003o
ooooooooo`02o`0001Kooooo00?o0000ooooooooool00_ooool2o`0001Cooooo00?oMgMgoiRHV?oo
ool00_l0000;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`0Aoooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Dooooo`002Oooool00omEEEGoIVIVo`00000Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01?ooool4o`0001Oooooo00?o0000ooooooooool06?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00004?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`00
00Cooooo1?l0000Iooooo`03oeEEEOmVIVKo000001Kooooo002/ooooo`03o`000?oooooooooo01[o
oooo0_l0002Mooooo`00[?ooool00ol0003oooooooooo`0Jooooo`;o0000WOooool00:cooooo00?o
0000ooooooooool03_ooool2o`0009kooooo0_l00002ooooo`;o00001Oooool00:cooooo00?o0000
ooooooooool03_ooool2o`0000?ooooo0_l0000?ooooo`;o00002Oooool2o`0007gooooo00Kok^k^
ob4Q8On7QhOo^[Zjo`000?oMgMd5ooooo`00SOooool2o`0001gooooo00?o0000ooooooooool04ooo
ool2o`0000Kooooo0_l00007ooooo`;o00002Oooool2o`0007kooooo00CogMgMo`000?l@413oc<c<
1_ooool000Ooooooool0001<o`0000cooooo00Cok^k^ob4Q8Ol@413ok^k^1_ooool000Oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co
0000oooooooooooooooo0_l00002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo0ol00007ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`04o`00
0?ooooooooooooooo`;o00000_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`04ob4Q8OmgMgOoMgMgoc8b
<PKooooo0007ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0Vooooo`04o`000?ooooooooooooooo`;o00008oooool00ol0003oooooooooo`0Soooo
o`;o00000_ooool00ol0003oooooooooo`0Dooooo`;o00004?ooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02Oooool2o`0000;ooooo0_l00005oooo
o`00P?ooool2o`0002[ooooo00?o0000ooooooooool08oooool2o`0001Wooooo0_l0001iooooo`00
P?ooool2o`0000gooooo0_l0000Kooooo`03o`000?oooooooooo0;Wooooo002?ooooo`;o00006ooo
ool00ol0003oooooooooo`0Cooooo`;o0000Y?ooool00:cooooo00?o0000ooooooooool04oooool3
o`0001Oooooo0_l0002:ooooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool05?ooool2o`00
00Cooooo0_l0000Aooooo`;o0000R_ooool009Cooooo0_l0000Fooooo`?o00006_ooool2o`0009go
oooo002/ooooo`;o0000^_ooool00:cooooo0_l0002jooooo`00T_ooool2o`0001Sooooo00?o0000
ooooooooool0??ooool2o`0007_ooooo002Booooo`;o00006?ooool00ol0003oooooooooo`06oooo
o`;o0000=?ooool2o`0007_ooooo0020ooooo`;o0000:_ooool00ol0003oooooooooo`06ooooo`;o
0000/Oooool0083ooooo0_l0000Dooooo`;o00005?ooool00ol0003oooooooooo`0Sooooo`;o0000
U?ooool009Kooooo0_l0000Dooooo`03o`000?oooooooooo00Wooooo0_l0000Hooooo`;o00006?oo
ool2o`0007[ooooo002/ooooo`03o`000?oooooooooo00Gooooo0_l00002ooooo`;o00000_ooool2
o`0001?ooooo0_l0000Iooooo`;o0000N_ooool009Kooooo0_l0000Dooooo`?o00001Oooool2o`00
00Kooooo0_l0000Cooooo`;o00006Oooool3o`0007Wooooo002Fooooo`;o00005?ooool00ol0003o
ooooooooo`0kooooo`Go0000NOooool009Cooooo0_l0000Fooooo`03o`000?oooooooooo03_ooooo
0_l0001looooo`00P?ooool2o`0001;ooooo0_l0000Fooooo`03o`000?oooooooooo03gooooo0_l0
001jooooo`00P?ooool2o`00013ooooo0_l0000Hooooo`03o`000?oooooooooo01[ooooo0_l00007
ooooo`;o00005_ooool4o`0007[ooooo002;ooooo`;o00001Oooool2o`0001Sooooo00?o0000oooo
ooooool06_ooool2o`0000Oooooo0_l0000Fooooo`;o0000O?ooool008_ooooo0_l0000>ooooo`;o
00003oooool00ol0003oooooooooo`0Hooooo`;o0000Woooool008kooooo0_l0000;ooooo`;o0000
3oooool00ol0003oooooooooo`0Hooooo`;o00001oooool2o`0000_ooooo0_l0000Nooooo`;o0000
JOooool008kooooo0_l0000Looooo`?o00002?ooool2o`0000kooooo0_l00007ooooo`;o00002ooo
ool2o`0001kooooo0_l0001Yooooo`00[?ooool00ol0003oooooooooo`08ooooo`;o00003_ooool2
o`0000Oooooo0_l0000[ooooo`;o0000JOooool00:cooooo00?o0000ooooooooool08oooool2o`00
00Oooooo1?l00029ooooo`00[?ooool00ol0003oooooooooo`0Aooooo`;o00004?ooool2o`0000Oo
oooo1?l00029ooooo`00[?ooool00ol0003oooooooooo`0Aooooo`;o0000Y_ooool00:cooooo00?o
0000ooooooooool00oooool2o`000;Cooooo002/ooooo`03o`000?oooooooooo00?ooooo0_l0000Y
ooooo`;o0000ROooool007cooooo0_l0000^ooooo`03o`000?oooooooooo02kooooo0_l0000<oooo
o`;o0000Noooool007cooooo0_l0000^ooooo`?o0000??ooool2o`0007_ooooo002/ooooo`03o`00
0?oooooooooo013ooooo0_l0002Wooooo`00[?ooool00ol0003oooooooooo`0@ooooo`;o00001_oo
ool2o`0001?ooooo0_l0002:ooooo`00[?ooool00ol0003oooooooooo`02ooooo`;o00003?ooool2
o`0000Kooooo0_l00005ooooo`;o00003?ooool2o`0000[ooooo0_l0001nooooo`00V?ooool2o`00
01;ooooo00?o0000ooooooooool00_ooool2o`0000cooooo0_l0000=ooooo`;o00006?ooool2o`00
07kooooo002Hooooo`;o00004_ooool00ol0003oooooooooo`0?ooooo`;o0000Z?ooool008Wooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q00Coooooo`000?l0003ooooo1Ol00004oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0?ooooo`;o00006oooool2
o`0008_ooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@09ooooool0003o
0000oooooonHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`0Zooooo`Co0000Roooool008Wooooo00Go410@oooooooooooooooooa0@400<ooooo`03
oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`0002[ooooo0_l0000Pooooo`;o
0000Joooool008Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0@ooooo`;o00003?ooool2o`0001So
oooo0ol0000Aooooo`;o0000Joooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo
00Cooooo0_l0000:ooooo`;o00003?ooool2o`0001Sooooo0ol0001nooooo`00ROooool01Ol@413o
oooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Cooooo0_l0000Tooooo`;o0000SOooool008Wooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`04ooooo`;o00001Oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Zooooo`;o0000SOooool008Wooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP04ooooo`;o00001Oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0
0006ooooo`03o`000?oooooooooo00Sooooo0_l0002_ooooo`00[?ooool00ol0003oooooooooo`08
ooooo`;o00000oooool2o`0000Kooooo0_l0000eooooo`;o0000Joooool00:cooooo00?o0000oooo
ooooool03Oooool2o`0000Gooooo0ol0000eooooo`;o0000Joooool0093ooooo0_l0000=ooooo`;o
00002oooool00ol0003oooooooooo`0Dooooo`;o00008?ooool2o`00087ooooo002@ooooo`;o0000
3Oooool2o`0000_ooooo0ol0000fooooo`;o0000POooool0093ooooo0_l0000Jooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo01?ooooo0_l0002Tooooo`00W?ooool2o`00
00_ooooo0_l000000ooooooo0000ooooo`0Dooooo`;o0000Y?ooool009cooooo0_l0000;ooooo`;o
000000?oooooo`000?ooool03Oooool2o`0000kooooo0_l0002Kooooo`00[?ooool00ol0003ooooo
ooooo`05ooooo`;o00001Oooool2o`0000kooooo0_l0002Kooooo`00R_ooool2o`00023ooooo00?o
0000ooooooooool01Oooool2o`0002oooooo0_l00021ooooo`00R_ooool2o`00023ooooo00?o0000
ooooooooool06_ooool2o`0000Wooooo0_l0000?ooooo`;o0000POooool00:_ooooo1?l0000Joooo
o`;o00002Oooool2o`0009;ooooo002Dooooo`;o00002oooool2o`0000Sooooo0_l0000hooooo`;o
0000POooool009Cooooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo0_l00009ooooo`03o`00
0?oooooooooo03Kooooo0_l00021ooooo`00V?ooool2o`0000;ooooo0_l0000>ooooo`03o`000?oo
oooooooo013ooooo0_l0002Wooooo`00Poooool2o`0001?ooooo0_l0000Booooo`03o`000?oooooo
oooo013ooooo0_l0002Wooooo`00Poooool2o`0001?ooooo0_l00003ooooo`;o00003Oooool00ol0
003oooooooooo`2iooooo`00S?ooool2o`0000oooooo0_l0000=ooooo`03o`000?oooooooooo01So
oooo0_l0002Oooooo`00O_ooool2o`0000cooooo0_l0000Nooooo`03o`000?oooooooooo01Sooooo
0_l0002Oooooo`00O_ooool2o`0000Oooooo0ol0000Rooooo`?o00000_ooool2o`000;Gooooo001n
ooooo`;o00001oooool3o`0000Gooooo0_l0000Kooooo`03o`000?oooooooooo00;ooooo0_l0000:
ooooo`;o0000ZOooool008_ooooo0_l00002ooooo`;o00005?ooool2o`0000Gooooo00?o0000oooo
ooooool03_ooool2o`0000Oooooo0_l0002Pooooo`00Roooool3o`0001?ooooo0ol000000ooooooo
0000o`000005ooooo`03o`000?oooooooooo01Oooooo0_l0000Jooooo`;o0000Q?ooool008cooooo
0_l0000Cooooo`?o00002?ooool00ol0003oooooooooo`0aooooo`Co0000Q?ooool008?ooooo0_l0
000Wooooo`03o`000?oooooooooo037ooooo0ol00025ooooo`00Poooool2o`0002Oooooo00?o0000
ooooooooool0^Oooool00:Sooooo0_l00002ooooo`03o`000?oooooooooo0;Wooooo002Xooooo`;o
00000_ooool3o`000;Wooooo0029ooooo`;o00007Oooool2o`0000;ooooo00?o0000ooooooooool0
0oooool3o`000;?ooooo0029ooooo`;o00008Oooool00ol0003oooooooooo`03ooooo`?o0000/ooo
ool008Wooooo0_l0000Qooooo`03o`000?oooooooooo0;Wooooo002Kooooo`;o00003_ooool2o`00
02oooooo0_l0002:ooooo`00U_ooool2o`0000?ooooo0_l0000>ooooo`;o00001?ooool2o`0002Wo
oooo0_l0002:ooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;o00000oooool2ob4Q8@Go
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00;ooooo0_l0000Xoooo
o`;o0000Roooool0097ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`04ooooo`04o`000?ooooooooooooooo`;o0000:Oooool2o`0008_ooooo002>oooo
o`;o000000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0>ooooo`03o`000?oooooooooo
00;o000000?oooooo`000?ooool00_ooool2o`000;Kooooo002>ooooo`;o000000?oooooo`000?oo
ool00_ooool00ol0003oooooooooo`0=ooooo`04ogMgMolb<S;oooooooooo`;o000000Coooooo`00
0?l0003o00007?ooool2o`0009_ooooo002Aooooo`05o`000?ooooooooooooooool000003?ooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool07?ooool2o`0009_ooooo002A
ooooo`05oa0@4?ooooooooooooooool@41001oooool2o`0000?ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0[ooooo`;o0000S?ooool008Gooooo0_l0000:ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01oooool2o`0000?ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0[ooooo`;o0000S?ooool008Gooooo0_l0000:ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?oo
ool4o`0000Kooooo00?o0000ooooooooool03oooool2o`000:Sooooo002Rooooo`;o00002?ooool0
0ol0003oooooooooo`05ooooo`;o00002?ooool2o`000:Sooooo002/ooooo`03o`000?oooooooooo
00Gooooo0_l0000dooooo`;o0000O?ooool00:cooooo0_l0000Xooooo`;o00004_ooool2o`0007co
oooo002Eooooo`;o00005Oooool3o`0002Oooooo0_l0000Aooooo`Co0000Noooool009Gooooo0_l0
0004ooooo`;o00003oooool00ol0003oooooooooo`0Vooooo`;o00004_ooool4o`0007_ooooo002K
ooooo`;o00003?ooool2o`000003ooooool0003ooooo02Oooooo0_l0002Aooooo`00Voooool2o`00
00cooooo0_l000000ooooooo0000ooooo`2jooooo`00Uoooool2o`0001?ooooo00?o0000oooooooo
ool02_ooool2o`0000Wooooo0_l0002Rooooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool0
2_ooool2o`0000Sooooo0ol0002Rooooo`00X?ooool4o`0000Sooooo00?o0000ooooooooool05?oo
ool2o`000:?ooooo002Hooooo`;o00001_ooool4o`000003ooooool0003o000000Gooooo00?o0000
ooooooooool0^Oooool009Sooooo0_l0000;ooooo`;o00001Oooool3o`000;Wooooo002/ooooo`03
o`000?oooooooooo00Oooooo0_l0002`ooooo`00[?ooool00ol0003oooooooooo`07ooooo`;o0000
2?ooool3o`000:Gooooo002/ooooo`;o00004_ooool3o`000:Gooooo002/ooooo`;o0000^_ooool0
0:cooooo00?o0000ooooooooool04_ooool2o`0000cooooo0_l0002Gooooo`00[?ooool00ol0003o
ooooooooo`0Booooo`;o00003?ooool2o`0009Oooooo002/ooooo`03o`000?oooooooooo03;ooooo
0_l00025ooooo`00UOooool2o`0001Gooooo0ol0000booooo`;o0000QOooool009Gooooo0ol00007
ooooo`;o00002oooool00ol0003oooooooooo`2iooooo`00Q?ooool2o`00013ooooo0ol00006oooo
o`;o00002oooool00ol0003oooooooooo`2iooooo`00Q?ooool2o`0000Wooooo0_l00006ooooo`;o
00001_ooool2o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`03o`000?oooooooooo0;Wo
oooo002?ooooo`;o00004oooool2o`000003ooooool0003o000000?ooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0;_ooool2o`0008Wooooo002/ooooo`03o`000?oooooo
oooo02kooooo0_l00029ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wo
oooo002Aooooo`;o00006Oooool3o`000;Wooooo002Aooooo`;o00006Oooool00ol0003ooooooooo
o`2iooooo`00V_ooool4o`0000kooooo00?o0000ooooooooool02Oooool2o`0000gooooo0_l0002O
ooooo`00V_ooool4o`0000cooooo0ol0000;ooooo`;o00003Oooool2o`0009oooooo002Zooooo`?o
00005oooool2o`000:;ooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool01oooool2o`0000cooooo0ol0002Qooooo`00ROooool01?mgMgOoV9RHoooooonHV9P2o`00
00Cooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00;o00001Oooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo00Oooooo0_l0000=ooooo`;o0000XOooool008Kooooo0_l000000ooooooo
410@ooooo`02ooooo`;o00003?ooool00onYZJWoEEEEooooo`02o`0000Kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Dooooo`;o0000Xoooool008Kooooo0_l000000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00cooooo00?o8B4Qooooooooool01Oooool2o`000003oc8b
<_oooooooooo00?ooooo0ol0000Dooooo`;o0000Xoooool008Wooooo00Go0000oooooooooooooooo
o`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o0000olc<c005ooooo`03
o`000?oooooooooo01;ooooo0_l0002Uooooo`00ROooool01Ol@413ooooooooooooooooo410@00So
oooo0_l00004ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Booooo`;o00004_ooool2o`00097ooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02?ooool2o`000003ooooool@413ooooo00;ooooo00?o<S8booooooooool00_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo01;ooooo0_l0000@ooooo`Co0000TOooool008Wooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo00?o0000oooooooo
ool04_ooool2o`00013ooooo0_l0002Cooooo`00[?ooool00ol0003oooooooooo`0?ooooo`;o0000
Z?ooool00:cooooo00?o0000ooooooooool03oooool2o`000:Sooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002?ooooo`?o00006_ooool3o`000;Wooooo002?ooooo`?o00006_ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00V_ooool2o`00013ooooo00?o
0000ooooooooool0^Oooool009[ooooo0_l0000;ooooo`Co000000?oooooo`000?ooool0^_ooool0
0:Oooooo1?l000000ooooooo0000ooooo`2jooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
W_ooool3o`0000_ooooo00?o0000ooooooooool0^Oooool009kooooo0ol00003ooooo`;o00001_oo
ool3o`000;Wooooo002Tooooo`;o00001_ooool00ol0003oooooooooo`0Iooooo`;o0000W_ooool0
0:cooooo00?o0000ooooooooool06Oooool2o`0009kooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool008kooooo0_l00009ooooo`;o00004Ooo
ool3o`000;Wooooo002>ooooo`;o00002Oooool2o`00017ooooo00?o0000ooooooooool0^Oooool0
09[ooooo0_l0000@ooooo`?o0000^Oooool009[ooooo0_l0000@ooooo`?o00004?ooool2o`000:Oo
oooo002Jooooo`;o00003?ooool2o`0000;ooooo00?o0000ooooooooool04?ooool2o`000:Oooooo
002Jooooo`;o00000oooool2o`0000Oooooo0ol000000ooooooo0000ooooo`2jooooo`00Woooool2
o`0000Oooooo0ol000000ooooooo0000ooooo`2jooooo`00Yoooool3o`0000;ooooo0ol0002ioooo
o`00Yoooool2o`0000?ooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:;ooooo1?l000000ol@413oooooooooo`03ooooo`03
o`000?oooooooooo0;Wooooo002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
^Oooool00:Cooooo00?o0000ooooooooool01Oooool3o`0000Gooooo0_l0002booooo`00Y?ooool0
0ol0003oooooooooo`0=ooooo`;o0000/_ooool00:Cooooo00?o0000ooooooooool0`Oooool00:Co
oooo00?o0000ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:;ooooo00?o
EEEEofIVI_l00000`oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00:[ooooo00Co410@o`000?l0003o0000^_ooool00:_ooooo00?o0000ooooooooool0^_oo
ool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00Ko0000ogMgMol0003o0000oeEEEOo^
k^jgooooo`00Zoooool01_l0003oEEEEonk^k_ooooooMgMgoeEEEKOooooo002[ooooo`03o`000?o^
k^kooooo00;ooooo00?o0000ooooooooool0]Oooool00:_ooooo00?o0000onk^k_ooool00_ooool0
0ol0003oooooooooo`2eooooo`00Zoooool01_l0003oEEEEonk^k_ooooooMgMgofIVI[Oooooo002Z
ooooo`03oa0@4?l0003oMgMg00;o000000?oIVIVonk^k_ooool0]_ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.52204 .14824 Mdot
.64942 .41689 Mdot
.49579 .59939 Mdot
.50741 .29016 Mdot
.46386 .18686 Mdot
.44352 .8576 Mdot
.47054 .32767 Mdot
.43836 .96431 Mdot
.63813 .76979 Mdot
.41458 .43585 Mdot
.5267 .29484 Mdot
.3748 .70349 Mdot
.6026 .75895 Mdot
.47955 .21512 Mdot
.36791 .58743 Mdot
.54873 .5933 Mdot
.52088 .19726 Mdot
.59385 .77671 Mdot
.50506 .77332 Mdot
.50096 .06472 Mdot
.58391 .78799 Mdot
.65582 .55048 Mdot
.64564 .60736 Mdot
.5743 .81008 Mdot
.42036 .07052 Mdot
.58207 .63666 Mdot
.56207 .41403 Mdot
.52018 .73936 Mdot
.54364 .11633 Mdot
.65039 .43433 Mdot
.54423 .84811 Mdot
.64066 .7695 Mdot
.50023 .97185 Mdot
.60035 .37622 Mdot
.62022 .56253 Mdot
.40389 .19975 Mdot
.69391 .42832 Mdot
.55968 .62045 Mdot
.58191 .17406 Mdot
.3654 .57574 Mdot
.42176 .06213 Mdot
.61991 .4741 Mdot
.56508 .75192 Mdot
.55647 .19337 Mdot
.46688 .10351 Mdot
.57545 .36453 Mdot
.45752 .23173 Mdot
.68373 .66549 Mdot
.43456 .7949 Mdot
.5302 .10448 Mdot
.6852 .65637 Mdot
.63663 .25962 Mdot
.54433 .98741 Mdot
.59922 .66029 Mdot
.59333 .68784 Mdot
.58029 .86862 Mdot
.42526 .93845 Mdot
.51764 .19003 Mdot
.70251 .55701 Mdot
.4413 .13281 Mdot
.58483 .40535 Mdot
.69276 .26058 Mdot
.58869 .18655 Mdot
.52495 .64003 Mdot
.50642 .95882 Mdot
.61296 .82088 Mdot
.41339 .50325 Mdot
.55349 .53733 Mdot
.55798 .63421 Mdot
.54402 .8559 Mdot
.55614 .25011 Mdot
.50677 .62547 Mdot
.4176 .39883 Mdot
.43935 .72132 Mdot
.58834 .18608 Mdot
.44844 .41421 Mdot
.54366 .98808 Mdot
.59312 .50435 Mdot
.61608 .22185 Mdot
.47808 .8355 Mdot
.41776 .84404 Mdot
.64698 .42022 Mdot
.47339 .25093 Mdot
.62191 .49496 Mdot
.51164 .96254 Mdot
.54367 .62782 Mdot
.47838 .18232 Mdot
.52398 .2473 Mdot
.48075 .14584 Mdot
.55215 .55178 Mdot
.42852 .05245 Mdot
.73297 .68408 Mdot
.44811 .71433 Mdot
.5503 .29705 Mdot
.47606 .74253 Mdot
.7471 .6407 Mdot
.46968 .21617 Mdot
.67979 .66455 Mdot
.4912 .14927 Mdot
.55577 .19843 Mdot
.42985 .20933 Mdot
.37686 .71707 Mdot
.58235 .23788 Mdot
.46391 .92735 Mdot
.60849 .40919 Mdot
.57554 .29312 Mdot
.46215 .80148 Mdot
.44576 .70844 Mdot
.53843 .86249 Mdot
.4379 .2713 Mdot
.49922 .26993 Mdot
.64468 .76004 Mdot
.42435 .11798 Mdot
.36142 .27383 Mdot
.52831 .56076 Mdot
.59208 .45679 Mdot
.58943 .8632 Mdot
.61491 .82173 Mdot
.68699 .41056 Mdot
.60334 .75565 Mdot
.65117 .18846 Mdot
.61281 .71864 Mdot
.55377 .1278 Mdot
.53797 .86402 Mdot
.52876 .34805 Mdot
.45352 .06615 Mdot
.75802 .57696 Mdot
.61466 .31756 Mdot
.45687 .69773 Mdot
.64824 .60504 Mdot
.58891 .25721 Mdot
.3648 .48468 Mdot
.42858 .82694 Mdot
.52896 .81902 Mdot
.5949 .18517 Mdot
.69107 .39633 Mdot
.50735 .07521 Mdot
.41557 .42933 Mdot
.45638 .97795 Mdot
.36598 .53305 Mdot
.73586 .37595 Mdot
.42868 .35832 Mdot
.54026 .69431 Mdot
.5223 .19902 Mdot
.46302 .05533 Mdot
.54455 .92349 Mdot
.44659 .7733 Mdot
.54311 .28556 Mdot
.62453 .14562 Mdot
.41535 .26768 Mdot
.57398 .52741 Mdot
.56947 .81957 Mdot
.5159 .57888 Mdot
.3904 .57295 Mdot
.67568 .35147 Mdot
.60663 .21173 Mdot
.58943 .86062 Mdot
.69282 .42873 Mdot
.67968 .36199 Mdot
.53441 .76308 Mdot
.61779 .22256 Mdot
.41113 .08549 Mdot
.37898 .44212 Mdot
.56723 .74203 Mdot
.54098 .17879 Mdot
.55445 .91023 Mdot
.43169 .88693 Mdot
.56304 .61068 Mdot
.67854 .35159 Mdot
.48177 .05954 Mdot
.43237 .64878 Mdot
.57074 .54611 Mdot
.47775 .18503 Mdot
.42372 .70099 Mdot
.49264 .9763 Mdot
.75117 .62043 Mdot
.39337 .62003 Mdot
.52917 .5259 Mdot
.55632 .13516 Mdot
.66095 .30464 Mdot
.36765 .37137 Mdot
.49051 .7624 Mdot
.43773 .02932 Mdot
.4321 .39203 Mdot
.64515 .75183 Mdot
.7574 .57008 Mdot
.64742 .76108 Mdot
.3986 .13219 Mdot
.54614 .79069 Mdot
.61332 .13612 Mdot
.46295 .05495 Mdot
.54136 .53066 Mdot
.67396 .23037 Mdot
.47723 .98949 Mdot
.50212 .01006 Mdot
.36845 .61997 Mdot
.53434 .26362 Mdot
.70449 .76248 Mdot
.60767 .38103 Mdot
.51575 .38962 Mdot
.5202 .41036 Mdot
.49515 .66532 Mdot
.44887 .209 Mdot
.68501 .79945 Mdot
.56962 .22375 Mdot
.51441 .34423 Mdot
.4157 .77934 Mdot
.49521 .25992 Mdot
.47226 .27352 Mdot
.53713 .31837 Mdot
.63839 .66743 Mdot
.5929 .48605 Mdot
.42909 .8808 Mdot
.51596 .70701 Mdot
.54992 .19276 Mdot
.58874 .44616 Mdot
.41724 .06837 Mdot
.43608 .35967 Mdot
.41518 .21405 Mdot
.37429 .70656 Mdot
.59058 .44213 Mdot
.69819 .57292 Mdot
.45102 .91889 Mdot
.39301 .72377 Mdot
.538 .63492 Mdot
.41192 .36594 Mdot
.64349 .38314 Mdot
.43743 .67575 Mdot
.3671 .56795 Mdot
.66518 .20754 Mdot
.55615 .50098 Mdot
.47093 .66349 Mdot
.67861 .80618 Mdot
.39828 .5436 Mdot
.56236 .40841 Mdot
.6326 .16315 Mdot
.56676 .58378 Mdot
.59888 .26894 Mdot
.61719 .71413 Mdot
.57907 .23822 Mdot
.69208 .26105 Mdot
.49435 .87308 Mdot
.38905 .70733 Mdot
.55495 .24791 Mdot
.63798 .77876 Mdot
.49359 .72458 Mdot
.66603 .33281 Mdot
.43299 .20848 Mdot
.55033 .23918 Mdot
.59362 .1924 Mdot
.52933 .54851 Mdot
.54057 .5255 Mdot
.67606 .3651 Mdot
.57723 .64776 Mdot
.57149 .52711 Mdot
.577 .73461 Mdot
.45693 .37598 Mdot
.44268 .96709 Mdot
.69538 .61629 Mdot
.40951 .68482 Mdot
.56198 .40627 Mdot
.38288 .6273 Mdot
.4976 .68585 Mdot
.40837 .31413 Mdot
.48528 .10825 Mdot
.47493 .22096 Mdot
.4878 .87325 Mdot
.43464 .10024 Mdot
.55079 .72065 Mdot
.42264 .12608 Mdot
.58362 .71544 Mdot
.41384 .44398 Mdot
.4417 .80664 Mdot
.67395 .34409 Mdot
.47696 .77325 Mdot
.4077 .58306 Mdot
.67792 .67942 Mdot
.53062 .29981 Mdot
.39511 .6462 Mdot
.57943 .1656 Mdot
.44149 .66065 Mdot
.47251 .76813 Mdot
.69192 .42772 Mdot
.38998 .80817 Mdot
.45413 .79334 Mdot
.51916 .46398 Mdot
.40901 .41756 Mdot
.39256 .25335 Mdot
.55882 .32146 Mdot
.44408 .90371 Mdot
.7568 .56912 Mdot
.70184 .53747 Mdot
.38198 .75167 Mdot
.69954 .54183 Mdot
.43715 .47121 Mdot
.70527 .51233 Mdot
.65076 .19636 Mdot
.37727 .43423 Mdot
.37175 .65267 Mdot
.46374 .83748 Mdot
.53716 .8117 Mdot
.59766 .27281 Mdot
.63828 .7765 Mdot
.40823 .1044 Mdot
.47752 .21868 Mdot
.67904 .67241 Mdot
.56928 .67526 Mdot
.47562 .30263 Mdot
.63984 .65756 Mdot
.5387 .22612 Mdot
.61202 .73425 Mdot
.60592 .12235 Mdot
.52211 .59873 Mdot
.43686 .14661 Mdot
.6128 .42829 Mdot
.48034 .97966 Mdot
.48983 .70368 Mdot
.37063 .33017 Mdot
.57394 .0941 Mdot
.75129 .42541 Mdot
.55025 .43966 Mdot
.42272 .81099 Mdot
.62305 .50592 Mdot
.61519 .22904 Mdot
.41597 .32824 Mdot
.50605 .34948 Mdot
.44774 .37827 Mdot
.56143 .26404 Mdot
.39338 .83332 Mdot
.67104 .35376 Mdot
.48004 .74218 Mdot
.65002 .61426 Mdot
.44636 .67355 Mdot
.49282 .67042 Mdot
.64583 .39324 Mdot
.45875 .87735 Mdot
.56595 .74504 Mdot
.53427 .7629 Mdot
.4352 .24353 Mdot
.58377 .94453 Mdot
.56917 .67108 Mdot
.63706 .38326 Mdot
.52348 .64291 Mdot
.53825 .92534 Mdot
.55577 .38626 Mdot
.49233 .06049 Mdot
.65266 .47365 Mdot
.41978 .53608 Mdot
.57216 .36902 Mdot
.73501 .3713 Mdot
.37809 .73477 Mdot
.70668 .50815 Mdot
.41715 .14544 Mdot
.48616 .83787 Mdot
.60094 .36298 Mdot
.46946 .05893 Mdot
.3989 .42383 Mdot
.37893 .7407 Mdot
.75678 .4418 Mdot
.38417 .66218 Mdot
.36495 .5121 Mdot
.37467 .28639 Mdot
.43587 .02966 Mdot
.45973 .67815 Mdot
.407 .6617 Mdot
.36589 .5167 Mdot
.43647 .95903 Mdot
.45022 .65651 Mdot
.48102 .92503 Mdot
.56863 .667 Mdot
.41068 .75907 Mdot
.5453 .18225 Mdot
.6716 .68987 Mdot
.59633 .26444 Mdot
.70056 .46946 Mdot
.64943 .29861 Mdot
.64821 .58998 Mdot
.7057 .47786 Mdot
.65017 .58869 Mdot
.39147 .1787 Mdot
.39007 .08986 Mdot
.69318 .4474 Mdot
.38825 .48807 Mdot
.51934 .5374 Mdot
.52577 .03994 Mdot
.46902 .14527 Mdot
.44289 .40612 Mdot
.37123 .31769 Mdot
.53851 .86383 Mdot
.50218 .33641 Mdot
.42537 .65988 Mdot
.59342 .56621 Mdot
.56774 .44118 Mdot
.67789 .68609 Mdot
.43501 .89773 Mdot
.66714 .22081 Mdot
.37041 .33053 Mdot
.57852 .30744 Mdot
.60677 .91345 Mdot
.59259 .34145 Mdot
.42921 .72624 Mdot
.40958 .59977 Mdot
.51144 .54165 Mdot
.40341 .87451 Mdot
.37762 .72814 Mdot
.56023 .40439 Mdot
.42198 .56781 Mdot
.56863 .42594 Mdot
.52484 .6895 Mdot
.56268 .07307 Mdot
.54204 .27665 Mdot
.37832 .45591 Mdot
.43995 .30546 Mdot
.57306 .53846 Mdot
.47976 .71262 Mdot
.51446 .22486 Mdot
.59144 .34712 Mdot
.57191 .46374 Mdot
.52359 .37518 Mdot
.63828 .16717 Mdot
.46101 .9813 Mdot
.47695 .37598 Mdot
.61714 .58888 Mdot
.57563 .29354 Mdot
.39291 .38245 Mdot
.5565 .70196 Mdot
.56906 .57117 Mdot
.5342 .04713 Mdot
.73793 .68102 Mdot
.60925 .2938 Mdot
.35636 .6536 Mdot
.57378 .22024 Mdot
.53608 .43144 Mdot
.62136 .79744 Mdot
.36618 .45933 Mdot
.53459 .31618 Mdot
.65171 .47417 Mdot
.5734 .95606 Mdot
.41989 .51461 Mdot
.47446 .29913 Mdot
.41187 .6165 Mdot
.38449 .65101 Mdot
.5054 .80765 Mdot
.71863 .72765 Mdot
.44889 .31009 Mdot
.61247 .60162 Mdot
.62018 .46366 Mdot
.50049 .71381 Mdot
.52389 .58422 Mdot
.4522 .75448 Mdot
.43669 .96126 Mdot
.50958 .65363 Mdot
.60315 .19956 Mdot
.63854 .37152 Mdot
.4582 .11159 Mdot
.43675 .09138 Mdot
.47552 .92471 Mdot
.56122 .26794 Mdot
.76079 .57529 Mdot
.41967 .61881 Mdot
.38848 .80841 Mdot
.47617 .22184 Mdot
.70596 .51185 Mdot
.55353 .71161 Mdot
.49073 .1574 Mdot
.48744 .05703 Mdot
.55801 .201 Mdot
.48904 .79734 Mdot
.57395 .37451 Mdot
.60023 .37277 Mdot
.69427 .25757 Mdot
.534 .80787 Mdot
.44468 .44154 Mdot
.57776 .72035 Mdot
.46989 .83657 Mdot
.46544 .68693 Mdot
.5524 .46759 Mdot
.60278 .64902 Mdot
.53749 .80683 Mdot
.52953 .47724 Mdot
.58558 .60888 Mdot
.60987 .82583 Mdot
.45488 .19528 Mdot
.4605 .11254 Mdot
.55136 .66503 Mdot
.52072 .73454 Mdot
.43195 .52858 Mdot
.3545 .36126 Mdot
.43164 .48393 Mdot
.64774 .40499 Mdot
.69538 .57834 Mdot
.38041 .40076 Mdot
.55082 .66042 Mdot
.52822 .09968 Mdot
.36427 .491 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo0_l0002jooooo`00Y?ooool00ol0003oooooooooo`05
ooooo`;o0000^_ooool00:;ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?oo
ool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Fooooo`?o00004oooool00ol0
003oooooooooo`2iooooo`00U_ooool3o`0001?ooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool01Oooool2o`000;;ooooo002/
ooooo`03o`000?oooooooooo00Gooooo0_l0002booooo`00[?ooool00ol0003oooooooooo`08oooo
o`;o0000[oooool00:cooooo00?o0000ooooooooool02?ooool2o`000:oooooo002Dooooo`;o0000
5_ooool3o`000;Wooooo002Dooooo`;o00002Oooool2o`0000_ooooo00?o0000ooooooooool0^Ooo
ool009oooooo1?l00004ooooo`;o00000oooool00ol0003oooooooooo`2iooooo`00T_ooool2o`00
00gooooo0_l00003ooooo`Go000000?oooooo`000?ooool0^_ooool009;ooooo0_l0000Booooo`;o
000000Coooooo`000?l0003ooooo0_l0002jooooo`00W?ooool2o`0000kooooo0_l0002jooooo`00
T?ooool3o`0000Wooooo0_l0000>ooooo`03o`000?oooooooooo0;Wooooo002@ooooo`?o00006Ooo
ool00ol0003oooooooooo`0Aooooo`;o0000Y_ooool00:cooooo1?l0000@ooooo`;o0000Y_ooool0
0:cooooo00Co0000ooooool0003o0000^?ooool00:cooooo00?o0000ooooooooool0^Oooool008ko
oooo0_l0000Looooo`03o`000?oooooooooo0;Wooooo002>ooooo`;o00007?ooool00ol0003ooooo
ooooo`2iooooo`00Qoooool2o`0000kooooo0_l0000Cooooo`03o`000?oooooooooo0;Wooooo0027
ooooo`;o00003_ooool2o`0001?ooooo00?o0000ooooooooool05Oooool2o`000:;ooooo002/oooo
o`03o`000?oooooooooo01Gooooo0_l0002Rooooo`00U_ooool2o`0001Cooooo0ol00006ooooo`;o
0000/Oooool008gooooo0_l00007ooooo`;o00002Oooool2o`0000Wooooo00?o0000ooooooooool0
1_ooool3o`000;3ooooo002=ooooo`;o00004_ooool2o`0000Wooooo00?o0000ooooooooool01ooo
ool2o`000;3ooooo002Wooooo`;o00000oooool00ol0003oooooooooo`2iooooo`00W_ooool3o`00
00Kooooo0_l00003ooooo`03o`000?oooooooooo0;Wooooo002Nooooo`?o00002oooool00ol0003o
ooooooooo`0;ooooo`;o0000[?ooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
00001_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`0;ooooo`;o0000[?ooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o00001_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool08?ooool2o`0009Oooooo0021ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@
00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o00008?ooool2o`00
09Oooooo0029ooooo`05o`000?ooooooooooooooool000001?ooool2o`0000Sooooo00?o8B4Qoooo
ooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00kooooo0_l0002Yoooo
o`00ROooool01Ol0003ooooooooooooooooo000000Cooooo0_l00008ooooo`03oeEEEOo<c<cooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00kooooo0_l0002Y
ooooo`00ROooool01Ol@413o0000o`000?oooooo410@00[ooooo0_l00002ooooo`03ojVYZOmgMgOo
oooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2iooooo`00ROooool01Omg
MgOo0000o`000?nHV9SoMgMg00[ooooo0_l00003ooooo`03oc8b<_oooooooooo00;ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0?ooooo`;o00004Oooool2o`0009Gooooo0029oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooo
oooo00oooooo0_l0000Aooooo`;o0000UOooool00:cooooo00?o0000ooooooooool0^Oooool0093o
oooo0_l00005ooooo`;o00002?ooool2o`0000;ooooo0_l00005ooooo`03o`000?oooooooooo02Ko
oooo0_l0002Aooooo`00T?ooool2o`0000Gooooo0_l00008ooooo`;o00000_ooool2o`0000;ooooo
0_l000000ooooooo0000ooooo`05ooooo`;o00008?ooool2o`00097ooooo002Yooooo`;o000000Co
ooooo`000?l0003o00001?ooool2o`000;?ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Y
ooooo`;o000000?oooooo`000?ooool0^_ooool00:Wooooo0_l000000ooooooo0000ooooo`2joooo
o`00[?ooool00ol0003oooooooooo`0Xooooo`;o0000Soooool00:cooooo00?o0000ooooooooool0
5oooool2o`0000oooooo1?l0002=ooooo`00[?ooool00ol0003oooooooooo`0Gooooo`;o00004Ooo
ool2o`0008gooooo002/ooooo`03o`000?oooooooooo01Sooooo0_l0002Oooooo`00[?ooool3o`00
01Sooooo0_l0002Oooooo`00R?ooool2o`0002;ooooo00?o0000ooooooooool02_ooool2o`000:go
oooo0028ooooo`;o00006_ooool2o`0000Kooooo00?o0000ooooooooool02_ooool4o`000:_ooooo
002Tooooo`;o00001_ooool00ol0003oooooooooo`0<ooooo`;o00003?ooool4o`0009_ooooo002P
ooooo`;o00000_ooool2o`0000Kooooo00?o0000ooooooooool06_ooool4o`00013ooooo0_l00029
ooooo`00X?ooool2o`0000[ooooo00?o0000ooooooooool00_ooool2o`0001Kooooo0ol0000Aoooo
o`;o0000ROooool009gooooo0_l0000=ooooo`03o`000?oooooooooo00;ooooo0_l00009ooooo`Co
00002_ooool2o`0009cooooo002Mooooo`;o00003Oooool00ol0003oooooooooo`03ooooo`;o0000
2?ooool4o`0001gooooo0_l00029ooooo`00S?ooool2o`0001kooooo0ol00003ooooo`?o00002Ooo
ool3o`0000gooooo0_l0000=ooooo`;o0000ROooool008cooooo0_l0000Nooooo`03o`000?oooooo
oooo00Cooooo0_l0000:ooooo`;o00003Oooool2o`0009Sooooo002/ooooo`03o`000?oooooooooo
03?ooooo0_l00024ooooo`00U?ooool3o`0000Cooooo0_l0000?ooooo`03o`000?oooooooooo03?o
oooo0_l00024ooooo`00U?ooool3o`0000Cooooo0_l0000?ooooo`03o`000?oooooooooo023ooooo
0_l0002Gooooo`00T?ooool2o`00013ooooo0_l000000ooooooo0000o`000005ooooo`03o`000?oo
oooooooo023ooooo0_l0002Gooooo`00T?ooool2o`00013ooooo1Ol00005ooooo`03o`000?oooooo
oooo0;Wooooo002Sooooo`?o00001_ooool00ol0003oooooooooo`0Eooooo`;o00003?ooool2o`00
00oooooo0_l00023ooooo`00Xoooool3o`0000Kooooo0ol000000ooooooo0000o`00000Aooooo`?o
00003?ooool2o`0000oooooo0_l00023ooooo`00[?ooool01?l0003oooooooooooooool2o`0000Ko
oooo0_l00009ooooo`;o0000Xoooool009kooooo0_l0000<ooooo`03o`000?oooooooooo00Wooooo
0_l0000Hooooo`;o00004Oooool2o`00087ooooo002Nooooo`;o00003?ooool00ol0003ooooooooo
o`0Sooooo`;o00004Oooool2o`00087ooooo002/ooooo`03o`000?oooooooooo01Sooooo0_l0002O
ooooo`00[?ooool00ol0003oooooooooo`0=ooooo`;o00002?ooool3o`0009oooooo002Aooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00_l00003ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool03Oooool2o`0000Sooooo0_l0002Pooooo`00TOooool01Omg
MgOoV9RHoooooonHV9SoMgMg00;o00000oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`2iooooo`00ROooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool2o`0000Wooooo0_l0002X
ooooo`00TOooool01Ol0003ooooooooooooooooo000000gooooo0_l000000omgMgOo<S8booooo`04
ooooo`?o00001?ooool2o`0000Wooooo0_l0002Xooooo`00R?ooool2o`0000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`?o000000?o<S8bolc<c?ooool01?ooool00ol0003oooooooooo`0?
ooooo`;o0000Z?ooool008Sooooo0_l00007ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo01[ooooo0_l0000Qooooo`;o0000N_ooool0
097ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Gooooo0ol0000L
ooooo`;o00003_ooool2o`00013ooooo0ol0001jooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo1?l00004ooooo`?o00002_ooool2o`0000Oooooo0_l00009ooooo`;o00003?ooool2
o`00013ooooo0_l0001kooooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool02?ooool2o`00
00Oooooo0_l00009ooooo`;o0000Voooool0093ooooo0_l00005ooooo`;o00004_ooool2o`0001?o
oooo0_l0000:ooooo`;o0000V_ooool007kooooo0_l0000Gooooo`;o00002Oooool2o`0000Oooooo
0_l0000Oooooo`;o0000V_ooool007kooooo0_l0000Rooooo`;o00002?ooool3o`0000[ooooo0_l0
000Aooooo`;o0000V_ooool00:cooooo00?o0000ooooooooool02_ooool2o`000:gooooo002/oooo
o`03o`000?oooooooooo0;Wooooo0022ooooo`;o0000:?ooool00ol0003oooooooooo`0;ooooo`;o
0000[?ooool008;ooooo0_l0000Xooooo`03o`000?oooooooooo00_ooooo0_l0002/ooooo`00[?oo
ool01?l0003oooooo`000?l0002hooooo`00[?ooool01?l0003oooooo`000?l00004ooooo`;o0000
3oooool2o`0000Wooooo0_l0002Fooooo`00[?ooool00ol0003oooooooooo`05ooooo`;o00001_oo
ool2o`0000Oooooo0_l00009ooooo`;o0000U_ooool00:?ooooo0_l00007ooooo`?o00001oooool2
o`0000Cooooo0_l0000Oooooo`;o0000ROooool00:?ooooo0ol00006ooooo`03o`000?oooooooooo
00Oooooo0_l0000Uooooo`;o0000ROooool009Sooooo0_l0000:ooooo`;o00001_ooool00ol0003o
ooooooooo`0Fooooo`;o00006_ooool2o`0008Gooooo002Hooooo`;o000000?oooooo`000?l00000
3oooool00ol0003oooooooooo`0Fooooo`;o00006_ooool2o`0008Gooooo002Kooooo`;o00003ooo
ool00ol0003oooooooooo`2iooooo`00SOooool2o`0001gooooo00?o0000ooooooooool02?ooool2
o`000:oooooo0021ooooo`;o00002_ooool2o`0001gooooo00?o0000ooooooooool02?ooool3o`00
01Oooooo0_l0002Eooooo`00POooool2o`0002Wooooo00?o0000ooooooooool02Oooool2o`0000Go
oooo0_l0000@ooooo`;o0000UOooool00:cooooo0ol0000@ooooo`;o0000Yoooool0093ooooo0_l0
000@ooooo`;o00002?ooool00ol0003oooooooooo`2iooooo`00POooool2o`0000gooooo0_l0000@
ooooo`;o00002?ooool00ol0003oooooooooo`2iooooo`00POooool2o`0002Wooooo00?o0000oooo
ooooool0<oooool2o`0008Cooooo002/ooooo`;o0000=?ooool2o`0008Cooooo002/ooooo`;o0000
^_ooool00:cooooo00?o0000ooooooooool06oooool2o`0009cooooo002/ooooo`04o`000?oooooo
ooooooooo`;o00006?ooool2o`0001Wooooo0_l00021ooooo`00[?ooool00ol0003oooooo`000003
o`0000?ooooo0_l0000Cooooo`;o00006Oooool2o`00087ooooo002/ooooo`Co00001Oooool2o`00
01?ooooo0_l0000Jooooo`?o0000Ooooool00:cooooo00?o0000ooooooooool0=Oooool5o`0007oo
oooo002Dooooo`;o00005_ooool00ol0003oooooooooo`0eooooo`;o0000P_ooool007cooooo0_l0
000Fooooo`Co00005?ooool00ol0003oooooooooo`0hooooo`;o0000Ooooool007cooooo0_l0000H
ooooo`;o00005?ooool00ol0003oooooooooo`0Eooooo`;o00001oooool2o`0001Oooooo0ol0001o
ooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;o00000oooool2ob4Q8@Cooooo1Ol00004
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Eooooo`;o00001ooo
ool2o`0001Oooooo0_l00020ooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00;o00000ooo
ool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool05?ooool2o`000:?ooooo0020ooooo`Oo00000_ooool01Ol@413ooooooooo
oooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo01Cooooo0_l00008ooooo`;o00002_ooool2o`0001kooooo0_l0001]ooooo`00P?oo
ool2o`0000Oooooo00Go0000ooooooooooooooooo`00000=ooooo`04oiRHV?lQ8B7o0000o`0000Go
oooo0_l000000olb<S;oooooooooo`03ooooo`?o00001?ooool2o`0000oooooo0_l00007ooooo`;o
00002_ooool2o`0001kooooo0_l0001]ooooo`00ROooool01Ol0003ooooooooooooooooo000000co
oooo0_l000000omgMgOo0000o`000003ooooo`05o`000?lQ8B7o0000o`000?o<c<`01Oooool00ol0
003oooooooooo`04ooooo`;o00003oooool2o`0000Oooooo0_l0000Zooooo`;o0000KOooool008So
oooo0_l00003ooooo`03oa0@4?oooooooooo00[ooooo0_l000000ooooooo0000ooooo`03ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool08?ooool2o`0000Sooooo1?l0002;ooooo`00
R?ooool2o`000004oiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4004oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03oooool2o`0000oooooo0_l00008oooo
o`Co0000Roooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool03oooool2o`000:Sooooo002Eoooo
o`;o00005Oooool00ol0003oooooooooo`02ooooo`;o0000]Oooool009Gooooo0_l0000Eooooo`03
o`000?oooooooooo00;ooooo0_l0000Yooooo`;o0000R_ooool00:cooooo00?o0000ooooooooool0
;Oooool2o`0000gooooo0_l0001kooooo`00Q?ooool2o`0000[ooooo0_l0000Jooooo`?o0000??oo
ool2o`0007_ooooo0024ooooo`;o00002_ooool2o`0001[ooooo00?o0000ooooooooool04?ooool2
o`000:Oooooo002Iooooo`;o00004Oooool00ol0003oooooooooo`0@ooooo`?o00001_ooool2o`00
01;ooooo0_l0002:ooooo`00VOooool2o`00017ooooo00?o0000ooooooooool00oooool2o`0000co
oooo0_l00006ooooo`;o00001Oooool2o`0000_ooooo0_l0000;ooooo`;o0000OOooool00:cooooo
00?o0000ooooooooool00oooool2o`0000cooooo0_l0000=ooooo`;o00006?ooool2o`0007gooooo
002Kooooo`;o00003oooool00ol0003oooooooooo`0Aooooo`;o0000Y_ooool008kooooo0_l0000;
ooooo`;o00003oooool00ol0003oooooooooo`0Aooooo`;o00006oooool2o`0008Wooooo002>oooo
o`;o00007?ooool00ol0003oooooooooo`0]ooooo`?o0000ROooool008[ooooo0_l0000Pooooo`?o
0000;Oooool2o`00027ooooo0_l0001Wooooo`00R_ooool2o`00023ooooo00?o0000ooooooooool0
4oooool2o`0000gooooo0_l0000Hooooo`?o00004Oooool2o`0006Oooooo002@ooooo`;o00006_oo
ool00ol0003oooooooooo`08ooooo`;o00002Oooool2o`0000gooooo0_l0000Hooooo`?o0000N_oo
ool008?ooooo0_l0000;ooooo`;o00006_ooool00ol0003oooooooooo`08ooooo`;o00009?ooool2
o`0008Wooooo0023ooooo`;o00002_ooool2o`0001_ooooo00?o0000ooooooooool0;_ooool2o`00
08Wooooo002?ooooo`;o00006oooool00ol0003oooooooooo`0=ooooo`;o0000Z_ooool008Cooooo
0_l0000Cooooo`;o00004Oooool00ol0003oooooooooo`0=ooooo`;o00001?ooool2o`0000Gooooo
0_l0000eooooo`;o0000I_ooool008Cooooo0_l00009ooooo`;o00002?ooool2o`00017ooooo00?o
0000ooooooooool04oooool2o`0000Gooooo0_l0000eooooo`;o0000I_ooool008oooooo0_l0000K
ooooo`03o`000?oooooooooo01[ooooo0_l0000Pooooo`;o0000Noooool00:cooooo0ol0000loooo
o`;o0000Noooool008?ooooo0_l0000Wooooo`03o`000?oooooooooo0;Wooooo0023ooooo`;o0000
9oooool00ol0003oooooooooo`0Kooooo`;o0000W?ooool000Wooooo1?l000000ol@413ooooooooo
o`0Fooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool0
1?ooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP02ooooo`;o000000?oooooob4Q8OlQ8B401?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8b
omgMg@0Fooooo`03o`000?oooooooooo01Sooooo00?ok^k^oc8b<_l000000_l00005ooooo`;o8B4Q
1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM01Sooooo1?l000000ol@413oooooooooo`0Booooo`002oooool00ol0003ooooooooo
o`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool0
1oooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo0_l000000ooo
oooo8B4Qob4Q8@04ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`0E
ooooo`03o`000?oooooooooo00?ooooo0_l0000?ooooo`;o00000_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B42o`0000;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMg
Molb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo
<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVY
ZOooool01oooool00omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo0006o`0000Go
oooo00?o0000ooooooooool04?ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=oooo
o`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool01Oooool6o`0000;ooooo00Go410@oooo
oooooooooooooa0@400@ooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool00oooool2o`0000Wooooo0_l00004ooooo`;o00000_ooool01Ol@413ooooooooo
oooooooo410@00Oooooo0_l00003ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool0
3Oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool03Oooool01Ol@413o
oooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool03_ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooo
oooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`02o`0001?ooooo00?o
0000ooooooooool03_ooool2o`0000Sooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool02?ooool2o`0000Cooooo00Go0000oooooooooooo
ooooo`00000?ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool06Oooool00ol0003oooooooooo`0Doooo
o`002oooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool00omE
EEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooo
oooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool0
00003_ooool00omgMgOoIVIVooooo`03ooooo`06o`000?lQ8B7o0000oc8b<_o<c<cooooo0_l0000C
ooooo`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`000007ooooo`;o00001Ooo
ool01?mgMgOoIVIVooooooooool3o`000004ob4Q8Ol0003o<S8bolc<c0Wooooo0_l00004ooooo`05
o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000
ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00Jooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go
410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool0
4Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04Oooool01Ol@413o
oooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Hoooo
o`?o00001_ooool2o`00013ooooo00Go410@oooooooooooooooooa0@4007ooooo`;o00001_ooool0
0ol0003oooooooooo`03o`0001?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oo
oooooooo017ooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003ooooooooo
o`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Co
oooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@
4004ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01_ooool2o`00013ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003o
ooooooooo`0<ooooo`;o00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b
<P04ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05?ooool000Wooooo00?oEEEE
ofIVI_l000006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00004?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0000Gooooo`03o`000?oooooooooo
01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?oo
ool4o`0000_ooooo0_l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00013ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0001Wooooo00?oEEEEofIVI_l0
00005_ooool007oooooo0_l0000Dooooo`;o00005Oooool00ol0003oooooooooo`0Kooooo`;o0000
W?ooool007oooooo0_l00006ooooo`;o00003?ooool2o`0001Gooooo00?o0000ooooooooool06ooo
ool2o`0009cooooo001oooooo`;o00001_ooool2o`0002?ooooo00?o0000ooooooooool0[_ooool2
o`0000;ooooo0_l00005ooooo`00Ooooool2o`0002_ooooo00?o0000ooooooooool09Oooool2o`00
08Oooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd5ooooo`00[?ooool00ol0003oooooooooo`0U
ooooo`;o0000R?ooool01?oMgMgo0000oa0@4?o<c<`6ooooo`001oooooooo`0004co00003?ooool0
1?o^k^ko8B4Qoa0@4?o^k^h6ooooo`001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`04o`000?oooooo
ooooooooo`;o00000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo0ol0
0005ooooo`03o`000?oooooooooo00;ooooo0_l000000ooooooo0000ooooo`07ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00[ooooo00Co8B4QogMgMomgMgOo<S8b1_ooool000Oooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02Ooo
ool2o`0001_ooooo00?o0000ooooooooool06oooool2o`0000Sooooo0ol0000Xooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`09ooooo`;o00000_oo
ool2o`0000Gooooo002/ooooo`03o`000?oooooooooo02Gooooo0_l0000Jooooo`;o0000M_ooool0
07oooooo0_l0000[ooooo`03o`000?oooooooooo043ooooo0ol0001fooooo`00Ooooool2o`00013o
oooo0_l0000Iooooo`03o`000?oooooooooo043ooooo0ol0001fooooo`00Ooooool2o`00013ooooo
0_l0000Iooooo`03o`000?oooooooooo0;Wooooo001oooooo`;o0000:oooool00ol0003ooooooooo
o`2iooooo`00[?ooool3o`0000[ooooo0_l0002]ooooo`00UOooool2o`0001Gooooo00?o0000oooo
ooooool01_ooool2o`0000;ooooo0_l00008ooooo`?o0000X_ooool009Gooooo0_l0000Eooooo`03
o`000?oooooooooo00Kooooo0_l00002ooooo`;o00002?ooool3o`000:;ooooo001oooooo`;o0000
:oooool00ol0003oooooooooo`0:ooooo`;o0000[Oooool007oooooo0_l0000@ooooo`;o00006Ooo
ool00ol0003oooooooooo`03ooooo`;o00002Oooool2o`0002oooooo0_l0001hooooo`00TOooool2
o`0001Wooooo00?o0000ooooooooool00oooool2o`0000Wooooo0_l00005ooooo`;o0000:?ooool2
o`0007Sooooo002:ooooo`;o00008?ooool00ol0003oooooooooo`02o`0001?ooooo0_l0000Woooo
o`;o0000NOooool008[ooooo0_l0000Pooooo`03o`000?oooooooooo00;o00004_ooool2o`0002So
oooo0_l0001iooooo`00[?ooool00ol0003oooooooooo`06ooooo`;o00003?ooool2o`000:?ooooo
002/ooooo`?o00001_ooool2o`0000Kooooo0_l0000Pooooo`;o0000Qoooool00:cooooo00?o0000
ooooooooool03_ooool2o`00023ooooo0_l00027ooooo`00[?ooool00ol0003oooooooooo`0ooooo
o`;o0000N?ooool00:cooooo00?o0000ooooooooool01_ooool2o`0003Oooooo0_l0001hooooo`00
[?ooool00ol0003oooooooooo`06ooooo`;o00007?ooool2o`0009?ooooo0020ooooo`;o00004?oo
ool2o`0001Sooooo00?o0000ooooooooool06oooool2o`0000Oooooo0_l0002Cooooo`00P?ooool2
o`00013ooooo0_l0000Hooooo`03o`000?oooooooooo01?ooooo0_l00006ooooo`;o0000=?ooool3
o`0006Gooooo0027ooooo`;o00008oooool00ol0003oooooooooo`0Cooooo`;o0000:Oooool2o`00
017ooooo0ol0001Uooooo`00Ooooool2o`0000Kooooo0_l0000Sooooo`?o0000?_ooool2o`0001;o
oooo0ol0001Tooooo`00Ooooool2o`0002_ooooo00?o0000ooooooooool00_ooool2o`0003Wooooo
0_l0000Cooooo`?o0000I?ooool008gooooo0_l0000Mooooo`03o`000?oooooooooo00;ooooo0_l0
000iooooo`;o0000N_ooool008gooooo0_l0000Mooooo`03o`000?oooooooooo00Cooooo0_l0000=
ooooo`;o0000Y?ooool0083ooooo0_l0000Zooooo`03o`000?oooooooooo00Cooooo0_l0000=oooo
o`;o00003_ooool2o`0000Wooooo0_l00029ooooo`00P?ooool2o`0002[ooooo00?o0000oooooooo
ool08oooool2o`0000Sooooo0ol00029ooooo`00[?ooool00ol0003oooooooooo`0=ooooo`;o0000
7_ooool2o`0008[ooooo002/ooooo`03o`000?oooooooooo00gooooo0_l0002Zooooo`00S_ooool2
o`0001[ooooo1Ol00004ooooo`;o0000/oooool008kooooo0_l0000Jooooo`?o00001_ooool2o`00
01cooooo0_l0002Eooooo`00[?ooool00ol0003oooooooooo`0Rooooo`;o00002Oooool2o`0008[o
oooo002/ooooo`03o`000?oooooooooo01Wooooo0_l0000Booooo`;o0000R_ooool00:cooooo00?o
0000ooooooooool04Oooool2o`0000Kooooo0_l0002Nooooo`00S_ooool2o`0001cooooo00?o0000
ooooooooool04Oooool2o`0001_ooooo0_l0000=ooooo`;o0000N_ooool008Wooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP02o`000003ooooool0003o000000;o8B4Q1?ooool5o`0000Cooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo02kooooo0_l0000=ooooo`;o0000N_oo
ool0083ooooo0_l00006ooooo`;o000000CoV9RHoooooonHV9SoMgMg0oooool2o`0000;o8B4Q1?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`0@ooooo`;o0000?Oooool2o`0006Sooooo0020ooooo`;o00001_ooool2o`0000?ooooo00?o
410@ooooooooool02_ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo1?l0
000?ooooo`;o0000?Oooool2o`0006Sooooo0025ooooo`;o00000_ooool01Ol0003ooooooooooooo
oooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`04o`000?oo
oooo0000o`0000[ooooo0_l0002/ooooo`00QOooool2o`0000;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo00_ooooo0_l0002/ooooo`00ROooool01Ol@413ooooooooooooooooo410@00oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo013o
oooo0_l0002Wooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oo
ooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool2o`00
00Gooooo0_l00006ooooo`;o0000Woooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool01Oooool2
o`0000;ooooo0_l0000=ooooo`;o0000=?ooool2o`0006Wooooo002/ooooo`03o`000?oooooooooo
00Cooooo0ol00017ooooo`;o0000JOooool008Wooooo0_l0000Qooooo`03o`000?oooooooooo00Co
oooo0_l0002cooooo`00ROooool2o`0000[ooooo0_l0000Eooooo`03o`000?oooooooooo01Kooooo
0_l00006ooooo`;o0000VOooool0087ooooo0_l00002ooooo`;o00003_ooool2o`0001Gooooo0ol0
000Fooooo`;o00001_ooool2o`0009Wooooo001looooo`;o00000oooool2o`0000;ooooo0_l0000U
ooooo`03o`000?oooooooooo00;o0000]oooool007cooooo0_l0000Mooooo`;o00003oooool00ol0
003oooooooooo`02o`0002Wooooo0_l0000=ooooo`;o0000OOooool008gooooo0_l00004ooooo`;o
00000oooool2o`000003ooooool0003o000000oooooo00?o0000ooooooooool03Oooool2o`0000ko
oooo0_l0000<ooooo`;o00003Oooool2o`0007gooooo0025ooooo`;o00001_ooool2o`0000Cooooo
0_l00003ooooo`;o00002?ooool2o`0000Sooooo00?o0000ooooooooool03Oooool3o`0000gooooo
0_l0000Iooooo`;o0000Ooooool008Gooooo0_l0000Kooooo`;o00001_ooool3o`00013ooooo0_l0
0003ooooo`;o00005Oooool2o`0000cooooo0ol0001nooooo`00ZOooool4o`0001Gooooo0_l0000E
ooooo`;o00003Oooool2o`0007kooooo002Jooooo`;o00003Oooool2o`000003ooooool0003ooooo
01Cooooo0_l0000Sooooo`;o0000Ooooool009Oooooo0_l000000ooooooo0000o`00000@ooooo`?o
00004oooool2o`0002?ooooo0_l0001oooooo`00Uoooool2o`0000Gooooo0_l0000<ooooo`03o`00
0?oooooooooo01?ooooo0_l0000Rooooo`;o0000P?ooool009kooooo0_l0000<ooooo`03o`000?oo
oooooooo03Oooooo0_l0000Booooo`;o0000K?ooool008kooooo0_l0000Kooooo`;o0000>Oooool2
o`00013ooooo1?l0001/ooooo`00S_ooool2o`00013ooooo0_l00009ooooo`;o00007Oooool2o`00
01[ooooo0_l0000@ooooo`;o0000K_ooool00:3ooooo0_l0000:ooooo`03o`000?oooooooooo00Go
oooo0_l0000Dooooo`;o00006?ooool2o`0008;ooooo002/ooooo`03o`000?oooooooooo00Gooooo
0_l00003ooooo`;o0000:Oooool2o`0008;ooooo002Mooooo`;o00003Oooool00ol0003ooooooooo
o`0:ooooo`;o0000[Oooool009;ooooo0_l00009ooooo`;o00003Oooool3o`000;Wooooo0022oooo
o`;o00003_ooool2o`0001Cooooo0_l00002ooooo`03o`000?oooooooooo00oooooo0_l0002Xoooo
o`00P_ooool2o`0000?ooooo0_l0000Oooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`;o
00002oooool2o`000:Sooooo0022ooooo`;o00000oooool2o`00017ooooo0_l0000@ooooo`03o`00
0?oooooooooo00;ooooo0_l0002eooooo`00V_ooool2o`0000Wooooo0_l00005ooooo`03o`000?oo
oooooooo00kooooo0_l0002Yooooo`00V_ooool2o`0000Wooooo0_l00005ooooo`;o00003oooool2
o`0000Sooooo0_l00009ooooo`;o0000U?ooool008?ooooo0_l0000Eooooo`;o00004?ooool2o`00
01Wooooo0_l00008ooooo`?o0000U?ooool008?ooooo0_l0000Cooooo`;o00004_ooool00ol0003o
ooooooooo`0=ooooo`;o00001oooool2o`0000[ooooo0_l0002Eooooo`00R?ooool2o`0000kooooo
0_l0000?ooooo`;o000000Coooooo`000?l0003o00003Oooool2o`0000Oooooo0_l0002Qooooo`00
Poooool2o`0000?ooooo0_l0000:ooooo`;o00004oooool2o`000003ooooool0003ooooo04Kooooo
0_l0001booooo`00Poooool2o`0000oooooo0_l0000Fooooo`03o`000?oooooooooo04Gooooo0_l0
001booooo`00Poooool2o`0002Oooooo00?o0000ooooooooool00oooool2o`00017ooooo0_l0000:
ooooo`;o0000UOooool008?ooooo0_l0000Wooooo`03o`000?oooooooooo00?ooooo0_l0000Aoooo
o`;o00002_ooool2o`0009Gooooo0024ooooo`;o00009_ooool00ol0003oooooooooo`03ooooo`;o
0000]?ooool008Cooooo0_l0000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Go
oooo00?oA4A4o`000?l000000_l00005ooooo`03o`000?oooooooooo00?ooooo0_l0000>ooooo`;o
0000Y?ooool0097ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool3o`0000Go
oooo00?o0000ooooooooool04_ooool3o`000:Cooooo002Aooooo`05oa0@4?ooooooooooooooool@
41004?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01;ooooo0_l0002Uooooo`00
QOooool2o`0000[ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Co
oooo0ol0000Booooo`;o00006?ooool2o`0008_ooooo0025ooooo`;o00002_ooool01Ol0003ooooo
oooooooooooo000000Kooooo0_l00004ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0
003oooooooooo`0Booooo`;o00002oooool2o`0000_ooooo0_l0002;ooooo`00TOooool01Ol@413o
oooooooooooooooo410@00Kooooo0_l00004ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool07_ooool3o`0009Sooooo002>ooooo`;o000000KoooooogMgMonHV9SooooooiRHV?mgMgL<
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07_ooool2o`0000cooooo0ol0002:
ooooo`00S_ooool2o`000006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool4o`0000;ooooo0_l0
0002ooooo`03o`000?oooooooooo00Sooooo0_l0000Rooooo`?o00004Oooool2o`0007Oooooo002X
ooooo`;o00000_ooool00ol0003oooooooooo`08ooooo`;o0000=_ooool2o`0007Oooooo002Roooo
o`;o00002?ooool00ol0003oooooooooo`0Zooooo`?o0000S?ooool009[ooooo0_l00006ooooo`Co
00001_ooool3o`0002[ooooo0ol0002<ooooo`00V_ooool2o`0000Sooooo0_l00006ooooo`?o0000
7?ooool2o`0000cooooo0_l0002=ooooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool07?oo
ool2o`0000cooooo0_l0002=ooooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool0:_ooool2
o`0008gooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo01So
oooo0_l0002Oooooo`00[?ooool00ol0003oooooooooo`0<ooooo`;o00002_ooool2o`0009oooooo
002Fooooo`;o00001?ooool2o`0000kooooo00?o0000ooooooooool03?ooool2o`000:_ooooo002F
ooooo`;o00001?ooool2o`0000[ooooo0_l00002ooooo`03o`000?oooooooooo02Gooooo0_l0002B
ooooo`00Z?ooool2o`0000;ooooo0ol0000Uooooo`;o00004oooool2o`0007gooooo002Oooooo`;o
00002oooool00ol0003oooooooooo`0jooooo`;o0000OOooool009Sooooo0_l00005ooooo`;o0000
2oooool00ol0003oooooooooo`09ooooo`;o0000;Oooool2o`0007oooooo0027ooooo`;o00003ooo
ool2o`0001;ooooo0ol00008ooooo`?o00002_ooool2o`00027ooooo0_l0001oooooo`00Qoooool2
o`0000Wooooo0_l0000Hooooo`?o00002?ooool3o`0000[ooooo0_l0002Rooooo`00T_ooool2o`00
01Sooooo00?o0000ooooooooool02Oooool2o`000:kooooo002/ooooo`03o`000?oooooooooo00Ko
oooo0_l0000;ooooo`;o0000Y?ooool00:cooooo00?o0000ooooooooool01_ooool2o`0000_ooooo
0_l0000=ooooo`;o0000UOooool00:cooooo0ol0000Rooooo`;o0000UOooool009Cooooo0_l0000F
ooooo`03o`000?oooooooooo027ooooo0_l0002Fooooo`00U?ooool2o`0001Kooooo00?o0000oooo
ooooool08Oooool2o`0009Kooooo0028ooooo`;o00008_ooool00ol0003oooooooooo`2iooooo`00
R?ooool2o`0001Kooooo1_l00006ooooo`03o`000?oooooooooo0;Wooooo002Pooooo`Ko000000?o
ooooo`000?l000000oooool00ol0003oooooooooo`2iooooo`00Yoooool2o`0000?ooooo00?o0000
ooooooooool0^Oooool0093ooooo0_l0000Jooooo`03o`000?oooooooooo0;Wooooo002@ooooo`;o
00006_ooool00ol0003oooooooooo`0;ooooo`;o0000[?ooool00:cooooo0ol0000;ooooo`;o0000
[?ooool00:cooooo00?o0000ooooooooool02oooool2o`000:cooooo002Iooooo`;o00004Oooool0
0ol0003oooooooooo`0;ooooo`;o0000[?ooool009Wooooo0_l0000Aooooo`03o`000?oooooooooo
01[ooooo0_l0002Mooooo`00[?ooool00ol0003oooooooooo`09ooooo`;o00003oooool2o`0009go
oooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_oo
ool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool02Oooool2o`00
00oooooo0_l0002Mooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46oooo
o`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Goooo
o`;o0000X?ooool008Wooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo
00Sooooo00?o0000ooooool000001?l0000Iooooo`;o0000X?ooool008Wooooo00?o0000oooooooo
ool00_l0000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01ol0002iooooo`00
ROooool00ol0003oooooooooo`02o`0000kooooo00CoEEEEolc<c?l0003o00000_ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0^Oooool008Wooooo00Go410@oooooooo
oooooooooa0@4006ooooo`;o00001_ooool01?nYZJWoMgMgo`000?l00002ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0^Oooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06
ooooo`;o00000oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`2iooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo0_l0
0002ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool0^Oooool009Gooooo0_l0000E
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Fooooo`;o
00005?ooool00ol0003oooooooooo`2iooooo`00U_ooool2o`0001Cooooo0ol0002iooooo`00VOoo
ool2o`00017ooooo00?o0000ooooooooool0^Oooool009Wooooo0_l0000Aooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`03o`000?oooooooooo00oooooo0_l0002Xooooo`00[?ooool00ol0003o
ooooooooo`0?ooooo`;o00003oooool2o`0009Oooooo002/ooooo`03o`000?oooooooooo023ooooo
0_l0002Gooooo`00Voooool2o`0000oooooo00?o0000ooooooooool0^Oooool009_ooooo0_l0000?
ooooo`03o`000?oooooooooo0;Wooooo002Sooooo`Co00001Oooool3o`0000Wooooo1?l0002/oooo
o`00X?ooool2o`000003ooooool0003o000000;o00001Oooool00ol0003oooooooooo`09ooooo`Co
0000[?ooool00:3ooooo0_l0000:ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Cooooo`;o00005oooool00ol0
003oooooooooo`2iooooo`00Toooool2o`0001Oooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool06?ooool2o`0009oooooo002/ooooo`03o`000?oooooooooo01Sooooo0_l0
002Oooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`04
o`000?oooooo0000o`0001Cooooo0_l0002Rooooo`00Uoooool2o`0001?ooooo00Co0000ooooool0
003o00005?ooool2o`000:;ooooo002Gooooo`;o00004oooool00ol0003oooooooooo`02o`000;Oo
oooo002Gooooo`Co00004Oooool00ol0003oooooooooo`02o`000;Oooooo002Iooooo`;o00004Ooo
ool00ol0003oooooooooo`2iooooo`00[?ooool2o`000;[ooooo002Yooooo`;o000000Coooooo`00
0?l0003o0000^Oooool009gooooo0_l00006ooooo`;o00000_ooool2o`000003ooooool0003ooooo
0;[ooooo002Mooooo`Co00001?ooool2o`0000Gooooo00?o0000ooooooooool0^Oooool009oooooo
0_l0000;ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00_ooooo0_l0
002/ooooo`00Y?ooool2o`0000Kooooo00?o0000ooooooooool02oooool2o`000:cooooo002Roooo
o`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`2iooooo`00Y?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`03o`000?oooooooooo00Gooooo
0ol0002iooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31
ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00
X_ooool00omEEEGoIVIVo`000033ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00Z_ooool01?l@413o0000o`000?l0002jooooo`00Zoooool00ol0003ooooo
ooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool01_l0003oMgMgo`000?l0
003oEEEEonk^k[Oooooo002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoEEEE]oooool00:_ooooo
00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`2eooooo`00Zoooool00ol0003ok^k^oooo
o`02ooooo`03o`000?oooooooooo0;Gooooo002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoIVIV
]oooool00:[ooooo00?o410@o`000?mgMgL00_l000000omVIVKok^k^ooooo`2fooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.391 .36902 Mdot
.57618 .21689 Mdot
.4963 .40281 Mdot
.42274 .40344 Mdot
.40905 .61638 Mdot
.57633 .74263 Mdot
.43834 .55673 Mdot
.61225 .84306 Mdot
.70604 .56979 Mdot
.47407 .77769 Mdot
.42606 .31724 Mdot
.54234 .93285 Mdot
.66618 .55895 Mdot
.41182 .54177 Mdot
.51734 .95516 Mdot
.54605 .3933 Mdot
.40206 .36353 Mdot
.66453 .57671 Mdot
.57439 .57332 Mdot
.37436 .48082 Mdot
.65911 .58799 Mdot
.63602 .35048 Mdot
.64859 .40736 Mdot
.65833 .61008 Mdot
.39306 .83149 Mdot
.59673 .43666 Mdot
.48776 .21946 Mdot
.57593 .53936 Mdot
.38691 .2806 Mdot
.58412 .23433 Mdot
.64347 .64811 Mdot
.70846 .5695 Mdot
.64897 .77185 Mdot
.51084 .17622 Mdot
.60523 .36253 Mdot
.42484 .87543 Mdot
.62524 .22832 Mdot
.56786 .42045 Mdot
.42076 .12344 Mdot
.5153 .96709 Mdot
.39092 .82717 Mdot
.56955 .2741 Mdot
.62584 .55192 Mdot
.41144 .21329 Mdot
.3902 .62122 Mdot
.48147 .17524 Mdot
.42022 .63436 Mdot
.70993 .46549 Mdot
.55625 .72569 Mdot
.38167 .34214 Mdot
.70774 .45637 Mdot
.50048 .05962 Mdot
.6993 .78741 Mdot
.62333 .46029 Mdot
.62846 .48784 Mdot
.68774 .66862 Mdot
.60183 .85691 Mdot
.40026 .37957 Mdot
.68531 .35701 Mdot
.40213 .72657 Mdot
.50697 .20535 Mdot
.557 .06058 Mdot
.42958 .10227 Mdot
.54096 .44003 Mdot
.64995 .75882 Mdot
.70131 .62088 Mdot
.48904 .7683 Mdot
.52842 .33733 Mdot
.57166 .43421 Mdot
.64638 .6559 Mdot
.42731 .20742 Mdot
.51696 .42547 Mdot
.46533 .77252 Mdot
.53441 .6658 Mdot
.42917 .1033 Mdot
.46202 .63453 Mdot
.69889 .78808 Mdot
.55486 .30435 Mdot
.46549 .04818 Mdot
.57775 .65 Mdot
.57216 .815 Mdot
.57506 .22022 Mdot
.42097 .56093 Mdot
.5799 .29496 Mdot
.65666 .76254 Mdot
.5548 .42782 Mdot
.40492 .55398 Mdot
.41401 .33899 Mdot
.39644 .55152 Mdot
.53287 .35178 Mdot
.38735 .79978 Mdot
.7666 .48408 Mdot
.5313 .62881 Mdot
.43764 .2242 Mdot
.5419 .56665 Mdot
.76338 .4407 Mdot
.41419 .58462 Mdot
.70561 .46455 Mdot
.68667 .81105 Mdot
.39493 .50515 Mdot
.41249 .21528 Mdot
.42131 .76004 Mdot
.54515 .92672 Mdot
.44171 .12398 Mdot
.60616 .75776 Mdot
.53216 .20919 Mdot
.45514 .14935 Mdot
.55962 .64857 Mdot
.52994 .63459 Mdot
.64343 .66249 Mdot
.4331 .71146 Mdot
.41953 .44401 Mdot
.70869 .56004 Mdot
.40256 .80378 Mdot
.51261 .36076 Mdot
.53479 .25679 Mdot
.69471 .6632 Mdot
.7036 .62173 Mdot
.61122 .21056 Mdot
.6656 .55565 Mdot
.66026 .51864 Mdot
.39292 .23529 Mdot
.64358 .66402 Mdot
.44045 .2988 Mdot
.38493 .68764 Mdot
.7488 .37696 Mdot
.50168 .11756 Mdot
.52557 .5872 Mdot
.65025 .40504 Mdot
.45387 .11086 Mdot
.4955 .98447 Mdot
.56631 .76679 Mdot
.61657 .61902 Mdot
.43389 .08441 Mdot
.6096 .19633 Mdot
.37554 .4504 Mdot
.47243 .77479 Mdot
.62214 .81737 Mdot
.5058 .96958 Mdot
.64624 .17595 Mdot
.45409 .7329 Mdot
.57799 .49431 Mdot
.40258 .35681 Mdot
.38052 .64852 Mdot
.67394 .72349 Mdot
.35602 .6804 Mdot
.54909 .67105 Mdot
.43026 .2519 Mdot
.44494 .00548 Mdot
.43719 .81069 Mdot
.54495 .32741 Mdot
.65729 .61957 Mdot
.50745 .37888 Mdot
.50925 .85597 Mdot
.57627 .15147 Mdot
.45305 .06115 Mdot
.69367 .66062 Mdot
.62431 .22873 Mdot
.58448 .16199 Mdot
.59964 .56308 Mdot
.46737 .04602 Mdot
.39833 .86854 Mdot
.48313 .93175 Mdot
.62404 .54203 Mdot
.40152 .27937 Mdot
.67854 .71023 Mdot
.58526 .79911 Mdot
.56732 .41068 Mdot
.57918 .15159 Mdot
.37738 .56573 Mdot
.51718 .66969 Mdot
.54919 .34611 Mdot
.40564 .55614 Mdot
.53172 .72086 Mdot
.64361 .77745 Mdot
.75934 .42043 Mdot
.51905 .84075 Mdot
.49953 .32591 Mdot
.3958 .22344 Mdot
.5428 .10464 Mdot
.47014 .99654 Mdot
.55682 .56589 Mdot
.38031 .76454 Mdot
.46071 .71065 Mdot
.70588 .55183 Mdot
.74543 .37008 Mdot
.71185 .56108 Mdot
.41123 .91315 Mdot
.62241 .59069 Mdot
.43202 .02959 Mdot
.38045 .64888 Mdot
.51363 .33066 Mdot
.52611 .03037 Mdot
.63712 .80014 Mdot
.36219 .48757 Mdot
.52447 .95218 Mdot
.42068 .29097 Mdot
.76948 .56248 Mdot
.52008 .18103 Mdot
.44632 .34511 Mdot
.45334 .32292 Mdot
.52185 .46679 Mdot
.41712 .67703 Mdot
.76479 .59945 Mdot
.42786 .16238 Mdot
.43518 .36048 Mdot
.55382 .78643 Mdot
.41821 .46369 Mdot
.42615 .56096 Mdot
.43634 .2704 Mdot
.66536 .46743 Mdot
.54732 .28605 Mdot
.5832 .80244 Mdot
.55877 .50701 Mdot
.40831 .2395 Mdot
.5272 .24616 Mdot
.39327 .84555 Mdot
.45278 .70027 Mdot
.42552 .82304 Mdot
.54318 .93572 Mdot
.52743 .24213 Mdot
.68736 .37292 Mdot
.59887 .77496 Mdot
.54346 .85856 Mdot
.55196 .43492 Mdot
.45938 .80444 Mdot
.55675 .18314 Mdot
.52271 .65463 Mdot
.51321 .96015 Mdot
.50819 .00754 Mdot
.51654 .30098 Mdot
.51428 .5166 Mdot
.76109 .60618 Mdot
.50112 .82557 Mdot
.48585 .21558 Mdot
.56027 .38378 Mdot
.46718 .09559 Mdot
.66284 .51413 Mdot
.43926 .13319 Mdot
.5565 .06105 Mdot
.60393 .67394 Mdot
.54027 .87146 Mdot
.42598 .21202 Mdot
.70948 .57876 Mdot
.54415 .52644 Mdot
.55915 .13281 Mdot
.42045 .74649 Mdot
.42103 .23054 Mdot
.43531 .08862 Mdot
.36323 .55659 Mdot
.50873 .34851 Mdot
.51077 .3255 Mdot
.5821 .1651 Mdot
.59634 .44776 Mdot
.54233 .32711 Mdot
.63085 .53461 Mdot
.45183 .60574 Mdot
.61411 .83533 Mdot
.7019 .41629 Mdot
.53059 .77723 Mdot
.48465 .21468 Mdot
.52297 .8879 Mdot
.53206 .48617 Mdot
.44884 .83115 Mdot
.38725 .53986 Mdot
.4141 .56066 Mdot
.59867 .67728 Mdot
.39646 .76272 Mdot
.59905 .52065 Mdot
.4047 .80953 Mdot
.6298 .51544 Mdot
.476 .77917 Mdot
.55963 .70994 Mdot
.57159 .14409 Mdot
.55359 .59299 Mdot
.50771 .77799 Mdot
.70969 .47942 Mdot
.42859 .29969 Mdot
.52461 .83452 Mdot
.41652 .1321 Mdot
.51815 .63272 Mdot
.55018 .59665 Mdot
.62301 .22772 Mdot
.56566 .90171 Mdot
.55575 .66282 Mdot
.4682 .32102 Mdot
.47128 .80597 Mdot
.43899 .91333 Mdot
.45127 .1968 Mdot
.59212 .77836 Mdot
.74445 .36912 Mdot
.67683 .33747 Mdot
.55257 .91391 Mdot
.67627 .34183 Mdot
.4769 .67147 Mdot
.6702 .31233 Mdot
.48178 .94095 Mdot
.53116 .93914 Mdot
.35093 .39468 Mdot
.57286 .67627 Mdot
.62184 .6117 Mdot
.4675 .09919 Mdot
.70888 .5765 Mdot
.40308 .87712 Mdot
.41304 .54987 Mdot
.708 .47241 Mdot
.59938 .47526 Mdot
.43178 .54 Mdot
.66287 .45756 Mdot
.41266 .27982 Mdot
.66572 .53425 Mdot
.42153 .04848 Mdot
.52161 .39873 Mdot
.4061 .743 Mdot
.54411 .22829 Mdot
.63533 .78777 Mdot
.5333 .50891 Mdot
.4605 .99243 Mdot
.39272 .15972 Mdot
.68146 .22541 Mdot
.48626 .2473 Mdot
.56197 .77732 Mdot
.58542 .30592 Mdot
.46739 .05284 Mdot
.45027 .79489 Mdot
.43594 .39663 Mdot
.45432 .64537 Mdot
.43481 .18806 Mdot
.57193 .8999 Mdot
.57255 .15376 Mdot
.54318 .55903 Mdot
.65573 .41426 Mdot
.52046 .61646 Mdot
.52219 .47356 Mdot
.56312 .19324 Mdot
.58592 .72195 Mdot
.62397 .54504 Mdot
.59943 .5629 Mdot
.42762 .72926 Mdot
.72158 .74453 Mdot
.5976 .47108 Mdot
.55037 .18326 Mdot
.54064 .44291 Mdot
.66839 .72534 Mdot
.47127 .21552 Mdot
.3753 .51943 Mdot
.60212 .27365 Mdot
.49482 .7333 Mdot
.48004 .18171 Mdot
.64353 .1713 Mdot
.54919 .92575 Mdot
.66994 .30815 Mdot
.41011 .82931 Mdot
.58353 .6436 Mdot
.50613 .16298 Mdot
.37991 .61962 Mdot
.47484 .84876 Mdot
.55047 .92374 Mdot
.6935 .2418 Mdot
.53065 .88489 Mdot
.50145 .97791 Mdot
.45007 .98428 Mdot
.38078 .7726 Mdot
.51961 .56551 Mdot
.52563 .78371 Mdot
.50225 .97288 Mdot
.61007 .84325 Mdot
.51539 .59429 Mdot
.61432 .73357 Mdot
.59544 .467 Mdot
.54914 .79703 Mdot
.4038 .26044 Mdot
.70754 .48987 Mdot
.46313 .09813 Mdot
.64835 .26946 Mdot
.52887 .09861 Mdot
.6442 .38998 Mdot
.65685 .27786 Mdot
.64564 .38869 Mdot
.42293 .93423 Mdot
.40384 .95957 Mdot
.63214 .2474 Mdot
.49116 .88133 Mdot
.49433 .33947 Mdot
.36671 .37595 Mdot
.39885 .60284 Mdot
.46145 .66049 Mdot
.45765 .99253 Mdot
.64404 .66383 Mdot
.43347 .41667 Mdot
.5213 .70257 Mdot
.57991 .36621 Mdot
.50421 .24118 Mdot
.71232 .48609 Mdot
.58902 .79774 Mdot
.51546 .02081 Mdot
.46063 .99333 Mdot
.46285 .14624 Mdot
.73215 .71345 Mdot
.48921 .14476 Mdot
.53731 .70814 Mdot
.51099 .76844 Mdot
.48837 .35135 Mdot
.5824 .88451 Mdot
.54767 .9261 Mdot
.48222 .21571 Mdot
.50127 .71692 Mdot
.499 .22597 Mdot
.56064 .4895 Mdot
.38215 .20841 Mdot
.42727 .25737 Mdot
.48629 .93166 Mdot
.44011 .69514 Mdot
.54844 .33846 Mdot
.5321 .53251 Mdot
.40803 .38619 Mdot
.49032 .14982 Mdot
.5174 .26374 Mdot
.44543 .31513 Mdot
.62526 .81274 Mdot
.4475 .51831 Mdot
.6127 .38888 Mdot
.45536 .14923 Mdot
.4671 .88385 Mdot
.59728 .50196 Mdot
.55753 .37117 Mdot
.3689 .33677 Mdot
.77034 .48102 Mdot
.48682 .09816 Mdot
.4296 .14882 Mdot
.47035 .27011 Mdot
.70033 .59744 Mdot
.48966 .98394 Mdot
.43451 .2807 Mdot
.60138 .27417 Mdot
.71582 .75606 Mdot
.49011 .73747 Mdot
.43126 .54582 Mdot
.51422 .75798 Mdot
.52801 .88225 Mdot
.58847 .60765 Mdot
.76969 .52765 Mdot
.43919 .65508 Mdot
.61312 .40162 Mdot
.56564 .26366 Mdot
.54601 .51381 Mdot
.51758 .38422 Mdot
.54309 .63988 Mdot
.61088 .84458 Mdot
.53103 .45363 Mdot
.44564 .06563 Mdot
.54715 .17152 Mdot
.39384 .65737 Mdot
.39407 .75543 Mdot
.61081 .7389 Mdot
.43588 .18862 Mdot
.75091 .37529 Mdot
.51304 .72317 Mdot
.56597 .90786 Mdot
.36324 .56335 Mdot
.41402 .55508 Mdot
.6707 .31185 Mdot
.59818 .51161 Mdot
.3968 .50544 Mdot
.3756 .54153 Mdot
.41433 .20624 Mdot
.56956 .60143 Mdot
.48389 .18281 Mdot
.50933 .17277 Mdot
.5573 .05757 Mdot
.61715 .60787 Mdot
.4688 .64502 Mdot
.6259 .52035 Mdot
.57453 .66365 Mdot
.52172 .55051 Mdot
.49944 .2676 Mdot
.62239 .44902 Mdot
.62022 .60683 Mdot
.48102 .2955 Mdot
.58914 .40888 Mdot
.7002 .62583 Mdot
.41283 .65377 Mdot
.39355 .64714 Mdot
.57737 .46503 Mdot
.57454 .53454 Mdot
.49055 .68176 Mdot
.48087 .69281 Mdot
.56974 .20499 Mdot
.68672 .37834 Mdot
.4738 .93446 Mdot
.57499 .46042 Mdot
.38038 .35198 Mdot
.49699 .98543 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00VOooool2o`0000Wooooo00?o0000ooooooooool01Oooool01?l0003ooooo
o`000?l0002hooooo`00VOooool2o`0000Wooooo00?o0000ooooooooool01Oooool01?l0003ooooo
o`000?l0002hooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Rooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool00_ooool2o`000;Gooooo002/ooooo`?o
00000_ooool2o`000;Gooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Eooooo`;o00005Ooo
ool00ol0003oooooooooo`05ooooo`;o0000/_ooool009Gooooo0_l0000Eooooo`03o`000?oooooo
oooo00Gooooo0_l0002booooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00XOooool2o`0000Wooooo00?o
0000ooooooooool0^Oooool009;ooooo0_l0000<ooooo`?o00002Oooool00ol0003oooooooooo`2i
ooooo`00T_ooool2o`0000cooooo0ol00009ooooo`?o0000^Oooool00:7ooooo0_l00009ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00oooooo0_l0002Xooooo`00W?oo
ool2o`0000kooooo0_l0000@ooooo`;o0000Z?ooool009cooooo0_l0000>ooooo`;o00004?ooool2
o`000:Sooooo002Jooooo`;o00004?ooool00ol0003oooooooooo`2iooooo`00V_ooool2o`00013o
oooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0
002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00U_ooool2o`0001Cooooo00?o0000ooooooooool0^Oooool009Kooooo0_l0000Dooooo`03o`00
0?oooooooooo0;Wooooo002Fooooo`;o00005?ooool00ol0003oooooooooo`2iooooo`00XOooool2
o`0000Wooooo00?o0000ooooooooool0^Oooool009oooooo1?l00004ooooo`;o00000oooool00ol0
003oooooooooo`06ooooo`;o0000/Oooool009oooooo1?l00004ooooo`;o00000oooool3o`0000Ko
oooo0_l0002aooooo`00U?ooool2o`0000_ooooo0_l00009ooooo`03o`000?oooooooooo00_ooooo
0_l0002/ooooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool02oooool2o`000:cooooo002/
ooooo`03o`000?oooooooooo0;Wooooo002Looooo`;o00003_ooool00ol0003oooooooooo`2ioooo
o`00W?ooool2o`0000kooooo00?o0000ooooooooool0^Oooool008Wooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool2o`000;[ooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`;o0000^_ooool0087o
oooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41000oooool2o`0000Gooooo0_l000000ooo
ooooZJVYoeEEE@09ooooo`03o`000?oooooooooo00?ooooo0ol0002iooooo`00ROooool01Ol0003o
oooooooooooooooo000000?ooooo0_l00005ooooo`;o00000_ooool00olQ8B7oooooooooo`06oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0^Oooool008Wooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005
ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05oa0@4?ooooooooooooooool@41000_ooool2
o`0000Kooooo0_l00002ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0@ooooo`;o0000Yoooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02
ooooo`;o00001_ooool2o`0000?ooooo00?o<S8booooooooool00_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo013ooooo0_l0002Wooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00_ooooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00Woooool2o`0000Oooooo0_l00002ooooo`03o`000?oooooooooo01Co
oooo0_l0002Sooooo`00U?ooool2o`0000Oooooo1?l00007ooooo`;o00000_ooool00ol0003ooooo
ooooo`0Dooooo`;o0000Xoooool009Cooooo0_l00007ooooo`;o00002Oooool2o`0000;ooooo0ol0
000Fooooo`?o0000X?ooool00:cooooo00?o0000ooooooooool05Oooool4o`000:3ooooo002/oooo
o`03o`000?oooooooooo01Gooooo0_l0002Rooooo`00R?ooool2o`0002;ooooo00?o0000oooooooo
ool06?ooool2o`0009oooooo0028ooooo`;o00002_ooool2o`0001Kooooo00Co0000ooooool0003o
00005oooool2o`0009oooooo002Dooooo`;o00005_ooool01?l0003oooooo`000?l0000Gooooo`;o
0000Woooool00:cooooo00?o0000ooooooooool0;?ooool2o`0008_ooooo002/ooooo`03o`000?oo
oooooooo00;o00002_ooool2o`0001kooooo0_l0002;ooooo`00YOooool2o`0000Gooooo1Ol0000:
ooooo`;o00007oooool2o`0008[ooooo002Uooooo`;o00001Oooool00ol0003oooooooooo`02o`00
02_ooooo0_l0002:ooooo`00YOooool3o`0000Cooooo00?o0000ooooooooool00oooool2o`0000So
oooo1?l0002Xooooo`00YOooool3o`0000Cooooo00?o0000ooooooooool00oooool2o`0000Sooooo
1?l0002Xooooo`00U_ooool2o`0001Cooooo00?o0000ooooooooool0^Oooool009Kooooo0_l0000D
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo017ooooo0_l0002Voooo
o`00Voooool2o`0000oooooo00?o0000ooooooooool04Oooool2o`0000kooooo0_l0002Fooooo`00
Voooool2o`0000oooooo0ol0000Qooooo`;o0000U_ooool00:cooooo00?o0000ooooooooool0^Ooo
ool008oooooo0_l00003ooooo`;o00005_ooool01?l0003oooooo`000?l0000Cooooo`;o0000Xooo
ool008Gooooo0_l00008ooooo`;o00000oooool2o`0001Kooooo00Co0000ooooool0003o00001_oo
ool2o`0000_ooooo0_l0000;ooooo`;o0000U_ooool008Gooooo0_l00007ooooo`;o00000oooool2
o`0001Oooooo00?o0000ooooooooool01oooool2o`0001Sooooo0_l0002Fooooo`00S_ooool3o`00
00;ooooo0_l0000=ooooo`;o00000_ooool3o`0000?ooooo00?o0000ooooooooool0^Oooool008oo
oooo0_l0000Aooooo`;o00000_ooool4o`0000;ooooo00?o0000ooooooooool05_ooool2o`000:7o
oooo002Xooooo`;o00000_ooool00ol0003oooooooooo`0Eooooo`?o0000XOooool008Wooooo0_l0
000<ooooo`;o00004oooool3o`0001Gooooo0_l0000Qooooo`;o0000Ooooool008Wooooo0_l0000<
ooooo`;o00004_ooool2o`0000gooooo0_l0000Hooooo`?o00004?ooool2o`0007oooooo002Aoooo
o`;o00006?ooool2o`0000gooooo0_l0000Hooooo`?o0000TOooool0097ooooo0_l0000Iooooo`03
o`000?oooooooooo01Sooooo0_l0002Oooooo`00R?ooool2o`0002;ooooo00?o0000ooooooooool0
6?ooool2o`0009oooooo0028ooooo`;o00000oooool2o`0001gooooo00?o0000ooooooooool0^Ooo
ool008gooooo0_l00002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`?o00001_ooool2o`0003Cooooo0_l0001kooooo`00TOoo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo
0ol00006ooooo`;o0000=?ooool2o`0007_ooooo0029ooooo`Ko00000_ooool01Ol@413ooooooooo
oooooooo410@013ooooo0ol00003ooooo`03o`000?oooooooooo00Kooooo0_l0000Pooooo`;o0000
Soooool0097ooooo00Co0000oooooooooooooooo0_l0000>ooooo`04ogMgMolb<S;o0000o`0000?o
oooo0ol0000Xooooo`;o0000Soooool0097ooooo00Co0000oooooooooooooooo0_l0000;ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2iooooo`00TOooool00ol@413o
ooooooooo`02o`0000cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`;o
0000[oooool008cooooo0_l00003ooooo`03ogMgMonHV9Sooooo00;o00003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Sooooo0_l0002_ooooo`00S?ooool2o`0000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`02ooooo`;o0000
3_ooool2o`000:Gooooo002[ooooo`;o00001?ooool2o`0000kooooo0_l0002Uooooo`00Uoooool2
o`0000Wooooo0_l00007ooooo`;o0000<?ooool2o`0008Wooooo002Gooooo`;o00002Oooool2o`00
00Sooooo00?o0000ooooooooool05?ooool2o`0000Sooooo0_l0000>ooooo`;o0000ROooool00:co
oooo0ol0000Dooooo`;o00002?ooool2o`0009Wooooo002;ooooo`;o00000_ooool2o`0001_ooooo
00?o0000ooooooooool0<?ooool2o`0008Oooooo0026ooooo`;o00000oooool2o`0000;ooooo0_l0
0005ooooo`;o00005?ooool00ol0003oooooooooo`0`ooooo`;o0000Qoooool008Kooooo0_l0000>
ooooo`;o00005?ooool00ol0003oooooooooo`0<ooooo`;o0000Zoooool00:cooooo00?o0000oooo
ooooool03?ooool2o`000:_ooooo002Aooooo`;o00006Oooool00ol0003oooooooooo`2iooooo`00
TOooool2o`0001;ooooo0_l00005ooooo`03o`000?oooooooooo01Oooooo0_l0002Pooooo`00YOoo
ool2o`0000Gooooo00?o0000ooooooooool05oooool2o`000:3ooooo002Dooooo`;o00000_ooool2
o`0001;ooooo0ol00002ooooo`;o0000]Oooool009Cooooo0_l00002ooooo`;o00004_ooool00ol0
003oooooooooo`02ooooo`;o00002oooool2o`000:Sooooo002/ooooo`03o`000?oooooooooo00oo
oooo0_l00008ooooo`;o0000W_ooool00:cooooo00?o0000ooooooooool06Oooool2o`0001[ooooo
0_l00022ooooo`00[?ooool00ol0003oooooooooo`0eooooo`;o0000P_ooool009[ooooo0_l0000@
ooooo`03o`000?oooooooooo03Gooooo0_l00022ooooo`00Toooool2o`0000Gooooo0_l0000@oooo
o`03o`000?oooooooooo0;Wooooo002Cooooo`;o00003?ooool2o`0000Wooooo00?o0000oooooooo
ool0^Oooool009cooooo0_l00003ooooo`;o00002Oooool5o`000;Oooooo002Looooo`;o00003Ooo
ool2o`0000;ooooo0_l00009ooooo`;o0000[?ooool00:_ooooo0_l00003ooooo`;o00002?ooool2
o`000:cooooo002/ooooo`04o`000?ooooooooooooooo`;o0000]_ooool0083ooooo0_l0000Zoooo
o`03o`000?oooooooooo00Kooooo0_l0000_ooooo`;o0000P?ooool0083ooooo0_l0000=ooooo`;o
00006Oooool3o`0000Sooooo0_l00005ooooo`;o0000:?ooool2o`00083ooooo0025ooooo`;o0000
2?ooool2o`0001Wooooo0ol0000?ooooo`;o0000:?ooool2o`00083ooooo0025ooooo`;o00004ooo
ool2o`00013ooooo00?o0000ooooooooool03Oooool2o`0002Sooooo0_l00020ooooo`00V_ooool2
o`00013ooooo00Co0000ooooool0003o00003?ooool2o`000:[ooooo0024ooooo`;o00008_ooool2
o`0000;ooooo1?l00006ooooo`;o00008?ooool2o`0008kooooo0024ooooo`;o00008_ooool2o`00
00;ooooo00?o0000ooooooooool01oooool2o`00023ooooo0_l0002>ooooo`00Roooool2o`0001oo
oooo00?o0000ooooooooool0>_ooool2o`0007gooooo002;ooooo`;o00002Oooool2o`0001Cooooo
00Co0000oooooooooooooooo0_l0000gooooo`;o0000OOooool008_ooooo0_l00009ooooo`;o0000
5?ooool01?l0003oooooooooooooool2o`0001cooooo0_l0002Hooooo`00ROooool01Oo^k^ko<S8b
o`000?l0003ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool05oooool2o`0000Kooooo0_l0002Hooooo`00R?ooool2o`000004
oiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo013ooooo0_l00005ooooo`;o0000=?ooool3
o`0006Wooooo0021ooooo`Ko000000?oooooo`000?l000000oooool00ol@413oooooooooo`0:oooo
o`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0@oooo
o`;o0000:?ooool2o`00017ooooo0ol0001Yooooo`00P?ooool2o`0000Oooooo00Go0000oooooooo
ooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`00
03[ooooo0_l0000Cooooo`;o0000J?ooool0083ooooo0_l00007ooooo`03o`000?oooooo000000;o
00003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool01?l0
003oooooo`000?l0000iooooo`;o00004oooool2o`0006Sooooo0029ooooo`05oa0@4?oooooo0000
o`000?l@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00Co0000
ooooool0003o0000>Oooool2o`0007gooooo0029ooooo`04ogMgMonHV9SooooooiRHV0;o00002_oo
ool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`02ooooo`;o00003?ooool2o`000:Oooooo0029ooooo`04onk^k_lb<S;o0000oc8b<P;o0000
2_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo00;o
oooo0_l0000<ooooo`;o00004?ooool2o`0000Wooooo0_l0002:ooooo`00[?ooool00ol0003ooooo
ooooo`0Rooooo`;o00002?ooool3o`0008[ooooo001jooooo`;o0000<?ooool00ol0003ooooooooo
o`0<ooooo`;o00007_ooool2o`0008_ooooo001jooooo`;o00006_ooool2o`0001Cooooo00?o0000
ooooooooool03?ooool2o`000:_ooooo002Fooooo`;o00005?ooool3o`0000Cooooo0_l0002coooo
o`00T_ooool2o`0001Kooooo0ol00006ooooo`;o00007?ooool2o`0009Gooooo002Booooo`;o0000
5_ooool3o`0002Cooooo0_l0000:ooooo`;o0000ROooool00:cooooo00?o0000ooooooooool06_oo
ool2o`0001;ooooo0_l00029ooooo`00[?ooool00ol0003oooooooooo`0Cooooo`;o00001Oooool2
o`0009gooooo002Fooooo`;o00005?ooool00ol0003oooooooooo`0Cooooo`;o00006oooool2o`00
00gooooo0_l0001hooooo`00U_ooool2o`0001Cooooo00?o0000ooooooooool0<?ooool2o`0000go
oooo0_l0001hooooo`00[?ooool00ol0003oooooooooo`0Cooooo`;o0000?Oooool2o`0006Gooooo
002/ooooo`?o00000_ooool2o`0000oooooo0_l0000mooooo`;o0000IOooool00:cooooo00?o0000
ooooooooool00_ooool2o`0000_ooooo0_l0002Xooooo`00[?ooool00ol0003oooooooooo`0?oooo
o`;o0000Z?ooool00:cooooo00?o0000ooooooooool05?ooool2o`000:?ooooo002/ooooo`03o`00
0?oooooooooo00kooooo0_l00004ooooo`;o00001_ooool2o`0009_ooooo002/ooooo`03o`000?oo
oooooooo00[ooooo0_l00002ooooo`;o00003?ooool2o`0003Kooooo0_l0001Sooooo`00[?ooool0
0ol0003oooooooooo`0:ooooo`;o0000B?ooool2o`0006?ooooo002Aooooo`;o00006Oooool00ol0
003oooooooooo`0:ooooo`;o0000[Oooool0097ooooo0_l0000Iooooo`03o`000?oooooooooo01co
oooo0_l00007ooooo`;o0000T_ooool008;ooooo0_l0000Xooooo`?o00007?ooool2o`0000Oooooo
0_l0002Booooo`00P_ooool2o`0002Sooooo00?o0000ooooooooool01oooool2o`000;3ooooo002/
ooooo`03o`000?oooooooooo00Oooooo0_l0000Yooooo`;o00003Oooool2o`0007Kooooo0009oooo
o`Co000000?o410@ooooooooool05_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46
ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000
oc8b<_oMgMd05_ooool00ol0003oooooooooo`0Eooooo`;o000000Koooooonk^k_lb<S;o0000oc8b
<_o^k^h5ooooo`;o8B4Q00Coooooo`000?l0003ooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b
<_oMgMd02oooool2o`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool0
1Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd06?ooool4o`000003
oa0@4?oooooooooo01;ooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4
A004ooooo`;o000000?oooooogMgMolb<S805_ooool00ol0003oooooooooo`0Eooooo`?o000000Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q00Woooooo`000?l0003ooooooiRHV?lQ8B7ok^k^
oooooom4A4@01oooool00omgMgOo<S8booooo`09ooooo`;o00000oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo01Wooooo
00?o0000ooooooooool05?ooool000Ko00001Oooool00ol0003oooooooooo`0@ooooo`Ko00000_oo
ool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003ooooo
ooooo`05ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooooooo
ool01Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^
00Gooooo0_l00002ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01?ooool2o`00
013ooooo0_l000001?l@413oooooooooooooool2o`0000_ooooo00?oV9RHob4Q8Oo^k^h01oooool3
o`0000[ooooo1?l000000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00kooooo00?o0000
ooooooooool03Oooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?oo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooo
oooo01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?o
MgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool0
3_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo
<S8booooo`0Eooooo`03o`000?oooooooooo00Cooooo0_l0000Booooo`04o`000?oooooooooooooo
o`?o00002oooool00onHV9So8B4Qonk^kP06ooooo`;o000000?o<S8booooooooool02_ooool2o`00
0003ooooool0003ooooo00;ooooo00?o0000ooooooooool03Oooool00omgMgOo<S8booooo`0>oooo
o`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;o
oooo01Wooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol0
003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`03oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<01Kooooo00?o0000ooooooooool01?ooool2o`0001;ooooo00Co0000
oooooooooooooooo0ol0000<ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00;ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0
003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06_ooool00ol0003oooooooooo`0Dooooo`002oooool0
0ol0003oooooooooo`0Hooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgoooo
o`03ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`00
0?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool06?ooool3o`0000Cooooo0_l0000Booooo`05oa0@4?oooooooooooooo
ool@41000_l0000=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool2o`00
00;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo017ooooo00Go410@
oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool0
4Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00;o00002Ooo
ool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool03_ooool2o`000006oooo
oomgMgOoV9RHoooooonHV9SoMgMg3?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Dooooo`002Oooool00omEEEGoIVIVo`00000Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o00001?ooool01OnHV9So
410@o`000?lQ8B7oc<c<00Cooooo1?l0000Gooooo`03o`000?oooooooooo01Sooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000gooooo0_l0
00001_ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool5o`0000Cooooo1?l0000Iooooo`03oeEEEOmVIVKo000001Kooooo0022ooooo`;o
0000:?ooool00ol0003oooooooooo`07ooooo`;o0000>_ooool2o`00013ooooo0ol0001Qooooo`00
O_ooool2o`0002cooooo00?o0000ooooooooool01oooool2o`0001kooooo0_l0000Jooooo`;o0000
4?ooool2o`0006;ooooo001nooooo`;o0000;?ooool00ol0003oooooooooo`0Aooooo`;o00005?oo
ool2o`0001Sooooo0_l0001[ooooo`;o00000_ooool2o`0000Gooooo002/ooooo`03o`000?oooooo
oooo017ooooo0_l00003ooooo`;o0000:Oooool2o`0006_ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`00
0?oMgMd5ooooo`00[?ooool00ol0003oooooooooo`0Fooooo`;o0000Uoooool01?oMgMgo0000oa0@
4?o<c<`6ooooo`001oooooooo`0004co00003?ooool01?o^k^ko8B4Qoa0@4?o^k^h6ooooo`001ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?oo
ool2o`0000Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool02_ooool01?lQ8B7oMgMgogMgMolb<S86ooooo`001ooo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`03ooooo`;o00008Oooool00ol0003oooooooooo`0@ooooo`;o00002ooo
ool2o`0000Sooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool02Oooool2o`0000;ooooo0_l00005ooooo`00ROooool2
o`00027ooooo00?o0000ooooooooool02?ooool2o`0000Kooooo0_l0002Wooooo`00[?ooool00ol0
003oooooooooo`08ooooo`;o00004oooool2o`0009[ooooo002/ooooo`04o`000?oooooooooooooo
o`;o00002Oooool2o`0000oooooo0_l00008ooooo`;o00002Oooool2o`0008Gooooo0022ooooo`;o
00005_ooool2o`00013ooooo00Co0000oooooooooooooooo0_l00009ooooo`;o00006Oooool2o`00
00Sooooo0ol00025ooooo`00P_ooool2o`0001Kooooo0_l0000@ooooo`03o`000?oooooooooo01go
oooo0_l00007ooooo`;o00002Oooool2o`0008Kooooo002/ooooo`?o00007Oooool2o`0000Oooooo
0_l0002Aooooo`00[?ooool00ol0003oooooooooo`0;ooooo`;o0000BOooool2o`00067ooooo002/
ooooo`03o`000?oooooooooo00_ooooo0_l00019ooooo`;o0000HOooool00:cooooo00?o0000oooo
ooooool01oooool2o`0000cooooo0_l0000Aooooo`;o00002Oooool2o`0008Cooooo002/ooooo`03
o`000?oooooooooo00Oooooo0_l0000<ooooo`;o00004Oooool2o`0000Wooooo0_l00024ooooo`00
Q_ooool2o`0000gooooo0_l0000Eooooo`03o`000?oooooooooo01Kooooo0_l0002Qooooo`00P_oo
ool2o`0000;ooooo0_l00006ooooo`;o00001Oooool2o`0001Gooooo00?o0000ooooooooool05_oo
ool2o`0000kooooo0_l0002Aooooo`00P_ooool2o`0000[ooooo0_l00005ooooo`;o00005Oooool0
0ol0003oooooooooo`0Uooooo`?o0000TOooool008oooooo0_l00004ooooo`;o00005Oooool00ol0
003oooooooooo`0Uooooo`;o0000T_ooool008Wooooo0_l00004ooooo`;o00006oooool3o`0000Co
oooo0_l0000Pooooo`;o00006Oooool2o`0007Kooooo0029ooooo`;o000000Coooooo`000?l0003o
oooo0_l0000Kooooo`03o`000?oooooooooo00Cooooo0_l0000Pooooo`;o00002oooool2o`0000co
oooo0_l0001fooooo`00O_ooool2o`0000cooooo0_l000000ooooooo0000o`000006ooooo`;o0000
4oooool00ol0003oooooooooo`0;ooooo`;o00009_ooool2o`0008Cooooo001nooooo`;o00003?oo
ool2o`000003ooooool0003o000000Co00000_ooool2o`0001?ooooo00?o0000ooooooooool02ooo
ool2o`0002Kooooo0_l0000<ooooo`?o0000MOooool007kooooo0_l0000?ooooo`Ko00005oooool0
0ol0003oooooooooo`0Mooooo`;o00008_ooool3o`0001;ooooo0_l0001Qooooo`00O_ooool2o`00
00?ooooo0_l0000Wooooo`03o`000?oooooooooo00?ooooo0_l00005ooooo`;o00000oooool2o`00
00cooooo0_l0000gooooo`;o0000HOooool008?ooooo0_l0000Wooooo`03o`000?oooooooooo00?o
oooo0_l00005ooooo`;o00000oooool2o`00033ooooo0_l0001fooooo`00[?ooool00ol0003ooooo
ooooo`0Eooooo`;o0000:_ooool2o`0007Kooooo002/ooooo`?o00005Oooool2o`0001cooooo0_l0
000=ooooo`;o0000MOooool00:cooooo00?o0000ooooooooool0<oooool2o`0000gooooo0_l0001e
ooooo`00[?ooool00ol0003oooooooooo`12ooooo`;o0000MOooool008oooooo0_l0000Kooooo`03
o`000?oooooooooo0;Wooooo002?ooooo`;o00006oooool00ol0003oooooooooo`05ooooo`;o0000
:_ooool2o`0008Kooooo002/ooooo`03o`000?oooooooooo00Gooooo0_l0000Nooooo`;o00002_oo
ool2o`0008Kooooo002/ooooo`03o`000?oooooooooo00;ooooo0_l0000:ooooo`;o00005Oooool2
o`0009;ooooo002/ooooo`03o`000?oooooooooo00;ooooo0_l00009ooooo`?o0000;oooool2o`00
07Sooooo002/ooooo`?o00003Oooool2o`0000Gooooo0_l0000Yooooo`;o00004oooool2o`0006?o
oooo002:ooooo`;o00008?ooool00ol0003oooooooooo`0Dooooo`;o0000?_ooool2o`0006?ooooo
002:ooooo`;o00004?ooool2o`0000kooooo00?o0000ooooooooool09?ooool2o`0002gooooo0_l0
001Tooooo`00W?ooool2o`0000kooooo00?o0000ooooooooool06_ooool2o`0000Oooooo0ol0000;
ooooo`;o00008?ooool2o`0006Cooooo002/ooooo`03o`000?oooooooooo01[ooooo0_l00007oooo
o`Co00002_ooool2o`0008Kooooo002>ooooo`;o00007?ooool00ol0003oooooooooo`03ooooo`;o
00008?ooool2o`0009;ooooo0024ooooo`;o00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;o
00000oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`03ooooo`;o00007_ooool2o`0000_ooooo0_l00027ooooo`00Q?ooool2o`000008
ooooool0003o0000ogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^
k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Sooooo`;o0000
2oooool2o`0000gooooo0ol0001gooooo`00Qoooool2o`000005oa0@4?ooooooooooooooool@4100
3?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0000oooooo`?o0000
Moooool008Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0oooooo`;o0000N?ooool008Wooooo00Go
0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo00Oooooo0_l0000fooooo`;o0000N?ooool008Wooooo
00Go410@oooooooooooooooooa0@4003ooooo`;o00002_ooool01_l0003oooooo`000?l0003ooooo
o`0000Wooooo00?o0000ooooooooool00oooool2o`000004ooooool0003o0000o`000;3ooooo0029
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool2o`0000Kooooo00Ko0000okZj^_ooooooV9RH
oa0@4?ooool2o`000003ooooool0003ooooo00Sooooo00?o0000ooooooooool00oooool2o`000003
ooooool0003o00000;7ooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So
410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo00_ooooo0_l0002/oooo
o`00[?ooool00ol0003oooooooooo`0;ooooo`;o00002oooool2o`0009oooooo002Looooo`;o0000
0oooool2o`0000Wooooo00?o0000ooooooooool06?ooool2o`0009oooooo0024ooooo`;o00000_oo
ool2o`0001;ooooo0_l00003ooooo`;o00002Oooool00ol0003oooooooooo`0@ooooo`;o00006_oo
ool2o`0008_ooooo0024ooooo`;o00000_ooool2o`0002;ooooo0ol0000@ooooo`;o00001?ooool2
o`0001Cooooo0_l0002;ooooo`00Soooool2o`0000Kooooo0_l0000Cooooo`03o`000?oooooooooo
00Cooooo0_l0000@ooooo`;o00005Oooool2o`0008[ooooo0029ooooo`;o00001?ooool2o`0000Ko
oooo0_l0000Cooooo`03o`000?oooooooooo00Cooooo0_l0000Wooooo`;o0000R_ooool008Wooooo
0_l0000Dooooo`;o00002oooool00ol0003oooooooooo`0looooo`;o0000Noooool009oooooo0_l0
000;ooooo`03o`000?oooooooooo00oooooo0_l00004ooooo`;o00005Oooool2o`0000kooooo0ol0
001jooooo`00[?ooool00ol0003oooooooooo`08ooooo`;o00001Oooool2o`0000Cooooo0_l0000E
ooooo`;o00003oooool2o`0007[ooooo002/ooooo`03o`000?oooooooooo00;ooooo0_l00004oooo
o`;o00000oooool2o`0002cooooo0_l0001looooo`00Y?ooool2o`0000Kooooo00?o0000oooooooo
ool00_ooool2o`0000Wooooo0_l0000@ooooo`;o00006_ooool2o`0007cooooo002@ooooo`;o0000
4_ooool2o`0000Kooooo0ol0000Eooooo`;o00002?ooool2o`0009Sooooo002@ooooo`;o00006_oo
ool00ol0003oooooooooo`0Eooooo`;o00001_ooool2o`0009[ooooo001looooo`;o0000:_ooool2
o`0000;ooooo00?o0000ooooooooool07Oooool2o`0009[ooooo001looooo`;o0000:_ooool2o`00
00;ooooo00?o0000ooooooooool0^Oooool008Kooooo0_l0000Tooooo`03o`000?oooooooooo0;Wo
oooo0026ooooo`;o00009?ooool00ol0003oooooooooo`2iooooo`00V?ooool2o`0000_ooooo0_l0
0005ooooo`03o`000?oooooooooo0;Wooooo002Hooooo`;o00002oooool2o`0000Gooooo00?o0000
ooooooooool0^Oooool009cooooo0_l0000>ooooo`?o0000^Oooool009cooooo0_l0000>ooooo`03
o`000?oooooooooo00Cooooo0_l0002cooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o0000
/oooool00:cooooo00?o0000ooooooooool02Oooool2o`0000Gooooo0_l0000Vooooo`;o0000Oooo
ool009Gooooo0_l00008ooooo`;o00002oooool00ol0003oooooooooo`09ooooo`;o00001Oooool2
o`0002Kooooo0_l0000?ooooo`;o0000K_ooool009Gooooo0_l00008ooooo`;o00002oooool00ol0
003oooooooooo`19ooooo`;o0000K_ooool00:cooooo0_l0002jooooo`00[?ooool2o`0000Sooooo
0_l0000@ooooo`;o0000W_ooool00:cooooo0ol000000ooooooo0000o`000004ooooo`;o00004?oo
ool2o`0001Wooooo1?l00021ooooo`00Roooool2o`0001oooooo00Co0000oooooooooooooooo0_l0
000<ooooo`;o00008oooool4o`00087ooooo002;ooooo`;o00001oooool2o`0001Kooooo00?o0000
ooooooooool03oooool2o`000:Sooooo002Dooooo`;o00001_ooool2o`0000cooooo0ol0000Toooo
o`;o0000UOooool009cooooo0_l0000:ooooo`Go00009?ooool2o`0009Gooooo002Xooooo`;o0000
0_ooool00ol0003oooooooooo`0Qooooo`;o0000U_ooool008gooooo0_l00002ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo01Kooooo0_l00009ooooo`;o0000U_ooool008gooooo0_l00002ooooo`;o0000
00?ooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`0Fooooo`;o0000;_ooool2o`00077ooooo002Aooooo`;o00000_ooool00ol@413ooooooooo
o`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0A_ooool2o`00077ooooo002A
ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`?o0000^Ooo
ool008Wooooo0_l00006ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0^Oooool008Wooooo0_l00006ooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooooooo`;o
00007Oooool2o`0000cooooo0_l0000Dooooo`;o0000Loooool0097ooooo00GoMgMgo`000?l0003o
V9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooooooo0_l0000Moooo
o`;o00003?ooool2o`0001Cooooo0_l0001cooooo`00Q?ooool2o`0000?ooooo0_l00006ooooo`05
onk^k_l0003o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0<?ooool2o`00
08Oooooo0024ooooo`;o00000oooool2o`00027ooooo00?o0000ooooooooool04_ooool2o`0001co
oooo0_l00027ooooo`00Z?ooool2o`0000;ooooo00?o0000ooooooooool00_l0000@ooooo`;o0000
YOooool008Cooooo0_l0000Jooooo`;o00001_ooool2o`0000;ooooo00?o0000ooooooooool00_l0
000/ooooo`;o0000ROooool008Cooooo0_l0000Jooooo`Co00002?ooool3o`0001gooooo0_l0000?
ooooo`;o0000ROooool00:;ooooo1?l00006ooooo`04o`000?oooooo0000o`0000Kooooo0_l00008
ooooo`;o00002?ooool4o`0000gooooo0_l0002;ooooo`00Xoooool3o`0000Kooooo00Co0000oooo
ool0003o00001_ooool2o`0000Sooooo0_l00008ooooo`;o00003oooool2o`0008_ooooo002/oooo
o`03o`000?oooooooooo00Gooooo0_l0002booooo`00[?ooool00ol0003oooooooooo`05ooooo`;o
00001oooool2o`0001Wooooo0_l0000Cooooo`;o0000NOooool00:cooooo00?o0000ooooooooool0
3_ooool2o`0001Wooooo0_l0000Cooooo`;o0000NOooool009_ooooo0_l0000?ooooo`03o`000?oo
oooooooo0;Wooooo002Kooooo`;o00003oooool00ol0003oooooooooo`0=ooooo`;o00002oooool2
o`0009gooooo0026ooooo`;o00009?ooool3o`0000gooooo0_l0000:ooooo`?o00003_ooool2o`00
08gooooo0026ooooo`;o00000oooool2o`00017ooooo0_l0000<ooooo`03o`000?oooooooooo01So
oooo0ol0000?ooooo`;o0000SOooool008_ooooo0_l0000Aooooo`;o00000_ooool2o`0000Sooooo
00?o0000ooooooooool06?ooool2o`0009oooooo002<ooooo`;o00005?ooool2o`0000Sooooo00?o
0000ooooooooool0^Oooool008cooooo0_l00009ooooo`;o00004oooool00ol0003oooooooooo`0V
ooooo`;o00004_ooool2o`0007gooooo002Gooooo`;o00004oooool00ol0003oooooooooo`0Doooo
o`;o00004?ooool2o`0001;ooooo0_l0001mooooo`00[?ooool00ol0003oooooooooo`0Dooooo`;o
00003oooool2o`0009;ooooo002/ooooo`03o`000?oooooooooo02Gooooo0_l0002Booooo`00Tooo
ool2o`0001Oooooo0ol0002iooooo`00R?ooool2o`0000Wooooo0_l0000Gooooo`;o0000^_ooool0
08Sooooo0_l00004ooooo`;o00002oooool2o`0000oooooo00?o0000ooooooooool0^Oooool008So
oooo0_l00004ooooo`;o00002oooool2o`0000oooooo00?o0000ooooooooool01Oooool2o`000;;o
oooo002/ooooo`03o`000?oooooooooo00Gooooo0_l0000Kooooo`;o0000UOooool00:cooooo00?o
0000ooooooooool00oooool2o`0001gooooo0_l0002Eooooo`00[?ooool00ol0003oooooooooo`03
ooooo`;o00007?ooool3o`0009Gooooo0028ooooo`;o00008_ooool00ol0003oooooooooo`0Qoooo
o`?o0000UOooool008Sooooo0_l0000Iooooo`;o00001oooool00ol0003oooooooooo`0Qooooo`;o
0000U_ooool00:?ooooo0_l00007ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Ooo
ool00:cooooo00?o0000ooooooooool00_l00009ooooo`;o00004Oooool2o`0009Wooooo002/oooo
o`03o`000?oooooooooo00;o00002Oooool2o`00017ooooo0_l0002Iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03
o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
0;Wooooo0029ooooo`05ogMgMol0003o0000oiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVY
ZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05
oa0@4?l0003o0000ooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool02_ooool2o`000:gooooo0029ooooo`03o`000?oooooooooo00;o
00001Oooool2o`0000Oooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`?o
00002_ooool2o`000:gooooo0029ooooo`03o`000?oooooooooo00;o00001Oooool2o`0000Oooooo
00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool0^Oooool008Wooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?o
oooo00?o0000ooooooooool01?ooool2o`000003ooooool0003ooooo00Oooooo0_l0002aooooo`00
ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P03oooo
o`;o00001_ooool2o`000003ooooool0003ooooo00Oooooo0ol0000?ooooo`;o0000Woooool008Wo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00000oooool5o`0000Kooooo00?o0000oooo
ooooool01?ooool2o`000003ooooool0003o000000oooooo0_l0002Oooooo`00[?ooool00ol0003o
ooooooooo`04ooooo`;o0000/oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o
0000ooooooooool0^Oooool00:cooooo0ol0000Dooooo`;o0000Xoooool00:cooooo00?o0000oooo
ooooool04_ooool4o`000:?ooooo002/ooooo`03o`000?oooooooooo01;ooooo0_l0002Uooooo`00
[?ooool00ol0003oooooooooo`0Booooo`;o0000YOooool008kooooo0_l00007ooooo`;o00004ooo
ool00ol0003oooooooooo`0Booooo`;o0000YOooool008kooooo0_l00007ooooo`;o00004oooool0
0ol0003oooooooooo`0>ooooo`;o0000ZOooool00:cooooo00?o0000ooooooooool03_ooool2o`00
0:Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o00003Oooool2o`000:[ooooo
002/ooooo`03o`000?oooooooooo00_ooooo1?l0002Zooooo`00Yoooool2o`0000?ooooo00?o0000
ooooooooool02oooool4o`000:[ooooo002Booooo`;o00003oooool2o`000004ooooool0003o0000
o`0000?ooooo00?o0000ooooooooool02oooool2o`000:cooooo002Booooo`;o00003oooool2o`00
0003ooooool0003o000000Cooooo00?o0000ooooooooool02oooool2o`000:cooooo002/ooooo`03
o`000?oooooooooo00Oooooo0_l00002ooooo`;o0000[?ooool00:Kooooo0_l00004ooooo`03o`00
0?oooooooooo00Oooooo0_l0002`ooooo`00Y_ooool2o`0000Cooooo00?o0000ooooooooool0^Ooo
ool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol00005ooooo`;o0000/_ooool00:co
oooo00?o0000ooooooooool00_ooool2o`000003ooooool0003o00000;;ooooo002/ooooo`03o`00
0?oooooooooo00;ooooo0_l0002eooooo`00S?ooool2o`0001kooooo00Co0000oooooooooooooooo
0_l0002fooooo`00S?ooool2o`0001kooooo00Co0000oooooooooooooooo0_l0002fooooo`00[?oo
ool00ol0003oooooooooo`02ooooo`;o0000]Oooool00:cooooo0ol00002ooooo`;o0000]Oooool0
0:cooooo0ol0002iooooo`00[?ooool3o`000;Wooooo002/ooooo`;o0000^_ooool00:cooooo0_l0
002jooooo`00Voooool2o`0000_ooooo1Ol0002kooooo`00Voooool2o`0000_ooooo1Ol0002koooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00W_ooool3o`000003ooooool0003o000000;o0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`2iooooo`00W_ooool3o`000004ooooool0
003o0000o`0000Oooooo00?o0000ooooooooool0^Oooool00:;ooooo0ol00007ooooo`?o0000^Ooo
ool00:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:Co
oooo00?o0000ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:;ooooo00?o
EEEEofIVI_l00000`oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00:[ooooo00Co410@o`000?l0003o0000^_ooool00:_ooooo00?o0000ooooooooool0^_oo
ool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00Ko0000ogMgMol0003o0000oeEEEOo^
k^jgooooo`00Zoooool01_l0003oEEEEonk^k_ooooooMgMgoeEEEKOooooo002[ooooo`03o`000?o^
k^kooooo00;ooooo00?o0000ooooooooool0]Oooool00:_ooooo00?o0000onk^k_ooool00_ooool0
0ol0003oooooooooo`2eooooo`00Zoooool01_l0003oEEEEonk^k_ooooooMgMgofIVI[Oooooo002Z
ooooo`03oa0@4?l0003oMgMg00;o000000?oIVIVonk^k_ooool0]_ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.46458 .89509 Mdot
.43022 .14122 Mdot
.44917 .42802 Mdot
.46523 .74907 Mdot
.51481 .77061 Mdot
.63338 .54263 Mdot
.49532 .64778 Mdot
.70947 .64306 Mdot
.69396 .36979 Mdot
.55418 .60223 Mdot
.44569 .7532 Mdot
.67548 .73285 Mdot
.64976 .35895 Mdot
.49779 .76681 Mdot
.6594 .75516 Mdot
.46539 .23907 Mdot
.46099 .84799 Mdot
.65521 .37671 Mdot
.56372 .37332 Mdot
.49258 .94356 Mdot
.6543 .38799 Mdot
.53621 .15048 Mdot
.57153 .20736 Mdot
.66237 .41008 Mdot
.57147 .90024 Mdot
.5314 .23666 Mdot
.41099 .50499 Mdot
.55167 .33936 Mdot
.44616 .93209 Mdot
.44192 .1188 Mdot
.66272 .44811 Mdot
.69626 .3695 Mdot
.7177 .57185 Mdot
.39735 .41297 Mdot
.51024 .16253 Mdot
.58147 .81194 Mdot
.47677 .04012 Mdot
.49604 .22101 Mdot
.40453 .81829 Mdot
.66213 .76709 Mdot
.57062 .90657 Mdot
.44384 .16287 Mdot
.60661 .35192 Mdot
.42616 .83953 Mdot
.52001 .85499 Mdot
.4027 .54202 Mdot
.51645 .72164 Mdot
.65612 .26549 Mdot
.60652 .52569 Mdot
.46073 .94166 Mdot
.65029 .25637 Mdot
.37335 .48402 Mdot
.77426 .58741 Mdot
.56744 .26029 Mdot
.5836 .28784 Mdot
.71519 .46862 Mdot
.7046 .65691 Mdot
.46488 .85237 Mdot
.58812 .15701 Mdot
.54234 .82046 Mdot
.40411 .42388 Mdot
.37699 .23456 Mdot
.398 .78435 Mdot
.47767 .26143 Mdot
.71348 .55882 Mdot
.70966 .42088 Mdot
.55812 .57286 Mdot
.43747 .302 Mdot
.50534 .23421 Mdot
.66874 .4559 Mdot
.42144 .77152 Mdot
.45594 .33341 Mdot
.55007 .6165 Mdot
.56072 .4658 Mdot
.39831 .78595 Mdot
.50758 .5373 Mdot
.77412 .58808 Mdot
.44287 .20847 Mdot
.37842 .63926 Mdot
.59775 .45 Mdot
.65816 .615 Mdot
.43049 .14473 Mdot
.49999 .72271 Mdot
.45955 .13992 Mdot
.72167 .56254 Mdot
.48606 .23531 Mdot
.50195 .79445 Mdot
.45304 .80115 Mdot
.50324 .83218 Mdot
.44346 .28219 Mdot
.56388 .90882 Mdot
.72023 .28408 Mdot
.54282 .42881 Mdot
.42287 .72281 Mdot
.52856 .36665 Mdot
.69966 .2407 Mdot
.50664 .74896 Mdot
.65143 .26455 Mdot
.77108 .61105 Mdot
.49345 .8485 Mdot
.42637 .83453 Mdot
.54769 .7551 Mdot
.67584 .72672 Mdot
.40011 .72669 Mdot
.66926 .55776 Mdot
.4066 .31117 Mdot
.40275 .66258 Mdot
.57905 .44857 Mdot
.54377 .43459 Mdot
.66842 .46249 Mdot
.53272 .68604 Mdot
.47478 .7543 Mdot
.69271 .36004 Mdot
.56247 .84967 Mdot
.64475 .88975 Mdot
.43877 .36489 Mdot
.4191 .29036 Mdot
.71999 .4632 Mdot
.7123 .42173 Mdot
.45675 .05185 Mdot
.64786 .35565 Mdot
.36159 .5593 Mdot
.62772 .31864 Mdot
.43497 .91563 Mdot
.66919 .46402 Mdot
.43855 .69437 Mdot
.53644 .88538 Mdot
.65959 .17696 Mdot
.38575 .46622 Mdot
.52045 .3872 Mdot
.57227 .20504 Mdot
.39462 .67645 Mdot
.64945 .78489 Mdot
.63303 .56679 Mdot
.62418 .41902 Mdot
.39317 .76941 Mdot
.4501 .05064 Mdot
.48569 .94499 Mdot
.55258 .60276 Mdot
.70909 .61737 Mdot
.65364 .76958 Mdot
.53632 .619 Mdot
.53571 .29431 Mdot
.45941 .84717 Mdot
.5283 .89974 Mdot
.72334 .52349 Mdot
.5775 .47105 Mdot
.43052 .74904 Mdot
.37354 .73823 Mdot
.56097 .72728 Mdot
.44338 .24069 Mdot
.66512 .41957 Mdot
.44248 .38395 Mdot
.61163 .65597 Mdot
.41033 .14419 Mdot
.38394 .69078 Mdot
.71792 .46062 Mdot
.47603 .04133 Mdot
.41876 .11533 Mdot
.58488 .36308 Mdot
.37754 .63153 Mdot
.58119 .89964 Mdot
.6184 .73839 Mdot
.60085 .34203 Mdot
.44273 .86856 Mdot
.72263 .51023 Mdot
.6649 .59911 Mdot
.49162 .21317 Mdot
.41214 .13388 Mdot
.51049 .91465 Mdot
.54506 .46969 Mdot
.4521 .22636 Mdot
.50226 .79085 Mdot
.58006 .52086 Mdot
.71459 .57745 Mdot
.68751 .22043 Mdot
.61535 .64075 Mdot
.43169 .43058 Mdot
.43176 .90562 Mdot
.38387 .28662 Mdot
.63559 .81453 Mdot
.54318 .36589 Mdot
.55613 .92508 Mdot
.52921 .58212 Mdot
.68661 .35183 Mdot
.65346 .17008 Mdot
.69628 .36108 Mdot
.59355 .88207 Mdot
.61869 .39069 Mdot
.3816 .78944 Mdot
.5284 .90008 Mdot
.43194 .36688 Mdot
.36457 .3765 Mdot
.71717 .60014 Mdot
.49669 .99523 Mdot
.66534 .75218 Mdot
.44112 .78241 Mdot
.75447 .36248 Mdot
.39833 .37062 Mdot
.44739 .65872 Mdot
.44103 .63287 Mdot
.471 .31256 Mdot
.52713 .74228 Mdot
.76458 .39945 Mdot
.41149 .77887 Mdot
.45316 .70403 Mdot
.62839 .58643 Mdot
.47936 .75579 Mdot
.49888 .7001 Mdot
.43324 .71849 Mdot
.61234 .26743 Mdot
.43265 .23597 Mdot
.66417 .60244 Mdot
.52157 .30701 Mdot
.43256 .84755 Mdot
.41436 .32508 Mdot
.57533 .90643 Mdot
.52674 .60364 Mdot
.56532 .77479 Mdot
.67746 .73572 Mdot
.41345 .32492 Mdot
.59653 .17292 Mdot
.66885 .57496 Mdot
.64689 .65856 Mdot
.48607 .24262 Mdot
.56016 .6578 Mdot
.40878 .21372 Mdot
.54456 .45463 Mdot
.65727 .76015 Mdot
.36061 .46135 Mdot
.42543 .36036 Mdot
.48181 .33835 Mdot
.76356 .40618 Mdot
.59135 .62557 Mdot
.41056 .51417 Mdot
.36864 .67974 Mdot
.47445 .20628 Mdot
.3884 .62163 Mdot
.6285 .31413 Mdot
.40265 .7354 Mdot
.37695 .23657 Mdot
.6335 .47394 Mdot
.64885 .67146 Mdot
.42274 .77634 Mdot
.70099 .37876 Mdot
.51472 .32644 Mdot
.39636 .21228 Mdot
.54416 .75223 Mdot
.42785 .79393 Mdot
.39378 .76229 Mdot
.51156 .97855 Mdot
.43568 .38484 Mdot
.43056 .38076 Mdot
.41812 .12311 Mdot
.53544 .24776 Mdot
.44169 .24995 Mdot
.60469 .33461 Mdot
.50311 .5794 Mdot
.70825 .63533 Mdot
.62841 .21629 Mdot
.60148 .57723 Mdot
.41062 .51961 Mdot
.63813 .6879 Mdot
.48673 .29506 Mdot
.56795 .70713 Mdot
.50268 .87469 Mdot
.50142 .75287 Mdot
.62958 .47728 Mdot
.55261 .85677 Mdot
.56731 .32065 Mdot
.56373 .84412 Mdot
.59598 .31544 Mdot
.55544 .60011 Mdot
.60361 .50994 Mdot
.4055 .16212 Mdot
.55079 .39299 Mdot
.57891 .57799 Mdot
.66146 .27942 Mdot
.44131 .74597 Mdot
.61842 .63452 Mdot
.40734 .83493 Mdot
.53124 .43272 Mdot
.54884 .39665 Mdot
.47437 .04214 Mdot
.68634 .70171 Mdot
.58088 .46282 Mdot
.4374 .5684 Mdot
.56367 .63313 Mdot
.5947 .7993 Mdot
.41394 .66922 Mdot
.66346 .57836 Mdot
.6521 .16912 Mdot
.57181 .13747 Mdot
.67814 .71391 Mdot
.573 .14183 Mdot
.51696 .50404 Mdot
.55513 .11233 Mdot
.36245 .54592 Mdot
.62109 .74853 Mdot
.66681 .73914 Mdot
.60336 .47627 Mdot
.62652 .4117 Mdot
.38912 .61948 Mdot
.69949 .3765 Mdot
.5832 .88726 Mdot
.49929 .75974 Mdot
.65697 .27241 Mdot
.54948 .27526 Mdot
.49308 .68006 Mdot
.60589 .25756 Mdot
.44042 .81983 Mdot
.63942 .33425 Mdot
.388 .83112 Mdot
.45084 .31919 Mdot
.54575 .8094 Mdot
.41526 .25699 Mdot
.71044 .58777 Mdot
.49687 .30944 Mdot
.62925 .82395 Mdot
.41851 .93288 Mdot
.53162 .02541 Mdot
.4174 .50552 Mdot
.6329 .57732 Mdot
.46856 .13291 Mdot
.37903 .62997 Mdot
.55602 .67512 Mdot
.46088 .69292 Mdot
.5118 .57337 Mdot
.4156 .74296 Mdot
.69189 .6999 Mdot
.40882 .15746 Mdot
.52679 .35903 Mdot
.58143 .21426 Mdot
.52704 .41646 Mdot
.4735 .31199 Mdot
.41487 .1879 Mdot
.6347 .52195 Mdot
.60198 .34504 Mdot
.58459 .3629 Mdot
.53837 .71583 Mdot
.77939 .54453 Mdot
.54603 .27108 Mdot
.40599 .23932 Mdot
.47844 .263 Mdot
.71852 .52534 Mdot
.4137 .57784 Mdot
.50081 .93112 Mdot
.47203 .09297 Mdot
.5486 .53447 Mdot
.40442 .54686 Mdot
.67949 .72575 Mdot
.5532 .10815 Mdot
.5686 .834 Mdot
.60097 .4436 Mdot
.39493 .43677 Mdot
.52189 .90096 Mdot
.58122 .66707 Mdot
.67996 .72374 Mdot
.55022 .0418 Mdot
.64461 .68489 Mdot
.65261 .77791 Mdot
.62231 .83487 Mdot
.55807 .92576 Mdot
.50581 .36551 Mdot
.59912 .58371 Mdot
.6514 .77288 Mdot
.70737 .64325 Mdot
.5131 .39429 Mdot
.66775 .53357 Mdot
.54224 .267 Mdot
.62795 .59703 Mdot
.4381 .86269 Mdot
.66349 .28987 Mdot
.38984 .63878 Mdot
.51613 .06946 Mdot
.38019 .34932 Mdot
.56019 .18998 Mdot
.52799 .07786 Mdot
.56112 .18869 Mdot
.60032 .86051 Mdot
.60819 .93794 Mdot
.49111 .04916 Mdot
.6045 .68339 Mdot
.43577 .45035 Mdot
.47134 .99966 Mdot
.51401 .81628 Mdot
.51445 .54984 Mdot
.62809 .82867 Mdot
.66957 .46383 Mdot
.46579 .69935 Mdot
.56233 .50257 Mdot
.48647 .17186 Mdot
.41232 .42832 Mdot
.66675 .28609 Mdot
.66812 .59774 Mdot
.36272 .42618 Mdot
.62964 .82459 Mdot
.4004 .62959 Mdot
.77753 .51345 Mdot
.39437 .51483 Mdot
.58056 .50814 Mdot
.57837 .56844 Mdot
.43966 .47377 Mdot
.6962 .68451 Mdot
.67811 .7261 Mdot
.41137 .52997 Mdot
.54804 .51692 Mdot
.40998 .45449 Mdot
.51644 .2895 Mdot
.43143 .96848 Mdot
.43236 .76087 Mdot
.62066 .73605 Mdot
.52721 .6507 Mdot
.44912 .22864 Mdot
.50511 .33251 Mdot
.46464 .81704 Mdot
.39524 .50889 Mdot
.41696 .36457 Mdot
.44104 .66911 Mdot
.36574 .65102 Mdot
.71036 .61274 Mdot
.48495 .6161 Mdot
.52825 .18888 Mdot
.40267 .66166 Mdot
.59112 .71207 Mdot
.55806 .30196 Mdot
.46736 .20767 Mdot
.46232 .99857 Mdot
.72274 .28102 Mdot
.38472 .53532 Mdot
.69784 .80782 Mdot
.40816 .77419 Mdot
.42582 .57003 Mdot
.69931 .39744 Mdot
.64411 .78615 Mdot
.43588 .72422 Mdot
.47152 .09424 Mdot
.77825 .55606 Mdot
.54672 .54168 Mdot
.49447 .68104 Mdot
.57742 .55798 Mdot
.64091 .68225 Mdot
.59153 .40765 Mdot
.74075 .32765 Mdot
.51726 .64122 Mdot
.53376 .20162 Mdot
.43758 .17443 Mdot
.51154 .31381 Mdot
.44553 .33838 Mdot
.55904 .43988 Mdot
.70871 .64458 Mdot
.47386 .28633 Mdot
.38652 .72215 Mdot
.40172 .25472 Mdot
.52746 .84139 Mdot
.55118 .86408 Mdot
.66637 .5389 Mdot
.41549 .73819 Mdot
.66102 .17529 Mdot
.56231 .52317 Mdot
.68911 .70786 Mdot
.51304 .9778 Mdot
.50022 .75432 Mdot
.55544 .11185 Mdot
.56282 .31161 Mdot
.4931 .84025 Mdot
.50557 .92572 Mdot
.424 .82845 Mdot
.57014 .40143 Mdot
.40383 .52979 Mdot
.39671 .42043 Mdot
.37633 .23385 Mdot
.62029 .40787 Mdot
.50911 .51362 Mdot
.59404 .32035 Mdot
.59999 .46365 Mdot
.50192 .35051 Mdot
.41898 .44357 Mdot
.562 .24902 Mdot
.62295 .40683 Mdot
.42905 .51798 Mdot
.51269 .20888 Mdot
.71053 .42583 Mdot
.52253 .75675 Mdot
.52516 .84157 Mdot
.52339 .26503 Mdot
.54835 .33454 Mdot
.5252 .48686 Mdot
.65911 .87151 Mdot
.52521 .51256 Mdot
.42223 .16299 Mdot
.59805 .17834 Mdot
.61361 .75034 Mdot
.51916 .26042 Mdot
.46316 .94517 Mdot
.65124 .78562 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o00001oooool2o`000;3ooooo002/ooooo`03o`000?oooooo
oooo00Oooooo0_l0002`ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00Y?ooool2o`0000Kooooo00?o
0000ooooooooool0^Oooool00:?ooooo0ol00006ooooo`03o`000?oooooooooo00gooooo0_l0002Z
ooooo`00Xoooool3o`0000Kooooo00?o0000ooooooooool03Oooool2o`000:[ooooo002Yooooo`;o
000000?oooooo`000?ooool0^_ooool009_ooooo1?l0000:ooooo`;o000000Coooooo`000?l0003o
0000^Oooool009_ooooo1?l0000=ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00;ooooo
0_l0002eooooo`00[?ooool00ol0003oooooooooo`02ooooo`;o0000]Oooool00:cooooo0ol0002i
ooooo`00[?ooool00ol0003oooooooooo`06ooooo`;o0000/Oooool00:cooooo00?o0000oooooooo
ool01_ooool2o`000;7ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Rooooo`;o00002?ooool00ol0
003oooooooooo`2iooooo`00X_ooool2o`0000Sooooo00?o0000ooooooooool0^Oooool00:cooooo
0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`0>ooooo`;o0000ZOooool00:cooooo00?o0000oooooooo
ool03_ooool3o`000:Sooooo002Aooooo`;o00006Oooool00ol0003oooooooooo`0?ooooo`;o0000
Z?ooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`;o00000_lQ8B43ooooo`;o0000
00?oooooo`000?o^k^h01Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooooooo
ool0^Oooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q0oooool2o`000003
oooooomEEEGoZJVY00Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2iooooo`00
POooool6o`0000;ooooo00Go410@oooooooooooooooooa0@4003ooooo`;o00002?ooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002iooooo`00ROooool01Ol0003ooooo
oooooooooooo000000?ooooo0_l00009ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`2iooooo`00ROooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0^Oooool008Wooooo00Ko410@oooooooooooooooooa0@4?ooool2o`0000_ooooo00?oZJVY
ogMgMoooool00_ooool2o`0000Wooooo00?o0000ooooooooool0^Oooool008Wooooo00KoMgMgoiRH
V?ooooooV9RHogMgMoooool2o`0000Sooooo00Go410@oooooooooooooooooc8b<P03ooooo`;o0000
2Oooool00ol0003oooooooooo`0Dooooo`;o0000Xoooool008Wooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`Oo00000_ooool4o`0000Kooooo00?o0000ooooooooool05?ooool2o`000:?ooooo
002Eooooo`;o00001oooool2o`0000cooooo00?o0000ooooooooool05Oooool2o`000:;ooooo002>
ooooo`;o00001Oooool2o`0001Gooooo00?o0000ooooooooool05Oooool2o`000:;ooooo002>oooo
o`;o00001Oooool2o`0001Gooooo00?o0000ooooooooool0^Oooool00:cooooo0ol00009ooooo`;o
0000[_ooool00:cooooo00?o0000ooooooooool02Oooool2o`000:kooooo002=ooooo`;o00007Ooo
ool00ol0003oooooooooo`0Jooooo`;o0000WOooool008cooooo0ol0000Mooooo`03o`000?oooooo
oooo01[ooooo0_l0002Mooooo`00S?ooool2o`0000Cooooo0_l00005ooooo`;o00004Oooool00ol0
003oooooooooo`02o`000;Oooooo002Booooo`;o00001Oooool2o`00017ooooo00?o0000oooooooo
ool00_l0002gooooo`00[?ooool00ol0003oooooooooo`0_ooooo`;o0000R?ooool00:Oooooo0_l0
0003ooooo`03o`000?oooooooooo01cooooo0_l0000Aooooo`;o0000R?ooool009Oooooo0_l0000>
ooooo`;o00000oooool3o`0001cooooo0_l0000Cooooo`?o0000QOooool009Oooooo0_l0000Coooo
o`03o`000?oooooooooo01gooooo0_l0000Booooo`?o0000QOooool00:cooooo00?o0000oooooooo
ool07Oooool2o`0009[ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002?ooooo`;o00006ooo
ool00ol0003oooooooooo`06ooooo`;o00002Oooool2o`000:Kooooo002?ooooo`;o00006oooool0
0ol0003oooooooooo`06ooooo`;o00002?ooool3o`000:Kooooo002/ooooo`03o`000?oooooooooo
013ooooo0_l0002Wooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`0000Sooooo
0_l0002_ooooo`00[?ooool00ol0003oooooooooo`08ooooo`;o0000[oooool00:7ooooo1?l00007
ooooo`03o`000?oooooooooo01Cooooo0_l0002Sooooo`00VOooool2o`0000Kooooo1?l00007oooo
o`04o`000?ooooooooooooooo`;o00004Oooool2o`000:?ooooo0029ooooo`;o00000_ooool2o`00
00[ooooo0_l0000>ooooo`;o000000?oooooo`000?ooool00_ooool2o`000;Kooooo0029ooooo`;o
00000_ooool2o`0001[ooooo0_l000000ooooooo0000ooooo`0Hooooo`;o00003_ooool2o`00093o
oooo002/ooooo`03o`000?oooooooooo01Oooooo0_l0000>ooooo`;o0000T?ooool00:[ooooo0ol0
000looooo`;o0000OOooool00:[ooooo1Ol0000jooooo`;o0000OOooool009_ooooo0ol0000>oooo
o`03o`000?oooooooooo0;Wooooo002Kooooo`?o00003_ooool00ol0003oooooooooo`2iooooo`00
Poooool2o`0002Oooooo0ol0002iooooo`00Poooool2o`00013ooooo0_l0000@ooooo`;o00000ooo
ool3o`0000Oooooo0_l0002`ooooo`00Poooool2o`0000Sooooo0_l00006ooooo`;o00000_ooool2
o`0000Gooooo0_l00005ooooo`;o00000oooool00ol0003oooooooooo`07ooooo`;o0000=Oooool2
o`0007Wooooo002=ooooo`;o00000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo0_l00002
ob4Q8@?ooooo0_l000001Om4A4Co0000o`000?lb<S;ogMgM00;o00000oooool00ol0003ooooooooo
o`0nooooo`;o0000NOooool0097ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?oo
ool01?mgMgOo<S8bo`000?l00003ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`Ko00000_oo
ool01Ol@413ooooooooooooooooo410@00;ooooo0_l0000<ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool2o`0000Oooooo0_l0002Vooooo`00TOooool01Ol0003ooooooooo
oooooooo000000;ooooo0_l0000;ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00008ooooo`;o0000
1oooool2o`000:Kooooo002;ooooo`;o00001?ooool01Ol0003ooooooooooooooooo000000cooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;Wooooo002;ooooo`;o0000
0oooool2o`0000?ooooo00?o410@ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo023ooooo0_l0000<ooooo`;o0000ROooool0093ooooo0_l000001?nHV9SooooooiRH
V?mgMgL<ooooo`04o`000?oooooo0000o`0000Kooooo00?o0000ooooooooool00oooool2o`0000ko
oooo0_l0000;ooooo`;o00003?ooool2o`0008Wooooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03?ooool4o`0000Kooooo00?o0000ooooooooool00oooool3o`0000gooooo0_l0000Jooooo`;o
0000R?ooool00:Cooooo0_l00006ooooo`03o`000?oooooooooo00Cooooo0_l00005ooooo`;o0000
5Oooool2o`0000_ooooo0ol00027ooooo`00[?ooool00ol0003oooooooooo`0;ooooo`?o00005?oo
ool2o`0000cooooo0_l00027ooooo`00[?ooool00ol0003oooooooooo`0<ooooo`;o00008_ooool2
o`0008Oooooo002/ooooo`?o00003Oooool2o`00027ooooo0_l00027ooooo`00[?ooool00ol0003o
ooooooooo`0=ooooo`;o00008oooool2o`0008Gooooo002Iooooo`;o00004Oooool00ol0003ooooo
ooooo`0booooo`;o00004_ooool2o`00077ooooo002Iooooo`;o00002?ooool2o`0000Oooooo00?o
0000ooooooooool0=?ooool2o`0000oooooo0ol0001aooooo`00QOooool2o`0001cooooo0_l00007
ooooo`03o`000?oooooooooo01Sooooo0_l0000Jooooo`;o00003oooool2o`0007;ooooo0025oooo
o`;o00002_ooool2o`0001Wooooo00?o0000ooooooooool00_ooool2o`0001Cooooo0_l0000Ioooo
o`;o0000Q?ooool0097ooooo0_l0000Dooooo`;o00000oooool00ol0003oooooooooo`02ooooo`;o
00001?ooool2o`0002Wooooo0_l00024ooooo`00Yoooool2o`0000?ooooo00?o0000ooooooooool0
2?ooool2o`000:oooooo002/ooooo`?o0000^Oooool009Oooooo0_l0000Cooooo`03o`000?oooooo
oooo013ooooo0_l0002Wooooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool01?ooool2o`00
00[ooooo0_l0002Wooooo`00Zoooool2o`0000Kooooo0_l0002cooooo`00SOooool2o`0001?ooooo
0ol00006ooooo`;o00004oooool2o`000:Kooooo002=ooooo`;o00004oooool3o`0000Oooooo00?o
0000ooooooooool00_l0000?ooooo`;o00002Oooool2o`0000Wooooo0_l0002@ooooo`00Voooool2
o`0000oooooo00?o0000ooooooooool00_l0000Jooooo`;o00002Oooool2o`00093ooooo002Koooo
o`;o00003oooool00ol0003oooooooooo`0Cooooo`;o00001oooool2o`0000Wooooo0_l0002@oooo
o`00Soooool2o`0001_ooooo0ol0000Cooooo`;o00001oooool2o`0009_ooooo002?ooooo`;o0000
6oooool01?l0003oooooooooooooool2o`0004Wooooo0_l0001[ooooo`00[?ooool01?l0003ooooo
ooooooooool2o`0004Wooooo0_l0001[ooooo`00WOooool2o`0000gooooo0ol0000=ooooo`;o0000
4?ooool2o`0000[ooooo0_l0002<ooooo`00WOooool2o`0000gooooo0ol0000=ooooo`;o00004?oo
ool2o`0000[ooooo0_l0002<ooooo`00V_ooool2o`0000[ooooo0_l00004ooooo`03o`000?oooooo
oooo00kooooo0_l0002Yooooo`00V_ooool2o`0000[ooooo0_l00004ooooo`03o`000?oooooooooo
00kooooo0_l0000>ooooo`;o0000VOooool00:cooooo00?o0000ooooooooool07_ooool2o`0009Wo
oooo0024ooooo`;o00009_ooool00ol0003oooooooooo`0Nooooo`;o0000VOooool008Cooooo0_l0
000Vooooo`?o00008?ooool2o`0001Sooooo0_l0001mooooo`00[?ooool2o`00027ooooo0_l0000;
ooooo`;o00002oooool2o`0007gooooo002/ooooo`03o`000?oooooooooo00Gooooo0_l0000Voooo
o`?o0000ROooool009?ooooo0_l0000Gooooo`03o`000?oooooooooo00Gooooo0_l0000Wooooo`;o
00003?ooool3o`0007[ooooo002@ooooo`;o000000?oooooo`000?l000000_ooool2o`0001?ooooo
00?o0000ooooooooool06?ooool3o`00027ooooo0ol0000Booooo`;o0000I_ooool008Wooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP02ooooo`;o000000?oooooob4Q8OlQ8B402Ol00004ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool3o`0000Kooooo0_l00003ooooo`;o00002oooool3o`0003Ko
oooo0_l0001Vooooo`00ROooool01OmgMgOo0000o`000?nHV9SoMgMg00Gooooo0_lQ8B42o`0000;o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00006oooo
o`;o00000oooool2o`00033ooooo0_l0001jooooo`00POooool6o`0000;ooooo00Go410@o`000?l0
003ooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Booooo`;o0000:Oooool2o`0007[ooooo001oooooo`;o00002?ooool01Ol0003o
oooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04oooo
o`?o00004_ooool2o`0001cooooo0_l0000<ooooo`;o0000NOooool007oooooo0_l00008ooooo`05
o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01Oooool00ol0003oooooooooo`0`ooooo`;o00003?ooool3o`0007Sooooo0029oooo
o`05oa0@4?ooooooooooooooool@41001oooool2o`0000Kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo03oooooo0_l0001hooooo`00ROooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Oooooo0ol000001_oooooo0000o`000?ooooooV9RHoa0@40Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`2iooooo`00ROooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Sooooo0_l000001_oooooo0000o`000?l0003o8B4Qolc<c0Cooooo1?l00006oooo
o`03o`000?oooooooooo00?ooooo0_l0000[ooooo`;o0000Qoooool00:cooooo00?o0000oooooooo
ool00oooool2o`0001oooooo0_l0000:ooooo`;o0000Qoooool00:cooooo00Co0000oooooooooooo
oooo0_l0000:ooooo`;o00005Oooool2o`0009?ooooo002/ooooo`04o`000?ooooooooooooooo`;o
00002_ooool2o`0002oooooo0_l0001iooooo`00[?ooool3o`0000gooooo0_l00005ooooo`;o0000
:?ooool2o`0001Cooooo0_l0001Sooooo`00[?ooool00ol0003oooooooooo`0Dooooo`;o0000?_oo
ool2o`0006?ooooo002/ooooo`03o`000?oooooooooo02Gooooo0_l0000]ooooo`;o0000Hoooool0
0:cooooo00?o0000ooooooooool06oooool2o`0000Oooooo0ol0000;ooooo`;o00008?ooool2o`00
06?ooooo002:ooooo`;o00008?ooool00ol0003oooooooooo`0Kooooo`;o00001oooool4o`0000[o
oooo0_l00025ooooo`00R_ooool2o`00023ooooo00?o0000ooooooooool01Oooool2o`0001oooooo
0_l0002Aooooo`00[?ooool00ol0003oooooooooo`05ooooo`;o00007oooool2o`0000_ooooo0_l0
0024ooooo`00ROooool2o`00027ooooo00?o0000ooooooooool09_ooool2o`0000_ooooo0_l0000=
ooooo`?o0000M?ooool008Wooooo0_l000000ooooooo0000o`00000Nooooo`?o0000@_ooool3o`00
07Cooooo001nooooo`;o00003?ooool2o`000003ooooool0003o000000[ooooo0_l0000?ooooo`03
o`000?oooooooooo00_ooooo0_l0000eooooo`;o0000MOooool007kooooo0_l0000?ooooo`;o0000
1?ooool2o`0000Cooooo0_l0000?ooooo`03o`000?oooooooooo00_ooooo0_l0000eooooo`;o0000
MOooool009Gooooo0_l0000Eooooo`03o`000?oooooooooo00Oooooo0_l00002ooooo`;o0000[?oo
ool008Wooooo0_l0000Qooooo`03o`000?oooooooooo00Oooooo0_l00002ooooo`;o0000[?ooool0
08Wooooo0_l0000Qooooo`03o`000?oooooooooo013ooooo0_l0002Wooooo`00TOooool2o`0001Wo
oooo00?o0000ooooooooool04?ooool2o`0000cooooo0_l0002Iooooo`00TOooool2o`0001Wooooo
00?o0000ooooooooool07_ooool2o`0009Wooooo002/ooooo`03o`000?oooooooooo01Oooooo0_l0
0004ooooo`;o00004oooool2o`0008Gooooo002Fooooo`;o00005?ooool3o`0001Oooooo0_l00004
ooooo`;o00004oooool2o`0008Gooooo002>ooooo`;o00001_ooool2o`0001Cooooo00?o0000oooo
ooooool02oooool2o`0002Oooooo0_l00023ooooo`00S_ooool2o`0001cooooo00?o0000oooooooo
ool02oooool2o`0002Oooooo0_l00023ooooo`002Oooool4o`000003oa0@4?oooooooooo01Kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05
odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01_o^k^ko<S8bo`000?lb<S;ok^k^ooooo`;o
00000_ooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd05_ooool00ol0
003oooooooooo`0Hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004
ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool3o`000003oc8b<_o^k^kooooo00Cooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hoooo
o`Co000000?o410@ooooooooool04_ooool000_ooooo00?o0000ooooooooool06?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b
<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo00kooooo00KoMgMgoiRHV?ooooooV9RHogMgMoooool2o`0000;ooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`0Eooooo`03o`000?oooooooooo01Oo
oooo0_l000001OnHV9SooooooiRHV?mgMgOooooo00;o00000_ooool2ob4Q8@Cooooo00GoV9RHob4Q
8Oo^k^koooooodA4A007ooooo`?o00003_ooool2o`000003oooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_oo
ool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo01Wooooo00?o0000ooooooooool05?oo
ool000Ko00001Oooool00ol0003oooooooooo`0@ooooo`Ko00000_ooool01Ol@413ooooooooooooo
oooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`05ooooo`Ko00000_oo
ool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool01Oooool6o`0000;ooooo
00Go410@oooooooooooooooooa0@4009ooooo`;o000000CooooooiRHV?lQ8B7ok^k^2Oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo017ooooo0_l00004ooooo`;o00000oooool01?l@
413oooooo`000?l00009ooooo`03oiRHV?lQ8B7ok^k^00Sooooo0ol0000>ooooo`;o00000_ooool0
0ol@413oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00Go410@oooooooooooooooooa0@
400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_oo
ool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000oooooooooooooooo
o`00000?ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`000009ooooo`;o
00000_ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo01Gooooo00?o0000oooooooo
ool02oooool2o`0000Cooooo0_l00003ooooo`?o00000oooool00ol0003oooooooooo`0;ooooo`03
oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool03Oooool2o`0000?ooooo00?o0000oooooooo
ool03Oooool00omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003_ooool00olQ
8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Wooooo00?o0000ooooooooool05?ooool000_o
oooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<
c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00
000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000ko
oooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo0_l0000Boooo
o`03o`000?oooooooooo00_ooooo0_l00009ooooo`?o00000oooool00ol0003oooooooooo`0:oooo
o`;o000000?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00kooooo0_l00003
ooooo`03o`000?oooooooooo00[ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?oo
ooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`06_ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05oa0@
4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo017o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo017ooooo00Go410@oooo
oooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool2
o`0001;ooooo0ol0000Hooooo`05oa0@4?ooooooooooooooool@41000_ooool2o`0000Kooooo1?l0
00000ooooooo0000ooooo`03ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400>ooooo`03
ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Dooooo`00
2oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413o
oooooooooooooooo<S8b00Cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
6?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo0_l00006ooooo`;o000000Co^[ZjoooooonH
V9So410@1?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooo
oooooooo<S8b00Cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Dooooo`002Ooo
ool00omEEEGoIVIVo`00000Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo
1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00013ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0001Oooooo00?o0000
ooooooooool06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c004ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000Iooooo`03oeEEEOmVIVKo0000
01Kooooo0022ooooo`;o0000:?ooool00ol0003oooooooooo`2iooooo`00P_ooool2o`0002Sooooo
00?o0000ooooooooool01Oooool2o`000;;ooooo002/ooooo`03o`000?oooooooooo00Gooooo0_l0
002Wooooo`;o00000_ooool2o`0000Gooooo002/ooooo`03o`000?oooooooooo0:kooooo00Kok^k^
ob4Q8On7QhOo^[Zjo`000?oMgMd5ooooo`00[?ooool00ol0003oooooooooo`2_ooooo`04omgMgOl0
003o410@olc<c0Kooooo0007oooooooo0000C?l0000<ooooo`04onk^k_lQ8B7o410@onk^kPKooooo
0007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`;o00000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o00000ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_oo
ool01?lQ8B7oMgMgogMgMolb<S86ooooo`001oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`08ooooo`Co00006_oo
ool00ol0003oooooooooo`02ooooo`;o00003Oooool2o`0001Cooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02Ooo
ool2o`0000;ooooo0_l00005ooooo`00ROooool2o`0000?ooooo1?l0000Jooooo`03o`000?oooooo
oooo01Oooooo0_l00006ooooo`;o00009Oooool2o`00077ooooo0029ooooo`;o00008Oooool00ol0
003oooooooooo`02o`0000?ooooo0_l0000@ooooo`;o00001_ooool2o`0002Gooooo0_l0000@oooo
o`;o0000Goooool008Wooooo0_l00003ooooo`;o00007?ooool00ol0003oooooooooo`02o`0000?o
oooo0_l0001Aooooo`;o0000Goooool008Wooooo0_l00003ooooo`;o00001?ooool2o`0001Kooooo
00?o0000ooooooooool03?ooool2o`000:_ooooo002>ooooo`;o00001?ooool2o`0001Kooooo00?o
0000ooooooooool03?ooool2o`0000Wooooo0_l0000@ooooo`;o0000S_ooool00:cooooo0ol0000A
ooooo`;o00001?ooool2o`0000Oooooo0_l00007ooooo`;o00006_ooool3o`00077ooooo002/oooo
o`03o`000?oooooooooo017ooooo0_l0000=ooooo`;o00008oooool3o`00077ooooo002<ooooo`Co
00007?ooool00ol0003oooooooooo`2iooooo`00S?ooool4o`0001cooooo00?o0000ooooooooool0
3Oooool2o`0002Gooooo0_l00023ooooo`00Q_ooool2o`0002Cooooo00Co0000ooooool0003o0000
3?ooool2o`0002Gooooo0_l00023ooooo`00Q_ooool2o`0002Cooooo00Co0000ooooool0003o0000
<_ooool2o`0008Cooooo002;ooooo`;o00007oooool00ol0003oooooooooo`0<ooooo`;o00006ooo
ool2o`0000Sooooo0_l00024ooooo`00O_ooool2o`0000_ooooo0ol0000Nooooo`03o`000?oooooo
oooo00cooooo0_l0000Kooooo`;o0000;_ooool2o`0005kooooo001nooooo`;o00003?ooool2o`00
01kooooo00Co0000oooooooooooooooo0_l0001Fooooo`;o0000G_ooool00:cooooo0ol000000ooo
oooo0000o`00002fooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooo
ooooo`0Fooooo`;o00007?ooool2o`0000gooooo0_l0000Cooooo`;o0000Goooool007kooooo0_l0
000/ooooo`03o`000?oooooooooo01Kooooo0_l0000Looooo`;o00003Oooool2o`0001?ooooo0_l0
001Oooooo`00O_ooool2o`0002cooooo00?o0000ooooooooool0A_ooool2o`00077ooooo002/oooo
o`03o`000?oooooooooo02Sooooo0_l0000Looooo`;o0000LOooool009?ooooo0_l00002ooooo`;o
00004oooool00ol0003oooooooooo`0Fooooo`;o00004?ooool2o`0008oooooo002Cooooo`;o0000
0_ooool2o`0001?ooooo00?o0000ooooooooool00_l0000>ooooo`;o00001?ooool2o`0002cooooo
0_l0001cooooo`00[?ooool5o`0000kooooo0_l0000<ooooo`;o00005?ooool2o`0000kooooo0_l0
001cooooo`00Soooool2o`0001_ooooo0ol0000Gooooo`;o00001Oooool2o`0000Sooooo0_l00009
ooooo`?o00003Oooool2o`0007Cooooo002?ooooo`;o00006oooool3o`0000Kooooo0_l0000?oooo
o`;o00003oooool2o`0000Wooooo0_l0000>ooooo`;o0000M?ooool00:cooooo00?o0000oooooooo
ool01_ooool2o`0001Gooooo0_l0002Jooooo`00[?ooool00ol0003oooooooooo`0Mooooo`;o0000
2?ooool2o`0001Wooooo0_l0000Cooooo`;o0000H?ooool00:cooooo00?o0000ooooooooool09ooo
ool2o`0001Wooooo0_l0000Cooooo`;o0000H?ooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool09oooool2o`0000_ooooo0_l00023ooooo`00[?ooool3o`0000oo
oooo0_l0000Fooooo`;o00002_ooool3o`0000kooooo0_l0001cooooo`00[?ooool00ol0003ooooo
ooooo`05ooooo`;o00001oooool3o`0002;ooooo0_l0000?ooooo`;o0000Loooool00:cooooo00?o
0000ooooooooool01Oooool2o`0000Oooooo0_l0000Sooooo`;o0000Q?ooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0@_ooool2o`0001;ooooo0_l0001Qoooo
o`00Yoooool2o`0000?ooooo00?o0000ooooooooool03Oooool2o`0002;ooooo0_l0000?ooooo`;o
00004_ooool2o`00067ooooo0027ooooo`;o000000Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@02o`0000?ooooo00?o0000oooo
ooooool02Oooool2o`0000;ooooo0_l0000Rooooo`;o00003oooool2o`0007Gooooo0027ooooo`;o
000000GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`09ooooo`;o0000=oooool2
o`0007Gooooo0027ooooo`;o000000Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7o
k^k^00Wooooo00?o0000ooooooooool00oooool3o`0001_ooooo0_l0002Looooo`00ROooool01Ol0
003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo01_ooooo0_l0002Looooo`00Poooool3o`0000?ooooo00?o0000oooo
ool000000_l0000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005
ooooo`03o`000?oooooooooo0;Wooooo0023ooooo`?o00000oooool01Ol@413oooooo`000?l0003o
410@00[ooooo0_l00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Booooo`;o00004?ooool2o`0009?ooooo0029ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02_ooool2o`000004okZj^_ooooooV9RHoa0@40Cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Booooo`;o00004?ooool2o`0001_ooooo0_l0001fooooo`00Poooool2
o`0000;ooooo0_l000001Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c004ooooo`Co00001_ooool00ol0003oooooooooo`0Sooooo`;o00007?ooool2o`0007Kooooo
0023ooooo`;o00000_ooool2o`0002?ooooo00?o0000ooooooooool00_ooool2o`0001oooooo0_l0
000Looooo`?o0000MOooool00:cooooo00?o0000ooooooooool00_ooool2o`0003gooooo0ol0001e
ooooo`00Z_ooool3o`0004?ooooo0_l0001fooooo`00Ooooool2o`0002Wooooo1Ol00006ooooo`;o
0000/Oooool007oooooo0_l0000[ooooo`03o`000?oooooooooo00Kooooo0_l0000Iooooo`;o0000
U_ooool009[ooooo0_l0000@ooooo`03o`000?oooooooooo013ooooo0_l0000?ooooo`;o00002_oo
ool2o`00017ooooo0_l0001gooooo`00Roooool2o`0000gooooo0_l0000@ooooo`03o`000?oooooo
oooo013ooooo0_l0000Kooooo`;o00004Oooool2o`0007Oooooo002;ooooo`;o00007oooool00ol0
003oooooooooo`2iooooo`00Roooool2o`0001oooooo00?o0000ooooooooool05oooool2o`000:3o
oooo002?ooooo`;o00001oooool2o`0001;ooooo00?o0000ooooooooool05oooool2o`000:3ooooo
002?ooooo`;o00001oooool2o`0001;ooooo00?o0000ooooooooool0;_ooool2o`0008Wooooo0029
ooooo`;o00008Oooool3o`0000oooooo0_l0000Mooooo`;o0000ROooool0083ooooo0_l00007oooo
o`;o00007_ooool2o`000003ooooool0003ooooo013ooooo0_l0002Xooooo`00P?ooool2o`0002Oo
oooo1?l0000]ooooo`;o0000S?ooool00:[ooooo0ol00009ooooo`;o00005_ooool2o`0000[ooooo
0ol0000?ooooo`;o0000N_ooool00:cooooo00?o0000ooooooooool01oooool2o`0001Kooooo0_l0
0009ooooo`Co00003oooool2o`0007[ooooo0025ooooo`;o00009Oooool00ol0003oooooooooo`0Z
ooooo`;o0000SOooool008Gooooo0_l0000@ooooo`;o00001_ooool2o`0000_ooooo00?o0000oooo
ooooool0^Oooool009Oooooo0_l00006ooooo`;o00002oooool00ol0003oooooooooo`2iooooo`00
X?ooool2o`0000Wooooo1?l0000looooo`;o0000Noooool009cooooo0_l00002ooooo`;o00002Ooo
ool2o`0003cooooo1?l0001kooooo`00W?ooool2o`0000kooooo00?o0000ooooooooool04oooool2
o`0002Gooooo0_l0001mooooo`00[?ooool00ol0003oooooooooo`0Cooooo`;o00009_ooool2o`00
07cooooo002/ooooo`03o`000?oooooooooo01_ooooo0_l0000Nooooo`;o0000O?ooool00:cooooo
00?o0000ooooooooool02Oooool2o`00013ooooo0_l0000Jooooo`;o0000P?ooool009Kooooo0_l0
000Dooooo`03o`000?oooooooooo00Wooooo0_l0000/ooooo`;o0000P?ooool008Kooooo0_l0000>
ooooo`;o00005?ooool00ol0003oooooooooo`02ooooo`;o0000]Oooool008Kooooo0_l0000:oooo
o`;o00000_ooool2o`0001Cooooo0ol00002ooooo`;o0000=?ooool2o`0007oooooo002;ooooo`;o
00001Oooool2o`0000;ooooo0_l0000Dooooo`;o00004_ooool2o`0002Cooooo0ol0001oooooo`00
Roooool2o`0001oooooo00?o0000ooooooooool04Oooool2o`0002Cooooo0ol0001oooooo`00[?oo
ool00ol0003oooooooooo`0fooooo`;o0000POooool008_ooooo0_l0000Oooooo`03o`000?oooooo
oooo02Cooooo0_l0000@ooooo`?o0000P?ooool008;ooooo0_l00007ooooo`;o00000oooool2o`00
01[ooooo00?o0000ooooooooool09?ooool2o`0000kooooo0_l000000ooooooo0000o`000020oooo
o`00P_ooool2o`0000cooooo0_l000001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1Oooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool01_ooool2o`0001cooooo0_l0000>
ooooo`;o0000Poooool0093ooooo0_l000001?nHV9SooooooiRHV?mgMgL2ooooo`;o000000?ooooo
ob4Q8OlQ8B402?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00Kooooo0_l0002a
ooooo`00TOooool01?l@413oooooooooooooool2o`000003ooooool0003o000000Kooooo0_l00004
ooooo`03o`000?oooooooooo00?ooooo00Co0000ooooool0003o00009?ooool2o`0009;ooooo002A
ooooo`04o`000?ooooooooooooooo`;o00002Oooool2o`0000?ooooo00?oMgMgoc8b<_ooool01?oo
ool4o`0000[ooooo0_l0000Eooooo`;o000000?oooooo`000?l000003?ooool2o`0008Cooooo002A
ooooo`05o`000?ooooooooooooooool000001?ooool2o`0000Kooooo1Ol00005ooooo`;o00003?oo
ool3o`0001Cooooo0_l0000=ooooo`Co0000Q?ooool0097ooooo00Go410@oooooooooooooooooa0@
4004ooooo`;o00001_ooool5o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0002?ooooo0_l0
0026ooooo`00TOooool01?mgMgOoV9RHoooooonHV9P2o`0000_ooooo00?o0000ooooooooool01_oo
ool2o`0000Kooooo0_l0000Zooooo`;o0000Qoooool008Sooooo0_l00007ooooo`04onk^k_lb<S;o
0000oc8b<P;o00002oooool4o`0000Gooooo0_l0000booooo`;o0000Qoooool008Sooooo0_l0000Q
ooooo`;o0000=?ooool2o`0008Gooooo0028ooooo`;o00008Oooool2o`0000?ooooo0_l0000/oooo
o`;o000000?oooooo`000?l00000QOooool008Sooooo0_l00008ooooo`;o00006?ooool01?l0003o
ooooooooooooool2o`0002cooooo0_l00028ooooo`00SOooool2o`0000?ooooo0_l0000Hooooo`?o
00004_ooool2o`0001_ooooo0_l00028ooooo`00SOooool3o`0000;ooooo0_l0000Hooooo`03o`00
0?oooooooooo01;ooooo0_l0000Kooooo`;o0000R?ooool008kooooo0_l00008ooooo`;o00004_oo
ool00ol0003oooooooooo`0_ooooo`;o0000R?ooool008[ooooo0_l0000<ooooo`;o00004_ooool0
0ol0003oooooooooo`0/ooooo`Co0000ROooool008[ooooo0_l0000Pooooo`03o`000?oooooooooo
02cooooo1?l00029ooooo`00Q?ooool2o`0002Kooooo0_l0002jooooo`00Q?ooool2o`0000kooooo
0_l0000Fooooo`;o0000^_ooool009Cooooo0_l0000Fooooo`;o0000^_ooool009cooooo0_l0000>
ooooo`?o00007?ooool2o`0009_ooooo002Looooo`;o00003_ooool00ol0003oooooooooo`0Loooo
o`;o0000Voooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
3?ooool2o`00033ooooo0_l0001iooooo`00[?ooool00ol0003oooooooooo`0<ooooo`;o00002Ooo
ool2o`0002Gooooo0_l0001iooooo`00[?ooool01?l0003oooooooooooooool2o`0001Cooooo0_l0
000@ooooo`;o0000S_ooool008cooooo0_l0000Booooo`;o00002_ooool01?l0003ooooooooooooo
ool2o`0002Kooooo0_l0002>ooooo`00S?ooool2o`0000[ooooo0_l00006ooooo`;o00002_ooool0
0ol0003oooooooooo`0;ooooo`;o0000[?ooool009Sooooo0_l0000Booooo`?o00002oooool2o`00
01[ooooo0_l0002@ooooo`00T_ooool2o`0001Sooooo00?o0000ooooooooool09oooool2o`00093o
oooo0027ooooo`;o00002Oooool2o`0001Sooooo00?o0000ooooooooool09oooool2o`00093ooooo
0027ooooo`;o00002_ooool2o`0001Oooooo0ol0000Cooooo`;o0000Y?ooool008gooooo0_l00004
ooooo`;o00005oooool3o`0001?ooooo0_l0000@ooooo`;o0000T_ooool008gooooo0_l00004oooo
o`;o00005?ooool2o`000003ooooool0003ooooo02Kooooo0_l0002Booooo`00Toooool2o`0001Co
oooo0_l000000ooooooo0000ooooo`06ooooo`?o0000/Oooool00:cooooo00?o0000ooooooooool0
1Oooool3o`0000[ooooo0_l0002Uooooo`00UOooool2o`0000Oooooo0ol00008ooooo`;o000000?o
ooooo`000?ooool04_ooool3o`000:Gooooo002Eooooo`;o00001oooool4o`0000Oooooo0_l00000
1?oooooo0000o`000?l0000Aooooo`;o0000Y_ooool00:3ooooo0_l0000:ooooo`03o`000?oooooo
oooo00?ooooo0_l0002dooooo`00[?ooool00ol0003oooooooooo`03ooooo`;o00002Oooool2o`00
0:Wooooo002/ooooo`03o`000?oooooooooo00kooooo0_l0000>ooooo`;o0000VOooool009Oooooo
0_l0000Cooooo`03o`000?oooooooooo00gooooo0_l0000?ooooo`;o0000VOooool008Wooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q0_ooool2o`0000;ooooo00?o0000onk^k_ooool0
1?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool03Oooool2o`000:[o
oooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo0_l000000omEEEGo
ZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0^Oooool008Wooooo
00Go410@oooooooooooooooooa0@400;ooooo`;o000000?oZJVYoeEEEOooool02?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo037ooooo0_l00026ooooo`00ROooool01Ol0003ooooo
oooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`?o
0000<Oooool2o`0008Kooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGo
c<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool2o`000;[ooooo0029ooooo`05
oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool06oooool2o`0009cooooo0029ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`09ooooo`;o00004?ooool2o`0009cooooo0029ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo00Wooooo0_l0000=
ooooo`;o0000Woooool00:cooooo00?o0000ooooooooool06?ooool2o`0001;ooooo0_l0002;oooo
o`00X?ooool2o`0000[ooooo00?o0000ooooooooool0;?ooool2o`0008_ooooo002Pooooo`;o0000
2_ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`0000Cooooo1?l0000<ooooo`;o000000?o
ooooo`000?l00000X?ooool00:cooooo00?o0000ooooooooool01?ooool4o`0000cooooo0_l00000
0ooooooo0000o`00002Pooooo`00UOooool2o`0001Gooooo00?o0000ooooooooool05?ooool3o`00
0:;ooooo002Eooooo`;o00005Oooool00ol0003oooooooooo`0Booooo`Go0000X_ooool00:cooooo
00?o0000ooooooooool04_ooool2o`000:Gooooo002Fooooo`;o00005?ooool00ol0003ooooooooo
o`02o`000;Oooooo002Fooooo`;o00005?ooool00ol0003oooooooooo`02o`000;Oooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`?o00003oooool2o`000:Sooooo002/ooooo`?o0000
3oooool3o`000:Oooooo002/ooooo`?o00004?ooool2o`000:Oooooo002Aooooo`;o00001oooool2
o`00013ooooo0_l0002jooooo`00TOooool2o`0000Oooooo0_l0000@ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo023ooooo0_l0002Gooooo`00Woooool2o`0000Sooooo
0_l000000ooooooo0000ooooo`0Qooooo`;o0000Uoooool009oooooo0_l00006ooooo`Co000000?o
ooooo`000?ooool0^_ooool009oooooo0_l00006ooooo`;o00000oooool00ol0003oooooooooo`2i
ooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Eooooo`;o00005Oooool00ol0003o
ooooooooo`2iooooo`00UOooool2o`0001Gooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0
002iooooo`00[?ooool00ol0003oooooooooo`03o`000;Kooooo002/ooooo`03o`000?oooooooooo
00?o0000]_ooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:;ooooo1?l000001?l@413ooooooooooooo
ool3o`000;_ooooo002Tooooo`03o`000?oooooooooo00?ooooo0ol0002kooooo`00Woooool2o`00
0004ooooool0003o0000o`0000Oooooo0ol0002iooooo`00Woooool2o`000004ooooool0003o0000
o`000<?ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7o
oooo002Tooooo`03o`000?oooooooooo0<7ooooo002Rooooo`03oeEEEOmVIVKo00000<?ooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Zooooo`04oa0@4?l0
003o0000o`000;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooo
oooo0;[ooooo002[ooooo`06o`000?mgMgOo0000o`000?mEEEGok^k^]oooool00:_ooooo00Ko0000
oeEEEOo^k^koooooogMgMomEEEFgooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03o`000?oo
oooooooo0;Gooooo002[ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0]Oooool0
0:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomVIVJgooooo`00Z_ooool00ol@413o0000ogMgM`02
o`000003ofIVI_o^k^kooooo0;Kooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.59434 .72678 Mdot
.40636 .77314 Mdot
.46487 .62834 Mdot
.54195 .59744 Mdot
.58306 .57061 Mdot
.61043 .34263 Mdot
.51502 .44931 Mdot
.72669 .44306 Mdot
.60187 .16979 Mdot
.55507 .40223 Mdot
.54296 .66074 Mdot
.72862 .53285 Mdot
.55334 .15895 Mdot
.56458 .56699 Mdot
.72147 .55516 Mdot
.42012 .59841 Mdot
.57592 .69134 Mdot
.56589 .17671 Mdot
.47372 .1963 Mdot
.6305 .74481 Mdot
.5695 .18799 Mdot
.3934 .30581 Mdot
.4241 .15671 Mdot
.5864 .21008 Mdot
.69157 .70024 Mdot
.41307 .30883 Mdot
.48994 .77839 Mdot
.45174 .21865 Mdot
.60245 .79729 Mdot
.39894 .7269 Mdot
.60196 .24811 Mdot
.60406 .1695 Mdot
.70644 .37185 Mdot
.4728 .85787 Mdot
.39438 .41861 Mdot
.66624 .61194 Mdot
.37422 .59177 Mdot
.40954 .46849 Mdot
.56619 .84922 Mdot
.72897 .56709 Mdot
.69325 .70657 Mdot
.40814 .709 Mdot
.50738 .15192 Mdot
.57028 .78322 Mdot
.622 .65499 Mdot
.49981 .80658 Mdot
.56511 .52164 Mdot
.52232 .06549 Mdot
.57679 .32569 Mdot
.61025 .77637 Mdot
.51284 .05637 Mdot
.4935 .94728 Mdot
.76923 .38741 Mdot
.4378 .16874 Mdot
.46024 .1302 Mdot
.66264 .26862 Mdot
.72736 .45691 Mdot
.57864 .68729 Mdot
.41971 .10363 Mdot
.63052 .62046 Mdot
.47372 .82597 Mdot
.43826 .98537 Mdot
.55798 .85911 Mdot
.42234 .53998 Mdot
.69701 .35882 Mdot
.63802 .22088 Mdot
.54726 .37286 Mdot
.43989 .70672 Mdot
.41064 .42482 Mdot
.6111 .2559 Mdot
.55084 .76028 Mdot
.44276 .61926 Mdot
.55666 .4165 Mdot
.50704 .2658 Mdot
.55835 .85852 Mdot
.48342 .3584 Mdot
.76936 .38808 Mdot
.41831 .70337 Mdot
.52665 .90841 Mdot
.53775 .25 Mdot
.66416 .415 Mdot
.40707 .77119 Mdot
.54907 .52271 Mdot
.39973 .64538 Mdot
.70669 .36254 Mdot
.41482 .50896 Mdot
.57973 .59445 Mdot
.55827 .67193 Mdot
.59612 .63218 Mdot
.43427 .68483 Mdot
.68741 .70882 Mdot
.59386 .08408 Mdot
.47523 .25425 Mdot
.53748 .73239 Mdot
.44541 .29671 Mdot
.55594 .0407 Mdot
.56623 .54896 Mdot
.51725 .06455 Mdot
.7755 .41105 Mdot
.59334 .64974 Mdot
.56874 .77924 Mdot
.60973 .5551 Mdot
.72653 .52672 Mdot
.54277 .82906 Mdot
.65236 .35776 Mdot
.44857 .83952 Mdot
.52675 .80264 Mdot
.51848 .24857 Mdot
.47821 .25434 Mdot
.61342 .26249 Mdot
.56713 .48604 Mdot
.54581 .57974 Mdot
.59672 .16004 Mdot
.66234 .64967 Mdot
.76065 .68975 Mdot
.45334 .6874 Mdot
.44133 .78943 Mdot
.66527 .2632 Mdot
.64099 .22173 Mdot
.38111 .67662 Mdot
.55012 .15565 Mdot
.51251 .98551 Mdot
.51517 .11864 Mdot
.59502 .81191 Mdot
.6148 .26402 Mdot
.52728 .65676 Mdot
.65059 .68538 Mdot
.48693 .89698 Mdot
.44731 .32584 Mdot
.42387 .15432 Mdot
.53174 .84076 Mdot
.72341 .58489 Mdot
.61974 .36679 Mdot
.55178 .21902 Mdot
.55493 .87293 Mdot
.38229 .70593 Mdot
.62549 .74963 Mdot
.55369 .40276 Mdot
.71604 .41737 Mdot
.72147 .56958 Mdot
.36251 .60334 Mdot
.54392 .419 Mdot
.42916 .27978 Mdot
.57523 .69406 Mdot
.6482 .69974 Mdot
.69273 .32349 Mdot
.70577 .81208 Mdot
.52592 .27105 Mdot
.54334 .71391 Mdot
.55096 .94627 Mdot
.61188 .52728 Mdot
.42523 .69415 Mdot
.59295 .21957 Mdot
.4567 .6671 Mdot
.63402 .45597 Mdot
.41131 .85934 Mdot
.53739 .8903 Mdot
.66217 .26062 Mdot
.37465 .59476 Mdot
.40319 .82878 Mdot
.49014 .16603 Mdot
.52509 .91191 Mdot
.70104 .69964 Mdot
.67376 .53839 Mdot
.49766 .14218 Mdot
.57993 .75343 Mdot
.68672 .31023 Mdot
.66455 .39911 Mdot
.40879 .48951 Mdot
.40867 .85366 Mdot
.63635 .71465 Mdot
.49296 .27191 Mdot
.42022 .6592 Mdot
.5786 .59085 Mdot
.54841 .32086 Mdot
.70557 .37745 Mdot
.53568 .02043 Mdot
.63165 .44075 Mdot
.46921 .70412 Mdot
.5914 .81309 Mdot
.44813 .94404 Mdot
.72141 .61453 Mdot
.45409 .24521 Mdot
.68616 .72508 Mdot
.52206 .38212 Mdot
.58734 .15183 Mdot
.60071 .16108 Mdot
.70638 .68207 Mdot
.53496 .19069 Mdot
.56222 .92838 Mdot
.64844 .70008 Mdot
.45525 .7168 Mdot
.71723 .40014 Mdot
.65487 .79545 Mdot
.72621 .55218 Mdot
.55209 .69525 Mdot
.65946 .16248 Mdot
.46334 .86277 Mdot
.51649 .60698 Mdot
.51161 .62896 Mdot
.43494 .55801 Mdot
.58404 .54228 Mdot
.68436 .19945 Mdot
.55432 .80268 Mdot
.52778 .60438 Mdot
.62297 .38643 Mdot
.54801 .5728 Mdot
.53894 .50016 Mdot
.53457 .68853 Mdot
.47947 .07748 Mdot
.42652 .74205 Mdot
.66515 .40244 Mdot
.42771 .33692 Mdot
.57261 .76778 Mdot
.44993 .8026 Mdot
.6979 .70643 Mdot
.52819 .40364 Mdot
.63523 .57479 Mdot
.73175 .53572 Mdot
.45009 .80663 Mdot
.43107 .0788 Mdot
.65884 .37496 Mdot
.67031 .45856 Mdot
.41641 .50733 Mdot
.58328 .4578 Mdot
.42683 .85105 Mdot
.48657 .26242 Mdot
.72133 .56015 Mdot
.45524 .74665 Mdot
.43824 .50525 Mdot
.68603 .20618 Mdot
.60158 .42557 Mdot
.49203 .77829 Mdot
.53807 .95607 Mdot
.411 .56595 Mdot
.52049 .86301 Mdot
.51415 .11413 Mdot
.54446 .82114 Mdot
.4387 .98511 Mdot
.58308 .27394 Mdot
.67743 .47146 Mdot
.55201 .75783 Mdot
.61249 .17876 Mdot
.43109 .36293 Mdot
.4292 .90562 Mdot
.60505 .55223 Mdot
.55649 .74874 Mdot
.55299 .86776 Mdot
.66297 .77855 Mdot
.45837 .69659 Mdot
.45858 .71984 Mdot
.40503 .8299 Mdot
.41703 .28937 Mdot
.42762 .69955 Mdot
.49854 .13467 Mdot
.4949 .38172 Mdot
.72238 .43533 Mdot
.47516 .02947 Mdot
.59237 .37723 Mdot
.49321 .77684 Mdot
.67329 .4879 Mdot
.42772 .49313 Mdot
.6108 .50713 Mdot
.61256 .67469 Mdot
.56257 .55287 Mdot
.58049 .27728 Mdot
.65531 .65677 Mdot
.45784 .17429 Mdot
.66138 .64412 Mdot
.48229 .12387 Mdot
.55548 .40011 Mdot
.56759 .30994 Mdot
.41627 .87653 Mdot
.46931 .2278 Mdot
.5701 .37799 Mdot
.53322 .07942 Mdot
.54117 .67184 Mdot
.63222 .43452 Mdot
.57053 .84745 Mdot
.46692 .28331 Mdot
.46892 .23302 Mdot
.37518 .60183 Mdot
.72703 .50171 Mdot
.52601 .26282 Mdot
.49807 .64938 Mdot
.57692 .43313 Mdot
.67442 .5993 Mdot
.52593 .75449 Mdot
.65481 .37836 Mdot
.40375 .16206 Mdot
.72371 .51391 Mdot
.40564 .15711 Mdot
.47966 .32959 Mdot
.38945 .23252 Mdot
.50939 .9833 Mdot
.6805 .54853 Mdot
.72247 .53914 Mdot
.66773 .87247 Mdot
.55387 .27627 Mdot
.5512 .2117 Mdot
.51985 .85975 Mdot
.61009 .1765 Mdot
.6981 .68726 Mdot
.56319 .55976 Mdot
.52594 .07241 Mdot
.43076 .22915 Mdot
.52617 .4828 Mdot
.46946 .07982 Mdot
.56382 .72335 Mdot
.53312 .13425 Mdot
.57215 .91999 Mdot
.44075 .64458 Mdot
.62951 .6094 Mdot
.43487 .81342 Mdot
.70555 .38777 Mdot
.42867 .44573 Mdot
.71883 .62395 Mdot
.59973 .87278 Mdot
.3637 .35296 Mdot
.48867 .75031 Mdot
.62383 .37732 Mdot
.39625 .60755 Mdot
.52442 .90521 Mdot
.58607 .47512 Mdot
.5238 .56999 Mdot
.50115 .37337 Mdot
.54404 .77031 Mdot
.73185 .4999 Mdot
.41454 .86306 Mdot
.44252 .30491 Mdot
.43319 .12501 Mdot
.45885 .29676 Mdot
.43428 .54723 Mdot
.41987 .83007 Mdot
.60348 .32195 Mdot
.49999 .14504 Mdot
.48978 .16606 Mdot
.58471 .51583 Mdot
.7572 .34453 Mdot
.42772 .24267 Mdot
.43302 .85769 Mdot
.42252 .53627 Mdot
.68866 .32534 Mdot
.50526 .75188 Mdot
.63326 .73112 Mdot
.38678 .60104 Mdot
.52239 .33447 Mdot
.5005 .79802 Mdot
.36343 .62287 Mdot
.72978 .52575 Mdot
.38771 .24141 Mdot
.6622 .634 Mdot
.53841 .2436 Mdot
.47852 .86328 Mdot
.64228 .70096 Mdot
.60805 .46707 Mdot
.72946 .52374 Mdot
.37046 .26743 Mdot
.67857 .48489 Mdot
.72377 .57791 Mdot
.71626 .63487 Mdot
.68837 .72576 Mdot
.4395 .39419 Mdot
.5926 .38371 Mdot
.72055 .57288 Mdot
.72467 .44325 Mdot
.44678 .35562 Mdot
.64118 .33357 Mdot
.42475 .25808 Mdot
.62676 .39703 Mdot
.57763 .76198 Mdot
.53944 .08987 Mdot
.52406 .85743 Mdot
.37342 .41258 Mdot
.46262 .94656 Mdot
.41238 .19938 Mdot
.37539 .35775 Mdot
.4125 .19602 Mdot
.70452 .66051 Mdot
.74337 .73794 Mdot
.37309 .52721 Mdot
.63786 .48339 Mdot
.47265 .68201 Mdot
.63748 .81613 Mdot
.60053 .61628 Mdot
.49441 .35203 Mdot
.71956 .62867 Mdot
.61511 .26383 Mdot
.52559 .55789 Mdot
.52335 .30257 Mdot
.40088 .52091 Mdot
.47291 .78916 Mdot
.54119 .08609 Mdot
.66721 .39774 Mdot
.71948 .62459 Mdot
.51968 .80971 Mdot
.74291 .31345 Mdot
.49568 .84882 Mdot
.54381 .30814 Mdot
.56574 .36844 Mdot
.47692 .65999 Mdot
.73001 .48451 Mdot
.72854 .5261 Mdot
.49531 .77133 Mdot
.51481 .31692 Mdot
.47913 .79372 Mdot
.42277 .36329 Mdot
.61257 .86383 Mdot
.54644 .71326 Mdot
.67508 .53605 Mdot
.54749 .4507 Mdot
.42136 .67171 Mdot
.43226 .40451 Mdot
.56572 .65634 Mdot
.4942 .84633 Mdot
.45799 .78273 Mdot
.52034 .63721 Mdot
.53209 .9658 Mdot
.71545 .41274 Mdot
.49917 .43859 Mdot
.401 .33261 Mdot
.52655 .80283 Mdot
.63594 .51207 Mdot
.44437 .19831 Mdot
.41283 .5966 Mdot
.63239 .82695 Mdot
.59515 .08102 Mdot
.50224 .88669 Mdot
.78097 .60782 Mdot
.55358 .81378 Mdot
.50093 .69963 Mdot
.61828 .19744 Mdot
.71857 .58615 Mdot
.53571 .68074 Mdot
.38717 .60297 Mdot
.76067 .35606 Mdot
.52339 .34168 Mdot
.52756 .48278 Mdot
.56061 .35798 Mdot
.67381 .48225 Mdot
.51459 .20765 Mdot
.63181 .12765 Mdot
.53374 .44122 Mdot
.40515 .30579 Mdot
.41202 .73381 Mdot
.42795 .37986 Mdot
.44609 .66363 Mdot
.495 .24086 Mdot
.72654 .44458 Mdot
.4286 .5512 Mdot
.54438 .88604 Mdot
.43731 .873 Mdot
.62401 .64139 Mdot
.65681 .66408 Mdot
.64193 .3389 Mdot
.54281 .76882 Mdot
.53158 .32317 Mdot
.73226 .50786 Mdot
.66416 .7778 Mdot
.56195 .55432 Mdot
.38944 .23129 Mdot
.4511 .18475 Mdot
.58976 .64166 Mdot
.63586 .72572 Mdot
.56705 .78349 Mdot
.49074 .20437 Mdot
.4969 .8043 Mdot
.47457 .85904 Mdot
.43824 .98839 Mdot
.54344 .20787 Mdot
.4768 .35257 Mdot
.48232 .12886 Mdot
.54545 .26365 Mdot
.43659 .41475 Mdot
.4748 .75681 Mdot
.43059 .18688 Mdot
.54568 .20683 Mdot
.48887 .69672 Mdot
.40448 .39759 Mdot
.64086 .22583 Mdot
.58523 .55675 Mdot
.62179 .64157 Mdot
.41808 .3378 Mdot
.44783 .22896 Mdot
.48066 .30704 Mdot
.76771 .67151 Mdot
.49033 .31789 Mdot
.41284 .80332 Mdot
.43408 .07511 Mdot
.67375 .55034 Mdot
.41637 .35748 Mdot
.61255 .77556 Mdot
.72548 .58562 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo00Sooooo0_l0002_ooooo`00[?ooool3o`0000Sooooo0_l0002_ooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00Xoooool2o`0000Oooooo00?o0000ooooooooool0^Oooool00:?o
oooo0_l00007ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo00oooooo0_l0002Xooooo`00[?ooool00ol0003oooooooooo`0?
ooooo`;o0000Z?ooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
1?l0003oooooooooooooool2o`000;Kooooo002/ooooo`04o`000?ooooooooooooooo`;o0000]_oo
ool00:cooooo00?o0000ooooooooool00_ooool2o`000;Gooooo002/ooooo`03o`000?oooooooooo
00;ooooo1?l0002cooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o0000/oooool00:cooooo
00?o0000ooooooooool01Oooool2o`000;;ooooo002Fooooo`;o00005?ooool3o`0000Gooooo0_l0
002booooo`00UOooool3o`0000Wooooo0_l00002ooooo`;o00001Oooool00ol0003oooooooooo`08
ooooo`;o0000[oooool009Gooooo0_l0000:ooooo`;o00000_ooool2o`0000Gooooo00?o0000oooo
ooooool02?ooool2o`0001;ooooo0_l0002Kooooo`00[?ooool00ol0003oooooooooo`0:ooooo`;o
00004?ooool2o`0009_ooooo002/ooooo`03o`000?oooooooooo00[ooooo0_l0000@ooooo`;o0000
Voooool00:cooooo00?o0000ooooooooool02_ooool2o`000:gooooo002/ooooo`03o`000?oooooo
oooo00[ooooo0_l0002]ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wo
oooo002Aooooo`;o00006Oooool00ol0003oooooooooo`2iooooo`00TOooool2o`0001Wooooo00?o
0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00Co0000oooooooooooooooo0_l0002fooooo`00ROooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`04o`000?ooooooooooooooo`?o0000]Oooool008Wooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool00_ooool2o`000;Gooooo0021ooooo`Ko00000_ooool0
1Ol@413ooooooooooooooooo410@00Sooooo0_l00003ooooo`03ojVYZOmEEEGooooo00Sooooo0_l0
0004ooooo`?o0000^Oooool008Wooooo00Go0000ooooooooooooooooo`000008ooooo`;o00001?oo
ool00olQ8B7oooooooooo`06ooooo`03ogMgMol0003o000000Cooooo00?o0000ooooooooool0:?oo
ool2o`0008oooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool01?mEEEGoc<c<o`00
0?l00002ooooo`04o`000?lQ8B7o0000oc8b<P;o00001?ooool00ol0003oooooooooo`0Xooooo`;o
0000Soooool008Wooooo00Go410@oooooooooooooooooa0@400>ooooo`04ojVYZOmgMgOo0000o`00
00;ooooo00?o0000ooooooooool01_ooool2o`0000Wooooo0_l0002`ooooo`00ROooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooo
oooo00Kooooo0_l00009ooooo`;o0000/?ooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool0^Oooool00:_ooooo0_l0002koooo
o`00Zoooool3o`000;[ooooo002/ooooo`;o0000^_ooool00:cooooo1?l0000Hooooo`;o0000W_oo
ool009;ooooo0_l0000Hooooo`04o`000?oooooo0000o`0000cooooo0_l0000:ooooo`;o0000W_oo
ool008cooooo0_l00004ooooo`?o00005oooool00ol0003oooooooooo`0=ooooo`?o0000ZOooool0
08cooooo0_l00005ooooo`;o00005oooool00ol0003oooooooooo`0>ooooo`;o00003?ooool4o`00
09Wooooo002<ooooo`;o00007_ooool00ol0003oooooooooo`0Looooo`Co00004Oooool2o`0008Ko
oooo002Xooooo`;o00000_ooool00ol0003oooooooooo`0aooooo`;o0000Q_ooool009Oooooo0_l0
000?ooooo`;o00000_ooool00ol0003oooooooooo`0Nooooo`?o0000V?ooool009Oooooo0_l00005
ooooo`;o00003?ooool00ol0003oooooooooo`0Nooooo`?o0000V?ooool009kooooo0_l0000<oooo
o`?o00004_ooool2o`0000gooooo0_l0002Fooooo`00[?ooool00ol0003oooooooooo`0Booooo`;o
00003Oooool3o`0009Gooooo002/ooooo`03o`000?oooooooooo02;ooooo0_l0002Eooooo`00Vooo
ool2o`0000oooooo00?o0000ooooooooool0^Oooool009Gooooo0_l00004ooooo`;o00003oooool0
0ol0003oooooooooo`0Dooooo`;o0000Xoooool009Gooooo0_l0000Eooooo`03o`000?oooooooooo
00Sooooo0_l0000:ooooo`;o0000Xoooool00:cooooo00?o0000ooooooooool02?ooool2o`000:oo
oooo002?ooooo`;o00002?ooool2o`0000Sooooo0_l00007ooooo`03o`000?oooooooooo02Cooooo
0_l0002Cooooo`00Soooool2o`0000Sooooo0_l00008ooooo`;o00001oooool3o`0002Cooooo0_l0
000Cooooo`;o0000O_ooool008oooooo0_l0000Hooooo`;o000000?oooooo`000?ooool0>_ooool2
o`0007kooooo002Yooooo`;o000000?oooooo`000?ooool00_ooool2o`0000Wooooo0_l0000/oooo
o`;o0000OOooool00:cooooo00Co0000oooooooooooooooo0_l00008ooooo`?o00002oooool2o`00
01oooooo0_l0001mooooo`00[?ooool00ol0003oooooooooo`0;ooooo`Co00002_ooool2o`0009ko
oooo002/ooooo`03o`000?oooooooooo00gooooo0_l0002Zooooo`00W?ooool2o`0000kooooo00?o
0000ooooooooool03_ooool2o`0000_ooooo0_l0002Looooo`00W?ooool2o`0000kooooo00?o0000
ooooooooool03_ooool2o`0000_ooooo0_l0000=ooooo`?o0000S?ooool00:cooooo0ol0000Zoooo
o`?o0000S?ooool00:7ooooo0_l00009ooooo`03o`000?oooooooooo02_ooooo0_l0002<ooooo`00
Qoooool2o`0000cooooo0_l00003ooooo`;o00001Oooool2o`0000Wooooo00?o0000ooooooooool0
^Oooool008Oooooo0_l0000<ooooo`;o00000oooool2o`0000Gooooo0_l00009ooooo`03o`000?oo
oooooooo0;Wooooo0027ooooo`;o00006?ooool2o`0000Wooooo00?o0000ooooooooool0^Oooool0
0:[ooooo0ol0002kooooo`00Q_ooool2o`0000Wooooo00?ok^k^oc8b<_l000000_l00005ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00?ooooo0ol0000;ooooo`;o0000[_ooool008Ko
oooo0_l00009ooooo`03ogMgMonHV9Sooooo00;o00001Oooool00olQ8B7o0000o`000007ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool02Oooool2o`000:kooooo0029ooooo`Ko0000
0_ooool01Ol@413ooooooooooooooooo410@00Kooooo0_l00008ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l0000Cooooo`;o0000VOooool0097ooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00003ooooo`;o
00001?ooool2o`0001?ooooo0_l0002Iooooo`00TOooool01Ol0003ooooooooooooooooo000000co
oooo1?l000000oo<c<coooooooooo`03ooooo`03o`000?oooooooooo027ooooo0_l0002Fooooo`00
TOooool01Ol@413oooooo`000?l0003o410@00cooooo1?l00006ooooo`03o`000?oooooooooo027o
oooo0_l0002Fooooo`00TOooool01OmgMgOoV9RHo`000?l0003oMgMg00cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0booooo`;o0000QOooool0097ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`Co000000?oooooo`000?l000000oooool00ol0003oooooooooo`05ooooo`;o
00001Oooool2o`0001Cooooo0ol0000=ooooo`?o0000Q?ooool0087ooooo0_l0000Tooooo`;o0000
0oooool01?l0003oooooo`000?l00004ooooo`;o00001Oooool2o`0001Cooooo0ol0000>ooooo`;o
0000Q?ooool0087ooooo0_l0000Yooooo`04o`000?oooooo0000o`0000Cooooo0_l0000[ooooo`;o
0000QOooool00:Wooooo0_l000000ooooooo0000ooooo`06ooooo`;o00004Oooool2o`0001Sooooo
0_l00025ooooo`00ZOooool2o`000004ooooool0003o0000o`0000kooooo0_l00007ooooo`?o0000
Woooool009Cooooo0_l0000Fooooo`03o`000?oooooooooo00kooooo0_l00007ooooo`;o0000X?oo
ool009Cooooo0_l0000;ooooo`;o00002Oooool00ol0003oooooooooo`2iooooo`00XOooool2o`00
00Wooooo00?o0000ooooooooool0^Oooool0093ooooo0_l0000Jooooo`03o`000?oooooooooo0;Wo
oooo002@ooooo`;o00006_ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00V_ooool2o`0000;ooooo0_l0000<ooooo`03o`000?oooooooooo0;Wooooo002Joooo
o`;o00000_ooool2o`0000cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o
0000/oooool008Sooooo0_l00002ooooo`;o00002oooool2o`0000[ooooo0_l00005ooooo`03o`00
0?oooooooooo00Cooooo0_l0002cooooo`00R?ooool2o`0000;ooooo0_l000000ooooooo0000o`00
0008ooooo`;o00002_ooool2o`0000Gooooo00?o0000ooooooooool02oooool2o`0000Kooooo0_l0
000Uooooo`;o0000OOooool008oooooo0_l0000Kooooo`03o`000?oooooooooo00_ooooo0_l00006
ooooo`;o00009Oooool2o`00017ooooo0_l0001Zooooo`00[?ooool00ol0003oooooooooo`1=oooo
o`;o0000J_ooool00:Sooooo0_l00002ooooo`04o`000?ooooooooooooooo`;o0000]_ooool00:So
oooo0_l00002ooooo`04o`000?ooooooooooooooo`;o00002_ooool2o`00013ooooo0_l0002Hoooo
o`00[?ooool3o`0000Oooooo0_l00004ooooo`;o00001oooool2o`0000Oooooo0_l0000Jooooo`?o
0000Noooool009[ooooo0_l0000@ooooo`03o`000?oooooooooo00Oooooo0_l0000=ooooo`;o0000
8oooool3o`0007_ooooo002Jooooo`;o00002Oooool2o`0000Gooooo00?o0000ooooooooool0^Ooo
ool008_ooooo0_l0000Hooooo`;o00001Oooool00ol0003oooooooooo`04ooooo`;o00009Oooool2
o`0008cooooo002;ooooo`;o00001?ooool2o`000003ooooool0003o000001Kooooo00?o0000oooo
ooooool01?ooool2o`0002Gooooo0_l0002<ooooo`00TOooool2o`000003ooooool0003o000001Ko
oooo00?o0000ooooooooool0:oooool2o`0008cooooo002/ooooo`03o`000?oooooooooo00Cooooo
0_l0000Kooooo`;o00002?ooool2o`0008cooooo002/ooooo`03o`000?oooooooooo00Cooooo0_l0
000Kooooo`;o0000;_ooool2o`0006Kooooo002/ooooo`03o`000?oooooooooo057ooooo0_l0001V
ooooo`00Ooooool2o`0002?ooooo0_l00004ooooo`Go0000^Oooool007oooooo0_l0000Iooooo`;o
00002?ooool2o`0000Cooooo0ol0001Eooooo`;o0000I?ooool008;ooooo0_l0000<ooooo`;o0000
2?ooool2o`0000[ooooo0_l00004ooooo`03o`000?oooooooooo017ooooo0_l0000Looooo`;o0000
3Oooool2o`0001?ooooo0_l0001Tooooo`00P_ooool2o`0000cooooo0_l0000Dooooo`;o00001?oo
ool00ol0003oooooooooo`0Aooooo`;o00007?ooool2o`0000gooooo0_l0001iooooo`00T_ooool2
o`000003ooooool0003o000001Gooooo00?o0000ooooooooool0@Oooool2o`0007Kooooo0029oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool2o`000003ob4Q8Ol0003o000000;ooooo1Ol00004
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Tooooo`;o00006ooo
ool2o`0007Kooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
4_ooool2o`00013ooooo0_l0002Cooooo`00POooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool2o`0000gooooo
0_l00004ooooo`;o0000;Oooool2o`0007Kooooo0029ooooo`05o`000?ooooooooooooooool00000
3Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000<ooooo`;o0000
3Oooool2o`0000Sooooo0_l0000:ooooo`;o00003_ooool2o`0007Kooooo0029ooooo`05o`000?oo
ooooooooooooool000001_ooool2o`0000Kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool05?ooool2o`0000Gooooo0_l00008ooooo`;o
00002Oooool3o`0000gooooo0_l0001gooooo`00ROooool01Ol@413ooooooooooooooooo410@00Ko
oooo0_l00007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool3o`0000Ko
oooo0_l0000>ooooo`;o00006_ooool2o`0000kooooo0_l0001gooooo`00ROooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo
00Gooooo0ol00006ooooo`;o00005Oooool2o`0009cooooo0029ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooo
oooo01_ooooo0_l00008ooooo`;o00006Oooool2o`0001?ooooo0_l0001Rooooo`00[?ooool00ol0
003oooooooooo`0Uooooo`;o00006Oooool2o`0001?ooooo0_l0001Rooooo`00V?ooool2o`0001;o
oooo00?o0000ooooooooool0^Oooool008cooooo0_l0000:ooooo`;o00004_ooool00ol0003ooooo
ooooo`0Vooooo`;o00003?ooool2o`0008?ooooo002<ooooo`;o00007_ooool3o`0000oooooo0_l0
000Eooooo`;o00002oooool3o`0000kooooo0_l0001cooooo`00UOooool2o`0001Gooooo00?o0000
ooooooooool01_ooool2o`0000Kooooo0ol0000Rooooo`;o00003oooool2o`0007?ooooo002Eoooo
o`;o00005Oooool00ol0003oooooooooo`06ooooo`;o00001_ooool3o`0002;ooooo0_l00024oooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00P_ooool2o`0002Sooooo00?o0000ooooooooool0
A?ooool2o`0001;ooooo0_l0001Oooooo`00P_ooool2o`0001?ooooo0_l0000Cooooo`03o`000?oo
oooooooo00oooooo0_l0000Rooooo`;o00003oooool2o`0001;ooooo0_l0001Oooooo`00ROooool2
o`0000cooooo0_l0000Cooooo`03o`000?oooooooooo00_ooooo0_l00002ooooo`;o00008_ooool2
o`0000oooooo0_l0001cooooo`00ROooool2o`00027ooooo00?o0000ooooooooool02oooool2o`00
03Oooooo0_l0001cooooo`00S_ooool2o`0001cooooo0ol0000Nooooo`;o0000VOooool008kooooo
0_l0000Looooo`03o`000?oooooooooo01kooooo0_l0002Iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`0Fooooo`;o00004?ooool2o`0008oooooo002/oooo
o`03o`000?oooooooooo01Kooooo0_l0000@ooooo`;o00007?ooool2o`00077ooooo002[ooooo`;o
0000:_ooool2o`0001cooooo0_l0001aooooo`00Zoooool2o`0000[ooooo0_l0000Nooooo`;o0000
7Oooool2o`00073ooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`08ooooo`;o0000?Ooo
ool2o`00073ooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`02ooooo`;o0000@oooool2
o`00073ooooo002/ooooo`?o00000_ooool2o`0000Sooooo0_l0002[ooooo`00[?ooool00ol0003o
ooooooooo`0<ooooo`;o00006oooool2o`0008kooooo002/ooooo`03o`000?oooooooooo01Sooooo
0_l0000?ooooo`;o00002_ooool2o`00017ooooo0_l0001_ooooo`002Oooool4o`000003oa0@4?oo
oooooooo01Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^
ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Kooooo
00?o0000ooooooooool06?ooool3o`000003oc8b<_o^k^kooooo00Cooooo0_lQ8B44ooooo`Go0000
1?ooool01?m4A4Co0000o`000?lb<S82o`0000kooooo00?ok^k^oc8b<_l000000_l00005ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd06?oo
ool4o`000003oa0@4?oooooooooo01;ooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb
<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8b
ooooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo01Gooooo00?o0000ooooooooool06?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01ooo
ool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03
oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool06Oooool00ol0003oooooooooo`0Dooooo`00
1_l00005ooooo`03o`000?oooooooooo013ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@
41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`05ooooo`Ko00000_ooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo01Sooooo00Go410@oooooooooooooooooa0@4003ooooo`;o00001ooo
ool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00gooooo00Go410@oooooooooooooooo
oa0@400@ooooo`03o`000?oooooooooo00gooooo00Go410@oooooooooooooooooa0@400=ooooo`03
ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Dooooo`00
2oooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7o
ooooooooo`06ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000=ooooo`04oiRHV?lQ8B7o
k^k^ooooo`;o00001?ooool00omgMgOo<S8booooo`0Eooooo`03o`000?oooooooooo01Sooooo00Go
0000ooooooooooooooooo`000003ooooo`;o00002?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMg
Molb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00ko
oooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b
<_ooool06Oooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05
o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00?ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`02o`000006
ooooool0003o8B4Qo`000?lb<S;oc<c<5_ooool00ol0003oooooooooo`0Hooooo`05o`000?oooooo
ooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`06o`000?lQ8B7o0000oc8b<_o<c<co
oooo0_l0000<ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00oooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c00Jooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oo
oooooooo01Sooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo
00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooooooo
ool04Oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Hooooo`?o00006?ooool01Ol@413o0000o`000?oooooo410@00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`;o00003?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00kooooo
00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Cooooo
000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0Hooooo`05ogMgMol0003o0000oiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Co
oooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b
<P04ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05?ooool000Wooooo00?oEEEE
ofIVI_l000006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00004?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0000Gooooo`03o`000?oooooooooo
00Gooooo0ol0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<00Cooooo1?l000000ooooooo0000o`00000=ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0001Wo
oooo00?oEEEEofIVI_l000005_ooool00:cooooo00?o0000ooooooooool01Oooool3o`0000_ooooo
0_l0000Eooooo`;o00002_ooool4o`0000kooooo0_l0001_ooooo`00[?ooool00ol0003ooooooooo
o`0Cooooo`;o00005Oooool2o`0000[ooooo1?l0000>ooooo`;o0000Koooool008gooooo0_l0000M
ooooo`03o`000?oooooooooo03Kooooo0_l0001fooooo`;o00000_ooool2o`0000Gooooo002=oooo
o`;o00001Oooool2o`0001Kooooo00?o0000ooooooooool0[_ooool01_o^k^ko8B4QohN7Qonj^[[o
0000omgMg@Gooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`2_ooooo`04omgMgOl0003o
410@olc<c0Kooooo0007oooooooo0000C?l0000<ooooo`04onk^k_lQ8B7o410@onk^kPKooooo0007
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00;o00000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`?o00001Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00Co8B4QogMgMomgMgOo<S8b1_oo
ool000Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool02_ooool2o`0000Gooooo0_l0000Cooooo`03o`000?oooooo
oooo027ooooo0_l00004ooooo`03o`000?oooooooooo01kooooo0_l00006ooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`09ooooo`;o00000_ooool2
o`0000Gooooo002?ooooo`?o00001Oooool2o`0001?ooooo00?o0000ooooooooool08Oooool2o`00
02Kooooo0_l0001^ooooo`00Soooool2o`0001_ooooo00?o0000ooooooooool0:Oooool2o`0001ko
oooo0_l0001^ooooo`00[?ooool00ol0003oooooooooo`0Iooooo`;o00003_ooool2o`0001_ooooo
0_l0001aooooo`00[?ooool00ol0003oooooooooo`0Iooooo`;o0000:oooool2o`00077ooooo002;
ooooo`;o00007oooool00ol0003oooooooooo`0=ooooo`;o00000oooool2o`000:Gooooo002;oooo
o`;o00007oooool3o`0000gooooo0_l00003ooooo`;o0000=?ooool2o`0006oooooo0022ooooo`;o
0000:?ooool00ol0003oooooooooo`0Qooooo`;o00009?ooool3o`0006oooooo0022ooooo`;o0000
:?ooool00ol0003oooooooooo`0Qooooo`;o00009?ooool3o`0006oooooo002/ooooo`03o`000?oo
oooooooo04Sooooo0_l0001_ooooo`00T_ooool2o`0001Sooooo00?o0000ooooooooool0=_ooool2
o`00013ooooo0ol0001^ooooo`00T_ooool2o`0001Sooooo00?o0000ooooooooool0=_ooool2o`00
00kooooo0_l000000ooooooo0000o`00001^ooooo`00T_ooool2o`0001Sooooo00?o0000oooooooo
ool06?ooool2o`0001cooooo0_l0000>ooooo`;o0000LOooool00:cooooo00?o0000ooooooooool0
6?ooool2o`0009oooooo002Fooooo`;o00005?ooool00ol0003oooooooooo`0Booooo`;o00009?oo
ool2o`0007oooooo002Dooooo`Co00005?ooool3o`00017ooooo0ol0000;ooooo`;o00005Oooool4
o`0000gooooo0_l0001`ooooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool04Oooool2o`00
00cooooo1?l0000Cooooo`;o00003_ooool3o`00073ooooo002Fooooo`;o00005?ooool00ol0003o
ooooooooo`05ooooo`;o00002_ooool2o`0000Kooooo0_l00006ooooo`;o00008oooool2o`00077o
oooo002Fooooo`;o00005?ooool00ol0003oooooooooo`05ooooo`;o00002_ooool2o`0000Kooooo
0_l0000[ooooo`;o0000LOooool00:cooooo00?o0000ooooooooool04Oooool2o`0003?ooooo0_l0
001aooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool04_ooool2o`0003Cooooo0_l0001_
ooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool01?ooool2o`0000cooooo0_l00004oooo
o`;o0000;?ooool4o`0006oooooo002/ooooo`03o`000?oooooooooo00Cooooo0_l00006ooooo`;o
00002_ooool2o`0002_ooooo0ol0001aooooo`00[?ooool3o`0000cooooo0_l0000Kooooo`;o0000
6_ooool2o`0007;ooooo002/ooooo`03o`000?oooooooooo00cooooo0_l0000Kooooo`;o00006ooo
ool2o`00077ooooo002/ooooo`03o`000?oooooooooo00cooooo0_l0000hooooo`;o0000LOooool0
0:cooooo00?o0000ooooooooool0AOooool4o`00073ooooo002/ooooo`03o`000?oooooooooo04Go
oooo1?l0001`ooooo`00P_ooool2o`0002Sooooo00?o0000ooooooooool05oooool2o`000:3ooooo
0022ooooo`;o0000:?ooool00ol0003oooooooooo`0Gooooo`;o0000X?ooool008;ooooo0_l0000;
ooooo`Co00006Oooool00ol0003oooooooooo`0:ooooo`;o00002oooool2o`000:3ooooo0026oooo
o`;o00001oooool4o`0001Wooooo0ol0000:ooooo`;o0000:_ooool2o`00087ooooo001nooooo`;o
00000_ooool2o`0000;ooooo0_l0000Tooooo`03o`000?oooooooooo00Kooooo0_l0000^ooooo`;o
0000POooool007kooooo0_l00002ooooo`;o00000_ooool2o`0002Cooooo00?o0000ooooooooool0
0_ooool2o`0000;ooooo0_l0002aooooo`00ROooool2o`00027ooooo00?o0000ooooooooool00_oo
ool2o`0002?ooooo0_l0000`ooooo`;o0000G_ooool008Wooooo0_l0000Qooooo`03o`000?oooooo
oooo02Oooooo0_l0000:ooooo`;o00009?ooool2o`0005kooooo002/ooooo`03o`000?oooooooooo
01kooooo0_l0000Cooooo`;o00004Oooool2o`00077ooooo0029ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`0Nooooo`;o00009_ooool2o`00077ooooo0029ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo0_l000000oo^k^koooooodA4A007ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0:?ooool2o`0008oooooo001nooooo`;o00002Oooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03
ooooo`?o0000:?ooool2o`0001_ooooo0_l0001booooo`00O_ooool2o`0000Wooooo00Go0000oooo
ooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00;ooooo0_l00003ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0AOooool2o`0007;ooooo0029ooooo`05o`000?oooooooooo
ooooool000003_ooool01?mgMgOoIVIVooooooooool3o`000004ob4Q8Ol0003o<S8bolc<c0Gooooo
00?o0000ooooooooool00_l00013ooooo`;o0000L_ooool008Wooooo00Go410@oooooooooooooooo
oa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`02o`0001[ooooo0_l0000Dooooo`;o0000QOooool008Wooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00?ooooo0_l0000Gooooo`;o00005?ooool2o`00013ooooo0_l0001cooooo`00
ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co00001_ooool00ol0003oooooooooo`03ooooo`;o0000?oooool2o`0007?ooooo002/ooooo`03
o`000?oooooooooo01[ooooo0_l00009ooooo`?o0000TOooool008[ooooo0_l0000<ooooo`;o0000
4_ooool00ol0003oooooooooo`0Jooooo`;o00002Oooool3o`0000[ooooo0_l00025ooooo`00R_oo
ool2o`0000cooooo0_l0000Aooooo`;o00007Oooool2o`0001Gooooo0_l00025ooooo`00Zoooool4
o`0001_ooooo0_l0000Eooooo`;o0000QOooool00:cooooo00?o0000ooooooooool09Oooool2o`00
09;ooooo002/ooooo`03o`000?oooooooooo00Kooooo0_l0000:ooooo`;o00004Oooool2o`0000Wo
oooo0_l00027ooooo`00TOooool2o`00017ooooo0_l00006ooooo`03o`000?oooooooooo00Kooooo
0_l00003ooooo`;o00001Oooool2o`0001cooooo0_l0000>ooooo`;o0000Moooool0097ooooo0_l0
0007ooooo`;o00002?ooool2o`0000Kooooo00?o0000ooooooooool02oooool2o`0002?ooooo0_l0
000>ooooo`;o0000Moooool009[ooooo0_l000000ooooooo0000o`00000=ooooo`03o`000?oooooo
oooo033ooooo0_l00027ooooo`00WOooool2o`0000gooooo00?o0000ooooooooool0^Oooool009;o
oooo0_l0000Hooooo`03o`000?oooooooooo00[ooooo0_l00004ooooo`;o0000@oooool2o`0006;o
oooo0024ooooo`;o00003?ooool2o`0001Sooooo0ol0000:ooooo`;o00001?ooool2o`00013ooooo
0_l0000aooooo`;o0000H_ooool008Cooooo0_l0000Vooooo`03o`000?oooooooooo02;ooooo0_l0
002Eooooo`00Xoooool2o`0000Oooooo00?o0000ooooooooool02?ooool2o`0003Oooooo0_l0001f
ooooo`00U_ooool2o`0000_ooooo0_l00007ooooo`03o`000?oooooooooo00Sooooo0_l0000Toooo
o`;o00004Oooool2o`0007Kooooo002Fooooo`;o00001?ooool2o`0000kooooo00?o0000oooooooo
ool02?ooool2o`0000gooooo0_l0000Eooooo`;o00003_ooool2o`0007Wooooo002Looooo`;o0000
3_ooool00ol0003oooooooooo`08ooooo`;o00003?ooool3o`0002Gooooo0_l0000Cooooo`;o0000
I?ooool009?ooooo0_l0000Gooooo`03o`000?oooooooooo00kooooo0_l00005ooooo`?o0000>ooo
ool2o`0006Cooooo002Cooooo`;o00002Oooool2o`0000Sooooo0_l00002ooooo`03o`000?oooooo
oooo00kooooo0_l00005ooooo`;o0000X_ooool009Cooooo0_l00008ooooo`;o00002?ooool2o`00
00;ooooo0ol0000/ooooo`Co00003?ooool2o`000003ooooool0003o000007Sooooo002Aooooo`;o
000000?oooooo`000?l000002oooool2o`0000Wooooo0_l0000]ooooo`Co00003?ooool2o`000003
ooooool0003o000007Sooooo0025ooooo`;o00002_ooool2o`0000Gooooo0_l00007ooooo`;o0000
2Oooool00ol0003oooooooooo`0looooo`Co0000NOooool008Gooooo0_l00006ooooo`;o00002Ooo
ool2o`0001;ooooo00?o0000ooooooooool0>_ooool6o`0007Wooooo002=ooooo`;o00007Oooool0
0ol0003oooooooooo`0<ooooo`;o0000;?ooool2o`0007gooooo002/ooooo`03o`000?oooooooooo
00_ooooo0ol0000Looooo`;o0000SOooool009gooooo0_l0000=ooooo`03o`000?oooooooooo00_o
oooo0_l0000Mooooo`;o0000SOooool009gooooo0ol0000<ooooo`03o`000?oooooooooo0;Wooooo
002Nooooo`;o00003?ooool3o`0001;ooooo0_l0000Vooooo`;o0000OOooool008[ooooo0_l0000P
ooooo`03o`000?oooooooooo01;ooooo0_l00008ooooo`;o00002oooool2o`0000oooooo0ol0001l
ooooo`00R_ooool2o`00023ooooo00?o0000ooooooooool07?ooool2o`0000_ooooo0_l0000@oooo
o`;o0000O?ooool008oooooo0_l0000Kooooo`03o`000?oooooooooo00Wooooo0_l0000Nooooo`;o
0000S_ooool008oooooo0_l0000Kooooo`03o`000?oooooooooo00Wooooo0_l0002^ooooo`00[?oo
ool00ol0003oooooooooo`1=ooooo`;o0000J_ooool0097ooooo00Gok^k^oc8b<_l0003o0000onk^
kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0
COooool2o`0006[ooooo002Aooooo`05ogMgMonHV9So0000o`000?mgMgL01Oooool2ob4Q8@;o0000
1_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02Sooooo0_l0002?ooooo`00TOoo
ool01Ol@413ooooooooooooooooo410@00Oooooo0_l00007ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool03oooool2o`0001Gooooo1?l0002?ooooo`00TOooool01Ol0003ooooooooo
oooooooo000000oooooo00?oMgMgoc8b<_ooool00_l00002ooooo`?o00003oooool2o`0001Gooooo
0_l0002Aooooo`00TOooool01Ol0003ooooooooooooooooo000000cooooo00Ko0000ob4Q8Ol0003o
<S8bolc<c?ooool2o`0000;ooooo0ol00005ooooo`;o00004?ooool2o`000:3ooooo002Aooooo`05
oa0@4?ooooooooooooooool@41003?ooool3o`0000Oooooo00?o0000ooooooooool01Oooool2o`00
00Oooooo0_l00007ooooo`;o0000X?ooool0097ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`?o00001oooool00ol0003oooooooooo`0=ooooo`?o00001_ooool2o`000:7ooooo002Aooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool03Oooool2o`00
00Oooooo0_l0002Qooooo`00[?ooool00ol0003oooooooooo`0Eooooo`;o0000X_ooool00:cooooo
00?o0000ooooooooool02oooool2o`0000Sooooo0_l0002Rooooo`00SOooool2o`0001_ooooo0ol0
000=ooooo`;o0000[?ooool008gooooo0_l0000Jooooo`Ko00008Oooool3o`0009Gooooo002Xoooo
o`?o000000?oooooo`000?ooool05?ooool2o`0000cooooo0ol0000>ooooo`?o0000Q?ooool009ko
oooo0_l00008ooooo`?o000000?oooooo`000?ooool05?ooool3o`0001cooooo0ol00024ooooo`00
W_ooool2o`0000cooooo00?o0000ooooooooool04oooool3o`000:?ooooo002Sooooo`;o00001ooo
ool00ol0003oooooooooo`0Cooooo`;o0000Y?ooool009Sooooo0_l00009ooooo`;o00001oooool0
0ol0003oooooooooo`2iooooo`00V?ooool2o`0000_ooooo0_l00005ooooo`03o`000?oooooooooo
0;Wooooo002Uooooo`;o00001Oooool2o`0001oooooo0_l0000@ooooo`;o0000Qoooool00:cooooo
0ol0000Nooooo`;o00004?ooool2o`0008Oooooo002?ooooo`;o00002_ooool2o`0000kooooo0_l0
0007ooooo`;o00001oooool2o`000:Wooooo002?ooooo`;o00002_ooool2o`0000kooooo0ol00006
ooooo`;o00001oooool2o`000:Wooooo002Kooooo`;o00003oooool2o`0000Cooooo0_l0002doooo
o`00U_ooool2o`0001Cooooo00?o0000ooooooooool00oooool2o`0001Kooooo0ol0000Rooooo`;o
0000Moooool009Kooooo0_l0000Dooooo`03o`000?oooooooooo00kooooo0_l0000;ooooo`?o0000
3?ooool2o`0001Cooooo0_l0001gooooo`00[?ooool00ol0003oooooooooo`0>ooooo`;o00006_oo
ool2o`0008gooooo002/ooooo`03o`000?oooooooooo00_ooooo0_l0002/ooooo`00[?ooool3o`00
00_ooooo0_l0002/ooooo`00Xoooool2o`0000Oooooo00?o0000ooooooooool0:?ooool2o`0008oo
oooo002<ooooo`;o00000oooool2o`00013ooooo0_l00007ooooo`03o`000?oooooooooo00_ooooo
0_l0000Kooooo`;o0000Soooool008cooooo0_l00003ooooo`;o00006Oooool00ol0003ooooooooo
o`0;ooooo`;o0000[?ooool00:cooooo00?o0000ooooooooool0^Oooool009_ooooo0_l0000?oooo
o`03o`000?oooooooooo00Oooooo0_l0002`ooooo`00Voooool2o`0000oooooo00?o0000oooooooo
ool01oooool2o`000;3ooooo002Zooooo`?o0000^oooool00:[ooooo0ol0000Dooooo`Co0000Xooo
ool009?ooooo0_l0000Eooooo`Go00004_ooool4o`000:?ooooo002=ooooo`;o00001?ooool2o`00
01Oooooo00?o0000ooooooooool0^Oooool008gooooo0_l00006ooooo`;o00003?ooool2o`0000Oo
oooo00?o0000ooooooooool01Oooool2o`0000Wooooo0_l0002Wooooo`00S_ooool2o`0000Gooooo
0_l0000<ooooo`;o00001oooool00ol0003oooooooooo`03ooooo`Co00002Oooool2o`000:Oooooo
002>ooooo`?o00003_ooool2o`0000;ooooo0ol00006ooooo`03o`000?oooooooooo00?ooooo0_l0
000;ooooo`;o00004?ooool2o`0009Gooooo0029ooooo`06onk^k_lb<S;o0000oc8b<_o^k^kooooo
0_l00002ooooo`;o8B4Q1_ooool01?l0003ok^k^ooooooooool2o`000003oooooom4A4Co000000;o
000000?ogMgMooooooooool00oooool00ol0003oooooooooo`03ooooo`;o00002Oooool2o`0001;o
oooo0_l0002Eooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03
oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0>ooooo`;o
0000ZOooool008Wooooo00Go410@oooooooooooooooooa0@4009ooooo`;o00000_ooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03oooool2o`0000co
oooo0_l0000Eooooo`;o0000Poooool008Wooooo00Go0000ooooooooooooooooo`000002ooooo`;o
00001Oooool2o`0000?ooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`?o
00003oooool2o`0000cooooo0_l0000Eooooo`;o0000Poooool008Wooooo00Go0000oooooooooooo
ooooo`000002ooooo`;o00002_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`2iooooo`00ROooool01Ol@413ooooooooooooooooo410@
00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
0;Wooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo
<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0;ooooo`;o0000[?ooool0
08Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0000<
ooooo`;o0000[?ooool00:cooooo0_l0000:ooooo`;o0000[_ooool00:cooooo00?o0000oooooooo
ool02Oooool2o`000:kooooo002Wooooo`;o00000oooool00ol0003oooooooooo`2iooooo`00Yooo
ool2o`0000?ooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00U?ooool2o`00
01Kooooo00?o0000ooooooooool01Oooool2o`000;;ooooo002Dooooo`;o00005_ooool00ol0003o
ooooooooo`05ooooo`;o0000/_ooool00:cooooo00?o0000ooooooooool01Oooool2o`000;;ooooo
002/ooooo`03o`000?oooooooooo00Gooooo0_l0002booooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`0Dooooo`;o0000Xoooool00:cooooo0ol0000Dooooo`;o
0000Xoooool00:cooooo00?o0000ooooooooool04Oooool2o`000:Kooooo002/ooooo`03o`000?oo
oooooooo017ooooo0_l0002Vooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00V_ooool2o`0000?ooooo0_l0000;ooooo`03o`000?oooooooooo00gooooo0_l0
002Zooooo`00V_ooool2o`0000?ooooo0_l00008ooooo`;o000000?oooooo`000?ooool03_ooool2
o`000:[ooooo002Yooooo`;o000000Coooooo`000?l0003o0000^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool02Oooool2o`000:kooooo002/ooooo`03o`00
0?oooooooooo00Wooooo0_l0002^ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`07ooooo`;o0000/?ooool00:cooooo00?o0000ooooooooool01oooool2o`00
0;3ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o
0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool009Oooooo0_l0000Coooo
o`03o`000?oooooooooo00?o0000]_ooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo00?o
0000]_ooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo0;Wooooo002Rooooo`Co000000?o
410@ooooooooool00oooool00ol0003oooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`03o`000?oooooooooo00Gooooo0ol0002ioooo
o`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?oo
ool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00X_ooool00omE
EEGoIVIVo`000033ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00Z_ooool01?l@413o0000o`000?l0002jooooo`00Zoooool00ol0003oooooooooo`2joooo
o`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool01_l0003oMgMgo`000?l0003oEEEEonk^
k[Oooooo002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoEEEE]oooool00:_ooooo00?o0000onk^
k_ooool00_ooool00ol0003oooooooooo`2eooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03
o`000?oooooooooo0;Gooooo002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoIVIV]oooool00:[o
oooo00?o410@o`000?mgMgL00_l000000omVIVKok^k^ooooo`2fooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.64505 .52678 Mdot
.5536 .82051 Mdot
.50548 .52331 Mdot
.54093 .39744 Mdot
.5713 .37061 Mdot
.50749 .14263 Mdot
.4615 .33737 Mdot
.66392 .24306 Mdot
.43424 .06389 Mdot
.47654 .22237 Mdot
.56725 .46074 Mdot
.70176 .33285 Mdot
.40083 .23143 Mdot
.55138 .36699 Mdot
.70353 .35516 Mdot
.5084 .72144 Mdot
.61245 .49134 Mdot
.41168 .17951 Mdot
.40897 .57128 Mdot
.68842 .54481 Mdot
.41702 .16515 Mdot
.45026 .89828 Mdot
.41107 .79651 Mdot
.43558 .11028 Mdot
.73166 .50024 Mdot
.44666 .81174 Mdot
.56272 .58208 Mdot
.41861 .66242 Mdot
.68137 .59729 Mdot
.54305 .83413 Mdot
.46223 .08209 Mdot
.43592 .05813 Mdot
.61518 .17185 Mdot
.58374 .67868 Mdot
.47467 .86963 Mdot
.67102 .41194 Mdot
.51692 .92677 Mdot
.48228 .79262 Mdot
.66588 .64922 Mdot
.71581 .36709 Mdot
.73587 .50657 Mdot
.53678 .78948 Mdot
.39234 .43366 Mdot
.64356 .58322 Mdot
.644 .45499 Mdot
.58245 .60658 Mdot
.53377 .32164 Mdot
.37239 .38579 Mdot
.468 .15547 Mdot
.6808 .57637 Mdot
.37077 .43014 Mdot
.63279 .74823 Mdot
.68419 .18741 Mdot
.41073 .73409 Mdot
.39746 .64446 Mdot
.53008 .06862 Mdot
.67012 .25691 Mdot
.61355 .48729 Mdot
.40043 .82718 Mdot
.63871 .42046 Mdot
.57208 .64735 Mdot
.61964 .86117 Mdot
.66163 .65911 Mdot
.49512 .72127 Mdot
.60054 .15882 Mdot
.4864 .02479 Mdot
.45942 .23341 Mdot
.53033 .65667 Mdot
.47251 .79726 Mdot
.47379 .07203 Mdot
.61495 .56028 Mdot
.50811 .62002 Mdot
.48347 .22669 Mdot
.4174 .4104 Mdot
.66176 .65852 Mdot
.44226 .49387 Mdot
.68459 .18808 Mdot
.53337 .74449 Mdot
.65001 .70841 Mdot
.41842 .27928 Mdot
.59016 .215 Mdot
.55296 .81682 Mdot
.51816 .32271 Mdot
.52342 .81387 Mdot
.6117 .16254 Mdot
.48998 .76081 Mdot
.57751 .39445 Mdot
.58704 .47193 Mdot
.60899 .43218 Mdot
.52561 .67096 Mdot
.73094 .50882 Mdot
.40111 .0875 Mdot
.4213 .55218 Mdot
.59044 .53239 Mdot
.43702 .6732 Mdot
.37171 .24302 Mdot
.54581 .34896 Mdot
.37228 .40867 Mdot
.69992 .21105 Mdot
.61323 .44974 Mdot
.64044 .57924 Mdot
.59177 .3551 Mdot
.69722 .32672 Mdot
.63439 .62906 Mdot
.55546 .15776 Mdot
.57074 .71448 Mdot
.60781 .60264 Mdot
.41358 .36308 Mdot
.42068 .53912 Mdot
.47859 .0733 Mdot
.52155 .28604 Mdot
.53771 .37974 Mdot
.42695 .07737 Mdot
.68221 .44967 Mdot
.79655 .48975 Mdot
.52304 .59467 Mdot
.55425 .69925 Mdot
.53056 .0632 Mdot
.4897 .02397 Mdot
.53467 .90041 Mdot
.39873 .24532 Mdot
.66671 .78551 Mdot
.38436 .40616 Mdot
.67978 .61191 Mdot
.48054 .07296 Mdot
.54998 .45676 Mdot
.68474 .48538 Mdot
.35788 .54561 Mdot
.60741 .70132 Mdot
.44297 .6586 Mdot
.41059 .79801 Mdot
.62804 .64076 Mdot
.71737 .38489 Mdot
.52646 .16679 Mdot
.4162 .22781 Mdot
.66411 .67293 Mdot
.54134 .9006 Mdot
.68534 .54963 Mdot
.47547 .22497 Mdot
.64299 .21737 Mdot
.7093 .36958 Mdot
.52205 .97875 Mdot
.47265 .24925 Mdot
.43684 .74778 Mdot
.61285 .49406 Mdot
.6881 .49974 Mdot
.58213 .12349 Mdot
.79061 .61208 Mdot
.42005 .32546 Mdot
.5889 .51391 Mdot
.68947 .74627 Mdot
.5828 .32728 Mdot
.5297 .7122 Mdot
.44405 .09388 Mdot
.51698 .57171 Mdot
.57641 .25597 Mdot
.57723 .84717 Mdot
.65351 .6903 Mdot
.52642 .06062 Mdot
.51749 .92474 Mdot
.5693 .85976 Mdot
.39881 .50616 Mdot
.64985 .71191 Mdot
.7409 .49964 Mdot
.64912 .33839 Mdot
.39198 .47846 Mdot
.64131 .55343 Mdot
.57081 .11023 Mdot
.58419 .19911 Mdot
.48703 .79137 Mdot
.5758 .85323 Mdot
.68221 .51465 Mdot
.42132 .47093 Mdot
.52223 .72504 Mdot
.57495 .39085 Mdot
.44363 .22924 Mdot
.61655 .17745 Mdot
.36292 .33594 Mdot
.56795 .24075 Mdot
.52723 .55105 Mdot
.67664 .61309 Mdot
.60717 .80322 Mdot
.72722 .41453 Mdot
.4239 .64643 Mdot
.73619 .52508 Mdot
.44663 .32012 Mdot
.41755 .10625 Mdot
.35932 .58457 Mdot
.43038 .06612 Mdot
.7392 .48207 Mdot
.4028 .30284 Mdot
.69357 .72838 Mdot
.68847 .50008 Mdot
.53136 .60459 Mdot
.64141 .82442 Mdot
.63728 .20014 Mdot
.73305 .59545 Mdot
.70708 .35218 Mdot
.59019 .49525 Mdot
.58196 .69964 Mdot
.51928 .40698 Mdot
.52319 .42896 Mdot
.49633 .66234 Mdot
.56095 .34228 Mdot
.63539 .60268 Mdot
.52953 .40438 Mdot
.53754 .18643 Mdot
.53713 .3728 Mdot
.49901 .30021 Mdot
.56998 .48853 Mdot
.38179 .57188 Mdot
.542 .72604 Mdot
.58612 .20244 Mdot
.44963 .74174 Mdot
.63972 .56778 Mdot
.55854 .68194 Mdot
.74047 .50643 Mdot
.45574 .2937 Mdot
.62515 .37479 Mdot
.70604 .33572 Mdot
.55987 .68454 Mdot
.39255 .78294 Mdot
.56882 .17496 Mdot
.61373 .25856 Mdot
.48928 .75421 Mdot
.5264 .2578 Mdot
.57381 .78869 Mdot
.42063 .5009 Mdot
.70539 .36015 Mdot
.65503 .80933 Mdot
.5406 .62471 Mdot
.4841 .65938 Mdot
.5285 .00618 Mdot
.53181 .22557 Mdot
.56425 .5806 Mdot
.6805 .75607 Mdot
.50325 .76557 Mdot
.6257 .66301 Mdot
.38342 .41172 Mdot
.63292 .62114 Mdot
.61964 .85992 Mdot
.4548 .12782 Mdot
.62602 .27146 Mdot
.61515 .55783 Mdot
.4463 .03987 Mdot
.45458 .72136 Mdot
.59126 .82051 Mdot
.58594 .35223 Mdot
.61598 .54874 Mdot
.66009 .66776 Mdot
.73439 .57855 Mdot
.5251 .58114 Mdot
.53213 .59534 Mdot
.56938 .85338 Mdot
.44156 .79866 Mdot
.53061 .70398 Mdot
.39015 .47626 Mdot
.44487 .43869 Mdot
.65651 .23533 Mdot
.37224 .60111 Mdot
.50326 .17723 Mdot
.5646 .57852 Mdot
.62845 .2879 Mdot
.48373 .70792 Mdot
.57365 .30713 Mdot
.64244 .47469 Mdot
.54372 .35287 Mdot
.45376 .13452 Mdot
.67802 .45677 Mdot
.40761 .64539 Mdot
.67903 .44412 Mdot
.39131 .54954 Mdot
.47613 .22084 Mdot
.45436 .17184 Mdot
.58207 .84086 Mdot
.41681 .58373 Mdot
.48152 .18913 Mdot
.37623 .33412 Mdot
.5699 .47184 Mdot
.56603 .23452 Mdot
.66951 .64745 Mdot
.42944 .58216 Mdot
.41803 .5843 Mdot
.51895 .92213 Mdot
.68771 .30171 Mdot
.41809 .3268 Mdot
.51792 .44963 Mdot
.51018 .23313 Mdot
.67414 .3993 Mdot
.58772 .55449 Mdot
.56615 .17836 Mdot
.35976 .59201 Mdot
.41664 .88422 Mdot
.68927 .31391 Mdot
.41515 .87702 Mdot
.43679 .5165 Mdot
.43511 .93139 Mdot
.6627 .7833 Mdot
.65991 .34853 Mdot
.69812 .33914 Mdot
.77672 .67247 Mdot
.43365 .21323 Mdot
.41393 .23123 Mdot
.62375 .65975 Mdot
.44342 .04471 Mdot
.73301 .48726 Mdot
.5471 .35976 Mdot
.37404 .36812 Mdot
.42544 .75174 Mdot
.48004 .3039 Mdot
.38447 .61511 Mdot
.61316 .52335 Mdot
.38898 .32278 Mdot
.70014 .71999 Mdot
.51441 .63209 Mdot
.63327 .4094 Mdot
.56189 .73675 Mdot
.62066 .18777 Mdot
.47318 .71404 Mdot
.72841 .42395 Mdot
.70885 .67278 Mdot
.5508 .55555 Mdot
.53475 .17732 Mdot
.51563 .82781 Mdot
.6465 .70521 Mdot
.53612 .27512 Mdot
.5118 .36999 Mdot
.44172 .41321 Mdot
.61216 .57031 Mdot
.6918 .2999 Mdot
.57809 .83814 Mdot
.43944 .68403 Mdot
.40218 .76367 Mdot
.43412 .61447 Mdot
.49412 .66757 Mdot
.56784 .79897 Mdot
.49227 .12355 Mdot
.3921 .46767 Mdot
.3989 .50771 Mdot
.55104 .31583 Mdot
.65501 .14453 Mdot
.42905 .76212 Mdot
.57585 .77359 Mdot
.49427 .7213 Mdot
.57879 .12534 Mdot
.56601 .55188 Mdot
.68571 .53112 Mdot
.51624 .87028 Mdot
.43461 .32777 Mdot
.57971 .59802 Mdot
.52622 .97472 Mdot
.70008 .32575 Mdot
.43743 .93705 Mdot
.6758 .434 Mdot
.41702 .27773 Mdot
.5887 .6761 Mdot
.68266 .50096 Mdot
.55487 .26707 Mdot
.69895 .32374 Mdot
.63252 .28489 Mdot
.71494 .37791 Mdot
.73021 .43487 Mdot
.73868 .52576 Mdot
.45958 .67788 Mdot
.50608 .18371 Mdot
.7097 .37288 Mdot
.66197 .24325 Mdot
.44959 .65446 Mdot
.53461 .13357 Mdot
.43306 .77174 Mdot
.54557 .19703 Mdot
.64243 .56198 Mdot
.37963 .30442 Mdot
.62703 .65743 Mdot
.47789 .96242 Mdot
.61285 .77774 Mdot
.42292 .83846 Mdot
.4655 .96571 Mdot
.42216 .83866 Mdot
.72873 .46051 Mdot
.79854 .53794 Mdot
.50299 .93927 Mdot
.59122 .28339 Mdot
.52015 .52428 Mdot
.72394 .61613 Mdot
.60704 .41628 Mdot
.4385 .44726 Mdot
.73102 .42867 Mdot
.48077 .07255 Mdot
.50874 .35789 Mdot
.42706 .3301 Mdot
.4956 .81909 Mdot
.55802 .61481 Mdot
.37908 .29755 Mdot
.58631 .19774 Mdot
.64784 .81183 Mdot
.72931 .42459 Mdot
.60356 .60971 Mdot
.62829 .11345 Mdot
.59542 .64936 Mdot
.43703 .24645 Mdot
.47376 .19094 Mdot
.51315 .49512 Mdot
.68381 .28451 Mdot
.69898 .3261 Mdot
.56416 .57214 Mdot
.42891 .3646 Mdot
.56228 .60878 Mdot
.45645 .75762 Mdot
.7181 .66383 Mdot
.59175 .51326 Mdot
.6495 .33605 Mdot
.48788 .25689 Mdot
.52497 .72263 Mdot
.4634 .70729 Mdot
.58826 .45634 Mdot
.59311 .64731 Mdot
.55255 .64378 Mdot
.53522 .43721 Mdot
.6784 .7658 Mdot
.64055 .21274 Mdot
.45636 .40775 Mdot
.45447 .85932 Mdot
.60768 .60283 Mdot
.60077 .31207 Mdot
.41577 .69902 Mdot
.50958 .75405 Mdot
.72317 .62695 Mdot
.401 .08325 Mdot
.61692 .68669 Mdot
.7841 .40782 Mdot
.6391 .61378 Mdot
.54078 .49963 Mdot
.45835 .0344 Mdot
.71303 .38615 Mdot
.56801 .48074 Mdot
.51659 .8685 Mdot
.6631 .15606 Mdot
.43672 .32207 Mdot
.48127 .30108 Mdot
.46532 .19767 Mdot
.62671 .28225 Mdot
.40418 .38936 Mdot
.4718 .27753 Mdot
.44771 .84699 Mdot
.5423 .78142 Mdot
.45895 .73141 Mdot
.51798 .61406 Mdot
.4141 .46875 Mdot
.66437 .24458 Mdot
.49622 .69151 Mdot
.6588 .68604 Mdot
.58098 .77215 Mdot
.64057 .44139 Mdot
.68245 .46408 Mdot
.53749 .1389 Mdot
.61034 .56882 Mdot
.35728 .54269 Mdot
.43505 .29159 Mdot
.6954 .30786 Mdot
.73528 .5778 Mdot
.54368 .35432 Mdot
.43485 .93169 Mdot
.41135 .67258 Mdot
.60642 .44166 Mdot
.68615 .52572 Mdot
.64044 .58349 Mdot
.40706 .49524 Mdot
.57875 .60462 Mdot
.58501 .6772 Mdot
.6207 .86379 Mdot
.40969 .26342 Mdot
.44243 .52404 Mdot
.39239 .54834 Mdot
.42536 .24597 Mdot
.4647 .68613 Mdot
.54674 .58195 Mdot
.41625 .76164 Mdot
.41027 .25436 Mdot
.53003 .50324 Mdot
.4679 .83005 Mdot
.4912 .02747 Mdot
.56794 .35675 Mdot
.63842 .44157 Mdot
.4519 .7836 Mdot
.42171 .67728 Mdot
.43165 .51705 Mdot
.79632 .47151 Mdot
.43193 .47246 Mdot
.56089 .80965 Mdot
.39109 .77058 Mdot
.65389 .35034 Mdot
.45657 .78682 Mdot
.68277 .57556 Mdot
.71973 .38562 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
0_l0002aooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo0_l0
002aooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo002Roooo
o`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:Oooooo0ol00002ooooo`?o0000^Ooo
ool00:Oooooo1?l000000ooooooo0000ooooo`2jooooo`00ZOooool2o`000003ooooool0003ooooo
0;[ooooo002Nooooo`;o00003?ooool00ol0003oooooooooo`2iooooo`00W_ooool2o`0000cooooo
00?o0000ooooooooool0^Oooool009[ooooo0_l0000@ooooo`03o`000?oooooooooo0;Wooooo002J
ooooo`;o00004?ooool00ol0003oooooooooo`2iooooo`00VOooool2o`00017ooooo00?o0000oooo
ooooool0^Oooool009Wooooo0_l0000Aooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000
^Oooool00:cooooo00?o0000ooooooooool0^Oooool009Kooooo0_l0000Dooooo`03o`000?oooooo
oooo0;Wooooo002Fooooo`;o00005?ooool00ol0003oooooooooo`05ooooo`;o0000/_ooool009Ko
oooo0_l0000Dooooo`03o`000?oooooooooo00Gooooo1?l0002`ooooo`00UOooool3o`0001Cooooo
00?o0000ooooooooool01oooool2o`000;3ooooo002Eooooo`;o00005Oooool00ol0003ooooooooo
o`06ooooo`;o0000/Oooool00:?ooooo1?l00005ooooo`03o`000?oooooooooo00Kooooo0_l0002a
ooooo`00Toooool2o`0000kooooo1?l00005ooooo`?o0000^Oooool009?ooooo0_l0000Gooooo`03
o`000?oooooooooo0;Wooooo002;ooooo`;o00004_ooool2o`0000_ooooo00?o0000ooooooooool0
^Oooool008_ooooo0_l0000Booooo`;o00002oooool00ol0003oooooooooo`2iooooo`00Roooool2
o`0001oooooo00?o0000ooooooooool0^Oooool008_ooooo0_l0000Oooooo`03o`000?oooooooooo
0;Wooooo002Iooooo`;o00004Oooool00ol0003oooooooooo`2iooooo`00VOooool2o`00017ooooo
00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool0^Oooool0093ooooo0_l00004ooooo`;o
00005?ooool00ol0003oooooooooo`0Dooooo`;o0000Xoooool009Kooooo0_l0000Dooooo`03o`00
0?oooooooooo01Cooooo0_l0000Aooooo`;o0000T?ooool00:cooooo00?o0000ooooooooool09ooo
ool2o`00093ooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o
0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0
^Oooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVY
ooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0^Oooool0087ooooo1_l0
0002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`00
0?oooooooooo00;o000000Coooooo`000?l0003o00005oooool3o`0009oooooo0029ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7o0000o`000006ooooo`04ogMgMolb<S;ooooooooo
o`;o000000?oooooo`000?ooool06?ooool3o`0009oooooo0029ooooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGo0000o`000003ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2iooooo`00ROooool01Ol@413ooooooooooooooooo410@00kooooo0_l00004
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool2o`000:oooooo0029oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol@413oooooooooo`02o`0000Cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`08ooooo`;o0000[oooool008Wooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool02Oooool2
o`000:kooooo002/ooooo`04o`000?oooooo0000o`0000Sooooo0_l0002^ooooo`00[?ooool01?l0
003oooooo`000?l0000_ooooo`;o0000Qoooool00:cooooo00?o0000ooooooooool0<?ooool2o`00
08Oooooo002/ooooo`?o0000^Oooool00:7ooooo0_l00009ooooo`03o`000?oooooooooo03;ooooo
0_l00025ooooo`00XOooool2o`0000Wooooo00?o0000ooooooooool03oooool2o`0000gooooo0_l0
000Booooo`;o0000QOooool00:cooooo00?o0000ooooooooool03oooool2o`0000gooooo0_l0002I
ooooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool08Oooool2o`0009Kooooo002@ooooo`;o
00006_ooool00ol0003oooooooooo`05ooooo`;o00006_ooool2o`0009Kooooo002/ooooo`03o`00
0?oooooooooo00Gooooo0_l0002booooo`00W?ooool2o`0000kooooo00?o0000ooooooooool08ooo
ool2o`0009Cooooo002Looooo`;o00003_ooool3o`0000Sooooo0_l00009ooooo`;o00003_ooool2
o`0009Cooooo002>ooooo`;o00007?ooool3o`0000Sooooo0_l00008ooooo`?o00003_ooool2o`00
09Cooooo002>ooooo`;o00007?ooool00ol0003oooooooooo`0Booooo`;o00003oooool2o`0009Co
oooo002/ooooo`04o`000?oooooo0000o`0000Sooooo0_l0002^ooooo`00YOooool2o`0000Gooooo
00Co0000ooooool0003o00002?ooool2o`0001Wooooo0_l0000Cooooo`;o0000O_ooool00:?ooooo
1?l00005ooooo`03o`000?oooooooooo02Cooooo0_l0000Cooooo`;o0000O_ooool00:?ooooo0_l0
0007ooooo`03o`000?oooooooooo0;Wooooo002Pooooo`;o00002_ooool00ol0003oooooooooo`0<
ooooo`;o00002oooool2o`0009kooooo002Pooooo`;o00002_ooool3o`0000cooooo0_l0000:oooo
o`?o00003oooool2o`0008gooooo002/ooooo`03o`000?oooooooooo01Sooooo0ol0000?ooooo`;o
0000SOooool00:cooooo00?o0000ooooooooool06Oooool2o`0009kooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002Fooooo`;o00005?ooool00ol0003oooooooooo`0[ooooo`;o00004_ooool2
o`0007Sooooo002Fooooo`;o00005?ooool00ol0003oooooooooo`0Jooooo`;o00003oooool2o`00
01;ooooo0_l0001hooooo`00[?ooool00ol0003oooooooooo`0Jooooo`;o00004?ooool2o`0008_o
oooo002Tooooo`;o00001_ooool00ol0003oooooooooo`0/ooooo`;o0000Roooool00:?ooooo0ol0
0006ooooo`?o00001oooool2o`000;3ooooo002@ooooo`;o00004Oooool2o`000003ooooool0003o
000000Cooooo00?o0000ooooooooool01oooool2o`000;3ooooo002;ooooo`;o00000_ooool3o`00
00Oooooo0_l0000;ooooo`;o00001?ooool00ol0003oooooooooo`2iooooo`00Roooool2o`0000;o
oooo0_l00008ooooo`;o00000oooool2o`0000cooooo00?o0000ooooooooool00_l0000@ooooo`;o
0000YOooool009kooooo0_l0000<ooooo`03o`000?oooooooooo00;o00004?ooool2o`0001cooooo
0_l00027ooooo`00[?ooool00ol0003oooooooooo`0Cooooo`;o00006oooool2o`0008Oooooo0021
ooooo`;o00003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Cooooo`;o00007Oooool3o`0008Cooooo
0021ooooo`;o00001oooool2o`0000Gooooo00KoMgMgoiRHV?l0003o0000ogMgMoooool2o`0000;o
oooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0<_ooool3o`0008Co
oooo0029ooooo`Ko00000_ooool01_l@413oooooo`000?l0003o410@ooooo`;o00002_ooool2o`00
0003ooooool0003ooooo00Cooooo00?o0000ooooooooool0<oooool2o`0008Cooooo002Aooooo`05
o`000?ooooooooooooooool000003Oooool2o`000003ogMgMolb<S;ooooo00Cooooo0ol0002ioooo
o`00S_ooool2o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool02_ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool05_ooool2o`000:7ooooo002>ooooo`;o
000000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03o`000?oooooooooo00?o
oooo0_l00002ooooo`03o`000?oooooooooo00Gooooo0_l0000?ooooo`;o00002_ooool2o`00017o
oooo0_l00022ooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooooooo
ool00oooool2o`0000;ooooo00?o0000ooooooooool01Oooool2o`0001_ooooo0_l0000Aooooo`;o
0000P_ooool008kooooo0_l000001_ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo1?l00006oooo
o`03o`000?oooooooooo0;Wooooo002>ooooo`;o00007?ooool00ol0003oooooooooo`0?ooooo`;o
0000Z?ooool00:cooooo00?o0000ooooooooool03oooool2o`000:Sooooo002/ooooo`03o`000?oo
oooooooo02Kooooo0_l0002Aooooo`00[?ooool3o`0000Sooooo0_l0000Looooo`;o0000TOooool0
093ooooo0ol0000?ooooo`;o00002?ooool00ol0003oooooooooo`08ooooo`;o0000[oooool0093o
oooo0ol0000?ooooo`;o00002?ooool00ol0003oooooooooo`0Kooooo`;o00002Oooool2o`00097o
oooo002/ooooo`03o`000?oooooooooo00Cooooo0_l0000Eooooo`;o00002Oooool4o`0000oooooo
0_l0001nooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o00008Oooool3o`0000oooooo0_l0
001nooooo`00U_ooool2o`0001Cooooo00?o0000ooooooooool09oooool2o`00093ooooo002Foooo
o`;o00001Oooool2o`0000gooooo00?o0000ooooooooool0^Oooool008Cooooo0_l0000Gooooo`;o
00003Oooool00ol0003oooooooooo`2iooooo`00Q?ooool2o`0001oooooo0_l00004ooooo`Co0000
??ooool2o`0007_ooooo0024ooooo`;o00001Oooool2o`0001Sooooo0_l00004ooooo`;o0000?Ooo
ool3o`0007_ooooo0024ooooo`;o00001Oooool2o`0001Sooooo0_l00005ooooo`03o`000?oooooo
oooo01Gooooo0_l0000Tooooo`;o0000O?ooool00:cooooo00?o0000ooooooooool05Oooool2o`00
02Kooooo0_l0001jooooo`00[?ooool00ol0003oooooooooo`0Nooooo`;o00007Oooool2o`0007[o
oooo002/ooooo`03o`000?oooooooooo00gooooo0_l0000?ooooo`;o00006oooool2o`0007cooooo
002/ooooo`03o`000?oooooooooo00gooooo0_l0000/ooooo`;o0000O?ooool008Oooooo0_l0000>
ooooo`;o000000?oooooo`000?l000004?ooool00ol0003oooooooooo`03ooooo`;o00000oooool2
o`000:oooooo0027ooooo`;o00002?ooool2o`0000Cooooo0_l000000ooooooo0000o`00000@oooo
o`?o00000oooool2o`0000?ooooo0_l0000dooooo`?o0000N?ooool0097ooooo0_l00003ooooo`;o
00005?ooool00ol0003oooooooooo`0Hooooo`;o00009?ooool3o`0007Sooooo002Aooooo`Co0000
00?oooooo`000?l000005?ooool00ol0003oooooooooo`0Hooooo`;o00009?ooool2o`0007Wooooo
0023ooooo`;o00003_ooool2o`0001Oooooo00?o0000ooooooooool0?oooool2o`0007Sooooo001n
ooooo`;o00000oooool2o`0001[ooooo0_l0000;ooooo`03o`000?oooooooooo02kooooo0_l0000?
ooooo`Co0000M_ooool007kooooo0_l0000Oooooo`;o00002oooool00ol0003oooooooooo`0^oooo
o`;o00003_ooool2o`000003ooooool0003o000007Kooooo002/ooooo`03o`000?oooooooooo017o
oooo0_l0000Kooooo`;o00003_ooool2o`0007Wooooo002/ooooo`03o`000?oooooooooo017ooooo
0_l0002Vooooo`00[?ooool00ol0003oooooooooo`0<ooooo`;o00008oooool2o`0008Kooooo002/
ooooo`?o00002oooool3o`0000_ooooo0_l0000Dooooo`Co00003_ooool2o`0007Kooooo002/oooo
o`03o`000?oooooooooo00_ooooo0_l0000<ooooo`Co00004_ooool2o`0000oooooo0ol0001foooo
o`00[?ooool01?l0003oooooo`000?l0000:ooooo`;o00001_ooool2o`0000Kooooo0_l0000Soooo
o`;o0000Moooool00:cooooo00Co0000ooooool0003o00002oooool2o`0000Gooooo0_l0000[oooo
o`;o0000Moooool008oooooo0_l00003ooooo`;o00005_ooool00ol0003oooooooooo`0<ooooo`;o
0000<_ooool2o`0007Oooooo0022ooooo`;o00001Oooool01_o^k^ko<S8bo`000?lb<S;ok^k^oooo
o`;o00000_ooool00olQ8B7o0000o`000003ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool03_ooool2o`0003Cooooo0_l0001cooooo`00P_ooool2o`00
00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`02o`0000cooooo0_l0
0004ooooo`;o0000;?ooool4o`0007?ooooo0021ooooo`Ko00000_ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;o00001oooool2o`0000Wooooo0_l0000/ooooo`;o0000MOooool008Wooooo00Go0000
ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?oo
ool3o`0000Wooooo0_l0000Kooooo`;o00006_ooool2o`0007Gooooo0029ooooo`05o`000?oooooo
ooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`09ooooo`;o00006oooool2o`0001cooooo0_l0001cooooo`00ROoo
ool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Wooooo0_l0000iooooo`;o0000Loooool0087ooooo0_l0
0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`13ooooo`Co0000L_ooool0087ooooo
0_l00006ooooo`03onk^k_lb<S;o000000;o00002oooool01OnHV9So410@o`000?lQ8B7oc<c<00Co
oooo1?l00006ooooo`03o`000?oooooooooo04?ooooo1?l0001booooo`00S?ooool2o`0001kooooo
00?o0000ooooooooool05Oooool2o`000:;ooooo002/ooooo`03o`000?oooooooooo01Gooooo0ol0
002Qooooo`00[?ooool00ol0003oooooooooo`0:ooooo`;o00002_ooool2o`000:7ooooo002/oooo
o`?o00002_ooool2o`0002[ooooo0_l00021ooooo`00[?ooool00ol0003oooooooooo`06ooooo`;o
0000;_ooool2o`00087ooooo0025ooooo`;o00009Oooool00ol0003oooooooooo`03ooooo`;o0000
00?oooooo`000?l00000/Oooool0087ooooo0_l00002ooooo`;o00002Oooool2o`0000_ooooo0_l0
000=ooooo`03o`000?oooooooooo00?ooooo0_l0000Tooooo`;o0000;oooool2o`0005gooooo0021
ooooo`;o00000_ooool2o`0000Wooooo0_l00006ooooo`;o00000oooool2o`0000gooooo00?o0000
ooooooooool0:Oooool2o`0000[ooooo0_l0000Sooooo`;o0000GOooool008Gooooo0_l0000Aoooo
o`;o00004_ooool00ol0003oooooooooo`0Pooooo`;o00004oooool2o`00017ooooo0_l0001_oooo
o`00[?ooool00ol0003oooooooooo`0Pooooo`;o00009_ooool2o`0006oooooo002/ooooo`03o`00
0?oooooooooo02[ooooo0_l0002=ooooo`00[?ooool3o`0002[ooooo0_l0000Looooo`;o0000Kooo
ool00:cooooo00?o0000ooooooooool0B?ooool3o`0006kooooo0021ooooo`;o0000:Oooool00ol0
003oooooooooo`04ooooo`;o0000@oooool2o`0006kooooo0021ooooo`;o00001Oooool2o`0002;o
oooo00?o0000ooooooooool01?ooool2o`0001_ooooo0_l0000Dooooo`;o00004?ooool2o`0006ko
oooo0028ooooo`;o00008_ooool00ol0003oooooooooo`08ooooo`;o00005oooool2o`0001Cooooo
0_l0000@ooooo`;o0000K_ooool009Wooooo0_l0000Aooooo`03o`000?oooooooooo00Sooooo0_l0
002_ooooo`00VOooool2o`00017ooooo00?o0000ooooooooool08?ooool2o`0000Sooooo0ol0002<
ooooo`00[?ooool00ol0003oooooooooo`0Pooooo`;o00002?ooool3o`0000_ooooo0_l0001ooooo
o`00Uoooool2o`0001?ooooo00?o0000ooooooooool00_ooool2o`0001kooooo0_l0000Dooooo`?o
0000O_ooool009Oooooo0_l0000Cooooo`?o00000_ooool2o`0001kooooo0_l0000Eooooo`;o0000
O_ooool00:cooooo00?o0000ooooooooool0;?ooool2o`0008_ooooo002/ooooo`03o`000?oooooo
oooo00gooooo0_l0000;ooooo`;o00004?ooool2o`0000Wooooo0_l00020ooooo`002Oooool4o`00
0003oa0@4?oooooooooo01Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool0
0ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;o
gMgM01Kooooo00?o0000ooooooooool03Oooool2o`0000Cooooo0_l00003ooooo`05onk^k_lb<S;o
0000o`000?o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`06odA4A?l0003o0000oc8b<_oMgMgo
oooo0_l0000<ooooo`03onk^k_lb<S;o000000;o00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0
003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000
onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1?l000000ol@413ooooooooo
o`0Booooo`002oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omg
MgOo<S8booooo`0Eooooo`03o`000?oooooooooo01?ooooo0_l00003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb
<S;ooooo00;ooooo0_l0000:ooooo`03ogMgMonHV9Sooooo00;o00001Oooool2ob4Q8@Sooooo00?o
MgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEE
EOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool06Oooool00ol0003oooooooooo`0Dooooo`001_l0
0005ooooo`03o`000?oooooooooo013ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@4100
3Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`05ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@00_ooooo0_l000000olQ8B7ok^k^ooooo`08ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool06?ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RH
ob4Q8Oo^k^h02Oooool01?l0003oooooooooooooool2o`0000[ooooo00Go410@oooooooooooooooo
oa0@400@ooooo`03o`000?oooooooooo00gooooo00Go410@oooooooooooooooooa0@400=ooooo`03
ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Dooooo`00
2oooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7o
ooooooooo`06ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000;ooooo`;o000000?oV9RH
ob4Q8Oo^k^h00_ooool2o`000005ooooool0003o0000ogMgMolb<S805_ooool00ol0003ooooooooo
o`0Hooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMg
Molb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00ko
oooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b
<_ooool06Oooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05
o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00?ooooo`05o`000?ooooooooooooooool000003_ooool01?mgMgOoIVIVooooooooool5o`00
0003oc8b<_l0003o000001Gooooo00?o0000ooooooooool05?ooool2o`0000;ooooo0ol000000ooo
oooo0000ooooo`0=ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?
ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00?ooooo
0_l0000:ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`06_ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003o
ooooooooo`0Hooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03oooo
o`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooo
oooo017ooooo00Go410@oooooooooooooooooa0@400:ooooo`;o00000oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooooooo`;o00005Oooool3o`0001Cooooo0_l00002ooooo`05oa0@
4?l0003o0000ooooool@41003oooool2o`0000?ooooo00?o0000ooooooooool04Oooool01Ol@413o
oooooooooooooooo410@00cooooo00?o0000ooooooooool01Oooool2o`0000[ooooo00Go410@oooo
oooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool04Ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00[ooooo0ol000000oooooooV9RHoa0@4004ooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Co0000okZj
^_ooooooV9RH0_l00003ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Co
oooo0009ooooo`03oeEEEOmVIVKo000001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go
00001?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00004?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo0ol000000olQ8B7oc<c<ooooo`03ooooo`Co00005oooool0
0ol0003oooooooooo`0Cooooo`;o00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;o
oooo0_l00008ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004oooo
o`Co00006Oooool00omEEEGoIVIVo`00000Fooooo`00[?ooool00ol0003oooooooooo`0Cooooo`;o
00009Oooool2o`00013ooooo0_l0001[ooooo`00[?ooool00ol0003oooooooooo`0Dooooo`;o0000
3?ooool2o`0001Kooooo0_l0000=ooooo`;o0000K_ooool00:cooooo00?o0000ooooooooool05?oo
ool2o`0000cooooo0_l0000Uooooo`;o00004oooool2o`0004kooooo0_l00002ooooo`;o00001Ooo
ool008gooooo0_l0000:ooooo`;o00004Oooool01?l0003oooooooooooooool2o`0001Oooooo0_l0
0006ooooo`;o0000>_ooool2o`0004kooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd5ooooo`00
SOooool2o`0000[ooooo0_l0000Aooooo`04o`000?ooooooooooooooo`;o00005oooool2o`0000Ko
oooo0_l0002;ooooo`04omgMgOl0003o410@olc<c0Kooooo0007oooooooo0000C?l0000<ooooo`04
onk^k_lQ8B7o410@onk^kPKooooo0007ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00oooool2o`000003ooooool0003ooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Kooooo0_l00002ooooo`;o00000_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000000ol00002ooooo`03
o`000?oooooooooo00Kooooo0ol000000ooooooo0000o`000002ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02_ooool01?lQ8B7oMgMgogMgMolb<S86ooooo`001oooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`04ooooo`;o00008?ooool00ol0003oooooooooo`06ooooo`;o00007oooool00ol0003o
ooooooooo`0Pooooo`Co00000_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool02Oooool2o`0000;ooooo0_l00005ooooo`00R_ooool2o`00023ooooo
00?o0000ooooooooool0BOooool5o`0006_ooooo002:ooooo`;o00008?ooool00ol0003ooooooooo
o`0Kooooo`;o0000;?ooool2o`0006kooooo002Gooooo`;o00004oooool00ol0003oooooooooo`0J
ooooo`?o00007?ooool2o`0007kooooo002Eooooo`Co00004oooool00ol0003oooooooooo`0Joooo
o`;o00007Oooool2o`0007kooooo002Eooooo`;o00005Oooool00ol0003oooooooooo`2iooooo`00
VOooool2o`00017ooooo0ol00003ooooo`;o00007Oooool2o`0001Kooooo0_l0000?ooooo`;o0000
K?ooool009Wooooo0_l0000Aooooo`?o00000oooool2o`0001gooooo0_l00008ooooo`;o00003?oo
ool2o`0000oooooo0_l0001/ooooo`00[?ooool00ol0003oooooooooo`0/ooooo`;o00003?ooool2
o`0000oooooo0_l0001/ooooo`00[?ooool00ol0003oooooooooo`0Jooooo`;o00007_ooool2o`00
07gooooo002/ooooo`03o`000?oooooooooo01[ooooo0_l0002Mooooo`00TOooool2o`0001Wooooo
00?o0000ooooooooool0Goooool2o`0005Sooooo001looooo`;o00004oooool2o`0001Wooooo00?o
0000ooooooooool0Goooool2o`0005Sooooo001looooo`?o0000;Oooool00ol0003oooooooooo`0k
ooooo`;o0000O?ooool007gooooo0_l00009ooooo`;o00008_ooool00ol0003oooooooooo`0Soooo
o`;o00005Oooool3o`0007cooooo0028ooooo`;o00002?ooool2o`0001Sooooo0ol00006ooooo`;o
00002_ooool2o`0000oooooo0_l0000Eooooo`;o0000OOooool009;ooooo0_l0000Hooooo`03o`00
0?oooooooooo00Kooooo0_l00005ooooo`;o00000oooool2o`0000Kooooo0_l0000?ooooo`;o0000
S?ooool00:cooooo00?o0000ooooooooool03Oooool2o`0000_ooooo0_l00007ooooo`;o00001_oo
ool2o`0008cooooo002/ooooo`03o`000?oooooooooo02?ooooo0_l00007ooooo`;o0000Roooool0
0:cooooo00?o0000ooooooooool08oooool2o`0000Oooooo0_l0002;ooooo`00[?ooool00ol0003o
ooooooooo`0[ooooo`;o0000S?ooool00:cooooo00?o0000ooooooooool08Oooool3o`0000Oooooo
0_l0002<ooooo`00QOooool2o`0000Oooooo0_l0000Looooo`03o`000?oooooooooo00;ooooo0_l0
000>ooooo`;o00003Oooool3o`0009Gooooo0025ooooo`;o00001oooool2o`0001cooooo0ol00002
ooooo`;o00003_ooool2o`0002Cooooo0ol0001nooooo`00[?ooool00ol0003oooooooooo`0Boooo
o`;o00005oooool2o`0000_ooooo0ol0000?ooooo`;o0000KOooool009Cooooo0_l0000Fooooo`03
o`000?oooooooooo00Gooooo0_l00005ooooo`;o00000oooool3o`0001Oooooo0ol0000Looooo`;o
0000KOooool007gooooo0_l0000Aooooo`?o000000?oooooo`000?l000005_ooool00ol0003ooooo
ooooo`05ooooo`;o00001Oooool2o`0000?ooooo0ol0000Gooooo`?o0000Roooool007gooooo0_l0
000Aooooo`?o00006Oooool00ol0003oooooooooo`0[ooooo`;o0000S?ooool007gooooo0_l0000]
ooooo`03o`000?oooooooooo0;Wooooo001mooooo`;o0000;Oooool00ol0003oooooooooo`04oooo
o`;o000000?oooooo`000?l00000/?ooool00:cooooo00?o0000ooooooooool01?ooool2o`000003
ooooool0003o000000kooooo0_l0000Oooooo`;o00003oooool2o`0006kooooo0021ooooo`;o0000
:Oooool3o`0001Oooooo0_l0000Oooooo`;o00003oooool2o`0006kooooo0021ooooo`;o0000:Ooo
ool00ol0003oooooooooo`0Pooooo`;o00001oooool2o`0008kooooo002/ooooo`03o`000?oooooo
oooo00Oooooo0_l0000>ooooo`?o00001_ooool2o`0000Oooooo0_l0002>ooooo`00[?ooool00ol0
003oooooooooo`07ooooo`;o00002?ooool2o`0000Cooooo0ol00005ooooo`;o0000V?ooool00:co
oooo00?o0000ooooooooool04Oooool2o`0000cooooo0_l0000Fooooo`?o00008_ooool2o`0005_o
oooo0025ooooo`;o00003oooool2o`0001Cooooo00?o0000ooooooooool00_ooool2o`0000cooooo
0_l0000Hooooo`;o00002oooool3o`0000cooooo0_l0000Dooooo`;o0000Foooool008Gooooo0_l0
0002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@04ooooool0003o0000ooooo`Go
00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool00_ooool2o`00
00cooooo0_l0000Hooooo`;o00006_ooool2o`00077ooooo0029ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;o
oooo00Cooooo00Co0000ooooool0003o00009oooool2o`0008oooooo0029ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo1?l0
0009ooooo`;o00007?ooool2o`0008oooooo0029ooooo`05o`000?ooooooooooooooool000003Ooo
ool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool02_oo
ool2o`0003[ooooo0_l0001aooooo`00ROooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
:Oooool2o`0001_ooooo0_l0001aooooo`00ROooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooooooo`;o
00009_ooool2o`0008kooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o
^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool01?l0003oooooooooooooool2
o`000;Kooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo02Oooooo0_l0002@ooooo`00[?ooool0
0ol0003oooooooooo`0>ooooo`;o00005oooool2o`00093ooooo002:ooooo`;o000000?oooooo`00
0?l000000oooool2o`0001Sooooo00?o0000ooooooooool03_ooool2o`000:Wooooo002:ooooo`;o
000000?oooooo`000?l000000oooool2o`0001Sooooo00?o0000ooooooooool05?ooool2o`0000Go
oooo0ol0000Eooooo`Co0000P_ooool00:cooooo0ol0000Dooooo`;o00001Oooool3o`0001Gooooo
1?l00022ooooo`00Voooool2o`0000oooooo00?o0000ooooooooool0^Oooool009Wooooo1?l0000?
ooooo`03o`000?oooooooooo00Oooooo0_l0000Mooooo`;o00002_ooool2o`0008Gooooo002Ioooo
o`;o00002oooool2o`0000Cooooo00?o0000ooooooooool01oooool2o`0001cooooo0ol0000:oooo
o`;o0000QOooool0097ooooo0_l0000Cooooo`;o00000_ooool3o`0002Oooooo0ol0000:ooooo`;o
00004Oooool2o`0007;ooooo002Aooooo`;o00005oooool3o`0002Sooooo0_l00009ooooo`;o0000
4_ooool2o`0007;ooooo002Zooooo`?o00001oooool2o`0002[ooooo0_l00026ooooo`00S_ooool2
o`0000Oooooo0_l0000Cooooo`03o`000?oooooooooo00Gooooo0_l0000/ooooo`;o00003Oooool2
o`0001Cooooo0_l0001Oooooo`00S_ooool2o`0000Oooooo0_l0000Cooooo`?o00006Oooool3o`00
01Oooooo0_l0000=ooooo`;o00005?ooool2o`0005oooooo002Booooo`;o00002_ooool2o`0000co
oooo00?o0000ooooooooool06?ooool4o`0009gooooo002Booooo`;o00002_ooool2o`0000cooooo
00?o0000ooooooooool04?ooool2o`0000Kooooo0_l0002Oooooo`00V?ooool2o`0000Kooooo0_l0
000:ooooo`03o`000?oooooooooo013ooooo0_l0000Oooooo`;o0000Q_ooool009Sooooo0_l00006
ooooo`;o00002_ooool00ol0003oooooooooo`0@ooooo`;o00004Oooool2o`0000cooooo0_l00026
ooooo`00Z_ooool3o`0002Gooooo0_l0000:ooooo`;o0000R?ooool00:[ooooo0ol0000aooooo`;o
0000R?ooool00:cooooo00?o0000ooooooooool0^Oooool0093ooooo0_l0000Jooooo`?o00003_oo
ool2o`0000Sooooo0_l00006ooooo`;o0000Uoooool0093ooooo0_l0000Jooooo`03o`000?oooooo
oooo00Oooooo0_l00005ooooo`;o00002?ooool2o`0000Kooooo0_l0002Gooooo`00Woooool2o`00
00_ooooo00?o0000ooooooooool01oooool2o`0002Cooooo0_l0002:ooooo`00Woooool2o`0000Go
oooo0_l00004ooooo`03o`000?oooooooooo02gooooo0ol00029ooooo`00Y_ooool2o`0000Cooooo
00?o0000ooooooooool01_ooool2o`0002Kooooo0_l00029ooooo`00Xoooool2o`0000Oooooo00?o
0000ooooooooool01_ooool2o`0000cooooo0_l0000Hooooo`;o0000ROooool00:?ooooo0_l00007
ooooo`03o`000?oooooooooo01Cooooo0_l0002Sooooo`00WOooool2o`0000_ooooo0ol000000ooo
oooo0000o`000004ooooo`;o0000>?ooool2o`0007Sooooo002Mooooo`;o00002oooool6o`0000?o
oooo0ol0000hooooo`;o0000N?ooool00:cooooo00?o0000ooooooooool01?ooool2o`0000Cooooo
0_l0000`ooooo`;o0000Noooool009kooooo0_l0000<ooooo`03o`000?oooooooooo00[ooooo0_l0
000`ooooo`;o0000Noooool008kooooo0_l0000>ooooo`;o00003?ooool00ol0003oooooooooo`2i
ooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool04Oooool2o`000:Kooooo002/ooooo`03
o`000?oooooooooo017ooooo0_l0002Vooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_l00005ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2ioooo
o`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l00008ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool02?ooool2o`00037ooooo0_l0001looooo`00TOooool01_l@413o
oooooooooooooooo410@ooooo`;o00003Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Sooooo0_l0000Nooooo`;o00004Oooool2o`0007cooooo002Aooooo`03o`000?oooooo0000
00;o000000?oooooo`000?l000003?ooool00omgMgOo<S8booooo`04ooooo`?o0000:?ooool2o`00
08oooooo002Aooooo`03o`000?oooooo000000;o00003?ooool01_l0003o8B4Qo`000?lb<S;oc<c<
ooooo`;o00000_ooool00ol0003oooooooooo`02o`000;Oooooo002Aooooo`05oa0@4?oooooooooo
ooooool@41001oooool2o`0000?ooooo00?o0000ooooooooool00oooool2o`0000;ooooo00?o0000
ooooooooool00_l0000fooooo`;o0000Ooooool0093ooooo0_l000001?nHV9SooooooiRHV?mgMgL7
ooooo`;o00000oooool00ol0003oooooooooo`03ooooo`;o00000_ooool00ol0003oooooooooo`0h
ooooo`;o0000Ooooool008_ooooo0_l00003ooooo`;o000000Co<S8bo`000?l0003o00003?ooool4
o`0000;ooooo0_l00002ooooo`03o`000?oooooooooo0;Wooooo002;ooooo`;o00001oooool2o`00
01Kooooo0ol0000gooooo`;o0000P?ooool008Sooooo0_l0000Rooooo`?o0000=oooool2o`00083o
oooo0028ooooo`;o00002oooool2o`0001Gooooo00?o0000ooooooooool05_ooool3o`000:3ooooo
002Eooooo`;o00005Oooool3o`0001Kooooo0ol0002Pooooo`00[?ooool00ol0003oooooooooo`0R
ooooo`;o0000UOooool008Sooooo0_l0000Rooooo`03o`000?oooooooooo00_ooooo0_l0000Eoooo
o`;o0000UOooool008Sooooo0_l0000Booooo`;o00003_ooool00ol0003oooooooooo`0;ooooo`;o
00009Oooool4o`0008?ooooo002Looooo`?o00003Oooool00ol0003oooooooooo`0Eooooo`;o0000
6oooool4o`0008?ooooo002Mooooo`;o00002?ooool2o`0000?ooooo00?o0000ooooooooool02Ooo
ool2o`0000[ooooo0_l0002Rooooo`00Y_ooool3o`0000?ooooo00?o0000ooooooooool02Oooool2
o`000:kooooo002>ooooo`;o00004_ooool2o`0000;ooooo0_l00004ooooo`03o`000?oooooooooo
0;Wooooo002>ooooo`;o00002?ooool2o`0000Sooooo0_l00008ooooo`?o00004oooool2o`000:Co
oooo002Hooooo`;o00004_ooool00ol0003oooooooooo`0Cooooo`;o00002oooool2o`0009Oooooo
002/ooooo`03o`000?oooooooooo023ooooo0_l0002Gooooo`00[?ooool00ol0003oooooooooo`0A
ooooo`;o00007Oooool2o`0008Oooooo002Jooooo`;o00004?ooool00ol0003oooooooooo`0Aoooo
o`;o00006_ooool2o`000003ooooool0003o000008Oooooo002Jooooo`;o00004?ooool00ol0003o
ooooooooo`04ooooo`;o00009oooool2o`0008[ooooo002Zooooo`?o00001_ooool2o`0000Sooooo
0_l0002Yooooo`00Z_ooool3o`00013ooooo0_l0000;ooooo`;o0000W?ooool00:cooooo0ol0000>
ooooo`;o00002oooool2o`0000kooooo0_l0002<ooooo`00Roooool2o`0001oooooo00?o0000oooo
ooooool00_ooool2o`0002Oooooo0_l0002<ooooo`00Roooool2o`0001Cooooo0_l00009ooooo`03
o`000?oooooooooo00;ooooo0_l0002eooooo`00XOooool2o`0000Wooooo00?o0000ooooooooool0
2oooool2o`000:cooooo002/ooooo`03o`000?oooooooooo00_ooooo0_l0002/ooooo`00T_ooool2
o`0001Sooooo00?o0000ooooooooool05_ooool2o`000:7ooooo002Booooo`;o00006?ooool00ol0
003oooooooooo`0Fooooo`Co0000Woooool00:cooooo00?o0000ooooooooool06?ooool2o`0009oo
oooo002Jooooo`;o00004?ooool00ol0003oooooooooo`0Fooooo`;o0000XOooool009[ooooo0_l0
000@ooooo`?o00005_ooool2o`000:7ooooo002/ooooo`03o`000?oooooooooo01?ooooo0_l00000
0ooooooo0000o`00002Qooooo`00[?ooool00ol0003oooooooooo`0Cooooo`;o000000?oooooo`00
0?l00000XOooool009gooooo0_l0000=ooooo`03o`000?oooooooooo01?ooooo0_l0000?ooooo`;o
0000Toooool009gooooo0_l0000=ooooo`03o`000?oooooooooo01?ooooo0_l0000?ooooo`;o0000
Toooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^
ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Tooooo`;o
0000Toooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGo
ZJVYooooo`05ooooo`;o000000?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`02ooooo`;o
0000]Oooool008Wooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Go
oooo0_l000000ooooooo0000ooooo`04ooooo`03o`000?oooooooooo00;ooooo0_l0002eooooo`00
ROooool01Ol0003ooooooooooooooooo000000;ooooo0_l0000:ooooo`03ob4Q8Ooooooooooo00Ko
oooo00?oMgMgoc8b<_ooool01?ooool3o`000;Wooooo0029ooooo`05o`000?ooooooooooooooool0
00000_ooool2o`0000[ooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool0^Oooool008Wooooo00Go410@oooooooooooooooooa0@400>oooo
o`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2ioooo
o`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo0_l00007ooooo`05oa0@4?oooooooooo
oooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Wooooo0029oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool2o`0000Oooooo1Ol00004ooooo`Co00001_ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00Voooool2o`0000oooooo00?o0000ooooooooool0^Oooool009_ooooo0_l0
000?ooooo`?o00002?ooool4o`000:gooooo002/ooooo`03o`000?oooooooooo00Sooooo1?l0002]
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`03ooooo`;o0000]?ooool00:co
oooo0ol00002ooooo`?o0000]?ooool00:cooooo00?o0000ooooooooool00_ooool2o`000;Gooooo
002Fooooo`;o00005?ooool00ol0003oooooooooo`02ooooo`;o0000]Oooool009Kooooo0_l0000D
ooooo`03o`000?oooooooooo0;Wooooo002Fooooo`?o00004oooool00ol0003oooooooooo`2ioooo
o`00Uoooool2o`0001?ooooo0ol0002iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:co
oooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o
0000ooooooooool0^Oooool00:Cooooo0_l00006ooooo`03o`000?oooooooooo0;Wooooo002Poooo
o`;o00000_ooool2o`0000Kooooo00?o0000ooooooooool0^Oooool00:3ooooo0_l0000:ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o00001Ooo
ool2o`000;;ooooo002/ooooo`03o`000?oooooooooo00Cooooo0ol0002booooo`00[?ooool00ol0
003oooooooooo`04ooooo`;o0000/oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:;ooooo1?l00000
0ol@413oooooooooo`03ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000ooooooooool01Oooool3o`000;Wo
oooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002T
ooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Rooooo`03
oeEEEOmVIVKo00000<?ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo002Zooooo`04oa0@4?l0003o0000o`000;[ooooo002[ooooo`03o`000?oooooooooo0;[o
oooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`06o`000?mgMgOo0000o`000?mEEEGo
k^k^]oooool00:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomEEEFgooooo`00Zoooool00ol0003o
k^k^ooooo`02ooooo`03o`000?oooooooooo0;Gooooo002[ooooo`03o`000?o^k^kooooo00;ooooo
00?o0000ooooooooool0]Oooool00:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomVIVJgooooo`00
Z_ooool00ol@413o0000ogMgM`02o`000003ofIVI_o^k^kooooo0;Kooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.61576 .32678 Mdot
.6418 .62051 Mdot
.47736 .36432 Mdot
.46269 .25319 Mdot
.47982 .18365 Mdot
.3903 .43518 Mdot
.44242 .59413 Mdot
.52114 .04306 Mdot
.38861 .77231 Mdot
.41406 .55334 Mdot
.51155 .26074 Mdot
.5949 .13285 Mdot
.43241 .88195 Mdot
.46071 .22163 Mdot
.6056 .15516 Mdot
.55697 .52144 Mdot
.56899 .29134 Mdot
.41873 .84582 Mdot
.50485 .77372 Mdot
.66635 .34481 Mdot
.41444 .82558 Mdot
.59135 .75888 Mdot
.55923 .81295 Mdot
.39845 .75641 Mdot
.69176 .30024 Mdot
.56137 .69844 Mdot
.55555 .38208 Mdot
.52333 .7327 Mdot
.68029 .39729 Mdot
.63671 .63413 Mdot
.38653 .64618 Mdot
.38699 .76622 Mdot
.44618 .03229 Mdot
.61521 .47868 Mdot
.58911 .68711 Mdot
.59579 .21194 Mdot
.64763 .72677 Mdot
.56347 .60353 Mdot
.68556 .44922 Mdot
.62264 .16709 Mdot
.6985 .30657 Mdot
.61257 .58948 Mdot
.4784 .87524 Mdot
.63685 .38322 Mdot
.58599 .25499 Mdot
.58508 .40658 Mdot
.43562 .28307 Mdot
.47226 .97272 Mdot
.4013 .60512 Mdot
.67135 .37637 Mdot
.4823 .97019 Mdot
.69208 .54823 Mdot
.54261 .78688 Mdot
.5237 .8239 Mdot
.37344 .35043 Mdot
.53289 .05691 Mdot
.56847 .28729 Mdot
.56923 .8695 Mdot
.56689 .22046 Mdot
.59102 .44735 Mdot
.72411 .66117 Mdot
.68528 .45911 Mdot
.54406 .52237 Mdot
.42949 .06639 Mdot
.36879 .55301 Mdot
.42017 .6257 Mdot
.553 .45667 Mdot
.56088 .62292 Mdot
.38183 .59787 Mdot
.59907 .36028 Mdot
.51612 .42002 Mdot
.4135 .52213 Mdot
.4679 .7709 Mdot
.68517 .45852 Mdot
.48074 .64425 Mdot
.59116 .54449 Mdot
.69338 .50841 Mdot
.43906 .79481 Mdot
.4402 .10042 Mdot
.63969 .61682 Mdot
.43075 .34856 Mdot
.60897 .61387 Mdot
.43987 .03805 Mdot
.55582 .56473 Mdot
.4953 .19519 Mdot
.53582 .27193 Mdot
.54186 .23218 Mdot
.55399 .47096 Mdot
.69447 .30882 Mdot
.40093 .91186 Mdot
.49801 .72317 Mdot
.56339 .33239 Mdot
.52215 .65554 Mdot
.45059 .23693 Mdot
.47728 .96825 Mdot
.54434 .01105 Mdot
.55313 .24974 Mdot
.63213 .37924 Mdot
.49381 .15622 Mdot
.58791 .12672 Mdot
.64602 .42906 Mdot
.40139 .22299 Mdot
.61653 .51448 Mdot
.60887 .40264 Mdot
.4584 .79779 Mdot
.49529 .72873 Mdot
.38107 .57663 Mdot
.42271 .34143 Mdot
.45463 .26258 Mdot
.39313 .80123 Mdot
.62207 .24967 Mdot
.75245 .28975 Mdot
.5209 .39467 Mdot
.59395 .49925 Mdot
.37224 .3495 Mdot
.3679 .53881 Mdot
.65483 .70041 Mdot
.4359 .8881 Mdot
.74092 .58551 Mdot
.47412 .91604 Mdot
.68454 .41191 Mdot
.38057 .56819 Mdot
.49271 .25901 Mdot
.63889 .28538 Mdot
.64794 .50132 Mdot
.51734 .62581 Mdot
.55971 .81553 Mdot
.64435 .44076 Mdot
.63132 .18489 Mdot
.39561 .34528 Mdot
.4283 .81562 Mdot
.69328 .47293 Mdot
.66158 .7006 Mdot
.66519 .34963 Mdot
.41486 .55745 Mdot
.48996 .01948 Mdot
.61714 .16958 Mdot
.67354 .77875 Mdot
.42077 .56453 Mdot
.54218 .68932 Mdot
.57048 .29406 Mdot
.64799 .29974 Mdot
.40561 .12573 Mdot
.79544 .41208 Mdot
.44878 .77766 Mdot
.55447 .31391 Mdot
.74798 .54627 Mdot
.47418 .14629 Mdot
.57458 .5122 Mdot
.39304 .723 Mdot
.50566 .37171 Mdot
.44311 .14206 Mdot
.6761 .64717 Mdot
.68963 .4903 Mdot
.37139 .36853 Mdot
.64739 .72474 Mdot
.67321 .65976 Mdot
.49283 .83131 Mdot
.69462 .51191 Mdot
.70075 .29964 Mdot
.54447 .13839 Mdot
.48826 .86714 Mdot
.62268 .35343 Mdot
.39561 .16956 Mdot
.43032 .11622 Mdot
.56584 .59724 Mdot
.67709 .65323 Mdot
.64807 .31465 Mdot
.48027 .74067 Mdot
.57224 .52504 Mdot
.49131 .19335 Mdot
.42268 .69556 Mdot
.44941 .03097 Mdot
.432 .16731 Mdot
.50765 .35105 Mdot
.68187 .41309 Mdot
.68846 .60322 Mdot
.65303 .21453 Mdot
.51844 .70669 Mdot
.70622 .32508 Mdot
.44187 .6628 Mdot
.40147 .83604 Mdot
.51857 .99369 Mdot
.38993 .7887 Mdot
.69203 .28207 Mdot
.44758 .85791 Mdot
.74493 .52838 Mdot
.64851 .30008 Mdot
.5332 .40459 Mdot
.73118 .62442 Mdot
.4775 .01054 Mdot
.73123 .39545 Mdot
.60795 .15218 Mdot
.54829 .29525 Mdot
.35659 .57386 Mdot
.62182 .49964 Mdot
.45202 .32714 Mdot
.4602 .30933 Mdot
.5216 .46319 Mdot
.46007 .19362 Mdot
.35763 .39206 Mdot
.63646 .40268 Mdot
.45679 .28895 Mdot
.40242 .29258 Mdot
.45211 .26477 Mdot
.42619 .43841 Mdot
.5254 .28853 Mdot
.51088 .89439 Mdot
.59241 .52604 Mdot
.43285 .1106 Mdot
.53925 .63988 Mdot
.62683 .36778 Mdot
.59131 .48194 Mdot
.70304 .30643 Mdot
.43413 .62872 Mdot
.53507 .17479 Mdot
.60032 .13572 Mdot
.59369 .48454 Mdot
.55856 .88072 Mdot
.41282 .16888 Mdot
.47737 .07056 Mdot
.55274 .55882 Mdot
.41698 .32612 Mdot
.64928 .58869 Mdot
.48696 .73719 Mdot
.60945 .16015 Mdot
.73876 .60933 Mdot
.55048 .42471 Mdot
.51399 .47626 Mdot
.35919 .37107 Mdot
.41048 .30934 Mdot
.55649 .3806 Mdot
.74293 .55607 Mdot
.56948 .56557 Mdot
.6509 .46301 Mdot
.47554 .91897 Mdot
.64137 .42114 Mdot
.72361 .65992 Mdot
.39812 .66873 Mdot
.4946 .07214 Mdot
.59828 .35783 Mdot
.38076 .72484 Mdot
.53278 .60983 Mdot
.67946 .62051 Mdot
.4869 .1573 Mdot
.59548 .34874 Mdot
.68719 .46776 Mdot
.72581 .37855 Mdot
.51755 .38114 Mdot
.53027 .39534 Mdot
.67073 .65338 Mdot
.55712 .70481 Mdot
.57221 .50398 Mdot
.48817 .8756 Mdot
.46813 .64481 Mdot
.51065 .03533 Mdot
.51943 .93529 Mdot
.39849 .44636 Mdot
.55601 .37852 Mdot
.50361 .0879 Mdot
.53181 .5211 Mdot
.45847 .15665 Mdot
.59232 .27469 Mdot
.45037 .24363 Mdot
.39981 .6718 Mdot
.62073 .25677 Mdot
.52172 .77885 Mdot
.61668 .24412 Mdot
.50392 .85513 Mdot
.41381 .55547 Mdot
.40783 .66112 Mdot
.67842 .64086 Mdot
.50588 .7374 Mdot
.40572 .53878 Mdot
.46015 .96712 Mdot
.51864 .27184 Mdot
.42879 .17395 Mdot
.68849 .44745 Mdot
.50279 .68157 Mdot
.50574 .7319 Mdot
.6478 .72213 Mdot
.5684 .10171 Mdot
.4495 .78593 Mdot
.46314 .32639 Mdot
.40997 .40353 Mdot
.59386 .1993 Mdot
.56952 .35449 Mdot
.41229 .17837 Mdot
.52013 .99137 Mdot
.58441 .84471 Mdot
.57484 .11391 Mdot
.58228 .84498 Mdot
.48687 .66327 Mdot
.60037 .82411 Mdot
.73602 .5833 Mdot
.55932 .14853 Mdot
.59378 .13914 Mdot
.80571 .47247 Mdot
.42134 .74257 Mdot
.42954 .82477 Mdot
.64765 .45975 Mdot
.38244 .7364 Mdot
.68791 .28726 Mdot
.45497 .23309 Mdot
.46805 .96936 Mdot
.54481 .73492 Mdot
.4311 .52041 Mdot
.51989 .8805 Mdot
.5825 .32335 Mdot
.45492 .91392 Mdot
.74814 .51999 Mdot
.52725 .43209 Mdot
.55703 .2094 Mdot
.61659 .53675 Mdot
.45693 .02658 Mdot
.53104 .54836 Mdot
.65799 .22395 Mdot
.73796 .47278 Mdot
.64206 .83882 Mdot
.53302 .35555 Mdot
.39952 .30653 Mdot
.60675 .62781 Mdot
.68859 .50521 Mdot
.42429 .28146 Mdot
.44081 .36649 Mdot
.46325 .66407 Mdot
.60029 .37031 Mdot
.57176 .0999 Mdot
.67335 .63814 Mdot
.52443 .64909 Mdot
.55182 .83355 Mdot
.50892 .65844 Mdot
.52197 .4697 Mdot
.64743 .59897 Mdot
.38908 .50603 Mdot
.48588 .86895 Mdot
.49315 .8306 Mdot
.44383 .22066 Mdot
.5472 .72635 Mdot
.64528 .57359 Mdot
.54338 .52281 Mdot
.40417 .1376 Mdot
.54677 .35188 Mdot
.65815 .33112 Mdot
.62436 .67028 Mdot
.44614 .71361 Mdot
.57892 .39802 Mdot
.6761 .77472 Mdot
.59038 .12575 Mdot
.60262 .82268 Mdot
.6094 .234 Mdot
.43902 .80126 Mdot
.61914 .4761 Mdot
.64304 .30096 Mdot
.43154 .21043 Mdot
.58845 .12374 Mdot
.62954 .86142 Mdot
.50648 .08489 Mdot
.6261 .17791 Mdot
.66416 .23487 Mdot
.70898 .32576 Mdot
.51955 .56594 Mdot
.39948 .43249 Mdot
.61885 .17288 Mdot
.51927 .04325 Mdot
.515 .59632 Mdot
.38907 .31638 Mdot
.5495 .71685 Mdot
.40769 .2566 Mdot
.62722 .36198 Mdot
.45293 .9587 Mdot
.65 .45743 Mdot
.62694 .77305 Mdot
.68394 .57774 Mdot
.57013 .79355 Mdot
.62136 .79125 Mdot
.57024 .7963 Mdot
.67293 .26051 Mdot
.77372 .33794 Mdot
.63869 .73927 Mdot
.46549 .11422 Mdot
.48999 .33046 Mdot
.73039 .41613 Mdot
.53355 .21628 Mdot
.47138 .67078 Mdot
.66249 .22867 Mdot
.38043 .56728 Mdot
.43779 .38275 Mdot
.44828 .74607 Mdot
.58348 .6197 Mdot
.56394 .41481 Mdot
.45155 .96262 Mdot
.43145 .10982 Mdot
.73258 .61183 Mdot
.65915 .22459 Mdot
.60744 .40971 Mdot
.61516 .44936 Mdot
.42786 .72065 Mdot
.4078 .57227 Mdot
.47379 .33987 Mdot
.55762 .08451 Mdot
.58942 .1261 Mdot
.55302 .37214 Mdot
.45541 .73055 Mdot
.56579 .40878 Mdot
.54413 .62891 Mdot
.74363 .46383 Mdot
.55705 .31326 Mdot
.54392 .13605 Mdot
.41914 .49637 Mdot
.57402 .52263 Mdot
.52811 .57108 Mdot
.53079 .25634 Mdot
.61204 .44731 Mdot
.57006 .44378 Mdot
.47164 .27319 Mdot
.74472 .5658 Mdot
.48569 .01701 Mdot
.45889 .60133 Mdot
.57846 .71583 Mdot
.60881 .40283 Mdot
.48566 .11749 Mdot
.53278 .75396 Mdot
.5712 .55405 Mdot
.73395 .42695 Mdot
.40003 .91325 Mdot
.65159 .48669 Mdot
.70723 .20782 Mdot
.64461 .41378 Mdot
.50064 .29963 Mdot
.37695 .67341 Mdot
.6275 .18615 Mdot
.5203 .28074 Mdot
.62399 .6685 Mdot
.44444 .70561 Mdot
.43022 .51564 Mdot
.41109 .60769 Mdot
.49961 .08225 Mdot
.46617 .83316 Mdot
.36917 .74283 Mdot
.42712 .5621 Mdot
.57317 .72276 Mdot
.61487 .58142 Mdot
.53576 .6022 Mdot
.5236 .41406 Mdot
.48135 .77267 Mdot
.5222 .04458 Mdot
.53312 .49228 Mdot
.69322 .48604 Mdot
.64984 .57215 Mdot
.57712 .24139 Mdot
.62808 .26408 Mdot
.39091 .30262 Mdot
.59786 .36882 Mdot
.43814 .7195 Mdot
.57854 .10786 Mdot
.7264 .3778 Mdot
.45079 .24373 Mdot
.60044 .82505 Mdot
.52727 .76653 Mdot
.54309 .24166 Mdot
.65644 .32572 Mdot
.63383 .38349 Mdot
.48866 .79769 Mdot
.5806 .40462 Mdot
.6159 .4772 Mdot
.72622 .66379 Mdot
.43748 .83635 Mdot
.4873 .63702 Mdot
.50343 .85056 Mdot
.43028 .77169 Mdot
.52151 .55251 Mdot
.53952 .38195 Mdot
.54891 .77582 Mdot
.43538 .83575 Mdot
.49139 .3072 Mdot
.57141 .66133 Mdot
.36834 .53148 Mdot
.47142 .18267 Mdot
.57505 .24157 Mdot
.55241 .66183 Mdot
.52625 .72245 Mdot
.4881 .68559 Mdot
.74492 .27151 Mdot
.47831 .69403 Mdot
.64475 .60965 Mdot
.55562 .88197 Mdot
.55403 .15034 Mdot
.55378 .65091 Mdot
.673 .37556 Mdot
.63398 .18562 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`;o00001_ooool00ol0003oooooooooo`2iooooo`00Y?ooool2o`0000Kooooo00?o0000
ooooooooool02oooool2o`000:cooooo002Rooooo`03oeEEEOmVIVKo000000Oooooo00?o0000oooo
ooooool02oooool2o`000:cooooo002Wooooo`?o00000_ooool00ol0003oooooooooo`2iooooo`00
Yoooool3o`0000;ooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00WOooool2
o`0000gooooo00?o0000ooooooooool0^Oooool009_ooooo1?l0000=ooooo`03o`000?oooooooooo
0;Wooooo002Jooooo`?o00003oooool00ol0003oooooooooo`2iooooo`00V?ooool4o`00013ooooo
00?o0000ooooooooool00_l0002gooooo`00V?ooool2o`0001;ooooo00?o0000ooooooooool00_l0
002gooooo`00[?ooool00ol0003oooooooooo`03ooooo`?o0000/oooool00:cooooo00?o0000oooo
ooooool00oooool3o`000;?ooooo002/ooooo`03o`000?oooooooooo00Cooooo0_l0002cooooo`00
[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooo
oooo00Oooooo0_l0002`ooooo`00[?ooool00ol0003oooooooooo`07ooooo`;o0000/?ooool00:co
oooo00?o0000ooooooooool0^Oooool009Cooooo0_l0000Fooooo`03o`000?oooooooooo0;Wooooo
002Dooooo`;o00003_ooool2o`0000Kooooo00?o0000ooooooooool0^Oooool00:Cooooo0_l00004
ooooo`?o0000^oooool00:[ooooo1Ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
Zoooool2o`000;_ooooo002[ooooo`;o000000?oooooo`000?l000003oooool2o`000:Oooooo002/
ooooo`Co00003oooool2o`000:Oooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool009Sooooo0_l0000Booooo`?o00005?oo
ool2o`000:?ooooo002Hooooo`;o00004_ooool00ol0003oooooooooo`0Cooooo`?o0000Xoooool0
0:cooooo00?o0000ooooooooool04oooool2o`000:Cooooo002Eooooo`;o00005Oooool00ol0003o
ooooooooo`0Fooooo`;o0000XOooool009Gooooo0_l0000Eooooo`03o`000?oooooooooo01Kooooo
0_l0002Qooooo`00UOooool2o`0000Wooooo0_l0000:ooooo`03o`000?oooooooooo01Gooooo0_l0
002Rooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B42o`0000Cooooo00?o
0000onk^k_ooool00_ooool2o`000005odA4A?l0003o0000oc8b<_oMgMd00_l00003ooooo`03o`00
0?oooooooooo01Gooooo0_l0002Rooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00CoMgMgoc8b<_l0003o00000oooool00ol0003o
ooooooooo`2iooooo`00POooool6o`0000;ooooo00?o410@ooooooooool00_l0000=ooooo`03ojVY
ZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`0001[ooooo0_l0002Mooooo`00ROoo
ool00ol0003oooooooooo`02o`0000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo01[ooooo0_l0002Mooooo`00ROooool01Ol0003ooooooooooooo
oooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool06_ooool2o`0009gooooo0029ooooo`05oa0@4?ooooooooooooooool@4100
3_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
7?ooool2o`0009_ooooo0029ooooo`03ogMgMonHV9Sooooo00;o00002oooool01Ol@413ooooooooo
oooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0;ooooo`;o0000
3oooool4o`0009Wooooo0029ooooo`03onk^k_lb<S;o000000;o00002oooool5o`0000Cooooo1?l0
0006ooooo`03o`000?oooooooooo00_ooooo0_l0000?ooooo`Co0000VOooool009Wooooo0_l0000A
ooooo`03o`000?oooooooooo00_ooooo0_l0000?ooooo`;o0000Voooool009Wooooo0_l00008oooo
o`;o00001oooool00ol0003oooooooooo`2iooooo`00Xoooool2o`0000Oooooo00?o0000oooooooo
ool04?ooool2o`000:Oooooo002/ooooo`?o00003_ooool4o`0000kooooo0_l0002Gooooo`00[?oo
ool00ol0003oooooooooo`0>ooooo`;o00003oooool3o`0009Oooooo002Nooooo`;o00001oooool2
o`000004ooooool0003o0000o`00027ooooo0_l0002Hooooo`00W_ooool2o`0000Oooooo0_l00000
1?oooooo0000o`000?l0000Sooooo`;o0000U_ooool00:cooooo00?o0000ooooooooool08Oooool2
o`0009Kooooo002Eooooo`;o00005Oooool00ol0003oooooooooo`0Uooooo`;o0000T_ooool008Wo
oooo0_l00004ooooo`;o00001?ooool2o`0001Gooooo00?o0000ooooooooool08oooool4o`0009;o
oooo0029ooooo`;o00001?ooool2o`0000?ooooo0_l0000Fooooo`03o`000?oooooooooo02?ooooo
0ol0002Cooooo`00U?ooool2o`0001Kooooo0ol00008ooooo`;o00006_ooool2o`0009?ooooo002?
ooooo`;o00006oooool00ol0003oooooooooo`08ooooo`;o00007?ooool2o`00097ooooo002?oooo
o`;o00004Oooool2o`0000Sooooo00?o0000ooooooooool09_ooool2o`00097ooooo002Rooooo`;o
000000?oooooo`000?l000001Oooool00ol0003oooooooooo`0Wooooo`Co0000S_ooool00:Gooooo
0_l00005ooooo`03o`000?oooooooooo02Oooooo1?l0002>ooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00W_ooool2o`0000Wooooo1?l0002kooooo`00W_ooool2o`0000Wooooo1?l0002koooo
o`00[?ooool3o`0001cooooo0_l0002Kooooo`00[?ooool00ol0003oooooooooo`0Looooo`;o0000
Voooool00:cooooo00?o0000ooooooooool0^Oooool009Gooooo0_l0000Eooooo`03o`000?oooooo
oooo00oooooo0_l0000`ooooo`;o0000M_ooool009Gooooo0_l0000Eooooo`03o`000?oooooooooo
00oooooo0_l0000;ooooo`;o00008oooool2o`0007Kooooo002/ooooo`03o`000?oooooooooo00So
oooo0_l0000Booooo`;o00004Oooool2o`0008Sooooo002/ooooo`03o`000?oooooooooo00Sooooo
0_l0000Uooooo`;o0000R?ooool009Wooooo0_l00004ooooo`;o00002oooool00ol0003ooooooooo
o`0Cooooo`;o0000Y?ooool008_ooooo0_l0000<ooooo`;o00001?ooool2o`0000_ooooo0ol0000C
ooooo`;o00007?ooool2o`0008Kooooo002;ooooo`;o00007oooool00ol0003oooooooooo`0aoooo
o`?o0000QOooool00:cooooo00?o0000ooooooooool0<_ooool2o`0008Gooooo002Mooooo`;o0000
3Oooool00ol0003oooooooooo`0:ooooo`;o00005Oooool2o`00013ooooo0_l00024ooooo`00Vooo
ool4o`0000gooooo00?o0000ooooooooool02_ooool2o`0001Gooooo0_l0000@ooooo`;o0000Q?oo
ool009_ooooo0_l0000?ooooo`03o`000?oooooooooo0;Wooooo002Aooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2o`0000Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo00_ooooo0_l00008ooooo`?o0000XOooool0097ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o00002?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00_ooooo0_l0
0008ooooo`?o00002oooool2o`0009Cooooo0029ooooo`Ko00000_ooool01Ol@413ooooooooooooo
oooo410@013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`;o00004ooo
ool4o`0009;ooooo002Aooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8boooo
o`04ooooo`?o00003_ooool2o`0001Gooooo0_l0002Booooo`00TOooool01Ol0003ooooooooooooo
oooo000000Wooooo0_l000001_oooooo0000ob4Q8Ol0003o<S8bolc<c0Gooooo00?o0000oooooooo
ool06Oooool2o`0009kooooo002=ooooo`;o00000_ooool01Ol@413ooooooooooooooooo410@00Wo
oooo0_l000000ooooooo0000ooooo`05ooooo`;o000000?oooooo`000?ooool02?ooool2o`00013o
oooo0_l00009ooooo`;o0000Toooool008gooooo0_l00002ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03?ooool00ol0003oooooooooo`04ooooo`;o000000Coooooo`000?oooooooooo0_l00005oooo
o`;o00006oooool2o`00013ooooo0_l00021ooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Kooooo0ol00003ooooo`Co00001_ooool00ol0003oooooooooo`02o`0002Gooooo0_l0000=oooo
o`;o0000POooool009cooooo0ol0000=ooooo`03o`000?oooooooooo02Oooooo0_l0002@ooooo`00
[?ooool00ol0003oooooooooo`2iooooo`00X_ooool2o`0000Sooooo00?o0000ooooooooool00ooo
ool2o`0000?ooooo0_l00013ooooo`;o0000J_ooool00:;ooooo0_l00008ooooo`?o00000oooool2
o`0000?ooooo0_l0000Aooooo`;o0000<?ooool2o`0006[ooooo002/ooooo`03o`000?oooooooooo
01_ooooo0_l0002Looooo`00Toooool2o`000003ooooool0003o000001Cooooo00?o0000oooooooo
ool00oooool2o`0003Oooooo0_l0001kooooo`00Toooool2o`000003ooooool0003o000001Cooooo
00?o0000ooooooooool00oooool2o`0002Gooooo0_l0000@ooooo`;o0000Noooool009gooooo0_l0
000=ooooo`03o`000?oooooooooo00Gooooo0_l0000<ooooo`;o00005Oooool2o`0000oooooo0_l0
001looooo`00WOooool2o`0000gooooo00?o0000ooooooooool01Oooool2o`0000cooooo0_l0000V
ooooo`;o00004oooool2o`0006Oooooo002;ooooo`;o00007oooool00ol0003oooooooooo`0=oooo
o`;o00001?ooool3o`0003[ooooo0_l0001Wooooo`00Roooool2o`0001oooooo00?o0000oooooooo
ool03Oooool2o`0000Gooooo0_l0002Sooooo`00[?ooool3o`0002cooooo1?l0000<ooooo`;o0000
00?oooooo`000?l00000N?ooool008Sooooo0_l0000Rooooo`;o0000;Oooool4o`0000cooooo0_l0
00000ooooooo0000o`00001hooooo`00R?ooool4o`0001gooooo0_l000000ooooooo0000ooooo`0o
ooooo`Co0000Moooool008[ooooo0_l00002ooooo`;o00003_ooool2o`0000Wooooo0_l000000ooo
oooo0000ooooo`0nooooo`Go0000Moooool008kooooo0_l0000>ooooo`;o00003?ooool00ol0003o
ooooooooo`0?ooooo`;o0000;?ooool2o`0007[ooooo0027ooooo`;o00008oooool00ol0003ooooo
ooooo`0?ooooo`;o00007?ooool2o`0008[ooooo0027ooooo`;o00008oooool00ol0003ooooooooo
o`0?ooooo`;o00007?ooool2o`0008[ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`?o00006?ooool2o`0001Kooooo0_l0000?ooooo`?o0000MOooool0093ooooo0_l0000:ooooo`;o
000000?oooooo`000?l000002oooool00ol0003oooooooooo`0Hooooo`;o00002Oooool2o`0000_o
oooo0_l0000?ooooo`?o0000MOooool0093ooooo0_l0000:ooooo`;o000000?oooooo`000?l00000
1oooool2o`0000;ooooo00?o0000ooooooooool08oooool2o`0000cooooo0_l00026ooooo`00Z?oo
ool2o`0000;ooooo00?o0000ooooooooool04Oooool2o`0001kooooo0_l00026ooooo`00[?ooool0
0ol0003oooooooooo`0Aooooo`;o0000A?ooool2o`00063ooooo002Sooooo`;o00001oooool00ol0
003oooooooooo`1Gooooo`;o0000H?ooool009;ooooo0_l0000?ooooo`;o00001oooool00ol0003o
ooooooooo`2iooooo`00ROooool2o`0000Oooooo0_l0000Hooooo`03o`000?oooooooooo03?ooooo
0_l00024ooooo`00POooool2o`0000Kooooo0_l0000:ooooo`;o00005Oooool00ol0003ooooooooo
o`0Looooo`;o00005Oooool2o`0008Cooooo0021ooooo`?o00004Oooool2o`0001Gooooo1?l0000;
ooooo`;o00003_ooool2o`0001Gooooo0_l00024ooooo`00P_ooool2o`0002Sooooo00Co0000oooo
ool0003o00001_ooool2o`0000?ooooo0_l00006ooooo`;o00003oooool2o`0009;ooooo002/oooo
o`03o`000?oooooooooo00Oooooo0_l0000;ooooo`;o00001oooool2o`0000Kooooo0_l0002Boooo
o`00[?ooool00ol0003oooooooooo`0Mooooo`;o00002?ooool2o`00093ooooo002Tooooo`;o0000
1_ooool00ol0003oooooooooo`0Mooooo`;o00002?ooool2o`00093ooooo0029ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@?ooooo1_l00004ooooo`05odA4A?l0003o0000o`000?oM
gMd01Oooool00ol0003oooooooooo`0Vooooo`;o0000TOooool007gooooo0_l00002ooooo`;o0000
1_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B43ooooo`;o000000Co8B4Qonk^k_oo
ooooA4A41oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01gooooo0ol00006oooo
o`;o0000TOooool007gooooo0_l00002ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@
00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o00003_ooool2o`00
00gooooo0ol0002Iooooo`00ROooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q
8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o00003_ooool2o`0002Gooooo0ol00021oooo
o`00ROooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool03oooool2o`0001Oooooo0_l0000;
ooooo`?o00003oooool2o`00073ooooo0029ooooo`05oa0@4?ooooooooooooooool@41002Oooool2
o`0000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00;ooooo0_l00006ooooo`;o00000oooool2o`0001Oooooo1?l0000Kooooo`;o0000L?ooool0
08Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`09ooooo`?o000000Co^[ZjoooooonHV9So410@1?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo0_l00006ooooo`;o00000ooo
ool2o`0001Sooooo0ol0002=ooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`0Yooooo`;o0000
S_ooool007gooooo0_l0000]ooooo`03o`000?oooooooooo0;Wooooo001mooooo`;o0000;Oooool0
0ol0003oooooooooo`03ooooo`;o00000_ooool2o`00043ooooo0_l0001^ooooo`00[?ooool00ol0
003oooooooooo`03ooooo`;o00000_ooool2o`0000kooooo0_l0000Oooooo`;o00003oooool2o`00
06kooooo002/ooooo`?o00005oooool2o`0001oooooo0_l0001oooooo`00S_ooool2o`0001cooooo
00?o0000ooooooooool02?ooool2o`0001Kooooo0ol00007ooooo`;o0000SOooool008kooooo0_l0
000Looooo`03o`000?oooooooooo00Sooooo0_l0000=ooooo`Co00001Oooool3o`0000Oooooo0_l0
002=ooooo`00[?ooool00ol0003oooooooooo`0Booooo`;o00000oooool4o`0000Gooooo0_l0002G
ooooo`00[?ooool00ol0003oooooooooo`0Booooo`;o00003?ooool2o`0001Oooooo0_l0000Soooo
o`;o0000FOooool00:cooooo00?o0000ooooooooool01?ooool2o`0000cooooo0_l0000Hooooo`;o
00002oooool2o`0000kooooo0_l0000Cooooo`;o0000FOooool00:cooooo00?o0000ooooooooool0
1?ooool2o`0000cooooo0_l0000Hooooo`;o00006oooool2o`0006kooooo002/ooooo`03o`000?oo
oooooooo00;ooooo0_l0000Wooooo`;o0000S?ooool00:cooooo0ol00002ooooo`;o00002Oooool2
o`0001cooooo0_l0002<ooooo`00[?ooool00ol0003oooooooooo`0=ooooo`;o0000>oooool2o`00
06gooooo002/ooooo`03o`000?oooooooooo02gooooo0_l0000Kooooo`;o0000KOooool008[ooooo
0_l0000Pooooo`03o`000?oooooooooo00Kooooo0_l0000Uooooo`;o0000R_ooool008Oooooo0_l0
00000ooooooo0000o`00000Pooooo`03o`000?oooooooooo00Kooooo0_l0002aooooo`00Qoooool2
o`0000[ooooo0_l0000Gooooo`03o`000?oooooooooo02cooooo0_l0002;ooooo`00Toooool2o`00
01Oooooo00?o0000ooooooooool05?ooool2o`0001Kooooo0_l0002;ooooo`00R_ooool2o`00023o
oooo00?o0000ooooooooool05?ooool2o`000:?ooooo002:ooooo`;o00008?ooool00ol0003ooooo
ooooo`0Kooooo`;o00001Oooool3o`0001Gooooo0ol0001looooo`00[?ooool3o`0001_ooooo0_l0
0005ooooo`?o00005Oooool3o`0007cooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo00kooooo0_l0000Nooooo`;o00002_ooool2o`0007gooooo0009ooooo`Co
000000?o410@ooooooooool05_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b
<_oMgMd05_ooool00ol0003oooooooooo`0>ooooo`;o00002?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`So000000KoooooodA4A?l0003o0000oc8b<_oMgMd4ooooo`;o0000
2Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^ko
oooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`Co000000?o410@ooooooooool04_oo
ool000_ooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b
<_ooool05Oooool00ol0003oooooooooo`04ooooo`;o00004_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ol00004ooooo`03ogMgMolb
<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`;o00000_lQ8B48ooooo`03ogMg
Molb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGo
ZJVYooooo`07ooooo`03ogMgMolb<S;ooooo01Wooooo00?o0000ooooooooool05?ooool000Ko0000
1Oooool00ol0003oooooooooo`0@ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00go
oooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`05ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool01Oooool6o`0000;ooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`04ooooo`;o00004_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h00_ooool2o`0000Gooooo00?o0000ooooooooool00_ooool2o`0000Wooooo00Go
410@oooooooooooooooooa0@4003ooooo`;o00002oooool00ol0003oooooooooo`0=ooooo`05oa0@
4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol0003ooooo
oooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`0>ooooo`05
o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0>ooooo`05o`000?oooooooooo
ooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo01Gooooo00?o0000
ooooooooool01?ooool2o`0000Sooooo0_l00008ooooo`05o`000?ooooooooooooooool000003Ooo
ool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00?ooooo0_l00009ooooo`05o`000?oo
ooooooooooooool000003oooool00omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool0
00003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Wooooo00?o0000oooooooo
ool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooo
oooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Ko
oooo00?o0000ooooooooool01?ooool2o`0000Sooooo0_l00008ooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01_ooool2
o`0000Oooooo00Ko0000ooooooooooooooooo`000?ooool2o`0000Wooooo00Go0000ob4Q8Ol0003o
<S8bolc<c006ooooo`;o00001oooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<
c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[ooooo00?o0000ooooooooool05?ooool0
00_ooooo00?o0000ooooooooool06?ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo01Sooooo0ol000000ooooooo0000o`00000Eooooo`05oa0@
4?ooooooooooooooool@41001_ooool3o`0000Kooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`08ooooo`;o00001oooool01_l@413ooooooooooooooooo410@ooooo`;o00002Oooool0
0ol0003oooooooooo`08ooooo`;o00001oooool01Ol@413ooooooooooooooooo410@00kooooo00?o
ZJVYogMgMoooool00oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Cooooo000;
ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oo
oooooooooooooolb<S801?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool06?ooool01?l0003ooooooooooooo
ool2o`0001Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`?o00000_ooool01Ol0003o^[Zj
oooooonHV9So410@00Cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@
oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05?oo
ool000Wooooo00?oEEEEofIVI_l000006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol0
0004ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0000Goooo
o`03o`000?oooooooooo01Sooooo00?ok^k^oc8b<_l000000_l00006ooooo`;o00000oooool01OnH
V9So410@o`000?lQ8B7oc<c<00Cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?oo
ool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0001Wooooo
00?oEEEEofIVI_l000005_ooool00:cooooo00?o0000ooooooooool06oooool2o`0001oooooo0_l0
001kooooo`00[?ooool00ol0003oooooooooo`0Kooooo`;o00004_ooool2o`0000_ooooo0_l0001k
ooooo`00[?ooool00ol0003oooooooooo`07ooooo`;o00009_ooool2o`0000[ooooo0_l0001aoooo
o`;o00000_ooool2o`0000Gooooo002/ooooo`03o`000?oooooooooo00Oooooo0_l0000booooo`;o
0000LOooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Gooooo002Aooooo`;o00006Oooool00ol0
003oooooooooo`2_ooooo`04omgMgOl0003o410@olc<c0Kooooo0007oooooooo0000C?l0000<oooo
o`04onk^k_lQ8B7o410@onk^kPKooooo0007ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooool3o`0000Gooooo0ol00006ooooo`?o00001Oooool3o`0000Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0:ooooo`04ob4Q8OmgMgOoMgMgoc8b<PKooooo0007oooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Voooo
o`04o`000?ooooooooooooooo`;o00008oooool00ol0003oooooooooo`0Dooooo`;o00004Oooool0
0ol0003oooooooooo`0Aooooo`;o00004oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool02Oooool2o`0000;ooooo0_l00005ooooo`00Qoooool2o`00
02?ooooo00?o0000ooooooooool0>oooool3o`0007_ooooo002/ooooo`03o`000?oooooooooo01Go
oooo0_l0000Uooooo`?o0000N_ooool009Gooooo0_l0000Eooooo`03o`000?oooooooooo01Gooooo
0_l0000<ooooo`;o00006?ooool2o`0007[ooooo002Eooooo`;o00005Oooool00ol0003ooooooooo
o`0Sooooo`;o0000U?ooool008oooooo0_l00004ooooo`;o00005Oooool00ol0003oooooooooo`07
ooooo`;o00000_ooool2o`0000;ooooo0_l00004ooooo`;o0000=oooool2o`0006Wooooo002?oooo
o`;o00001?ooool2o`0001Gooooo0ol00007ooooo`;o00000_ooool2o`0000;ooooo0_l00003oooo
o`?o0000=oooool2o`0006Wooooo002/ooooo`03o`000?oooooooooo00_ooooo0_l00007ooooo`;o
00001Oooool2o`00033ooooo0_l0001Zooooo`00P?ooool2o`0002[ooooo00?o0000ooooooooool0
6oooool2o`00033ooooo0_l0001Zooooo`00P?ooool2o`0002[ooooo00?o0000ooooooooool0^Ooo
ool00:cooooo00?o0000ooooooooool08oooool2o`0009Cooooo0020ooooo`;o00002_ooool2o`00
01kooooo00?o0000ooooooooool08oooool2o`0009Cooooo0020ooooo`;o00002_ooool2o`0001ko
oooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool06oooool2o`00037ooooo
0_l0001Yooooo`00[?ooool00ol0003oooooooooo`07ooooo`;o00004_ooool2o`0001oooooo0_l0
000@ooooo`;o0000JOooool0083ooooo0_l0000Zooooo`?o00001?ooool2o`000003ooooool0003o
000003?ooooo0_l0001kooooo`00P?ooool2o`0000gooooo0_l0000Kooooo`03o`000?oooooooooo
00Cooooo0_l0000>ooooo`;o0000Xoooool008oooooo0_l0000Kooooo`03o`000?oooooooooo00ko
oooo0_l00004ooooo`;o0000=oooool2o`0006[ooooo002?ooooo`;o00000oooool2o`0001Kooooo
00?o0000ooooooooool03_ooool2o`0003gooooo0_l0001Zooooo`00TOooool2o`000003ooooool0
003o000001Kooooo00?o0000ooooooooool03oooool2o`000:Sooooo0024ooooo`;o00002oooool2
o`0001Wooooo00?o0000ooooooooool00oooool2o`0000[ooooo0_l00002ooooo`;o0000>?ooool2
o`0006[ooooo0024ooooo`;o00009_ooool00ol0003oooooooooo`03ooooo`;o000000?oooooo`00
0?l000002oooool2o`0003Sooooo0_l0001Zooooo`00O?ooool2o`0000Kooooo0_l00007ooooo`;o
00007Oooool00ol0003oooooooooo`06ooooo`;o00009Oooool3o`0008Wooooo001looooo`;o0000
1_ooool2o`0000Oooooo0_l0000Mooooo`?o0000;Oooool3o`0008Wooooo0024ooooo`;o00009_oo
ool00ol0003oooooooooo`0iooooo`;o0000O_ooool00:cooooo00?o0000ooooooooool08_ooool2
o`0001Gooooo0_l0000?ooooo`;o0000KOooool00:cooooo00?o0000ooooooooool08_ooool2o`00
02Kooooo1?l0001[ooooo`00[?ooool00ol0003oooooooooo`0^ooooo`;o00007?ooool2o`0006_o
oooo002/ooooo`03o`000?oooooooooo02;ooooo0_l0000:ooooo`;o0000ROooool009Wooooo0_l0
000Aooooo`03o`000?oooooooooo02;ooooo0_l0002Eooooo`00QOooool2o`0001;ooooo0_l0000A
ooooo`03o`000?oooooooooo00;ooooo0_l0000>ooooo`;o0000YOooool008Gooooo0_l0000Goooo
o`;o00003?ooool3o`0000;ooooo0_l0000>ooooo`;o00006Oooool2o`0008[ooooo002Nooooo`;o
00003?ooool00ol0003oooooooooo`08ooooo`;o00002?ooool2o`0001Wooooo0_l0000<ooooo`;o
0000O?ooool008_ooooo0_l0000Oooooo`03o`000?oooooooooo00Sooooo0_l00008ooooo`;o0000
9oooool2o`0007cooooo002;ooooo`;o000000?oooooo`000?l000007?ooool00ol0003ooooooooo
o`07ooooo`;o00008oooool2o`0001gooooo0_l0001/ooooo`00S_ooool2o`0001cooooo00?o0000
ooooooooool01oooool2o`0002?ooooo0_l0000Kooooo`Co0000K?ooool00:cooooo00?o0000oooo
ooooool08Oooool2o`0002Kooooo0_l0001^ooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool08Oooool2o`0000Sooooo0_l0002<ooooo`00ROooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo01Sooooo0_l0000Aooooo`;o00002oooool2o`0007oooooo0029
ooooo`05oa0@4?ooooooooooooooool@41000oooool2o`0000Oooooo00?oV9RHob4Q8Oo^k^h02Ooo
ool00ol0003oooooooooo`03ooooo`?o00004Oooool2o`0000Gooooo0_l0000Aooooo`;o00002ooo
ool2o`0000oooooo0_l0001^ooooo`00ROooool01Ol0003ooooooooooooooooo000000?ooooo0_l0
0003ooooo`;o00000oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool00_ooool2o`0000gooooo0_l0000=ooooo`;o00009oooool2o`0006kooooo0029
ooooo`05o`000?ooooooooooooooool000002?ooool2o`0000Cooooo00?oMgMgofIVI_ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool00_ooool2o`0000Oooooo
0_l0000Cooooo`;o0000Uoooool008Wooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0;ooooo`;o0000
7Oooool2o`0008gooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zj
oooooonHV9So410@00Cooooo00?o0000ooooooooool00_ooool2o`0000?ooooo00?o0000oooooooo
ool0:_ooool2o`0008gooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So
410@o`000?lQ8B7oc<c<00Cooooo1?l000000ooooooo0000o`000003ooooo`03o`000?oooooooooo
00[ooooo0_l0000Zooooo`?o0000P?ooool00:cooooo00?o0000ooooooooool02_ooool2o`0002[o
oooo0ol00020ooooo`00Q_ooool2o`0001Wooooo0_l00002ooooo`;o00001Oooool00ol0003ooooo
ooooo`2iooooo`00Q_ooool2o`0001Wooooo0_l00002ooooo`;o00001Oooool00ol0003ooooooooo
o`05ooooo`;o0000<?ooool2o`00083ooooo002/ooooo`?o00001Oooool2o`0000Oooooo0_l0000W
ooooo`;o0000P?ooool00:cooooo00?o0000ooooooooool01?ooool2o`0000Sooooo0_l0000Uoooo
o`Co0000P?ooool00:cooooo00?o0000ooooooooool00_l00002ooooo`;o0000;oooool4o`00083o
oooo002=ooooo`;o00007Oooool00ol0003oooooooooo`02o`0000cooooo0_l00004ooooo`;o0000
8?ooool2o`0000kooooo0ol0001`ooooo`00SOooool2o`0000Wooooo0_l00005ooooo`;o00001_oo
ool2o`0000?ooooo00?o0000ooooooooool03_ooool2o`0000Cooooo0_l0000Pooooo`;o00003_oo
ool3o`00073ooooo002Hooooo`;o00001Oooool2o`0000Kooooo0_l00003ooooo`03o`000?oooooo
oooo04Oooooo0_l0001`ooooo`00R_ooool2o`0001Kooooo0_l00008ooooo`03o`000?oooooooooo
02Gooooo0ol0002Aooooo`00Poooool2o`0000Gooooo0_l0000Fooooo`;o00002?ooool00ol0003o
ooooooooo`0Uooooo`?o0000TOooool008?ooooo0_l00005ooooo`;o00008?ooool3o`000;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`;o0000^_ooool00:Sooooo0_l00002oooo
o`;o0000^_ooool00:Sooooo0_l00002ooooo`03o`000?oooooooooo00[ooooo0_l0000>ooooo`;o
0000WOooool00:cooooo00?o0000ooooooooool02_ooool2o`0000kooooo0_l0002Mooooo`00Y?oo
ool2o`0000Kooooo00?o0000ooooooooool0^Oooool009;ooooo0_l0000@ooooo`;o00001_ooool0
0ol0003oooooooooo`2iooooo`00T_ooool2o`0001Sooooo0ol0000Aooooo`;o00007Oooool4o`00
08Gooooo002/ooooo`03o`000?oooooooooo017ooooo0_l0000Mooooo`Co0000QOooool009Wooooo
0_l0000Aooooo`03o`000?oooooooooo00?ooooo0_l0000:ooooo`;o0000Z?ooool009Wooooo0_l0
000Aooooo`03o`000?oooooooooo00?ooooo0_l0000:ooooo`;o0000Z?ooool00:cooooo00?o0000
ooooooooool0^Oooool009[ooooo0_l0000@ooooo`03o`000?oooooooooo01Kooooo0_l0002Qoooo
o`00Uoooool2o`000003ooooool0003o0000013ooooo00?o0000ooooooooool03Oooool2o`0000Oo
oooo0_l0002Qooooo`00U?ooool2o`000003ooooool0003o000001?ooooo00?o0000ooooooooool0
1Oooool2o`0000Kooooo0_l0000Nooooo`;o0000R_ooool008Cooooo0_l00002ooooo`;o00002_oo
ool2o`0001Gooooo1?l00005ooooo`;o00003_ooool2o`0001Kooooo0_l0002:ooooo`00Q?ooool2
o`0000;ooooo0_l0000Qooooo`;o00003_ooool2o`0000Oooooo0_l0000Fooooo`;o0000R_ooool0
09gooooo0_l0000;ooooo`?o00003_ooool2o`0001oooooo0_l0002:ooooo`00WOooool2o`0000_o
oooo1Ol00004ooooo`;o0000/oooool008Gooooo0_l0000Pooooo`;o00000oooool4o`0000?ooooo
0_l00005ooooo`;o0000[?ooool008Gooooo0_l0000Nooooo`Co00000oooool01?l0003oooooo`00
0?l0000:ooooo`;o00007Oooool2o`0008gooooo0020ooooo`;o00003oooool01Oo^k^ko0000o`00
0?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`03odA4A?l0003o000000;o00001Oooool00ol0003ooooo
ooooo`0Zooooo`;o0000SOooool0083ooooo0_l0000?ooooo`05ogMgMol0003o0000oiRHV?mgMgL0
1?ooool2o`000003ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`2iooooo`00TOooool01Ol@413ooooooooooooooooo410@00Cooooo0_l0000:ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0^Oooool0097ooooo00Go0000oooooooooooooooo
o`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002iooooo`00TOooool01Ol0003ooooooooo
oooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00Oo
oooo0_l0002`ooooo`00R_ooool2o`0000Gooooo00Go410@oooooooooooooooooa0@400<ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool2o`0001;ooooo0_l0002Looooo`00
R_ooool2o`0000Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool06oooool2o`0009cooooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0^Oooool008Kooooo0_l0000Tooooo`03o`00
0?oooooooooo00Kooooo0_l0002aooooo`00Q_ooool2o`0001Wooooo0_l00009ooooo`03o`000?oo
oooooooo00Kooooo0_l0002aooooo`00Qoooool2o`0000cooooo0_l0000:ooooo`;o00000_ooool2
o`0000Gooooo0ol0000Vooooo`;o0000TOooool008Oooooo0_l0000<ooooo`;o00003_ooool2o`00
00Gooooo0ol0000=ooooo`;o00005oooool2o`0000oooooo0_l00020ooooo`00Voooool2o`0000oo
oooo00?o0000ooooooooool01?ooool2o`0000Oooooo0_l0000Wooooo`?o0000P?ooool009_ooooo
0_l0000?ooooo`03o`000?oooooooooo00Cooooo0_l0000`ooooo`;o0000POooool009_ooooo0_l0
000?ooooo`03o`000?oooooooooo0;Wooooo0027ooooo`;o00004_ooool2o`0000oooooo00?o0000
ooooooooool02oooool2o`000:cooooo0027ooooo`;o00008oooool00ol0003oooooooooo`0;oooo
o`;o00006?ooool2o`0009;ooooo002Gooooo`;o00004oooool00ol0003oooooooooo`0Dooooo`;o
00003oooool2o`0009;ooooo002Gooooo`;o00001Oooool2o`0000Sooooo0_l00002ooooo`03o`00
0?oooooooooo01Cooooo0_l0002Sooooo`00R?ooool2o`0000gooooo0_l00005ooooo`;o00002?oo
ool2o`0000;ooooo0ol0000Dooooo`;o0000Xoooool008Sooooo0_l0000=ooooo`;o00004oooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0@ooooo`;o0000Yoooool009Cooooo0_l0
000Fooooo`03o`000?oooooooooo013ooooo0_l0002Wooooo`00U?ooool2o`0001Kooooo00?o0000
ooooooooool04?ooool2o`000:Oooooo002/ooooo`03o`000?oooooooooo0;Wooooo002?ooooo`;o
00000oooool2o`0001Kooooo0ol00004ooooo`;o00006?ooool2o`0009Wooooo002?ooooo`;o0000
0oooool2o`0001Kooooo00?o0000ooooooooool01?ooool2o`0001Sooooo0_l0002Iooooo`00ZOoo
ool2o`000003ooooool0003ooooo0;[ooooo002Pooooo`;o00001oooool2o`000003ooooool0003o
oooo00oooooo0_l0002Yooooo`00Roooool2o`0000Wooooo0ol00007ooooo`;o00002_ooool00ol0
003oooooooooo`0>ooooo`;o0000ZOooool008_ooooo0_l00009ooooo`?o00004oooool00ol0003o
ooooooooo`0[ooooo`;o0000S?ooool00:cooooo00?o0000ooooooooool0:oooool2o`0008cooooo
002Aooooo`;o00006Oooool00ol0003oooooooooo`0Hooooo`;o0000Woooool0097ooooo0_l0000I
ooooo`03o`000?oooooooooo01Sooooo0_l0002Oooooo`00[?ooool3o`000;Wooooo002/ooooo`?o
0000^Oooool009[ooooo0_l0000@ooooo`?o0000^Oooool009[ooooo0_l0000@ooooo`03o`000?oo
oooooooo02Oooooo0_l0002@ooooo`00[?ooool00ol0003oooooooooo`0Wooooo`;o0000T?ooool0
08Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04
ooooo`06odA4A?l0003o0000oc8b<_oMgMgooooo0_l00002ooooo`03o`000?oooooooooo0;Wooooo
0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool0
1oooool00omgMgOo<S8bo`000002o`0000;ooooo00?o0000ooooooooool04oooool2o`000:Cooooo
0029ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`?o0000
0oooool00ol0003oooooooooo`0Cooooo`;o0000Y?ooool008Wooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ob4Q8Ooooooooooo00Gooooo0_l000001?lb<S;oooooo`000?l00002ooooo`?o
0000^Oooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?o
oooo00Ko0000ob4Q8Ol0003o0000olc<c?ooool2o`0000;ooooo00?o0000ooooooooool0^Oooool0
08Wooooo00Go410@oooooooooooooooooa0@4007ooooo`;o00001Oooool00onYZJWoMgMgooooo`03
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool2o`0000[ooooo0ol0002W
ooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo0_l00002ooooo`05oa0@4?oooooo
oooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo0_l0
000:ooooo`?o0000Yoooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`;o000000?o
ooooo`000?l000000ol00004ooooo`Co00001_ooool00ol0003oooooooooo`2iooooo`00U_ooool2
o`0001Cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool00_l0002goooo
o`00[?ooool00ol0003oooooooooo`02o`000;Oooooo002/ooooo`?o0000^Oooool00:cooooo00?o
0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool008_ooooo0_l0000Oooooo`03o`000?oooooooooo0;Wooooo002;ooooo`;o0000
4?ooool2o`0000Cooooo0_l00007ooooo`03o`000?oooooooooo0;Wooooo002Mooooo`;o00001?oo
ool2o`0000Oooooo00?o0000ooooooooool0^Oooool00:?ooooo0_l00007ooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool00oooool2o`000;Cooooo002/ooooo`03o`000?oooooooooo00?ooooo0_l0002doooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002Looooo`;o00003_ooool00ol0003oooooooooo`2iooooo`00W?ooool2o`0000kooooo
00?o0000ooooooooool0^Oooool009cooooo0_l0000>ooooo`03o`000?oooooooooo0;Wooooo002L
ooooo`Co00003?ooool00ol0003oooooooooo`2iooooo`00W_ooool2o`000004ooooool0003o0000
ooooo`Co00001?ooool00ol0003oooooooooo`2iooooo`00XOooool7o`0000Cooooo00?o0000oooo
ooooool0^Oooool00:;ooooo0_l00008ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool00oooool2o`000;Co
oooo002Rooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`03ooooo`;o0000
]?ooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`;o0000]?oo
ool00:Cooooo00?o0000ooooooooool01Oooool3o`000;Wooooo002Tooooo`03o`000?oooooooooo
0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo
002Tooooo`03o`000?oooooooooo0<7ooooo002Rooooo`03oeEEEOmVIVKo00000<?ooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Zooooo`04oa0@4?l0003o
0000o`000;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo
0;[ooooo002[ooooo`06o`000?mgMgOo0000o`000?mEEEGok^k^]oooool00:_ooooo00Ko0000oeEE
EOo^k^koooooogMgMomEEEFgooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooo
oooo0;Gooooo002[ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0]Oooool00:_o
oooo00Ko0000oeEEEOo^k^koooooogMgMomVIVJgooooo`00Z_ooool00ol@413o0000ogMgM`02o`00
0003ofIVI_o^k^kooooo0;Kooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.50647 .12678 Mdot
.65001 .42051 Mdot
.44487 .51904 Mdot
.42378 .60714 Mdot
.40489 .54739 Mdot
.47917 .88386 Mdot
.5026 .62243 Mdot
.36739 .39596 Mdot
.55652 .89294 Mdot
.49983 .75455 Mdot
.41605 .39137 Mdot
.41684 .0822 Mdot
.58366 .79324 Mdot
.41732 .6226 Mdot
.43226 .05225 Mdot
.52555 .32144 Mdot
.44915 .16584 Mdot
.57263 .81271 Mdot
.57434 .57372 Mdot
.56427 .14481 Mdot
.56705 .81592 Mdot
.65491 .55888 Mdot
.64441 .61295 Mdot
.55062 .84617 Mdot
.57185 .10024 Mdot
.60074 .49844 Mdot
.46956 .21475 Mdot
.57641 .5327 Mdot
.59921 .19729 Mdot
.65036 .43413 Mdot
.52647 .87275 Mdot
.55527 .89752 Mdot
.37913 .72704 Mdot
.56669 .27868 Mdot
.62396 .48711 Mdot
.44377 .08556 Mdot
.69834 .52677 Mdot
.56488 .40353 Mdot
.62525 .24922 Mdot
.45109 .01571 Mdot
.58113 .10657 Mdot
.60836 .38948 Mdot
.59327 .68779 Mdot
.55014 .18322 Mdot
.45058 .11711 Mdot
.50771 .20658 Mdot
.43616 .71889 Mdot
.62756 .78905 Mdot
.51398 .80528 Mdot
.5819 .17637 Mdot
.63297 .7769 Mdot
.67138 .34823 Mdot
.3551 .41696 Mdot
.61736 .58688 Mdot
.61326 .6239 Mdot
.46432 .97581 Mdot
.37101 .34048 Mdot
.44738 .16689 Mdot
.67703 .6695 Mdot
.42508 .17182 Mdot
.52996 .24735 Mdot
.74858 .46117 Mdot
.62892 .25911 Mdot
.513 .32237 Mdot
.39018 .79252 Mdot
.50956 .95427 Mdot
.51449 .72122 Mdot
.49567 .25745 Mdot
.57005 .42292 Mdot
.51662 .89252 Mdot
.50318 .16028 Mdot
.45415 .33777 Mdot
.49314 .76374 Mdot
.55 .60905 Mdot
.62857 .25852 Mdot
.50819 .47204 Mdot
.35522 .41382 Mdot
.56896 .34449 Mdot
.65674 .30841 Mdot
.55599 .71039 Mdot
.3953 .73839 Mdot
.64642 .41682 Mdot
.45151 .72595 Mdot
.61452 .41387 Mdot
.38175 .75335 Mdot
.54171 .36473 Mdot
.40406 .47733 Mdot
.42335 .28328 Mdot
.41538 .26551 Mdot
.50238 .27096 Mdot
.578 .10882 Mdot
.59368 .91614 Mdot
.54735 .52335 Mdot
.45866 .18592 Mdot
.54437 .45554 Mdot
.62789 .87283 Mdot
.42285 .6635 Mdot
.62884 .77933 Mdot
.36191 .29962 Mdot
.42548 .21854 Mdot
.54382 .17924 Mdot
.39588 .49223 Mdot
.41019 .10536 Mdot
.57764 .22906 Mdot
.43045 .88131 Mdot
.58232 .31448 Mdot
.52992 .20264 Mdot
.55772 .65483 Mdot
.54717 .52971 Mdot
.51209 .89717 Mdot
.4517 .76261 Mdot
.42758 .64031 Mdot
.56328 .88602 Mdot
.48204 .057 Mdot
.62835 .08975 Mdot
.44945 .32268 Mdot
.55365 .29925 Mdot
.46438 .98124 Mdot
.50665 .96019 Mdot
.69499 .50041 Mdot
.58589 .78777 Mdot
.73512 .38551 Mdot
.60668 .73223 Mdot
.60931 .21191 Mdot
.51034 .90018 Mdot
.41856 .47482 Mdot
.51304 .08538 Mdot
.67176 .80362 Mdot
.60847 .30132 Mdot
.52767 .42581 Mdot
.64592 .61553 Mdot
.58065 .24076 Mdot
.46583 .00864 Mdot
.4584 .8801 Mdot
.5629 .76046 Mdot
.64245 .27293 Mdot
.70182 .5006 Mdot
.56504 .14963 Mdot
.50055 .75018 Mdot
.36686 .53866 Mdot
.44708 .02754 Mdot
.74504 .57875 Mdot
.50082 .72286 Mdot
.5779 .48932 Mdot
.45127 .16218 Mdot
.52789 .09974 Mdot
.40831 .88396 Mdot
.72027 .21208 Mdot
.55043 .66705 Mdot
.4456 .20964 Mdot
.72648 .34627 Mdot
.39796 .58012 Mdot
.53947 .3122 Mdot
.54327 .85822 Mdot
.44088 .39351 Mdot
.40376 .71668 Mdot
.69496 .44717 Mdot
.64575 .2903 Mdot
.46871 .98081 Mdot
.69729 .52474 Mdot
.69711 .45976 Mdot
.58597 .63288 Mdot
.65938 .31191 Mdot
.58061 .09964 Mdot
.39254 .27252 Mdot
.59659 .67094 Mdot
.52405 .15343 Mdot
.42004 .91811 Mdot
.40088 .77813 Mdot
.56474 .39724 Mdot
.69838 .45323 Mdot
.53393 .11465 Mdot
.5427 .55725 Mdot
.54226 .32504 Mdot
.40453 .49513 Mdot
.53056 .72348 Mdot
.37814 .7132 Mdot
.64296 .8503 Mdot
.41167 .75972 Mdot
.43624 .38912 Mdot
.60711 .21309 Mdot
.68974 .40322 Mdot
.49885 .01456 Mdot
.56112 .50669 Mdot
.59625 .12508 Mdot
.5186 .63174 Mdot
.57157 .87013 Mdot
.67605 .79369 Mdot
.56053 .89377 Mdot
.56486 .08207 Mdot
.57687 .73188 Mdot
.71628 .32838 Mdot
.52854 .10008 Mdot
.4593 .27669 Mdot
.74095 .42442 Mdot
.3676 .59497 Mdot
.64941 .19545 Mdot
.43315 .04568 Mdot
.43588 .23146 Mdot
.58167 .29964 Mdot
.44223 .63772 Mdot
.43658 .60588 Mdot
.46965 .31324 Mdot
.41134 .63149 Mdot
.55753 .20268 Mdot
.43287 .62517 Mdot
.44542 .86175 Mdot
.4286 .65083 Mdot
.47211 .72644 Mdot
.42416 .32413 Mdot
.62864 .69439 Mdot
.56283 .32604 Mdot
.39911 .76829 Mdot
.5552 .43988 Mdot
.53394 .16778 Mdot
.54409 .28194 Mdot
.58562 .10643 Mdot
.51214 .65917 Mdot
.39898 .30568 Mdot
.4217 .06559 Mdot
.54751 .28454 Mdot
.67085 .68072 Mdot
.41616 .84313 Mdot
.38074 .58255 Mdot
.53627 .35882 Mdot
.44959 .79095 Mdot
.64476 .38869 Mdot
.54464 .54454 Mdot
.43714 .04307 Mdot
.74249 .40933 Mdot
.48073 .23925 Mdot
.46861 .33801 Mdot
.44733 .82297 Mdot
.46985 .21239 Mdot
.72536 .35607 Mdot
.55571 .36557 Mdot
.59611 .26301 Mdot
.60859 .73334 Mdot
.56983 .22114 Mdot
.74758 .45992 Mdot
.52918 .82404 Mdot
.37735 .50698 Mdot
.50141 .15783 Mdot
.54622 .91166 Mdot
.53671 .40983 Mdot
.68766 .42051 Mdot
.39761 .52219 Mdot
.49497 .14946 Mdot
.6343 .26776 Mdot
.63723 .17855 Mdot
.44475 .33912 Mdot
.45455 .28704 Mdot
.69208 .45338 Mdot
.59904 .50481 Mdot
.5338 .30398 Mdot
.59988 .67936 Mdot
.50915 .5161 Mdot
.36638 .44445 Mdot
.65354 .73529 Mdot
.47984 .84566 Mdot
.46868 .21282 Mdot
.37891 .46418 Mdot
.50025 .3211 Mdot
.40362 .64644 Mdot
.46327 .10907 Mdot
.42436 .66302 Mdot
.52954 .81711 Mdot
.48352 .06303 Mdot
.59326 .57885 Mdot
.47462 .05881 Mdot
.60597 .65513 Mdot
.50035 .75517 Mdot
.52532 .77998 Mdot
.69476 .44086 Mdot
.56084 .5374 Mdot
.49845 .79409 Mdot
.61956 .80092 Mdot
.41895 .35733 Mdot
.41382 .77228 Mdot
.62747 .24745 Mdot
.53542 .48157 Mdot
.5585 .5319 Mdot
.69665 .52213 Mdot
.39213 .18032 Mdot
.55309 .6708 Mdot
.43966 .58936 Mdot
.46801 .80482 Mdot
.43784 .08871 Mdot
.47204 .17904 Mdot
.41835 .8434 Mdot
.67667 .79137 Mdot
.6823 .64471 Mdot
.39871 .1536 Mdot
.68027 .64498 Mdot
.51632 .47443 Mdot
.69002 .62411 Mdot
.72934 .3833 Mdot
.40061 .20898 Mdot
.41804 .08574 Mdot
.75469 .27247 Mdot
.54296 .74691 Mdot
.5656 .76213 Mdot
.59155 .25975 Mdot
.5487 .90747 Mdot
.56281 .08726 Mdot
.42106 .64519 Mdot
.62401 .79113 Mdot
.59878 .53492 Mdot
.48895 .68727 Mdot
.63209 .6805 Mdot
.47241 .14493 Mdot
.5981 .76228 Mdot
.71614 .31999 Mdot
.4638 .29543 Mdot
.41617 .20886 Mdot
.59129 .33675 Mdot
.37556 .6813 Mdot
.51039 .34836 Mdot
.50757 .02395 Mdot
.68707 .27278 Mdot
.73758 .63882 Mdot
.44461 .28111 Mdot
.44909 .87142 Mdot
.61787 .42781 Mdot
.65067 .30521 Mdot
.43826 .76869 Mdot
.45325 .67816 Mdot
.51518 .54468 Mdot
.50841 .17031 Mdot
.39324 .16737 Mdot
.6886 .43814 Mdot
.54407 .44909 Mdot
.64524 .63355 Mdot
.53229 .45844 Mdot
.47205 .31234 Mdot
.64702 .39897 Mdot
.4949 .87384 Mdot
.59557 .67442 Mdot
.58595 .63203 Mdot
.42076 .69651 Mdot
.35709 .6258 Mdot
.59774 .52635 Mdot
.63472 .37359 Mdot
.51251 .32281 Mdot
.41121 .88765 Mdot
.45219 .23392 Mdot
.5506 .13112 Mdot
.65247 .47028 Mdot
.53134 .63584 Mdot
.49813 .19814 Mdot
.74599 .57472 Mdot
.41152 .09706 Mdot
.69169 .62268 Mdot
.46382 .06393 Mdot
.55799 .71485 Mdot
.56959 .2761 Mdot
.52343 .10096 Mdot
.42119 .75242 Mdot
.40964 .10368 Mdot
.73411 .66142 Mdot
.37779 .45217 Mdot
.45827 .01343 Mdot
.51811 .03487 Mdot
.59929 .12576 Mdot
.50593 .36594 Mdot
.4766 .84434 Mdot
.4498 .02496 Mdot
.36748 .40426 Mdot
.51353 .39632 Mdot
.4535 .91489 Mdot
.59624 .51685 Mdot
.43642 .84655 Mdot
.53201 .16198 Mdot
.61384 .80627 Mdot
.59298 .25743 Mdot
.69616 .57305 Mdot
.67504 .37774 Mdot
.64755 .59355 Mdot
.69786 .59125 Mdot
.64876 .5963 Mdot
.53713 .06051 Mdot
.66889 .13794 Mdot
.6944 .53927 Mdot
.39284 .62497 Mdot
.43474 .47123 Mdot
.65684 .21613 Mdot
.40866 .30369 Mdot
.51653 .52003 Mdot
.51396 .02867 Mdot
.51017 .90089 Mdot
.45745 .68783 Mdot
.54064 .64728 Mdot
.59136 .4197 Mdot
.48991 .21848 Mdot
.61485 .81251 Mdot
.39924 .77456 Mdot
.73731 .41183 Mdot
.50899 .02459 Mdot
.53133 .20971 Mdot
.3718 .77782 Mdot
.55491 .24936 Mdot
.53604 .71114 Mdot
.50532 .77879 Mdot
.4403 .53991 Mdot
.38324 .22735 Mdot
.41099 .10027 Mdot
.46384 .21826 Mdot
.53555 .61303 Mdot
.48935 .21279 Mdot
.55569 .42891 Mdot
.68916 .26383 Mdot
.44726 .20162 Mdot
.39181 .27536 Mdot
.48629 .74468 Mdot
.54307 .32263 Mdot
.51654 .37108 Mdot
.41774 .30745 Mdot
.55096 .24731 Mdot
.50758 .24378 Mdot
.42621 .56373 Mdot
.73104 .3658 Mdot
.36725 .55784 Mdot
.5006 .54848 Mdot
.62479 .51583 Mdot
.52994 .20283 Mdot
.38919 .5362 Mdot
.59437 .55396 Mdot
.55282 .35405 Mdot
.66473 .22695 Mdot
.59416 .92016 Mdot
.60627 .28669 Mdot
.55036 .00782 Mdot
.57012 .21378 Mdot
.42572 .43141 Mdot
.53481 .91835 Mdot
.46269 .01475 Mdot
.42125 .34806 Mdot
.65139 .4685 Mdot
.35481 .57073 Mdot
.52934 .63827 Mdot
.4881 .69215 Mdot
.51242 .76145 Mdot
.37848 .48292 Mdot
.572 .66749 Mdot
.55298 .96635 Mdot
.49891 .6956 Mdot
.62228 .52276 Mdot
.60744 .38142 Mdot
.53664 .4022 Mdot
.45611 .30935 Mdot
.55532 .58567 Mdot
.36771 .39087 Mdot
.49012 .29724 Mdot
.64763 .28604 Mdot
.6387 .37215 Mdot
.43882 .13899 Mdot
.49372 .06499 Mdot
.4501 .90986 Mdot
.50539 .16882 Mdot
.67244 .80662 Mdot
.53408 .6696 Mdot
.399 .14044 Mdot
.63752 .1778 Mdot
.42429 .66114 Mdot
.69046 .62505 Mdot
.59389 .56653 Mdot
.41835 .25886 Mdot
.54673 .12572 Mdot
.54723 .18349 Mdot
.56943 .60207 Mdot
.50245 .20462 Mdot
.56678 .2772 Mdot
.75174 .46379 Mdot
.56907 .74436 Mdot
.50678 .44981 Mdot
.60365 .65056 Mdot
.54978 .727 Mdot
.50251 .35251 Mdot
.45659 .25674 Mdot
.61924 .57582 Mdot
.56887 .75052 Mdot
.42936 .47015 Mdot
.59594 .46133 Mdot
.50495 .95944 Mdot
.4065 .58427 Mdot
.43732 .14512 Mdot
.57714 .46183 Mdot
.57523 .52245 Mdot
.52533 .49353 Mdot
.61352 .07151 Mdot
.525 .51919 Mdot
.64861 .40965 Mdot
.6684 .68197 Mdot
.39885 .23014 Mdot
.57415 .45091 Mdot
.58322 .17556 Mdot
.46865 .00552 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00XOooool2o`000003ooooool0003ooooo00Kooooo00?o0000ooooooooool0
^Oooool00:3ooooo0ol000000ooooooo0000ooooo`06ooooo`03o`000?oooooooooo00gooooo0_l0
002Zooooo`00W_ooool4o`0000;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0=
ooooo`;o0000Z_ooool009_ooooo0_l000002?oooooo0000o`000?l0003ooooooeEEEOmVIVKo0000
1_ooool2o`000;_ooooo002Kooooo`;o00000_ooool2o`0000[ooooo0_l0002kooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00Voooool2o`0000oooooo1Ol0002gooooo`00V_ooool3o`0000oo
oooo00?o0000ooooool000000ol0002fooooo`00V_ooool2o`00013ooooo00Co0000oooooooooooo
oooo0_l0002fooooo`00[?ooool00ol0003oooooooooo`03ooooo`;o0000]?ooool00:cooooo00?o
0000ooooooooool00oooool2o`000;Cooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Goooo
o`;o00004oooool00ol0003oooooooooo`2iooooo`00UOooool4o`0001?ooooo00?o0000oooooooo
ool0^Oooool009Gooooo0_l0000Eooooo`03o`000?oooooooooo0;Wooooo002Eooooo`;o00005Ooo
ool3o`000;Wooooo002Eooooo`;o00005Oooool00ol0003oooooooooo`2iooooo`00Xoooool2o`00
0003ooooool0003o000000Cooooo00?o0000ooooooooool0^Oooool00:?ooooo0_l000000ooooooo
0000o`000004ooooo`03o`000?oooooooooo00Wooooo0_l0002^ooooo`00X?ooool2o`0000Cooooo
0_l000001Ooooooo0000o`000?oooooo000000_ooooo0_l0002^ooooo`00T_ooool2o`0000cooooo
0_l00004ooooo`;o000000Goooooo`000?l0003oooooo`00002kooooo`00T_ooool2o`0001Sooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool08_ooool2o`0009Gooooo002/
ooooo`?o00008_ooool2o`0009Gooooo002/ooooo`03o`000?oooooooooo0;Wooooo002@ooooo`;o
00006_ooool00ol0003oooooooooo`0Booooo`;o0000YOooool0093ooooo0ol00006ooooo`;o0000
4Oooool01?l0003oooooooooooooool2o`0000oooooo0_l0002Uooooo`00TOooool2o`0000Cooooo
1?l0000Aooooo`04o`000?ooooooooooooooo`;o00003_ooool2o`000:Kooooo002Gooooo`;o0000
4oooool00ol0003oooooooooo`0Aooooo`;o00005?ooool2o`00093ooooo002/ooooo`03o`000?oo
oooooooo02Oooooo0_l0002@ooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool0^Oooool0
08kooooo0_l0000Looooo`?o00001?ooool4o`0000cooooo0_l000000ooooooo0000o`00002Poooo
o`00S_ooool2o`0001cooooo00?o0000ooooooooool01?ooool4o`0000cooooo0_l000000ooooooo
0000o`00002Pooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool05oooool4o`0009kooooo
002>ooooo`;o00003oooool2o`0000_ooooo00?o0000ooooooooool05_ooool5o`0009kooooo002O
ooooo`;o00002oooool00ol0003oooooooooo`0Fooooo`;o0000XOooool00:cooooo00?o0000oooo
ooooool02?ooool2o`000:oooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Kooooo0_l00005ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`08
ooooo`;o0000[oooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool2
o`0000Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2iooooo`00POooool6o`00
00;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000
ooooooooool00oooool3o`0000cooooo0_l0000>ooooo`?o0000V_ooool008Wooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool0
1?l0003oooooo`000?l0000;ooooo`;o00003_ooool3o`0009[ooooo0029ooooo`05o`000?oooooo
ooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool01?l0003oooooo`000?l0000<ooooo`;o0000Z_ooool008Wooooo00Go410@oooooooooooo
oooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0=ooooo`;o0000Z_ooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
03Cooooo0_l00023ooooo`00ROooool01Oo^k^ko0000o`000?lb<S;ok^k^00Wooooo1ol00004oooo
o`Co00001_ooool00ol0003oooooooooo`0dooooo`;o0000Poooool008[ooooo0_l0000;ooooo`;o
00004oooool00ol0003oooooooooo`2iooooo`00Uoooool2o`0000Wooooo0_l00008ooooo`03o`00
0?oooooooooo01;ooooo0_l0002Uooooo`00Uoooool2o`0000Wooooo0_l00006ooooo`?o00005?oo
ool2o`000:Gooooo002Zooooo`Go00004_ooool2o`000:Gooooo002:ooooo`;o00008?ooool00ol0
003oooooooooo`05ooooo`;o0000/_ooool008[ooooo0_l0000Pooooo`;o00001_ooool2o`000;;o
oooo002Kooooo`;o00003oooool3o`0000Oooooo0_l0002`ooooo`00Voooool2o`0000oooooo0ol0
0007ooooo`;o0000/?ooool008Sooooo0_l0000@ooooo`?o00003oooool00ol0003oooooooooo`08
ooooo`;o0000[oooool008Sooooo0_l0000@ooooo`?o00003oooool4o`0000Oooooo0_l0002_oooo
o`00Toooool2o`0001Oooooo1?l0002hooooo`00Toooool2o`0001Oooooo0ol0000Hooooo`;o0000
Woooool008Sooooo0_l0000Hooooo`;o00002?ooool00ol0003oooooooooo`0;ooooo`;o00002ooo
ool2o`00013ooooo0_l0002=ooooo`00R?ooool2o`0001Sooooo0_l00008ooooo`03o`000?oooooo
oooo00_ooooo1?l0000Kooooo`;o0000SOooool009kooooo0_l0000<ooooo`03o`000?oooooooooo
00cooooo0ol0002Zooooo`00W_ooool2o`0000cooooo00?o0000ooooooooool03?ooool2o`000:_o
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo02kooooo0_l0
0029ooooo`00Zoooool2o`0001oooooo0_l0000?ooooo`;o0000ROooool009[ooooo0_l0000?oooo
o`Co00007Oooool2o`0009[ooooo002Jooooo`;o00004?ooool2o`0000Oooooo0_l00008ooooo`;o
0000Yoooool00:cooooo1?l00005ooooo`;o00002?ooool2o`000:Oooooo002;ooooo`;o00000ooo
ool2o`0000Sooooo0_l0000@ooooo`04o`000?oooooo0000o`0000Kooooo0_l0002`ooooo`00Rooo
ool2o`0000?ooooo0_l00008ooooo`;o00001Oooool3o`0000Cooooo0_l00002ooooo`03o`000?oo
oooooooo00Oooooo0_l0000Gooooo`?o00008_ooool2o`0007;ooooo002Qooooo`?o00001?ooool2
o`0000;ooooo00?o0000ooooooooool05?ooool2o`0000[ooooo0ol0000=ooooo`;o00004oooool2
o`0007;ooooo002Cooooo`;o00002oooool4o`0000Cooooo0_l00002ooooo`03o`000?oooooooooo
01Cooooo0_l0000Jooooo`;o0000Qoooool009?ooooo0_l0000;ooooo`;o00001_ooool2o`0000;o
oooo00?o0000ooooooooool05?ooool2o`000:?ooooo002/ooooo`?o00005?ooool2o`000:?ooooo
0025ooooo`;o00009Oooool00ol0003oooooooooo`0cooooo`;o0000Q?ooool008Gooooo0_l00003
ooooo`;o00002_ooool2o`0001Cooooo00?o0000ooooooooool05_ooool2o`0001_ooooo0_l00024
ooooo`00R_ooool2o`0000[ooooo0_l00004ooooo`;o00003_ooool00ol0003oooooooooo`0Foooo
o`;o0000XOooool009cooooo0_l0000>ooooo`03o`000?oooooooooo0;Wooooo002Uooooo`;o0000
1Oooool00ol0003oooooooooo`0Gooooo`;o0000X?ooool0097ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1Oooool00om4A4Co0000o`000002o`0000Gooooo00Co0000ooooool0003o
00005_ooool2o`000:3ooooo002Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool01?ooool01?l0003oooooo`000?l0002hooooo`00ROooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01_ooool2o`0000Gooooo1?l0000Eooooo`?o0000T?ooool0097ooooo00Go0000oooooooo
ooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00006ooooo`;o00001Oooool4o`00
01Gooooo0ol0002@ooooo`00TOooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;Wooooo002Aooooo`;o00000_ooool00ol@
413oooooooooo`05ooooo`;o00000oooool00ol0003oooooooooo`05ooooo`?o00007Oooool2o`00
00[ooooo0_l0002@ooooo`00TOooool2o`000003oooooonHV9SoMgMg00Oooooo0_l00003ooooo`03
o`000?oooooooooo00Gooooo0ol0000Mooooo`;o00002_ooool2o`00093ooooo002Aooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool06oooool3o`0001go
oooo0_l0001looooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool07?ooool2o`0000_ooooo
0_l0000@ooooo`;o0000O?ooool0093ooooo0_l0000Jooooo`;o0000:_ooool2o`0008kooooo0028
ooooo`;o00008_ooool2o`0002gooooo0_l0000<ooooo`;o00005Oooool2o`0006Kooooo0028oooo
o`;o00005?ooool2o`0000cooooo0ol0000Cooooo`?o00005_ooool2o`0000cooooo0_l0000Eoooo
o`;o0000I_ooool008Sooooo0_l0000Dooooo`;o00003?ooool00ol0003oooooooooo`0Cooooo`?o
0000Xoooool009;ooooo0_l00005ooooo`;o00004Oooool00ol0003oooooooooo`0;ooooo`;o0000
1_ooool2o`000:Cooooo002Booooo`;o00001Oooool2o`00017ooooo00?o0000ooooooooool02ooo
ool3o`0001oooooo0_l0002:ooooo`00WOooool2o`0000gooooo00?o0000ooooooooool03?ooool2
o`0001;ooooo0_l0000;ooooo`;o0000R_ooool009gooooo0_l0000=ooooo`03o`000?oooooooooo
023ooooo0_l0000;ooooo`;o0000R_ooool00:3ooooo0_l0000:ooooo`03o`000?oooooooooo02go
oooo0_l0002:ooooo`00X?ooool2o`0000Kooooo0_l00002ooooo`03o`000?oooooooooo0;Wooooo
001nooooo`;o0000:?ooool2o`0000;ooooo0ol0000>ooooo`;o00002?ooool2o`0000Kooooo0_l0
002Gooooo`00O_ooool2o`0000gooooo0_l0000Mooooo`03o`000?oooooooooo00Sooooo0_l00004
ooooo`;o00002?ooool2o`0000Kooooo0_l0002Gooooo`00R_ooool2o`000004ooooool0003o0000
ooooo`;o00006_ooool00ol0003oooooooooo`08ooooo`;o00009?ooool2o`0008Wooooo002:oooo
o`;o00001?ooool2o`0000_ooooo0_l0000=ooooo`03o`000?oooooooooo02kooooo1?l00027oooo
o`00WOooool2o`0000?ooooo0_l00008ooooo`03o`000?oooooooooo00[ooooo0_l0000Tooooo`?o
0000Q_ooool00:;ooooo0_l00008ooooo`03o`000?oooooooooo00[ooooo0_l0000<ooooo`;o0000
5oooool2o`0008Kooooo002/ooooo`03o`000?oooooooooo01Sooooo0_l0002Oooooo`00Voooool2
o`0000oooooo0_l00002ooooo`;o00000_ooool2o`0000Cooooo0_l0000gooooo`;o0000Loooool0
09?ooooo0_l00006ooooo`;o00003oooool3o`000003ooooool0003o000000;ooooo0_l00004oooo
o`;o0000=oooool2o`0007?ooooo002Cooooo`;o00005oooool01?l0003oooooooooooooool2o`00
00Sooooo0_l00004ooooo`;o0000<Oooool2o`0007?ooooo002/ooooo`03o`000?oooooooooo017o
oooo0_l0000aooooo`;o0000Loooool00:cooooo00?o0000ooooooooool0^Oooool009cooooo0_l0
000>ooooo`03o`000?oooooooooo01_ooooo0_l0002Looooo`00POooool2o`0001Kooooo0_l00000
0ooooooo0000o`000003ooooo`;o00002Oooool00ol0003oooooooooo`0Kooooo`;o0000W?ooool0
087ooooo0_l0000Fooooo`;o00001_ooool2o`0000Wooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool04oooool2o`0003;ooooo0_l0001`ooooo`00T_ooool2o`0001Sooooo
00?o0000ooooooooool00_l0000Aooooo`;o00008?ooool2o`00013ooooo0_l0001`ooooo`00T_oo
ool2o`0001Sooooo1Ol0000cooooo`;o0000P_ooool00:cooooo0_l0000?ooooo`;o0000=oooool2
o`00073ooooo002Aooooo`;o00006Oooool00ol0003oooooooooo`09ooooo`;o00000oooool2o`00
03Oooooo0_l0001`ooooo`00TOooool2o`0001Wooooo00?o0000ooooooooool02Oooool2o`000:ko
oooo002/ooooo`03o`000?oooooooooo00[ooooo0_l0002]ooooo`00ROooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Go
oooo00Co0000ooooool0003o00002Oooool2o`0000?ooooo0_l0000hooooo`;o0000K_ooool008Wo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400Oooooo00?oMgMgoc8b<_ooool01?ooool01Ol0003oooooo`000?l0003ooooo00;o00002ooo
ool2o`0003Sooooo0_l0001^ooooo`00POooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`;o00009Oooool3o`0008gooooo0029ooooo`05o`000?ooooooooooooooool000003Ooo
ool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Yooooo`?o0000SOoo
ool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo03Kooooo0_l00021ooooo`00ROoo
ool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo023ooooo0_l0000Dooooo`;o00004?ooool2o`0006oooooo
0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Pooooo`;o00009_ooool4o`0006go
oooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02Oooool2o`000005oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool0;?ooool2o`0001cooooo0_l0001]oooo
o`00P?ooool2o`0000kooooo0_l00005ooooo`;o00004oooool00ol0003oooooooooo`0Pooooo`;o
00002_ooool2o`0008_ooooo0020ooooo`;o00003_ooool2o`0000Kooooo0_l0000Booooo`03o`00
0?oooooooooo023ooooo0_l0002Gooooo`00P?ooool2o`0001Kooooo0_l0000Booooo`04o`000?oo
ooooooooooooo`;o00003oooool2o`000:Gooooo0020ooooo`;o0000:_ooool3o`000003ooooool0
003o000000oooooo0_l0000Iooooo`;o0000R_ooool0083ooooo0_l0000Zooooo`03o`000?oooooo
oooo00Wooooo0_l00007ooooo`;o00006Oooool2o`0000cooooo0_l0001looooo`00P?ooool2o`00
02[ooooo00?o0000ooooooooool02Oooool2o`0000Oooooo0_l0000Wooooo`;o0000O?ooool00:co
oooo00?o0000ooooooooool02Oooool2o`0002?ooooo0_l0000Mooooo`;o0000J_ooool00:cooooo
00?o0000ooooooooool02Oooool2o`0002?ooooo0_l0000Kooooo`Co0000J_ooool007cooooo0_l0
000^ooooo`03o`000?oooooooooo02;ooooo0_l0000Wooooo`;o0000K?ooool007cooooo0_l0000^
ooooo`03o`000?oooooooooo01_ooooo0_l00005ooooo`;o00002Oooool2o`0008[ooooo001loooo
o`;o0000;_ooool00ol0003oooooooooo`0Kooooo`;o00004?ooool3o`0000_ooooo0_l0001loooo
o`00[?ooool3o`0001Cooooo0_l0000Hooooo`;o00002oooool2o`0000oooooo0_l0001[ooooo`00
[?ooool00ol0003oooooooooo`06ooooo`;o00003?ooool2o`0000gooooo0_l0000Wooooo`;o0000
Joooool009?ooooo0_l0000Gooooo`03o`000?oooooooooo00Kooooo0_l00007ooooo`;o00004_oo
ool2o`0009Cooooo002Cooooo`;o00005oooool00ol0003oooooooooo`0?ooooo`;o00007Oooool2
o`0008Wooooo002/ooooo`03o`000?oooooooooo02kooooo0_l00029ooooo`00[?ooool00ol0003o
ooooooooo`0?ooooo`;o0000:_ooool4o`0007[ooooo002/ooooo`03o`000?oooooooooo00oooooo
0_l0000Zooooo`Co0000N_ooool007oooooo0_l0000[ooooo`03o`000?oooooooooo0;Wooooo001o
ooooo`;o0000:oooool01?l0003oooooo`000?l0000:ooooo`;o0000<?ooool2o`0007[ooooo0023
ooooo`;o00009oooool4o`0000[ooooo0_l00008ooooo`;o00009_ooool2o`0007[ooooo0023oooo
o`;o00009oooool00ol0003oooooooooo`0;ooooo`;o00002?ooool2o`0002Gooooo1?l0001ioooo
o`00[?ooool00ol0003oooooooooo`07ooooo`;o00000_ooool2o`0002oooooo1?l0001iooooo`00
2Oooool4o`000003oa0@4?oooooooooo01Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd03ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000
o`000?lb<S;ogMgM01Kooooo00?o0000ooooooooool01oooool2o`0000gooooo0_l000001?o^k^ko
<S8bo`000?lb<S82o`0000Cooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;o
gMgM00Sooooo0_l00005ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool3o`0000Gooooo00Go
A4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1?l000000ol@
413oooooooooo`0Booooo`002oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`0>oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B42o`0000;ooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A007ooooo`03ogMgMolb<S;ooooo01Gooooo00?o0000ooooooooool05_ooool2o`000004ogMg
MonHV9SooooooiRHV0;o00001?ooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007oooo
o`03ogMgMolb<S;ooooo00Oooooo0_l00005ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool4
o`0000Oooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool06Oooool00ol0003ooooooooo
o`0Dooooo`001_l00005ooooo`03o`000?oooooooooo013ooooo1_l00002ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00Gooooo1_l0
0002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`05ooooo`Ko0000
0_ooool01Ol@413ooooooooooooooooo410@00Oooooo0_l00003ooooo`03oiRHV?lQ8B7ok^k^00Wo
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Hooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00gooooo00Go410@oooo
oooooooooooooa0@4006ooooo`;o00002?ooool00ol0003oooooooooo`0=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooo
oooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`0>ooooo`05o`000?oo
ooooooooooooool000003oooool00omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool0
00003Oooool00onHV9So8B4Qonk^kP07ooooo`Co00005?ooool00ol0003oooooooooo`0Hooooo`05
o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP02ooooo`;o00000oooool00omg
MgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0>
ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb
<S;ooooo01Wooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`03oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool0
0ol0003o8B4Qo`000004o`0001Cooooo00Co0000ooooool0003o00005oooool01Ol0003ooooooooo
oooooooo000000kooooo00CoMgMgofIVI_oooooooooo0ol000001?lQ8B7o0000oc8b<_o<c<`?oooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go
0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c00Jooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo
00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000oooooooo
ool04Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04Oooool01Ol@
413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool2o`0001Wooooo1?l00000
0ooooooo0000o`00000Dooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`00
0?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?o
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003ooooo
ooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b
00Cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000
ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Co0000okZj^_ooooooV9RH
0_l00003ooooo`;o00006Oooool00ol0003oooooooooo`02ooooo`;o00005?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo
017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo01Cooooo0009ooooo`03oeEEEOmVIVKo000001[ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo0_l00003oooo
o`04oiRHV?l@413o0000ob4Q8@;o00000oooool4o`0001Oooooo00?o0000ooooooooool02?ooool2
o`0000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
1?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00004?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00006Oooool00omEEEGoIVIVo`00000Foooo
o`00Poooool2o`0002Oooooo00?o0000ooooooooool02?ooool2o`000:oooooo002/ooooo`03o`00
0?oooooooooo01Kooooo0_l0000=ooooo`;o0000T_ooool008Wooooo0_l0000Qooooo`03o`000?oo
oooooooo01Kooooo0_l0000=ooooo`;o0000Qoooool2o`0000;ooooo0_l00005ooooo`00ROooool2
o`000003ooooool0003o000001kooooo00?o0000ooooooooool01Oooool2o`000:Oooooo00Kok^k^
ob4Q8On7QhOo^[Zjo`000?oMgMd5ooooo`00S?ooool2o`0001kooooo00?o0000ooooooooool01Ooo
ool2o`0001Oooooo0_l0002?ooooo`04omgMgOl0003o410@olc<c0Kooooo0007oooooooo0000C?l0
000<ooooo`04onk^k_lQ8B7o410@onk^kPKooooo0007ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo1?l0
0007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0:ooooo`04ob4Q8OmgMgOoMgMgoc8b<PKooooo0007ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`;o00009oooool00ol0003ooooooooo
o`0Aooooo`;o00002_ooool2o`0000Sooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02Oooool2o`0000;ooooo0_l0
0005ooooo`00Poooool2o`0002Oooooo00?o0000ooooooooool04Oooool2o`0000[ooooo0_l0002J
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`02o`0002Co
oooo0_l0002Aooooo`00VOooool2o`00017ooooo00?o0000ooooooooool00_l00003ooooo`;o0000
5Oooool2o`0000Sooooo0_l0002Aooooo`00R_ooool2o`0000gooooo0_l0000Aooooo`03o`000?oo
oooooooo00;ooooo0_l000000ooooooo0000o`00000>ooooo`;o00001Oooool2o`0001oooooo0_l0
001jooooo`00R_ooool2o`00023ooooo0ol00002ooooo`;o00002?ooool2o`0000Oooooo0_l0000>
ooooo`;o00005_ooool3o`0007Wooooo002/ooooo`03o`000?oooooooooo00cooooo0_l0000?oooo
o`;o00001_ooool2o`0001Oooooo0_l0001iooooo`00[?ooool00ol0003oooooooooo`0<ooooo`;o
00003oooool2o`0001oooooo0_l0001iooooo`00[?ooool00ol0003oooooooooo`0<ooooo`;o0000
0_ooool2o`0000Cooooo0_l0002Qooooo`00Qoooool2o`0002?ooooo00?o0000ooooooooool04?oo
ool3o`0000?ooooo0_l00005ooooo`;o0000V_ooool0083ooooo0_l00005ooooo`;o00003oooool2
o`0001;ooooo00?o0000ooooooooool04Oooool2o`0000[ooooo0_l0000Nooooo`;o0000N_ooool0
083ooooo0_l0000Fooooo`;o00004_ooool00ol0003oooooooooo`0mooooo`;o0000N_ooool00:co
oooo00?o0000ooooooooool00_ooool2o`0000Oooooo0_l0002/ooooo`00S?ooool2o`0001kooooo
0_l00003ooooo`;o00001oooool2o`000:cooooo002<ooooo`;o00007_ooool3o`000;Wooooo002/
ooooo`03o`000?oooooooooo01cooooo0_l0002Kooooo`00P?ooool2o`0002[ooooo00?o0000oooo
ooooool02oooool2o`0000oooooo0_l0000Booooo`;o0000Qoooool0083ooooo0_l0000Zooooo`03
o`000?oooooooooo00_ooooo0_l0000Sooooo`;o0000Qoooool009?ooooo0_l0000Gooooo`03o`00
0?oooooooooo0;Wooooo002Cooooo`;o00005oooool00ol0003oooooooooo`0Looooo`;o0000Vooo
ool007cooooo0_l0000^ooooo`03o`000?oooooooooo01cooooo0_l0002Kooooo`00O?ooool2o`00
02kooooo00?o0000ooooooooool05Oooool2o`0002Kooooo0_l0001jooooo`00[?ooool3o`0001Go
oooo0_l0000=ooooo`;o00005oooool2o`0000oooooo0_l0001Yooooo`00R_ooool2o`00023ooooo
00?o0000ooooooooool06oooool2o`0000Oooooo0_l0000Wooooo`?o0000JOooool008Cooooo0_l0
0004ooooo`;o00008?ooool00ol0003oooooooooo`0Kooooo`;o0000<?ooool2o`0006[ooooo0024
ooooo`;o00001oooool2o`0001gooooo00?o0000ooooooooool03oooool2o`000:Sooooo002=oooo
o`;o00002Oooool2o`0001;ooooo00?o0000ooooooooool03oooool2o`0001;ooooo0_l0002Doooo
o`00V?ooool2o`0001;ooooo00?o0000ooooooooool08oooool2o`0001Wooooo0_l0001iooooo`00
P?ooool2o`0002[ooooo00?o0000ooooooooool0;Oooool2o`0000oooooo0_l0001iooooo`00P?oo
ool2o`0002[ooooo00?o0000ooooooooool0;Oooool3o`0008Wooooo002/ooooo`?o0000;_ooool2
o`0008Wooooo002/ooooo`03o`000?oooooooooo01?ooooo0_l0002Tooooo`00T_ooool2o`0000?o
oooo0_l0000Cooooo`03o`000?oooooooooo01?ooooo0_l0002Tooooo`00T_ooool2o`0000?ooooo
0_l0000Cooooo`03o`000?oooooooooo00gooooo0_l0002Zooooo`00[?ooool00ol0003ooooooooo
o`08ooooo`;o00000oooool2o`0001gooooo0_l0002;ooooo`00[?ooool00ol0003oooooooooo`08
ooooo`;o00008_ooool3o`0008[ooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooooooo
o`0]ooooo`;o0000R_ooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`;o000000?o
ooooob4Q8OlQ8B401?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool2o`0003gooooo0_l0001kooooo`00R?ooool2o`0000?ooooo00?o410@ooooooooool00_l0
0003ooooo`;o00000oooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0
000Rooooo`;o00005oooool3o`0007_ooooo001looooo`;o00002_ooool2o`0000?ooooo00?o0000
ooooooooool01Oooool2o`0000Cooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo02;ooooo0_l0000Gooooo`;o0000O?ooool007cooooo0_l0000;oooo
o`04o`000?ooooooooooooooo`?o00003?ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`03ooooo`;o0000]?ooool008Wooooo00Go410@
oooooooooooooooooa0@4002o`0000gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00?ooooo0_l0000Dooooo`;o00004_ooool2o`0008[ooooo0029
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02_ooool2o`000004okZj^_ooooooV9RHoa0@40Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`;o00004?ooool2o`0001;ooooo
0_l0002:ooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo0_l00002ooooo`;o0000
00Co410@o`000?lQ8B7oc<c<1?ooool4o`0000Kooooo00?o0000ooooooooool01_ooool3o`0004;o
oooo0_l0001/ooooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool01_ooool2o`0004?ooooo
0_l0001/ooooo`00S?ooool2o`0000Cooooo0_l0000Hooooo`03o`000?oooooooooo03Sooooo0ol0
001nooooo`00S?ooool2o`0000Cooooo0_l0000Hooooo`03o`000?oooooooooo00[ooooo0_l0000/
ooooo`?o0000O_ooool009Cooooo0_l0000Fooooo`?o00002_ooool2o`0001?ooooo0_l0002Hoooo
o`00U?ooool2o`0001Kooooo00?o0000ooooooooool04?ooool2o`0000gooooo0ol0002Gooooo`00
[?ooool00ol0003oooooooooo`0@ooooo`;o00003_ooool2o`0009Oooooo002Cooooo`;o00005ooo
ool01?l0003oooooooooooooool2o`0004Oooooo0_l0001]ooooo`00T_ooool3o`0001Oooooo00Co
0000oooooooooooooooo0_l00017ooooo`;o0000KOooool009;ooooo0ol0000Gooooo`03o`000?oo
oooooooo00gooooo0_l00005ooooo`;o0000Xoooool00:cooooo00?o0000ooooooooool02?ooool2
o`0000?ooooo0ol00004ooooo`;o00001_ooool2o`0001Wooooo0_l00020ooooo`00[?ooool00ol0
003oooooooooo`08ooooo`;o00001?ooool2o`0000cooooo0_l0000Iooooo`;o0000P?ooool00:co
oooo0ol0000Looooo`;o0000Voooool009cooooo0_l0000>ooooo`03o`000?oooooooooo01cooooo
1?l0002Iooooo`00P_ooool2o`0001Sooooo0_l0000>ooooo`03o`000?oooooooooo01kooooo0_l0
0008ooooo`;o00002_ooool3o`0008;ooooo0022ooooo`;o0000:?ooool00ol0003oooooooooo`0X
ooooo`;o00002_ooool3o`0008;ooooo002Nooooo`;o00002?ooool2o`0000;ooooo00?o0000oooo
ooooool06oooool2o`0009cooooo002Nooooo`;o00002?ooool2o`0000;ooooo00?o0000oooooooo
ool06oooool2o`0009cooooo002Xooooo`;o00000_ooool00ol0003oooooooooo`0Wooooo`;o0000
T?ooool0097ooooo0_l0000Hooooo`;o0000:Oooool2o`00093ooooo002Aooooo`;o00006?ooool4
o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo00oooooo0_l0002Xooooo`00Poooool2o`0002Oooooo00?o
0000ooooooooool02?ooool2o`0000Gooooo0_l0002Xooooo`00Poooool2o`0002Oooooo00?o0000
ooooooooool02?ooool2o`0000Kooooo0_l0002Wooooo`00S?ooool2o`0000Sooooo0_l0000Doooo
o`03o`000?oooooooooo013ooooo0_l0002Wooooo`00S?ooool2o`0000Sooooo0_l0000Dooooo`04
o`000?ooooooooooooooo`;o0000]_ooool00:cooooo0ol000000ooooooo0000o`000004ooooo`;o
0000/?ooool008Cooooo0_l0000Fooooo`;o00001?ooool2o`0000Sooooo0_l00008ooooo`;o0000
1?ooool2o`000:[ooooo0024ooooo`;o00005_ooool2o`0000Cooooo0_l00008ooooo`03o`000?oo
oooooooo00gooooo0_l0002Zooooo`00[?ooool00ol0003oooooooooo`0Fooooo`;o00002?ooool2
o`0009Oooooo002/ooooo`03o`000?oooooooooo01Kooooo0_l00008ooooo`;o00003Oooool2o`00
08Sooooo0029ooooo`;o00008Oooool00ol0003oooooooooo`0_ooooo`;o0000R?ooool008Wooooo
0_l00006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;Wooooo002Aooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Sooooo00CoMgMgoc8b<_l0003o00000oooool00ol0003oooooooooo`0C
ooooo`;o0000Y?ooool0097ooooo00Go410@oooooooooooooooooa0@400@ooooo`?o00000oooool0
0ol0003oooooooooo`0;ooooo`;o00001_ooool2o`000:Cooooo002Aooooo`?o000000?oooooo`00
0?ooool03_ooool00omgMgOo<S8booooo`04ooooo`?o00002oooool2o`0000Kooooo0_l0002Toooo
o`00QOooool2o`0000[ooooo0ol000000ooooooo0000ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool2o`0001Cooooo0_l0002Tooooo`00QOooool2o`0000[ooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo0_l0002jooooo`00S_ooool2o`000006
oooooomgMgOoV9RHoooooonHV9SoMgMg3?ooool00ol0003oooooooooo`07ooooo`04o`000?oooooo
ooooooooo`;o00003_ooool2o`000:Kooooo002>ooooo`;o000000Koooooonk^k_lb<S;o0000oc8b
<_o^k^h6ooooo`;o00001?ooool4o`0000?ooooo0_l000000ooooooo0000ooooo`02ooooo`;o0000
3_ooool3o`0000Wooooo0_l0002Jooooo`00W?ooool2o`0000_ooooo0_l000000ooooooo0000oooo
o`0Cooooo`;o00002Oooool2o`0009[ooooo002:ooooo`;o00002oooool2o`0001?ooooo00?o0000
ooooooooool0^Oooool008[ooooo0_l00003ooooo`;o00001_ooool2o`0001?ooooo00?o0000oooo
ooooool0^Oooool008[ooooo0_l00003ooooo`;o00006oooool3o`0002Sooooo0_l0002?ooooo`00
POooool2o`0000Oooooo0ol0000Oooooo`?o00001Oooool2o`00023ooooo0ol0002?ooooo`00POoo
ool2o`0000Sooooo0_l0000Oooooo`?o00001Oooool2o`00023ooooo0_l0002@ooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0Iooooo`;o00003?ooool2o`00
093ooooo002Kooooo`;o00003oooool00ol0003oooooooooo`0Iooooo`;o00002oooool3o`0000ko
oooo0_l00020ooooo`00Qoooool2o`0001;ooooo0_l0000>ooooo`;o00006_ooool2o`0000cooooo
0_l0000?ooooo`;o0000P?ooool008Oooooo0_l0000Rooooo`;o00006_ooool2o`0001gooooo0_l0
0020ooooo`00[?ooool3o`0002Cooooo0_l0002Cooooo`00[?ooool00ol0003oooooooooo`0Toooo
o`;o00003oooool2o`0008;ooooo002Qooooo`;o00002Oooool01?l0003oooooooooooooool2o`00
01oooooo0_l0000Aooooo`;o0000P_ooool00:7ooooo0_l00009ooooo`04o`000?oooooooooooooo
o`;o00007oooool2o`00017ooooo0_l00022ooooo`00[?ooool00ol0003oooooooooo`0Eooooo`;o
00002oooool2o`0009Gooooo002/ooooo`03o`000?oooooooooo01?ooooo1?l0000;ooooo`;o0000
UOooool00:cooooo00?o0000ooooooooool01_ooool2o`0000_ooooo0_l0002Tooooo`00[?ooool0
0ol0003oooooooooo`06ooooo`;o0000/Oooool009[ooooo0_l0000@ooooo`?o00001_ooool2o`00
0;7ooooo002Jooooo`;o00004?ooool00ol0003oooooooooo`06ooooo`;o0000/Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool0093ooooo0ol0000Iooooo`03
o`000?oooooooooo0;Wooooo002@ooooo`?o00001?ooool2o`0000_ooooo0ol00005ooooo`03o`00
0?oooooooooo00gooooo0_l0002Zooooo`00Uoooool2o`0000_ooooo0ol00005ooooo`03o`000?oo
oooooooo00gooooo0_l0002Zooooo`00[?ooool3o`0002cooooo0_l0002;ooooo`00[?ooool00ol0
003oooooooooo`0/ooooo`;o0000Roooool00:cooooo00?o0000ooooooooool02oooool2o`000:co
oooo002Jooooo`;o00004?ooool00ol0003oooooooooo`0;ooooo`;o0000[?ooool009[ooooo0_l0
000@ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo
00?o0000ooooooooool0^Oooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
5?ooool2o`000:?ooooo0029ooooo`05oa0@4?ooooooooooooooool@41003Oooool2o`0000Wooooo
00Co0000oooooooooooooooo0ol00007ooooo`;o00003Oooool2o`00017ooooo0_l0002@ooooo`00
ROooool01Ol0003ooooooooooooooooo000000gooooo0_l00008ooooo`03ogMgMolb<S;ooooo00;o
oooo1Ol00005ooooo`;o00008?ooool2o`00093ooooo0029ooooo`05o`000?ooooooooooooooool0
00003_ooool01?mEEEGoc<c<o`000?l00002ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2iooooo`00ROooool01Ol@413ooooooooooooooooo410@00Oooooo0_l00005
ooooo`04ojVYZOmgMgOo0000o`0000;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`2iooooo`00ROooool01?mgMgOoV9RHoooooonHV9P2o`0000Kooooo0_l00002ooooo`05oa0@4?oo
oooooooooooooolb<S801?ooool00ol0003oooooooooo`02o`0000Gooooo00?o0000ooooooooool0
4Oooool2o`000:Kooooo0029ooooo`04onk^k_lb<S;o0000oc8b<P?o00002Oooool5o`0000Cooooo
1Ol00005ooooo`03o`000?oooooooooo017ooooo0_l0002Vooooo`00S_ooool2o`0001cooooo00?o
0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool00_ooool2o`0000_ooooo1?l0002V
ooooo`00[?ooool01?l0003oooooooooooooool3o`0000_ooooo1?l0002Vooooo`00[?ooool6o`00
00cooooo0_l0002Xooooo`00[?ooool00ol0003oooooooooo`02o`000;Oooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002Kooooo`;o00003oooool00ol0003oooooooooo`0=ooooo`;o0000Z_oo
ool009_ooooo0_l0000?ooooo`03o`000?oooooooooo00cooooo0ol0002Zooooo`00W?ooool2o`00
00kooooo00?o0000ooooooooool03?ooool2o`0000gooooo0_l0002Looooo`00TOooool2o`0000Wo
oooo0_l0000>ooooo`03o`000?oooooooooo00Sooooo0_l0000Aooooo`;o0000W?ooool0097ooooo
0_l0000Iooooo`03o`000?oooooooooo00Sooooo0_l0000Booooo`;o0000Voooool00:cooooo0ol0
000Looooo`;o0000Voooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
0ol0002iooooo`00[?ooool00ol0003oooooooooo`02o`000;Oooooo002/ooooo`03o`000?oooooo
oooo00;o0000]oooool00:cooooo1?l0002hooooo`00[?ooool4o`000;Sooooo002/ooooo`03o`00
0?oooooooooo00kooooo0_l0002Yooooo`00[?ooool00ol0003oooooooooo`0>ooooo`;o0000ZOoo
ool00:cooooo00?o0000ooooooooool0^Oooool00:3ooooo0_l0000:ooooo`?o0000^Oooool00:3o
oooo0_l0000:ooooo`03o`000?oooooooooo0;Wooooo002Pooooo`?o00002Oooool00ol0003ooooo
ooooo`2iooooo`00X?ooool3o`0000Wooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:;ooooo1?l000000ol@413o
ooooooooo`03ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0^Oooool00:Cooooo00?o0000ooooooooool01Oooool3o`000;Wooooo002T
ooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03
o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Rooooo`03oeEEEOmV
IVKo00000<?ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
002Zooooo`04oa0@4?l0003o0000o`000;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[
ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`06o`000?mgMgOo0000o`000?mEEEGok^k^]ooo
ool00:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomEEEFgooooo`00Zoooool00ol0003ok^k^oooo
o`02ooooo`03o`000?oooooooooo0;Gooooo002[ooooo`03o`000?o^k^kooooo00;ooooo00?o0000
ooooooooool0]Oooool00:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomVIVJgooooo`00Z_ooool0
0ol@413o0000ogMgM`02o`000003ofIVI_o^k^kooooo0;Kooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.38696 .44311 Mdot
.57822 .22051 Mdot
.48568 .62744 Mdot
.50953 .70473 Mdot
.50051 .79585 Mdot
.59707 .69526 Mdot
.51158 .42243 Mdot
.47557 .99237 Mdot
.6737 .69294 Mdot
.56165 .55455 Mdot
.46404 .78087 Mdot
.39637 .84431 Mdot
.66096 .59324 Mdot
.51441 .7338 Mdot
.3865 .78347 Mdot
.43234 .3169 Mdot
.40764 .68517 Mdot
.65771 .61271 Mdot
.56382 .37372 Mdot
.40191 .19 Mdot
.65341 .61592 Mdot
.63846 .35888 Mdot
.64959 .41295 Mdot
.64909 .64617 Mdot
.39338 .16696 Mdot
.56012 .29844 Mdot
.4139 .58547 Mdot
.54949 .3327 Mdot
.44152 .07466 Mdot
.58401 .23413 Mdot
.63557 .67275 Mdot
.67428 .69752 Mdot
.54709 .91926 Mdot
.44318 .1715 Mdot
.5788 .28711 Mdot
.39128 .72603 Mdot
.66904 .32677 Mdot
.4864 .21002 Mdot
.48499 .05431 Mdot
.37445 .70917 Mdot
.40008 .13101 Mdot
.52415 .18948 Mdot
.62839 .48779 Mdot
.40589 .24026 Mdot
.39669 .68944 Mdot
.40431 .42031 Mdot
.53422 .6771 Mdot
.70319 .58905 Mdot
.5961 .60528 Mdot
.42148 .12338 Mdot
.70373 .5769 Mdot
.57067 .14823 Mdot
.61211 .38688 Mdot
.62282 .4239 Mdot
.62466 .80251 Mdot
.46267 .98854 Mdot
.40825 .69265 Mdot
.70483 .4695 Mdot
.41415 .78895 Mdot
.41531 .31287 Mdot
.69305 .26117 Mdot
.49258 .06038 Mdot
.42998 .37145 Mdot
.56148 .89429 Mdot
.65127 .75427 Mdot
.56298 .52122 Mdot
.41758 .4622 Mdot
.49922 .22295 Mdot
.63363 .69252 Mdot
.3948 .4504 Mdot
.44409 .62615 Mdot
.55934 .56555 Mdot
.55362 .40905 Mdot
.49199 .05998 Mdot
.46457 .3611 Mdot
.46782 .17656 Mdot
.5401 .10841 Mdot
.60015 .51039 Mdot
.54664 .8532 Mdot
.57315 .21682 Mdot
.53437 .62336 Mdot
.54007 .21387 Mdot
.55304 .91539 Mdot
.45269 .24989 Mdot
.4854 .81462 Mdot
.43886 .77242 Mdot
.43671 .81107 Mdot
.41913 .42997 Mdot
.39897 .14235 Mdot
.72014 .71614 Mdot
.51669 .32335 Mdot
.40997 .63929 Mdot
.48673 .26317 Mdot
.73703 .67283 Mdot
.52269 .71433 Mdot
.70057 .57933 Mdot
.42427 .77709 Mdot
.40253 .26723 Mdot
.49042 .84715 Mdot
.40287 .86834 Mdot
.43518 .1369 Mdot
.58339 .79867 Mdot
.4689 .14154 Mdot
.40455 .32232 Mdot
.57965 .45483 Mdot
.51905 .32971 Mdot
.63095 .69717 Mdot
.54566 .6472 Mdot
.51623 .68957 Mdot
.67769 .68602 Mdot
.37677 .56509 Mdot
.44182 .64991 Mdot
.44046 .21262 Mdot
.62675 .80756 Mdot
.65072 .76019 Mdot
.65516 .30041 Mdot
.66099 .58777 Mdot
.64933 .18551 Mdot
.65957 .53223 Mdot
.45552 .05591 Mdot
.63041 .70018 Mdot
.48171 .75189 Mdot
.37715 .4229 Mdot
.7532 .60362 Mdot
.48903 .10439 Mdot
.46212 .29419 Mdot
.65214 .41553 Mdot
.44135 .12891 Mdot
.36971 .64634 Mdot
.58682 .7251 Mdot
.62708 .56046 Mdot
.51163 .07293 Mdot
.66206 .3006 Mdot
.40362 .18631 Mdot
.56063 .55018 Mdot
.50684 .96479 Mdot
.3779 .72412 Mdot
.73654 .37875 Mdot
.54996 .52286 Mdot
.53363 .28932 Mdot
.40638 .6767 Mdot
.38036 .35346 Mdot
.5848 .87295 Mdot
.5651 .01208 Mdot
.57726 .46705 Mdot
.41797 .69117 Mdot
.62499 .14627 Mdot
.50918 .82163 Mdot
.43581 .26226 Mdot
.64656 .65822 Mdot
.45913 .672 Mdot
.53956 .81049 Mdot
.63383 .24717 Mdot
.52187 .0903 Mdot
.62875 .8012 Mdot
.66718 .32474 Mdot
.64102 .25976 Mdot
.59912 .43288 Mdot
.54415 .11191 Mdot
.39779 .13371 Mdot
.44318 .90924 Mdot
.62496 .47094 Mdot
.39231 .35891 Mdot
.59502 .85737 Mdot
.55585 .84479 Mdot
.4838 .20632 Mdot
.63967 .25323 Mdot
.38452 .32342 Mdot
.5256 .35725 Mdot
.44104 .2504 Mdot
.48918 .80876 Mdot
.57995 .52348 Mdot
.54395 .92028 Mdot
.74308 .6503 Mdot
.54914 .79329 Mdot
.45918 .69321 Mdot
.45397 .06059 Mdot
.61103 .20322 Mdot
.36386 .5009 Mdot
.52379 .30669 Mdot
.41533 .07797 Mdot
.5313 .43174 Mdot
.67962 .67013 Mdot
.75353 .59369 Mdot
.67803 .69377 Mdot
.38536 .19783 Mdot
.62962 .53188 Mdot
.60763 .12838 Mdot
.3805 .35049 Mdot
.42965 .61688 Mdot
.67072 .22442 Mdot
.51908 .9562 Mdot
.38487 .781 Mdot
.42484 .72888 Mdot
.67942 .80654 Mdot
.46282 .13758 Mdot
.51248 .62434 Mdot
.50646 .64756 Mdot
.43538 .56374 Mdot
.51772 .76097 Mdot
.65504 .84589 Mdot
.41455 .20785 Mdot
.51161 .66452 Mdot
.57792 .74073 Mdot
.51847 .68666 Mdot
.53518 .56133 Mdot
.4476 .76001 Mdot
.66639 .49439 Mdot
.456 .18636 Mdot
.55357 .84799 Mdot
.49119 .24295 Mdot
.39706 .31207 Mdot
.42975 .24863 Mdot
.40268 .11478 Mdot
.53581 .45917 Mdot
.44902 .87394 Mdot
.39169 .82669 Mdot
.43232 .23542 Mdot
.70314 .48072 Mdot
.57202 .82008 Mdot
.51346 .8982 Mdot
.44739 .26881 Mdot
.55472 .67421 Mdot
.56024 .18869 Mdot
.52245 .34454 Mdot
.38344 .76416 Mdot
.66622 .20933 Mdot
.41684 .5314 Mdot
.44102 .56295 Mdot
.651 .84837 Mdot
.56509 .70499 Mdot
.41333 .5847 Mdot
.62779 .15607 Mdot
.4638 .21057 Mdot
.4624 .09801 Mdot
.66193 .53334 Mdot
.4272 .16178 Mdot
.69154 .25992 Mdot
.6188 .62404 Mdot
.49765 .92484 Mdot
.3946 .4587 Mdot
.67088 .71166 Mdot
.46355 .26608 Mdot
.61586 .22051 Mdot
.49659 .8331 Mdot
.39415 .48863 Mdot
.5014 .06776 Mdot
.44642 .66687 Mdot
.43293 .63537 Mdot
.63343 .25338 Mdot
.56097 .30481 Mdot
.43091 .28587 Mdot
.63162 .47936 Mdot
.47761 .35243 Mdot
.48637 .98629 Mdot
.70766 .53529 Mdot
.58263 .65755 Mdot
.41367 .58973 Mdot
.48797 .92729 Mdot
.43048 .42848 Mdot
.52282 .7967 Mdot
.39219 .6358 Mdot
.52226 .70762 Mdot
.61638 .61711 Mdot
.37776 .55733 Mdot
.5848 .37885 Mdot
.37877 .59713 Mdot
.62803 .45513 Mdot
.56241 .55517 Mdot
.59731 .57998 Mdot
.6311 .24086 Mdot
.5358 .3374 Mdot
.57612 .59417 Mdot
.69993 .60092 Mdot
.45598 .77561 Mdot
.55217 .79041 Mdot
.48649 .05155 Mdot
.48818 .28837 Mdot
.53126 .3319 Mdot
.6655 .32213 Mdot
.42314 .93097 Mdot
.58141 .4708 Mdot
.50215 .63529 Mdot
.56222 .63848 Mdot
.39325 .75124 Mdot
.40557 .58238 Mdot
.57193 .81253 Mdot
.75322 .59137 Mdot
.70018 .44471 Mdot
.41588 .90805 Mdot
.69826 .44498 Mdot
.46953 .33007 Mdot
.69966 .42411 Mdot
.64266 .1833 Mdot
.42756 .88774 Mdot
.39688 .83832 Mdot
.62368 .07247 Mdot
.60173 .54691 Mdot
.63046 .56213 Mdot
.4571 .10584 Mdot
.67169 .70747 Mdot
.38589 .20528 Mdot
.51876 .71909 Mdot
.70046 .59113 Mdot
.57274 .33492 Mdot
.52643 .49403 Mdot
.66428 .4805 Mdot
.39805 .58814 Mdot
.66301 .56228 Mdot
.60414 .11999 Mdot
.43276 .59318 Mdot
.42417 .81985 Mdot
.48606 .14224 Mdot
.53695 .92567 Mdot
.43571 .37748 Mdot
.36429 .46054 Mdot
.55618 .07278 Mdot
.75311 .43882 Mdot
.43379 .68007 Mdot
.58173 .73906 Mdot
.54899 .22781 Mdot
.53276 .10521 Mdot
.54813 .69636 Mdot
.52051 .59051 Mdot
.49311 .34794 Mdot
.39626 .42505 Mdot
.42007 .92896 Mdot
.62386 .23814 Mdot
.48396 .26009 Mdot
.65866 .43355 Mdot
.47665 .28444 Mdot
.43467 .55348 Mdot
.56661 .19897 Mdot
.60472 .67454 Mdot
.62534 .47442 Mdot
.59876 .43203 Mdot
.53117 .73192 Mdot
.56828 .32635 Mdot
.54415 .17359 Mdot
.43004 .37357 Mdot
.58572 .86529 Mdot
.42185 .65715 Mdot
.39265 .24792 Mdot
.60058 .27028 Mdot
.54567 .43584 Mdot
.4041 .46433 Mdot
.73588 .37472 Mdot
.40077 .86433 Mdot
.70076 .42268 Mdot
.38222 .64314 Mdot
.60393 .51485 Mdot
.44452 .16289 Mdot
.38038 .37312 Mdot
.54564 .75198 Mdot
.40262 .87114 Mdot
.75868 .46142 Mdot
.48559 .9348 Mdot
.3724 .67831 Mdot
.36566 .4113 Mdot
.41772 .06847 Mdot
.43959 .39359 Mdot
.58039 .6604 Mdot
.37674 .71279 Mdot
.47736 .99018 Mdot
.44737 .35335 Mdot
.59807 .7661 Mdot
.56298 .31685 Mdot
.57233 .75502 Mdot
.39531 .32176 Mdot
.69635 .60627 Mdot
.45752 .10225 Mdot
.68538 .37305 Mdot
.58614 .17774 Mdot
.64497 .39355 Mdot
.69436 .39125 Mdot
.64728 .3963 Mdot
.37236 .32087 Mdot
.67011 .33927 Mdot
.52028 .8433 Mdot
.47743 .68199 Mdot
.5033 .01613 Mdot
.4465 .83211 Mdot
.48501 .33439 Mdot
.36458 .43116 Mdot
.63052 .70089 Mdot
.52264 .57937 Mdot
.55955 .44728 Mdot
.51924 .2197 Mdot
.41031 .49579 Mdot
.69985 .61251 Mdot
.55519 .84997 Mdot
.66204 .21183 Mdot
.36423 .45413 Mdot
.40653 .3147 Mdot
.56112 .9654 Mdot
.42637 .212 Mdot
.5805 .51114 Mdot
.57684 .57879 Mdot
.49122 .64286 Mdot
.43533 .95964 Mdot
.40158 .86595 Mdot
.41591 .60967 Mdot
.54076 .41303 Mdot
.40919 .49948 Mdot
.48736 .23506 Mdot
.55469 .06383 Mdot
.41586 .68567 Mdot
.44396 .91183 Mdot
.54716 .55254 Mdot
.44081 .24769 Mdot
.44199 .3455 Mdot
.44535 .79169 Mdot
.42363 .227 Mdot
.4125 .41281 Mdot
.49947 .69923 Mdot
.63736 .1658 Mdot
.51096 .96055 Mdot
.48186 .37952 Mdot
.59113 .31583 Mdot
.40459 .32219 Mdot
.50147 .8669 Mdot
.57595 .35396 Mdot
.45748 .21631 Mdot
.51551 .02695 Mdot
.72223 .72016 Mdot
.48109 .09561 Mdot
.36231 .27388 Mdot
.42514 .16114 Mdot
.47069 .73002 Mdot
.66215 .71835 Mdot
.37173 .65874 Mdot
.45346 .76757 Mdot
.59879 .2685 Mdot
.54465 .43827 Mdot
.52785 .49979 Mdot
.577 .56145 Mdot
.49215 .92514 Mdot
.599 .46749 Mdot
.69951 .76635 Mdot
.53718 .49566 Mdot
.59138 .32276 Mdot
.52 .18142 Mdot
.461 .26594 Mdot
.43747 .62375 Mdot
.54958 .38567 Mdot
.47439 .99204 Mdot
.42747 .47787 Mdot
.52205 .08604 Mdot
.54756 .17215 Mdot
.40401 .73606 Mdot
.37598 .51238 Mdot
.59543 .76917 Mdot
.39632 .43878 Mdot
.75509 .60662 Mdot
.56192 .4696 Mdot
.41295 .90964 Mdot
.52183 .70754 Mdot
.70049 .42505 Mdot
.5805 .36653 Mdot
.43461 .7995 Mdot
.39007 .2654 Mdot
.40482 .25218 Mdot
.57026 .40207 Mdot
.40462 .44403 Mdot
.44276 .17117 Mdot
.69725 .26379 Mdot
.62681 .54436 Mdot
.45871 .37159 Mdot
.62387 .45056 Mdot
.60058 .527 Mdot
.43694 .4117 Mdot
.42588 .63302 Mdot
.60957 .37582 Mdot
.62907 .55052 Mdot
.47836 .70571 Mdot
.54048 .26133 Mdot
.64872 .75944 Mdot
.50824 .78322 Mdot
.40568 .74129 Mdot
.52187 .26183 Mdot
.54421 .32245 Mdot
.48322 .30889 Mdot
.41064 .02378 Mdot
.49272 .32227 Mdot
.57247 .20965 Mdot
.70119 .48197 Mdot
.43256 .89085 Mdot
.51451 .25091 Mdot
.42213 .11911 Mdot
.36842 .63472 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Booooo`;o0000YOooool00:;ooooo00?oEEEEofIV
I_l000001oooool3o`0001;ooooo0_l0002Uooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002>ooooo`;o00007?ooool3o`000;Wooooo002>ooooo`;o00007?ooool0
0ol0003oooooooooo`02ooooo`;o0000]Oooool00:cooooo00?o0000ooooooooool00_ooool2o`00
0;Gooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Wooooo`;o0000
0oooool3o`000;Wooooo002Mooooo`;o00002?ooool2o`0000?ooooo00?o0000ooooooooool0^Ooo
ool009gooooo0_l00008ooooo`;o00000oooool00ol0003oooooooooo`2iooooo`00W?ooool2o`00
00_ooooo0_l000000ooooooo0000ooooo`2jooooo`00W?ooool2o`0000_ooooo0_l000000ooooooo
0000ooooo`0@ooooo`;o0000Z?ooool00:cooooo0_l0000@ooooo`;o0000Z?ooool0093ooooo0_l0
000Jooooo`;o0000^_ooool0093ooooo0_l0000Jooooo`03o`000?oooooooooo00;o00003Oooool2
o`0001Cooooo0_l0002Booooo`00V?ooool2o`0001;ooooo1Ol0000=ooooo`;o00005?ooool2o`00
09;ooooo002@ooooo`;o00001_ooool2o`0001;ooooo00?o0000ooooooooool0^Oooool0093ooooo
0_l0000Jooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00Cooooo0_l0
002cooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o0000/oooool00:cooooo00?o0000oooo
ooooool01?ooool2o`000;?ooooo002Uooooo`;o00001Oooool00ol0003oooooooooo`04ooooo`;o
0000/oooool009oooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`2iooooo`00Wooo
ool2o`0000_ooooo0ol0002iooooo`00W_ooool2o`0000Sooooo0_l00002ooooo`03o`000?oooooo
oooo0;Wooooo002Mooooo`?o00002?ooool2o`0000;ooooo00?o0000ooooooooool01oooool2o`00
0;3ooooo002Mooooo`;o00003Oooool00ol0003oooooooooo`07ooooo`;o000000?oooooo`000?l0
0000[Oooool00:cooooo00?o0000ooooooooool02_ooool3o`000:cooooo002;ooooo`;o00007ooo
ool00ol0003oooooooooo`0;ooooo`;o0000[?ooool008Wooooo00Gok^k^oc8b<_l0003o0000onk^
kP04ooooo`;o000000?o8B4Qooooooooool01?ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2iooooo`00ROooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Cooooo0_l000000olQ8B7oooooooooo`04ooooo`03oeEEEOnYZJWooooo00Oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Oooooo`;o0000V?ooool0087ooooo1_l0
0002ooooo`05oa0@4?ooooooooooooooool@41001?ooool2o`0000Oooooo00?oZJVYoeEEEOooool0
2?ooool00ol0003oooooooooo`03ooooo`?o00007oooool2o`0009Sooooo0029ooooo`05o`000?oo
ooooooooooooool000001?ooool2o`0000Cooooo0_l00002ooooo`03ob4Q8Ooooooooooo00Kooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Pooooo`;o0000Uoooool008Wooooo00?o
0000ooooool000000_l0000:ooooo`;o00000_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Pooooo`;o0000Uoooool008Wooooo00Go
410@o`000?l0003o0000oa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`2iooooo`00ROooool01OmgMgOo0000o`000?nHV9SoMgMg00Sooooo
0_l000000ooooooo410@ooooo`02ooooo`06oc8b<_oooooo0000o`000?oooooo00002Oooool00ol0
003oooooooooo`2iooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo0_l000000ooo
oooo0000o`000003o`000004ooooool0003o0000ooooo`Co00001_ooool00ol0003oooooooooo`2i
ooooo`00R_ooool2o`0001Gooooo0_l00004ooooo`;o00000oooool00ol0003oooooooooo`2ioooo
o`00R_ooool2o`0001Gooooo0_l00004ooooo`;o00000oooool00ol0003oooooooooo`0Vooooo`;o
0000TOooool00:cooooo00?o0000ooooooooool05?ooool2o`00013ooooo0_l0002Aooooo`00[?oo
ool3o`0001Cooooo0_l0002Sooooo`00[?ooool00ol0003oooooooooo`0Wooooo`;o0000T?ooool0
0:cooooo00?o0000ooooooooool09oooool2o`00093ooooo002Cooooo`?o00005_ooool00ol0003o
ooooooooo`2iooooo`00Toooool3o`0000?ooooo0_l0000Aooooo`03o`000?oooooooooo0;Wooooo
0028ooooo`;o00003oooool2o`00017ooooo00?o0000ooooooooool0:_ooool2o`0008gooooo0028
ooooo`;o00003oooool2o`00017ooooo00?o0000ooooooooool0:_ooool2o`0008gooooo002Ioooo
o`;o00004Oooool00ol0003oooooooooo`0;ooooo`?o0000Zoooool009Wooooo0_l00006ooooo`;o
00002Oooool3o`0000_ooooo0ol0002[ooooo`00XOooool2o`0000Wooooo00?o0000ooooooooool0
6Oooool2o`0009kooooo002/ooooo`03o`000?oooooooooo00?ooooo0_l0000Dooooo`;o00004Ooo
ool2o`0008_ooooo002<ooooo`;o00003oooool2o`0000gooooo00?o0000ooooooooool00oooool2
o`0002Oooooo1?l00029ooooo`00S?ooool2o`0000oooooo0_l0000=ooooo`03o`000?oooooooooo
00Gooooo0_l00009ooooo`;o00007?ooool2o`0008Wooooo002;ooooo`;o00007oooool00ol0003o
ooooooooo`05ooooo`;o00002Oooool2o`000:Oooooo002;ooooo`;o00007oooool00ol0003ooooo
ooooo`2iooooo`00Q_ooool2o`0002Cooooo00?o0000ooooooooool0^Oooool008Kooooo0_l0000T
ooooo`?o00004oooool2o`000:Cooooo002/ooooo`03o`000?oooooooooo01?ooooo0_l0000<oooo
o`;o0000U_ooool008Kooooo0_l0000Nooooo`;o00001?ooool00ol0003oooooooooo`0Qooooo`;o
0000U_ooool008Kooooo0_l00007ooooo`;o00003oooool2o`0000Cooooo0ol00003ooooo`03o`00
0?oooooooooo01Cooooo0_l0000Mooooo`;o0000Q?ooool008oooooo0_l00002ooooo`;o00000ooo
ool2o`0000Kooooo0_l00005ooooo`;o00000oooool00ol0003oooooooooo`0Dooooo`;o00007?oo
ool3o`0008Cooooo002Cooooo`;o00000oooool2o`0000Cooooo0_l0000<ooooo`03o`000?oooooo
oooo00[ooooo0_l0000Vooooo`;o0000QOooool009kooooo0_l0000<ooooo`03o`000?oooooooooo
00?ooooo0_l00005ooooo`;o00002Oooool2o`000:;ooooo002/ooooo`03o`000?oooooooooo00?o
oooo0_l0000@ooooo`?o00002oooool2o`0009Cooooo002[ooooo`Co00005_ooool2o`0000_ooooo
0_l0000@ooooo`;o0000P_ooool009;ooooo0_l0000Gooooo`;o00003oooool2o`0002Kooooo0_l0
0022ooooo`00T_ooool2o`0001Sooooo00?o0000ooooooooool03Oooool2o`000:[ooooo002/oooo
o`03o`000?oooooooooo01Sooooo0_l0002Oooooo`00UOooool2o`00013ooooo0_l00003ooooo`03
o`000?oooooooooo01Sooooo0_l0002Oooooo`00S?ooool2o`0000Oooooo0_l0000@ooooo`;o0000
0oooool00ol0003oooooooooo`0Uooooo`;o000000?oooooo`000?l00000Soooool008cooooo0_l0
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@02ooooo`;o000000?oooooo`000?ooool09_ooool2o`000003ooooool0003o000008oo
oooo002Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00CoMgMgoc8b<_oo
oooooooo0_l000000ooooooo0000ooooo`2jooooo`00R?ooool7o`0000;ooooo00?o410@oooooooo
ool00_l00002ooooo`;o00000_ooool2o`0000Sooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Yooooo`;o0000S_ooool008Sooooo0_l00002ooooo`;o00000oooool00ol0003ooooo
ooooo`02o`0000;ooooo0_l00002ooooo`;o00001oooool00omgMgOo<S8booooo`04ooooo`?o0000
00?oooooo`000?l000009_ooool2o`0008kooooo002<ooooo`;o00000oooool01Ol0003ooooooooo
oooooooo000000;ooooo0_l00008ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool01?l0003o
ooooooooooooool2o`0002Kooooo1?l0002<ooooo`00TOooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Yooooo`Co0000S?ooool0097o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`04o`000?ooooooooooooooo`;o00001?ooool0
0ol0003oooooooooo`04ooooo`;o00001?ooool2o`0001oooooo0_l0000?ooooo`;o0000Noooool0
097ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02o`0000[ooooo1ol00003ooooo`03o`000?oooooo
oooo00Cooooo0_l00004ooooo`;o00007oooool2o`0000oooooo1?l0001iooooo`00Qoooool2o`00
00;ooooo0_l00009ooooo`;o00001oooool3o`0000Gooooo0_l00003ooooo`03o`000?oooooooooo
03kooooo0_l0001iooooo`00Qoooool2o`0000;ooooo0_l0000=ooooo`;o00000oooool3o`0000[o
oooo00?o0000ooooooooool07Oooool3o`0009Wooooo001nooooo`;o00006_ooool2o`00013ooooo
00?o0000ooooooooool07Oooool3o`0009Wooooo001nooooo`;o0000;?ooool3o`000;Wooooo002/
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Eooooo`;o
00003Oooool2o`0000Kooooo00?o0000ooooooooool0^Oooool009Gooooo0_l0000=ooooo`;o0000
0_ooool2o`0000;ooooo00?o0000ooooooooool02?ooool2o`0000gooooo0_l0002Pooooo`00Z?oo
ool2o`0000;ooooo00?o0000ooooooooool02?ooool2o`0000gooooo0_l0002Pooooo`00Woooool2
o`0000_ooooo00?o0000ooooooooool0^Oooool009oooooo0_l0000;ooooo`03o`000?oooooooooo
013ooooo0_l0002Wooooo`00[?ooool3o`00013ooooo0_l0000Nooooo`Co0000QOooool00:cooooo
00?o0000ooooooooool0<?ooool4o`0008Gooooo002/ooooo`03o`000?oooooooooo00Cooooo0_l0
000;ooooo`;o0000Y_ooool00:Kooooo0_l00004ooooo`03o`000?oooooooooo00Cooooo0_l0000;
ooooo`;o0000Y_ooool008[ooooo0_l00004ooooo`;o00005?ooool2o`0000Cooooo00?o0000oooo
ooooool0^Oooool008[ooooo0_l000001?oooooo0000o`000?ooool2o`0001[ooooo00?o0000oooo
ooooool06oooool2o`0009cooooo002=ooooo`;o00001_ooool2o`0001Gooooo00?o0000oooooooo
ool04Oooool2o`0000Sooooo0_l0002Looooo`00POooool2o`0000Kooooo0_l000000ooooooo0000
o`000007ooooo`;o00004_ooool2o`000003ooooool0003ooooo00cooooo0_l00004ooooo`;o0000
2?ooool2o`0001Kooooo0_l00024ooooo`00POooool2o`0000;ooooo0_l00002ooooo`;o000000?o
ooooo`000?l000006oooool2o`000004ooooool0003o0000o`0000;ooooo0_l00007ooooo`;o0000
3_ooool2o`0001Kooooo0ol00023ooooo`00QOooool2o`0002Gooooo00?o0000ooooooooool00_oo
ool2o`0000oooooo0_l0000Oooooo`;o0000Poooool00:;ooooo0_l00008ooooo`03o`000?oooooo
oooo00?ooooo0_l0000>ooooo`;o00007oooool2o`0008?ooooo002Rooooo`;o00000oooool2o`00
00?ooooo00?o0000ooooooooool00oooool2o`0000;ooooo0_l00004ooooo`;o0000Z_ooool00:Oo
oooo0_l00003ooooo`03o`000?oooooooooo00Oooooo0ol00003ooooo`;o00001_ooool2o`000:;o
oooo002/ooooo`03o`000?oooooooooo00Sooooo0_l0000;ooooo`;o00007_ooool2o`0008;ooooo
002/ooooo`03o`000?oooooooooo03Gooooo0_l00022ooooo`00V?ooool2o`0001;ooooo00?o0000
ooooooooool01?ooool2o`000;?ooooo002Hooooo`;o00003oooool2o`000003ooooool0003ooooo
00Gooooo0_l0002cooooo`00Q?ooool2o`0001kooooo0_l00003ooooo`;o000000Coooooo`000?l0
003o0000^Oooool008Cooooo0_l0000Dooooo`;o00002?ooool2o`0000Kooooo00?o0000oooooooo
ool05_ooool2o`000:7ooooo0024ooooo`;o00000_ooool2o`00013ooooo0_l0000@ooooo`03o`00
0?oooooooooo00Gooooo0_l0000?ooooo`;o00004_ooool2o`0008gooooo0028ooooo`;o00005_oo
ool2o`0000[ooooo00?o0000ooooooooool01Oooool2o`0002?ooooo0_l0002=ooooo`00X?ooool2
o`0000[ooooo00?o0000ooooooooool0^Oooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo01Oooooo0_l0002Pooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo01Oooooo0_l0002Pooooo`00POooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@4006ooooo`;o00001?ooool01?nHV9So8B4Qonk^k_ooool2o`0000Kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Booooo`;o00009_ooool2o`0007gooooo0024ooooo`;o0000
0oooool01Ol0003ooooooooooooooooo000000Kooooo0_l00005ooooo`03oiRHV?lQ8B7ok^k^00;o
00001Oooool00omgMgOo<S8booooo`04ooooo`?o00004_ooool2o`0000gooooo0_l0000Gooooo`;o
00003_ooool2o`0006gooooo0029ooooo`05o`000?ooooooooooooooool000002?ooool2o`0000Co
oooo00?oMgMgofIVI_ooool00oooool01?l0003o8B4Qo`000?lb<S82o`0000Cooooo00?o0000oooo
ooooool06Oooool2o`0000Kooooo0_l0000Wooooo`?o0000K?ooool008Wooooo00Go410@oooooooo
oooooooooa0@4008ooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
ooooo`;o00001?ooool00ol0003oooooooooo`0Iooooo`;o0000<?ooool2o`0006cooooo0029oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0=ooooo`;o0000Z_ooool008Wooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo
00?o0000ooooooooool03Oooool2o`0001?ooooo0_l0002Eooooo`00[?ooool00ol0003ooooooooo
o`0Rooooo`;o00006Oooool2o`0007[ooooo002Hooooo`;o00004_ooool00ol0003oooooooooo`0/
ooooo`;o00003oooool2o`0007[ooooo002Hooooo`;o00004_ooool00ol0003oooooooooo`0/oooo
o`?o0000R_ooool00:cooooo0ol0000]ooooo`;o0000R_ooool00:cooooo00?o0000ooooooooool0
5?ooool2o`000:?ooooo002/ooooo`03o`000?oooooooooo01Cooooo0_l0002Sooooo`00[?ooool0
0ol0003oooooooooo`0>ooooo`;o0000ZOooool007oooooo0_l0000>ooooo`;o00001_ooool2o`00
01?ooooo00?o0000ooooooooool02_ooool2o`0000;ooooo0_l0000Nooooo`;o0000ROooool007oo
oooo0_l0000>ooooo`;o00001_ooool2o`0001?ooooo00?o0000ooooooooool02_ooool2o`0002;o
oooo0ol00028ooooo`00[?ooool00ol0003oooooooooo`0_ooooo`;o0000R?ooool008cooooo0_l0
000Nooooo`03o`000?oooooooooo00;o0000?Oooool2o`0007Sooooo0023ooooo`;o00001?ooool2
o`000003ooooool0003o000001kooooo1Ol0000Sooooo`;o00005oooool3o`0007Sooooo0023oooo
o`;o00001?ooool2o`0000[ooooo0_l0000Eooooo`03o`000?oooooooooo02Gooooo0_l0000Goooo
o`?o0000N?ooool007oooooo0_l0000@ooooo`;o00000_ooool2o`0001Gooooo00?o0000oooooooo
ool01oooool2o`000;3ooooo001oooooo`;o00004?ooool2o`0001Wooooo00?o0000ooooooooool0
1oooool2o`0001Cooooo0_l0000Booooo`;o0000Q_ooool00:cooooo00?o0000ooooooooool03?oo
ool2o`0000oooooo0_l0000Booooo`;o0000Q_ooool008Wooooo0_l0000Qooooo`03o`000?oooooo
oooo00_ooooo0ol00012ooooo`;o0000Ioooool008Kooooo0_l000000ooooooo0000o`00000Qoooo
o`03o`000?oooooooooo00_ooooo0_l00013ooooo`;o0000Ioooool008Kooooo0_l00004ooooo`;o
00007_ooool00ol0003oooooooooo`0nooooo`?o0000N?ooool008cooooo0_l0000Nooooo`03o`00
0?oooooooooo013ooooo0_l0000/ooooo`?o0000N?ooool008Wooooo0_l0000Qooooo`?o00004?oo
ool2o`0001?ooooo0_l0002Booooo`00Ooooool2o`0000Sooooo0_l0000Qooooo`03o`000?oooooo
oooo01Oooooo0_l0000<ooooo`Co0000T?ooool007oooooo0_l00008ooooo`;o00008Oooool00ol0
003oooooooooo`0Gooooo`;o00003_ooool2o`00093ooooo0009ooooo`Co000000?o410@oooooooo
ool05_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo
00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00_ooool2o`000003oooooolQ8B7o8B4Q00Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b
<_oMgMd05_ooool00ol0003oooooooooo`08ooooo`;o00003_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q00?oooooo`000?l000000_ooool01Om4A4Co0000
o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0
003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd06?ooool4o`000003oa0@4?oooooo
oooo01;ooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00_ooool2o`000003oooooolQ8B7o8B4Q00Cooooo00CoV9RHob4Q8Oo^k^ko
oooo0_l00002ooooo`;o00000_ooool00omgMgOo<S8booooo`0Eooooo`03o`000?oooooooooo00So
oooo0_l0000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q
8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q00?oooooo`000?l000001Oooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8b
ooooo`0Iooooo`03o`000?oooooooooo01Cooooo0006o`0000Gooooo00?o0000ooooooooool04?oo
ool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo
00?o0000ooooooooool01Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03
o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onH
V9So8B4Qonk^kP02o`0000;ooooo0_l00003ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool05_ooool2o`000005oa0@4?ooooooooooooooool@41000_l0000:ooooo`03oiRHV?lQ8B7o
k^k^00Wooooo00?o0000ooooooooool03Oooool01Ol@413ooooooooooooooooo410@013ooooo00?o
0000ooooooooool03Oooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool0
2?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oo
oooooooo01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo
00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_oo
ool03_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omg
MgOo<S8booooo`0Eooooo`03o`000?oooooooooo017ooooo0_l00003ooooo`?o00000oooool3o`00
00Oooooo0_l00002ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool02Oooool2o`00
00?ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool06Ooo
ool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05o`000?oooooo
ooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
3oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?oooo
o`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`05_ooool00ol0003oooooooooo`0Aooooo`;o00001?ooool2o`0000?ooooo00?o
0000ooooooooool01oooool2o`0000?ooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00[ooooo0_l00003ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<co
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Jooooo`03o`000?oooooooooo01Cooooo000;
ooooo`03o`000?oooooooooo01Sooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmg
MgOooooo00?ooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00cooooo
00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Hooooo`?o00006?ooool01Ol@413ooooooooooooooooo410@
00Wooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04Oooool01Ol@
413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooo
oooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`0Aooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool00_l0000F
ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`09ooooo`Co000000?o
oooooiRHV?l@41001?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413o
oooooooooooooooo<S8b00Cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Doooo
o`002Oooool00omEEEGoIVIVo`00000Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`00
00Cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00013ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool5o`0001Kooooo
00?o0000ooooooooool06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo0ol000000olQ8B7o
c<c<ooooo`03ooooo`Co00002_ooool3o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00006Oooool0
0omEEEGoIVIVo`00000Fooooo`00[?ooool00ol0003oooooooooo`0cooooo`;o00002_ooool3o`00
07Oooooo0029ooooo`;o00008Oooool00ol0003oooooooooo`0Wooooo`;o0000T?ooool008Wooooo
0_l0000Qooooo`03o`000?oooooooooo02Oooooo0_l00025ooooo`;o00000_ooool2o`0000Gooooo
002/ooooo`03o`000?oooooooooo00Gooooo0_l0000/ooooo`;o0000NOooool01_o^k^ko8B4QohN7
Qonj^[[o0000omgMg@Gooooo002>ooooo`;o00007?ooool00ol0003oooooooooo`05ooooo`;o0000
0_ooool2o`0002Sooooo0_l0001jooooo`04omgMgOl0003o410@olc<c0Kooooo0007oooooooo0000
C?l0000<ooooo`04onk^k_lQ8B7o410@onk^kPKooooo0007ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool01?l0003oooooooooooooool2o`0000;ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`02o`0000Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool2o`0000Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02_ooool01?lQ8B7oMgMgogMgMolb<S86ooooo`001oooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02Oooool2o`0000;o
oooo0_l00005ooooo`00[?ooool00ol0003oooooooooo`0Nooooo`;o0000VOooool008?ooooo0_l0
000Wooooo`03o`000?oooooooooo01Oooooo0_l00005ooooo`;o0000VOooool008?ooooo0_l0000W
ooooo`03o`000?oooooooooo01Oooooo0_l00006ooooo`;o0000V?ooool00:cooooo00?o0000oooo
ooooool07oooool2o`0009Sooooo002/ooooo`03o`000?oooooooooo017ooooo0_l0002Vooooo`00
[?ooool3o`0000gooooo0_l00002ooooo`;o00001?ooool2o`000:3ooooo002/ooooo`03o`000?oo
oooooooo00gooooo0_l00008ooooo`;o00001Oooool2o`0009Wooooo002@ooooo`;o00006_ooool0
0ol0003oooooooooo`0Nooooo`;o0000VOooool0093ooooo0_l0000Jooooo`03o`000?oooooooooo
02Oooooo0_l00008ooooo`?o0000QOooool00:cooooo00?o0000ooooooooool09oooool2o`0000So
oooo0ol0000=ooooo`;o0000M_ooool00:cooooo00?o0000ooooooooool0@Oooool2o`0007Kooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo01kooooo0_l00006
ooooo`;o0000TOooool00:cooooo00?o0000ooooooooool07_ooool2o`0000Kooooo0_l0002Aoooo
o`00[?ooool3o`0000cooooo0_l00003ooooo`;o00005?ooool2o`00093ooooo002Fooooo`;o0000
5?ooool00ol0003oooooooooo`0<ooooo`;o00000oooool2o`0001Cooooo0_l0002@ooooo`00Pooo
ool2o`00017ooooo0_l0000Dooooo`03o`000?oooooooooo017ooooo0_l0002Vooooo`00Poooool2
o`0002Oooooo00?o0000ooooooooool02?ooool2o`0000cooooo0_l0000?ooooo`;o0000T?ooool0
08?ooooo0_l0000Aooooo`Co00004_ooool00ol0003oooooooooo`08ooooo`;o00003?ooool2o`00
00oooooo0ol00008ooooo`;o0000QOooool008?ooooo0_l0000Aooooo`Co00004_ooool00ol0003o
ooooooooo`0@ooooo`;o00005_ooool2o`0000Sooooo0_l00025ooooo`00[?ooool00ol0003ooooo
ooooo`0@ooooo`;o0000Yoooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol00010
ooooo`;o0000Moooool00:cooooo00?o0000ooooooooool01?ooool2o`00013ooooo0_l00005oooo
o`;o00008?ooool3o`0007Oooooo002<ooooo`;o00007_ooool00ol0003oooooooooo`04ooooo`;o
00004?ooool2o`0000Gooooo0_l0000Pooooo`;o0000N?ooool008cooooo0_l000000ooooooo0000
o`00000Kooooo`03o`000?oooooooooo0;Wooooo002:ooooo`;o00000oooool2o`0001_ooooo00?o
0000ooooooooool0<_ooool2o`0000cooooo0_l0001gooooo`00R_ooool2o`0000?ooooo0_l0000K
ooooo`03o`000?oooooooooo00?ooooo0_l0000]ooooo`;o00002oooool3o`0000kooooo0_l0001W
ooooo`00Soooool2o`0000Cooooo0_l0000Eooooo`03o`000?oooooooooo00?ooooo0_l0000Aoooo
o`;o00006_ooool2o`0000_ooooo0_l0000?ooooo`;o0000Ioooool008Cooooo0_l0000?ooooo`;o
00005Oooool00ol0003oooooooooo`0Fooooo`;o00006_ooool2o`0001cooooo0_l0001Wooooo`00
Q?ooool2o`0002Kooooo0ol0000oooooo`;o0000N?ooool00:cooooo00?o0000ooooooooool0?ooo
ool2o`0000oooooo0_l0001Wooooo`00[?ooool00ol0003oooooooooo`0Looooo`;o00007oooool2
o`00017ooooo0ol0001Vooooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool07?ooool2o`00
01oooooo0_l0000Booooo`;o0000I_ooool0093ooooo0_l0000Jooooo`03o`000?oooooooooo037o
oooo0_l0000<ooooo`;o0000N?ooool00:cooooo00?o0000ooooooooool0;oooool4o`0000cooooo
0_l0001hooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o8B4Qo`000?l00000
0oooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo02?o
oooo0_l0000:ooooo`;o0000R?ooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03
ob4Q8Ol0003o000000?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool08oooool2o`0009Cooooo0029ooooo`05oa0@4?oooooooooooooo
ool@41002Oooool2o`000004oooooonHV9So8B4Qonk^kPWooooo00?o0000ooooooooool00oooool3
o`000003ooooool0003o000000Gooooo0_l0000Jooooo`;o0000Toooool008Wooooo00Go0000oooo
ooooooooooooo`000009ooooo`Co000000?oV9RHob4Q8Oo^k^h01oooool01?mgMgOo<S8bo`000?l0
0003ooooo`04o`000?ooooooooooooooo`;o00001Oooool2o`0001[ooooo0_l0002Cooooo`00ROoo
ool01Ol0003ooooooooooooooooo000000_ooooo0_l000000oooooooMgMgofIVIP04ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`00_l00003ooooo`03o`000?oooooooooo0;Wooooo0020ooooo`;o0000
1oooool01Ol@413ooooooooooooooooo410@00Gooooo0_l00008ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2iooooo`00P?ooool2o`0000Kooooo
0_l000001?nHV9SooooooiRHV?mgMgL5ooooo`Co00000_ooool01Ol0003o^[ZjoooooonHV9So410@
00Cooooo00?o0000ooooooooool01oooool2o`000;[ooooo0028ooooo`;o000000Co<S8bo`000?lb
<S;ok^k^0_l00005ooooo`;o00000_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006
ooooo`;o00004_ooool2o`000:Kooooo0025ooooo`;o00001oooool2o`0001Wooooo0_l000000ooo
oooo0000ooooo`0Booooo`;o0000Y_ooool0087ooooo0_l00002ooooo`;o00008_ooool2o`000003
ooooool0003ooooo02oooooo0_l00029ooooo`00POooool2o`0001Gooooo0_l0000Booooo`04o`00
0?oooooo0000o`0000_ooooo0_l0000Pooooo`;o0000ROooool009Sooooo0_l0000Booooo`Co0000
2oooool2o`0003oooooo0_l0001Zooooo`00[?ooool00ol0003oooooooooo`1=ooooo`;o0000J_oo
ool0087ooooo0_l0000?ooooo`;o00006?ooool00ol0003oooooooooo`0Hooooo`;o00004oooool2
o`0008[ooooo0021ooooo`;o00003oooool2o`0001Sooooo00?o0000ooooooooool05oooool3o`00
01?ooooo0_l0002:ooooo`00[?ooool00ol0003oooooooooo`02o`0001Gooooo0_l0002Pooooo`00
V_ooool2o`00013ooooo00?o0000ooooooooool00_l0002gooooo`00V_ooool2o`00013ooooo00?o
0000ooooooooool0>?ooool2o`0007oooooo002Nooooo`;o00003?ooool00ol0003oooooooooo`0Y
ooooo`;o00003Oooool2o`00017ooooo0_l0001/ooooo`00SOooool2o`0000oooooo0_l0000<oooo
o`?o00002?ooool2o`0000Gooooo0_l0000>ooooo`;o00002?ooool2o`00023ooooo0_l0001/oooo
o`00POooool2o`0000[ooooo0_l00007ooooo`;o00005?ooool00ol0003oooooooooo`08ooooo`;o
00001Oooool2o`0000kooooo0_l0002Hooooo`00POooool2o`0001?ooooo0_l0000<ooooo`;o0000
1_ooool00ol0003oooooooooo`2iooooo`00SOooool2o`000003ooooool0003o000001;ooooo0_l0
0006ooooo`03o`000?oooooooooo03Oooooo0_l00020ooooo`00SOooool2o`000003ooooool0003o
000001[ooooo00?o0000ooooooooool00oooool2o`0003;ooooo0_l00020ooooo`00ROooool2o`00
00Gooooo0_l0000Jooooo`03o`000?oooooooooo00;ooooo0ol0002dooooo`00ROooool2o`0000;o
oooo0_l000000ooooooo0000o`00000<ooooo`;o00003?ooool00ol0003oooooooooo`02ooooo`;o
00006Oooool2o`0000[ooooo0_l0000;ooooo`?o0000P?ooool008gooooo0_l0000?ooooo`;o0000
3?ooool00ol0003oooooooooo`0<ooooo`;o00003oooool2o`0000Wooooo0ol0000;ooooo`?o0000
P?ooool00:_ooooo1?l0000<ooooo`;o00006_ooool2o`0000cooooo0_l00021ooooo`00Zoooool2
o`0002[ooooo0_l0002?ooooo`00Y?ooool2o`0000Kooooo00?o0000ooooooooool00_l0000@oooo
o`;o00008Oooool2o`0008;ooooo0022ooooo`;o00008?ooool2o`0000Kooooo00?o0000oooooooo
ool00_l00002ooooo`;o00003?ooool2o`00027ooooo0_l00022ooooo`00P_ooool3o`0002Oooooo
00?o0000ooooooooool01?ooool2o`0002oooooo0_l00022ooooo`00Poooool2o`0002Oooooo00?o
0000ooooooooool01?ooool2o`0002oooooo0_l0000>ooooo`;o0000L_ooool00:cooooo00?o0000
ooooooooool00oooool3o`0002cooooo0_l0000Aooooo`;o0000L_ooool00:cooooo00?o0000oooo
ooooool00oooool2o`0002gooooo0_l0000Booooo`;o0000LOooool008?ooooo0_l0000Wooooo`?o
00006Oooool2o`0002_ooooo0_l0001aooooo`00Poooool2o`0000?ooooo0_l0000Rooooo`03o`00
0?oooooooooo01Wooooo0_l0002Nooooo`00R?ooool2o`0000Wooooo0_l0000=ooooo`;o00002?oo
ool00ol0003oooooooooo`2iooooo`00Toooool2o`0000gooooo0_l00008ooooo`04o`000?oooooo
ooooooooo`;o00001?ooool2o`000;3ooooo002<ooooo`;o00007_ooool01?l0003ooooooooooooo
ool2o`0000Cooooo0_l0002`ooooo`00S?ooool2o`0001kooooo00?o0000ooooooooool05_ooool4
o`0009oooooo002<ooooo`;o00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Fooooo`Co0000Wooo
ool008cooooo0_l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2iooooo`00TOooool01Ol@413ooooooooooooo
oooo410@013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2iooooo`00R?ooool2
o`0000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMol0003o000000Cooooo0ol0
000<ooooo`;o0000Zoooool008Sooooo0_l00007ooooo`05o`000?ooooooooooooooool000003?oo
ool01?l0003o8B4Qo`000?lb<S82o`0000Cooooo00?o0000ooooooooool03?ooool2o`0000Kooooo
0_l0000Iooooo`;o0000R?ooool0097ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool05?ooool2o`0001Wooooo0_l00028ooooo`00TOoo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo0_l00006ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool00_ooool2o`0002[ooooo0_l00029ooooo`00QOooool2o`0000[ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP04ooooo`;o00001_ooool4o`0000Kooooo00?o0000ooooooooool0
0_ooool2o`0002[ooooo0_l00029ooooo`00QOooool2o`0001Gooooo0_l0000>ooooo`03o`000?oo
oooooooo01gooooo0_l0000Oooooo`;o0000NOooool009cooooo0_l0000>ooooo`03o`000?oooooo
oooo01cooooo0ol0000Oooooo`;o0000NOooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo
01cooooo0_l0002Kooooo`00Toooool2o`0000;ooooo0_l00004ooooo`;o00003Oooool3o`000;Wo
oooo002Cooooo`;o00002?ooool2o`0000gooooo00?o0000ooooooooool0^Oooool008Kooooo0_l0
000Hooooo`;o00002_ooool01?l0003oooooo`000?l0002hooooo`00Q_ooool2o`0001Sooooo0_l0
000:ooooo`04o`000?oooooo0000o`000;Sooooo0026ooooo`;o00001oooool2o`0001_ooooo00?o
0000ooooooooool0^Oooool008oooooo0_l00009ooooo`;o00004?ooool00ol0003oooooooooo`0>
ooooo`;o0000ZOooool009[ooooo0_l0000@ooooo`03o`000?oooooooooo00gooooo0ol0002Yoooo
o`00[?ooool2o`0000Gooooo0_l00007ooooo`;o0000Z_ooool009Kooooo0_l0000Dooooo`?o0000
1?ooool2o`0001;ooooo0_l0000=ooooo`;o0000T?ooool009Kooooo0_l0000Dooooo`03o`000?oo
oooooooo01Sooooo0_l0000<ooooo`?o0000T?ooool00:cooooo00?o0000ooooooooool09_ooool2
o`00013ooooo0_l0001oooooo`00Z?ooool2o`0000;ooooo00?o0000ooooooooool02_ooool2o`00
01[ooooo0_l0000@ooooo`;o0000Ooooool009Oooooo0_l0000?ooooo`;o00000_ooool00ol0003o
ooooooooo`0:ooooo`;o00002?ooool2o`00013ooooo0_l0002Aooooo`00Uoooool2o`0000kooooo
0_l00003ooooo`03o`000?oooooooooo01Cooooo0_l0002Sooooo`00Yoooool2o`0000?ooooo00?o
0000ooooooooool0^Oooool009?ooooo0_l0000Gooooo`03o`000?oooooooooo00;o00004_ooool2
o`000:?ooooo002Cooooo`;o00005oooool5o`0001;ooooo0_l0002Sooooo`00R?ooool2o`0002;o
oooo00?o0000ooooooooool0^Oooool008Sooooo0_l0000Rooooo`03o`000?oooooooooo0;Wooooo
002Jooooo`;o00003_ooool3o`000;_ooooo002Jooooo`;o00003_ooool3o`000;_ooooo002:oooo
o`;o00008?ooool00ol0003oooooooooo`2iooooo`00R_ooool2o`00023ooooo00?o0000oooooooo
ool00oooool2o`000;Cooooo0029ooooo`;o00008Oooool00ol0003oooooooooo`03ooooo`;o0000
2_ooool2o`0001oooooo0_l00027ooooo`00ROooool2o`0001gooooo0_l00002ooooo`03o`000?oo
oooooooo00kooooo0ol0000Mooooo`Co0000Qoooool00:Sooooo0_l00002ooooo`?o00003_ooool3
o`0001gooooo0_l00029ooooo`00[?ooool00ol0003oooooooooo`0<ooooo`;o000000?oooooo`00
0?l00000Z?ooool00:cooooo00?o0000ooooooooool03?ooool2o`0000kooooo0_l0002Kooooo`00
[?ooool00ol0003oooooooooo`0Looooo`;o0000Voooool008_ooooo0_l0000Oooooo`03o`000?oo
oooooooo0;Wooooo0029ooooo`05onk^k_lb<S;o0000o`000?o^k^h01Oooool2ob4Q8@Kooooo00?o
0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo0_l0000Jooooo`;o0000
W_ooool008Wooooo00GoMgMgoiRHV?l0003o0000ogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVY
ooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo0_l0000Jooooo`;o0000W_ooool008Wooooo00Go
410@ooooool0003o0000oa0@400=ooooo`;o00002Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo01Wooooo0_l0002Nooooo`00ROooool00ol0003oooooo`000002o`0000gooooo0_l0
0008ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Iooooo`;o0000W_ooool008Wooooo00Go0000
ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05oa0@4?ooooooooooooooool@4100
3_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
^Oooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb
<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01_ooool2o`0000?ooooo1Ol00004ooooo`Co00001_ooool00ol0003o
ooooooooo`2iooooo`00U?ooool3o`0001Gooooo00?o0000ooooooooool0^Oooool009Gooooo0_l0
000Eooooo`03o`000?oooooooooo017ooooo0_l0002Vooooo`00[?ooool01?l0003ooooooooooooo
ool2o`0000kooooo0_l0002Vooooo`00[?ooool3o`000003ooooool0003o00000;Kooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002?ooooo`?o0000
1oooool2o`00017ooooo00?o0000ooooooooool0^Oooool008oooooo0ol00007ooooo`;o00004Ooo
ool00ol0003oooooooooo`2iooooo`00VOooool2o`00017ooooo00?o0000ooooooooool03_ooool2
o`000:Wooooo002/ooooo`03o`000?oooooooooo00cooooo1?l0002Yooooo`00[?ooool00ol0003o
ooooooooo`0;ooooo`?o0000Zoooool00:Wooooo1_l0000;ooooo`;o0000[?ooool00:Sooooo1Ol0
000;ooooo`;o0000[_ooool0097ooooo0ol0000Dooooo`;o00000_ooool00ol0003oooooooooo`09
ooooo`;o0000[_ooool0097ooooo0ol0000Hooooo`03o`000?oooooooooo0;Wooooo002Wooooo`;o
00000oooool00ol0003oooooooooo`2iooooo`00Yoooool2o`0000?ooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool00ol0003oooooooooo`03ooooo`;o0000]?ooool009Kooooo0_l0000D
ooooo`03o`000?oooooooooo00;o000000?oooooo`000?l00000]?ooool009Kooooo0_l0000Doooo
o`03o`000?oooooo000000;o0000]oooool00:cooooo00Co0000ooooool0003o00004?ooool2o`00
0:Kooooo002/ooooo`03o`000?oooooooooo017ooooo0_l0002Vooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Oooooo`;o0000
1_ooool2o`0000?ooooo00?o0000ooooooooool0^Oooool009oooooo0_l00002ooooo`?o000000?o
ooooo`000?l000000oooool00ol0003oooooooooo`2iooooo`00X_ooool4o`000003oa0@4?oooooo
oooo00?ooooo00?o0000ooooooooool0^Oooool00:?ooooo0_l00007ooooo`03o`000?oooooooooo
0;Wooooo002Tooooo`03o`000?oooooooooo00Gooooo0ol0002iooooo`00Y?ooool00ol0003ooooo
ooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31
ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00X_ooool00omEEEGoIVIVo`000033ooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Z_ooool01?l@413o
0000o`000?l0002jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooo
ooooo`2jooooo`00Zoooool01_l0003oMgMgo`000?l0003oEEEEonk^k[Oooooo002[ooooo`06o`00
0?mEEEGok^k^oooooomgMgOoEEEE]oooool00:_ooooo00?o0000onk^k_ooool00_ooool00ol0003o
ooooooooo`2eooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo0;Gooooo
002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoIVIV]oooool00:[ooooo00?o410@o`000?mgMgL0
0_l000000omVIVKok^k^ooooo`2fooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.48163 .89673 Mdot
.43285 .13491 Mdot
.50303 .44531 Mdot
.55142 .50473 Mdot
.57885 .59585 Mdot
.63518 .49526 Mdot
.45323 .35643 Mdot
.63718 .80455 Mdot
.71087 .49294 Mdot
.54347 .35455 Mdot
.55275 .62665 Mdot
.57456 .89388 Mdot
.65825 .39324 Mdot
.56793 .5338 Mdot
.55978 .90586 Mdot
.44426 .72589 Mdot
.53106 .78542 Mdot
.66279 .41271 Mdot
.47396 .19628 Mdot
.42314 .88618 Mdot
.65978 .41592 Mdot
.54201 .15888 Mdot
.57477 .21295 Mdot
.66755 .44617 Mdot
.41995 .92844 Mdot
.44472 .19192 Mdot
.50689 .75013 Mdot
.44804 .22535 Mdot
.38939 .73821 Mdot
.44177 .11906 Mdot
.66467 .47275 Mdot
.71329 .49752 Mdot
.67479 .71926 Mdot
.41017 .71002 Mdot
.4558 .14049 Mdot
.54437 .86661 Mdot
.55975 .12677 Mdot
.40923 .51297 Mdot
.37554 .55279 Mdot
.54376 .93556 Mdot
.41065 .90695 Mdot
.40058 .35063 Mdot
.58351 .28779 Mdot
.43325 .85794 Mdot
.53438 .83413 Mdot
.4729 .82591 Mdot
.56506 .4771 Mdot
.69881 .38905 Mdot
.59821 .40528 Mdot
.40436 .81518 Mdot
.69449 .3769 Mdot
.40618 .16504 Mdot
.66153 .84694 Mdot
.52686 .18688 Mdot
.55238 .2239 Mdot
.70566 .60251 Mdot
.62874 .81698 Mdot
.53274 .78455 Mdot
.65263 .2695 Mdot
.5567 .79721 Mdot
.44706 .80113 Mdot
.55752 .06117 Mdot
.37522 .51837 Mdot
.45668 .72437 Mdot
.6792 .69429 Mdot
.71298 .55427 Mdot
.53146 .32122 Mdot
.47917 .7589 Mdot
.40928 .45421 Mdot
.67063 .49252 Mdot
.48152 .86089 Mdot
.5094 .61456 Mdot
.54556 .36555 Mdot
.47775 .22753 Mdot
.37526 .52102 Mdot
.44693 .57557 Mdot
.66107 .84758 Mdot
.40594 .60131 Mdot
.38417 .29761 Mdot
.5643 .31039 Mdot
.64792 .6532 Mdot
.42809 .15095 Mdot
.54371 .42336 Mdot
.41002 .2764 Mdot
.67919 .71539 Mdot
.42522 .65151 Mdot
.57389 .6215 Mdot
.54919 .69656 Mdot
.5611 .72911 Mdot
.4718 .75909 Mdot
.41337 .90933 Mdot
.76659 .51614 Mdot
.43065 .35489 Mdot
.5198 .76774 Mdot
.42076 .50003 Mdot
.76616 .47283 Mdot
.56842 .51433 Mdot
.6923 .37933 Mdot
.64406 .87331 Mdot
.55203 .75244 Mdot
.43986 .86677 Mdot
.59032 .64981 Mdot
.58065 .88287 Mdot
.40434 .7524 Mdot
.66286 .59867 Mdot
.39807 .6042 Mdot
.45145 .84606 Mdot
.52159 .25483 Mdot
.4326 .34316 Mdot
.66982 .49717 Mdot
.56454 .4472 Mdot
.55206 .48957 Mdot
.7121 .48602 Mdot
.51048 .91744 Mdot
.37255 .81498 Mdot
.51547 .62858 Mdot
.41973 .71298 Mdot
.70978 .60756 Mdot
.7148 .56019 Mdot
.53532 .10041 Mdot
.6561 .38777 Mdot
.63246 .33223 Mdot
.38227 .68114 Mdot
.67048 .50018 Mdot
.54756 .56547 Mdot
.47934 .94393 Mdot
.75465 .40362 Mdot
.3856 .52433 Mdot
.43286 .60075 Mdot
.57835 .21553 Mdot
.40127 .72722 Mdot
.53015 .94773 Mdot
.63686 .5251 Mdot
.61126 .36046 Mdot
.37453 .43193 Mdot
.5423 .1006 Mdot
.42196 .87952 Mdot
.5407 .35018 Mdot
.65276 .76479 Mdot
.54664 .92388 Mdot
.64804 .17875 Mdot
.5191 .32286 Mdot
.42701 .28915 Mdot
.5293 .78911 Mdot
.46348 .94491 Mdot
.69398 .67295 Mdot
.36744 .20971 Mdot
.52408 .26705 Mdot
.5304 .74226 Mdot
.44559 .00471 Mdot
.59783 .62163 Mdot
.43158 .72253 Mdot
.66984 .45822 Mdot
.51795 .56454 Mdot
.62375 .61049 Mdot
.4927 .04835 Mdot
.37795 .38237 Mdot
.70923 .6012 Mdot
.55708 .12474 Mdot
.50492 .05976 Mdot
.53227 .23288 Mdot
.38596 .2793 Mdot
.41174 .91636 Mdot
.59389 .7852 Mdot
.57334 .27094 Mdot
.46209 .89157 Mdot
.69797 .65737 Mdot
.65376 .64479 Mdot
.40898 .52511 Mdot
.50097 .05323 Mdot
.45603 .93327 Mdot
.44154 .31003 Mdot
.42786 .70229 Mdot
.57418 .6126 Mdot
.54934 .32348 Mdot
.67206 .72028 Mdot
.7632 .4503 Mdot
.62646 .59329 Mdot
.52403 .5762 Mdot
.38362 .68688 Mdot
.45388 .04978 Mdot
.49924 .98505 Mdot
.42817 .32736 Mdot
.39578 .85183 Mdot
.46664 .28307 Mdot
.70767 .47013 Mdot
.751 .39369 Mdot
.71554 .49377 Mdot
.42843 .95678 Mdot
.60237 .33188 Mdot
.42485 .044 Mdot
.4628 .94496 Mdot
.51043 .67851 Mdot
.52049 .02442 Mdot
.66156 .7562 Mdot
.36279 .55342 Mdot
.55945 .91169 Mdot
.53874 .72689 Mdot
.76203 .60654 Mdot
.39851 .63159 Mdot
.52221 .42434 Mdot
.52549 .44756 Mdot
.49749 .65918 Mdot
.58211 .56097 Mdot
.75339 .64589 Mdot
.4243 .82714 Mdot
.53741 .46452 Mdot
.63421 .54073 Mdot
.55313 .48666 Mdot
.51971 .36133 Mdot
.54493 .65869 Mdot
.62415 .29439 Mdot
.41064 .65081 Mdot
.65277 .64799 Mdot
.41538 .48492 Mdot
.45083 .88097 Mdot
.42991 .75195 Mdot
.40655 .89912 Mdot
.48005 .27759 Mdot
.58259 .74132 Mdot
.57037 .9033 Mdot
.42647 .74358 Mdot
.65543 .28072 Mdot
.66005 .62008 Mdot
.63274 .6982 Mdot
.4305 .67058 Mdot
.5844 .47421 Mdot
.41204 .19939 Mdot
.43714 .3255 Mdot
.55542 .91174 Mdot
.50995 .00933 Mdot
.49444 .74716 Mdot
.4961 .63475 Mdot
.75035 .64837 Mdot
.60709 .50499 Mdot
.50685 .75278 Mdot
.45169 .0023 Mdot
.41424 .6115 Mdot
.38997 .64198 Mdot
.63526 .33334 Mdot
.4115 .78189 Mdot
.55551 .05992 Mdot
.62841 .42404 Mdot
.62764 .72497 Mdot
.48338 .85998 Mdot
.71555 .51166 Mdot
.42641 .60061 Mdot
.46478 .04791 Mdot
.58997 .63346 Mdot
.49001 .85546 Mdot
.37493 .47825 Mdot
.36662 .63469 Mdot
.51874 .61377 Mdot
.51393 .66518 Mdot
.49478 .05399 Mdot
.44742 .18959 Mdot
.43779 .73881 Mdot
.58337 .27936 Mdot
.44222 .52053 Mdot
.64239 .79013 Mdot
.68177 .33529 Mdot
.60565 .45755 Mdot
.50788 .75078 Mdot
.62021 .7307 Mdot
.46902 .70985 Mdot
.6015 .5967 Mdot
.52287 .84671 Mdot
.56531 .50762 Mdot
.62323 .41711 Mdot
.50856 .91391 Mdot
.49634 .17927 Mdot
.51712 .90624 Mdot
.57008 .25513 Mdot
.54448 .35517 Mdot
.5893 .37998 Mdot
.48748 .04432 Mdot
.44097 .2729 Mdot
.57379 .39417 Mdot
.7003 .40092 Mdot
.55 .64386 Mdot
.62833 .59041 Mdot
.37461 .54687 Mdot
.42595 .48823 Mdot
.43724 .29143 Mdot
.55436 .12213 Mdot
.59926 .85744 Mdot
.52973 .2708 Mdot
.51627 .43529 Mdot
.57761 .43848 Mdot
.55027 .86607 Mdot
.50802 .78752 Mdot
.65694 .61253 Mdot
.74977 .39137 Mdot
.63807 .24471 Mdot
.59184 .8634 Mdot
.63626 .24498 Mdot
.43909 .56065 Mdot
.6293 .22411 Mdot
.5854 .81218 Mdot
.57281 .88882 Mdot
.58049 .34691 Mdot
.61531 .36213 Mdot
.39282 .66344 Mdot
.71468 .50747 Mdot
.42994 .95283 Mdot
.5664 .51909 Mdot
.69691 .39113 Mdot
.46773 .16618 Mdot
.48441 .30715 Mdot
.61648 .2805 Mdot
.51093 .82059 Mdot
.64793 .36228 Mdot
.41942 .05361 Mdot
.50449 .66544 Mdot
.56446 .77752 Mdot
.3945 .52911 Mdot
.66722 .72567 Mdot
.45675 .69804 Mdot
.49034 .99192 Mdot
.37979 .23564 Mdot
.68864 .23882 Mdot
.5245 .67143 Mdot
.63735 .53906 Mdot
.41727 .23745 Mdot
.38215 .33063 Mdot
.58668 .49636 Mdot
.51672 .39051 Mdot
.43789 .45383 Mdot
.47567 .86 Mdot
.59851 .86516 Mdot
.47926 .04771 Mdot
.42069 .51279 Mdot
.59209 .23355 Mdot
.42758 .53945 Mdot
.4954 .66452 Mdot
.41852 .17453 Mdot
.63453 .47454 Mdot
.57511 .27442 Mdot
.53158 .23203 Mdot
.58394 .53192 Mdot
.6895 .80311 Mdot
.46068 .17315 Mdot
.40122 .26694 Mdot
.45713 .72364 Mdot
.69184 .66529 Mdot
.5214 .7175 Mdot
.43778 .91409 Mdot
.46929 .09355 Mdot
.48044 .25161 Mdot
.48255 .8173 Mdot
.64576 .17472 Mdot
.57971 .88825 Mdot
.62983 .22268 Mdot
.52671 .89172 Mdot
.56987 .31485 Mdot
.408 .70599 Mdot
.46777 .94058 Mdot
.60643 .55198 Mdot
.58149 .8854 Mdot
.70324 .26142 Mdot
.62138 .73961 Mdot
.53693 .93922 Mdot
.47929 .99657 Mdot
.39318 .84345 Mdot
.45943 .67762 Mdot
.60455 .4604 Mdot
.54415 .92628 Mdot
.63747 .80069 Mdot
.44896 .65237 Mdot
.66451 .5661 Mdot
.45299 .18482 Mdot
.63433 .55502 Mdot
.45333 .88649 Mdot
.69886 .40627 Mdot
.39195 .66236 Mdot
.5946 .17305 Mdot
.42487 .10984 Mdot
.5624 .19355 Mdot
.61086 .19125 Mdot
.5658 .1963 Mdot
.4581 .9869 Mdot
.35132 .58085 Mdot
.56582 .13927 Mdot
.6176 .6433 Mdot
.52061 .51115 Mdot
.36329 .48108 Mdot
.56807 .71443 Mdot
.43668 .49214 Mdot
.48386 .99703 Mdot
.67088 .50089 Mdot
.51438 .37937 Mdot
.49846 .24737 Mdot
.40705 .36594 Mdot
.48807 .78334 Mdot
.70486 .41251 Mdot
.65518 .64997 Mdot
.50677 .01183 Mdot
.48895 .99356 Mdot
.44936 .83904 Mdot
.70728 .7654 Mdot
.42265 .77461 Mdot
.54496 .31114 Mdot
.56836 .37879 Mdot
.51053 .44858 Mdot
.6101 .84662 Mdot
.58009 .88618 Mdot
.51181 .7399 Mdot
.46785 .25545 Mdot
.48912 .78744 Mdot
.41449 .50337 Mdot
.37708 .24372 Mdot
.52949 .74987 Mdot
.59492 .78541 Mdot
.52817 .35254 Mdot
.42731 .70385 Mdot
.44841 .67754 Mdot
.55489 .68782 Mdot
.42651 .78337 Mdot
.46949 .79174 Mdot
.53916 .49925 Mdot
.65518 .76055 Mdot
.44722 .49613 Mdot
.47773 .12933 Mdot
.45141 .84587 Mdot
.60823 .6669 Mdot
.47788 .16892 Mdot
.41686 .63788 Mdot
.36407 .4246 Mdot
.77029 .52016 Mdot
.3854 .56092 Mdot
.41181 .79101 Mdot
.53618 .56782 Mdot
.70949 .51835 Mdot
.53255 .93982 Mdot
.54726 .6453 Mdot
.46693 .09555 Mdot
.68237 .81468 Mdot
.4804 .25428 Mdot
.48794 .30764 Mdot
.56158 .36145 Mdot
.62278 .7266 Mdot
.546 .26749 Mdot
.76605 .56635 Mdot
.49545 .2967 Mdot
.48067 .13305 Mdot
.39841 .37087 Mdot
.42693 .61177 Mdot
.51028 .64389 Mdot
.46568 .22904 Mdot
.63633 .80543 Mdot
.48045 .71233 Mdot
.37699 .38252 Mdot
.40203 .2529 Mdot
.54437 .81564 Mdot
.49912 .92965 Mdot
.6631 .56917 Mdot
.47866 .8568 Mdot
.75774 .40662 Mdot
.50977 .2696 Mdot
.5924 .87405 Mdot
.36645 .63489 Mdot
.56484 .50754 Mdot
.63051 .22505 Mdot
.48717 .1716 Mdot
.55763 .72845 Mdot
.44216 .92159 Mdot
.43608 .86002 Mdot
.49112 .20478 Mdot
.47801 .81939 Mdot
.41019 .7119 Mdot
.56277 .06379 Mdot
.60456 .34436 Mdot
.45049 .59892 Mdot
.5641 .25056 Mdot
.57138 .327 Mdot
.46396 .68528 Mdot
.51492 .69631 Mdot
.5199 .17582 Mdot
.60928 .35052 Mdot
.52919 .52924 Mdot
.42246 .26607 Mdot
.7125 .55944 Mdot
.58153 .58322 Mdot
.54539 .81055 Mdot
.41707 .34516 Mdot
.44145 .24365 Mdot
.4315 .50546 Mdot
.38496 .88403 Mdot
.43237 .4611 Mdot
.42542 .15344 Mdot
.65398 .28197 Mdot
.58658 .7995 Mdot
.41387 .38029 Mdot
.40328 .81324 Mdot
.5278 .95279 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool009[ooooo1?l00006ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0^Oooool009[ooooo1?l00006ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02o`000;Oooooo002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000000_l0002g
ooooo`00X_ooool00omEEEGoIVIVo`000007ooooo`04o`000?oooooo0000o`000;Sooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000
0oooool2o`000;Cooooo002/ooooo`03o`000?oooooooooo00?ooooo0_l0002dooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00Toooool2o`0001Oooooo00?o
0000ooooooooool0^Oooool009?ooooo0_l0000Booooo`;o00000oooool00ol0003oooooooooo`2i
ooooo`00W?ooool2o`0000;ooooo0_l00003ooooo`Ko000000?oooooo`000?ooool0^_ooool009co
oooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l000001?oooooo0000o`000?l0002ioooo
o`00TOooool2o`0001Oooooo1?l0002jooooo`00TOooool2o`0001Oooooo1?l0002jooooo`00[?oo
ool3o`0000oooooo0ol0002Wooooo`00[?ooool3o`0000oooooo1?l0002Vooooo`00[?ooool00ol0
003oooooooooo`0Aooooo`;o0000Y_ooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00XOooool2
o`0000Wooooo00?o0000ooooooooool0^Oooool00:7ooooo0_l00009ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`?o00002?ooool2o`000003ooooool0003o00000:cooooo002/ooooo`03o`00
0?oooooooooo00Sooooo0_l000000ooooooo0000o`00002/ooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00Toooool2o`0001Oooooo00?o0000ooooooooool0^Oooool009?ooooo0_l0000Goooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@?ooooo0_l000000ooooooo0000onk^kP05ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2iooooo`00ROooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B43ooooo`;o000000?ooooooeEEEOnYZJT02?ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo00oooooo0_l0002Xooooo`00POooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000oooo
ooooool00oooool3o`0000oooooo0_l0002Xooooo`00ROooool01Ol0003ooooooooooooooooo0000
00kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
00oooooo0ol0002Wooooo`00ROooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<
c?ooool00oooool01Ol0003o8B4Qo`000?l0003oc<c<00Gooooo00?o0000ooooooooool04?ooool2
o`000:Oooooo0029ooooo`05oa0@4?ooooooooooooooool@41001oooool2o`0000Gooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooo`000002o`0000Gooooo00?o0000ooooooooool0^Oooool0
08Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`;o00000_ooool01Ol@413ooooooooooooo
oooo<S8b00Cooooo00?o0000ooooooooool00_l00005ooooo`03o`000?oooooooooo0;Wooooo0029
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool6o`0000?ooooo1?l00006ooooo`03o`000?oo
oooooooo01;ooooo0_l0002Uooooo`00WOooool2o`0000gooooo00?o0000ooooooooool04_ooool2
o`000:Gooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002Dooooo`;o00005_ooool3o`000;Wooooo002Cooooo`?o00005_ooool00ol0003ooooooooo
o`2iooooo`00Toooool2o`0001Oooooo00?o0000ooooooooool02_ooool2o`000:gooooo002/oooo
o`03o`000?oooooooooo00[ooooo0_l0002]ooooo`00SOooool2o`0001gooooo00?o0000oooooooo
ool0^Oooool008gooooo0_l0000Booooo`;o00002Oooool00ol0003oooooooooo`2iooooo`00XOoo
ool2o`000003ooooool0003o000000Kooooo00?o0000ooooooooool0^Oooool009oooooo0_l00003
ooooo`;o000000?oooooo`000?l000000oooool00ol0003oooooooooo`0Looooo`;o0000Voooool0
097ooooo0_l0000<ooooo`;o00001_ooool2o`0000?ooooo0ol00003ooooo`;o00005oooool2o`00
00oooooo0_l0002:ooooo`00TOooool2o`0001Oooooo0ol00005ooooo`;o0000:?ooool2o`0008[o
oooo002Zooooo`?o0000;oooool2o`0008[ooooo002Looooo`;o00003_ooool00ol0003ooooooooo
o`2iooooo`00W?ooool2o`0000kooooo00?o0000ooooooooool01Oooool2o`000;;ooooo002Ioooo
o`?o00004?ooool00ol0003oooooooooo`05ooooo`;o00006_ooool2o`0009Kooooo002Iooooo`?o
00004?ooool00ol0003oooooooooo`0Aooooo`;o00003_ooool2o`0009Kooooo002Sooooo`;o0000
1oooool00ol0003oooooooooo`0Aooooo`?o0000YOooool008oooooo0_l0000Booooo`;o00001ooo
ool3o`0001;ooooo0_l0002Uooooo`00Soooool2o`0001_ooooo00?o0000ooooooooool0^Oooool0
0:Wooooo0_l000000ooooooo0000ooooo`2jooooo`00P?ooool2o`0002Oooooo0_l000000ooooooo
0000ooooo`2jooooo`00P?ooool2o`0002[ooooo00?o0000ooooooooool05Oooool2o`000:;ooooo
002/ooooo`03o`000?oooooooooo01Gooooo0ol0002Qooooo`00[?ooool00ol0003oooooooooo`0F
ooooo`;o0000XOooool00:cooooo00?o0000ooooooooool09oooool2o`00093ooooo002Jooooo`;o
00004?ooool3o`0000kooooo0_l0000Gooooo`?o0000Soooool009[ooooo0_l00008ooooo`;o0000
1_ooool00ol0003oooooooooo`0>ooooo`;o00005oooool3o`0008oooooo002Pooooo`;o00000_oo
ool2o`0000Kooooo00?o0000ooooooooool0^Oooool00:3ooooo0_l0000:ooooo`03o`000?oooooo
oooo00Oooooo0_l0000Booooo`;o0000W?ooool008Cooooo0_l0000:ooooo`;o00006_ooool00ol0
003oooooooooo`07ooooo`;o00004_ooool2o`0009cooooo0024ooooo`;o00002_ooool2o`0001[o
oooo00?o0000ooooooooool0>oooool2o`0007cooooo0023ooooo`;o00003?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00;ooooo0_l000000ooooooo8B4Qob4Q8@05ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`0kooooo`;o0000O?ooool008?ooooo0_l0000<ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00_ooool2o`000003oooooolQ8B7o8B4Q00Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`0Zooooo`;o0000SOooool008Wooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`;o0000;?ooool2o`00
08gooooo002;ooooo`;o00001?ooool01Ol0003ooooooooooooooooo000000oooooo0_l00004oooo
o`Co00004_ooool2o`000:Gooooo002;ooooo`;o00001?ooool01Ol0003ooooooooooooooooo0000
00_ooooo0_l000001?lQ8B7o0000o`000?l00005ooooo`03o`000?oooooooooo00Cooooo0_l0000<
ooooo`Co0000Xoooool0097ooooo00Go410@oooooooooooooooooa0@400;ooooo`;o00000_ooool2
o`0000Gooooo00?o0000ooooooooool01?ooool2o`0000kooooo0_l0002Sooooo`00TOooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`10
ooooo`;o0000Moooool0097ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool0
0ol0003oooooooooo`10ooooo`;o0000Moooool008_ooooo0_l00005ooooo`;o00006?ooool00ol0
003oooooooooo`05ooooo`;o00001Oooool2o`000:_ooooo002;ooooo`;o00001Oooool2o`0001So
oooo00?o0000ooooooooool00_l00003ooooo`?o00001?ooool2o`0000Oooooo0_l0000Hooooo`;o
0000R?ooool009Sooooo0_l0000Booooo`03o`000?oooooooooo00;o00001?ooool2o`0000gooooo
0_l0000Hooooo`;o0000R?ooool008kooooo0_l00008ooooo`;o00004_ooool3o`0001Gooooo0_l0
002Rooooo`00Q_ooool2o`0000Kooooo0_l0000Eooooo`;o00001Oooool00ol0003oooooooooo`0E
ooooo`;o000000?oooooo`000?l00000Woooool008Kooooo0_l0000Iooooo`;o00000_ooool2o`00
00Gooooo00?o0000ooooooooool06?ooool2o`0000Wooooo0_l0000:ooooo`?o0000Qoooool00:7o
oooo0_l00009ooooo`03o`000?oooooooooo02?ooooo0_l0000:ooooo`?o0000Qoooool009?ooooo
0_l0000Gooooo`03o`000?oooooooooo01Sooooo0_l0002Oooooo`00Toooool2o`0000;ooooo0_l0
000Cooooo`03o`000?oooooooooo01Sooooo0_l0002Oooooo`00Uoooool2o`0001?ooooo00?o0000
ooooooooool09_ooool2o`00097ooooo0025ooooo`;o00008oooool3o`0002Sooooo0_l0002Aoooo
o`00QOooool2o`0002?ooooo1Ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00Y_oo
ool4o`0000;ooooo00?o0000ooooooooool0^Oooool009Sooooo0_l0000<ooooo`Co00000_ooool0
0ol0003oooooooooo`0Booooo`;o0000YOooool009Sooooo0_l0000Booooo`03o`000?oooooooooo
00_ooooo0_l00005ooooo`;o0000YOooool00:cooooo00?o0000ooooooooool02oooool2o`0000Oo
oooo0_l0002Sooooo`00[?ooool00ol0003oooooooooo`0Dooooo`;o0000Xoooool00:cooooo00?o
0000ooooooooool01oooool2o`000;3ooooo002Gooooo`;o00004oooool3o`0000?ooooo0_l00002
ooooo`;o00001?ooool2o`000:[ooooo002Dooooo`;o000000?oooooo`000?l000004oooool00ol0
003oooooooooo`03ooooo`;o00002?ooool2o`0000Gooooo0_l0002Sooooo`00QOooool2o`0000go
oooo0_l0000Fooooo`03o`000?oooooooooo01Cooooo0_l00008ooooo`;o0000VOooool008Gooooo
0_l0000Uooooo`03o`000?oooooooooo01kooooo0_l00008ooooo`?o0000S_ooool00:cooooo00?o
0000ooooooooool0:?ooool3o`0000kooooo0_l0001nooooo`00[?ooool00ol0003oooooooooo`0i
ooooo`;o0000O_ooool009Gooooo0_l0000Eooooo`03o`000?oooooooooo0;Wooooo002@ooooo`;o
00000oooool2o`0001Gooooo00?o0000ooooooooool05oooool2o`0000Kooooo0_l0002Hooooo`00
T?ooool2o`0001[ooooo00?o0000ooooooooool05oooool2o`0000Kooooo0_l0002Hooooo`00Rooo
ool2o`0001oooooo0ol00006ooooo`;o00000_ooool2o`0001Gooooo0_l0002Fooooo`00Roooool2
o`0000Sooooo0_l0000Eooooo`03o`000?oooooooooo00Kooooo0_l00002ooooo`?o00005?ooool2
o`0009Kooooo002Eooooo`;o00001Oooool2o`0000kooooo00?o0000ooooooooool02oooool2o`00
0:cooooo002Looooo`;o00003_ooool00ol0003oooooooooo`03ooooo`;o00003?ooool2o`0000ko
oooo1?l0002Dooooo`00[?ooool00ol0003oooooooooo`03ooooo`;o00003?ooool2o`0000kooooo
1?l00008ooooo`;o0000R_ooool008Wooooo00Cok^k^oc8b<_l0003o<S8b0_l00004ooooo`;o8B4Q
1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00co
oooo0_l0000Oooooo`;o0000R_ooool008Wooooo00CoMgMgo`000?l0003oV9RH0_l00004ooooo`;o
8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`0<ooooo`;o0000Zoooool0087ooooo1_l00002ooooo`05oa0@4?l0003o0000oooo
ool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0^Oooool008Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^
00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0003gooooo0_l0001jooooo`00ROooool01_l0003o
oooooooooooooooo0000ooooo`;o00002oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool01?l0003oooooooooooooool2o`00013ooooo0_l00005ooooo`;o0000
8?ooool3o`0007[ooooo0023ooooo`;o00001?ooool01_l@413ooooooooooooooooo410@ooooo`;o
00003?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooo
oooooooo0_l0000@ooooo`;o00001Oooool2o`00023ooooo0_l0001kooooo`00Poooool2o`0000Co
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oo
oooooooo033ooooo0_l0000<ooooo`;o0000NOooool00:cooooo00?o0000ooooooooool00_ooool2
o`0002cooooo0_l0000<ooooo`;o00003oooool2o`0006Sooooo002/ooooo`03o`000?oooooooooo
00;ooooo0_l0000Aooooo`;o00006_ooool2o`0000_ooooo0_l0000?ooooo`;o0000J?ooool00:co
oooo00?o0000ooooooooool05Oooool2o`0001[ooooo0_l0000Looooo`;o0000J?ooool00:cooooo
0ol0000oooooo`;o0000N?ooool00:cooooo00?o0000ooooooooool0?oooool2o`00013ooooo0_l0
001Vooooo`00[?ooool00ol0003oooooooooo`0Mooooo`;o00007oooool2o`00017ooooo0ol0001U
ooooo`00[?ooool00ol0003oooooooooo`0Mooooo`;o00007oooool2o`0001;ooooo0_l0001Uoooo
o`00[?ooool00ol0003oooooooooo`0booooo`;o00003?ooool2o`0007Oooooo002/ooooo`03o`00
0?oooooooooo037ooooo0ol0000<ooooo`;o0000Moooool00:cooooo00?o0000ooooooooool09Ooo
ool2o`0000[ooooo0_l00026ooooo`00[?ooool00ol0003oooooooooo`0Uooooo`;o0000T_ooool0
07oooooo0_l0000[ooooo`?o00001?ooool2o`0000Gooooo0_l0000Jooooo`;o0000T?ooool007oo
oooo0_l0000[ooooo`03o`000?oooooooooo00Cooooo0_l00005ooooo`;o00006_ooool2o`00093o
oooo002/ooooo`03o`000?oooooooooo0;Wooooo0022ooooo`;o0000:?ooool00ol0003ooooooooo
o`2iooooo`00P_ooool2o`0002Sooooo00?o0000ooooooooool00_ooool2o`000;Gooooo002/oooo
o`03o`000?oooooooooo00;ooooo0_l0000Booooo`;o0000XOooool00:cooooo00?o0000oooooooo
ool05_ooool2o`000:7ooooo002/ooooo`?o0000=?ooool2o`0008?ooooo002/ooooo`Go00000ooo
ool2o`0000_ooooo0_l0000Pooooo`;o0000Poooool00:cooooo1Ol00003ooooo`;o00002oooool2
o`0003oooooo0_l0001Tooooo`00S_ooool2o`0000Oooooo0_l0000Cooooo`03o`000?oooooooooo
05?ooooo0_l0001Tooooo`00S_ooool2o`0000Oooooo0_l0000Cooooo`03o`000?oooooooooo01oo
oooo0_l0000Dooooo`;o0000P_ooool000Wooooo1?l000000ol@413oooooooooo`0Fooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool0
1Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Cooooo00CoA4A4o`000?l0003o<S8b0_l0000Eooooo`03o`000?oooooooooo01So
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`;o000000?oooooob4Q8OlQ8B401?ooool5o`00
00Cooooo00CoA4A4o`000?l0003o<S8b0_l0000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM
01Sooooo1?l000000ol@413oooooooooo`0Booooo`002oooool00ol0003oooooooooo`0Hooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omg
MgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01oooool00omgMgOo0000o`00000Eooooo`03o`000?oooooooooo00Wooooo
0_l0000=ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool2o`000003oooooolQ8B7o8B4Q00Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8boooo
o`0Iooooo`03o`000?oooooooooo01Cooooo0006o`0000Gooooo00?o0000ooooooooool04?ooool6
o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o
0000ooooooooool01Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`00
0?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP09ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02Oooool2o`0000go
oooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000oooo
ooooool03Oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool03Oooool0
1Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool03_oo
ool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooo
oooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`0Eooooo`03
o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^
00Oooooo00?oMgMgoc8b<_ooool02_ooool2o`0000;ooooo00Go0000ooooooooooooooooo`00000?
ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooo
oooooooo00Kooooo00?oMgMgoc8b<_ooool06Oooool00ol0003oooooooooo`0Dooooo`002oooool0
0ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<oooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000co
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003_ooool0
0omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05_ooool00ol0003ooooooooo
o`0Hooooo`;o00000_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00?ooooo00Go
0000ob4Q8Ol0003o0000olc<c00;ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000[o
oooo0ol000001?lQ8B7o0000oc8b<_o<c<`?ooooo`05o`000?ooooooooooooooool000003_ooool0
0omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06_ooool00ol0003ooooooooo
o`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05oa0@4?ooooooooooooooool@41003_oo
ool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool06?ooool3o`0001;ooooo0_l00004ooooo`;o
00000_ooool00ol@413oooooooooo`0:ooooo`;o000000?oooooo`000?ooool00oooool01?l0003o
ooooo`000?l0000@ooooo`05oa0@4?ooooooooooooooool@41002_ooool3o`0001?ooooo00Go410@
oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool0
4Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_l00004ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01;ooooo0_l00004ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool3o`000003oiRHV?l@413ooooo00?ooooo00?o0000ooooooooool04Ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool05?ooool000Wooooo00?oEEEEofIVI_l000006_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo1?l0000@ooooo`06onk^k_lb<S;o0000oc8b<_o^k^kooooo0_l00002ooooo`;o0000
1?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0000Gooooo`03o`000?oooooooooo01So
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4
o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00004?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00006Oooool00omEEEGoIVIVo`00000Fooooo`00O_oo
ool2o`00013ooooo0_l0000Jooooo`03o`000?oooooooooo04?ooooo0_l0001dooooo`00T?ooool2
o`000003ooooool0003o000001Oooooo00?o0000ooooooooool03_ooool2o`0003?ooooo0_l0001d
ooooo`00Toooool2o`0000;ooooo0_l0000Cooooo`03o`000?oooooooooo00kooooo0_l0002Noooo
o`;o00000_ooool2o`0000Gooooo002Gooooo`;o00004oooool00ol0003oooooooooo`0>ooooo`;o
00006Oooool2o`0000[ooooo0_l0000;ooooo`Co0000J?ooool01_o^k^ko8B4QohN7Qonj^[[o0000
omgMg@Gooooo002Jooooo`;o00004?ooool00ol0003oooooooooo`0Iooooo`;o00003_ooool2o`00
00[ooooo0_l0000;ooooo`Co0000JOooool01?oMgMgo0000oa0@4?o<c<`6ooooo`001oooooooo`00
04co00003?ooool01?o^k^ko8B4Qoa0@4?o^k^h6ooooo`001oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`04o`000?ooooooooooooooo`Co000000?oooooo`000?ooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02
o`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`?o00001oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0:ooooo`04ob4Q8OmgMgOoMgMgoc8b<PKooooo0007ooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo00Wooooo0_l00004ooooo`;o00005Oooool00ol0003oooooooooo`0>ooooo`;o00000_ooool2
o`0000cooooo0_l00005ooooo`03o`000?oooooooooo01Wooooo0_l0000;ooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`09ooooo`;o00000_ooool2
o`0000Gooooo002Eooooo`;o00005Oooool00ol0003oooooooooo`0>ooooo`;o00000_ooool2o`00
00cooooo0_l0000Qooooo`;o0000M?ooool008kooooo0_l000000ooooooo0000o`00000Iooooo`03
o`000?oooooooooo00?ooooo0_l0000=ooooo`;o0000<?ooool2o`0007?ooooo002>ooooo`;o0000
00?oooooo`000?l000006Oooool00ol0003oooooooooo`03ooooo`;o00003_ooool2o`0002oooooo
0_l0000?ooooo`;o0000H_ooool008;ooooo0_l0000Xooooo`03o`000?oooooooooo01;ooooo0ol0
000]ooooo`;o00004Oooool2o`0006;ooooo0022ooooo`;o00005?ooool2o`0001;ooooo00?o0000
ooooooooool04_ooool2o`0002kooooo0_l0000Booooo`;o0000HOooool008;ooooo0_l00002oooo
o`;o00001_ooool2o`0000Sooooo0_l0000Booooo`?o0000:_ooool2o`0002[ooooo0_l0001Qoooo
o`00Q_ooool2o`0000Kooooo0_l0000Looooo`03o`000?oooooooooo02[ooooo0_l0002=ooooo`00
ROooool2o`00027ooooo00?o0000ooooooooool01_ooool2o`000;7ooooo0029ooooo`;o00008Ooo
ool00ol0003oooooooooo`06ooooo`;o00002oooool2o`0000?ooooo0_l0002Oooooo`00[?ooool0
0ol0003oooooooooo`0Cooooo`;o00000oooool2o`0009oooooo002Dooooo`;o00005_ooool00ol0
003oooooooooo`0Yooooo`?o0000SOooool009Cooooo0_l0000Fooooo`03o`000?oooooooooo02Wo
oooo0ol0002=ooooo`00P_ooool2o`0002Sooooo00?o0000ooooooooool0^Oooool008;ooooo0_l0
000Xooooo`03o`000?oooooooooo0;Wooooo0022ooooo`;o0000:?ooool3o`00023ooooo0_l0002G
ooooo`00O_ooool2o`0000;ooooo0_l0000Xooooo`03o`000?oooooooooo023ooooo0_l00007oooo
o`;o00006?ooool2o`0007Cooooo001nooooo`;o0000;?ooool00ol0003oooooooooo`0Yooooo`;o
00006?ooool2o`0007Cooooo0026ooooo`;o00003oooool2o`0001?ooooo00?o0000ooooooooool0
6?ooool2o`0002Wooooo0_l0001dooooo`00Q_ooool2o`0000oooooo0_l0000Cooooo`03o`000?oo
oooooooo00;ooooo0_l0000Dooooo`;o0000:Oooool2o`0007Cooooo002/ooooo`03o`000?oooooo
oooo00;ooooo0_l00005ooooo`;o000000?oooooo`000?l000009Oooool2o`0001oooooo0_l0001S
ooooo`00[?ooool00ol0003oooooooooo`09ooooo`;o000000?oooooo`000?l000009?ooool3o`00
01oooooo0_l0001Sooooo`00[?ooool00ol0003oooooooooo`0booooo`;o0000QOooool009[ooooo
0_l0000@ooooo`?o00001?ooool2o`000;?ooooo002Jooooo`;o00004?ooool00ol0003ooooooooo
o`04ooooo`;o0000/oooool007[ooooo0_l0000`ooooo`03o`000?oooooooooo01Oooooo0_l0002P
ooooo`00N_ooool2o`00033ooooo00?o0000ooooooooool05oooool2o`000:3ooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo02Oooooo0_l0002@ooooo`00[?oo
ool00ol0003oooooooooo`0Vooooo`?o0000T?ooool00:cooooo00?o0000ooooooooool05oooool2
o`0000Gooooo0_l00006ooooo`;o0000TOooool008gooooo0_l00004ooooo`Co00001?ooool2o`00
00oooooo0ol0000Gooooo`;o00001Oooool2o`0001;ooooo0_l0000>ooooo`;o0000MOooool008[o
oooo0_l000000ooooooo0000o`000004ooooo`Co00001?ooool2o`0000oooooo00?o0000oooooooo
ool0<_ooool2o`0000cooooo1?l0001eooooo`00R_ooool2o`00023ooooo00?o0000ooooooooool0
@?ooool2o`00017ooooo0_l0001Tooooo`00[?ooool00ol0003oooooooooo`0Uooooo`;o00006ooo
ool2o`0000oooooo0_l0001Tooooo`00Soooool2o`0000;ooooo0_l0000Gooooo`03o`000?oooooo
oooo01Gooooo0_l0000>ooooo`;o00002Oooool2o`00013ooooo0_l0001eooooo`00Soooool2o`00
00;ooooo0_l0000Gooooo`03o`000?oooooooooo00;o000000?oooooo`000?l000004?ooool2o`00
01Wooooo0_l00027ooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool00_l00000
0ooooooo0000o`00002dooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo01Gooooo0_l00006ooooo`;o00004_ooool2o`0008Kooooo0029ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0
000Eooooo`;o00001_ooool2o`0001;ooooo0_l00026ooooo`00ROooool01Ol0003ooooooooooooo
oooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo00;ooooo0_l0000:ooooo`;o0000ZOooool008Wooooo0ol000000ooooooo0000ooooo`0=
ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oo
oooooooo00;ooooo0_l0000:ooooo`;o0000ZOooool0083ooooo0_l00007ooooo`05oa0@4?l0003o
0000ooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo0ol0
000Looooo`;o0000WOooool007oooooo0ol00007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01Oooool3o`0001cooooo
0_l0002Mooooo`00Ooooool2o`0000Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`;o0000
1oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo0;Wo
oooo0027ooooo`;o00001oooool2o`0001[ooooo00?o0000ooooooooool00_l0000;ooooo`;o0000
5?ooool2o`0009Cooooo0027ooooo`;o00008oooool00ol0003oooooooooo`02o`0000[ooooo0ol0
000Dooooo`;o00002_ooool2o`0001oooooo0_l0001Wooooo`00[?ooool00ol0003oooooooooo`0<
ooooo`;o00003?ooool2o`0001?ooooo0_l0000Nooooo`?o0000Ioooool008kooooo0_l00003oooo
o`;o00001_ooool2o`0000oooooo0ol0000Jooooo`;o00004oooool3o`0001gooooo0_l0001Xoooo
o`00S_ooool2o`0000?ooooo0_l00006ooooo`;o00003oooool00ol0003oooooooooo`0]ooooo`;o
000000?oooooo`000?l00000Qoooool00:cooooo00?o0000ooooooooool02oooool2o`00023ooooo
0_l0000?ooooo`;o0000NOooool00:_ooooo0_l0000=ooooo`;o0000<Oooool2o`0007Wooooo0028
ooooo`;o00008?ooool3o`000;_ooooo0028ooooo`;o00008?ooool5o`000003ooooool0003o0000
01gooooo0_l0000Jooooo`;o0000Noooool009Gooooo0_l0000Eooooo`?o000000?oooooo`000?l0
00007Oooool2o`0001[ooooo0_l0001kooooo`00UOooool2o`0001Gooooo00?o0000ooooooooool0
1Oooool2o`0003Kooooo0_l0001jooooo`00[?ooool3o`0000Gooooo0_l0000fooooo`;o0000N_oo
ool009_ooooo0_l000000ooooooo0000o`00000<ooooo`03o`000?oooooooooo00;o0000]oooool0
08Gooooo0_l0000Dooooo`;o000000?oooooo`000?l000003?ooool00ol0003oooooooooo`02o`00
0;Oooooo0025ooooo`;o00006Oooool2o`0000[ooooo00?o0000ooooooooool0^Oooool008Gooooo
0_l0000Iooooo`;o00002_ooool00ol0003oooooooooo`0?ooooo`;o0000Z?ooool008Gooooo0_l0
000Uooooo`03o`000?oooooooooo00oooooo0_l0002Xooooo`00[?ooool00ol0003oooooooooo`0h
ooooo`;o0000Ooooool009gooooo0_l0000=ooooo`04o`000?ooooooooooooooo`;o00002_ooool2
o`0001Wooooo0_l0000>ooooo`;o0000Ooooool009gooooo0_l0000=ooooo`?o000000?oooooo`00
0?l000002_ooool2o`0001Wooooo0_l0002?ooooo`00U?ooool2o`0001Kooooo00?o0000oooooooo
ool0^Oooool008gooooo0_l00005ooooo`;o00005_ooool00ol0003oooooooooo`2iooooo`00SOoo
ool3o`00017ooooo0_l00009ooooo`03o`000?oooooooooo0;Wooooo002>ooooo`;o000000?ooooo
o`000?l000003_ooool2o`0000;ooooo0_l00005ooooo`03o`000?oooooooooo0;Wooooo002>oooo
o`;o000000?oooooo`000?l000004_ooool2o`0000Gooooo00?o0000ooooooooool04oooool2o`00
02?ooooo0_l0001oooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o00003Oooool2o`00027o
oooo1?l0001oooooo`00UOooool2o`0001Gooooo00?o0000ooooooooool01?ooool2o`0002oooooo
0ol00021ooooo`00UOooool2o`0000Kooooo0_l0000=ooooo`?o00009oooool2o`0000_ooooo0ol0
0022ooooo`00Roooool2o`0000cooooo0_l00002ooooo`;o00003Oooool00ol0003oooooooooo`09
ooooo`;o00001Oooool2o`0001?ooooo1?l0000;ooooo`;o0000Poooool008_ooooo0_l0000<oooo
o`;o00004Oooool00ol0003oooooooooo`09ooooo`;o00001Oooool3o`00017ooooo0ol0002Boooo
o`00[?ooool00ol0003oooooooooo`0Aooooo`;o00004Oooool2o`0009?ooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo0027ooooo`;o00003_ooool2o`0001?ooooo00?o0000ooooooooool00_l0
000Sooooo`;o0000T_ooool008Oooooo0_l00008ooooo`06onk^k_lb<S;o0000o`000?o^k^kooooo
0_l00002ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooooooo
ool00_l00005ooooo`;o00003oooool2o`0000_ooooo0_l0002Booooo`00TOooool01OmgMgOoV9RH
o`000?l0003oMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool01oooool2o`0000oooooo0_l0002Oooooo`00TOooool01Ol@413ooooooooooooooooo410@013o
oooo00Co0000oooooooooooooooo0ol00008ooooo`;o0000/Oooool008cooooo0_l00003ooooo`03
o`000?oooooooooo00;o00003oooool00omgMgOo<S8booooo`02ooooo`Ko00001Oooool2o`0000Ko
oooo0_l0002Yooooo`00S?ooool2o`0000?ooooo00?o0000ooooooooool00_l0000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool01?l0003oooooo`000?l0000=ooooo`;o0000ZOooool0097o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00;o00001Oooool00ol0
003oooooooooo`0booooo`;o0000QOooool0097ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`;o000000?oooooo`000?l000001Oooool00ol0003oooooooooo`0`ooooo`Co0000QOooool0097o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`0_oooo
o`?o0000Qoooool00:cooooo00?o0000ooooooooool00oooool2o`0002[ooooo0_l0000@ooooo`;o
0000M_ooool00:cooooo00?o0000ooooooooool00oooool2o`0003cooooo0_l0001fooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00T_ooool2o`0001Sooooo0ol0002iooooo`00T_ooool2o`00
01Sooooo00?o0000ooooooooool04_ooool2o`000:Gooooo002>ooooo`;o00007?ooool00ol0003o
ooooooooo`0Booooo`;o0000YOooool008kooooo0_l00003ooooo`;o00004oooool2o`0000;ooooo
00?o0000ooooooooool01oooool2o`0001?ooooo0_l0002Kooooo`00Toooool2o`0001?ooooo0_l0
0002ooooo`04o`000?oooooo0000o`0000Gooooo0ol0000Cooooo`;o0000Voooool008kooooo0_l0
000Aooooo`;o00001Oooool2o`0000;ooooo00Co0000ooooool0003o00001Oooool2o`0002Cooooo
0_l0002;ooooo`00S_ooool2o`00017ooooo0_l00009ooooo`03o`000?oooooooooo02cooooo0_l0
002;ooooo`00[?ooool00ol0003oooooooooo`0?ooooo`;o0000Z?ooool009[ooooo0_l0000@oooo
o`?o00003oooool2o`0000Sooooo0_l0000?ooooo`;o0000SOooool009[ooooo0_l0000@ooooo`03
o`000?oooooooooo01Wooooo0_l0000?ooooo`;o00003oooool2o`0007cooooo002/ooooo`03o`00
0?oooooooooo02[ooooo0_l0000?ooooo`;o0000O?ooool00:cooooo00?o0000ooooooooool0:_oo
ool2o`0008gooooo002<ooooo`;o00007_ooool00ol0003oooooooooo`0<ooooo`;o00002oooool2
o`0009kooooo0021ooooo`;o00002Oooool2o`0001kooooo00?o0000ooooooooool02oooool3o`00
00_ooooo0_l0000Nooooo`;o0000O_ooool0087ooooo0_l00009ooooo`;o00005_ooool4o`0000Co
oooo00?o0000ooooooooool02oooool2o`0001[ooooo0_l0000@ooooo`;o0000O_ooool00:Cooooo
1?l00004ooooo`03o`000?oooooooooo00;o00009Oooool2o`00093ooooo002/ooooo`Go0000]ooo
ool009?ooooo0_l0000>ooooo`;o00001oooool00ol0003oooooooooo`2iooooo`00Toooool2o`00
00kooooo0_l00007ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00So
oooo0_l0002_ooooo`00[?ooool00ol0003oooooooooo`08ooooo`;o0000[oooool009_ooooo0_l0
000?ooooo`03o`000?oooooooooo0;Wooooo0028ooooo`;o00004Oooool2o`0000oooooo00?o0000
ooooooooool0^Oooool008Sooooo0_l0000Booooo`;o00003_ooool00ol0003oooooooooo`04oooo
o`;o00006oooool2o`0009Kooooo002Looooo`;o00003_ooool00ol0003oooooooooo`04ooooo`;o
00006oooool2o`0000oooooo0_l00025ooooo`00ROooool2o`00027ooooo0ol0000booooo`;o0000
QOooool008Wooooo0_l0000Mooooo`;o00000_ooool00ol0003oooooooooo`2iooooo`00U_ooool2
o`0000gooooo0_l000000ooooooo0000o`000002ooooo`03o`000?oooooooooo01gooooo0_l0002J
ooooo`00U_ooool2o`0000cooooo1?l00004ooooo`03o`000?oooooooooo01gooooo0_l0002Joooo
o`00U_ooool2o`0000cooooo1?l00004ooooo`03o`000?oooooooooo01_ooooo0_l0002Looooo`00
ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B43ooooo`;o000000?oooooo`000?o^
k^h01Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool02oooool4o`00
00cooooo1?l0002Jooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B43oooo
o`;o000000?ooooooeEEEOnYZJT02?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
00_ooooo1?l0000>ooooo`;o0000V_ooool008Wooooo00Go410@oooooooooooooooooa0@400=oooo
o`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Koooo
o`;o00003oooool2o`0008_ooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool00olQ
8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Kooooo`;o00003oooool2o`00
08_ooooo0029ooooo`05o`000?ooooooooooooooool000001?ooool2o`0000Sooooo00?oEEEEolc<
c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0^Oooool0
08Wooooo00Go410@oooooooooooooooooa0@4004ooooo`;o00001oooool2o`000003ogMgMooooooo
oooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Gooooo`;o0000X?ooool0
08Kooooo0_l000001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Cooooo0_l00005ooooo`05oa0@4?oo
oooo0000o`000?lb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Oooooo
0_l0002Pooooo`00Q_ooool2o`000006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1?ooool2o`0000Go
oooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`0Eooooo`Co0000X?ooool009cooooo
0_l000000ooooooo0000o`00000;ooooo`03o`000?oooooooooo00Gooooo0_l0000>ooooo`Co0000
X?ooool009oooooo0_l0000;ooooo`03o`000?oooooooooo00Gooooo0_l0000>ooooo`;o0000X_oo
ool00:Gooooo0_l00005ooooo`03o`000?oooooooooo01Gooooo0_l0002Rooooo`00SOooool2o`00
01Kooooo0_l00005ooooo`?o0000^Oooool008gooooo0_l0000Mooooo`03o`000?oooooooooo01Co
oooo0_l0002Sooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool00_ooool2o`0000cooooo
0_l00002ooooo`;o0000Xoooool008kooooo0ol0000Kooooo`03o`000?oooooooooo00;ooooo0_l0
000<ooooo`;o0000Yoooool008oooooo0_l0000Kooooo`03o`000?oooooooooo00oooooo0ol0002W
ooooo`00S_ooool2o`0000Oooooo0_l0000Cooooo`04o`000?oooooo0000o`0000kooooo0ol0002W
ooooo`00S_ooool2o`0000Oooooo0_l0000Cooooo`03o`000?oooooo000000;o0000]oooool009So
oooo0_l0000Booooo`03o`000?oooooooooo00;o0000]oooool009Sooooo0_l0000Booooo`?o0000
3?ooool2o`000:_ooooo002Aooooo`;o00006Oooool00ol0003oooooooooo`0;ooooo`?o0000Zooo
ool0097ooooo0_l0000Hooooo`;o00003Oooool2o`000:cooooo002Mooooo`;o00003?ooool2o`00
0;_ooooo002Mooooo`;o00003Oooool00ol0003oooooooooo`0;ooooo`;o0000[?ooool00:7ooooo
0_l00009ooooo`03o`000?oooooooooo00Oooooo1_l0002/ooooo`00XOooool2o`0000Wooooo00?o
0000ooooooooool01oooool4o`000:kooooo002Oooooo`?o00000oooool2o`0000Gooooo00?o0000
ooooooooool0^Oooool009oooooo0ol00003ooooo`;o00001Oooool00ol0003oooooooooo`07oooo
o`;o0000/?ooool009Cooooo0_l0000Fooooo`?o00001_ooool3o`000;3ooooo002Dooooo`;o0000
5_ooool00ol0003oooooooooo`06ooooo`;o0000/Oooool009Cooooo0_l0000Fooooo`03o`000?oo
oooooooo0;Wooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002[ooooo`;o0000
^oooool009kooooo0_l0000;ooooo`;o0000^oooool009kooooo0_l00008ooooo`;o00000_ooool0
0ol0003oooooooooo`2iooooo`00X_ooool4o`000004oa0@4?oooooo0000o`0000;ooooo00?o0000
ooooooooool0^Oooool00:Cooooo1_l00002ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`Co
00001?ooool3o`000;Wooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oo
oooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo
0<7ooooo002Rooooo`03oeEEEOmVIVKo00000<?ooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo002Zooooo`04oa0@4?l0003o0000o`000;[ooooo002[ooooo`03
o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`06o`000?mg
MgOo0000o`000?mEEEGok^k^]oooool00:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomEEEFgoooo
o`00Zoooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo0;Gooooo002[ooooo`03o`00
0?o^k^kooooo00;ooooo00?o0000ooooooooool0]Oooool00:_ooooo00Ko0000oeEEEOo^k^kooooo
ogMgMomVIVJgooooo`00Z_ooool00ol@413o0000ogMgM`02o`000003ofIVI_o^k^kooooo0;Kooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.60362 .70531 Mdot
.40442 .76304 Mdot
.45732 .38923 Mdot
.51331 .30473 Mdot
.57719 .39585 Mdot
.59328 .29526 Mdot
.44837 .62612 Mdot
.719 .60455 Mdot
.66805 .29294 Mdot
.45072 .24438 Mdot
.56341 .42665 Mdot
.69211 .69388 Mdot
.57555 .19324 Mdot
.54145 .3338 Mdot
.68213 .70586 Mdot
.53506 .64958 Mdot
.60523 .58542 Mdot
.58788 .21271 Mdot
.40892 .57024 Mdot
.58487 .8249 Mdot
.58614 .21592 Mdot
.39689 .27896 Mdot
.428 .14577 Mdot
.60602 .24617 Mdot
.59834 .86514 Mdot
.41429 .69885 Mdot
.56694 .55013 Mdot
.42087 .67715 Mdot
.54776 .87826 Mdot
.39902 .7275 Mdot
.61377 .27275 Mdot
.6723 .29752 Mdot
.72249 .51926 Mdot
.53663 .78114 Mdot
.40067 .66163 Mdot
.65101 .66661 Mdot
.39501 .2109 Mdot
.49206 .78437 Mdot
.50805 .92437 Mdot
.67799 .73556 Mdot
.59165 .87982 Mdot
.45849 .85725 Mdot
.46014 .13037 Mdot
.57593 .77306 Mdot
.62803 .63413 Mdot
.57171 .64863 Mdot
.5159 .2771 Mdot
.61443 .18905 Mdot
.52032 .20528 Mdot
.56535 .84827 Mdot
.60525 .1769 Mdot
.41676 .87294 Mdot
.7603 .64694 Mdot
.40032 .33916 Mdot
.41783 .22477 Mdot
.70667 .40251 Mdot
.71553 .61698 Mdot
.60657 .58455 Mdot
.52043 .0695 Mdot
.63558 .59721 Mdot
.55793 .68936 Mdot
.3773 .23224 Mdot
.5006 .93168 Mdot
.5336 .60469 Mdot
.71691 .49429 Mdot
.69468 .35427 Mdot
.43449 .2924 Mdot
.5491 .57601 Mdot
.47922 .79687 Mdot
.62764 .29252 Mdot
.58953 .67045 Mdot
.51522 .41456 Mdot
.45571 .23791 Mdot
.41492 .54692 Mdot
.50117 .93095 Mdot
.49757 .6062 Mdot
.7601 .64758 Mdot
.51213 .78463 Mdot
.45047 .94035 Mdot
.45186 .18057 Mdot
.6692 .4532 Mdot
.40895 .78032 Mdot
.47404 .25086 Mdot
.44024 .83207 Mdot
.72535 .51539 Mdot
.51935 .70164 Mdot
.58249 .4215 Mdot
.58782 .49656 Mdot
.61274 .52911 Mdot
.54671 .59014 Mdot
.5923 .87246 Mdot
.73305 .31614 Mdot
.45292 .72503 Mdot
.5869 .56774 Mdot
.48674 .73682 Mdot
.71529 .27283 Mdot
.53415 .31433 Mdot
.60404 .17933 Mdot
.75338 .67331 Mdot
.61301 .55244 Mdot
.57909 .76004 Mdot
.61025 .44981 Mdot
.6938 .68287 Mdot
.5485 .82023 Mdot
.66232 .39867 Mdot
.51449 .81977 Mdot
.57333 .71217 Mdot
.41539 .34793 Mdot
.44993 .71905 Mdot
.62869 .29717 Mdot
.50342 .2472 Mdot
.50789 .28957 Mdot
.66651 .28602 Mdot
.63746 .71744 Mdot
.57048 .97558 Mdot
.5269 .42858 Mdot
.53552 .74171 Mdot
.7128 .40756 Mdot
.69887 .36019 Mdot
.3814 .32033 Mdot
.57121 .18777 Mdot
.36198 .57264 Mdot
.52535 .13223 Mdot
.53548 .89601 Mdot
.63056 .30018 Mdot
.53375 .36547 Mdot
.62063 .75362 Mdot
.6761 .20362 Mdot
.49965 .88508 Mdot
.50614 .66442 Mdot
.43134 .13442 Mdot
.54267 .82432 Mdot
.66924 .74773 Mdot
.6069 .3251 Mdot
.51545 .16046 Mdot
.48187 .95339 Mdot
.38278 .28964 Mdot
.5828 .82404 Mdot
.44755 .25389 Mdot
.71867 .56479 Mdot
.67619 .72388 Mdot
.43098 .34437 Mdot
.43935 .75515 Mdot
.60495 .58911 Mdot
.61258 .77479 Mdot
.72316 .47295 Mdot
.4187 .33435 Mdot
.58731 .54226 Mdot
.37324 .73558 Mdot
.60649 .42163 Mdot
.53593 .697 Mdot
.61313 .25822 Mdot
.50377 .36454 Mdot
.62795 .41049 Mdot
.37257 .52042 Mdot
.47032 .94921 Mdot
.70971 .4012 Mdot
.39339 .22215 Mdot
.37254 .46449 Mdot
.41238 .30585 Mdot
.44608 .9365 Mdot
.59453 .88258 Mdot
.66797 .5852 Mdot
.44572 .15192 Mdot
.59214 .72807 Mdot
.72092 .45737 Mdot
.67168 .44479 Mdot
.49476 .78281 Mdot
.37185 .48328 Mdot
.6055 .77736 Mdot
.44077 .68718 Mdot
.53127 .70396 Mdot
.57922 .4126 Mdot
.44505 .22602 Mdot
.72017 .52028 Mdot
.70332 .2503 Mdot
.62377 .39329 Mdot
.51451 .3762 Mdot
.53654 .89101 Mdot
.38128 .6896 Mdot
.65326 .78506 Mdot
.44744 .74181 Mdot
.57675 .90009 Mdot
.42945 .58343 Mdot
.65572 .27013 Mdot
.66848 .19369 Mdot
.67305 .29377 Mdot
.60822 .86235 Mdot
.49513 .13253 Mdot
.3863 .81761 Mdot
.61232 .77595 Mdot
.54184 .47851 Mdot
.36325 .40295 Mdot
.72404 .5562 Mdot
.51096 .98084 Mdot
.68412 .71169 Mdot
.58949 .52689 Mdot
.76464 .40654 Mdot
.52054 .81824 Mdot
.45828 .31333 Mdot
.46746 .301 Mdot
.52132 .45959 Mdot
.5665 .36097 Mdot
.77175 .44589 Mdot
.56663 .78161 Mdot
.48354 .27704 Mdot
.6105 .34073 Mdot
.50779 .28666 Mdot
.44048 .33385 Mdot
.56841 .45869 Mdot
.5019 .09439 Mdot
.52231 .76604 Mdot
.67196 .44799 Mdot
.48461 .76357 Mdot
.58537 .74279 Mdot
.54423 .71773 Mdot
.58948 .88863 Mdot
.42535 .52606 Mdot
.63912 .54132 Mdot
.69169 .7033 Mdot
.54242 .72696 Mdot
.52772 .08072 Mdot
.66808 .42008 Mdot
.67202 .4982 Mdot
.52281 .68272 Mdot
.53408 .27421 Mdot
.423 .83994 Mdot
.44509 .70306 Mdot
.68012 .71174 Mdot
.36076 .45316 Mdot
.5538 .54843 Mdot
.51045 .43592 Mdot
.76969 .44837 Mdot
.56908 .30499 Mdot
.56796 .55278 Mdot
.37139 .70946 Mdot
.51259 .74736 Mdot
.52476 .85708 Mdot
.5286 .13334 Mdot
.55514 .80406 Mdot
.37636 .24101 Mdot
.55803 .22404 Mdot
.67763 .52497 Mdot
.59035 .66774 Mdot
.68021 .31166 Mdot
.50751 .69321 Mdot
.37852 .64245 Mdot
.60335 .43346 Mdot
.5933 .6583 Mdot
.4919 .94161 Mdot
.52818 .96084 Mdot
.52424 .41377 Mdot
.54 .46518 Mdot
.37335 .51012 Mdot
.4132 .68757 Mdot
.53951 .68086 Mdot
.45698 .12844 Mdot
.48657 .63869 Mdot
.71844 .59013 Mdot
.57589 .13529 Mdot
.54867 .25755 Mdot
.56819 .55078 Mdot
.67249 .5307 Mdot
.52911 .55602 Mdot
.60018 .3967 Mdot
.62155 .64671 Mdot
.52836 .30762 Mdot
.55007 .21711 Mdot
.63413 .71391 Mdot
.40037 .47623 Mdot
.63962 .70624 Mdot
.43805 .16054 Mdot
.45161 .24112 Mdot
.50129 .17998 Mdot
.37282 .5441 Mdot
.43278 .69773 Mdot
.49148 .19659 Mdot
.62066 .20092 Mdot
.56754 .44386 Mdot
.6245 .39041 Mdot
.50696 .92929 Mdot
.48304 .71672 Mdot
.43764 .70999 Mdot
.39168 .23391 Mdot
.70224 .65744 Mdot
.421 .30909 Mdot
.45827 .33461 Mdot
.513 .23848 Mdot
.6567 .66607 Mdot
.58303 .58752 Mdot
.66195 .41253 Mdot
.66632 .19137 Mdot
.49596 .04508 Mdot
.6972 .6634 Mdot
.49425 .04572 Mdot
.49601 .64369 Mdot
.47909 .03354 Mdot
.36441 .6043 Mdot
.67027 .61218 Mdot
.68834 .68882 Mdot
.37681 .85518 Mdot
.47951 .15938 Mdot
.52016 .16213 Mdot
.52908 .84668 Mdot
.67767 .30747 Mdot
.60705 .85513 Mdot
.53403 .31909 Mdot
.61337 .19113 Mdot
.4037 .60398 Mdot
.43086 .50062 Mdot
.48871 .08358 Mdot
.59917 .62059 Mdot
.55284 .16228 Mdot
.38957 .83924 Mdot
.53067 .46544 Mdot
.63547 .57752 Mdot
.49877 .84517 Mdot
.71749 .52567 Mdot
.52567 .5878 Mdot
.64786 .79383 Mdot
.43788 .97291 Mdot
.54417 .03882 Mdot
.55307 .47143 Mdot
.61298 .33906 Mdot
.43017 .80886 Mdot
.45811 .94205 Mdot
.54522 .29636 Mdot
.44683 .34083 Mdot
.47295 .67203 Mdot
.58593 .67658 Mdot
.70457 .66516 Mdot
.37534 .57926 Mdot
.48954 .73437 Mdot
.44821 .09847 Mdot
.49387 .69849 Mdot
.52172 .46584 Mdot
.41617 .81701 Mdot
.58435 .27454 Mdot
.44831 .1475 Mdot
.41199 .309 Mdot
.55671 .33192 Mdot
.77074 .60311 Mdot
.40674 .63324 Mdot
.44008 .87257 Mdot
.53335 .60271 Mdot
.71796 .46529 Mdot
.5684 .5175 Mdot
.59481 .80309 Mdot
.3875 .61288 Mdot
.4196 .53001 Mdot
.57318 .62703 Mdot
.69501 .68825 Mdot
.47905 .03212 Mdot
.6434 .69172 Mdot
.45797 .16706 Mdot
.53606 .78922 Mdot
.61287 .76418 Mdot
.58722 .35198 Mdot
.69565 .6854 Mdot
.56781 .06142 Mdot
.67722 .53961 Mdot
.67262 .73922 Mdot
.64127 .80526 Mdot
.57476 .90569 Mdot
.51949 .56637 Mdot
.54872 .2604 Mdot
.67466 .72628 Mdot
.71775 .60069 Mdot
.5146 .59835 Mdot
.65095 .3661 Mdot
.41096 .66429 Mdot
.61634 .35502 Mdot
.58784 .74172 Mdot
.62137 .20627 Mdot
.52902 .85042 Mdot
.42962 .0843 Mdot
.40067 .80329 Mdot
.41456 .19059 Mdot
.44938 .04661 Mdot
.41727 .17772 Mdot
.62615 .82269 Mdot
.40115 .18478 Mdot
.63492 .4433 Mdot
.48544 .32377 Mdot
.49504 .99183 Mdot
.61384 .51443 Mdot
.48157 .66901 Mdot
.64472 .8023 Mdot
.63124 .30089 Mdot
.44348 .35314 Mdot
.41477 .45221 Mdot
.46043 .82567 Mdot
.56338 .58844 Mdot
.62986 .21251 Mdot
.67516 .44997 Mdot
.36176 .46671 Mdot
.64735 .79605 Mdot
.57066 .71198 Mdot
.77343 .5654 Mdot
.55154 .75727 Mdot
.43857 .24198 Mdot
.48016 .19175 Mdot
.45942 .35573 Mdot
.70875 .64662 Mdot
.69456 .68618 Mdot
.56777 .5399 Mdot
.42316 .58412 Mdot
.56572 .59162 Mdot
.48883 .76348 Mdot
.44023 .98298 Mdot
.58943 .54987 Mdot
.66908 .58541 Mdot
.4414 .30042 Mdot
.53177 .7068 Mdot
.52114 .60963 Mdot
.59001 .48782 Mdot
.55356 .7475 Mdot
.55789 .62383 Mdot
.49886 .29931 Mdot
.36617 .65703 Mdot
.7194 .56055 Mdot
.48017 .62215 Mdot
.39349 .56827 Mdot
.57326 .71212 Mdot
.63499 .4669 Mdot
.4021 .55907 Mdot
.51799 .73693 Mdot
.73835 .32016 Mdot
.50769 .87957 Mdot
.64323 .88648 Mdot
.5576 .80732 Mdot
.52331 .36782 Mdot
.67683 .31835 Mdot
.66848 .73982 Mdot
.56538 .4453 Mdot
.38845 .62275 Mdot
.76824 .61468 Mdot
.42019 .5296 Mdot
.4302 .4851 Mdot
.46742 .19648 Mdot
.67342 .5266 Mdot
.4267 .24329 Mdot
.75259 .36635 Mdot
.42619 .45469 Mdot
.39366 .55465 Mdot
.46338 .86235 Mdot
.50988 .69059 Mdot
.52784 .44389 Mdot
.41786 .5993 Mdot
.7185 .60543 Mdot
.53222 .53092 Mdot
.47055 .95334 Mdot
.43684 .87206 Mdot
.63063 .61564 Mdot
.63099 .72967 Mdot
.65077 .36917 Mdot
.58628 .66969 Mdot
.68038 .20662 Mdot
.41807 .39742 Mdot
.70202 .67405 Mdot
.52827 .96159 Mdot
.52786 .30754 Mdot
.48064 .03313 Mdot
.40067 .5179 Mdot
.60901 .52845 Mdot
.59801 .79799 Mdot
.57667 .76597 Mdot
.40706 .49351 Mdot
.57154 .63473 Mdot
.53709 .78164 Mdot
.37979 .20972 Mdot
.5023 .14436 Mdot
.5019 .58601 Mdot
.43243 .17972 Mdot
.46362 .16651 Mdot
.5213 .5545 Mdot
.55344 .49631 Mdot
.39714 .37258 Mdot
.50949 .15052 Mdot
.50088 .32924 Mdot
.4353 .78003 Mdot
.69627 .35944 Mdot
.57482 .38322 Mdot
.62961 .61055 Mdot
.45373 .78644 Mdot
.4263 .70196 Mdot
.4856 .68875 Mdot
.5872 .95817 Mdot
.47573 .69456 Mdot
.41007 .79146 Mdot
.52677 .08197 Mdot
.66639 .5995 Mdot
.46209 .79278 Mdot
.56496 .85145 Mdot
.66891 .75279 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:Gooooo0_l00005ooooo`03o`000?oooooooooo0;Wo
oooo002Uooooo`;o00001Oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`0;ooooo`;o0000[?ooool00:cooooo00?o0000ooooooooool02oooool2o`000:cooooo002Koooo
o`;o00003Oooool3o`000;_ooooo002Kooooo`;o00003Oooool3o`000;_ooooo002/ooooo`?o0000
^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool04oooool2o`000:Cooooo002/ooooo`03o`000?oooooooooo01?o
oooo0_l0002Tooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`03ooooo`;o0000]?ooool00:cooooo00?o0000ooooooooool00oooool2o`000;Cooooo002/oooo
o`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
1Oooool3o`000;7ooooo002Dooooo`;o00004_ooool2o`0000;ooooo00?o0000ooooooooool01Ooo
ool3o`000;7ooooo002Dooooo`;o00004_ooool2o`0000;ooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo0_l0002jooooo`00V_ooool2o`00013ooooo
0_l0002jooooo`00V_ooool2o`00013ooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00ROooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo0;Wooooo0021ooooo`Ko00000_ooool01Ol@413ooooooooo
oooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000
^Oooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ol0003o000000Kooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2iooooo`00ROooool01Ol0003ooooooooo
oooooooo000000kooooo00CoEEEEo`000?l0003o00000_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool0^Oooool008Wooooo00Go410@oooooooooooooooooa0@4007oooo
o`;o00001Oooool01?nYZJWoMgMgo`000?l00002ooooo`03o`000?oooooooooo00Gooooo0ol00007
ooooo`?o0000/Oooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`;o00000_ooool0
1Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01Oooool3o`0000Oooooo0ol0
000>ooooo`;o0000XOooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?oo
ool4o`0000Kooooo00?o0000ooooooooool05_ooool2o`000:7ooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002Dooooo`;o00005_ooool2o`000;[ooooo002Dooooo`;o00001?ooool2o`00013o
oooo0_l0002jooooo`00V_ooool2o`00013ooooo1Ol0002gooooo`00V_ooool2o`00013ooooo00?o
0000ooooooooool00_l0002gooooo`00[?ooool00ol0003oooooooooo`2iooooo`00Uoooool2o`00
00cooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo0ol0002dooooo`00Uoooool2o`0000co
oooo0_l00005ooooo`03o`000?oooooooooo00;ooooo0ol00009ooooo`;o0000ZOooool009kooooo
1?l0000:ooooo`03o`000?oooooooooo00kooooo0_l0002Yooooo`00W_ooool4o`0000[ooooo00?o
0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0000Ooooo
o`;o0000V?ooool0093ooooo0_l00003ooooo`;o00005Oooool2o`00023ooooo0_l0002Hooooo`00
T?ooool2o`0000?ooooo0_l00005ooooo`;o00003_ooool2o`00023ooooo0_l0002Hooooo`00Rooo
ool2o`0000oooooo0_l0000>ooooo`03o`000?oooooooooo0;Wooooo002;ooooo`;o00007oooool0
0ol0003oooooooooo`0Dooooo`;o00003?ooool2o`0009Gooooo002?ooooo`;o00005?ooool2o`00
00Gooooo00?o0000ooooooooool05?ooool2o`0000cooooo0_l0000?ooooo`;o0000Q?ooool008oo
oooo0_l0000Dooooo`;o00001Oooool00ol0003oooooooooo`0Fooooo`;o00002_ooool2o`0000oo
oooo0ol00023ooooo`00XOooool2o`0000Kooooo0_l000000ooooooo0000ooooo`0Gooooo`;o0000
7?ooool2o`0008?ooooo002Qooooo`;o00001_ooool2o`000004ooooool0003o0000o`0002Cooooo
0_l0002Cooooo`00[?ooool00ol0003oooooooooo`0Tooooo`;o00004Oooool2o`00083ooooo002/
ooooo`03o`000?oooooooooo00?ooooo0_l0000Pooooo`;o00004?ooool3o`0007oooooo0024oooo
o`;o00009_ooool00ol0003oooooooooo`03ooooo`;o00008?ooool2o`00017ooooo0_l0001ooooo
o`00Q?ooool2o`0000?ooooo0_l0000Qooooo`03o`000?oooooooooo01[ooooo0_l0000;ooooo`;o
0000T?ooool008Wooooo0_l0000Qooooo`03o`000?oooooooooo01Wooooo0ol0000;ooooo`;o0000
T?ooool00:cooooo00?o0000ooooooooool03Oooool2o`0000[ooooo0_l0002Nooooo`00R?ooool2
o`0002;ooooo00?o0000ooooooooool03Oooool2o`000:[ooooo0028ooooo`;o00001_ooool2o`00
01[ooooo0ol0000@ooooo`;o0000Yoooool0093ooooo0_l00007ooooo`;o00004Oooool00ol0003o
ooooooooo`0@ooooo`;o0000Yoooool009Wooooo0_l0000Aooooo`03o`000?oooooooooo0;Wooooo
0023ooooo`;o00000oooool2o`0002;ooooo00?o0000ooooooooool0^Oooool008?ooooo0_l00003
ooooo`;o00004oooool2o`0000gooooo00?o0000ooooooooool0^Oooool008?ooooo0_l0000Hoooo
o`;o00003Oooool01?l0003oooooooooooooool2o`000;Kooooo0023ooooo`;o00003?ooool01_o^
k^ko<S8bo`000?l0003ok^k^ooooo`;o00000_ooool00olQ8B7o0000o`000004ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool01?l0003oooooooooooooool2o`000;Kooooo002Aooooo`06ogMg
MonHV9So0000o`000?mgMgOooooo0_l00002ooooo`?o00001oooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo023ooooo0_l0002Gooooo`00ROooool6o`0000;ooooo00Go410@oooooooo
oooooooooa0@4005ooooo`;o00002Oooool00ol0003oooooooooo`03ooooo`?o00008?ooool2o`00
09Oooooo002Aooooo`05o`000?ooooooooooooooool000003Oooool2o`000003ogMgMolb<S;ooooo
00Cooooo0ol00010ooooo`;o0000Moooool0097ooooo00Go0000ooooooooooooooooo`000004oooo
o`;o00001_ooool3o`000003oc8b<_o<c<cooooo00Cooooo00?o0000ooooooooool0@?ooool2o`00
07Oooooo002Aooooo`05oa0@4?ooooooooooooooool@41001?ooool2o`0000Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0=ooooo`;o00004oooool2o`0009Gooooo002Aooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00gooooo0_l0000Cooooo`;o0000UOooool0097ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`Co00001_ooool00ol0003oooooooooo`0=ooooo`;o0000Z_ooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0<?ooool2o`0008Oooooo002/ooooo`03o`000?oo
oooooooo00Sooooo0_l0000Hooooo`;o00003?ooool2o`0001;ooooo0_l0001cooooo`00Y_ooool2
o`0000Cooooo0ol00002ooooo`;o00001?ooool2o`0000kooooo0_l00008ooooo`;o00008?ooool2
o`0007?ooooo002:ooooo`;o00006_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool2o`00
01Cooooo0_l0002Oooooo`00R_ooool2o`00023ooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0=?ooool2o`0008?ooooo002/ooooo`04o`000?oooooo0000o`0003?ooooo
0_l00023ooooo`00QOooool2o`0000oooooo0_l0000Dooooo`04o`000?oooooo0000o`000;Sooooo
0025ooooo`;o00003oooool2o`0001Cooooo00Co0000ooooool0003o00006_ooool2o`0000[ooooo
0_l0000;ooooo`Co0000POooool00:cooooo00?o0000ooooooooool02oooool2o`0000kooooo0_l0
000:ooooo`;o00002oooool4o`00087ooooo002Hooooo`;o00001oooool2o`0000Sooooo1?l0000;
ooooo`;o00006_ooool3o`0000_ooooo0_l00022ooooo`00V?ooool2o`0000Oooooo0_l00008oooo
o`;o0000:_ooool2o`0008oooooo002?ooooo`;o00006oooool01?l0003oooooooooooooool2o`00
00?ooooo0_l0000;ooooo`;o00008_ooool2o`00083ooooo002?ooooo`Co00006Oooool01?l0003o
ooooooooooooool2o`0000?ooooo0_l0000;ooooo`;o00008_ooool2o`00083ooooo002?ooooo`Co
00002oooool2o`0000cooooo00?o0000ooooooooool0>?ooool2o`0007oooooo002Nooooo`;o0000
3?ooool00ol0003oooooooooo`08ooooo`;o0000;_ooool2o`0000oooooo0_l0001^ooooo`00[?oo
ool00ol0003oooooooooo`08ooooo`;o0000;Oooool2o`00013ooooo0_l0001^ooooo`00Q?ooool2
o`0002Kooooo00?o0000ooooooooool02?ooool2o`0002gooooo0_l0000Booooo`;o0000K?ooool0
08Cooooo0_l0000Qooooo`;o00000oooool3o`00023ooooo0_l0000Yooooo`;o0000K?ooool00:Oo
oooo0_l00003ooooo`03o`000?oooooooooo023ooooo0_l0002Gooooo`00[?ooool2o`000;[ooooo
002Aooooo`;o00001Oooool2o`0000Cooooo0_l0000<ooooo`;o00002oooool2o`0000?ooooo0_l0
002Xooooo`00TOooool2o`0000Gooooo0_l00004ooooo`;o00003?ooool00ol0003oooooooooo`0:
ooooo`;o00000oooool2o`000:Sooooo002;ooooo`;o00003Oooool2o`00013ooooo00?o0000oooo
ooooool08Oooool3o`0009Gooooo002;ooooo`;o00003Oooool2o`00013ooooo00?o0000oooooooo
ool08Oooool3o`0009Gooooo002Eooooo`;o00005Oooool00ol0003oooooooooo`2iooooo`00T?oo
ool2o`0000?ooooo0_l0000Eooooo`03o`000?oooooooooo0;Wooooo002@ooooo`;o00006_ooool3
o`0001Wooooo0_l0002Nooooo`00VOooool2o`0000?ooooo0_l0000<ooooo`03o`000?oooooooooo
01Wooooo0_l00008ooooo`;o00006?ooool2o`0007[ooooo002Iooooo`;o00000oooool2o`0000co
oooo00?o0000ooooooooool08oooool2o`0001Sooooo0_l0001jooooo`00[?ooool00ol0003ooooo
ooooo`0Cooooo`;o0000:?ooool3o`0007Wooooo002/ooooo`?o00004oooool2o`0002Sooooo0ol0
001iooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo0ol00004ooooo`;o00000_ooool2o`0002Cooooo
0_l0000Pooooo`;o0000Ioooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`04ooooo`;o00000_ooool2o`0002Cooooo0_l0000Pooooo`;o0000Ioooool0087ooooo
1_l00002ooooo`05oa0@4?l0003o0000ooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0;_ooool2o`0008Wooooo0029ooooo`?o0000
00?oooooo`000?ooool03?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo
0ol000000ooooooo0000o`00002fooooo`00ROooool01Ol0003ooooooooooooooooo000000kooooo
00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00Co0000oooooooo
oooooooo0_l0002fooooo`00ROooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Gooooo0_l0002Roooo
o`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05Oooool2o`000:;ooooo0029oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01?nHV9So410@o`000?lQ8B42o`0000?ooooo1?l0
0006ooooo`03o`000?oooooooooo0;Wooooo002Mooooo`;o00003Oooool00ol0003oooooooooo`0V
ooooo`;o0000TOooool00:cooooo00?o0000ooooooooool09Oooool3o`00097ooooo002Aooooo`;o
00006Oooool00ol0003oooooooooo`0Fooooo`;o00001_ooool2o`0000Gooooo0_l0002Booooo`00
TOooool2o`0001Wooooo0ol0000Fooooo`;o00001_ooool2o`0001;ooooo0_l0000>ooooo`;o0000
MOooool007kooooo0_l0000/ooooo`03o`000?oooooooooo03;ooooo0_l0000=ooooo`?o0000MOoo
ool007kooooo0_l0000/ooooo`03o`000?oooooooooo047ooooo1?l0000?ooooo`;o0000Hoooool0
0:cooooo00?o0000ooooooooool09oooool2o`0001[ooooo0_l0000?ooooo`;o0000Hoooool00:co
oooo00?o0000ooooooooool05oooool2o`0000kooooo0_l00009ooooo`;o0000QOooool00:cooooo
00?o0000ooooooooool00_ooool2o`000003ooooool0003o0000013ooooo0_l0000Iooooo`;o0000
QOooool00:cooooo00?o0000ooooooooool00_ooool2o`000003ooooool0003o00000;;ooooo002/
ooooo`03o`000?oooooooooo01Sooooo0_l00006ooooo`;o00004_ooool2o`0008?ooooo002/oooo
o`?o00006?ooool2o`0000Kooooo0_l0000Booooo`;o0000Poooool00:cooooo00?o0000oooooooo
ool01Oooool2o`0000[ooooo0_l0002Vooooo`00[?ooool00ol0003oooooooooo`05ooooo`;o0000
2_ooool2o`000:Kooooo002/ooooo`03o`000?oooooooooo01oooooo0_l0002Hooooo`00[?ooool0
0ol0003oooooooooo`02o`0001gooooo0_l0002Hooooo`00[?ooool00ol0003oooooooooo`02o`00
0;Oooooo002/ooooo`03o`000?oooooooooo00Kooooo0_l0000;ooooo`;o00005?ooool2o`0008ko
oooo002/ooooo`03o`000?oooooooooo00Kooooo0_l0000:ooooo`?o00005?ooool2o`0000[ooooo
0_l0000Oooooo`;o0000HOooool00:cooooo00?o0000ooooooooool04_ooool2o`0000gooooo0_l0
000Booooo`?o00007_ooool2o`00067ooooo002?ooooo`;o00006oooool3o`00027ooooo0_l0000B
ooooo`?o00007_ooool2o`00067ooooo001nooooo`;o00003oooool2o`0000;ooooo0_l0000Goooo
o`03o`000?oooooooooo03Cooooo0_l00023ooooo`00O_ooool2o`0001?ooooo0_l0000Gooooo`03
o`000?oooooooooo01?ooooo0_l0000Oooooo`;o00003oooool2o`0007;ooooo0009ooooo`Co0000
00?o410@ooooooooool05_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03
o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oM
gMd05_ooool00ol0003oooooooooo`04ooooo`;o00003Oooool2o`0000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0?
ooooo`?o000000?o<S8bonk^k_ooool01?ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool0
1?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1?l000000ol@413oooooooooo`0Booooo`00
2oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Ko
oooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Cooooo0_l000000olQ8B7oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01ooo
ool00omgMgOo<S8booooo`0Eooooo`03o`000?oooooooooo00Cooooo0_l0000Booooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03
ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEE
ojVYZOooool01oooool00omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo0006o`00
00Gooooo00?o0000ooooooooool04?ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=
ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool01Oooool6o`0000;ooooo00Go410@
oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`06oa0@4?oo
ooooooooooooool@413ooooo0_l000000ooooooo0000o`000006ooooo`03oiRHV?lQ8B7ok^k^00Wo
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`04ooooo`;o000000Coooooo`000?l0
003ooooo0_l0000<ooooo`05oa0@4?ooooooooooooooool@41003?ooool2o`000003onk^k_oooooo
oooo00Oooooo00?o0000ooooooooool03Oooool2o`0000;ooooo00?o410@ooooooooool03_ooool0
0ol0003oooooooooo`0=ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEoooo
o`08ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000
ooooooooool06?ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_oo
ool00omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8b
ooooo`0>ooooo`06o`000?ooooooooooooooool0003ooooo0_l0000:ooooo`03oiRHV?lQ8B7ok^k^
00Oooooo00?oMgMgoc8b<_ooool05Oooool00ol0003oooooooooo`04ooooo`;o000000Coooooo`00
0?l0003ooooo0_l0000<ooooo`05o`000?ooooooooooooooool000003?ooool2o`000003ob4Q8Oo^
k^kooooo00Kooooo00?oMgMgoc8b<_ooool03_ooool2o`0000;ooooo00?o0000ooooooooool03Ooo
ool00omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooo
ooooo`06ooooo`03ogMgMolb<S;ooooo01Wooooo00?o0000ooooooooool05?ooool000_ooooo00?o
0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool0
0oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000<oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Kooooo00?o0000ooooooooool0
3_ooool2o`0000Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`?o000000?oooooo`000?ooool02oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<
c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Jooooo`03o`000?oooooooooo01Cooooo
000;ooooo`03o`000?oooooooooo01Sooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVY
ZOmgMgOooooo00?ooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00co
oooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00kooooo0_l00004oooo
o`03o`000?oooooooooo01Sooooo0ol0000>ooooo`;o00002?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Aooooo`05oa0@4?l0003o
0000ooooool@41003?ooool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@4100
3_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
5?ooool000_ooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`03o`000?nj^[[ooooo00;o00001?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo00[ooooo0_l0000<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooo
oonHV9So410@00Cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00co
oooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooo
oooooooooooooc8b<P04ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05?ooool0
00Wooooo00?oEEEEofIVI_l000006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004
ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01?ooool2o`0000Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co
00005oooool00ol0003oooooooooo`0:ooooo`;o00003?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo
1?l0000Iooooo`03oeEEEOmVIVKo000001Kooooo0021ooooo`;o00004_ooool2o`0001Gooooo00?o
0000ooooooooool0^Oooool009Gooooo0_l0000Eooooo`03o`000?oooooooooo01[ooooo0_l0002M
ooooo`00[?ooool00ol0003oooooooooo`0Jooooo`;o0000T_ooool2o`0000;ooooo0_l00005oooo
o`00SOooool2o`0001gooooo00?o0000ooooooooool0A?ooool2o`0006Sooooo00Kok^k^ob4Q8On7
QhOo^[Zjo`000?oMgMd5ooooo`00SOooool2o`0001gooooo00?o0000ooooooooool03_ooool2o`00
00[ooooo0_l0000Iooooo`;o00003Oooool2o`0006Wooooo00CogMgMo`000?l@413oc<c<1_ooool0
00Ooooooool0001<o`0000cooooo00Cok^k^ob4Q8Ol@413ok^k^1_ooool000Oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`?o00001Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00[ooooo00Co8B4QogMgMomgMgOo<S8b1_ooool000Oooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Wooooo0_l00002oooo
o`;o00001Oooool008;ooooo0_l0000Xooooo`03o`000?oooooooooo0;Wooooo0022ooooo`;o0000
:?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0Rooooo`;o00008ooo
ool2o`00073ooooo002;ooooo`;o00007oooool00ol0003oooooooooo`0Cooooo`;o00003Oooool2
o`0002;ooooo0ol0001`ooooo`00POooool2o`0000Sooooo0_l0000Oooooo`03o`000?oooooooooo
01?ooooo0_l0000`ooooo`?o0000LOooool0087ooooo0_l0000Yooooo`?o0000=oooool2o`0000_o
oooo0ol0001booooo`00Toooool2o`0001Oooooo00?o0000ooooooooool06_ooool2o`0000Gooooo
0_l0000Cooooo`?o00002oooool2o`0007?ooooo002Aooooo`Co00005oooool00ol0003ooooooooo
o`07ooooo`;o00004Oooool2o`0000Gooooo0ol0000Booooo`;o0000POooool0097ooooo0_l0000I
ooooo`03o`000?oooooooooo00Oooooo0_l0000Iooooo`;o00004_ooool2o`00087ooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo01?ooooo0_l0000Rooooo`;o
0000P?ooool00:cooooo00?o0000ooooooooool04oooool2o`0000Cooooo0_l0000?ooooo`;o0000
2oooool2o`00083ooooo0022ooooo`;o00002oooool2o`0001_ooooo00?o0000ooooooooool06Ooo
ool2o`0000oooooo0_l0002=ooooo`00P_ooool2o`0000_ooooo0_l0000Kooooo`03o`000?oooooo
oooo00kooooo0_l0000:ooooo`;o0000WOooool00:cooooo0ol0000>ooooo`;o00000oooool2o`00
00Gooooo0_l00006ooooo`;o0000UOooool008Sooooo0_l0000Rooooo`03o`000?oooooooooo00Co
oooo1?l0000;ooooo`;o00003Oooool2o`0009Gooooo0028ooooo`;o000000?oooooo`000?l00000
7oooool00ol0003oooooooooo`04ooooo`Co0000?oooool2o`00073ooooo002;ooooo`;o00007ooo
ool00ol0003oooooooooo`15ooooo`Co0000L?ooool00:cooooo00?o0000ooooooooool0AOooool2
o`0007;ooooo002/ooooo`03o`000?oooooooooo00?ooooo0_l0000Dooooo`;o0000:_ooool2o`00
013ooooo0_l0001Pooooo`00R?ooool2o`0000?ooooo0_l0000Mooooo`03o`000?oooooooooo00?o
oooo0_l0000Dooooo`;o0000??ooool2o`00063ooooo001nooooo`;o00002?ooool2o`0000?ooooo
0_l0000Mooooo`03o`000?oooooooooo0;Wooooo001nooooo`;o0000;?ooool3o`0000gooooo0_l0
002Zooooo`00P_ooool2o`0002Sooooo00?o0000ooooooooool03Oooool2o`0001[ooooo0_l0002>
ooooo`00P_ooool2o`0002Sooooo00?o0000ooooooooool0:Oooool2o`0008kooooo002Booooo`Co
00005_ooool2o`00023ooooo0ol0000Booooo`;o0000Poooool009;ooooo1?l0000Fooooo`;o0000
1_ooool2o`0000[ooooo0_l00005ooooo`;o00001Oooool3o`0001;ooooo0_l00023ooooo`00[?oo
ool00ol0003oooooooooo`05ooooo`;o00001Oooool2o`0000?ooooo0ol00004ooooo`;o00001Ooo
ool2o`0002Cooooo0_l0001booooo`00[?ooool00ol0003oooooooooo`0<ooooo`;o00001?ooool2
o`00037ooooo0_l0001booooo`00[?ooool01?l0003oooooooooooooool2o`0002Kooooo0_l0002>
ooooo`00T?ooool2o`0001[ooooo0ol000000ooooooo0000o`00000Vooooo`;o00002?ooool2o`00
00oooooo0_l0001cooooo`00Ooooool2o`0000_ooooo0_l00002ooooo`;o00006_ooool00ol0003o
ooooooooo`08ooooo`;o0000:Oooool2o`0000oooooo0_l0000@ooooo`;o0000HOooool007oooooo
0_l0000;ooooo`;o00007Oooool2o`0000[ooooo0_l0000kooooo`;o00003oooool2o`00067ooooo
002[ooooo`;o00001_ooool2o`0000;ooooo0_l0000Mooooo`;o00007?ooool2o`0007;ooooo0026
ooooo`;o00009?ooool00ol0003oooooooooo`04ooooo`;o00008Oooool2o`0000cooooo0_l00022
ooooo`00Q_ooool2o`0002Cooooo00?o0000ooooooooool0:?ooool2o`0000_ooooo0_l0000Noooo
o`;o0000H_ooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`00
00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo02Sooooo0_l0000J
ooooo`;o00003oooool2o`0006;ooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`;o00001Oooool00ol0003ooooooooo
o`0Mooooo`;o00009Oooool2o`0007?ooooo0027ooooo`;o000000Go410@oooooooooooooooooa0@
400<ooooo`03oiRHV?lQ8B7ok^k^00Sooooo0_l00005ooooo`?o00004?ooool2o`0000_ooooo0_l0
002Jooooo`00Qoooool3o`0000?ooooo00?o0000ooooooooool02oooool2o`000003onk^k_oooooo
oooo00Gooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0@ooooo`;o00000oooool2
o`000:;ooooo0029ooooo`05o`000?ooooooooooooooool000003Oooool2o`000003ofIVI_oooooo
oooo00;ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo01Gooooo0_l0
002Rooooo`00ROooool01?l@413oooooooooooooool2o`0000kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Cooooo0_l0000Aooooo`;o0000T?oo
ool008Wooooo00CoMgMgoiRHV?ooooooV9RH0_l0000:ooooo`05o`000?nj^[[ooooooiRHV?l@4100
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Cooooo0_l0000Aooooo`;o0000
T?ooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`01?ooool4o`000003ooooool0003o000000?ooooo00?o0000ooooooooool0^Oooool008?ooooo
0_l0000Rooooo`;o000000Coooooo`000?l0003o0000^oooool008?ooooo0_l0000Uooooo`?o0000
9oooool2o`0001[ooooo0_l0001fooooo`00[?ooool00ol0003oooooooooo`08ooooo`;o00002_oo
ool2o`0000oooooo0_l0000Jooooo`;o00003oooool2o`0006Gooooo002/ooooo`?o00002?ooool2
o`0000[ooooo0_l0000looooo`;o0000IOooool00:cooooo00?o0000ooooooooool0^Oooool007oo
oooo0_l0000[ooooo`03o`000?oooooooooo01_ooooo0_l0000Rooooo`;o0000N?ooool007oooooo
0_l0000:ooooo`;o00007oooool00ol0003oooooooooo`0Kooooo`;o00008_ooool2o`0007Sooooo
002;ooooo`;o000000?oooooo`000?l000007?ooool01?l0003oooooo`000?l0000mooooo`;o0000
NOooool008kooooo0_l0000Looooo`04o`000?oooooo0000o`0001Wooooo0_l0000Booooo`Co0000
3?ooool4o`0007Oooooo002Uooooo`;o00001Oooool00ol0003oooooooooo`0Iooooo`?o00004_oo
ool4o`0000kooooo0_l0001gooooo`00Xoooool4o`0000Gooooo00?o0000ooooooooool06Oooool3
o`0002?ooooo0_l0000?ooooo`;o0000Ioooool0097ooooo0_l0000@ooooo`;o00001oooool3o`00
01Wooooo0_l0000Tooooo`;o00003oooool2o`0006Oooooo002Aooooo`;o00006Oooool00ol0003o
ooooooooo`0Iooooo`;o0000W_ooool00:cooooo00?o0000ooooooooool01?ooool2o`0000Cooooo
0_l0000aooooo`;o0000N_ooool00:cooooo00?o0000ooooooooool01?ooool2o`0000Cooooo0_l0
000aooooo`;o0000N_ooool008oooooo0_l00007ooooo`;o00003Oooool2o`0000?ooooo00?o0000
ooooooooool0>oooool4o`0007[ooooo0024ooooo`;o00002Oooool2o`0000Oooooo0_l0000=oooo
o`;o00000oooool00ol0003oooooooooo`02o`0000kooooo0_l0000Jooooo`;o00003Oooool4o`00
07[ooooo0024ooooo`;o00007_ooool2o`0000Kooooo00?o0000ooooool000000_l0000>ooooo`;o
00006_ooool2o`0000kooooo0_l0001kooooo`00UOooool2o`0000gooooo0_l00006ooooo`04o`00
0?oooooo0000o`0000Oooooo0_l0000booooo`;o0000Noooool008oooooo0_l00004ooooo`;o0000
4oooool5o`0000Sooooo0_l0002_ooooo`00Soooool2o`0000;ooooo0_l00004ooooo`;o00003ooo
ool3o`0000Gooooo0_l00002ooooo`;o0000<oooool2o`0007_ooooo002Cooooo`;o00001?ooool2
o`00017ooooo00?o0000ooooooooool00oooool2o`0000;ooooo0_l0000Fooooo`;o00002_ooool2
o`0000cooooo0_l000000ooooooo0000o`00001kooooo`00POooool2o`0001Cooooo0_l0000Coooo
o`03o`000?oooooooooo00Oooooo0_l0000Fooooo`;o00002_ooool2o`0000cooooo0_l0001noooo
o`00POooool2o`0001Cooooo0_l0000Cooooo`03o`000?oooooooooo01Cooooo0ol0000Qooooo`?o
0000O_ooool00:cooooo00?o0000ooooooooool05?ooool3o`0001;ooooo0_l0000=ooooo`?o0000
O_ooool009_ooooo0_l00009ooooo`;o00001?ooool00ol0003oooooooooo`0;ooooo`;o00007?oo
ool3o`0008gooooo002Kooooo`;o00002Oooool2o`0000Cooooo00?o0000ooooooooool02oooool2
o`0001gooooo0_l0002=ooooo`00W?ooool2o`0000kooooo0ol0000gooooo`;o0000P?ooool008[o
oooo0_l0000@ooooo`;o00003_ooool00ol0003oooooooooo`0;ooooo`;o00003_ooool2o`0001Wo
oooo0ol00020ooooo`00R_ooool2o`00023ooooo00?o0000ooooooooool02oooool2o`0000kooooo
0_l0000;ooooo`;o00003?ooool2o`00087ooooo002Xooooo`;o00000_ooool00ol0003ooooooooo
o`0Xooooo`;o0000Soooool008;ooooo0_l0000Sooooo`?o00000_ooool00ol0003oooooooooo`03
ooooo`;o0000<_ooool2o`00083ooooo0022ooooo`;o00008oooool2o`0000?ooooo00?o0000oooo
ooooool00oooool2o`0002oooooo1Ol00020ooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Cooooo0_l000000olQ8B7oooooooooo`03ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`08ooooo`;o00003oooool3o`0001Sooooo1?l00021ooooo`00TOooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Cooooo0_l000000olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool02?ooool2o`0000oooooo0ol0002Mooooo`00TOooool01Ol@
413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool01?l0003ooooooooooooo
ool2o`0000_ooooo0_l0000Tooooo`;o0000Poooool0097ooooo00Go0000ooooooooooooooooo`00
000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol000000ooooooo0000o`00000;ooooo`;o00009?oo
ool2o`0008?ooooo002Aooooo`05o`000?ooooooooooooooool000000_ooool2o`0000Sooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo02Cooooo0_l0000>ooooo`;o0000
Poooool0097ooooo00Go410@oooooooooooooooooa0@4002ooooo`;o00002?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00kooooo0_l0000Dooooo`;o0000Toooool0097ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
3_ooool2o`0000Oooooo0_l0002Pooooo`00S?ooool2o`0000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`So00000_ooool00ol0003oooooooooo`0Gooooo`;o00002Oooool2o`0009Gooooo
002<ooooo`;o00006?ooool4o`0000;ooooo00?o0000ooooooooool01?ooool2o`00013ooooo0_l0
000:ooooo`;o0000UOooool00:cooooo00?o0000ooooooooool01?ooool2o`00013ooooo0_l0002Q
ooooo`00[?ooool00ol0003oooooooooo`0Fooooo`;o0000XOooool00:cooooo0ol0000Fooooo`;o
00002_ooool2o`0009Gooooo002Fooooo`;o00005?ooool00ol0003oooooooooo`0Oooooo`;o0000
00?oooooo`000?l00000UOooool008kooooo0_l00006ooooo`;o00004_ooool3o`0000_ooooo0_l0
0008ooooo`;o00002_ooool2o`0009Sooooo002>ooooo`;o00006Oooool4o`0000?ooooo0_l00006
ooooo`;o00002?ooool2o`0001[ooooo0_l00028ooooo`00W?ooool2o`0000_ooooo0_l000000ooo
oooo0000ooooo`02ooooo`;o00001Oooool2o`0002Gooooo0_l00028ooooo`00S_ooool2o`0000co
oooo0_l0000>ooooo`03o`000?oooooooooo00Sooooo0_l0002_ooooo`00S_ooool2o`0000oooooo
0_l0000;ooooo`03o`000?oooooooooo02gooooo0_l0002:ooooo`00Woooool2o`0000Cooooo0_l0
0005ooooo`03o`000?oooooooooo01gooooo0_l0000>ooooo`;o0000R_ooool00:Gooooo0_l00005
ooooo`?o00007Oooool2o`0000kooooo0_l0002:ooooo`00Roooool2o`0001oooooo00?o0000oooo
ooooool03oooool2o`0000_ooooo0_l0000>ooooo`;o0000Roooool008_ooooo0_l0000Oooooo`03
o`000?oooooooooo00oooooo0ol0000:ooooo`;o00003Oooool3o`0008_ooooo002Eooooo`;o0000
5Oooool00ol0003oooooooooo`0@ooooo`;o00006Oooool2o`0008cooooo002Eooooo`;o00005Ooo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00Q_ooool2o`00
00Sooooo0_l0000Jooooo`03o`000?oooooooooo00?ooooo0_l0002dooooo`00Q_ooool2o`0000So
oooo0_l0000Jooooo`04o`000?ooooooooooooooo`Co00002?ooool2o`000:[ooooo002/ooooo`?o
000000?oooooo`000?l000002?ooool4o`0000Wooooo0ol0000;ooooo`;o0000TOooool009oooooo
0_l0000;ooooo`03o`000?oooooooooo00_ooooo0_l0000;ooooo`?o00002oooool2o`00097ooooo
002Oooooo`;o00002oooool00ol0003oooooooooo`2iooooo`00V?ooool2o`0001;ooooo00?o0000
ooooooooool0^Oooool009Sooooo0_l0000Booooo`03o`000?oooooooooo0;Wooooo0027ooooo`;o
00002Oooool2o`0001Sooooo00?o0000ooooooooool0^Oooool008Oooooo0_l00009ooooo`;o0000
6?ooool00ol0003oooooooooo`2iooooo`00Zoooool2o`0000Sooooo0_l0002aooooo`00Zoooool2
o`0000Sooooo0_l0000:ooooo`;o0000YOooool00:cooooo0ol00006ooooo`;o00002_ooool2o`00
0:Gooooo0023ooooo`;o00009oooool00ol0003oooooooooo`06ooooo`;o00002_ooool2o`0000co
oooo0_l0002Gooooo`00Poooool2o`0001Wooooo0_l0000<ooooo`03o`000?oooooooooo00Gooooo
0_l0000Iooooo`;o0000Uoooool009kooooo0_l0000<ooooo`03o`000?oooooooooo00Gooooo0_l0
002booooo`00Woooool2o`0000_ooooo00?o0000ooooooooool08?ooool2o`0009Oooooo0029oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00Co0000onk^k_oooooooooo0_l0
00001_ooooooA4A4o`000?l0003o<S8bomgMg@Gooooo00?o0000ooooooooool07Oooool2o`000003
ooooool0003o000009Oooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Ko
oooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01go
oooo0_l0002Jooooo`00ROooool01Ol@413ooooooooooooooooo410@00;ooooo0_l00005ooooo`?o
000000?oooooojVYZOmEEED02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_o
oooo0_l0002Looooo`00ROooool01Ol0003ooooooooooooooooo000000;ooooo0_l00005ooooo`?o
00000_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Kooooo`;o
0000W?ooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`04o`000?oooooo0000o`0000_ooooo0_l0000=
ooooo`;o0000W?ooool008Wooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOo
oooo00?ooooo00?o0000ooooooooool01oooool01?l0003oooooo`000?l0000;ooooo`;o00003Ooo
ool3o`0009_ooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooo
oooooooo<S8b00Cooooo00?o0000ooooooooool01_ooool2o`0001kooooo0_l0002Kooooo`00ROoo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001Oooool2o`0001cooooo
0_l0000@ooooo`;o0000Roooool00:cooooo00?o0000ooooooooool02Oooool2o`0000oooooo0_l0
000@ooooo`;o0000Roooool00:cooooo00?o0000ooooooooool02Oooool2o`000:kooooo002/oooo
o`03o`000?oooooooooo00Sooooo0_l0002_ooooo`00[?ooool3o`0000Sooooo0_l0000<ooooo`;o
0000XOooool00:cooooo00?o0000ooooooooool05_ooool2o`000:7ooooo002/ooooo`03o`000?oo
oooooooo01Gooooo0_l0002Rooooo`00[?ooool00ol0003oooooooooo`0Eooooo`;o0000X_ooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo1?l0002h
ooooo`00[?ooool01?l0003oooooo`000?l0002hooooo`00[?ooool4o`000;Sooooo002/ooooo`Co
0000^?ooool009[ooooo0_l0000@ooooo`;o0000^_ooool009[ooooo0ol0000?ooooo`03o`000?oo
oooooooo0;Wooooo002Kooooo`;o000000?oooooo`000?l000002Oooool2o`000003ooooool0003o
oooo0;[ooooo002Nooooo`;o00002Oooool2o`000003ooooool0003ooooo0;[ooooo002Rooooo`;o
00002?ooool00ol0003oooooooooo`2iooooo`00X_ooool2o`0000Sooooo0ol0002iooooo`00X_oo
ool2o`0000;ooooo0_l00004ooooo`03o`000?oooooooooo0;Wooooo002Rooooo`;o00000_ooool2
o`0000Cooooo00?o0000ooooooooool06Oooool2o`0009kooooo002/ooooo`03o`000?oooooooooo
00Kooooo0_l0000Aooooo`;o0000W_ooool00:cooooo00?o0000ooooooooool01_ooool2o`000;7o
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002G
ooooo`;o00004oooool00ol0003oooooooooo`2iooooo`00Uoooool2o`0001?ooooo0ol0000Doooo
o`;o0000Xoooool00:cooooo00?o0000ooooooooool05?ooool2o`000:?ooooo002Hooooo`;o0000
4_ooool00ol0003oooooooooo`02o`000;Oooooo002Hooooo`;o00004_ooool00ol0003ooooooooo
o`02o`000;Oooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Zooooo`?o0000^oooool00:;o
oooo1?l000001?l@413oooooooooooooool3o`000;_ooooo002Tooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000ooooooooool01Oooool3o`000;Wooooo
002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Toooo
o`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Rooooo`03oeEE
EOmVIVKo00000<?ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo002Zooooo`04oa0@4?l0003o0000o`000;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`06o`000?mgMgOo0000o`000?mEEEGok^k^
]oooool00:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomEEEFgooooo`00Zoooool00ol0003ok^k^
ooooo`02ooooo`03o`000?oooooooooo0;Gooooo002[ooooo`03o`000?o^k^kooooo00;ooooo00?o
0000ooooooooool0]Oooool00:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomVIVJgooooo`00Z_oo
ool00ol@413o0000ogMgM`02o`000003ofIVI_o^k^kooooo0;Kooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.64574 .50531 Mdot
.55126 .82414 Mdot
.45464 .60116 Mdot
.42599 .3739 Mdot
.49554 .19651 Mdot
.4719 .11594 Mdot
.50846 .59555 Mdot
.72082 .40455 Mdot
.54522 .09294 Mdot
.42445 .6613 Mdot
.49409 .22796 Mdot
.72966 .49388 Mdot
.42242 .14384 Mdot
.44313 .25251 Mdot
.72447 .50586 Mdot
.55489 .44958 Mdot
.5994 .38542 Mdot
.43761 .10635 Mdot
.50463 .77411 Mdot
.67483 .6249 Mdot
.43733 .11146 Mdot
.44364 .88885 Mdot
.40784 .78187 Mdot
.46526 .07449 Mdot
.70439 .66514 Mdot
.53303 .76021 Mdot
.547 .35013 Mdot
.52639 .72604 Mdot
.65906 .67826 Mdot
.54318 .83394 Mdot
.48296 .07971 Mdot
.55131 .09752 Mdot
.6902 .31926 Mdot
.60908 .58114 Mdot
.52697 .81169 Mdot
.67766 .46661 Mdot
.42919 .9118 Mdot
.56669 .58662 Mdot
.6378 .72437 Mdot
.73221 .53556 Mdot
.70358 .67982 Mdot
.57861 .70485 Mdot
.39752 .64485 Mdot
.64515 .57306 Mdot
.64168 .43413 Mdot
.59117 .44863 Mdot
.41988 .36839 Mdot
.45175 .03869 Mdot
.40385 .36428 Mdot
.66465 .64827 Mdot
.43946 .05628 Mdot
.58095 .83684 Mdot
.77908 .44694 Mdot
.45604 .86086 Mdot
.42728 .80915 Mdot
.62767 .20251 Mdot
.72232 .41698 Mdot
.60039 .38455 Mdot
.37329 .39337 Mdot
.63447 .39721 Mdot
.59368 .48936 Mdot
.43768 .98449 Mdot
.63327 .73168 Mdot
.53547 .40469 Mdot
.67463 .29429 Mdot
.59639 .15427 Mdot
.43844 .72181 Mdot
.53951 .37601 Mdot
.56352 .61164 Mdot
.50465 .09252 Mdot
.61772 .47045 Mdot
.4524 .3425 Mdot
.42196 .64093 Mdot
.49824 .75217 Mdot
.63355 .73095 Mdot
.50028 .40678 Mdot
.77914 .44758 Mdot
.58598 .58463 Mdot
.60645 .79496 Mdot
.41027 .67016 Mdot
.61048 .2532 Mdot
.55511 .81342 Mdot
.42082 .55811 Mdot
.56775 .73278 Mdot
.6915 .31539 Mdot
.56 .50164 Mdot
.51109 .2215 Mdot
.54644 .29656 Mdot
.58439 .32911 Mdot
.54277 .39014 Mdot
.70128 .67246 Mdot
.6195 .11614 Mdot
.53399 .61789 Mdot
.57399 .36774 Mdot
.54437 .54443 Mdot
.58443 .07283 Mdot
.43382 .28272 Mdot
.4393 .0597 Mdot
.7827 .47331 Mdot
.59398 .35244 Mdot
.64311 .56004 Mdot
.55017 .24981 Mdot
.72695 .48287 Mdot
.63659 .62023 Mdot
.58179 .19867 Mdot
.60239 .61977 Mdot
.61819 .51217 Mdot
.4547 .79317 Mdot
.53247 .62482 Mdot
.50755 .09717 Mdot
.41376 .43052 Mdot
.42258 .40146 Mdot
.54091 .08602 Mdot
.68443 .51744 Mdot
.72071 .77558 Mdot
.46246 .29665 Mdot
.59221 .54171 Mdot
.63582 .20756 Mdot
.60295 .16019 Mdot
.45602 .94754 Mdot
.418 .1591 Mdot
.51536 .98257 Mdot
.38758 .3577 Mdot
.65388 .69601 Mdot
.51063 .10018 Mdot
.44785 .27726 Mdot
.68208 .55362 Mdot
.51754 .00362 Mdot
.61369 .68508 Mdot
.53191 .46442 Mdot
.40463 .76971 Mdot
.6324 .62432 Mdot
.72834 .54773 Mdot
.49694 .12535 Mdot
.39364 .39581 Mdot
.62605 .76069 Mdot
.44903 .94814 Mdot
.67241 .62404 Mdot
.42721 .67311 Mdot
.70459 .36479 Mdot
.72574 .52388 Mdot
.36197 .59074 Mdot
.45055 .72589 Mdot
.54404 .68432 Mdot
.60059 .38911 Mdot
.6825 .57479 Mdot
.67234 .27295 Mdot
.63562 .90933 Mdot
.45102 .78167 Mdot
.56421 .34226 Mdot
.55038 .94692 Mdot
.53514 .22163 Mdot
.57472 .497 Mdot
.47666 .07101 Mdot
.43943 .40351 Mdot
.55215 .21049 Mdot
.50162 .94287 Mdot
.61743 .76887 Mdot
.63019 .2012 Mdot
.432 .91643 Mdot
.48941 .95506 Mdot
.44616 .81542 Mdot
.604 .80126 Mdot
.70756 .68258 Mdot
.66205 .3852 Mdot
.40534 .70315 Mdot
.64337 .52807 Mdot
.66387 .25737 Mdot
.60959 .24479 Mdot
.56827 .58379 Mdot
.49366 .95398 Mdot
.67644 .57736 Mdot
.52501 .64481 Mdot
.57285 .50396 Mdot
.50426 .2126 Mdot
.42167 .69002 Mdot
.68828 .32028 Mdot
.56344 .0503 Mdot
.54109 .19329 Mdot
.44275 .35326 Mdot
.65294 .69101 Mdot
.53768 .90179 Mdot
.72729 .58506 Mdot
.53941 .64748 Mdot
.69678 .70009 Mdot
.50307 .68135 Mdot
.52377 .07013 Mdot
.55055 .09377 Mdot
.71317 .66235 Mdot
.39042 .49161 Mdot
.56878 .92065 Mdot
.6827 .57595 Mdot
.49327 .28062 Mdot
.70652 .3562 Mdot
.66329 .78084 Mdot
.7288 .51169 Mdot
.56025 .32689 Mdot
.68726 .20654 Mdot
.60784 .61824 Mdot
.43787 .6134 Mdot
.43319 .57596 Mdot
.46831 .3141 Mdot
.47168 .18678 Mdot
.71011 .24589 Mdot
.63927 .58161 Mdot
.42448 .51095 Mdot
.5068 .14073 Mdot
.42194 .40251 Mdot
.44619 .68667 Mdot
.51189 .25869 Mdot
.38065 .47027 Mdot
.58873 .56604 Mdot
.61116 .24799 Mdot
.55352 .57275 Mdot
.64248 .54279 Mdot
.59132 .51773 Mdot
.70493 .68863 Mdot
.49143 .71114 Mdot
.61565 .34132 Mdot
.73301 .5033 Mdot
.5932 .52696 Mdot
.37602 .35836 Mdot
.59612 .22008 Mdot
.6313 .2982 Mdot
.5559 .48272 Mdot
.42329 .29005 Mdot
.57057 .79424 Mdot
.52854 .63445 Mdot
.72481 .51174 Mdot
.53317 .34843 Mdot
.45623 .35854 Mdot
.70904 .24837 Mdot
.45388 .16729 Mdot
.54907 .35278 Mdot
.54448 .949 Mdot
.57153 .54736 Mdot
.62759 .65708 Mdot
.38814 .34301 Mdot
.63676 .60406 Mdot
.4398 .98673 Mdot
.42085 .20328 Mdot
.64761 .32497 Mdot
.61745 .46774 Mdot
.56488 .11166 Mdot
.5448 .49321 Mdot
.52736 .90819 Mdot
.53673 .23346 Mdot
.61662 .4583 Mdot
.62913 .74311 Mdot
.67252 .76084 Mdot
.45638 .307 Mdot
.48626 .27377 Mdot
.4992 .94163 Mdot
.53049 .76186 Mdot
.57186 .48086 Mdot
.39778 .65907 Mdot
.50718 .4528 Mdot
.71449 .39013 Mdot
.40539 .14717 Mdot
.4253 .2344 Mdot
.5485 .35078 Mdot
.64477 .3307 Mdot
.51152 .35602 Mdot
.51886 .1967 Mdot
.64024 .44671 Mdot
.42979 .3077 Mdot
.41488 .23486 Mdot
.6797 .51391 Mdot
.48596 .83101 Mdot
.68212 .50624 Mdot
.40889 .73477 Mdot
.42354 .65812 Mdot
.39946 .45443 Mdot
.50674 .93763 Mdot
.52919 .68181 Mdot
.4052 .4937 Mdot
.46187 .03185 Mdot
.50509 .24386 Mdot
.54066 .19041 Mdot
.63867 .72929 Mdot
.53484 .53042 Mdot
.53158 .66715 Mdot
.43493 .92135 Mdot
.72522 .45744 Mdot
.445 .77707 Mdot
.44251 .60885 Mdot
.41107 .38974 Mdot
.68313 .46607 Mdot
.57804 .38752 Mdot
.58696 .21253 Mdot
.37115 .50692 Mdot
.72256 .4634 Mdot
.37166 .51422 Mdot
.51393 .44483 Mdot
.37228 .58307 Mdot
.52184 .97023 Mdot
.67514 .41218 Mdot
.72387 .48882 Mdot
.58041 .97545 Mdot
.39966 .55401 Mdot
.39406 .37437 Mdot
.62775 .64668 Mdot
.56066 .10747 Mdot
.7091 .65513 Mdot
.43505 .28243 Mdot
.45156 .04144 Mdot
.51321 .79459 Mdot
.48468 .69258 Mdot
.38112 .53022 Mdot
.6074 .42059 Mdot
.4015 .2329 Mdot
.57412 .91764 Mdot
.47774 .28974 Mdot
.62648 .37752 Mdot
.59685 .64521 Mdot
.68776 .32567 Mdot
.52079 .3878 Mdot
.72539 .59383 Mdot
.61518 .85146 Mdot
.36844 .29446 Mdot
.50165 .27143 Mdot
.5086 .13906 Mdot
.56074 .7497 Mdot
.60944 .78138 Mdot
.43443 .24256 Mdot
.44635 .65742 Mdot
.51692 .51598 Mdot
.61656 .47658 Mdot
.73063 .46516 Mdot
.51391 .92251 Mdot
.54513 .53915 Mdot
.39314 .70384 Mdot
.53402 .50043 Mdot
.4706 .3129 Mdot
.56439 .8047 Mdot
.4561 .12511 Mdot
.40382 .69278 Mdot
.44693 .81643 Mdot
.45311 .20356 Mdot
.77199 .40311 Mdot
.51912 .78162 Mdot
.58104 .76392 Mdot
.53444 .40271 Mdot
.66408 .26529 Mdot
.5354 .3175 Mdot
.67604 .60309 Mdot
.51872 .86692 Mdot
.49354 .73541 Mdot
.58399 .42703 Mdot
.36264 .60755 Mdot
.73031 .48825 Mdot
.37198 .58356 Mdot
.68009 .49172 Mdot
.406 .64639 Mdot
.61175 .58922 Mdot
.67854 .56418 Mdot
.48806 .15617 Mdot
.72981 .4854 Mdot
.38114 .18939 Mdot
.65307 .33961 Mdot
.7283 .53922 Mdot
.72337 .60526 Mdot
.69703 .70569 Mdot
.50604 .36637 Mdot
.42612 .23383 Mdot
.72517 .52628 Mdot
.71803 .40069 Mdot
.51394 .39835 Mdot
.55739 .1661 Mdot
.5254 .7667 Mdot
.51835 .15502 Mdot
.64453 .54172 Mdot
.46456 .03314 Mdot
.62919 .65042 Mdot
.39407 .78808 Mdot
.56262 .85688 Mdot
.42053 .83085 Mdot
.38156 .70996 Mdot
.41713 .82181 Mdot
.71523 .62269 Mdot
.69134 .82961 Mdot
.42216 .89064 Mdot
.57224 .2433 Mdot
.43427 .49252 Mdot
.65197 .79233 Mdot
.57961 .31443 Mdot
.51683 .49022 Mdot
.72564 .6023 Mdot
.5116 .10089 Mdot
.44976 .66939 Mdot
.4776 .7733 Mdot
.56781 .6732 Mdot
.55876 .38844 Mdot
.4751 .02565 Mdot
.61515 .24997 Mdot
.72577 .59605 Mdot
.61545 .51198 Mdot
.75959 .3654 Mdot
.61445 .55727 Mdot
.42655 .7149 Mdot
.40659 .54416 Mdot
.44687 .59924 Mdot
.72739 .44662 Mdot
.72903 .48618 Mdot
.54373 .3399 Mdot
.50459 .70914 Mdot
.56236 .39162 Mdot
.55608 .56831 Mdot
.61922 .85458 Mdot
.56938 .34987 Mdot
.66325 .38541 Mdot
.4387 .6899 Mdot
.57449 .5068 Mdot
.52499 .40963 Mdot
.54514 .28782 Mdot
.61256 .5475 Mdot
.56742 .42383 Mdot
.42602 .43923 Mdot
.53336 .96442 Mdot
.70362 .36055 Mdot
.50123 .45848 Mdot
.50755 .84277 Mdot
.61811 .51212 Mdot
.58175 .2669 Mdot
.50367 .80596 Mdot
.57276 .53693 Mdot
.64517 .80678 Mdot
.62641 .12016 Mdot
.61952 .67957 Mdot
.75782 .68648 Mdot
.64053 .60732 Mdot
.44339 .31754 Mdot
.56417 .11835 Mdot
.72441 .53982 Mdot
.5035 .2453 Mdot
.52073 .86283 Mdot
.77411 .41468 Mdot
.49332 .73291 Mdot
.48144 .69881 Mdot
.41038 .59877 Mdot
.64406 .3266 Mdot
.42941 .76643 Mdot
.65913 .16635 Mdot
.47567 .72291 Mdot
.50453 .84389 Mdot
.58182 .69919 Mdot
.54612 .49059 Mdot
.46801 .29382 Mdot
.50908 .73145 Mdot
.72067 .40543 Mdot
.50459 .33092 Mdot
.61914 .77252 Mdot
.58064 .77277 Mdot
.63688 .41564 Mdot
.68286 .52967 Mdot
.55844 .16917 Mdot
.61415 .46969 Mdot
.52303 .00662 Mdot
.46492 .77077 Mdot
.73164 .47405 Mdot
.6729 .76159 Mdot
.42959 .30983 Mdot
.37186 .57638 Mdot
.49499 .82066 Mdot
.5804 .32845 Mdot
.67721 .59799 Mdot
.64306 .56597 Mdot
.48828 .79803 Mdot
.58543 .43473 Mdot
.60975 .58164 Mdot
.43223 .97849 Mdot
.39149 .4577 Mdot
.49632 .38727 Mdot
.41429 .75514 Mdot
.40466 .62186 Mdot
.5031 .3545 Mdot
.51197 .29631 Mdot
.46403 .86753 Mdot
.3918 .42457 Mdot
.43213 .42392 Mdot
.55174 .71378 Mdot
.60005 .15944 Mdot
.48817 .18777 Mdot
.63383 .41055 Mdot
.55344 .65863 Mdot
.53148 .71037 Mdot
.52537 .5002 Mdot
.73047 .75817 Mdot
.5247 .52582 Mdot
.55798 .81431 Mdot
.37624 .36232 Mdot
.66619 .3995 Mdot
.55656 .64139 Mdot
.66554 .65145 Mdot
.73003 .55279 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`02ooooo`;o0000]Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`02ooooo`Co0000/oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`04ooooo`;o0000/oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2i
ooooo`00X_ooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Sooooo`;o00001ooo
ool3o`000;Wooooo002Sooooo`;o00001oooool00ol0003oooooooooo`2iooooo`00Woooool2o`00
00_ooooo00?o0000ooooooooool0^Oooool009oooooo0ol0000:ooooo`03o`000?oooooooooo0;Wo
oooo002Pooooo`;o00002_ooool00ol0003oooooooooo`2iooooo`00W?ooool2o`0000kooooo00?o
0000ooooooooool0^Oooool009cooooo0_l0000>ooooo`03o`000?oooooooooo0;Wooooo002Loooo
o`;o00003_ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
[?ooool3o`0001;ooooo0_l0002Uooooo`00[?ooool00ol0003oooooooooo`0Booooo`;o0000YOoo
ool009Sooooo0_l0000Booooo`03o`000?oooooooooo0;Wooooo002Hooooo`;o00004_ooool00ol0
003oooooooooo`2iooooo`00V?ooool2o`0001;ooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:Cooooo0_l00006ooooo`03o`000?oooooooooo00Cooooo0_l0
002cooooo`00Y?ooool2o`0000Kooooo00?o0000ooooooooool01?ooool2o`0001;ooooo0_l0002O
ooooo`00X?ooool2o`0000[ooooo0ol0000Hooooo`;o0000Woooool00:3ooooo0_l00004ooooo`;o
00001?ooool00ol0003oooooooooo`2iooooo`00Y_ooool2o`0000Cooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool02_ooool2o`000:gooooo002/ooooo`03o`000?oooooo
oooo00[ooooo0_l0002]ooooo`00[?ooool3o`000;Wooooo002/ooooo`?o00002oooool4o`000:[o
oooo002/ooooo`04o`000?oooooo0000o`0000[ooooo1Ol0002Yooooo`00[?ooool5o`0000cooooo
0_l0002Yooooo`00[?ooool00ol0003oooooooooo`02o`000;Oooooo002Gooooo`;o00004oooool0
0ol0003oooooooooo`0Aooooo`;o0000Y_ooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo
017ooooo0_l0002Vooooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool04_ooool2o`000:Go
oooo002Gooooo`;o00002Oooool2o`0000Sooooo00?o0000ooooooooool04_ooool2o`00013ooooo
0_l0002Cooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`00
0?o^k^kooooo00Cooooo0ol000000olb<S;ogMgMooooo`04ooooo`03o`000?oooooooooo01;ooooo
0_l0000@ooooo`;o0000Toooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
4_ooool2o`0001;ooooo0_l0002Aooooo`00POooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400=ooooo`04ojVYZOmEEEGo0000o`0000Oooooo00?o0000ooooooooool00_ooool4o`0002Ko
oooo0_l0002Aooooo`00ROooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qo`000?l0
00001_ooool00omgMgOo<S8booooo`03ooooo`;o0000^oooool008Wooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005oooo
o`03o`000?oooooooooo0;Wooooo0029ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onY
ZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0^Oooool008Wo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`04o`000?oooooo0000o`000;Sooooo002B
ooooo`;o00006?ooool01?l0003oooooo`000?l0002hooooo`00T_ooool2o`0001Sooooo00?o0000
ooooooooool0^Oooool008cooooo0_l0000Nooooo`03o`000?oooooooooo0;Wooooo002<ooooo`;o
00007_ooool3o`000;Wooooo002Xooooo`;o00000_ooool00ol0003oooooooooo`03ooooo`;o0000
5oooool2o`0009_ooooo002@ooooo`;o00005_ooool2o`0000;ooooo00?o0000ooooooooool00ooo
ool2o`0001Oooooo0_l0002Kooooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool07_ooool3
o`0009Sooooo002/ooooo`03o`000?oooooooooo01kooooo0ol0002Hooooo`00W?ooool2o`0000ko
oooo00?o0000ooooooooool04?ooool2o`0001oooooo0_l00026ooooo`00W?ooool2o`0000kooooo
00?o0000ooooooooool04?ooool2o`0001oooooo0_l00026ooooo`00[?ooool00ol0003ooooooooo
o`0@ooooo`;o0000Yoooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00Q?oo
ool2o`0001cooooo0_l00004ooooo`;o00000_ooool00ol0003oooooooooo`2iooooo`00Q?ooool2
o`0001cooooo0_l00004ooooo`;o00000_ooool00ol0003oooooooooo`0:ooooo`;o0000[Oooool0
0:cooooo00?o0000ooooooooool02_ooool2o`000:gooooo002Zooooo`?o00001Oooool2o`0000Go
oooo0_l0002]ooooo`00Z_ooool5o`0000?ooooo0_l0000Cooooo`;o00003_ooool2o`0008oooooo
002Aooooo`;o00002Oooool2o`0000kooooo00?o0000ooooooooool06?ooool2o`0000gooooo0ol0
002?ooooo`00TOooool2o`0000Wooooo0_l0000>ooooo`03o`000?oooooooooo02Oooooo1?l0000?
ooooo`;o0000OOooool00:cooooo00?o0000ooooooooool03_ooool2o`0001Wooooo0_l0000?oooo
o`;o0000OOooool00:cooooo0ol0000>ooooo`;o00002Oooool2o`0009kooooo002/ooooo`?o0000
6Oooool2o`0009kooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooo
oooo00;o00001_ooool2o`0001;ooooo0_l0002Kooooo`00[?ooool5o`0000Kooooo0_l0000Boooo
o`;o0000Voooool00:[ooooo0ol0002kooooo`00Z_ooool3o`000;_ooooo002;ooooo`;o00000_oo
ool2o`0000;ooooo0_l0000Gooooo`03o`000?oooooooooo00Wooooo0_l0002^ooooo`00Roooool2
o`0000;ooooo0_l00002ooooo`;o00005oooool00ol0003oooooooooo`09ooooo`;o0000[_ooool0
0:cooooo00?o0000ooooooooool0^Oooool0097ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02o`00
00?ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool3o`0001Cooooo0_l0002S
ooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00;o00000oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool01?ooool3o`0001Cooooo0_l0000;ooooo`;o00007oooool2o`0007Gooooo0029oooo
o`Ko00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3
o`0000gooooo0_l0000Booooo`Co00007Oooool2o`0007Gooooo002Aooooo`05o`000?oooooooooo
ooooool000000oooool2o`0000[ooooo00?oMgMgoc8b<_ooool01?ooool3o`0000gooooo0_l0000B
ooooo`Co00007Oooool2o`0007Gooooo002Aooooo`05o`000?ooooooooooooooool000000oooool2
o`0000Oooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo027ooooo0_l0
002Fooooo`00TOooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`02o`0001oooooo0_l0000@ooooo`;o0000Q?ooool0097ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_l0
000aooooo`;o0000Q?ooool0097ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0Hooooo`;o00006Oooool2
o`0008Cooooo002/ooooo`03o`000?oooooooooo01Sooooo0_l0000Iooooo`;o0000Q?ooool00:Oo
oooo0_l00003ooooo`;o0000=_ooool2o`0008;ooooo002Jooooo`;o00002oooool2o`0000?ooooo
0ol0000eooooo`;o0000P_ooool009[ooooo0_l0000@ooooo`03o`000?oooooooooo0;Wooooo002F
ooooo`;o00004Oooool2o`000003ooooool0003ooooo0;[ooooo002Fooooo`;o00004Oooool2o`00
0003ooooool0003ooooo0;[ooooo002/ooooo`03o`000?oooooooooo00_ooooo0_l0002/ooooo`00
T_ooool2o`00013ooooo0_l00006ooooo`03o`000?oooooooooo00_ooooo0_l0002/ooooo`00P?oo
ool2o`00013ooooo0_l0000=ooooo`;o000000?oooooo`000?l000001_ooool00ol0003ooooooooo
o`0fooooo`;o0000POooool0083ooooo0_l0000Mooooo`Co00002Oooool01?l0003ooooooooooooo
ool2o`0000Wooooo0_l0000Jooooo`;o00003?ooool2o`00087ooooo002Oooooo`;o00002oooool3
o`000003ooooool0003o000000Wooooo0_l0000Jooooo`;o0000Soooool00:cooooo00?o0000oooo
ooooool0^Oooool009gooooo0_l0000=ooooo`03o`000?oooooooooo0;Wooooo002Dooooo`;o0000
1oooool2o`0000gooooo00?o0000ooooooooool0^Oooool009Cooooo0_l0000<ooooo`;o00002?oo
ool00ol0003oooooooooo`2iooooo`00XOooool3o`0000Sooooo00?o0000ooooooooool05oooool2
o`0002?ooooo0_l0001kooooo`00VOooool2o`0000Kooooo0_l00009ooooo`03o`000?oooooooooo
00Sooooo0_l0000=ooooo`;o00008_ooool3o`0007_ooooo002Iooooo`;o00004Oooool00ol0003o
ooooooooo`08ooooo`;o0000<Oooool2o`0007cooooo002/ooooo`?o0000;Oooool2o`0000cooooo
0_l0001looooo`00[?ooool00ol0003oooooooooo`0@ooooo`;o00001Oooool2o`0001?ooooo0ol0
000<ooooo`;o0000O?ooool00:cooooo0ol0000@ooooo`;o00001Oooool3o`0001;ooooo0_l0002;
ooooo`00[?ooool3o`0001Sooooo0_l0000Booooo`;o0000Roooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool02oooool2o`0002;ooooo0_l00028ooooo`00Qooo
ool2o`0001?ooooo0_l0000>ooooo`03o`000?oooooooooo00_ooooo0_l00005ooooo`;o00003ooo
ool2o`0000[ooooo0_l00028ooooo`00Qoooool2o`0001?ooooo0_l0000>ooooo`03o`000?oooooo
oooo01;ooooo0_l0000?ooooo`;o0000U?ooool00:cooooo00?o0000ooooooooool02?ooool2o`00
00Wooooo0_l0002Tooooo`00[?ooool3o`0000Sooooo0_l00002ooooo`?o00001?ooool2o`0000Oo
oooo0_l0002Kooooo`00VOooool2o`00017ooooo1Ol0000:ooooo`?o00003Oooool2o`0009_ooooo
0023ooooo`;o000000?oooooo`000?l000004Oooool2o`0000;ooooo0_l0000=ooooo`Go0000?ooo
ool2o`0007Kooooo0023ooooo`;o000000?oooooo`000?l000005Oooool2o`0000gooooo00?o0000
ooooooooool0@?ooool3o`0007Kooooo0023ooooo`;o00001oooool2o`0001kooooo00?o0000oooo
ooooool0@?ooool2o`0007Oooooo0023ooooo`;o00001?ooool00oo^k^ko<S8bo`000002o`0000Go
oooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00Co0000oooo
ool0003o00005?ooool2o`0002Wooooo0_l0000@ooooo`;o0000IOooool008Wooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`;o00000_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01ooo
ool00omgMgOo<S8booooo`04ooooo`04o`000?oooooo0000o`0001Cooooo0_l0000kooooo`;o0000
IOooool0087ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41000oooool4o`0000Gooooo
00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;Wooooo
0029ooooo`;o00000_ooool00ol0003oooooooooo`03ooooo`;o00001_ooool00onHV9So8B4Qonk^
kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000:ooooo`;o0000[Oooool008Wooooo0_l00002
ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Gooooo00?o0000ooooooooool02_ooool2o`0001[ooooo0_l0002Aooooo`00ROooool0
1Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo02Kooooo0_l0002Aooooo`00ROooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool07Oooool3o`0001;ooooo0_l00025ooooo`00ROooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001?ooool3o`0000Go
oooo0_l0000;ooooo`;o00001?ooool2o`0000Gooooo0ol0000Booooo`;o0000QOooool008kooooo
0_l0000Jooooo`?o00001Oooool2o`0000Kooooo0_l00003ooooo`?o00000oooool2o`0000Kooooo
0_l0000Sooooo`;o0000M?ooool008;ooooo0_l0000:ooooo`;o00007?ooool00ol0003ooooooooo
o`0;ooooo`;o00001?ooool2o`00033ooooo0_l0001dooooo`00P_ooool2o`0000Cooooo0_l0000R
ooooo`04o`000?ooooooooooooooo`;o00009_ooool2o`0008kooooo0028ooooo`;o00002?ooool2
o`0001Sooooo0ol000000ooooooo0000o`00000Vooooo`;o00002?ooool2o`00013ooooo0_l0001b
ooooo`00T_ooool2o`0000Cooooo0_l0000Booooo`03o`000?oooooooooo00Sooooo0_l0000Yoooo
o`;o00004?ooool2o`0000oooooo0_l0001Qooooo`00T_ooool2o`0000Cooooo0_l0000Booooo`;o
00002Oooool2o`0003_ooooo0_l0000?ooooo`;o0000HOooool00:cooooo0_l00006ooooo`;o0000
00?oooooo`000?l000007oooool2o`0001[ooooo0_l0001booooo`00[?ooool00ol0003ooooooooo
o`05ooooo`;o00008_ooool2o`0000_ooooo0_l00021ooooo`00[?ooool00ol0003oooooooooo`0Z
ooooo`;o00002_ooool2o`0001oooooo0_l0001Pooooo`00[?ooool00ol0003oooooooooo`0Zoooo
o`;o00006_ooool2o`0000oooooo0_l0001Pooooo`00[?ooool00ol0003oooooooooo`0Pooooo`;o
00009?ooool2o`00077ooooo0028ooooo`;o00002oooool2o`0001Gooooo0ol0000Cooooo`;o0000
2oooool2o`0009Oooooo0028ooooo`;o00002oooool2o`0001Gooooo00?o0000ooooooooool04ooo
ool2o`0000?ooooo0_l0002Oooooo`00Soooool2o`0001_ooooo00?o0000ooooooooool06?ooool2
o`0009oooooo002?ooooo`;o00006oooool00ol0003oooooooooo`0Iooooo`;o00004?ooool2o`00
08cooooo002/ooooo`03o`000?oooooooooo01Wooooo0_l0000@ooooo`;o0000S?ooool009?ooooo
0_l0000Gooooo`03o`000?oooooooooo0;Wooooo002Cooooo`;o00005oooool00ol0003ooooooooo
o`2iooooo`00[?ooool01?l0003oooooooooooooool2o`0002Sooooo0_l0000Kooooo`;o00003ooo
ool2o`0005kooooo002/ooooo`04o`000?ooooooooooooooo`;o00003?ooool2o`0000[ooooo0_l0
000>ooooo`;o00006oooool2o`0000oooooo0_l0001Nooooo`00[?ooool4o`0000kooooo0_l0000:
ooooo`;o0000??ooool2o`0005kooooo002:ooooo`;o00008?ooool01?l0003oooooo`000?l0002h
ooooo`00R?ooool4o`00023ooooo0_l0000Tooooo`;o00008_ooool2o`00073ooooo0009ooooo`Co
000000?o410@ooooooooool05_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b
<_oMgMd05_ooool2o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03ob4Q8Ol0003o
000000?ooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`00
0?l0003ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@0Hooooo`Co000000?o410@ooooooooool04_ooool000_ooooo00?o0000oooo
ooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWo
oooo00Oooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B48ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool05Oooool00ol0003o
ooooooooo`07ooooo`;o00003oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`0>ooooo`04ogMgMol0003o
0000oiRHV0;o00001?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool0
6Oooool00ol0003oooooooooo`0Dooooo`001_l00005ooooo`03o`000?oooooooooo013ooooo1_l0
0002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`00
0?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003o
ooooooooo`05ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q
8Oo^k^h02Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Oooooo0_l0000?oooo
o`05oa0@4?ooooooooooooooool@41001_ooool2o`0000Cooooo00?oV9RHob4Q8Oo^k^h02Oooool0
0ol0003oooooo`000003o`0000[ooooo00Co410@o`000?l0003ooooo0_l0000?ooooo`03o`000?oo
oooooooo00gooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003ooooooooo
o`0Hooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMg
Molb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00ko
oooo00Go0000ooooooooooooooooo`000007ooooo`;o00001?ooool00onHV9So8B4Qonk^kP07oooo
o`03ogMgMolb<S;ooooo01Gooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo
000000Gooooo0ol00005ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?l0000:
ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0>ooooo`05o`000?oo
ooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Wooooo
00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooo
oooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oo
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool0
1Ol0003ooooooooooooooooo000000Oooooo0_l00005ooooo`03ogMgMomVIVKooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c00Fooooo`03o`000?oooooooooo01Sooooo00Go0000oooooooooooo
ooooo`000005ooooo`?o00001_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`03oooool01?l0003oooooooooooooool2o`0000_ooooo00Co0000ob4Q8Ol0003o<S8b0_l0
000>ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`06_ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003ooooo
ooooo`0Hooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03
o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo
017ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool06?ooool3o`0001Sooooo00Go410@oooooooooooooooooa0@4006ooooo`;o00001ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo00Co410@oooooooooooooooo
0_l0000;ooooo`04o`000?ooooooooooooooo`;o00003_ooool01Ol@413ooooooooooooooooo410@
00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool2o`0000?ooooo00Go0000okZj
^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Co
oooo0009ooooo`03oeEEEOmVIVKo000001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go
00001?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00004?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00005ooo
ool00ol0003oooooooooo`0?ooooo`;o00000oooool2o`0000;ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`00013ooooo00Gok^k^oc8b<_l0
003o0000onk^kP0<ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004
ooooo`Co00006Oooool00omEEEGoIVIVo`00000Fooooo`00[?ooool00ol0003oooooooooo`0?oooo
o`;o00000oooool2o`00037ooooo0ol0001_ooooo`00[?ooool00ol0003oooooooooo`0Kooooo`;o
0000:Oooool5o`0006kooooo0027ooooo`;o00008oooool00ol0003oooooooooo`02ooooo`;o0000
2?ooool2o`0000gooooo0_l0000Kooooo`;o00003?ooool2o`000003ooooool0003o000006?ooooo
0_l00002ooooo`;o00001Oooool008Oooooo0_l00003ooooo`;o00002?ooool2o`0001Cooooo00?o
0000ooooooooool00_ooool2o`0000Oooooo0ol0000Zooooo`;o00003_ooool2o`0006Cooooo00Ko
k^k^ob4Q8On7QhOo^[Zjo`000?oMgMd5ooooo`00S?ooool2o`0000Sooooo0_l0000Dooooo`03o`00
0?oooooooooo00_ooooo0_l00008ooooo`;o0000<Oooool2o`0006Gooooo00CogMgMo`000?l@413o
c<c<1_ooool000Ooooooool0001<o`0000cooooo00Cok^k^ob4Q8Ol@413ok^k^1_ooool000Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
0_l000000ooooooo0000o`000004ooooo`04o`000?oooooo0000o`0000?ooooo0_l00007ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool3o`0000Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0:ooooo`04ob4Q8OmgMgOoMgMgoc8b<PKooooo0007ooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Tooooo`?o
0000:?ooool00ol0003oooooooooo`0@ooooo`;o00000oooool2o`00013ooooo00?o0000oooooooo
ool00oooool2o`0000[ooooo0_l0000<ooooo`Co00001Oooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool02Oooool2o`0000;ooooo0_l00005ooooo`00
POooool2o`0002Wooooo00?o0000ooooooooool05Oooool2o`0001Kooooo0_l0000:ooooo`;o0000
3?ooool2o`00073ooooo002Cooooo`;o00005oooool00ol0003oooooooooo`0Sooooo`?o00008Ooo
ool3o`0006oooooo0021ooooo`;o00004?ooool2o`0001Oooooo00?o0000ooooooooool00_ooool2
o`0001oooooo0ol0000Booooo`;o00003Oooool3o`0006oooooo0021ooooo`;o0000:Oooool00ol0
003oooooooooo`02ooooo`;o00005oooool2o`0001_ooooo0ol0001nooooo`00[?ooool00ol0003o
ooooooooo`0Kooooo`;o00007?ooool2o`0007kooooo002/ooooo`?o0000Aoooool2o`00073ooooo
002/ooooo`03o`000?oooooooooo00Gooooo0_l0000Dooooo`;o00003oooool2o`0001Wooooo0_l0
001`ooooo`00Q?ooool2o`0002Kooooo00?o0000ooooooooool01Oooool2o`000003ooooool0003o
0000017ooooo0_l0000?ooooo`;o00002oooool2o`0000cooooo0_l0001`ooooo`00Q?ooool2o`00
02Kooooo00?o0000ooooooooool02?ooool2o`0002oooooo0_l0001nooooo`00[?ooool00ol0003o
ooooooooo`0Eooooo`;o0000<_ooool2o`0006kooooo002/ooooo`03o`000?oooooooooo00_ooooo
0_l00008ooooo`;o0000<?ooool4o`0006kooooo002/ooooo`03o`000?oooooooooo00_ooooo0_l0
000>ooooo`;o00003oooool2o`0001Wooooo0ol0001_ooooo`00SOooool2o`0001gooooo00?o0000
ooooooooool02oooool2o`0000kooooo0_l0000?ooooo`;o0000Roooool008gooooo0_l0000Moooo
o`03o`000?oooooooooo00_ooooo0_l00007ooooo`;o00003?ooool2o`0002Cooooo0_l0001_oooo
o`00[?ooool3o`0001Cooooo0_l0000<ooooo`;o00009?ooool3o`0006kooooo002:ooooo`;o0000
8?ooool00ol0003oooooooooo`0iooooo`;o00003_ooool2o`0006kooooo002:ooooo`;o00001Ooo
ool2o`0001Wooooo00?o0000ooooooooool08_ooool2o`0001Gooooo0_l0001nooooo`00TOooool2
o`0001Wooooo00?o0000ooooooooool08_ooool2o`0000Sooooo0_l0002;ooooo`00[?ooool00ol0
003oooooooooo`0/ooooo`;o00002_ooool2o`0007oooooo002/ooooo`03o`000?oooooooooo01[o
oooo0_l0000@ooooo`;o00002_ooool2o`0007oooooo002/ooooo`03o`000?oooooooooo00oooooo
0_l00009ooooo`;o00004?ooool2o`0008_ooooo002/ooooo`03o`000?oooooooooo00kooooo0ol0
000Kooooo`;o0000Roooool0087ooooo0_l0000Cooooo`;o00005?ooool3o`0000kooooo0_l0000L
ooooo`;o00002oooool2o`0007kooooo0021ooooo`;o00004oooool2o`0001Cooooo00?o0000oooo
ooooool0=oooool4o`0007kooooo0021ooooo`;o0000:Oooool00ol0003oooooooooo`0Qooooo`;o
00002?ooool2o`0000[ooooo0_l00020ooooo`00POooool2o`0002Wooooo00?o0000ooooooooool0
4oooool2o`0000Cooooo0_l00006ooooo`;o00002?ooool2o`0001_ooooo0_l0001_ooooo`00POoo
ool2o`0002Wooooo00?o0000ooooooooool04oooool2o`0000Cooooo0_l00006ooooo`;o00009Ooo
ool2o`0006oooooo001nooooo`;o0000;?ooool00ol0003oooooooooo`0Cooooo`;o00003?ooool2
o`0009Kooooo001nooooo`;o0000;?ooool00ol0003oooooooooo`17ooooo`;o0000L?ooool00:co
oooo00Co0000ooooool0003o0000=_ooool2o`0000kooooo0_l0001`ooooo`00S_ooool2o`0000[o
oooo0_l000000ooooooo0000o`00000=ooooo`Co0000=_ooool2o`0000kooooo0_l0001`ooooo`00
S_ooool2o`0000[ooooo0_l000000ooooooo0000o`00000=ooooo`03o`000?oooooooooo02[ooooo
0_l0000;ooooo`;o00003_ooool2o`00073ooooo002/ooooo`03o`000?oooooooooo02[ooooo0ol0
000:ooooo`;o00003Oooool3o`00073ooooo001nooooo`;o00006Oooool2o`00017ooooo00?o0000
ooooooooool0:oooool2o`0001Wooooo0_l0001aooooo`00O_ooool2o`0001Oooooo1?l0000Aoooo
o`03o`000?oooooooooo01;ooooo0_l0002Uooooo`00Uoooool2o`0001?ooooo00?o0000oooooooo
ool04_ooool2o`000:Gooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`08oooo
o`;o00005_ooool2o`0009Oooooo0029ooooo`03ogMgMonHV9Sooooo00;o00001Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool02?ooool2o`0001Cooooo1?l00008ooooo`;o00006?ooool2o`0007?ooooo0029ooooo`03
oa0@4?oooooooooo00;o00003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?o
oooo0ol00007ooooo`;o00005Oooool2o`0000Sooooo1?l00009ooooo`?o00003?ooool2o`0007?o
oooo0029ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool01oooool2o`0001oooooo0_l0000;ooooo`?o
0000POooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05
oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01_ooool2o`000;7ooooo0029ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`;o0000/Oooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool0^Ooo
ool009;ooooo0_l0000Hooooo`03o`000?oooooooooo00oooooo0_l0002Xooooo`00R_ooool2o`00
0003ooooool0003o000000?ooooo0_l0000Hooooo`03o`000?oooooooooo00Gooooo0_l00008oooo
o`;o00003?ooool2o`0000Sooooo0_l0002@ooooo`00R_ooool2o`000003ooooool0003o000001go
oooo00?o0000ooooooooool01Oooool2o`0000?ooooo0_l0000Aooooo`;o00002?ooool2o`0000[o
oooo0_l00024ooooo`00[?ooool3o`0000[ooooo0_l0000Kooooo`;o00002_ooool2o`0008Cooooo
002/ooooo`03o`000?oooooooooo02Oooooo0_l0000:ooooo`;o00003Oooool2o`0007Gooooo002B
ooooo`;o00001_ooool2o`00013ooooo00?o0000ooooooooool03_ooool2o`0001Oooooo0_l0000I
ooooo`;o0000MOooool008[ooooo0_l00006ooooo`?o00001Oooool2o`00013ooooo00?o0000oooo
ooooool03_ooool2o`0001Oooooo0_l0002@ooooo`00R_ooool2o`0000Oooooo0_l0000Gooooo`03
o`000?oooooooooo04?ooooo0_l0001dooooo`00[?ooool00ol0003oooooooooo`07ooooo`;o0000
=oooool2o`000003ooooool0003o000007Cooooo002>ooooo`;o00002oooool2o`0000oooooo00?o
0000ooooooooool01oooool2o`0003Oooooo0_l0001gooooo`00S_ooool2o`0000Cooooo0_l00005
ooooo`;o00003oooool00ol0003oooooooooo`0Cooooo`;o0000:_ooool2o`0007Sooooo002Doooo
o`;o00005_ooool3o`0001?ooooo0_l0000Zooooo`;o0000N?ooool00:cooooo00?o0000oooooooo
ool09?ooool2o`0000_ooooo0_l0000=ooooo`;o0000Moooool00:cooooo0ol00006ooooo`;o0000
7?ooool2o`0000_ooooo0_l0000=ooooo`?o0000M_ooool00:cooooo0ol00006ooooo`;o00000ooo
ool2o`0001Gooooo0_l0000Mooooo`;o0000M_ooool009[ooooo0_l0000@ooooo`03o`000?oooooo
oooo00_ooooo0_l0000Eooooo`;o00007?ooool2o`00013ooooo0_l0001Uooooo`00T_ooool2o`00
00?ooooo0_l000000ooooooo0000o`00000@ooooo`03o`000?oooooooooo02oooooo0_l0000?oooo
o`;o00004?ooool2o`0006Gooooo002<ooooo`;o00001?ooool2o`0000?ooooo0_l0000>ooooo`;o
00000oooool00ol0003oooooooooo`0_ooooo`;o0000R?ooool008cooooo0_l0000Iooooo`;o0000
0oooool00ol0003oooooooooo`0_ooooo`;o0000R?ooool00:Gooooo0_l00005ooooo`?o00006?oo
ool2o`0001Gooooo0_l0000=ooooo`;o0000NOooool008Sooooo0_l00002ooooo`;o00005oooool2
o`0000Gooooo00?o0000ooooooooool06?ooool2o`0002Cooooo0_l0001iooooo`00R?ooool2o`00
00;ooooo0_l0000Nooooo`03o`000?oooooooooo01Oooooo0_l0000Uooooo`;o0000NOooool008Co
oooo0_l0000Vooooo`?o00001oooool2o`0000kooooo0_l0000Uooooo`;o0000NOooool008Cooooo
0_l0000Sooooo`;o000000Coooooo`000?l0003o00001oooool2o`000;3ooooo002Cooooo`;o0000
5?ooool2o`000003ooooool0003ooooo00oooooo0_l0002Yooooo`00Toooool2o`0001Oooooo00?o
0000ooooooooool03_ooool2o`000:Wooooo002Gooooo`;o00004oooool00ol0003oooooooooo`2i
ooooo`00Uoooool2o`0000_ooooo0_l00006ooooo`?o0000:_ooool2o`0008gooooo002Kooooo`;o
00001oooool2o`0000Kooooo00?o0000ooooooooool01Oooool2o`0002?ooooo0_l0002=ooooo`00
Voooool2o`0000oooooo00?o0000ooooooooool00_l00003ooooo`;o00008_ooool3o`0008gooooo
002=ooooo`;o00006_ooool2o`000004ooooool0003oooooooooo`;o00004Oooool2o`0001Cooooo
0ol0002=ooooo`00SOooool2o`0001[ooooo0_l000000ooooooo0000ooooo`0Dooooo`;o0000Y?oo
ool00:Wooooo0_l000000ooooooo0000ooooo`2jooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooooooo
o`0Wooooo`;o0000T?ooool0097ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02Oooooo0_l0002@ooooo`00TOooool0
1Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Aooooo`;o0000Y_ooool0097ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo00?ooooo1?l0000Aooooo`;o0000Y_ooool008oooooo0ol00003ooooo`03o`000?oooooo
oooo00[ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`;o0000^oooool008oooooo0_l00000
1Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`19ooooo`;o0000K_ooool0097ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool2o`0001gooooo0_l0000>ooooo`;o00004Ooo
ool2o`0006kooooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o
0000ooooooooool01oooool2o`0000kooooo0_l0000=ooooo`;o00003_ooool2o`00087ooooo002D
ooooo`;o00005_ooool00ol0003oooooooooo`05ooooo`;o00004?ooool2o`000:3ooooo002<oooo
o`;o00001_ooool2o`0000[ooooo0_l0000:ooooo`03o`000?oooooooooo00Gooooo0_l0000Loooo
o`;o0000U?ooool008cooooo0_l0000Booooo`;o00000_ooool2o`0000Kooooo0ol0000Gooooo`;o
00002_ooool3o`0009?ooooo002Iooooo`;o00002Oooool2o`0000Kooooo0ol0000Gooooo`;o0000
2oooool2o`0001oooooo0_l0001booooo`00VOooool2o`00017ooooo00?o0000ooooooooool0AOoo
ool2o`0007;ooooo002=ooooo`;o00003?ooool2o`0000oooooo00?o0000ooooooooool00oooool2
o`0001cooooo0_l0000?ooooo`;o0000QOooool008gooooo0_l0000<ooooo`;o00003oooool00ol0
003oooooooooo`03ooooo`;o00007?ooool2o`0000oooooo0_l00025ooooo`00ROooool2o`00027o
oooo00?o0000ooooooooool0^Oooool008Wooooo0_l0000Qooooo`03o`000?oooooooooo0;Wooooo
002Mooooo`;o00003Oooool01?l0003oooooooooooooool2o`00017ooooo0_l0000:ooooo`;o0000
3Oooool2o`0008Sooooo002Mooooo`;o00002Oooool2o`0000;ooooo00Co0000oooooooooooooooo
0_l0000Aooooo`;o00002_ooool2o`0000gooooo0_l00028ooooo`00Z?ooool2o`0000;ooooo0ol0
000Oooooo`;o0000V?ooool00:cooooo00?o0000ooooooooool07oooool2o`0009Sooooo002/oooo
o`?o00004_ooool2o`0001Sooooo0_l0002;ooooo`00U?ooool2o`0001Kooooo0ol0000Booooo`;o
00006?ooool2o`0008_ooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`05ooooo`;o0000
2?ooool2o`000:Sooooo002Jooooo`;o00004?ooool00ol0003oooooooooo`05ooooo`;o00002?oo
ool3o`000:Oooooo002Jooooo`;o00004?ooool00ol0003oooooooooo`0@ooooo`;o0000Yoooool0
093ooooo0_l0000Hooooo`?o0000^oooool0093ooooo0_l0000Hooooo`Go00003Oooool2o`000:[o
oooo002/ooooo`03o`000?oooooooooo00gooooo0_l0002Zooooo`00TOooool2o`0001Cooooo0_l0
0003ooooo`03o`000?oooooooooo03cooooo0_l0001kooooo`00TOooool2o`0001Cooooo0_l00003
ooooo`03o`000?oooooooooo00_ooooo0_l0000_ooooo`;o0000Noooool00:cooooo00?o0000oooo
ooooool02oooool2o`0000[ooooo0_l0002Pooooo`00[?ooool00ol0003oooooooooo`0Gooooo`;o
0000X?ooool00:cooooo00Co0000ooooool0003o0000^?ooool00:cooooo1?l0002hooooo`00[?oo
ool3o`000;Wooooo002/ooooo`?o00008oooool2o`0009Cooooo002/ooooo`03o`000?oooooooooo
02?ooooo0ol0002Cooooo`00[?ooool00ol0003oooooooooo`0Aooooo`;o00004Oooool2o`0009?o
oooo002Mooooo`;o00003Oooool00ol0003oooooooooo`0Aooooo`;o0000Y_ooool009gooooo0_l0
000=ooooo`03o`000?oooooooooo00?ooooo0_l0002dooooo`00ROooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00;ooooo0_l000001Om4A4Co0000o`00
0?lb<S;ogMgM00Gooooo00?o0000ooooooooool00oooool2o`000;Cooooo0029ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool00_ooool2o`0000?ooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`03ooooo`;o0000]?ooool008Wooooo00Go
410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`2iooooo`00ROooool01Ol0003ooooooooooooooooo000000kooooo
00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`?o0000^Oooool008Wooooo00Go
0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05oa0@4?ooooooooooooooool@
41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0^Oooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooo
oolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo
0;Wooooo002Booooo`;o00001Oooool2o`00017ooooo00?o0000ooooooooool0^Oooool009;ooooo
0_l0000Hooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool02Oooool2o`000:kooooo002/ooooo`03
o`000?oooooooooo00Wooooo0_l0002^ooooo`00[?ooool00ol0003oooooooooo`06ooooo`;o0000
8Oooool2o`0008kooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`06ooooo`;o00008Ooo
ool2o`0008kooooo002Dooooo`?o00005Oooool00ol0003oooooooooo`2iooooo`00UOooool2o`00
01Gooooo00?o0000ooooooooool05Oooool2o`000:;ooooo002Fooooo`;o00005?ooool01?l0003o
ooooooooooooool2o`00013ooooo1?l0002Rooooo`00U_ooool2o`0001Cooooo0ol000000ooooooo
0000o`00000@ooooo`;o0000Y?ooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o
0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00Co0000oooo
ool0003o0000^?ooool00:cooooo00Co0000ooooool0003o0000^?ooool00:_ooooo0ol0002joooo
o`00Zoooool3o`000;[ooooo002Kooooo`Co00003Oooool00ol0003oooooooooo`0;ooooo`Co0000
Z_ooool009_ooooo1?l0000=ooooo`?o00002oooool4o`000:[ooooo002Xooooo`?o000000?ooooo
o`000?ooool0^_ooool00:Sooooo0ol000000ooooooo0000ooooo`2jooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`08ooooo`;o0000[oooool00:cooooo00?o
0000ooooooooool02?ooool2o`000:oooooo002/ooooo`03o`000?oooooooooo00Cooooo0_l0002c
ooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o0000/oooool00:cooooo0ol0000Gooooo`;o
0000X?ooool009Gooooo0_l0000Eooooo`03o`000?oooooooooo01Oooooo0_l0002Pooooo`00UOoo
ool2o`0001Gooooo00?o0000ooooooooool00_ooool2o`000;Gooooo002Gooooo`;o00004oooool0
0ol0003oooooooooo`02ooooo`;o0000]Oooool009Oooooo0ol0000Booooo`03o`000?oooooooooo
0;Wooooo002Hooooo`;o00004_ooool00ol0003oooooooooo`2iooooo`00X_ooool4o`000003oa0@
4?oooooooooo00?ooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`?o0000^Oooool0
0:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo
00?o0000ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:;ooooo00?oEEEE
ofIVI_l00000`oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00:[ooooo00Co410@o`000?l0003o0000^_ooool00:_ooooo00?o0000ooooooooool0^_ooool0
0:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00Ko0000ogMgMol0003o0000oeEEEOo^k^jg
ooooo`00Zoooool01_l0003oEEEEonk^k_ooooooMgMgoeEEEKOooooo002[ooooo`03o`000?o^k^ko
oooo00;ooooo00?o0000ooooooooool0]Oooool00:_ooooo00?o0000onk^k_ooool00_ooool00ol0
003oooooooooo`2eooooo`00Zoooool01_l0003oEEEEonk^k_ooooooMgMgofIVI[Oooooo002Zoooo
o`03oa0@4?l0003oMgMg00;o000000?oIVIVonk^k_ooool0]_ooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.60787 .30531 Mdot
.64092 .62414 Mdot
.50149 .56731 Mdot
.45807 .74128 Mdot
.4043 .47599 Mdot
.39183 .59665 Mdot
.50668 .39555 Mdot
.64264 .20455 Mdot
.38163 .27853 Mdot
.52183 .70688 Mdot
.41148 .47553 Mdot
.68721 .29388 Mdot
.40862 .80664 Mdot
.42787 .69271 Mdot
.68682 .30586 Mdot
.49473 .25071 Mdot
.51356 .18542 Mdot
.39715 .74841 Mdot
.57428 .57411 Mdot
.68479 .4249 Mdot
.39833 .74855 Mdot
.58693 .76728 Mdot
.5557 .81853 Mdot
.38421 .63457 Mdot
.73045 .46514 Mdot
.59712 .56021 Mdot
.4518 .23318 Mdot
.5768 .52604 Mdot
.69036 .47826 Mdot
.63676 .63394 Mdot
.38152 .55616 Mdot
.38444 .25147 Mdot
.5779 .11926 Mdot
.60154 .38114 Mdot
.61165 .61169 Mdot
.62431 .26661 Mdot
.59329 .82522 Mdot
.56133 .38662 Mdot
.68755 .52437 Mdot
.70643 .33556 Mdot
.73551 .47982 Mdot
.62055 .50485 Mdot
.52378 .82367 Mdot
.63438 .37306 Mdot
.57534 .23413 Mdot
.53062 .24863 Mdot
.45819 .76913 Mdot
.37932 .70132 Mdot
.46076 .84004 Mdot
.68396 .44827 Mdot
.38582 .75116 Mdot
.67568 .63684 Mdot
.71786 .24694 Mdot
.57934 .71347 Mdot
.56103 .75996 Mdot
.46911 .02253 Mdot
.64911 .21698 Mdot
.51421 .18455 Mdot
.47372 .96715 Mdot
.55335 .19721 Mdot
.54942 .28936 Mdot
.61921 .86177 Mdot
.68594 .53168 Mdot
.46095 .26955 Mdot
.55234 .09429 Mdot
.42481 .07805 Mdot
.53467 .66957 Mdot
.4547 .25682 Mdot
.56818 .41164 Mdot
.37974 .4586 Mdot
.5659 .27045 Mdot
.4455 .63274 Mdot
.51759 .71459 Mdot
.55916 .55229 Mdot
.68593 .53095 Mdot
.44918 .4098 Mdot
.71817 .24758 Mdot
.57983 .38463 Mdot
.68443 .59496 Mdot
.52693 .77078 Mdot
.47215 .07137 Mdot
.64048 .61342 Mdot
.49941 .72399 Mdot
.62086 .53278 Mdot
.57765 .11539 Mdot
.52066 .30164 Mdot
.40734 .40201 Mdot
.43518 .23804 Mdot
.47638 .14496 Mdot
.46168 .24744 Mdot
.73026 .47246 Mdot
.43021 .01088 Mdot
.54115 .41789 Mdot
.48131 .17876 Mdot
.52214 .34443 Mdot
.39224 .1226 Mdot
.43648 .72681 Mdot
.3866 .75115 Mdot
.73202 .27331 Mdot
.49496 .15318 Mdot
.62713 .36004 Mdot
.42392 .22968 Mdot
.6801 .28287 Mdot
.64469 .42023 Mdot
.42843 .12355 Mdot
.6103 .41977 Mdot
.58306 .31217 Mdot
.55574 .66109 Mdot
.5424 .42482 Mdot
.38032 .44475 Mdot
.47308 .78241 Mdot
.46483 .7502 Mdot
.37901 .29877 Mdot
.65141 .31744 Mdot
.79094 .57558 Mdot
.43332 .59875 Mdot
.56889 .34171 Mdot
.47898 .01675 Mdot
.43185 .05991 Mdot
.61074 .79026 Mdot
.41291 .82264 Mdot
.66839 .78257 Mdot
.46285 .9125 Mdot
.69229 .49601 Mdot
.38062 .43044 Mdot
.43225 .66671 Mdot
.66353 .35362 Mdot
.35878 .42063 Mdot
.64772 .48508 Mdot
.47846 .28685 Mdot
.55298 .82602 Mdot
.64213 .42432 Mdot
.70743 .34773 Mdot
.38846 .48525 Mdot
.46986 .87776 Mdot
.69033 .56069 Mdot
.60888 .80487 Mdot
.68203 .42404 Mdot
.5241 .69759 Mdot
.6105 .16479 Mdot
.69529 .32388 Mdot
.51936 .98154 Mdot
.53443 .62671 Mdot
.57777 .48432 Mdot
.51624 .18911 Mdot
.67242 .37479 Mdot
.54152 .07295 Mdot
.75935 .70933 Mdot
.55175 .66306 Mdot
.46283 .18594 Mdot
.68915 .74692 Mdot
.41041 .2958 Mdot
.53352 .297 Mdot
.38099 .58558 Mdot
.46163 .67619 Mdot
.41405 .22768 Mdot
.63877 .74287 Mdot
.68498 .56887 Mdot
.47103 .01869 Mdot
.59501 .82076 Mdot
.63241 .75753 Mdot
.56255 .70268 Mdot
.68451 .60126 Mdot
.74059 .48258 Mdot
.57613 .1852 Mdot
.5359 .79985 Mdot
.6146 .32807 Mdot
.52681 .05737 Mdot
.46809 .06841 Mdot
.56179 .38379 Mdot
.63561 .75487 Mdot
.66738 .37736 Mdot
.54293 .44481 Mdot
.53444 .30396 Mdot
.40606 .43431 Mdot
.52938 .7261 Mdot
.57639 .12028 Mdot
.37658 .20942 Mdot
.40518 .27604 Mdot
.44994 .67256 Mdot
.68934 .49101 Mdot
.65839 .70179 Mdot
.72131 .38506 Mdot
.5584 .44748 Mdot
.73681 .50009 Mdot
.53561 .48135 Mdot
.37345 .37829 Mdot
.35792 .47425 Mdot
.38328 .25542 Mdot
.73811 .46235 Mdot
.49147 .8711 Mdot
.69705 .72065 Mdot
.67308 .37595 Mdot
.42315 .46771 Mdot
.64524 .81847 Mdot
.609 .1562 Mdot
.73563 .58084 Mdot
.69347 .31169 Mdot
.4542 .1933 Mdot
.52987 .00654 Mdot
.61513 .41824 Mdot
.50786 .6417 Mdot
.50063 .66616 Mdot
.43586 .56941 Mdot
.40734 .58227 Mdot
.56846 .04589 Mdot
.63192 .38161 Mdot
.48832 .71823 Mdot
.38997 .43865 Mdot
.4652 .75276 Mdot
.52393 .6225 Mdot
.41559 .39032 Mdot
.48892 .91839 Mdot
.57515 .36604 Mdot
.4708 .06778 Mdot
.54262 .37275 Mdot
.6196 .34279 Mdot
.55842 .31773 Mdot
.74038 .48863 Mdot
.53726 .5147 Mdot
.51217 .14132 Mdot
.69433 .3033 Mdot
.56399 .32696 Mdot
.46549 .96282 Mdot
.44689 .08628 Mdot
.51058 .0982 Mdot
.50899 .28272 Mdot
.44035 .77121 Mdot
.64827 .59424 Mdot
.54232 .43445 Mdot
.68951 .31174 Mdot
.65392 .81112 Mdot
.44268 .28146 Mdot
.44818 .61255 Mdot
.56839 .04837 Mdot
.40694 .66419 Mdot
.45417 .22692 Mdot
.68408 .749 Mdot
.55048 .34736 Mdot
.65043 .45708 Mdot
.45952 .91321 Mdot
.63839 .40406 Mdot
.62045 .85879 Mdot
.42194 .80062 Mdot
.5376 .12497 Mdot
.56455 .26774 Mdot
.39321 .19275 Mdot
.50208 .29321 Mdot
.65063 .70819 Mdot
.41386 .28669 Mdot
.55994 .2583 Mdot
.68638 .54311 Mdot
.73686 .56084 Mdot
.43689 .62304 Mdot
.42317 .49979 Mdot
.63586 .74165 Mdot
.59524 .56186 Mdot
.5242 .28086 Mdot
.527 .82412 Mdot
.4595 .3692 Mdot
.63054 .19013 Mdot
.41303 .88027 Mdot
.42777 .77447 Mdot
.4531 .22856 Mdot
.53705 .1307 Mdot
.43755 .37076 Mdot
.40181 .37266 Mdot
.57892 .24671 Mdot
.4428 .73902 Mdot
.43012 .81988 Mdot
.64526 .31391 Mdot
.58069 .63705 Mdot
.64461 .30624 Mdot
.54312 .79481 Mdot
.52126 .71022 Mdot
.48139 .83969 Mdot
.64179 .73763 Mdot
.56191 .48181 Mdot
.48873 .80614 Mdot
.37564 .65863 Mdot
.41279 .42387 Mdot
.40432 .27843 Mdot
.69039 .52929 Mdot
.507 .33042 Mdot
.55844 .46715 Mdot
.59694 .81654 Mdot
.6682 .25744 Mdot
.5503 .67878 Mdot
.50583 .62094 Mdot
.46476 .80298 Mdot
.62955 .26607 Mdot
.49306 .18908 Mdot
.43683 .10889 Mdot
.35797 .48834 Mdot
.49898 .95193 Mdot
.66791 .2634 Mdot
.50046 .94814 Mdot
.45978 .34239 Mdot
.51542 .93589 Mdot
.66994 .77023 Mdot
.60002 .21218 Mdot
.6794 .28882 Mdot
.73059 .77545 Mdot
.50309 .81755 Mdot
.46508 .88059 Mdot
.64643 .44668 Mdot
.39031 .21053 Mdot
.73116 .45513 Mdot
.43615 .72152 Mdot
.37996 .70156 Mdot
.59105 .59459 Mdot
.52643 .50526 Mdot
.50191 .90343 Mdot
.53563 .22059 Mdot
.43259 .87871 Mdot
.70117 .71764 Mdot
.42851 .53354 Mdot
.53749 .17752 Mdot
.61494 .44521 Mdot
.57803 .12567 Mdot
.4476 .32433 Mdot
.72292 .39383 Mdot
.71576 .65146 Mdot
.41936 .43309 Mdot
.38938 .43102 Mdot
.62061 .5497 Mdot
.68199 .58138 Mdot
.42757 .73282 Mdot
.51638 .61102 Mdot
.48388 .33236 Mdot
.56719 .27658 Mdot
.6767 .26516 Mdot
.64292 .72251 Mdot
.52079 .33915 Mdot
.53858 .85285 Mdot
.49421 .30216 Mdot
.43511 .55968 Mdot
.64627 .6047 Mdot
.39725 .66361 Mdot
.53369 .80382 Mdot
.56291 .70117 Mdot
.41502 .6597 Mdot
.69323 .20311 Mdot
.59177 .58162 Mdot
.64661 .56392 Mdot
.45957 .27275 Mdot
.53019 .06529 Mdot
.43525 .27727 Mdot
.67728 .40309 Mdot
.62549 .66692 Mdot
.5484 .53721 Mdot
.5148 .22703 Mdot
.52296 .97814 Mdot
.68561 .28825 Mdot
.51559 .9372 Mdot
.63677 .29172 Mdot
.52229 .7861 Mdot
.60744 .38922 Mdot
.66421 .36418 Mdot
.39711 .51736 Mdot
.68397 .2854 Mdot
.42749 .977 Mdot
.54891 .13961 Mdot
.70399 .33922 Mdot
.72548 .40526 Mdot
.73931 .50569 Mdot
.43968 .39299 Mdot
.42747 .77099 Mdot
.69568 .32628 Mdot
.63831 .20069 Mdot
.44797 .35113 Mdot
.40446 .21386 Mdot
.59208 .5667 Mdot
.39241 .38404 Mdot
.62121 .34172 Mdot
.37534 .6466 Mdot
.64936 .45042 Mdot
.55964 .87663 Mdot
.66537 .65688 Mdot
.56802 .79713 Mdot
.54246 .90464 Mdot
.56567 .80391 Mdot
.7243 .42269 Mdot
.78318 .62961 Mdot
.58629 .83114 Mdot
.43582 .15369 Mdot
.48218 .67946 Mdot
.7289 .59233 Mdot
.46639 .14636 Mdot
.47489 .32845 Mdot
.72656 .4023 Mdot
.38069 .42598 Mdot
.51877 .60084 Mdot
.55387 .59198 Mdot
.59709 .4732 Mdot
.47479 .21069 Mdot
.37142 .6022 Mdot
.47541 .06392 Mdot
.65336 .80285 Mdot
.72419 .39605 Mdot
.58024 .31198 Mdot
.66575 .1654 Mdot
.59736 .35727 Mdot
.53477 .71415 Mdot
.49944 .78914 Mdot
.50276 .60204 Mdot
.66604 .24662 Mdot
.6835 .28618 Mdot
.44639 .24409 Mdot
.54824 .50914 Mdot
.47937 .20635 Mdot
.5434 .36831 Mdot
.72105 .65458 Mdot
.47019 .17757 Mdot
.57741 .18541 Mdot
.52609 .65438 Mdot
.53721 .3068 Mdot
.45561 .3047 Mdot
.43195 .24387 Mdot
.59156 .3475 Mdot
.49695 .22417 Mdot
.47233 .72698 Mdot
.67913 .76442 Mdot
.60784 .16055 Mdot
.46033 .39439 Mdot
.60466 .64277 Mdot
.58296 .31212 Mdot
.45118 .12955 Mdot
.58605 .60596 Mdot
.54753 .33693 Mdot
.72789 .60678 Mdot
.65135 .47957 Mdot
.79241 .48648 Mdot
.64345 .40732 Mdot
.44201 .6775 Mdot
.39469 .19452 Mdot
.70033 .33982 Mdot
.41333 .43056 Mdot
.62587 .66283 Mdot
.69998 .21468 Mdot
.54724 .53486 Mdot
.52757 .5168 Mdot
.5106 .76491 Mdot
.53469 .1266 Mdot
.54838 .72733 Mdot
.53469 .55011 Mdot
.60209 .64389 Mdot
.6215 .49919 Mdot
.50235 .29059 Mdot
.4315 .57511 Mdot
.56166 .53145 Mdot
.64284 .20543 Mdot
.43195 .40716 Mdot
.68815 .57252 Mdot
.64975 .57277 Mdot
.56314 .21564 Mdot
.65472 .32967 Mdot
.40578 .20923 Mdot
.56203 .26969 Mdot
.35924 .39546 Mdot
.54938 .61603 Mdot
.68126 .27405 Mdot
.73754 .56159 Mdot
.44331 .73939 Mdot
.51403 .93826 Mdot
.58356 .62145 Mdot
.47236 .15045 Mdot
.6764 .39799 Mdot
.62945 .36597 Mdot
.5693 .60271 Mdot
.51933 .23473 Mdot
.60241 .38164 Mdot
.61614 .87001 Mdot
.48383 .87379 Mdot
.44578 .4313 Mdot
.54748 .78077 Mdot
.517 .79036 Mdot
.4373 .40868 Mdot
.42402 .38175 Mdot
.58393 .70262 Mdot
.47653 .87958 Mdot
.46767 .70363 Mdot
.59725 .51378 Mdot
.42931 .06782 Mdot
.40399 .51006 Mdot
.55805 .21055 Mdot
.57689 .45863 Mdot
.57563 .51037 Mdot
.48575 .31142 Mdot
.79374 .55817 Mdot
.49504 .32728 Mdot
.6437 .61431 Mdot
.46631 .96098 Mdot
.58599 .1995 Mdot
.57312 .44139 Mdot
.68612 .45145 Mdot
.71114 .35279 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
0_l0002aooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo0_l0
002aooooo`00UOooool2o`0000gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2i
ooooo`00UOooool2o`0000_ooooo00?oEEEEofIVI_l000000_l00005ooooo`03o`000?oooooooooo
0;Wooooo002Rooooo`;o000000?oooooo`000?l000001Oooool00ol0003oooooooooo`2iooooo`00
XOooool3o`0000Sooooo00?o0000ooooooooool0^Oooool00:7ooooo0_l00009ooooo`?o0000^Ooo
ool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o
0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool04oooool2o`000:Cooooo002/ooooo`03o`000?oooooooooo01?ooooo0_l0002Tooooo`00
[?ooool3o`0001?ooooo0_l0002Tooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`05ooooo`;o0000/_ooool009Gooooo0_l0000Eooooo`03o`000?oooooooooo
00Gooooo0_l0002booooo`00UOooool2o`0000cooooo0_l00007ooooo`03o`000?oooooooooo00Oo
oooo0_l0002`ooooo`00U?ooool2o`0000cooooo0ol00007ooooo`03o`000?oooooooooo00Oooooo
0_l0002`ooooo`00U?ooool2o`0000_ooooo0ol00008ooooo`03o`000?oooooooooo0;Wooooo002Q
ooooo`?o00002?ooool00ol0003oooooooooo`0:ooooo`;o0000[Oooool00:cooooo0ol0000:oooo
o`;o0000[Oooool009?ooooo0_l0000Gooooo`03o`000?oooooooooo0;Wooooo002Cooooo`;o0000
5oooool00ol0003oooooooooo`2iooooo`00V_ooool2o`00013ooooo00?o0000ooooooooool0^Ooo
ool009[ooooo0_l0000@ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo00kooooo0_l0002Yooooo`00[?ooool00ol0003ooooo
ooooo`02o`0000cooooo0_l0002Yooooo`00[?ooool5o`000;Oooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Gooooo`;o00004oooool00ol0003o
ooooooooo`2iooooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool0^Oooool00:cooooo00?o
0000ooooooooool05_ooool2o`000:7ooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo
00?o0000ooooooooool05_ooool2o`000:7ooooo0028ooooo`;o000000CoV9RHoooooonHV9SoMgMg
1Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo01Kooooo0_l0002Qooooo`00POooool6o`000003ooooool0003o000000?ooooo00?o
410@ooooooooool01?ooool2o`0000Gooooo00?oZJVYoeEEEOooool02?ooool00ol0003ooooooooo
o`03ooooo`?o00002Oooool2o`0000_ooooo0_l0002Qooooo`00ROooool01Ol0003ooooooooooooo
oooo000000Kooooo0_l00006ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`08ooooo`?o00002oooool2o`000:7ooooo0029ooooo`05o`000?oooooo
ooooooooool000003Oooool2o`000003olc<c?oooooooooo00;ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`03o`000?oooooooooo00Sooooo0ol0002^ooooo`00ROooool01Ol@413ooooooooo
oooooooo410@00gooooo0_l000000omgMgOoooooooooo`02ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02Oooool2o`000:kooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2iooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co
00001_ooool00ol0003oooooooooo`0=ooooo`;o0000Z_ooool00:cooooo00Co0000oooooooooooo
oooo0_l0000:ooooo`;o0000Z_ooool00:3ooooo0_l00002ooooo`;o00001_ooool01?l0003ooooo
ooooooooool2o`000;Kooooo002Pooooo`;o00000_ooool2o`0000Kooooo00?o0000ooooooooool0
^Oooool00:;ooooo0_l00008ooooo`?o0000^Oooool009Kooooo0_l0000:ooooo`;o00001_ooool3
o`000;_ooooo002Fooooo`;o00004_ooool3o`0002?ooooo0_l0002Fooooo`00[?ooool00ol0003o
ooooooooo`0Pooooo`?o0000U_ooool00:cooooo00?o0000ooooooooool08?ooool3o`0009Kooooo
002/ooooo`03o`000?oooooooooo027ooooo0_l0000@ooooo`;o0000Q?ooool00:cooooo00?o0000
ooooooooool0<oooool2o`0008Cooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o
0000^Oooool00:;ooooo0_l000000ooooooo0000o`000005ooooo`03o`000?oooooooooo00Wooooo
0_l0002^ooooo`00X_ooool2o`000003ooooool0003o000000Gooooo00?o0000ooooooooool02Ooo
ool2o`000:kooooo002Oooooo`;o00002oooool01?l0003oooooooooooooool2o`0001?ooooo0_l0
002Qooooo`00Woooool2o`0000Sooooo0_l000000ooooooo0000ooooo`02ooooo`?o00004_ooool2
o`000:7ooooo002Yooooo`;o000000?oooooo`000?ooool00oooool2o`0002Cooooo0_l0002?oooo
o`00R?ooool3o`00017ooooo0_l0000>ooooo`03o`000?oooooooooo02Sooooo0_l0002?ooooo`00
R?ooool3o`00017ooooo0_l0000>ooooo`03o`000?oooooooooo00kooooo0_l0002Yooooo`00[?oo
ool3o`0000kooooo0_l00009ooooo`;o00003oooool2o`0008gooooo002/ooooo`03o`000?oooooo
oooo01Wooooo0_l0000?ooooo`Co00003_ooool2o`0007_ooooo002Uooooo`;o00001Oooool00ol0
003oooooooooo`0/ooooo`;o00003_ooool2o`0007_ooooo0023ooooo`;o00000_ooool2o`0000?o
oooo0_l0000Eooooo`Co00001Oooool00ol0003oooooooooo`0@ooooo`;o00006_ooool2o`0008_o
oooo0023ooooo`;o00000_ooool2o`0000?ooooo0_l0000Eooooo`;o00001oooool00ol0003ooooo
ooooo`0@ooooo`;o00003?ooool2o`0009Wooooo002<ooooo`;o00007_ooool00ol0003ooooooooo
o`0Aooooo`;o00002oooool2o`0001oooooo0_l0001hooooo`00S?ooool2o`0001kooooo00?o0000
ooooooooool04Oooool2o`0001_ooooo0_l0000?ooooo`;o0000N?ooool00:cooooo00?o0000oooo
ooooool02?ooool2o`0002Cooooo0_l00029ooooo`00Zoooool4o`0000Sooooo0_l0002_ooooo`00
Soooool2o`0000_ooooo0_l0000=ooooo`;o00000oooool2o`000;Kooooo002?ooooo`;o000000?o
ooooo`000?l000002?ooool2o`0000kooooo00Co0000oooooooooooooooo0_l0002fooooo`00T_oo
ool2o`0000Sooooo0_l0000>ooooo`03o`000?oooooooooo00?ooooo0_l0000@ooooo`;o0000X_oo
ool009cooooo0_l0000>ooooo`03o`000?oooooooooo00?ooooo0_l0000@ooooo`;o0000X_ooool0
09Kooooo0_l0000Dooooo`03o`000?oooooooooo0;Wooooo002Aooooo`04onk^k_lb<S;o0000oc8b
<P?o00000oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0;Wooooo002Aooooo`04ogMgMonHV9SooooooiRHV0;o00000oooool2o`000003ob4Q8Ooooooo
oooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Gooooo`;o00006_ooool2
o`0000oooooo0_l0001cooooo`00ROooool6o`0000;ooooo00Go410@oooooooooooooooooa0@4004
ooooo`;o00000oooool2o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07
ooooo`;o00003_ooool2o`0001[ooooo0_l0000?ooooo`?o0000L_ooool008Gooooo0_l0000:oooo
o`05o`000?ooooooooooooooool000002Oooool2o`0000Cooooo00?oMgMgoc8b<_ooool00_ooool5
o`0000Oooooo0_l0000looooo`;o0000L_ooool008Gooooo0_l0000:ooooo`05o`000?oooooooooo
ooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00?ooooo0ol0002kooooo`00QOooool2
o`0000[ooooo00Go410@oooooooooooooooooa0@4007ooooo`;o00000oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo013ooooo0_l0000Rooooo`;o0000Poooool0097ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`07ooooo`;o00000oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo013ooooo0_l0000Rooooo`;o0000Poooool0097ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`Co00001_ooool00ol0003oooooooooo`0dooooo`;o000000?oooooo`000?l00000P?oo
ool00:cooooo00?o0000ooooooooool04_ooool2o`0001;ooooo0ol0000;ooooo`;o000000?ooooo
o`000?l00000P?ooool009oooooo0_l0000;ooooo`03o`000?oooooooooo017ooooo0ol0000Boooo
o`?o0000T?ooool009kooooo0ol0000;ooooo`03o`000?oooooooooo017ooooo0ol0000Tooooo`;o
00003oooool2o`0006kooooo002<ooooo`;o00002?ooool2o`0000Kooooo0_l0000<ooooo`?o0000
4oooool2o`0002?ooooo0_l0000?ooooo`;o0000K_ooool008Cooooo0_l00006ooooo`;o00002?oo
ool2o`0001Cooooo00?o0000ooooooooool04oooool2o`000:Cooooo0024ooooo`;o00001_ooool2
o`0000_ooooo0_l0000Aooooo`03o`000?oooooooooo00;o00000oooool2o`00037ooooo0_l0001o
ooooo`00VOooool2o`00017ooooo00?o0000ooooooooool00_l00003ooooo`;o0000<Oooool3o`00
07kooooo002?ooooo`;o00004oooool2o`0000Kooooo00?o0000ooooooooool03Oooool2o`0002Wo
oooo1?l0001mooooo`00Soooool2o`0001?ooooo0_l00006ooooo`;o00003_ooool2o`0001_ooooo
0_l0000<ooooo`Co0000OOooool00:cooooo0_l0000[ooooo`;o00003_ooool2o`0007gooooo002>
ooooo`;o00007?ooool2o`0000Wooooo0_l0000`ooooo`;o0000OOooool008Cooooo0_l00008oooo
o`;o00007?ooool3o`0000Sooooo0_l0002_ooooo`00Q?ooool2o`0002Cooooo0ol00005ooooo`;o
00000oooool2o`0003?ooooo0_l0001jooooo`00WOooool2o`0000_ooooo0ol00005ooooo`;o0000
0oooool3o`0001Gooooo0_l0000:ooooo`;o00003?ooool2o`000003ooooool0003o000007[ooooo
002Mooooo`;o00003Oooool00ol0003oooooooooo`09ooooo`;o00005Oooool2o`0000[ooooo0_l0
000<ooooo`;o0000OOooool00:Oooooo0_l00003ooooo`03o`000?oooooooooo01Oooooo0ol0000Q
ooooo`?o0000Noooool00:Oooooo0_l00003ooooo`03o`000?oooooooooo01Oooooo0ol0000Coooo
o`;o00003?ooool3o`0007_ooooo002/ooooo`03o`000?oooooooooo013ooooo0_l0000Kooooo`Co
0000R?ooool00:cooooo00?o0000ooooooooool04?ooool2o`0001gooooo0_l00028ooooo`00V_oo
ool2o`00013ooooo0ol0000mooooo`;o0000N_ooool009[ooooo0_l00007ooooo`;o00001Oooool3
o`0001Cooooo0_l0000>ooooo`;o00006Oooool2o`0007[ooooo002Sooooo`;o00001Oooool3o`00
0003ooooool0003o0000017ooooo0_l0000>ooooo`;o00003?ooool2o`0000_ooooo0_l0001joooo
o`00Y_ooool2o`0000Cooooo00Co0000ooooool0003o0000;oooool2o`0008Oooooo002Vooooo`;o
00001?ooool00ol0003oooooooooo`0<ooooo`;o0000<oooool2o`0007Kooooo002/ooooo`03o`00
0?oooooooooo00?ooooo0_l00007ooooo`;o0000<Oooool4o`0007Kooooo002Nooooo`;o00003?oo
ool00ol0003oooooooooo`03ooooo`;o00003_ooool2o`0000oooooo0ol0000Hooooo`?o0000Mooo
ool009kooooo0_l0000<ooooo`03o`000?oooooooooo00Cooooo0_l0000=ooooo`;o00003oooool3
o`0009;ooooo002/ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`;o00003?ooool2o`00
02Cooooo0_l0001fooooo`00V_ooool2o`00013ooooo0ol0000=ooooo`;o00003?ooool2o`0002Co
oooo0ol0001eooooo`00V_ooool2o`00013ooooo00?o0000ooooooooool0<oooool2o`0000gooooo
0_l0001eooooo`00[?ooool00ol0003oooooooooo`0Mooooo`;o00005?ooool2o`0008Cooooo002/
ooooo`03o`000?oooooooooo01gooooo0_l00008ooooo`;o0000T?ooool00:cooooo00?o0000oooo
ooooool09oooool2o`0000[ooooo0_l00024ooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool05Oooool2o`00013ooooo0_l0000:ooooo`;o0000Q?ooool008Wooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q0_ooool2o`000005oiRHV?lQ8B7ok^k^oooooom4A4@00_l0
0005ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool02oooool2o`0000Sooooo0_l0
000@ooooo`;o0000T?ooool0087ooooo1_l00002ooooo`05oa0@4?oooooo0000o`000?l@41002Ooo
ool2o`000005oooooonHV9So8B4Qonk^k_ooool00_l00006ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02oooool2o`0001cooooo0_l0002>ooooo`00ROooool00ol0003oooooo`00
0002o`0000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o00002ooo
ool2o`0001cooooo0_l0000:ooooo`?o0000POooool008;ooooo0_l00005ooooo`05o`000?oooooo
ooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`0dooooo`Co0000POooool008;ooooo0_l00005ooooo`05oa0@4?oo
ooooooooooooool@41001?ooool2o`0000Wooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo01kooooo0_l00008ooooo`;o00002_ooool2o`0008?ooooo
0028ooooo`;o000000CoV9RHoooooonHV9SoMgMg1?ooool2o`0000Gooooo00Go0000okZj^_oooooo
V9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04Oooool2o`0000Co
oooo0_l00005ooooo`;o00002?ooool2o`0001cooooo0_l0001aooooo`00R?ooool2o`000004oc8b
<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0
003oooooooooo`0Aooooo`;o00001?ooool2o`0000Oooooo0_l0000Tooooo`;o0000LOooool0093o
oooo0_l0000Jooooo`03o`000?oooooooooo017ooooo0_l0000=ooooo`;o0000Uoooool007gooooo
0_l0000Aooooo`;o00001_ooool2o`0000Cooooo0_l0000<ooooo`03o`000?oooooooooo04Kooooo
0_l0001aooooo`00OOooool2o`0001Wooooo0_l00004ooooo`;o00003?ooool01?l0003oooooo`00
0?l0000fooooo`;o00003Oooool3o`00073ooooo002/ooooo`Co0000=_ooool2o`0000kooooo0_l0
001`ooooo`00SOooool2o`0001gooooo00?o0000ooooooooool0:_ooool2o`0000_ooooo0_l0000>
ooooo`;o0000L?ooool008gooooo0_l00006ooooo`;o00005Oooool00ol0003oooooooooo`0Zoooo
o`Co00002Oooool2o`0000kooooo0_l0001`ooooo`00UOooool4o`0000;ooooo0_l0000?ooooo`03
o`000?oooooooooo02cooooo0_l0000Iooooo`;o0000L?ooool009Oooooo0_l00002ooooo`;o0000
3oooool00ol0003oooooooooo`0Cooooo`;o0000Y?ooool00:cooooo00?o0000ooooooooool04ooo
ool2o`000:Cooooo002/ooooo`03o`000?oooooooooo00[ooooo0_l0000Gooooo`;o0000U?ooool0
07gooooo0_l0000]ooooo`03o`000?oooooooooo00[ooooo0_l0000Eooooo`Co00001oooool2o`00
01Wooooo0_l0001`ooooo`00OOooool2o`00013ooooo0_l0000Kooooo`?o00002oooool2o`0001Co
oooo0_l00008ooooo`?o00002oooool3o`0000_ooooo0_l0001`ooooo`00Q?ooool2o`0000Wooooo
0_l0000Kooooo`03o`000?oooooooooo00_ooooo0_l0000Nooooo`;o00003?ooool3o`0007gooooo
0024ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Wooooo0_l0000@ooooo`03o`000?oo
oooooooo0;Wooooo0024ooooo`;o000000?oooooo`000?l000001?ooool6o`0000Oooooo0_l0000@
ooooo`03o`000?oooooooooo00_ooooo0_l0002/ooooo`00SOooool2o`0000;ooooo0_l0000Ioooo
o`03o`000?oooooooooo00_ooooo0_l0002/ooooo`00Qoooool2o`0002?ooooo00?o0000oooooooo
ool0^Oooool008Oooooo0_l0000Sooooo`03o`000?oooooooooo01Gooooo0_l0002Rooooo`00Q?oo
ool2o`0002Kooooo00?o0000ooooooooool02oooool2o`0000Sooooo0_l0000<ooooo`;o00002?oo
ool2o`0008[ooooo0024ooooo`;o00009_ooool00ol0003oooooooooo`0;ooooo`;o00000oooool2
o`00017ooooo0_l00008ooooo`;o00002_ooool2o`0007kooooo002/ooooo`?o00004?ooool2o`00
01cooooo0_l00009ooooo`?o0000OOooool00:cooooo00?o0000ooooooooool0;_ooool2o`0000[o
oooo0_l0000=ooooo`;o0000K_ooool008Cooooo0_l0000Vooooo`03o`000?oooooooooo01Kooooo
0_l0000Fooooo`;o00006Oooool2o`0006kooooo0009ooooo`Co000000?o410@ooooooooool05_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo
00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@;o00000_ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Fooooo`03o`00
0?oooooooooo01Kooooo0_l000001Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go
000000Goooooo`000?l0003oooooodA4A002o`000003oc8b<_oMgMgooooo00kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4
A?l0003o0000oc8b<_oMgMd06?ooool4o`000003oa0@4?oooooooooo01;ooooo000;ooooo`03o`00
0?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGo
ZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo01Gooooo00?o
0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`0>ooooo`04ogMgMonHV9SooooooiRH
V0Co00000_ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool06Oooool0
0ol0003oooooooooo`0Dooooo`001_l00005ooooo`03o`000?oooooooooo013ooooo1_l00002oooo
o`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooo
oooo00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`05ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0
1_ooool2o`000003ooooool0003ooooo01Gooooo00?o0000ooooooooool04?ooool2o`0000Kooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000oooooooo
ool03Oooool01?l@413oooooooooooooool4o`0000gooooo00?o0000ooooooooool03Oooool01Ol@
413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool03_ooool0
1Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool2o`000003ogMgMolb<S;ooooo01Gooooo
00?o0000ooooooooool04?ooool2o`0000Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03
oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Q
ooooooooool01_ooool00omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo000;oooo
o`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<co
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Co0000oooooooooooooooo0ol0000<oooo
o`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Fooooo`03o`000?oooooo
oooo01Sooooo00Co0000oooooooooooooooo0ol0000<ooooo`03ogMgMomVIVKooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c00?ooooo`04o`000?ooooooooooooooo`;o00002oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<co
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Jooooo`03o`000?oooooooooo01Cooooo000;
ooooo`03o`000?oooooooooo01Sooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmg
MgOooooo00?ooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00cooooo
00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00;o00003Oooool4o`000003
ooooool0003ooooo01Wooooo0ol0000Hooooo`05oa0@4?ooooooooooooooool@41000_l0000=oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04Oooool01?l@413oooooooooooooool2
o`0000_ooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o
ZJVYogMgMoooool00oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Cooooo000;
ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oo
oooooooooooooolb<S801?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01?l0
003o^[ZjoooooonHV9P4o`000003ooooool0003ooooo01Wooooo00?o0000ooooooooool06?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4002ooooo`?o0000
2Oooool2o`0000Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02o`0000[ooooo00?o0000oooooooo
ool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05?ooool000Wooooo00?oEEEEofIV
I_l000006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00004?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0000Gooooo`03o`000?oooooooooo00So
oooo0_l00007ooooo`;o00001Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c002ooooo`Ko00001_ooool2o`0000Sooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP04o`0000Sooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo
1?l0000Iooooo`03oeEEEOmVIVKo000001Kooooo0027ooooo`;o00008oooool00ol0003ooooooooo
o`08ooooo`;o00001oooool2o`0000?ooooo0_l0000Eooooo`;o00007Oooool2o`0006_ooooo001m
ooooo`;o00002?ooool2o`0002?ooooo00?o0000ooooooooool05_ooool2o`0001Gooooo0_l0000M
ooooo`;o00003oooool2o`0005[ooooo001mooooo`;o0000;Oooool00ol0003oooooooooo`0koooo
o`;o00003oooool2o`0000oooooo0_l0001?ooooo`;o00000_ooool2o`0000Gooooo002/ooooo`03
o`000?oooooooooo03_ooooo0_l0001aooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1Oooool0
0:cooooo00?o0000ooooooooool0??ooool2o`00077ooooo00CogMgMo`000?l@413oc<c<1_ooool0
00Ooooooool0001<o`0000cooooo00Cok^k^ob4Q8Ol@413ok^k^1_ooool000Oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`04ooooo`?o00001oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04oooo
o`?o00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`02o`0000?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0:ooooo`04ob4Q8OmgMgOoMgMgoc8b<PKooooo0007ooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool01Oooool2o`0001gooooo0_l000000ooooooo0000ooooo`0Soooo
o`;o00000_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool02Oooool2o`0000;ooooo0_l00005ooooo`00S?ooool2o`0001kooooo00?o0000oooooooo
ool01Oooool2o`0000Gooooo0_l00008ooooo`;o00003?ooool2o`0002Kooooo0_l0001[ooooo`00
S?ooool2o`0001kooooo00?o0000ooooooooool03?ooool2o`0000Sooooo0_l0002Qooooo`00[?oo
ool00ol0003oooooooooo`09ooooo`;o00004_ooool2o`0009[ooooo002:ooooo`;o00008?ooool0
0ol0003oooooooooo`06ooooo`;o000000?oooooo`000?l000004_ooool2o`0009[ooooo002:oooo
o`;o00008?ooool00ol0003oooooooooo`06ooooo`;o0000/Oooool00:cooooo0ol0000jooooo`;o
0000OOooool00:cooooo00?o0000ooooooooool05_ooool2o`0002;ooooo0_l0001mooooo`00[?oo
ool00ol0003oooooooooo`0Aooooo`;o00000oooool2o`0002;ooooo0ol0001looooo`00U?ooool2
o`0001Kooooo00?o0000ooooooooool04Oooool2o`00017ooooo0_l0000Dooooo`?o0000O?ooool0
09Cooooo0_l0000Fooooo`03o`000?oooooooooo00cooooo0ol0000Eooooo`;o0000Toooool00:co
oooo00?o0000ooooooooool03?ooool3o`000:[ooooo002/ooooo`03o`000?oooooooooo03[ooooo
0_l0001mooooo`00[?ooool00ol0003oooooooooo`0jooooo`;o0000OOooool00:cooooo00?o0000
ooooooooool09?ooool2o`0009?ooooo002/ooooo`?o00002?ooool2o`0000Kooooo0_l0000Boooo
o`;o0000Toooool00:cooooo00?o0000ooooooooool02?ooool2o`0000Kooooo0_l0002Wooooo`00
Q?ooool2o`0002Kooooo00?o0000ooooooooool0G_ooool2o`0005Wooooo0024ooooo`;o00004?oo
ool2o`0001Cooooo00?o0000ooooooooool07?ooool3o`0001cooooo0_l0000>ooooo`;o00004Ooo
ool2o`0005Wooooo002Fooooo`;o00005?ooool00ol0003oooooooooo`0Looooo`?o00003_ooool2
o`0000cooooo0_l0000>ooooo`;o0000K?ooool00:cooooo0_l0000Looooo`;o00004?ooool2o`00
08[ooooo002Fooooo`;o00005?ooool2o`0001cooooo0_l0000Mooooo`;o0000OOooool009Kooooo
0_l0000Dooooo`03o`000?oooooooooo01Gooooo0_l0000Gooooo`;o00002_ooool3o`0007cooooo
002Eooooo`;o00005Oooool3o`0001Gooooo0_l0000Gooooo`;o00002oooool2o`00023ooooo0_l0
001Jooooo`00UOooool2o`0001Gooooo00?o0000ooooooooool0GOooool2o`0005[ooooo002=oooo
o`;o00007Oooool00ol0003oooooooooo`0Kooooo`;o00007?ooool2o`0000oooooo0_l0001]oooo
o`00Q?ooool2o`0000Oooooo0_l0000Mooooo`03o`000?oooooooooo01_ooooo0_l0000Looooo`;o
00003oooool2o`0006gooooo0024ooooo`;o00009_ooool00ol0003oooooooooo`2iooooo`00[?oo
ool00ol0003oooooooooo`0>ooooo`;o0000>?ooool2o`0006oooooo002/ooooo`03o`000?oooooo
oooo00kooooo0_l0000;ooooo`;o00004Oooool2o`0000Wooooo0_l0000=ooooo`;o0000Koooool0
08Sooooo0_l0000Rooooo`03o`000?oooooooooo01_ooooo0_l0000Aooooo`;o00002Oooool2o`00
07kooooo0028ooooo`;o00003?ooool2o`0001Cooooo0ol00003ooooo`;o0000=?ooool2o`0007ko
oooo0021ooooo`;o00004oooool2o`0001Cooooo0_l00004ooooo`;o00003_ooool2o`0002Cooooo
0_l0001nooooo`00POooool2o`0002Wooooo0_l0000Dooooo`;o00001?ooool2o`0001;ooooo0_l0
000Iooooo`;o0000Koooool00:cooooo00?o0000ooooooooool06Oooool2o`0001;ooooo0_l0000I
ooooo`;o0000Koooool009[ooooo0_l0000@ooooo`03o`000?oooooooooo00;ooooo0_l0000Moooo
o`;o00002?ooool2o`0008cooooo002Jooooo`;o00004?ooool00ol0003oooooooooo`02ooooo`;o
00002Oooool2o`0001;ooooo0_l00008ooooo`?o0000Roooool008Wooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo00gooooo0_l0000Mooooo`;o0000Roooool008Wooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMg
oc8b<_ooool01?ooool3o`0000Cooooo0_l0000Booooo`;o0000Woooool008Wooooo00Go410@oooo
oooooooooooooa0@4009ooooo`;o000000CooooooiRHV?lQ8B7ok^k^2Oooool00ol0003ooooooooo
o`03ooooo`?o00001?ooool2o`0001;ooooo0_l0000Aooooo`;o0000S?ooool008Wooooo00Go0000
ooooooooooooooooo`000009ooooo`;o00000_ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool02?ooool2o`00027ooooo0_l0002<ooooo`00ROooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool02?ooool2o`00053ooooo0_l0001Mooooo`00QOoo
ool2o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`;o000000?oooooo`000?ooool0
0oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02[ooooo0_l0000^ooooo`;o0000
GOooool008Gooooo0_l00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool3o`000003oiRH
V?l@413ooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Gooooo`;o0000
4Oooool2o`0000_ooooo0_l00020ooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`0Gooooo`;o
00007_ooool2o`00083ooooo002/ooooo`04o`000?oooooo0000o`0001gooooo0ol0002Hooooo`00
P_ooool2o`0002Sooooo00Co0000ooooool0003o00007Oooool3o`0009Sooooo0022ooooo`;o0000
:?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`0004Cooooo0_l0001cooooo`00[?ooool0
0ol0003oooooooooo`05ooooo`;o0000?Oooool4o`00077ooooo0023ooooo`;o00009oooool00ol0
003oooooooooo`05ooooo`;o0000;?ooool2o`00017ooooo0_l0001aooooo`00Poooool2o`0000_o
oooo0_l0000Jooooo`03o`000?oooooooooo00oooooo0_l0000Rooooo`;o0000Q?ooool008[ooooo
0_l000001?oooooo0000o`000?ooool2o`0001[ooooo00?o0000ooooooooool03_ooool3o`0001Go
oooo0_l0002Aooooo`00R_ooool2o`000003ooooool0003o000000Kooooo0_l0000Eooooo`;o0000
3oooool2o`0001Kooooo0_l0002Aooooo`00UOooool2o`0001Gooooo0_l00009ooooo`;o00007?oo
ool2o`00097ooooo002Kooooo`;o00003oooool00ol0003oooooooooo`08ooooo`;o0000[oooool0
09_ooooo0_l00002ooooo`;o00002oooool3o`000;Wooooo002Hooooo`;o00001Oooool2o`0000Go
oooo0_l00004ooooo`03o`000?oooooooooo00gooooo0_l0002Zooooo`00V?ooool2o`0000cooooo
0_l00004ooooo`03o`000?oooooooooo00gooooo0_l0002Zooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00U?ooool2o`0001Kooooo00?o0000ooooooooool0^Oooool009Cooooo0_l0000Fooooo`03o`00
0?oooooooooo00Gooooo0_l0002booooo`00Q?ooool2o`0002Kooooo0ol00005ooooo`;o00002_oo
ool2o`000:Kooooo0024ooooo`;o00006oooool2o`0000Wooooo00?o0000ooooooooool04Oooool2
o`0000Gooooo0_l0000Gooooo`;o0000Q_ooool008Cooooo0_l0000Kooooo`;o00002Oooool00ol0
003oooooooooo`04ooooo`;o00002oooool2o`0000Gooooo0_l0000Gooooo`;o0000Q_ooool00:co
oooo00?o0000ooooooooool01?ooool2o`0002Sooooo0_l0000Rooooo`;o0000IOooool00:cooooo
00?o0000ooooooooool01?ooool2o`00017ooooo0_l0000Eooooo`;o00008_ooool2o`0006Gooooo
002/ooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`;o00003Oooool2o`000:3ooooo002X
ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`;o00001?ooool2o`0003Gooooo0_l0001h
ooooo`00U_ooool2o`00013ooooo0_l00002ooooo`03o`000?oooooooooo02cooooo0_l0000@oooo
o`?o0000N?ooool009Kooooo0_l0000Cooooo`Co0000;?ooool2o`00013ooooo0_l0001iooooo`00
Uoooool2o`0000Wooooo0_l00007ooooo`;o00002?ooool2o`0000Gooooo0_l0002Zooooo`00Uooo
ool2o`0000Wooooo0_l00008ooooo`03o`000?oooooooooo00Kooooo0_l00005ooooo`;o0000Z_oo
ool009Cooooo0_l0000Fooooo`03o`000?oooooooooo0;Wooooo002Dooooo`;o00005_ooool00ol0
003oooooooooo`0[ooooo`;o0000S?ooool009Wooooo0_l0000Aooooo`03o`000?oooooooooo02_o
oooo0_l0002<ooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo0_l00002ob4Q8@03
ooooool0003o000000;ooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
02Wooooo0ol0002=ooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B400ooo
oooo0000o`000005ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0:Oooool3o`00
08gooooo002:ooooo`;o00001Oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0iooooo`Co0000O?ooool008Kooooo0_l00002ooooo`;o
00001Oooool01Ol0003ooooooooooooooooo000000[ooooo0_l00003ooooo`03ogMgMolb<S;ooooo
00Cooooo0ol0000iooooo`Co0000O?ooool008Kooooo0_l00009ooooo`05o`000?oooooooooooooo
ool000002_ooool3o`000004ob4Q8Ol0003o<S8bolc<c0Gooooo00?o0000ooooooooool0:Oooool2
o`0008kooooo002Aooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo02Sooooo0ol0002>ooooo`00TOooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Aooooo`;o00005Oooool2
o`0008oooooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000
ooooooooool00_l0000?ooooo`;o00009Oooool2o`0007oooooo002/ooooo`03o`000?oooooooooo
00;o00005oooool2o`0001gooooo0_l0001oooooo`00U?ooool2o`0000Sooooo0_l0000<ooooo`03
o`000?oooooooooo00Gooooo0_l0000Booooo`;o00006_ooool2o`0008;ooooo002Dooooo`;o0000
0_ooool2o`0000Cooooo0_l0000<ooooo`03o`000?oooooooooo00Gooooo0_l0000^ooooo`;o0000
P_ooool009Cooooo0_l00002ooooo`;o00004_ooool3o`0004Wooooo0_l0001^ooooo`00U?ooool2
o`0001Kooooo00?o0000ooooooooool0BOooool2o`0006kooooo002Sooooo`;o00001oooool00ol0
003oooooooooo`0<ooooo`;o00009_ooool2o`0008?ooooo002Sooooo`;o00001oooool00ol0003o
ooooooooo`04ooooo`;o00001_ooool2o`0002Kooooo0_l00023ooooo`00Zoooool2o`0000Kooooo
0_l0002cooooo`00Zoooool2o`0000Cooooo0_l0000Mooooo`;o0000U_ooool00:cooooo00?o0000
ooooooooool00_ooool2o`0000Oooooo0_l0000Dooooo`;o0000U_ooool00:cooooo00?o0000oooo
ooooool02oooool2o`0000Kooooo0_l0002Tooooo`00T_ooool2o`0001Sooooo0ol00008ooooo`;o
00002Oooool2o`000:Cooooo002Booooo`;o00003?ooool2o`0000[ooooo00?o0000ooooooooool0
2?ooool2o`0000Sooooo0_l0000Kooooo`;o0000R?ooool008gooooo0_l0000Aooooo`;o00001_oo
ool2o`0000;ooooo00?o0000ooooooooool02?ooool2o`0000Sooooo0_l0000=ooooo`;o00003?oo
ool2o`0008Sooooo002=ooooo`;o00006Oooool2o`0000;ooooo00?o0000ooooooooool08Oooool2
o`0009Kooooo002/ooooo`03o`000?oooooooooo02oooooo0_l00028ooooo`00[?ooool00ol0003o
ooooooooo`0Mooooo`;o00004?ooool2o`0008Sooooo002/ooooo`?o00003oooool2o`0000cooooo
0_l0000>ooooo`;o0000R_ooool009Cooooo0_l0000Fooooo`?o00003oooool2o`0000_ooooo0_l0
000?ooooo`;o0000R_ooool008oooooo0_l00003ooooo`;o00005_ooool3o`0000Cooooo0ol0000D
ooooo`?o0000Voooool008oooooo0_l0000Kooooo`03o`000?oooooooooo00Cooooo0ol00007oooo
o`;o00002oooool2o`0009cooooo002/ooooo`03o`000?oooooooooo00kooooo0_l00009ooooo`;o
0000W_ooool00:cooooo00?o0000ooooooooool06Oooool2o`0009kooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002Oooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0^Oooool0
09oooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`0000Wooooo0_l0
002^ooooo`00[?ooool00ol0003oooooooooo`09ooooo`;o0000[_ooool00:cooooo00?o0000oooo
ooooool09?ooool2o`0009?ooooo002/ooooo`03o`000?oooooooooo02Cooooo0_l0002Cooooo`00
[?ooool00ol0003oooooooooo`0Tooooo`;o0000Toooool008Wooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01Oooool00ol0003oooooooooo`2iooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`0Sooooo`;o0000U?ooool008Wooooo00Go410@oooooooooooooooooa0@400=ooooo`03
ojVYZOmEEEGooooo00Sooooo0_l000001Ooooooo0000o`000?oooooo000002Gooooo0_l0002Doooo
o`00ROooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool01?mg
MgOo0000o`000?ooool2o`000004ooooool0003o0000o`00013ooooo0_l0002Wooooo`00ROooool0
1Ol0003ooooooooooooooooo000000Oooooo0_l00005ooooo`03oeEEEOo<c<cooooo00?ooooo1?l0
00000oo<c<coooooooooo`03ooooo`03o`000?oooooooooo013ooooo0_l0002Wooooo`00ROooool0
1_l@413ooooooooooooooooo410@ooooo`;o00001?ooool2o`0000Gooooo00CoZJVYogMgMooooooo
oooo1_l00006ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`06ogMgMonHV9SooooooiRHV?mg
MgOooooo0_l00008ooooo`05oa0@4?oooooooooooooooolb<S800_ooool3o`0000Wooooo00?o0000
ooooooooool0^Oooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4
o`0000Kooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0
002iooooo`00[?ooool2o`000;[ooooo002/ooooo`;o00003?ooool2o`000:cooooo002/ooooo`03
o`000?oooooooooo00_ooooo0_l0002/ooooo`00W_ooool3o`0000_ooooo00?o0000ooooooooool0
^Oooool009kooooo0ol0000;ooooo`03o`000?oooooooooo0;Wooooo002Xooooo`;o00000_ooool0
0ol0003oooooooooo`2iooooo`00Z?ooool2o`0000;ooooo00?o0000ooooooooool0^Oooool00:co
oooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`02oooo
o`;o0000]Oooool00:cooooo00Co0000oooooooooooooooo0ol0002eooooo`00[?ooool01?l0003o
ooooooooooooool2o`000;Kooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`;o0000
^_ooool00:_ooooo1?l0002iooooo`00Zoooool2o`000;_ooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002Pooooo`;o00002_ooool00ol0003oooooooooo`2iooooo`00X?ooool2o`0000[ooooo
00?o0000ooooooooool0^Oooool00:3ooooo0_l000000ooooooo0000o`000007ooooo`03o`000?oo
oooooooo0;Wooooo002Sooooo`;o00001oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00U?ooool2o`0001Kooooo0ol0002iooooo`00U?ooool2o`0001Kooooo
00?o0000ooooooooool01?ooool2o`000;?ooooo002/ooooo`03o`000?oooooooooo00?ooooo0ol0
002cooooo`00[?ooool00ol0003oooooooooo`03ooooo`;o0000]?ooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:;ooooo1?l000000ol@413ooooo
ooooo`03ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0^Oooool00:Cooooo00?o0000ooooooooool01Oooool3o`000;Wooooo002Toooo
o`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`00
0?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Rooooo`03oeEEEOmVIVKo
00000<?ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Z
ooooo`04oa0@4?l0003o0000o`000;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`03o`000?oooooooooo0;[ooooo002[ooooo`06o`000?mgMgOo0000o`000?mEEEGok^k^]oooool0
0:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomEEEFgooooo`00Zoooool00ol0003ok^k^ooooo`02
ooooo`03o`000?oooooooooo0;Gooooo002[ooooo`03o`000?o^k^kooooo00;ooooo00?o0000oooo
ooooool0]Oooool00:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomVIVJgooooo`00Z_ooool00ol@
413o0000ogMgM`02o`000003ofIVI_o^k^kooooo0;Kooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.49001 .10787 Mdot
.65058 .42414 Mdot
.48882 .37875 Mdot
.5389 .61201 Mdot
.48505 .81388 Mdot
.51417 .84789 Mdot
.44621 .38375 Mdot
.48452 .00947 Mdot
.44685 .9556 Mdot
.56458 .50688 Mdot
.4834 .78263 Mdot
.56476 .09388 Mdot
.56238 .82752 Mdot
.52883 .7006 Mdot
.56916 .10586 Mdot
.41631 .4678 Mdot
.39924 .3988 Mdot
.54881 .84872 Mdot
.56392 .37411 Mdot
.61475 .2249 Mdot
.54862 .84384 Mdot
.65385 .56728 Mdot
.64311 .61853 Mdot
.52433 .88226 Mdot
.6765 .26514 Mdot
.5812 .36021 Mdot
.42177 .65902 Mdot
.54721 .32604 Mdot
.64167 .27826 Mdot
.65034 .43394 Mdot
.50749 .89739 Mdot
.44034 .94918 Mdot
.40191 .14152 Mdot
.514 .18114 Mdot
.61633 .41169 Mdot
.49097 .06852 Mdot
.68337 .62522 Mdot
.4765 .20565 Mdot
.65729 .32437 Mdot
.60065 .13556 Mdot
.68744 .27982 Mdot
.58249 .30485 Mdot
.61324 .62367 Mdot
.5436 .17306 Mdot
.43513 .14401 Mdot
.41579 .30975 Mdot
.54801 .63256 Mdot
.54087 .91261 Mdot
.573 .68487 Mdot
.62327 .24827 Mdot
.55169 .89743 Mdot
.69042 .43684 Mdot
.57663 .04694 Mdot
.62473 .51347 Mdot
.62501 .55996 Mdot
.37204 .62901 Mdot
.4959 .01733 Mdot
.39903 .39611 Mdot
.62624 .78199 Mdot
.41101 .22498 Mdot
.43483 .22795 Mdot
.72392 .66177 Mdot
.65862 .33168 Mdot
.42773 .61121 Mdot
.38395 .24771 Mdot
.39374 .81043 Mdot
.5625 .46957 Mdot
.4263 .64124 Mdot
.49285 .21344 Mdot
.48657 .92487 Mdot
.43993 .17366 Mdot
.51061 .60911 Mdot
.56342 .51459 Mdot
.54008 .35229 Mdot
.65831 .33095 Mdot
.46089 .63224 Mdot
.5772 .04758 Mdot
.49369 .18591 Mdot
.68241 .39496 Mdot
.59524 .57078 Mdot
.38204 .60518 Mdot
.64584 .41342 Mdot
.54901 .52401 Mdot
.59397 .33278 Mdot
.40066 .14286 Mdot
.42624 .34203 Mdot
.46824 .8166 Mdot
.42643 .73053 Mdot
.39719 .57077 Mdot
.42274 .61278 Mdot
.67924 .27246 Mdot
.37791 .80136 Mdot
.46986 .25533 Mdot
.40351 .54196 Mdot
.43701 .32684 Mdot
.41051 .94298 Mdot
.53634 .67969 Mdot
.55154 .89411 Mdot
.60134 .07331 Mdot
.39497 .48787 Mdot
.53114 .16004 Mdot
.42704 .78153 Mdot
.55325 .08287 Mdot
.57278 .22023 Mdot
.40289 .78479 Mdot
.53821 .21977 Mdot
.46872 .13937 Mdot
.58018 .46109 Mdot
.4734 .25403 Mdot
.48342 .92533 Mdot
.55559 .60836 Mdot
.54229 .59941 Mdot
.45184 .96267 Mdot
.53839 .11744 Mdot
.78117 .37558 Mdot
.5056 .66248 Mdot
.46674 .17584 Mdot
.36864 .58716 Mdot
.38826 .78362 Mdot
.68685 .59026 Mdot
.56637 .81989 Mdot
.74141 .58257 Mdot
.60018 .74582 Mdot
.65069 .29601 Mdot
.48023 .92712 Mdot
.52151 .67418 Mdot
.56497 .15362 Mdot
.60175 .28508 Mdot
.42772 .53101 Mdot
.64339 .62602 Mdot
.57186 .22432 Mdot
.60652 .14773 Mdot
.4905 .88103 Mdot
.58997 .7019 Mdot
.6746 .36069 Mdot
.69082 .60487 Mdot
.61165 .22404 Mdot
.56314 .49759 Mdot
.43964 .04135 Mdot
.58485 .12388 Mdot
.67198 .78154 Mdot
.54511 .42671 Mdot
.5315 .28432 Mdot
.40003 .38604 Mdot
.58233 .17479 Mdot
.37602 .29888 Mdot
.80308 .50933 Mdot
.57698 .46306 Mdot
.40907 .62109 Mdot
.74792 .54692 Mdot
.44439 .82618 Mdot
.42897 .28821 Mdot
.51408 .89688 Mdot
.51883 .55737 Mdot
.42874 .82505 Mdot
.69592 .54287 Mdot
.67253 .36887 Mdot
.37079 .62148 Mdot
.68332 .62076 Mdot
.69542 .55753 Mdot
.60362 .50268 Mdot
.68501 .40126 Mdot
.69362 .28258 Mdot
.42035 .14224 Mdot
.61584 .59985 Mdot
.50583 .12807 Mdot
.37068 .36747 Mdot
.38227 .62355 Mdot
.47586 .20372 Mdot
.69756 .55487 Mdot
.57833 .17736 Mdot
.48126 .25981 Mdot
.43118 .28328 Mdot
.47557 .8152 Mdot
.57982 .5261 Mdot
.40136 .14698 Mdot
.43286 .99259 Mdot
.44121 .85331 Mdot
.51956 .60135 Mdot
.64575 .29101 Mdot
.69911 .50179 Mdot
.63534 .18506 Mdot
.49739 .24775 Mdot
.69685 .30009 Mdot
.48828 .28803 Mdot
.4704 .96972 Mdot
.44145 .95339 Mdot
.68305 .26235 Mdot
.60068 .67308 Mdot
.74531 .52065 Mdot
.58346 .17595 Mdot
.47917 .73335 Mdot
.73262 .61847 Mdot
.4354 .04357 Mdot
.72796 .38084 Mdot
.57814 .11169 Mdot
.41254 .65715 Mdot
.35932 .36488 Mdot
.54243 .21824 Mdot
.52454 .4417 Mdot
.52709 .46616 Mdot
.49862 .65586 Mdot
.50762 .77967 Mdot
.37734 .18946 Mdot
.54456 .18161 Mdot
.53806 .52466 Mdot
.48 .88454 Mdot
.54321 .60051 Mdot
.53293 .4225 Mdot
.46391 .78311 Mdot
.61743 .72134 Mdot
.48176 .17646 Mdot
.38155 .61185 Mdot
.45588 .24701 Mdot
.51672 .14279 Mdot
.44973 .19773 Mdot
.69584 .28863 Mdot
.50314 .3147 Mdot
.38955 .41461 Mdot
.57565 .1033 Mdot
.45727 .18355 Mdot
.62026 .78852 Mdot
.39076 .71225 Mdot
.38019 .43107 Mdot
.42101 .39803 Mdot
.54873 .69062 Mdot
.64596 .39424 Mdot
.47684 .25699 Mdot
.5742 .11174 Mdot
.73837 .61112 Mdot
.43428 .68838 Mdot
.50542 .59558 Mdot
.37796 .1893 Mdot
.52623 .7844 Mdot
.41989 .65001 Mdot
.74367 .549 Mdot
.45346 .22253 Mdot
.59326 .25708 Mdot
.59926 .75254 Mdot
.56001 .20406 Mdot
.72397 .65879 Mdot
.55903 .77414 Mdot
.38761 .30506 Mdot
.43811 .17786 Mdot
.42562 .92357 Mdot
.42404 .42646 Mdot
.69391 .50819 Mdot
.44166 .81312 Mdot
.43207 .1934 Mdot
.66362 .34311 Mdot
.7212 .36084 Mdot
.51025 .6464 Mdot
.48617 .72633 Mdot
.69252 .54165 Mdot
.57998 .36186 Mdot
.42202 .33092 Mdot
.61665 .62412 Mdot
.4498 .59596 Mdot
.46709 .01235 Mdot
.58338 .85429 Mdot
.55086 .73787 Mdot
.42048 .65434 Mdot
.38886 .30626 Mdot
.45489 .69147 Mdot
.46304 .84711 Mdot
.44198 .13425 Mdot
.539 .66238 Mdot
.56408 .75694 Mdot
.53083 .11391 Mdot
.59551 .43705 Mdot
.52711 .10624 Mdot
.62105 .59481 Mdot
.56535 .51022 Mdot
.5812 .65 Mdot
.69684 .53763 Mdot
.51463 .28181 Mdot
.57281 .61035 Mdot
.53168 .92241 Mdot
.47184 .78809 Mdot
.44192 .85655 Mdot
.66211 .32929 Mdot
.43167 .39651 Mdot
.5053 .26715 Mdot
.68356 .61654 Mdot
.53117 .05744 Mdot
.58181 .47878 Mdot
.51421 .42094 Mdot
.56071 .64383 Mdot
.49598 .06644 Mdot
.40322 .48841 Mdot
.39787 .75126 Mdot
.63976 .75195 Mdot
.53327 .0634 Mdot
.63971 .74814 Mdot
.44389 .60057 Mdot
.64977 .73589 Mdot
.73803 .57023 Mdot
.44743 .07555 Mdot
.55493 .08882 Mdot
.80077 .57545 Mdot
.59011 .61755 Mdot
.58913 .71256 Mdot
.5851 .24668 Mdot
.43013 .9324 Mdot
.67321 .25513 Mdot
.53493 .67841 Mdot
.54079 .90985 Mdot
.58889 .39459 Mdot
.48869 .31235 Mdot
.62328 .70343 Mdot
.4103 .29388 Mdot
.58262 .7903 Mdot
.74823 .51764 Mdot
.49238 .69575 Mdot
.40023 .29463 Mdot
.55302 .24521 Mdot
.40383 .14035 Mdot
.44258 .65765 Mdot
.64045 .19383 Mdot
.73634 .45146 Mdot
.63279 .85223 Mdot
.47243 .7574 Mdot
.47846 .88876 Mdot
.60049 .3497 Mdot
.67454 .38138 Mdot
.53933 .71761 Mdot
.52079 .41102 Mdot
.43648 .49749 Mdot
.44287 .16991 Mdot
.54276 .06516 Mdot
.69192 .52251 Mdot
.43531 .33369 Mdot
.63972 .65285 Mdot
.42765 .45893 Mdot
.49666 .66127 Mdot
.64814 .4047 Mdot
.52817 .82713 Mdot
.61522 .60382 Mdot
.60338 .50117 Mdot
.52345 .748 Mdot
.53447 .00311 Mdot
.58442 .38162 Mdot
.63218 .36392 Mdot
.42873 .61652 Mdot
.37269 .35066 Mdot
.43497 .72173 Mdot
.59852 .20309 Mdot
.65226 .46692 Mdot
.52329 .33721 Mdot
.40852 .38419 Mdot
.67421 .77814 Mdot
.56091 .08825 Mdot
.65047 .7372 Mdot
.51346 .09172 Mdot
.59673 .5861 Mdot
.52313 .18922 Mdot
.56989 .16418 Mdot
.49564 .83632 Mdot
.55813 .0854 Mdot
.61498 .88103 Mdot
.39423 .25341 Mdot
.59968 .13922 Mdot
.64758 .20526 Mdot
.70158 .30569 Mdot
.45928 .67735 Mdot
.54991 .7371 Mdot
.5862 .12628 Mdot
.47872 .00999 Mdot
.44835 .65023 Mdot
.42779 .86988 Mdot
.57876 .3667 Mdot
.46755 .88568 Mdot
.5179 .14172 Mdot
.52899 .92267 Mdot
.58953 .25042 Mdot
.67029 .67663 Mdot
.68813 .45688 Mdot
.64687 .59713 Mdot
.66431 .70464 Mdot
.64723 .60391 Mdot
.65338 .22269 Mdot
.79502 .42961 Mdot
.67875 .63114 Mdot
.40787 .74599 Mdot
.52073 .49802 Mdot
.72583 .39233 Mdot
.39966 .61409 Mdot
.43757 .53757 Mdot
.64749 .2023 Mdot
.47924 .92781 Mdot
.5191 .40084 Mdot
.55066 .39198 Mdot
.54637 .2732 Mdot
.41189 .5635 Mdot
.51985 .93893 Mdot
.37971 .59257 Mdot
.7345 .60285 Mdot
.64261 .19605 Mdot
.46607 .14433 Mdot
.50026 .15727 Mdot
.58042 .51415 Mdot
.5751 .58915 Mdot
.50357 .40204 Mdot
.52469 .04662 Mdot
.55797 .08618 Mdot
.42532 .6803 Mdot
.5119 .30914 Mdot
.40995 .54447 Mdot
.45502 .24453 Mdot
.74288 .45458 Mdot
.40565 .59074 Mdot
.42125 .13792 Mdot
.54784 .45438 Mdot
.4332 .27178 Mdot
.43656 .62689 Mdot
.4284 .74336 Mdot
.49058 .15006 Mdot
.41003 .46383 Mdot
.53541 .56128 Mdot
.7449 .56442 Mdot
.43594 .04717 Mdot
.45512 .58688 Mdot
.62177 .44277 Mdot
.4686 .13953 Mdot
.39928 .68414 Mdot
.58844 .40596 Mdot
.44801 .23158 Mdot
.7306 .40678 Mdot
.37288 .7732 Mdot
.60318 .27957 Mdot
.74701 .28648 Mdot
.56638 .20732 Mdot
.52228 .63601 Mdot
.42568 .91676 Mdot
.59626 .13982 Mdot
.47318 .78427 Mdot
.651 .46283 Mdot
.54586 .01468 Mdot
.52119 .33486 Mdot
.49431 .31863 Mdot
.57656 .56491 Mdot
.38745 .31749 Mdot
.59931 .52733 Mdot
.35703 .56788 Mdot
.51473 .35011 Mdot
.61964 .44389 Mdot
.58117 .29919 Mdot
.42342 .42583 Mdot
.50081 .67372 Mdot
.53424 .33145 Mdot
.48506 .01001 Mdot
.46405 .70804 Mdot
.67716 .37252 Mdot
.63886 .37277 Mdot
.42135 .18545 Mdot
.54659 .12967 Mdot
.4265 .86515 Mdot
.43697 .18592 Mdot
.5558 .41603 Mdot
.55088 .07405 Mdot
.72218 .36159 Mdot
.53906 .66075 Mdot
.64934 .73826 Mdot
.59214 .42145 Mdot
.39926 .58715 Mdot
.5956 .19799 Mdot
.53583 .16597 Mdot
.57038 .40271 Mdot
.41049 .36231 Mdot
.51507 .18164 Mdot
.72414 .67001 Mdot
.59607 .68085 Mdot
.46632 .64245 Mdot
.61979 .58077 Mdot
.59315 .59036 Mdot
.46322 .68437 Mdot
.46021 .74816 Mdot
.62498 .50262 Mdot
.59391 .69421 Mdot
.52699 .55523 Mdot
.56276 .31378 Mdot
.39054 .793 Mdot
.49256 .80788 Mdot
.41703 .20485 Mdot
.52034 .25863 Mdot
.53977 .31037 Mdot
.4315 .49385 Mdot
.77701 .35817 Mdot
.43296 .44987 Mdot
.64943 .41431 Mdot
.61995 .7856 Mdot
.43179 .11085 Mdot
.50968 .24139 Mdot
.6267 .25145 Mdot
.61226 .15279 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`08ooooo`;o0000[oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`08ooooo`;o0000[oooool00:Cooooo1Ol00003ooooo`03o`000?oooooooooo0;Wooooo002Q
ooooo`;o000000?oooooo`000?l000000ol00003ooooo`03o`000?oooooooooo0;Wooooo002Qoooo
o`;o000000?oIVIVo`000?ooool01_ooool00ol0003oooooooooo`0<ooooo`;o0000Zoooool00:[o
oooo0ol0000>ooooo`;o0000Zoooool00:[ooooo0ol0002kooooo`00[?ooool3o`000;Wooooo002/
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002Fooooo`Co00004_ooool00ol0003oooooooooo`2iooooo`00U_ooool4o`00
01;ooooo00?o0000ooooooooool01Oooool2o`0000oooooo0_l0002Qooooo`00U_ooool2o`0001Co
oooo00?o0000ooooooooool01Oooool2o`0000oooooo0_l0002Qooooo`00U_ooool2o`0001Cooooo
0ol0000Fooooo`;o0000XOooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool01oooool2o`000;3ooooo002/ooooo`03o`000?oooooooooo00Oooooo0_l0002`oooo
o`00[?ooool00ol0003oooooooooo`08ooooo`;o000000?oooooo`000?l00000[?ooool00:[ooooo
0ol0000:ooooo`;o000000?oooooo`000?l00000[?ooool00:Wooooo1?l0002kooooo`00ZOooool2
o`000003ooooool0003ooooo00kooooo0_l0000?ooooo`;o0000VOooool009[ooooo0_l0000@oooo
o`?o00003Oooool2o`0000oooooo0_l0002Iooooo`00V_ooool2o`00013ooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool03_ooool2o`000:Wooooo002/ooooo`03o`000?oo
oooooooo00kooooo1?l0002Wooooo`00[?ooool00ol0003oooooooooo`0?ooooo`Co0000Y_ooool0
0:cooooo00Co0000oooooooooooooooo0_l0000<ooooo`Co0000Y_ooool00:cooooo00Co0000oooo
oooooooooooo0_l0000?ooooo`;o0000YOooool00:cooooo00?o0000ooooooooool04_ooool2o`00
0:Gooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool05_ooool2o`000:7ooooo
002/ooooo`03o`000?oooooooooo00Kooooo0_l0000;ooooo`;o000000?oooooo`000?l00000XOoo
ool00:Sooooo0_l00002ooooo`03o`000?oooooooooo00Kooooo0_l0000;ooooo`;o0000Y?ooool0
09Gooooo0_l0000Aooooo`;o00000_ooool00ol0003oooooooooo`0Eooooo`?o0000XOooool009Go
oooo0_l0000Eooooo`03o`000?oooooooooo00Oooooo0_l0000<ooooo`?o0000XOooool008Wooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`07ooooo`Co0000[_ooool008Wo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool02Oooool2o`000:kooooo0021ooooo`Ko
00000_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0
003oooooooooo`03ooooo`?o00006Oooool2o`0009kooooo0029ooooo`05o`000?oooooooooooooo
ool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Ioooo
o`;o0000W_ooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`?o00003?ooool2o`0000_ooooo0_l0002N
ooooo`00ROooool01Ol@413ooooooooooooooooo410@00[ooooo0_l00002ooooo`03ojVYZOmgMgOo
oooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<ooooo`;o0000Zoooool0
08Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`;o00001?ooool2o`0000?ooooo00?o<S8b
ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01kooooo0_l0002I
ooooo`00ROooool00oo^k^ko<S8bo`000002o`0000Cooooo0_l00005ooooo`Go00000oooool5o`00
00Kooooo00?o0000ooooooooool07?ooool4o`0009Wooooo002;ooooo`?o00000oooool2o`0000?o
oooo0_l00009ooooo`;o00002Oooool00ol0003oooooooooo`02ooooo`;o00006?ooool3o`0009[o
oooo002;ooooo`;o00001?ooool2o`0000?ooooo0_l00008ooooo`;o00002_ooool00ol0003ooooo
ooooo`02ooooo`;o0000]Oooool008_ooooo0_l0000Cooooo`;o00001_ooool2o`0000;ooooo00?o
0000ooooooooool08?ooool2o`0009Oooooo002Xooooo`;o00000_ooool3o`00023ooooo1?l0002E
ooooo`00[?ooool00ol0003oooooooooo`0Booooo`;o00003_ooool2o`0009Gooooo002/ooooo`;o
00004oooool2o`000:Gooooo002/ooooo`;o00002?ooool2o`000;3ooooo002/ooooo`03o`000?oo
oooooooo00Oooooo0_l0000;ooooo`;o0000Xoooool00:cooooo00?o0000ooooooooool02?ooool2
o`0000[ooooo0_l0002Sooooo`00VOooool2o`00017ooooo00?o0000ooooooooool02?ooool2o`00
0:oooooo002Hooooo`?o00004Oooool00ol0003oooooooooo`0;ooooo`;o0000[?ooool009Sooooo
0_l00007ooooo`;o00000oooool2o`0000Cooooo0ol0000;ooooo`;o00002Oooool4o`0009oooooo
002Gooooo`;o00002?ooool2o`0000?ooooo0_l00004ooooo`03o`000?oooooooooo01Kooooo1?l0
002Oooooo`00Uoooool2o`0001?ooooo00Co0000oooooooooooooooo0ol00007ooooo`;o0000[?oo
ool009;ooooo0_l00003ooooo`;o00001?ooool2o`0000[ooooo0_l000000ooooooo0000ooooo`02
ooooo`?o00001oooool2o`0001cooooo0_l0002>ooooo`00Poooool2o`0000gooooo0_l00003oooo
o`;o00001?ooool2o`0000[ooooo0_l000000ooooooo0000ooooo`05ooooo`;o00008oooool2o`00
08kooooo0023ooooo`;o00009oooool00ol0003oooooooooo`04ooooo`;o0000/oooool009Gooooo
0_l0000Eooooo`03o`000?oooooooooo02_ooooo0_l0002<ooooo`00UOooool2o`0000Cooooo0_l0
000?ooooo`03o`000?oooooooooo01cooooo0_l0000=ooooo`?o0000Roooool009_ooooo0_l0000?
ooooo`?o00007?ooool2o`0000kooooo0_l0002;ooooo`00Y?ooool2o`0000Kooooo00?o0000oooo
ooooool04?ooool2o`0000_ooooo0_l0000>ooooo`;o0000R_ooool0093ooooo0_l0000Booooo`;o
00001_ooool00ol0003oooooooooo`0@ooooo`Co00002Oooool2o`0000kooooo0_l0002:ooooo`00
T?ooool2o`0001;ooooo0_l00006ooooo`03o`000?oooooooooo01;ooooo0_l0000Iooooo`;o0000
R_ooool00:Wooooo0_l000000ooooooo0000ooooo`2jooooo`00ZOooool2o`000003ooooool0003o
oooo0;[ooooo002/ooooo`03o`000?oooooooooo00Wooooo1?l0002/ooooo`00W?ooool2o`0000ko
oooo00?o0000ooooooooool02Oooool4o`0000Sooooo0_l0000Hooooo`;o0000R?ooool008kooooo
0_l0000<ooooo`;o00003_ooool3o`0001Cooooo0ol0000:ooooo`?o00002oooool2o`0008Sooooo
002>ooooo`;o00001_ooool2o`0001Cooooo00?o0000ooooooooool05?ooool2o`0000_ooooo0ol0
002Eooooo`00U_ooool2o`0000;ooooo0_l0000@ooooo`03o`000?oooooooooo0;Wooooo002Joooo
o`;o00004?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
[?ooool00ol0003oooooooooo`2iooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`02o`000;Oo
oooo002Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@;o00001_ooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo00;o00003?ooool2o`0000Wooooo0_l0002Nooooo`00
QOooool2o`0000;ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41001oooool2o`0000Oo
oooo00?o0000ooooooooool00_ooool2o`00013ooooo0_l00009ooooo`;o00002_ooool2o`0009;o
oooo0025ooooo`;o00002_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_oo
ool00oooool4o`0001[ooooo0_l00009ooooo`?o0000TOooool008Wooooo0_l00006ooooo`05o`00
0?ooooooooooooooool000003?ooool3o`000003oc8b<_o<c<cooooo00Cooooo00?o0000oooooooo
ool06_ooool2o`0000[ooooo0_l0000>ooooo`;o0000POooool008Wooooo0_l00006ooooo`05oa0@
4?ooooooooooooooool@41003?ooool4o`0000Kooooo00?o0000ooooooooool00oooool2o`0001Ko
oooo0_l0000Iooooo`;o0000POooool0097ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
o`000?oooooo000000;o00001Oooool00ol0003oooooooooo`03ooooo`;o00005_ooool2o`0009co
oooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool5o`0000Gooooo00?o0000oooooooo
ool0=oooool4o`0007kooooo002/ooooo`?o0000=oooool4o`0007kooooo002/ooooo`?o0000^Ooo
ool009Kooooo0_l0000Dooooo`03o`000?oooooooooo00cooooo0_l0000Zooooo`;o0000Ooooool0
09Kooooo0_l0000Dooooo`?o00003?ooool2o`0002[ooooo0_l0001oooooo`00[?ooool00ol0003o
ooooooooo`0Oooooo`;o00002_ooool2o`0000gooooo0_l0001mooooo`00UOooool2o`0001Gooooo
00Co0000oooooooooooooooo0_l0000Looooo`;o00002_ooool2o`0000gooooo1?l0001kooooo`00
UOooool2o`0001Gooooo00Co0000oooooooooooooooo0_l00004ooooo`;o00005Oooool2o`0001co
oooo0_l0001kooooo`00U?ooool2o`0001;ooooo0_l00002ooooo`03o`000?oooooooooo00Oooooo
0_l0000Eooooo`;o00007Oooool2o`0000oooooo0_l0001Yooooo`00U?ooool2o`0001;ooooo0_l0
0002ooooo`03o`000?oooooooooo02gooooo0_l0000>ooooo`;o00003oooool2o`0006Wooooo002;
ooooo`;o000000?oooooo`000?l000007?ooool00ol0003oooooooooo`0]ooooo`;o0000R_ooool0
08_ooooo0_l000000ooooooo0000o`00000Looooo`03o`000?oooooooooo02kooooo0_l00029oooo
o`00Poooool2o`0002Oooooo0ol0000Gooooo`;o00005Oooool2o`0000kooooo0_l0001iooooo`00
Poooool2o`0002Oooooo00?o0000ooooooooool05oooool2o`0002Gooooo0_l0001iooooo`00Q_oo
ool3o`0002?ooooo00?o0000ooooooooool06?ooool2o`0002Gooooo0_l0001hooooo`00Q_ooool3
o`0000Oooooo0_l0000Jooooo`03o`000?oooooooooo00;o00002?ooool2o`0000cooooo0_l0000U
ooooo`;o0000N?ooool0093ooooo0_l0000Fooooo`;o00000_ooool00ol0003oooooooooo`02o`00
00Sooooo0_l0002]ooooo`00Z?ooool2o`0000;ooooo0ol0000Aooooo`;o0000Y_ooool008Kooooo
0_l0000Rooooo`Go00004Oooool2o`000:Kooooo0026ooooo`;o00008_ooool3o`000;_ooooo002/
ooooo`?o0000<?ooool2o`0008Oooooo002Gooooo`;o00004oooool00ol0003oooooooooo`0<oooo
o`;o00008_ooool2o`0008Oooooo002Booooo`;o00000oooool2o`0001?ooooo00?o0000oooooooo
ool02?ooool2o`0000;ooooo0_l0000Sooooo`?o0000QOooool009;ooooo0_l00002ooooo`;o0000
5?ooool00ol0003oooooooooo`04ooooo`;o00000_ooool2o`0001;ooooo0_l0000Cooooo`?o0000
QOooool009Kooooo0_l0000Dooooo`03o`000?oooooooooo00Cooooo0_l0000Fooooo`;o0000Vooo
ool00:cooooo00?o0000ooooooooool01?ooool2o`000;?ooooo002Cooooo`;o00005oooool00ol0
003oooooooooo`0cooooo`;o0000Q?ooool009?ooooo0_l0000Gooooo`03o`000?oooooooooo03?o
oooo0_l00024ooooo`00[?ooool00ol0003oooooooooo`0Nooooo`;o0000VOooool008;ooooo0_l0
000Xooooo`?o000000?oooooo`000?l000001oooool2o`0001;ooooo0_l0002Iooooo`00P_ooool2
o`0002Sooooo00Co0000oooooooooooooooo0_l00007ooooo`;o0000[Oooool00:cooooo00?o0000
ooooooooool0F?ooool2o`0005oooooo002/ooooo`03o`000?oooooooooo01Oooooo0_l0000Moooo
o`;o00003_ooool2o`00013ooooo0_l0001Oooooo`00OOooool2o`0000oooooo0_l0000Looooo`03
o`000?oooooooooo01Oooooo0_l0000?ooooo`;o00003?ooool2o`0000kooooo0_l0001aooooo`00
OOooool2o`0000;ooooo0_l00006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_l00003ooooo`;o
8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
01Oooooo0_l0000?ooooo`;o0000Soooool0087ooooo0_l00006ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool05oooool2o`0001gooooo0_l00021ooooo`00POooool6o`00
00;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Booooo`;o00005_ooool2o`0000[ooooo0ol00020
ooooo`00ROooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool0
0omgMgOo<S8booooo`04ooooo`?o00004_ooool2o`0001Kooooo0_l0000;ooooo`;o00008?ooool2
o`0005kooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03
ooooo`06o`000?lQ8B7o0000oc8b<_o<c<cooooo0_l00002ooooo`03o`000?oooooooooo05Wooooo
0_l0001Nooooo`00ROooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`;o00000_ooool00ol0003oooooooooo`0Hooooo`;o0000
7?ooool2o`00013ooooo0_l0001_ooooo`00ROooool00omgMgOoV9RHo`000003o`0000[ooooo0ol0
00000onHV9So410@ooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06?oo
ool2o`0001cooooo0_l0000@ooooo`;o0000Koooool008Wooooo00?ok^k^oc8b<_l000000ol0000:
ooooo`05oiRHV?l0003o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool0^Ooo
ool00:cooooo00?o0000ooooooooool03Oooool2o`0003Sooooo0_l0001`ooooo`00[?ooool00ol0
003oooooooooo`0=ooooo`;o00002oooool2o`00017ooooo0_l0000:ooooo`;o00003?ooool2o`00
073ooooo002:ooooo`;o00001Oooool2o`0000;ooooo0_l0000Eooooo`03o`000?oooooooooo01[o
oooo0_l0000Aooooo`;o00002_ooool2o`0007kooooo002:ooooo`;o00001Oooool2o`0000;ooooo
0_l0000Eooooo`?o00000oooool2o`0003Gooooo0_l0001mooooo`00R_ooool2o`00023ooooo0ol0
0003ooooo`;o00003oooool2o`0002Cooooo0_l0001mooooo`00[?ooool3o`0001Cooooo0_l00004
ooooo`;o00004Oooool2o`0001[ooooo0_l0001^ooooo`00[?ooool00ol0003oooooooooo`0Joooo
o`;o00004Oooool2o`0001[ooooo0_l0001^ooooo`00[?ooool00ol0003oooooooooo`03ooooo`;o
00007_ooool2o`0000Sooooo0_l0002:ooooo`00Qoooool2o`0002?ooooo00?o0000ooooooooool0
0oooool2o`0000[ooooo0_l0000Booooo`;o00002?ooool3o`0008Wooooo0027ooooo`;o00008ooo
ool00ol0003oooooooooo`0?ooooo`;o00007Oooool2o`0008Wooooo002/ooooo`04o`000?oooooo
ooooooooo`;o00001?ooool2o`0001;ooooo0_l0002Looooo`00[?ooool3o`000003ooooool0003o
000000Cooooo0_l0000Booooo`;o00004Oooool2o`0008Wooooo002Booooo`;o00006?ooool00ol0
003oooooooooo`0;ooooo`;o00008Oooool2o`0008Wooooo0024ooooo`;o00003?ooool2o`0001So
oooo00?o0000ooooooooool02oooool2o`00057ooooo0_l0001Iooooo`00Q?ooool2o`0002Kooooo
00?o0000ooooooooool0;_ooool2o`0002kooooo0_l0001Iooooo`00[?ooool00ol0003ooooooooo
o`0Looooo`;o00004?ooool2o`0000_ooooo0_l0001looooo`00[?ooool00ol0003oooooooooo`0L
ooooo`;o00007Oooool2o`0007cooooo002/ooooo`03o`000?oooooooooo00Gooooo0_l0000Moooo
o`?o0000T_ooool00:cooooo00?o0000ooooooooool01Oooool2o`0001gooooo0ol0002Booooo`00
UOooool2o`0001Gooooo00?o0000ooooooooool0^Oooool009Gooooo0_l0000Eooooo`?o0000Booo
ool2o`0006cooooo002/ooooo`03o`000?oooooooooo00cooooo0_l0000mooooo`Co0000J_ooool0
09Cooooo0_l0000Fooooo`03o`000?oooooooooo00cooooo0_l0000]ooooo`;o00004?ooool2o`00
06[ooooo0009ooooo`Co000000?o410@ooooooooool05_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0?
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8b
omgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`03
odA4A?l0003o000000;o00005_ooool00ol0003oooooooooo`0Gooooo`;o000000Co<S8bo`000?lb
<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool2
o`0000Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`00
0?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003o
k^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd06?ooool4o`000003oa0@4?oooooooooo
01;ooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00KoV9RHob4Q8Oo^k^koooooodA4A?ooool2o`0000Co
oooo00?oMgMgoc8b<_ooool05Oooool00ol0003oooooooooo`0Fooooo`?o000000CoV9RHoooooonH
V9SoMgMg1Oooool2ob4Q8@Cooooo00KoV9RHob4Q8Oo^k^koooooodA4A?ooool2o`0000Cooooo00?o
MgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGo
ZJVYooooo`07ooooo`03ogMgMolb<S;ooooo01Wooooo00?o0000ooooooooool05?ooool000Ko0000
1Oooool00ol0003oooooooooo`0@ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00go
oooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`05ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool01Oooool6o`0000;ooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00;ooooo1?l00003ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool01_ooool2o`0000kooooo0_l000001Ol@413ooooooooooooo
oooo410@00cooooo00?oV9RHob4Q8Oo^k^h00_ooool3o`0000Cooooo00?o0000ooooooooool03Ooo
ool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool03Oooool01Ol@413ooooo
oooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003o
oooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo
000000gooooo00?oV9RHob4Q8Oo^k^h00oooool2o`0000;ooooo00?oMgMgoc8b<_ooool05Oooool0
0ol0003oooooooooo`06ooooo`;o00002Oooool2o`0000Gooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^00;ooooo0_l00003ooooo`03ogMgMolb<S;ooooo00kooooo00Go
0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool06Oooool00ol0003o
ooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool0
00003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0
003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?oo
ooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`05_ooool00ol0003oooooooooo`0Aooooo`;o00001Oooool01Ol0003ooooooooooooooooo0000
00kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000
ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooo
oooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
01[ooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol@413o
oooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`0Aoooo
o`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0Aooooo`05oa0@4?oooooo
ooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Sooooo0ol0
000Hooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo017o
oooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000
ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool06?ooool2o`000003oooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo01Cooooo0009ooooo`03oeEEEOmVIVKo000001[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`Go00001?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co
00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004
ooooo`Co00005oooool00ol0003oooooooooo`0Hooooo`?o000000?o<S8bonk^k_ooool02_ooool0
1OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0001Wo
oooo00?oEEEEofIVI_l000005_ooool00:cooooo00?o0000ooooooooool0^Oooool008Wooooo0_l0
00000ooooooo0000o`00000Nooooo`03o`000?oooooooooo0;Wooooo0029ooooo`;o000000?ooooo
o`000?l000007_ooool00ol0003oooooooooo`2^ooooo`;o00000_ooool2o`0000Gooooo002Eoooo
o`;o00005Oooool00ol0003oooooooooo`2^ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1Ooo
ool009Gooooo1?l0000Cooooo`03o`000?oooooooooo00?ooooo0_l0000<ooooo`;o0000W?ooool0
1?oMgMgo0000oa0@4?o<c<`6ooooo`001oooooooo`0004co00003?ooool01?o^k^ko8B4Qoa0@4?o^
k^h6ooooo`001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool3o`0000Gooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?ooool2o`0000Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00[ooooo00Co8B4QogMgMomgMgOo<S8b1_ooool000Oooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0Booooo`;o00002oooool2o`0000Gooooo0_l0000F
ooooo`;o00004?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool02Oooool2o`0000;ooooo0_l00005ooooo`00[?ooool00ol0003oooooooooo`0Boooo
o`;o0000:Oooool2o`0002;ooooo0_l0001Fooooo`00[?ooool00ol0003oooooooooo`0Booooo`;o
00004_ooool2o`0001Gooooo0_l0000Rooooo`;o0000E_ooool00:cooooo00?o0000ooooooooool0
4Oooool2o`0000Cooooo0_l0000=ooooo`;o0000TOooool00:cooooo00?o0000ooooooooool04Ooo
ool2o`0000Cooooo0_l0000fooooo`;o0000J?ooool00:cooooo00?o0000ooooooooool0??ooool2
o`00013ooooo0ol0001Xooooo`00[?ooool3o`0000Wooooo0_l00002ooooo`;o0000;Oooool2o`00
013ooooo0_l0001Yooooo`00[?ooool00ol0003oooooooooo`09ooooo`;o00000_ooool2o`0000So
oooo0_l00004ooooo`;o0000V_ooool009Cooooo0_l0000Fooooo`03o`000?oooooooooo01Oooooo
0_l00004ooooo`;o0000V_ooool009Cooooo0_l0000Fooooo`03o`000?oooooooooo0;Wooooo002G
ooooo`;o00004oooool00ol0003oooooooooo`0nooooo`;o0000NOooool009Oooooo0_l0000Coooo
o`03o`000?oooooooooo03kooooo0_l0001iooooo`00S?ooool2o`0001kooooo00?o0000oooooooo
ool0??ooool3o`0007[ooooo002<ooooo`Co00007?ooool00ol0003oooooooooo`0looooo`?o0000
3oooool2o`0006Wooooo002>ooooo`;o00007?ooool00ol0003oooooooooo`1=ooooo`?o0000JOoo
ool00:cooooo0ol0001=ooooo`;o0000J_ooool00:cooooo00?o0000ooooooooool01Oooool2o`00
03Oooooo0_l0001iooooo`00[?ooool00ol0003oooooooooo`03ooooo`Co0000=_ooool3o`0007Wo
oooo002/ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`;o00007?ooool2o`0001Gooooo
0_l0001jooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool02?ooool2o`0000cooooo0_l0
000>ooooo`;o00009Oooool2o`0006[ooooo001looooo`;o00004?ooool2o`0001cooooo00?o0000
ooooooooool05_ooool2o`0001Oooooo0_l0000Looooo`;o0000J_ooool007cooooo0_l0000<oooo
o`;o00008?ooool00ol0003oooooooooo`0Looooo`;o00004Oooool2o`0001[ooooo0_l0001/oooo
o`00R_ooool2o`00023ooooo00?o0000ooooooooool07?ooool2o`0002gooooo0_l0001/ooooo`00
[?ooool3o`00063ooooo0_l0001Gooooo`00[?ooool00ol0003oooooooooo`1Pooooo`;o0000Eooo
ool00:cooooo00?o0000ooooooooool09?ooool2o`0002Kooooo0_l0001[ooooo`00[?ooool00ol0
003oooooooooo`0Looooo`;o00001_ooool2o`0002Kooooo0_l0001[ooooo`00P?ooool2o`0000So
oooo0_l0000Aooooo`;o00003Oooool00ol0003oooooooooo`0Eooooo`;o00001Oooool2o`0009_o
oooo0020ooooo`;o00002?ooool4o`0000oooooo0_l0000=ooooo`03o`000?oooooooooo01Gooooo
0_l00004ooooo`;o00007Oooool2o`0007gooooo0024ooooo`;o00001_ooool2o`0001kooooo00?o
0000ooooooooool06oooool2o`0000Sooooo0_l0000Cooooo`;o0000OOooool008Cooooo0_l0000E
ooooo`;o00003oooool3o`0002Gooooo0_l00006ooooo`;o0000R_ooool009Wooooo1?l0000?oooo
o`?o00000oooool2o`0000Kooooo0_l0000Fooooo`;o00002?ooool2o`0008[ooooo002Iooooo`;o
00004Oooool00ol0003oooooooooo`03ooooo`;o00001_ooool2o`0001Kooooo0_l00008ooooo`;o
00006oooool2o`0006gooooo0025ooooo`;o00009Oooool00ol0003oooooooooo`0Sooooo`;o0000
2?ooool2o`0000gooooo0_l0000<ooooo`;o0000KOooool008Gooooo0_l0000Uooooo`03o`000?oo
oooooooo00;o00003Oooool2o`0000Cooooo0_l0000Uooooo`;o0000Noooool008Cooooo0_l0000<
ooooo`Co00005_ooool00ol0003oooooooooo`02o`0000Oooooo0_l00004ooooo`;o00001?ooool2
o`0003Cooooo0_l0001/ooooo`00Q?ooool2o`0000Cooooo0_l00006ooooo`Co00005_ooool00ol0
003oooooooooo`09ooooo`;o0000;_ooool2o`00013ooooo0_l0001/ooooo`00ROooool01Oo^k^ko
0000o`000?lb<S;ok^k^00Gooooo00?o8B4Qo`000?l000000oooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01[ooooo0_l0000@ooooo`;o00002oooool2
o`0000kooooo0_l0001^ooooo`00POooool2o`0000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02
o`0000?ooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo01[ooooo0_l0000@ooooo`;o00002oooool2o`0000kooooo0_l0
001^ooooo`00POooool2o`0000;ooooo0_l00002ooooo`05oa0@4?ooooooooooooooool@41000_l0
000:ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`0002;ooooo0ol0
000Dooooo`;o0000O_ooool008Gooooo0_l00002ooooo`05o`000?ooooooooooooooool000002Ooo
ool2o`0000;ooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo02;ooooo0ol00007ooooo`;o00002oooool2o`0007kooooo0021ooooo`;o00001_ooool0
1Ol0003ooooooooooooooooo000000Wooooo0_l00003ooooo`03ogMgMomVIVKooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo02cooooo0_l0000:ooooo`;o0000
Ooooool0087ooooo0_l00006ooooo`05oa0@4?ooooooooooooooool@41003oooool01_l0003ooooo
o`000?l0003oooooo`0000Wooooo00?o0000ooooooooool03?ooool2o`0002[ooooo0_l0001ooooo
o`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Ko0000okZj^_ooooooV9RHoa0@4?oo
ool2o`000003ooooool0003ooooo00Sooooo00?o0000ooooooooool01?ooool2o`0000Kooooo0_l0
002[ooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c004ooooo`Co00001_ooool00ol0003oooooooooo`04ooooo`;o0000/oooool009?ooooo0_l0
000;ooooo`;o00002_ooool00ol0003oooooooooo`0Aooooo`;o0000Y_ooool009?ooooo0_l0000;
ooooo`;o00002_ooool00ol0003oooooooooo`02o`0000oooooo0_l0002Vooooo`00[?ooool00ol0
003oooooooooo`02o`000;Oooooo002Aooooo`;o00002?ooool2o`0000oooooo0ol0000Gooooo`;o
00004_ooool2o`0008cooooo002Aooooo`;o00002?ooool2o`0000kooooo0_l0000Iooooo`;o0000
4_ooool2o`0008cooooo002?ooooo`Go00001Oooool2o`00013ooooo0_l00018ooooo`;o0000LOoo
ool008oooooo0_l000000ooooooo0000o`000005ooooo`;o00003oooool3o`0000_ooooo0_l0000k
ooooo`;o0000LOooool00:[ooooo1Ol00009ooooo`;o0000>oooool2o`00077ooooo002/ooooo`?o
00002Oooool2o`000:kooooo002/ooooo`03o`000?oooooooooo04Oooooo0_l0001`ooooo`00[?oo
ool2o`0000Gooooo0_l0000Hooooo`;o00009oooool2o`00073ooooo002/ooooo`?o00001?ooool2
o`0001Sooooo0_l0000Eooooo`;o0000P_ooool009kooooo0_l0000<ooooo`03o`000?oooooooooo
00Sooooo0ol0000Zooooo`;o0000P_ooool009?ooooo0_l00009ooooo`;o00003?ooool00ol0003o
ooooooooo`08ooooo`?o00004Oooool2o`0009_ooooo002:ooooo`;o00001oooool2o`0000[ooooo
0_l0000;ooooo`03o`000?oooooooooo01Gooooo0_l00005ooooo`;o0000Voooool008[ooooo0_l0
000:ooooo`;o00001oooool2o`0000_ooooo00?o0000ooooooooool05Oooool2o`000:;ooooo002F
ooooo`;o00001Oooool2o`0000gooooo00?o0000ooooooooool03Oooool2o`000:[ooooo002Moooo
o`;o00003Oooool00ol0003oooooooooo`0=ooooo`;o00003Oooool2o`0009_ooooo002Yooooo`;o
000000?oooooo`000?ooool07Oooool2o`0009_ooooo002Yooooo`;o000000Coooooo`000?l0003o
00001_ooool2o`000;7ooooo002/ooooo`03o`000?oooooooooo00Kooooo0_l0000Booooo`;o0000
2Oooool2o`0009;ooooo002/ooooo`03o`000?oooooooooo01[ooooo0_l00009ooooo`;o00003?oo
ool2o`0008Cooooo002Pooooo`;o00002_ooool00ol0003oooooooooo`0cooooo`;o0000Q?ooool0
08Sooooo0_l0000Fooooo`;o00002_ooool00ol0003oooooooooo`0Jooooo`;o0000WOooool008So
oooo0_l0000Rooooo`03o`000?oooooooooo01[ooooo0_l0002Mooooo`00[?ooool00ol0003ooooo
ooooo`0:ooooo`;o0000[Oooool009Kooooo0_l0000Dooooo`03o`000?oooooooooo00[ooooo0_l0
000Gooooo`;o0000U?ooool009Kooooo0_l0000Dooooo`?o00008oooool2o`0009Cooooo002Woooo
o`;o00000oooool00ol0003oooooooooo`2iooooo`00Toooool2o`0001;ooooo0_l00003ooooo`03
o`000?oooooooooo0;Wooooo002Cooooo`;o00004?ooool2o`0000Gooooo00?o0000ooooooooool0
^Oooool00:Gooooo0_l00005ooooo`03o`000?oooooooooo00gooooo0_l0000Oooooo`;o0000ROoo
ool00:cooooo00?o0000ooooooooool03Oooool2o`0001oooooo0_l00029ooooo`00TOooool00oo^
k^ko<S8bo`000002o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`0=ooooo`;o00007oooool2o`0008Wooooo002=ooooo`;o00000_ooool00omg
MgOoV9RHooooo`02o`0000Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool07_ooool2o`0009Wooooo002=ooooo`;o00000_ooool01Ol@413ooooooooooooooooo410@
00Sooooo0_l00006ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool2o`00
01Sooooo0_l0000;ooooo`;o0000S?ooool008[ooooo0_l00005ooooo`05o`000?oooooooooooooo
ool000002?ooool2o`0000Gooooo00?oMgMgoc8b<_ooool01?ooool3o`0000Cooooo0_l0000Goooo
o`;o00003?ooool2o`0008cooooo002:ooooo`;o00001Oooool01Ol0003ooooooooooooooooo0000
00cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo01gooooo0_l0000<
ooooo`;o0000S?ooool0097ooooo00Go410@oooooooooooooooooa0@400<ooooo`;o00002?ooool0
0ol0003oooooooooo`0Booooo`;o0000YOooool0097ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<
ooooo`;o00002?ooool00ol0003oooooooooo`0Booooo`;o0000YOooool0097ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00P_ooool2o`0002Sooooo
00?o0000ooooooooool04?ooool2o`000:Oooooo0022ooooo`;o0000:?ooool3o`00013ooooo0_l0
002Wooooo`00[?ooool01?l0003oooooo`000?l0000eooooo`;o0000POooool009?ooooo0_l0000;
ooooo`;o00001?ooool2o`0000Cooooo00Co0000ooooool0003o00009Oooool2o`0000gooooo0ol0
0021ooooo`00Qoooool2o`0000?ooooo0_l00005ooooo`;o00002oooool2o`000004ooooool0003o
0000ooooo`;o00001?ooool00ol0003oooooooooo`05ooooo`;o00007Oooool4o`0000gooooo0_l0
0022ooooo`00Qoooool2o`0000?ooooo0_l0000Dooooo`?o00001oooool00ol0003oooooooooo`05
ooooo`;o00007Oooool2o`0009?ooooo002Rooooo`;o00002?ooool00ol0003oooooooooo`0Hoooo
o`;o00002_ooool2o`0009?ooooo0027ooooo`;o00008oooool00ol0003oooooooooo`0Hooooo`;o
0000Woooool008Oooooo0_l0000Sooooo`03o`000?oooooooooo0;Wooooo0023ooooo`;o00009ooo
ool3o`000;Wooooo0023ooooo`;o00009oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00R?ooool2o`0001oooooo0_l000000ooooooo0000ooooo`2jooooo`00
R?ooool2o`0000kooooo0_l0000?ooooo`;o000000?oooooo`000?ooool0^_ooool009Sooooo0_l0
0009ooooo`;o00000_ooool2o`0000?ooooo00?o0000ooooooooool0^Oooool00:7ooooo1?l00002
ooooo`;o00000oooool00ol0003oooooooooo`2iooooo`00XOooool2o`0000Wooooo00?o0000oooo
ooooool04_ooool2o`000:Gooooo002Dooooo`;o00005_ooool3o`0001;ooooo0_l0002Uooooo`00
U?ooool2o`0000?ooooo0_l0000Aooooo`03o`000?oooooooooo00Kooooo0_l00009ooooo`;o0000
Y_ooool009Wooooo0_l0000Aooooo`03o`000?oooooooooo00Kooooo0_l00009ooooo`;o0000Y_oo
ool00:cooooo00?o0000ooooooooool0^Oooool00:[ooooo0ol0002kooooo`00Z_ooool3o`000;_o
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00gooooo0_l0
002Zooooo`00Woooool2o`0000_ooooo00Co0000oooooooooooooooo0_l0000:ooooo`;o0000Z_oo
ool009oooooo0_l0000;ooooo`?o000000?oooooo`000?l000002_ooool2o`0001Wooooo0_l0002?
ooooo`00V?ooool2o`0001;ooooo00?o0000ooooooooool06?ooool2o`0000kooooo0_l0002?oooo
o`00V?ooool2o`0001;ooooo00?o0000ooooooooool06?ooool2o`0009oooooo002Hooooo`;o0000
4_ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00ROooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_l00006ooooo`03o`000?o^k^kooooo00Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool3o`0000Gooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05oa0@4?ooooooooooooooool@4100
1_ooool2o`0000Gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo0;Wooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooo
ooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002iooooo`00ROooool01Ol0003ooooooooo
oooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool0^Oooool008Wooooo00Go410@oooooooooooooooooa0@400>ooooo`03
ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool00oooool2o`0000;ooooo00?o0000oooooooo
ool01Oooool2o`0001cooooo0_l0002Dooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go410@oooooooooooooooooc8b<P03ooooo`;o00000_ooool2o`000003ooooool0003o0000
00;ooooo00?o0000ooooooooool01Oooool2o`0001cooooo0_l0002Dooooo`00ROooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo1Ol00003ooooo`Ko00001Oooool00ol0003oooooooooo`2ioooo
o`00Y?ooool2o`0000Kooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
3_ooool2o`000:Wooooo002/ooooo`03o`000?oooooo000000?o00002oooool2o`000:Wooooo002/
ooooo`Ko00002oooool2o`000:Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00[ooooo0_l0002]ooooo`00[?oo
ool00ol0003oooooooooo`0:ooooo`;o0000[Oooool00:cooooo00?o0000ooooooooool02_ooool2
o`000:gooooo002Cooooo`;o00005oooool00ol0003oooooooooo`2iooooo`00Toooool2o`0001Oo
oooo00?o0000ooooooooool01oooool2o`000;3ooooo002Cooooo`;o00004Oooool3o`0000?ooooo
0ol00006ooooo`?o0000/?ooool009?ooooo0_l0000@ooooo`Co00000oooool00ol0003ooooooooo
o`06ooooo`;o0000/Oooool00:Gooooo0_l00005ooooo`03o`000?oooooooooo0;Wooooo002Doooo
o`;o00005_ooool00ol0003oooooooooo`2iooooo`00U?ooool2o`0001Kooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool00oooool2o`000;Cooooo002>ooooo`;o00007?oo
ool00ol0003oooooooooo`03ooooo`;o0000]?ooool008kooooo0_l0000Looooo`03o`000?oooooo
oooo0;Wooooo002Hooooo`;o00004_ooool00ol0003oooooooooo`2iooooo`00V?ooool2o`0001;o
oooo0ol0002iooooo`00V?ooool4o`00013ooooo00?o0000ooooooooool0^Oooool009Sooooo1?l0
000@ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Loooo
o`;o00003_ooool00ol0003oooooooooo`2iooooo`00W?ooool2o`0000kooooo00?o0000oooooooo
ool0^Oooool00:;ooooo0_l00008ooooo`03o`000?oooooooooo0;Wooooo002Rooooo`;o00002?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Eoooo
o`;o00002oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0^Oooool009Go
oooo0_l0000=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo
00?o0000ooooooooool01Oooool3o`000;Wooooo002Tooooo`03o`000?oooooooooo0<7ooooo002T
ooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03
o`000?oooooooooo0<7ooooo002Rooooo`03oeEEEOmVIVKo00000<?ooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo002Zooooo`04oa0@4?l0003o0000o`000;[o
oooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[
ooooo`06o`000?mgMgOo0000o`000?mEEEGok^k^]oooool00:_ooooo00Ko0000oeEEEOo^k^kooooo
ogMgMomEEEFgooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo0;Gooooo
002[ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0]Oooool00:_ooooo00Ko0000
oeEEEOo^k^koooooogMgMomVIVJgooooo`00Z_ooool00ol@413o0000ogMgM`02o`000003ofIVI_o^
k^kooooo0;Kooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.38615 .51929 Mdot
.58023 .22414 Mdot
.44554 .46591 Mdot
.5437 .41201 Mdot
.57338 .6211 Mdot
.61333 .64789 Mdot
.45585 .65085 Mdot
.36585 .56457 Mdot
.611 .8161 Mdot
.52733 .30688 Mdot
.56023 .59256 Mdot
.38843 .19621 Mdot
.65339 .62752 Mdot
.56907 .5006 Mdot
.39362 .17667 Mdot
.48067 .76322 Mdot
.4693 .85267 Mdot
.6483 .64872 Mdot
.4742 .19626 Mdot
.46539 .05158 Mdot
.64616 .64384 Mdot
.64076 .36728 Mdot
.65053 .41853 Mdot
.63723 .68226 Mdot
.54256 .06514 Mdot
.48538 .1667 Mdot
.52185 .71818 Mdot
.44443 .23301 Mdot
.51297 .07826 Mdot
.58391 .23394 Mdot
.62645 .69739 Mdot
.60731 .82555 Mdot
.41255 .8967 Mdot
.39828 .39779 Mdot
.541 .21169 Mdot
.37735 .52364 Mdot
.69346 .42522 Mdot
.41042 .55715 Mdot
.54704 .12437 Mdot
.42189 .06461 Mdot
.55937 .07982 Mdot
.46548 .1377 Mdot
.62271 .42367 Mdot
.40091 .26936 Mdot
.40591 .7511 Mdot
.44628 .79967 Mdot
.56103 .43256 Mdot
.66591 .71261 Mdot
.60695 .48487 Mdot
.48266 .05507 Mdot
.67067 .69743 Mdot
.62516 .23684 Mdot
.38113 .15628 Mdot
.59012 .31347 Mdot
.609 .35996 Mdot
.52572 .93641 Mdot
.3651 .51315 Mdot
.46876 .85417 Mdot
.69904 .58199 Mdot
.4288 .8389 Mdot
.4243 .73427 Mdot
.74862 .46177 Mdot
.55129 .13168 Mdot
.50958 .68702 Mdot
.43962 .95212 Mdot
.56565 .88765 Mdot
.51033 .26957 Mdot
.51672 .69534 Mdot
.40858 .48406 Mdot
.61818 .72914 Mdot
.41134 .72371 Mdot
.51426 .40911 Mdot
.52926 .31459 Mdot
.44779 .2559 Mdot
.55069 .13095 Mdot
.50724 .54151 Mdot
.38156 .15392 Mdot
.40239 .48636 Mdot
.6004 .19496 Mdot
.58356 .37078 Mdot
.5182 .89139 Mdot
.57121 .21342 Mdot
.51861 .32401 Mdot
.48714 .13739 Mdot
.41312 .90186 Mdot
.45106 .74708 Mdot
.56658 .64854 Mdot
.53891 .72118 Mdot
.50729 .82603 Mdot
.51102 .70932 Mdot
.54823 .07246 Mdot
.56597 .94819 Mdot
.4227 .57536 Mdot
.49963 .80308 Mdot
.44542 .70331 Mdot
.6029 .90497 Mdot
.56821 .47969 Mdot
.66918 .69411 Mdot
.40268 .06261 Mdot
.48967 .85207 Mdot
.39471 .326 Mdot
.55297 .74453 Mdot
.38138 .24611 Mdot
.42891 .15206 Mdot
.55728 .83957 Mdot
.41089 .2831 Mdot
.39763 .60544 Mdot
.52461 .26109 Mdot
.42165 .56018 Mdot
.61607 .73185 Mdot
.55893 .40836 Mdot
.54205 .39941 Mdot
.61495 .81199 Mdot
.38597 .30322 Mdot
.6914 .17558 Mdot
.53059 .46248 Mdot
.40602 .60618 Mdot
.51712 .95192 Mdot
.5595 .89865 Mdot
.68295 .39026 Mdot
.65432 .61989 Mdot
.73444 .38257 Mdot
.65851 .54582 Mdot
.5291 .09601 Mdot
.61463 .73634 Mdot
.55118 .47418 Mdot
.40469 .186 Mdot
.65486 .83027 Mdot
.47608 .09948 Mdot
.492 .69973 Mdot
.6538 .42602 Mdot
.42955 .15497 Mdot
.43048 .04893 Mdot
.60385 .68341 Mdot
.63073 .5019 Mdot
.57888 .16069 Mdot
.69277 .40487 Mdot
.46217 .05614 Mdot
.52218 .29759 Mdot
.38252 .75361 Mdot
.40739 .1161 Mdot
.74459 .58154 Mdot
.47652 .24913 Mdot
.42495 .29894 Mdot
.46634 .85198 Mdot
.42128 .12202 Mdot
.45251 .97568 Mdot
.76681 .30933 Mdot
.5222 .26306 Mdot
.51586 .77061 Mdot
.72669 .34692 Mdot
.56598 .71598 Mdot
.43872 .74681 Mdot
.63283 .69688 Mdot
.50177 .35737 Mdot
.56573 .76502 Mdot
.67307 .34287 Mdot
.58008 .16887 Mdot
.5243 .94178 Mdot
.69162 .42076 Mdot
.67843 .35753 Mdot
.56469 .30268 Mdot
.60552 .20126 Mdot
.56666 .08258 Mdot
.40872 .81603 Mdot
.61578 .39985 Mdot
.38733 .44569 Mdot
.46864 .98417 Mdot
.52226 .89047 Mdot
.41013 .56035 Mdot
.6795 .35487 Mdot
.41938 .13522 Mdot
.42121 .52465 Mdot
.43717 .73821 Mdot
.56881 .63435 Mdot
.55025 .3261 Mdot
.41386 .8979 Mdot
.62114 .88017 Mdot
.57473 .74583 Mdot
.5201 .40135 Mdot
.52215 .09101 Mdot
.65982 .30179 Mdot
.46974 .00354 Mdot
.41509 .4568 Mdot
.57688 .10009 Mdot
.42585 .48789 Mdot
.62537 .78842 Mdot
.66162 .8173 Mdot
.60901 .82645 Mdot
.54799 .06235 Mdot
.62991 .47308 Mdot
.71357 .32065 Mdot
.42241 .11835 Mdot
.53955 .55243 Mdot
.74001 .41847 Mdot
.38392 .77166 Mdot
.64029 .18084 Mdot
.39987 .14146 Mdot
.52338 .75852 Mdot
.41198 .2657 Mdot
.46493 .30401 Mdot
.47493 .29816 Mdot
.52102 .45599 Mdot
.57948 .57967 Mdot
.42833 .99358 Mdot
.40338 .26367 Mdot
.50793 .32466 Mdot
.59783 .69503 Mdot
.54341 .40051 Mdot
.46485 .27779 Mdot
.55351 .62885 Mdot
.66597 .52134 Mdot
.40291 .54048 Mdot
.51979 .89354 Mdot
.42391 .63821 Mdot
.38968 .39399 Mdot
.41448 .67572 Mdot
.57129 .08863 Mdot
.42857 .41712 Mdot
.47484 .89157 Mdot
.39615 .15188 Mdot
.40975 .64589 Mdot
.69567 .58852 Mdot
.5411 .86519 Mdot
.48046 .92887 Mdot
.46442 .7578 Mdot
.58498 .49062 Mdot
.56366 .19424 Mdot
.42155 .54454 Mdot
.39776 .1563 Mdot
.74281 .41112 Mdot
.52651 .67216 Mdot
.50365 .39558 Mdot
.42816 .99091 Mdot
.59999 .5844 Mdot
.52014 .72496 Mdot
.72327 .349 Mdot
.41909 .6541 Mdot
.45765 .10157 Mdot
.66028 .55254 Mdot
.41624 .19826 Mdot
.74748 .45879 Mdot
.62868 .57414 Mdot
.45135 .92374 Mdot
.41266 .73077 Mdot
.59696 .84457 Mdot
.46997 .7384 Mdot
.65719 .30819 Mdot
.56169 .71468 Mdot
.41735 .75376 Mdot
.56086 .14311 Mdot
.62554 .16084 Mdot
.52881 .4464 Mdot
.53999 .53502 Mdot
.66918 .34165 Mdot
.48483 .1689 Mdot
.44955 .76789 Mdot
.62629 .42412 Mdot
.5014 .5895 Mdot
.37025 .64003 Mdot
.6851 .65429 Mdot
.60601 .53787 Mdot
.52103 .72304 Mdot
.45134 .91802 Mdot
.52398 .59095 Mdot
.57616 .68626 Mdot
.4023 .72329 Mdot
.56395 .46238 Mdot
.62685 .55694 Mdot
.38392 .33731 Mdot
.53033 .23705 Mdot
.38179 .35551 Mdot
.61897 .39481 Mdot
.52944 .31022 Mdot
.60121 .45 Mdot
.67189 .33763 Mdot
.42086 .373 Mdot
.57695 .41035 Mdot
.66065 .72241 Mdot
.55727 .61587 Mdot
.57585 .74629 Mdot
.55382 .12929 Mdot
.46178 .71158 Mdot
.41787 .41787 Mdot
.69018 .41654 Mdot
.37097 .348 Mdot
.53333 .27878 Mdot
.45367 .34555 Mdot
.57824 .44383 Mdot
.37581 .5022 Mdot
.488 .81593 Mdot
.5494 .8467 Mdot
.66322 .81361 Mdot
.70054 .55195 Mdot
.37254 .33737 Mdot
.69897 .54814 Mdot
.5037 .61523 Mdot
.70413 .53589 Mdot
.72612 .37023 Mdot
.3883 .7122 Mdot
.38341 .23782 Mdot
.79096 .37545 Mdot
.59713 .41755 Mdot
.63416 .51256 Mdot
.44694 .11786 Mdot
.60019 .83845 Mdot
.53526 .05513 Mdot
.5663 .47841 Mdot
.66473 .70985 Mdot
.50672 .19459 Mdot
.43107 .48083 Mdot
.66465 .50343 Mdot
.444 .82709 Mdot
.65874 .5903 Mdot
.71529 .31764 Mdot
.53186 .4988 Mdot
.44634 .87088 Mdot
.42413 .21949 Mdot
.41188 .88855 Mdot
.51719 .62724 Mdot
.47813 .00352 Mdot
.67693 .25146 Mdot
.73368 .65223 Mdot
.54626 .58731 Mdot
.59856 .7008 Mdot
.50037 .1497 Mdot
.5871 .18138 Mdot
.58638 .51761 Mdot
.4538 .32053 Mdot
.48278 .66872 Mdot
.40989 .7117 Mdot
.37441 .29506 Mdot
.66093 .32251 Mdot
.44728 .70926 Mdot
.66086 .45285 Mdot
.47628 .71561 Mdot
.52145 .46198 Mdot
.57002 .2047 Mdot
.61902 .62713 Mdot
.61674 .40382 Mdot
.56385 .30117 Mdot
.58265 .548 Mdot
.35884 .34509 Mdot
.49707 .18189 Mdot
.53774 .16392 Mdot
.51055 .68262 Mdot
.46453 .97903 Mdot
.53517 .68312 Mdot
.44297 .07733 Mdot
.59903 .26692 Mdot
.43557 .32338 Mdot
.4641 .81534 Mdot
.74547 .57814 Mdot
.38541 .21294 Mdot
.70536 .5372 Mdot
.37851 .41965 Mdot
.59118 .3861 Mdot
.40042 .35523 Mdot
.41031 .16612 Mdot
.59039 .63689 Mdot
.38364 .22505 Mdot
.72739 .68103 Mdot
.43864 .90602 Mdot
.42236 .06766 Mdot
.4897 .00743 Mdot
.58386 .10569 Mdot
.51944 .56679 Mdot
.60474 .5371 Mdot
.40896 .11124 Mdot
.36722 .58978 Mdot
.5142 .60038 Mdot
.5797 .79863 Mdot
.48553 .17319 Mdot
.59199 .71301 Mdot
.38943 .38895 Mdot
.65806 .72267 Mdot
.45199 .10792 Mdot
.70095 .47663 Mdot
.63088 .25688 Mdot
.64572 .39713 Mdot
.70617 .50464 Mdot
.6488 .40391 Mdot
.50245 .02269 Mdot
.72687 .22961 Mdot
.69121 .43114 Mdot
.5462 .8032 Mdot
.48075 .31951 Mdot
.64277 .19233 Mdot
.51635 .81257 Mdot
.4913 .65529 Mdot
.48843 .00502 Mdot
.61426 .73795 Mdot
.45033 .32894 Mdot
.46884 .22784 Mdot
.42848 .2411 Mdot
.50252 .76207 Mdot
.65542 .73893 Mdot
.5159 .9022 Mdot
.73564 .40285 Mdot
.48112 .00326 Mdot
.39929 .61596 Mdot
.3549 .54154 Mdot
.39471 .46384 Mdot
.54608 .31415 Mdot
.57076 .38915 Mdot
.4477 .39623 Mdot
.36819 .37933 Mdot
.38379 .22553 Mdot
.52625 .70766 Mdot
.42691 .37926 Mdot
.49878 .77441 Mdot
.42355 .64249 Mdot
.68471 .25458 Mdot
.50985 .78648 Mdot
.40758 .81301 Mdot
.48966 .25891 Mdot
.43422 .7319 Mdot
.5112 .64819 Mdot
.54207 .7193 Mdot
.39523 .50768 Mdot
.48116 .79148 Mdot
.51992 .36128 Mdot
.73067 .36442 Mdot
.38459 .76852 Mdot
.49827 .56801 Mdot
.55888 .24277 Mdot
.39769 .60592 Mdot
.53257 .82173 Mdot
.51082 .20596 Mdot
.42224 .67593 Mdot
.65331 .20678 Mdot
.55974 .95929 Mdot
.47532 .0947 Mdot
.6216 .08648 Mdot
.42084 .17461 Mdot
.53669 .43601 Mdot
.59473 .83925 Mdot
.42004 .07801 Mdot
.55631 .60986 Mdot
.59613 .26283 Mdot
.36304 .29217 Mdot
.43437 .33284 Mdot
.43123 .45491 Mdot
.56253 .36491 Mdot
.4541 .92177 Mdot
.57024 .32733 Mdot
.43661 .35782 Mdot
.5572 .24389 Mdot
.46221 .13844 Mdot
.46997 .74124 Mdot
.5303 .47372 Mdot
.43851 .27971 Mdot
.36585 .56207 Mdot
.52834 .56956 Mdot
.58617 .17252 Mdot
.54797 .17277 Mdot
.41794 .80228 Mdot
.391 .26521 Mdot
.57821 .79944 Mdot
.41466 .734 Mdot
.65225 .83794 Mdot
.48246 .22754 Mdot
.3785 .25799 Mdot
.62682 .16159 Mdot
.56336 .46075 Mdot
.70464 .53826 Mdot
.52072 .22145 Mdot
.51045 .81524 Mdot
.4388 .08395 Mdot
.39703 .3042 Mdot
.49149 .2052 Mdot
.4589 .81146 Mdot
.39837 .3929 Mdot
.75215 .47001 Mdot
.62841 .48085 Mdot
.50881 .52222 Mdot
.6121 .38077 Mdot
.58929 .39036 Mdot
.52107 .55649 Mdot
.54121 .61068 Mdot
.58603 .30262 Mdot
.63159 .49421 Mdot
.50908 .35523 Mdot
.45178 .1851 Mdot
.56155 .89305 Mdot
.57642 .60969 Mdot
.42311 .81698 Mdot
.4161 .35263 Mdot
.43546 .26133 Mdot
.48307 .69124 Mdot
.68028 .15817 Mdot
.47315 .69441 Mdot
.57515 .21431 Mdot
.69419 .5856 Mdot
.39939 .77288 Mdot
.41182 .40397 Mdot
.48732 .05509 Mdot
.43691 .03492 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:;ooooo1Ol00005ooooo`03o`000?oooooooooo0;Wo
oooo002Rooooo`Go000000?oooooo`000?l000000_ooool00ol0003oooooooooo`2iooooo`00Y?oo
ool01?l0003oooooooooooooool2o`0000;ooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`;o
0000^_ooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool0^Oooool009Oo
oooo0_l0000Cooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Eoooo
o`;o00005Oooool00ol0003oooooooooo`2iooooo`00UOooool2o`0000Wooooo0_l0000:ooooo`?o
0000^Oooool009oooooo0ol00004ooooo`?o00000oooool00ol0003oooooooooo`08ooooo`;o0000
[oooool009oooooo0_l00005ooooo`?o00000oooool00ol0003oooooooooo`08ooooo`;o0000[ooo
ool00:cooooo00?o0000ooooooooool0^Oooool008_ooooo0_l00005ooooo`;o00006?ooool00ol0
003oooooooooo`0;ooooo`?o0000Zoooool008_ooooo0_l00005ooooo`;o00006?ooool00ol0003o
ooooooooo`0;ooooo`?o0000Zoooool009;ooooo0_l0000Hooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo00cooooo0_l0002[ooooo`00VOooool2o`00017ooooo0ol0000<
ooooo`;o0000Zoooool0097ooooo0_l00006ooooo`;o00004Oooool01?l0003oooooooooooooool2
o`0000gooooo0_l0002Wooooo`00TOooool2o`0001Wooooo00Co0000oooooooooooooooo0_l0000=
ooooo`;o000000?oooooo`000?l00000Y?ooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo
01?ooooo0_l0000@ooooo`;o0000T_ooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo01Co
oooo0_l0000?ooooo`;o0000T_ooool00:cooooo00?o0000ooooooooool01?ooool2o`0000kooooo
0_l0002Sooooo`00Xoooool2o`0000Oooooo00?o0000ooooooooool01?ooool2o`000;?ooooo002S
ooooo`;o00001oooool00ol0003oooooooooo`06ooooo`;o0000/Oooool009kooooo0_l00004oooo
o`;o00001_ooool3o`0000Kooooo0_l0000>ooooo`;o0000XOooool009kooooo0_l00004ooooo`;o
00001_ooool00ol0003oooooooooo`0Fooooo`;o0000XOooool00:cooooo00?o0000ooooooooool0
6?ooool2o`0009oooooo002Looooo`;o00003_ooool00ol0003oooooooooo`0Hooooo`;o0000Wooo
ool008kooooo0_l0000<ooooo`;o00003_ooool00ol0003oooooooooo`2iooooo`00SOooool3o`00
01cooooo00?o0000ooooooooool0^Oooool008Wooooo00Cok^k^oc8b<_l0003o<S8b0_l00003oooo
o`;o000000?o8B4Qooooooooool00oooool2o`000003onk^k_oooooooooo00?ooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01?ooool2o`000003ob4Q8Ooooooooooo00?ooooo0_l000000onYZJWoooooooooo`06
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0^Oooool0087ooooo1_l00002oooo
o`05oa0@4?ooooooooooooooool@41001?ooool2o`0000Oooooo00?oZJVYoeEEEOooool02?ooool0
0ol0003oooooooooo`03ooooo`?o00003?ooool2o`000:_ooooo0029ooooo`05o`000?oooooooooo
ooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool03?ooool2o`000:_ooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool0
0omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`0=ooooo`?o0000ZOooool008Wooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmg
MgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0=ooooo`?o0000ZOoo
ool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`;o00001_ooool01Ol@413ooooooooo
oooooooo<S8b00;ooooo0ol00004ooooo`;o00000oooool00ol0003oooooooooo`2iooooo`00ROoo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo0_l00006ooooo`Go000000?oooooo`000?l00000
1Ol000000ooooooo0000o`000003ooooo`03o`000?oooooooooo0;Wooooo002;ooooo`;o00004_oo
ool2o`0000_ooooo00?o0000ooooooooool04Oooool2o`000:Kooooo002;ooooo`;o00007oooool0
0ol0003oooooooooo`0Aooooo`;o0000Y_ooool00:cooooo0_l0002jooooo`00ROooool2o`0000Wo
oooo0_l0000Fooooo`?o0000^Oooool008Cooooo0_l00003ooooo`;o00002Oooool2o`0001Kooooo
00?o0000ooooooooool0^Oooool008Cooooo0_l00004ooooo`;o00002?ooool2o`0001Kooooo00?o
0000ooooooooool0>?ooool2o`0007oooooo0024ooooo`;o00001?ooool2o`00023ooooo00?o0000
ooooooooool05oooool2o`0000gooooo0_l0000@ooooo`;o0000Ooooool00:cooooo00?o0000oooo
ooooool02Oooool2o`0000cooooo0_l0000=ooooo`;o0000TOooool008kooooo0_l0000Gooooo`;o
00000oooool00ol0003oooooooooo`09ooooo`;o0000[_ooool008kooooo0_l0000Gooooo`;o0000
0oooool00ol0003oooooooooo`0Gooooo`;o0000X?ooool00:Oooooo0_l00003ooooo`03o`000?oo
oooooooo00cooooo0_l00009ooooo`Co0000W_ooool008Sooooo0_l00007ooooo`;o00005?ooool2
o`0000?ooooo0ol0000<ooooo`;o00002oooool2o`00027ooooo0_l0001kooooo`00R?ooool2o`00
00Oooooo0_l0000Iooooo`03o`000?oooooooooo03cooooo0_l0001kooooo`00Zoooool2o`0001_o
oooo0_l0000@ooooo`;o0000S?ooool008cooooo0_l0000>ooooo`;o00003Oooool2o`0001_ooooo
0_l0000@ooooo`;o0000S?ooool008cooooo0_l0000>ooooo`;o00003_ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`0/ooooo`;o0000Roooool00:cooooo00Co0000oooo
ool0003o00004Oooool2o`0000[ooooo0_l0000<ooooo`;o0000Roooool008Oooooo0_l00007oooo
o`;o00004Oooool2o`0000Oooooo00Co0000ooooool0003o00004Oooool2o`0000[ooooo0_l0002I
ooooo`00Qoooool2o`0000Oooooo0_l0000Aooooo`;o00001oooool3o`0001oooooo0_l0002Hoooo
o`00[?ooool00ol0003oooooooooo`0Oooooo`;o0000V?ooool00:Wooooo0_l000001?oooooo0000
ooooooooool2o`0001;ooooo0_l0000Iooooo`;o0000R?ooool00:Wooooo0_l000001?oooooo0000
ooooooooool2o`0001;ooooo0_l0000Iooooo`;o0000R?ooool008Kooooo0_l0000Tooooo`03o`00
0?oooooooooo00[ooooo0_l00008ooooo`;o0000Xoooool008Kooooo0_l0000Tooooo`03o`000?oo
oooooooo00[ooooo0_l00008ooooo`?o0000X_ooool009?ooooo0_l0000Gooooo`03o`000?oooooo
oooo01Gooooo0_l0002Rooooo`00Toooool2o`0001Oooooo00?o0000ooooooooool00oooool2o`00
0;Cooooo0025ooooo`;o00009Oooool3o`0000?ooooo0_l0000Booooo`;o0000X?ooool008Gooooo
0_l0000Jooooo`;o00000oooool2o`0000Cooooo00?o0000ooooooooool05oooool2o`000:3ooooo
002Qooooo`;o00000oooool2o`0000Cooooo00?o0000ooooooooool0Aoooool2o`00073ooooo002I
ooooo`;o00004Oooool00ol0003oooooooooo`0Hooooo`;o0000;Oooool2o`00073ooooo0025oooo
o`;o00004_ooool2o`00017ooooo00?o0000ooooooooool01oooool2o`0000oooooo0_l0000<oooo
o`;o0000TOooool008Gooooo0_l0000Uooooo`03o`000?oooooooooo00Oooooo0_l0000Mooooo`;o
0000TOooool0097ooooo00?ok^k^oc8b<_l000000_l00005ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool03oooool3o`000:Oooooo0024ooooo`;o0000
2oooool00omgMgOoV9RHooooo`02o`0000Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool03oooool3o`000:Oooooo0024ooooo`;o00000oooool6o`0000;ooooo00Go
410@oooooooooooooooooa0@400>ooooo`?o00001Oooool00ol0003oooooooooo`2iooooo`00TOoo
ool01Ol0003ooooooooooooooooo000000kooooo0_l000000olb<S;oooooooooo`03ooooo`?o0000
=oooool2o`00083ooooo002Aooooo`05o`000?ooooooooooooooool000001?ooool2o`0000Kooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo03Oooooo0_l000000ooooooo
0000o`00001mooooo`00Poooool2o`0000cooooo00Go410@oooooooooooooooooa0@4004ooooo`;o
00001_ooool00ol0003oooooooooo`03ooooo`;o00000_ooool00ol0003oooooooooo`0Xooooo`;o
00004?ooool2o`0007gooooo0023ooooo`;o00003?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00;o
00002_ooool00ol0003oooooooooo`03ooooo`;o00000_ooool00ol0003oooooooooo`05ooooo`;o
00008Oooool2o`0008oooooo0028ooooo`;o00000_ooool2o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP02o`0000[ooooo1?l00006ooooo`03o`000?oooooooooo00Cooooo0ol0000Eooooo`;o
0000Voooool008Sooooo0_l00002ooooo`;o000000?oooooo`000?l000006oooool00ol0003ooooo
ooooo`04ooooo`;o00005_ooool3o`0009[ooooo002;ooooo`;o00000_ooool2o`0001_ooooo00?o
0000ooooooooool00_l0000Kooooo`;o0000V_ooool008_ooooo0_l0000Oooooo`03o`000?oooooo
oooo00;o0000]oooool00:cooooo0ol0002iooooo`00Uoooool2o`0000Oooooo0_l0000:ooooo`03
o`000?oooooooooo00Sooooo0_l0002_ooooo`00S_ooool2o`0000Oooooo0_l00007ooooo`;o0000
2_ooool00ol0003oooooooooo`08ooooo`;o0000[oooool008kooooo0_l0000Looooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo001nooooo`;o0000;?ooool00ol0
003oooooooooo`2iooooo`00O_ooool2o`0000;ooooo0_l0000Xooooo`03o`000?oooooooooo0;Wo
oooo0022ooooo`;o00007oooool2o`0000Oooooo00?o0000ooooooooool01?ooool2o`000;?ooooo
002Cooooo`;o00003_ooool2o`0000Oooooo0ol00004ooooo`;o00003?ooool2o`000:Gooooo0026
ooooo`;o00000_ooool2o`0000Oooooo0_l0000;ooooo`;o00002_ooool00ol0003oooooooooo`0B
ooooo`;o00001Oooool2o`0001Kooooo0_l00026ooooo`00Q_ooool2o`0000;ooooo0_l0000Doooo
o`;o00002_ooool00ol0003oooooooooo`06ooooo`;o00002_ooool2o`0000Gooooo0_l0000Foooo
o`;o0000Q_ooool00:cooooo00?o0000ooooooooool01_ooool2o`0002Sooooo0_l0000Sooooo`;o
0000H_ooool00:cooooo00?o0000ooooooooool01_ooool2o`0001;ooooo0_l0000Dooooo`;o0000
8oooool2o`0006;ooooo002/ooooo`03o`000?oooooooooo00Kooooo0_l00004ooooo`;o00003?oo
ool2o`0009gooooo002Uooooo`;o00001Oooool00ol0003oooooooooo`06ooooo`;o00001?ooool2
o`0003Kooooo0_l0001cooooo`00W?ooool2o`0000Oooooo0_l00005ooooo`03o`000?oooooooooo
03;ooooo0_l0000?ooooo`?o0000Loooool009Kooooo0_l00004ooooo`;o00003_ooool4o`0000;o
oooo0_l0000]ooooo`;o00003oooool2o`0007Cooooo0029ooooo`;o00002oooool2o`0001Cooooo
00Co0000ooooool0003o00000_ooool2o`0000Sooooo0_l00005ooooo`;o0000Xoooool008Wooooo
0_l0000@ooooo`;o00003oooool00ol0003oooooooooo`0=ooooo`;o00001Oooool2o`000:?ooooo
002Fooooo`;o00000oooool2o`0000oooooo00?o0000ooooooooool0^Oooool0087ooooo0_l00002
ooooo`;o00003oooool2o`0001Cooooo00?o0000ooooooooool0=Oooool2o`0008;ooooo0021oooo
o`;o00000_ooool2o`0002Gooooo00?o0000ooooooooool0=Oooool2o`0008;ooooo002/ooooo`03
o`000?oooooooooo03Cooooo1?l00021ooooo`00OOooool2o`0001gooooo0_l0000>ooooo`03o`00
0?oooooooooo03Cooooo1?l0000?ooooo`;o0000L?ooool007gooooo0_l00002ooooo`;o00006Ooo
ool2o`0000kooooo00?o0000ooooooooool0A_ooool3o`00073ooooo0021ooooo`;o00003Oooool2
o`0001[ooooo0ol00016ooooo`;o0000LOooool008Gooooo0_l00004ooooo`;o00000oooool2o`00
01[ooooo00?o0000ooooooooool00_l0000fooooo`;o0000Ooooool008Gooooo0_l00004ooooo`;o
00002_ooool2o`0001?ooooo0_l000000ooooooo0000o`00000eooooo`?o0000Ooooool009Oooooo
0_l0000Cooooo`;o00001?ooool2o`0001cooooo0_l0000Dooooo`;o0000P?ooool00:cooooo00?o
0000ooooooooool00oooool2o`0000cooooo0_l0000>ooooo`;o00009_ooool2o`0006kooooo0029
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Aooooo`;o00006?ooool2o`0001cooooo
0_l0001^ooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01So
oooo0_l0000Aooooo`;o00006_ooool2o`00073ooooo0021ooooo`Ko00000_ooool01Ol@413ooooo
oooooooooooo410@00?ooooo0_l00007ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Hooooo`;o0000;Oooool2o`00073ooooo0029ooooo`05o`00
0?ooooooooooooooool000000oooool2o`0000Sooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo
<S8booooo`04ooooo`?o0000GOooool2o`0005[ooooo0020ooooo`;o00001oooool01Ol0003ooooo
oooooooooooo000000Gooooo0_l00007ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c005ooooo`03o`000?oooooooooo05gooooo0_l0001Jooooo`00P?ooool2o`0000Oo
oooo00Go410@oooooooooooooooooa0@4005ooooo`;o00002?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08_ooool2o`0002Kooooo0_l0001]oooo
o`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06oooool2o`0000Gooooo0_l0000V
ooooo`;o0000KOooool008Oooooo0_l000001Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`0Dooooo`;o00001Ooo
ool2o`0009cooooo0027ooooo`;o00008oooool00ol0003oooooooooo`0Dooooo`;o00001?ooool2
o`0001gooooo0_l0001nooooo`00Qoooool2o`000003ooooool0003o0000023ooooo00?o0000oooo
ooooool06_ooool2o`0000Sooooo0_l0000Cooooo`;o0000O_ooool008Oooooo0_l000000ooooooo
0000o`00000>ooooo`;o00004?ooool3o`0002Cooooo0_l00007ooooo`;o0000R_ooool008[ooooo
0_l0000>ooooo`;o00004?ooool3o`0000?ooooo0_l00005ooooo`?o00005_ooool2o`0000Sooooo
0_l0002:ooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool00oooool2o`0000Gooooo0ol0
000Fooooo`;o00002Oooool2o`0001[ooooo0_l0001]ooooo`00S_ooool2o`0001cooooo00?o0000
ooooooooool08oooool2o`0000Wooooo0_l0000<ooooo`;o00003?ooool2o`0006gooooo002/oooo
o`04o`000?ooooooooooooooo`;o00003Oooool2o`0000Cooooo0_l0000Tooooo`;o0000Noooool0
0:cooooo00Co0000oooooooooooooooo0_l00008ooooo`;o00000oooool2o`0000Cooooo0_l0000e
ooooo`;o0000J_ooool00:cooooo00?o0000ooooooooool02oooool2o`0002kooooo0_l0000@oooo
o`;o0000J_ooool008?ooooo0_l0000;ooooo`;o00000_ooool2o`0001Kooooo00?o0000oooooooo
ool07Oooool2o`0000oooooo0_l0000;ooooo`;o00003oooool2o`0006_ooooo0023ooooo`;o0000
2oooool2o`0000;ooooo0_l0000Fooooo`03o`000?oooooooooo01gooooo0_l0000?ooooo`;o0000
3?ooool2o`0000kooooo0_l0001[ooooo`00[?ooool3o`0002Gooooo0ol0000Dooooo`;o0000Nooo
ool00:cooooo00?o0000ooooooooool09Oooool3o`0000Oooooo0_l0000;ooooo`;o0000Noooool0
0:cooooo00?o0000ooooooooool0;oooool2o`0000_ooooo0_l0001kooooo`00[?ooool00ol0003o
ooooooooo`0Aooooo`;o0000:Oooool2o`0007_ooooo002/ooooo`03o`000?oooooooooo00Wooooo
0_l00006ooooo`;o0000Y_ooool00:cooooo00?o0000ooooooooool02Oooool2o`000:kooooo002/
ooooo`03o`000?oooooooooo01Kooooo0_l0002Qooooo`00Q_ooool2o`0002Cooooo00?o0000oooo
ooooool01_ooool2o`0000kooooo0_l0002Qooooo`00Q_ooool2o`0002Cooooo00?o0000oooooooo
ool01_ooool2o`0001Kooooo0_l0002Iooooo`00[?ooool3o`0001kooooo0_l0000Booooo`;o0000
QOooool009Gooooo0_l0000Eooooo`03o`000?oooooooooo00Cooooo0_l0000/ooooo`;o0000QOoo
ool0093ooooo0_l00003ooooo`;o00005Oooool00ol0003oooooooooo`04ooooo`;o0000B?ooool2
o`0006Wooooo0009ooooo`Co000000?o410@ooooooooool05_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgM
g@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00003oooo
o`Co000000?o<S8bomgMgOooool05Oooool00ol0003oooooooooo`04ooooo`;o00002oooool2o`00
00Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4
o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool3o`0000Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1?l00000
0ol@413oooooooooo`0Booooo`002oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`0>
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?l0003o0000oooooom4
A4@01oooool00omgMgOo<S8booooo`0Eooooo`03o`000?oooooooooo00Cooooo0_l000000ooooooo
0000o`000008ooooo`?o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2o`0000Sooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool0
6Oooool00ol0003oooooooooo`0Dooooo`001_l00005ooooo`03o`000?oooooooooo013ooooo1_l0
0002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`00
0?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003o
ooooooooo`05ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo0_l000000oo^
k^koooooooooo`07ooooo`03o`000?oooooooooo00;ooooo0_l0000@ooooo`03o`000?oooooooooo
00Oooooo0_l00009ooooo`;o00001?ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RH
ob4Q8Oo^k^h02Oooool00ol0003oooooooooo`0=ooooo`05oa0@4?ooooooooooooooool@41004?oo
ool00ol0003oooooooooo`0=ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEE
ooooo`08ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05?ooool000_ooooo00?o
0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool0
1_ooool00omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo
<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07oooo
o`03ogMgMolb<S;ooooo00?ooooo0_l0000@ooooo`03o`000?oooooooooo01Sooooo00Go0000oooo
ooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool03_ooool0
1Ol0003ooooooooooooooooo000000Kooooo0_l00007ooooo`03ogMgMolb<S;ooooo00kooooo00Go
0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool0
6Oooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05o`000?oo
ooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`03oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?
ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`05_ooool00ol0003oooooooooo`07ooooo`;o00001?ooool2o`0000Wooooo
00Go0000ooooooooooooooooo`00000:ooooo`;o00000_ooool00omgMgOoIVIVooooo`03ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000Kooooo0_l00004
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000kooooo
00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[ooooo00?o0000oooooooo
ool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol@413ooooooooooooooooo410@00ko
oooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`0Aooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Sooooo0ol00007ooooo`;o00001?ooool2
o`0000Wooooo00Go410@oooooooooooooooooa0@400:ooooo`;o00000oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00_ooooo0_l00004ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWo
MgMgooooo`03ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05?ooool000_ooooo
00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooo
oooooooooc8b<P04ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<
ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj
^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01;ooooo
0ol00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@
00Cooooo00?o0000ooooooooool02oooool2o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<
ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oo
oooooooooooooolb<S801?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Cooooo
0009ooooo`03oeEEEOmVIVKo000001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go0000
1?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00004?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Ko00005Oooool0
0ol0003oooooooooo`0Booooo`?o00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00[ooooo0_l0
00001?l@413o0000ob4Q8Oo<c<`4ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000Ioooo
o`03oeEEEOmVIVKo000001Kooooo002;ooooo`Co00001_ooool2o`0001Gooooo00?o0000oooooooo
ool08?ooool2o`0000Gooooo0_l0002@ooooo`00Roooool4o`0000Cooooo0_l0000Gooooo`03o`00
0?oooooooooo023ooooo0_l0002Gooooo`00Toooool2o`0001Oooooo00?o0000ooooooooool06Ooo
ool2o`0009?ooooo0_l00002ooooo`;o00001Oooool00:cooooo00?o0000ooooooooool06Oooool2
o`0000gooooo0_l00024ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1Oooool00:cooooo00?o
0000ooooooooool0:?ooool2o`0008Gooooo00CogMgMo`000?l@413oc<c<1_ooool000Ooooooool0
001<o`0000cooooo00Cok^k^ob4Q8Ol@413ok^k^1_ooool000Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01_ooool3o`0000Gooooo00?o0000ooooooooool00_oo
ool2o`000003ooooool0003ooooo00Kooooo00?o0000ooooooooool01_ooool3o`0000Gooooo00Co
0000oooooooooooooooo0_l00002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
2_ooool01?lQ8B7oMgMgogMgMolb<S86ooooo`001oooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool09_ooool2o`0002Oooooo00?o0000ooooooooool0
9oooool3o`0000Wooooo0_l0000<ooooo`;o00003Oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool02Oooool2o`0000;ooooo0_l00005ooooo`00ROoo
ool2o`00027ooooo00?o0000ooooooooool0@Oooool2o`0007Kooooo001oooooo`;o00002?ooool2
o`00027ooooo00?o0000ooooooooool0:Oooool2o`0008kooooo001oooooo`;o0000:oooool00ol0
003oooooooooo`0Yooooo`;o0000S_ooool008Kooooo0_l0000Tooooo`03o`000?oooooooooo01Wo
oooo0_l0002Nooooo`00Q_ooool2o`0002Cooooo00Co0000ooooool0003o00006?ooool2o`0001So
oooo0_l00024ooooo`00Poooool2o`0000gooooo0_l0000Hooooo`Co0000<_ooool2o`0008Cooooo
0023ooooo`;o00003Oooool2o`0001Sooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool02_ooool2o`0001?ooooo0ol0000Nooooo`;o0000Moooool008cooooo0_l0000Nooooo`03o`00
0?oooooooooo00[ooooo0_l0000Cooooo`?o00007_ooool2o`0007Oooooo001looooo`;o00003_oo
ool2o`0001kooooo00Co0000ooooool0003o0000?oooool2o`0007Oooooo001looooo`;o00005?oo
ool2o`0001Sooooo00Co0000ooooool0003o0000<?ooool2o`0008Kooooo002Booooo`;o00006?oo
ool00ol0003oooooooooo`0Hooooo`;o00005oooool2o`0000_ooooo0_l0001iooooo`00[?ooool3
o`0000[ooooo0_l0000<ooooo`;o00005oooool2o`0000_ooooo0ol0001hooooo`00[?ooool00ol0
003oooooooooo`0:ooooo`;o00009Oooool2o`0000cooooo0_l0001hooooo`00S_ooool2o`0001co
oooo00?o0000ooooooooool01?ooool2o`00023ooooo0_l0002Aooooo`00Ooooool2o`0000gooooo
0_l00002ooooo`;o00006?ooool00ol0003oooooooooo`04ooooo`;o00008?ooool2o`00097ooooo
001oooooo`;o00003Oooool2o`0000;ooooo0_l0000Hooooo`03o`000?oooooooooo0;Wooooo001o
ooooo`;o0000:_ooool2o`0000Gooooo0_l0002dooooo`00Zoooool2o`0000Gooooo0_l000000ooo
oooo0000o`00002aooooo`00[?ooool00ol0003oooooooooo`06ooooo`;o00007oooool2o`00093o
oooo002Booooo`;o00006?ooool3o`0002Oooooo0_l0002@ooooo`00T_ooool2o`0001Sooooo00?o
0000ooooooooool05oooool2o`0003Gooooo0_l0001Yooooo`00[?ooool00ol0003oooooooooo`0G
ooooo`;o00009Oooool2o`0000gooooo0ol0001Yooooo`00[?ooool00ol0003oooooooooo`0Noooo
o`;o00007Oooool3o`0000gooooo0_l0001Zooooo`00[?ooool00ol0003oooooooooo`0<ooooo`;o
00004?ooool2o`0001gooooo0_l0001jooooo`00P?ooool2o`0002[ooooo0_l00005ooooo`;o0000
1_ooool2o`0002?ooooo0_l0000:ooooo`;o0000N_ooool0083ooooo0_l0000Zooooo`;o00001Ooo
ool2o`0000[ooooo0_l0000Oooooo`;o0000Q_ooool00:cooooo00?o0000ooooooooool04?ooool2
o`000:Oooooo002/ooooo`?o000000?oooooo`000?l00000]_ooool00:cooooo00Co0000oooooooo
oooooooo0_l0002fooooo`00R_ooool2o`000003ooooool0003o000001gooooo00?o0000oooooooo
ool0^Oooool008[ooooo0_l000000ooooooo0000o`00000Mooooo`03o`000?oooooooooo00oooooo
0_l00005ooooo`;o0000XOooool00:cooooo00?o0000ooooooooool02_ooool2o`0000?ooooo0_l0
0005ooooo`;o0000XOooool008[ooooo0_l0000Pooooo`?o00002_ooool2o`0000?ooooo0_l0002X
ooooo`00ROooool01Oo^k^ko0000o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo0ol0000?ooooo`;o0000Z?ooool008Wooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Eooooo`;o00006Oooool2o`0008Oooooo
0029ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`00
0?oooooooooo00?ooooo0ol0000Eooooo`;o00006Oooool2o`0008Oooooo0029ooooo`05o`000?oo
ooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool00_ooool2o`00023ooooo0_l00009ooooo`;o0000R?ooool008Wooooo00Go
0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo00;ooooo0_l0000:ooooo`;o00005?ooool2o`0000Wo
oooo0_l00028ooooo`00ROooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00kooooo0_l00003ooooo`;o
0000Y?ooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRH
V?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01?ooooo0_l00005oooo
o`;o0000WOooool0087ooooo0_l00006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool2o`00
00Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`0J
ooooo`;o0000WOooool0087ooooo0_l0000?ooooo`;o00006?ooool00ol0003oooooooooo`0]oooo
o`;o0000R_ooool008kooooo0_l00002ooooo`;o00006?ooool00ol0003oooooooooo`0]ooooo`;o
0000R_ooool008kooooo0_l0000Looooo`03o`000?oooooooooo00;o00004Oooool2o`0000gooooo
0_l0000:ooooo`;o0000ROooool009gooooo0_l0000=ooooo`Go00004Oooool2o`0000gooooo0_l0
000:ooooo`;o00006_ooool2o`0006gooooo002Aooooo`;o00002_ooool2o`0000[ooooo0_l00000
0ooooooo0000ooooo`0kooooo`;o00003_ooool2o`0006gooooo002Aooooo`;o00005_ooool2o`00
0003ooooool0003ooooo03_ooooo0_l0001mooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00Y_ooool2
o`0000Cooooo00?o0000ooooooooool0^Oooool00:Kooooo0_l00004ooooo`03o`000?oooooooooo
00Gooooo0_l0002booooo`00Soooool2o`000003ooooool0003o000001Sooooo0ol00005ooooo`;o
0000/_ooool008oooooo0_l000000ooooooo0000o`00000Hooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo00;o00001_ooool2o`00023ooooo0_l0000Looooo`;o0000Kooo
ool00:cooooo00?o0000ooooooooool00_l00006ooooo`;o00003?ooool2o`0000Oooooo0_l00009
ooooo`;o00007?ooool2o`0006oooooo002/ooooo`03o`000?oooooooooo00;o00005?ooool2o`00
00Oooooo0_l0002Hooooo`00Y_ooool2o`0000Cooooo00?o0000ooooooooool00_l0002gooooo`00
Xoooool2o`000003ooooool0003o000000Cooooo00?o0000ooooooooool00_ooool2o`0001Wooooo
0_l0000Eooooo`;o0000Poooool00:?ooooo0_l00007ooooo`03o`000?oooooooooo00;ooooo0_l0
000Iooooo`;o00001oooool4o`0000[ooooo0ol00022ooooo`00ZOooool2o`000004ooooool0003o
0000o`0001gooooo0_l00007ooooo`Co00002oooool2o`0008;ooooo002Jooooo`;o00003Oooool2
o`000003ooooool0003ooooo01kooooo0_l0002Jooooo`00V_ooool2o`00013ooooo00?o0000oooo
ooooool0^Oooool009[ooooo0_l0000@ooooo`03o`000?oooooooooo00;o00000oooool2o`0002co
oooo0_l00024ooooo`00Qoooool2o`0000Gooooo0_l0000:ooooo`;o00000oooool2o`0000_ooooo
00?o0000ooooooooool00_l00003ooooo`;o00005?ooool2o`0001Kooooo0_l00024ooooo`00Qooo
ool2o`0000Gooooo0_l0000?ooooo`;o00000oooool2o`0000Kooooo00?o0000ooooooooool04Ooo
ool3o`0000Oooooo0_l0000Fooooo`;o0000Q?ooool00:Cooooo0_l00006ooooo`03o`000?oooooo
oooo00Cooooo0_l00004ooooo`;o00001Oooool3o`000:Gooooo002/ooooo`03o`000?oooooooooo
00Cooooo0_l00003ooooo`?o00009_ooool2o`0008Gooooo002;ooooo`;o000000?oooooo`000?l0
00007?ooool3o`0000?ooooo0ol00003ooooo`;o00009_ooool3o`0008Gooooo002;ooooo`;o0000
00?oooooo`000?l000007?ooool00ol0003oooooooooo`03ooooo`?o0000:oooool2o`0008Kooooo
002?ooooo`;o00006oooool00ol0003oooooooooo`0Tooooo`;o0000Toooool008oooooo0_l00002
ooooo`;o000000?oooooo`000?l000005?ooool00ol0003oooooooooo`0Sooooo`?o0000Toooool0
08oooooo0_l00002ooooo`;o000000?oooooo`000?l000005?ooool00ol0003oooooooooo`0Roooo
o`?o0000U?ooool009Oooooo0_l00009ooooo`;o00002?ooool00ol0003oooooooooo`0Rooooo`;o
00003?ooool2o`0008Oooooo002Aooooo`06onk^k_lb<S;o0000oc8b<_o^k^kooooo0_l00002oooo
o`;o8B4Q1Oooool3o`000003oc8b<_oMgMgooooo00Cooooo00?o0000ooooooooool08_ooool2o`00
00cooooo0_l00027ooooo`00TOooool01_mgMgOoV9RHoooooonHV9SoMgMgooooo`;o00000_ooool2
ob4Q8@Gooooo0_l000000oooooooMgMgoc8b<P05ooooo`03o`000?oooooooooo00kooooo0_l00005
ooooo`?o0000XOooool0097ooooo00Ko410@oooooooooooooooooa0@4?ooool2o`0000;ooooo0_l0
0009ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool2o`0000Gooooo0ol0
002Qooooo`00SOooool2o`0000;ooooo00Go0000ooooooooooooooooo`000005ooooo`;o00002?oo
ool00omgMgOo<S8booooo`04ooooo`?o0000^Oooool008Gooooo0_l00006ooooo`;o000000?ooooo
o`000?l000000oooool00ol0003oooooooooo`0:ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`2iooooo`00QOooool2o`0000Wooooo0_l00003ooooo`03oa0@4?oooooo
oooo00Sooooo0ol00009ooooo`03o`000?oooooooooo00Cooooo0_l0002cooooo`00TOooool01Omg
MgOoV9RHoooooonHV9SoMgMg00[ooooo0ol00009ooooo`03o`000?oooooooooo00Cooooo0_l0002c
ooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1Ol00005ooooo`;o00004oooool2
o`000:Gooooo002Kooooo`;o00002?ooool2o`0000Gooooo0_l0000Cooooo`;o0000YOooool008Go
oooo0_l0000Dooooo`;o00003oooool00ol0003oooooooooo`02ooooo`;o0000]Oooool008Gooooo
0_l00003ooooo`;o00008?ooool00ol0003oooooooooo`02ooooo`;o0000]Oooool008Gooooo0_l0
0003ooooo`;o00007oooool4o`000;Wooooo002[ooooo`;o0000^oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
0_l0000Tooooo`;o0000TOooool00:Gooooo0_l00005ooooo`03o`000?oooooooooo00;o00009?oo
ool2o`00097ooooo002Uooooo`;o00001Oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00V_ooool2o`00013ooooo0ol0000Fooooo`?o0000X?ooool0093ooooo
0_l00008ooooo`;o00003oooool2o`0000kooooo0_l00008ooooo`?o0000X?ooool0093ooooo0_l0
000Iooooo`;o00003_ooool2o`000:_ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002=oooo
o`;o00003oooool2o`0000cooooo00?o0000ooooooooool00_ooool2o`0001oooooo0_l0002Doooo
o`00SOooool2o`0000oooooo1?l00006ooooo`;o00000_ooool00ol0003oooooooooo`04o`0001go
oooo1?l0000=ooooo`;o0000QOooool008gooooo0_l00003ooooo`;o00003?ooool2o`0000Kooooo
0_l00002ooooo`03o`000?oooooooooo00;o00007oooool2o`0000oooooo0_l00025ooooo`00T_oo
ool2o`0001Sooooo00?o0000ooooooooool01oooool2o`0002Wooooo0_l00025ooooo`00[?ooool3
o`0000Oooooo0_l0000Gooooo`;o0000Uoooool009Wooooo0_l0000Aooooo`04o`000?oooooo0000
o`0001oooooo0ol0002Fooooo`00VOooool2o`00017ooooo00Co0000ooooool0003o00008?ooool2
o`0000gooooo0_l00027ooooo`00[?ooool00ol0003oooooooooo`0`ooooo`;o0000Qoooool00:co
oooo00?o0000ooooooooool0^Oooool009Cooooo0_l0000Fooooo`03o`000?oooooooooo00oooooo
0_l0000;ooooo`Co00003oooool2o`0008Sooooo002Dooooo`;o00005_ooool00ol0003ooooooooo
o`0?ooooo`;o00002oooool4o`0000oooooo0_l00028ooooo`00[?ooool00ol0003oooooooooo`0=
ooooo`;o00003_ooool2o`0009[ooooo002/ooooo`03o`000?oooooooooo00gooooo0_l0000>oooo
o`;o0000V_ooool00:3ooooo0ol00005ooooo`;o00000_ooool3o`000;Wooooo002Pooooo`?o0000
1Oooool2o`0000;ooooo00?o0000ooooooooool0^Oooool00:7ooooo0_l00009ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^
k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool02_ooool2
o`000:gooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Gooooo0_l00000
0onYZJWoooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool02_ooool2
o`000:gooooo0029ooooo`05oa0@4?ooooooooooooooool@41003?ooool2o`000003oeEEEOoooooo
oooo00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2iooooo`00ROooool01Ol0
003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04
ooooo`?o0000^Oooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<co
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo02Gooooo0_l0
002Booooo`00ROooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Gooooo0_l0002Booooo`00ROooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0^Oooool008Wooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP02o`0000Wooooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`0Booooo`;o0000
YOooool008kooooo0_l0000Cooooo`;o00001oooool00ol0003oooooooooo`03ooooo`?o00003?oo
ool2o`000:Gooooo002Sooooo`;o00001oooool00ol0003oooooooooo`03ooooo`?o00002oooool2
o`000:Kooooo002?ooooo`;o00006oooool00ol0003oooooooooo`03ooooo`;o00003?ooool2o`00
0:Kooooo002?ooooo`;o00006oooool3o`00013ooooo0_l0002Wooooo`00Soooool2o`0001_ooooo
00?o0000ooooooooool00_ooool2o`0000cooooo0_l0002Wooooo`00Soooool2o`0000Kooooo0_l0
000Cooooo`03o`000?oooooooooo00;ooooo0_l0000Kooooo`;o0000V?ooool009Oooooo0_l0000C
ooooo`03o`000?oooooooooo01oooooo0_l0002Hooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00Voooool2o`0000oooooo00?o0000ooooooooool0
^Oooool009_ooooo0ol0000>ooooo`03o`000?oooooooooo0;Wooooo002Looooo`;o00003_ooool3
o`000;Wooooo002Looooo`;o00003_ooool00ol0003oooooooooo`2iooooo`00YOooool2o`0000Go
oooo00?o0000ooooooooool0^Oooool00:Gooooo0_l00005ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo00Gooooo0_l0002booooo`00[?ooool00ol0003oooooooooo`05
ooooo`;o0000/_ooool00:cooooo00?o0000ooooooooool01Oooool2o`000;;ooooo002/ooooo`03
o`000?oooooooooo00Gooooo0_l0002booooo`00[?ooool00ol0003oooooooooo`0Booooo`;o0000
YOooool009Sooooo0_l0000Booooo`?o00000_ooool2o`0000kooooo0_l0002Uooooo`00V?ooool2
o`0001;ooooo00?o0000ooooooooool00_ooool2o`000;Gooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo013ooooo0_l0002Wooooo`00[?ooool00ol0003ooooo
ooooo`0@ooooo`;o0000Yoooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool009cooooo0_l0000>ooooo`?o
0000^Oooool009cooooo0_l00002ooooo`;o00002_ooool00ol0003oooooooooo`2iooooo`00X?oo
ool2o`0000[ooooo00?o0000ooooooooool0^Oooool00:7ooooo0_l00009ooooo`03o`000?oooooo
oooo0;Wooooo002Qooooo`;o00002Oooool00ol0003oooooooooo`2iooooo`00U?ooool2o`0001Ko
oooo00?o0000ooooooooool0^Oooool009Cooooo0_l0000<ooooo`Co000000?o410@ooooooooool0
0oooool00ol0003oooooooooo`2iooooo`00U?ooool2o`0000kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`?o0000^Oooool0
0:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo
00?o0000ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:;ooooo00?oEEEE
ofIVI_l00000`oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00:[ooooo00Co410@o`000?l0003o0000^_ooool00:_ooooo00?o0000ooooooooool0^_ooool0
0:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00Ko0000ogMgMol0003o0000oeEEEOo^k^jg
ooooo`00Zoooool01_l0003oEEEEonk^k_ooooooMgMgoeEEEKOooooo002[ooooo`03o`000?o^k^ko
oooo00;ooooo00?o0000ooooooooool0]Oooool00:_ooooo00?o0000onk^k_ooool00_ooool00ol0
003oooooooooo`2eooooo`00Zoooool01_l0003oEEEEonk^k_ooooooMgMgofIVI[Oooooo002Zoooo
o`03oa0@4?l0003oMgMg00;o000000?oIVIVonk^k_ooool0]_ooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.49843 .88378 Mdot
.43552 .12898 Mdot
.47393 .636 Mdot
.46996 .24813 Mdot
.58181 .4211 Mdot
.63248 .44789 Mdot
.51288 .56866 Mdot
.51274 .96604 Mdot
.69744 .6161 Mdot
.42926 .31218 Mdot
.55725 .39256 Mdot
.42741 .94373 Mdot
.6644 .42752 Mdot
.52931 .3006 Mdot
.42202 .92529 Mdot
.55139 .57771 Mdot
.58031 .67949 Mdot
.66778 .44872 Mdot
.40886 .56921 Mdot
.37918 .63896 Mdot
.66369 .44384 Mdot
.54767 .16728 Mdot
.57794 .21853 Mdot
.67014 .48226 Mdot
.37437 .29597 Mdot
.39999 .52678 Mdot
.56913 .51818 Mdot
.42333 .69125 Mdot
.37558 .42478 Mdot
.44162 .11932 Mdot
.6654 .49739 Mdot
.69753 .62555 Mdot
.58842 .86667 Mdot
.46928 .85709 Mdot
.40979 .27288 Mdot
.50129 .92129 Mdot
.62354 .22522 Mdot
.50145 .7697 Mdot
.38982 .26433 Mdot
.39144 .82608 Mdot
.38266 .22092 Mdot
.39796 .61995 Mdot
.55218 .22367 Mdot
.44068 .8734 Mdot
.54788 .81328 Mdot
.55744 .69069 Mdot
.49407 .2339 Mdot
.71096 .51261 Mdot
.5609 .28487 Mdot
.37621 .5628 Mdot
.70964 .49743 Mdot
.48003 .04568 Mdot
.42027 .98424 Mdot
.47585 .12934 Mdot
.51298 .15996 Mdot
.66028 .73641 Mdot
.50164 .97704 Mdot
.58066 .68181 Mdot
.69184 .38199 Mdot
.56998 .77396 Mdot
.54026 .73137 Mdot
.69333 .26177 Mdot
.39303 .24492 Mdot
.54439 .48702 Mdot
.60821 .82975 Mdot
.68071 .68765 Mdot
.41804 .3949 Mdot
.55486 .49534 Mdot
.48589 .79345 Mdot
.66984 .52914 Mdot
.53984 .78062 Mdot
.45071 .34762 Mdot
.43188 .30262 Mdot
.4276 .67161 Mdot
.39264 .24759 Mdot
.4846 .35992 Mdot
.41966 .98284 Mdot
.48773 .82 Mdot
.4417 .07132 Mdot
.49189 .17282 Mdot
.63475 .69139 Mdot
.42574 .15749 Mdot
.43115 .34628 Mdot
.39321 .52544 Mdot
.58999 .86823 Mdot
.54081 .63854 Mdot
.586 .44854 Mdot
.58738 .52118 Mdot
.59771 .62603 Mdot
.55475 .50932 Mdot
.3774 .26974 Mdot
.70525 .74819 Mdot
.50277 .71242 Mdot
.58086 .60308 Mdot
.52857 .63332 Mdot
.72488 .70497 Mdot
.52009 .27969 Mdot
.70683 .49411 Mdot
.39516 .91039 Mdot
.59169 .65514 Mdot
.45438 .88822 Mdot
.61078 .54453 Mdot
.43983 .96368 Mdot
.40901 .77652 Mdot
.65311 .63957 Mdot
.44152 .82683 Mdot
.51486 .82169 Mdot
.41738 .33326 Mdot
.49968 .71993 Mdot
.66881 .53185 Mdot
.48251 .21947 Mdot
.46423 .2503 Mdot
.69975 .61199 Mdot
.4513 .93128 Mdot
.47661 .28918 Mdot
.51319 .78417 Mdot
.65788 .75192 Mdot
.67896 .69865 Mdot
.59905 .19026 Mdot
.66228 .41989 Mdot
.64747 .18257 Mdot
.63684 .34582 Mdot
.37961 .34889 Mdot
.66916 .53634 Mdot
.50086 .27418 Mdot
.42166 .8749 Mdot
.74697 .63027 Mdot
.38733 .58196 Mdot
.53316 .50302 Mdot
.58421 .22602 Mdot
.40951 .77309 Mdot
.38616 .79199 Mdot
.63721 .48341 Mdot
.59149 .3019 Mdot
.41468 .13429 Mdot
.61472 .20487 Mdot
.38088 .65204 Mdot
.42559 .33625 Mdot
.55295 .91221 Mdot
.40582 .87827 Mdot
.73721 .38154 Mdot
.4199 .54766 Mdot
.44193 .76201 Mdot
.57897 .68416 Mdot
.40411 .81634 Mdot
.61994 .82241 Mdot
.65054 .10933 Mdot
.41741 .34344 Mdot
.58411 .57061 Mdot
.62546 .14692 Mdot
.61237 .51598 Mdot
.54168 .68179 Mdot
.67158 .49688 Mdot
.43812 .41391 Mdot
.63173 .56502 Mdot
.57022 .14287 Mdot
.41794 .12971 Mdot
.66101 .74178 Mdot
.61992 .22076 Mdot
.58144 .15753 Mdot
.44958 .17875 Mdot
.44829 .06069 Mdot
.38624 .19044 Mdot
.565 .83201 Mdot
.53572 .19985 Mdot
.48211 .89452 Mdot
.63 .80452 Mdot
.63845 .69047 Mdot
.50221 .77035 Mdot
.58145 .15487 Mdot
.4074 .82175 Mdot
.49202 .72953 Mdot
.53942 .68289 Mdot
.58255 .43435 Mdot
.4465 .22297 Mdot
.58874 .8631 Mdot
.73321 .68017 Mdot
.63306 .54583 Mdot
.45088 .32479 Mdot
.37811 .38097 Mdot
.54054 .10179 Mdot
.36776 .63037 Mdot
.47853 .77094 Mdot
.3959 .14763 Mdot
.48299 .71721 Mdot
.70074 .58842 Mdot
.74854 .6173 Mdot
.69959 .62645 Mdot
.37489 .27286 Mdot
.57914 .27308 Mdot
.60183 .12065 Mdot
.40306 .81218 Mdot
.52052 .35243 Mdot
.6674 .21847 Mdot
.55723 .91226 Mdot
.41298 .90559 Mdot
.58679 .55852 Mdot
.65046 .85059 Mdot
.43748 .82583 Mdot
.43439 .58635 Mdot
.43095 .54396 Mdot
.46698 .31516 Mdot
.57135 .37967 Mdot
.62076 .89232 Mdot
.4389 .86383 Mdot
.43036 .39364 Mdot
.63584 .49503 Mdot
.46571 .24685 Mdot
.42869 .59241 Mdot
.56505 .42885 Mdot
.63451 .32134 Mdot
.49943 .80602 Mdot
.63721 .69354 Mdot
.51654 .70561 Mdot
.47031 .89544 Mdot
.52737 .75351 Mdot
.38993 .17092 Mdot
.46695 .72064 Mdot
.59763 .70784 Mdot
.41606 .91958 Mdot
.52137 .76937 Mdot
.69108 .38852 Mdot
.64718 .66519 Mdot
.61546 .73784 Mdot
.54483 .60663 Mdot
.54122 .29062 Mdot
.41545 .1858 Mdot
.49629 .72374 Mdot
.41668 .91161 Mdot
.66726 .21112 Mdot
.55537 .47216 Mdot
.44627 .39729 Mdot
.61982 .89056 Mdot
.59375 .3844 Mdot
.57012 .52496 Mdot
.62287 .149 Mdot
.52127 .72915 Mdot
.39177 .66195 Mdot
.6413 .35254 Mdot
.42184 .82182 Mdot
.691 .25879 Mdot
.61834 .37414 Mdot
.60069 .77849 Mdot
.5414 .77766 Mdot
.69479 .64457 Mdot
.53898 .57659 Mdot
.54047 .10819 Mdot
.60756 .51468 Mdot
.54661 .76785 Mdot
.39985 .20371 Mdot
.45141 .00814 Mdot
.46959 .29121 Mdot
.514 .33502 Mdot
.56584 .14165 Mdot
.40059 .5287 Mdot
.54734 .65773 Mdot
.55594 .22412 Mdot
.49721 .39023 Mdot
.5286 .94492 Mdot
.70681 .45429 Mdot
.58116 .33787 Mdot
.57024 .52304 Mdot
.59863 .7735 Mdot
.52036 .39095 Mdot
.61066 .48626 Mdot
.54149 .81873 Mdot
.5089 .26238 Mdot
.60963 .35694 Mdot
.45919 .93288 Mdot
.41289 .31337 Mdot
.46362 .93825 Mdot
.5369 .19481 Mdot
.43083 .30269 Mdot
.54121 .25 Mdot
.56694 .13763 Mdot
.45899 .76384 Mdot
.50109 .21035 Mdot
.70961 .52241 Mdot
.56362 .41587 Mdot
.63437 .54629 Mdot
.39333 .2348 Mdot
.52948 .57926 Mdot
.46943 .7672 Mdot
.61679 .21654 Mdot
.46432 .98708 Mdot
.42418 .29235 Mdot
.4459 .62655 Mdot
.51577 .24383 Mdot
.49694 .93261 Mdot
.57616 .62055 Mdot
.64808 .6467 Mdot
.74866 .61361 Mdot
.68132 .35195 Mdot
.46166 .98253 Mdot
.67822 .34814 Mdot
.50979 .41523 Mdot
.67849 .33589 Mdot
.63421 .17023 Mdot
.5416 .87584 Mdot
.43758 .9566 Mdot
.70114 .17545 Mdot
.52415 .21755 Mdot
.59918 .31256 Mdot
.39765 .70517 Mdot
.69557 .63845 Mdot
.37086 .33034 Mdot
.51766 .27841 Mdot
.70867 .50985 Mdot
.40178 .4273 Mdot
.48032 .69595 Mdot
.62603 .30343 Mdot
.56626 .71782 Mdot
.65486 .3903 Mdot
.60234 .11764 Mdot
.49143 .30262 Mdot
.58114 .74564 Mdot
.42477 .78279 Mdot
.58596 .86357 Mdot
.52809 .42724 Mdot
.36593 .59374 Mdot
.53751 .05146 Mdot
.75457 .45223 Mdot
.54119 .38731 Mdot
.63888 .5008 Mdot
.39304 .46501 Mdot
.42673 .10692 Mdot
.55342 .31761 Mdot
.44041 .6314 Mdot
.51702 .48728 Mdot
.5371 .78285 Mdot
.45202 .98351 Mdot
.54993 .12251 Mdot
.52997 .6292 Mdot
.602 .25285 Mdot
.53222 .54241 Mdot
.46916 .3137 Mdot
.42232 .16202 Mdot
.62987 .42713 Mdot
.53827 .20382 Mdot
.44842 .18102 Mdot
.56185 .348 Mdot
.40078 .47246 Mdot
.39699 .29632 Mdot
.5436 .48262 Mdot
.62599 .80525 Mdot
.56842 .48312 Mdot
.38966 .73131 Mdot
.46655 .09451 Mdot
.44497 .71037 Mdot
.56497 .65603 Mdot
.73672 .37814 Mdot
.43171 .95329 Mdot
.68024 .3372 Mdot
.47833 .93867 Mdot
.50562 .1861 Mdot
.45953 .85697 Mdot
.4161 .85466 Mdot
.60515 .43689 Mdot
.43474 .95837 Mdot
.7598 .48103 Mdot
.59216 .79432 Mdot
.392 .82339 Mdot
.36429 .5424 Mdot
.40141 .12116 Mdot
.50615 .36679 Mdot
.57958 .3371 Mdot
.40442 .87246 Mdot
.51801 .95813 Mdot
.51435 .40038 Mdot
.65915 .59863 Mdot
.40137 .52472 Mdot
.63719 .51301 Mdot
.46927 .89763 Mdot
.70713 .52267 Mdot
.39438 .6853 Mdot
.6516 .27663 Mdot
.49363 .0578 Mdot
.56457 .19713 Mdot
.66802 .30464 Mdot
.57036 .20391 Mdot
.36489 .48337 Mdot
.57871 .02961 Mdot
.62366 .23114 Mdot
.62748 .6032 Mdot
.43435 .51392 Mdot
.47981 .00054 Mdot
.60137 .61257 Mdot
.51536 .46041 Mdot
.36404 .54846 Mdot
.66944 .53795 Mdot
.44299 .64473 Mdot
.41692 .58579 Mdot
.42854 .75912 Mdot
.56735 .56207 Mdot
.71099 .53893 Mdot
.63678 .7022 Mdot
.65678 .20285 Mdot
.36523 .58074 Mdot
.51685 .81425 Mdot
.48448 .85837 Mdot
.44013 .23769 Mdot
.48651 .19521 Mdot
.45825 .64163 Mdot
.47176 .99247 Mdot
.43481 .95763 Mdot
.56931 .50766 Mdot
.45904 .73608 Mdot
.56857 .57446 Mdot
.5176 .70771 Mdot
.54654 .05458 Mdot
.58444 .58648 Mdot
.5643 .83478 Mdot
.4192 .48817 Mdot
.53806 .69097 Mdot
.53047 .44819 Mdot
.58979 .5193 Mdot
.49393 .84662 Mdot
.56243 .60387 Mdot
.44053 .33297 Mdot
.63644 .16442 Mdot
.55631 .90836 Mdot
.48654 .3869 Mdot
.42678 .19826 Mdot
.51495 .82141 Mdot
.62126 .62173 Mdot
.40392 .40657 Mdot
.52581 .71981 Mdot
.49602 .0071 Mdot
.70346 .75929 Mdot
.38645 .5863 Mdot
.42178 .00156 Mdot
.41568 .80686 Mdot
.47246 .26946 Mdot
.69044 .63925 Mdot
.39477 .83128 Mdot
.56025 .40986 Mdot
.46235 .09791 Mdot
.4473 .71356 Mdot
.47463 .70088 Mdot
.46953 .19557 Mdot
.60072 .77094 Mdot
.46273 .16902 Mdot
.6774 .80504 Mdot
.45227 .69839 Mdot
.42612 .2042 Mdot
.39883 .63406 Mdot
.53997 .57898 Mdot
.48042 .29288 Mdot
.4348 .70696 Mdot
.51219 .96629 Mdot
.51616 .36956 Mdot
.42323 .10973 Mdot
.40234 .25107 Mdot
.55996 .7899 Mdot
.44191 .91754 Mdot
.65799 .59944 Mdot
.54186 .77056 Mdot
.74743 .63794 Mdot
.41391 .52637 Mdot
.44304 .9737 Mdot
.45285 .00601 Mdot
.50766 .26075 Mdot
.67994 .33826 Mdot
.40757 .35898 Mdot
.59654 .61524 Mdot
.392 .74808 Mdot
.44912 .88277 Mdot
.40707 .49177 Mdot
.56252 .66484 Mdot
.4682 .85776 Mdot
.70015 .27001 Mdot
.58076 .28085 Mdot
.47933 .35363 Mdot
.52441 .18077 Mdot
.50543 .19036 Mdot
.50367 .35649 Mdot
.54548 .41068 Mdot
.46789 .13058 Mdot
.58928 .29421 Mdot
.4372 .3818 Mdot
.41128 .6695 Mdot
.67876 .69305 Mdot
.5803 .40969 Mdot
.5637 .77953 Mdot
.45557 .78905 Mdot
.43145 .72428 Mdot
.52533 .50687 Mdot
.52431 .53244 Mdot
.42869 .14451 Mdot
.68843 .3856 Mdot
.55472 .84866 Mdot
.4677 .79663 Mdot
.37521 .54247 Mdot
.38171 .76691 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Booooo`;o00001Oooool6o`00
00Gooooo0ol00005ooooo`?o0000^Oooool009;ooooo0_l0000@ooooo`?o00001Oooool00ol0003o
ooooooooo`2iooooo`00W?ooool2o`0000Kooooo00?o0000ooooooooool00oooool3o`000;_ooooo
002Looooo`;o00001_ooool00ol0003oooooooooo`03ooooo`?o0000^oooool009cooooo0_l00006
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:;ooooo00?oEEEEofIV
I_l000001oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`03o`000?oooooooooo01Oooooo0_l0002Pooooo`00[?ooool00ol0003o
ooooooooo`0Gooooo`;o0000X?ooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o
0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:Gooooo0_l00005oooo
o`03o`000?oooooooooo0;Wooooo002Uooooo`;o00001Oooool00ol0003oooooooooo`2iooooo`00
[?ooool3o`0000Wooooo0_l0002^ooooo`00[?ooool00ol0003oooooooooo`09ooooo`;o000000?o
ooooo`000?l00000Zoooool00:Wooooo0_l000000ooooooo0000ooooo`0=ooooo`;o0000Zoooool0
09[ooooo0_l0000=ooooo`;o000000?oooooo`000?ooool0^_ooool009[ooooo0_l0000@ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Hooooo`;o00004_oo
ool00ol0003oooooooooo`2iooooo`00V?ooool2o`0001;ooooo00?o0000ooooooooool0^Oooool0
0:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00XOooool2o`0000Wooooo00?o0000oooooooo
ool0^Oooool009oooooo1?l00009ooooo`03o`000?oooooooooo0;Wooooo002Oooooo`;o00002ooo
ool3o`000;Wooooo002/ooooo`03o`000?oooooooooo00[ooooo0_l0002]ooooo`00Toooool2o`00
01Oooooo00?o0000ooooooooool02_ooool2o`000:gooooo002Booooo`?o00005oooool00ol0003o
ooooooooo`0:ooooo`;o00008_ooool2o`0008Wooooo002Booooo`;o00006?ooool00ol0003ooooo
ooooo`0:ooooo`;o00008_ooool2o`0008Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo0029
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@?ooooo0_l000000ooooooo0000onk^
kP05ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Nooooo`;o0000
VOooool008Wooooo00GoMgMgoiRHV?l0003o0000ogMgM`05ooooo`;o8B4Q0oooool2o`000003oooo
oomEEEGoZJVY00Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0=ooooo`;o0000
3oooool2o`0009Wooooo0021ooooo`Ko00000_ooool01Ol@413oooooo`000?l0003o410@00gooooo
00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o00003Oooool2o`0000oooooo
0_l0002Iooooo`00ROooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool0
1_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05o`000?oo
ooooooooooooool000000_ooool2o`0000Cooooo0_l00004ooooo`03oeEEEOo<c<cooooo00;ooooo
0_l000001?lQ8B7o0000o`000?o<c<`5ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`06oa0@
4?ooooooooooooooool@413ooooo0ol00004ooooo`;o00001?ooool00onYZJWoMgMgooooo`02oooo
o`;o000000?oooooo`000?l000001_ooool00ol0003oooooooooo`2iooooo`00ROooool01_mgMgOo
V9RHoooooonHV9SoMgMgooooo`;o00002?ooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`;o0000Y?ooool008Wooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool04ooo
ool2o`000:Cooooo002/ooooo`03o`000?oooooooooo01;ooooo1?l0002Sooooo`00U?ooool2o`00
01Kooooo00?o0000ooooooooool04_ooool4o`00013ooooo0_l0002Aooooo`00ROooool2o`0000Wo
oooo0_l0000Fooooo`03o`000?oooooooooo02Gooooo0ol0002Aooooo`00ROooool2o`00027ooooo
0ol0000Uooooo`;o0000T_ooool00:cooooo00?o0000ooooooooool05oooool2o`000:3ooooo002C
ooooo`;o00005oooool00ol0003oooooooooo`0Gooooo`;o0000X?ooool009;ooooo0ol0000Goooo
o`04o`000?ooooooooooooooo`;o00005?ooool2o`000:3ooooo002Booooo`;o00006?ooool01?l0
003oooooooooooooool2o`0002Oooooo0_l0002=ooooo`00[?ooool00ol0003oooooooooo`0<oooo
o`;o00007?ooool2o`0008gooooo0027ooooo`;o00005_ooool2o`0000_ooooo00?o0000oooooooo
ool03?ooool2o`0001_ooooo0_l0002>ooooo`00Qoooool2o`0001Kooooo0_l00008ooooo`;o0000
00?oooooo`000?ooool0:_ooool2o`0008kooooo002Yooooo`;o000000Coooooo`000?l0003o0000
?oooool2o`0007Sooooo002Kooooo`;o00003oooool00ol0003oooooooooo`0oooooo`;o0000N?oo
ool009_ooooo0_l0000?ooooo`03o`000?oooooooooo00Gooooo0_l0000Vooooo`;o0000R_ooool0
093ooooo0_l00009ooooo`;o00003oooool3o`0000Gooooo0_l0000Vooooo`;o0000R_ooool0093o
oooo0_l0000Jooooo`?o0000^Oooool008Kooooo0_l0000Tooooo`?o00007Oooool2o`0009[ooooo
0026ooooo`;o00006_ooool2o`0000?ooooo0_l00003ooooo`?o00002Oooool2o`0001;ooooo0_l0
002Jooooo`00Toooool2o`0000gooooo0_l00003ooooo`;o00000oooool00ol0003oooooooooo`09
ooooo`;o00001oooool2o`000:Gooooo002Cooooo`;o00005oooool3o`0000Sooooo0_l00008oooo
o`;o0000YOooool008_ooooo0_l00006ooooo`;o00005oooool00ol0003oooooooooo`08ooooo`?o
00002Oooool2o`0001[ooooo0_l00027ooooo`00Roooool2o`0000Kooooo0_l0000Gooooo`03o`00
0?oooooooooo00Wooooo0_l00009ooooo`;o00003?ooool2o`0000cooooo0_l00027ooooo`00[?oo
ool2o`0002?ooooo0_l0002Eooooo`00[?ooool2o`0003Gooooo0_l00023ooooo`00[?ooool00ol0
003oooooooooo`0Sooooo`;o00003oooool2o`0008?ooooo002Vooooo`;o00001?ooool00ol0003o
ooooooooo`05ooooo`;o00003oooool2o`0000_ooooo0_l0000?ooooo`;o0000Poooool008Gooooo
0_l0000Oooooo`;o00001?ooool00ol0003oooooooooo`05ooooo`;o00003oooool2o`0000cooooo
0_l0000>ooooo`;o0000Poooool008Gooooo0_l0000Cooooo`;o00004?ooool3o`0000kooooo0ol0
000Cooooo`?o0000T_ooool009[ooooo0_l0000@ooooo`03o`000?oooooooooo00kooooo0ol00007
ooooo`;o00002oooool2o`0009;ooooo002/ooooo`03o`000?oooooooooo01Sooooo0_l0000;oooo
o`;o0000T_ooool008Sooooo0_l0000Pooooo`?o00009oooool2o`0009;ooooo0028ooooo`;o0000
3_ooool2o`00013ooooo0ol0002kooooo`00V?ooool2o`0001;ooooo00?o0000ooooooooool0^Ooo
ool0097ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Gooooo00?o0000ooooooooool00_ooool2o`000;Gooooo0028ooooo`;o00001ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B43ooooo`;o00000oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo00;ooooo0_l0002eooooo`00R?ooool7o`0000;ooooo00Go
410@oooooooooooooooooa0@400:ooooo`Co00000_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00[ooooo0_l0002]ooooo`00R?ooool2o`000003ooooool0003o000000Cooooo00Go
0000ooooooooooooooooo`00000:ooooo`Co000000?oooooogMgMolb<S801Oooool3o`0000[ooooo
0_l0000Booooo`;o0000VOooool008_ooooo0_l00004ooooo`05o`000?ooooooooooooooool00000
2_ooool3o`000004ob4Q8Ol0003o<S8bolc<c0Gooooo00?o0000ooooooooool07_ooool2o`0009Wo
oooo002Aooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo03cooooo0_l0001kooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00co
oooo00?o0000ooooooooool01oooool01?l0003oooooo`000?l0000kooooo`;o0000Noooool008Oo
oooo0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000oooo
ool000000_l0000jooooo`;o0000Noooool008Oooooo0_l0000Sooooo`03o`000?oooooooooo00;o
0000]oooool008?ooooo0_l0000Mooooo`;o00002?ooool00ol0003oooooooooo`0oooooo`;o0000
N?ooool008;ooooo0ol00009ooooo`;o00004_ooool2o`0000Sooooo0_l0000Hooooo`;o00009_oo
ool2o`0007Sooooo0022ooooo`;o00002_ooool2o`0001cooooo0ol0000Gooooo`;o00005_ooool2
o`0008Sooooo002/ooooo`03o`000?oooooooooo00;ooooo0ol0000Zooooo`;o0000R?ooool00:co
oooo00?o0000ooooooooool00_ooool3o`0001;ooooo0_l0002Pooooo`00[?ooool00ol0003ooooo
ooooo`0Aooooo`;o00001?ooool2o`000:3ooooo002Tooooo`;o00001_ooool00ol0003ooooooooo
o`0Aooooo`;o0000Y_ooool009?ooooo0_l0000=ooooo`Co00001_ooool00ol0003oooooooooo`0:
ooooo`;o0000[Oooool009?ooooo0_l0000=ooooo`;o000000?oooooo`000?l000001Oooool00ol0
003oooooooooo`0:ooooo`;o00003_ooool2o`0009gooooo0022ooooo`;o00001_ooool2o`0001Wo
oooo0_l00005ooooo`03o`000?oooooooooo01[ooooo0_l0002Mooooo`00P_ooool2o`0000Kooooo
0_l0000Pooooo`?o00001_ooool2o`000;7ooooo002Eooooo`;o00004_ooool2o`000003ooooool0
003ooooo00Oooooo0_l0000Cooooo`;o00002Oooool2o`00097ooooo002Eooooo`;o00004_ooool2
o`000003ooooool0003ooooo01cooooo0_l00009ooooo`;o00003?ooool2o`0008?ooooo002/oooo
o`03o`000?oooooooooo03Cooooo0_l00023ooooo`00Soooool2o`0000?ooooo0_l0000;ooooo`;o
00002Oooool00ol0003oooooooooo`0Mooooo`;o0000V_ooool008oooooo0_l00003ooooo`;o0000
2oooool2o`0000Wooooo00?o0000ooooooooool07Oooool2o`0009[ooooo002Qooooo`;o00002Ooo
ool00ol0003oooooooooo`0>ooooo`;o0000ZOooool00:cooooo00?o0000ooooooooool03_ooool2
o`0001Wooooo0_l0002>ooooo`00Voooool2o`0000oooooo0ol0000Yooooo`;o0000S_ooool009_o
oooo0_l0000?ooooo`03o`000?oooooooooo0;Wooooo0021ooooo`;o0000:Oooool00ol0003ooooo
ooooo`2iooooo`00POooool2o`0000gooooo0_l00006ooooo`;o00004_ooool00ol0003ooooooooo
o`2iooooo`00T?ooool2o`000003ooooool0003o000000?ooooo0_l0000Booooo`04o`000?oooooo
ooooooooo`;o00005?ooool2o`0001kooooo0ol0001oooooo`00Toooool2o`0001Oooooo00Co0000
oooooooooooooooo0_l0000Dooooo`;o00007_ooool3o`0007oooooo002@ooooo`;o00006_ooool0
0ol0003oooooooooo`0hooooo`;o0000Ooooool0093ooooo0_l00003ooooo`;o00005Oooool00ol0
003oooooooooo`0Zooooo`;o0000SOooool008Cooooo0_l0000?ooooo`;o00001?ooool2o`0000oo
oooo00?o0000ooooooooool04Oooool2o`0001Oooooo0_l0000;ooooo`;o0000P?ooool008Cooooo
0_l0000Eooooo`;o00003oooool3o`0000?ooooo0_l0000<ooooo`;o00006?ooool2o`0000[ooooo
0ol0001oooooo`00YOooool2o`0000Gooooo00?o0000ooooooooool00oooool2o`0002Kooooo0_l0
000;ooooo`;o0000Ooooool008gooooo0_l0000Fooooo`;o00001Oooool3o`00027ooooo0_l0002F
ooooo`00SOooool2o`0001Oooooo0_l00004ooooo`?o00008Oooool2o`0009Kooooo002Vooooo`;o
00001?ooool00ol0003oooooooooo`2iooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00Co0000oooo
ool0003o0000^?ooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool01Ol0003oooooo`00
0?l0003ooooo00;o0000]Oooool0087ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool2o`00023ooooo0_l0002Cooooo`00ROooool01Ol0003ooooooooooooooooo000000gooooo
00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o00009?ooool2o`0009?ooooo
0029ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Dooooo`;o0000=Oooool2o`0006co
oooo0023ooooo`;o00001?ooool01Ol@413ooooooooooooooooo410@00Wooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Dooooo`;o
00009_ooool2o`0000gooooo0_l0001/ooooo`00Poooool2o`0000Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`09ooooo`?o000000Co^[ZjoooooonHV9So410@1?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo01cooooo0_l0000Mooooo`?o00003Oooool2o`0006cooooo0029ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00000
0ooooooo0000o`000003ooooo`03o`000?oooooooooo00[ooooo0_l0000@ooooo`;o00007Oooool3
o`0007_ooooo002Wooooo`;o00000_ooool2o`0000Gooooo0_l00005ooooo`;o00009?ooool2o`00
00[ooooo0_l0001kooooo`00TOooool2o`0000;ooooo0_l0000Dooooo`;o00001Oooool2o`0000[o
oooo0_l0000Oooooo`;o0000Qoooool0097ooooo0_l00002ooooo`;o00000oooool2o`00013ooooo
00?o0000ooooooooool03oooool2o`000:Sooooo002Jooooo`;o00004?ooool3o`000003ooooool0
003o00000;Kooooo002/ooooo`04o`000?ooooooooooooooo`;o0000]_ooool008cooooo0_l0000N
ooooo`03o`000?oooooooooo0;Wooooo002<ooooo`;o00007_ooool00ol0003oooooooooo`0@oooo
o`;o00001Oooool2o`000:3ooooo002/ooooo`03o`000?oooooooooo00cooooo0_l00002ooooo`;o
00001Oooool2o`000:3ooooo002Gooooo`;o00004oooool00ol0003oooooooooo`02o`0000[ooooo
0_l00004ooooo`;o0000YOooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo00;o00004?oo
ool2o`000:Gooooo002/ooooo`03o`000?oooooooooo01Sooooo0_l0000Hooooo`;o0000QOooool0
08;ooooo0_l0000Xooooo`?o00006?ooool2o`0001Sooooo0_l00025ooooo`00P_ooool2o`0000Oo
oooo0_l0000Oooooo`03o`000?oooooooooo00Kooooo0_l0000Oooooo`;o00002_ooool2o`0008Co
oooo002;ooooo`;o00007oooool00ol0003oooooooooo`06ooooo`;o00002_ooool2o`0001?ooooo
0_l0000:ooooo`;o0000Q?ooool00:cooooo00?o0000ooooooooool04_ooool2o`0000Cooooo0_l0
002Oooooo`00[?ooool00ol0003oooooooooo`0Hooooo`;o00001Oooool2o`0009Sooooo002/oooo
o`03o`000?oooooooooo01oooooo0_l0002Hooooo`00[?ooool00ol0003oooooooooo`0cooooo`;o
0000Q?ooool00:cooooo00?o0000ooooooooool0<oooool2o`0008Cooooo002/ooooo`03o`000?oo
oooooooo00Oooooo0_l0000@ooooo`;o00003Oooool2o`0000[ooooo0_l00023ooooo`00[?ooool3
o`0000Oooooo0_l0000@ooooo`;o00003Oooool2o`0000[ooooo0_l0000Kooooo`;o0000I_ooool0
0:cooooo00?o0000ooooooooool0@Oooool2o`0000kooooo0_l0001Vooooo`00[?ooool00ol0003o
ooooooooo`11ooooo`;o0000M_ooool000Wooooo1?l000000ol@413oooooooooo`0Fooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool0
1Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Fooooo`03o`000?oooooooooo00;o
oooo0_l0000Dooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004oooo
o`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hoooo
o`Co000000?o410@ooooooooool04_ooool000_ooooo00?o0000ooooooooool06?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b
<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool2o`000003onk^k_oo
ooooA4A400Oooooo00?oMgMgoc8b<_ooool05Oooool00ol0003oooooooooo`02ooooo`;o00005?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01oooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46
ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool06Oooool00ol0003oooooooooo`0D
ooooo`001_l00005ooooo`03o`000?oooooooooo013ooooo1_l00002ooooo`05oa0@4?oooooooooo
ooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00Gooooo1_l00002
ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`05ooooo`Ko00000_oo
ool01Ol@413ooooooooooooooooo410@00_ooooo0_l000000olQ8B7ok^k^ooooo`08ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool06?ooool01Ol@413ooooooooooooooooo410@00co
oooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`0=ooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol0003oooooooooo`0=ooooo`05oa0@4?ooooooooooooooool@41003Oooool0
0onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05?ooool0
00_ooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Q
ooooooooool01_ooool00omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003ooo
ool00omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Q
onk^kP07ooooo`03ogMgMolb<S;ooooo01Gooooo00?o0000ooooooooool06?ooool01Ol0003ooooo
oooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`0>ooooo`05
o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0>ooooo`05o`000?oooooooooo
ooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Wooooo00?o0000
ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo
000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go
0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003o
oooooooooooooooo000000kooooo0_l00004ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05_ooool0
0ol0003oooooooooo`0?ooooo`;o00001oooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo
000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[ooooo00?o
0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol@413ooooooooooooo
oooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`0Aooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@
41003_ooool2o`0000Cooooo00?o0000ooooooooool06?ooool3o`0000oooooo0_l00007ooooo`05
oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
017ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo017ooooo00Go410@
oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool0
4Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0<ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo01Cooooo0009ooooo`03oeEEEOmVIVKo000001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`Go00001?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00004?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co
00005oooool00ol0003oooooooooo`0;ooooo`;o00001_ooool2o`0000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool6o`0000kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP08ooooo`;o00000_ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`Go00001?ooool4o`0001Wooooo00?oEEEEofIVI_l000005_ooool007oooooo0_l0
000[ooooo`03o`000?oooooooooo00_ooooo0_l00006ooooo`;o00003?ooool2o`0000Oooooo0_l0
0009ooooo`;o00006oooool2o`0006Gooooo001oooooo`;o00004?ooool2o`0001Wooooo00?o0000
ooooooooool00_ooool2o`0000Oooooo0_l0000Dooooo`;o00001oooool2o`0008gooooo002=oooo
o`;o00000_ooool2o`0001Wooooo00?o0000ooooooooool00_ooool2o`0000Oooooo0_l0002Qoooo
o`;o00000_ooool2o`0000Gooooo002=ooooo`;o00007Oooool00ol0003oooooooooo`0?ooooo`;o
00006?ooool2o`0001Kooooo0_l0001[ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1Oooool0
0:cooooo00?o0000ooooooooool03oooool2o`0001Sooooo0_l00008ooooo`Co00002_ooool3o`00
06_ooooo00CogMgMo`000?l@413oc<c<1_ooool000Ooooooool0001<o`0000cooooo00Cok^k^ob4Q
8Ol@413ok^k^1_ooool000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00Co0000ooooool0003o00001?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02
o`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00[ooooo00Co8B4QogMgMomgMgOo<S8b1_ooool000Oooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`05ooooo`;o000000?oooooo`000?l000007Oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`09
ooooo`;o00000_ooool2o`0000Gooooo002/ooooo`03o`000?oooooooooo00Gooooo0_l00008oooo
o`;o00000_ooool2o`0002cooooo0_l0001fooooo`00[?ooool00ol0003oooooooooo`0?ooooo`;o
00000_ooool2o`0001Gooooo0_l0000Eooooo`?o0000MOooool009Kooooo0_l0000Dooooo`03o`00
0?oooooooooo023ooooo1?l00006ooooo`;o00005_ooool2o`0007Gooooo002Fooooo`;o00005?oo
ool00ol0003oooooooooo`0Cooooo`;o00001Oooool2o`0000Cooooo1?l0002Eooooo`00[?ooool0
0ol0003oooooooooo`0Cooooo`;o00001?ooool3o`0002Gooooo0ol0001eooooo`00R?ooool2o`00
0003ooooool0003o000001oooooo0ol0000Dooooo`;o00000oooool2o`0002Kooooo0ol0001eoooo
o`00R?ooool2o`000003ooooool0003o000000;ooooo0_l0000Kooooo`03o`000?oooooooooo01Co
oooo0_l0002Sooooo`00Roooool2o`0000;ooooo0_l0000Kooooo`03o`000?oooooooooo03Gooooo
0_l00022ooooo`00[?ooool00ol0003oooooooooo`05ooooo`;o0000;Oooool3o`0008;ooooo002/
ooooo`03o`000?oooooooooo00Gooooo0_l0000]ooooo`;o0000Poooool00:cooooo00?o0000oooo
ooooool0=?ooool2o`0000cooooo0_l0001eooooo`00Ooooool2o`000003ooooool0003o000002So
oooo00?o0000ooooooooool01oooool2o`0002_ooooo0_l0000<ooooo`;o0000MOooool007oooooo
0_l000000ooooooo0000o`00000Aooooo`;o00005Oooool00ol0003oooooooooo`07ooooo`;o0000
6?ooool2o`0000Gooooo0ol0002>ooooo`00Ooooool2o`00013ooooo0_l00002ooooo`;o00005Ooo
ool00ol0003oooooooooo`0Qooooo`;o00001Oooool3o`0008kooooo001oooooo`;o00004?ooool2
o`0001Wooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`0Iooooo`;o0000W_ooool00:cooooo00?o0000ooooooooool04oooool2o`0000Cooooo
0_l0002Nooooo`00Poooool2o`0002Oooooo00?o0000ooooooooool04oooool2o`0001?ooooo0_l0
002?ooooo`00Poooool2o`0002Oooooo00?o0000ooooooooool0:?ooool2o`0008oooooo002=oooo
o`;o00007Oooool01?l0003oooooooooooooool2o`0001Gooooo0_l0002Oooooo`00SOooool2o`00
01gooooo00Co0000oooooooooooooooo0_l0000Eooooo`;o0000Woooool00:cooooo0ol00009oooo
o`;o00002?ooool2o`000:Cooooo002/ooooo`03o`000?oooooooooo00Kooooo0_l000001?oooooo
0000o`000?l00002ooooo`;o00000oooool2o`000:Cooooo001oooooo`;o00001Oooool2o`0002Co
oooo00?o0000ooooooooool01_ooool2o`0000;ooooo0_l00002ooooo`;o0000ZOooool007oooooo
0_l00005ooooo`;o00002?ooool2o`0001[ooooo00?o0000ooooooooool0^Oooool008Kooooo0_l0
0008ooooo`;o00001?ooool2o`0001Cooooo00?o0000ooooooooool06?ooool2o`0002Gooooo0_l0
001hooooo`00U_ooool2o`0001Cooooo00?o0000ooooooooool06?ooool2o`0002Gooooo0_l0001h
ooooo`00Ooooool2o`0001?ooooo0_l0000Fooooo`03o`000?oooooooooo0;Wooooo001oooooo`;o
00004oooool2o`0001Kooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0000aooooo`;o0000
Q_ooool00:cooooo00?o0000ooooooooool04Oooool2o`0000Cooooo0_l0000>ooooo`;o00002?oo
ool2o`0008Kooooo002/ooooo`03o`000?oooooooooo00_ooooo0_l00004ooooo`;o00001?ooool2
o`0000kooooo0_l0002@ooooo`00[?ooool00ol0003oooooooooo`0;ooooo`;o0000[?ooool00:co
oooo00?o0000ooooooooool07_ooool2o`0001oooooo0_l0001hooooo`00[?ooool00ol0003ooooo
ooooo`0Looooo`Co00007_ooool3o`0000kooooo0_l0001Xooooo`00ROooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Go
oooo00?o0000ooooooooool07?ooool2o`00023ooooo0_l0000?ooooo`;o0000J?ooool008Wooooo
00GoMgMgo`000?l0003oV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A4
00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Fooooo`;o00003Oooool2o`00
02Sooooo0_l0001Xooooo`00ROooool01Ol@413o0000o`000?oooooo410@00cooooo00?oV9RHob4Q
8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o00005_ooool2o`0000gooooo0_l0000Goooo
o`;o0000NOooool008Wooooo00Go0000ooooooooooooooooo`00000<ooooo`;o000000?o8B4Qonk^
k_ooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01gooooo0_l0000Ooooo
o`;o0000NOooool0083ooooo0_l00007ooooo`05o`000?ooooooooooooooool000002_ooool4o`00
0003ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo00Kooooo0_l0000Eooooo`;o00007oooool2o`0000kooooo0_l0001Yooooo`00P?ooool2o`00
00Oooooo00Go410@o`000?l0003ooooooa0@400:ooooo`;o00000oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool2o`0004Kooooo0_l0001Y
ooooo`00ROooool01OmgMgOo0000o`000?nHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@
4004ooooo`?o00001oooool00ol0003oooooooooo`06ooooo`;o0000/Oooool008Cooooo0_l00003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo
1?l00006ooooo`03o`000?oooooooooo00[ooooo0_l0000Sooooo`;o00002_ooool4o`0000oooooo
0_l0001Yooooo`00Q?ooool2o`0001Sooooo0_l0000<ooooo`03o`000?oooooooooo00[ooooo0_l0
000Sooooo`;o00002_ooool4o`0000oooooo0_l0001Yooooo`00VOooool2o`0000?ooooo0_l0000<
ooooo`03o`000?oooooooooo02gooooo0_l0000>ooooo`;o0000N_ooool009Wooooo0_l0000Aoooo
o`03o`000?oooooooooo02gooooo0_l0000>ooooo`;o0000N_ooool008Cooooo0_l0000Vooooo`?o
0000^Oooool008Cooooo0_l0000Vooooo`03o`000?oooooooooo01_ooooo0_l0002Looooo`00[?oo
ool00ol0003oooooooooo`0<ooooo`;o00001?ooool2o`0000Oooooo0_l0002Looooo`00R?ooool2
o`0002;ooooo00?o0000ooooooooool03?ooool2o`0000Cooooo0_l0002Uooooo`00R?ooool2o`00
02;ooooo00?o0000ooooooooool04Oooool2o`000:Kooooo002/ooooo`03o`000?oooooooooo017o
oooo0_l0000Jooooo`;o0000R_ooool008kooooo0_l0000Looooo`03o`000?oooooooooo02gooooo
0_l0002:ooooo`00S_ooool2o`0000Cooooo0_l0000Fooooo`03o`000?oooooooooo0;Wooooo002D
ooooo`;o00005_ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo01Oooooo0_l0000aoooo
o`;o0000KOooool00:cooooo00?o0000ooooooooool02_ooool2o`0000_ooooo0_l0000aooooo`;o
0000KOooool008Wooooo0_l0000Qooooo`03o`000?oooooooooo00[ooooo0_l0000;ooooo`;o0000
X?ooool008Wooooo0_l0000Qooooo`03o`000?oooooooooo01Oooooo0_l0000Oooooo`;o0000Oooo
ool009;ooooo0_l0000Hooooo`03o`000?oooooooooo00Wooooo0_l00005ooooo`;o00005oooool3
o`0000cooooo0_l0001oooooo`00T_ooool2o`0001Sooooo00?o0000ooooooooool02Oooool2o`00
00Gooooo0_l0000Gooooo`?o00003?ooool2o`0007oooooo002Looooo`;o00001oooool2o`0000Go
oooo00?o0000ooooooooool0:_ooool2o`0000cooooo0_l0001oooooo`00W?ooool2o`0000Gooooo
1?l00005ooooo`?o0000>?ooool2o`0007oooooo002Sooooo`;o00001oooool00ol0003ooooooooo
o`0Zooooo`;o00003?ooool2o`0007oooooo002:ooooo`;o00002_ooool2o`0001Cooooo00?o0000
ooooooooool00_ooool2o`0002Kooooo0_l0000Kooooo`;o0000L?ooool008[ooooo0_l0000:oooo
o`;o000000?oooooo`000?l000004Oooool00ol0003oooooooooo`02ooooo`;o00006Oooool2o`00
02Sooooo0_l0001`ooooo`00VOooool3o`00013ooooo0_l00003ooooo`;o00006Oooool2o`0009[o
oooo002Jooooo`;o00004?ooool2o`000;[ooooo002Vooooo`;o00001?ooool00ol0003ooooooooo
o`0Booooo`;o0000YOooool00:7ooooo0_l00003ooooo`;o00000oooool2o`0000Oooooo0_l0000;
ooooo`;o0000YOooool009Gooooo0_l0000:ooooo`;o00001oooool5o`0000Gooooo0_l0002boooo
o`00UOooool2o`0001?ooooo0ol0002kooooo`00Qoooool2o`00023ooooo0_l000000ooooooo0000
ooooo`05ooooo`;o00001?ooool2o`000:gooooo0027ooooo`;o00008?ooool2o`000003ooooool0
003ooooo00Gooooo0_l00004ooooo`;o0000[Oooool009kooooo0_l0000<ooooo`03o`000?oooooo
oooo037ooooo0_l00026ooooo`00W_ooool2o`0000cooooo00?o0000ooooooooool08oooool2o`00
00cooooo0_l00026ooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Sooooo`;o00003Oooool2
o`0008Gooooo002Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`0Gooooo`;o00006Oooool2o`0008Gooooo0028oooo
o`;o00001oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Gooooo`;o00009oooool2o`0007Oooooo0028ooooo`;o00001oooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool3o`00037ooooo0_l0000=
ooooo`;o0000Moooool0097ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`06ooooo`;o0000:Oooool2o`0008Kooooo002A
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Kooooo0_l0002aooooo`00TOooool00omgMgOoV9RHooooo`02o`0000;ooooo0_l00008
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0@?ooool2o`0007Oooooo002Aoooo
o`03onk^k_lb<S;o000000;o00000_ooool2o`0000Cooooo0_l00002ooooo`Co00001_ooool00ol0
003oooooooooo`10ooooo`;o0000Moooool008Gooooo0_l0000Gooooo`;o000000?oooooo`000?l0
00002Oooool00ol0003oooooooooo`0<ooooo`;o0000Zoooool008Gooooo0_l0000Jooooo`;o0000
00?oooooo`000?l000001_ooool2o`0000Gooooo0_l00004ooooo`Co00004?ooool2o`0009Wooooo
002>ooooo`;o00005?ooool2o`0000Kooooo0_l00005ooooo`;o00001?ooool2o`0000Sooooo0_l0
0007ooooo`?o0000VOooool008kooooo0_l0000Looooo`?o00005?ooool2o`0000Oooooo0_l0002J
ooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool02_ooool2o`0000Kooooo0_l0000:oooo
o`;o0000VOooool009?ooooo0_l0000Gooooo`03o`000?oooooooooo00Wooooo0ol00006ooooo`;o
00002_ooool2o`0009Wooooo002Cooooo`;o00005oooool01?l0003oooooooooooooool2o`0000Ko
oooo0ol0002]ooooo`00WOooool2o`0000gooooo00Co0000oooooooooooooooo0_l0002fooooo`00
Q_ooool2o`0001Gooooo0_l0000=ooooo`03o`000?oooooooooo013ooooo0_l0002Wooooo`00Q_oo
ool2o`0001oooooo0_l00003ooooo`03o`000?oooooooooo013ooooo0_l00009ooooo`;o0000W?oo
ool00:7ooooo0_l00004ooooo`;o00000oooool00ol0003oooooooooo`0Kooooo`;o0000W?ooool0
0:7ooooo0_l00009ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool0093ooooo
0_l0000Iooooo`;o0000:?ooool3o`0000kooooo0_l00020ooooo`00T?ooool2o`0001Wooooo0_l0
000Xooooo`?o00003_ooool2o`00083ooooo002<ooooo`;o00007_ooool00ol0003oooooooooo`0<
ooooo`;o0000Zoooool008cooooo0_l0000Nooooo`03o`000?oooooooooo00;ooooo0_l00008oooo
o`;o0000Zoooool008cooooo0_l0000Nooooo`03o`000?oooooooooo00;ooooo0_l00006ooooo`;o
0000[Oooool008gooooo0_l00003ooooo`;o00005?ooool2o`0000;ooooo00Co0000oooooooooooo
oooo0_l00007ooooo`;o00006?ooool2o`0009?ooooo0028ooooo`;o00000oooool2o`0000?ooooo
0_l0000Dooooo`;o00000_ooool3o`000003ooooool0003o0000027ooooo0_l0002Cooooo`00R?oo
ool2o`0000gooooo0ol0000Booooo`03o`000?oooooooooo0;Wooooo0028ooooo`?o00003?ooool3
o`0001;ooooo00?o0000ooooooooool08?ooool2o`0009Oooooo0029ooooo`;o00008Oooool00ol0
003oooooooooo`0Booooo`;o00003?ooool2o`0009Oooooo002/ooooo`03o`000?oooooooooo01;o
oooo0_l0002Uooooo`00[?ooool00ol0003oooooooooo`0Booooo`;o0000YOooool00:cooooo00?o
0000ooooooooool0^Oooool00:[ooooo0ol0002kooooo`00Z_ooool3o`00017ooooo0_l0002Xoooo
o`00[?ooool3o`0000oooooo0_l0000Mooooo`;o0000ROooool0093ooooo0_l0000Jooooo`03o`00
0?oooooooooo02kooooo0_l00029ooooo`00T?ooool2o`0000cooooo0_l000000ooooooo0000o`00
0003ooooo`;o00001?ooool00ol0003oooooooooo`2iooooo`00W_ooool2o`000003ooooool0003o
000000?ooooo0_l00004ooooo`03o`000?oooooooooo0;Wooooo002Gooooo`;o00004oooool00ol0
003oooooooooo`0Iooooo`?o0000WOooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q0_ooool2o`0000;ooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool06Oooool3o`0009gooooo0029ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo01[ooooo0_l0002Mooooo`00ROooool00ol@413oooooooooo`02o`00
00[ooooo0_l000000oooooooZJVYoeEEE@09ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool06_ooool2o`0009gooooo0029ooooo`03o`000?oooooooooo00;o00001?ooool2o`0000Co
oooo0_l00002ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`0000[o
oooo0_l0002]ooooo`00ROooool00ol0003oooooooooo`02o`0000Cooooo0_l00008ooooo`03oeEE
EOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00[o
oooo0_l0002]ooooo`00ROooool00ol@413oooooooooo`02o`0000gooooo0_l000000omgMgOooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0^Oooool008Wooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooo0000o`000?lb<S801?ooool00ol0003o
ooooooooo`06ooooo`;o0000^oooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Ko
00000oooool4o`0000Gooooo0_l0002kooooo`00WOooool2o`0000gooooo00?o0000ooooooooool0
9?ooool2o`0009?ooooo002Vooooo`;o00001?ooool00ol0003oooooooooo`0Tooooo`;o0000Tooo
ool00:7ooooo0ol00002ooooo`;o00001?ooool00ol0003oooooooooo`0Tooooo`;o0000Toooool0
0:7ooooo0ol00008ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool008oooooo
0_l0000Kooooo`03o`000?oooooooooo0;Wooooo0029ooooo`;o00001?ooool2o`0001_ooooo00?o
0000ooooooooool03oooool2o`000:Sooooo0029ooooo`;o00001Oooool2o`0001[ooooo00?o0000
ooooooooool03_ooool3o`000:Sooooo002@ooooo`;o00006_ooool00ol0003oooooooooo`0>oooo
o`?o0000Z?ooool009Sooooo0_l0000Booooo`03o`000?oooooooooo0;Wooooo002@ooooo`;o0000
1_ooool2o`0001;ooooo0_l0002jooooo`00T?ooool4o`0001Sooooo0ol0002iooooo`00T_ooool2
o`0001Sooooo00?o0000ooooooooool0^Oooool009_ooooo0_l0000?ooooo`03o`000?oooooooooo
0;Wooooo002Kooooo`;o000000?oooooo`000?l000002oooool2o`000;_ooooo002Nooooo`;o0000
2oooool2o`000;_ooooo002Pooooo`;o00000_ooool2o`0000Kooooo00?o0000ooooooooool0^Ooo
ool009Cooooo0_l0000:ooooo`;o00000_ooool2o`0000Kooooo00?o0000ooooooooool0^Oooool0
09Cooooo0_l0000Fooooo`03o`000?oooooooooo00Kooooo0_l0002aooooo`00[?ooool00ol0003o
ooooooooo`06ooooo`;o0000/Oooool00:cooooo0ol0002iooooo`00UOooool2o`0001Gooooo00?o
0000ooooooooool0^Oooool009Gooooo1?l0000Cooooo`03o`000?oooooooooo00?ooooo0_l0002d
ooooo`00U_ooool3o`0001?ooooo00?o0000ooooooooool00oooool2o`000;Cooooo002Hooooo`;o
00004_ooool00ol0003oooooooooo`2iooooo`00V?ooool2o`0001;ooooo00Co0000oooooooooooo
oooo0_l0002fooooo`00[?ooool01?l0003oooooooooooooool2o`000;Kooooo002Iooooo`;o0000
4Oooool00ol0003oooooooooo`2iooooo`00VOooool2o`00017ooooo0ol0002iooooo`00[?ooool2
o`000;[ooooo002Aooooo`;o00003?ooool2o`0000_ooooo00?o0000ooooooooool0^Oooool0097o
oooo0_l00009ooooo`;o000000?oooooo`000?l000002oooool00ol0003oooooooooo`2iooooo`00
TOooool2o`0000Wooooo0_l00002ooooo`;o00002_ooool00ol0003oooooooooo`2iooooo`00X?oo
ool2o`0000[ooooo00?o0000ooooooooool0^Oooool00:;ooooo1?l000000ol@413oooooooooo`03
ooooo`03o`000?oooooooooo0;Wooooo002Rooooo`?o00001oooool00ol0003oooooooooo`2ioooo
o`00Y?ooool00ol0003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool0
`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool0
0:Cooooo00?o0000ooooooooool0`Oooool00:;ooooo00?oEEEEofIVI_l00000`oooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:[ooooo00Co410@o`000?l0
003o0000^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0
^_ooool00:_ooooo00Ko0000ogMgMol0003o0000oeEEEOo^k^jgooooo`00Zoooool01_l0003oEEEE
onk^k_ooooooMgMgoeEEEKOooooo002[ooooo`03o`000?o^k^kooooo00;ooooo00?o0000oooooooo
ool0]Oooool00:_ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`2eooooo`00Zooo
ool01_l0003oEEEEonk^k_ooooooMgMgofIVI[Oooooo002Zooooo`03oa0@4?l0003oMgMg00;o0000
00?oIVIVonk^k_ooool0]_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.61197 .68384 Mdot
.40254 .75265 Mdot
.50591 .48931 Mdot
.4211 .57649 Mdot
.51025 .2211 Mdot
.57164 .24789 Mdot
.50034 .36866 Mdot
.65916 .76604 Mdot
.70388 .4161 Mdot
.44389 .74036 Mdot
.47494 .21488 Mdot
.60375 .85489 Mdot
.5954 .22752 Mdot
.42833 .30505 Mdot
.59737 .85655 Mdot
.54247 .37771 Mdot
.61211 .47949 Mdot
.60727 .24872 Mdot
.50442 .77449 Mdot
.52642 .90498 Mdot
.60123 .24384 Mdot
.40082 .25337 Mdot
.43201 .13572 Mdot
.62304 .28226 Mdot
.45223 .98352 Mdot
.49707 .82171 Mdot
.5364 .31818 Mdot
.52935 .71938 Mdot
.48009 .95035 Mdot
.39911 .72809 Mdot
.62436 .29739 Mdot
.70775 .42555 Mdot
.69509 .66667 Mdot
.58196 .6836 Mdot
.43953 .83385 Mdot
.6298 .72129 Mdot
.47391 .04008 Mdot
.56933 .5697 Mdot
.44198 .92288 Mdot
.57024 .90402 Mdot
.43405 .96355 Mdot
.51803 .82023 Mdot
.41767 .22557 Mdot
.58137 .76291 Mdot
.63319 .61328 Mdot
.59372 .49069 Mdot
.41278 .47432 Mdot
.676 .31261 Mdot
.44095 .18937 Mdot
.5101 .92016 Mdot
.66861 .29743 Mdot
.37473 .57633 Mdot
.61668 .90647 Mdot
.3939 .57647 Mdot
.39362 .40695 Mdot
.71485 .53641 Mdot
.65246 .77704 Mdot
.61338 .48181 Mdot
.60463 .18199 Mdot
.63956 .57396 Mdot
.5928 .53137 Mdot
.55803 .06177 Mdot
.43705 .91308 Mdot
.49919 .28705 Mdot
.70011 .62975 Mdot
.71577 .48765 Mdot
.46438 .77142 Mdot
.51299 .29534 Mdot
.56592 .60035 Mdot
.6415 .32914 Mdot
.61209 .58062 Mdot
.44699 .63901 Mdot
.44124 .73095 Mdot
.52366 .69554 Mdot
.43771 .91422 Mdot
.44234 .48838 Mdot
.61616 .90709 Mdot
.57757 .62476 Mdot
.38862 .73815 Mdot
.39992 .49705 Mdot
.67131 .49139 Mdot
.41088 .78918 Mdot
.45093 .72471 Mdot
.49825 .8516 Mdot
.69728 .66823 Mdot
.55623 .43854 Mdot
.52541 .24854 Mdot
.55585 .32118 Mdot
.60812 .42603 Mdot
.51848 .30932 Mdot
.44585 .97594 Mdot
.76453 .54819 Mdot
.54774 .51242 Mdot
.5821 .40308 Mdot
.5419 .43332 Mdot
.76687 .50497 Mdot
.42097 .3492 Mdot
.66447 .29411 Mdot
.5937 .93556 Mdot
.61375 .45514 Mdot
.5887 .74085 Mdot
.58859 .34453 Mdot
.6123 .83902 Mdot
.55407 .81141 Mdot
.66894 .43957 Mdot
.56609 .72506 Mdot
.60353 .62169 Mdot
.45106 .78764 Mdot
.54765 .51993 Mdot
.64155 .33185 Mdot
.41213 .5279 Mdot
.42282 .60103 Mdot
.70455 .41199 Mdot
.6034 .7852 Mdot
.35237 .40846 Mdot
.42863 .53859 Mdot
.58686 .58417 Mdot
.71865 .55192 Mdot
.71842 .49865 Mdot
.43896 .07396 Mdot
.59024 .21989 Mdot
.53517 .14582 Mdot
.46265 .94916 Mdot
.6437 .33634 Mdot
.42011 .43595 Mdot
.58136 .82185 Mdot
.75908 .43027 Mdot
.5119 .86884 Mdot
.49439 .30467 Mdot
.4392 .11773 Mdot
.55307 .80788 Mdot
.56205 .91056 Mdot
.59058 .28341 Mdot
.47273 .12167 Mdot
.40821 .84248 Mdot
.45785 .04345 Mdot
.52903 .89846 Mdot
.44994 .75117 Mdot
.67784 .71221 Mdot
.58329 .87818 Mdot
.64983 .18154 Mdot
.49732 .73025 Mdot
.54586 .67933 Mdot
.61264 .48416 Mdot
.5657 .84984 Mdot
.70891 .62241 Mdot
.45328 .78532 Mdot
.57235 .37061 Mdot
.44624 .00395 Mdot
.57876 .31598 Mdot
.5744 .48179 Mdot
.63033 .29688 Mdot
.46418 .67966 Mdot
.61774 .36502 Mdot
.40442 .16742 Mdot
.40651 .82924 Mdot
.71772 .54178 Mdot
.46872 .04217 Mdot
.41537 .12568 Mdot
.41037 .68051 Mdot
.38487 .71166 Mdot
.42662 .95452 Mdot
.6578 .63201 Mdot
.40522 .2977 Mdot
.60307 .70271 Mdot
.71181 .60452 Mdot
.67463 .49047 Mdot
.57035 .57035 Mdot
.41457 .1258 Mdot
.56678 .84007 Mdot
.54493 .53236 Mdot
.57257 .48289 Mdot
.51629 .23435 Mdot
.42069 .68439 Mdot
.69398 .6631 Mdot
.76527 .48017 Mdot
.61139 .34583 Mdot
.44197 .64322 Mdot
.46998 .9488 Mdot
.38269 .29708 Mdot
.52696 .95559 Mdot
.55337 .58827 Mdot
.41519 .92162 Mdot
.535 .53096 Mdot
.69611 .38842 Mdot
.75546 .4173 Mdot
.71017 .42645 Mdot
.44707 .98623 Mdot
.45115 .13701 Mdot
.41793 .06058 Mdot
.5647 .8518 Mdot
.43851 .33214 Mdot
.51478 .01847 Mdot
.68214 .71226 Mdot
.36531 .61836 Mdot
.59115 .87119 Mdot
.5702 .35852 Mdot
.7507 .65059 Mdot
.56572 .73684 Mdot
.50264 .65906 Mdot
.49413 .68282 Mdot
.43638 .57501 Mdot
.48338 .18867 Mdot
.73769 .69232 Mdot
.57805 .76054 Mdot
.46144 .71793 Mdot
.59386 .29503 Mdot
.42174 .59533 Mdot
.50521 .68367 Mdot
.4966 .22928 Mdot
.52304 .12134 Mdot
.58185 .60603 Mdot
.67462 .49354 Mdot
.55878 .50561 Mdot
.59687 .71781 Mdot
.58878 .55351 Mdot
.42156 .94261 Mdot
.53255 .57023 Mdot
.64077 .50784 Mdot
.59547 .87088 Mdot
.58912 .56937 Mdot
.60649 .18852 Mdot
.67326 .46519 Mdot
.6706 .53784 Mdot
.54748 .40663 Mdot
.43071 .25849 Mdot
.41929 .82799 Mdot
.54603 .52436 Mdot
.59295 .86332 Mdot
.51171 .01112 Mdot
.50423 .27216 Mdot
.45879 .64765 Mdot
.73604 .69056 Mdot
.50751 .1844 Mdot
.5401 .32496 Mdot
.4447 .00989 Mdot
.57293 .52915 Mdot
.52896 .85115 Mdot
.54231 .15254 Mdot
.56524 .78698 Mdot
.55451 .05879 Mdot
.528 .17414 Mdot
.67209 .57849 Mdot
.61246 .57766 Mdot
.71261 .44457 Mdot
.52961 .37659 Mdot
.3842 .29607 Mdot
.57343 .31468 Mdot
.61375 .56785 Mdot
.42658 .89221 Mdot
.37273 .70943 Mdot
.43059 .56881 Mdot
.43299 .36429 Mdot
.40181 .18436 Mdot
.49736 .81868 Mdot
.57043 .45773 Mdot
.41973 .2111 Mdot
.44623 .42678 Mdot
.66657 .74492 Mdot
.64853 .25429 Mdot
.47667 .15375 Mdot
.53945 .32304 Mdot
.66803 .5735 Mdot
.44825 .32555 Mdot
.56517 .28626 Mdot
.62898 .61873 Mdot
.41651 .40287 Mdot
.51241 .15694 Mdot
.60642 .77105 Mdot
.44769 .81154 Mdot
.61014 .76836 Mdot
.4043 .29366 Mdot
.44148 .73555 Mdot
.41977 .26506 Mdot
.40125 .18064 Mdot
.54631 .62622 Mdot
.40613 .44875 Mdot
.67858 .32241 Mdot
.49001 .21948 Mdot
.61288 .34629 Mdot
.43477 .91398 Mdot
.52118 .37926 Mdot
.54903 .6024 Mdot
.46415 .04471 Mdot
.62895 .81317 Mdot
.44066 .76679 Mdot
.5091 .60659 Mdot
.41232 .37621 Mdot
.63007 .73283 Mdot
.58438 .42055 Mdot
.66676 .4467 Mdot
.7541 .41361 Mdot
.5821 .15195 Mdot
.62601 .81287 Mdot
.57748 .14814 Mdot
.45108 .36571 Mdot
.57284 .13589 Mdot
.65194 .67584 Mdot
.60941 .8385 Mdot
.40708 .3446 Mdot
.4843 .1191 Mdot
.53797 .83362 Mdot
.71095 .43845 Mdot
.46049 .99138 Mdot
.42035 .36025 Mdot
.67261 .30985 Mdot
.47497 .8354 Mdot
.52619 .51649 Mdot
.5074 .10343 Mdot
.61339 .51782 Mdot
.57098 .1903 Mdot
.41733 .05894 Mdot
.42835 .47094 Mdot
.6394 .54564 Mdot
.55359 .75367 Mdot
.69139 .66357 Mdot
.46285 .29281 Mdot
.51917 .96371 Mdot
.37031 .32114 Mdot
.69547 .25223 Mdot
.45954 .25179 Mdot
.59919 .3008 Mdot
.48509 .86544 Mdot
.39963 .7958 Mdot
.44604 .21293 Mdot
.5114 .63153 Mdot
.47407 .32778 Mdot
.61024 .58285 Mdot
.62266 .83043 Mdot
.39026 .25241 Mdot
.54165 .4292 Mdot
.46403 .08386 Mdot
.50919 .34241 Mdot
.43559 .5658 Mdot
.41261 .80312 Mdot
.56072 .22713 Mdot
.40692 .28596 Mdot
.41111 .68508 Mdot
.46284 .19259 Mdot
.65055 .86169 Mdot
.48504 .83002 Mdot
.44741 .88467 Mdot
.49665 .28314 Mdot
.70809 .60525 Mdot
.52167 .28312 Mdot
.546 .87507 Mdot
.3883 .62462 Mdot
.53058 .63859 Mdot
.58738 .45603 Mdot
.64797 .17814 Mdot
.60742 .85076 Mdot
.57512 .1372 Mdot
.61793 .74945 Mdot
.40007 .43404 Mdot
.57877 .70234 Mdot
.57546 .82741 Mdot
.5399 .23689 Mdot
.60957 .84706 Mdot
.71222 .28103 Mdot
.66989 .59432 Mdot
.56942 .90052 Mdot
.50822 .97564 Mdot
.40822 .90329 Mdot
.43977 .39239 Mdot
.47488 .15559 Mdot
.5817 .87968 Mdot
.66126 .75813 Mdot
.44858 .34896 Mdot
.6586 .39863 Mdot
.49632 .81612 Mdot
.60239 .31301 Mdot
.59723 .72144 Mdot
.6762 .32267 Mdot
.53388 .84342 Mdot
.52225 .07663 Mdot
.37443 .51432 Mdot
.4168 .18212 Mdot
.54988 .10464 Mdot
.4223 .16092 Mdot
.49519 .98439 Mdot
.3774 .15077 Mdot
.47633 .04348 Mdot
.62876 .4032 Mdot
.48683 .67446 Mdot
.36492 .58704 Mdot
.6064 .41257 Mdot
.46479 .33464 Mdot
.5096 .97593 Mdot
.64462 .33795 Mdot
.51398 .62231 Mdot
.50631 .73669 Mdot
.54642 .72668 Mdot
.55218 .36207 Mdot
.68657 .33893 Mdot
.67766 .5022 Mdot
.49792 .00294 Mdot
.51644 .9675 Mdot
.60254 .61425 Mdot
.677 .81734 Mdot
.59044 .66517 Mdot
.42528 .709 Mdot
.40597 .51567 Mdot
.51009 .5555 Mdot
.63494 .80871 Mdot
.60933 .84626 Mdot
.53237 .30766 Mdot
.53725 .60525 Mdot
.55835 .37446 Mdot
.56069 .50771 Mdot
.37268 .28078 Mdot
.57903 .38648 Mdot
.65821 .63478 Mdot
.48449 .74621 Mdot
.57445 .49097 Mdot
.47152 .28689 Mdot
.55751 .3193 Mdot
.593 .64769 Mdot
.56398 .40387 Mdot
.44599 .68664 Mdot
.67965 .70836 Mdot
.44781 .47408 Mdot
.41956 .77581 Mdot
.60351 .62141 Mdot
.62995 .42173 Mdot
.46998 .83057 Mdot
.57373 .51981 Mdot
.36285 .51487 Mdot
.76718 .55929 Mdot
.51305 .87245 Mdot
.3777 .84022 Mdot
.56153 .80084 Mdot
.42522 .56099 Mdot
.70614 .43925 Mdot
.57117 .89348 Mdot
.48436 .21871 Mdot
.38995 .64221 Mdot
.64204 .8733 Mdot
.53118 .63145 Mdot
.52671 .53382 Mdot
.40972 .58976 Mdot
.6691 .57094 Mdot
.4054 .62518 Mdot
.75942 .60504 Mdot
.52627 .60455 Mdot
.421 .77743 Mdot
.52103 .81697 Mdot
.53156 .37898 Mdot
.42861 .52116 Mdot
.53124 .67724 Mdot
.6587 .76629 Mdot
.44153 .34744 Mdot
.401 .81047 Mdot
.43638 .8711 Mdot
.63592 .5899 Mdot
.59656 .79524 Mdot
.65777 .39944 Mdot
.61009 .57056 Mdot
.7626 .43794 Mdot
.49397 .76105 Mdot
.61656 .84023 Mdot
.37195 .70359 Mdot
.41623 .40877 Mdot
.57524 .13826 Mdot
.4588 .82491 Mdot
.60264 .41524 Mdot
.54971 .87026 Mdot
.58568 .74845 Mdot
.4879 .79836 Mdot
.58846 .46484 Mdot
.58179 .68608 Mdot
.56816 .07001 Mdot
.45525 .13465 Mdot
.44211 .51277 Mdot
.3986 .35136 Mdot
.40103 .43393 Mdot
.43767 .4057 Mdot
.47102 .2438 Mdot
.39589 .61098 Mdot
.46774 .12175 Mdot
.45737 .6906 Mdot
.52656 .76624 Mdot
.71598 .49305 Mdot
.50418 .20969 Mdot
.63551 .57953 Mdot
.55444 .65543 Mdot
.53641 .69829 Mdot
.48825 .31463 Mdot
.35059 .49253 Mdot
.49729 .33289 Mdot
.40741 .77911 Mdot
.60267 .1856 Mdot
.65418 .64866 Mdot
.55917 .63187 Mdot
.50586 .92733 Mdot
.55645 .91995 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool009[ooooo0_l00008ooooo`03o`000?oooooooooo00Co
oooo0_l0002kooooo`00V_ooool2o`0000Sooooo00?o0000ooooooooool01?ooool2o`000;_ooooo
002Iooooo`;o00002Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo002I
ooooo`;o00002Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o0000]oooool0
0:;ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`02o`000;Oooooo002/ooooo`04
o`000?ooooooooooooooo`;o0000]_ooool00:cooooo00Co0000oooooooooooooooo0_l0002foooo
o`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002Sooooo`;o00001oooool00ol0003oooooooooo`2iooooo`00W_ooool2o`000003oooo
ool0003o000000?o00001_ooool00ol0003oooooooooo`2iooooo`00W_ooool5o`000003ooooool0
003o000000Kooooo00?o0000ooooooooool0^Oooool00:3ooooo0_l0000:ooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool0093ooooo
0_l0000Jooooo`03o`000?oooooooooo00oooooo0_l0002Xooooo`00T?ooool2o`0001[ooooo00?o
0000ooooooooool03oooool3o`000:Oooooo002@ooooo`;o00006_ooool00ol0003oooooooooo`0@
ooooo`;o0000Yoooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool04oooool2o`000:Cooooo002Gooooo`;o00004oooool00ol0003oooooooooo`0Cooooo`;o0000
Y?ooool009Oooooo0_l0000Cooooo`?o00001?ooool2o`000;?ooooo002/ooooo`03o`000?oooooo
oooo00Cooooo0_l0002cooooo`00[?ooool00ol0003oooooooooo`2iooooo`00X?ooool2o`0000[o
oooo00?o0000ooooooooool0^Oooool00:3ooooo0_l0000:ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00Co0000ooooool0003o
00003?ooool2o`000:[ooooo002/ooooo`04o`000?oooooo0000o`0000cooooo0_l0002Zooooo`00
[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B42
ooooo`;o00000_ooool00ol0003ok^k^ooooo`04ooooo`04odA4A?l0003o0000oc8b<P;o00001?oo
ool00ol0003oooooooooo`2iooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B42ooooo`;o00000_ooool00omEEEGoZJVYooooo`03ooooo`Co000000?oMgMgo`000?l000001?oo
ool00ol0003oooooooooo`04ooooo`;o0000/oooool0087ooooo1_l00002ooooo`06oa0@4?oooooo
ooooooooool@413ooooo0ol00009ooooo`03ojVYZOmEEEGooooo00?ooooo1?l000000ooooooo0000
ooooo`04ooooo`?o00001?ooool2o`000;?ooooo0029ooooo`06o`000?ooooooooooooooool0003o
oooo0ol0000:ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`2iooooo`00ROooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?oo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0^Oooool008Wo
oooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOl0003o000000?ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`2iooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Oooooo0_l00002ooooo`03oa0@4?oooooo000000?o00000oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo01Gooooo0_l0002Rooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Oooooo0_l00002ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool05Oooool2o`00
0:;ooooo002/ooooo`03o`000?oooooooooo01Gooooo0_l0002Rooooo`00[?ooool00ol0003ooooo
ooooo`08ooooo`;o0000[oooool00:cooooo00?o0000ooooooooool02?ooool2o`0000cooooo0_l0
002Qooooo`00Poooool2o`0002Oooooo0ol0000;ooooo`;o00002Oooool4o`0009oooooo0023oooo
o`;o00007_ooool3o`0000Kooooo00?o0000ooooooooool02oooool2o`0000_ooooo0_l0002Ooooo
o`00Xoooool3o`0000Kooooo00Co0000oooooooooooooooo0_l0002fooooo`00T_ooool2o`0001So
oooo00Co0000oooooooooooooooo0_l0002fooooo`00T_ooool2o`0001Sooooo00?o0000oooooooo
ool0^Oooool008cooooo0_l0000Nooooo`03o`000?oooooooooo0;Wooooo002<ooooo`;o00007_oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`06ooooo`;o0000/Oooool0
0:cooooo0ol00006ooooo`;o0000/Oooool00:cooooo00?o0000ooooooooool0;Oooool2o`0008[o
oooo002;ooooo`;o00000oooool2o`0001[ooooo00?o0000ooooooooool07oooool2o`0000cooooo
0ol00029ooooo`00Roooool2o`0000?ooooo0_l0000Jooooo`04o`000?oooooo0000o`0001gooooo
0ol0000=ooooo`;o0000ROooool008_ooooo0_l0000;ooooo`;o00003?ooool2o`0000Cooooo00Co
0000ooooool0003o00007Oooool4o`0009Oooooo002Hooooo`;o00003?ooool2o`0000Cooooo00?o
0000ooooooooool05?ooool2o`0000[ooooo0_l0002Gooooo`00Woooool2o`0000_ooooo00?o0000
ooooooooool05?ooool2o`000:?ooooo002Oooooo`;o00002oooool00ol0003oooooooooo`2ioooo
o`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`?o0000^Oooool0097ooooo0_l00007ooooo`;o00004?ooool3o`00
0;Wooooo002Aooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`03o`000?oooooooooo0;Wo
oooo002Sooooo`;o000000?oooooo`000?l000000_l00002ooooo`03o`000?oooooooooo0;Wooooo
002Vooooo`Co00000_ooool00ol0003oooooooooo`02o`0001Sooooo0_l0002Mooooo`00T?ooool2
o`0001[ooooo1Ol0000Hooooo`;o0000WOooool0093ooooo0_l0000Jooooo`03o`000?oooooooooo
017ooooo0_l00009ooooo`;o0000Voooool00:[ooooo0ol0000Cooooo`;o00002Oooool2o`0009_o
oooo002Zooooo`?o00001?ooool2o`000;Gooooo002/ooooo`03o`000?oooooooooo00;ooooo0_l0
0006ooooo`;o0000[Oooool00:cooooo00?o0000ooooooooool02_ooool2o`000:gooooo002Aoooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo0ol000000olb<S;ogMgMooooo`04
ooooo`03o`000?oooooooooo01kooooo0_l0002Iooooo`00TOooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B45ooooo`;o000000?oooooogMgMolb<S801Oooool00ol0003oooooooooo`0N
ooooo`;o0000VOooool008Wooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo0_l0000=ooooo`;o00002_ooool2
o`0009Oooooo0027ooooo`;o00002?ooool01Ol0003ooooooooooooooooo000000Sooooo0_l00005
ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00005ooooo`;o00003Oooool2o`0000[ooooo0_l0000K
ooooo`;o0000N_ooool008Oooooo0_l00002ooooo`;o00001?ooool01Ol0003ooooooooooooooooo
000000Sooooo0_l00002ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`0^ooooo`;o00003Oooool2o`0007[ooooo002;ooooo`;o00001?ooool01?l@413ooooooooooooo
ool2o`0000_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0^ooooo`;o0000ROoo
ool0097ooooo00CoMgMgoiRHV?ooooooV9RH0_l0000;ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0^Oooool0097ooooo0ol000000olb<S;ok^k^ooooo`0;ooooo`Co00001_ooool0
0ol0003oooooooooo`2iooooo`00TOooool2o`0001Wooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00[?ooool3o`000;Wooooo002/
ooooo`03o`000?oooooooooo0;Wooooo0022ooooo`;o00009_ooool3o`0000Kooooo0_l0000Doooo
o`;o00002Oooool2o`0001cooooo0_l0001dooooo`00P_ooool2o`0000Wooooo0_l0000Kooooo`?o
00001_ooool2o`0000cooooo0_l00006ooooo`;o00002Oooool2o`0001cooooo0_l0001dooooo`00
SOooool2o`0001?ooooo0_l00007ooooo`;o00005?ooool2o`000:Gooooo002Rooooo`;o00001ooo
ool2o`000;_ooooo002<ooooo`;o00004Oooool2o`0000_ooooo00Co0000oooooooooooooooo0_l0
000Iooooo`;o00005Oooool2o`0008Cooooo0025ooooo`;o00001Oooool2o`00017ooooo0_l0000;
ooooo`04o`000?ooooooooooooooo`;o00006Oooool2o`0000Sooooo1?l00009ooooo`?o0000Pooo
ool008Gooooo0_l00005ooooo`;o00007_ooool3o`0001gooooo0_l00007ooooo`Co00002_ooool2
o`0008?ooooo002/ooooo`03o`000?oooooooooo01gooooo0_l0002Jooooo`00U?ooool2o`0001Co
oooo0ol0002kooooo`00U?ooool2o`0001Cooooo0ol00005ooooo`;o00000_ooool2o`0002gooooo
0_l00021ooooo`00[?ooool00ol0003oooooooooo`03ooooo`;o00000_ooool2o`0001Gooooo0_l0
000Fooooo`?o0000P?ooool00:Sooooo0_l00002ooooo`03o`000?oooooooooo01Gooooo1?l00005
ooooo`;o00005oooool2o`00083ooooo002Xooooo`;o00000_ooool00ol0003oooooooooo`09oooo
o`;o00001Oooool2o`0000?ooooo1?l0002Pooooo`00POooool2o`0002Wooooo00?o0000oooooooo
ool02Oooool2o`0000Cooooo0ol0000Uooooo`?o0000Ooooool0087ooooo0_l0000Gooooo`;o0000
4?ooool3o`0000[ooooo0_l00003ooooo`;o00009_ooool3o`0007oooooo002Jooooo`;o00001ooo
ool2o`0000Oooooo00?o0000ooooooooool02_ooool2o`000:gooooo002Sooooo`;o00001oooool0
0ol0003oooooooooo`0[ooooo`;o0000S?ooool009Oooooo0_l00007ooooo`;o00002Oooool2o`00
02gooooo0_l0002<ooooo`00Uoooool2o`0000Oooooo0_l00009ooooo`;o0000;_ooool2o`0008_o
oooo002/ooooo`03o`000?oooooooooo02cooooo0_l0000<ooooo`;o0000OOooool00:cooooo00?o
0000ooooooooool00_l0000Zooooo`;o00003?ooool2o`0007gooooo002=ooooo`;o00007Oooool0
0ol0003oooooooooo`02o`0001Sooooo0_l00005ooooo`?o0000UOooool008gooooo0_l00002oooo
o`;o00001Oooool2o`000003ooooool0003o000000oooooo00?o0000ooooooooool06_ooool2o`00
00Gooooo0ol0002Eooooo`00R_ooool2o`0000Gooooo0_l00005ooooo`;o000000?oooooo`000?l0
00003oooool3o`000;Wooooo002:ooooo`;o00008?ooool00ol0003oooooooooo`2iooooo`00[?oo
ool00ol0003oooooooooo`0Dooooo`;o0000Xoooool0097ooooo0_l0000Iooooo`03o`000?oooooo
oooo00kooooo0_l00004ooooo`;o0000Xoooool0097ooooo0_l00002ooooo`;o00005Oooool00ol0
003oooooooooo`0>ooooo`;o00004oooool2o`0009Cooooo0029ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@;o00000_ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo02?ooooo0_l0002Dooooo`00ROooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7o0000o`000?m4A4@01oooool00omgMgOo<S8boooo
o`04ooooo`;o00005Oooool2o`000:?ooooo0021ooooo`Ko00000_ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`;o00005Ooo
ool2o`000:?ooooo0029ooooo`06o`000?ooooooooooooooool0003ooooo0_l0000:ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0000Kooooo0_l00008ooooo`;o0000
Yoooool008Wooooo00Ko0000ooooooooooooooooo`000?ooool2o`0000_ooooo00?oMgMgofIVI_oo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool01?ooool5o`00
00;ooooo0_l00003ooooo`;o0000Yoooool008Wooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04oooo
o`;o000000?oooooo`000?l000000_ooool2o`000:cooooo0029ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`2iooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`0Gooooo`;o00009?oo
ool2o`0007[ooooo002Hooooo`;o00004_ooool00ol0003oooooooooo`0Gooooo`;o00009?ooool2
o`0007[ooooo002Hooooo`;o00004_ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool3o`00037ooooo0_l00026ooooo`00T?ooool2o`0001[ooooo00?o
0000ooooooooool04_ooool2o`0000Cooooo0_l0000=ooooo`;o00002?ooool2o`0008Kooooo0028
ooooo`;o00001_ooool2o`0000Gooooo0_l0000Cooooo`03o`000?oooooooooo00cooooo0_l00004
ooooo`;o00001?ooool2o`0000gooooo0_l0002@ooooo`00Noooool2o`0000_ooooo0_l00006oooo
o`;o00001Oooool2o`0001?ooooo00?o0000ooooooooool03?ooool2o`000:_ooooo001kooooo`;o
00004oooool2o`0001[ooooo00?o0000ooooooooool08?ooool2o`0001kooooo0_l0000>ooooo`;o
0000Ioooool00:cooooo00?o0000ooooooooool07_ooool4o`0001kooooo0_l0000>ooooo`;o0000
Ioooool00:cooooo00?o0000ooooooooool07_ooool2o`00023ooooo0_l0000?ooooo`;o0000I_oo
ool00:cooooo00?o0000ooooooooool06?ooool2o`0000gooooo0_l0000Xooooo`;o0000I_ooool0
0:cooooo0ol0000Hooooo`;o00003Oooool2o`0001Sooooo0_l0001fooooo`00V_ooool2o`00013o
oooo00?o0000ooooooooool08?ooool2o`0001oooooo0ol0001eooooo`00V_ooool2o`00013ooooo
00?o0000ooooooooool02_ooool2o`0001Cooooo0_l0000Pooooo`;o00003_ooool2o`0006Gooooo
002;ooooo`;o00007oooool00ol0003oooooooooo`0:ooooo`;o0000A_ooool2o`0006Gooooo002;
ooooo`;o00001?ooool2o`0001Wooooo00?o0000ooooooooool02_ooool2o`000:gooooo002Aoooo
o`;o00006Oooool00ol0003oooooooooo`0?ooooo`;o00008oooool2o`0000_ooooo0ol0000?oooo
o`;o0000I?ooool00:cooooo00?o0000ooooooooool03oooool2o`0002?ooooo0_l0000;ooooo`?o
00003oooool2o`0006Cooooo002/ooooo`03o`000?oooooooooo03Cooooo0_l0000=ooooo`;o0000
M?ooool008gooooo0_l0000Mooooo`03o`000?oooooooooo03Cooooo0_l0000=ooooo`;o0000M?oo
ool008gooooo0_l0000Mooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool06Oooool2o`00
00Oooooo0_l0002Eooooo`00[?ooool00ol0003oooooooooo`0Dooooo`;o00000oooool2o`0000Oo
oooo0_l0002Eooooo`002Oooool4o`000003oa0@4?oooooooooo01Kooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b
<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000
1?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Kooooo00?o0000ooooooooool05?ooool2o`0000;o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00Go
A4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1?l000000ol@
413oooooooooo`0Booooo`002oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`0>oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1oooool00omgMgOo<S8booooo`0Eooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?l0003o
0000ogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b
<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYoooo
o`07ooooo`03ogMgMolb<S;ooooo01Wooooo00?o0000ooooooooool05?ooool000Ko00001Oooool0
0ol0003oooooooooo`0@ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00gooooo00?o
ZJVYoeEEEOooool02?ooool00ol0003oooooooooo`05ooooo`Ko00000_ooool01Ol@413ooooooooo
oooooooo410@013ooooo00?o0000ooooooooool01Oooool6o`0000;ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0Hooooo`05oa0@4?oooooo0000o`000?l@41003?ooool00onHV9So8B4Qonk^kP09oooo
o`?o00003Oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool03Oooool0
1Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool03_oo
ool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooo
oooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool2o`0001Kooooo00?o0000oooooooo
ool06?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool01?mg
MgOo<S8bo`000?l0000=ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8boooo
o`0>ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMg
Molb<S;ooooo01Wooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?oo
ool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00ooo
ool00ol0003o8B4Qo`000002o`0000Cooooo0_l0000@ooooo`03o`000?oooooooooo01Sooooo00Go
0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00oooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c00Jooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oo
oooooooo01Sooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo
00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooooooo
ool04Oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00ol00008oooo
o`;o00004?ooool3o`0001Sooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o
0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool0
0oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oo
oooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb
<S801?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0
003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonH
V9So410@00;ooooo0ol0000Jooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o00001?ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooooooo
ool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo0ol0000Cooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Dooooo`002Oooool00omEEEGoIVIVo`00000Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0001Oooooo00?o0000ooooooooool05Oooool2o`000006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^1Oooool2o`0000Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co0000
4?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00[ooooo1_l0000@ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool5o`0000Cooooo1?l0000Iooooo`03oeEEEOmVIVKo000001Kooooo002/ooooo`03
o`000?oooooooooo01Gooooo0_l0000;ooooo`;o0000UOooool009Wooooo0_l0000Aooooo`04o`00
0?oooooo0000o`00027ooooo0_l0000Pooooo`;o0000Loooool009Wooooo0_l0000Aooooo`04o`00
0?oooooo0000o`0001Cooooo0_l00005ooooo`;o00005oooool3o`0000cooooo0_l0001Xooooo`;o
00000_ooool2o`0000Gooooo001jooooo`;o0000<?ooool00ol0003oooooooooo`0Eooooo`;o0000
1Oooool2o`0001Oooooo0ol0000<ooooo`;o0000J?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgM
g@Gooooo001jooooo`;o00003oooool2o`0001oooooo00?o0000ooooooooool0=_ooool2o`0000co
oooo0_l0001Yooooo`04omgMgOl0003o410@olc<c0Kooooo0007oooooooo0000C?l0000<ooooo`04
onk^k_lQ8B7o410@onk^kPKooooo0007ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`03ooooo`;o
000000?oooooo`000?ooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[o
oooo00Co8B4QogMgMomgMgOo<S8b1_ooool000Oooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0@ooooo`;o00005Oooool00ol0003oooooooooo`0=ooooo`;o00005oooool00ol0003o
ooooooooo`02ooooo`;o00008_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Wo
oooo0_l00002ooooo`;o00001Oooool00:cooooo00?o0000ooooooooool04?ooool3o`0001Sooooo
0_l0000Xooooo`;o0000H_ooool009Sooooo0_l0000Booooo`03o`000?oooooooooo00cooooo0_l0
0003ooooo`;o00006?ooool2o`0008cooooo001nooooo`;o00000_ooool2o`0000Wooooo0_l00009
ooooo`;o00004_ooool00ol0003oooooooooo`05ooooo`;o00001Oooool2o`000:_ooooo001noooo
o`;o00000_ooool2o`0000Wooooo0_l0000Mooooo`03o`000?oooooooooo00Gooooo0_l0000Koooo
o`;o0000UOooool009Cooooo0_l0000Fooooo`03o`000?oooooooooo00cooooo0_l00007ooooo`;o
00002oooool2o`0009Gooooo002Dooooo`;o00005_ooool3o`0000cooooo0_l00007ooooo`;o0000
X_ooool008oooooo0_l0000Kooooo`03o`000?oooooooooo00cooooo0_l0002[ooooo`00Soooool2
o`0001_ooooo00?o0000ooooooooool02?ooool2o`0000_ooooo0_l00004ooooo`;o0000W?ooool0
0:cooooo00?o0000ooooooooool01Oooool2o`000004ooooool0003o0000ooooo`;o00002?ooool2
o`0000Cooooo0_l0002Looooo`00[?ooool00ol0003oooooooooo`05ooooo`;o00001?ooool2o`00
02Sooooo0_l0000<ooooo`;o0000M?ooool009Cooooo0_l0000Fooooo`03o`000?oooooooooo03Go
oooo0_l0000<ooooo`;o0000M?ooool009Cooooo0_l0000Fooooo`03o`000?oooooooooo04Cooooo
0_l0001cooooo`00[?ooool00ol0003oooooooooo`0[ooooo`;o00005oooool2o`0007?ooooo002/
ooooo`03o`000?oooooooooo02_ooooo0_l0000Wooooo`;o0000Hoooool00:cooooo0ol00015oooo
o`;o00003Oooool2o`0006?ooooo002/ooooo`03o`000?oooooooooo00;o00006?ooool2o`0002Wo
oooo0_l0001booooo`00[?ooool00ol0003oooooooooo`02o`0001Sooooo0_l0002Mooooo`00Tooo
ool2o`0001Oooooo00?o0000ooooooooool0EOooool2o`0006;ooooo002Cooooo`;o00005oooool0
0ol0003oooooooooo`1Eooooo`;o0000H_ooool009Kooooo0_l0000Dooooo`03o`000?oooooooooo
02;ooooo0_l0002Eooooo`00UOooool3o`0001Cooooo00?o0000ooooooooool01oooool2o`0000[o
oooo0ol00004ooooo`;o00001Oooool3o`00013ooooo0_l00023ooooo`00UOooool2o`0001Gooooo
00?o0000ooooooooool01oooool2o`0000[ooooo0ol00004ooooo`;o00001Oooool2o`0000Sooooo
0_l00007ooooo`;o0000Poooool008;ooooo0_l00005ooooo`;o00001oooool2o`0000?ooooo0_l0
000Cooooo`?o0000:oooool2o`0000Oooooo0_l00023ooooo`00P_ooool2o`0000Gooooo0_l00007
ooooo`;o00000oooool2o`0001?ooooo00?o0000ooooooooool08_ooool2o`0000Gooooo0_l0000:
ooooo`;o0000P_ooool00:cooooo00?o0000ooooooooool08Oooool3o`0000Gooooo0_l0000:oooo
o`;o0000P_ooool00:cooooo00?o0000ooooooooool06Oooool2o`0000Kooooo0ol0002Eooooo`00
Ooooool2o`0002_ooooo00?o0000ooooooooool03_ooool2o`0000Wooooo0_l0002Nooooo`00Oooo
ool2o`0000gooooo0_l0000Looooo`03o`000?oooooooooo00kooooo0_l0000Iooooo`;o0000S_oo
ool008kooooo0_l00002ooooo`;o00006?ooool00ol0003oooooooooo`0Yooooo`;o00002_ooool2
o`0008;ooooo002Booooo`;o00006?ooool00ol0003oooooooooo`0eooooo`;o0000P_ooool009;o
oooo0_l0000Hooooo`?o00004_ooool2o`000:Gooooo002Booooo`;o00006?ooool00ol0003ooooo
ooooo`0=ooooo`;o00000oooool2o`000:Gooooo002/ooooo`03o`000?oooooooooo00;o00000ooo
ool2o`0000;ooooo0_l00002ooooo`;o00002Oooool2o`0002Oooooo0ol0000>ooooo`;o0000IOoo
ool00:cooooo00?o0000ooooooooool00_l00003ooooo`;o00000_ooool2o`0000gooooo0_l0000W
ooooo`?o00003_ooool2o`0006Gooooo0029ooooo`;o00008Oooool00ol0003oooooooooo`0Yoooo
o`;o0000S_ooool008Wooooo0_l0000Qooooo`03o`000?oooooooooo01kooooo0_l00009ooooo`;o
0000S_ooool007oooooo0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Noooo
o`;o00001oooool2o`00093ooooo001oooooo`;o00002?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04
ooooo`04o`000?ooooooooooooooo`;o00007?ooool2o`0000Kooooo0_l0000Iooooo`;o0000MOoo
ool008Oooooo0_l000000ol@413oooooooooo`02o`0000cooooo00?oV9RHob4Q8Oo^k^h02Oooool0
0ol0003oooooooooo`03ooooo`?o000000?oooooo`000?l000004oooool2o`0000Oooooo0_l0000Q
ooooo`;o0000MOooool008Oooooo0ol00002ooooo`;o00003Oooool00onHV9So8B4Qonk^kP07oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool03?ooool2o`0000Sooooo0_l0002Qoooo
o`00ROooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool00_l00005ooooo`;o00000oooool2
o`00037ooooo0_l0001hooooo`00ROooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;o00001Oooool2
o`0000Oooooo0_l0000Oooooo`;o00003?ooool2o`0007Sooooo0029ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0@ooooo`;o00007oooool2o`0008Kooooo0029ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool01OnHV9So0000o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`00
0?oooooooooo00Oooooo0_l0002`ooooo`00Qoooool2o`0000oooooo1?l0000@ooooo`03o`000?oo
oooooooo00Oooooo0_l0002`ooooo`00Qoooool2o`0000oooooo0_l0000Booooo`03o`000?oooooo
oooo0;Wooooo002Nooooo`;o00003?ooool00ol0003oooooooooo`0Kooooo`;o00004_ooool2o`00
08Sooooo002Nooooo`;o00003?ooool3o`0001_ooooo0_l0000Booooo`;o00007_ooool2o`0006So
oooo002/ooooo`03o`000?oooooooooo00oooooo0_l0000nooooo`;o0000J?ooool00:cooooo00?o
0000ooooooooool03oooool2o`000:Sooooo002/ooooo`;o0000^_ooool00:cooooo0_l0000moooo
o`?o0000N_ooool00:cooooo00?o0000ooooooooool06_ooool2o`00023ooooo0ol0001jooooo`00
[?ooool00ol0003oooooooooo`0Jooooo`;o00008Oooool3o`0007Wooooo002/ooooo`03o`000?oo
oooooooo03kooooo0_l0001iooooo`00Yoooool2o`0000?ooooo0ol0000_ooooo`;o0000R?ooool0
0:3ooooo0_l00005ooooo`;o00000oooool00ol0003oooooooooo`07ooooo`;o00000oooool2o`00
027ooooo0_l00028ooooo`00S_ooool2o`00013ooooo0_l00008ooooo`?o00002Oooool2o`0000?o
oooo0_l0002[ooooo`00S_ooool2o`000003ooooool0003o000001Oooooo1Ol0000Hooooo`;o0000
2?ooool2o`0009Gooooo002>ooooo`;o000000?oooooo`000?l000001oooool2o`00013ooooo0ol0
000Hooooo`;o00002?ooool2o`0009Gooooo002Jooooo`;o000000?oooooo`000?l000003Oooool0
0ol0003oooooooooo`1:ooooo`?o0000K?ooool009gooooo0_l0000=ooooo`03o`000?oooooooooo
04[ooooo0ol0001/ooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o00000oooool2o`000:ko
oooo002/ooooo`?o00001?ooool2o`0000?ooooo0_l0002^ooooo`00POooool2o`0002Wooooo00?o
0000ooooooooool05oooool2o`0000Kooooo0_l0002Hooooo`00POooool2o`0002Wooooo00?o0000
ooooooooool05oooool2o`0000Kooooo0_l0002Hooooo`00P_ooool2o`0000oooooo0_l0000Goooo
o`03o`000?oooooooooo03Sooooo0_l0001oooooo`00P_ooool2o`0000;ooooo0_l0000;ooooo`;o
00005oooool00ol0003oooooooooo`0gooooo`Co0000O_ooool008Kooooo0_l0000Tooooo`03o`00
0?oooooooooo03Oooooo1?l0001nooooo`00Woooool2o`0000_ooooo00?o0000ooooooooool01_oo
ool2o`0001Gooooo0_l0002Jooooo`00Woooool2o`0000_ooooo00?o0000ooooooooool01_ooool2
o`0001Gooooo0_l00008ooooo`;o0000T?ooool009_ooooo0_l0000?ooooo`?o00004_ooool2o`00
00Wooooo0_l00008ooooo`;o0000T?ooool008[ooooo0_l0000?ooooo`;o00003oooool00ol0003o
ooooooooo`0<ooooo`;o00001?ooool2o`000:Gooooo002:ooooo`;o00003?ooool2o`00017ooooo
0_l0000>ooooo`;o0000Zoooool009Sooooo0_l0000Aooooo`;o0000:_ooool2o`0008oooooo002H
ooooo`;o00004_ooool01?l0003oooooo`000?l0000Aooooo`;o00005?ooool2o`0008oooooo0027
ooooo`;o00003oooool3o`00017ooooo00Co0000ooooool0003o00004Oooool2o`000:Gooooo0027
ooooo`;o00002?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo0_l00002ob4Q8@Gooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01[ooooo0_l0002Mooooo`00TOoo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMol0003o000000Cooooo
00?o0000ooooooooool06_ooool2o`0001Sooooo0_l00023ooooo`00TOooool01Ol@413ooooooooo
oooooooo410@013ooooo0_l00004ooooo`03o`000?oooooooooo01Wooooo0_l00008ooooo`;o0000
3oooool2o`0008?ooooo002;ooooo`;o00001?ooool01Ol0003ooooooooooooooooo000000Gooooo
0_l00008ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Iooooo`;o00002?ooool2o`0009Cooooo
002;ooooo`;o00001?ooool01Ol0003ooooooooooooooooo000000Gooooo0_l00005ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0>ooooo`;o0000ZOooool0097ooooo
00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool03_ooool2o`0002;ooooo0_l00025ooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00co
oooo00?o0000ooooooooool01Oooool3o`0001Sooooo0_l0000Jooooo`;o0000QOooool0097ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001?ooool3o`0001Sooooo0ol0002Pooooo`00
V?ooool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`00013ooooo0_l0000Hooooo`;o0000
Q_ooool009Sooooo0_l0000Booooo`03o`000?oooooooooo00Gooooo0_l0000Iooooo`?o00003_oo
ool2o`0008Kooooo002Pooooo`;o00002_ooool00ol0003oooooooooo`0Pooooo`?o0000U_ooool0
097ooooo0_l0000=ooooo`;o00002_ooool3o`0002oooooo0_l00028ooooo`00SOooool2o`0000;o
oooo0_l0000Iooooo`?o0000;oooool2o`0008Sooooo002=ooooo`;o00000_ooool2o`0001Wooooo
00?o0000ooooooooool0^Oooool009cooooo0_l0000>ooooo`03o`000?oooooooooo01oooooo0_l0
002Hooooo`00S_ooool2o`0000_ooooo0ol0000>ooooo`03o`000?oooooooooo01;ooooo0_l0000;
ooooo`;o0000V?ooool008kooooo0_l0000;ooooo`;o00003oooool00ol0003oooooooooo`0Boooo
o`;o0000YOooool00:cooooo00?o0000ooooooooool07?ooool2o`0009_ooooo002:ooooo`;o0000
7?ooool2o`0000;ooooo00?o0000ooooooooool07?ooool2o`0009_ooooo002:ooooo`;o00007?oo
ool2o`0000;ooooo0ol0000Aooooo`;o0000Y_ooool008oooooo0_l0000Kooooo`03o`000?oooooo
oooo017ooooo0_l0002Vooooo`00Soooool2o`0001_ooooo00?o0000ooooooooool0^Oooool008_o
oooo0_l0000Oooooo`03o`000?oooooooooo00kooooo0_l0000Iooooo`;o0000S_ooool008_ooooo
0_l0000=ooooo`;o00004?ooool00ol0003oooooooooo`0>ooooo`;o00005_ooool5o`0008kooooo
002Jooooo`;o00003_ooool3o`00013ooooo0_l0000Fooooo`?o0000T?ooool00:[ooooo0ol00006
ooooo`;o0000<Oooool2o`00083ooooo002[ooooo`;o00001Oooool3o`00017ooooo0_l0000Noooo
o`;o0000P?ooool009kooooo0_l0000;ooooo`Co00000oooool2o`0001;ooooo0_l0002Pooooo`00
TOooool2o`0000_ooooo0_l0000<ooooo`03o`000?oooooooooo01Gooooo0_l0002Rooooo`00SOoo
ool2o`0000;ooooo0_l0000?ooooo`;o00000oooool2o`0000?ooooo00?o0000ooooooooool05Ooo
ool2o`0000kooooo0_l0002Booooo`00SOooool2o`0000Wooooo0_l00008ooooo`;o00000oooool2
o`0000?ooooo00?o0000ooooooooool02Oooool2o`0001[ooooo0_l0002Booooo`00V?ooool2o`00
00Wooooo0_l00007ooooo`03o`000?oooooooooo00Wooooo0_l0002^ooooo`00Poooool2o`0001ko
oooo0_l00007ooooo`03o`000?oooooooooo01?ooooo0_l0000<ooooo`Co0000U?ooool008?ooooo
0_l00008ooooo`;o00007Oooool00ol0003oooooooooo`08ooooo`;o00002Oooool2o`0000cooooo
1?l0002Dooooo`00SOooool2o`0001gooooo00?o0000ooooooooool02?ooool2o`0001Oooooo0_l0
002Fooooo`00[?ooool00ol0003oooooooooo`0Booooo`;o00003Oooool2o`0009Kooooo002[oooo
o`Co00001_ooool2o`0000[ooooo0_l0000<ooooo`?o0000U_ooool00:_ooooo0_l00008ooooo`;o
00002_ooool2o`0000_ooooo0ol0002Gooooo`00[?ooool00ol0003oooooooooo`0Mooooo`Co0000
V?ooool00:cooooo00?o0000ooooooooool07Oooool2o`0000oooooo0_l00029ooooo`00[?ooool0
0ol0003oooooooooo`0Kooooo`;o00004Oooool2o`0008Wooooo0029ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00;o00000oooool00ol0003oooooooooo`0Kooooo`;o0000W?ooool008Wooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`04ogMgMolb
<S;o0000o`0000?ooooo00?o0000ooooooooool00_l0000;ooooo`;o00003Oooool2o`0009_ooooo
0029ooooo`05oa0@4?ooooooooooooooool@41002Oooool2o`0000;ooooo00?oZJVYoeEEEOooool0
2?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o00002_ooool2o`0000cooooo
0ol0000=ooooo`;o0000S?ooool008Wooooo00Go0000ooooooooooooooooo`000009ooooo`;o0000
0oooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol000000ooooooo0000
o`000009ooooo`;o00003Oooool2o`0000kooooo0_l0002<ooooo`00ROooool01Ol0003ooooooooo
oooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool03?ooool2o`0000[ooooo0_l0002Oooooo`00ROooool01Ol@413ooooo
oooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo01Sooooo0_l0002Oooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go410@o`000?l0003ooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0^Oooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`00
00Kooooo00?o0000ooooooooool0^Oooool009?ooooo0_l0000Gooooo`03o`000?oooooooooo0;Wo
oooo002Cooooo`;o00005oooool00ol0003oooooooooo`0Dooooo`;o0000Xoooool00:cooooo00?o
0000ooooooooool05?ooool2o`000:?ooooo002/ooooo`?o00001_ooool2o`0000_ooooo0_l0002T
ooooo`00SOooool2o`0001gooooo00?o0000ooooooooool01_ooool2o`0000_ooooo0ol0002Soooo
o`00SOooool2o`0001gooooo00?o0000ooooooooool01Oooool2o`0000gooooo0_l0000=ooooo`;o
0000U?ooool00:cooooo00?o0000ooooooooool01Oooool2o`0001cooooo0_l0002Dooooo`00Uooo
ool2o`0001?ooooo00?o0000ooooooooool04Oooool2o`000:Kooooo002Fooooo`?o00004oooool0
0ol0003oooooooooo`0Aooooo`;o0000Y_ooool009Kooooo0ol0000Cooooo`03o`000?oooooooooo
0;Wooooo002@ooooo`;o00006_ooool00ol0003oooooooooo`02o`0000gooooo0_l0002Xooooo`00
T?ooool2o`0000Kooooo0_l0000Booooo`Go00003Oooool2o`000:Sooooo002Hooooo`;o00004_oo
ool3o`000;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool06oooool2o`0009cooooo002/ooooo`03o`000?oooooooooo01_ooooo
0_l0002Looooo`00T_ooool2o`0001Sooooo00?o0000ooooooooool0^Oooool009;ooooo0_l0000H
ooooo`03o`000?oooooooooo0;Wooooo002Oooooo`;o000000?oooooo`000?l000002?ooool00ol0
003oooooooooo`2iooooo`00Woooool2o`000004ooooool0003o0000ooooo`;o00001Oooool3o`00
0;Wooooo002Cooooo`;o00004?ooool2o`0000Gooooo00?o0000ooooooooool01Oooool2o`000;;o
oooo002Cooooo`;o00005oooool00ol0003oooooooooo`05ooooo`;o0000/_ooool00:cooooo00?o
0000ooooooooool0^Oooool009Kooooo0_l0000Dooooo`03o`000?oooooooooo00?ooooo0_l0002d
ooooo`00U_ooool2o`0001Cooooo00?o0000ooooooooool00_ooool3o`000;Cooooo002/ooooo`03
o`000?oooooooooo00;ooooo0_l0002eooooo`00[?ooool00ol0003oooooooooo`2iooooo`00V_oo
ool2o`00013ooooo1Ol0002gooooo`00V_ooool2o`00013ooooo00?o0000ooooool000000_l0002g
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00W?ooool2o`0000cooooo0ol0002kooooo`00
V_ooool4o`0000cooooo0ol0002kooooo`00V_ooool2o`0000?ooooo0_l0000;ooooo`03o`000?oo
oooooooo0;Wooooo002Oooooo`;o000000?oooooo`000?l000000_l000000ol@413oooooooooo`03
ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0^Oooool00:Cooooo00?o0000ooooooooool01Oooool3o`000;Wooooo002Tooooo`03o`00
0?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooo
oooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Rooooo`03oeEEEOmVIVKo00000<?o
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Zooooo`04
oa0@4?l0003o0000o`000;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`00
0?oooooooooo0;[ooooo002[ooooo`06o`000?mgMgOo0000o`000?mEEEGok^k^]oooool00:_ooooo
00Ko0000oeEEEOo^k^koooooogMgMomEEEFgooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03
o`000?oooooooooo0;Gooooo002[ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0
]Oooool00:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomVIVJgooooo`00Z_ooool00ol@413o0000
ogMgM`02o`000003ofIVI_o^k^kooooo0;Kooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.64551 .48384 Mdot
.54889 .82778 Mdot
.46817 .36738 Mdot
.50336 .71928 Mdot
.4073 .40582 Mdot
.43686 .15561 Mdot
.44085 .41776 Mdot
.72557 .56604 Mdot
.63032 .2161 Mdot
.53928 .6592 Mdot
.41277 .56194 Mdot
.7057 .65489 Mdot
.44891 .08947 Mdot
.44254 .74595 Mdot
.69999 .65655 Mdot
.45738 .24758 Mdot
.5639 .27949 Mdot
.46739 .07367 Mdot
.57422 .57449 Mdot
.64841 .70498 Mdot
.45997 .08187 Mdot
.43721 .87723 Mdot
.40477 .76652 Mdot
.49595 .08266 Mdot
.62274 .83004 Mdot
.58586 .62198 Mdot
.43592 .27325 Mdot
.5771 .51938 Mdot
.62364 .75922 Mdot
.54332 .83376 Mdot
.50331 .09739 Mdot
.63797 .22555 Mdot
.72175 .46667 Mdot
.6154 .4836 Mdot
.5683 .73627 Mdot
.67832 .52129 Mdot
.37483 .60425 Mdot
.55721 .3697 Mdot
.59843 .79952 Mdot
.69185 .70402 Mdot
.61126 .85307 Mdot
.60612 .62023 Mdot
.42749 .80967 Mdot
.64653 .56291 Mdot
.6385 .41328 Mdot
.55 .29069 Mdot
.48285 .77721 Mdot
.56105 .11261 Mdot
.41455 .71587 Mdot
.63816 .72016 Mdot
.54758 .09743 Mdot
.5134 .92545 Mdot
.73927 .70647 Mdot
.50926 .84007 Mdot
.47229 .87545 Mdot
.68941 .33641 Mdot
.72328 .57704 Mdot
.56611 .28181 Mdot
.44072 .05869 Mdot
.62914 .37396 Mdot
.56535 .33137 Mdot
.37762 .22995 Mdot
.59438 .80425 Mdot
.42328 .44044 Mdot
.71201 .42975 Mdot
.67083 .28765 Mdot
.54952 .61793 Mdot
.42384 .37737 Mdot
.56606 .40035 Mdot
.53316 .12914 Mdot
.60434 .38062 Mdot
.51177 .60366 Mdot
.53686 .66364 Mdot
.56187 .49554 Mdot
.59484 .80338 Mdot
.47953 .64511 Mdot
.739 .70709 Mdot
.58748 .42476 Mdot
.5479 .88151 Mdot
.4906 .82846 Mdot
.62787 .29139 Mdot
.55723 .81002 Mdot
.53405 .62465 Mdot
.59892 .65169 Mdot
.72457 .46823 Mdot
.49168 .24127 Mdot
.41456 .3324 Mdot
.44894 .20547 Mdot
.53853 .22603 Mdot
.42765 .35 Mdot
.61806 .83609 Mdot
.7438 .34819 Mdot
.5127 .31242 Mdot
.50333 .20308 Mdot
.47604 .25747 Mdot
.72886 .30497 Mdot
.45377 .76853 Mdot
.54212 .09411 Mdot
.72792 .73556 Mdot
.5558 .25514 Mdot
.64505 .54085 Mdot
.48647 .14981 Mdot
.70791 .63902 Mdot
.63864 .61141 Mdot
.60477 .23957 Mdot
.61611 .52506 Mdot
.61221 .42169 Mdot
.55369 .66734 Mdot
.51563 .31993 Mdot
.53429 .13185 Mdot
.49469 .76846 Mdot
.50839 .70924 Mdot
.62935 .21199 Mdot
.67748 .5852 Mdot
.49346 .69412 Mdot
.58053 .38417 Mdot
.69942 .35192 Mdot
.67788 .29865 Mdot
.38979 .74955 Mdot
.44194 .10083 Mdot
.36245 .58591 Mdot
.39208 .31134 Mdot
.61384 .78012 Mdot
.53824 .13634 Mdot
.47289 .7535 Mdot
.67011 .62185 Mdot
.69118 .23027 Mdot
.61943 .66884 Mdot
.42816 .45761 Mdot
.39929 .73903 Mdot
.63622 .60788 Mdot
.68628 .71056 Mdot
.46491 .11535 Mdot
.3929 .59176 Mdot
.5726 .84844 Mdot
.37904 .67366 Mdot
.64841 .69846 Mdot
.54212 .64501 Mdot
.72272 .51221 Mdot
.69456 .67818 Mdot
.54955 .53056 Mdot
.57759 .47933 Mdot
.5663 .28416 Mdot
.66564 .64984 Mdot
.71787 .42241 Mdot
.35815 .70638 Mdot
.55304 .65907 Mdot
.48083 .18233 Mdot
.37293 .73291 Mdot
.4662 .14846 Mdot
.52712 .28179 Mdot
.50908 .09688 Mdot
.5196 .55019 Mdot
.52375 .16502 Mdot
.41766 .88014 Mdot
.56901 .84744 Mdot
.69444 .34178 Mdot
.37641 .62648 Mdot
.40618 .84134 Mdot
.52938 .7725 Mdot
.54218 .89062 Mdot
.60729 .86552 Mdot
.67061 .43201 Mdot
.44593 .84844 Mdot
.64415 .50271 Mdot
.71361 .40452 Mdot
.63082 .29047 Mdot
.55848 .37035 Mdot
.40638 .84481 Mdot
.6628 .64007 Mdot
.51787 .33236 Mdot
.52573 .28289 Mdot
.4102 .37595 Mdot
.52819 .72871 Mdot
.71922 .4631 Mdot
.71734 .28017 Mdot
.50972 .14583 Mdot
.51383 .62649 Mdot
.6171 .76893 Mdot
.45067 .94696 Mdot
.6692 .75559 Mdot
.54868 .38827 Mdot
.59612 .87509 Mdot
.50738 .33096 Mdot
.61148 .18842 Mdot
.68238 .2173 Mdot
.64075 .22645 Mdot
.62213 .84264 Mdot
.40091 .68265 Mdot
.39142 .84425 Mdot
.66542 .6518 Mdot
.44625 .69562 Mdot
.36226 .4297 Mdot
.72705 .51226 Mdot
.52479 .96623 Mdot
.69962 .67119 Mdot
.47418 .17953 Mdot
.77094 .45059 Mdot
.62046 .53684 Mdot
.52626 .45906 Mdot
.52801 .48475 Mdot
.49973 .65238 Mdot
.40522 .53077 Mdot
.77462 .49232 Mdot
.64227 .56054 Mdot
.53148 .58479 Mdot
.47235 .11499 Mdot
.50736 .71436 Mdot
.53867 .48367 Mdot
.41123 .46428 Mdot
.38497 .37039 Mdot
.58426 .40603 Mdot
.63204 .29354 Mdot
.52103 .30561 Mdot
.644 .51781 Mdot
.57018 .35351 Mdot
.603 .87083 Mdot
.52064 .37023 Mdot
.6039 .30784 Mdot
.70382 .67088 Mdot
.57687 .36937 Mdot
.44459 .05557 Mdot
.61934 .26519 Mdot
.64573 .33784 Mdot
.47131 .23842 Mdot
.43186 .74564 Mdot
.56728 .79978 Mdot
.51577 .32436 Mdot
.69828 .66332 Mdot
.36094 .44499 Mdot
.41911 .4215 Mdot
.51151 .55523 Mdot
.77227 .49056 Mdot
.39946 .42601 Mdot
.43977 .25828 Mdot
.37456 .73834 Mdot
.54458 .32915 Mdot
.62942 .65115 Mdot
.39542 .27892 Mdot
.64003 .58698 Mdot
.37578 .24549 Mdot
.39751 .3369 Mdot
.66348 .37849 Mdot
.60352 .37766 Mdot
.65044 .24457 Mdot
.44873 .29136 Mdot
.45012 .94057 Mdot
.46097 .15891 Mdot
.60089 .36785 Mdot
.58681 .81846 Mdot
.54419 .94314 Mdot
.49963 .67901 Mdot
.45446 .71279 Mdot
.42193 .88783 Mdot
.58492 .6189 Mdot
.51353 .25773 Mdot
.42389 .80381 Mdot
.46524 .64145 Mdot
.72454 .54492 Mdot
.51024 .05429 Mdot
.39905 .56761 Mdot
.43886 .26093 Mdot
.65743 .3735 Mdot
.4427 .65456 Mdot
.44451 .17634 Mdot
.63647 .41873 Mdot
.46645 .77641 Mdot
.39299 .41017 Mdot
.67484 .57105 Mdot
.56135 .69525 Mdot
.67748 .56836 Mdot
.44525 .85332 Mdot
.53814 .66527 Mdot
.43566 .79197 Mdot
.42124 .89108 Mdot
.5568 .42622 Mdot
.47871 .81179 Mdot
.56754 .12241 Mdot
.41051 .49515 Mdot
.5114 .14629 Mdot
.59444 .81113 Mdot
.44553 .32425 Mdot
.54999 .4024 Mdot
.37795 .64589 Mdot
.71422 .61317 Mdot
.54738 .68676 Mdot
.51173 .40659 Mdot
.46153 .80044 Mdot
.6832 .53283 Mdot
.5126 .22055 Mdot
.60544 .2467 Mdot
.67955 .21361 Mdot
.4141 .12374 Mdot
.71116 .61287 Mdot
.41007 .14016 Mdot
.45086 .63348 Mdot
.40386 .1584 Mdot
.36789 .66126 Mdot
.68227 .47584 Mdot
.70481 .6385 Mdot
.35236 .36519 Mdot
.45577 .83019 Mdot
.38983 .5418 Mdot
.63142 .63362 Mdot
.64633 .23845 Mdot
.62884 .82299 Mdot
.45631 .76885 Mdot
.55654 .10985 Mdot
.5762 .65426 Mdot
.49283 .31943 Mdot
.38172 .44407 Mdot
.58052 .31782 Mdot
.41861 .15972 Mdot
.39119 .84721 Mdot
.47875 .70995 Mdot
.61765 .34564 Mdot
.61506 .55367 Mdot
.71682 .46357 Mdot
.4324 .59786 Mdot
.66465 .76371 Mdot
.4586 .9958 Mdot
.55636 .05223 Mdot
.42416 .6212 Mdot
.4797 .1115 Mdot
.59364 .67158 Mdot
.56077 .85755 Mdot
.41859 .68856 Mdot
.52401 .43153 Mdot
.4376 .54131 Mdot
.60338 .38285 Mdot
.71484 .63043 Mdot
.43928 .92357 Mdot
.47432 .25679 Mdot
.38653 .63793 Mdot
.43432 .38414 Mdot
.49789 .65783 Mdot
.56086 .81043 Mdot
.42328 .1931 Mdot
.443 .84354 Mdot
.53032 .7703 Mdot
.41052 .61959 Mdot
.75523 .66169 Mdot
.5797 .63689 Mdot
.58605 .75425 Mdot
.42297 .45239 Mdot
.71019 .40525 Mdot
.42204 .34152 Mdot
.65602 .67507 Mdot
.52119 .86355 Mdot
.54602 .43859 Mdot
.52979 .25603 Mdot
.70772 .65076 Mdot
.4055 .1498 Mdot
.67771 .54945 Mdot
.47681 .84144 Mdot
.61971 .50234 Mdot
.66642 .62741 Mdot
.41584 .27276 Mdot
.70839 .64706 Mdot
.58463 .08103 Mdot
.66762 .39432 Mdot
.68963 .70052 Mdot
.65847 .77564 Mdot
.59064 .88561 Mdot
.45913 .67708 Mdot
.39984 .57505 Mdot
.69357 .67968 Mdot
.72451 .55813 Mdot
.44774 .64804 Mdot
.57805 .19863 Mdot
.58294 .61655 Mdot
.48764 .11703 Mdot
.64581 .52144 Mdot
.56526 .12267 Mdot
.63125 .64342 Mdot
.37489 .38366 Mdot
.49988 .93601 Mdot
.41819 .8229 Mdot
.38577 .25616 Mdot
.41238 .80347 Mdot
.64913 .78486 Mdot
.37505 .59294 Mdot
.55004 .2032 Mdot
.52051 .48489 Mdot
.5179 .96854 Mdot
.53143 .21257 Mdot
.44111 .58035 Mdot
.65997 .77593 Mdot
.53981 .13795 Mdot
.5229 .42231 Mdot
.56098 .53669 Mdot
.59709 .52668 Mdot
.45968 .21892 Mdot
.58214 .13893 Mdot
.63854 .3022 Mdot
.36153 .50745 Mdot
.66344 .7675 Mdot
.60824 .41425 Mdot
.76394 .61734 Mdot
.61651 .46517 Mdot
.53347 .71715 Mdot
.49336 .79801 Mdot
.49237 .35989 Mdot
.71842 .60871 Mdot
.70783 .64626 Mdot
.43129 .29105 Mdot
.53935 .40525 Mdot
.46928 .20682 Mdot
.52377 .30771 Mdot
.44928 .99417 Mdot
.49363 .18779 Mdot
.67212 .43478 Mdot
.54676 .55622 Mdot
.53084 .29097 Mdot
.42923 .5613 Mdot
.44956 .20047 Mdot
.61208 .44769 Mdot
.48565 .21112 Mdot
.52396 .6233 Mdot
.36661 .66303 Mdot
.723 .50836 Mdot
.47522 .62431 Mdot
.55229 .76972 Mdot
.61208 .42141 Mdot
.55865 .22173 Mdot
.57233 .65796 Mdot
.54165 .31981 Mdot
.50251 .9866 Mdot
.7509 .35929 Mdot
.62203 .67245 Mdot
.57624 .96514 Mdot
.64187 .60084 Mdot
.49908 .70415 Mdot
.64184 .23925 Mdot
.68856 .69348 Mdot
.41157 .51999 Mdot
.52482 .85716 Mdot
.75136 .6733 Mdot
.54376 .43145 Mdot
.50024 .33382 Mdot
.50875 .76838 Mdot
.65747 .37094 Mdot
.51759 .78717 Mdot
.76144 .40504 Mdot
.52809 .40455 Mdot
.55255 .76503 Mdot
.60782 .61697 Mdot
.45051 .28389 Mdot
.48966 .69797 Mdot
.56214 .47724 Mdot
.72522 .56629 Mdot
.44894 .67914 Mdot
.56453 .85899 Mdot
.5803 .7734 Mdot
.63188 .3899 Mdot
.67466 .59524 Mdot
.57755 .19944 Mdot
.59832 .37056 Mdot
.69778 .23794 Mdot
.55895 .56246 Mdot
.71265 .64023 Mdot
.54296 .94539 Mdot
.4678 .77633 Mdot
.40588 .14922 Mdot
.56721 .67637 Mdot
.52873 .21524 Mdot
.65782 .67026 Mdot
.64506 .54845 Mdot
.56917 .60334 Mdot
.53439 .26484 Mdot
.61622 .48608 Mdot
.38355 .1865 Mdot
.39951 .66527 Mdot
.4849 .64085 Mdot
.45908 .86571 Mdot
.47658 .83728 Mdot
.46249 .6834 Mdot
.41993 .57282 Mdot
.51647 .82941 Mdot
.39399 .61351 Mdot
.52344 .58122 Mdot
.59305 .56624 Mdot
.6732 .29305 Mdot
.40544 .4353 Mdot
.62732 .37953 Mdot
.57661 .45543 Mdot
.57573 .49829 Mdot
.43166 .48227 Mdot
.4337 .43883 Mdot
.55503 .81897 Mdot
.44034 .06413 Mdot
.67365 .44866 Mdot
.57191 .43187 Mdot
.6368 .72733 Mdot
.68443 .71995 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo0ol0000?ooooo`;o0000Z?ooool009Wooooo0_l0000Aooooo`03o`000?oo
oooooooo00;o00003Oooool2o`000:Sooooo002Hooooo`?o00004Oooool00ol0003oooooooooo`02
o`000;Oooooo002Hooooo`;o00004_ooool00ol0003oooooooooo`2iooooo`00V?ooool2o`0001;o
oooo00?o0000ooooooooool0^Oooool009Sooooo0_l0000Booooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002Qooooo`;o00002Oooool00ol0003oooooooooo`2i
ooooo`00XOooool2o`0000Wooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
W_ooool2o`0000[ooooo0ol0000Kooooo`;o0000W_ooool009kooooo0_l0000:ooooo`?o00006ooo
ool2o`0009kooooo002Kooooo`;o00003oooool00ol0003oooooooooo`2iooooo`00Voooool2o`00
00oooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool02_ooool2o`000:go
oooo002/ooooo`Go00002?ooool4o`000:_ooooo002Hooooo`;o00004_ooool5o`0000[ooooo0_l0
002[ooooo`00V?ooool2o`0001;ooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool03oooool2o`000:Sooooo002Uooooo`;o0000
1Oooool00ol0003oooooooooo`0?ooooo`Co0000Y_ooool00:3ooooo1?l000000ooooooo0000o`00
0005ooooo`03o`000?oooooooooo017ooooo0_l0002Vooooo`00ROooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00;ooooo1Ol000001?lb<S;ogMgMo`00
0?l00003ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool01?mgMgOo<S8bo`000?l00003ooooo`03
o`000?oooooooooo01;ooooo0ol0002Tooooo`00POooool6o`0000;ooooo00Ko410@oooooooooooo
oooooa0@4?ooool2o`0000[ooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03oooo
o`?o00004_ooool3o`000:Cooooo0029ooooo`06o`000?ooooooooooooooool0003ooooo0_l0000;
ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2i
ooooo`00ROooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool02?ooool2o`000:oooooo0029
ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool2o`000:oooooo0029ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`09ooooo`?o0000[Oooool008Wooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP02o`0000Wooooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`09ooooo`?o0000
3?ooool2o`0009oooooo002>ooooo`;o00007?ooool00ol0003oooooooooo`0Hooooo`;o0000Wooo
ool00:cooooo00?o0000ooooooooool00_l0002gooooo`00S?ooool2o`0001;ooooo0_l00005oooo
o`;o00000oooool00ol0003oooooooooo`02o`000;Oooooo002<ooooo`;o00004_ooool2o`0000Go
oooo0_l00003ooooo`?o0000^Oooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo0;Wooooo
002<ooooo`;o00002Oooool2o`0000Kooooo0_l0000;ooooo`03o`000?oooooooooo0;Wooooo002<
ooooo`;o00000oooool2o`0000cooooo0_l0000;ooooo`03o`000?oooooooooo0;Wooooo002Aoooo
o`;o00006Oooool00ol0003oooooooooo`04ooooo`;o0000/oooool00:cooooo00?o0000oooooooo
ool01?ooool2o`000;?ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002Iooooo`;o00004Oooool3o`000;Wooooo002Iooooo`;o00002?ooool2o`00
00Oooooo00?o0000ooooooooool0^Oooool00:?ooooo1?l00005ooooo`03o`000?oooooooooo0;Wo
oooo002Uooooo`;o00001Oooool00ol0003oooooooooo`2iooooo`00QOooool2o`0002;ooooo0_l0
00000ooooooo0000ooooo`0Rooooo`;o0000U_ooool008Gooooo0_l0000Rooooo`;o000000?ooooo
o`000?ooool08_ooool2o`0009Kooooo002Booooo`;o00006?ooool00ol0003oooooooooo`2ioooo
o`00T_ooool2o`0001Sooooo00?o0000ooooooooool0^Oooool009_ooooo0_l0000?ooooo`?o0000
5_ooool2o`000:7ooooo002Kooooo`;o00003oooool3o`0000gooooo0_l00007ooooo`;o0000XOoo
ool009_ooooo0_l00004ooooo`;o00002Oooool3o`0000gooooo0_l0002Zooooo`00Voooool2o`00
00Cooooo0_l00009ooooo`03o`000?oooooooooo0;Wooooo002Wooooo`;o00000oooool00ol0003o
ooooooooo`07ooooo`;o00007_ooool2o`0000oooooo0_l0001oooooo`00Yoooool2o`0000?ooooo
00?o0000ooooooooool01_ooool3o`0001kooooo0ol0000>ooooo`;o0000Ooooool009kooooo0_l0
000<ooooo`03o`000?oooooooooo00Kooooo0_l0000Pooooo`;o00003oooool2o`0007kooooo002N
ooooo`;o00003?ooool01?l0003oooooooooooooool2o`0000gooooo0_l0000Wooooo`;o0000O_oo
ool00:cooooo0ol000000ooooooo0000o`00000=ooooo`;o00006?ooool2o`0008gooooo002/oooo
o`03o`000?oooooooooo00Wooooo0_l0000Oooooo`?o0000S?ooool008?ooooo0_l0000Wooooo`03
o`000?oooooooooo00Wooooo0_l0000Pooooo`;o00003oooool2o`0007_ooooo0023ooooo`;o0000
9oooool00ol0003oooooooooo`0looooo`;o0000Noooool00:cooooo00?o0000ooooooooool0?_oo
ool2o`0007Wooooo002Rooooo`;o00002?ooool00ol0003oooooooooo`0Oooooo`;o00002_ooool4
o`0000oooooo0_l0001iooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45
ooooo`?o000000Co<S8bomgMgOoooooooooo0_l000000ooooooo0000ooooo`0Pooooo`;o00002_oo
ool4o`0008[ooooo0023ooooo`;o00003?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B48ooooo`04ogMgMolb<S;oooooooooo`;o000000?oooooo`000?ooool08?ooool2o`0000gooooo
0_l00029ooooo`00Poooool2o`0000Cooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@4100
1oooool2o`0000Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Oooooo`;o0000
3Oooool2o`0008Wooooo002Aooooo`05o`000?ooooooooooooooool000001oooool2o`0000Kooooo
00?oMgMgoc8b<_ooool01?ooool3o`000;Wooooo002Aooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool01_ooool2o`0000Oo
oooo0_l0002Xooooo`00Q_ooool2o`0000Wooooo00Go410@oooooooooooooooooa0@4002ooooo`;o
00002?ooool4o`0000Kooooo00Co0000oooooooooooooooo0_l00003ooooo`;o00001oooool2o`00
0:Sooooo0026ooooo`;o00002Oooool01_mgMgOoV9RHoooooonHV9SoMgMgooooo`?o00002?ooool4
o`0000Kooooo00Co0000oooooooooooooooo0_l0002fooooo`00TOooool01_o^k^ko<S8bo`000?lb
<S;ok^k^ooooo`;o00002Oooool4o`0000Kooooo00?o0000ooooooooool02?ooool2o`0001[ooooo
0_l0002Cooooo`00[?ooool00ol0003oooooooooo`08ooooo`;o00006_ooool2o`0009?ooooo002/
ooooo`03o`000?oooooooooo0;Wooooo002@ooooo`;o00001?ooool2o`0001Cooooo00?o0000oooo
ooooool0^Oooool0093ooooo0_l00004ooooo`;o00005?ooool3o`000;Wooooo0029ooooo`;o0000
8Oooool00ol0003oooooooooo`0Booooo`;o0000<?ooool2o`0007?ooooo0029ooooo`;o00008Ooo
ool00ol0003oooooooooo`05ooooo`?o00002_ooool2o`00033ooooo0_l0001cooooo`00Voooool2
o`0000oooooo00?o0000ooooooooool01Oooool3o`0000[ooooo0_l0002Uooooo`00Voooool2o`00
00oooooo00?o0000ooooooooool04_ooool2o`00027ooooo0_l00022ooooo`00UOooool2o`0000Co
oooo0_l0000?ooooo`03o`000?oooooooooo00Oooooo0_l00004ooooo`;o00006?ooool3o`0000_o
oooo0_l00022ooooo`00UOooool2o`0000Cooooo0_l0000?ooooo`03o`000?oooooooooo00Oooooo
0_l00004ooooo`;o00006?ooool3o`0000cooooo0_l00021ooooo`00[?ooool00ol0003ooooooooo
o`0Xooooo`;o00003?ooool2o`00087ooooo002/ooooo`?o0000=oooool2o`00083ooooo002/oooo
o`03o`000?oooooooooo02[ooooo0_l0000;ooooo`;o0000P?ooool00:cooooo00?o0000oooooooo
ool01?ooool2o`0002Cooooo0_l0000Looooo`;o0000Koooool00:cooooo00?o0000ooooooooool0
1?ooool2o`0001Wooooo0_l0000Wooooo`;o0000Koooool008Sooooo0_l0000Rooooo`04o`000?oo
ooooooooooooo`;o000000?oooooo`000?l000006Oooool2o`0009Sooooo0028ooooo`;o00008_oo
ool01?l0003oooooooooooooool2o`000;Kooooo002Yooooo`;o000000?oooooo`000?ooool06?oo
ool2o`000:3ooooo002Yooooo`;o000000?oooooo`000?ooool00oooool2o`0000Kooooo0_l0000;
ooooo`;o0000X?ooool009[ooooo0_l0000@ooooo`?o00000_ooool2o`0000Kooooo0_l0002]oooo
o`00V_ooool2o`00013ooooo00?o0000ooooooooool00_ooool2o`000;Gooooo002/ooooo`04o`00
0?oooooo0000o`0000[ooooo0_l00005ooooo`;o0000YOooool008oooooo0_l0000Kooooo`Co0000
00?oooooo`000?l000001oooool2o`0000Gooooo0_l0002Uooooo`00R_ooool2o`0000?ooooo0_l0
000Kooooo`;o00000oooool2o`0002Wooooo0_l0000<ooooo`;o0000O?ooool008[ooooo0_l0000P
ooooo`03o`000?oooooooooo02gooooo0_l0000<ooooo`;o0000O?ooool009;ooooo0_l0000Hoooo
o`03o`000?oooooooooo03gooooo0_l0001jooooo`00T_ooool2o`0001Sooooo00?o0000oooooooo
ool08oooool2o`0001Sooooo0_l0001jooooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool0
8oooool2o`0002Sooooo0_l0001Zooooo`00U?ooool2o`0001Kooooo0ol0000nooooo`;o00003Ooo
ool2o`0006[ooooo002/ooooo`03o`000?oooooooooo01Cooooo0_l0000Xooooo`;o0000NOooool0
0:cooooo00?o0000ooooooooool05?ooool2o`000:?ooooo002Yooooo`;o000000?oooooo`000?oo
ool0D?ooool2o`0006Sooooo001kooooo`;o0000;?ooool2o`000003ooooool0003ooooo053ooooo
0_l0001Xooooo`00Noooool2o`0000cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000?ooooo1?l000000olb<S;ogMgMooooo`04ooooo`03o`000?oooooooooo01kooooo
0_l0002Iooooo`00Q_ooool2o`000006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`;o00000_ooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo00?ooooo0_l0000:ooooo`?o00001?ooool2o`0000Gooooo0ol0000Aoooo
o`;o0000Q_ooool0087ooooo1ol000000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[o
oooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo0_l0000:ooooo`?o00001?ooool2o`0000Gooooo0_l00008ooooo`;o00002?ooool2o`0008Ko
oooo0029ooooo`04o`000?ooooooooooooooo`?o00002oooool00onHV9So8B4Qonk^kP07ooooo`03
ogMgMolb<S;ooooo00Cooooo0ol0000Wooooo`;o00002?ooool2o`0008Kooooo0029ooooo`04o`00
0?ooooooooooooooo`?o00000_ooool2o`0000Sooooo00?oMgMgofIVI_ooool00oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool07oooool2o`0000Kooooo0_l0000:oooo
o`;o0000Q?ooool008Wooooo00Go410@oooooooooooooooooa0@4004ooooo`;o00002Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07oooool2o`00
00Kooooo0_l0000:ooooo`;o0000Q?ooool008;ooooo0_l00005ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02?ooool2o`000006ooooool0003o^[ZjoooooonHV9So410@1?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo01Oooooo0_l00006ooooo`;o0000V?ooool008;ooooo0_l00005
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool2o`000006oooooonHV9So410@o`000?lQ8B7o
c<c<1?ooool4o`0000Kooooo00?o0000ooooooooool03Oooool2o`0000Sooooo0_l0002Pooooo`00
[?ooool00ol0003oooooooooo`0=ooooo`;o00006Oooool2o`0008oooooo002/ooooo`03o`000?oo
oooooooo02Sooooo0_l0000:ooooo`;o0000Poooool00:cooooo00?o0000ooooooooool0=?ooool2
o`0008?ooooo002/ooooo`?o00004_ooool2o`000:Gooooo002/ooooo`03o`000?oooooooooo00Ko
oooo0_l00005ooooo`;o00000oooool2o`0002oooooo0_l0001dooooo`00SOooool2o`0001gooooo
00?o0000ooooooooool00_l00004ooooo`;o00000_ooool2o`000003ooooool0003o000000Wooooo
0_l0000Xooooo`?o00003_ooool2o`0006Cooooo0028ooooo`;o00000oooool2o`0001gooooo00?o
0000ooooooooool00_l00008ooooo`;o00003?ooool2o`0002Sooooo0_l0000?ooooo`;o0000I?oo
ool008Sooooo0_l0000Rooooo`03o`000?oooooooooo02[ooooo0_l0002=ooooo`00[?ooool00ol0
003oooooooooo`0Pooooo`;o00002?ooool2o`0008gooooo002Hooooo`;o00004_ooool00ol0003o
ooooooooo`0Pooooo`;o00002?ooool2o`0008gooooo002Aooooo`;o00001Oooool2o`0001;ooooo
00?o0000ooooooooool01?ooool2o`0001cooooo0_l00006ooooo`;o00006?ooool2o`0007?ooooo
002Aooooo`;o00006Oooool3o`0000Cooooo0_l0000Cooooo`;o00001oooool2o`00023ooooo0_l0
001cooooo`00R_ooool2o`00023ooooo00?o0000ooooooooool03oooool2o`0000Sooooo0_l0002N
ooooo`00O_ooool2o`0000[ooooo0_l0000Pooooo`03o`000?oooooooooo00Cooooo0_l00005oooo
o`;o00000_ooool2o`0003;ooooo0_l0001dooooo`00O_ooool2o`0002cooooo00?o0000oooooooo
ool01?ooool2o`0000Gooooo0_l00007ooooo`;o00007oooool2o`0000cooooo0_l0001dooooo`00
S?ooool2o`0001kooooo00?o0000ooooooooool05?ooool2o`0001oooooo0_l00022ooooo`00S?oo
ool2o`0000Cooooo0_l00002ooooo`;o00005?ooool00ol0003oooooooooo`0<ooooo`;o0000Zooo
ool009;ooooo0_l00002ooooo`;o00005?ooool00ol0003oooooooooo`0<ooooo`;o0000Zoooool0
07kooooo0_l00005ooooo`;o00009Oooool00ol0003oooooooooo`2iooooo`00O_ooool2o`0000Go
oooo0_l0000Uooooo`03o`000?oooooooooo02;ooooo0_l0000Booooo`;o0000POooool009;ooooo
0_l0000Hooooo`?o00008_ooool2o`0001;ooooo0_l0000Nooooo`;o0000HOooool009;ooooo0_l0
000Hooooo`03o`000?oooooooooo01Kooooo0_l0000nooooo`;o0000HOooool009Cooooo0_l0000F
ooooo`03o`000?oooooooooo00Gooooo0_l0000?ooooo`;o0000XOooool000Wooooo1?l000000ol@
413oooooooooo`0Fooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000
onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00?oA4A4o`000?l000000_l0000Foooo
o`03o`000?oooooooooo00Gooooo0_l0000Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@0Hooooo`Co000000?o410@ooooooooool04_ooool000_ooooo00?o0000oooo
ooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWo
oooo00Oooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B48ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01_nHV9So8B4Qonk^k_ooooooA4A4ooooo`;o00001?ooool00omgMgOo<S8booooo`0Eoooo
o`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03ob4Q8Ol0003o
000000?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00gooooo0ol0
00000oooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8b
ooooo`0Iooooo`03o`000?oooooooooo01Cooooo0006o`0000Gooooo00?o0000ooooooooool04?oo
ool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo
00?o0000ooooooooool01Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03
o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onH
V9So8B4Qonk^kP02ooooo`;o00001Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
01Sooooo00Go410@oooooooooooooooooa0@4006ooooo`;o00001?ooool00onHV9So8B4Qonk^kP09
ooooo`03o`000?oooooooooo00cooooo1?l000000ooooooo410@ooooo`0?ooooo`03o`000?oooooo
oooo00gooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0H
ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb
<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00kooooo
00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_oo
ool05Oooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000003Oooool00onH
V9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00kooooo1Ol0000?ooooo`03ogMgMolb<S;ooooo
00kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMg
oc8b<_ooool06Oooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hoooo
o`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o
<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`05_ooool00ol0003oooooooooo`0Hooooo`05o`000?oooooo
ooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
3oooool00ol0003oooooo`000002o`0000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05
o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`06_ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hoooo
o`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooo
oooo017ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo017ooooo00Go
410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
6?ooool3o`00017ooooo0_l00005ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Gooooo0_l0000:ooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003_ooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05?ooool0
00_ooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@
oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0<ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
017ooooo0_l00003ooooo`;o000000GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001?ooool00ol0003oooooooooo`05ooooo`;o00002_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool05?ooool000Wooooo00?oEEEEofIVI_l000006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo1Ol00004ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo
1_l0000Eooooo`03o`000?oooooooooo01Kooooo0_l000001Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0
000Iooooo`03oeEEEOmVIVKo000001Kooooo002Eooooo`;o00005Oooool00ol0003oooooooooo`03
ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Hooooo`;o00002?ooool2o`0008[ooooo002/
ooooo`03o`000?oooooooooo00?ooooo0_l000001?oooooo0000o`000?ooool2o`0001Sooooo0_l0
0008ooooo`;o0000R_ooool00:cooooo00?o0000ooooooooool0E_ooool3o`0005Gooooo0_l00002
ooooo`;o00001Oooool008kooooo0_l0000Looooo`03o`000?oooooooooo05Kooooo0ol0001Eoooo
o`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1Oooool008kooooo0_l0000Looooo`03o`000?oooooo
oooo017ooooo0_l00003ooooo`;o0000Uoooool01?oMgMgo0000oa0@4?o<c<`6ooooo`001ooooooo
o`0004co00003?ooool01?o^k^ko8B4Qoa0@4?o^k^h6ooooo`001oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03
ooooo`;o000000?oooooo`000?ooool00oooool2o`000003ooooool0003ooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`04ob4Q8OmgMgOoMgMgoc8b<PKooooo0007
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Q
ooooo`;o00000oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Cooooo0_l00000
0ooooooo0000ooooo`03ooooo`;o00008_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool02Oooool2o`0000;ooooo0_l00005ooooo`00O_ooool2o`00
02cooooo00?o0000ooooooooool0A_ooool2o`00077ooooo002/ooooo`03o`000?oooooooooo04Ko
oooo1?l0001_ooooo`00[?ooool00ol0003oooooooooo`16ooooo`Co0000Koooool00:cooooo00?o
0000ooooooooool05_ooool2o`0001Cooooo0_l0002;ooooo`00S_ooool2o`0001cooooo00?o0000
ooooooooool05_ooool2o`0001Cooooo0ol00008ooooo`;o0000P?ooool008kooooo0_l0000Loooo
o`?o00008oooool2o`0000Sooooo0_l00008ooooo`;o0000P?ooool00:cooooo00?o0000oooooooo
ool07Oooool2o`0000Cooooo0_l0002Dooooo`00S?ooool2o`0001kooooo00?o0000ooooooooool0
3Oooool2o`0000kooooo0_l0002Jooooo`00S?ooool2o`0001kooooo00?o0000ooooooooool03Ooo
ool2o`0002[ooooo0_l0001nooooo`00[?ooool00ol0003oooooooooo`0Aooooo`;o00004Oooool2
o`0001?ooooo0_l0001nooooo`00[?ooool00ol0003oooooooooo`0Aooooo`;o00004Oooool2o`00
00Kooooo0_l0002;ooooo`00Qoooool2o`0000kooooo0_l0000Cooooo`03o`000?oooooooooo02co
oooo0_l0002;ooooo`00Qoooool2o`0000kooooo0_l0000Cooooo`03o`000?oooooooooo04Oooooo
0_l0001`ooooo`00[?ooool00ol0003oooooooooo`0/ooooo`;o00002Oooool2o`0000kooooo0_l0
001`ooooo`00[?ooool3o`0000?ooooo0_l0000Wooooo`;o00002Oooool2o`00083ooooo002/oooo
o`03o`000?oooooooooo00;o000000?oooooo`000?l000007_ooool2o`0009Cooooo002/ooooo`03
o`000?oooooooooo00;o00002_ooool2o`0001Gooooo0_l0000Rooooo`;o0000L?ooool008oooooo
0_l00003ooooo`;o00005_ooool00ol0003oooooooooo`0<ooooo`;o00007_ooool2o`0001Wooooo
0_l0001`ooooo`00Soooool2o`0000?ooooo0_l0000Fooooo`03o`000?oooooooooo013ooooo0_l0
000Jooooo`?o0000R_ooool008[ooooo0_l0000Pooooo`03o`000?oooooooooo013ooooo0_l00009
ooooo`;o00004?ooool2o`0001Sooooo0_l0001`ooooo`00R_ooool2o`00023ooooo00?o0000oooo
ooooool06oooool2o`0001Wooooo0ol0000>ooooo`;o0000L?ooool0097ooooo0_l0000Iooooo`03
o`000?oooooooooo03Kooooo0ol00020ooooo`00R_ooool2o`0000Gooooo0_l0000Iooooo`?o0000
5Oooool2o`0002oooooo0_l0001aooooo`00R_ooool2o`00023ooooo00?o0000ooooooooool05Ooo
ool2o`0002oooooo0_l0001aooooo`00V?ooool2o`0001;ooooo00?o0000ooooooooool01?ooool2
o`000;?ooooo001nooooo`;o00006?ooool2o`0001;ooooo00?o0000ooooooooool01?ooool2o`00
0003ooooool0003o000002kooooo0_l00020ooooo`00O_ooool2o`0002cooooo00?o0000oooooooo
ool01oooool2o`0002;ooooo0_l0000:ooooo`;o0000P?ooool008Sooooo0_l0000Rooooo`03o`00
0?oooooooooo02_ooooo0_l0002<ooooo`00P_ooool2o`0000Cooooo0_l0000Rooooo`03o`000?oo
oooooooo03Kooooo0_l00021ooooo`00P_ooool2o`00017ooooo0_l0000Eooooo`03o`000?oooooo
oooo03Kooooo0_l00021ooooo`00UOooool2o`0001Gooooo0ol0000[ooooo`;o0000S?ooool008;o
oooo0_l0000Xooooo`03o`000?oooooooooo00;o00004Oooool2o`0001Kooooo0_l0002<ooooo`00
P_ooool2o`0002Sooooo00?o0000ooooooooool00_l0000Aooooo`;o0000Y?ooool00:cooooo00?o
0000ooooooooool0:_ooool2o`0001Wooooo0_l0001booooo`00ROooool2o`00027ooooo00?o0000
ooooooooool0:_ooool2o`0001Kooooo1Ol0001booooo`00ROooool2o`00027ooooo00?o0000oooo
ooooool06?ooool2o`00013ooooo0_l0000Fooooo`?o0000M?ooool008Wooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP02o`0000?ooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool03Oooool2o`0000Wooooo0ol00005ooooo`;o0000<_ooool2
o`0006?ooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_l00003ooooo`;o00001?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`0=ooooo`;o00002_ooool2o`0000Gooooo0_l0000Cooooo`;o00007Oooool2o`0006?ooooo0029
ooooo`05oa0@4?ooooooooooooooool@41001Oooool2o`0000Gooooo00?oV9RHob4Q8Oo^k^h01_oo
ool2o`000003ooooool0003ooooo00Cooooo0ol00004ooooo`;o00000_ooool2o`0000oooooo0_l0
0005ooooo`;o00004oooool2o`0008;ooooo0023ooooo`;o00001?ooool01Ol0003ooooooooooooo
oooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool2o`000003ogMgMolb<S;ooooo00Cooooo00Co
0000oooooooooooooooo0_l000000ooooooo0000o`000002ooooo`;o0000:_ooool2o`0008?ooooo
0023ooooo`;o00001?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool0
0oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00Co0000oooooooooooooooo0_l0000aoooo
o`;o00003Oooool2o`0007Cooooo0029ooooo`05oa0@4?ooooooooooooooool@41003Oooool3o`00
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Xooooo`;o00006Oooool2o`00
07Cooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjo`000?l0003o
410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Gooooo`;o00003oooool2
o`0008oooooo0026ooooo`;o000000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`01?ooool4o`000003ooooool0003o000000?ooooo00?o0000ooooooooool0
5oooool2o`0001Wooooo0_l0000<ooooo`Go0000M?ooool008Kooooo0_l0000Hooooo`;o00001Ooo
ool2o`0000?ooooo00?o0000ooooooooool0:?ooool2o`0000Sooooo0_l0000<ooooo`Go0000M?oo
ool008?ooooo0_l0000Kooooo`;o00000oooool2o`0000Gooooo00?o0000ooooooooool02_ooool2
o`0001cooooo0_l0000Gooooo`;o0000M_ooool008?ooooo0_l0000Eooooo`;o00002Oooool2o`00
00Gooooo00?o0000ooooooooool02_ooool2o`0002Oooooo0_l0000<ooooo`;o0000M_ooool009[o
oooo0_l0000?ooooo`Co00007Oooool2o`0000Sooooo0_l0000:ooooo`;o00003?ooool2o`0007Ko
oooo002Iooooo`;o00004?ooool2o`0001Sooooo0_l00005ooooo`;o00002?ooool2o`0000[ooooo
0_l0000;ooooo`?o0000M_ooool009Wooooo0_l0000@ooooo`;o00005_ooool4o`0002Oooooo0ol0
001gooooo`00P?ooool2o`0002Wooooo0_l0000<ooooo`;o00000_ooool2o`0000Cooooo0_l0000Y
ooooo`;o00004?ooool2o`0006Kooooo0020ooooo`;o0000:_ooool00ol0003oooooooooo`09oooo
o`?o00000_ooool2o`0002kooooo0_l0000Aooooo`;o0000I_ooool0083ooooo0_l00008ooooo`;o
00008?ooool00ol0003oooooooooo`09ooooo`;o00000oooool2o`0002kooooo0_l0001iooooo`00
R_ooool2o`00023ooooo00?o0000ooooooooool02Oooool2o`0000?ooooo0_l0000Dooooo`;o0000
2oooool2o`0000gooooo0_l0001gooooo`00Q?ooool2o`0002Kooooo00?o0000ooooooooool06ooo
ool2o`0000Oooooo0ol0000:ooooo`;o00002oooool4o`0000kooooo0_l0001Wooooo`00Q?ooool2
o`0001Sooooo0_l0000<ooooo`?o00004oooool2o`0000Kooooo0_l00008ooooo`;o00002Oooool2
o`0000cooooo0_l0000@ooooo`;o0000Ioooool009_ooooo0_l000000ooooooo0000o`00000;oooo
o`;o00005Oooool2o`0001_ooooo0_l0000:ooooo`?o0000N_ooool008_ooooo0_l0000>ooooo`;o
00003_ooool2o`0003kooooo0ol0001jooooo`00Roooool2o`0001;ooooo0_l0000;ooooo`03o`00
0?oooooooooo0;Wooooo002Aooooo`;o00003?ooool2o`0000_ooooo00?o0000ooooooooool03?oo
ool2o`000:_ooooo002Aooooo`;o00006Oooool00ol0003oooooooooo`0<ooooo`;o0000Zoooool0
0:Wooooo0_l000000ooooooo0000ooooo`0Booooo`;o0000:?ooool2o`0007cooooo002Jooooo`;o
00003?ooool3o`000003ooooool0003ooooo01;ooooo0_l0000Xooooo`;o0000O?ooool009[ooooo
0_l0000<ooooo`;o00000_ooool3o`0002kooooo0_l0000;ooooo`;o0000O?ooool00:_ooooo0_l0
000`ooooo`;o00002oooool3o`0007_ooooo001mooooo`;o0000;?ooool2o`00033ooooo0_l0000<
ooooo`;o00003Oooool3o`0006_ooooo001mooooo`;o00009_ooool2o`0000Gooooo00Co0000oooo
ool0003o0000;Oooool2o`0001_ooooo0ol0001[ooooo`00WOooool2o`0000Kooooo0_l00005oooo
o`04o`000?oooooo0000o`0003Wooooo0_l0001mooooo`00Soooool2o`0000cooooo0_l0000=oooo
o`04o`000?oooooo0000o`0003Wooooo0_l0001mooooo`00Soooool2o`0001_ooooo1?l00007oooo
o`;o0000[oooool00:cooooo0ol00008ooooo`;o00008?ooool2o`0000gooooo0_l0001nooooo`00
[?ooool3o`0002[ooooo0_l0000=ooooo`;o0000O_ooool00:cooooo00?o0000ooooooooool01_oo
ool2o`0002;ooooo0_l0002=ooooo`00[?ooool00ol0003oooooooooo`06ooooo`;o00008_ooool2
o`0008gooooo0022ooooo`;o0000:?ooool00ol0003oooooooooo`2iooooo`00P_ooool2o`0002So
oooo00?o0000ooooooooool04oooool2o`0003?ooooo0_l0001_ooooo`00P_ooool2o`0000Kooooo
0_l0000Pooooo`03o`000?oooooooooo01?ooooo0_l0000cooooo`;o0000Koooool008;ooooo0_l0
0006ooooo`;o00001Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2iooooo`00TOooool01?mgMgOoV9RH
oooooonHV9P2o`0000;ooooo0_l00002ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`2iooooo`00Qoooool2o`0000Sooooo00Co410@oooooooooooooooo0_l00002ooooo`;o
00002oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;Wooooo0027ooooo`;o0000
2?ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool3o`000;Wo
oooo002Aooooo`05o`000?ooooooooooooooool000003?ooool3o`000003oc8b<_o<c<cooooo00Co
oooo00?o0000ooooooooool06Oooool2o`0001Wooooo0_l00023ooooo`00TOooool01Ol@413ooooo
oooooooooooo410@00cooooo0ol00007ooooo`03o`000?oooooooooo01Wooooo0_l0000Iooooo`;o
0000Poooool0097ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool09Oooool2o`0009;ooooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03?ooool4o`0000Kooooo00?o0000ooooooooool03_ooool2o`0001Gooooo0_l0000<ooooo`;o
0000Q?ooool008cooooo0_l0000Nooooo`03o`000?oooooooooo00kooooo0_l0000Sooooo`;o0000
Q?ooool008cooooo0_l0000>ooooo`?o00002oooool3o`000003ooooool0003o000000Kooooo0_l0
0005ooooo`;o00004oooool2o`0000kooooo0_l00024ooooo`00W?ooool3o`0000_ooooo0ol00000
0ooooooo0000o`000005ooooo`?o00001Oooool2o`0000Oooooo0_l0000:ooooo`;o0000U?ooool0
0:3ooooo0ol00009ooooo`?o00001_ooool2o`0000oooooo0_l0000Hooooo`;o0000Q_ooool00:3o
oooo0ol00003ooooo`;o00001?ooool00ol0003oooooooooo`0Rooooo`;o00003Oooool2o`0008Ko
oooo002Vooooo`;o00001?ooool00ol0003oooooooooo`0Rooooo`;o0000UOooool00:cooooo00?o
0000ooooooooool0;_ooool2o`0008Wooooo002/ooooo`03o`000?oooooooooo00;ooooo0_l0000Z
ooooo`;o0000ROooool009Kooooo0_l0000Dooooo`03o`000?oooooooooo00;ooooo0_l0002eoooo
o`00U_ooool2o`0001Cooooo00?o0000ooooooooool0^Oooool00:Wooooo0_l000000ooooooo0000
ooooo`2jooooo`00Woooool2o`0000Sooooo0_l000001?oooooo0000o`000?l0000Cooooo`;o0000
2?ooool2o`0009[ooooo002?ooooo`;o000000?oooooo`000?l000002oooool2o`0000_ooooo00?o
0000ooooooooool04oooool2o`0000Oooooo0ol0002Jooooo`00Soooool2o`000003ooooool0003o
000001Sooooo00?o0000ooooooooool07?ooool2o`0009_ooooo002Dooooo`;o00005_ooool00ol0
003oooooooooo`0?ooooo`Co0000Y_ooool009Cooooo0_l0000?ooooo`;o00001Oooool00ol0003o
ooooooooo`0?ooooo`Co00002Oooool2o`0009_ooooo002Uooooo`;o00001Oooool00ol0003ooooo
ooooo`0Looooo`;o0000Voooool00:cooooo00?o0000ooooooooool03oooool2o`0000Sooooo0_l0
002Nooooo`00[?ooool00ol0003oooooooooo`0?ooooo`;o00002?ooool2o`0009kooooo002Aoooo
o`;o00006Oooool3o`0002Oooooo0_l0002@ooooo`00TOooool2o`0001Gooooo0_l00002ooooo`03
o`000?oooooooooo00gooooo0_l0000Hooooo`;o0000T?ooool009gooooo0_l00009ooooo`;o0000
0_ooool00ol0003oooooooooo`02ooooo`;o00002Oooool2o`0001Kooooo0_l0002Booooo`00WOoo
ool2o`0000gooooo00?o0000ooooooooool00_ooool2o`0000Oooooo0_l0000Hooooo`;o0000T_oo
ool00:Cooooo0_l00006ooooo`03o`000?oooooooooo00_ooooo0_l0000Gooooo`;o0000Toooool0
0:Cooooo0_l00006ooooo`03o`000?oooooooooo00;o00008_ooool2o`0009?ooooo002=ooooo`;o
00002_ooool2o`0000Wooooo0_l00006ooooo`03o`000?oooooooooo00;o00008oooool2o`0009;o
oooo0028ooooo`;o00000oooool2o`0000[ooooo0_l00009ooooo`;o00001_ooool00ol0003ooooo
ooooo`0Uooooo`;o0000T_ooool008Sooooo0_l00003ooooo`;o00002oooool2o`00013ooooo00?o
0000ooooooooool04oooool4o`000:;ooooo0028ooooo`;o00004?ooool2o`00013ooooo0ol0000C
ooooo`Co0000X_ooool009Wooooo0_l0000Aooooo`03o`000?oooooooooo027ooooo0_l0002Foooo
o`00VOooool2o`00017ooooo00?o0000ooooooooool01Oooool2o`0000[ooooo0_l0000>ooooo`;o
0000U_ooool00:cooooo00?o0000ooooooooool01Oooool2o`0000[ooooo0ol0002Uooooo`00[?oo
ool00ol0003oooooooooo`04ooooo`;o00003?ooool2o`000:Gooooo0029ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool00_l00002ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`04ooooo`;o00006_ooool2o`0009Oooooo
0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool0
0_l00005ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool07oooool3o`0009Oooooo
0029ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool07oooool2o`0009Sooooo0029ooooo`05o`000?oo
ooooooooooooool000003_ooool00olQ8B7oooooooooo`03ooooo`;o000000?oooooogMgMolb<S80
1Oooool3o`0001cooooo0_l0002Kooooo`00ROooool01Ol0003ooooooooooooooooo000000;ooooo
0_l00005ooooo`;o00000oooool00omEEEGoc<c<ooooo`03ooooo`?o000000?o<S8bolc<c?ooool0
1?ooool00ol0003oooooooooo`0Looooo`;o0000Voooool008Wooooo00Go410@oooooooooooooooo
oa0@4002ooooo`;o00001Oooool2o`0000?ooooo00?oZJVYogMgMoooool00oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00cooooo0_l0002[ooooo`00ROooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool03?ooool2o`0000cooooo0_l0002Mooooo`00ROooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Cooooo0_l00005ooooo`Go00001?ooool4o`0000Kooooo00?o0000oooooooo
ool06_ooool2o`0009gooooo002Booooo`;o00006?ooool00ol0003oooooooooo`0:ooooo`;o0000
[Oooool009;ooooo0_l0000Hooooo`03o`000?oooooooooo00[ooooo0_l0002]ooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Hooooo`;o00004_oo
ool3o`000003ooooool0003o00000;Kooooo002Hooooo`;o00004_ooool01?l0003ooooooooooooo
ool2o`000;Kooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`;o0000^_ooool009_ooooo0_l0000?ooooo`;o0000^_ooool009_ooooo0_l0
000?ooooo`03o`000?oooooooooo00_ooooo0_l0002/ooooo`00[?ooool00ol0003oooooooooo`0;
ooooo`;o0000[?ooool009_ooooo0_l0000?ooooo`03o`000?oooooooooo00_ooooo0_l0002/oooo
o`00Voooool2o`0000oooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`05ooooo`;o00003oooool2o`000:7o
oooo002/ooooo`03o`000?oooooooooo00;ooooo0_l000000ooooooo0000o`00000?ooooo`;o0000
XOooool00:cooooo00?o0000ooooooooool00_ooool2o`000;Gooooo002/ooooo`?o0000^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo0_l0002jooooo`00[?ooool2o`000;[ooooo002Koooo
o`;o00001Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0^Oooool009_o
oooo0_l000000ooooooo0000o`000004ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0^Oooool009kooooo0_l00004ooooo`03o`000?oooooooooo00Gooooo0ol0002iooooo`00Y?oo
ool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0
003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00X_ooool00omEEEGoIVIV
o`000033ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
Z_ooool01?l@413o0000o`000?l0002jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zooo
ool00ol0003oooooooooo`2jooooo`00Zoooool01_l0003oMgMgo`000?l0003oEEEEonk^k[Oooooo
002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoEEEE]oooool00:_ooooo00?o0000onk^k_ooool0
0_ooool00ol0003oooooooooo`2eooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03o`000?oo
oooooooo0;Gooooo002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoIVIV]oooool00:[ooooo00?o
410@o`000?mgMgL00_l000000omVIVKok^k^ooooo`2fooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.59904 .28384 Mdot
.64 .62778 Mdot
.44753 .55851 Mdot
.55107 .51928 Mdot
.46909 .81597 Mdot
.40807 .74103 Mdot
.46444 .66691 Mdot
.71199 .36604 Mdot
.47695 .02741 Mdot
.56296 .4592 Mdot
.50199 .75847 Mdot
.72766 .45489 Mdot
.39102 .70275 Mdot
.54105 .6674 Mdot
.72262 .45655 Mdot
.42371 .63156 Mdot
.44139 .17994 Mdot
.38357 .62545 Mdot
.56402 .37449 Mdot
.6904 .50498 Mdot
.38697 .65609 Mdot
.58237 .77568 Mdot
.55211 .82412 Mdot
.37936 .49882 Mdot
.71475 .63004 Mdot
.59466 .42198 Mdot
.43395 .71968 Mdot
.54485 .31938 Mdot
.68733 .55922 Mdot
.63682 .63376 Mdot
.38104 .46342 Mdot
.48821 .02851 Mdot
.66842 .26667 Mdot
.56884 .2836 Mdot
.62281 .53627 Mdot
.64684 .32129 Mdot
.51956 .92366 Mdot
.46656 .208 Mdot
.67823 .59952 Mdot
.73345 .50402 Mdot
.71248 .65307 Mdot
.61421 .42023 Mdot
.56117 .75955 Mdot
.6317 .36291 Mdot
.56381 .21328 Mdot
.43556 .22577 Mdot
.55783 .58801 Mdot
.39182 .20805 Mdot
.53724 .76445 Mdot
.68623 .52016 Mdot
.38333 .26743 Mdot
.64358 .72545 Mdot
.78185 .50647 Mdot
.60529 .64007 Mdot
.59019 .69602 Mdot
.58398 .13641 Mdot
.7141 .37704 Mdot
.44376 .17335 Mdot
.38607 .74515 Mdot
.53873 .17396 Mdot
.45995 .18101 Mdot
.43711 .9836 Mdot
.67608 .60425 Mdot
.47319 .73872 Mdot
.64391 .22975 Mdot
.54589 .08765 Mdot
.55669 .41793 Mdot
.4593 .7499 Mdot
.4863 .20686 Mdot
.38779 .32373 Mdot
.51658 .18062 Mdot
.51324 .40366 Mdot
.56231 .46364 Mdot
.52009 .29554 Mdot
.67619 .60338 Mdot
.5084 .47624 Mdot
.78183 .50709 Mdot
.51738 .22476 Mdot
.6605 .68151 Mdot
.58304 .63118 Mdot
.50443 .09139 Mdot
.64124 .61002 Mdot
.54391 .42465 Mdot
.6196 .45169 Mdot
.67186 .26823 Mdot
.41491 .48316 Mdot
.45149 .80015 Mdot
.41634 .6775 Mdot
.41258 .28052 Mdot
.4525 .73918 Mdot
.7125 .63609 Mdot
.64308 .14819 Mdot
.4277 .37496 Mdot
.40413 .44047 Mdot
.42183 .54792 Mdot
.61085 .10497 Mdot
.54758 .64506 Mdot
.38119 .2918 Mdot
.78215 .53556 Mdot
.42858 .20818 Mdot
.62139 .34085 Mdot
.39607 .52567 Mdot
.72352 .43902 Mdot
.6432 .41141 Mdot
.46163 .07395 Mdot
.58613 .32506 Mdot
.54089 .22169 Mdot
.58063 .46734 Mdot
.4297 .36032 Mdot
.38861 .31813 Mdot
.56249 .56952 Mdot
.55208 .50924 Mdot
.47439 .02588 Mdot
.67156 .3852 Mdot
.66604 .8614 Mdot
.53198 .49638 Mdot
.4942 .18525 Mdot
.60018 .15192 Mdot
.55734 .09865 Mdot
.55051 .8801 Mdot
.39501 .73072 Mdot
.51819 .97963 Mdot
.45175 .90286 Mdot
.68588 .58012 Mdot
.39046 .29989 Mdot
.54498 .58289 Mdot
.67885 .42185 Mdot
.54329 .03027 Mdot
.64697 .46884 Mdot
.47588 .71367 Mdot
.54603 .83652 Mdot
.63937 .40788 Mdot
.7305 .51056 Mdot
.39321 .62726 Mdot
.51285 .84334 Mdot
.67197 .64844 Mdot
.53442 .90915 Mdot
.6878 .49846 Mdot
.56012 .44501 Mdot
.6876 .31221 Mdot
.72584 .47818 Mdot
.3615 .57808 Mdot
.52177 .33056 Mdot
.52932 .27933 Mdot
.44467 .1729 Mdot
.68558 .44984 Mdot
.64684 .22241 Mdot
.57667 .45907 Mdot
.40439 .54326 Mdot
.54979 .94758 Mdot
.40016 .61449 Mdot
.42297 .31808 Mdot
.38007 .43802 Mdot
.49968 .3502 Mdot
.39493 .35772 Mdot
.58312 .83858 Mdot
.66798 .64744 Mdot
.59115 .14178 Mdot
.5242 .91677 Mdot
.57249 .8553 Mdot
.59838 .5725 Mdot
.65843 .69062 Mdot
.7135 .66552 Mdot
.60342 .23201 Mdot
.57348 .72876 Mdot
.60523 .30271 Mdot
.63542 .20452 Mdot
.50701 .09047 Mdot
.4679 .2054 Mdot
.57347 .85651 Mdot
.67883 .44007 Mdot
.43299 .34776 Mdot
.42288 .32385 Mdot
.46194 .80975 Mdot
.57967 .52871 Mdot
.66446 .2631 Mdot
.58941 .08017 Mdot
.39075 .42455 Mdot
.52443 .42649 Mdot
.68467 .56893 Mdot
.6089 .80037 Mdot
.73143 .55559 Mdot
.46583 .23171 Mdot
.70616 .67509 Mdot
.43177 .3947 Mdot
.4489 .04455 Mdot
.5293 .0173 Mdot
.49134 .02805 Mdot
.71918 .64264 Mdot
.53187 .81427 Mdot
.57523 .91293 Mdot
.68614 .4518 Mdot
.52633 .62635 Mdot
.69195 .31226 Mdot
.67128 .76623 Mdot
.7281 .47119 Mdot
.40521 .57291 Mdot
.71117 .25059 Mdot
.59519 .33684 Mdot
.47183 .2994 Mdot
.48241 .3009 Mdot
.52068 .45239 Mdot
.49681 .79801 Mdot
.73155 .29232 Mdot
.62648 .36054 Mdot
.5254 .38479 Mdot
.39152 .59486 Mdot
.5531 .51436 Mdot
.49218 .2866 Mdot
.481 .78617 Mdot
.46618 .92115 Mdot
.50667 .20603 Mdot
.50945 .09354 Mdot
.42726 .33959 Mdot
.61112 .31781 Mdot
.47228 .17752 Mdot
.71133 .67083 Mdot
.44302 .3282 Mdot
.48709 .11218 Mdot
.73217 .47088 Mdot
.48473 .17668 Mdot
.38455 .72891 Mdot
.48547 .07014 Mdot
.54087 .13784 Mdot
.41869 .5727 Mdot
.54221 .70702 Mdot
.64719 .59978 Mdot
.43075 .35873 Mdot
.72361 .46332 Mdot
.46996 .76103 Mdot
.49364 .35821 Mdot
.7285 .29056 Mdot
.47519 .84585 Mdot
.42985 .7061 Mdot
.55078 .94192 Mdot
.44368 .24183 Mdot
.64988 .45115 Mdot
.44395 .8953 Mdot
.63482 .38698 Mdot
.4409 .98829 Mdot
.45616 .8736 Mdot
.57488 .17849 Mdot
.51459 .17766 Mdot
.50827 .04457 Mdot
.43513 .65986 Mdot
.60643 .79588 Mdot
.40357 .63504 Mdot
.50804 .16785 Mdot
.6742 .61846 Mdot
.68145 .74314 Mdot
.53124 .47902 Mdot
.53022 .60485 Mdot
.58541 .82992 Mdot
.59248 .4189 Mdot
.41539 .38319 Mdot
.55976 .76887 Mdot
.50873 .52619 Mdot
.7025 .34492 Mdot
.37058 .44213 Mdot
.5062 .81819 Mdot
.43063 .70949 Mdot
.56683 .1735 Mdot
.51641 .62587 Mdot
.41094 .70314 Mdot
.56396 .21873 Mdot
.55165 .61713 Mdot
.47313 .87753 Mdot
.66326 .37105 Mdot
.59945 .49525 Mdot
.66482 .36836 Mdot
.57505 .73449 Mdot
.56425 .46527 Mdot
.55529 .72003 Mdot
.58644 .8344 Mdot
.48738 .23228 Mdot
.56898 .62652 Mdot
.39736 .18052 Mdot
.48789 .78261 Mdot
.3907 .41697 Mdot
.67889 .61113 Mdot
.44301 .6667 Mdot
.472 .23198 Mdot
.52826 .91095 Mdot
.71949 .41317 Mdot
.58209 .48676 Mdot
.44942 .35903 Mdot
.55914 .64917 Mdot
.65633 .33283 Mdot
.40708 .39544 Mdot
.46491 .07566 Mdot
.52499 .01361 Mdot
.40603 .84729 Mdot
.7163 .41287 Mdot
.41049 .86133 Mdot
.50964 .58562 Mdot
.41582 .88453 Mdot
.53396 .95716 Mdot
.63261 .27584 Mdot
.72021 .4385 Mdot
.56851 .68819 Mdot
.50255 .86299 Mdot
.64486 .43362 Mdot
.50171 .03845 Mdot
.71804 .62299 Mdot
.54779 .63773 Mdot
.38933 .22708 Mdot
.5979 .45426 Mdot
.43172 .46123 Mdot
.48297 .91939 Mdot
.46848 .14594 Mdot
.41291 .81984 Mdot
.57608 .91529 Mdot
.53083 .53215 Mdot
.51591 .14564 Mdot
.59652 .35367 Mdot
.66225 .26357 Mdot
.5056 .66667 Mdot
.73013 .56371 Mdot
.62971 .83014 Mdot
.3747 .23892 Mdot
.5126 .70319 Mdot
.38917 .56353 Mdot
.62228 .47158 Mdot
.66379 .65755 Mdot
.52964 .73886 Mdot
.46147 .30624 Mdot
.49211 .65435 Mdot
.51652 .18285 Mdot
.72701 .43043 Mdot
.59825 .80689 Mdot
.42205 .55557 Mdot
.52459 .87215 Mdot
.45851 .70268 Mdot
.52114 .45811 Mdot
.64503 .61043 Mdot
.41919 .7922 Mdot
.57161 .73321 Mdot
.59844 .5703 Mdot
.51521 .76409 Mdot
.77991 .46169 Mdot
.59445 .43689 Mdot
.64775 .55425 Mdot
.47586 .73746 Mdot
.63229 .20525 Mdot
.45186 .76551 Mdot
.68605 .47507 Mdot
.62661 .66355 Mdot
.4818 .25228 Mdot
.41738 .3118 Mdot
.36196 .59214 Mdot
.72802 .45076 Mdot
.41358 .8792 Mdot
.65749 .34945 Mdot
.57939 .65735 Mdot
.58065 .30234 Mdot
.67739 .42741 Mdot
.43819 .80746 Mdot
.72722 .44706 Mdot
.39471 .12089 Mdot
.58535 .19432 Mdot
.72984 .50052 Mdot
.72873 .57564 Mdot
.70489 .68561 Mdot
.51938 .56721 Mdot
.50766 .81378 Mdot
.72545 .47968 Mdot
.70776 .35813 Mdot
.51379 .60241 Mdot
.42578 .13541 Mdot
.58956 .41655 Mdot
.38866 .52767 Mdot
.61438 .32144 Mdot
.39635 .18946 Mdot
.64862 .44342 Mdot
.47126 .96229 Mdot
.63429 .73601 Mdot
.56589 .80069 Mdot
.44107 .94234 Mdot
.56099 .81151 Mdot
.72308 .58486 Mdot
.6225 .92128 Mdot
.517 .92302 Mdot
.41113 .23723 Mdot
.47599 .31774 Mdot
.66531 .76854 Mdot
.40724 .31367 Mdot
.49987 .63059 Mdot
.73034 .57593 Mdot
.39121 .29273 Mdot
.45808 .31103 Mdot
.53566 .33669 Mdot
.56777 .32668 Mdot
.41695 .6277 Mdot
.4102 .12446 Mdot
.51942 .1022 Mdot
.50118 .99387 Mdot
.73044 .5675 Mdot
.53394 .21425 Mdot
.77088 .41734 Mdot
.56258 .26517 Mdot
.58033 .51715 Mdot
.57315 .59951 Mdot
.44065 .45446 Mdot
.72191 .40871 Mdot
.72633 .44626 Mdot
.43884 .73604 Mdot
.46407 .25827 Mdot
.41223 .58842 Mdot
.42842 .32724 Mdot
.62569 .84533 Mdot
.40281 .48619 Mdot
.60604 .23478 Mdot
.52925 .35622 Mdot
.42641 .30045 Mdot
.49828 .68659 Mdot
.41511 .67588 Mdot
.55115 .24769 Mdot
.40963 .516 Mdot
.53328 .4233 Mdot
.53465 .96304 Mdot
.68634 .30836 Mdot
.50249 .47849 Mdot
.62018 .56972 Mdot
.54064 .22141 Mdot
.42053 .20126 Mdot
.59551 .45796 Mdot
.43917 .25314 Mdot
.65715 .7866 Mdot
.65461 .15929 Mdot
.65101 .47245 Mdot
.7223 .76514 Mdot
.64221 .40084 Mdot
.54076 .5042 Mdot
.49754 .03939 Mdot
.72595 .49348 Mdot
.49309 .77264 Mdot
.62768 .65716 Mdot
.78068 .4733 Mdot
.47703 .25327 Mdot
.43326 .42576 Mdot
.5761 .56838 Mdot
.56585 .17094 Mdot
.59246 .58717 Mdot
.68345 .20504 Mdot
.45595 .294 Mdot
.61856 .56503 Mdot
.6146 .41697 Mdot
.43312 .6537 Mdot
.53097 .50355 Mdot
.51303 .27724 Mdot
.71173 .36629 Mdot
.52147 .60819 Mdot
.66813 .65899 Mdot
.64966 .5734 Mdot
.54784 .1899 Mdot
.67276 .39524 Mdot
.42569 .13703 Mdot
.50654 .17056 Mdot
.55295 .03794 Mdot
.54393 .36246 Mdot
.72874 .44023 Mdot
.68112 .74539 Mdot
.55191 .61396 Mdot
.41338 .87769 Mdot
.59775 .47637 Mdot
.4073 .32487 Mdot
.68592 .47026 Mdot
.62444 .34845 Mdot
.57051 .40334 Mdot
.421 .29052 Mdot
.57065 .28608 Mdot
.42634 .96711 Mdot
.52807 .81734 Mdot
.50757 .45842 Mdot
.5818 .71098 Mdot
.57768 .65372 Mdot
.52085 .55848 Mdot
.50281 .72504 Mdot
.60824 .62941 Mdot
.51745 .8379 Mdot
.51593 .38122 Mdot
.57955 .36624 Mdot
.55042 .09305 Mdot
.47592 .81771 Mdot
.53913 .17953 Mdot
.51878 .25543 Mdot
.53505 .29829 Mdot
.4805 .69304 Mdot
.67822 .84483 Mdot
.47058 .69358 Mdot
.64262 .61897 Mdot
.38734 .74565 Mdot
.61311 .24866 Mdot
.50466 .23187 Mdot
.68773 .52733 Mdot
.73242 .51995 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`;o0000/_ooool00:;ooooo00?oEEEEofIV
I_l000001oooool00ol0003oooooooooo`05ooooo`;o0000/_ooool00:cooooo00?o0000oooooooo
ool01_ooool2o`000;7ooooo002/ooooo`03o`000?oooooooooo00Kooooo0_l0002aooooo`00Xooo
ool2o`0000Oooooo0ol0002iooooo`00Xoooool3o`0000;ooooo0ol000000ooooooo0000ooooo`2j
ooooo`00Y?ooool2o`0000;ooooo0ol000000ooooooo0000ooooo`0<ooooo`;o0000[?ooool00:co
oooo00?o0000ooooooooool02oooool2o`000:cooooo002/ooooo`03o`000?oooooooooo00kooooo
0_l0002Yooooo`00Zoooool3o`0000oooooo0_l0002Yooooo`00Zoooool3o`000;[ooooo002Koooo
o`;o00003oooool01?l0003oooooo`000?l0002hooooo`00Voooool2o`0000oooooo00Co0000oooo
ool0003o0000^?ooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00Yoooool2o`0000?o
oooo00?o0000ooooooooool0^Oooool009oooooo0_l00006ooooo`;o00000oooool00ol0003ooooo
ooooo`2iooooo`00Woooool3o`0000[ooooo0ol0002iooooo`00X?ooool2o`0000[ooooo00?o0000
ooooooooool06_ooool2o`0009gooooo002/ooooo`03o`000?oooooooooo01[ooooo0_l0002Moooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0<ooooo`;o0000
Zoooool00:cooooo1?l0000;ooooo`;o0000Zoooool00:cooooo1Ol0000;ooooo`;o0000Z_ooool0
0:cooooo00?o0000ooooooooool00_l0000;ooooo`;o0000Z_ooool00:cooooo0ol0000?ooooo`;o
0000Z?ooool00:cooooo00?o0000ooooooooool00oooool2o`0000[ooooo0_l0002Xooooo`00[?oo
ool00ol0003oooooooooo`03ooooo`;o00007?ooool2o`0009Kooooo002/ooooo`03o`000?oooooo
oooo027ooooo0_l0002Fooooo`00Yoooool2o`0000?ooooo00?o0000ooooooooool0^Oooool00:Oo
oooo0_l00003ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0^Oooool008Wooooo0_l000000oooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0^Oooool0087ooooo1_l00002ooooo`;o00000_ooool00ol@413o0000o`00000;ooooo`03ojVY
ZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000;Wooooo0029ooooo`04o`000?oo
ooooooooooooo`?o00003?ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0^Oooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEE
EOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;Wo
oooo0029ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0^Oooool008Wooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o00001?ooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0:ooooo`;o00003?ooool2o`0009oooooo0029ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2o`0000Cooooo1Ol00004ooooo`Co00001_ooool00ol0
003oooooooooo`0:ooooo`;o00003?ooool2o`0009oooooo002/ooooo`03o`000?oooooooooo01_o
oooo0_l0002Looooo`00XOooool2o`0000Wooooo00?o0000ooooooooool00_ooool2o`0001Oooooo
0_l0002Looooo`00XOooool2o`0000Wooooo00?o0000ooooooooool00_ooool2o`0002Sooooo0_l0
002;ooooo`00[?ooool3o`0001kooooo0_l0000<ooooo`;o0000Roooool00:cooooo00?o0000oooo
ooooool07_ooool2o`0009Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo033ooooo0_l00027ooooo`00[?ooool00ol0003oooooooooo`0`ooooo`;o0000Qooo
ool00:cooooo00Co0000ooooool0003o0000^?ooool00:cooooo00Co0000ooooool0003o00004Ooo
ool2o`000:Gooooo002Iooooo`;o00004Oooool01?l0003oooooo`000?l00008ooooo`;o00001ooo
ool3o`000:Cooooo002Iooooo`;o00003?ooool2o`0000?ooooo0ol00009ooooo`;o00002?ooool2
o`000:Cooooo002Hooooo`;o00002?ooool2o`0000?ooooo0_l00003ooooo`04o`000?oooooooooo
ooooo`;o00001_ooool2o`0000[ooooo0_l0002Rooooo`00R_ooool2o`0000cooooo0_l00004oooo
o`;o00000_ooool2o`0000Sooooo00Co0000oooooooooooooooo0ol00005ooooo`;o00002_ooool2
o`000:;ooooo002:ooooo`;o00004_ooool2o`0000[ooooo0ol00004ooooo`;o0000]Oooool008Wo
oooo0_l0000Oooooo`?o0000^oooool008Wooooo0_l0000Qooooo`03o`000?oooooooooo00cooooo
0_l0002[ooooo`00[?ooool00ol0003oooooooooo`0<ooooo`;o00002oooool2o`0009kooooo002/
ooooo`03o`000?oooooooooo01Wooooo0_l0002Nooooo`00TOooool2o`0001Wooooo0ol0002ioooo
o`00TOooool2o`0001Wooooo00?o0000ooooooooool0:Oooool2o`0008kooooo002Qooooo`;o0000
1?ooool2o`0000?ooooo00Co0000ooooool0003o00009oooool3o`0000kooooo0_l0001nooooo`00
R?ooool2o`0000[ooooo0_l0000;ooooo`;o00001?ooool2o`0000?ooooo00Co0000ooooool0003o
00009oooool2o`0000oooooo0_l0001nooooo`00R?ooool2o`0000[ooooo0_l0000;ooooo`;o0000
2Oooool00ol0003oooooooooo`0Booooo`;o0000YOooool00:cooooo00?o0000ooooooooool02?oo
ool2o`0000Sooooo0_l0002Uooooo`00[?ooool00ol0003oooooooooo`08ooooo`;o00002?ooool2
o`000:Gooooo002/ooooo`03o`000?oooooooooo00[ooooo0_l00006ooooo`;o00006Oooool2o`00
08[ooooo002Fooooo`;o00005?ooool3o`0000;ooooo0_l00006ooooo`;o00008Oooool2o`0008[o
oooo0027ooooo`;o00003Oooool2o`0001Cooooo00?o0000ooooooooool00_ooool2o`000;Gooooo
0027ooooo`;o00005oooool2o`0000[ooooo0ol0000/ooooo`;o0000Roooool00:3ooooo1?l00003
ooooo`;o00000oooool3o`0001oooooo0ol0000:ooooo`;o0000Roooool008kooooo0_l0000Boooo
o`;o00000oooool2o`0000?ooooo00?o0000ooooooooool07oooool3o`0009Oooooo0022ooooo`;o
00002_ooool2o`0001cooooo00?o0000ooooooooool0^Oooool008;ooooo0_l0000=ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool2o`0000;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0^Oooool0097ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`;o00000_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0^Oooool008Wo
oooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00gooooo0_l0000Cooooo`;o0000UOooool0097ooooo00Go0000oooooooo
ooooooooo`00000?ooooo`03ogMgMol0003o000000Cooooo0ol0000=ooooo`;o00004oooool2o`00
01kooooo0_l0001eooooo`00TOooool01_l0003ooooooooooooooooo0000ooooo`;o00002Oooool0
0ol0003o8B4Qo`000003o`0000Cooooo00?o0000ooooooooool00oooool2o`0003gooooo0_l0001e
ooooo`00TOooool01_l@413ooooooooooooooooo410@ooooo`;o00001oooool3o`000003ooooool0
003o000000Kooooo00?o0000ooooooooool00oooool2o`000;Cooooo002Aooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02_ooool3o`0000Wooooo00?o0000ooooooooool0^Oooool0097ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`0Aooooo`;o00007ooo
ool3o`0008Cooooo0025ooooo`;o00009Oooool00ol0003oooooooooo`0Aooooo`;o00007oooool5
o`0008;ooooo0025ooooo`;o00009Oooool00ol0003oooooooooo`0dooooo`?o0000P_ooool00:co
oooo00?o0000ooooooooool0^Oooool00:cooooo0ol000000ooooooo0000o`00000Uooooo`;o0000
Soooool00:cooooo00Co0000oooooooooooooooo0_l00003ooooo`;o00008?ooool2o`0008oooooo
002?ooooo`;o00006oooool00ol0003oooooooooo`06ooooo`;o0000/Oooool008oooooo0_l0000K
ooooo`03o`000?oooooooooo01?ooooo0ol00007ooooo`;o0000V_ooool00:Wooooo0_l000000ooo
oooo0000ooooo`0Dooooo`?o00001oooool2o`0009[ooooo0024ooooo`;o00002oooool2o`0001Ko
oooo0_l000000ooooooo0000ooooo`19ooooo`?o0000K_ooool008Cooooo0_l00002ooooo`;o0000
1oooool2o`0000[ooooo0_l0000=ooooo`03o`000?oooooooooo04Sooooo0ol0001^ooooo`00R?oo
ool2o`0001?ooooo0_l0000=ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`;o0000[ooo
ool008Oooooo0_l0000:ooooo`;o00003Oooool2o`0000;ooooo0_l00004ooooo`?o00000oooool2
o`0000?ooooo0_l0002_ooooo`00Qoooool2o`0000[ooooo0_l0000=ooooo`;o00000_ooool2o`00
00Cooooo00?o0000ooooooooool05oooool2o`0000Kooooo0_l0002Hooooo`00Woooool2o`0000_o
oooo00?o0000ooooooooool05oooool2o`0000Kooooo0_l0002Hooooo`00Woooool2o`0000_ooooo
00?o0000ooooooooool0>_ooool2o`0007gooooo002=ooooo`;o000000?oooooo`000?l000003?oo
ool2o`0000cooooo00?o0000ooooooooool0>_ooool4o`0007_ooooo002=ooooo`;o000000?ooooo
o`000?l000003?ooool2o`0000cooooo00?o0000ooooooooool0>_ooool4o`0007_ooooo0027oooo
o`;o00002Oooool2o`00013ooooo0_l00006ooooo`03o`000?oooooooooo00_ooooo0_l0000Doooo
o`;o0000U_ooool008Oooooo0_l00009ooooo`;o00004?ooool2o`0000Kooooo00?o0000oooooooo
ool02oooool2o`0001Cooooo0ol00009ooooo`;o0000R_ooool008Oooooo0_l00004ooooo`;o0000
0oooool2o`0001Sooooo0ol0000Iooooo`;o00001oooool2o`0000Wooooo0_l0002:ooooo`00Qooo
ool2o`0000Cooooo0_l00003ooooo`Co00000oooool2o`00017ooooo00?o0000ooooooooool04ooo
ool2o`0000Cooooo0_l0002Nooooo`00U?ooool2o`0000?ooooo0_l0000Aooooo`03o`000?oooooo
oooo00Cooooo0_l0000=ooooo`;o0000Y?ooool00:cooooo00?o0000ooooooooool01?ooool2o`00
02[ooooo0_l00027ooooo`00[?ooool00ol0003oooooooooo`08ooooo`;o00004_ooool2o`0001;o
oooo0_l00027ooooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool02?ooool2o`0001;ooooo
0_l00007ooooo`;o0000T_ooool009Cooooo0_l0000Fooooo`03o`000?oooooooooo02Gooooo0_l0
002Booooo`00[?ooool00ol0003oooooooooo`0oooooo`;o0000N?ooool009Gooooo0_l0000Eoooo
o`03o`000?oooooooooo02Kooooo0_l00009ooooo`;o00003?ooool2o`0007Sooooo002Eooooo`;o
00005?ooool4o`0002Kooooo0_l00009ooooo`;o0000Q_ooool00:_ooooo0_l0000Nooooo`;o0000
Voooool008Wooooo0_l0000:ooooo`;o00001?ooool2o`0000cooooo0_l000000ooooooo0000oooo
o`07ooooo`;o00005?ooool2o`0002?ooooo0_l0001fooooo`00ROooool2o`0000Wooooo0ol00004
ooooo`;o00003?ooool2o`000003ooooool0003ooooo00Oooooo0_l0000Nooooo`;o00006Oooool2
o`0007Kooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`0;ooooo`;o00006Oooool4o`00
08oooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0;ooooo`;o00002_ooool2
o`0000oooooo0_l0000Hooooo`?o0000M?ooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`0Gooooo`;o00006Oooool3o`0000gooooo0ol0001dooooo`00POooool6
o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0booooo`?o0000Q?ooool008Wooooo00Go0000
ooooooooooooooooo`000006ooooo`;o00001Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol0000Booooo`;o0000;oooool2o`0007Cooooo0029ooooo`05o`000?oooooo
ooooooooool000001_ooool2o`0000Kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool04_ooool2o`0002oooooo0_l0001dooooo`00ROoo
ool01Ol@413ooooooooooooooooo410@00;ooooo0_l0000;ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`;o0000]Oooool008Wooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`02ooooo`;o00001oooool01Ol0003o^[ZjoooooonHV9So410@00Co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`;o000000?oooooo`000?l0
0000;_ooool2o`0008;ooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So
410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo00Gooooo0_l0000Roooo
o`;o00002_ooool2o`0008;ooooo002/ooooo`03o`000?oooooooooo02Wooooo0_l0002>ooooo`00
SOooool2o`0000Kooooo0_l0000Eooooo`03o`000?oooooooooo03Kooooo0_l00021ooooo`00SOoo
ool2o`0000Kooooo0_l0000Eooooo`03o`000?oooooooooo03Kooooo0_l00021ooooo`00[?ooool3
o`0002cooooo0_l0002;ooooo`00[?ooool01?l0003oooooooooooooool2o`00017ooooo0_l0000F
ooooo`;o0000Roooool00:cooooo00Co0000oooooooooooooooo0_l0000Aooooo`;o0000Xoooool0
0:cooooo00?o0000ooooooooool0:oooool2o`0001Wooooo0_l0001aooooo`00[?ooool00ol0003o
ooooooooo`0[ooooo`?o00005_ooool4o`00077ooooo002/ooooo`03o`000?oooooooooo01[ooooo
0_l0000@ooooo`;o00005_ooool3o`0007;ooooo0027ooooo`;o00008oooool00ol0003ooooooooo
o`0?ooooo`;o00002Oooool3o`0000Gooooo0_l0000booooo`;o0000HOooool008Oooooo0_l0000S
ooooo`03o`000?oooooooooo00oooooo0_l0000:ooooo`?o00001?ooool2o`0001Cooooo0_l0000L
ooooo`;o0000HOooool008Oooooo0_l0000=ooooo`;o00005?ooool3o`0000Sooooo0_l000000ooo
oooo0000o`00000?ooooo`;o00001?ooool2o`0001Cooooo0_l0001oooooo`00Qoooool2o`0000go
oooo0_l0000Dooooo`03o`000?oooooooooo00Gooooo0_l000001?oooooo0000o`000?ooool2o`00
02[ooooo0_l00020ooooo`00[?ooool00ol0003oooooooooo`05ooooo`;o0000<?ooool2o`0000oo
oooo0_l0001_ooooo`00[?ooool00ol0003oooooooooo`0/ooooo`;o00006_ooool2o`0006oooooo
002/ooooo`03o`000?oooooooooo01cooooo0_l0000>ooooo`;o0000Roooool008Cooooo0_l00006
ooooo`;o00007_ooool00ol0003oooooooooo`0Looooo`;o00006_ooool2o`0000_ooooo1Ol0001_
ooooo`00POooool2o`000003ooooool0003o000000Kooooo0_l0000Nooooo`03o`000?oooooooooo
02kooooo0_l00008ooooo`;o00002oooool5o`0006oooooo0021ooooo`;o0000:Oooool00ol0003o
ooooooooo`0@ooooo`;o00007?ooool2o`0001Oooooo0_l0001`ooooo`00[?ooool00ol0003ooooo
ooooo`0@ooooo`;o0000:?ooool2o`0000_ooooo0ol0001_ooooo`00[?ooool3o`0000?ooooo0_l0
000Oooooo`;o00002?ooool2o`0000[ooooo0_l0000<ooooo`;o0000Koooool009Sooooo0_l0000B
ooooo`03o`000?oooooooooo00?ooooo0_l0000Hooooo`;o00001Oooool2o`0000Sooooo0_l0000:
ooooo`;o00003?ooool2o`0006oooooo002Hooooo`;o00004_ooool01?l0003oooooo`000?l00003
ooooo`;o00004?ooool2o`0000Cooooo0ol0000Wooooo`Co0000Koooool000Wooooo1?l000000ol@
413oooooooooo`0Fooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000
onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00CoA4A4o`000?l0003o<S8b0_l0000E
ooooo`04o`000?oooooo0000o`0000?ooooo0_l0000;ooooo`;o00000oooool2o`000004onk^k_lb
<S;o0000oc8b<P;o00001?ooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oM
gMd03oooool01Oo^k^ko0000o`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`03odA4A?l0003o0000
00;o00003oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^ko
oooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`Co000000?o410@ooooooooool04_oo
ool000_ooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q0_l00002ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omg
MgOo0000o`00000Eooooo`03o`000?oooooooooo017ooooo0_l00005ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb
<S;ooooo00kooooo00GoMgMgo`000?l0003oV9RHogMgM`05ooooo`;o8B4Q2?ooool2o`0000oooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03
ogMgMolb<S;ooooo01Wooooo00?o0000ooooooooool05?ooool000Ko00001Oooool00ol0003ooooo
ooooo`0@ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOoo
ool02?ooool00ol0003oooooooooo`05ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@
013ooooo00?o0000ooooooooool01Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@4007
ooooo`;o00000oooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool04Oooool3o`0000?ooooo0_l00003ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RH
ob4Q8Oo^k^h02Oooool00ol0003oooooooooo`0=ooooo`05oa0@4?l0003o0000ooooool@41004?oo
ool00ol0003oooooooooo`0=ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEE
ooooo`08ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05?ooool000_ooooo00?o
0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool0
1_ooool00omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo
<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07oooo
o`03ogMgMolb<S;ooooo01Gooooo00?o0000ooooooooool04_ooool2o`0000?ooooo0_l00003oooo
o`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h00_l00005ooooo`03ogMgMolb<S;ooooo
00?ooooo0_l00009ooooo`03o`000?oooooooooo00?o00003_ooool00omgMgOo<S8booooo`0>oooo
o`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;o
oooo01Wooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol0
003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`03oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<01Kooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooo
oooo000000Sooooo0_l00004ooooo`03ogMgMomVIVKo000000;o000000Koooooo`000?lQ8B7o0000
oc8b<_o<c<`4ooooo`;o00002Oooool00ol0003oooooooooo`03o`0000_ooooo00?o0000ob4Q8Ol0
00000_l0000?ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`06_ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0
003oooooooooo`0Hooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03
ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oo
oooooooo017ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool06?ooool4o`0001Oooooo00Go410@oooooooooooooooooa0@4002o`0000Ko
oooo0_l00005ooooo`06o`000?oooooo0000o`000?oooooo00002?ooool2o`0000Wooooo00Go410@
oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00;o00003oooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`0Aooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool06?oo
ool4o`0000Kooooo0_l0000?ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_l00009ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`06ooooo`;o00002Oooool01OmgMgOo
V9RHo`000?l0003oMgMg00cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool05?ooool000Wooooo00?oEEEEofIVI_l000006_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
00;ooooo1_l0000Gooooo`;o00002?ooool2o`0000oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o0000
onk^kP0<ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co
00006Oooool00omEEEGoIVIVo`00000Fooooo`00Roooool2o`0000;ooooo0_l0000Kooooo`03o`00
0?oooooooooo0;Wooooo002;ooooo`;o00007oooool00ol0003oooooooooo`0Hooooo`;o0000Wooo
ool00:cooooo00?o0000ooooooooool06?ooool2o`0009Cooooo0_l00002ooooo`;o00001Oooool0
0:cooooo00?o0000ooooooooool07Oooool2o`0002Sooooo0_l0001Uooooo`06onk^k_lQ8B7oQhN7
okZj^_l0003ogMgM1Oooool00:cooooo00?o0000ooooooooool01oooool2o`0001Cooooo0_l0000L
ooooo`;o00002_ooool2o`0006Kooooo00CogMgMo`000?l@413oc<c<1_ooool000Ooooooool0001<
o`0000cooooo00Cok^k^ob4Q8Ol@413ok^k^1_ooool000Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0ol00005ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool3o`000003ooooool0003o000000;ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool4o`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:
ooooo`04ob4Q8OmgMgOoMgMgoc8b<PKooooo0007ooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool01oooool2o`000003ooooool0003o000001_ooooo00?o0000ooooooooool04Oooool2
o`0000gooooo0_l00004ooooo`03o`000?oooooooooo00Oooooo0_l0000Mooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool02Oooool2o`0000;ooooo0_l00005ooooo`00[?ooool00ol0
003oooooooooo`0>ooooo`;o0000:oooool2o`0000cooooo0_l0000?ooooo`;o0000GOooool00:co
oooo00?o0000ooooooooool03_ooool2o`0003Wooooo0_l0001^ooooo`00S_ooool2o`0001cooooo
00?o0000ooooooooool03_ooool2o`000:Wooooo002>ooooo`;o00007?ooool00ol0003ooooooooo
o`0=ooooo`?o00001oooool2o`000:3ooooo002/ooooo`03o`000?oooooooooo00gooooo0_l00008
ooooo`;o00008Oooool2o`0000gooooo0_l0001^ooooo`00ROooool2o`00027ooooo0ol0000joooo
o`;o00003Oooool2o`0006kooooo0027ooooo`Co00008Oooool01?l0003oooooo`000?l0000Foooo
o`;o00008_ooool2o`0007cooooo0027ooooo`;o00008oooool01?l0003oooooo`000?l0000Foooo
o`;o00008_ooool2o`0007cooooo002/ooooo`03o`000?oooooooooo00Oooooo0_l0002`ooooo`00
[?ooool00ol0003oooooooooo`07ooooo`;o00007?ooool2o`0003?ooooo0_l0001Mooooo`00[?oo
ool00ol0003oooooooooo`0Uooooo`;o0000<oooool2o`0005gooooo002<ooooo`;o00007_ooool0
0ol0003oooooooooo`2iooooo`00S?ooool2o`0001kooooo00?o0000ooooooooool0^Oooool009;o
oooo0_l0000Hooooo`03o`000?oooooooooo0;Wooooo002Booooo`;o00006?ooool3o`000;Wooooo
002Booooo`;o00006?ooool00ol0003oooooooooo`0]ooooo`;o00006_ooool2o`0006kooooo002B
ooooo`;o00001_ooool2o`00013ooooo00?o0000ooooooooool00oooool2o`0002Sooooo0_l0000J
ooooo`;o0000K_ooool009[ooooo0_l0000@ooooo`03o`000?oooooooooo00?ooooo0_l0000eoooo
o`;o0000OOooool008Oooooo0_l0000Sooooo`03o`000?oooooooooo02Cooooo0_l0000Dooooo`;o
00003Oooool2o`0006kooooo0027ooooo`;o00008oooool00ol0003oooooooooo`03ooooo`;o0000
7oooool2o`0002?ooooo0_l0001^ooooo`00[?ooool00ol0003oooooooooo`03ooooo`;o00003?oo
ool2o`0000?ooooo0_l00005ooooo`;o00001Oooool2o`0001Cooooo0_l0000=ooooo`;o0000K_oo
ool008cooooo0_l00003ooooo`;o00006Oooool00ol0003oooooooooo`0Aooooo`;o00000oooool2
o`0000Gooooo0_l00005ooooo`;o00002?ooool2o`0000[ooooo0_l0001mooooo`00S?ooool2o`00
00?ooooo0_l0000Iooooo`?o00007Oooool2o`0000oooooo0_l0000Hooooo`?o0000K_ooool007ko
oooo0_l0000/ooooo`03o`000?oooooooooo03[ooooo0_l0000<ooooo`?o0000K_ooool007kooooo
0_l0000/ooooo`03o`000?oooooooooo00_ooooo0_l0000]ooooo`;o0000OOooool00:cooooo00?o
0000ooooooooool00_l00009ooooo`;o0000>Oooool2o`00077ooooo002?ooooo`;o00006oooool0
0ol0003oooooooooo`02o`0000kooooo0_l00009ooooo`;o0000:Oooool2o`00077ooooo001noooo
o`;o00003oooool2o`0001_ooooo00?o0000ooooooooool04?ooool2o`0000Wooooo0_l0002Loooo
o`00O_ooool2o`0000Sooooo0_l0000Rooooo`03o`000?oooooooooo0;Wooooo0028ooooo`;o0000
8_ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`0001Gooooo0_l0000Fooooo`;o00002?oo
ool2o`00083ooooo002/ooooo`04o`000?ooooooooooooooo`;o00004_ooool2o`0001Kooooo0_l0
0008ooooo`;o0000P?ooool00:cooooo00Co0000oooooooooooooooo0_l00004ooooo`;o0000;_oo
ool2o`00083ooooo002/ooooo`03o`000?oooooooooo00Cooooo0_l000000ooooooo0000o`00000R
ooooo`?o0000Roooool00:cooooo00?o0000ooooooooool01?ooool2o`0002Gooooo0ol0000:oooo
o`;o0000Ooooool008_ooooo0_l0000Oooooo`03o`000?oooooooooo00kooooo0_l0000Xooooo`;o
0000Ooooool008Wooooo00Gok^k^oc8b<_l0003o0000onk^kP05ooooo`;o8B4Q1?ooool5o`0000Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00kooooo0_l0000Loooo
o`;o00002?ooool2o`00087ooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool03_ooool2o`0001cooooo0_l00008ooooo`;o0000POooool008Gooooo0_l00002oooo
o`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooo
oooo00?ooooo0ol00015ooooo`;o0000L_ooool008Gooooo0_l000000ooooooo0000o`000003oooo
o`03o`000?oooooooooo00;o00002Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool00_ooool2o`000003ooooool0003o000000cooooo0_l0000Foooo
o`;o00006?ooool2o`0007;ooooo0028ooooo`;o00000oooool00ol0003oooooooooo`04o`0000So
oooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo0_l00003oooo
o`;o000000?oooooo`000?l000003?ooool2o`0000?ooooo0_l00006ooooo`;o00002Oooool2o`00
01Kooooo0_l0001dooooo`00ROooool01Ol@413ooooooooooooooooo410@00Cooooo0_l00009oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool2o`0001Wooooo0_l00006oooo
o`;o00002?ooool2o`0001Oooooo0_l0001dooooo`00ROooool00omgMgOoV9RHooooo`02o`0000_o
oooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool03?ooool2o`0001cooooo0_l0000Gooooo`;o0000M?ooool008Wooooo00?ok^k^oc8b<_l0
00000_l0000;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000oooo
ooooool03?ooool2o`00017ooooo0_l0000Rooooo`;o0000M?ooool00:cooooo00?o0000oooooooo
ool07oooool2o`0002Cooooo0_l0001booooo`00[?ooool00ol0003oooooooooo`0<ooooo`;o0000
=oooool2o`0007;ooooo002/ooooo`03o`000?oooooooooo00cooooo0_l00002ooooo`;o00008_oo
ool3o`0008;ooooo002/ooooo`?o00004?ooool2o`0002;ooooo0ol00022ooooo`00UOooool2o`00
01;ooooo0_l000000ooooooo0000ooooo`0Gooooo`;o0000:oooool2o`0007Cooooo0026ooooo`;o
00003Oooool2o`0001;ooooo0_l000000ooooooo0000ooooo`0Gooooo`?o00003_ooool2o`0000[o
oooo0ol0000=ooooo`;o0000M?ooool008Kooooo0_l0000>ooooo`;o00005?ooool00ol0003ooooo
ooooo`0Gooooo`;o00003_ooool2o`0000[ooooo0ol00023ooooo`00U_ooool2o`0001Cooooo00?o
0000ooooooooool09_ooool2o`00097ooooo002Iooooo`;o00001Oooool2o`0000[ooooo0ol0000:
ooooo`;o00006_ooool2o`0001_ooooo0_l0001dooooo`00VOooool2o`0000Gooooo0_l0000:oooo
o`?o00002_ooool2o`0003Kooooo0ol0001dooooo`00[?ooool00ol0003oooooooooo`12ooooo`;o
0000MOooool0093ooooo0_l0000Jooooo`?o0000@Oooool2o`0007Kooooo002@ooooo`;o00006_oo
ool00ol0003oooooooooo`11ooooo`;o0000M_ooool0093ooooo0_l0000Jooooo`03o`000?oooooo
oooo03;ooooo0_l00025ooooo`00[?ooool00ol0003oooooooooo`0booooo`;o00003?ooool2o`00
07Oooooo002[ooooo`;o00005Oooool2o`0002_ooooo0_l0001gooooo`00Zoooool2o`0001Gooooo
0_l0000Looooo`;o0000Q_ooool00:;ooooo0_l000000ooooooo0000o`000005ooooo`03o`000?oo
oooooooo037ooooo0_l00026ooooo`00X_ooool2o`000003ooooool0003o000000Gooooo00?o0000
ooooooooool06_ooool2o`0009gooooo002/ooooo`?o00006_ooool2o`0009gooooo0028ooooo`;o
00001?ooool2o`0000kooooo0_l0000<ooooo`04o`000?ooooooooooooooo`;o0000]_ooool008So
oooo0_l00004ooooo`;o00001?ooool2o`0000Sooooo0_l0000<ooooo`04o`000?oooooooooooooo
o`;o00001oooool2o`000:gooooo002Dooooo`?o00005Oooool00ol0003oooooooooo`0:ooooo`;o
0000[Oooool009Gooooo0_l0000Eooooo`03o`000?oooooooooo01Sooooo0_l0002Oooooo`00Y?oo
ool2o`0000Kooooo00?o0000ooooooooool06?ooool2o`0009oooooo002Tooooo`;o00001_ooool0
0ol0003oooooooooo`2iooooo`00U_ooool2o`0001Cooooo00?o0000ooooooooool03oooool2o`00
0:Sooooo002Fooooo`;o00005?ooool3o`0000oooooo0_l0000Kooooo`;o0000Roooool00:cooooo
0_l0000]ooooo`;o0000Roooool008Gooooo0_l00002ooooo`;o00008Oooool00ol0003ooooooooo
o`0Eooooo`;o0000X_ooool008Gooooo0_l00002ooooo`;o00008Oooool00ol0003oooooooooo`0D
ooooo`?o0000X_ooool009Oooooo0_l0000;ooooo`;o00001_ooool00ol0003oooooooooo`0Doooo
o`?o00004_ooool2o`0008kooooo002Gooooo`;o00000oooool2o`0000Gooooo0ol00006ooooo`03
o`000?oooooooooo00Kooooo0_l0000Qooooo`;o0000S_ooool008gooooo0_l00002ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool00olQ8B7o0000o`000004ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`06ooooo`;o0000<?ooool2o`0007oooooo0026ooooo`;o
00001Oooool2o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo03Sooooo0_l0001oooooo`00Q_ooool2o`0000Wo
oooo00Go410@oooooooooooooooooa0@4008ooooo`;o00001_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo03Sooooo0_l0001oooooo`00TOooool01Ol0003ooooooooooooooooo0000
00Sooooo0_l00005ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002iooooo`00TOooool01Ol0003o
oooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo0;Wooooo002Aooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07
ooooo`;o0000^_ooool0097ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`;o00002?ooool2
o`0001;ooooo0_l0002Vooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006
ooooo`03o`000?oooooooooo00;ooooo0_l00005ooooo`;o00001_ooool2o`000:Kooooo002Loooo
o`;o00003_ooool00ol0003oooooooooo`02ooooo`;o00001Oooool2o`0002[ooooo0_l0000?oooo
o`;o0000LOooool009cooooo0_l0000>ooooo`03o`000?oooooooooo013ooooo0_l0000Qooooo`Co
00003oooool2o`00077ooooo002Yooooo`;o000000?oooooo`000?ooool04Oooool2o`00027ooooo
0_l00024ooooo`00ZOooool2o`000004ooooool0003o0000o`0001Sooooo0_l0002Oooooo`00[?oo
ool00ol0003oooooooooo`0Hooooo`;o0000Woooool00:Sooooo0_l00002ooooo`03o`000?oooooo
oooo0;Wooooo002Uooooo`;o000000?oooooo`000?l000000_ooool00ol0003oooooooooo`2ioooo
o`00YOooool2o`0000Gooooo00?o0000ooooooooool0<?ooool2o`0008Oooooo002Aooooo`;o0000
6Oooool00ol0003oooooooooo`0`ooooo`;o0000Qoooool0097ooooo0_l0000Iooooo`03o`000?oo
oooooooo0;Wooooo002[ooooo`;o00008_ooool2o`0009Oooooo002Looooo`;o00003Oooool4o`00
01;ooooo0_l0000<ooooo`?o0000U_ooool009cooooo0_l0000>ooooo`03o`000?oooooooooo01;o
oooo0_l0000=ooooo`;o0000U_ooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo01gooooo
0_l0002Jooooo`00Uoooool2o`0000Kooooo0_l0000;ooooo`03o`000?oooooooooo01gooooo0_l0
002Jooooo`00Woooool2o`0000_ooooo00?o0000ooooooooool04Oooool2o`000:Kooooo002Qoooo
o`;o00002Oooool01?l0003oooooo`000?l00006ooooo`;o00002?ooool2o`000:Kooooo002Qoooo
o`;o000000?oooooo`000?l000001_ooool01?l0003oooooo`000?l00005ooooo`?o0000/?ooool0
08oooooo0_l0000Cooooo`;o00001_ooool01?l0003oooooo`000?l00005ooooo`;o0000/Oooool0
08oooooo0_l0000Kooooo`?o00003_ooool2o`000:Wooooo002/ooooo`03o`000?oooooooooo00ko
oooo0_l0002Yooooo`00[?ooool00ol0003oooooooooo`0Iooooo`;o00003?ooool2o`00093ooooo
002/ooooo`03o`000?oooooooooo01Wooooo0_l0000<ooooo`;o0000T?ooool00:cooooo00?o0000
ooooooooool03?ooool2o`0000_ooooo0_l0002Nooooo`00[?ooool00ol0003oooooooooo`02oooo
o`;o00002?ooool2o`0000[ooooo0_l0002Oooooo`00[?ooool01?l0003oooooooooooooool3o`00
01Cooooo0_l0002Oooooo`00Xoooool2o`0000Oooooo00Co0000oooooooooooooooo0_l0000Soooo
o`;o00003oooool2o`00083ooooo002=ooooo`;o00005?ooool2o`0000Oooooo00?o0000oooooooo
ool09_ooool2o`0000oooooo0_l00020ooooo`00SOooool2o`0001gooooo0ol0002iooooo`00[?oo
ool00ol0003oooooooooo`0Dooooo`;o0000Xoooool00:cooooo00?o0000ooooooooool05?ooool3
o`000:;ooooo002>ooooo`;o00007?ooool00ol0003oooooooooo`0Eooooo`;o00007?ooool2o`00
08Cooooo002>ooooo`;o00007?ooool2o`0003Cooooo0_l00024ooooo`00ROooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`;o0000^_ooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0^Oooool008Wooooo00Go410@oooooooooooooooooa0@400=ooooo`04ojVYZOmEEEGo0000
o`0000Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`;o0000/_ooool0
08Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ol0003o000000Kooooo00?oMgMg
oc8b<_ooool01?ooool3o`0000Gooooo0_l0002booooo`00ROooool01_l0003ooooooooooooooooo
0000ooooo`;o00002oooool00omEEEGoc<c<ooooo`03ooooo`?o000000?o<S8bolc<c?ooool01?oo
ool00ol0003oooooooooo`0=ooooo`;o0000Z_ooool008Wooooo00Ko410@oooooooooooooooooa0@
4?ooool2o`0000_ooooo00?oZJVYogMgMoooool00oooool3o`0000Oooooo00?o0000ooooooooool0
3Oooool2o`000:[ooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool2o`0000Oooooo
00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0^Oooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`;o00001oooool5o`0000Co
oooo1?l00006ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002Iooooo`;o00004Oooool00ol0003oooooooooo`2iooooo`00VOooool2o`00017ooooo00?o0000
ooooooooool0^Oooool00:cooooo0ol0002iooooo`00W?ooool2o`0000kooooo00?o0000oooooooo
ool0^Oooool009cooooo0_l0000>ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo00Sooooo0_l0002_ooooo`00[?ooool00ol0003oooooooooo`06ooooo`Co00002oooool2
o`000:;ooooo002/ooooo`03o`000?oooooooooo00Kooooo0_l0000=ooooo`?o0000XOooool00:Ko
oooo0_l00004ooooo`03o`000?oooooooooo00Gooooo0_l0000?ooooo`;o0000XOooool00:3ooooo
0_l00004ooooo`;o00001?ooool00ol0003oooooooooo`05ooooo`;o00007_ooool2o`0009;ooooo
002Pooooo`;o00002_ooool3o`0000;ooooo0ol0000Pooooo`;o0000T_ooool00:cooooo00?o0000
ooooooooool00_ooool3o`000;Cooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002Hooooo`;o00004_ooool00ol0003oooooooooo`0=ooooo`;o0000Z_ooool0
09Sooooo0_l0000Booooo`03o`000?oooooooooo00gooooo0_l0002Zooooo`00[?ooool00ol0003o
ooooooooo`0=ooooo`;o0000Z_ooool00:cooooo0ol0000=ooooo`;o0000Z_ooool00:cooooo00?o
0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool02?ooool2o`000:oooooo002/oooo
o`03o`000?oooooooooo00Sooooo0_l0002_ooooo`00X_ooool2o`0000Sooooo00?o0000oooooooo
ool02?ooool2o`000:oooooo002Cooooo`;o00003Oooool2o`0000Sooooo00?o0000ooooooooool0
2?ooool2o`000:oooooo002Cooooo`;o00005oooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo00?o
oooo0_l0002dooooo`00[?ooool00ol0003oooooooooo`03ooooo`;o0000]?ooool009Oooooo0_l0
000Cooooo`03o`000?oooooooooo0;Wooooo002Gooooo`?o00004_ooool00ol0003oooooooooo`2i
ooooo`00V?ooool2o`0001;ooooo00?o0000ooooooooool0^Oooool00:;ooooo1?l000000ol@413o
ooooooooo`03ooooo`;o0000^_ooool00:Cooooo00?o0000ooooooooool01Oooool2o`000;[ooooo
002Tooooo`03o`000?oooooooooo00Gooooo0ol0002iooooo`00Y?ooool00ol0003oooooooooo`31
ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00
Y?ooool00ol0003oooooooooo`31ooooo`00X_ooool00omEEEGoIVIVo`000033ooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Z_ooool01?l@413o0000o`00
0?l0002jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2j
ooooo`00Zoooool01_l0003oMgMgo`000?l0003oEEEEonk^k[Oooooo002[ooooo`06o`000?mEEEGo
k^k^oooooomgMgOoEEEE]oooool00:_ooooo00?o0000onk^k_ooool00_ooool00ol0003ooooooooo
o`2eooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo0;Gooooo002[oooo
o`06o`000?mEEEGok^k^oooooomgMgOoIVIV]oooool00:[ooooo00?o410@o`000?mgMgL00_l00000
0omVIVKok^k^ooooo`2fooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.473 .10227 Mdot
.65112 .42778 Mdot
.49372 .6073 Mdot
.51879 .31928 Mdot
.56662 .64634 Mdot
.54488 .80052 Mdot
.51585 .54178 Mdot
.6184 .16604 Mdot
.37141 .59375 Mdot
.50664 .2592 Mdot
.56537 .55847 Mdot
.66962 .25489 Mdot
.53875 .8618 Mdot
.56801 .4674 Mdot
.66524 .25655 Mdot
.51505 .70584 Mdot
.4124 .71598 Mdot
.5224 .88472 Mdot
.47443 .19625 Mdot
.6524 .30498 Mdot
.52864 .87176 Mdot
.65265 .57568 Mdot
.64176 .62412 Mdot
.49543 .91785 Mdot
.72677 .43004 Mdot
.52345 .22198 Mdot
.53478 .68624 Mdot
.44093 .24162 Mdot
.67102 .35922 Mdot
.65032 .43376 Mdot
.48734 .91817 Mdot
.36921 .54432 Mdot
.53509 .06667 Mdot
.44644 .16556 Mdot
.59732 .33627 Mdot
.53535 .12129 Mdot
.64903 .72366 Mdot
.41308 .60003 Mdot
.67804 .39952 Mdot
.69506 .30402 Mdot
.73371 .45307 Mdot
.54231 .22023 Mdot
.62499 .55955 Mdot
.53686 .16291 Mdot
.42106 .18325 Mdot
.42367 .73152 Mdot
.55304 .38801 Mdot
.42926 .92635 Mdot
.60302 .56445 Mdot
.65429 .32016 Mdot
.44406 .95055 Mdot
.69376 .52545 Mdot
.74444 .30647 Mdot
.62131 .44007 Mdot
.62859 .49602 Mdot
.4106 .11825 Mdot
.62491 .17704 Mdot
.41045 .70706 Mdot
.55014 .89448 Mdot
.39969 .29 Mdot
.40862 .63473 Mdot
.61878 .86235 Mdot
.67778 .40425 Mdot
.53975 .56934 Mdot
.49581 .03013 Mdot
.38051 .27674 Mdot
.48406 .22744 Mdot
.54173 .61468 Mdot
.40856 .51408 Mdot
.45539 .91892 Mdot
.39813 .38633 Mdot
.44908 .3531 Mdot
.50777 .26364 Mdot
.42469 .34584 Mdot
.67755 .40338 Mdot
.46575 .35945 Mdot
.74467 .30709 Mdot
.40809 .37314 Mdot
.6931 .48151 Mdot
.59551 .43118 Mdot
.37954 .45982 Mdot
.64524 .41002 Mdot
.47468 .25084 Mdot
.56028 .25169 Mdot
.53915 .06823 Mdot
.48432 .76602 Mdot
.55782 .67558 Mdot
.52741 .74581 Mdot
.44059 .82001 Mdot
.53832 .6285 Mdot
.72694 .43609 Mdot
.45794 .73359 Mdot
.47734 .8223 Mdot
.49696 .72179 Mdot
.41956 .03317 Mdot
.56561 .44506 Mdot
.44984 .95465 Mdot
.75637 .33556 Mdot
.42134 .76583 Mdot
.51773 .14085 Mdot
.49768 .83908 Mdot
.65913 .23902 Mdot
.56777 .21141 Mdot
.38488 .65056 Mdot
.4765 .14057 Mdot
.4123 .27148 Mdot
.52756 .26734 Mdot
.45431 .728 Mdot
.45398 .91653 Mdot
.5503 .36952 Mdot
.51578 .30924 Mdot
.37163 .60522 Mdot
.58564 .1852 Mdot
.7706 .6614 Mdot
.49061 .30095 Mdot
.40213 .48426 Mdot
.42691 .06687 Mdot
.38675 .22586 Mdot
.66255 .6801 Mdot
.54478 .85202 Mdot
.67004 .77963 Mdot
.59331 .75941 Mdot
.67793 .38012 Mdot
.4496 .91241 Mdot
.53814 .38289 Mdot
.60759 .22185 Mdot
.36626 .30015 Mdot
.59451 .26884 Mdot
.53144 .54163 Mdot
.64064 .63652 Mdot
.56252 .20788 Mdot
.69472 .31056 Mdot
.52071 .84172 Mdot
.61019 .64334 Mdot
.69135 .44844 Mdot
.65808 .70915 Mdot
.64718 .29846 Mdot
.49812 .24515 Mdot
.57248 .11221 Mdot
.67711 .27818 Mdot
.51666 .98434 Mdot
.43348 .33118 Mdot
.423 .30914 Mdot
.41015 .70318 Mdot
.62551 .24984 Mdot
.4958 .02278 Mdot
.70918 .80657 Mdot
.5203 .25907 Mdot
.49972 .79895 Mdot
.68882 .74758 Mdot
.51633 .81032 Mdot
.44654 .76652 Mdot
.48201 .92791 Mdot
.43696 .42467 Mdot
.46126 .88038 Mdot
.67855 .63858 Mdot
.68696 .44744 Mdot
.41703 .0941 Mdot
.65091 .71677 Mdot
.67461 .6553 Mdot
.58737 .3725 Mdot
.69467 .49062 Mdot
.73971 .46552 Mdot
.45759 .07377 Mdot
.62498 .52876 Mdot
.48637 .10748 Mdot
.47739 .01511 Mdot
.37893 .44862 Mdot
.41222 .59472 Mdot
.67607 .65651 Mdot
.61486 .24007 Mdot
.45085 .71636 Mdot
.44782 .7657 Mdot
.56249 .6561 Mdot
.55116 .32871 Mdot
.5297 .0631 Mdot
.39722 .10356 Mdot
.47675 .88418 Mdot
.46022 .30515 Mdot
.67225 .36893 Mdot
.68904 .60037 Mdot
.71367 .35559 Mdot
.41841 .59807 Mdot
.73619 .47509 Mdot
.46136 .71151 Mdot
.38122 .7125 Mdot
.36173 .36507 Mdot
.36843 .53075 Mdot
.73624 .44264 Mdot
.61758 .61427 Mdot
.7004 .71293 Mdot
.62686 .2518 Mdot
.53687 .42635 Mdot
.64899 .81251 Mdot
.57686 .11226 Mdot
.73777 .56623 Mdot
.67658 .27119 Mdot
.50602 .79016 Mdot
.57141 .05059 Mdot
.48996 .13967 Mdot
.43189 .55722 Mdot
.42993 .51074 Mdot
.46565 .31642 Mdot
.57616 .59836 Mdot
.60847 .09232 Mdot
.5307 .16054 Mdot
.44884 .30638 Mdot
.51384 .84933 Mdot
.51885 .31436 Mdot
.4247 .47117 Mdot
.56031 .59901 Mdot
.60477 .74829 Mdot
.4043 .42503 Mdot
.37929 .4371 Mdot
.45031 .74315 Mdot
.49824 .11789 Mdot
.40519 .58163 Mdot
.73966 .47083 Mdot
.44441 .67682 Mdot
.38772 .53113 Mdot
.68052 .27088 Mdot
.40231 .52745 Mdot
.54644 .89632 Mdot
.37889 .54728 Mdot
.39144 .28816 Mdot
.50305 .73053 Mdot
.58501 .50702 Mdot
.6471 .39978 Mdot
.45373 .72377 Mdot
.66893 .26332 Mdot
.6528 .81291 Mdot
.54695 .59588 Mdot
.44001 .44927 Mdot
.60472 .09056 Mdot
.58028 .66381 Mdot
.53188 .69713 Mdot
.68755 .74192 Mdot
.42541 .69262 Mdot
.59034 .25115 Mdot
.58919 .77175 Mdot
.54961 .18698 Mdot
.62126 .85765 Mdot
.5839 .72423 Mdot
.41751 .14696 Mdot
.39749 .39592 Mdot
.3687 .453 Mdot
.51925 .65996 Mdot
.68479 .59588 Mdot
.52022 .79589 Mdot
.39576 .42727 Mdot
.68158 .41846 Mdot
.7387 .54314 Mdot
.48324 .29307 Mdot
.53216 .40485 Mdot
.67737 .62992 Mdot
.52005 .2189 Mdot
.4624 .78556 Mdot
.62731 .56887 Mdot
.48058 .35409 Mdot
.60047 .14492 Mdot
.48495 .96842 Mdot
.59348 .61819 Mdot
.53263 .69529 Mdot
.41128 .17639 Mdot
.52675 .42587 Mdot
.53477 .77582 Mdot
.42275 .18223 Mdot
.5585 .41713 Mdot
.59138 .69677 Mdot
.57168 .17105 Mdot
.55755 .29525 Mdot
.57217 .16836 Mdot
.62885 .53449 Mdot
.51036 .26527 Mdot
.6033 .52003 Mdot
.68019 .6344 Mdot
.41388 .50387 Mdot
.57959 .42652 Mdot
.42205 .9081 Mdot
.56297 .58789 Mdot
.47511 .88601 Mdot
.68335 .41113 Mdot
.51935 .6281 Mdot
.41714 .5711 Mdot
.65264 .71095 Mdot
.64476 .21317 Mdot
.53679 .28676 Mdot
.44976 .64217 Mdot
.57881 .44917 Mdot
.54946 .13283 Mdot
.46687 .81917 Mdot
.38454 .63585 Mdot
.36079 .38516 Mdot
.57422 .85919 Mdot
.64145 .21287 Mdot
.57788 .85129 Mdot
.50389 .38562 Mdot
.58454 .84767 Mdot
.67683 .75716 Mdot
.50294 .07584 Mdot
.65561 .2385 Mdot
.66325 .87844 Mdot
.60379 .48819 Mdot
.60775 .66299 Mdot
.57831 .23362 Mdot
.36847 .48324 Mdot
.72724 .42299 Mdot
.56289 .43773 Mdot
.43395 .93309 Mdot
.53961 .25426 Mdot
.4759 .69734 Mdot
.61342 .72636 Mdot
.39912 .60505 Mdot
.56556 .81832 Mdot
.70219 .71529 Mdot
.50369 .33215 Mdot
.39033 .39698 Mdot
.49799 .15378 Mdot
.52768 .06357 Mdot
.53227 .46667 Mdot
.71561 .36371 Mdot
.72176 .63014 Mdot
.4397 .99441 Mdot
.55388 .50319 Mdot
.50745 .86253 Mdot
.57091 .27158 Mdot
.68681 .45755 Mdot
.58518 .53886 Mdot
.43563 .60098 Mdot
.51546 .45857 Mdot
.39863 .38614 Mdot
.65918 .23043 Mdot
.681 .60689 Mdot
.49859 .71916 Mdot
.63345 .67215 Mdot
.5269 .58439 Mdot
.46772 .31471 Mdot
.6492 .41043 Mdot
.55694 .77971 Mdot
.62489 .53321 Mdot
.58656 .3703 Mdot
.58085 .56409 Mdot
.72458 .26169 Mdot
.52921 .23689 Mdot
.62945 .35425 Mdot
.53999 .56252 Mdot
.47463 .01869 Mdot
.54658 .64874 Mdot
.63608 .27507 Mdot
.65202 .46355 Mdot
.41945 .52391 Mdot
.44638 .79229 Mdot
.51968 .98155 Mdot
.66832 .25076 Mdot
.58303 .85173 Mdot
.55726 .14945 Mdot
.60233 .45735 Mdot
.46289 .14045 Mdot
.60835 .22741 Mdot
.55994 .72179 Mdot
.66604 .24706 Mdot
.40961 .9326 Mdot
.42963 .11256 Mdot
.69005 .30052 Mdot
.71898 .37564 Mdot
.73913 .48561 Mdot
.50626 .36721 Mdot
.59317 .61378 Mdot
.67732 .27968 Mdot
.61101 .15813 Mdot
.51475 .40241 Mdot
.40606 .79378 Mdot
.51618 .21655 Mdot
.49972 .87099 Mdot
.50296 .12144 Mdot
.42422 .91057 Mdot
.58598 .24342 Mdot
.62297 .78022 Mdot
.68869 .53601 Mdot
.64616 .60069 Mdot
.60505 .81802 Mdot
.6456 .61151 Mdot
.71703 .38486 Mdot
.75101 .72128 Mdot
.64621 .72302 Mdot
.43145 .83572 Mdot
.435 .53513 Mdot
.73273 .56854 Mdot
.44898 .83616 Mdot
.51211 .43059 Mdot
.72071 .37593 Mdot
.44788 .9107 Mdot
.43741 .61476 Mdot
.44069 .27354 Mdot
.46036 .1744 Mdot
.51564 .7357 Mdot
.40703 .86417 Mdot
.3806 .39076 Mdot
.65872 .79387 Mdot
.71744 .3675 Mdot
.40827 .30242 Mdot
.69781 .21734 Mdot
.43594 .18423 Mdot
.54719 .31715 Mdot
.57295 .39951 Mdot
.47249 .65982 Mdot
.64539 .20871 Mdot
.66484 .24626 Mdot
.5386 .67541 Mdot
.42459 .60004 Mdot
.50791 .7573 Mdot
.44736 .74077 Mdot
.72382 .64533 Mdot
.4876 .81819 Mdot
.461 .06993 Mdot
.44288 .29558 Mdot
.44195 .75531 Mdot
.53298 .48675 Mdot
.52727 .75078 Mdot
.42384 .22621 Mdot
.49263 .78196 Mdot
.46537 .27682 Mdot
.67986 .76304 Mdot
.56968 .10836 Mdot
.46477 .38441 Mdot
.60807 .36972 Mdot
.41214 .27255 Mdot
.42157 .80245 Mdot
.5387 .25796 Mdot
.42886 .70987 Mdot
.73179 .5866 Mdot
.59999 .27245 Mdot
.78835 .56514 Mdot
.56254 .20084 Mdot
.50244 .3042 Mdot
.36957 .50125 Mdot
.68334 .29348 Mdot
.56284 .57441 Mdot
.65054 .45716 Mdot
.73 .2733 Mdot
.4207 .5445 Mdot
.46782 .6983 Mdot
.56345 .36838 Mdot
.41001 .18038 Mdot
.58732 .38717 Mdot
.52547 .00504 Mdot
.43415 .62776 Mdot
.60458 .36503 Mdot
.54139 .21697 Mdot
.51819 .66736 Mdot
.49243 .30659 Mdot
.41976 .38115 Mdot
.61825 .16629 Mdot
.52475 .40819 Mdot
.69173 .45899 Mdot
.63902 .3734 Mdot
.40672 .24851 Mdot
.59086 .19524 Mdot
.40643 .79384 Mdot
.39654 .43332 Mdot
.37021 .25638 Mdot
.45353 .24285 Mdot
.66484 .24023 Mdot
.73928 .54539 Mdot
.5575 .41396 Mdot
.58258 .85146 Mdot
.5483 .27637 Mdot
.45141 .83346 Mdot
.63403 .27026 Mdot
.52382 .14845 Mdot
.49186 .20562 Mdot
.44095 .78108 Mdot
.4487 .16077 Mdot
.6115 .87623 Mdot
.61501 .61734 Mdot
.46096 .36637 Mdot
.62619 .51098 Mdot
.59917 .45372 Mdot
.50424 .35848 Mdot
.55283 .52504 Mdot
.62 .42941 Mdot
.61261 .6379 Mdot
.44431 .34604 Mdot
.48613 .17218 Mdot
.38306 .25615 Mdot
.56991 .63616 Mdot
.40117 .28716 Mdot
.41518 .36023 Mdot
.42994 .28179 Mdot
.52519 .51353 Mdot
.77615 .64483 Mdot
.52384 .53907 Mdot
.6502 .41897 Mdot
.55001 .88923 Mdot
.47293 .0656 Mdot
.41022 .42834 Mdot
.65866 .32733 Mdot
.7004 .31995 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
0_l0002booooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l0
002booooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo002Roooo
o`04oeEEEOmVIVKo0000o`0000Kooooo00?o0000ooooooooool0^Oooool00:?ooooo0ol00006oooo
o`03o`000?oooooooooo0;Wooooo002Sooooo`;o00001Oooool3o`000;_ooooo002Zooooo`Go0000
^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:[ooooo0ol0002kooooo`00TOooool2o`00
01Oooooo0ol0002kooooo`00TOooool2o`0001Wooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0000Dooooo`;o
0000Xoooool00:cooooo00?o0000ooooooooool05?ooool2o`000:?ooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
00Kooooo0_l0002aooooo`00Toooool2o`0000kooooo0_l00007ooooo`03o`000?oooooooooo00Ko
oooo1Ol0002^ooooo`00Toooool2o`0000[ooooo0_l00002ooooo`;o00001oooool00ol0003ooooo
ooooo`08ooooo`?o0000[_ooool009kooooo0ol0000;ooooo`03o`000?oooooooooo0;Wooooo002N
ooooo`;o00003?ooool3o`000;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Ooo
ool00:cooooo00?o0000ooooooooool07oooool3o`0009Oooooo002@ooooo`;o00006_ooool00ol0
003oooooooooo`0Oooooo`?o0000Uoooool0093ooooo0_l0000Jooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`?o0000^Oooool008[ooooo0_l0000Gooooo`;o00001oooool00ol0003ooooooooo
o`2iooooo`00R_ooool2o`0001Oooooo0_l00002ooooo`;o00000oooool00ol0003oooooooooo`2i
ooooo`00Yoooool2o`0000?ooooo00?o0000ooooooooool05?ooool2o`000:?ooooo002Dooooo`;o
00005_ooool00ol0003oooooooooo`0Dooooo`Co0000XOooool009Cooooo0_l0000Fooooo`03o`00
0?oooooooooo01Cooooo1?l0002Qooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;o0000
0oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Co
oooo0_l0002kooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00;o00000oooool2ob4Q8@Ko
oooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`03ooooo`Co00002?ooool2o`000:oo
oooo0021ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOoo
ool02?ooool00ol0003oooooooooo`03ooooo`?o00002?ooool2o`000:oooooo0029ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0^Oooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo
0;Wooooo0029ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03Oooool2o`000:[ooooo0029ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0=ooooo`;o0000Z_ooool008Wooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go000000Coooooo`000?l0003ooooo1?l00002ooooo`;o00000_oo
ool00ol0003oooooooooo`02ooooo`;o0000]Oooool009oooooo0_l00003ooooo`;o00000_ooool2
o`0000;ooooo00?o0000ooooooooool00_ooool2o`000;Gooooo002@ooooo`;o00006_ooool00ol0
003oooooooooo`0Nooooo`;o0000VOooool0093ooooo0_l0000Jooooo`03o`000?oooooooooo00Co
oooo0_l00009ooooo`;o00003Oooool2o`0009Wooooo002/ooooo`?o00001?ooool2o`0000Wooooo
0_l0002Xooooo`00Zoooool2o`000;_ooooo002[ooooo`;o00008oooool2o`0009Kooooo002Koooo
o`;o00003oooool00ol0003oooooooooo`07ooooo`;o00006?ooool2o`0009Kooooo002Kooooo`;o
00003oooool00ol0003oooooooooo`07ooooo`Co0000[_ooool009[ooooo0_l0000@ooooo`03o`00
0?oooooooooo00Wooooo0_l0000Iooooo`;o0000Toooool009[ooooo0_l0000@ooooo`03o`000?oo
oooooooo01Cooooo0_l0000>ooooo`;o0000Toooool00:Oooooo0_l00003ooooo`03o`000?oooooo
oooo01Cooooo0_l0002Sooooo`00S_ooool2o`0000kooooo0_l00007ooooo`;o00000oooool3o`00
02Kooooo0_l0002Aooooo`00S_ooool2o`0000kooooo0_l0000<ooooo`03o`000?oooooooooo02Ko
oooo0_l0002Aooooo`00S_ooool2o`0000;ooooo0_l0000Hooooo`03o`000?oooooooooo0;Wooooo
002Booooo`;o00000_ooool2o`0001Cooooo00?o0000ooooooooool06Oooool2o`0009kooooo002F
ooooo`;o00005?ooool00ol0003oooooooooo`0=ooooo`;o00002_ooool2o`0009kooooo002/oooo
o`03o`000?oooooooooo00gooooo0_l0002Zooooo`00[?ooool00ol0003oooooooooo`0Kooooo`;o
0000W?ooool00:?ooooo0_l00007ooooo`03o`000?oooooooooo01_ooooo0_l0002Looooo`00Xooo
ool2o`0000Oooooo0ol0000Aooooo`;o0000Y_ooool00:cooooo00?o0000ooooooooool04Oooool2
o`000:Kooooo002Yooooo`;o000000?oooooo`000?ooool0^_ooool00:Wooooo0_l000000ooooooo
0000ooooo`0Booooo`;o00006_ooool2o`0008[ooooo002/ooooo`03o`000?oooooooooo017ooooo
1?l0000Fooooo`Co0000R_ooool00:cooooo00?o0000ooooooooool00_ooool2o`0000oooooo0_l0
000Fooooo`?o0000Roooool00:cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo0_l0000b
ooooo`;o0000NOooool00:cooooo00?o0000ooooooooool00oooool3o`0000Cooooo0ol0000Coooo
o`;o00007?ooool2o`0007Wooooo0026ooooo`;o00009?ooool3o`0000Cooooo0_l00005ooooo`;o
00004oooool2o`0009Oooooo0026ooooo`;o00002_ooool2o`0001;ooooo0_l00004ooooo`03o`00
0?oooooooooo023ooooo0_l0002Gooooo`00T_ooool2o`0001;ooooo0_l00004ooooo`03o`000?oo
oooooooo023ooooo0_l0000?ooooo`;o0000Q_ooool00:cooooo00?o0000ooooooooool05_ooool2
o`0001Wooooo0_l00026ooooo`00[?ooool00ol0003oooooooooo`06ooooo`;o00003_ooool2o`00
0:7ooooo002/ooooo`03o`000?oooooooooo00Kooooo0_l0000Jooooo`;o00003?ooool5o`0008Co
oooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool2o`000004oooooolQ8B7o0000o`00
00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01Wooooo0_l00007
ooooo`;o00003?ooool5o`0008Cooooo002Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool2
o`000004oooooolQ8B7o0000o`0000Oooooo00?oMgMgoc8b<_ooool00oooool2o`0001_ooooo0_l0
000Hooooo`;o0000Q?ooool008Wooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?oo
ool00ol0003oooooooooo`02ooooo`;o0000:?ooool2o`0000_ooooo0_l00024ooooo`00SOooool2
o`0000;ooooo00Go0000ooooooooooooooooo`00000=ooooo`;o000000?oMgMgoc8b<_ooool01?oo
ool3o`00013ooooo0_l00008ooooo`;o00002_ooool2o`0000cooooo0_l00023ooooo`00QOooool2
o`0000[ooooo00Go0000ooooooooooooooooo`00000<ooooo`?o000000?o<S8bolc<c?ooool01?oo
ool00ol0003oooooooooo`0:ooooo`;o00001?ooool2o`0000Sooooo0_l0000:ooooo`;o00003?oo
ool3o`0008;ooooo0021ooooo`;o00000_ooool2o`0000[ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool2o`0000Cooooo0ol0
000Wooooo`Co0000P_ooool0087ooooo0_l0000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00ol0003oooooooooo`07ooooo`04o`000?oooooo0000o`0000;ooooo0_l00004ooooo`;o0000
:?ooool2o`0001;ooooo0_l0001`ooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l00006ooooo`04o`000?oooooo0000o`0003?ooooo0_l0000Aooooo`;o0000L?ooool00:cooooo
00?o0000ooooool000000_l00004ooooo`;o0000;?ooool2o`0008?ooooo002/ooooo`03o`000?oo
oooooooo00;o00001?ooool2o`0001Cooooo0_l0000;ooooo`;o00003?ooool3o`0007oooooo002?
ooooo`;o00001oooool2o`0001;ooooo00?o0000ooooooooool05?ooool2o`0000Kooooo1?l00009
ooooo`;o00003?ooool3o`0000kooooo0_l0001_ooooo`00Q?ooool2o`0000Wooooo0_l00007oooo
o`;o00001_ooool2o`0000[ooooo0ol0000=ooooo`;o00001Oooool2o`0000Sooooo0_l00009oooo
o`;o00007Oooool2o`0006oooooo0024ooooo`;o00006_ooool2o`0000[ooooo00?o0000oooooooo
ool03Oooool2o`0001[ooooo0_l0000<ooooo`;o0000P?ooool009Cooooo0_l0000Fooooo`03o`00
0?oooooooooo03Oooooo0_l00020ooooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool0^Ooo
ool008Sooooo0_l000000ooooooo0000o`00000Oooooo`03o`000?oooooooooo00Wooooo0_l0002^
ooooo`00R?ooool5o`0001oooooo00?o0000ooooooooool02Oooool2o`000:kooooo002:ooooo`;o
00006_ooool2o`0000Cooooo00?o0000ooooooooool04?ooool2o`0002Oooooo0_l0001nooooo`00
VOooool2o`0000_ooooo0_l00004ooooo`03o`000?oooooooooo013ooooo0_l0000Kooooo`;o0000
2_ooool2o`0007kooooo001oooooo`;o00006?ooool2o`0000gooooo0_l00002ooooo`?o0000;Ooo
ool2o`0000cooooo0_l0001looooo`00Ooooool2o`0000cooooo0_l0000Iooooo`;o00000_ooool2
o`0003cooooo1?l0001jooooo`00SOooool2o`0000cooooo0_l000000ooooooo0000o`000009oooo
o`;o000000?oooooo`000?l00000<?ooool2o`0000cooooo0_l0000>ooooo`;o0000J_ooool009;o
oooo0_l00007ooooo`;o000000?oooooo`000?l000002Oooool2o`000003ooooool0003ooooo00?o
oooo0_l0000[ooooo`;o00003?ooool2o`0000kooooo0_l0001Zooooo`00T_ooool2o`0001Sooooo
00?o0000ooooooooool00_ooool2o`0003Wooooo0_l0001jooooo`00X?ooool3o`0000Wooooo00?o
0000ooooooooool00oooool2o`000;Cooooo002Pooooo`?o00002Oooool00ol0003oooooooooo`03
ooooo`;o00001oooool2o`000:_ooooo002/ooooo`03o`000?oooooooooo00?ooooo0_l00007oooo
o`;o00008Oooool2o`0000kooooo0_l0001hooooo`00[?ooool3o`0002oooooo0_l0000>ooooo`;o
0000N?ooool00:cooooo00?o0000ooooooooool03Oooool2o`0002;ooooo0_l00026ooooo`00U_oo
ool2o`0001Cooooo00?o0000ooooooooool03Oooool2o`0002;ooooo0_l00026ooooo`00U_ooool2
o`0001Cooooo0ol0002iooooo`00[?ooool3o`0001gooooo0_l0000booooo`;o0000I_ooool00:co
oooo00?o0000ooooooooool07Oooool2o`0003;ooooo0_l0001Vooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00Toooool2o`0000Cooooo0_l0000Aooooo`03o`000?oooooooooo0;Wooooo002C
ooooo`;o00001?ooool2o`00017ooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002ioooo
o`00Voooool2o`0000Sooooo0_l00005ooooo`03o`000?oooooooooo02Oooooo0_l0000Jooooo`;o
0000M?ooool009_ooooo0_l00008ooooo`;o00001Oooool3o`0002Oooooo0_l0000Jooooo`;o0000
M?ooool0093ooooo0_l0000>ooooo`;o00002_ooool3o`0003Gooooo0_l00022ooooo`00O_ooool2
o`00013ooooo0_l0000>ooooo`;o00002_ooool00ol0003oooooooooo`0Oooooo`;o00005?ooool2
o`0000gooooo0_l0001cooooo`00O_ooool2o`0000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool5o`000005ooooool0003o0000oooooom4A4@00_l000000olb<S;ogMgMoooo
o`04ooooo`04o`000?oooooo0000o`0001kooooo0_l0000Sooooo`;o0000Loooool008Wooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01_nHV9So8B4Qonk^k_ooooooA4A4oooo
o`;o00001?ooool00omgMgOo<S8booooo`04ooooo`04o`000?oooooo0000o`0000cooooo0_l00003
ooooo`;o00001Oooool2o`0000Gooooo0_l0000Cooooo`;o00003Oooool2o`0007?ooooo0021oooo
o`Ko00000_ooool01?l@413oooooooooooooool2o`0000_ooooo00?oV9RHob4Q8Oo^k^h02Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo0_l00003ooooo`;o00001Oooool2
o`0000Gooooo0_l00008ooooo`;o00002Oooool2o`0008;ooooo0029ooooo`04o`000?oooooooooo
ooooo`;o00003?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000I
ooooo`;o00003oooool2o`0001Wooooo0_l0001booooo`00ROooool01Ol0003ooooooooooooooooo
000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool0=oooool2o`0000cooooo0_l0001booooo`00ROooool01Ol@413ooooooooooooo
oooo410@00?ooooo0_l0000:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`09ooooo`;o0000;?ooool2o`00083ooooo001nooooo`;o00002Oooool0
1OmgMgOo0000o`000?nHV9SoMgMg00?ooooo0_l00006ooooo`05o`000?nj^[[ooooooiRHV?l@4100
0_ooool3o`0000Wooooo0ol00009ooooo`;o0000>Oooool2o`0007?ooooo001nooooo`;o00002Ooo
ool01Oo^k^ko0000o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c002ooooo`Ko
00001_ooool3o`0000kooooo0_l00009ooooo`;o0000:Oooool2o`0007?ooooo0024ooooo`;o0000
9_ooool00ol0003oooooooooo`0>ooooo`;o00002Oooool2o`0009kooooo0024ooooo`;o00009_oo
ool00ol0003oooooooooo`2iooooo`00Qoooool2o`000003ooooool0003o0000023ooooo00?o0000
ooooooooool0^Oooool008Oooooo0_l000000ooooooo0000o`00000Pooooo`?o00005Oooool2o`00
01Kooooo0_l00008ooooo`;o0000P?ooool00:cooooo00Co0000oooooooooooooooo0_l0000Boooo
o`;o00005_ooool2o`0000Sooooo0_l00020ooooo`00[?ooool01?l0003oooooooooooooool2o`00
00Cooooo0_l0000^ooooo`;o0000P?ooool00:cooooo00?o0000ooooooooool01Oooool4o`0002Co
oooo0ol00029ooooo`00[?ooool00ol0003oooooooooo`05ooooo`;o00009_ooool3o`0000Wooooo
0_l0001nooooo`00[?ooool00ol0003oooooooooo`0@ooooo`;o00009oooool2o`0007kooooo002/
ooooo`03o`000?oooooooooo013ooooo0_l0000Looooo`;o00002Oooool2o`0007kooooo002/oooo
o`03o`000?oooooooooo013ooooo0_l0000Looooo`;o00002Oooool2o`0007kooooo002<ooooo`;o
00002Oooool2o`0001?ooooo0ol00018ooooo`;o0000Koooool008Wooooo0_l000000ooooooo0000
o`000002o`0000Oooooo0_l0000Cooooo`03o`000?oooooooooo00Gooooo0_l00002ooooo`;o0000
3?ooool2o`0001Gooooo0_l0000Hooooo`;o0000Koooool008Wooooo0_l00003ooooo`;o00007?oo
ool01?l0003oooooooooooooool2o`0000;ooooo0_l00002ooooo`;o00003?ooool2o`0000?ooooo
0_l00006ooooo`;o00002?ooool2o`0001Oooooo0_l0001`ooooo`00ROooool2o`00027ooooo00Co
0000oooooooooooooooo0_l0000Iooooo`;o00001_ooool2o`0000Sooooo0_l0000Gooooo`;o0000
L?ooool008Cooooo0_l00003ooooo`;o00008Oooool00ol0003oooooooooo`0Aooooo`;o00006ooo
ool2o`0001Oooooo0_l0001`ooooo`00Q?ooool2o`0002Kooooo00?o0000ooooooooool04Oooool2
o`0001;ooooo0_l0000Pooooo`;o0000L?ooool00:cooooo00?o0000ooooooooool09Oooool2o`00
02Cooooo0_l0001/ooooo`00[?ooool00ol0003oooooooooo`0Booooo`;o0000=oooool2o`0006co
oooo0024ooooo`;o00004_ooool2o`0001;ooooo00?o0000ooooooooool04_ooool2o`0000?ooooo
0_l0000Qooooo`Co0000Noooool0083ooooo0_l00002ooooo`;o00004_ooool2o`0001;ooooo0ol0
000Gooooo`;o00008Oooool4o`0007_ooooo0020ooooo`;o0000:_ooool00ol0003oooooooooo`0M
ooooo`;o0000:oooool2o`0006gooooo002/ooooo`03o`000?oooooooooo00;ooooo0_l0000Ioooo
o`?o00003_ooool2o`0000[ooooo1?l0000<ooooo`;o0000KOooool000Wooooo1?l000000ol@413o
ooooooooo`0Fooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^
k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q0_l00002ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM
01Kooooo00?o0000ooooooooool00_ooool2o`0001Cooooo00Kok^k^oc8b<_l0003o<S8bonk^k_oo
ool2o`0000;ooooo0_lQ8B44ooooo`Go000000Goooooo`000?l0003oooooodA4A002o`000003oc8b
<_oMgMgooooo00?ooooo1?l00007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Go
oooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1?l0
00000ol@413oooooooooo`0Booooo`002oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8boooo
o`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0
3_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B42o`0000;ooooo00GoV9RHob4Q8Oo^
k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo01Gooooo00?o0000ooooooooool06?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00_oo
ool2o`0000?ooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B48ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo01Wooooo00?o0000oooooooo
ool05?ooool000Ko00001Oooool00ol0003oooooooooo`0@ooooo`Ko00000_ooool01Ol@413ooooo
oooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`05ooooo`Ko
00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool01Oooool6o`00
00;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`07ooooo`;o00002_ooool2o`0000?ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00?ooooo0_l00004ooooo`03o`000?oo
oooooooo00gooooo00Go410@oooooooooooooooooa0@4002ooooo`;o00003?ooool00ol0003ooooo
ooooo`0=ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool0
6?ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo
<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0>oooo
o`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`;o000000?o<S8b
ooooooooool05?ooool00ol0003oooooooooo`07ooooo`;o00002_ooool2o`0000?ooooo00Go0000
ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool03_oo
ool01Ol0003ooooooooooooooooo000000;ooooo0_l0000;ooooo`03ogMgMolb<S;ooooo00kooooo
00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_oo
ool06Oooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05o`00
0?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`03oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00?ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`00
0?lQ8B7o0000o`000?o<c<`05_ooool00ol0003oooooooooo`0Hooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool0
1Ol0003ooooooooooooooooo000000;ooooo0_l00008ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
3oooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<01[ooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000oooooooo
ool06?ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0
003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0A
ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo01Sooooo0ol0000Hooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo017ooooo00Ko410@oooooooooooooooooa0@4?ooool2o`00
00Wooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Cooooo000;oooo
o`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooo
oooooooooolb<S801?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o
^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Hoooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o
0000ooooooooool04Oooool01_mgMgOoV9RHoooooonHV9SoMgMgooooo`;o00002Oooool00ol0003o
ooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo
<S8b00Cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Dooooo`002Oooool00omE
EEGoIVIVo`00000Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000@
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`;o00001_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0000Gooooo`03
o`000?oooooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01?ooool4o`0000Oooooo0_l00007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?oo
ool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0001Wooooo
00?oEEEEofIVI_l000005_ooool0083ooooo0_l00009ooooo`;o00007oooool00ol0003ooooooooo
o`0looooo`;o00003_ooool2o`0006_ooooo002;ooooo`;o00007oooool00ol0003oooooooooo`07
ooooo`;o00005_ooool2o`0002_ooooo0_l0001[ooooo`00[?ooool00ol0003oooooooooo`07oooo
o`;o00005_ooool2o`0001cooooo0_l0001_ooooo`;o00000_ooool2o`0000Gooooo002/ooooo`03
o`000?oooooooooo03gooooo0_l0001_ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1Oooool0
0:cooooo00?o0000ooooooooool09oooool2o`0008Kooooo00CogMgMo`000?l@413oc<c<1_ooool0
00Ooooooool0001<o`0000cooooo00Cok^k^ob4Q8Ol@413ok^k^1_ooool000Oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo0ol00007oooo
o`04o`000?ooooooooooooooo`;o00000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0:ooooo`04ob4Q8OmgMgOoMgMgoc8b<PKooooo0007ooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo00Wooooo0_l0000Kooooo`03o`000?oooooooooo00kooooo0_l00009ooooo`;o00003?ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`09ooooo`;o00000_ooool2o`0000Gooooo002/ooooo`03o`000?oooooooooo
01Wooooo0_l0002Nooooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool01Oooool2o`0001oo
oooo0_l0002Aooooo`00SOooool2o`0000Gooooo0_l0000Fooooo`03o`000?oooooooooo00Gooooo
0_l0000Oooooo`;o0000TOooool008gooooo0_l0000Mooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`03o`000?oooooooooo01oooooo0_l0002Hooooo`00TOooool2o`0001Wooooo0ol0000>oooo
o`;o00003oooool2o`0001cooooo0_l0001jooooo`00Roooool2o`0000Cooooo0_l0000Iooooo`03
o`000?oooooooooo00kooooo0_l0000Fooooo`;o00005Oooool2o`0007[ooooo0020ooooo`;o0000
1?ooool2o`0000?ooooo0_l0000Oooooo`03o`000?oooooooooo02Kooooo0_l0002Aooooo`00P?oo
ool2o`0000Cooooo0_l0000Tooooo`03o`000?oooooooooo02Kooooo0ol0002@ooooo`00U_ooool2
o`0001Cooooo00?o0000ooooooooool09_ooool3o`0001;ooooo0_l0001looooo`00U_ooool2o`00
01Cooooo00?o0000ooooooooool01?ooool2o`0001?ooooo0_l0000Pooooo`;o0000O?ooool00:co
oooo00?o0000ooooooooool00_ooool4o`000003ooooool0003o0000013ooooo0_l0000`ooooo`;o
0000K?ooool0083ooooo0_l0000?ooooo`;o00006Oooool00ol0003oooooooooo`02ooooo`;o0000
0oooool2o`0004;ooooo0ol0001[ooooo`00P?ooool2o`0000;ooooo0_l0000;ooooo`;o00006Ooo
ool00ol0003oooooooooo`1<ooooo`;o0000Joooool008Cooooo0_l0000Vooooo`?o0000^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool009Gooooo0_l0000Eooooo`03o`000?oooooooooo01;o
oooo0_l0002Uooooo`00UOooool2o`0001Gooooo00?o0000ooooooooool04_ooool2o`0001;ooooo
0_l0002Aooooo`00[?ooool00ol0003oooooooooo`0:ooooo`;o00002oooool2o`0000Kooooo0_l0
0005ooooo`;o0000TOooool00:cooooo00?o0000ooooooooool02_ooool2o`0000_ooooo0_l00006
ooooo`;o0000:_ooool2o`0000oooooo0_l0001Kooooo`00T?ooool2o`0001[ooooo00?o0000oooo
ooooool02_ooool2o`0001_ooooo0_l0000Pooooo`Co00003oooool2o`0005_ooooo002@ooooo`;o
00006_ooool00ol0003oooooooooo`0:ooooo`;o00006oooool2o`00023ooooo0_l0001^ooooo`00
[?ooool3o`00017ooooo0_l0000Looooo`;o0000R?ooool00:cooooo00?o0000ooooooooool04Ooo
ool2o`0001cooooo0_l00028ooooo`00S?ooool2o`0001kooooo00?o0000ooooooooool0^Oooool0
08cooooo0_l0000Nooooo`03o`000?oooooooooo00Gooooo0_l0002booooo`00[?ooool00ol0003o
ooooooooo`05ooooo`;o00002_ooool2o`0003Kooooo0_l0001^ooooo`00[?ooool00ol0003ooooo
ooooo`0Aooooo`;o0000=_ooool2o`0006kooooo0021ooooo`;o00003?ooool2o`0001_ooooo00?o
0000ooooooooool0^Oooool0087ooooo0_l0000<ooooo`Co00006Oooool00ol0003oooooooooo`0<
ooooo`;o00002?ooool2o`0002;ooooo0_l0001mooooo`00Soooool6o`000003ooooool0003o0000
01Cooooo0ol0000<ooooo`;o00000_ooool2o`0000Cooooo0_l0000Eooooo`;o00002oooool3o`00
07cooooo002?ooooo`;o00000_ooool2o`000003ooooool0003o000001Cooooo00?o0000oooooooo
ool04?ooool2o`0001_ooooo0_l0000<ooooo`;o0000O?ooool0087ooooo0_l00007ooooo`;o0000
7Oooool2o`000003ooooool0003ooooo03Wooooo0_l0001oooooo`00POooool2o`0000Oooooo0_l0
000Mooooo`;o000000?oooooo`000?ooool0>Oooool2o`0007oooooo002/ooooo`03o`000?oooooo
oooo02gooooo0_l0002:ooooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool02_ooool2o`00
00oooooo0_l00006ooooo`;o00002?ooool2o`0008[ooooo0029ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@;ooooo1ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`0:ooooo`;o00003oooool2o`0000Kooooo0_l0002Dooooo`00ROooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01_ooooo0_l00006ooooo`;o0000U?oo
ool008Wooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o
0000ooooooooool00oooool3o`0002_ooooo0_l0002<ooooo`00ROooool01Ol0003ooooooooooooo
oooo000000Sooooo0_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`00023ooooo0_l0002<ooooo`00ROooool0
1Ol0003ooooooooooooooooo000000Sooooo0_l00004ooooo`03ogMgMomVIVKooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o0000
;?ooool2o`0000gooooo0_l0001aooooo`00ROooool01?l@413oooooooooooooool2o`0000kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Oooooo
0ol0000<ooooo`;o0000LOooool008Gooooo0_l00002ooooo`04ogMgMonHV9SooooooiRHV0;o0000
2_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Dooooo`;o00005Oooool2o`0000_ooooo0_l0001oooooo`00QOooool2o`0000;ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`00
00Kooooo00?o0000ooooooooool05?ooool2o`0000cooooo0_l00007ooooo`;o00002oooool2o`00
07oooooo002Kooooo`;o00003oooool00ol0003oooooooooo`0Qooooo`?o00005?ooool2o`0007oo
oooo002Kooooo`;o00003oooool00ol0003oooooooooo`0Cooooo`;o00003?ooool2o`0002?ooooo
0_l0000@ooooo`;o0000Goooool00:cooooo00?o0000ooooooooool03?ooool2o`0000Gooooo0_l0
000aooooo`;o00004?ooool2o`0005oooooo0026ooooo`;o00009?ooool3o`0000cooooo0_l0002[
ooooo`00Q_ooool2o`0002Cooooo00?o0000ooooooooool0=_ooool2o`00087ooooo002/ooooo`03
o`000?oooooooooo017ooooo0_l0000Sooooo`?o0000P?ooool00:;ooooo0_l00008ooooo`03o`00
0?oooooooooo00?ooooo0_l0000<ooooo`;o00009?ooool2o`0001gooooo0_l0001Qooooo`00X_oo
ool2o`0000Sooooo00?o0000ooooooooool00oooool2o`0001;ooooo0_l00007ooooo`;o0000=?oo
ool2o`00067ooooo002/ooooo`03o`000?oooooooooo00?ooooo0_l0000Booooo`;o00001oooool2
o`0009Oooooo002/ooooo`03o`000?oooooooooo00?ooooo0_l0002dooooo`00[?ooool00ol0003o
ooooooooo`0Yooooo`;o0000S_ooool009Wooooo0_l0000Aooooo`?o00002Oooool2o`0000Gooooo
0_l0000Gooooo`;o0000S_ooool009Wooooo0_l0000Aooooo`03o`000?oooooooooo00Wooooo0_l0
0005ooooo`;o00008?ooool2o`0008Gooooo002/ooooo`03o`000?oooooooooo03;ooooo0_l00025
ooooo`00[?ooool00ol0003oooooooooo`08ooooo`;o0000[oooool00:cooooo00?o0000oooooooo
ool02?ooool2o`000:oooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Cooooo`;o00005ooo
ool00ol0003oooooooooo`07ooooo`;o0000/?ooool009?ooooo0_l0000<ooooo`;o000000?ooooo
o`000?l000001_ooool00ol0003oooooooooo`07ooooo`;o00004_ooool2o`0009cooooo002Qoooo
o`;o000000?oooooo`000?l000001_ooool3o`0000Oooooo0_l0000Booooo`;o0000W?ooool008ko
oooo0_l0000Looooo`03o`000?oooooooooo0;Wooooo002>ooooo`;o00007?ooool00ol0003ooooo
ooooo`02ooooo`;o0000]Oooool008kooooo0_l00004ooooo`;o00005_ooool00ol0003ooooooooo
o`02ooooo`;o0000;Oooool2o`0008Kooooo0024ooooo`;o00003_ooool2o`0000Wooooo0_l0000;
ooooo`03o`000?oooooooooo02oooooo1?l0000<ooooo`;o0000N?ooool008Cooooo0_l00009oooo
o`;o00002_ooool2o`0000;ooooo0_l0000;ooooo`03o`000?oooooooooo02oooooo0_l0000>oooo
o`;o0000N?ooool008oooooo0_l0000:ooooo`;o00003_ooool2o`00033ooooo0_l0000?ooooo`;o
0000N?ooool00:_ooooo0_l0000Booooo`;o00007?ooool2o`0001oooooo0_l0001Xooooo`00W?oo
ool2o`0000gooooo1?l0000@ooooo`;o00001_ooool2o`0001?ooooo0ol0000Oooooo`;o0000J?oo
ool009cooooo0_l0000>ooooo`03o`000?oooooooooo01Sooooo0_l00008ooooo`;o00002Oooool3
o`0008Wooooo002Booooo`;o00002?ooool2o`0000kooooo0ol0000Rooooo`;o0000UOooool009;o
oooo0_l0000:ooooo`;o00003?ooool3o`000;Wooooo002Nooooo`;o00003?ooool00ol0003ooooo
ooooo`02ooooo`;o0000]Oooool009[ooooo0_l0000@ooooo`03o`000?oooooooooo00;ooooo0_l0
002eooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo0ol00005ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0jooooo`;o0000OOooool0097ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o00002?ooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo00Kooooo0_l0000booooo`;o0000OOooool0097ooooo00Go410@oooooooooooooooo
oa0@400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool2o`0001Oooooo
0_l0000Jooooo`;o0000O?ooool0097ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMg
Molb<S;ooooo00Cooooo0ol00006ooooo`;o00005oooool2o`0001[ooooo0_l0001looooo`00TOoo
ool01Ol0003ooooooooooooooooo000000;ooooo0_l00008ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`06ooooo`;o0000/Oooool0097ooooo00Go410@oooooooooooo
oooooa0@4002ooooo`;o00002?ooool00ol0003oooooooooo`07ooooo`04o`000?oooooo0000o`00
03Kooooo0_l00020ooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool01oooool01?l0003oooooo`000?l0000Jooooo`;o00006_ooool2o`00083ooooo002Aoooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool06oooool2
o`0001_ooooo0_l0001oooooo`00T_ooool2o`0000Kooooo0_l0000:ooooo`;o00001?ooool00ol0
003oooooooooo`0hooooo`;o0000Ooooool009;ooooo0_l00006ooooo`;o00002_ooool2o`0000Co
oooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool06_ooool2o`0009gooooo
002/ooooo`?o00002?ooool2o`00013ooooo0_l0002Mooooo`00[?ooool00ol0003oooooooooo`08
ooooo`;o00001Oooool2o`0002Cooooo0_l00022ooooo`00V?ooool2o`0000oooooo0_l000000ooo
oooo0000ooooo`0@ooooo`;o00005?ooool2o`0000kooooo0_l00022ooooo`00V?ooool2o`0000Go
oooo0_l00008ooooo`;o000000?oooooo`000?ooool09_ooool2o`0009;ooooo002Oooooo`;o0000
2oooool00ol0003oooooooooo`2iooooo`00V_ooool2o`00013ooooo00Co0000ooooool0003o0000
^?ooool008gooooo0_l0000;ooooo`;o00004?ooool01?l0003oooooo`000?l0000`ooooo`;o0000
Q_ooool008gooooo0_l0000Mooooo`03o`000?oooooooooo00?ooooo0_l0000/ooooo`;o0000Q_oo
ool00:_ooooo1?l00003ooooo`;o00001_ooool2o`000:cooooo002Booooo`;o00005oooool2o`00
00gooooo0_l0002/ooooo`00T_ooool2o`0001Sooooo00?o0000ooooooooool0@_ooool2o`0007Go
oooo002/ooooo`03o`000?oooooooooo00;ooooo0_l0000nooooo`;o0000MOooool00:cooooo00?o
0000ooooooooool00_ooool2o`0002[ooooo0ol00028ooooo`00[?ooool00ol0003oooooooooo`0^
ooooo`?o0000R?ooool00:7ooooo0_l00004ooooo`;o00000oooool00ol0003oooooooooo`0Boooo
o`;o00002oooool2o`0009Sooooo002Hooooo`;o00001oooool2o`000004ooooool0003o0000oooo
o`;o00000oooool00ol0003oooooooooo`0Booooo`;o00002oooool2o`0009Sooooo002Hooooo`;o
00002_ooool2o`0000Kooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00W?ooool2o`0000kooooo00?o0000ooooooooool0^Oooool0
09Gooooo0_l00004ooooo`?o00003_ooool00ol0003oooooooooo`2iooooo`00UOooool2o`0000Co
oooo0_l0000>ooooo`;o0000^oooool00:_ooooo0_l00005ooooo`;o0000]?ooool00:cooooo00?o
0000ooooooooool00oooool2o`000;Cooooo002/ooooo`04o`000?ooooooooooooooo`;o00005Ooo
ool2o`0009oooooo002/ooooo`?o000000?oooooo`000?l000002?ooool2o`0000Wooooo1?l0002O
ooooo`00[?ooool00ol0003oooooooooo`0;ooooo`;o00002Oooool4o`0009oooooo002/ooooo`03
o`000?oooooooooo02Gooooo0_l0002Booooo`00[?ooool00ol0003oooooooooo`09ooooo`;o0000
2_ooool2o`0000kooooo0_l0002Booooo`00SOooool2o`0001gooooo00Co0000ooooool0003o0000
2?ooool2o`0000[ooooo0_l0000=ooooo`;o0000Toooool008Wooooo00Cok^k^oc8b<_l0003o<S8b
0_l00004ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01Oooool01?l0003oooooo`000?l0000Sooooo`;o0000Toooool008Wooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00?ooooo0_l0002kooooo`00ROooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEE
EOooool02?ooool00ol0003oooooooooo`02ooooo`;o00002?ooool2o`000;7ooooo0029ooooo`05
o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo
00Cooooo0ol00006ooooo`;o00006Oooool2o`0009Kooooo0029ooooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`0Qooooo`;o00003oooool2o`0008Gooooo0029ooooo`05oa0@4?oooooooooo
ooooool@41003_ooool00onYZJWoMgMgooooo`02o`000003ooooool0003ooooo00Sooooo00?o0000
ooooooooool0<_ooool2o`0008Gooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1_l@413ooooooooooooooooo<S8booooo`;o000000?oooooo`000?l000000_l00006ooooo`03o`00
0?oooooooooo00Cooooo0_l0002cooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`04ooooo`;o00001oooool2o`000:[ooooo
002/ooooo`03o`000?oooooooooo00gooooo0_l0002Zooooo`00[?ooool00ol0003oooooooooo`0=
ooooo`;o0000Z_ooool00:cooooo00?o0000ooooooooool03?ooool3o`000:[ooooo002/ooooo`?o
00003?ooool2o`000:_ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002Booooo`;o00006?ooool00ol0003oooooooooo`2iooooo`00T_ooool3o`00
00Gooooo0ol0000?ooooo`03o`000?oooooooooo0;Wooooo002Cooooo`;o00001Oooool3o`0000oo
oooo00?o0000ooooooooool0^Oooool009cooooo0ol00008ooooo`;o000000Coooooo`000?l0003o
0000^oooool009cooooo0ol00008ooooo`;o000000Coooooo`000?l0003o0000^oooool00:cooooo
0ol0002iooooo`00U?ooool2o`00013ooooo0_l00004ooooo`03o`000?oooooooooo0;Wooooo002D
ooooo`;o00004?ooool2o`0000Cooooo00?o0000ooooooooool0^Oooool008kooooo0_l00006oooo
o`;o00005?ooool00ol0003oooooooooo`2iooooo`00S_ooool2o`0000Kooooo0_l0000Dooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002Iooooo`;o00004Oooool3o`000;Wooooo002Iooooo`Co00003oooool00ol0003ooooo
ooooo`2iooooo`00Voooool2o`0000oooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:Oooooo0_l00003ooooo`03o`000?oooooooooo0;Wooooo002Wooooo`;o00000ooo
ool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo00?ooooo0_l0002dooooo`00[?ooool00ol0003ooooo
ooooo`02ooooo`?o0000]?ooool00:cooooo00?o0000ooooooooool00_ooool2o`000;Gooooo002/
ooooo`03o`000?oooooooooo0;Wooooo002Hooooo`;o00002?ooool4o`000003oa0@4?oooooooooo
00?ooooo00?o0000ooooooooool0^Oooool009Sooooo0_l0000:ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000ooooooooool01Oooool3o`000;Wooooo
002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Toooo
o`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Rooooo`03oeEE
EOmVIVKo00000<?ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo002Zooooo`04oa0@4?l0003o0000o`000;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`06o`000?mgMgOo0000o`000?mEEEGok^k^
]oooool00:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomEEEFgooooo`00Zoooool00ol0003ok^k^
ooooo`02ooooo`03o`000?oooooooooo0;Gooooo002[ooooo`03o`000?o^k^kooooo00;ooooo00?o
0000ooooooooool0]Oooool00:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomVIVJgooooo`00Z_oo
ool00ol@413o0000ogMgM`02o`000003ofIVI_o^k^kooooo0;Kooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.3886 .59479 Mdot
.58223 .22778 Mdot
.49816 .41171 Mdot
.43006 .34652 Mdot
.58516 .44634 Mdot
.62509 .60052 Mdot
.49262 .34546 Mdot
.44692 .02391 Mdot
.51797 .93926 Mdot
.41598 .41363 Mdot
.54876 .35847 Mdot
.53157 .05489 Mdot
.64347 .6618 Mdot
.51496 .2674 Mdot
.52786 .05655 Mdot
.55739 .50584 Mdot
.53769 .77357 Mdot
.63629 .68472 Mdot
.40881 .56818 Mdot
.53439 .10498 Mdot
.63735 .67176 Mdot
.64292 .37568 Mdot
.65141 .42412 Mdot
.62277 .71835 Mdot
.65878 .23004 Mdot
.40801 .34675 Mdot
.56927 .48624 Mdot
.42596 .70466 Mdot
.5747 .15922 Mdot
.58382 .23376 Mdot
.61611 .72203 Mdot
.50757 .95357 Mdot
.37351 .32861 Mdot
.40817 .69707 Mdot
.49184 .13813 Mdot
.38631 .31572 Mdot
.69849 .52366 Mdot
.51029 .75279 Mdot
.59785 .19952 Mdot
.57667 .10402 Mdot
.67494 .25307 Mdot
.41245 .26585 Mdot
.60881 .35955 Mdot
.39654 .30035 Mdot
.41752 .80405 Mdot
.53964 .73275 Mdot
.46949 .22166 Mdot
.5981 .83618 Mdot
.5888 .36445 Mdot
.54236 .12016 Mdot
.60854 .81796 Mdot
.66394 .32545 Mdot
.62702 .10647 Mdot
.55734 .24007 Mdot
.587 .29602 Mdot
.40559 .86377 Mdot
.45685 .0151 Mdot
.53584 .77906 Mdot
.66793 .69448 Mdot
.44545 .87425 Mdot
.51906 .77337 Mdot
.72372 .66235 Mdot
.59948 .20425 Mdot
.52748 .36934 Mdot
.36792 .5108 Mdot
.4467 .96087 Mdot
.41354 .51942 Mdot
.5476 .41468 Mdot
.49245 .78705 Mdot
.60005 .76577 Mdot
.46681 .86021 Mdot
.44854 .64496 Mdot
.41686 .40763 Mdot
.45223 .75302 Mdot
.5989 .20338 Mdot
.44632 .57081 Mdot
.6275 .10709 Mdot
.46178 .8196 Mdot
.64571 .28151 Mdot
.52799 .23118 Mdot
.48688 .92551 Mdot
.56925 .21002 Mdot
.42067 .55531 Mdot
.4303 .19265 Mdot
.37448 .31029 Mdot
.55431 .57545 Mdot
.58805 .47558 Mdot
.58573 .54581 Mdot
.56388 .72296 Mdot
.54972 .4285 Mdot
.66138 .23609 Mdot
.36282 .66629 Mdot
.53645 .60695 Mdot
.57232 .63843 Mdot
.54585 .52221 Mdot
.38508 .84304 Mdot
.50363 .24506 Mdot
.61145 .80889 Mdot
.6506 .13556 Mdot
.54928 .75783 Mdot
.38924 .38989 Mdot
.59338 .63924 Mdot
.51474 .03902 Mdot
.42292 .1694 Mdot
.52783 .88048 Mdot
.39621 .57121 Mdot
.43868 .82319 Mdot
.41956 .31911 Mdot
.53481 .61504 Mdot
.59879 .76653 Mdot
.46071 .22479 Mdot
.42724 .36196 Mdot
.52048 .93797 Mdot
.4269 .11146 Mdot
.79516 .4614 Mdot
.42817 .47491 Mdot
.48733 .82157 Mdot
.39085 .80366 Mdot
.43424 .94463 Mdot
.6946 .4801 Mdot
.64559 .65202 Mdot
.74189 .57963 Mdot
.65708 .55941 Mdot
.58998 .18012 Mdot
.59622 .77251 Mdot
.45591 .26112 Mdot
.45763 .06249 Mdot
.4631 .103 Mdot
.50809 .34163 Mdot
.65524 .43652 Mdot
.41874 .18847 Mdot
.57894 .11056 Mdot
.6174 .64172 Mdot
.62752 .44334 Mdot
.63073 .24844 Mdot
.70174 .50915 Mdot
.52656 .09846 Mdot
.41436 .45418 Mdot
.397 .16281 Mdot
.54838 .07818 Mdot
.6704 .78434 Mdot
.44713 .71782 Mdot
.44458 .76835 Mdot
.53494 .77919 Mdot
.4855 .05459 Mdot
.36632 .51242 Mdot
.79181 .60657 Mdot
.4162 .35273 Mdot
.5793 .59895 Mdot
.74785 .54758 Mdot
.60046 .61032 Mdot
.54698 .66659 Mdot
.61611 .73553 Mdot
.46678 .68239 Mdot
.58776 .71955 Mdot
.69398 .43858 Mdot
.62594 .24744 Mdot
.39893 .84093 Mdot
.69762 .51677 Mdot
.69673 .4553 Mdot
.49637 .1729 Mdot
.65092 .29062 Mdot
.68592 .26552 Mdot
.38572 .66822 Mdot
.59649 .32876 Mdot
.38685 .53527 Mdot
.36863 .59446 Mdot
.48457 .93057 Mdot
.5093 .7569 Mdot
.69867 .45651 Mdot
.47129 .05881 Mdot
.5316 .61991 Mdot
.54669 .66181 Mdot
.58493 .4561 Mdot
.44795 .22006 Mdot
.37215 .35335 Mdot
.40528 .92538 Mdot
.59581 .69836 Mdot
.43566 .60667 Mdot
.57982 .16893 Mdot
.68919 .40037 Mdot
.6159 .15559 Mdot
.50869 .72906 Mdot
.68623 .27509 Mdot
.52947 .58057 Mdot
.54314 .90671 Mdot
.50477 .95914 Mdot
.67329 .24264 Mdot
.62328 .41427 Mdot
.74557 .51293 Mdot
.48762 .05528 Mdot
.46925 .26733 Mdot
.734 .61251 Mdot
.39933 .14621 Mdot
.72427 .36623 Mdot
.54505 .07119 Mdot
.58209 .59016 Mdot
.37979 .17661 Mdot
.3931 .51265 Mdot
.49682 .67584 Mdot
.48709 .69445 Mdot
.43694 .58054 Mdot
.5755 .39836 Mdot
.41366 .03966 Mdot
.39475 .32787 Mdot
.43839 .65609 Mdot
.61357 .64933 Mdot
.42891 .34728 Mdot
.47959 .72587 Mdot
.55991 .39901 Mdot
.66409 .54829 Mdot
.47393 .82491 Mdot
.48197 .9315 Mdot
.53964 .63847 Mdot
.38655 .48119 Mdot
.50794 .7893 Mdot
.688 .27083 Mdot
.52166 .62576 Mdot
.50068 .87436 Mdot
.54888 .07088 Mdot
.49672 .81144 Mdot
.66497 .69632 Mdot
.50612 .91031 Mdot
.44683 .91068 Mdot
.55527 .53053 Mdot
.54782 .30702 Mdot
.56702 .19978 Mdot
.53356 .61427 Mdot
.53426 .06332 Mdot
.73797 .61291 Mdot
.54531 .39588 Mdot
.47149 .66374 Mdot
.41039 .05126 Mdot
.6058 .46381 Mdot
.57074 .49713 Mdot
.74432 .54192 Mdot
.52928 .71093 Mdot
.45295 .10625 Mdot
.65789 .57175 Mdot
.40666 .24177 Mdot
.72433 .65765 Mdot
.63359 .52423 Mdot
.41036 .82741 Mdot
.46905 .86095 Mdot
.48773 .97428 Mdot
.54324 .45996 Mdot
.68314 .39588 Mdot
.59858 .59589 Mdot
.47626 .86169 Mdot
.60896 .21846 Mdot
.71596 .34314 Mdot
.42804 .50877 Mdot
.45867 .28005 Mdot
.68934 .42992 Mdot
.40693 .36254 Mdot
.5541 .6346 Mdot
.61486 .36887 Mdot
.44194 .50722 Mdot
.42482 .0656 Mdot
.63422 .77328 Mdot
.60075 .41819 Mdot
.57075 .49529 Mdot
.41814 .84824 Mdot
.46153 .29722 Mdot
.6051 .57582 Mdot
.41693 .79688 Mdot
.48549 .22493 Mdot
.63009 .49677 Mdot
.41335 .15888 Mdot
.44187 .19996 Mdot
.41285 .15737 Mdot
.60264 .33449 Mdot
.41709 .39573 Mdot
.57131 .32003 Mdot
.69395 .4344 Mdot
.48907 .76605 Mdot
.5102 .22652 Mdot
.59184 .84391 Mdot
.55813 .38789 Mdot
.59563 .70218 Mdot
.6078 .21113 Mdot
.53059 .4281 Mdot
.50304 .73764 Mdot
.69702 .51095 Mdot
.49004 .01523 Mdot
.42763 .27667 Mdot
.51195 .59223 Mdot
.51848 .24917 Mdot
.3927 .2524 Mdot
.56711 .65358 Mdot
.52454 .88086 Mdot
.6779 .65919 Mdot
.48663 .01659 Mdot
.6784 .65129 Mdot
.44406 .39839 Mdot
.68361 .64767 Mdot
.73969 .55716 Mdot
.3764 .46971 Mdot
.51101 .0385 Mdot
.77462 .67844 Mdot
.55906 .28819 Mdot
.63295 .46299 Mdot
.43717 .1351 Mdot
.49439 .96874 Mdot
.65643 .22299 Mdot
.49798 .23789 Mdot
.60081 .82856 Mdot
.42024 .27085 Mdot
.52569 .52771 Mdot
.66397 .52636 Mdot
.51445 .81505 Mdot
.65289 .61832 Mdot
.74831 .51529 Mdot
.43232 .41092 Mdot
.47083 .89196 Mdot
.39444 .47452 Mdot
.37212 .36227 Mdot
.47961 .2868 Mdot
.6211 .16371 Mdot
.73382 .43014 Mdot
.62316 .86564 Mdot
.51515 .30319 Mdot
.61246 .66253 Mdot
.44405 .15879 Mdot
.62983 .25755 Mdot
.56072 .33886 Mdot
.50559 .65204 Mdot
.46432 .33448 Mdot
.46666 .85807 Mdot
.51136 .03043 Mdot
.68376 .40689 Mdot
.54629 .51926 Mdot
.66231 .47215 Mdot
.52065 .38439 Mdot
.43612 .57186 Mdot
.57337 .21043 Mdot
.62883 .57971 Mdot
.59818 .33321 Mdot
.49468 .17116 Mdot
.56648 .36409 Mdot
.58926 .06169 Mdot
.41259 .31827 Mdot
.53115 .15425 Mdot
.525 .36252 Mdot
.37001 .60577 Mdot
.56608 .44874 Mdot
.50611 .07507 Mdot
.59744 .26355 Mdot
.49224 .73737 Mdot
.55508 .68503 Mdot
.6723 .78155 Mdot
.52863 .05076 Mdot
.68372 .65173 Mdot
.39996 .21711 Mdot
.54527 .25735 Mdot
.39913 .63067 Mdot
.46039 .06309 Mdot
.60866 .52179 Mdot
.52486 .04706 Mdot
.59964 .90065 Mdot
.40023 .78194 Mdot
.57026 .10052 Mdot
.62924 .17564 Mdot
.69338 .28561 Mdot
.43987 .3918 Mdot
.59869 .41378 Mdot
.54919 .07968 Mdot
.43774 .03889 Mdot
.44919 .34685 Mdot
.55921 .83115 Mdot
.40619 .38031 Mdot
.60812 .671 Mdot
.38636 .45977 Mdot
.59268 .83906 Mdot
.44654 .11513 Mdot
.69506 .58022 Mdot
.66309 .33601 Mdot
.64644 .40069 Mdot
.69226 .61802 Mdot
.6502 .41151 Mdot
.63097 .18486 Mdot
.79952 .52128 Mdot
.69542 .52302 Mdot
.56891 .7631 Mdot
.49132 .66706 Mdot
.72014 .36854 Mdot
.56965 .71071 Mdot
.45541 .35252 Mdot
.63109 .17593 Mdot
.59525 .77502 Mdot
.50826 .64377 Mdot
.43298 .6988 Mdot
.40709 .63438 Mdot
.56993 .5357 Mdot
.57903 .86535 Mdot
.47157 .93581 Mdot
.73627 .59387 Mdot
.62444 .1675 Mdot
.4463 .83411 Mdot
.54475 .01734 Mdot
.41452 .73887 Mdot
.44172 .2336 Mdot
.49277 .20128 Mdot
.51309 .50894 Mdot
.4889 .01125 Mdot
.52334 .04626 Mdot
.56876 .47541 Mdot
.50778 .70136 Mdot
.57083 .5573 Mdot
.53911 .6471 Mdot
.74195 .44533 Mdot
.57677 .62308 Mdot
.38414 .65416 Mdot
.43732 .68446 Mdot
.54386 .67514 Mdot
.48783 .29418 Mdot
.58758 .55078 Mdot
.4263 .78263 Mdot
.56618 .58391 Mdot
.42836 .59032 Mdot
.74508 .56304 Mdot
.39455 .17424 Mdot
.45198 .56967 Mdot
.51596 .16972 Mdot
.43894 .82366 Mdot
.5596 .77655 Mdot
.42084 .27393 Mdot
.53304 .70268 Mdot
.72643 .3866 Mdot
.35813 .60002 Mdot
.46955 .09543 Mdot
.77441 .36514 Mdot
.41672 .18918 Mdot
.42638 .42249 Mdot
.49808 .96007 Mdot
.56074 .09348 Mdot
.5526 .37441 Mdot
.59341 .25716 Mdot
.59932 .0733 Mdot
.49646 .72748 Mdot
.52527 .55083 Mdot
.47164 .19496 Mdot
.41928 .85291 Mdot
.50219 .18717 Mdot
.35887 .38489 Mdot
.51192 .65899 Mdot
.51059 .16503 Mdot
.41127 .27027 Mdot
.54514 .46736 Mdot
.429 .46572 Mdot
.461 .7669 Mdot
.44687 .02431 Mdot
.45506 .30576 Mdot
.63533 .25899 Mdot
.54838 .1734 Mdot
.43487 .85255 Mdot
.4341 .09654 Mdot
.55917 .82971 Mdot
.47742 .857 Mdot
.4235 .64937 Mdot
.52093 .04023 Mdot
.71743 .34539 Mdot
.48329 .22428 Mdot
.68316 .65146 Mdot
.43042 .23341 Mdot
.56901 .70203 Mdot
.50213 .07026 Mdot
.39116 .36103 Mdot
.40708 .49006 Mdot
.55169 .69495 Mdot
.40663 .68824 Mdot
.72199 .67623 Mdot
.62195 .41734 Mdot
.44886 .5902 Mdot
.59059 .31098 Mdot
.54066 .25372 Mdot
.43805 .40275 Mdot
.52285 .32504 Mdot
.55177 .22941 Mdot
.62777 .4379 Mdot
.44803 .66731 Mdot
.40103 .52233 Mdot
.44166 .95419 Mdot
.58438 .43616 Mdot
.44451 .86842 Mdot
.45743 .79142 Mdot
.43711 .74397 Mdot
.49069 .31848 Mdot
.79408 .44483 Mdot
.49946 .33908 Mdot
.57779 .21897 Mdot
.66571 .68923 Mdot
.38061 .60301 Mdot
.47337 .79833 Mdot
.54959 .12733 Mdot
.58838 .11995 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00Co0000
oooooooooooooooo0_l00002ooooo`03o`000?oooooooooo0;Wooooo002Mooooo`;o00000oooool0
0omEEEGoIVIVo`000002ooooo`?o00000_ooool00ol0003oooooooooo`2iooooo`00WOooool2o`00
00Sooooo0ol00002ooooo`03o`000?oooooooooo00_ooooo0_l0002/ooooo`00[?ooool00ol0003o
ooooooooo`0;ooooo`;o0000[?ooool009[ooooo0_l0000@ooooo`?o0000^Oooool009[ooooo0_l0
000@ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00;o0000]oooool0
0:cooooo00?o0000ooooooooool00_l0002gooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
Soooool2o`0000Kooooo0_l0000Cooooo`03o`000?oooooooooo00Go0000]?ooool008oooooo0_l0
0006ooooo`;o00004oooool00ol0003oooooooooo`05o`000;Cooooo002/ooooo`03o`000?oooooo
oooo00Cooooo0ol0002booooo`00[?ooool00ol0003oooooooooo`04ooooo`?o0000/_ooool008ko
oooo0_l0000Looooo`?o00001_ooool2o`000;7ooooo002>ooooo`;o00005oooool2o`0000?ooooo
00?o0000ooooooooool01_ooool3o`000;3ooooo002Rooooo`;o00000oooool2o`0000?ooooo00?o
0000ooooooooool01_ooool3o`000;3ooooo002Rooooo`;o00002?ooool00ol0003oooooooooo`06
ooooo`;o00004_ooool2o`0009gooooo002Nooooo`;o00003?ooool00ol0003oooooooooo`08oooo
o`;o00004?ooool2o`0009gooooo002Cooooo`;o00002Oooool2o`0000cooooo00?o0000oooooooo
ool02?ooool2o`000:oooooo002Cooooo`;o00005oooool2o`0000cooooo1?l0002Zooooo`00[?oo
ool2o`0000cooooo1?l0000>ooooo`;o0000V_ooool00:cooooo1?l0000Looooo`;o0000V_ooool0
0:cooooo00Co0000ooooool0003o00003?ooool2o`000:[ooooo002/ooooo`03o`000?oooooooooo
00gooooo0_l0002Zooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00X_ooool2o`0000Sooooo00?o0000
ooooooooool04Oooool2o`000:Kooooo002Fooooo`;o00002_ooool2o`0000Sooooo00?o0000oooo
ooooool01Oooool2o`0000[ooooo0_l0002Vooooo`00U_ooool2o`0001Cooooo0ol00005ooooo`;o
00003Oooool2o`000:?ooooo002Oooooo`;o00002oooool00ol0003oooooooooo`0Dooooo`Co0000
XOooool009cooooo0_l000000ooooooo0000o`00000;ooooo`03o`000?oooooooooo00Sooooo0_l0
000<ooooo`;o00003_ooool3o`00093ooooo002Looooo`;o00003_ooool00ol0003oooooooooo`08
ooooo`;o00003Oooool2o`0000gooooo0ol0002@ooooo`00Toooool2o`0001Oooooo00?o0000oooo
ooooool05oooool2o`000:3ooooo002Cooooo`;o00001Oooool2o`00013ooooo00?o0000oooooooo
ool0^Oooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool2o`000003
onk^k_oooooooooo00?ooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
0;Wooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVY
ZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00_ooooo0_l0000=oooo
o`;o0000WOooool0087ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onY
ZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0000;ooooo`;o00003Oooool2o`00
09gooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool03Oooool2o`000:[ooooo0029ooooo`05
o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01Oooool00ol0003oooooooooo`0=ooooo`;o0000Z_ooool008Wooooo00Go410@oooo
oooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`2iooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Wooooo0_l00000
1Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0^ooooo`;o0000ROooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP09ooooo`Oo00001?oo
ool4o`0000?ooooo0_l000000ooooooo0000ooooo`0_ooooo`;o0000ROooool00:Wooooo0_l00000
0ooooooo0000ooooo`2jooooo`00R_ooool2o`00023ooooo00?o0000ooooooooool0^Oooool008[o
oooo0_l0000Pooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o
0000ooooooooool01oooool2o`0001[ooooo0_l0002Dooooo`00Soooool2o`0000Sooooo0_l0000A
ooooo`03o`000?oooooooooo00Oooooo0_l0000<ooooo`;o00003?ooool2o`0009Cooooo002?oooo
o`;o00002?ooool2o`00017ooooo00?o0000ooooooooool05Oooool2o`000:;ooooo002:ooooo`;o
00008?ooool00ol0003oooooooooo`02o`0002?ooooo0_l0002Booooo`00R_ooool2o`00023ooooo
00?o0000ooooooooool00_l0000Sooooo`?o0000TOooool009;ooooo0_l0000Fooooo`?o00001?oo
ool2o`0001?ooooo0_l0000=ooooo`;o0000TOooool008Wooooo0_l00007ooooo`;o00005_ooool3
o`0000Cooooo0_l00009ooooo`;o00002?ooool2o`000:3ooooo0024ooooo`;o00000oooool2o`00
01oooooo1Ol0000=ooooo`;o00006?ooool3o`0008oooooo0024ooooo`;o00009_ooool00ol0003o
ooooooooo`0Jooooo`;o00002oooool3o`0008oooooo002/ooooo`03o`000?oooooooooo01[ooooo
0_l0002Mooooo`00[?ooool00ol0003oooooooooo`0Xooooo`;o0000Soooool0093ooooo0ol0000I
ooooo`;o0000:Oooool2o`0008oooooo002@ooooo`?o00006Oooool2o`000;[ooooo002Eooooo`;o
00002oooool2o`0000Sooooo00?o0000ooooooooool0^Oooool009Gooooo0_l0000;ooooo`;o0000
2?ooool00ol0003oooooooooo`2iooooo`00V?ooool2o`0000oooooo0_l000001?oooooo0000o`00
0?l0000Cooooo`;o00002?ooool2o`0009[ooooo002Hooooo`;o00003oooool2o`000003ooooool0
003ooooo01Cooooo0_l00008ooooo`;o0000V_ooool00:cooooo00?o0000ooooooooool07Oooool2
o`0009[ooooo002/ooooo`03o`000?oooooooooo01?ooooo1?l0002Rooooo`00[?ooool00ol0003o
ooooooooo`0Cooooo`Co00002Oooool2o`0009Oooooo002/ooooo`03o`000?oooooooooo023ooooo
0_l0002Gooooo`00Roooool2o`0001oooooo00?o0000ooooooooool05_ooool2o`0000Wooooo0_l0
002Fooooo`00Roooool2o`0000gooooo0_l00005ooooo`;o00002Oooool00ol0003oooooooooo`0F
ooooo`;o00002Oooool2o`0009Kooooo002Jooooo`;o00000oooool4o`0000?ooooo0ol00003oooo
o`?o0000<?ooool2o`0008Oooooo002Oooooo`;o00001Oooool3o`0000?ooooo00?o0000oooooooo
ool00_l0000Fooooo`;o00005_ooool2o`0008Oooooo002/ooooo`03o`000?oooooooooo00;o0000
1?ooool2o`0000Kooooo0_l00008ooooo`;o00005oooool2o`0008Kooooo002Eooooo`;o000000?o
ooooo`000?l000004_ooool00ol0003oooooooooo`06ooooo`;o00001_ooool2o`0000Sooooo0_l0
000Gooooo`;o0000Q_ooool009Gooooo0_l000000ooooooo0000o`00000Aooooo`;o00006_ooool2
o`0001Sooooo0_l00025ooooo`00Zoooool2o`00017ooooo0_l0000Qooooo`;o0000QOooool008go
oooo0_l00002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00oooooo0_l0000Uooooo`;o0000POooool0
08gooooo0_l00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool01?ooool3o`0003Kooooo0_l00021ooooo`00ROooool6o`0000;ooooo00Go410@oooo
oooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol00003ooooo`;o00008Oooool4
o`0008oooooo0028ooooo`;o00001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMg
oc8b<_ooool01?ooool3o`0000?ooooo0_l0000Qooooo`Co00003?ooool2o`00087ooooo0028oooo
o`;o00001oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo00[ooooo0_l0000Zooooo`;o0000POooool0097ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_oo
ool4o`0000gooooo0_l0000:ooooo`Co0000S_ooool0097ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`07ooooo`;o00000oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo0_l0
000=ooooo`;o00002_ooool4o`0008kooooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01ooo
ool2o`0000?ooooo1?l00006ooooo`03o`000?oooooooooo01gooooo0_l0002Jooooo`00Soooool2
o`00013ooooo0_l00009ooooo`03o`000?oooooooooo00;ooooo0_l0000Iooooo`;o00006oooool2
o`0007gooooo002>ooooo`Go00003_ooool2o`0000Wooooo00?o0000ooooooooool00_ooool2o`00
03Kooooo0ol0001looooo`00S_ooool2o`000003ooooool0003o000001Wooooo00?o0000oooooooo
ool0>oooool2o`0007cooooo002Aooooo`;o000000?oooooo`000?l000005_ooool3o`0003[ooooo
0_l0001mooooo`00U?ooool2o`0000Sooooo0_l0000<ooooo`03o`000?oooooooooo03[ooooo0_l0
001mooooo`00W_ooool2o`0000cooooo00?o0000ooooooooool0;Oooool2o`0008[ooooo002/oooo
o`03o`000?oooooooooo02gooooo0_l0000=ooooo`;o0000Noooool00:Gooooo0_l00005ooooo`03
o`000?oooooooooo013ooooo0_l0000Zooooo`;o0000Noooool00:Gooooo0_l00005ooooo`03o`00
0?oooooooooo013ooooo0_l0000Looooo`;o0000ROooool00:Sooooo0_l00002ooooo`03o`000?oo
oooooooo02kooooo0_l00029ooooo`00Woooool2o`0000Oooooo0_l00002ooooo`03o`000?oooooo
oooo01Wooooo0_l0002Nooooo`00ROooool2o`0001Cooooo0_l0000;ooooo`?o00006Oooool2o`00
09kooooo0029ooooo`;o00008Oooool00ol0003oooooooooo`02ooooo`;o0000]Oooool009gooooo
0_l0000=ooooo`03o`000?oooooooooo00;ooooo0_l00008ooooo`;o0000Zoooool008;ooooo0_l0
000Iooooo`;o00003Oooool00ol0003oooooooooo`0<ooooo`;o0000Zoooool008;ooooo0_l0000X
ooooo`03o`000?oooooooooo01[ooooo0_l0002Mooooo`00Q_ooool2o`0002Cooooo00?o0000oooo
ooooool06_ooool2o`0009gooooo0026ooooo`;o00001oooool4o`0001Gooooo0_l00002ooooo`03
o`000?oooooooooo0;Wooooo002?ooooo`Co00005Oooool2o`0000;ooooo00?o0000ooooooooool0
5?ooool2o`000:?ooooo002/ooooo`?o00001?ooool2o`0000kooooo0_l0000Mooooo`;o0000Q?oo
ool008;ooooo0_l00005ooooo`;o00008Oooool00ol0003oooooooooo`04ooooo`;o00005_ooool2
o`0001Gooooo0_l00024ooooo`00P_ooool2o`0000Gooooo0_l0000Qooooo`03o`000?oooooooooo
01cooooo0_l0002Kooooo`00X?ooool2o`0000[ooooo00?o0000ooooooooool07Oooool3o`0009Wo
oooo002Pooooo`;o00002_ooool00ol0003oooooooooo`0Mooooo`?o00004_ooool2o`0008Gooooo
002[ooooo`;o00004oooool2o`0001oooooo0_l00025ooooo`00Zoooool2o`000003ooooool0003o
0000013ooooo0_l0000aooooo`;o0000Loooool008gooooo0_l00005ooooo`;o00001Oooool2o`00
00cooooo0_l000000ooooooo0000ooooo`02o`0004?ooooo0_l0001cooooo`00SOooool2o`0000Go
oooo0_l00005ooooo`;o00003?ooool2o`000003ooooool0003ooooo04Gooooo0_l0001cooooo`00
T?ooool2o`0000;ooooo0_l00007ooooo`;o00003Oooool3o`000;Wooooo0021ooooo`;o00003Ooo
ool2o`0000_ooooo0_l0000=ooooo`03o`000?oooooooooo0;Wooooo0021ooooo`;o0000:Oooool0
0ol0003oooooooooo`0=ooooo`;o0000Z_ooool008Sooooo0_l0000:ooooo`;o00005_ooool00ol0
003oooooooooo`0=ooooo`;o00004Oooool2o`0009Oooooo0021ooooo`;o00001Oooool2o`0000?o
oooo0_l00005ooooo`;o00005_ooool00ol0003oooooooooo`05ooooo`;o00003?ooool2o`0000Go
oooo0_l00004ooooo`;o0000=Oooool2o`00063ooooo0021ooooo`;o00001_ooool01?o^k^ko<S8b
o`000?lb<S82o`0000Cooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool01Oooool2o`0000cooooo0_l00005ooooo`;o0000:oooool2o`00
00kooooo0_l0001Pooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo00Kooooo0_l0000Jooooo`;o00008Oooool4o`00073ooooo0021ooooo`Ko00000_ooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Kooooo0_l0000Jooooo`;o00008Oooool2o`0007;ooooo0029oooo
o`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;o
oooo00Cooooo0ol0000>ooooo`;o00007?ooool2o`0008_ooooo0029ooooo`04o`000?oooooooooo
ooooo`;o00003Oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`0>ooooo`;o00007?ooool2o`0008_ooooo0029ooooo`04oa0@4?oooooo
ooooooooo`;o00003_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0^Oooool007gooooo0_l0000:ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`03ooooo`;o0000]?ooool007gooooo0_l0000:ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo00?o
oooo0_l0000;ooooo`;o0000=Oooool2o`00073ooooo0027ooooo`;o00003oooool2o`0001;ooooo
00?o0000ooooooooool04?ooool2o`0003Gooooo0_l0001`ooooo`00Qoooool2o`0000oooooo0_l0
000Booooo`03o`000?oooooooooo0;Wooooo002@ooooo`;o00001oooool2o`00017ooooo00?o0000
ooooooooool03?ooool2o`0000Oooooo0_l0000Rooooo`;o0000O_ooool0093ooooo0_l00007oooo
o`;o00004Oooool3o`0000cooooo0_l00002ooooo`;o00000oooool2o`0001Kooooo0_l0000:oooo
o`Co0000O?ooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo013ooooo0_l0000Kooooo`;o
00003?ooool2o`0007cooooo002Gooooo`;o00004oooool00ol0003oooooooooo`0iooooo`;o0000
O_ooool0093ooooo0_l0000Jooooo`03o`000?oooooooooo03Wooooo0_l0001nooooo`00T?ooool2
o`0000?ooooo0_l0000Dooooo`;o0000<?ooool2o`0008Wooooo002@ooooo`;o00000oooool2o`00
01Cooooo0_l0000>ooooo`;o00003oooool2o`0000Kooooo0_l00007ooooo`;o0000ROooool00:co
oooo00?o0000ooooooooool03?ooool2o`0000oooooo0ol00005ooooo`;o0000T_ooool009?ooooo
0_l0000Gooooo`03o`000?oooooooooo01kooooo0_l00005ooooo`;o0000T_ooool009?ooooo0_l0
000Gooooo`?o0000;oooool2o`0008Sooooo002/ooooo`03o`000?oooooooooo00Oooooo0_l00004
ooooo`;o00008?ooool2o`0008Sooooo002/ooooo`03o`000?oooooooooo00Oooooo0_l00004oooo
o`;o0000;?ooool2o`0000gooooo0_l0001]ooooo`00[?ooool00ol0003oooooooooo`0kooooo`Co
00002oooool2o`0006gooooo002/ooooo`03o`000?oooooooooo01Sooooo0_l0000=ooooo`;o0000
1oooool2o`0000_ooooo0_l0001jooooo`00[?ooool00ol0003oooooooooo`0Hooooo`;o00003Ooo
ool2o`0000Oooooo0_l0000;ooooo`;o0000N_ooool00:cooooo00?o0000ooooooooool09oooool2
o`0001Cooooo0_l0001jooooo`00[?ooool00ol0003oooooooooo`0Iooooo`;o00003?ooool2o`00
02?ooooo0_l0000@ooooo`;o0000FOooool00:cooooo00?o0000ooooooooool04_ooool2o`0000Go
oooo0_l0000aooooo`;o00004?ooool2o`0005Wooooo002/ooooo`?o00004_ooool2o`000:Gooooo
002?ooooo`;o00006oooool00ol0003oooooooooo`0nooooo`;o0000NOooool008oooooo0_l0000K
ooooo`03o`000?oooooooooo01Wooooo0_l0000Sooooo`;o0000NOooool000Wooooo1?l000000ol@
413oooooooooo`0Fooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000
onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q0_ooool7o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0F
ooooo`03o`000?oooooooooo00_ooooo0_l0000;ooooo`05onk^k_l0003o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd02?ooool2o`0000Gooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM
00?ooooo0_l0000:ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000
onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1?l000000ol@413ooooooooo
o`0Booooo`002oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B42ooooo`;o000000GoV9RHob4Q8Oo^k^koooooodA4A007oooo
o`03ogMgMolb<S;ooooo01Gooooo00?o0000ooooooooool02oooool2o`0000_ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`02ooooo`;o000000?oooooob4Q8OlQ8B401?ooool2o`000003onk^k_oooooo
A4A400Oooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B48ooooo`03ogMgMolb<S;ooooo00;ooooo0_l0000:ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`0Iooooo`03o`00
0?oooooooooo01Cooooo0006o`0000Gooooo00?o0000ooooooooool04?ooool6o`0000;ooooo00Go
410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool0
1Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00Go
oooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP08oooo
o`;o00005_ooool00ol0003oooooooooo`0;ooooo`;o00002oooool01Ol@413ooooooooooooooooo
410@00;ooooo0_l00007ooooo`;o000000?o8B4Qonk^k_ooool02?ooool00ol0003oooooooooo`0=
ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0=ooooo`05oa0@4?oo
ooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooo
oooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`0>ooooo`05o`00
0?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0>ooooo`05o`000?oooooooooooooo
ool000001_ooool2o`0000Gooooo00?oV9RHob4Q8Oo^k^h01oooool2o`0001Kooooo00?o0000oooo
ooooool02oooool2o`0000_ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^00Oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000oooooo00?o
MgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool0
1_ooool00omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oo
oooooooo01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`000006ooooo`;o00001_oo
ool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05_ooool00ol0003ooooo
ooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`?o
000000?o<S8bolc<c?ooool03_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<oooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06_ooool00ol0003oooooooooo`0Dooooo`002ooo
ool00ol0003oooooooooo`0Hooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMg
ooooo`03ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400<ooooo`03
o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400<ooooo`;o000000?oooooo`00
0?ooool00oooool00ol0003oooooooooo`02o`0001Kooooo0ol0000Cooooo`;o00000oooool01Ol@
413oooooo`000?l0003o410@00oooooo00?o0000ooooooooool00_ooool3o`00017ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooo
oa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool04Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo0ol000000onHV9So410@ooooo`03ooooo`03o`000?oooooooooo00;o00005_ooool0
0ol0003oooooooooo`0Cooooo`;o00000oooool01OmgMgOoV9RHo`000?l0003oMgMg00_ooooo00Go
0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Wooooo0_l00006ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Dooooo`002Oooool00omEEEGoIVIVo`00000Jooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?oo
ool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP09ooooo`;o000000GoV9RHoa0@4?l0003o
8B4Qolc<c004ooooo`Co00005oooool00ol0003oooooooooo`0Hooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00008ooooo`;o00001_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool5o`0000Cooooo1?l0000Iooooo`03oeEEEOmVIVKo000001Kooooo0026ooooo`;o00009?oo
ool00ol0003oooooooooo`0Cooooo`;o0000Y?ooool00:cooooo00?o0000ooooooooool04oooool2
o`000:Cooooo002=ooooo`;o00007Oooool00ol0003oooooooooo`2^ooooo`;o00000_ooool2o`00
00Gooooo002=ooooo`;o00007Oooool00ol0003oooooooooo`0Dooooo`;o0000V?ooool01_o^k^ko
8B4QohN7Qonj^[[o0000omgMg@Gooooo002/ooooo`03o`000?oooooooooo01Cooooo0_l0000Boooo
o`;o0000QOooool01?oMgMgo0000oa0@4?o<c<`6ooooo`001oooooooo`0004co00003?ooool01?o^
k^ko8B4Qoa0@4?o^k^h6ooooo`001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00[ooooo00Co8B4QogMgMomgMgOo<S8b1_ooool000Oooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04_ooool2o`00
01;ooooo00?o0000ooooooooool04?ooool2o`0001Gooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02Oooool2o`00
00;ooooo0_l00005ooooo`00U?ooool2o`0000;ooooo0_l0000Booooo`04o`000?oooooooooooooo
o`;o00003Oooool2o`0002gooooo0_l0001hooooo`00Ooooool3o`0000Kooooo0_l0000:ooooo`;o
00005_ooool01?l0003oooooooooooooool2o`0003_ooooo0ol0000=ooooo`;o0000JOooool007oo
oooo0ol00006ooooo`;o00008_ooool00ol0003oooooooooo`0nooooo`;o00003_ooool3o`0006So
oooo002?ooooo`;o00006oooool00ol0003oooooooooo`0<ooooo`;o0000<?ooool2o`0000oooooo
0_l0001Xooooo`00Roooool2o`0000;ooooo0_l0000Kooooo`03o`000?oooooooooo00cooooo0_l0
000Booooo`;o00007?ooool2o`0001oooooo0_l0001Hooooo`00Roooool2o`0001oooooo0ol0000<
ooooo`;o00004_ooool2o`0000Oooooo0_l0000Booooo`?o00007oooool2o`0005Sooooo002/oooo
o`03o`000?oooooooooo00Gooooo0_l0000Rooooo`;o00002?ooool2o`0000Sooooo0ol0001ioooo
o`00[?ooool00ol0003oooooooooo`05ooooo`;o00002?ooool2o`0002;ooooo0_l00024ooooo`00
[?ooool00ol0003oooooooooo`0?ooooo`;o0000Z?ooool008Kooooo0_l0000Tooooo`03o`000?oo
oooooooo01Cooooo0_l0002Sooooo`00Q_ooool2o`0002Cooooo00?o0000ooooooooool05?ooool2
o`000:?ooooo002/ooooo`03o`000?oooooooooo04gooooo0_l0001Zooooo`00[?ooool00ol0003o
ooooooooo`0Iooooo`;o0000<_ooool2o`0006[ooooo002/ooooo`03o`000?oooooooooo01Wooooo
0_l0000Hooooo`;o00006Oooool2o`0006Wooooo002/ooooo`?o00001Oooool2o`0001;ooooo0_l0
000Hooooo`;o00006Oooool2o`0006Wooooo002Aooooo`;o00006Oooool00ol0003oooooooooo`05
ooooo`;o00004_ooool2o`0009kooooo002Aooooo`;o00006Oooool00ol0003oooooooooo`0Doooo
o`;o0000=_ooool2o`0006_ooooo002/ooooo`03o`000?oooooooooo01Cooooo0_l0000Jooooo`;o
00006_ooool2o`0006_ooooo002/ooooo`03o`000?oooooooooo033ooooo0_l0000Kooooo`;o0000
J_ooool00:cooooo00?o0000ooooooooool0COooool2o`0006[ooooo002=ooooo`;o00002oooool4
o`0000kooooo00?o0000ooooooooool0^Oooool008Wooooo0_l00002ooooo`;o00001oooool2o`00
00;ooooo1?l0000>ooooo`03o`000?oooooooooo037ooooo0_l00026ooooo`00ROooool2o`0000_o
oooo0_l0000Dooooo`?o00003_ooool2o`0000oooooo0_l0000@ooooo`;o0000Q_ooool00:cooooo
00?o0000ooooooooool03_ooool2o`0000oooooo0_l00006ooooo`;o00005?ooool2o`0000gooooo
0_l0001[ooooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool01_ooool2o`0001oooooo0_l0
000Dooooo`;o00003Oooool2o`0006_ooooo002Gooooo`;o00004oooool00ol0003oooooooooo`06
ooooo`;o00002_ooool2o`000:Gooooo002/ooooo`03o`000?oooooooooo01;ooooo0_l0002Uoooo
o`00U?ooool2o`0000Gooooo0_l0000?ooooo`04o`000?ooooooooooooooo`;o00005Oooool2o`00
09oooooo0020ooooo`;o00001Oooool2o`0000_ooooo0_l00005ooooo`;o00003oooool01?l0003o
ooooooooooooool2o`0001Gooooo0_l0000aooooo`;o0000K?ooool0083ooooo0_l00005ooooo`;o
00008oooool00ol0003oooooooooo`0Mooooo`;o0000;?ooool2o`0006cooooo001mooooo`;o0000
;Oooool3o`0001Oooooo0_l00004ooooo`;o00001oooool2o`00097ooooo001mooooo`;o00001Ooo
ool2o`0002Kooooo00?o0000ooooooooool05oooool2o`0000gooooo0_l0002Aooooo`00POooool2
o`000003ooooool0003o0000013ooooo0_l0000Dooooo`03o`000?oooooooooo00Wooooo0_l0001B
ooooo`;o0000F_ooool0087ooooo0_l0000Cooooo`;o00005?ooool00ol0003oooooooooo`09oooo
o`;o00004oooool2o`0003gooooo0_l0001Jooooo`00[?ooool00ol0003oooooooooo`0Nooooo`;o
0000:_ooool3o`0006cooooo002/ooooo`03o`000?oooooooooo00Sooooo0_l00010ooooo`?o0000
K?ooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00Sooooo0_l0000Uooooo`;o
00002oooool2o`0007_ooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool01oooool2o`0002Kooooo0_l0000;ooooo`;o0000Noooool008Wooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`00
00Oooooo0_l0000=ooooo`;o0000XOooool008Wooooo00Go0000ooooooooooooooooo`00000=oooo
o`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`04oooo
o`;o00004?ooool2o`000:7ooooo0029ooooo`?o000000?oooooo`000?ooool03Oooool00omgMgOo
IVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`04oooo
o`;o0000/oooool008Wooooo00Co410@o`000?l0003ooooo0_l0000>ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0>ooooo`;o0000ZOooool008Wo
oooo00CoMgMgoiRHV?ooooooV9RH0_l0000:ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00kooooo0_l0002Yooooo`00ROooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_oo
ool00ol0003oooooooooo`0:ooooo`;o00002?ooool2o`0000Gooooo0_l0002Looooo`00[?ooool0
1?l0003oooooo`000?l00009ooooo`;o00002?ooool2o`0000Gooooo0_l00006ooooo`;o0000U?oo
ool009_ooooo0_l0000?ooooo`04o`000?oooooo0000o`0002;ooooo0_l0002Dooooo`00T_ooool2
o`0000Oooooo0_l0000?ooooo`03o`000?oooooooooo00Wooooo0_l0000Gooooo`;o00005Oooool2
o`0007kooooo002Booooo`;o00006?ooool3o`0000Wooooo0_l0000Gooooo`;o00002Oooool2o`00
00Sooooo1?l0001nooooo`00QOooool2o`0002Gooooo0ol0000Cooooo`;o00006?ooool2o`0000So
oooo1?l0001nooooo`00QOooool2o`00013ooooo0_l0000Cooooo`03o`000?oooooooooo00;o0000
4Oooool2o`0003;ooooo0_l0001`ooooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool00_l0
000:ooooo`;o00007_ooool2o`0000Wooooo0_l0000>ooooo`;o0000L?ooool00:;ooooo0_l00008
ooooo`03o`000?oooooooooo00cooooo0_l0000Dooooo`;o00002?ooool2o`0000Wooooo0_l0000=
ooooo`;o0000LOooool007kooooo0_l0000Jooooo`;o00001_ooool2o`0000Gooooo0_l000000ooo
oooo0000ooooo`0=ooooo`;o00005?ooool2o`0002;ooooo0_l0001aooooo`00O_ooool2o`0000Ko
oooo0_l0000Booooo`;o00003Oooool2o`000003ooooool0003ooooo00gooooo0_l0000Booooo`;o
0000Uoooool008Kooooo0_l0000Tooooo`03o`000?oooooooooo023ooooo0_l00008ooooo`;o0000
SOooool00:_ooooo1?l0000;ooooo`;o00007Oooool2o`0001[ooooo0_l0001aooooo`00Zoooool2
o`0000gooooo0_l0000iooooo`;o00003oooool2o`00063ooooo002Qooooo`;o00002Oooool00ol0
003oooooooooo`1Gooooo`;o0000H?ooool009Oooooo0_l00008ooooo`;o00002Oooool00ol0003o
ooooooooo`0?ooooo`;o00006Oooool2o`0008gooooo002=ooooo`;o00002?ooool2o`0001?ooooo
00?o0000ooooooooool03oooool2o`0001Wooooo0_l00007ooooo`;o0000Q?ooool008gooooo0_l0
000Mooooo`03o`000?oooooooooo03?ooooo0_l00024ooooo`00Yoooool2o`0000?ooooo00?o0000
ooooooooool03_ooool2o`0002Cooooo0_l00023ooooo`00SOooool2o`0001Sooooo0_l00003oooo
o`03o`000?oooooooooo00kooooo0_l0000<ooooo`;o00005Oooool3o`0008?ooooo002=ooooo`;o
00001_ooool2o`0001Gooooo1?l0000Kooooo`;o00005Oooool2o`0008Cooooo002Eooooo`;o0000
5Oooool01?l0003oooooo`000?l00006ooooo`;o00002_ooool2o`0000Oooooo0_l0002Kooooo`00
Toooool2o`0001Oooooo00?o0000ooooooooool01oooool2o`0000[ooooo0_l00007ooooo`;o0000
Voooool009?ooooo0_l0000Gooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooo
oooo00Kooooo0_l0000<ooooo`;o0000Xoooool00:cooooo00?o0000ooooooooool01_ooool2o`00
00cooooo0_l0002Sooooo`00V_ooool2o`00013ooooo00?o0000ooooooooool06_ooool2o`0000Wo
oooo0_l0002Booooo`00V_ooool2o`00013ooooo00?o0000ooooooooool06_ooool2o`0000Oooooo
1?l0002Booooo`00[?ooool3o`0001;ooooo0_l0000?ooooo`;o0000U?ooool00:Gooooo0_l00003
ooooo`?o00005?ooool2o`000:Gooooo002Uooooo`;o00000oooool3o`000003ooooool0003o0000
0;Sooooo002/ooooo`04o`000?oooooo0000o`0000Wooooo0_l0002]ooooo`00ZOooool2o`000004
ooooool0003o0000o`0000[ooooo0_l0000Gooooo`;o0000U?ooool008oooooo0_l0000Hooooo`;o
000000Coooooo`000?l0003o00008oooool2o`0009Cooooo002?ooooo`;o000000Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool0^Oooool0097ooooo00KoMgMgoiRHV?ooooooV9RHogMgMoooool2o`0000;ooooo0_lQ
8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0^Oooool0097ooooo00Ko410@
oooooooooooooooooa0@4?ooool2o`0000gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2iooooo`00TOooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool0
1?ooool5o`000;Oooooo002Aooooo`05o`000?ooooooooooooooool000001_ooool2o`0000Cooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00;o0000]oooool0097ooooo
00Go410@oooooooooooooooooa0@4006ooooo`;o00001?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00;o00002oooool2o`000:[ooooo002Aooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;o00002oooool2o`000:[o
oooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000oooooooo
ool04oooool2o`000:Cooooo002Oooooo`;o00001oooool2o`0000;ooooo00?o0000ooooooooool0
4oooool2o`0000Sooooo0ol0002Iooooo`00VOooool2o`0000Cooooo0_l00007ooooo`;o00000_oo
ool00ol0003oooooooooo`0Mooooo`?o0000VOooool009Wooooo0_l0000Aooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o00004Oooool2o`0000_ooooo0_l0002>ooooo`00[?ooool3o`00
00?ooooo0_l00004ooooo`;o00001Oooool2o`0000[ooooo0_l0000;ooooo`;o0000S_ooool00:co
oooo00?o0000ooooooooool02?ooool2o`0000Kooooo0_l0000:ooooo`;o0000Voooool008_ooooo
0_l00006ooooo`;o00005oooool00ol0003oooooooooo`08ooooo`;o0000:oooool2o`0008;ooooo
002;ooooo`;o00001_ooool2o`0001Oooooo00?o0000ooooooooool0=Oooool2o`0008;ooooo002Y
ooooo`;o000000?oooooo`000?ooool00_l0000dooooo`;o0000P_ooool009kooooo0_l00009oooo
o`;o000000?oooooo`000?ooool00_l0002hooooo`00W_ooool2o`0000cooooo00?o0000oooooooo
ool0^Oooool0093ooooo0_l0000Aooooo`;o00001oooool00ol0003oooooooooo`2iooooo`00T?oo
ool2o`00017ooooo0_l00007ooooo`?o0000^Oooool008Sooooo0_l00006ooooo`;o00006_ooool0
0ol0003oooooooooo`2iooooo`00R?ooool2o`0000Kooooo0_l0000Jooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo027ooooo0_l0002Fooooo`00Z_ooool3o`0002?ooooo
0_l0002Fooooo`00Z_ooool3o`0000?ooooo0_l0002fooooo`00[?ooool01?l0003ooooooooooooo
ool2o`0001gooooo0_l0002Gooooo`00Woooool2o`0000Kooooo0_l00003ooooo`03o`000?oooooo
oooo023ooooo0_l0002Gooooo`00Uoooool2o`0000Kooooo0_l00002ooooo`;o00000_ooool2o`00
00?ooooo0ol0002iooooo`00S_ooool2o`0000Oooooo0_l0000:ooooo`;o00001oooool00ol0003o
ooooooooo`0Nooooo`;o0000VOooool008kooooo0_l0000Looooo`03o`000?oooooooooo013ooooo
0_l0000<ooooo`;o0000VOooool009[ooooo0_l0000@ooooo`03o`000?oooooooooo013ooooo0_l0
002Wooooo`00V_ooool2o`00013ooooo00?o0000ooooooooool07Oooool2o`0009[ooooo002/oooo
o`03o`000?oooooooooo01_ooooo1?l0002Jooooo`00Q_ooool2o`0000;ooooo0_l0000Pooooo`03
o`000?oooooooooo01_ooooo0_l0002Looooo`00Q_ooool2o`0000;ooooo0_l0000Pooooo`03o`00
0?oooooooooo01_ooooo0_l0002Looooo`00TOooool2o`0001Wooooo00?o0000ooooooooool06ooo
ool2o`0009cooooo002Aooooo`;o00000oooool2o`0001Cooooo0ol0002iooooo`00TOooool2o`00
00?ooooo0_l0000Dooooo`03o`000?oooooooooo0;Wooooo002Qooooo`;o000000?oooooo`000?l0
00001_ooool00ol0003oooooooooo`2iooooo`00XOooool2o`000003ooooool0003o000000Kooooo
00?o0000ooooooooool0^Oooool008cooooo0_l0000Cooooo`;o000000?oooooo`000?l000001_oo
ool00ol0003oooooooooo`2iooooo`00ROooool00oo^k^ko<S8bo`000002o`0000Gooooo0_lQ8B46
ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo01Oooooo0_l0000<ooooo`;o0000T_ooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool2o`000003oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`0Gooooo`;o00003?ooool2o`0009;ooooo0029ooooo`05oa0@4?oooooo
ooooooooool@41002oooool2o`000003ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`2iooooo`00ROooool01Ol0003ooooooooooooooooo000000cooooo0_l0
00000olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002iooooo`00ROooool0
1Ol0003ooooooooooooooooo000000cooooo0_l000000omEEEGoc<c<ooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool2o`000;[ooooo0029ooooo`05oa0@4?ooooooooooooooool@4100
3_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1Oooool3o`000;7ooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooo
oooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`?o
0000/Oooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo00?o0000ooooooooool0^Oooool00:;ooooo0_l00008ooooo`03o`000?oooooooooo0;Wooooo
002Rooooo`;o00002?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool3o`0001gooooo0_l0002Jooooo`00[?ooool00ol0003oooooooooo`0Mooooo`;o
0000V_ooool00:cooooo00?o0000ooooooooool02oooool2o`000:cooooo002/ooooo`04o`000?oo
oooo0000o`0000[ooooo0_l0002/ooooo`00V_ooool2o`00013ooooo00Co0000ooooool0003o0000
^?ooool009[ooooo0_l0000@ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002<ooooo`;o00006Oooool2o`0000?o
oooo0ol0002iooooo`00S?ooool2o`0001Wooooo0_l00003ooooo`03o`000?oooooooooo0;Wooooo
002Vooooo`;o00001?ooool00ol0003oooooooooo`2iooooo`00Y_ooool2o`0000Cooooo00?o0000
ooooooooool0^Oooool00:;ooooo0_l00008ooooo`03o`000?oooooooooo0;Wooooo002Rooooo`;o
00002?ooool00ol0003oooooooooo`02ooooo`?o0000]?ooool00:cooooo00?o0000ooooooooool0
0_ooool3o`000;Cooooo002Fooooo`;o00005?ooool00ol0003oooooooooo`2iooooo`00U_ooool2
o`0001Cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00V?ooool2o`0001;o
oooo00Co0000ooooool0003o0000^?ooool009Sooooo0_l0000Booooo`04o`000?oooooo0000o`00
0;Sooooo002Jooooo`;o00003oooool4o`000;Wooooo002Jooooo`;o00003oooool4o`000;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002Zooooo`?o0000^oooool00:[ooooo0ol0002koooo
o`00Z?ooool2o`0000;ooooo0ol0002iooooo`00Z?ooool2o`0000;ooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:;ooooo
1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000ooooooooool01Oooool3
o`000;Wooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7o
oooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002R
ooooo`03oeEEEOmVIVKo00000<?ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo002Zooooo`04oa0@4?l0003o0000o`000;[ooooo002[ooooo`03o`000?oooooo
oooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`06o`000?mgMgOo0000o`00
0?mEEEGok^k^]oooool00:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomEEEFgooooo`00Zoooool0
0ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo0;Gooooo002[ooooo`03o`000?o^k^kooooo
00;ooooo00?o0000ooooooooool0]Oooool00:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomVIVJg
ooooo`00Z_ooool00ol@413o0000ogMgM`02o`000003ofIVI_o^k^kooooo0;Kooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.51446 .86237 Mdot
.43824 .12344 Mdot
.45071 .418 Mdot
.45122 .72941 Mdot
.5237 .24634 Mdot
.6253 .40052 Mdot
.43745 .45651 Mdot
.37714 .72561 Mdot
.65368 .73926 Mdot
.46891 .77638 Mdot
.4558 .22811 Mdot
.37043 .34678 Mdot
.66819 .4618 Mdot
.41762 .37467 Mdot
.37054 .36298 Mdot
.51973 .30584 Mdot
.60711 .57357 Mdot
.67018 .48472 Mdot
.50421 .77488 Mdot
.38233 .32346 Mdot
.66605 .47176 Mdot
.55319 .17568 Mdot
.58105 .22412 Mdot
.67012 .51835 Mdot
.5108 .03004 Mdot
.45604 .82566 Mdot
.52377 .28624 Mdot
.53223 .71272 Mdot
.41167 .1491 Mdot
.44149 .11954 Mdot
.66492 .52203 Mdot
.649 .75357 Mdot
.45954 .98019 Mdot
.53384 .78606 Mdot
.39236 .50478 Mdot
.45396 .9271 Mdot
.66795 .32366 Mdot
.5714 .55279 Mdot
.44116 .07841 Mdot
.39689 .14794 Mdot
.53617 .05307 Mdot
.43742 .82377 Mdot
.51263 .15955 Mdot
.44839 .88578 Mdot
.56051 .79242 Mdot
.59273 .53275 Mdot
.41543 .58429 Mdot
.69257 .63618 Mdot
.49459 .16533 Mdot
.38752 .28534 Mdot
.69573 .61796 Mdot
.55412 .12545 Mdot
.42508 .20408 Mdot
.46632 .12636 Mdot
.57905 .87031 Mdot
.37307 .68416 Mdot
.60746 .57906 Mdot
.70573 .49448 Mdot
.58218 .75071 Mdot
.5884 .57337 Mdot
.74866 .46235 Mdot
.44417 .07521 Mdot
.44562 .30053 Mdot
.50052 .96521 Mdot
.61286 .82103 Mdot
.49254 .76415 Mdot
.47434 .24044 Mdot
.56805 .58906 Mdot
.66636 .56577 Mdot
.58219 .69079 Mdot
.51287 .5982 Mdot
.46741 .77383 Mdot
.54263 .63878 Mdot
.44338 .07646 Mdot
.49666 .60991 Mdot
.56595 .6649 Mdot
.51831 .08151 Mdot
.41095 .32479 Mdot
.61867 .72959 Mdot
.42343 .16435 Mdot
.49883 .72523 Mdot
.41757 .76168 Mdot
.45533 .97994 Mdot
.54449 .37545 Mdot
.53828 .27558 Mdot
.56406 .34581 Mdot
.61307 .52296 Mdot
.48146 .24212 Mdot
.51581 .03609 Mdot
.53622 .98024 Mdot
.53923 .40695 Mdot
.5877 .43843 Mdot
.51473 .32221 Mdot
.57583 .93711 Mdot
.41326 .43004 Mdot
.695 .60889 Mdot
.61241 .55783 Mdot
.46952 .89826 Mdot
.60907 .43924 Mdot
.36679 .42544 Mdot
.41409 .79893 Mdot
.64002 .68048 Mdot
.50761 .83035 Mdot
.56488 .73122 Mdot
.4475 .7812 Mdot
.54083 .41504 Mdot
.6654 .56653 Mdot
.41801 .62195 Mdot
.4552 .73837 Mdot
.65566 .73797 Mdot
.40058 .79408 Mdot
.73972 .2614 Mdot
.47965 .70991 Mdot
.57791 .62662 Mdot
.56431 .89629 Mdot
.60478 .8371 Mdot
.64664 .2801 Mdot
.6664 .45202 Mdot
.73374 .37963 Mdot
.64084 .35941 Mdot
.42844 .09819 Mdot
.66523 .57251 Mdot
.42698 .63502 Mdot
.38324 .6705 Mdot
.63655 .85692 Mdot
.3909 .63785 Mdot
.43414 .38922 Mdot
.58985 .23652 Mdot
.41916 .81305 Mdot
.39999 .13863 Mdot
.63409 .44172 Mdot
.56486 .24334 Mdot
.49012 .05063 Mdot
.6654 .30915 Mdot
.37997 .35965 Mdot
.47812 .77468 Mdot
.41826 .9135 Mdot
.37884 .2679 Mdot
.74413 .58434 Mdot
.53241 .63442 Mdot
.54762 .67434 Mdot
.60661 .57919 Mdot
.37549 .55051 Mdot
.50122 .97188 Mdot
.79443 .40657 Mdot
.45557 .7886 Mdot
.57888 .39895 Mdot
.72689 .34758 Mdot
.60458 .41032 Mdot
.57362 .46659 Mdot
.67033 .53553 Mdot
.52027 .54301 Mdot
.63558 .51955 Mdot
.62941 .23858 Mdot
.48497 .05252 Mdot
.57327 .88236 Mdot
.66433 .31677 Mdot
.63885 .2553 Mdot
.39897 .47745 Mdot
.52717 .09062 Mdot
.55213 .06552 Mdot
.53172 .87882 Mdot
.48803 .1327 Mdot
.50177 .87734 Mdot
.51874 .95166 Mdot
.61896 .73615 Mdot
.57206 .5569 Mdot
.64128 .25651 Mdot
.37949 .61163 Mdot
.53956 .41991 Mdot
.57141 .46181 Mdot
.52737 .2561 Mdot
.41974 .67866 Mdot
.46524 .9808 Mdot
.59754 .91003 Mdot
.63516 .49836 Mdot
.50684 .65164 Mdot
.41779 .13059 Mdot
.60934 .20037 Mdot
.44099 .02683 Mdot
.56032 .52906 Mdot
.55627 .07509 Mdot
.52169 .38057 Mdot
.66583 .70671 Mdot
.64608 .84091 Mdot
.64843 .75914 Mdot
.53035 .04264 Mdot
.54899 .21427 Mdot
.71074 .31293 Mdot
.37518 .54113 Mdot
.42545 .57546 Mdot
.739 .41251 Mdot
.41413 .90694 Mdot
.63076 .16623 Mdot
.37634 .2838 Mdot
.57815 .39016 Mdot
.425 .98567 Mdot
.49548 .85486 Mdot
.52738 .47642 Mdot
.52823 .50335 Mdot
.50082 .64878 Mdot
.49485 .19925 Mdot
.38777 .86743 Mdot
.45478 .88763 Mdot
.51767 .64493 Mdot
.6333 .44933 Mdot
.45163 .73428 Mdot
.53693 .54483 Mdot
.47986 .2134 Mdot
.64341 .34829 Mdot
.57177 .64603 Mdot
.6175 .73908 Mdot
.55503 .43847 Mdot
.49003 .89025 Mdot
.58366 .5893 Mdot
.55633 .07083 Mdot
.53197 .42576 Mdot
.61042 .67436 Mdot
.37719 .26726 Mdot
.58143 .61179 Mdot
.70349 .49632 Mdot
.63024 .71031 Mdot
.59503 .77748 Mdot
.52748 .33053 Mdot
.43908 .23213 Mdot
.419 .17299 Mdot
.53927 .41427 Mdot
.37264 .33298 Mdot
.74313 .41291 Mdot
.46567 .24134 Mdot
.51433 .51488 Mdot
.39101 .87919 Mdot
.55133 .26381 Mdot
.52959 .29713 Mdot
.72109 .34192 Mdot
.57366 .51093 Mdot
.39381 .68148 Mdot
.64659 .37175 Mdot
.43341 .85426 Mdot
.74739 .45765 Mdot
.60329 .32423 Mdot
.56802 .832 Mdot
.58331 .68757 Mdot
.6387 .77747 Mdot
.48735 .267 Mdot
.60149 .19588 Mdot
.59694 .39589 Mdot
.58688 .67741 Mdot
.45763 .05876 Mdot
.61322 .14314 Mdot
.48707 .70313 Mdot
.43052 .61891 Mdot
.62131 .22992 Mdot
.45972 .82694 Mdot
.56794 .4346 Mdot
.52241 .16887 Mdot
.48373 .64279 Mdot
.39102 .81307 Mdot
.70353 .57328 Mdot
.52803 .21819 Mdot
.52886 .29529 Mdot
.57339 .8163 Mdot
.43365 .6027 Mdot
.59543 .37582 Mdot
.55855 .79074 Mdot
.41268 .51373 Mdot
.58879 .29677 Mdot
.41387 .84299 Mdot
.41666 .70955 Mdot
.41365 .8455 Mdot
.49644 .13484 Mdot
.46477 .77543 Mdot
.46105 .16487 Mdot
.62771 .2344 Mdot
.55725 .57062 Mdot
.4085 .40488 Mdot
.6894 .64391 Mdot
.474 .2116 Mdot
.6365 .50218 Mdot
.45388 .05861 Mdot
.46492 .28499 Mdot
.5581 .53764 Mdot
.6614 .31095 Mdot
.36591 .53921 Mdot
.43649 .75516 Mdot
.50884 .39223 Mdot
.41372 .36296 Mdot
.43875 .91291 Mdot
.58854 .45358 Mdot
.63689 .68086 Mdot
.64877 .83584 Mdot
.70157 .45919 Mdot
.36695 .55379 Mdot
.69891 .45129 Mdot
.45951 .65708 Mdot
.70268 .44767 Mdot
.72256 .35716 Mdot
.48972 .93706 Mdot
.36703 .44213 Mdot
.806 .47844 Mdot
.44071 .19519 Mdot
.57814 .26299 Mdot
.40352 .74411 Mdot
.64215 .76943 Mdot
.50563 .02299 Mdot
.41281 .45638 Mdot
.69224 .62856 Mdot
.43682 .78869 Mdot
.49678 .32832 Mdot
.63451 .32636 Mdot
.60047 .61505 Mdot
.66022 .41832 Mdot
.71442 .31529 Mdot
.46479 .7056 Mdot
.59579 .71376 Mdot
.48686 .85724 Mdot
.46719 .97898 Mdot
.42746 .52602 Mdot
.44846 .01771 Mdot
.66587 .23014 Mdot
.72942 .66564 Mdot
.42578 .36605 Mdot
.63747 .46253 Mdot
.40721 .70897 Mdot
.49286 .05872 Mdot
.45868 .19363 Mdot
.5264 .45204 Mdot
.44118 .58243 Mdot
.58134 .68911 Mdot
.36522 .44236 Mdot
.60651 .20689 Mdot
.51399 .31926 Mdot
.61117 .27215 Mdot
.44665 .3255 Mdot
.4991 .65419 Mdot
.42626 .1504 Mdot
.62071 .37971 Mdot
.49148 .13522 Mdot
.39895 .4852 Mdot
.47282 .18797 Mdot
.39176 .10594 Mdot
.44883 .81183 Mdot
.39335 .32721 Mdot
.44268 .31155 Mdot
.52095 .94521 Mdot
.50557 .24874 Mdot
.37569 .45592 Mdot
.46383 .09583 Mdot
.54819 .53996 Mdot
.58909 .48503 Mdot
.74492 .58155 Mdot
.36927 .36081 Mdot
.70441 .45173 Mdot
.42948 .88885 Mdot
.42355 .2476 Mdot
.5202 .81546 Mdot
.38278 .65833 Mdot
.57737 .32179 Mdot
.36829 .37844 Mdot
.7199 .70065 Mdot
.55696 .84903 Mdot
.39268 .17317 Mdot
.46035 .0074 Mdot
.56762 .08561 Mdot
.45898 .67681 Mdot
.5242 .21378 Mdot
.37942 .26412 Mdot
.3824 .76245 Mdot
.44715 .64581 Mdot
.65167 .63115 Mdot
.46376 .82634 Mdot
.63652 .471 Mdot
.48539 .89573 Mdot
.6883 .63906 Mdot
.39714 .70751 Mdot
.68715 .38022 Mdot
.55749 .13601 Mdot
.56672 .20069 Mdot
.69947 .41802 Mdot
.5748 .21151 Mdot
.46549 .00911 Mdot
.76803 .32128 Mdot
.66462 .32302 Mdot
.63415 .5631 Mdot
.51994 .47176 Mdot
.62756 .16854 Mdot
.61393 .51071 Mdot
.44704 .61745 Mdot
.46219 .0047 Mdot
.66525 .57502 Mdot
.52577 .44377 Mdot
.52943 .68139 Mdot
.51931 .78017 Mdot
.54421 .3357 Mdot
.68517 .66535 Mdot
.61294 .75442 Mdot
.73382 .39387 Mdot
.45286 .01246 Mdot
.56872 .71652 Mdot
.36347 .29647 Mdot
.54316 .77307 Mdot
.42404 .70295 Mdot
.40594 .48704 Mdot
.47822 .34044 Mdot
.36529 .54507 Mdot
.36809 .38542 Mdot
.51893 .27541 Mdot
.54832 .50136 Mdot
.55375 .3573 Mdot
.55795 .4471 Mdot
.68009 .24533 Mdot
.586 .42308 Mdot
.52881 .88414 Mdot
.52494 .65806 Mdot
.57392 .47514 Mdot
.42729 .4885 Mdot
.56789 .35078 Mdot
.55337 .74788 Mdot
.55974 .38391 Mdot
.50482 .68532 Mdot
.73029 .36304 Mdot
.42129 .92174 Mdot
.49519 .58544 Mdot
.3957 .39152 Mdot
.56503 .7307 Mdot
.63022 .57655 Mdot
.43736 .78539 Mdot
.57411 .50268 Mdot
.64106 .1866 Mdot
.52226 .99843 Mdot
.38786 .61132 Mdot
.68046 .16514 Mdot
.41975 .8217 Mdot
.4686 .72904 Mdot
.64214 .76015 Mdot
.38669 .21272 Mdot
.46428 .21969 Mdot
.45781 .10129 Mdot
.40134 .06944 Mdot
.54767 .52803 Mdot
.5056 .35083 Mdot
.40913 .58067 Mdot
.57472 .81529 Mdot
.40086 .44893 Mdot
.53551 .45899 Mdot
.3949 .41653 Mdot
.43864 .82795 Mdot
.49211 .27012 Mdot
.47747 .70824 Mdot
.54752 .62303 Mdot
.37724 .72574 Mdot
.43691 .62907 Mdot
.49892 .05902 Mdot
.40265 .24927 Mdot
.57422 .76415 Mdot
.39577 .76586 Mdot
.65105 .62971 Mdot
.58568 .67143 Mdot
.6301 .86926 Mdot
.51921 .70888 Mdot
.36676 .39751 Mdot
.61559 .14539 Mdot
.41301 .52344 Mdot
.70375 .45146 Mdot
.42644 .75231 Mdot
.60982 .50203 Mdot
.37534 .47448 Mdot
.4628 .89614 Mdot
.48752 .79868 Mdot
.58967 .49495 Mdot
.53201 .79052 Mdot
.75248 .47623 Mdot
.54888 .21734 Mdot
.50035 .59462 Mdot
.47535 .12743 Mdot
.42052 .26665 Mdot
.46176 .68238 Mdot
.43242 .3277 Mdot
.41905 .22635 Mdot
.56293 .2379 Mdot
.51855 .60721 Mdot
.49588 .81815 Mdot
.60933 .82665 Mdot
.51884 .23616 Mdot
.58008 .7485 Mdot
.55542 .65223 Mdot
.54106 .68621 Mdot
.43198 .47077 Mdot
.73202 .24483 Mdot
.43458 .428 Mdot
.43204 .13619 Mdot
.7014 .48923 Mdot
.51802 .89782 Mdot
.56159 .62235 Mdot
.39136 .25291 Mdot
.40844 .10413 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool009oooooo0_l00003ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0^Oooool009kooooo0ol00003ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0^Oooool009kooooo1?l00002ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0^Oooool009cooooo0_l00002ooooo`;o00000_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0;Wooooo002Looooo`;o00001?ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002Kooooo`;o00003oooool00ol0003oooooooooo`2iooooo`00
Voooool2o`0000oooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00V?ooool2
o`0001;ooooo0ol0002iooooo`00V?ooool2o`0001;ooooo00?o0000ooooooooool00_l0002goooo
o`00[?ooool00ol0003oooooooooo`02o`000;Oooooo002/ooooo`03o`000?oooooooooo00;ooooo
0_l0002eooooo`00[?ooool00ol0003oooooooooo`02ooooo`;o0000]Oooool00:cooooo00?o0000
ooooooooool01oooool2o`000;3ooooo002/ooooo`03o`000?oooooooooo00Oooooo0_l0002`oooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00Yoooool3o`0000;ooooo0ol00009ooooo`;o0000
[_ooool00:Oooooo0ol00002ooooo`03o`000?oooooooooo00Wooooo0_l0002^ooooo`00W?ooool4
o`0000Wooooo1?l0002kooooo`00W?ooool4o`0000Wooooo1?l0002kooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0>ooooo`;o0000ZOooool008_ooooo0_l0
000Oooooo`03o`000?oooooooooo00kooooo0ol0002Xooooo`00Roooool2o`0001oooooo00?o0000
ooooooooool03oooool2o`000:Sooooo002Iooooo`;o00004Oooool3o`0000oooooo0_l0002Xoooo
o`00V?ooool3o`00017ooooo00?o0000ooooooooool03oooool2o`000:Sooooo002Hooooo`;o0000
4_ooool00ol0003oooooooooo`03ooooo`;o0000]?ooool00:cooooo00?o0000ooooooooool00ooo
ool2o`0000kooooo0_l0002Tooooo`00[?ooool00ol0003oooooooooo`0Cooooo`;o0000Y?ooool0
0:cooooo00?o0000ooooooooool01_ooool2o`000;7ooooo002/ooooo`03o`000?oooooooooo00Ko
oooo0_l0002aooooo`00U?ooool2o`0000[ooooo0_l0000:ooooo`03o`000?oooooooooo0;Wooooo
002Dooooo`;o00002?ooool4o`0000[ooooo0ol0002iooooo`00SOooool2o`0000oooooo0_l0000<
ooooo`03o`000?oooooooooo0;Wooooo0028ooooo`;o00000oooool2o`0001gooooo00?o0000oooo
ooooool0^Oooool008Sooooo0_l0000Rooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@?ooooo0_l000000ooooooo0000onk^kP05ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2iooooo`00ROooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B43ooooo`;o000000?ooooooeEEEOnYZJT02?ooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo0;Wooooo0021ooooo`Ko00000_ooool01Ol@413ooooooooo
oooooooo410@00Wooooo0_l00002ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool0
0oooool3o`0000kooooo0_l0002Yooooo`00ROooool01Ol0003ooooooooooooooooo000000Wooooo
0_l00003ooooo`04ob4Q8Oooooooooooooooo`;o000000Goooooo`000?l0003oMgMgoc8b<P05oooo
o`03o`000?oooooooooo00kooooo0_l0002Yooooo`00ROooool01Ol0003ooooooooooooooooo0000
00;ooooo0_l0000:ooooo`04oeEEEOo<c<coooooooooo`Go000000?o<S8bolc<c?ooool01?ooool0
0ol0003oooooooooo`2iooooo`00ROooool01Ol@413ooooooooooooooooo410@00;ooooo0_l0000:
ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool00oooool5o`000;_ooooo0029oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01oooool2o`0000;ooooo00Go410@oooooooooooooooooc8b
<P04ooooo`03o`000?oooooooooo00?ooooo1Ol0000Booooo`;o0000Yoooool008Wooooo00Gok^k^
oc8b<_l0003o0000onk^kP07ooooo`;o00000_ooool5o`0000Cooooo1?l00003ooooo`;o000000?o
ooooo`000?ooool04Oooool2o`000:Oooooo002;ooooo`;o00007oooool00ol0003oooooooooo`0R
ooooo`;o0000UOooool00:cooooo00?o0000ooooooooool08_ooool3o`0009Cooooo002:ooooo`;o
00000_ooool2o`0001cooooo00?o0000ooooooooool08oooool2o`0009Cooooo002:ooooo`;o0000
0_ooool2o`0000?ooooo0_l0000Gooooo`?o0000^Oooool009?ooooo0_l0000Gooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`04o`000?oooooooooo
ooooo`;o0000]_ooool009;ooooo0_l0000;ooooo`;o00002oooool01?l0003oooooooooooooool2
o`0003Gooooo0_l0001oooooo`00T_ooool2o`0000_ooooo0_l00009ooooo`?o0000:_ooool2o`00
00kooooo0_l0001oooooo`00Z_ooool3o`0000Kooooo0_l0000Qooooo`?o0000Soooool008Sooooo
0_l00007ooooo`;o00006Oooool00ol0003oooooooooo`04ooooo`;o00008Oooool2o`00093ooooo
0028ooooo`;o00001oooool2o`0001Wooooo0ol0000>ooooo`;o0000ZOooool00:cooooo00?o0000
ooooooooool03_ooool2o`000:Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002Sooooo`;o00001oooool00ol0003oooooooooo`0[ooooo`;o0000
S?ooool00:?ooooo0_l00007ooooo`03o`000?oooooooooo02_ooooo0_l0002<ooooo`00V?ooool2
o`0000Cooooo0_l0000<ooooo`03o`000?oooooooooo0;Wooooo002Hooooo`;o00001?ooool2o`00
00cooooo00?o0000ooooooooool07_ooool2o`0009Wooooo002Zooooo`Go00004oooool2o`0000Wo
oooo0_l000000ooooooo0000o`00002Fooooo`00Toooool2o`0001Gooooo0ol0000Eooooo`;o0000
3?ooool2o`0009Kooooo002Cooooo`;o00005oooool00ol0003oooooooooo`0Pooooo`;o0000Uooo
ool00:cooooo00?o0000ooooooooool08?ooool2o`0009Oooooo0026ooooo`;o00006oooool4o`00
00Gooooo00?o0000ooooooooool05Oooool2o`000:;ooooo0026ooooo`;o00006oooool4o`0000Go
oooo00?o0000ooooooooool01Oooool2o`0000Kooooo0_l00006ooooo`;o0000X_ooool00:3ooooo
0_l0000:ooooo`03o`000?oooooooooo00Gooooo0ol00005ooooo`;o0000Z_ooool00:3ooooo0_l0
000:ooooo`03o`000?oooooooooo00Kooooo0_l00005ooooo`;o0000Z_ooool00:cooooo0ol0000G
ooooo`;o0000X?ooool0097ooooo0_l0000:ooooo`;o00003Oooool00ol0003oooooooooo`0Goooo
o`;o0000X?ooool0097ooooo0_l0000:ooooo`;o00003Oooool00ol0003oooooooooo`0Uooooo`;o
00003?ooool2o`0008Cooooo002Gooooo`;o00004oooool00ol0003oooooooooo`0Uooooo`Co0000
2_ooool2o`0008Cooooo002Gooooo`;o00004oooool00ol0003oooooooooo`03ooooo`;o00003?oo
ool2o`0000Oooooo0_l0000;ooooo`;o0000T?ooool00:?ooooo0_l00007ooooo`03o`000?oooooo
oooo00?ooooo0_l0000<ooooo`;o00001oooool2o`0000_ooooo0_l0002@ooooo`00TOooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B43ooooo`;o000000?oA4A4o`000?l000000_l00005
ooooo`03o`000?oooooooooo01;ooooo0_l0000Cooooo`;o0000T?ooool0097ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q0oooool2o`0000?ooooo0_l00005ooooo`03o`000?oooooo
oooo00Cooooo0_l0000<ooooo`;o00009?ooool2o`0000oooooo0_l0001^ooooo`00ROooool6o`00
00;ooooo00Go410@o`000?l0003ooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol00004
ooooo`;o0000<_ooool2o`0000oooooo0_l0001^ooooo`00R?ooool2o`000003ooooool0003o0000
00Cooooo0ol000000ooooooo0000ooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002ioooo
o`00R?ooool2o`0000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01Oooool00ol0003oooooooooo`06ooooo`;o00008_ooool2o`0008gooooo002Aoooo
o`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo0_l0000Rooooo`?o0000S?ooool0097ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0:oooool2o`0001oooooo0_l0001[
ooooo`00Q?ooool2o`0000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool0
0ol0003oooooooooo`0>ooooo`;o00001_ooool2o`0003Cooooo0_l0001[ooooo`00Poooool3o`00
00_ooooo0_l0000Dooooo`;o00000oooool00ol0003oooooooooo`0>ooooo`;o00001_ooool2o`00
0:7ooooo0023ooooo`?o00002oooool2o`0001Cooooo1?l000000ooooooo0000ooooo`2jooooo`00
ZOooool2o`000003ooooool0003ooooo02;ooooo0_l0002Fooooo`00[?ooool3o`0000?ooooo0_l0
0004ooooo`;o00005_ooool2o`0009Kooooo002/ooooo`03o`000?oooooooooo00?ooooo0_l00004
ooooo`;o00008_ooool2o`0008[ooooo002/ooooo`03o`000?oooooooooo02gooooo0_l0002:oooo
o`00Poooool2o`000003ooooool0003o000001Sooooo0_l0000:ooooo`03o`000?oooooooooo00Co
oooo0_l0002cooooo`00Poooool2o`000003ooooool0003o000001Sooooo0_l0000:ooooo`03o`00
0?oooooooooo00Cooooo0_l0002cooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`06ooooo`;o0000/Oooool007kooooo0_l0000/ooooo`03o`000?oooooooooo
00Kooooo0_l0000Booooo`;o0000WOooool007kooooo0_l0000Jooooo`;o00004?ooool3o`0000Ko
oooo0_l0000Booooo`;o0000WOooool009[ooooo0_l0000@ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo00?ooooo0_l0002dooooo`00[?ooool00ol0003oooooooooo`03
ooooo`;o0000;_ooool2o`0008Cooooo002Iooooo`;o00004Oooool00ol0003oooooooooo`0boooo
o`?o00003Oooool2o`0007Gooooo002Iooooo`;o00004Oooool00ol0003oooooooooo`0booooo`;o
00003_ooool3o`0007Cooooo002/ooooo`04o`000?ooooooooooooooo`;o0000<?ooool2o`0000ko
oooo0_l0001dooooo`00[?ooool01?l0003oooooooooooooool2o`0001?ooooo0_l0000Kooooo`;o
00008?ooool2o`0006;ooooo0025ooooo`;o00001oooool2o`0000[ooooo0_l0000@ooooo`?o0000
00?oooooo`000?l000004oooool2o`0000Oooooo0_l0000Booooo`?o00007oooool2o`0006;ooooo
0025ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Gooooo0_l00003ooooo`;o00003_oo
ool3o`00027ooooo0_l00008ooooo`;o00002?ooool3o`0008?ooooo0028ooooo`;o00002oooool2
o`0001?ooooo0ol00008ooooo`;o00008Oooool2o`0008kooooo0022ooooo`;o0000:?ooool00ol0
003oooooooooo`06ooooo`;o0000/Oooool008;ooooo0_l0000Xooooo`03o`000?oooooooooo00_o
oooo0_l0002/ooooo`00Y?ooool2o`0000Kooooo00?o0000ooooooooool02oooool2o`000:cooooo
002Tooooo`;o00001_ooool00ol0003oooooooooo`16ooooo`;o0000LOooool0087ooooo0_l0000Y
ooooo`03o`000?oooooooooo01;ooooo0_l0000booooo`;o0000LOooool0087ooooo0_l0000Yoooo
o`03o`000?oooooooooo01;ooooo0_l0000Hooooo`;o00006Oooool2o`00073ooooo002/ooooo`?o
00004oooool2o`0001Oooooo0_l0000Iooooo`;o0000L?ooool00:cooooo0ol0000Cooooo`;o0000
Y?ooool00:cooooo00?o0000ooooooooool03_ooool2o`0003Kooooo0_l0001aooooo`00P?ooool2
o`0000;ooooo0_l0000Vooooo`03o`000?oooooooooo00kooooo0_l0000Kooooo`;o00006Oooool2
o`00077ooooo0020ooooo`?o000000?oooooo`000?l000002Oooool2o`0001_ooooo00?o0000oooo
ooooool0:oooool2o`0001cooooo0_l0001^ooooo`00POooool2o`0000Kooooo00Kok^k^oc8b<_l0
003o<S8bonk^k_ooool2o`0000;ooooo0_l00004ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0BOooool2o`0006kooooo0029ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2o`0000Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0^Oooool0087ooooo1_l00002ooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0;Oooool2o`0008[ooooo0029ooooo`05o`000?ooooooooooooooool00000
0_ooool2o`0000Wooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000
2oooool2o`0000oooooo0_l0000?ooooo`;o0000R_ooool0083ooooo0_l00007ooooo`05o`000?oo
ooooooooooooool000000_ooool2o`0000[ooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool02oooool2o`0000oooooo0_l00006ooooo`;o
00005?ooool2o`0000kooooo0_l0001]ooooo`00P?ooool2o`0000Oooooo00Go410@oooooooooooo
oooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`04ooooo`;o00007_ooool2o`0001Cooooo0_l0000>ooooo`;o0000KOooool0083ooooo
0_l00007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`;o00002_ooool2o`00
0:Oooooo0020ooooo`;o00001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo0_l000001_oo
ooooV9RHoa0@4?l0003o8B4Qolc<c0Cooooo1?l00006ooooo`03o`000?oooooooooo013ooooo0_l0
002Wooooo`00ROooool2o`0000_ooooo0_l0000Dooooo`04o`000?oooooo0000o`0001Gooooo0_l0
002Qooooo`00ROooool2o`00027ooooo00Co0000ooooool0003o00005Oooool2o`0003;ooooo0_l0
001]ooooo`00P?ooool2o`0002[ooooo00?o0000ooooooooool07Oooool2o`0002_ooooo0_l0001]
ooooo`00P?ooool2o`0002[ooooo0ol0000Gooooo`;o00001?ooool2o`0000Oooooo0_l0002Aoooo
o`00[?ooool00ol0003oooooooooo`0Gooooo`;o00003Oooool2o`00097ooooo002=ooooo`;o0000
7Oooool00ol0003oooooooooo`0:ooooo`;o0000D_ooool2o`0005Wooooo002=ooooo`;o00007Ooo
ool00ol0003oooooooooo`0:ooooo`;o00004oooool2o`0003gooooo0_l0001Iooooo`00[?ooool0
0ol0003oooooooooo`0Oooooo`;o0000:_ooool4o`0006[ooooo0029ooooo`;o00008Oooool00ol0
003oooooooooo`0:ooooo`;o0000?oooool4o`0006[ooooo0029ooooo`;o00004?ooool2o`0000oo
oooo00?o0000ooooooooool02_ooool2o`0002Gooooo0_l0000;ooooo`;o0000NOooool009_ooooo
0_l0000?ooooo`03o`000?oooooooooo00[ooooo0_l0000Uooooo`;o00002oooool2o`0007Wooooo
0020ooooo`;o0000:_ooool3o`0000Oooooo0_l000000ooooooo0000o`00000=ooooo`;o0000W_oo
ool0083ooooo0_l0000Dooooo`;o00005?ooool00ol0003oooooooooo`07ooooo`;o00004?ooool2
o`0009kooooo002?ooooo`;o00001Oooool2o`0001Cooooo00?o0000ooooooooool0^Oooool008oo
oooo0_l0000Kooooo`03o`000?oooooooooo01?ooooo0_l0002Tooooo`00[?ooool00ol0003ooooo
ooooo`0Cooooo`;o0000Y?ooool00:cooooo00?o0000ooooooooool03oooool2o`0000Wooooo0_l0
0005ooooo`;o0000U_ooool007oooooo0ol0000Zooooo`03o`000?oooooooooo00Gooooo0_l00008
ooooo`;o00002Oooool2o`0000Gooooo0_l00006ooooo`;o0000S_ooool007oooooo0ol0000Zoooo
o`03o`000?oooooooooo00Gooooo0_l0000Rooooo`;o0000S_ooool008_ooooo0_l0000Oooooo`03
o`000?oooooooooo013ooooo0_l0000Gooooo`;o00005?ooool2o`0007Sooooo002;ooooo`;o0000
7oooool3o`0000Gooooo0_l00009ooooo`;o00005oooool2o`0000Sooooo0_l00009ooooo`Co0000
Moooool008?ooooo0_l0000Wooooo`03o`000?oooooooooo00Gooooo0_l0000Cooooo`;o00005ooo
ool2o`0000Wooooo1?l0001gooooo`00Poooool2o`0000[ooooo0_l00006ooooo`;o00004oooool0
0ol0003oooooooooo`08ooooo`;o00004?ooool2o`0003;ooooo0_l0001Yooooo`002Oooool4o`00
0003oa0@4?oooooooooo01Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool0
0ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00000_ooool2o`000006odA4A?l0003o0000
oc8b<_oMgMgooooo0_l0000Cooooo`03o`000?oooooooooo00Sooooo0_l0000:ooooo`;o00000_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool00om4A4Co0000
o`000002o`0000Wooooo0_l00004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool2o`000003
ob4Q8Ooooooooooo00?ooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb
<S;ogMgM01Sooooo1?l000000ol@413oooooooooo`0Booooo`002oooool00ol0003oooooooooo`0H
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01ooo
ool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`0Eooooo`03o`000?oooooooooo
01Cooooo0_l00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RH
ob4Q8Ol0003o0000odA4A007ooooo`;o00002Oooool2o`0000Cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o00002?ooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`0Iooooo`03
o`000?oooooooooo01Cooooo0006o`0000Gooooo00?o0000ooooooooool04?ooool6o`0000;ooooo
00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000oooooooo
ool01Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo
00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05Oooool2o`000003ooooool@413o
oooo00;ooooo00?o410@ooooooooool02_ooool00onHV9So0000o`000009ooooo`03o`000?oooooo
oooo00gooooo00Go410@oooooooooooooooooa0@4005ooooo`;o00002Oooool00ol0003ooooooooo
o`0=ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?oo
ool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8b
ooooo`0>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0>ooooo`05
o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMol0003o0000
01Gooooo00?o0000ooooooooool05Oooool2o`000003ooooool0003ooooo00;ooooo00?o0000oooo
ooooool02oooool2o`000003onk^k_oooooooooo00Gooooo00?oMgMgoc8b<_ooool03_ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooo
oooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`0Iooooo`03o`000?oo
oooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00
000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`00
0?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Co0000ob4Q8Ol0003o<S8b0_l0
000Eooooo`03o`000?oooooooooo00?ooooo0_l0000Cooooo`05o`000?ooooooooooooooool00000
3Oooool2o`000003ofIVI_oooooooooo00;ooooo00Go0000ob4Q8Ol0003o0000olc<c00?ooooo`05
o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000
ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00Jooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go
410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool0
4Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04Oooool01Ol@413o
oooooooooooooooo410@00Gooooo0_l00008ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool06?ooool3o`0000?ooooo0_l000000ooooooo0000o`00000=ooooo`;o000000?ooooooa0@
4?ooool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
ool0003o00004?ooool01Ol@413ooooooooooooooooo410@00Kooooo0_l00004ooooo`03o`000?oo
oooooooo017ooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003ooooooooo
o`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Co
oooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l00004ooooo`05o`000?nj^[[o
0000o`000?l@41001?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Kooooo0_l0
000=ooooo`;o000000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRH
V?l@41001?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool2
o`0000Cooooo00?o0000ooooooooool02Oooool2o`0000Kooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo01Cooooo0009ooooo`03oeEEEOmVIVKo000001[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`Go00001?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co
00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o0000olc<c004
ooooo`Co00005oooool00ol0003oooooooooo`0Hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03?ooool4o`0000Sooooo0_l00006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`00
00Cooooo1?l0000Iooooo`03oeEEEOmVIVKo000001Kooooo002:ooooo`;o00008?ooool00ol0003o
ooooooooo`0Jooooo`;o00006Oooool2o`0008;ooooo002:ooooo`;o000000?oooooo`000?l00000
1Oooool2o`0001Kooooo00?o0000ooooooooool06_ooool2o`0001Wooooo0_l00008ooooo`;o0000
N?ooool008gooooo0_l00005ooooo`;o00005_ooool00ol0003oooooooooo`0oooooo`;o0000KOoo
ool2o`0000;ooooo0_l00005ooooo`00[?ooool00ol0003oooooooooo`0Jooooo`;o00009?ooool2
o`0006cooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd5ooooo`00[?ooool00ol0003ooooooooo
o`0Jooooo`;o00003Oooool2o`0001Gooooo0_l0001]ooooo`04omgMgOl0003o410@olc<c0Kooooo
0007oooooooo0000C?l0000<ooooo`04onk^k_lQ8B7o410@onk^kPKooooo0007ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`;o00001Ooo
ool2o`0000Kooooo0_l00007ooooo`03o`000?oooooooooo00;o00001?ooool00ol0003ooooooooo
o`02o`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00[ooooo00Co8B4QogMgMomgMgOo<S8b1_ooool000Oooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool00_oo
ool2o`0002;ooooo00?o0000ooooooooool01_ooool2o`0000gooooo0_l0000:ooooo`;o00001?oo
ool00ol0003oooooooooo`02o`0002Cooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo00Wooooo0_l00002ooooo`;o00001Oooool008Sooooo0_l0000R
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo01Gooooo0_l0000;oooo
o`;o0000UOooool008oooooo0_l0000Kooooo`04o`000?ooooooooooooooo`;o00004_ooool2o`00
00_ooooo0_l0002Eooooo`00Soooool2o`0001_ooooo00Co0000oooooooooooooooo0_l0000Voooo
o`;o00002_ooool2o`0008;ooooo002/ooooo`03o`000?oooooooooo02Wooooo0_l00008ooooo`Co
0000P_ooool008oooooo0_l0000Kooooo`?o00008_ooool2o`0000oooooo0_l00024ooooo`00Sooo
ool2o`0000?ooooo0_l0000Fooooo`03o`000?oooooooooo00cooooo0_l0000Dooooo`;o0000UOoo
ool009Cooooo0_l0000Fooooo`03o`000?oooooooooo00cooooo0_l00002ooooo`;o0000Yoooool0
0:cooooo00?o0000ooooooooool04?ooool2o`0000Wooooo0_l0002Looooo`00[?ooool00ol0003o
ooooooooo`0@ooooo`;o00002Oooool2o`0001Sooooo0_l00022ooooo`00Ooooool2o`0002_ooooo
00?o0000ooooooooool03?ooool2o`0000;ooooo0_l0000Sooooo`;o0000P_ooool007oooooo0_l0
00000ooooooo0000o`00000Xooooo`03o`000?oooooooooo00?ooooo0_l00007ooooo`;o0000Zooo
ool007oooooo0_l000000ooooooo0000o`00000Xooooo`03o`000?oooooooooo00?ooooo0_l00004
ooooo`;o0000[_ooool007oooooo0_l0000[ooooo`03o`000?oooooooooo00Wooooo0_l0002^oooo
o`00P_ooool2o`0002Sooooo0ol0000Dooooo`;o0000Xoooool0083ooooo1?l0000Xooooo`03o`00
0?oooooooooo01Cooooo0_l0002Sooooo`00P?ooool2o`0002[ooooo00?o0000ooooooooool05?oo
ool2o`0000cooooo0_l0002Eooooo`00[?ooool00ol0003oooooooooo`0Dooooo`;o00003?ooool2
o`0009Gooooo002/ooooo`03o`000?oooooooooo02Wooooo0_l0002>ooooo`00[?ooool00ol0003o
ooooooooo`0Yooooo`;o00002?ooool2o`0008Cooooo002/ooooo`03o`000?oooooooooo00oooooo
0_l0000Rooooo`;o0000Q?ooool00:cooooo00?o0000ooooooooool03oooool2o`0000Wooooo0_l0
0004ooooo`;o00004Oooool2o`0000_ooooo0_l0001gooooo`00Toooool2o`0001Oooooo0ol0000J
ooooo`;o00001?ooool2o`0000Kooooo0_l00009ooooo`;o00002oooool2o`0007Oooooo002Coooo
o`;o00005oooool00ol0003oooooooooo`0Pooooo`;o00001_ooool2o`0000Wooooo0_l00024oooo
o`00S_ooool2o`0000Sooooo0_l0000Booooo`03o`000?oooooooooo023ooooo0_l0000[ooooo`;o
0000J_ooool008kooooo1?l00006ooooo`;o00004?ooool3o`0004oooooo0_l0001Zooooo`00T?oo
ool2o`0001Sooooo0ol0000Eooooo`;o00000oooool2o`0003?ooooo0_l0001Zooooo`00[?ooool0
0ol0003oooooooooo`0Cooooo`;o00000oooool2o`0009oooooo002/ooooo`;o0000^_ooool00:co
oooo0_l00002ooooo`;o0000]_ooool00:cooooo0ol000000ooooooo0000o`00002fooooo`00U_oo
ool2o`0001Cooooo00?o0000ooooooooool0^Oooool009Kooooo0_l0000Dooooo`03o`000?oooooo
oooo00?ooooo0_l0002dooooo`00Z_ooool3o`0000Gooooo0_l0000hooooo`;o0000N_ooool008Co
oooo0_l000000ooooooo0000o`00000Qooooo`?o00006Oooool2o`0002Cooooo0_l0001jooooo`00
Q?ooool2o`000003ooooool0003o000002?ooooo00?o0000ooooooooool05oooool2o`0000Gooooo
0_l0002Iooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B42o`0000;ooooo
1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Nooooo`;o
00007Oooool2o`0007[ooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool2o`000003
oooooolQ8B7o8B4Q00;o00000_ooool01OnHV9So0000o`000?ooooooA4A400Oooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`0Aooooo`;o0000:_ooool2o`0007[ooooo0029ooooo`05
oa0@4?ooooooooooooooool@41000_ooool2o`0000Sooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0
003oooooooooo`03ooooo`?o00003?ooool2o`0000?ooooo0_l0002Vooooo`00ROooool01Ol0003o
oooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo00cooooo0_l00008ooooo`;o00009?ooool2o`0007_ooooo0029ooooo`05
o`000?ooooooooooooooool000002Oooool2o`0000?ooooo00?oMgMgofIVI_ooool00oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool05_ooool2o`0001Kooooo0ol0000;
ooooo`;o0000Noooool008Wooooo00Go410@oooooooooooooooooa0@4009ooooo`;o00001?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool2
o`0002Gooooo0ol00028ooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l00004
ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo0_l0000cooooo`;o0000Noooool008Sooooo0_l000001?lb<S;o0000oc8b<_o^
k^h5ooooo`;o00001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`00
0?oooooooooo00_ooooo0_l0000^ooooo`?o0000Noooool008Sooooo0_l0000Looooo`;o00001?oo
ool00ol0003oooooooooo`0;ooooo`;o0000;_ooool2o`0007cooooo002Jooooo`;o00002_ooool2
o`0000Cooooo00?o0000ooooooooool00_ooool2o`00013ooooo0_l0000Uooooo`;o0000O?ooool0
09[ooooo0_l0000@ooooo`;o00000oooool2o`00013ooooo0_l0000Uooooo`;o0000O?ooool00:co
oooo1?l0000>ooooo`;o0000Z?ooool00:_ooooo0_l000000ooooooo0000o`00000>ooooo`;o0000
Z?ooool008Gooooo0_l0000Gooooo`;o00002oooool2o`0000Oooooo0_l0002booooo`00QOooool2
o`0001Oooooo0_l0000<ooooo`03o`000?oooooooooo00Gooooo0_l0002booooo`00[?ooool00ol0
003oooooooooo`0Booooo`;o0000YOooool00:cooooo00?o0000ooooooooool04_ooool2o`0002Ko
oooo0_l0000<ooooo`;o0000Koooool008Gooooo0_l0000Uooooo`03o`000?oooooooooo03[ooooo
0_l0000<ooooo`;o0000Koooool008Gooooo0_l0000Uooooo`03o`000?oooooooooo01Wooooo0_l0
002Nooooo`00W_ooool2o`0000cooooo0ol0000<ooooo`;o00002oooool2o`0000Kooooo0_l0002F
ooooo`00TOooool2o`0000_ooooo0_l0000<ooooo`03o`000?oooooooooo00cooooo0_l0000;oooo
o`;o00001_ooool2o`0009Kooooo0029ooooo`;o00001_ooool2o`0000cooooo0_l0000;ooooo`03
o`000?oooooooooo00Kooooo0_l0000Aooooo`;o00003oooool3o`0008cooooo0022ooooo`;o0000
1Oooool2o`0001Cooooo0_l0000;ooooo`?o00001_ooool2o`0000;ooooo0_l0000Nooooo`?o0000
S?ooool008;ooooo0_l0000Xooooo`?o00002_ooool2o`0000_ooooo0ol0002Oooooo`00[?ooool0
0ol0003oooooooooo`0Gooooo`?o0000Woooool00:cooooo00?o0000ooooooooool06?ooool2o`00
09oooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000AOooool2o`0007;ooooo
002Booooo`;o00004oooool2o`0000?ooooo00?o0000ooooooooool0AOooool2o`0007;ooooo002:
ooooo`;o00001_ooool2o`0000cooooo0_l00005ooooo`;o00000oooool00ol0003oooooooooo`0c
ooooo`;o0000Q?ooool008[ooooo0_l000001?oooooo0000o`000?ooool2o`0000kooooo0_l00002
ooooo`?o00001Oooool00ol0003oooooooooo`03ooooo`;o00008oooool2o`0000Wooooo0_l00024
ooooo`00SOooool2o`000003ooooool0003o000001;ooooo0ol00005ooooo`03o`000?oooooooooo
00?ooooo0_l00002ooooo`;o00007oooool2o`0008oooooo002/ooooo`03o`000?oooooooooo00Oo
oooo0_l0000:ooooo`;o00001oooool2o`0009_ooooo002/ooooo`03o`000?oooooooooo01?ooooo
0_l00007ooooo`;o0000Voooool00:cooooo00?o0000ooooooooool0^Oooool008?ooooo0_l0000V
ooooo`Co0000^Oooool008?ooooo0_l0000Vooooo`;o0000^oooool008?ooooo0_l0000Fooooo`;o
00001?ooool2o`0000Wooooo00?o0000ooooooooool04_ooool2o`00013ooooo0_l0002Cooooo`00
Voooool3o`0000?ooooo0_l00009ooooo`03o`000?oooooooooo01;ooooo0_l0000@ooooo`;o0000
Toooool009cooooo0_l0000>ooooo`03o`000?oooooooooo02Cooooo0_l0002Cooooo`00WOooool2
o`0000gooooo00?o0000ooooooooool08oooool3o`0000Wooooo0ol00027ooooo`00TOooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B42o`0000?ooooo00GoA4A4o`000?l0003o<S8bomgM
g@05ooooo`03o`000?oooooooooo02?ooooo0_l0000:ooooo`?o0000Qoooool008cooooo0_l00003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2iooooo`00S?ooool2o`0000?ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool2o`0000Oooooo0_l0
002Pooooo`00TOooool00ol0003oooooo`000002o`0000oooooo00?oMgMgoc8b<_ooool01?ooool3
o`0000kooooo0_l00007ooooo`?o0000Woooool0097ooooo00?o0000ooooool000000_l000000ooo
oooo0000o`000009ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0H
ooooo`;o00002?ooool2o`0000[ooooo0_l00029ooooo`00TOooool01_l@413ooooooooooooooooo
410@ooooo`;o00002Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02;ooooo0_l0
000:ooooo`;o0000ROooool0093ooooo0_l000001?nHV9SooooooiRHV?mgMgL<ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0:oooool2o`000003ooooool0003o000008Wooooo0025
ooooo`;o00002Oooool2o`000004oc8b<_l0003o<S8bonk^kPcooooo1?l00003ooooo`;o000000?o
ooooo`000?ooool05_ooool2o`0001Cooooo0_l000000ooooooo0000o`000029ooooo`00QOooool2
o`0000;ooooo0_l0000Nooooo`;o000000?oooooo`000?ooool05_ooool2o`000:;ooooo0029oooo
o`;o00008Oooool00ol0003oooooooooo`0[ooooo`;o0000S?ooool00:7ooooo0_l00009ooooo`03
o`000?oooooooooo00_ooooo0_l0000Nooooo`;o0000S?ooool00:3ooooo0ol000000ooooooo0000
o`000006ooooo`?o00002oooool2o`000:cooooo002Pooooo`?o000000?oooooo`000?l000001_oo
ool3o`0000?ooooo0_l0000Gooooo`;o00003?ooool2o`0008gooooo002Jooooo`;o00004?ooool0
0ol0003oooooooooo`03ooooo`;o00005oooool2o`0000cooooo0_l0002=ooooo`00Uoooool2o`00
0003ooooool0003o0000013ooooo00?o0000ooooooooool02?ooool2o`000:oooooo002Gooooo`;o
00001?ooool2o`0000gooooo00?o0000ooooooooool02?ooool2o`000:oooooo002Gooooo`;o0000
1?ooool2o`0000gooooo00?o0000ooooooooool01oooool2o`0000Oooooo0_l0002Wooooo`00Rooo
ool2o`0001oooooo00?o0000ooooooooool01oooool2o`0000Oooooo0ol0002Vooooo`00Roooool2
o`0001oooooo00?o0000ooooooooool04Oooool2o`000:Kooooo002?ooooo`;o00005_ooool2o`00
00?ooooo0ol0002iooooo`00Soooool2o`0001Kooooo0_l00003ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo0028
ooooo`;o00001oooool2o`0000Sooooo0_l0000?ooooo`03o`000?oooooooooo0;Wooooo0028oooo
o`;o00001oooool2o`0000Sooooo0_l0000?ooooo`03o`000?oooooooooo00?ooooo0_l0000@oooo
o`;o0000X_ooool00:[ooooo0ol00005ooooo`;o00004?ooool2o`000:;ooooo002Aooooo`;o0000
5oooool3o`0002Cooooo0_l0002Eooooo`00TOooool2o`0000Cooooo0_l0000Cooooo`?o00008_oo
ool2o`0009Gooooo002Gooooo`;o00001?ooool5o`0000[ooooo00?o0000ooooooooool08Oooool2
o`0009Kooooo002Gooooo`;o00001?ooool5o`0000[ooooo00Co0000ooooool0003o00008?ooool2
o`0009Kooooo002/ooooo`04o`000?oooooo0000o`0001;ooooo0_l0002Tooooo`00[?ooool00ol0
003oooooooooo`0Cooooo`;o00002_ooool2o`0000gooooo0_l00029ooooo`00[?ooool00ol0003o
ooooooooo`0Oooooo`;o00003Oooool2o`0008Wooooo002?ooooo`;o00006oooool00ol0003ooooo
ooooo`0]ooooo`;o0000R_ooool008oooooo0_l0000Kooooo`03o`000?oooooooooo02gooooo0_l0
002:ooooo`00Soooool2o`0001_ooooo00?o0000ooooooooool03oooool2o`000:Sooooo002/oooo
o`?o00003oooool2o`000:Sooooo002Fooooo`;o00004_ooool3o`000;_ooooo002Fooooo`;o0000
3oooool2o`000004ooooool0003o0000o`0002cooooo0_l0002=ooooo`00Yoooool2o`0000?ooooo
00?o0000ooooooooool0:_ooool2o`0008gooooo002/ooooo`04o`000?ooooooooooooooo`;o0000
]_ooool008Oooooo0_l000001Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`00
0?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`04o`000?oooooooooooooo
o`;o0000]_ooool008Oooooo0_l000001OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46oooo
o`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Goooo
o`;o00003oooool2o`0008oooooo0029ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onY
ZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05oooool2o`00
00oooooo0_l0002?ooooo`00ROooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qoooo
ooooool01_ooool00omgMgOo<S8booooo`04ooooo`?o0000^Oooool008Sooooo0_l00003ooooo`03
o`000?oooooooooo00cooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo0_l00008ooooo`;o0000/?ooool008Sooooo0_l00003ooooo`03oa0@4?oooooooooo00co
oooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`;o00002?ooool2o`0000co
oooo0_l0002Rooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@ooooool0
003o0000oc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool2o`00
00gooooo0_l0002Rooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo0_l00003oooo
o`Ko00000oooool4o`0000Kooooo00?o0000ooooooooool01_ooool2o`000;7ooooo002Dooooo`;o
00001oooool2o`0000Wooooo0_l00002ooooo`03o`000?oooooooooo0;Wooooo002Xooooo`;o0000
0_ooool00ol0003oooooooooo`2iooooo`00Woooool2o`000003ooooool0003o000000?ooooo0_l0
0003ooooo`03o`000?oooooooooo00?ooooo0_l0000=ooooo`;o0000YOooool009oooooo0_l00000
0ooooooo0000o`000003ooooo`;o00000oooool3o`0000?ooooo0_l0000=ooooo`;o0000YOooool0
0:cooooo00?o0000ooooooooool0^Oooool008oooooo0_l0000Kooooo`03o`000?oooooooooo0;Wo
oooo002?ooooo`;o00006oooool00ol0003oooooooooo`0Mooooo`;o0000V_ooool009Oooooo0_l0
000Cooooo`03o`000?oooooooooo01gooooo0_l0002Jooooo`00TOooool2o`0000Cooooo0_l0000C
ooooo`03o`000?oooooooooo0;Wooooo002Aooooo`;o00006Oooool00ol0003oooooooooo`2ioooo
o`00T_ooool2o`0001Sooooo00?o0000ooooooooool0^Oooool009;ooooo0_l0000Hooooo`?o0000
^Oooool009cooooo0_l0000>ooooo`03o`000?oooooooooo0;Wooooo002Looooo`;o00003_ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00Z?ooool2o`0000;o
oooo00?o0000ooooooooool05_ooool2o`000:7ooooo002Xooooo`;o00000_ooool00ol0003ooooo
ooooo`0Fooooo`;o0000XOooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool00oooool2o`000;Cooooo002/ooooo`03o`000?oooooooooo00?ooooo0_l0002doooo
o`00[?ooool3o`0000?ooooo0_l0002dooooo`00[?ooool00ol0003oooooooooo`03ooooo`;o0000
]?ooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo0_l0002jooooo`00[?ooool2o`000;[ooooo
002/ooooo`;o0000^_ooool00:cooooo0ol0002iooooo`00WOooool2o`0000;ooooo0_l00009oooo
o`03o`000?oooooooooo0;Wooooo002Mooooo`Ko00002Oooool00ol0003oooooooooo`09ooooo`;o
0000[_ooool009?ooooo0_l00009ooooo`Co00002_ooool00ol0003oooooooooo`09ooooo`;o0000
[_ooool009?ooooo0_l0000Gooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002Rooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`2ioooo
o`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`03o`00
0?oooooooooo00Gooooo0ol00004ooooo`;o0000/oooool00:Cooooo00?o0000ooooooooool03?oo
ool2o`000;?ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo
0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Rooooo`03oeEEEOmVIVKo00000<?ooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Zooooo`04oa0@
4?l0003o0000o`000;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oo
oooooooo0;[ooooo002[ooooo`06o`000?mgMgOo0000o`000?mEEEGok^k^]oooool00:_ooooo00Ko
0000oeEEEOo^k^koooooogMgMomEEEFgooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03o`00
0?oooooooooo0;Gooooo002[ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0]Ooo
ool00:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomVIVJgooooo`00Z_ooool00ol@413o0000ogMg
M`02o`000003ofIVI_o^k^kooooo0;Kooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.6194 .66237 Mdot
.40075 .74199 Mdot
.46235 .62377 Mdot
.53543 .62656 Mdot
.41373 .34042 Mdot
.54551 .20052 Mdot
.47363 .67336 Mdot
.54715 .92753 Mdot
.70938 .53926 Mdot
.55219 .61152 Mdot
.4198 .64263 Mdot
.46417 .98974 Mdot
.61291 .2618 Mdot
.46005 .77767 Mdot
.46768 .98573 Mdot
.42706 .34522 Mdot
.59654 .37357 Mdot
.62407 .28472 Mdot
.57416 .57488 Mdot
.45651 .94282 Mdot
.61475 .27176 Mdot
.40517 .22915 Mdot
.43613 .12658 Mdot
.63746 .31835 Mdot
.3652 .44492 Mdot
.56698 .68375 Mdot
.42322 .33169 Mdot
.57732 .51272 Mdot
.4121 .85241 Mdot
.39919 .72862 Mdot
.63373 .32203 Mdot
.71042 .55357 Mdot
.62422 .81407 Mdot
.60826 .58606 Mdot
.49392 .85981 Mdot
.60262 .77597 Mdot
.55742 .12366 Mdot
.55252 .35279 Mdot
.39028 .73895 Mdot
.41504 .91721 Mdot
.3705 .32672 Mdot
.56507 .73561 Mdot
.39355 .40859 Mdot
.58661 .75276 Mdot
.63748 .59242 Mdot
.56583 .33275 Mdot
.5063 .74347 Mdot
.70705 .43618 Mdot
.3977 .48687 Mdot
.44706 .9284 Mdot
.70291 .41796 Mdot
.39245 .23427 Mdot
.37288 .79298 Mdot
.4212 .78198 Mdot
.39531 .61873 Mdot
.68717 .67031 Mdot
.53815 .93711 Mdot
.59909 .37906 Mdot
.66352 .29448 Mdot
.64246 .55071 Mdot
.57775 .37337 Mdot
.6936 .26235 Mdot
.38893 .72649 Mdot
.43781 .67144 Mdot
.64661 .76521 Mdot
.70127 .62103 Mdot
.55903 .56629 Mdot
.41848 .55905 Mdot
.56368 .38906 Mdot
.65267 .36577 Mdot
.6185 .49079 Mdot
.51215 .3982 Mdot
.55094 .61268 Mdot
.55814 .43878 Mdot
.38938 .72968 Mdot
.50104 .41097 Mdot
.37253 .79048 Mdot
.59191 .4649 Mdot
.37601 .40022 Mdot
.45061 .81757 Mdot
.67051 .52959 Mdot
.41288 .79776 Mdot
.54894 .52529 Mdot
.54871 .7706 Mdot
.62249 .82107 Mdot
.45815 .2415 Mdot
.4253 .27254 Mdot
.46396 .18712 Mdot
.58225 .32296 Mdot
.41731 .5276 Mdot
.36607 .42127 Mdot
.68831 .78024 Mdot
.46454 .25875 Mdot
.52307 .23843 Mdot
.43012 .3638 Mdot
.71068 .73711 Mdot
.47308 .7847 Mdot
.69856 .40889 Mdot
.35872 .65969 Mdot
.59555 .35783 Mdot
.59758 .72167 Mdot
.54476 .23924 Mdot
.48213 .98859 Mdot
.55949 .80258 Mdot
.67221 .48048 Mdot
.59975 .63035 Mdot
.61737 .53122 Mdot
.55156 .6736 Mdot
.4686 .2556 Mdot
.65202 .36653 Mdot
.51411 .73069 Mdot
.53799 .61907 Mdot
.71085 .53797 Mdot
.56015 .85297 Mdot
.60428 .0614 Mdot
.53108 .53028 Mdot
.58856 .42662 Mdot
.68283 .69629 Mdot
.69962 .6371 Mdot
.51868 .0801 Mdot
.60721 .25202 Mdot
.64559 .17963 Mdot
.54461 .15941 Mdot
.39735 .79021 Mdot
.65423 .37251 Mdot
.51514 .6916 Mdot
.53278 .89009 Mdot
.73931 .65692 Mdot
.52362 .8526 Mdot
.45966 .70239 Mdot
.44737 .1044 Mdot
.56292 .79144 Mdot
.41234 .90568 Mdot
.57078 .24172 Mdot
.43072 .17749 Mdot
.37363 .53121 Mdot
.54906 .10915 Mdot
.46492 .94527 Mdot
.5546 .59242 Mdot
.59354 .85962 Mdot
.44513 .97007 Mdot
.73787 .38434 Mdot
.54618 .43442 Mdot
.57736 .47434 Mdot
.59829 .37919 Mdot
.50756 .92489 Mdot
.64997 .77188 Mdot
.71706 .20657 Mdot
.55429 .65508 Mdot
.49846 .19903 Mdot
.62592 .14758 Mdot
.52871 .21032 Mdot
.52025 .26659 Mdot
.64454 .33553 Mdot
.49747 .34343 Mdot
.6034 .31955 Mdot
.4849 .04361 Mdot
.37515 .55326 Mdot
.68622 .68236 Mdot
.55104 .11677 Mdot
.50097 .0553 Mdot
.48653 .83686 Mdot
.37823 .35866 Mdot
.37675 .25436 Mdot
.64325 .67882 Mdot
.39199 .52256 Mdot
.61271 .67734 Mdot
.6594 .75166 Mdot
.67342 .53615 Mdot
.55482 .3569 Mdot
.50388 .05651 Mdot
.5202 .90277 Mdot
.46924 .25956 Mdot
.51614 .26181 Mdot
.41679 .32226 Mdot
.52698 .73133 Mdot
.627 .80591 Mdot
.72156 .71003 Mdot
.5945 .29836 Mdot
.5275 .45164 Mdot
.40673 .82971 Mdot
.45133 .05232 Mdot
.37906 .75086 Mdot
.53194 .32906 Mdot
.3804 .23483 Mdot
.44607 .32191 Mdot
.70851 .50671 Mdot
.74244 .64091 Mdot
.71208 .55914 Mdot
.36754 .3549 Mdot
.41362 .23963 Mdot
.59591 .11293 Mdot
.50558 .92765 Mdot
.50219 .70026 Mdot
.664 .21251 Mdot
.59153 .86832 Mdot
.45821 .00098 Mdot
.44914 .97756 Mdot
.49422 .19125 Mdot
.61763 .89465 Mdot
.59765 .65544 Mdot
.47881 .29963 Mdot
.48967 .30913 Mdot
.52033 .44878 Mdot
.40505 .47841 Mdot
.58218 .93875 Mdot
.58859 .73946 Mdot
.53564 .44493 Mdot
.57304 .24933 Mdot
.53687 .62822 Mdot
.51486 .34483 Mdot
.41138 .54077 Mdot
.54273 .14829 Mdot
.59018 .44603 Mdot
.67313 .53908 Mdot
.49046 .24206 Mdot
.60713 .69282 Mdot
.57938 .3893 Mdot
.37935 .23539 Mdot
.46518 .2808 Mdot
.64017 .47436 Mdot
.44535 .97743 Mdot
.58615 .41179 Mdot
.66202 .29632 Mdot
.67436 .51031 Mdot
.66602 .57748 Mdot
.43532 .30709 Mdot
.42429 .71479 Mdot
.41572 .81524 Mdot
.46706 .25947 Mdot
.46068 .98306 Mdot
.66829 .21291 Mdot
.42055 .59668 Mdot
.48125 .33791 Mdot
.58508 .93275 Mdot
.42851 .22362 Mdot
.42755 .30453 Mdot
.61786 .14192 Mdot
.53803 .31093 Mdot
.5331 .84522 Mdot
.5553 .17175 Mdot
.57475 .76989 Mdot
.69045 .25765 Mdot
.49299 .12555 Mdot
.66082 .632 Mdot
.61834 .48757 Mdot
.70968 .57747 Mdot
.42146 .49648 Mdot
.44293 .06882 Mdot
.5153 .19589 Mdot
.61784 .47741 Mdot
.38243 .67132 Mdot
.43436 .03092 Mdot
.53154 .51164 Mdot
.5107 .67468 Mdot
.47357 .04535 Mdot
.56811 .67595 Mdot
.50178 .2346 Mdot
.39571 .36288 Mdot
.50803 .46289 Mdot
.56679 .8997 Mdot
.69284 .37328 Mdot
.40787 .32735 Mdot
.42684 .30795 Mdot
.65991 .6163 Mdot
.5064 .66078 Mdot
.50576 .17582 Mdot
.63484 .59074 Mdot
.49148 .76913 Mdot
.46826 .12359 Mdot
.57218 .82818 Mdot
.53524 .75344 Mdot
.57294 .83048 Mdot
.39064 .4854 Mdot
.55098 .62031 Mdot
.40486 .63342 Mdot
.48157 .04186 Mdot
.5455 .37062 Mdot
.46862 .81092 Mdot
.70697 .44391 Mdot
.41225 .56674 Mdot
.59737 .30218 Mdot
.38321 .6877 Mdot
.43024 .59052 Mdot
.53316 .33764 Mdot
.54578 .11095 Mdot
.50717 .9689 Mdot
.54434 .69474 Mdot
.4456 .37483 Mdot
.45834 .79722 Mdot
.59452 .79959 Mdot
.52997 .25358 Mdot
.66923 .48086 Mdot
.74311 .63584 Mdot
.64525 .25919 Mdot
.51013 .96235 Mdot
.63943 .25129 Mdot
.51384 .556 Mdot
.64175 .24767 Mdot
.62542 .15716 Mdot
.6255 .7395 Mdot
.48572 .98393 Mdot
.75737 .27844 Mdot
.41588 .71567 Mdot
.44686 .13809 Mdot
.54652 .82055 Mdot
.70992 .56943 Mdot
.36438 .46933 Mdot
.47893 .78099 Mdot
.70366 .42856 Mdot
.55423 .71393 Mdot
.43281 .44204 Mdot
.52506 .12636 Mdot
.60649 .41505 Mdot
.58755 .21832 Mdot
.60054 .11529 Mdot
.52757 .5655 Mdot
.64129 .51376 Mdot
.59165 .66212 Mdot
.62726 .80147 Mdot
.49097 .70194 Mdot
.37545 .72021 Mdot
.51793 .03014 Mdot
.75567 .46564 Mdot
.45641 .74387 Mdot
.58248 .26253 Mdot
.53696 .79348 Mdot
.3748 .51749 Mdot
.41165 .63752 Mdot
.4696 .29846 Mdot
.50031 .62986 Mdot
.61699 .48911 Mdot
.48617 .99179 Mdot
.45119 .06001 Mdot
.42936 .36774 Mdot
.48018 .08162 Mdot
.44304 .66151 Mdot
.5208 .45425 Mdot
.40922 .78843 Mdot
.53259 .17971 Mdot
.3918 .50698 Mdot
.48822 .83524 Mdot
.40735 .57702 Mdot
.40698 .94872 Mdot
.56151 .69216 Mdot
.45494 .89389 Mdot
.44085 .68188 Mdot
.65904 .74521 Mdot
.4138 .42065 Mdot
.48686 .94313 Mdot
.38918 .63623 Mdot
.52417 .33996 Mdot
.5431 .28503 Mdot
.73754 .38155 Mdot
.46749 .99175 Mdot
.6451 .25173 Mdot
.5858 .80717 Mdot
.43103 .77925 Mdot
.60638 .61546 Mdot
.53007 .89063 Mdot
.46708 .15305 Mdot
.47155 .99222 Mdot
.76016 .50065 Mdot
.65658 .64903 Mdot
.42146 .93012 Mdot
.37063 .67056 Mdot
.38746 .18604 Mdot
.51932 .56763 Mdot
.40621 .34518 Mdot
.44418 .96836 Mdot
.55519 .91557 Mdot
.51337 .60443 Mdot
.66414 .43115 Mdot
.56884 .66639 Mdot
.58492 .271 Mdot
.6058 .70117 Mdot
.70393 .43906 Mdot
.53864 .83641 Mdot
.59923 .18022 Mdot
.39651 .21848 Mdot
.41909 .17398 Mdot
.62668 .21802 Mdot
.42757 .14569 Mdot
.36989 .64775 Mdot
.65655 .12128 Mdot
.55383 .12302 Mdot
.61939 .3631 Mdot
.4712 .31848 Mdot
.45611 .00726 Mdot
.57821 .31071 Mdot
.50677 .60078 Mdot
.36964 .66309 Mdot
.65526 .37502 Mdot
.46645 .30007 Mdot
.56198 .48139 Mdot
.59138 .58017 Mdot
.44542 .24271 Mdot
.71131 .46535 Mdot
.67471 .55442 Mdot
.65137 .19387 Mdot
.37335 .70212 Mdot
.61532 .51652 Mdot
.61239 .57307 Mdot
.53216 .72016 Mdot
.48711 .80433 Mdot
.43947 .52048 Mdot
.50858 .9708 Mdot
.47311 .99158 Mdot
.41981 .35528 Mdot
.50887 .30136 Mdot
.45932 .21418 Mdot
.49679 .24751 Mdot
.53822 .04533 Mdot
.51524 .22308 Mdot
.64247 .68414 Mdot
.54816 .45806 Mdot
.52397 .27514 Mdot
.48281 .7108 Mdot
.46917 .18065 Mdot
.61252 .54788 Mdot
.47401 .20725 Mdot
.53895 .48532 Mdot
.63551 .16304 Mdot
.59621 .85617 Mdot
.49085 .3979 Mdot
.46847 .86972 Mdot
.61731 .5307 Mdot
.62084 .37655 Mdot
.5532 .70996 Mdot
.53519 .30268 Mdot
.68163 .79843 Mdot
.5183 .86533 Mdot
.56539 .79436 Mdot
.53554 .57238 Mdot
.7062 .56015 Mdot
.43139 .94772 Mdot
.41612 .60744 Mdot
.39168 .66131 Mdot
.39694 .91476 Mdot
.51888 .32803 Mdot
.43626 .39833 Mdot
.50688 .77184 Mdot
.66084 .61529 Mdot
.47989 .83478 Mdot
.6523 .84373 Mdot
.47971 .27807 Mdot
.47411 .8678 Mdot
.5664 .73474 Mdot
.42111 .47501 Mdot
.52987 .53338 Mdot
.55673 .42303 Mdot
.54716 .92714 Mdot
.51162 .64683 Mdot
.37355 .49095 Mdot
.43592 .87013 Mdot
.63988 .56415 Mdot
.55354 .86082 Mdot
.66294 .42971 Mdot
.61425 .47143 Mdot
.7378 .66926 Mdot
.56277 .50888 Mdot
.47604 .99477 Mdot
.43713 .0255 Mdot
.49353 .76558 Mdot
.64433 .25146 Mdot
.54481 .7313 Mdot
.57063 .30203 Mdot
.49099 .94067 Mdot
.59408 .73092 Mdot
.56904 .60397 Mdot
.54765 .29495 Mdot
.60822 .59052 Mdot
.70298 .27623 Mdot
.4144 .23956 Mdot
.4982 .39494 Mdot
.39359 .57909 Mdot
.43584 .78835 Mdot
.52061 .56046 Mdot
.4466 .72321 Mdot
.42736 .80348 Mdot
.42782 .18439 Mdot
.52143 .40721 Mdot
.58335 .61869 Mdot
.69999 .62665 Mdot
.41077 .36415 Mdot
.63948 .5485 Mdot
.57632 .45223 Mdot
.57554 .48621 Mdot
.47793 .69417 Mdot
.58995 .04483 Mdot
.46803 .69207 Mdot
.40487 .76628 Mdot
.65709 .28923 Mdot
.63715 .69782 Mdot
.57053 .42235 Mdot
.43915 .91866 Mdot
.40298 .87625 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Oo00001?ooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool009kooooo0_l00004ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0^Oooool009gooooo0_l00005ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0^Oooool009gooooo0_l00005ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2i
ooooo`00X_ooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Gooooo`;o00004ooo
ool3o`000;Wooooo002Gooooo`;o00004oooool00ol0003oooooooooo`2iooooo`00U_ooool2o`00
01Cooooo00?o0000ooooooooool00_ooool2o`000;Gooooo002Fooooo`;o00005?ooool00ol0003o
ooooooooo`02ooooo`;o0000]Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o
0000ooooooooool0^Oooool00:Gooooo1?l00003ooooo`03o`000?oooooooooo0;Wooooo002Soooo
o`Ko00000oooool00ol0003oooooooooo`09ooooo`;o00003oooool2o`0009gooooo002Sooooo`;o
00001oooool00ol0003oooooooooo`09ooooo`;o00003oooool2o`0009gooooo002Kooooo`;o0000
3oooool3o`000;Wooooo002Kooooo`;o00003oooool2o`000;[ooooo002/ooooo`?o0000^Oooool0
09_ooooo0_l0000?ooooo`?o00007oooool2o`0009Sooooo002Kooooo`;o00003oooool00ol0003o
ooooooooo`0Oooooo`;o0000V?ooool00:cooooo00?o0000ooooooooool0^Oooool009Wooooo0_l0
000Aooooo`03o`000?oooooooooo0;Wooooo002Iooooo`;o00004Oooool00ol0003oooooooooo`2i
ooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo00?ooooo0_l0002dooooo`00
YOooool2o`0000Gooooo00?o0000ooooooooool00oooool2o`000;Cooooo002Uooooo`;o00001Ooo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool3o`000;Wooooo002Jooooo`;o00004?ooool00ol0003oooooooooo`2i
ooooo`00V_ooool2o`00013ooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool03Oooool2o`000:[ooooo002/ooooo`03o`000?oooooooooo00cooooo0ol0000=ooooo`;o0000
Voooool00:cooooo00?o0000ooooooooool03?ooool3o`0000gooooo1?l0002Iooooo`00ROooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00gooooo0_l0000?ooooo`;o0000
VOooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVY
ooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0<?ooool2o`0008Oooooo
0021ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool0
0oooool2o`0000?ooooo00?o0000ooooooooool00_l000001?oooooo0000o`000?l0000>ooooo`Co
00007_ooool2o`0008Oooooo0029ooooo`05o`000?ooooooooooooooool000002?ooool2o`0000Co
oooo00?o8B4Qooooooooool00_ooool2o`0000;ooooo00CoMgMgoc8b<_oooooooooo0_l000000ooo
oooo0000ooooo`06ooooo`;o00001oooool4o`000:Oooooo0029ooooo`05o`000?oooooooooooooo
ool000002?ooool2o`0000Cooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool01Oooool2o`000;;ooooo0029ooooo`05oa0@4?oooooooooo
ooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0^Oooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooo
oooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Wooooo0029
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`03o`000?oo
oooooooo0;Wooooo002Jooooo`;o00004?ooool00ol0003oooooooooo`0Sooooo`;o0000U?ooool0
09Cooooo0_l0000Fooooo`03o`000?oooooooooo02?ooooo0_l0002Dooooo`00U?ooool2o`0001Ko
oooo00?o0000ooooooooool02oooool2o`0001Wooooo0_l0002Aooooo`00XOooool2o`0000Wooooo
0ol0000;ooooo`;o00006Oooool2o`00097ooooo002Qooooo`;o00002Oooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`0Vooooo`;o0000TOooool00:cooooo00?o0000oooo
ooooool02oooool2o`0001Wooooo0_l0002Aooooo`00[?ooool00ol0003oooooooooo`0;ooooo`;o
00007?ooool2o`0008kooooo002/ooooo`03o`000?oooooooooo02Wooooo0_l0002>ooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00TOooool2o`0001Wooooo00?o0000ooooooooool03oooool2
o`000:Sooooo002Aooooo`;o00006Oooool3o`0000oooooo0_l0002Xooooo`00UOooool2o`0001Go
oooo0ol00007ooooo`;o00005?ooool2o`0000kooooo0_l0002:ooooo`00UOooool2o`0000[ooooo
0_l00009ooooo`03o`000?oooooooooo00Oooooo0_l0000Dooooo`;o00003_ooool2o`0008[ooooo
0026ooooo`;o00003?ooool2o`0000_ooooo0_l00009ooooo`03o`000?oooooooooo0;Wooooo0026
ooooo`;o00003?ooool2o`0000[ooooo0_l0000:ooooo`03o`000?oooooooooo0;Wooooo002Poooo
o`;o00002?ooool3o`000;_ooooo002Zooooo`?o0000<Oooool2o`0008Sooooo002/ooooo`03o`00
0?oooooooooo00;ooooo0_l0000[ooooo`;o0000R?ooool00:_ooooo1?l00002ooooo`;o00002?oo
ool2o`000:_ooooo002[ooooo`;o00003_ooool2o`000:_ooooo002Sooooo`;o00001oooool00ol0
003oooooooooo`14ooooo`;o0000Loooool00:?ooooo0_l00007ooooo`03o`000?oooooooooo00Ko
oooo0_l0000looooo`;o0000Loooool00:cooooo00?o0000ooooooooool01_ooool2o`0002_ooooo
0ol00023ooooo`00W_ooool2o`0000cooooo00?o0000ooooooooool0<oooool3o`0008?ooooo0029
ooooo`;o00004oooool2o`0000cooooo00?o0000ooooooooool06Oooool2o`0000_ooooo0_l0002A
ooooo`00ROooool2o`00027ooooo00?o0000ooooooooool06Oooool2o`0000_ooooo0_l0002Aoooo
o`00U?ooool2o`0001Kooooo0ol00002ooooo`;o0000]Oooool009Cooooo0_l0000Fooooo`03o`00
0?oooooooooo00;ooooo0_l0002eooooo`00S?ooool2o`0001kooooo00?o0000ooooooooool0^Ooo
ool008Cooooo0_l00002ooooo`;o00000_ooool2o`0001kooooo0_l0002jooooo`00Q?ooool2o`00
00;ooooo0_l0000Rooooo`;o0000^_ooool008Cooooo0_l00009ooooo`;o00006oooool00ol0003o
ooooooooo`04ooooo`;o00001Oooool2o`000:cooooo002?ooooo`;o000000Gok^k^oc8b<_l0003o
<S8bonk^kP04ooooo`;o000000Co8B4Qooooool0003o00000_ooool01_m4A4Co0000o`000?lb<S;o
gMgMooooo`;o00000_ooool00ol0003oooooooooo`04ooooo`;o00001Oooool2o`0000Oooooo0_l0
002Sooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo0_l000001?lQ8B7oooooo`00
0?l00005ooooo`03ogMgMolb<S;ooooo00;o00000_ooool00ol0003oooooooooo`0Dooooo`;o0000
Xoooool008Wooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooo
ooooo`02ooooo`;o00005oooool2o`0001Cooooo0_l0002<ooooo`00TOooool01Ol0003ooooooooo
oooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool4o`0001Gooooo0_l00009ooooo`;o0000
2Oooool3o`0008_ooooo0023ooooo`;o00003?ooool01Ol0003ooooooooooooooooo000000_ooooo
0_l000001?lQ8B7o0000oc8b<_o<c<`5ooooo`03o`000?oooooooooo00Kooooo0_l0000Hooooo`;o
00002Oooool3o`0008_ooooo0023ooooo`;o00003?ooool01Ol@413ooooooooooooooooo410@00[o
oooo0ol00009ooooo`03o`000?oooooooooo00Kooooo0_l0000cooooo`;o0000O?ooool0097ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0:ooooo`?o00002Oooool00ol0003oooooooooo`02ooooo`;o
00007_ooool2o`0000Wooooo0_l0000<ooooo`;o0000O?ooool0097ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`Go00001_ooool00ol0003oooooooooo`02ooooo`;o00005?ooool2o`0000So
oooo0_l00009ooooo`;o00003Oooool2o`0007_ooooo002/ooooo`03o`000?oooooooooo00?ooooo
0_l0000Cooooo`;o00008_ooool2o`0007_ooooo002/ooooo`03o`000?oooooooooo00?ooooo0_l0
000Dooooo`;o0000W_ooool009?ooooo0_l0000Gooooo`03o`000?oooooooooo01Wooooo0_l00007
ooooo`;o0000UOooool009?ooooo0_l0000Gooooo`?o00001?ooool2o`0001cooooo0_l0000Loooo
o`;o0000Moooool00:Gooooo0_l00005ooooo`03o`000?oooooooooo00Cooooo0_l0000jooooo`;o
00004?ooool2o`0006Gooooo002Pooooo`;o00000oooool2o`0000Gooooo00?o0000ooooooooool0
D_ooool2o`0006Gooooo002Pooooo`;o00002_ooool00ol0003oooooooooo`0;ooooo`;o00006Ooo
ool2o`00097ooooo002/ooooo`03o`000?oooooooooo00_ooooo0_l0000Iooooo`;o00002?ooool2
o`0008Oooooo002/ooooo`03o`000?oooooooooo033ooooo0_l00027ooooo`00[?ooool00ol0003o
ooooooooo`0<ooooo`;o00009Oooool2o`0008Cooooo002Rooooo`;o00002?ooool00ol0003ooooo
ooooo`0<ooooo`;o00003_ooool2o`0001Cooooo0ol00024ooooo`00X?ooool4o`000003ooooool0
003o000000Gooooo1?l0000Kooooo`;o00005?ooool2o`0008Gooooo002Dooooo`;o00002_ooool2
o`0000?ooooo0_l00005ooooo`04o`000?oooooo0000o`0000Oooooo0_l0000:ooooo`;o00001ooo
ool2o`0009[ooooo002Dooooo`Co00005?ooool00ol0003oooooooooo`08ooooo`;o00002_ooool2
o`0000Oooooo0_l0002Jooooo`00Toooool2o`000003ooooool0003o0000013ooooo0_l00002oooo
o`03o`000?oooooooooo0;Wooooo002Cooooo`;o00004oooool2o`0000;ooooo00?o0000oooooooo
ool02Oooool2o`0000_ooooo0_l0002Qooooo`00[?ooool00ol0003oooooooooo`09ooooo`;o0000
2oooool2o`000:7ooooo002Rooooo`;o00002?ooool00ol0003oooooooooo`0Oooooo`;o00002Ooo
ool2o`0008gooooo002@ooooo`;o00002?ooool2o`0000Kooooo0_l00008ooooo`03o`000?oooooo
oooo01oooooo0_l00008ooooo`?o0000SOooool0093ooooo0_l00008ooooo`;o00004?ooool3o`00
01Sooooo0_l0000?ooooo`;o0000S_ooool0087ooooo0_l0000:ooooo`;o00007Oooool00ol0003o
ooooooooo`03ooooo`;o00004oooool2o`0009oooooo0021ooooo`;o00002_ooool2o`0000?ooooo
0_l0000Hooooo`03o`000?oooooooooo00?ooooo0_l00002ooooo`;o0000/?ooool009;ooooo0_l0
000Hooooo`03o`000?oooooooooo00Oooooo0_l00009ooooo`;o0000YOooool00:Gooooo0_l00005
ooooo`03o`000?oooooooooo00Sooooo0_l00008ooooo`;o00006?ooool2o`0008_ooooo002?oooo
o`;o00005?ooool2o`0000Gooooo00?o0000ooooooooool01Oooool2o`000003ooooool0003o0000
02;ooooo0_l0002;ooooo`00Soooool2o`0001[ooooo0_l00007ooooo`;o0000/_ooool008gooooo
0_l00004ooooo`;o00005_ooool2o`0000?ooooo0_l0002fooooo`00SOooool2o`0000Cooooo0_l0
000Gooooo`04o`000?ooooooooooooooo`;o0000]_ooool00:cooooo0ol0000>ooooo`;o0000ZOoo
ool0083ooooo0_l0000?ooooo`;o00006Oooool00ol0003oooooooooo`0>ooooo`;o0000ZOooool0
083ooooo0_l000000ooooooo0000o`00000<ooooo`;o00006Oooool00ol0003oooooooooo`0?oooo
o`;o00002oooool2o`0009_ooooo0023ooooo`;o00009oooool00ol0003oooooooooo`0?ooooo`;o
00002oooool2o`0009_ooooo0029ooooo`;o00000oooool2o`0000Cooooo0_l0000Fooooo`03o`00
0?oooooooooo02Cooooo0_l0002Cooooo`00ROooool3o`000004oc8b<_o^k^ko0000o`0000?ooooo
00?o8B4Qo`000?l000000oooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo02Cooooo0_l00009ooooo`;o0000R?ooool008Wooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`03ob4Q8Ol0003o000000?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A007oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool03?ooool2o`00027ooooo0_l00028oooo
o`00POooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^
00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`;o00002?ooool2o`00
00Cooooo0_l0000Aooooo`;o00002oooool2o`0007_ooooo0029ooooo`05o`000?oooooooooooooo
ool000003?ooool2o`000003ob4Q8Oo^k^kooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`00
01Kooooo0_l00004ooooo`;o00001_ooool2o`0000Wooooo0ol0000:ooooo`;o0000Noooool008Wo
oooo00Go0000ooooooooooooooooo`00000<ooooo`;o000000?oMgMgofIVI_ooool00oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool07Oooool2o`0000Gooooo0_l0000:
ooooo`;o0000Qoooool008Wooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Mooooo`;o0000;?ooool2
o`0006cooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonH
V9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1;ooooo`;o0000K?oo
ool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
1?ooool4o`0000Kooooo00?o0000ooooooooool04_ooool2o`0000?ooooo0_l0000booooo`;o0000
K?ooool00:cooooo00?o0000ooooooooool04_ooool2o`0000?ooooo0_l0002Pooooo`00Zoooool2
o`000;_ooooo002Gooooo`;o00004?ooool4o`0000?ooooo0_l0002fooooo`00Poooool2o`0001;o
oooo0_l0000@ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`000;Kooooo0023ooooo`;o
00009oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o0000
/oooool008Sooooo0_l0000Rooooo`03o`000?oooooooooo00Cooooo0_l0000hooooo`;o0000NOoo
ool008Sooooo0_l0000Rooooo`;o00006_ooool2o`0002?ooooo0_l0001iooooo`00[?ooool2o`00
01[ooooo0_l00005ooooo`;o0000Uoooool00:cooooo00?o0000ooooooooool08?ooool2o`0001ko
oooo0_l0001gooooo`00Ooooool2o`0000kooooo0_l0000Kooooo`03o`000?oooooooooo01Cooooo
0_l0000Zooooo`;o0000Moooool007oooooo0_l0000>ooooo`;o00006oooool3o`0000oooooo0_l0
0003ooooo`;o0000Xoooool00:cooooo00?o0000ooooooooool03oooool2o`0000Wooooo0_l0000T
ooooo`;o0000Moooool00:cooooo00?o0000ooooooooool06_ooool2o`0001Kooooo0ol0000;oooo
o`;o0000Moooool00:cooooo00?o0000ooooooooool03?ooool2o`0002Cooooo0ol00024ooooo`00
[?ooool00ol0003oooooooooo`0<ooooo`;o0000<oooool2o`0007Kooooo002/ooooo`03o`000?oo
oooooooo013ooooo0_l0000^ooooo`?o0000M_ooool009Gooooo0_l0000Eooooo`03o`000?oooooo
oooo013ooooo0_l0000^ooooo`?o0000M_ooool007oooooo0_l0000Dooooo`;o00005Oooool00ol0
003oooooooooo`08ooooo`;o00004?ooool2o`0002Gooooo0_l0001fooooo`00Ooooool2o`0002_o
oooo00?o0000ooooooooool00oooool2o`0000?ooooo0_l0000@ooooo`;o0000WOooool00:cooooo
0ol00003ooooo`;o000000?oooooo`000?l000003_ooool2o`000:7ooooo002/ooooo`03o`000?oo
oooooooo00?ooooo0_l000000ooooooo0000o`00000>ooooo`;o0000XOooool00:cooooo00?o0000
ooooooooool00oooool2o`0000Oooooo0_l0002[ooooo`002Oooool4o`000003oa0@4?oooooooooo
01Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04
ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Kooooo00?o0000
ooooooooool03?ooool2o`0000[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb
<S;ogMgM01Sooooo1?l000000ol@413oooooooooo`0Booooo`002oooool00ol0003oooooooooo`0H
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01ooo
ool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`0Eooooo`04o`000?oooooo0000
o`0001Oooooo00?oMgMgoiRHV?ooool00_l00005ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Oooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B48ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo01Wooooo00?o0000oooooooo
ool05?ooool000Ko00001Oooool00ol0003oooooooooo`0@ooooo`Ko00000_ooool01Ol@413ooooo
oooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`05ooooo`Ko
00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool01Oooool6o`00
00;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000
ooooooooool05?ooool01?l0003oooooo`000?l0000Gooooo`03oa0@4?oooooooooo00;o00003?oo
ool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo410@oooo
o`02ooooo`03oa0@4?oooooooooo00Gooooo0_l00007ooooo`03o`000?oooooooooo00gooooo00Go
410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05o`000?oo
ooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00kooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000oooooooo
ooooooooo`000002ooooo`;o00002Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo
01Gooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`0;ooooo`;o000000?oooooo`000?ooool00_ooool0
0ol0003oooooooooo`05ooooo`;o00001_ooool00omgMgOo<S8booooo`0>ooooo`05o`000?oooooo
ooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Wooooo00?o
0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooo
oooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo
00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0
003ooooooooooooooooo000000;ooooo0_l0000:ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c00Fooooo`03o`000?oooooooooo01Sooooo00Go0000oooooooooooooooo
o`000005ooooo`;o00001oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`03oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?
ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`06_ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003ooooooooo
o`0Hooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo017o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo0ol0000Hoooo
o`?o00005_ooool2o`000005oa0@4?ooooooooooooooool@41001Oooool2o`0000Oooooo0_l00004
ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oo
oooooooo017ooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003ooooooooo
o`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Co
oooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Co0000okZj^_ooooooV9RH0_l0
0003ooooo`?o00006?ooool00ol0003oooooooooo`0Fooooo`;o000000GoMgMgoiRHV?ooooooV9RH
ogMgM`06ooooo`;o00000oooool00ol0003o^[Zjooooo`02o`0000Cooooo00?o0000ooooooooool0
4Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool05?ooool000Wooooo00?oEEEEofIVI_l000006_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01?nHV9So410@
o`000?lQ8B42o`0000?ooooo1?l0000Gooooo`03o`000?oooooooooo017ooooo0_l00005ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01_ooool2o`0000?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004
ooooo`Ko00003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000Iooooo`03oeEEEOmVIVKo000001Kooooo
0027ooooo`;o00008oooool00ol0003oooooooooo`09ooooo`;o00001_ooool2o`0000?ooooo0_l0
000Looooo`?o0000P_ooool008Oooooo0_l000000ooooooo0000o`00000Pooooo`03o`000?oooooo
oooo00Wooooo0_l0000;ooooo`;o00002oooool3o`0009?ooooo0022ooooo`;o00001_ooool2o`00
023ooooo00?o0000ooooooooool08oooool3o`0008Sooooo0_l00002ooooo`;o00001Oooool008;o
oooo0_l0000Xooooo`03o`000?oooooooooo02Cooooo0_l00028ooooo`06onk^k_lQ8B7oQhN7okZj
^_l0003ogMgM1Oooool009;ooooo0_l0000Hooooo`03o`000?oooooooooo0:oooooo00CogMgMo`00
0?l@413oc<c<1_ooool000Ooooooool0001<o`0000cooooo00Cok^k^ob4Q8Ol@413ok^k^1_ooool0
00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00Co0000ooooool0003o00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`04ob4Q8OmgMgOo
MgMgoc8b<PKooooo0007ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00;ooooo0_l0000Rooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool05oooool2o`0000gooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Wooooo0_l00002ooooo`;o00001Oooool0
08Sooooo0_l0000Rooooo`03o`000?oooooooooo017ooooo0_l0000Sooooo`;o00002Oooool2o`00
07Kooooo002/ooooo`03o`000?oooooooooo00Oooooo0_l00008ooooo`;o00000oooool2o`0001ko
oooo0_l00021ooooo`00[?ooool00ol0003oooooooooo`07ooooo`;o00003Oooool2o`0000_ooooo
0_l00006ooooo`;o0000S?ooool008;ooooo0_l0000Xooooo`03o`000?oooooooooo02?ooooo0_l0
0006ooooo`;o0000S?ooool008;ooooo0_l00004ooooo`;o00003_ooool2o`0001;ooooo00?o0000
ooooooooool0^Oooool008Sooooo0_l0000>ooooo`;o00004_ooool3o`0000gooooo0_l0002Zoooo
o`00T?ooool2o`0001[ooooo00?o0000ooooooooool03Oooool2o`000:[ooooo0022ooooo`;o0000
3?ooool2o`0001[ooooo00?o0000ooooooooool01oooool2o`0001[ooooo0_l0000@ooooo`;o0000
P_ooool008;ooooo0_l0000Xooooo`03o`000?oooooooooo00Kooooo0ol0000Jooooo`;o00004?oo
ool2o`0008;ooooo002/ooooo`03o`000?oooooooooo00Kooooo0_l0000^ooooo`;o0000POooool0
08kooooo0_l0000Looooo`03o`000?oooooooooo03Kooooo0_l0000:ooooo`;o0000MOooool008ko
oooo0_l0000Looooo`03o`000?oooooooooo03Kooooo0_l0000:ooooo`;o0000MOooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool08_ooool2o`0000Oooooo0_l0
002<ooooo`00[?ooool3o`0002;ooooo0_l00007ooooo`?o0000Roooool008;ooooo0_l0000Xoooo
o`04o`000?ooooooooooooooo`;o0000:Oooool2o`0000Sooooo0_l0000:ooooo`;o0000MOooool0
08;ooooo0_l0000=ooooo`;o00006Oooool01?l0003oooooooooooooool2o`0003?ooooo0_l0000:
ooooo`;o0000MOooool0097ooooo0_l0000Iooooo`03o`000?oooooooooo00?ooooo0_l0000loooo
o`Co0000M?ooool00:cooooo00?o0000ooooooooool00oooool2o`0002Kooooo0_l0000Dooooo`Co
0000M?ooool008oooooo0_l0000Kooooo`03o`000?oooooooooo00?ooooo0_l000000ooooooo0000
o`000008ooooo`;o00006Oooool2o`0008cooooo002?ooooo`;o00006oooool00ol0003ooooooooo
o`03ooooo`;o000000?oooooo`000?l000002?ooool2o`00033ooooo0_l0001eooooo`00[?ooool0
0ol0003oooooooooo`08ooooo`;o00006?ooool2o`0001kooooo0_l0001eooooo`00SOooool2o`00
01gooooo0ol00008ooooo`;o00002oooool2o`0000_ooooo0_l0002Eooooo`00R?ooool2o`0000?o
oooo0_l0000Mooooo`03o`000?oooooooooo01Gooooo0_l00004ooooo`;o00005_ooool2o`0000go
oooo0_l0001eooooo`00R?ooool2o`0002;ooooo00?o0000ooooooooool06oooool2o`0001Kooooo
0_l0000=ooooo`;o0000MOooool00:cooooo00?o0000ooooooooool08?ooool2o`0009Oooooo002/
ooooo`03o`000?oooooooooo023ooooo0_l0002Gooooo`00UOooool2o`0001Gooooo00?o0000oooo
ooooool08?ooool2o`0000Oooooo0_l0002>ooooo`00UOooool2o`0001Gooooo00?o0000oooooooo
ool03oooool2o`0000oooooo0_l00007ooooo`?o0000SOooool0097ooooo0_l0000Iooooo`03o`00
0?oooooooooo00oooooo0_l0000Iooooo`;o0000SOooool0097ooooo0_l0000Iooooo`Co0000^?oo
ool00:cooooo00?o0000ooooool000000ol0000@ooooo`;o0000Y?ooool0093ooooo0_l0000Joooo
o`04o`000?ooooooooooooooo`;o00004?ooool2o`000:Cooooo002@ooooo`;o00006_ooool00ol0
003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0=ooooo`?o0000ZOooool00:cooooo
00?o0000ooooooooool03Oooool3o`00013ooooo0_l0000?ooooo`?o0000QOooool008Wooooo0ol0
00000olb<S;ok^k^ooooo`04ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8b
omgMg@05ooooo`03o`000?oooooooooo00Wooooo0_l0000=ooooo`;o00001_ooool2o`0000oooooo
0ol00025ooooo`00ROooool2o`000003oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00Wooooo
0_l00002ooooo`;o00002Oooool2o`0002Gooooo0_l0001hooooo`00ROooool01Ol@413ooooooooo
oooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h00_ooool2o`0000Gooooo00?o0000ooooooooool0
0oooool3o`0000gooooo0_l0000`ooooo`;o0000N?ooool008Wooooo00Go0000oooooooooooooooo
o`00000=ooooo`04oiRHV?lQ8B7ok^k^ooooo`;o00001?ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo00Sooooo0ol0000dooooo`;o0000N?ooool008Wooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005oooo
o`;o00002Oooool3o`0001;ooooo0_l0000Pooooo`;o0000N?ooool008Wooooo00?o410@oooooooo
ool00_l0000?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool2o`0001ko
oooo0_l0000Cooooo`;o0000QOooool008Oooooo0_l000000omgMgOoV9RHooooo`04o`0000Wooooo
00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0<_ooool2o`0000[ooooo0_l0000=ooooo`;o0000J_ooool008Oooooo0_l000001Oo^k^ko<S8b
o`000?lb<S;ok^k^00;o00002Oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006oooo
o`03o`000?oooooooooo03kooooo0_l0000=ooooo`;o0000J_ooool0097ooooo0_l0000Iooooo`03
o`000?oooooooooo04gooooo0_l0001Zooooo`00TOooool2o`0001Wooooo00?o0000ooooooooool0
0_l0001;ooooo`;o0000J_ooool0087ooooo0_l0000Yooooo`03o`000?oooooooooo00;o0000;_oo
ool2o`0008Oooooo0021ooooo`;o0000:Oooool3o`00033ooooo0_l00027ooooo`00[?ooool00ol0
003oooooooooo`0>ooooo`;o00003Oooool2o`0009[ooooo002/ooooo`03o`000?oooooooooo00ko
oooo0_l0000=ooooo`;o0000;Oooool2o`0006_ooooo001mooooo`;o00002Oooool2o`0000oooooo
0_l0000Aooooo`04o`000?oooooo0000o`0004_ooooo0_l0001[ooooo`00OOooool2o`0000;ooooo
0_l00005ooooo`;o00003oooool2o`00017ooooo00Co0000ooooool0003o00006_ooool2o`0000Oo
oooo0_l0002Cooooo`00POooool2o`0002Wooooo00?o0000ooooooooool04oooool2o`0000Kooooo
0_l00007ooooo`;o0000Toooool0087ooooo0_l0000Yooooo`03o`000?oooooooooo01?ooooo0_l0
000Uooooo`;o00003oooool2o`0006cooooo0021ooooo`;o00000_ooool2o`00013ooooo0_l0000:
ooooo`;o00001oooool00ol0003oooooooooo`0>ooooo`;o0000:_ooool2o`0000oooooo0_l0001/
ooooo`00QOooool2o`00013ooooo0_l0000:ooooo`;o00001oooool5o`0000cooooo0_l00003oooo
o`;o0000Y?ooool00:cooooo00?o0000ooooooooool00_l0000Aooooo`;o00003Oooool2o`0000So
oooo0_l0002;ooooo`00V?ooool2o`0001;ooooo00?o0000ooooooooool08_ooool2o`0000Sooooo
0_l0000<ooooo`;o0000OOooool009Sooooo0_l0000Booooo`03o`000?oooooooooo01?ooooo0_l0
000Gooooo`;o00003?ooool2o`0007gooooo0025ooooo`;o00009Oooool00ol0003oooooooooo`0C
ooooo`;o00005oooool2o`0008_ooooo0025ooooo`;o00006_ooool2o`0000Wooooo00?o0000oooo
ooooool00_ooool2o`0000gooooo0_l0002Vooooo`00XOooool2o`000003ooooool0003o000000Ko
oooo00?o0000ooooooooool00_ooool2o`0000Oooooo0_l00004ooooo`;o00003Oooool2o`0009Oo
oooo002Tooooo`;o00001_ooool00ol0003oooooooooo`0;ooooo`;o00004oooool2o`0000Sooooo
0_l0000=ooooo`;o0000O_ooool00:cooooo0ol0000Oooooo`;o00002Oooool2o`0000gooooo0_l0
001nooooo`00P_ooool2o`0001[ooooo0_l00009ooooo`;o000000?oooooo`000?l000008?ooool2
o`0009Sooooo0022ooooo`;o00006_ooool2o`0000Wooooo0_l000000ooooooo0000ooooo`2joooo
o`00[?ooool00ol0003oooooooooo`0>ooooo`;o0000=_ooool2o`00077ooooo002Vooooo`;o0000
1?ooool00ol0003oooooooooo`0>ooooo`;o0000=_ooool2o`00077ooooo002@ooooo`;o000000?o
ooooo`000?l000004Oooool2o`0000Cooooo00?o0000ooooooooool03_ooool2o`000:Wooooo002@
ooooo`;o000000?oooooo`000?l000005oooool00ol0003oooooooooo`0>ooooo`;o0000ZOooool0
08;ooooo0_l0000Xooooo`03o`000?oooooooooo00Oooooo0_l0000Dooooo`;o0000V_ooool008;o
oooo0_l0000Fooooo`;o00004?ooool3o`0000Oooooo0_l0000Dooooo`;o0000V_ooool008Oooooo
0_l000000ooooooo0000o`00000>ooooo`;o00004?ooool00ol0003oooooooooo`2iooooo`00Qooo
ool2o`000003ooooool0003o0000023ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o0000
1?ooool2o`0000oooooo0_l0002Kooooo`00Qoooool2o`0002?ooooo00Co0000oooooooooooooooo
0_l00002ooooo`;o00001?ooool2o`0000Gooooo0_l00008ooooo`;o0000Voooool00:cooooo00?o
0000ooooooooool04_ooool2o`0002kooooo0_l0001eooooo`00Qoooool2o`0002?ooooo00?o0000
ooooooooool04_ooool2o`0000Kooooo0_l0000:ooooo`;o00006_ooool2o`0007Gooooo0027oooo
o`;o00000_ooool2o`0000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00Co0000ooooool0003o00006Oooool2o`0000[ooooo
0_l0002Aooooo`00Roooool2o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
0_l00006ooooo`03ogMgMolb<S;ooooo00Cooooo00Co0000ooooool0003o0000<?ooool2o`0008Ko
oooo002Aooooo`05oa0@4?ooooooooooooooool@41001oooool2o`0000Oooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0aooooo`;o0000Q_ooool008Cooooo0_l0000;ooooo`05o`00
0?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`?o00006Oooool2o`0001Ko
oooo0_l00026ooooo`00Q?ooool2o`0000_ooooo00Go0000ooooooooooooooooo`00000<ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`08ooooo`;o00003oooool2o`00
01Kooooo0_l00026ooooo`00TOooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`08ooooo`;o0000[oooool0097ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0^Oooool0097o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`2ioooo
o`00S?ooool2o`0001_ooooo0_l000000ooooooo0000ooooo`0^ooooo`;o0000R_ooool008cooooo
0_l0000Kooooo`;o000000?oooooo`000?ooool03_ooool2o`0000Kooooo0_l0000Fooooo`;o0000
R_ooool00:Wooooo0_l000000ooooooo0000ooooo`02o`0000cooooo0_l00006ooooo`;o00005ooo
ool2o`0008Wooooo002/ooooo`Co00007Oooool2o`0000kooooo0_l00029ooooo`00UOooool2o`00
00Oooooo0_l0000<ooooo`03o`000?oooooooooo01kooooo0_l0002Iooooo`00T_ooool2o`000003
ooooool0003o000000Oooooo0_l00005ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`;o
0000O?ooool009;ooooo0_l0000?ooooo`Co00001Oooool00ol0003oooooooooo`0kooooo`;o0000
O?ooool008kooooo0_l00006ooooo`;o00002oooool2o`0000Oooooo00?o0000ooooooooool0^Ooo
ool0087ooooo0_l00007ooooo`;o00000_ooool2o`0000Kooooo0_l0000Dooooo`03o`000?oooooo
oooo017ooooo0_l0002Vooooo`00POooool3o`0000Kooooo0_l0000Pooooo`03o`000?oooooooooo
00Wooooo0_l00006ooooo`?o0000YOooool008;ooooo0_l0000;ooooo`;o00003Oooool2o`0000co
oooo00?o0000ooooooooool02Oooool2o`0000Oooooo0_l0002Uooooo`00Soooool2o`0000gooooo
0_l0000<ooooo`?o00007?ooool2o`0001_ooooo0_l0001nooooo`00U?ooool2o`00017ooooo0_l0
0003ooooo`03o`000?oooooooooo013ooooo0_l0000:ooooo`;o00002Oooool2o`00013ooooo0_l0
001nooooo`00U?ooool2o`00017ooooo0_l00003ooooo`03o`000?oooooooooo013ooooo0_l00007
ooooo`;o00002oooool3o`00093ooooo002/ooooo`03o`000?oooooooooo01Wooooo0_l0000;oooo
o`;o0000TOooool00:7ooooo0_l00009ooooo`03o`000?oooooooooo0;Wooooo002@ooooo`;o0000
3oooool2o`0000Wooooo00?o0000ooooooooool09_ooool2o`00097ooooo002@ooooo`;o00002Ooo
ool2o`0000oooooo00?o0000ooooooooool09_ooool2o`00097ooooo002Kooooo`;o00003oooool0
0ol0003oooooooooo`0<ooooo`;o00005oooool2o`0009;ooooo002/ooooo`?o00003?ooool2o`00
01Oooooo0_l0002Booooo`00[?ooool00ol0003oooooooooo`0Dooooo`;o0000Xoooool008gooooo
0_l0000Mooooo`03o`000?oooooooooo01Cooooo0ol0002Rooooo`00SOooool2o`0001gooooo00?o
0000ooooooooool05Oooool2o`000:;ooooo002Uooooo`Go00000_ooool00ol0003oooooooooo`09
ooooo`;o0000[_ooool00:Gooooo1Ol00002ooooo`03o`000?oooooooooo00Wooooo0_l0002^oooo
o`00[?ooool00ol0003oooooooooo`0_ooooo`;o0000R?ooool00:cooooo00?o0000ooooooooool0
1oooool2o`0002Kooooo0_l00028ooooo`00[?ooool00ol0003oooooooooo`07ooooo`;o0000/?oo
ool008oooooo0_l0000Kooooo`?o00001?ooool2o`000;?ooooo002?ooooo`;o00006oooool00ol0
003oooooooooo`04ooooo`;o00002_ooool2o`000:Oooooo002/ooooo`03o`000?oooooooooo013o
oooo0_l0000:ooooo`;o0000Voooool00:[ooooo0ol0000@ooooo`;o00002oooool3o`0009_ooooo
002Zooooo`?o00004?ooool2o`0000_ooooo0_l0002Looooo`00ROooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8b
omgMg@05ooooo`03o`000?oooooooooo00?ooooo0_l0002dooooo`00ROooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B400ooooooo0000o`000003ooooo`03oeEEEOnYZJWooooo00?ooooo
1?l000000omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00?ooooo0_l0000Fooooo`;o0000
W?ooool008Wooooo00Go410@oooooooooooooooooa0@4008ooooo`;o00000oooool00onYZJWoEEEE
ooooo`03ooooo`;o00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo
0_l0002Looooo`00ROooool00ol0003oooooooooo`02o`0000kooooo00?o8B4Qooooooooool01_oo
ool00omgMgOo<S8booooo`04ooooo`?o0000^Oooool008Wooooo00?o0000ooooooooool00_l0000>
ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oo
oooooooo0;Wooooo0029ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgoooo
o`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0^Oooool008Wooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo00Kooooo0ol0002`ooooo`00WOooool2o`0000gooooo00?o0000ooooooooool01_ooool3
o`0001[ooooo0_l0002Dooooo`00WOooool2o`0000gooooo00?o0000ooooooooool08oooool2o`00
09Cooooo002/ooooo`?o00004oooool2o`000:Cooooo002/ooooo`03o`000?oooooooooo00?ooooo
0_l0000>ooooo`;o0000Y?ooool008oooooo0_l0000Kooooo`03o`000?oooooooooo00?ooooo0_l0
002dooooo`00Soooool2o`0001_ooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool008[ooooo0_l0000Pooooo`03o`000?oooooooooo00oooooo0_l0002Xooooo`00
R_ooool2o`0000Cooooo0_l00005ooooo`;o00004oooool00ol0003oooooooooo`0?ooooo`;o0000
Z?ooool0093ooooo0_l00005ooooo`;o00004oooool00ol0003oooooooooo`2iooooo`00[?ooool4
o`000;Sooooo002Jooooo`;o00004?ooool4o`0000_ooooo0_l0002[ooooo`00T_ooool2o`0000Ko
oooo0_l0000@ooooo`?o00003?ooool2o`000:_ooooo002Booooo`;o00006?ooool00ol0003ooooo
ooooo`0Iooooo`;o0000W_ooool00:cooooo00?o0000ooooooooool02Oooool2o`0000kooooo0_l0
002Nooooo`00ZOooool2o`000003ooooool0003ooooo00[ooooo0_l0000=ooooo`;o0000Woooool0
09gooooo0_l00008ooooo`Co000000?oooooo`000?ooool06Oooool2o`0009oooooo002Mooooo`;o
000000?oooooo`000?l000001Oooool2o`0000?ooooo00?o0000ooooooooool0^Oooool008gooooo
0_l00006ooooo`;o00002Oooool2o`0000[ooooo00?o0000ooooooooool0^Oooool008gooooo0_l0
0006ooooo`;o00005Oooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo00;o0000]oooool00:cooooo00?o0000ooooooooool00_l0002gooooo`00VOooool2
o`00017ooooo00Co0000ooooool0003o0000^?ooool009Wooooo0_l0000Aooooo`04o`000?oooooo
0000o`000;Sooooo002/ooooo`?o0000^Oooool009[ooooo0ol0000?ooooo`03o`000?oooooooooo
0;Wooooo002Jooooo`?o00000_ooool2o`0000_ooooo00?o0000ooooooooool0^Oooool009oooooo
1?l00004ooooo`;o00000oooool00ol0003oooooooooo`2iooooo`00XOooool2o`0000?ooooo0ol0
0003ooooo`03o`000?oooooooooo0;Wooooo002Pooooo`Go000000Coooooo`000?l0003o00000ooo
ool00ol0003oooooooooo`2iooooo`00X?ooool6o`000003oa0@4?l0003o000000?ooooo00?o0000
ooooooooool0^Oooool00:Cooooo0_l00006ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`03
o`000?oooooooooo00Gooooo0ol0002iooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?oo
ool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0
003oooooooooo`31ooooo`00X_ooool00omEEEGoIVIVo`000033ooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00Z_ooool01?l@413o0000o`000?l0002joooo
o`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zooo
ool01_l0003oMgMgo`000?l0003oEEEEonk^k[Oooooo002[ooooo`06o`000?mEEEGok^k^oooooomg
MgOoEEEE]oooool00:_ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`2eooooo`00
Zoooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo0;Gooooo002[ooooo`06o`000?mE
EEGok^k^oooooomgMgOoIVIV]oooool00:[ooooo00?o410@o`000?mgMgL00_l000000omVIVKok^k^
ooooo`2fooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.64435 .46237 Mdot
.5465 .83141 Mdot
.50491 .5333 Mdot
.54605 .42656 Mdot
.45342 .80203 Mdot
.40857 .25619 Mdot
.51737 .51489 Mdot
.67816 .72753 Mdot
.68508 .33926 Mdot
.5568 .41152 Mdot
.51845 .72438 Mdot
.6299 .8159 Mdot
.47783 .0734 Mdot
.55106 .63419 Mdot
.6301 .80724 Mdot
.45158 .74281 Mdot
.50597 .17357 Mdot
.49796 .08482 Mdot
.56411 .37488 Mdot
.60917 .78507 Mdot
.48354 .07823 Mdot
.43098 .86347 Mdot
.40189 .75051 Mdot
.5248 .11835 Mdot
.48673 .99133 Mdot
.60048 .48375 Mdot
.44946 .76251 Mdot
.5424 .31272 Mdot
.57511 .84018 Mdot
.54343 .83358 Mdot
.52254 .12203 Mdot
.69185 .35357 Mdot
.70985 .61407 Mdot
.60269 .38606 Mdot
.59825 .66084 Mdot
.673 .57597 Mdot
.39324 .22097 Mdot
.45681 .21703 Mdot
.54776 .87466 Mdot
.59473 .87247 Mdot
.45978 .99374 Mdot
.61931 .53561 Mdot
.47266 .87541 Mdot
.64771 .55276 Mdot
.63445 .39242 Mdot
.46085 .18015 Mdot
.56369 .54347 Mdot
.64152 .23618 Mdot
.48886 .84035 Mdot
.60134 .79206 Mdot
.6301 .21796 Mdot
.43485 .91793 Mdot
.56475 .96599 Mdot
.5538 .76666 Mdot
.51833 .83208 Mdot
.71529 .47031 Mdot
.67299 .73711 Mdot
.51071 .17906 Mdot
.54132 .09448 Mdot
.62274 .35071 Mdot
.48717 .17856 Mdot
.55854 .06235 Mdot
.54495 .87682 Mdot
.52155 .65165 Mdot
.71269 .56521 Mdot
.70968 .42103 Mdot
.54555 .36629 Mdot
.50012 .73401 Mdot
.47964 .20326 Mdot
.55898 .16577 Mdot
.57482 .29079 Mdot
.44751 .35893 Mdot
.55601 .41268 Mdot
.49367 .24034 Mdot
.54565 .87581 Mdot
.44996 .40555 Mdot
.56418 .96659 Mdot
.53787 .2649 Mdot
.47463 .95381 Mdot
.56355 .69157 Mdot
.64235 .32959 Mdot
.55933 .80661 Mdot
.51906 .32529 Mdot
.61695 .5706 Mdot
.71092 .62107 Mdot
.42221 .62952 Mdot
.4361 .76623 Mdot
.40908 .61588 Mdot
.47202 .14515 Mdot
.49351 .74593 Mdot
.48138 .99265 Mdot
.76041 .58024 Mdot
.42459 .59785 Mdot
.41178 .34488 Mdot
.45498 .72543 Mdot
.76552 .53711 Mdot
.55643 .61043 Mdot
.62212 .20889 Mdot
.53559 .99781 Mdot
.49868 .15789 Mdot
.64625 .52167 Mdot
.41843 .25248 Mdot
.64012 .79516 Mdot
.64052 .60258 Mdot
.6244 .28048 Mdot
.61189 .43035 Mdot
.58985 .33122 Mdot
.581 .4736 Mdot
.42303 .5808 Mdot
.55863 .16653 Mdot
.56639 .53069 Mdot
.54562 .41907 Mdot
.68604 .33797 Mdot
.66134 .65297 Mdot
.40097 .05329 Mdot
.50319 .33028 Mdot
.51921 .22662 Mdot
.72134 .49629 Mdot
.71446 .4371 Mdot
.37568 .3989 Mdot
.46859 .07529 Mdot
.39781 .26777 Mdot
.55965 .86422 Mdot
.56323 .17251 Mdot
.55178 .4916 Mdot
.64882 .69009 Mdot
.76208 .45692 Mdot
.62466 .6526 Mdot
.52673 .58022 Mdot
.39461 .70624 Mdot
.6395 .59144 Mdot
.5912 .87338 Mdot
.43427 .15824 Mdot
.41417 .76312 Mdot
.50374 .93619 Mdot
.38665 .25874 Mdot
.61334 .77287 Mdot
.55157 .39242 Mdot
.69739 .65962 Mdot
.61577 .83248 Mdot
.6516 .18434 Mdot
.48037 .25019 Mdot
.52709 .27434 Mdot
.50997 .17919 Mdot
.63752 .72489 Mdot
.71872 .57188 Mdot
.55969 .00657 Mdot
.57632 .45508 Mdot
.40422 .46266 Mdot
.44689 .0032 Mdot
.40613 .32601 Mdot
.41794 .35131 Mdot
.53875 .13553 Mdot
.43596 .43575 Mdot
.49123 .1216 Mdot
.37322 .55552 Mdot
.50824 .92601 Mdot
.71916 .48236 Mdot
.38917 .24885 Mdot
.3723 .48283 Mdot
.58338 .64231 Mdot
.46508 .95309 Mdot
.44263 .98212 Mdot
.67478 .47882 Mdot
.49788 .85754 Mdot
.64364 .47734 Mdot
.72006 .55166 Mdot
.64788 .33615 Mdot
.46005 .21134 Mdot
.37201 .46979 Mdot
.64131 .70277 Mdot
.42376 .57717 Mdot
.41642 .37065 Mdot
.44879 .79261 Mdot
.57952 .53133 Mdot
.70936 .60591 Mdot
.76557 .51003 Mdot
.47424 .11575 Mdot
.47031 .29532 Mdot
.56911 .84686 Mdot
.38239 .70019 Mdot
.55295 .92611 Mdot
.43678 .28918 Mdot
.43758 .97043 Mdot
.44238 .66485 Mdot
.6712 .30671 Mdot
.75881 .44091 Mdot
.69574 .35914 Mdot
.43144 .82431 Mdot
.41128 .07924 Mdot
.63664 .72765 Mdot
.5423 .50026 Mdot
.50901 .01251 Mdot
.69886 .66832 Mdot
.36969 .68127 Mdot
.61957 .83069 Mdot
.40344 .48287 Mdot
.73549 .69465 Mdot
.61983 .45544 Mdot
.43043 .52671 Mdot
.43016 .47723 Mdot
.46433 .31786 Mdot
.48542 .81009 Mdot
.71767 .73875 Mdot
.64438 .53946 Mdot
.47472 .27379 Mdot
.43835 .15142 Mdot
.54816 .42822 Mdot
.43539 .35836 Mdot
.49766 .76896 Mdot
.39449 .27801 Mdot
.52859 .24603 Mdot
.64877 .33908 Mdot
.41534 .4883 Mdot
.64426 .49282 Mdot
.49511 .19008 Mdot
.43793 .97489 Mdot
.42927 .59028 Mdot
.58991 .27436 Mdot
.61847 .83846 Mdot
.51087 .21179 Mdot
.54055 .09632 Mdot
.63848 .31031 Mdot
.65701 .37748 Mdot
.44147 .71497 Mdot
.53514 .72343 Mdot
.56392 .80532 Mdot
.42421 .58673 Mdot
.62578 .8149 Mdot
.51345 .01291 Mdot
.50792 .71961 Mdot
.43826 .5078 Mdot
.71818 .73275 Mdot
.42472 .76278 Mdot
.44259 .74948 Mdot
.43783 .01943 Mdot
.43473 .26797 Mdot
.63118 .64522 Mdot
.40504 .22132 Mdot
.64271 .56989 Mdot
.55351 .05765 Mdot
.38936 .50248 Mdot
.67362 .432 Mdot
.57336 .28757 Mdot
.70067 .37747 Mdot
.48581 .73452 Mdot
.38781 .73329 Mdot
.40155 .38877 Mdot
.56881 .27741 Mdot
.53315 .8938 Mdot
.38139 .77892 Mdot
.4962 .31242 Mdot
.54057 .47468 Mdot
.37605 .60459 Mdot
.59849 .47595 Mdot
.41129 .44045 Mdot
.46222 .87588 Mdot
.4622 .36348 Mdot
.68668 .6997 Mdot
.60216 .17328 Mdot
.45183 .83047 Mdot
.44349 .75182 Mdot
.66643 .4163 Mdot
.53071 .46078 Mdot
.3978 .43565 Mdot
.63114 .39074 Mdot
.5602 .57187 Mdot
.39428 .61087 Mdot
.66345 .62818 Mdot
.59661 .55344 Mdot
.66513 .63048 Mdot
.49006 .87148 Mdot
.5591 .42031 Mdot
.51958 .79005 Mdot
.37356 .57044 Mdot
.45732 .2383 Mdot
.56462 .6427 Mdot
.64453 .24391 Mdot
.50315 .7599 Mdot
.47847 .1143 Mdot
.53682 .89297 Mdot
.50445 .67694 Mdot
.43968 .28304 Mdot
.38616 .27244 Mdot
.65472 .7689 Mdot
.58223 .49474 Mdot
.45404 .65545 Mdot
.55752 .65451 Mdot
.67436 .59959 Mdot
.41683 .31153 Mdot
.62158 .28086 Mdot
.75745 .43584 Mdot
.50893 .05919 Mdot
.65507 .76235 Mdot
.49994 .05129 Mdot
.49625 .35702 Mdot
.50081 .04767 Mdot
.44995 .00715 Mdot
.6813 .5395 Mdot
.64095 .78817 Mdot
.62875 .07844 Mdot
.53694 .75882 Mdot
.40208 .70115 Mdot
.63474 .62055 Mdot
.6977 .36943 Mdot
.49223 .98962 Mdot
.55734 .59705 Mdot
.63508 .22856 Mdot
.5998 .51393 Mdot
.47148 .69675 Mdot
.38622 .36029 Mdot
.53251 .21505 Mdot
.43924 .10781 Mdot
.41527 .06447 Mdot
.51377 .3655 Mdot
.60679 .31376 Mdot
.6165 .46212 Mdot
.70785 .60147 Mdot
.53334 .5061 Mdot
.5462 .93358 Mdot
.36463 .41313 Mdot
.70193 .26564 Mdot
.53971 .61906 Mdot
.45027 .12698 Mdot
.61435 .59348 Mdot
.50049 .93372 Mdot
.51904 .7601 Mdot
.43217 .56717 Mdot
.51226 .42986 Mdot
.57263 .28911 Mdot
.64441 .7957 Mdot
.3841 .69915 Mdot
.456 .7279 Mdot
.38254 .56792 Mdot
.51805 .62636 Mdot
.4663 .31595 Mdot
.55727 .81616 Mdot
.39963 .31546 Mdot
.49452 .86176 Mdot
.58394 .63943 Mdot
.50646 .78017 Mdot
.60474 .92028 Mdot
.59837 .49216 Mdot
.59087 .74458 Mdot
.52362 .64242 Mdot
.71712 .54521 Mdot
.47092 .78437 Mdot
.62564 .74705 Mdot
.52362 .86018 Mdot
.43655 .31912 Mdot
.4301 .25201 Mdot
.65016 .18155 Mdot
.63231 .81326 Mdot
.50579 .05173 Mdot
.66867 .60717 Mdot
.55189 .7286 Mdot
.61256 .41546 Mdot
.64632 .69063 Mdot
.40097 .60963 Mdot
.63472 .80872 Mdot
.72043 .30065 Mdot
.67619 .44903 Mdot
.59892 .86182 Mdot
.53551 .94602 Mdot
.4254 .95014 Mdot
.50637 .36763 Mdot
.45608 .83386 Mdot
.61492 .83307 Mdot
.68142 .71557 Mdot
.51514 .40443 Mdot
.5966 .23115 Mdot
.5954 .46639 Mdot
.45533 .12301 Mdot
.64626 .50117 Mdot
.63955 .23906 Mdot
.63321 .63641 Mdot
.43567 .07216 Mdot
.43052 .90363 Mdot
.41592 .81464 Mdot
.47415 .03237 Mdot
.40791 .78374 Mdot
.53044 .94704 Mdot
.39172 .23592 Mdot
.52463 .1631 Mdot
.43619 .55585 Mdot
.37152 .68907 Mdot
.46377 .14783 Mdot
.50708 .40078 Mdot
.534 .94956 Mdot
.56527 .17502 Mdot
.4332 .58057 Mdot
.51454 .28139 Mdot
.58344 .38017 Mdot
.42523 .68483 Mdot
.65745 .26535 Mdot
.65648 .35442 Mdot
.54232 .93894 Mdot
.58193 .31652 Mdot
.64133 .86929 Mdot
.60162 .37307 Mdot
.58022 .52016 Mdot
.57098 .60987 Mdot
.48716 .6507 Mdot
.6569 .7708 Mdot
.63538 .80634 Mdot
.45535 .77229 Mdot
.42515 .39452 Mdot
.41599 .6303 Mdot
.41517 .4595 Mdot
.36898 .31933 Mdot
.40764 .3831 Mdot
.67613 .48414 Mdot
.49142 .2612 Mdot
.4206 .33311 Mdot
.53252 .5253 Mdot
.40654 .59454 Mdot
.59168 .34788 Mdot
.4113 .56767 Mdot
.4931 .28761 Mdot
.69868 .65617 Mdot
.44928 .45287 Mdot
.58637 .69666 Mdot
.58959 .3307 Mdot
.53146 .17655 Mdot
.59718 .50996 Mdot
.43116 .28048 Mdot
.36527 .60466 Mdot
.761 .59843 Mdot
.62443 .66533 Mdot
.35159 .47794 Mdot
.64313 .59436 Mdot
.52449 .37238 Mdot
.69027 .36015 Mdot
.60548 .84714 Mdot
.51127 .73896 Mdot
.52883 .85149 Mdot
.59484 .93191 Mdot
.43216 .34424 Mdot
.46118 .69114 Mdot
.57561 .57184 Mdot
.66695 .41529 Mdot
.57844 .647 Mdot
.74979 .64373 Mdot
.42553 .52743 Mdot
.58814 .68616 Mdot
.62029 .53474 Mdot
.4812 .74069 Mdot
.50322 .33338 Mdot
.48607 .23037 Mdot
.67802 .72714 Mdot
.53035 .44683 Mdot
.49497 .9449 Mdot
.57996 .77402 Mdot
.62554 .36415 Mdot
.65787 .66082 Mdot
.59482 .22971 Mdot
.56283 .27143 Mdot
.7655 .46926 Mdot
.52632 .30888 Mdot
.63842 .80642 Mdot
.3796 .76801 Mdot
.56038 .56718 Mdot
.50491 .05146 Mdot
.59733 .5313 Mdot
.45414 .16293 Mdot
.62799 .74253 Mdot
.64645 .53092 Mdot
.57063 .40397 Mdot
.43541 .23382 Mdot
.60443 .39052 Mdot
.57347 .07623 Mdot
.43125 .82094 Mdot
.44705 .42145 Mdot
.50991 .84118 Mdot
.55419 .71707 Mdot
.50479 .36046 Mdot
.53402 .63941 Mdot
.55934 .75621 Mdot
.4163 .77427 Mdot
.45307 .31856 Mdot
.59083 .41869 Mdot
.71065 .42665 Mdot
.45924 .80981 Mdot
.61888 .3485 Mdot
.51721 .25223 Mdot
.53002 .28621 Mdot
.52496 .52019 Mdot
.3873 .1053 Mdot
.52328 .54569 Mdot
.55203 .82363 Mdot
.53278 .08923 Mdot
.67628 .49782 Mdot
.49947 .22236 Mdot
.59654 .8032 Mdot
.58295 .88712 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool009[ooooo0_l00008ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0^Oooool009[ooooo0ol00007ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool04?ooool2o`000:Oooooo002Kooooo`;o00001oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo013ooooo0_l0002Wooooo`00Y?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00?o0000]_ooool00:;ooooo00?oEEEEofIVI_l000001oooool00ol0
003oooooooooo`03o`000;Kooooo002Gooooo`;o00004oooool00ol0003oooooooooo`2iooooo`00
Uoooool2o`0001?ooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00Xoooool2o`0000Oo
oooo00?o0000ooooooooool0^Oooool00:?ooooo0_l00007ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`;o0000^_ooool00:cooooo0ol0002iooooo`00Rooo
ool2o`0001oooooo0ol0002iooooo`00Roooool2o`0001oooooo00?o0000ooooooooool00_l0000<
ooooo`;o0000ZOooool00:cooooo00?o0000ooooooooool00_l0000<ooooo`;o0000ZOooool0093o
oooo0_l0000Jooooo`03o`000?oooooooooo013ooooo0_l0002Wooooo`00T?ooool2o`0001[ooooo
00?o0000ooooooooool04?ooool2o`000:Oooooo002/ooooo`03o`000?oooooooooo0;Wooooo002F
ooooo`;o00003?ooool2o`0000Kooooo00?o0000ooooooooool0^Oooool009Kooooo0_l00009oooo
o`;o000000?oooooo`000?l000001_ooool3o`0001Gooooo0_l0002Rooooo`00S_ooool2o`00017o
oooo0_l00003ooooo`;o00001?ooool00ol0003oooooooooo`0Eooooo`;o00004?ooool2o`00093o
oooo002>ooooo`;o00005_ooool2o`0000Cooooo00?o0000ooooooooool09oooool2o`00093ooooo
002[ooooo`;o0000^oooool00:_ooooo0_l00009ooooo`;o0000/?ooool00:cooooo00?o0000oooo
ooooool01oooool2o`000;3ooooo002/ooooo`03o`000?oooooooooo00[ooooo0_l0002]ooooo`00
[?ooool00ol0003oooooooooo`0:ooooo`;o0000[Oooool00:cooooo0ol0000:ooooo`;o0000[Ooo
ool00:cooooo00?o0000ooooooooool0^Oooool008Kooooo0_l0000Tooooo`03o`000?oooooooooo
0;Wooooo0026ooooo`;o00004?ooool2o`0001;ooooo00?o0000ooooooooool0^Oooool009Sooooo
0_l0000Booooo`03o`000?oooooooooo0;Wooooo002Sooooo`?o00001_ooool00ol0003ooooooooo
o`2iooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^
k^kooooo00Cooooo00GoA4A4o`000?l0003o0000omgMg@05ooooo`03o`000?oooooooooo00Gooooo
0_l0002booooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEE
EOnYZJWooooo00Oooooo00CoMgMgoc8b<_oooooooooo0_l000000ooooooo0000ooooo`05ooooo`?o
0000/_ooool0087ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool01?nYZJWo
EEEEo`000?l00007ooooo`03o`000?oooooooooo00;o000000Coooooo`000?l0003o00001?ooool2
o`000;?ooooo0029ooooo`05o`000?ooooooooooooooool000003Oooool4o`0000Kooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`2iooooo`00ROooool01Ol0003ooooooooooooooooo
000000gooooo0_l000000oo<c<coooooooooo`02ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`2iooooo`00ROooool01Ol@413ooooooooooooooooo410@00kooooo00?o
ZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Wooooo0029
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`;o0000[_ooool008Wooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool0
2Oooool2o`000:kooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Rooooo`;o00002?ooool0
0ol0003oooooooooo`2iooooo`00X?ooool4o`0000Sooooo00?o0000ooooooooool0^Oooool009Oo
oooo0_l00007ooooo`;o00002_ooool3o`000;Wooooo002Gooooo`;o00004oooool00ol0003ooooo
ooooo`2iooooo`00U_ooool2o`0001?ooooo0_l0002kooooo`00U_ooool2o`0001?ooooo0_l0002k
ooooo`00W?ooool2o`0000kooooo00?o0000ooooooooool01Oooool2o`000;;ooooo002Looooo`;o
00003_ooool00ol0003oooooooooo`05ooooo`;o00002Oooool2o`000:Oooooo002/ooooo`03o`00
0?oooooooooo013ooooo0_l0002Wooooo`00[?ooool01?l0003oooooo`000?l0000@ooooo`;o0000
2oooool2o`0009Wooooo002/ooooo`Co00001_ooool2o`0000Sooooo0ol0000:ooooo`;o0000VOoo
ool009oooooo0_l00006ooooo`;o00000oooool00ol0003oooooooooo`02o`0000Gooooo0_l00009
ooooo`;o0000YOooool009oooooo0_l00006ooooo`;o00000oooool00ol0003oooooooooo`02o`00
02cooooo0_l00029ooooo`00[?ooool00ol0003oooooooooo`0^ooooo`?o0000R?ooool00:cooooo
00?o0000ooooooooool0;oooool2o`0008Sooooo002Zooooo`?o0000^oooool00:[ooooo0ol0002k
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002Uooooo`;o0000
1Oooool00ol0003oooooooooo`2iooooo`00YOooool2o`0000Gooooo00?o0000ooooooooool0^Ooo
ool00:cooooo00?o0000ooooooooool09Oooool2o`0009;ooooo002Nooooo`;o00003?ooool00ol0
003oooooooooo`02o`0002?ooooo0_l0002Booooo`00W_ooool2o`0000cooooo00?o0000oooooooo
ool00_l00005ooooo`;o0000/?ooool009gooooo0_l0000=ooooo`03o`000?oooooooooo00Oooooo
0_l0000Oooooo`;o0000Soooool008Sooooo0_l00002ooooo`;o00003oooool2o`0000cooooo0_l0
000Zooooo`;o0000Soooool008Sooooo0_l00002ooooo`;o00007Oooool4o`000;Wooooo002/oooo
o`03o`000?oooooooooo00?ooooo0_l0000Tooooo`;o0000S_ooool00:Oooooo0_l00003ooooo`03
o`000?oooooooooo00?ooooo0_l0000Gooooo`;o00002oooool2o`0008kooooo002Fooooo`;o0000
3oooool2o`0000?ooooo00?o0000ooooooooool07?ooool2o`0009_ooooo0028ooooo`;o00003?oo
ool2o`0001Cooooo00?o0000ooooooooool0:oooool2o`0008cooooo0028ooooo`;o00004oooool2
o`0000[ooooo0_l000000ooooooo0000ooooo`0/ooooo`;o0000S?ooool0097ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q0_l00003ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_oo
ool2o`000003ooooool0003ooooo02cooooo0ol0002;ooooo`00TOooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool01_oo
ool2o`0002Cooooo0_l0002;ooooo`00Qoooool8o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool2o`000;7ooooo0027
ooooo`;o00002?ooool2o`000003ooooool0003o000000oooooo0_l00005ooooo`?o00000_ooool2
o`000;Gooooo002Aooooo`;o000000?oooooo`000?l000003?ooool00ol0003o8B4Qo`000002o`00
00Gooooo00?o0000ooooooooool00_ooool2o`000;Gooooo0026ooooo`;o00001Oooool2o`0000;o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0^Oooool008Kooooo0_l00005ooooo`;o00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool01?ooool2o`000003ooooool0003ooooo0;[ooooo002Aooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000?ooooo0_l000000ooooooo0000ooooo`0:oooo
o`;o0000[_ooool008[ooooo0_l0000:ooooo`;o00005?ooool00ol0003oooooooooo`09ooooo`;o
00009_ooool2o`0000cooooo0_l0001hooooo`00R_ooool2o`0000[ooooo0_l0000Dooooo`03o`00
0?oooooooooo037ooooo0_l0000<ooooo`;o0000N?ooool008Kooooo0_l0000Kooooo`;o00001ooo
ool00ol0003oooooooooo`0Aooooo`;o0000Y_ooool008Kooooo0_l0000Kooooo`;o00001oooool3
o`0000Kooooo0_l00009ooooo`;o00001oooool2o`0009gooooo0029ooooo`;o00008Oooool00ol0
003oooooooooo`06ooooo`;o00002oooool2o`0000Gooooo0_l0002Mooooo`00ROooool2o`0000[o
oooo0_l000000ooooooo0000o`00000Booooo`04o`000?ooooooooooooooo`;o00004?ooool2o`00
013ooooo0ol0002Aooooo`00UOooool2o`000003ooooool0003o000001;ooooo00Co0000oooooooo
oooooooo0_l00003ooooo`;o00007Oooool3o`00097ooooo002Gooooo`;o00004?ooool2o`000003
ooooool0003ooooo00Oooooo0_l0000=ooooo`;o0000X_ooool009Oooooo0_l0000@ooooo`;o0000
00?oooooo`000?ooool05_ooool2o`000:;ooooo002Rooooo`;o00002?ooool00ol0003ooooooooo
o`0Eooooo`;o0000X_ooool00:;ooooo0_l00008ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`?o0000AOooool2o`0007;ooooo002/ooooo`03o`000?oooooooooo04Gooooo0_l0001booooo`00
[?ooool00ol0003oooooooooo`0eooooo`;o0000P_ooool00:cooooo00?o0000ooooooooool01Ooo
ool2o`0002?ooooo0_l00009ooooo`;o0000P_ooool0093ooooo0_l0000Hooooo`?o00001oooool2
o`0000Cooooo0_l0000Mooooo`;o0000SOooool008[ooooo0_l00004ooooo`;o00003_ooool2o`00
00Sooooo0ol0000=ooooo`;o00002oooool2o`0000Kooooo0_l0002Gooooo`00P?ooool2o`0000So
oooo0_l0000;ooooo`;o00000oooool2o`0000;ooooo0_l0000:ooooo`03o`000?oooooooooo01So
oooo0_l00006ooooo`;o0000Uoooool0083ooooo0_l0000Eooooo`;o00000oooool2o`0000;ooooo
0_l0000:ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o00000oooool2o`000;Cooooo002=
ooooo`;o00007Oooool00ol0003oooooooooo`03ooooo`;o0000]?ooool008gooooo0_l0000Moooo
o`?o00006_ooool2o`00013ooooo0_l0002;ooooo`00TOooool2o`0001Wooooo0ol0000Jooooo`;o
00004?ooool2o`0008_ooooo002Aooooo`;o00006Oooool3o`0002gooooo0_l0002:ooooo`00[?oo
ool00ol0003oooooooooo`0]ooooo`?o00002_ooool2o`0007gooooo002/ooooo`03o`000?oooooo
oooo02kooooo0_l0000:ooooo`;o0000OOooool008kooooo0_l00005ooooo`;o00005Oooool00ol0
003oooooooooo`2iooooo`00S_ooool2o`0000Gooooo0_l0000Eooooo`03o`000?oooooooooo01_o
oooo0_l00007ooooo`;o0000Toooool0093ooooo0_l0000Jooooo`?o00006oooool2o`0000Oooooo
0ol0002Booooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool09Oooool2o`0000Wooooo0_l0
000:ooooo`;o0000Noooool009Kooooo0_l00002ooooo`;o00003_ooool3o`0003;ooooo0_l0000:
ooooo`?o0000N_ooool008Kooooo0_l0000>ooooo`;o00000_ooool2o`0000kooooo1Ol0000koooo
o`Co0000N_ooool008Kooooo0_l0000Gooooo`;o00002oooool3o`0002Kooooo0_l0000Cooooo`;o
0000O?ooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`000005
ooooool0003o0000oooooom4A4@00_l000000olb<S;ogMgMooooo`04ooooo`03o`000?oooooo0000
00?o00002Oooool2o`0001Sooooo0_l0002Aooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg
00;ooooo0_l000000ooooooo8B4Qob4Q8@04ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooo000000?o00002Oooool2o`00033ooooo0_l0001i
ooooo`00POooool6o`0000;ooooo00Go410@oooooooooooooooooa0@4002ooooo`;o00002?ooool0
0onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool2
o`0001Oooooo0_l0000Nooooo`;o0000NOooool008Wooooo00Go0000ooooooooooooooooo`00000=
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0000Gooooo0_l0000;
ooooo`;o00002_ooool2o`0009Wooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool0
0omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`0Booooo`;o00001?ooool2o`0001Kooooo0_l0000=ooooo`;o0000N?ooool008Wooooo00Co410@
oooooooooooooooo0_l0000>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Hooooo`;o00005_ooool2o`0000gooooo0_l0001hooooo`00ROooool0
1?mgMgOoV9RHoooooonHV9P2o`0000[ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool07_ooool2o`0009Wooooo0029ooooo`05onk^k_lb
<S;o0000o`000?o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03
o`000?oooooooooo01kooooo0_l0002Iooooo`00Roooool2o`0001oooooo00?o0000ooooooooool0
3_ooool2o`0000oooooo0_l00007ooooo`?o0000S_ooool009?ooooo0_l0000Gooooo`03o`000?oo
oooooooo00kooooo0_l0000?ooooo`;o00001oooool3o`0008kooooo002Cooooo`;o00005oooool0
0ol0003oooooooooo`2iooooo`00Poooool2o`0002Oooooo1?l0002hooooo`00Poooool2o`0002Oo
oooo00Go0000ooooool0003o0000ooooo`02o`00013ooooo0_l0002Sooooo`00Voooool2o`0000oo
oooo00?o0000ooooooooool00_ooool2o`00013ooooo0_l0002Sooooo`00Voooool2o`0000oooooo
00?o0000ooooooooool0^Oooool007oooooo0_l0000[ooooo`03o`000?oooooooooo00oooooo0_l0
002Xooooo`00Ooooool2o`0002_ooooo00?o0000ooooooooool03oooool2o`00017ooooo0_l0000@
ooooo`;o0000Poooool00:cooooo00?o0000ooooooooool03?ooool2o`0000gooooo0_l00005oooo
o`;o00004?ooool2o`0008?ooooo002Jooooo`;o00004?ooool00ol0003oooooooooo`0<ooooo`;o
00000_ooool2o`0000Wooooo0_l0000Uooooo`;o0000MOooool009[ooooo0_l0000@ooooo`?o0000
4?ooool2o`00033ooooo0_l0001eooooo`00[?ooool00ol0003oooooooooo`0<ooooo`;o0000=?oo
ool2o`0007Gooooo002/ooooo`04o`000?ooooooooooooooo`;o00002Oooool2o`0001?ooooo0_l0
000Oooooo`;o0000MOooool00:cooooo00Co0000oooooooooooooooo0_l0000Nooooo`;o00004ooo
ool2o`00087ooooo002:ooooo`;o00002_ooool2o`0001Cooooo00?o0000ooooooooool0=_ooool2
o`0000_ooooo0_l0000=ooooo`;o0000IOooool008[ooooo0_l00002ooooo`;o00001_ooool2o`00
01Cooooo00?o0000ooooooooool0@oooool2o`0000gooooo0_l0001Uooooo`00S_ooool2o`0001co
oooo00?o0000ooooooooool0D_ooool2o`0006Gooooo002/ooooo`03o`000?oooooooooo00Oooooo
0_l0002`ooooo`00[?ooool00ol0003oooooooooo`07ooooo`;o0000;_ooool2o`00083ooooo002K
ooooo`;o00003oooool3o`0003Oooooo0_l00020ooooo`00Voooool2o`0000oooooo00?o0000oooo
ooooool05_ooool2o`0000cooooo0_l0002Cooooo`00[?ooool00ol0003oooooooooo`0Fooooo`;o
00003?ooool2o`0002gooooo0_l0001Tooooo`002Oooool4o`000003oa0@4?oooooooooo01Kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05
odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`Go00000oooool4o`000003oc8b<_oMgMgooooo01Gooooo00?o0000ooooooooool0
1oooool2o`0000oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03ob4Q8Ol0003o000000?o
oooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B42ooooo`;o000000KoooooodA4A?l0003o0000oc8b<_oMgMd?ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM01Sooooo1?l000000ol@413oooooooooo`0Booooo`002oooool00ol0003o
ooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVY
ZOooool01oooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Sooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`04oiRHV?lQ8B7ok^k^ooooo`;o00000_ooool2o`0000;ooooo00?oMgMgoc8b<_ooool0
5Oooool00ol0003oooooooooo`07ooooo`;o00003oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo00?o8B4Qo`000?l000000oooool01?nHV9So8B4Qonk^k_ooool2o`0000Kooooo00?oMgMgoc8b
<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYoooo
o`07ooooo`03ogMgMolb<S;ooooo01Wooooo00?o0000ooooooooool05?ooool000Ko00001Oooool0
0ol0003oooooooooo`0@ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00gooooo00?o
ZJVYoeEEEOooool02?ooool00ol0003oooooooooo`05ooooo`Ko00000_ooool01Ol@413ooooooooo
oooooooo410@013ooooo00?o0000ooooooooool01Oooool6o`0000;ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00;o00001oooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo01Sooooo00Co410@oooooooooooooooo0_l0000;ooooo`03oiRHV?lQ8B7ok^k^
00;o00001oooool00ol0003oooooooooo`0=ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`0=ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEoooo
o`08ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000
ooooooooool06?ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_oo
ool00omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8b
ooooo`0>ooooo`05o`000?ooooooooooooooool000001?ooool2o`0000Oooooo00?oV9RHob4Q8Oo^
k^h01oooool00omgMgOo<S8booooo`0Eooooo`03o`000?oooooooooo01Sooooo00Co0000oooooooo
oooooooo0_l0000<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool03Oooool2o`00
00?ooooo00?o0000ooooooooool02?ooool2o`0000?ooooo00?oMgMgoc8b<_ooool03_ooool01Ol0
003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`0I
ooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00?ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oo
oooo00Go0000ooooooooooooooooo`000004ooooo`;o00002?ooool00omgMgOoIVIVooooo`03oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`05_ooool00ol0003oooooooooo`0Gooooo`;o00000oooool0
0ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00>ooooo`;o00000oooool00ol0003oooooooooo`08ooooo`?o000000Co8B4Qo`000?lb<S;oc<c<
3oooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<01[ooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000oooooooo
ool06?ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0
003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0A
ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooooooo`;o00005Oooool3o`0000[ooooo0_l0000;ooooo`;o00000oooool00ol@413o0000
o`00000=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04Oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@
00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`03ogMgMonHV9Sooooo00;o00002ooo
ool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00Co0000oooooooooooooooo0_l0000Eooooo`03
o`000?oooooooooo00[ooooo0_l0000<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_l00009oooo
o`04o`000?nj^[[ooooooiRHV0;o00000oooool00ol0003oooooooooo`02ooooo`;o00003Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool05?ooool000Wooooo00?oEEEEofIVI_l000006_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo1?l0000@ooooo`03onk^k_lb<S;o000000;o00001?ooool2o`0000Gooooo00CoV9RHoa0@
4?l0003o8B4Q0_l00003ooooo`Co00005oooool00ol0003oooooooooo`0Hooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool01?nHV9So410@o`000?lQ8B42o`0000?ooooo1?l000000ooooooo0000
o`00000=ooooo`?o000000?o<S8bonk^k_ooool02oooool4o`00013ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`Go00001?ooool4o`0001Wooooo00?oEEEEofIVI_l000005_ooool0087ooooo
0_l00009ooooo`;o00007_ooool00ol0003oooooooooo`0Nooooo`;o00005oooool2o`0000cooooo
0_l0001booooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool07_ooool2o`0001Oooooo0_l0
0020ooooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool03_ooool2o`0000gooooo0_l0002?
ooooo`;o00000_ooool2o`0000Gooooo002/ooooo`03o`000?oooooooooo00kooooo0_l00008oooo
o`;o00000oooool2o`0000gooooo0_l00020ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1Ooo
ool00:cooooo00?o0000ooooooooool06?ooool2o`0001;ooooo0_l00009ooooo`;o00003Oooool2
o`0006Oooooo00CogMgMo`000?l@413oc<c<1_ooool000Ooooooool0001<o`0000cooooo00Cok^k^
ob4Q8Ol@413ok^k^1_ooool000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooooooo0_l00002ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`;o000000?o
ooooo`000?ooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool00oooool3o`0000Oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0:ooooo`04ob4Q8OmgMgOoMgMgoc8b<PKooooo0007ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`04o`000?ooooooooooooooo`;o0000
8oooool00ol0003oooooooooo`08ooooo`;o00007Oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`09ooooo`;o0000
0_ooool2o`0000Gooooo002Gooooo`;o00004oooool00ol0003oooooooooo`08ooooo`;o00004ooo
ool2o`0003Gooooo0_l0001Sooooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool07Oooool2
o`0003Gooooo0_l0001Sooooo`00[?ooool00ol0003oooooooooo`02ooooo`;o00006_ooool2o`00
09Wooooo002/ooooo`03o`000?oooooooooo00;ooooo0_l0000Jooooo`;o0000VOooool00:cooooo
00?o0000ooooooooool01Oooool2o`00013ooooo0_l0000Dooooo`;o0000R_ooool00:cooooo0ol0
0005ooooo`Co00003_ooool2o`0001Cooooo0_l0002:ooooo`00Toooool4o`0001Gooooo00?o0000
ooooooooool01oooool2o`000;3ooooo002Cooooo`Co00005Oooool00ol0003oooooooooo`0Boooo
o`;o00000oooool2o`0000Cooooo0_l0000>ooooo`;o0000R_ooool00:cooooo0ol0000Booooo`;o
00000oooool2o`0000Cooooo0_l00005ooooo`;o00001oooool2o`0008[ooooo002/ooooo`?o0000
9?ooool2o`0002kooooo0_l0001Sooooo`00[?ooool00ol0003oooooooooo`0Tooooo`;o00001_oo
ool2o`0000[ooooo0_l0000Jooooo`;o0000Hoooool00:cooooo00?o0000ooooooooool04_ooool2
o`0001Sooooo0_l0000:ooooo`;o0000Ooooool00:cooooo00?o0000ooooooooool01?ooool2o`00
00cooooo0_l0000`ooooo`;o0000Loooool00:cooooo00?o0000ooooooooool01?ooool2o`0003ko
oooo0_l0001cooooo`00[?ooool3o`0002gooooo0_l0000Fooooo`;o0000L_ooool008;ooooo0_l0
000Booooo`;o00005?ooool00ol0003oooooooooo`0Looooo`;o00003oooool2o`0001Kooooo0_l0
001booooo`00P_ooool2o`0001;ooooo0_l0000Dooooo`03o`000?oooooooooo01cooooo0_l0002K
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
QOooool2o`0000Oooooo0_l00005ooooo`;o00005Oooool00ol0003oooooooooo`0@ooooo`;o0000
<Oooool2o`0007Cooooo0022ooooo`;o000000?oooooo`000?l000001oooool2o`0000Gooooo0_l0
000Eooooo`03o`000?oooooooooo013ooooo0_l0000Aooooo`;o00001oooool2o`0001Gooooo0_l0
001dooooo`00P_ooool2o`0002Sooooo00?o0000ooooooooool04?ooool2o`0000Cooooo0_l0000;
ooooo`;o00001oooool2o`0001Oooooo0_l0001booooo`00T_ooool2o`0001Sooooo0ol0000@oooo
o`;o00001?ooool2o`0001kooooo0_l0000=ooooo`;o0000L_ooool009;ooooo0_l0000Hooooo`03
o`000?oooooooooo00Gooooo0_l0000_ooooo`;o00006oooool2o`0006Cooooo002Booooo`;o0000
0_ooool2o`0001Cooooo00?o0000ooooooooool01Oooool2o`0004cooooo0_l0001Tooooo`00T_oo
ool2o`0000;ooooo0_l0000Dooooo`03o`000?oooooooooo0;Wooooo002Cooooo`;o00005oooool0
0ol0003oooooooooo`2iooooo`00Toooool3o`0001Kooooo00?o0000ooooooooool0:oooool2o`00
08cooooo002=ooooo`;o00001Oooool2o`0001Kooooo00?o0000ooooooooool08_ooool2o`0000Oo
oooo0ol0002;ooooo`00SOooool2o`0000Cooooo0_l0000Gooooo`03o`000?oooooooooo00oooooo
0_l0000Aooooo`;o00002?ooool2o`0002Gooooo0_l0001Tooooo`00Toooool2o`0001Oooooo0ol0
000?ooooo`;o00009Oooool2o`0000Wooooo0_l0000@ooooo`;o0000I?ooool00:cooooo00?o0000
ooooooooool0:oooool2o`0000Wooooo0_l00009ooooo`;o0000M_ooool007oooooo0_l00002oooo
o`;o00009oooool00ol0003oooooooooo`0[ooooo`;o00001oooool2o`0000cooooo0_l0001eoooo
o`00Ooooool2o`0000;ooooo0_l00006ooooo`;o00007oooool00ol0003oooooooooo`0?ooooo`;o
00000oooool2o`0001kooooo0_l0000<ooooo`;o0000MOooool008Wooooo1?l0000Oooooo`03o`00
0?oooooooooo00oooooo0_l00003ooooo`;o0000Xoooool008Wooooo0_l00003ooooo`;o00007?oo
ool00ol0003oooooooooo`12ooooo`;o0000MOooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP02o`0000?ooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo
00?o0000ooooooooool02_ooool2o`0003Kooooo0_l0001eooooo`00ROooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo00[ooooo0_l0000Mooooo`;o00005oooool2o`0007Go
oooo0029ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03
o`000?oooooooooo00?ooooo0ol0000Yooooo`;o00005oooool2o`0007Gooooo0029ooooo`05o`00
0?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool00oooool2o`0002kooooo0_l00024ooooo`00ROooool01Ol0003ooooo
oooooooooooo000000;ooooo1?l00008ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c005ooooo`03o`000?oooooooooo00?ooooo0_l0000^ooooo`;o0000Q?ooool008Wo
oooo00Go410@oooooooooooooooooa0@4002ooooo`Co00002Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03Oooool2o`0002Cooooo0_l00024oooo
o`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03Oooool2o`0001[ooooo0_l0002>
ooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c004ooooo`Co00001_ooool00ol0003oooooooooo`08ooooo`;o00003_ooool2o`0000oooooo0_l0
002>ooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o00000_ooool2o`0000Sooooo0_l00004
ooooo`;o0000=Oooool2o`0006Sooooo002/ooooo`03o`000?oooooooooo00Cooooo0_l0000<oooo
o`;o00001?ooool2o`0000kooooo0_l0000Uooooo`;o0000J?ooool00:cooooo00?o0000oooooooo
ool05_ooool2o`00013ooooo0_l0002?ooooo`00Yoooool2o`0000?ooooo0ol00004ooooo`;o0000
4?ooool2o`0000kooooo0_l0000:ooooo`;o0000QOooool009cooooo0_l00009ooooo`;o00000ooo
ool00ol0003oooooooooo`04ooooo`;o00002_ooool2o`0001Cooooo0_l0000:ooooo`;o0000QOoo
ool009cooooo0_l0000>ooooo`03o`000?oooooooooo013ooooo0_l0000/ooooo`;o0000NOooool0
0:cooooo00?o0000ooooooooool07Oooool2o`0001;ooooo0_l0000;ooooo`;o0000NOooool009Wo
oooo0_l0000Aooooo`03o`000?oooooooooo01gooooo0_l0000Booooo`;o00002oooool2o`0007Wo
oooo002Iooooo`;o00004Oooool00ol0003oooooooooo`0Vooooo`;o0000TOooool00:cooooo00?o
0000ooooooooool09_ooool2o`0001Kooooo0_l0001iooooo`00[?ooool00ol0003oooooooooo`0n
ooooo`;o0000NOooool00:cooooo0ol0002iooooo`00[?ooool3o`000;Wooooo0021ooooo`;o0000
:Oooool00ol0003oooooooooo`2iooooo`00POooool2o`00013ooooo0_l0000Gooooo`03o`000?oo
oooooooo01[ooooo0_l0002Mooooo`00POooool2o`00013ooooo0_l0000Gooooo`03o`000?oooooo
oooo01[ooooo0_l0002Mooooo`00POooool2o`0001cooooo0_l0000;ooooo`03o`000?oooooooooo
01;ooooo0_l0000Iooooo`?o0000ROooool009oooooo0_l0000;ooooo`03o`000?oooooooooo01;o
oooo0_l0000Iooooo`?o00006_ooool2o`0006gooooo002Rooooo`;o00002?ooool00ol0003ooooo
ooooo`0Iooooo`;o0000;oooool2o`0006gooooo0025ooooo`;o00001?ooool2o`0001Gooooo0_l0
0008ooooo`?o00006Oooool2o`0001oooooo0_l0001mooooo`00QOooool2o`0000Cooooo0_l0000O
ooooo`03o`000?oooooooooo02_ooooo0_l0000=ooooo`;o0000OOooool008Wooooo0_l0000Qoooo
o`03o`000?oooooooooo02_ooooo0_l0002<ooooo`00ROooool2o`00027ooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool009Sooooo0_l0000Booooo`03o`000?oo
oooooooo03Sooooo0_l0001oooooo`00V?ooool2o`0001;ooooo00Co0000ooooool0003o00003Ooo
ool2o`0002Sooooo0_l0001oooooo`00[?ooool01?l0003oooooo`000?l0000=ooooo`;o0000ZOoo
ool009gooooo0_l0000=ooooo`?o00000oooool2o`0000?ooooo0_l0000Pooooo`;o0000SOooool0
09gooooo0_l0000=ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`;o00001?ooool2o`00
01[ooooo0_l0000;ooooo`;o0000P?ooool009gooooo0_l0000=ooooo`03o`000?oooooooooo00ko
oooo0_l0000Jooooo`;o00002oooool2o`00083ooooo0027ooooo`;o00007_ooool2o`0000?ooooo
0_l00016ooooo`;o0000L_ooool008Oooooo0_l0000Nooooo`;o00000oooool2o`0003Oooooo0_l0
000=ooooo`;o0000L_ooool00:Gooooo0_l00005ooooo`03o`000?oooooooooo00;o0000=?ooool2
o`0000cooooo0_l0001cooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o8B4Q
o`000?l000001?ooool00om4A4Co0000o`000002o`0000Gooooo00?o0000ooooooooool00_l0000U
ooooo`;o00006oooool2o`0007?ooooo002Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool0
0olQ8B7o0000o`000007ooooo`04ogMgMolb<S;oooooooooo`;o000000?oooooo`000?ooool07?oo
ool2o`0000[ooooo0_l0002@ooooo`00TOooool01Ol@413ooooooooooooooooo410@00?ooooo0_l0
000;ooooo`03o`000?oooooooooo00;o000000?oooooo`000?ooool07?ooool2o`0000Wooooo0_l0
002Aooooo`00Roooool2o`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`;o00002_oo
ool00omgMgOo<S8booooo`04ooooo`?o00009_ooool2o`00097ooooo002;ooooo`;o00001?ooool0
1Ol0003ooooooooooooooooo000000?ooooo0_l00007ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`2iooooo`00TOooool01Ol@413ooooooooooooooooo410@00cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`;o00001Oooool2o`000:Oooooo
002Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`?o0000
0oooool2o`0000Cooooo0_l00005ooooo`;o0000Yoooool008oooooo0_l000001Oo^k^ko<S8bo`00
0?l0003ok^k^00Gooooo0_l00005ooooo`Co00001_ooool3o`0000?ooooo0_l0000[ooooo`;o0000
Qoooool008Cooooo0_l00009ooooo`;o00000_ooool2o`000003ooooool0003o000000?ooooo0_l0
000?ooooo`03o`000?oooooooooo00kooooo0_l0000Pooooo`;o0000Qoooool008Cooooo0_l0000@
ooooo`;o00004oooool2o`00013ooooo0_l0000Pooooo`;o0000Qoooool009gooooo0_l0000<oooo
o`;o00006Oooool2o`0000Wooooo0_l0000<ooooo`;o0000Qoooool0093ooooo0_l0000;ooooo`;o
00003Oooool3o`0001Oooooo0_l00009ooooo`;o0000UOooool008Cooooo0_l0000:ooooo`;o0000
6_ooool01?l0003oooooo`000?l0002hooooo`00Q?ooool2o`0002Kooooo00Co0000ooooool0003o
0000^?ooool008gooooo0_l0000Cooooo`;o00002?ooool00ol0003oooooooooo`0Qooooo`;o0000
U_ooool008gooooo0_l0000Cooooo`;o00002?ooool00ol0003oooooooooo`0Qooooo`;o00002?oo
ool2o`0008cooooo002/ooooo`03o`000?oooooooooo00?ooooo0_l0000Iooooo`;o00002oooool2
o`0008cooooo002Kooooo`;o00003oooool00ol0003oooooooooo`03ooooo`;o00006Oooool2o`00
00_ooooo0_l0002<ooooo`00Voooool2o`0000oooooo00?o0000ooooooooool0:oooool3o`0008_o
oooo002/ooooo`?o0000;?ooool2o`0008_ooooo002Looooo`;o00003_ooool00ol0003ooooooooo
o`0Looooo`;o0000Voooool009cooooo0_l0000>ooooo`03o`000?oooooooooo013ooooo1?l00008
ooooo`;o00002_ooool4o`0008gooooo002Nooooo`;o00001oooool2o`0000?ooooo00?o0000oooo
ooooool04?ooool4o`0001Cooooo1?l0002=ooooo`00W_ooool2o`0000Oooooo0_l00003ooooo`03
o`000?oooooooooo02Sooooo0ol0002>ooooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool0
3oooool2o`0001Gooooo1?l0002?ooooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool03ooo
ool2o`0001Gooooo0ol0002@ooooo`00UOooool2o`0001Gooooo00?o0000ooooooooool0^Oooool0
09Gooooo0_l0000Eooooo`?o00003_ooool2o`000:Wooooo002Eooooo`;o00005Oooool00ol0003o
ooooooooo`0>ooooo`;o0000ZOooool009cooooo0_l0000>ooooo`03o`000?oooooooooo00cooooo
0_l0000Fooooo`;o0000Toooool009cooooo0ol0000=ooooo`03o`000?oooooooooo00?ooooo0_l0
0006ooooo`?o00005Oooool3o`0009?ooooo002Mooooo`;o00003Oooool00ol0003oooooooooo`03
ooooo`;o00001_ooool2o`0001Kooooo0_l0002Dooooo`00Z?ooool2o`0000;ooooo00?o0000oooo
ooooool05Oooool2o`0000gooooo0_l0002Cooooo`00Z?ooool2o`0000;ooooo00?o0000oooooooo
ool00_l0000Cooooo`;o00003Oooool2o`0009?ooooo002/ooooo`03o`000?oooooooooo00;o0000
]oooool00:cooooo00?o0000ooooooooool04oooool2o`0000[ooooo0_l0002Hooooo`00[?ooool3
o`0000Kooooo0_l0000;ooooo`;o00002_ooool2o`0009Sooooo002/ooooo`03o`000?oooooooooo
00Kooooo0_l0002aooooo`00Zoooool2o`000;_ooooo002Zooooo`?o00001_ooool2o`0001Oooooo
0_l0002Jooooo`00UOooool2o`0001?ooooo0ol00006ooooo`;o00002_ooool2o`0000_ooooo0_l0
002Jooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B42o`0000Cooooo00?o
0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0
4?ooool2o`000:Oooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo
00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02_ooooo
0_l0002<ooooo`00ROooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool0
2?ooool01?l0003oooooo`000?l00002ooooo`03o`000?oooooooooo01_ooooo0ol0000=ooooo`;o
0000S?ooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00;o
00000_ooool2o`000003ogMgMolb<S;ooooo00;o00000_ooool3o`0000_ooooo0ol0000=ooooo`?o
0000Voooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00;o
000000Koooooo`000?l0003o0000oc8b<_o<c<`5ooooo`03o`000?oooooooooo00_ooooo0ol0002[
ooooo`00ROooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`2iooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol0
0004ooooo`Co00001_ooool00ol0003oooooooooo`0Hooooo`;o0000Woooool00:cooooo00?o0000
ooooooooool06?ooool2o`0009oooooo002/ooooo`03o`000?oooooooooo00Sooooo0ol0002^oooo
o`00[?ooool00ol0003oooooooooo`08ooooo`?o0000[_ooool00:cooooo0ol0002iooooo`00UOoo
ool2o`0001Gooooo00?o0000ooooooooool0^Oooool009Gooooo0_l0000Eooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002Fooooo`;o00005?ooool00ol0003ooooooooo
o`2iooooo`00U_ooool2o`0001Cooooo00?o0000ooooooooool07oooool2o`0009Sooooo002/oooo
o`?o00007oooool2o`0009Sooooo002/ooooo`04o`000?oooooo0000o`0000gooooo0_l0002Yoooo
o`00[?ooool01?l0003oooooo`000?l0000=ooooo`;o0000ZOooool00:cooooo0_l0000=ooooo`;o
00003_ooool2o`0009_ooooo002/ooooo`?o00003?ooool2o`0000kooooo0_l0002Kooooo`00[?oo
ool3o`0000_ooooo0_l0002/ooooo`00[?ooool00ol0003oooooooooo`0;ooooo`;o0000[?ooool0
0:[ooooo0ol0000:ooooo`;o0000[oooool00:[ooooo0ol00009ooooo`?o0000[oooool009?ooooo
0_l0000Gooooo`?o00001oooool3o`000:oooooo002Cooooo`;o00002oooool2o`000003ooooool0
003o000000Oooooo00?o0000ooooooooool0^Oooool00:3ooooo0_l000000ooooooo0000o`000007
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo01;ooooo0_l0002Uooooo`00Uooo
ool2o`0001?ooooo00?o0000ooooooooool04_ooool2o`000:Gooooo002Gooooo`;o00004oooool0
0ol0003oooooooooo`2iooooo`00Uoooool2o`0001?ooooo0ol0002iooooo`00Uoooool2o`0001?o
oooo00?o0000ooooooooool0^Oooool009Wooooo0_l0000Aooooo`03o`000?oooooooooo0;Wooooo
002Iooooo`;o00004Oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00Yoooool4o`000003ooooool0003ooooo0;[ooooo002Nooooo`;o00000_ooool9o`000003
ooooool0003ooooo0;[ooooo002Nooooo`;o00001?ooool3o`0000Gooooo00?o0000ooooooooool0
2?ooool2o`000:oooooo002Tooooo`03o`000?oooooooooo00Gooooo0ol00008ooooo`;o0000[ooo
ool00:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:Co
oooo00?o0000ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:;ooooo00?o
EEEEofIVI_l00000`oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00:[ooooo00Co410@o`000?l0003o0000^_ooool00:_ooooo00?o0000ooooooooool0^_oo
ool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00Ko0000ogMgMol0003o0000oeEEEOo^
k^jgooooo`00Zoooool01_l0003oEEEEonk^k_ooooooMgMgoeEEEKOooooo002[ooooo`03o`000?o^
k^kooooo00;ooooo00?o0000ooooooooool0]Oooool00:_ooooo00?o0000onk^k_ooool00_ooool0
0ol0003oooooooooo`2eooooo`00Zoooool01_l0003oEEEEonk^k_ooooooMgMgofIVI[Oooooo002Z
ooooo`03oa0@4?l0003oMgMg00;o000000?oIVIVonk^k_ooool0]_ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.5893 .26237 Mdot
.63906 .63141 Mdot
.48006 .36581 Mdot
.47731 .24734 Mdot
.5586 .67159 Mdot
.43614 .84278 Mdot
.48388 .33114 Mdot
.72917 .52753 Mdot
.58078 .13926 Mdot
.48168 .2239 Mdot
.5682 .52438 Mdot
.71626 .6159 Mdot
.38126 .57994 Mdot
.56474 .43419 Mdot
.713 .60724 Mdot
.53948 .63397 Mdot
.39727 .43519 Mdot
.3794 .48959 Mdot
.47467 .19625 Mdot
.68319 .58507 Mdot
.38108 .55396 Mdot
.57767 .78408 Mdot
.54846 .8297 Mdot
.38438 .3632 Mdot
.64467 .79494 Mdot
.55398 .28375 Mdot
.54565 .65429 Mdot
.43755 .25115 Mdot
.67118 .64018 Mdot
.63686 .63358 Mdot
.3851 .37246 Mdot
.59328 .15357 Mdot
.71548 .41407 Mdot
.51711 .18606 Mdot
.62259 .46084 Mdot
.66339 .37597 Mdot
.43177 .91735 Mdot
.41716 .64063 Mdot
.65763 .67466 Mdot
.70372 .67247 Mdot
.62943 .82633 Mdot
.59355 .33561 Mdot
.59035 .69543 Mdot
.62881 .35276 Mdot
.55142 .19242 Mdot
.40824 .63098 Mdot
.54108 .34347 Mdot
.49599 .03653 Mdot
.58643 .64404 Mdot
.67816 .59206 Mdot
.47746 .02881 Mdot
.59578 .81405 Mdot
.71115 .76599 Mdot
.62046 .56666 Mdot
.61117 .63208 Mdot
.66342 .27031 Mdot
.72784 .53711 Mdot
.39798 .41292 Mdot
.3811 .29523 Mdot
.52302 .15071 Mdot
.40219 .5164 Mdot
.37794 .22769 Mdot
.65568 .67682 Mdot
.54222 .45165 Mdot
.69877 .36521 Mdot
.6381 .22103 Mdot
.45595 .23796 Mdot
.55372 .53401 Mdot
.40921 .54396 Mdot
.40511 .20762 Mdot
.45371 .15068 Mdot
.45015 .65056 Mdot
.48138 .22556 Mdot
.41428 .47467 Mdot
.65597 .67581 Mdot
.4598 .62978 Mdot
.71081 .76659 Mdot
.42232 .2761 Mdot
.62159 .76806 Mdot
.60018 .49157 Mdot
.53418 .12959 Mdot
.64197 .60661 Mdot
.43155 .34405 Mdot
.60519 .3706 Mdot
.71935 .42107 Mdot
.51491 .71235 Mdot
.54759 .70262 Mdot
.51469 .77044 Mdot
.39818 .58976 Mdot
.55256 .54767 Mdot
.64118 .79973 Mdot
.75251 .38024 Mdot
.5073 .70147 Mdot
.45481 .80958 Mdot
.534 .6111 Mdot
.74036 .33711 Mdot
.5606 .41043 Mdot
.46626 .03328 Mdot
.69472 .79781 Mdot
.39519 .47061 Mdot
.61492 .32167 Mdot
.4332 .80053 Mdot
.71818 .59516 Mdot
.64156 .40258 Mdot
.4966 .08076 Mdot
.54403 .23035 Mdot
.48248 .13983 Mdot
.53044 .2736 Mdot
.50389 .71015 Mdot
.40515 .20888 Mdot
.53866 .33069 Mdot
.47417 .24573 Mdot
.58123 .13797 Mdot
.68253 .45297 Mdot
.39349 .91986 Mdot
.43198 .41352 Mdot
.40863 .36458 Mdot
.67986 .29629 Mdot
.6493 .2371 Mdot
.47441 .9555 Mdot
.38367 .61987 Mdot
.363 .59914 Mdot
.441 .88728 Mdot
.66533 .66422 Mdot
.40906 .19011 Mdot
.50842 .2916 Mdot
.68485 .49009 Mdot
.70485 .25692 Mdot
.64569 .4526 Mdot
.51882 .38022 Mdot
.53885 .84701 Mdot
.63607 .39144 Mdot
.70055 .67338 Mdot
.4092 .75178 Mdot
.54964 .78477 Mdot
.63822 .73619 Mdot
.44144 .93796 Mdot
.68249 .57287 Mdot
.46978 .22596 Mdot
.72124 .45962 Mdot
.70876 .63248 Mdot
.4193 .53058 Mdot
.42114 .31971 Mdot
.39807 .4162 Mdot
.68747 .52489 Mdot
.70747 .37188 Mdot
.36437 .23379 Mdot
.51835 .25508 Mdot
.48216 .81712 Mdot
.37262 .73023 Mdot
.45192 .83833 Mdot
.45488 .78132 Mdot
.39038 .29782 Mdot
.46942 .68437 Mdot
.38888 .51099 Mdot
.50915 .93428 Mdot
.63864 .72601 Mdot
.6721 .28236 Mdot
.43874 .92907 Mdot
.49347 .95211 Mdot
.6003 .44231 Mdot
.61638 .77997 Mdot
.61947 .84846 Mdot
.62631 .27882 Mdot
.60095 .65767 Mdot
.59458 .27734 Mdot
.70072 .35166 Mdot
.54234 .13615 Mdot
.41522 .62773 Mdot
.49069 .95623 Mdot
.68242 .50277 Mdot
.50293 .70747 Mdot
.45944 .78377 Mdot
.55523 .67786 Mdot
.55205 .33133 Mdot
.71173 .40591 Mdot
.72958 .31003 Mdot
.39128 .58646 Mdot
.43133 .56474 Mdot
.66786 .64686 Mdot
.53995 .89896 Mdot
.6834 .72611 Mdot
.43724 .71249 Mdot
.61424 .85009 Mdot
.51901 .63018 Mdot
.55388 .10671 Mdot
.69517 .24091 Mdot
.59939 .15914 Mdot
.63524 .82292 Mdot
.56538 .75545 Mdot
.39693 .86923 Mdot
.6877 .52765 Mdot
.5024 .30026 Mdot
.36158 .45668 Mdot
.72619 .46832 Mdot
.5382 .95162 Mdot
.71185 .63069 Mdot
.48674 .81616 Mdot
.77335 .49465 Mdot
.56201 .25544 Mdot
.49047 .68882 Mdot
.47973 .70072 Mdot
.43755 .58599 Mdot
.57213 .61705 Mdot
.77317 .53875 Mdot
.62016 .33946 Mdot
.42568 .55017 Mdot
.40683 .73542 Mdot
.47988 .2444 Mdot
.45265 .70358 Mdot
.56533 .56917 Mdot
.44396 .89956 Mdot
.41464 .31907 Mdot
.5444 .13908 Mdot
.48535 .763 Mdot
.60139 .29282 Mdot
.40299 .47925 Mdot
.61588 .85304 Mdot
.50461 .68129 Mdot
.46097 .11349 Mdot
.71385 .63846 Mdot
.40521 .40511 Mdot
.38138 .29818 Mdot
.52261 .11031 Mdot
.568 .17748 Mdot
.53235 .65443 Mdot
.58451 .52343 Mdot
.64605 .60532 Mdot
.50493 .70418 Mdot
.71175 .6149 Mdot
.36115 .43683 Mdot
.55576 .51961 Mdot
.48465 .65872 Mdot
.77129 .53275 Mdot
.54796 .74322 Mdot
.54208 .66931 Mdot
.37813 .76626 Mdot
.43306 .72603 Mdot
.64927 .44522 Mdot
.4293 .86574 Mdot
.63066 .36989 Mdot
.3752 .25 Mdot
.49407 .87337 Mdot
.60642 .232 Mdot
.45139 .15381 Mdot
.61166 .17747 Mdot
.54296 .54333 Mdot
.54686 .88356 Mdot
.46661 .84477 Mdot
.44436 .16521 Mdot
.65067 .6938 Mdot
.55956 .92544 Mdot
.42946 .448 Mdot
.49051 .27886 Mdot
.51937 .91819 Mdot
.54886 .27595 Mdot
.47578 .79104 Mdot
.58641 .71363 Mdot
.44797 .58541 Mdot
.72656 .4997 Mdot
.43567 .06359 Mdot
.56804 .69851 Mdot
.5427 .66754 Mdot
.59295 .2163 Mdot
.47611 .28852 Mdot
.47765 .85101 Mdot
.54743 .19074 Mdot
.54895 .37187 Mdot
.5168 .83659 Mdot
.67473 .42818 Mdot
.57799 .35344 Mdot
.67732 .43048 Mdot
.5997 .67416 Mdot
.48732 .22629 Mdot
.5956 .59005 Mdot
.51235 .93116 Mdot
.42169 .63381 Mdot
.58171 .4427 Mdot
.5021 .04391 Mdot
.56711 .5599 Mdot
.39005 .56828 Mdot
.65401 .69297 Mdot
.53523 .47694 Mdot
.43528 .70114 Mdot
.44454 .93714 Mdot
.72228 .5689 Mdot
.54013 .29474 Mdot
.51439 .57788 Mdot
.57932 .45451 Mdot
.6742 .39959 Mdot
.44644 .79475 Mdot
.49393 .08175 Mdot
.69178 .23584 Mdot
.37182 .44689 Mdot
.72001 .56235 Mdot
.37164 .48818 Mdot
.43919 .43816 Mdot
.37067 .48515 Mdot
.37282 .71602 Mdot
.65709 .3395 Mdot
.71622 .58817 Mdot
.60047 .55882 Mdot
.53608 .81342 Mdot
.64296 .42055 Mdot
.60547 .16943 Mdot
.64857 .79085 Mdot
.55616 .39705 Mdot
.48654 .03246 Mdot
.56537 .31393 Mdot
.52494 .53893 Mdot
.46371 .91787 Mdot
.4081 .30845 Mdot
.39712 .741 Mdot
.39284 .85502 Mdot
.44006 .35877 Mdot
.49231 .11531 Mdot
.56135 .26212 Mdot
.70843 .40147 Mdot
.49579 .30704 Mdot
.67963 .73358 Mdot
.56818 .06564 Mdot
.54733 .41906 Mdot
.39892 .68868 Mdot
.61174 .39348 Mdot
.63398 .73372 Mdot
.58308 .5601 Mdot
.49893 .67248 Mdot
.45527 .35204 Mdot
.45132 .15591 Mdot
.72269 .5957 Mdot
.53934 .89126 Mdot
.53471 .6093 Mdot
.50985 .89145 Mdot
.5286 .42636 Mdot
.4367 .57783 Mdot
.64374 .61616 Mdot
.45102 .86902 Mdot
.59956 .6626 Mdot
.59972 .43943 Mdot
.57853 .58017 Mdot
.73285 .72028 Mdot
.55524 .29216 Mdot
.64871 .54458 Mdot
.54059 .44242 Mdot
.6952 .34521 Mdot
.55562 .61436 Mdot
.68446 .54705 Mdot
.62769 .66018 Mdot
.44383 .70701 Mdot
.43058 .74969 Mdot
.71762 .61326 Mdot
.37064 .46239 Mdot
.67154 .40717 Mdot
.60333 .5286 Mdot
.53874 .21546 Mdot
.68257 .49063 Mdot
.51506 .8067 Mdot
.7182 .60872 Mdot
.60069 .10065 Mdot
.6158 .24903 Mdot
.70365 .66182 Mdot
.67392 .74602 Mdot
.60572 .86553 Mdot
.43996 .39122 Mdot
.56984 .69047 Mdot
.70815 .63307 Mdot
.72765 .51557 Mdot
.44982 .34479 Mdot
.45123 .0876 Mdot
.54195 .26639 Mdot
.39695 .66744 Mdot
.60673 .30117 Mdot
.49518 .03957 Mdot
.64777 .43641 Mdot
.39011 .7643 Mdot
.59067 .81513 Mdot
.56373 .80426 Mdot
.3731 .60489 Mdot
.5562 .81911 Mdot
.66925 .74704 Mdot
.35537 .66208 Mdot
.43537 .92075 Mdot
.39457 .35423 Mdot
.49559 .65735 Mdot
.53963 .94473 Mdot
.40055 .62523 Mdot
.44741 .38082 Mdot
.67383 .74956 Mdot
.41085 .18206 Mdot
.50163 .66523 Mdot
.42076 .37351 Mdot
.49551 .1808 Mdot
.52738 .70933 Mdot
.52359 .06535 Mdot
.55825 .15442 Mdot
.36203 .54814 Mdot
.6779 .73894 Mdot
.4693 .143 Mdot
.74905 .66929 Mdot
.51085 .17307 Mdot
.54828 .32016 Mdot
.57493 .40987 Mdot
.51175 .46239 Mdot
.72522 .5708 Mdot
.71791 .60634 Mdot
.54887 .64316 Mdot
.46276 .74047 Mdot
.51644 .74014 Mdot
.4791 .77001 Mdot
.46405 .81941 Mdot
.62978 .28414 Mdot
.41931 .47997 Mdot
.45033 .77362 Mdot
.50264 .3253 Mdot
.51049 .78226 Mdot
.49085 .1503 Mdot
.50355 .76394 Mdot
.42472 .46692 Mdot
.36707 .669 Mdot
.72114 .45617 Mdot
.47027 .6225 Mdot
.62503 .49666 Mdot
.48203 .13977 Mdot
.39866 .32108 Mdot
.56116 .30996 Mdot
.43656 .73889 Mdot
.52174 .96641 Mdot
.76037 .39843 Mdot
.65057 .46533 Mdot
.64088 .39436 Mdot
.44507 .31194 Mdot
.59433 .16015 Mdot
.70434 .64714 Mdot
.56686 .53896 Mdot
.62943 .65149 Mdot
.72761 .73191 Mdot
.45026 .72073 Mdot
.52325 .56784 Mdot
.56435 .37184 Mdot
.59306 .21529 Mdot
.59725 .447 Mdot
.76729 .44373 Mdot
.49169 .71006 Mdot
.6226 .48616 Mdot
.59418 .33474 Mdot
.54309 .55574 Mdot
.43265 .4127 Mdot
.41374 .50999 Mdot
.72887 .52714 Mdot
.47095 .28704 Mdot
.63316 .74547 Mdot
.64957 .57402 Mdot
.5312 .16415 Mdot
.6822 .46082 Mdot
.44919 .09128 Mdot
.43806 .18333 Mdot
.71321 .26926 Mdot
.42944 .31608 Mdot
.72099 .60642 Mdot
.55713 .92919 Mdot
.54726 .36718 Mdot
.37072 .46632 Mdot
.56985 .3313 Mdot
.40593 .66402 Mdot
.685 .54253 Mdot
.61882 .33092 Mdot
.49223 .20605 Mdot
.42545 .73043 Mdot
.52063 .19052 Mdot
.38759 .16423 Mdot
.56435 .75383 Mdot
.4639 .63905 Mdot
.60638 .64118 Mdot
.60102 .51707 Mdot
.43844 .39983 Mdot
.54978 .43941 Mdot
.62183 .55621 Mdot
.55234 .78158 Mdot
.44013 .63502 Mdot
.51831 .21869 Mdot
.64131 .22665 Mdot
.56201 .66263 Mdot
.51828 .1485 Mdot
.41431 .36794 Mdot
.42493 .30481 Mdot
.49308 .32298 Mdot
.40781 .96832 Mdot
.50155 .34569 Mdot
.64148 .62363 Mdot
.37845 .33395 Mdot
.63541 .29782 Mdot
.4091 .45323 Mdot
.67782 .6032 Mdot
.6978 .68712 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:Cooooo0_l00006ooooo`03o`000?oooooo
oooo0;Wooooo002Tooooo`;o00001_ooool00ol0003oooooooooo`2iooooo`00X?ooool2o`0000Go
oooo0_l00003ooooo`03o`000?oooooooooo0;Wooooo002Pooooo`;o00001Oooool2o`000004oooo
ool0003o0000o`000;_ooooo002Zooooo`?o0000^oooool00:[ooooo1?l0002jooooo`00[?ooool2
o`000;[ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool009Kooooo0_l0000Dooooo`03o`000?oooooooooo0;Wooooo002Fooooo`;o
00005?ooool00ol0003oooooooooo`04ooooo`;o00003Oooool2o`000:Cooooo002/ooooo`03o`00
0?oooooooooo00Cooooo0_l0000=ooooo`;o0000Y?ooool00:cooooo00?o0000ooooooooool0^Ooo
ool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00Z_ooool3o`000;_o
oooo002Zooooo`?o0000^oooool009_ooooo0_l0000?ooooo`03o`000?oooooooooo0;Wooooo002K
ooooo`;o00003oooool00ol0003oooooooooo`2iooooo`00Voooool2o`0000oooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0000Nooooo`;o0000
VOooool00:cooooo00?o0000ooooooooool07_ooool2o`0009Wooooo002/ooooo`03o`000?oooooo
oooo00kooooo0_l0002Yooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o00002?ooool2o`00
0:Wooooo002Oooooo`;o00002oooool00ol0003oooooooooo`04ooooo`;o0000/oooool009oooooo
0_l00008ooooo`;o000000?oooooo`000?ooool0^_ooool008Wooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oM
gMd00_ooool2o`000003ooooool0003ooooo0;[ooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo0;Wooooo0021ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00go
oooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000^Oooool008Wooooo
00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`2iooooo`00ROooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool02?ooool2o`000:oooooo0029ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onY
ZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool2o`00
0:oooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo
<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0;ooooo`;o00002_ooool2
o`000:3ooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1_l00004
ooooo`03o`000?oooooooooo00_ooooo0_l0000:ooooo`;o0000X?ooool00:7ooooo0_l00003oooo
o`;o00001?ooool00ol0003oooooooooo`0;ooooo`;o00002_ooool2o`000:3ooooo002Qooooo`;o
00002Oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`03ooooo`;o0000
]?ooool009cooooo0_l0000;ooooo`;o000000Coooooo`000?l0003o00000oooool3o`000;?ooooo
002Kooooo`?o00002oooool2o`000003ooooool0003ooooo00Gooooo0_l0000:ooooo`;o00002Ooo
ool2o`0009cooooo002Kooooo`?o00003_ooool00ol0003oooooooooo`0@ooooo`;o00002Oooool4
o`0009[ooooo002/ooooo`03o`000?oooooooooo01cooooo0ol0002Jooooo`00Q_ooool2o`00017o
oooo0_l0000Aooooo`03o`000?oooooooooo00Oooooo0_l0000Cooooo`;o0000Voooool008Kooooo
0_l0000Aooooo`;o00004Oooool00ol0003oooooooooo`07ooooo`;o0000/?ooool00:cooooo00?o
0000ooooooooool07oooool2o`0009Sooooo002/ooooo`03o`000?oooooooooo00;o00007Oooool2
o`0009Sooooo002/ooooo`Go0000]oooool00:cooooo00?o0000ooooooooool04oooool2o`0000co
oooo0_l0002Fooooo`00S_ooool2o`0000Oooooo0_l0000Aooooo`?o00005Oooool2o`0000cooooo
0_l0002Fooooo`00S_ooool2o`0000Oooooo0_l0000Aooooo`?o00001?ooool2o`000;Gooooo002/
ooooo`03o`000?oooooooooo00;ooooo0_l0002eooooo`00S_ooool2o`0001cooooo00?o0000oooo
ooooool00oooool2o`0000Oooooo1?l0002Yooooo`00S_ooool2o`0001cooooo00?o0000oooooooo
ool00oooool2o`0000Oooooo1?l0002Yooooo`00Xoooool2o`0000Oooooo00?o0000ooooooooool0
^Oooool00:?ooooo0_l00007ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
08cooooo0_l0000Kooooo`;o000000?oooooo`000?ooool0^_ooool008cooooo0_l0000Kooooo`;o
000000?oooooo`000?ooool0^_ooool008cooooo0_l0000Nooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo00Wooooo0_l0000@ooooo`;o0000W?ooool00:cooooo00?o0000
ooooooooool00oooool2o`0000Cooooo0_l0000@ooooo`;o0000W?ooool00:cooooo00?o0000oooo
ooooool00oooool2o`0002Gooooo0_l0002=ooooo`00YOooool3o`0000Cooooo0ol0000Zooooo`;o
0000SOooool008?ooooo0_l0000Mooooo`;o000000?oooooo`000?l000000_l00003ooooo`03o`00
0?oooooooooo02_ooooo0_l0002<ooooo`00Poooool2o`0001gooooo0_l00003ooooo`;o00000ooo
ool00ol0003oooooooooo`0;ooooo`;o00007_ooool2o`0008cooooo001oooooo`;o0000:oooool0
0ol0003oooooooooo`0;ooooo`;o00004oooool2o`0009Oooooo001oooooo`;o00007?ooool2o`00
00gooooo00?o0000ooooooooool08?ooool2o`0000cooooo0_l0000<ooooo`;o0000Noooool009go
oooo0_l0000=ooooo`03o`000?oooooooooo02kooooo0_l0000<ooooo`?o0000N_ooool0097ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0?Oooool2o`0007[ooooo002Aooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Kooooo1?l00005ooooo`03o`000?oooooooooo0;Wooooo0022ooooo`;o
00001Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`Co00001Oooool00ol0
003oooooooooo`0Sooooo`;o0000U?ooool008;ooooo0_l0000=ooooo`06o`000?oooooooooooooo
ool0003ooooo0_l0000;ooooo`;o000000?o<S8booooooooool00oooool3o`0002?ooooo0_l0002D
ooooo`00TOooool01_l0003ooooooooooooooooo0000ooooo`;o00002Oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool00oooool2o`0000cooooo0_l0002Vooooo`00TOoo
ool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`03ooooo`;o00003?ooool2o`0002gooooo0_l0001gooooo`00TOooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Aooooo`;o0000
;Oooool2o`0007Oooooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo
00?o0000ooooooooool04Oooool2o`0000Oooooo0_l0002Mooooo`00[?ooool00ol0003ooooooooo
o`0:ooooo`;o00003_ooool2o`0009gooooo002/ooooo`03o`000?oooooooooo00[ooooo0_l0000W
ooooo`;o00003_ooool2o`0007Cooooo002/ooooo`03o`000?oooooooooo00Oooooo0_l0000Zoooo
o`;o00003_ooool2o`0007Cooooo002Booooo`;o00006?ooool3o`0000Oooooo0_l00004ooooo`;o
00003Oooool2o`0009_ooooo002Booooo`;o00005?ooool2o`0000;ooooo00?o0000ooooooooool0
3Oooool2o`0000gooooo0_l00008ooooo`;o0000TOooool00:Sooooo0_l00002ooooo`03o`000?oo
oooooooo02Kooooo0_l0000=ooooo`;o0000P_ooool00:cooooo00?o0000ooooooooool03_ooool2
o`0001Oooooo0_l0000<ooooo`;o0000P_ooool00:;ooooo1?l00006ooooo`03o`000?oooooooooo
00kooooo0_l0000Gooooo`;o0000T?ooool00:;ooooo1?l00006ooooo`04o`000?oooooo0000o`00
00kooooo0_l0002Xooooo`00Q?ooool2o`0002Kooooo00Co0000ooooool0003o00002Oooool2o`00
00?ooooo0_l0000=ooooo`;o0000VOooool008Cooooo0_l000000ooooooo0000o`00000Sooooo`03
o`000?oooooooooo00[ooooo0_l0000Booooo`;o00002Oooool2o`0000gooooo0_l0001oooooo`00
Q?ooool2o`000003ooooool0003o000002?ooooo0ol0000Pooooo`;o00001oooool2o`0000gooooo
0_l0001oooooo`00[?ooool2o`00027ooooo0_l0002Gooooo`00Toooool2o`0001Gooooo0ol0002k
ooooo`00SOooool2o`0000Cooooo0_l0000Eooooo`?o00004oooool2o`0003Gooooo0_l0001_oooo
o`00SOooool2o`0000[ooooo0_l0000Aooooo`03o`000?oooooooooo017ooooo0_l0000eooooo`;o
0000Koooool009Cooooo0_l00003ooooo`;o00004Oooool00ol0003oooooooooo`0Booooo`;o0000
YOooool008oooooo0_l000000ooooooo0000o`000002o`0001Kooooo00?o0000ooooooooool04_oo
ool2o`000:Gooooo002:ooooo`;o00000oooool2o`000003ooooool0003o000001Sooooo00?o0000
ooooooooool03Oooool2o`0001Cooooo0_l0002Dooooo`00R_ooool2o`0001gooooo0_l000001?oo
oooo0000o`000?l0000=ooooo`;o00005?ooool2o`0009Cooooo002Yooooo`;o000000?oooooo`00
0?l00000^_ooool00:Kooooo0_l00004ooooo`03o`000?oooooooooo00Wooooo0_l00003ooooo`;o
00001?ooool2o`0000kooooo0_l0002Cooooo`00Poooool2o`00027ooooo0_l00004ooooo`03o`00
0?oooooooooo00Wooooo0_l00003ooooo`;o00001?ooool2o`0000Kooooo0_l00006ooooo`;o0000
Toooool008?ooooo0_l0000Wooooo`03o`000?oooooooooo01_ooooo0ol0000^ooooo`;o0000Jooo
ool00:cooooo00?o0000ooooooooool06oooool2o`0000Oooooo0_l0000:ooooo`;o00006_ooool2
o`0006_ooooo002/ooooo`03o`000?oooooooooo00[ooooo0_l0000Hooooo`;o00002_ooool2o`00
08Oooooo002Eooooo`;o00001?ooool2o`0000oooooo0_l0000;ooooo`;o0000<Oooool2o`0007[o
oooo002Eooooo`;o00001?ooool2o`0000oooooo0_l0000nooooo`;o0000N_ooool009gooooo0_l0
000=ooooo`?o00009oooool2o`0001Kooooo0_l0001hooooo`00ROooool2o`0001;ooooo0_l0000=
ooooo`03o`000?oooooooooo01Kooooo0_l0000?ooooo`;o00005_ooool2o`0007Sooooo0029oooo
o`;o00003Oooool2o`0001;ooooo00?o0000ooooooooool05_ooool2o`000:7ooooo002Hooooo`;o
00004_ooool00ol0003oooooooooo`2iooooo`00QOooool2o`0000Kooooo0_l0000Mooooo`03o`00
0?oooooooooo03kooooo0_l0001iooooo`00QOooool2o`0000;ooooo00Cok^k^oc8b<_l0003o<S8b
1?l00002ooooo`;o8B4Q1?ooool5o`0000Cooooo00?oA4A4o`000?l000000_l00005ooooo`03o`00
0?oooooooooo00cooooo0_l0000`ooooo`;o0000NOooool008Wooooo00KoMgMgoiRHV?ooooooV9RH
ogMgMoooool2o`0000;ooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool2o`00
00Gooooo00?o0000ooooooooool03?ooool2o`00017ooooo0_l00007ooooo`;o0000Soooool0087o
oooo1ol000000ooooooo410@ooooo`02ooooo`04oa0@4?ooooooooooooooo`;o00001oooool00onH
V9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03Oooool2o`00
00?ooooo0_l0000;ooooo`;o00001oooool2o`0001Oooooo0_l0001fooooo`00Q_ooool2o`000003
ooooool0003ooooo00;ooooo00Co0000oooooooooooooooo0_l00008ooooo`03oiRHV?lQ8B7ok^k^
00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0000gooooo0_l00003ooooo`;o00007oooool2o`00
00cooooo0_l0001fooooo`00ROooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool00oooool2
o`0002kooooo0_l0000Kooooo`;o0000Ioooool008Wooooo00Go410@oooooooooooooooooa0@400<
ooooo`;o000000?oooooo`000?ooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00?ooooo0_l0001;ooooo`;o0000Ioooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`?o000000?oV9RHoa0@4?ooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0;Wooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo0;Wooooo002Hooooo`;o00004_ooool0
0ol0003oooooooooo`0Yooooo`;o0000S_ooool009Sooooo0_l0000Booooo`03o`000?oooooooooo
027ooooo0_l00006ooooo`Co0000S?ooool00:cooooo00?o0000ooooooooool03oooool2o`00013o
oooo0_l00008ooooo`;o00009_ooool2o`0006Cooooo002Gooooo`;o00004oooool3o`0000oooooo
0_l0000Uooooo`;o00002Oooool2o`00013ooooo0_l0001Tooooo`00Uoooool2o`0001?ooooo00?o
0000ooooooooool0:oooool2o`0000Wooooo0_l00009ooooo`;o0000M_ooool008cooooo0_l0000N
ooooo`03o`000?oooooooooo02_ooooo0_l00008ooooo`;o00002oooool2o`0007Gooooo002<oooo
o`;o00007_ooool00ol0003oooooooooo`0Aooooo`;o00000_ooool2o`0001kooooo0_l0000;oooo
o`;o0000MOooool008[ooooo0_l00009ooooo`;o00005Oooool00ol0003oooooooooo`0Aooooo`;o
00000_ooool2o`000:;ooooo002:ooooo`;o00002Oooool2o`0001Gooooo00?o0000ooooooooool0
A?ooool2o`0007?ooooo002:ooooo`;o00008?ooool00ol0003oooooooooo`0<ooooo`;o0000=_oo
ool2o`0007?ooooo002/ooooo`03o`000?oooooooooo00cooooo0_l0000Nooooo`;o00005oooool2
o`0007;ooooo002/ooooo`?o0000;?ooool2o`0001Oooooo0_l0001booooo`00[?ooool00ol0003o
ooooooooo`06ooooo`;o0000;_ooool2o`00087ooooo002/ooooo`03o`000?oooooooooo00Kooooo
0_l0000^ooooo`?o0000P?ooool00:cooooo00?o0000ooooooooool04_ooool2o`0002?ooooo0_l0
0020ooooo`00O_ooool2o`0000[ooooo0_l0000Pooooo`03o`000?oooooooooo01;ooooo0_l0000I
ooooo`;o0000R_ooool007kooooo0_l0000:ooooo`;o00002oooool2o`0001?ooooo00?o0000oooo
ooooool03Oooool2o`0000kooooo0_l0000>ooooo`;o0000R_ooool009Oooooo0_l0000Cooooo`03
o`000?oooooooooo00[ooooo0_l000000ooooooo0000o`000009ooooo`;o00000oooool3o`0003Go
oooo0_l0001Rooooo`00POooool2o`0002Wooooo00?o0000ooooooooool02_ooool2o`0000cooooo
0_l00004ooooo`;o00003_ooool2o`0002Gooooo0_l0001Rooooo`00POooool2o`00017ooooo0_l0
000Fooooo`03o`000?oooooooooo01gooooo0_l0000?ooooo`;o0000ROooool009Cooooo0_l0000F
ooooo`?o00002oooool2o`00013ooooo0_l0000>ooooo`;o00002_ooool2o`0007kooooo002>oooo
o`;o00007?ooool00ol0003oooooooooo`0;ooooo`;o00002_ooool2o`0001Cooooo0_l0000:oooo
o`;o0000O_ooool007kooooo0_l0000>ooooo`;o00007?ooool00ol0003oooooooooo`0Gooooo`;o
0000;Oooool2o`00077ooooo0009ooooo`Co000000?o410@ooooooooool05_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@0?ooooo`06onk^k_lb<S;o0000oc8b<_o^k^kooooo0_l00002ooooo`;o
8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Fooooo`03o`000?oooooooooo
01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q00Coooooo`000?l0003ooooo1Ol0
0004ooooo`05odA4A?l0003o0000oc8b<_oMgMd00oooool2o`0000[ooooo00Gok^k^o`000?l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o
0000oc8b<_oMgMd06?ooool4o`000003oa0@4?oooooooooo01;ooooo000;ooooo`03o`000?oooooo
oooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYoooo
o`07ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
2?ooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool2o`000003
ob4Q8Ooooooooooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo
01Gooooo00?o0000ooooooooool00_l0000Fooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@09ooooool0003o0000oooooonHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_oo
ool00_ooool2o`0000[ooooo00GoMgMgo`000?l0003oV9RHogMgM`05ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEE
ojVYZOooool01oooool00omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo0006o`00
00Gooooo00?o0000ooooooooool04?ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=
ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool01Oooool6o`0000;ooooo00Go410@
oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?oo
ooooooooooooool@41001?ooool2o`0000Kooooo00?oV9RHob4Q8Oo^k^h01oooool3o`0001Kooooo
00?o0000ooooooooool00_l0000Fooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP02ooooo`;o00001Oooool00ol0003oooooooooo`0=ooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol0003oooooooooo`0=ooooo`05oa0@4?ooooooooooooooool@41003Oooool0
0onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05?ooool0
00_ooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Q
ooooooooool01_ooool00omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003ooo
ool00omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000001?ooool2o`0000Kooooo
0_l000000olQ8B7ok^k^ooooo`05ooooo`;o000000?o<S8booooooooool05?ooool00ol0003ooooo
ooooo`0Hooooo`05o`000?ooooooooooooooool000003Oooool01?nHV9So8B4Qonk^k_ooool2o`00
00Cooooo00?oMgMgoc8b<_ooool03_ooool00ol0003oooooo`000002o`0000oooooo00?oMgMgoc8b
<_ooool03_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool0
0omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo
01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000<ooooo`;o000000?oMgMgofIV
I_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Kooooo00?o0000ooooooooool06?ooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00oooooo00?o0000ooooool000000_l0000<ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`03oooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<01[ooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000oooo
ooooool06?ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool0
0ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`0Aooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`03o`0001[ooooo
0ol00008ooooo`;o00003_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0
003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000oooo
ooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b
<P04ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`00
0?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`04o`000?nj^[[ooooooiRH
V0;o000000?oooooo`000?l000000_l0000Iooooo`03o`000?oooooooooo00Sooooo0_l0000>oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o
0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool0
4Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool05?ooool000Wooooo00?oEEEEofIVI_l0
00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00004?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01?nHV9So410@o`000?lQ8B42o`0000?ooooo1?l0000Gooooo`03o`000?oooooooooo01Sooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`00
013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00006Oooool00omEEEGoIVIVo`00000Fooooo`00POooool2
o`0002Wooooo00?o0000ooooooooool09Oooool2o`0009;ooooo0021ooooo`;o0000:Oooool00ol0
003oooooooooo`0Uooooo`;o0000T_ooool0087ooooo0_l000000ooooooo0000o`00000Vooooo`03
o`000?oooooooooo01kooooo0_l0000Iooooo`?o0000L_ooool2o`0000;ooooo0_l00005ooooo`00
Q?ooool2o`0002Kooooo00?o0000ooooooooool07_ooool2o`0001Wooooo0ol0000Kooooo`;o0000
EOooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Gooooo002/ooooo`03o`000?oooooooooo02Ko
oooo0_l0000_ooooo`;o0000E_ooool01?oMgMgo0000oa0@4?o<c<`6ooooo`001oooooooo`0004co
00003?ooool01?o^k^ko8B4Qoa0@4?o^k^h6ooooo`001oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01?l0003oooooo`000?l00004oooo
o`03o`000?oooooooooo00Gooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool02_ooool01?lQ8B7oMgMgogMgMolb<S86ooooo`001oooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool03oooool2o`0001Gooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Wooooo0_l00002oooo
o`;o00001Oooool008oooooo0_l0000Kooooo`03o`000?oooooooooo0;Wooooo0027ooooo`;o0000
1_ooool2o`0001_ooooo00?o0000ooooooooool0^Oooool008Oooooo0_l00002ooooo`;o00007ooo
ool00ol0003oooooooooo`18ooooo`;o0000Koooool008_ooooo0_l0000Oooooo`03o`000?oooooo
oooo00oooooo0_l0000=ooooo`;o0000:?ooool2o`0006oooooo002/ooooo`03o`000?oooooooooo
00oooooo0_l0000=ooooo`;o0000VOooool00:cooooo0ol0000Cooooo`;o00000oooool2o`00023o
oooo0_l0001mooooo`00[?ooool00ol0003oooooooooo`0Cooooo`;o00000oooool2o`0000Gooooo
0_l0000Iooooo`?o00002oooool2o`0006oooooo002Aooooo`;o00006Oooool00ol0003ooooooooo
o`0Oooooo`;o00006_ooool2o`0000_ooooo0_l0001_ooooo`00TOooool2o`0001Wooooo00?o0000
ooooooooool03_ooool2o`0004Kooooo0_l0001Qooooo`00[?ooool00ol0003oooooooooo`0>oooo
o`;o0000>?ooool2o`0000cooooo0_l0001Qooooo`00[?ooool00ol0003oooooooooo`05ooooo`;o
00003?ooool2o`0003?ooooo0_l0000=ooooo`;o0000H?ooool00:cooooo00?o0000ooooooooool0
1Oooool2o`0000Cooooo0_l00006ooooo`;o00009Oooool2o`0001_ooooo0_l0001Pooooo`00S_oo
ool2o`0001cooooo00?o0000ooooooooool02oooool2o`00027ooooo0_l0000:ooooo`;o0000OOoo
ool007kooooo0_l0000>ooooo`;o00007?ooool00ol0003oooooooooo`0>ooooo`;o00007_ooool2
o`0000Wooooo0_l0001nooooo`00O_ooool2o`0001?ooooo0_l0000Gooooo`?o00003_ooool2o`00
02Wooooo0_l0001nooooo`00Q?ooool2o`0000gooooo0_l0000Gooooo`03o`000?oooooooooo00_o
oooo0_l0002/ooooo`00Q?ooool2o`0002Kooooo00?o0000ooooooooool02oooool2o`00017ooooo
0_l00005ooooo`;o0000T_ooool00:cooooo00?o0000ooooooooool04oooool2o`0000?ooooo0_l0
0004ooooo`;o00001Oooool2o`0009;ooooo002Eooooo`;o00005Oooool00ol0003oooooooooo`0C
ooooo`;o00000oooool2o`0002_ooooo0_l0001booooo`00UOooool2o`0001Gooooo00?o0000oooo
ooooool01?ooool2o`0001kooooo0_l0000Oooooo`;o0000L_ooool008Oooooo0_l0000Sooooo`03
o`000?oooooooooo00Cooooo0_l0000<ooooo`;o00004?ooool2o`00023ooooo0ol0001`ooooo`00
Qoooool2o`0002?ooooo00?o0000ooooooooool04_ooool2o`0001[ooooo0_l00009ooooo`;o0000
2oooool3o`00073ooooo002/ooooo`?o0000;_ooool2o`0000Wooooo0_l0001nooooo`00Q?ooool2
o`00017ooooo0_l0000Cooooo`04o`000?ooooooooooooooo`;o00004oooool2o`000:7ooooo0024
ooooo`;o00004Oooool2o`0001?ooooo00Co0000oooooooooooooooo0_l0000Cooooo`;o0000XOoo
ool009Oooooo0_l000000ooooooo0000o`00000@ooooo`03o`000?oooooooooo03Wooooo0_l0001n
ooooo`00R?ooool2o`0000gooooo0_l000000ooooooo0000o`00000@ooooo`03o`000?oooooooooo
03Wooooo0_l00009ooooo`;o0000Loooool008Sooooo1?l0000Pooooo`03o`000?oooooooooo01co
oooo0_l0000Iooooo`;o00002oooool2o`0007?ooooo002:ooooo`;o00008?ooool00ol0003ooooo
ooooo`0Looooo`;o00006Oooool2o`0000cooooo0_l0001booooo`00[?ooool00ol0003ooooooooo
o`15ooooo`?o0000LOooool007kooooo0_l0000/ooooo`?o0000A_ooool2o`00077ooooo001noooo
o`;o0000;?ooool00ol0003oooooooooo`0gooooo`;o0000P?ooool008;ooooo0_l0000Xooooo`03
o`000?oooooooooo02_ooooo1?l00008ooooo`;o00002_ooool5o`00077ooooo0022ooooo`;o0000
:?ooool00ol0003oooooooooo`08ooooo`;o00008Oooool4o`0001Cooooo1Ol0001aooooo`00[?oo
ool00ol0003oooooooooo`08ooooo`;o0000>_ooool3o`0007;ooooo002/ooooo`03o`000?oooooo
oooo00Sooooo0_l00005ooooo`;o00006oooool2o`0001Cooooo1?l0001cooooo`00ROooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool03oooool2o`0000?ooooo0_l0000Fooooo`;o00005?oo
ool4o`0007?ooooo0025ooooo`;o00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01?ooool2o`000003oooooomgMgOo<S8b00Gooooo
00?o0000ooooooooool05?ooool2o`000:?ooooo0025ooooo`;o00000_ooool01Ol@413oooooo`00
0?l0003o410@00cooooo00?oV9RHob4Q8Oo^k^h01Oooool2o`0000;ooooo00?o0000ooooooooool0
0oooool3o`0002_ooooo0_l0002<ooooo`00ROooool00ol0003oooooo`000002o`0000;ooooo0_l0
0009ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`0[ooooo`;o0000S?ooool008Wooooo00Co0000oooooooooooooooo0_l000000ooooooo0000o`00
000:ooooo`04ogMgMomVIVKo0000o`0000;ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo00?ooooo0_l0000Uooooo`;o00005_ooool2o`0007Gooooo0029ooooo`04oa0@
4?ooooooooooooooo`;o00000oooool2o`0000Wooooo0ol00002ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool00oooool2o`0000Gooooo0_l0000Eooooo`;o00001oooool2o`0001Go
oooo0ol0001eooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo0_l00004ooooo`;o
000000Co^[ZjoooooonHV9So410@1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00[ooooo0_l0000Eooooo`;o00001oooool2o`0001Gooooo0_l0001fooooo`00ROooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00;ooooo0_l00006ooooo`;o000000Co410@o`000?lQ8B7oc<c<0_ooool6
o`0000Kooooo00?o0000ooooooooool0=Oooool2o`0000cooooo0_l0001dooooo`00T?ooool2o`00
00kooooo0_l0000:ooooo`03o`000?oooooooooo00gooooo0_l0000Aooooo`;o00004oooool2o`00
00cooooo0_l0001dooooo`00[?ooool00ol0003oooooooooo`0=ooooo`;o00002_ooool2o`0000Go
oooo0_l0000Booooo`;o0000Poooool00:cooooo00?o0000ooooooooool06Oooool2o`0001Wooooo
0_l0000:ooooo`;o0000Moooool009_ooooo0_l0000?ooooo`?o00009oooool2o`0001Oooooo0_l0
001gooooo`00Voooool2o`0000oooooo00?o0000ooooooooool01oooool2o`0000?ooooo0_l0000I
ooooo`;o0000T?ooool00:Kooooo0_l00002ooooo`?o00002Oooool2o`0000?ooooo0_l0000@oooo
o`;o0000VOooool00:Kooooo0_l00002ooooo`?o00008?ooool2o`0000Oooooo0_l0000Gooooo`;o
0000Moooool007cooooo0_l0000?ooooo`;o00007Oooool00ol0003oooooooooo`0Aooooo`;o0000
2_ooool2o`0000Sooooo0_l0000:ooooo`;o00002oooool2o`0007Oooooo001looooo`;o00003?oo
ool2o`000003ooooool0003o000001gooooo0_l0000<ooooo`;o00001?ooool2o`0000[ooooo0_l0
000Dooooo`;o0000Q?ooool0083ooooo0_l00008ooooo`;o00008?ooool2o`0000_ooooo0ol00012
ooooo`;o0000J?ooool0083ooooo0_l0000Yooooo`;o00003?ooool2o`0000Cooooo0_l0000;oooo
o`;o00008?ooool3o`0000gooooo0_l0001Xooooo`00Zoooool4o`00013ooooo0_l0000;ooooo`;o
00004Oooool3o`0000cooooo0ol0001gooooo`00[?ooool00ol0003oooooooooo`0?ooooo`;o0000
7oooool3o`0008Kooooo002/ooooo`?o00003oooool2o`000:Sooooo002Qooooo`;o00002Oooool3
o`000;Wooooo002:ooooo`;o00005Oooool2o`0000Gooooo0_l00002ooooo`03o`000?oooooooooo
03kooooo0_l0001iooooo`00R_ooool2o`0001cooooo0_l00002ooooo`03o`000?oooooooooo01Co
oooo0_l0000Xooooo`;o0000NOooool00:cooooo00?o0000ooooooooool05?ooool2o`0001Sooooo
0ol00028ooooo`00[?ooool00ol0003oooooooooo`0Jooooo`;o00004_ooool3o`0008Sooooo002F
ooooo`;o00003Oooool2o`0000Gooooo0ol0000Cooooo`;o00001Oooool2o`0009gooooo002Foooo
o`;o00001?ooool2o`0000Oooooo0_l00005ooooo`Co00002oooool2o`0000Gooooo0_l0002Toooo
o`00VOooool2o`000003ooooool0003o000000kooooo1?l0000;ooooo`;o0000Zoooool009Wooooo
0_l0000>ooooo`;o000000Coooooo`000?l0003o00001_ooool2o`000;7ooooo002Gooooo`;o0000
4?ooool2o`000005ooooool0003o0000o`000?ooool00_l00003ooooo`;o0000/Oooool008;ooooo
0_l0000Cooooo`;o00004oooool01?l0003oooooooooooooool2o`0001Kooooo0_l0002Nooooo`00
P_ooool2o`0002Sooooo00?o0000ooooooooool06Oooool2o`0009kooooo002Kooooo`;o00003ooo
ool00ol0003oooooooooo`19ooooo`;o0000K_ooool009_ooooo0_l0000?ooooo`?o0000BOooool2
o`0006kooooo002Eooooo`;o00005Oooool00ol0003oooooooooo`0Zooooo`;o00003Oooool2o`00
07kooooo0022ooooo`;o00003oooool4o`0001Gooooo00?o0000ooooooooool0:_ooool2o`0000go
oooo0_l0001nooooo`00P_ooool2o`0000oooooo0_l0000Gooooo`03o`000?oooooooooo02Wooooo
0_l0000=ooooo`;o00003_ooool2o`0006oooooo002=ooooo`;o00007Oooool00ol0003ooooooooo
o`0Yooooo`?o00003?ooool2o`0000kooooo0_l0001_ooooo`00SOooool2o`0000Sooooo0_l00006
ooooo`;o00002oooool00ol0003oooooooooo`02ooooo`;o00009_ooool2o`0000_ooooo0_l00020
ooooo`00R_ooool2o`0000Gooooo00Kok^k^oc8b<_l0003o<S8bonk^k_ooool2o`0000;ooooo0_lQ
8B42ooooo`;o000000KoooooodA4A?l0003o0000oc8b<_oMgMd5ooooo`03o`000?oooooooooo00;o
oooo0_l00008ooooo`;o0000:Oooool2o`00083ooooo002:ooooo`;o00001Oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool03?ooool2o`0001_ooooo0_l0000;ooooo`;o0000POooool0097ooooo00Co410@oooooooooooo
oooo0_l0000?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:Oooool2o`0000Wo
oooo1?l00021ooooo`00S_ooool2o`000003ooooool0003ooooo00;ooooo0_l0000>ooooo`03ogMg
Molb<S;ooooo00Cooooo0ol0000dooooo`Co0000POooool008kooooo0_l000000ooooooo0000oooo
o`02ooooo`03o`000?oooooooooo00[ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo01;ooooo0_l0002Uooooo`00TOooool01Ol@413ooooooooooooooooo410@00cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`;o0000YOooool0097ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
^Oooool008Oooooo0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`000003oooo
ool0003o000000?ooooo0ol0002iooooo`00Poooool2o`0000;ooooo0_l0000Nooooo`;o00000ooo
ool3o`0002Gooooo0_l0000Kooooo`;o0000MOooool008?ooooo0_l0000Pooooo`;o00001Oooool0
1?l0003oooooooooooooool2o`0002;ooooo0_l0000Kooooo`;o0000MOooool009_ooooo0_l00008
ooooo`;o00001Oooool01?l0003oooooooooooooool2o`000;Kooooo002Kooooo`;o00003oooool3
o`000;Wooooo002/ooooo`03o`000?oooooooooo02?ooooo0_l0002Dooooo`00WOooool2o`0000go
oooo00?o0000ooooooooool00_l0000<ooooo`;o00004oooool2o`0009Cooooo002Mooooo`?o0000
3?ooool00ol0003oooooooooo`02o`0000_ooooo0ol00006ooooo`;o0000XOooool009kooooo0_l0
000<ooooo`03o`000?oooooooooo00gooooo0_l00007ooooo`;o0000XOooool00:Cooooo0_l00006
ooooo`03o`000?oooooooooo02kooooo0_l00029ooooo`00V_ooool2o`0000Sooooo0_l00006oooo
o`03o`000?oooooooooo02cooooo1?l00029ooooo`00V_ooool2o`00013ooooo00?o0000oooooooo
ool0;?ooool2o`0000oooooo0_l0001jooooo`00U_ooool2o`0001Cooooo0ol0000[ooooo`;o0000
4?ooool2o`0007[ooooo002Fooooo`;o00005?ooool00ol0003oooooooooo`0Booooo`;o00005ooo
ool2o`0008cooooo002/ooooo`03o`000?oooooooooo00;ooooo0_l0000>ooooo`;o0000YOooool0
09gooooo0_l0000=ooooo`03o`000?oooooooooo00;ooooo0_l0002eooooo`00WOooool2o`0000go
oooo00?o0000ooooooooool02?ooool2o`000:oooooo002Wooooo`;o00000oooool00ol0003ooooo
ooooo`08ooooo`;o00004?ooool4o`0009_ooooo002Pooooo`;o00001?ooool3o`0000?ooooo00?o
0000ooooooooool03oooool2o`0000Wooooo1?l0002Kooooo`00X?ooool2o`0000Cooooo0_l00004
ooooo`03o`000?oooooooooo00oooooo0_l0002Xooooo`00[?ooool3o`0002Wooooo0_l0002>oooo
o`00[?ooool00ol0003oooooooooo`0Wooooo`Co0000S_ooool00:cooooo00?o0000ooooooooool0
3Oooool2o`0001Sooooo0_l0002@ooooo`00[?ooool00ol0003oooooooooo`0=ooooo`;o0000Z_oo
ool00:cooooo00?o0000ooooooooool00_ooool2o`000;Gooooo002Looooo`;o00003_ooool00ol0
003oooooooooo`02ooooo`;o0000]Oooool009Kooooo0_l00004ooooo`;o00003_ooool00ol0003o
ooooooooo`2iooooo`00U_ooool2o`0000Wooooo0_l00009ooooo`03o`000?oooooooooo0;Wooooo
002Qooooo`;o00002Oooool00ol0003oooooooooo`09ooooo`;o00006Oooool2o`0009?ooooo002T
ooooo`;o00001_ooool3o`0000Wooooo0_l0000Gooooo`Co0000Toooool008Sooooo0_l0000Joooo
o`;o00001_ooool00ol0003oooooooooo`0Rooooo`?o0000U?ooool008Sooooo0_l0000Rooooo`03
o`000?oooooooooo02?ooooo0_l0002Dooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o
8B4Qo`000?l000001Oooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1Oooool00ol0003oooooooooo`0Oooooo`;o0000V?ooool008Wooooo00GoMgMgo`000?l0003oV9RH
ogMgM`05ooooo`03ob4Q8Ol0003o000000Gooooo0_l00008ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool07oooool2o`0009Sooooo0029ooooo`05oa0@4?l0003o0000ooooool@4100
3Oooool2o`0000Wooooo00Co0000oooooooooooooooo0ol0002kooooo`00ROooool01Ol0003ooooo
oooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`02ooooo`Go
0000^Oooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05
oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0^Oooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00cooooo0_l0002[ooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00[ooooo1_l00004
ooooo`Co00001_ooool00ol0003oooooooooo`0<ooooo`;o0000Zoooool009Sooooo0_l0000Boooo
o`03o`000?oooooooooo00;o00002?ooool2o`000:gooooo002/ooooo`03o`000?oooooooooo00;o
00002?ooool2o`000:gooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Iooooo`;o00004Ooo
ool3o`0000[ooooo0_l0002]ooooo`00VOooool2o`00017ooooo00?o0000ooooooooool02_ooool2
o`000:gooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002E
ooooo`;o00002Oooool2o`0000[ooooo00?o0000ooooooooool00oooool2o`000;Cooooo0028oooo
o`;o00002oooool3o`0000Sooooo0_l0000:ooooo`03o`000?oooooooooo00?ooooo0_l0002doooo
o`00R?ooool2o`0000cooooo0_l0000Dooooo`?o00004?ooool2o`000:Oooooo002/ooooo`03o`00
0?oooooooooo013ooooo0_l0002Wooooo`00Uoooool2o`0001?ooooo00Co0000oooooooooooooooo
0_l0000<ooooo`;o0000Z?ooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo00?o00003?oo
ool2o`000:Sooooo002Iooooo`;o00004Oooool00ol0003oooooooooo`02o`000;Oooooo002Hoooo
o`?o00004Oooool00ol0003oooooooooo`2iooooo`00V?ooool2o`0001;ooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool02_ooool2o`000:gooooo002/ooooo`03o`000?oo
oooooooo00[ooooo0_l0002]ooooo`00ZOooool2o`000004ooooool0003o0000o`0000Wooooo0_l0
002^ooooo`00Xoooool2o`0000Cooooo0_l000000ooooooo0000ooooo`0:ooooo`;o0000[_ooool0
0:?ooooo0_l00003ooooo`;o00000_ooool00ol0003oooooooooo`2iooooo`00Z?ooool2o`0000;o
oooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o
0000ooooooooool01?ooool2o`000;?ooooo002=ooooo`;o00007Oooool00ol0003oooooooooo`04
ooooo`;o0000/oooool008gooooo0_l0000Mooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o
0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Ooo
ool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool0^Oooool00:;ooooo1?l000000ol@413oooooooooo`03ooooo`03o`00
0?oooooooooo0;Wooooo002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Ooo
ool00:Cooooo00?o0000ooooooooool01Oooool3o`000;Wooooo002Tooooo`03o`000?oooooooooo
0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo
002Tooooo`03o`000?oooooooooo0<7ooooo002Rooooo`03oeEEEOmVIVKo00000<?ooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Zooooo`04oa0@4?l0003o
0000o`000;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo
0;[ooooo002[ooooo`06o`000?mgMgOo0000o`000?mEEEGok^k^]oooool00:_ooooo00Ko0000oeEE
EOo^k^koooooogMgMomEEEFgooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooo
oooo0;Gooooo002[ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0]Oooool00:_o
oooo00Ko0000oeEEEOo^k^koooooogMgMomVIVJgooooo`00Z_ooool00ol@413o0000ogMgM`02o`00
0003ofIVI_o^k^kooooo0;Kooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.45606 .1113 Mdot
.65162 .43141 Mdot
.44461 .50694 Mdot
.41934 .54457 Mdot
.58723 .47159 Mdot
.57111 .75315 Mdot
.43622 .49776 Mdot
.70018 .32753 Mdot
.40946 .12919 Mdot
.41328 .53055 Mdot
.53795 .32438 Mdot
.72262 .4159 Mdot
.51278 .89607 Mdot
.49841 .23428 Mdot
.7159 .40724 Mdot
.55306 .43397 Mdot
.47767 .85339 Mdot
.49341 .91968 Mdot
.40876 .56716 Mdot
.67722 .38507 Mdot
.50711 .89967 Mdot
.6513 .58408 Mdot
.64034 .6297 Mdot
.46474 .92526 Mdot
.72265 .59494 Mdot
.43596 .21232 Mdot
.56737 .45429 Mdot
.42878 .71736 Mdot
.68725 .44018 Mdot
.6503 .43358 Mdot
.46661 .92012 Mdot
.42229 .08742 Mdot
.64111 .21407 Mdot
.39936 .3828 Mdot
.56693 .26084 Mdot
.57378 .17597 Mdot
.5953 .8221 Mdot
.51855 .73587 Mdot
.6875 .47466 Mdot
.73271 .47247 Mdot
.71996 .62633 Mdot
.48784 .13975 Mdot
.62852 .49543 Mdot
.52991 .15276 Mdot
.40886 .2335 Mdot
.51829 .77481 Mdot
.44577 .25303 Mdot
.36928 .50863 Mdot
.60404 .44404 Mdot
.67498 .39206 Mdot
.3716 .59121 Mdot
.6814 .61405 Mdot
.77754 .56599 Mdot
.60713 .36666 Mdot
.624 .43208 Mdot
.53154 .07031 Mdot
.70268 .33711 Mdot
.47265 .85511 Mdot
.45061 .95427 Mdot
.39162 .36407 Mdot
.49433 .81435 Mdot
.43655 .98271 Mdot
.68641 .47682 Mdot
.48318 .26396 Mdot
.60486 .16521 Mdot
.48655 .02486 Mdot
.42192 .63989 Mdot
.52733 .33401 Mdot
.49883 .77772 Mdot
.42629 .86842 Mdot
.40334 .66852 Mdot
.51392 .59274 Mdot
.41371 .53151 Mdot
.48261 .77062 Mdot
.6863 .47581 Mdot
.50688 .54569 Mdot
.77745 .56659 Mdot
.43752 .77846 Mdot
.68881 .56806 Mdot
.55681 .29157 Mdot
.38806 .31909 Mdot
.64462 .40661 Mdot
.45035 .72346 Mdot
.51343 .1706 Mdot
.64777 .22107 Mdot
.55985 .51235 Mdot
.58864 .50262 Mdot
.58287 .57044 Mdot
.51126 .81989 Mdot
.53163 .34767 Mdot
.72107 .59973 Mdot
.6646 .18024 Mdot
.54789 .50147 Mdot
.56129 .67378 Mdot
.53844 .4111 Mdot
.6352 .13711 Mdot
.48492 .21865 Mdot
.375 .63914 Mdot
.77384 .59781 Mdot
.48585 .85483 Mdot
.50358 .12167 Mdot
.55803 .73394 Mdot
.71625 .39516 Mdot
.56259 .20258 Mdot
.3788 .49641 Mdot
.41577 .25696 Mdot
.39475 .54525 Mdot
.42191 .30553 Mdot
.54795 .51015 Mdot
.42656 .86796 Mdot
.44061 .26298 Mdot
.41967 .55865 Mdot
.40935 .12773 Mdot
.62371 .25297 Mdot
.59664 .94722 Mdot
.46543 .70655 Mdot
.4598 .81909 Mdot
.55837 .09629 Mdot
.50414 .0371 Mdot
.62212 .76995 Mdot
.52113 .88415 Mdot
.52101 .97668 Mdot
.58608 .773 Mdot
.69102 .46422 Mdot
.42161 .85493 Mdot
.423 .39864 Mdot
.64089 .29009 Mdot
.56762 .05692 Mdot
.58673 .2526 Mdot
.44493 .33391 Mdot
.63766 .64701 Mdot
.55265 .19144 Mdot
.7299 .47338 Mdot
.54747 .80002 Mdot
.62354 .58477 Mdot
.6927 .53619 Mdot
.60359 .81343 Mdot
.67164 .37287 Mdot
.4163 .58206 Mdot
.66509 .25962 Mdot
.72175 .43248 Mdot
.3611 .56534 Mdot
.49373 .73658 Mdot
.44729 .77416 Mdot
.47335 .85402 Mdot
.65743 .32489 Mdot
.61622 .17188 Mdot
.41506 .36222 Mdot
.57289 .6273 Mdot
.5492 .94824 Mdot
.57074 .70466 Mdot
.55182 .65138 Mdot
.44917 .91321 Mdot
.52083 .53583 Mdot
.49603 .87365 Mdot
.64286 .73428 Mdot
.68905 .52601 Mdot
.54504 .08236 Mdot
.60006 .81279 Mdot
.63469 .75306 Mdot
.53723 .24231 Mdot
.68837 .57997 Mdot
.71885 .64846 Mdot
.49784 .07894 Mdot
.62402 .45767 Mdot
.46634 .1061 Mdot
.60139 .15166 Mdot
.3914 .28215 Mdot
.51603 .74345 Mdot
.63393 .75814 Mdot
.64353 .30277 Mdot
.54592 .50747 Mdot
.55306 .64074 Mdot
.58637 .47786 Mdot
.44943 .2173 Mdot
.63409 .20591 Mdot
.61359 .11003 Mdot
.51203 .85089 Mdot
.49858 .67666 Mdot
.6866 .44686 Mdot
.65953 .69896 Mdot
.73384 .52611 Mdot
.53231 .66984 Mdot
.71428 .65009 Mdot
.53108 .43018 Mdot
.38758 .2388 Mdot
.55153 .04091 Mdot
.4287 .06965 Mdot
.72441 .62292 Mdot
.62756 .55545 Mdot
.58154 .9052 Mdot
.65876 .32765 Mdot
.42553 .42351 Mdot
.67352 .26832 Mdot
.67885 .75162 Mdot
.72412 .43069 Mdot
.57538 .6218 Mdot
.73121 .29465 Mdot
.43255 .18652 Mdot
.5279 .49379 Mdot
.52775 .52193 Mdot
.50188 .64517 Mdot
.57895 .41705 Mdot
.74867 .33875 Mdot
.51595 .13946 Mdot
.49662 .7045 Mdot
.54368 .80364 Mdot
.41814 .53398 Mdot
.5277 .60599 Mdot
.553 .36917 Mdot
.59066 .77525 Mdot
.44856 .80267 Mdot
.39269 .27268 Mdot
.55372 .57133 Mdot
.47873 .10435 Mdot
.48605 .8189 Mdot
.71709 .65304 Mdot
.53713 .48129 Mdot
.39366 .64489 Mdot
.72923 .43846 Mdot
.46938 .82527 Mdot
.45119 .95241 Mdot
.38246 .37474 Mdot
.41308 .17161 Mdot
.55412 .45443 Mdot
.55388 .32343 Mdot
.64818 .40532 Mdot
.5466 .50418 Mdot
.71771 .4149 Mdot
.5236 .31961 Mdot
.51391 .47452 Mdot
.74439 .33275 Mdot
.60524 .54322 Mdot
.5698 .46931 Mdot
.55698 .93485 Mdot
.53663 .69271 Mdot
.58736 .24522 Mdot
.57838 .79096 Mdot
.53862 .16989 Mdot
.44201 .98981 Mdot
.60379 .67432 Mdot
.46033 .06821 Mdot
.40453 .67797 Mdot
.44512 .04138 Mdot
.52029 .34333 Mdot
.66028 .68356 Mdot
.57641 .67711 Mdot
.40854 .70619 Mdot
.68819 .4938 Mdot
.68974 .72544 Mdot
.4735 .71007 Mdot
.42337 .48014 Mdot
.64665 .71819 Mdot
.43062 .23137 Mdot
.55979 .61147 Mdot
.63186 .51363 Mdot
.49949 .59956 Mdot
.68644 .2997 Mdot
.38824 .76616 Mdot
.60744 .49851 Mdot
.56972 .46754 Mdot
.44292 .09337 Mdot
.42859 .54091 Mdot
.5835 .66538 Mdot
.40678 .25003 Mdot
.46042 .22869 Mdot
.61144 .63659 Mdot
.606 .22818 Mdot
.47963 .16602 Mdot
.60951 .23048 Mdot
.62937 .47416 Mdot
.41258 .50541 Mdot
.59162 .39005 Mdot
.64482 .73116 Mdot
.51601 .71501 Mdot
.51879 .2427 Mdot
.36959 .48033 Mdot
.55107 .3599 Mdot
.5083 .85806 Mdot
.6912 .49297 Mdot
.48621 .28612 Mdot
.52963 .67289 Mdot
.6039 .80536 Mdot
.70984 .3689 Mdot
.43131 .26214 Mdot
.50554 .37788 Mdot
.52113 .25451 Mdot
.59403 .19959 Mdot
.55587 .68661 Mdot
.3796 .50785 Mdot
.54612 .03584 Mdot
.48573 .96199 Mdot
.70495 .36235 Mdot
.49478 .95383 Mdot
.46925 .66974 Mdot
.49433 .95874 Mdot
.54574 .94409 Mdot
.55289 .1395 Mdot
.71149 .38817 Mdot
.37272 .83124 Mdot
.58399 .35882 Mdot
.62145 .61342 Mdot
.57118 .22055 Mdot
.43705 .05454 Mdot
.72491 .59085 Mdot
.47562 .21848 Mdot
.37043 .55074 Mdot
.45392 .17813 Mdot
.50052 .33893 Mdot
.60252 .74929 Mdot
.44766 .83354 Mdot
.54694 .84634 Mdot
.57803 .91294 Mdot
.45173 .6831 Mdot
.38727 .50766 Mdot
.43416 .18841 Mdot
.62902 .20147 Mdot
.42838 .45098 Mdot
.73306 .53358 Mdot
.64333 .80882 Mdot
.3824 .18715 Mdot
.47571 .24237 Mdot
.53373 .82426 Mdot
.52913 .19348 Mdot
.68747 .53372 Mdot
.56712 .3601 Mdot
.52795 .47254 Mdot
.44697 .61815 Mdot
.405 .67781 Mdot
.72097 .3957 Mdot
.65585 .69126 Mdot
.53843 .4093 Mdot
.62643 .69145 Mdot
.46293 .29118 Mdot
.50028 .65038 Mdot
.6502 .41616 Mdot
.58122 .73229 Mdot
.6246 .4626 Mdot
.53549 .23943 Mdot
.57059 .38017 Mdot
.78096 .52028 Mdot
.43934 .2076 Mdot
.62654 .34458 Mdot
.4782 .26294 Mdot
.59329 .14521 Mdot
.56137 .41436 Mdot
.66328 .34705 Mdot
.65177 .46018 Mdot
.52981 .64132 Mdot
.54351 .71402 Mdot
.36138 .57664 Mdot
.72292 .41326 Mdot
.48937 .9638 Mdot
.5944 .20717 Mdot
.57477 .3286 Mdot
.40998 .28167 Mdot
.63882 .29063 Mdot
.59774 .6067 Mdot
.72169 .40872 Mdot
.41074 .06403 Mdot
.47567 .06265 Mdot
.72838 .46182 Mdot
.73233 .54602 Mdot
.71193 .66553 Mdot
.45883 .67654 Mdot
.60603 .49047 Mdot
.72138 .43307 Mdot
.69388 .31557 Mdot
.44656 .64353 Mdot
.39011 .693 Mdot
.42446 .25931 Mdot
.52913 .82899 Mdot
.48725 .10533 Mdot
.37012 .51151 Mdot
.58234 .23641 Mdot
.55419 .8838 Mdot
.67673 .61513 Mdot
.64543 .60426 Mdot
.52008 .9314 Mdot
.64384 .61911 Mdot
.72807 .54704 Mdot
.59679 .8149 Mdot
.46058 .88271 Mdot
.51902 .45862 Mdot
.67753 .74473 Mdot
.51866 .80885 Mdot
.45495 .64625 Mdot
.73365 .54956 Mdot
.41947 .84886 Mdot
.52772 .46523 Mdot
.45912 .76417 Mdot
.40088 .47949 Mdot
.57111 .50933 Mdot
.37237 .38014 Mdot
.40171 .21234 Mdot
.50996 .98489 Mdot
.73347 .53894 Mdot
.3983 .60211 Mdot
.77676 .46929 Mdot
.39665 .41362 Mdot
.44333 .2297 Mdot
.49887 .20991 Mdot
.46351 .34826 Mdot
.71355 .3708 Mdot
.72045 .40634 Mdot
.56613 .44316 Mdot
.53883 .59747 Mdot
.5725 .54014 Mdot
.55326 .58649 Mdot
.63199 .83608 Mdot
.56642 .65968 Mdot
.50344 .08414 Mdot
.48267 .74746 Mdot
.54915 .65931 Mdot
.43097 .41706 Mdot
.5834 .58226 Mdot
.39523 .50645 Mdot
.56913 .56394 Mdot
.47866 .7267 Mdot
.53592 .96166 Mdot
.66361 .25617 Mdot
.50295 .49848 Mdot
.5837 .29666 Mdot
.39484 .54725 Mdot
.45246 .87204 Mdot
.44926 .1893 Mdot
.53969 .68556 Mdot
.66831 .76641 Mdot
.67974 .19843 Mdot
.5967 .26533 Mdot
.6744 .8438 Mdot
.55863 .19436 Mdot
.44042 .67135 Mdot
.42518 .08444 Mdot
.7232 .44714 Mdot
.54244 .33896 Mdot
.65002 .45149 Mdot
.78037 .53191 Mdot
.53293 .62461 Mdot
.51039 .36784 Mdot
.47375 .19464 Mdot
.44267 .09292 Mdot
.53605 .247 Mdot
.70478 .24373 Mdot
.53701 .51342 Mdot
.57707 .28616 Mdot
.48812 .13868 Mdot
.52539 .35574 Mdot
.4651 .70378 Mdot
.49043 .76531 Mdot
.69973 .32714 Mdot
.42938 .56374 Mdot
.69134 .54547 Mdot
.63917 .37402 Mdot
.39568 .32488 Mdot
.62652 .26082 Mdot
.39136 .70113 Mdot
.41386 .72979 Mdot
.58091 .06926 Mdot
.44471 .73872 Mdot
.72356 .40642 Mdot
.68881 .72919 Mdot
.45753 .233 Mdot
.49021 .96258 Mdot
.46382 .17089 Mdot
.52641 .78882 Mdot
.66201 .34253 Mdot
.51119 .13092 Mdot
.4071 .48835 Mdot
.53904 .72506 Mdot
.40051 .36608 Mdot
.42061 .95429 Mdot
.62588 .55383 Mdot
.50835 .53081 Mdot
.62285 .44118 Mdot
.56785 .31707 Mdot
.46104 .68129 Mdot
.48571 .24768 Mdot
.60431 .35621 Mdot
.62497 .58158 Mdot
.5123 .6332 Mdot
.40676 .37034 Mdot
.49197 .02802 Mdot
.58706 .46263 Mdot
.39095 .38578 Mdot
.4593 .79354 Mdot
.44322 .76083 Mdot
.43244 .45937 Mdot
.61094 .93149 Mdot
.4356 .41743 Mdot
.65094 .42363 Mdot
.45964 .95749 Mdot
.51454 .09782 Mdot
.47905 .79787 Mdot
.6791 .4032 Mdot
.73265 .48712 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002Wooooo`;o00000oooool3o`000;Wooooo002Wooooo`Co000000?ooooo
o`000?ooool0^_ooool00:Wooooo0_l000000ooooooo0000ooooo`2jooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool3o`0000cooooo0_l0002[ooooo`00[?ooool3o`0000cooooo1?l0
002Yooooo`00VOooool2o`00017ooooo00?o0000ooooooooool03_ooool2o`000:Wooooo002Ioooo
o`;o00004Oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
[?ooool3o`000;Wooooo002Gooooo`;o00004oooool00ol0003oooooooooo`2iooooo`00Uoooool2
o`0001?ooooo00?o0000ooooooooool04oooool2o`000:Cooooo002/ooooo`03o`000?oooooooooo
01?ooooo0_l0002Tooooo`00S_ooool2o`0001Cooooo0_l00006ooooo`03o`000?oooooooooo0;Wo
oooo002>ooooo`;o00003_ooool2o`0000Cooooo0_l00006ooooo`03o`000?oooooooooo0;Wooooo
002Dooooo`;o00002?ooool2o`0000cooooo00?o0000ooooooooool01oooool2o`0000kooooo0_l0
002Pooooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool01oooool2o`0000kooooo0_l0002P
ooooo`00[?ooool3o`000;Wooooo002[ooooo`;o0000^oooool00:_ooooo0_l0000=ooooo`;o0000
[?ooool009?ooooo0_l0000Gooooo`?o00002oooool2o`000:cooooo002Booooo`?o00005oooool3
o`000;Wooooo002Booooo`;o00006?ooool00ol0003oooooooooo`2iooooo`00VOooool2o`00017o
oooo00?o0000ooooooooool0^Oooool009Wooooo0_l0000Aooooo`04o`000?ooooooooooooooo`;o
00003Oooool2o`000:Oooooo002/ooooo`?o000000?oooooo`000?l000003Oooool2o`000:Oooooo
002Uooooo`;o00001Oooool00ol0003oooooooooo`2iooooo`00X?ooool2o`0000?ooooo1?l00003
ooooo`03o`000?oooooooooo0;Wooooo002Pooooo`;o00001Oooool2o`0000?ooooo00?o0000oooo
ooooool08_ooool2o`0009Gooooo002Mooooo`;o00003Oooool00ol0003oooooooooo`0Rooooo`;o
0000UOooool009gooooo0_l0000=ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000
o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0^Oooool008Wooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Co
oooo0ol0002iooooo`00POooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03
ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000;Wooooo0029ooooo`04o`00
0?ooooooooooooooo`?o00003?ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0^Oooool008Wooooo00Co0000oooooooooooooooo0ol0000<ooooo`03
oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo
00;o0000]oooool008Wooooo00Go410@oooooooooooooooooa0@4002o`0000cooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;o0000]oooool008Wo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Wooooo0_l0002>ooooo`00ROooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00000_ooool2o`0000;ooooo00?o0000
ooooooooool00_ooool2o`0000[ooooo0_l0000Iooooo`;o0000S_ooool00:Sooooo0_l00002oooo
o`03o`000?oooooooooo00;ooooo0_l0000:ooooo`;o0000ZOooool00:cooooo00?o0000oooooooo
ool06oooool2o`0009cooooo002/ooooo`03o`000?oooooooooo01_ooooo0_l0002Looooo`00[?oo
ool3o`0000Kooooo0_l0000Fooooo`;o0000VOooool00:cooooo00?o0000ooooooooool01_ooool2
o`0001Kooooo0_l0002Iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0Oooooo`;o0000V?ooool00:Gooooo0_l0
0005ooooo`03o`000?oooooooooo01oooooo0_l0002Hooooo`00X?ooool2o`0000?ooooo0_l00005
ooooo`04o`000?ooooooooooooooo`;o00001_ooool2o`000:kooooo002?ooooo`;o00003oooool2
o`0000[ooooo00Co0000oooooooooooooooo0_l00006ooooo`;o00006?ooool2o`0009Cooooo002?
ooooo`;o00006oooool3o`0001Gooooo0_l0000<ooooo`;o0000U?ooool009cooooo0_l0000>oooo
o`03o`000?oooooooooo01Gooooo0_l0000Looooo`;o0000Q?ooool009cooooo0_l0000>ooooo`03
o`000?oooooooooo03?ooooo0_l00024ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00QOoo
ool2o`0000kooooo0ol00003ooooo`;o00003oooool00ol0003oooooooooo`2iooooo`00QOooool2
o`0000kooooo0ol00003ooooo`;o00003oooool00ol0003oooooooooo`0>ooooo`;o0000ZOooool0
0:?ooooo0_l00007ooooo`03o`000?oooooooooo00Kooooo0_l00006ooooo`Co0000Yoooool00:?o
oooo0_l00007ooooo`03o`000?oooooooooo00Kooooo0_l00008ooooo`;o00009_ooool2o`0007oo
oooo002/ooooo`?o00007?ooool2o`0000Wooooo0_l0000?ooooo`;o0000Ooooool00:cooooo00?o
0000ooooooooool04Oooool2o`0000Wooooo0_l00009ooooo`;o0000T?ooool009Sooooo0_l0000B
ooooo`03o`000?oooooooooo017ooooo0_l00009ooooo`;o00002oooool2o`0008kooooo002Hoooo
o`;o00004Oooool2o`0001kooooo0_l0000;ooooo`;o0000S_ooool008_ooooo0_l00009ooooo`;o
00004oooool2o`000;_ooooo002;ooooo`;o00002Oooool2o`0001Cooooo00?o0000ooooooooool0
:oooool2o`0008cooooo002Kooooo`;o00001oooool2o`000003ooooool0003o000000?ooooo00?o
0000ooooooooool0:oooool2o`0008cooooo002Kooooo`;o00001oooool2o`000003ooooool0003o
000000?ooooo00?o0000ooooooooool05?ooool2o`0001Oooooo0_l0002:ooooo`00[?ooool3o`00
01Cooooo0_l0000Gooooo`;o0000R_ooool009kooooo0_l0000<ooooo`03o`000?oooooooooo023o
oooo0_l0002Gooooo`00UOooool2o`0000;ooooo0_l00003ooooo`;o00003?ooool00ol0003ooooo
ooooo`0Pooooo`?o0000U_ooool008gooooo0_l00006ooooo`;o00000_ooool2o`0000?ooooo0_l0
000;ooooo`;o00008oooool2o`0009Kooooo002=ooooo`;o00003oooool2o`0000_ooooo0_l0000J
ooooo`;o0000Woooool008Kooooo0_l0000Tooooo`03o`000?oooooooooo00Sooooo0_l0000>oooo
o`;o0000Woooool008Kooooo0_l00009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o0000omgMg@05ooooo`03o`000?oooooooooo00?ooooo0_l00003
ooooo`?o0000=Oooool2o`0007Oooooo002Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Oooooo0_l000000olb<S;oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l00003
ooooo`?o00003_ooool2o`0002Gooooo0_l0001gooooo`00ROooool6o`0000;ooooo00Go410@oooo
oooooooooooooa0@400@ooooo`?o00000oooool00ol0003oooooooooo`08ooooo`;o00003oooool2
o`0009kooooo002=ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000Cooooo0_l00009
ooooo`04ogMgMolb<S;o0000o`0000?ooooo0ol0000Iooooo`;o00002_ooool2o`0009;ooooo002A
ooooo`05o`000?ooooooooooooooool000001?ooool2o`0000Kooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`03o`000?oooooooooo00Cooooo0_l0000Cooooo`;o00002_ooool2o`0009;ooooo
002@ooooo`;o00000oooool00ol@413oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01?ooool2o`0002gooooo0_l00024ooooo`00T?ooool2o`000003oiRHV?l0003o
000000;o00002oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01?ooooo0_l0000A
ooooo`;o00002oooool2o`0008Cooooo002Aooooo`03onk^k_lb<S;o000000?o000000?oooooo`00
0?l000002?ooool6o`0000Cooooo00?o0000ooooooooool04oooool2o`00017ooooo0_l0000;oooo
o`;o0000Q?ooool009Sooooo0_l0000:ooooo`Co00001?ooool00ol0003oooooooooo`0Looooo`;o
0000Voooool00:cooooo00?o0000ooooooooool07?ooool2o`0001Sooooo0_l00021ooooo`00R?oo
ool2o`0002;ooooo00?o0000ooooooooool0=_ooool2o`00087ooooo0028ooooo`;o00008_ooool3
o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo0028ooooo`;o00001?ooool2o`0001co
oooo00?o0000ooooooooool0^Oooool008Sooooo0_l00004ooooo`;o00005oooool2o`0000?ooooo
00?o0000ooooooooool05_ooool2o`000:7ooooo002Wooooo`;o00000oooool00ol0003ooooooooo
o`0Fooooo`;o0000XOooool009oooooo0_l0000;ooooo`03o`000?oooooooooo00oooooo0_l0000I
ooooo`?o0000S?ooool009oooooo0_l0000;ooooo`03o`000?oooooooooo00oooooo0_l0000Ioooo
o`?o00007?ooool2o`0006kooooo002/ooooo`03o`000?oooooooooo01Sooooo0_l0000_ooooo`;o
0000K_ooool00:cooooo0ol0000Hooooo`;o00008?ooool2o`0007gooooo002/ooooo`03o`000?oo
oooooooo02cooooo0_l0000<ooooo`;o0000OOooool009;ooooo0_l0000Hooooo`03o`000?oooooo
oooo02cooooo0_l0002;ooooo`00T_ooool2o`0001Sooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0?Oooool2o`0007[ooooo
0027ooooo`;o00008oooool00ol0003oooooooooo`04ooooo`;o00003Oooool2o`0002Sooooo0_l0
001jooooo`00Qoooool2o`0002?ooooo00?o0000ooooooooool01?ooool2o`0000gooooo0_l0002T
ooooo`00ROooool2o`00027ooooo0ol00009ooooo`;o00000oooool2o`00027ooooo0_l00026oooo
o`00ROooool2o`00027ooooo00?o0000ooooooooool02Oooool2o`0000?ooooo0_l00005ooooo`;o
00006_ooool2o`0000_ooooo0ol0001hooooo`00[?ooool00ol0003oooooooooo`0Eooooo`;o0000
6_ooool2o`0000_ooooo0ol0001hooooo`00VOooool2o`00017ooooo00?o0000ooooooooool01_oo
ool2o`0004Gooooo0_l0001Zooooo`00VOooool2o`00017ooooo00?o0000ooooooooool01_ooool2
o`0003Oooooo0_l0000<ooooo`;o0000J_ooool00:cooooo0_l0000<ooooo`;o0000<_ooool2o`00
00kooooo0_l0001Xooooo`00[?ooool2o`0000Cooooo0_l00006ooooo`;o00009Oooool2o`0001_o
oooo0_l0001Xooooo`00[?ooool00ol0003oooooooooo`03ooooo`;o00008Oooool2o`0000[ooooo
0_l00025ooooo`00X?ooool2o`0000[ooooo00?o0000ooooooooool01oooool2o`0001gooooo0_l0
000:ooooo`;o0000QOooool00:3ooooo0_l0000:ooooo`?o00001oooool2o`0002Wooooo0_l00025
ooooo`00[?ooool00ol0003oooooooooo`05ooooo`;o0000/_ooool00:cooooo00?o0000oooooooo
ool01Oooool2o`00017ooooo0_l00005ooooo`;o0000V?ooool00:cooooo00?o0000ooooooooool0
3Oooool2o`0000Cooooo0_l00003ooooo`;o00001Oooool2o`0009Sooooo0028ooooo`;o00001_oo
ool2o`0001[ooooo00?o0000ooooooooool03Oooool2o`0000Cooooo0_l0000[ooooo`;o0000Mooo
ool008Sooooo0_l000001?lb<S;o0000o`000?o^k^h2ooooo`;o000000?oooooob4Q8OlQ8B401?oo
ool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00;o0000
7_ooool2o`0001kooooo0_l0001gooooo`00ROooool00omgMgOoV9RHo`000003o`0000Cooooo0_lQ
8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo00;o00003?ooool2o`00013ooooo0_l0000Pooooo`?o0000M?ooool0087ooooo1_l0
0002ooooo`04oa0@4?ooooooooooooooo`;o00002oooool00onHV9So8B4Qonk^kP09ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool03_ooool2o`0001_ooooo0_l00008ooooo`;o0000
2oooool3o`0007Cooooo0025ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000gooooo
00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000:oooool2o`0000Sooooo
0_l00022ooooo`00POooool2o`0000;ooooo0_l00002ooooo`05o`000?ooooooooooooooool00000
3_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool3o`0001Co
oooo0_l0002Sooooo`00POooool2o`0000Kooooo00Go410@o`000?l0003ooooooa0@400?ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool3o`0001Cooooo0_l0002Sooooo`00
R?ooool4o`000003oiRHV?mgMgOooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0=oooool2o`00083ooooo0028ooooo`;o0000
00Co<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006oooo
o`03o`000?oooooooooo03Oooooo0_l00009ooooo`;o0000MOooool00:cooooo00?o0000oooooooo
ool06oooool2o`0001Wooooo0_l0000:ooooo`;o0000MOooool00:cooooo00?o0000ooooooooool0
6oooool2o`0001Wooooo0_l0000<ooooo`;o0000Loooool00:cooooo00?o0000ooooooooool0A?oo
ool4o`00077ooooo002Booooo`;o00006?ooool3o`0004Kooooo0_l0001aooooo`00T_ooool2o`00
01Sooooo00?o0000ooooooooool0>?ooool2o`0007oooooo002/ooooo`03o`000?oooooooooo02co
oooo0ol00009ooooo`;o00002_ooool4o`00077ooooo002/ooooo`03o`000?oooooooooo00Wooooo
0_l0000Qooooo`?o00005Oooool4o`00077ooooo0029ooooo`;o00008Oooool00ol0003ooooooooo
o`09ooooo`;o0000>oooool2o`00077ooooo0029ooooo`;o00008Oooool00ol0003oooooooooo`09
ooooo`;o00001_ooool2o`0001_ooooo0_l0000Dooooo`Co0000LOooool009Gooooo0ol0000Doooo
o`03o`000?oooooooooo017ooooo0_l00004ooooo`;o00005Oooool2o`0001Cooooo1?l0001aoooo
o`00UOooool3o`0001Cooooo00?o0000ooooooooool05oooool2o`000:3ooooo002Cooooo`;o0000
5oooool3o`0002kooooo0_l00029ooooo`00Toooool2o`0001Oooooo00?o0000ooooooooool0;_oo
ool2o`0008Wooooo002/ooooo`03o`000?oooooooooo00Oooooo0_l0000Vooooo`;o00005_ooool2
o`00073ooooo002/ooooo`03o`000?oooooooooo00Oooooo0_l00005ooooo`;o00005Oooool2o`00
00Oooooo0ol0000Eooooo`?o0000L?ooool00:cooooo00?o0000ooooooooool03_ooool2o`0001Go
oooo0_l00007ooooo`;o00005_ooool2o`00077ooooo002/ooooo`03o`000?oooooooooo03[ooooo
0_l0000<ooooo`;o0000Koooool00:cooooo00?o0000ooooooooool04_ooool2o`00017ooooo0_l0
000Cooooo`;o00003?ooool2o`0006oooooo002/ooooo`03o`000?oooooooooo01;ooooo0_l0000;
ooooo`;o00001?ooool2o`0001?ooooo0_l0001mooooo`00[?ooool00ol0003oooooooooo`0Ooooo
o`;o00006Oooool2o`0000[ooooo0_l0001aooooo`00U?ooool2o`0001Kooooo0ol0000^ooooo`;o
00005_ooool2o`00077ooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`0>ooooo`;o0000
0oooool2o`0001Wooooo0_l00029ooooo`00[?ooool00ol0003oooooooooo`03ooooo`;o00002Ooo
ool2o`0000?ooooo0_l0000Aooooo`;o0000TOooool000Wooooo1?l000000ol@413oooooooooo`0F
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool5o`0000Cooooo00CoA4A4o`000?l0003o<S8b0_l0000Eooooo`03o`000?oo
oooooooo00?ooooo0_l0000Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@;ooooo
1ol00002ooooo`;o000000GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`03onk^k_lb<S;o000000;o
00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb
<S;ogMgM01Sooooo1?l000000ol@413oooooooooo`0Booooo`002oooool00ol0003oooooooooo`0H
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01ooo
ool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo0000o`00000Eooooo`03o`000?oooooooooo
01Sooooo00GoMgMgo`000?l0003oV9RHogMgM`05ooooo`;o8B4Q0_ooool2o`000005oiRHV?lQ8B7o
k^k^oooooom4A4@00_ooool2o`0000?ooooo00?oMgMgoc8b<_ooool01Oooool2o`0000Oooooo00?o
MgMgoiRHV?ooool00_l00005ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8b
ooooo`0Iooooo`03o`000?oooooooooo01Cooooo0006o`0000Gooooo00?o0000ooooooooool04?oo
ool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo
00?o0000ooooooooool01Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03
o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onH
V9So8B4Qonk^kP09ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01_ooool2o`00
00cooooo0_l00002ooooo`05oa0@4?l0003o0000ooooool@41002Oooool2o`000004oooooonHV9So
8B4Qonk^kPWooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00Go410@oooooooooooooooo
oa0@400@ooooo`03o`000?oooooooooo00gooooo00Go410@oooooooooooooooooa0@400=ooooo`03
ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Dooooo`00
2oooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7o
ooooooooo`06ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^00Oooooo00?oMgMgoc8b<_ooool05Oooool00ol0003oooooooooo`06ooooo`;o00003?ooool2
o`0000;ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o
MgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000kooooo0_l000000olb<S;ooooo
ooooo`0=ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03
ogMgMolb<S;ooooo01Wooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool0
6?ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool0
0oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Kooooo00?o0000ooooooooool01_ooool2o`0000co
oooo0_l00002ooooo`?o000000?oooooo`000?ooool02Oooool2o`0000;ooooo00?oMgMgofIVI_oo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00?o0000ooooooooool00ol0000;oooo
o`05o`000?lQ8B7o0000o`000?o<c<`03oooool01Ol0003ooooooooooooooooo000000kooooo00?o
EEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[ooooo00?o0000ooooooooool0
5?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol@413ooooooooooooooooo410@00kooooo
00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@
41003?ooool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo01Sooooo0ol000000ooooooo0000o`000003oooo
o`;o00004?ooool01Ol@413o0000o`000?oooooo410@00[ooooo0_l00003ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01_ooool2o`0000Wooooo00?o410@ooooooooool00ol0000;
ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmg
MgOooooo00?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Dooooo`002oooool0
0ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooo
oooooooo<S8b00Cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00co
oooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000okZj
^_ooool00_l00004ooooo`?o00006?ooool01?l0003oooooooooooooool2o`0001Gooooo00GoMgMg
o`000?l0003oV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooo
ooooo`06ooooo`;o00002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooooooo
ool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05?ooool000Wooooo00?oEEEEofIV
I_l000006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00004?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1?ooool2o`0000Gooooo00?oV9RHoa0@4?l000000_l00004ooooo`Co00005oooool00ol0003ooooo
ooooo`09ooooo`;o00003Oooool01Oo^k^ko0000o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c004ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000Iooooo`03oeEEEOmV
IVKo000001Kooooo0021ooooo`;o0000:Oooool00ol0003oooooooooo`09ooooo`;o0000[_ooool0
08gooooo0_l0000Mooooo`03o`000?oooooooooo04Wooooo0_l0001^ooooo`00SOooool2o`0001go
oooo00?o0000ooooooooool08?ooool2o`0002Oooooo0_l0001Sooooo`;o00000_ooool2o`0000Go
oooo002/ooooo`03o`000?oooooooooo00Kooooo0_l0000Hooooo`;o00001Oooool2o`0001;ooooo
0ol0001`ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1Oooool008Cooooo0_l0000Aooooo`;o
00004oooool3o`0000Kooooo0_l0000Oooooo`;o00004_ooool3o`00077ooooo00CogMgMo`000?l@
413oc<c<1_ooool000Ooooooool0001<o`0000cooooo00Cok^k^ob4Q8Ol@413ok^k^1_ooool000Oo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool00oooool3o`0000Oooooo00Co0000oooooooooooooooo0_l00002oooo
o`04o`000?oooooo0000o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool01?lQ8B7oMgMgogMgMolb
<S86ooooo`001oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`0000Sooooo0_l0000A
ooooo`03o`000?oooooooooo00cooooo0_l0000<ooooo`;o00002oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`09
ooooo`;o00000_ooool2o`0000Gooooo0020ooooo`;o00000_ooool4o`000003ooooool0003o0000
00Cooooo0_l00008ooooo`;o00004Oooool00ol0003oooooooooo`0<ooooo`;o00001_ooool2o`00
0:?ooooo0020ooooo`?o000000?oooooo`000?l000000_l0000Tooooo`03o`000?oooooooooo00Wo
oooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool2o`0001;ooooo0_l0002?ooooo`00
POooool2o`0002Wooooo00?o0000ooooooooool02Oooool2o`0000Gooooo0_l0000Fooooo`;o0000
Soooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool01_ooool2
o`00057ooooo0_l0001Nooooo`00[?ooool3o`0000Kooooo0_l0001Aooooo`;o0000G_ooool00:co
oooo00?o0000ooooooooool0>oooool2o`0000gooooo0_l0001]ooooo`00Soooool2o`0001_ooooo
00Co0000ooooool0003o0000>_ooool2o`0000gooooo0_l0001]ooooo`00Soooool4o`0001Wooooo
00Co0000ooooool0003o0000>Oooool2o`0000kooooo0_l0000=ooooo`;o0000G_ooool0097ooooo
0_l0000Iooooo`03o`000?oooooooooo00?ooooo0_l0000eooooo`Co00003?ooool2o`0000gooooo
0_l0001Nooooo`00[?ooool00ol0003oooooooooo`03ooooo`;o00003oooool2o`0002Kooooo0_l0
000<ooooo`;o0000KOooool009Cooooo0_l0000Fooooo`03o`000?oooooooooo01Cooooo0_l00009
ooooo`;o0000:Oooool2o`0006gooooo0029ooooo`;o00001_ooool2o`000003ooooool0003o0000
01Kooooo00Co0000ooooool0003o00007_ooool2o`0001_ooooo0_l0000;ooooo`;o0000K_ooool0
08Wooooo0_l00006ooooo`;o00006Oooool01?l0003oooooo`000?l0000kooooo`;o00002_ooool4
o`0006gooooo0021ooooo`;o00001_ooool2o`00027ooooo0ol00018ooooo`Co0000KOooool0087o
oooo0_l0000Yooooo`03o`000?oooooooooo02Kooooo0ol0002@ooooo`00TOooool2o`0001Wooooo
00?o0000ooooooooool09_ooool3o`00093ooooo002Aooooo`;o00006Oooool00ol0003ooooooooo
o`2iooooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool04oooool2o`000:Cooooo001noooo
o`;o00003Oooool2o`0000Gooooo0_l0000Fooooo`03o`000?oooooooooo01?ooooo0_l0000Voooo
o`;o00006oooool2o`0005oooooo001nooooo`;o00003Oooool2o`0001gooooo00?o0000oooooooo
ool06?ooool2o`00027ooooo0_l0000Kooooo`;o0000Goooool00:cooooo00?o0000ooooooooool0
3_ooool2o`0000Sooooo0_l0002Oooooo`00O_ooool2o`0002cooooo0ol0000>ooooo`;o0000ZOoo
ool007kooooo0_l0000/ooooo`03o`000?oooooooooo03_ooooo0_l0001looooo`00T?ooool2o`00
01[ooooo00?o0000ooooooooool06?ooool2o`0000cooooo0_l0000Cooooo`;o0000O?ooool0093o
oooo0_l0000Jooooo`03o`000?oooooooooo01Sooooo0_l0000;ooooo`?o00001oooool2o`0008So
oooo002/ooooo`03o`000?oooooooooo00kooooo0_l0000Eooooo`;o00002?ooool2o`0008Sooooo
0021ooooo`;o0000:Oooool00ol0003oooooooooo`0>ooooo`;o0000=oooool2o`00073ooooo0021
ooooo`;o0000:Oooool01?l0003oooooooooooooool2o`0004?ooooo0ol0001`ooooo`00[?ooool0
1?l0003oooooooooooooool2o`0000Kooooo0_l0000kooooo`;o00003oooool2o`00063ooooo002[
ooooo`Co00002Oooool2o`0003_ooooo0_l0000?ooooo`;o0000H?ooool008[ooooo0_l0000Ooooo
o`;o0000;oooool2o`0001Oooooo0_l0001aooooo`00R_ooool2o`00023ooooo00?o0000oooooooo
ool01_ooool2o`0001Gooooo0_l0000>ooooo`;o0000R_ooool00:cooooo00?o0000ooooooooool0
1_ooool2o`0001Gooooo0_l0002Jooooo`00[?ooool00ol0003oooooooooo`0@ooooo`;o00004ooo
ool2o`0009;ooooo002/ooooo`03o`000?oooooooooo013ooooo0_l0000Cooooo`;o00004?ooool3
o`0007oooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0/ooooo`;o00002Ooo
ool3o`0007oooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
V9RHo`000?l0003oooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
5Oooool2o`0001Gooooo0_l0002;ooooo`00ROooool01Ol@413ooooooooooooooooo410@00cooooo
00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o00001oooool2o`0000cooooo
0_l0000`ooooo`;o0000L?ooool008Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`07ooooo`;o0000
3?ooool2o`0002kooooo1?l0001`ooooo`00ROooool01Ol0003ooooooooooooooooo000000kooooo
00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool05Oooool2o`0001Cooooo0_l0000Hooooo`;o0000L_ooool008Wooooo00Go410@oooooooooooo
oooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool01?l0003o
ooooooooooooool2o`0002Sooooo0_l0002<ooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00Co0000
oooooooooooooooo0_l0000Nooooo`;o0000U_ooool008;ooooo0_l00005ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01?ooool2o`0000Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co0000
1_ooool00ol0003oooooooooo`0>ooooo`;o00004Oooool2o`0009Kooooo0022ooooo`;o00003_oo
ool2o`0000Kooooo0_l0000@ooooo`03o`000?oooooooooo00Kooooo0_l00006ooooo`;o0000ZOoo
ool008Sooooo0_l0000@ooooo`;o000000?oooooo`000?l000003Oooool2o`0000Oooooo0_l0002a
ooooo`00R?ooool2o`0001?ooooo0_l0000=ooooo`;o0000:oooool2o`0001Wooooo0_l0001boooo
o`00[?ooool3o`0000kooooo0_l0000Jooooo`;o00005oooool4o`0007;ooooo002/ooooo`;o0000
3oooool2o`0003?ooooo0ol0001cooooo`00[?ooool00ol0003oooooooooo`14ooooo`;o0000Looo
ool00:cooooo00?o0000ooooooooool03Oooool2o`0000?ooooo0_l0002Uooooo`00[?ooool00ol0
003oooooooooo`0=ooooo`;o00000oooool2o`000:Gooooo002/ooooo`03o`000?oooooooooo01So
oooo0_l0000Yooooo`;o0000M?ooool008cooooo0_l0000Cooooo`;o00002Oooool00ol0003ooooo
ooooo`07ooooo`;o00003oooool2o`0002Wooooo0_l0001dooooo`00S?ooool2o`0000[ooooo0_l0
0007ooooo`;o00002Oooool00ol0003oooooooooo`06ooooo`?o00002?ooool2o`000:Kooooo002H
ooooo`;o00001?ooool2o`0000_ooooo1?l00006ooooo`;o00002Oooool2o`0000?ooooo0_l00007
ooooo`;o0000V?ooool008cooooo0_l0000@ooooo`;o00002oooool2o`0001Sooooo0_l00007oooo
o`;o0000V?ooool008cooooo0_l0000>ooooo`;o000000?oooooo`000?l000002oooool00ol0003o
ooooooooo`2iooooo`00W?ooool2o`000003ooooool0003o000000_ooooo00?o0000ooooooooool0
2_ooool2o`0002Gooooo0_l00026ooooo`00[?ooool00ol0003oooooooooo`0:ooooo`;o00000ooo
ool2o`00023ooooo0_l00026ooooo`00[?ooool00ol0003oooooooooo`0?ooooo`;o00005Oooool2
o`0000Sooooo0_l00027ooooo`00Qoooool2o`0002?ooooo00?o0000ooooooooool02Oooool2o`00
01_ooooo0_l00008ooooo`;o0000Qoooool008Oooooo0_l0000Sooooo`03o`000?oooooooooo00Wo
oooo0_l0002^ooooo`00R?ooool2o`0002;ooooo0ol0000aooooo`;o0000Q_ooool008Sooooo0_l0
000Fooooo`;o00002_ooool00ol0003oooooooooo`0aooooo`;o0000Q_ooool008gooooo0_l0000A
ooooo`;o00002?ooool3o`0001Kooooo0_l0002Sooooo`00SOooool2o`00017ooooo0_l000000ooo
oooo0000o`000005ooooo`?o00005_ooool2o`000:?ooooo002Sooooo`;o00001oooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`02ooooo`;o00001oooool2o`000:cooooo
002Dooooo`;o00005_ooool00ol0003oooooooooo`02ooooo`;o00001oooool2o`00023ooooo0_l0
002:ooooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool0;Oooool2o`0008[ooooo002Koooo
o`;o00003oooool3o`0000Wooooo0_l0000`ooooo`;o0000O?ooool009_ooooo0_l00008ooooo`;o
00001Oooool00ol0003oooooooooo`09ooooo`;o0000<?ooool2o`0007cooooo002?ooooo`;o0000
5?ooool2o`0000Gooooo00?o0000ooooooooool0;?ooool2o`0000gooooo0_l0001looooo`00Sooo
ool2o`0001_ooooo00?o0000ooooooooool04?ooool2o`0000Gooooo0_l0000Cooooo`;o00003Ooo
ool2o`0007cooooo002Yooooo`;o000000?oooooo`000?ooool01?ooool2o`0000_ooooo0_l00005
ooooo`;o00004oooool2o`0008_ooooo002Iooooo`;o00003_ooool2o`000003ooooool0003ooooo
00Cooooo0_l0002dooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo0_l00002ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00;ooooo0_l0002e
ooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool00_ooool2o`0003?ooooo0_l00020ooooo`00TOooool01Ol@
413ooooooooooooooooo410@013ooooo0_l00004ooooo`03o`000?oooooooooo01kooooo0_l0000G
ooooo`;o0000P?ooool0097ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMol0003o
000000Cooooo0ol0000Nooooo`;o00006?ooool2o`0007oooooo002Aooooo`05o`000?oooooooooo
ooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool05?oo
ool2o`0001?ooooo0_l0000=ooooo`;o0000Ooooool0097ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05?ooool2o`0001?ooooo0_l0
002>ooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0_l00007ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0:Oooool2o`0008kooooo002Aooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool2o`0000?ooooo0_l00002ooooo`Co00001_ooool00ol0003ooooooooo
o`2iooooo`00Qoooool2o`0001Gooooo0_l00008ooooo`;o00000_ooool00ol0003oooooooooo`0d
ooooo`;o0000Poooool008Oooooo0_l0000Mooooo`Co00000_ooool00ol0003oooooooooo`0Uoooo
o`;o00003Oooool2o`0008?ooooo002Vooooo`;o00001?ooool00ol0003oooooooooo`0Iooooo`;o
00002_ooool2o`0009;ooooo002Jooooo`;o00004?ooool3o`0000?ooooo0_l0000Dooooo`?o0000
WOooool009Oooooo0_l000000ooooooo0000o`00000?ooooo`;o00001Oooool2o`0001Gooooo0_l0
002Mooooo`00Uoooool2o`0001;ooooo0_l0002kooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`05ooooo`;o0000/_ooool00:cooooo00?o0000ooooooooool0
1Oooool2o`0000oooooo0_l0002Qooooo`00W_ooool2o`0000cooooo00?o0000ooooooooool05_oo
ool2o`000:7ooooo002Nooooo`;o00001Oooool2o`0000Gooooo00?o0000ooooooooool0^Oooool0
0:Gooooo0_l00005ooooo`?o00003?ooool2o`000:_ooooo002Kooooo`;o00003oooool00ol0003o
ooooooooo`0;ooooo`?o0000Zoooool009_ooooo0_l0000?ooooo`03o`000?oooooooooo00_ooooo
0_l0000Booooo`;o0000V?ooool00:cooooo00?o0000ooooooooool00oooool2o`0001[ooooo0_l0
000;ooooo`;o0000Roooool00:cooooo00?o0000ooooooooool00oooool2o`0001Wooooo0ol0000;
ooooo`;o0000Roooool00:[ooooo0ol0000Oooooo`Co0000V?ooool009kooooo0_l00007ooooo`;o
000000Coooooo`000?l0003o00007oooool2o`0009[ooooo002Nooooo`;o00001oooool2o`0000?o
oooo00?o0000ooooooooool00_l0000Jooooo`;o0000Voooool00:7ooooo0_l00009ooooo`Go0000
1_ooool2o`0001;ooooo0_l0002Kooooo`00XOooool2o`0000Wooooo00?o0000ooooooooool02?oo
ool2o`000:oooooo0022ooooo`;o0000:?ooool00ol0003oooooooooo`06ooooo`;o0000/Oooool0
08;ooooo0_l0000Fooooo`;o00004?ooool00ol0003oooooooooo`06ooooo`;o0000/Oooool009[o
oooo0_l0000@ooooo`03o`000?oooooooooo02Sooooo0_l0002?ooooo`00[?ooool00ol0003ooooo
ooooo`0Xooooo`;o0000Soooool00:cooooo00?o0000ooooooooool0=_ooool2o`00087ooooo002/
ooooo`03o`000?oooooooooo00cooooo0_l0000Xooooo`;o0000POooool0097ooooo0_l0000Ioooo
o`03o`000?oooooooooo00cooooo0_l0002[ooooo`00TOooool2o`0001Wooooo0ol000000ooooooo
0000o`00002fooooo`00T_ooool2o`0000oooooo0ol000000ooooooo0000o`000003ooooo`04o`00
0?ooooooooooooooo`;o0000]_ooool009;ooooo0_l0000?ooooo`?o000000?oooooo`000?l00000
0oooool01?l0003oooooo`000?l0002hooooo`00[?ooool01?l0003oooooo`000?l0002hooooo`00
[?ooool00ol0003oooooooooo`2iooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_l00006ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0;Wooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0000Ko
oooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;Wo
oooo0029ooooo`05oa0@4?ooooooooooooooool@41001Oooool2o`0000Kooooo00?oZJVYo`000?l0
00002?ooool01?l0003oooooooooooooool3o`000;_ooooo0029ooooo`05o`000?oooooooooooooo
ool000003_ooool2o`0000Oooooo00?oMgMgoc8b<_ooool00_ooool5o`000;Wooooo0029ooooo`05
o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01Oooool00ol0003oooooooooo`2iooooo`00ROooool01Ol@413ooooooooooooooooo
410@00kooooo00?oZJVYogMgMoooool00_l000000ooooooo0000ooooo`08ooooo`03o`000?oooooo
oooo0;Wooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01_l@413ooooooooooooo
oooo<S8booooo`;o000000?oooooo`000?ooool02?ooool00ol0003oooooooooo`04ooooo`;o0000
2?ooool2o`000:Wooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo
1?l00006ooooo`03o`000?oooooooooo00Cooooo0_l00008ooooo`;o0000ZOooool00:cooooo00?o
0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00Co0000oooo
oooooooooooo0_l0002fooooo`00[?ooool6o`000;Kooooo002/ooooo`04o`000?oooooo0000o`00
0;Sooooo002/ooooo`03o`000?oooooooooo01Oooooo0_l0002Pooooo`00[?ooool00ol0003ooooo
ooooo`0Gooooo`;o0000X?ooool009_ooooo0_l0000?ooooo`03o`000?oooooooooo01Kooooo0_l0
002Qooooo`00Voooool2o`0000oooooo00?o0000ooooooooool05_ooool2o`000:7ooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002Qooooo`;o00001_ooool2o`000003ooooool0003ooooo0;[o
oooo002Pooooo`?o00001_ooool2o`000004ooooool0003o0000o`000;Wooooo002Pooooo`;o0000
2_ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`03ooooo`;o00007?oo
ool2o`0009Kooooo002/ooooo`03o`000?oooooooooo00?ooooo0_l0000Looooo`;o0000U_ooool0
0:cooooo00?o0000ooooooooool03oooool2o`000:Sooooo002/ooooo`03o`000?oooooooooo00oo
oooo0_l0002Xooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`0<ooooo`;o0000Zoooool00:cooooo00?o0000ooooooooool03?ooool3o`0000gooooo0_l0002K
ooooo`00Voooool2o`0000oooooo0ol0000=ooooo`;o00003Oooool2o`0009_ooooo002Aooooo`;o
00002?ooool2o`0000gooooo0ol0002kooooo`00TOooool2o`0000Sooooo0_l000000ooooooo0000
o`00000:ooooo`?o0000^oooool009kooooo0_l0000:ooooo`?o00002_ooool2o`000:oooooo002W
ooooo`?o00000_ooool00ol0003oooooooooo`08ooooo`;o0000[oooool00:Oooooo0ol00002oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o00000oooool2o`000;Cooooo002/ooooo`03o`000?oooooo
oooo00?ooooo0_l0002dooooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool0^Oooool009Oo
oooo0_l0000Cooooo`03o`000?oooooooooo00;o0000]oooool00:cooooo00?o0000ooooooooool0
0_l0002gooooo`00V?ooool2o`0001;ooooo00?o0000ooooooooool0^Oooool009Sooooo0_l00008
ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`2iooooo`00Y?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`03o`000?oooooooooo00Go
oooo0ol0002iooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003ooooooooo
o`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31oooo
o`00X_ooool00omEEEGoIVIVo`000033ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00Z_ooool01?l@413o0000o`000?l0002jooooo`00Zoooool00ol0003o
ooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool01_l0003oMgMgo`00
0?l0003oEEEEonk^k[Oooooo002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoEEEE]oooool00:_o
oooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`2eooooo`00Zoooool00ol0003ok^k^
ooooo`02ooooo`03o`000?oooooooooo0;Gooooo002[ooooo`06o`000?mEEEGok^k^oooooomgMgOo
IVIV]oooool00:[ooooo00?o410@o`000?mgMgL00_l000000omVIVKok^k^ooooo`2fooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.39424 .6668 Mdot
.58419 .23141 Mdot
.48309 .63119 Mdot
.49677 .73338 Mdot
.53587 .27159 Mdot
.63237 .55315 Mdot
.4829 .66982 Mdot
.59119 .12753 Mdot
.40823 .8664 Mdot
.49502 .76288 Mdot
.43844 .26642 Mdot
.64898 .2159 Mdot
.6312 .69607 Mdot
.41193 .45527 Mdot
.63879 .20724 Mdot
.48677 .24086 Mdot
.58442 .66765 Mdot
.62169 .72072 Mdot
.50399 .77527 Mdot
.59124 .18507 Mdot
.62698 .69967 Mdot
.64494 .38408 Mdot
.65222 .4297 Mdot
.60571 .75444 Mdot
.72062 .39494 Mdot
.42064 .7327 Mdot
.50909 .25429 Mdot
.53502 .70606 Mdot
.62332 .24018 Mdot
.58373 .23358 Mdot
.60457 .74666 Mdot
.39633 .81942 Mdot
.48677 .01772 Mdot
.46578 .85562 Mdot
.43761 .17036 Mdot
.41607 .15099 Mdot
.68414 .6221 Mdot
.5729 .53587 Mdot
.63736 .27466 Mdot
.6817 .27247 Mdot
.73049 .42633 Mdot
.39358 .52187 Mdot
.58669 .29543 Mdot
.39281 .333 Mdot
.43113 .84645 Mdot
.58821 .57481 Mdot
.42741 .68105 Mdot
.49976 .95974 Mdot
.54166 .24404 Mdot
.59181 .19206 Mdot
.51737 .93849 Mdot
.68702 .41405 Mdot
.76394 .36599 Mdot
.51379 .16666 Mdot
.55683 .23208 Mdot
.37395 .34358 Mdot
.59752 .13711 Mdot
.58263 .67632 Mdot
.61153 .80697 Mdot
.46336 .89347 Mdot
.58048 .61538 Mdot
.61836 .86293 Mdot
.63714 .27682 Mdot
.4217 .51535 Mdot
.4351 .05548 Mdot
.36877 .55237 Mdot
.51735 .71464 Mdot
.43617 .30708 Mdot
.56994 .57777 Mdot
.57925 .80239 Mdot
.52801 .80096 Mdot
.51101 .39274 Mdot
.49514 .76081 Mdot
.55516 .58202 Mdot
.63662 .27581 Mdot
.48576 .36163 Mdot
.76409 .36659 Mdot
.5511 .70503 Mdot
.67603 .36806 Mdot
.44022 .20242 Mdot
.45431 .91872 Mdot
.56726 .20661 Mdot
.53372 .62593 Mdot
.39596 .40265 Mdot
.4962 .02137 Mdot
.52479 .31235 Mdot
.54969 .30262 Mdot
.57105 .37044 Mdot
.59922 .61989 Mdot
.44169 .28752 Mdot
.72097 .39973 Mdot
.50848 .30147 Mdot
.5908 .47378 Mdot
.46531 .26133 Mdot
.41143 .51754 Mdot
.52737 .92366 Mdot
.77297 .39781 Mdot
.58999 .66054 Mdot
.3863 .45698 Mdot
.61161 .53394 Mdot
.63432 .19516 Mdot
.41725 .18881 Mdot
.49503 .9208 Mdot
.43476 .81121 Mdot
.50224 .84074 Mdot
.44403 .77388 Mdot
.51201 .31015 Mdot
.5791 .80122 Mdot
.4307 .70142 Mdot
.49977 .72889 Mdot
.40793 .8672 Mdot
.48496 .05813 Mdot
.73553 .74722 Mdot
.52788 .56418 Mdot
.56536 .66908 Mdot
.38652 .22199 Mdot
.36772 .47283 Mdot
.6901 .56995 Mdot
.63479 .68415 Mdot
.67168 .77668 Mdot
.65528 .573 Mdot
.63671 .26422 Mdot
.57521 .80867 Mdot
.46412 .74896 Mdot
.51692 .09009 Mdot
.37989 .19097 Mdot
.45037 .11489 Mdot
.44525 .66723 Mdot
.65646 .44701 Mdot
.40914 .2287 Mdot
.67926 .27338 Mdot
.62748 .60002 Mdot
.61745 .38477 Mdot
.66717 .33619 Mdot
.68896 .61343 Mdot
.58078 .17287 Mdot
.50562 .73983 Mdot
.52894 .05962 Mdot
.65474 .23248 Mdot
.51394 .98714 Mdot
.54902 .53827 Mdot
.54934 .66934 Mdot
.58253 .67423 Mdot
.54738 .12489 Mdot
.4471 .03008 Mdot
.6401 .9038 Mdot
.45789 .79152 Mdot
.58381 .4273 Mdot
.6885 .74824 Mdot
.6126 .50466 Mdot
.57237 .45138 Mdot
.59641 .77419 Mdot
.49518 .3373 Mdot
.60566 .67408 Mdot
.69657 .53428 Mdot
.65945 .32601 Mdot
.37902 .2815 Mdot
.68518 .61279 Mdot
.69591 .55306 Mdot
.41626 .28291 Mdot
.68036 .37997 Mdot
.73824 .44846 Mdot
.37814 .49137 Mdot
.56708 .25767 Mdot
.39088 .62304 Mdot
.42776 .06343 Mdot
.44553 .91213 Mdot
.57341 .54345 Mdot
.69718 .55814 Mdot
.52464 .10277 Mdot
.50891 .30747 Mdot
.56936 .44074 Mdot
.53751 .27786 Mdot
.41882 .67282 Mdot
.47664 .01727 Mdot
.42337 .02581 Mdot
.61239 .65089 Mdot
.52929 .47678 Mdot
.62535 .24686 Mdot
.69912 .49896 Mdot
.70428 .32611 Mdot
.56025 .46984 Mdot
.73432 .45009 Mdot
.46597 .28361 Mdot
.43689 .93819 Mdot
.37057 .26193 Mdot
.39107 .79526 Mdot
.73358 .42292 Mdot
.60974 .35545 Mdot
.70363 .7052 Mdot
.54982 .12765 Mdot
.469 .73255 Mdot
.65268 .80655 Mdot
.54085 .06832 Mdot
.7395 .55162 Mdot
.6564 .23069 Mdot
.5841 .4218 Mdot
.60907 .09465 Mdot
.41575 .75317 Mdot
.4857 .30468 Mdot
.49653 .32262 Mdot
.51994 .44517 Mdot
.50577 .21705 Mdot
.64417 .13875 Mdot
.38896 .39816 Mdot
.53864 .50506 Mdot
.62513 .60364 Mdot
.49472 .7409 Mdot
.5301 .40599 Mdot
.46279 .2178 Mdot
.66076 .57525 Mdot
.55849 .68602 Mdot
.44318 .90855 Mdot
.54226 .37133 Mdot
.38782 .56933 Mdot
.57599 .62508 Mdot
.73831 .45304 Mdot
.48972 .28637 Mdot
.52462 .84088 Mdot
.66462 .23846 Mdot
.57015 .65421 Mdot
.61102 .80412 Mdot
.46767 .93115 Mdot
.4167 .8414 Mdot
.49589 .25512 Mdot
.44822 .21152 Mdot
.57031 .20532 Mdot
.50827 .30418 Mdot
.64367 .2149 Mdot
.65168 .8147 Mdot
.43129 .32553 Mdot
.46804 .33849 Mdot
.63749 .13275 Mdot
.58253 .34322 Mdot
.51753 .26931 Mdot
.69092 .73485 Mdot
.57372 .49271 Mdot
.44831 .11202 Mdot
.65477 .59096 Mdot
.39867 .2913 Mdot
.62207 .85652 Mdot
.63352 .47432 Mdot
.38391 .65749 Mdot
.53 .79748 Mdot
.38134 .72967 Mdot
.4362 .33497 Mdot
.69371 .48356 Mdot
.60725 .47711 Mdot
.536 .78697 Mdot
.64571 .2938 Mdot
.73991 .52544 Mdot
.52972 .54425 Mdot
.48183 .72974 Mdot
.69392 .51819 Mdot
.42596 .75191 Mdot
.56438 .41147 Mdot
.59731 .31363 Mdot
.49933 .39964 Mdot
.56632 .0997 Mdot
.55502 .89228 Mdot
.56685 .29851 Mdot
.51673 .26754 Mdot
.39317 .72806 Mdot
.49397 .69378 Mdot
.60965 .46538 Mdot
.43519 .85196 Mdot
.41892 .62237 Mdot
.62607 .43659 Mdot
.45853 .06761 Mdot
.40109 .55205 Mdot
.4626 .0623 Mdot
.57903 .27416 Mdot
.48969 .77137 Mdot
.50764 .19005 Mdot
.69728 .53116 Mdot
.56201 .51501 Mdot
.41226 .36298 Mdot
.49351 .9645 Mdot
.45806 .22169 Mdot
.61152 .65806 Mdot
.64838 .29297 Mdot
.42588 .49734 Mdot
.55878 .47289 Mdot
.68604 .60536 Mdot
.6174 .1689 Mdot
.43253 .74224 Mdot
.44226 .3927 Mdot
.41525 .35003 Mdot
.43807 .08829 Mdot
.59051 .48661 Mdot
.49735 .91486 Mdot
.36811 .28654 Mdot
.63225 .76643 Mdot
.60989 .16235 Mdot
.63655 .75443 Mdot
.51628 .52639 Mdot
.6381 .75945 Mdot
.68338 .74409 Mdot
.39561 .23677 Mdot
.62676 .18817 Mdot
.5747 .98142 Mdot
.48758 .16346 Mdot
.62682 .41342 Mdot
.42792 .15732 Mdot
.38596 .76208 Mdot
.72125 .39085 Mdot
.41341 .55821 Mdot
.50871 .94727 Mdot
.40929 .6617 Mdot
.43432 .42343 Mdot
.66223 .54929 Mdot
.56864 .71229 Mdot
.64548 .64634 Mdot
.7032 .71294 Mdot
.52209 .59885 Mdot
.49565 .88138 Mdot
.41581 .74571 Mdot
.47 .02027 Mdot
.47439 .71417 Mdot
.7065 .33358 Mdot
.72686 .60882 Mdot
.42673 .97198 Mdot
.4186 .55266 Mdot
.62343 .62426 Mdot
.40223 .32776 Mdot
.66096 .33372 Mdot
.47192 .18536 Mdot
.47791 .29744 Mdot
.50695 .60115 Mdot
.52986 .79537 Mdot
.63925 .1957 Mdot
.69235 .49126 Mdot
.46471 .26117 Mdot
.66301 .49145 Mdot
.43202 .59786 Mdot
.52043 .45038 Mdot
.57666 .21616 Mdot
.63414 .53229 Mdot
.56964 .2626 Mdot
.41495 .29077 Mdot
.48284 .1898 Mdot
.74908 .32028 Mdot
.41888 .71897 Mdot
.52437 .14458 Mdot
.42255 .53729 Mdot
.41962 .0873 Mdot
.4872 .22032 Mdot
.5621 .14705 Mdot
.59584 .26018 Mdot
.54634 .44132 Mdot
.58912 .51402 Mdot
.51637 .98497 Mdot
.64822 .21326 Mdot
.63585 .76625 Mdot
.44096 .08831 Mdot
.46723 .16024 Mdot
.4414 .83111 Mdot
.51507 .09063 Mdot
.60042 .4067 Mdot
.64517 .20872 Mdot
.39373 .87491 Mdot
.37938 .59169 Mdot
.67311 .26182 Mdot
.71074 .34602 Mdot
.73815 .46553 Mdot
.51926 .56805 Mdot
.56221 .29047 Mdot
.65461 .23307 Mdot
.5801 .11557 Mdot
.51294 .60645 Mdot
.53661 .86368 Mdot
.43339 .77276 Mdot
.62072 .62899 Mdot
.38619 .53192 Mdot
.5002 .95545 Mdot
.44121 .12386 Mdot
.66771 .6838 Mdot
.68278 .41513 Mdot
.64714 .40426 Mdot
.65264 .7314 Mdot
.65149 .41911 Mdot
.70688 .34704 Mdot
.70204 .81294 Mdot
.68275 .6149 Mdot
.5884 .72299 Mdot
.46647 .32173 Mdot
.73542 .54473 Mdot
.6022 .60885 Mdot
.51189 .57097 Mdot
.71348 .34956 Mdot
.57349 .81208 Mdot
.47514 .29645 Mdot
.54643 .62609 Mdot
.48656 .82807 Mdot
.53485 .30933 Mdot
.47103 .97402 Mdot
.42806 .88222 Mdot
.66392 .78489 Mdot
.70905 .33894 Mdot
.51397 .81879 Mdot
.72448 .26929 Mdot
.47309 .86077 Mdot
.42284 .69676 Mdot
.40651 .45852 Mdot
.44436 .583 Mdot
.62187 .1708 Mdot
.64298 .20634 Mdot
.5034 .24316 Mdot
.53781 .39747 Mdot
.54855 .34014 Mdot
.54786 .38649 Mdot
.72643 .63608 Mdot
.59029 .45968 Mdot
.37812 .46573 Mdot
.54633 .55989 Mdot
.57288 .45931 Mdot
.46642 .7102 Mdot
.5763 .38226 Mdot
.49367 .84691 Mdot
.55471 .36394 Mdot
.53692 .54734 Mdot
.68059 .76166 Mdot
.52608 .05617 Mdot
.46953 .37812 Mdot
.46355 .13268 Mdot
.50266 .83999 Mdot
.58254 .73138 Mdot
.41274 .67959 Mdot
.57391 .48556 Mdot
.73487 .56641 Mdot
.46381 .0978 Mdot
.77192 .6438 Mdot
.41279 .2048 Mdot
.52102 .64056 Mdot
.39506 .80741 Mdot
.66206 .24714 Mdot
.44527 .2486 Mdot
.59062 .25149 Mdot
.75314 .33191 Mdot
.54277 .42461 Mdot
.44015 .37324 Mdot
.40861 .57151 Mdot
.39312 .72925 Mdot
.41705 .28696 Mdot
.56227 .04373 Mdot
.50238 .31342 Mdot
.45398 .14439 Mdot
.39328 .52088 Mdot
.44106 .31114 Mdot
.52699 .5632 Mdot
.55792 .56882 Mdot
.59058 .12714 Mdot
.49878 .68538 Mdot
.66953 .34547 Mdot
.54878 .17402 Mdot
.45393 .88421 Mdot
.49086 .06274 Mdot
.5383 .85998 Mdot
.54092 .7723 Mdot
.38935 .13635 Mdot
.53873 .6553 Mdot
.64612 .20642 Mdot
.74048 .52919 Mdot
.42049 .63406 Mdot
.63606 .76466 Mdot
.40557 .62002 Mdot
.60193 .58882 Mdot
.55902 .14253 Mdot
.38733 .42125 Mdot
.48715 .79899 Mdot
.58907 .52506 Mdot
.46188 .85422 Mdot
.60678 .88245 Mdot
.60741 .35383 Mdot
.48183 .35555 Mdot
.55932 .24118 Mdot
.45705 .17234 Mdot
.52036 .56245 Mdot
.4176 .50783 Mdot
.50679 .15621 Mdot
.6176 .38158 Mdot
.52558 .4332 Mdot
.46146 .826 Mdot
.36829 .528 Mdot
.53211 .26263 Mdot
.46825 .89168 Mdot
.55639 .64903 Mdot
.54541 .67412 Mdot
.47534 .6946 Mdot
.74354 .73149 Mdot
.4655 .68988 Mdot
.58039 .22363 Mdot
.61575 .79286 Mdot
.37979 .41352 Mdot
.56382 .61284 Mdot
.60038 .2032 Mdot
.68749 .28712 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002Tooooo`;o000000?oooooo`000?l000000oooool00ol0003o
ooooooooo`2iooooo`00X_ooool4o`000004ooooool0003o0000ooooo`?o0000^oooool009;ooooo
0_l0000>ooooo`;o00001_ooool5o`000;Wooooo002Booooo`;o00006?ooool00ol0003ooooooooo
o`2iooooo`00V_ooool2o`00013ooooo00?o0000ooooooooool0^Oooool009[ooooo0_l0000@oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo017ooooo0_l0002Vooooo`00[?ooool0
0ol0003oooooooooo`0Aooooo`;o0000Y_ooool00:cooooo00?o0000ooooooooool0^Oooool00:co
oooo0ol0002iooooo`00U_ooool2o`0001Cooooo00?o0000ooooooooool01Oooool2o`000;;ooooo
002Fooooo`;o00003oooool2o`0000?ooooo00?o0000ooooooooool01Oooool2o`000;;ooooo002W
ooooo`;o00000oooool00ol0003oooooooooo`06ooooo`;o0000/Oooool009Cooooo0_l00009oooo
o`;o00002?ooool2o`000003ooooool0003ooooo00Oooooo0_l0002aooooo`00U?ooool2o`0000So
oooo0ol00008ooooo`;o000000?oooooo`000?ooool02oooool2o`000:gooooo002Nooooo`;o0000
3?ooool00ol0003oooooooooo`0:ooooo`;o0000[Oooool00:cooooo00?o0000ooooooooool0^Ooo
ool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00TOooool2o`0000Cooooo0ol0
000Booooo`03o`000?oooooooooo0;Wooooo002Aooooo`;o00001?ooool3o`0001;ooooo00?o0000
ooooooooool00_ooool2o`000;Gooooo002/ooooo`03o`000?oooooooooo00;ooooo0_l0000Moooo
o`;o0000U_ooool00:3ooooo0_l0000:ooooo`03o`000?oooooooooo027ooooo0_l0002Fooooo`00
X?ooool2o`0000[ooooo0ol0000Booooo`;o0000YOooool00:cooooo00?o0000ooooooooool01Ooo
ool2o`0000_ooooo0_l0002Uooooo`00[?ooool00ol0003oooooooooo`05ooooo`;o0000/_ooool0
0:cooooo00?o0000ooooooooool0^Oooool009[ooooo0_l0000@ooooo`03o`000?oooooooooo0;Wo
oooo002Jooooo`?o00003oooool00ol0003oooooooooo`0Gooooo`;o0000X?ooool008Wooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`0000Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo01Oooooo0_l0002Pooooo`00ROooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`2iooooo`00POooool6o`0000;ooooo00Go410@oooooooooooo
oooooa0@400:ooooo`;o000000?oooooojVYZOmEEED02Oooool00ol0003oooooooooo`03ooooo`?o
00003?ooool2o`000:_ooooo0029ooooo`05o`000?ooooooooooooooool000002_ooool2o`0000;o
oooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00co
oooo0ol0000;ooooo`?o0000W?ooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo
00gooooo0_l0000;ooooo`?o0000W?ooool008Wooooo00Go410@oooooooooooooooooa0@400>oooo
o`04ojVYZOmgMgOoooooooooo`?o00002Oooool00ol0003oooooooooo`0Zooooo`;o0000SOooool0
08Oooooo0_l000001OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b
<P02ooooo`?o00002Oooool00ol0003oooooooooo`0Mooooo`;o00002oooool2o`0008gooooo0027
ooooo`;o000000Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo00?o
0000ooooooooool07Oooool2o`0000gooooo0_l0002;ooooo`00[?ooool00ol0003oooooooooo`0@
ooooo`;o00006_ooool2o`0008_ooooo002Looooo`;o00003_ooool00ol0003oooooooooo`05oooo
o`;o00002Oooool3o`000:Kooooo002Looooo`;o00003_ooool00ol0003oooooooooo`05ooooo`;o
00002_ooool2o`000:Kooooo002@ooooo`;o00006_ooool3o`000;Wooooo002@ooooo`;o00006_oo
ool00ol0003oooooooooo`2iooooo`00U?ooool2o`0001Kooooo00Co0000ooooool0003o0000^?oo
ool009Cooooo0_l0000;ooooo`;o00002Oooool01?l0003oooooo`000?l0002hooooo`00XOooool2
o`0000Cooooo0_l00003ooooo`03o`000?oooooooooo027ooooo0_l0002Fooooo`00Yoooool2o`00
00?ooooo00Co0000oooooooooooooooo0_l0000Nooooo`;o0000U_ooool009Oooooo0_l0000Coooo
o`04o`000?ooooooooooooooo`;o00008?ooool4o`0009;ooooo002Gooooo`;o00001?ooool2o`00
00gooooo00?o0000ooooooooool03Oooool2o`0000Sooooo0_l0000:ooooo`Co0000T_ooool009go
oooo0_l0000=ooooo`?o00003Oooool2o`0000Sooooo0_l0002Pooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00X_ooool2o`0000Sooooo00?o0000
ooooooooool06oooool2o`0009cooooo002@ooooo`;o00004?ooool2o`0000Sooooo00?o0000oooo
ooooool06oooool2o`0000Wooooo0_l0002Aooooo`00Q?ooool2o`0000[ooooo0_l0000Dooooo`;o
00001?ooool01?l0003oooooo`000?l0000Jooooo`;o00002Oooool2o`00097ooooo0024ooooo`;o
00008?ooool2o`0000Cooooo00Co0000ooooool0003o00006_ooool2o`0000cooooo0_l0002>oooo
o`00[?ooool00ol0003oooooooooo`0Yooooo`Co0000S?ooool00:cooooo0ol0000[ooooo`;o0000
S?ooool009Sooooo0_l0000Booooo`03o`000?oooooooooo01kooooo0_l0002Iooooo`00Soooool2
o`0000Oooooo0_l0000Booooo`03o`000?oooooooooo01?ooooo0ol00008ooooo`;o00002_ooool5
o`0008[ooooo002?ooooo`;o00006oooool00ol0003oooooooooo`0Cooooo`?o00005?ooool5o`00
08[ooooo002Jooooo`;o00004?ooool00ol0003oooooooooo`0/ooooo`?o0000R_ooool009[ooooo
0_l0000@ooooo`03o`000?oooooooooo01Kooooo0_l0000Dooooo`Co0000ROooool009oooooo0_l0
000;ooooo`?o00005_ooool2o`0001Cooooo1?l00029ooooo`00Q_ooool2o`0001Kooooo0ol00006
ooooo`;o00000oooool3o`000;Wooooo0026ooooo`;o00005_ooool2o`0000Oooooo0_l00003oooo
o`?o00005oooool2o`000:3ooooo002>ooooo`;o00007?ooool00ol0003oooooooooo`0Gooooo`;o
0000X?ooool008kooooo0_l0000Looooo`03o`000?oooooooooo01Sooooo0_l0000Fooooo`;o0000
Qoooool00:cooooo00?o0000ooooooooool03oooool2o`0000Oooooo0_l0000Fooooo`;o0000Qooo
ool008Wooooo0_l0000Qooooo`03o`000?oooooooooo00oooooo0_l00007ooooo`;o00005_ooool2
o`0008Oooooo0029ooooo`;o00007?ooool2o`0000?ooooo00?o0000ooooooooool09Oooool2o`00
00cooooo0_l00024ooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd00_l00003ooooo`?o00002_ooool2o`0000Cooooo0_l0000C
ooooo`;o00003?ooool2o`0008Cooooo002Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool3o`0000[ooooo0_l00004ooooo`;o00005?ooool2
o`00097ooooo0029ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00?ooooo0_l0000;
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09_ooool2o`0000[ooooo0_l00025
ooooo`00TOooool01Ol0003ooooooooooooooooo000000?ooooo0_l0000:ooooo`03ogMgMolb<S;o
oooo00Cooooo0ol0000Jooooo`;o00005_ooool2o`0008Gooooo002Aooooo`05o`000?oooooooooo
ooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00?ooooo0ol00002ooooo`;o00006?oo
ool2o`0009gooooo002Aooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`05ooooo`?o00000_ooool2o`00017ooooo0_l0002Tooooo`00POooool2o`0000kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0:ooooo`?o00002Oooool00ol0003oooooooooo`0Cooooo`;o00001ooo
ool2o`0001Sooooo0_l00021ooooo`00POooool2o`0000kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0:ooooo`Ko00001_ooool00ol0003oooooooooo`07ooooo`;o00002oooool2o`0000Kooooo0_l0
000<ooooo`;o00002_ooool2o`00087ooooo002Gooooo`;o00004oooool00ol0003oooooooooo`02
ooooo`;o00000oooool2o`0000_ooooo0_l0000Dooooo`;o0000SOooool009Oooooo0_l0000Coooo
o`03o`000?oooooooooo00;ooooo0_l00013ooooo`;o0000L?ooool00:cooooo00?o0000oooooooo
ool00_ooool2o`0000Cooooo0_l0000=ooooo`;o00007oooool3o`0000cooooo0_l0001`ooooo`00
[?ooool3o`0000Sooooo0_l0000=ooooo`;o00004Oooool2o`0000cooooo0ol0001nooooo`00[?oo
ool00ol0003oooooooooo`09ooooo`;o00007oooool2o`0008gooooo0024ooooo`;o00002_ooool2
o`0001[ooooo00?o0000ooooooooool02Oooool2o`000:kooooo0024ooooo`;o00002_ooool2o`00
00kooooo0_l00006ooooo`;o00000_ooool00ol0003oooooooooo`2iooooo`00P?ooool2o`0000ko
oooo0_l00006ooooo`;o00001_ooool2o`0000Kooooo0_l00002ooooo`03o`000?oooooooooo03[o
oooo0_l0001mooooo`00P?ooool2o`0000Sooooo0_l00003ooooo`?o00001_ooool2o`0001;ooooo
00?o0000ooooooooool04Oooool2o`0002Oooooo0_l0001mooooo`00R_ooool2o`0000?ooooo0_l0
000Kooooo`03o`000?oooooooooo017ooooo0_l00006ooooo`;o00004_ooool3o`0008Wooooo002S
ooooo`?o00001_ooool00ol0003oooooooooo`0Cooooo`;o00001?ooool2o`0001;ooooo0ol00029
ooooo`00Xoooool3o`0000Kooooo1?l0000Booooo`;o0000Y?ooool00:cooooo00Co0000ooooool0
003o00003?ooool2o`000:[ooooo002Fooooo`;o00003oooool2o`0000?ooooo00?o0000ooooool0
00000_l0000;ooooo`;o0000Z_ooool009Kooooo0_l0000?ooooo`;o00000oooool00ol0003ooooo
ooooo`03o`0000Gooooo0_l0002_ooooo`00V?ooool2o`0001;ooooo0_l00002ooooo`;o00000_oo
ool2o`000003ooooool0003o000001?ooooo0_l0002Jooooo`00V?ooool2o`0001;ooooo0_l00006
ooooo`;o00005_ooool2o`0009[ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Pooooo`;o
00002?ooool3o`00057ooooo0_l0001Xooooo`00UOooool2o`0000Wooooo0_l00008ooooo`Go0000
Coooool2o`0006Sooooo002;ooooo`;o00002?ooool2o`0001Gooooo00?o0000ooooooooool0<Ooo
ool2o`0000gooooo0_l0001gooooo`00Roooool2o`0001oooooo00?o0000ooooooooool0<Oooool2
o`0000gooooo0_l0001gooooo`00R?ooool2o`0002;ooooo00?o0000ooooooooool0<_ooool2o`00
00gooooo0_l0000=ooooo`;o0000Ioooool008Sooooo0_l0000=ooooo`;o00004Oooool3o`0003Co
oooo1?l0000;ooooo`;o00003Oooool2o`0006Oooooo002Gooooo`;o00002?ooool2o`0000Oooooo
0ol0000?ooooo`;o00009Oooool2o`0000cooooo0_l0001eooooo`00P_ooool2o`0001gooooo0_l0
0009ooooo`03o`000?oooooooooo00gooooo0_l00009ooooo`;o0000:?ooool2o`0007Gooooo0022
ooooo`;o0000:?ooool00ol0003oooooooooo`0Hooooo`;o00006oooool2o`0000_ooooo0_l0001e
ooooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool0=Oooool2o`0000[ooooo1?l0001doooo
o`00T?ooool2o`0001[ooooo0ol00011ooooo`Co0000M?ooool00:Kooooo0_l00004ooooo`03o`00
0?oooooooooo023ooooo0ol0002Fooooo`00Y_ooool2o`0000Cooooo00?o0000ooooooooool08?oo
ool3o`0009Kooooo002Wooooo`;o00000oooool00ol0003oooooooooo`2iooooo`00Soooool2o`00
01Kooooo0_l00003ooooo`03o`000?oooooooooo00oooooo0_l0002Xooooo`00ROooool01_o^k^ko
<S8bo`000?lb<S;ok^k^ooooo`;o00000_ooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0?ooooo`;o00009_ooool2o`0001_ooooo0_l0
001Sooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01Cooooo
0_l0000Qooooo`;o00006oooool2o`0006?ooooo0021ooooo`Ko00000_ooool01Ol@413ooooooooo
oooooooo410@00[ooooo0_l000000onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02oooool2o`0000Oooooo0_l0002Sooooo`00ROooool01Ol0003ooooooooo
oooooooo000000[ooooo0_l000001?ooooooV9RHob4Q8Oo^k^h7ooooo`03ogMgMolb<S;ooooo00Co
oooo0ol0000;ooooo`;o0000[?ooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo00?ooooo0ol000000olb<S;oc<c<ooooo`04ooooo`03o`000?oooooooooo03So
oooo0_l0001oooooo`00ROooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooooooo
ool00_ooool2o`0000Sooooo00?o0000ooooooooool05_ooool2o`0000_ooooo0_l0000Cooooo`;o
0000Ooooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRH
V?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo0_l0000;oooo
o`;o00001oooool2o`0008_ooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnH
V9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo00cooooo0_l0000E
ooooo`;o00001oooool2o`0008_ooooo002/ooooo`03o`000?oooooooooo00cooooo0_l0000hoooo
o`;o0000LOooool009Wooooo0_l0000Aooooo`03o`000?oooooooooo00;o0000@oooool3o`00077o
oooo0027ooooo`;o00004?ooool2o`00017ooooo00?o0000ooooooooool00_l00007ooooo`;o0000
>_ooool2o`00013ooooo0_l0001Pooooo`00Qoooool2o`0002;ooooo1?l00009ooooo`;o0000>ooo
ool2o`0000oooooo0_l0001Pooooo`00ROooool2o`00023ooooo0_l0000_ooooo`;o00005oooool2
o`00077ooooo0029ooooo`;o00008Oooool00ol0003oooooooooo`06ooooo`;o00005_ooool2o`00
00gooooo0_l0002:ooooo`00[?ooool00ol0003oooooooooo`06ooooo`;o00005_ooool2o`0009Wo
oooo0024ooooo`;o00009_ooool00ol0003oooooooooo`0Booooo`;o00004_ooool2o`00097ooooo
0024ooooo`;o00009_ooool00ol0003oooooooooo`0Booooo`;o00004_ooool2o`00017ooooo0ol0
001mooooo`00[?ooool00ol0003oooooooooo`0_ooooo`;o00002?ooool3o`0007gooooo0026oooo
o`;o00009?ooool00ol0003oooooooooo`0Hooooo`;o00005Oooool2o`0008Sooooo0026ooooo`;o
00003_ooool2o`0001Cooooo0ol0000;ooooo`;o00002oooool2o`00033ooooo0_l0001]ooooo`00
U_ooool2o`0001Cooooo00?o0000ooooooooool02oooool2o`0000_ooooo0_l0000_ooooo`?o0000
KOooool00:cooooo00?o0000ooooooooool06?ooool2o`0001Gooooo0_l0000Hooooo`;o0000K_oo
ool00:cooooo00?o0000ooooooooool01Oooool2o`0002Sooooo0_l00028ooooo`00[?ooool00ol0
003oooooooooo`05ooooo`;o00007oooool2o`00097ooooo002/ooooo`03o`000?oooooooooo01?o
oooo0_l0000Aooooo`;o0000TOooool00:cooooo00?o0000ooooooooool03?ooool2o`0000Gooooo
0_l0002Tooooo`00[?ooool00ol0003oooooooooo`03ooooo`;o00001oooool2o`000:_ooooo002/
ooooo`03o`000?oooooooooo00?ooooo0_l0000[ooooo`;o00006Oooool2o`0006cooooo002/oooo
o`?o00000oooool2o`0000oooooo0_l0000Jooooo`;o00006?ooool3o`0006cooooo002>ooooo`;o
00007?ooool00ol0003oooooooooo`03ooooo`;o00003oooool2o`0003Cooooo0ol0001/ooooo`00
Q_ooool2o`0000Gooooo0ol0000Looooo`03o`000?oooooooooo0;Wooooo0009ooooo`Co000000?o
410@ooooooooool05_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`00
0?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@;ooooo2Ol00002ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
5_ooool00ol0003oooooooooo`0Eooooo`;o000000?oooooonk^k_lb<S800_l000000oo^k^kooooo
ooooo`03ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0?
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1?l000000ol@413oooooooooo`0Booooo`002ooo
ool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo
00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`0E
ooooo`03o`000?oooooooooo01Gooooo0_l000000oooooooMgMgoiRHV002o`000003ogMgMooooooo
oooo00?ooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8boooo
o`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0
3_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oo
oooo00?oMgMgoc8b<_ooool06Oooool00ol0003oooooooooo`0Dooooo`001_l00005ooooo`03o`00
0?oooooooooo013ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol0003oooooooooo`05ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo
410@00Kooooo0_l00004ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0Hooooo`05oa0@4?ooooooooooooooool@41001?ooool2o`0000Kooooo00?o
V9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`0=ooooo`06oa0@4?ooooooooooooooool@413o
oooo0_l0000=ooooo`03o`000?oooooooooo00gooooo00Go410@oooooooooooooooooa0@400=oooo
o`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Doooo
o`002oooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool00olQ
8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000?
ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`000006ooooo`;o00001Ooo
ool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo01Gooooo00?o0000ooooooooool04?oo
ool2o`0000Kooooo00Go0000ooooooooooooooooo`000004ooooo`;o00001oooool00onHV9So8B4Q
onk^kP07ooooo`03ogMgMolb<S;ooooo00kooooo00Ko0000ooooooooooooooooo`000?ooool2o`00
00cooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Q
ooooooooool01_ooool00omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo000;oooo
o`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<co
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`000003oooo
o`;o00002Oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05_ooool0
0ol0003oooooooooo`0@ooooo`;o00001_ooool00ol0003oooooooooo`02o`0000kooooo00?oMgMg
ofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000oooooooooooooooo
o`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo0000
00kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[ooooo00?o0000
ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol@413ooooooooooooooooo
410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`0Aooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@4100
0oooool2o`0000[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Hooooo`?o0000
1_ooool2o`0000Sooooo0_l00006ooooo`03oa0@4?oooooooooo00;o00000oooool2o`0000Oooooo
0_l000000ooooooo0000ooooo`03ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400>oooo
o`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Doooo
o`002oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@
413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool01_ooool2o`00013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`;o00001_ooool3o`00
0003oiRHV?l@413ooooo00?ooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
5?ooool000Wooooo00?oEEEEofIVI_l000006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
1Ol00004ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0000G
ooooo`03o`000?oooooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`01?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co
00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00006Oooool00omE
EEGoIVIVo`00000Fooooo`00[?ooool00ol0003oooooooooo`0Eooooo`;o00009_ooool2o`0007[o
oooo002/ooooo`03o`000?oooooooooo01Gooooo0_l00003ooooo`;o00008Oooool2o`0007[ooooo
0023ooooo`;o00009oooool00ol0003oooooooooo`0Jooooo`;o00005_ooool2o`0000Sooooo0_l0
001`ooooo`;o00000_ooool2o`0000Gooooo0023ooooo`;o00009oooool00ol0003oooooooooo`0E
ooooo`;o00006oooool2o`0000Sooooo0_l0001`ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM
1Oooool009?ooooo0_l0000Gooooo`03o`000?oooooooooo01Gooooo0_l0002Hooooo`04omgMgOl0
003o410@olc<c0Kooooo0007oooooooo0000C?l0000<ooooo`04onk^k_lQ8B7o410@onk^kPKooooo
0007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo0_l00008ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`04ob4Q8OmgMgOoMgMgoc8b<PKooooo
0007ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02Oooool2o`0001Oooooo0_l0
0003ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo00Wooooo0_l00002ooooo`;o00001Oooool0093ooooo0_l0000J
ooooo`03o`000?oooooooooo00Wooooo0_l0000Gooooo`;o0000UOooool0093ooooo0_l0000Joooo
o`03o`000?oooooooooo0;Wooooo002Booooo`;o00006?ooool00ol0003oooooooooo`0Aooooo`;o
00001oooool2o`0009gooooo002>ooooo`;o00000_ooool2o`0001Sooooo00?o0000ooooooooool0
4Oooool2o`0000Oooooo0_l0000Qooooo`;o0000N_ooool008Sooooo0_l00004ooooo`;o00007?oo
ool00ol0003oooooooooo`0mooooo`;o0000N_ooool008Sooooo0_l0000Rooooo`?o00006_ooool2
o`00033ooooo0_l0001[ooooo`00P?ooool2o`0002[ooooo00?o0000ooooooooool00_ooool2o`00
01Kooooo0_l0000`ooooo`;o0000Joooool0083ooooo0_l0000Zooooo`03o`000?oooooooooo00;o
oooo0_l0000jooooo`;o00003?ooool2o`0006_ooooo0026ooooo`;o00009?ooool00ol0003ooooo
ooooo`0Qooooo`;o00001_ooool2o`0001;ooooo0ol0000<ooooo`;o0000Joooool008Kooooo0_l0
000:ooooo`;o00006?ooool00ol0003oooooooooo`0Eooooo`;o00002_ooool2o`0000Kooooo0_l0
000Booooo`;o0000N_ooool009;ooooo0_l0000Hooooo`03o`000?oooooooooo00gooooo0_l00006
ooooo`;o0000X_ooool00:cooooo00?o0000ooooooooool03Oooool2o`0000Kooooo0_l0002Roooo
o`00[?ooool00ol0003oooooooooo`06ooooo`;o00003Oooool2o`0003?ooooo0_l0001]ooooo`00
[?ooool00ol0003oooooooooo`06ooooo`;o000000?oooooo`000?l000009oooool2o`0001Kooooo
0_l0001]ooooo`00P?ooool2o`0000Wooooo0_l00004ooooo`;o00006Oooool3o`0000Wooooo0_l0
000Wooooo`;o00006?ooool2o`0006_ooooo0020ooooo`;o00002Oooool2o`0000Cooooo0_l0000I
ooooo`03o`000?oooooooooo02Sooooo0_l0000Cooooo`;o00003Oooool2o`0006_ooooo002?oooo
o`;o00006oooool00ol0003oooooooooo`0Xooooo`;o00004oooool3o`0007Wooooo002?ooooo`;o
00006oooool00ol0003oooooooooo`0<ooooo`;o0000<?ooool2o`0007Wooooo002/ooooo`03o`00
0?oooooooooo00?ooooo1Ol00004ooooo`;o0000Zoooool00:cooooo00?o0000ooooooooool00ooo
ool5o`0004;ooooo0_l0001]ooooo`00Qoooool2o`0002?ooooo00?o0000ooooooooool00_l00000
0ooooooo0000o`00000;ooooo`;o0000:Oooool2o`0000gooooo0_l0001]ooooo`00Qoooool2o`00
00Cooooo0_l0000Mooooo`03o`000?oooooooooo00;o00003_ooool2o`0001kooooo0_l00009oooo
o`;o0000O?ooool008gooooo0_l0000Mooooo`?o00006_ooool2o`0001Cooooo1?l00025ooooo`00
[?ooool00ol0003oooooooooo`0Dooooo`;o00001?ooool2o`0001Kooooo0_l00025ooooo`00VOoo
ool2o`00017ooooo00?o0000ooooooooool03oooool2o`0000?ooooo0_l0002Sooooo`00VOooool2
o`00017ooooo00?o0000ooooooooool03oooool2o`000:Sooooo002/ooooo`03o`000?oooooooooo
01kooooo0_l0002Iooooo`00Q?ooool2o`0002Kooooo00?o0000ooooooooool07_ooool2o`00013o
oooo0_l00027ooooo`00Q?ooool2o`0002Kooooo00?o0000ooooooooool0<?ooool2o`0008Oooooo
002Eooooo`;o00005Oooool00ol0003oooooooooo`2iooooo`00UOooool2o`0001Gooooo1?l00003
ooooo`;o00008Oooool2o`00093ooooo002/ooooo`04o`000?oooooo0000o`0000?ooooo0_l0000P
ooooo`?o0000T?ooool00:cooooo00Co0000oooooooooooooooo0_l0000Sooooo`;o00004_ooool2
o`0007gooooo002/ooooo`04o`000?ooooooooooooooo`;o00006oooool2o`0001[ooooo0_l0000;
ooooo`;o0000L?ooool00:cooooo00?o0000ooooooooool04_ooool2o`0000[ooooo0_l0000Joooo
o`?o00002_ooool2o`00073ooooo002/ooooo`03o`000?oooooooooo01;ooooo0_l00003ooooo`;o
00008?ooool4o`0007cooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Goooo
o`;o00008?ooool2o`0007kooooo0029ooooo`03ogMgMonHV9Sooooo00;o00000oooool2o`0000;o
8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`0Mooooo`;o00006_ooool2o`0007kooooo0028ooooo`;o00000_ooool2o`0000?o
oooo0_l00007ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`0001Ko
oooo0_l00005ooooo`;o00001_ooool2o`0001;ooooo0_l0001nooooo`00R?ooool2o`0000?ooooo
00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool02?ooool2o`0000;ooooo0_l00008ooooo`;o00003Oooool2o`0009;ooooo
0029ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`04o`00
0?lQ8B7o0000oc8b<P;o00001?ooool00ol0003oooooooooo`08ooooo`;o00000_ooool2o`0001Ko
oooo0_l0002Cooooo`00ROooool01Ol@413ooooooooooooooooo410@00?ooooo0_l0000:ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0_l00004ooooo`03o`000?oooooooooo
02Cooooo0_l0002Cooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0_l00006oooo
o`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo04Oooooo0_l0001`ooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`04ooooo`;o0000@Ooo
ool2o`00073ooooo002/ooooo`03o`000?oooooooooo00Cooooo0_l0001@ooooo`;o0000HOooool0
0:cooooo00?o0000ooooooooool0;Oooool2o`0002Oooooo0_l0001Qooooo`00[?ooool00ol0003o
ooooooooo`0?ooooo`;o00007?ooool2o`0008[ooooo002/ooooo`?o00003oooool2o`00017ooooo
0_l0002Eooooo`00[?ooool00ol0003oooooooooo`09ooooo`;o00002Oooool2o`0000cooooo0_l0
002Eooooo`00QOooool2o`0002Gooooo00?o0000ooooooooool02Oooool2o`0000Wooooo0_l0000;
ooooo`;o0000U_ooool008Gooooo0_l00007ooooo`;o00007?ooool00ol0003oooooooooo`0Joooo
o`;o00001Oooool2o`0009Kooooo002>ooooo`;o00007?ooool00ol0003oooooooooo`0Jooooo`;o
0000WOooool008Wooooo0_l0000>ooooo`;o00004Oooool00ol0003oooooooooo`0Hooooo`;o0000
Woooool008Wooooo0_l0000>ooooo`;o00002oooool2o`0000Cooooo00?o0000ooooooooool03Ooo
ool2o`0000?ooooo0_l00004ooooo`;o0000Woooool0097ooooo0_l0000Cooooo`;o00001?ooool0
0ol0003oooooooooo`0<ooooo`?o00000oooool2o`0000_ooooo0_l0002Hooooo`00TOooool2o`00
01Wooooo0ol0000<ooooo`;o00002_ooool2o`0000Gooooo0_l0002Hooooo`00Soooool2o`0001_o
oooo00?o0000ooooooooool06?ooool2o`0009oooooo002?ooooo`;o00000oooool2o`0001Kooooo
00?o0000ooooooooool0^Oooool009Cooooo0_l0000Eooooo`;o00004_ooool2o`0001Oooooo0_l0
0009ooooo`;o0000Poooool00:_ooooo0_l0000Booooo`;o00005oooool2o`0000Wooooo0_l00023
ooooo`00X?ooool2o`0000[ooooo00?o0000ooooooooool0^Oooool00:3ooooo0_l000000ooooooo
0000o`000005ooooo`?o0000^oooool009;ooooo0_l0000?ooooo`;o00001Oooool3o`0002[ooooo
0_l0002?ooooo`00T_ooool2o`000003ooooool0003o000001Gooooo0ol0000Vooooo`Co0000Sooo
ool009Gooooo0_l0000Eooooo`03o`000?oooooooooo02Kooooo0_l0002Aooooo`00[?ooool00ol0
003oooooooooo`08ooooo`;o00000oooool2o`00037ooooo0_l0001gooooo`00X?ooool2o`0000[o
oooo00?o0000ooooooooool02?ooool2o`0000?ooooo0_l0000aooooo`;o0000Moooool00:3ooooo
0_l0000:ooooo`03o`000?oooooooooo01?ooooo0_l0000[ooooo`;o0000Moooool00:?ooooo0_l0
0007ooooo`03o`000?oooooooooo00;ooooo0_l0000?ooooo`;o0000:oooool2o`0007Oooooo002A
ooooo`;o00004?ooool2o`0000Oooooo00?o0000ooooooooool00_ooool2o`000;Gooooo002Aoooo
o`;o00006Oooool00ol0003oooooooooo`0Uooooo`;o0000T_ooool00:cooooo0ol0000Jooooo`;o
00002Oooool2o`0009;ooooo0028ooooo`;o00008_ooool00ol0003oooooooooo`0Jooooo`;o0000
WOooool008Cooooo0_l00002ooooo`;o00007?ooool2o`0000?ooooo0_l0000Jooooo`;o00005Ooo
ool2o`0001cooooo0_l0001Zooooo`00Q?ooool2o`0000;ooooo0_l00007ooooo`;o00003_ooool2
o`0000?ooooo0_l00002ooooo`?o00006_ooool2o`0001Gooooo0_l0000Looooo`;o0000J_ooool0
097ooooo0_l0000>ooooo`;o00001oooool3o`0003kooooo0_l0001kooooo`00[?ooool3o`0003co
oooo0_l0001kooooo`00TOooool01?o^k^ko<S8bo`000?lb<S82o`0000Cooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd00oooool5o`000;Wooooo002@ooooo`;o000000?oV9RHoooooonH
V9P00_l00004ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`02ooooo`?o00008Oooool2o`0001So
oooo0_l0001nooooo`00T?ooool2o`0000?ooooo00?o410@ooooooooool02?ooool2o`0000Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Oooooo`;o00006?ooool4o`0000gooooo
0_l0001]ooooo`00TOooool00ol0003oooooo`000002o`0000[ooooo0_l00003ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol0000kooooo`;o00003Oooool2o`0006gooooo002@ooooo`;o000000Cooooo
o`000?l0003o00003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
7oooool2o`0000Wooooo0_l0002=ooooo`00T?ooool2o`0000?ooooo00?o410@ooooooooool02_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01oooooo0_l00009ooooo`;o0000SOoo
ool0097ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Gooooo0ol0
000/ooooo`;o00003?ooool2o`0007oooooo0026ooooo`;o00002Oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l00004ooooo`?o0000:oooool3o`0000cooooo0_l0001oooooo`00Q_ooool2
o`0002;ooooo0ol0000Zooooo`?o0000S_ooool00:cooooo00?o0000ooooooooool0:?ooool3o`00
08kooooo002Fooooo`;o000000?oooooo`000?l000003Oooool2o`0000;ooooo00?o0000oooooooo
ool02_ooool2o`000:gooooo002Fooooo`;o000000?oooooo`000?l000003Oooool2o`0000;ooooo
0ol0000:ooooo`;o00004?ooool2o`0001Oooooo0_l00022ooooo`00[?ooool3o`0001cooooo0_l0
000Gooooo`;o0000P_ooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool0<oooool2o`0008Cooooo002/ooooo`03o`000?oooooooooo00Sooooo0_l0000Yooooo`;o
0000Q?ooool009kooooo0_l0000<ooooo`03o`000?oooooooooo00Sooooo0_l0002_ooooo`00R?oo
ool2o`0001Cooooo0_l0000<ooooo`03o`000?oooooooooo02?ooooo0_l0002Dooooo`00R?ooool2
o`0002;ooooo00?o0000ooooooooool01_ooool2o`0001_ooooo0_l0002Dooooo`00Yoooool2o`00
00?ooooo0ol00006ooooo`;o00003oooool2o`000:3ooooo002Wooooo`;o00000oooool00ol0003o
ooooooooo`06ooooo`;o00003oooool2o`0000Sooooo0_l0002Fooooo`00ROooool2o`00027ooooo
00?o0000ooooooooool05oooool2o`0000Sooooo0_l0000<ooooo`;o0000R?ooool008Wooooo0_l0
000Qooooo`03o`000?oooooooooo01Gooooo0_l0000:ooooo`;o00003?ooool2o`0008Sooooo002F
ooooo`;o00005?ooool00ol0003oooooooooo`0Eooooo`;o0000:?ooool2o`0007Sooooo002Foooo
o`;o00005?ooool00ol0003oooooooooo`0Eooooo`;o00006?ooool2o`0000kooooo0_l0001hoooo
o`00ROooool2o`00027ooooo00Co0000oooooooooooooooo0_l0000/ooooo`;o0000R?ooool008Wo
oooo0_l0000Qooooo`04o`000?ooooooooooooooo`;o0000]_ooool00:cooooo0ol0002iooooo`00
Woooool2o`0000Kooooo0_l00003ooooo`03o`000?oooooooooo0;Wooooo002Hooooo`;o00001Ooo
ool2o`0000Kooooo0_l00003ooooo`03o`000?oooooooooo0;Wooooo002Hooooo`;o00004_ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool2o`000;[o
oooo002@ooooo`;o00006_ooool2o`0000Kooooo0_l0002booooo`00T?ooool2o`0000?ooooo0_l0
000Eooooo`03o`000?oooooooooo00Gooooo0_l0002booooo`00UOooool2o`0001;ooooo0_l00000
0ooooooo0000ooooo`2jooooo`00U_ooool2o`00017ooooo0_l000001?oooooo0000o`000?l0002i
ooooo`00U_ooool2o`0000Oooooo0ol0000:ooooo`03o`000?oooooooooo0;Wooooo002Oooooo`?o
00002_ooool00ol0003oooooooooo`0Uooooo`;o0000T_ooool00:?ooooo0_l00007ooooo`03o`00
0?oooooooooo00Wooooo0_l0000Jooooo`;o0000T_ooool00:?ooooo0_l00007ooooo`03o`000?oo
oooooooo00Wooooo0_l0000Iooooo`;o0000Toooool008Wooooo00Cok^k^oc8b<_l0003o<S8b0_l0
0004ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1Oooool00ol0003oooooooooo`09ooooo`;o00006Oooool2o`0009?ooooo0029ooooo`04ogMgMonH
V9SooooooiRHV0;o00001?ooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05oa0@4?ooooooooooooooool@4100
3Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
^Oooool008Sooooo0_l00003ooooo`03o`000?oooooooooo00cooooo00?o8B4Qooooooooool01_oo
ool00omgMgOo<S8booooo`04ooooo`?o0000^Oooool008Sooooo0_l00003ooooo`03o`000?oooooo
oooo00cooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool0^Oooool008Wooooo00Go410@oooooooooooooooooa0@4006ooooo`;o00001_oo
ool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Gooooo0ol0000Rooooo`;o0000Uooo
ool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`;o00000oooool00ol@413ooooooooo
o`02o`0000Cooooo00?o0000ooooooooool01Oooool3o`0002;ooooo0_l0002Gooooo`00ROooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool00ol0003ooooooooo
o`2iooooo`00XOooool2o`0000Wooooo00?o0000ooooooooool03oooool2o`000:Sooooo002Ooooo
o`Co00002Oooool00ol0003oooooooooo`0?ooooo`;o0000Z?ooool009oooooo0_l0000;ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0:ooo
ool2o`0008cooooo002/ooooo`03o`000?oooooooooo02_ooooo0_l0002<ooooo`00VOooool2o`00
017ooooo00?o0000ooooooooool0^Oooool009Wooooo0ol0000@ooooo`03o`000?oooooooooo0;Wo
oooo002Jooooo`;o00003oooool2o`000;_ooooo002Looooo`;o00003Oooool2o`000;_ooooo002L
ooooo`;o00003?ooool3o`000;_ooooo002Zooooo`Go00001_ooool2o`000;7ooooo002/ooooo`03
o`000?oooooooooo00Kooooo0_l0002aooooo`00XOooool2o`0000Wooooo00?o0000ooooooooool0
^Oooool00:7ooooo0_l00009ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002Gooooo`;o00004oooool00ol0003oooooooooo`02ooooo`;o0000]Oooool009Oo
oooo0_l0000Cooooo`03o`000?oooooooooo00;ooooo0_l0002eooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool01?l0003oooooo`000?l0002hooooo`00[?ooool4o`000;Sooooo002/
ooooo`;o0000^_ooool00:cooooo0_l0002jooooo`00Zoooool2o`000;_ooooo002Yooooo`Co0000
^oooool00:Wooooo0_l000000ooooooo0000ooooo`2jooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00Toooool2o`0000gooooo0_l00008ooooo`03o`000?oooooooooo0;Wooooo002Cooooo`;o
00003Oooool2o`0000Sooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?oo
ool00ol0003oooooooooo`0Eooooo`;o0000X_ooool00:cooooo00?o0000ooooooooool00_ooool2
o`00017ooooo0_l0002Rooooo`00[?ooool01?l0003oooooooooooooool3o`000;Gooooo002/oooo
o`04o`000?ooooooooooooooo`;o0000]_ooool00:;ooooo1?l000000ol@413oooooooooo`03oooo
o`03o`000?oooooooooo0;Wooooo002Tooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0^Oooool00:Cooooo00?o0000ooooooooool01Oooool3o`000;Wooooo002Tooooo`03o`000?oo
oooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo
0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Rooooo`03oeEEEOmVIVKo00000<?ooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Zooooo`04oa0@
4?l0003o0000o`000;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oo
oooooooo0;[ooooo002[ooooo`06o`000?mgMgOo0000o`000?mEEEGok^k^]oooool00:_ooooo00Ko
0000oeEEEOo^k^koooooogMgMomEEEFgooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03o`00
0?oooooooooo0;Gooooo002[ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0]Ooo
ool00:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomVIVJgooooo`00Z_ooool00ol@413o0000ogMg
M`02o`000003ofIVI_o^k^kooooo0;Kooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.52956 .84089 Mdot
.44099 .1183 Mdot
.50402 .4553 Mdot
.5503 .53383 Mdot
.42328 .28312 Mdot
.61363 .35315 Mdot
.51745 .488 Mdot
.41261 .0943 Mdot
.57958 .86241 Mdot
.56055 .56384 Mdot
.43192 .71017 Mdot
.49534 .01635 Mdot
.66963 .49607 Mdot
.47888 .78507 Mdot
.48178 .01412 Mdot
.41588 .50466 Mdot
.61148 .46765 Mdot
.66998 .52072 Mdot
.5741 .57527 Mdot
.43102 .09473 Mdot
.66685 .49967 Mdot
.55857 .18408 Mdot
.5841 .2297 Mdot
.66749 .55444 Mdot
.6386 .19494 Mdot
.54047 .74552 Mdot
.41471 .40378 Mdot
.57744 .50606 Mdot
.47954 .04953 Mdot
.44136 .11977 Mdot
.66323 .54666 Mdot
.56768 .88159 Mdot
.36717 .55295 Mdot
.58013 .68852 Mdot
.41113 .73458 Mdot
.41156 .83282 Mdot
.69298 .4221 Mdot
.54725 .33587 Mdot
.50723 .07466 Mdot
.55069 .07247 Mdot
.66102 .22633 Mdot
.49739 .85078 Mdot
.46582 .1267 Mdot
.45632 .89498 Mdot
.57228 .77156 Mdot
.57813 .37481 Mdot
.52601 .69892 Mdot
.64365 .75974 Mdot
.41839 .26425 Mdot
.43377 .09362 Mdot
.65277 .73849 Mdot
.61264 .21405 Mdot
.67033 .16599 Mdot
.39507 .40188 Mdot
.42248 .20683 Mdot
.46271 .97503 Mdot
.42008 .0741 Mdot
.61315 .47632 Mdot
.69431 .60697 Mdot
.59329 .72745 Mdot
.58663 .41538 Mdot
.72353 .66293 Mdot
.50786 .07682 Mdot
.48988 .7294 Mdot
.38659 .77039 Mdot
.50943 .95442 Mdot
.56321 .51464 Mdot
.44129 .71129 Mdot
.56104 .37777 Mdot
.6602 .60239 Mdot
.6084 .60096 Mdot
.446 .36511 Mdot
.55982 .56173 Mdot
.54797 .38202 Mdot
.50694 .07581 Mdot
.44246 .48294 Mdot
.67072 .16659 Mdot
.59311 .50503 Mdot
.58326 .16806 Mdot
.41756 .71626 Mdot
.59967 .76779 Mdot
.42117 .17153 Mdot
.54409 .42593 Mdot
.47085 .86618 Mdot
.36592 .51098 Mdot
.42984 .3219 Mdot
.43892 .22593 Mdot
.47952 .18389 Mdot
.60717 .41989 Mdot
.43582 .69139 Mdot
.64086 .19973 Mdot
.35688 .51765 Mdot
.42519 .39624 Mdot
.54031 .27378 Mdot
.42499 .59393 Mdot
.36702 .71497 Mdot
.49258 .77376 Mdot
.65683 .72366 Mdot
.69209 .19781 Mdot
.6142 .46054 Mdot
.4848 .89661 Mdot
.58519 .33394 Mdot
.47267 .01048 Mdot
.41956 .81949 Mdot
.62358 .72138 Mdot
.56121 .73565 Mdot
.59854 .64074 Mdot
.54935 .67985 Mdot
.42714 .37857 Mdot
.65958 .60122 Mdot
.53052 .69185 Mdot
.55133 .5289 Mdot
.57984 .86394 Mdot
.37638 .55211 Mdot
.79442 .54722 Mdot
.51355 .36418 Mdot
.59299 .46908 Mdot
.43345 .94646 Mdot
.49228 .97428 Mdot
.67808 .36995 Mdot
.66845 .48415 Mdot
.74235 .57668 Mdot
.64448 .373 Mdot
.50239 .06422 Mdot
.65867 .60867 Mdot
.54179 .60031 Mdot
.37796 .40458 Mdot
.42811 .98215 Mdot
.39625 .69084 Mdot
.51905 .61882 Mdot
.59527 .24701 Mdot
.43002 .84626 Mdot
.54861 .07338 Mdot
.62749 .40002 Mdot
.53136 .18477 Mdot
.56165 .13619 Mdot
.69433 .41343 Mdot
.41963 .12719 Mdot
.56156 .53983 Mdot
.3713 .35751 Mdot
.50773 .03248 Mdot
.6688 .78714 Mdot
.52432 .33827 Mdot
.57708 .46934 Mdot
.61222 .47423 Mdot
.39005 .26277 Mdot
.37845 .72347 Mdot
.76162 .7038 Mdot
.55552 .65108 Mdot
.51473 .2273 Mdot
.74779 .54824 Mdot
.57447 .30466 Mdot
.51292 .25138 Mdot
.66608 .57419 Mdot
.43511 .4471 Mdot
.63529 .47408 Mdot
.67029 .33428 Mdot
.54986 .12601 Mdot
.44806 .96632 Mdot
.69029 .41279 Mdot
.67714 .35306 Mdot
.44031 .80342 Mdot
.59235 .17997 Mdot
.67762 .24846 Mdot
.49407 .9248 Mdot
.43671 .16988 Mdot
.52027 .85198 Mdot
.38991 .80073 Mdot
.5953 .78183 Mdot
.55078 .34345 Mdot
.68044 .35814 Mdot
.38084 .36732 Mdot
.42651 .39299 Mdot
.50565 .24074 Mdot
.42557 .27527 Mdot
.52577 .73395 Mdot
.36926 .59726 Mdot
.38265 .82801 Mdot
.63275 .45089 Mdot
.48063 .2958 Mdot
.48416 .05251 Mdot
.6587 .29896 Mdot
.59473 .12611 Mdot
.50819 .26984 Mdot
.67436 .25009 Mdot
.42971 .58626 Mdot
.60293 .825 Mdot
.56205 .89183 Mdot
.66275 .22292 Mdot
.51192 .15545 Mdot
.74571 .5052 Mdot
.39151 .25187 Mdot
.5368 .57417 Mdot
.7353 .60655 Mdot
.3748 .30281 Mdot
.72014 .35162 Mdot
.50867 .03069 Mdot
.51282 .2218 Mdot
.41485 .03793 Mdot
.54672 .77404 Mdot
.43004 .49555 Mdot
.43162 .44436 Mdot
.46302 .3195 Mdot
.40683 .42666 Mdot
.47138 .89771 Mdot
.50067 .30507 Mdot
.62659 .40364 Mdot
.55154 .54207 Mdot
.45765 .28689 Mdot
.41603 .61435 Mdot
.65086 .37525 Mdot
.59289 .48602 Mdot
.59365 .78463 Mdot
.45516 .24813 Mdot
.50901 .86783 Mdot
.58603 .42508 Mdot
.67952 .25304 Mdot
.42518 .48193 Mdot
.62098 .64088 Mdot
.52 .03846 Mdot
.59183 .45421 Mdot
.69266 .60412 Mdot
.60923 .75541 Mdot
.57146 .81711 Mdot
.41702 .46175 Mdot
.41781 .67933 Mdot
.42269 .161 Mdot
.4258 .39656 Mdot
.48965 .01714 Mdot
.73756 .6147 Mdot
.44637 .72858 Mdot
.44125 .56532 Mdot
.48004 .15489 Mdot
.41824 .36283 Mdot
.74486 .53485 Mdot
.53081 .29271 Mdot
.39607 .70047 Mdot
.65115 .39096 Mdot
.44595 .87844 Mdot
.72468 .65652 Mdot
.58325 .27432 Mdot
.52963 .88551 Mdot
.60899 .59748 Mdot
.54728 .91038 Mdot
.44737 .7051 Mdot
.64713 .28356 Mdot
.5581 .27711 Mdot
.61079 .58697 Mdot
.52323 .0938 Mdot
.71009 .32544 Mdot
.50742 .34425 Mdot
.53923 .54451 Mdot
.66119 .31819 Mdot
.54478 .733 Mdot
.48903 .21578 Mdot
.48289 .12144 Mdot
.44783 .41548 Mdot
.39065 .18894 Mdot
.67193 .69228 Mdot
.44987 .17241 Mdot
.41777 .36673 Mdot
.54449 .85909 Mdot
.53223 .4957 Mdot
.5558 .26538 Mdot
.57404 .76274 Mdot
.51401 .72661 Mdot
.56071 .23659 Mdot
.38417 .66547 Mdot
.50235 .81164 Mdot
.38213 .64882 Mdot
.45144 .13747 Mdot
.55978 .57536 Mdot
.40068 .42422 Mdot
.66975 .33116 Mdot
.52802 .31501 Mdot
.45866 .80356 Mdot
.63967 .76542 Mdot
.41791 .63418 Mdot
.63475 .45806 Mdot
.52557 .09297 Mdot
.48504 .71503 Mdot
.50793 .27289 Mdot
.68818 .40536 Mdot
.44706 .0268 Mdot
.54117 .70272 Mdot
.45866 .66617 Mdot
.45519 .79333 Mdot
.39311 .7503 Mdot
.54516 .28661 Mdot
.62336 .71503 Mdot
.69883 .56643 Mdot
.43826 .04239 Mdot
.69832 .55443 Mdot
.48714 .33713 Mdot
.70188 .55945 Mdot
.74101 .54409 Mdot
.43471 .9036 Mdot
.46276 .01679 Mdot
.72726 .78142 Mdot
.39881 .51788 Mdot
.55219 .21342 Mdot
.41038 .77972 Mdot
.55441 .90041 Mdot
.63759 .19085 Mdot
.50103 .75638 Mdot
.64762 .74727 Mdot
.52514 .77359 Mdot
.46709 .69418 Mdot
.64195 .34929 Mdot
.61356 .51229 Mdot
.66401 .44634 Mdot
.74837 .51294 Mdot
.52163 .39885 Mdot
.6084 .68187 Mdot
.54473 .77058 Mdot
.37135 .62562 Mdot
.5313 .54553 Mdot
.59993 .13358 Mdot
.73039 .40882 Mdot
.61318 .87904 Mdot
.4987 .73485 Mdot
.63313 .42426 Mdot
.45314 .855 Mdot
.55445 .13372 Mdot
.40698 .58153 Mdot
.43015 .53111 Mdot
.5074 .40115 Mdot
.60801 .59537 Mdot
.47768 .00583 Mdot
.64885 .29126 Mdot
.42509 .59662 Mdot
.61959 .29145 Mdot
.50568 .66833 Mdot
.46488 .31741 Mdot
.43033 .13969 Mdot
.60705 .33229 Mdot
.44014 .16208 Mdot
.44231 .80744 Mdot
.40558 .53287 Mdot
.63719 .12028 Mdot
.53721 .74743 Mdot
.39032 .35941 Mdot
.49449 .72092 Mdot
.39689 .8311 Mdot
.4113 .50723 Mdot
.40149 .19819 Mdot
.46111 .09752 Mdot
.48315 .2531 Mdot
.55473 .31402 Mdot
.67036 .78497 Mdot
.49353 .01412 Mdot
.70235 .56625 Mdot
.39249 .73767 Mdot
.40251 .60745 Mdot
.56747 .72856 Mdot
.37817 .4127 Mdot
.52311 .2067 Mdot
.48868 .01135 Mdot
.58354 .92027 Mdot
.51578 .90374 Mdot
.53784 .06182 Mdot
.60915 .14602 Mdot
.68436 .26553 Mdot
.50648 .36805 Mdot
.44369 .18534 Mdot
.50783 .03307 Mdot
.4021 .13381 Mdot
.51552 .40645 Mdot
.64208 .66368 Mdot
.54976 .71624 Mdot
.63232 .42899 Mdot
.50118 .8809 Mdot
.64238 .75545 Mdot
.4002 .72891 Mdot
.70123 .4838 Mdot
.60883 .21513 Mdot
.56884 .20426 Mdot
.7052 .5314 Mdot
.57913 .21911 Mdot
.6057 .14704 Mdot
.78721 .61294 Mdot
.6887 .4149 Mdot
.6376 .52299 Mdot
.43793 .5758 Mdot
.71332 .34473 Mdot
.60574 .40885 Mdot
.50028 .37097 Mdot
.6133 .14956 Mdot
.65832 .61208 Mdot
.43053 .54343 Mdot
.55687 .42609 Mdot
.57994 .63365 Mdot
.43279 .28076 Mdot
.62738 .79177 Mdot
.58363 .80665 Mdot
.73788 .58489 Mdot
.60463 .13894 Mdot
.60149 .61879 Mdot
.59219 .06929 Mdot
.58498 .68098 Mdot
.53082 .72316 Mdot
.48076 .80803 Mdot
.49975 .61583 Mdot
.45175 .01841 Mdot
.48556 .01062 Mdot
.41288 .43148 Mdot
.46033 .26226 Mdot
.44973 .22826 Mdot
.46453 .23344 Mdot
.74086 .43608 Mdot
.53417 .25968 Mdot
.48848 .9304 Mdot
.53028 .35989 Mdot
.5166 .25931 Mdot
.52908 .56384 Mdot
.48925 .18599 Mdot
.59289 .64808 Mdot
.4624 .2127 Mdot
.51586 .34734 Mdot
.74525 .56166 Mdot
.37038 .371 Mdot
.44958 .55025 Mdot
.39729 .62947 Mdot
.59866 .63999 Mdot
.6351 .53138 Mdot
.52866 .76195 Mdot
.52814 .28556 Mdot
.72144 .36641 Mdot
.35754 .41475 Mdot
.38962 .63588 Mdot
.78944 .4438 Mdot
.42401 .83547 Mdot
.53725 .44056 Mdot
.56462 .88105 Mdot
.52091 .04714 Mdot
.42655 .68418 Mdot
.45331 .10571 Mdot
.6459 .13191 Mdot
.47366 .25318 Mdot
.45487 .67957 Mdot
.50498 .77531 Mdot
.54479 .85963 Mdot
.44103 .79912 Mdot
.37449 .21556 Mdot
.42841 .42074 Mdot
.40191 .6687 Mdot
.49724 .85229 Mdot
.44111 .68904 Mdot
.51227 .3632 Mdot
.54545 .36882 Mdot
.41209 .09634 Mdot
.53297 .48546 Mdot
.56772 .14547 Mdot
.40296 .2475 Mdot
.58716 .73839 Mdot
.37611 .52534 Mdot
.64229 .65998 Mdot
.60984 .5723 Mdot
.41414 .95263 Mdot
.56085 .4553 Mdot
.48871 .00903 Mdot
.71216 .32919 Mdot
.51632 .72039 Mdot
.70192 .56466 Mdot
.51639 .78622 Mdot
.59746 .38882 Mdot
.39888 .21118 Mdot
.47677 .89981 Mdot
.5689 .6046 Mdot
.55909 .32506 Mdot
.57841 .69495 Mdot
.71976 .68245 Mdot
.50894 .15383 Mdot
.44199 .50144 Mdot
.42658 .19681 Mdot
.40735 .64928 Mdot
.50534 .36245 Mdot
.48913 .74893 Mdot
.39336 .43531 Mdot
.53023 .18158 Mdot
.463 .30085 Mdot
.56815 .67115 Mdot
.5042 .96025 Mdot
.41969 .30058 Mdot
.59453 .71747 Mdot
.576 .44903 Mdot
.57506 .47412 Mdot
.52465 .52684 Mdot
.79613 .53149 Mdot
.52263 .5523 Mdot
.43547 .1285 Mdot
.69289 .59286 Mdot
.47672 .93443 Mdot
.56896 .41284 Mdot
.44457 .07285 Mdot
.56234 .08712 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool2o`0000Kooooo00?o0000ooooooooool0^Oooool00:?ooooo0ol0
00001?oooooo0000o`000?l00002ooooo`03o`000?oooooooooo0;Wooooo002Sooooo`;o00000_oo
ool3o`0000;ooooo00?o0000ooooooooool0^Oooool009oooooo0_l000001OooooooEEEEofIVI_l0
003ooooo00Oo0000^oooool009cooooo0_l000000ooooooo0000o`000005ooooo`Oo0000^oooool0
09cooooo0_l0000:ooooo`;o00000_ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wo
oooo002Jooooo`;o00004?ooool00ol0003oooooooooo`2iooooo`00V_ooool2o`00013ooooo00Co
0000ooooool0003o0000^?ooool00:cooooo00Co0000ooooool0003o0000^?ooool008oooooo0_l0
000Kooooo`04o`000?oooooo0000o`000;Sooooo002?ooooo`;o00006oooool00ol0003ooooooooo
o`03ooooo`;o0000]?ooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo00?ooooo0_l0002d
ooooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool00oooool2o`000;Cooooo002Uooooo`;o
00001Oooool00ol0003oooooooooo`03ooooo`;o0000]?ooool00:Gooooo0ol00004ooooo`?o0000
^Oooool00:Kooooo0_l00004ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`03o`000?oooooooooo00Wooooo0_l0002^ooooo`00[?ooool2o`0000[o
oooo0_l0002^ooooo`00[?ooool2o`000;[ooooo002/ooooo`03o`000?oooooooooo01_ooooo0_l0
002Looooo`00TOooool2o`0000Kooooo0_l0000Aooooo`03o`000?oooooooooo00gooooo0_l0000<
ooooo`;o0000W?ooool0097ooooo0_l00006ooooo`;o00004Oooool4o`0000cooooo0_l0002Zoooo
o`00[?ooool01?l0003oooooo`000?l0002hooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0Aooooo`;o0000Y_oo
ool00:cooooo00?o0000ooooooooool04Oooool2o`000:Kooooo002?ooooo`;o00001?ooool3o`00
01Cooooo00?o0000ooooooooool01?ooool3o`000;;ooooo002?ooooo`;o00001?ooool3o`0000Oo
oooo0_l0000;ooooo`03o`000?oooooooooo00Cooooo0ol0002booooo`00Soooool2o`0000kooooo
0_l0000;ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool009cooooo0_l0000>
ooooo`03o`000?oooooooooo0;Wooooo002Looooo`;o00003_ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00ROoo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B43ooooo`;o000000?oooooo`000?o^k^h0
1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0^Oooool008Wooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q0oooool2o`000003oooooomEEEGoZJVY00So
oooo00?oMgMgo`000?l000001?ooool00ol0003oooooooooo`0Zooooo`;o0000SOooool0087ooooo
1_l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`;o
00001?ooool3o`0002[ooooo0_l0002=ooooo`00ROooool01Ol0003ooooooooooooooooo000000?o
oooo0_l00003ooooo`;o00001?ooool01?lQ8B7oooooooooooooool2o`0000?ooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`0=ooooo`;o00003Oooool2o`0009_ooooo0029ooooo`05
o`000?ooooooooooooooool000000oooool2o`0000?ooooo0_l00004ooooo`04oeEEEOo<c<cooooo
ooooo`?o000000Co8B4Qo`000?lb<S;oc<c<1Oooool00ol0003oooooooooo`0=ooooo`;o00003Ooo
ool2o`0000oooooo0_l0002:ooooo`00ROooool01Ol@413oooooo`000?l0003o410@00kooooo00?o
ZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo0_l0
000=ooooo`;o00003Oooool2o`0008[ooooo0029ooooo`05ogMgMonHV9So0000o`000?mgMgL02ooo
ool00ol@413oooooooooo`02o`0000Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0?ooooo`Co00002oooool2o`0009Wooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01ooo
ool2o`0000;ooooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`0Aooooo`;o00003?oo
ool2o`0009Sooooo002Eooooo`;o00005Oooool00ol0003oooooooooo`0Oooooo`;o0000V?ooool0
0:cooooo00?o0000ooooooooool04oooool2o`0000[ooooo1?l0002Fooooo`00[?ooool00ol0003o
ooooooooo`0Cooooo`;o00002_ooool5o`0009Gooooo002/ooooo`?o00008_ooool2o`0009Gooooo
002Uooooo`;o00001Oooool00ol0003oooooooooo`02o`000;Oooooo002Uooooo`;o00001Oooool0
0ol0003oooooooooo`02o`000;Oooooo002Booooo`;o00001?ooool2o`0001;ooooo00?o0000oooo
ooooool0^Oooool009;ooooo0_l00004ooooo`;o00004_ooool00ol0003oooooooooo`2iooooo`00
[?ooool00ol0003oooooooooo`0Hooooo`;o00006oooool2o`0008;ooooo002Gooooo`;o00004ooo
ool00ol0003oooooooooo`0Hooooo`;o00006oooool2o`0008;ooooo002Booooo`;o00000oooool2
o`0000;ooooo0_l0000?ooooo`03o`000?oooooooooo0;Wooooo002Booooo`;o00001oooool2o`00
00oooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`0Kooooo`;o0000W?ooool00:cooooo
00?o0000ooooooooool01oooool2o`0001;ooooo0_l0002Looooo`00VOooool2o`0000[ooooo0_l0
00000ooooooo0000o`000002ooooo`03o`000?oooooooooo00Oooooo0_l00007ooooo`;o0000Yooo
ool008Oooooo0_l0000@ooooo`;o00002_ooool2o`000003ooooool0003o000000;ooooo00?o0000
ooooooooool01oooool2o`0000Oooooo0_l0002Wooooo`00Qoooool2o`0002?ooooo00?o0000oooo
ooooool0:_ooool2o`0008gooooo002/ooooo`03o`000?oooooooooo02[ooooo0_l0002=ooooo`00
Roooool2o`0000Kooooo0_l0000Gooooo`03o`000?oooooooooo02[ooooo0_l0000@ooooo`;o0000
Noooool008_ooooo0_l00006ooooo`;o00005oooool3o`0002_ooooo0_l0000?ooooo`;o0000Nooo
ool00:cooooo00?o0000ooooooooool04oooool2o`0001Kooooo0_l0002<ooooo`00T_ooool2o`00
01Sooooo00?o0000ooooooooool01?ooool2o`0000gooooo0_l0002Tooooo`00T_ooool2o`0001So
oooo00?o0000ooooooooool01?ooool2o`000;?ooooo002:ooooo`;o00004oooool2o`0000_ooooo
00?o0000ooooooooool03_ooool2o`000:Wooooo0022ooooo`;o00001_ooool2o`0001?ooooo0_l0
0007ooooo`;o00000_ooool00ol0003oooooooooo`0>ooooo`;o00004?ooool4o`0009Gooooo0022
ooooo`;o00009?ooool2o`0000;ooooo00?o0000ooooooooool05oooool2o`0000Oooooo1?l0002E
ooooo`00[?ooool01?l0003oooooooooooooool2o`0001Cooooo0_l0002Pooooo`00[?ooool3o`00
0003ooooool0003o000002oooooo0_l00025ooooo`00Uoooool2o`0000;ooooo0_l0000?ooooo`04
o`000?ooooooooooooooo`;o0000;oooool2o`0008Gooooo002Gooooo`;o00000_ooool2o`0000oo
oooo00Co0000oooooooooooooooo0_l0000Eooooo`;o00006?ooool2o`0008Gooooo002Pooooo`;o
00002_ooool00ol0003oooooooooo`0Hooooo`;o0000Woooool00:3ooooo0_l0000:ooooo`03o`00
0?oooooooooo017ooooo0_l0002Vooooo`00[?ooool3o`00017ooooo0_l0002Vooooo`00TOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1Oooool3o`000;Wooooo002Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Looooo`;o0000Voooool008Wooooo1_l0
0002ooooo`05oa0@4?ooooooooooooooool@41001oooool2o`0000Oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Looooo`;o00006?ooool3o`00083ooooo0028ooooo`;o00000_oo
ool2o`0000?ooooo00Go0000ooooooooooooooooo`000007ooooo`;o00001_ooool00omgMgOo0000
o`000004ooooo`?o000000?oooooo`000?l00000<oooool4o`0007oooooo0028ooooo`;o00001ooo
ool01Ol0003ooooooooooooooooo000000cooooo0ol000000olb<S;o0000o`000004ooooo`04o`00
0?ooooooooooooooo`;o0000=Oooool2o`0007oooooo002Aooooo`05oa0@4?ooooooooooooooool@
41003?ooool3o`0000Oooooo00?o0000ooooooooool0^Oooool0097ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool2o`0000Co
oooo0_l0002_ooooo`00Qoooool2o`0000Sooooo0ol000000olb<S;ok^k^ooooo`07ooooo`;o0000
0_ooool4o`0000Kooooo00?o0000ooooooooool00_ooool2o`0000Cooooo0_l0002_ooooo`00Qooo
ool2o`0000Sooooo0_l0000;ooooo`;o00003?ooool00ol0003oooooooooo`0?ooooo`;o0000:?oo
ool2o`0007kooooo002/ooooo`04o`000?oooooo0000o`0000kooooo0_l0000Xooooo`;o0000O_oo
ool00:cooooo00Co0000ooooool0003o00002Oooool2o`0000cooooo0_l0002Oooooo`00Toooool2
o`0001Oooooo1?l00009ooooo`;o00001?ooool2o`0000Kooooo0_l0002Oooooo`00Toooool2o`00
01Oooooo00?o0000ooooooooool04?ooool2o`000:Oooooo002Booooo`;o000000?oooooo`000?l0
00005Oooool00ol0003oooooooooo`2iooooo`00T_ooool2o`000003ooooool0003o000001Gooooo
00?o0000ooooooooool01_ooool2o`0002Gooooo0_l0002:ooooo`00W_ooool2o`0000cooooo00?o
0000ooooooooool01_ooool2o`0000?ooooo0_l0000Pooooo`;o0000R_ooool009kooooo0_l0000<
ooooo`03o`000?oooooooooo00_ooooo0_l0000Gooooo`;o00002?ooool2o`0008Wooooo002/oooo
o`03o`000?oooooooooo00Oooooo0_l0000Kooooo`;o00002?ooool2o`0008Wooooo002Uooooo`;o
00001Oooool00ol0003oooooooooo`07ooooo`;o0000/?ooool0097ooooo0_l0000<ooooo`;o0000
1?ooool2o`0000Gooooo0ol0000aooooo`;o0000Q_ooool008;ooooo0_l0000=ooooo`;o00003?oo
ool2o`0000_ooooo00?o0000ooooooooool0<Oooool2o`0008Kooooo0022ooooo`;o0000:?ooool2
o`0001Kooooo0_l0002Rooooo`00[?ooool2o`0001Kooooo0_l0002Rooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`06ooooo`;o00001oooool2o`000:Sooooo
002Oooooo`?o00002_ooool00ol0003oooooooooo`06ooooo`;o00001oooool2o`00027ooooo0_l0
0025ooooo`00U?ooool2o`0000Wooooo0ol0000:ooooo`03o`000?oooooooooo03;ooooo0_l00025
ooooo`00U?ooool2o`0001Kooooo0ol0000@ooooo`;o0000<?ooool2o`0007Gooooo002/ooooo`03
o`000?oooooooooo013ooooo0_l0000`ooooo`;o0000MOooool00:cooooo00?o0000ooooooooool0
=Oooool2o`0000cooooo0_l0001dooooo`00[?ooool00ol0003oooooooooo`0Iooooo`;o00001Ooo
ool2o`0001?ooooo0_l0000<ooooo`;o0000M?ooool00:Oooooo0_l00003ooooo`03o`000?oooooo
oooo00cooooo0_l0000;ooooo`;o00001Oooool2o`0001?ooooo0_l00022ooooo`00Yoooool2o`00
00?ooooo00?o0000ooooooooool01Oooool2o`0000Gooooo0_l0002[ooooo`00[?ooool00ol0003o
ooooooooo`05ooooo`;o00001_ooool2o`000:[ooooo002/ooooo`04o`000?oooooo0000o`0000co
oooo0_l0000dooooo`;o0000M?ooool00:cooooo00Go0000ooooool0003o0000ooooo`02o`0002Oo
oooo0_l0000Fooooo`;o0000M?ooool00:cooooo0ol00002ooooo`;o00009oooool2o`0000[ooooo
0_l0000<ooooo`;o0000L_ooool00:cooooo00?o0000ooooooooool08_ooool2o`0001?ooooo0_l0
000<ooooo`;o0000L_ooool0087ooooo0_l0000Yooooo`03o`000?oooooooooo02;ooooo0_l0000D
ooooo`;o0000Ooooool0087ooooo0_l00004ooooo`;o00008oooool00ol0003oooooooooo`07oooo
o`;o0000;oooool2o`0007oooooo0027ooooo`;o00002?ooool2o`0000Oooooo0_l0000@ooooo`?o
000000?oooooo`000?l000001?ooool2o`000;3ooooo0024ooooo`;o00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00;ooooo0ol00002ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool6o`0004?ooooo0_l0001aooooo`00POooool2o`000003ooooool0003o000000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`;o000000?oooooob4Q8OlQ8B401?ooool01OnH
V9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool4o`0000_ooooo0_l0000Y
ooooo`;o00003Oooool2o`00077ooooo0021ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`;o00003Oooool2
o`0001kooooo0_l00009ooooo`;o0000P?ooool008Wooooo00Go0000ooooooooooooooooo`00000=
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0001Kooooo0_l0000D
ooooo`Co0000ROooool008Wooooo00Go0000ooooooooooooooooo`000006ooooo`;o00001_ooool0
0omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`0Aooooo`;o00000oooool2o`0001Kooooo0_l00029ooooo`00ROooool01Ol@413ooooooooooooo
oooo410@00Kooooo0_l00007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0<ooooo`;o00000oooool2o`000:Kooooo0029ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0<ooooo`;o0000Zoooool008Wooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000oooooooo
ool07Oooool2o`0009[ooooo002/ooooo`03o`000?oooooooooo01gooooo0_l0000?ooooo`;o0000
ROooool009?ooooo0_l0000Gooooo`03o`000?oooooooooo02kooooo0_l00029ooooo`00Toooool2
o`0001Oooooo00?o0000ooooooooool0^Oooool009?ooooo0_l0000Gooooo`Co00000oooool2o`00
027ooooo0_l0002@ooooo`00Poooool2o`0000Cooooo0_l00004ooooo`;o00006oooool01?l0003o
ooooo`000?l00003ooooo`;o00008?ooool3o`00093ooooo0023ooooo`;o00001?ooool2o`0000Co
oooo0_l0000Kooooo`03o`000?oooooooooo00;ooooo0_l0000Rooooo`;o00004oooool2o`0007co
oooo002/ooooo`03o`000?oooooooooo00;ooooo0_l0000Kooooo`;o00006_ooool2o`0000cooooo
0_l0001^ooooo`00Poooool2o`0002Oooooo00?o0000ooooooooool04oooool2o`0000[ooooo0_l0
000Jooooo`Co00002_ooool2o`0006kooooo001mooooo`;o00001?ooool2o`0001Gooooo0_l0000@
ooooo`03o`000?oooooooooo01?ooooo0_l00004ooooo`;o00008?ooool4o`0007[ooooo001moooo
o`;o00006oooool2o`00013ooooo00?o0000ooooooooool06Oooool2o`00023ooooo0_l0001loooo
o`00U?ooool2o`0001Kooooo00?o0000ooooooooool08?ooool2o`0001[ooooo0_l0001kooooo`00
Roooool2o`0000Oooooo0_l0000Fooooo`?o00006Oooool2o`0000Gooooo0_l00007ooooo`;o0000
4Oooool2o`0007_ooooo002;ooooo`Co00007Oooool00ol0003oooooooooo`0;ooooo`;o00000_oo
ool2o`0000Sooooo0_l0000>ooooo`;o0000S_ooool008gooooo1?l0000Kooooo`03o`000?oooooo
oooo00_ooooo0_l00002ooooo`;o00005oooool2o`0008oooooo002?ooooo`;o00006oooool00ol0
003oooooooooo`0Xooooo`;o0000Soooool008Sooooo0_l0000Rooooo`03o`000?oooooooooo04co
oooo0_l0001[ooooo`00R?ooool2o`0002;ooooo00?o0000ooooooooool02Oooool2o`00047ooooo
0_l0001[ooooo`00[?ooool00ol0003oooooooooo`09ooooo`;o0000DOooool2o`0005_ooooo002E
ooooo`;o00005Oooool00ol0003oooooooooo`0cooooo`;o00009oooool2o`0005_ooooo002Eoooo
o`?o00005?ooool00ol0003oooooooooo`0Fooooo`;o00006oooool2o`0008Cooooo002Fooooo`;o
00005?ooool3o`0001Kooooo0_l0000@ooooo`;o0000Soooool00:cooooo0ol0000Aooooo`;o0000
2?ooool2o`0000_ooooo0_l0002?ooooo`00[?ooool3o`00017ooooo0_l00008ooooo`;o00003?oo
ool2o`0008kooooo0009ooooo`Co000000?o410@ooooooooool05_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8b
omgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0
003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00003
ooooo`Co000000?o<S8bomgMgOooool05Oooool00ol0003oooooooooo`0Hooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2o`0000Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
3oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^ko
oooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`Co000000?o410@ooooooooool04_oo
ool000_ooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo0_l00002oooo
o`03ogMgMolb<S;ooooo01Gooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_l00004ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8boooo
o`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0
3_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oo
oooo00?oMgMgoc8b<_ooool06Oooool00ol0003oooooooooo`0Dooooo`001_l00005ooooo`03o`00
0?oooooooooo013ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol0003oooooooooo`05ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo01Sooooo00Go410@oooooooooooooooooa0@4004ooooo`;o00001_ooool00onHV9So8B4Qonk^
kP09ooooo`03o`000?oooooooooo00gooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`00
0?oooooooooo00gooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00So
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003ooooo
ooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03
ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo
00kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMg
oc8b<_ooool05Oooool00ol0003oooooooooo`0Fooooo`?o00000_ooool2o`0000Cooooo0_l00007
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooo
oooo000000oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000kooooo
00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo
000;ooooo`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEE
EOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?oooooooooooooo
ool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Fooooo`03o`00
0?oooooooooo01Gooooo1?l00002ooooo`;o00001Oooool2o`0000Gooooo0_l000000omgMgOoIVIV
ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo0000
00cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003_oo
ool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06_ooool00ol0003ooooo
ooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05oa0@4?ooooooooooooooool@4100
3_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06?ooool3o`0001Gooooo0_l000000ooo
oooo410@ooooo`02ooooo`03oa0@4?oooooooooo00?ooooo0_l00005ooooo`;o000000?oooooo`00
0?ooool00oooool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgoooo
o`03ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000
ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooo
oc8b<P04ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Sooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o00001?ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo
00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooooooo
ool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05?ooool000Wooooo00?oEEEEofIV
I_l000006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00004?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00004ooooo`;o00004Oooool00ol0003o
ooooooooo`0Hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7o
c<c<00Cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00013ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0001Wooooo00?oEEEEofIVI_l00000
5_ooool009?ooooo0_l00004ooooo`;o00004Oooool00ol0003oooooooooo`07ooooo`;o00004_oo
ool2o`0001Oooooo0_l00009ooooo`;o0000N?ooool00:cooooo00?o0000ooooooooool00_ooool2
o`0000?ooooo0_l0000Booooo`;o00005oooool2o`0000Wooooo0_l0001hooooo`00[?ooool00ol0
003oooooooooo`02ooooo`;o0000Z_ooool2o`0000;ooooo0_l00005ooooo`00[?ooool00ol0003o
ooooooooo`2^ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1Oooool009Cooooo0_l0000Foooo
o`03o`000?oooooooooo00Oooooo0_l0000/ooooo`;o0000N?ooool01?oMgMgo0000oa0@4?o<c<`6
ooooo`001oooooooo`0004co00003?ooool01?o^k^ko8B4Qoa0@4?o^k^h6ooooo`001oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooooooo0_l00002
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02
ooooo`;o000000?oooooo`000?ooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`04ob4Q8OmgMgOo
MgMgoc8b<PKooooo0007ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Sooooo1?l0000Jooooo`03o`000?oooooo
oooo01Kooooo0_l00003ooooo`;o00002_ooool00ol0003oooooooooo`0Tooooo`?o0000:?ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Wooooo0_l00002ooooo`;o00001Oooool0
08kooooo1?l0000Jooooo`03o`000?oooooooooo01Kooooo0_l00003ooooo`;o0000<Oooool2o`00
06Wooooo001oooooo`;o0000:oooool00ol0003oooooooooo`0Rooooo`;o0000:oooool2o`0006So
oooo001oooooo`;o0000:oooool00ol0003oooooooooo`0Aooooo`;o00003oooool2o`0002_ooooo
0_l0001Xooooo`00O?ooool2o`0000cooooo0_l0000Pooooo`03o`000?oooooooooo017ooooo0_l0
002Vooooo`00O?ooool2o`0000cooooo0_l0000Pooooo`03o`000?oooooooooo03Gooooo0_l00022
ooooo`00Poooool2o`0002Oooooo0ol0000Zooooo`;o00002Oooool2o`0008;ooooo0023ooooo`;o
00009oooool00ol0003oooooooooo`05ooooo`;o00008oooool2o`0008gooooo002Eooooo`;o0000
5Oooool00ol0003oooooooooo`05ooooo`;o00001oooool2o`0001Wooooo0_l0000Eooooo`;o0000
7?ooool2o`0005Wooooo002<ooooo`;o00001oooool2o`0001Gooooo00?o0000ooooooooool03Ooo
ool3o`0001Wooooo0_l0000Eooooo`;o00007?ooool2o`0005Wooooo002<ooooo`;o00007_ooool0
0ol0003oooooooooo`0=ooooo`;o0000?_ooool2o`0006[ooooo002/ooooo`03o`000?oooooooooo
017ooooo0_l0000jooooo`;o0000J_ooool009Gooooo0_l0000Eooooo`03o`000?oooooooooo00ko
oooo0_l000000ooooooo0000o`00002Vooooo`00UOooool2o`0001Gooooo00?o0000ooooooooool0
1oooool2o`000003ooooool0003o000000;ooooo0_l0000Rooooo`;o00006?ooool2o`0006_ooooo
002/ooooo`03o`000?oooooooooo00Oooooo0_l000000ooooooo0000o`00000Vooooo`;o00006?oo
ool4o`0000kooooo0_l0001Iooooo`00P?ooool2o`000003ooooool0003o000001Kooooo0_l0000?
ooooo`?o00001?ooool2o`0004Sooooo0_l0000>ooooo`;o0000FOooool0083ooooo0_l000000ooo
oooo0000o`00000Fooooo`;o00003oooool00ol0003oooooooooo`04ooooo`;o0000;_ooool2o`00
00Sooooo0_l0001iooooo`00[?ooool00ol0003oooooooooo`0dooooo`;o00002?ooool2o`0007Wo
oooo002/ooooo`03o`000?oooooooooo013ooooo0_l0000]ooooo`;o00003Oooool2o`0006Wooooo
002/ooooo`03o`000?oooooooooo00Kooooo0_l00008ooooo`?o0000;?ooool2o`0000gooooo0_l0
001Yooooo`00V?ooool2o`0001;ooooo00?o0000ooooooooool01_ooool2o`0000Wooooo0_l0000[
ooooo`?o0000N?ooool009Sooooo0_l0000Booooo`03o`000?oooooooooo03kooooo0ol0001hoooo
o`00[?ooool00ol0003oooooooooo`09ooooo`;o00005_ooool2o`00013ooooo0_l00024ooooo`00
Uoooool2o`0001?ooooo0ol00009ooooo`;o00001Oooool2o`0000?ooooo0_l0000:ooooo`;o0000
4?ooool2o`0001Sooooo0_l0001Zooooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool04?oo
ool2o`0000?ooooo0_l0000fooooo`;o0000J_ooool008gooooo0_l0000Mooooo`03o`000?oooooo
oooo0;Wooooo002=ooooo`;o00001Oooool2o`0001Kooooo00?o0000ooooooooool0Boooool2o`00
06cooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`0Qooooo`;o0000:?ooool2o`0006co
oooo002/ooooo`03o`000?oooooooooo027ooooo0_l0002Fooooo`00Toooool2o`0001Oooooo00?o
0000ooooooooool08?ooool2o`0001[ooooo0_l0001kooooo`00P?ooool2o`00017ooooo0_l0000G
ooooo`03o`000?oooooooooo023ooooo0ol0000Iooooo`;o0000Noooool0083ooooo0_l0000Aoooo
o`;o00005oooool3o`0000[ooooo0_l0000Dooooo`?o00003_ooool2o`0008Kooooo002/ooooo`03
o`000?oooooooooo00[ooooo0_l0000Dooooo`;o00003oooool2o`0000Wooooo0_l0001kooooo`00
Roooool2o`0001oooooo00?o0000ooooooooool04oooool2o`0001cooooo0_l00009ooooo`?o0000
2oooool2o`0006gooooo002;ooooo`;o00007oooool00ol0003oooooooooo`0Cooooo`;o00007?oo
ool2o`0000[ooooo0_l0000;ooooo`;o0000KOooool00:cooooo00?o0000ooooooooool0<Oooool2
o`0002Sooooo0_l0001Looooo`00T?ooool2o`0001Wooooo0_l0000cooooo`;o00006?ooool2o`00
00kooooo0_l0001Looooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo0_l000000ooo
oooo8B4Qob4Q8@04ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo0_l00005
ooooo`;o00006Oooool2o`0002_ooooo0_l0001/ooooo`00ROooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo00?ooooo0_l0000Iooooo`;o0000VOooool0087ooooo0_l00006
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oo
oooooooo00?ooooo0ol0002iooooo`00POooool2o`0000Kooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`2iooooo`00ROooool3o`000003ooooool0003ooooo00gooooo00?oMgMgofIVI_ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0^Oooool008Wooooo00Go410@
o`000?l0003ooooooa0@4002ooooo`;o00002oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool05oooool2o`000:3ooooo0027ooooo`;o000000GoMgMg
oiRHV?ooooooV9RHogMgM`02ooooo`;o00001oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Gooooo`;o0000X?ooool008Oooooo0_l0
00001Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co
00001_ooool00ol0003oooooooooo`0Mooooo`;o0000V_ooool00:cooooo00?o0000ooooooooool0
7Oooool2o`0000Kooooo0_l0002Booooo`00[?ooool00ol0003oooooooooo`0Uooooo`;o0000T_oo
ool008Gooooo0_l00006ooooo`;o00007Oooool00ol0003oooooooooo`0Kooooo`;o0000W?ooool0
08Gooooo0_l00006ooooo`;o00007Oooool3o`0000oooooo0_l0000:ooooo`;o0000W?ooool00:co
oooo00?o0000ooooooooool03oooool2o`000:Sooooo002/ooooo`03o`000?oooooooooo04Oooooo
0_l0001`ooooo`00[?ooool00ol0003oooooooooo`0/ooooo`;o00006Oooool2o`00073ooooo002/
ooooo`03o`000?oooooooooo02_ooooo0ol0000Hooooo`;o0000LOooool008Gooooo0_l0000Goooo
o`;o00003?ooool00ol0003oooooooooo`0[ooooo`;o00006Oooool2o`00077ooooo0025ooooo`;o
00001?ooool2o`00017ooooo0_l0000<ooooo`?o00004oooool2o`000:Cooooo002;ooooo`;o0000
7oooool3o`0001?ooooo0_l0002Tooooo`00[?ooool3o`000;Wooooo002@ooooo`;o00002oooool2
o`0000gooooo00?o0000ooooooooool03Oooool2o`000:[ooooo002@ooooo`;o00002oooool2o`00
00gooooo00?o0000ooooooooool03Oooool2o`0000[ooooo0_l00005ooooo`;o00008oooool2o`00
07;ooooo002Cooooo`;o00005oooool00ol0003oooooooooo`0Iooooo`;o00001Oooool2o`0002?o
oooo0_l0001booooo`00Toooool2o`0000?ooooo0_l0000Booooo`03o`000?oooooooooo01Oooooo
0_l0002Pooooo`00ROooool2o`0000_ooooo1?l0000Booooo`03o`000?oooooooooo00Oooooo0_l0
000>ooooo`;o00007?ooool2o`0008;ooooo0029ooooo`;o00002oooool2o`0000Wooooo0_l00009
ooooo`03o`000?oooooooooo00Oooooo0_l0000=ooooo`;o00007Oooool2o`0008;ooooo002Qoooo
o`;o00002Oooool00ol0003oooooooooo`0Fooooo`;o0000XOooool008Wooooo0_l0000Qooooo`?o
00001Oooool2o`000;;ooooo0029ooooo`;o00008Oooool00ol0003oooooooooo`05ooooo`;o0000
0oooool2o`0004Oooooo0_l0001Tooooo`00V_ooool2o`00013ooooo00?o0000ooooooooool02_oo
ool2o`0004Oooooo0_l0001Tooooo`00UOooool2o`0000?ooooo0_l0000@ooooo`03o`000?oooooo
oooo0;Wooooo002Eooooo`;o000000?oooooo`000?l000004_ooool00ol0003oooooooooo`2ioooo
o`00P?ooool2o`0000kooooo0_l00006ooooo`;o00003Oooool2o`0000?ooooo00?o0000oooooooo
ool03Oooool2o`0001Kooooo0_l0002Booooo`00P?ooool2o`0000kooooo0_l0000Eooooo`;o0000
0oooool00ol0003oooooooooo`0=ooooo`;o00003Oooool2o`0000Oooooo0_l0002Booooo`00Z_oo
ool3o`0000Cooooo0_l0000Hooooo`;o00001oooool2o`0009;ooooo0023ooooo`;o00009Oooool5
o`0000;ooooo0_l00003ooooo`;o00007?ooool2o`0000Wooooo0_l00027ooooo`00Poooool2o`00
01Gooooo0_l0000@ooooo`04o`000?ooooooooooooooo`;o00001?ooool2o`0000[ooooo0_l00006
ooooo`;o00004oooool2o`0008Oooooo002;ooooo`;o00003Oooool2o`0000cooooo0_l00002oooo
o`04o`000?ooooooooooooooo`;o00004?ooool2o`0000Kooooo0_l0002Looooo`00Roooool2o`00
0003ooooool0003o000001Sooooo0_l00002ooooo`03o`000?oooooooooo00Gooooo0_l00004oooo
o`;o0000[?ooool008Sooooo0_l00004ooooo`;o00006oooool2o`0000Oooooo0_l00004ooooo`;o
00001?ooool2o`000:Kooooo0028ooooo`;o00008Oooool2o`0001?ooooo0_l00006ooooo`;o0000
5?ooool2o`0008Sooooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01Wooooo0_l0000Dooooo`;o
0000R?ooool0097ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo00[ooooo0_l0002]ooooo`00TOooool01Ol@413ooooo
oooooooooooo410@013ooooo00Co0000ooooool0003o00000_ooool00ol0003oooooooooo`09oooo
o`?o00008Oooool2o`0008[ooooo0028ooooo`;o00001oooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool00_l00002ooooo`?o00002Oooool2o`0002;ooooo0_l0002:oooo
o`00R?ooool2o`0000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Qooooo`;o00002Oooool2o`0008_ooooo002Aoooo
o`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`;o00008_ooool2
o`0000Wooooo0_l0002;ooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000
ooooooooool01oooool2o`0000Oooooo0_l0000Tooooo`;o0000Roooool0097ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`06ooooo`;o00003Oooool2
o`0001Gooooo0_l0002;ooooo`00[?ooool00ol0003oooooooooo`0Eooooo`;o00001_ooool2o`00
00cooooo0_l0002<ooooo`00Q_ooool2o`0002Cooooo00?o0000ooooooooool02oooool2o`00013o
oooo0_l0000<ooooo`;o0000S?ooool008Kooooo0_l0000Qooooo`;o000000?oooooo`000?ooool0
1_ooool2o`0000Cooooo0ol00006ooooo`;o0000Xoooool00:Wooooo0_l000001?oooooo0000o`00
0?l00005ooooo`;o00001Oooool2o`0000Kooooo0_l0002Sooooo`00S_ooool2o`0001cooooo0ol0
002iooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool07?ooool2o`0002[ooooo0_l0001_
ooooo`00YOooool2o`0000Gooooo00?o0000ooooooooool00_ooool2o`0001Oooooo0ol0000Goooo
o`;o00004Oooool2o`0006oooooo002Uooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`;o
00005oooool2o`0001Oooooo0ol00022ooooo`00[?ooool00ol0003oooooooooo`0Wooooo`;o0000
2oooool2o`0008?ooooo002Mooooo`;o00003Oooool00ol0003oooooooooo`0Wooooo`;o0000T?oo
ool009gooooo0_l0000=ooooo`03o`000?oooooooooo0;Wooooo0027ooooo`;o00003oooool2o`00
01;ooooo0ol0002iooooo`00Qoooool2o`0000oooooo0_l00004ooooo`;o00003?ooool00ol0003o
ooooooooo`2iooooo`00V?ooool3o`0000?ooooo0_l0000<ooooo`03o`000?oooooooooo01Sooooo
0_l0002Oooooo`00VOooool2o`0000[ooooo0_l00005ooooo`03o`000?oooooooooo01Sooooo0_l0
002Oooooo`00YOooool2o`0000Gooooo0_l0002jooooo`00[?ooool2o`000;[ooooo002Aooooo`;o
00006Oooool00ol0003oooooooooo`0Dooooo`;o0000Xoooool0097ooooo0_l0000Iooooo`03o`00
0?oooooooooo01Cooooo0_l0002Sooooo`00[?ooool3o`0001oooooo0_l0002Hooooo`00QOooool2
o`0002Gooooo00?o0000ooooooooool07oooool2o`0009Sooooo0025ooooo`;o00000oooool2o`00
023ooooo00?o0000ooooooooool0^Oooool008[ooooo0_l00002ooooo`;o00007?ooool00ol0003o
ooooooooo`2iooooo`00S_ooool2o`0000;ooooo0_l0000Hooooo`03o`000?oooooooooo0;Wooooo
002Booooo`;o00006?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`06
ooooo`;o0000/Oooool009Cooooo0_l0000Fooooo`03o`000?oooooooooo00Kooooo0_l0002aoooo
o`00U?ooool2o`0001Kooooo00?o0000ooooooooool0^Oooool00:_ooooo1?l00003ooooo`;o0000
]?ooool009cooooo0_l0000=ooooo`;o00001Oooool2o`000;Cooooo002Looooo`;o00003_ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0;ooooo`;o0000[?ooool00:co
oooo00?o0000ooooooooool02oooool2o`0000[ooooo0_l0002Pooooo`00ROooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo0ol000000olb<S;o
gMgMooooo`04ooooo`03o`000?oooooooooo00;o00005Oooool2o`000:3ooooo0029ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01?ooool2o`000003
oooooomgMgOo<S8b00Gooooo00?o0000ooooooooool00_l0002gooooo`00ROooool01Ol@413ooooo
oooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo0;Wooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7o
ooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002iooooo`00ROooool01Ol0003ooooo
oooooooooooo000000cooooo0_l000000omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`0Rooooo`;o0000UOooool008Wooooo00Go410@oooooooo
oooooooooa0@400<ooooo`;o000000?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07oooo
o`;o00004oooool3o`0000gooooo0_l0002Eooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo0_l00007
ooooo`;o00002_ooool3o`000:Cooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5
o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo00Kooooo0_l0002aooooo`00[?ooool00ol0
003oooooooooo`0Aooooo`;o0000Y_ooool009gooooo0_l0000=ooooo`03o`000?oooooooooo017o
oooo0_l0002Vooooo`00WOooool2o`0000?ooooo0_l00003ooooo`;o00000oooool00ol0003ooooo
ooooo`2iooooo`00X_ooool4o`000003ooooool0003o000000?ooooo0ol0000?ooooo`;o0000Z?oo
ool009Kooooo0_l0000<ooooo`;o00001_ooool00ol0003oooooooooo`02ooooo`;o00002oooool2
o`000:Sooooo002Fooooo`;o00005?ooool00ol0003oooooooooo`02ooooo`;o0000]Oooool00:co
oooo00?o0000ooooooooool03?ooool2o`000:_ooooo002/ooooo`03o`000?oooooooooo00cooooo
0_l0002[ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`0Hooooo`;o0000Woooool00:[ooooo1Ol0000Hooooo`;o
0000Woooool00:[ooooo0ol0002kooooo`00Z?ooool2o`0000;ooooo00?o0000ooooooooool0^Ooo
ool00:Cooooo0_l00002ooooo`;o00000_ooool00ol0003oooooooooo`2iooooo`00Y?ooool2o`00
00Kooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool009Kooooo0_l0000Dooooo`03o`000?oooooooooo0;Wooooo002F
ooooo`;o00005?ooool00ol0003oooooooooo`2iooooo`00Soooool2o`0001_ooooo0ol0002ioooo
o`00Soooool2o`0001_ooooo00?o0000ooooooooool00_l0002gooooo`00[?ooool00ol0003ooooo
ooooo`02o`000;Oooooo002/ooooo`?o0000^Oooool00:cooooo0ol0002iooooo`00V_ooool2o`00
013ooooo00?o0000ooooooooool0^Oooool009[ooooo0_l0000@ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002Oooooo`;o00002?ooool2o`000004ooooool0
003o0000o`000;Wooooo002Oooooo`;o00002?ooool2o`000003ooooool0003ooooo0;[ooooo002D
ooooo`;o00005_ooool00ol0003oooooooooo`2iooooo`00U?ooool2o`0001Kooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
^Oooool00:;ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0;Wooooo002T
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000oooo
ooooool01Oooool3o`000;Wooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`00
0?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooo
oooo0<7ooooo002Rooooo`03oeEEEOmVIVKo00000<?ooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo002Zooooo`04oa0@4?l0003o0000o`000;[ooooo002[oooo
o`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`06o`00
0?mgMgOo0000o`000?mEEEGok^k^]oooool00:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomEEEFg
ooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo0;Gooooo002[ooooo`03
o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0]Oooool00:_ooooo00Ko0000oeEEEOo^k^ko
ooooogMgMomVIVJgooooo`00Z_ooool00ol@413o0000ogMgM`02o`000003ofIVI_o^k^kooooo0;Ko
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.62592 .64089 Mdot
.39903 .73108 Mdot
.4596 .38263 Mdot
.52383 .33383 Mdot
.43884 .77275 Mdot
.51489 .15315 Mdot
.47463 .32655 Mdot
.39993 .86016 Mdot
.68454 .66241 Mdot
.54609 .36384 Mdot
.53258 .69029 Mdot
.36501 .51583 Mdot
.62806 .29607 Mdot
.55887 .60098 Mdot
.36746 .57553 Mdot
.48881 .75712 Mdot
.55854 .26765 Mdot
.63827 .32072 Mdot
.56421 .37527 Mdot
.39604 .7797 Mdot
.62671 .29967 Mdot
.40992 .20647 Mdot
.44035 .11836 Mdot
.64926 .35444 Mdot
.47675 .00594 Mdot
.59867 .54552 Mdot
.46704 .78406 Mdot
.53987 .30606 Mdot
.37568 .57764 Mdot
.39927 .72914 Mdot
.6419 .34666 Mdot
.68032 .68159 Mdot
.5099 .96148 Mdot
.61554 .48852 Mdot
.54266 .78542 Mdot
.56945 .83065 Mdot
.62182 .2221 Mdot
.44748 .23253 Mdot
.37544 .45107 Mdot
.37806 .25912 Mdot
.51155 .02633 Mdot
.59778 .65098 Mdot
.39549 .62086 Mdot
.59163 .7426 Mdot
.6409 .57156 Mdot
.48812 .17927 Mdot
.56558 .49892 Mdot
.70755 .55974 Mdot
.43578 .79818 Mdot
.3952 .76792 Mdot
.70816 .53849 Mdot
.45935 .05055 Mdot
.47087 .87022 Mdot
.42236 .79272 Mdot
.62363 .80421 Mdot
.3939 .83193 Mdot
.56368 .27632 Mdot
.6971 .40697 Mdot
.64428 .52745 Mdot
.51278 .21538 Mdot
.74871 .46293 Mdot
.37582 .44779 Mdot
.5434 .53397 Mdot
.55641 .90066 Mdot
.65119 .75442 Mdot
.52907 .31464 Mdot
.53136 .65334 Mdot
.47292 .20268 Mdot
.66116 .40239 Mdot
.60878 .40096 Mdot
.45182 .65581 Mdot
.54451 .36173 Mdot
.46309 .23251 Mdot
.37573 .45208 Mdot
.47831 .64576 Mdot
.55513 .30503 Mdot
.41981 .11917 Mdot
.53677 .75196 Mdot
.66679 .56779 Mdot
.41494 .80608 Mdot
.47531 .25084 Mdot
.58602 .6895 Mdot
.501 .9739 Mdot
.44589 .7357 Mdot
.42297 .71682 Mdot
.40501 .54867 Mdot
.53513 .21989 Mdot
.527 .66685 Mdot
.48085 .00722 Mdot
.46312 .73993 Mdot
.4257 .26466 Mdot
.50635 .69999 Mdot
.54671 .96924 Mdot
.56288 .57579 Mdot
.7063 .52366 Mdot
.55842 .26054 Mdot
.60572 .70248 Mdot
.47902 .14653 Mdot
.36864 .61608 Mdot
.56476 .79376 Mdot
.67213 .52138 Mdot
.61547 .53565 Mdot
.61483 .44074 Mdot
.58129 .47985 Mdot
.45884 .73522 Mdot
.66007 .40122 Mdot
.56726 .49185 Mdot
.52289 .3289 Mdot
.68541 .66394 Mdot
.50772 .92073 Mdot
.77331 .34722 Mdot
.43971 .36003 Mdot
.54062 .26908 Mdot
.6053 .84067 Mdot
.64249 .77555 Mdot
.58606 .16995 Mdot
.6221 .28415 Mdot
.73302 .37668 Mdot
.55368 .173 Mdot
.37397 .47465 Mdot
.66214 .40867 Mdot
.54191 .40031 Mdot
.47516 .94435 Mdot
.61681 .88357 Mdot
.53481 .83635 Mdot
.52658 .41882 Mdot
.45578 .09456 Mdot
.57223 .775 Mdot
.37773 .2679 Mdot
.54749 .20002 Mdot
.40058 .31982 Mdot
.39835 .20168 Mdot
.6197 .21343 Mdot
.40559 .8224 Mdot
.53749 .33983 Mdot
.46633 .98359 Mdot
.36613 .45799 Mdot
.74365 .58714 Mdot
.43617 .31881 Mdot
.52481 .26934 Mdot
.56191 .27423 Mdot
.44159 .92221 Mdot
.54636 .92133 Mdot
.80314 .5038 Mdot
.57595 .45108 Mdot
.40858 .38447 Mdot
.72709 .34824 Mdot
.4583 .15424 Mdot
.41395 .3873 Mdot
.65576 .37419 Mdot
.47208 .68559 Mdot
.58493 .27408 Mdot
.564 .13428 Mdot
.39111 .25205 Mdot
.61518 .82293 Mdot
.61541 .21279 Mdot
.57836 .15306 Mdot
.55863 .71213 Mdot
.43018 .09123 Mdot
.53701 .04846 Mdot
.62432 .72563 Mdot
.41122 .73862 Mdot
.62106 .65198 Mdot
.56369 .89879 Mdot
.66803 .58183 Mdot
.45241 .22145 Mdot
.5837 .15814 Mdot
.4664 .93982 Mdot
.46213 .73487 Mdot
.41204 .42204 Mdot
.43663 .76442 Mdot
.57935 .53395 Mdot
.51922 .94873 Mdot
.57216 .93989 Mdot
.5731 .25089 Mdot
.4292 .51957 Mdot
.37533 .55683 Mdot
.53828 .09896 Mdot
.41459 .08283 Mdot
.4182 .40442 Mdot
.53439 .05009 Mdot
.50363 .67979 Mdot
.69293 .625 Mdot
.62943 .8645 Mdot
.67878 .69183 Mdot
.51192 .02292 Mdot
.39269 .41266 Mdot
.70779 .3052 Mdot
.43889 .91819 Mdot
.52647 .37417 Mdot
.73792 .40655 Mdot
.45363 .98016 Mdot
.62079 .15162 Mdot
.36561 .4542 Mdot
.40735 .39419 Mdot
.38714 .86261 Mdot
.61633 .57404 Mdot
.48375 .69725 Mdot
.47224 .70145 Mdot
.43819 .59135 Mdot
.47374 .81352 Mdot
.36204 .67885 Mdot
.59824 .71839 Mdot
.4269 .43008 Mdot
.54804 .20364 Mdot
.52837 .34207 Mdot
.43223 .62187 Mdot
.51283 .73934 Mdot
.56096 .17525 Mdot
.5473 .28602 Mdot
.6675 .58463 Mdot
.4243 .64111 Mdot
.61614 .66783 Mdot
.51606 .22508 Mdot
.54074 .05304 Mdot
.48183 .72145 Mdot
.63733 .44088 Mdot
.36639 .40206 Mdot
.53352 .25421 Mdot
.69431 .40412 Mdot
.6714 .55541 Mdot
.65831 .61711 Mdot
.47919 .76143 Mdot
.52754 .73983 Mdot
.41231 .80173 Mdot
.46306 .73721 Mdot
.36642 .54052 Mdot
.74344 .4147 Mdot
.5356 .64333 Mdot
.49656 .63325 Mdot
.36568 .71412 Mdot
.39857 .55264 Mdot
.45733 .77749 Mdot
.7188 .33485 Mdot
.42684 .30026 Mdot
.53715 .83929 Mdot
.56754 .19096 Mdot
.58368 .75281 Mdot
.74729 .45652 Mdot
.45508 .12752 Mdot
.64383 .68551 Mdot
.60798 .39748 Mdot
.67143 .71038 Mdot
.52879 .62669 Mdot
.52056 .08356 Mdot
.43661 .19866 Mdot
.60558 .38697 Mdot
.37876 .37554 Mdot
.60027 .12544 Mdot
.43473 .39164 Mdot
.51704 .34451 Mdot
.54847 .11819 Mdot
.59798 .533 Mdot
.40992 .50025 Mdot
.39065 .54747 Mdot
.46243 .63693 Mdot
.42534 .93558 Mdot
.70884 .49228 Mdot
.40892 .68061 Mdot
.45829 .77872 Mdot
.64812 .65909 Mdot
.49058 .30027 Mdot
.4316 .20729 Mdot
.63914 .56274 Mdot
.56466 .52661 Mdot
.42606 .19227 Mdot
.53142 .88532 Mdot
.58701 .61164 Mdot
.52803 .89259 Mdot
.40095 .68131 Mdot
.54992 .37536 Mdot
.47453 .84088 Mdot
.56221 .13116 Mdot
.43154 .30773 Mdot
.55975 .65887 Mdot
.70584 .56542 Mdot
.51691 .73191 Mdot
.57797 .25806 Mdot
.37867 .36526 Mdot
.53509 .52577 Mdot
.41889 .40488 Mdot
.61033 .20536 Mdot
.37774 .72436 Mdot
.58225 .50272 Mdot
.51642 .56352 Mdot
.55584 .65985 Mdot
.55006 .86635 Mdot
.43162 .24396 Mdot
.66937 .51503 Mdot
.63335 .85807 Mdot
.6854 .36643 Mdot
.38305 .7594 Mdot
.6801 .35443 Mdot
.43682 .48225 Mdot
.68566 .35945 Mdot
.71865 .34409 Mdot
.59095 .80315 Mdot
.37216 .65798 Mdot
.79983 .58142 Mdot
.49539 .82881 Mdot
.41487 .22707 Mdot
.55472 .80748 Mdot
.67458 .70041 Mdot
.47417 .00437 Mdot
.56358 .55638 Mdot
.70653 .54727 Mdot
.59458 .57359 Mdot
.52394 .55014 Mdot
.54167 .14929 Mdot
.57847 .31229 Mdot
.60255 .24634 Mdot
.71355 .31294 Mdot
.45089 .31909 Mdot
.64115 .48187 Mdot
.61296 .57058 Mdot
.52511 .93936 Mdot
.50952 .34553 Mdot
.42071 .06669 Mdot
.65391 .20882 Mdot
.7248 .67904 Mdot
.55266 .53492 Mdot
.56284 .22426 Mdot
.5767 .71537 Mdot
.3947 .23136 Mdot
.50753 .78136 Mdot
.49149 .6891 Mdot
.44751 .37931 Mdot
.60616 .39537 Mdot
.36654 .59519 Mdot
.52536 .09126 Mdot
.50692 .69935 Mdot
.49617 .09181 Mdot
.53301 .46833 Mdot
.43733 .5837 Mdot
.406 .77298 Mdot
.49997 .13229 Mdot
.40877 .72532 Mdot
.55988 .70857 Mdot
.49719 .79598 Mdot
.59618 .54743 Mdot
.46263 .90016 Mdot
.5434 .52232 Mdot
.57081 .88516 Mdot
.49036 .77656 Mdot
.42502 .88627 Mdot
.39014 .64774 Mdot
.41934 .51785 Mdot
.44583 .20881 Mdot
.74435 .58497 Mdot
.36492 .52423 Mdot
.68885 .36625 Mdot
.54701 .86488 Mdot
.51424 .79984 Mdot
.61889 .52856 Mdot
.47689 .94168 Mdot
.40443 .35157 Mdot
.36536 .54598 Mdot
.71165 .72027 Mdot
.63728 .70374 Mdot
.37277 .31746 Mdot
.43201 .04175 Mdot
.55057 .06553 Mdot
.44005 .39064 Mdot
.41308 .70479 Mdot
.36625 .4574 Mdot
.41083 .89753 Mdot
.45045 .34278 Mdot
.66756 .46368 Mdot
.59626 .51624 Mdot
.56391 .22899 Mdot
.61354 .6809 Mdot
.70456 .55545 Mdot
.54331 .8294 Mdot
.65475 .2838 Mdot
.45628 .05788 Mdot
.42145 .16617 Mdot
.67776 .3314 Mdot
.43306 .13209 Mdot
.42959 .05107 Mdot
.79239 .41294 Mdot
.61466 .2149 Mdot
.6068 .32299 Mdot
.49957 .64548 Mdot
.61121 .14473 Mdot
.52928 .20885 Mdot
.44136 .41755 Mdot
.43666 .0318 Mdot
.66315 .41208 Mdot
.4941 .68476 Mdot
.4874 .23213 Mdot
.5934 .43365 Mdot
.43627 .73173 Mdot
.70409 .59177 Mdot
.66629 .60665 Mdot
.73183 .38489 Mdot
.42604 .0533 Mdot
.609 .41879 Mdot
.39568 .09457 Mdot
.61737 .48098 Mdot
.58009 .52316 Mdot
.5686 .62023 Mdot
.50608 .41584 Mdot
.37489 .70569 Mdot
.36588 .55977 Mdot
.47348 .78604 Mdot
.42627 .61548 Mdot
.42114 .66912 Mdot
.41907 .60337 Mdot
.67529 .23608 Mdot
.41962 .29244 Mdot
.62185 .73351 Mdot
.4444 .291 Mdot
.41588 .36912 Mdot
.51462 .36384 Mdot
.40337 .50573 Mdot
.61212 .44808 Mdot
.41501 .61719 Mdot
.43615 .35344 Mdot
.72991 .36166 Mdot
.46947 .98472 Mdot
.49147 .60013 Mdot
.52032 .8236 Mdot
.61465 .43999 Mdot
.60765 .33138 Mdot
.59344 .56195 Mdot
.42419 .31296 Mdot
.628 .16641 Mdot
.52345 .85822 Mdot
.72695 .2438 Mdot
.56916 .78788 Mdot
.47455 .26919 Mdot
.67704 .68105 Mdot
.3683 .39608 Mdot
.52696 .70351 Mdot
.39361 .68001 Mdot
.42141 .55926 Mdot
.52065 .58485 Mdot
.5751 .57531 Mdot
.64864 .65963 Mdot
.55727 .70684 Mdot
.46778 .72057 Mdot
.52836 .8073 Mdot
.59824 .65251 Mdot
.52543 .64412 Mdot
.4393 .36587 Mdot
.45669 .23837 Mdot
.40049 .86203 Mdot
.48732 .2935 Mdot
.40383 .17657 Mdot
.43546 .86915 Mdot
.64252 .53839 Mdot
.50193 .92639 Mdot
.66628 .45998 Mdot
.59876 .3723 Mdot
.606 .90057 Mdot
.50297 .2553 Mdot
.36485 .54635 Mdot
.60383 .12919 Mdot
.56448 .52039 Mdot
.68779 .36466 Mdot
.59088 .58622 Mdot
.51299 .18882 Mdot
.42842 .89485 Mdot
.60187 .7134 Mdot
.57075 .4046 Mdot
.45268 .19631 Mdot
.61639 .49495 Mdot
.75274 .48245 Mdot
.39259 .42627 Mdot
.48246 .64382 Mdot
.41929 .777 Mdot
.52267 .78043 Mdot
.43884 .39695 Mdot
.55056 .55377 Mdot
.47854 .87045 Mdot
.39962 .32543 Mdot
.43412 .59547 Mdot
.59661 .47115 Mdot
.6483 .76025 Mdot
.44343 .78464 Mdot
.64152 .51747 Mdot
.51561 .24903 Mdot
.52471 .27412 Mdot
.4954 .3281 Mdot
.76873 .33149 Mdot
.50355 .3523 Mdot
.40245 .75298 Mdot
.69004 .39286 Mdot
.61529 .74698 Mdot
.4941 .21407 Mdot
.38833 .72527 Mdot
.38567 .20725 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:?ooooo0_l00007ooooo`03o`000?oooooooooo0;Wo
oooo002Sooooo`Co00001Oooool00ol0003oooooooooo`2iooooo`00Y?ooool3o`0000Gooooo00?o
0000ooooooooool0^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2i
ooooo`00X_ooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`Go0000]ooo
ool00:cooooo00?o0000ooooooooool00_l0002gooooo`00Uoooool2o`0001?ooooo00?o0000oooo
ooooool00_l0002gooooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool009Gooooo0_l0000E
ooooo`03o`000?oooooooooo0;Wooooo002Eooooo`;o00005Oooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`08ooooo`?o0000[_ooool009Cooooo0_l00008ooooo`;o0000
3?ooool3o`0000Sooooo1?l0002]ooooo`00Toooool3o`0000Sooooo0_l0000<ooooo`03o`000?oo
oooooooo00[ooooo0_l0002]ooooo`00Toooool2o`0000Sooooo0_l0000=ooooo`03o`000?oooooo
oooo0;Wooooo002Mooooo`;o00003Oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00TOooool2o`0001Wooooo00?o0000ooooooooool03Oooool2o`000:[ooooo
002Aooooo`;o00006Oooool00ol0003oooooooooo`0=ooooo`;o0000Z_ooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
Soooool2o`0001_ooooo00?o0000ooooooooool0^Oooool008oooooo0_l0000Kooooo`03o`000?oo
oooooooo00?ooooo0_l0002dooooo`00[?ooool00ol0003oooooooooo`03ooooo`;o0000]?ooool0
09Gooooo0_l0000Cooooo`?o00001oooool2o`000;;ooooo0029ooooo`;o00002_ooool2o`0000Ko
oooo0_l0000;ooooo`?o00001oooool2o`000;;ooooo0029ooooo`;o00004_ooool2o`0000gooooo
00?o0000ooooooooool0^Oooool00:cooooo0ol00009ooooo`;o0000[_ooool00:cooooo00?o0000
ooooooooool02Oooool2o`000:kooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool2o`0000;o8B4Q0ooo
ool2o`000003ooooool0003ok^k^00Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`00
0?oooooooooo00gooooo0_l0002Zooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
0_l00002ob4Q8@?ooooo0_l000000oooooooEEEEojVYZ@08ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool03Oooool2o`000:[ooooo0021ooooo`Ko00000_ooool01Ol@413ooooooooo
oooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000
7_ooool2o`0009Wooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7o0000
o`000006ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool07_ooool2o`0009Wooooo
0029ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGo0000o`000003ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Aooooo`;o00003?ooool2o`0009So
oooo0029ooooo`05oa0@4?ooooooooooooooool@41001oooool2o`0000Gooooo00?oZJVYogMgMooo
ool00oooool00ol0003oooooooooo`07ooooo`;o00004_ooool3o`0000_ooooo0_l0002Hooooo`00
ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo0_l00002ooooo`05oa0@4?oooooooooooooo
oolb<S801?ooool00ol0003oooooooooo`07ooooo`;o00004oooool2o`000:Gooooo0029ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Uooooo`;o00001Oooool00ol0003ooooo
ooooo`0Qooooo`;o0000U_ooool00:Gooooo0_l00005ooooo`03o`000?oooooooooo00[ooooo0_l0
000Eooooo`;o0000U_ooool00:cooooo0ol000000ooooooo0000o`000007ooooo`;o00002_ooool2
o`0000cooooo0_l0002Cooooo`00W_ooool2o`0000cooooo00Co0000oooooooooooooooo0_l0000C
ooooo`;o00003?ooool2o`0009?ooooo002Nooooo`;o00003?ooool00ol0003oooooooooo`0Hoooo
o`;o0000Woooool00:cooooo00?o0000ooooooooool06?ooool2o`0009oooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002Booooo`;o00006?ooool00ol0003oooooooooo`0Wooooo`;o0000T?oo
ool009;ooooo0_l0000Hooooo`03o`000?oooooooooo01Wooooo0_l0000<ooooo`;o0000T?ooool0
0:cooooo00?o0000ooooooooool03_ooool2o`0000Wooooo0_l0002Nooooo`00S?ooool2o`0001ko
oooo0ol0000>ooooo`;o000000?oooooo`000?l00000Y_ooool008cooooo0_l0000Jooooo`;o0000
0_ooool00ol0003oooooooooo`0Aooooo`;o0000Y_ooool00:Sooooo0_l00002ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`04o`000?oooooooooo
ooooo`;o0000]_ooool009?ooooo0_l0000Gooooo`04o`000?ooooooooooooooo`;o00004?ooool2
o`000:Cooooo002Cooooo`;o00005oooool00ol0003oooooooooo`0Cooooo`;o0000Y?ooool009co
oooo0_l0000>ooooo`03o`000?oooooooooo0;Wooooo002Gooooo`;o00000oooool2o`0000kooooo
0ol0000<ooooo`;o0000Zoooool008[ooooo0_l0000;ooooo`;o00002_ooool2o`0000Oooooo00?o
0000ooooooooool03?ooool2o`000:_ooooo0026ooooo`;o00000_ooool2o`0000;ooooo0_l00005
ooooo`;o00003?ooool2o`0000Oooooo00?o0000ooooooooool03?ooool2o`0001?ooooo0_l0002F
ooooo`00Q_ooool2o`0000Kooooo0_l00005ooooo`;o00000oooool2o`00013ooooo00?o0000oooo
ooooool01_ooool2o`0001Wooooo0_l0000<ooooo`;o0000R?ooool009[ooooo0_l0000@ooooo`03
o`000?oooooooooo00Kooooo0_l0000Kooooo`?o00002Oooool2o`0008Sooooo002Zooooo`?o0000
0oooool2o`0001oooooo1?l0002Cooooo`00Z_ooool3o`0000?ooooo0_l0000Oooooo`;o0000UOoo
ool009cooooo0_l0000>ooooo`03o`000?oooooooooo00Sooooo0_l0000Kooooo`;o0000T_ooool0
09cooooo0_l0000>ooooo`?o00000_ooool2o`0000Cooooo0_l00007ooooo`;o00004_ooool2o`00
09;ooooo002?ooooo`;o00006oooool00ol0003oooooooooo`02ooooo`;o00003Oooool2o`000:Ko
oooo0029ooooo`;o00001?ooool2o`0001_ooooo00?o0000ooooooooool04_ooool2o`000:Gooooo
0029ooooo`;o00003oooool2o`0000?ooooo0_l00006ooooo`;o00000oooool00ol0003ooooooooo
o`0Booooo`;o0000YOooool009[ooooo0_l00003ooooo`;o00001_ooool2o`0000?ooooo00?o0000
ooooooooool0=_ooool2o`00087ooooo002Mooooo`;o00003Oooool00ol0003oooooooooo`0foooo
o`;o0000POooool0097ooooo00Cok^k^oc8b<_l0003o<S8b0_l00004ooooo`;o8B4Q0_l00003oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`17ooooo`;o0000L?ooool0
097ooooo00CoMgMgoiRHV?ooooooV9RH0_l00004ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo01kooooo0_l0000Wooooo`;o0000L?ooool008Wooooo1_l00002oooo
o`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo0_l0000Jooooo`;o0000VOooool008Sooooo0_l00007ooooo`05o`000?oooooooooo
ooooool000003Oooool2o`000003ogMgMolb<S;ooooo00Cooooo0ol00002ooooo`;o00004Oooool2
o`000:;ooooo0028ooooo`;o00001oooool01Ol0003ooooooooooooooooo000000cooooo0ol00000
0olb<S;oc<c<ooooo`04ooooo`?o00002?ooool2o`0000_ooooo0_l0002Rooooo`00Poooool2o`00
00cooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo0ol00008
ooooo`;o00003?ooool2o`000:7ooooo0023ooooo`;o00003?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0@ooooo`;o00001?ooool2
o`000:7ooooo002Aooooo`05onk^k_lb<S;o0000o`000?o^k^h03?ooool4o`0000Kooooo00?o0000
ooooooooool04?ooool2o`000:Oooooo0023ooooo`;o00003_ooool2o`0001Oooooo00?o0000oooo
ooooool04?ooool2o`000:Oooooo0023ooooo`;o00007_ooool2o`0000Oooooo00?o0000oooooooo
ool01Oooool2o`0000?ooooo0_l00004ooooo`;o0000Yoooool00:?ooooo0_l00007ooooo`03o`00
0?oooooooooo00Gooooo0_l00003ooooo`;o00001Oooool2o`0000Kooooo0_l0002Nooooo`00[?oo
ool3o`0000Gooooo0_l0000:ooooo`?o00001Oooool2o`0009kooooo002/ooooo`03o`000?oooooo
oooo01;ooooo0_l0002Uooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`0<ooooo`;o00005oooool2o`0000Wooooo0_l00027ooooo`00[?ooool00ol0003ooooo
ooooo`0<ooooo`;o00005oooool2o`0000Wooooo0_l00027ooooo`00TOooool2o`0000Kooooo0_l0
000Aooooo`03o`000?oooooooooo0;Wooooo002Aooooo`;o00001_ooool2o`0000cooooo0_l00003
ooooo`03o`000?oooooooooo0;Wooooo002Wooooo`;o00000oooool00ol0003oooooooooo`0Woooo
o`;o0000T?ooool009?ooooo0_l0000Cooooo`;o00000_ooool3o`0002Kooooo0ol0002@ooooo`00
Toooool2o`0001?ooooo0_l00002ooooo`03o`000?oooooooooo02Kooooo0_l0002Aooooo`00[?oo
ool00ol0003oooooooooo`0:ooooo`;o00000oooool2o`00033ooooo0_l0001fooooo`00UOooool2
o`0001Gooooo00?o0000ooooooooool02_ooool2o`0000?ooooo0_l0000`ooooo`;o0000M_ooool0
09?ooooo1?l0000Eooooo`03o`000?oooooooooo01Kooooo0_l0000[ooooo`;o0000M?ooool009?o
oooo0_l0000Gooooo`03o`000?oooooooooo00Kooooo0_l0000>ooooo`;o0000:oooool2o`0007Co
oooo0022ooooo`;o00004_ooool2o`0000?ooooo0_l0000?ooooo`03o`000?oooooooooo00Kooooo
0_l0002aooooo`00P_ooool2o`0000Oooooo0_l00009ooooo`;o00000oooool2o`0000oooooo00?o
0000ooooooooool0:_ooool2o`0008gooooo002:ooooo`?o00007oooool3o`00023ooooo0_l00008
ooooo`;o0000SOooool008[ooooo0_l0000Gooooo`;o00001Oooool3o`0002;ooooo0_l0002Goooo
o`00Xoooool2o`0000Gooooo0ol00006ooooo`;o00006_ooool2o`0001Gooooo0_l0000Looooo`;o
0000H_ooool00:cooooo00?o0000ooooooooool01?ooool2o`0001[ooooo0_l0000Eooooo`;o0000
3?ooool2o`0000kooooo0_l0001Rooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o0000?ooo
ool2o`0007;ooooo002/ooooo`03o`000?oooooooooo00Wooooo0_l0002^ooooo`00Voooool2o`00
00oooooo00?o0000ooooooooool01_ooool2o`000003ooooool0003o00000:kooooo002Kooooo`;o
00003oooool00ol0003oooooooooo`04o`0000;ooooo0_l0000Sooooo`;o00006?ooool2o`0007;o
oooo002/ooooo`03o`000?oooooooooo00Co00009oooool2o`0001Sooooo0_l000000ooooooo0000
o`00000=ooooo`;o0000H?ooool008cooooo0_l0000Nooooo`?o0000B?ooool2o`0000gooooo0_l0
001Pooooo`00S?ooool2o`0000Sooooo0_l0000Dooooo`?o0000;_ooool2o`0000Sooooo0_l0001o
ooooo`00U_ooool2o`0001Cooooo00?o0000ooooooooool0;_ooool2o`0000Sooooo0_l0001ooooo
o`00V?ooool2o`0001;ooooo00?o0000ooooooooool02oooool2o`0002gooooo0_l0000<ooooo`;o
0000Koooool009Sooooo0_l0000Booooo`04o`000?ooooooooooooooo`;o00002?ooool3o`0002co
oooo0ol0000;ooooo`;o0000Koooool008Cooooo0_l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@?ooooo1_l00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool01?l0
003oooooooooooooool2o`0000Wooooo0_l0000/ooooo`?o0000O?ooool008Cooooo0_l00003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool2o`000003oooooolQ8B7o8B4Q00?ooooo0_l00000
1?lQ8B7ok^k^oooooom4A4@7ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0>_oo
ool3o`0007cooooo0021ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00;ooooo0_l0
0008ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`05ooooo`;o00005_ooool2o`00017ooooo0_l00027ooooo`00Q?ooool2o`0000?ooooo00Go0000
ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?oo
ool3o`0000Gooooo0_l00006ooooo`;o00000oooool2o`0000Wooooo0_l0000Aooooo`;o00005ooo
ool2o`0006kooooo0024ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000cooooo0_l0
00000omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`0=ooooo`;o00000oooool2o`0003Gooooo0_l0001^ooooo`00ROooool01Ol@413ooooooooo
oooooooo410@00cooooo0_l000001?oooooo0000o`000?l00002ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0^Oooool008Wooooo00CoMgMgoiRHV?ooooooV9RH0_l0000:ooooo`05
o`000?nj^[[ooooooiRHV?l@41000_l00002ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0BOooool2o`0006kooooo0029ooooo`04onk^k_lb<S;o0000oc8b<PCo00002?ooool01OnH
V9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo01oooooo0_l0000X
ooooo`;o0000K_ooool008oooooo0_l00005ooooo`Co00004_ooool00ol0003oooooooooo`0Ooooo
o`;o0000V?ooool008gooooo0_l00007ooooo`Co00004_ooool00ol0003oooooooooo`0Pooooo`;o
00006Oooool2o`0007cooooo0020ooooo`;o00002oooool2o`0000Sooooo0_l0000Cooooo`03o`00
0?oooooooooo023ooooo0_l0000Iooooo`;o0000O?ooool0083ooooo0_l0000Eooooo`;o00004ooo
ool3o`0000[ooooo0_l0000Dooooo`;o00003oooool2o`0008Kooooo001oooooo`;o00004?ooool2
o`0001Wooooo00?o0000ooooooooool02_ooool2o`0001Cooooo0_l0000?ooooo`?o00002Oooool2
o`0007[ooooo001oooooo`;o00004?ooool2o`0001Wooooo00?o0000ooooooooool05?ooool2o`00
01cooooo0_l00009ooooo`?o00002oooool2o`0006cooooo002Aooooo`;o00006Oooool00ol0003o
ooooooooo`0Dooooo`;o00007?ooool2o`0000[ooooo0_l0000;ooooo`;o0000K?ooool008Sooooo
0_l0000Rooooo`03o`000?oooooooooo03;ooooo0_l0000Yooooo`;o0000F_ooool008Sooooo0_l0
000Rooooo`04o`000?oooooo0000o`00037ooooo0_l0000Iooooo`;o00003_ooool2o`0005[ooooo
002Hooooo`;o00004_ooool01?l0003oooooo`000?l00004ooooo`;o00006_ooool2o`0002[ooooo
0_l0001Zooooo`00Soooool2o`0000Oooooo0_l0000Booooo`03o`000?oooooooooo00Gooooo0_l0
000Jooooo`;o0000U_ooool008oooooo0_l0000Kooooo`?o0000^Oooool008Sooooo0_l0000Roooo
o`03o`000?oooooooooo0;Wooooo0028ooooo`;o00002Oooool2o`0001Oooooo00?o0000oooooooo
ool0^Oooool009?ooooo0_l0000Gooooo`03o`000?oooooooooo01_ooooo0_l0002Looooo`00[?oo
ool00ol0003oooooooooo`0Kooooo`;o0000W?ooool00:cooooo00?o0000ooooooooool08_ooool2
o`0000Kooooo0_l0002=ooooo`00[?ooool00ol0003oooooooooo`0Rooooo`;o00001_ooool2o`00
08gooooo002/ooooo`03o`000?oooooooooo0;Wooooo0023ooooo`;o00009oooool00ol0003ooooo
ooooo`0Rooooo`;o0000UOooool008;ooooo0ol0000Wooooo`?o00005_ooool2o`0000[ooooo0_l0
002Eooooo`00Ooooool2o`000004ooooool0003o0000o`0002Oooooo00?o0000ooooooooool05_oo
ool2o`000:7ooooo001oooooo`;o0000:oooool00ol0003oooooooooo`1>ooooo`;o0000JOooool0
00Wooooo1?l000000ol@413oooooooooo`0Fooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`;o000000?oooooob4Q8OlQ8B401?ooool5o`00
00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Fooooo`03o`000?oooooooooo01Sooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o0000
omgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool2o`000003ob4Q8Ooooooooooo00?o
oooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1?l0
00000ol@413oooooooooo`0Booooo`002oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8boooo
o`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0
3_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@01oooool00omgMgOo<S8booooo`0Eooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo0ol0
000?ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0000Sooooo00?oMgMgoc8b<_ooool0
3_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oo
oooo00?oMgMgoc8b<_ooool06Oooool00ol0003oooooooooo`0Dooooo`001_l00005ooooo`03o`00
0?oooooooooo013ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol0003oooooooooo`05ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo01Sooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Sooooo0_l0
000?ooooo`05oa0@4?ooooooooooooooool@41001Oooool2o`0000Wooooo00?o0000ooooooooool0
3Oooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo
00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_oo
ool03_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0
003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`0E
ooooo`03o`000?oooooooooo00Oooooo0_l0000?ooooo`04o`000?ooooooooooooooo`;o00003?oo
ool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000oooooooooooooooo
o`00000?ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool06Oooool00ol0003oooooooooo`0Dooooo`00
2oooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGo
c<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo
000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool00000
3_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05_ooool00ol0003o
ooooooooo`07ooooo`;o00003oooool01?l0003oooooooooooooool2o`0000gooooo00?oMgMgofIV
I_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00
000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[ooooo00?o0000oooo
ooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol@413ooooooooooooooooo410@
00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`0Aooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41001Ooo
ool2o`0000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Hooooo`?o00006?oo
ool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0Aooooo`05
oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooo
oooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o00001?ooool01Ol0003o^[ZjoooooonHV9So410@00Co
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Gooooo`;o000000CoV9RHoooooonH
V9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool04Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool05?ooool000Wooooo00?oEEEEofIVI_l000006_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<00Cooooo1?l00002ooooo`;o00004oooool00ol0003oooooooooo`0Gooooo`;o000000Co
<S8bo`000?lb<S;ok^k^1_ooool2o`0000?ooooo00?oV9RHoa0@4?l000000_l00004ooooo`Co0000
4?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo0_l00004ooooo`Co00004?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00006Oooool00omEEEGoIVIVo`00000Foooo
o`00Uoooool2o`0001?ooooo00?o0000ooooooooool08oooool2o`0000Kooooo0_l0000Sooooo`;o
0000Ioooool00:cooooo00?o0000ooooooooool08oooool2o`0009Cooooo002/ooooo`03o`000?oo
oooooooo01?ooooo0_l0000>ooooo`;o00007Oooool2o`0006[ooooo0_l00002ooooo`;o00001Ooo
ool00:cooooo00?o0000ooooooooool04oooool2o`0000kooooo0_l0000Mooooo`;o0000J_ooool0
1_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Gooooo002/ooooo`03o`000?oooooooooo02?ooooo0_l0
002:ooooo`04omgMgOl0003o410@olc<c0Kooooo0007oooooooo0000C?l0000<ooooo`04onk^k_lQ
8B7o410@onk^kPKooooo0007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_l0
0004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool01?l0003ooooooooo
ooooool2o`0000;ooooo00Co0000ooooool0003o00001?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo0ol00006ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool02_ooool01?lQ8B7oMgMgogMgMolb<S86ooooo`001oooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`06ooooo`;o
00007_ooool00ol0003oooooooooo`0Hooooo`;o00003Oooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo00kooooo0_l0000Fooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool02Oooool2o`0000;ooooo0_l00005ooooo`00S?ooool2o`0001kooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0^Oooool007oooooo0_l0000[ooooo`03o`000?oooooo
oooo01cooooo0_l0000Fooooo`;o0000Poooool007oooooo0_l0000@ooooo`;o000000?oooooo`00
0?l000005_ooool00ol0003oooooooooo`0Looooo`;o00003Oooool2o`0000Oooooo0_l00023oooo
o`00TOooool2o`000003ooooool0003o000001Kooooo00?o0000ooooooooool02oooool2o`0000Go
oooo0_l0000Gooooo`;o00002?ooool2o`0008;ooooo001oooooo`;o0000:oooool3o`0000_ooooo
0_l00005ooooo`;o00000oooool2o`0001cooooo0_l0000:ooooo`;o0000M_ooool007oooooo0_l0
000[ooooo`03o`000?oooooooooo00Sooooo0_l00008ooooo`;o00000oooool2o`0000_ooooo0_l0
0006ooooo`;o00004oooool2o`0007Kooooo002/ooooo`03o`000?oooooooooo00Sooooo0_l00008
ooooo`;o00004?ooool2o`0000Kooooo0_l0002;ooooo`00[?ooool00ol0003oooooooooo`0;oooo
o`;o00002_ooool2o`0000Cooooo0_l0002Jooooo`00[?ooool00ol0003oooooooooo`0;ooooo`;o
000000?oooooo`000?l000001oooool2o`0000Cooooo0_l00004ooooo`;o0000U?ooool007oooooo
0_l0000[ooooo`03o`000?oooooooooo00kooooo0_l0000Cooooo`;o00001oooool2o`0001?ooooo
0_l0001fooooo`00Ooooool2o`0002_ooooo00?o0000ooooooooool0;?ooool2o`0001?ooooo0_l0
001fooooo`00Ooooool2o`0002_ooooo00?o0000ooooooooool07Oooool2o`0009[ooooo001ooooo
o`;o00001_ooool2o`0000?ooooo0_l0000Nooooo`03o`000?oooooooooo01cooooo0ol0000Roooo
o`;o0000M_ooool008Oooooo0_l000000ooooooo0000o`000002o`0001kooooo0ol00004ooooo`;o
00005_ooool2o`0002?ooooo0_l0001fooooo`00R_ooool2o`00023ooooo00?o0000ooooooooool0
1?ooool2o`0000Oooooo0_l0000Vooooo`;o00002Oooool2o`0007Oooooo0022ooooo`;o0000:?oo
ool00ol0003oooooooooo`0=ooooo`;o00000oooool2o`00027ooooo0_l00009ooooo`;o0000Mooo
ool007oooooo0_l000000ooooooo0000o`00000>ooooo`;o00006?ooool00ol0003oooooooooo`0B
ooooo`;o00001oooool2o`0002Cooooo0_l0001fooooo`00Ooooool2o`00017ooooo0_l0000Hoooo
o`03o`000?oooooooooo00;ooooo0_l0000Gooooo`;o00003Oooool2o`0001Gooooo0_l0001foooo
o`00[?ooool00ol0003oooooooooo`02ooooo`;o00009_ooool2o`0000Sooooo0_l0000;ooooo`;o
0000M_ooool00:cooooo00?o0000ooooooooool08_ooool2o`00013ooooo0_l0000;ooooo`;o0000
M_ooool00:cooooo00?o0000ooooooooool07?ooool2o`0000Cooooo0ol00006ooooo`;o0000S?oo
ool0083ooooo0_l0000Zooooo`?o00004Oooool2o`0000;ooooo0_l00005ooooo`;o00001Oooool2
o`0000Kooooo0_l0002<ooooo`00P?ooool2o`000003ooooool0003o000002Oooooo00?o0000oooo
ooooool04Oooool2o`0000;ooooo0_l0002Rooooo`00Poooool2o`0002Oooooo00?o0000oooooooo
ool0=?ooool2o`0002[ooooo0_l0001Gooooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool0
0oooool2o`0001Kooooo0_l0000Gooooo`;o00005oooool2o`00017ooooo0_l0001Gooooo`00Uooo
ool2o`0001?ooooo00?o0000ooooooooool00oooool2o`0001Kooooo0_l0000Gooooo`;o00005ooo
ool2o`0006[ooooo002Gooooo`;o00004oooool00ol0003oooooooooo`10ooooo`;o00002oooool2
o`0006[ooooo0020ooooo`;o00005Oooool2o`0001?ooooo00?o0000ooooooooool0@?ooool2o`00
07Oooooo0020ooooo`;o00005?ooool2o`0001Cooooo00?o0000ooooooooool0^Oooool009Kooooo
0_l0000Aooooo`;o000000Coooooo`000?l0003o00004?ooool2o`000:Oooooo002Aooooo`;o0000
5_ooool2o`000003ooooool0003ooooo017ooooo0_l0002Wooooo`00TOooool2o`0001Wooooo00?o
0000ooooooooool0<oooool2o`0008Cooooo002/ooooo`03o`000?oooooooooo03?ooooo0_l00024
ooooo`00[?ooool00ol0003oooooooooo`0Iooooo`;o0000W_ooool0083ooooo0_l0000Aooooo`;o
00005oooool00ol0003oooooooooo`0Iooooo`;o0000W_ooool0083ooooo0_l00007ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00_ooool2o`000003ooooool0003o000000Cooooo1Ol00004ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0aooooo`;o0000Q_ooool008Wo
oooo0_l000000oooooooV9RHogMgM`02ooooo`;o000000?oooooob4Q8OlQ8B400_l00002ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
01?ooooo0_l0000Looooo`;o0000Q_ooool008Wooooo0_l00002ooooo`03oa0@4?oooooooooo00Go
oooo0_l00003ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`0001?o
oooo0_l0000Wooooo`;o0000Noooool008Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03
oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`06ooooo`;o
0000=?ooool2o`0007_ooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOo
IVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`06oooo
o`;o0000/Oooool008Wooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01Oooool3o`000;_ooooo0029ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01_l0003o^[ZjoooooonHV9So410@ooooo`;o000000?oooooo`000?ooool01_oo
ool3o`000;_ooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01_nHV9So410@o`00
0?lQ8B7oc<c<ooooo`;o000000?oooooo`000?l000000_l00006ooooo`03o`000?oooooooooo0;Wo
oooo002Cooooo`;o00004Oooool2o`0000Cooooo00?o0000ooooooooool02?ooool2o`0001cooooo
0_l0002Aooooo`00Toooool2o`0000oooooo1?l00003ooooo`;o00001oooool2o`000003ooooool0
003o000001cooooo0_l0002Aooooo`00Qoooool2o`0001_ooooo0_l00005ooooo`;o00001oooool2
o`000;;ooooo0027ooooo`;o00008oooool3o`0001gooooo0_l00006ooooo`;o0000T_ooool009co
oooo0_l0000>ooooo`03o`000?oooooooooo00Oooooo0_l0000Dooooo`;o00001_ooool2o`0009;o
oooo0021ooooo`;o00006Oooool2o`0000kooooo00?o0000ooooooooool01oooool2o`0000Oooooo
0_l0002Wooooo`00POooool2o`0002Wooooo00?o0000ooooooooool03oooool3o`0001_ooooo0ol0
0029ooooo`00[?ooool00ol0003oooooooooo`0?ooooo`;o00007?ooool3o`0000Wooooo0ol0001m
ooooo`00[?ooool00ol0003oooooooooo`05ooooo`;o00007?ooool2o`0001Cooooo0ol0001moooo
o`00T_ooool2o`0001Sooooo00?o0000ooooooooool01Oooool2o`0001cooooo0_l0002Dooooo`00
T_ooool2o`0001Sooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00O_ooool2
o`0000Sooooo0_l0000Rooooo`?o0000Aoooool2o`00073ooooo001nooooo`;o00002?ooool2o`00
0003ooooool0003o000000;o00007Oooool3o`0002;ooooo0_l0000Cooooo`?o00003Oooool2o`00
073ooooo002;ooooo`Co00004oooool2o`0000Kooooo0ol0000Tooooo`;o00002?ooool2o`0000Wo
oooo0ol0001oooooo`00X_ooool2o`0000Gooooo1?l0000^ooooo`;o0000Roooool00:Wooooo0_l0
00000ooooooo0000ooooo`08ooooo`;o00004?ooool2o`0001gooooo0_l0001oooooo`00[?ooool0
0ol0003oooooooooo`07ooooo`;o00004?ooool2o`0001gooooo0_l0001oooooo`00Y_ooool2o`00
00Cooooo00?o0000ooooooooool0^Oooool00:;ooooo0_l00002ooooo`;o00001?ooool4o`0003Go
oooo0_l00021ooooo`00X_ooool2o`0000Sooooo00Co0000ooooool0003o00001?ooool2o`0001So
oooo0_l00009ooooo`;o00002_ooool2o`00087ooooo0022ooooo`;o00002oooool2o`0001_ooooo
00?o0000ooooooooool01Oooool2o`0000Sooooo0_l0000>ooooo`;o00002Oooool2o`0008gooooo
0022ooooo`;o00002oooool2o`0001_ooooo00?o0000ooooooooool03oooool3o`0002?ooooo0_l0
0022ooooo`00[?ooool00ol0003oooooooooo`0@ooooo`;o00003?ooool2o`0001Gooooo0_l00022
ooooo`00Ooooool2o`0002_ooooo00?o0000ooooooooool04?ooool2o`0000Cooooo0_l00006oooo
o`;o0000VOooool007oooooo0_l0000Aooooo`;o00006?ooool00ol0003oooooooooo`0Fooooo`;o
00001Oooool2o`0009[ooooo002Booooo`;o00003Oooool2o`0000?ooooo0_l00004ooooo`03o`00
0?oooooooooo01gooooo0_l0000Sooooo`;o0000MOooool008?ooooo0_l00002ooooo`;o00001?oo
ool2o`0001;ooooo0_l00003ooooo`;o00001?ooool3o`0002Kooooo0_l0000Jooooo`;o0000MOoo
ool008?ooooo0_l00002ooooo`;o00001?ooool2o`0001gooooo00?o0000ooooooooool09_ooool2
o`00097ooooo002:ooooo`;o00002oooool2o`0001?ooooo00?o0000ooooooooool0^Oooool008[o
oooo0_l0000;ooooo`;o00004oooool00ol0003oooooooooo`02ooooo`;o00008Oooool2o`0009;o
oooo002Jooooo`;o00000_ooool3o`0000_ooooo00?o0000ooooooooool00_ooool2o`00027ooooo
0_l0002Booooo`00S_ooool2o`0000[ooooo0_l00002ooooo`?o00002oooool01?l0003ooooooooo
ooooool2o`0000?ooooo0_l0002aooooo`00S_ooool2o`000006ooooooo^k^ko<S8bo`000?lb<S;o
k^k^1Oooool2ob4Q8@;ooooo0_l000001_ooooooA4A4o`000?l0003o<S8bomgMg@Gooooo00Co0000
oooooooooooooooo0_l00003ooooo`;o00004oooool2o`0009cooooo002Aooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`0Kooooo`;o0000W?ooool0097ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool08oooool2o`0009Cooooo002Aooooo`05o`000?oooooo
ooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`?o00002Oooool2o`0000gooooo0_l0
0009ooooo`;o0000U?ooool008_ooooo0_l00004ooooo`05o`000?ooooooooooooooool000003?oo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool02Oooool2o`0000gooooo
0_l0000Dooooo`;o0000ROooool008_ooooo0_l00004ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00ol0003oooooooooo`03ooooo`;o00000_ooool00ol0003oooooooooo`0^ooooo`;o0000
ROooool008Gooooo0_l0000:ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooo
ooooo`02o`000003ooooool0003o000000;ooooo00?o0000ooooooooool0;_ooool2o`0008Wooooo
0025ooooo`;o00002_ooool01_o^k^ko<S8bo`000?lb<S;ok^k^ooooo`;o00002Oooool5o`0000Go
oooo00?o0000ooooooooool0;_ooool2o`0008Wooooo0029ooooo`;o00003?ooool2o`0001?ooooo
00?o0000ooooooooool0^Oooool008Wooooo0_l0000Qooooo`03o`000?oooooooooo0;Wooooo002=
ooooo`;o00002?ooool2o`0001?ooooo00?o0000ooooooooool0^Oooool008gooooo0_l00002oooo
o`;o00001?ooool2o`0000oooooo0_l00002ooooo`?o00005?ooool2o`0001Kooooo0_l0002;oooo
o`00ROooool2o`0000Kooooo0_l0000:ooooo`?o00002?ooool2o`0000;ooooo00?o0000oooooooo
ool05?ooool2o`0001Kooooo0_l0002;ooooo`00ROooool2o`0001;ooooo0ol0000<ooooo`04o`00
0?oooooo0000o`0000?ooooo0_l0002cooooo`00VOooool2o`0000Kooooo1?l00007ooooo`04o`00
0?oooooo0000o`0000?ooooo0_l00005ooooo`;o0000[?ooool009Wooooo0_l00006ooooo`Co0000
1oooool00ol0003oooooooooo`0;ooooo`;o00001_ooool2o`000:Cooooo002/ooooo`03o`000?oo
oooooooo01?ooooo0_l0002Tooooo`00T_ooool2o`0001Sooooo00?o0000ooooooooool04_ooool2
o`000:Gooooo002Booooo`;o00000_ooool2o`0001?ooooo0_l0000Dooooo`;o0000YOooool009Ko
oooo0_l0000Cooooo`Co000000?oooooo`000?l00000]_ooool008oooooo0_l0000Kooooo`04o`00
0?ooooooooooooooo`;o00006?ooool2o`0000Sooooo0_l0002Booooo`00Soooool2o`0001_ooooo
00?o0000ooooooooool01_ooool2o`0001?ooooo0_l00008ooooo`;o0000T_ooool008oooooo0_l0
000Kooooo`03o`000?oooooooooo00Kooooo0_l00007ooooo`;o0000Z?ooool00:?ooooo0_l00007
ooooo`03o`000?oooooooooo00oooooo0_l0002Xooooo`00Xoooool2o`0000Oooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool008cooooo0_l0000Nooooo`03o`00
0?oooooooooo0;Wooooo002<ooooo`;o00007_ooool3o`0000?ooooo0_l0000Nooooo`;o0000U?oo
ool00:cooooo00?o0000ooooooooool00oooool2o`0001kooooo0_l0002Dooooo`00Z_ooool3o`00
00gooooo0_l00006ooooo`;o0000Y?ooool008Wooooo0_l0000Oooooo`?o00003Oooool2o`0000Ko
oooo0_l0002Tooooo`00ROooool2o`00027ooooo00?o0000ooooooooool02?ooool2o`000:oooooo
002/ooooo`03o`000?oooooooooo00Sooooo0ol0000Dooooo`;o0000V?ooool00:?ooooo0_l00007
ooooo`03o`000?oooooooooo00Wooooo0_l0000Dooooo`;o0000V?ooool00:?ooooo0_l00007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000
^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool01?ooool2
o`0002?ooooo0_l0002>ooooo`00Roooool2o`0001oooooo00?o0000ooooooooool01?ooool2o`00
02?ooooo0_l0002>ooooo`00Q_ooool2o`0000?ooooo0_l0000Oooooo`03o`000?oooooooooo00co
oooo0_l0000Iooooo`;o0000T?ooool008Kooooo0_l000000oooooook^k^oc8b<P02o`000003onk^
k_oooooooooo00?ooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo00cooooo0ol0000Hooooo`;o0000T?ooool008Wooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q00?oooooo`000?l000000oooool00omEEEGo
ZJVYooooo`04ooooo`Co000000?o<S8booooooooool00oooool00ol0003oooooooooo`0=ooooo`;o
0000Z_ooool008Wooooo00Go410@oooooooooooooooooa0@4008ooooo`;o00000oooool00onYZJWo
EEEEooooo`04ooooo`Go00001Oooool00ol0003oooooooooo`2iooooo`00ROooool01Ol0003ooooo
oooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`?o
0000^Oooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05
oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0^Oooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo0_l0000;ooooo`;o00003Oooool2o`0009Cooooo0029ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2o`0000Cooooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`07
ooooo`;o00002oooool2o`0000gooooo0_l0002Dooooo`00Toooool2o`0001Oooooo00?o0000oooo
ooooool0^Oooool009Cooooo0_l0000Fooooo`03o`000?oooooooooo00Kooooo0_l0002aooooo`00
S_ooool2o`0000Cooooo0_l0000Fooooo`03o`000?oooooooooo00Kooooo0_l0002aooooo`00S_oo
ool2o`0000oooooo0_l0000;ooooo`?o00003oooool2o`000003ooooool0003o000000cooooo0_l0
002Gooooo`00Woooool2o`0000_ooooo00?o0000ooooooooool03oooool2o`000003ooooool0003o
000000cooooo0_l0002Gooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool0^Oooool009Oooooo0ol0000Boooo
o`04o`000?oooooo0000o`0000_ooooo0_l0002[ooooo`00V?ooool2o`0001;ooooo1?l0000;oooo
o`;o0000Zoooool00:cooooo0_l0002jooooo`00[?ooool2o`000;[ooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002Cooooo`;o00005oooool00ol0003oooooooooo`2iooooo`00Toooool2o`00
00_ooooo0_l0000:ooooo`03o`000?oooooooooo00Gooooo0_l0000=ooooo`;o0000Xoooool00:3o
oooo0_l00002ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`;o00003Oooool2o`000:?o
oooo002Sooooo`?o00001_ooool00ol0003oooooooooo`2iooooo`00Xoooool2o`0000Oooooo00?o
0000ooooooooool00oooool2o`000;Cooooo002/ooooo`?o00000oooool2o`000;Cooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo00;o0000]oooool00:cooooo00?o0000ooooooooool00_l0002gooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0<ooooo`;o0000Zoooool00:co
oooo0_l0000=ooooo`;o0000Zoooool00:cooooo0ol0002iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00W?ooool2o`0000kooooo00?o0000ooooooooool0^Oooool009cooooo0_l00002oooo
o`?o00002Oooool00ol0003oooooooooo`2iooooo`00X?ooool3o`0000Wooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:;ooooo1?l000000ol@413ooooooooo
o`03ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0^Oooool00:Cooooo00?o0000ooooooooool01Oooool3o`000;Wooooo002Tooooo`03
o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oo
oooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Rooooo`03oeEEEOmVIVKo0000
0<?ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Zoooo
o`04oa0@4?l0003o0000o`000;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03
o`000?oooooooooo0;[ooooo002[ooooo`06o`000?mgMgOo0000o`000?mEEEGok^k^]oooool00:_o
oooo00Ko0000oeEEEOo^k^koooooogMgMomEEEFgooooo`00Zoooool00ol0003ok^k^ooooo`02oooo
o`03o`000?oooooooooo0;Gooooo002[ooooo`03o`000?o^k^kooooo00;ooooo00?o0000oooooooo
ool0]Oooool00:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomVIVJgooooo`00Z_ooool00ol@413o
0000ogMgM`02o`000003ofIVI_o^k^kooooo0;Kooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.64227 .44089 Mdot
.54408 .83504 Mdot
.45271 .59263 Mdot
.43489 .32175 Mdot
.5493 .69684 Mdot
.39203 .39991 Mdot
.43721 .53915 Mdot
.5786 .88901 Mdot
.70951 .46241 Mdot
.45555 .23626 Mdot
.5687 .49029 Mdot
.50225 .97691 Mdot
.50649 .09607 Mdot
.55926 .40098 Mdot
.5148 .95793 Mdot
.55357 .56209 Mdot
.43401 .19763 Mdot
.52656 .12072 Mdot
.47491 .19624 Mdot
.55709 .86515 Mdot
.50658 .09967 Mdot
.425 .84767 Mdot
.39918 .73388 Mdot
.55104 .15444 Mdot
.36676 .59927 Mdot
.57688 .34552 Mdot
.55449 .62235 Mdot
.4343 .26155 Mdot
.51348 .92113 Mdot
.54355 .83341 Mdot
.54056 .14666 Mdot
.71295 .48159 Mdot
.65449 .76148 Mdot
.57094 .28852 Mdot
.61683 .58542 Mdot
.66171 .63065 Mdot
.47104 .0404 Mdot
.42256 .67802 Mdot
.48586 .94529 Mdot
.44339 .97537 Mdot
.3643 .44239 Mdot
.61817 .45098 Mdot
.51877 .83131 Mdot
.64867 .5426 Mdot
.62952 .37156 Mdot
.40214 .51213 Mdot
.52515 .29892 Mdot
.69144 .35974 Mdot
.55717 .72362 Mdot
.55418 .86395 Mdot
.68356 .33849 Mdot
.38027 .66557 Mdot
.35376 .52062 Mdot
.58756 .69325 Mdot
.55671 .76814 Mdot
.70532 .60421 Mdot
.57147 .89717 Mdot
.44021 .18061 Mdot
.61989 .20697 Mdot
.61526 .32745 Mdot
.40593 .39578 Mdot
.69388 .26293 Mdot
.48506 .94432 Mdot
.51699 .33397 Mdot
.67667 .70066 Mdot
.71296 .55442 Mdot
.43183 .3034 Mdot
.5527 .45334 Mdot
.41054 .5734 Mdot
.58212 .20239 Mdot
.52916 .20096 Mdot
.5149 .58728 Mdot
.45372 .24101 Mdot
.41918 .60989 Mdot
.48601 .9438 Mdot
.50858 .48041 Mdot
.35374 .51776 Mdot
.44327 .2076 Mdot
.4038 .82335 Mdot
.59755 .55196 Mdot
.65391 .36779 Mdot
.5614 .80321 Mdot
.42054 .55256 Mdot
.62182 .4895 Mdot
.65056 .7739 Mdot
.53773 .64925 Mdot
.53591 .72965 Mdot
.50077 .79507 Mdot
.40998 .29617 Mdot
.55374 .46685 Mdot
.36615 .58108 Mdot
.66932 .81229 Mdot
.53867 .596 Mdot
.43429 .76616 Mdot
.54634 .49999 Mdot
.6944 .76924 Mdot
.5532 .37579 Mdot
.67577 .32366 Mdot
.35742 .36077 Mdot
.43178 .19849 Mdot
.64671 .50248 Mdot
.39697 .55894 Mdot
.52356 .95131 Mdot
.64226 .59376 Mdot
.64069 .32138 Mdot
.58973 .33565 Mdot
.55113 .24074 Mdot
.53323 .27985 Mdot
.53697 .60526 Mdot
.58056 .20122 Mdot
.524 .29185 Mdot
.43338 .32674 Mdot
.71099 .46394 Mdot
.63601 .72073 Mdot
.6722 .14722 Mdot
.45208 .68435 Mdot
.42458 .26421 Mdot
.70157 .64067 Mdot
.71271 .57555 Mdot
.42234 .1101 Mdot
.49576 .08458 Mdot
.64369 .17668 Mdot
.40467 .22763 Mdot
.49132 .94662 Mdot
.58561 .20867 Mdot
.46443 .25077 Mdot
.61822 .75831 Mdot
.73024 .68357 Mdot
.62935 .63635 Mdot
.45927 .29821 Mdot
.39065 .67165 Mdot
.64223 .575 Mdot
.44537 .97493 Mdot
.40922 .24812 Mdot
.45176 .86391 Mdot
.42646 .89922 Mdot
.4657 .03892 Mdot
.5672 .84728 Mdot
.44258 .26629 Mdot
.6286 .80704 Mdot
.48938 .98443 Mdot
.73851 .38714 Mdot
.44384 .70873 Mdot
.4194 .33065 Mdot
.43831 .18622 Mdot
.59813 .79994 Mdot
.6749 .72133 Mdot
.76467 .3038 Mdot
.51638 .25108 Mdot
.46415 .81502 Mdot
.62638 .14824 Mdot
.40313 .64772 Mdot
.4636 .79092 Mdot
.56543 .17419 Mdot
.52129 .52864 Mdot
.45644 .12373 Mdot
.39891 .19267 Mdot
.43902 .91992 Mdot
.70436 .62293 Mdot
.46144 .04534 Mdot
.41207 .13664 Mdot
.60348 .51213 Mdot
.39546 .78412 Mdot
.36954 .324 Mdot
.67457 .52563 Mdot
.54368 .78657 Mdot
.64185 .45198 Mdot
.68321 .69879 Mdot
.66076 .38183 Mdot
.41908 .65889 Mdot
.41704 .11806 Mdot
.61194 .76548 Mdot
.53695 .59503 Mdot
.4716 .79178 Mdot
.54701 .69961 Mdot
.55292 .33395 Mdot
.65871 .74873 Mdot
.70812 .73989 Mdot
.43891 .15128 Mdot
.48918 .69573 Mdot
.50898 .92479 Mdot
.38157 .30758 Mdot
.397 .85401 Mdot
.46642 .76867 Mdot
.3696 .33526 Mdot
.53555 .47979 Mdot
.70293 .425 Mdot
.73523 .6645 Mdot
.71551 .49183 Mdot
.36351 .44147 Mdot
.47374 .87829 Mdot
.58987 .1052 Mdot
.59635 .8035 Mdot
.44645 .30379 Mdot
.66054 .20655 Mdot
.62197 .82438 Mdot
.44381 .01502 Mdot
.48867 .98754 Mdot
.46654 .81825 Mdot
.58092 .9387 Mdot
.60595 .37404 Mdot
.52782 .51116 Mdot
.52659 .54052 Mdot
.50291 .64156 Mdot
.5674 .63574 Mdot
.53929 .98516 Mdot
.64559 .51839 Mdot
.47014 .72516 Mdot
.4104 .24525 Mdot
.43869 .30138 Mdot
.511 .66715 Mdot
.56857 .53934 Mdot
.40867 .19847 Mdot
.43263 .23603 Mdot
.66135 .38463 Mdot
.51712 .70418 Mdot
.64328 .46783 Mdot
.40811 .37899 Mdot
.37118 .30654 Mdot
.53612 .53681 Mdot
.57368 .24088 Mdot
.47712 .99541 Mdot
.41803 .29625 Mdot
.61596 .20412 Mdot
.65356 .35541 Mdot
.66515 .41711 Mdot
.55006 .57832 Mdot
.58348 .53983 Mdot
.56051 .81086 Mdot
.53777 .59408 Mdot
.50734 .96648 Mdot
.66932 .2147 Mdot
.55293 .44333 Mdot
.51022 .43416 Mdot
.54679 .97494 Mdot
.50303 .82262 Mdot
.55073 .64148 Mdot
.61274 .13485 Mdot
.44181 .75347 Mdot
.63287 .63929 Mdot
.41673 .17194 Mdot
.6448 .55281 Mdot
.6899 .25652 Mdot
.39799 .66758 Mdot
.67804 .48551 Mdot
.52697 .19748 Mdot
.71558 .51038 Mdot
.53946 .42669 Mdot
.37643 .38972 Mdot
.41752 .7328 Mdot
.52037 .18697 Mdot
.46865 .94713 Mdot
.41833 .06545 Mdot
.46006 .69927 Mdot
.43571 .34887 Mdot
.38872 .25948 Mdot
.57117 .333 Mdot
.48913 .78412 Mdot
.50361 .85838 Mdot
.5081 .53629 Mdot
.60089 .85448 Mdot
.66575 .29228 Mdot
.5297 .77883 Mdot
.55123 .6398 Mdot
.67176 .45909 Mdot
.42803 .47517 Mdot
.42049 .75282 Mdot
.62424 .36274 Mdot
.5353 .32661 Mdot
.41841 .78024 Mdot
.64554 .68532 Mdot
.59166 .41164 Mdot
.64506 .69259 Mdot
.53155 .81383 Mdot
.46239 .22655 Mdot
.57808 .66008 Mdot
.39725 .20025 Mdot
.44243 .73134 Mdot
.5833 .45887 Mdot
.69201 .36542 Mdot
.56967 .53191 Mdot
.44505 .13796 Mdot
.46642 .94975 Mdot
.5054 .32577 Mdot
.46637 .76557 Mdot
.45403 .05184 Mdot
.54673 .92462 Mdot
.54334 .30272 Mdot
.50183 .36352 Mdot
.57978 .45985 Mdot
.6566 .66635 Mdot
.42849 .7448 Mdot
.63539 .31503 Mdot
.73657 .65807 Mdot
.59197 .16643 Mdot
.5543 .91182 Mdot
.58187 .15443 Mdot
.47939 .67055 Mdot
.58944 .15945 Mdot
.61629 .14409 Mdot
.67221 .60315 Mdot
.53229 .93784 Mdot
.7924 .38142 Mdot
.58717 .62946 Mdot
.42843 .82161 Mdot
.63771 .60748 Mdot
.71474 .50041 Mdot
.36698 .61085 Mdot
.54613 .35638 Mdot
.68544 .34727 Mdot
.58401 .37359 Mdot
.504 .35014 Mdot
.39444 .28237 Mdot
.46458 .14782 Mdot
.4621 .0804 Mdot
.59872 .11294 Mdot
.44072 .64442 Mdot
.5939 .28187 Mdot
.60119 .37058 Mdot
.66085 .73936 Mdot
.43503 .38199 Mdot
.39215 .83077 Mdot
.49744 .00895 Mdot
.75642 .47904 Mdot
.52663 .33492 Mdot
.4237 .18576 Mdot
.62285 .51537 Mdot
.43372 .9087 Mdot
.58008 .58136 Mdot
.52865 .49305 Mdot
.4546 .64612 Mdot
.52431 .19537 Mdot
.51936 .96097 Mdot
.37827 .36661 Mdot
.54666 .49935 Mdot
.38131 .4959 Mdot
.48089 .28594 Mdot
.50142 .64651 Mdot
.55362 .82189 Mdot
.38932 .47053 Mdot
.54074 .79199 Mdot
.60331 .50857 Mdot
.57569 .59624 Mdot
.36591 .73631 Mdot
.57515 .34743 Mdot
.59551 .7349 Mdot
.51233 .32232 Mdot
.68488 .68516 Mdot
.56231 .57997 Mdot
.5849 .81902 Mdot
.52604 .85681 Mdot
.49094 .73918 Mdot
.41774 .69038 Mdot
.73834 .38497 Mdot
.5041 .97575 Mdot
.59535 .16625 Mdot
.65296 .66488 Mdot
.59418 .59984 Mdot
.59031 .32856 Mdot
.61822 .75385 Mdot
.45786 .84023 Mdot
.50877 .97037 Mdot
.75975 .52027 Mdot
.67877 .50374 Mdot
.45727 .98585 Mdot
.38426 .78683 Mdot
.37632 .26105 Mdot
.45869 .67627 Mdot
.53475 .76715 Mdot
.48923 .98405 Mdot
.58875 .87301 Mdot
.44599 .64121 Mdot
.61303 .26368 Mdot
.56276 .31624 Mdot
.42577 .18159 Mdot
.6459 .4809 Mdot
.68674 .35545 Mdot
.63507 .6294 Mdot
.52827 .0838 Mdot
.38253 .67739 Mdot
.41371 .80605 Mdot
.57032 .1314 Mdot
.40375 .7627 Mdot
.38682 .79539 Mdot
.71757 .21294 Mdot
.46154 .04743 Mdot
.496 .12342 Mdot
.51776 .44549 Mdot
.43326 .03624 Mdot
.40589 .32385 Mdot
.46428 .6647 Mdot
.38108 .76869 Mdot
.58798 .21208 Mdot
.52876 .48669 Mdot
.41384 .50381 Mdot
.52686 .23365 Mdot
.53773 .68296 Mdot
.7008 .39177 Mdot
.66895 .40665 Mdot
.64579 .18489 Mdot
.38807 .81043 Mdot
.53651 .21879 Mdot
.40365 .93404 Mdot
.56976 .28098 Mdot
.54935 .32316 Mdot
.57669 .42023 Mdot
.45077 .38201 Mdot
.54284 .9329 Mdot
.51168 .96641 Mdot
.55706 .61091 Mdot
.51086 .69357 Mdot
.52439 .72298 Mdot
.50972 .72588 Mdot
.52972 .03608 Mdot
.44167 .7867 Mdot
.67525 .53351 Mdot
.43599 .67884 Mdot
.45922 .78644 Mdot
.43983 .35539 Mdot
.49175 .81153 Mdot
.55135 .24808 Mdot
.5137 .74397 Mdot
.45141 .70132 Mdot
.63457 .16166 Mdot
.63066 .80398 Mdot
.49466 .41213 Mdot
.60977 .6236 Mdot
.55065 .23999 Mdot
.5002 .13138 Mdot
.57822 .36195 Mdot
.44516 .76232 Mdot
.45573 .00568 Mdot
.65675 .83755 Mdot
.62674 .65822 Mdot
.58447 .0438 Mdot
.64431 .58788 Mdot
.42471 .55189 Mdot
.70946 .48105 Mdot
.4754 .98835 Mdot
.56836 .50351 Mdot
.53279 .84581 Mdot
.361 .68432 Mdot
.49953 .72118 Mdot
.51459 .38485 Mdot
.56523 .37531 Mdot
.6725 .45963 Mdot
.60001 .50684 Mdot
.6242 .88242 Mdot
.53259 .56786 Mdot
.61128 .6073 Mdot
.61924 .45251 Mdot
.54308 .44412 Mdot
.45344 .6849 Mdot
.42184 .63654 Mdot
.57908 .88799 Mdot
.42725 .49087 Mdot
.41979 .88072 Mdot
.57962 .77463 Mdot
.61788 .33839 Mdot
.63248 .72639 Mdot
.61027 .25998 Mdot
.50768 .1723 Mdot
.72622 .70057 Mdot
.41561 .43075 Mdot
.50896 .9726 Mdot
.4222 .05493 Mdot
.53264 .32039 Mdot
.59365 .16466 Mdot
.58537 .38622 Mdot
.40002 .40061 Mdot
.58771 .81479 Mdot
.64723 .5134 Mdot
.4926 .20649 Mdot
.41353 .66317 Mdot
.57437 .29495 Mdot
.70572 .28245 Mdot
.47673 .87579 Mdot
.50821 .467 Mdot
.55267 .77138 Mdot
.59484 .58043 Mdot
.46033 .68016 Mdot
.53207 .35377 Mdot
.5915 .68301 Mdot
.4532 .8669 Mdot
.5047 .65918 Mdot
.54507 .27115 Mdot
.7124 .56025 Mdot
.5527 .68909 Mdot
.60851 .31747 Mdot
.41349 .37578 Mdot
.42052 .33011 Mdot
.43306 .44812 Mdot
.66133 .13149 Mdot
.43676 .40716 Mdot
.549 .82829 Mdot
.60718 .19286 Mdot
.67408 .54698 Mdot
.40845 .47847 Mdot
.54478 .87907 Mdot
.43042 .95338 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00WOooool2o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`2iooooo`00WOooool2o`0000Gooooo00?o0000ooooooooool01?ooool2o`000;_ooooo002T
ooooo`03o`000?oooooooooo00Cooooo0_l0002kooooo`00VOooool2o`0000Oooooo00?oEEEEofIV
I_l000001oooool00ol0003oooooooooo`2iooooo`00VOooool2o`00017ooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00U_ooool2o`0001Cooooo00?o0000ooooooooool01_ooool2o`000;7ooooo
002Fooooo`;o00002?ooool4o`0000Sooooo00?o0000ooooooooool01_ooool2o`000;7ooooo002P
ooooo`Co00002?ooool00ol0003oooooooooo`0Hooooo`;o0000Woooool009oooooo0_l0000;oooo
o`03o`000?oooooooooo01Sooooo0_l0002Oooooo`00Woooool2o`0000_ooooo00?o0000oooooooo
ool0^Oooool009cooooo0_l000000ooooooo0000o`00000;ooooo`?o0000^Oooool009;ooooo0_l0
0008ooooo`;o00003_ooool00ol0003oooooooooo`2iooooo`00T_ooool2o`0001Sooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool0097ooooo0_l0000Iooooo`03o`000?oooooooooo0;Wooooo002Aooooo`;o00006Ooo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`00
0;Wooooo002Oooooo`;o00002oooool00ol0003oooooooooo`2iooooo`00Woooool2o`0000_ooooo
00?o0000ooooooooool0^Oooool00:[ooooo0ol00008ooooo`;o0000/Oooool00:[ooooo0ol00008
ooooo`;o0000/Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00Co0000ooooool0003o0000^?ooool00:cooooo1?l0002hooooo`00[?oo
ool01?l0003oooooo`000?l0002hooooo`00[?ooool00ol0003oooooooooo`0Jooooo`;o0000WOoo
ool009;ooooo0_l0000Hooooo`03o`000?oooooooooo01[ooooo0_l0002Mooooo`00T_ooool2o`00
01Sooooo00?o0000ooooooooool07Oooool2o`0009[ooooo002/ooooo`03o`000?oooooooooo01go
oooo0_l0002Jooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo0_l000000ooooooo
8B4Qob4Q8@06ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0;Wooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool2o`00
0003oooooolQ8B7o8B4Q00Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo00Gooooo0_l0002booooo`00POooool6o`0000;ooooo00Go410@oooooooo
oooooooooa0@400=ooooo`04ojVYZOmEEEGo0000o`0000Oooooo00Co0000oooooooooooooooo1Ol0
0005ooooo`;o0000/_ooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ol0
003o000000Kooooo00?oMgMgoc8b<_ooool00_ooool3o`000;_ooooo0029ooooo`05o`000?oooooo
ooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool2o`0001Gooooo0_l0000Looooo`;o0000QOooool008Wooooo00Go410@oooooooooooooooo
oa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool2o`0001Gooooo
0_l0000<ooooo`;o00003_ooool2o`0008Gooooo0029ooooo`06ogMgMonHV9SooooooiRHV?mgMgOo
oooo0_l00008ooooo`;o00000_ooool00olb<S;oooooooooo`02ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool08_ooool2o`0009Gooooo0029ooooo`06onk^k_lb<S;o0000oc8b<_o^
k^kooooo0_l00008ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool02_ooool2o`0001Oooooo
0_l0002Dooooo`00X?ooool2o`0000[ooooo00?o0000ooooooooool02_ooool2o`0001Oooooo0_l0
00000ooooooo0000o`00000=ooooo`;o0000P_ooool009Oooooo0_l00007ooooo`;o00002_ooool3
o`0002Kooooo0_l0000=ooooo`;o0000P_ooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo
00gooooo0_l00009ooooo`;o0000Woooool00:cooooo00?o0000ooooooooool03Oooool2o`0000Wo
oooo0_l0002Oooooo`00[?ooool00ol0003oooooooooo`0Jooooo`;o00003Oooool2o`0008kooooo
002/ooooo`03o`000?oooooooooo01[ooooo0ol0000<ooooo`;o0000S_ooool00:cooooo00?o0000
ooooooooool06oooool3o`0009_ooooo002/ooooo`03o`000?oooooooooo01_ooooo0ol0002Koooo
o`00T?ooool2o`0001[ooooo00Co0000ooooool0003o00004Oooool2o`000:Gooooo002@ooooo`;o
00006_ooool4o`00017ooooo0_l0000Hooooo`;o0000Roooool00:cooooo00?o0000ooooooooool0
;?ooool2o`0008_ooooo002Cooooo`;o00000oooool2o`0001;ooooo00?o0000ooooooooool0^Ooo
ool009;ooooo0ol00002ooooo`?o00004_ooool00ol0003oooooooooo`0]ooooo`;o0000R_ooool0
09;ooooo0_l00003ooooo`;o00004oooool00ol0003oooooooooo`03ooooo`;o0000:?ooool2o`00
08[ooooo002/ooooo`03o`000?oooooooooo00?ooooo0_l0002dooooo`00R_ooool2o`00023ooooo
00?o0000ooooooooool01Oooool2o`0001Wooooo0_l0002Gooooo`00R_ooool2o`000003ooooool0
003o000000Kooooo0ol0000;ooooo`;o00001oooool00ol0003oooooooooo`05ooooo`;o00006Ooo
ool2o`0009Oooooo002:ooooo`;o000000?oooooo`000?l000001_ooool3o`0000_ooooo0_l00007
ooooo`?o00001Oooool3o`0000oooooo0_l0002Pooooo`00R_ooool2o`00023ooooo00?o0000oooo
ooooool01_ooool2o`0000oooooo0ol00009ooooo`;o0000U?ooool009Wooooo0_l0000>ooooo`;o
000000?oooooo`000?ooool06Oooool2o`0000Wooooo0ol0000<ooooo`;o0000QOooool009Wooooo
0_l0000>ooooo`;o000000?oooooo`000?ooool06_ooool2o`0000Wooooo0_l0000<ooooo`;o0000
QOooool00:cooooo00?o0000ooooooooool06Oooool3o`0002Sooooo0_l0001cooooo`00[?ooool0
0ol0003oooooooooo`0Jooooo`;o00006?ooool2o`0000kooooo0_l0001cooooo`00[?ooool00ol0
003oooooooooo`09ooooo`;o0000:Oooool2o`0008?ooooo002/ooooo`03o`000?oooooooooo00Wo
oooo0_l0002^ooooo`00[?ooool3o`000;Wooooo002<ooooo`;o00004Oooool2o`0000_ooooo00?o
0000ooooooooool0^Oooool008cooooo0_l0000Aooooo`;o00002oooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`05ooooo`;o0000/_ooool009Gooooo0_l00006ooooo`;o
00003Oooool00ol0003oooooooooo`05ooooo`;o0000/_ooool009Gooooo0_l00005ooooo`?o0000
3Oooool00ol0003oooooooooo`0=ooooo`;o00001_ooool2o`000:;ooooo002Aooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool00olQ8B7o0000o`000004ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01Oooool00ol0003oooooooooo`0=ooooo`;o00001_ooool2o`000:;ooooo002>ooooo`;o0000
00KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo0;Wooooo0029ooooo`Oo000000?ooooooa0@4?ooool00_ooool00ol@413o
ooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool2o`000:Wo
oooo002>ooooo`;o000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`08ooooo`;o0000
0oooool00omgMgOo<S8booooo`04ooooo`?o00000_ooool2o`0000[ooooo0_l0002Yooooo`00TOoo
ool01Ol0003ooooooooooooooooo000000[ooooo0ol000001?lQ8B7o0000oc8b<_o<c<`5ooooo`03
o`000?oooooooooo00;ooooo0_l0002eooooo`00TOooool01Ol@413ooooooooooooooooo410@00co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0kooooo`;o0000O?ooool008?ooooo
0_l00002ooooo`;o00002?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00;o00002_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo027ooooo0_l0000Hooooo`;o0000O?ooool008?ooooo
0_l00002ooooo`;o00002?ooool01Oo^k^ko<S8bo`000?l0003ok^k^00;o00002_ooool4o`0000Ko
oooo00?o0000ooooooooool08Oooool3o`0001Wooooo0_l0001jooooo`00Toooool2o`0000Cooooo
0_l0000Aooooo`03o`000?oooooooooo02;ooooo0_l0000Iooooo`;o0000N_ooool009Wooooo0_l0
000Aooooo`03o`000?oooooooooo00_ooooo0_l0002/ooooo`00[?ooool00ol0003oooooooooo`0;
ooooo`;o0000[?ooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`08ooooo`;o
0000[oooool008Wooooo0_l0000Qooooo`03o`000?oooooooooo00Sooooo0_l0000:ooooo`;o0000
1_ooool2o`0002;ooooo0_l0001gooooo`00ROooool2o`0001[ooooo0_l00005ooooo`03o`000?oo
oooooooo01Cooooo0_l00006ooooo`;o00008_ooool2o`0007Oooooo002Uooooo`;o00001Oooool0
0ol0003oooooooooo`0Dooooo`;o0000Xoooool00:cooooo00?o0000ooooooooool01?ooool2o`00
00kooooo0_l0000Mooooo`;o0000Q?ooool00:cooooo00?o0000ooooooooool01?ooool2o`0000oo
oooo0_l0000Looooo`;o0000Q?ooool008kooooo0_l000000ooooooo0000o`00000;ooooo`;o0000
3?ooool00ol0003oooooooooo`0Eooooo`;o0000X_ooool008kooooo0_l000000ooooooo0000o`00
0004ooooo`;o00001Oooool2o`0000cooooo0ol00005ooooo`;o0000/_ooool009Gooooo1?l00000
0ooooooo0000o`00000@ooooo`03o`000?oooooooooo00Gooooo0_l00004ooooo`;o0000Aoooool2
o`0006?ooooo0021ooooo`;o000000?oooooo`000?l000003oooool2o`0000?ooooo0_l0000@oooo
o`03o`000?oooooooooo00_ooooo0_l00017ooooo`;o0000Hoooool0087ooooo0_l000000ooooooo
0000o`00000Vooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo017ooooo0_l0000Fooooo`;o0000S_ooool00:cooooo00?o0000
ooooooooool04Oooool2o`0000gooooo0_l00007ooooo`;o0000S_ooool009Kooooo0_l0000Doooo
o`04o`000?ooooooooooooooo`;o00001?ooool2o`0001Oooooo0_l00009ooooo`;o0000S?ooool0
083ooooo0_l0000:ooooo`;o00002?ooool2o`0001Cooooo0ol000000ooooooo0000o`000004oooo
o`;o00001?ooool2o`0001cooooo0_l0000:ooooo`;o0000P?ooool0083ooooo0_l0000:ooooo`;o
00002?ooool2o`0001Cooooo0ol00008ooooo`;o00000oooool2o`0000_ooooo0_l00007ooooo`;o
00004_ooool2o`00083ooooo002Aooooo`;o00000oooool2o`0001Cooooo00?o0000ooooooooool0
2?ooool2o`00013ooooo0_l00007ooooo`;o0000U?ooool0097ooooo0_l0000Iooooo`03o`000?oo
oooooooo00;ooooo0_l0000:ooooo`;o00001?ooool2o`000:?ooooo0021ooooo`;o0000:Oooool0
0ol0003oooooooooo`02ooooo`;o000000?oooooo`000?l000001oooool2o`0000Cooooo0_l00004
ooooo`;o0000WOooool0087ooooo0_l0000Yooooo`03o`000?oooooooooo00Gooooo0_l0000Coooo
o`;o00001oooool2o`0001Cooooo0_l0001nooooo`00[?ooool00ol0003oooooooooo`0Sooooo`;o
00005?ooool2o`0007kooooo002/ooooo`03o`000?oooooooooo01Kooooo0_l0002Qooooo`00U_oo
ool2o`0001Cooooo00?o0000ooooooooool05Oooool3o`0002;ooooo0_l0001mooooo`00U_ooool2
o`0001Cooooo0ol0000Eooooo`;o00008oooool2o`0007gooooo002Hooooo`;o00004_ooool3o`00
00Oooooo0_l0000Vooooo`;o00002Oooool2o`0007gooooo002Hooooo`;o00004_ooool00ol0003o
ooooooooo`07ooooo`;o00000oooool2o`00027ooooo0_l00009ooooo`;o0000OOooool007cooooo
0_l0000^ooooo`03o`000?oooooooooo00cooooo0_l00008ooooo`;o00009?ooool2o`0007_ooooo
001looooo`;o0000;_ooool2o`0001Oooooo0_l0000>ooooo`;o00005?ooool2o`0007_ooooo0023
ooooo`;o00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo0_l0000Wooooo`;o00001oooool2o`0000_ooooo
0_l0001kooooo`00Poooool2o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`0Nooooo`;o00003oooool2o`0000_ooooo0_l0001kooooo`00POooool6o`0000;ooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Hooooo`;o00001?ooool4o`0000Gooooo0_l0002@ooooo`00
ROooool01_l0003ooooooooooooooooo0000ooooo`;o00002_ooool00onHV9So8B4Qonk^kP07oooo
o`03ogMgMolb<S;ooooo00Cooooo0ol0000>ooooo`;o00000_ooool2o`0000Cooooo0_l00006oooo
o`;o00001Oooool2o`00093ooooo0029ooooo`04o`000?ooooooooooooooo`Co00002oooool00omg
MgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0>
ooooo`;o00000_ooool2o`000:Gooooo0029ooooo`04oa0@4?ooooooooooooooo`;o00001oooool2
o`0000?ooooo0ol00004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<_ooool2
o`0002Wooooo0_l0001Jooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo0_l00000
0ooooooo0000okZj^P02o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool01oooool0
1?l0003oooooooooooooool2o`0001Kooooo0_l0000Gooooo`;o00005oooool2o`00013ooooo0_l0
001Jooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c004ooooo`Co00001_ooool01?l0003oooooooooooooool2o`0001Kooooo0_l0000Gooooo`;o
00005oooool2o`0006cooooo0023ooooo`;o00009oooool00ol0003oooooooooo`0oooooo`;o0000
2_ooool2o`0006cooooo0023ooooo`;o00009oooool00ol0003oooooooooo`0oooooo`;o0000N?oo
ool008gooooo0_l0000Mooooo`03o`000?oooooooooo0;Wooooo0028ooooo`;o000000?oooooo`00
0?l000000_l0000Mooooo`?o00004?ooool2o`000:Oooooo0028ooooo`;o000000?oooooo`000?l0
00007oooool00ol0003oooooooooo`0@ooooo`;o0000Yoooool009Oooooo0_l0000Cooooo`03o`00
0?oooooooooo03Cooooo0_l00023ooooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool0=?oo
ool2o`0008?ooooo002Zooooo`?o00007Oooool2o`0009cooooo002Zooooo`?o00007Oooool2o`00
09cooooo002/ooooo`03o`000?oooooooooo03?ooooo0_l00024ooooo`00[?ooool00ol0003ooooo
ooooo`0Fooooo`;o00006oooool2o`0008Cooooo002/ooooo`?o00005_ooool2o`0002Sooooo0_l0
001gooooo`00[?ooool00ol0003oooooooooo`0:ooooo`;o0000=?ooool2o`0007Oooooo002@oooo
o`;o00006_ooool00ol0003oooooooooo`0:ooooo`;o0000[Oooool0093ooooo0_l0000Jooooo`03
o`000?oooooooooo00;o0000]oooool00:cooooo00?o0000ooooooooool00_l0002gooooo`00[?oo
ool00ol0003oooooooooo`0/ooooo`;o0000Roooool007oooooo0_l0000[ooooo`03o`000?oooooo
oooo00kooooo0_l0000Looooo`;o0000Roooool007oooooo0_l0000[ooooo`03o`000?oooooooooo
00;ooooo0_l00007ooooo`;o000000?oooooo`000?l00000ZOooool009Gooooo0_l0000Eooooo`03
o`000?oooooooooo00;ooooo0_l00007ooooo`;o0000[?ooool009Gooooo0_l0000Eooooo`?o0000
9?ooool2o`0000Gooooo0_l0002<ooooo`00[?ooool00ol0003oooooooooo`0>ooooo`;o00005?oo
ool2o`0000Gooooo0_l0002<ooooo`00[?ooool00ol0003oooooooooo`0>ooooo`;o00002?ooool2
o`0001_ooooo0_l00022ooooo`002Oooool4o`000003oa0@4?oooooooooo01Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o
0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Kooooo00?o0000ooooooooool05oooool4
o`000003oc8b<_o^k^kooooo00Cooooo0_lQ8B44ooooo`Go00001?ooool01?m4A4Co0000o`000?lb
<S83o`0000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0
003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd06?ooool4o`000003oa0@4?oooooo
oooo01;ooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03
ogMgMolb<S;ooooo01Gooooo00?o0000ooooooooool05oooool2o`000004oiRHV?ooooooV9RHogMg
M`Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool01?mgMgOo<S8bo`000?l0
000:ooooo`;o000000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q2?ooool00omgMgOo
<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVY
ZOooool01oooool00omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo0006o`0000Go
oooo00?o0000ooooooooool04?ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=oooo
o`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool01Oooool6o`0000;ooooo00Go410@oooo
oooooooooooooa0@400@ooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo01Cooooo00Co
0000ooooool0003o00003Oooool2o`0000Sooooo00Go410@oooooooooooooooooa0@400<ooooo`03
oiRHV?lQ8B7ok^k^00;o00001oooool00ol0003oooooooooo`0:ooooo`;o000000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00Go410@oooooooo
oooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05o`000?oooooooooooooo
ool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00
000:ooooo`;o000000CooooooiRHV?lQ8B7ok^k^1oooool00omgMgOo<S8booooo`0Eooooo`04o`00
0?oooooo0000o`0000gooooo0_l00008ooooo`05o`000?ooooooooooooooool000003Oooool01?nH
V9So8B4Qo`000?l00006ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00
000?ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q
8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool06Oooool00ol0003oooooooooo`0Dooooo`002ooo
ool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<
ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo0000
00cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000002_oo
ool2o`0000;ooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Kooooo
00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_oo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000<
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000kooooo
00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[ooooo00?o0000oooooooo
ool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol@413ooooooooooooooooo410@00ko
oooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`0Aooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o00005_ooool3o`0001Sooooo00Go410@
oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04Ooo
ool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04Oooool01Ol@413ooooo
oooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`0Aoooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00;o00000_ooool00ol0003ooooo
ooooo`02o`0001Kooooo00?o0000ooooooooool02?ooool2o`0000kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`0Aoooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01oooool2o`0000?ooooo00?o0000ooooooooool04Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool05?ooool000Wooooo00?oEEEEofIVI_l000006_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00004?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnH
V9So410@o`000?lQ8B7oc<c<00;o00000_ooool4o`0001Oooooo00Co0000ooooool0003o00001ooo
ool2o`0000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`00_l00002ooooo`Co00003Oooool3o`000005onk^k_lb<S;o0000oc8b<_o^k^h01oooool2o`00
00?ooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000I
ooooo`03oeEEEOmVIVKo000001Kooooo002/ooooo`04o`000?oooooo0000o`0002cooooo0_l00008
ooooo`;o00002Oooool3o`0007Cooooo002/ooooo`03o`000?oooooooooo00Kooooo0_l0000_oooo
o`;o0000P?ooool009Cooooo0_l0000Fooooo`03o`000?oooooooooo00Kooooo0_l0000;ooooo`;o
00004?ooool2o`0001gooooo0_l0001Xooooo`;o00000_ooool2o`0000Gooooo002Dooooo`;o0000
5_ooool00ol0003oooooooooo`06ooooo`;o00002oooool2o`00013ooooo0_l0000Mooooo`;o0000
J?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Gooooo0024ooooo`;o00009_ooool00ol0003o
ooooooooo`06ooooo`;o0000Yoooool01?oMgMgo0000oa0@4?o<c<`6ooooo`001oooooooo`0004co
00003?ooool01?o^k^ko8B4Qoa0@4?o^k^h6ooooo`001oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`04
o`000?ooooooooooooooo`;o00000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00?ooooo0ol00004ooooo`;o000000?oooooo`000?ooool01_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00?ooooo0ol00007ooooo`?o00001Oooool01?l0003oooooooooooooool2
o`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00[ooooo00Co8B4QogMgMomgMgOo<S8b1_ooool000Oooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02Oooool2
o`0001_ooooo00?o0000ooooooooool04oooool2o`0000Wooooo0_l00007ooooo`03o`000?oooooo
oooo00?ooooo0_l00009ooooo`;o00005_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool02Oooool2o`0000;ooooo0_l00005ooooo`00[?ooool00ol0
003oooooooooo`0Nooooo`?o00008oooool2o`0007?ooooo002;ooooo`;o00007oooool00ol0003o
ooooooooo`06ooooo`;o00005oooool2o`0000cooooo0_l0000Eooooo`;o0000Loooool008_ooooo
0_l0000Oooooo`03o`000?oooooooooo00Kooooo0_l0000Gooooo`;o00001?ooool2o`0000Kooooo
0_l0002:ooooo`00Noooool2o`0002oooooo00?o0000ooooooooool09Oooool2o`0000Kooooo0_l0
002:ooooo`00Noooool2o`0002oooooo00?o0000ooooooooool0;Oooool2o`0002?ooooo0_l0001U
ooooo`00Noooool2o`0002oooooo0ol0000fooooo`;o00006_ooool2o`0006Gooooo002/ooooo`03
o`000?oooooooooo00Cooooo0_l0000`ooooo`;o0000POooool00:cooooo00?o0000ooooooooool0
1?ooool2o`000;?ooooo002/ooooo`03o`000?oooooooooo01Cooooo0_l0000Pooooo`;o0000POoo
ool00:cooooo00Co0000ooooool0003o00001oooool2o`0000[ooooo0_l0000Pooooo`;o0000POoo
ool009Oooooo0_l0000Cooooo`04o`000?oooooo0000o`0000Cooooo0_l000000ooooooo0000o`00
0009ooooo`;o00000oooool2o`0009oooooo002Gooooo`;o00004oooool00ol0003oooooooooo`05
ooooo`;o00003?ooool2o`0000?ooooo0_l0000Dooooo`;o0000ROooool00:cooooo00?o0000oooo
ooooool0;_ooool2o`0008Wooooo002/ooooo`03o`000?oooooooooo03Kooooo0_l00021ooooo`00
TOooool4o`0001Oooooo0ol0000Mooooo`;o00003Oooool2o`0000Sooooo0_l00021ooooo`00TOoo
ool4o`0001Oooooo00?o0000ooooooooool07Oooool2o`0000gooooo0_l0000Eooooo`;o0000M?oo
ool008[ooooo0_l0000Pooooo`03o`000?oooooooooo04?ooooo0_l0001dooooo`00R_ooool2o`00
023ooooo00?o0000ooooooooool03_ooool2o`0003?ooooo0_l0001dooooo`00[?ooool00ol0003o
ooooooooo`0>ooooo`;o0000<oooool2o`0007Cooooo002/ooooo`03o`000?oooooooooo00Oooooo
0_l0002`ooooo`00[?ooool00ol0003oooooooooo`07ooooo`;o0000/?ooool008kooooo0_l0000L
ooooo`03o`000?oooooooooo0;Wooooo002>ooooo`;o00007?ooool3o`0002cooooo0_l0000Eoooo
o`;o0000M?ooool00:cooooo00?o0000ooooooooool03Oooool2o`0000;ooooo0_l0000Iooooo`;o
00005Oooool2o`0007Cooooo001oooooo`;o0000:oooool00ol0003oooooooooo`0=ooooo`;o0000
0_ooool2o`0000Cooooo0_l00003ooooo`;o0000Voooool007oooooo0_l0000[ooooo`03o`000?oo
oooooooo01Oooooo0_l00003ooooo`;o00001Oooool2o`0009Cooooo002/ooooo`04o`000?oooooo
ooooooooo`;o00008?ooool2o`0000Oooooo0_l0002;ooooo`00[?ooool01?l0003ooooooooooooo
ool2o`0002Wooooo0_l0002;ooooo`00W?ooool2o`0000kooooo00?o0000ooooooooool02Oooool2
o`00027ooooo0_l0002;ooooo`00W?ooool2o`0000kooooo00?o0000ooooooooool02Oooool2o`00
00_ooooo0_l0000Dooooo`;o0000Roooool0083ooooo0_l0000Zooooo`?o00002Oooool2o`0000_o
oooo0_l00004ooooo`;o0000Voooool0083ooooo0_l0000Zooooo`03o`000?oooooooooo01cooooo
0_l0000Gooooo`;o00002Oooool2o`0007Oooooo002/ooooo`03o`000?oooooooooo00Wooooo0_l0
000Fooooo`;o00001oooool2o`0000Wooooo0_l00009ooooo`;o0000Moooool0097ooooo0_l0000I
ooooo`03o`000?oooooooooo00Wooooo0_l0000Fooooo`;o00001oooool2o`0008gooooo0020oooo
o`;o00003oooool2o`0001Wooooo00?o0000ooooooooool03oooool2o`000:Sooooo0020ooooo`;o
0000:_ooool00ol0003oooooooooo`0?ooooo`;o0000Z?ooool008Wooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0;Wooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool03oooool2o`000:Sooooo0029ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0000?ooooo`;o00004?ooool2
o`0001gooooo0_l0001gooooo`00ROooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo027ooooo0_l0000M
ooooo`;o0000Moooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKo
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo01Wooooo0_l0
000>ooooo`;o00001oooool2o`0008Gooooo0029ooooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06Ooo
ool2o`0000kooooo0_l00007ooooo`;o0000QOooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`04ooooo`;o00001Oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Cooooo`;o00004_ooool2o`00093ooooo0029ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01?ooool2o`0000Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co
00001_ooool00ol0003oooooooooo`0=ooooo`;o00001?ooool2o`0001;ooooo0ol0000Eooooo`;o
0000N?ooool009[ooooo0_l0000@ooooo`?o00003Oooool2o`0001Wooooo0_l0000Eooooo`;o0000
N?ooool009Sooooo1?l000000ooooooo0000o`00000=ooooo`?o00003Oooool2o`000:[ooooo002<
ooooo`;o00002_ooool2o`0000?ooooo0_l0000=ooooo`;o00002_ooool2o`000:kooooo002<oooo
o`;o00007_ooool3o`0000Wooooo0_l0002^ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
TOooool2o`0001Wooooo00?o0000ooooooooool09_ooool2o`0002?ooooo0_l0001/ooooo`00TOoo
ool2o`0001Wooooo0ol0000Fooooo`;o00003_ooool2o`0002?ooooo0_l0001/ooooo`00Soooool2
o`0000oooooo0_l0000:ooooo`?o00005_ooool2o`0001Oooooo0_l0000Iooooo`;o0000KOooool0
08Cooooo0_l00004ooooo`;o00000oooool2o`0000oooooo0_l0000:ooooo`03o`000?oooooooooo
00;o0000;Oooool3o`0001Sooooo0_l0001]ooooo`00Q?ooool2o`0000Cooooo0_l0000Iooooo`;o
00001Oooool00ol0003oooooooooo`02o`0002kooooo0_l00027ooooo`00Qoooool2o`0001cooooo
0_l00005ooooo`03o`000?oooooooooo0;Wooooo0027ooooo`;o00005Oooool2o`0000cooooo0ol0
002iooooo`00QOooool2o`0000_ooooo0_l00002ooooo`;o00001_ooool2o`0000cooooo00?o0000
ooooooooool0^Oooool008Gooooo0_l0000;ooooo`;o00000_ooool2o`0000Kooooo0_l0000<oooo
o`03o`000?oooooooooo00Wooooo0_l0000@ooooo`;o0000W?ooool007kooooo0_l0000Looooo`;o
00003_ooool00ol0003oooooooooo`09ooooo`;o00004?ooool2o`00013ooooo0_l0000;ooooo`;o
00003Oooool2o`0006kooooo001nooooo`;o00007?ooool2o`0000kooooo00?o0000ooooooooool0
3_ooool2o`0001gooooo0_l0000;ooooo`;o00003Oooool2o`0006kooooo002@ooooo`;o00006_oo
ool00ol0003oooooooooo`0>ooooo`;o0000ZOooool0093ooooo0_l0000Jooooo`03o`000?oooooo
oooo00;o00005oooool2o`00017ooooo0_l0002;ooooo`00Z?ooool2o`0000;ooooo00?o0000oooo
ooooool00_l0000;ooooo`;o00002_ooool2o`00017ooooo0_l0002;ooooo`00W?ooool4o`0000So
oooo0_l00002ooooo`?o00003?ooool3o`0002Sooooo1?l0000<ooooo`;o0000L?ooool009cooooo
1?l0000<ooooo`03o`000?oooooooooo00;ooooo0_l00008ooooo`;o0000:Oooool4o`0000cooooo
0_l0001`ooooo`00[?ooool00ol0003oooooooooo`02ooooo`;o0000]Oooool009Wooooo0_l0000A
ooooo`03o`000?oooooooooo0;Wooooo002Iooooo`;o00004Oooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00Zooo
ool2o`0002_ooooo0_l0000;ooooo`;o0000POooool00:;ooooo0_l00007ooooo`Co00001Oooool2
o`0000Sooooo0_l0000Hooooo`;o00002oooool2o`00087ooooo002Rooooo`;o00002?ooool00ol0
003oooooooooo`02o`0000?ooooo0_l00008ooooo`;o00005oooool2o`0008oooooo002Iooooo`;o
00004Oooool00ol0003oooooooooo`02o`0000Kooooo0_l0000Nooooo`;o0000Soooool008[ooooo
0_l00004ooooo`;o00001oooool2o`00017ooooo00?o0000ooooooooool02?ooool2o`000:oooooo
001oooooo`;o00002Oooool2o`0000Cooooo0_l0000Jooooo`03o`000?oooooooooo01cooooo0_l0
002Kooooo`00Ooooool2o`0002Sooooo0_l000000ooooooo0000ooooo`0Mooooo`;o00005?ooool2
o`0000gooooo0_l0001fooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool2o`000003ooooool0003ooooo03?ooooo0_l0
000=ooooo`;o0000M_ooool0097ooooo00?oMgMgoiRHV?ooool00_l00005ooooo`;o8B4Q2?ooool0
0omgMgOo<S8booooo`04ooooo`04o`000?ooooooooooooooo`;o0000]_ooool0097ooooo00?o410@
ooooooooool00_l0000@ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l0
000^ooooo`;o0000Q_ooool0097ooooo0_l00002ooooo`03o`000?oooooooooo00gooooo00?oMgMg
oc8b<_ooool01?ooool3o`00037ooooo0_l00026ooooo`00TOooool2o`0000;ooooo00?o0000oooo
ooooool00_l00008ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0T
ooooo`;o0000Toooool0097ooooo00Go410@oooooooooooooooooa0@4002ooooo`;o00002?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Cooooo0_l0002Cooooo`00TOooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0T
ooooo`;o00002_ooool2o`0008Oooooo002<ooooo`;o00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo0_l00007ooooo`Co00001_ooool00ol0003oooooooooo`0`ooooo`;o0000Qoooool0
08cooooo0_l00008ooooo`;o000000?oooooo`000?l000001Oooool2o`0000[ooooo00?o0000oooo
ooooool02?ooool2o`0001Sooooo0_l0002Eooooo`00Q?ooool2o`00013ooooo0_l00008ooooo`;o
00002_ooool00ol0003oooooooooo`08ooooo`;o00001Oooool2o`00017ooooo0_l0000Iooooo`;o
0000N_ooool008Cooooo0_l0000Jooooo`;o00002_ooool00ol0003oooooooooo`0>ooooo`?o0000
7Oooool2o`0000gooooo0_l0001jooooo`00[?ooool3o`0000kooooo0_l00007ooooo`;o00005Ooo
ool2o`0008Wooooo002/ooooo`03o`000?oooooooooo00Kooooo0_l0000?ooooo`;o0000X?ooool0
097ooooo0_l0000Iooooo`03o`000?oooooooooo00Kooooo0_l0002aooooo`00ROooool2o`0000Ko
oooo0_l0000Eooooo`;o00000_ooool00ol0003oooooooooo`2iooooo`00QOooool2o`0000;ooooo
0_l0000=ooooo`;o00001?ooool2o`0000Sooooo0_l00002ooooo`03o`000?oooooooooo00_ooooo
0_l0002/ooooo`00QOooool2o`00017ooooo0_l00004ooooo`Ko00002?ooool00ol0003ooooooooo
o`0:ooooo`?o0000[?ooool00:3ooooo1?l00008ooooo`;o00002oooool2o`000:gooooo0026oooo
o`;o00009?ooool2o`000;[ooooo0026ooooo`;o00009?ooool3o`0001gooooo0_l0002Jooooo`00
[?ooool00ol0003oooooooooo`0Aooooo`;o00002Oooool3o`0000Wooooo0_l0002?ooooo`00Sooo
ool2o`0001_ooooo00?o0000ooooooooool04Oooool2o`0000Wooooo0_l00009ooooo`?o0000Sooo
ool008Oooooo0_l00006ooooo`;o00006oooool00ol0003oooooooooo`0Wooooo`;o0000T?ooool0
08Oooooo0_l0000Pooooo`;o000000?oooooo`000?ooool04_ooool2o`00027ooooo0_l00023oooo
o`00X?ooool2o`0000Oooooo0_l000000ooooooo0000ooooo`08ooooo`;o00002?ooool2o`0000Oo
oooo0_l0000Hooooo`;o0000Poooool00:3ooooo0ol00009ooooo`03o`000?oooooooooo00Oooooo
0_l0000@ooooo`?o0000WOooool009Cooooo0_l0000;ooooo`;o00002Oooool3o`0000kooooo0_l0
0009ooooo`;o0000W_ooool008cooooo0_l00006ooooo`;o00005_ooool3o`0000kooooo0_l0000E
ooooo`;o0000T_ooool008cooooo0_l0000Nooooo`03o`000?oooooooooo00gooooo0_l0000Foooo
o`;o0000T_ooool008Sooooo0_l0000Rooooo`03o`000?oooooooooo00?ooooo0_l00008ooooo`;o
0000Z_ooool008Sooooo0_l0000Rooooo`03o`000?oooooooooo00?ooooo0_l00006ooooo`;o0000
[?ooool00:cooooo00?o0000ooooooooool02oooool2o`0002?ooooo0_l00027ooooo`00W_ooool2
o`0000cooooo00?o0000ooooooooool02oooool2o`0002?ooooo0_l00027ooooo`00W_ooool2o`00
00cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool01oooool2o`000;3o
oooo002Cooooo`;o00005oooool00ol0003oooooooooo`07ooooo`;o00002_ooool2o`000:Cooooo
002Cooooo`;o00005oooool3o`0001?ooooo0_l0002Tooooo`00R_ooool2o`00023ooooo00?o0000
ooooooooool07_ooool2o`0009Wooooo002:ooooo`;o00008?ooool3o`0000Gooooo0_l0000Goooo
o`;o0000VOooool00:cooooo0ol00005ooooo`;o0000/_ooool009cooooo0_l0000>ooooo`03o`00
0?oooooooooo00kooooo0_l0002Yooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`?o00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooooooo
ool03_ooool3o`000:Sooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Ko
oooo00?oEEEEo`000?l000001oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00oo
oooo0_l0002Xooooo`00ROooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOoo
ool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01[ooooo0_l0002Mooooo`00
ROooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01Oooool2o`000003
oc8b<_oooooooooo00?ooooo0ol0000Jooooo`;o0000WOooool008Wooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo1?l000000oo<c<coooooooooo`03ooooo`03
o`000?oooooooooo00_ooooo0_l0002/ooooo`00ROooool01Ol@413ooooooooooooooooo410@00?o
oooo0_l00009ooooo`03ojVYZOmgMgOooooo00?ooooo0ol00007ooooo`03o`000?oooooooooo00_o
oooo0_l0000Iooooo`;o0000TOooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`;o
00001_ooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Vooooo`;o0000TOooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool05oooool2o`000:3ooooo002/ooooo`03
o`000?oooooooooo01Oooooo0_l0002Pooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?oo
ool00ol0003oooooooooo`0Dooooo`;o0000Xoooool009?ooooo0_l0000Gooooo`?o00005?ooool2
o`000:?ooooo002Cooooo`;o00005oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00U_ooool2o`0001Cooooo00?o0000ooooooooool0^Oooool009Kooooo0_l0
000Dooooo`03o`000?oooooooooo00kooooo0_l0002Yooooo`00[?ooool00ol0003oooooooooo`0>
ooooo`;o0000ZOooool00:cooooo00?o0000ooooooooool0^Oooool009Oooooo0_l0000Cooooo`04
o`000?ooooooooooooooo`;o0000]_ooool009Oooooo0_l0000Cooooo`Ko00002Oooool2o`000:_o
oooo002/ooooo`03o`000?oooooooooo00;o00002_ooool2o`000:_ooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002<ooooo`;o00007_ooool00ol0003oooooooooo`0;ooooo`;o0000[?ooool0
08cooooo0_l0000Nooooo`03o`000?oooooooooo00_ooooo0_l0002/ooooo`00[?ooool00ol0003o
ooooooooo`07ooooo`;o00003_ooool2o`000:3ooooo002/ooooo`03o`000?oooooooooo00Oooooo
0_l0000>ooooo`;o0000X?ooool00:Oooooo1?l000000ooooooo0000ooooo`2jooooo`00X?ooool3
o`0000Cooooo1?l000000ooooooo0000ooooo`2jooooo`00X?ooool3o`0000Wooooo0ol00004oooo
o`;o0000/oooool009Gooooo0_l0000Eooooo`03o`000?oooooooooo00Cooooo0_l0002cooooo`00
UOooool2o`0001Gooooo00Co0000oooooooooooooooo0_l0002fooooo`00[?ooool01?l0003ooooo
ooooooooool4o`000;Cooooo002/ooooo`03o`000?oooooooooo00?ooooo0_l0002dooooo`00[?oo
ool00ol0003oooooo`000002o`000;Oooooo002/ooooo`03o`000?oooooo000000;o0000]oooool0
0:cooooo00?o0000ooooool000000_l0002gooooo`00VOooool3o`00013ooooo1Ol0000:ooooo`;o
0000Zoooool009Wooooo0ol0000@ooooo`?o00003?ooool2o`000:_ooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002Mooooo`;o00002Oooool2o`0000;ooooo00?o0000ooooooooool02_ooool2
o`000:gooooo002Mooooo`;o00001?ooool2o`0000?ooooo0_l00002ooooo`03o`000?oooooooooo
00[ooooo0_l0002]ooooo`00Xoooool2o`0000?ooooo0_l00002ooooo`03o`000?oooooooooo0;Wo
oooo002Rooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`2iooooo`00Y?oo
ool2o`0000Kooooo00?o0000ooooooooool0^Oooool00:Cooooo0_l00006ooooo`?o0000^Oooool0
0:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo
00?o0000ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:;ooooo00?oEEEE
ofIVI_l00000`oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00:[ooooo00Co410@o`000?l0003o0000^_ooool00:_ooooo00?o0000ooooooooool0^_ooool0
0:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00Ko0000ogMgMol0003o0000oeEEEOo^k^jg
ooooo`00Zoooool01_l0003oEEEEonk^k_ooooooMgMgoeEEEKOooooo002[ooooo`03o`000?o^k^ko
oooo00;ooooo00?o0000ooooooooool0]Oooool00:_ooooo00?o0000onk^k_ooool00_ooool00ol0
003oooooooooo`2eooooo`00Zoooool01_l0003oEEEEonk^k_ooooooMgMgofIVI[Oooooo002Zoooo
o`03oa0@4?l0003oMgMg00;o000000?oIVIVonk^k_ooool0]_ooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.57863 .24089 Mdot
.63809 .63504 Mdot
.50004 .57729 Mdot
.44476 .71368 Mdot
.58803 .49684 Mdot
.4711 .88391 Mdot
.49172 .65652 Mdot
.69421 .68901 Mdot
.65447 .26241 Mdot
.42163 .64198 Mdot
.52481 .29029 Mdot
.65301 .77691 Mdot
.38023 .44968 Mdot
.47999 .21528 Mdot
.65797 .75793 Mdot
.5384 .36209 Mdot
.41786 .74438 Mdot
.38505 .35482 Mdot
.40871 .56613 Mdot
.66315 .66515 Mdot
.38101 .4485 Mdot
.57283 .79248 Mdot
.54475 .83528 Mdot
.39877 .2417 Mdot
.52021 .95983 Mdot
.47553 .16349 Mdot
.56343 .42235 Mdot
.43175 .72927 Mdot
.64193 .72113 Mdot
.63691 .63341 Mdot
.39351 .28767 Mdot
.66559 .28159 Mdot
.71908 .56148 Mdot
.44975 .16027 Mdot
.61099 .38542 Mdot
.67396 .43065 Mdot
.37552 .61671 Mdot
.52625 .71895 Mdot
.62573 .74981 Mdot
.61723 .84093 Mdot
.48637 .99581 Mdot
.55856 .25098 Mdot
.6113 .63131 Mdot
.62571 .3426 Mdot
.53815 .17156 Mdot
.49341 .81548 Mdot
.42663 .3231 Mdot
.59534 .15974 Mdot
.60662 .52362 Mdot
.65976 .66395 Mdot
.57895 .13849 Mdot
.53228 .90265 Mdot
.62486 .49325 Mdot
.62397 .56814 Mdot
.707 .40421 Mdot
.69034 .69717 Mdot
.4128 .72099 Mdot
.46343 .03569 Mdot
.50624 .12745 Mdot
.46719 .82414 Mdot
.55905 .06293 Mdot
.62475 .74938 Mdot
.4332 .35131 Mdot
.71694 .50066 Mdot
.69473 .35442 Mdot
.44142 .73103 Mdot
.49405 .2548 Mdot
.50497 .76648 Mdot
.42986 .1226 Mdot
.404 .32602 Mdot
.50981 .38728 Mdot
.42306 .64895 Mdot
.51115 .72526 Mdot
.62526 .74824 Mdot
.46692 .35801 Mdot
.41803 .70182 Mdot
.5677 .8546 Mdot
.57834 .35196 Mdot
.56102 .16779 Mdot
.64269 .60321 Mdot
.49826 .72642 Mdot
.57762 .2895 Mdot
.72012 .5739 Mdot
.55743 .44925 Mdot
.58777 .52965 Mdot
.57879 .59507 Mdot
.44457 .82798 Mdot
.50048 .26685 Mdot
.51631 .96336 Mdot
.75424 .61229 Mdot
.53707 .396 Mdot
.54775 .70913 Mdot
.50633 .29999 Mdot
.7621 .56924 Mdot
.46527 .21852 Mdot
.56523 .12366 Mdot
.41853 .75392 Mdot
.6077 .30248 Mdot
.50475 .82864 Mdot
.66408 .75131 Mdot
.63976 .39376 Mdot
.52924 .12138 Mdot
.48409 .14281 Mdot
.42187 .22724 Mdot
.42442 .29256 Mdot
.53907 .40526 Mdot
.42836 .12742 Mdot
.42462 .32949 Mdot
.44618 .71921 Mdot
.65657 .26394 Mdot
.68431 .52073 Mdot
.52238 .59807 Mdot
.43443 .77116 Mdot
.71783 .44067 Mdot
.70293 .37555 Mdot
.40127 .81429 Mdot
.37982 .49922 Mdot
.43075 .866 Mdot
.63064 .74832 Mdot
.43451 .11246 Mdot
.42288 .60006 Mdot
.68155 .55831 Mdot
.76367 .48357 Mdot
.64389 .43635 Mdot
.43435 .61233 Mdot
.53146 .85751 Mdot
.63223 .375 Mdot
.61757 .83621 Mdot
.43424 .8417 Mdot
.57957 .72619 Mdot
.58907 .82394 Mdot
.37635 .64034 Mdot
.66611 .64728 Mdot
.43099 .69212 Mdot
.71141 .60704 Mdot
.64407 .78677 Mdot
.65336 .18714 Mdot
.53029 .64211 Mdot
.45006 .77942 Mdot
.41444 .72809 Mdot
.67811 .59994 Mdot
.72343 .52133 Mdot
.64619 .1038 Mdot
.414 .37189 Mdot
.56487 .65564 Mdot
.44754 .00247 Mdot
.52322 .79901 Mdot
.55619 .63616 Mdot
.41071 .18155 Mdot
.4928 .33184 Mdot
.39687 .66243 Mdot
.42437 .89872 Mdot
.59696 .80458 Mdot
.71353 .42293 Mdot
.37868 .65758 Mdot
.40929 .85337 Mdot
.56833 .31213 Mdot
.55836 .86933 Mdot
.45939 .99852 Mdot
.64482 .32563 Mdot
.61831 .58657 Mdot
.58264 .25198 Mdot
.72273 .49879 Mdot
.57349 .18183 Mdot
.5224 .72999 Mdot
.40416 .8357 Mdot
.67813 .56548 Mdot
.53496 .39503 Mdot
.55855 .61966 Mdot
.58686 .49961 Mdot
.45091 .2147 Mdot
.7182 .54873 Mdot
.76408 .53989 Mdot
.40668 .73302 Mdot
.52983 .50192 Mdot
.6389 .72479 Mdot
.45321 .94957 Mdot
.57721 .89663 Mdot
.54892 .61063 Mdot
.46184 .99583 Mdot
.48761 .28722 Mdot
.63293 .225 Mdot
.76103 .4645 Mdot
.67224 .29183 Mdot
.48634 .99945 Mdot
.59197 .69664 Mdot
.40494 .09991 Mdot
.67775 .6035 Mdot
.43834 .66709 Mdot
.50316 .00655 Mdot
.71172 .62438 Mdot
.37587 .7411 Mdot
.64472 .79018 Mdot
.56667 .65344 Mdot
.7164 .7387 Mdot
.51556 .17404 Mdot
.49233 .31443 Mdot
.5028 .34052 Mdot
.51953 .44156 Mdot
.5817 .43574 Mdot
.69335 .78516 Mdot
.61295 .31839 Mdot
.53442 .56519 Mdot
.43336 .83719 Mdot
.43949 .70149 Mdot
.53786 .46715 Mdot
.5443 .33934 Mdot
.42352 .85486 Mdot
.42654 .74212 Mdot
.5752 .18463 Mdot
.55879 .50418 Mdot
.59041 .26783 Mdot
.46305 .81825 Mdot
.45523 .99517 Mdot
.51084 .33681 Mdot
.43609 .14921 Mdot
.63936 .80603 Mdot
.44285 .79283 Mdot
.45871 .04098 Mdot
.55573 .15541 Mdot
.592 .21711 Mdot
.54139 .37832 Mdot
.55941 .33983 Mdot
.64486 .61086 Mdot
.5354 .39408 Mdot
.65393 .76648 Mdot
.5152 .0147 Mdot
.49032 .24711 Mdot
.45574 .35989 Mdot
.69676 .77494 Mdot
.59208 .62262 Mdot
.56732 .44148 Mdot
.43111 .0309 Mdot
.54332 .67449 Mdot
.64858 .43929 Mdot
.41599 .82541 Mdot
.62592 .35281 Mdot
.55251 .05652 Mdot
.52894 .82441 Mdot
.63225 .28551 Mdot
.40281 .3364 Mdot
.67973 .31038 Mdot
.47153 .26105 Mdot
.47225 .95423 Mdot
.54104 .75833 Mdot
.39969 .36805 Mdot
.61579 .76914 Mdot
.39239 .84144 Mdot
.52577 .57686 Mdot
.45051 .70424 Mdot
.44116 .92877 Mdot
.46561 .16864 Mdot
.56441 .58834 Mdot
.60696 .65838 Mdot
.48349 .35693 Mdot
.70269 .65448 Mdot
.54266 .09228 Mdot
.60123 .57883 Mdot
.56714 .4398 Mdot
.61539 .25909 Mdot
.47974 .71047 Mdot
.54586 .75493 Mdot
.52933 .16274 Mdot
.4377 .2763 Mdot
.55369 .77641 Mdot
.67967 .48532 Mdot
.51632 .21164 Mdot
.6821 .49259 Mdot
.61708 .61383 Mdot
.41803 .61422 Mdot
.60211 .46008 Mdot
.42638 .90433 Mdot
.53683 .65941 Mdot
.52685 .25887 Mdot
.59817 .16542 Mdot
.54244 .33191 Mdot
.40244 .70909 Mdot
.61572 .77481 Mdot
.43074 .40467 Mdot
.54782 .60813 Mdot
.3817 .6885 Mdot
.67657 .72462 Mdot
.43521 .24883 Mdot
.43945 .41234 Mdot
.52372 .25985 Mdot
.68314 .46635 Mdot
.54245 .71964 Mdot
.5214 .11503 Mdot
.7598 .45807 Mdot
.42548 .09173 Mdot
.67903 .71182 Mdot
.41471 .12439 Mdot
.51696 .49677 Mdot
.4214 .09942 Mdot
.43726 .02358 Mdot
.67347 .40315 Mdot
.66742 .73784 Mdot
.70496 .18142 Mdot
.59895 .42946 Mdot
.5647 .76385 Mdot
.64071 .40748 Mdot
.67491 .30041 Mdot
.52275 .95871 Mdot
.45318 .23592 Mdot
.58434 .14727 Mdot
.49346 .17492 Mdot
.43624 .4056 Mdot
.44492 .89882 Mdot
.40037 .62171 Mdot
.38619 .64709 Mdot
.41324 .07018 Mdot
.51438 .63219 Mdot
.46741 .10907 Mdot
.50942 .17058 Mdot
.71659 .53936 Mdot
.45788 .70004 Mdot
.57141 .90346 Mdot
.36294 .50825 Mdot
.70803 .27904 Mdot
.43614 .30978 Mdot
.4175 .79195 Mdot
.58899 .31537 Mdot
.59258 .80989 Mdot
.57262 .38136 Mdot
.48612 .30321 Mdot
.51193 .57243 Mdot
.40196 .34867 Mdot
.66374 .76097 Mdot
.4668 .9512 Mdot
.5064 .29935 Mdot
.49437 .90997 Mdot
.42699 .52058 Mdot
.52003 .44651 Mdot
.64237 .62189 Mdot
.4871 .88046 Mdot
.61754 .59199 Mdot
.56674 .30857 Mdot
.57419 .39624 Mdot
.55206 .97886 Mdot
.47463 .16694 Mdot
.64947 .5349 Mdot
.42992 .37446 Mdot
.71894 .48516 Mdot
.55429 .37997 Mdot
.67251 .61902 Mdot
.62876 .65681 Mdot
.54796 .54268 Mdot
.53025 .74302 Mdot
.65233 .18497 Mdot
.6544 .77575 Mdot
.42795 .0817 Mdot
.67892 .46488 Mdot
.59411 .39984 Mdot
.48189 .13771 Mdot
.67976 .55385 Mdot
.57242 .69161 Mdot
.65692 .77037 Mdot
.72786 .32027 Mdot
.64027 .30374 Mdot
.62543 .82312 Mdot
.56106 .9164 Mdot
.44418 .98253 Mdot
.51921 .56846 Mdot
.60161 .56715 Mdot
.64379 .78646 Mdot
.69796 .67301 Mdot
.51251 .60847 Mdot
.47868 .07444 Mdot
.45261 .18537 Mdot
.41614 .78384 Mdot
.59826 .2809 Mdot
.58892 .15545 Mdot
.64683 .4294 Mdot
.37676 .35521 Mdot
.53454 .89426 Mdot
.56155 .80782 Mdot
.40125 .16849 Mdot
.55129 .82671 Mdot
.56283 .90921 Mdot
.56274 .01294 Mdot
.37911 .65669 Mdot
.38825 .4898 Mdot
.46186 .32743 Mdot
.38279 .7826 Mdot
.45149 .83985 Mdot
.51523 .54115 Mdot
.55702 .92319 Mdot
.43748 .10601 Mdot
.48382 .30031 Mdot
.48906 .76622 Mdot
.41131 .32919 Mdot
.57091 .48296 Mdot
.6175 .19177 Mdot
.59161 .20665 Mdot
.56658 .91038 Mdot
.41012 .29048 Mdot
.60027 .92122 Mdot
.44627 .16277 Mdot
.44496 .22599 Mdot
.50478 .22023 Mdot
.45448 .63133 Mdot
.676 .7329 Mdot
.65824 .76641 Mdot
.56143 .41091 Mdot
.54828 .49357 Mdot
.57358 .52298 Mdot
.56007 .52588 Mdot
.36601 .35911 Mdot
.55339 .69628 Mdot
.64866 .33351 Mdot
.52376 .66171 Mdot
.55395 .64348 Mdot
.45104 .68486 Mdot
.57723 .61374 Mdot
.42405 .22541 Mdot
.57129 .54397 Mdot
.5272 .60935 Mdot
.71225 .60398 Mdot
.45156 .43317 Mdot
.61921 .4236 Mdot
.42142 .22918 Mdot
.38907 .46972 Mdot
.48315 .17068 Mdot
.54575 .66843 Mdot
.37125 .69109 Mdot
.75177 .63755 Mdot
.65002 .45822 Mdot
.38408 .12613 Mdot
.63947 .38788 Mdot
.49721 .70836 Mdot
.66188 .28105 Mdot
.63551 .80081 Mdot
.52976 .30351 Mdot
.63112 .64581 Mdot
.54078 .99052 Mdot
.54801 .52119 Mdot
.44485 .35109 Mdot
.47587 .19462 Mdot
.61635 .25963 Mdot
.56274 .30684 Mdot
.73717 .68242 Mdot
.51973 .36786 Mdot
.6142 .4073 Mdot
.56025 .25251 Mdot
.48114 .25928 Mdot
.52233 .59303 Mdot
.5166 .7146 Mdot
.69427 .68799 Mdot
.48334 .71045 Mdot
.58322 .83194 Mdot
.64947 .57463 Mdot
.51323 .13839 Mdot
.68303 .52639 Mdot
.47456 .07529 Mdot
.39678 .42786 Mdot
.76645 .50057 Mdot
.47273 .7743 Mdot
.658 .7726 Mdot
.38926 .82681 Mdot
.43477 .28779 Mdot
.42615 .08663 Mdot
.49985 .18622 Mdot
.46952 .84889 Mdot
.67363 .61479 Mdot
.61259 .3134 Mdot
.40711 .48664 Mdot
.52458 .75517 Mdot
.45479 .15252 Mdot
.5787 .08245 Mdot
.59256 .69032 Mdot
.4633 .36195 Mdot
.62122 .57138 Mdot
.58701 .38043 Mdot
.52011 .56442 Mdot
.44361 .28495 Mdot
.6247 .48301 Mdot
.58088 .72526 Mdot
.52837 .45918 Mdot
.42725 .24636 Mdot
.69649 .36025 Mdot
.58833 .48909 Mdot
.4955 .118 Mdot
.46119 .79543 Mdot
.4497 .77464 Mdot
.47275 .69434 Mdot
.463 .68704 Mdot
.64031 .62829 Mdot
.44673 .05499 Mdot
.65287 .34698 Mdot
.4847 .79525 Mdot
.65641 .67907 Mdot
.60729 .85428 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool009[ooooo0_l00008ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0^Oooool009[ooooo0_l00008ooooo`03o`000?oooooooooo00Gooooo
0ol0002iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`;o0000Y_ooool00:;ooooo00?oEEEEofIV
I_l000001oooool00ol0003oooooooooo`02ooooo`;o00003Oooool2o`000:Kooooo002/ooooo`03
o`000?oooooooooo00;ooooo0_l0002eooooo`00[?ooool00ol0003oooooooooo`2iooooo`00Uooo
ool2o`0001?ooooo0ol0002iooooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool0^Oooool0
09Gooooo0_l0000Eooooo`03o`000?oooooooooo0;Wooooo002Eooooo`;o00005Oooool00ol0003o
ooooooooo`2iooooo`00Woooool2o`0000_ooooo00?o0000ooooooooool0^Oooool009kooooo0ol0
000;ooooo`03o`000?oooooooooo0;Wooooo002Nooooo`;o00003?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
[?ooool3o`000;Wooooo002Jooooo`;o00004?ooool00ol0003oooooooooo`2iooooo`00V_ooool2
o`00013ooooo00?o0000ooooooooool03_ooool2o`000:Wooooo002/ooooo`03o`000?oooooooooo
00kooooo0_l0002Yooooo`00[?ooool00ol0003oooooooooo`0@ooooo`;o0000Yoooool00:cooooo
00?o0000ooooooooool04?ooool2o`000:Oooooo002?ooooo`;o00006oooool00ol0003ooooooooo
o`2iooooo`00Soooool2o`0001_ooooo00?o0000ooooooooool0^Oooool00:?ooooo1?l00005oooo
o`?o0000^Oooool00:?ooooo1?l00005ooooo`03o`000?oooooooooo0;Wooooo002Dooooo`;o0000
5_ooool00ol0003oooooooooo`0Gooooo`;o0000X?ooool009Cooooo0_l0000Fooooo`03o`000?oo
oooooooo01Oooooo0_l0002Pooooo`00Toooool2o`0001Oooooo00?o0000ooooooooool0^Oooool0
09?ooooo0_l0000Gooooo`03o`000?oooooooooo00_ooooo0_l0002/ooooo`00Toooool2o`0001Oo
oooo00?o0000ooooooooool02oooool2o`000:cooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002<ooooo`;o00001?ooool2o`0001Sooooo0ol0002iooooo`00S?ooool2o`0000Cooooo0_l0000H
ooooo`03o`000?oooooooooo02gooooo0_l0002:ooooo`00Uoooool2o`0001?ooooo00?o0000oooo
ooooool0;Oooool2o`0008[ooooo002Gooooo`;o00002?ooool2o`0000Wooooo00?o0000oooooooo
ool0^Oooool009Kooooo0_l00009ooooo`;o00002Oooool00ol0003oooooooooo`2iooooo`00U_oo
ool2o`0001Cooooo00?o0000ooooooooool01?ooool2o`000;?ooooo0029ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00?ooooo0ol00006ooooo`;o0000/oooool008Wooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`03ob4Q8Ol0003o000000Gooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8b
ooooo`02ooooo`?o00002?ooool2o`000;7ooooo0021ooooo`Ko00000_ooool01_l@413ooooooooo
oooooooo410@ooooo`;o00000oooool2o`0000Gooooo00?oZJVYoeEEEOooool02?ooool00ol0003o
ooooooooo`03ooooo`?o00001_ooool2o`0000[ooooo0_l0002Uooooo`00QOooool2o`0000;ooooo
00Ko0000ooooooooooooooooo`000?ooool2o`0000?ooooo0_l00006ooooo`03ob4Q8Ooooooooooo
00Kooooo00?oMgMgoc8b<_ooool01?ooool01?l0003oooooo`000?l0000Aooooo`;o0000YOooool0
08Gooooo0_l00002ooooo`05o`000?ooooooooooooooool000001_ooool2o`0000Kooooo00?oEEEE
olc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00Co0000ooooool0003o0000
^?ooool008Wooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`2iooooo`00ROooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`04o`000?oooooooooooooo
o`;o00001?ooool00ol0003oooooooooo`2iooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo1Ol00004ooooo`Ko00001?ooool01?l0003oooooooooooooool2o`0001Cooooo0_l0002P
ooooo`00Y_ooool2o`0000Cooooo00Co0000oooooooooooooooo0_l0000Dooooo`;o0000X?ooool0
0:Kooooo0_l00004ooooo`03o`000?oooooooooo0;Wooooo002Fooooo`;o00005?ooool00ol0003o
ooooooooo`0Hooooo`;o0000Woooool009Kooooo0_l00005ooooo`;o00003Oooool3o`0001Sooooo
0_l0002Oooooo`00WOooool2o`0000gooooo00?o0000ooooooooool03oooool2o`0000Wooooo0_l0
002Mooooo`00[?ooool00ol0003oooooooooo`0?ooooo`;o00002Oooool2o`0009gooooo002Koooo
o`;o00003oooool00ol0003oooooooooo`0Looooo`;o0000Voooool009[ooooo0ol00006ooooo`;o
00001oooool00ol0003oooooooooo`06ooooo`;o00005?ooool2o`0009_ooooo002Jooooo`;o0000
1oooool2o`0000Oooooo00?o0000ooooooooool01_ooool2o`0000Wooooo0_l0000:ooooo`;o0000
V_ooool008_ooooo0_l0000Cooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`03o`00
0?oooooooooo00;o00003oooool2o`0000[ooooo0_l0002Jooooo`00Roooool2o`0001?ooooo0_l0
0004ooooo`;o00001?ooool00ol0003oooooooooo`04o`0000Gooooo0_l0002^ooooo`00ZOooool2
o`000004ooooool0003o0000o`0000;ooooo0_l00005ooooo`;o0000[_ooool00:Wooooo0_l00000
0ooooooo0000ooooo`2jooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool05Oooool2o`00
02Wooooo0_l0001gooooo`00S_ooool2o`0000cooooo0_l0000>ooooo`;o00005_ooool2o`0001So
oooo0_l0000?ooooo`;o0000Moooool009cooooo0_l0000>ooooo`;o00005_ooool2o`0001Sooooo
0_l00028ooooo`00[?ooool00ol0003oooooooooo`0Sooooo`;o00002_ooool2o`0008Sooooo002T
ooooo`;o00001_ooool00ol0003oooooooooo`0Sooooo`;o0000U?ooool00:Cooooo0_l00006oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool06oooool2o`0009cooooo002/ooooo`03o`000?oooooo
oooo01_ooooo0_l0002Looooo`00[?ooool00ol0003oooooooooo`02ooooo`;o0000]Oooool009_o
oooo0_l00008ooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`;o0000]Oooool009_ooooo
0_l00003ooooo`;o00000oooool2o`0000Gooooo00?o0000ooooooooool06oooool2o`0009cooooo
002Pooooo`;o00002_ooool3o`0001_ooooo0_l0002Looooo`00T_ooool2o`0001Sooooo0ol0000X
ooooo`;o0000Soooool009;ooooo0_l00005ooooo`;o00004Oooool00ol0003oooooooooo`0Xoooo
o`;o0000Soooool009;ooooo0_l00005ooooo`;o00004Oooool00ol0003oooooooooo`2iooooo`00
T_ooool2o`0001Sooooo00?o0000ooooooooool0^Oooool009cooooo0_l0000>ooooo`03o`000?oo
oooooooo0;Wooooo002Looooo`;o00003_ooool00ol0003oooooooooo`0Gooooo`;o0000X?ooool0
08[ooooo0_l00005ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01Oooooo0_l0002Pooooo`00R_ooool2
o`0000Gooooo00?oMgMgoiRHV?ooool00_l00005ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`Ko00000_ooool00ol@413oooooooooo`04o`00
00kooooo00Co0000ooooool0003o00000_ooool00ol0003oooooooooo`2iooooo`00TOooool01?l0
003oooooooooooooool3o`0000gooooo00?oMgMgoc8b<_ooool00_l00002ooooo`?o00004?ooool2
o`0000Kooooo0_l0002Oooooo`00TOooool01Ol0003ooooooooooooooooo000000cooooo00Go0000
ob4Q8Ol0003o<S8bolc<c003ooooo`?o00004_ooool2o`0000Kooooo0_l0002Oooooo`00TOooool0
1Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01Oooool3o`0000Oooooo0_l0
000Looooo`;o0000U?ooool0097ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`;o000000?o
ooooo`000?l000001Oooool00ol0003oooooooooo`04ooooo`?o00007?ooool2o`0009Cooooo002A
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool5o`0000Gooooo00?o0000ooooooooool01?oo
ool2o`0001gooooo0_l0000;ooooo`;o0000Qoooool00:cooooo0_l0000Kooooo`;o00005?ooool2
o`0008Oooooo002/ooooo`;o00006oooool2o`0009gooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002Gooooo`;o00004oooool3o`000;Wooooo002Gooooo`;o00004oooool00ol0003ooooooooo
o`11ooooo`;o0000M_ooool00:cooooo00?o0000ooooooooool07Oooool2o`0001?ooooo0ol0000<
ooooo`;o0000M_ooool009Wooooo0_l0000Aooooo`03o`000?oooooooooo01gooooo0_l00009oooo
o`;o00002?ooool3o`0008Cooooo0028ooooo`;o00003?ooool2o`000003ooooool0003o000000co
oooo0_l00003ooooo`03o`000?oooooooooo02Sooooo0_l0002?ooooo`00R?ooool2o`0000Cooooo
0_l00006ooooo`;o00003oooool2o`0000?ooooo00?o0000ooooooooool01Oooool2o`0000oooooo
0_l0000Mooooo`;o0000P_ooool008kooooo0_l00003ooooo`;o00005oooool00ol0003ooooooooo
o`05ooooo`;o00003oooool2o`0001gooooo0_l00022ooooo`00Toooool2o`0001Oooooo00?o0000
ooooooooool0^Oooool00:Kooooo0_l00004ooooo`Co0000=Oooool2o`00087ooooo002Vooooo`?o
00000oooool01?l0003oooooo`000?l00005ooooo`;o00006?ooool2o`0000Wooooo0_l00009oooo
o`;o0000POooool00:Oooooo0_l00003ooooo`03o`000?oooooooooo00Kooooo0_l00009ooooo`;o
00003Oooool2o`0000Wooooo0_l0002<ooooo`00U_ooool2o`0001Cooooo00?o0000ooooooooool0
4Oooool4o`0002?ooooo0_l0001oooooo`00U_ooool2o`0001Cooooo00?o0000ooooooooool04ooo
ool2o`0000gooooo0_l0000Dooooo`;o0000Ooooool00:Wooooo0_l000000ooooooo0000ooooo`0D
ooooo`;o00001Oooool2o`0000Kooooo0_l0002Eooooo`00ZOooool2o`000003ooooool0003ooooo
01_ooooo0_l00006ooooo`;o0000UOooool00:cooooo00?o0000ooooooooool08_ooool2o`0002Co
oooo0_l0001_ooooo`00Toooool2o`0001Oooooo0ol0000/ooooo`;o00006_ooool2o`0006oooooo
002<ooooo`;o00001Oooool2o`0000[ooooo0_l0000;ooooo`03o`000?oooooooooo02cooooo0_l0
002;ooooo`00S?ooool4o`0000?ooooo0_l0000:ooooo`;o00002?ooool2o`000003ooooool0003o
oooo0;[ooooo002>ooooo`;o00000oooool2o`0001Cooooo0_l000000ooooooo0000ooooo`0<oooo
o`;o00008Oooool2o`0008Wooooo002;ooooo`;o00007oooool00ol0003oooooooooo`02o`0000Wo
oooo0_l0000Qooooo`;o0000ROooool008_ooooo0_l0000Oooooo`;o000000?oooooo`000?l00000
2Oooool2o`0000?ooooo0_l0002Wooooo`00[?ooool2o`0000cooooo0_l00003ooooo`;o00005?oo
ool2o`00097ooooo002/ooooo`03o`000?oooooooooo02Kooooo0_l00007ooooo`;o0000R?ooool0
08_ooooo0_l0000Oooooo`03o`000?oooooooooo02oooooo0_l00028ooooo`00Roooool2o`0000Wo
oooo0_l000000ooooooo0000o`00000Aooooo`?o00005_ooool2o`0000kooooo0_l0002Aooooo`00
Poooool2o`000003ooooool0003o000000kooooo0_l000000ooooooo0000o`00000Aooooo`03o`00
0?oooooooooo01Kooooo0_l0000>ooooo`;o00005Oooool2o`0007[ooooo001oooooo`;o00000_oo
ool2o`000003ooooool0003o000001Wooooo0_l00003ooooo`;o00001?ooool00ol0003ooooooooo
o`0mooooo`;o0000N_ooool007oooooo0_l0000Looooo`Ko00000oooool2o`0000Cooooo00?o0000
ooooooooool02Oooool2o`0003;ooooo0_l0001jooooo`00WOooool4o`0000_ooooo00?o0000oooo
ooooool02Oooool2o`0003;ooooo0_l0001jooooo`00ROooool01Oo^k^ko0000o`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool00oooool2o`000;Cooooo0029ooooo`05ogMgMol0003o0000oiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool00oooool2o`000;Cooooo0021ooooo`Ko00000_ooool01_l@413ooooooooooooo
oooo410@ooooo`;o00002Oooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0^Oooool008Wooooo00Ko0000ooooooooooooooooo`000?ooool2o`0000?o
oooo0_l00005ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0002So
oooo0_l0000Fooooo`;o0000Moooool008Wooooo00Go0000ooooooooooooooooo`000006ooooo`;o
00001_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0
003oooooooooo`0:ooooo`;o00000_ooool2o`0001Sooooo0_l0000Fooooo`;o0000Moooool008Wo
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0:ooooo`;o00000_ooool2o`0000Gooooo0_l00002oooo
o`;o0000W_ooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Gooooo0_l00002
ooooo`;o00001_ooool2o`0009Kooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo00;o00007ooo
ool2o`0000Sooooo0_l0002<ooooo`00[?ooool00ol0003oooooooooo`02o`0002Wooooo0_l0002<
ooooo`00[?ooool00ol0003oooooooooo`08ooooo`;o00008Oooool2o`0008cooooo002/ooooo`03
o`000?oooooooooo00Sooooo0ol0000:ooooo`;o00005?ooool2o`0008cooooo002/ooooo`?o0000
2Oooool2o`0000[ooooo0_l00005ooooo`;o0000Voooool00:cooooo00?o0000ooooooooool07?oo
ool2o`0001Sooooo0_l00009ooooo`;o0000M_ooool009Gooooo1?l0000Cooooo`03o`000?oooooo
oooo00Wooooo0_l0000Gooooo`;o00001oooool2o`0000Wooooo0_l00009ooooo`;o0000M_ooool0
09Gooooo1?l0000Cooooo`03o`000?oooooooooo00Wooooo0_l0000Gooooo`;o00001oooool2o`00
08cooooo002Hooooo`;o00004_ooool00ol0003oooooooooo`0Aooooo`;o0000Y_ooool009Sooooo
0_l0000Booooo`03o`000?oooooooooo017ooooo0_l0002Vooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`0Booooo`;o0000YOooool00:cooooo0ol0000Boooo
o`;o00004?ooool2o`0001gooooo0_l0001dooooo`00ROooool2o`00027ooooo00?o0000oooooooo
ool09?ooool2o`0001gooooo0_l0001dooooo`00ROooool2o`00027ooooo00?o0000ooooooooool0
7Oooool2o`0000kooooo0_l00007ooooo`;o0000POooool009cooooo0_l0000>ooooo`03o`000?oo
oooooooo01gooooo0_l0000>ooooo`;o00001oooool2o`00087ooooo002Looooo`;o00003_ooool0
0ol0003oooooooooo`0Hooooo`;o00004_ooool2o`0008_ooooo002/ooooo`03o`000?oooooooooo
01?ooooo0_l00003ooooo`;o00004_ooool4o`0001Cooooo0_l0001cooooo`00[?ooool00ol0003o
ooooooooo`03ooooo`;o00003_ooool2o`0001Wooooo0_l0000Dooooo`;o0000Loooool00:cooooo
00?o0000ooooooooool00oooool2o`0000kooooo0_l0002Tooooo`00Q?ooool2o`0002Kooooo00?o
0000ooooooooool00oooool2o`0000_ooooo0_l0002Wooooo`00Q?ooool2o`0002Kooooo0ol0000@
ooooo`;o0000Yoooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0;_ooool2o`0002;ooooo0_l0001Uooooo`002Oooool4o`000003oa0@4?oooooooooo01Kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05
odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Kooooo00?o0000oooooooo
ool01_ooool2o`00013ooooo00Kok^k^oc8b<_l0003o<S8bonk^k_ooool2o`0000;ooooo0_lQ8B44
ooooo`Go000000Goooooo`000?l0003oooooodA4A002o`000003oc8b<_oMgMgooooo00kooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q00?oooooo`000?l000000_ooool01Om4A4Co0000
o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0
003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd06?ooool4o`000003oa0@4?oooooo
oooo01;ooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03
ogMgMolb<S;ooooo01Gooooo00?o0000ooooooooool01_ooool2o`00013ooooo00KoMgMgoiRHV?oo
ooooV9RHogMgMoooool2o`0000;ooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01ooo
ool01?mgMgOo<S8booooooooool2o`0000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q0_ooool2o`0000Cooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool06Oooool00ol0
003oooooooooo`0Dooooo`001_l00005ooooo`03o`000?oooooooooo013ooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo
00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`05
ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Wooooo0_l0000=ooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?o0000
2_ooool01Ol@413ooooooooooooooooo410@00Wooooo0_l00005ooooo`03o`000?oooooooooo00go
oooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05
o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo
00kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000
ooooooooooooooooo`00000:ooooo`;o000000CooooooiRHV?lQ8B7ok^k^1oooool00omgMgOo<S8b
ooooo`0Eooooo`03o`000?oooooooooo00Wooooo0_l0000=ooooo`05o`000?ooooooooooooooool0
00003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00;ooooo0_l0000:ooooo`05
o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0>ooooo`05o`000?oooooooooo
ooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Wooooo00?o0000
ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo
000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go
0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003o
oooooooooooooooo000000[ooooo0_l00002ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c00Fooooo`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`00
0?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Jooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go410@
oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool04Ooo
ool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04Oooool01Ol@413ooooo
oooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Hooooo`?o
00006?ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0A
ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`00
0?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`0Aooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Dooooo`002Oooool00omEEEGoIVIVo`00000Jooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?oo
ool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`01?ooool4o`0001Oooooo00?o0000ooooooooool05?ooool2o`0000;ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP09ooooo`;o000000GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00004?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool5o`0000Cooooo1?l0000Iooooo`03oeEEEOmVIVKo000001Kooooo002/ooooo`03o`000?oo
oooooooo01Cooooo0_l0000@ooooo`;o00004?ooool2o`0000_ooooo0_l0000=ooooo`;o0000Hooo
ool008gooooo0_l0000Mooooo`03o`000?oooooooooo01[ooooo0_l0000Looooo`;o00002oooool2
o`0000gooooo0_l0001Sooooo`00Qoooool2o`0000Cooooo0_l0000Mooooo`03o`000?oooooooooo
01[ooooo0_l0002Booooo`;o00000_ooool2o`0000Gooooo0027ooooo`;o00008oooool00ol0003o
ooooooooo`0=ooooo`;o00005oooool2o`00017ooooo0_l0001cooooo`06onk^k_lQ8B7oQhN7okZj
^_l0003ogMgM1Oooool00:cooooo00?o0000ooooooooool00_ooool2o`0000Wooooo0_l0000;oooo
o`;o00002_ooool2o`00017ooooo0_l0001dooooo`04omgMgOl0003o410@olc<c0Kooooo0007oooo
oooo0000C?l0000<ooooo`04onk^k_lQ8B7o410@onk^kPKooooo0007ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`?o00001Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo0_l00006ooooo`04o`000?oooooo0000
o`0000Cooooo00?o0000ooooooooool00_l00003ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool5o`0000Oooooo00?o0000ooooooooool00_ooool2o`000003ooooool0003o
oooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00[ooooo00Co8B4QogMgMomgMgOo<S8b1_ooool000Oooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`06ooooo`;o00002?ooool2o`0001Gooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02Oooool2
o`0000;ooooo0_l00005ooooo`00O_ooool2o`0002cooooo00?o0000ooooooooool0^Oooool007ko
oooo0_l0000/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002Cooooo`;o00005oooool00ol0003oooooooooo`0<
ooooo`;o0000:oooool2o`0000_ooooo0_l0001aooooo`00Toooool2o`0001Oooooo0ol0000<oooo
o`;o00001oooool2o`0000Wooooo0_l0000Gooooo`;o00002oooool2o`00077ooooo002/ooooo`03
o`000?oooooooooo013ooooo0_l00003ooooo`;o00002Oooool2o`0001Oooooo0_l0001nooooo`00
[?ooool00ol0003oooooooooo`0@ooooo`;o00002?ooool2o`0001gooooo0_l0001nooooo`00[?oo
ool00ol0003oooooooooo`0Jooooo`;o0000WOooool00:cooooo00?o0000ooooooooool0;_ooool2
o`0008Wooooo002/ooooo`03o`000?oooooooooo02kooooo0_l0000Dooooo`;o00003_ooool2o`00
06?ooooo002/ooooo`03o`000?oooooooooo00;ooooo0_l00008ooooo`;o0000=_ooool2o`0000ko
oooo0_l0001Sooooo`00[?ooool00ol0003oooooooooo`02ooooo`;o00002?ooool2o`0000Kooooo
0_l0002Sooooo`00[?ooool00ol0003oooooooooo`0Dooooo`;o0000;oooool2o`0007;ooooo002/
ooooo`?o0000AOooool2o`0007;ooooo002/ooooo`03o`000?oooooooooo03Sooooo0_l0001ooooo
o`00[?ooool00ol0003oooooooooo`0hooooo`;o0000Ooooool00:cooooo00?o0000ooooooooool0
>?ooool2o`0000_ooooo0_l0001booooo`00[?ooool00ol0003oooooooooo`03ooooo`;o0000@?oo
ool2o`0007;ooooo002=ooooo`;o00007Oooool00ol0003oooooooooo`03ooooo`;o00000oooool2
o`0001Cooooo0_l00005ooooo`;o00004?ooool2o`00083ooooo002=ooooo`;o00007Oooool00ol0
003oooooooooo`03ooooo`;o00000oooool2o`0001Cooooo0_l00005ooooo`;o00004?ooool2o`00
01[ooooo0_l0001Tooooo`00[?ooool01?l0003oooooooooooooool4o`00023ooooo0_l0000Noooo
o`;o00003?ooool2o`0006Cooooo002/ooooo`?o000000?oooooo`000?l000000_ooool2o`0001ko
oooo0_l00007ooooo`;o00005Oooool2o`0007;ooooo002/ooooo`;o00001_ooool2o`0001Oooooo
0_l0000>ooooo`;o0000ROooool00:cooooo0_l0000Oooooo`;o0000VOooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool04_ooool2o`00013ooooo0_l0002Coooo
o`00[?ooool00ol0003oooooooooo`0Booooo`;o00003oooool3o`0009?ooooo002/ooooo`03o`00
0?oooooooooo00Cooooo0_l0000Aooooo`;o00002_ooool2o`0009Cooooo002/ooooo`03o`000?oo
oooooooo00Cooooo0_l0000Aooooo`;o0000X?ooool009;ooooo0_l0000Hooooo`?o00001?ooool2
o`00037ooooo0_l00020ooooo`00T_ooool2o`0001Sooooo00?o0000ooooooooool0;?ooool2o`00
00Wooooo0_l0000:ooooo`;o0000M?ooool00:cooooo00?o0000ooooooooool0;?ooool2o`0000Wo
oooo0_l00009ooooo`?o0000M?ooool00:cooooo00Co0000oooooooooooooooo0_l00003ooooo`;o
00001?ooool2o`0003Cooooo0_l0001eooooo`00U_ooool2o`0001Cooooo00Co0000oooooooooooo
oooo0_l00003ooooo`;o00001?ooool3o`0001gooooo0_l0000Rooooo`;o0000Ioooool0097ooooo
0_l00003ooooo`;o00005?ooool00ol0003oooooooooo`0=ooooo`;o00001oooool2o`0000_ooooo
0_l00007ooooo`;o00002?ooool2o`0001Sooooo0_l0001Wooooo`00P_ooool2o`0000Gooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`;o00000_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000
o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool04?ooool2o`0000Cooooo0_l0000;ooooo`;o
00004Oooool2o`00087ooooo0022ooooo`;o00001Oooool01OmgMgOoV9RHo`000?l0003oMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo013ooooo0_l00009ooooo`;o00003oooool2o`0000Sooooo0_l00021oooo
o`00ROooool01Ol@413oooooo`000?l0003o410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0
003oooooooooo`03ooooo`?o00006oooool2o`0000oooooo0_l0000Dooooo`;o0000MOooool008Wo
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`0[ooooo`;o00005Oooool2o`0007Gooooo0029ooooo`05
o`000?ooooooooooooooool000003_ooool00omgMgOo0000o`000003ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Qooooo`;o00002?ooool2o`0008cooooo0029oooo
o`05oa0@4?ooooooooooooooool@41003oooool2o`0000?ooooo00?o0000ooooooooool01oooool0
1?l0003oooooooooooooool2o`0001kooooo0_l00007ooooo`;o0000SOooool008Wooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooo
ooooo`07ooooo`04o`000?ooooooooooooooo`;o00003?ooool2o`0001Wooooo0_l0000Tooooo`;o
0000Ioooool008?ooooo0_l00004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So
410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo00oooooo0_l0000Ioooo
o`;o00009?ooool2o`0006Oooooo0023ooooo`;o00003Oooool2o`0001Sooooo00?o0000oooooooo
ool01oooool2o`0000Gooooo0_l0002Yooooo`00T_ooool2o`0001Sooooo00?o0000ooooooooool0
1oooool2o`0000Gooooo0_l0000Hooooo`;o0000Soooool008Kooooo0_l0000:ooooo`;o00006?oo
ool00ol0003oooooooooo`0Xooooo`;o00002Oooool2o`0008Cooooo0026ooooo`;o00002_ooool2
o`0001Sooooo0ol0000cooooo`;o0000Q?ooool00:cooooo00?o0000ooooooooool04_ooool3o`00
02[ooooo0_l0001hooooo`00Q?ooool2o`0002?ooooo0_l000000ooooooo0000ooooo`0Cooooo`?o
00002oooool2o`0000Gooooo0_l0000Fooooo`;o0000N?ooool008Cooooo0_l0000Sooooo`;o0000
00?oooooo`000?ooool01Oooool2o`0000?ooooo0_l0000Eooooo`;o00001Oooool2o`00093ooooo
002:ooooo`;o00008?ooool00ol0003oooooooooo`04ooooo`;o00000oooool2o`0002Kooooo0_l0
0026ooooo`00R_ooool2o`0000_ooooo0_l0000Cooooo`03o`000?oooooooooo037ooooo0ol00025
ooooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool03?ooool2o`0002Cooooo0_l00025oooo
o`00[?ooool00ol0003oooooooooo`0<ooooo`;o0000<?ooool2o`0007Wooooo002/ooooo`?o0000
2oooool2o`00037ooooo0_l0001iooooo`00[?ooool00ol0003oooooooooo`0;ooooo`;o00008ooo
ool2o`0008Oooooo002/ooooo`03o`000?oooooooooo033ooooo0_l0000Iooooo`;o0000K?ooool0
09_ooooo0_l0000?ooooo`03o`000?oooooooooo04_ooooo0_l0001/ooooo`00QOooool2o`0001Co
oooo0_l00002ooooo`;o00002oooool00ol0003oooooooooo`0mooooo`;o0000N_ooool0087ooooo
0_l00002ooooo`;o00003_ooool2o`0000Sooooo0_l0000;ooooo`03o`000?oooooooooo01Cooooo
0_l00005ooooo`;o00008?ooool2o`0007[ooooo0021ooooo`;o00004_ooool2o`0000cooooo0_l0
0007ooooo`03o`000?oooooooooo01Cooooo0_l00005ooooo`;o0000W?ooool00:?ooooo0_l00007
ooooo`03o`000?oooooooooo00kooooo0_l0000;ooooo`;o00007_ooool2o`0007cooooo002Noooo
o`;o00003?ooool3o`0000kooooo0_l0000;ooooo`;o00007_ooool2o`0007cooooo002Aooooo`;o
00001Oooool2o`000004ooooool0003o0000ooooo`;o00003?ooool00ol0003oooooooooo`2ioooo
o`00TOooool2o`0000Gooooo0_l000000ooooooo0000o`00000?ooooo`03o`000?oooooooooo0;Wo
oooo002;ooooo`;o00006?ooool3o`0000?ooooo0_l0000>ooooo`;o0000Zoooool008_ooooo0_l0
000Hooooo`?o00000oooool2o`0000kooooo0_l0000Zooooo`;o0000Ooooool009Wooooo0_l0000A
ooooo`03o`000?oooooooooo00;ooooo0_l0000dooooo`;o0000Ooooool009Wooooo0ol0000@oooo
o`03o`000?oooooooooo00;ooooo0_l000000ooooooo0000o`00002booooo`00Soooool2o`0000Wo
oooo0_l0000@ooooo`03o`000?oooooooooo00Gooooo0_l00004ooooo`;o00007_ooool2o`0008co
oooo002?ooooo`;o00006oooool5o`0000Wooooo0_l0000:ooooo`;o00004Oooool3o`0000[ooooo
0_l00020ooooo`00Soooool2o`0001[ooooo0_l00002ooooo`;o00005Oooool2o`00017ooooo0_l0
000;ooooo`;o0000P?ooool008oooooo0_l00004ooooo`;o000000?oooooo`000?l000004Oooool2
o`0000Kooooo0_l0000Aooooo`;o0000X?ooool008gooooo0_l00006ooooo`;o000000?oooooo`00
0?l000004_ooool00ol0003oooooooooo`04ooooo`;o0000<Oooool2o`00083ooooo002=ooooo`;o
00007Oooool00ol0003oooooooooo`0gooooo`;o0000P?ooool00:cooooo00?o0000ooooooooool0
=?ooool2o`0000kooooo0_l0001cooooo`00Poooool2o`0000cooooo00Gok^k^oc8b<_l0003o0000
onk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooooooo
ool01oooool2o`0002_ooooo0_l0000>ooooo`;o0000Loooool008?ooooo0_l0000;ooooo`;o0000
00CoV9RHo`000?l0003oMgMg1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`07ooooo`;o0000/?ooool0093ooooo0_l00003ooooo`03oa0@4?oooooooooo00kooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Vooooo`Co0000Soooool0097ooooo00Go
0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Vooooo`Co0000
2Oooool2o`0008Cooooo002Aooooo`;o00000_ooool00ol0003oooooooooo`0:ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`05ooooo`;o00001Oooool2o`0002Gooooo
0_l00024ooooo`00TOooool2o`0000;ooooo00?o410@ooooooooool02_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Gooooo0_l00003ooooo`Co00008oooool2o`0008Kooooo002A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00[ooooo0_l0000Uooooo`Co0000Q?ooool0097ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`Co00001_ooool00ol0003oooooooooo`0Booooo`;o00007oooool2o`0008Cooooo002X
ooooo`;o00000_ooool3o`0001;ooooo0_l0000Kooooo`Co0000Q_ooool00:Sooooo0_l00002oooo
o`?o00008oooool2o`0000[ooooo1?l00026ooooo`00U_ooool2o`0001Cooooo00?o0000oooooooo
ool08oooool2o`0000_ooooo0ol00026ooooo`00U_ooool2o`0000?ooooo0_l00006ooooo`;o0000
1oooool3o`0000kooooo0_l0000Cooooo`;o00002_ooool4o`0000_ooooo0_l0001iooooo`00Vooo
ool2o`0000Kooooo0_l00007ooooo`03o`000?oooooooooo00kooooo0_l0000Cooooo`;o00002_oo
ool3o`0000cooooo0_l0001iooooo`00QOooool2o`0001Cooooo0_l0000?ooooo`03o`000?oooooo
oooo0;Wooooo0025ooooo`;o00002Oooool2o`0001[ooooo00?o0000ooooooooool0??ooool2o`00
07_ooooo002@ooooo`;o00006_ooool00ol0003oooooooooo`0/ooooo`;o00003_ooool2o`0007_o
oooo002@ooooo`;o00006_ooool00ol0003oooooooooo`0/ooooo`;o0000Roooool0093ooooo0_l0
0007ooooo`;o00003?ooool2o`0000?ooooo00?o0000ooooooooool05Oooool2o`0001Gooooo0_l0
002;ooooo`00VOooool2o`0000Cooooo0_l00006ooooo`;o00000oooool00ol0003oooooooooo`0E
ooooo`;o0000X_ooool009oooooo0_l0000;ooooo`?o00001?ooool2o`0002?ooooo0_l0002>oooo
o`00[?ooool00ol0003oooooooooo`04ooooo`;o00008oooool2o`0008kooooo002/ooooo`03o`00
0?oooooooooo01gooooo0_l0000<ooooo`;o0000S?ooool00:cooooo00?o0000ooooooooool04Ooo
ool2o`0000Sooooo1?l0000<ooooo`;o0000S?ooool00:cooooo00?o0000ooooooooool04Oooool2
o`0000Sooooo0_l0002Looooo`00Roooool2o`0001cooooo0_l000000ooooooo0000ooooo`2joooo
o`00Roooool2o`0001;ooooo0_l00008ooooo`;o000000?oooooo`000?ooool0^_ooool009oooooo
0_l0000;ooooo`03o`000?oooooooooo0;Wooooo002@ooooo`;o00003oooool2o`0000Wooooo0ol0
0006ooooo`;o00004_ooool2o`0000[ooooo0_l0002Aooooo`00Qoooool2o`0000Oooooo0_l00007
ooooo`;o00001_ooool2o`0000Wooooo0ol00006ooooo`;o00001Oooool2o`0000_ooooo0_l0000:
ooooo`;o0000TOooool008Oooooo0_l0000@ooooo`;o00004Oooool3o`0000gooooo0_l0002Zoooo
o`00[?ooool00ol0003oooooooooo`0Hooooo`;o0000Woooool008cooooo0_l00008ooooo`;o0000
5?ooool00ol0003oooooooooo`0;ooooo`;o00002oooool2o`0000Wooooo0_l0002Dooooo`00S?oo
ool2o`0000Sooooo0_l00004ooooo`;o00003_ooool00ol0003oooooooooo`0;ooooo`;o00005_oo
ool2o`0009Cooooo0028ooooo`;o00003?ooool2o`0000Cooooo0_l0000>ooooo`03o`000?oooooo
oooo02?ooooo0_l0002Dooooo`00R?ooool2o`0000cooooo0_l0000Dooooo`03o`000?oooooooooo
02?ooooo0_l0002Dooooo`00X_ooool2o`0000Sooooo00?o0000ooooooooool0^Oooool00:;ooooo
0_l00008ooooo`?o0000^Oooool008kooooo0_l00002ooooo`;o00006?ooool00ol0003ooooooooo
o`0Cooooo`;o00002oooool2o`0009Oooooo002>ooooo`;o00000_ooool2o`0001Sooooo00?o0000
ooooooooool01oooool2o`0000[ooooo0_l0000;ooooo`;o0000Uoooool00:cooooo00?o0000oooo
ooooool01oooool2o`000;3ooooo002/ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@;o00001?ooool00ol0003ok^k^ooooo`04ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2iooooo`00ROooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B42o`0000Cooooo00?oEEEEojVYZOooool01oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo013ooooo0_l0002Wooooo`00ROooool01Ol@413o
oooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo013ooooo0_l0002Wooooo`00ROooool01Ol0003ooooooooooooooooo0000
00kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`?o0000^Oooool008Wo
oooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05oa0@4?oooooooooo
ooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00;ooooo0_l00003
ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol@413ooooooooooooooooo<S8b00Cooooo0_l00003ooooo`;o00000oooool00ol0003ooooooooo
o`2iooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`08ooooo`;o0000[oooool00:cooooo00?o0000ooooooooool02?ooool2o`0000co
oooo0_l0002Qooooo`00Toooool2o`0000Cooooo0_l0000Aooooo`?o00005_ooool2o`000:7ooooo
002Cooooo`;o00001?ooool2o`00017ooooo00?o0000ooooooooool01oooool2o`0000_ooooo0_l0
002Sooooo`00Toooool2o`0001Oooooo00?o0000ooooooooool01oooool2o`0000_ooooo0_l0002S
ooooo`00Z_ooool3o`0001?ooooo1?l0002Tooooo`00Z_ooool3o`0001?ooooo1?l0002Tooooo`00
[?ooool00ol0003oooooooooo`0Aooooo`;o0000Y_ooool00:cooooo00?o0000ooooooooool04Ooo
ool2o`000:Kooooo002/ooooo`03o`000?oooooooooo01kooooo0_l0002Iooooo`00[?ooool3o`00
00oooooo0_l0000=ooooo`;o0000VOooool00:cooooo00?o0000ooooooooool03oooool2o`000:So
oooo002Hooooo`;o00004_ooool00ol0003oooooooooo`2iooooo`00V?ooool2o`0001;ooooo00?o
0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
^Oooool009cooooo0_l0000>ooooo`03o`000?oooooooooo0;Wooooo002Looooo`;o00000oooool2
o`0000Wooooo0ol0002iooooo`00XOooool3o`0000Sooooo00?o0000ooooooooool0^Oooool00:;o
oooo0_l00008ooooo`03o`000?oooooooooo00Cooooo0_l0002cooooo`00[?ooool00ol0003ooooo
ooooo`03ooooo`?o0000/oooool00:cooooo00?o0000ooooooooool00_ooool3o`000;Cooooo002/
ooooo`03o`000?oooooooooo00;ooooo0_l0002eooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oo
oooooooo00kooooo0_l0002Yooooo`00VOooool2o`00017ooooo00?o0000ooooooooool03_ooool2
o`000:Wooooo002Iooooo`;o00004Oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0:ooooo`;o0000[Oooool009gooooo0_l0
0003ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`0:ooooo`;o0000[Ooo
ool009gooooo1?l00003ooooo`03o`000?oooooooooo00;o00000oooool00ol0003oooooooooo`2i
ooooo`00W_ooool3o`0000?ooooo00?o0000ooooooooool00_l00003ooooo`?o0000^Oooool009ko
oooo0_l00004ooooo`03o`000?oooooooooo00;o0000_oooool00:Cooooo00?o0000ooooooooool0
`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool0
0:;ooooo00?oEEEEofIVI_l00000`oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00:[ooooo00Co410@o`000?l0003o0000^_ooool00:_ooooo00?o0000oooo
ooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00Ko0000ogMgMol0003o
0000oeEEEOo^k^jgooooo`00Zoooool01_l0003oEEEEonk^k_ooooooMgMgoeEEEKOooooo002[oooo
o`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0]Oooool00:_ooooo00?o0000onk^k_oo
ool00_ooool00ol0003oooooooooo`2eooooo`00Zoooool01_l0003oEEEEonk^k_ooooooMgMgofIV
I[Oooooo002Zooooo`03oa0@4?l0003oMgMg00;o000000?oIVIVonk^k_ooool0]_ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.43981 .13462 Mdot
.65211 .43504 Mdot
.49118 .38475 Mdot
.53154 .6411 Mdot
.54677 .29684 Mdot
.59286 .70578 Mdot
.51608 .4611 Mdot
.72981 .48901 Mdot
.51944 .06241 Mdot
.5179 .71616 Mdot
.42444 .32629 Mdot
.72378 .57691 Mdot
.48452 .92466 Mdot
.41176 .53979 Mdot
.72114 .55793 Mdot
.44968 .26104 Mdot
.54403 .76172 Mdot
.46277 .92417 Mdot
.50378 .77566 Mdot
.68921 .46515 Mdot
.48409 .92154 Mdot
.64982 .59248 Mdot
.63886 .63528 Mdot
.4351 .88874 Mdot
.66415 .75983 Mdot
.40142 .5705 Mdot
.49239 .22448 Mdot
.53772 .69941 Mdot
.69039 .52113 Mdot
.65027 .43341 Mdot
.44628 .90176 Mdot
.53823 .08159 Mdot
.70367 .36148 Mdot
.40629 .68374 Mdot
.52516 .18542 Mdot
.60622 .23065 Mdot
.5222 .92054 Mdot
.57383 .51895 Mdot
.68566 .54981 Mdot
.71361 .64093 Mdot
.64617 .79958 Mdot
.42902 .19869 Mdot
.62382 .43131 Mdot
.52275 .1426 Mdot
.39895 .29301 Mdot
.58015 .61687 Mdot
.44684 .74944 Mdot
.42581 .08141 Mdot
.57607 .32362 Mdot
.68534 .46395 Mdot
.40812 .13575 Mdot
.65334 .70265 Mdot
.67594 .82551 Mdot
.58216 .29325 Mdot
.61122 .36814 Mdot
.62868 .20421 Mdot
.72921 .49717 Mdot
.53887 .77357 Mdot
.37614 .65095 Mdot
.38714 .444 Mdot
.56902 .65738 Mdot
.37826 .22543 Mdot
.68451 .54938 Mdot
.45158 .71467 Mdot
.6772 .30066 Mdot
.59649 .15442 Mdot
.53686 .663 Mdot
.41735 .46989 Mdot
.57157 .56648 Mdot
.40238 .77875 Mdot
.45238 .84764 Mdot
.44456 .37161 Mdot
.51921 .71077 Mdot
.56125 .52526 Mdot
.68455 .54824 Mdot
.44575 .56598 Mdot
.67555 .82609 Mdot
.53303 .74516 Mdot
.66954 .6546 Mdot
.47939 .16479 Mdot
.40664 .19929 Mdot
.64397 .40321 Mdot
.54888 .52655 Mdot
.45563 .14373 Mdot
.70968 .3739 Mdot
.49713 .24958 Mdot
.55963 .32965 Mdot
.57682 .39507 Mdot
.56658 .71682 Mdot
.41859 .43921 Mdot
.66166 .76336 Mdot
.75916 .41229 Mdot
.45932 .26448 Mdot
.59141 .50913 Mdot
.42499 .40612 Mdot
.74979 .36924 Mdot
.41565 .60337 Mdot
.39661 .18944 Mdot
.65376 .86006 Mdot
.54646 .76324 Mdot
.48873 .10573 Mdot
.59621 .62864 Mdot
.72461 .55131 Mdot
.55726 .19376 Mdot
.38546 .34274 Mdot
.39505 .53758 Mdot
.42695 .79097 Mdot
.44066 .76571 Mdot
.46385 .25904 Mdot
.40375 .78426 Mdot
.44867 .75684 Mdot
.53292 .63872 Mdot
.52214 .06394 Mdot
.6526 .32073 Mdot
.35116 .549 Mdot
.5216 .39807 Mdot
.5492 .71153 Mdot
.6541 .24067 Mdot
.61315 .17555 Mdot
.56554 .85979 Mdot
.49542 .91576 Mdot
.36362 .61233 Mdot
.57847 .78659 Mdot
.68996 .54832 Mdot
.39916 .76064 Mdot
.50816 .70902 Mdot
.66487 .35831 Mdot
.71709 .28357 Mdot
.57843 .23635 Mdot
.50839 .65741 Mdot
.63446 .65751 Mdot
.54223 .175 Mdot
.71206 .63621 Mdot
.57075 .75831 Mdot
.63004 .52619 Mdot
.67865 .62394 Mdot
.52735 .9177 Mdot
.68502 .44728 Mdot
.52808 .68724 Mdot
.71422 .40704 Mdot
.71878 .58677 Mdot
.54713 .44211 Mdot
.55101 .66435 Mdot
.54038 .76927 Mdot
.67808 .39994 Mdot
.69196 .32133 Mdot
.46023 .79407 Mdot
.58712 .45564 Mdot
.37232 .72754 Mdot
.60282 .59901 Mdot
.57066 .43616 Mdot
.41939 .84962 Mdot
.43444 .45867 Mdot
.52798 .82862 Mdot
.58887 .82998 Mdot
.67879 .60458 Mdot
.6427 .22293 Mdot
.53078 .90879 Mdot
.57565 .85082 Mdot
.45573 .1703 Mdot
.66609 .66933 Mdot
.63107 .8314 Mdot
.53508 .12563 Mdot
.61294 .38657 Mdot
.44675 .12491 Mdot
.68224 .29879 Mdot
.41764 .15154 Mdot
.57439 .52999 Mdot
.57113 .85977 Mdot
.66433 .36548 Mdot
.45752 .27117 Mdot
.56641 .41966 Mdot
.5467 .29961 Mdot
.41793 .66689 Mdot
.69769 .34873 Mdot
.74003 .33989 Mdot
.54309 .80342 Mdot
.49067 .30656 Mdot
.68881 .52479 Mdot
.61058 .79754 Mdot
.69586 .69663 Mdot
.55317 .41063 Mdot
.63112 .82509 Mdot
.42582 .49096 Mdot
.483 .0312 Mdot
.70684 .2645 Mdot
.54897 .09183 Mdot
.64759 .80321 Mdot
.63062 .49664 Mdot
.40281 .89245 Mdot
.67915 .4035 Mdot
.52037 .64808 Mdot
.36123 .48378 Mdot
.72147 .42438 Mdot
.55119 .937 Mdot
.72079 .59018 Mdot
.58805 .45344 Mdot
.77187 .5387 Mdot
.39667 .39234 Mdot
.43074 .4645 Mdot
.43427 .41304 Mdot
.46172 .32133 Mdot
.516 .23574 Mdot
.76742 .58516 Mdot
.50031 .11839 Mdot
.5205 .36519 Mdot
.56934 .75796 Mdot
.529 .65593 Mdot
.48497 .27762 Mdot
.44658 .24219 Mdot
.5751 .8022 Mdot
.54201 .726 Mdot
.41957 .14545 Mdot
.52047 .30418 Mdot
.45902 .1105 Mdot
.56576 .66087 Mdot
.62813 .83524 Mdot
.43312 .37795 Mdot
.40684 .74576 Mdot
.72178 .60603 Mdot
.55527 .69662 Mdot
.37832 .67045 Mdot
.40088 .22233 Mdot
.44242 .09591 Mdot
.45678 .25089 Mdot
.45794 .19711 Mdot
.6492 .41086 Mdot
.45752 .26976 Mdot
.72053 .56648 Mdot
.36139 .42869 Mdot
.41648 .48783 Mdot
.44858 .61442 Mdot
.76674 .57494 Mdot
.60112 .42262 Mdot
.50391 .24148 Mdot
.38208 .7931 Mdot
.57312 .47449 Mdot
.5843 .23929 Mdot
.56684 .81017 Mdot
.52705 .15281 Mdot
.37464 .25453 Mdot
.6187 .62441 Mdot
.50645 .08551 Mdot
.4549 .85059 Mdot
.56388 .11038 Mdot
.42359 .56684 Mdot
.6204 .77125 Mdot
.60437 .55833 Mdot
.46249 .85738 Mdot
.68345 .56914 Mdot
.57431 .90774 Mdot
.51651 .37686 Mdot
.52814 .61433 Mdot
.60034 .80645 Mdot
.40469 .6127 Mdot
.55975 .38834 Mdot
.63031 .45838 Mdot
.44193 .49387 Mdot
.72448 .45448 Mdot
.38087 .28981 Mdot
.59277 .37883 Mdot
.50306 .2398 Mdot
.47919 .06921 Mdot
.53131 .53061 Mdot
.60783 .55493 Mdot
.39505 .33342 Mdot
.43423 .71124 Mdot
.62425 .57641 Mdot
.6338 .28532 Mdot
.40509 .38077 Mdot
.63913 .29259 Mdot
.62261 .41383 Mdot
.51237 .7304 Mdot
.54614 .26008 Mdot
.59072 .82794 Mdot
.56059 .45941 Mdot
.41734 .32397 Mdot
.42984 .07358 Mdot
.44317 .24914 Mdot
.53795 .81395 Mdot
.68565 .57481 Mdot
.46376 .71385 Mdot
.55107 .40813 Mdot
.53733 .89976 Mdot
.72642 .52462 Mdot
.42878 .72809 Mdot
.46355 .67416 Mdot
.41692 .33744 Mdot
.62969 .26635 Mdot
.59031 .51964 Mdot
.38349 .37912 Mdot
.70303 .25807 Mdot
.39658 .80456 Mdot
.72376 .51182 Mdot
.40605 .84451 Mdot
.47718 .3286 Mdot
.39914 .82068 Mdot
.37916 .76785 Mdot
.59474 .20315 Mdot
.72256 .53784 Mdot
.53073 .22946 Mdot
.63024 .56385 Mdot
.5637 .20748 Mdot
.55507 .10041 Mdot
.66623 .75871 Mdot
.42207 .65242 Mdot
.41414 .11638 Mdot
.40004 .48975 Mdot
.46278 .68966 Mdot
.59056 .77223 Mdot
.5179 .80952 Mdot
.52675 .87436 Mdot
.39453 .86266 Mdot
.52726 .43219 Mdot
.3913 .61773 Mdot
.39622 .42053 Mdot
.69234 .33936 Mdot
.52616 .58495 Mdot
.6928 .70346 Mdot
.50104 .9875 Mdot
.57965 .07904 Mdot
.44188 .71082 Mdot
.55709 .78598 Mdot
.47551 .13179 Mdot
.67653 .60989 Mdot
.48527 .18842 Mdot
.42963 .49401 Mdot
.5009 .37243 Mdot
.45777 .85166 Mdot
.72813 .56097 Mdot
.61646 .77563 Mdot
.42484 .40597 Mdot
.61867 .71074 Mdot
.48988 .70515 Mdot
.46347 .31908 Mdot
.65113 .42189 Mdot
.601 .68487 Mdot
.61433 .39199 Mdot
.4532 .17384 Mdot
.4927 .19803 Mdot
.70361 .77886 Mdot
.40237 .57368 Mdot
.62344 .3349 Mdot
.45735 .72398 Mdot
.67301 .28516 Mdot
.4677 .21692 Mdot
.68012 .41902 Mdot
.65148 .45681 Mdot
.52504 .34268 Mdot
.58746 .54302 Mdot
.7247 .57575 Mdot
.39386 .79591 Mdot
.62487 .26488 Mdot
.51405 .19984 Mdot
.39442 .54829 Mdot
.6613 .35385 Mdot
.60906 .49161 Mdot
.72507 .57037 Mdot
.61597 .12027 Mdot
.52177 .10374 Mdot
.71468 .62312 Mdot
.68762 .7164 Mdot
.62 .84545 Mdot
.50659 .36846 Mdot
.58847 .36715 Mdot
.71838 .58646 Mdot
.72716 .47301 Mdot
.51589 .40847 Mdot
.3813 .576 Mdot
.41116 .66585 Mdot
.555 .78698 Mdot
.47113 .10192 Mdot
.41978 .10107 Mdot
.57859 .2294 Mdot
.46464 .96027 Mdot
.65225 .69426 Mdot
.64468 .60782 Mdot
.41858 .89375 Mdot
.64197 .62671 Mdot
.68651 .70921 Mdot
.36688 .21952 Mdot
.53048 .90677 Mdot
.49154 .88099 Mdot
.44017 .59472 Mdot
.56024 .92093 Mdot
.5712 .70699 Mdot
.49178 .34574 Mdot
.68629 .72319 Mdot
.39711 .74906 Mdot
.4295 .5047 Mdot
.55731 .57079 Mdot
.45149 .81504 Mdot
.52409 .28296 Mdot
.45553 .03371 Mdot
.43853 .09557 Mdot
.36325 .58852 Mdot
.69073 .71038 Mdot
.4433 .82862 Mdot
.72876 .72122 Mdot
.40759 .69838 Mdot
.42168 .69043 Mdot
.40766 .43035 Mdot
.50837 .56927 Mdot
.72916 .5329 Mdot
.72481 .56641 Mdot
.48592 .21807 Mdot
.50571 .29357 Mdot
.54277 .32298 Mdot
.53042 .32588 Mdot
.5919 .49628 Mdot
.54206 .13351 Mdot
.54845 .46171 Mdot
.57134 .44348 Mdot
.52267 .60238 Mdot
.58272 .41374 Mdot
.42608 .78187 Mdot
.54887 .34397 Mdot
.53094 .40935 Mdot
.36754 .67495 Mdot
.71384 .40398 Mdot
.46548 .61678 Mdot
.54865 .2236 Mdot
.42747 .79252 Mdot
.48698 .88172 Mdot
.40134 .53564 Mdot
.57312 .46843 Mdot
.54016 .94623 Mdot
.76679 .43755 Mdot
.59331 .25822 Mdot
.41305 .97784 Mdot
.55462 .18788 Mdot
.5407 .50874 Mdot
.5343 .08105 Mdot
.71583 .60081 Mdot
.42923 .30259 Mdot
.64944 .44581 Mdot
.69699 .79052 Mdot
.51648 .32119 Mdot
.44901 .66385 Mdot
.40814 .56229 Mdot
.48034 .06866 Mdot
.44945 .18457 Mdot
.77014 .48242 Mdot
.44212 .33247 Mdot
.53712 .2073 Mdot
.43052 .1927 Mdot
.42112 .52528 Mdot
.51954 .39303 Mdot
.56244 .5146 Mdot
.72947 .48799 Mdot
.5326 .52409 Mdot
.676 .63194 Mdot
.63932 .37463 Mdot
.38884 .41052 Mdot
.65359 .32639 Mdot
.38238 .59378 Mdot
.47617 .85713 Mdot
.72668 .30057 Mdot
.5525 .60172 Mdot
.72704 .5726 Mdot
.57078 .91298 Mdot
.43738 .72155 Mdot
.39533 .80272 Mdot
.40112 .45937 Mdot
.57898 .67561 Mdot
.67955 .41479 Mdot
.49795 .11351 Mdot
.48677 .79929 Mdot
.58665 .55517 Mdot
.40351 .66342 Mdot
.3919 .14303 Mdot
.62868 .49032 Mdot
.4474 .58097 Mdot
.60977 .37138 Mdot
.49918 .18045 Mdot
.50588 .36442 Mdot
.43484 .68359 Mdot
.5779 .28301 Mdot
.63099 .52526 Mdot
.47358 .29385 Mdot
.42996 .76338 Mdot
.60059 .16025 Mdot
.54397 .28909 Mdot
.38717 .49314 Mdot
.55733 .64582 Mdot
.54948 .66203 Mdot
.52425 .5335 Mdot
.35372 .62425 Mdot
.52189 .55891 Mdot
.65163 .42829 Mdot
.38396 .7197 Mdot
.55167 .14698 Mdot
.56588 .60332 Mdot
.68803 .47907 Mdot
.70901 .65428 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:Kooooo0_l00004ooooo`03o`000?oooooooooo0;Wooooo002Mooooo`;o00001oooool2o`0000Co
oooo00?o0000ooooooooool0^Oooool009gooooo0_l0000=ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000
^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool00oooool3o`000;?o
oooo002/ooooo`03o`000?oooooooooo00?ooooo0ol0002cooooo`00YOooool2o`0000Gooooo00?o
0000ooooooooool0^Oooool009Cooooo0_l0000?ooooo`;o00001Oooool00ol0003oooooooooo`2i
ooooo`00U?ooool2o`0001Kooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`0Gooooo`;o
0000X?ooool009?ooooo0_l0000Gooooo`03o`000?oooooooooo00Sooooo0ol0000<ooooo`;o0000
X?ooool009?ooooo0_l0000Gooooo`04o`000?oooooo0000o`0000Oooooo0ol0002^ooooo`00[?oo
ool01?l0003oooooo`000?l0002hooooo`00[?ooool00ol0003oooooooooo`0=ooooo`;o0000Z_oo
ool009Oooooo0_l0000Cooooo`03o`000?oooooooooo00gooooo0_l0002Zooooo`00Uoooool4o`00
017ooooo00?o0000ooooooooool0^Oooool0097ooooo0_l00006ooooo`;o00004Oooool3o`0000oo
oooo0_l0002Xooooo`00TOooool2o`0000oooooo0_l00008ooooo`03o`000?oooooooooo00Cooooo
0_l00009ooooo`;o0000Z?ooool00:;ooooo0_l00004ooooo`;o00000_ooool00ol0003ooooooooo
o`04ooooo`;o0000/oooool009kooooo0_l00008ooooo`;o00000_ooool00ol0003oooooooooo`0B
ooooo`;o0000YOooool009kooooo0_l0000;ooooo`;o00005?ooool2o`000:Gooooo002?ooooo`;o
00006_ooool2o`000;_ooooo0029ooooo`06onk^k_lb<S;o0000oc8b<_o^k^kooooo0_l00002oooo
o`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool2
o`000;[ooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEE
ojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`;o00009?ooool2o`0009Cooooo0021oooo
o`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo0_l000000omEEEGoooooooooo`07
ooooo`03o`000?oooooooooo00?ooooo0ol00008ooooo`;o00006Oooool2o`0009Cooooo0029oooo
o`05o`000?ooooooooooooooool000003?ooool2o`000003ob4Q8Ooooooooooo00Kooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`08ooooo`;o0000[oooool008Wooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo0ol000000olb<S;oc<c<ooooo`04
ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05oa0@4?ooooooooooooooool@41002_ooool2
o`0000;ooooo00?oZJVYogMgMoooool00oooool3o`0000Oooooo00?o0000ooooooooool02_ooool2
o`000:gooooo0029ooooo`04ogMgMonHV9SooooooiRHV0;o00002Oooool2o`0000?ooooo00?o<S8b
ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo0_l0002]
ooooo`00ROooool01?o^k^ko<S8bo`000?lb<S82o`0000[ooooo1Ol00004ooooo`Co00001_ooool0
0ol0003oooooooooo`2iooooo`00R?ooool2o`0001?ooooo0_l0000=ooooo`03o`000?oooooooooo
00Cooooo0_l0002cooooo`00R?ooool2o`0000Oooooo0_l0000:ooooo`;o00003Oooool00ol0003o
ooooooooo`04ooooo`;o00002?ooool2o`000:Wooooo002Aooooo`;o00006Oooool00ol0003ooooo
ooooo`0>ooooo`;o0000ZOooool0093ooooo0_l0000Jooooo`?o00001Oooool2o`000;;ooooo002@
ooooo`;o00006_ooool00ol0003oooooooooo`05ooooo`;o00005Oooool2o`0009_ooooo002/oooo
o`03o`000?oooooooooo01cooooo0_l0002Kooooo`00[?ooool00ol0003oooooooooo`0Nooooo`;o
0000VOooool00:Gooooo0_l00005ooooo`03o`000?oooooooooo01kooooo0_l0002Iooooo`00YOoo
ool2o`0000Gooooo00?o0000ooooooooool0^Oooool009gooooo0_l0000=ooooo`03o`000?oooooo
oooo0;Wooooo002Looooo`?o00003Oooool00ol0003oooooooooo`2iooooo`00W?ooool2o`0000ko
oooo0ol0000;ooooo`;o00005Oooool2o`0009Gooooo002/ooooo`03o`000?oooooooooo00_ooooo
0_l0000Eooooo`;o0000UOooool00:_ooooo0_l0002kooooo`00Voooool2o`0000kooooo0_l00007
ooooo`;o0000/_ooool008Wooooo0_l0000@ooooo`;o00002_ooool2o`0000?ooooo00?o0000oooo
ooooool01Oooool2o`0000Sooooo0_l0002Xooooo`00ROooool2o`0001cooooo0_l00003ooooo`03
o`000?oooooooooo00oooooo0_l0002Xooooo`00UOooool2o`0001Gooooo00?o0000ooooooooool0
3oooool2o`000:Sooooo002Eooooo`;o00001oooool2o`0000Wooooo0_l000000ooooooo0000oooo
o`0@ooooo`;o0000Z?ooool008gooooo0_l00005ooooo`;o00002?ooool2o`0000Wooooo0_l00000
1Ooooooo0000o`000?l0003ooooo00;o0000]_ooool008gooooo0_l00005ooooo`;o00005_ooool0
1?l0003oooooooooooooool2o`0001Wooooo0_l00009ooooo`;o0000T?ooool00:cooooo00?o0000
ooooooooool02Oooool2o`0000Oooooo0_l00008ooooo`;o00002Oooool2o`00093ooooo002/oooo
o`03o`000?oooooooooo00Wooooo0_l00007ooooo`;o0000YOooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool0083ooooo0_l0000Oooooo`;o00001?oo
ool2o`0000?ooooo00?o0000ooooooooool0^Oooool0083ooooo0_l00009ooooo`;o00005?ooool2
o`0000Cooooo0_l00003ooooo`03o`000?oooooooooo0;Wooooo0023ooooo`;o00001_ooool2o`00
01cooooo0_l000001?oooooo0000o`000?l0000=ooooo`;o00007Oooool2o`0008_ooooo0023oooo
o`;o00009?ooool2o`000003ooooool0003ooooo00kooooo0_l0000Mooooo`;o0000Roooool00:co
oooo00?o0000ooooooooool01oooool2o`0000kooooo0_l00007ooooo`;o0000Uoooool00:cooooo
00?o0000ooooooooool01oooool2o`0000kooooo0_l00007ooooo`;o0000Uoooool00:cooooo00?o
0000ooooooooool00_ooool2o`0001;ooooo0_l0002Qooooo`00[?ooool3o`0000;ooooo0_l0000B
ooooo`Co00005Oooool2o`0008Sooooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool2
o`000003ob4Q8Ooooooooooo00?ooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`?o00006?oo
ool2o`0001Gooooo0_l00028ooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo0_l0
00000olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002iooooo`00ROooool6
o`0000;ooooo00Go410@oooooooooooooooooa0@4003ooooo`;o00002oooool00ol0003ooooooooo
o`02ooooo`;o0000^oooool0097ooooo00Go0000ooooooooooooooooo`000003ooooo`;o00000_oo
ool2o`0000Kooooo00?oMgMgoc8b<_ooool00oooool4o`000;Wooooo0022ooooo`;o00003Oooool0
1Ol0003ooooooooooooooooo000000Oooooo0_l00003ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`2iooooo`00P_ooool2o`0000gooooo00Go410@oooooooooooooooo
oa0@400:ooooo`?o00002Oooool00ol0003oooooooooo`0Kooooo`;o00008oooool2o`0007Oooooo
002Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0000?ooooo0ol00009ooooo`03o`00
0?oooooooooo00cooooo0_l0000=ooooo`;o00008oooool2o`0007Oooooo002Aooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2o`000003ooooool0003o000000;ooooo1?l00006ooooo`03o`00
0?oooooooooo00cooooo0_l0000Hooooo`;o00006Oooool2o`0007Kooooo002Nooooo`;o00003?oo
ool00ol0003oooooooooo`0Vooooo`?o00006?ooool2o`0007Kooooo002Nooooo`;o00003?ooool0
0ol0003oooooooooo`0Wooooo`;o0000T?ooool009kooooo0_l0000<ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`?o0000^Oooool00:Oooooo0_l00003ooooo`03o`000?oooooooooo0;Wooooo
002Wooooo`;o00000oooool00ol0003oooooooooo`05ooooo`;o00003oooool2o`000:7ooooo002/
ooooo`03o`000?oooooooooo00Gooooo0_l0000?ooooo`;o00004Oooool2o`0000_ooooo0_l0000<
ooooo`;o0000Loooool00:cooooo00?o0000ooooooooool02oooool2o`0001cooooo0_l0000;oooo
o`;o00003?ooool2o`0007?ooooo0024ooooo`;o00009_ooool00ol0003oooooooooo`0;ooooo`;o
0000[?ooool008Cooooo0_l00004ooooo`;o00005oooool2o`0000Oooooo0ol0000Hooooo`;o0000
4?ooool2o`0008gooooo002:ooooo`;o00005oooool2o`0000Oooooo0ol0000<ooooo`;o00002_oo
ool2o`00013ooooo0_l0002=ooooo`00[?ooool3o`0000cooooo0_l0000Yooooo`Co00003?ooool2
o`00073ooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`03ooooo`;o00001oooool2o`00
02Wooooo1?l0000<ooooo`;o0000L?ooool009Cooooo0_l0000Booooo`;o00000_ooool00ol0003o
ooooooooo`03ooooo`;o0000]?ooool00:Sooooo0_l00002ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Poooo
o`;o00002_ooool00ol0003oooooooooo`2iooooo`00Woooool3o`0000[ooooo00?o0000oooooooo
ool00_ooool2o`0002_ooooo0_l0000;ooooo`;o0000Noooool0093ooooo0_l0000=ooooo`;o0000
2oooool3o`0000;ooooo0_l00007ooooo`;o00002Oooool2o`0001Oooooo0_l0000;ooooo`;o0000
Noooool0093ooooo0_l000000ooooooo0000o`00000?ooooo`;o00001_ooool00ol0003ooooooooo
o`07ooooo`;o00000_ooool2o`0000Wooooo0_l0000Gooooo`;o0000R?ooool009?ooooo0_l0000?
ooooo`;o00001_ooool00ol0003oooooooooo`07ooooo`;o00001oooool2o`0001gooooo0_l00028
ooooo`00ROooool2o`0000gooooo0_l0000Booooo`03o`000?oooooooooo013ooooo0_l0000Coooo
o`;o0000T_ooool008Wooooo0_l00005ooooo`;o00001_ooool2o`0001;ooooo00?o0000oooooooo
ool09Oooool2o`0009;ooooo002@ooooo`;o00006_ooool00ol0003oooooooooo`0looooo`;o0000
3_ooool2o`0006_ooooo0026ooooo`;o00009?ooool00ol0003oooooooooo`05ooooo`;o00001_oo
ool2o`0002gooooo0_l0000>ooooo`;o0000Joooool008Kooooo0_l0000Qooooo`;o000000?ooooo
o`000?ooool01_ooool2o`0000Kooooo0_l0002Zooooo`00ZOooool2o`000003ooooool0003ooooo
03oooooo0_l0001iooooo`00[?ooool3o`0003kooooo0_l0001iooooo`00[?ooool00ol0003ooooo
ooooo`0booooo`;o0000QOooool00:cooooo00?o0000ooooooooool0<_ooool3o`0008Cooooo002/
ooooo`03o`000?oooooooooo03?ooooo0_l0000;ooooo`;o0000Moooool00:cooooo00Co0000oooo
ool0003o00000_ooool2o`0003_ooooo0_l0001gooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00Co
0000ooooool0003o00000_ooool2o`0001Gooooo0_l00005ooooo`;o00004?ooool2o`0008Cooooo
0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00Co0000ooooool0003o00006Oooool2o`00
00Gooooo0_l0000@ooooo`;o00006_ooool2o`0006Sooooo0021ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@00_ooooo0_l000000olQ8B7ok^k^ooooo`08ooooo`03o`000?oooooooooo
00?ooooo1?l0000Pooooo`;o00007oooool2o`0000_ooooo0_l0001Xooooo`00ROooool01Ol0003o
oooooooooooooooo000000_ooooo0_l000000onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo
00Cooooo0ol00002ooooo`;o00007Oooool2o`0000Sooooo0_l0000Eooooo`;o0000MOooool008Go
oooo0_l00002ooooo`05o`000?ooooooooooooooool000001oooool2o`0000Gooooo00?oMgMgofIV
I_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool00_ooool2
o`0001Oooooo0_l0000>ooooo`;o0000S?ooool008Gooooo0_l00002ooooo`03oa0@4?oooooooooo
00;o00001oooool2o`0000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo01_ooooo0_l0002Looooo`00ROooool00omgMgOoV9RHooooo`02o`0000_o
oooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Cooooo0_l000000ooo
oooo0000ooooo`2jooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c004ooooo`Co00000oooool2o`000003ooooool0003ooooo017ooooo0_l0000@
ooooo`;o0000UOooool008Wooooo0_l0000Qooooo`03o`000?oooooooooo013ooooo0_l0000@oooo
o`;o0000UOooool008Wooooo0_l0000Qooooo`03o`000?oooooooooo00?ooooo0_l0000Aooooo`;o
00002_ooool2o`0009Gooooo002/ooooo`03o`000?oooooooooo00?ooooo0ol0000@ooooo`;o0000
XOooool00:cooooo0ol00004ooooo`;o0000<Oooool2o`00083ooooo002/ooooo`03o`000?oooooo
oooo02cooooo0_l00009ooooo`?o00002Oooool2o`0007Cooooo002Cooooo`;o00005oooool00ol0
003oooooooooo`0/ooooo`;o00002_ooool2o`0000Wooooo0_l0001dooooo`00Qoooool2o`0000[o
oooo0_l0000Gooooo`03o`000?oooooooooo00;ooooo0_l00003ooooo`;o00001?ooool3o`0003?o
oooo0_l0001dooooo`00Qoooool2o`0000gooooo0_l0000Dooooo`03o`000?oooooooooo00;ooooo
0_l00003ooooo`;o00001?ooool3o`0001kooooo0_l0000Rooooo`;o0000IOooool009Kooooo0_l0
000Dooooo`03o`000?oooooooooo01Sooooo0_l0000;ooooo`;o00001oooool2o`0000Sooooo0_l0
000Hooooo`;o0000IOooool00:cooooo00?o0000ooooooooool04_ooool2o`0000Cooooo0_l0000;
ooooo`;o00004Oooool2o`0007oooooo0029ooooo`;o00008Oooool00ol0003oooooooooo`0Boooo
o`;o00002_ooool2o`0000kooooo0_l00008ooooo`;o0000Ooooool008Wooooo0_l0000Qooooo`?o
00007_ooool2o`0000kooooo0_l0000Fooooo`;o0000LOooool007kooooo0_l0000/ooooo`03o`00
0?oooooooooo02oooooo0_l0000Eooooo`;o0000LOooool007kooooo0_l0000=ooooo`;o00007Ooo
ool00ol0003oooooooooo`0Uooooo`;o00002?ooool2o`0008Sooooo002=ooooo`;o00007Oooool0
0ol0003oooooooooo`06ooooo`;o00007Oooool2o`0000Oooooo0_l00029ooooo`00[?ooool00ol0
003oooooooooo`06ooooo`;o00003?ooool2o`0001Sooooo0ol0000Tooooo`;o0000H_ooool0097o
oooo0_l0000Iooooo`03o`000?oooooooooo01Cooooo0_l0000Iooooo`;o00009?ooool2o`0006;o
oooo002Aooooo`;o00006Oooool00ol0003oooooooooo`0<ooooo`;o00001_ooool2o`000:?ooooo
0026ooooo`;o00009?ooool00ol0003oooooooooo`0<ooooo`;o00001_ooool2o`0001Sooooo0_l0
0029ooooo`00Q_ooool2o`0002Cooooo00?o0000ooooooooool0;_ooool2o`0000[ooooo0_l0001m
ooooo`00[?ooool3o`0003[ooooo0_l0001mooooo`00[?ooool00ol0003oooooooooo`0Iooooo`?o
0000:oooool2o`00073ooooo002Fooooo`;o00005?ooool00ol0003oooooooooo`0Iooooo`?o0000
3?ooool2o`0000Gooooo0_l0000Fooooo`;o0000L?ooool000Wooooo1?l000000ol@413ooooooooo
o`0Fooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool0
1?ooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@02o`0001Cooooo
00?o0000ooooooooool00_ooool2o`0000Wooooo0_l00002ooooo`;o00001Oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00000_ooool2o`000005odA4A?l0003o0000oc8b
<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`00
0?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`Co000000?o410@oooooooo
ool04_ooool000_ooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool00onHV9So8B4Qonk^kP02o`0000Oooooo00?oMgMg
o`000?l000005Oooool00ol0003oooooooooo`02ooooo`;o00002Oooool2o`0000;ooooo0_l00005
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A007ooooo`03ogMgMolb<S;ooooo00?ooooo0ol00008ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool06Oooool00ol0
003oooooooooo`0Dooooo`001_l00005ooooo`03o`000?oooooooooo013ooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo
00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`05
ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Ooo
ool2o`0001Gooooo00?o0000ooooooooool06?ooool01Ol@413ooooooooooooooooo410@00cooooo
00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`02ooooo`?o00002?ooool01Ol@413ooooo
oooooooooooo410@013ooooo00?o0000ooooooooool03Oooool01Ol@413ooooooooooooooooo410@
00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo
000000oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h00oooool2o`0000;ooooo00?oMgMgoc8b<_ooool05Oooool00ol0003ooooooooo
o`0Eooooo`;o000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ
8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000oooooo
00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qoooooooo
ool01_ooool00omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`00
0?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003?ooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMg
MomVIVKooooo00;ooooo0_l000001?lQ8B7o0000oc8b<_o<c<`Fooooo`03o`000?oooooooooo01Go
oooo0_l000000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_oo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00?o0000ooooooooool00_l0000<oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000kooooo00?o
EEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[ooooo00?o0000ooooooooool0
5?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol@413ooooooooooooooooo410@00kooooo
00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@
41003?ooool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo01Sooooo0ol0000Eooooo`;o000000?ooooooa0@
4?ooool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool04Oooool00ol@413oooooooooo`02o`0000cooooo00?o0000ooooooooool04Oooool01Ol@
413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooooooo
o`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0Eooooo`;o000000KoooooogMgMonHV9SooooooiRHV?mg
MgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`;o0000
2?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool05?ooool000Wooooo00?oEEEEofIVI_l000006_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@
o`000?lQ8B7oc<c<00Cooooo1?l0000Gooooo`03o`000?oooooooooo01Sooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l00008
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`Go00001?ooool4o`0001Wooooo00?oEEEEofIVI_l000005_ooool007kooooo0_l0
000/ooooo`03o`000?oooooooooo05Kooooo0_l0001Qooooo`00O_ooool2o`00013ooooo0_l0000J
ooooo`03o`000?oooooooooo04Sooooo0_l0001_ooooo`00Roooool2o`0000?ooooo0_l000000ooo
oooo0000o`00000Gooooo`03o`000?oooooooooo027ooooo0_l00004ooooo`;o00007oooool2o`00
06Cooooo0_l00002ooooo`;o00001Oooool008Kooooo0_l00003ooooo`;o00001_ooool3o`0000;o
oooo0_l0000Booooo`03o`000?oooooooooo027ooooo0_l00004ooooo`;o0000QOooool01_o^k^ko
8B4QohN7Qonj^[[o0000omgMg@Gooooo0026ooooo`;o00003?ooool2o`0000;ooooo0_l0000Boooo
o`03o`000?oooooooooo01_ooooo0_l0000;ooooo`;o00007_ooool2o`0006Gooooo00CogMgMo`00
0?l@413oc<c<1_ooool000Ooooooool0001<o`0000cooooo00Cok^k^ob4Q8Ol@413ok^k^1_ooool0
00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`04ob4Q8OmgMgOoMgMg
oc8b<PKooooo0007ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo00kooooo0_l0000Fooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool02Oooool2o`0000;ooooo0_l00005ooooo`00U?ooool2o`0001Ko
oooo00?o0000ooooooooool02_ooool2o`0000oooooo0_l0002Looooo`00[?ooool00ol0003ooooo
ooooo`0:ooooo`;o00003oooool2o`0002Wooooo0_l0001aooooo`00[?ooool00ol0003ooooooooo
o`0Aooooo`;o0000<oooool2o`00077ooooo002/ooooo`03o`000?oooooooooo017ooooo0_l00002
ooooo`;o00000oooool2o`0009gooooo002/ooooo`03o`000?oooooooooo01Gooooo0_l00003oooo
o`;o00007oooool2o`0007cooooo002Booooo`;o00006?ooool3o`0000Oooooo0_l00008ooooo`;o
00005Oooool2o`00017ooooo0_l0000:ooooo`;o0000L?ooool009;ooooo0_l0000Hooooo`03o`00
0?oooooooooo00Oooooo0_l00004ooooo`;o00000_ooool2o`0001Cooooo0ol0000Aooooo`;o0000
2_ooool2o`00073ooooo002/ooooo`03o`000?oooooooooo00Oooooo0_l00004ooooo`;o00001_oo
ool2o`00013ooooo0_l0002@ooooo`00[?ooool00ol0003oooooooooo`05ooooo`Co00003?ooool2
o`00037ooooo0_l0001_ooooo`00ROooool4o`0001oooooo00?o0000ooooooooool01Oooool2o`00
03oooooo1?l0001_ooooo`00ROooool4o`000003ooooool0003o000001cooooo00?o0000oooooooo
ool0A_ooool2o`0000kooooo0_l0001Qooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool0
6Oooool2o`0003_ooooo0_l0001Qooooo`00[?ooool00ol0003oooooooooo`0Iooooo`;o0000W_oo
ool007[ooooo0_l0000=ooooo`;o00008Oooool00ol0003oooooooooo`0iooooo`Co0000O?ooool0
07[ooooo0_l0000=ooooo`;o00008Oooool3o`0003Wooooo1?l0000:ooooo`;o0000L?ooool00:co
oooo00?o0000ooooooooool06Oooool2o`0000Gooooo0_l0000Uooooo`;o0000L?ooool00:cooooo
00?o0000ooooooooool01?ooool2o`0001?ooooo0_l00004ooooo`?o00009?ooool2o`00077ooooo
002/ooooo`03o`000?oooooooooo00Cooooo0_l0000Iooooo`;o00009Oooool4o`0006oooooo002=
ooooo`;o00007Oooool00ol0003oooooooooo`0Xooooo`;o00007_ooool2o`0006oooooo002=oooo
o`;o00000oooool2o`0000Kooooo0_l0000@ooooo`03o`000?oooooooooo01Cooooo0_l0000Boooo
o`;o00006oooool4o`00073ooooo002;ooooo`;o00001Oooool2o`0000Kooooo0_l0000@ooooo`04
o`000?oooooo0000o`0000kooooo0_l00003ooooo`;o00008oooool2o`0000[ooooo1?l0001`oooo
o`00Roooool2o`0001oooooo00Co0000ooooool0003o00003_ooool2o`0002Sooooo0_l0000<oooo
o`?o0000Koooool008Cooooo0_l00005ooooo`;o00007oooool3o`0002Kooooo0_l0000Booooo`;o
00002_ooool4o`0000_ooooo0_l0001Rooooo`00Q?ooool2o`0002Kooooo00?o0000ooooooooool0
9_ooool2o`0001;ooooo0_l0000:ooooo`?o00003?ooool2o`0006;ooooo002Jooooo`;o00004?oo
ool00ol0003oooooooooo`2iooooo`00V_ooool2o`00013ooooo00?o0000ooooooooool01Oooool2
o`0004kooooo0_l0001Rooooo`00O_ooool2o`0002cooooo00?o0000ooooooooool01Oooool2o`00
03kooooo0_l0000>ooooo`;o0000H_ooool007kooooo0_l0000/ooooo`03o`000?oooooooooo04Go
oooo0_l0001booooo`00QOooool2o`00017ooooo0_l0000Booooo`03o`000?oooooooooo02kooooo
0_l0000Eooooo`;o0000L_ooool008Gooooo0_l0000Aooooo`;o00004_ooool00ol0003ooooooooo
o`0^ooooo`;o0000ROooool00:cooooo0ol0000Oooooo`;o00008oooool2o`0007?ooooo002@oooo
o`;o00006_ooool00ol0003oooooooooo`04ooooo`;o00002?ooool2o`0000;ooooo0_l0000;oooo
o`;o00008oooool2o`0007?ooooo002@ooooo`;o00006_ooool00ol0003oooooooooo`04ooooo`;o
00002?ooool2o`0000;ooooo0_l0000Tooooo`;o00003?ooool2o`00077ooooo002/ooooo`03o`00
0?oooooooooo02cooooo0_l00009ooooo`?o00003?ooool2o`00077ooooo001oooooo`;o00002ooo
ool2o`0001kooooo00?o0000ooooooooool0;?ooool2o`0000Wooooo0_l00020ooooo`00Ooooool2
o`0000_ooooo0_l0000=ooooo`;o00003oooool00ol0003oooooooooo`06ooooo`;o0000/Oooool0
08Sooooo0_l000001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000;ooooo0_l00000
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool01_ooool2o`0000oooooo0_l0
002Pooooo`00R?ooool2o`000004oiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@00_ooool2o`0000?ooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`0Gooooo`;o0000X?ooool007_ooooo0_l0000<ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0000Tooooo`;o0000
4_ooool2o`0000Wooooo0_l0001dooooo`00Noooool2o`0000cooooo00Go0000oooooooooooooooo
o`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`0Looooo`;o00001_ooool2o`0000Gooooo0_l0000;ooooo`;o00002Oooool2o`0007Cooooo
0029ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Looooo`;o00003Oooool2o`0008co
oooo0029ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0=oooool2o`00083ooooo0029ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Zooooo`;o00002oooool2o`0000[ooooo0_l0001doooo
o`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004
ooooo`Co00001_ooool00ol0003oooooooooo`07ooooo`;o00008Oooool2o`0001Oooooo0_l0001d
ooooo`00[?ooool00ol0003oooooooooo`07ooooo`;o0000>_ooool2o`0007Cooooo002/ooooo`03
o`000?oooooooooo00Oooooo0_l00006ooooo`;o0000<_ooool2o`0007Cooooo002/ooooo`03o`00
0?oooooooooo00?ooooo0_l0000:ooooo`;o0000Z?ooool008?ooooo0_l0000=ooooo`;o00006?oo
ool3o`0000?ooooo0_l0002dooooo`00Poooool2o`0000gooooo0_l0000Hooooo`03o`000?oooooo
oooo00Kooooo0_l0000]ooooo`;o00002oooool2o`0007Gooooo002/ooooo`04o`000?oooooo0000
o`0000Gooooo0_l0000;ooooo`;o00005?ooool2o`0000[ooooo0_l0000;ooooo`;o0000MOooool0
0:cooooo00Co0000ooooool0003o00003?ooool2o`0000?ooooo0ol0000Dooooo`;o0000S_ooool0
08cooooo0_l0000=ooooo`;o00003oooool00ol0003oooooooooo`09ooooo`;o00000_ooool2o`00
00?ooooo0_l0002Uooooo`00S?ooool6o`0000Wooooo0_l0000?ooooo`03o`000?oooooooooo00Wo
oooo0_l00002ooooo`;o0000Z_ooool008?ooooo0_l00009ooooo`Co00006_ooool00ol0003ooooo
ooooo`0cooooo`;o0000Q?ooool008?ooooo0_l0000Kooooo`;o00002_ooool00ol0003ooooooooo
o`0cooooo`;o0000Q?ooool0083ooooo0_l0000Nooooo`;o00002_ooool3o`0001Oooooo0_l0002P
ooooo`00P?ooool2o`0002[ooooo00?o0000ooooooooool05oooool2o`000:3ooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002=ooooo`;o00001oooool2o`0001Cooooo00?o0000ooooooooool0
7_ooool2o`0009Wooooo002=ooooo`;o00001oooool2o`0001Cooooo00?o0000ooooooooool01_oo
ool2o`0001Kooooo0_l0002Iooooo`00T_ooool2o`0000_ooooo0_l0000;ooooo`03o`000?oooooo
oooo00Kooooo0_l0002aooooo`00T_ooool2o`0000_ooooo0_l0000;ooooo`03o`000?oooooooooo
02oooooo0_l00028ooooo`00SOooool2o`0001gooooo00?o0000ooooooooool03oooool2o`0001ko
oooo0_l0000<ooooo`;o0000N_ooool008gooooo0_l0000Mooooo`?o00002Oooool2o`0000Cooooo
0_l0000/ooooo`;o0000N_ooool00:cooooo00?o0000ooooooooool02Oooool2o`0002Cooooo0_l0
000;ooooo`;o0000Noooool00:Sooooo0_l00002ooooo`03o`000?oooooooooo01Cooooo0_l00005
ooooo`;o00004_ooool2o`0000_ooooo0_l0001kooooo`00Z?ooool2o`0000;ooooo00Co0000oooo
ool0003o00004oooool2o`0000Gooooo0_l0000Mooooo`Co0000Noooool009Kooooo1?l0000Boooo
o`04o`000?oooooo0000o`0000;ooooo0_l00008ooooo`;o00005Oooool2o`0001Cooooo1?l0001k
ooooo`00U_ooool4o`0000;ooooo0_l00002ooooo`;o00002_ooool00ol0003oooooooooo`02oooo
o`?o00002?ooool2o`0001Gooooo0_l0000Dooooo`;o0000OOooool009cooooo0_l00002ooooo`;o
00002_ooool00ol0003oooooooooo`02ooooo`;o00003oooool2o`0002Gooooo0_l0001mooooo`00
QOooool2o`00013ooooo0_l0000Cooooo`03o`000?oooooooooo01?ooooo0_l0000cooooo`;o0000
Koooool008Gooooo0_l0000@ooooo`;o00001?ooool2o`0000gooooo0ol0000jooooo`;o00003?oo
ool2o`0006oooooo0021ooooo`;o00004Oooool2o`0000Oooooo0_l0000=ooooo`03o`000?oooooo
oooo00[ooooo0_l0000^ooooo`;o0000OOooool0087ooooo0_l0000Aooooo`;o00005_ooool01?l0
003oooooooooooooool2o`0000Oooooo0_l0002]ooooo`00[?ooool01?l0003oooooooooooooool2
o`000;Kooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;Wooooo002=ooooo`;o00000_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool01oooool2o`000;3ooooo002:ooooo`;o000000?oooooo`000?l000000_ooool01Ol@413o
oooooooooooooooo410@00Cooooo0_l0000:ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01oooool2o`000;3ooooo002:ooooo`;o00001Oooool01Ol0003ooooooooooooooooo0000
00Cooooo0_l00009ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002iooooo`00TOooool01Ol0003o
oooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo0;Wooooo002Aooooo`05oa0@4?ooooooooooooooool@41001Oooool2o`0000Gooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Cooooo`?o00007Oooool2o`0008Cooooo002:oooo
o`;o00001Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l00005ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02oooool2o`0000Kooooo0ol0000Mooooo`;o0000Q?ooool0
08[ooooo0_l00005ooooo`03onk^k_lb<S;o000000;o00003?ooool4o`0000Kooooo00?o0000oooo
ooooool02oooool3o`0002Cooooo0ol00024ooooo`00Q?ooool2o`0000kooooo0_l00002ooooo`;o
00004_ooool00ol0003oooooooooo`0<ooooo`;o00009?ooool2o`0008Gooooo0024ooooo`;o0000
4_ooool2o`0001;ooooo00?o0000ooooooooool02_ooool2o`000:gooooo002/ooooo`03o`000?oo
oooooooo00Wooooo0ol0000>ooooo`;o00002?ooool2o`0009?ooooo002/ooooo`?o00002Oooool2
o`0000oooooo0_l00007ooooo`?o0000Toooool008_ooooo0_l0000Oooooo`?o00008oooool2o`00
01_ooooo0_l0001gooooo`00Roooool2o`0000Kooooo0_l0000Gooooo`03o`000?oooooooooo043o
oooo0_l0001gooooo`00S?ooool2o`0000Gooooo0_l0000Gooooo`03o`000?oooooooooo00oooooo
0_l0002Xooooo`00S?ooool2o`0001kooooo00?o0000ooooooooool03oooool2o`0000Gooooo0_l0
002Qooooo`00Toooool2o`0001Oooooo00?o0000ooooooooool03oooool2o`0000Gooooo0_l0000V
ooooo`;o0000NOooool008Gooooo0_l0000<ooooo`?o00002?ooool2o`0000cooooo00?o0000oooo
ooooool0?_ooool2o`0007Wooooo0025ooooo`;o00000_ooool2o`0000Wooooo0_l00008ooooo`;o
00003?ooool00ol0003oooooooooo`0Qooooo`;o0000U_ooool008Wooooo0_l0000Looooo`;o0000
0oooool3o`00027ooooo0_l0000:ooooo`;o0000R_ooool008Wooooo0_l0000Looooo`;o00000ooo
ool00ol0003oooooooooo`0;ooooo`;o00002?ooool2o`0001Kooooo0_l0002:ooooo`00ROooool2
o`00027ooooo00?o0000ooooooooool02oooool2o`0000Sooooo0_l00007ooooo`;o00003Oooool2
o`0008[ooooo0029ooooo`;o00008Oooool00ol0003oooooooooo`02ooooo`;o00003oooool2o`00
00Wooooo0_l0002Iooooo`00[?ooool00ol0003oooooooooo`02ooooo`;o00003oooool2o`000:Co
oooo002Looooo`;o00003_ooool00ol0003oooooooooo`09ooooo`;o0000[_ooool009cooooo0_l0
000>ooooo`03o`000?oooooooooo00Wooooo0_l0002^ooooo`00R_ooool2o`00023ooooo00?o0000
ooooooooool0^Oooool008[ooooo0_l0000Pooooo`?o0000:?ooool2o`0000gooooo0_l00020oooo
o`00VOooool2o`00017ooooo00?o0000ooooooooool01_ooool2o`0001?ooooo0_l0000;ooooo`;o
00003Oooool2o`00083ooooo002Iooooo`;o00004Oooool00ol0003oooooooooo`06ooooo`;o0000
4_ooool3o`0000_ooooo0_l0000=ooooo`;o0000P?ooool00:cooooo00?o0000ooooooooool06_oo
ool2o`0000cooooo0_l0002?ooooo`00[?ooool00ol0003oooooooooo`0Wooooo`;o0000T?ooool0
0:cooooo00?o0000ooooooooool09oooool2o`00093ooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002=ooooo`;o00007Oooool00ol0003oooooooooo`0Tooooo`;o0000Toooool008gooooo0_l0
0002ooooo`;o00002Oooool2o`0000kooooo00?o0000ooooooooool09?ooool2o`0009?ooooo002A
ooooo`;o00002Oooool4o`0000cooooo0ol0000Fooooo`;o0000XOooool009gooooo0ol0000<oooo
o`03o`000?oooooooooo01Kooooo0_l0002Qooooo`00Woooool2o`0000?ooooo0_l00006ooooo`03
o`000?oooooooooo0;Wooooo002Oooooo`;o00000oooool2o`0000Kooooo00?o0000ooooooooool0
4_ooool4o`0001Wooooo0_l00028ooooo`00ROooool2o`00027ooooo00?o0000ooooooooool04_oo
ool4o`0001Wooooo0_l00028ooooo`00ROooool3o`000003oc8b<_o^k^kooooo00Cooooo0_lQ8B46
ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo0;Wooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?o
EEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;Wooooo0029
ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0^Oooool008Wooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`0000Gooooo0_l0
002booooo`00ROooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool01Oooool2o`000;;ooooo
0029ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo00;ooooo1?l000000ooooooo0000ooooo`2jooooo`00ROooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00;o
oooo1?l000000ooooooo0000ooooo`2jooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00So
oooo0_l000000ooooooo0000o`000003o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo0;Wo
oooo002Fooooo`;o00005?ooool00ol0003oooooooooo`2iooooo`00Roooool2o`0000Cooooo0_l0
000Iooooo`03o`000?oooooooooo0;Wooooo002;ooooo`;o00001?ooool2o`0001Wooooo00?o0000
ooooooooool0^Oooool00:cooooo0ol00009ooooo`;o0000[_ooool009[ooooo0_l0000@ooooo`03
o`000?oooooooooo00Wooooo0_l0002^ooooo`00V_ooool2o`00013ooooo00?o0000ooooooooool0
1oooool2o`000;3ooooo002/ooooo`03o`000?oooooooooo00Oooooo0_l0000<ooooo`;o0000X_oo
ool00:cooooo00?o0000ooooooooool01oooool2o`0000_ooooo0ol0002Rooooo`00Z_ooool3o`00
01Kooooo0_l0002Sooooo`00Z_ooool3o`0000Sooooo0_l0002aooooo`00Y_ooool2o`0000Cooooo
00?o0000ooooooooool01?ooool4o`0000Sooooo0_l0002Wooooo`00Woooool2o`0000Gooooo0_l0
0004ooooo`?o00001?ooool2o`0000[ooooo0_l0002Wooooo`00Woooool2o`0000Gooooo0_l00004
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00gooooo0_l0002Zooooo`00[?oo
ool00ol0003oooooooooo`0=ooooo`;o0000Z_ooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool02_ooool2o`000:gooooo002/ooooo`03o`000?oooooooooo00[o
oooo0_l0002]ooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`03o`000?oooooooooo0;Wooooo002Pooooo`;o00002_ooool00ol0003oooooooooo`2ioooo
o`00X?ooool2o`0000[ooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo0ol0002iooooo`00Soooool2o`0001_ooooo00?o0000ooooooooool0^Oooool008oooooo
0_l0000Kooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`;o0000^_ooool00:cooooo0_l0002jooooo`00X_ooool4o`000003oa0@4?oooooooooo00?o
oooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000
ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo00?o0000oooooooo
ool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:;ooooo00?oEEEEofIVI_l00000`ooo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:[ooooo00Co
410@o`000?l0003o0000^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000
ooooooooool0^_ooool00:_ooooo00Ko0000ogMgMol0003o0000oeEEEOo^k^jgooooo`00Zoooool0
1_l0003oEEEEonk^k_ooooooMgMgoeEEEKOooooo002[ooooo`03o`000?o^k^kooooo00;ooooo00?o
0000ooooooooool0]Oooool00:_ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`2e
ooooo`00Zoooool01_l0003oEEEEonk^k_ooooooMgMgofIVI[Oooooo002Zooooo`03oa0@4?l0003o
MgMg00;o000000?oIVIVonk^k_ooool0]_ooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.40285 .73268 Mdot
.58612 .23504 Mdot
.44634 .4543 Mdot
.54798 .4411 Mdot
.43545 .23683 Mdot
.63517 .50578 Mdot
.4654 .33194 Mdot
.68541 .28901 Mdot
.37173 .39936 Mdot
.56437 .51616 Mdot
.44802 .75832 Mdot
.71454 .37691 Mdot
.61659 .73035 Mdot
.49737 .7675 Mdot
.70431 .35793 Mdot
.42831 .66225 Mdot
.60872 .56172 Mdot
.60451 .75672 Mdot
.57404 .57566 Mdot
.63527 .26515 Mdot
.61505 .72759 Mdot
.64681 .39248 Mdot
.65297 .43528 Mdot
.58604 .79053 Mdot
.72808 .55983 Mdot
.50632 .80729 Mdot
.41109 .48369 Mdot
.57748 .49941 Mdot
.65884 .32113 Mdot
.58364 .23341 Mdot
.59181 .7713 Mdot
.37746 .31152 Mdot
.60827 .16148 Mdot
.531 .79097 Mdot
.39976 .34703 Mdot
.45964 .06808 Mdot
.65041 .72054 Mdot
.54141 .31895 Mdot
.66558 .34981 Mdot
.72998 .44093 Mdot
.726 .59958 Mdot
.41917 .76595 Mdot
.55635 .23131 Mdot
.38976 .36704 Mdot
.44626 .87683 Mdot
.58689 .41687 Mdot
.54175 .65437 Mdot
.39426 .80535 Mdot
.46657 .15612 Mdot
.63092 .26395 Mdot
.40995 .87082 Mdot
.6944 .50265 Mdot
.76614 .62551 Mdot
.46093 .1347 Mdot
.51848 .16814 Mdot
.47073 .02218 Mdot
.68807 .29717 Mdot
.6083 .57357 Mdot
.52981 .91946 Mdot
.48178 .89574 Mdot
.59197 .45738 Mdot
.43599 .98181 Mdot
.66426 .34938 Mdot
.53103 .61628 Mdot
.55747 .10066 Mdot
.42493 .07776 Mdot
.56206 .463 Mdot
.4809 .75823 Mdot
.55816 .36648 Mdot
.55576 .83901 Mdot
.57401 .71112 Mdot
.45356 .66068 Mdot
.56352 .51077 Mdot
.53136 .32526 Mdot
.66385 .34824 Mdot
.49573 .61344 Mdot
.76598 .62609 Mdot
.5911 .54516 Mdot
.69138 .4546 Mdot
.40087 .55336 Mdot
.42414 .86353 Mdot
.56525 .20321 Mdot
.5195 .32655 Mdot
.40141 .66166 Mdot
.61924 .1739 Mdot
.41554 .45755 Mdot
.45465 .19526 Mdot
.49485 .19595 Mdot
.61331 .51682 Mdot
.47393 .75944 Mdot
.727 .56336 Mdot
.68407 .21229 Mdot
.42698 .61943 Mdot
.55506 .30913 Mdot
.46533 .73868 Mdot
.65749 .16924 Mdot
.51047 .74116 Mdot
.42416 .90947 Mdot
.75779 .66006 Mdot
.61176 .56324 Mdot
.38596 .52536 Mdot
.60767 .42864 Mdot
.70513 .35131 Mdot
.41194 .21014 Mdot
.46004 .92499 Mdot
.5005 .84094 Mdot
.55571 .75026 Mdot
.54706 .6861 Mdot
.42481 .60081 Mdot
.557 .8359 Mdot
.54391 .65302 Mdot
.54841 .43872 Mdot
.37204 .38693 Mdot
.54089 .12073 Mdot
.45067 .3193 Mdot
.59381 .51153 Mdot
.51037 .04067 Mdot
.44573 .03764 Mdot
.66946 .65979 Mdot
.62193 .71627 Mdot
.52381 .97373 Mdot
.65311 .58659 Mdot
.66929 .34832 Mdot
.55158 .84483 Mdot
.55177 .50902 Mdot
.5682 .15831 Mdot
.59052 .08357 Mdot
.43816 .1349 Mdot
.53135 .45741 Mdot
.65746 .45751 Mdot
.40096 .27481 Mdot
.72654 .43621 Mdot
.63408 .55831 Mdot
.60052 .32619 Mdot
.68822 .42394 Mdot
.65443 .7177 Mdot
.62393 .24728 Mdot
.56298 .48724 Mdot
.63704 .20704 Mdot
.71348 .38677 Mdot
.36077 .55256 Mdot
.4842 .25244 Mdot
.57674 .46435 Mdot
.60809 .56927 Mdot
.59805 .19994 Mdot
.5805 .12133 Mdot
.36058 .73195 Mdot
.55671 .64709 Mdot
.52938 .25564 Mdot
.54861 .94889 Mdot
.60243 .39901 Mdot
.50512 .23616 Mdot
.57372 .81283 Mdot
.47475 .68605 Mdot
.61942 .62862 Mdot
.68086 .62998 Mdot
.68062 .40458 Mdot
.49188 .02432 Mdot
.6543 .70879 Mdot
.67598 .65082 Mdot
.40719 .65547 Mdot
.69382 .46933 Mdot
.72363 .6314 Mdot
.38729 .31602 Mdot
.52757 .18657 Mdot
.39923 .70451 Mdot
.56176 .09879 Mdot
.41134 .82583 Mdot
.54639 .32999 Mdot
.67504 .65977 Mdot
.57052 .16548 Mdot
.42883 .62584 Mdot
.49428 .22084 Mdot
.43622 .23678 Mdot
.52453 .73657 Mdot
.59718 .14873 Mdot
.63599 .13989 Mdot
.62446 .60342 Mdot
.42938 .47342 Mdot
.65872 .32479 Mdot
.6896 .59754 Mdot
.73451 .49663 Mdot
.47793 .22892 Mdot
.72116 .62509 Mdot
.48367 .71669 Mdot
.37092 .56649 Mdot
.57264 .0645 Mdot
.38234 .26258 Mdot
.72887 .60321 Mdot
.58927 .29664 Mdot
.58775 .89748 Mdot
.60055 .2035 Mdot
.5396 .44808 Mdot
.65122 .22438 Mdot
.68599 .737 Mdot
.71687 .39018 Mdot
.52942 .25344 Mdot
.74735 .3387 Mdot
.46844 .86531 Mdot
.47683 .70093 Mdot
.46483 .69663 Mdot
.43887 .59662 Mdot
.41051 .37695 Mdot
.76148 .38516 Mdot
.38622 .47207 Mdot
.44169 .32975 Mdot
.63252 .55796 Mdot
.55137 .45593 Mdot
.4243 .5046 Mdot
.42486 .67985 Mdot
.65598 .6022 Mdot
.59241 .526 Mdot
.40959 .81874 Mdot
.42681 .34234 Mdot
.39343 .65403 Mdot
.59011 .46087 Mdot
.72223 .63524 Mdot
.45742 .70926 Mdot
.54633 .8074 Mdot
.72419 .40603 Mdot
.59392 .49662 Mdot
.53383 .91192 Mdot
.43042 .88368 Mdot
.39383 .7297 Mdot
.42456 .63345 Mdot
.41257 .64002 Mdot
.57354 .21086 Mdot
.42852 .62612 Mdot
.70712 .36648 Mdot
.485 .75816 Mdot
.50575 .5938 Mdot
.75672 .37494 Mdot
.53017 .22262 Mdot
.41244 .42958 Mdot
.56308 .92779 Mdot
.52292 .27449 Mdot
.44375 .1189 Mdot
.6509 .61017 Mdot
.39245 .34571 Mdot
.44312 .99128 Mdot
.62846 .42441 Mdot
.37793 .45215 Mdot
.57548 .7074 Mdot
.39243 .19698 Mdot
.50071 .71005 Mdot
.6889 .57125 Mdot
.5877 .35833 Mdot
.57973 .69652 Mdot
.67111 .36914 Mdot
.69741 .70774 Mdot
.4434 .34443 Mdot
.53387 .41433 Mdot
.68292 .60645 Mdot
.51494 .79004 Mdot
.47567 .20895 Mdot
.57367 .25838 Mdot
.48082 .64572 Mdot
.66627 .25448 Mdot
.44948 .95648 Mdot
.5043 .17883 Mdot
.4122 .4337 Mdot
.38005 .5749 Mdot
.50355 .33061 Mdot
.5898 .35493 Mdot
.45593 .8851 Mdot
.53247 .68136 Mdot
.61482 .37641 Mdot
.50793 .08532 Mdot
.46409 .83105 Mdot
.51617 .09259 Mdot
.54814 .21383 Mdot
.56453 .5304 Mdot
.42472 .24379 Mdot
.68189 .62794 Mdot
.50435 .25941 Mdot
.44905 .78985 Mdot
.39168 .78942 Mdot
.42712 .69325 Mdot
.62352 .61395 Mdot
.67557 .37481 Mdot
.53019 .5746 Mdot
.47507 .23165 Mdot
.65723 .69976 Mdot
.69627 .32462 Mdot
.53787 .71069 Mdot
.51804 .54916 Mdot
.45208 .78876 Mdot
.49623 .06668 Mdot
.55817 .31964 Mdot
.46841 .92571 Mdot
.56626 .05807 Mdot
.56361 .87367 Mdot
.68849 .31182 Mdot
.57342 .85758 Mdot
.43711 .52758 Mdot
.56761 .87122 Mdot
.55718 .93102 Mdot
.43986 .0869 Mdot
.6977 .33784 Mdot
.35414 .33619 Mdot
.41115 .31319 Mdot
.61578 .36385 Mdot
.4193 .18423 Mdot
.3864 .23499 Mdot
.72972 .55871 Mdot
.52024 .7157 Mdot
.40442 .84875 Mdot
.48898 .82952 Mdot
.52269 .56136 Mdot
.65945 .57223 Mdot
.60171 .60952 Mdot
.63649 .67436 Mdot
.57996 .91059 Mdot
.46384 .29539 Mdot
.51899 .84999 Mdot
.47469 .86116 Mdot
.58808 .13936 Mdot
.52014 .38495 Mdot
.73418 .50346 Mdot
.65604 .7875 Mdot
.39144 .13986 Mdot
.53115 .65078 Mdot
.63148 .58598 Mdot
.39451 .57744 Mdot
.68049 .40989 Mdot
.40476 .52255 Mdot
.48351 .69938 Mdot
.44156 .4145 Mdot
.57645 .70164 Mdot
.71252 .36097 Mdot
.68671 .57563 Mdot
.46532 .73934 Mdot
.66296 .51074 Mdot
.53391 .5103 Mdot
.438 .58948 Mdot
.57988 .22189 Mdot
.63495 .48487 Mdot
.53113 .19199 Mdot
.40851 .66576 Mdot
.40525 .48806 Mdot
.77515 .57886 Mdot
.50681 .8027 Mdot
.5174 .1349 Mdot
.53345 .60222 Mdot
.54707 .08516 Mdot
.41478 .59314 Mdot
.60772 .21902 Mdot
.59421 .25681 Mdot
.43755 .31499 Mdot
.56467 .34302 Mdot
.36091 .56108 Mdot
.715 .37575 Mdot
.56175 .88078 Mdot
.49084 .06683 Mdot
.40244 .39348 Mdot
.50298 .84166 Mdot
.56284 .15385 Mdot
.5657 .29161 Mdot
.71322 .37037 Mdot
.42874 .02055 Mdot
.38096 .37993 Mdot
.72392 .42312 Mdot
.73418 .5164 Mdot
.71818 .64545 Mdot
.44014 .39005 Mdot
.49533 .16781 Mdot
.71296 .38646 Mdot
.67637 .27301 Mdot
.45109 .34083 Mdot
.5119 .89621 Mdot
.52572 .76609 Mdot
.62979 .58698 Mdot
.38893 .60302 Mdot
.39986 .82742 Mdot
.43601 .13407 Mdot
.6189 .78738 Mdot
.68995 .49426 Mdot
.64781 .40782 Mdot
.58731 .84478 Mdot
.65266 .42671 Mdot
.73019 .50921 Mdot
.65319 .70677 Mdot
.60468 .68289 Mdot
.50322 .63235 Mdot
.68861 .72093 Mdot
.614 .50699 Mdot
.43769 .4601 Mdot
.73557 .52319 Mdot
.54898 .84913 Mdot
.48587 .69766 Mdot
.54563 .37079 Mdot
.56278 .68714 Mdot
.4225 .33094 Mdot
.37742 .68589 Mdot
.3946 .74673 Mdot
.51859 .97592 Mdot
.73488 .51038 Mdot
.56673 .72105 Mdot
.77725 .52122 Mdot
.53428 .78888 Mdot
.52948 .72616 Mdot
.47436 .8091 Mdot
.49609 .3705 Mdot
.70232 .3329 Mdot
.71137 .36641 Mdot
.41109 .51333 Mdot
.42363 .41029 Mdot
.44074 .24874 Mdot
.43528 .29582 Mdot
.63812 .82684 Mdot
.55042 .29628 Mdot
.39069 .2839 Mdot
.49315 .26373 Mdot
.50873 .24348 Mdot
.52363 .40238 Mdot
.50822 .21374 Mdot
.55318 .74828 Mdot
.45118 .22728 Mdot
.45924 .28392 Mdot
.5372 .96027 Mdot
.63544 .20398 Mdot
.50261 .51846 Mdot
.41598 .23948 Mdot
.55611 .74928 Mdot
.60141 .68621 Mdot
.49872 .81389 Mdot
.5205 .26843 Mdot
.67865 .74623 Mdot
.70181 .23755 Mdot
.45811 .1018 Mdot
.61413 .92245 Mdot
.40907 .22141 Mdot
.5042 .30874 Mdot
.37675 .32899 Mdot
.71615 .40081 Mdot
.44181 .74256 Mdot
.58776 .24581 Mdot
.7732 .59052 Mdot
.43011 .35626 Mdot
.51748 .60186 Mdot
.50306 .77877 Mdot
.37968 .57001 Mdot
.41167 .67981 Mdot
.72311 .28242 Mdot
.44554 .67982 Mdot
.40744 .2902 Mdot
.41753 .76068 Mdot
.49218 .72978 Mdot
.44846 .32853 Mdot
.52828 .3146 Mdot
.68466 .28799 Mdot
.50223 .32409 Mdot
.68878 .43194 Mdot
.54918 .17463 Mdot
.47411 .89557 Mdot
.54414 .12639 Mdot
.51559 .89024 Mdot
.58508 .67317 Mdot
.6069 .10057 Mdot
.55319 .40172 Mdot
.71608 .3726 Mdot
.69597 .71298 Mdot
.53476 .67361 Mdot
.56332 .87786 Mdot
.48211 .83136 Mdot
.60923 .47561 Mdot
.60546 .21479 Mdot
.38566 .48342 Mdot
.56877 .60523 Mdot
.56872 .35517 Mdot
.52678 .79939 Mdot
.41505 .94006 Mdot
.58481 .29032 Mdot
.49865 .60301 Mdot
.51832 .17138 Mdot
.40001 .46356 Mdot
.43926 .39411 Mdot
.52519 .66814 Mdot
.45358 .1418 Mdot
.60109 .32526 Mdot
.4303 .5508 Mdot
.54744 .7236 Mdot
.43001 .06637 Mdot
.43169 .24814 Mdot
.4925 .88497 Mdot
.57566 .44582 Mdot
.57429 .46203 Mdot
.49765 .33383 Mdot
.50546 .35891 Mdot
.58294 .22829 Mdot
.54431 .89649 Mdot
.39708 .24049 Mdot
.56721 .40332 Mdot
.63966 .27907 Mdot
.73072 .45428 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Dooooo`;o0000
3?ooool2o`0000Sooooo00?o0000ooooooooool0^Oooool009Cooooo0_l0000<ooooo`;o00001Ooo
ool2o`000004ooooool0003o0000o`000;Wooooo002Yooooo`;o000000?oooooo`000?ooool0^_oo
ool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool009[o
oooo0_l0000@ooooo`03o`000?oooooooooo0;Wooooo002Jooooo`;o00004?ooool00ol0003ooooo
ooooo`02o`000;Oooooo002/ooooo`03o`000?oooooooooo00;o0000]oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00
[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0Booooo`;o0000YOoo
ool00:cooooo00?o0000ooooooooool04_ooool2o`000:Gooooo002/ooooo`03o`000?oooooooooo
01Gooooo0_l0002Rooooo`00U?ooool2o`0000Sooooo0_l00009ooooo`Co00005oooool2o`000:;o
oooo002Dooooo`;o00002?ooool2o`0000Wooooo1?l0002kooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool3o`000;Wooooo002Cooooo`;o00005oooool00ol0003oooooooooo`2ioooo
o`00Toooool2o`0001Oooooo00?o0000ooooooooool0^Oooool00:cooooo00Co0000ooooool0003o
00002oooool2o`0000cooooo0_l0002Mooooo`00V?ooool2o`0001;ooooo00Co0000ooooool0003o
00002oooool2o`0000cooooo0_l0002Mooooo`00V?ooool2o`0001;ooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool00_ooool2o`000;Gooooo002/ooooo`03o`000?oooooo
oooo00;ooooo0_l0002eooooo`00[?ooool3o`00013ooooo0ol0000=ooooo`;o0000Uoooool009ko
oooo0_l0000<ooooo`03o`000?oooooooooo013ooooo0ol0000=ooooo`;o0000Uoooool009kooooo
0_l0000<ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo0ol000000oo^k^koooooooooo`03oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2iooooo`00ROooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`;o000000?oEEEEojVYZOooool01oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00[ooooo0_l0000;ooooo`;o0000X?ooool0
087ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08
ooooo`03o`000?oooooooooo00?ooooo0ol0000:ooooo`;o00002oooool2o`000:3ooooo0029oooo
o`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool02oooool2o`000:cooooo0029ooooo`05o`000?oooooooooo
ooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`0;ooooo`;o0000[?ooool008Wooooo00Go410@oooooooooooooooooa0@
4008ooooo`?o00000oooool00onYZJWoMgMgooooo`02o`000003ooooool0003ooooo00Sooooo00?o
0000ooooooooool00_ooool2o`000;Gooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?oo
ool3o`000006oa0@4?oooooooooooooooolb<S;ooooo0_l000000ooooooo0000ooooo`08ooooo`03
o`000?oooooooooo00;ooooo0_l0002eooooo`00R?ooool2o`000004oc8b<_l0003o<S8bonk^kP_o
oooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`0Jooooo`;o00003Oooool2o`0008ko
oooo0028ooooo`;o00004_ooool2o`0000kooooo00?o0000ooooooooool06_ooool2o`0000gooooo
0_l0002>ooooo`00W?ooool2o`0000kooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool07Oooool2o`0009[ooooo002/ooooo`?o00007Oooool2o`0009[ooooo002Qooooo`;o
00002Oooool00ol0003oooooooooo`0Aooooo`;o0000Y_ooool00:7ooooo0_l00009ooooo`03o`00
0?oooooooooo017ooooo1?l0002Tooooo`00[?ooool00ol0003oooooooooo`0Cooooo`;o00002ooo
ool2o`0009Oooooo002/ooooo`03o`000?oooooooooo023ooooo0_l0002Gooooo`00Z_ooool3o`00
00Gooooo0_l0000?ooooo`;o0000Xoooool00:[ooooo0ol00005ooooo`;o00003oooool2o`0001_o
oooo0_l00026ooooo`00[?ooool00ol0003oooooooooo`03ooooo`;o00007oooool2o`0000_ooooo
0_l00026ooooo`00[?ooool3o`0000?ooooo0_l00008ooooo`;o00005Oooool2o`0009?ooooo002/
ooooo`?o00003Oooool2o`000:[ooooo002/ooooo`?o0000^Oooool0097ooooo0_l0000Iooooo`03
o`000?oooooooooo0;Wooooo002Aooooo`;o00006Oooool00ol0003oooooooooo`06ooooo`;o0000
/Oooool00:cooooo00?o0000ooooooooool01_ooool3o`000;3ooooo002Mooooo`;o00003Oooool0
0ol0003oooooooooo`07ooooo`;o0000/?ooool008Sooooo0_l0000Cooooo`;o00002oooool3o`00
0;_ooooo0028ooooo`;o00008?ooool5o`0001gooooo0_l0002Jooooo`00[?ooool00ol0003ooooo
ooooo`0Booooo`;o00002Oooool3o`0000Wooooo0_l0002>ooooo`00[?ooool00ol0003ooooooooo
o`0Booooo`;o00002_ooool2o`0000Wooooo0ol0002=ooooo`00S_ooool2o`0001Cooooo0_l00006
ooooo`03o`000?oooooooooo02[ooooo0_l0002=ooooo`00S_ooool2o`0001Cooooo0_l00006oooo
o`04o`000?oooooo0000o`0001Cooooo0_l0000Rooooo`;o0000O_ooool00:cooooo00Co0000oooo
ool0003o00002oooool2o`0000Oooooo0_l00008ooooo`;o00006?ooool2o`0007kooooo002/oooo
o`03o`000?oooooooooo00cooooo0_l0000Aooooo`?o0000Uoooool008kooooo0_l0000Jooooo`?o
00002Oooool2o`0000kooooo0_l00007ooooo`;o0000Uoooool008kooooo0_l0000Jooooo`Go0000
1oooool2o`0000kooooo0_l0000Eooooo`;o0000ROooool009_ooooo0_l0000?ooooo`03o`000?oo
oooooooo01Sooooo0_l0000Dooooo`;o0000ROooool009_ooooo0_l00006ooooo`?o00001_ooool0
0ol0003oooooooooo`0?ooooo`;o00001oooool2o`0009oooooo002Sooooo`?o00001_ooool00ol0
003oooooooooo`0?ooooo`;o00001oooool2o`0009oooooo0026ooooo`;o00003_ooool3o`0001?o
oooo0ol0000Hooooo`?o00009?ooool2o`0007Sooooo0026ooooo`;o00000_ooool2o`0000Cooooo
0_l00004ooooo`?o00004oooool3o`0001Wooooo0_l0000Tooooo`;o0000N?ooool008[ooooo0_l0
0004ooooo`;o000000Co<S8bo`000?l0003ok^k^1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`04o`000?oooooo0000o`000;Sooooo002Aooooo`05ogMgMonHV9So0000o`00
0?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool01?l0003oooooo`000?l0000I
ooooo`;o0000WOooool008Wooooo1_l00002ooooo`04oa0@4?ooooooooooooooo`;o000000?ooooo
o`000?l000003?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01[ooooo0_l00009
ooooo`;o0000T_ooool0097ooooo00Co0000oooooooooooooooo0_l000000ooooooo0000o`00000;
ooooo`03ogMgMol0003o000000Cooooo0ol0000Uooooo`;o0000T_ooool0097ooooo00Go0000oooo
ooooooooooooo`00000<ooooo`04o`000?lQ8B7o0000oc8b<P;o00001?ooool00ol0003ooooooooo
o`06ooooo`;o0000:oooool2o`0008Cooooo002Aooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo0_l0000=ooooo`;o00001Ooo
ool2o`0001Gooooo0_l00024ooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o
0000ooooooooool01oooool3o`0001Gooooo0_l00005ooooo`;o0000Voooool008Gooooo0_l0000:
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000?ooooo0_l000001?oooooo0000o`00
0?l0000Xooooo`?o0000S_ooool008Gooooo0_l0000Rooooo`;o000000?oooooo`000?ooool0:Ooo
ool3o`0008kooooo002/ooooo`03o`000?oooooooooo00?ooooo0_l0002dooooo`00[?ooool00ol0
003oooooooooo`03ooooo`;o0000<_ooool2o`00083ooooo002;ooooo`;o00007oooool3o`0000Co
oooo0_l0000aooooo`;o0000P?ooool008_ooooo0_l0000Oooooo`03o`000?oooooooooo00Cooooo
0_l0000Uooooo`;o0000S?ooool00:cooooo00?o0000ooooooooool0:oooool2o`0001Wooooo0_l0
001aooooo`00Qoooool2o`0001Gooooo0_l0000<ooooo`03o`000?oooooooooo04Kooooo0_l0001a
ooooo`00Qoooool2o`0001Gooooo0_l0000<ooooo`03o`000?oooooooooo03[ooooo0_l0001moooo
o`00SOooool2o`0001gooooo00?o0000ooooooooool04_ooool2o`0000Gooooo0_l0000Oooooo`;o
0000OOooool008gooooo0_l0000Aooooo`;o00002_ooool00ol0003oooooooooo`0Booooo`;o0000
1Oooool2o`0009kooooo002Fooooo`;o00002?ooool2o`0000[ooooo00?o0000ooooooooool03Ooo
ool2o`0000_ooooo0_l0000Oooooo`;o0000O?ooool009Kooooo0_l0000Dooooo`?o00003Oooool2
o`0000_ooooo0_l0000Oooooo`;o0000O?ooool00:cooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool0^Oooool00:cooooo0ol0000?ooooo`;o0000Z?ooool008?ooooo0_l0
0009ooooo`;o00007?ooool3o`0000oooooo0_l0000Zooooo`;o0000O?ooool008?ooooo0_l00000
0ooooooo0000o`000006ooooo`;o00001oooool2o`0001?ooooo00?o0000ooooooooool01_ooool2
o`0003?ooooo0_l0001looooo`00Q_ooool2o`0000oooooo0_l00002ooooo`;o00003oooool00ol0
003oooooooooo`06ooooo`;o00000_ooool2o`0000Cooooo0_l0002Wooooo`00Voooool2o`0000oo
oooo00?o0000ooooooooool02_ooool2o`0000Cooooo0_l0000Oooooo`;o0000Q_ooool00:cooooo
0ol00007ooooo`;o00005Oooool2o`00017ooooo0_l0000:ooooo`;o0000N_ooool009_ooooo0_l0
000?ooooo`;o00001?ooool2o`0000;ooooo0_l0000Eooooo`;o00004Oooool2o`0000[ooooo0_l0
001jooooo`00Poooool2o`0000gooooo0_l00004ooooo`;o000000?oooooo`000?l000003oooool3
o`0000?ooooo0_l00007ooooo`;o00004?ooool2o`0009Wooooo0023ooooo`;o00003Oooool2o`00
00Cooooo0_l00006ooooo`;o00002Oooool4o`0000cooooo0_l0000aooooo`;o0000N?ooool007_o
oooo0_l0000Sooooo`;o00002Oooool2o`00043ooooo0ol0001hooooo`00Noooool2o`0001kooooo
0_l0000?ooooo`03o`000?oooooooooo03kooooo0_l0000>ooooo`;o0000JOooool009?ooooo0_l0
0006ooooo`;o00003oooool00ol0003oooooooooo`0Booooo`;o0000>_ooool2o`0006Wooooo0028
ooooo`Co00001oooool2o`0000Cooooo0_l0000Aooooo`03o`000?oooooooooo01;ooooo0_l0002U
ooooo`00R?ooool4o`0000gooooo0_l0000Aooooo`03o`000?oooooooooo03?ooooo0ol00023oooo
o`00[?ooool3o`0003?ooooo0ol0000:ooooo`;o0000Moooool00:cooooo00?o0000ooooooooool0
4oooool2o`0000Gooooo0_l0000Tooooo`;o0000Moooool009Cooooo0_l0000Fooooo`?o00004ooo
ool2o`0000Gooooo0_l0000Tooooo`;o0000Moooool009Cooooo0_l0000Fooooo`?o00006_ooool2
o`0002Cooooo0_l000000ooooooo0000o`00001dooooo`00[?ooool00ol0003oooooooooo`0Soooo
o`;o00007_ooool2o`0007Cooooo0027ooooo`;o000000Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo013ooooo0_l0000Aooooo`;o00007?ooool3o`0007Gooooo0027ooooo`;o000000GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool00_ooool3o`0000kooooo0_l00002ooooo`;o00008oooool2o`0000[ooooo1?l0
001dooooo`00POooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00Co0000oooooooooooooooo0ol0000>ooooo`;o00009oooool2o`0000cooooo
0ol0001cooooo`00ROooool01?l0003oooooooooooooool3o`0000_ooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o00008_ooool2o`0001?ooooo0_l0000:ooooo`?o0000
2oooool2o`0006Kooooo0024ooooo`;o00000oooool01?l0003oooooooooooooool3o`0000cooooo
00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool08_ooool2o`0001?ooooo0_l0000:ooooo`?o00002oooool2o`0006Kooooo0024ooooo`;o0000
0oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`03ooooo`;o0000C_ooool2o`0006Cooooo0021ooooo`;o00001_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool0
0ol0003oooooooooo`03ooooo`;o0000?_ooool2o`0000kooooo0_l0001Tooooo`00POooool2o`00
01Gooooo0_l0000Booooo`03o`000?oooooooooo04?ooooo0ol0001cooooo`00Roooool2o`0000_o
oooo0_l0000Booooo`03o`000?oooooooooo02gooooo0_l0000Eooooo`;o0000Loooool008_ooooo
0_l0000;ooooo`;o00004_ooool00ol0003oooooooooo`0]ooooo`;o0000R_ooool0087ooooo0_l0
000Yooooo`?o00007_ooool2o`0002Cooooo0_l0001cooooo`00POooool2o`0002Wooooo00?o0000
ooooooooool01?ooool2o`0000Sooooo0_l00003ooooo`;o00002Oooool2o`0001Sooooo0_l0000:
ooooo`;o0000Loooool00:cooooo00?o0000ooooooooool01?ooool2o`0000Sooooo0_l00003oooo
o`;o00008oooool2o`0000gooooo0_l0001`ooooo`00T_ooool2o`0001Sooooo00?o0000oooooooo
ool0;Oooool2o`0000Wooooo0_l0000=ooooo`;o0000L?ooool009;ooooo0_l0000Hooooo`03o`00
0?oooooooooo02gooooo0_l00009ooooo`;o0000Ooooool009Sooooo0_l0000Booooo`03o`000?oo
oooooooo00Sooooo0_l0002_ooooo`00V?ooool2o`0001;ooooo00?o0000ooooooooool02?ooool2
o`0000oooooo0_l0002Nooooo`00[?ooool00ol0003oooooooooo`0Iooooo`;o0000W_ooool00:co
oooo0ol0000Wooooo`;o00004_ooool2o`0000Wooooo0_l0001aooooo`00[?ooool00ol0003ooooo
ooooo`0Pooooo`;o00001Oooool2o`0000Kooooo0_l0000:ooooo`;o00002Oooool2o`00077ooooo
002?ooooo`;o00006oooool00ol0003oooooooooo`0Pooooo`;o00003Oooool2o`0008Sooooo002?
ooooo`;o00006oooool00ol0003oooooooooo`0kooooo`;o0000O?ooool008oooooo0_l0000Koooo
o`03o`000?oooooooooo02oooooo0_l0000:ooooo`;o00002_ooool2o`00073ooooo002/ooooo`03
o`000?oooooooooo00gooooo0_l0000Pooooo`;o00005_ooool3o`0006oooooo002/ooooo`03o`00
0?oooooooooo00cooooo0ol0000iooooo`;o0000Koooool00:cooooo00?o0000ooooooooool03?oo
ool2o`0000Sooooo0_l0002Qooooo`00[?ooool00ol0003oooooooooo`0:ooooo`;o00002_ooool2
o`000:7ooooo0023ooooo`;o00009oooool3o`0000[ooooo0_l0002]ooooo`00Poooool2o`0001Go
oooo0_l0000@ooooo`03o`000?oooooooooo00kooooo0_l0000/ooooo`;o00002oooool2o`0006ko
oooo002@ooooo`;o00002?ooool2o`00013ooooo00?o0000ooooooooool01oooool2o`0000Gooooo
0_l0000;ooooo`;o00005?ooool2o`0000Wooooo0_l0000;ooooo`;o0000K_ooool000Wooooo1?l0
00000ol@413oooooooooo`0Fooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo
00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000?ooooo1?l000000olb<S;ogMgMoooo
o`02o`0001?ooooo00?o0000ooooooooool01oooool2o`0000cooooo0_l000000oooooook^k^oc8b
<P03o`0000Gooooo0_lQ8B44ooooo`Go00001?ooool3o`000003oc8b<_oMgMgooooo00kooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06?ooool4o`000003oa0@4?oooooooooo01;ooooo000;oooo
o`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool0
0omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00?oV9RHob4Q8Oo^k^h00_l00007ooooo`03ogMgMolb<S;ooooo00;o0000
4oooool00ol0003oooooooooo`0Aooooo`;o00000_ooool3o`000005ogMgMonHV9So0000o`000?mg
MgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo
00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01ooo
ool00omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo0006o`0000Gooooo00?o0000
ooooooooool04?ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmE
EEGooooo00Sooooo00?o0000ooooooooool01Oooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400@ooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@
41003?ooool01?nHV9So8B4Qo`000?l00008ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool04Oooool2o`0000?ooooo0_l000001Ol@413ooooooooooooooooo410@00cooooo00?oV9RH
ob4Q8Oo^k^h02Oooool00ol0003oooooooooo`0=ooooo`05oa0@4?ooooooooooooooool@41004?oo
ool00ol0003oooooooooo`0=ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEE
ooooo`08ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05?ooool000_ooooo00?o
0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool0
1_ooool00omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo
<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07oooo
o`03ogMgMolb<S;ooooo01Gooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo
000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`06ooooo`;o00001_ooool0
1Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooo
oooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`0Iooooo`03o`00
0?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go0000oooooooooooooooo
o`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05
o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000
ooooooooooooooooo`000009ooooo`;o00000oooool00omgMgOoIVIVooooo`03ooooo`03o`000?lQ
8B7o000000;o00005_ooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool00000
3_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01oooool2o`0000Ko
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<01[ooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?oo
ool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003ooooo
ooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0Aooooo`05
oa0@4?ooooooooooooooool@41002Oooool2o`0000Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02o`0001Kooooo0ol0000Hooooo`05oa0@4?ooooooooooooooool@41001?ooool2
o`0000Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Aooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@4100
3_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
5?ooool000_ooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`;o00001Oooool01Ol0003o^[Zj
oooooonHV9So410@00Cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@
oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05?oo
ool000Wooooo00?oEEEEofIVI_l000006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol0
0004ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0000Goooo
o`03o`000?oooooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co0000
4?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00006Oooool00omEEEGo
IVIVo`00000Fooooo`00Q_ooool2o`0000Kooooo0_l0000Looooo`03o`000?oooooooooo02Wooooo
0_l0002>ooooo`00Q_ooool2o`0000Cooooo1?l0000Looooo`03o`000?oooooooooo017ooooo0_l0
000Fooooo`;o0000S_ooool008cooooo0_l0000Nooooo`03o`000?oooooooooo017ooooo0_l0002K
ooooo`;o00000_ooool2o`0000Gooooo002/ooooo`03o`000?oooooooooo03_ooooo0_l0001aoooo
o`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1Oooool00:cooooo00?o0000ooooooooool07?ooool2
o`0001gooooo0_l0000=ooooo`;o0000Hoooool01?oMgMgo0000oa0@4?o<c<`6ooooo`001ooooooo
o`0004co00003?ooool01?o^k^ko8B4Qoa0@4?o^k^h6ooooo`001oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo0ol00008
ooooo`04o`000?oooooo0000o`0000Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0:ooooo`04ob4Q8OmgMgOoMgMgoc8b<PKooooo0007ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00gooooo0_l0
000Gooooo`03o`000?oooooooooo02;ooooo0_l00003ooooo`04o`000?oooooo0000o`0001;ooooo
0_l0000;ooooo`;o00001?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool02Oooool2o`0000;ooooo0_l00005ooooo`00Toooool2o`0001Oooooo00?o
0000ooooooooool02?ooool2o`0000Cooooo0_l0000Booooo`;o00001Oooool2o`0001kooooo0ol0
001]ooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool02?ooool2o`0000Cooooo0_l00002
ooooo`;o00002?ooool2o`0001Cooooo0_l0000Eooooo`?o0000KOooool008kooooo0_l0000Loooo
o`03o`000?oooooooooo01;ooooo0_l00008ooooo`;o00005?ooool2o`0001Kooooo0_l0001]oooo
o`00[?ooool2o`0001?ooooo0_l0000>ooooo`;o00009_ooool2o`0006gooooo002<ooooo`;o0000
7_ooool2o`0002?ooooo0_l0000dooooo`;o0000Goooool008Kooooo0_l00004ooooo`;o00007_oo
ool3o`0004[ooooo0_l0000<ooooo`;o0000Goooool008Kooooo0_l0000?ooooo`;o00004oooool0
0ol0003oooooooooo`0Kooooo`;o0000;Oooool2o`0006gooooo002Gooooo`;o00004oooool00ol0
003oooooooooo`0Booooo`;o00001oooool2o`0009cooooo002/ooooo`03o`000?oooooooooo01;o
oooo0_l0002Uooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0Koooo
o`;o0000W?ooool00:cooooo00?o0000ooooooooool00oooool2o`0001Kooooo0_l0002Looooo`00
O_ooool2o`0001Gooooo0_l0000Eooooo`?o00000oooool2o`000;Cooooo001nooooo`;o00002ooo
ool2o`0000Sooooo0_l0000Eooooo`03o`000?oooooooooo0;Wooooo002;ooooo`;o00007oooool0
0ol0003oooooooooo`0Xooooo`?o00007Oooool2o`0006oooooo001nooooo`;o0000;?ooool00ol0
003oooooooooo`04ooooo`;o00006_ooool2o`0000Kooooo0ol0000Mooooo`;o0000Koooool007ko
oooo0_l0000/ooooo`03o`000?oooooooooo00Cooooo0_l0000Jooooo`?o00009?ooool3o`0006oo
oooo0021ooooo`;o0000:Oooool00ol0003oooooooooo`0Qooooo`;o00009?ooool2o`00073ooooo
0021ooooo`;o000000?oooooo`000?l000009_ooool00ol0003oooooooooo`0Pooooo`;o0000Uooo
ool008Cooooo0_l0000Vooooo`03o`000?oooooooooo023ooooo0_l0000?ooooo`;o00002?ooool2
o`0007cooooo0024ooooo`;o00009_ooool3o`0000Oooooo0_l0000<ooooo`;o00002Oooool2o`00
00oooooo0_l00007ooooo`?o0000O?ooool008Cooooo0_l00003ooooo`;o00008Oooool00ol0003o
ooooooooo`07ooooo`;o00003?ooool2o`0002?ooooo0_l0000Kooooo`;o0000H?ooool008Wooooo
0_l0000Qooooo`03o`000?oooooooooo05Oooooo0_l0001Pooooo`00[?ooool00ol0003ooooooooo
o`0Xooooo`;o0000Soooool00:cooooo00?o0000ooooooooool09oooool3o`0000Gooooo0_l00028
ooooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool09oooool2o`0000Kooooo0_l0000Voooo
o`;o0000H?ooool008oooooo0_l00006ooooo`;o00004oooool3o`0005Oooooo0_l0001Pooooo`00
Soooool2o`0000Kooooo0_l0000Cooooo`?o0000>oooool2o`0007cooooo002Cooooo`;o00000_oo
ool2o`0001?ooooo0ol0000kooooo`;o00002_ooool2o`00073ooooo0027ooooo`;o00002_ooool2
o`0001Kooooo0_l00004ooooo`;o00001?ooool2o`0001cooooo0_l00008ooooo`;o00005Oooool3
o`0006oooooo0027ooooo`;o00008_ooool2o`0000Cooooo0_l00004ooooo`;o00002Oooool2o`00
017ooooo0_l00008ooooo`;o00001oooool2o`0000gooooo0_l0001_ooooo`00[?ooool00ol0003o
ooooooooo`0Cooooo`;o00002Oooool2o`0000kooooo0_l00009ooooo`;o0000O_ooool00:[ooooo
0ol0000Pooooo`;o00003_ooool2o`0008Wooooo002Zooooo`?o00002Oooool2o`0001cooooo0_l0
002Booooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_l00004ooooo`Go00001?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool01oooool2o`0001cooooo
0_l0002Booooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l00004ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;Wo
oooo0029ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03
o`000?oooooooooo00?ooooo0ol00016ooooo`;o00003?ooool2o`0006?ooooo0029ooooo`05o`00
0?ooooooooooooooool000001_ooool2o`0000Gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo02Cooooo0_l0000Cooooo`;o00002oooool2o`0000co
oooo0_l0001Sooooo`00ROooool01Ol0003ooooooooooooooooo000000Kooooo0_l00006ooooo`03
ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo
02Cooooo0_l0000Booooo`?o00002oooool2o`0000cooooo0_l0001Sooooo`00ROooool01Ol@413o
oooooooooooooooo410@00Gooooo0_l00008ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01oooool3o`0003Sooooo0_l0000<ooooo`;o0000LOooool008Wooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o00001?ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000
ooooooooool01oooool3o`0004Kooooo0_l0001aooooo`00ROooool01_o^k^ko<S8bo`000?lb<S;o
k^k^ooooo`;o00002?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`00
0?oooooooooo04Kooooo0_l0001aooooo`00Soooool2o`0001_ooooo00?o0000ooooooooool0^Ooo
ool00:Gooooo0_l00005ooooo`03o`000?oooooooooo04Gooooo0_l0001booooo`00YOooool2o`00
00Gooooo00?o0000ooooooooool03oooool2o`0003Cooooo0_l0001booooo`00[?ooool3o`0000Oo
oooo0_l00006ooooo`;o00009_ooool2o`00083ooooo0028ooooo`;o00000oooool2o`0001gooooo
00?o0000ooooooooool01oooool2o`000004ooooool0003o0000o`0002[ooooo0_l00020ooooo`00
R?ooool2o`0000?ooooo0_l0000Mooooo`03o`000?oooooooooo00[ooooo0ol0002/ooooo`00Rooo
ool2o`0000oooooo0_l0000>ooooo`03o`000?oooooooooo03Gooooo0ol0000Jooooo`;o0000IOoo
ool008_ooooo0_l00007ooooo`;o00001_ooool2o`0000kooooo00?o0000ooooooooool0=Oooool3
o`0001[ooooo0_l0001Uooooo`00SOooool2o`0000Gooooo0_l0000Fooooo`03o`000?oooooooooo
0;Wooooo002=ooooo`;o00007Oooool00ol0003oooooooooo`05ooooo`;o0000/_ooool00:cooooo
00?o0000ooooooooool01Oooool2o`000003ooooool0003o000000oooooo0_l0002Nooooo`00[?oo
ool3o`0000Sooooo0_l0000?ooooo`;o00003oooool2o`0008gooooo002>ooooo`;o00000oooool2
o`0000Gooooo0_l0000@ooooo`03o`000?oooooooooo02[ooooo0_l0002=ooooo`00S_ooool2o`00
00?ooooo0_l00005ooooo`;o00004?ooool00ol0003oooooooooo`07ooooo`;o00005_ooool2o`00
09Sooooo0023ooooo`;o00007_ooool2o`0000Oooooo00?o0000ooooooooool01oooool2o`0000?o
oooo0_l0000@ooooo`?o0000V?ooool008?ooooo0_l0000Nooooo`;o00001oooool00ol0003ooooo
ooooo`0<ooooo`;o00000oooool2o`0000_ooooo0_l0002Iooooo`00[?ooool00ol0003ooooooooo
o`0Aooooo`;o0000Y_ooool009Cooooo0_l0000Fooooo`03o`000?oooooooooo0;Wooooo002Doooo
o`;o00002_ooool2o`0000Gooooo0_l00003ooooo`03o`000?oooooooooo01Oooooo0_l0002Poooo
o`00X?ooool2o`0000;ooooo1Ol00003ooooo`?o00005oooool2o`0001Oooooo0_l00027ooooo`00
Y?ooool4o`0000Cooooo00?o0000ooooooooool05_ooool2o`0001Sooooo0_l00027ooooo`00R_oo
ool2o`00023ooooo00?o0000ooooooooool05Oooool3o`0001Oooooo0_l00028ooooo`00R_ooool2
o`0001;ooooo0_l0000<ooooo`;o00005_ooool2o`0001Sooooo0ol0000<ooooo`;o0000NOooool0
09kooooo0_l0000<ooooo`;o00002_ooool2o`0000[ooooo0_l0000Iooooo`;o00002oooool3o`00
07Wooooo002/ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o00002_ooool2o`0000ko
oooo0_l0000Fooooo`;o0000N_ooool00:Kooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo
0_l0000Pooooo`;o00002Oooool2o`0008Oooooo002Vooooo`;o00001?ooool00ol0003ooooooooo
o`0Cooooo`;o00006Oooool4o`0000Wooooo0_l0001looooo`00[?ooool3o`0000cooooo0_l00005
ooooo`;o00006Oooool2o`0000_ooooo0_l0001looooo`00[?ooool00ol0003oooooooooo`06oooo
o`;o00001?ooool2o`0001Gooooo0_l0002Dooooo`00ROooool2o`0001kooooo0_l000000ooooooo
0000ooooo`07ooooo`;o00006oooool2o`0009Cooooo001nooooo`;o00002Oooool4o`0001cooooo
0_l000000ooooooo0000ooooo`0Tooooo`;o0000U?ooool007kooooo0_l0000;ooooo`;o00007ooo
ool00ol0003oooooooooo`05ooooo`;o0000<oooool2o`0007gooooo002Pooooo`;o00002_ooool0
0ol0003oooooooooo`05ooooo`;o0000<oooool2o`0007gooooo002Aooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00_ooool2o`000003oooooolQ8B7o8B4Q00?ooooo0_l000001Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool00_l0002gooooo`00ROooool2o`0000Kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`02ooooo`;o000000?oooooob4Q8OlQ8B402?ooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo00;o0000=_ooool2o`0007oooooo0029ooooo`;o00001_ooool0
1Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0>ooooo`?o00009oooool2o`0007oooooo002Aooooo`05o`000?ooooooooooooooool000003ooo
ool00omgMgOo<S8booooo`04ooooo`?o00003_ooool3o`000:Sooooo002Aooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
3oooool2o`000:Sooooo002Aooooo`05oa0@4?ooooooooooooooool@41001?ooool2o`0000Kooooo
00?o0000ooooooooool01?l00003ooooo`03o`000?oooooooooo01oooooo0_l0002Hooooo`00T?oo
ool2o`000004oiRHV?ooooooV9RHogMgM`Cooooo0_l00006ooooo`Oo00000oooool00ol0003ooooo
ooooo`0Oooooo`;o0000V?ooool0093ooooo0_l000001?lb<S;o0000oc8b<_o^k^h<ooooo`Co0000
1_ooool00ol0003oooooooooo`2iooooo`00TOooool2o`0001Sooooo0_l00007ooooo`;o0000/_oo
ool0097ooooo0_l0000Hooooo`;o00001oooool2o`000;;ooooo002/ooooo`03o`000?oooooooooo
01_ooooo0_l0002Looooo`00[?ooool3o`0001_ooooo0_l0002Looooo`00[?ooool3o`000;Wooooo
002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool009cooooo0_l0000>oooo
o`03o`000?oooooooooo00Sooooo0_l0000Jooooo`;o00002_ooool2o`0008Oooooo0028ooooo`;o
00004Oooool3o`0000kooooo00Co0000oooooooooooooooo0_l00004ooooo`?o00003oooool2o`00
00Wooooo0_l0000:ooooo`;o0000Qoooool008Sooooo0_l0000Aooooo`;o00003oooool01?l0003o
ooooooooooooool2o`0000Cooooo0_l0000@ooooo`;o0000W_ooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo0ol00005ooooo`;o0000/_ooool00:cooooo00Co0000ooooool0003o0000
1?ooool2o`000;;ooooo0029ooooo`;o00008Oooool01?l0003oooooo`000?l0000;ooooo`;o0000
Zoooool008Wooooo0_l0000Hooooo`;o00001oooool01?l0003oooooo`000?l0000;ooooo`;o0000
Zoooool00:?ooooo0_l00007ooooo`03o`000?oooooooooo01Gooooo0_l0002Rooooo`00Zoooool2
o`0001Oooooo0_l0002Rooooo`00S_ooool2o`0001_ooooo0_l0002kooooo`00S_ooool2o`0001co
oooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00Roooool2o`000003ooooool0
003o000001cooooo00?o0000ooooooooool0:_ooool2o`0008gooooo002;ooooo`;o000000?ooooo
o`000?l000004?ooool2o`0000Cooooo1?l00002ooooo`03o`000?oooooooooo02[ooooo0_l0002=
ooooo`00X?ooool2o`0000Cooooo1?l00002ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03
o`000?oooooooooo00oooooo0_l0002Xooooo`00[?ooool00ol0003oooooooooo`0?ooooo`;o0000
Z?ooool00:cooooo0ol0000?ooooo`;o0000Z?ooool00:cooooo0ol0000>ooooo`;o00002Oooool2
o`0009kooooo002<ooooo`;o00007_ooool00ol0003oooooooooo`0=ooooo`?o00002Oooool2o`00
09kooooo002<ooooo`;o00007_ooool3o`0000?ooooo0_l00008ooooo`;o0000Z_ooool00:cooooo
00?o0000ooooooooool00oooool2o`000;Cooooo002/ooooo`03o`000?oooooooooo01Gooooo0_l0
002Rooooo`00Xoooool2o`0000Oooooo00?o0000ooooooooool05Oooool2o`000:;ooooo002Coooo
o`;o00003_ooool2o`0000Oooooo00?o0000ooooooooool0^Oooool008Wooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o00001_ooool00ol0003ok^k^ooooo`03ooooo`Co000000?o<S8bomgM
gOooool01?ooool00ol0003oooooooooo`2iooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg
00;o00000oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool00oooool2o`0000;ooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`2iooooo`00ROooool01Ol@413ooooooooooooooooo410@
00;o00002oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool04_ooool3o`000:Cooooo0029ooooo`05o`000?ooooooooooooooool000003?ooool2o`00
0003ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`0001;ooooo0ol0002Toooo
o`00ROooool01Ol0003ooooooooooooooooo000000cooooo0_l000000omEEEGoc<c<ooooo`03oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Aooooo`;o0000Y_ooool0
08Wooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Aooooo`;o0000Y_ooool008Wooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`07ooooo`;o00000_ooool01?l@413oooooooooooooool2o`0000?ooooo00?o
0000ooooooooool01?ooool2o`000003ooooool0003ooooo01;ooooo0_l0002Vooooo`00ROooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo0_l00002ooooo`Ko00000oooool4o`0000?ooooo0_l0
00000ooooooo0000ooooo`2jooooo`00[?ooool00ol0003oooooooooo`02ooooo`;o0000]Oooool0
0:cooooo00?o0000ooooooooool00_ooool2o`000;Gooooo002Sooooo`;o000000?oooooo`000?l0
00001?ooool00ol0003oooooooooo`02o`0000Wooooo0_l0000=ooooo`;o0000WOooool00:?ooooo
0_l000000ooooooo0000o`000004ooooo`Go00002Oooool2o`0000gooooo0_l0002Mooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00Toooool2o`00
01Oooooo00?o0000ooooooooool0^Oooool009?ooooo0_l0000Gooooo`03o`000?oooooooooo00So
oooo0_l0000=ooooo`;o0000X?ooool00:cooooo00?o0000ooooooooool02?ooool2o`0000gooooo
0_l0002Pooooo`00[?ooool00ol0003oooooooooo`06ooooo`;o0000/Oooool00:cooooo00?o0000
ooooooooool01_ooool2o`0001[ooooo0_l0002Eooooo`00W_ooool2o`0000cooooo0ol0000Roooo
o`;o0000UOooool009kooooo0_l000000ooooooo0000o`000009ooooo`03o`000?oooooooooo017o
oooo0_l0002Vooooo`00XOooool2o`0000Wooooo00?o0000ooooooooool03oooool4o`000:Kooooo
002/ooooo`03o`000?oooooooooo00oooooo0_l0002Xooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool0^Oooool0093ooooo0_l0000Jooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo00gooooo0_l0002Zooooo`00[?ooool3o`0000gooooo0_l0002Zooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00Voooool2o`0000oooooo00?o0000ooooooooool0^Oooool009_ooooo
0_l0000?ooooo`03o`000?oooooooooo00Wooooo0_l0002^ooooo`00[?ooool00ol0003ooooooooo
o`09ooooo`;o0000[_ooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool01?ooool2o`000;?ooooo002/ooooo`?o0000
0oooool3o`000;?ooooo002/ooooo`03o`000?oooooooooo00?ooooo0_l0002dooooo`00U_ooool2
o`0001Cooooo00?o0000ooooooooool0^Oooool009Kooooo0_l0000Dooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Iooooo`;o00004Oooool00ol0003ooooo
ooooo`2iooooo`00VOooool2o`0000Oooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oo
oooooooo0;Wooooo002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool0
0:Cooooo00?o0000ooooooooool01Oooool3o`000;Wooooo002Tooooo`03o`000?oooooooooo0<7o
oooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002T
ooooo`03o`000?oooooooooo0<7ooooo002Rooooo`03oeEEEOmVIVKo00000<?ooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Zooooo`04oa0@4?l0003o0000
o`000;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[o
oooo002[ooooo`06o`000?mgMgOo0000o`000?mEEEGok^k^]oooool00:_ooooo00Ko0000oeEEEOo^
k^koooooogMgMomEEEFgooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo
0;Gooooo002[ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0]Oooool00:_ooooo
00Ko0000oeEEEOo^k^koooooogMgMomVIVJgooooo`00Z_ooool00ol@413o0000ogMgM`02o`000003
ofIVI_o^k^kooooo0;Kooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.54374 .81941 Mdot
.44377 .11357 Mdot
.47122 .63503 Mdot
.48462 .25081 Mdot
.4261 .72961 Mdot
.59748 .30578 Mdot
.44039 .57828 Mdot
.56102 .08901 Mdot
.47537 .97267 Mdot
.53083 .31616 Mdot
.5444 .65619 Mdot
.6253 .17691 Mdot
.66873 .53035 Mdot
.56447 .56776 Mdot
.60748 .15793 Mdot
.52125 .6902 Mdot
.59341 .36172 Mdot
.6672 .55672 Mdot
.56431 .37566 Mdot
.50133 .06515 Mdot
.66609 .52759 Mdot
.56381 .19248 Mdot
.58709 .23528 Mdot
.66226 .59053 Mdot
.71201 .35983 Mdot
.58923 .60729 Mdot
.48527 .78258 Mdot
.53724 .29941 Mdot
.54729 .12113 Mdot
.44123 .12 Mdot
.66033 .5713 Mdot
.45495 .96664 Mdot
.43661 .04625 Mdot
.60739 .59097 Mdot
.45788 .86161 Mdot
.38403 .66052 Mdot
.69862 .52054 Mdot
.43878 .25414 Mdot
.56551 .14981 Mdot
.66635 .24093 Mdot
.72583 .39958 Mdot
.54963 .76635 Mdot
.422 .20871 Mdot
.46441 .90093 Mdot
.58317 .75069 Mdot
.51364 .21687 Mdot
.5635 .45437 Mdot
.5642 .8833 Mdot
.40175 .61122 Mdot
.4965 .06423 Mdot
.58075 .85901 Mdot
.65546 .30265 Mdot
.77635 .42551 Mdot
.3983 .64048 Mdot
.39536 .38059 Mdot
.37161 .62202 Mdot
.56694 .09717 Mdot
.59773 .37357 Mdot
.65759 .71946 Mdot
.60333 .7042 Mdot
.53492 .25738 Mdot
.61794 .86351 Mdot
.56402 .14938 Mdot
.53754 .41628 Mdot
.38731 .22493 Mdot
.39365 .80995 Mdot
.50726 .263 Mdot
.5496 .57266 Mdot
.46623 .20513 Mdot
.65136 .63901 Mdot
.61846 .51112 Mdot
.51582 .58181 Mdot
.52783 .31077 Mdot
.43551 .29215 Mdot
.56314 .14824 Mdot
.50176 .41513 Mdot
.77642 .42609 Mdot
.56916 .34516 Mdot
.63322 .2546 Mdot
.50269 .81235 Mdot
.57776 .80598 Mdot
.41896 .17901 Mdot
.43194 .34188 Mdot
.52682 .8084 Mdot
.45052 .02451 Mdot
.4786 .76879 Mdot
.41288 .65479 Mdot
.40433 .4791 Mdot
.58004 .31682 Mdot
.54743 .58603 Mdot
.71235 .36336 Mdot
.52899 .01229 Mdot
.51159 .69052 Mdot
.44451 .20777 Mdot
.53844 .58888 Mdot
.56693 .54116 Mdot
.59232 .83843 Mdot
.78181 .46006 Mdot
.59706 .36324 Mdot
.4998 .88329 Mdot
.53912 .22864 Mdot
.60565 .15131 Mdot
.42536 .83804 Mdot
.6038 .76229 Mdot
.59687 .64094 Mdot
.61582 .55026 Mdot
.5815 .4861 Mdot
.5079 .70036 Mdot
.65136 .6359 Mdot
.56512 .45302 Mdot
.48412 .249 Mdot
.47259 .974 Mdot
.38731 .29158 Mdot
.68573 .83305 Mdot
.44082 .64534 Mdot
.55842 .31153 Mdot
.36758 .44453 Mdot
.38039 .72784 Mdot
.69337 .45979 Mdot
.66843 .51627 Mdot
.6733 .77373 Mdot
.64774 .38659 Mdot
.56862 .14832 Mdot
.64951 .64483 Mdot
.51538 .30902 Mdot
.4077 .17309 Mdot
.39889 .09928 Mdot
.40326 .73983 Mdot
.47547 .28631 Mdot
.60047 .25751 Mdot
.44186 .872 Mdot
.66103 .23621 Mdot
.61741 .35831 Mdot
.49101 .12838 Mdot
.6178 .22394 Mdot
.70151 .5177 Mdot
.48293 .05386 Mdot
.51787 .28724 Mdot
.47997 .01536 Mdot
.62819 .18677 Mdot
.51121 .98994 Mdot
.41896 .51338 Mdot
.52248 .26435 Mdot
.59579 .36927 Mdot
.44148 .07796 Mdot
.404 .1318 Mdot
.57554 .44709 Mdot
.41718 .31365 Mdot
.68817 .74889 Mdot
.52203 .19901 Mdot
.4111 .42537 Mdot
.65885 .61283 Mdot
.52165 .52145 Mdot
.63087 .42862 Mdot
.69285 .42998 Mdot
.60245 .20458 Mdot
.3675 .5292 Mdot
.69782 .50879 Mdot
.69631 .45082 Mdot
.52414 .78194 Mdot
.64155 .26933 Mdot
.73619 .4314 Mdot
.45381 .92278 Mdot
.40035 .33612 Mdot
.53748 .82661 Mdot
.38848 .20756 Mdot
.56746 .82752 Mdot
.4451 .2356 Mdot
.69894 .45977 Mdot
.41105 .16366 Mdot
.51264 .68259 Mdot
.40988 .4762 Mdot
.42592 .72625 Mdot
.57916 .53657 Mdot
.42359 .07547 Mdot
.62583 .40342 Mdot
.47907 .70494 Mdot
.54864 .12479 Mdot
.68862 .39754 Mdot
.69316 .29663 Mdot
.41519 .54586 Mdot
.73119 .42509 Mdot
.53509 .52939 Mdot
.51206 .94328 Mdot
.38404 .16938 Mdot
.44321 .95593 Mdot
.73016 .40321 Mdot
.46865 .12274 Mdot
.70674 .69748 Mdot
.44482 .07251 Mdot
.4794 .26674 Mdot
.6563 .80058 Mdot
.50097 .02438 Mdot
.74079 .537 Mdot
.63294 .19018 Mdot
.41665 .31393 Mdot
.64283 .1387 Mdot
.58471 .69264 Mdot
.52713 .52852 Mdot
.52474 .55909 Mdot
.50392 .63794 Mdot
.46209 .80821 Mdot
.67555 .18516 Mdot
.48811 .89369 Mdot
.44504 .68225 Mdot
.6157 .35796 Mdot
.49375 .25756 Mdot
.48697 .72039 Mdot
.52623 .7095 Mdot
.65686 .4022 Mdot
.56281 .326 Mdot
.56565 .83017 Mdot
.45101 .74454 Mdot
.52677 .84284 Mdot
.53445 .26087 Mdot
.73632 .43524 Mdot
.52895 .59233 Mdot
.62929 .6074 Mdot
.6466 .20603 Mdot
.55257 .29662 Mdot
.6586 .71192 Mdot
.58416 .80052 Mdot
.54476 .85674 Mdot
.5153 .70222 Mdot
.51941 .75623 Mdot
.42651 .14984 Mdot
.51277 .68398 Mdot
.61371 .16648 Mdot
.65055 .81648 Mdot
.55165 .56706 Mdot
.50328 .3938 Mdot
.6667 .17494 Mdot
.40937 .31705 Mdot
.47316 .7884 Mdot
.69419 .72779 Mdot
.42024 .33786 Mdot
.39856 .7189 Mdot
.65497 .41017 Mdot
.45917 .8938 Mdot
.62288 .85539 Mdot
.55823 .22441 Mdot
.48555 .93419 Mdot
.61844 .5074 Mdot
.42671 .92609 Mdot
.54474 .51005 Mdot
.6774 .37125 Mdot
.49106 .16071 Mdot
.61834 .49652 Mdot
.57876 .16914 Mdot
.7405 .50774 Mdot
.44787 .67164 Mdot
.46289 .27466 Mdot
.6855 .40645 Mdot
.59096 .59004 Mdot
.41132 .56004 Mdot
.44179 .15001 Mdot
.50868 .47298 Mdot
.52807 .05448 Mdot
.61201 .81127 Mdot
.39867 .44145 Mdot
.47411 .78854 Mdot
.51193 .90187 Mdot
.432 .41184 Mdot
.49179 .15692 Mdot
.58797 .73475 Mdot
.56502 .48136 Mdot
.52539 .17641 Mdot
.37768 .44565 Mdot
.57063 .66983 Mdot
.37854 .40739 Mdot
.41313 .24313 Mdot
.53669 .3304 Mdot
.42994 .77496 Mdot
.69307 .42794 Mdot
.4163 .42375 Mdot
.55434 .67505 Mdot
.56041 .88692 Mdot
.52911 .70392 Mdot
.6291 .41395 Mdot
.5855 .17481 Mdot
.52003 .3746 Mdot
.4164 .55776 Mdot
.69714 .49976 Mdot
.58612 .12462 Mdot
.58215 .51069 Mdot
.4977 .34952 Mdot
.5541 .66519 Mdot
.37581 .50106 Mdot
.45017 .19856 Mdot
.6075 .7492 Mdot
.37964 .19636 Mdot
.67308 .67367 Mdot
.57322 .11182 Mdot
.67645 .65758 Mdot
.48922 .65946 Mdot
.6761 .67122 Mdot
.68959 .73102 Mdot
.39242 .74281 Mdot
.59283 .13784 Mdot
.44803 .81918 Mdot
.52132 .16385 Mdot
.41812 .81153 Mdot
.43631 .9442 Mdot
.7132 .35871 Mdot
.56652 .5157 Mdot
.57482 .86598 Mdot
.58224 .63325 Mdot
.50724 .36136 Mdot
.64834 .37223 Mdot
.60552 .40952 Mdot
.66623 .47436 Mdot
.7042 .71059 Mdot
.43275 .593 Mdot
.61898 .64999 Mdot
.58588 .67903 Mdot
.41418 .1042 Mdot
.4466 .32752 Mdot
.69556 .30346 Mdot
.73104 .5875 Mdot
.41446 .94277 Mdot
.55146 .45078 Mdot
.62587 .38598 Mdot
.50934 .83725 Mdot
.60445 .20989 Mdot
.49512 .80183 Mdot
.52852 .51355 Mdot
.46357 .6645 Mdot
.6171 .50164 Mdot
.61691 .16097 Mdot
.67696 .37563 Mdot
.53866 .5894 Mdot
.62726 .31074 Mdot
.49803 .3105 Mdot
.50254 .64264 Mdot
.43452 .12992 Mdot
.5889 .28487 Mdot
.40225 .3193 Mdot
.52626 .77771 Mdot
.48748 .80714 Mdot
.76669 .37886 Mdot
.58789 .6027 Mdot
.38792 .39267 Mdot
.53434 .40222 Mdot
.3802 .27212 Mdot
.50839 .74558 Mdot
.45671 .06127 Mdot
.4584 .09958 Mdot
.44271 .70356 Mdot
.4635 .18509 Mdot
.51305 .98839 Mdot
.6253 .17575 Mdot
.67406 .68078 Mdot
.37701 .52455 Mdot
.46744 .83985 Mdot
.59964 .64166 Mdot
.4037 .19426 Mdot
.44667 .17506 Mdot
.62137 .17037 Mdot
.38034 .8057 Mdot
.46913 .93658 Mdot
.65317 .22312 Mdot
.70074 .3164 Mdot
.73636 .44545 Mdot
.45854 .676 Mdot
.39808 .48311 Mdot
.62755 .18646 Mdot
.54557 .07301 Mdot
.44543 .63885 Mdot
.63038 .69621 Mdot
.59216 .56609 Mdot
.62458 .38698 Mdot
.51621 .86063 Mdot
.56937 .87184 Mdot
.40355 .74942 Mdot
.69386 .58738 Mdot
.64765 .29426 Mdot
.57093 .20782 Mdot
.68523 .64478 Mdot
.58335 .22671 Mdot
.69387 .30921 Mdot
.63627 .9046 Mdot
.6959 .50677 Mdot
.63783 .48289 Mdot
.51616 .43235 Mdot
.73698 .52093 Mdot
.57679 .30699 Mdot
.47436 .67152 Mdot
.70484 .32319 Mdot
.64864 .64913 Mdot
.52887 .50814 Mdot
.45748 .23792 Mdot
.59764 .48714 Mdot
.44945 .76579 Mdot
.53763 .91819 Mdot
.54888 .85888 Mdot
.66896 .77592 Mdot
.69903 .31038 Mdot
.61515 .52105 Mdot
.74574 .32122 Mdot
.60983 .58888 Mdot
.57994 .52616 Mdot
.566 .63059 Mdot
.44217 .43594 Mdot
.59547 .1329 Mdot
.61793 .16641 Mdot
.49174 .77616 Mdot
.46653 .7437 Mdot
.42756 .70396 Mdot
.43902 .7176 Mdot
.72886 .62684 Mdot
.43748 .22383 Mdot
.44606 .91488 Mdot
.41949 .47186 Mdot
.41234 .40775 Mdot
.45282 .31074 Mdot
.40583 .41649 Mdot
.61249 .54828 Mdot
.42062 .66299 Mdot
.43124 .61558 Mdot
.68131 .76027 Mdot
.4772 .01475 Mdot
.47446 .37572 Mdot
.43089 .81407 Mdot
.61583 .54928 Mdot
.63589 .48621 Mdot
.5843 .61395 Mdot
.4184 .34983 Mdot
.73714 .54623 Mdot
.55683 .03755 Mdot
.39172 .65991 Mdot
.74311 .72245 Mdot
.42844 .84812 Mdot
.42713 .41373 Mdot
.45892 .96599 Mdot
.63648 .20081 Mdot
.54013 .66806 Mdot
.44886 .11114 Mdot
.7694 .39052 Mdot
.45333 .72708 Mdot
.51822 .40186 Mdot
.57457 .57877 Mdot
.51093 .90397 Mdot
.52894 .76668 Mdot
.59607 .08242 Mdot
.52224 .62229 Mdot
.44381 .84035 Mdot
.54845 .77029 Mdot
.54514 .5325 Mdot
.44331 .65296 Mdot
.43153 .30669 Mdot
.55986 .08799 Mdot
.43077 .4191 Mdot
.62155 .23194 Mdot
.40327 .24575 Mdot
.59878 .71263 Mdot
.3895 .27635 Mdot
.63169 .69024 Mdot
.61435 .47317 Mdot
.41517 .04465 Mdot
.47462 .22552 Mdot
.62513 .1726 Mdot
.74117 .51298 Mdot
.5642 .47361 Mdot
.67447 .67786 Mdot
.57839 .64114 Mdot
.55947 .27561 Mdot
.45313 .06441 Mdot
.49071 .89367 Mdot
.57087 .40523 Mdot
.47155 .1807 Mdot
.60654 .59939 Mdot
.60199 .88868 Mdot
.46222 .1285 Mdot
.49992 .40319 Mdot
.39608 .38059 Mdot
.48327 .83532 Mdot
.45962 .67897 Mdot
.55244 .46814 Mdot
.40143 .67102 Mdot
.49121 .12735 Mdot
.49576 .68417 Mdot
.59689 .5236 Mdot
.39007 .79027 Mdot
.42939 .7436 Mdot
.60707 .68644 Mdot
.51399 .24582 Mdot
.5191 .26203 Mdot
.43382 .43706 Mdot
.6959 .81815 Mdot
.43806 .39722 Mdot
.43896 .12146 Mdot
.66291 .69649 Mdot
.4352 .89637 Mdot
.48859 .20784 Mdot
.51129 .07907 Mdot
.67243 .25428 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`;o0000/Oooool00:;ooooo00?oEEEEofIV
I_l000000_l00005ooooo`03o`000?oooooooooo00Kooooo0_l0002aooooo`00Y?ooool3o`0000Go
oooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool009_ooooo0_l0
000?ooooo`?o0000^Oooool009_ooooo0_l0000?ooooo`;o0000^_ooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
3oooool2o`000:Sooooo002/ooooo`03o`000?oooooooooo00oooooo0_l0002Xooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00T?ooool2o`0000Gooooo0_l0000Cooooo`03o`000?oooooooooo
0;Wooooo002@ooooo`;o00001Oooool2o`0001?ooooo00?o0000ooooooooool0^Oooool00:cooooo
0ol0002iooooo`00Y_ooool2o`0000Cooooo00?o0000ooooooooool01_ooool2o`000;7ooooo002V
ooooo`;o00001?ooool00ol0003oooooooooo`06ooooo`;o0000/Oooool009gooooo0_l0000=oooo
o`03o`000?oooooooooo0;Wooooo002Looooo`?o00002oooool4o`000;[ooooo002Looooo`;o0000
3?ooool4o`000;[ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Iooooo`;o00004Oooool0
0ol0003oooooooooo`0<ooooo`;o0000Zoooool009;ooooo0_l00005ooooo`;o00004Oooool3o`00
00cooooo0_l0002[ooooo`00T_ooool2o`0000Cooooo0_l0000Booooo`03o`000?oooooooooo00;o
0000]oooool009Sooooo0_l0000Booooo`03o`000?oooooooooo00;o00006_ooool2o`0009_ooooo
002/ooooo`03o`000?oooooooooo01cooooo0_l0002Kooooo`00[?ooool00ol0003oooooooooo`0@
ooooo`?o0000Y_ooool00:cooooo00?o0000ooooooooool04?ooool3o`000:Kooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo01?ooooo0_l0002Tooooo`00R_oo
ool2o`0001;ooooo0_l0000<ooooo`?o00004oooool2o`000:Cooooo002:ooooo`;o00000oooool2
o`0000gooooo0_l0000<ooooo`03o`000?oooooooooo0;Wooooo002?ooooo`;o00006oooool00ol0
003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00VOooool4o`0000oooooo
00?o0000ooooooooool05Oooool2o`000:;ooooo002Iooooo`Co00003oooool00ol0003ooooooooo
o`0Eooooo`;o0000X_ooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`2iooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B42ooooo`?o0000
00?ooooooeEEEOnYZJT01?ooool2o`0000;ooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`0<ooooo`;o0000Zoooool0087ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@4100
2Oooool3o`000003oooooonYZJWoEEEE00Cooooo0_l00003ooooo`03o`000?oooooooooo00?ooooo
0ol0000<ooooo`?o00002_ooool2o`0009kooooo0029ooooo`05o`000?ooooooooooooooool00000
3_ooool00olQ8B7oooooooooo`02o`0000Cooooo00CoMgMgoc8b<_oooooooooo0_l000000ooooooo
0000ooooo`0>ooooo`;o00002_ooool2o`0009kooooo0029ooooo`03o`000?oooooooooo00;o0000
2?ooool2o`0000Cooooo00?oEEEEolc<c?ooool00_l000001_oooooo0000ob4Q8Ol0003o<S8bolc<
c0;ooooo0_l000000ooooooo0000ooooo`2jooooo`00ROooool00ol@413oooooooooo`02o`0000So
oooo0_l00004ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Looooo`;o0000Voooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
01_ooooo0ol0002Kooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004oooo
o`Co00001_ooool00ol0003oooooooooo`0Kooooo`;o00003oooool2o`0008_ooooo002/ooooo`03
o`000?oooooooooo02cooooo0_l0002;ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00Tooo
ool2o`0000?ooooo0_l0000Booooo`03o`000?oooooooooo017ooooo1?l0002Tooooo`00Toooool2
o`0000?ooooo0_l0000Booooo`?o00004Oooool4o`0000[ooooo0_l0002Hooooo`00[?ooool00ol0
003oooooooooo`0Oooooo`;o0000V?ooool00:Wooooo0_l000000ooooooo0000ooooo`0Qooooo`;o
0000Uoooool00:Wooooo0_l000000ooooooo0000ooooo`0Qooooo`;o000000?oooooo`000?l00000
U?ooool008kooooo0_l0000Iooooo`;o000000?oooooo`000?ooool01Oooool2o`0001gooooo0_l0
002Dooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool01?ooool2o`0001cooooo0ol0002D
ooooo`00QOooool2o`0002Gooooo00?o0000ooooooooool05oooool2o`0000Wooooo1Ol0002Boooo
o`00QOooool2o`0000Kooooo0_l0000Mooooo`03o`000?oooooooooo01Oooooo0_l0000<ooooo`?o
0000TOooool008gooooo0_l0000;ooooo`;o00004?ooool3o`0000Gooooo0_l0000Booooo`;o0000
2oooool2o`0000cooooo0_l00023ooooo`00TOooool2o`0000Oooooo0_l0000@ooooo`03o`000?oo
oooooooo00Gooooo0_l0000Booooo`;o00002oooool2o`0000cooooo0_l00023ooooo`00TOooool2
o`0000oooooo0_l00008ooooo`03o`000?oooooooooo0;Wooooo002Pooooo`Co00002?ooool00ol0
003oooooooooo`0Wooooo`;o00003_ooool2o`00083ooooo002Pooooo`;o00002_ooool00ol0003o
ooooooooo`0Wooooo`;o00003_ooool2o`00083ooooo002/ooooo`03o`000?oooooooooo01;ooooo
0_l0000Cooooo`?o0000Soooool008cooooo0_l0000Nooooo`03o`000?oooooooooo01;ooooo0_l0
000Dooooo`;o0000Soooool008Cooooo0_l00006ooooo`;o00003Oooool2o`0000oooooo00?o0000
ooooooooool0^Oooool008Cooooo0_l0000Eooooo`;o00003oooool3o`0000Cooooo0_l0000Toooo
o`;o0000SOooool00:cooooo00?o0000ooooooooool01?ooool2o`0001Sooooo0_l0000:ooooo`;o
0000SOooool008Oooooo0_l0000Gooooo`;o00002_ooool00ol0003oooooooooo`0Nooooo`;o0000
3Oooool2o`0008[ooooo0027ooooo`;o00002Oooool2o`0000Gooooo0_l00005ooooo`;o00001_oo
ool2o`0000;ooooo00?o0000ooooooooool05?ooool2o`0000Wooooo0_l0000<ooooo`;o0000R_oo
ool009;ooooo0_l00005ooooo`;o00003Oooool2o`0000;ooooo00?o0000ooooooooool05?ooool2
o`0000Wooooo0_l0002Hooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool01?l0003o
ooooooooooooool2o`000;Kooooo002/ooooo`04o`000?ooooooooooooooo`;o0000]_ooool008Ko
oooo0_l0000?ooooo`;o00002_ooool2o`0000Oooooo0ol0000@ooooo`;o00004Oooool2o`0000[o
oooo0_l00028ooooo`00Q_ooool2o`0000oooooo0_l0000:ooooo`;o00001oooool00ol0003ooooo
ooooo`09ooooo`;o00001Oooool2o`0000Kooooo0_l00009ooooo`;o00002_ooool2o`0008Sooooo
002/ooooo`03o`000?oooooooooo00Wooooo0_l0000=ooooo`;o0000Woooool00:cooooo00?o0000
ooooooooool09Oooool2o`0009;ooooo002Iooooo`;o00000oooool2o`0000cooooo00?o0000oooo
ooooool06Oooool2o`0000[ooooo0_l0000;ooooo`;o0000QOooool009Wooooo0_l00003ooooo`;o
00003?ooool00ol0003oooooooooo`0Iooooo`;o00005oooool3o`0008Cooooo002?ooooo`;o0000
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0<oooool2o`0008Cooooo002<ooooo`;o000000Soooooo`000?l0
003oMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00Co
0000oooooooooooooooo0_l0002fooooo`00ROooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400@ooooo`;o00001?ooool01?l0003oooooooooooooool2o`000;Kooooo002Aooooo`05o`00
0?ooooooooooooooool000003oooool00omgMgOo0000o`000004ooooo`?o0000^Oooool0097ooooo
00Ko0000ooooooooooooooooo`000?ooool2o`0000Wooooo00Co0000ob4Q8Ol0003o<S8b0_l00004
ooooo`03o`000?oooooooooo02Wooooo0_l0000:ooooo`;o0000P_ooool0097ooooo00Ko410@oooo
oooooooooooooa0@4?ooool2o`0000Wooooo00?o0000ooooooooool01?ooool2o`000003ooooool0
003ooooo00Wooooo0_l0000Dooooo`;o00002Oooool2o`0000[ooooo0_l00022ooooo`00TOooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01?ooool2o`000003ooooool0
003ooooo00Cooooo0_l00003ooooo`;o00005?ooool2o`0009Wooooo002Aooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool4o`0000Kooooo00Co0000ooooool0003o00000_ooool3o`0000;ooooo
0_l0002_ooooo`00YOooool2o`0000Gooooo00Co0000ooooool0003o00000oooool2o`000;?ooooo
002Uooooo`;o00001Oooool00ol0003oooooooooo`0[ooooo`;o0000S?ooool008Cooooo0_l0000V
ooooo`03o`000?oooooooooo02_ooooo0_l0002<ooooo`00Q?ooool2o`000003ooooool0003o0000
01Kooooo0_l0000;ooooo`?o00004?ooool2o`000:Oooooo0027ooooo`;o00005_ooool2o`0000_o
oooo00?o0000ooooooooool04?ooool2o`000:Oooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002Sooooo`;o00001oooool00ol0003oooooooooo`0Jooooo`;o0000WOooool00:?ooooo0_l00007
ooooo`03o`000?oooooooooo00;ooooo0_l0000Fooooo`;o0000WOooool008Kooooo0_l0000>oooo
o`;o00005?ooool00ol0003oooooooooo`02ooooo`;o0000]Oooool008Kooooo0_l0000>ooooo`;o
00005?ooool00ol0003oooooooooo`0]ooooo`;o0000R_ooool00:cooooo00?o0000ooooooooool0
3_ooool2o`0001gooooo0_l0000=ooooo`;o0000Noooool00:cooooo0ol00009ooooo`;o00000ooo
ool2o`0002cooooo0_l0001kooooo`00[?ooool00ol0003oooooooooo`09ooooo`;o00009Oooool2
o`0000_ooooo0_l0001jooooo`00UOooool2o`0001Gooooo00?o0000ooooooooool05_ooool2o`00
00Gooooo0_l0000Aooooo`;o00002oooool2o`0007[ooooo002Eooooo`;o00005?ooool2o`0000Co
oooo0_l0000Booooo`;o00001Oooool2o`0001kooooo0ol0001iooooo`00T?ooool2o`0000[ooooo
0_l0000=ooooo`;o00001?ooool2o`0000;ooooo0_l00008ooooo`;o00005Oooool2o`0001Cooooo
0ol0001iooooo`00T?ooool2o`0000[ooooo0_l0000>ooooo`03o`000?oooooooooo00Kooooo0ol0
0007ooooo`;o00005Oooool2o`0001Kooooo0_l0001hooooo`00Roooool2o`000003ooooool0003o
000000;o00006_ooool00ol0003oooooooooo`07ooooo`;o00003_ooool2o`0002Kooooo0_l0001h
ooooo`00Roooool2o`000003ooooool0003o000001cooooo00?o0000ooooooooool05oooool2o`00
03Gooooo0_l0001Yooooo`00[?ooool3o`00043ooooo0_l0000<ooooo`;o0000JOooool009[ooooo
0_l0000@ooooo`03o`000?oooooooooo017ooooo0_l0000]ooooo`;o0000Moooool009[ooooo0_l0
000@ooooo`03o`000?oooooooooo00Wooooo0_l00006ooooo`;o0000Y_ooool00:cooooo00?o0000
ooooooooool02Oooool2o`000:kooooo002;ooooo`;o00001?ooool2o`0001Wooooo00?o0000oooo
ooooool0^Oooool008_ooooo0_l00004ooooo`;o00006Oooool00ol0003oooooooooo`2iooooo`00
UOooool2o`0001Gooooo00?o0000ooooooooool0^Oooool009Gooooo0_l0000Eooooo`03o`000?oo
oooooooo01?ooooo0_l0002Tooooo`00TOooool2o`0001Sooooo0_l0000Eooooo`;o0000Y?ooool0
097ooooo0_l0000Hooooo`Co0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool08oooool2o`0001kooooo0_l0001dooooo`00[?ooool01?l0003oooooo`00
0?l0000Jooooo`;o00001_ooool2o`0001kooooo0_l0001dooooo`00[?ooool01?l0003oooooo`00
0?l0000Jooooo`Co00009?ooool2o`0007Cooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`0Mooooo`;o00009?ooool2o`0007Cooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool07?ooool2o`0001Wooooo0_l00020ooooo`00POooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Looooo`?o00003oooool2o`0000Oooooo0_l00020oooo
o`00ROooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool2o`00
0003ogMgMolb<S;ooooo00Cooooo0ol00003ooooo`;o00003Oooool2o`0000Wooooo0_l0000?oooo
o`;o00001oooool2o`00083ooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool00omg
MgOoIVIVooooo`03ooooo`?o000000?o<S8bolc<c?ooool01?ooool00ol0003oooooooooo`03oooo
o`;o00003Oooool2o`0002?ooooo0_l0000Looooo`;o0000H_ooool008Wooooo0_l00002ooooo`03
oa0@4?oooooooooo00gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo05Gooooo0_l0001Rooooo`00ROooool2o`000003oooooonHV9SoMgMg00_ooooo
00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool09_ooool2o`00097ooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So
410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo02Kooooo0_l00005oooo
o`;o0000R_ooool00:cooooo00?o0000ooooooooool09_ooool2o`0000Gooooo0_l0000Vooooo`;o
0000H_ooool008Oooooo0_l0000Sooooo`?o0000EOooool2o`0006;ooooo0027ooooo`;o00003_oo
ool2o`0001?ooooo0ol0000kooooo`;o0000O?ooool009Oooooo0_l0000Cooooo`?o0000>oooool2
o`0000[ooooo0_l0001`ooooo`00[?ooool2o`0000Cooooo0_l00003ooooo`;o00007?ooool2o`00
00Sooooo0_l0000Eooooo`Co0000K_ooool008?ooooo0_l0000Wooooo`;o00001?ooool2o`0000?o
oooo0_l0000:ooooo`;o00004?ooool2o`0000Sooooo0_l00008ooooo`;o00003Oooool2o`0006ko
oooo0023ooooo`;o00002_ooool2o`0001_ooooo00?o0000ooooooooool05?ooool2o`0000Wooooo
0_l0000?ooooo`;o00002?ooool2o`0007gooooo002?ooooo`;o00001?ooool2o`0001Gooooo00?o
0000ooooooooool07oooool2o`0000oooooo0_l00027ooooo`00S?ooool2o`0000Kooooo0ol0000E
ooooo`;o00002_ooool2o`0001cooooo0_l0002@ooooo`00S?ooool2o`0000Kooooo0ol0000Eoooo
o`;o00002_ooool2o`0001cooooo0_l0002@ooooo`00UOooool2o`0001Gooooo00?o0000oooooooo
ool0^Oooool008kooooo1?l0000Jooooo`?o0000BOooool2o`0000gooooo0_l0001Oooooo`00S_oo
ool4o`0001[ooooo00?o0000ooooooooool0:?ooool2o`0001;ooooo0_l0000;ooooo`;o00003Ooo
ool2o`0005oooooo002/ooooo`03o`000?oooooooooo02Sooooo0_l0000Booooo`;o00003Oooool2
o`0000_ooooo0_l0001Oooooo`00[?ooool00ol0003oooooooooo`02ooooo`;o0000>?ooool2o`00
00gooooo0_l0001/ooooo`00U_ooool4o`0001;ooooo00?o0000ooooooooool00_ooool2o`0004Oo
oooo0_l0001/ooooo`00U_ooool4o`0001;ooooo00?o0000ooooooooool0Boooool2o`0006cooooo
002:ooooo`;o00008?ooool00ol0003oooooooooo`2iooooo`00P?ooool2o`000003ooooool0003o
000000Gooooo0_l0000Pooooo`03o`000?oooooooooo04_ooooo0_l0001/ooooo`00P?ooool2o`00
0003ooooool0003o000002Oooooo00?o0000ooooooooool05_ooool2o`0003?ooooo0_l0001/oooo
o`00[?ooool3o`0000kooooo0_l00002ooooo`;o00000_ooool2o`0002Gooooo0_l0001jooooo`00
[?ooool00ol0003oooooooooo`0>ooooo`;o00000_ooool2o`0002Wooooo0_l0001jooooo`00[?oo
ool00ol0003oooooooooo`0Booooo`;o0000YOooool000Wooooo1?l000000ol@413oooooooooo`0F
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Fooooo`03o`000?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo
00GoA4A4o`000?l0003o<S8bomgMg@06ooooo`Co00001Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`04odA4A?l0003o0000oc8b<P;o00003_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8b
omgMg@0Hooooo`Co000000?o410@ooooooooool04_ooool000_ooooo00?o0000ooooooooool06?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo
00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03
ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnH
V9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool05Oooool00ol0003oooooooooo`0H
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A007ooooo`03ogMgMolb<S;ooooo00Gooooo1?l00005ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Sooooo00?oMgMgo`000?l000003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool06Oooool00ol0
003oooooooooo`0Dooooo`001_l00005ooooo`03o`000?oooooooooo013ooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo
00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`05
ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00kooooo0_l00008ooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00gooooo
00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00gooooo00Go410@oooooooo
oooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05o`000?oooooooooooooo
ool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool05Oooool00ol0003ooooooooo
o`0>ooooo`;o00002?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo
<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06oooo
o`03ogMgMolb<S;ooooo01Wooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000oooooooo
ool06?ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_oo
ool00oooool3o`000003oc8b<_o<c<cooooo01Gooooo00Co0000ooooool0003o00004Oooool2o`00
00Cooooo00Go0000ooooooooooooooooo`000005ooooo`;o00001oooool00omgMgOoIVIVooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000cooooo
00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003_ooool00omE
EEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06_ooool00ol0003oooooooooo`0D
ooooo`002oooool00ol0003oooooooooo`0Hooooo`05oa0@4?ooooooooooooooool@41003_ooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400?ooooo`05o`00
0?oooooo0000o`000?ooool00_l0000Iooooo`Co00004Oooool2o`0000Cooooo00Go410@oooooooo
oooooooooa0@4005ooooo`;o00002?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo0000
o`00013ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo017ooooo00Go
410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000oooooooo
ool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00Co0000okZj^_ooooooV9RH1?l000000ooooooo0000oooo
o`0Iooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool01?l0003oooooo`000?l0000@ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Dooooo`002Oooool00omEEEGoIVIVo`00000Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool5o`0000Cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00013o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`03oiRHV?l@413o000000?o00000oooool4o`00
01Oooooo00?o0000ooooooooool04_ooool2o`0000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`05oiRHV?l@413o0000o`000?o<c<`01?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co
00006Oooool00omEEEGoIVIVo`00000Fooooo`00R_ooool2o`00023ooooo00?o0000ooooooooool0
4_ooool2o`0000?ooooo0_l0000@ooooo`?o0000SOooool00:cooooo00?o0000ooooooooool05ooo
ool2o`0000Cooooo0_l0000:ooooo`;o0000S_ooool00:cooooo00?o0000ooooooooool07Oooool2
o`0008oooooo0_l00002ooooo`;o00001Oooool00:cooooo00?o0000ooooooooool0[_ooool01_o^
k^ko8B4QohN7Qonj^[[o0000omgMg@Gooooo002/ooooo`03o`000?oooooooooo02Cooooo0_l00029
ooooo`04omgMgOl0003o410@olc<c0Kooooo0007oooooooo0000C?l0000<ooooo`04onk^k_lQ8B7o
410@onk^kPKooooo0007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00_ooool2o`0000;ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l00008ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`04ob4Q8OmgMgOo
MgMgoc8b<PKooooo0007ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool08oooool3
o`000003ooooool0003ooooo01Cooooo0_l0000Aooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`09ooooo`;o00000_ooool2o`0000Gooooo002/oooo
o`03o`000?oooooooooo00Kooooo0_l00003ooooo`;o00005oooool2o`0001Oooooo0ol0000<oooo
o`;o0000Joooool0097ooooo0_l0000Iooooo`03o`000?oooooooooo00Kooooo0_l00003ooooo`;o
00002oooool2o`0000[ooooo0_l0000Hooooo`;o00003?ooool2o`0006_ooooo002Aooooo`;o0000
6Oooool00ol0003oooooooooo`06ooooo`;o00002oooool2o`0000?ooooo0_l0000:ooooo`;o0000
3_ooool2o`0001Kooooo0_l0001[ooooo`00[?ooool00ol0003oooooooooo`0Cooooo`;o00007ooo
ool2o`0000Wooooo0_l0001hooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o00007Oooool2
o`0001Wooooo0ol0000:ooooo`;o0000K?ooool008?ooooo0_l0000Wooooo`?o00001?ooool2o`00
01Oooooo0_l00004ooooo`;o00006Oooool2o`0000_ooooo0_l0001/ooooo`00Poooool2o`0002Oo
oooo00?o0000ooooooooool01_ooool2o`0000oooooo0_l00004ooooo`;o00005?ooool2o`0008Co
oooo0020ooooo`;o0000:_ooool00ol0003oooooooooo`06ooooo`Co00003Oooool2o`0001[ooooo
0ol00023ooooo`00P?ooool2o`0002[ooooo00?o0000ooooooooool02?ooool2o`000003ooooool0
003o000002Oooooo0_l00023ooooo`00[?ooool00ol0003oooooooooo`0;ooooo`;o00002_ooool2
o`0003?ooooo0_l0001[ooooo`00[?ooool00ol0003oooooooooo`0Gooooo`;o0000<oooool2o`00
06_ooooo002/ooooo`03o`000?oooooooooo01?ooooo0_l0002Tooooo`00T?ooool2o`0001[ooooo
00?o0000ooooooooool04oooool2o`0003Kooooo0_l0001/ooooo`00T?ooool2o`0001[ooooo00?o
0000ooooooooool08_ooool3o`0002Kooooo0_l0001/ooooo`00[?ooool3o`0002;ooooo0ol0002D
ooooo`00[?ooool00ol0003oooooooooo`0Sooooo`;o0000U?ooool0093ooooo0_l0000Jooooo`03
o`000?oooooooooo03Cooooo0_l00023ooooo`00S_ooool4o`0001[ooooo00?o0000ooooooooool0
1Oooool2o`0002gooooo0_l00023ooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool01Ooo
ool2o`000;;ooooo002/ooooo`03o`000?oooooooooo00kooooo0_l00002ooooo`;o00001oooool2
o`0009cooooo002/ooooo`03o`000?oooooooooo00kooooo0_l00002ooooo`;o00001oooool2o`00
09cooooo002/ooooo`03o`000?oooooooooo00gooooo0_l0000Rooooo`;o0000Q_ooool00:cooooo
0ol0000=ooooo`;o00008_ooool2o`0008Kooooo002Hooooo`;o00004_ooool00ol0003ooooooooo
o`0Eooooo`;o0000X_ooool009Sooooo0_l0000Booooo`03o`000?oooooooooo00;ooooo0_l0000A
ooooo`;o0000X_ooool00:cooooo00?o0000ooooooooool00_ooool2o`0000Sooooo0_l0002[oooo
o`00[?ooool00ol0003oooooooooo`09ooooo`;o000000?oooooo`000?l000004oooool2o`0001[o
oooo0_l0000:ooooo`;o0000K_ooool00:cooooo00?o0000ooooooooool01_ooool2o`000003oooo
ool0003o0000013ooooo0_l00003ooooo`?o00003oooool2o`0000Wooooo0_l0000:ooooo`;o0000
K_ooool009Gooooo0_l0000Eooooo`03o`000?oooooooooo00Kooooo0_l000000ooooooo0000o`00
000@ooooo`;o00000oooool2o`00013ooooo0_l00025ooooo`00UOooool2o`0001Gooooo00?o0000
ooooooooool0^Oooool00:cooooo0ol0000Pooooo`;o0000Uoooool00:cooooo00?o0000oooooooo
ool06_ooool2o`0000Cooooo0_l0002Gooooo`00[?ooool00ol0003oooooooooo`0Jooooo`;o0000
2oooool2o`00093ooooo002/ooooo`03o`000?oooooooooo01[ooooo0_l0000;ooooo`;o0000T?oo
ool008_ooooo0_l0000Oooooo`03o`000?oooooooooo037ooooo0_l00026ooooo`00Roooool2o`00
00Sooooo0_l0000Eooooo`03o`000?oooooooooo01Sooooo0_l0000Gooooo`;o0000Q_ooool008Wo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q0_l00002ooooo`Go00001?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool06?ooool2o`0009oooooo0021oooo
o`;o00001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00Cooooo0_l0
002cooooo`00POooool2o`0000Kooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`0000Cooooo0_l0002cooooo`00ROooool0
1Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo04Sooooo0_l0001_ooooo`00ROooool01Ol0003ooooooooooooo
oooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool04_ooool2o`0003Cooooo0_l0001_ooooo`00ROooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01;ooooo0_l00004ooooo`;o0000Woooool008Wooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool2o`0000Sooooo00?o0000oooooooo
ool06?ooool2o`0001Gooooo0_l00028ooooo`00ROooool01Oo^k^ko0000o`000?lb<S;ok^k^00_o
oooo00GoV9RHo`000?l0003o8B4Qolc<c004ooooo`Co00001_ooool3o`0002oooooo0_l00028oooo
o`00R_ooool2o`0000kooooo0_l0000@ooooo`?o00005_ooool2o`0000Gooooo0_l0000@ooooo`;o
0000R?ooool009Sooooo0_l0000Booooo`;o00005oooool2o`0000Gooooo0_l0000?ooooo`;o0000
2_ooool2o`0007gooooo002Hooooo`;o00004_ooool00ol0003oooooooooo`0^ooooo`;o00002_oo
ool2o`0007gooooo002Iooooo`;o00004Oooool3o`0002Cooooo0_l00008ooooo`;o0000ROooool0
08oooooo0_l00008ooooo`;o00004Oooool00ol0003oooooooooo`0Tooooo`;o0000Toooool008oo
oooo0_l0000Kooooo`03o`000?oooooooooo00_ooooo0_l0000Zooooo`;o0000P?ooool008Gooooo
0_l000000ooooooo0000o`00000Nooooo`;o00000_ooool00ol0003oooooooooo`0;ooooo`;o0000
:_ooool2o`00083ooooo0025ooooo`;o000000?oooooo`000?l000001oooool2o`0000gooooo0_l0
0006ooooo`;o00000_ooool00ol0003oooooooooo`2iooooo`00TOooool2o`0000gooooo0_l0000:
ooooo`03o`000?oooooooooo00[ooooo0_l00002ooooo`;o0000ZOooool008_ooooo0_l0000Ooooo
o`03o`000?oooooooooo00[ooooo0_l00002ooooo`;o00001?ooool2o`000:?ooooo002;ooooo`;o
00003Oooool2o`0000Oooooo0_l00007ooooo`03o`000?oooooooooo01Cooooo0_l0000Pooooo`?o
0000P?ooool009[ooooo0_l00002ooooo`;o00000oooool2o`0000Oooooo0ol0000?ooooo`;o0000
9Oooool3o`00083ooooo002Nooooo`;o00003?ooool00ol0003oooooooooo`0?ooooo`;o00002?oo
ool2o`0001_ooooo0_l00021ooooo`00VOooool2o`0000?ooooo0_l0000<ooooo`04o`000?oooooo
ooooooooo`;o00005_ooool2o`0001_ooooo0_l00021ooooo`00VOooool2o`0000oooooo0ol00003
ooooo`;o0000<oooool2o`00087ooooo002Zooooo`?o00000oooool2o`0001gooooo0_l0002Goooo
o`00[?ooool00ol0003oooooooooo`02o`0000;ooooo0_l0000Jooooo`;o00001_ooool2o`0008oo
oooo002/ooooo`03o`000?oooooooooo00;o00000_ooool2o`0001?ooooo0_l0000=ooooo`;o0000
Soooool00:cooooo00?o0000ooooooooool06Oooool2o`0000gooooo0_l00008ooooo`;o00003Ooo
ool2o`0007Kooooo002/ooooo`Co00009oooool2o`0000Sooooo0_l0000=ooooo`;o0000M_ooool0
09Cooooo0_l00003ooooo`;o00004Oooool01Ol0003oooooo`000?l0003ooooo00;o00000_ooool2
o`0001Oooooo0_l0002Hooooo`00U?ooool2o`0000?ooooo0_l0000:ooooo`;o00001Oooool00ol0
003oooooooooo`02ooooo`;o00000_ooool2o`0001Oooooo0_l0002Hooooo`00YOooool2o`0000Go
oooo00?o0000ooooooooool01Oooool2o`000;;ooooo002/ooooo`03o`000?oooooooooo00Gooooo
0_l0000Fooooo`;o00004_ooool2o`0000gooooo0_l0001gooooo`00[?ooool00ol0003ooooooooo
o`0Mooooo`;o00004_ooool2o`0000gooooo0_l0001gooooo`00R_ooool2o`0000_ooooo0_l0000C
ooooo`03o`000?oooooooooo037ooooo0_l00026ooooo`00R_ooool2o`0000_ooooo0_l0000>oooo
o`;o00000oooool00ol0003oooooooooo`0aooooo`;o00006_ooool2o`0006[ooooo002Wooooo`;o
00000oooool3o`0004gooooo0_l0001Zooooo`00Q?ooool2o`0000gooooo0_l00007ooooo`;o0000
3_ooool00ol0003oooooooooo`0mooooo`;o0000N_ooool008Cooooo0_l0000=ooooo`;o00001ooo
ool2o`0000kooooo00?o0000ooooooooool0>oooool4o`0007[ooooo002Cooooo`;o00005oooool0
0ol0003oooooooooo`0Jooooo`;o00007oooool2o`0007cooooo002/ooooo`03o`000?oooooooooo
01[ooooo0_l0002Mooooo`00S?ooool2o`0001kooooo00?o0000ooooooooool0^Oooool008Sooooo
0_l00002ooooo`;o00000oooool00oo^k^ko<S8bo`000002o`0000Gooooo0_lQ8B44ooooo`Co0000
00?o<S8bomgMgOooool01?ooool00ol0003oooooooooo`2iooooo`00R?ooool2o`0000Oooooo00?o
MgMgoiRHV?ooool00_l00005ooooo`;o00001?ooool2o`0000;ooooo00?oMgMgoc8b<_ooool01?oo
ool01?l0003oooooo`000?l0002hooooo`00S?ooool2o`0000?ooooo00Go410@oooooooooooooooo
oa0@4005ooooo`;o00002Oooool00ol0003oooooooooo`03ooooo`04o`000?oooooo0000o`0001oo
oooo0_l0000Iooooo`;o0000O?ooool008cooooo0_l00003ooooo`05o`000?ooooooooooooooool0
00003oooool00omgMgOo<S8booooo`04ooooo`?o00006?ooool2o`0000Kooooo0_l0000Iooooo`;o
0000O?ooool0097ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`0Hooooo`;o0000Woooool0097ooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool2o`00
0;Cooooo002Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00?ooooo0_l0000cooooo`;o0000Ooooool0097ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`0Oooooo`;o00005oooool2o`00
07oooooo002Kooooo`;o00003oooool00ol0003oooooooooo`06ooooo`;o00001Oooool2o`00013o
oooo0_l0002Hooooo`00Voooool2o`0000Oooooo0_l00006ooooo`03o`000?oooooooooo00Kooooo
0_l00005ooooo`;o0000Z_ooool00:Cooooo0_l00006ooooo`03o`000?oooooooooo00gooooo0_l0
000Wooooo`;o0000POooool009Cooooo0_l0000Cooooo`;o000000Coooooo`000?l0003o0000=?oo
ool4o`00087ooooo002Dooooo`;o00004oooool2o`000003ooooool0003ooooo00Kooooo0_l0000]
ooooo`;o0000Poooool00:Oooooo0_l00003ooooo`03o`000?oooooooooo00Gooooo0_l0002boooo
o`00Yoooool2o`0000?ooooo00?o0000ooooooooool01Oooool2o`000;;ooooo002Sooooo`;o0000
1oooool00ol0003oooooooooo`2iooooo`00Qoooool2o`0001[ooooo0_l00007ooooo`03o`000?oo
oooooooo0;Wooooo0027ooooo`;o00008oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00[?ooool3o`0001Sooooo0_l0000Fooooo`;o0000Qoooool00:[ooooo
0ol0000Jooooo`;o00005_ooool2o`0008Oooooo0024ooooo`;o00008Oooool2o`000004ooooool0
003o0000o`0001Sooooo0_l0002Qooooo`00Q?ooool2o`0000;ooooo0_l0000Eooooo`;o00001_oo
ool2o`0000?ooooo00?o0000ooooooooool01Oooool2o`0000oooooo0_l0002Qooooo`00R?ooool2
o`0000Oooooo0_l0000<ooooo`;o00002oooool2o`0000Kooooo0_l0000Kooooo`;o0000UOooool0
097ooooo0_l00002ooooo`;o00005Oooool2o`0002?ooooo0_l0000:ooooo`;o0000ROooool009Go
oooo0_l00003ooooo`;o00004?ooool00ol0003oooooooooo`0;ooooo`;o00008Oooool2o`0000go
oooo0_l0001jooooo`00V_ooool2o`00013ooooo00?o0000ooooooooool02oooool2o`00033ooooo
0_l0001jooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo00Wooooo0_l00008
ooooo`;o0000Y?ooool00:cooooo00?o0000ooooooooool02Oooool2o`0000Oooooo0ol0002Toooo
o`00[?ooool00ol0003oooooooooo`0Booooo`;o00009_ooool2o`0007gooooo002Vooooo`;o0000
1?ooool00ol0003oooooooooo`02o`0003Sooooo0_l0001mooooo`00Toooool2o`0000Cooooo0_l0
0006ooooo`;o00000oooool2o`0000Cooooo00?o0000ooooooooool00_l0000Iooooo`;o0000W?oo
ool009?ooooo0_l00004ooooo`;o00001_ooool2o`0000Wooooo00?o0000ooooooooool01Oooool2
o`0001Cooooo0_l0002Looooo`00[?ooool00ol0003oooooooooo`05ooooo`;o0000/_ooool009Co
oooo0_l0000Fooooo`03o`000?oooooooooo0;Wooooo002Dooooo`;o00005_ooool3o`000;Wooooo
002/ooooo`03o`000?oooooooooo02Gooooo0_l0002Booooo`00[?ooool00ol0003oooooooooo`0;
ooooo`Co00005_ooool2o`0009;ooooo002Nooooo`;o00003?ooool00ol0003oooooooooo`02oooo
o`;o00001oooool4o`0000Sooooo0_l0002Pooooo`00W_ooool2o`0000cooooo00?o0000oooooooo
ool00_ooool2o`0001?ooooo0_l0000:ooooo`;o0000U?ooool008Wooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`0Eooooo`;o00003?ooool2o`0009Cooooo0029ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo01Gooooo0_l0002Rooooo`00ROooool01Ol@413o
oooooooooooooooo410@00[ooooo0_l000000oooooooZJVYoeEEE@09ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool04oooool2o`000:Cooooo0029ooooo`05o`000?oooooooooooooo
ool000002_ooool2o`0000;ooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04oooo
o`?o00004oooool2o`000:Cooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool00omE
EEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2i
ooooo`00ROooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01_oo
ool2o`0001Cooooo0_l0002Uooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol0
0004ooooo`Co00001Oooool2o`0001?ooooo0ol0000:ooooo`;o0000VOooool00:cooooo00?o0000
ooooooooool04Oooool2o`0000_ooooo0_l0002Iooooo`00W_ooool2o`0000Sooooo0_l00002oooo
o`03o`000?oooooooooo0;Wooooo002Fooooo`;o00001_ooool2o`0000Sooooo0_l00002ooooo`03
o`000?oooooooooo0;Wooooo002Fooooo`;o00002?ooool2o`0000[ooooo0ol0002iooooo`00X?oo
ool2o`0000[ooooo00?o0000ooooooooool00ol0002fooooo`00[?ooool00ol0003oooooooooo`03
o`0002Oooooo0_l0002=ooooo`00[?ooool00ol0003oooooooooo`0Zooooo`;o0000SOooool00:co
oooo00?o0000ooooooooool0^Oooool009[ooooo0_l0000@ooooo`03o`000?oooooooooo0;Wooooo
002Jooooo`;o00004?ooool00ol0003oooooooooo`09ooooo`;o0000[_ooool00:cooooo00?o0000
ooooooooool02Oooool2o`000:kooooo002Looooo`;o00003_ooool3o`000;Wooooo002Cooooo`;o
00001oooool2o`0000kooooo00?o0000ooooooooool0^Oooool009?ooooo0_l0000Gooooo`03o`00
0?oooooooooo0;Wooooo002Wooooo`;o00000oooool00ol0003oooooooooo`2iooooo`00XOooool2
o`0000Cooooo0_l00003ooooo`03o`000?oooooooooo0;Wooooo002Qooooo`;o00002Oooool00ol0
003oooooooooo`2iooooo`00Soooool2o`0001_ooooo00Co0000oooooooooooooooo0_l0002foooo
o`00Soooool2o`0000Kooooo0_l0000Cooooo`04o`000?ooooooooooooooo`;o0000]_ooool009Oo
oooo0_l0000Cooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o
0000ooooooooool0^Oooool009Wooooo0_l0000Aooooo`03o`000?oooooooooo0;Wooooo002Ioooo
o`;o00004Oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
WOooool3o`0000cooooo00?o0000ooooooooool0^Oooool009gooooo0ol0000<ooooo`03o`000?oo
oooooooo0;Wooooo002Sooooo`;o00001oooool00ol0003oooooooooo`2iooooo`00Xoooool2o`00
00Oooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool01?l0003ooooooooooooo
ool2o`000;Kooooo002/ooooo`03o`000?oooooooooo00?o0000]_ooool00:;ooooo1?l000000ol@
413oooooooooo`03ooooo`03o`000?oooooooooo00;o0000]oooool00:Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`?o0000
^Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool0
0:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:;ooooo
00?oEEEEofIVI_l00000`oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00:[ooooo00Co410@o`000?l0003o0000^_ooool00:_ooooo00?o0000ooooooooool0
^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00Ko0000ogMgMol0003o0000oeEE
EOo^k^jgooooo`00Zoooool01_l0003oEEEEonk^k_ooooooMgMgoeEEEKOooooo002[ooooo`03o`00
0?o^k^kooooo00;ooooo00?o0000ooooooooool0]Oooool00:_ooooo00?o0000onk^k_ooool00_oo
ool00ol0003oooooooooo`2eooooo`00Zoooool01_l0003oEEEEonk^k_ooooooMgMgofIVI[Oooooo
002Zooooo`03oa0@4?l0003oMgMg00;o000000?oIVIVonk^k_ooool0]_ooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.6315 .61941 Mdot
.39739 .71995 Mdot
.50602 .49928 Mdot
.41852 .51191 Mdot
.53872 .72209 Mdot
.47997 .11633 Mdot
.49958 .63419 Mdot
.38564 .21237 Mdot
.62937 .78556 Mdot
.4329 .29586 Mdot
.56687 .45619 Mdot
.45716 .01438 Mdot
.64087 .33035 Mdot
.55158 .36776 Mdot
.43474 .04769 Mdot
.55733 .4902 Mdot
.4981 .16183 Mdot
.64989 .35672 Mdot
.47514 .19624 Mdot
.37438 .47912 Mdot
.63712 .32759 Mdot
.41503 .18545 Mdot
.44465 .11111 Mdot
.65847 .39053 Mdot
.61595 .15983 Mdot
.59215 .40729 Mdot
.56129 .5904 Mdot
.43121 .2728 Mdot
.38909 .26391 Mdot
.39935 .72966 Mdot
.64884 .3713 Mdot
.61743 .80961 Mdot
.38425 .76578 Mdot
.60378 .39097 Mdot
.58003 .70999 Mdot
.5303 .88533 Mdot
.66684 .32054 Mdot
.42916 .71134 Mdot
.40391 .18448 Mdot
.52272 .04093 Mdot
.64567 .19958 Mdot
.61617 .56635 Mdot
.42287 .79445 Mdot
.59646 .73244 Mdot
.64345 .55069 Mdot
.40624 .3916 Mdot
.50525 .25437 Mdot
.67752 .6833 Mdot
.51525 .8032 Mdot
.37522 .50042 Mdot
.68435 .65901 Mdot
.53652 .10265 Mdot
.70655 .22551 Mdot
.52261 .81984 Mdot
.46616 .87356 Mdot
.52424 .9381 Mdot
.39025 .18686 Mdot
.50716 .17357 Mdot
.70538 .51946 Mdot
.64501 .5042 Mdot
.41929 .28971 Mdot
.72334 .66351 Mdot
.40305 .19032 Mdot
.46635 .2643 Mdot
.43392 .94237 Mdot
.56553 .8878 Mdot
.41676 .41006 Mdot
.53866 .37266 Mdot
.41252 .60209 Mdot
.66697 .43901 Mdot
.58291 .31112 Mdot
.50855 .38181 Mdot
.4304 .30934 Mdot
.43817 .71739 Mdot
.40231 .1939 Mdot
.45076 .40145 Mdot
.70686 .22609 Mdot
.46826 .17638 Mdot
.49506 .05515 Mdot
.58763 .61235 Mdot
.66015 .60598 Mdot
.41705 .81411 Mdot
.4498 .72221 Mdot
.61018 .6084 Mdot
.37649 .70975 Mdot
.55258 .58615 Mdot
.52276 .75669 Mdot
.48573 .8131 Mdot
.46767 .14642 Mdot
.54184 .38603 Mdot
.61769 .16336 Mdot
.36059 .36756 Mdot
.5478 .49052 Mdot
.4178 .69635 Mdot
.53399 .38888 Mdot
.35783 .56929 Mdot
.54339 .34116 Mdot
.68769 .63843 Mdot
.72584 .26006 Mdot
.50235 .16324 Mdot
.61312 .6833 Mdot
.41345 .27754 Mdot
.431 .05165 Mdot
.56986 .78493 Mdot
.66871 .56229 Mdot
.61325 .44094 Mdot
.59592 .35026 Mdot
.53594 .2861 Mdot
.54805 .50036 Mdot
.66572 .4359 Mdot
.50633 .25302 Mdot
.41823 .51449 Mdot
.62824 .78991 Mdot
.44847 .92797 Mdot
.77895 .63305 Mdot
.51458 .63196 Mdot
.44771 .19743 Mdot
.48613 .98102 Mdot
.54702 .91399 Mdot
.63729 .25979 Mdot
.63494 .31627 Mdot
.74279 .57373 Mdot
.56238 .18659 Mdot
.4051 .17278 Mdot
.66744 .44483 Mdot
.42715 .36378 Mdot
.41819 .86456 Mdot
.40398 .91901 Mdot
.54547 .82011 Mdot
.42825 .5442 Mdot
.46436 .08829 Mdot
.58101 .75855 Mdot
.51551 .03621 Mdot
.52073 .15831 Mdot
.39041 .5105 Mdot
.46791 .04668 Mdot
.66859 .3177 Mdot
.37589 .56189 Mdot
.42241 .3574 Mdot
.36812 .58316 Mdot
.46358 .014 Mdot
.66718 .78994 Mdot
.49004 .74178 Mdot
.41776 .34194 Mdot
.5035 .16927 Mdot
.39012 .73767 Mdot
.40998 .88965 Mdot
.71253 .80103 Mdot
.51438 .24709 Mdot
.44683 .79278 Mdot
.74773 .54889 Mdot
.40255 .35802 Mdot
.47253 .79514 Mdot
.66398 .41283 Mdot
.49034 .32707 Mdot
.56232 .22862 Mdot
.62484 .22998 Mdot
.44682 .06832 Mdot
.50463 .9635 Mdot
.66134 .30879 Mdot
.63664 .25082 Mdot
.59692 .58194 Mdot
.50929 .06933 Mdot
.66875 .2314 Mdot
.60101 .77243 Mdot
.45537 .86139 Mdot
.62813 .62661 Mdot
.42987 .94102 Mdot
.65847 .62752 Mdot
.42375 .68777 Mdot
.64285 .25977 Mdot
.41541 .85199 Mdot
.54567 .48259 Mdot
.48389 .78946 Mdot
.53786 .72137 Mdot
.55379 .33657 Mdot
.39344 .8163 Mdot
.36657 .70739 Mdot
.5472 .20342 Mdot
.5291 .52705 Mdot
.39041 .25745 Mdot
.60763 .19754 Mdot
.57181 .09663 Mdot
.49795 .75124 Mdot
.66123 .22509 Mdot
.50685 .32939 Mdot
.64937 .74328 Mdot
.4225 .96869 Mdot
.61027 .82452 Mdot
.65144 .20321 Mdot
.39401 .60933 Mdot
.74573 .49748 Mdot
.3882 .72425 Mdot
.42312 .53123 Mdot
.73654 .60058 Mdot
.36555 .48948 Mdot
.71559 .337 Mdot
.46941 .00929 Mdot
.447 .79502 Mdot
.62176 .49264 Mdot
.49854 .32865 Mdot
.50838 .35909 Mdot
.5191 .43794 Mdot
.56198 .65443 Mdot
.607 .69731 Mdot
.52296 .62532 Mdot
.51889 .15796 Mdot
.41802 .47057 Mdot
.53814 .52831 Mdot
.57002 .5095 Mdot
.57774 .2022 Mdot
.45597 .1864 Mdot
.65772 .63017 Mdot
.54003 .63704 Mdot
.62391 .64284 Mdot
.42002 .29101 Mdot
.67042 .23524 Mdot
.52588 .39233 Mdot
.63225 .4074 Mdot
.48904 .00849 Mdot
.43895 .21639 Mdot
.70336 .51192 Mdot
.66436 .60052 Mdot
.64746 .65674 Mdot
.55619 .50222 Mdot
.5819 .55623 Mdot
.40905 .78749 Mdot
.54636 .48398 Mdot
.44298 .03423 Mdot
.73714 .61648 Mdot
.53847 .36706 Mdot
.44591 .39935 Mdot
.44926 .82613 Mdot
.55783 .61365 Mdot
.74531 .52779 Mdot
.45145 .77419 Mdot
.54114 .83335 Mdot
.57904 .21017 Mdot
.59203 .73572 Mdot
.72504 .65539 Mdot
.42107 .20251 Mdot
.62111 .73903 Mdot
.5814 .3074 Mdot
.59785 .84328 Mdot
.50876 .31005 Mdot
.5859 .17125 Mdot
.39746 .50329 Mdot
.57695 .29652 Mdot
.41717 .13417 Mdot
.70359 .30774 Mdot
.51969 .60947 Mdot
.42843 .60165 Mdot
.60808 .20645 Mdot
.58697 .39004 Mdot
.50188 .76521 Mdot
.40578 .72072 Mdot
.46501 .35888 Mdot
.37008 .3625 Mdot
.69652 .61127 Mdot
.47873 .84593 Mdot
.55821 .61205 Mdot
.63268 .70187 Mdot
.46506 .70681 Mdot
.39647 .50091 Mdot
.64187 .53475 Mdot
.51756 .28136 Mdot
.39771 .34798 Mdot
.48419 .93669 Mdot
.59856 .46983 Mdot
.47565 .94118 Mdot
.43231 .8257 Mdot
.43946 .27044 Mdot
.55076 .7301 Mdot
.62424 .22794 Mdot
.47105 .77281 Mdot
.58437 .47505 Mdot
.67518 .68692 Mdot
.57068 .50392 Mdot
.55468 .21395 Mdot
.42348 .11184 Mdot
.44392 .3299 Mdot
.50029 .74337 Mdot
.65705 .29976 Mdot
.40841 .11163 Mdot
.54642 .31069 Mdot
.43724 .43342 Mdot
.58018 .46519 Mdot
.49669 .93286 Mdot
.41456 .67362 Mdot
.66718 .5492 Mdot
.42934 .98204 Mdot
.70254 .47367 Mdot
.39727 .16006 Mdot
.69949 .45758 Mdot
.51589 .46715 Mdot
.70459 .47122 Mdot
.74199 .53102 Mdot
.54831 .8668 Mdot
.41696 .08875 Mdot
.6587 .88439 Mdot
.56389 .70009 Mdot
.3945 .36884 Mdot
.56259 .7944 Mdot
.60492 .8314 Mdot
.61669 .15871 Mdot
.53279 .3157 Mdot
.68121 .66598 Mdot
.59554 .43325 Mdot
.43855 .38872 Mdot
.55723 .17223 Mdot
.52933 .20952 Mdot
.61598 .27436 Mdot
.74843 .51059 Mdot
.50446 .66554 Mdot
.63897 .44999 Mdot
.6175 .47903 Mdot
.40175 .85119 Mdot
.44349 .6613 Mdot
.57695 .10346 Mdot
.72604 .3875 Mdot
.60284 .89244 Mdot
.49181 .25356 Mdot
.54026 .18598 Mdot
.60425 .63725 Mdot
.45046 .06518 Mdot
.57616 .60262 Mdot
.49396 .31558 Mdot
.51526 .54371 Mdot
.57776 .30164 Mdot
.44378 .02582 Mdot
.58721 .17563 Mdot
.53443 .3894 Mdot
.51156 .11074 Mdot
.42865 .44045 Mdot
.5196 .44264 Mdot
.40296 .7568 Mdot
.46392 .11892 Mdot
.45129 .85672 Mdot
.59735 .57771 Mdot
.57234 .61231 Mdot
.67824 .17886 Mdot
.58897 .4027 Mdot
.47041 .90345 Mdot
.45935 .27306 Mdot
.44576 .96321 Mdot
.56662 .54558 Mdot
.38318 .67479 Mdot
.39118 .65912 Mdot
.52904 .64404 Mdot
.40874 .61834 Mdot
.6684 .78839 Mdot
.45673 .01393 Mdot
.70637 .48078 Mdot
.50156 .9226 Mdot
.57487 .67108 Mdot
.6163 .44166 Mdot
.42368 .87747 Mdot
.41019 .69398 Mdot
.45114 .01924 Mdot
.56667 .93989 Mdot
.61199 .75845 Mdot
.50242 .02312 Mdot
.5873 .1164 Mdot
.67454 .24545 Mdot
.51915 .56888 Mdot
.48795 .8395 Mdot
.46285 .01482 Mdot
.37689 .28116 Mdot
.51207 .61048 Mdot
.66886 .49621 Mdot
.57859 .36609 Mdot
.53937 .18698 Mdot
.62046 .66063 Mdot
.67811 .67184 Mdot
.54788 .8224 Mdot
.68881 .38738 Mdot
.52535 .09426 Mdot
.42385 .15871 Mdot
.70314 .44478 Mdot
.43875 .12019 Mdot
.57756 .10921 Mdot
.75811 .7046 Mdot
.65861 .30677 Mdot
.59099 .28289 Mdot
.45742 .33551 Mdot
.70536 .32093 Mdot
.46115 .1497 Mdot
.5168 .51133 Mdot
.59412 .12319 Mdot
.66829 .44913 Mdot
.49217 .31149 Mdot
.42158 .63321 Mdot
.55249 .28714 Mdot
.54668 .65659 Mdot
.6649 .71819 Mdot
.65243 .65888 Mdot
.73932 .57592 Mdot
.58319 .11038 Mdot
.58357 .32105 Mdot
.63423 .12122 Mdot
.60538 .38888 Mdot
.55041 .32616 Mdot
.57823 .43059 Mdot
.46812 .65722 Mdot
.41726 .0804 Mdot
.44663 .025 Mdot
.56318 .57866 Mdot
.54028 .58968 Mdot
.53175 .70581 Mdot
.53343 .66526 Mdot
.73959 .42684 Mdot
.42283 .72355 Mdot
.59636 .78286 Mdot
.48086 .74845 Mdot
.46842 .79354 Mdot
.43848 .63777 Mdot
.47173 .82008 Mdot
.5918 .34828 Mdot
.52304 .72401 Mdot
.50979 .67136 Mdot
.74542 .56027 Mdot
.36859 .59538 Mdot
.44798 .52924 Mdot
.56227 .75055 Mdot
.59554 .34928 Mdot
.59038 .28621 Mdot
.58987 .41395 Mdot
.45446 .77961 Mdot
.71564 .34623 Mdot
.3712 .23983 Mdot
.5285 .8511 Mdot
.79209 .52245 Mdot
.57285 .7814 Mdot
.46652 .72769 Mdot
.61865 .80194 Mdot
.47697 .01172 Mdot
.56735 .46806 Mdot
.39576 .69826 Mdot
.68561 .19052 Mdot
.53459 .61777 Mdot
.45025 .33238 Mdot
.56608 .37877 Mdot
.63252 .70397 Mdot
.59561 .56668 Mdot
.40202 .07999 Mdot
.53116 .42229 Mdot
.57061 .72843 Mdot
.61656 .57029 Mdot
.51814 .3325 Mdot
.51589 .62284 Mdot
.4422 .7316 Mdot
.38494 .21735 Mdot
.46691 .71064 Mdot
.4746 .04623 Mdot
.43501 .86818 Mdot
.64383 .51263 Mdot
.44467 .92171 Mdot
.66778 .49024 Mdot
.56362 .27317 Mdot
.38854 .85976 Mdot
.41516 .56104 Mdot
.45539 .01305 Mdot
.70636 .31298 Mdot
.51364 .27361 Mdot
.70561 .47786 Mdot
.59485 .44114 Mdot
.43707 .19414 Mdot
.38464 .68973 Mdot
.60904 .69588 Mdot
.49297 .20694 Mdot
.40604 .58415 Mdot
.60629 .39939 Mdot
.71746 .68868 Mdot
.39666 .63615 Mdot
.44847 .41212 Mdot
.466 .8704 Mdot
.58064 .64378 Mdot
.51985 .5664 Mdot
.4997 .26814 Mdot
.52901 .8098 Mdot
.39014 .50984 Mdot
.52982 .48516 Mdot
.56633 .3236 Mdot
.56091 .89384 Mdot
.54199 .71555 Mdot
.64164 .48644 Mdot
.41272 .38373 Mdot
.41674 .35739 Mdot
.47017 .6934 Mdot
.78317 .61815 Mdot
.46055 .68354 Mdot
.40016 .73925 Mdot
.7015 .49649 Mdot
.58858 .79615 Mdot
.40828 .50385 Mdot
.37591 .43209 Mdot
.53415 .05428 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Qooooo`;o000000?oooooo`000?ooool00_ooool2o`0000;ooooo00?o0000ooooooooool0^Ooo
ool009gooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo00?o0000
ooooooooool0^Oooool009gooooo1Ol000001?mEEEGoIVIVo`000?l00006ooooo`03o`000?oooooo
oooo0;Wooooo002Kooooo`Oo00002_ooool00ol0003oooooooooo`2iooooo`00Voooool2o`0000oo
oooo00?o0000ooooooooool0^Oooool009Wooooo0ol0000@ooooo`?o0000^Oooool009Wooooo0ol0
000@ooooo`;o0000^_ooool00:cooooo00?o0000ooooooooool0^Oooool009Wooooo0_l0000Aoooo
o`03o`000?oooooooooo0;Wooooo002Iooooo`;o00004Oooool00ol0003oooooooooo`02ooooo`;o
0000]Oooool00:cooooo00?o0000ooooooooool00_ooool4o`000;?ooooo002/ooooo`03o`000?oo
oooooooo00Cooooo0_l0002cooooo`00XOooool4o`0000Oooooo00?o0000ooooooooool0^Oooool0
09Kooooo0_l00009ooooo`Co00001oooool00ol0003oooooooooo`2iooooo`00UOooool3o`0001Co
oooo0ol0002iooooo`00UOooool2o`0001?ooooo0ol0000:ooooo`;o0000[oooool00:[ooooo0ol0
000:ooooo`;o0000[oooool00:cooooo00?o0000ooooooooool0^Oooool009_ooooo0_l0000?oooo
o`03o`000?oooooooooo0;Wooooo002Jooooo`?o00003oooool00ol0003oooooooooo`2iooooo`00
V_ooool2o`00013ooooo00?o0000ooooooooool00_l0002gooooo`00[?ooool00ol0003ooooooooo
o`02o`000;Oooooo002/ooooo`?o0000^Oooool008_ooooo0_l00003ooooo`;o00006_ooool00ol0
003oooooooooo`2iooooo`00Roooool2o`0000?ooooo0_l0000Jooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002@ooooo`;o00003_ooool2o`0000[ooooo00?o
0000ooooooooool0^Oooool0093ooooo0_l0000>ooooo`;o00002_ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`05ooooo`;o0000/_ooool00:cooooo00?o0000oooooooo
ool01Oooool2o`0000gooooo0_l0002Sooooo`00[?ooool3o`0001Cooooo0_l0002Sooooo`00[?oo
ool00ol0003oooooooooo`09ooooo`;o00002oooool2o`000:7ooooo002/ooooo`03o`000?oooooo
oooo00Wooooo0_l0000;ooooo`;o0000XOooool00:cooooo00?o0000ooooooooool00_l0000Doooo
o`Co0000Woooool008gooooo0_l00003ooooo`;o00001Oooool2o`00017ooooo00?o0000oooooooo
ool00_l0000Dooooo`Co0000Woooool008gooooo0_l00003ooooo`;o00001Oooool2o`0000[ooooo
0_l00005ooooo`03o`000?oooooooooo01Wooooo0_l0002Nooooo`00ROooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00;ooooo0_l000000om4A4Co0000
o`000002o`0000Gooooo00?o0000ooooooooool06Oooool2o`0009kooooo0029ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@;ooooo0_l00002ooooo`03oeEEEOnYZJWooooo00;ooooo
0_l00003ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0:Oooool2o`0008kooooo
0021ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00Wooooo0_l00002ooooo`03ojVY
ZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`0001cooooo0_l0000;ooooo`;o0000
S_ooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Looooo`;o0000Voooool008Wooooo00Go
0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05oa0@4?ooooooooooooooool@
41000_ooool2o`0000[ooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0;Wooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool2o`0000Oo
oooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0^Oooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`00
00Kooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:7ooooo
0_l00009ooooo`03o`000?oooooooooo0;Wooooo002Oooooo`Co00002Oooool00ol0003ooooooooo
o`2iooooo`00Woooool2o`0000_ooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00T_ooool2o`0001Sooooo00?o0000ooooooooool00oooool2o`0001kooooo0_l0002Dooooo`00
R_ooool2o`0000Kooooo0_l0000Gooooo`;o00001Oooool2o`0001kooooo0_l0002Dooooo`00R_oo
ool2o`0001oooooo0ol0000Tooooo`;o0000U?ooool00:cooooo0_l0000Tooooo`;o0000U?ooool0
0:cooooo0ol0000Iooooo`;o0000W_ooool008cooooo0_l0000Nooooo`Co00003_ooool2o`0000So
oooo0_l0002Nooooo`00S?ooool2o`0001?ooooo0_l00009ooooo`Co00003_ooool2o`0000Sooooo
0_l0002Nooooo`00XOooool2o`0000Wooooo00?o0000ooooooooool06Oooool2o`0001cooooo0_l0
0020ooooo`00[?ooool00ol0003oooooooooo`0gooooo`;o0000P?ooool008cooooo0_l00002oooo
o`;o00002oooool2o`0000gooooo00?o0000ooooooooool02_ooool2o`000:gooooo0027ooooo`;o
00000oooool2o`0000;ooooo0_l0000;ooooo`;o00003Oooool00ol0003oooooooooo`0:ooooo`;o
00001Oooool2o`000:Kooooo0027ooooo`;o00000oooool2o`0001kooooo00?o0000ooooooooool0
2_ooool2o`0000Gooooo0_l0000Wooooo`;o0000OOooool008_ooooo0ol00009ooooo`;o00004ooo
ool00ol0003oooooooooo`0jooooo`;o0000OOooool008_ooooo0_l0000:ooooo`;o000000?ooooo
o`000?l000001oooool2o`0000Oooooo00?o0000ooooooooool08?ooool2o`0009Oooooo002Joooo
o`;o00001oooool2o`0000Oooooo0ol0000Pooooo`;o00002oooool2o`0008[ooooo002Booooo`;o
00006?ooool00ol0003oooooooooo`0<ooooo`;o00002?ooool2o`0001Gooooo1?l00028ooooo`00
T_ooool2o`0001Gooooo0_l000000ooooooo0000ooooo`0=ooooo`;o00002?ooool2o`0000Sooooo
0_l0000=ooooo`;o0000R?ooool00:Wooooo0_l000000ooooooo0000ooooo`07ooooo`;o00003ooo
ool2o`0000Oooooo0_l0002Gooooo`00Q_ooool2o`0002Cooooo00?o0000ooooooooool01_ooool2
o`0000oooooo0_l0002Pooooo`00Q_ooool2o`0000oooooo0_l0000Cooooo`03o`000?oooooooooo
00oooooo0_l0002Xooooo`00Q_ooool2o`0000oooooo0_l0000Cooooo`03o`000?oooooooooo00oo
oooo0_l0002Xooooo`00Q_ooool2o`0002Cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0
000booooo`;o00003Oooool2o`0007Kooooo002/ooooo`03o`000?oooooooooo017ooooo0_l0000C
ooooo`;o00002_ooool2o`0000gooooo0_l0001fooooo`00[?ooool00ol0003oooooooooo`0Aoooo
o`;o00004oooool2o`0000cooooo0_l0000;ooooo`;o0000M_ooool00:cooooo00?o0000oooooooo
ool09_ooool2o`0000cooooo0_l00023ooooo`00[?ooool00ol0003oooooooooo`0eooooo`;o0000
P_ooool0087ooooo0_l0000Yooooo`03o`000?oooooooooo03Gooooo0_l00022ooooo`00POooool2
o`0000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Gooooo00?o0000ooooooooool0^Oooool0097ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo03Kooooo
0_l00021ooooo`00ROooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`00
0?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l0000cooooo`;o0000POooool0097ooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo1_l0000Wooooo`;o
0000SOooool0097ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`00_ooool2o`000003ooooool0003o000000;o0000:Oooool2o`0008gooooo0027ooooo`;o
00002?ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01?ooool2o`00
0004ooooool0003o0000o`000;Wooooo0027ooooo`;o00002?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Zooooo`Co00006Oooool2
o`00073ooooo0027ooooo`;o00002?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00[ooooo1_l00006
ooooo`03o`000?oooooooooo02[ooooo1?l0000Iooooo`;o0000L?ooool008Oooooo0_l0000Goooo
o`;o00002Oooool2o`000;_ooooo002Hooooo`;o00004Oooool2o`000;_ooooo002Eooooo`;o0000
00?oooooo`000?l000001?ooool2o`0000cooooo00Co0000oooooooooooooooo0_l0000?ooooo`;o
0000YOooool009Gooooo0_l00007ooooo`;o00003?ooool3o`000003ooooool0003o000000oooooo
0_l0000?ooooo`;o0000U?ooool008oooooo0_l0000Kooooo`03o`000?oooooooooo02?ooooo0_l0
002Dooooo`00Poooool2o`0000[ooooo0_l0000Kooooo`03o`000?oooooooooo00;ooooo0_l0000G
ooooo`;o0000W?ooool008?ooooo0_l0000Wooooo`03o`000?oooooooooo00;ooooo0_l00004oooo
o`;o00004?ooool3o`0009cooooo002/ooooo`03o`000?oooooooooo00Sooooo0_l00004ooooo`;o
00002_ooool2o`0009gooooo002Aooooo`;o00006Oooool00ol0003oooooooooo`0>ooooo`;o0000
ZOooool0097ooooo0_l0000Iooooo`03o`000?oooooooooo0;Wooooo002Eooooo`;o00005Oooool0
0ol0003oooooooooo`0Fooooo`;o0000XOooool009Gooooo0_l0000Eooooo`?o00005_ooool2o`00
01Sooooo0_l00027ooooo`00[?ooool00ol0003oooooooooo`0Fooooo`;o00006?ooool2o`0008Oo
oooo002/ooooo`03o`000?oooooooooo01Kooooo0ol0000Hooooo`;o0000Q_ooool009Gooooo0_l0
000Eooooo`04o`000?oooooo0000o`0001Kooooo0_l0000Hooooo`?o00003?ooool2o`0007Oooooo
002Eooooo`;o00004_ooool2o`000003ooooool0003ooooo00;o00002oooool2o`0000[ooooo0_l0
000Hooooo`;o00003?ooool3o`0007Kooooo002Yooooo`Co00002Oooool2o`0000?ooooo0_l0000:
ooooo`;o00003oooool2o`0001Kooooo0_l0001fooooo`00Z_ooool3o`0000Wooooo0_l0000Poooo
o`;o00002Oooool2o`0008?ooooo002/ooooo`03o`000?oooooooooo01Sooooo0_l0000Jooooo`;o
00002_ooool2o`0007Oooooo002/ooooo`?o00004_ooool2o`0000Cooooo0_l0000Jooooo`;o0000
2_ooool2o`0007Oooooo002Xooooo`;o000000?oooooo`000?l000003oooool2o`0000?ooooo0_l0
000Fooooo`;o0000SOooool009Wooooo0_l0000=ooooo`;o000000Coooooo`000?l0003ooooo0_l0
000<ooooo`;o00006oooool3o`0008cooooo002Iooooo`Co00003oooool01?l0003oooooo`000?l0
0002ooooo`;o00009_ooool2o`0008cooooo002Kooooo`;o000000?oooooo`000?l000003?ooool0
0ol0003oooooooooo`03ooooo`;o00002Oooool2o`0003Cooooo0_l0001cooooo`00W_ooool2o`00
00cooooo00?o0000ooooooooool03_ooool2o`0003Cooooo0_l0001cooooo`00T?ooool2o`0001[o
oooo00?o0000ooooooooool02oooool2o`000:cooooo002@ooooo`;o00006_ooool00ol0003ooooo
ooooo`0;ooooo`;o0000=oooool2o`0007?ooooo002:ooooo`;o00008?ooool00ol0003ooooooooo
o`0Kooooo`?o00009_ooool2o`0007?ooooo002:ooooo`;o00008?ooool3o`0001_ooooo0ol0002K
ooooo`00[?ooool00ol0003oooooooooo`0Looooo`;o0000Voooool008_ooooo0_l00003ooooo`Co
00003?ooool2o`0000[ooooo00Co0000ooooool0003o0000;Oooool2o`0008Wooooo002;ooooo`;o
00000oooool4o`0000cooooo0_l0000:ooooo`04o`000?oooooo0000o`0002gooooo0_l00029oooo
o`00POooool2o`00017ooooo0_l0000Fooooo`03o`000?oooooooooo0;Wooooo001nooooo`;o0000
00?oooooo`000?l000001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o8B4Qo`000?l0
00000oooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
00Wooooo0_l00003ooooo`;o00001oooool2o`000:3ooooo001nooooo`;o00002Oooool2o`000003
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo00Wooooo0_l00003ooooo`;o00001oooool2o`00
0:3ooooo0021ooooo`Ko00000_ooool2o`0000;ooooo00?o410@ooooooooool02_ooool00onHV9So
8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool2o`0002?o
oooo0_l00029ooooo`00ROooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^
k^h01oooool00omgMgOo<S8booooo`04ooooo`?o00002Oooool2o`0002?ooooo0_l00029ooooo`00
ROooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool04_ooool2o`000:Gooooo0029ooooo`05
oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Oooooo00Co0000ooooool0003o00004Oooool2o`000:Gooooo0029ooooo`06ogMgMonHV9Sooooo
oiRHV?mgMgOooooo0_l00008ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooo
ooooo`07ooooo`04o`000?oooooo0000o`0000Wooooo0_l0002]ooooo`00ROooool01_o^k^ko<S8b
o`000?lb<S;ok^k^ooooo`;o00001_ooool2o`000005oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4
o`0000Kooooo00?o0000ooooooooool02?ooool4o`0001?ooooo0_l0000Jooooo`;o00002_ooool2
o`00073ooooo002=ooooo`;o00002?ooool2o`0001?ooooo00?o0000ooooooooool01Oooool2o`00
0003ooooool0003o000000oooooo0_l00004ooooo`;o00004?ooool2o`0000Sooooo0_l0000:oooo
o`;o0000L?ooool008gooooo0_l0000Mooooo`03o`000?oooooooooo00Gooooo0_l0000Booooo`;o
00001?ooool2o`00013ooooo0_l00026ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00V_oo
ool3o`0000oooooo0ol0000Pooooo`;o0000Uoooool009[ooooo0ol0000?ooooo`03o`000?oooooo
oooo01[ooooo0_l00004ooooo`;o0000Uoooool00:cooooo00?o0000ooooooooool06_ooool3o`00
00_ooooo0_l0002?ooooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool06oooool2o`0000_o
oooo0_l0002?ooooo`00T?ooool2o`0000Wooooo0_l0000?ooooo`03o`000?oooooooooo03?ooooo
0_l00024ooooo`00Voooool2o`0000oooooo00?o0000ooooooooool06_ooool2o`0001Oooooo0_l0
0024ooooo`00[?ooool00ol0003oooooooooo`0Jooooo`;o0000WOooool00:cooooo00?o0000oooo
ooooool01oooool2o`000;3ooooo002/ooooo`?o00001oooool2o`000;3ooooo002/ooooo`03o`00
0?oooooooooo04cooooo0_l0001[ooooo`00[?ooool00ol0003oooooooooo`0Fooooo`;o0000=?oo
ool2o`0006_ooooo0023ooooo`;o00004_ooool2o`0001?ooooo00?o0000ooooooooool05_ooool2
o`0000Cooooo0_l0002Kooooo`00Poooool2o`0001;ooooo0_l0000Cooooo`03o`000?oooooooooo
01cooooo0_l0000Eooooo`;o0000Q?ooool009Cooooo0_l0000Fooooo`03o`000?oooooooooo00?o
oooo0_l0000Mooooo`;o00003oooool3o`0008?ooooo002Dooooo`;o00005_ooool00ol0003ooooo
ooooo`03ooooo`;o00005oooool2o`0000Cooooo0ol0000?ooooo`;o0000Poooool00:cooooo00?o
0000ooooooooool00oooool2o`0001Oooooo0_l00005ooooo`;o00003oooool2o`0000[ooooo0_l0
001gooooo`00[?ooool00ol0003oooooooooo`0Zooooo`;o00002?ooool2o`0000[ooooo0_l0001g
ooooo`00[?ooool3o`0002[ooooo0_l00008ooooo`;o0000Poooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool04oooool2o`0002Wooooo0_l0001iooooo`002Ooo
ool4o`000003oa0@4?oooooooooo01Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM01Kooooo00?o0000ooooooooool04oooool2o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@08oooo
o`;o00001Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`00
0?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`Co000000?o410@oooooooo
ool04_ooool000_ooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool05Oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool0
0omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo0006o`0000Gooooo00?o0000oooo
ooooool04?ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGo
oooo00Sooooo00?o0000ooooooooool01Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
0_ooool2o`0000oooooo0_l00002ooooo`;o00000oooool00ol@413oooooooooo`0:ooooo`03oiRH
V?lQ8B7ok^k^00Wooooo00?o0000ooooooooool03Oooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool03Oooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEE
EOooool02?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Cooooo000;ooooo`03
o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo
00Kooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMg
oc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h00ooo
ool2o`0000;ooooo00?oMgMgoc8b<_ooool05Oooool00ol0003oooooooooo`02ooooo`;o00003ooo
ool2o`0000;ooooo0_l00003ooooo`?o00002oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Wooooo0_l00003ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8b
ooooo`0>ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03
ogMgMolb<S;ooooo01Wooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool0
6?ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool0
0_ooool2o`000004ob4Q8Ol0003o<S8bolc<c1Kooooo00?o0000ooooooooool06?ooool01?l0003o
ooooooooooooool3o`0000cooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Wooooo0ol00003ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00Jooooo`03o`000?oooooooooo01Cooooo000;ooooo`03
o`000?oooooooooo01Sooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo
00?ooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000
ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0Hooooo`?o00006?ooool2o`0000;ooooo00?o410@ooooooooool03Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo0_l00004ooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@
41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool05?ooool000_ooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o00001?ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0Hooooo`;o000000?ooooooiRHV?mgMgL01_ooool2o`0000?ooooo
00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00cooooo0_l00003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Dooooo`002Oooool00omEEEGoIVIVo`00000Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o00001?ooool01OnHV9So
410@o`000?lQ8B7oc<c<00Cooooo1?l0000Gooooo`03o`000?oooooooooo00cooooo0_l0000:oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool2o`0000?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c004ooooo`Co00002oooool3o`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co0000
4?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00006Oooool00omEEEGo
IVIVo`00000Fooooo`00[?ooool00ol0003oooooooooo`06ooooo`;o00001?ooool2o`0003?ooooo
0_l0001fooooo`00[?ooool00ol0003oooooooooo`06ooooo`;o00001?ooool2o`0001gooooo0_l0
002<ooooo`00Ooooool2o`0002_ooooo00?o0000ooooooooool03?ooool2o`000003ooooool0003o
000001[ooooo0_l00007ooooo`;o0000N?ooool2o`0000;ooooo0_l00005ooooo`00Ooooool2o`00
02_ooooo00?o0000ooooooooool03?ooool2o`000003ooooool0003o000001Cooooo0_l0000=oooo
o`;o0000N?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Gooooo002/ooooo`03o`000?oooooo
oooo02Gooooo0_l0000=ooooo`;o00002Oooool2o`0000gooooo0_l0001Oooooo`04omgMgOl0003o
410@olc<c0Kooooo0007oooooooo0000C?l0000<ooooo`04onk^k_lQ8B7o410@onk^kPKooooo0007
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04
ooooo`;o00001Oooool3o`000003ooooool0003o000000Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000ooooool0003o00001Ooo
ool00ol0003oooooooooo`03ooooo`Go00000oooool3o`0000Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`02ooooo`;o000000?oooooo`000?ooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00[ooooo00Co8B4QogMgMomgMgOo<S8b1_ooool000Oooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool01?ooool2o`000003ooooool0003o000001gooooo00?o0000ooooooooool03ooo
ool2o`0000?ooooo0_l0000Aooooo`03o`000?oooooooooo00;ooooo0_l0000Rooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`09ooooo`;o00000_oo
ool2o`0000Gooooo0027ooooo`;o00008oooool00ol0003oooooooooo`0Dooooo`;o0000>Oooool2
o`0006Sooooo0027ooooo`;o00002?ooool2o`0001Wooooo00?o0000ooooooooool00_ooool2o`00
013ooooo0_l0000Fooooo`;o00004_ooool2o`0000gooooo0_l0001Xooooo`00TOooool2o`0001Wo
oooo00?o0000ooooooooool00_ooool2o`0002Sooooo0_l0000Booooo`;o0000Moooool0097ooooo
0_l0000Iooooo`03o`000?oooooooooo043ooooo0_l0001gooooo`00[?ooool00ol0003ooooooooo
o`10ooooo`;o00006oooool2o`0005[ooooo002/ooooo`?o0000GOooool2o`0005[ooooo002/oooo
o`03o`000?oooooooooo00Kooooo0_l000000ooooooo0000o`000013ooooo`;o0000JOooool009;o
oooo0_l00006ooooo`;o00004?ooool00ol0003oooooooooo`06ooooo`;o000000?oooooo`000?l0
0000@Oooool4o`0006Wooooo002Booooo`;o00001_ooool2o`00013ooooo00?o0000ooooooooool0
:oooool2o`0001oooooo0_l0001[ooooo`00[?ooool00ol0003oooooooooo`0[ooooo`;o0000S?oo
ool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool00_ooool2o`00
0;Gooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`02ooooo`;o00003oooool2o`000:Co
oooo002Dooooo`;o00005_ooool00ol0003oooooooooo`0Cooooo`;o00007oooool2o`0001Sooooo
0_l0001Yooooo`00[?ooool3o`0002cooooo0_l00006ooooo`;o00006?ooool2o`0006Wooooo002/
ooooo`03o`000?oooooooooo02cooooo0_l0002;ooooo`00[?ooool00ol0003oooooooooo`0Hoooo
o`;o0000Woooool008?ooooo0_l0000;ooooo`;o00006_ooool00ol0003oooooooooo`0Hooooo`;o
0000=?ooool2o`0006Wooooo0023ooooo`;o00002oooool2o`0001[ooooo00?o0000ooooooooool0
=?ooool2o`0001Sooooo0_l0001Yooooo`00[?ooool00ol0003oooooooooo`03ooooo`;o00005ooo
ool2o`0000Gooooo0_l0000?ooooo`;o0000Poooool007gooooo0_l0000]ooooo`03o`000?oooooo
oooo00?ooooo0_l0000Gooooo`;o00001Oooool2o`0009Cooooo001mooooo`;o0000;Oooool00ol0
003oooooooooo`03ooooo`;o00007_ooool2o`0002Sooooo0_l0001Zooooo`00[?ooool3o`0004co
oooo0ol0001Zooooo`00[?ooool00ol0003oooooooooo`0Aooooo`;o00002_ooool2o`0002gooooo
0_l0001[ooooo`00P?ooool2o`0002[ooooo00?o0000ooooooooool04Oooool2o`0000[ooooo0_l0
002Jooooo`00P?ooool2o`0000_ooooo0_l0000Mooooo`03o`000?oooooooooo00kooooo0_l0000=
ooooo`;o0000V_ooool008gooooo0_l0000Mooooo`03o`000?oooooooooo00kooooo0_l0002Yoooo
o`00[?ooool00ol0003oooooooooo`0:ooooo`;o00001Oooool2o`000:Kooooo0020ooooo`;o0000
:_ooool00ol0003oooooooooo`0:ooooo`;o00001Oooool2o`000:Kooooo0020ooooo`;o0000:_oo
ool00ol0003oooooooooo`2iooooo`00[?ooool3o`0003?ooooo0_l0000Fooooo`;o0000K?ooool0
08oooooo0_l00003ooooo`;o00005_ooool00ol0003oooooooooo`0Fooooo`;o00006oooool2o`00
01Kooooo0_l0001/ooooo`00Soooool2o`0000?ooooo0_l0000Fooooo`03o`000?oooooooooo01Ko
oooo0_l0000Iooooo`;o0000Q_ooool008Wooooo0_l0000Qooooo`04o`000?ooooooooooooooo`Co
00007?ooool2o`0000kooooo0_l00026ooooo`00ROooool2o`00027ooooo00Co0000oooooooooooo
oooo1?l0000;ooooo`;o00000_ooool2o`0000?ooooo0_l00006ooooo`;o00006_ooool2o`0007[o
oooo002/ooooo`03o`000?oooooooooo013ooooo0_l00002ooooo`;o00000oooool2o`0002;ooooo
0_l0000<ooooo`;o0000K?ooool008Wooooo00Cok^k^oc8b<_l0003o<S8b0_l00004ooooo`;o8B4Q
1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00So
oooo0_l00006ooooo`;o00005_ooool2o`00027ooooo0_l0000=ooooo`;o0000GOooool008Wooooo
00CoMgMgoiRHV?ooooooV9RH0_l00004ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A4
00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`08ooooo`;o00007_ooool2o`00
033ooooo0_l0001Mooooo`00ROooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q
8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o00000_ooool4o`000;?ooooo0029ooooo`05
o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool00_ooool4o`00027ooooo0_l00008ooooo`;o0000Q_ooool008Wo
oooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo02Oooooo0_l00008ooooo`;o0000Q_ooool0
08Wooooo00Go410@oooooooooooooooooa0@4004ooooo`;o00002Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Kooooo0_l00003ooooo`;o0000;_ooool2o`0002Kooooo0_l0001N
ooooo`00ROooool2o`000003oooooonHV9SoMgMg00Cooooo0_l00003ooooo`?o000000Co^[Zjoooo
oonHV9So410@1?ooool00ol0003oooooooooo`06ooooo`;o00000oooool2o`0000Oooooo0_l0000C
ooooo`;o0000>?ooool2o`0005kooooo0029ooooo`?o000000?o<S8bonk^k_ooool02?ooool2o`00
0005oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool02_ooool2
o`0001?ooooo0_l0000Jooooo`;o0000O?ooool00:cooooo00?o0000ooooooooool05oooool2o`00
00cooooo0_l0000Dooooo`;o0000O?ooool00:cooooo00?o0000ooooooooool01_ooool2o`0000oo
oooo0_l0000<ooooo`;o0000T_ooool00:cooooo00?o0000ooooooooool01_ooool2o`000;7ooooo
002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool04Oooool2o`0003Cooooo0_l0001`
ooooo`00XOooool2o`0000Wooooo00?o0000ooooooooool03?ooool2o`0000?ooooo0_l0000Joooo
o`Co00002?ooool2o`0000cooooo0_l0001`ooooo`00R?ooool2o`0000oooooo0_l00006ooooo`;o
00002Oooool00ol0003oooooooooo`0<ooooo`;o00005_ooool2o`0000Oooooo1?l00008ooooo`;o
0000O_ooool008Sooooo0_l0000?ooooo`;o00004Oooool00ol0003oooooooooo`0Tooooo`;o0000
8?ooool2o`00077ooooo002/ooooo`?o00002?ooool2o`0002kooooo0_l0000<ooooo`;o0000LOoo
ool00:cooooo0ol00008ooooo`;o00002oooool2o`00027ooooo0_l0001oooooo`00Soooool2o`00
01_ooooo00?o0000ooooooooool00_l0000Cooooo`;o00008?ooool2o`00083ooooo0025ooooo`;o
00002?ooool2o`0001_ooooo1Ol0000eooooo`;o0000P?ooool008Gooooo0_l0000Uooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Oooooo`;o00002oooool0
0ol0003oooooooooo`0Rooooo`;o00004oooool2o`00083ooooo002Booooo`;o00002oooool2o`00
00_ooooo00?o0000ooooooooool08_ooool2o`0001;ooooo0ol0000;ooooo`;o0000Loooool008Go
oooo0_l0000;ooooo`;o00006?ooool00ol0003oooooooooo`0fooooo`;o00003?ooool2o`0007?o
oooo0025ooooo`;o00001oooool2o`0001;ooooo0_l00008ooooo`03o`000?oooooooooo0;Wooooo
0029ooooo`;o00000oooool4o`00013ooooo0_l00008ooooo`03o`000?oooooooooo023ooooo0ol0
002Fooooo`00ROooool2o`0000Gooooo0_l0000Jooooo`?o00004_ooool2o`0000cooooo0ol0002F
ooooo`00[?ooool00ol0003oooooooooo`0Booooo`;o00005?ooool2o`0008oooooo0020ooooo`;o
00007_ooool2o`0000[ooooo00?o0000ooooooooool01oooool2o`0001oooooo0_l0000Xooooo`;o
0000IOooool0083ooooo0_l000000ooooooo0000o`00000Kooooo`;o00002_ooool00ol0003ooooo
ooooo`07ooooo`;o00003_ooool2o`0003Wooooo0_l0001Uooooo`00Poooool2o`0000oooooo0_l0
000;ooooo`;o00002Oooool00ol0003oooooooooo`0Gooooo`;o0000X?ooool009Cooooo0_l0000;
ooooo`;o00002Oooool00ol0003oooooooooo`0:ooooo`;o0000[Oooool009Oooooo0_l0000Coooo
o`03o`000?oooooooooo00[ooooo0_l0000Wooooo`;o0000Q?ooool008[ooooo1?l00009ooooo`;o
00000_ooool2o`0000oooooo00?o0000ooooooooool02Oooool2o`0002Sooooo0_l00024ooooo`00
Qoooool2o`000003ooooool0003o000000;o00001?ooool2o`0000Oooooo0_l0000?ooooo`?o0000
1?ooool2o`0000?ooooo0_l0002^ooooo`00Qoooool2o`0000Wooooo0_l0000=ooooo`;o00002Ooo
ool00ol0003oooooooooo`04ooooo`;o00003_ooool2o`000:?ooooo002:ooooo`;o00003?ooool2
o`0000Oooooo0_l00009ooooo`03o`000?oooooooooo00gooooo0_l00005ooooo`;o0000Xoooool0
08[ooooo0_l0000<ooooo`;o00004_ooool00ol0003oooooooooo`0=ooooo`;o00003Oooool2o`00
09_ooooo0027ooooo`;o00008oooool00ol0003oooooooooo`0Kooooo`?o0000Voooool008Oooooo
0_l00002ooooo`;o00007oooool00ol0003oooooooooo`0Kooooo`;o00002?ooool2o`0009;ooooo
002;ooooo`;o00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`06odA4
A?l0003o0000oc8b<_oMgMgooooo0_l00002ooooo`;o00009_ooool2o`0000Oooooo0_l00029oooo
o`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
00;o00000_ooool2o`0002oooooo0_l00029ooooo`00TOooool01Ol@413ooooooooooooooooo410@
00oooooo0_l00005ooooo`03o`000?oooooooooo0;Wooooo002Aooooo`05o`000?oooooooooooooo
ool000003oooool2o`0000Cooooo1?l0000Aooooo`;o0000Y_ooool0097ooooo00Go0000oooooooo
ooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool2o`0001?ooooo0_l0002V
ooooo`00S?ooool2o`0000?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01?ooool2o`00017ooooo0_l00009ooooo`;o0000UOooool0
08cooooo0_l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Cooooo0_l0000Aooooo`;o00002Oooool2o`0009Gooooo002Aoooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0^Oooool0
08Gooooo0_l0000Uooooo`;o0000^_ooool008Gooooo0_l0000Uooooo`;o0000^_ooool00:;ooooo
0_l00008ooooo`03o`000?oooooooooo01kooooo0_l0002Iooooo`00W?ooool2o`0000Cooooo0_l0
0008ooooo`?o00007_ooool2o`0009Wooooo002Looooo`?o00003Oooool00ol0003oooooooooo`2i
ooooo`00WOooool2o`0000gooooo00?o0000ooooooooool05Oooool2o`0000Gooooo0_l0002Koooo
o`00[?ooool00ol0003oooooooooo`0Dooooo`?o00001Oooool2o`0000Wooooo0_l0002@ooooo`00
S_ooool2o`0001cooooo00?o0000ooooooooool05?ooool2o`00017ooooo0_l0000;ooooo`;o0000
Poooool008kooooo0_l0000Fooooo`;o00001?ooool00ol0003oooooooooo`0Wooooo`;o00002ooo
ool2o`0008?ooooo002Booooo`;o00001_ooool2o`0000Gooooo0ol00002ooooo`;o00001?ooool0
0ol0003oooooooooo`0Aooooo`;o00005?ooool2o`0000_ooooo0_l00023ooooo`00T_ooool2o`00
00Kooooo0_l00005ooooo`?o00002?ooool00ol0003oooooooooo`0Aooooo`;o00001oooool2o`00
09gooooo002/ooooo`?o00006_ooool2o`0002Oooooo0_l0001dooooo`00[?ooool00ol0003ooooo
ooooo`02ooooo`;o00008?ooool2o`0001gooooo0_l0001dooooo`00[?ooool00ol0003ooooooooo
o`02ooooo`;o00008?ooool2o`0009?ooooo002/ooooo`03o`000?oooooooooo00Kooooo0_l0000K
ooooo`;o0000U?ooool00:Oooooo0_l00003ooooo`03o`000?oooooooooo00Kooooo0_l0000Koooo
o`;o0000U?ooool008Sooooo0_l00006ooooo`;o00005Oooool2o`0000?ooooo00?o0000oooooooo
ool0^Oooool008Sooooo0_l00006ooooo`;o00006_ooool00ol0003oooooooooo`2iooooo`00X_oo
ool2o`0000Sooooo00?o0000ooooooooool01?ooool2o`0000Kooooo0_l0002[ooooo`00X_ooool2
o`0000Sooooo0ol00004ooooo`;o00001_ooool2o`0001?ooooo0_l0002Fooooo`00UOooool2o`00
00Cooooo0_l0000?ooooo`03o`000?oooooooooo027ooooo0_l0002Fooooo`00UOooool2o`0000Co
oooo0_l0000?ooooo`03o`000?oooooooooo01oooooo0_l0002Hooooo`00[?ooool00ol0003ooooo
ooooo`0:ooooo`;o00004oooool2o`0009Sooooo002/ooooo`03o`000?oooooooooo00[ooooo0_l0
002]ooooo`00Z?ooool2o`0000;ooooo00?o0000ooooooooool0^Oooool00:Sooooo0_l00002oooo
o`03o`000?oooooooooo01gooooo0_l0002Jooooo`00YOooool2o`0000Gooooo00?o0000oooooooo
ool07Oooool2o`0009[ooooo002Uooooo`;o00001Oooool00ol0003oooooooooo`2iooooo`00Rooo
ool2o`0000?ooooo0_l0000Jooooo`?o00001_ooool2o`000;7ooooo002;ooooo`;o00000oooool2
o`0001[ooooo00?o0000ooooooooool01_ooool2o`000;7ooooo002Kooooo`;o00003oooool00ol0
003oooooooooo`2iooooo`00Qoooool2o`0001;ooooo1?l0000=ooooo`03o`000?oooooooooo0;Wo
oooo0027ooooo`;o00002?ooool2o`0000[ooooo0_l0000=ooooo`03o`000?oooooooooo0;Wooooo
0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool2o`0000;o8B4Q1_ooool00ol0003ok^k^
ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0=ooooo`;o
0000Z_ooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q00?oooooo`000?l0
00000oooool00omEEEGoZJVYooooo`02ooooo`;o00000oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo00gooooo0_l0002Zooooo`00ROooool01Ol@413ooooooooooooooooo410@00So
oooo0_l00003ooooo`03ojVYZOmEEEGooooo00;ooooo0_l00004ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0^Oooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`04
ob4Q8Oooooooooooooooo`;o00000oooool00omgMgOo<S8booooo`04ooooo`?o0000^Oooool008Wo
oooo00Go0000ooooooooooooooooo`000004ooooo`;o00002?ooool00omEEEGoc<c<ooooo`03oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2iooooo`00ROooool01Ol@
413ooooooooooooooooo410@00Cooooo0_l00008ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`2iooooo`00ROooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool2o`0002Sooooo0_l00026ooooo`00ROooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`07ooooo`;o00002Ooo
ool2o`0001gooooo0_l00026ooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool04_ooool2
o`000:Gooooo002>ooooo`;o00007?ooool00ol0003oooooooooo`0Aooooo`;o00003?ooool2o`00
09Sooooo002/ooooo`03o`000?oooooooooo017ooooo0_l0000<ooooo`;o0000V?ooool00:cooooo
0ol0002iooooo`00X_ooool2o`0000Sooooo00?o0000ooooooooool0^Oooool00:;ooooo0_l00008
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00cooooo0_l0002[ooooo`00S?oo
ool2o`0001kooooo00?o0000ooooooooool03?ooool2o`000:_ooooo002<ooooo`;o00002oooool2
o`00017ooooo00?o0000ooooooooool0^Oooool009Wooooo0_l0000Aooooo`?o0000^Oooool009_o
oooo0_l0000?ooooo`;o0000^_ooool009_ooooo0_l0000?ooooo`03o`000?oooooooooo0;Wooooo
002Zooooo`?o0000^oooool00:Kooooo0_l00002ooooo`?o0000^oooool00:Kooooo0_l00004oooo
o`03o`000?oooooooooo00Gooooo0_l0000<ooooo`;o0000Y?ooool009Cooooo1?l0000<ooooo`;o
00001_ooool00ol0003oooooooooo`05ooooo`;o00003?ooool2o`000:Cooooo002Dooooo`Co0000
3?ooool2o`0000Kooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Ooo
ool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00V_ooool2o`00013ooooo0ol0
002iooooo`00V_ooool2o`00013ooooo0ol0002iooooo`00T_ooool2o`0001Sooooo00?o0000oooo
ooooool0^Oooool009;ooooo0_l0000Hooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000
^Oooool00:cooooo00?o0000ooooooooool0^Oooool009Cooooo0_l0000Aooooo`;o00000oooool0
0ol0003oooooooooo`2iooooo`00U?ooool2o`00017ooooo0_l00003ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002Rooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`2iooooo`00Y?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`03o`000?oooooooooo
00Gooooo0ol0002iooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003ooooo
ooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31
ooooo`00X_ooool00omEEEGoIVIVo`000033ooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00Z_ooool01?l@413o0000o`000?l0002jooooo`00Zoooool00ol0
003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool01_l0003oMgMg
o`000?l0003oEEEEonk^k[Oooooo002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoEEEE]oooool0
0:_ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`2eooooo`00Zoooool00ol0003o
k^k^ooooo`02ooooo`03o`000?oooooooooo0;Gooooo002[ooooo`06o`000?mEEEGok^k^oooooomg
MgOoIVIV]oooool00:[ooooo00?o410@o`000?mgMgL00_l000000omVIVKok^k^ooooo`2fooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.63927 .41941 Mdot
.54164 .83866 Mdot
.47084 .3652 Mdot
.48982 .74403 Mdot
.58755 .52209 Mdot
.39016 .56129 Mdot
.51326 .4342 Mdot
.43154 .95239 Mdot
.7036 .58556 Mdot
.43954 .728 Mdot
.50935 .25619 Mdot
.37284 .68296 Mdot
.53301 .13035 Mdot
.46114 .22121 Mdot
.38497 .77363 Mdot
.51341 .2902 Mdot
.39618 .47232 Mdot
.55257 .15672 Mdot
.40866 .56511 Mdot
.49221 .94385 Mdot
.52816 .12759 Mdot
.4193 .8299 Mdot
.39667 .71667 Mdot
.57468 .19053 Mdot
.44254 .02768 Mdot
.51507 .20729 Mdot
.55745 .3904 Mdot
.43487 .74037 Mdot
.44204 .92616 Mdot
.54366 .83324 Mdot
.55736 .1713 Mdot
.70128 .60961 Mdot
.55568 .90888 Mdot
.52017 .19097 Mdot
.62402 .50999 Mdot
.64443 .68533 Mdot
.55505 .12054 Mdot
.53337 .70202 Mdot
.4215 .87867 Mdot
.3669 .38937 Mdot
.48554 .00382 Mdot
.60271 .36635 Mdot
.55715 .76719 Mdot
.64943 .53244 Mdot
.62373 .35069 Mdot
.46621 .82366 Mdot
.41508 .42087 Mdot
.71084 .4833 Mdot
.59653 .6032 Mdot
.49668 .93559 Mdot
.70796 .45901 Mdot
.38212 .31456 Mdot
.55676 .02551 Mdot
.61054 .61984 Mdot
.58691 .7042 Mdot
.65948 .7381 Mdot
.42497 .93779 Mdot
.39712 .42992 Mdot
.67316 .31946 Mdot
.60669 .3042 Mdot
.44114 .78872 Mdot
.74875 .46351 Mdot
.42296 .88115 Mdot
.42542 .58876 Mdot
.60397 .83611 Mdot
.68065 .6878 Mdot
.46796 .77374 Mdot
.45308 .25965 Mdot
.51086 .75519 Mdot
.60257 .23901 Mdot
.46819 .13922 Mdot
.44319 .37842 Mdot
.44302 .73598 Mdot
.5335 .66849 Mdot
.4239 .88361 Mdot
.45873 .62716 Mdot
.55729 .02609 Mdot
.40581 .59946 Mdot
.37354 .50864 Mdot
.59257 .41235 Mdot
.66255 .40598 Mdot
.56345 .7998 Mdot
.53341 .62718 Mdot
.61354 .4084 Mdot
.54347 .92674 Mdot
.54704 .38615 Mdot
.58543 .55669 Mdot
.5735 .61969 Mdot
.3994 .60851 Mdot
.45961 .2498 Mdot
.44533 .0247 Mdot
.504 .29052 Mdot
.53172 .74448 Mdot
.45497 .27458 Mdot
.44655 .24518 Mdot
.70307 .43843 Mdot
.58986 .06006 Mdot
.3956 .45339 Mdot
.64644 .4833 Mdot
.43975 .81687 Mdot
.38664 .78912 Mdot
.64384 .58493 Mdot
.65363 .36229 Mdot
.54962 .24094 Mdot
.49603 .15072 Mdot
.42709 .28025 Mdot
.50819 .30036 Mdot
.60008 .2359 Mdot
.41465 .41637 Mdot
.49044 .74473 Mdot
.70421 .58991 Mdot
.6015 .7885 Mdot
.79217 .43305 Mdot
.52736 .43196 Mdot
.41485 .68461 Mdot
.64011 .78504 Mdot
.67262 .71399 Mdot
.5012 .05979 Mdot
.52145 .11627 Mdot
.73229 .37373 Mdot
.41257 .19152 Mdot
.41869 .876 Mdot
.60537 .24483 Mdot
.45561 .7384 Mdot
.57832 .82654 Mdot
.59566 .91022 Mdot
.63351 .62011 Mdot
.49476 .69457 Mdot
.38742 .63555 Mdot
.64443 .55855 Mdot
.36611 .4226 Mdot
.39322 .37266 Mdot
.49559 .86708 Mdot
.37757 .62903 Mdot
.55567 .1177 Mdot
.50997 .9217 Mdot
.45524 .76045 Mdot
.51634 .95445 Mdot
.37137 .65502 Mdot
.74316 .58994 Mdot
.54837 .54596 Mdot
.45288 .78412 Mdot
.39671 .44704 Mdot
.54748 .87499 Mdot
.5864 .87079 Mdot
.79295 .60103 Mdot
.41301 .3817 Mdot
.55524 .68399 Mdot
.72728 .34889 Mdot
.45968 .84703 Mdot
.5601 .62095 Mdot
.58912 .21283 Mdot
.43393 .47042 Mdot
.42468 .18724 Mdot
.47702 .04156 Mdot
.38686 .71642 Mdot
.65003 .7635 Mdot
.54485 .10879 Mdot
.49697 .05103 Mdot
.58969 .38194 Mdot
.374 .44311 Mdot
.52131 .0314 Mdot
.66998 .57243 Mdot
.57938 .71547 Mdot
.63877 .42661 Mdot
.60306 .84593 Mdot
.66947 .42752 Mdot
.5284 .71654 Mdot
.50676 .05977 Mdot
.57471 .82819 Mdot
.49871 .28267 Mdot
.56315 .59858 Mdot
.5864 .52137 Mdot
.45241 .21226 Mdot
.56728 .89153 Mdot
.545 .96974 Mdot
.40999 .24873 Mdot
.49992 .32705 Mdot
.44035 .92179 Mdot
.4488 .05516 Mdot
.39236 .16767 Mdot
.55851 .55141 Mdot
.51127 .02509 Mdot
.43145 .39742 Mdot
.70668 .54328 Mdot
.61168 .8881 Mdot
.70008 .62452 Mdot
.49273 .00428 Mdot
.51651 .83781 Mdot
.70472 .29748 Mdot
.54455 .87935 Mdot
.49304 .71974 Mdot
.73677 .40058 Mdot
.49638 .98016 Mdot
.61039 .137 Mdot
.36908 .63056 Mdot
.55596 .68507 Mdot
.36275 .68401 Mdot
.57882 .29264 Mdot
.4325 .4343 Mdot
.43805 .38411 Mdot
.46044 .32334 Mdot
.58375 .45443 Mdot
.35551 .45992 Mdot
.64592 .49731 Mdot
.53309 .42532 Mdot
.39308 .38098 Mdot
.4809 .75517 Mdot
.50946 .32831 Mdot
.53382 .3095 Mdot
.42668 .13637 Mdot
.41066 .65094 Mdot
.66978 .43017 Mdot
.55485 .43704 Mdot
.64104 .44284 Mdot
.44127 .78528 Mdot
.52452 .03524 Mdot
.45118 .30346 Mdot
.55521 .2074 Mdot
.36466 .54505 Mdot
.42088 .71876 Mdot
.66813 .31192 Mdot
.66457 .40052 Mdot
.67015 .45674 Mdot
.51708 .30222 Mdot
.56439 .35623 Mdot
.55704 .81639 Mdot
.49995 .28398 Mdot
.38024 .74058 Mdot
.74374 .41648 Mdot
.45123 .26053 Mdot
.45932 .64878 Mdot
.35573 .51891 Mdot
.5663 .70202 Mdot
.56329 .41365 Mdot
.71642 .32779 Mdot
.54935 .65627 Mdot
.63448 .63335 Mdot
.43013 .13221 Mdot
.64631 .53572 Mdot
.74719 .45539 Mdot
.42172 .79985 Mdot
.67672 .53903 Mdot
.46542 .14062 Mdot
.69516 .64328 Mdot
.42709 .39311 Mdot
.42264 .11059 Mdot
.49249 .83787 Mdot
.45754 .14678 Mdot
.40765 .83165 Mdot
.58669 .10774 Mdot
.52348 .40947 Mdot
.5073 .68415 Mdot
.45242 .05665 Mdot
.50299 .19004 Mdot
.56797 .56521 Mdot
.54016 .80312 Mdot
.44635 .57416 Mdot
.46768 .98783 Mdot
.70103 .41127 Mdot
.58212 .65916 Mdot
.56303 .41205 Mdot
.67343 .50187 Mdot
.52796 .56552 Mdot
.49219 .84269 Mdot
.61577 .33475 Mdot
.42102 .36006 Mdot
.45853 .87036 Mdot
.6211 .74246 Mdot
.54649 .26983 Mdot
.61728 .7547 Mdot
.56577 .75349 Mdot
.43257 .70482 Mdot
.6028 .5301 Mdot
.47565 .04092 Mdot
.55146 .6038 Mdot
.53439 .27505 Mdot
.70995 .48692 Mdot
.53225 .30392 Mdot
.41623 .21727 Mdot
.40141 .80891 Mdot
.44459 .67252 Mdot
.55763 .54337 Mdot
.53695 .09976 Mdot
.40462 .87478 Mdot
.43931 .23678 Mdot
.46863 .67929 Mdot
.52626 .26519 Mdot
.62993 .73311 Mdot
.52685 .75267 Mdot
.64686 .3492 Mdot
.61694 .88029 Mdot
.65201 .27367 Mdot
.4176 .91293 Mdot
.64252 .25758 Mdot
.46707 .33203 Mdot
.65308 .27122 Mdot
.7144 .33102 Mdot
.65503 .6668 Mdot
.39778 .84237 Mdot
.77246 .68439 Mdot
.60393 .50009 Mdot
.46378 .87986 Mdot
.64035 .5944 Mdot
.69748 .6314 Mdot
.44278 .02576 Mdot
.43359 .28795 Mdot
.7076 .46598 Mdot
.52884 .23325 Mdot
.45859 .68323 Mdot
.40605 .21351 Mdot
.40606 .32347 Mdot
.48577 .0792 Mdot
.71266 .31059 Mdot
.53067 .46554 Mdot
.57897 .24999 Mdot
.56911 .27903 Mdot
.57582 .87725 Mdot
.51791 .62437 Mdot
.39688 .14695 Mdot
.64104 .1875 Mdot
.71982 .69244 Mdot
.41756 .47994 Mdot
.40309 .28103 Mdot
.61915 .43725 Mdot
.38538 .70122 Mdot
.57721 .40262 Mdot
.43064 .45713 Mdot
.49281 .34725 Mdot
.46007 .14624 Mdot
.37824 .73891 Mdot
.42496 .10649 Mdot
.45541 .2731 Mdot
.38286 .424 Mdot
.47203 .71526 Mdot
.46208 .32098 Mdot
.54989 .82762 Mdot
.3942 .63081 Mdot
.57699 .72137 Mdot
.58843 .37771 Mdot
.57726 .41231 Mdot
.51004 .2027 Mdot
.59996 .72523 Mdot
.42884 .61744 Mdot
.61346 .82512 Mdot
.54485 .34558 Mdot
.5338 .891 Mdot
.52844 .85343 Mdot
.54665 .44404 Mdot
.51532 .77202 Mdot
.74376 .58839 Mdot
.37284 .68495 Mdot
.65868 .28078 Mdot
.6306 .7226 Mdot
.60331 .47108 Mdot
.55297 .24166 Mdot
.58212 .81707 Mdot
.53267 .77651 Mdot
.37521 .70818 Mdot
.70262 .73989 Mdot
.67537 .55845 Mdot
.36499 .48343 Mdot
.40668 .10809 Mdot
.53272 .04545 Mdot
.5067 .36888 Mdot
.58543 .64383 Mdot
.37171 .658 Mdot
.44845 .9757 Mdot
.51626 .41048 Mdot
.62734 .29621 Mdot
.48513 .17294 Mdot
.40308 .28461 Mdot
.64471 .46063 Mdot
.70684 .47184 Mdot
.63683 .6224 Mdot
.60376 .18738 Mdot
.37895 .36595 Mdot
.41156 .79716 Mdot
.64105 .24478 Mdot
.39993 .74044 Mdot
.39884 .14395 Mdot
.79995 .5046 Mdot
.54132 .10677 Mdot
.46509 .11443 Mdot
.44289 .61233 Mdot
.59373 .12093 Mdot
.40152 .63624 Mdot
.4821 .33142 Mdot
.41325 .08485 Mdot
.60795 .24913 Mdot
.43013 .46581 Mdot
.51589 .71548 Mdot
.43604 .21725 Mdot
.56932 .45659 Mdot
.71218 .51819 Mdot
.67598 .45888 Mdot
.72969 .37592 Mdot
.40238 .12313 Mdot
.47254 .14227 Mdot
.52093 .18888 Mdot
.44662 .22248 Mdot
.51047 .23059 Mdot
.51265 .52272 Mdot
.39589 .84288 Mdot
.37744 .72662 Mdot
.55464 .37866 Mdot
.53615 .38968 Mdot
.57407 .50581 Mdot
.55954 .46526 Mdot
.67033 .22684 Mdot
.53768 .73288 Mdot
.66951 .58286 Mdot
.54588 .56354 Mdot
.55824 .62764 Mdot
.51329 .64092 Mdot
.56907 .64522 Mdot
.49113 .15055 Mdot
.57264 .52401 Mdot
.53834 .47136 Mdot
.72953 .36027 Mdot
.51895 .95179 Mdot
.48723 .61163 Mdot
.62249 .55055 Mdot
.49526 .14993 Mdot
.46577 .11675 Mdot
.51545 .21395 Mdot
.55123 .6513 Mdot
.61413 .14623 Mdot
.62894 .6511 Mdot
.76107 .32245 Mdot
.64541 .5814 Mdot
.53486 .57692 Mdot
.69943 .60194 Mdot
.36798 .59703 Mdot
.51457 .26806 Mdot
.53669 .84013 Mdot
.54169 .41777 Mdot
.44376 .64435 Mdot
.47798 .19488 Mdot
.67411 .50397 Mdot
.58228 .36668 Mdot
.3991 .90953 Mdot
.46346 .28313 Mdot
.62198 .52843 Mdot
.60467 .37029 Mdot
.43308 .34654 Mdot
.52503 .42284 Mdot
.53693 .66039 Mdot
.43278 .95438 Mdot
.52924 .56272 Mdot
.37602 .59992 Mdot
.57929 .77524 Mdot
.60889 .31263 Mdot
.59849 .79195 Mdot
.62388 .29024 Mdot
.43917 .18078 Mdot
.57993 .93187 Mdot
.50127 .74814 Mdot
.37294 .69098 Mdot
.59155 .11298 Mdot
.41896 .37922 Mdot
.65676 .27786 Mdot
.5313 .24114 Mdot
.41643 .73179 Mdot
.53699 .88705 Mdot
.64739 .49588 Mdot
.40713 .48493 Mdot
.50831 .78528 Mdot
.52605 .19939 Mdot
.75293 .48868 Mdot
.52198 .8268 Mdot
.46155 .63483 Mdot
.58568 .70158 Mdot
.59815 .44378 Mdot
.50642 .3664 Mdot
.41904 .44233 Mdot
.61293 .6098 Mdot
.49551 .86839 Mdot
.48423 .29793 Mdot
.45805 .1772 Mdot
.67845 .69384 Mdot
.58821 .51555 Mdot
.59622 .28644 Mdot
.46309 .79708 Mdot
.45647 .78524 Mdot
.52376 .54015 Mdot
.79043 .41815 Mdot
.52107 .56552 Mdot
.54592 .83295 Mdot
.6601 .29649 Mdot
.66704 .59615 Mdot
.49028 .7905 Mdot
.48161 .94732 Mdot
.37054 .33544 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01?l000000ooooooo
0000ooooo`2jooooo`00Y?ooool00ol0003oooooooooo`04o`000003ooooool0003ooooo0;[ooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002Iooooo`?o00004?ooool5o`0000gooooo0_l0002Xooooo`00VOooool3
o`00013ooooo00?o0000ooooooooool00_l0000=ooooo`;o0000Z?ooool009Wooooo0_l0000Aoooo
o`03o`000?oooooooooo00Cooooo0_l00009ooooo`;o0000Z?ooool00:cooooo00?o0000oooooooo
ool01?ooool2o`000;?ooooo002/ooooo`03o`000?oooooooooo00Gooooo0_l0002booooo`00Y?oo
ool2o`0000Kooooo00?o0000ooooooooool01Oooool2o`000;;ooooo002Tooooo`;o00001_ooool0
0ol0003oooooooooo`2iooooo`00Y?ooool2o`0000Kooooo00?o0000ooooooooool01oooool2o`00
0;3ooooo002/ooooo`03o`000?oooooooooo00Oooooo0_l0002`ooooo`00Zoooool4o`000;Wooooo
002Kooooo`;o00003_ooool2o`000;_ooooo002Kooooo`?o00003_ooool00ol0003oooooooooo`2i
ooooo`00W?ooool2o`0000kooooo1?l0000Iooooo`;o0000WOooool00:cooooo1?l0000Iooooo`;o
0000WOooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Ooo
ool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00Yoooool2o`0000?o
oooo00?o0000ooooooooool0^Oooool00:Oooooo0_l00003ooooo`03o`000?oooooooooo0;Wooooo
002?ooooo`;o00006oooool00ol0003oooooooooo`2iooooo`00Soooool2o`0001_ooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol00009ooooo`;o0000[_oo
ool00:cooooo00?o0000ooooooooool02Oooool2o`000:kooooo002Cooooo`;o00005oooool00ol0
003oooooooooo`0:ooooo`;o0000[Oooool008gooooo0_l00003ooooo`?o00005oooool00ol0003o
ooooooooo`0:ooooo`?o00003?ooool2o`0009kooooo002=ooooo`;o00000oooool2o`0001Sooooo
00?o0000ooooooooool02oooool2o`0000cooooo1?l0002Looooo`00X?ooool2o`0000[ooooo00?o
0000ooooooooool01?ooool2o`0001Gooooo0_l0002Looooo`00ROooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00;ooooo0_l000001Om4A4Co0000o`00
0?lb<S;ogMgM00Gooooo00?o0000ooooooooool01?ooool2o`0000Wooooo0_l0002Xooooo`00ROoo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0?ooooo`;o00002oooool2o`0009_ooooo
0021ooooo`Ko00000_ooool01Ol@413oooooo`000?l0003o410@00gooooo00?oZJVYoeEEEOooool0
2?ooool00ol0003oooooooooo`03ooooo`?o00003oooool2o`0000_ooooo0_l0002Kooooo`00ROoo
ool00ol0003oooooo`000002o`0000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo00Kooooo0_l0002aooooo`00ROooool01Ol0003ooooooooooooo
oooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool01_ooool3o`000;3ooooo0029ooooo`05oa0@4?ooooooooooooooool@4100
1_ooool2o`0000Kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo0_l0002`ooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0ol00003ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo027ooooo0_l0002Fooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_l00004ooooo`Go00000_ooool6o`0000Kooooo00?o0000ooooooooool08Oooool2o`0009Ko
oooo002:ooooo`;o00005?ooool4o`0000Sooooo00?o0000ooooooooool0^Oooool008[ooooo0_l0
000Booooo`;o00000_ooool2o`0000Sooooo00?o0000ooooooooool08_ooool2o`0009Gooooo002:
ooooo`;o00004_ooool2o`0000[ooooo0ol0000Tooooo`;o0000UOooool00:Wooooo1_l0002ioooo
o`00ZOooool4o`000;_ooooo002/ooooo`03o`000?oooooooooo00kooooo0_l0002Yooooo`00[?oo
ool00ol0003oooooooooo`0>ooooo`;o0000ZOooool00:cooooo00?o0000ooooooooool0^Oooool0
08Sooooo0_l0000Rooooo`03o`000?oooooooooo0;Wooooo0028ooooo`;o00008_ooool00ol0003o
ooooooooo`0?ooooo`;o0000Z?ooool00:Oooooo0_l00003ooooo`03o`000?oooooooooo00oooooo
0_l0002Xooooo`00W_ooool2o`0000Oooooo0_l00003ooooo`?o0000^Oooool009kooooo0_l0000<
ooooo`03o`000?oooooooooo0;Wooooo002Gooooo`;o00004oooool00ol0003oooooooooo`2ioooo
o`00Uoooool2o`0001?ooooo00?o0000ooooooooool0^Oooool009?ooooo0_l0000Gooooo`03o`00
0?oooooooooo00?ooooo0_l0000Jooooo`;o00002_ooool2o`0008cooooo002?ooooo`;o00000_oo
ool2o`0001Oooooo0ol00003ooooo`;o00004?ooool2o`0000Sooooo0_l0000:ooooo`;o0000S?oo
ool008oooooo0_l0000Cooooo`;o00001_ooool3o`0000?ooooo0_l0000@ooooo`;o0000X_ooool0
0:Cooooo0_l00006ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o00001Oooool2o`000;;o
oooo002/ooooo`03o`000?oooooooooo00;o00000oooool2o`000;;ooooo002/ooooo`03o`000?oo
oooooooo00Co00002oooool2o`000:Sooooo002/ooooo`03o`000?oooooooooo00;ooooo0_l0000;
ooooo`;o0000Z?ooool008gooooo0_l0000=ooooo`;o00003_ooool00ol0003oooooooooo`0Joooo
o`;o0000WOooool008gooooo0_l0000=ooooo`;o00003_ooool00ol0003oooooooooo`02ooooo`;o
00005_ooool2o`0009gooooo002@ooooo`;o00001?ooool2o`0001Cooooo00?o0000ooooooooool0
0_ooool2o`000;Gooooo002@ooooo`;o00001?ooool2o`0000;ooooo0_l00003ooooo`;o00002ooo
ool00ol0003oooooooooo`2iooooo`00V_ooool2o`0000?ooooo0_l0000;ooooo`?o0000^Oooool0
0:cooooo00?o0000ooooooooool0=Oooool2o`0008;ooooo002/ooooo`03o`000?oooooooooo00;o
0000<oooool2o`0008;ooooo002/ooooo`03o`000?oooooooooo00;o00001?ooool2o`000;7ooooo
002Hooooo`;o00004_ooool00ol0003oooooooooo`06ooooo`;o00005_ooool2o`0009Wooooo002H
ooooo`;o00004_ooool00ol0003oooooooooo`0=ooooo`;o00003oooool2o`0009Wooooo002Aoooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@05ooooo`03o`000?oooooooooo00Oooooo0_l00004ooooo`?o00003_ooool2o`0009Wooooo002A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool2o`000003ob4Q8Ooooooooooo00Kooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`07ooooo`;o00001Oooool2o`0000oooooo0_l0
000:ooooo`;o0000S?ooool008Wooooo1ol000000ooooooo410@ooooo`02ooooo`03oa0@4?oooooo
oooo00;ooooo0_l00002ooooo`;o00001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo01Oooooo0_l00006ooooo`?o00002Oooool2o`0008cooooo002>ooooo`;o000000?oooooo`00
0?ooool00_ooool00ol0003oooooooooo`06ooooo`;o00001Oooool00omgMgOo<S8booooo`04oooo
o`?o00005oooool2o`0000Oooooo0_l0002Gooooo`00TOooool01Ol0003ooooooooooooooooo0000
00cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;Wooooo002Aoooo
o`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00;o0000:_ooool2o`0008_ooooo002Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool3
o`0000Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02o`0002[ooooo0_l0002;
ooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0ol00004ooooo`Co00001_ooool0
0ol0003oooooooooo`05ooooo`;o0000/_ooool00:cooooo00Co0000oooooooooooooooo0_l00002
ooooo`;o0000/_ooool00:cooooo00Co0000oooooooooooooooo0_l00009ooooo`;o00008Oooool2
o`0008Sooooo002Mooooo`;o00003Oooool00ol0003oooooooooo`0<ooooo`;o00008Oooool2o`00
08Sooooo002Mooooo`;o00003Oooool3o`0000Sooooo0_l0000Uooooo`;o0000R?ooool009?ooooo
0_l00008ooooo`;o00003Oooool00ol0003oooooooooo`08ooooo`;o00002Oooool2o`0001_ooooo
0_l00027ooooo`00S?ooool2o`0000Gooooo0_l0000;ooooo`;o00002Oooool2o`0001Gooooo0_l0
000Kooooo`?o0000Q_ooool008cooooo0_l0000Booooo`;o00002Oooool3o`0001gooooo0_l0000C
ooooo`;o0000Q_ooool008cooooo0_l00008ooooo`;o00005?ooool2o`0001gooooo0_l0002Koooo
o`00U_ooool2o`0001Cooooo0ol000000ooooooo0000o`00000Rooooo`;o0000T_ooool00:cooooo
0ol000000ooooooo0000o`00000Dooooo`;o00003?ooool2o`0009;ooooo002Vooooo`;o00001?oo
ool00ol0003oooooooooo`0Gooooo`;o00003_ooool2o`0000Sooooo0_l0000=ooooo`;o0000Mooo
ool00:Kooooo0_l00004ooooo`Co00009_ooool2o`0000Sooooo0_l0000=ooooo`;o0000Moooool0
09_ooooo0_l0000?ooooo`05o`000?oooooo0000o`000?ooool00_l00003ooooo`;o00005oooool2
o`0009Oooooo002Kooooo`;o00003oooool00ol0003oooooooooo`02ooooo`;o00000oooool2o`00
01Oooooo0_l0002Gooooo`00[?ooool00ol0003oooooooooo`08ooooo`;o0000>Oooool2o`0007Co
oooo002/ooooo`03o`000?oooooooooo00Sooooo0_l0000Gooooo`;o00004Oooool2o`0000gooooo
0_l0001dooooo`00QOooool2o`0002Gooooo00?o0000ooooooooool08Oooool2o`00017ooooo0_l0
0023ooooo`00QOooool2o`0002Gooooo00?o0000ooooooooool0=_ooool2o`00087ooooo002Ooooo
o`;o00002oooool00ol0003oooooooooo`0fooooo`;o00006oooool2o`0006Cooooo002=ooooo`;o
00004?ooool2o`0000_ooooo0ol0001Cooooo`;o0000I?ooool008gooooo0_l0000@ooooo`;o0000
2oooool2o`000003ooooool0003o000004;ooooo0_l0001cooooo`00Y_ooool2o`0000Cooooo0_l0
00000ooooooo0000o`000011ooooo`?o0000Loooool00:7ooooo0_l00003ooooo`;o00001?ooool0
0ol0003oooooooooo`0Sooooo`;o00007_ooool2o`0007Cooooo0021ooooo`;o00007_ooool2o`00
00Wooooo00?o0000ooooooooool08oooool2o`0009Cooooo0021ooooo`;o0000:Oooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00UOooool2o`0001Gooooo00?o
0000ooooooooool02oooool2o`000:cooooo002Eooooo`;o00004_ooool2o`000003ooooool0003o
oooo00cooooo0_l0000Pooooo`;o00006Oooool2o`0006oooooo002Yooooo`;o000000Coooooo`00
0?l0003o00009Oooool2o`0000Kooooo0_l0000Iooooo`;o0000Koooool00:cooooo00?o0000oooo
ooooool09Oooool2o`0009;ooooo002/ooooo`03o`000?oooooooooo01;ooooo0_l0002Uooooo`00
TOooool2o`0001Wooooo00?o0000ooooooooool04_ooool2o`0003Cooooo0_l0001_ooooo`00TOoo
ool2o`0000oooooo0_l00008ooooo`03o`000?oooooooooo02oooooo0_l0000Gooooo`;o0000Kooo
ool008Cooooo0_l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0
0004ooooo`?o000000?o<S8bomgMgOooool01?ooool01?l0003oooooo`000?l0000Gooooo`;o0000
1?ooool2o`0000oooooo0_l00028ooooo`00Q?ooool2o`0000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_oo
ool01?ooool01?l0003oooooo`000?l0000Gooooo`;o00001?ooool3o`0009Sooooo0021ooooo`Ko
000000?oooooo`000?l000000oooool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Wo
oooo00?o0000ooooooooool00oooool01?l0003oooooo`000?l0000Nooooo`;o0000:?ooool2o`00
06kooooo0028ooooo`;o00000oooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo00?oMgMgoc8b<_ooool01?ooool3o`0004Sooooo0ol0001^ooooo`00ROooool01Ol0003ooooo
oooooooooooo000000?ooooo0_l00006ooooo`;o000000?oooooogMgMomVIVH01?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool03oooool2o`0000Wooooo0_l0000/oooo
o`;o0000Koooool008Sooooo0_l00003ooooo`03oa0@4?oooooo000000?o00001_ooool2o`0000;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oo
oooo0_l00009ooooo`;o0000WOooool008Sooooo0_l000001OnHV9SooooooiRHV?mgMgOooooo00;o
00001_ooool3o`000004okZj^_ooooooV9RHoa0@40Cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0<ooooo`;o00003?ooool2o`0009gooooo0020ooooo`;o00001oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Wooooo0_l000001OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006
ooooo`03o`000?oooooooooo00cooooo0_l0002[ooooo`00P?ooool2o`0002[ooooo00?o0000oooo
ooooool02?ooool2o`0000Kooooo0_l0002Wooooo`00Toooool2o`0001Oooooo00?o0000oooooooo
ool02?ooool2o`0000Kooooo0_l0002Wooooo`00Toooool4o`0001Gooooo00?o0000ooooooooool0
^Oooool009Gooooo0_l0000Eooooo`?o0000<oooool2o`0001Kooooo0_l0001/ooooo`00[?ooool0
0ol0003oooooooooo`0Fooooo`;o00006oooool2o`0001Kooooo0_l0001/ooooo`00[?ooool00ol0
003oooooooooo`0Fooooo`;o00006_ooool2o`0008Gooooo002/ooooo`03o`000?oooooooooo00;o
oooo1?l0000Looooo`;o00003_ooool2o`0008Gooooo002/ooooo`03o`000?oooooooooo00;ooooo
1?l0000;ooooo`;o00000oooool2o`0000?ooooo0_l00005ooooo`;o00006oooool2o`0007Sooooo
002?ooooo`;o00006oooool00ol0003oooooooooo`0Aooooo`;o00000oooool2o`0000?ooooo0_l0
000Rooooo`;o00003?ooool2o`0006[ooooo002?ooooo`;o00006oooool00ol0003oooooooooo`0:
ooooo`;o00007oooool2o`00023ooooo0_l0000=ooooo`;o0000Foooool007oooooo0_l0000?oooo
o`;o00006_ooool00ol0003oooooooooo`0:ooooo`;o00007oooool2o`0002oooooo0_l0001Koooo
o`00Ooooool2o`0000Cooooo0_l00009ooooo`;o00006_ooool3o`0000Gooooo1?l0002`ooooo`00
QOooool2o`0002Gooooo00?o0000ooooooooool01Oooool4o`00027ooooo0_l00009ooooo`;o0000
P_ooool008[ooooo0_l0000Pooooo`03o`000?oooooooooo02[ooooo0_l00009ooooo`;o0000P_oo
ool008[ooooo0_l00009ooooo`;o00005Oooool01?l0003oooooooooooooool2o`0000?ooooo0_l0
000]ooooo`;o00009_ooool2o`0005[ooooo002Eooooo`;o00005Oooool01?l0003ooooooooooooo
ool2o`0000?ooooo0_l00007ooooo`;o00004oooool2o`0003Oooooo0_l0001Jooooo`00[?ooool0
0ol0003oooooooooo`0?ooooo`;o00004oooool2o`0001[ooooo0_l0001gooooo`00P_ooool2o`00
00gooooo0_l0000Iooooo`03o`000?oooooooooo01gooooo0_l0000<ooooo`;o00004oooool2o`00
07Oooooo0022ooooo`;o00003Oooool2o`0001Wooooo00?o0000ooooooooool03?ooool2o`0000oo
oooo0_l0000<ooooo`;o0000S?ooool008Wooooo0_l0000Qooooo`03o`000?oooooooooo00cooooo
0_l0002[ooooo`00ROooool2o`00027ooooo0ol0002iooooo`00ROooool2o`00027ooooo00?o0000
ooooooooool06?ooool2o`0003Cooooo0_l0001Yooooo`00ROooool2o`0000[ooooo0_l0000Eoooo
o`03o`000?oooooooooo01?ooooo0_l00003ooooo`;o00006oooool4o`0000Sooooo0_l0000;oooo
o`;o0000JOooool000Wooooo1?l000000ol@413oooooooooo`0Fooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;o
gMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`00
0?lb<S;ogMgM00oooooo00Cok^k^oc8b<_l0003o<S8b0_l00004ooooo`;o8B4Q1?ooool5o`0000Co
oooo00CoA4A4o`000?l0003o<S8b0_l0000Eooooo`03o`000?oooooooooo01?ooooo0_l00003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1_l00003ooooo`04odA4A?l0003o
0000oc8b<PCo00002?ooool2o`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd06?ooool4
o`000003oa0@4?oooooooooo01;ooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;o
oooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8boooo
o`0>ooooo`04ogMgMonHV9SooooooiRHV0;o00001?ooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A007ooooo`03ogMgMolb<S;ooooo01Gooooo00?o0000ooooooooool06?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`04oiRHV?lQ8B7ok^k^ooooo`;o00001_ooool0
0omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0000Sooooo00?o
MgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEE
EOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool06Oooool00ol0003oooooooooo`0Dooooo`001_l0
0005ooooo`03o`000?oooooooooo013ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@4100
3Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`05ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02?ooool2o`0001Kooooo00?o0000oooo
ooooool01oooool2o`0000Oooooo0_l00006ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00Wooooo0_l00002ooooo`05oa0@4?oooooo
ooooooooool@41001Oooool2o`0000Wooooo00?o0000ooooooooool03Oooool01Ol@413ooooooooo
oooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooo
oooooooooooo000000oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h01oooool4o`0001Cooooo00?o0000ooooooooool01oooool2o`00
00Oooooo0_l00006ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000Wooooo00?oV9RH
ob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`0:ooooo`;o00000_ooool01Ol0003ooooooooooooo
oooo000000oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000kooooo
00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo
000;ooooo`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEE
EOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?oooooooooooooo
ool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00
000<ooooo`;o000000?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;o0000
5?ooool00ol0003oooooooooo`09ooooo`;o00003Oooool01Ol0003ooooooooooooooooo000000;o
oooo0_l0000:ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00;oooo
o`;o00000_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00?ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`06_ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003ooooo
ooooo`0Hooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03
o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo
017ooooo00Go410@oooooooooooooooooa0@400<ooooo`;o000000?oooooo`000?ooool00oooool0
0ol0003oooooooooo`0Hooooo`?o00002Oooool2o`0000gooooo00Go410@oooooooooooooooooa0@
400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool2o`0000;ooooo00Go
410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooo
oooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool04Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`;o00006_ooool00ol0003ooooo
ooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@
00Cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000
ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooo
oc8b<P04ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05?ooool000Wooooo00?o
EEEEofIVI_l000006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co0000
4?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo1Ol0000Gooooo`03o`000?oooooo
oooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0_l00002ooooo`Co00003Oooool2o`000006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool4o`00
013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0001Wooooo00?oEEEE
ofIVI_l000005_ooool007oooooo0_l0000<ooooo`;o00007Oooool00ol0003oooooooooo`0]oooo
o`;o00004oooool2o`0007Gooooo001oooooo`;o00003?ooool2o`0001gooooo00?o0000oooooooo
ool0@_ooool2o`0000cooooo0_l0001Wooooo`00[?ooool00ol0003oooooooooo`12ooooo`;o0000
3?ooool2o`0005cooooo0_l00002ooooo`;o00001Oooool00:cooooo00?o0000ooooooooool0[_oo
ool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Gooooo002/ooooo`03o`000?oooooooooo02gooooo
0_l00020ooooo`04omgMgOl0003o410@olc<c0Kooooo0007oooooooo0000C?l0000<ooooo`04onk^
k_lQ8B7o410@onk^kPKooooo0007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`?o00001_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00Co8B4QogMgMomgMgOo
<S8b1_ooool000Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Eooooo`;o0000
4?ooool00ol0003oooooooooo`0<ooooo`;o00006?ooool00ol0003oooooooooo`0=ooooo`;o0000
5oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Wooooo0_l00002ooooo`;o0000
1Oooool008;ooooo0_l0000Xooooo`03o`000?oooooooooo01Gooooo0_l0000?ooooo`;o0000>?oo
ool2o`0005Oooooo0022ooooo`;o0000:?ooool00ol0003oooooooooo`0Vooooo`;o0000TOooool0
0:cooooo00?o0000ooooooooool06_ooool2o`0009gooooo001looooo`;o0000;_ooool00ol0003o
ooooooooo`0Jooooo`;o00009oooool2o`0007Cooooo001looooo`;o0000;_ooool01?l0003ooooo
ooooooooool2o`0001Kooooo0_l0000Xooooo`;o0000M?ooool00:cooooo0ol000000ooooooo0000
o`00000Booooo`;o00000_ooool2o`0009kooooo002/ooooo`03o`000?oooooooooo01Gooooo0_l0
000>ooooo`;o0000T_ooool00:cooooo00?o0000ooooooooool07_ooool2o`0000Gooooo0_l0002B
ooooo`00[?ooool00ol0003oooooooooo`0Nooooo`;o00003_ooool2o`0008Wooooo002/ooooo`03
o`000?oooooooooo02gooooo0ol00029ooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o0000
9oooool2o`0000Sooooo0_l00020ooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o00002_oo
ool2o`0002Gooooo0_l00008ooooo`;o0000M_ooool007oooooo0_l0000[ooooo`03o`000?oooooo
oooo00gooooo0_l000000ooooooo0000o`00000_ooooo`;o0000M_ooool007oooooo0_l0000[oooo
o`03o`000?oooooooooo00gooooo0_l0002Zooooo`00[?ooool3o`00013ooooo0_l0000Cooooo`;o
0000T_ooool00:cooooo00?o0000ooooooooool04?ooool2o`0001?ooooo0_l0002Booooo`00[?oo
ool00ol0003oooooooooo`0Iooooo`;o00004Oooool2o`0000Sooooo0_l00021ooooo`00Qoooool2
o`0002?ooooo00?o0000ooooooooool06Oooool2o`00017ooooo0_l00008ooooo`;o0000POooool0
08Oooooo0_l00004ooooo`;o00007Oooool00ol0003oooooooooo`06ooooo`;o00001?ooool2o`00
0:_ooooo002=ooooo`;o00007Oooool00ol0003oooooooooo`04ooooo`Co00001?ooool2o`0000Go
oooo0_l0002Tooooo`00[?ooool00ol0003oooooooooo`04ooooo`Co00002oooool2o`000:Cooooo
002Jooooo`;o00004?ooool00ol0003oooooooooo`0eooooo`;o0000P_ooool009[ooooo0_l0000@
ooooo`?o00002?ooool2o`0002_ooooo0_l00022ooooo`00[?ooool00ol0003oooooooooo`08oooo
o`;o0000[oooool00:cooooo00?o0000ooooooooool0;Oooool2o`0000Kooooo0_l00022ooooo`00
[?ooool00ol0003oooooooooo`0/ooooo`?o00001_ooool2o`0000Wooooo0_l0001gooooo`00Tooo
ool2o`0001Oooooo00?o0000ooooooooool0;?ooool2o`0001;ooooo0_l0000;ooooo`;o0000J_oo
ool009?ooooo0_l0000Gooooo`03o`000?oooooooooo043ooooo0_l0000;ooooo`;o0000J_ooool0
0:cooooo00?o0000ooooooooool0:oooool2o`0001?ooooo0_l0000;ooooo`;o0000J_ooool0083o
oooo0_l0000Zooooo`03o`000?oooooooooo02_ooooo0_l00007ooooo`;o0000Poooool0083ooooo
0_l000000ooooooo0000o`000007ooooo`;o00007_ooool3o`00017ooooo0_l0000Qooooo`;o0000
9oooool2o`0005[ooooo0023ooooo`;o00001oooool2o`0001kooooo00?o0000ooooooooool03_oo
ool2o`000003ooooool0003o000000Wooooo0_l0000Pooooo`;o00007Oooool2o`0005[ooooo002/
ooooo`03o`000?oooooooooo00kooooo0_l0000<ooooo`;o00008?ooool2o`0007Wooooo002:oooo
o`;o00008?ooool00ol0003oooooooooo`0Rooooo`;o00006oooool2o`0007Sooooo002:ooooo`;o
00003Oooool2o`0000cooooo0_l00003ooooo`03o`000?oooooooooo02;ooooo0_l0000Kooooo`;o
0000N?ooool009Wooooo0_l0000<ooooo`;o00000oooool00ol0003oooooooooo`2iooooo`00ROoo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o8B4Qo`000?l000000oooool5o`0000Cooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool00olQ8B7o0000o`000003ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo013ooooo0_l00003oooo
o`;o00002_ooool2o`0000Kooooo0ol0002=ooooo`00ROooool01Ol@413ooooooooooooooooo410@
00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o00000_ooool2o`00
00cooooo0_l00003ooooo`;o00002_ooool2o`0000Kooooo0ol0000Cooooo`;o0000N?ooool008Wo
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00;o00001Oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`;o00001_ooool2o`00
02gooooo0_l0001hooooo`00P?ooool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`03
o`000?oooooooooo00cooooo00CoMgMgofIVI_l0003o00000_ooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool02?ooool2o`0000Kooooo0_l0000/ooooo`;o0000NOooool0
083ooooo0_l000000ooooooo0000o`000004ooooo`;o00000_ooool00ol@413oooooooooo`0=oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Yoooo
o`;o00004oooool2o`0007Wooooo0026ooooo`;o000000?oooooogMgMonHV9P00_l000000omgMgOo
ooooooooo`09ooooo`06o`000?nj^[[ooooooiRHV?l@413ooooo0_l000000ooooooo0000ooooo`08
ooooo`03o`000?oooooooooo02Wooooo0_l0002>ooooo`00Q_ooool2o`000003ooooooo^k^ko<S8b
00;o000000?ok^k^ooooooooool02Oooool01_nHV9So410@o`000?lQ8B7oc<c<ooooo`;o000000?o
ooooo`000?l000000_l00006ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`04o`000?oooooo
ooooooooo`;o00005_ooool2o`0002;ooooo0_l0001jooooo`00VOooool2o`00017ooooo00Co0000
oooooooooooooooo0_l0000@ooooo`;o00001?ooool2o`0002;ooooo0_l0001jooooo`00VOooool2
o`0000?ooooo0_l0000<ooooo`03o`000?oooooooooo01?ooooo0_l0002Tooooo`00S_ooool2o`00
00kooooo0_l0000<ooooo`?o00003Oooool2o`0001Sooooo0_l0002@ooooo`00POooool2o`0000_o
oooo0_l0000Looooo`03o`000?oooooooooo00gooooo0_l0000Hooooo`;o0000T?ooool0087ooooo
0_l0000Yooooo`03o`000?oooooooooo00gooooo0_l0002Zooooo`00POooool2o`0002Wooooo00?o
0000ooooooooool02Oooool2o`0000;ooooo0_l00009ooooo`;o0000Woooool00:cooooo00?o0000
ooooooooool02Oooool2o`0000gooooo0_l0002Oooooo`00[?ooool00ol0003oooooooooo`0`oooo
o`;o0000Qoooool00:cooooo00?o0000ooooooooool02?ooool2o`0002Kooooo0_l00027ooooo`00
VOooool2o`00017ooooo00?o0000ooooooooool02?ooool2o`000:oooooo002Iooooo`;o00004Ooo
ool3o`000;Wooooo002Qooooo`;o00002Oooool00ol0003oooooooooo`2iooooo`00P_ooool2o`00
01[ooooo0_l000000ooooooo0000o`000009ooooo`03o`000?oooooooooo0;Wooooo001nooooo`;o
00000_ooool2o`0000_ooooo0_l0000=ooooo`;o00003?ooool01?l0003oooooo`000?l0000>oooo
o`;o00006oooool2o`0002Wooooo0_l0001Pooooo`00O_ooool2o`0000;ooooo0_l0000;ooooo`;o
00006oooool01?l0003oooooo`000?l0000>ooooo`;o00006oooool2o`0000[ooooo0_l0000Moooo
o`;o0000H?ooool008;ooooo0_l0000Xooooo`03o`000?oooooooooo03Sooooo0_l0001oooooo`00
P_ooool2o`0002Kooooo0ol0000iooooo`;o00003?ooool2o`0007;ooooo002Zooooo`?o0000>Ooo
ool2o`0000cooooo0_l0001booooo`00Q_ooool2o`0002Cooooo0ol0002iooooo`00Q_ooool2o`00
02Cooooo00?o0000ooooooooool02?ooool2o`0000Sooooo0_l00005ooooo`;o0000W_ooool009Go
oooo0_l0000Eooooo`03o`000?oooooooooo00Sooooo0_l00008ooooo`;o00001Oooool2o`0009ko
oooo0022ooooo`;o00004Oooool2o`0001Gooooo00?o0000ooooooooool0^Oooool008;ooooo0_l0
000Xooooo`03o`000?oooooooooo0;Wooooo0026ooooo`;o00006_ooool2o`0000Sooooo00?o0000
ooooooooool00_ooool2o`0000;ooooo0_l0000?ooooo`;o00007Oooool2o`00087ooooo0026oooo
o`;o000000?oooooo`000?l000001_ooool2o`0000oooooo0_l00008ooooo`03o`000?oooooooooo
00;ooooo0_l00002ooooo`;o00003oooool2o`0001gooooo0_l00021ooooo`00ROooool2o`0000Ko
oooo0_l0000Fooooo`;o000000?oooooo`000?ooool05oooool2o`00013ooooo0_l0002?ooooo`00
ZOooool2o`000004ooooool0003o0000o`0001Kooooo0_l00006ooooo`;o00002?ooool2o`0008oo
oooo0023ooooo`;o00004oooool2o`0001;ooooo00?o0000ooooooooool07_ooool2o`0009Wooooo
0023ooooo`;o00004oooool2o`0001;ooooo00?o0000ooooooooool0^Oooool0093ooooo0_l0000J
ooooo`03o`000?oooooooooo00Wooooo0_l0000Looooo`;o0000T?ooool0093ooooo0_l00007oooo
o`;o00004Oooool00ol0003oooooooooo`09ooooo`;o00007?ooool2o`00093ooooo0023ooooo`?o
00001Oooool2o`0000Wooooo0_l000000ooooooo0000o`000002ooooo`;o00003Oooool00ol0003o
ooooooooo`0aooooo`;o00003?ooool2o`0007Sooooo0023ooooo`?o00001Oooool2o`0000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP02o`0000?ooooo0_lQ8B42o`0000?ooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo02Gooooo0_l0000:ooooo`;o00003?ooool2o`00
07Sooooo002Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool00_l00002ooooo`03o`000?oooooooooo00Oooooo0_l0000Looooo`;o0000T_ooool0097o
oooo00Go410@oooooooooooooooooa0@400@ooooo`04o`000?oooooo0000o`0000;ooooo0_l00008
ooooo`;o0000/?ooool0097ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo00Cooooo0ol00005ooooo`;o0000/_ooool0097ooooo00Go0000ooooooooooooooooo`00000<
ooooo`03o`000?lQ8B7o000000;o00001Oooool00ol0003oooooooooo`02o`0000?ooooo0_l0000;
ooooo`;o00003oooool2o`0009Cooooo002Aooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`02o`0000Gooooo00?o0000ooooooooool00_l0000@ooooo`;o00003oooool2
o`0009Cooooo002Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL01oooool2o`0000?ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`2iooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Oooooo0_l00003ooooo`Co00001_ooool00ol0003oooooooooo`0^ooooo`;o0000ROooool0
0:cooooo00?o0000ooooooooool03oooool2o`0001gooooo0_l00029ooooo`00[?ooool00ol0003o
ooooooooo`0?ooooo`;o0000Z?ooool008Kooooo0_l0000Iooooo`;o00002Oooool00ol0003ooooo
ooooo`02ooooo`;o0000]Oooool008Kooooo0_l0000Iooooo`;o00002Oooool3o`0000;ooooo0_l0
0003ooooo`;o00003_ooool2o`000:3ooooo002/ooooo`03o`000?oooooooooo00Oooooo0_l0000>
ooooo`;o0000X?ooool00:cooooo00?o0000ooooooooool0^Oooool009Sooooo0_l00002ooooo`?o
00003Oooool01?l0003oooooo`000?l0000Zooooo`;o0000S?ooool008Kooooo0_l0000@ooooo`;o
00000_ooool3o`0000gooooo00Co0000ooooool0003o00007Oooool2o`0000_ooooo0_l0002<oooo
o`00Q_ooool2o`00013ooooo0_l0000>ooooo`;o00000_ooool00ol0003oooooooooo`0Mooooo`?o
0000VOooool00:Sooooo0_l00002ooooo`03o`000?oooooooooo01gooooo0_l0002Jooooo`00S_oo
ool2o`0000oooooo0_l0000;ooooo`03o`000?oooooooooo0;Wooooo002>ooooo`;o00000_ooool2
o`0000_ooooo0_l0000;ooooo`?o00004_ooool2o`000:Gooooo002Booooo`;o00006?ooool00ol0
003oooooooooo`0:ooooo`;o00001_ooool2o`000:Gooooo002/ooooo`03o`000?oooooooooo00[o
oooo0_l0002]ooooo`00Roooool2o`0001oooooo00?o0000ooooooooool0^Oooool008_ooooo0_l0
000Oooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00oooooo0_l0002X
ooooo`00V?ooool2o`0001;ooooo00?o0000ooooooooool03oooool2o`0000Oooooo0_l0002Ooooo
o`00V?ooool2o`0001;ooooo00?o0000ooooooooool06?ooool2o`0009oooooo002Pooooo`;o0000
2_ooool3o`0002;ooooo0_l0002Eooooo`00X?ooool2o`0000[ooooo00?o0000ooooooooool01?oo
ool2o`0000Oooooo0_l00006ooooo`?o00002_ooool2o`0009Gooooo002=ooooo`;o00000_ooool2
o`0001Wooooo00?o0000ooooooooool01?ooool2o`0000Oooooo0_l00006ooooo`?o0000XOooool0
08gooooo0_l00002ooooo`;o00006Oooool00ol0003oooooooooo`0;ooooo`?o0000Zoooool00:co
oooo00?o0000ooooooooool02oooool3o`00017ooooo0_l0002Hooooo`00ZOooool2o`000003oooo
ool0003ooooo00?ooooo0_l00005ooooo`?o00004oooool2o`0009Sooooo0029ooooo`?o00007Ooo
ool2o`000003ooooool0003ooooo00?ooooo0_l00005ooooo`?o0000[Oooool008Wooooo0ol0000M
ooooo`;o000000?oooooo`000?ooool08?ooool2o`0009Sooooo002Nooooo`;o00003?ooool00ol0
003oooooooooo`0Oooooo`;o0000V?ooool009kooooo0_l0000<ooooo`?o0000^Oooool00:cooooo
00?o0000ooooooooool01_ooool2o`000;7ooooo002/ooooo`03o`000?oooooooooo00Kooooo0_l0
002aooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo
00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@03ooooo`?o0000^oooool008Wooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`02o`0000Gooooo00?oMgMg
oc8b<_ooool00_ooool3o`0001_ooooo0_l0002Nooooo`00ROooool01Ol@413ooooooooooooooooo
410@00gooooo00?oZJVYoeEEEOooool00_l00006ooooo`04o`000?ooooooooooooooo`?o00006ooo
ool2o`0009kooooo0029ooooo`03o`000?oooooooooo00;o00000oooool2o`0000Wooooo00?o8B4Q
ooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`?o00003?ooool2o`000:_ooooo0029oooo
o`03o`000?oooooooooo00;o00000oooool3o`0000Sooooo00CoEEEEolc<c?oooooooooo0ol00000
1?lQ8B7o0000oc8b<_o<c<`5ooooo`03o`000?oooooooooo00_ooooo0ol00008ooooo`;o0000XOoo
ool008Wooooo00Go410@oooooooooooooooooa0@4004ooooo`;o00002?ooool01?nYZJWoMgMgoooo
ooooool3o`0000Wooooo00?o0000ooooooooool02oooool2o`0000Wooooo0_l0000;ooooo`;o0000
U?ooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`;o00001Oooool01Ol@413ooooo
oooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Sooooo`;o
0000U?ooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`;o00001Oooool5o`0000Co
oooo1?l00006ooooo`03o`000?oooooooooo00Wooooo0_l0000Fooooo`;o0000U_ooool00:cooooo
00?o0000ooooooooool02?ooool3o`0000Sooooo0_l0000<ooooo`;o0000U_ooool00:cooooo00?o
0000ooooooooool02?ooool2o`0000Wooooo0_l0002Tooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002:ooooo`;o00008?ooool00ol0003oooooooooo`0?ooooo`;o00002ooo
ool2o`0009_ooooo002:ooooo`;o00001?ooool2o`0001[ooooo00?o0000ooooooooool03oooool2
o`0000_ooooo0_l0002Kooooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool0^Oooool009Sooooo0_l0000Booooo`03o`000?oooooooooo00;o0000
]oooool009Sooooo0_l0000Booooo`Go0000]oooool009Sooooo0_l0000Booooo`03o`000?oooooo
oooo00_ooooo0_l0002/ooooo`00V?ooool2o`0001;ooooo00?o0000ooooooooool02oooool2o`00
0:cooooo002/ooooo`03o`000?oooooooooo01Oooooo0_l0002Pooooo`00Z_ooool3o`0001Wooooo
0_l0002Pooooo`00Toooool2o`0001Gooooo0ol0002kooooo`00Toooool2o`0001Oooooo00?o0000
ooooooooool0^Oooool00:Wooooo0_l000000ooooooo0000ooooo`2jooooo`00YOooool2o`0000;o
oooo0_l000000ooooooo0000ooooo`2jooooo`00UOooool2o`0000kooooo0_l00005ooooo`?o0000
0oooool2o`000;Cooooo002Eooooo`;o00005Oooool00ol0003oooooooooo`02ooooo`?o0000]?oo
ool009Gooooo0_l0000Eooooo`03o`000?oooooooooo00;ooooo0_l0002eooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool00ol0003oooooooooo`0;ooooo`;o0000[?ooool00:cooooo00?o0000
ooooooooool02oooool2o`000:cooooo002Kooooo`;o00003oooool3o`000;Wooooo002Kooooo`;o
00003oooool00ol0003oooooooooo`2iooooo`00Z_ooool3o`000;_ooooo002Zooooo`?o0000^ooo
ool00:7ooooo0_l00009ooooo`03o`000?oooooooooo0;Wooooo002Qooooo`;o00002Oooool00ol0
003oooooooooo`2iooooo`00X_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooooooo
ool0^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00Y?oo
ool00ol0003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool0`Oooool0
0:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo
00?o0000ooooooooool0`Oooool00:;ooooo00?oEEEEofIVI_l00000`oooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:[ooooo00Co410@o`000?l0003o0000
^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool0
0:_ooooo00Ko0000ogMgMol0003o0000oeEEEOo^k^jgooooo`00Zoooool01_l0003oEEEEonk^k_oo
ooooMgMgoeEEEKOooooo002[ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0]Ooo
ool00:_ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`2eooooo`00Zoooool01_l0
003oEEEEonk^k_ooooooMgMgofIVI[Oooooo002Zooooo`03oa0@4?l0003oMgMg00;o000000?oIVIV
onk^k_ooool0]_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.56704 .21941 Mdot
.6371 .63866 Mdot
.44647 .54734 Mdot
.5491 .54837 Mdot
.55639 .32209 Mdot
.50674 .85841 Mdot
.45672 .34701 Mdot
.60709 .85049 Mdot
.69782 .38556 Mdot
.53624 .66848 Mdot
.41511 .4022 Mdot
.53792 .93792 Mdot
.38805 .3241 Mdot
.41714 .62084 Mdot
.55754 .9086 Mdot
.4227 .37664 Mdot
.48601 .85014 Mdot
.39994 .23496 Mdot
.50357 .77604 Mdot
.63029 .74522 Mdot
.38677 .34623 Mdot
.56784 .80089 Mdot
.54098 .84086 Mdot
.42103 .1469 Mdot
.37891 .74391 Mdot
.4041 .38731 Mdot
.47432 .21373 Mdot
.54033 .69276 Mdot
.59958 .80208 Mdot
.63696 .63324 Mdot
.40585 .21315 Mdot
.70512 .40961 Mdot
.67923 .70888 Mdot
.40058 .36807 Mdot
.58802 .30999 Mdot
.67856 .48533 Mdot
.39153 .2313 Mdot
.57418 .50202 Mdot
.58254 .82495 Mdot
.47423 .99594 Mdot
.3644 .56132 Mdot
.50925 .16635 Mdot
.62402 .56719 Mdot
.62241 .33244 Mdot
.524 .15069 Mdot
.56855 .65892 Mdot
.47069 .77876 Mdot
.66416 .2833 Mdot
.5978 .4032 Mdot
.63101 .73584 Mdot
.65156 .25901 Mdot
.45461 .94563 Mdot
.3682 .24254 Mdot
.61848 .41984 Mdot
.62859 .5042 Mdot
.71472 .5381 Mdot
.6016 .85723 Mdot
.47655 .8552 Mdot
.56094 .11946 Mdot
.48841 .10765 Mdot
.55403 .69938 Mdot
.69415 .26351 Mdot
.58329 .82195 Mdot
.50512 .69858 Mdot
.69841 .63611 Mdot
.71577 .4878 Mdot
.55103 .61135 Mdot
.42727 .6477 Mdot
.57294 .55519 Mdot
.45941 .07772 Mdot
.39771 .60779 Mdot
.45534 .66518 Mdot
.53809 .65981 Mdot
.5609 .46849 Mdot
.58406 .82066 Mdot
.50648 .54985 Mdot
.3685 .24013 Mdot
.51174 .78529 Mdot
.49884 .94111 Mdot
.51751 .21235 Mdot
.58494 .20598 Mdot
.64338 .5998 Mdot
.54428 .42718 Mdot
.5369 .2084 Mdot
.67417 .72674 Mdot
.46375 .23548 Mdot
.56811 .35669 Mdot
.58138 .41969 Mdot
.51515 .81374 Mdot
.42371 .6213 Mdot
.37766 .73239 Mdot
.64828 .84434 Mdot
.42316 .41854 Mdot
.58951 .54448 Mdot
.43012 .63624 Mdot
.67607 .80137 Mdot
.42553 .67936 Mdot
.63844 .23843 Mdot
.39163 .10392 Mdot
.482 .85676 Mdot
.59976 .2833 Mdot
.56288 .72334 Mdot
.56122 .90745 Mdot
.63781 .38493 Mdot
.55854 .16229 Mdot
.42117 .23302 Mdot
.3942 .48375 Mdot
.43739 .75671 Mdot
.42495 .39775 Mdot
.45601 .08153 Mdot
.4698 .78158 Mdot
.54981 .54854 Mdot
.70017 .38991 Mdot
.6769 .5885 Mdot
.72538 .23305 Mdot
.46384 .29506 Mdot
.52944 .75398 Mdot
.71412 .58504 Mdot
.71822 .51399 Mdot
.37323 .48082 Mdot
.38377 .37861 Mdot
.64178 .17373 Mdot
.42116 .83931 Mdot
.5818 .83241 Mdot
.46415 .075 Mdot
.53799 .61773 Mdot
.66894 .62654 Mdot
.71974 .71022 Mdot
.64156 .42011 Mdot
.53315 .49601 Mdot
.52385 .86799 Mdot
.62785 .35855 Mdot
.48166 .99216 Mdot
.46489 .88463 Mdot
.60263 .66761 Mdot
.52452 .91169 Mdot
.39103 .22925 Mdot
.63865 .7217 Mdot
.54501 .63465 Mdot
.65812 .75445 Mdot
.53178 .94105 Mdot
.73913 .38994 Mdot
.52675 .34596 Mdot
.55262 .65934 Mdot
.48038 .85328 Mdot
.65748 .67499 Mdot
.69472 .67079 Mdot
.79336 .40103 Mdot
.46258 .79624 Mdot
.58884 .48399 Mdot
.62684 .14889 Mdot
.57524 .69335 Mdot
.56848 .42095 Mdot
.43863 .10298 Mdot
.47743 .68573 Mdot
.41761 .78738 Mdot
.37448 .59035 Mdot
.54292 .88315 Mdot
.71543 .5635 Mdot
.38539 .27688 Mdot
.37223 .50123 Mdot
.50247 .18194 Mdot
.48443 .9533 Mdot
.36479 .39774 Mdot
.65895 .37243 Mdot
.62557 .51547 Mdot
.56941 .22661 Mdot
.70143 .64593 Mdot
.60048 .22752 Mdot
.57502 .51654 Mdot
.37225 .45637 Mdot
.66599 .62819 Mdot
.42242 .4435 Mdot
.56258 .39858 Mdot
.55495 .32137 Mdot
.41707 .66087 Mdot
.68389 .69153 Mdot
.6929 .76974 Mdot
.43421 .8382 Mdot
.43185 .42861 Mdot
.59779 .80271 Mdot
.38355 .71062 Mdot
.42033 .9327 Mdot
.53908 .35141 Mdot
.36406 .44392 Mdot
.46203 .71234 Mdot
.68399 .34328 Mdot
.72691 .6881 Mdot
.70989 .42452 Mdot
.36294 .52984 Mdot
.61164 .63781 Mdot
.58371 .09748 Mdot
.65629 .67935 Mdot
.54181 .52199 Mdot
.657 .20058 Mdot
.64855 .78043 Mdot
.42994 .03734 Mdot
.52672 .94968 Mdot
.58999 .48507 Mdot
.54033 .98274 Mdot
.45777 .1417 Mdot
.46985 .69978 Mdot
.45769 .68639 Mdot
.43958 .6018 Mdot
.52553 .25443 Mdot
.60485 .29731 Mdot
.46589 .27749 Mdot
.46674 .88342 Mdot
.54844 .56978 Mdot
.43116 .38599 Mdot
.43239 .28483 Mdot
.40607 .78965 Mdot
.52234 .76598 Mdot
.60185 .23017 Mdot
.48972 .2412 Mdot
.57818 .24284 Mdot
.55297 .69665 Mdot
.36563 .38256 Mdot
.43725 .64652 Mdot
.41468 .21617 Mdot
.50871 .97361 Mdot
.53679 .73903 Mdot
.5529 .11192 Mdot
.58478 .20052 Mdot
.61284 .25674 Mdot
.42578 .35769 Mdot
.46802 .18921 Mdot
.6436 .61639 Mdot
.42244 .43779 Mdot
.55017 .91806 Mdot
.67033 .21648 Mdot
.42786 .65558 Mdot
.5117 .55344 Mdot
.60711 .50202 Mdot
.48881 .21817 Mdot
.60754 .12779 Mdot
.57186 .45627 Mdot
.64782 .43335 Mdot
.40442 .7755 Mdot
.6206 .33572 Mdot
.68935 .25539 Mdot
.55883 .77449 Mdot
.65234 .33903 Mdot
.39862 .61958 Mdot
.71247 .44328 Mdot
.46203 .73232 Mdot
.40132 .81287 Mdot
.5883 .63955 Mdot
.40167 .65264 Mdot
.56956 .84448 Mdot
.40371 .11086 Mdot
.45474 .31037 Mdot
.54096 .48415 Mdot
.3831 .69449 Mdot
.40134 .44479 Mdot
.55405 .36521 Mdot
.62141 .60312 Mdot
.49739 .60903 Mdot
.63091 .80926 Mdot
.62553 .21127 Mdot
.60578 .45916 Mdot
.48793 .21729 Mdot
.63418 .30187 Mdot
.51416 .36552 Mdot
.58997 .64449 Mdot
.50967 .13475 Mdot
.45613 .76597 Mdot
.58334 .71623 Mdot
.67808 .54246 Mdot
.42761 .24106 Mdot
.67916 .5547 Mdot
.62717 .55349 Mdot
.53107 .68544 Mdot
.57484 .3301 Mdot
.37464 .59649 Mdot
.55298 .4038 Mdot
.42361 .28863 Mdot
.66471 .28692 Mdot
.43027 .29223 Mdot
.42599 .81776 Mdot
.56405 .85665 Mdot
.52052 .62343 Mdot
.53498 .34337 Mdot
.38152 .31326 Mdot
.58237 .88034 Mdot
.42526 .71277 Mdot
.51924 .5348 Mdot
.41872 .32523 Mdot
.68318 .53311 Mdot
.58792 .55267 Mdot
.54654 .1492 Mdot
.72905 .68029 Mdot
.52148 .07367 Mdot
.59336 .8613 Mdot
.50555 .05758 Mdot
.44005 .57098 Mdot
.52157 .07122 Mdot
.60681 .13102 Mdot
.68175 .4668 Mdot
.57383 .88751 Mdot
.80621 .48439 Mdot
.56396 .30009 Mdot
.5884 .71428 Mdot
.63812 .3944 Mdot
.71004 .4314 Mdot
.37844 .74326 Mdot
.43767 .72668 Mdot
.65399 .26598 Mdot
.41163 .32064 Mdot
.52119 .57257 Mdot
.42737 .86305 Mdot
.45137 .83918 Mdot
.3808 .544 Mdot
.5969 .11059 Mdot
.47777 .28975 Mdot
.44312 .13443 Mdot
.44513 .16446 Mdot
.68672 .67725 Mdot
.52766 .42437 Mdot
.41483 .91746 Mdot
.7568 .49244 Mdot
.48305 .75513 Mdot
.44275 .86135 Mdot
.55405 .23725 Mdot
.53957 .88606 Mdot
.49826 .20272 Mdot
.47524 .70297 Mdot
.4378 .4553 Mdot
.401 .64171 Mdot
.55017 .92624 Mdot
.39992 .80361 Mdot
.4297 .63462 Mdot
.47834 .91875 Mdot
.53128 .55226 Mdot
.43871 .59516 Mdot
.64094 .62762 Mdot
.5213 .83746 Mdot
.62554 .52137 Mdot
.49952 .17772 Mdot
.50219 .21231 Mdot
.3541 .46054 Mdot
.40325 .41075 Mdot
.65005 .52523 Mdot
.51074 .68211 Mdot
.70351 .62512 Mdot
.44887 .2401 Mdot
.65019 .691 Mdot
.62981 .65343 Mdot
.48449 .25406 Mdot
.58413 .57202 Mdot
.73912 .38839 Mdot
.53839 .93824 Mdot
.53099 .08078 Mdot
.67964 .5226 Mdot
.55174 .27108 Mdot
.4231 .22012 Mdot
.66895 .61707 Mdot
.60328 .57651 Mdot
.54337 .93203 Mdot
.75857 .53989 Mdot
.65875 .35845 Mdot
.49518 .98393 Mdot
.40422 .88309 Mdot
.36837 .34372 Mdot
.44023 .38947 Mdot
.60296 .44383 Mdot
.53239 .93985 Mdot
.61869 .83045 Mdot
.45173 .33894 Mdot
.50583 .09621 Mdot
.40141 .52652 Mdot
.44354 .86063 Mdot
.58897 .26063 Mdot
.65558 .27184 Mdot
.64579 .4224 Mdot
.44187 .06177 Mdot
.46652 .94838 Mdot
.55934 .81139 Mdot
.49897 .04481 Mdot
.54626 .83432 Mdot
.41375 .90956 Mdot
.76179 .3046 Mdot
.38405 .29265 Mdot
.39297 .62667 Mdot
.50652 .61921 Mdot
.41228 .08617 Mdot
.52094 .80513 Mdot
.43666 .50548 Mdot
.39773 .85941 Mdot
.46819 .07285 Mdot
.47724 .7033 Mdot
.56208 .51548 Mdot
.4217 .73127 Mdot
.51195 .25659 Mdot
.67945 .31819 Mdot
.61953 .25888 Mdot
.64006 .17592 Mdot
.40844 .89859 Mdot
.39743 .58813 Mdot
.36773 .74508 Mdot
.40015 .36513 Mdot
.42055 .68395 Mdot
.40939 .40277 Mdot
.48258 .34342 Mdot
.57422 .89499 Mdot
.54734 .92647 Mdot
.46753 .21584 Mdot
.45667 .2674 Mdot
.5364 .30581 Mdot
.50564 .26526 Mdot
.52106 .02684 Mdot
.59084 .53288 Mdot
.66265 .38286 Mdot
.53129 .36354 Mdot
.56929 .42764 Mdot
.52966 .44092 Mdot
.58716 .44522 Mdot
.39522 .50519 Mdot
.54225 .32401 Mdot
.48704 .27919 Mdot
.63364 .16027 Mdot
.65967 .75179 Mdot
.49784 .42916 Mdot
.60271 .35055 Mdot
.39419 .48729 Mdot
.39333 .62321 Mdot
.40559 .38412 Mdot
.57175 .4513 Mdot
.43619 .02919 Mdot
.6288 .87667 Mdot
.64938 .4511 Mdot
.65005 .12245 Mdot
.63797 .3814 Mdot
.52563 .37692 Mdot
.7002 .40194 Mdot
.51945 .95448 Mdot
.41775 .37627 Mdot
.63274 .64013 Mdot
.35568 .40437 Mdot
.47028 .25401 Mdot
.51372 .61886 Mdot
.40774 .55301 Mdot
.6357 .30397 Mdot
.48899 .1704 Mdot
.59312 .9211 Mdot
.43015 .59729 Mdot
.59335 .32843 Mdot
.51279 .17029 Mdot
.45057 .71624 Mdot
.45951 .30332 Mdot
.56109 .46039 Mdot
.60792 .84884 Mdot
.51433 .36272 Mdot
.51834 .91841 Mdot
.64938 .57524 Mdot
.49394 .11358 Mdot
.67527 .59195 Mdot
.49997 .09024 Mdot
.41306 .72549 Mdot
.71268 .73187 Mdot
.56053 .54814 Mdot
.53978 .93879 Mdot
.40838 .0937 Mdot
.46076 .77081 Mdot
.5279 .07786 Mdot
.41414 .30832 Mdot
.54097 .7624 Mdot
.65181 .68705 Mdot
.60574 .29588 Mdot
.48639 .79958 Mdot
.58242 .58528 Mdot
.40312 .34011 Mdot
.7084 .28868 Mdot
.6127 .6268 Mdot
.50774 .53938 Mdot
.62631 .50158 Mdot
.53566 .24378 Mdot
.43968 .3913 Mdot
.47452 .75681 Mdot
.61685 .4098 Mdot
.60308 .66894 Mdot
.42889 .50341 Mdot
.4082 .64384 Mdot
.71599 .49384 Mdot
.55443 .31555 Mdot
.47131 .1075 Mdot
.55826 .64261 Mdot
.55325 .64994 Mdot
.49982 .34015 Mdot
.71769 .21815 Mdot
.50728 .36552 Mdot
.63909 .63295 Mdot
.5387 .09649 Mdot
.6655 .39615 Mdot
.56776 .5938 Mdot
.62348 .75494 Mdot
.46167 .99169 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool01?ooool2
o`000;?ooooo002Fooooo`;o00005?ooool00ol0003oooooooooo`04ooooo`;o0000/oooool009Ko
oooo0_l0000Dooooo`03o`000?oooooooooo0;Wooooo002Dooooo`;o00005_ooool00ol0003ooooo
ooooo`2iooooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:_ooooo0_l0002kooooo`00Zoooool2o`000;_ooooo002/ooooo`?o0000
^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00V?ooool2o`00
01;ooooo0ol0002iooooo`00V?ooool2o`0001;ooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool01?ooool2o`000;?ooooo002Q
ooooo`;o00002Oooool00ol0003oooooooooo`04ooooo`;o0000/oooool00:3ooooo0ol00009oooo
o`?o00001?ooool2o`000;?ooooo002Nooooo`Co00002_ooool00ol0003oooooooooo`06ooooo`;o
0000/Oooool009gooooo0ol0000<ooooo`03o`000?oooooooooo00Kooooo0ol0002`ooooo`00Sooo
ool2o`0000cooooo0_l0000=ooooo`03o`000?oooooooooo00Oooooo0_l0002`ooooo`00Soooool2
o`0001_ooooo00?o0000ooooooooool0^Oooool00:cooooo0_l0002jooooo`00SOooool2o`0001go
oooo0_l0002jooooo`00SOooool2o`0001gooooo0ol00009ooooo`;o00003Oooool2o`0009oooooo
002/ooooo`?o00002Oooool2o`0000gooooo0_l0002Oooooo`00R?ooool2o`0000gooooo0_l0000C
ooooo`03o`000?oooooooooo0;Wooooo0028ooooo`;o00003Oooool2o`0000Wooooo0_l00004oooo
o`;o00000_ooool00ol0003oooooooooo`2iooooo`00X_ooool2o`0000Cooooo0_l00002ooooo`03
o`000?oooooooooo01gooooo0_l0002Jooooo`00S?ooool2o`0001cooooo0ol0000@ooooo`;o0000
3Oooool2o`0009[ooooo002<ooooo`;o00007?ooool3o`00013ooooo0_l0002Yooooo`00ROooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo017ooooo0_l0002Vooooo`00ROoo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Aooooo`;o00006oooool2o`0008Wooooo
0021ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool0
2?ooool00ol0003oooooooooo`03ooooo`?o0000;_ooool2o`0008Wooooo0029ooooo`05o`000?oo
ooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool08?ooool2o`0009Oooooo0029ooooo`05o`000?ooooooooooooooool00000
3_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003o
ooooooooo`0Pooooo`;o0000Uoooool008Wooooo00Go410@oooooooooooooooooa0@400;ooooo`;o
000000?oooooojVYZOmgMgL01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;o
00007_ooool2o`0009Oooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool2o`0000;o
oooo00?o<S8booooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;o
0000]oooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo00?o0000ooooooooool0^Oooool009kooooo0_l0000<ooooo`03o`000?oooooooooo0;Wooooo
002Aooooo`;o00002oooool2o`0000cooooo00?o0000ooooooooool0^Oooool0097ooooo0_l0000I
ooooo`03o`000?oooooooooo00cooooo0_l0000Hooooo`;o0000TOooool00:cooooo0ol00004oooo
o`;o00001_ooool2o`0001Sooooo0_l0002Aooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o
0000/oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0:Ooo
ool2o`0008kooooo002Iooooo`;o00004Oooool00ol0003oooooooooo`0@ooooo`;o00005oooool2
o`0008kooooo002Iooooo`;o00004Oooool00ol0003oooooooooo`02o`0000kooooo0_l0002Woooo
o`00Z?ooool2o`0000;ooooo00?o0000ooooooooool00ol0002fooooo`00Z?ooool2o`0000;ooooo
00Co0000oooooooooooooooo0_l0000Xooooo`;o0000S?ooool00:cooooo0ol0000[ooooo`;o0000
S?ooool00:_ooooo0_l0000]ooooo`;o0000S?ooool00:_ooooo0ol0002jooooo`00[?ooool2o`00
0;[ooooo002Qooooo`;o00002Oooool00ol0003oooooooooo`2iooooo`00XOooool2o`0000Wooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo0ol0000Iooooo`;o00005Oooool2o`0008Oooooo002[ooooo`;o
00006oooool2o`0001Gooooo0_l00027ooooo`00Zoooool2o`0001_ooooo0_l0002Nooooo`00[?oo
ool00ol0003oooooooooo`09ooooo`;o00003_ooool2o`0009kooooo002<ooooo`;o00005Oooool2
o`0000Oooooo0_l00003ooooo`;o00001Oooool2o`0001_ooooo0_l0002Aooooo`00S?ooool2o`00
0003ooooool0003o0000013ooooo1?l00007ooooo`;o00000oooool2o`0002;ooooo0_l0000=oooo
o`;o0000P_ooool008oooooo0_l0000@ooooo`;o00001Oooool2o`0000;ooooo00?o0000oooooooo
ool04oooool2o`00023ooooo0_l0000=ooooo`;o0000Loooool009;ooooo0_l0000Dooooo`;o0000
0_ooool00ol0003oooooooooo`0Cooooo`;o0000;oooool2o`0007?ooooo002Booooo`;o00006?oo
ool3o`000;Wooooo002/ooooo`03o`000?oooooooooo01?ooooo0_l00009ooooo`;o0000VOooool0
08Sooooo0_l0000Rooooo`03o`000?oooooooooo01?ooooo0_l00009ooooo`;o0000VOooool008So
oooo0_l00008ooooo`;o00006?ooool00ol0003oooooooooo`0Nooooo`;o00009oooool2o`00073o
oooo002;ooooo`;o00001Oooool2o`0000cooooo0_l0000:ooooo`03o`000?oooooooooo00kooooo
0_l0000gooooo`;o0000L?ooool0083ooooo0_l00009ooooo`;o00003_ooool2o`0000?ooooo0_l0
000:ooooo`03o`000?oooooooooo00kooooo0_l0000Jooooo`;o0000SOooool0083ooooo0_l0000?
ooooo`03onk^k_lb<S;o000000;o00001Oooool2o`0000Gooooo00KoA4A4o`000?l0003o<S8bomgM
gOooool2o`0000;ooooo00?o0000ooooooooool02?ooool2o`0000cooooo0_l0000Booooo`;o0000
SOooool0083ooooo0_l0000?ooooo`03ogMgMonHV9Sooooo00;o00001Oooool2ob4Q8@Sooooo00?o
MgMgoc8b<_ooool00_l00002ooooo`03o`000?oooooooooo00Sooooo0_l0000<ooooo`;o0000XOoo
ool008Wooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo0;Wooooo002Aooooo`05o`000?ooooooooooooooool000003ooo
ool00omgMgOo<S8booooo`04ooooo`?o0000^Oooool0097ooooo00Go0000ooooooooooooooooo`00
000<ooooo`?o000000?o<S8bo`000?l000001?ooool00ol0003oooooooooo`05ooooo`;o0000=?oo
ool2o`0007cooooo002Aooooo`05oa0@4?ooooooooooooooool@41003?ooool2o`0000;ooooo0_l0
0004ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0001_ooooo1?l00009ooooo`;o0000
2_ooool2o`0007cooooo002Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooo
ooooo`07ooooo`04o`000?ooooooooooooooo`;o00005oooool2o`0000Kooooo1?l00009ooooo`;o
0000R?ooool0097ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003o
ooooooooo`0Jooooo`;o00008Oooool2o`0007[ooooo002Mooooo`;o00003Oooool3o`0002oooooo
0_l0000<ooooo`;o0000N_ooool009gooooo0_l0000=ooooo`?o00003_ooool2o`0001oooooo0_l0
0028ooooo`00[?ooool00ol0003oooooooooo`0>ooooo`;o00008?ooool2o`0008Oooooo0026oooo
o`;o00009?ooool3o`00033ooooo0_l00027ooooo`00Q_ooool2o`0001Sooooo0_l00005ooooo`;o
00000oooool00ol0003oooooooooo`2iooooo`00X?ooool2o`0000Gooooo0_l00003ooooo`03o`00
0?oooooooooo01gooooo0_l0000Dooooo`;o0000Q?ooool009Gooooo0_l0000Eooooo`03o`000?oo
oooooooo01gooooo0_l0000Dooooo`;o0000Q?ooool009;ooooo0_l000000ooooooo0000o`00000E
ooooo`03o`000?oooooooooo03?ooooo0_l0000<ooooo`;o0000M_ooool009;ooooo0_l000000ooo
oooo0000o`00000=ooooo`;o00001_ooool00ol0003oooooooooo`0cooooo`;o00003?ooool2o`00
07Kooooo0025ooooo`;o00003_ooool2o`0000Wooooo0_l00002ooooo`;o00001_ooool00ol0003o
ooooooooo`2iooooo`00QOooool2o`0001Wooooo0_l0000:ooooo`03o`000?oooooooooo01oooooo
0_l0002Hooooo`00[?ooool3o`0001;ooooo0_l0000;ooooo`;o0000V?ooool009kooooo0_l0000<
ooooo`03o`000?oooooooooo01;ooooo0_l0000Eooooo`;o0000:?ooool2o`0006Cooooo002Noooo
o`;o00003?ooool00ol0003oooooooooo`09ooooo`;o00007_ooool2o`0002Sooooo0_l0001Toooo
o`00Soooool2o`0000cooooo0_l0000=ooooo`03o`000?oooooooooo00Wooooo0_l0000?ooooo`;o
0000WOooool008Cooooo0_l00009ooooo`;o00003?ooool2o`0000gooooo00?o0000ooooooooool0
6_ooool2o`0009gooooo0024ooooo`;o00009_ooool00ol0003oooooooooo`0?ooooo`;o0000Z?oo
ool00:cooooo00?o0000ooooooooool03oooool2o`0002Oooooo0_l0001oooooo`00S_ooool2o`00
01cooooo00?o0000ooooooooool03oooool2o`0002Oooooo0_l0001oooooo`00Qoooool2o`0000Go
oooo0_l000000ooooooo0000o`00000Iooooo`?o00002oooool2o`0000;ooooo0_l0002Xooooo`00
Qoooool2o`0000Sooooo0_l0000Iooooo`03o`000?oooooooooo00_ooooo0_l0000>ooooo`;o0000
W?ooool00:cooooo00?o0000ooooooooool05Oooool2o`0000Cooooo0_l0002Looooo`00[?ooool0
0ol0003oooooooooo`0Eooooo`;o00003_ooool2o`0009;ooooo002/ooooo`03o`000?oooooooooo
02Cooooo0ol0002Booooo`00S?ooool2o`0000kooooo0_l0000>ooooo`;o00009Oooool2o`0000Wo
oooo0_l00028ooooo`00P?ooool2o`0000[ooooo0_l0000>ooooo`;o00002?ooool2o`0000Cooooo
0_l00009ooooo`;o00009Oooool2o`0000Sooooo0_l0001nooooo`00P?ooool2o`0000Cooooo0_l0
000Eooooo`;o00001oooool2o`0000Cooooo00?o0000ooooooooool01Oooool2o`000003ooooool0
003o000002oooooo0_l0001nooooo`00Q_ooool2o`0001Gooooo0_l0000=ooooo`03o`000?oooooo
oooo00Gooooo0_l0002booooo`00[?ooool3o`0000Wooooo0_l0000Cooooo`;o0000VOooool00:co
oooo00?o0000ooooooooool02Oooool2o`0001?ooooo0_l0002Iooooo`00Toooool2o`0001Oooooo
00?o0000ooooooooool04oooool2o`0001;ooooo0_l00008ooooo`;o0000Q_ooool009?ooooo0_l0
000Gooooo`03o`000?oooooooooo01?ooooo0_l0000Booooo`;o00002?ooool2o`0008Kooooo002;
ooooo`;o00007oooool01?l0003oooooooooooooool2o`0000Cooooo0_l00005ooooo`;o0000ZOoo
ool008Wooooo00Gok^k^oc8b<_l0003o0000onk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo000000?o00001?ooool2o`0000Gooooo
0_l0002Yooooo`00ROooool01OmgMgOoV9RHo`000?l0003oMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo000000?o
0000]_ooool0087ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0<Oooool2o`0008Ko
oooo0029ooooo`05o`000?ooooooooooooooool000000_ooool4o`0000Oooooo00?oV9RHob4Q8Oo^
k^h01oooool00omgMgOo<S8booooo`04ooooo`?o00001Oooool2o`0002[ooooo0_l00026ooooo`00
QOooool2o`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`Co00002?ooool00omgMgOo
IVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`05oooo
o`;o0000/_ooool007oooooo0_l00004ooooo`;o00000_ooool01Ol@413ooooooooooooooooo410@
00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
02[ooooo0_l00006ooooo`;o0000QOooool007oooooo0_l00008ooooo`03ogMgMonHV9Sooooo00;o
00001oooool2o`0000;ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0:_ooool2o`0000Kooooo0_l0000:ooooo`;o0000NOooool008Wo
oooo00?ok^k^oc8b<_l000000_l00007ooooo`;o00000_ooool01OnHV9So410@o`000?lQ8B7oc<c<
00Cooooo1?l00006ooooo`03o`000?oooooooooo02[ooooo0_l0000Booooo`;o00003?ooool2o`00
06_ooooo002<ooooo`;o00002_ooool2o`0001;ooooo00?o0000ooooooooool0?oooool2o`0000_o
oooo0_l0001[ooooo`00V?ooool2o`0001;ooooo00?o0000ooooooooool0:_ooool2o`0001?ooooo
0_l0000;ooooo`;o0000Joooool007oooooo0_l0000Booooo`;o00005oooool00ol0003ooooooooo
o`0Zooooo`;o00001oooool2o`0008Cooooo001oooooo`;o00004_ooool2o`0001Oooooo0ol0000A
ooooo`;o00008?ooool2o`0002Sooooo0_l0001Jooooo`00O?ooool2o`00013ooooo1?l0000Joooo
o`03o`000?oooooooooo00kooooo0_l000000ooooooo0000o`00000:ooooo`;o00008?ooool2o`00
01cooooo0_l0001Jooooo`00O?ooool2o`00013ooooo1?l0000Jooooo`03o`000?oooooooooo00ko
oooo0_l0000=ooooo`;o00008?ooool2o`0007Sooooo002/ooooo`03o`000?oooooooooo02?ooooo
0_l0000Kooooo`;o0000Moooool008cooooo0_l0000Nooooo`03o`000?oooooooooo02?ooooo0_l0
000Kooooo`;o0000Moooool008cooooo0_l0000Nooooo`03o`000?oooooooooo0;Wooooo002Boooo
o`;o00006?ooool00ol0003oooooooooo`0Gooooo`;o0000X?ooool009;ooooo0_l0000Hooooo`03
o`000?oooooooooo01?ooooo0_l00002ooooo`;o00002oooool2o`0000Gooooo1?l0002:ooooo`00
[?ooool3o`0000Kooooo0_l0000;ooooo`;o00003oooool2o`0000Gooooo1?l0000Cooooo`;o0000
MOooool009Gooooo0_l0000Eooooo`03o`000?oooooooooo00Kooooo0_l00003ooooo`;o00001_oo
ool2o`0002gooooo0_l0001eooooo`00UOooool2o`0001Cooooo0_l0000=ooooo`;o00001_ooool2
o`0002gooooo0_l0001eooooo`00Zoooool2o`0002oooooo0_l0000Cooooo`;o0000MOooool009;o
oooo0_l0000Hooooo`03o`000?oooooooooo02gooooo0_l0002:ooooo`00T_ooool2o`0001Sooooo
00?o0000ooooooooool01_ooool2o`000;7ooooo001oooooo`;o00004Oooool2o`0001Sooooo00?o
0000ooooooooool01_ooool2o`0001Oooooo0_l0000Rooooo`;o0000M?ooool007oooooo0_l0000:
ooooo`;o00001Oooool2o`0001Sooooo00?o0000ooooooooool06Oooool2o`0000Cooooo0_l0000R
ooooo`;o0000M?ooool008_ooooo0_l0000Oooooo`03o`000?oooooooooo01Wooooo0_l0002Noooo
o`00[?ooool3o`0001Cooooo0_l0000Hooooo`;o0000ROooool009Oooooo0_l0000Cooooo`03o`00
0?oooooooooo01Cooooo0_l0000Hooooo`;o0000ROooool0087ooooo0_l0000Dooooo`;o00004ooo
ool00ol0003oooooooooo`0Dooooo`;o0000Xoooool000Wooooo1?l000000ol@413oooooooooo`0F
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00?ok^k^oc8b<_l000000_l00004oooo
o`;o000000?o8B4Qooooooooool00_ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0F
ooooo`03o`000?oooooooooo017ooooo0_l000000ooooooo0000o`000002ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00_ooool2o`000003oooooolQ8B7o8B4Q00Cooooo1Ol00004ooooo`05odA4A?l0
003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46
ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`Co000000?o
410@ooooooooool04_ooool000_ooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool03_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00kooooo
00?oMgMgoiRHV?ooool00_l00005ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oo
oooo00?oMgMgoc8b<_ooool05Oooool00ol0003oooooooooo`0Aooooo`;o00001Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00;ooooo0_l000000ooooooo8B4Qob4Q8@04ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@01oooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool06Oooool00ol0003ooooo
ooooo`0Dooooo`001_l00005ooooo`03o`000?oooooooooo013ooooo1_l00002ooooo`05oa0@4?oo
ooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00Gooooo
1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`05ooooo`Ko
00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo01Sooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00Co0000oooooooooooooooo0_l0000:ooooo`05oa0@4?oo
ooooooooooooool@41004?ooool00ol0003oooooooooo`0=ooooo`05oa0@4?ooooooooooooooool@
41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000ko
oooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`0>ooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003Oooool0
0onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo01Gooooo00?o0000ooooooooool04Oooool2
o`0000Gooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o
MgMgoc8b<_ooool00_ooool2o`0000[ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMg
Molb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Ko
oooo00?oMgMgoc8b<_ooool06Oooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003ooooo
ooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000
ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIV
ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05_ooool00ol0003oooooooooo`0Aooooo`;o
00001Oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?oo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[ooooo00?o0000ooooooooool05?ooool000_o
oooo00?o0000ooooooooool06?ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo01Sooooo0ol0000Hooooo`05oa0@4?ooooooooooooooool@4100
3oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400>oooo
o`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Doooo
o`002oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@
413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004
ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oo
oooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb
<S801?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Cooooo0009ooooo`03oeEE
EOmVIVKo000001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`00013o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_l00004ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0001Oooooo00?o
0000ooooooooool06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c004ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000Iooooo`03oeEEEOmVIVKo
000001Kooooo0022ooooo`;o00001Oooool2o`00027ooooo00?o0000ooooooooool02_ooool2o`00
00kooooo0_l0000Looooo`;o0000:?ooool2o`0005Gooooo0029ooooo`;o00008Oooool00ol0003o
ooooooooo`0:ooooo`;o00003_ooool2o`0001cooooo0_l0000:ooooo`;o00007?ooool2o`0005Go
oooo0029ooooo`;o00008Oooool00ol0003oooooooooo`14ooooo`;o0000J?ooool2o`0000;ooooo
0_l00005ooooo`00[?ooool00ol0003oooooooooo`14ooooo`;o00002oooool2o`0005_ooooo00Ko
k^k^ob4Q8On7QhOo^[Zjo`000?oMgMd5ooooo`00[?ooool00ol0003oooooooooo`08ooooo`;o0000
>_ooool2o`0000_ooooo0_l0001Looooo`04omgMgOl0003o410@olc<c0Kooooo0007oooooooo0000
C?l0000<ooooo`04onk^k_lQ8B7o410@onk^kPKooooo0007ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`?o00001oooool00ol0003ooooo
ooooo`06ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
0_l00007ooooo`04o`000?oooooo0000o`0000Cooooo0ol00006ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`04ob4Q8OmgMgOoMgMgoc8b
<PKooooo0007ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo00?ooooo0_l00009ooooo`;o000000?oooooo`000?l0
00004oooool00ol0003oooooooooo`0Eooooo`;o00002Oooool2o`0000Cooooo0ol0000Wooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`09ooooo`;o
00000_ooool2o`0000Gooooo0029ooooo`;o00003?ooool2o`0001?ooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool04Oooool2
o`0000;ooooo0_l0000?ooooo`;o00007Oooool2o`0007;ooooo002/ooooo`03o`000?oooooooooo
017ooooo0_l00002ooooo`;o00003oooool2o`0001gooooo0_l0001booooo`00[?ooool00ol0003o
ooooooooo`0:ooooo`;o00006_ooool2o`00013ooooo0_l0001oooooo`00[?ooool3o`0000[ooooo
0_l0000Jooooo`;o00001_ooool2o`0000Sooooo0_l0001oooooo`00Roooool2o`0001oooooo00?o
0000ooooooooool0;_ooool2o`0008Wooooo001nooooo`;o00002oooool2o`0001oooooo00?o0000
ooooooooool0^Oooool007kooooo0_l0000/ooooo`03o`000?oooooooooo00?ooooo0_l0000Foooo
o`;o00007?ooool2o`0007kooooo002/ooooo`03o`000?oooooooooo00?ooooo0_l0000Fooooo`;o
00007?ooool2o`0007kooooo002/ooooo`04o`000?oooooo0000o`0004;ooooo0_l0000=ooooo`;o
0000IOooool00:cooooo00Co0000ooooool0003o0000=_ooool2o`0000[ooooo0_l0000=ooooo`;o
0000IOooool008Cooooo0_l0000Vooooo`03o`000?oooooooooo01[ooooo0_l0000Kooooo`;o0000
P?ooool008Cooooo0_l0000Dooooo`;o00004?ooool01?l0003oooooo`000?l0000<ooooo`;o0000
0_ooool2o`0000Oooooo0_l0002Mooooo`00SOooool2o`0000_ooooo0_l0000@ooooo`Co00001_oo
ool2o`0000Cooooo0_l00002ooooo`;o00001oooool2o`0009gooooo002=ooooo`;o00007Oooool0
0ol0003oooooooooo`02o`0000Gooooo0_l0000<ooooo`;o00000oooool2o`0000_ooooo0_l0000?
ooooo`;o0000Ooooool00:cooooo00?o0000ooooooooool00_l0000Cooooo`;o00004?ooool2o`00
00oooooo0_l0001oooooo`00Ooooool2o`0002_ooooo00?o0000ooooooooool0^Oooool007oooooo
0_l0000[ooooo`03o`000?oooooooooo04Cooooo0_l0001cooooo`00[?ooool00ol0003ooooooooo
o`0Vooooo`;o00007?ooool2o`0007?ooooo002Hooooo`;o00004_ooool00ol0003oooooooooo`0=
ooooo`;o00005oooool2o`00097ooooo002Hooooo`;o00004_ooool00ol0003oooooooooo`04oooo
o`;o00001oooool2o`0000Wooooo0_l0002Oooooo`00[?ooool3o`0000Cooooo0_l0000Booooo`;o
00001Oooool2o`0000gooooo0_l00029ooooo`00[?ooool00ol0003oooooooooo`0Oooooo`;o0000
3Oooool2o`0008Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooo
oooo01Sooooo0_l0000Yooooo`;o0000M?ooool008[ooooo0_l0000Pooooo`03o`000?oooooooooo
01Sooooo0_l0000Mooooo`;o00002_ooool2o`0007Cooooo0022ooooo`;o00001_ooool2o`00023o
oooo00?o0000ooooooooool0=_ooool3o`00083ooooo0022ooooo`;o00004oooool2o`0001?ooooo
00?o0000ooooooooool04oooool2o`00027ooooo0_l00021ooooo`00P_ooool2o`00017ooooo1?l0
000Cooooo`03o`000?oooooooooo01?ooooo0_l0002Tooooo`00P_ooool2o`00017ooooo0_l0000E
ooooo`?o0000;?ooool2o`0008_ooooo002Hooooo`;o00004_ooool00ol0003oooooooooo`0Uoooo
o`;o00001Oooool2o`0008_ooooo002Hooooo`;o00004_ooool00ol0003oooooooooo`0Uooooo`;o
0000T_ooool008[ooooo0_l0000Oooooo`;o0000^oooool008[ooooo0_l0000Oooooo`;o00003ooo
ool2o`000:[ooooo002/ooooo`03o`000?oooooooooo00gooooo0_l0000Mooooo`;o0000Roooool0
08Wooooo00Gok^k^o`000?l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo000000?o00001_ooool2o`00027ooooo0_l0
0006ooooo`;o0000Poooool008Wooooo00GoMgMgo`000?l0003oV9RHogMgM`02ooooo`Co000000?o
8B4Qooooooooool00_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooo`000003o`0000Kooooo0_l0000Yooooo`;o0000Poooool008Sooooo0_l0
0003ooooo`03oa0@4?oooooooooo00Co00001_ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oo
oooooooo00?ooooo0ol00003ooooo`;o0000>oooool2o`0007Oooooo0028ooooo`;o00000oooool0
0ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`03ooooo`;o00007Oooool2o`0000Oooooo0_l00006ooooo`?o00002_ooool2
o`0007Oooooo0028ooooo`;o00000oooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo02;ooooo0_l00007
ooooo`;o00001_ooool3o`0008?ooooo0029ooooo`05oa0@4?ooooooooooooooool@41001_ooool2
o`0000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00_ooooo0_l0000Mooooo`;o0000SOooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06
ooooo`;o00000oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0;ooooo`;o00005?ooool2o`0000Oooooo0_l0000Booooo`;o0000NOoo
ool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`;o00000oooool01OnHV9So410@o`00
0?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo01[ooooo0_l00005ooooo`;o0000
1Oooool4o`0001;ooooo0_l0001iooooo`00Roooool4o`0001gooooo00?o0000ooooooooool04?oo
ool2o`0000Sooooo0_l0000<ooooo`Co0000SOooool008_ooooo1?l00008ooooo`;o00004oooool0
0ol0003oooooooooo`0@ooooo`;o00002?ooool2o`0002?ooooo0_l0001hooooo`00U?ooool2o`00
0003ooooool0003o000001?ooooo00?o0000ooooooooool03_ooool2o`0000[ooooo0_l0000Soooo
o`;o0000N?ooool008_ooooo0_l00007ooooo`;o00005_ooool3o`0000kooooo0_l0002Yooooo`00
Roooool2o`0000Oooooo0_l0000Fooooo`03o`000?oooooooooo02Oooooo0_l0002@ooooo`00U?oo
ool2o`0001Kooooo00?o0000ooooooooool04oooool2o`0001;ooooo0_l0002@ooooo`00T?ooool2
o`0001[ooooo00?o0000ooooooooool02Oooool2o`0000?ooooo0_l00003ooooo`;o0000Y?ooool0
093ooooo0_l0000Jooooo`03o`000?oooooooooo00Wooooo0_l00003ooooo`;o0000ZOooool009go
oooo0_l0000=ooooo`03o`000?oooooooooo01kooooo0_l0002Iooooo`00WOooool2o`0000gooooo
00?o0000ooooooooool02Oooool2o`0001?ooooo0ol0000Looooo`;o0000N_ooool00:cooooo00?o
0000ooooooooool02Oooool2o`0001Cooooo0_l0000Looooo`;o0000N_ooool00:cooooo0ol0000a
ooooo`;o0000Q_ooool009?ooooo0_l0000Gooooo`03o`000?oooooooooo033ooooo0ol00007oooo
o`;o0000OOooool009?ooooo0_l0000Gooooo`03o`000?oooooooooo00;o0000;_ooool2o`0000So
oooo0_l0000<ooooo`;o0000Koooool0097ooooo0_l0000Aooooo`;o00001_ooool00ol0003ooooo
ooooo`02o`0000Gooooo0_l0000oooooo`;o0000Koooool0097ooooo0_l0000;ooooo`;o00001?oo
ool2o`0000Kooooo00?o0000ooooooooool01oooool2o`0002Kooooo0_l0000Fooooo`;o0000L?oo
ool009kooooo0_l0000<ooooo`03o`000?oooooooooo02kooooo0ol00008ooooo`;o00003?ooool2
o`00073ooooo0025ooooo`;o00009Oooool00ol0003oooooooooo`0:ooooo`;o00002Oooool2o`00
01Oooooo0_l00009ooooo`;o0000O_ooool008Gooooo0_l0000Uooooo`03o`000?oooooooooo00[o
oooo0_l00002ooooo`;o00001Oooool2o`000:;ooooo002Rooooo`;o00002?ooool3o`0000kooooo
0_l0002Yooooo`00X_ooool4o`0000Kooooo0ol0000>ooooo`;o0000ZOooool00:?ooooo0ol00006
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo03Sooooo0_l0000;oooo
o`;o0000L_ooool008Gooooo0_l0000<ooooo`;o00002_ooool2o`0000_ooooo00?o0000oooooooo
ool0>?ooool2o`0000_ooooo0_l0001booooo`00QOooool2o`0000cooooo0_l00006ooooo`;o0000
0_ooool2o`0000_ooooo00?o0000ooooooooool06?ooool4o`0009gooooo002Kooooo`;o00003ooo
ool00ol0003oooooooooo`0Hooooo`Co0000WOooool00:cooooo00?o0000ooooooooool0:_ooool2
o`0008gooooo002?ooooo`;o00006oooool3o`00017ooooo0_l0000Gooooo`;o0000SOooool008oo
oooo0_l00006ooooo`;o00004oooool00ol0003oooooooooo`0Aooooo`;o00008oooool2o`00087o
oooo002Booooo`;o00000oooool2o`0001?ooooo00?o0000ooooooooool0=_ooool2o`00087ooooo
0023ooooo`;o00003Oooool2o`0000_ooooo0_l0000;ooooo`03o`000?oooooooooo04?ooooo0_l0
001dooooo`00Poooool2o`0001[ooooo0_l0000;ooooo`03o`000?oooooooooo02Sooooo0_l0000I
ooooo`;o0000M?ooool00:cooooo00?o0000ooooooooool02Oooool2o`0001gooooo0_l0002?oooo
o`00Poooool2o`0000cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool02Oooool2o`000:kooooo0020oooo
o`;o000000Coooooo`000?l0003o00002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0:?ooool2o`0008oooooo0020
ooooo`;o00000_ooool2o`0000_ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0:?ooool2o`0008oooooo002Aooooo`05o`000?oooooo
ooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`?o0000<Oooool2o`0008Kooooo002A
ooooo`05o`000?ooooooooooooooool000003?ooool01?l0003o8B4Qo`000?lb<S82o`0000Cooooo
00?o0000ooooooooool01_ooool2o`0001gooooo0_l0000:ooooo`;o0000Q_ooool0097ooooo00Ko
410@oooooooooooooooooa0@4?ooool2o`0000Wooooo0ol000000ooooooo0000o`000004ooooo`03
o`000?oooooooooo00Kooooo0_l0000Mooooo`;o00002_ooool2o`0008Kooooo002Aooooo`06ogMg
MonHV9SooooooiRHV?mgMgOooooo0_l00009ooooo`?o00001oooool00ol0003oooooooooo`2ioooo
o`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`03o`000?oooooooooo
00[ooooo0_l0002]ooooo`00WOooool2o`0000gooooo00?o0000ooooooooool01?ooool2o`0000Co
oooo0_l0002]ooooo`00WOooool4o`0000_ooooo00?o0000ooooooooool01?ooool2o`0003Kooooo
0_l0001kooooo`00Woooool2o`0000_ooooo00?o0000ooooooooool0??ooool2o`0007_ooooo002<
ooooo`;o00007_ooool3o`00013ooooo0_l0002Wooooo`00S?ooool2o`0001Cooooo0_l00008oooo
o`?o00004?ooool2o`000:Oooooo002Rooooo`;o00002?ooool00ol0003oooooooooo`0^ooooo`;o
0000ROooool00:;ooooo0_l00008ooooo`03o`000?oooooooooo00;o0000;?ooool2o`0008Wooooo
002@ooooo`;o00006_ooool00ol0003oooooooooo`02o`000;Oooooo002=ooooo`;o000000?ooooo
o`000?l000006_ooool00ol0003oooooooooo`2iooooo`00SOooool2o`0001gooooo00?o0000oooo
ooooool0^Oooool009oooooo0_l0000;ooooo`03o`000?oooooooooo0;Wooooo002Oooooo`;o0000
1_ooool2o`0000?ooooo0ol0000Cooooo`;o00008_ooool2o`00083ooooo002;ooooo`;o00006_oo
ool2o`0000?ooooo00?o0000ooooooooool04oooool2o`0000Sooooo0_l0000Hooooo`;o0000P?oo
ool008_ooooo0_l0000Oooooo`03o`000?oooooooooo00?ooooo0_l0000Hooooo`;o0000V_ooool0
0:cooooo00?o0000ooooooooool00oooool2o`0002?ooooo0_l0002?ooooo`00Roooool2o`0001oo
oooo00?o0000ooooooooool04?ooool2o`0001Kooooo0_l0002?ooooo`00Roooool2o`0001oooooo
00?o0000ooooooooool00_ooool2o`0000cooooo0_l0002Wooooo`00Toooool2o`0001Oooooo00?o
0000ooooooooool00_ooool2o`000;Gooooo002Cooooo`;o00005oooool00ol0003oooooooooo`0H
ooooo`;o0000Woooool00:cooooo0ol0000Hooooo`;o0000Woooool00:cooooo00?o0000oooooooo
ool06?ooool2o`0009oooooo002/ooooo`03o`000?oooooooooo02Cooooo0_l0002Cooooo`00[?oo
ool00ol0003oooooooooo`0<ooooo`;o00002_ooool2o`0000[ooooo0_l0002Cooooo`00[?ooool0
0ol0003oooooooooo`04ooooo`;o00001_ooool2o`0000[ooooo0_l0002Oooooo`00T_ooool2o`00
00;ooooo0_l00004ooooo`;o00003_ooool00ol0003oooooooooo`04ooooo`;o0000/oooool009;o
oooo0_l00002ooooo`;o00001?ooool2o`0000kooooo00?o0000ooooooooool02_ooool2o`000:go
oooo002/ooooo`03o`000?oooooooooo00[ooooo0_l00008ooooo`;o00006?ooool2o`0008Wooooo
002/ooooo`03o`000?oooooooooo01Cooooo0_l0000:ooooo`;o00003?ooool2o`0008Wooooo002W
ooooo`;o00000oooool3o`00023ooooo0_l0002Gooooo`00Y?ooool5o`0000?ooooo00?o0000oooo
ooooool08?ooool2o`0009Oooooo002Tooooo`Co00001?ooool01?l0003oooooo`000?l0000Aoooo
o`;o00002_ooool2o`0009Wooooo002:ooooo`;o00003Oooool2o`0000_ooooo0_l00004ooooo`04
o`000?oooooo0000o`00017ooooo0_l00007ooooo`;o000000?oooooo`000?l00000VOooool008[o
oooo0_l00008ooooo`;o00000oooool2o`00017ooooo00?o0000ooooooooool06oooool2o`0009co
oooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00olQ8B7o0000o`000005ooooo`03
o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
00Cooooo0_l0002cooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46oooo
o`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`04oooo
o`;o0000/oooool008Wooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo
00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2iooooo`00ROooool01Ol0003o
oooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04oooo
o`?o00009oooool2o`00093ooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool00omE
EEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0W
ooooo`;o0000T?ooool008Wooooo00?o410@ooooooooool00_l0000>ooooo`03ojVYZOmgMgOooooo
00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0;ooooo`;o00002oooool2o`00
09oooooo0029ooooo`03ogMgMonHV9Sooooo00;o00002oooool01Ol@413ooooooooooooooooo<S8b
00;ooooo0ol00009ooooo`03o`000?oooooooooo00[ooooo0ol0000;ooooo`;o0000Woooool008Wo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00000_ooool6o`0000Kooooo00?o0000oooo
ooooool02_ooool2o`0000Wooooo0_l0002Rooooo`00[?ooool00ol0003oooooooooo`0Eooooo`;o
0000X_ooool00:cooooo00?o0000ooooooooool05Oooool2o`000:;ooooo002/ooooo`03o`000?oo
oooooooo01Gooooo0_l0002Rooooo`00SOooool2o`0001gooooo0ol0002iooooo`00SOooool2o`00
01gooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool008oooooo
0_l0000Kooooo`03o`000?oooooooooo013ooooo0ol0002Vooooo`00Soooool2o`0001_ooooo00?o
0000ooooooooool01Oooool2o`0000Wooooo0ol0002Vooooo`00[?ooool00ol0003oooooooooo`05
ooooo`;o0000/_ooool008oooooo0_l0000Cooooo`;o00001_ooool00ol0003oooooooooo`03oooo
o`;o00002?ooool2o`000:[ooooo002?ooooo`;o00004oooool2o`0000Kooooo00?o0000oooooooo
ool00oooool2o`0000Sooooo0_l0000<ooooo`;o0000W?ooool00:cooooo0ol0000Kooooo`;o0000
W?ooool00:cooooo00?o0000ooooooooool03?ooool3o`000:[ooooo002/ooooo`03o`000?oooooo
oooo00cooooo0ol0002Zooooo`00TOooool2o`0001Wooooo00?o0000ooooooooool02oooool2o`00
0:cooooo002Aooooo`;o00006Oooool00ol0003oooooooooo`0;ooooo`;o0000[?ooool00:cooooo
00?o0000ooooooooool01oooool5o`000:gooooo002[ooooo`;o00002Oooool5o`000:gooooo002M
ooooo`;o00003?ooool2o`0000Wooooo0_l0002`ooooo`00WOooool2o`0000;ooooo0_l00009oooo
o`03o`000?oooooooooo00Gooooo0_l0002booooo`00XOooool2o`0000Wooooo0ol00005ooooo`;o
0000/_ooool00:Kooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l0002dooooo`00Y_oo
ool2o`0000Cooooo00?o0000ooooooooool00oooool2o`000;Cooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`04o`000?oooooo0000o`000;Sooooo
002/ooooo`Co0000^?ooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool02_ooool2o`000:gooooo002Zooooo`?o00003?ooool2o`000:gooooo002Zooooo`?o0000
^oooool009oooooo0_l00005ooooo`;o00001?ooool00ol0003oooooooooo`2iooooo`00Woooool2
o`000003ooooool0003o000000Co00001?ooool00ol0003oooooooooo`2iooooo`00Xoooool2o`00
00Oooooo00?o0000ooooooooool0^Oooool00:?ooooo0_l00007ooooo`?o0000^Oooool00:Cooooo
00?o0000ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo00?o0000
ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:;ooooo00?oEEEEofIVI_l0
0000`oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:[o
oooo00Co410@o`000?l0003o0000^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo
00?o0000ooooooooool0^_ooool00:_ooooo00Ko0000ogMgMol0003o0000oeEEEOo^k^jgooooo`00
Zoooool01_l0003oEEEEonk^k_ooooooMgMgoeEEEKOooooo002[ooooo`03o`000?o^k^kooooo00;o
oooo00?o0000ooooooooool0]Oooool00:_ooooo00?o0000onk^k_ooool00_ooool00ol0003ooooo
ooooo`2eooooo`00Zoooool01_l0003oEEEEonk^k_ooooooMgMgofIVI[Oooooo002Zooooo`03oa0@
4?l0003oMgMg00;o000000?oIVIVonk^k_ooool0]_ooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.42486 .17139 Mdot
.65257 .43866 Mdot
.49151 .61431 Mdot
.52845 .34837 Mdot
.44963 .20391 Mdot
.6101 .65841 Mdot
.44556 .61291 Mdot
.70728 .65049 Mdot
.61205 .18556 Mdot
.56363 .46848 Mdot
.4666 .78263 Mdot
.67309 .73792 Mdot
.45541 .9177 Mdot
.51405 .73455 Mdot
.68098 .7086 Mdot
.45938 .75504 Mdot
.58825 .6558 Mdot
.43338 .88505 Mdot
.57398 .57604 Mdot
.68838 .54522 Mdot
.46052 .91851 Mdot
.6482 .60089 Mdot
.63732 .64086 Mdot
.40959 .81206 Mdot
.55126 .92473 Mdot
.46574 .83396 Mdot
.41265 .56492 Mdot
.57743 .49276 Mdot
.68041 .60208 Mdot
.65025 .43324 Mdot
.42734 .86397 Mdot
.62896 .20961 Mdot
.72278 .50888 Mdot
.4623 .85346 Mdot
.47253 .13054 Mdot
.63269 .28533 Mdot
.4344 .92258 Mdot
.53499 .30202 Mdot
.67252 .62495 Mdot
.63775 .80938 Mdot
.51234 .97284 Mdot
.39531 .42218 Mdot
.6109 .36719 Mdot
.51539 .13244 Mdot
.39168 .35971 Mdot
.59212 .45892 Mdot
.55352 .60983 Mdot
.53748 .0833 Mdot
.51908 .2032 Mdot
.68535 .53584 Mdot
.51517 .05901 Mdot
.60958 .79125 Mdot
.54641 .21984 Mdot
.59027 .3042 Mdot
.68996 .3381 Mdot
.70449 .65723 Mdot
.58453 .67083 Mdot
.39358 .2073 Mdot
.38645 .52635 Mdot
.59378 .49938 Mdot
.55956 .06351 Mdot
.67207 .62195 Mdot
.54455 .49858 Mdot
.71286 .43611 Mdot
.67089 .2878 Mdot
.55557 .41135 Mdot
.51802 .69199 Mdot
.55501 .35519 Mdot
.38618 .65945 Mdot
.51536 .82129 Mdot
.51669 .57634 Mdot
.56202 .45981 Mdot
.50829 .26849 Mdot
.67232 .62066 Mdot
.48691 .36352 Mdot
.58586 .58529 Mdot
.63529 .74114 Mdot
.40529 .37528 Mdot
.43312 .11425 Mdot
.6433 .3998 Mdot
.47593 .25088 Mdot
.40765 .29091 Mdot
.72486 .52674 Mdot
.41969 .60637 Mdot
.47156 .18233 Mdot
.50926 .21969 Mdot
.60065 .61374 Mdot
.51273 .7052 Mdot
.54869 .927 Mdot
.74602 .64434 Mdot
.46843 .74397 Mdot
.5673 .34448 Mdot
.51474 .67777 Mdot
.75662 .60137 Mdot
.52597 .70652 Mdot
.49382 .03927 Mdot
.40657 .94972 Mdot
.58822 .66594 Mdot
.47347 .10104 Mdot
.61221 .52334 Mdot
.6842 .70745 Mdot
.55178 .18493 Mdot
.40396 .20989 Mdot
.42836 .79281 Mdot
.48893 .85631 Mdot
.54469 .69235 Mdot
.4635 .74063 Mdot
.38775 .67344 Mdot
.55429 .61418 Mdot
.52922 .34854 Mdot
.61613 .18991 Mdot
.6723 .3885 Mdot
.5786 .03305 Mdot
.43267 .59307 Mdot
.59103 .55398 Mdot
.70814 .38504 Mdot
.68381 .31399 Mdot
.49283 .94848 Mdot
.46824 .9246 Mdot
.5705 .80017 Mdot
.67477 .63241 Mdot
.38457 .63934 Mdot
.54508 .41773 Mdot
.67955 .42654 Mdot
.76383 .51022 Mdot
.5696 .22011 Mdot
.49161 .29962 Mdot
.63105 .66799 Mdot
.53126 .15855 Mdot
.64119 .79904 Mdot
.59056 .7166 Mdot
.62968 .46761 Mdot
.6492 .71169 Mdot
.43406 .9252 Mdot
.68733 .5217 Mdot
.55887 .43465 Mdot
.7199 .55445 Mdot
.6682 .74105 Mdot
.65511 .18994 Mdot
.43905 .30729 Mdot
.57636 .45934 Mdot
.58589 .6643 Mdot
.68748 .47499 Mdot
.72303 .47079 Mdot
.71377 .20103 Mdot
.55786 .6431 Mdot
.54243 .28399 Mdot
.44819 .00176 Mdot
.61258 .49335 Mdot
.49687 .22131 Mdot
.39619 .74469 Mdot
.52191 .51425 Mdot
.55579 .78315 Mdot
.51655 .92567 Mdot
.65618 .68315 Mdot
.70084 .3635 Mdot
.44568 .93954 Mdot
.4975 .94844 Mdot
.39966 .44884 Mdot
.62784 .75869 Mdot
.56792 .17243 Mdot
.59176 .31547 Mdot
.4286 .16295 Mdot
.71981 .44593 Mdot
.45333 .0783 Mdot
.54163 .31654 Mdot
.4877 .95808 Mdot
.67726 .42819 Mdot
.47404 .74178 Mdot
.48224 .20962 Mdot
.44833 .20822 Mdot
.52329 .73918 Mdot
.7205 .49153 Mdot
.7608 .56974 Mdot
.56965 .75595 Mdot
.46875 .70384 Mdot
.67887 .60271 Mdot
.5422 .89611 Mdot
.59972 .86714 Mdot
.4469 .25945 Mdot
.48676 .99653 Mdot
.52971 .579 Mdot
.5813 .14328 Mdot
.76215 .4881 Mdot
.63969 .22452 Mdot
.50576 .98349 Mdot
.62676 .43781 Mdot
.39893 .1225 Mdot
.68804 .47935 Mdot
.51061 .32199 Mdot
.49724 .00074 Mdot
.72072 .58043 Mdot
.38374 .79682 Mdot
.66659 .74968 Mdot
.54402 .28507 Mdot
.69343 .78274 Mdot
.40051 .65275 Mdot
.52583 .54589 Mdot
.5222 .57767 Mdot
.5049 .63433 Mdot
.41598 .33067 Mdot
.66472 .83158 Mdot
.48387 .10395 Mdot
.42839 .5879 Mdot
.59082 .71229 Mdot
.53635 .36978 Mdot
.45959 .71608 Mdot
.43725 .73261 Mdot
.55808 .82915 Mdot
.58873 .56598 Mdot
.45551 .07626 Mdot
.41532 .49173 Mdot
.44011 .13604 Mdot
.59163 .49665 Mdot
.51562 .64785 Mdot
.42609 .82476 Mdot
.65816 .77361 Mdot
.5924 .53903 Mdot
.38857 .24195 Mdot
.43121 .1145 Mdot
.4758 .07045 Mdot
.45458 .74568 Mdot
.40866 .5977 Mdot
.65015 .41639 Mdot
.47279 .74294 Mdot
.6774 .71806 Mdot
.51692 .01648 Mdot
.51975 .69078 Mdot
.49313 .3569 Mdot
.67179 .81713 Mdot
.56792 .30202 Mdot
.41049 .50068 Mdot
.42458 .04422 Mdot
.51437 .25627 Mdot
.58117 .23335 Mdot
.55455 .82938 Mdot
.51489 .13572 Mdot
.55151 .05539 Mdot
.62863 .57449 Mdot
.54795 .13903 Mdot
.51781 .81731 Mdot
.64978 .24328 Mdot
.53611 .59341 Mdot
.56515 .85893 Mdot
.60412 .43955 Mdot
.52467 .80608 Mdot
.66735 .64448 Mdot
.40547 .89543 Mdot
.43799 .62951 Mdot
.49463 .28552 Mdot
.53845 .89472 Mdot
.47888 .83356 Mdot
.46229 .21454 Mdot
.62266 .40312 Mdot
.50125 .40968 Mdot
.71461 .60926 Mdot
.47044 .02991 Mdot
.54944 .25916 Mdot
.41048 .50471 Mdot
.51493 .10187 Mdot
.44014 .35703 Mdot
.60777 .44449 Mdot
.38832 .4272 Mdot
.54684 .63611 Mdot
.62983 .51623 Mdot
.65507 .34246 Mdot
.42872 .76295 Mdot
.66104 .3547 Mdot
.60857 .35349 Mdot
.56524 .48544 Mdot
.46785 .16061 Mdot
.51788 .92471 Mdot
.47521 .22662 Mdot
.43997 .77009 Mdot
.53948 .08692 Mdot
.43932 .74027 Mdot
.5637 .76983 Mdot
.66671 .65665 Mdot
.52989 .42343 Mdot
.44221 .27525 Mdot
.45446 .94855 Mdot
.6945 .68034 Mdot
.53445 .71867 Mdot
.49321 .33775 Mdot
.44902 .78354 Mdot
.65642 .33311 Mdot
.56899 .35267 Mdot
.39586 .26159 Mdot
.76117 .48029 Mdot
.37422 .38777 Mdot
.69788 .6613 Mdot
.37196 .46219 Mdot
.49806 .63725 Mdot
.37367 .38792 Mdot
.42509 .04654 Mdot
.62847 .2668 Mdot
.68883 .68751 Mdot
.75997 .28439 Mdot
.44815 .18061 Mdot
.63411 .51428 Mdot
.55588 .1944 Mdot
.64259 .2314 Mdot
.5512 .92657 Mdot
.53613 .67502 Mdot
.52038 .06598 Mdot
.44956 .8155 Mdot
.51022 .37257 Mdot
.57754 .79517 Mdot
.57096 .70676 Mdot
.50499 .90237 Mdot
.41123 .07608 Mdot
.4285 .53338 Mdot
.40209 .7183 Mdot
.40821 .70303 Mdot
.71762 .47725 Mdot
.46167 .29428 Mdot
.59481 .87334 Mdot
.36533 .60311 Mdot
.71377 .29244 Mdot
.54944 .56665 Mdot
.57752 .74769 Mdot
.42243 .21659 Mdot
.65399 .68606 Mdot
.40507 .46276 Mdot
.52754 .53404 Mdot
.47329 .67209 Mdot
.5223 .8079 Mdot
.68067 .72624 Mdot
.56283 .85999 Mdot
.51446 .67945 Mdot
.61016 .73004 Mdot
.51219 .35226 Mdot
.50363 .63877 Mdot
.65199 .42762 Mdot
.61628 .63746 Mdot
.59409 .32137 Mdot
.39934 .46268 Mdot
.40635 .4435 Mdot
.47104 .8326 Mdot
.62015 .32523 Mdot
.54358 .48211 Mdot
.71356 .42512 Mdot
.42391 .6703 Mdot
.68659 .491 Mdot
.65118 .45343 Mdot
.41926 .51179 Mdot
.57294 .37202 Mdot
.65447 .18839 Mdot
.67368 .73824 Mdot
.3763 .34374 Mdot
.64868 .3226 Mdot
.43085 .22133 Mdot
.42513 .78716 Mdot
.67578 .41707 Mdot
.59388 .37651 Mdot
.67618 .73203 Mdot
.73453 .33989 Mdot
.56213 .15845 Mdot
.64894 .78441 Mdot
.58485 .88677 Mdot
.46395 .9994 Mdot
.45839 .67572 Mdot
.54049 .24383 Mdot
.66833 .73985 Mdot
.71087 .63045 Mdot
.44487 .63644 Mdot
.38036 .4526 Mdot
.49671 .81559 Mdot
.57735 .74496 Mdot
.45514 .11157 Mdot
.52431 .07184 Mdot
.57475 .2224 Mdot
.3865 .73944 Mdot
.61524 .77338 Mdot
.64389 .61139 Mdot
.37044 .49384 Mdot
.63999 .63432 Mdot
.59236 .87137 Mdot
.64363 .1046 Mdot
.44941 .94198 Mdot
.52063 .84277 Mdot
.51421 .41921 Mdot
.39822 .86335 Mdot
.60299 .60513 Mdot
.48449 .66621 Mdot
.57865 .89681 Mdot
.38322 .62214 Mdot
.52806 .5296 Mdot
.52828 .31548 Mdot
.53991 .74062 Mdot
.41512 .39049 Mdot
.56673 .11819 Mdot
.48316 .06545 Mdot
.5892 .88182 Mdot
.51106 .82332 Mdot
.55382 .97316 Mdot
.46175 .85597 Mdot
.52811 .72917 Mdot
.46797 .80751 Mdot
.43918 .5008 Mdot
.69222 .69499 Mdot
.67793 .72647 Mdot
.41458 .59408 Mdot
.42819 .63038 Mdot
.43255 .27513 Mdot
.41742 .41676 Mdot
.36378 .39983 Mdot
.56399 .33288 Mdot
.5758 .18286 Mdot
.44594 .28664 Mdot
.50035 .22764 Mdot
.46843 .28836 Mdot
.52525 .24522 Mdot
.49339 .8472 Mdot
.44073 .25054 Mdot
.42419 .49518 Mdot
.72038 .55179 Mdot
.45459 .41561 Mdot
.50293 .15055 Mdot
.48971 .85557 Mdot
.51977 .84105 Mdot
.46472 .82812 Mdot
.51227 .2513 Mdot
.38061 .77131 Mdot
.73947 .67667 Mdot
.58982 .2511 Mdot
.55053 .1814 Mdot
.4468 .30667 Mdot
.62098 .20194 Mdot
.66124 .75448 Mdot
.46038 .77675 Mdot
.64879 .44013 Mdot
.42232 .57381 Mdot
.52127 .41886 Mdot
.50112 .78223 Mdot
.51729 .10397 Mdot
.40002 .51021 Mdot
.72156 .7211 Mdot
.50596 .67673 Mdot
.48481 .13481 Mdot
.39592 .40556 Mdot
.53159 .62087 Mdot
.43542 .6102 Mdot
.50524 .26039 Mdot
.70746 .64884 Mdot
.43951 .35688 Mdot
.6457 .71841 Mdot
.63948 .37524 Mdot
.38654 .5009 Mdot
.67206 .39195 Mdot
.38014 .47961 Mdot
.53997 .77405 Mdot
.76543 .53187 Mdot
.53978 .34814 Mdot
.67529 .73879 Mdot
.40071 .87877 Mdot
.54881 .62681 Mdot
.37538 .35815 Mdot
.44632 .80718 Mdot
.60593 .5624 Mdot
.68663 .48705 Mdot
.48418 .10223 Mdot
.56864 .60586 Mdot
.57653 .38528 Mdot
.45564 .84845 Mdot
.58387 .08868 Mdot
.62342 .4268 Mdot
.48428 .35832 Mdot
.58694 .30158 Mdot
.4161 .28922 Mdot
.45891 .67772 Mdot
.54665 .5825 Mdot
.54077 .2098 Mdot
.63066 .46894 Mdot
.48572 .7006 Mdot
.52123 .77606 Mdot
.67352 .29384 Mdot
.4461 .20975 Mdot
.39011 .60104 Mdot
.5753 .44261 Mdot
.57322 .44994 Mdot
.43473 .42623 Mdot
.56495 .01815 Mdot
.43948 .38764 Mdot
.65227 .43295 Mdot
.38106 .30629 Mdot
.58396 .19615 Mdot
.56528 .3938 Mdot
.68545 .55494 Mdot
.62948 .82145 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`04ooooo`Co0000^Oooool009[ooooo0_l00008ooooo`03o`000?oooooooooo00Co
oooo0_l0002kooooo`00V_ooool2o`0000Sooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo002T
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:;ooooo00?oEEEEofIV
I_l000001oooool00ol0003oooooooooo`02ooooo`;o0000]Oooool00:cooooo00?o0000oooooooo
ool00_ooool2o`0000kooooo0_l0002Uooooo`00[?ooool00ol0003oooooooooo`0Booooo`;o0000
YOooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00X_ooool2o`00
00Sooooo00?o0000ooooooooool0^Oooool00:;ooooo0_l00008ooooo`03o`000?oooooooooo01Oo
oooo0_l0002Pooooo`00[?ooool00ol0003oooooooooo`0Gooooo`;o0000X?ooool00:[ooooo0ol0
002kooooo`00Z_ooool3o`000;_ooooo002Cooooo`;o00005oooool00ol0003oooooooooo`2ioooo
o`00Toooool2o`0001Oooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00[?oo
ool00ol0003oooooooooo`0>ooooo`;o0000ZOooool00:cooooo00?o0000ooooooooool00_ooool2
o`0000[ooooo0_l0002Yooooo`00[?ooool00ol0003oooooooooo`02ooooo`;o0000]Oooool00:co
oooo00?o0000ooooooooool04?ooool2o`000:Oooooo002Vooooo`;o00001?ooool00ol0003ooooo
ooooo`03ooooo`;o00002oooool2o`000:Oooooo002Tooooo`Co00001?ooool00ol0003ooooooooo
o`03ooooo`;o0000]?ooool00:Cooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo0_l0002b
ooooo`00S_ooool2o`0000gooooo0_l0000=ooooo`?o00001Oooool2o`000;;ooooo002>ooooo`;o
00003?ooool3o`0000gooooo00?o0000ooooooooool0^Oooool009cooooo0_l0000>ooooo`03o`00
0?oooooooooo00Wooooo0_l0002^ooooo`00[?ooool00ol0003oooooooooo`09ooooo`;o0000[_oo
ool00:cooooo00?o0000ooooooooool02_ooool2o`0000cooooo0_l0002Oooooo`00[?ooool00ol0
003oooooooooo`0:ooooo`;o00003?ooool2o`0009oooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002Sooooo`;o00001oooool3o`000;Wooooo002S
ooooo`;o000000?oooooo`000?l000001?ooool01?l0003oooooooooooooool3o`0002Sooooo0_l0
002;ooooo`00Y_ooool2o`0000Cooooo00Co0000oooooooooooooooo0ol0000Xooooo`;o0000Rooo
ool00:cooooo00?o0000ooooooooool0^Oooool009gooooo0_l0000=ooooo`03o`000?oooooooooo
0;Wooooo002Eooooo`;o00001_ooool2o`0000gooooo00?o0000ooooooooool0^Oooool008Wooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q0_l00004ooooo`03o`000?o^k^kooooo00Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01?ooooo0_l0002Toooo
o`00ROooool01OmgMgOo0000o`000?nHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo
00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Cooooo`;o0000Y?ooool0087o
oooo1_l00002ooooo`05oa0@4?l0003o0000ooooool@41003Oooool00onYZJWoEEEEooooo`08oooo
o`03o`000?oooooooooo00?ooooo0ol0002iooooo`00ROooool01Ol0003ooooooooooooooooo0000
00kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
0;Wooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03oooo
o`?o000000?o<S8bolc<c?ooool01?ooool00ol0003oooooooooo`2iooooo`00ROooool01Ol@413o
oooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool2o`0000?ooooo0_l00003oooo
o`03o`000?oooooooooo00;ooooo0_l0002eooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg
00[ooooo0_l00003ooooo`03oc8b<_oooooooooo00;ooooo00?o0000ooooooooool00_ooool2o`00
00?ooooo00Co0000oooooooooooooooo0ol0002eooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00[ooooo1_l00004ooooo`Co00001_ooool01?l0003oooooooooooooool2o`0000Wooooo0_l0
002[ooooo`00[?ooool00ol0003oooooooooo`0<ooooo`;o00002Oooool2o`000:3ooooo002/oooo
o`03o`000?oooooooooo01Oooooo0_l0002Pooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
[?ooool3o`000;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool01oooool2
o`0000Sooooo0_l0002Vooooo`00XOooool2o`0000Wooooo00?o0000ooooooooool01oooool2o`00
00Sooooo0_l0002Vooooo`00U?ooool2o`0000_ooooo0_l00009ooooo`03o`000?oooooooooo0;Wo
oooo002Dooooo`;o00005_ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00Toooool2o`0001Oooooo00?o0000ooooooooool04oooool2o`000:Cooooo002Coooo
o`;o00005oooool3o`0001?ooooo0_l0002Tooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
V_ooool2o`0000Kooooo0_l00008ooooo`03o`000?oooooooooo00gooooo0_l00007ooooo`;o0000
XOooool009[ooooo0_l00006ooooo`;o00002?ooool00ol0003oooooooooo`0=ooooo`?o00001_oo
ool2o`0000[ooooo0_l0002Eooooo`00[?ooool00ol0003oooooooooo`0>ooooo`;o00004_ooool2
o`0000cooooo0_l00027ooooo`00[?ooool00ol0003oooooooooo`0Sooooo`;o00002oooool2o`00
08Oooooo002/ooooo`03o`000?oooooooooo00oooooo0_l0000Booooo`;o00002oooool2o`0008Oo
oooo002/ooooo`03o`000?oooooooooo00oooooo0_l00007ooooo`;o0000Woooool00:cooooo0ol0
000Hooooo`;o0000:Oooool2o`0007Cooooo002Kooooo`;o00003oooool00ol0003oooooooooo`03
ooooo`;o00008?ooool2o`0001cooooo0_l0001dooooo`00R?ooool2o`00017ooooo0_l0000?oooo
o`03o`000?oooooooooo00?ooooo0_l0000Pooooo`;o0000T_ooool008Sooooo0_l00002ooooo`;o
00003?ooool3o`0000Wooooo0_l00004ooooo`03o`000?oooooooooo00[ooooo0_l0000Kooooo`;o
0000T?ooool008cooooo0_l0000<ooooo`?o00002Oooool2o`0000Cooooo00?o0000ooooooooool0
2_ooool2o`0001_ooooo0_l0002@ooooo`00T_ooool2o`0000_ooooo0_l0000;ooooo`03o`000?oo
oooooooo0;Wooooo002Booooo`;o00002oooool2o`0000_ooooo00?o0000ooooooooool00_l0002g
ooooo`00UOooool2o`0001Cooooo0_l00002ooooo`;o00002_ooool2o`0000Kooooo0ol0002Roooo
o`00UOooool2o`0001Cooooo1?l0000<ooooo`;o00001_ooool3o`0001Cooooo0_l0002<ooooo`00
Xoooool2o`0000Oooooo0_l0000/ooooo`;o0000S?ooool00:?ooooo0_l00007ooooo`;o0000;Ooo
ool2o`0008_ooooo002/ooooo`03o`000?oooooooooo01Oooooo0_l0000Cooooo`;o0000Roooool0
0:cooooo00?o0000ooooooooool05oooool2o`000:3ooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo0027ooooo`;o00002?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0:ooooo`;o00008_ooool2o`00
08Wooooo0027ooooo`;o00002?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool01Oooool2o`0000?ooooo0_l0000Roooo
o`;o0000ROooool008Wooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo0_l0002booooo`00TOooool01Ol0003o
oooooooooooooooo000000;ooooo0_l0000:ooooo`;o000000?o<S8booooooooool00oooool3o`00
0003ooooool0003o000001Oooooo0_l0002Mooooo`00TOooool01Ol0003ooooooooooooooooo0000
00;ooooo0_l00008ooooo`05o`000?lQ8B7o0000o`000?o<c<`01Oooool01?l0003ooooooooooooo
ool2o`0001Oooooo0_l0002Mooooo`00TOooool01Ol@413ooooooooooooooooo410@00cooooo00?o
0000ooooooooool01oooool01?l0003oooooooooooooool2o`0000[ooooo0_l0002Zooooo`00ROoo
ool2o`0000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`;o00001_ooool00ol0003ooooo
ooooo`07ooooo`?o000000?oooooo`000?l000002_ooool2o`000:[ooooo0029ooooo`;o00001_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo0_l00006ooooo`Co00001_ooool3o`000;Wooooo
002/ooooo`03o`000?oooooooooo02Oooooo0_l0002@ooooo`00[?ooool01?l0003oooooo`000?l0
000Vooooo`;o0000T?ooool00:cooooo00Co0000ooooool0003o0000^?ooool009Gooooo0_l00000
0ooooooo0000o`00000Booooo`?o0000^Oooool009Gooooo0_l000000ooooooo0000o`00000Boooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Zooooo`?o0000
3Oooool2o`0001_ooooo0_l0000Xooooo`;o0000IOooool0093ooooo0_l00008ooooo`;o00001Ooo
ool2o`0000Oooooo0ol0000=ooooo`;o00006oooool2o`0000_ooooo0_l0000Kooooo`;o0000IOoo
ool008gooooo0_l000000ooooooo0000o`000008ooooo`;o00001Oooool2o`0000Wooooo00?o0000
ooooooooool0=Oooool2o`0000cooooo0_l0001dooooo`00SOooool2o`00013ooooo0_l0000;oooo
o`03o`000?oooooooooo03Kooooo0_l0000;ooooo`;o0000M?ooool009oooooo0_l0000;ooooo`03
o`000?oooooooooo03Kooooo0_l00021ooooo`00ZOooool2o`000004ooooool0003o0000o`0001Wo
oooo0_l0002Nooooo`00ZOooool2o`000003ooooool0003ooooo00Wooooo0_l00009ooooo`;o0000
1?ooool3o`0009gooooo0024ooooo`;o00004Oooool2o`000003ooooool0003o0000013ooooo00?o
0000ooooooooool02?ooool2o`0000Wooooo0_l00005ooooo`;o0000WOooool008Cooooo0_l0000A
ooooo`;o000000?oooooo`000?l000004?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`06ooooo`;o00000_ooool2o`0000oo
oooo0_l0000Looooo`;o0000O_ooool00:cooooo00?o0000ooooooooool01_ooool2o`0000;ooooo
0_l0000?ooooo`;o00007?ooool2o`0007kooooo002/ooooo`03o`000?oooooooooo00;o00006_oo
ool2o`00013ooooo0_l00029ooooo`00[?ooool5o`0001[ooooo0_l00006ooooo`;o00002?ooool2
o`0008Wooooo002/ooooo`03o`000?oooooooooo02Cooooo0_l0002Cooooo`00T?ooool2o`0001[o
oooo00?o0000ooooooooool0^Oooool0093ooooo0_l0000Jooooo`03o`000?oooooooooo01;ooooo
0_l0000Looooo`;o0000Qoooool00:Wooooo0_l000000ooooooo0000ooooo`0Cooooo`;o00007?oo
ool2o`0008Oooooo002Yooooo`;o000000?oooooo`000?ooool0??ooool2o`0000gooooo0_l0001]
ooooo`00Poooool2o`0002Oooooo00?o0000ooooooooool0<?ooool2o`0000Wooooo0_l0000=oooo
o`;o0000KOooool008?ooooo0_l0000Wooooo`03o`000?oooooooooo01?ooooo0_l0000Kooooo`;o
0000Qoooool00:cooooo00?o0000ooooooooool01_ooool2o`0000;ooooo0_l00007ooooo`;o0000
Y?ooool00:cooooo0ol000000ooooooo0000o`000003ooooo`;o00000_ooool2o`0000Oooooo0_l0
002Tooooo`00[?ooool01?l0003oooooooooooooool2o`0000cooooo0_l00002ooooo`;o00002ooo
ool2o`00013ooooo0_l00025ooooo`00P_ooool2o`0001Cooooo0_l0000<ooooo`;o000000Gooooo
o`000?l0003oooooo`00000Aooooo`;o00003oooool2o`00013ooooo0_l00025ooooo`00P_ooool2
o`0000Cooooo0_l0000>ooooo`;o00003?ooool2o`000005ooooool0003o0000ooooool00000^ooo
ool008Sooooo0_l0000Mooooo`;o00000oooool00ol0003oooooooooo`0oooooo`;o0000N?ooool0
08Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4
o`000?l0003o<S8bomgMg@02o`0000?ooooo00?o0000ooooooooool08Oooool2o`0001cooooo0_l0
001hooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00Wooooo
0_l0000Fooooo`;o0000U_ooool0087ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_l00007ooooo`;o00002_ooool2o`000:;ooooo0029ooooo`03o`000?oooooooooo00;o00003Ooo
ool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo1Ol0000Cooooo`;o00001Ooo
ool2o`0000gooooo0_l0002<ooooo`00ROooool00ol0003oooooooooo`02o`0000kooooo00?oMgMg
ofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool07?oo
ool2o`0000gooooo0_l0002<ooooo`00ROooool01Ol@413ooooooooooooooooo410@00oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Wooooo0029
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Fooooo`;o0000:Oooool2o`0007Kooooo
0022ooooo`;o00001Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00[ooooo0_l000001?l@413o0000
ob4Q8Oo<c<`4ooooo`Co00001_ooool00ol0003oooooooooo`0Fooooo`;o00007Oooool2o`0000[o
oooo0_l0001fooooo`00P_ooool2o`0000cooooo0_l00006ooooo`;o00004_ooool00ol0003ooooo
ooooo`0eooooo`;o0000P_ooool0093ooooo0_l0000Jooooo`03o`000?oooooooooo01;ooooo0_l0
000Qooooo`;o0000P_ooool00:cooooo00?o0000ooooooooool04_ooool2o`000:Gooooo001ooooo
o`;o0000:oooool3o`0002cooooo0_l0002;ooooo`00Ooooool2o`0002_ooooo00?o0000oooooooo
ool09Oooool2o`0000Gooooo0_l0002;ooooo`00ROooool2o`00027ooooo00?o0000ooooooooool0
9Oooool2o`0009;ooooo0029ooooo`;o00008Oooool2o`000;[ooooo002/ooooo`;o00004?ooool2
o`000:Sooooo002Mooooo`;o00003Oooool00ol0003oooooooooo`0?ooooo`;o00007Oooool2o`00
08Wooooo002@ooooo`;o00002oooool2o`0000gooooo00Co0000oooooooooooooooo0_l000000ooo
oooo0000o`000005ooooo`;o00008Oooool2o`0000Oooooo0_l00020ooooo`00ROooool2o`0000Go
oooo0_l0000Jooooo`04o`000?ooooooooooooooo`;o000000?oooooo`000?l000001Oooool2o`00
02[ooooo0_l00020ooooo`00ROooool2o`00027ooooo0ol00006ooooo`;o0000>oooool2o`0007Co
oooo0027ooooo`;o00003Oooool2o`0001Cooooo00?o0000ooooooooool01_ooool2o`0001gooooo
0_l00008ooooo`;o00001_ooool3o`0000Wooooo0_l0001dooooo`00Qoooool2o`0000gooooo0_l0
000Dooooo`03o`000?oooooooooo02Gooooo0_l00008ooooo`;o00001_ooool3o`0007oooooo002/
ooooo`03o`000?oooooooooo013ooooo0_l0000Looooo`?o0000R?ooool00:cooooo00?o0000oooo
ooooool04?ooool2o`0001Cooooo0_l00006ooooo`?o00004_ooool2o`0007Cooooo002/ooooo`03
o`000?oooooooooo01oooooo0_l00005ooooo`;o00001_ooool3o`0001;ooooo0_l0001dooooo`00
SOooool2o`0001gooooo00?o0000ooooooooool05Oooool2o`0000Sooooo0_l0000=ooooo`?o0000
R?ooool008gooooo0_l0000Mooooo`03o`000?oooooooooo01Gooooo0_l00009ooooo`;o00008ooo
ool2o`0007;ooooo002:ooooo`;o00008?ooool00ol0003oooooooooo`0Eooooo`;o00002Oooool2
o`0002?ooooo0_l0001booooo`00Q?ooool2o`0000Cooooo0_l0000Pooooo`?o00005Oooool2o`00
0:;ooooo0024ooooo`;o00009_ooool00ol0003oooooooooo`0^ooooo`;o0000ROooool00:cooooo
00?o0000ooooooooool06oooool2o`00017ooooo0_l00029ooooo`002Oooool4o`000003oa0@4?oo
oooooooo01Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^
ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Kooooo
00?o0000ooooooooool04Oooool2o`0000?ooooo0_l000000oo^k^ko<S8bo`000002o`0000Gooooo
0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0
003o0000oc8b<_oMgMd06?ooool4o`000003oa0@4?oooooooooo01;ooooo000;ooooo`03o`000?oo
oooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVY
ooooo`07ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool2o`00
0003ob4Q8Ooooooooooo00;ooooo00?oV9RHob4Q8Ol000000ol00006ooooo`03ogMgMolb<S;ooooo
01Gooooo00?o0000ooooooooool04Oooool2o`0000?ooooo0_l000001OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8boooo
o`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0
3_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oo
oooo00?oMgMgoc8b<_ooool06Oooool00ol0003oooooooooo`0Dooooo`001_l00005ooooo`03o`00
0?oooooooooo013ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol0003oooooooooo`05ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo
410@00Cooooo0_l00006ooooo`03oiRHV?l0003o000000;o00001oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo01Sooooo00Go410@oooooooooooooooooa0@400:ooooo`;o000000?o
V9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`0=ooooo`05oa0@4?ooooooooooooooool@4100
4?ooool00ol0003oooooooooo`0=ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05?ooool000_ooooo
00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qoooooooo
ool01_ooool00omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003oooool00omg
MgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07
ooooo`03ogMgMolb<S;ooooo01Gooooo00?o0000ooooooooool04_ooool2o`0000Cooooo00Go0000
ooooooooooooooooo`00000:ooooo`?o000000?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8boooo
o`0>ooooo`?o000000?oooooo`000?ooool03_ooool00omgMgOo<S8booooo`0>ooooo`05o`000?oo
ooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Wooooo
00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooo
oooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oo
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<01Kooooo00?o0000ooooooooool04_ooool2o`0000Cooooo00Go0000oooooooooooo
ooooo`00000;ooooo`;o000000?oooooogMgMomVIVH01?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00oooooo0ol000000ooooooo0000ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<01[ooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?oo
ool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003ooooo
ooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0Aooooo`05
oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01Sooooo0ol0000Hooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Kooooo0_l00008ooooo`;o00000oooool00ol@413oooooooooo`0:
ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmg
MgOooooo00?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Dooooo`002oooool0
0ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooo
oooooooo<S8b00Cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00co
oooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo0_l00002oooo
o`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
1?ooool00ol0003oooooooooo`06ooooo`?o00001oooool2o`000004oiRHV?ooooooV9RHogMgM`Wo
oooo0_l000000ooooooo0000ooooo`0Booooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@
413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0D
ooooo`002Oooool00omEEEGoIVIVo`00000Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5
o`0000Cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00013ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP07ooooo`;o00000_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Co
oooo1?l0000Gooooo`03o`000?oooooooooo00_ooooo0_l0000;ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o00002?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Wooooo0_l000000ooooooo0000o`000002o`00013ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0001Wooooo00?oEEEEofIVI_l00000
5_ooool00:cooooo00?o0000ooooooooool02oooool2o`0000Gooooo0_l0002Uooooo`00[?ooool0
0ol0003oooooooooo`0Booooo`;o00009_ooool2o`0001Oooooo0_l0001Tooooo`00T?ooool2o`00
01[ooooo00?o0000ooooooooool0>_ooool2o`0000Wooooo0_l0000<ooooo`;o0000FOooool2o`00
00;ooooo0_l00005ooooo`00POooool2o`0000gooooo0_l000000ooooooo0000o`00000Gooooo`03
o`000?oooooooooo01Kooooo0_l0000:ooooo`;o00005_ooool2o`0000Wooooo0_l0001Wooooo`06
onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1Oooool0087ooooo0_l0000@ooooo`;o00005oooool00ol0
003oooooooooo`0Fooooo`;o00000oooool2o`0000Gooooo0_l0002;ooooo`04omgMgOl0003o410@
olc<c0Kooooo0007oooooooo0000C?l0000<ooooo`04onk^k_lQ8B7o410@onk^kPKooooo0007oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;o00000oooool00ol0003oooooooooo`02o`0000Cooooo00?o0000oooo
ooooool00_l00003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo0_l000000ooooooo0000ooooo`06oooo
o`03o`000?oooooooooo00?ooooo0ol00008ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00Co8B4QogMg
MomgMgOo<S8b1_ooool000Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02?ooool2o`0001cooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`09ooooo`;o00000_ooool2o`0000Gooooo002;ooooo`;o
000000?oooooo`000?l000007?ooool00ol0003oooooooooo`16ooooo`;o00003?ooool2o`0006?o
oooo002;ooooo`;o00001?ooool2o`0001Wooooo00?o0000ooooooooool0A_ooool2o`0000cooooo
0_l0001Sooooo`00TOooool2o`0001Wooooo00?o0000ooooooooool01?ooool2o`00027ooooo1?l0
002>ooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o00008Oooool4o`0008kooooo002/oooo
o`03o`000?oooooooooo03[ooooo0_l0001mooooo`00[?ooool3o`0002;ooooo0_l0000Fooooo`;o
0000OOooool008Kooooo0_l0000Tooooo`03o`000?oooooooooo02;ooooo0_l0000Sooooo`;o0000
L?ooool008Kooooo0_l0000Tooooo`03o`000?oooooooooo00Kooooo0_l0000oooooo`;o0000L?oo
ool009Cooooo0_l0000Fooooo`03o`000?oooooooooo00Kooooo0_l0001<ooooo`;o0000Hoooool0
09Cooooo0_l0000Fooooo`03o`000?oooooooooo00Kooooo0_l0000booooo`;o00006?ooool2o`00
06?ooooo002/ooooo`03o`000?oooooooooo01_ooooo0_l0000Mooooo`;o0000OOooool00:cooooo
00?o0000ooooooooool06oooool2o`0009cooooo002/ooooo`03o`000?oooooooooo00Gooooo0_l0
000dooooo`;o0000O?ooool00:cooooo00?o0000ooooooooool01Oooool2o`0003Cooooo0_l0001l
ooooo`00[?ooool3o`0004Gooooo0_l0001booooo`00[?ooool00ol0003oooooooooo`0Kooooo`;o
00007Oooool2o`0000Wooooo0_l0001booooo`00[?ooool00ol0003oooooooooo`0Kooooo`;o0000
7Oooool2o`0000Wooooo0_l0001booooo`00[?ooool00ol0003oooooooooo`2iooooo`00Soooool2
o`0001_ooooo00?o0000ooooooooool08?ooool2o`0009Oooooo002?ooooo`;o00006oooool00ol0
003oooooooooo`0=ooooo`;o00002oooool2o`0000Cooooo0_l0002Gooooo`00[?ooool00ol0003o
ooooooooo`0=ooooo`;o00002oooool2o`0003Oooooo0_l0001Tooooo`00T_ooool2o`0001Sooooo
00?o0000ooooooooool0Doooool2o`0006Cooooo002Booooo`;o00006?ooool3o`0000;ooooo0_l0
000Aooooo`;o00004?ooool2o`00093ooooo002/ooooo`03o`000?oooooooooo00;ooooo1_l0000=
ooooo`;o00004?ooool2o`00093ooooo002/ooooo`03o`000?oooooooooo00Cooooo1?l00004oooo
o`;o0000=oooool2o`0007;ooooo002/ooooo`03o`000?oooooooooo00cooooo0_l0000;ooooo`;o
0000:_ooool2o`0007;ooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`0Iooooo`;o0000
W_ooool009Cooooo0_l0000Fooooo`03o`000?oooooooooo0;Wooooo002?ooooo`;o00001?ooool2
o`0001Gooooo00?o0000ooooooooool02?ooool2o`000:oooooo002=ooooo`Co00001?ooool2o`00
01Gooooo00?o0000ooooooooool02?ooool2o`000:oooooo0027ooooo`;o00001?ooool2o`0001go
oooo0ol0000]ooooo`;o00008_ooool2o`0006Kooooo001oooooo`;o00001_ooool2o`0002?ooooo
00?o0000ooooooooool0;Oooool2o`0000Wooooo0_l0000Gooooo`;o0000I_ooool007oooooo0_l0
000@ooooo`;o00006Oooool00ol0003oooooooooo`0Cooooo`;o00002_ooool2o`0001Oooooo0_l0
001oooooo`00TOooool2o`0000?ooooo0_l0000Dooooo`03o`000?oooooooooo00kooooo0_l00003
ooooo`;o00002_ooool2o`0002;ooooo0_l0001dooooo`00U_ooool2o`0000;ooooo0_l0000@oooo
o`03o`000?oooooooooo00kooooo0_l0000Looooo`;o00005Oooool2o`0007Cooooo002Jooooo`;o
00003Oooool2o`000003ooooool0003ooooo00oooooo0_l0000>ooooo`;o00003?ooool2o`0008_o
oooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05
odA4A?l0003o0000oc8b<_oMgMd00_ooool2o`000003ooooool0003ooooo00oooooo0_l0000>oooo
o`;o0000VOooool008Gooooo0_l00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool01oooool2o`0002cooooo0_l00022ooooo`00QOooool2o`0000;ooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3
o`0000Oooooo0_l0000/ooooo`?o0000POooool008Wooooo00Go0000ooooooooooooooooo`00000=
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0=
ooooo`;o00009oooool2o`00087ooooo0029ooooo`05o`000?ooooooooooooooool000001_ooool2
o`000003ooooool0003o000000?ooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Gooooo00?o0000ooooooooool03Oooool2o`0003?ooooo0_l0001eooooo`00ROooool0
1Ol@413ooooooooooooooooo410@00Kooooo0_l000000ooooooo0000o`000004ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01oooool3o`0002_ooooo0_l00009ooooo`;o00002_oo
ool2o`0007Gooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool2o`000003oooooonH
V9So410@00Cooooo00?o0000ooooooooool01_ooool4o`0000cooooo0_l0000Eooooo`;o00001_oo
ool2o`0000Wooooo0_l00021ooooo`00QOooool2o`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`?o000000?o8B4Qolc<c?ooool00oooool4o`0000Gooooo1?l0000<ooooo`;o00005Ooo
ool2o`0000Gooooo0_l0002=ooooo`00QOooool2o`0002Gooooo0ol0000@ooooo`;o00006?ooool2
o`0008gooooo002/ooooo`03o`000?oooooooooo013ooooo0_l0000Rooooo`;o00006?ooool2o`00
06Wooooo002/ooooo`03o`000?oooooooooo00;ooooo0_l0000`ooooo`;o00002oooool2o`0000_o
oooo0_l0001Yooooo`00Roooool2o`0001oooooo0ol00002ooooo`;o0000?Oooool2o`0007Kooooo
002;ooooo`;o00007oooool00ol0003oooooooooo`0Jooooo`;o00009Oooool2o`0007Kooooo002/
ooooo`03o`000?oooooooooo01[ooooo0_l00005ooooo`;o00004Oooool2o`0000[ooooo0_l0001g
ooooo`00Q_ooool2o`0002Cooooo00?o0000ooooooooool08Oooool2o`00017ooooo0_l00008oooo
o`Co0000Moooool008Kooooo0_l0000Tooooo`03o`000?oooooooooo01Wooooo0_l0000Sooooo`;o
0000NOooool00:Kooooo0_l00004ooooo`03o`000?oooooooooo01Wooooo0ol0000<ooooo`;o0000
Soooool009;ooooo0_l0000Booooo`;o00001?ooool00ol0003oooooooooo`0Hooooo`Co00003?oo
ool2o`0008oooooo0027ooooo`;o00002Oooool2o`0000oooooo0_l00007ooooo`03o`000?oooooo
oooo01Sooooo0_l0002Oooooo`00Qoooool2o`0001Gooooo0_l00003ooooo`;o00001oooool4o`00
00Oooooo0_l00012ooooo`;o0000Joooool009kooooo0_l0000<ooooo`03o`000?oooooo000000?o
00001Oooool2o`0004;ooooo0_l0001[ooooo`00W_ooool2o`0000cooooo00Co0000oooooooooooo
oooo0_l0000]ooooo`;o00002oooool2o`0007[ooooo002/ooooo`03o`000?oooooooooo02oooooo
0ol0000;ooooo`;o0000N_ooool00:cooooo00?o0000ooooooooool0;oooool2o`0000[ooooo0_l0
001looooo`00[?ooool00ol0003oooooooooo`03ooooo`;o00001_ooool2o`0002kooooo0_l0001l
ooooo`00[?ooool00ol0003oooooooooo`03ooooo`;o00001_ooool2o`0002oooooo0_l0001koooo
o`00[?ooool00ol0003oooooooooo`0looooo`;o0000Noooool00:Oooooo0_l00003ooooo`?o0000
^Oooool008gooooo0_l0000Booooo`;o00001?ooool2o`0000?ooooo00?o0000ooooooooool0^Ooo
ool008gooooo0_l0000Booooo`;o00002Oooool01?l0003oooooooooooooool2o`0000;ooooo0_l0
000=ooooo`;o00008oooool2o`0007kooooo002/ooooo`04o`000?ooooooooooooooo`;o00000_oo
ool2o`0000gooooo0_l0000Rooooo`?o0000O_ooool00:cooooo00?o0000ooooooooool06oooool2
o`00017ooooo0_l00008ooooo`;o0000Ooooool009kooooo0_l0000<ooooo`03o`000?oooooooooo
01_ooooo0_l0000Aooooo`;o0000ROooool008_ooooo0_l0000Aooooo`;o00003?ooool00ol0003o
ooooooooo`08ooooo`;o00004?ooool2o`00017ooooo0_l00008ooooo`;o0000P?ooool008_ooooo
0_l0000Oooooo`03o`000?oooooooooo00Sooooo0_l0000@ooooo`;o00004Oooool2o`0000Sooooo
0_l0000=ooooo`;o0000LOooool00:cooooo0ol00016ooooo`;o0000LOooool00:cooooo00?o0000
ooooooooool0=oooool3o`0007oooooo002/ooooo`03o`000?oooooooooo00Kooooo0_l0000Ioooo
o`;o00005?ooool3o`0007oooooo002Gooooo`;o00004oooool01?l0003oooooooooooooool2o`00
00?ooooo0_l0000Iooooo`;o00005?ooool2o`00083ooooo002Gooooo`;o00004oooool01?l0003o
ooooooooooooool2o`0003Cooooo0_l00020ooooo`00Q_ooool2o`00013ooooo0_l00006ooooo`;o
00002_ooool00ol0003oooooooooo`04ooooo`;o00001?ooool2o`0002Sooooo1?l00021ooooo`00
Q_ooool2o`0000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`;o000000?oooooob4Q8OlQ
8B400oooool2o`000005odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`04oooo
o`;o00001?ooool2o`0001gooooo0_l00009ooooo`Co0000POooool008Wooooo0_l00006ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@;o00000_ooool4o`000003ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool05_ooool2o`00017ooooo0_l00009ooooo`;o0000Poooool008Wo
oooo0_l00006ooooo`05oa0@4?ooooooooooooooool@41001oooool2o`0000;ooooo0_l00003oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05_ooool2o`0001cooooo0_l00023oooo
o`00TOooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool3o`00
01Kooooo0_l0000Looooo`;o0000Poooool0097ooooo00Go0000ooooooooooooooooo`000008oooo
o`;o00000_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool05?ooool2
o`0001cooooo0_l00025ooooo`00TOooool01Ol@413ooooooooooooooooo410@00Sooooo0_l00002
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05?ooool2o`00017ooooo0_l00009
ooooo`;o0000QOooool0097ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool09oooool2o`00093ooooo002Aooooo`03onk^k_lb<S;o0000
00;o00003?ooool4o`0000Kooooo00?o0000ooooooooool0^Oooool009Cooooo0_l0000Fooooo`03
o`000?oooooooooo0;Wooooo002Hooooo`;o00004_ooool00ol0003oooooooooo`0Booooo`;o0000
YOooool008Cooooo0_l0000Booooo`;o00004_ooool00ol0003oooooooooo`0:ooooo`;o00001_oo
ool2o`0000oooooo0_l0000<ooooo`;o0000Q_ooool008Cooooo0_l0000Hooooo`;o00003?ooool3
o`0000Cooooo0_l00004ooooo`;o00005oooool2o`0000cooooo0_l00026ooooo`00W_ooool2o`00
00cooooo00?o0000ooooooooool01?ooool2o`000;?ooooo002Qooooo`;o00002Oooool2o`00013o
oooo0_l0000[ooooo`;o0000Noooool009_ooooo0_l00004ooooo`;o00002Oooool2o`00013ooooo
0_l0000Mooooo`;o00003?ooool2o`0007_ooooo002Cooooo`;o00001_ooool2o`0000oooooo00?o
0000ooooooooool0;_ooool2o`0008Wooooo002Cooooo`;o00005oooool00ol0003oooooooooo`0Q
ooooo`;o0000U_ooool009Cooooo0_l0000Fooooo`03o`000?oooooooooo01Kooooo0_l00009oooo
o`;o0000U_ooool008Gooooo0_l0000=ooooo`;o00005_ooool00ol0003oooooooooo`0Fooooo`;o
0000XOooool008Gooooo0_l0000Uooooo`?o00005?ooool2o`0001Gooooo0_l0002<ooooo`00[?oo
ool00ol0003oooooooooo`0Dooooo`;o00005Oooool2o`0008cooooo002Jooooo`;o00004?ooool0
0ol0003oooooooooo`05ooooo`;o0000/_ooool009[ooooo0_l00005ooooo`;o00002Oooool00ol0
003oooooooooo`04ooooo`?o00008oooool2o`0008gooooo002>ooooo`;o00004Oooool2o`0000Wo
oooo00?o0000ooooooooool01?ooool2o`0002Cooooo0_l0002=ooooo`00S_ooool2o`0000_ooooo
0_l0000=ooooo`?o0000^oooool009_ooooo0_l0000=ooooo`?o00001?ooool2o`00037ooooo0_l0
0022ooooo`00[?ooool00ol0003oooooooooo`02ooooo`;o00008oooool2o`0000cooooo0_l00022
ooooo`00Toooool2o`0001Oooooo1ol0000Sooooo`;o0000T?ooool009?ooooo0_l0000;ooooo`;o
00002_ooool00ol0003oooooooooo`02o`000;Oooooo002Pooooo`;o00002_ooool00ol0003ooooo
ooooo`0?ooooo`?o00008Oooool2o`0008Cooooo002Pooooo`Co000000?oooooo`000?l000001Ooo
ool00ol0003oooooooooo`0?ooooo`?o00008Oooool2o`0008Cooooo002Pooooo`Co000000?ooooo
o`000?l000001Oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`03ooooo`;o0000]?ooool00:cooooo00?o0000ooooooooool0
0oooool2o`000;Cooooo002Mooooo`;o00002_ooool2o`000003ooooool0003ooooo0;[ooooo002M
ooooo`;o00002_ooool2o`000004ooooool0003o0000o`000;Wooooo002Oooooo`;o00001oooool2
o`0000;ooooo00?o0000ooooooooool0^Oooool009oooooo0_l00007ooooo`;o00000_ooool00ol0
003oooooooooo`0Booooo`;o0000YOooool009oooooo0_l00007ooooo`;o00000_ooool00ol0003o
ooooooooo`0Aooooo`?o0000YOooool008[ooooo0_l00008ooooo`;o00005_ooool00ol0003ooooo
ooooo`0Aooooo`;o0000Y_ooool008Wooooo00Gok^k^o`000?l0003o<S8bonk^kP05ooooo`03ob4Q
8Ol0003o000000Gooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Go
oooo00?o0000ooooooooool07Oooool2o`0009[ooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo01gooooo0_l0002Jooooo`00ROooool01Ol@413ooooooooooooooooo410@00go
oooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_o
oooo0ol0002Kooooo`00ROooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qoooooooo
ool01_ooool00omgMgOo<S8booooo`04ooooo`?o00006oooool3o`0009_ooooo0029ooooo`03o`00
0?oooooo000000;o00003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`2iooooo`00ROooool01Ol@413oooooo`000?l0003o410@00ko
oooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01[o
oooo0_l0002Mooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo0_l000000ooooooo
410@ooooo`02ooooo`03oc8b<_oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Jooooo`;o0000WOooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`;o
000000?oooooo`000?l000000ol00004ooooo`Co00001_ooool00ol0003oooooooooo`0Iooooo`;o
0000W_ooool00:cooooo00?o0000ooooooooool06Oooool2o`0009kooooo002/ooooo`03o`000?oo
oooooooo00Wooooo0_l0002^ooooo`00S?ooool2o`0001kooooo00?o0000ooooooooool02Oooool3
o`0000_ooooo0_l0002Pooooo`00S?ooool2o`0001kooooo0ol0000:ooooo`;o00002oooool2o`00
0:3ooooo002/ooooo`?o0000^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00WOooool4o`0000_ooooo00?o0000ooooooooool0^Oooool009Kooooo0_l00005ooooo`Co0000
2oooool00ol0003oooooooooo`2iooooo`00U_ooool2o`0000Wooooo0_l00009ooooo`?o00000_oo
ool2o`0000Wooooo0_l0002Zooooo`00U_ooool2o`0000Wooooo0_l00009ooooo`03o`000?oooooo
oooo00;ooooo0_l00009ooooo`;o0000Z_ooool00:cooooo00?o0000ooooooooool00_ooool2o`00
00Wooooo0_l0002Zooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00V_ooool2o`00013ooooo00?o0000ooooooooool0^Oooool009[ooooo0ol0000?
ooooo`03o`000?oooooooooo0;Wooooo002Kooooo`;o00003oooool00ol0003oooooooooo`2ioooo
o`00SOooool2o`0000kooooo0_l0000:ooooo`Co0000^oooool008gooooo0_l0000>ooooo`;o0000
2_ooool6o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Xooooo`;o00000_ooool0
0ol0003oooooooooo`2iooooo`00Z?ooool2o`0000;ooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o
0000ooooooooool0^Oooool00:cooooo00Co0000oooooooooooooooo0_l0000;ooooo`;o0000ZOoo
ool00:cooooo0ol000000ooooooo0000o`00000;ooooo`;o0000ZOooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00[?oo
ool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Rooooo`Co000000?o410@oooo
ooooool00oooool00ol0003oooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`02o`0000?o
oooo00?o0000ooooooooool0^Oooool00:3ooooo0_l00002ooooo`03o`000?oooooooooo00;o0000
0oooool3o`000;Wooooo002Pooooo`;o00000_ooool00ol0003oooooooooo`31ooooo`00Y?ooool0
0ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003o
ooooooooo`31ooooo`00X_ooool00omEEEGoIVIVo`000033ooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Z_ooool01?l@413o0000o`000?l0002jooooo`00
Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool0
1_l0003oMgMgo`000?l0003oEEEEonk^k[Oooooo002[ooooo`06o`000?mEEEGok^k^oooooomgMgOo
EEEE]oooool00:_ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`2eooooo`00Zooo
ool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo0;Gooooo002[ooooo`06o`000?mEEEGo
k^k^oooooomgMgOoIVIV]oooool00:[ooooo00?o410@o`000?mgMgL00_l000000omVIVKok^k^oooo
o`2fooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.41411 .79001 Mdot
.58803 .23866 Mdot
.49982 .42127 Mdot
.4404 .29999 Mdot
.41585 .67481 Mdot
.63347 .45841 Mdot
.50607 .6073 Mdot
.72748 .45049 Mdot
.44837 .04258 Mdot
.51103 .26848 Mdot
.55388 .6221 Mdot
.72825 .53792 Mdot
.59962 .76464 Mdot
.56787 .53455 Mdot
.72442 .5086 Mdot
.54342 .61832 Mdot
.61057 .4558 Mdot
.58472 .79273 Mdot
.5644 .37604 Mdot
.66647 .34522 Mdot
.60156 .7555 Mdot
.64855 .40089 Mdot
.65366 .44086 Mdot
.56377 .82662 Mdot
.68115 .72473 Mdot
.57216 .66906 Mdot
.50266 .75845 Mdot
.53453 .29276 Mdot
.68124 .40208 Mdot
.58354 .23324 Mdot
.57783 .79593 Mdot
.4731 .0249 Mdot
.68633 .30888 Mdot
.57825 .69342 Mdot
.39488 .59073 Mdot
.50682 .08533 Mdot
.5973 .81897 Mdot
.4309 .28138 Mdot
.6825 .42495 Mdot
.7215 .60938 Mdot
.66148 .77284 Mdot
.47525 .86479 Mdot
.51778 .16719 Mdot
.38741 .4022 Mdot
.4624 .89413 Mdot
.53568 .25892 Mdot
.55745 .40983 Mdot
.37774 .31447 Mdot
.40329 .37025 Mdot
.65969 .33584 Mdot
.37117 .41916 Mdot
.68608 .59125 Mdot
.63364 .88504 Mdot
.41399 .24909 Mdot
.47245 .12453 Mdot
.5852 .1381 Mdot
.72738 .45723 Mdot
.61286 .47083 Mdot
.42871 .91882 Mdot
.49991 .88094 Mdot
.55354 .29938 Mdot
.37857 .2232 Mdot
.68085 .42195 Mdot
.50398 .29858 Mdot
.6473 .23611 Mdot
.54601 .0878 Mdot
.48045 .22554 Mdot
.55481 .49199 Mdot
.45963 .21059 Mdot
.52959 .87563 Mdot
.60388 .62129 Mdot
.50722 .37634 Mdot
.50594 .25981 Mdot
.4179 .40424 Mdot
.68059 .42066 Mdot
.44263 .47754 Mdot
.6332 .8856 Mdot
.57998 .38529 Mdot
.69175 .54114 Mdot
.46285 .83136 Mdot
.39985 .76632 Mdot
.56322 .1998 Mdot
.42041 .54984 Mdot
.44392 .83928 Mdot
.69556 .32674 Mdot
.51025 .72305 Mdot
.40639 .58375 Mdot
.40706 .41055 Mdot
.60615 .41374 Mdot
.55481 .5052 Mdot
.67949 .727 Mdot
.76375 .44434 Mdot
.54066 .58503 Mdot
.46634 .17986 Mdot
.54585 .47777 Mdot
.75716 .40137 Mdot
.56858 .50652 Mdot
.37035 .51752 Mdot
.60506 .92231 Mdot
.6146 .46594 Mdot
.38823 .59299 Mdot
.58155 .32334 Mdot
.72718 .50745 Mdot
.40703 .23329 Mdot
.42703 .87293 Mdot
.55611 .74623 Mdot
.59281 .65979 Mdot
.58163 .49235 Mdot
.53893 .59546 Mdot
.5325 .87057 Mdot
.55996 .41418 Mdot
.44079 .29688 Mdot
.4536 .03564 Mdot
.5877 .1885 Mdot
.37828 .15065 Mdot
.50449 .66585 Mdot
.57262 .35398 Mdot
.62216 .18504 Mdot
.56941 .11399 Mdot
.63267 .74963 Mdot
.607 .74839 Mdot
.36432 .62542 Mdot
.65057 .60017 Mdot
.68773 .43241 Mdot
.52533 .88098 Mdot
.47321 .24645 Mdot
.61017 .22654 Mdot
.72792 .31022 Mdot
.42673 .1626 Mdot
.42766 .47084 Mdot
.65825 .46799 Mdot
.39438 .32579 Mdot
.7208 .59904 Mdot
.6372 .5166 Mdot
.57672 .26761 Mdot
.69387 .51169 Mdot
.59815 .82198 Mdot
.65601 .3217 Mdot
.49275 .23667 Mdot
.70168 .35445 Mdot
.72462 .54105 Mdot
.44071 .69865 Mdot
.5201 .25934 Mdot
.61161 .4643 Mdot
.63747 .27499 Mdot
.67135 .27079 Mdot
.55419 .00103 Mdot
.5751 .4431 Mdot
.42948 .25475 Mdot
.37203 .72486 Mdot
.56992 .29335 Mdot
.40943 .46482 Mdot
.54805 .85147 Mdot
.48782 .32301 Mdot
.62905 .58315 Mdot
.64682 .72567 Mdot
.68944 .48315 Mdot
.60624 .1635 Mdot
.60499 .8048 Mdot
.63693 .74858 Mdot
.48013 .84 Mdot
.69132 .55869 Mdot
.64208 .81434 Mdot
.41158 .17246 Mdot
.4782 .12838 Mdot
.41145 .77549 Mdot
.65818 .24593 Mdot
.38763 .68587 Mdot
.43822 .25356 Mdot
.63223 .7614 Mdot
.60854 .22819 Mdot
.54106 .57014 Mdot
.41004 .53121 Mdot
.41707 .67956 Mdot
.57896 .53918 Mdot
.67712 .29153 Mdot
.7487 .36974 Mdot
.63203 .55595 Mdot
.52711 .55218 Mdot
.67996 .40271 Mdot
.66065 .69611 Mdot
.70658 .66714 Mdot
.42856 .67473 Mdot
.64676 .80008 Mdot
.52131 .379 Mdot
.41098 .12708 Mdot
.71739 .2881 Mdot
.48952 .02685 Mdot
.65916 .78349 Mdot
.56189 .23781 Mdot
.40905 .91381 Mdot
.63978 .27935 Mdot
.42976 .38223 Mdot
.36119 .51093 Mdot
.71289 .38043 Mdot
.56375 .92239 Mdot
.72646 .54968 Mdot
.43059 .24848 Mdot
.76653 .58274 Mdot
.52495 .81124 Mdot
.50419 .34589 Mdot
.51327 .37767 Mdot
.51863 .43433 Mdot
.4508 .79431 Mdot
.75735 .63158 Mdot
.38662 .54697 Mdot
.50428 .68544 Mdot
.63573 .51229 Mdot
.4507 .26763 Mdot
.53093 .58947 Mdot
.53784 .67966 Mdot
.64974 .62915 Mdot
.57512 .36598 Mdot
.38671 .67679 Mdot
.48611 .76238 Mdot
.40309 .73107 Mdot
.55028 .29665 Mdot
.63974 .81745 Mdot
.53475 .44785 Mdot
.5658 .77391 Mdot
.7276 .57361 Mdot
.56802 .33903 Mdot
.43736 .93321 Mdot
.40032 .77461 Mdot
.38105 .58944 Mdot
.54029 .62612 Mdot
.51073 .77263 Mdot
.57671 .21639 Mdot
.54116 .57387 Mdot
.72462 .51806 Mdot
.36166 .42059 Mdot
.55606 .49078 Mdot
.43984 .45179 Mdot
.75864 .61713 Mdot
.45192 .16992 Mdot
.48911 .78154 Mdot
.38641 .81875 Mdot
.41508 .37976 Mdot
.43927 .12686 Mdot
.6463 .62938 Mdot
.38816 .40373 Mdot
.3741 .25906 Mdot
.61842 .37449 Mdot
.39376 .25759 Mdot
.60473 .61731 Mdot
.50709 .04328 Mdot
.53348 .39341 Mdot
.66872 .65893 Mdot
.53994 .23955 Mdot
.6071 .60608 Mdot
.68514 .44448 Mdot
.58844 .89005 Mdot
.51149 .64208 Mdot
.42393 .46069 Mdot
.65633 .69472 Mdot
.57743 .64709 Mdot
.41543 .61727 Mdot
.54391 .20312 Mdot
.44964 .40488 Mdot
.71832 .40926 Mdot
.37336 .62163 Mdot
.42616 .23123 Mdot
.48999 .78067 Mdot
.38066 .41091 Mdot
.45133 .68314 Mdot
.54556 .24449 Mdot
.47786 .89422 Mdot
.56128 .43611 Mdot
.59632 .31623 Mdot
.55205 .14246 Mdot
.54748 .72803 Mdot
.56291 .1547 Mdot
.50996 .15349 Mdot
.51942 .28544 Mdot
.40245 .60464 Mdot
.64776 .72471 Mdot
.41527 .55824 Mdot
.54842 .69123 Mdot
.37894 .30485 Mdot
.53974 .67593 Mdot
.63163 .56983 Mdot
.68936 .45665 Mdot
.46292 .28707 Mdot
.43303 .69179 Mdot
.6106 .79417 Mdot
.72664 .48034 Mdot
.58191 .51867 Mdot
.43564 .45561 Mdot
.55231 .67053 Mdot
.54966 .13311 Mdot
.47087 .1793 Mdot
.44007 .89712 Mdot
.71328 .28029 Mdot
.4723 .96432 Mdot
.7224 .4613 Mdot
.48904 .95809 Mdot
.51307 .43753 Mdot
.47245 .96667 Mdot
.3868 .81604 Mdot
.49519 .06734 Mdot
.72384 .48751 Mdot
.63373 .08439 Mdot
.41108 .68634 Mdot
.59982 .31428 Mdot
.41144 .21546 Mdot
.49515 .0319 Mdot
.68183 .72657 Mdot
.56614 .47502 Mdot
.37251 .39435 Mdot
.56278 .69291 Mdot
.44122 .37296 Mdot
.65561 .59517 Mdot
.61366 .50676 Mdot
.62594 .70237 Mdot
.39625 .87014 Mdot
.49235 .6958 Mdot
.54029 .81809 Mdot
.53529 .78748 Mdot
.66852 .27725 Mdot
.43297 .60272 Mdot
.70415 .67334 Mdot
.52138 .96617 Mdot
.59075 .09244 Mdot
.5361 .36665 Mdot
.63659 .54769 Mdot
.4245 .79083 Mdot
.68842 .48606 Mdot
.482 .81339 Mdot
.50116 .33404 Mdot
.51695 .51498 Mdot
.60546 .6079 Mdot
.73116 .52624 Mdot
.66683 .65999 Mdot
.54623 .47945 Mdot
.66218 .53004 Mdot
.43676 .36861 Mdot
.51914 .43877 Mdot
.58304 .22762 Mdot
.63127 .43746 Mdot
.48276 .12948 Mdot
.48322 .83843 Mdot
.47752 .81197 Mdot
.66751 .83743 Mdot
.57348 .65797 Mdot
.51024 .12523 Mdot
.49643 .28271 Mdot
.6436 .22512 Mdot
.5241 .71119 Mdot
.64299 .291 Mdot
.59256 .25343 Mdot
.48963 .74084 Mdot
.48195 .18243 Mdot
.72898 .53824 Mdot
.46224 .96474 Mdot
.53772 .1226 Mdot
.42371 .75306 Mdot
.5548 .75476 Mdot
.6026 .21707 Mdot
.50449 .17651 Mdot
.72899 .53203 Mdot
.63048 .13989 Mdot
.40461 .19635 Mdot
.72271 .58441 Mdot
.69956 .68677 Mdot
.63347 .82537 Mdot
.51909 .5693 Mdot
.41786 .26907 Mdot
.72426 .53985 Mdot
.72305 .43045 Mdot
.51162 .61249 Mdot
.48513 .92346 Mdot
.58308 .61594 Mdot
.63533 .54496 Mdot
.3945 .67074 Mdot
.37385 .37549 Mdot
.43096 .14571 Mdot
.54864 .89096 Mdot
.6846 .57338 Mdot
.64845 .41139 Mdot
.49627 .95786 Mdot
.65372 .43432 Mdot
.70091 .67137 Mdot
.60676 .79864 Mdot
.61774 .64277 Mdot
.45323 .34587 Mdot
.57971 .89712 Mdot
.60504 .40513 Mdot
.51658 .48151 Mdot
.69737 .69681 Mdot
.52174 .88619 Mdot
.4999 .3296 Mdot
.43176 .30655 Mdot
.59616 .54062 Mdot
.46405 .78513 Mdot
.39582 .18436 Mdot
.37837 .55837 Mdot
.3652 .62828 Mdot
.70193 .68182 Mdot
.60039 .62332 Mdot
.70308 .77316 Mdot
.57901 .69677 Mdot
.57977 .52917 Mdot
.56318 .64095 Mdot
.48292 .65624 Mdot
.73022 .49499 Mdot
.72852 .52647 Mdot
.50864 .74641 Mdot
.51381 .68578 Mdot
.43509 .734 Mdot
.46928 .76942 Mdot
.45933 .18455 Mdot
.41942 .14351 Mdot
.43471 .67305 Mdot
.41006 .44824 Mdot
.43022 .57448 Mdot
.41374 .33383 Mdot
.59277 .64847 Mdot
.42795 .7036 Mdot
.48494 .7229 Mdot
.36803 .68088 Mdot
.7011 .35179 Mdot
.46099 .60735 Mdot
.39272 .45362 Mdot
.59311 .65857 Mdot
.61619 .64105 Mdot
.56974 .66595 Mdot
.41394 .39022 Mdot
.55777 .92604 Mdot
.77014 .47667 Mdot
.45248 .10742 Mdot
.35864 .68518 Mdot
.40557 .23898 Mdot
.43889 .66494 Mdot
.46255 .03179 Mdot
.72303 .55448 Mdot
.55079 .6326 Mdot
.58485 .24013 Mdot
.65949 .84913 Mdot
.50251 .71434 Mdot
.45621 .31754 Mdot
.57401 .58223 Mdot
.38103 .3999 Mdot
.49345 .82519 Mdot
.77 .5211 Mdot
.53665 .47673 Mdot
.39315 .53616 Mdot
.47149 .86572 Mdot
.53994 .42087 Mdot
.50768 .65265 Mdot
.4164 .41958 Mdot
.727 .44884 Mdot
.45143 .68593 Mdot
.69307 .51841 Mdot
.54957 .17524 Mdot
.49433 .88603 Mdot
.58884 .19195 Mdot
.49107 .91858 Mdot
.60959 .57405 Mdot
.73818 .33187 Mdot
.44636 .25723 Mdot
.73081 .53879 Mdot
.5839 .89678 Mdot
.55954 .42681 Mdot
.46558 .96565 Mdot
.55987 .69607 Mdot
.59089 .3624 Mdot
.64145 .28705 Mdot
.38618 .54599 Mdot
.57098 .40586 Mdot
.49067 .1881 Mdot
.57487 .70382 Mdot
.39648 .12286 Mdot
.55414 .2268 Mdot
.44206 .49014 Mdot
.46834 .12862 Mdot
.44173 .80276 Mdot
.51959 .56838 Mdot
.53965 .3825 Mdot
.40923 .27422 Mdot
.57823 .26894 Mdot
.52991 .51114 Mdot
.59166 .57606 Mdot
.55106 .09384 Mdot
.41789 .68898 Mdot
.51552 .8554 Mdot
.51234 .24261 Mdot
.5132 .24994 Mdot
.46761 .69177 Mdot
.36892 .2092 Mdot
.45816 .6794 Mdot
.58545 .23295 Mdot
.45303 .95207 Mdot
.42919 .11683 Mdot
.48299 .20373 Mdot
.66743 .35494 Mdot
.71806 .62145 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o00003_ooool2o`000:Wooooo002Tooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool03_ooool2o`000:Wooooo002Tooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo002Roooo
o`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:?ooooo0_l00007ooooo`?o0000^Ooo
ool00:?ooooo0_l00003ooooo`;o00000_ooool00ol0003oooooooooo`2iooooo`00Woooool2o`00
00Oooooo1Ol0002kooooo`00Woooool2o`0000Wooooo0ol0002kooooo`00W?ooool2o`0000kooooo
00?o0000ooooooooool0^Oooool009cooooo0_l0000>ooooo`03o`000?oooooooooo0;Wooooo002K
ooooo`;o00003oooool01?l0003oooooo`000?l0002hooooo`00Voooool2o`0000oooooo00Co0000
ooooool0003o0000^?ooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00Z_ooool3o`00
0;_ooooo002Zooooo`?o0000^oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0
002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool01?l0003oooooo`000?l0000Xooooo`;o0000S_ooool00:cooooo00Co0000ooooool0
003o00002oooool2o`0001_ooooo0_l0002>ooooo`00[?ooool00ol0003oooooooooo`0<ooooo`;o
00003Oooool2o`0009cooooo002/ooooo`03o`000?oooooooooo00gooooo0_l0000<ooooo`;o0000
W?ooool00:cooooo00?o0000ooooooooool03Oooool2o`000:[ooooo002/ooooo`?o0000^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool009cooooo0_l0000>ooooo`03o`000?oooooooooo0;Wo
oooo002Looooo`;o00003_ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`0Cooooo`;o0000Y?ooool008Wooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`03ob4Q8Ol0003o000000Gooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool04oooool2o`000:Cooooo0029
ooooo`;o000000?ooooooiRHV?mgMgL01Oooool00olQ8B7o0000o`000005ooooo`03oeEEEOnYZJWo
oooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`09ooooo`;o0000[_ooool0
087ooooo1_l00002ooooo`;o00000_ooool00ol@413oooooooooo`0;ooooo`03ojVYZOmEEEGooooo
00Cooooo0_l00002ooooo`03o`000?oooooooooo00?ooooo1Ol00007ooooo`;o0000[_ooool008Wo
oooo00Co0000oooooooooooooooo0ol00008ooooo`;o00000_ooool00olQ8B7oooooooooo`02oooo
o`Go000000?o<S8booooooooool00oooool00ol0003oooooooooo`02o`000;Oooooo0029ooooo`04
o`000?ooooooooooooooo`?o00002?ooool2o`0000;ooooo00?oEEEEolc<c?ooool00_ooool2o`00
0003ob4Q8Ol0003o000000;o00001?ooool00ol0003oooooooooo`2iooooo`00ROooool01Ol@413o
oooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool01?l0003oooooooooooooool2
o`0000Cooooo00?o0000ooooooooool03Oooool2o`000:[ooooo0029ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0=ooooo`;o0000Z_ooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool06Oooool2o`0000gooooo0_l0
002?ooooo`00TOooool2o`0001Wooooo00?o0000ooooooooool03_ooool2o`0000Wooooo0_l0000=
ooooo`;o0000Soooool0097ooooo0_l00002ooooo`;o00005Oooool00ol0003oooooooooo`0>oooo
o`;o0000ZOooool009Gooooo0_l0000Eooooo`03o`000?oooooooooo0;Wooooo0023ooooo`;o0000
9oooool3o`000;Wooooo0023ooooo`;o00009oooool00ol0003oooooooooo`02o`0000oooooo0_l0
002Vooooo`00[?ooool00ol0003oooooooooo`02o`0000oooooo0_l0002Vooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00Toooool2o`0001Oooooo00?o0000ooooooooool08?ooool2o`0009Oo
oooo002Cooooo`;o00005oooool00ol0003oooooooooo`02ooooo`;o00007?ooool2o`0009Oooooo
002Looooo`;o00003_ooool00ol0003oooooooooo`02ooooo`;o0000]Oooool008kooooo0_l0000<
ooooo`;o00003_ooool00ol0003oooooooooo`2iooooo`00S_ooool2o`0001cooooo0ol0000=oooo
o`;o0000Z_ooool00:3ooooo1?l00008ooooo`?o00003Oooool2o`000:[ooooo002Pooooo`Co0000
0_ooool2o`0000Cooooo00?o0000ooooooooool0^Oooool008Wooooo0_l0000Cooooo`;o00001_oo
ool2o`0000Cooooo00?o0000ooooooooool09Oooool2o`0009;ooooo0029ooooo`;o00004oooool2
o`0000Sooooo0_l00002ooooo`03o`000?oooooooooo01[ooooo0_l00009ooooo`;o0000T_ooool0
0:Sooooo0_l00002ooooo`03o`000?oooooooooo01[ooooo0_l0002Mooooo`00[?ooool00ol0003o
ooooooooo`0Jooooo`;o0000WOooool008cooooo0_l0000Nooooo`03o`000?oooooooooo0;Wooooo
002<ooooo`;o00007_ooool3o`00017ooooo0_l0002Vooooo`00Y_ooool2o`0000Cooooo00?o0000
ooooooooool02oooool2o`0000Cooooo0_l0002Vooooo`00Y_ooool2o`0000Cooooo00?o0000oooo
ooooool02oooool2o`000:cooooo0020ooooo`;o00007?ooool2o`0000cooooo00?o0000oooooooo
ool0^Oooool0083ooooo0_l0000Looooo`;o00003?ooool00ol0003oooooooooo`2iooooo`00S_oo
ool2o`0001cooooo00?o0000ooooooooool05_ooool2o`000:7ooooo002>ooooo`;o00007?ooool0
0ol0003oooooooooo`0Fooooo`;o00001_ooool2o`0009Wooooo002/ooooo`03o`000?oooooooooo
01kooooo0_l0002Iooooo`00Poooool2o`00023ooooo0_l00005ooooo`?o0000;?ooool2o`0008_o
oooo0023ooooo`;o00008?ooool2o`0000Gooooo00?o0000ooooooooool03_ooool2o`0000Sooooo
0_l00006ooooo`?o00002Oooool2o`0008_ooooo002Cooooo`;o00005oooool00ol0003ooooooooo
o`0>ooooo`;o00002?ooool2o`0000Kooooo0ol0002Fooooo`00SOooool2o`0000Cooooo0_l0000G
ooooo`03o`000?oooooooooo01Sooooo0ol0002Nooooo`00SOooool2o`0001[ooooo0_l000000ooo
oooo0000ooooo`0Booooo`;o00001Oooool3o`0001;ooooo0_l0002:ooooo`00S?ooool2o`0001_o
oooo0_l000000ooooooo0000ooooo`0;ooooo`;o00001Oooool2o`0000Kooooo0ol0000Aooooo`;o
0000R_ooool008cooooo0_l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Go
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`04o`000?ooooooooooooooo`;o00001oooool2
o`0000gooooo0ol0002Mooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46
ooooo`;o000000?oMgMgoc8b<_ooool01?ooool01?l0003oooooooooooooool2o`0000Wooooo0_l0
000Sooooo`;o0000Q_ooool008Wooooo2?l000001?l@413oooooooooooooool2o`0000cooooo0_l0
00000ooooooo0000ooooo`04ooooo`04o`000?ooooooooooooooo`;o00002Oooool2o`0002?ooooo
0_l00026ooooo`00Soooool3o`0000?ooooo0_l0000>ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0
00000ooooooo0000o`00002fooooo`00TOooool00ol0003oooooooooo`02o`000003ooooool0003o
000000Wooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo01_ooooo0_l0
002Looooo`00P_ooool2o`0000Cooooo0_l00007ooooo`03oa0@4?oooooooooo00;o000000Cooooo
o`000?l0003ooooo0_l00006ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool2o`00017ooooo0_l0002Looooo`00P_ooool2o`0000Cooooo0_l00007ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01?ooool2o`0000Kooooo00?o0000ooooooooool01oooool01?l0003oooooo`00
0?l00002ooooo`;o00000oooool2o`000:oooooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool4o`0000Kooooo00Co0000ooooool0003o00000_ooool2o`000;Cooooo002Kooooo`;o0000
3oooool00ol0003oooooooooo`0Fooooo`;o0000XOooool0093ooooo0_l00009ooooo`;o00003ooo
ool00ol0003oooooooooo`02o`0001Cooooo0_l0000Mooooo`;o0000P_ooool008kooooo1?l0000J
ooooo`03o`000?oooooooooo00;o00005?ooool2o`0001gooooo0_l00022ooooo`00S_ooool2o`00
01cooooo0ol0000Zooooo`;o00002?ooool2o`0008?ooooo002/ooooo`03o`000?oooooooooo02[o
oooo0ol00007ooooo`;o00003Oooool2o`0007Cooooo002Eooooo`;o00004oooool3o`0002gooooo
0_l0000Fooooo`;o0000M?ooool009Gooooo0_l0000Cooooo`?o00001Oooool2o`000;Cooooo002O
ooooo`;o00002oooool00ol0003oooooooooo`03ooooo`;o00009_ooool2o`0001Oooooo0_l0001c
ooooo`00Woooool2o`0000_ooooo00?o0000ooooooooool0:oooool3o`0000Wooooo0_l0000;oooo
o`;o0000Loooool00:cooooo00?o0000ooooooooool02?ooool2o`0000[ooooo0_l0000Fooooo`;o
00002Oooool2o`00083ooooo002Hooooo`;o00004_ooool00ol0003oooooooooo`08ooooo`;o0000
0oooool2o`0000Gooooo0_l0002Sooooo`00V?ooool2o`0001;ooooo0ol0000=ooooo`?o0000ZOoo
ool009Sooooo0_l0000Booooo`?o00003_ooool2o`000:Wooooo0024ooooo`;o00003oooool2o`00
01Gooooo00?o0000ooooooooool0^Oooool008Cooooo0_l0000?ooooo`;o00005Oooool00ol0003o
ooooooooo`0jooooo`;o00003?ooool2o`0006oooooo002/ooooo`03o`000?oooooooooo03[ooooo
0_l0000<ooooo`;o0000Koooool008?ooooo0_l0000Wooooo`03o`000?oooooooooo01cooooo1?l0
002Iooooo`00Poooool2o`0001Sooooo0_l0000=ooooo`03o`000?oooooooooo01cooooo1?l0002I
ooooo`00WOooool2o`0000gooooo00?o0000ooooooooool0<?ooool2o`0008Oooooo0029ooooo`;o
00007Oooool2o`0000;ooooo0ol0000Gooooo`;o00005oooool2o`0008Oooooo0029ooooo`;o0000
7Oooool2o`0000;ooooo00?o0000ooooooooool05oooool2o`0002Cooooo0_l0001jooooo`00[?oo
ool2o`0003kooooo0_l0000<ooooo`;o0000K?ooool008oooooo0_l0000Kooooo`;o0000C?ooool2
o`0006cooooo002?ooooo`;o00006oooool2o`0003;ooooo0_l00026ooooo`00[?ooool00ol0003o
ooooooooo`0Cooooo`;o00007?ooool2o`0008Kooooo002/ooooo`03o`000?oooooooooo01?ooooo
0_l0002Tooooo`00W?ooool2o`0000kooooo0ol0000dooooo`;o0000Poooool009cooooo0_l0000>
ooooo`?o0000=?ooool2o`0008?ooooo002/ooooo`?o0000?oooool2o`0007Sooooo002/ooooo`03
o`000?oooooooooo01Gooooo0_l0000Mooooo`;o00002Oooool2o`0007Sooooo002/ooooo`03o`00
0?oooooooooo01Gooooo0_l0000Mooooo`;o00002Oooool2o`0007Sooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo01_ooooo0_l0002Looooo`00ROooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool02?ooool2o`0000_ooooo0_l00004ooooo`;o0000W?oo
ool008Wooooo00?oMgMgoiRHV?ooool00_l00005ooooo`;o8B4Q0_ooool2o`000005oiRHV?lQ8B7o
k^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00Sooooo0_l0
000;ooooo`;o0000>?ooool2o`0006Sooooo0021ooooo`Ko00000_ooool00ol@413oooooooooo`02
o`0000Wooooo0ol000000onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0Coooool2o`0006Sooooo0022ooooo`;o00001Oooool01Ol0003ooooooooooooooooo
000000[ooooo0_l000001?ooooooV9RHob4Q8Oo^k^h7ooooo`03ogMgMolb<S;ooooo00Cooooo1?l0
000Aooooo`;o00004?ooool2o`0009?ooooo0022ooooo`;o00001Oooool01Ol0003ooooooooooooo
oooo000000;ooooo0_l0000:ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`03o`000?oooooo000000?o000000?oooooo`000?l000003?ooool2o`00013ooooo
0_l0002Cooooo`00ROooool01Ol@413ooooooooooooooooo410@00;ooooo0_l00002ooooo`;o0000
1oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo
oooo0_l000000ooooooo0000o`000004ooooo`;o0000=oooool2o`0007Cooooo0029ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool2o`0000?ooooo00Go0000okZj^_ooooooV9RHoa0@4004oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool2o`0000_ooooo0_l0000Zoooo
o`;o0000M?ooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool05oooool2o`000:3ooooo002?oooo
o`;o00006oooool00ol0003oooooooooo`2iooooo`00POooool2o`0000cooooo0_l0000Kooooo`03
o`000?oooooooooo00Sooooo0_l0002_ooooo`00POooool2o`0002Wooooo00?o0000ooooooooool0
2?ooool2o`000:oooooo0024ooooo`;o00009_ooool3o`0002kooooo0_l0000Qooooo`;o0000I_oo
ool008Cooooo1Ol00007ooooo`;o00006_ooool00ol0003oooooooooo`0^ooooo`;o00002?ooool2
o`0001Oooooo0_l0001Vooooo`00Q_ooool3o`0000Oooooo0_l00009ooooo`;o00003oooool00ol0
003oooooooooo`0Dooooo`;o00002Oooool2o`0001Oooooo0_l0001oooooo`00SOooool2o`0000co
oooo0_l0000?ooooo`03o`000?oooooooooo013ooooo0_l00002ooooo`;o00002Oooool2o`0002Co
oooo0_l0001booooo`00Q?ooool2o`0000Oooooo0_l0000Mooooo`03o`000?oooooooooo013ooooo
0_l0000Looooo`;o00005Oooool2o`0007;ooooo0024ooooo`;o00009_ooool00ol0003ooooooooo
o`0@ooooo`;o00003_ooool2o`0000cooooo0_l00029ooooo`00POooool2o`0000gooooo0_l0000J
ooooo`03o`000?oooooooooo013ooooo0_l0000>ooooo`;o0000Uoooool007kooooo0_l000000ooo
oooo0000o`00000=ooooo`;o00006_ooool2o`0000_ooooo0_l0000/ooooo`;o0000Ooooool007ko
oooo0_l0000/ooooo`?o00002_ooool2o`0002cooooo0ol0001nooooo`00[?ooool00ol0003ooooo
ooooo`0@ooooo`;o00009oooool2o`0007kooooo002/ooooo`03o`000?oooooooooo013ooooo0_l0
000dooooo`;o0000LOooool00:cooooo00?o0000ooooooooool00oooool2o`0002[ooooo0_l0000:
ooooo`;o00002Oooool2o`00077ooooo002/ooooo`04o`000?ooooooooooooooo`Co00003?ooool2
o`0001Gooooo0_l00005ooooo`;o00002_ooool2o`0007cooooo002/ooooo`04o`000?oooooooooo
ooooo`Co00003?ooool2o`0001Gooooo0_l00005ooooo`;o0000R?ooool00:cooooo00?o0000oooo
ooooool00oooool2o`00013ooooo0_l0000Hooooo`;o0000R?ooool00:cooooo00?o0000oooooooo
ool05Oooool2o`0002?ooooo0_l0000Hooooo`;o0000Hoooool008kooooo0_l0000Looooo`03o`00
0?oooooooooo00Sooooo0_l0000`ooooo`;o00002oooool2o`0000_ooooo0_l0001Sooooo`00S_oo
ool2o`0000Sooooo0_l0000Booooo`?o00002?ooool2o`0003gooooo0ol0001_ooooo`00R?ooool2
o`0000cooooo1?l0000Booooo`03o`000?oooooooooo027ooooo0_l0000Uooooo`;o0000Koooool0
08Sooooo0_l0000<ooooo`;o00005?ooool00ol0003oooooooooo`0Qooooo`;o00001_ooool2o`00
013ooooo0_l0000;ooooo`;o0000Koooool000Wooooo1?l000000ol@413oooooooooo`0Fooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Ooo
ool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Fooooo`03o`000?oooooooooo
01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`;o00002?ooool00oo^k^ko0000o`000002o`0000Gooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hoooo
o`Co000000?o410@ooooooooool04_ooool000_ooooo00?o0000ooooooooool06?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b
<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01_nHV9So8B4Qonk^
k_ooooooA4A4ooooo`;o00000_ooool2o`000003ogMgMolb<S;ooooo01Gooooo00?o0000oooooooo
ool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo0_l000000olQ8B7oooooooooo`02oooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`0>ooooo`05ogMgMol0003o
0000oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool0
6Oooool00ol0003oooooooooo`0Dooooo`001_l00005ooooo`03o`000?oooooooooo013ooooo1_l0
0002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`00
0?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003o
ooooooooo`05ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q
8Oo^k^h00_ooool2o`0000Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Hoooo
o`05oa0@4?ooooooooooooooool@41001?ooool3o`0000Gooooo00?oV9RHob4Q8Oo^k^h01Oooool2
o`0000;ooooo00?o0000ooooooooool03Oooool01Ol@413ooooooooooooooooo410@013ooooo00?o
0000ooooooooool03Oooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool0
2?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oo
oooooooo01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo
00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_oo
ool03_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool2o`00
01Kooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000Gooooo0_l00006
ooooo`03oiRHV?lQ8B7ok^k^00Cooooo0_l000000oooooooMgMgoc8b<P0?ooooo`05o`000?oooooo
ooooooooool000003oooool00omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool00000
3_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Wooooo00?o0000ooooooooool0
5?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000kooooo
00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000oooooooo
ooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooo
oooo000000kooooo00?oMgMgofIVI_ooool00oooool00ol0003o8B4Qo`000002o`0001Kooooo00?o
0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000Gooooo0_l00007ooooo`03ogMg
MomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?oooooooooooooo
ool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00
000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Jooooo`03o`00
0?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go410@oooooooooooooooo
oa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool04Oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@
00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Hooooo`?o00002Oooool2o`00
00Oooooo0_l00004ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400<ooooo`;o00004_oo
ool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003o
ooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aoooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o
0000ooooooooool01Oooool2o`00017ooooo00?o0000ooooooooool02Oooool2o`000003ooooool0
003o000000Cooooo0_l00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zj
oooooonHV9So410@00Cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo0_l0000Booooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooo
oooo<S8b00Cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Dooooo`002Oooool0
0omEEEGoIVIVo`00000Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0
000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Cooooo0_l0000Aoooo
o`03o`000?oooooooooo00;ooooo0_l00008ooooo`;o00002_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`0000Sooooo00Go
k^k^oc8b<_l0003o0000onk^kP0<ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo1Ol00004ooooo`Co00006Oooool00omEEEGoIVIVo`00000Fooooo`00[?ooool00ol0003ooooo
ooooo`02ooooo`;o0000=oooool2o`0000[ooooo0_l0001`ooooo`00[?ooool00ol0003ooooooooo
o`0kooooo`;o00002Oooool2o`00077ooooo002Hooooo`;o00004_ooool00ol0003oooooooooo`0?
ooooo`;o00001oooool2o`0002cooooo0_l0001Vooooo`;o00000_ooool2o`0000Gooooo002Hoooo
o`;o00004_ooool00ol0003oooooooooo`0?ooooo`;o00001oooool2o`0002oooooo0_l0001Soooo
o`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1Oooool00:cooooo00?o0000ooooooooool0BOooool2
o`0006Cooooo00CogMgMo`000?l@413oc<c<1_ooool000Ooooooool0001<o`0000cooooo00Cok^k^
ob4Q8Ol@413ok^k^1_ooool000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:
ooooo`04ob4Q8OmgMgOoMgMgoc8b<PKooooo0007ooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool03oooool2o`0000;ooooo0_l0000=ooooo`;o00000oooool00ol0003oooooooooo`0N
ooooo`;o00001_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool02Oooool2o`0000;ooooo0_l00005ooooo`00[?ooool00ol0003oooooooooo`0?oooo
o`;o00000_ooool2o`0000gooooo0_l0000Sooooo`?o0000Koooool007kooooo0_l0000/ooooo`03
o`000?oooooooooo00Kooooo0_l0000Qooooo`;o00004_ooool2o`0000Sooooo0_l0001`ooooo`00
O_ooool2o`0002cooooo00?o0000ooooooooool00_ooool2o`0000;ooooo0_l0000Qooooo`?o0000
4Oooool2o`0007[ooooo0021ooooo`;o0000:Oooool00ol0003oooooooooo`02ooooo`;o00005?oo
ool2o`00013ooooo0_l0000@ooooo`;o00002Oooool2o`00073ooooo0021ooooo`;o0000:Oooool0
0ol0003oooooooooo`0Hooooo`;o00008_ooool2o`0000Wooooo0_l0000=ooooo`;o0000HOooool0
0:cooooo0ol0001Fooooo`;o0000HOooool00:cooooo00?o0000ooooooooool0B?ooool3o`0006ko
oooo002>ooooo`;o00007?ooool00ol0003oooooooooo`0Gooooo`;o00006Oooool2o`0001Cooooo
0ol0001^ooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool04oooool2o`0000;ooooo0_l0
000Iooooo`;o00005?ooool2o`0006oooooo0028ooooo`;o00008_ooool00ol0003oooooooooo`0C
ooooo`;o0000<oooool2o`0006oooooo0028ooooo`;o00008_ooool00ol0003oooooooooo`0Goooo
o`;o00000oooool2o`0002Wooooo1?l0001^ooooo`00[?ooool00ol0003oooooooooo`0Gooooo`;o
00000oooool2o`0001kooooo0_l00009ooooo`Co0000K_ooool008Kooooo0_l0000Tooooo`03o`00
0?oooooooooo02Wooooo0_l0000Aooooo`;o00002Oooool2o`00073ooooo0026ooooo`;o00002Ooo
ool2o`0001Wooooo00?o0000ooooooooool0:Oooool3o`0001_ooooo0_l0001`ooooo`00Q_ooool2
o`0000Wooooo0_l0000Iooooo`?o00001_ooool2o`0002;ooooo0_l0000Kooooo`;o0000L?ooool0
0:cooooo00?o0000ooooooooool01_ooool2o`00023ooooo0_l0000Looooo`;o0000LOooool008?o
oooo0_l0000;ooooo`;o00006_ooool00ol0003oooooooooo`0Xooooo`;o00004_ooool2o`0000So
oooo0_l0001aooooo`00Poooool2o`0000_ooooo0_l0000Jooooo`03o`000?oooooooooo03cooooo
0_l0001kooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`03ooooo`;o00001Oooool2o`0001cooooo0_l0002?oooo
o`00[?ooool00ol0003oooooooooo`03ooooo`;o00001Oooool2o`0001Gooooo0_l00005ooooo`;o
00004?ooool2o`0000cooooo0_l0001_ooooo`00UOooool2o`0001Gooooo0ol0000:ooooo`;o0000
3oooool2o`0000Cooooo0_l0000Gooooo`;o00003?ooool2o`0006oooooo002Eooooo`;o00005Ooo
ool00ol0003oooooooooo`0Kooooo`;o0000W?ooool00:cooooo00?o0000ooooooooool05Oooool2
o`00013ooooo0_l0000/ooooo`;o0000H_ooool008gooooo0_l0000Mooooo`03o`000?oooooooooo
00[ooooo0_l00009ooooo`;o00004?ooool2o`0001gooooo0_l0000=ooooo`;o0000H_ooool008go
oooo0_l0000Mooooo`03o`000?oooooooooo00[ooooo0_l0000jooooo`;o0000LOooool008Cooooo
0_l00003ooooo`;o00008Oooool00ol0003oooooooooo`07ooooo`;o0000<Oooool2o`0007gooooo
0024ooooo`;o000000?oooooo`000?l000000_l0000Qooooo`03o`000?oooooooooo00Oooooo0_l0
000Wooooo`;o00002?ooool2o`0007gooooo0027ooooo`;o00008oooool00ol0003oooooooooo`09
ooooo`;o00009Oooool2o`0008Oooooo002/ooooo`?o00002Oooool2o`0002?ooooo0_l0000Eoooo
o`;o0000L_ooool009Gooooo0_l0000Eooooo`03o`000?oooooooooo02kooooo0_l0000Eooooo`;o
0000L_ooool008_ooooo0_l00008ooooo`;o00002?ooool2o`0000_ooooo00Co0000ooooool0003o
00007oooool2o`0009Oooooo002;ooooo`;o00004_ooool2o`0000_ooooo00Co0000ooooool0003o
00007_ooool3o`0002Cooooo0_l0001aooooo`00[?ooool00ol0003oooooooooo`02o`0001gooooo
0_l0000Uooooo`;o0000LOooool00:cooooo00?o0000ooooooooool00_l0000Fooooo`;o0000Wooo
ool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`;o000000?oooooob4Q8OlQ8B401?oo
ool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00_ooooo
0_l0000;ooooo`;o00001Oooool2o`00037ooooo0_l0001Uooooo`00P_ooool2o`0000Gooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`02ooooo`;o000000?oooooob4Q8OlQ8B401?ooool01OnHV9So8B4Q
onk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0;ooooo`;o
000000?oooooo`000?l000003oooool2o`0002Cooooo0_l0000;ooooo`;o0000IOooool007oooooo
0_l000000ooooooo0000o`000005ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0000>ooooo`;o00003_ooool3o`0002Co
oooo0_l0001booooo`00Ooooool2o`0000Sooooo00Go0000ooooooooooooooooo`00000=ooooo`03
oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0:ooooo`;o
00004_ooool2o`0009Wooooo001oooooo`;o00002?ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool02_ooool2o`00027ooooo0ol0000Rooooo`;o0000IOooool008Wooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0=ooooo`;o00007_ooool3o`0002;ooooo0_l0001Uooooo`00ROooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool03Oooool2o`000:[ooooo0029ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00;o00003oooool2o`00013ooooo0_l0002D
ooooo`00[?ooool00ol0003oooooooooo`02o`0000oooooo0_l0000@ooooo`;o0000U?ooool00:co
oooo00?o0000ooooooooool05_ooool2o`0000?ooooo0_l0002Looooo`00[?ooool4o`0001Gooooo
0_l00003ooooo`;o0000W?ooool00:cooooo00Co0000ooooool0003o0000^?ooool00:Kooooo0_l0
0004ooooo`03o`000?oooooooooo01Gooooo0_l00004ooooo`;o00005oooool2o`0008?ooooo002V
ooooo`;o00001?ooool00ol0003oooooooooo`0Eooooo`;o00001?ooool2o`0001Oooooo0_l00023
ooooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool06oooool2o`0001Oooooo0_l00023oooo
o`00Uoooool2o`0001?ooooo0ol0000Dooooo`;o0000:oooool2o`0007Kooooo0029ooooo`;o0000
8Oooool3o`0000kooooo0_l00004ooooo`;o0000:oooool2o`0007Kooooo0029ooooo`;o00002ooo
ool2o`0001Cooooo00?o0000ooooooooool03_ooool2o`0000Cooooo0_l0000Yooooo`?o0000Mooo
ool008Kooooo0_l00008ooooo`;o00000_ooool4o`0001Cooooo0ol0000:ooooo`;o0000<oooool3
o`0007Oooooo0026ooooo`;o00002?ooool2o`0000;ooooo0_l00008ooooo`;o00003?ooool00ol0
003oooooooooo`09ooooo`?o0000[Oooool0083ooooo0_l0000>ooooo`;o00002Oooool2o`000003
ooooool0003o000000cooooo00?o0000ooooooooool02Oooool2o`0003Cooooo0_l0001hooooo`00
OOooool2o`000003ooooool0003o000000Cooooo0_l0000Cooooo`?o00003_ooool3o`000003oooo
ool0003o000003cooooo0_l0001hooooo`00OOooool2o`0000Oooooo0_l00006ooooo`Co00002_oo
ool2o`0000kooooo0ol000000ooooooo0000o`00000kooooo`;o0000NOooool008kooooo1?l00003
ooooo`;o00002_ooool2o`0000Wooooo00?o0000ooooooooool03Oooool2o`0002oooooo0_l0001i
ooooo`00UOooool2o`0000[ooooo0_l00009ooooo`03o`000?oooooooooo00gooooo0_l00002oooo
o`;o00000oooool2o`0001Sooooo0_l00027ooooo`00ZOooool2o`000003ooooool0003ooooo017o
oooo0ol00003ooooo`?o00005oooool4o`0000[ooooo0_l0001iooooo`00V?ooool2o`0000oooooo
0_l000001?oooooo0000o`000?l0000@ooooo`;o00001Oooool2o`0001Wooooo0_l0000:ooooo`;o
0000NOooool009Cooooo0_l00002ooooo`;o00004_ooool00ol0003oooooooooo`0Eooooo`;o0000
3oooool2o`00097ooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`0Eooooo`;o00003ooo
ool2o`00097ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
00Gooooo0_l0002booooo`00[?ooool2o`0000Kooooo0_l0002booooo`00[?ooool2o`000;[ooooo
002/ooooo`03o`000?oooooooooo0;Wooooo0021ooooo`;o00009?ooool2o`0000?ooooo1Ol0000[
ooooo`;o00002Oooool2o`0007oooooo0021ooooo`;o00009?ooool2o`0000?ooooo00?o0000oooo
ooooool00_l0000:ooooo`;o00007oooool2o`0000Wooooo0ol0001nooooo`00S?ooool2o`0001ko
oooo00?o0000ooooooooool03?ooool2o`0002[ooooo0ol0001nooooo`00S?ooool2o`0000Sooooo
0_l0000Dooooo`03o`000?oooooooooo0;Wooooo002Fooooo`;o00005?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B45ooooo`06odA4A?l0003o0000oc8b<_oMgMgooooo0_l00002ooooo`03o`00
0?oooooooooo0;Wooooo002Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool00_l00002ooooo`04o`000?oooooo0000o`0000kooooo0_l0002Xooooo`00
TOooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool01?l0003o
ooooo`000?l0000>ooooo`;o00003oooool2o`0000Kooooo1?l0002=ooooo`00TOooool01Ol0003o
oooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool3o`00023ooooo0_l00006oooo
o`Co0000SOooool0097ooooo0ol000000ooooooo0000ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`0?ooooo`;o00003Oooool2o`0009Wooooo002Aooooo`05
oa0@4?l0003o0000ooooool@41003?ooool00ol0003oooooooooo`07ooooo`;o00004?ooool2o`00
00gooooo0_l0002Iooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool01oooool2o`0002Wooooo0_l0002?ooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo1?l000000ooooooo0000o`000003ooooo`03o`000?oooooooooo01gooooo0_l00009oooo
o`;o0000Soooool008_ooooo0_l0000Jooooo`;o00000oooool00ol0003oooooooooo`0Mooooo`;o
0000V_ooool008_ooooo0_l0000Dooooo`;o00002Oooool00ol0003oooooooooo`2iooooo`00XOoo
ool2o`0000Wooooo00?o0000ooooooooool00_l0000@ooooo`;o00007_ooool2o`0000cooooo0_l0
001gooooo`00Roooool2o`000003ooooool0003o000001cooooo1Ol0000@ooooo`;o00007_ooool2
o`0000cooooo0_l0001gooooo`00Roooool2o`000003ooooool0003o000001cooooo00?o0000oooo
ooooool0^Oooool00:Sooooo0_l00002ooooo`03o`000?oooooooooo0;Wooooo002Pooooo`;o0000
1_ooool2o`0000;ooooo00?o0000ooooooooool0<Oooool2o`0008Kooooo002Pooooo`;o00002_oo
ool00ol0003oooooooooo`08ooooo`;o00009oooool2o`0008Kooooo002?ooooo`;o00000_ooool2
o`0001Oooooo00?o0000ooooooooool02?ooool2o`000:oooooo002?ooooo`;o00000_ooool2o`00
00Kooooo0_l0000?ooooo`03o`000?oooooooooo01Wooooo0_l00006ooooo`;o0000U_ooool009_o
oooo0_l0000?ooooo`03o`000?oooooooooo01Kooooo0_l000000ooooooo0000o`000006ooooo`;o
0000U_ooool00:cooooo0ol0000Fooooo`;o00002?ooool2o`0000_ooooo0_l0002:ooooo`00V?oo
ool2o`0001;ooooo00?o0000ooooooooool08?ooool2o`0000_ooooo0_l0002:ooooo`00V?ooool2
o`0001;ooooo00?o0000ooooooooool07oooool2o`0009Sooooo002/ooooo`03o`000?oooooooooo
01oooooo0_l0002Hooooo`00Y?ooool4o`0000Cooooo00?o0000ooooooooool01Oooool2o`000;;o
oooo0026ooooo`;o00007?ooool4o`0000Cooooo00?o0000ooooooooool01Oooool2o`0002Cooooo
0_l0002<ooooo`00Q_ooool2o`0002Cooooo00?o0000ooooooooool02_ooool2o`00017ooooo0_l0
000<ooooo`;o0000S?ooool008Kooooo0_l0000Tooooo`03o`000?oooooooooo00[ooooo0_l0000A
ooooo`;o00003?ooool2o`0008cooooo002Yooooo`;o000000Coooooo`000?l0003o00007Oooool2
o`0000[ooooo0_l0002>ooooo`00ZOooool2o`000003ooooool0003ooooo01?ooooo0_l0000Eoooo
o`;o0000S_ooool009oooooo0_l0000;ooooo`03o`000?oooooooooo01;ooooo0_l0002Uooooo`00
Woooool2o`0000_ooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0=?oo
ool2o`0008?ooooo002Iooooo`;o00002_ooool3o`0000Cooooo00?o0000ooooooooool0=?ooool2
o`0008?ooooo002Iooooo`;o00002_ooool3o`0000Cooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0<Oooool2o`0008Kooooo
002/ooooo`?o00003?ooool2o`0002?ooooo0_l00026ooooo`00[?ooool00ol0003oooooooooo`02
ooooo`;o00002?ooool2o`000:_ooooo002/ooooo`03o`000?oooooooooo00;ooooo0_l0002eoooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00Xoooool2o`0000Oooooo00?o0000ooooooooool0
^Oooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^
ooooo`04ooooo`?o000000?o<S8bomgMgOooool01?ooool00ol0003oooooooooo`2iooooo`00ROoo
ool2o`000003oooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Cooooo0_l0
00000oooooooMgMgoc8b<P05ooooo`03o`000?oooooooooo00Oooooo0_l0002`ooooo`00ROooool2
o`0000;ooooo00?o410@ooooooooool00oooool2o`0000Kooooo00?oZJVYoeEEEOooool02?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo0_l0002`ooooo`00ROooool01Ol0
003ooooooooooooooooo000000Gooooo0_l00007ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMg
oc8b<_ooool01?ooool3o`0000Kooooo0_l0002aooooo`00ROooool01Ol0003ooooooooooooooooo
000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool01_ooool2o`000;7ooooo0029ooooo`05oa0@4?ooooooooooooooool@41003_oo
ool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo0_l00006ooooo`;o0000/_oo
ool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S80
1?ooool00ol0003oooooooooo`05ooooo`Co00001Oooool3o`0002;ooooo0_l0002>ooooo`00ROoo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001?ooool3o`0000Kooooo
0_l0000Sooooo`;o0000S_ooool00:cooooo00?o0000ooooooooool03Oooool2o`0000_ooooo0_l0
002Mooooo`00Woooool2o`0000?ooooo0_l00006ooooo`03o`000?oooooooooo00gooooo0_l0000;
ooooo`;o0000WOooool009Sooooo0_l00005ooooo`;o00000oooool2o`0000Kooooo00?o0000oooo
ooooool05oooool3o`0009oooooo002Hooooo`;o00004_ooool3o`0001Oooooo0ol0002Oooooo`00
[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00S_ooool2o`0001co
oooo00?o0000ooooooooool0^Oooool008kooooo0_l00004ooooo`;o00004oooool2o`000003oooo
ool0003ooooo0;[ooooo002Dooooo`;o00004oooool2o`000003ooooool0003ooooo01?ooooo0_l0
000;ooooo`;o0000V?ooool00:Oooooo0_l00003ooooo`?o00004_ooool2o`0000_ooooo0_l0002H
ooooo`00Yoooool2o`0000?ooooo00?o0000ooooooooool04?ooool2o`000:Oooooo002/ooooo`03
o`000?oooooooooo013ooooo0_l0002Wooooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool0
^Oooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002Looooo`;o00003_ooool3o`000;Wooooo002L
ooooo`;o00003_ooool00ol0003oooooooooo`2iooooo`00Z?ooool5o`000;_ooooo002Xooooo`Go
0000^oooool009oooooo0_l000000ooooooo0000o`000008ooooo`03o`000?oooooooooo0;Wooooo
002Oooooo`Go00002?ooool00ol0003oooooooooo`04ooooo`;o0000/oooool00:3ooooo1?l00008
ooooo`03o`000?oooooooooo00Cooooo0_l0002cooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Rooooo`Co000000?o410@ooooooooool0
0oooool00ol0003oooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0;Wooooo002Tooooo`03o`000?oooooooooo00Gooooo0ol0002iooooo`00Y?ooool00ol0
003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003ooooo
ooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00X_ooool00omEEEGoIVIVo`000033
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Z_ooool0
1?l@413o0000o`000?l0002jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0
003oooooooooo`2jooooo`00Zoooool01_l0003oMgMgo`000?l0003oEEEEonk^k[Oooooo002[oooo
o`06o`000?mEEEGok^k^oooooomgMgOoEEEE]oooool00:_ooooo00?o0000onk^k_ooool00_ooool0
0ol0003oooooooooo`2eooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo
0;Gooooo002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoIVIV]oooool00:[ooooo00?o410@o`00
0?mgMgL00_l000000omVIVKok^k^ooooo`2fooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.557 .79793 Mdot
.44659 .10925 Mdot
.45244 .40867 Mdot
.43882 .69433 Mdot
.52686 .74734 Mdot
.57683 .25841 Mdot
.509 .4073 Mdot
.66768 .25049 Mdot
.3809 .71524 Mdot
.41779 .39204 Mdot
.56272 .4221 Mdot
.70342 .33792 Mdot
.66547 .56464 Mdot
.54169 .33455 Mdot
.68786 .3086 Mdot
.55075 .41832 Mdot
.55289 .2558 Mdot
.66182 .59273 Mdot
.47537 .19625 Mdot
.56456 .14522 Mdot
.66376 .5555 Mdot
.56891 .20089 Mdot
.59001 .24086 Mdot
.65442 .62662 Mdot
.73105 .52473 Mdot
.59979 .46906 Mdot
.56604 .55845 Mdot
.42826 .28483 Mdot
.60208 .20208 Mdot
.44109 .12024 Mdot
.6562 .59593 Mdot
.37169 .61109 Mdot
.56989 .10888 Mdot
.61562 .49342 Mdot
.51219 .83456 Mdot
.37783 .45056 Mdot
.68489 .61897 Mdot
.43681 .73983 Mdot
.61248 .22495 Mdot
.72525 .40938 Mdot
.73061 .57284 Mdot
.58755 .68172 Mdot
.39514 .38393 Mdot
.4726 .90357 Mdot
.5932 .72983 Mdot
.41995 .28622 Mdot
.48166 .22216 Mdot
.45554 .9648 Mdot
.46219 .84116 Mdot
.55403 .13584 Mdot
.47981 .97082 Mdot
.68258 .39125 Mdot
.74766 .68504 Mdot
.43342 .82067 Mdot
.39358 .59237 Mdot
.4119 .11394 Mdot
.67027 .25723 Mdot
.5612 .27083 Mdot
.59557 .83194 Mdot
.61229 .68095 Mdot
.44043 .21298 Mdot
.43543 .9809 Mdot
.60963 .22195 Mdot
.42493 .41688 Mdot
.50175 .03611 Mdot
.38057 .2762 Mdot
.4139 .53556 Mdot
.51161 .29199 Mdot
.41515 .62974 Mdot
.63984 .67563 Mdot
.61239 .42129 Mdot
.4419 .38552 Mdot
.41619 .4166 Mdot
.46645 .77005 Mdot
.60885 .22066 Mdot
.4771 .6462 Mdot
.74744 .6856 Mdot
.4941 .18641 Mdot
.6682 .34114 Mdot
.57041 .67274 Mdot
.55293 .84418 Mdot
.4168 .1868 Mdot
.49769 .72756 Mdot
.57027 .7273 Mdot
.58625 .12674 Mdot
.55947 .52305 Mdot
.50815 .78373 Mdot
.47017 .81601 Mdot
.53164 .21374 Mdot
.51689 .3052 Mdot
.73029 .527 Mdot
.70149 .24434 Mdot
.53467 .38503 Mdot
.40698 .60708 Mdot
.49696 .27819 Mdot
.67771 .20137 Mdot
.53119 .30652 Mdot
.50146 .9532 Mdot
.73399 .72231 Mdot
.56098 .26594 Mdot
.51414 .86411 Mdot
.47151 .14643 Mdot
.69016 .30745 Mdot
.43148 .85449 Mdot
.58066 .80319 Mdot
.6146 .54623 Mdot
.61673 .45979 Mdot
.53857 .29235 Mdot
.53712 .39546 Mdot
.64073 .67057 Mdot
.48576 .22159 Mdot
.43806 .69331 Mdot
.37826 .69391 Mdot
.42947 .10531 Mdot
.41966 .99789 Mdot
.53083 .46585 Mdot
.47473 .17375 Mdot
.45729 .02294 Mdot
.39596 .17447 Mdot
.69253 .54963 Mdot
.66636 .54839 Mdot
.52659 .97078 Mdot
.65064 .40017 Mdot
.6207 .23241 Mdot
.63773 .68098 Mdot
.42004 .56267 Mdot
.46174 .05962 Mdot
.61201 .11022 Mdot
.41178 .78375 Mdot
.47887 .713 Mdot
.60544 .26799 Mdot
.45441 .88971 Mdot
.72042 .39904 Mdot
.60385 .3166 Mdot
.44728 .14242 Mdot
.65855 .31169 Mdot
.68695 .62198 Mdot
.54469 .1217 Mdot
.41367 .47948 Mdot
.60346 .15445 Mdot
.70104 .34105 Mdot
.36051 .53976 Mdot
.52804 .64981 Mdot
.41624 .35354 Mdot
.55733 .2643 Mdot
.50747 .07499 Mdot
.53966 .07079 Mdot
.36155 .25864 Mdot
.51234 .2431 Mdot
.43131 .75182 Mdot
.54803 .94954 Mdot
.45057 .16356 Mdot
.48151 .79391 Mdot
.64864 .65147 Mdot
.43359 .4823 Mdot
.62231 .38315 Mdot
.69709 .52567 Mdot
.6427 .28315 Mdot
.43564 .05169 Mdot
.68691 .6048 Mdot
.69636 .54858 Mdot
.5806 .65176 Mdot
.67479 .35869 Mdot
.72782 .61434 Mdot
.41722 .84777 Mdot
.39318 .56642 Mdot
.55341 .80124 Mdot
.51655 .04593 Mdot
.53545 .8732 Mdot
.42916 .71393 Mdot
.69679 .5614 Mdot
.46085 .06306 Mdot
.52911 .37014 Mdot
.49587 .77687 Mdot
.52775 .74312 Mdot
.55464 .33918 Mdot
.55373 .09153 Mdot
.65659 .16974 Mdot
.6144 .35595 Mdot
.50798 .35218 Mdot
.60104 .20271 Mdot
.6991 .49611 Mdot
.73344 .46714 Mdot
.52422 .69218 Mdot
.72679 .60008 Mdot
.44551 .32375 Mdot
.40744 .86022 Mdot
.59263 .0881 Mdot
.36857 .53897 Mdot
.73255 .58349 Mdot
.42715 .18801 Mdot
.59383 .88975 Mdot
.51152 .07935 Mdot
.45908 .72299 Mdot
.50201 .99462 Mdot
.62506 .18043 Mdot
.6927 .72239 Mdot
.70633 .34968 Mdot
.4297 .74834 Mdot
.75962 .38274 Mdot
.60944 .61124 Mdot
.43529 .40568 Mdot
.44285 .35838 Mdot
.45917 .32554 Mdot
.55586 .67312 Mdot
.76998 .43158 Mdot
.50438 .87624 Mdot
.53846 .48544 Mdot
.60065 .31229 Mdot
.42953 .65638 Mdot
.52672 .38947 Mdot
.5697 .47966 Mdot
.6614 .42915 Mdot
.48172 .17645 Mdot
.53351 .8757 Mdot
.55393 .56989 Mdot
.54328 .81784 Mdot
.43751 .22427 Mdot
.72672 .61745 Mdot
.47499 .27645 Mdot
.63536 .57391 Mdot
.71704 .37361 Mdot
.465 .17685 Mdot
.60129 .81971 Mdot
.55501 .84562 Mdot
.51492 .89636 Mdot
.55074 .42612 Mdot
.57979 .57263 Mdot
.43044 .13954 Mdot
.53071 .37387 Mdot
.69184 .31806 Mdot
.51237 .29078 Mdot
.47208 .66396 Mdot
.76549 .41713 Mdot
.40793 .67221 Mdot
.56338 .58582 Mdot
.56907 .92072 Mdot
.46171 .78765 Mdot
.40127 .73673 Mdot
.65805 .42938 Mdot
.47277 .89999 Mdot
.44423 .99269 Mdot
.52822 .17449 Mdot
.43965 .90714 Mdot
.61166 .41731 Mdot
.36859 .45849 Mdot
.45601 .27611 Mdot
.69229 .45893 Mdot
.41654 .27212 Mdot
.60953 .40608 Mdot
.62294 .24448 Mdot
.70446 .69005 Mdot
.52832 .44208 Mdot
.47747 .73149 Mdot
.69422 .49472 Mdot
.59626 .44709 Mdot
.51362 .74207 Mdot
.40864 .26234 Mdot
.45972 .63131 Mdot
.64202 .20926 Mdot
.52377 .93026 Mdot
.42689 .7714 Mdot
.56366 .5843 Mdot
.47596 .93117 Mdot
.52216 .60043 Mdot
.4202 .24844 Mdot
.60033 .70676 Mdot
.49573 .23681 Mdot
.48294 .12406 Mdot
.39606 .23973 Mdot
.59869 .52803 Mdot
.40397 .19383 Mdot
.39241 .42181 Mdot
.42221 .35095 Mdot
.51363 .80013 Mdot
.69765 .52471 Mdot
.50063 .7482 Mdot
.58491 .49123 Mdot
.45318 .96162 Mdot
.57011 .47593 Mdot
.61956 .36983 Mdot
.63202 .25665 Mdot
.43113 .59881 Mdot
.52761 .6786 Mdot
.68827 .59417 Mdot
.67877 .28034 Mdot
.54938 .31867 Mdot
.47382 .68145 Mdot
.58052 .47053 Mdot
.39284 .25149 Mdot
.40588 .58742 Mdot
.58931 .78336 Mdot
.5854 .08029 Mdot
.62433 .7809 Mdot
.66692 .2613 Mdot
.63331 .76072 Mdot
.45751 .34719 Mdot
.62533 .783 Mdot
.56828 .91794 Mdot
.37618 .50543 Mdot
.67884 .28751 Mdot
.53063 .77074 Mdot
.48561 .11978 Mdot
.42663 .83908 Mdot
.36845 .51328 Mdot
.73246 .52657 Mdot
.51614 .27502 Mdot
.47411 .97036 Mdot
.59994 .49291 Mdot
.45457 .67497 Mdot
.65368 .39517 Mdot
.57637 .30676 Mdot
.66689 .50237 Mdot
.58188 .90824 Mdot
.53186 .49888 Mdot
.62753 .61809 Mdot
.61028 .58748 Mdot
.53942 .07725 Mdot
.50655 .66379 Mdot
.73348 .47334 Mdot
.66785 .76617 Mdot
.40167 .09775 Mdot
.4496 .26873 Mdot
.61567 .34769 Mdot
.55593 .75914 Mdot
.64284 .28606 Mdot
.57135 .62388 Mdot
.43313 .42169 Mdot
.48354 .33203 Mdot
.60862 .4079 Mdot
.70165 .32624 Mdot
.69082 .45999 Mdot
.49801 .27963 Mdot
.63419 .33004 Mdot
.45459 .6954 Mdot
.4607 .32309 Mdot
.43882 .12113 Mdot
.56625 .23746 Mdot
.39243 .54627 Mdot
.58182 .64686 Mdot
.56847 .62838 Mdot
.76248 .63743 Mdot
.59667 .45797 Mdot
.38617 .42674 Mdot
.42293 .45344 Mdot
.49366 .02597 Mdot
.56858 .51119 Mdot
.51939 .091 Mdot
.4557 .102 Mdot
.54772 .54539 Mdot
.40417 .53837 Mdot
.36054 .54544 Mdot
.70427 .33824 Mdot
.61954 .7953 Mdot
.38707 .30505 Mdot
.54542 .74232 Mdot
.61671 .55476 Mdot
.45142 .071 Mdot
.39814 .44112 Mdot
.7018 .33203 Mdot
.42394 .87301 Mdot
.71647 .38441 Mdot
.73427 .48677 Mdot
.72362 .62537 Mdot
.50681 .3693 Mdot
.43695 .79943 Mdot
.7002 .33985 Mdot
.65523 .23045 Mdot
.51661 .41249 Mdot
.61656 .72873 Mdot
.58946 .41594 Mdot
.61332 .34496 Mdot
.53042 .84035 Mdot
.4697 .96859 Mdot
.40718 .76894 Mdot
.66503 .69096 Mdot
.67395 .37338 Mdot
.573 .21139 Mdot
.63954 .75816 Mdot
.58745 .23432 Mdot
.72946 .47137 Mdot
.36209 .73983 Mdot
.68621 .59864 Mdot
.63485 .44277 Mdot
.44606 .62839 Mdot
.69856 .69712 Mdot
.52709 .20513 Mdot
.47191 .32902 Mdot
.73609 .49681 Mdot
.63621 .68619 Mdot
.43241 .42816 Mdot
.44212 .73067 Mdot
.5724 .34062 Mdot
.55424 .63022 Mdot
.42322 .91399 Mdot
.50866 .9111 Mdot
.52705 .96695 Mdot
.73466 .48182 Mdot
.60971 .42332 Mdot
.77235 .57316 Mdot
.61772 .49677 Mdot
.55144 .32917 Mdot
.57956 .44095 Mdot
.5126 .47616 Mdot
.68821 .29499 Mdot
.69911 .32647 Mdot
.56721 .54641 Mdot
.54812 .48578 Mdot
.53852 .68864 Mdot
.54979 .60465 Mdot
.64408 .8176 Mdot
.40952 .63666 Mdot
.4092 .81981 Mdot
.52257 .66536 Mdot
.47775 .79475 Mdot
.50095 .67946 Mdot
.45198 .80341 Mdot
.61216 .44847 Mdot
.53159 .70405 Mdot
.53804 .53337 Mdot
.53847 .95889 Mdot
.60182 .15179 Mdot
.50147 .53843 Mdot
.48267 .86928 Mdot
.61654 .45857 Mdot
.63261 .44105 Mdot
.59612 .46595 Mdot
.46424 .79036 Mdot
.68819 .72604 Mdot
.72081 .27667 Mdot
.39417 .68328 Mdot
.43304 .85961 Mdot
.51973 .64509 Mdot
.37548 .65567 Mdot
.70482 .35448 Mdot
.56383 .4326 Mdot
.44448 .11757 Mdot
.75915 .64913 Mdot
.54825 .51434 Mdot
.43923 .62151 Mdot
.5669 .38223 Mdot
.47348 .93195 Mdot
.58405 .62652 Mdot
.73844 .3211 Mdot
.48749 .28419 Mdot
.5006 .84956 Mdot
.58613 .68807 Mdot
.46989 .2588 Mdot
.52874 .45265 Mdot
.47012 .77327 Mdot
.66653 .24884 Mdot
.5229 .60135 Mdot
.66043 .31841 Mdot
.40358 .244 Mdot
.60907 .68687 Mdot
.43146 .10211 Mdot
.61926 .7205 Mdot
.59921 .37405 Mdot
.63093 .13187 Mdot
.4282 .67756 Mdot
.70632 .33879 Mdot
.70261 .69678 Mdot
.49031 .23035 Mdot
.62138 .79106 Mdot
.5983 .49607 Mdot
.49585 .16292 Mdot
.51628 .08705 Mdot
.50426 .87835 Mdot
.49334 .20739 Mdot
.40352 .49906 Mdot
.6164 .50382 Mdot
.40965 .92444 Mdot
.41954 .21759 Mdot
.47997 .64595 Mdot
.39536 .60942 Mdot
.55841 .70713 Mdot
.50694 .36838 Mdot
.45686 .25634 Mdot
.43994 .83601 Mdot
.44897 .13866 Mdot
.49439 .31286 Mdot
.58208 .37606 Mdot
.38345 .25325 Mdot
.52988 .74201 Mdot
.61768 .6554 Mdot
.412 .39178 Mdot
.41364 .38635 Mdot
.52318 .5468 Mdot
.52016 .57213 Mdot
.44252 .11507 Mdot
.61144 .80012 Mdot
.40126 .78291 Mdot
.40859 .52922 Mdot
.5694 .15494 Mdot
.72664 .42145 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002Mooooo`;o00003Oooool3o`000;Wooooo002Mooooo`;o00002_ooool2
o`000003ooooool0003ooooo0;[ooooo002Yooooo`;o000000?oooooo`000?ooool0^_ooool00:co
oooo00?o0000ooooooooool0^Oooool00:cooooo0_l0002jooooo`00[?ooool2o`000;[ooooo002/
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00;ooooo0_l0002eoooo
o`00[?ooool00ol0003oooooooooo`02ooooo`;o0000]Oooool009Kooooo0_l0000Dooooo`?o0000
^Oooool009Kooooo0_l0000Dooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002Oooooo`;o00002oooool00ol0003oooooooooo`2iooooo`00Woooool2o`0000_o
oooo00?o0000ooooooooool0^Oooool009oooooo0_l0000;ooooo`03o`000?oooooooooo0;Wooooo
002Looooo`;o00003_ooool00ol0003oooooooooo`0:ooooo`;o0000[Oooool009cooooo0_l0000>
ooooo`03o`000?oooooooooo00[ooooo0_l0002]ooooo`00[?ooool4o`0000Wooooo0_l0002]oooo
o`00[?ooool00ol0003oooooo`000002o`0000Sooooo0_l0000=ooooo`;o0000W_ooool00:cooooo
00?o0000ooooooooool00_l0000Gooooo`;o0000W_ooool00:cooooo00?o0000ooooooooool0^Ooo
ool00:cooooo00?o0000ooooooooool00_ooool2o`0001Oooooo0_l0002Looooo`00[?ooool00ol0
003oooooooooo`02ooooo`?o00002Oooool2o`0000_ooooo0_l0002Looooo`00[?ooool00ol0003o
ooooooooo`03ooooo`;o00002Oooool2o`000:Wooooo002;ooooo`;o00007oooool00ol0003ooooo
ooooo`2iooooo`00Roooool2o`0001oooooo0ol0002iooooo`00UOooool2o`0000Kooooo0_l0000=
ooooo`03o`000?oooooooooo0;Wooooo002Dooooo`?o00001_ooool2o`0000gooooo00?o0000oooo
ooooool0^Oooool009Cooooo0_l00004ooooo`;o00004?ooool00ol0003oooooooooo`0Dooooo`;o
00003?ooool2o`0009Gooooo002Jooooo`;o00004?ooool00ol0003oooooooooo`0Dooooo`;o0000
3?ooool2o`0009Gooooo002>ooooo`;o00002Oooool2o`00017ooooo00?o0000ooooooooool0^Ooo
ool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02o`0000?ooooo0_lQ8B44ooooo`?o000000?o
k^k^ooooooooool00oooool01Om4A4Co0000o`000?lb<S;ogMgM00;o00000oooool00ol0003ooooo
ooooo`2iooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B42ooooo`Co0000
00?oEEEEojVYZOooool01oooool01?mgMgOo<S8bo`000?l00003ooooo`03o`000?oooooooooo00_o
oooo0_l0002/ooooo`00POooool6o`0000;ooooo00Go410@oooooooooooooooooa0@4009ooooo`?o
000000?oooooojVYZOmEEED02Oooool2o`0000Cooooo0ol0000;ooooo`;o0000[?ooool008Wooooo
00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgo`000?l0
00001?ooool00ol0003oooooooooo`0Iooooo`;o0000W_ooool008Wooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005oooo
o`03o`000?oooooooooo01Wooooo0_l0000=ooooo`;o0000Soooool008Wooooo00Go410@oooooooo
oooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Xooooo`;o0000Soooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00kooooo0_l0002Yooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo0_l00002
ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool03_ooool2o`000:Wooooo002Eoooo
o`;o00000oooool3o`0000oooooo00?o0000ooooooooool0^Oooool009[ooooo0_l00006ooooo`;o
00002?ooool00ol0003oooooooooo`0Booooo`;o0000YOooool00:;ooooo0_l00008ooooo`03o`00
0?oooooooooo01;ooooo0_l0002Uooooo`00[?ooool3o`0001kooooo0_l0002Iooooo`00[?ooool0
0ol0003oooooooooo`0Cooooo`;o00002Oooool3o`0009Sooooo002/ooooo`03o`000?oooooooooo
01?ooooo0_l0000:ooooo`;o0000V?ooool00:cooooo00?o0000ooooooooool0^Oooool009_ooooo
0_l0000=ooooo`?o0000^oooool009_ooooo0_l0000=ooooo`?o0000^oooool00:cooooo00?o0000
ooooooooool0<?ooool2o`0008Oooooo002Sooooo`;o00001oooool00ol0003oooooooooo`0`oooo
o`;o0000Qoooool008Wooooo0_l0000Eooooo`;o000000Coooooo`000?l0003ooooo0_l00004oooo
o`?o00001_ooool2o`000;7ooooo0029ooooo`;o00005Oooool2o`0000Cooooo0_l00004ooooo`03
o`000?oooooooooo00Kooooo0_l0002aooooo`00[?ooool00ol0003oooooooooo`0Vooooo`;o0000
TOooool00:[ooooo0ol0000Xooooo`;o0000TOooool0093ooooo0_l00002ooooo`;o00005?ooool3
o`000;_ooooo002@ooooo`;o00000_ooool2o`0001Kooooo00?o0000ooooooooool0^Oooool008co
oooo0_l0000Nooooo`03o`000?oooooooooo0;Wooooo002<ooooo`;o00005Oooool2o`0000Oooooo
00?o0000ooooooooool0^Oooool00:?ooooo0_l00007ooooo`?o00004oooool2o`0002;ooooo0_l0
0020ooooo`00[?ooool00ol0003oooooooooo`0Cooooo`;o00002Oooool2o`0001Oooooo0_l00020
ooooo`00ZOooool2o`000003ooooool0003ooooo00Oooooo0_l0000Fooooo`;o0000VOooool00:Wo
oooo0_l000000ooooooo0000ooooo`07ooooo`;o00008oooool2o`0008cooooo002Hooooo`;o0000
4_ooool00ol0003oooooooooo`07ooooo`;o00003?ooool2o`0001Cooooo0_l0002<ooooo`00V?oo
ool2o`0001;ooooo00?o0000ooooooooool01oooool2o`0000cooooo0_l0002Rooooo`00TOooool2
o`0001Wooooo00?o0000ooooooooool0^Oooool0097ooooo0_l0000Cooooo`?o00000oooool00ol0
003oooooooooo`0Pooooo`?o0000U_ooool009Oooooo0_l0000=ooooo`?o00000oooool3o`00023o
oooo1?l0002Eooooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool08_ooool2o`0009Gooooo
002Xooooo`;o00000_ooool00ol0003oooooooooo`0`ooooo`;o0000Qoooool00:Sooooo0_l00002
ooooo`03o`000?oooooooooo01Wooooo0_l00009ooooo`;o00002_ooool2o`0008Oooooo002Zoooo
o`?o00005?ooool2o`0000Gooooo0_l00009ooooo`;o0000Toooool008Wooooo0_l0000Oooooo`?o
00005?ooool2o`0000Kooooo0_l0002Mooooo`00ROooool2o`000003ooooool0003o000000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00Co0000oooooooooooooooo0_l0000Gooooo`;o0000WOooool008cooooo0_l00003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool0
1?l0003oooooooooooooool2o`0002;ooooo0_l0000Hooooo`;o0000N?ooool008Wooooo1_l00002
ooooo`;o00000_ooool00ol@413oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool09Oooool2o`0000gooooo0_l00009ooooo`;o0000N?ooool008Sooooo0_l00007oooo
o`;o00000_ooool00ol0003oooooooooo`0=ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000doooo
o`;o0000Poooool008Gooooo0_l000000ooooooo0000o`000007ooooo`05o`000?oooooooooooooo
ool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool03_ooool2
o`0002Cooooo0_l00023ooooo`00O_ooool2o`0000Gooooo0_l0000:ooooo`05oa0@4?oooooooooo
ooooool@41001oooool2o`0000?ooooo0_l00008ooooo`03o`000?oooooooooo00kooooo0_l00006
ooooo`;o00004?ooool2o`0000_ooooo0_l00022ooooo`00O_ooool2o`00017ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`07ooooo`;o00000oooool2o`0000Sooooo00?o0000ooooooooool05_ooool2
o`00013ooooo0_l0000:ooooo`?o0000P_ooool008gooooo0_l00002ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool03oooool2o`0002?ooooo0_l00023
ooooo`00SOooool2o`0001gooooo00?o0000ooooooooool03oooool4o`0000cooooo0_l0002Hoooo
o`00Voooool2o`0000oooooo00?o0000ooooooooool04Oooool2o`0000cooooo0_l0002Hooooo`00
T?ooool2o`0000Wooooo0_l0000?ooooo`03o`000?oooooooooo017ooooo0_l0002Vooooo`00Q?oo
ool2o`0000[ooooo0_l0000;ooooo`;o00001?ooool2o`0000Oooooo0ol00002ooooo`;o0000@Ooo
ool2o`0007;ooooo0024ooooo`;o00005oooool2o`0000Cooooo0_l00006ooooo`;o00001?ooool2
o`0003Cooooo0_l0000;ooooo`;o0000L_ooool00:_ooooo0_l0000^ooooo`;o00002_ooool2o`00
07oooooo002Aooooo`;o000000?oooooo`000?l000004Oooool2o`0000?ooooo00?o0000oooooooo
ool0;?ooool2o`0008_ooooo002Aooooo`;o000000?oooooo`000?l000004Oooool2o`0000?ooooo
00?o0000ooooooooool0;?ooool2o`0000[ooooo0_l0001oooooo`00[?ooool00ol0003ooooooooo
o`03o`0000Kooooo0_l0000]ooooo`;o0000Ooooool00:cooooo00?o0000ooooooooool00ol00006
ooooo`;o0000<?ooool2o`0007cooooo002/ooooo`03o`000?oooooooooo03_ooooo0_l0001loooo
o`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo0026ooooo`;o00009?oo
ool00ol0003oooooooooo`02ooooo`;o00000oooool2o`0000gooooo0_l0000Sooooo`;o0000O?oo
ool008Kooooo0_l0000Tooooo`03o`000?oooooooooo00;ooooo0_l00003ooooo`;o00003Oooool2
o`0002?ooooo0_l0001looooo`00Z_ooool3o`00023ooooo0_l0000Aooooo`;o00002?ooool2o`00
07cooooo002Zooooo`?o00008?ooool3o`00013ooooo0_l00026ooooo`00[?ooool00ol0003ooooo
ooooo`0=ooooo`;o00004?ooool2o`00017ooooo0_l00008ooooo`;o0000Noooool00:cooooo00?o
0000ooooooooool03Oooool2o`0002?ooooo0_l00008ooooo`;o00003Oooool2o`0006cooooo002J
ooooo`;o00000_ooool3o`0000_ooooo0ol0001;ooooo`;o0000K?ooool009[ooooo0_l00002oooo
o`?o00002oooool00ol0003oooooooooo`0nooooo`?o0000N?ooool00:;ooooo0_l00008ooooo`03
o`000?oooooooooo00kooooo0_l0000Iooooo`;o00004oooool3o`0007Sooooo002Rooooo`;o0000
0_ooool2o`0000Cooooo00?o0000ooooooooool02_ooool2o`0000;ooooo0_l0000Iooooo`;o0000
5?ooool2o`0007Sooooo002Vooooo`;o00001?ooool00ol0003oooooooooo`0:ooooo`;o0000<ooo
ool3o`0007Oooooo002/ooooo`03o`000?oooooooooo00oooooo0_l00003ooooo`;o0000:Oooool4
o`0007Kooooo002/ooooo`03o`000?oooooooooo00oooooo0_l00003ooooo`;o00007_ooool2o`00
00Wooooo1?l0001fooooo`00[?ooool00ol0003oooooooooo`0Rooooo`;o00004?ooool2o`0000Wo
oooo0_l0001hooooo`00W_ooool2o`0000cooooo00?o0000ooooooooool08_ooool3o`0001cooooo
0_l0001fooooo`00T_ooool2o`0000[ooooo0_l0000<ooooo`Co00008_ooool2o`0001cooooo0_l0
001fooooo`00T?ooool4o`0001Sooooo00Co0000ooooool0003o00008Oooool2o`0001cooooo0_l0
001gooooo`00T?ooool2o`0000Oooooo0_l0000Aooooo`03o`000?oooooooooo02;ooooo0_l0000B
ooooo`;o00002?ooool2o`0007Oooooo002Iooooo`;o00004Oooool00ol0003oooooooooo`0foooo
o`;o0000POooool00:cooooo00?o0000ooooooooool0^Oooool008Wooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0;Wooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00Co0000
ooooool0003o00001Oooool2o`0001cooooo0_l0002Cooooo`00POooool6o`0000;ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00ooo
ool01?l0003oooooo`000?l00005ooooo`?o00005?ooool2o`0000Gooooo0_l0000@ooooo`;o0000
3?ooool2o`0007?ooooo0029ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Q
onk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00007ooooo`;o00003oooool2o`0000?ooooo
0_l0000Gooooo`;o00003?ooool2o`0007?ooooo0029ooooo`05o`000?ooooooooooooooool00000
3_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003o
ooooooooo`0Hooooo`;o0000Woooool008Wooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`;o
00004?ooool2o`0002_ooooo0_l0001Uooooo`00ROooool2o`000004oooooonHV9SoMgMgooooo`;o
00001oooool2o`000004okZj^_ooooooV9RHoa0@40Cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`08ooooo`;o00002Oooool2o`00013ooooo0_l0000Mooooo`;o00003?ooool2o`00
06Gooooo0029ooooo`?o000000?o<S8bonk^k_ooool00_l00007ooooo`;o000000Co410@o`000?lQ
8B7oc<c<1?ooool4o`0000Kooooo00?o0000ooooooooool02?ooool2o`0003[ooooo0_l0001coooo
o`00Soooool3o`0001[ooooo00?o0000ooooooooool01Oooool2o`0003;ooooo0_l0001nooooo`00
Soooool3o`0001[ooooo00?o0000ooooooooool01Oooool2o`0000;ooooo0_l0000Tooooo`;o0000
2?ooool2o`0007kooooo002/ooooo`03o`000?oooooooooo00Wooooo0_l0000Tooooo`;o0000R?oo
ool00:cooooo0ol0000^ooooo`;o00005Oooool2o`0007;ooooo002/ooooo`03o`000?oooooooooo
02kooooo0_l0000Eooooo`;o0000L_ooool009Kooooo0_l0000Dooooo`03o`000?oooooooooo00;o
00007oooool2o`0009Kooooo002Fooooo`;o00001?ooool2o`0000kooooo00?o0000ooooooooool0
0_l0000Nooooo`?o00009?ooool2o`00073ooooo002Looooo`;o00003_ooool00ol0003ooooooooo
o`02ooooo`;o00007?ooool2o`0002Gooooo0_l0001`ooooo`00T?ooool2o`0001[ooooo00?o0000
ooooooooool00_ooool2o`0001Kooooo0_l0002Mooooo`00T?ooool2o`000003ooooool0003o0000
01Oooooo00?o0000ooooooooool03Oooool2o`0000_ooooo0_l00005ooooo`;o0000<Oooool2o`00
06?ooooo0028ooooo`;o00002Oooool4o`0001Gooooo00?o0000ooooooooool03Oooool2o`0000;o
oooo0_l0000>ooooo`?o00008oooool2o`0000_ooooo0_l0001Sooooo`00R?ooool2o`0000_ooooo
0_l0000Eooooo`?o00004Oooool2o`0000kooooo0ol0000Sooooo`;o0000L?ooool008Kooooo0_l0
000=ooooo`;o00005Oooool00ol0003oooooooooo`0=ooooo`;o00004_ooool2o`0009Kooooo0026
ooooo`;o00003Oooool2o`0001Gooooo00?o0000ooooooooool03Oooool2o`0002;ooooo0ol0000R
ooooo`;o0000HOooool00:cooooo00?o0000ooooooooool04_ooool2o`0001gooooo0ol0000Roooo
o`;o0000HOooool00:cooooo00?o0000ooooooooool04_ooool2o`000:Gooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002:ooooo`;o00008?ooool00ol0003oooooooooo`06ooooo`;o00003ooo
ool2o`0000oooooo0ol0002>ooooo`00R_ooool2o`00023ooooo00?o0000ooooooooool01_ooool2
o`0000oooooo0_l0000?ooooo`?o0000S_ooool00:cooooo00?o0000ooooooooool07?ooool2o`00
00Cooooo0_l0002Eooooo`00Poooool2o`0002Oooooo0ol00006ooooo`;o00005?ooool2o`0000Co
oooo0_l0002Eooooo`00Poooool2o`0000gooooo0_l0000Hooooo`03o`000?oooooooooo00Kooooo
0_l0002aooooo`00P?ooool2o`00013ooooo0_l0000Hooooo`03o`000?oooooooooo01cooooo0_l0
0005ooooo`;o00005oooool2o`0007_ooooo0009ooooo`Co000000?o410@ooooooooool05_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Go
oooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool2
o`0000;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Fooooo`03o`000?oo
oooooooo01Sooooo00Cok^k^oc8b<_l0003o<S8b0_l00004ooooo`03ob4Q8Ol0003o000000?ooooo
1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01_ooool2o`0000Oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0
003o0000oc8b<_oMgMd06?ooool4o`000003oa0@4?oooooooooo01;ooooo000;ooooo`03o`000?oo
oooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVY
ooooo`07ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo01Gooooo00?o0000
ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o8B4Qo`000?l000000ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01Oooool2o`0000Oooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omg
MgOo<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo0006o`0000Gooooo00?o0000oooooooo
ool04?ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo
00Sooooo00?o0000ooooooooool01Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@
ooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01ooo
ool2o`0000oooooo00Co410@oooooooooooooooo0_l0000;ooooo`03oiRHV?lQ8B7ok^k^00Wooooo
00?o0000ooooooooool03Oooool01Ol@413ooooooooooooooooo410@00;o00003_ooool00ol0003o
ooooooooo`0=ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000oooooooo
ool06?ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0>
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo01Gooooo00?o0000ooooooooool01oooool2o`0000kooooo0_l00003ooooo`Co00002_oo
ool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00kooooo00Co0000oooooooooooooooo
0ol0000=ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool06Oooool00ol0003oooooooooo`0Dooooo`00
2oooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGo
c<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo
000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool00000
3_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05_ooool00ol0003o
ooooooooo`0Gooooo`;o00000oooool01?l0003oooooo`000?l0000;ooooo`03ogMgMomVIVKooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`03o`000?oooooooooo00Co00002_ooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEE
EOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Jooooo`03o`000?oooooooooo01Co
oooo000;ooooo`03o`000?oooooooooo01Sooooo00Go410@oooooooooooooooooa0@400>ooooo`03
ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Hooooo`?o000000?oooooo`000?l000004Oooool2
o`0000;ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool04Oooool00ol@413oooooooooo`04o`0000[ooooo00?o0000ooooooooool04Ooo
ool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003o
ooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aoooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00;ooooo0ol0
000Jooooo`04o`000?ooooooooooooooo`;o00004Oooool2o`0000;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`0Aoooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Dooooo`002Oooool00omEEEGoIVIVo`00000Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`00_ooool6o`000003ooooool0003o000001Cooooo00?o0000ooooooooool05?ooool2
o`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
1?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02o`0000[ooooo1?l0000@ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000Iooooo`03oeEEEOmVIVKo0000
01Kooooo002Fooooo`;o00005?ooool00ol0003oooooooooo`09ooooo`;o000000?oooooo`000?l0
0000??ooool2o`0006gooooo002/ooooo`03o`000?oooooooooo00Wooooo0_l000000ooooooo0000
o`00000looooo`;o0000KOooool00:cooooo00?o0000ooooooooool06Oooool2o`0002oooooo0_l0
001Rooooo`;o00000_ooool2o`0000Gooooo002/ooooo`03o`000?oooooooooo01Wooooo0_l00003
ooooo`;o00000oooool2o`0001Sooooo0_l0001_ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM
1Oooool00:cooooo00?o0000ooooooooool07Oooool3o`0000?ooooo0_l0000Hooooo`?o00002ooo
ool2o`0006;ooooo00CogMgMo`000?l@413oc<c<1_ooool000Ooooooool0001<o`0000cooooo00Co
k^k^ob4Q8Ol@413ok^k^1_ooool000Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool3o`0000Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool3o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00_ooool2o`000003ooooool0003ooooo00Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_oo
ool01?lQ8B7oMgMgogMgMolb<S86ooooo`001oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool09_ooool2o`0002Oooooo00?o0000ooooooooool08ooo
ool2o`0000;ooooo00?o0000ooooooooool02_ooool2o`0001[ooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Wooooo0_l00002ooooo`;o00001Ooo
ool008?ooooo0_l0000Wooooo`03o`000?oooooooooo0;Wooooo0020ooooo`;o0000:_ooool00ol0
003oooooooooo`0Cooooo`;o0000Y?ooool0083ooooo0_l0000Zooooo`03o`000?oooooooooo00co
oooo0_l00005ooooo`;o0000Y?ooool00:cooooo00?o0000ooooooooool03?ooool2o`000:_ooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o00004?ooool2o`0002cooooo0_l00009
ooooo`;o0000K_ooool00:cooooo00?o0000ooooooooool04?ooool2o`0000_ooooo0_l0000Ooooo
o`;o00002Oooool2o`0006kooooo002=ooooo`;o00007Oooool00ol0003oooooooooo`0Mooooo`;o
0000:_ooool2o`0006kooooo002=ooooo`;o00007Oooool00ol0003oooooooooo`09ooooo`;o0000
[_ooool008oooooo0_l0000Kooooo`03o`000?oooooooooo00Wooooo0_l0002^ooooo`00O_ooool4
o`0000[ooooo0_l000000ooooooo0000o`00000Kooooo`;o0000^_ooool007kooooo1?l0000:oooo
o`;o00007_ooool2o`000;[ooooo001nooooo`;o00002?ooool2o`0002;ooooo00?o0000oooooooo
ool01?ooool2o`0000Kooooo0_l00005ooooo`;o00003Oooool2o`0009Gooooo001nooooo`;o0000
2?ooool2o`0002;ooooo00?o0000ooooooooool01?ooool2o`0000Kooooo0_l00005ooooo`;o0000
3Oooool2o`0000oooooo0_l00007ooooo`?o0000N_ooool00:cooooo0ol0000cooooo`;o00001ooo
ool3o`0007[ooooo002/ooooo`03o`000?oooooooooo02?ooooo0_l0000>ooooo`;o0000Q?ooool0
0:cooooo00?o0000ooooooooool04_ooool2o`0000oooooo0_l0000>ooooo`;o0000Q?ooool00:co
oooo00?o0000ooooooooool04_ooool2o`0002[ooooo0_l0001iooooo`00TOooool2o`0001Wooooo
00?o0000ooooooooool0<oooool2o`0000Wooooo0_l0001iooooo`00R?ooool2o`0000Oooooo0_l0
000Iooooo`03o`000?oooooooooo03?ooooo0_l00024ooooo`00R?ooool2o`0002;ooooo00?o0000
ooooooooool03_ooool2o`000:Wooooo002/ooooo`03o`000?oooooooooo00?ooooo0_l00009oooo
o`;o00001oooool2o`00013ooooo0_l0000Nooooo`;o00002oooool2o`00067ooooo002/ooooo`?o
00000oooool2o`0001;ooooo0_l0000@ooooo`;o00007_ooool2o`0000_ooooo0_l0001Qooooo`00
[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`0Aooooo`?o0000=Oooool2o`0006kooooo002<ooooo`;o00007_ooool00ol0
003oooooooooo`0Aooooo`?o00003Oooool2o`0002Kooooo0_l0001^ooooo`00R?ooool2o`0000;o
oooo0_l0000Nooooo`03o`000?oooooooooo027ooooo0_l0002Fooooo`00R?ooool2o`0002;ooooo
00?o0000ooooooooool0<_ooool2o`0000Oooooo0_l0001looooo`00[?ooool00ol0003ooooooooo
o`0`ooooo`Co00001oooool2o`0007cooooo002Eooooo`;o00005Oooool3o`0000Cooooo0_l0000Z
ooooo`;o00002?ooool2o`0000_ooooo0_l0001`ooooo`00UOooool2o`0001Gooooo00?o0000oooo
ooooool01?ooool2o`0003Cooooo0_l0000;ooooo`;o0000L?ooool008gooooo0_l0000Mooooo`03
o`000?oooooooooo00gooooo0_l0000[ooooo`;o0000OOooool008Wooooo0_l00002ooooo`;o0000
7Oooool00ol0003oooooooooo`0=ooooo`;o0000:oooool2o`0007gooooo0021ooooo`;o00001_oo
ool2o`00027ooooo00?o0000ooooooooool08Oooool2o`0009Kooooo0021ooooo`;o0000:Oooool0
0ol0003oooooooooo`0Qooooo`;o00009Oooool2o`0006oooooo0029ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`0Wooooo`;o00004Oooool2o`0000_ooooo0ol0001_ooooo`00ROooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B43ooooo`;o000000Co8B4Qonk^k_ooooooA4A4
1oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02Oooooo0_l0000Aooooo`;o0000
2oooool2o`00073ooooo0029ooooo`05oa0@4?ooooooooooooooool@41002_ooool2o`000003oiRH
V?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`0001Cooooo0_l0000Tooooo`;o0000
2_ooool2o`00077ooooo0029ooooo`05o`000?ooooooooooooooool000003?ooool2o`000003ob4Q
8Oo^k^kooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Cooooo`?o0000
0_ooool2o`0001Kooooo0_l0000Dooooo`;o0000LOooool008Wooooo00Go0000oooooooooooooooo
o`000002ooooo`;o00002?ooool2o`000004ogMgMomVIVKo0000o`0000;ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c005ooooo`03o`000?oooooooooo00kooooo0_l00003ooooo`;o00000oooool2o`00
01Kooooo0_l00027ooooo`00ROooool01Ol@413ooooooooooooooooo410@00;ooooo0_l0000;oooo
o`?o00000_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00kooooo0_l0002Yoooo
o`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00;o00002Oooool01Ol0003o^[ZjoooooonHV9So
410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Cooooo`;o0000I?ooool0
08Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02o`0000Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c004ooooo`Co00001_ooool00ol0003oooooooooo`1Cooooo`;o0000I?ooool00:cooooo00?o0000
ooooooooool0^Oooool00:Cooooo0ol00005ooooo`03o`000?oooooooooo00?ooooo0_l0000Coooo
o`;o0000Woooool00:Cooooo0ol00005ooooo`03o`000?oooooooooo00?ooooo0_l000000ooooooo
0000o`00000@ooooo`;o0000>?ooool2o`0006Gooooo002/ooooo`?o00001_ooool2o`0000oooooo
0_l0000Eooooo`;o00008_ooool2o`0006Gooooo0022ooooo`;o0000:?ooool00ol0003ooooooooo
o`0Gooooo`;o00002_ooool2o`0000Wooooo0_l00029ooooo`00P_ooool2o`00013ooooo0_l0000F
ooooo`03o`000?oooooooooo02?ooooo0_l0002Dooooo`00U?ooool2o`0001Kooooo00?o0000oooo
ooooool0^Oooool00:;ooooo0_l00008ooooo`04o`000?oooooo0000o`000;Sooooo002Rooooo`;o
00002?ooool01?l0003oooooo`000?l00003ooooo`;o0000/oooool00:cooooo00?o0000oooooooo
ool01?ooool2o`0002Gooooo0_l0002<ooooo`00SOooool2o`0001gooooo00?o0000ooooooooool0
3oooool2o`0000?ooooo0_l0000Eooooo`;o0000S?ooool008gooooo0_l0000>ooooo`;o00003Ooo
ool3o`0000oooooo0_l00003ooooo`;o00005Oooool2o`0008cooooo002Dooooo`;o00001oooool2
o`0000gooooo0_l00007ooooo`;o00008oooool2o`0008cooooo002Dooooo`;o00003Oooool2o`00
00Oooooo0_l00007ooooo`;o00004Oooool2o`0000Oooooo0_l00006ooooo`;o0000SOooool008Wo
oooo0_l0000Hooooo`;o00001oooool00ol0003oooooooooo`0Iooooo`;o00001oooool2o`0000Ko
oooo0_l0000Rooooo`;o0000JOooool008Wooooo0_l0000Qooooo`03o`000?oooooooooo00Wooooo
0_l0000>ooooo`;o00001_ooool2o`0000Oooooo0_l0000Rooooo`;o0000JOooool00:cooooo00?o
0000ooooooooool01Oooool2o`0000;ooooo0_l0000>ooooo`;o00001_ooool2o`00013ooooo0_l0
000;ooooo`;o0000Moooool008?ooooo0_l0000Booooo`;o00004oooool00ol0003oooooooooo`05
ooooo`;o0000;?ooool2o`0000_ooooo0_l0001gooooo`00Poooool2o`0001;ooooo0_l00004oooo
o`;o00003Oooool00ol0003oooooooooo`0nooooo`?o0000N?ooool009gooooo0_l0000=ooooo`?o
0000?_ooool3o`0007Sooooo002/ooooo`03o`000?oooooooooo00Oooooo0_l0002`ooooo`00[?oo
ool00ol0003oooooooooo`07ooooo`;o00001oooool2o`0000cooooo0_l0002Iooooo`00[?ooool0
0ol0003oooooooooo`0@ooooo`;o00003?ooool2o`0009Wooooo002Uooooo`;o00001Oooool00ol0
003oooooooooo`2iooooo`00Q?ooool2o`0000kooooo0_l0000?ooooo`;o00001Oooool00ol0003o
ooooooooo`2iooooo`00Q?ooool2o`0000kooooo0_l0000Fooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo02Cooooo0_l0000Fooooo`;o00003?ooool2o`0006gooooo002N
ooooo`;o00003?ooool3o`0002Cooooo0_l0000Fooooo`;o00003?ooool2o`0006gooooo002Noooo
o`;o00002oooool2o`0001Kooooo0_l0000Uooooo`;o0000O?ooool009Sooooo0_l0000:ooooo`;o
00001Oooool2o`0001Kooooo0_l00005ooooo`;o00001_ooool2o`0001Kooooo0_l0001looooo`00
V?ooool2o`0000[ooooo0_l00006ooooo`03o`000?oooooooooo01_ooooo0_l00006ooooo`;o0000
U?ooool008_ooooo0_l0000Oooooo`03o`000?oooooooooo0;Wooooo001nooooo`;o00002oooool2
o`0000[ooooo0_l0000Cooooo`03o`000?oooooooooo0;Wooooo001nooooo`;o00004Oooool01_o^
k^ko<S8bo`000?lb<S;ok^k^ooooo`;o00000_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8b
omgMg@05ooooo`04o`000?ooooooooooooooo`;o00000oooool2o`0000Cooooo0_l0002[ooooo`00
TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Co
oooo00Co0000oooooooooooooooo0_l00003ooooo`;o00001?ooool2o`000:_ooooo002Aooooo`03
oa0@4?oooooooooo00;o00004?ooool00ol0003oooooooooo`03ooooo`;o00001_ooool2o`000;;o
oooo002Aooooo`03o`000?oooooooooo00?o00003_ooool00omgMgOo<S8booooo`04ooooo`?o0000
1Oooool2o`000;;ooooo002Aooooo`04o`000?ooooooooooooooo`;o00002oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0^Oooool0097ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0:oooool2o`0008co
oooo002Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00oooooo0_l0000Hooooo`Co0000S?ooool0097ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`0?ooooo`;o00006?ooool2o`0008ko
oooo002/ooooo`03o`000?oooooooooo03Cooooo0_l00023ooooo`00SOooool2o`00017ooooo0_l0
000:ooooo`03o`000?oooooooooo00Oooooo0_l0000[ooooo`;o0000Poooool008gooooo0_l00004
ooooo`;o00002oooool4o`0000Sooooo00?o0000ooooooooool01oooool2o`000;3ooooo002Coooo
o`;o00003Oooool2o`0000Kooooo1Ol0002iooooo`00Z_ooool3o`000;_ooooo002;ooooo`;o0000
7oooool00ol0003oooooooooo`0Vooooo`;o0000TOooool008_ooooo0_l000000ooooooo0000o`00
000Looooo`04o`000?oooooo0000o`0001Wooooo0_l0000:ooooo`;o0000TOooool008kooooo0_l0
000?ooooo`;o00002oooool01?l0003oooooo`000?l0000Iooooo`;o0000WOooool009oooooo0ol0
000:ooooo`03o`000?oooooooooo02Gooooo0_l0002Booooo`00X?ooool2o`0000;ooooo0ol00005
ooooo`03o`000?oooooooooo02Cooooo0ol0002Booooo`00Y?ooool3o`0000Gooooo00?o0000oooo
ooooool03oooool2o`0001?ooooo0_l0002Cooooo`00Uoooool2o`0001?ooooo0ol000000ooooooo
0000o`00000;ooooo`?o00004?ooool2o`0009Kooooo002Gooooo`;o00000oooool2o`0000kooooo
00Co0000oooooooooooooooo0_l0000;ooooo`;o00001oooool2o`0000Sooooo0_l0002Fooooo`00
W?ooool2o`0000kooooo00?o0000ooooooooool05oooool2o`000:3ooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Rooooo`;o00002?ooool00ol0
003oooooooooo`2iooooo`00X_ooool2o`0000Sooooo00?o0000ooooooooool02oooool2o`0001oo
oooo0_l0002;ooooo`00S_ooool2o`0000Kooooo0_l0000Dooooo`03o`000?oooooooooo00_ooooo
0_l0000Aooooo`;o00003?ooool2o`0008_ooooo002>ooooo`;o00001_ooool2o`0001Cooooo0ol0
000Nooooo`;o0000VOooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00Co0000oooooooooooooooo0_l0000Iooooo`;o0000Voooool009So
oooo0_l0000Booooo`04o`000?ooooooooooooooo`;o00006Oooool2o`0009_ooooo002Cooooo`;o
00000oooool2o`0001;ooooo00?o0000ooooooooool01oooool2o`000;3ooooo002Cooooo`;o0000
2_ooool2o`0000_ooooo00?o0000ooooooooool01oooool2o`000;3ooooo002Oooooo`;o00002ooo
ool00ol0003oooooooooo`0>ooooo`?o0000Z?ooool0093ooooo0_l0000Jooooo`;o00003oooool3
o`000:Sooooo002@ooooo`;o00006_ooool3o`000;Wooooo002Eooooo`;o00005Oooool00ol0003o
ooooooooo`2iooooo`00UOooool2o`0001Gooooo00?o0000ooooooooool0^Oooool008gooooo0_l0
0006ooooo`;o00005Oooool00ol0003oooooooooo`2iooooo`00SOooool2o`0000Kooooo0_l0000E
ooooo`04o`000?ooooooooooooooo`;o0000]_ooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1Oooool01?l0003oooooooooooooool2o`000;Kooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo0000o`000004ooooo`03
o`000?oooooooooo0;Wooooo0029ooooo`05oa0@4?ooooooooooooooool@41001?ooool2o`0000Oo
oooo00?oZJVYoeEEEOooool02?ooool2o`0000Cooooo00?o0000ooooooooool02?ooool2o`000:oo
oooo0029ooooo`05o`000?ooooooooooooooool000001?ooool2o`0000Sooooo00?o8B4Qoooooooo
ool01_ooool00omgMgOo<S8booooo`04ooooo`?o00002?ooool2o`000:oooooo0029ooooo`05o`00
0?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool3o`0000Sooooo0_l0002_ooooo`00ROooool01Ol@413ooooooooooooooooo410@
00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`?o0000^Oooool008Wo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo0;Wooooo002Moooo
o`;o00003Oooool00ol0003oooooooooo`0Looooo`;o0000Voooool009gooooo0_l0000=ooooo`03
o`000?oooooooooo01cooooo0_l0002Kooooo`00[?ooool01?l0003oooooooooooooool2o`000;Ko
oooo002Sooooo`;o00001oooool3o`000003ooooool0003o00000;Kooooo002Sooooo`;o00001ooo
ool00ol0003oooooooooo`2iooooo`00V?ooool2o`0000Wooooo0_l00007ooooo`03o`000?oooooo
oooo0;Wooooo002Hooooo`;o00004_ooool00ol0003oooooooooo`0Hooooo`;o0000Woooool00:co
oooo00Co0000ooooool0003o00005oooool2o`0009oooooo002Booooo`;o00006?ooool01?l0003o
ooooo`000?l0002hooooo`00T_ooool2o`0001Sooooo00?o0000ooooooooool04oooool2o`000:Co
oooo002/ooooo`03o`000?oooooooooo01?ooooo0_l0002Tooooo`00S_ooool2o`0001cooooo0ol0
000Cooooo`;o0000Y?ooool008kooooo0_l0000Looooo`03o`000?oooooooooo0;Wooooo002Toooo
o`;o00001_ooool00ol0003oooooooooo`04ooooo`;o0000/oooool00:?ooooo0ol00006ooooo`03
o`000?oooooooooo00Cooooo0_l0002cooooo`00Xoooool2o`0000Oooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool03?ooool2o`000:_o
oooo002/ooooo`?o00003?ooool2o`000:_ooooo002/ooooo`;o0000^_ooool00:cooooo0_l0000:
ooooo`;o0000[_ooool009cooooo0_l0000>ooooo`03o`000?oooooooooo00Wooooo0_l0002^oooo
o`00W?ooool3o`0000gooooo00?o0000ooooooooool0^Oooool009gooooo0_l0000=ooooo`03o`00
0?oooooooooo00Gooooo0_l0002booooo`00X_ooool5o`0000Gooooo00?o0000ooooooooool01Ooo
ool2o`000;;ooooo002Rooooo`Go00001Oooool00ol0003oooooooooo`05ooooo`;o0000/_ooool0
0:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00U_ooool2o`0001Cooooo
00?o0000ooooooooool0^Oooool009Kooooo0_l0000Dooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Iooooo`;o
00001oooool4o`000003oa0@4?oooooooooo00?ooooo0_l0002jooooo`00TOooool2o`0000Kooooo
0_l00009ooooo`03o`000?oooooooooo00Gooooo0_l0002jooooo`00TOooool2o`00017ooooo00?o
0000ooooooooool01Oooool3o`000;Wooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Toooo
o`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`00
0?oooooooooo0<7ooooo002Rooooo`03oeEEEOmVIVKo00000<?ooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo002Zooooo`04oa0@4?l0003o0000o`000;[ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`06o`000?mgMgOo0000o`000?mEEEGok^k^]oooool00:_ooooo00Ko0000oeEEEOo^k^koooooogMg
MomEEEFgooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo0;Gooooo002[
ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0]Oooool00:_ooooo00Ko0000oeEE
EOo^k^koooooogMgMomVIVJgooooo`00Z_ooool00ol@413o0000ogMgM`02o`000003ofIVI_o^k^ko
oooo0;Kooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.63617 .59793 Mdot
.39584 .70857 Mdot
.45994 .61824 Mdot
.52722 .65564 Mdot
.5858 .54734 Mdot
.44426 .14111 Mdot
.4491 .3709 Mdot
.52787 .05049 Mdot
.54387 .90872 Mdot
.46381 .77317 Mdot
.49159 .22471 Mdot
.59858 .13792 Mdot
.65133 .36464 Mdot
.44349 .25158 Mdot
.57131 .1086 Mdot
.47857 .23605 Mdot
.42709 .21874 Mdot
.65891 .39273 Mdot
.40861 .56409 Mdot
.40217 .18881 Mdot
.64597 .3555 Mdot
.42048 .16619 Mdot
.44902 .10483 Mdot
.66507 .42662 Mdot
.70094 .32473 Mdot
.54741 .26906 Mdot
.54942 .35845 Mdot
.43814 .75061 Mdot
.44562 .06865 Mdot
.39943 .7302 Mdot
.65458 .39593 Mdot
.52177 .93763 Mdot
.39479 .17336 Mdot
.57299 .29342 Mdot
.60601 .63456 Mdot
.48523 .93495 Mdot
.69248 .41897 Mdot
.53993 .68512 Mdot
.46329 .05515 Mdot
.649 .20938 Mdot
.71975 .37284 Mdot
.62024 .48172 Mdot
.46694 .87382 Mdot
.60108 .72227 Mdot
.64513 .52983 Mdot
.44024 .7866 Mdot
.41291 .53105 Mdot
.61695 .80686 Mdot
.57377 .68277 Mdot
.39509 .23275 Mdot
.6315 .77953 Mdot
.59908 .19125 Mdot
.78167 .48504 Mdot
.56418 .74642 Mdot
.51284 .84025 Mdot
.40437 .85903 Mdot
.53316 .05723 Mdot
.43675 .18862 Mdot
.68835 .63194 Mdot
.64467 .48095 Mdot
.41982 .71305 Mdot
.61752 .86409 Mdot
.45953 .0588 Mdot
.46769 .7366 Mdot
.36796 .48357 Mdot
.44657 .96071 Mdot
.49598 .75908 Mdot
.42304 .38431 Mdot
.5165 .74389 Mdot
.67009 .47563 Mdot
.5409 .22129 Mdot
.45717 .66928 Mdot
.46952 .77483 Mdot
.54941 .61173 Mdot
.45834 .05974 Mdot
.50872 .48456 Mdot
.78168 .4856 Mdot
.40241 .48443 Mdot
.56466 .14114 Mdot
.59951 .47274 Mdot
.6506 .64418 Mdot
.41922 .82186 Mdot
.54881 .52779 Mdot
.62118 .5273 Mdot
.40913 .11102 Mdot
.52869 .32305 Mdot
.58164 .58373 Mdot
.567 .64432 Mdot
.40757 .31248 Mdot
.42645 .35791 Mdot
.70109 .327 Mdot
.55923 .04434 Mdot
.45423 .27249 Mdot
.51318 .77983 Mdot
.42183 .45212 Mdot
.51826 .00137 Mdot
.43053 .29611 Mdot
.64275 .7532 Mdot
.78291 .52231 Mdot
.43509 .1895 Mdot
.61978 .66411 Mdot
.39857 .59173 Mdot
.57314 .10745 Mdot
.57481 .7761 Mdot
.66194 .60319 Mdot
.59309 .34623 Mdot
.56064 .25979 Mdot
.42991 .26862 Mdot
.45918 .26433 Mdot
.66896 .47057 Mdot
.41189 .51324 Mdot
.52709 .65835 Mdot
.53934 .91588 Mdot
.39868 .78416 Mdot
.6212 .91887 Mdot
.47803 .2895 Mdot
.40383 .57176 Mdot
.37468 .68051 Mdot
.42103 .91552 Mdot
.67238 .34963 Mdot
.64571 .34839 Mdot
.67491 .77078 Mdot
.57071 .20017 Mdot
.47395 .04748 Mdot
.67012 .48098 Mdot
.50057 .72644 Mdot
.38173 .65317 Mdot
.4222 .03024 Mdot
.55561 .80386 Mdot
.53197 .5346 Mdot
.47303 .08564 Mdot
.58924 .74209 Mdot
.64003 .19904 Mdot
.49051 .11899 Mdot
.40293 .69838 Mdot
.54322 .11169 Mdot
.69574 .42198 Mdot
.3885 .27497 Mdot
.48379 .77221 Mdot
.43031 .05792 Mdot
.59746 .14105 Mdot
.50846 .99274 Mdot
.54796 .44981 Mdot
.45574 .78826 Mdot
.43223 .20202 Mdot
.37548 .44992 Mdot
.37517 .30749 Mdot
.41211 .39167 Mdot
.54401 .71233 Mdot
.68785 .74954 Mdot
.40684 .67945 Mdot
.56355 .60575 Mdot
.66922 .45147 Mdot
.48009 .68464 Mdot
.53557 .18315 Mdot
.66736 .32567 Mdot
.51596 .08315 Mdot
.38564 .76883 Mdot
.68883 .4048 Mdot
.6758 .34858 Mdot
.6013 .45176 Mdot
.57827 .15869 Mdot
.73356 .41434 Mdot
.57332 .81923 Mdot
.50721 .84438 Mdot
.63391 .60124 Mdot
.36819 .41584 Mdot
.64473 .6732 Mdot
.53405 .70308 Mdot
.68135 .3614 Mdot
.38267 .65632 Mdot
.44665 .29408 Mdot
.56686 .57749 Mdot
.585 .54312 Mdot
.45393 .20997 Mdot
.3837 .24237 Mdot
.51678 .15595 Mdot
.4365 .3874 Mdot
.44495 .07121 Mdot
.65754 .29611 Mdot
.6803 .26714 Mdot
.56109 .49218 Mdot
.72682 .40008 Mdot
.4429 .66688 Mdot
.57783 .86155 Mdot
.40154 .0915 Mdot
.50654 .95722 Mdot
.72595 .38349 Mdot
.41724 .77642 Mdot
.70973 .68975 Mdot
.37595 .43101 Mdot
.5331 .59589 Mdot
.65985 .79462 Mdot
.45826 .01618 Mdot
.74166 .52239 Mdot
.6062 .14968 Mdot
.54325 .71671 Mdot
.67272 .18274 Mdot
.61394 .41124 Mdot
.463 .69381 Mdot
.45104 .67103 Mdot
.44034 .60687 Mdot
.58511 .47312 Mdot
.70262 .23158 Mdot
.61487 .67624 Mdot
.49266 .28804 Mdot
.48563 .11774 Mdot
.51959 .68363 Mdot
.45082 .30065 Mdot
.52156 .27966 Mdot
.59306 .22915 Mdot
.40291 .54067 Mdot
.64379 .6757 Mdot
.54188 .36989 Mdot
.63042 .61784 Mdot
.42292 .72335 Mdot
.7337 .41745 Mdot
.4262 .54839 Mdot
.62492 .37391 Mdot
.62648 .17361 Mdot
.40662 .61359 Mdot
.68918 .61971 Mdot
.65326 .64562 Mdot
.63346 .69636 Mdot
.48151 .23952 Mdot
.56884 .37263 Mdot
.40595 .77254 Mdot
.44855 .28757 Mdot
.57907 .11806 Mdot
.64942 .81827 Mdot
.42279 .38116 Mdot
.51438 .51308 Mdot
.69235 .21713 Mdot
.52791 .78143 Mdot
.55771 .38582 Mdot
.69736 .72072 Mdot
.55472 .63804 Mdot
.54507 .82741 Mdot
.58981 .22938 Mdot
.59979 .71862 Mdot
.62368 .85427 Mdot
.39763 .33582 Mdot
.59267 .79254 Mdot
.53858 .21731 Mdot
.48896 .97359 Mdot
.43023 .63133 Mdot
.63586 .25893 Mdot
.4379 .80454 Mdot
.53196 .20608 Mdot
.48085 .05274 Mdot
.74048 .49005 Mdot
.46778 .29232 Mdot
.5383 .55396 Mdot
.65211 .29472 Mdot
.5351 .24709 Mdot
.57045 .54207 Mdot
.43747 .84114 Mdot
.50726 .54638 Mdot
.48577 .01345 Mdot
.65588 .73026 Mdot
.5501 .73949 Mdot
.55738 .3843 Mdot
.61357 .74466 Mdot
.52233 .40043 Mdot
.43194 .7937 Mdot
.64303 .50676 Mdot
.41306 .46645 Mdot
.39121 .54668 Mdot
.43526 .901 Mdot
.5699 .32803 Mdot
.42353 .87638 Mdot
.4758 .87751 Mdot
.45388 .76274 Mdot
.59368 .60013 Mdot
.66753 .32471 Mdot
.55991 .5482 Mdot
.5414 .29123 Mdot
.61499 .80842 Mdot
.52048 .27593 Mdot
.5275 .16983 Mdot
.49469 .05729 Mdot
.50609 .67225 Mdot
.55906 .4786 Mdot
.68594 .39417 Mdot
.55091 .08034 Mdot
.4436 .22607 Mdot
.52004 .52044 Mdot
.52873 .27053 Mdot
.43852 .9125 Mdot
.50907 .7857 Mdot
.66265 .58336 Mdot
.39492 .11816 Mdot
.69669 .5809 Mdot
.53144 .0613 Mdot
.6976 .56072 Mdot
.44542 .60944 Mdot
.69853 .583 Mdot
.69546 .71794 Mdot
.49756 .93031 Mdot
.55384 .08751 Mdot
.36892 .80645 Mdot
.59893 .57074 Mdot
.3897 .53595 Mdot
.57012 .78133 Mdot
.50095 .96238 Mdot
.70308 .32657 Mdot
.41943 .36774 Mdot
.62772 .78468 Mdot
.55711 .29291 Mdot
.51944 .58378 Mdot
.57174 .19517 Mdot
.4607 .15055 Mdot
.62784 .30237 Mdot
.70518 .70824 Mdot
.49146 .30268 Mdot
.63477 .41809 Mdot
.60528 .38748 Mdot
.37665 .30717 Mdot
.53206 .46379 Mdot
.68282 .27334 Mdot
.73432 .56617 Mdot
.40305 .90721 Mdot
.43001 .66092 Mdot
.51475 .14769 Mdot
.61959 .55914 Mdot
.51726 .08606 Mdot
.5809 .42388 Mdot
.46696 .69976 Mdot
.43648 .49904 Mdot
.53178 .2079 Mdot
.59215 .12624 Mdot
.63482 .25999 Mdot
.42191 .44719 Mdot
.5262 .13004 Mdot
.52514 .59422 Mdot
.43947 .60072 Mdot
.40012 .73996 Mdot
.42984 .17307 Mdot
.50296 .85076 Mdot
.60057 .44686 Mdot
.57982 .42838 Mdot
.77745 .43743 Mdot
.53985 .25797 Mdot
.47823 .90371 Mdot
.4761 .73744 Mdot
.36748 .52109 Mdot
.53305 .31119 Mdot
.3781 .39333 Mdot
.39229 .67036 Mdot
.52588 .34539 Mdot
.4987 .80097 Mdot
.50969 .99181 Mdot
.59957 .13824 Mdot
.69766 .5953 Mdot
.45146 .92611 Mdot
.60235 .54232 Mdot
.59861 .35476 Mdot
.38645 .69575 Mdot
.47877 .84835 Mdot
.59462 .13203 Mdot
.36986 .7271 Mdot
.58072 .81315 Mdot
.63024 .18441 Mdot
.68898 .28677 Mdot
.73377 .42537 Mdot
.44032 .38889 Mdot
.55749 .7205 Mdot
.59614 .13985 Mdot
.50741 .03045 Mdot
.45238 .3371 Mdot
.66805 .52873 Mdot
.51583 .21594 Mdot
.5113 .14496 Mdot
.62656 .64035 Mdot
.62456 .78822 Mdot
.55234 .81539 Mdot
.70141 .49096 Mdot
.5833 .17338 Mdot
.42631 .15159 Mdot
.7028 .55816 Mdot
.44461 .11005 Mdot
.67801 .27137 Mdot
.5537 .99625 Mdot
.68567 .39864 Mdot
.57196 .24277 Mdot
.50948 .60606 Mdot
.73741 .49712 Mdot
.40462 .33424 Mdot
.43834 .55048 Mdot
.69481 .29681 Mdot
.67069 .48619 Mdot
.46853 .70148 Mdot
.53667 .66017 Mdot
.46952 .16878 Mdot
.56633 .43022 Mdot
.59375 .84461 Mdot
.6331 .7111 Mdot
.67383 .76695 Mdot
.68739 .28182 Mdot
.53904 .22332 Mdot
.76161 .37316 Mdot
.57642 .29677 Mdot
.4483 .21916 Mdot
.51595 .24095 Mdot
.46776 .3431 Mdot
.56621 .09499 Mdot
.5897 .12647 Mdot
.54578 .34641 Mdot
.50243 .28578 Mdot
.57398 .48864 Mdot
.55165 .40465 Mdot
.73112 .6176 Mdot
.5193 .76948 Mdot
.566 .83222 Mdot
.54872 .46536 Mdot
.56203 .6118 Mdot
.53273 .47946 Mdot
.55894 .6767 Mdot
.55155 .24847 Mdot
.57321 .50405 Mdot
.51139 .33337 Mdot
.68202 .75889 Mdot
.42814 .06223 Mdot
.47941 .37728 Mdot
.59354 .67749 Mdot
.55996 .25857 Mdot
.56903 .24105 Mdot
.5425 .26595 Mdot
.55612 .63417 Mdot
.7386 .52604 Mdot
.59147 .07667 Mdot
.53345 .84398 Mdot
.70193 .80111 Mdot
.57646 .77491 Mdot
.53776 .44509 Mdot
.53103 .92283 Mdot
.60661 .15448 Mdot
.49687 .23297 Mdot
.39811 .71599 Mdot
.7788 .44913 Mdot
.51399 .31434 Mdot
.50939 .63587 Mdot
.48009 .19544 Mdot
.61247 .74832 Mdot
.59466 .42652 Mdot
.62688 .1211 Mdot
.42518 .49214 Mdot
.60042 .64956 Mdot
.62136 .48807 Mdot
.42345 .57449 Mdot
.47164 .29202 Mdot
.55138 .60618 Mdot
.52607 .04884 Mdot
.52344 .40135 Mdot
.5478 .11841 Mdot
.43456 .86721 Mdot
.64382 .48687 Mdot
.39756 .77618 Mdot
.66746 .5205 Mdot
.50883 .17405 Mdot
.52499 .69455 Mdot
.60184 .13879 Mdot
.74132 .49678 Mdot
.41282 .4915 Mdot
.69781 .59106 Mdot
.55672 .29607 Mdot
.3969 .48187 Mdot
.37731 .40811 Mdot
.6156 .67835 Mdot
.40715 .48324 Mdot
.49026 .81231 Mdot
.57792 .30382 Mdot
.5971 .89491 Mdot
.42535 .80326 Mdot
.5087 .47556 Mdot
.51624 .83177 Mdot
.60126 .50713 Mdot
.44012 .38853 Mdot
.42573 .63193 Mdot
.56901 .73659 Mdot
.40175 .69183 Mdot
.42995 .45584 Mdot
.49252 .17781 Mdot
.44094 .95312 Mdot
.58669 .54201 Mdot
.63984 .4554 Mdot
.465 .79849 Mdot
.46346 .79252 Mdot
.5019 .3468 Mdot
.63325 .90481 Mdot
.50901 .37213 Mdot
.39799 .72509 Mdot
.69149 .60012 Mdot
.55705 .8453 Mdot
.49575 .78363 Mdot
.4074 .16899 Mdot
.65522 .22145 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o00000oooool2o`000;Cooooo002Tooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool2o`000;Cooooo002Tooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`2iooooo`00Y?ooool00ol0003oooooooooo`02o`0000?ooooo00?o0000ooooooooool0^Oooool0
09kooooo0_l00002ooooo`03oeEEEOmVIVKo000000;ooooo0_l00003ooooo`03o`000?oooooooooo
0;Wooooo002Nooooo`;o00003?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Boooo
o`;o00006?ooool01?l0003oooooo`000?l0002hooooo`00T_ooool2o`0001Sooooo00Co0000oooo
ool0003o0000^?ooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool04?oo
ool2o`000:Oooooo002Sooooo`;o00001oooool00ol0003oooooooooo`05ooooo`;o00002Oooool2
o`000:Oooooo002Sooooo`Co00001Oooool3o`0000Gooooo0ol0002aooooo`00Woooool2o`0000Co
oooo0_l00005ooooo`03o`000?oooooooooo00Kooooo0_l0002aooooo`00UOooool2o`0000Oooooo
0ol00009ooooo`?o00002_ooool2o`000:oooooo002Dooooo`?o00001oooool2o`0000[ooooo0ol0
0009ooooo`?o0000[oooool009Cooooo0_l00008ooooo`;o00003?ooool00ol0003oooooooooo`07
ooooo`;o0000/?ooool00:cooooo00?o0000ooooooooool0^Oooool009Wooooo0ol0000@ooooo`03
o`000?oooooooooo0;Wooooo002Iooooo`?o00004?ooool00ol0003oooooooooo`2iooooo`00[?oo
ool3o`0001_ooooo0_l0002Looooo`00[?ooool00ol0003oooooooooo`0=ooooo`;o00003?ooool2
o`0009cooooo002/ooooo`03o`000?oooooooooo00;ooooo0_l00009ooooo`;o0000Z_ooool00:?o
oooo0_l00007ooooo`03o`000?oooooooooo00;ooooo0_l0002eooooo`00Xoooool2o`0000Oooooo
00?o0000ooooooooool00_ooool2o`0000[ooooo0_l0002Yooooo`00Roooool2o`0001oooooo00?o
0000ooooooooool03_ooool2o`000:Wooooo002;ooooo`;o00007oooool00ol0003oooooooooo`0B
ooooo`;o0000YOooool00:cooooo00?o0000ooooooooool04_ooool2o`000:Gooooo002/ooooo`?o
0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool009_ooooo0_l0000?ooooo`03o`000?oo
oooooooo01Gooooo0_l0002Rooooo`00VOooool4o`0000oooooo00?o0000ooooooooool05?ooool3
o`000:;ooooo002>ooooo`;o00002Oooool2o`00017ooooo00?o0000ooooooooool02oooool2o`00
00Oooooo0_l0002Sooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool02oooool2o`000:co
oooo0029ooooo`?o000000?o<S8bonk^k_ooool01?ooool2ob4Q8@Kooooo00?o0000onk^k_ooool0
1?ooool01Om4A4Co0000o`000?lb<S;ogMgM00?o00000_ooool00ol0003oooooooooo`0<ooooo`;o
00002Oooool2o`000:3ooooo0029ooooo`;o000000?ooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo
00?oEEEEojVYZOooool01oooool00omgMgOo<S8bo`000002o`0000;ooooo00?o0000ooooooooool0
3?ooool2o`0000Wooooo0_l0000=ooooo`;o0000TOooool0087ooooo1_l00002ooooo`05oa0@4?oo
ooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo
0ol0000Vooooo`;o0000TOooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q
8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Jooooo`?o0000
W?ooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00Gooooo0_l0000Cooooo`?o
0000W?ooool008Wooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`;o00005Oooool2o`0009_o
oooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Looooo`?o0000V_ooool008Wo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo00?o0000oooo
ooooool07?ooool4o`0009Wooooo002Iooooo`;o00004Oooool00ol0003oooooooooo`0Booooo`;o
00002?ooool4o`0009Wooooo002Iooooo`;o00004Oooool00ol0003oooooooooo`02o`00013ooooo
0_l00009ooooo`;o0000V_ooool00:cooooo00?o0000ooooooooool00ol0000Mooooo`;o0000Uooo
ool009?ooooo0_l0000:ooooo`;o00002oooool3o`000003ooooool0003o000001gooooo0_l0002G
ooooo`00Toooool2o`0000[ooooo0_l0000;ooooo`03o`000?oooooooooo00;ooooo0_l0000Loooo
o`;o0000Uoooool00:cooooo00?o0000ooooooooool00_ooool2o`0001;ooooo0_l00008ooooo`;o
0000Uoooool00:cooooo00?o0000ooooooooool05_ooool2o`000:7ooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002Aooooo`;o00006Oooool00ol0003oooooooooo`2iooooo`00SOooool2o`00
00;ooooo0_l0000?ooooo`;o00002?ooool00ol0003oooooooooo`06ooooo`;o0000/Oooool008Wo
oooo0_l00002ooooo`;o00001Oooool2o`0000cooooo0_l00008ooooo`04o`000?oooooo0000o`00
00Gooooo0_l0000@ooooo`;o00003?ooool2o`00097ooooo0029ooooo`;o00002Oooool2o`0001Ko
oooo1?l0000Gooooo`;o00003?ooool2o`00097ooooo002Yooooo`;o000000?oooooo`000?ooool0
^_ooool00:Wooooo0_l000000ooooooo0000ooooo`09ooooo`;o0000;?ooool2o`00087ooooo002/
ooooo`03o`000?oooooooooo00Sooooo0_l0000Nooooo`;o00003?ooool2o`00087ooooo002;oooo
o`;o00002Oooool3o`0001?ooooo00?o0000ooooooooool0:?ooool2o`0008oooooo002;ooooo`;o
00002Oooool3o`0001?ooooo00?o0000ooooooooool07Oooool2o`0009[ooooo002Uooooo`;o0000
1Oooool00ol0003oooooooooo`0Dooooo`;o00001oooool2o`0009[ooooo002Uooooo`;o00001Ooo
ool00ol0003oooooooooo`0Dooooo`;o0000Xoooool00:cooooo0ol0000Dooooo`;o00005Oooool2
o`0008cooooo002Eooooo`;o00005Oooool00ol0003oooooooooo`0Dooooo`;o00005Oooool2o`00
08cooooo002Eooooo`;o00005Oooool00ol0003oooooooooo`07ooooo`;o0000/?ooool009cooooo
0_l0000>ooooo`03o`000?oooooooooo00Oooooo0_l0000Uooooo`;o0000ROooool009cooooo0_l0
000>ooooo`03o`000?oooooooooo00Oooooo0_l0000Uooooo`;o0000ROooool00:cooooo00?o0000
ooooooooool00_ooool2o`000;Gooooo002Cooooo`;o00001Oooool2o`00013ooooo00?o0000oooo
ooooool00_ooool2o`0000Gooooo0_l0000aooooo`;o0000Noooool009?ooooo0_l00005ooooo`;o
00004?ooool00ol0003oooooooooo`09ooooo`?o00009?ooool2o`0000[ooooo0_l0001kooooo`00
ZOooool2o`000004ooooool0003o0000o`0000Wooooo0ol0000Tooooo`;o0000Qoooool009Wooooo
0_l0000>ooooo`;o000000?oooooo`000?ooool02_ooool2o`000:kooooo002Iooooo`;o00004Ooo
ool00ol0003oooooooooo`0Jooooo`?o00008_ooool2o`0007Sooooo0029ooooo`;o00008?ooool2
o`0001cooooo0ol0000Rooooo`;o0000N?ooool008Wooooo0_l0000Iooooo`;o00001Oooool2o`00
0;_ooooo002Tooooo`?o00001Oooool00ol0003oooooooooo`02ooooo`;o0000]Oooool008Gooooo
0_l0000:ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00?oA4A4o`000?l0
00000_l00005ooooo`03o`000?oooooooooo00;ooooo0_l0000?ooooo`?o0000Xoooool008Gooooo
0_l0000:ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`0Cooooo`?o0000Xoooool008Wooooo1_l00002ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00So
oooo0_l00004ooooo`;o0000ZOooool0097ooooo00Go0000ooooooooooooooooo`000003ooooo`;o
00002_ooool00omgMgOo<S8booooo`04ooooo`?o00002?ooool2o`0000Cooooo0_l0002Yooooo`00
TOooool01Ol0003ooooooooooooooooo000000?ooooo0_l00007ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`2iooooo`00TOooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`;o00001?ooool2o`00
01Oooooo0_l0002>ooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0:ooooo`;o00001?ooool3o`0001Kooooo0_l0002>oooo
o`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo0_l00002ooooo`Co00001_ooool00ol0
003oooooooooo`0Aooooo`;o00005_ooool2o`0008kooooo002Nooooo`;o00003?ooool00ol0003o
ooooooooo`0;ooooo`;o0000:oooool2o`0007oooooo002Dooooo`;o00005_ooool00ol0003ooooo
ooooo`06ooooo`;o00000oooool3o`0002[ooooo0_l0001oooooo`00U?ooool2o`0000Kooooo0_l0
000>ooooo`03o`000?oooooooooo00Kooooo0_l00004ooooo`;o0000:Oooool4o`0007kooooo0027
ooooo`;o00004oooool2o`0000kooooo0ol00003ooooo`;o0000<_ooool4o`0007kooooo0027oooo
o`;o00008oooool00ol0003oooooooooo`03ooooo`?o0000/oooool00:cooooo00?o0000oooooooo
ool01?ooool2o`0003Cooooo0_l0001mooooo`00[?ooool2o`0003_ooooo0_l0001mooooo`00Vooo
ool2o`0000cooooo0_l000000ooooooo0000o`00000looooo`;o0000O?ooool009_ooooo0_l00004
ooooo`Go00000oooool2o`000003ooooool0003ooooo00_ooooo0_l0000_ooooo`;o0000O?ooool0
09[ooooo0_l00005ooooo`Go00001_ooool00ol0003oooooooooo`0:ooooo`;o00000oooool2o`00
00Cooooo0_l0000Hooooo`;o0000R?ooool009Gooooo0_l00003ooooo`;o00004?ooool00ol0003o
ooooooooo`0?ooooo`;o00001?ooool3o`0001Oooooo1?l0000:ooooo`;o0000N_ooool009Gooooo
0_l00004ooooo`;o00003oooool3o`0000oooooo0_l00005ooooo`;o00006Oooool2o`0000[ooooo
0_l0001jooooo`00Voooool2o`0000cooooo0_l000000ooooooo0000ooooo`0Gooooo`;o00003ooo
ool2o`00093ooooo0022ooooo`?o00009?ooool2o`000003ooooool0003ooooo01Oooooo0_l0000?
ooooo`;o0000T?ooool008;ooooo0ol0000Wooooo`03o`000?oooooooooo0;Wooooo002=ooooo`;o
00007Oooool00ol0003oooooooooo`07ooooo`;o0000/?ooool008gooooo0_l0000Mooooo`04o`00
0?ooooooooooooooo`;o00001?ooool2o`000;3ooooo002/ooooo`04o`000?ooooooooooooooo`;o
0000]_ooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol00006ooooo`;o0000;?oo
ool2o`0000Wooooo0_l0001hooooo`00[?ooool00ol0003oooooooooo`06ooooo`;o00003?ooool2
o`0001kooooo0_l00009ooooo`?o0000Moooool00:cooooo00?o0000ooooooooool05?ooool2o`00
02Wooooo0ol0001gooooo`00S?ooool2o`0001kooooo00?o0000ooooooooool00_l0002gooooo`00
R_ooool4o`0000kooooo0_l0000>ooooo`03o`000?oooooooooo00;o0000]oooool008[ooooo0_l0
000@ooooo`;o00003_ooool00ol0003oooooooooo`2iooooo`00XOooool2o`0000Wooooo00?o0000
ooooooooool0^Oooool00:7ooooo0_l00009ooooo`;o00001_ooool2o`0000Gooooo0_l0000=oooo
o`;o0000W?ooool00:cooooo0_l00006ooooo`;o00001Oooool2o`0000gooooo0_l0000@ooooo`;o
00001_ooool4o`00083ooooo002/ooooo`?o0000;Oooool2o`0000Kooooo1?l00020ooooo`00[?oo
ool00ol0003oooooooooo`0Mooooo`;o00003_ooool2o`0008[ooooo002Cooooo`;o00005oooool0
0ol0003oooooooooo`0=ooooo`;o00003_ooool2o`0000kooooo0_l0002:ooooo`00Toooool2o`00
01Oooooo00?o0000ooooooooool03Oooool2o`0002Wooooo0_l0001oooooo`00[?ooool00ol0003o
ooooooooo`0_ooooo`;o00001oooool2o`0007oooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool2o`0000;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo02oooooo0_l00028ooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo0_l00002ob4Q8@Cooooo00GoV9RHob4Q8Ol0003o0000odA4A007ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool02_ooool2o`000:gooooo0021ooooo`Ko00000_ooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHo`000?l000002Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;o00002?ooool2o`0000Oooooo0_l0000Aooooo`;o00007Oooool2
o`0000cooooo0_l0001Tooooo`00ROooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h01oooool2o`0000Gooooo1Ol0000Aooooo`;o00004Oooool2o`0001gooooo0_l0000<
ooooo`;o0000I?ooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKo
oooo00?ooooo00?o0000ob4Q8Ol000000_l00005ooooo`03o`000?oooooooooo0;Wooooo0029oooo
o`05oa0@4?ooooooooooooooool@41001?ooool2o`0000Wooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01?ooool2o`0000Gooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool04?ooool2o`0003Gooooo0_l0001`ooooo`00ROooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo0_l00003ooooo`?o000000Co410@o`000?lQ8B7oc<c<
1?ooool4o`0000Kooooo00?o0000ooooooooool04?ooool2o`0000gooooo0_l0000Vooooo`;o0000
L?ooool008oooooo0_l00006ooooo`?o00004_ooool00ol0003oooooooooo`0Oooooo`;o0000V?oo
ool008?ooooo0_l0000:ooooo`;o00006oooool00ol0003oooooooooo`0aooooo`;o00001oooool2
o`0007gooooo0023ooooo`;o00009oooool00ol0003oooooooooo`0`ooooo`?o00001oooool2o`00
07gooooo002/ooooo`?o00001?ooool2o`0002[ooooo0_l00008ooooo`;o00002oooool2o`00073o
oooo002/ooooo`03o`000?oooooooooo00Cooooo0_l0000dooooo`;o00002oooool2o`00073ooooo
002/ooooo`03o`000?oooooooooo00kooooo0_l0000[ooooo`;o0000O?ooool008?ooooo0_l0000W
ooooo`03o`000?oooooooooo00kooooo0_l0000[ooooo`;o0000O?ooool008?ooooo0_l0000Woooo
o`03o`000?oooooooooo02;ooooo0_l0002Eooooo`00P?ooool2o`0002[ooooo00?o0000oooooooo
ool08_ooool2o`0002Kooooo0_l0001]ooooo`00P?ooool2o`0002[ooooo00?o0000ooooooooool0
:Oooool2o`00017ooooo0_l0000<ooooo`;o0000KOooool00:cooooo00?o0000ooooooooool0:Ooo
ool2o`00017ooooo0ol0000;ooooo`;o0000KOooool00:cooooo0ol0000Gooooo`;o00009?ooool2
o`0000_ooooo0_l0001]ooooo`00[?ooool00ol0003oooooooooo`0Gooooo`;o00000oooool2o`00
01Gooooo0_l0000Eooooo`;o0000KOooool008?ooooo0_l0000Wooooo`03o`000?oooooooooo01;o
oooo0_l00003ooooo`;o00000oooool2o`0001Gooooo0_l00024ooooo`00Poooool2o`0002Oooooo
00?o0000ooooooooool04_ooool2o`000:Gooooo002/ooooo`03o`000?oooooooooo05Sooooo0_l0
001Oooooo`00[?ooool00ol0003oooooooooo`1Hooooo`;o0000Goooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool02Oooool2o`0001?ooooo0_l0002Iooooo`00
P_ooool2o`0000kooooo0_l0000Hooooo`03o`000?oooooooooo00Wooooo0_l000000ooooooo0000
o`00000@ooooo`;o0000>Oooool2o`0005kooooo0022ooooo`;o00003_ooool2o`0001Sooooo0ol0
000<ooooo`;o00004?ooool2o`0001Cooooo0_l0000Sooooo`;o0000G_ooool009;ooooo1?l0000F
ooooo`03o`000?oooooooooo01kooooo0_l0000;ooooo`;o00001oooool2o`0008?ooooo002Doooo
o`;o00005_ooool00ol0003oooooooooo`0[ooooo`;o0000S?ooool000Wooooo1?l000000ol@413o
ooooooooo`0Fooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^
k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Foooo
o`03o`000?oooooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;o
gMgM01Sooooo1?l000000ol@413oooooooooo`0Booooo`002oooool00ol0003oooooooooo`0Hoooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool0
0omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?o
MgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`0Eooooo`03o`000?oooooooooo00Oo
oooo0_l0000?ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q
8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`0Iooooo`03o`00
0?oooooooooo01Cooooo0006o`0000Gooooo00?o0000ooooooooool04?ooool6o`0000;ooooo00Go
410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool0
1Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00Go
oooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP03oooo
o`;o00001?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Oooooo0_l00004oooo
o`;o00002Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool0
0ol0003oooooooooo`0=ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`0=ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?oo
ool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8b
ooooo`0>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0>ooooo`05
o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP02ooooo`;o00000oooool00omg
MgOo<S8booooo`0Eooooo`03o`000?oooooooooo00gooooo0_l00009ooooo`05o`000?oooooooooo
ooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`;o00003oooool01Ol0003ooooooooooooo
oooo000000oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000kooooo
00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo
000;ooooo`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEE
EOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?oooooooooooooo
ool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Fooooo`03o`00
0?oooooooooo01Sooooo0ol000001?oooooo0000o`000?l0000<ooooo`03ogMgMomVIVKooooo00?o
oooo00?o0000ob4Q8Ol000000_l0000?ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<
c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Jooooo`03o`000?oooooooooo01Cooooo
000;ooooo`03o`000?oooooooooo01Sooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVY
ZOmgMgOooooo00?ooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00co
oooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Hooooo`Co00005oooool01Ol@413o0000o`000?oooooo
410@00;o00003Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`;o00003_oo
ool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04Oooool01Ol@413ooooo
oooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`0Aoooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool0
6?ooool01?l0003oooooo`000?l00006ooooo`;o00001oooool2o`0000Kooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool01?l0003ooooooooooooo
ool2o`0000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01Cooooo0009ooooo`03oeEEEOmVIVKo000001[o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`00013ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
V9RHoa0@4?l0003o0000olc<c002o`0000;ooooo1?l0000Gooooo`03o`000?oooooooooo00Oooooo
0_l00007ooooo`;o00001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo0_l00002ooooo`04
oiRHV?l@413o0000ob4Q8@;o00000oooool6o`0000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00006Ooo
ool00omEEEGoIVIVo`00000Fooooo`00P?ooool2o`0000Sooooo1Ol0000Mooooo`04o`000?oooooo
0000o`0002?ooooo0_l00006ooooo`;o00001oooool2o`0002?ooooo0_l0001Mooooo`00P?ooool2
o`0000Wooooo0_l0000Oooooo`04o`000?oooooo0000o`0001Cooooo0_l0000>ooooo`;o00001Ooo
ool2o`0000Oooooo0_l0000Sooooo`;o0000GOooool008oooooo0_l00002ooooo`;o00005oooool0
0ol0003oooooooooo`0Aooooo`;o00000_ooool2o`0000kooooo0_l00005ooooo`;o00004Oooool2
o`0000_ooooo0_l0001Pooooo`;o00000_ooool2o`0000Gooooo002?ooooo`;o00000_ooool2o`00
01Oooooo00?o0000ooooooooool04Oooool2o`0002cooooo0_l0000;ooooo`;o0000H?ooool01_o^
k^ko8B4QohN7Qonj^[[o0000omgMg@Gooooo002/ooooo`03o`000?oooooooooo04_ooooo0ol0001Q
ooooo`04omgMgOl0003o410@olc<c0Kooooo0007oooooooo0000C?l0000<ooooo`04onk^k_lQ8B7o
410@onk^kPKooooo0007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`02o`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04
ooooo`;o00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00Co8B4Q
ogMgMomgMgOo<S8b1_ooool000Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0E
ooooo`;o00001oooool2o`0000Oooooo00?o0000ooooooooool00_ooool2o`0002;ooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Wooooo0_l00002
ooooo`;o00001Oooool00:cooooo00?o0000ooooooooool07_ooool2o`0000cooooo0_l0002;oooo
o`00S_ooool2o`0001cooooo00Co0000oooooooooooooooo0_l0002fooooo`00S_ooool2o`0001co
oooo00Co0000oooooooooooooooo0_l0002fooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
P?ooool2o`0002[ooooo00?o0000ooooooooool00oooool2o`0002oooooo0_l0000Fooooo`;o0000
3?ooool2o`0005gooooo0020ooooo`;o0000:_ooool3o`0000?ooooo0_l0000_ooooo`;o00005_oo
ool2o`0000cooooo0_l0001Mooooo`00[?ooool00ol0003oooooooooo`0=ooooo`;o00005_ooool2
o`0000gooooo0_l0000Eooooo`;o0000K?ooool008oooooo0_l0000Kooooo`03o`000?oooooooooo
00gooooo0_l0000Fooooo`;o00001Oooool2o`0000Kooooo0_l0000Eooooo`;o0000K?ooool008oo
oooo0_l0000Kooooo`03o`000?oooooooooo00Oooooo0_l0000Sooooo`;o0000Roooool008Oooooo
0_l0000Sooooo`03o`000?oooooooooo00Oooooo0_l0002`ooooo`00Qoooool2o`0000?ooooo0_l0
000Nooooo`03o`000?oooooooooo0;Wooooo002<ooooo`;o00007_ooool00ol0003oooooooooo`0D
ooooo`;o00000oooool2o`0000?ooooo0_l0002Iooooo`00R?ooool2o`0002;ooooo00Co0000oooo
ool0003o00004oooool2o`0000?ooooo0_l00003ooooo`;o0000VOooool008Sooooo0_l00009oooo
o`;o00005oooool01?l0003oooooo`000?l0000?ooooo`;o00001oooool2o`0009kooooo002Coooo
o`;o00000_ooool2o`0001?ooooo0ol0000@ooooo`;o00001oooool2o`0009kooooo002Gooooo`;o
00004oooool00ol0003oooooooooo`09ooooo`;o0000[_ooool00:cooooo00?o0000ooooooooool0
2Oooool2o`0003Gooooo0_l0001gooooo`00[?ooool00ol0003oooooooooo`0Tooooo`;o00006?oo
ool4o`0007Oooooo002=ooooo`;o00007Oooool00ol0003oooooooooo`0Tooooo`;o00006?ooool2
o`0007Wooooo002=ooooo`;o00007Oooool00ol0003oooooooooo`1:ooooo`;o0000KOooool00:co
oooo00?o0000ooooooooool07Oooool2o`0002_ooooo0_l0001]ooooo`00S?ooool2o`0001kooooo
00?o0000ooooooooool07Oooool2o`0009[ooooo002<ooooo`;o00001?ooool2o`0001Sooooo0ol0
002iooooo`00T_ooool2o`0001Sooooo00?o0000ooooooooool04oooool2o`000:Cooooo002/oooo
o`03o`000?oooooooooo01?ooooo0_l0000Xooooo`?o0000NOooool00:cooooo00?o0000oooooooo
ool00oooool2o`0001?ooooo0_l0000Hooooo`;o00002Oooool3o`0007Wooooo002/ooooo`03o`00
0?oooooooooo00?ooooo0_l0000Cooooo`;o00006?ooool2o`0008Gooooo002:ooooo`;o00008?oo
ool00ol0003oooooooooo`0nooooo`;o0000NOooool008[ooooo0_l0000Pooooo`03o`000?oooooo
oooo00Gooooo0_l0000gooooo`;o0000NOooool00:cooooo00?o0000ooooooooool01Oooool4o`00
027ooooo0_l0000Booooo`;o0000NOooool009Sooooo0_l0000Booooo`?o00001oooool2o`0001;o
oooo0_l0000<ooooo`?o00004?ooool2o`0007_ooooo002Hooooo`;o00004_ooool00ol0003ooooo
ooooo`0Kooooo`;o00003?ooool2o`0000Oooooo0_l00008ooooo`;o0000Noooool009Sooooo0_l0
000Booooo`03o`000?oooooooooo00;o00003?ooool2o`0000;ooooo0_l0000Nooooo`;o0000QOoo
ool009Sooooo1?l0000@ooooo`03o`000?oooooooooo00;o00003?ooool2o`0000;ooooo0_l0002U
ooooo`00SOooool2o`0000_ooooo0_l0000@ooooo`03o`000?oooooooooo00gooooo0_l00002oooo
o`;o0000Y_ooool008gooooo0_l0000Mooooo`03o`000?oooooooooo00gooooo0_l00002ooooo`;o
0000Y_ooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool7o`0000;o
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo02Sooooo0_l0000Ooooo
o`;o0000K_ooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnH
V9So8B4Qonk^k_ooooooA4A400;o00001Oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo02Sooooo0_l0000Aooooo`;o00003?ooool2o`0006kooooo0029ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0000k
ooooo`;o0000O?ooool008Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2iooooo`00ROooool01Ol0
003ooooooooooooooooo000000Oooooo0_l00005ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05oa0@4?oooooo
ooooooooool@41001Oooool4o`0000Kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00oooooo0_l0000?ooooo`;o00006Oooool2o`0007cooooo0029
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0000Cooooo00Go0000okZj^_ooooooV9RH
oa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_l0000=ooooo`;o0000
3oooool2o`0001Wooooo0_l0001looooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`02o`0000go
oooo0_l0000Eooooo`;o0000TOooool00:cooooo00?o0000ooooooooool03oooool2o`0001Gooooo
0_l0002Aooooo`00[?ooool00ol0003oooooooooo`0Cooooo`;o00006Oooool3o`0008Sooooo002/
ooooo`03o`000?oooooooooo01?ooooo0_l00009ooooo`;o00003_ooool3o`0008Sooooo002/oooo
o`?o00007_ooool2o`0009Wooooo0025ooooo`;o00009Oooool00ol0003oooooooooo`06ooooo`;o
0000/Oooool008Gooooo0_l0000Uooooo`03o`000?oooooooooo00Kooooo0_l0002aooooo`00QOoo
ool2o`0000gooooo0_l0000Fooooo`03o`000?oooooooooo00Kooooo0_l000000ooooooo0000o`00
002^ooooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool02Oooool2o`0001Wooooo0_l0002C
ooooo`00VOooool2o`00017ooooo00?o0000ooooooooool09?ooool2o`0009?ooooo0028ooooo`;o
00003oooool6o`0000gooooo00?o0000ooooooooool0^Oooool008Sooooo0_l0000Aooooo`Co0000
3Oooool01?l0003oooooo`000?l0000[ooooo`;o0000Roooool00:cooooo1?l0000?ooooo`;o0000
4?ooool2o`0000Sooooo0_l0002;ooooo`00SOooool2o`0001gooooo00?o0000ooooooooool04?oo
ool2o`0000Wooooo0_l00005ooooo`?o00001oooool2o`0008_ooooo0022ooooo`;o00002Oooool2
o`0001gooooo00?o0000ooooooooool05Oooool2o`0000Cooooo0_l00006ooooo`;o0000U?ooool0
08;ooooo0_l0000Qooooo`;o00001Oooool00ol0003oooooooooo`03ooooo`;o00001Oooool2o`00
00Wooooo0_l0002Rooooo`00YOooool2o`0000Gooooo00?o0000ooooooooool00oooool2o`0000Go
oooo0_l0002]ooooo`00Roooool2o`0001oooooo00?o0000ooooooooool0@_ooool2o`0007Gooooo
002;ooooo`;o00004_ooool2o`0000_ooooo00?o0000ooooooooool01Oooool2o`0003_ooooo0_l0
001eooooo`00Q_ooool2o`0000Cooooo0_l0000Aooooo`;o00002oooool00ol0003oooooooooo`05
ooooo`;o00008_ooool2o`0008kooooo0026ooooo`;o00001?ooool2o`0001?ooooo0_l00009oooo
o`?o0000:Oooool2o`0008kooooo002Qooooo`;o00002Oooool00ol0003oooooooooo`08ooooo`;o
0000[oooool00:7ooooo0_l00009ooooo`03o`000?oooooooooo00Sooooo0_l0002_ooooo`00ROoo
ool2o`00027ooooo00?o0000ooooooooool0@?ooool2o`0007Oooooo0029ooooo`;o00001_ooool2
o`0001Wooooo00?o0000ooooooooool02oooool2o`0001cooooo0_l0000Eooooo`;o0000Moooool0
08[ooooo0_l00005ooooo`;o00006Oooool00ol0003oooooooooo`0;ooooo`;o00007?ooool2o`00
08kooooo002:ooooo`;o00008?ooool00ol0003oooooooooo`0;ooooo`;o00004Oooool2o`0001go
oooo0_l0001jooooo`00[?ooool00ol0003oooooooooo`0;ooooo`;o00000oooool2o`0000cooooo
0_l0000Mooooo`?o0000NOooool008[ooooo0_l00006ooooo`;o00006?ooool3o`00013ooooo0_l0
000<ooooo`;o00007_ooool2o`0007Wooooo0021ooooo`;o00001oooool2o`0000Kooooo0_l0000H
ooooo`;o0000^_ooool0087ooooo0_l00007ooooo`;o00008?ooool2o`00037ooooo0_l00027oooo
o`00R_ooool2o`00023ooooo00?o0000ooooooooool0<?ooool2o`0008Oooooo002Qooooo`;o0000
00?oooooo`000?l000001_ooool00ol0003oooooooooo`0Cooooo`;o0000Y?ooool008_ooooo0_l0
000Dooooo`;o000000?oooooo`000?l000001_ooool00ol0003oooooooooo`0=ooooo`;o00001?oo
ool2o`000:Cooooo002;ooooo`;o00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0=ooooo`;o0000
2oooool2o`0009gooooo002Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`02ooooo`;o00003_ooool2o`0000Kooooo
0_l00006ooooo`;o0000UOooool0097ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool2o`0000kooooo0_l0000>ooooo`;o0000
5oooool2o`0007cooooo002Aooooo`06o`000?ooooooooooooooool0003ooooo0_l0000<ooooo`03
ogMgMolb<S;ooooo00Cooooo0ol0000Rooooo`;o00005oooool2o`0007cooooo002Aooooo`06o`00
0?ooooooooooooooool0003ooooo0_l00009ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`0/ooooo`;o0000Roooool0097ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0;?ooool2o`0000_ooooo0_l0001n
ooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01Oooool3
o`0003_ooooo0_l0001nooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo0_l00004
ooooo`Co00001?ooool3o`000;_ooooo002Looooo`;o00003_ooool00ol0003oooooooooo`0foooo
o`;o0000POooool008Kooooo0_l0000Tooooo`03o`000?oooooooooo00?ooooo0_l0000aooooo`;o
0000POooool008Kooooo0_l00005ooooo`;o00004Oooool2o`0000Cooooo0_l00004ooooo`03o`00
0?oooooooooo00?ooooo0_l0000aooooo`;o0000POooool008[ooooo0_l000001?oooooo0000o`00
0?ooool2o`0000kooooo1?l00002ooooo`;o00001?ooool3o`0001Gooooo0ol0002Qooooo`00R_oo
ool2o`0000Cooooo0_l0000@ooooo`;o00002?ooool01?l0003oooooooooooooool2o`0001;ooooo
0ol0000@ooooo`;o0000Soooool00:cooooo00Co0000oooooooooooooooo0_l00003ooooo`;o0000
3?ooool2o`0001;ooooo0_l0002?ooooo`00R_ooool2o`0001kooooo0ol00002ooooo`;o00001?oo
ool2o`0000cooooo0_l0000Aooooo`;o0000T?ooool008[ooooo0_l0000<ooooo`;o00000oooool2
o`0000_ooooo0ol00002ooooo`;o00009?ooool3o`00093ooooo002Hooooo`;o00000oooool2o`00
00gooooo00?o0000ooooooooool09_ooool2o`00097ooooo002Eooooo`;o00002Oooool2o`0000[o
oooo00?o0000ooooooooool06oooool2o`0001Cooooo0_l00026ooooo`00UOooool2o`0000Wooooo
0_l0000:ooooo`03o`000?oooooooooo01_ooooo0_l0000Dooooo`;o0000Q_ooool00:3ooooo0_l0
0009ooooo`Co0000?oooool2o`0007Sooooo002Cooooo`;o00002oooool2o`0000Wooooo0_l0000A
ooooo`;o0000;_ooool2o`0007Sooooo0020ooooo`;o00004Oooool2o`0000;ooooo0_l0000Coooo
o`03o`000?oooooooooo00oooooo0_l0000Booooo`;o0000U?ooool0083ooooo0_l0000Eooooo`;o
00004oooool00ol0003oooooooooo`0Sooooo`;o0000U?ooool00:Sooooo0_l00002ooooo`03o`00
0?oooooooooo01Oooooo0_l0000:ooooo`;o0000U?ooool00:Sooooo0_l00002ooooo`03o`000?oo
oooooooo00kooooo0_l00007ooooo`;o0000X?ooool00:cooooo00?o0000ooooooooool03_ooool2
o`0000Gooooo0_l0000Gooooo`;o0000ROooool0097ooooo0_l0000Iooooo`03o`000?oooooooooo
01Gooooo0_l0000Gooooo`;o0000ROooool0097ooooo0_l0000Iooooo`?o0000^Oooool00:cooooo
00?o0000ooooooooool02oooool2o`000:cooooo002/ooooo`03o`000?oooooooooo00_ooooo0_l0
002/ooooo`00[?ooool00ol0003oooooooooo`02ooooo`;o00003_ooool2o`000:Gooooo002/oooo
o`03o`000?oooooooooo00;ooooo0_l0000>ooooo`;o0000YOooool00:cooooo00Co0000oooooooo
oooooooo0_l0002fooooo`00Uoooool2o`0001?ooooo00Co0000oooooooooooooooo0_l0002foooo
o`00Uoooool2o`0001?ooooo00Co0000ooooool0003o00001oooool2o`0000Gooooo0_l0000;oooo
o`;o0000Voooool00:Gooooo0_l00005ooooo`04o`000?oooooo0000o`0000Oooooo0_l00005oooo
o`;o00002oooool2o`0009_ooooo002Uooooo`;o00001Oooool3o`000;Wooooo002/ooooo`?o0000
9Oooool2o`0009;ooooo002/ooooo`03o`000?oooooooooo02Gooooo0_l0002Booooo`00S?ooool2
o`0001kooooo00?o0000ooooooooool05_ooool2o`000:7ooooo002<ooooo`;o00007_ooool00ol0
003oooooooooo`0Fooooo`;o00002oooool2o`0009Cooooo0029ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@03ooooool0003o000000?ooooo00?o0000onk^k_ooool01?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool08oooool2o`0009Cooooo0029oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@03ooooool0003o000000?ooooo00?oEEEE
ojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;Wooooo0029oooo
o`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`03ooooo`;o00000oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05o`000?oooooooooo
ooooool000001?ooool2o`0000Sooooo00?o8B4Qooooooooool00_ooool2o`0000;ooooo00?oMgMg
oc8b<_ooool01?ooool3o`000;Wooooo0029ooooo`05o`000?ooooooooooooooool000001?ooool2
o`0000Sooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?l0003oc<c<00Gooooo00?o
0000ooooooooool0^Oooool008Wooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmg
MgOooooo00?ooooo00Co0000ooooool0003o00001_ooool00ol0003oooooooooo`2iooooo`00ROoo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0^Oooool008Wooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool07Oooool2o`0009[ooooo002/
ooooo`03o`000?oooooooooo01gooooo0_l0002Jooooo`00U_ooool2o`0001Cooooo0ol0002ioooo
o`00U_ooool2o`0000cooooo0_l00006ooooo`03o`000?oooooooooo0;Wooooo002<ooooo`;o0000
5_ooool2o`0000Kooooo00?o0000ooooooooool0:Oooool2o`0008kooooo002<ooooo`;o00007_oo
ool00ol0003oooooooooo`0;ooooo`;o00007?ooool2o`0008kooooo002Gooooo`;o00004oooool0
0ol0003oooooooooo`0;ooooo`;o0000[?ooool0097ooooo0_l00004ooooo`;o00004oooool00ol0
003oooooooooo`0:ooooo`;o0000[Oooool0097ooooo0_l0000Iooooo`03o`000?oooooooooo00[o
oooo0_l0000Iooooo`;o0000T_ooool00:cooooo00?o0000ooooooooool09Oooool2o`0009;ooooo
002/ooooo`?o00001oooool2o`000;3ooooo002Looooo`;o00003_ooool00ol0003oooooooooo`07
ooooo`;o0000/?ooool009cooooo0_l0000=ooooo`;o0000^oooool00:_ooooo0_l0002kooooo`00
Yoooool2o`0000?ooooo00?o0000ooooooooool01?ooool2o`000;?ooooo002Wooooo`;o00000ooo
ool00ol0003oooooooooo`04ooooo`;o0000/oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
0ol0002iooooo`00V?ooool2o`0001;ooooo00?o0000ooooooooool0^Oooool009Sooooo0_l0000B
ooooo`04o`000?oooooo0000o`000;Sooooo002Jooooo`;o00004?ooool01?l0003oooooo`000?l0
002hooooo`00V_ooool2o`00013ooooo0_l0002jooooo`00[?ooool2o`000;[ooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002Xooooo`;o00000_ooool00ol0003oooooooooo`2iooooo`00Z?oo
ool2o`0000;ooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool00ol0003oooooooooo`02o`000;Oooooo002Rooooo`Co000000?o410@
ooooooooool00oooool00ol0003oooooo`000002o`000;Oooooo002Tooooo`03o`000?oooooooooo
00Gooooo00Co0000ooooool0003o00003Oooool2o`000:Wooooo002Tooooo`03o`000?oooooooooo
00Gooooo0ol0000>ooooo`;o0000ZOooool00:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo
00?o0000ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo00?o0000
ooooooooool0`Oooool00:;ooooo00?oEEEEofIVI_l00000`oooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00:[ooooo00Co410@o`000?l0003o0000^_ooool0
0:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo
00Ko0000ogMgMol0003o0000oeEEEOo^k^jgooooo`00Zoooool01_l0003oEEEEonk^k_ooooooMgMg
oeEEEKOooooo002[ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0]Oooool00:_o
oooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`2eooooo`00Zoooool01_l0003oEEEE
onk^k_ooooooMgMgofIVI[Oooooo002Zooooo`03oa0@4?l0003oMgMg00;o000000?oIVIVonk^k_oo
ool0]_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.63535 .39793 Mdot
.53917 .84229 Mdot
.50414 .54325 Mdot
.54948 .45564 Mdot
.56473 .34734 Mdot
.4033 .71185 Mdot
.45242 .64103 Mdot
.36917 .36424 Mdot
.66736 .70872 Mdot
.55003 .6208 Mdot
.41131 .48712 Mdot
.42112 .07089 Mdot
.55718 .16464 Mdot
.42758 .6913 Mdot
.39541 .16788 Mdot
.41661 .54151 Mdot
.42396 .77005 Mdot
.576 .19273 Mdot
.50336 .77643 Mdot
.42282 .88532 Mdot
.54817 .1555 Mdot
.41392 .81025 Mdot
.39435 .69893 Mdot
.59572 .22662 Mdot
.59083 .12473 Mdot
.42787 .23766 Mdot
.4563 .22621 Mdot
.54285 .68612 Mdot
.38719 .72162 Mdot
.54378 .83306 Mdot
.57295 .19593 Mdot
.65682 .73763 Mdot
.42104 .92088 Mdot
.4531 .15565 Mdot
.61984 .43456 Mdot
.62117 .74001 Mdot
.62007 .21897 Mdot
.57397 .48512 Mdot
.38042 .64736 Mdot
.49276 .01045 Mdot
.62888 .17284 Mdot
.57293 .28172 Mdot
.5873 .70307 Mdot
.64999 .52227 Mdot
.61706 .32983 Mdot
.55341 .70097 Mdot
.49521 .7644 Mdot
.6997 .60686 Mdot
.60688 .48277 Mdot
.43394 .90672 Mdot
.70331 .57953 Mdot
.43932 .07404 Mdot
.73569 .28504 Mdot
.62275 .54642 Mdot
.60894 .64025 Mdot
.57779 .872 Mdot
.37111 .33918 Mdot
.4153 .73437 Mdot
.70112 .43194 Mdot
.59704 .28095 Mdot
.53552 .74137 Mdot
.72315 .66409 Mdot
.38203 .66301 Mdot
.53801 .58089 Mdot
.49457 .97093 Mdot
.61277 .82117 Mdot
.55986 .55971 Mdot
.46098 .75189 Mdot
.57406 .54389 Mdot
.62034 .27563 Mdot
.41221 .27148 Mdot
.51749 .57086 Mdot
.55178 .60885 Mdot
.5541 .41173 Mdot
.38249 .66801 Mdot
.46811 .35678 Mdot
.73591 .2856 Mdot
.48731 .82033 Mdot
.4011 .18901 Mdot
.54861 .27274 Mdot
.66827 .44418 Mdot
.56549 .7964 Mdot
.51992 .32779 Mdot
.5921 .3273 Mdot
.40433 .87175 Mdot
.43385 .30343 Mdot
.57513 .38373 Mdot
.58473 .44432 Mdot
.44865 .83497 Mdot
.45448 .74272 Mdot
.59189 .127 Mdot
.37363 .22828 Mdot
.42982 .63989 Mdot
.58512 .57983 Mdot
.47605 .74252 Mdot
.35824 .41792 Mdot
.44011 .73828 Mdot
.70403 .5532 Mdot
.75183 .32231 Mdot
.41585 .74142 Mdot
.64543 .46411 Mdot
.51161 .81803 Mdot
.39601 .16095 Mdot
.64525 .5761 Mdot
.66322 .40319 Mdot
.4916 .14825 Mdot
.43298 .19091 Mdot
.43424 .74691 Mdot
.42697 .62006 Mdot
.61719 .27057 Mdot
.49154 .77268 Mdot
.55043 .45835 Mdot
.66569 .71588 Mdot
.55782 .85625 Mdot
.74875 .71887 Mdot
.42839 .53233 Mdot
.50607 .79644 Mdot
.53695 .92942 Mdot
.59421 .85244 Mdot
.57223 .14963 Mdot
.54507 .14839 Mdot
.74322 .57078 Mdot
.42139 .15995 Mdot
.37644 .60249 Mdot
.62251 .28098 Mdot
.55115 .52644 Mdot
.52911 .89477 Mdot
.38387 .83218 Mdot
.63715 .60386 Mdot
.50581 .3346 Mdot
.38497 .59826 Mdot
.64608 .54209 Mdot
.47976 .0074 Mdot
.38847 .51473 Mdot
.53523 .80902 Mdot
.38568 .28335 Mdot
.62453 .22198 Mdot
.44459 .92638 Mdot
.55641 .58205 Mdot
.38816 .79075 Mdot
.42131 .07438 Mdot
.66555 .79274 Mdot
.48799 .25585 Mdot
.55419 .65434 Mdot
.4192 .75122 Mdot
.4856 .94537 Mdot
.45457 .97753 Mdot
.64454 .89826 Mdot
.46496 .79803 Mdot
.58894 .51233 Mdot
.74766 .54954 Mdot
.52986 .78768 Mdot
.56585 .40575 Mdot
.60981 .25147 Mdot
.52206 .50705 Mdot
.40112 .30177 Mdot
.55763 .12567 Mdot
.37646 .41039 Mdot
.55619 .90407 Mdot
.61075 .2048 Mdot
.57523 .14858 Mdot
.542 .25176 Mdot
.41369 .13655 Mdot
.65929 .21434 Mdot
.66101 .61923 Mdot
.60496 .64438 Mdot
.6344 .40124 Mdot
.47973 .98454 Mdot
.67401 .4732 Mdot
.57528 .50308 Mdot
.58591 .1614 Mdot
.52963 .89089 Mdot
.43618 .66833 Mdot
.55786 .37749 Mdot
.56225 .34312 Mdot
.41624 .65476 Mdot
.43851 .95436 Mdot
.35817 .57209 Mdot
.39262 .39082 Mdot
.45875 .69248 Mdot
.38789 .72396 Mdot
.53599 .09611 Mdot
.54715 .06714 Mdot
.51797 .29218 Mdot
.64685 .20008 Mdot
.51942 .6286 Mdot
.68245 .66155 Mdot
.40171 .90912 Mdot
.64942 .75722 Mdot
.63935 .18349 Mdot
.55279 .77899 Mdot
.74563 .48975 Mdot
.48136 .94738 Mdot
.53146 .39589 Mdot
.7377 .59462 Mdot
.373 .67778 Mdot
.71062 .32239 Mdot
.43088 .05 Mdot
.58994 .51671 Mdot
.53843 .21124 Mdot
.52394 .56326 Mdot
.51897 .59624 Mdot
.50586 .63071 Mdot
.53436 .27312 Mdot
.55525 .03158 Mdot
.64537 .47624 Mdot
.42491 .46873 Mdot
.38925 .53628 Mdot
.55304 .48363 Mdot
.43671 .64872 Mdot
.42121 .34272 Mdot
.44749 .09529 Mdot
.49947 .80595 Mdot
.67407 .4757 Mdot
.45444 .24929 Mdot
.63756 .41784 Mdot
.53761 .73243 Mdot
.66068 .21745 Mdot
.49612 .70261 Mdot
.53449 .17391 Mdot
.45702 .01107 Mdot
.51472 .78144 Mdot
.69706 .41971 Mdot
.67151 .44562 Mdot
.67201 .49636 Mdot
.41673 .52793 Mdot
.47826 .18799 Mdot
.55351 .82192 Mdot
.43435 .66143 Mdot
.40222 .13735 Mdot
.73672 .61827 Mdot
.46035 .75368 Mdot
.48066 .33749 Mdot
.5392 .01713 Mdot
.60048 .58143 Mdot
.47286 .21164 Mdot
.74565 .52072 Mdot
.56993 .43804 Mdot
.63603 .62741 Mdot
.44485 .10332 Mdot
.64724 .51862 Mdot
.72538 .65427 Mdot
.45589 .87333 Mdot
.66968 .59254 Mdot
.4104 .28199 Mdot
.63941 .77618 Mdot
.51359 .67677 Mdot
.49943 .05893 Mdot
.55904 .72077 Mdot
.4058 .31269 Mdot
.37609 .57123 Mdot
.6965 .29005 Mdot
.43122 .57645 Mdot
.51988 .35396 Mdot
.53 .09472 Mdot
.41675 .29095 Mdot
.54728 .34207 Mdot
.57061 .74787 Mdot
.48634 .36094 Mdot
.36645 .55824 Mdot
.70798 .53026 Mdot
.60589 .53949 Mdot
.472 .21175 Mdot
.67144 .54466 Mdot
.45164 .31606 Mdot
.55607 .73405 Mdot
.60573 .30676 Mdot
.48108 .77771 Mdot
.50332 .85605 Mdot
.59013 .79959 Mdot
.46268 .16995 Mdot
.58178 .8168 Mdot
.59272 .69315 Mdot
.54572 .64048 Mdot
.59373 .40013 Mdot
.55742 .12471 Mdot
.53919 .3482 Mdot
.43097 .2577 Mdot
.69836 .60842 Mdot
.42015 .34828 Mdot
.39644 .34003 Mdot
.37409 .50982 Mdot
.53499 .47225 Mdot
.5105 .2786 Mdot
.60361 .19417 Mdot
.38006 .25661 Mdot
.42199 .69638 Mdot
.48841 .32866 Mdot
.42065 .31341 Mdot
.59436 .79986 Mdot
.58335 .5857 Mdot
.65599 .38336 Mdot
.40896 .93225 Mdot
.68905 .3809 Mdot
.37188 .34599 Mdot
.68189 .36072 Mdot
.50533 .60791 Mdot
.69173 .383 Mdot
.74263 .51794 Mdot
.62974 .73045 Mdot
.38273 .24266 Mdot
.56894 .98736 Mdot
.58722 .37074 Mdot
.5013 .86471 Mdot
.64265 .58133 Mdot
.6459 .76238 Mdot
.59371 .12657 Mdot
.45815 .77126 Mdot
.70159 .58468 Mdot
.44084 .20142 Mdot
.51295 .38378 Mdot
.42054 .1567 Mdot
.4018 .63805 Mdot
.50879 .10237 Mdot
.74847 .50824 Mdot
.42836 .47081 Mdot
.562 .21809 Mdot
.52027 .18748 Mdot
.45418 .97114 Mdot
.47837 .28635 Mdot
.55216 .07334 Mdot
.72079 .36617 Mdot
.59214 .90585 Mdot
.52057 .68252 Mdot
.39082 .40172 Mdot
.60324 .35914 Mdot
.37705 .40392 Mdot
.51045 .22388 Mdot
.52572 .55453 Mdot
.48312 .66839 Mdot
.4062 .31311 Mdot
.41286 .09119 Mdot
.49882 .06002 Mdot
.47496 .74322 Mdot
.38714 .35438 Mdot
.52283 .39422 Mdot
.50469 .63489 Mdot
.5461 .83335 Mdot
.4134 .76792 Mdot
.60327 .65076 Mdot
.53931 .24686 Mdot
.51117 .22838 Mdot
.71243 .23743 Mdot
.42131 .26918 Mdot
.60423 .71555 Mdot
.54006 .56201 Mdot
.50287 .96508 Mdot
.4325 .28767 Mdot
.47268 .94617 Mdot
.53081 .85006 Mdot
.43856 .31098 Mdot
.57911 .60102 Mdot
.66642 .79181 Mdot
.42196 .06795 Mdot
.69578 .3953 Mdot
.60157 .78031 Mdot
.57928 .34232 Mdot
.50051 .15476 Mdot
.53804 .88028 Mdot
.58307 .66142 Mdot
.41638 .08312 Mdot
.54902 .9595 Mdot
.66598 .61315 Mdot
.46461 .00992 Mdot
.56369 .08677 Mdot
.66392 .22537 Mdot
.45825 .67545 Mdot
.60569 .5205 Mdot
.41996 .07839 Mdot
.36573 .45984 Mdot
.44433 .634 Mdot
.63954 .32873 Mdot
.40604 .382 Mdot
.39042 .41772 Mdot
.64271 .44035 Mdot
.69985 .58822 Mdot
.6385 .61539 Mdot
.6578 .29096 Mdot
.4215 .1189 Mdot
.40947 .78796 Mdot
.68607 .35816 Mdot
.39645 .71706 Mdot
.54655 .07137 Mdot
.7122 .79625 Mdot
.60513 .19864 Mdot
.43545 .15453 Mdot
.51191 .40606 Mdot
.69626 .29712 Mdot
.45404 .84316 Mdot
.49395 .64914 Mdot
.57354 .09681 Mdot
.62517 .28619 Mdot
.52633 .55104 Mdot
.56074 .46017 Mdot
.40388 .59557 Mdot
.49842 .23031 Mdot
.6916 .64461 Mdot
.67754 .5111 Mdot
.74061 .56695 Mdot
.56012 .08182 Mdot
.41207 .2789 Mdot
.67087 .17316 Mdot
.45718 .14804 Mdot
.41947 .67733 Mdot
.41168 .37604 Mdot
.44231 .56554 Mdot
.38934 .19016 Mdot
.41129 .09933 Mdot
.44976 .23708 Mdot
.42236 .42651 Mdot
.52943 .28864 Mdot
.47431 .22939 Mdot
.73816 .4176 Mdot
.58709 .56948 Mdot
.65889 .63222 Mdot
.49487 .26651 Mdot
.56675 .4118 Mdot
.48481 .29088 Mdot
.58962 .4767 Mdot
.42426 .22463 Mdot
.53483 .30405 Mdot
.43237 .37624 Mdot
.74558 .55889 Mdot
.38957 .79932 Mdot
.44726 .50731 Mdot
.62454 .47749 Mdot
.43218 .19329 Mdot
.43283 .16381 Mdot
.42458 .25721 Mdot
.56979 .43417 Mdot
.70902 .32604 Mdot
.39743 .09648 Mdot
.63104 .64398 Mdot
.78237 .60111 Mdot
.64642 .57491 Mdot
.47664 .2693 Mdot
.66016 .72283 Mdot
.43285 .04948 Mdot
.41197 .46228 Mdot
.54052 .83446 Mdot
.71845 .24913 Mdot
.42823 .36881 Mdot
.52374 .43587 Mdot
.40741 .54368 Mdot
.67179 .54832 Mdot
.52526 .22652 Mdot
.48406 .71921 Mdot
.62025 .44956 Mdot
.57658 .28807 Mdot
.50242 .70924 Mdot
.43032 .55966 Mdot
.55385 .40618 Mdot
.36872 .37266 Mdot
.45244 .31159 Mdot
.38857 .26229 Mdot
.57895 .77585 Mdot
.59857 .28687 Mdot
.55591 .85752 Mdot
.63566 .3205 Mdot
.39704 .42237 Mdot
.36967 .73889 Mdot
.56281 .49455 Mdot
.42384 .06129 Mdot
.70003 .29678 Mdot
.4866 .77332 Mdot
.69423 .39106 Mdot
.44156 .2026 Mdot
.48794 .84493 Mdot
.47607 .94641 Mdot
.64694 .47835 Mdot
.48602 .79986 Mdot
.57638 .61539 Mdot
.461 .14646 Mdot
.71506 .69491 Mdot
.55946 .76328 Mdot
.46569 .35836 Mdot
.60895 .63177 Mdot
.56411 .30713 Mdot
.45821 .67642 Mdot
.5147 .69686 Mdot
.62364 .53659 Mdot
.53389 .81262 Mdot
.4751 .70624 Mdot
.40087 .49321 Mdot
.60881 .82744 Mdot
.56349 .34201 Mdot
.582 .2554 Mdot
.55916 .6394 Mdot
.55673 .63785 Mdot
.43579 .41563 Mdot
.75518 .70481 Mdot
.44102 .37846 Mdot
.54279 .83761 Mdot
.69154 .40012 Mdot
.65517 .6453 Mdot
.56945 .58428 Mdot
.41736 .86678 Mdot
.5038 .02145 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool3o`0000Gooooo00?o0000ooooooooool0^Oooool00:3ooooo0_l0
0002ooooo`?o00000_ooool2o`000003ooooool0003ooooo0;[ooooo002Mooooo`;o000000?ooooo
o`000?l000000_ooool00ol0003oooooooooo`02ooooo`;o000000?oooooo`000?ooool0^_ooool0
09gooooo0_l00003ooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool02_ooool2o`000:gooooo002/ooooo`?o00002_ooool2o`000:gooooo
002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool03oooool2o`000:Sooooo002/ooooo`03o`000?oooooooooo00oooooo0_l0002Xooooo`00
[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00UOooool2o`0001Go
oooo00?o0000ooooooooool0^Oooool009Gooooo0_l0000Eooooo`?o0000^Oooool00:cooooo00?o
0000ooooooooool0^Oooool00:_ooooo0_l0002kooooo`00T_ooool2o`0001Oooooo0_l0002koooo
o`00T_ooool2o`0001Oooooo0_l0002kooooo`00T_ooool2o`0001Sooooo00?o0000ooooooooool0
3?ooool2o`000:_ooooo002Booooo`;o00006?ooool00ol0003oooooooooo`0<ooooo`;o0000Zooo
ool009;ooooo0_l00004ooooo`;o00004_ooool00ol0003oooooooooo`0<ooooo`Co0000ZOooool0
09;ooooo0_l00004ooooo`;o00004_ooool3o`0000kooooo0_l0002Yooooo`00TOooool2o`0001Wo
oooo00?o0000ooooooooool0^Oooool0093ooooo0ol0000Iooooo`03o`000?oooooooooo013ooooo
0_l0002Wooooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool04?ooool2o`000:Oooooo002/
ooooo`03o`000?oooooooooo01;ooooo0_l0002Uooooo`00Soooool2o`0001_ooooo00?o0000oooo
ooooool04_ooool2o`000:Gooooo002?ooooo`;o00002Oooool2o`00013ooooo00?o0000oooooooo
ool01_ooool2o`000;7ooooo002:ooooo`;o00003_ooool2o`00013ooooo00?o0000ooooooooool0
1_ooool4o`0000_ooooo0_l0002Rooooo`00R_ooool2o`0000;ooooo0_l0000Looooo`?o00002?oo
ool2o`0000_ooooo0_l0002Rooooo`00S_ooool2o`0000Wooooo0_l0000Aooooo`04o`000?oooooo
0000o`000;Sooooo002Iooooo`;o00004Oooool01?l0003oooooo`000?l0002hooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo0_l000000olQ8B7o
ooooooooo`04ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0;Wooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool2o`00
0003ob4Q8Ooooooooooo00Cooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo0;Wooooo0021ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@
00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o00004?ooool2o`00
00Wooooo0_l0002Looooo`00ROooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qoooo
ooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo013ooooo0_l00009oooo
o`;o0000W?ooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo01_ooooo0_l0002L
ooooo`00ROooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`06ogMgMonHV9So0000
o`000?mgMgOooooo0_l00008ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`06onk^k_lb<S;o0000o`000?o^k^ko
oooo0_l00008ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool0^Oooool00:cooooo
00?o0000ooooooooool0^Oooool009oooooo0_l0000;ooooo`03o`000?oooooooooo0;Wooooo002M
ooooo`Co00002?ooool2o`000003ooooool0003ooooo00cooooo0_l00007ooooo`?o0000X_ooool0
09gooooo0_l0000:ooooo`;o000000Coooooo`000?l0003o00002oooool2o`0000Oooooo0ol0002R
ooooo`00U_ooool2o`0000Cooooo0_l0000>ooooo`;o00003Oooool2o`000:_ooooo002Aooooo`;o
00000oooool2o`0000Cooooo0_l0000>ooooo`;o00003Oooool2o`000:_ooooo0029ooooo`;o0000
1_ooool3o`0001Sooooo00?o0000ooooooooool06Oooool2o`0009kooooo0029ooooo`;o00001ooo
ool2o`000003ooooool0003o000001Gooooo00?o0000ooooooooool03oooool2o`0000Sooooo0_l0
002Nooooo`00ROooool2o`0000[ooooo0_l0000Eooooo`03o`000?oooooooooo00oooooo0_l0002X
ooooo`00ROooool2o`0001Cooooo0_l0000;ooooo`03o`000?oooooooooo0;Wooooo002Oooooo`;o
00002oooool00ol0003oooooooooo`08ooooo`;o00007Oooool2o`0000cooooo0_l00022ooooo`00
[?ooool3o`0000Sooooo0_l0000Mooooo`;o00003?ooool2o`0008;ooooo002/ooooo`03o`000?oo
oooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo
02_ooooo0_l0002<ooooo`00Roooool2o`0001Oooooo0_l00006ooooo`03o`000?oooooooooo00?o
oooo0_l0000Vooooo`;o0000S?ooool008Oooooo0_l00002ooooo`;o00002?ooool2o`0000gooooo
0_l00006ooooo`03o`000?oooooooooo00?ooooo0_l0002dooooo`00Qoooool2o`0000cooooo0_l0
000Eooooo`03o`000?oooooooooo01Kooooo0_l00007ooooo`;o0000V?ooool009Gooooo0_l0000E
ooooo`03o`000?oooooooooo01Gooooo0ol00007ooooo`;o0000V?ooool009Sooooo0_l0000Boooo
o`?o00005Oooool2o`0000Sooooo0_l0000<ooooo`;o0000R_ooool009Sooooo0_l0000Booooo`03
o`000?oooooooooo01oooooo0_l0000<ooooo`;o0000R_ooool009Sooooo0_l0000Booooo`03o`00
0?oooooooooo027ooooo0_l0002Fooooo`00[?ooool00ol0003oooooooooo`0Qooooo`;o0000U_oo
ool00:;ooooo0ol00007ooooo`03o`000?oooooooooo00Wooooo0_l0002^ooooo`00X_ooool3o`00
00Oooooo00?o0000ooooooooool02Oooool2o`0002Kooooo0_l00026ooooo`00[?ooool00ol0003o
ooooooooo`0Aooooo`;o00004Oooool2o`0000_ooooo0ol00025ooooo`00[?ooool00ol0003ooooo
ooooo`0Aooooo`;o00004Oooool4o`0000[ooooo0_l00025ooooo`00Toooool2o`0001Oooooo1Ol0
000Tooooo`;o00002oooool2o`0008Cooooo0022ooooo`;o00003oooool2o`0000Sooooo0_l0000=
ooooo`03o`000?oooooooooo00;o00000oooool2o`0001Gooooo0_l0000Eooooo`;o0000Q?ooool0
08;ooooo0_l0000Iooooo`;o00001?ooool2o`0000Kooooo0_l00002ooooo`;o00000oooool2o`00
01Gooooo0_l0002Kooooo`00Xoooool2o`0000Kooooo0_l0002kooooo`00U?ooool2o`0000Gooooo
0_l0000?ooooo`03o`000?oooooooooo04?ooooo0_l0001dooooo`00U?ooool2o`0000Gooooo0_l0
000?ooooo`03o`000?oooooooooo04?ooooo0_l0001dooooo`00QOooool2o`0000[ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo
00?o0000ooooooooool0^Oooool008Gooooo0_l0000:ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0:ooooo`;o0000
[Oooool008Wooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41001oooool2o`0000Oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`;o0000>Oooool2o`0007;ooooo
002Aooooo`05o`000?ooooooooooooooool000001oooool2o`0000Kooooo00?oMgMgoc8b<_ooool0
1?ooool3o`0000[ooooo0_l0000Eooooo`;o00008_ooool2o`0007;ooooo002Aooooo`05o`000?oo
ooooooooooooool000003?ooool01_l0003o8B4Qo`000?lb<S;oc<c<ooooo`;o00000_ooool00ol0
003oooooooooo`0:ooooo`;o00003?ooool2o`0000Oooooo0_l0002Fooooo`00Q?ooool2o`0000_o
oooo00?o410@ooooool000000ol0000;ooooo`03o`000?oooooooooo00?ooooo0_l00002ooooo`03
o`000?oooooooooo01Sooooo0_l0002Oooooo`00Q?ooool2o`0000_ooooo00?oMgMgoiRHV?l00000
0ol0000;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0^Oooool008Oooooo0_l0
0008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0
^Oooool008Oooooo0_l0000Qooooo`?o0000^oooool009;ooooo0_l0000@ooooo`;o00001?ooool3
o`0002Gooooo0_l0002Dooooo`00Soooool2o`000003ooooool0003o0000013ooooo0_l00006oooo
o`03o`000?oooooooooo00Sooooo0_l00003ooooo`;o00005?ooool2o`0009Cooooo002?ooooo`;o
00006oooool3o`0000Sooooo0_l00003ooooo`;o00005Oooool2o`0009?ooooo002?ooooo`;o0000
6oooool00ol0003oooooooooo`02o`0002;ooooo0_l0002Cooooo`00Q_ooool2o`0000Kooooo0ol0
000Kooooo`03o`000?oooooooooo00;o00004oooool2o`0000Kooooo0_l00006ooooo`;o0000T_oo
ool008Kooooo0_l00006ooooo`;o00005?ooool2o`0000Kooooo00?o0000ooooooooool05Oooool2
o`0000Kooooo0_l00006ooooo`?o00008_ooool2o`0006gooooo002Eooooo`;o00003Oooool2o`00
00Kooooo00?o0000ooooooooool01_ooool2o`0000kooooo0_l00005ooooo`;o00001oooool2o`00
02;ooooo0_l0001]ooooo`00T?ooool2o`0000?ooooo0_l0000@ooooo`;o00000oooool00ol0003o
ooooooooo`02ooooo`;o00000_ooool2o`0000kooooo0_l00005ooooo`;o00004_ooool2o`0000[o
oooo0_l0001jooooo`00T?ooool2o`0001Gooooo0_l00003ooooo`03o`000?oooooooooo00;ooooo
0_l0000]ooooo`;o00002_ooool2o`0007[ooooo002/ooooo`03o`000?oooooooooo03gooooo1?l0
001hooooo`00[?ooool3o`0003gooooo1?l0001hooooo`00Roooool2o`0000Wooooo0_l0000Doooo
o`03o`000?oooooooooo00Sooooo0_l0002_ooooo`00Roooool2o`0000Wooooo0_l0000Dooooo`03
o`000?oooooooooo00Sooooo0_l00008ooooo`;o00002oooool2o`0009Sooooo002/ooooo`03o`00
0?oooooooooo01;ooooo0_l0000;ooooo`;o0000V?ooool008cooooo0ol00002ooooo`;o00001?oo
ool2o`0000?ooooo0_l0000>ooooo`03o`000?oooooooooo0;Wooooo002<ooooo`?o00000_ooool2
o`0000Cooooo0_l00003ooooo`;o00003_ooool00ol0003oooooooooo`2iooooo`00W?ooool2o`00
00kooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0:Oooool2o`0001Oo
oooo0_l0000<ooooo`;o0000Ioooool00:cooooo0ol0000Yooooo`;o00005oooool2o`0000cooooo
0_l0001Wooooo`00Z?ooool2o`0000;ooooo00?o0000ooooooooool00oooool2o`0001Kooooo0_l0
000>ooooo`;o00005Oooool2o`0007Gooooo002Xooooo`;o00000_ooool00ol0003oooooooooo`03
ooooo`;o00005_ooool2o`0000Kooooo0_l00006ooooo`;o00005Oooool2o`0007Gooooo002/oooo
o`?o00008oooool2o`0009Cooooo002Uooooo`;o00001Oooool3o`000;Wooooo0021ooooo`;o0000
1_ooool2o`0001[ooooo0_l00005ooooo`03o`000?oooooooooo0;Wooooo0021ooooo`;o00001_oo
ool2o`0000Oooooo0_l0000Hooooo`03o`000?oooooooooo00cooooo0_l00003ooooo`?o00000ooo
ool2o`000:3ooooo0021ooooo`;o00003oooool2o`0001Sooooo00?o0000ooooooooool03?ooool2
o`0000?ooooo0ol00003ooooo`;o0000X?ooool0087ooooo0_l0000>ooooo`;o00006Oooool00ol0
003oooooooooo`0:ooooo`;o00001_ooool2o`000:Gooooo002Aooooo`;o00006Oooool3o`0000[o
oooo0_l00006ooooo`;o0000YOooool008Kooooo0_l0000Tooooo`03o`000?oooooooooo00?ooooo
0_l0002dooooo`00Q_ooool2o`0001Sooooo0ol00009ooooo`03o`000?oooooooooo00?ooooo0_l0
000Jooooo`;o00006Oooool2o`0007gooooo002Pooooo`?o00001?ooool2o`0000?ooooo00?o0000
ooooooooool07oooool2o`0001Sooooo0ol0001mooooo`00P?ooool2o`0002Gooooo0_l00003oooo
o`03o`000?oooooooooo03Wooooo0_l0001nooooo`00P?ooool2o`0000Oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo04Gooooo0_l0001booooo`00ROooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo00?o8B4Qo`000?l000000oooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Iooooo`;o0000:_ooool2o`0007;ooooo0020
ooooo`Oo00000_ooool01Ol@413ooooooooooooooooo410@00Kooooo0_l00004ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Iooooo`;o0000W_oo
ool0083ooooo0_l00007ooooo`04o`000?ooooooooooooooo`?o00001Oooool2o`0000Cooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000^Oooool008Wooooo00Co0000
oooooooooooooooo0ol00005ooooo`;o000000?oooooo`000?l000000_ooool00omgMgOoIVIVoooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0@ooooo`;o0000
Yoooool008Wooooo00Co410@oooooooooooooooo0_l00009ooooo`;o00000oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04?ooool2o`0001kooooo
0_l00009ooooo`?o0000Noooool008Wooooo00CoMgMgoiRHV?ooooooV9RH0_l0000:ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooooooo
o`;o00004_ooool2o`0001Wooooo0_l00009ooooo`?o0000Noooool008Wooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00Co0000
oooooooooooooooo0_l0000Booooo`;o0000X_ooool008Sooooo0_l0000Rooooo`03o`000?oooooo
oooo03gooooo0_l0001jooooo`00R?ooool2o`0002;ooooo00?o0000ooooooooool01?ooool2o`00
03Oooooo0_l0001jooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o000000?oooooo`000?l0
00008?ooool2o`0001;ooooo0_l0001jooooo`00[?ooool3o`0000Oooooo0_l0000Cooooo`;o0000
2oooool2o`00017ooooo0_l0001kooooo`00Poooool2o`0000?ooooo0_l0000Rooooo`03o`000?oo
oooooooo01cooooo0_l0000;ooooo`;o00001oooool2o`0000Sooooo0_l0001kooooo`00Poooool2
o`0000?ooooo0_l0000Rooooo`03o`000?oooooooooo00;o00003?ooool2o`0000;ooooo0_l0000N
ooooo`;o0000QOooool008?ooooo0_l0000Wooooo`03o`000?oooooooooo00;o00003?ooool2o`00
00;ooooo0_l0002Uooooo`00Poooool2o`0002Oooooo00?o0000ooooooooool03_ooool2o`0000?o
oooo0_l0002Tooooo`00U_ooool2o`0001Cooooo00?o0000ooooooooool03_ooool2o`0000?ooooo
0_l0002Tooooo`00OOooool2o`0000Sooooo0_l0000=ooooo`;o00005?ooool00ol0003ooooooooo
o`0Zooooo`;o00004_ooool2o`0000_ooooo0_l0001/ooooo`00OOooool2o`0000Sooooo0_l00000
0ooooooo0000o`00000Pooooo`03o`000?oooooooooo02[ooooo0_l0000Booooo`;o00002oooool2
o`0006cooooo002:ooooo`;o00008?ooool3o`000;Wooooo002Booooo`;o00006?ooool00ol0003o
ooooooooo`2iooooo`00T_ooool2o`0001Sooooo00?o0000ooooooooool0^Oooool00:cooooo00?o
0000ooooooooool05?ooool2o`0000kooooo0_l0000Iooooo`;o0000N?ooool00:cooooo00?o0000
ooooooooool01?ooool2o`0000kooooo0_l0000>ooooo`;o00006Oooool2o`0007Sooooo002/oooo
o`03o`000?oooooooooo00Cooooo0_l0000>ooooo`;o00005_ooool2o`0008_ooooo002/ooooo`03
o`000?oooooooooo01Cooooo0_l0000Fooooo`;o0000Roooool00:cooooo00?o0000ooooooooool0
6Oooool2o`0001Wooooo0ol00022ooooo`00[?ooool00ol0003oooooooooo`0Iooooo`;o00002Ooo
ool2o`0000kooooo0ol00022ooooo`00[?ooool3o`0002Cooooo0_l0002Cooooo`00[?ooool00ol0
003oooooooooo`0=ooooo`;o0000Z_ooool00:cooooo00?o0000ooooooooool03Oooool2o`000:[o
oooo0009ooooo`Co000000?o410@ooooooooool05_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0?oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool2o`000003oooooolQ8B7o8B4Q00Cooooo
1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd05_ooool00ol0003oooooooooo`0=ooooo`;o
00000_ooool2o`0000Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`00
00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM
01Sooooo1?l000000ol@413oooooooooo`0Booooo`002oooool00ol0003oooooooooo`0Hooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omg
MgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo0_l000000ooooooo8B4Qob4Q
8@04ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00_ooool2o`0000?ooooo00?oMgMgoc8b<_ooool0
5Oooool00ol0003oooooooooo`0Aooooo`;o00001Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00_l00005ooooo`03ogMgMolb<S;ooooo
00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01ooo
ool00omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo0006o`0000Gooooo00?o0000
ooooooooool04?ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmE
EEGooooo00Sooooo00?o0000ooooooooool01Oooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400@ooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@
41003?ooool00onHV9So8B4Qonk^kP03ooooo`;o00001?ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo01Sooooo00Go410@oooooooooooooooooa0@400<ooooo`04oiRHV?lQ8B7ok^k^
ooooo`;o00001_ooool00ol0003oooooooooo`0=ooooo`05oa0@4?ooooooooooooooool@41004?oo
ool00ol0003oooooooooo`0=ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEE
ooooo`08ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05?ooool000_ooooo00?o
0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool0
1_ooool00omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo
<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06oooo
o`?o00005_ooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000003Oooool0
0onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00
000?ooooo`03ogMgMolb<S;ooooo00kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q
8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool06Oooool00ol0003oooooooooo`0Dooooo`002ooo
ool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<
ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo0000
00cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003_oo
ool00omgMgOoIVIVooooo`03ooooo`03o`000?lQ8B7o000000;o00005_ooool00ol0003ooooooooo
o`08ooooo`;o00003_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool0
0oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;o00003Oooool01Ol0003ooooooooooooooooo0000
00cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003_oo
ool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06_ooool00ol0003ooooo
ooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05oa0@4?ooooooooooooooool@4100
3_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06?ooool3o`0000Sooooo0_l0000>oooo
o`05oa0@4?oooooo0000o`000?l@41003oooool3o`0000;ooooo00?o0000ooooooooool00_ooool2
o`0000gooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo017ooooo00Go
410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Dooooo`002oooool00ol0003oooooooooo`0Hooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000oooooooo
ool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHo`000?l0003oMgMg00Wooooo
0ol000001?nj^[[ooooooiRHV?l@4102o`0000;ooooo00?o0000ooooooooool00_ooool2o`0000go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo01Cooooo0009ooooo`03oeEEEOmVIVKo000001[ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c004ooooo`Co00005oooool00ol0003oooooooooo`0Hooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool2o`0000Cooooo0_l000001OnHV9So410@o`000?lQ8B7oc<c<00;o00000_oo
ool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00004?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00006Oooool00omEEEGoIVIVo`00000Fooooo`00
[?ooool00ol0003oooooooooo`0>ooooo`;o00001Oooool2o`0000Wooooo0_l0002Gooooo`00S_oo
ool2o`0001cooooo00?o0000ooooooooool03_ooool2o`0000Gooooo0_l0002Rooooo`00S_ooool2
o`0001cooooo00?o0000ooooooooool0C_ooool2o`0005kooooo0_l00002ooooo`;o00001Oooool0
08_ooooo0_l0000Oooooo`03o`000?oooooooooo017ooooo0_l0000kooooo`;o0000G_ooool01_o^
k^ko8B4QohN7Qonj^[[o0000omgMg@Gooooo002;ooooo`;o00007oooool00ol0003oooooooooo`0A
ooooo`;o00008_ooool2o`0007Sooooo00CogMgMo`000?l@413oc<c<1_ooool000Ooooooool0001<
o`0000cooooo00Cok^k^ob4Q8Ol@413ok^k^1_ooool000Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`04ooooo`;o00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00[ooooo00Co8B4QogMgMomgMgOo<S8b1_ooool000Oooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool05?ooool2
o`00013ooooo00?o0000ooooooooool01?ooool2o`0000oooooo0_l0000@ooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo00Wooooo0_l00002ooooo`;o00001Oooool008;ooooo0_l0000Fooooo`;o00004?ooool00ol0
003oooooooooo`04ooooo`;o0000BOooool2o`0006Sooooo0022ooooo`;o0000:?ooool00ol0003o
ooooooooo`0Jooooo`;o00006oooool2o`0001Kooooo0_l0001Xooooo`00Qoooool2o`0002?ooooo
00?o0000ooooooooool06_ooool2o`0001_ooooo0_l00020ooooo`00Qoooool2o`0002?ooooo00?o
0000ooooooooool06_ooool2o`00017ooooo0_l0000Nooooo`;o0000J_ooool00:cooooo00?o0000
ooooooooool06_ooool2o`0000?ooooo0_l0000<ooooo`?o00007Oooool3o`0006Wooooo002/oooo
o`?o00007oooool2o`0000gooooo0_l0000Nooooo`;o0000JOooool0093ooooo0_l0000Jooooo`03
o`000?oooooooooo00gooooo0_l0002Zooooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool0
3Oooool2o`0003;ooooo0_l0001fooooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool0@Ooo
ool2o`0007Kooooo0027ooooo`;o00002oooool2o`0001Kooooo00?o0000ooooooooool09Oooool2
o`0009;ooooo0027ooooo`;o00008oooool00ol0003oooooooooo`0Pooooo`;o00000oooool2o`00
09;ooooo002=ooooo`;o000000?oooooo`000?l000006_ooool3o`0001Gooooo0_l00009ooooo`;o
00002oooool2o`0008[ooooo002=ooooo`;o000000?oooooo`000?l000006_ooool3o`0001Gooooo
0_l0000>ooooo`;o00001_ooool2o`0000Kooooo0_l00022ooooo`00[?ooool00ol0003ooooooooo
o`0Uooooo`;o00003_ooool2o`0001Oooooo0_l0001Yooooo`00[?ooool3o`0000Gooooo0_l0000^
ooooo`;o00005oooool2o`0006Wooooo002/ooooo`03o`000?oooooooooo00Gooooo0_l0000ioooo
o`;o0000Moooool007oooooo0_l0000[ooooo`03o`000?oooooooooo00Gooooo0_l0000iooooo`;o
00003?ooool2o`0006Wooooo001oooooo`;o00005?ooool2o`0001Gooooo00?o0000ooooooooool0
2_ooool2o`0000Cooooo0_l0000looooo`;o0000JOooool009Gooooo0_l0000Eooooo`03o`000?oo
oooooooo00Cooooo0_l00004ooooo`;o00001?ooool2o`000:Oooooo002Iooooo`;o00004Oooool0
0ol0003oooooooooo`04ooooo`;o0000A_ooool2o`0006_ooooo002Iooooo`;o00004Oooool00ol0
003oooooooooo`02ooooo`;o00005Oooool2o`00037ooooo0ol0001Zooooo`00OOooool2o`0000Co
oooo0_l0000Wooooo`03o`000?oooooooooo00;ooooo0_l0000Eooooo`;o0000<_ooool2o`0006[o
oooo001mooooo`;o00001?ooool2o`00013ooooo0_l0000Eooooo`?o0000;Oooool2o`0008[ooooo
002Eooooo`;o00005Oooool00ol0003oooooooooo`0Iooooo`;o00004_ooool2o`00017ooooo0_l0
001gooooo`00[?ooool00ol0003oooooooooo`09ooooo`;o00001?ooool2o`0000Sooooo0_l00003
ooooo`;o00003?ooool2o`0001;ooooo0_l0001gooooo`00[?ooool00ol0003oooooooooo`09oooo
o`;o00001?ooool2o`0000;ooooo0_l00003ooooo`;o00001?ooool2o`0000cooooo0_l0000Aoooo
o`;o0000N?ooool00:cooooo00?o0000ooooooooool04oooool2o`0000?ooooo0_l0000Uooooo`;o
0000N?ooool00:cooooo00?o0000ooooooooool0?oooool2o`0007Sooooo002/ooooo`03o`000?oo
oooooooo03Gooooo0_l0000Dooooo`;o0000K?ooool008Kooooo0_l00004ooooo`;o00007_ooool0
0ol0003oooooooooo`03ooooo`;o0000<?ooool2o`0001Cooooo0_l0001/ooooo`00Q_ooool2o`00
00Cooooo0_l0000Nooooo`?o00000oooool2o`0001;ooooo0_l00011ooooo`;o0000GOooool008?o
oooo0_l0000Wooooo`03o`000?oooooooooo01Oooooo0_l0000Aooooo`;o0000;_ooool2o`0005go
oooo0023ooooo`;o00009oooool00ol0003oooooooooo`0Zooooo`;o00004_ooool2o`0007Wooooo
002/ooooo`?o00003_ooool2o`0002kooooo0_l0001iooooo`00[?ooool3o`0000kooooo0_l0000S
ooooo`;o00002Oooool2o`0007Wooooo002/ooooo`03o`000?oooooooooo01Kooooo0_l0000Boooo
o`;o00001oooool2o`0008Cooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0F
ooooo`;o00004_ooool2o`0000Kooooo0_l0000Gooooo`;o0000K?ooool008Wooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o00001?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0=ooooo`;o00008oooool2o`0001Oooooo0_l0
001/ooooo`00ROooool01Ol@413ooooooooooooooooo410@00Gooooo0_l00005ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`0000gooooo0_l0002Zooooo`00ROooool0
1Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo00?ooooo0_l0000Tooooo`;o0000S_ooool008Wooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`?o00000oooool2o`0001cooooo0_l00006ooooo`;o0000S_ooool008Wooooo00Go
410@oooooooooooooooooa0@400;ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Oooooo0ol0000Qooooo`;o00003_ooool2o`0008Kooooo0029ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool2o`000003oooooonHV9So410@00Cooooo00?o0000ooooooooool0
1oooool3o`00037ooooo0_l00026ooooo`00ROooool01Oo^k^ko<S8bo`000?l0003ok^k^00Kooooo
0_l00003ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0ol0000<ooooo`;o
000000Coooooo`000?l0003o00003oooool2o`0009Kooooo002;ooooo`;o00001oooool2o`0000Ko
oooo0_l0000>ooooo`03o`000?oooooooooo00cooooo0_l000001?oooooo0000o`000?l0000?oooo
o`;o0000U_ooool009cooooo0_l0000>ooooo`03o`000?oooooooooo01oooooo0_l00007ooooo`;o
00001_ooool2o`0000[ooooo0_l0001kooooo`00Q?ooool2o`00017ooooo0_l0000Aooooo`?o0000
8Oooool2o`0000Oooooo0_l00006ooooo`;o00002_ooool2o`0007_ooooo0024ooooo`;o00004Ooo
ool2o`00017ooooo1Ol0000Oooooo`;o0000V?ooool0093ooooo0_l0000Jooooo`03o`000?oooooo
oooo00kooooo0_l0000?ooooo`;o00009_ooool2o`00073ooooo002@ooooo`;o00006_ooool00ol0
003oooooooooo`0>ooooo`;o0000=oooool2o`00073ooooo002Fooooo`;o00005?ooool00ol0003o
ooooooooo`0Hooooo`;o00007oooool2o`0007kooooo0025ooooo`;o00003oooool2o`0001Cooooo
00?o0000ooooooooool06?ooool2o`0001oooooo0_l0000;ooooo`;o0000LOooool008Gooooo0_l0
000Uooooo`03o`000?oooooooooo04Kooooo0_l0001aooooo`00QOooool2o`0000oooooo0_l0000>
ooooo`;o00001?ooool00ol0003oooooooooo`2iooooo`00U_ooool2o`0000kooooo0_l00004oooo
o`03o`000?oooooooooo0;Wooooo002Nooooo`;o00003?ooool3o`000003ooooool0003o00000;Ko
oooo0022ooooo`;o00003Oooool2o`0000_ooooo0_l0000<ooooo`04o`000?ooooooooooooooo`;o
0000]_ooool008;ooooo0_l0000=ooooo`;o00006Oooool00ol0003oooooooooo`03ooooo`;o0000
]?ooool00:cooooo00?o0000ooooooooool00oooool2o`0000Kooooo0_l0002/ooooo`00[?ooool0
0ol0003oooooooooo`0;ooooo`;o0000[?ooool009Cooooo0_l0000Fooooo`03o`000?oooooooooo
0;Wooooo002Dooooo`;o00002?ooool2o`0000cooooo00?o0000ooooooooool06oooool2o`0002Oo
oooo0_l0001cooooo`00T_ooool2o`0000[ooooo0_l0000<ooooo`04o`000?ooooooooooooooo`;o
00006?ooool2o`0002Oooooo0_l0001cooooo`00ROooool2o`0000Oooooo0_l0000Hooooo`?o0000
00?oooooo`000?l000002oooool2o`000:Wooooo0029ooooo`;o00007oooool3o`00013ooooo0_l0
0009ooooo`;o0000W_ooool00:?ooooo0_l00005ooooo`?o00006oooool2o`0003Kooooo0_l0001V
ooooo`00Xoooool2o`0000Oooooo0_l0000eooooo`;o00006oooool2o`0006Kooooo002<ooooo`;o
00007_ooool2o`0003Gooooo0_l00023ooooo`00S?ooool2o`0001kooooo00?o0000ooooooooool0
7oooool2o`0001;ooooo0_l00024ooooo`00ROooool2o`0001_ooooo0_l00004ooooo`03o`000?oo
oooooooo01oooooo0_l0000Booooo`;o00006_ooool2o`0006Sooooo0026ooooo`;o000000?ooooo
o`000?l000006oooool2o`0000Cooooo00?o0000ooooooooool04?ooool2o`0003gooooo0_l0001X
ooooo`00Q_ooool3o`0002?ooooo0ol0000@ooooo`;o00007oooool2o`0008Kooooo0027ooooo`;o
00008oooool00ol0003oooooooooo`0aooooo`;o0000Q_ooool00:cooooo00?o0000ooooooooool0
9oooool2o`00093ooooo002@ooooo`;o00006_ooool00ol0003oooooooooo`09ooooo`;o00001?oo
ool2o`0001Kooooo0_l0002@ooooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool02Oooool2
o`0000Cooooo0_l0000Oooooo`;o0000Qoooool0087ooooo0_l0000Eooooo`;o00004_ooool00ol0
003oooooooooo`0Uooooo`;o00002Oooool2o`0008Oooooo0021ooooo`;o00003Oooool2o`000004
oc8b<_l0003o<S8bonk^kP;ooooo0_l000000ooooooo8B4Qob4Q8@02o`0000?ooooo00GoA4A4o`00
0?l0003o0000omgMg@05ooooo`03o`000?oooooooooo00Sooooo0_l0000Kooooo`;o0000T_ooool0
093ooooo0_l000001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q0_l00004ooooo`?o000000?o<S8b
ooooooooool00oooool00ol0003oooooooooo`08ooooo`;o0000[oooool0097ooooo00Go410@oooo
oooooooooooooa0@4002o`0000kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0D
ooooo`;o0000Xoooool0097ooooo0_l00002ooooo`?o00001oooool2o`0000Cooooo00?oMgMgoc8b
<_ooool01?ooool3o`0001Cooooo0_l0002Sooooo`00TOooool2o`0000;ooooo00?o0000oooooooo
ool01_ooool3o`000006ooooool0003o8B4Qo`000?lb<S;oc<c<1Oooool00ol0003oooooooooo`2i
ooooo`00TOooool01Ol@413ooooooooooooooooo410@00Sooooo0_l00002ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0;_ooool2o`0008Wooooo002Aooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02kooooo0_l00029
ooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00004ooooo`?o00004_ooool2
o`0001_ooooo0_l0002:ooooo`00Soooool2o`0001Wooooo0ol0000Booooo`;o00006oooool2o`00
08[ooooo002?ooooo`;o000000?oooooo`000?l000006?ooool00ol0003oooooooooo`2iooooo`00
T_ooool2o`0000[ooooo0_l00007ooooo`Co000000?oooooo`000?ooool0^_ooool009kooooo0_l0
0007ooooo`Co000000Coooooo`000?l0003o00005oooool2o`0001;ooooo0_l0002<ooooo`00YOoo
ool2o`0000Gooooo0ol0000>ooooo`;o00001oooool2o`0001;ooooo0_l0002<ooooo`00YOooool2
o`0000Gooooo00Co0000oooooooooooooooo0_l0000;ooooo`;o00003_ooool2o`0009Wooooo002/
ooooo`04o`000?ooooooooooooooo`;o00006oooool2o`0009Wooooo002>ooooo`;o00007?ooool0
0ol0003oooooooooo`06ooooo`;o0000/Oooool008Oooooo0_l00005ooooo`;o00007?ooool00ol0
003oooooooooo`06ooooo`;o0000;?ooool2o`0008?ooooo0027ooooo`;o00008oooool00ol0003o
ooooooooo`0cooooo`?o0000Poooool00:3ooooo0_l0000:ooooo`04o`000?oooooo0000o`00017o
oooo0_l0000Oooooo`;o00003_ooool2o`0007Cooooo0027ooooo`;o00005oooool2o`0000Gooooo
0_l00003ooooo`Co00004Oooool2o`0000Kooooo1?l0000Uooooo`;o0000M?ooool008Oooooo0_l0
000Nooooo`;o00000oooool00ol0003oooooooooo`0Jooooo`Co0000Voooool00:_ooooo0_l0002k
ooooo`00Soooool2o`0001[ooooo0_l0000:ooooo`;o0000[oooool008oooooo0_l0000Kooooo`03
o`000?oooooooooo00Sooooo0_l0002_ooooo`00[?ooool00ol0003oooooooooo`08ooooo`;o0000
[oooool00:cooooo00?o0000ooooooooool00_l0000Fooooo`;o0000Woooool00:Oooooo0_l00003
ooooo`03o`000?oooooooooo00;o00003?ooool2o`0000Sooooo0_l00008ooooo`;o0000UOooool0
0:Oooooo0_l00003ooooo`?o00003_ooool2o`0001;ooooo0_l0002Eooooo`00[?ooool00ol0003o
ooooooooo`0Pooooo`;o0000Uoooool00:cooooo00?o0000ooooooooool08?ooool2o`0009Oooooo
0025ooooo`;o00009Oooool00ol0003oooooooooo`0:ooooo`Co0000Zoooool008Gooooo0_l0000D
ooooo`;o00003oooool00ol0003oooooooooo`0:ooooo`Co0000Zoooool009_ooooo0_l0000?oooo
o`03o`000?oooooooooo00_ooooo0_l0002/ooooo`00W?ooool2o`0000kooooo00?o0000oooooooo
ool02Oooool2o`000:kooooo002Looooo`;o00002_ooool2o`0000;ooooo00?o0000ooooooooool0
2Oooool2o`000:kooooo002Xooooo`;o00000_ooool00ol0003oooooooooo`2iooooo`00[?ooool3
o`0000Oooooo0_l0000Cooooo`;o0000Voooool00:cooooo00?o0000ooooooooool01oooool2o`00
01?ooooo0_l0002Kooooo`00[?ooool3o`0000oooooo0ol0002Wooooo`00[?ooool3o`0000oooooo
0ol0002Wooooo`00[?ooool2o`000;[ooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_oo
ool2o`000003oooooolQ8B7o8B4Q00Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Gooooo0_l0002jooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo
0_l000000ooooooo8B4Qob4Q8@06ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2iooooo`00ROooool00ol@413oooooooooo`02o`0000gooooo00Co
ZJVYoeEEEOl0003o00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo
0_l0002Qooooo`00ROooool00ol0003oooooooooo`02o`0000kooooo00?o8B4Qo`000?l000001_oo
ool00omgMgOo<S8booooo`04ooooo`?o00005_ooool2o`000:7ooooo0029ooooo`05o`000?oooooo
ooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`2iooooo`00ROooool01Ol@413ooooooooooooooooo410@00kooooo
00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo
0_l0002^ooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo0_l00005ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wo
oooo0_l0002^ooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo0_l00005ooooo`Go
00001?ooool4o`0000Kooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0
1_ooool2o`000;7ooooo002/ooooo`03o`000?oooooooooo00Kooooo0_l0002aooooo`00[?ooool0
0ol0003oooooooooo`06ooooo`;o00009?ooool2o`0008_ooooo002/ooooo`?o0000;?ooool2o`00
08_ooooo002/ooooo`03o`000?oooooooooo00oooooo0_l0002Xooooo`00U_ooool2o`0001Cooooo
00?o0000ooooooooool03oooool2o`0000[ooooo0_l0002Looooo`00Roooool2o`0000Wooooo0_l0
000Dooooo`03o`000?oooooooooo01_ooooo0_l0002Looooo`00Roooool2o`0001oooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool0097ooooo0_l0000Iooooo`03o`000?oooooooooo0;Wooooo002Aooooo`;o00006Ooo
ool3o`000;Wooooo002Iooooo`;o00004Oooool00ol0003oooooooooo`2iooooo`00VOooool2o`00
017ooooo00?o0000ooooooooool02Oooool2o`000:kooooo002>ooooo`;o00007?ooool00ol0003o
ooooooooo`09ooooo`;o0000[_ooool008kooooo0_l0000Looooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Soooo
o`?o000000?oooooo`000?l000000oooool00ol0003oooooooooo`2iooooo`00Xoooool6o`0000?o
oooo00?o0000ooooooooool0^Oooool00:Gooooo0_l00005ooooo`?o0000^Oooool009Oooooo0_l0
000Cooooo`03o`000?oooooooooo0;Wooooo002Gooooo`;o00004oooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`0=ooooo`;o0000Z_ooool00:cooooo00?o0000oooooooo
ool03Oooool2o`000:[ooooo002/ooooo`?o0000^Oooool00:[ooooo1Ol0002iooooo`00W?ooool2
o`0000cooooo0ol0002kooooo`00W?ooool2o`0000kooooo0ol0002iooooo`00WOooool2o`0000go
oooo00?o0000ooooooooool0^Oooool009gooooo0_l0000=ooooo`03o`000?oooooooooo0;Wooooo
002Uooooo`;o00001Oooool00ol0003oooooooooo`2iooooo`00YOooool2o`0000Gooooo00?o0000
ooooooooool04oooool2o`000:Cooooo002/ooooo`03o`000?oooooooooo01?ooooo0_l0002Toooo
o`00X_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0^Oooool00:Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00Y?ooool00ol0003ooooooooo
o`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo00?o0000oooo
ooooool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0
`Oooool00:;ooooo00?oEEEEofIVI_l00000`oooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00:[ooooo00Co410@o`000?l0003o0000^_ooool00:_ooooo00?o
0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00Ko0000ogMg
Mol0003o0000oeEEEOo^k^jgooooo`00Zoooool01_l0003oEEEEonk^k_ooooooMgMgoeEEEKOooooo
002[ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0]Oooool00:_ooooo00?o0000
onk^k_ooool00_ooool00ol0003oooooooooo`2eooooo`00Zoooool01_l0003oEEEEonk^k_oooooo
MgMgofIVI[Oooooo002Zooooo`03oa0@4?l0003oMgMg00;o000000?oIVIVonk^k_ooool0]_ooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.55452 .19793 Mdot
.63608 .64229 Mdot
.4827 .36837 Mdot
.49176 .2585 Mdot
.4651 .18602 Mdot
.53845 .81104 Mdot
.51112 .5804 Mdot
.46826 .99144 Mdot
.71084 .50872 Mdot
.55835 .4208 Mdot
.48597 .78087 Mdot
.39298 .82807 Mdot
.40398 .21493 Mdot
.52853 .70133 Mdot
.41971 .91936 Mdot
.4967 .74598 Mdot
.55009 .74987 Mdot
.42256 .14235 Mdot
.57393 .57643 Mdot
.5846 .8253 Mdot
.398 .2535 Mdot
.56271 .80929 Mdot
.53714 .84644 Mdot
.44886 .08856 Mdot
.4115 .09562 Mdot
.42792 .76253 Mdot
.41928 .6409 Mdot
.57729 .48612 Mdot
.54412 .88303 Mdot
.637 .63306 Mdot
.42154 .1525 Mdot
.71187 .53763 Mdot
.59592 .85628 Mdot
.40456 .6701 Mdot
.55366 .23456 Mdot
.67718 .54001 Mdot
.46817 .04107 Mdot
.52802 .28512 Mdot
.52806 .90009 Mdot
.36428 .52836 Mdot
.45895 .00678 Mdot
.44904 .15418 Mdot
.62853 .50307 Mdot
.6189 .32227 Mdot
.50899 .12983 Mdot
.5938 .50097 Mdot
.56132 .56528 Mdot
.70244 .40686 Mdot
.55999 .28277 Mdot
.59193 .80774 Mdot
.69512 .37953 Mdot
.38973 .74795 Mdot
.6097 .08504 Mdot
.60132 .34642 Mdot
.62504 .44025 Mdot
.68659 .672 Mdot
.46237 .98838 Mdot
.54184 .76809 Mdot
.6339 .23194 Mdot
.47 .10373 Mdot
.59207 .54137 Mdot
.74879 .46409 Mdot
.53131 .8945 Mdot
.53037 .38089 Mdot
.64319 .77156 Mdot
.70123 .62117 Mdot
.54374 .35971 Mdot
.54248 .61131 Mdot
.55161 .34389 Mdot
.49061 .07773 Mdot
.4387 .82362 Mdot
.50584 .37086 Mdot
.55532 .40885 Mdot
.47921 .22791 Mdot
.53237 .89308 Mdot
.44522 .56108 Mdot
.61015 .0856 Mdot
.57741 .62542 Mdot
.4231 .88995 Mdot
.42956 .2327 Mdot
.60594 .24418 Mdot
.64404 .5964 Mdot
.43234 .33976 Mdot
.48314 .13517 Mdot
.5815 .87957 Mdot
.44099 .72219 Mdot
.48867 .1879 Mdot
.52246 .24432 Mdot
.56921 .71066 Mdot
.53936 .62437 Mdot
.41292 .09203 Mdot
.51565 .67955 Mdot
.57705 .37983 Mdot
.5419 .56666 Mdot
.53908 .67188 Mdot
.68531 .3532 Mdot
.64076 .12231 Mdot
.54359 .76865 Mdot
.59107 .26411 Mdot
.59882 .61803 Mdot
.41807 .91823 Mdot
.63569 .3761 Mdot
.58449 .20319 Mdot
.39462 .50361 Mdot
.41661 .75033 Mdot
.54225 .69861 Mdot
.51173 .69056 Mdot
.48548 .07558 Mdot
.56165 .57534 Mdot
.49378 .25999 Mdot
.71204 .51588 Mdot
.66032 .65625 Mdot
.79629 .51887 Mdot
.49214 .69651 Mdot
.58465 .59644 Mdot
.66872 .72942 Mdot
.69518 .65244 Mdot
.40745 .15909 Mdot
.3952 .26797 Mdot
.73153 .37078 Mdot
.41236 .80762 Mdot
.51882 .91651 Mdot
.49491 .08161 Mdot
.52173 .32644 Mdot
.64701 .69477 Mdot
.57308 .93687 Mdot
.6387 .40386 Mdot
.43266 .40093 Mdot
.51602 .87849 Mdot
.62292 .34209 Mdot
.36643 .58576 Mdot
.49694 .87464 Mdot
.61884 .60902 Mdot
.44703 .93687 Mdot
.47361 .03709 Mdot
.60012 .79611 Mdot
.54923 .38205 Mdot
.56138 .90186 Mdot
.3937 .8265 Mdot
.74265 .59274 Mdot
.41889 .49612 Mdot
.57593 .45434 Mdot
.54563 .75933 Mdot
.62557 .75006 Mdot
.62133 .82024 Mdot
.76385 .69826 Mdot
.55899 .63911 Mdot
.55387 .31233 Mdot
.72748 .34954 Mdot
.60494 .58768 Mdot
.48821 .21062 Mdot
.47085 .07136 Mdot
.48525 .31969 Mdot
.44771 .86546 Mdot
.39385 .21975 Mdot
.47675 .94962 Mdot
.67782 .70407 Mdot
.45421 .05083 Mdot
.40887 .14822 Mdot
.42057 .26152 Mdot
.40892 .8463 Mdot
.50503 .01434 Mdot
.6687 .41923 Mdot
.62271 .44438 Mdot
.5549 .20124 Mdot
.63684 .79307 Mdot
.62329 .2732 Mdot
.53652 .30308 Mdot
.41955 .11068 Mdot
.64598 .69089 Mdot
.52111 .65769 Mdot
.46994 .2087 Mdot
.46145 .19067 Mdot
.52203 .7418 Mdot
.60879 .83433 Mdot
.51607 .9996 Mdot
.46899 .88332 Mdot
.52385 .57731 Mdot
.54455 .88062 Mdot
.3805 .31829 Mdot
.37585 .27549 Mdot
.42357 .35591 Mdot
.48691 .00355 Mdot
.53086 .4286 Mdot
.70707 .46155 Mdot
.59281 .91169 Mdot
.71231 .55722 Mdot
.62439 .57899 Mdot
.70153 .28975 Mdot
.62334 .7552 Mdot
.45546 .28284 Mdot
.73555 .39462 Mdot
.53668 .93648 Mdot
.59957 .12239 Mdot
.3863 .78998 Mdot
.55662 .31671 Mdot
.35555 .47723 Mdot
.40883 .28382 Mdot
.50924 .36326 Mdot
.51747 .39624 Mdot
.51815 .43071 Mdot
.42311 .28911 Mdot
.36927 .24781 Mdot
.59586 .27624 Mdot
.47901 .72549 Mdot
.50147 .86662 Mdot
.50649 .28363 Mdot
.51625 .65062 Mdot
.4523 .76891 Mdot
.3926 .70767 Mdot
.58186 .60596 Mdot
.62435 .2757 Mdot
.42472 .64402 Mdot
.5647 .21784 Mdot
.59059 .53243 Mdot
.50766 .01745 Mdot
.53746 .50336 Mdot
.39864 .30841 Mdot
.37215 .6843 Mdot
.58729 .58144 Mdot
.62494 .21971 Mdot
.60975 .24562 Mdot
.63055 .29636 Mdot
.4937 .74839 Mdot
.40618 .55329 Mdot
.64228 .62192 Mdot
.51979 .66377 Mdot
.41157 .89622 Mdot
.74403 .41827 Mdot
.54304 .6145 Mdot
.4383 .51045 Mdot
.36257 .32103 Mdot
.59305 .38143 Mdot
.41251 .57174 Mdot
.71394 .32072 Mdot
.50515 .23804 Mdot
.647 .42741 Mdot
.39492 .71748 Mdot
.61469 .31862 Mdot
.74709 .45427 Mdot
.58374 .72458 Mdot
.6667 .39254 Mdot
.44138 .82923 Mdot
.70988 .57618 Mdot
.5443 .47677 Mdot
.37343 .48877 Mdot
.60734 .52077 Mdot
.44908 .84266 Mdot
.51198 .91982 Mdot
.57252 .09005 Mdot
.50116 .67468 Mdot
.43871 .33458 Mdot
.3794 .34516 Mdot
.44196 .79956 Mdot
.44944 .23232 Mdot
.62975 .54787 Mdot
.44219 .48056 Mdot
.51122 .96403 Mdot
.68009 .33026 Mdot
.58169 .33949 Mdot
.41272 .57544 Mdot
.6493 .34466 Mdot
.4399 .64178 Mdot
.60969 .53405 Mdot
.48847 .1102 Mdot
.55711 .59085 Mdot
.60574 .65605 Mdot
.66997 .59959 Mdot
.40561 .6252 Mdot
.66851 .6168 Mdot
.62998 .49315 Mdot
.56191 .44048 Mdot
.51379 .20013 Mdot
.39352 .22077 Mdot
.44602 .2593 Mdot
.43163 .74468 Mdot
.70173 .40842 Mdot
.45374 .77232 Mdot
.45707 .8776 Mdot
.49897 .93846 Mdot
.48419 .28421 Mdot
.42005 .39219 Mdot
.44413 .06344 Mdot
.4424 .9672 Mdot
.53089 .72664 Mdot
.43469 .47852 Mdot
.44602 .77767 Mdot
.6743 .59986 Mdot
.57763 .3857 Mdot
.56934 .18336 Mdot
.59955 .9025 Mdot
.60142 .1809 Mdot
.46369 .98356 Mdot
.58618 .16072 Mdot
.50849 .40791 Mdot
.60493 .183 Mdot
.70981 .31794 Mdot
.68192 .53045 Mdot
.43878 .95854 Mdot
.72388 .78736 Mdot
.49552 .17135 Mdot
.60719 .66471 Mdot
.63518 .38133 Mdot
.71085 .56238 Mdot
.41403 .08609 Mdot
.54871 .63434 Mdot
.69546 .38468 Mdot
.41721 .71376 Mdot
.44424 .35848 Mdot
.41184 .81204 Mdot
.52129 .804 Mdot
.38131 .43816 Mdot
.71177 .30824 Mdot
.47872 .70995 Mdot
.4214 .18933 Mdot
.3998 .36837 Mdot
.61883 .81514 Mdot
.42763 .5315 Mdot
.37869 .25265 Mdot
.62726 .16617 Mdot
.71448 .70585 Mdot
.55358 .48252 Mdot
.47175 .88879 Mdot
.5069 .15914 Mdot
.47521 .94845 Mdot
.4079 .40431 Mdot
.50754 .35453 Mdot
.51698 .48626 Mdot
.44909 .84084 Mdot
.3992 .85976 Mdot
.3738 .4912 Mdot
.54183 .56949 Mdot
.46222 .9151 Mdot
.45019 .31506 Mdot
.51865 .43489 Mdot
.63944 .63335 Mdot
.55106 .79004 Mdot
.62357 .45076 Mdot
.41819 .2734 Mdot
.40887 .40012 Mdot
.5674 .03743 Mdot
.43623 .78437 Mdot
.65045 .51555 Mdot
.52486 .36201 Mdot
.6489 .76508 Mdot
.43784 .73148 Mdot
.61752 .76297 Mdot
.63083 .65006 Mdot
.44162 .69999 Mdot
.57952 .40102 Mdot
.74314 .59181 Mdot
.39215 .82506 Mdot
.6139 .1953 Mdot
.6737 .58031 Mdot
.47658 .15854 Mdot
.39411 .46329 Mdot
.65015 .68028 Mdot
.60764 .46142 Mdot
.39667 .84614 Mdot
.69282 .7595 Mdot
.67124 .41315 Mdot
.37026 .65138 Mdot
.38612 .20178 Mdot
.51406 .02537 Mdot
.51904 .56971 Mdot
.57389 .3205 Mdot
.39486 .83154 Mdot
.48987 .98576 Mdot
.51116 .61449 Mdot
.53103 .12873 Mdot
.46416 .82661 Mdot
.47534 .8871 Mdot
.57885 .24035 Mdot
.69514 .38822 Mdot
.64466 .41539 Mdot
.53418 .09096 Mdot
.40337 .81604 Mdot
.55711 .81495 Mdot
.58933 .15816 Mdot
.54112 .84193 Mdot
.37673 .27722 Mdot
.7907 .59625 Mdot
.44702 .06092 Mdot
.40814 .74741 Mdot
.44934 .35835 Mdot
.57511 .09712 Mdot
.57273 .70326 Mdot
.51459 .45169 Mdot
.39326 .16092 Mdot
.49964 .0862 Mdot
.50674 .35104 Mdot
.5048 .26017 Mdot
.5113 .79411 Mdot
.41106 .45611 Mdot
.70944 .44461 Mdot
.64199 .3111 Mdot
.72739 .36695 Mdot
.38345 .21742 Mdot
.44035 .82261 Mdot
.40202 .65395 Mdot
.52672 .73218 Mdot
.46164 .80328 Mdot
.49638 .62855 Mdot
.42589 .94103 Mdot
.40131 .86486 Mdot
.42306 .66707 Mdot
.47034 .74574 Mdot
.42536 .30683 Mdot
.41607 .56157 Mdot
.6652 .2176 Mdot
.57488 .36948 Mdot
.67178 .43222 Mdot
.41973 .46376 Mdot
.4915 .21437 Mdot
.42723 .50242 Mdot
.5403 .2767 Mdot
.42586 .78111 Mdot
.43137 .2817 Mdot
.4572 .7129 Mdot
.72914 .35889 Mdot
.56338 .8996 Mdot
.4826 .61955 Mdot
.57553 .27749 Mdot
.41731 .75334 Mdot
.41073 .75685 Mdot
.4329 .77265 Mdot
.50345 .23417 Mdot
.59943 .12604 Mdot
.40369 .926 Mdot
.64863 .44398 Mdot
.78281 .40111 Mdot
.63639 .37491 Mdot
.42428 .54274 Mdot
.7093 .52283 Mdot
.38577 .7815 Mdot
.4804 .78335 Mdot
.6343 .63446 Mdot
.5781 .04913 Mdot
.45648 .73258 Mdot
.46261 .30692 Mdot
.49916 .78566 Mdot
.65112 .34832 Mdot
.40934 .33774 Mdot
.37254 .77016 Mdot
.53622 .53116 Mdot
.56007 .24956 Mdot
.45424 .14591 Mdot
.54611 .50924 Mdot
.49769 .68217 Mdot
.47689 .22599 Mdot
.47019 .99158 Mdot
.43875 .63925 Mdot
.4418 .9288 Mdot
.64929 .57585 Mdot
.47371 .10445 Mdot
.65892 .65752 Mdot
.52386 .1205 Mdot
.47492 .85718 Mdot
.55191 .96318 Mdot
.52064 .29455 Mdot
.39029 .81828 Mdot
.57874 .09678 Mdot
.55849 .58002 Mdot
.61066 .19106 Mdot
.41731 .71035 Mdot
.58757 .64919 Mdot
.61956 .75931 Mdot
.59828 .27835 Mdot
.56851 .60648 Mdot
.58253 .41539 Mdot
.40085 .6376 Mdot
.75303 .49491 Mdot
.62477 .56328 Mdot
.44609 .5713 Mdot
.62166 .43177 Mdot
.45061 .18077 Mdot
.51931 .57035 Mdot
.55344 .49686 Mdot
.59828 .33659 Mdot
.61894 .61262 Mdot
.52866 .53711 Mdot
.48955 .82513 Mdot
.69978 .62744 Mdot
.46212 .18754 Mdot
.4474 .12706 Mdot
.57492 .4394 Mdot
.57187 .43785 Mdot
.46507 .68947 Mdot
.7971 .50481 Mdot
.45582 .67464 Mdot
.63783 .63761 Mdot
.61159 .20012 Mdot
.67329 .4453 Mdot
.56316 .38428 Mdot
.57904 .8308 Mdot
.36436 .47772 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool00_l00003ooooo`03
o`000?oooooooooo0;Wooooo002Nooooo`;o00001?ooool00ol0003oooooooooo`02o`0000?ooooo
00?o0000ooooooooool0^Oooool009kooooo0_l00004ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2i
ooooo`00X_ooool00omEEEGoIVIVo`000007ooooo`?o0000^Oooool00:cooooo1?l0002hooooo`00
[?ooool01?l0003oooooo`000?l0002hooooo`00[?ooool3o`000003ooooool0003o00000;Kooooo
002/ooooo`04o`000?ooooooooooooooo`;o0000]_ooool00:cooooo00?o0000ooooooooool0^Ooo
ool00:cooooo00?o0000ooooooooool0^Oooool00:?ooooo0_l00007ooooo`03o`000?oooooooooo
01?ooooo0_l0002Tooooo`00XOooool4o`0000Oooooo00?o0000ooooooooool04oooool2o`000:Co
oooo002Qooooo`;o00002Oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`0Fooooo`;o0000XOooool009cooooo0_l0000>oooo
o`?o00005_ooool2o`000:7ooooo002Looooo`;o00003_ooool00ol0003oooooooooo`2iooooo`00
[?ooool00ol0003oooooooooo`2iooooo`00V_ooool2o`00013ooooo00?o0000ooooooooool0^Ooo
ool009Wooooo0ol0000@ooooo`03o`000?oooooooooo0;Wooooo002Iooooo`;o00004Oooool00ol0
003oooooooooo`2iooooo`00X_ooool2o`0000Sooooo00?o0000ooooooooool0^Oooool00:;ooooo
0_l00008ooooo`03o`000?oooooooooo0;Wooooo002Wooooo`;o00000oooool3o`000;Wooooo002W
ooooo`?o00000_ooool00ol0003oooooooooo`2iooooo`00Z?ooool5o`000;_ooooo002?ooooo`;o
00006Oooool3o`0002?ooooo0_l0002Fooooo`00Soooool2o`0000[ooooo0_l0000>ooooo`;o0000
8oooool2o`0009Kooooo002?ooooo`;o00002_ooool2o`0000oooooo00?o0000ooooooooool02?oo
ool2o`0000_ooooo0_l0002Rooooo`00Soooool2o`0001_ooooo00?o0000ooooooooool02?ooool2
o`0000_ooooo0_l0002Rooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool05Oooool4o`00
0:3ooooo002>ooooo`;o00007?ooool3o`0001Gooooo1?l0002Pooooo`00X_ooool3o`0000Oooooo
00?o0000ooooooooool0^Oooool00:;ooooo0ol00007ooooo`03o`000?oooooooooo0;Wooooo002A
ooooo`;o00005Oooool2o`0000;ooooo00?o0000ooooooooool0^Oooool0097ooooo0_l0000Eoooo
o`;o00000_ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo00Cooooo0_l0000Gooooo`;o00003?ooool2o`00
08cooooo0021ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEE
EOooool02?ooool00ol0003oooooooooo`03ooooo`?o00001?ooool2o`0001Oooooo0_l0000<oooo
o`;o0000S?ooool008Wooooo00Go0000ooooooooooooooooo`00000<ooooo`;o000000?o8B4Qoooo
ooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00Oooooo0_l0000Doooo
o`;o0000V_ooool008Wooooo00Go0000ooooooooooooooooo`00000<ooooo`;o000000?oEEEEolc<
c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool00_l00005
ooooo`;o00005?ooool2o`0009[ooooo0029ooooo`05oa0@4?ooooooooooooooool@41003_ooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_l0002g
ooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b
<P04ooooo`04o`000?ooooooooooooooo`;o00001?ooool00ol0003oooooooooo`2iooooo`00ROoo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Ko00001?ooool00ol0003ooooo
ooooo`2iooooo`00T_ooool2o`0001Sooooo00?o0000ooooooooool0^Oooool009;ooooo0_l00008
ooooo`;o00003_ooool00ol0003oooooooooo`2iooooo`00SOooool2o`0000gooooo0_l0000>oooo
o`03o`000?oooooooooo0;Wooooo002=ooooo`;o00000oooool2o`0001Sooooo0ol0002iooooo`00
T_ooool2o`0000Oooooo0_l0000?ooooo`03o`000?oooooooooo0;Wooooo002=ooooo`;o00003?oo
ool2o`0000Oooooo0_l00006ooooo`04o`000?oooooo0000o`0001Wooooo0_l0002Mooooo`00R?oo
ool2o`0000?ooooo0_l0000Eooooo`;o00001_ooool01?l0003oooooo`000?l0000Hooooo`?o0000
WOooool008Sooooo0_l0000Rooooo`03o`000?oooooooooo01Wooooo0_l0002Nooooo`00[?ooool0
0ol0003oooooooooo`0Wooooo`;o0000T?ooool00:cooooo00?o0000ooooooooool09oooool2o`00
093ooooo002Zooooo`?o0000^oooool00:[ooooo1Ol0002iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00Voooool2o`0000oooooo00?o0000ooooooooool04oooool2o`0000Wooooo0ol0002H
ooooo`00Voooool2o`0000?ooooo0_l0000:ooooo`03o`000?oooooooooo01?ooooo0_l00009oooo
o`?o0000V?ooool009;ooooo0_l0000;ooooo`?o00001_ooool2o`0000;ooooo00?o0000oooooooo
ool0^Oooool009;ooooo0_l0000;ooooo`;o00001oooool2o`0000;ooooo00?o0000ooooooooool0
8Oooool2o`0009Kooooo002Oooooo`;o00002oooool00ol0003oooooooooo`0Qooooo`?o0000UOoo
ool00:cooooo00?o0000ooooooooool03oooool2o`00017ooooo0_l0002Eooooo`00[?ooool3o`00
0003ooooool0003o000000cooooo0_l0000@ooooo`;o0000U_ooool008Kooooo0_l0000Tooooo`04
o`000?ooooooooooooooo`;o00003?ooool2o`0000Oooooo0_l00007ooooo`;o0000U_ooool008Ko
oooo0_l0000Tooooo`03o`000?oooooooooo01Sooooo0_l0002Oooooo`00X_ooool2o`0000Cooooo
0_l00002ooooo`03o`000?oooooooooo0;Wooooo002Rooooo`;o00001?ooool2o`0000;ooooo00?o
0000ooooooooool0^Oooool008cooooo0_l0000Kooooo`;o000000?oooooo`000?ooool0^_ooool0
08Gooooo0_l00002ooooo`;o000000?oooooo`000?l000006oooool2o`000003ooooool0003ooooo
01?ooooo0_l0000Booooo`;o00002oooool2o`0008Cooooo0025ooooo`;o000000Coooooo`000?l0
003o00008Oooool00ol0003oooooooooo`0Booooo`;o00004_ooool2o`0000_ooooo0_l00024oooo
o`00R?ooool2o`0002;ooooo0ol0002iooooo`00Y?ooool3o`0000Gooooo00?o0000ooooooooool0
^Oooool00:Cooooo0ol00005ooooo`03o`000?oooooooooo0;Wooooo002Dooooo`;o00001Oooool2
o`0000oooooo0ol0000>ooooo`;o00006Oooool2o`0008kooooo002Dooooo`;o00001Oooool2o`00
00oooooo0ol0000>ooooo`;o00006Oooool2o`0008kooooo002/ooooo`?o00005oooool2o`000:3o
oooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`?o00005oooool2o`000:3ooooo002Aooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`04oooo
o`;o00006_ooool3o`0009Kooooo0020ooooo`;o00001oooool6o`0000;ooooo00Go410@oooooooo
oooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool2o`00
00[ooooo0_l0000>ooooo`?o0000U_ooool0083ooooo0_l00002ooooo`;o00002oooool01Ol0003o
oooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool3o`00013ooooo0_l0002Woooo
o`00Q?ooool2o`0000Cooooo0_l00005ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0^Oooool008[ooooo0_l00005oooo
o`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`04ooooo`;o000000?ooooo
o`000?ooool0^_ooool0097ooooo0_l000000oooooooV9RHogMgM`04ooooo`;o00001_ooool00ol0
003oooooooooo`04ooooo`Ko0000^Oooool0097ooooo0ol000000olb<S;ok^k^ooooo`03ooooo`;o
00001_ooool4o`0000Cooooo1Ol0000Kooooo`;o0000W?ooool008Wooooo0_l0000Qooooo`03o`00
0?oooooooooo01_ooooo0_l0002Looooo`00ROooool2o`00027ooooo00?o0000ooooooooool0^Ooo
ool0097ooooo0_l0000Iooooo`03o`000?oooooooooo02Gooooo0_l0002Booooo`00Poooool2o`00
00cooooo0_l0000Iooooo`?o00002_ooool2o`00013ooooo0_l00007ooooo`?o0000TOooool008?o
oooo0_l0000Wooooo`03o`000?oooooooooo00[ooooo0_l00009ooooo`;o00001Oooool3o`0000Oo
oooo0_l0002Aooooo`00UOooool2o`0000Kooooo0_l0000=ooooo`03o`000?oooooooooo013ooooo
0_l00003ooooo`;o00001_ooool2o`0009[ooooo002=ooooo`;o00001_ooool2o`0000Kooooo0_l0
0007ooooo`;o00001?ooool01?l0003oooooo`000?l00005ooooo`;o00002?ooool2o`000:Oooooo
002=ooooo`;o00000oooool2o`0001;ooooo0_l00004ooooo`04o`000?oooooo0000o`0000Gooooo
0_l0002aooooo`00T_ooool2o`0001Sooooo00?o0000ooooooooool0?oooool2o`0007Sooooo002/
ooooo`03o`000?oooooooooo00?ooooo0_l0000jooooo`;o0000N?ooool00:cooooo00?o0000oooo
ooooool00oooool2o`0002?ooooo0_l0002?ooooo`00[?ooool3o`0002Sooooo0_l0002?ooooo`00
[?ooool00ol0003oooooooooo`09ooooo`;o0000[_ooool009?ooooo0_l0000:ooooo`;o00002ooo
ool00ol0003oooooooooo`09ooooo`;o0000[_ooool008[ooooo0_l00007ooooo`;o00002_ooool2
o`0000_ooooo00?o0000ooooooooool0@_ooool2o`0007Gooooo002:ooooo`;o00008?ooool00ol0
003oooooooooo`0>ooooo`;o00006oooool2o`0001Gooooo0_l0001eooooo`00Voooool2o`0000oo
oooo00?o0000ooooooooool03_ooool3o`0001[ooooo0_l0002<ooooo`00Q?ooool2o`0001Gooooo
0_l0000:ooooo`;o00000oooool00ol0003oooooooooo`0?ooooo`;o00004Oooool2o`0001kooooo
0_l0001eooooo`00O_ooool2o`0000Cooooo0_l0000Qooooo`;o00000oooool00ol0003ooooooooo
o`0Eooooo`;o00002oooool4o`0001cooooo0ol0001dooooo`00O_ooool2o`0002cooooo0ol0000E
ooooo`;o00003Oooool2o`0001gooooo0_l0001dooooo`00[?ooool00ol0003oooooooooo`04oooo
o`;o0000/oooool00:cooooo00?o0000ooooooooool01?ooool2o`0003;ooooo0_l0001oooooo`00
Uoooool2o`0001?ooooo00?o0000ooooooooool0>?ooool2o`0007oooooo002>ooooo`;o00001ooo
ool2o`0001?ooooo00?o0000ooooooooool07Oooool2o`0009[ooooo002>ooooo`;o00001Oooool2
o`0001Gooooo00?o0000ooooooooool06?ooool2o`0000?ooooo0_l0002Jooooo`00UOooool2o`00
01Gooooo00?o0000ooooooooool03_ooool2o`0000Sooooo0_l0000;ooooo`;o0000T_ooool008Co
oooo0_l0000Vooooo`03o`000?oooooooooo00kooooo0_l0000>ooooo`;o00001Oooool2o`0000Oo
oooo0_l00029ooooo`00Q?ooool2o`0002Kooooo00?o0000ooooooooool07_ooool2o`0000kooooo
0_l0000Hooooo`;o0000Koooool00:cooooo1?l0000]ooooo`;o00006?ooool2o`0006oooooo002B
ooooo`;o00006?ooool01?l0003oooooo`000?l0000iooooo`;o0000OOooool009;ooooo0_l00005
ooooo`Co00003oooool01?l0003oooooo`000?l0000iooooo`;o00003?ooool2o`0006oooooo002I
ooooo`Co00003oooool00ol0003oooooooooo`05ooooo`;o00001?ooool2o`0003_ooooo0_l0001_
ooooo`00[?ooool00ol0003oooooooooo`02o`0000?ooooo0_l00004ooooo`;o0000[?ooool008Wo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00;o0000A_ooool2o`0006oooooo0029oooo
o`05ogMgMol0003o0000oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4
A007ooooo`03ogMgMol0003o000000Cooooo0ol0000Eooooo`;o0000<Oooool3o`0006kooooo0021
ooooo`Ko00000_ooool01Ol@413o0000o`000?oooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Ooo
ool2o`0000Cooooo0ol0000Eooooo`;o0000<_ooool2o`0006kooooo0029ooooo`05o`000?oooooo
ooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0
000Yooooo`?o0000SOooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo01Kooooo
0_l0000Aooooo`?o00004Oooool2o`0007[ooooo0029ooooo`05oa0@4?ooooooooooooooool@4100
3oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool2o`0000Cooooo0_l00007ooooo`;o00000oooool2o`0000cooooo0_l0000Booooo`;o0000
N_ooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@
41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo0_l00004ooooo`;o
00000_ooool2o`0000?ooooo0_l00003ooooo`;o00003?ooool2o`0001;ooooo0_l0001jooooo`00
ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co00001_ooool00ol0003oooooooooo`0Aooooo`;o00000oooool2o`0002Gooooo0_l0001joooo
o`00TOooool2o`0001Wooooo00?o0000ooooooooool0?Oooool2o`0007[ooooo002Aooooo`;o0000
6Oooool00ol0003oooooooooo`0dooooo`;o00005?ooool2o`0006gooooo002/ooooo`03o`000?oo
oooooooo00;ooooo0_l0000`ooooo`;o00005?ooool2o`0006gooooo002=ooooo`;o00001_ooool2
o`0001Gooooo0ol00002ooooo`;o00004oooool2o`00047ooooo0_l0001Mooooo`00SOooool2o`00
00Kooooo0_l0000Eooooo`03o`000?oooooooooo01Oooooo0_l0000Aooooo`;o0000;_ooool2o`00
05gooooo002=ooooo`;o00007Oooool00ol0003oooooooooo`0Zooooo`;o00004oooool2o`0007So
oooo002/ooooo`04o`000?oooooo0000o`0000kooooo0_l0000^ooooo`;o0000N?ooool00:cooooo
00Co0000ooooool0003o00003_ooool2o`0002Cooooo0_l00008ooooo`;o0000N?ooool00:cooooo
00?o0000ooooooooool06?ooool2o`0001;ooooo0_l00007ooooo`;o0000P_ooool00:cooooo00?o
0000ooooooooool06?ooool2o`0001;ooooo0_l00006ooooo`;o00005oooool2o`0006[ooooo002/
ooooo`03o`000?oooooooooo013ooooo0_l0000Rooooo`;o00005oooool2o`0006[ooooo002/oooo
o`?o00004?ooool2o`000:Oooooo002/ooooo`03o`000?oooooooooo00Oooooo0_l0000Tooooo`;o
0000R_ooool00:cooooo00?o0000ooooooooool00oooool2o`0000;ooooo0_l0000Looooo`;o0000
1_ooool2o`0008[ooooo002/ooooo`03o`000?oooooooooo00?ooooo0_l0000Pooooo`;o00003_oo
ool2o`0008;ooooo002/ooooo`03o`000?oooooooooo00?ooooo0_l0000?ooooo`;o00007oooool2
o`0008;ooooo0024ooooo`;o00009_ooool00ol0003oooooooooo`03ooooo`;o00003?ooool2o`00
0004ooooool0003o0000o`0000oooooo0_l0002Aooooo`00Q?ooool2o`0002Kooooo00?o0000oooo
ooooool04Oooool2o`0000;ooooo0_l0000?ooooo`;o0000TOooool00:cooooo00?o0000oooooooo
ool09Oooool2o`0000Oooooo0_l00006ooooo`;o00002_ooool2o`0007Gooooo002/ooooo`03o`00
0?oooooooooo02Gooooo0_l00007ooooo`;o00001_ooool2o`0000[ooooo0_l0001eooooo`00[?oo
ool3o`000003ooooool0003o000002;ooooo0_l0002Booooo`00[?ooool01?l0003ooooooooooooo
ool2o`0001?ooooo0_l0000=ooooo`;o00009oooool2o`0006Wooooo002>ooooo`;o00007?ooool0
0ol0003oooooooooo`0Fooooo`;o0000=_ooool2o`0006Wooooo0009ooooo`Co000000?o410@oooo
ooooool05_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^ko
oooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo1Ol000001Ooooooo0000o`000?ooooooA4A400;o000000?o<S8b
omgMgOooool05Oooool00ol0003oooooooooo`0Hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool2o`0000;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0;ooooo`;o0000
0_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^ko
oooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`Co000000?o410@ooooooooool04_oo
ool000_ooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So0000o`000?ooooooA4A400Cooooo0_l000000ooo
ooooMgMgoc8b<P0Fooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`;o00000_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8boooo
o`0:ooooo`;o00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l00008ooooo`03ogMg
Molb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGo
ZJVYooooo`07ooooo`03ogMgMolb<S;ooooo01Wooooo00?o0000ooooooooool05?ooool000Ko0000
1Oooool00ol0003oooooooooo`0@ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00go
oooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`05ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool01Oooool6o`0000;ooooo00Go410@oooo
oooooooooooooa0@400<ooooo`;o000000?ok^k^ooooooooool00oooool2o`0000;ooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0Hooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00gooooo00Go410@oooooooooooooooo
oa0@4005ooooo`;o00002Oooool00ol0003oooooooooo`0=ooooo`05oa0@4?ooooooooooooooool@
41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000ko
oooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`0>ooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003Oooool0
0onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo01Gooooo00?o0000ooooooooool06?ooool0
1Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8boooo
o`0>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0>ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Wo
oooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol0003ooooo
oooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03ooo
ool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<01Kooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo0000
00kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000
ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooo
oooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
01[ooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol@413o
oooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`0Aoooo
o`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0Aooooo`04oa0@4?oooooo
ooooooooo`;o00003_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Sooooo0ol0
000;ooooo`;o00002oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003o
ooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000oooooooo
ool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04
ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oo
oooooooo017ooooo00CoMgMgoiRHV?ooooooV9RH0_l000000ooooooo0000o`000007ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`02ooooo`;o00005?ooool00ol0003o
ooooooooo`0;ooooo`;o00002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Co
oooo0009ooooo`03oeEEEOmVIVKo000001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go
00001?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00004?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00;ooooo0_l00007ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?oo
ool4o`000003ooooool0003o000000;o00004_ooool00ol0003oooooooooo`0>ooooo`;o00002?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co
00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000Iooooo`03oeEEEOmVIVKo000001Kooooo002Hoooo
o`;o00004_ooool00ol0003oooooooooo`02ooooo`;o00002_ooool2o`0000Kooooo0_l0002Qoooo
o`00P_ooool2o`0002Sooooo00?o0000ooooooooool00_ooool2o`0001;ooooo0_l0002Qooooo`00
P_ooool2o`0002Sooooo00?o0000ooooooooool0[_ooool2o`0000;ooooo0_l00005ooooo`00P_oo
ool2o`0002Sooooo00?o0000ooooooooool09oooool2o`0002Oooooo0_l0001Looooo`06onk^k_lQ
8B7oQhN7okZj^_l0003ogMgM1Oooool0097ooooo0_l0000Iooooo`03o`000?oooooooooo00kooooo
0_l0000Gooooo`;o00009oooool2o`0005gooooo00CogMgMo`000?l@413oc<c<1_ooool000Oooooo
ool0001<o`0000cooooo00Cok^k^ob4Q8Ol@413ok^k^1_ooool000Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0oooool3o`0000Sooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;o00000oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00?ooooo0ol00008ooooo`;o00001_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool01?lQ8B7oMgMg
ogMgMolb<S86ooooo`001oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`03ooooo`;o00002Oooool2o`0001Kooooo
00?o0000ooooooooool02Oooool2o`0001cooooo0_l0000Wooooo`03o`000?oooooooooo00cooooo
0_l0000Hooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02Oooool2o`0000;ooooo
0_l00005ooooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool03?ooool2o`0003Cooooo0_l0
000Kooooo`;o0000F?ooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo00cooooo0_l0000d
ooooo`;o0000MOooool00:cooooo00?o0000ooooooooool0;_ooool2o`0001?ooooo0_l0001doooo
o`00[?ooool00ol0003oooooooooo`0^ooooo`;o00004oooool2o`0001Wooooo0_l0001Iooooo`00
[?ooool00ol0003oooooooooo`0Pooooo`;o0000??ooool2o`0005Wooooo002/ooooo`?o00008?oo
ool2o`00023ooooo0_l0001eooooo`00Ooooool2o`0002_ooooo00?o0000ooooooooool0@_ooool2
o`0007Gooooo001oooooo`;o00004oooool2o`0001Kooooo00?o0000ooooooooool02Oooool2o`00
02kooooo0_l0001nooooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool02Oooool2o`0000oo
oooo0_l00005ooooo`;o00005_ooool2o`0007kooooo002/ooooo`03o`000?oooooooooo00Kooooo
0_l0000Booooo`;o00001Oooool2o`00023ooooo0_l0001dooooo`00[?ooool00ol0003ooooooooo
o`06ooooo`;o0000;oooool2o`0000[ooooo0_l0001dooooo`00Toooool2o`0001Oooooo00?o0000
ooooooooool06oooool2o`0001[ooooo0_l00020ooooo`00Toooool2o`0001Oooooo00?o0000oooo
ooooool06oooool2o`0009cooooo002/ooooo`03o`000?oooooooooo02Oooooo0_l0002@ooooo`00
[?ooool3o`0002Oooooo0_l0002@ooooo`00SOooool2o`0001gooooo00?o0000ooooooooool0^Ooo
ool008gooooo0_l0000Mooooo`03o`000?oooooooooo04?ooooo0_l0001dooooo`00T?ooool2o`00
00Oooooo0_l0000Aooooo`03o`000?oooooooooo04?ooooo0_l0001dooooo`00T?ooool2o`0000Oo
oooo0_l0000Aooooo`03o`000?oooooooooo02Kooooo0_l0000Jooooo`;o0000MOooool00:cooooo
00?o0000ooooooooool02_ooool2o`0000Gooooo0_l0000Cooooo`;o00006_ooool2o`0007Gooooo
002/ooooo`03o`000?oooooooooo00?ooooo0_l00005ooooo`;o00001Oooool2o`000:Kooooo002?
ooooo`;o00002Oooool2o`00013ooooo00?o0000ooooooooool00oooool2o`0000Gooooo0_l0002]
ooooo`00Soooool2o`0000Wooooo0_l0000@ooooo`?o00004Oooool2o`0000;ooooo0_l0000Goooo
o`;o00004_ooool2o`0007Gooooo002?ooooo`;o00006oooool00ol0003oooooooooo`04ooooo`;o
00002_ooool3o`0000;ooooo0_l0000?ooooo`;o00001_ooool2o`0001;ooooo0_l0001eooooo`00
[?ooool00ol0003oooooooooo`02o`0000;ooooo0_l0000:ooooo`;o00001oooool2o`0000_ooooo
0_l0000>ooooo`;o0000POooool007oooooo0_l0000[ooooo`03o`000?oooooooooo00;o00005ooo
ool2o`0001_ooooo0_l00021ooooo`00Ooooool2o`0002_ooooo00?o0000ooooooooool07oooool2
o`0009Sooooo002/ooooo`03o`000?oooooooooo00oooooo0_l0000>ooooo`;o0000;?ooool2o`00
06[ooooo002/ooooo`03o`000?oooooooooo00oooooo0_l0000looooo`;o0000J_ooool00:cooooo
00?o0000ooooooooool06Oooool2o`00017ooooo0_l0000Oooooo`;o00003_ooool2o`0005[ooooo
002/ooooo`?o00006Oooool2o`00017ooooo0_l00007ooooo`?o00009Oooool2o`0005[ooooo002/
ooooo`03o`000?oooooooooo03Gooooo0ol00021ooooo`00[?ooool00ol0003oooooooooo`0Coooo
o`;o00000oooool2o`0009oooooo002/ooooo`03o`000?oooooooooo01?ooooo0_l00003ooooo`;o
00002_ooool2o`0009?ooooo002/ooooo`03o`000?oooooooooo00_ooooo0_l0000Gooooo`;o0000
Toooool00:cooooo00?o0000ooooooooool00_l00009ooooo`;o00005oooool2o`0009?ooooo0029
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`04odA4A?l0
003o0000oc8b<P;o00001?ooool00ol0003oooooooooo`02o`0000Wooooo0_l0000@ooooo`;o0000
5Oooool2o`0008?ooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo
00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMol0003o000000Cooooo00?o0000oooooooo
ool07Oooool2o`0000gooooo0_l00006ooooo`;o00002Oooool2o`0007Sooooo0029ooooo`03oa0@
4?oooooooooo00;o00003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo
0ol0000:ooooo`;o00002_ooool2o`0001Cooooo0_l0000Aooooo`;o0000N?ooool008Wooooo00?o
0000ooooooooool00_l0000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool00_oo
ool3o`0000cooooo0_l0000:ooooo`;o00009oooool2o`0007Sooooo0029ooooo`05o`000?oooooo
ooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
0oooool3o`00047ooooo0_l0001hooooo`00ROooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo
0_l0000Jooooo`Co0000S?ooool008Wooooo00GoMgMgoiRHV?l0003o0000ogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00go
oooo0_l0000Jooooo`Co0000S?ooool008Wooooo00Gok^k^oc8b<_l0003o0000onk^kP09ooooo`;o
000000GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`0@oooo
o`;o00006?ooool2o`0008gooooo002Aooooo`;o00001?ooool3o`0001;ooooo00?o0000oooooooo
ool04?ooool2o`0001Oooooo0_l0002>ooooo`00TOooool4o`0000?ooooo0_l0000Booooo`03o`00
0?oooooooooo02Wooooo0_l0002>ooooo`00Toooool2o`0001Oooooo00?o0000ooooooooool06Ooo
ool2o`0009kooooo0021ooooo`;o0000:Oooool3o`0000;ooooo0_l0000Eooooo`;o00003Oooool2
o`0001?ooooo0_l0001jooooo`00POooool2o`0000Sooooo0_l0000Oooooo`03o`000?oooooooooo
00;ooooo0_l0000Tooooo`;o00004oooool2o`0007[ooooo002;ooooo`;o00007oooool00ol0003o
ooooooooo`04ooooo`;o00006Oooool2o`00013ooooo0_l00026ooooo`00[?ooool00ol0003ooooo
ooooo`04ooooo`;o00006Oooool2o`00013ooooo0_l00026ooooo`00[?ooool00ol0003ooooooooo
o`03ooooo`;o00006oooool2o`0009Oooooo002Booooo`;o00006?ooool00ol0003oooooooooo`03
ooooo`;o00006oooool2o`0009Oooooo002<ooooo`;o00001?ooool2o`0001Sooooo00?o0000oooo
ooooool0^Oooool008cooooo0_l0000Nooooo`03o`000?oooooooooo00Wooooo0_l0000_ooooo`;o
0000OOooool009gooooo0_l0000=ooooo`?o00002Oooool2o`0002oooooo0_l0001mooooo`00WOoo
ool2o`0000gooooo0_l00003ooooo`;o0000]Oooool00:_ooooo0_l00004ooooo`;o0000:_ooool2
o`0008Wooooo0021ooooo`;o0000:?ooool2o`00033ooooo0_l00029ooooo`00POooool2o`0002Wo
oooo00?o0000ooooooooool0^Oooool00:3ooooo0_l0000:ooooo`03o`000?oooooooooo00;o0000
:oooool2o`0008[ooooo002Pooooo`;o00002_ooool00ol0003oooooooooo`02o`0002_ooooo0_l0
002:ooooo`00ZOooool2o`000003ooooool0003ooooo02kooooo0_l0000Uooooo`;o0000Hoooool0
09Sooooo0_l0000?ooooo`;o000000Coooooo`000?l0003o00001_ooool2o`0000?ooooo0_l00017
ooooo`;o0000Hoooool009Sooooo0_l0000Booooo`03o`000?oooooooooo00Kooooo0_l00003oooo
o`;o00002?ooool2o`00023ooooo0_l00020ooooo`00[?ooool00ol0003oooooooooo`0Eooooo`;o
00008?ooool2o`0000[ooooo0_l0001dooooo`00R?ooool2o`0000Kooooo0_l0000Cooooo`;o0000
1Oooool00ol0003oooooooooo`13ooooo`;o0000M?ooool008Sooooo0_l00006ooooo`;o00002ooo
ool2o`0000Kooooo0_l00005ooooo`03o`000?oooooooooo01?ooooo0_l0002Tooooo`00T?ooool2
o`0000_ooooo0_l0000=ooooo`03o`000?oooooooooo01?ooooo0_l0002Tooooo`00ROooool2o`00
00Gooooo0_l0000Jooooo`03o`000?oooooooooo0;Wooooo0029ooooo`;o00003Oooool2o`0001;o
oooo00?o0000ooooooooool0^Oooool009Sooooo0_l0000;ooooo`;o00001Oooool3o`0001Sooooo
0_l0002Oooooo`00YOooool2o`0000Gooooo00?o0000ooooooooool01oooool2o`0000oooooo0_l0
002Oooooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool01oooool2o`0002_ooooo0_l00023
ooooo`00Uoooool2o`0000Cooooo0_l0000=ooooo`03o`000?oooooooooo00Gooooo0_l0000]oooo
o`;o0000Poooool009gooooo0_l0000=ooooo`03o`000?oooooooooo00Gooooo0_l0002booooo`00
[?ooool00ol0003oooooooooo`2iooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`04ooooo`;o
0000/oooool0097ooooo00CoMgMgoiRHV?ooooooV9RH0_l00004ooooo`;o8B4Q1Oooool2o`000003
oooooomgMgOo<S8b00?ooooo0ol00006ooooo`;o0000/oooool008Oooooo0_l00004ooooo`;o0000
0_ooool01?l@413oooooooooooooool2o`0000_ooooo0_l00002ooooo`03o`000?oooooooooo00Co
00003oooool2o`000:[ooooo0027ooooo`;o00001?ooool2o`000003ooooool0003o000000?ooooo
00?o0000ooooooooool03Oooool01?mgMgOo<S8booooooooool2o`000004ooooool0003o0000o`00
00gooooo0_l0000Gooooo`;o0000TOooool0093ooooo0_l00003ooooo`03o`000?oooooooooo00[o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo02Gooooo0ol0002Aoooo
o`00S_ooool4o`0000?ooooo00?o410@ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo02Gooooo0_l0002Booooo`00S_ooool2o`000006oooooomgMgOoV9RHoooooonH
V9SoMgMg3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo0_l0000Foooo
o`;o00005_ooool2o`0007_ooooo002Aooooo`03onk^k_lb<S;o000000;o00003?ooool4o`0000Ko
oooo00?o0000ooooooooool03?ooool2o`0001Gooooo0ol0000Fooooo`;o0000Noooool009Cooooo
0_l0000Fooooo`03o`000?oooooooooo00[ooooo0_l0000Gooooo`;o00002Oooool2o`0008Wooooo
0021ooooo`;o00006Oooool2o`0000kooooo00?o0000ooooooooool02_ooool3o`00027ooooo0_l0
0029ooooo`00POooool2o`0001;ooooo0_l00005ooooo`;o00003_ooool00ol0003oooooooooo`0;
ooooo`;o00007oooool2o`0008_ooooo002Eooooo`;o00001Oooool2o`0000kooooo0ol0000/oooo
o`;o0000Roooool009[ooooo0_l0000@ooooo`03o`000?oooooooooo0;Wooooo0026ooooo`;o0000
2oooool2o`0000Gooooo0_l0000;ooooo`;o00000oooool00ol0003oooooooooo`2iooooo`00Q_oo
ool2o`0000_ooooo0_l00002ooooo`;o00003?ooool4o`0000;ooooo0_l0002kooooo`00Uoooool2
o`0000cooooo0_l00004ooooo`;o0000B?ooool2o`00077ooooo0026ooooo`;o00009?ooool00ol0
003oooooooooo`0=ooooo`;o0000=oooool2o`00077ooooo0026ooooo`;o00009?ooool00ol0003o
ooooooooo`02o`0000_ooooo0_l0000Kooooo`;o0000SOooool00:cooooo00?o0000ooooooooool0
0_l0000Looooo`;o00002_ooool2o`0008gooooo002Hooooo`;o00004_ooool3o`0001kooooo0_l0
002Iooooo`00V?ooool2o`0000Gooooo0_l0000;ooooo`03o`000?oooooooooo00Cooooo0_l0002c
ooooo`00Woooool2o`0000_ooooo00?o0000ooooooooool01?ooool2o`000;?ooooo002?ooooo`;o
00006oooool00ol0003oooooooooo`0Aooooo`;o00002?ooool2o`0009cooooo002>ooooo`?o0000
6oooool00ol0003oooooooooo`09ooooo`;o00001_ooool2o`0000Sooooo0_l0002Looooo`00S?oo
ool4o`0001cooooo00?o0000ooooooooool02Oooool2o`0000Cooooo0_l0000Cooooo`;o0000Tooo
ool008Oooooo0_l00003ooooo`;o00007_ooool00ol0003oooooooooo`0?ooooo`;o00004oooool2
o`0009?ooooo0027ooooo`;o00003oooool2o`0001;ooooo00?o0000ooooooooool09Oooool2o`00
09;ooooo0028ooooo`;o00003Oooool3o`0000kooooo0_l00002ooooo`?o00006?ooool2o`0000_o
oooo0_l0002Booooo`00R?ooool2o`0000gooooo0_l00007ooooo`;o00001_ooool2o`0000;ooooo
00?o0000ooooooooool06?ooool2o`0009oooooo0028ooooo`?o00003Oooool2o`0000Kooooo0_l0
000:ooooo`03o`000?oooooooooo01Oooooo0_l0002Pooooo`00ROooool2o`0000gooooo0_l0000B
ooooo`03o`000?oooooooooo01Oooooo0_l00007ooooo`;o0000Uoooool00:cooooo00?o0000oooo
ooooool08?ooool2o`0009Oooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Kooooo`;o0000
3oooool00ol0003oooooooooo`0:ooooo`;o0000[Oooool008Wooooo0_l00002ooooo`;o00003?oo
ool2o`0000oooooo00?o0000ooooooooool02Oooool3o`000:gooooo0029ooooo`;o00000_ooool2
o`0001gooooo00?o0000ooooooooool02Oooool2o`000:kooooo002/ooooo`?o0000^Oooool00:co
oooo00?o0000ooooooooool0^Oooool00:?ooooo0_l00007ooooo`03o`000?oooooooooo01cooooo
0_l0002Kooooo`00R_ooool2o`0001Oooooo0_l00007ooooo`03o`000?oooooooooo01cooooo0_l0
002Kooooo`00R_ooool3o`0001oooooo00?o0000ooooooooool0^Oooool008Wooooo00Gok^k^oc8b
<_l0003o0000onk^kP05ooooo`;o8B4Q1Oooool2o`000003onk^k_oooooooooo00?ooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`;o0000^_ooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1Oooool2o`000003ojVYZOoooooooooo00Kooooo00?oMgMgoc8b<_ooool01?oo
ool2o`000;[ooooo0029ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEoooo
o`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0^Oooool008Wooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool00ooo
ool4o`000;Wooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGo0000o`00
0003ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool2o`0000Cooooo0_l0000Cooooo`;o0000
X?ooool008Wooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOl0003o000000?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`;o00001oooool2o`0000[ooooo
0_l0002Pooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooo
oooooc8b<P03ooooo`;o00002Oooool00ol0003oooooooooo`0;ooooo`;o0000[?ooool008Wooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00000oooool5o`0000Kooooo00?o0000oooooooo
ool0^Oooool009;ooooo0_l0000>ooooo`?o00001oooool00ol0003oooooooooo`2iooooo`00T_oo
ool2o`0001Sooooo00?o0000ooooooooool01oooool2o`000;3ooooo002>ooooo`;o00007?ooool0
0ol0003oooooooooo`07ooooo`;o0000/?ooool008kooooo0_l0000Looooo`?o00001_ooool2o`00
00Wooooo0_l0002Vooooo`00[?ooool00ol0003oooooooooo`06ooooo`;o00002Oooool2o`0000[o
oooo0_l0002Jooooo`00[?ooool00ol0003oooooooooo`0Aooooo`;o00002_ooool2o`0009[ooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo01_ooooo0_l0002L
ooooo`00Woooool2o`0000_ooooo00?o0000ooooooooool00oooool2o`0001Kooooo0_l0002Loooo
o`00TOooool2o`0000cooooo0_l0000;ooooo`03o`000?oooooooooo00?ooooo0_l0002dooooo`00
TOooool2o`0001Wooooo00Co0000oooooooooooooooo0_l0002fooooo`00[?ooool3o`000003oooo
ool0003o00000;Kooooo002<ooooo`;o00007_ooool00ol0003oooooooooo`2iooooo`00S?ooool2
o`0000[ooooo0_l0000Booooo`03o`000?oooooooooo0;Wooooo002Hooooo`;o00004_ooool00ol0
003oooooooooo`2iooooo`00V_ooool2o`00013ooooo00?o0000ooooooooool02Oooool2o`0000[o
oooo0_l0002Rooooo`00V_ooool2o`0000oooooo0_l0000;ooooo`;o00002_ooool2o`000:;ooooo
002Cooooo`;o00005_ooool2o`000;_ooooo002Cooooo`;o00005oooool00ol0003oooooooooo`2i
ooooo`00Xoooool3o`0000Kooooo00?o0000ooooooooool0^Oooool00:?ooooo0ol00006ooooo`?o
0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool009Oooooo0_l0000Cooooo`03o`000?oo
oooooooo0;Wooooo002Gooooo`;o00004oooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`02o`0000cooooo0_l0002Yooooo`00VOooool2o`00017ooooo00?o0000oooooooo
ool00_l0000<ooooo`;o0000ZOooool009Wooooo0_l0000Aooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:3ooooo0_l00006ooooo`;o0000
0_ooool00ol0003oooooooooo`2iooooo`00Woooool3o`0000Kooooo0_l00002ooooo`03o`000?oo
oooooooo0;Wooooo002Oooooo`Go00002?ooool00ol0003oooooooooo`2iooooo`00XOooool5o`00
0003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`?o0000
0_ooool2o`000;Gooooo002Tooooo`03o`000?oooooooooo00[ooooo0_l0002eooooo`00Y?ooool0
0ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003o
ooooooooo`31ooooo`00X_ooool00omEEEGoIVIVo`000033ooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Z_ooool01?l@413o0000o`000?l0002jooooo`00
Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool0
1_l0003oMgMgo`000?l0003oEEEEonk^k[Oooooo002[ooooo`06o`000?mEEEGok^k^oooooomgMgOo
EEEE]oooool00:_ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`2eooooo`00Zooo
ool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo0;Gooooo002[ooooo`06o`000?mEEEGo
k^k^oooooomgMgOoIVIV]oooool00:[ooooo00?o410@o`000?mgMgL00_l000000omVIVKok^k^oooo
o`2fooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.41175 .22025 Mdot
.653 .44229 Mdot
.4446 .49484 Mdot
.41865 .47905 Mdot
.4086 .61115 Mdot
.62287 .61104 Mdot
.50328 .3804 Mdot
.6326 .81197 Mdot
.67433 .30872 Mdot
.48678 .22733 Mdot
.56105 .588 Mdot
.57055 .89892 Mdot
.42813 .87178 Mdot
.56906 .50133 Mdot
.59541 .85928 Mdot
.55527 .54643 Mdot
.61004 .54987 Mdot
.40827 .80634 Mdot
.5645 .37643 Mdot
.67472 .6253 Mdot
.43784 .88953 Mdot
.64643 .60929 Mdot
.63572 .64644 Mdot
.39083 .70315 Mdot
.40046 .86472 Mdot
.54746 .73084 Mdot
.51816 .72649 Mdot
.53174 .28612 Mdot
.65733 .68303 Mdot
.65022 .43306 Mdot
.4107 .80858 Mdot
.68692 .33763 Mdot
.69844 .65628 Mdot
.52813 .79587 Mdot
.42146 .21841 Mdot
.65318 .34001 Mdot
.37629 .62911 Mdot
.42404 .31355 Mdot
.6481 .70009 Mdot
.50515 .97783 Mdot
.3708 .67678 Mdot
.40512 .68819 Mdot
.58976 .30307 Mdot
.50781 .12227 Mdot
.38731 .4313 Mdot
.55419 .30097 Mdot
.54743 .36528 Mdot
.62518 .20686 Mdot
.43965 .19229 Mdot
.67503 .60774 Mdot
.60693 .17953 Mdot
.55012 .87985 Mdot
.41221 .03573 Mdot
.49989 .14642 Mdot
.56114 .24025 Mdot
.71539 .472 Mdot
.62854 .81728 Mdot
.60908 .56809 Mdot
.48671 .03577 Mdot
.38957 .60756 Mdot
.56862 .34137 Mdot
.69442 .26409 Mdot
.64911 .6945 Mdot
.45038 .28805 Mdot
.71181 .57156 Mdot
.7097 .42117 Mdot
.45253 .24343 Mdot
.54701 .41131 Mdot
.45318 .219 Mdot
.37944 .52319 Mdot
.56502 .73145 Mdot
.44069 .39291 Mdot
.47927 .22474 Mdot
.41469 .54049 Mdot
.6496 .69308 Mdot
.49478 .61679 Mdot
.41272 .03438 Mdot
.58758 .42542 Mdot
.58607 .82768 Mdot
.42648 .75625 Mdot
.46443 .0738 Mdot
.6426 .3964 Mdot
.44925 .72094 Mdot
.39359 .54338 Mdot
.69333 .67957 Mdot
.53442 .65994 Mdot
.40391 .50784 Mdot
.41307 .34633 Mdot
.61347 .51066 Mdot
.54911 .42437 Mdot
.39937 .85932 Mdot
.62518 .87639 Mdot
.54747 .47955 Mdot
.48903 .18369 Mdot
.52856 .36666 Mdot
.65567 .8335 Mdot
.56783 .47188 Mdot
.58659 .1532 Mdot
.61105 .56865 Mdot
.45825 .10808 Mdot
.60604 .41803 Mdot
.59504 .86359 Mdot
.54613 .1761 Mdot
.43187 .11545 Mdot
.49318 .85018 Mdot
.54581 .76931 Mdot
.58169 .49861 Mdot
.54796 .49056 Mdot
.38008 .54609 Mdot
.55178 .37534 Mdot
.41854 .46993 Mdot
.67839 .31588 Mdot
.68282 .45625 Mdot
.76384 .31887 Mdot
.53199 .49974 Mdot
.58322 .39644 Mdot
.72049 .52942 Mdot
.71615 .45244 Mdot
.41519 .8687 Mdot
.44161 .89862 Mdot
.63984 .17078 Mdot
.56216 .81376 Mdot
.64542 .71651 Mdot
.37935 .50358 Mdot
.43246 .33222 Mdot
.68492 .49477 Mdot
.70783 .73687 Mdot
.56024 .20386 Mdot
.46253 .7063 Mdot
.62741 .67849 Mdot
.51976 .14209 Mdot
.51729 .96186 Mdot
.60689 .67489 Mdot
.62244 .40902 Mdot
.60434 .79943 Mdot
.37424 .60621 Mdot
.67856 .59611 Mdot
.46413 .2293 Mdot
.68212 .70186 Mdot
.57001 .89534 Mdot
.73974 .39274 Mdot
.48629 .74583 Mdot
.51767 .25434 Mdot
.60936 .55933 Mdot
.6856 .55006 Mdot
.70943 .62024 Mdot
.80315 .49826 Mdot
.57463 .43911 Mdot
.44469 .21153 Mdot
.62729 .14954 Mdot
.60001 .38768 Mdot
.40897 .50491 Mdot
.38232 .61086 Mdot
.43342 .49426 Mdot
.57947 .73769 Mdot
.43137 .91495 Mdot
.62123 .76171 Mdot
.71945 .50407 Mdot
.38144 .68795 Mdot
.41251 .86486 Mdot
.43471 .78925 Mdot
.57363 .84804 Mdot
.36259 .47385 Mdot
.59639 .21923 Mdot
.56046 .24438 Mdot
.41284 .21827 Mdot
.71407 .59307 Mdot
.49258 .0745 Mdot
.43187 .2751 Mdot
.402 .82632 Mdot
.68234 .49089 Mdot
.54418 .45769 Mdot
.4125 .58512 Mdot
.4104 .62609 Mdot
.57875 .5418 Mdot
.70253 .63433 Mdot
.6759 .7996 Mdot
.5917 .70847 Mdot
.51478 .37731 Mdot
.6568 .68062 Mdot
.45577 .9519 Mdot
.44744 .98148 Mdot
.45467 .75571 Mdot
.36404 .55538 Mdot
.46528 .28421 Mdot
.65169 .26155 Mdot
.71748 .71169 Mdot
.6952 .35722 Mdot
.36585 .61729 Mdot
.61599 .37899 Mdot
.57743 .08975 Mdot
.68542 .5552 Mdot
.43182 .6323 Mdot
.65339 .19462 Mdot
.67127 .73648 Mdot
.41685 .06754 Mdot
.5615 .90917 Mdot
.44805 .20302 Mdot
.44212 .8357 Mdot
.43903 .37933 Mdot
.44853 .33655 Mdot
.45791 .32793 Mdot
.44019 .77219 Mdot
.46711 .10353 Mdot
.53659 .54556 Mdot
.60812 .66662 Mdot
.42137 .40897 Mdot
.5365 .45062 Mdot
.54767 .64981 Mdot
.53962 .8561 Mdot
.58424 .40596 Mdot
.49463 .07638 Mdot
.51771 .70274 Mdot
.42294 .17969 Mdot
.56356 .33243 Mdot
.36285 .46157 Mdot
.49881 .30343 Mdot
.44969 .87485 Mdot
.53838 .94118 Mdot
.57987 .38144 Mdot
.47313 .03531 Mdot
.46856 .06857 Mdot
.5091 .09636 Mdot
.55369 .55001 Mdot
.50152 .78903 Mdot
.65105 .42192 Mdot
.5453 .46377 Mdot
.58832 .86963 Mdot
.67134 .21827 Mdot
.54883 .4145 Mdot
.48522 .65799 Mdot
.50563 .18143 Mdot
.50418 .75799 Mdot
.60223 .12072 Mdot
.41151 .42485 Mdot
.57796 .22741 Mdot
.54153 .84859 Mdot
.50214 .11862 Mdot
.6888 .25427 Mdot
.63357 .52458 Mdot
.58372 .19254 Mdot
.56686 .72723 Mdot
.70035 .37618 Mdot
.49501 .27791 Mdot
.49452 .94592 Mdot
.57565 .32077 Mdot
.57186 .71563 Mdot
.63991 .71982 Mdot
.39091 .16587 Mdot
.53103 .47468 Mdot
.44674 .69426 Mdot
.46188 .95089 Mdot
.55739 .70413 Mdot
.42209 .6695 Mdot
.6089 .34787 Mdot
.47785 .64747 Mdot
.65683 .76403 Mdot
.57219 .13026 Mdot
.47779 .15389 Mdot
.50495 .75655 Mdot
.54716 .14466 Mdot
.51393 .63533 Mdot
.58331 .33405 Mdot
.38699 .52551 Mdot
.55345 .39085 Mdot
.62816 .45605 Mdot
.6698 .39959 Mdot
.51755 .78623 Mdot
.67523 .4168 Mdot
.58724 .29315 Mdot
.4981 .24062 Mdot
.40251 .39459 Mdot
.43167 .91618 Mdot
.42872 .67862 Mdot
.54197 .70741 Mdot
.6251 .20842 Mdot
.54881 .64793 Mdot
.58556 .72572 Mdot
.63437 .73849 Mdot
.4259 .50655 Mdot
.46335 .76325 Mdot
.38637 .72923 Mdot
.61409 .83605 Mdot
.58155 .52664 Mdot
.47903 .68063 Mdot
.55046 .67587 Mdot
.67424 .39986 Mdot
.49193 .18781 Mdot
.41557 .16616 Mdot
.72055 .7025 Mdot
.43767 .06656 Mdot
.62732 .81077 Mdot
.41952 .10984 Mdot
.44917 .37301 Mdot
.44132 .05815 Mdot
.59698 .11794 Mdot
.6541 .33045 Mdot
.6103 .83718 Mdot
.79882 .58736 Mdot
.39881 .48149 Mdot
.63307 .46471 Mdot
.54771 .18133 Mdot
.6958 .36238 Mdot
.39783 .85574 Mdot
.56245 .43434 Mdot
.60933 .18468 Mdot
.5362 .75258 Mdot
.45076 .66494 Mdot
.56348 .8181 Mdot
.60289 .604 Mdot
.48177 .92246 Mdot
.59506 .10824 Mdot
.53082 .53222 Mdot
.41877 .80124 Mdot
.46253 .85683 Mdot
.70488 .61514 Mdot
.49213 .70002 Mdot
.44184 .97402 Mdot
.45495 .00689 Mdot
.75682 .50585 Mdot
.50659 .28252 Mdot
.59502 .70941 Mdot
.39399 .4342 Mdot
.61985 .76222 Mdot
.46863 .81366 Mdot
.43702 .38888 Mdot
.47372 .32784 Mdot
.57124 .71415 Mdot
.57857 .89151 Mdot
.49497 .94378 Mdot
.52962 .36949 Mdot
.60091 .74933 Mdot
.43999 .64834 Mdot
.45933 .32542 Mdot
.65279 .43335 Mdot
.62707 .59004 Mdot
.56387 .25076 Mdot
.43782 .79706 Mdot
.4675 .81036 Mdot
.37473 .19537 Mdot
.55296 .71323 Mdot
.61667 .31555 Mdot
.44249 .31222 Mdot
.71493 .56508 Mdot
.53744 .6768 Mdot
.68271 .56297 Mdot
.65086 .45006 Mdot
.52825 .64675 Mdot
.49993 .20103 Mdot
.73987 .39181 Mdot
.56986 .90073 Mdot
.45356 .04169 Mdot
.66582 .38031 Mdot
.40011 .56696 Mdot
.48449 .86112 Mdot
.68227 .48028 Mdot
.55221 .26142 Mdot
.57503 .89368 Mdot
.75663 .5595 Mdot
.5965 .21315 Mdot
.53119 .9457 Mdot
.42912 .95261 Mdot
.36384 .4314 Mdot
.50692 .36971 Mdot
.46348 .15947 Mdot
.57122 .89323 Mdot
.64501 .78789 Mdot
.51696 .41449 Mdot
.38738 .33321 Mdot
.56904 .66578 Mdot
.59617 .70294 Mdot
.4398 .13396 Mdot
.61043 .18822 Mdot
.57081 .21539 Mdot
.37903 .32738 Mdot
.56572 .8525 Mdot
.64309 .61495 Mdot
.42092 .09976 Mdot
.63789 .64193 Mdot
.44762 .97727 Mdot
.7892 .39625 Mdot
.3852 .71716 Mdot
.54652 .80266 Mdot
.44963 .64269 Mdot
.39414 .1548 Mdot
.61403 .50326 Mdot
.46194 .33871 Mdot
.41866 .93024 Mdot
.37933 .48193 Mdot
.43625 .39319 Mdot
.4164 .42158 Mdot
.58895 .59411 Mdot
.47925 .78868 Mdot
.64729 .24461 Mdot
.52643 .1111 Mdot
.63417 .16695 Mdot
.43312 .96087 Mdot
.56471 .72558 Mdot
.35455 .50422 Mdot
.5249 .80467 Mdot
.57959 .53218 Mdot
.56015 .65131 Mdot
.50821 .4296 Mdot
.60273 .85709 Mdot
.5798 .88655 Mdot
.5235 .71416 Mdot
.54162 .58188 Mdot
.44357 .75855 Mdot
.50119 .74403 Mdot
.51224 .0176 Mdot
.48284 .17877 Mdot
.60467 .23222 Mdot
.47905 .74917 Mdot
.40907 .48977 Mdot
.48586 .70807 Mdot
.42648 .26426 Mdot
.55298 .74866 Mdot
.43678 .73772 Mdot
.53006 .59538 Mdot
.6327 .15889 Mdot
.68322 .6996 Mdot
.50029 .44841 Mdot
.44971 .14681 Mdot
.5465 .76785 Mdot
.54854 .79588 Mdot
.54978 .71794 Mdot
.41091 .43319 Mdot
.41791 .06803 Mdot
.5978 .91578 Mdot
.58622 .24398 Mdot
.70326 .20111 Mdot
.54635 .17491 Mdot
.4953 .71221 Mdot
.67843 .32283 Mdot
.55941 .90815 Mdot
.55894 .59715 Mdot
.64808 .43446 Mdot
.38241 .15012 Mdot
.53615 .61092 Mdot
.43553 .59587 Mdot
.57343 .58568 Mdot
.55045 .14832 Mdot
.45378 .8218 Mdot
.55905 .95978 Mdot
.50869 .33116 Mdot
.42953 .19351 Mdot
.40219 .66723 Mdot
.50981 .30924 Mdot
.53067 .48246 Mdot
.41477 .55101 Mdot
.6337 .80969 Mdot
.51358 .63997 Mdot
.60046 .80488 Mdot
.63963 .37585 Mdot
.38893 .59123 Mdot
.68192 .45752 Mdot
.38481 .36692 Mdot
.58447 .67494 Mdot
.69718 .76318 Mdot
.42456 .34364 Mdot
.56831 .90496 Mdot
.39596 .14101 Mdot
.5505 .38002 Mdot
.44913 .04699 Mdot
.53532 .75099 Mdot
.60724 .44919 Mdot
.68329 .55931 Mdot
.47018 .1007 Mdot
.5711 .40648 Mdot
.50869 .21539 Mdot
.5214 .80824 Mdot
.71099 .29491 Mdot
.61009 .36328 Mdot
.49682 .61079 Mdot
.55436 .23177 Mdot
.41059 .67556 Mdot
.50745 .37035 Mdot
.51219 .29686 Mdot
.49292 .13798 Mdot
.62399 .41262 Mdot
.5035 .33711 Mdot
.58093 .62852 Mdot
.71076 .42744 Mdot
.40957 .62383 Mdot
.39955 .70121 Mdot
.51068 .2394 Mdot
.50701 .23785 Mdot
.52251 .55346 Mdot
.75902 .30481 Mdot
.51916 .57873 Mdot
.65288 .43761 Mdot
.45325 .04773 Mdot
.61142 .2453 Mdot
.47733 .20176 Mdot
.67136 .6308 Mdot
.49407 .98789 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00WOooool2o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`2iooooo`00WOooool2o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo002Roooo
o`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0^Oooool00:cooooo00Co0000oooooooo
oooooooo0_l0002fooooo`00[?ooool01?l0003oooooooooooooool2o`000;Kooooo002/ooooo`?o
0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Ooo
ool008oooooo0_l0000Kooooo`03o`000?oooooooooo0;Wooooo002?ooooo`;o00004_ooool2o`00
00;ooooo0_l00003ooooo`03o`000?oooooooooo0;Wooooo002?ooooo`;o00004_ooool2o`0000;o
oooo0_l00003ooooo`03o`000?oooooooooo0;Wooooo002Looooo`;o00003_ooool00ol0003ooooo
ooooo`2iooooo`00Voooool3o`0000kooooo00?o0000ooooooooool0^Oooool009_ooooo0ol0000>
ooooo`03o`000?oooooooooo0;Wooooo002Looooo`;o00003_ooool3o`000;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002Hooooo`;o00004_ooool00ol0003oooooooooo`2iooooo`00V?oo
ool2o`0001;ooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
093ooooo0_l00005ooooo`;o00004oooool00ol0003oooooooooo`2iooooo`00T?ooool2o`0000Go
oooo0_l00008ooooo`;o00002Oooool00ol0003oooooooooo`2iooooo`00X?ooool3o`0000Wooooo
00?o0000ooooooooool0^Oooool00:3ooooo0_l00007ooooo`Ko0000^Oooool00:Wooooo1?l0002k
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0Fooooo`;o0000XOoo
ool00:cooooo00?o0000ooooooooool05_ooool2o`000:7ooooo002/ooooo`03o`000?oooooooooo
00;o0000]oooool0097ooooo0_l0000?ooooo`;o00002?ooool5o`000;Oooooo002Aooooo`;o0000
3_ooool3o`0000Sooooo00?o0000ooooooooool0^Oooool00:7ooooo0_l00009ooooo`03o`000?oo
oooooooo0;Wooooo002Aooooo`;o00002oooool2o`0000cooooo00?o0000ooooooooool07?ooool2
o`0009_ooooo002Aooooo`;o00002oooool2o`0000cooooo00?o0000ooooooooool01Oooool2o`00
01Gooooo0_l0002Kooooo`00UOooool2o`0001Gooooo00?o0000ooooooooool01Oooool2o`000;;o
oooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@;o00001?ooool00ol0003o
k^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool2o`0001kooooo0_l0002Joooo
o`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo
00Oooooo00?oMgMgoc8b<_ooool01?ooool4o`0001cooooo0ol0002Iooooo`00POooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000oooo
ooooool00oooool4o`0001gooooo0_l0002Iooooo`00ROooool01Ol0003ooooooooooooooooo0000
00kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
0;Wooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Dooooo`;o0000Xoooool0
08Wooooo00Go410@oooooooooooooooooa0@400:ooooo`;o00000_ooool00onYZJWoMgMgooooo`03
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05?ooool2o`000:?ooooo0029oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02_ooool2o`0000?ooooo00?o<S8booooooooool00_ooool0
0ol0003oooooooooo`04ooooo`;o000000?oooooo`000?ooool0^_ooool008Wooooo0ol000000olb
<S;ok^k^ooooo`0:ooooo`Go00001?ooool4o`0000?ooooo0_l000000ooooooo0000ooooo`2joooo
o`00ROooool2o`00027ooooo00?o0000ooooooooool00oooool2o`000;Cooooo002Kooooo`;o0000
3oooool2o`0000Cooooo0_l00007ooooo`;o0000Zoooool008Gooooo0_l0000Dooooo`;o00003ooo
ool2o`0000gooooo0ol0000Hooooo`;o0000T?ooool008Gooooo0_l0000Uooooo`?o00003Oooool2
o`0001Sooooo0_l0002@ooooo`00ROooool2o`0001Wooooo0_l00006ooooo`03o`000?oooooooooo
01Wooooo0_l0002Nooooo`00ROooool2o`0001Wooooo0_l00006ooooo`03o`000?oooooooooo01Wo
oooo0_l0000=ooooo`;o0000Soooool00:3ooooo0_l0000:ooooo`03o`000?oooooooooo02Sooooo
0_l0002?ooooo`00X?ooool2o`0000[ooooo00?o0000ooooooooool0^Oooool008Sooooo0_l00006
ooooo`;o00006_ooool00ol0003oooooooooo`0Yooooo`;o0000S_ooool008Sooooo0_l00006oooo
o`;o00006_ooool00ol0003oooooooooo`0Yooooo`Co0000S?ooool00:cooooo00?o0000oooooooo
ool0:oooool2o`0008cooooo002/ooooo`?o00003?ooool2o`000:_ooooo002Booooo`;o00004_oo
ool2o`0000Cooooo00?o0000ooooooooool03?ooool2o`0001;ooooo0_l0002Gooooo`00T_ooool2
o`0001;ooooo0_l00004ooooo`?o00003?ooool2o`0001;ooooo0_l0002Gooooo`00Z?ooool2o`00
00;ooooo0ol0000<ooooo`;o00004oooool2o`0009Kooooo002Xooooo`?o000000?oooooo`000?oo
ool08_ooool2o`0009Kooooo002Hooooo`;o00003oooool2o`000003ooooool0003ooooo01Wooooo
0_l00007ooooo`;o0000U_ooool008;ooooo0_l0000@ooooo`;o00000_ooool2o`0001;ooooo00?o
0000ooooooooool06?ooool2o`0001Gooooo0_l00028ooooo`00P_ooool2o`00013ooooo0_l0000F
ooooo`03o`000?oooooooooo02oooooo0_l00028ooooo`00[?ooool3o`00043ooooo0_l0001goooo
o`00V_ooool2o`0000Sooooo0_l00006ooooo`;o00004Oooool2o`0002kooooo0_l0001gooooo`00
V_ooool2o`0000Sooooo0_l00006ooooo`03o`000?oooooooooo013ooooo0_l0000Dooooo`;o0000
TOooool00:cooooo00?o0000ooooooooool09_ooool2o`00097ooooo002Iooooo`;o00004Oooool0
0ol0003oooooooooo`0Looooo`;o00002?ooool2o`00097ooooo002Iooooo`;o00004Oooool01?l0
003oooooo`000?l0000Cooooo`;o00001_ooool2o`0009_ooooo002?ooooo`;o000000?oooooo`00
0?l000002?ooool2o`0000kooooo00Co0000ooooool0003o00004oooool2o`0000Kooooo0_l0000G
ooooo`;o0000P_ooool008kooooo0ol000000ooooooo0000o`000008ooooo`;o00003_ooool00ol0
003oooooooooo`0Looooo`;o00005oooool2o`0008;ooooo002>ooooo`;o00005Oooool2o`0000Go
oooo0ol0002iooooo`00YOooool4o`0000?ooooo00?o0000ooooooooool05_ooool2o`000:7ooooo
002Pooooo`;o00001Oooool2o`0000?ooooo00?o0000ooooooooool03oooool2o`0000Gooooo0_l0
002Qooooo`00X?ooool2o`0000[ooooo00?o0000ooooooooool03oooool2o`0000kooooo0_l0002H
ooooo`00[?ooool01?l0003oooooo`000?l0000Nooooo`;o0000V?ooool00:_ooooo0_l000001?oo
oooo0000o`000?l0000?ooooo`;o0000Y_ooool0097ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`03ob4Q8Ol0003o000000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`;o00000_oo
ool2o`0000oooooo0_l00006ooooo`;o0000W_ooool0097ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`03ob4Q8Ol0003o000000Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`0Aooooo`;o00001_ooool2o`0000Kooooo0_l0000:ooooo`;o0000R_ooool008Wooooo1_l00002
ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo017ooooo0_l0000>ooooo`;o00002_ooool2o`0008[ooooo002Aooooo`05o`000?oooooo
ooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`?o00004_ooool2o`000:Gooooo002A
ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool00_ooool2o`0000kooooo0_l0000Wooooo`;o0000O?ooool0097ooooo00Go
410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
0_ooool2o`0003Oooooo0_l0001looooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0>ooooo`;o00007oooool2o`0008Sooooo
002Aooooo`05onk^k_lb<S;o0000o`000?o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0
3_ooool2o`0001oooooo0_l0000<ooooo`;o0000N_ooool009?ooooo0_l0000Gooooo`03o`000?oo
oooooooo03gooooo0_l0001jooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00UOooool2o`0001Gooooo0ol0002iooooo`00UOooool2o`0001?ooooo
0ol0002kooooo`00Z_ooool3o`000003ooooool0003o00000;Sooooo002Pooooo`;o00002_ooool0
1?l0003oooooo`000?l00006ooooo`;o0000/?ooool009_ooooo0_l00003ooooo`;o00002_ooool0
0ol0003oooooooooo`07ooooo`;o0000/?ooool009_ooooo0_l0000?ooooo`03o`000?oooooooooo
0;Wooooo002/ooooo`03o`000?oooooooooo01Wooooo0_l0000Wooooo`;o0000MOooool00:cooooo
00Co0000oooooooooooooooo0_l0000Fooooo`;o00009oooool2o`0007Gooooo002/ooooo`?o0000
00?oooooo`000?l000002oooool2o`000:Wooooo002[ooooo`;o00004?ooool2o`0000[ooooo0_l0
002Mooooo`00Zoooool2o`0001cooooo0_l0000fooooo`;o0000IOooool00:cooooo00?o0000oooo
ooooool00_l0000dooooo`;o00006_ooool2o`0006Gooooo002Booooo`;o00001Oooool2o`00017o
oooo00?o0000ooooooooool00_l0000dooooo`;o0000POooool009;ooooo0_l00005ooooo`;o0000
4Oooool00ol0003oooooooooo`0Sooooo`;o00004_ooool2o`00083ooooo002/ooooo`03o`000?oo
oooooooo02?ooooo0_l0000Booooo`;o00006oooool2o`0006?ooooo002/ooooo`03o`000?oooooo
oooo01Kooooo0_l0000looooo`;o0000Hoooool009kooooo0_l0000<ooooo`?o00005_ooool2o`00
01oooooo0_l00020ooooo`00Q?ooool2o`0001Sooooo0_l00003ooooo`;o00001oooool00ol0003o
ooooooooo`0gooooo`;o0000P?ooool008Cooooo0_l0000Hooooo`;o00000oooool2o`0000Oooooo
00Co0000ooooool0003o0000;_ooool2o`0008Sooooo0026ooooo`;o00003Oooool2o`0001Gooooo
00Co0000ooooool0003o00004Oooool2o`0000Cooooo0_l0000Eooooo`;o0000R?ooool008Kooooo
0_l0000=ooooo`;o00001?ooool2o`0000oooooo0ol0000Booooo`;o00001?ooool2o`00023ooooo
0_l0001mooooo`00Voooool2o`0000;ooooo0_l0000;ooooo`?o0000;oooool2o`0000Wooooo0_l0
001mooooo`00Toooool2o`0000[ooooo0_l0000;ooooo`03o`000?oooooooooo01?ooooo0_l0000J
ooooo`;o0000R?ooool008oooooo0_l00002ooooo`;o00005oooool00ol0003oooooooooo`0Coooo
o`;o0000Y?ooool008oooooo0_l0000Kooooo`03o`000?oooooooooo027ooooo0_l0002Fooooo`00
[?ooool3o`00027ooooo0_l0002Fooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`0mooooo`;o0000N_ooool00:cooooo00?o0000ooooooooool0?Oooool2o`00
07[ooooo002/ooooo`03o`000?oooooooooo027ooooo0_l0000Jooooo`;o0000N_ooool008Kooooo
0_l000001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool01_ooool2o`0000Cooooo0_l0000C
ooooo`;o00006_ooool2o`0007[ooooo0026ooooo`;o000000KoooooogMgMonHV9SooooooiRHV?mg
MgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool01?l0003oooooo`000?l00005ooooo`;o00001?ooool2o`000:_ooooo0021ooooo`Ko0000
0_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHo`000?l000002Oooool00ol0003o
ooooooooo`03ooooo`04o`000?oooooo0000o`0000Gooooo0_l0002aooooo`00ROooool01Ol0003o
oooooooooooooooo000000gooooo0_l000000oo^k^koooooooooo`05ooooo`03ogMgMolb<S;ooooo
00Cooooo0ol000000ooooooo0000o`00000;ooooo`;o00000_ooool2o`0001Oooooo0_l0000Boooo
o`;o0000N?ooool008Wooooo00Go0000ooooooooooooooooo`000009ooooo`;o00000oooool00omg
MgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool01?l0003ooooooooooooo
ool2o`0000[ooooo0ol00002ooooo`;o00003oooool2o`0000Kooooo0_l00006ooooo`;o00002_oo
ool2o`0007Sooooo0029ooooo`05oa0@4?ooooooooooooooool@41002Oooool2o`0000Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`?o00003Oooool2o`0000Sooooo0_l0
000:ooooo`;o00003_ooool2o`0008Cooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool3o`0001Oooooo
0_l0002Pooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Wooooo0_l000001OnHV9So410@
o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo01kooooo0_l0002Iooooo`00
Uoooool2o`0001?ooooo00?o0000ooooooooool03_ooool2o`0000kooooo0_l0000/ooooo`;o0000
Joooool008_ooooo0_l0000:ooooo`?o00004_ooool00ol0003oooooooooo`0>ooooo`;o0000??oo
ool2o`0006_ooooo002;ooooo`;o00002_ooool3o`0001;ooooo00?o0000ooooooooool06?ooool2
o`0001;ooooo0_l0000Nooooo`;o00003_ooool2o`0005_ooooo002/ooooo`?o00006?ooool2o`00
01;ooooo0_l00007ooooo`?o00009?ooool2o`0005_ooooo002/ooooo`03o`000?oooooooooo03Go
oooo0ol00021ooooo`00[?ooool00ol0003oooooooooo`0Dooooo`;o00000_ooool2o`0009oooooo
002Booooo`;o00006?ooool00ol0003oooooooooo`0Dooooo`;o00000_ooool2o`0000_ooooo0_l0
002Booooo`00T_ooool2o`0001Sooooo00?o0000ooooooooool03?ooool2o`0001Oooooo0_l0002B
ooooo`00[?ooool00ol0003oooooooooo`02ooooo`;o00002?ooool3o`0001Kooooo0_l0002Boooo
o`00[?ooool00ol0003oooooooooo`02ooooo`;o00002Oooool2o`00017ooooo0_l0000Dooooo`;o
0000POooool0093ooooo0_l0000Jooooo`03o`000?oooooooooo023ooooo0_l0000<ooooo`;o0000
1_ooool2o`0000[ooooo0_l0001eooooo`00S_ooool4o`0001[ooooo0ol0000=ooooo`;o00002_oo
ool2o`0001?ooooo0_l0000Booooo`;o0000MOooool008kooooo0_l0000Looooo`03o`000?oooooo
oooo00gooooo0_l0000:ooooo`;o00009oooool2o`0007Gooooo001oooooo`;o00001Oooool2o`00
02Cooooo00Co0000ooooool0003o0000@Oooool2o`0007Gooooo001oooooo`;o00001Oooool2o`00
0003ooooool0003o000000?ooooo0_l0000Looooo`04o`000?oooooo0000o`00013ooooo0_l0000J
ooooo`Co0000R?ooool008Wooooo0_l00003ooooo`;o00007?ooool00ol0003oooooooooo`0Aoooo
o`;o00006_ooool4o`0008Sooooo002/ooooo`03o`000?oooooooooo01Gooooo0_l0000Hooooo`;o
0000R?ooool00:cooooo00?o0000ooooooooool05Oooool2o`0001Sooooo0_l00028ooooo`00[?oo
ool00ol0003oooooooooo`0_ooooo`;o0000R?ooool00:cooooo0_l0000Qooooo`;o0000Uoooool0
0:cooooo0ol00009ooooo`;o00005Oooool2o`0000cooooo0_l0000Dooooo`;o0000Loooool00:co
oooo00?o0000ooooooooool02Oooool2o`0001cooooo0_l00005ooooo`;o00005?ooool2o`0007?o
oooo002/ooooo`03o`000?oooooooooo00_ooooo0_l0000Jooooo`;o00004?ooool2o`0007kooooo
0009ooooo`Co000000?o410@ooooooooool05_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0?
ooooo`06onk^k_lb<S;o0000oc8b<_o^k^kooooo0_l00002ooooo`;o8B4Q1?ooool5o`0000Cooooo
00GoA4A4o`000?l0003o<S8bomgMg@0Fooooo`03o`000?oooooooooo00_ooooo0_l0000;ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000
oc8b<_oMgMd00oooool2o`0000[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Ooo
ool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd06?ooool4o`00
0003oa0@4?oooooooooo01;ooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0>
ooooo`06ogMgMonHV9SooooooiRHV?mgMgOooooo0_l00002ooooo`;o8B4Q1?ooool01OnHV9So8B4Q
onk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool05Oooool00ol0003oooooooooo`0<ooooo`;o
00002_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`;o000000?ok^k^oooo
oom4A4@01oooool00omgMgOo<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Sooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool06Oooool00ol0003ooooooooo
o`0Dooooo`001_l00005ooooo`03o`000?oooooooooo013ooooo1_l00002ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00Gooooo1_l0
0002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`05ooooo`Ko0000
0_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo00cooooo0_l0000:ooooo`05oa0@4?oooooooooooooo
ool@41002oooool2o`000003ob4Q8Oo^k^kooooo00Sooooo00?o0000ooooooooool03Oooool01Ol@
413ooooooooooooooooo410@013ooooo00?o0000ooooooooool03Oooool01Ol@413ooooooooooooo
oooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooo
oooooooo000000oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01?ooool2o`000003oooooomgMgOo<S8b01Kooooo00?o0000oooooooo
ool06?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omg
MgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0>
ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb
<S;ooooo01Wooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`03oooool01_l0003ooooooooooooooooo0000ooooo`;o00002oooool00omgMgOoIVIVoooo
o`03ooooo`?o000000?o<S8bolc<c?ooool05Oooool00ol0003oooooooooo`0Cooooo`;o00000ooo
ool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00kooooo0_l00003ooooo`03o`000?oooooooooo00[ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06_ooool00ol0003oooooooooo`0Dooooo`002oooool0
0ol0003oooooooooo`0Hooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgoooo
o`03ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`00
0?oooooooooo017ooooo00Ko410@oooooooooooooooooa0@4?ooool2o`0000cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Hooooo`?o00001oooool2o`0000[ooooo0_l00003oooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo013ooooo0_l00003ooooo`03oa0@4?oooooooooo00[ooooo00?o0000ooooooooool04Oooool0
1Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooo
ooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo0_l0000I
ooooo`03o`000?oooooooooo00Oooooo0_l00003ooooo`;o00002_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Gooooo
0_l0000:ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Dooooo`002Oooool00omEEEGoIVIVo`00000Joooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000@ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`;o0000
0_ooool01OnHV9So410@o`000?l0003oc<c<00Cooooo1?l0000Gooooo`03o`000?oooooooooo00Oo
oooo0_l00003ooooo`;o00002_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c004ooooo`Co00001?ooool2o`0000[ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co0000
6Oooool00omEEEGoIVIVo`00000Fooooo`00Q?ooool2o`0000Cooooo0_l0000Pooooo`03o`000?oo
oooooooo00Oooooo0_l0002`ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00S_ooool2o`00
01cooooo00?o0000ooooooooool03?ooool2o`0002_ooooo0_l0001cooooo`;o00000_ooool2o`00
00Gooooo002>ooooo`;o00001_ooool2o`000003ooooool0003o0000017ooooo00?o0000oooooooo
ool03?ooool2o`0002_ooooo0ol0001booooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1Oooool0
09Kooooo0_l000000ooooooo0000o`00000Aooooo`03o`000?oooooooooo03[ooooo0_l0000Uoooo
o`;o0000C?ooool01?oMgMgo0000oa0@4?o<c<`6ooooo`001oooooooo`0004co00003?ooool01?o^
k^ko8B4Qoa0@4?o^k^h6ooooo`001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo0ol00005ooooo`?o00001Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo0ol00005ooooo`03o`000?oooooooooo00;ooooo0_l000000ooooooo0000ooooo`02o`00
00Cooooo00Co0000oooooooooooooooo0_l00003ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo0_l00000
0ooooooo0000ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool0
1?lQ8B7oMgMgogMgMolb<S86ooooo`001oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool07oooool2o`0000Gooooo0ol00008ooooo`;o00000oooool2
o`0001Oooooo00?o0000ooooooooool08_ooool2o`0000?ooooo00?o0000ooooooooool06oooool2
o`0000Wooooo0ol0000Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02Oooool2
o`0000;ooooo0_l00005ooooo`00S?ooool4o`0000?ooooo0_l0000Gooooo`03o`000?oooooooooo
057ooooo0_l0001Vooooo`00S?ooool2o`0001kooooo00?o0000ooooooooool08_ooool2o`0009Go
oooo002/ooooo`03o`000?oooooooooo02;ooooo0_l0002Eooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00Q?ooool4o`0002Cooooo0ol0000Yoooo
o`;o0000S_ooool008Cooooo1?l0000Tooooo`03o`000?oooooooooo01Oooooo0_l0000@ooooo`;o
0000S_ooool00:cooooo00?o0000ooooooooool05oooool2o`0002cooooo0_l0001booooo`00[?oo
ool00ol0003oooooooooo`07ooooo`;o00003_ooool2o`0002cooooo0_l0001booooo`00[?ooool0
0ol0003oooooooooo`07ooooo`;o00003_ooool2o`000:3ooooo002?ooooo`;o00006oooool00ol0
003oooooooooo`2iooooo`00R?ooool2o`0000Gooooo0_l0000Kooooo`03o`000?oooooooooo01Oo
oooo0_l0002Pooooo`00Q?ooool2o`0000;ooooo0_l0000Rooooo`03o`000?oooooooooo00Wooooo
0_l00004ooooo`;o00001_ooool2o`000:3ooooo0024ooooo`;o00009_ooool00ol0003ooooooooo
o`09ooooo`;o00001?ooool2o`00013ooooo0_l0002Fooooo`00Soooool2o`0001_ooooo0ol0000>
ooooo`;o00004Oooool2o`0001Oooooo0_l0001mooooo`00Ooooool2o`0000kooooo0_l0000Koooo
o`03o`000?oooooooooo00Cooooo0_l00008ooooo`;o0000:_ooool2o`0007gooooo001oooooo`;o
0000:oooool00ol0003oooooooooo`04ooooo`;o0000=?ooool2o`0007gooooo002/ooooo`03o`00
0?oooooooooo027ooooo0_l0000Fooooo`;o00005_ooool2o`0006Kooooo002/ooooo`03o`000?oo
oooooooo027ooooo0_l0000Fooooo`;o00002Oooool2o`0000_ooooo0_l0001Vooooo`00Roooool2
o`0001oooooo00?o0000ooooooooool08Oooool2o`0001Kooooo0_l00009ooooo`;o0000Loooool0
08_ooooo0_l0000Oooooo`03o`000?oooooooooo027ooooo0_l0002Fooooo`00[?ooool00ol0003o
ooooooooo`0Qooooo`;o00007oooool2o`0007Gooooo002/ooooo`?o0000@_ooool2o`0007Gooooo
002/ooooo`03o`000?oooooooooo00?ooooo0_l0002dooooo`00[?ooool00ol0003oooooooooo`03
ooooo`;o00001Oooool2o`000:gooooo002?ooooo`;o00006oooool00ol0003oooooooooo`0:oooo
o`;o00002Oooool2o`000:;ooooo002?ooooo`;o00006oooool00ol0003oooooooooo`0Aooooo`;o
00000_ooool2o`0004Sooooo0_l0001Hooooo`00Qoooool2o`0002?ooooo00?o0000ooooooooool0
4Oooool2o`0001Cooooo0_l0000fooooo`;o0000F?ooool008Oooooo0_l0000Sooooo`03o`000?oo
oooooooo00Kooooo0_l0000Booooo`;o00002oooool2o`0001[ooooo0_l0001dooooo`00U_ooool2
o`0001Cooooo00?o0000ooooooooool01_ooool2o`0000Sooooo0_l00008ooooo`;o00007?ooool2
o`0000Wooooo0_l0001dooooo`00U_ooool2o`0001Cooooo0ol0000@ooooo`;o00009_ooool2o`00
07oooooo002/ooooo`03o`000?oooooooooo01oooooo0_l0002Hooooo`00P_ooool2o`0002Sooooo
00?o0000ooooooooool07oooool2o`0009Sooooo0022ooooo`;o00000oooool2o`0002?ooooo00?o
0000ooooooooool0;Oooool2o`0000Oooooo0_l00021ooooo`00QOooool4o`0000Cooooo0_l0000L
ooooo`;o00002_ooool2o`0001_ooooo0_l00006ooooo`;o00001oooool2o`00087ooooo0025oooo
o`;o00001_ooool2o`0001cooooo0_l0000:ooooo`;o00006oooool2o`0000Gooooo0_l0000Boooo
o`;o0000Moooool007oooooo0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd00oooool3o`0002kooooo0_l0000B
ooooo`;o0000Moooool007oooooo0_l00008ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00;ooooo0ol0
0014ooooo`;o0000MOooool008Wooooo00Go410@oooooooooooooooooa0@4002o`0000[ooooo00?o
V9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000=_ooool2o`0000[ooooo0_l0
001eooooo`00ROooool01?l0003oooooooooooooool3o`0000_ooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01Oooooo0_l0000Mooooo`;o0000POoo
ool008?ooooo0_l00004ooooo`04o`000?ooooooooooooooo`?o00003?ooool00omgMgOoIVIVoooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Gooooo`;o0000
7?ooool2o`0008;ooooo0023ooooo`;o00001?ooool01Ol@413ooooooooooooooooo410@00Oooooo
0_l00006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0eooooo`;o00002?ooool2o`0007Sooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1oooool2o`0000;ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oo
oooo00Co0000oooooooooooooooo0_l0000looooo`;o0000N?ooool008Wooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00Co0000
oooooooooooooooo0_l0002fooooo`00Voooool2o`0000oooooo00Co0000oooooooooooooooo0_l0
000Wooooo`;o0000SOooool009_ooooo0_l0000?ooooo`03o`000?oooooooooo00Kooooo0_l0000Q
ooooo`?o0000SOooool009Sooooo0_l0000:ooooo`;o00001_ooool00ol0003oooooooooo`06oooo
o`;o00001?ooool3o`0001[ooooo0_l0002>ooooo`00V?ooool2o`0000[ooooo0_l00006ooooo`?o
00003?ooool3o`000003ooooool0003o00000:Oooooo002/ooooo`03o`000?oooooooooo013ooooo
0_l0002Wooooo`00Yoooool2o`0000?ooooo00?o0000ooooooooool0?_ooool2o`0007Wooooo002W
ooooo`;o00000oooool00ol0003oooooooooo`08ooooo`;o0000=?ooool2o`0007Wooooo002Koooo
o`;o00003oooool00ol0003oooooooooo`08ooooo`;o0000[oooool008_ooooo0_l0000>ooooo`;o
00003oooool00ol0003oooooooooo`0Cooooo`;o00002oooool2o`0009Oooooo002;ooooo`;o0000
1Oooool2o`0001Sooooo00?o0000ooooooooool04oooool2o`0000_ooooo0_l0002Gooooo`00T_oo
ool2o`0001Sooooo00?o0000ooooooooool0^Oooool0087ooooo0_l0000;ooooo`;o00007?ooool3
o`0000Wooooo0_l00002ooooo`;o00002Oooool2o`0000Kooooo0_l0002Gooooo`00POooool2o`00
00_ooooo0_l00004ooooo`;o00005_ooool00ol0003oooooooooo`09ooooo`;o00000_ooool2o`00
00Wooooo0_l00006ooooo`;o00001Oooool2o`0001?ooooo0_l0001kooooo`00U?ooool2o`0000oo
oooo0_l00005ooooo`03o`000?oooooooooo02Oooooo0_l00007ooooo`?o00002Oooool2o`0007_o
oooo002Uooooo`;o00001Oooool00ol0003oooooooooo`0`ooooo`?o0000Q_ooool008Cooooo0_l0
0006ooooo`;o00007_ooool00ol0003oooooooooo`2iooooo`00Q?ooool2o`0000Kooooo0_l0000N
ooooo`03o`000?oooooooooo0;Wooooo002Jooooo`;o00004?ooool00ol0003oooooooooo`0^oooo
o`;o0000ROooool009[ooooo0_l0000@ooooo`03o`000?oooooooooo02kooooo0_l00029ooooo`00
R_ooool2o`0001gooooo0_l000001?oooooo0000o`000?l0000]ooooo`;o00002_ooool2o`0007ko
oooo0028ooooo`Co00007Oooool2o`000003ooooool0003ooooo00?ooooo0_l0000<ooooo`;o0000
2_ooool2o`0000oooooo0_l0000:ooooo`;o00002_ooool2o`0007;ooooo0028ooooo`;o00005Ooo
ool2o`0000_ooooo00?o0000ooooooooool00_ooool2o`0000Kooooo0_l00004ooooo`;o00002_oo
ool2o`0001_ooooo0_l0000:ooooo`;o0000L_ooool009oooooo0_l00006ooooo`;o00000oooool0
0ol0003oooooooooo`0:ooooo`;o00003oooool3o`0009_ooooo002Wooooo`;o000000Coooooo`00
0?l0003o00004?ooool2o`0000_ooooo0ol0000Vooooo`;o0000Loooool00:[ooooo0ol00006oooo
o`;o00002?ooool2o`0000Cooooo0_l0000Gooooo`;o00005Oooool2o`0007?ooooo0026ooooo`;o
00009?ooool00ol0003oooooooooo`04ooooo`;o00001oooool2o`0000Gooooo0_l0000Gooooo`;o
0000R_ooool008Kooooo0_l0000Cooooo`;o00003oooool00ol0003oooooooooo`0=ooooo`;o0000
7?ooool2o`0008cooooo002Kooooo`;o00003oooool3o`0001;ooooo0_l0000Gooooo`;o0000S?oo
ool00:cooooo00?o0000ooooooooool00oooool2o`0000gooooo0ol00004ooooo`;o0000W_ooool0
08Kooooo0_l0000Tooooo`03o`000?oooooooooo00?ooooo0_l00007ooooo`;o00001?ooool3o`00
00Cooooo0_l0002Nooooo`00Q_ooool2o`0002Cooooo00?o0000ooooooooool03?ooool2o`0000Co
oooo0_l0002Uooooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool05oooool2o`0001cooooo
0_l0000:ooooo`;o0000M_ooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo01Oooooo0_l0
000@ooooo`;o00002_ooool2o`0000[ooooo0_l0001fooooo`00TOooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`0Yooooo`;o0000S_ooool0097ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
2?ooool01?mgMgOo<S8bo`000?l00003ooooo`;o0000^_ooool0097ooooo00Go410@oooooooooooo
oooooa0@400?ooooo`Co00000oooool2o`0000oooooo0_l0000>ooooo`;o0000VOooool0097ooooo
00Go0000ooooooooooooooooo`00000?ooooo`;o00001Oooool3o`0000Sooooo0ol00003ooooo`;o
00003_ooool2o`0009Wooooo002Aooooo`05o`000?ooooooooooooooool000001oooool2o`0000?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00Sooooo0ol0002^oooo
o`00TOooool01Ol@413oooooo`000?l0003o410@00?ooooo0_l00002ooooo`;o00000oooool00ol0
003oooooooooo`07ooooo`?o0000^Oooool0097ooooo00GoMgMgoiRHV?l0003o0000ogMgM`03oooo
o`;o00001oooool00ol0003oooooooooo`07ooooo`?o00009Oooool2o`0009;ooooo002Aooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02Oooool2o`000003ooooool0003o000000;o00001_ooool00ol0
003oooooooooo`0Tooooo`?o00002Oooool2o`0000cooooo0_l0001iooooo`00Woooool2o`0000_o
oooo00?o0000ooooooooool03?ooool2o`0001Kooooo0_l0000:ooooo`;o00003?ooool2o`0007Wo
oooo002/ooooo`03o`000?oooooooooo00cooooo0_l0002[ooooo`00V?ooool2o`0001;ooooo00?o
0000ooooooooool03?ooool2o`000:_ooooo002Hooooo`;o00004_ooool3o`000;Wooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo00;ooooo0_l0002eooooo`00U_ooool2o`0000gooooo0_l00005ooooo`;o00000ooo
ool2o`0002Sooooo0_l0002;ooooo`00U_ooool2o`0000gooooo0_l00005ooooo`;o0000;Oooool2
o`0008_ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Gooooo`;o00004oooool00ol0003o
ooooooooo`06ooooo`;o00001Oooool2o`000:[ooooo002Aooooo`;o00001?ooool2o`0001?ooooo
0ol00006ooooo`;o00001Oooool2o`00013ooooo0_l0000Fooooo`;o0000P?ooool0097ooooo0_l0
000Iooooo`03o`000?oooooooooo00cooooo0_l0000Aooooo`;o00005_ooool2o`00083ooooo002=
ooooo`;o00007Oooool00ol0003oooooooooo`05ooooo`;o00001Oooool2o`00013ooooo0_l0002I
ooooo`00SOooool3o`00017ooooo0_l00009ooooo`03o`000?oooooooooo00Cooooo0ol0000Goooo
o`;o00002Oooool2o`0008kooooo002>ooooo`;o00004Oooool2o`0000Wooooo00?o0000oooooooo
ool01?ooool2o`00027ooooo1?l0002>ooooo`00XOooool2o`0000Wooooo00?o0000ooooooooool0
4Oooool2o`0001Cooooo0ol0002?ooooo`00XOooool2o`0000Wooooo00?o0000ooooooooool04Ooo
ool3o`0001?ooooo0_l0002@ooooo`00W?ooool2o`0000kooooo00?o0000ooooooooool04_ooool2
o`0001?ooooo0_l0002@ooooo`00W?ooool2o`0000kooooo0ol0002iooooo`00Roooool2o`0001oo
oooo00?o0000ooooooooool06Oooool2o`0009kooooo002;ooooo`;o00007oooool00ol0003ooooo
ooooo`0Iooooo`;o0000W_ooool00:cooooo00?o0000ooooooooool0<?ooool2o`0008Oooooo002H
ooooo`;o00004_ooool00ol0003oooooooooo`0Qooooo`?o00003?ooool2o`0008Oooooo002Hoooo
o`;o00004_ooool00ol0003oooooooooo`0Qooooo`?o0000UOooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool02_oo
ool2o`0000Wooooo0_l0002Rooooo`00ZOooool2o`000004ooooool0003o0000o`0000[ooooo0_l0
0006ooooo`;o000000?oooooo`000?l00000X_ooool008[ooooo0_l0000Mooooo`;o000000?ooooo
o`000?ooool04oooool2o`000:Gooooo002:ooooo`;o00004oooool2o`0000_ooooo00?o0000oooo
ooooool02_ooool2o`0001;ooooo0_l0002Iooooo`00R_ooool2o`0001?ooooo0_l00005ooooo`;o
00001?ooool00ol0003oooooooooo`0:ooooo`;o00004?ooool4o`0009Wooooo002:ooooo`?o0000
0_ooool2o`0001Gooooo0_l00004ooooo`03o`000?oooooooooo01cooooo0_l0002Kooooo`00ROoo
ool01_o^k^ko<S8bo`000?l0003ok^k^ooooo`;o00000_ooool2ob4Q8@Kooooo00?o0000onk^k_oo
ool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool07?ooool2o`00
09_ooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool2o`000003oooooolQ8B7o8B4Q
00Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
01[ooooo0_l0002Mooooo`00ROooool01Ol@413ooooooooooooooooo410@00;ooooo0_l00002oooo
o`;o00001Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool06_ooool2o`0009gooooo0029ooooo`05o`000?ooooooooooooooool000001_ooool2o`00
00Gooooo0_l00008ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Vooooo`;o0000TOooool008Wo
oooo00Go0000ooooooooooooooooo`00000=ooooo`;o000000?oc<c<ooooooooool00_ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool03Oooool2o`0001Oooooo0_l0002A
ooooo`00ROooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo0_l0002Zooooo`00ROooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0^Oooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool05oooool2o`000:3ooooo002G
ooooo`;o00004oooool00ol0003oooooooooo`0Gooooo`;o0000X?ooool009Oooooo0_l0000Coooo
o`03o`000?oooooooooo01Cooooo1Ol0002Pooooo`00[?ooool00ol0003oooooooooo`0Dooooo`?o
0000X_ooool009Sooooo0_l0000Booooo`?o00005?ooool2o`000:?ooooo002Hooooo`;o00004_oo
ool00ol0003oooooooooo`0Dooooo`;o0000Xoooool00:cooooo00?o0000ooooooooool04oooool2
o`000:Cooooo002/ooooo`03o`000?oooooooooo013ooooo1Ol0002Tooooo`00[?ooool00ol0003o
ooooooooo`0@ooooo`?o0000Y_ooool009Gooooo0_l0000Eooooo`03o`000?oooooooooo01gooooo
0_l0002Jooooo`00UOooool2o`0001Gooooo00?o0000ooooooooool07Oooool2o`0009[ooooo002V
ooooo`;o00001?ooool00ol0003oooooooooo`2iooooo`00Y_ooool2o`0000Cooooo0ol0002ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00TOooool2o`0001Wooooo00?o0000ooooooooool0
^Oooool0097ooooo0_l0000Iooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Zooooo`?o00002oooool2o`000:ko
oooo002Zooooo`?o00002Oooool4o`000:kooooo002Zooooo`?o00002Oooool2o`000;3ooooo002D
ooooo`;o00001oooool4o`0000_ooooo0ol0002iooooo`00U?ooool2o`0000Oooooo1?l0000;oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Eooooo`;o0000
5Oooool00ol0003oooooooooo`02ooooo`;o00003?ooool2o`000:Oooooo002Eooooo`;o00005Ooo
ool00ol0003oooooooooo`02ooooo`;o00003?ooool2o`000:Oooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Hooooo`;o00004_ooool00ol0003o
ooooooooo`2iooooo`00V?ooool2o`0001;ooooo0ol0002iooooo`00V_ooool2o`00013ooooo0ol0
002iooooo`00V_ooool2o`00013ooooo0ol0002iooooo`00V_ooool2o`00013ooooo00?o0000oooo
ooooool0^Oooool00:[ooooo0ol0002kooooo`00Z_ooool3o`000;_ooooo002Rooooo`Co000000?o
410@ooooooooool00oooool00ol0003oooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`03o`000?oooooooooo00Gooooo0ol0002ioooo
o`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?oo
ool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00X_ooool00omE
EEGoIVIVo`000033ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00Z_ooool01?l@413o0000o`000?l0002jooooo`00Zoooool00ol0003oooooooooo`2joooo
o`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool01_l0003oMgMgo`000?l0003oEEEEonk^
k[Oooooo002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoEEEE]oooool00:_ooooo00?o0000onk^
k_ooool00_ooool00ol0003oooooooooo`2eooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03
o`000?oooooooooo0;Gooooo002[ooooo`06o`000?mEEEGok^k^oooooomgMgOoIVIV]oooool00:[o
oooo00?o410@o`000?mgMgL00_l000000omVIVKok^k^ooooo`2fooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.42761 .83667 Mdot
.58991 .24229 Mdot
.48045 .63387 Mdot
.48262 .75056 Mdot
.51374 .77258 Mdot
.62728 .41104 Mdot
.44296 .40222 Mdot
.71739 .61197 Mdot
.55782 .10872 Mdot
.41292 .50756 Mdot
.55625 .388 Mdot
.69012 .69892 Mdot
.5803 .79892 Mdot
.52959 .30133 Mdot
.69912 .65928 Mdot
.53384 .34643 Mdot
.58998 .34987 Mdot
.56235 .82873 Mdot
.47561 .19626 Mdot
.68484 .4253 Mdot
.58652 .78342 Mdot
.65015 .40929 Mdot
.65429 .44644 Mdot
.53889 .86271 Mdot
.57985 .88962 Mdot
.59979 .53084 Mdot
.56875 .52649 Mdot
.42549 .29761 Mdot
.69054 .48303 Mdot
.58345 .23306 Mdot
.56265 .82056 Mdot
.58197 .13763 Mdot
.72095 .45628 Mdot
.60647 .59587 Mdot
.42511 .79468 Mdot
.54918 .14001 Mdot
.52482 .91741 Mdot
.44532 .76282 Mdot
.68813 .50009 Mdot
.65628 .77783 Mdot
.53692 .94609 Mdot
.53231 .79709 Mdot
.47154 .12477 Mdot
.38579 .43816 Mdot
.47897 .89774 Mdot
.44136 .21075 Mdot
.45703 .23238 Mdot
.4684 .02804 Mdot
.41547 .72091 Mdot
.67812 .40774 Mdot
.4418 .05269 Mdot
.66206 .67985 Mdot
.38723 .8746 Mdot
.39243 .46784 Mdot
.42741 .19045 Mdot
.66419 .272 Mdot
.71545 .61728 Mdot
.59631 .36809 Mdot
.37112 .54929 Mdot
.51709 .85769 Mdot
.46638 .17627 Mdot
.56006 .06409 Mdot
.68691 .4945 Mdot
.43406 .65337 Mdot
.70044 .37156 Mdot
.63817 .22117 Mdot
.42385 .65362 Mdot
.47259 .24066 Mdot
.41838 .65608 Mdot
.50074 .91225 Mdot
.6176 .53145 Mdot
.45904 .67298 Mdot
.41398 .54089 Mdot
.49689 .75458 Mdot
.68683 .49308 Mdot
.50244 .41927 Mdot
.38682 .87267 Mdot
.51775 .22542 Mdot
.67714 .62768 Mdot
.5459 .73314 Mdot
.38424 .63835 Mdot
.56116 .1964 Mdot
.53309 .62841 Mdot
.50208 .84619 Mdot
.72516 .47957 Mdot
.5584 .45994 Mdot
.49209 .80871 Mdot
.45485 .80366 Mdot
.57774 .31066 Mdot
.47932 .24124 Mdot
.57843 .89063 Mdot
.73573 .67639 Mdot
.49929 .27957 Mdot
.40291 .50719 Mdot
.44541 .29671 Mdot
.74907 .6335 Mdot
.51658 .27188 Mdot
.41746 .10868 Mdot
.36376 .72008 Mdot
.59851 .36865 Mdot
.39306 .65791 Mdot
.53325 .21803 Mdot
.70047 .66359 Mdot
.40253 .25811 Mdot
.40038 .77152 Mdot
.59378 .65152 Mdot
.61354 .56931 Mdot
.54114 .29861 Mdot
.50418 .29056 Mdot
.5056 .90525 Mdot
.46392 .22184 Mdot
.48065 .75303 Mdot
.56474 .11588 Mdot
.62532 .25625 Mdot
.65139 .11887 Mdot
.49193 .30313 Mdot
.5018 .19644 Mdot
.69225 .32942 Mdot
.65713 .25244 Mdot
.57975 .83947 Mdot
.59001 .78051 Mdot
.64766 .61376 Mdot
.69202 .51651 Mdot
.49647 .91684 Mdot
.44758 .72205 Mdot
.64283 .29477 Mdot
.76258 .53687 Mdot
.41631 .19742 Mdot
.52781 .57319 Mdot
.65881 .47849 Mdot
.38954 .38054 Mdot
.66203 .76186 Mdot
.63685 .47489 Mdot
.54605 .20902 Mdot
.68412 .59943 Mdot
.52013 .92626 Mdot
.677 .39611 Mdot
.41826 .60602 Mdot
.72286 .50186 Mdot
.68815 .69534 Mdot
.65683 .19274 Mdot
.5476 .55365 Mdot
.41483 .36545 Mdot
.5931 .35933 Mdot
.66562 .35006 Mdot
.71752 .42024 Mdot
.76246 .29826 Mdot
.51028 .23911 Mdot
.41858 .69477 Mdot
.44884 .00107 Mdot
.51508 .18768 Mdot
.49036 .78725 Mdot
.5194 .8901 Mdot
.48274 .68279 Mdot
.63454 .53769 Mdot
.59447 .82136 Mdot
.68591 .56171 Mdot
.68108 .30407 Mdot
.53725 .9008 Mdot
.57877 .84633 Mdot
.55454 .72157 Mdot
.67284 .64804 Mdot
.49361 .99645 Mdot
.44682 .08546 Mdot
.42822 .19252 Mdot
.42694 .83237 Mdot
.7113 .39307 Mdot
.37831 .5153 Mdot
.43523 .73699 Mdot
.56877 .86303 Mdot
.63869 .29089 Mdot
.48739 .26462 Mdot
.50712 .75641 Mdot
.5167 .76486 Mdot
.55547 .3418 Mdot
.71626 .43433 Mdot
.75574 .5996 Mdot
.63508 .50847 Mdot
.44307 .35186 Mdot
.68904 .48062 Mdot
.61227 .79469 Mdot
.6205 .83766 Mdot
.54348 .63296 Mdot
.51111 .97507 Mdot
.42999 .58911 Mdot
.51631 .06155 Mdot
.76216 .51169 Mdot
.59809 .15722 Mdot
.52444 .96378 Mdot
.52758 .17899 Mdot
.39329 .14689 Mdot
.6675 .3552 Mdot
.51347 .6698 Mdot
.72586 .53648 Mdot
.39317 .84747 Mdot
.68517 .70917 Mdot
.416 .6819 Mdot
.66658 .82678 Mdot
.56899 .72984 Mdot
.45644 .68317 Mdot
.44504 .65095 Mdot
.44113 .61183 Mdot
.54904 .69181 Mdot
.63179 .87798 Mdot
.39015 .62021 Mdot
.51482 .34556 Mdot
.63477 .46662 Mdot
.46673 .75385 Mdot
.47753 .27349 Mdot
.5676 .44981 Mdot
.64206 .6561 Mdot
.50663 .20596 Mdot
.37827 .50594 Mdot
.5588 .50274 Mdot
.41634 .79661 Mdot
.45881 .18552 Mdot
.49087 .99797 Mdot
.42694 .43858 Mdot
.58302 .74042 Mdot
.67485 .74118 Mdot
.49246 .18325 Mdot
.37396 .6087 Mdot
.38221 .62146 Mdot
.37995 .43807 Mdot
.5337 .35001 Mdot
.57713 .58903 Mdot
.57981 .22192 Mdot
.49086 .26744 Mdot
.69617 .66963 Mdot
.51864 .01827 Mdot
.47538 .238 Mdot
.51381 .47271 Mdot
.64324 .85933 Mdot
.39904 .435 Mdot
.56738 .55799 Mdot
.41825 .05936 Mdot
.47233 .79348 Mdot
.43489 .13587 Mdot
.64096 .64859 Mdot
.3859 .46399 Mdot
.55051 .05427 Mdot
.6034 .32458 Mdot
.42786 .11751 Mdot
.61775 .52723 Mdot
.61083 .17618 Mdot
.42219 .46067 Mdot
.63316 .7466 Mdot
.46515 .15601 Mdot
.61811 .51563 Mdot
.68783 .51982 Mdot
.42025 .93946 Mdot
.48144 .29181 Mdot
.52589 .62378 Mdot
.61417 .78298 Mdot
.59904 .50413 Mdot
.52429 .71893 Mdot
.50805 .14787 Mdot
.50912 .48307 Mdot
.72245 .56403 Mdot
.40191 .16153 Mdot
.39884 .56269 Mdot
.56757 .55655 Mdot
.39492 .25981 Mdot
.52806 .43533 Mdot
.47726 .14893 Mdot
.49961 .87876 Mdot
.47087 .22158 Mdot
.57058 .25605 Mdot
.58964 .19959 Mdot
.59204 .58623 Mdot
.60195 .2168 Mdot
.46548 .12488 Mdot
.41338 .45524 Mdot
.46767 .83931 Mdot
.5949 .82149 Mdot
.52514 .69259 Mdot
.58493 .50741 Mdot
.46892 .02896 Mdot
.56798 .44793 Mdot
.63585 .52572 Mdot
.68976 .53849 Mdot
.48705 .71296 Mdot
.54655 .61384 Mdot
.54615 .88858 Mdot
.70851 .63605 Mdot
.55221 .32664 Mdot
.52041 .50607 Mdot
.58081 .47587 Mdot
.59419 .19986 Mdot
.40318 .49364 Mdot
.41498 .83173 Mdot
.76155 .5025 Mdot
.38845 .75674 Mdot
.71162 .61077 Mdot
.40183 .82664 Mdot
.45286 .64025 Mdot
.38583 .74265 Mdot
.4136 .07568 Mdot
.54628 .13045 Mdot
.70518 .63718 Mdot
.79377 .38736 Mdot
.48744 .83666 Mdot
.57895 .26471 Mdot
.40445 .25058 Mdot
.60075 .16238 Mdot
.57759 .89443 Mdot
.49619 .23489 Mdot
.44568 .04827 Mdot
.59723 .55258 Mdot
.51743 .59499 Mdot
.65072 .6181 Mdot
.60449 .404 Mdot
.61381 .73039 Mdot
.40925 .08216 Mdot
.50371 .33222 Mdot
.55956 .7862 Mdot
.57954 .69593 Mdot
.71094 .41514 Mdot
.53336 .5032 Mdot
.61639 .84322 Mdot
.37169 .69422 Mdot
.71915 .30585 Mdot
.42112 .4088 Mdot
.63878 .50941 Mdot
.47816 .86795 Mdot
.68474 .56222 Mdot
.56563 .64515 Mdot
.45896 .68987 Mdot
.43769 .54285 Mdot
.6169 .51415 Mdot
.69517 .69151 Mdot
.63271 .74436 Mdot
.44673 .29221 Mdot
.66064 .54933 Mdot
.51547 .63618 Mdot
.44028 .60617 Mdot
.58613 .23335 Mdot
.62309 .39004 Mdot
.43235 .18046 Mdot
.55673 .71601 Mdot
.56408 .64444 Mdot
.59826 .51323 Mdot
.50289 .11555 Mdot
.44104 .68257 Mdot
.70096 .36508 Mdot
.56816 .4768 Mdot
.6679 .36297 Mdot
.59088 .25006 Mdot
.54695 .44675 Mdot
.40434 .45584 Mdot
.65659 .19181 Mdot
.69015 .70073 Mdot
.37958 .69275 Mdot
.57795 .18031 Mdot
.50583 .81356 Mdot
.59153 .66786 Mdot
.63438 .28028 Mdot
.42832 .22063 Mdot
.6925 .69368 Mdot
.74043 .3595 Mdot
.44478 .08404 Mdot
.66946 .7457 Mdot
.60689 .85715 Mdot
.44041 .38832 Mdot
.40315 .62396 Mdot
.68851 .69323 Mdot
.72017 .58789 Mdot
.45304 .33531 Mdot
.45754 .91866 Mdot
.59535 .46578 Mdot
.63734 .50294 Mdot
.4027 .73287 Mdot
.4479 .04673 Mdot
.42608 .15874 Mdot
.45808 .95636 Mdot
.66672 .6525 Mdot
.64907 .41495 Mdot
.39932 .82271 Mdot
.65466 .44193 Mdot
.61903 .83354 Mdot
.70771 .19625 Mdot
.54344 .89052 Mdot
.62759 .60266 Mdot
.5121 .59292 Mdot
.41713 .92772 Mdot
.57534 .30326 Mdot
.44261 .59191 Mdot
.59889 .87042 Mdot
.49175 .92162 Mdot
.46006 .69228 Mdot
.47056 .77282 Mdot
.58659 .39411 Mdot
.56042 .60384 Mdot
.50513 .04461 Mdot
.38284 .3575 Mdot
.6102 .85326 Mdot
.61494 .52558 Mdot
.60677 .60467 Mdot
.55246 .33218 Mdot
.58068 .45131 Mdot
.45419 .3696 Mdot
.70556 .65709 Mdot
.69442 .68655 Mdot
.56916 .51416 Mdot
.53437 .38188 Mdot
.5447 .67147 Mdot
.5588 .54403 Mdot
.36231 .44123 Mdot
.40318 .53525 Mdot
.45881 .07148 Mdot
.5454 .56719 Mdot
.48703 .79006 Mdot
.53283 .518 Mdot
.43403 .76286 Mdot
.61245 .54866 Mdot
.53933 .6841 Mdot
.52821 .39538 Mdot
.72306 .4996 Mdot
.45827 .40075 Mdot
.40337 .68686 Mdot
.61365 .56785 Mdot
.62689 .59588 Mdot
.59696 .51794 Mdot
.47428 .79429 Mdot
.39305 .84271 Mdot
.72412 .71578 Mdot
.44693 .11463 Mdot
.5437 .00111 Mdot
.4023 .25742 Mdot
.5406 .51326 Mdot
.56756 .12283 Mdot
.68267 .70815 Mdot
.55779 .39715 Mdot
.58186 .23446 Mdot
.41865 .97998 Mdot
.54052 .41092 Mdot
.50448 .65287 Mdot
.5677 .38568 Mdot
.39697 .24531 Mdot
.56533 .68636 Mdot
.70296 .75978 Mdot
.43179 .38882 Mdot
.41793 .76486 Mdot
.52796 .80584 Mdot
.42689 .38857 Mdot
.48401 .29541 Mdot
.49917 .75194 Mdot
.71758 .60969 Mdot
.52957 .43997 Mdot
.68241 .60488 Mdot
.54997 .17585 Mdot
.5136 .8611 Mdot
.62493 .25752 Mdot
.46546 .92256 Mdot
.61445 .47494 Mdot
.76245 .56318 Mdot
.45178 .75408 Mdot
.6903 .70496 Mdot
.41373 .92279 Mdot
.46448 .2258 Mdot
.3817 .71096 Mdot
.59571 .55099 Mdot
.54692 .24919 Mdot
.66701 .35931 Mdot
.38887 .60745 Mdot
.4937 .20785 Mdot
.40615 .41403 Mdot
.60469 .60824 Mdot
.58896 .09491 Mdot
.5154 .16328 Mdot
.5015 .41174 Mdot
.42105 .2161 Mdot
.52815 .77048 Mdot
.44056 .3858 Mdot
.42415 .38065 Mdot
.39209 .50006 Mdot
.54904 .21262 Mdot
.43343 .41065 Mdot
.59233 .42852 Mdot
.64173 .22744 Mdot
.51637 .76847 Mdot
.53661 .82436 Mdot
.41133 .39992 Mdot
.41125 .41664 Mdot
.5039 .35346 Mdot
.64095 .10481 Mdot
.51065 .37873 Mdot
.58792 .23761 Mdot
.38097 .69282 Mdot
.47002 .06608 Mdot
.40939 .55436 Mdot
.68368 .4308 Mdot
.64951 .78862 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o00002oooool2o`000:cooooo002Kooooo`;o00001oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00_ooooo0_l0002/ooooo`00Y?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2i
ooooo`00X_ooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03
o`000?oooooooooo00?ooooo0_l0002dooooo`00[?ooool00ol0003oooooooooo`03ooooo`;o0000
]?ooool00:cooooo0ol0002iooooo`00XOooool2o`0000Wooooo00?o0000ooooooooool0^Oooool0
0:7ooooo0_l00009ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`03o`000?oooooooooo0;Wooooo002Jooooo`;o00004?ooool3o`000;Wooooo002Jooooo`;o
00004?ooool3o`000;Wooooo002Hooooo`Co00004?ooool3o`000;Wooooo002Hooooo`;o00004_oo
ool00ol0003oooooooooo`0=ooooo`;o0000Z_ooool00:cooooo00?o0000ooooooooool03Oooool2
o`000:[ooooo002Aooooo`;o00006Oooool00ol0003oooooooooo`02ooooo`;o0000]Oooool0097o
oooo0_l0000Iooooo`03o`000?oooooooooo00;ooooo0_l0000<ooooo`;o0000Yoooool00:;ooooo
0_l00008ooooo`03o`000?oooooooooo013ooooo0_l0002Wooooo`00X_ooool2o`0000Sooooo00?o
0000ooooooooool0^Oooool009kooooo0_l0000<ooooo`03o`000?oooooooooo0;Wooooo002?oooo
o`;o00003Oooool2o`0000cooooo0ol0002iooooo`00Soooool2o`0001_ooooo00?o0000oooooooo
ool0^Oooool008kooooo0_l0000Looooo`03o`000?oooooooooo0;Wooooo002>ooooo`;o00002Ooo
ool3o`00013ooooo00?o0000ooooooooool0^Oooool009Wooooo0ol0000@ooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo01[o
oooo0_l0002Mooooo`00[?ooool00ol0003oooooooooo`0Jooooo`;o0000WOooool00:cooooo0ol0
002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0[oooo
o`;o0000S?ooool0093ooooo0_l0000Jooooo`03o`000?oooooooooo013ooooo0_l0000Iooooo`;o
0000S?ooool0093ooooo0_l0000Jooooo`03o`000?oooooooooo013ooooo0_l0002Wooooo`00V_oo
ool2o`00013ooooo0ol0000Booooo`;o0000YOooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`03ob4Q8Ol0003o000000Cooooo0_l000000oo^k^koooooooooo`03ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool3o`0001;ooooo0_l0000Kooooo`;o0000R?ooool008Wooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`03ob4Q8Ol0003o000000Gooooo00?oEEEEojVYZOooool0
1oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01?ooooo0_l0000Jooooo`;o0000
R?ooool0087ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEE
ooooo`02ooooo`Co00000_ooool00ol0003oooooooooo`03ooooo`?o00004oooool2o`000:Cooooo
0029ooooo`05o`000?ooooooooooooooool000003_ooool01?lQ8B7oooooooooooooool4o`000003
oooooomgMgOo<S8b00Gooooo00?o0000ooooooooool0^Oooool008Wooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005oooo
o`03o`000?oooooooooo00cooooo0_l0002[ooooo`00ROooool01Ol@413ooooooooooooooooo410@
00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00cooooo0_l0002[ooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo0_l000000ooo
oooo410@ooooo`02ooooo`03oc8b<_oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Hooooo`;o0000Woooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08oooo
o`;o000000?oooooo`000?l000000ol00004ooooo`Co00001_ooool00ol0003oooooooooo`0=oooo
o`;o00002Oooool2o`0009oooooo002/ooooo`03o`000?oooooooooo00gooooo0_l0002Zooooo`00
R?ooool2o`0002;ooooo00?o0000ooooooooool0^Oooool008Sooooo0_l0000Jooooo`;o00001_oo
ool01?l0003oooooo`000?l0002hooooo`00Y?ooool2o`0000Kooooo1?l0002hooooo`00X?ooool2
o`0000[ooooo00?o0000ooooooooool0^Oooool009?ooooo0_l0000;ooooo`;o00002_ooool00ol0
003oooooooooo`0Mooooo`;o0000V_ooool008_ooooo0_l00006ooooo`;o00005oooool00ol0003o
ooooooooo`0Mooooo`;o0000V_ooool008_ooooo0_l0000Oooooo`03o`000?oooooooooo00;ooooo
0_l0000Jooooo`;o0000VOooool00:cooooo00?o0000ooooooooool00_ooool2o`0001[ooooo0_l0
002Iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00X?ooool2o`0000[ooooo0ol0000=ooooo`;o00004_ooool2o`0009Kooooo002Pooooo`;o0000
2_ooool00ol0003oooooooooo`06ooooo`;o00001Oooool2o`0000Oooooo0_l00009ooooo`;o0000
U_ooool009Gooooo0_l0000Booooo`;o000000?oooooo`000?ooool01oooool2o`0000kooooo0_l0
002Qooooo`00UOooool2o`0000Oooooo0_l00009ooooo`;o000000?oooooo`000?ooool0^_ooool0
09kooooo0_l0000<ooooo`03o`000?oooooooooo00;ooooo0_l0002eooooo`00U?ooool2o`0001Ko
oooo00?o0000ooooooooool00_ooool2o`0002cooooo0_l00027ooooo`00U?ooool2o`0001Kooooo
00?o0000ooooooooool0<?ooool2o`0008Oooooo002@ooooo`;o00004_ooool2o`0000Kooooo0_l0
000Booooo`;o00007Oooool2o`0000oooooo0_l0001fooooo`00T?ooool2o`0001;ooooo0_l00006
ooooo`?o00004Oooool2o`0000Oooooo1?l0000Sooooo`;o0000M_ooool00:cooooo00?o0000oooo
ooooool06_ooool4o`0009_ooooo002/ooooo`04o`000?oooooo0000o`000;Sooooo002Yooooo`;o
000000?oooooo`000?ooool00_l0000;ooooo`;o0000Zoooool009Sooooo0_l0000?ooooo`;o0000
00?oooooo`000?ooool03Oooool3o`000:[ooooo002Booooo`;o00001?ooool2o`0001;ooooo00?o
0000ooooooooool03Oooool2o`000:[ooooo002Booooo`;o00006?ooool00ol0003oooooooooo`08
ooooo`;o00005?ooool2o`0009Wooooo002Dooooo`;o00002_ooool4o`0000Sooooo00?o0000oooo
ooooool02?ooool2o`0000gooooo0_l00005ooooo`;o00002_ooool2o`0008gooooo002Dooooo`;o
00002_ooool4o`0000Sooooo0ol00002ooooo`;o00004oooool2o`00017ooooo0_l0002=ooooo`00
X?ooool2o`0000[ooooo00?o0000ooooooooool00_ooool2o`0002Oooooo0_l0002<ooooo`00[?oo
ool00ol0003oooooooooo`0[ooooo`;o0000S?ooool009gooooo0_l0000;ooooo`?o00006_ooool3
o`0009kooooo002Mooooo`;o00002oooool3o`0001[ooooo1?l0002Mooooo`00Xoooool2o`0000Oo
oooo00?o0000ooooooooool00_l0000Hooooo`;o0000WOooool0097ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool00om4A4Co0000o`000002o`0000Gooooo00?o0000oooooooo
ool00_l0000Hooooo`;o0000WOooool008[ooooo0_l00005ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Sooooo0_l00005ooooo`03o`000?oooooooooo01[ooooo0_l0002Mooooo`00
ROooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool03?ooool2o`0000gooooo0_l0002Looooo`00S?ooool2o`0000?ooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000<ooooo`;o
00003Oooool2o`0001?ooooo0_l00027ooooo`00S?ooool2o`0000?ooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Doooo
o`;o00006_ooool2o`0008Oooooo002;ooooo`;o00001?ooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Dooooo`;o00004?ooool2o`00
097ooooo0029ooooo`Co00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Vooooo`;o0000TOooool008Wooooo0_l00006ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`000003ooooool0003o000000?ooooo00?o0000oooo
ooooool05oooool2o`000:3ooooo002Wooooo`Co000000?oooooo`000?ooool06?ooool2o`000:3o
oooo002Yooooo`;o000000?oooooo`000?ooool0^_ooool00:Cooooo0_l00006ooooo`03o`000?oo
oooooooo00;ooooo0_l0000_ooooo`;o0000Q?ooool00:Cooooo0_l00006ooooo`?o00000_ooool2
o`0002oooooo0_l00024ooooo`00Zoooool2o`0002_ooooo0_l0002>ooooo`00Zoooool2o`0002_o
oooo0_l0002>ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00V_ooool2o`0000Wooooo0_l00005ooooo`?o0000:_ooool2o`0008gooooo002Joooo
o`;o00002Oooool3o`0000Cooooo0ol0000Zooooo`Co0000Roooool009?ooooo0_l00005ooooo`;o
00002_ooool2o`0000Cooooo00?o0000ooooooooool0;?ooool2o`0002Gooooo0_l0001Tooooo`00
Toooool2o`0000Gooooo0_l0000@ooooo`?o00001_ooool2o`0000;ooooo0_l00017ooooo`;o0000
I?ooool00:Wooooo0_l000000ooooooo0000ooooo`07ooooo`;o00000_ooool2o`0000Wooooo0_l0
000Qooooo`;o0000Ooooool00:Wooooo0_l000000ooooooo0000ooooo`0Fooooo`;o00008Oooool2
o`0000_ooooo0_l0001booooo`00[?ooool00ol0003oooooooooo`0Fooooo`;o0000;Oooool2o`00
07;ooooo002/ooooo`03o`000?oooooooooo01Kooooo0_l0002Qooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool3o`0001oooooo0_l0002Hooooo`00[?ooool00ol0003oooooooooo`0>ooooo`;o
00003oooool2o`0009Sooooo002/ooooo`03o`000?oooooooooo00kooooo0_l0000/ooooo`;o0000
Noooool00:cooooo0ol0000>ooooo`;o0000;?ooool2o`0007_ooooo002Looooo`;o00003_ooool3
o`0000kooooo0_l0002Yooooo`00W?ooool2o`0000kooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool03oooool2o`000:Sooooo002/ooooo`04o`000?ooooooooooooooo`;o
00001Oooool2o`0000Gooooo0_l0002Xooooo`00[?ooool01?l0003oooooooooooooool2o`0000Go
oooo0_l0000@ooooo`;o00005oooool2o`0008Cooooo002Iooooo`;o00004Oooool3o`0000Sooooo
0_l0000@ooooo`;o00005oooool2o`0008Cooooo002Iooooo`;o00004Oooool3o`0003Cooooo0_l0
0023ooooo`00QOooool2o`0002Gooooo0ol0000dooooo`;o0000Poooool008Gooooo0_l0000Uoooo
o`03o`000?oooooooooo01_ooooo0_l0000Gooooo`;o00005_ooool2o`0006_ooooo002/ooooo`03
o`000?oooooooooo01_ooooo0_l0000Gooooo`;o00002Oooool2o`0000_ooooo0_l0001[ooooo`00
ROooool01_o^k^ko<S8bo`000?lb<S;ok^k^ooooo`;o00000_ooool2ob4Q8@Cooooo1Ol00004oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Looooo`;o00005_ooool2
o`0000Wooooo0_l0001hooooo`00ROooool01_mgMgOoV9RHoooooonHV9SoMgMgooooo`;o00000_oo
ool2ob4Q8@Cooooo00?oV9RHob4Q8Oo^k^h00_l00007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool07?ooool3o`0009[ooooo0021ooooo`Ko00000_ooool01Ol@413ooooooooooooo
oooo410@00cooooo00CoV9RHob4Q8Ol0003o00002?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo01gooooo0_l0000Pooooo`;o0000N?ooool008Wooooo00Go0000oooooooooooooooo
o`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0003oooooo
0_l0001hooooo`00ROooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool0
0oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool00_l0002gooooo`00
Qoooool2o`000005oa0@4?ooooooooooooooool@41001Oooool2o`0000Sooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;o00001_ooool2o`000:oo
oooo0027ooooo`;o000000GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o00000oooool2o`000004
okZj^_ooooooV9RHoa0@40Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08oooo
o`;o00002Oooool2o`000:Cooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool4o`00
0007ooooool0003o0000oa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003ooooooooo
o`0?ooooo`;o00000_ooool2o`0004Wooooo0_l0001Iooooo`00Toooool4o`000003ooooool0003o
000001;ooooo00?o0000ooooooooool03oooool2o`0001Cooooo0_l0000gooooo`;o0000FOooool0
0:cooooo00?o0000ooooooooool01_ooool2o`00017ooooo0_l0000:ooooo`;o00006oooool2o`00
07Gooooo002/ooooo`03o`000?oooooooooo00Kooooo0_l00008ooooo`;o00001oooool2o`0001co
oooo0_l00009ooooo`;o0000MOooool008kooooo0_l0000>ooooo`;o00003?ooool3o`00013ooooo
0_l0000Uooooo`;o0000P?ooool008kooooo0_l00009ooooo`;o00000oooool2o`0000cooooo00?o
0000ooooooooool07oooool2o`0009Sooooo002Iooooo`;o00004Oooool00ol0003oooooooooo`0O
ooooo`;o0000V?ooool009;ooooo0_l0000Hooooo`03o`000?oooooooooo02kooooo0_l00007oooo
o`;o0000P?ooool009;ooooo0_l00002ooooo`;o00005?ooool2o`0000_ooooo0_l0000Kooooo`;o
00001Oooool2o`0000Oooooo0_l00020ooooo`00SOooool3o`0000Kooooo0_l0000Dooooo`;o0000
2oooool2o`0001_ooooo0_l00005ooooo`;o00004_ooool2o`0007Gooooo002=ooooo`?o00007?oo
ool2o`0002oooooo0_l0000Booooo`;o0000MOooool00:cooooo0_l00015ooooo`;o0000Loooool0
0:cooooo0ol0000jooooo`;o00002?ooool2o`0007?ooooo002/ooooo`03o`000?oooooooooo01_o
oooo0_l0000Mooooo`;o0000OOooool00:cooooo00?o0000ooooooooool06oooool2o`0001cooooo
0_l0001nooooo`00[?ooool00ol0003oooooooooo`0iooooo`;o00002Oooool2o`0007?ooooo002:
ooooo`;o00008?ooool00ol0003oooooooooo`06ooooo`;o0000??ooool2o`0007?ooooo0024oooo
o`Co00000_ooool2o`0000Oooooo0_l0000Gooooo`03o`000?oooooooooo00Kooooo0_l0002aoooo
o`00O_ooool2o`0000Cooooo1?l0000;ooooo`;o00005oooool00ol0003oooooooooo`06ooooo`;o
0000:?ooool2o`0008Oooooo001nooooo`;o0000;?ooool00ol0003oooooooooo`0<ooooo`;o0000
8Oooool3o`0008Oooooo002/ooooo`03o`000?oooooooooo00cooooo0_l00005ooooo`;o00006_oo
ool2o`0008Sooooo002/ooooo`?o00004oooool2o`0000;ooooo0_l0002Pooooo`00S?ooool2o`00
0003ooooool0003o000001_ooooo00?o0000ooooooooool05oooool2o`000:3ooooo002<ooooo`;o
000000?oooooo`000?l000006oooool00ol0003oooooooooo`16ooooo`;o0000LOooool000Wooooo
1?l000000ol@413oooooooooo`0Fooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o
<S8bomgMg@0Fooooo`03o`000?oooooooooo013ooooo0_l00006ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool0
1Oo^k^ko0000o`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
3oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`Co000000?o410@ooooooooool04_ooool000_o
oooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46oooo
o`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q0_ooool2o`000005oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2o`000003ogMg
Molb<S;ooooo01Gooooo00?o0000ooooooooool04?ooool2o`0000Kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b
<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYoooo
o`07ooooo`03ogMgMolb<S;ooooo01Wooooo00?o0000ooooooooool05?ooool000Ko00001Oooool0
0ol0003oooooooooo`0@ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00gooooo00?o
ZJVYoeEEEOooool02?ooool00ol0003oooooooooo`05ooooo`Ko00000_ooool01Ol@413ooooooooo
oooooooo410@013ooooo00?o0000ooooooooool01Oooool6o`0000;ooooo00Go410@oooooooooooo
oooooa0@4009ooooo`Co000000?o8B4Qonk^k_ooool02?ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo01Sooooo00Co410@oooooooooooooooo0_l0000;ooooo`;o000000?ok^k^oooo
ooooool01oooool00ol0003oooooooooo`0=ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`0=ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEoooo
o`08ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000
ooooooooool06?ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_oo
ool00omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8b
ooooo`0>ooooo`05o`000?ooooooooooooooool000002oooool2o`000003oiRHV?lQ8B7ok^k^00Oo
oooo00?oMgMgoc8b<_ooool05Oooool00ol0003oooooooooo`0Hooooo`04o`000?oooooooooooooo
o`;o00002oooool2o`000003ob4Q8Oo^k^kooooo00Kooooo00?oMgMgoc8b<_ooool03_ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooo
oooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`0Iooooo`03o`000?oo
oooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00
000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`00
0?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Fooooo`04o`000?ooooooooooooooo`;o00005Oooool01Ol0003ooooooooooooooooo000000ko
oooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooo
oooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol@413ooooo
oooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`0Aooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0Aooooo`05oa0@4?oooooooooo
ooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Sooooo0ol00000
0ooooooo0000o`00000@ooooo`;o00000_ooool2o`0000?ooooo00?o410@ooooooooool00oooool2
o`0000Kooooo0ol00004ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVY
ZOmgMgOooooo00?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Dooooo`002ooo
ool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooo
oooooooooooo<S8b00Cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000
okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool04ooo
ool2o`0000;ooooo0_l000001?nHV9SooooooiRHV?mgMgL5ooooo`;o00001?ooool01Ol0003o^[Zj
o`000?l0003o410@00Cooooo0_l0000Booooo`05ogMgMonHV9So0000o`000?mgMgL03?ooool00ol0
003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooo
oooo<S8b00Cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Dooooo`002Oooool0
0omEEEGoIVIVo`00000Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0
000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0001Oooooo00?o0000oooo
ooooool00_l0000Fooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<00Cooooo1?l00006ooooo`;o00002?ooool01Oo^k^ko<S8bo`000?l0003ok^k^00cooooo
1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000Iooooo`03
oeEEEOmVIVKo000001Kooooo002/ooooo`03o`000?oooooooooo00;o0000>Oooool2o`0007cooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0:kooooo0_l00002
ooooo`;o00001Oooool008cooooo0_l0000Nooooo`03o`000?oooooooooo03[ooooo0_l0001boooo
o`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1Oooool008cooooo0_l0000Nooooo`03o`000?oooooo
oooo03[ooooo0_l0001cooooo`04omgMgOl0003o410@olc<c0Kooooo0007oooooooo0000C?l0000<
ooooo`04onk^k_lQ8B7o410@onk^kPKooooo0007ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo0_l00000
0ooooooo0000ooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00Co0000ooooool0003o00001?oo
ool01?l0003oooooo`000?l00004ooooo`03o`000?oooooooooo00Cooooo0_l00008ooooo`03o`00
0?oooooooooo00;o00000oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooooooo`;o
00000_ooool00ol0003oooooooooo`04ooooo`?o00001oooool00ol0003oooooooooo`02o`0000?o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02_ooool01?lQ8B7oMgMgogMgMolb<S86ooooo`001oooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool2o`0000Oo
oooo0_l000000ooooooo0000o`00000Kooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`;o
00001_ooool2o`0000Oooooo0_l00002ooooo`;o00002?ooool00ol0003oooooooooo`02o`0001[o
oooo0_l00008ooooo`03o`000?oooooooooo00;o00009?ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo00Wooooo0_l00002ooooo`;o00001Oooool008?ooooo0_l00007ooooo`;o0000
00?oooooo`000?l000006oooool00ol0003oooooooooo`03ooooo`;o00005?ooool2o`0000kooooo
0ol0002=ooooo`00[?ooool00ol0003oooooooooo`0:ooooo`;o00004Oooool2o`0000[ooooo0ol0
000Wooooo`;o0000I?ooool008?ooooo0_l0000Wooooo`03o`000?oooooooooo00[ooooo0_l00007
ooooo`;o00002?ooool2o`0000Cooooo0ol0000Fooooo`;o00005Oooool2o`0006Cooooo0023oooo
o`;o00009oooool00ol0003oooooooooo`07ooooo`;o00002_ooool2o`0000Sooooo0_l00004oooo
o`?o00005_ooool2o`0007_ooooo002/ooooo`03o`000?oooooooooo00Oooooo0_l0000Dooooo`;o
00007?ooool2o`0007cooooo002/ooooo`?o00008oooool2o`0000Cooooo0_l0000@ooooo`;o0000
O?ooool00:cooooo00?o0000ooooooooool04oooool2o`0000kooooo0_l00004ooooo`;o0000S_oo
ool00:cooooo00?o0000ooooooooool04oooool2o`0000Wooooo0_l00003ooooo`;o0000U?ooool0
0:cooooo00?o0000ooooooooool07_ooool2o`0000?ooooo0_l0002Dooooo`00S?ooool2o`0001ko
oooo00?o0000ooooooooool0:Oooool2o`0001cooooo0_l0000:ooooo`;o0000I?ooool008cooooo
0_l000000ooooooo0000o`00000Kooooo`03o`000?oooooooooo02Wooooo0_l0000@ooooo`;o0000
2_ooool2o`0000[ooooo0_l0001Tooooo`00Soooool2o`0000Kooooo0_l0000Cooooo`03o`000?oo
oooooooo03_ooooo0_l0001looooo`00Uoooool2o`0001?ooooo00?o0000ooooooooool04?ooool2
o`000:Oooooo0021ooooo`;o0000:Oooool00ol0003oooooooooo`0@ooooo`;o00004?ooool2o`00
00kooooo0_l00025ooooo`00POooool2o`0002Wooooo0ol0000Looooo`?o00000oooool2o`0000ko
oooo0_l00025ooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool03?ooool2o`0000kooooo
0ol0002Jooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool03?ooool2o`0000Gooooo0_l0
002Tooooo`00[?ooool00ol0003oooooooooo`0Cooooo`;o00009Oooool2o`0007gooooo002:oooo
o`;o00008?ooool00ol0003oooooooooo`0jooooo`;o00002_ooool2o`0000_ooooo0_l0001Toooo
o`00R_ooool2o`00023ooooo00?o0000ooooooooool03?ooool2o`0001Cooooo0_l0000Fooooo`;o
00002_ooool2o`0000_ooooo0_l0001Tooooo`00[?ooool00ol0003oooooooooo`0<ooooo`;o0000
5?ooool2o`0009Gooooo002/ooooo`03o`000?oooooooooo00Kooooo0_l0000Jooooo`;o0000UOoo
ool00:cooooo0ol00006ooooo`;o0000/Oooool00:cooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool06oooool2o`0009cooooo
002Dooooo`;o00005_ooool00ol0003oooooooooo`0Fooooo`;o00000oooool2o`0002Sooooo0_l0
001booooo`00U?ooool2o`0000?ooooo0_l0000Aooooo`03o`000?oooooooooo01Kooooo0_l0000]
ooooo`;o0000L_ooool009Wooooo0_l0000Aooooo`04o`000?ooooooooooooooo`?o0000]Oooool0
0:cooooo00Co0000oooooooooooooooo0ol0000Looooo`;o00001?ooool2o`00097ooooo002/oooo
o`?o00008?ooool2o`0000Cooooo0_l0000Aooooo`;o00005_ooool2o`0006Kooooo002/ooooo`03
o`000?oooooooooo017ooooo0_l0000Dooooo`;o00004?ooool2o`0001Kooooo0_l0001Vooooo`00
Qoooool2o`0000Sooooo0_l00005ooooo`;o00004_ooool00ol0003oooooooooo`0Aooooo`;o0000
3Oooool2o`0000Gooooo0_l0000@ooooo`;o0000O_ooool008;ooooo0_l00003ooooo`;o00002?oo
ool2o`0000Gooooo0_l0000Booooo`03o`000?oooooooooo01oooooo0ol0000Gooooo`;o00002Ooo
ool2o`0007?ooooo0022ooooo`;o00005?ooool2o`0001;ooooo00?o0000ooooooooool07oooool2
o`00027ooooo1?l0001cooooo`00V?ooool2o`0001;ooooo00?o0000ooooooooool03?ooool2o`00
01oooooo0_l0000Cooooo`Co0000Loooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo00cooooo0_l0000Oooooo`?o00005?ooool2o`0007?ooooo0025ooooo`Co000000GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0^ooooo`;o00005?ooool2o`0007?ooooo0025
ooooo`Co000000?o410@ooooooooool00_l0000<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000
ooooooooool00oooool3o`0000Gooooo0_l0002booooo`00ROooool00ol0003oooooooooo`02o`00
00gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
00Gooooo1?l0000^ooooo`;o0000P?ooool008Wooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo00Oooooo0_l0000^ooooo`;o0000P?ooool008Wooooo00Go410@oooooooooooooooooa0@400?
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_l00005ooooo`03o`000?oooooo
oooo00_ooooo0_l00012ooooo`;o0000J?ooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`02o`0000Gooooo00?o
0000ooooooooool00_ooool2o`0000Oooooo0_l0000cooooo`?o00003?ooool2o`0006Sooooo0025
ooooo`;o00000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00?oV9RHoa0@4?l000000_l0
0004ooooo`Co00001_ooool00ol0003oooooooooo`02ooooo`;o0000??ooool3o`0007Kooooo0025
ooooo`;o00005Oooool2o`0000kooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooo
ooooool04_ooool2o`000:Gooooo002/ooooo`03o`000?oooooooooo01;ooooo0_l0000Gooooo`;o
00002Oooool2o`00087ooooo002Iooooo`;o00004Oooool3o`0001cooooo0_l0000=ooooo`;o0000
1oooool4o`00087ooooo002Booooo`;o00000_ooool2o`000003ooooool0003o0000017ooooo0ol0
000Looooo`;o00005_ooool2o`0008?ooooo0028ooooo`;o00001oooool3o`0000;ooooo0_l0000D
ooooo`03o`000?oooooooooo02_ooooo0_l0000Cooooo`;o0000Moooool008Sooooo0_l00007oooo
o`;o00006Oooool00ol0003oooooooooo`0[ooooo`;o00004Oooool4o`0007Oooooo002/ooooo`03
o`000?oooooooooo03kooooo0ol0001hooooo`00[?ooool00ol0003oooooooooo`0Kooooo`;o0000
8_ooool2o`0007Sooooo002/ooooo`04o`000?ooooooooooooooo`;o00006?ooool2o`00023ooooo
0_l0001jooooo`00W_ooool2o`0000cooooo00Co0000oooooooooooooooo0_l00008ooooo`;o0000
<?ooool2o`0007[ooooo002Nooooo`;o00003?ooool3o`0000_ooooo0_l0000mooooo`;o0000KOoo
ool00:cooooo00?o0000ooooooooool0<_ooool2o`0001Kooooo0_l0001]ooooo`00T?ooool2o`00
00Kooooo0_l00003ooooo`;o00001oooool2o`0000Cooooo00?o0000ooooooooool0<_ooool2o`00
08Gooooo002@ooooo`;o00001_ooool2o`0000?ooooo0_l00007ooooo`;o00001?ooool00ol0003o
ooooooooo`0:ooooo`;o0000[Oooool008cooooo0_l0000Nooooo`03o`000?oooooooooo00[ooooo
0_l00006ooooo`;o0000:Oooool2o`0007[ooooo002<ooooo`;o00004?ooool2o`0000cooooo00?o
0000ooooooooool03Oooool2o`0000?ooooo0_l0000Yooooo`;o0000N_ooool0087ooooo0_l00000
0ooooooo0000o`00000;ooooo`;o00002oooool2o`0000cooooo00?o0000ooooooooool01Oooool2
o`0000Kooooo0_l0000/ooooo`Co0000N_ooool0087ooooo0_l000000ooooooo0000o`00000;oooo
o`;o00006Oooool00ol0003oooooooooo`05ooooo`;o00004?ooool2o`0002;ooooo0ol0001koooo
o`00[?ooool3o`0001Oooooo0_l0000Rooooo`;o0000O?ooool00:cooooo00?o0000ooooooooool0
>oooool2o`0007cooooo002/ooooo`03o`000?oooooooooo03_ooooo0_l0001looooo`00[?ooool0
0ol0003oooooooooo`0iooooo`Co0000O?ooool008Gooooo0_l0000Pooooo`;o00000oooool00ol0
003oooooooooo`0iooooo`?o0000OOooool008Gooooo0_l0000Pooooo`;o00000oooool00ol0003o
ooooooooo`0?ooooo`;o0000=_ooool2o`00073ooooo002/ooooo`03o`000?oooooooooo00Gooooo
0_l00008ooooo`;o0000=_ooool2o`00073ooooo001oooooo`;o00003oooool2o`0000Sooooo0_l0
000@ooooo`03o`000?oooooooooo00Gooooo0_l00008ooooo`;o0000Z?ooool007oooooo0_l0000?
ooooo`;o00002?ooool2o`00013ooooo0ol0000?ooooo`;o0000Z?ooool00:cooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool04oooool2o`0000gooooo0_l0002Eooooo`00
Roooool2o`0001oooooo00?o0000ooooooooool03?ooool2o`0000Gooooo0_l0000=ooooo`;o0000
UOooool008_ooooo0_l00009ooooo`;o00005?ooool00ol0003oooooooooo`0<ooooo`;o0000Zooo
ool009Kooooo0_l0000Dooooo`03o`000?oooooooooo01Sooooo0_l0002Oooooo`00Q_ooool2o`00
00Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool06?ooool2o`0001cooooo0_l00021ooooo`00Q_ooool2
o`0000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo02Sooooo0ol0000:ooooo`?o0000POooool0097ooooo00Go410@
oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?oo
ool3o`0000[ooooo0_l00022ooooo`00TOooool01Ol0003ooooooooooooooooo000000oooooo00?o
MgMgo`000?l000000oooool4o`000;Wooooo002Aooooo`05o`000?ooooooooooooooool000001_oo
ool2o`0000?ooooo0_l000000olQ8B7o0000o`000002o`0000?ooooo0_l0002kooooo`00Qoooool2
o`0000Sooooo00Go410@oooooooooooooooooa0@4006ooooo`;o00000oooool2o`0000;ooooo0_l0
0004ooooo`;o000000?oooooo`000?l00000^?ooool008Oooooo0_l00008ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`04o`000?oooooo0000o`00037ooooo
0_l0000<ooooo`;o0000Moooool0093ooooo0_l000001?lb<S;o0000oc8b<_o^k^h2o`0000;ooooo
0_l00006ooooo`Co00001_ooool00ol0003oooooooooo`02ooooo`;o0000;_ooool2o`0000cooooo
0_l0001gooooo`00T?ooool2o`0000Cooooo0_l00002ooooo`;o00004?ooool00ol0003ooooooooo
o`02ooooo`;o0000]Oooool00:cooooo00?o0000ooooooooool00_ooool2o`0000;ooooo0_l0002a
ooooo`00Roooool2o`0001Gooooo0_l00008ooooo`04o`000?ooooooooooooooo`?o00000_ooool2
o`000;7ooooo002;ooooo`;o00005Oooool2o`0000Sooooo0ol000000ooooooo0000o`00002foooo
o`00[?ooool00ol0003oooooooooo`0`ooooo`;o0000Qoooool00:cooooo00?o0000ooooooooool0
6_ooool2o`0000Kooooo0_l0000<ooooo`;o0000Qoooool00:cooooo00?o0000ooooooooool04?oo
ool2o`0000Oooooo0ol00006ooooo`;o0000UOooool00:Sooooo0_l00002ooooo`03o`000?oooooo
oooo013ooooo0_l00007ooooo`;o00004oooool2o`0008Wooooo002Wooooo`?o00000_ooool00ol0
003oooooooooo`0^ooooo`;o0000ROooool009?ooooo0_l0000=ooooo`?o00000_ooool2o`0000?o
oooo00?o0000ooooooooool08_ooool2o`0009Gooooo002@ooooo`;o000000?oooooo`000?l00000
3Oooool3o`0000Oooooo00?o0000ooooooooool01oooool2o`0001Wooooo0_l0002Eooooo`00T?oo
ool2o`0001[ooooo0ol00007ooooo`;o00003_ooool2o`000:3ooooo002Mooooo`;o00003Oooool0
0ol0003oooooooooo`0Gooooo`;o0000X?ooool009gooooo0_l0000=ooooo`03o`000?oooooooooo
00Kooooo0_l0002aooooo`00ZOooool2o`000003ooooool0003ooooo00Oooooo0_l0002aooooo`00
ZOooool2o`000003ooooool0003ooooo0;[ooooo002/ooooo`?o0000^Oooool00:cooooo0ol0002i
ooooo`00[?ooool00ol0003oooooooooo`0Aooooo`;o00002Oooool2o`0009_ooooo002:ooooo`;o
00008?ooool3o`0000Wooooo0_l00006ooooo`;o00002Oooool2o`0009_ooooo002:ooooo`?o0000
7oooool00ol0003oooooooooo`09ooooo`;o0000:Oooool2o`0008?ooooo002;ooooo`;o00007ooo
ool00ol0003oooooooooo`0Aooooo`;o00008Oooool2o`0008?ooooo002?ooooo`;o00000_ooool2
o`0001Oooooo00?o0000ooooooooool04Oooool2o`00017ooooo0_l0002Cooooo`00Soooool2o`00
00;ooooo0ol0000Aooooo`;o00000oooool00ol0003oooooooooo`0Tooooo`;o0000Toooool009Co
oooo0_l0000;ooooo`;o00001?ooool2o`0000?ooooo00?o0000ooooooooool05oooool2o`0000_o
oooo0_l0002Cooooo`00R?ooool2o`0001Oooooo0_l00009ooooo`03o`000?oooooooooo01Oooooo
0_l0000:ooooo`;o0000U?ooool008Sooooo0_l0000Rooooo`;o00006?ooool2o`0000[ooooo0_l0
002Dooooo`00R?ooool2o`0002;ooooo0_l0000Hooooo`;o0000X?ooool008Sooooo0_l0000Roooo
o`?o0000^Oooool00:cooooo00?o0000ooooooooool08Oooool2o`0009Kooooo002/ooooo`03o`00
0?oooooooooo00;ooooo0_l0000Looooo`?o0000U_ooool00:cooooo00Co0000oooooooooooooooo
0ol0000Looooo`;o00002_ooool2o`0008_ooooo002/ooooo`04o`000?ooooooooooooooo`;o0000
1_ooool2o`0000Sooooo0_l0000Gooooo`;o0000Roooool008Wooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000o`000?oM
gMd01Oooool00ol0003oooooooooo`09ooooo`;o00002?ooool2o`000:Cooooo0029ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01_ooool2o`000003
oc8b<_oooooooooo00?ooooo00?o0000ooooooooool07Oooool2o`0009[ooooo0026ooooo`;o0000
00?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0;ooooo`03ojVYZOmEEEGooooo00Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Mooooo`;o0000V_ooool008Kooooo0_l0
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?o8B4Qooooooooool01_oo
ool00omgMgOo<S8booooo`04ooooo`?o0000^Oooool008Kooooo0_l000000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo00cooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo0_l0000Zooooo`;o0000Soooool008Wooooo00Go410@oooooooooooooooooa0@
400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01_ooool2o`0002[ooooo0_l0
002?ooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooo
oc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0^Oooool008Wooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool0
3?ooool2o`000:_ooooo002/ooooo`03o`000?oooooooooo00?ooooo0_l00006ooooo`?o00002?oo
ool3o`000:3ooooo002/ooooo`03o`000?oooooooooo00?ooooo0_l00006ooooo`;o00002Oooool3
o`000:3ooooo002Uooooo`;o00001Oooool00ol0003oooooooooo`0Fooooo`;o0000XOooool00:Go
oooo0_l00005ooooo`?o00002Oooool2o`000:kooooo002/ooooo`03o`000?oooooooooo00Wooooo
0_l0002^ooooo`00[?ooool3o`000;Wooooo002/ooooo`?o0000^Oooool00:cooooo0_l0002joooo
o`00[?ooool2o`000;[ooooo002Nooooo`;o00002_ooool3o`0000Oooooo0_l0002booooo`00W_oo
ool4o`0000Oooooo1?l00007ooooo`;o0000/_ooool008oooooo0_l0000?ooooo`;o00001oooool2
o`000004ooooool0003o0000o`000;Wooooo002?ooooo`?o00006_ooool00ol0003oooooooooo`03
ooooo`;o0000]?ooool0093ooooo0_l0000Jooooo`03o`000?oooooooooo00?ooooo0_l0002doooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00TOoo
ool2o`0001Wooooo00?o0000ooooooooool0^Oooool0097ooooo0_l0000Iooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`03o`000?oooooooooo00Wooooo0_l0002^ooooo`00[?ooool00ol0003o
ooooooooo`09ooooo`;o0000[_ooool00:cooooo0ol0002iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00W_ooool2o`0000cooooo00?o0000ooooooooool0^Oooool009kooooo0_l0000<oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00Gooooo0_l0002booooo`00
[?ooool00ol0003oooooooooo`05ooooo`;o0000/_ooool00:cooooo00?o0000ooooooooool0^Ooo
ool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo1Ol0002gooooo`00TOooool2o`0001Wo
oooo00?o0000ooooooooool00_l0002gooooo`00TOooool2o`0001Wooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:;ooooo1?l000000ol@413oooooooooo`03ooooo`03
o`000?oooooooooo0;Wooooo002Tooooo`03o`000?oooooooooo00;ooooo0_l000000ooooooo0000
ooooo`2jooooo`00Y?ooool00ol0003oooooooooo`02ooooo`;o000000Coooooo`000?l0003o0000
^Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool0
0:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:;ooooo
00?oEEEEofIVI_l00000`oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00:[ooooo00Co410@o`000?l0003o0000^_ooool00:_ooooo00?o0000ooooooooool0
^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00Ko0000ogMgMol0003o0000oeEE
EOo^k^jgooooo`00Zoooool01_l0003oEEEEonk^k_ooooooMgMgoeEEEKOooooo002[ooooo`03o`00
0?o^k^kooooo00;ooooo00?o0000ooooooooool0]Oooool00:_ooooo00?o0000onk^k_ooool00_oo
ool00ol0003oooooooooo`2eooooo`00Zoooool01_l0003oEEEEonk^k_ooooooMgMgofIVI[Oooooo
002Zooooo`03oa0@4?l0003oMgMg00;o000000?oIVIVonk^k_ooool0]_ooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.56934 .77645 Mdot
.44944 .10534 Mdot
.5048 .46523 Mdot
.54749 .5629 Mdot
.58277 .57258 Mdot
.5517 .21104 Mdot
.46059 .66103 Mdot
.72218 .41197 Mdot
.38952 .222 Mdot
.49008 .7694 Mdot
.47234 .21513 Mdot
.72968 .49892 Mdot
.65987 .59892 Mdot
.42861 .30372 Mdot
.72284 .45928 Mdot
.44247 .27919 Mdot
.48996 .1528 Mdot
.65384 .62873 Mdot
.40856 .56307 Mdot
.61496 .2253 Mdot
.65988 .58342 Mdot
.57386 .20929 Mdot
.59287 .24644 Mdot
.64398 .66271 Mdot
.6957 .68962 Mdot
.57213 .33084 Mdot
.53935 .32649 Mdot
.44153 .75995 Mdot
.64376 .28303 Mdot
.44096 .12049 Mdot
.65087 .62056 Mdot
.40971 .12513 Mdot
.66346 .25628 Mdot
.60482 .39587 Mdot
.55698 .75912 Mdot
.39442 .25219 Mdot
.65178 .71741 Mdot
.5459 .66822 Mdot
.64817 .30009 Mdot
.72741 .57783 Mdot
.67536 .74609 Mdot
.61115 .59709 Mdot
.39383 .59629 Mdot
.4808 .90288 Mdot
.60235 .70895 Mdot
.41913 .70946 Mdot
.42046 .63636 Mdot
.37339 .63091 Mdot
.53835 .76235 Mdot
.60122 .20774 Mdot
.38453 .74174 Mdot
.694 .47985 Mdot
.58426 .94457 Mdot
.48584 .86749 Mdot
.41772 .77474 Mdot
.53299 .072 Mdot
.72236 .41728 Mdot
.50355 .16809 Mdot
.50824 .94443 Mdot
.62016 .65769 Mdot
.40619 .60767 Mdot
.37889 .22099 Mdot
.64471 .2945 Mdot
.51792 .6632 Mdot
.60906 .17156 Mdot
.48668 .02493 Mdot
.52014 .70806 Mdot
.41891 .56665 Mdot
.52188 .7326 Mdot
.62564 .71225 Mdot
.59018 .33145 Mdot
.51824 .56538 Mdot
.49713 .75757 Mdot
.55887 .55496 Mdot
.64407 .29308 Mdot
.45159 .39752 Mdot
.58377 .9451 Mdot
.40826 .37138 Mdot
.68821 .42768 Mdot
.59915 .53314 Mdot
.52518 .88237 Mdot
.41469 .19488 Mdot
.54445 .42841 Mdot
.60056 .64619 Mdot
.67699 .27957 Mdot
.50237 .25994 Mdot
.57638 .61076 Mdot
.55929 .66894 Mdot
.46332 .14877 Mdot
.41757 .5371 Mdot
.69468 .69063 Mdot
.76629 .47639 Mdot
.42162 .44165 Mdot
.49217 .8132 Mdot
.43702 .67318 Mdot
.76247 .4335 Mdot
.41875 .36647 Mdot
.40202 .8359 Mdot
.54861 .98456 Mdot
.50597 .16865 Mdot
.52775 .84491 Mdot
.40901 .30463 Mdot
.72591 .46359 Mdot
.43787 .86875 Mdot
.55419 .84409 Mdot
.61439 .45152 Mdot
.60126 .36931 Mdot
.43288 .2577 Mdot
.42314 .41774 Mdot
.6277 .70525 Mdot
.41667 .60854 Mdot
.54752 .56816 Mdot
.39428 .19263 Mdot
.48786 .05963 Mdot
.42836 .46865 Mdot
.40296 .44865 Mdot
.58402 .12942 Mdot
.5181 .05244 Mdot
.67554 .63947 Mdot
.66222 .58051 Mdot
.3651 .63845 Mdot
.65317 .41376 Mdot
.65863 .31651 Mdot
.62333 .71714 Mdot
.53358 .63515 Mdot
.52073 .09477 Mdot
.73732 .33687 Mdot
.42164 .8217 Mdot
.51709 .37319 Mdot
.6102 .27849 Mdot
.46741 .899 Mdot
.72678 .56186 Mdot
.5868 .27489 Mdot
.41099 .25244 Mdot
.68389 .39943 Mdot
.65063 .72626 Mdot
.59545 .19611 Mdot
.51049 .72946 Mdot
.6836 .30186 Mdot
.72628 .49534 Mdot
.52906 .35365 Mdot
.45864 .79183 Mdot
.49683 .15963 Mdot
.56565 .15006 Mdot
.64562 .22024 Mdot
.64176 .09826 Mdot
.41128 .40178 Mdot
.53117 .74067 Mdot
.37174 .72217 Mdot
.39972 .3915 Mdot
.56653 .59054 Mdot
.63544 .6901 Mdot
.52211 .49985 Mdot
.60962 .33769 Mdot
.68301 .62136 Mdot
.6706 .36171 Mdot
.56271 .10407 Mdot
.65757 .7008 Mdot
.67731 .64633 Mdot
.60316 .52157 Mdot
.69206 .44804 Mdot
.65252 .79728 Mdot
.3906 .71272 Mdot
.41799 .77076 Mdot
.56805 .77587 Mdot
.62852 .19307 Mdot
.49926 .91888 Mdot
.53933 .68963 Mdot
.67398 .66303 Mdot
.51505 .09089 Mdot
.42093 .49684 Mdot
.56968 .55641 Mdot
.58265 .56486 Mdot
.45545 .20785 Mdot
.64999 .23433 Mdot
.75558 .3996 Mdot
.59847 .30847 Mdot
.44957 .67144 Mdot
.64129 .28062 Mdot
.69015 .59469 Mdot
.71557 .63766 Mdot
.55666 .43296 Mdot
.66114 .77507 Mdot
.5042 .67821 Mdot
.37166 .4135 Mdot
.72684 .31169 Mdot
.42706 .07325 Mdot
.66995 .76378 Mdot
.39859 .33768 Mdot
.41559 .93317 Mdot
.56958 .1552 Mdot
.54138 .4698 Mdot
.36149 .53806 Mdot
.70045 .33648 Mdot
.57587 .90778 Mdot
.72884 .50917 Mdot
.52854 .74834 Mdot
.7573 .62678 Mdot
.62093 .52984 Mdot
.52144 .58064 Mdot
.51505 .61482 Mdot
.5068 .62709 Mdot
.58576 .49181 Mdot
.74299 .67798 Mdot
.51979 .85516 Mdot
.43556 .3584 Mdot
.58142 .26662 Mdot
.54381 .59748 Mdot
.425 .53796 Mdot
.50752 .24981 Mdot
.6645 .4561 Mdot
.40429 .42524 Mdot
.49722 .92105 Mdot
.5199 .30274 Mdot
.55855 .79285 Mdot
.40985 .63872 Mdot
.65072 .79965 Mdot
.47199 .72314 Mdot
.63919 .54042 Mdot
.73132 .54118 Mdot
.40207 .49229 Mdot
.52075 .9275 Mdot
.5218 .89072 Mdot
.48204 .9284 Mdot
.4434 .27927 Mdot
.57275 .38903 Mdot
.43448 .13013 Mdot
.4208 .48106 Mdot
.72402 .46963 Mdot
.36196 .41252 Mdot
.41772 .555 Mdot
.46746 .33902 Mdot
.74697 .65933 Mdot
.47724 .8457 Mdot
.55058 .35799 Mdot
.39108 .84313 Mdot
.55942 .61982 Mdot
.40418 .75391 Mdot
.6604 .44859 Mdot
.48641 .89684 Mdot
.37356 .26361 Mdot
.49324 .12581 Mdot
.4017 .78858 Mdot
.58865 .32723 Mdot
.44394 .04296 Mdot
.47784 .73911 Mdot
.6918 .5466 Mdot
.40203 .61745 Mdot
.58436 .31563 Mdot
.65576 .31982 Mdot
.60191 .87238 Mdot
.42816 .51694 Mdot
.5354 .42378 Mdot
.68736 .58298 Mdot
.5607 .30413 Mdot
.57186 .51893 Mdot
.39138 .43156 Mdot
.46789 .35543 Mdot
.70806 .36403 Mdot
.41692 .89234 Mdot
.50517 .81981 Mdot
.55019 .35655 Mdot
.43989 .90159 Mdot
.46541 .29287 Mdot
.39787 .56609 Mdot
.61112 .67877 Mdot
.41511 .57826 Mdot
.43872 .15903 Mdot
.4346 .10032 Mdot
.58653 .38623 Mdot
.45075 .07234 Mdot
.39517 .62274 Mdot
.47856 .77875 Mdot
.57475 .67016 Mdot
.6835 .62149 Mdot
.56218 .49259 Mdot
.5479 .30741 Mdot
.37348 .62845 Mdot
.50715 .24793 Mdot
.60613 .32572 Mdot
.66516 .33849 Mdot
.53531 .52108 Mdot
.55209 .41384 Mdot
.66158 .68858 Mdot
.72293 .43605 Mdot
.44804 .21676 Mdot
.48339 .32239 Mdot
.53116 .27587 Mdot
.43829 .0879 Mdot
.48915 .81494 Mdot
.56878 .81753 Mdot
.72254 .3025 Mdot
.55259 .88813 Mdot
.71593 .41077 Mdot
.56888 .86386 Mdot
.51084 .57828 Mdot
.54957 .89478 Mdot
.39565 .8599 Mdot
.39111 .26635 Mdot
.72005 .43718 Mdot
.70871 .18736 Mdot
.58394 .6414 Mdot
.44811 .1362 Mdot
.43581 .86201 Mdot
.43084 .06613 Mdot
.69536 .69443 Mdot
.41254 .46486 Mdot
.38273 .72576 Mdot
.57826 .35258 Mdot
.51543 .39499 Mdot
.65796 .4181 Mdot
.52609 .204 Mdot
.66597 .53039 Mdot
.398 .87746 Mdot
.43234 .41081 Mdot
.63404 .5862 Mdot
.61792 .49593 Mdot
.63699 .21514 Mdot
.49466 .30469 Mdot
.71368 .64322 Mdot
.54081 .94485 Mdot
.60149 .10585 Mdot
.46675 .755 Mdot
.60255 .30941 Mdot
.59031 .68103 Mdot
.66963 .36222 Mdot
.58369 .44515 Mdot
.52307 .57502 Mdot
.49243 .65362 Mdot
.58256 .31415 Mdot
.73178 .49151 Mdot
.69046 .54436 Mdot
.43575 .66838 Mdot
.64038 .34933 Mdot
.52994 .43618 Mdot
.50572 .63101 Mdot
.4432 .11334 Mdot
.53911 .19004 Mdot
.41447 .75537 Mdot
.60314 .51601 Mdot
.58186 .44444 Mdot
.62455 .896 Mdot
.56355 .31323 Mdot
.38508 .46136 Mdot
.52376 .64191 Mdot
.60699 .16508 Mdot
.51889 .2768 Mdot
.57309 .16297 Mdot
.45302 .10479 Mdot
.48582 .25516 Mdot
.48065 .81808 Mdot
.73044 .50073 Mdot
.53878 .90983 Mdot
.42004 .13636 Mdot
.59125 .61356 Mdot
.61867 .46786 Mdot
.5065 .08028 Mdot
.42411 .76426 Mdot
.72997 .49368 Mdot
.64423 .1595 Mdot
.39073 .72193 Mdot
.72774 .5457 Mdot
.70975 .65715 Mdot
.64614 .80529 Mdot
.4581 .67517 Mdot
.5178 .79717 Mdot
.7258 .49323 Mdot
.71532 .38789 Mdot
.4438 .63152 Mdot
.60062 .76125 Mdot
.54167 .26578 Mdot
.59852 .30294 Mdot
.54382 .82007 Mdot
.38191 .71637 Mdot
.41108 .78741 Mdot
.61473 .79454 Mdot
.68773 .4525 Mdot
.57505 .21495 Mdot
.56815 .87154 Mdot
.59143 .24193 Mdot
.71244 .63354 Mdot
.65965 .69052 Mdot
.62865 .40266 Mdot
.50927 .39292 Mdot
.59806 .87331 Mdot
.45855 .15196 Mdot
.50207 .62186 Mdot
.70706 .67042 Mdot
.62104 .72325 Mdot
.52368 .57249 Mdot
.55133 .60485 Mdot
.50424 .19411 Mdot
.56195 .40384 Mdot
.36919 .46685 Mdot
.46383 .93321 Mdot
.36785 .66721 Mdot
.7115 .65326 Mdot
.58517 .32558 Mdot
.67202 .82509 Mdot
.60863 .40467 Mdot
.45 .21606 Mdot
.52121 .25131 Mdot
.45103 .61907 Mdot
.7284 .45709 Mdot
.72904 .48655 Mdot
.53483 .31416 Mdot
.45309 .27368 Mdot
.57329 .47147 Mdot
.53642 .34403 Mdot
.49823 .80597 Mdot
.38495 .66342 Mdot
.53227 .36719 Mdot
.56532 .59595 Mdot
.50003 .318 Mdot
.54683 .70817 Mdot
.59191 .34866 Mdot
.57297 .4841 Mdot
.45333 .2944 Mdot
.36854 .68678 Mdot
.6829 .2996 Mdot
.45695 .59451 Mdot
.53236 .80444 Mdot
.60079 .36785 Mdot
.62524 .39588 Mdot
.56413 .31794 Mdot
.56042 .61704 Mdot
.57457 .90585 Mdot
.77043 .51578 Mdot
.39694 .70592 Mdot
.35948 .30457 Mdot
.43777 .86988 Mdot
.50591 .31326 Mdot
.39748 .18041 Mdot
.72593 .50815 Mdot
.47716 .21578 Mdot
.44018 .12499 Mdot
.61514 .90774 Mdot
.46693 .25576 Mdot
.52563 .45287 Mdot
.48219 .19629 Mdot
.43628 .89578 Mdot
.59987 .48636 Mdot
.76687 .55978 Mdot
.46007 .7127 Mdot
.54952 .77069 Mdot
.6103 .60584 Mdot
.46108 .73414 Mdot
.42839 .50491 Mdot
.55995 .55197 Mdot
.72145 .40969 Mdot
.46804 .28856 Mdot
.68436 .40488 Mdot
.4039 .24227 Mdot
.61804 .6611 Mdot
.48797 .06084 Mdot
.605 .75076 Mdot
.56442 .27494 Mdot
.74773 .36318 Mdot
.54297 .64097 Mdot
.73229 .50496 Mdot
.5965 .88057 Mdot
.41742 .60525 Mdot
.54267 .90426 Mdot
.57611 .35099 Mdot
.42211 .24234 Mdot
.57073 .15931 Mdot
.51721 .86082 Mdot
.40718 .48155 Mdot
.47113 .81921 Mdot
.60799 .40824 Mdot
.40129 .10389 Mdot
.39427 .39541 Mdot
.45005 .40332 Mdot
.42469 .79697 Mdot
.59634 .57048 Mdot
.45752 .67507 Mdot
.45994 .74783 Mdot
.49295 .86199 Mdot
.41321 .2397 Mdot
.46449 .70081 Mdot
.52374 .22852 Mdot
.49272 .02857 Mdot
.58376 .56847 Mdot
.62636 .62436 Mdot
.46693 .79965 Mdot
.47059 .79638 Mdot
.43698 .40535 Mdot
.44269 .36971 Mdot
.44613 .10935 Mdot
.5385 .90375 Mdot
.38135 .61563 Mdot
.50106 .77476 Mdot
.616 .2308 Mdot
.72496 .58862 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X_ooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002Wooooo`;o00000oooool3o`000;Wooooo002Wooooo`Co000000?ooooo
o`000?ooool0^_ooool00:Wooooo0_l000000ooooooo0000ooooo`2jooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00VOooool2o`00017ooooo00?o0000ooooooooool0^Oooool009Wooooo0_l0000Aoooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o0000
0oooool2o`000;Cooooo002/ooooo`03o`000?oooooooooo00?ooooo0_l0002dooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00Z?ooool2o`0000;ooooo00?o0000ooooooooool0^Oooool00:So
oooo0_l00002ooooo`03o`000?oooooooooo0;Wooooo002Eooooo`;o00005Oooool00ol0003ooooo
ooooo`2iooooo`00UOooool2o`0001Gooooo00?o0000ooooooooool0^Oooool009?ooooo0_l00006
ooooo`;o00003oooool00ol0003oooooooooo`07ooooo`;o0000/?ooool009?ooooo0_l00006oooo
o`;o00003oooool3o`0000Oooooo0_l0002`ooooo`00[?ooool01?l0003oooooo`000?l0002hoooo
o`00[?ooool01?l0003oooooo`000?l0002hooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
Uoooool2o`0001?ooooo00?o0000ooooooooool0^Oooool009Oooooo0_l0000Cooooo`03o`000?oo
oooooooo00;ooooo0_l0002eooooo`00[?ooool00ol0003oooooooooo`02ooooo`?o0000]?ooool0
0:cooooo00?o0000ooooooooool00oooool2o`0002Kooooo0_l0002<ooooo`00U_ooool2o`0001Co
oooo0ol0000[ooooo`;o0000S?ooool008_ooooo0_l00009ooooo`;o00005?ooool00ol0003ooooo
ooooo`0Aooooo`;o0000Y_ooool008_ooooo0_l0000>ooooo`?o00003_ooool00ol0003ooooooooo
o`0Aooooo`;o00002oooool2o`0009Wooooo002Jooooo`Co00003_ooool00ol0003oooooooooo`0N
ooooo`;o0000VOooool009Wooooo0ol0000@ooooo`03o`000?oooooooooo0;Wooooo002Iooooo`;o
00004Oooool00ol0003oooooooooo`2iooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0;Wooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@?ooooo0_l000000oooooooEEEEojVYZ@08ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0^Oooool0087ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41000_l00008oooo
o`;o000000?oooooojVYZOmEEED02Oooool00ol0003oooooooooo`02o`000004ooooool0003o0000
o`000;Wooooo0029ooooo`04o`000?ooooooooooooooo`?o00002?ooool2o`0000;ooooo00?o8B4Q
ooooooooool01_ooool01?mgMgOo<S8booooooooool2o`000003ooooool0003ooooo0;[ooooo0029
ooooo`05o`000?ooooooooooooooool000002?ooool2o`0000Cooooo00?oEEEEolc<c?ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool06?ooool2o`0009oooooo
0029ooooo`05oa0@4?ooooooooooooooool@41002?ooool2o`0000Cooooo00?oZJVYogMgMoooool0
0oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Sooooo0_l0002Oooooo`00ROoo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0_l00006ooooo`05oa0@4?l0003o0000oooooolb
<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool2o`0000Kooooo1Ol00004ooooo`Co00001_ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00Woooool2o`0000_ooooo00?o0000ooooooooool04_ooool2o`000:Gooooo002Noooo
o`?o00001oooool2o`0000;ooooo0ol0000Booooo`;o0000YOooool009kooooo0_l00008ooooo`;o
00000_ooool00ol0003oooooooooo`0Dooooo`;o0000Xoooool009Oooooo0_l0000Cooooo`03o`00
0?oooooooooo01Cooooo0_l0002Sooooo`00Uoooool2o`0001;ooooo0_l0000Fooooo`;o00005_oo
ool2o`0008_ooooo002[ooooo`;o00005_ooool3o`0000Wooooo0_l0000:ooooo`;o0000Roooool0
0:cooooo0ol0000Eooooo`;o00002Oooool2o`0009Oooooo002/ooooo`Co0000^?ooool00:cooooo
00Co0000ooooool0003o00008?ooool2o`0009Kooooo002/ooooo`?o00008Oooool2o`0009Kooooo
002:ooooo`;o00008?ooool00ol0003oooooooooo`2iooooo`00R_ooool2o`00023ooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0@Oooool2o`0007Kooooo002/ooooo`03o`000?oooooooooo00Wooooo0_l0000fooooo`;o0000
M_ooool008Wooooo0_l00004ooooo`;o00006oooool3o`0000Wooooo0_l0000Looooo`;o0000T?oo
ool008Wooooo0_l00004ooooo`;o00005Oooool2o`0000Cooooo0ol0000Looooo`;o00002Oooool2
o`00093ooooo002Vooooo`;o00001?ooool3o`0001cooooo0_l0002Kooooo`00[?ooool00ol0003o
ooooooooo`05ooooo`;o0000/_ooool00:cooooo00?o0000ooooooooool01Oooool2o`000;;ooooo
002Mooooo`;o00003Oooool00ol0003oooooooooo`0Eooooo`;o00001oooool2o`0009Wooooo002M
ooooo`;o00003Oooool00ol0003oooooooooo`0>ooooo`;o00001Oooool2o`0000Oooooo0_l0002I
ooooo`00V_ooool3o`0000Gooooo1?l00006ooooo`03o`000?oooooooooo00kooooo0_l00005oooo
o`;o00004oooool2o`0008gooooo002Jooooo`?o00001Oooool4o`0000Kooooo00?o0000oooooooo
ool05Oooool2o`0001?ooooo0_l0002=ooooo`00Q?ooool2o`000003ooooool0003o000002?ooooo
00?o0000ooooooooool0;Oooool2o`0008[ooooo0024ooooo`;o000000?oooooo`000?l000008ooo
ool3o`0002?ooooo0_l00008ooooo`;o0000R_ooool00:cooooo00?o0000ooooooooool01?ooool2
o`0001gooooo0_l0002Dooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o00007Oooool2o`00
09Cooooo002/ooooo`03o`000?oooooooooo02?ooooo0_l00009ooooo`;o0000ROooool00:cooooo
00?o0000ooooooooool0;_ooool2o`0008Wooooo002?ooooo`;o00006oooool00ol0003ooooooooo
o`2iooooo`00S?ooool2o`000004ooooool0003o0000onk^kP;o000000?o<S8bonk^k_ooool01?oo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01_ooooo
0_l0002Looooo`00S?ooool2o`0000?ooooo00GoMgMgo`000?l0003oV9RHogMgM`05ooooo`;o8B4Q
2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01_ooooo0_l0002Looooo`00ROoo
ool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo
00Co0000ooooool0003o00006_ooool2o`0009cooooo0029ooooo`;o00000oooool2o`000003oooo
ool0003ooooo00;ooooo00?o0000ooooooooool03Oooool00omgMgOo<S8booooo`04ooooo`Co0000
0oooool2o`000;?ooooo0029ooooo`;o00000oooool2o`000003ooooool0003ooooo00;ooooo00?o
0000ooooooooool02Oooool2o`000004ob4Q8Ol0003o<S8bolc<c0;o00000oooool00ol0003ooooo
ooooo`04ooooo`;o0000/oooool0097ooooo00Co410@oooooooooooooooo0_l0000:ooooo`;o0000
1?ooool2o`0000?ooooo00?o0000ooooooooool0<oooool2o`0008Cooooo002Aooooo`04ogMgMonH
V9SooooooiRHV0;o00002oooool00ol0003oooooooooo`07ooooo`;o0000=?ooool2o`0008Cooooo
0022ooooo`;o00003Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000
^_ooool008;ooooo0_l00004ooooo`;o00008_ooool00ol0003oooooooooo`0:ooooo`;o00002ooo
ool2o`000:3ooooo0028ooooo`;o00008_ooool00ol0003oooooooooo`0:ooooo`;o00002oooool2
o`000:3ooooo002Looooo`;o00003_ooool00ol0003oooooooooo`2iooooo`00W?ooool2o`0000ko
oooo0ol00003ooooo`;o00000_ooool2o`0000Wooooo0_l00005ooooo`;o0000W_ooool009Wooooo
0_l0000Aooooo`03o`000?oooooooooo00?ooooo0_l00002ooooo`;o00002Oooool2o`0000Gooooo
0_l00006ooooo`;o00005?ooool2o`00083ooooo002Iooooo`;o00004Oooool00ol0003ooooooooo
o`0Qooooo`;o00002?ooool3o`0000Wooooo0_l00020ooooo`00[?ooool00ol0003oooooooooo`0[
ooooo`?o0000Roooool00:7ooooo0_l00009ooooo`03o`000?oooooooooo0;Wooooo002Qooooo`;o
00002Oooool00ol0003oooooooooo`2iooooo`00W?ooool2o`0000;ooooo0_l0000:ooooo`03o`00
0?oooooooooo02cooooo0_l0002;ooooo`00W?ooool2o`0000;ooooo0_l0000:ooooo`03o`000?oo
oooooooo02cooooo0_l0002;ooooo`00[?ooool3o`0002gooooo0_l0000:ooooo`;o0000O_ooool0
07gooooo0_l0000Eooooo`;o00005_ooool00ol0003oooooooooo`03ooooo`;o00003?ooool2o`00
00[ooooo0_l0000>ooooo`;o00002_ooool2o`0000_ooooo0_l0001aooooo`00OOooool2o`0000oo
oooo0_l00004ooooo`;o00005?ooool3o`0000Gooooo0_l00007ooooo`;o00000oooool2o`0000[o
oooo0_l0000Jooooo`;o00002oooool2o`00077ooooo002>ooooo`;o00006_ooool3o`0000kooooo
0_l0000?ooooo`?o0000VOooool00:cooooo00Co0000ooooool0003o00004Oooool2o`0000Wooooo
0ol0000Wooooo`;o0000L?ooool00:cooooo00Co0000ooooool0003o00001oooool2o`0000Sooooo
0_l00004ooooo`;o00005oooool2o`0001Cooooo0_l0001`ooooo`00[?ooool2o`0000Wooooo0_l0
0008ooooo`;o00001?ooool2o`0001Oooooo0_l00026ooooo`00Y_ooool2o`0000Cooooo0_l0000C
ooooo`;o00007?ooool2o`0008Oooooo002Vooooo`;o00001?ooool3o`0001Wooooo0_l00005oooo
o`;o00003_ooool2o`0008Oooooo002/ooooo`03o`000?oooooooooo00[ooooo0_l0000=ooooo`?o
00001?ooool2o`0009Oooooo002/ooooo`03o`000?oooooooooo00[ooooo0_l00008ooooo`;o0000
1?ooool2o`0009gooooo002/ooooo`03o`000?oooooooooo01Cooooo0_l00004ooooo`;o0000WOoo
ool008[ooooo0_l0000Pooooo`03o`000?oooooooooo027ooooo0_l0000Looooo`;o00002_ooool2
o`0006cooooo002:ooooo`;o00005Oooool2o`0000Wooooo00?o0000ooooooooool08Oooool2o`00
013ooooo0_l0000:ooooo`;o00002_ooool2o`0006cooooo002Qooooo`;o00002Oooool00ol0003o
ooooooooo`0cooooo`;o0000Q?ooool00:cooooo00?o0000ooooooooool02Oooool2o`000:kooooo
002/ooooo`03o`000?oooooooooo00Wooooo0_l0000@ooooo`;o00003_ooool2o`0008cooooo002/
ooooo`?o00005_ooool2o`0000?ooooo0_l0000>ooooo`;o0000S?ooool00:7ooooo0_l00009oooo
o`03o`000?oooooooooo00Kooooo0_l0000>ooooo`;o0000XOooool009Kooooo0_l00009ooooo`;o
00002Oooool00ol0003oooooooooo`06ooooo`;o00001Oooool2o`000:[ooooo002Fooooo`;o0000
5?ooool00ol0003oooooooooo`0=ooooo`;o00009_ooool2o`0008;ooooo002/ooooo`03o`000?oo
oooooooo03Gooooo0_l0000:ooooo`;o00002oooool2o`0006Wooooo0029ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool2o`0000;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8b
omgMg@05ooooo`03o`000?oooooooooo00Oooooo0_l0000Eooooo`;o00005Oooool2o`0000[ooooo
0_l0000;ooooo`;o0000JOooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`;o0000
0_lQ8B44ooooo`;o000000?ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo00Oooooo0_l0000Eooooo`;o0000VOooool0087ooooo1_l00002ooooo`04oa0@4?oo
ooooooooooooo`;o00002_ooool2o`000003ob4Q8Oo^k^kooooo00Sooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`;o00006_ooool2o`0009Wooooo0029ooooo`04o`000?oo
ooooooooooooo`;o00003?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo
0ol00002ooooo`;o0000]Oooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMg
MomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;Wo
oooo0029ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0^Oooool008Wooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo01Wooooo0_l0002Nooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`0E
ooooo`;o00000_ooool2o`0002Wooooo0_l0001cooooo`00R_ooool2o`00023ooooo00?o0000oooo
ooooool05Oooool2o`0002gooooo0_l0001cooooo`00ROooool3o`00023ooooo00?o0000oooooooo
ool01?l0002eooooo`00ROooool2o`00017ooooo0_l0000>ooooo`03o`000?oooooooooo00Co0000
6oooool2o`0000Gooooo0_l0002Aooooo`00W?ooool2o`0000kooooo0ol0000Oooooo`;o00001Ooo
ool2o`00017ooooo0_l0000Fooooo`;o0000I_ooool008kooooo0_l0000;ooooo`;o00003oooool0
0ol0003oooooooooo`0Aooooo`;o00005?ooool2o`00013ooooo0_l0000Fooooo`;o0000I_ooool0
08kooooo0_l00007ooooo`;o00000_ooool2o`0000oooooo00?o0000ooooooooool04Oooool2o`00
00gooooo0_l00005ooooo`;o00004?ooool2o`0007kooooo002Gooooo`;o00004oooool00ol0003o
ooooooooo`0Pooooo`;o00005oooool2o`0000_ooooo0_l0001aooooo`00O_ooool2o`000003oooo
ool0003o000001;ooooo0_l0000Eooooo`03o`000?oooooooooo023ooooo0_l0000Rooooo`Co0000
LOooool007kooooo0_l000000ooooooo0000o`00000Booooo`;o00005Oooool00ol0003ooooooooo
o`0>ooooo`;o00007oooool2o`0001?ooooo1?l0001aooooo`00T_ooool2o`0001Sooooo00?o0000
ooooooooool03_ooool2o`0001oooooo1?l0000Cooooo`;o0000LOooool009;ooooo0_l0000Hoooo
o`03o`000?oooooooooo037ooooo0_l0000Cooooo`;o0000LOooool008cooooo0_l0000Nooooo`?o
00002?ooool2o`000:oooooo002<ooooo`;o00007_ooool00ol0003oooooooooo`08ooooo`;o0000
00?oooooo`000?l00000;_ooool2o`0007cooooo0028ooooo`;o00008_ooool00ol0003ooooooooo
o`0;ooooo`;o0000;_ooool2o`0007cooooo0028ooooo`;o00008_ooool00ol0003oooooooooo`0?
ooooo`;o0000@_ooool2o`0006Cooooo002/ooooo`03o`000?oooooooooo00Kooooo0_l00007oooo
o`;o0000=?ooool3o`0000_ooooo0_l0001Tooooo`00[?ooool00ol0003oooooooooo`06ooooo`;o
0000?Oooool3o`00077ooooo002Booooo`;o00006?ooool00ol0003oooooooooo`2iooooo`00T_oo
ool2o`0001Sooooo00?o0000ooooooooool06?ooool2o`0009oooooo002<ooooo`;o00007_ooool0
0ol0003oooooooooo`0Hooooo`;o00006?ooool2o`0000Sooooo0_l0001kooooo`00S?ooool2o`00
01kooooo0ol00005ooooo`;o00006oooool2o`0000kooooo0_l00007ooooo`?o0000Noooool00:co
oooo00?o0000ooooooooool01Oooool2o`0001_ooooo0_l0000Gooooo`;o0000O?ooool00:cooooo
00?o0000ooooooooool0<oooool2o`0001?ooooo0_l0001_ooooo`002Oooool4o`000003oa0@4?oo
oooooooo01Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^
ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B42ooooo`Oo00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Kooooo
00?o0000ooooooooool06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go
00001?ooool01Om4A4Co0000o`000?l0003ogMgM00oooooo00?ok^k^o`000?l000000_l00005oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
6?ooool4o`000003oa0@4?oooooooooo01;ooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMg
Molb<S;ooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo
<S8booooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@;ooooo0_l000001OnH
V9So8B4Qonk^k_ooooooA4A400;ooooo0_l00003ooooo`03ogMgMolb<S;ooooo01Gooooo00?o0000
ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`0>ooooo`05ogMgMol0003o0000o`000?mg
MgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool06Oooool00ol0
003oooooooooo`0Dooooo`001_l00005ooooo`03o`000?oooooooooo013ooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo
00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`05
ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00?ooooo0_l00007ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo0_l00004ooooo`03o`000?oooooooooo01Cooooo0ol0000Hooooo`05oa0@4?oo
ooooooooooooool@41001oooool2o`0000?ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003ooooo
ooooo`0=ooooo`05oa0@4?oooooo0000o`000?l@41004?ooool00ol0003oooooooooo`0=ooooo`05
oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?ooool01Ol0003o
oooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`0>oooo
o`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0>ooooo`05o`000?oooooo
ooooooooool000000oooool2o`0000Sooooo00?oV9RHob4Q8Oo^k^h01oooool2o`0001Kooooo0ol0
000:ooooo`;o00003?ooool01Ol0003ooooooooooooooooo000000Oooooo0_l00004ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool03_ooool00ol0003oooooo`000002o`0000oooooo
00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qoooooooo
ool01_ooool00omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`00
0?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003?ooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMg
MomVIVKooooo00?ooooo00?o0000ob4Q8Ol000000_l0000Fooooo`03o`000?oooooooooo00[ooooo
0_l00009ooooo`;o000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMg
MomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00?ooooo`03o`000?oooooo000000;o
00003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000>
ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Jooooo`03o`000?oo
oooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go410@oooooooooooooooooa0@
400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooo
oooooooo410@00cooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Hooooo`?o00005Oooool2o`000003
ooooool@413ooooo00;ooooo00?o410@ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400:ooooo`?o00004oooool01Ol@
413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooooooo
o`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool02Oooool2o`0000Kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0:ooooo`?o00004oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool05?ooool000Wooooo00?oEEEEofIVI_l000006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo1Ol00004ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00;o0000
0_ooool4o`0001Oooooo00?o0000ooooooooool06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00002?ooool2o`0000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`Co00004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol0
0004ooooo`Co00006Oooool00omEEEGoIVIVo`00000Fooooo`00SOooool2o`0000;ooooo0_l0000I
ooooo`03o`000?oooooooooo01Gooooo0_l00007ooooo`;o0000VOooool00:cooooo00?o0000oooo
ooooool05Oooool2o`0000Oooooo0_l0000Xooooo`;o0000Koooool008_ooooo0_l0000Oooooo`03
o`000?oooooooooo01Wooooo0_l0000]ooooo`?o0000Hoooool2o`0000;ooooo0_l00005ooooo`00
Roooool2o`0001oooooo00?o0000ooooooooool04Oooool2o`0000Kooooo0_l0000/ooooo`Co0000
Hoooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Gooooo002Aooooo`;o00006Oooool00ol0003o
ooooooooo`0Aooooo`;o00004?ooool2o`0002;ooooo0ol0001Uooooo`04omgMgOl0003o410@olc<
c0Kooooo0007oooooooo0000C?l0000<ooooo`04onk^k_lQ8B7o410@onk^kPKooooo0007ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`?o
00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`?o00001Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00[ooooo00Co8B4QogMgMomgMgOo<S8b1_ooool000Oooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool03_ooool2o`0001Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Oooooo`;o
00001Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool02Oooool2o`0000;ooooo0_l00005ooooo`00U?ooool2o`0001Kooooo00?o0000ooooooooool0
Aoooool4o`0006kooooo002/ooooo`03o`000?oooooooooo04Oooooo0ol0001_ooooo`00[?ooool0
0ol0003oooooooooo`0Oooooo`;o0000=Oooool2o`00067ooooo002Dooooo`;o00005_ooool00ol0
003oooooooooo`0Dooooo`;o00002Oooool2o`0003Gooooo0_l0001Qooooo`00U?ooool2o`0001Ko
oooo00?o0000ooooooooool02?ooool2o`0000[ooooo0_l00009ooooo`;o0000V?ooool00:cooooo
0ol00008ooooo`;o00005Oooool2o`0009Sooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`03o`000?oooooooooo02Cooooo0_l0000=ooooo`;o0000Q?ooool00:cooooo00?o0000oooo
ooooool07Oooool2o`0000Gooooo0_l0000=ooooo`;o0000Q?ooool0093ooooo0_l0000Jooooo`03
o`000?oooooooooo01gooooo0_l0002Jooooo`00O_ooool2o`00013ooooo0_l000000ooooooo0000
o`00000Gooooo`03o`000?oooooooooo02_ooooo0_l0002<ooooo`00O_ooool2o`0001?ooooo0_l0
000Gooooo`03o`000?oooooooooo02_ooooo0_l0000Looooo`;o0000K_ooool00:cooooo00?o0000
ooooooooool0>oooool3o`0000[ooooo0ol0001^ooooo`00[?ooool00ol0003oooooooooo`0koooo
o`?o00002_ooool2o`0006oooooo002/ooooo`?o00004?ooool2o`000:Oooooo002@ooooo`;o0000
6_ooool00ol0003oooooooooo`0@ooooo`;o0000Yoooool0093ooooo0_l0000Jooooo`03o`000?oo
oooooooo013ooooo0_l00002ooooo`;o0000Xoooool00:cooooo00?o0000ooooooooool05?ooool2
o`00037ooooo0_l0000<ooooo`;o0000H_ooool008gooooo0_l0000Mooooo`03o`000?oooooooooo
00cooooo0_l0000:ooooo`;o0000;Oooool2o`0000cooooo0_l0001Rooooo`00R_ooool2o`000003
ooooool0003o000000;ooooo0_l0000Iooooo`03o`000?oooooooooo00?ooooo0_l00007ooooo`;o
00002_ooool2o`0009oooooo002:ooooo`;o00001Oooool2o`0001Wooooo00?o0000ooooooooool0
0oooool2o`0000Oooooo0_l0000:ooooo`;o00000_ooool2o`0009_ooooo002/ooooo`03o`000?oo
oooooooo00Cooooo0_l0000Booooo`;o00000_ooool2o`0009_ooooo002/ooooo`?o00001?ooool2
o`0001;ooooo0_l0002Oooooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool00_l00002oooo
o`;o0000@_ooool2o`0006oooooo002@ooooo`;o00006_ooool00ol0003oooooooooo`02o`0000;o
oooo0_l0000/ooooo`;o00001_ooool2o`0000cooooo0_l0001_ooooo`00[?ooool00ol0003ooooo
ooooo`04ooooo`;o00008oooool2o`0000Kooooo0ol00006ooooo`;o0000OOooool00:cooooo00?o
0000ooooooooool0:Oooool2o`0000Kooooo0_l0000Dooooo`;o0000L?ooool00:cooooo00?o0000
ooooooooool04oooool2o`0003;ooooo0_l0001`ooooo`00WOooool2o`0000gooooo00?o0000oooo
ooooool04oooool2o`0002Kooooo0_l0001looooo`00ROooool2o`0001;ooooo0_l0000=ooooo`03
o`000?oooooooooo00_ooooo0_l00005ooooo`;o00003Oooool2o`0001Sooooo0_l0001looooo`00
ROooool2o`00027ooooo0ol0000;ooooo`;o00001Oooool2o`0000gooooo0_l0000>ooooo`;o0000
Q_ooool00:cooooo00?o0000ooooooooool0<Oooool2o`0008Kooooo002@ooooo`;o00006_ooool0
0ol0003oooooooooo`0>ooooo`;o00004Oooool2o`0009Kooooo002=ooooo`;o000000?oooooo`00
0?l000006_ooool00ol0003oooooooooo`0>ooooo`;o00004Oooool2o`0009Kooooo002=ooooo`;o
000000?oooooo`000?l000006_ooool00ol0003oooooooooo`0Fooooo`;o00000oooool2o`0009co
oooo0024ooooo`;o00009_ooool00ol0003oooooooooo`02ooooo`;o00004_ooool2o`0000?ooooo
0_l0002Looooo`00Q?ooool2o`0000?ooooo00Gok^k^oc8b<_l0003o0000onk^kP05ooooo`;o8B4Q
1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00;o
oooo0_l0000=ooooo`;o0000Y_ooool008Wooooo00GoMgMgoiRHV?l0003o0000ogMgM`05ooooo`;o
8B4Q1?ooool01OnHV9So8B4Qo`000?l0003oA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool2o`00
017ooooo0ol0000Kooooo`;o00002Oooool2o`0007kooooo0029ooooo`;o00000_ooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`00013o
oooo0_l0000Dooooo`;o00001_ooool2o`0000Wooooo0_l0001nooooo`00P_ooool2o`0000Gooooo
0_l00002ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8b
ooooo`04ooooo`04o`000?oooooo0000o`0002Gooooo0_l00007ooooo`;o00008Oooool2o`0006Go
oooo0022ooooo`;o00001Oooool01Ol0003ooooooooooooooooo000000_ooooo0_l000000ooooooo
MgMgofIVIP04ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool4o`0002kooooo0_l0000Qoooo
o`;o0000IOooool008;ooooo0_l00005ooooo`05oa0@4?ooooooooooooooool@41002oooool2o`00
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`?o0000@oooool2o`00
07Cooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool2o`0000Kooooo00Go0000okZj
^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool2
o`0003Wooooo0ol0001cooooo`00Ooooool2o`0000Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02
o`000003ooooool0003o000000Kooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_oo
ool00ol0003oooooooooo`08ooooo`;o0000;Oooool2o`0000_ooooo0_l0001cooooo`00Ooooool2
o`0000gooooo0_l0000Looooo`03o`000?oooooooooo00Cooooo0_l00005ooooo`;o00002oooool2
o`0001gooooo0_l0000:ooooo`;o0000M?ooool00:cooooo00?o0000ooooooooool01?ooool2o`00
00Gooooo0_l0000;ooooo`;o00001?ooool2o`0001Oooooo0_l0000:ooooo`;o0000M?ooool00:co
oooo00?o0000ooooooooool07_ooool2o`0001Oooooo0_l00020ooooo`00[?ooool3o`000;Wooooo
002Yooooo`;o000000?oooooo`000?ooool0@oooool2o`0007Gooooo002Yooooo`;o000000?ooooo
o`000?ooool09Oooool2o`0001cooooo0_l0001eooooo`00Woooool2o`0000_ooooo00?o0000oooo
ooooool09?ooool2o`0001cooooo0_l0000:ooooo`;o0000JOooool008Kooooo0_l0000Gooooo`;o
00002oooool00ol0003oooooooooo`02ooooo`;o00008?ooool2o`0000Kooooo0_l00008ooooo`;o
00005_ooool2o`0006Wooooo0020ooooo`;o00001?ooool2o`0002Cooooo00?o0000ooooooooool0
0_ooool2o`0002Sooooo0_l00008ooooo`;o0000POooool0083ooooo0_l0000Dooooo`;o00005?oo
ool00ol0003oooooooooo`0<ooooo`;o00000_ooool2o`0000?ooooo0_l0000Zooooo`;o0000M_oo
ool009Kooooo0ol00002ooooo`;o00003oooool00ol0003oooooooooo`0<ooooo`;o00000_ooool2
o`0000?ooooo0_l0000Zooooo`;o0000M_ooool009Oooooo0_l00002ooooo`;o000000?oooooo`00
0?l000003?ooool3o`000;Wooooo002Nooooo`;o00003?ooool3o`00027ooooo0_l0000Zooooo`;o
0000J_ooool00:cooooo0ol0000Jooooo`;o00001Oooool2o`0002[ooooo0_l0001Zooooo`00[?oo
ool00ol0003oooooooooo`0Jooooo`;o0000WOooool0083ooooo0_l0000Zooooo`03o`000?oooooo
oooo03;ooooo0_l00025ooooo`00P?ooool2o`0002[ooooo00?o0000ooooooooool02_ooool2o`00
01gooooo0_l00006ooooo`?o00002Oooool2o`0007[ooooo002/ooooo`03o`000?oooooooooo00[o
oooo0_l0000Mooooo`;o00001_ooool2o`0000[ooooo0_l0001jooooo`00[?ooool00ol0003ooooo
ooooo`0mooooo`;o0000N_ooool00:3ooooo0_l0000:ooooo`?o0000<Oooool2o`0008Kooooo002P
ooooo`;o00002_ooool00ol0003oooooooooo`0aooooo`;o0000Q_ooool008[ooooo0_l0000Poooo
o`03o`000?oooooooooo02Oooooo0_l0002@ooooo`00R_ooool2o`0000Gooooo0_l0000Iooooo`03
o`000?oooooooooo00?ooooo0_l00007ooooo`;o00004?ooool2o`0000Oooooo0_l0002@ooooo`00
Qoooool2o`0000Sooooo0_l0000;ooooo`;o00003?ooool00ol0003oooooooooo`03ooooo`;o0000
1oooool2o`00013ooooo0_l00006ooooo`;o0000TOooool008Gooooo1?l0000Eooooo`;o00003?oo
ool00ol0003oooooooooo`0Vooooo`;o0000TOooool008Gooooo0_l0000Uooooo`03o`000?oooooo
oooo02Gooooo0_l00008ooooo`;o0000R?ooool0087ooooo0_l00004ooooo`;o00008oooool00ol0
003oooooooooo`0Uooooo`;o00002?ooool2o`0008Sooooo0021ooooo`;o00001?ooool2o`0001Wo
oooo0_l00008ooooo`?o00009Oooool2o`0009;ooooo0025ooooo`;o00006oooool2o`0000Sooooo
00?o0000ooooooooool09Oooool2o`0000Oooooo0_l00029ooooo`00QOooool2o`0002Gooooo00?o
0000ooooooooool00_l0000/ooooo`;o0000ROooool009oooooo0_l0000;ooooo`03o`000?oooooo
oooo00;o00000_ooool2o`000;?ooooo002Oooooo`;o00002oooool00ol0003oooooooooo`04oooo
o`;o0000/oooool00:Cooooo0_l00006ooooo`03o`000?oooooooooo00Oooooo0_l0002`ooooo`00
QOooool2o`0000[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?l0003ogMgM00Gooooo00?o0000ooooooooool01oooool2o`000;3ooooo0025ooooo`;o
00002_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0=_ooool2o`00087ooooo002Aooooo`05oa0@4?oooooooooooooo
ool@41002?ooool2o`0000Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06oooo
o`;o0000;_ooool2o`00087ooooo002Aooooo`05o`000?ooooooooooooooool000002?ooool2o`00
00Gooooo00?oMgMgoc8b<_ooool01?ooool3o`0000Kooooo0_l0000Gooooo`;o0000V?ooool008co
oooo0_l000001?oooooo0000o`000?l00003ooooo`03o`000?oooooooooo00Wooooo0_l000001?lQ
8B7o0000oc8b<_o<c<`5ooooo`03o`000?oooooooooo01oooooo0_l0002Hooooo`00S?ooool2o`00
0004ooooool0003o0000oa0@40?ooooo00?o410@ooooooooool02Oooool2o`0000Sooooo0_l0002k
ooooo`00TOooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo0_l00008ooooo`03o`000?oooooo
oooo00Kooooo0_l0000Aooooo`;o00003Oooool2o`0009Wooooo002Aooooo`05onk^k_lb<S;o0000
o`000?o^k^h00_ooool2o`0000Sooooo1?l00006ooooo`03o`000?oooooooooo00Wooooo0_l00004
ooooo`;o00003Oooool2o`0001Gooooo0_l00022ooooo`00Toooool2o`0001Oooooo00?o0000oooo
ooooool02Oooool2o`0002[ooooo0_l00022ooooo`00T?ooool2o`0001Kooooo0_l00002ooooo`03
o`000?oooooooooo00gooooo0_l0002Zooooo`00T?ooool2o`0001Kooooo0_l00002ooooo`03o`00
0?oooooooooo00gooooo0_l0002Zooooo`00T?ooool2o`0001[ooooo0ol0000Cooooo`;o00007Ooo
ool2o`0008Gooooo002@ooooo`;o00004_ooool2o`0000Kooooo0_l0000Dooooo`;o00007Oooool2
o`0008Gooooo002Tooooo`;o00001_ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00Roooool2o`000003ooooool0003o000001cooooo00?o0000ooooooooool0
^Oooool008_ooooo0_l000000ooooooo0000o`00000>ooooo`;o00003?ooool00ol0003ooooooooo
o`2iooooo`00W_ooool2o`0000cooooo00?o0000ooooooooool04?ooool2o`00013ooooo0_l0002E
ooooo`00Toooool2o`0000gooooo0_l00008ooooo`03o`000?oooooooooo00;ooooo0_l0000<oooo
o`;o00004?ooool2o`0000_ooooo0_l00028ooooo`00Toooool2o`0000cooooo0ol00008ooooo`?o
00000_ooool2o`0002[ooooo0ol00028ooooo`00XOooool2o`0000Wooooo00?o0000ooooooooool0
1oooool2o`0002Gooooo0_l00029ooooo`00Zoooool2o`0000Wooooo0_l0000Tooooo`;o0000R_oo
ool00:_ooooo0_l0000_ooooo`;o0000R_ooool00:Wooooo0_l000000ooooooo0000ooooo`2joooo
o`00Z?ooool3o`000003ooooool0003ooooo0;[ooooo002Rooooo`;o000000Coooooo`000?l0003o
oooo0_l00002ooooo`03o`000?oooooooooo01?ooooo0_l0002Tooooo`00T_ooool2o`0000kooooo
0_l000000ooooooo0000o`000005ooooo`?o00002oooool2o`0000Kooooo0_l0002Tooooo`00T_oo
ool2o`0001Sooooo0ol0000;ooooo`;o0000:?ooool2o`0008;ooooo002/ooooo`03o`000?oooooo
oooo03Gooooo0_l00022ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00Roooool2o`0001oooooo00?o0000ooooooooool0^Oooool008_ooooo0_l0
000Oooooo`03o`000?oooooooooo0;Wooooo0028ooooo`;o00008_ooool00ol0003oooooooooo`2i
ooooo`00R?ooool2o`0001[ooooo0_l00006ooooo`03o`000?oooooooooo00Kooooo0_l00006oooo
o`;o0000ZOooool00:Cooooo0_l00006ooooo`03o`000?oooooooooo00Kooooo0_l00006ooooo`;o
0000ZOooool00:cooooo0ol0002iooooo`00[?ooool00ol0003oooooooooo`03ooooo`;o0000]?oo
ool00:cooooo00?o0000ooooooooool00oooool2o`000;Cooooo0029ooooo`;o00007_ooool2o`00
0003ooooool0003ooooo00?ooooo0_l0002eooooo`00ROooool2o`0000_ooooo0_l0000Aooooo`;o
000000?oooooo`000?ooool00oooool2o`0000oooooo0_l0002Tooooo`00ROooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B400ooooooo0000o`000003ooooo`03o`000?o^k^kooooo00Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@02o`0000?ooooo00?o0000ooooooooool04oooool2o`00
0:Cooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@;ooooo0_l00002oooo
o`03oeEEEOnYZJWooooo00Oooooo00CoMgMgoc8b<_l0003o00000oooool00ol0003oooooooooo`2i
ooooo`00ROooool01Ol@413ooooooooooooooooo410@00Wooooo0_l00002ooooo`03ojVYZOmEEEGo
oooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`;o00002?ooool3
o`0009Wooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06
ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Cooooo`;o00002?ooool3o`0009Wooooo0029oooo
o`?o000000?oooooo`000?ooool03Oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01Oooool00ol0003oooooooooo`2iooooo`00ROooool01Ol@413o0000o`000?oooooo
410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Gooooo0_l0000Eooooo`;o0000Voooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Gooooo0_l0000Eooooo`;o0000Voooool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool03_ooool2o`000:Wooooo002/
ooooo`03o`000?oooooooooo00Cooooo0_l00008ooooo`;o0000ZOooool0093ooooo0_l0000Joooo
o`03o`000?oooooooooo00Cooooo0_l00007ooooo`;o0000Z_ooool0093ooooo0_l00005ooooo`;o
00003_ooool2o`0000?ooooo00?o0000ooooooooool03Oooool2o`0001Oooooo0_l0002Aooooo`00
Uoooool2o`0000Sooooo0_l00004ooooo`;o00000oooool3o`0002Kooooo0_l0002Aooooo`00V?oo
ool2o`0000Oooooo0_l00002ooooo`;o00001Oooool00ol0003oooooooooo`09ooooo`Co0000[?oo
ool009Sooooo0_l0000;ooooo`;o00001Oooool00ol0003oooooooooo`09ooooo`Co00002?ooool2
o`000:;ooooo002/ooooo`03o`000?oooooooooo00Wooooo0_l0000:ooooo`?o00002oooool2o`00
09Cooooo002/ooooo`03o`000?oooooooooo00Wooooo0_l0000;ooooo`;o00002oooool2o`0009Co
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002[ooooo`;o0000^oooool00:_ooooo0_l0002k
ooooo`00Zoooool4o`000;Wooooo002Vooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o
0000]?ooool00:Kooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l0002dooooo`00T?oo
ool2o`0000kooooo0_l0000:ooooo`03o`000?oooooooooo0;Wooooo002@ooooo`;o00003_ooool2
o`0000[ooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool0^Oooool00:cooooo00Co0000ooooool0003o00002Oooool2o`0000co
oooo0_l0002Oooooo`00[?ooool01?l0003oooooo`000?l00009ooooo`;o00003?ooool2o`0009oo
oooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Ooo
ool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`0=ooooo`;o0000Z_ooool00:cooooo00?o0000ooooooooool03Oooool2o`000:[ooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002Rooooo`Co000000?o410@ooooooooool00oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo0ol0002iooooo`00Y?ooool00ol0003oooooooooo`31
ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00Y?ooool00ol0003oooooooooo`31ooooo`00
Y?ooool00ol0003oooooooooo`31ooooo`00X_ooool00omEEEGoIVIVo`000033ooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Z_ooool01?l@413o0000o`00
0?l0002jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2j
ooooo`00Zoooool01_l0003oMgMgo`000?l0003oEEEEonk^k[Oooooo002[ooooo`06o`000?mEEEGo
k^k^oooooomgMgOoEEEE]oooool00:_ooooo00?o0000onk^k_ooool00_ooool00ol0003ooooooooo
o`2eooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo0;Gooooo002[oooo
o`06o`000?mEEEGok^k^oooooomgMgOoIVIV]oooool00:[ooooo00?o410@o`000?mgMgL00_l00000
0omVIVKok^k^ooooo`2fooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.63992 .57645 Mdot
.39437 .697 Mdot
.46199 .377 Mdot
.53265 .3629 Mdot
.57181 .37258 Mdot
.41399 .22936 Mdot
.51472 .5535 Mdot
.64697 .21197 Mdot
.4328 .93337 Mdot
.55928 .57311 Mdot
.41339 .57324 Mdot
.68925 .29892 Mdot
.65943 .39892 Mdot
.44219 .74501 Mdot
.66655 .25928 Mdot
.43383 .68981 Mdot
.39597 .5098 Mdot
.66533 .42873 Mdot
.50314 .77681 Mdot
.46575 .05144 Mdot
.65325 .38342 Mdot
.42624 .14882 Mdot
.45346 .09953 Mdot
.66906 .46271 Mdot
.73155 .48962 Mdot
.46567 .16608 Mdot
.43979 .26091 Mdot
.54527 .67948 Mdot
.51697 .08303 Mdot
.39951 .73074 Mdot
.65909 .42056 Mdot
.40729 .86618 Mdot
.52598 .05628 Mdot
.52317 .19587 Mdot
.62062 .55912 Mdot
.43833 .90544 Mdot
.69874 .51741 Mdot
.57319 .46822 Mdot
.52821 .10009 Mdot
.71854 .37783 Mdot
.73379 .54609 Mdot
.60998 .39709 Mdot
.51365 .83895 Mdot
.60549 .71211 Mdot
.64594 .50895 Mdot
.53474 .74302 Mdot
.51686 .72073 Mdot
.52586 .93042 Mdot
.60329 .56235 Mdot
.44688 .07184 Mdot
.5496 .90004 Mdot
.64594 .27985 Mdot
.72208 .74457 Mdot
.59497 .673 Mdot
.55226 .77631 Mdot
.37449 .33677 Mdot
.64928 .21728 Mdot
.39645 .44708 Mdot
.64601 .74443 Mdot
.64324 .45769 Mdot
.51349 .78337 Mdot
.43488 .97998 Mdot
.52251 .0945 Mdot
.5432 .4632 Mdot
.4408 .04609 Mdot
.36876 .5518 Mdot
.56336 .50806 Mdot
.50169 .73062 Mdot
.57492 .5326 Mdot
.67054 .51225 Mdot
.48289 .13967 Mdot
.50439 .36538 Mdot
.56028 .55789 Mdot
.54085 .35496 Mdot
.5213 .09308 Mdot
.45769 .62438 Mdot
.72181 .7451 Mdot
.46136 .81924 Mdot
.61928 .22768 Mdot
.57241 .33314 Mdot
.63813 .68237 Mdot
.42144 .82933 Mdot
.47654 .25094 Mdot
.61903 .44619 Mdot
.54882 .07957 Mdot
.41672 .43237 Mdot
.58068 .41076 Mdot
.58686 .46894 Mdot
.40085 .62697 Mdot
.49552 .74271 Mdot
.73093 .49063 Mdot
.71685 .27639 Mdot
.47381 .74567 Mdot
.57822 .61518 Mdot
.52215 .65555 Mdot
.69587 .2335 Mdot
.45802 .77451 Mdot
.57146 .86797 Mdot
.70244 .78456 Mdot
.3962 .43627 Mdot
.62571 .64491 Mdot
.44663 .83038 Mdot
.67134 .26359 Mdot
.57961 .76727 Mdot
.65183 .64409 Mdot
.555 .25152 Mdot
.50899 .16931 Mdot
.43122 .73633 Mdot
.46826 .74421 Mdot
.6698 .50525 Mdot
.5114 .73649 Mdot
.53478 .36816 Mdot
.42536 .91893 Mdot
.37608 .53915 Mdot
.35787 .6864 Mdot
.47825 .71043 Mdot
.47938 .82567 Mdot
.40853 .11859 Mdot
.36956 .40749 Mdot
.69132 .43947 Mdot
.65442 .38051 Mdot
.52937 .96783 Mdot
.57867 .21376 Mdot
.54523 .11651 Mdot
.67019 .51714 Mdot
.54764 .43515 Mdot
.37894 .3865 Mdot
.63207 .13687 Mdot
.56522 .78761 Mdot
.44265 .34271 Mdot
.48172 .08664 Mdot
.59694 .72564 Mdot
.71152 .36186 Mdot
.45838 .11993 Mdot
.4348 .83302 Mdot
.60366 .19943 Mdot
.70114 .52626 Mdot
.43803 .08412 Mdot
.56227 .52946 Mdot
.56435 .10186 Mdot
.68442 .29534 Mdot
.36032 .52693 Mdot
.4421 .29671 Mdot
.55571 .64934 Mdot
.39597 .47833 Mdot
.40405 .1839 Mdot
.49372 .02107 Mdot
.46734 .79945 Mdot
.58744 .54067 Mdot
.54744 .95019 Mdot
.4676 .85218 Mdot
.56275 .39054 Mdot
.67148 .4901 Mdot
.48263 .31712 Mdot
.50469 .13769 Mdot
.69156 .42136 Mdot
.57528 .16171 Mdot
.39026 .20278 Mdot
.69789 .5008 Mdot
.69584 .44633 Mdot
.57179 .32157 Mdot
.63128 .24804 Mdot
.73143 .59728 Mdot
.54125 .86603 Mdot
.55113 .77328 Mdot
.6384 .57587 Mdot
.4663 .01656 Mdot
.62681 .71889 Mdot
.57518 .48963 Mdot
.69919 .46303 Mdot
.37822 .41275 Mdot
.48601 .73675 Mdot
.55225 .35641 Mdot
.5686 .36486 Mdot
.41545 .64857 Mdot
.50373 .03433 Mdot
.67542 .1996 Mdot
.482 .11702 Mdot
.51934 .60243 Mdot
.51354 .08062 Mdot
.68802 .39469 Mdot
.73063 .43766 Mdot
.4899 .23691 Mdot
.73117 .57507 Mdot
.53548 .47821 Mdot
.47847 .9699 Mdot
.61151 .11169 Mdot
.39221 .80165 Mdot
.73546 .56378 Mdot
.4561 .86876 Mdot
.59979 .88203 Mdot
.40757 .16831 Mdot
.48939 .27493 Mdot
.50787 .98865 Mdot
.59504 .13648 Mdot
.69899 .70778 Mdot
.69251 .30917 Mdot
.58788 .54834 Mdot
.76801 .42678 Mdot
.59286 .32984 Mdot
.51369 .38064 Mdot
.52098 .41482 Mdot
.51763 .42709 Mdot
.54249 .29181 Mdot
.77418 .47798 Mdot
.62186 .65516 Mdot
.45262 .70285 Mdot
.45081 .1303 Mdot
.5428 .39748 Mdot
.4941 .71009 Mdot
.41383 .41175 Mdot
.60693 .2561 Mdot
.47398 .82491 Mdot
.62571 .72123 Mdot
.42635 .34514 Mdot
.63569 .59285 Mdot
.5197 .76822 Mdot
.73058 .59965 Mdot
.53401 .55887 Mdot
.61535 .34042 Mdot
.70779 .34118 Mdot
.48909 .82008 Mdot
.65175 .7275 Mdot
.63809 .69072 Mdot
.61633 .73599 Mdot
.43365 .68572 Mdot
.48842 .19347 Mdot
.40302 .75694 Mdot
.48259 .74075 Mdot
.67187 .26963 Mdot
.4994 .7382 Mdot
.44149 .56776 Mdot
.7707 .45933 Mdot
.58124 .66084 Mdot
.45704 .22289 Mdot
.57496 .91366 Mdot
.56734 .41982 Mdot
.54892 .82148 Mdot
.59983 .24859 Mdot
.60697 .70153 Mdot
.44534 .99405 Mdot
.38936 .50131 Mdot
.55849 .84605 Mdot
.47976 .13869 Mdot
.38194 .7345 Mdot
.54122 .56012 Mdot
.67044 .3466 Mdot
.51658 .80198 Mdot
.47123 .13865 Mdot
.54369 .11982 Mdot
.71086 .67238 Mdot
.48883 .70087 Mdot
.46718 .2709 Mdot
.68056 .38298 Mdot
.447 .19036 Mdot
.53943 .31893 Mdot
.47815 .87993 Mdot
.44498 .56231 Mdot
.61367 .16403 Mdot
.58692 .84926 Mdot
.59309 .61981 Mdot
.45626 .22387 Mdot
.5908 .78745 Mdot
.43186 .58671 Mdot
.50612 .82362 Mdot
.64262 .47877 Mdot
.50505 .74559 Mdot
.40841 .73219 Mdot
.39649 .76286 Mdot
.50102 .18623 Mdot
.38688 .69839 Mdot
.51927 .83281 Mdot
.55633 .59552 Mdot
.60282 .47016 Mdot
.69209 .42149 Mdot
.51922 .29259 Mdot
.43924 .23183 Mdot
.52528 .92993 Mdot
.41345 .41379 Mdot
.49642 .12606 Mdot
.56055 .13849 Mdot
.50374 .32108 Mdot
.47813 .23202 Mdot
.69701 .48858 Mdot
.65735 .23605 Mdot
.419 .67898 Mdot
.43441 .50181 Mdot
.4227 .30203 Mdot
.39298 .74943 Mdot
.57659 .61873 Mdot
.65579 .61753 Mdot
.60354 .1025 Mdot
.66784 .68813 Mdot
.64024 .21077 Mdot
.67443 .66386 Mdot
.50216 .37828 Mdot
.66748 .69478 Mdot
.57904 .90487 Mdot
.44214 .91684 Mdot
.65492 .23718 Mdot
.6005 .4414 Mdot
.4014 .69613 Mdot
.57731 .76825 Mdot
.38983 .78667 Mdot
.73313 .49443 Mdot
.48084 .78032 Mdot
.54604 .90338 Mdot
.47955 .16522 Mdot
.44756 .34542 Mdot
.5852 .2181 Mdot
.4042 .33892 Mdot
.63812 .33039 Mdot
.5838 .90589 Mdot
.46476 .70557 Mdot
.62852 .3862 Mdot
.57629 .29593 Mdot
.48311 .02113 Mdot
.42811 .45642 Mdot
.73097 .44322 Mdot
.67875 .74485 Mdot
.41295 .06143 Mdot
.54421 .59839 Mdot
.48637 .11428 Mdot
.62272 .48103 Mdot
.57452 .16222 Mdot
.52175 .24515 Mdot
.51308 .37502 Mdot
.51537 .45753 Mdot
.469 .141 Mdot
.68838 .29151 Mdot
.6682 .34436 Mdot
.52121 .65953 Mdot
.54011 .14933 Mdot
.46708 .28726 Mdot
.51813 .43101 Mdot
.39747 .72248 Mdot
.40376 .28514 Mdot
.54752 .78014 Mdot
.56954 .31601 Mdot
.51964 .24444 Mdot
.74295 .696 Mdot
.45222 .18289 Mdot
.48602 .90095 Mdot
.54053 .44191 Mdot
.4368 .05003 Mdot
.42013 .35516 Mdot
.41181 .15458 Mdot
.39348 .68145 Mdot
.41921 .50574 Mdot
.57241 .63003 Mdot
.36029 .52977 Mdot
.69073 .30073 Mdot
.66271 .70983 Mdot
.4075 .81864 Mdot
.59667 .41356 Mdot
.56582 .26786 Mdot
.37678 .4531 Mdot
.54845 .74632 Mdot
.68745 .29368 Mdot
.54347 .86785 Mdot
.70602 .3457 Mdot
.73261 .45715 Mdot
.72825 .60529 Mdot
.51898 .57012 Mdot
.59667 .59717 Mdot
.68309 .29323 Mdot
.63047 .18789 Mdot
.5107 .61649 Mdot
.66512 .56125 Mdot
.42416 .26055 Mdot
.47988 .11351 Mdot
.63184 .62007 Mdot
.54393 .9046 Mdot
.55671 .80838 Mdot
.69255 .59454 Mdot
.62873 .2525 Mdot
.42882 .14482 Mdot
.67676 .67154 Mdot
.45061 .10171 Mdot
.72586 .43354 Mdot
.35875 .29455 Mdot
.69585 .49052 Mdot
.54972 .20266 Mdot
.4458 .37279 Mdot
.70738 .67331 Mdot
.40258 .64711 Mdot
.51082 .42186 Mdot
.73522 .47042 Mdot
.67034 .52325 Mdot
.51267 .37249 Mdot
.55327 .40485 Mdot
.40202 .4384 Mdot
.48367 .21331 Mdot
.49065 .96916 Mdot
.60832 .76333 Mdot
.53534 .95798 Mdot
.7328 .45326 Mdot
.47578 .14211 Mdot
.76205 .62509 Mdot
.5305 .20467 Mdot
.41842 .67059 Mdot
.41452 .35037 Mdot
.50627 .58304 Mdot
.67123 .25709 Mdot
.68366 .28655 Mdot
.43408 .28005 Mdot
.43033 .64464 Mdot
.52188 .27147 Mdot
.44318 .26979 Mdot
.64986 .80836 Mdot
.58067 .60608 Mdot
.53077 .88158 Mdot
.44751 .28252 Mdot
.5637 .39595 Mdot
.42985 .43009 Mdot
.59009 .50817 Mdot
.49139 .1508 Mdot
.52661 .2841 Mdot
.4348 .63908 Mdot
.53973 .95751 Mdot
.56274 .0996 Mdot
.49954 .55835 Mdot
.61414 .60444 Mdot
.50793 .16785 Mdot
.54359 .19588 Mdot
.45429 .18188 Mdot
.56724 .41704 Mdot
.69691 .70585 Mdot
.73674 .31578 Mdot
.53829 .83686 Mdot
.57998 .76843 Mdot
.42795 .40514 Mdot
.422 .9076 Mdot
.68919 .30815 Mdot
.41248 .55205 Mdot
.40066 .73316 Mdot
.73823 .70774 Mdot
.42343 .58809 Mdot
.46929 .30075 Mdot
.40714 .53431 Mdot
.58847 .79266 Mdot
.55441 .28636 Mdot
.75078 .35978 Mdot
.52987 .58559 Mdot
.61779 .57069 Mdot
.61263 .40584 Mdot
.53667 .59762 Mdot
.48616 .70246 Mdot
.54074 .35197 Mdot
.64533 .20969 Mdot
.43035 .57613 Mdot
.60631 .20488 Mdot
.43412 .86622 Mdot
.64248 .4611 Mdot
.37632 .53837 Mdot
.6653 .55076 Mdot
.44031 .17829 Mdot
.653 .16318 Mdot
.55936 .44097 Mdot
.69427 .30496 Mdot
.70873 .68057 Mdot
.5105 .73323 Mdot
.66438 .70426 Mdot
.47689 .16722 Mdot
.43019 .78666 Mdot
.40939 .16355 Mdot
.62154 .66082 Mdot
.48564 .80013 Mdot
.56852 .6455 Mdot
.53129 .20824 Mdot
.40447 .90751 Mdot
.46963 .8751 Mdot
.45929 .62984 Mdot
.55769 .76197 Mdot
.58453 .37048 Mdot
.51903 .57232 Mdot
.54108 .61122 Mdot
.59829 .66337 Mdot
.43154 .82612 Mdot
.52606 .56308 Mdot
.40957 .34403 Mdot
.36825 .52464 Mdot
.57115 .36847 Mdot
.6361 .42436 Mdot
.56005 .63618 Mdot
.55991 .62576 Mdot
.46256 .68649 Mdot
.36373 .74896 Mdot
.45355 .66927 Mdot
.39596 .71055 Mdot
.66 .70375 Mdot
.52068 .89446 Mdot
.57097 .57476 Mdot
.46882 .05256 Mdot
.72041 .38862 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00X?ooool2o`000003oeEEEOmVIVKo0000
00Oooooo00?o0000ooooooooool0^Oooool00:3ooooo0_l0000:ooooo`03o`000?oooooooooo0;Wo
oooo002Vooooo`;o000000Goooooo`000?l0003oooooo`00002kooooo`00Y_ooool2o`000004oooo
ool0003o0000ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o
0000ooooooooool0^Oooool00:cooooo0ol0002iooooo`00[?ooool3o`000;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Hooooo`;o00004_oo
ool00ol0003oooooooooo`2iooooo`00Uoooool3o`0001;ooooo00?o0000ooooooooool0^Oooool0
09Oooooo0_l00007ooooo`?o00002Oooool3o`000;Wooooo002Pooooo`?o00002Oooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`05ooooo`;o0000/_ooool008oooooo0_l0
000Kooooo`03o`000?oooooooooo00Gooooo0_l0002booooo`00Soooool2o`0001_ooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool009[ooooo0_l0000@ooooo`03o`000?oooooooooo0;Wooooo002Jooooo`;o00004?oo
ool3o`000;Wooooo002/ooooo`03o`000?oooooooooo00gooooo0_l0002Zooooo`00[?ooool01?l0
003oooooooooooooool3o`0000Wooooo0_l0002Zooooo`00Uoooool2o`0001?ooooo00Co0000oooo
oooooooooooo0ol0002eooooo`00Uoooool2o`0000gooooo0_l00004ooooo`03o`000?oooooooooo
0;Wooooo002Vooooo`;o00001?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooo
ooooo`04ooooo`;o0000/oooool00:cooooo00?o0000ooooooooool01?ooool2o`000;?ooooo002L
ooooo`;o00003_ooool3o`0000Kooooo0_l00009ooooo`;o0000Y_ooool009_ooooo0ol0000>oooo
o`03o`000?oooooooooo00Kooooo0_l00009ooooo`?o00002oooool2o`0009Sooooo002Kooooo`;o
00003oooool00ol0003oooooooooo`0Booooo`;o00002oooool2o`0009Sooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002Uooooo`;o00001Oooool00ol0003oooooooooo`0Qooooo`;o0000U_oo
ool00:Gooooo1?l00003ooooo`03o`000?oooooooooo00_ooooo0_l0000Dooooo`;o0000U_ooool0
08Wooooo00Cok^k^oc8b<_l0003o<S8b0_l00004ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04
ooooo`04odA4A?l0003o0000oc8b<P?o00000oooool00ol0003oooooooooo`0;ooooo`;o0000[?oo
ool008Wooooo00CoMgMgoiRHV?ooooooV9RH0_l00004ooooo`;o8B4Q1_ooool00omEEEGoZJVYoooo
o`02o`0000Gooooo00?oMgMgo`000?l000001?ooool00ol0003oooooooooo`0;ooooo`;o0000[?oo
ool0087ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEoooo
o`02o`0000Kooooo00?o0000ooooooooool00oooool3o`000;Wooooo0029ooooo`05o`000?oooooo
ooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00;ooooo0ol0
002kooooo`00ROooool01Ol0003ooooooooooooooooo000000gooooo0_l000000oo<c<cooooooooo
o`02ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00oooool3o`000;_ooooo0029ooooo`05oa0@4?oo
ooooooooooooool@41003Oooool2o`000003ogMgMooooooooooo00;ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`2iooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo0ol0000Looooo`;o
00002_ooool2o`0008oooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000?o
oooo1ol00004ooooo`?o00004Oooool2o`0000Wooooo0_l0000:ooooo`;o0000Soooool00:7ooooo
1ol00004ooooo`03o`000?oooooooooo017ooooo0_l0002Vooooo`00U?ooool2o`0000kooooo0_l0
0006ooooo`03o`000?oooooooooo0;Wooooo002Cooooo`?o00005_ooool00ol0003oooooooooo`0:
ooooo`;o0000[Oooool009?ooooo0_l0000Dooooo`;o000000Coooooo`000?l0003o00002_ooool2
o`000:gooooo002>ooooo`;o00006Oooool2o`000003ooooool0003ooooo0;[ooooo002>ooooo`;o
00007?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`0Eooooo`;o0000
X_ooool008kooooo0_l0000Eooooo`;o00001Oooool00ol0003oooooooooo`0Eooooo`;o00002ooo
ool2o`0000_ooooo0_l00028ooooo`00SOooool3o`00013ooooo0_l00002ooooo`?o00001Oooool0
1?l0003oooooo`000?l0000Qooooo`;o00002oooool2o`0008Sooooo002=ooooo`;o00004Oooool2
o`0000;ooooo0_l00006ooooo`03o`000?oooooo000000;o0000]oooool00:cooooo00?o0000oooo
ooooool00_l0002gooooo`00[?ooool3o`000;Wooooo002Hooooo`;o00004_ooool00ol0003ooooo
ooooo`2iooooo`00V?ooool2o`0000;ooooo0_l0000>ooooo`03o`000?oooooooooo0;Wooooo002<
ooooo`;o00003_ooool2o`0000kooooo0_l0002jooooo`00S?ooool2o`0001kooooo0_l0000Yoooo
o`;o0000Soooool009[ooooo0_l0000@ooooo`03o`000?oooooooooo02Sooooo0_l0002?ooooo`00
V_ooool2o`0000cooooo0_l00002ooooo`03o`000?oooooooooo0;Wooooo002Xooooo`;o00000_oo
ool00ol0003oooooooooo`04ooooo`;o00001Oooool2o`000:cooooo002/ooooo`?o00001?ooool2
o`0000Gooooo0_l0000Booooo`;o00005Oooool2o`00087ooooo0027ooooo`;o00008oooool00ol0
003oooooooooo`0=ooooo`;o00004?ooool2o`0001Gooooo0_l00021ooooo`00Qoooool2o`0002?o
oooo00?o0000ooooooooool01oooool2o`0000Cooooo0_l0000Aooooo`;o0000Uoooool00:cooooo
00?o0000ooooooooool01oooool2o`0001Oooooo0_l0000;ooooo`;o0000R_ooool00:Kooooo0_l0
0004ooooo`03o`000?oooooooooo00Oooooo0_l0000Rooooo`Co0000R_ooool00:Kooooo0_l00004
ooooo`03o`000?oooooooooo01Oooooo0_l0000Booooo`Co0000R_ooool00:cooooo00?o0000oooo
ooooool05oooool4o`0001?ooooo0_l00029ooooo`00[?ooool00ol0003oooooooooo`0Iooooo`;o
00004oooool2o`0008Wooooo002Mooooo`;o00003Oooool3o`000;Wooooo002Mooooo`;o00003Ooo
ool00ol0003oooooooooo`0Tooooo`;o0000Toooool008oooooo0_l00007ooooo`;o00004_ooool0
0ol0003oooooooooo`0Tooooo`;o0000Toooool008oooooo0_l00007ooooo`;o00002_ooool2o`00
00Kooooo00?o0000ooooooooool0?Oooool2o`0007[ooooo002Tooooo`;o00000_ooool2o`0000;o
oooo00?o0000ooooooooool0<?ooool3o`0000[ooooo0_l0001jooooo`00Z?ooool2o`0000;ooooo
00?o0000ooooooooool0<?ooool3o`0008Kooooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;Wo
oooo002Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`03ooooo`?o0000/oooool008Wooooo1_l00002ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo0ol0000Hooooo`;o00002?ooool2o`0008oooooo002Aooooo`05o`000?ooooooooooooooool0
00003_ooool2o`000003oc8b<_oooooooooo00?ooooo0ol0000?ooooo`;o00003Oooool2o`0000Oo
oooo0ol0002?ooooo`00TOooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0
003o0000olc<c005ooooo`03o`000?oooooooooo00oooooo0_l0000?ooooo`;o00001Oooool2o`00
093ooooo002Aooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo023ooooo0_l0000Cooooo`;o0000P_ooool0097ooooo00GoMgMgoiRHV?l0
003o0000ogMgM`02ooooo`;o00002?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
03Cooooo0ol00022ooooo`00TOooool01Oo^k^ko<S8bo`000?l0003ok^k^00;ooooo0_l00008oooo
o`Co00001_ooool00ol0003oooooooooo`0dooooo`?o0000P_ooool00:cooooo00?o0000oooooooo
ool04_ooool2o`00027ooooo0_l00022ooooo`00VOooool2o`0000Kooooo0_l00009ooooo`03o`00
0?oooooooooo01;ooooo0_l0000Qooooo`;o0000P_ooool009Wooooo0_l00006ooooo`;o00002Ooo
ool00ol0003oooooooooo`04ooooo`;o0000;oooool2o`0008;ooooo002Xooooo`;o00000_ooool3
o`0000Cooooo0_l0000nooooo`;o0000Loooool009Kooooo0_l0000@ooooo`;o00000_ooool00ol0
003oooooooooo`0]ooooo`;o00005Oooool2o`0007?ooooo002Fooooo`;o00000_ooool2o`00013o
oooo00?o0000ooooooooool0;Oooool2o`0008[ooooo002<ooooo`;o00003?ooool2o`00013ooooo
00?o0000ooooooooool01Oooool2o`0000Sooooo0_l0002Xooooo`00S?ooool2o`0001?ooooo0_l0
0009ooooo`03o`000?oooooooooo00Gooooo0_l00008ooooo`;o0000:?ooool2o`0007kooooo002Q
ooooo`;o00002Oooool00ol0003oooooooooo`0;ooooo`;o0000;?ooool4o`0007cooooo001moooo
o`;o0000;Oooool00ol0003oooooooooo`03ooooo`;o00001_ooool2o`0002cooooo1?l0001loooo
o`00OOooool2o`0001Wooooo0_l0000Booooo`03o`000?oooooooooo00?ooooo0_l0000Aooooo`;o
00008Oooool3o`0007gooooo002Hooooo`;o00001oooool2o`0000Wooooo0ol0000Fooooo`;o0000
8oooool3o`0007_ooooo002Booooo`;o00003Oooool2o`0000Wooooo00?o0000ooooooooool0>ooo
ool3o`0007_ooooo002Booooo`;o00006?ooool00ol0003oooooooooo`0mooooo`;o0000N_ooool0
0:cooooo00?o0000ooooooooool0>oooool4o`0007[ooooo002/ooooo`03o`000?oooooooooo03_o
oooo0ol0001kooooo`00[?ooool00ol0003oooooooooo`0Dooooo`;o0000=Oooool2o`0006cooooo
002Vooooo`;o00001?ooool00ol0003oooooooooo`0:ooooo`;o00002?ooool2o`0003Gooooo0_l0
001/ooooo`00Y_ooool2o`0000Cooooo0ol0000:ooooo`;o00002?ooool2o`000:?ooooo002/oooo
o`?o00005?ooool2o`000:?ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo01_ooooo0_l0000=ooooo`;o0000SOooool00:cooooo00?o0000ooooooooool05?oo
ool2o`0000Gooooo0_l0000=ooooo`;o0000SOooool008;ooooo0_l0000Xooooo`03o`000?oooooo
oooo01Cooooo0_l0002Sooooo`00P_ooool2o`0000Sooooo0_l0000Nooooo`03o`000?oooooooooo
02?ooooo0_l0002Dooooo`00S?ooool2o`0000_ooooo0_l0000Aooooo`03o`000?oooooooooo02?o
oooo0_l0000Looooo`;o0000M_ooool008kooooo0_l00003ooooo`;o00001?ooool3o`00013ooooo
00?o0000ooooooooool0=?ooool3o`0000[ooooo0_l0001fooooo`00S_ooool2o`0000?ooooo0_l0
0005ooooo`;o00004?ooool00ol0003oooooooooo`0dooooo`?o00002_ooool2o`0007Kooooo002?
ooooo`;o00006oooool3o`0000[ooooo0_l0002]ooooo`00Soooool4o`0001Wooooo00?o0000oooo
ooooool02_ooool2o`000:gooooo002Aooooo`;o00006Oooool00ol0003oooooooooo`0:ooooo`;o
00000_ooool2o`000:Wooooo002/ooooo`03o`000?oooooooooo00kooooo0_l0000booooo`;o0000
2oooool2o`0006Sooooo002/ooooo`03o`000?oooooooooo00Oooooo0_l0000:ooooo`;o0000;Ooo
ool2o`0000_ooooo0_l0001Xooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo0ol00007ooooo`?o0000
2Oooool2o`000:Cooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo
00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00008ooooo`;o
00002_ooool2o`0000;ooooo0_l0002Oooooo`00POooool6o`0000;ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`;o000000?ok^k^ooooooooool01oooool00ol0003oooooooooo`03ooooo`04
o`000?ooooooooooooooo`;o00004Oooool2o`0000;ooooo0_l0002Oooooo`00ROooool01Ol0003o
oooooooooooooooo000000cooooo0_l000000olQ8B7ok^k^ooooo`02o`0000Cooooo00?oMgMgoc8b
<_ooool01?ooool3o`000003ooooool0003o0000017ooooo0_l0002Sooooo`00ROooool01Ol0003o
oooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00_l000001_oooooo0000ob4Q8Ol0003o
<S8bolc<c0Gooooo0_l00002ooooo`;o0000@_ooool2o`0007;ooooo0029ooooo`05oa0@4?oooooo
ooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo0_l0
0002ooooo`;o0000;Oooool2o`0000Kooooo0_l0000;ooooo`;o0000L_ooool008Wooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooo
ooooo`07ooooo`04o`000?ooooooooooooooo`;o00009?ooool2o`0000Kooooo0ol00006ooooo`;o
0000Ooooool008Cooooo0_l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So
410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo02Oooooo0_l00006oooo
o`;o00005?ooool2o`0007;ooooo0024ooooo`;o00009_ooool00ol0003oooooooooo`0Aooooo`;o
0000<_ooool2o`0007;ooooo002/ooooo`03o`000?oooooooooo017ooooo0_l0000Xooooo`;o0000
O?ooool00:cooooo00?o0000ooooooooool02oooool2o`0000Gooooo0_l0000=ooooo`;o00006?oo
ool2o`0007cooooo002/ooooo`?o00002oooool2o`0000Gooooo0_l0000=ooooo`;o00003_ooool2
o`0008Kooooo002/ooooo`03o`000?oooooooooo037ooooo0_l00026ooooo`00POooool2o`00017o
oooo0_l0000Fooooo`03o`000?oooooooooo00kooooo0_l0000Booooo`;o0000UOooool0087ooooo
0_l0000Aooooo`;o00005_ooool00ol0003oooooooooo`0>ooooo`;o00004_ooool2o`0009Gooooo
0023ooooo`;o00002_ooool2o`0001_ooooo00?o0000ooooooooool05oooool2o`0000?ooooo0_l0
002Kooooo`00Poooool2o`0000[ooooo0_l0000Kooooo`03o`000?oooooooooo00?ooooo0_l0000B
ooooo`;o00000oooool2o`0009_ooooo002?ooooo`;o00006oooool00ol0003oooooooooo`03oooo
o`;o00003_ooool2o`000:Cooooo002/ooooo`03o`000?oooooooooo00;o00004Oooool2o`0001co
oooo0_l00009ooooo`;o0000Noooool00:cooooo1Ol0000Aooooo`;o00005?ooool2o`0000Kooooo
0_l00009ooooo`;o0000Noooool00:cooooo00?o0000ooooooooool00_ooool2o`0002Gooooo0_l0
0008ooooo`;o00008?ooool2o`0006;ooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`02
ooooo`?o0000;_ooool2o`00023ooooo0_l0001Rooooo`00T?ooool2o`0000;ooooo0_l0000Foooo
o`03o`000?oooooooooo00?ooooo0_l00012ooooo`;o0000L?ooool008Wooooo0_l00005ooooo`;o
00006_ooool00ol0003oooooooooo`0<ooooo`;o0000>Oooool4o`0006kooooo0029ooooo`Co0000
7oooool00ol0003oooooooooo`0<ooooo`;o0000;_ooool2o`0000_ooooo0_l0001^ooooo`00Rooo
ool2o`0001oooooo00?o0000ooooooooool02_ooool2o`0000Cooooo0_l0000<ooooo`;o00007?oo
ool2o`0000_ooooo0_l0001^ooooo`00[?ooool00ol0003oooooooooo`0:ooooo`;o00001?ooool2
o`0000cooooo0_l00004ooooo`;o00005oooool2o`0000[ooooo0_l0001^ooooo`00ROooool2o`00
027ooooo00?o0000ooooooooool09?ooool2o`0001Oooooo0_l0001jooooo`00ROooool2o`00027o
oooo0ol0002iooooo`00Poooool2o`0002Oooooo00?o0000ooooooooool0BOooool2o`0006kooooo
0023ooooo`;o00003oooool2o`0001Kooooo00?o0000ooooooooool00_ooool2o`0002Sooooo0_l0
000Kooooo`;o0000K_ooool000Wooooo1?l000000ol@413oooooooooo`0Fooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0000Cooooo00?oA4A4o`000?l000000_l0000Fooooo`03o`000?oooooooooo00;ooooo0_l0000D
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1_l00003ooooo`05odA4A?l0
003o0000oc8b<_oMgMd03oooool01?o^k^ko<S8bo`000?lb<S82o`0000Cooooo0_lQ8B45ooooo`?o
000000?o<S8bomgMgOooool03_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`Co000000?o410@
ooooooooool04_ooool000_ooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool03_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oo
oooo00?oMgMgoc8b<_ooool05Oooool00ol0003oooooooooo`0;ooooo`;o00002oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`04oiRHV?lQ8B7ok^k^ooooo`;o00001_ooool2
o`0000Sooooo0_l00005ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Gooooo0_l0
00000oooooooMgMgoc8b<P0?ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo
00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo
0006o`0000Gooooo00?o0000ooooooooool04?ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool01Oooool6o`0000;ooooo
00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool02oooool2o`0000_ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^00Sooooo0_l00008ooooo`;o00001Oooool01Ol@413ooooooooooooo
oooo410@013ooooo00?o0000ooooooooool03Oooool01Ol@413ooooooooooooooooo410@00gooooo
00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Cooooo
000;ooooo`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q
8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000oo
oooo00?oMgMgoc8b<_ooool03_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q
8Oo^k^h01oooool00omgMgOo<S8booooo`0Eooooo`03o`000?oooooooooo01Gooooo0_l000001_oo
oooo0000o`000?l0003oooooo`0000;ooooo0_l00009ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o
MgMgoc8b<_ooool03_ooool01?l0003oooooooooooooool3o`0000gooooo00?oMgMgoc8b<_ooool0
3_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo
<S8booooo`0Iooooo`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo
00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c00?ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c00Fooooo`03o`000?oooooooooo01Gooooo0_l000001_oooooo
0000o`000?l0003oooooo`0000;ooooo0_l0000:ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c00?ooooo`04o`000?ooooooooooooooo`?o00002_ooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Jooooo`03o`000?oooooooooo01Cooooo000;oooo
o`03o`000?oooooooooo01Sooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOo
oooo00?ooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o
0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Hooooo`?o00006?ooool01Ol@413ooooooooooooooooo410@00oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Aooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003_ooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05?ooool0
00_ooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@
oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0<ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`?o
000000?oV9RHoa0@4?ooool00oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00So
oooo0_l0000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01?l0003o^[ZjoooooonHV9P2
o`0000?ooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo0ol0
000Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Co
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Dooooo`002Oooool00omEEEGoIVIV
o`00000Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000@ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`05oiRHV?l0003o0000ob4Q8Oo<c<`01?ooool4o`0001Oooooo00?o0000ooooooooool02?oo
ool2o`0000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`;o000000GooooooiRHV?l@413o
0000ob4Q8@02o`0000?ooooo1?l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00
013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0001Wooooo00?oEEEE
ofIVI_l000005_ooool00:cooooo00?o0000ooooooooool09Oooool2o`0009;ooooo002/ooooo`03
o`000?oooooooooo03kooooo0_l0001iooooo`00[?ooool00ol0003oooooooooo`0Eooooo`;o0000
7_ooool2o`0000Kooooo0ol00009ooooo`;o0000Hoooool2o`0000;ooooo0_l00005ooooo`00[?oo
ool00ol0003oooooooooo`0Eooooo`;o00007_ooool2o`0000Kooooo0_l0000:ooooo`?o0000H_oo
ool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Gooooo002/ooooo`03o`000?oooooooooo04[ooooo
0_l0001Sooooo`04omgMgOl0003o410@olc<c0Kooooo0007oooooooo0000C?l0000<ooooo`04onk^
k_lQ8B7o410@onk^kPKooooo0007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooooooo`;o00000_ooool00ol0003o
ooooooooo`06ooooo`04o`000?oooooo0000o`0000Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`00
00Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00[ooooo00Co8B4QogMgMomgMgOo<S8b1_ooool000Oooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02oooool2o`00
00?ooooo0_l0000Dooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool02oooool2o`00
01Wooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
00Wooooo0_l00002ooooo`;o00001Oooool008Wooooo0_l00006ooooo`;o00006Oooool00ol0003o
ooooooooo`0Aooooo`;o00001oooool2o`00017ooooo0_l00006ooooo`;o0000P_ooool008Wooooo
0_l0000Qooooo`03o`000?oooooooooo017ooooo0_l00007ooooo`;o00004Oooool2o`0000Kooooo
0_l00022ooooo`00[?ooool00ol0003oooooooooo`0eooooo`;o0000P_ooool00:cooooo00?o0000
ooooooooool0=Oooool2o`0000Oooooo0_l0001iooooo`00[?ooool00ol0003oooooooooo`0eoooo
o`;o00001oooool2o`0007Wooooo0020ooooo`;o0000:_ooool3o`0003Gooooo0_l00022ooooo`00
OOooool2o`000003ooooool0003o000002[ooooo00?o0000ooooooooool0=Oooool2o`0000Sooooo
0_l0001hooooo`00OOooool2o`0002gooooo00?o0000ooooooooool04Oooool2o`0002cooooo0_l0
001hooooo`00OOooool2o`0000kooooo0_l0000Mooooo`03o`000?oooooooooo017ooooo0_l00002
ooooo`;o0000X_ooool008gooooo0_l0000Mooooo`03o`000?oooooooooo01Gooooo0_l0002Roooo
o`00Poooool2o`0002Oooooo00?o0000ooooooooool06Oooool2o`0009kooooo0023ooooo`;o0000
9oooool00ol0003oooooooooo`0Iooooo`;o0000W_ooool00:cooooo00?o0000ooooooooool0B_oo
ool2o`0006gooooo002/ooooo`03o`000?oooooooooo01[ooooo0_l0000^ooooo`;o0000KOooool0
083ooooo0_l0000=ooooo`;o00006oooool3o`0001[ooooo0_l0000Gooooo`;o0000Q?ooool0083o
oooo0_l0000=ooooo`;o00006oooool01?l0003oooooooooooooool2o`00033ooooo0_l00024oooo
o`00Zoooool2o`0000?ooooo0_l00005ooooo`;o00001_ooool2o`000:Oooooo002[ooooo`;o0000
2_ooool4o`0000Cooooo0_l0000Booooo`;o00003Oooool2o`0008Cooooo002Iooooo`;o00004Ooo
ool00ol0003oooooooooo`05ooooo`;o00000oooool2o`0001?ooooo0_l00003ooooo`;o00003Ooo
ool2o`0001Gooooo0_l0001]ooooo`00V?ooool3o`00017ooooo00?o0000ooooooooool01Oooool2
o`0001Sooooo0_l0000Yooooo`;o0000KOooool009Sooooo0_l0000Booooo`03o`000?oooooooooo
00?ooooo0_l0000Nooooo`;o0000U?ooool008oooooo0_l0000Kooooo`03o`000?oooooooooo00?o
oooo0_l0000;ooooo`;o00004Oooool2o`0009Cooooo002?ooooo`;o00001?ooool2o`0001Gooooo
0ol00003ooooo`;o00002oooool2o`0000;ooooo0_l0000Dooooo`?o00007?ooool2o`0006kooooo
002Eooooo`;o00005Oooool00ol0003oooooooooo`0Dooooo`;o00005?ooool3o`0001cooooo0_l0
001^ooooo`00[?ooool01?l0003oooooo`000?l0002hooooo`00[?ooool01?l0003oooooo`000?l0
0005ooooo`;o0000/Oooool009;ooooo0_l000000ooooooo0000o`00000Eooooo`03o`000?oooooo
oooo00Kooooo0_l0002aooooo`00T_ooool2o`000003ooooool0003o000001Gooooo00?o0000oooo
ooooool0^Oooool00:cooooo00?o0000ooooooooool0:Oooool2o`00017ooooo0_l0001kooooo`00
[?ooool00ol0003oooooooooo`09ooooo`Co00000_ooool2o`0000_ooooo0_l0000;ooooo`;o0000
4Oooool2o`0000_ooooo0_l0001^ooooo`00[?ooool3o`0000Wooooo1?l00002ooooo`;o00002ooo
ool2o`0002_ooooo0_l0001^ooooo`00[?ooool00ol0003oooooooooo`03ooooo`;o00007Oooool2
o`0002Gooooo0_l0001^ooooo`00[?ooool00ol0003oooooooooo`03ooooo`;o00004_ooool2o`00
00Wooooo0_l0000Tooooo`;o0000Koooool00:cooooo00?o0000ooooooooool05oooool2o`0002oo
oooo0_l0001_ooooo`00[?ooool00ol0003oooooooooo`0:ooooo`;o0000[Oooool00:cooooo00?o
0000ooooooooool00_l00008ooooo`;o00002_ooool2o`000:7ooooo0029ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1Oooool00ol0003oooooooooo`02o`0001Cooooo0_l0000Hooooo`;o0000Qoooool008Wooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oo
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Fooooo`;o00000oooool2o`0000_o
oooo0_l00006ooooo`;o0000Qoooool008Wooooo00Go410@oooooooooooooooooa0@400<ooooo`04
oiRHV?lQ8B7ok^k^ooooo`;o00001_ooool00ol0003oooooooooo`03ooooo`?o00006oooool2o`00
00_ooooo0_l0000Yooooo`;o0000I?ooool008Wooooo00?o0000ooooool000000_l0000=ooooo`03
oiRHV?lQ8B7ok^k^00;o00001Oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo013o
oooo0_l00011ooooo`;o0000I?ooool008Wooooo00?o0000ooooool000000_l0000>ooooo`04ogMg
MomVIVKo0000o`0000;ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo
013ooooo0_l00002ooooo`;o0000Xoooool008Wooooo00Go410@oooooooooooooooooa0@400?oooo
o`?o00000_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Cooooo0_l0002Soooo
o`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04?ooool2o`000:Oooooo0029oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool2o`000006oooooonHV9So410@o`000?lQ8B7oc<c<
1?ooool4o`0000Kooooo00?o0000ooooooooool04?ooool2o`000:Oooooo002Fooooo`;o00005?oo
ool00ol0003oooooooooo`2iooooo`00UOooool2o`0001Gooooo00?o0000ooooooooool04oooool2
o`00017ooooo0_l00007ooooo`;o0000R?ooool008_ooooo0_l00003ooooo`;o00000oooool2o`00
01Gooooo00?o0000ooooooooool03oooool2o`0000;ooooo0_l0000Aooooo`;o00001oooool2o`00
08Sooooo002;ooooo`;o00000oooool2o`0001[ooooo0ol0000?ooooo`;o0000Z?ooool00:cooooo
00?o0000ooooooooool01?ooool2o`0001oooooo0_l0002Booooo`00[?ooool00ol0003ooooooooo
o`04ooooo`;o00007oooool2o`0009;ooooo002/ooooo`03o`000?oooooooooo00Cooooo0_l0000A
ooooo`;o00003?ooool2o`0009;ooooo002/ooooo`03o`000?oooooooooo00Cooooo0_l0000Aoooo
o`;o00001?ooool2o`0000Kooooo0_l0000?ooooo`;o0000POooool00:cooooo00?o0000oooooooo
ool07Oooool2o`0001Oooooo0_l00021ooooo`00TOooool2o`0000Wooooo0_l0000>ooooo`03o`00
0?oooooooooo0;Wooooo002Aooooo`;o00002Oooool2o`0000kooooo00?o0000ooooooooool07?oo
ool2o`0001Wooooo0_l00008ooooo`?o0000MOooool00:cooooo0ol0000Looooo`;o00006Oooool2
o`0000Sooooo0ol0001eooooo`00TOooool2o`0001Wooooo00?o0000ooooooooool03?ooool2o`00
0:_ooooo0028ooooo`;o00001oooool2o`0001Wooooo00?o0000ooooooooool03?ooool2o`0001co
oooo0_l0000Eooooo`;o0000M_ooool008Sooooo0_l0000<ooooo`;o00005?ooool00ol0003ooooo
ooooo`0Zooooo`;o00005Oooool2o`0007Kooooo001mooooo`;o00005oooool2o`0000Oooooo0_l0
000;ooooo`03o`000?oooooooooo03Cooooo0_l00023ooooo`00OOooool2o`0001Oooooo0_l00007
ooooo`;o00002oooool00ol0003oooooooooo`0Zooooo`;o00002?ooool2o`0008?ooooo002Foooo
o`;o00005?ooool00ol0003oooooooooo`0Zooooo`;o00002?ooool2o`0008?ooooo0026ooooo`;o
000000?oooooo`000?l000000_l0000Oooooo`03o`000?oooooooooo03Cooooo0_l0000Gooooo`;o
0000J_ooool008Kooooo0_l000000ooooooo0000o`000002o`0001_ooooo0_l00002ooooo`?o0000
COooool2o`0006[ooooo002Looooo`;o00002Oooool3o`0000;ooooo00?o0000ooooooooool08?oo
ool2o`0000oooooo1?l00024ooooo`00W?ooool2o`0000;ooooo0_l00005ooooo`;o00000oooool0
0ol0003oooooooooo`0Pooooo`;o00003oooool4o`0000Wooooo0_l0001iooooo`00X?ooool2o`00
00;ooooo0_l00004ooooo`?o0000=?ooool2o`0000[ooooo0_l0000;ooooo`;o0000K?ooool008Wo
oooo0_l0000Iooooo`;o00001?ooool3o`00027ooooo0_l0000Aooooo`;o00002_ooool2o`0000_o
oooo0_l0001/ooooo`00ROooool2o`00027ooooo00?o0000ooooooooool07oooool2o`0009Sooooo
002/ooooo`03o`000?oooooooooo02Kooooo0_l0002Aooooo`00R_ooool2o`00023ooooo00?o0000
ooooooooool00_ooool2o`0002;ooooo0_l0002Aooooo`00R_ooool2o`00023ooooo0ol00002oooo
o`;o00006Oooool2o`0000Oooooo0_l0002Aooooo`00[?ooool00ol0003oooooooooo`0Mooooo`;o
00004?ooool2o`0008Sooooo002:ooooo`;o00008?ooool2o`00033ooooo0_l00028ooooo`00QOoo
ool2o`0000?ooooo1Ol0000Mooooo`;o000000?oooooo`000?l00000]oooool008Gooooo0_l00004
ooooo`Co00001_ooool2o`00013ooooo0_l00003ooooo`03o`000?oooooooooo00;o00008Oooool2
o`0009Cooooo002Eooooo`;o00003oooool3o`0000;ooooo0_l00002ooooo`;o00008Oooool2o`00
09Cooooo002Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00CoA4A4o`00
0?l0003o<S8b0_l00002ooooo`?o00002_ooool2o`000:oooooo002Aooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00_ooool2o`000003oooooolQ8B7o8B4Q00Cooooo1?l000000omgMgOo<S8booooo`02
ooooo`Go00002?ooool2o`0000?ooooo0_l0000Nooooo`;o00002Oooool2o`0000cooooo0_l0001a
ooooo`00Ooooool2o`0000Oooooo0_l00007ooooo`05oa0@4?ooooooooooooooool@41000_ooool2
o`0000Oooooo1?l000000ooooooo0000ooooo`04ooooo`?o00003Oooool2o`0001kooooo0_l00009
ooooo`;o00003?ooool2o`00077ooooo001oooooo`;o00001oooool2o`0000Oooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002iooooo`00TOooool01Ol0
003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oo
oooooooo0;Wooooo002<ooooo`;o00000oooool01Ol@413ooooooooooooooooo410@00cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2iooooo`00S?ooool2o`0000?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04?oo
ool2o`000:Oooooo0029ooooo`;o00001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0
0006ooooo`03o`000?oooooooooo013ooooo0_l0000>ooooo`;o0000Uoooool008Wooooo0_l0000Q
ooooo`03o`000?oooooooooo01Oooooo0_l00007ooooo`;o0000Uoooool00:cooooo00?o0000oooo
ooooool00oooool2o`00017ooooo0ol0002Pooooo`00[?ooool00ol0003oooooooooo`03ooooo`;o
00002?ooool2o`0000Oooooo0ol0002Pooooo`00W_ooool2o`0000cooooo0ol0000=ooooo`?o0000
ZOooool009kooooo0_l0000<ooooo`?o00003?ooool4o`000:Wooooo002Uooooo`;o00001Oooool0
0ol0003oooooooooo`0<ooooo`;o0000Zoooool00:Gooooo0_l00005ooooo`04o`000?oooooooooo
ooooo`;o0000??ooool2o`0007Sooooo0027ooooo`;o00003?ooool2o`0001Gooooo00Co0000oooo
oooooooooooo0_l0000?ooooo`;o00001oooool2o`0002;ooooo0_l0001hooooo`00Qoooool2o`00
00cooooo0_l0000Eooooo`03o`000?oooooooooo01;ooooo0_l00007ooooo`;o0000W?ooool00:co
oooo00?o0000ooooooooool06_ooool2o`0009gooooo002/ooooo`03o`000?oooooooooo01[ooooo
0_l0002Mooooo`00XOooool2o`0000Cooooo0_l00003ooooo`?o0000^Oooool008Sooooo0_l0000G
ooooo`;o00001?ooool2o`0000?ooooo00?o0000ooooooooool00_ooool2o`000;Gooooo0028oooo
o`;o00008_ooool00ol0003oooooooooo`02ooooo`;o0000]Oooool00:cooooo00?o0000oooooooo
ool03oooool2o`0001gooooo0_l00029ooooo`00[?ooool00ol0003oooooooooo`0?ooooo`;o0000
7Oooool2o`0008Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002=ooooo`;o00004?ooool2
o`0000_ooooo00?o0000ooooooooool0^Oooool008gooooo0_l0000@ooooo`;o00001oooool2o`00
00;ooooo00?o0000ooooooooool03Oooool2o`000:[ooooo002Sooooo`;o00000oooool2o`0000;o
oooo1?l0000<ooooo`;o0000Z_ooool009Gooooo0_l0000<ooooo`Co00001Oooool01?l0003ooooo
o`000?l0002hooooo`00T_ooool2o`000003ooooool0003o000000?ooooo0_l00009ooooo`;o0000
1Oooool00ol0003oooooooooo`2iooooo`00T_ooool2o`0000;ooooo0_l00002ooooo`;o00004?oo
ool00ol0003oooooooooo`03ooooo`;o0000]?ooool009Kooooo0_l0000Dooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o0000[_ooool00:cooooo00Co0000oooooooooooooooo0_l00006
ooooo`;o0000[_ooool00:cooooo00Co0000oooooooooooooooo0_l0002fooooo`00[?ooool00ol0
003oooooooooo`0@ooooo`;o0000Yoooool00:cooooo00?o0000ooooooooool04?ooool2o`0000Oo
oooo0_l0002Nooooo`00XOooool2o`0000Wooooo0ol0000Iooooo`;o0000W_ooool00:7ooooo0_l0
0009ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`04onk^
k_lb<S;o0000oc8b<P;o00001?ooool2ob4Q8@03ooooool0003o000000?ooooo00?o0000onk^k_oo
ool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool02_ooool3o`00
00Oooooo0_l0002Sooooo`00ROooool01?mgMgOoV9RHoooooonHV9P2o`0000Cooooo0_lQ8B400ooo
oooo0000o`000003ooooo`04oeEEEOnYZJWo0000o`0000Kooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`0:ooooo`?o00001oooool2o`000:?ooooo0029ooooo`05oa0@4?oooooooooo
ooooool@41003Oooool01?nYZJWoEEEEo`000?l00007ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0^Oooool008Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooo
oooooooo00?ooooo0_l000000oooooooMgMgoc8b<P05ooooo`?o0000^Oooool008Wooooo00Go0000
ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo1?l000000oo<c<cooooooooo
o`03ooooo`03o`000?oooooooooo0;Wooooo0029ooooo`05oa0@4?ooooooooooooooool@41003_oo
ool00onYZJWoMgMgooooo`03ooooo`04o`000?oooooo0000o`0000Kooooo00?o0000ooooooooool0
1oooool2o`0001Gooooo0_l0002Iooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool2o`0001Gooooo0_l0002Iooooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool00ol0003oooooooooo`03ooooo`;o0000]?ooool00:cooooo00?o0000
ooooooooool00oooool2o`000;Cooooo002Wooooo`;o00000oooool3o`0000gooooo0_l0002Zoooo
o`00Yoooool2o`0000?ooooo00?o0000ooooooooool03?ooool3o`000:[ooooo002Gooooo`;o0000
4oooool00ol0003oooooooooo`0;ooooo`?o00002Oooool3o`0009oooooo002<ooooo`;o00001?oo
ool2o`0000?ooooo0_l0000Cooooo`03o`000?oooooooooo00_ooooo0_l0000:ooooo`?o0000Wooo
ool008cooooo0_l00004ooooo`;o00006?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`0Eooooo`;o0000X_ooool009?ooooo0_l00003ooooo`;o00004_ooool00ol0003o
ooooooooo`0Eooooo`;o0000X_ooool009?ooooo0_l00003ooooo`;o00004_ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo00Gooooo0_l0002booooo`00UOooool2o`0001Gooooo00?o0000oooooooo
ool01Oooool2o`000;;ooooo002Eooooo`;o00005Oooool00ol0003oooooooooo`2iooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`0000cooooo
0_l0002[ooooo`00[?ooool00ol0003oooooooooo`0<ooooo`;o0000Zoooool00:cooooo00?o0000
ooooooooool02?ooool4o`000:gooooo002/ooooo`03o`000?oooooooooo00Sooooo1?l0002]oooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`06ooooo`;o0000
/Oooool00:Cooooo0_l00002ooooo`;o00000_ooool00ol0003oooooooooo`06ooooo`;o0000/Ooo
ool00:Cooooo0_l00002ooooo`;o00000_ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`00
0;Wooooo002Fooooo`;o00005?ooool00ol0003oooooooooo`2iooooo`00U_ooool2o`0001Cooooo
00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00Co0000
ooooool0003o0000^?ooool00:cooooo00Co0000ooooool0003o0000^?ooool009[ooooo0_l00006
ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`2iooooo`00V_ooool2o`00
00Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2iooooo`00Y?ooool00ol0003o
ooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo00?o
0000ooooooooool0`Oooool00:Cooooo00?o0000ooooooooool0`Oooool00:Cooooo00?o0000oooo
ooooool0`Oooool00:;ooooo00?oEEEEofIVI_l00000`oooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00:[ooooo00Co410@o`000?l0003o0000^_ooool00:_o
oooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00Ko
0000ogMgMol0003o0000oeEEEOo^k^jgooooo`00Zoooool01_l0003oEEEEonk^k_ooooooMgMgoeEE
EKOooooo002[ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0]Oooool00:_ooooo
00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`2eooooo`00Zoooool01_l0003oEEEEonk^
k_ooooooMgMgofIVI[Oooooo002Zooooo`03oa0@4?l0003oMgMg00;o000000?oIVIVonk^k_ooool0
]_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.125 .4875 -15 -9 ]
[.125 .4875 15 0 ]
[.25 .4875 -12 -9 ]
[.25 .4875 12 0 ]
[.375 .4875 -15 -9 ]
[.375 .4875 15 0 ]
[.625 .4875 -12 -9 ]
[.625 .4875 12 0 ]
[.75 .4875 -9 -9 ]
[.75 .4875 9 0 ]
[.875 .4875 -12 -9 ]
[.875 .4875 12 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[1.025 .5 0 -6 ]
[1.025 .5 10 6 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -30 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -24 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -30 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -24 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -24 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-1)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-0.75)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-0.5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-0.25)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(0.25)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(0.5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(0.75)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(1)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-0.75)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-0.5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-0.25)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(0.25)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(0.5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(0.75)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(1)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.6305 .37645 Mdot
.53667 .84591 Mdot
.45096 .58342 Mdot
.44649 .28163 Mdot
.48107 .18409 Mdot
.42912 .82495 Mdot
.49613 .35456 Mdot
.49176 .01337 Mdot
.60078 .83188 Mdot
.54852 .37311 Mdot
.50432 .7539 Mdot
.56882 .09892 Mdot
.579 .19892 Mdot
.5408 .6681 Mdot
.53026 .05928 Mdot
.52696 .67454 Mdot
.49424 .84296 Mdot
.59683 .22873 Mdot
.57387 .57681 Mdot
.37908 .63745 Mdot
.56662 .18342 Mdot
.40888 .78887 Mdot
.39223 .68071 Mdot
.61414 .26271 Mdot
.68739 .28962 Mdot
.40412 .61297 Mdot
.43042 .70545 Mdot
.57706 .47948 Mdot
.37639 .40589 Mdot
.5439 .83288 Mdot
.58732 .22056 Mdot
.5796 .86564 Mdot
.3704 .37145 Mdot
.40194 .35364 Mdot
.60427 .35912 Mdot
.59193 .79469 Mdot
.6657 .31741 Mdot
.52047 .26822 Mdot
.38047 .35197 Mdot
.62967 .17783 Mdot
.71223 .34609 Mdot
.52882 .19709 Mdot
.60923 .63895 Mdot
.65034 .51211 Mdot
.60952 .30895 Mdot
.59195 .54302 Mdot
.56515 .52073 Mdot
.65802 .73042 Mdot
.58823 .36235 Mdot
.38761 .71541 Mdot
.66962 .70004 Mdot
.51788 .07985 Mdot
.77991 .54457 Mdot
.62417 .473 Mdot
.62279 .57631 Mdot
.46111 .97414 Mdot
.49619 .01758 Mdot
.48044 .85443 Mdot
.70379 .54443 Mdot
.58632 .25769 Mdot
.58683 .58337 Mdot
.6171 .86466 Mdot
.3789 .3786 Mdot
.48858 .26899 Mdot
.38331 .74755 Mdot
.5093 .95455 Mdot
.52659 .30806 Mdot
.55394 .53062 Mdot
.54796 .3326 Mdot
.63543 .31225 Mdot
.39463 .54351 Mdot
.43956 .40056 Mdot
.54344 .35789 Mdot
.4491 .25308 Mdot
.37856 .38434 Mdot
.50605 .55398 Mdot
.77985 .5451 Mdot
.56573 .66555 Mdot
.47076 .04659 Mdot
.46676 .16624 Mdot
.67107 .48237 Mdot
.5675 .79298 Mdot
.42029 .54714 Mdot
.55751 .24619 Mdot
.37929 .26574 Mdot
.47284 .76909 Mdot
.50499 .21076 Mdot
.53444 .26894 Mdot
.51898 .80757 Mdot
.55294 .54354 Mdot
.68718 .29063 Mdot
.58741 .07639 Mdot
.5424 .57405 Mdot
.5843 .41518 Mdot
.54436 .45555 Mdot
.54927 .0335 Mdot
.54979 .63723 Mdot
.67864 .66797 Mdot
.77626 .58456 Mdot
.47814 .85786 Mdot
.64368 .44491 Mdot
.5675 .71272 Mdot
.53678 .06359 Mdot
.64652 .56727 Mdot
.66946 .44409 Mdot
.42705 .21145 Mdot
.39598 .42272 Mdot
.53972 .70487 Mdot
.54071 .58566 Mdot
.6319 .30525 Mdot
.56599 .53649 Mdot
.44924 .2733 Mdot
.59543 .84185 Mdot
.50495 .92401 Mdot
.53086 .53362 Mdot
.57465 .6389 Mdot
.40611 .87276 Mdot
.47762 .98039 Mdot
.62711 .23947 Mdot
.56663 .18051 Mdot
.6765 .76783 Mdot
.43101 .13339 Mdot
.38737 .27369 Mdot
.63705 .31714 Mdot
.48203 .24828 Mdot
.471 .94399 Mdot
.64026 .58761 Mdot
.44766 .67526 Mdot
.3833 .56009 Mdot
.6472 .52564 Mdot
.61627 .16186 Mdot
.39562 .65477 Mdot
.56801 .75042 Mdot
.44604 .06442 Mdot
.67164 .32626 Mdot
.39221 .7514 Mdot
.53406 .32946 Mdot
.39036 .19652 Mdot
.56255 .09534 Mdot
.50569 .99554 Mdot
.43774 .68765 Mdot
.57545 .44934 Mdot
.48737 .84975 Mdot
.42134 .87818 Mdot
.36639 .52188 Mdot
.36329 .75702 Mdot
.56009 .63511 Mdot
.5637 .34067 Mdot
.68752 .75019 Mdot
.57949 .68202 Mdot
.47931 .20528 Mdot
.62752 .2901 Mdot
.43342 .50625 Mdot
.38961 .44862 Mdot
.6201 .22136 Mdot
.41276 .14682 Mdot
.42845 .93431 Mdot
.65822 .3008 Mdot
.63438 .24633 Mdot
.46202 .1642 Mdot
.49051 .05006 Mdot
.73034 .39728 Mdot
.64766 .66603 Mdot
.62044 .57328 Mdot
.62874 .37587 Mdot
.37134 .64258 Mdot
.67437 .51889 Mdot
.53104 .28963 Mdot
.6444 .26303 Mdot
.47689 .94142 Mdot
.54393 .54524 Mdot
.45782 .21811 Mdot
.47507 .18479 Mdot
.52076 .74442 Mdot
.36719 .47525 Mdot
.38988 .55231 Mdot
.52031 .40243 Mdot
.37606 .42171 Mdot
.6059 .19469 Mdot
.66569 .23766 Mdot
.41434 .49188 Mdot
.7212 .37507 Mdot
.48694 .28645 Mdot
.63025 .77982 Mdot
.42231 .03175 Mdot
.56355 .88992 Mdot
.72097 .36378 Mdot
.58216 .72016 Mdot
.7126 .68203 Mdot
.41718 .86619 Mdot
.42275 .48588 Mdot
.66333 .78865 Mdot
.41809 .08177 Mdot
.7421 .50778 Mdot
.57617 .10917 Mdot
.56722 .34834 Mdot
.69872 .22678 Mdot
.48489 .13619 Mdot
.44364 .35589 Mdot
.45494 .31922 Mdot
.45668 .33049 Mdot
.43168 .25344 Mdot
.72537 .27798 Mdot
.64392 .45516 Mdot
.5275 .60568 Mdot
.39952 .68561 Mdot
.46418 .24807 Mdot
.5388 .51178 Mdot
.46897 .78616 Mdot
.46989 .07763 Mdot
.57179 .64594 Mdot
.67421 .52123 Mdot
.45172 .7459 Mdot
.63283 .39285 Mdot
.58699 .56822 Mdot
.73044 .39965 Mdot
.51756 .35887 Mdot
.51152 .14042 Mdot
.60426 .14118 Mdot
.57859 .62384 Mdot
.70275 .5275 Mdot
.67438 .49072 Mdot
.67073 .53599 Mdot
.52595 .67389 Mdot
.40518 .50774 Mdot
.54992 .82745 Mdot
.54374 .55367 Mdot
.53973 .06963 Mdot
.64828 .82005 Mdot
.55468 .53821 Mdot
.49704 .63166 Mdot
.71443 .25933 Mdot
.60558 .46084 Mdot
.41839 .63838 Mdot
.70043 .71366 Mdot
.49528 .22063 Mdot
.63751 .62148 Mdot
.46045 .08611 Mdot
.64758 .50153 Mdot
.62447 .85314 Mdot
.49381 .87363 Mdot
.65692 .64605 Mdot
.39509 .5574 Mdot
.54834 .90908 Mdot
.52527 .36012 Mdot
.56908 .1466 Mdot
.59737 .60198 Mdot
.39693 .59462 Mdot
.38777 .27965 Mdot
.73981 .47238 Mdot
.53162 .50728 Mdot
.42668 .58371 Mdot
.59375 .18298 Mdot
.41346 .68925 Mdot
.43769 .26152 Mdot
.59495 .69261 Mdot
.4951 .61761 Mdot
.44208 .03377 Mdot
.68662 .64926 Mdot
.60102 .41981 Mdot
.41877 .64156 Mdot
.66578 .58745 Mdot
.50327 .67023 Mdot
.59557 .62362 Mdot
.59413 .27877 Mdot
.56328 .54559 Mdot
.54255 .79587 Mdot
.55264 .85672 Mdot
.40088 .45428 Mdot
.53858 .87891 Mdot
.61239 .63281 Mdot
.55454 .39552 Mdot
.55088 .27016 Mdot
.62069 .22149 Mdot
.42385 .35029 Mdot
.42419 .71415 Mdot
.65725 .72993 Mdot
.46949 .78737 Mdot
.38873 .48737 Mdot
.39847 .2057 Mdot
.42989 .41306 Mdot
.41582 .54431 Mdot
.65244 .28858 Mdot
.51177 .03605 Mdot
.52722 .73461 Mdot
.48417 .67683 Mdot
.44309 .77117 Mdot
.54987 .86661 Mdot
.58408 .41873 Mdot
.6628 .41753 Mdot
.41335 .055 Mdot
.70309 .48813 Mdot
.4846 .0157 Mdot
.69998 .46386 Mdot
.44263 .40769 Mdot
.70539 .49478 Mdot
.70099 .70487 Mdot
.59636 .7941 Mdot
.50979 .03718 Mdot
.35626 .30773 Mdot
.53706 .2414 Mdot
.535 .81513 Mdot
.64461 .56825 Mdot
.56001 .89335 Mdot
.6909 .29443 Mdot
.55799 .59365 Mdot
.66739 .70338 Mdot
.40093 .55256 Mdot
.44719 .65327 Mdot
.43732 .1143 Mdot
.45515 .84399 Mdot
.53028 .13039 Mdot
.70615 .70589 Mdot
.52756 .56556 Mdot
.543 .1862 Mdot
.45677 .14817 Mdot
.3687 .56817 Mdot
.47563 .71416 Mdot
.66826 .24322 Mdot
.73669 .54485 Mdot
.39268 .86581 Mdot
.54356 .39839 Mdot
.38833 .5338 Mdot
.57513 .28103 Mdot
.41244 .14951 Mdot
.41316 .3493 Mdot
.44218 .35979 Mdot
.46397 .33495 Mdot
.39792 .60385 Mdot
.56498 .09151 Mdot
.56594 .14436 Mdot
.54502 .45953 Mdot
.39404 .28909 Mdot
.43027 .58062 Mdot
.45799 .32795 Mdot
.54225 .83908 Mdot
.44351 .85755 Mdot
.61957 .58014 Mdot
.4581 .16806 Mdot
.41275 .35881 Mdot
.78135 .496 Mdot
.4107 .66806 Mdot
.60831 .70588 Mdot
.47796 .26288 Mdot
.38503 .76414 Mdot
.45525 .77093 Mdot
.41326 .85063 Mdot
.53316 .84668 Mdot
.48832 .74235 Mdot
.58442 .43003 Mdot
.50632 .99523 Mdot
.57102 .10073 Mdot
.70664 .50983 Mdot
.56589 .83802 Mdot
.5221 .21356 Mdot
.43905 .17387 Mdot
.48601 .93901 Mdot
.60698 .54632 Mdot
.56492 .09368 Mdot
.36261 .64153 Mdot
.65061 .66785 Mdot
.6043 .1457 Mdot
.67547 .25715 Mdot
.73037 .40529 Mdot
.50703 .37012 Mdot
.59554 .39717 Mdot
.56038 .09323 Mdot
.46617 .0113 Mdot
.5173 .41649 Mdot
.64962 .36125 Mdot
.43372 .77377 Mdot
.38957 .56232 Mdot
.63987 .42007 Mdot
.66577 .7046 Mdot
.64007 .60838 Mdot
.69037 .39454 Mdot
.48975 .05488 Mdot
.40745 .77847 Mdot
.70538 .47154 Mdot
.39332 .69265 Mdot
.65928 .23354 Mdot
.65206 .29052 Mdot
.41085 .23862 Mdot
.45355 .65501 Mdot
.73671 .47331 Mdot
.5232 .8014 Mdot
.45289 .35982 Mdot
.68339 .27042 Mdot
.63964 .32325 Mdot
.44152 .36211 Mdot
.47586 .22649 Mdot
.47734 .83196 Mdot
.41054 .52418 Mdot
.63905 .77103 Mdot
.67366 .56333 Mdot
.67853 .75798 Mdot
.67411 .25326 Mdot
.3967 .57401 Mdot
.77209 .42509 Mdot
.40515 .31936 Mdot
.52531 .73518 Mdot
.45542 .79645 Mdot
.49948 .38306 Mdot
.53407 .05709 Mdot
.55829 .08655 Mdot
.43584 .72624 Mdot
.51665 .67798 Mdot
.41933 .34308 Mdot
.43163 .68872 Mdot
.73321 .60836 Mdot
.5831 .40608 Mdot
.6434 .68158 Mdot
.43347 .66708 Mdot
.48231 .20681 Mdot
.4695 .71225 Mdot
.55336 .30817 Mdot
.39522 .50398 Mdot
.4234 .31981 Mdot
.51439 .65738 Mdot
.68274 .75751 Mdot
.38909 .20341 Mdot
.48421 .38274 Mdot
.61591 .40444 Mdot
.39578 .42774 Mdot
.40668 .26501 Mdot
.41003 .65926 Mdot
.49406 .2183 Mdot
.73925 .50585 Mdot
.62305 .11578 Mdot
.63304 .63686 Mdot
.64838 .87976 Mdot
.64735 .56843 Mdot
.46447 .72596 Mdot
.59168 .84371 Mdot
.57245 .10815 Mdot
.49989 .76169 Mdot
.54428 .82878 Mdot
.78133 .50774 Mdot
.5054 .70749 Mdot
.43274 .56803 Mdot
.49717 .78886 Mdot
.66554 .59266 Mdot
.43703 .21066 Mdot
.6547 .15978 Mdot
.52411 .38559 Mdot
.60607 .37069 Mdot
.53497 .20584 Mdot
.53572 .39762 Mdot
.53083 .51227 Mdot
.44812 .25363 Mdot
.48923 .01208 Mdot
.50128 .67859 Mdot
.45029 .0599 Mdot
.57861 .77646 Mdot
.58692 .2611 Mdot
.50473 .92308 Mdot
.64561 .35076 Mdot
.41227 .72109 Mdot
.49575 .24168 Mdot
.57626 .10496 Mdot
.74096 .48057 Mdot
.56379 .53323 Mdot
.70608 .50426 Mdot
.40194 .56375 Mdot
.55414 .73598 Mdot
.41575 .85928 Mdot
.64587 .46082 Mdot
.56837 .6071 Mdot
.58672 .4455 Mdot
.40617 .31519 Mdot
.59214 .90114 Mdot
.58887 .69977 Mdot
.507 .54792 Mdot
.62247 .56197 Mdot
.49274 .17211 Mdot
.50796 .37232 Mdot
.54557 .41122 Mdot
.62364 .46337 Mdot
.56593 .75631 Mdot
.51129 .36308 Mdot
.45511 .81942 Mdot
.50347 .96103 Mdot
.47886 .18274 Mdot
.56585 .22436 Mdot
.57452 .43618 Mdot
.57022 .42576 Mdot
.52176 .56012 Mdot
.55558 .99146 Mdot
.51808 .58533 Mdot
.53962 .84226 Mdot
.7015 .50375 Mdot
.63847 .69446 Mdot
.56087 .37476 Mdot
.37865 .62377 Mdot
.63585 .18862 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00X_ooool4o`000003oa0@4?oo
oooooooo0;oooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Iooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`?o0000^Oooool00:Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2iooooo`00Y?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo
002Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00:3ooooo0_l00002
ooooo`04o`000?ooooooooooooooo`?o000000?oooooo`000?ooool0^_ooool00:3ooooo0_l00000
1?mEEEGoIVIVo`000?ooool5o`000003ooooool0003ooooo0;[ooooo002Vooooo`;o00000_ooool3
o`000;_ooooo002Zooooo`?o0000^oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00T_ooool2o`0001Sooooo00?o0000ooooooooool0^Oooool009;ooooo0_l00004
ooooo`;o00004_ooool00ol0003oooooooooo`0=ooooo`;o0000Z_ooool009Sooooo0_l0000Boooo
o`03o`000?oooooooooo00;o00002oooool2o`000:[ooooo002/ooooo`03o`000?oooooooooo00;o
0000]oooool00:cooooo00?o0000ooooooooool0^Oooool00:;ooooo0_l00008ooooo`03o`000?oo
oooooooo0;Wooooo002Rooooo`;o00001?ooool2o`0000;ooooo00?o0000ooooooooool0^Oooool0
0:Sooooo0_l00002ooooo`?o0000^Oooool008oooooo0_l0000Gooooo`;o00000_ooool00ol0003o
ooooooooo`2iooooo`00Soooool2o`0001Oooooo0_l00002ooooo`03o`000?oooooooooo00Sooooo
0_l0002_ooooo`00Voooool2o`0000oooooo00?o0000ooooooooool01oooool3o`000:oooooo002J
ooooo`?o00003oooool00ol0003oooooooooo`07ooooo`Co0000[_ooool009[ooooo0_l0000@oooo
o`03o`000?oooooooooo00Wooooo0_l0002^ooooo`00[?ooool00ol0003oooooooooo`0:ooooo`;o
0000[Oooool00:cooooo00?o0000ooooooooool02_ooool2o`000:gooooo002/ooooo`?o00006Ooo
ool2o`0009kooooo002Rooooo`;o00002?ooool00ol0003oooooooooo`02ooooo`;o00005Oooool2
o`0009kooooo002Aooooo`;o00003oooool2o`0000Sooooo00?o0000ooooooooool00_ooool2o`00
0;Gooooo002Aooooo`;o00003?ooool2o`0000_ooooo00?o0000ooooooooool0^Oooool009oooooo
0_l0000;ooooo`03o`000?oooooooooo013ooooo0_l0002Wooooo`00[?ooool00ol0003ooooooooo
o`0@ooooo`Co0000YOooool00:cooooo00?o0000ooooooooool04?ooool4o`000:Gooooo002/oooo
o`03o`000?oooooooooo013ooooo1?l0002Uooooo`00[?ooool3o`0001?ooooo0ol0002Sooooo`00
[?ooool00ol0003oooooooooo`0Cooooo`?o0000Xoooool00:cooooo00?o0000ooooooooool05_oo
ool2o`000:7ooooo002/ooooo`03o`000?oooooooooo01Cooooo1?l0002Qooooo`00[?ooool00ol0
003oooooooooo`0Dooooo`Co0000XOooool009Oooooo0_l0000Cooooo`03o`000?oooooooooo02Go
oooo0_l0002Booooo`00ROooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B42ooooo`;o
00000_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`0Uooooo`;o0000T_ooool008Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0^Oooool0087ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onY
ZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002iooooo`00ROooool01Ol0003o
oooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo0;Wooooo0029ooooo`05o`000?ooooooooooooooool000003_ooool00omE
EEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`07
ooooo`;o0000/?ooool008Wooooo00Go410@oooooooooooooooooa0@4007ooooo`;o00001Oooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool2
o`000;3ooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01oooool2o`0000;ooooo00Go410@
oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00;ooooo0_l00003ooooo`03o`000?oo
oooooooo0;Wooooo0029ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0
00000ooooooo0000o`000003ooooo`03o`000?oooooooooo00;o0000]oooool00:cooooo00?o0000
ooooooooool00_l0000Mooooo`;o0000V?ooool008oooooo0_l0000Kooooo`03o`000?oooooooooo
01;ooooo0ol0000:ooooo`;o0000V?ooool008oooooo0_l0000<ooooo`;o00003Oooool00ol0003o
ooooooooo`0Booooo`?o00002_ooool2o`0009Sooooo002?ooooo`;o00003?ooool2o`0000gooooo
0ol0002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`0Sooooo`;o00002oooool2o`0008Oooooo002Oooooo`;o
00002oooool00ol0003oooooooooo`0Sooooo`;o00002oooool2o`0008Oooooo002Nooooo`Go0000
2Oooool00ol0003oooooooooo`2iooooo`00W_ooool2o`000003ooooool0003o000000Wooooo00?o
0000ooooooooool0^Oooool009Oooooo0_l0000@ooooo`;o000000?oooooo`000?ooool0^_ooool0
09Oooooo0_l0000@ooooo`;o000000Coooooo`000?l0003o0000^Oooool00:cooooo00?o0000oooo
ooooool09oooool2o`00093ooooo002Uooooo`;o00001Oooool00ol0003oooooooooo`0Cooooo`;o
00001oooool2o`0000Wooooo0_l0002@ooooo`00Xoooool4o`0000Gooooo00?o0000ooooooooool0
2oooool2o`0000Kooooo0_l00007ooooo`;o0000Voooool00:?ooooo1?l00005ooooo`03o`000?oo
oooooooo00_ooooo0_l0000Looooo`;o0000S_ooool00:cooooo00?o0000ooooooooool0:Oooool2
o`0008kooooo002/ooooo`03o`000?oooooooooo023ooooo0_l0002Gooooo`00Qoooool2o`0002?o
oooo00?o0000ooooooooool01_ooool2o`0001Sooooo0_l0002Gooooo`00Qoooool2o`0002?ooooo
0ol00006ooooo`;o00003oooool2o`000:3ooooo0027ooooo`;o00008oooool00ol0003ooooooooo
o`0Gooooo`;o0000X?ooool008Oooooo0_l000000ooooooo0000o`00000Iooooo`?o00001?ooool0
0ol0003oooooooooo`08ooooo`;o0000[oooool008[ooooo0_l0000;ooooo`;o00003?ooool3o`00
00Cooooo00?o0000ooooooooool02?ooool2o`000:oooooo002Cooooo`;o00000_ooool2o`0001?o
oooo0ol00004ooooo`;o0000/oooool009?ooooo0_l0000Gooooo`?o00001?ooool2o`000;?ooooo
002Nooooo`;o00002_ooool3o`000;_ooooo002Nooooo`;o00002_ooool3o`0001_ooooo0_l00009
ooooo`;o0000Toooool00:[ooooo1Ol0000Booooo`;o00001Oooool2o`0000Wooooo0_l0002Coooo
o`00Y?ooool2o`0000Kooooo00?o0000ooooooooool04_ooool2o`0000Wooooo0_l0000Oooooo`;o
0000NOooool00:Cooooo0_l00006ooooo`03o`000?oooooooooo01gooooo0_l0000Oooooo`;o0000
NOooool00:cooooo00?o0000ooooooooool0<Oooool2o`0008Kooooo002/ooooo`03o`000?oooooo
oooo037ooooo1?l00024ooooo`00S_ooool2o`0001cooooo00?o0000ooooooooool09oooool2o`00
00[ooooo0_l00024ooooo`00S_ooool2o`000006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@03ooooo`?o00002oooool2o`0001cooooo0_l0
000;ooooo`;o0000Poooool0097ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`02ooooo`?o00002oooool2o`0000Gooooo0_l0000Gooooo`;o00002Ooo
ool2o`0008?ooooo0029ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00[ooooo0_l0
0004ooooo`;o00001?ooool00ol0003oooooooooo`0@ooooo`;o00005oooool2o`0008kooooo002A
ooooo`05o`000?ooooooooooooooool000001Oooool2o`0000?ooooo0_l00003ooooo`03ogMgMol0
003o000000Cooooo0ol0002iooooo`00TOooool01?l0003oooooooooooooool2o`0000?ooooo0ol0
0005ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0fooooo`;o0000
POooool0097ooooo00Co410@oooooooooooooooo0_l00003ooooo`;o00001_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo01Wooooo0_l0000Kooooo`;o0000POooool0097ooooo00Ko
MgMgoiRHV?ooooooV9RHogMgMoooool2o`0000Wooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Iooooo`;o00006oooool2o`0000_ooooo0_l0001dooooo`00SOooool2o`0000;ooooo
00Kok^k^oc8b<_l0003o<S8bonk^k_ooool2o`0000Wooooo1?l00006ooooo`03o`000?oooooooooo
01Wooooo0_l00007ooooo`;o00002?ooool2o`0001Gooooo0_l0001dooooo`00Q?ooool2o`0000Oo
oooo0_l0000Eooooo`;o00001_ooool00ol0003oooooooooo`03ooooo`;o00007Oooool2o`0000So
oooo0_l0002;ooooo`00Q?ooool2o`0002;ooooo0_l00002ooooo`03o`000?oooooooooo00?ooooo
0_l00003ooooo`;o00000oooool2o`0002[ooooo0_l0001nooooo`00Q_ooool2o`0001?ooooo0_l0
000;ooooo`;o00000_ooool00ol0003oooooooooo`08ooooo`;o00000oooool2o`0002[ooooo0_l0
001nooooo`00Q_ooool2o`0001?ooooo0_l0000?ooooo`?o0000^Oooool008Oooooo0_l0000Soooo
o`03o`000?oooooooooo01cooooo0_l0000Yooooo`;o0000L?ooool008Oooooo0_l0000Aooooo`;o
00004?ooool00ol0003oooooooooo`0Eooooo`;o00001Oooool2o`0002Wooooo0_l0001`ooooo`00
V_ooool2o`0000_ooooo0_l00003ooooo`03o`000?oooooooooo01Gooooo0_l0002Rooooo`00ROoo
ool2o`0001cooooo0_l00003ooooo`03o`000?oooooooooo02oooooo0_l00028ooooo`00ROooool2
o`00027ooooo00?o0000ooooooooool01oooool2o`0001kooooo0_l00006ooooo`;o00002Oooool2
o`0007gooooo002/ooooo`03o`000?oooooooooo00Oooooo0_l0000Nooooo`;o00001_ooool2o`00
00Wooooo1?l0001kooooo`00[?ooool00ol0003oooooooooo`0looooo`;o0000Noooool00:cooooo
0ol0000aooooo`;o0000Q_ooool00:cooooo00?o0000ooooooooool0<Oooool2o`0008Kooooo002/
ooooo`03o`000?oooooooooo02Sooooo0_l0002?ooooo`00O?ooool2o`0002kooooo00?o0000oooo
ooooool01Oooool2o`0000Oooooo0_l0000Aooooo`;o00001Oooool2o`0008oooooo001looooo`;o
0000;_ooool00ol0003oooooooooo`05ooooo`;o00001oooool2o`00017ooooo0_l00006ooooo`;o
0000S_ooool008gooooo0_l0000Mooooo`03o`000?oooooooooo02Wooooo0_l0002>ooooo`00S?oo
ool3o`0000kooooo0_l0000=ooooo`03o`000?oooooooooo02[ooooo0_l00007ooooo`;o0000Q?oo
ool008cooooo0_l00004ooooo`;o00002Oooool2o`0000gooooo00?o0000ooooooooool0:_ooool2
o`0000Oooooo0_l00024ooooo`00T_ooool2o`0001Sooooo0ol0000[ooooo`;o0000S?ooool009ko
oooo0_l0000<ooooo`03o`000?oooooooooo02_ooooo0_l00008ooooo`;o0000P_ooool009gooooo
0ol0000<ooooo`03o`000?oooooooooo00Sooooo0_l0000[ooooo`;o0000P_ooool009gooooo0_l0
000=ooooo`03o`000?oooooooooo00Sooooo0_l00002ooooo`;o0000Zoooool00:3ooooo0_l0000:
ooooo`03o`000?oooooooooo00cooooo0_l0002[ooooo`00X?ooool2o`0000[ooooo00?o0000oooo
ooooool04_ooool2o`000:Gooooo002Aooooo`;o00006Oooool00ol0003oooooooooo`0Booooo`;o
0000YOooool0097ooooo0_l0000Iooooo`03o`000?oooooooooo04?ooooo0_l0001dooooo`00Sooo
ool2o`0001_ooooo00?o0000ooooooooool04oooool2o`0002kooooo0_l0001dooooo`00Q?ooool2
o`0000Wooooo0_l000000ooooooo0000o`00000Hooooo`?o00004oooool2o`0001Sooooo0_l0002:
ooooo`00Q?ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000oooooo0ol0000_oooo
o`;o0000R_ooool008_ooooo0_l00002ooooo`;o00002?ooool2o`0000oooooo0ol00004ooooo`;o
00001oooool2o`0001;ooooo0_l0002Hooooo`00Soooool2o`0000Oooooo0_l00002ooooo`;o0000
3_ooool00ol0003oooooooooo`02ooooo`;o000000?oooooo`000?l000001?ooool2o`0001;ooooo
0_l0000=ooooo`;o0000ROooool009Sooooo0_l00002ooooo`;o00003_ooool00ol0003ooooooooo
o`02o`0000?ooooo0_l0000Cooooo`;o00004_ooool2o`0001Kooooo0_l0001aooooo`00ROooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Gooooo00?o0000ooooooooool00_l0000Hooooo`;o0000:_ooool2o`00077ooooo
0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00Co0000ooooool0003o00007oooool2o`00
09Oooooo0021ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q
8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`04o`000?oooooo0000o`0000cooooo0_l0000A
ooooo`;o0000Uoooool0087ooooo0_l00006ooooo`05o`000?ooooooooooooooool000003Oooool0
0onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo1?l0000<ooooo`;o00000_ooool2
o`0001Cooooo0ol0000Looooo`;o0000LOooool008Cooooo0_l00003ooooo`05o`000?oooooooooo
ooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`0Aooooo`;o00005?ooool3o`0001cooooo0_l0001aooooo`00Q?ooool2
o`0000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooooooo0_l00003ooooo`;o0000^oooool008?ooooo0_l00004ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00Co0000oooooooo
oooooooo0_l00003ooooo`;o00001oooool2o`000;;ooooo0023ooooo`;o00001?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool0
0ol0003oooooooooo`05ooooo`;o0000/_ooool00:cooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool0:?ooool2o`00017ooooo0_l0001looooo`00[?ooool00ol0003ooooo
ooooo`08ooooo`;o000000?oooooo`000?l000000_ooool2o`0000_ooooo0_l0000:ooooo`;o0000
4Oooool2o`0000cooooo0_l0001^ooooo`00V?ooool2o`0001;ooooo0ol00008ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0000_ooooo0_l0000[ooooo`;o0000K_ooool009Sooooo0_l0000B
ooooo`03o`000?oooooooooo00?ooooo0_l0000Nooooo`;o00009?ooool2o`0006kooooo0023oooo
o`;o00009oooool00ol0003oooooooooo`03ooooo`;o00004oooool2o`0000Wooooo0_l0000Toooo
o`;o0000K_ooool008?ooooo0_l0000Dooooo`;o00004Oooool00ol0003oooooooooo`0Hooooo`;o
0000;oooool2o`0006kooooo002Dooooo`;o00000oooool2o`00017ooooo00?o0000ooooooooool0
3?ooool2o`000:_ooooo002Dooooo`;o00005_ooool00ol0003oooooooooo`02ooooo`;o00002?oo
ool2o`0000[ooooo0_l0002Oooooo`00[?ooool00ol0003oooooooooo`02ooooo`;o00005?ooool2
o`0001Sooooo0_l00025ooooo`00Poooool2o`0000Cooooo0_l0000Qooooo`03o`000?oooooooooo
01Sooooo0_l00004ooooo`;o00002oooool2o`0000Gooooo0_l00025ooooo`00Poooool2o`0000Co
oooo0_l0000Qooooo`?o00005?ooool2o`0000Sooooo0_l0000;ooooo`;o0000:Oooool2o`00067o
oooo0029ooooo`;o00008Oooool00ol0003oooooooooo`0Dooooo`;o0000@?ooool2o`00067ooooo
0029ooooo`;o00008Oooool00ol0003oooooooooo`0Hooooo`;o0000Woooool00:cooooo00?o0000
ooooooooool06?ooool2o`0009oooooo002/ooooo`03o`000?oooooooooo01Gooooo0_l0002Roooo
o`00[?ooool00ol0003oooooooooo`0Eooooo`;o0000X_ooool00:cooooo00?o0000ooooooooool0
^Oooool00:cooooo00?o0000ooooooooool06Oooool2o`00017ooooo0_l00007ooooo`;o0000P_oo
ool008Oooooo0_l0000Sooooo`03o`000?oooooooooo01Gooooo0_l00002ooooo`;o00004Oooool2
o`0000Oooooo0_l00022ooooo`00Qoooool2o`0002?ooooo0ol0000Eooooo`;o0000X_ooool008_o
oooo0_l0000Oooooo`03o`000?oooooooooo00_ooooo0_l0000Oooooo`;o0000Roooool008_ooooo
0_l0000Oooooo`03o`000?oooooooooo00_ooooo0_l0000Oooooo`;o0000Roooool000Wooooo1?l0
00000ol@413oooooooooo`0Fooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo
00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8b
omgMg@0Fooooo`03o`000?oooooooooo00_ooooo0_l0000;ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00_ooool2o`000003oooooolQ8B7o8B4Q00Cooooo1ol00002ooooo`05odA4A?l0003o0000oc8b
<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd03oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`00
0?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`Co000000?o410@oooooooo
ool04_ooool000_ooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool05Oooool00ol0003oooooooooo`0;ooooo`;o00002oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00;ooooo0_l000001?oooooo8B4Qob4Q8Oooool2o`000006oooooonHV9So8B4Qonk^
k_ooooooA4A40_l00005ooooo`03ogMgMolb<S;ooooo00Sooooo0_l00004ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool0
6Oooool00ol0003oooooooooo`0Dooooo`001_l00005ooooo`03o`000?oooooooooo013ooooo1_l0
0002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`00
0?oooooooooo00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003o
ooooooooo`05ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q
8Oo^k^h02Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Sooooo00Go410@oooo
oooooooooooooa0@4008ooooo`;o00000_ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooo
oooo00Oooooo0_l00004ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`0=ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool05?ooool000_ooooo00?o0000ooooooooool06?oo
ool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8b
ooooo`0>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0>ooooo`05
o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo
01Gooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003ooo
ool00omgMgOo<S8booooo`0>ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooo
ooooo`06ooooo`03ogMgMolb<S;ooooo01Wooooo00?o0000ooooooooool05?ooool000_ooooo00?o
0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool0
0oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000ooooooooooooooooo`00000<oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`03oooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Kooooo00?o0000ooooooooool0
6?ooool01Ol0003ooooooooooooooooo000000Wooooo0_l00003ooooo`03ogMgMomVIVKooooo00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00:ooooo`;o00000oooool01_l0003ooooooooooooooooo
0000ooooo`?o00002?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00oooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Joooo
o`03o`000?oooooooooo01Cooooo000;ooooo`03o`000?oooooooooo01Sooooo00Go410@oooooooo
oooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool04Oooool01Ol@
413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooo
oooo410@00?ooooo0_l0000:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06?oo
ool3o`0001Sooooo00Go410@oooooooooooooooooa0@4009ooooo`;o00001?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00cooooo0_l00003ooooo`06oa0@4?ooooooooooooooool@
413ooooo0ol00008ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400>
ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0D
ooooo`002oooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo0_l00006ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo01Kooooo0_l000001OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000
okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0<ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
01Cooooo0009ooooo`03oeEEEOmVIVKo000001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`Go00001?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00004?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co0000
5oooool00ol0003oooooooooo`0Fooooo`;o000000Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool6o`0000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02
ooooo`;o00002?ooool4o`00013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?oo
ool4o`0001Wooooo00?oEEEEofIVI_l000005_ooool009;ooooo0_l0000Hooooo`03o`000?oooooo
oooo03Gooooo0_l0000Eooooo`;o0000Joooool008Oooooo0_l00009ooooo`;o00006?ooool00ol0
003oooooooooo`10ooooo`;o0000Moooool008Oooooo0_l00006ooooo`;o00006oooool00ol0003o
ooooooooo`0fooooo`;o00002?ooool2o`0006cooooo0_l00002ooooo`;o00001Oooool008oooooo
0_l0000Kooooo`03o`000?oooooooooo03Kooooo0_l00008ooooo`;o0000K?ooool01_o^k^ko8B4Q
ohN7Qonj^[[o0000omgMg@Gooooo002/ooooo`03o`000?oooooooooo043ooooo0_l0000Gooooo`;o
0000E?ooool01?oMgMgo0000oa0@4?o<c<`6ooooo`001oooooooo`0004co00003?ooool01?o^k^ko
8B4Qoa0@4?o^k^h6ooooo`001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`?o00002?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool3o`0000Oo
oooo00?o0000ooooooooool01Oooool4o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00Co8B4QogMgMomgMgOo<S8b1_ooool000Oo
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool00oooool2o`0000_ooooo0_l0000Dooooo`03o`000?oooooooooo00Oo
oooo0_l0000Nooooo`03o`000?oooooooooo00?ooooo0_l0000@ooooo`Co00002Oooool2o`0000;o
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Wo
oooo0_l00002ooooo`;o00001Oooool008cooooo0_l00008ooooo`;o00005?ooool00ol0003ooooo
ooooo`07ooooo`;o0000>?ooool2o`0000Wooooo0_l0000;ooooo`;o0000G_ooool008cooooo0_l0
000Nooooo`03o`000?oooooooooo00Oooooo1?l0000Sooooo`;o00004Oooool2o`0000Wooooo0_l0
000;ooooo`;o0000G_ooool00:cooooo00?o0000ooooooooool01oooool4o`0002?ooooo0_l00029
ooooo`00[?ooool00ol0003oooooooooo`0fooooo`;o0000POooool007oooooo0_l0000[ooooo`03
o`000?oooooooooo01;ooooo0_l0000Rooooo`;o0000POooool007oooooo0_l0000=ooooo`;o0000
7?ooool3o`0001;ooooo0_l0000Iooooo`;o00001oooool2o`00087ooooo002>ooooo`;o00007?oo
ool00ol0003oooooooooo`0]ooooo`;o00004?ooool2o`0007Sooooo002/ooooo`03o`000?oooooo
oooo00kooooo0_l0000_ooooo`;o0000N?ooool008Oooooo0_l0000Sooooo`03o`000?oooooooooo
00Oooooo0_l00005ooooo`;o00000_ooool2o`000:Gooooo0027ooooo`;o00008oooool00ol0003o
ooooooooo`07ooooo`;o00002Oooool2o`00027ooooo0_l00022ooooo`00[?ooool00ol0003ooooo
ooooo`0?ooooo`;o000000?oooooo`000?l000008Oooool2o`0008;ooooo0029ooooo`;o00008Ooo
ool00ol0003oooooooooo`0>ooooo`?o00002_ooool2o`0009cooooo0029ooooo`;o00001Oooool2
o`0001[ooooo00?o0000ooooooooool02oooool2o`000004ooooool0003o0000ooooo`;o00002?oo
ool2o`0000?ooooo0_l0000Nooooo`;o00002Oooool2o`0000cooooo0_l0001Nooooo`00T?ooool3
o`0001Wooooo00Co0000ooooool0003o00002_ooool2o`0000Cooooo0_l0000=ooooo`;o00007_oo
ool2o`0000Wooooo0_l0000<ooooo`;o0000G_ooool008Oooooo0_l00002ooooo`;o00001?ooool2
o`0001Wooooo1?l0002hooooo`00Qoooool2o`0000;ooooo0_l0000Oooooo`04o`000?oooooo0000
o`0000[ooooo0_l0002/ooooo`00ROooool2o`00027ooooo00Co0000ooooool0003o00002_ooool2
o`000:cooooo0025ooooo`;o00000_ooool2o`00027ooooo00?o0000ooooooooool01?ooool2o`00
01oooooo0_l0002Booooo`00QOooool4o`0000;ooooo0_l0000Oooooo`03o`000?oooooooooo00Co
oooo0_l0000Oooooo`;o00003oooool2o`00087ooooo0027ooooo`;o00000_ooool2o`0000Sooooo
0_l0000Eooooo`03o`000?oooooooooo00Kooooo0_l0000Uooooo`;o00001oooool2o`00087ooooo
0020ooooo`;o00004oooool2o`0001Gooooo00?o0000ooooooooool01_ooool2o`00017ooooo0_l0
000Aooooo`?o0000R_ooool0083ooooo0_l00007ooooo`;o00008Oooool00ol0003oooooooooo`0;
ooooo`;o00003?ooool2o`0000Wooooo0_l00006ooooo`?o0000R_ooool008Wooooo0_l0000Qoooo
o`?o00002oooool2o`0000Sooooo0_l0000=ooooo`?o0000T_ooool00:cooooo00?o0000oooooooo
ool05Oooool2o`0000gooooo0ol0002Booooo`00UOooool2o`0001Gooooo00?o0000ooooooooool0
9?ooool2o`0009?ooooo002Cooooo`Co00001?ooool2o`0000oooooo00?o0000ooooooooool00ooo
ool2o`0000Gooooo0_l0000=ooooo`;o0000?Oooool2o`0005oooooo002Cooooo`;o00001_ooool2
o`0000oooooo00?o0000ooooooooool00oooool2o`0000Gooooo0_l0000=ooooo`;o00004?ooool2
o`0000Kooooo0_l0000Sooooo`;o0000Goooool00:cooooo00?o0000ooooooooool0:oooool2o`00
00Kooooo0_l00024ooooo`00R_ooool2o`00023ooooo00?o0000ooooooooool04?ooool2o`00027o
oooo0_l00024ooooo`00R_ooool2o`00023ooooo00?o0000ooooooooool04?ooool2o`00027ooooo
0_l00024ooooo`00[?ooool3o`000;Wooooo002:ooooo`;o00008?ooool00ol0003oooooooooo`0M
ooooo`;o0000V_ooool008[ooooo0_l0000Pooooo`03o`000?oooooooooo00Kooooo0_l0000;oooo
o`;o00002?ooool2o`0009[ooooo002/ooooo`03o`000?oooooooooo00Kooooo0_l0000;ooooo`;o
00005_ooool2o`0001gooooo0_l0001]ooooo`00S?ooool2o`0001kooooo00?o0000ooooooooool0
:oooool2o`0001gooooo0_l0001]ooooo`00S?ooool2o`0001kooooo00?o0000ooooooooool0^Ooo
ool008Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@03ooooo`?o0000^oooool008Wooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_oo
ool00_ooool3o`0002cooooo0_l0002=ooooo`00Q?ooool2o`0000?ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`0001Oo
oooo0_l00003ooooo`;o00003?ooool2o`0008gooooo0024ooooo`;o00000oooool01Ol0003ooooo
oooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo01Oooooo0_l00003ooooo`;o0000Voooool008Wooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004oooo
o`;o0000^oooool008Wooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01_ooool2o`0002Cooooo0_l0002Eooooo`00Q?ooool2o`0000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo0_l000000ooooooo0000o`00000@
ooooo`;o00001?ooool2o`0008oooooo0024ooooo`;o00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo0_l00006ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o
0000ooooooooool03Oooool2o`000003ooooool0003o000000?ooooo0_l0000:ooooo`;o00001Ooo
ool2o`0008oooooo001nooooo`;o000000?oooooo`000?l000003_ooool2o`0001Wooooo00?o0000
ooooooooool05Oooool2o`0000[ooooo0_l0002Fooooo`00O_ooool2o`000003ooooool0003o0000
00kooooo0_l0000Iooooo`03o`000?oooooooooo01Cooooo0_l0000Jooooo`;o0000Qoooool00:co
oooo00?o0000ooooooooool05?ooool2o`0001[ooooo0_l00008ooooo`;o0000OOooool00:cooooo
0ol0000jooooo`;o0000OOooool008Wooooo0_l0000?ooooo`Co00003_ooool00ol0003ooooooooo
o`2iooooo`00ROooool2o`0000oooooo1?l0000>ooooo`04o`000?ooooooooooooooo`;o0000]_oo
ool008kooooo0_l0000Looooo`04o`000?ooooooooooooooo`;o0000]_ooool008kooooo0_l0000L
ooooo`03o`000?oooooooooo0;Wooooo002>ooooo`;o00001_ooool2o`0001Cooooo00?o0000oooo
ooooool02_ooool2o`0000Kooooo0_l0000Iooooo`?o00002?ooool2o`0007oooooo002>ooooo`;o
00001_ooool2o`0001Cooooo0ol0000:ooooo`;o00001_ooool2o`0001Wooooo0ol00008ooooo`;o
0000Ooooool00:cooooo0ol00005ooooo`;o0000/_ooool009[ooooo0_l0000:ooooo`;o00001?oo
ool3o`0000Gooooo0_l0002booooo`00V_ooool2o`0000[ooooo0_l00004ooooo`;o00000oooool2
o`000003ooooool0003o00000;;ooooo0028ooooo`;o00008_ooool2o`0000?ooooo0_l0000Coooo
o`;o00004oooool2o`0001Gooooo0_l0001dooooo`00R?ooool4o`00023ooooo00?o0000oooooooo
ool05oooool2o`0001?ooooo0_l0000Eooooo`;o0000M?ooool008[ooooo0_l00003ooooo`;o0000
1?ooool4o`0001?ooooo00?o0000ooooooooool0^Oooool008oooooo0_l00004ooooo`Co00004ooo
ool00ol0003oooooooooo`2iooooo`00R?ooool2o`0002;ooooo00?o0000ooooooooool07?ooool2
o`0000cooooo0_l0002=ooooo`00R?ooool2o`0002;ooooo00?o0000ooooooooool07?ooool2o`00
00cooooo0_l0002=ooooo`00[?ooool3o`0001[ooooo0_l0000Iooooo`;o0000P_ooool00:cooooo
00?o0000ooooooooool06_ooool2o`0001Sooooo0ol00022ooooo`00UOooool2o`0001Gooooo0ol0
000:ooooo`;o00005?ooool2o`00017ooooo0ol00009ooooo`Co0000M_ooool009Gooooo0_l0000E
ooooo`?o00002_ooool2o`0001Cooooo0_l0000Aooooo`;o00002_ooool4o`0007Kooooo002Qoooo
o`;o00002Oooool00ol0003oooooooooo`0Cooooo`;o0000Y?ooool008Kooooo0_l0000;ooooo`;o
00003?ooool2o`000003ooooool0003o000000Kooooo00?o0000ooooooooool04oooool2o`0002[o
oooo0_l0001hooooo`00Q_ooool2o`0000_ooooo0_l0000?ooooo`;o00001_ooool00ol0003ooooo
ooooo`0oooooo`;o0000N?ooool008oooooo0_l0000Kooooo`03o`000?oooooooooo01Sooooo0_l0
002Oooooo`00Soooool2o`0001_ooooo0ol0000Hooooo`;o0000Woooool009Kooooo0_l00008oooo
o`;o00002_ooool00ol0003oooooooooo`2iooooo`00U_ooool2o`0000Sooooo0_l0000:ooooo`03
o`000?oooooooooo033ooooo0ol00026ooooo`00[?ooool00ol0003oooooooooo`06ooooo`;o0000
:?ooool3o`0008Kooooo002/ooooo`03o`000?oooooooooo00Gooooo0ol00006ooooo`;o0000ZOoo
ool00:cooooo00?o0000ooooooooool01Oooool2o`0000Oooooo0_l0002Yooooo`00TOooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`06odA4A?l0003o0000oc8b<_oMgMgooooo
0_l00002ooooo`03o`000?oooooooooo0;Wooooo002Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool00olQ8B7o0000o`000007ooooo`03ogMgMolb<S;ooooo00;o00000_ooool00ol0003ooooo
ooooo`03ooooo`;o0000]?ooool008Gooooo0_l0000:ooooo`05oa0@4?ooooooooooooooool@4100
1_ooool2o`0000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`;o0000
]?ooool008Gooooo0_l000000ooooooo0000o`000007ooooo`05o`000?ooooooooooooooool00000
3oooool00omgMgOo<S8booooo`04ooooo`?o00004oooool2o`0002Gooooo0_l0001mooooo`00R?oo
ool2o`0000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool3o`0001?ooooo0_l0000Uooooo`;o0000OOooool007kooooo0_l0000Aooooo`05oa0@
4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`?o00004_ooool2o`0002?o
oooo1?l0001nooooo`00O_ooool2o`00017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
o`000?oooooooooo00Oooooo0_l0000Cooooo`;o00008oooool4o`0007kooooo0026ooooo`;o0000
2Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000^_ooool008Kooooo
0_l0000Tooooo`03o`000?oooooooooo03Oooooo0_l00020ooooo`00WOooool2o`0000Cooooo0_l0
0007ooooo`03o`000?oooooooooo02[ooooo0_l0000;ooooo`;o0000P?ooool009Kooooo0_l00000
0ooooooo0000o`000002ooooo`;o00001?ooool2o`0000Oooooo00?o0000ooooooooool0:_ooool2
o`0008gooooo002Fooooo`;o000000?oooooo`000?l000004Oooool3o`0001Oooooo0_l0002Poooo
o`00SOooool2o`0001gooooo00?o0000ooooooooool05oooool2o`0000oooooo0_l0002?ooooo`00
SOooool2o`0001gooooo00?o0000ooooooooool0:?ooool2o`0008oooooo002Qooooo`;o00002Ooo
ool00ol0003oooooooooo`2iooooo`00SOooool2o`0001;ooooo0_l00008ooooo`;o0000=?ooool2
o`0008Gooooo002=ooooo`;o00004_ooool2o`0000Sooooo0_l0000dooooo`;o0000QOooool00:co
oooo00?o0000ooooooooool04oooool2o`0000Kooooo0ol0002Kooooo`00WOooool2o`0000gooooo
00?o0000ooooooooool02oooool2o`0000Kooooo0_l00006ooooo`?o0000Voooool009gooooo0_l0
000=ooooo`?o00001?ooool2o`0000Gooooo0_l0002/ooooo`00[?ooool00ol0003oooooooooo`04
ooooo`;o0000/oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool00oooool2o`000;Cooooo002/ooooo`03o`000?oooooooooo00?ooooo0_l0002dooooo`00[?oo
ool00ol0003oooooooooo`08ooooo`;o0000[oooool009gooooo0_l0000=ooooo`03o`000?oooooo
oooo00Sooooo0_l0002_ooooo`00WOooool2o`0000gooooo00?o0000ooooooooool0;_ooool2o`00
08Wooooo002Dooooo`;o00005_ooool3o`0002kooooo0_l00029ooooo`00U?ooool2o`0001Kooooo
00?o0000ooooooooool03Oooool2o`000:[ooooo002/ooooo`03o`000?oooooooooo00_ooooo1?l0
002Zooooo`00Y?ooool2o`0000Kooooo00?o0000ooooooooool02oooool2o`00017ooooo0_l0002I
ooooo`00Y?ooool2o`0000Kooooo00?o0000ooooooooool02oooool2o`00017ooooo0_l0002Ioooo
o`00[?ooool00ol0003oooooooooo`0;ooooo`;o00001Oooool2o`000:Gooooo002Zooooo`?o0000
3?ooool3o`0000Gooooo0_l00007ooooo`?o0000Voooool009gooooo0_l0000;ooooo`?o00002_oo
ool4o`0000oooooo0ol0002Kooooo`00WOooool2o`0000Sooooo0_l00003ooooo`03o`000?oooooo
oooo00Sooooo0ol0002^ooooo`00Soooool2o`0001Kooooo0_l00003ooooo`?o0000^Oooool008oo
oooo0_l0000Dooooo`;o00001Oooool00ol0003oooooooooo`0Vooooo`;o0000TOooool009Wooooo
0_l00009ooooo`?o00001Oooool00ol0003oooooooooo`0>ooooo`;o00005_ooool2o`00097ooooo
002@ooooo`;o00001oooool2o`0000Wooooo0_l00006ooooo`03o`000?oooooooooo00kooooo0_l0
002Yooooo`00T?ooool2o`0001[ooooo00?o0000ooooooooool08oooool2o`0009Cooooo0028oooo
o`;o000000Co<S8bo`000?lb<S;ok^k^0_ooool2o`000003oooooolQ8B7o8B4Q00Kooooo00?o0000
onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool03Ooo
ool2o`0000Sooooo0_l0000:ooooo`;o0000U?ooool008Sooooo0_l000001?nHV9SooooooiRHV?mg
MgL2ooooo`;o000000?oooooob4Q8OlQ8B401_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool03Oooool2o`0000Sooooo0_l0002Pooooo`00ROooool0
1?l@413oooooooooooooool2o`0000cooooo00?oZJVYoeEEEOooool02?ooool01?l0003ooooooooo
ooooool3o`000;_ooooo0029ooooo`04o`000?ooooooooooooooo`;o00003Oooool00olQ8B7ooooo
ooooo`06ooooo`03ogMgMolb<S;ooooo00;ooooo1Ol0002iooooo`00ROooool01Ol0003ooooooooo
oooooooo000000Cooooo0_l00008ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo00Wooooo0_l0000Sooooo`;o0000ROooool008Wooooo
00Go410@oooooooooooooooooa0@4004ooooo`;o00002?ooool00onYZJWoMgMgooooo`03ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool2o`0002?ooooo0_l00029ooooo`00
ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0^Oooool008Wooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool04_ooool2o`000:Gooooo002/ooooo`03o`000?oooooooooo013ooooo
1?l0002Uooooo`00[?ooool00ol0003oooooooooo`0@ooooo`;o0000Yoooool00:cooooo0ol0000K
ooooo`;o0000W?ooool00:cooooo00?o0000ooooooooool06oooool2o`0009cooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo00gooooo0_l0002Zooooo`00[?oo
ool00ol0003oooooooooo`0=ooooo`;o0000Z_ooool00:cooooo00?o0000ooooooooool0^Oooool0
0:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo
0ol0002iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Doooo
o`;o00005_ooool00ol0003oooooooooo`2iooooo`00U?ooool2o`0001Kooooo00?o0000oooooooo
ool0^Oooool00:Oooooo0_l00003ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`;o000000?o
ooooo`000?l000000oooool00ol0003oooooooooo`2iooooo`00X_ooool4o`0000Kooooo00?o0000
ooooooooool0^Oooool00:;ooooo0_l00008ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`?o
0000^Oooool00:cooooo00?o0000ooooooooool00_l0002gooooo`00[?ooool00ol0003ooooooooo
o`02o`000;Oooooo002/ooooo`?o0000^Oooool00:cooooo0ol0002iooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00Woooool2o`0000_ooooo0ol0002iooooo`00Woooool2o`0000_ooooo00?o0000oooo
ooooool0^Oooool00:Cooooo0_l00006ooooo`03o`000?oooooooooo0;Wooooo002Tooooo`;o0000
1_ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool0
0ol0003oooooooooo`0?ooooo`;o0000Z?ooool00:;ooooo1?l000000ol@413oooooooooo`03oooo
o`04o`000?oooooo0000o`0000kooooo0_l0002Xooooo`00Y?ooool00ol0003oooooooooo`05oooo
o`Co0000^?ooool00:Cooooo00?o0000ooooooooool01Oooool3o`000;Wooooo002Tooooo`03o`00
0?oooooooooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Tooooo`03o`000?oooooo
oooo0<7ooooo002Tooooo`03o`000?oooooooooo0<7ooooo002Rooooo`03oeEEEOmVIVKo00000<?o
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Zooooo`04
oa0@4?l0003o0000o`000;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`00
0?oooooooooo0;[ooooo002[ooooo`06o`000?mgMgOo0000o`000?mEEEGok^k^]oooool00:_ooooo
00Ko0000oeEEEOo^k^koooooogMgMomEEEFgooooo`00Zoooool00ol0003ok^k^ooooo`02ooooo`03
o`000?oooooooooo0;Gooooo002[ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0
]Oooool00:_ooooo00Ko0000oeEEEOo^k^koooooogMgMomVIVJgooooo`00Z_ooool00ol@413o0000
ogMgM`02o`000003ofIVI_o^k^kooooo0;Kooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.04734, -1.03409, 0.00757304, \
0.00757304}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "A series of filamentary structures form and then are stretched out to such \
a fine scale that they can no longer be discerned. Although ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " continues to evolve on finer and finer scales as the filaments are \
stretched and wrapped up, on larger scales ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " becomes time-independent. That is, the number of particles in any finite \
phase-space element ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], " ", 
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["p",
                FontSlant->"Italic"]}]]}], TraditionalForm]]],
  ", namely ",
  Cell[BoxData[
      FormBox[
        RowBox[{"f", " ", 
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], " ", 
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["p",
                FontSlant->"Italic"]}]]}], TraditionalForm]]],
  ", eventually becomes independent of time.  The time-independent solution \
",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_eq\)(x, p)\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " can be found by dropping the  partial time derivative in Eq.  ",
  ButtonBox["(7.1.21)",
    ButtonData:>{"Chapter7.nb", "(7.1.21)"},
    ButtonStyle->"Hyperlink"],
  " :"
}], "Text",
  CellTags->"i:9"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(p\/m\) \[PartialD]f\_eq\/\[PartialD]x - \(\
\[PartialD]V\/\[PartialD]x\) \[PartialD]f\_eq\/\[PartialD]p = 0\)]],
  "."
}], "NumberedEquation",
  CellTags->"(7.1.23)"],

Cell[TextData[{
  "Here we have used the fact that the force ",
  Cell[BoxData[
      \(TraditionalForm\`F(x)\)]],
  " in this example is derivable from a potential ",
  Cell[BoxData[
      \(TraditionalForm\`V(x)\)]],
  " via ",
  Cell[BoxData[
      \(TraditionalForm\`F = \(-\[PartialD]V\)/\[PartialD]x\)]],
  ". The solution to Eq. ",
  ButtonBox["(7.1.23)",
    ButtonData:>{"Chapter7.nb", "(7.1.23)"},
    ButtonStyle->"Hyperlink"],
  "   can be found by making a change of variables from ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, p)\)\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`\((E, p)\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`E\  = \ p\^2/\((2\ m)\) + V(x)\)]],
  " is the energy.  In these variables, ",
  Cell[BoxData[
      \(TraditionalForm\`f\_eq = \(f\_eq\)(E, p)\)]],
  ", and it is left as  an exercise in partial derivatives to show that Eq. \
",
  ButtonBox["(7.1.23)",
    ButtonData:>{"Chapter7.nb", "(7.1.23)"},
    ButtonStyle->"Hyperlink"],
  "  becomes"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(\(-\(\[PartialD]V\/\[PartialD]x\)\) \[PartialD]f\_eq\/\
\[PartialD]p\), 
          SubscriptBox[
            StyleBox["|",
              FontSize->14], "E"]}], "=", "0."}], 
      TraditionalForm]]]], "NumberedEquation",
  CellTags->"(7.1.24)"],

Cell["This equation can be integrated, yielding ", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`f\_eq = \ \(f\_eq\)(E)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(7.1.25)"],

Cell[TextData[{
  "The equilibrium is a function only of the energy ",
  Cell[BoxData[
      \(TraditionalForm\`E = p\^2/\((2\ m)\) + V(x)\)]],
  ". This can be easily understood intuitively: the phase mixing of the \
particle distribution eventually spreads particles out evenly along each \
energy surface, so that the particle density becomes constant on each \
surface, but may vary from surface to surface. "
}], "Text"],

Cell[TextData[{
  "\tThe functional form of ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_eq\)(E)\)]],
  " is determined by the initial conditions. For an initial distribution ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_o\)(x, p)\)]],
  ", energy conservation implies that the number of particles between the \
energy surfaces ",
  Cell[BoxData[
      \(TraditionalForm\`E\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`E + \[DifferentialD]E\)]],
  " remains constant over time. This number can be written either as ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(f\_eq\)(E)\)\ \[DifferentialD]E\)]],
  " or as ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\[DifferentialD]x \[DifferentialD]p\ \
\(\(f\_o\)(x, p)\)\)]],
  ", where the area integral is over the infinitesimal area between energy \
surfaces ",
  Cell[BoxData[
      \(TraditionalForm\`E\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`E + \[DifferentialD]E\)]],
  "  [",
  Cell[BoxData[
      \(TraditionalForm\`E \[LessEqual] H(x, p) \[LessEqual] \ 
        E + \ \[DifferentialD]E\)]],
  "], and where ",
  Cell[BoxData[
      \(TraditionalForm\`H(x, p) = p\^2/\((2\ m)\) + V(x)\)]],
  " is the Hamiltonian. Therefore, the equilibrium is determined by the \
equation"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(f\_eq\)(
            E)\)\ \[DifferentialD]E = \(\[Integral]\[DifferentialD]x \
\[DifferentialD]p\)\+\(E \[LessEqual] \ H(x, p)\  \[LessEqual] \ E + \ \
\[DifferentialD]E\)\ \(\(f\_o\)(x, p)\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(7.1.26)"],

Cell[TextData[{
  "\tEven though the area integral is an infinitessimal, it is nontrivial to \
evaluate because the distance between energy surfaces varies from place to \
place along the surfaces. (The integral can be evaluated using action-angle \
variables, but we will not involve ourselves with the canonical \
transformations required to define these variables.) On the other hand, the \
integral can be performed numerically if we convert ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]E\)]],
  " to a finite quantity ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["E",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tWe first define the initial particle density. Since there are ",
  Cell[BoxData[
      \(TraditionalForm\`M = 500\)]],
  " particles spread uniformly over a region ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < 1/2\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`0 < p < 1/2\)]],
  ", we define the initial distribution:"
}], "Text"],

Cell[BoxData[{
    \(\(f0[x_, p_]\  := \ 
        4\ M /; \ 0 < x < 1/2\  && \ 0 < p < 1/2;\)\), "\n", 
    \(f0[x_, p_]\  := \ 
      0\  /; \ Not[0 < x < 1/2\  && \ 0 < p < 1/2]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.8"],

Cell[TextData[{
  "With this definition, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\[DifferentialD]x \[DifferentialD]p\ \
\(\(f\_o\)(x, p)\) = M\)]],
  ". Next, we define the potential ",
  Cell[BoxData[
      \(TraditionalForm\`V(x)\)]],
  " for this problem, and the Hamiltonian function ",
  Cell[BoxData[
      \(TraditionalForm\`H(x, p)\)]],
  ":"
}], "Text"],

Cell[BoxData[{
    \(m = \(g = 1\); k = 20;\), "\n", 
    \(\(V[x_]\  = m\ g\ x\  + \ k\ x\^2/2\ \ UnitStep[\(-x\)]\ ;\)\), "\n", 
    \(\(H[x_, p_]\  = \ p\^2/\((2\ m)\)\  + \ V[x];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.9"],

Cell[TextData[{
  "Finally, we integrate over the area between two constant energy surfaces \
separated by ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["E",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " using ",
  StyleBox["Boole",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " notation:"
}], "Text"],

Cell[BoxData[{
    \(\(\(<< Calculus`;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(feq[e_]\  := \ 
        NIntegrate[
            Boole[e < H[x, p] < e + \[CapitalDelta]E]\ f0[x, p], {x, 0, 
              1/2}, {p, 0, 1/2}]/\[CapitalDelta]E;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[CapitalDelta]E\  = \ 0.001;\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.10"],

Cell[TextData[{
  "A plot of the equilibrium energy distribution is shown in Cell ",
  ButtonBox["7.11",
    ButtonData:>"Cell 7.11",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[Table[{e, feq[e]}, {e, \(- .2\), 1,  .025}], 
        PlotJoined \[Rule] True, 
        AxesLabel \[Rule] {"\<E\>", \*"\"\<\!\(f\_eq\)(E)\>\""}];\)\)], \
"Input",
  ShowCellTags->True,
  CellTags->"Cell 7.11"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.18254 0.793651 0.0147151 0.000588604 [
[.02381 .00222 -12 -9 ]
[.02381 .00222 12 0 ]
[.34127 .00222 -9 -9 ]
[.34127 .00222 9 0 ]
[.5 .00222 -9 -9 ]
[.5 .00222 9 0 ]
[.65873 .00222 -9 -9 ]
[.65873 .00222 9 0 ]
[.81746 .00222 -9 -9 ]
[.81746 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[1.025 .01472 0 -6 ]
[1.025 .01472 10 6 ]
[.17004 .13244 -18 -4.5 ]
[.17004 .13244 0 4.5 ]
[.17004 .25016 -18 -4.5 ]
[.17004 .25016 0 4.5 ]
[.17004 .36788 -18 -4.5 ]
[.17004 .36788 0 4.5 ]
[.17004 .4856 -18 -4.5 ]
[.17004 .4856 0 4.5 ]
[.17004 .60332 -24 -4.5 ]
[.17004 .60332 0 4.5 ]
[.18254 .64303 -18.7188 0 ]
[.18254 .64303 18.7188 12.9375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02097 L
s
[(-0.2)] .02381 .00222 0 1 Mshowa
.34127 .01472 m
.34127 .02097 L
s
[(0.2)] .34127 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(0.4)] .5 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(0.6)] .65873 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(0.8)] .81746 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.06349 .01472 m
.06349 .01847 L
s
.10317 .01472 m
.10317 .01847 L
s
.14286 .01472 m
.14286 .01847 L
s
.22222 .01472 m
.22222 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30159 .01472 m
.30159 .01847 L
s
.38095 .01472 m
.38095 .01847 L
s
.42063 .01472 m
.42063 .01847 L
s
.46032 .01472 m
.46032 .01847 L
s
.53968 .01472 m
.53968 .01847 L
s
.57937 .01472 m
.57937 .01847 L
s
.61905 .01472 m
.61905 .01847 L
s
.69841 .01472 m
.69841 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.77778 .01472 m
.77778 .01847 L
s
.85714 .01472 m
.85714 .01847 L
s
.89683 .01472 m
.89683 .01847 L
s
.93651 .01472 m
.93651 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(E) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.18254 .13244 m
.18879 .13244 L
s
[(200)] .17004 .13244 1 0 Mshowa
.18254 .25016 m
.18879 .25016 L
s
[(400)] .17004 .25016 1 0 Mshowa
.18254 .36788 m
.18879 .36788 L
s
[(600)] .17004 .36788 1 0 Mshowa
.18254 .4856 m
.18879 .4856 L
s
[(800)] .17004 .4856 1 0 Mshowa
.18254 .60332 m
.18879 .60332 L
s
[(1000)] .17004 .60332 1 0 Mshowa
.125 Mabswid
.18254 .04415 m
.18629 .04415 L
s
.18254 .07358 m
.18629 .07358 L
s
.18254 .10301 m
.18629 .10301 L
s
.18254 .16187 m
.18629 .16187 L
s
.18254 .1913 m
.18629 .1913 L
s
.18254 .22073 m
.18629 .22073 L
s
.18254 .27959 m
.18629 .27959 L
s
.18254 .30902 m
.18629 .30902 L
s
.18254 .33845 m
.18629 .33845 L
s
.18254 .39731 m
.18629 .39731 L
s
.18254 .42674 m
.18629 .42674 L
s
.18254 .45617 m
.18629 .45617 L
s
.18254 .51503 m
.18629 .51503 L
s
.18254 .54446 m
.18629 .54446 L
s
.18254 .57389 m
.18629 .57389 L
s
.25 Mabswid
.18254 0 m
.18254 .61803 L
s
gsave
.18254 .64303 -79.7188 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.9375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(eq) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.438 13.000 moveto
(H) show
84.438 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(E) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
90.438 13.000 moveto
(L) show
96.438 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.04365 .01472 L
.06349 .01472 L
.08333 .01472 L
.10317 .01472 L
.12302 .01472 L
.14286 .01472 L
.1627 .01472 L
.18254 .02712 L
.20238 .27794 L
.22222 .38698 L
.24206 .47064 L
.2619 .54118 L
.28175 .60302 L
.30159 .60332 L
.32143 .60332 L
.34127 .60332 L
.36111 .60332 L
.38095 .60332 L
.40079 .60332 L
.42063 .60332 L
.44048 .60332 L
.46032 .60332 L
.48016 .60332 L
.5 .60332 L
.51984 .60332 L
.53968 .60332 L
.55952 .60332 L
.57937 .59091 L
.59921 .34009 L
.61905 .23105 L
.63889 .14739 L
.65873 .07686 L
.67857 .01501 L
.69841 .01472 L
.71825 .01472 L
.7381 .01472 L
.75794 .01472 L
.77778 .01472 L
.79762 .01472 L
.81746 .01472 L
.8373 .01472 L
.85714 .01472 L
.87698 .01472 L
.89683 .01472 L
.91667 .01472 L
.93651 .01472 L
.95635 .01472 L
.97619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`005_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000Aoooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00006oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool06Ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<
c<`06oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000
ob4Q8Oo<c<`09?ooool4o`000003oa0@4?oooooooooo02Kooooo000Fooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A017ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Kooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool06_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B406ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ
8B409_ooool00ol0003oooooooooo`0Xooooo`003_ooool6o`0000;ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^04Sooooo00Go410@oooooooooooooooooa0@400<oooo
o`03oiRHV?lQ8B7ok^k^01cooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00006oooool0
1Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Kooooo`05oa0@
4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Kooooo00?o0000oooo
ooooool0:?ooool001Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^
04Oooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01_ooooo00Go0000
ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001cooooo00Go0000oooooooooooo
ooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B406oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Vooooo`03o`000?oooooooooo02Sooooo000F
ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`16ooooo`05o`000?oo
ooooooooooooool000003_ooool00omgMgOoIVIVooooo`0Jooooo`05o`000?ooooooooooooooool0
00002oooool01?oMgMgoEEEEooooool0000Looooo`05o`000?ooooooooooooooool000002oooool0
1Ol0003oEEEEo`000?l@413oc<c<01_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<
c?l0003o0000o`000?o<c<`09_ooool00ol0003oooooooooo`0Xooooo`005_ooool01Ol@413ooooo
oooooooooooo410@00oooooo00?o0000ooooooooool0AOooool01Ol@413ooooooooooooooooo410@
00oooooo00?o0000ooooooooool06Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMg
olc<c?l000007?ooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool07Ooo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400Vooooo`03
o`000?oooooooooo02Sooooo000Fooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o
^[ZjoooooonHV9So410@04Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@41006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
7?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P07Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000Vooooo`03o`000?oooooo
oooo02Sooooo000Fooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<04Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`06oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool06oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@6oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0Tooooo`03oeEEEOmVIVKo000002[o
oooo003oooooofWooooo001=ooooo`03o`000?oooooooooo0?oooooo6Oooool004gooooo00?o0000
ooooooooool0o_ooool6o`0001Cooooo001=ooooo`03o`000?oooooooooo0?oooooo00Go0000oooo
ooooooooooooo`00000Dooooo`00COooool00ol0003oooooooooo`3oooooo`05o`000?oooooooooo
ooooool@41005?ooool001Koooooool0000`o`0000[ooooo00?o0000ooooool@41005_ooool001go
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00oooooo0ol0000Foooo
o`007Oooool00ol0003oooooooooo`0Zooooo`;o000000?oooooo`000?ooool0;_ooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool03oooool01Ol0003o
oooooa0@4?oooooo410@01Cooooo001<ooooo`;o0000U?ooool00ol0003oooooooooo`1Zooooo`05
o`000?ooooooooooooooool000005?ooool004gooooo00?o0000ooooooooool0T_ooool00ol0003o
ooooooooo`1Yooooo`Ko00005?ooool004gooooo00?o0000ooooooooool0T_ooool00ol0003ooooo
ooooo`23ooooo`00COooool00ol0003oooooooooo`2Aooooo`03o`000?oooooooooo08Cooooo001=
ooooo`03o`000?oooooooooo097ooooo00?o0000ooooooooool0Q?ooool004gooooo00?o0000oooo
ooooool0TOooool00ol0003oooooooooo`24ooooo`00COooool2o`00097ooooo00?o0000oooooooo
ool0QOooool004gooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`25ooooo`00COoo
ool2o`00097ooooo00?o0000ooooooooool0QOooool004gooooo0_l0002@ooooo`03o`000?oooooo
oooo08Kooooo001=ooooo`;o0000T?ooool00ol0003oooooooooo`26ooooo`00COooool2o`00093o
oooo00?o0000ooooooooool0Q_ooool004gooooo0_l0002?ooooo`03o`000?oooooooooo08Oooooo
001=ooooo`;o0000Soooool00ol0003oooooooooo`27ooooo`00COooool2o`0008oooooo00?o0000
ooooooooool0Qoooool004gooooo0_l0002>ooooo`03o`000?oooooooooo08Sooooo001=ooooo`;o
0000S_ooool00ol0003oooooooooo`28ooooo`00COooool2o`0008kooooo00?o0000ooooooooool0
R?ooool004gooooo0_l0002>ooooo`03o`000?oooooooooo08Sooooo001=ooooo`;o0000SOooool0
0ol0003oooooooooo`29ooooo`00COooool2o`0008gooooo00?o0000ooooooooool0ROooool004go
oooo00?o0000ooooool00000S?ooool00ol0003oooooooooo`29ooooo`00COooool00ol0003ooooo
o`00002;ooooo`03o`000?oooooooooo08[ooooo001=ooooo`03o`000?oooooo000008_ooooo00?o
0000ooooooooool0R_ooool004gooooo0ol0002;ooooo`03o`000?oooooooooo08[ooooo001=oooo
o`03o`000?oooooo000008_ooooo00?o0000ooooooooool0R_ooool004gooooo00?o0000ooooool0
0000R_ooool00ol0003oooooooooo`2;ooooo`00COooool00ol0003oooooo`00002:ooooo`03o`00
0?oooooooooo08_ooooo001=ooooo`03o`000?oooooo000008[ooooo00?o0000ooooooooool0Rooo
ool004gooooo00?o0000ooooool00000ROooool00ol0003oooooooooo`2<ooooo`00<_ooool5o`00
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_oo
ool00ol0003oooooo`000029ooooo`03o`000?oooooooooo08cooooo000booooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`06ooooo`03o`000?oooooo000008Wooooo00?o0000ooooooooool0S?ooool003?ooooo
00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooooooooa0@4006ooooo`03o`000?oooooo000008Wooooo00?o0000ooooooooool0S?ooool003Co
oooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000006ooooo`?o0000R?ooool00ol0003oooooooooo`2=ooooo`00=Oooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000Kooooo00Co0000oooooooooooo0000Qoooool00ol0003oooooooooo`2=ooooo`00=_oo
ool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo00Cooooo00Co0000oooooooooooo0000Qoooool00ol0003oooooooooo`2=oooo
o`00<_ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool01?l0003oooooooooool00026ooooo`03o`00
0?oooooooooo08kooooo000booooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`04o`000?oooooooooo
o`0008Kooooo00?o0000ooooooooool0S_ooool004gooooo00Co0000oooooooooooo0000Q_ooool0
0ol0003oooooooooo`2>ooooo`00COooool01?l0003oooooooooool00026ooooo`03o`000?oooooo
oooo08kooooo001=ooooo`04o`000?ooooooooooo`0008Gooooo00?o0000ooooooooool0Soooool0
04gooooo00Co0000oooooooooooo0000QOooool00ol0003oooooooooo`2?ooooo`00COooool2o`00
0003ooooool0003ooooo08Cooooo00?o0000ooooooooool0Soooool004gooooo00Co0000oooooooo
oooo0000QOooool00ol0003oooooooooo`2?ooooo`00COooool01?l0003oooooooooool00024oooo
o`03o`000?oooooooooo093ooooo001=ooooo`04o`000?ooooooooooo`0008Cooooo00?o0000oooo
ooooool0T?ooool004gooooo00Go0000ooooooooooooooooo`000023ooooo`03o`000?oooooooooo
093ooooo001=ooooo`05o`000?ooooooooooooooool00000Poooool00ol0003oooooooooo`2@oooo
o`00COooool01Ol0003ooooooooooooooooo000008?ooooo00?o0000ooooooooool0T?ooool004go
oooo00Go0000ooooooooooooooooo`000022ooooo`03o`000?oooooooooo097ooooo001=ooooo`05
o`000?ooooooooooooooool00000P_ooool00ol0003oooooooooo`2Aooooo`00COooool2o`0000;o
oooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`2Aooooo`00COooool01Ol0003ooooo
oooooooooooo000008;ooooo00?o0000ooooooooool0TOooool004gooooo00Go0000oooooooooooo
ooooo`000021ooooo`03o`000?oooooooooo09;ooooo001=ooooo`05o`000?ooooooooooooooool0
0000POooool00ol0003oooooooooo`2Booooo`00COooool01Ol0003ooooooooooooooooo0000087o
oooo00?o0000ooooooooool0T_ooool004gooooo00Go0000ooooooooooooooooo`000021ooooo`03
o`000?oooooooooo09;ooooo001=ooooo`05o`000?ooooooooooooooool00000P?ooool00ol0003o
ooooooooo`2Cooooo`00COooool01Ol0003ooooooooooooooooo0000083ooooo00?o0000oooooooo
ool0Toooool004gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1mooooo`03o`00
0?oooooooooo09?ooooo001=ooooo`;o00000oooool00ol0003oooooooooo`1mooooo`03o`000?oo
oooooooo09?ooooo001=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0OOooool0
0ol0003oooooooooo`2Cooooo`00COooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
07cooooo00?o0000ooooooooool0U?ooool004gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`1looooo`03o`000?oooooooooo09Cooooo001=ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0O?ooool00ol0003oooooooooo`2Dooooo`00COooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0U?ooool003Cooooo0_l00000
2Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07cooooo00?o0000oooo
ooooool0U?ooool003Gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0Noooool00ol0003oooooooooo`2Eooooo`00<_ooool5o`0000?ooooo00Go410@oooo
oooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001_ooool3o`0000;ooooo00?o
0000ooooooooool0Noooool00ol0003oooooooooo`2Eooooo`00<_ooool01?m4A4CogMgMooooool0
0004ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo09Go
oooo000booooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo07_ooooo00?o0000ooooooooool0UOooool003?ooooo00?oMgMgolc<c?l000001?ooool01Ol@
413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`2Eooooo`00<oooool0
0oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1iooooo`03o`00
0?oooooooooo09Kooooo000dooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo07Wooooo00?o0000ooooooooool0U_ooool004gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo09Kooooo001=ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`2Fooooo`00COooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0U_ooool0
04gooooo0_l00004ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0U_ooool004go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo09Oo
oooo001=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0N?ooool00ol0003ooooo
ooooo`2Gooooo`00COooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07Sooooo00?o
0000ooooooooool0Uoooool004gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1g
ooooo`03o`000?oooooooooo09Oooooo001=ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0Moooool00ol0003oooooooooo`2Gooooo`00COooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo07Kooooo00?o0000ooooooooool0V?ooool004gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo09Sooooo001=ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`2Hooooo`00COooool2
o`0000Kooooo00?o0000ooooooooool0MOooool00ol0003oooooooooo`2Hooooo`00COooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool0V?ooool004go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo09So
oooo001=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0M?ooool00ol0003ooooo
ooooo`2Iooooo`00COooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07Cooooo00?o
0000ooooooooool0VOooool004gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1d
ooooo`03o`000?oooooooooo09Wooooo001=ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0Loooool00ol0003oooooooooo`2Iooooo`00COooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo07?ooooo00?o0000ooooooooool0VOooool004gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo09[ooooo001=ooooo`;o00001ooo
ool00ol0003oooooooooo`1booooo`03o`000?oooooooooo09[ooooo001=ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`2Jooooo`00COooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0V_ooool004go
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo09[o
oooo001=ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003ooooo
ooooo`2Jooooo`00COooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo077ooooo00?o
0000ooooooooool0V_ooool004gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1a
ooooo`03o`000?oooooooooo09[ooooo000booooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`2Jooooo`00<_oo
ool01OmEEEGoMgMgoooooonHV9So8B4Q00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
06oooooo00?o0000ooooooooool0Voooool003;ooooo00Go0000ooooooooooooooooo`000003oooo
o`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Kooooo0ol0
0008ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0Voooool003;ooooo00Go0000
oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1_ooooo`03
o`000?oooooooooo09_ooooo000booooo`05o`000?mEEEGo0000oa0@4?o<c<`00oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`2Kooooo`00<_ooool00omE
EEGoQhN7ooooo`05ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@00Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1_ooooo`03o`000?oo
oooooooo09_ooooo000booooo`03omgMgOl@413oV9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo06kooooo00?o0000ooooooooool0Voooool003?ooooo00Coc<c<odA4A?l0003o410@
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`2Koooo
o`00COooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo06kooooo00?o0000oooooooo
ool0Voooool004gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1^ooooo`03o`00
0?oooooooooo09_ooooo001=ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0K_oo
ool00ol0003oooooooooo`2Kooooo`00COooool2o`0000_ooooo00?o0000ooooooooool0KOooool0
0ol0003oooooooooo`2Kooooo`00COooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
06gooooo00?o0000ooooooooool0Voooool004gooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo09_ooooo001=ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0K?ooool00ol0003oooooooooo`2Looooo`00COooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0W?ooool004gooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo09cooooo001=oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`2Loooo
o`00COooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo06_ooooo00?o0000oooooooo
ool0W?ooool004gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Zooooo`03o`00
0?oooooooooo09cooooo001=ooooo`;o00003Oooool00ol0003oooooooooo`1Zooooo`03o`000?oo
oooooooo09cooooo001=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0J_ooool0
0ol0003oooooooooo`2Looooo`00COooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
06[ooooo00?o0000ooooooooool0W?ooool004gooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`1Zooooo`03o`000?oooooooooo09cooooo001=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0JOooool00ol0003oooooooooo`2Looooo`00COooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0W?ooool004gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo09cooooo001=oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`2Moooo
o`00COooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo06Oooooo00?o0000oooooooo
ool0WOooool004gooooo0_l0000?ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0
WOooool004gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1Wooooo`03o`000?oo
oooooooo09gooooo001=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0Ioooool0
0ol0003oooooooooo`2Mooooo`00COooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
06Kooooo00?o0000ooooooooool0WOooool004gooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`1Vooooo`03o`000?oooooooooo09gooooo001=ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0I_ooool00ol0003oooooooooo`2Mooooo`00<_ooool01Oo<c<co8B4Qo`00
0?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo06Kooooo00?o0000oooo
ooooool0WOooool003;ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo09gooooo000booooo`05o`000?oooooo
ooooooooool000000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@4006ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0IOooool00ol0003o
ooooooooo`2Mooooo`00<_ooool01Olb<S;oV9RHoooooonHV9So<S8b00?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool3o`00013ooooo00?o0000
ooooooooool0IOooool00ol0003oooooooooo`2Mooooo`00<_ooool01Oo<c<co0000o`000?l0003o
c<c<00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0
W_ooool003;ooooo00Go410@okZj^_oooooo^[Zjoa0@4003ooooo`05oa0@4?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1Sooooo`03o`000?oooooooooo09kooooo000booooo`05o`000?nj^[[ooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`06ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0Hoooool00ol0003ooooooooo
o`2Nooooo`00<_ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo06?ooooo00?o0000ooooooooool0W_ooool004gooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo09kooooo001=ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`2Nooooo`00COooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0W_ooool0
04gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
09kooooo001=ooooo`;o00005?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo09ko
oooo001=ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0HOooool00ol0003ooooo
ooooo`2Nooooo`00COooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo067ooooo00?o
0000ooooooooool0W_ooool004gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1P
ooooo`03o`000?oooooooooo09kooooo001=ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0H?ooool00ol0003oooooooooo`2Nooooo`00COooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo05oooooo00?o0000ooooooooool0Woooool004gooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo09oooooo001=ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`2Oooooo`00COooool2
o`0001Kooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`2Oooooo`00COooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0Woooool004go
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo09oo
oooo001=ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0GOooool00ol0003ooooo
ooooo`2Oooooo`00COooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo05gooooo00?o
0000ooooooooool0Woooool004gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1L
ooooo`03o`000?oooooooooo09oooooo001=ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool0G?ooool00ol0003oooooooooo`2Oooooo`00COooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo05cooooo00?o0000ooooooooool0Woooool004gooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo09oooooo001=ooooo`;o00006Ooo
ool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo09oooooo001=ooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`2Pooooo`00COooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0X?ooool004go
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo0:3o
oooo001=ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0FOooool00ol0003ooooo
ooooo`2Pooooo`00COooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05Sooooo00?o
0000ooooooooool0X?ooool004gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1G
ooooo`;o0000X_ooool002_ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0EOooool2o`000:Cooooo000]ooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`1Booooo`;o0000Y_ooool002gooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@
4?ooooooooooooooool@41001_ooool3o`0001_oooooEOl0002Xooooo`00;Oooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo6Oooool0
02gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`3ooooooaWooooo000]ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@
00Kooooo00?o0000ooooooooool0oooooolIooooo`00;Oooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo6Oooool002_ooooo00?oEEEE
ofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0016ooooo`?o0000oooooolPoooo
o`00Aoooool00ol0003oooooooooo`3ooooooaoooooo0010ooooo`?o00000_ooool3o`0000Sooooo
00?oMgMgofIVI_ooool02?ooool00omVIVKoMgMgooooo`3oooooo`_ooooo000oooooo`;o00000ooo
ool01?l0003oooooooooool00007ooooo`03omgMgOl@413ok^k^00Wooooo00?ok^k^oa0@4?oMgMd0
ooooool;ooooo`00>Oooool00ol@413o0000o`000002o`000003oa0@4?l0003ooooo00;o000000Go
ooooo`000?ooooooooooo`000007ooooo`04oeEEEOnHV9Soooooooooo`Ko00000oooool00on7QhOo
IVIVooooo`3oooooo`[ooooo000kooooo`03o`000?oooooooooo00;ooooo0_l00003ooooo`?o0000
1oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool00oo^k^ko
0000ooooo`3oooooo`[ooooo000kooooo`03o`000?oooooooooo017ooooo00?o<S8booooooooool0
0_ooool01Ol0003ooooooooooooooooo410@00Cooooo00?o0000ooooooooool0ooooool9ooooo`00
>oooool00ol0003oooooooooo`0Aooooo`03oc8b<_oooooooooo00;ooooo00?o0000ooooool@4100
1_ooool00ol0003oooooooooo`3oooooo`Wooooo000kooooo`03o`000?oooooooooo017ooooo00?o
0000onk^k_ooool00_ooool3o`0000Gooooo00?ok^k^o`000?ooool0ooooool:ooooo`00>Oooool0
0ol@413o0000o`000003o`00013ooooo00?oEEEEogMgMoooool00_ooool01Ol0003ooooooa0@4?oo
oooo410@00?ooooo00?oMgMgoeEEEOooool0ooooool:ooooo`00>oooool00ol0003oooooooooo`0A
ooooo`03omgMgOl@413ok^k^00;ooooo00Go0000ooooooooooooooooo`000002ooooo`03onk^k_l@
413ogMgM0?oooooo2oooool003_ooooo00?o410@okZj^_ooool04_ooool00omgMgOoIVIVooooo`06
o`0000;ooooo00?oIVIVogMgMoooool0ooooool;ooooo`00>oooool01?nj^[[o410@o`000?l@413o
ooooob[ooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.321714, -84.3828, \
0.00520376, 7.01655}}]
}, Open  ]],

Cell[TextData[{
  "(Using ",
  StyleBox["ListPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " rather than ",
  StyleBox["Plot ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "speeds up the evaluation considerably by reducing the number of function \
evaluations). "
}], "Text"],

Cell[TextData[{
  "\tThe distribution goes to zero for ",
  Cell[BoxData[
      \(TraditionalForm\`E < 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`E \[GreaterTilde] 0.6\)]],
  " due to our choice of initial conditions, with all particles concentrated \
in this energy range. Also, it can be easily verified that"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\(\( 
                  f\_eq\)(E)\) \[DifferentialD]E = M\)]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "\tWe must now translate this distribution over energies back to a \
distribution in the ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, p)\)\)]],
  " plane. Since ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(f\_eq\)(E)\) \[DifferentialD]E\)]],
  " is the number of particles between energy surfaces ",
  Cell[BoxData[
      \(TraditionalForm\`E\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`E + \[DifferentialD]E\)]],
  ", the distribution ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_eq\)(x, p)\)]],
  " is related to ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_eq\)(E)\)]],
  " by the same formula as we used in Eq. ",
  ButtonBox["(7.1.26)",
    ButtonData:>{"Chapter7.nb", "(7.1.26)"},
    ButtonStyle->"Hyperlink"],
  " :"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(f\_eq\)(
            E)\)\ \[DifferentialD]E = \(\[Integral]\[DifferentialD]x \
\[DifferentialD]p\)\+\(E \[LessEqual] \ H(x, p)\  \[LessEqual] \ E + \ \
\[DifferentialD]E\)\ \(\(f\_eq\)(x, p)\)\)]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "In fact, since ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\(f\_eq\)(x, p)\)\)\)]],
  " is constant along the energy surfaces, we can take it out of the integral \
and write "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(f\_eq\)(
            E)\)\ \[DifferentialD]E = \[DifferentialD]\(A(E)\)\ \(\(f\_eq\)(
            x, p)\)\)]],
  ","
}], "UNNEQ"],

Cell[" where", "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]\(A(
            E)\) = \(\[Integral]\[DifferentialD]x \[DifferentialD]p\)\+\(E \
\[LessEqual] \ H(x, p)\  \[LessEqual] \ E + \ \[DifferentialD]E\)\)]]
}], "UNNEQ"],

Cell[" is the area between adjacent energy surfaces. Thus,", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(f\_eq\)(x, 
          p)\  = \(\(\(\(f\_eq\)(
              E)\)/\(\[DifferentialD]A\/\[DifferentialD]E\)\) \((E)\)\(\ \)\)\
\)]],
  ","
}], "NumberedEquation",
  CellTags->"(7.1.27)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`E = H(x, p)\)]],
  ".  [Using action-angle variables, one can show that ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]A/\[DifferentialD]E = 
        2\ \[Pi]/\(\(\[Omega]\_o\)(E)\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Omega]\_o\)(E)\)]],
  " is the orbit frequency of particles with energy ",
  Cell[BoxData[
      \(TraditionalForm\`E\)]],
  ". ]"
}], "Text"],

Cell[TextData[{
  "\tIn order to plot ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_eq\)(x, p)\)]],
  " we must first work out ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]A/\[DifferentialD]E\)]],
  ". We do so numerically by first evaluating ",
  Cell[BoxData[
      \(TraditionalForm\`A(E)\)]],
  ", the phase space area within energy surface ",
  Cell[BoxData[
      \(TraditionalForm\`E\)]],
  ", and then taking a derivative: "
}], "Text"],

Cell[BoxData[
    \(A[e_]\  := \ 
      NIntegrate[
        Boole[H[x, p] < e], {x, \(-Infinity\), Infinity}, {p, \(-Infinity\), 
          Infinity}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.12"],

Cell[TextData[{
  "In mechanics, this phase-space area is  called the ",
  StyleBox["action",
    FontSlant->"Italic"],
  " for a given energy surface. To take the derivative of this numerical \
function, it is best to first interpolate the function, and then take a \
derivative of the interpolating function:"
}], "Text",
  CellTags->"i:10"],

Cell[BoxData[{
    \(\(\(areadata\  = \ Table[{e, A[e]}, {e, 0, 2,  .1}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Ainterp = Interpolation[areadata];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(dAdE[e_] := D[Ainterp[e1], e1] /. e1 \[Rule] e\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.13"],

Cell[TextData[{
  "This derivative of the action is plotted in Cell ",
  ButtonBox["7.14",
    ButtonData:>"Cell 7.14",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[dAdE[e], {e, 0, 1}, 
        PlotLabel \[Rule] "\<\[DifferentialD]A/\[DifferentialD]E\>", 
        AxesLabel \[Rule] {"\<E\>", "\<\>"}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.14"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.359092 0.267253 [
[.21429 .16291 -9 -9 ]
[.21429 .16291 9 0 ]
[.40476 .16291 -9 -9 ]
[.40476 .16291 9 0 ]
[.59524 .16291 -9 -9 ]
[.59524 .16291 9 0 ]
[.78571 .16291 -9 -9 ]
[.78571 .16291 9 0 ]
[.97619 .16291 -3 -9 ]
[.97619 .16291 3 0 ]
[1.025 .17541 0 -6 ]
[1.025 .17541 10 6 ]
[.01131 .04179 -18 -4.5 ]
[.01131 .04179 0 4.5 ]
[.01131 .30904 -18 -4.5 ]
[.01131 .30904 0 4.5 ]
[.01131 .44267 -6 -4.5 ]
[.01131 .44267 0 4.5 ]
[.01131 .57629 -18 -4.5 ]
[.01131 .57629 0 4.5 ]
[.5 .63053 -16.9688 0 ]
[.5 .63053 16.9688 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .17541 m
.21429 .18166 L
s
[(0.2)] .21429 .16291 0 1 Mshowa
.40476 .17541 m
.40476 .18166 L
s
[(0.4)] .40476 .16291 0 1 Mshowa
.59524 .17541 m
.59524 .18166 L
s
[(0.6)] .59524 .16291 0 1 Mshowa
.78571 .17541 m
.78571 .18166 L
s
[(0.8)] .78571 .16291 0 1 Mshowa
.97619 .17541 m
.97619 .18166 L
s
[(1)] .97619 .16291 0 1 Mshowa
.125 Mabswid
.07143 .17541 m
.07143 .17916 L
s
.11905 .17541 m
.11905 .17916 L
s
.16667 .17541 m
.16667 .17916 L
s
.2619 .17541 m
.2619 .17916 L
s
.30952 .17541 m
.30952 .17916 L
s
.35714 .17541 m
.35714 .17916 L
s
.45238 .17541 m
.45238 .17916 L
s
.5 .17541 m
.5 .17916 L
s
.54762 .17541 m
.54762 .17916 L
s
.64286 .17541 m
.64286 .17916 L
s
.69048 .17541 m
.69048 .17916 L
s
.7381 .17541 m
.7381 .17916 L
s
.83333 .17541 m
.83333 .17916 L
s
.88095 .17541 m
.88095 .17916 L
s
.92857 .17541 m
.92857 .17916 L
s
.25 Mabswid
0 .17541 m
1 .17541 L
s
gsave
1.025 .17541 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(E) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .04179 m
.03006 .04179 L
s
[(1.5)] .01131 .04179 1 0 Mshowa
.02381 .30904 m
.03006 .30904 L
s
[(2.5)] .01131 .30904 1 0 Mshowa
.02381 .44267 m
.03006 .44267 L
s
[(3)] .01131 .44267 1 0 Mshowa
.02381 .57629 m
.03006 .57629 L
s
[(3.5)] .01131 .57629 1 0 Mshowa
.125 Mabswid
.02381 .06851 m
.02756 .06851 L
s
.02381 .09524 m
.02756 .09524 L
s
.02381 .12196 m
.02756 .12196 L
s
.02381 .14869 m
.02756 .14869 L
s
.02381 .20214 m
.02756 .20214 L
s
.02381 .22886 m
.02756 .22886 L
s
.02381 .25559 m
.02756 .25559 L
s
.02381 .28231 m
.02756 .28231 L
s
.02381 .33577 m
.02756 .33577 L
s
.02381 .36249 m
.02756 .36249 L
s
.02381 .38922 m
.02756 .38922 L
s
.02381 .41594 m
.02756 .41594 L
s
.02381 .46939 m
.02756 .46939 L
s
.02381 .49612 m
.02756 .49612 L
s
.02381 .52284 m
.02756 .52284 L
s
.02381 .54957 m
.02756 .54957 L
s
.02381 .01506 m
.02756 .01506 L
s
.02381 .60302 m
.02756 .60302 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -77.9688 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\342) show
68.938 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(\\220) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\342) show
86.938 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(E) show
92.938 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .06076 L
.10458 .10705 L
.14415 .14678 L
.18221 .18158 L
.22272 .21345 L
.26171 .24309 L
.30316 .27241 L
.34309 .2981 L
.3815 .32222 L
.42237 .3462 L
.46172 .36863 L
.49955 .38934 L
.53984 .41034 L
.57861 .43007 L
.61984 .45018 L
.65954 .46911 L
.69774 .48669 L
.73838 .50499 L
.77751 .52216 L
.81909 .53987 L
.85916 .5566 L
.89771 .57227 L
.93871 .58865 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000oooooom=ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000oooooom=ooooo`006_ooool0
0ol0003oooooo`00003oooooodcooooo000Jooooo`04o`000?ooooooooooo`000?ooooooBoooool0
01[ooooo00Go0000ooooooooooooooooo`00003ooooood[ooooo0004o`000003oa0@4?oooooooooo
00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool01Ol0003ooooooooooooo
oooo00000?ooooooB_ooool000;ooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?ooooooAoooool0
00;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0oooooom6ooooo`000_ooool00ol0003oooooooooo`0>ooooo`03
ogMgMolb<S;ooooo00Cooooo0ol00004ooooo`03o`000?oooooooooo0?ooooooAOooool000;ooooo
00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooodCooooo0002ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
A?ooool000;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0oooooom3ooooo`0000?oEEEEofIVI_l000003Oooool4
o`0000Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooood;ooooo000Joooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo0?oooooo@?ooool001[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`3ooooood3ooooo000Jooooo`;o00002oooool00ol0003ooooooooo
o`3oooooocoooooo000Jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0ooooooln
ooooo`006_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0?oooooo?Oooool001[o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`3ooooooccooooo000Jooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0oooooolkooooo`006_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo0?oooooo>_ooool001[ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`3oooooocWooooo000Jooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0oooooolhooooo`006_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0?oo
oooo=oooool001[ooooo0_l0000Dooooo`03o`000?oooooooooo0?oooooo=_ooool001[ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`3oooooocGooooo000Jooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0ooooooldooooo`006_ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo0?oooooo<oooool001[ooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`3ooooooc;ooooo000Jooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
oooooolaooooo`006_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo0?oooooo<?oo
ool001[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`3ooooooboooooo000Joooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0ooooool^ooooo`006_ooool2o`0001go
oooo00?o0000ooooooooool0ooooool]ooooo`006_ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo0?oooooo;?ooool001[ooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`3oooooob_ooooo000Jooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0oooooolZ
ooooo`006_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002Sooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo02Kooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<02Sooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<033ooooo1?l00000
0ol@413oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A402Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003ooooo
ooooo`0Wooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMooo
ooooV9RHob4Q8@0Xooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4Q
oiRHV?ooooooV9RHob4Q8@0booooo`03o`000?oooooooooo01_ooooo000Jooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool02_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h0:Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0000Xooooo`05oa0@
4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Sooooo00Go410@oooo
oooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<_ooool00ol0003ooooooooo
o`0Kooooo`006_ooool00ol0003oooooooooo`0Sooooo`;o00002_ooool01Ol0003ooooooooooooo
oooo000000gooooo00?oV9RHob4Q8Oo^k^h0:?ooool01Ol0003ooooooooooooooooo000000_ooooo
00CoA4A4omgMgOoooooo0000:Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRH
V?ooooooV9RHob4Q8@0Xooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooo
oonHV9So<S8b03;ooooo00?o0000ooooooooool06oooool001[ooooo0_l0000Vooooo`03o`000?oo
oooooooo00Oooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo02Oooooo
00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0:?ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00booooo`03o`000?oooooooooo01_o
oooo000Jooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01_ooool01Ol@413ooooo
oooooooooooo410@00oooooo00?o0000ooooooooool09_ooool01Ol@413ooooooooooooooooo410@
00cooooo00?oMgMgolc<c?l00000:Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEE
ohN7Qoooool0:_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zj
oa0@400booooo`03o`000?oooooooooo01_ooooo000Jooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool01Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo
V9RHoa0@400Xooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00000Yoooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV00Zooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000003;ooooo00?o0000ooooooooool0
6oooool001[ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`04ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Sooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`04olc<c?m4A4Co0000oa0@42Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT0<?ooool00omEEEGoIVIVo`00000Mooooo`006_ooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo0?oooooo8?ooool001[ooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`3ooooooaoooooo000Jooooo`03o`000?oooooooooo02_ooooo00?o0000
ooooooooool0oooooolCooooo`Ko00001Oooool001[ooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`3ooooooa?ooooo00Go0000ooooooooooooooooo`000005ooooo`006_ooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo0?oooooo4_ooool01Ol0003ooooooooooooooooo
410@00Gooooo000Boooooooo0000@_l0000;ooooo`03o`000?oooooo410@00Oooooo000Jooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`05
o`000?ooooooooooooooool000002_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
017ooooo0ol00007ooooo`006_ooool00ol0003oooooooooo`0`ooooo`;o00002?ooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>_ooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo017ooooo00Go0000ooooool@413ooooooa0@4005oooo
o`006_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo0?oooooo3Oooool01Ol0003o
oooooooooooooooo000000Gooooo000Jooooo`03o`000?oooooooooo03?ooooo00?o0000oooooooo
ool0ooooool;ooooo`Ko00001Oooool001[ooooo00?o0000ooooooooool0=?ooool2o`000?oooooo
5_ooool001[ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`3ooooooa?ooooo000J
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0oooooolBooooo`006_ooool2o`00
03Wooooo00?o0000ooooooooool0oooooolAooooo`006_ooool00ol0003oooooooooo`0iooooo`;o
0000oooooolAooooo`006_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0?oooooo
3_ooool001[ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`3oooooo`gooooo000J
ooooo`03o`000?oooooooooo03gooooo0_l0003oooooo`gooooo000Jooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool0ooooool:ooooo`006_ooool00ol0003oooooooooo`10ooooo`03
o`000?oooooooooo0?oooooo2Oooool001[ooooo00?o0000ooooooooool0@Oooool2o`000?oooooo
2Oooool001[ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`3oooooo`Kooooo000J
ooooo`;o0000AOooool00ol0003oooooooooo`3oooooo`Gooooo000Jooooo`03o`000?oooooooooo
04Gooooo0_l0003oooooo`Gooooo000Jooooo`03o`000?oooooooooo04Oooooo00?o0000oooooooo
ool0ooooool2ooooo`006_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo0?oooooo
0Oooool001[ooooo00?o0000ooooooooool0BOooool2o`000?oooooo0Oooool001[ooooo00?o0000
ooooooooool0Boooool00ol0003oooooooooo`3mooooo`006_ooool00ol0003oooooooooo`1<oooo
o`03o`000?oooooooooo0?cooooo000Jooooo`03o`000?oooooooooo04gooooo0_l0003looooo`00
6_ooool2o`00053ooooo00?o0000ooooooooool0nOooool001[ooooo00?o0000ooooooooool0D?oo
ool00ol0003oooooooooo`3hooooo`006_ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooo
oooo0?Oooooo000Jooooo`03o`000?oooooooooo05;ooooo0_l0003gooooo`006_ooool00ol0003o
ooooooooo`1Dooooo`03o`000?oooooooooo0?Cooooo000Jooooo`03o`000?oooooooooo05Gooooo
00?o0000ooooooooool0loooool001[ooooo00?o0000ooooooooool0E_ooool2o`000??ooooo000J
ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0l?ooool001[ooooo00?o0000oooo
ooooool0FOooool2o`000?3ooooo000Jooooo`;o0000G?ooool2o`000>kooooo000Jooooo`03o`00
0?oooooooooo05gooooo00?o0000ooooooooool0joooool001[ooooo00?o0000ooooooooool0G_oo
ool2o`000>_ooooo000Jooooo`03o`000?oooooooooo063ooooo0_l0003Yooooo`006_ooool00ol0
003oooooooooo`1Rooooo`03o`000?oooooooooo0>Kooooo000Jooooo`03o`000?oooooooooo06?o
oooo0_l0003Vooooo`001?l00005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Go
oooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`3Sooooo`0000Co8B4Qonk^k_oooooo
A4A41Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1Vooooo`;o
0000hoooool00003oiRHV?lQ8B7ok^k^017ooooo00?o0000ooooooooool00oooool3o`0006Sooooo
00?o0000ooooooooool0h?ooool00004oooooonHV9So8B4Qonk^kPoooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`1Yooooo`;o0000h?ooool000;ooooo00?oMgMgofIVI_ooool02ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0Joooool00ol0003ooooo
ooooo`3Mooooo`000oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0K?ooool2o`000=gooooo00001?nj^[[ooooooiRHV?l@410<ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`3Jooooo`0000Co410@
o`000?lQ8B7oc<c<3?ooool4o`0000Kooooo00?o0000ooooooooool0Koooool2o`000=[ooooo000J
ooooo`03o`000?oooooooooo077ooooo0_l0003Hooooo`006_ooool00ol0003oooooooooo`1coooo
o`;o0000e_ooool001[ooooo00?o0000ooooooooool0MOooool2o`000=Cooooo000Jooooo`;o0000
N?ooool00ol0003oooooooooo`3Aooooo`006_ooool00ol0003oooooooooo`1hooooo`;o0000dOoo
ool001[ooooo00?o0000ooooooooool0N_ooool2o`000<oooooo000Jooooo`03o`000?oooooooooo
07cooooo0_l0003=ooooo`006_ooool00ol0003oooooooooo`1nooooo`;o0000boooool001[ooooo
00?o0000ooooooooool0P?ooool2o`000<Wooooo000Jooooo`03o`000?oooooooooo08;ooooo0_l0
0037ooooo`006_ooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo0<Cooooo000Joooo
o`;o0000Q_ooool2o`000<Cooooo000Jooooo`03o`000?oooooooooo08Oooooo0_l00032ooooo`00
6_ooool00ol0003oooooooooo`29ooooo`;o0000`?ooool001[ooooo00?o0000ooooooooool0Rooo
ool2o`000;kooooo000Jooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool0^oooool0
01[ooooo00?o0000ooooooooool0S_ooool2o`000;_ooooo000Jooooo`03o`000?oooooooooo093o
oooo0_l0002iooooo`006_ooool00ol0003oooooooooo`2Booooo`03o`000?oooooooooo0;Kooooo
000Jooooo`03o`000?oooooooooo09?ooooo0_l0002fooooo`006_ooool2o`0009Kooooo0_l0002d
ooooo`006_ooool00ol0003oooooooooo`2Gooooo`;o0000/_ooool001[ooooo00?o0000oooooooo
ool0VOooool2o`000;3ooooo000Jooooo`03o`000?oooooooooo09_ooooo0_l0002^ooooo`006_oo
ool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo0:_ooooo000Jooooo`03o`000?oooooo
oooo09kooooo0_l0002[ooooo`006_ooool00ol0003oooooooooo`2Pooooo`;o0000ZOooool001[o
oooo00?o0000ooooooooool0X_ooool2o`000:Oooooo000Jooooo`;o0000YOooool2o`000:Gooooo
000Jooooo`03o`000?oooooooooo0:Kooooo0_l0002Sooooo`006_ooool00ol0003oooooooooo`2X
ooooo`;o0000XOooool001[ooooo00?o0000ooooooooool0Z_ooool2o`0009oooooo000Jooooo`03
o`000?oooooooooo0:cooooo0_l0002Mooooo`006_ooool00ol0003oooooooooo`2^ooooo`;o0000
Voooool001[ooooo00?o0000ooooooooool0/?ooool3o`0009Sooooo000?ooooo`05oiRHV?l@413o
0000oc8b<_o<c<`01_ooool00ol0003oooooooooo`2cooooo`;o0000U_ooool000oooooo00Go410@
okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo0;Gooooo0_l0002Dooooo`004oooool0
0ol0003oooooooooo`04ooooo`?o0000]oooool3o`00097ooooo000Booooo`03ojVYZOl@413ooooo
00Gooooo00?o0000ooooooooool0^_ooool2o`0008oooooo000Aooooo`03oa0@4?l0003o^[Zj00Ko
oooo00?o0000ooooooooool0_?ooool2o`0008gooooo000Booooo`03okZj^_lQ8B7ooooo00Gooooo
00?o0000ooooooooool0__ooool2o`0008_ooooo000?ooooo`05oa0@4?nHV9SooooookZj^_l00000
1_ooool00ol0003oooooooooo`30ooooo`;o0000ROooool000oooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@06ooooo`03o`000?oooooooooo0<;ooooo0_l00027ooooo`006_ooool00ol0003ooooooooo
o`34ooooo`;o0000QOooool001[ooooo00?o0000ooooooooool0a_ooool2o`0008?ooooo000Joooo
o`03o`000?oooooooooo0<Sooooo0_l00021ooooo`006_ooool2o`000<_ooooo0_l0001oooooo`00
6_ooool00ol0003oooooooooo`3<ooooo`;o0000OOooool001[ooooo00?o0000ooooooooool0c_oo
ool2o`0007_ooooo000Jooooo`03o`000?oooooooooo0=3ooooo0_l0001iooooo`006_ooool00ol0
003oooooooooo`3Booooo`;o0000Moooool001[ooooo00?o0000ooooooooool0e?ooool2o`0007Go
oooo000Jooooo`03o`000?oooooooooo0=Kooooo0_l0001cooooo`006_ooool00ol0003ooooooooo
o`3Hooooo`;o0000LOooool001[ooooo0_l0003Kooooo`?o0000K_ooool001[ooooo00?o0000oooo
ooooool0gOooool2o`0006cooooo000Jooooo`03o`000?oooooooooo0=oooooo0_l0001Zooooo`00
6_ooool00ol0003oooooooooo`3Qooooo`;o0000J?ooool001[ooooo00?o0000ooooooooool0hooo
ool3o`0006Gooooo000Jooooo`03o`000?oooooooooo0>Kooooo0ol0001Rooooo`006_ooool00ol0
003oooooooooo`3Yooooo`;o0000H?ooool001[ooooo00?o0000ooooooooool0joooool3o`0005go
oooo000Jooooo`03o`000?oooooooooo0>kooooo0_l0001Kooooo`006_ooool2o`000?7ooooo0_l0
001Iooooo`006_ooool00ol0003oooooooooo`3booooo`;o0000Eoooool001[ooooo00?o0000oooo
ooooool0m?ooool3o`0005Cooooo000Jooooo`03o`000?oooooooooo0?Oooooo0_l0001Booooo`00
6_ooool00ol0003oooooooooo`3iooooo`;o0000D?ooool001[ooooo00?o0000ooooooooool0nooo
ool2o`0004kooooo000Jooooo`03o`000?oooooooooo0?gooooo0ol0001;ooooo`006_ooool00ol0
003oooooooooo`3oooooo`7ooooo0ol00018ooooo`006_ooool2o`000?oooooo1Oooool2o`0004Ko
oooo000Jooooo`03o`000?oooooooooo0?oooooo1_ooool3o`0004?ooooo000Jooooo`03o`000?oo
oooooooo0?oooooo2Oooool2o`00047ooooo000Jooooo`03o`000?oooooooooo0?oooooo2oooool3
o`0003kooooo000Jooooo`03o`000?oooooooooo0?oooooo3_ooool2o`0003cooooo000Jooooo`03
o`000?oooooooooo0?oooooo4?ooool2o`0003[ooooo00001?l@413o0000oc8b<_o<c<`5ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolBoooo
o`?o0000=oooool00004okZj^_ooooooMgMgoc8b<PGooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0oooooolEooooo`;o0000=Oooool000?ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo5oooool2o`0003?o
oooo0002ooooo`03ojVYZOl@413ooooo00kooooo00?oMgMgoc8b<_ooool01?ooool3o`000?oooooo
6Oooool2o`00037ooooo00001?oooooo410@o`000?nj^[X<ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`3ooooooa_ooooo0ol0000^ooooo`000_ooool00onj^[[o8B4Q
ooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolNooooo`;o0000
;?ooool00004oiRHV?oooooo^[Zjo`0000cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3oooooob3ooooo0_l0000Zooooo`0000Co410@o`000?l@413oZJVY3?ooool4o`0000Kooooo
00?o0000ooooooooool0oooooolRooooo`?o00009oooool001[ooooo00?o0000ooooooooool0oooo
oolUooooo`?o00009?ooool001[ooooo00?o0000ooooooooool0oooooolXooooo`?o00008Oooool0
01[ooooo00?o0000ooooooooool0ooooool[ooooo`?o00007_ooool001[ooooo0_l0003ooooooboo
oooo00?o0000ooooooooool06oooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo002`ooooo`03ob4Q8OoMgMgooooo0;Gooooo002Poooo
o`04olc<c?l@413o0000oeEEE@Ko00000_ooool3o`000003oooooonHV9SoEEEE00Gooooo00Coc<c<
oa0@4?l0003oEEEE2?l0002Uooooo`00X?ooool02_m4A4CoMgMgoooooomEEEGo0000okZj^_l0003o
k^k^o`000?o^k^h3ooooo`06o`000?oMgMgoooooooooool0003ogMgM1?ooool01_m4A4CoMgMgoooo
oomEEEGo0000okZj^P;o00000oooool00ol0003oooooooooo`2Sooooo`00X?ooool02Ol0003ooooo
oooooonj^[[o0000okZj^_l0003ooooooeEEE@04o`000004odA4A?ooooooooooooooo`;oMgMg1?oo
ool01_l0003ooooooooooonj^[[o0000okZj^P;o00000oooool00ol@413oooooooooo`2Sooooo`00
X?ooool02_l0003ooooooooooonj^[[o0000okZj^_l0003oooooojVYZOm4A4@2ooooo`03odA4A?nH
V9Sooooo00;ooooo00?ok^k^oa0@4?o^k^h00oooool01_l0003ooooooooooonj^[[o0000okZj^P;o
000000?ooooooa0@4?ooool0Y_ooool00:3ooooo00OoA4A4ohN7QoooooooEEEEo`000?nj^[[o0000
00;ooooo00Co0000onk^k_o^k^ko00001Oooool00omEEEGoV9RHooooo`02ooooo`06odA4A?n7QhOo
oooooeEEEOl0003o^[Zj1?l0002Wooooo`00X?ooool01oo<c<co410@o`000?mEEEGo0000okZj^_l0
00000_ooool01?mVIVKoV9RHohN7QomVIVH5ooooo`03omgMgOl@413ooooo00;ooooo00Koc<c<oa0@
4?l0003oEEEEo`000?nj^[X2o`000004ooooool@413ooooooa0@4:Gooooo002Sooooo`04okZj^_l0
003o^[Zjo`0000;ooooo00Coc<c<odA4A?lQ8B7ogMgM1_ooool00omEEEGoV9RHooooo`04ooooo`03
okZj^_l0003o^[Zj00;o00000oooool00ol0003oooooooooo`2Sooooo`00Xoooool4o`000005oooo
ool@413o0000o`000?lb<S801oooool00onj^[[oA4A4ooooo`04ooooo`Wo0000YOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.0870454, 1.31528, \
0.00410642, 0.0146336}}]
}, Open  ]],

Cell[TextData[{
  "To speed up the evaluation it is best to also create an interpolation \
function for  ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_eq\)(E)\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(feqinterp\  = \ 
        Interpolation[Table[{e, feq[e]}, {e, 0, 1,  .025}], 
          InterpolationOrder \[Rule] 1];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.15"],

Cell[TextData[{
  "We use an ",
  StyleBox["InterpolationOrder ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "of only 1 because ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_eq\)(E)\)]],
  " has a discontinuous first derivative. We then define the function ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_eq\)(x, p)\)]],
  " according to Eq. ",
  ButtonBox["(7.1.27)",
    ButtonData:>{"Chapter7.nb", "(7.1.27)"},
    ButtonStyle->"Hyperlink"],
  " :"
}], "Text"],

Cell[BoxData[{
    \(\(feq[x_, p_]\  := \ 
        feqinterp[H[x, p]]/dAdE[H[x, p]]\  /; \ 
          0 < H[x, p] < \ 1;\)\), "\n", 
    \(feq[x_, p_]\  := \ 0\  /; \ Not[0 < H[x, p] < \ 1]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.16"],

Cell[TextData[{
  "The use of the conditional statements allows us to extend the definition \
to energies beyond the range of the interpolation function.  We plot the \
equilibrium in Cell ",
  ButtonBox["7.17",
    ButtonData:>"Cell 7.17",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot3D[feq[x, p], {x, \(-1\), 1}, {p, \(-1\), 1}, 
        PlotRange \[Rule] All, PlotPoints \[Rule] 40, 
        AxesLabel \[Rule] \ {"\<x\>", "\<p\>", "\<\>"}, 
        PlotLabel -> \*"\"\<\!\(f\_eq\)(x,p)\>\""];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.17"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.5 .82364 -24.7188 0 ]
[.5 .82364 24.7188 12.9375 ]
[.02757 .24618 -12 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.17646 .18758 -23.5978 -9 ]
[.17646 .18758 .40224 0 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.50253 .05935 -15.8219 -9 ]
[.50253 .05935 2.17811 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.29165 .07573 -9.31117 -12 ]
[.29165 .07573 .68883 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 12 2.73794 ]
[.78313 .12104 0 -6.13858 ]
[.78313 .12104 24 2.86142 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9224 .33431 0 -5.93715 ]
[.9224 .33431 18 3.06285 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.91861 .21225 0 -8.04169 ]
[.91861 .21225 10 3.95831 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01124 .34581 -18 -2.81061 ]
[.01124 .34581 0 6.18939 ]
[-0.00233 .43086 -18 -2.88296 ]
[-0.00233 .43086 0 6.11704 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -85.7188 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.9375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(eq) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.438 13.000 moveto
(H) show
84.438 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
90.438 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
96.438 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.438 13.000 moveto
(L) show
108.438 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(-1)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(-0.5)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(0.5)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
gsave
.29165 .07573 -70.3112 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(-1)] .70096 -0.00478 -1 .39157 Mshowa
.7708 .12553 m
.76464 .12778 L
s
[(-0.5)] .78313 .12104 -1 .36413 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.9099 .3383 m
.90365 .34029 L
s
[(0.5)] .9224 .33431 -1 .31937 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
gsave
.91861 .21225 -61 -12.0417 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02352 .3412 m
.02966 .33889 L
s
[(200)] .01124 .34581 1 -0.37542 Mshowa
.01002 .42642 m
.01619 .4242 L
s
[(400)] -0.00233 .43086 1 -0.35934 Mshowa
.125 Mabswid
.03319 .28016 m
.03687 .27874 L
s
.03001 .30024 m
.03369 .29883 L
s
.02679 .32059 m
.03047 .31919 L
s
.02021 .36208 m
.0239 .36071 L
s
.01686 .38324 m
.02055 .38188 L
s
.01346 .40469 m
.01716 .40334 L
s
.00653 .44845 m
.01024 .44713 L
s
.00299 .47078 m
.0067 .46947 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.664 .741 .908 r
.39729 .59642 .40512 .60371 .41826 .59977 .41047 .59244 Metetra
.664 .741 .908 r
.41047 .59244 .41826 .59977 .43147 .59581 .42372 .58844 Metetra
.664 .741 .908 r
.42372 .58844 .43147 .59581 .44474 .59183 .43703 .58443 Metetra
.664 .741 .908 r
.43703 .58443 .44474 .59183 .45807 .58783 .4504 .58039 Metetra
.664 .741 .908 r
.4504 .58039 .45807 .58783 .47147 .58381 .46385 .57633 Metetra
.664 .741 .908 r
.46385 .57633 .47147 .58381 .48494 .57977 .47736 .57226 Metetra
.664 .741 .908 r
.47736 .57226 .48494 .57977 .49847 .57571 .49093 .56816 Metetra
.664 .741 .908 r
.49093 .56816 .49847 .57571 .51207 .57163 .50458 .56404 Metetra
.664 .741 .908 r
.50458 .56404 .51207 .57163 .52574 .56753 .51829 .5599 Metetra
.664 .741 .908 r
.51829 .5599 .52574 .56753 .53948 .56341 .53207 .55574 Metetra
.664 .741 .908 r
.53207 .55574 .53948 .56341 .55329 .55926 .54592 .55156 Metetra
.664 .741 .908 r
.54592 .55156 .55329 .55926 .56716 .5551 .55985 .54736 Metetra
.664 .741 .908 r
.55985 .54736 .56716 .5551 .58111 .55092 .57384 .54314 Metetra
.664 .741 .908 r
.57384 .54314 .58111 .55092 .59512 .54671 .5879 .53889 Metetra
.664 .741 .908 r
.5879 .53889 .59512 .54671 .60921 .54249 .60203 .53463 Metetra
0 .109 .623 r
.60203 .53463 .60921 .54249 .62337 .53826 .61672 .54791 Metetra
.922 .61 .435 r
.61672 .54791 .62337 .53826 .63966 .59555 .63485 .66349 Metetra
.576 .325 .499 r
.63485 .66349 .63966 .59555 .65713 .66785 .65007 .66654 Metetra
.479 .877 .959 r
.65007 .66654 .65713 .66785 .67213 .66402 .66514 .66254 Metetra
.749 .957 .94 r
.66514 .66254 .67213 .66402 .68411 .59384 .68006 .65336 Metetra
0 0 .291 r
.68006 .65336 .68411 .59384 .69665 .54415 .69189 .58026 Metetra
0 0 .192 r
.69189 .58026 .69665 .54415 .70984 .51235 .70445 .53089 Metetra
.70445 .53089 .70984 .51235 .72452 .5079 .71775 .49976 Metetra
.665 .743 .908 r
.71775 .49976 .72452 .5079 .73926 .50347 .73255 .49524 Metetra
.664 .741 .908 r
.73255 .49524 .73926 .50347 .75409 .49902 .74743 .49075 Metetra
.664 .741 .908 r
.74743 .49075 .75409 .49902 .76899 .49455 .76238 .48624 Metetra
.664 .741 .908 r
.76238 .48624 .76899 .49455 .78397 .49006 .77742 .4817 Metetra
.664 .741 .908 r
.77742 .4817 .78397 .49006 .79903 .48554 .79253 .47714 Metetra
.664 .741 .908 r
.79253 .47714 .79903 .48554 .81417 .481 .80773 .47255 Metetra
.664 .741 .908 r
.80773 .47255 .81417 .481 .82939 .47643 .823 .46794 Metetra
.664 .741 .908 r
.823 .46794 .82939 .47643 .84468 .47184 .83836 .46331 Metetra
.664 .741 .908 r
.83836 .46331 .84468 .47184 .86006 .46723 .8538 .45865 Metetra
.664 .741 .908 r
.8538 .45865 .86006 .46723 .87552 .46259 .86932 .45397 Metetra
.664 .741 .908 r
.86932 .45397 .87552 .46259 .89107 .45793 .88492 .44926 Metetra
.664 .741 .908 r
.88492 .44926 .89107 .45793 .90669 .45324 .9006 .44452 Metetra
.664 .741 .908 r
.9006 .44452 .90669 .45324 .9224 .44853 .91637 .43976 Metetra
.664 .741 .908 r
.91637 .43976 .9224 .44853 .93819 .44379 .93223 .43498 Metetra
.664 .741 .908 r
.93223 .43498 .93819 .44379 .95407 .43903 .94817 .43017 Metetra
.664 .741 .908 r
.94817 .43017 .95407 .43903 .97003 .43424 .96419 .42533 Metetra
.664 .741 .908 r
.38939 .58906 .39729 .59642 .41047 .59244 .40261 .58505 Metetra
.664 .741 .908 r
.40261 .58505 .41047 .59244 .42372 .58844 .41589 .58101 Metetra
.664 .741 .908 r
.41589 .58101 .42372 .58844 .43703 .58443 .42925 .57696 Metetra
.664 .741 .908 r
.42925 .57696 .43703 .58443 .4504 .58039 .44267 .57288 Metetra
.664 .741 .908 r
.44267 .57288 .4504 .58039 .46385 .57633 .45615 .56879 Metetra
.664 .741 .908 r
.45615 .56879 .46385 .57633 .47736 .57226 .4697 .56468 Metetra
.664 .741 .908 r
.4697 .56468 .47736 .57226 .49093 .56816 .48332 .56054 Metetra
.664 .741 .908 r
.48332 .56054 .49093 .56816 .50458 .56404 .49701 .55638 Metetra
.664 .741 .908 r
.49701 .55638 .50458 .56404 .51829 .5599 .51077 .55221 Metetra
.664 .741 .908 r
.51077 .55221 .51829 .5599 .53207 .55574 .5246 .54801 Metetra
.664 .741 .908 r
.5246 .54801 .53207 .55574 .54592 .55156 .5385 .54379 Metetra
.664 .741 .908 r
.5385 .54379 .54592 .55156 .55985 .54736 .55246 .53955 Metetra
.664 .741 .908 r
.55246 .53955 .55985 .54736 .57384 .54314 .5665 .53529 Metetra
.664 .741 .908 r
.5665 .53529 .57384 .54314 .5879 .53889 .58061 .531 Metetra
.664 .741 .908 r
.58061 .531 .5879 .53889 .60203 .53463 .59479 .5267 Metetra
.929 .546 .197 r
.59479 .5267 .60203 .53463 .61672 .54791 .61037 .57474 Metetra
.858 .552 .471 r
.61037 .57474 .61672 .54791 .63485 .66349 .62763 .66227 Metetra
0 .489 .709 r
.62763 .66227 .63485 .66349 .65007 .66654 .64289 .66464 Metetra
.515 .881 .979 r
.64289 .66464 .65007 .66654 .66514 .66254 .65804 .66062 Metetra
.771 .948 .935 r
.65804 .66062 .66514 .66254 .68006 .65336 .67303 .6509 Metetra
.794 .936 .923 r
.67303 .6509 .68006 .65336 .69189 .58026 .68803 .64043 Metetra
0 0 .278 r
.68803 .64043 .69189 .58026 .70445 .53089 .69963 .56372 Metetra
0 0 .148 r
.69963 .56372 .70445 .53089 .71775 .49976 .71228 .51578 Metetra
.71228 .51578 .71775 .49976 .73255 .49524 .72577 .48697 Metetra
.665 .743 .908 r
.72577 .48697 .73255 .49524 .74743 .49075 .7407 .4824 Metetra
.664 .741 .908 r
.7407 .4824 .74743 .49075 .76238 .48624 .75571 .47784 Metetra
.664 .741 .908 r
.75571 .47784 .76238 .48624 .77742 .4817 .7708 .47326 Metetra
.664 .741 .908 r
.7708 .47326 .77742 .4817 .79253 .47714 .78597 .46865 Metetra
.664 .741 .908 r
.78597 .46865 .79253 .47714 .80773 .47255 .80122 .46402 Metetra
.664 .741 .908 r
.80122 .46402 .80773 .47255 .823 .46794 .81656 .45937 Metetra
.664 .741 .908 r
.81656 .45937 .823 .46794 .83836 .46331 .83197 .45469 Metetra
.664 .741 .908 r
.83197 .45469 .83836 .46331 .8538 .45865 .84747 .44998 Metetra
.664 .741 .908 r
.84747 .44998 .8538 .45865 .86932 .45397 .86305 .44525 Metetra
.664 .741 .908 r
.86305 .44525 .86932 .45397 .88492 .44926 .87871 .4405 Metetra
.664 .741 .908 r
.87871 .4405 .88492 .44926 .9006 .44452 .89445 .43572 Metetra
.664 .741 .908 r
.89445 .43572 .9006 .44452 .91637 .43976 .91029 .43091 Metetra
.664 .741 .908 r
.91029 .43091 .91637 .43976 .93223 .43498 .9262 .42608 Metetra
.664 .741 .908 r
.9262 .42608 .93223 .43498 .94817 .43017 .94221 .42122 Metetra
.664 .741 .908 r
.94221 .42122 .94817 .43017 .96419 .42533 .9583 .41633 Metetra
.664 .741 .908 r
.38141 .58163 .38939 .58906 .40261 .58505 .39467 .57758 Metetra
.664 .741 .908 r
.39467 .57758 .40261 .58505 .41589 .58101 .408 .57351 Metetra
.664 .741 .908 r
.408 .57351 .41589 .58101 .42925 .57696 .42139 .56942 Metetra
.664 .741 .908 r
.42139 .56942 .42925 .57696 .44267 .57288 .43486 .56531 Metetra
.664 .741 .908 r
.43486 .56531 .44267 .57288 .45615 .56879 .44838 .56118 Metetra
.664 .741 .908 r
.44838 .56118 .45615 .56879 .4697 .56468 .46198 .55702 Metetra
.664 .741 .908 r
.46198 .55702 .4697 .56468 .48332 .56054 .47564 .55285 Metetra
.664 .741 .908 r
.47564 .55285 .48332 .56054 .49701 .55638 .48938 .54866 Metetra
.664 .741 .908 r
.48938 .54866 .49701 .55638 .51077 .55221 .50318 .54444 Metetra
.664 .741 .908 r
.50318 .54444 .51077 .55221 .5246 .54801 .51705 .5402 Metetra
.664 .741 .908 r
.51705 .5402 .5246 .54801 .5385 .54379 .531 .53594 Metetra
.664 .741 .908 r
.531 .53594 .5385 .54379 .55246 .53955 .54501 .53166 Metetra
.664 .741 .908 r
.54501 .53166 .55246 .53955 .5665 .53529 .5591 .52736 Metetra
.664 .741 .908 r
.5591 .52736 .5665 .53529 .58061 .531 .57325 .52304 Metetra
.664 .741 .908 r
.57325 .52304 .58061 .531 .59479 .5267 .58748 .51869 Metetra
.96 .646 .383 r
.58748 .51869 .59479 .5267 .61037 .57474 .60486 .64762 Metetra
.606 .351 .505 r
.60486 .64762 .61037 .57474 .62763 .66227 .62027 .65989 Metetra
0 .493 .772 r
.62027 .65989 .62763 .66227 .64289 .66464 .63563 .66325 Metetra
.479 .876 .961 r
.63563 .66325 .64289 .66464 .65804 .66062 .65086 .65923 Metetra
.786 .962 .921 r
.65086 .65923 .65804 .66062 .67303 .6509 .66592 .64858 Metetra
.794 .941 .923 r
.66592 .64858 .67303 .6509 .68803 .64043 .681 .638 Metetra
.81 .939 .913 r
.681 .638 .68803 .64043 .69963 .56372 .69608 .62672 Metetra
0 0 .273 r
.69608 .62672 .69963 .56372 .71228 .51578 .70732 .54424 Metetra
0 0 .082 r
.70732 .54424 .71228 .51578 .72577 .48697 .72011 .49884 Metetra
.72011 .49884 .72577 .48697 .7407 .4824 .73391 .47399 Metetra
.664 .742 .908 r
.73391 .47399 .7407 .4824 .75571 .47784 .74897 .46936 Metetra
.664 .741 .908 r
.74897 .46936 .75571 .47784 .7708 .47326 .76412 .46474 Metetra
.664 .741 .908 r
.76412 .46474 .7708 .47326 .78597 .46865 .77935 .46009 Metetra
.664 .741 .908 r
.77935 .46009 .78597 .46865 .80122 .46402 .79466 .45541 Metetra
.664 .741 .908 r
.79466 .45541 .80122 .46402 .81656 .45937 .81005 .45071 Metetra
.664 .741 .908 r
.81005 .45071 .81656 .45937 .83197 .45469 .82552 .44598 Metetra
.664 .741 .908 r
.82552 .44598 .83197 .45469 .84747 .44998 .84107 .44123 Metetra
.664 .741 .908 r
.84107 .44123 .84747 .44998 .86305 .44525 .85671 .43645 Metetra
.664 .741 .908 r
.85671 .43645 .86305 .44525 .87871 .4405 .87244 .43165 Metetra
.664 .741 .908 r
.87244 .43165 .87871 .4405 .89445 .43572 .88825 .42682 Metetra
.664 .741 .908 r
.88825 .42682 .89445 .43572 .91029 .43091 .90414 .42197 Metetra
.664 .741 .908 r
.90414 .42197 .91029 .43091 .9262 .42608 .92012 .41709 Metetra
.664 .741 .908 r
.92012 .41709 .9262 .42608 .94221 .42122 .93619 .41218 Metetra
.664 .741 .908 r
.93619 .41218 .94221 .42122 .9583 .41633 .95234 .40724 Metetra
.664 .741 .908 r
.37336 .57414 .38141 .58163 .39467 .57758 .38666 .57005 Metetra
.664 .741 .908 r
.38666 .57005 .39467 .57758 .408 .57351 .40003 .56594 Metetra
.664 .741 .908 r
.40003 .56594 .408 .57351 .42139 .56942 .41347 .56181 Metetra
.664 .741 .908 r
.41347 .56181 .42139 .56942 .43486 .56531 .42697 .55767 Metetra
.664 .741 .908 r
.42697 .55767 .43486 .56531 .44838 .56118 .44054 .55349 Metetra
.664 .741 .908 r
.44054 .55349 .44838 .56118 .46198 .55702 .45418 .5493 Metetra
.664 .741 .908 r
.45418 .5493 .46198 .55702 .47564 .55285 .46789 .54509 Metetra
.664 .741 .908 r
.46789 .54509 .47564 .55285 .48938 .54866 .48167 .54086 Metetra
.664 .741 .908 r
.48167 .54086 .48938 .54866 .50318 .54444 .49552 .5366 Metetra
.664 .741 .908 r
.49552 .5366 .50318 .54444 .51705 .5402 .50944 .53232 Metetra
.664 .741 .908 r
.50944 .53232 .51705 .5402 .531 .53594 .52343 .52802 Metetra
.664 .741 .908 r
.52343 .52802 .531 .53594 .54501 .53166 .53749 .5237 Metetra
.664 .741 .908 r
.53749 .5237 .54501 .53166 .5591 .52736 .55162 .51936 Metetra
.664 .741 .908 r
.55162 .51936 .5591 .52736 .57325 .52304 .56582 .51499 Metetra
.536 .695 .941 r
.56582 .51499 .57325 .52304 .58748 .51869 .58017 .51446 Metetra
.954 .642 .401 r
.58017 .51446 .58748 .51869 .60486 .64762 .59744 .64878 Metetra
.619 .071 0 r
.59744 .64878 .60486 .64762 .62027 .65989 .61283 .65791 Metetra
.192 0 0 r
.61283 .65791 .62027 .65989 .63563 .66325 .62828 .66214 Metetra
.456 .871 .947 r
.62828 .66214 .63563 .66325 .65086 .65923 .6436 .65812 Metetra
.8 .968 .91 r
.6436 .65812 .65086 .65923 .66592 .64858 .65873 .64669 Metetra
.811 .952 .911 r
.65873 .64669 .66592 .64858 .681 .638 .67387 .63513 Metetra
.793 .929 .924 r
.67387 .63513 .681 .638 .69608 .62672 .68908 .62462 Metetra
.828 .949 .899 r
.68908 .62462 .69608 .62672 .70732 .54424 .70422 .61224 Metetra
0 0 .275 r
.70422 .61224 .70732 .54424 .72011 .49884 .71495 .52189 Metetra
.71495 .52189 .72011 .49884 .73391 .47399 .72795 .48007 Metetra
.707 .908 .552 r
.72795 .48007 .73391 .47399 .74897 .46936 .74217 .4608 Metetra
.664 .741 .908 r
.74217 .4608 .74897 .46936 .76412 .46474 .75737 .45613 Metetra
.664 .741 .908 r
.75737 .45613 .76412 .46474 .77935 .46009 .77266 .45143 Metetra
.664 .741 .908 r
.77266 .45143 .77935 .46009 .79466 .45541 .78802 .44671 Metetra
.664 .741 .908 r
.78802 .44671 .79466 .45541 .81005 .45071 .80347 .44196 Metetra
.664 .741 .908 r
.80347 .44196 .81005 .45071 .82552 .44598 .819 .43719 Metetra
.664 .741 .908 r
.819 .43719 .82552 .44598 .84107 .44123 .83462 .43239 Metetra
.664 .741 .908 r
.83462 .43239 .84107 .44123 .85671 .43645 .85032 .42757 Metetra
.664 .741 .908 r
.85032 .42757 .85671 .43645 .87244 .43165 .8661 .42272 Metetra
.664 .741 .908 r
.8661 .42272 .87244 .43165 .88825 .42682 .88197 .41784 Metetra
.664 .741 .908 r
.88197 .41784 .88825 .42682 .90414 .42197 .89793 .41294 Metetra
.664 .741 .908 r
.89793 .41294 .90414 .42197 .92012 .41709 .91397 .40801 Metetra
.664 .741 .908 r
.91397 .40801 .92012 .41709 .93619 .41218 .93011 .40305 Metetra
.664 .741 .908 r
.93011 .40305 .93619 .41218 .95234 .40724 .94633 .39806 Metetra
.664 .741 .908 r
.36524 .56658 .37336 .57414 .38666 .57005 .37858 .56245 Metetra
.664 .741 .908 r
.37858 .56245 .38666 .57005 .40003 .56594 .39199 .55831 Metetra
.664 .741 .908 r
.39199 .55831 .40003 .56594 .41347 .56181 .40547 .55414 Metetra
.664 .741 .908 r
.40547 .55414 .41347 .56181 .42697 .55767 .41902 .54995 Metetra
.664 .741 .908 r
.41902 .54995 .42697 .55767 .44054 .55349 .43263 .54574 Metetra
.664 .741 .908 r
.43263 .54574 .44054 .55349 .45418 .5493 .44632 .54151 Metetra
.664 .741 .908 r
.44632 .54151 .45418 .5493 .46789 .54509 .46007 .53726 Metetra
.664 .741 .908 r
.46007 .53726 .46789 .54509 .48167 .54086 .47389 .53298 Metetra
.664 .741 .908 r
.47389 .53298 .48167 .54086 .49552 .5366 .48778 .52869 Metetra
.664 .741 .908 r
.48778 .52869 .49552 .5366 .50944 .53232 .50175 .52437 Metetra
.664 .741 .908 r
.50175 .52437 .50944 .53232 .52343 .52802 .51578 .52003 Metetra
.664 .741 .908 r
.51578 .52003 .52343 .52802 .53749 .5237 .52989 .51567 Metetra
.664 .741 .908 r
.52989 .51567 .53749 .5237 .55162 .51936 .54407 .51128 Metetra
.664 .741 .908 r
.54407 .51128 .55162 .51936 .56582 .51499 .55833 .50688 Metetra
.743 .269 0 r
.55833 .50688 .56582 .51499 .58017 .51446 .57304 .5292 Metetra
.908 .6 .45 r
.57304 .5292 .58017 .51446 .59744 .64878 .58982 .64547 Metetra
.534 0 0 r
.58982 .64547 .59744 .64878 .61283 .65791 .60529 .65626 Metetra
.319 0 0 r
.60529 .65626 .61283 .65791 .62828 .66214 .62084 .66178 Metetra
.394 .848 .903 r
.62084 .66178 .62828 .66214 .6436 .65812 .63626 .65777 Metetra
.815 .982 .889 r
.63626 .65777 .6436 .65812 .65873 .64669 .65145 .64516 Metetra
.828 .959 .897 r
.65145 .64516 .65873 .64669 .67387 .63513 .66665 .63258 Metetra
.807 .938 .915 r
.66665 .63258 .67387 .63513 .68908 .62462 .68192 .62127 Metetra
.793 .918 .923 r
.68192 .62127 .68908 .62462 .70422 .61224 .69726 .61076 Metetra
.964 .878 .7 r
.69726 .61076 .70422 .61224 .71495 .52189 .71153 .58014 Metetra
0 0 .241 r
.71153 .58014 .71495 .52189 .72795 .48007 .72261 .49873 Metetra
.72261 .49873 .72795 .48007 .74217 .4608 .73582 .46028 Metetra
.821 .988 .875 r
.73582 .46028 .74217 .4608 .75737 .45613 .75056 .44744 Metetra
.664 .741 .908 r
.75056 .44744 .75737 .45613 .77266 .45143 .7659 .4427 Metetra
.664 .741 .908 r
.7659 .4427 .77266 .45143 .78802 .44671 .78132 .43793 Metetra
.664 .741 .908 r
.78132 .43793 .78802 .44671 .80347 .44196 .79683 .43313 Metetra
.664 .741 .908 r
.79683 .43313 .80347 .44196 .819 .43719 .81242 .42831 Metetra
.664 .741 .908 r
.81242 .42831 .819 .43719 .83462 .43239 .8281 .42346 Metetra
.664 .741 .908 r
.8281 .42346 .83462 .43239 .85032 .42757 .84386 .41859 Metetra
.664 .741 .908 r
.84386 .41859 .85032 .42757 .8661 .42272 .85971 .41369 Metetra
.664 .741 .908 r
.85971 .41369 .8661 .42272 .88197 .41784 .87564 .40877 Metetra
.664 .741 .908 r
.87564 .40877 .88197 .41784 .89793 .41294 .89166 .40381 Metetra
.664 .741 .908 r
.89166 .40381 .89793 .41294 .91397 .40801 .90777 .39883 Metetra
.664 .741 .908 r
.90777 .39883 .91397 .40801 .93011 .40305 .92396 .39382 Metetra
.664 .741 .908 r
.92396 .39382 .93011 .40305 .94633 .39806 .94025 .38879 Metetra
.664 .741 .908 r
.35704 .55894 .36524 .56658 .37858 .56245 .37043 .55478 Metetra
.664 .741 .908 r
.37043 .55478 .37858 .56245 .39199 .55831 .38388 .5506 Metetra
.664 .741 .908 r
.38388 .5506 .39199 .55831 .40547 .55414 .3974 .54639 Metetra
.664 .741 .908 r
.3974 .54639 .40547 .55414 .41902 .54995 .41099 .54216 Metetra
.664 .741 .908 r
.41099 .54216 .41902 .54995 .43263 .54574 .42465 .53791 Metetra
.664 .741 .908 r
.42465 .53791 .43263 .54574 .44632 .54151 .43837 .53364 Metetra
.664 .741 .908 r
.43837 .53364 .44632 .54151 .46007 .53726 .45217 .52935 Metetra
.664 .741 .908 r
.45217 .52935 .46007 .53726 .47389 .53298 .46604 .52504 Metetra
.664 .741 .908 r
.46604 .52504 .47389 .53298 .48778 .52869 .47998 .5207 Metetra
.664 .741 .908 r
.47998 .5207 .48778 .52869 .50175 .52437 .49399 .51634 Metetra
.664 .741 .908 r
.49399 .51634 .50175 .52437 .51578 .52003 .50807 .51196 Metetra
.664 .741 .908 r
.50807 .51196 .51578 .52003 .52989 .51567 .52222 .50756 Metetra
.664 .741 .908 r
.52222 .50756 .52989 .51567 .54407 .51128 .53645 .50313 Metetra
.664 .741 .908 r
.53645 .50313 .54407 .51128 .55833 .50688 .55076 .49868 Metetra
.937 .564 .233 r
.55076 .49868 .55833 .50688 .57304 .5292 .56582 .55107 Metetra
.874 .565 .46 r
.56582 .55107 .57304 .5292 .58982 .64547 .5821 .64217 Metetra
.61 .046 0 r
.5821 .64217 .58982 .64547 .60529 .65626 .59766 .65475 Metetra
.442 0 0 r
.59766 .65475 .60529 .65626 .62084 .66178 .61332 .66206 Metetra
.334 .816 .851 r
.61332 .66206 .62084 .66178 .63626 .65777 .62883 .65807 Metetra
.839 .988 .862 r
.62883 .65807 .63626 .65777 .65145 .64516 .64408 .64383 Metetra
.843 .961 .884 r
.64408 .64383 .65145 .64516 .66665 .63258 .65935 .63027 Metetra
.825 .943 .902 r
.65935 .63027 .66665 .63258 .68192 .62127 .67468 .61795 Metetra
.804 .92 .916 r
.67468 .61795 .68192 .62127 .69726 .61076 .69009 .60683 Metetra
.789 .905 .922 r
.69009 .60683 .69726 .61076 .71153 .58014 .70556 .59645 Metetra
.944 .828 .385 r
.70556 .59645 .71153 .58014 .72261 .49873 .7179 .53122 Metetra
0 0 .056 r
.7179 .53122 .72261 .49873 .73582 .46028 .73028 .47425 Metetra
.683 .762 .272 r
.73028 .47425 .73582 .46028 .75056 .44744 .74371 .43911 Metetra
.675 .757 .913 r
.74371 .43911 .75056 .44744 .7659 .4427 .75908 .43387 Metetra
.664 .741 .908 r
.75908 .43387 .7659 .4427 .78132 .43793 .77456 .42905 Metetra
.664 .741 .908 r
.77456 .42905 .78132 .43793 .79683 .43313 .79013 .42421 Metetra
.664 .741 .908 r
.79013 .42421 .79683 .43313 .81242 .42831 .80578 .41934 Metetra
.664 .741 .908 r
.80578 .41934 .81242 .42831 .8281 .42346 .82151 .41445 Metetra
.664 .741 .908 r
.82151 .41445 .8281 .42346 .84386 .41859 .83733 .40953 Metetra
.664 .741 .908 r
.83733 .40953 .84386 .41859 .85971 .41369 .85324 .40458 Metetra
.664 .741 .908 r
.85324 .40458 .85971 .41369 .87564 .40877 .86924 .3996 Metetra
.664 .741 .908 r
.86924 .3996 .87564 .40877 .89166 .40381 .88532 .3946 Metetra
.664 .741 .908 r
.88532 .3946 .89166 .40381 .90777 .39883 .9015 .38956 Metetra
.664 .741 .908 r
.9015 .38956 .90777 .39883 .92396 .39382 .91776 .38451 Metetra
.664 .741 .908 r
.91776 .38451 .92396 .39382 .94025 .38879 .93411 .37942 Metetra
.664 .741 .908 r
.34877 .55124 .35704 .55894 .37043 .55478 .36219 .54704 Metetra
.664 .741 .908 r
.36219 .54704 .37043 .55478 .38388 .5506 .37569 .54281 Metetra
.664 .741 .908 r
.37569 .54281 .38388 .5506 .3974 .54639 .38925 .53857 Metetra
.664 .741 .908 r
.38925 .53857 .3974 .54639 .41099 .54216 .40288 .5343 Metetra
.664 .741 .908 r
.40288 .5343 .41099 .54216 .42465 .53791 .41658 .53001 Metetra
.664 .741 .908 r
.41658 .53001 .42465 .53791 .43837 .53364 .43036 .5257 Metetra
.664 .741 .908 r
.43036 .5257 .43837 .53364 .45217 .52935 .4442 .52137 Metetra
.664 .741 .908 r
.4442 .52137 .45217 .52935 .46604 .52504 .45811 .51701 Metetra
.664 .741 .908 r
.45811 .51701 .46604 .52504 .47998 .5207 .4721 .51263 Metetra
.664 .741 .908 r
.4721 .51263 .47998 .5207 .49399 .51634 .48615 .50823 Metetra
.664 .741 .908 r
.48615 .50823 .49399 .51634 .50807 .51196 .50028 .50381 Metetra
.664 .741 .908 r
.50028 .50381 .50807 .51196 .52222 .50756 .51448 .49937 Metetra
.664 .741 .908 r
.51448 .49937 .52222 .50756 .53645 .50313 .52876 .4949 Metetra
.664 .741 .908 r
.52876 .4949 .53645 .50313 .55076 .49868 .54311 .4904 Metetra
.959 .64 .376 r
.54311 .4904 .55076 .49868 .56582 .55107 .5587 .60368 Metetra
.698 .415 .491 r
.5587 .60368 .56582 .55107 .5821 .64217 .57429 .63906 Metetra
.685 .14 0 r
.57429 .63906 .5821 .64217 .59766 .65475 .58993 .65385 Metetra
.532 0 0 r
.58993 .65385 .59766 .65475 .61332 .66206 .60568 .66245 Metetra
.321 .808 .842 r
.60568 .66245 .61332 .66206 .62883 .65807 .62129 .65848 Metetra
.857 .986 .849 r
.62129 .65848 .62883 .65807 .64408 .64383 .63662 .64315 Metetra
.865 .969 .86 r
.63662 .64315 .64408 .64383 .65935 .63027 .65195 .62796 Metetra
.838 .942 .892 r
.65195 .62796 .65935 .63027 .67468 .61795 .66736 .61485 Metetra
.819 .926 .905 r
.66736 .61485 .67468 .61795 .69009 .60683 .68282 .60284 Metetra
.798 .905 .916 r
.68282 .60284 .69009 .60683 .70556 .59645 .69836 .59194 Metetra
.814 .892 .899 r
.69836 .59194 .70556 .59645 .7179 .53122 .71388 .58015 Metetra
0 0 .108 r
.71388 .58015 .7179 .53122 .73028 .47425 .725 .49518 Metetra
.725 .49518 .73028 .47425 .74371 .43911 .73801 .44952 Metetra
.73801 .44952 .74371 .43911 .75908 .43387 .75219 .42498 Metetra
.664 .742 .908 r
.75219 .42498 .75908 .43387 .77456 .42905 .76773 .42009 Metetra
.664 .741 .908 r
.76773 .42009 .77456 .42905 .79013 .42421 .78335 .4152 Metetra
.664 .741 .908 r
.78335 .4152 .79013 .42421 .80578 .41934 .79906 .41028 Metetra
.664 .741 .908 r
.79906 .41028 .80578 .41934 .82151 .41445 .81486 .40534 Metetra
.664 .741 .908 r
.81486 .40534 .82151 .41445 .83733 .40953 .83074 .40037 Metetra
.664 .741 .908 r
.83074 .40037 .83733 .40953 .85324 .40458 .84672 .39537 Metetra
.664 .741 .908 r
.84672 .39537 .85324 .40458 .86924 .3996 .86278 .39034 Metetra
.664 .741 .908 r
.86278 .39034 .86924 .3996 .88532 .3946 .87892 .38529 Metetra
.664 .741 .908 r
.87892 .38529 .88532 .3946 .9015 .38956 .89516 .3802 Metetra
.664 .741 .908 r
.89516 .3802 .9015 .38956 .91776 .38451 .91149 .37509 Metetra
.664 .741 .908 r
.91149 .37509 .91776 .38451 .93411 .37942 .92791 .36995 Metetra
.664 .741 .908 r
.34042 .54346 .34877 .55124 .36219 .54704 .35388 .53922 Metetra
.664 .741 .908 r
.35388 .53922 .36219 .54704 .37569 .54281 .36742 .53496 Metetra
.664 .741 .908 r
.36742 .53496 .37569 .54281 .38925 .53857 .38103 .53067 Metetra
.664 .741 .908 r
.38103 .53067 .38925 .53857 .40288 .5343 .3947 .52637 Metetra
.664 .741 .908 r
.3947 .52637 .40288 .5343 .41658 .53001 .40845 .52204 Metetra
.664 .741 .908 r
.40845 .52204 .41658 .53001 .43036 .5257 .42226 .51768 Metetra
.664 .741 .908 r
.42226 .51768 .43036 .5257 .4442 .52137 .43615 .51331 Metetra
.664 .741 .908 r
.43615 .51331 .4442 .52137 .45811 .51701 .45011 .50891 Metetra
.664 .741 .908 r
.45011 .50891 .45811 .51701 .4721 .51263 .46414 .50449 Metetra
.664 .741 .908 r
.46414 .50449 .4721 .51263 .48615 .50823 .47824 .50005 Metetra
.664 .741 .908 r
.47824 .50005 .48615 .50823 .50028 .50381 .49242 .49559 Metetra
.664 .741 .908 r
.49242 .49559 .50028 .50381 .51448 .49937 .50667 .4911 Metetra
.664 .741 .908 r
.50667 .4911 .51448 .49937 .52876 .4949 .52099 .48658 Metetra
.664 .741 .908 r
.52099 .48658 .52876 .4949 .54311 .4904 .53539 .48205 Metetra
.96 .649 .395 r
.53539 .48205 .54311 .4904 .5587 .60368 .55094 .6194 Metetra
.708 .34 .35 r
.55094 .6194 .5587 .60368 .57429 .63906 .56638 .636 Metetra
.742 .219 0 r
.56638 .636 .57429 .63906 .58993 .65385 .5821 .65333 Metetra
.625 .063 0 r
.5821 .65333 .58993 .65385 .60568 .66245 .59796 .66421 Metetra
.187 .713 .704 r
.59796 .66421 .60568 .66245 .62129 .65848 .61367 .66029 Metetra
.878 .992 .8 r
.61367 .66029 .62129 .65848 .63662 .64315 .62906 .64234 Metetra
.879 .962 .848 r
.62906 .64234 .63662 .64315 .65195 .62796 .64447 .6261 Metetra
.854 .95 .877 r
.64447 .6261 .65195 .62796 .66736 .61485 .65993 .61181 Metetra
.833 .928 .895 r
.65993 .61181 .66736 .61485 .68282 .60284 .67546 .59896 Metetra
.81 .909 .908 r
.67546 .59896 .68282 .60284 .69836 .59194 .69107 .58738 Metetra
.794 .892 .915 r
.69107 .58738 .69836 .59194 .71388 .58015 .70674 .57661 Metetra
.955 .856 .704 r
.70674 .57661 .71388 .58015 .725 .49518 .72126 .54552 Metetra
0 0 .147 r
.72126 .54552 .725 .49518 .73801 .44952 .73238 .46312 Metetra
.769 .804 .319 r
.73238 .46312 .73801 .44952 .75219 .42498 .74578 .42415 Metetra
.823 .987 .877 r
.74578 .42415 .75219 .42498 .76773 .42009 .76082 .41104 Metetra
.664 .741 .908 r
.76082 .41104 .76773 .42009 .78335 .4152 .77651 .4061 Metetra
.664 .741 .908 r
.77651 .4061 .78335 .4152 .79906 .41028 .79228 .40113 Metetra
.664 .741 .908 r
.79228 .40113 .79906 .41028 .81486 .40534 .80814 .39614 Metetra
.664 .741 .908 r
.80814 .39614 .81486 .40534 .83074 .40037 .82409 .39112 Metetra
.664 .741 .908 r
.82409 .39112 .83074 .40037 .84672 .39537 .84012 .38606 Metetra
.664 .741 .908 r
.84012 .38606 .84672 .39537 .86278 .39034 .85624 .38099 Metetra
.664 .741 .908 r
.85624 .38099 .86278 .39034 .87892 .38529 .87246 .37588 Metetra
.664 .741 .908 r
.87246 .37588 .87892 .38529 .89516 .3802 .88876 .37074 Metetra
.664 .741 .908 r
.88876 .37074 .89516 .3802 .91149 .37509 .90516 .36558 Metetra
.664 .741 .908 r
.90516 .36558 .91149 .37509 .92791 .36995 .92164 .36039 Metetra
.664 .741 .908 r
.33199 .53562 .34042 .54346 .35388 .53922 .3455 .53133 Metetra
.664 .741 .908 r
.3455 .53133 .35388 .53922 .36742 .53496 .35908 .52703 Metetra
.664 .741 .908 r
.35908 .52703 .36742 .53496 .38103 .53067 .37272 .5227 Metetra
.664 .741 .908 r
.37272 .5227 .38103 .53067 .3947 .52637 .38644 .51835 Metetra
.664 .741 .908 r
.38644 .51835 .3947 .52637 .40845 .52204 .40023 .51398 Metetra
.664 .741 .908 r
.40023 .51398 .40845 .52204 .42226 .51768 .41409 .50959 Metetra
.664 .741 .908 r
.41409 .50959 .42226 .51768 .43615 .51331 .42802 .50518 Metetra
.664 .741 .908 r
.42802 .50518 .43615 .51331 .45011 .50891 .44203 .50074 Metetra
.664 .741 .908 r
.44203 .50074 .45011 .50891 .46414 .50449 .45611 .49627 Metetra
.664 .741 .908 r
.45611 .49627 .46414 .50449 .47824 .50005 .47026 .49179 Metetra
.664 .741 .908 r
.47026 .49179 .47824 .50005 .49242 .49559 .48448 .48728 Metetra
.664 .741 .908 r
.48448 .48728 .49242 .49559 .50667 .4911 .49878 .48275 Metetra
.664 .741 .908 r
.49878 .48275 .50667 .4911 .52099 .48658 .51315 .47819 Metetra
.664 .741 .908 r
.51315 .47819 .52099 .48658 .53539 .48205 .5276 .47361 Metetra
.96 .65 .397 r
.5276 .47361 .53539 .48205 .55094 .6194 .54289 .61452 Metetra
.732 .213 0 r
.54289 .61452 .55094 .6194 .56638 .636 .55836 .63276 Metetra
.78 .275 0 r
.55836 .63276 .56638 .636 .5821 .65333 .57414 .65259 Metetra
.703 .169 0 r
.57414 .65259 .5821 .65333 .59796 .66421 .59013 .66678 Metetra
.59013 .66678 .59796 .66421 .61367 .66029 .60595 .6629 Metetra
.9 .987 .765 r
.60595 .6629 .61367 .66029 .62906 .64234 .62141 .6425 Metetra
.896 .971 .821 r
.62141 .6425 .62906 .64234 .64447 .6261 .63688 .62443 Metetra
.874 .949 .858 r
.63688 .62443 .64447 .6261 .65993 .61181 .65241 .60863 Metetra
.843 .923 .885 r
.65241 .60863 .65993 .61181 .67546 .59896 .66801 .59504 Metetra
.823 .909 .898 r
.66801 .59504 .67546 .59896 .69107 .58738 .68368 .58265 Metetra
.801 .889 .908 r
.68368 .58265 .69107 .58738 .70674 .57661 .69942 .57141 Metetra
.794 .878 .908 r
.69942 .57141 .70674 .57661 .72126 .54552 .71521 .56047 Metetra
.977 .818 .408 r
.71521 .56047 .72126 .54552 .73238 .46312 .72694 .48259 Metetra
.727 .733 .213 r
.72694 .48259 .73238 .46312 .74578 .42415 .73989 .4326 Metetra
.834 .893 .471 r
.73989 .4326 .74578 .42415 .76082 .41104 .75385 .40194 Metetra
.665 .743 .908 r
.75385 .40194 .76082 .41104 .77651 .4061 .7696 .39691 Metetra
.664 .741 .908 r
.7696 .39691 .77651 .4061 .79228 .40113 .78543 .39189 Metetra
.664 .741 .908 r
.78543 .39189 .79228 .40113 .80814 .39614 .80135 .38684 Metetra
.664 .741 .908 r
.80135 .38684 .80814 .39614 .82409 .39112 .81736 .38177 Metetra
.664 .741 .908 r
.81736 .38177 .82409 .39112 .84012 .38606 .83346 .37667 Metetra
.664 .741 .908 r
.83346 .37667 .84012 .38606 .85624 .38099 .84965 .37154 Metetra
.664 .741 .908 r
.84965 .37154 .85624 .38099 .87246 .37588 .86593 .36638 Metetra
.664 .741 .908 r
.86593 .36638 .87246 .37588 .88876 .37074 .88229 .36119 Metetra
.664 .741 .908 r
.88229 .36119 .88876 .37074 .90516 .36558 .89876 .35597 Metetra
.664 .741 .908 r
.89876 .35597 .90516 .36558 .92164 .36039 .91531 .35072 Metetra
.664 .741 .908 r
.32348 .52769 .33199 .53562 .3455 .53133 .33703 .52337 Metetra
.664 .741 .908 r
.33703 .52337 .3455 .53133 .35908 .52703 .35065 .51903 Metetra
.664 .741 .908 r
.35065 .51903 .35908 .52703 .37272 .5227 .36434 .51466 Metetra
.664 .741 .908 r
.36434 .51466 .37272 .5227 .38644 .51835 .37811 .51027 Metetra
.664 .741 .908 r
.37811 .51027 .38644 .51835 .40023 .51398 .39194 .50586 Metetra
.664 .741 .908 r
.39194 .50586 .40023 .51398 .41409 .50959 .40584 .50142 Metetra
.664 .741 .908 r
.40584 .50142 .41409 .50959 .42802 .50518 .41982 .49696 Metetra
.664 .741 .908 r
.41982 .49696 .42802 .50518 .44203 .50074 .43387 .49248 Metetra
.664 .741 .908 r
.43387 .49248 .44203 .50074 .45611 .49627 .44799 .48798 Metetra
.664 .741 .908 r
.44799 .48798 .45611 .49627 .47026 .49179 .46219 .48345 Metetra
.664 .741 .908 r
.46219 .48345 .47026 .49179 .48448 .48728 .47646 .47889 Metetra
.664 .741 .908 r
.47646 .47889 .48448 .48728 .49878 .48275 .49081 .47432 Metetra
.664 .741 .908 r
.49081 .47432 .49878 .48275 .51315 .47819 .50523 .46972 Metetra
.662 .741 .908 r
.50523 .46972 .51315 .47819 .5276 .47361 .51973 .46514 Metetra
.96 .651 .399 r
.51973 .46514 .5276 .47361 .54289 .61452 .53474 .60942 Metetra
.767 .262 0 r
.53474 .60942 .54289 .61452 .55836 .63276 .55024 .62972 Metetra
.819 .338 .024 r
.55024 .62972 .55836 .63276 .57414 .65259 .56609 .65283 Metetra
.535 .922 .908 r
.56609 .65283 .57414 .65259 .59013 .66678 .58178 .64617 Metetra
.643 .576 .765 r
.58178 .64617 .59013 .66678 .60595 .6629 .59758 .6409 Metetra
.53 .504 .771 r
.59758 .6409 .60595 .6629 .62141 .6425 .61365 .64315 Metetra
.92 .963 .788 r
.61365 .64315 .62141 .6425 .63688 .62443 .62918 .62232 Metetra
.883 .937 .848 r
.62918 .62232 .63688 .62443 .65241 .60863 .64479 .60567 Metetra
.859 .926 .871 r
.64479 .60567 .65241 .60863 .66801 .59504 .66045 .59084 Metetra
.83 .902 .89 r
.66045 .59084 .66801 .59504 .68368 .58265 .6762 .57789 Metetra
.81 .89 .901 r
.6762 .57789 .68368 .58265 .69942 .57141 .69201 .56605 Metetra
.794 .876 .907 r
.69201 .56605 .69942 .57141 .71521 .56047 .70789 .55506 Metetra
.907 .86 .783 r
.70789 .55506 .71521 .56047 .72694 .48259 .72318 .53343 Metetra
0 0 .103 r
.72318 .53343 .72694 .48259 .73989 .4326 .73401 .44335 Metetra
.879 .866 .421 r
.73401 .44335 .73989 .4326 .75385 .40194 .74753 .40306 Metetra
.82 1 .803 r
.74753 .40306 .75385 .40194 .7696 .39691 .76262 .38762 Metetra
.664 .741 .908 r
.76262 .38762 .7696 .39691 .78543 .39189 .77851 .38255 Metetra
.664 .741 .908 r
.77851 .38255 .78543 .39189 .80135 .38684 .79449 .37745 Metetra
.664 .741 .908 r
.79449 .37745 .80135 .38684 .81736 .38177 .81057 .37233 Metetra
.664 .741 .908 r
.81057 .37233 .81736 .38177 .83346 .37667 .82673 .36717 Metetra
.664 .741 .908 r
.82673 .36717 .83346 .37667 .84965 .37154 .84298 .36199 Metetra
.664 .741 .908 r
.84298 .36199 .84965 .37154 .86593 .36638 .85932 .35677 Metetra
.664 .741 .908 r
.85932 .35677 .86593 .36638 .88229 .36119 .87576 .35153 Metetra
.664 .741 .908 r
.87576 .35153 .88229 .36119 .89876 .35597 .89229 .34626 Metetra
.664 .741 .908 r
.89229 .34626 .89876 .35597 .91531 .35072 .90891 .34096 Metetra
.664 .741 .908 r
.31489 .5197 .32348 .52769 .33703 .52337 .32848 .51533 Metetra
.664 .741 .908 r
.32848 .51533 .33703 .52337 .35065 .51903 .34215 .51095 Metetra
.664 .741 .908 r
.34215 .51095 .35065 .51903 .36434 .51466 .35588 .50654 Metetra
.664 .741 .908 r
.35588 .50654 .36434 .51466 .37811 .51027 .36969 .5021 Metetra
.664 .741 .908 r
.36969 .5021 .37811 .51027 .39194 .50586 .38357 .49765 Metetra
.664 .741 .908 r
.38357 .49765 .39194 .50586 .40584 .50142 .39752 .49317 Metetra
.664 .741 .908 r
.39752 .49317 .40584 .50142 .41982 .49696 .41154 .48867 Metetra
.664 .741 .908 r
.41154 .48867 .41982 .49696 .43387 .49248 .42564 .48415 Metetra
.664 .741 .908 r
.42564 .48415 .43387 .49248 .44799 .48798 .43981 .4796 Metetra
.664 .741 .908 r
.43981 .4796 .44799 .48798 .46219 .48345 .45405 .47502 Metetra
.664 .741 .908 r
.45405 .47502 .46219 .48345 .47646 .47889 .46837 .47043 Metetra
.664 .741 .908 r
.46837 .47043 .47646 .47889 .49081 .47432 .48277 .46581 Metetra
.664 .741 .908 r
.48277 .46581 .49081 .47432 .50523 .46972 .49724 .46116 Metetra
.274 .565 .934 r
.49724 .46116 .50523 .46972 .51973 .46514 .51175 .46531 Metetra
.944 .636 .421 r
.51175 .46531 .51973 .46514 .53474 .60942 .52649 .60405 Metetra
.798 .307 0 r
.52649 .60405 .53474 .60942 .55024 .62972 .54201 .6266 Metetra
.847 .387 .08 r
.54201 .6266 .55024 .62972 .56609 .65283 .55791 .65329 Metetra
.967 .886 .698 r
.55791 .65329 .56609 .65283 .58178 .64617 .57334 .62076 Metetra
.634 .541 .732 r
.57334 .62076 .58178 .64617 .59758 .6409 .58912 .61522 Metetra
.022 .149 .658 r
.58912 .61522 .59758 .6409 .61365 .64315 .60568 .63987 Metetra
.898 .899 .819 r
.60568 .63987 .61365 .64315 .62918 .62232 .62138 .62084 Metetra
.898 .943 .83 r
.62138 .62084 .62918 .62232 .64479 .60567 .63707 .60264 Metetra
.872 .922 .857 r
.63707 .60264 .64479 .60567 .66045 .59084 .6528 .5867 Metetra
.84 .904 .881 r
.6528 .5867 .66045 .59084 .6762 .57789 .66862 .57297 Metetra
.82 .887 .892 r
.66862 .57297 .6762 .57789 .69201 .56605 .68449 .56042 Metetra
.799 .87 .901 r
.68449 .56042 .69201 .56605 .70789 .55506 .70045 .54904 Metetra
.795 .862 .899 r
.70045 .54904 .70789 .55506 .72318 .53343 .71645 .53778 Metetra
.999 .802 .499 r
.71645 .53778 .72318 .53343 .73401 .44335 .72824 .45818 Metetra
.86 .821 .341 r
.72824 .45818 .73401 .44335 .74753 .40306 .74137 .40837 Metetra
.92 .939 .58 r
.74137 .40837 .74753 .40306 .76262 .38762 .75556 .37828 Metetra
.665 .743 .908 r
.75556 .37828 .76262 .38762 .77851 .38255 .77152 .37312 Metetra
.664 .741 .908 r
.77152 .37312 .77851 .38255 .79449 .37745 .78756 .36797 Metetra
.664 .741 .908 r
.78756 .36797 .79449 .37745 .81057 .37233 .8037 .36279 Metetra
.664 .741 .908 r
.8037 .36279 .81057 .37233 .82673 .36717 .81993 .35758 Metetra
.664 .741 .908 r
.81993 .35758 .82673 .36717 .84298 .36199 .83625 .35234 Metetra
.664 .741 .908 r
.83625 .35234 .84298 .36199 .85932 .35677 .85266 .34707 Metetra
.664 .741 .908 r
.85266 .34707 .85932 .35677 .87576 .35153 .86916 .34178 Metetra
.664 .741 .908 r
.86916 .34178 .87576 .35153 .89229 .34626 .88576 .33645 Metetra
.664 .741 .908 r
.88576 .33645 .89229 .34626 .90891 .34096 .90245 .33109 Metetra
.664 .741 .908 r
.30622 .51162 .31489 .5197 .32848 .51533 .31985 .50722 Metetra
.664 .741 .908 r
.31985 .50722 .32848 .51533 .34215 .51095 .33356 .50279 Metetra
.664 .741 .908 r
.33356 .50279 .34215 .51095 .35588 .50654 .34734 .49834 Metetra
.664 .741 .908 r
.34734 .49834 .35588 .50654 .36969 .5021 .36119 .49386 Metetra
.664 .741 .908 r
.36119 .49386 .36969 .5021 .38357 .49765 .37511 .48936 Metetra
.664 .741 .908 r
.37511 .48936 .38357 .49765 .39752 .49317 .38911 .48484 Metetra
.664 .741 .908 r
.38911 .48484 .39752 .49317 .41154 .48867 .40318 .4803 Metetra
.664 .741 .908 r
.40318 .4803 .41154 .48867 .42564 .48415 .41732 .47573 Metetra
.664 .741 .908 r
.41732 .47573 .42564 .48415 .43981 .4796 .43154 .47114 Metetra
.664 .741 .908 r
.43154 .47114 .43981 .4796 .45405 .47502 .44583 .46652 Metetra
.664 .741 .908 r
.44583 .46652 .45405 .47502 .46837 .47043 .4602 .46188 Metetra
.664 .741 .908 r
.4602 .46188 .46837 .47043 .48277 .46581 .47464 .45721 Metetra
.664 .741 .908 r
.47464 .45721 .48277 .46581 .49724 .46116 .48916 .45252 Metetra
.568 .078 0 r
.48916 .45252 .49724 .46116 .51175 .46531 .50363 .46909 Metetra
.936 .625 .427 r
.50363 .46909 .51175 .46531 .52649 .60405 .51813 .59853 Metetra
.822 .346 0 r
.51813 .59853 .52649 .60405 .54201 .6266 .53367 .62329 Metetra
.705 .168 0 r
.53367 .62329 .54201 .6266 .55791 .65329 .5495 .63927 Metetra
.9 .719 .648 r
.5495 .63927 .55791 .65329 .57334 .62076 .56486 .59167 Metetra
.631 .522 .711 r
.56486 .59167 .57334 .62076 .58912 .61522 .58059 .58567 Metetra
0 .011 .566 r
.58059 .58567 .58912 .61522 .60568 .63987 .59724 .61956 Metetra
.565 .54 .786 r
.59724 .61956 .60568 .63987 .62138 .62084 .61347 .61937 Metetra
.913 .935 .81 r
.61347 .61937 .62138 .62084 .63707 .60264 .62923 .59943 Metetra
.882 .915 .844 r
.62923 .59943 .63707 .60264 .6528 .5867 .64504 .58237 Metetra
.85 .899 .871 r
.64504 .58237 .6528 .5867 .66862 .57297 .66093 .5678 Metetra
.827 .882 .883 r
.66093 .5678 .66862 .57297 .68449 .56042 .67688 .55465 Metetra
.805 .869 .895 r
.67688 .55465 .68449 .56042 .70045 .54904 .69291 .54278 Metetra
.79 .857 .9 r
.69291 .54278 .70045 .54904 .71645 .53778 .70901 .53172 Metetra
.954 .815 .668 r
.70901 .53172 .71645 .53778 .72824 .45818 .72352 .49352 Metetra
.72352 .49352 .72824 .45818 .74137 .40837 .73515 .41458 Metetra
.959 .906 .536 r
.73515 .41458 .74137 .40837 .75556 .37828 .74892 .37562 Metetra
.812 .957 .909 r
.74892 .37562 .75556 .37828 .77152 .37312 .76445 .36359 Metetra
.664 .741 .908 r
.76445 .36359 .77152 .37312 .78756 .36797 .78056 .35838 Metetra
.664 .741 .908 r
.78056 .35838 .78756 .36797 .8037 .36279 .79676 .35315 Metetra
.664 .741 .908 r
.79676 .35315 .8037 .36279 .81993 .35758 .81306 .34789 Metetra
.664 .741 .908 r
.81306 .34789 .81993 .35758 .83625 .35234 .82944 .34259 Metetra
.664 .741 .908 r
.82944 .34259 .83625 .35234 .85266 .34707 .84592 .33727 Metetra
.664 .741 .908 r
.84592 .33727 .85266 .34707 .86916 .34178 .86249 .33192 Metetra
.664 .741 .908 r
.86249 .33192 .86916 .34178 .88576 .33645 .87915 .32653 Metetra
.664 .741 .908 r
.87915 .32653 .88576 .33645 .90245 .33109 .89591 .32112 Metetra
.664 .741 .908 r
.29746 .50347 .30622 .51162 .31985 .50722 .31114 .49902 Metetra
.664 .741 .908 r
.31114 .49902 .31985 .50722 .33356 .50279 .32489 .49455 Metetra
.664 .741 .908 r
.32489 .49455 .33356 .50279 .34734 .49834 .33872 .49006 Metetra
.664 .741 .908 r
.33872 .49006 .34734 .49834 .36119 .49386 .35261 .48554 Metetra
.664 .741 .908 r
.35261 .48554 .36119 .49386 .37511 .48936 .36658 .481 Metetra
.664 .741 .908 r
.36658 .481 .37511 .48936 .38911 .48484 .38062 .47643 Metetra
.664 .741 .908 r
.38062 .47643 .38911 .48484 .40318 .4803 .39473 .47184 Metetra
.664 .741 .908 r
.39473 .47184 .40318 .4803 .41732 .47573 .40892 .46723 Metetra
.664 .741 .908 r
.40892 .46723 .41732 .47573 .43154 .47114 .42319 .46259 Metetra
.664 .741 .908 r
.42319 .46259 .43154 .47114 .44583 .46652 .43753 .45793 Metetra
.664 .741 .908 r
.43753 .45793 .44583 .46652 .4602 .46188 .45194 .45324 Metetra
.664 .741 .908 r
.45194 .45324 .4602 .46188 .47464 .45721 .46644 .44853 Metetra
.664 .741 .908 r
.46644 .44853 .47464 .45721 .48916 .45252 .48101 .44379 Metetra
.851 .408 0 r
.48101 .44379 .48916 .45252 .50363 .46909 .49536 .47292 Metetra
.934 .62 .422 r
.49536 .47292 .50363 .46909 .51813 .59853 .50968 .59274 Metetra
.836 .368 0 r
.50968 .59274 .51813 .59853 .53367 .62329 .52521 .61915 Metetra
.32 .737 .977 r
.52521 .61915 .53367 .62329 .5495 .63927 .541 .61918 Metetra
.891 .687 .62 r
.541 .61918 .5495 .63927 .56486 .59167 .55634 .55763 Metetra
.629 .502 .689 r
.55634 .55763 .56486 .59167 .58059 .58567 .572 .55083 Metetra
0 0 .452 r
.572 .55083 .58059 .58567 .59724 .61956 .58874 .59751 Metetra
.048 .201 .701 r
.58874 .59751 .59724 .61956 .61347 .61937 .60543 .61766 Metetra
.927 .919 .787 r
.60543 .61766 .61347 .61937 .62923 .59943 .62126 .59538 Metetra
.883 .895 .835 r
.62126 .59538 .62923 .59943 .64504 .58237 .63717 .57775 Metetra
.86 .891 .857 r
.63717 .57775 .64504 .58237 .66093 .5678 .65313 .56213 Metetra
.829 .871 .875 r
.65313 .56213 .66093 .5678 .67688 .55465 .66916 .54858 Metetra
.812 .863 .886 r
.66916 .54858 .67688 .55465 .69291 .54278 .68526 .53614 Metetra
.792 .849 .894 r
.68526 .53614 .69291 .54278 .70901 .53172 .70144 .52479 Metetra
.812 .846 .875 r
.70144 .52479 .70901 .53172 .72352 .49352 .71757 .51203 Metetra
.965 .799 .365 r
.71757 .51203 .72352 .49352 .73515 .41458 .72885 .42181 Metetra
.968 .886 .507 r
.72885 .42181 .73515 .41458 .74892 .37562 .74243 .37671 Metetra
.927 .973 .73 r
.74243 .37671 .74892 .37562 .76445 .36359 .75732 .35397 Metetra
.664 .742 .908 r
.75732 .35397 .76445 .36359 .78056 .35838 .77349 .3487 Metetra
.664 .741 .908 r
.77349 .3487 .78056 .35838 .79676 .35315 .78976 .34341 Metetra
.664 .741 .908 r
.78976 .34341 .79676 .35315 .81306 .34789 .80611 .33809 Metetra
.664 .741 .908 r
.80611 .33809 .81306 .34789 .82944 .34259 .82256 .33274 Metetra
.664 .741 .908 r
.82256 .33274 .82944 .34259 .84592 .33727 .83911 .32736 Metetra
.664 .741 .908 r
.83911 .32736 .84592 .33727 .86249 .33192 .85575 .32195 Metetra
.664 .741 .908 r
.85575 .32195 .86249 .33192 .87915 .32653 .87248 .31651 Metetra
.664 .741 .908 r
.87248 .31651 .87915 .32653 .89591 .32112 .88931 .31104 Metetra
.664 .741 .908 r
.28862 .49524 .29746 .50347 .31114 .49902 .30235 .49075 Metetra
.664 .741 .908 r
.30235 .49075 .31114 .49902 .32489 .49455 .31614 .48624 Metetra
.664 .741 .908 r
.31614 .48624 .32489 .49455 .33872 .49006 .33001 .4817 Metetra
.664 .741 .908 r
.33001 .4817 .33872 .49006 .35261 .48554 .34395 .47714 Metetra
.664 .741 .908 r
.34395 .47714 .35261 .48554 .36658 .481 .35796 .47255 Metetra
.664 .741 .908 r
.35796 .47255 .36658 .481 .38062 .47643 .37205 .46794 Metetra
.664 .741 .908 r
.37205 .46794 .38062 .47643 .39473 .47184 .38621 .46331 Metetra
.664 .741 .908 r
.38621 .46331 .39473 .47184 .40892 .46723 .40044 .45865 Metetra
.664 .741 .908 r
.40044 .45865 .40892 .46723 .42319 .46259 .41476 .45397 Metetra
.664 .741 .908 r
.41476 .45397 .42319 .46259 .43753 .45793 .42914 .44926 Metetra
.664 .741 .908 r
.42914 .44926 .43753 .45793 .45194 .45324 .44361 .44452 Metetra
.664 .741 .908 r
.44361 .44452 .45194 .45324 .46644 .44853 .45815 .43976 Metetra
.664 .741 .908 r
.45815 .43976 .46644 .44853 .48101 .44379 .47277 .43498 Metetra
.917 .52 .162 r
.47277 .43498 .48101 .44379 .49536 .47292 .48694 .47651 Metetra
.932 .614 .416 r
.48694 .47651 .49536 .47292 .50968 .59274 .50113 .58663 Metetra
.851 .394 .029 r
.50113 .58663 .50968 .59274 .52521 .61915 .51665 .61515 Metetra
.867 .885 .847 r
.51665 .61515 .52521 .61915 .541 .61918 .53246 .59892 Metetra
.912 .691 .591 r
.53246 .59892 .541 .61918 .55634 .55763 .5478 .51519 Metetra
.64 .488 .661 r
.5478 .51519 .55634 .55763 .572 .55083 .56333 .50466 Metetra
0 0 .326 r
.56333 .50466 .572 .55083 .58874 .59751 .5802 .57451 Metetra
0 0 .497 r
.5802 .57451 .58874 .59751 .60543 .61766 .5971 .60741 Metetra
.817 .77 .808 r
.5971 .60741 .60543 .61766 .62126 .59538 .61319 .59152 Metetra
.893 .897 .824 r
.61319 .59152 .62126 .59538 .63717 .57775 .62918 .57272 Metetra
.865 .881 .846 r
.62918 .57272 .63717 .57775 .65313 .56213 .64522 .5563 Metetra
.835 .868 .868 r
.64522 .5563 .65313 .56213 .66916 .54858 .66134 .54217 Metetra
.816 .856 .879 r
.66134 .54217 .66916 .54858 .68526 .53614 .67751 .52927 Metetra
.796 .846 .889 r
.67751 .52927 .68526 .53614 .70144 .52479 .69377 .51756 Metetra
.783 .837 .893 r
.69377 .51756 .70144 .52479 .71757 .51203 .71009 .50651 Metetra
.98 .768 .547 r
.71009 .50651 .71757 .51203 .72885 .42181 .72244 .42943 Metetra
.981 .867 .493 r
.72244 .42943 .72885 .42181 .74243 .37671 .73579 .37732 Metetra
.98 .912 .653 r
.73579 .37732 .74243 .37671 .75732 .35397 .75011 .34428 Metetra
.665 .743 .908 r
.75011 .34428 .75732 .35397 .77349 .3487 .76634 .33891 Metetra
.664 .741 .908 r
.76634 .33891 .77349 .3487 .78976 .34341 .78267 .33357 Metetra
.664 .741 .908 r
.78267 .33357 .78976 .34341 .80611 .33809 .7991 .32819 Metetra
.664 .741 .908 r
.7991 .32819 .80611 .33809 .82256 .33274 .81561 .32279 Metetra
.664 .741 .908 r
.81561 .32279 .82256 .33274 .83911 .32736 .83222 .31735 Metetra
.664 .741 .908 r
.83222 .31735 .83911 .32736 .85575 .32195 .84893 .31188 Metetra
.664 .741 .908 r
.84893 .31188 .85575 .32195 .87248 .31651 .86574 .30638 Metetra
.664 .741 .908 r
.86574 .30638 .87248 .31651 .88931 .31104 .88264 .30085 Metetra
.664 .741 .908 r
.2797 .48693 .28862 .49524 .30235 .49075 .29347 .4824 Metetra
.664 .741 .908 r
.29347 .4824 .30235 .49075 .31614 .48624 .3073 .47784 Metetra
.664 .741 .908 r
.3073 .47784 .31614 .48624 .33001 .4817 .32121 .47326 Metetra
.664 .741 .908 r
.32121 .47326 .33001 .4817 .34395 .47714 .3352 .46865 Metetra
.664 .741 .908 r
.3352 .46865 .34395 .47714 .35796 .47255 .34926 .46402 Metetra
.664 .741 .908 r
.34926 .46402 .35796 .47255 .37205 .46794 .36339 .45937 Metetra
.664 .741 .908 r
.36339 .45937 .37205 .46794 .38621 .46331 .3776 .45469 Metetra
.664 .741 .908 r
.3776 .45469 .38621 .46331 .40044 .45865 .39188 .44998 Metetra
.664 .741 .908 r
.39188 .44998 .40044 .45865 .41476 .45397 .40624 .44525 Metetra
.664 .741 .908 r
.40624 .44525 .41476 .45397 .42914 .44926 .42068 .4405 Metetra
.664 .741 .908 r
.42068 .4405 .42914 .44926 .44361 .44452 .43519 .43572 Metetra
.664 .741 .908 r
.43519 .43572 .44361 .44452 .45815 .43976 .44978 .43091 Metetra
.664 .741 .908 r
.44978 .43091 .45815 .43976 .47277 .43498 .46446 .42608 Metetra
.94 .572 .25 r
.46446 .42608 .47277 .43498 .48694 .47651 .47837 .48061 Metetra
.927 .605 .41 r
.47837 .48061 .48694 .47651 .50113 .58663 .49248 .58013 Metetra
.863 .415 .05 r
.49248 .58013 .50113 .58663 .51665 .61515 .50797 .61065 Metetra
.937 .821 .706 r
.50797 .61065 .51665 .61515 .53246 .59892 .5239 .57728 Metetra
.929 .691 .556 r
.5239 .57728 .53246 .59892 .5478 .51519 .53923 .44802 Metetra
.613 .437 .62 r
.53923 .44802 .5478 .51519 .56333 .50466 .55455 .43712 Metetra
0 0 .197 r
.55455 .43712 .56333 .50466 .5802 .57451 .57165 .55196 Metetra
0 0 .355 r
.57165 .55196 .5802 .57451 .5971 .60741 .58857 .59119 Metetra
.629 .621 .824 r
.58857 .59119 .5971 .60741 .61319 .59152 .605 .58713 Metetra
.897 .883 .811 r
.605 .58713 .61319 .59152 .62918 .57272 .62108 .56719 Metetra
.868 .87 .836 r
.62108 .56719 .62918 .57272 .64522 .5563 .6372 .55003 Metetra
.838 .859 .86 r
.6372 .55003 .64522 .5563 .66134 .54217 .6534 .53534 Metetra
.818 .848 .871 r
.6534 .53534 .66134 .54217 .67751 .52927 .66966 .52202 Metetra
.798 .839 .882 r
.66966 .52202 .67751 .52927 .69377 .51756 .68599 .50998 Metetra
.784 .831 .889 r
.68599 .50998 .69377 .51756 .71009 .50651 .70239 .49874 Metetra
.958 .787 .627 r
.70239 .49874 .71009 .50651 .72244 .42943 .71666 .4503 Metetra
.889 .787 .296 r
.71666 .4503 .72244 .42943 .73579 .37732 .72902 .37757 Metetra
.988 .886 .625 r
.72902 .37757 .73579 .37732 .75011 .34428 .74315 .33914 Metetra
.775 .895 .928 r
.74315 .33914 .75011 .34428 .76634 .33891 .75912 .32902 Metetra
.664 .741 .908 r
.75912 .32902 .76634 .33891 .78267 .33357 .77552 .32362 Metetra
.664 .741 .908 r
.77552 .32362 .78267 .33357 .7991 .32819 .79201 .31819 Metetra
.664 .741 .908 r
.79201 .31819 .7991 .32819 .81561 .32279 .80859 .31273 Metetra
.664 .741 .908 r
.80859 .31273 .81561 .32279 .83222 .31735 .82527 .30723 Metetra
.664 .741 .908 r
.82527 .30723 .83222 .31735 .84893 .31188 .84205 .30171 Metetra
.664 .741 .908 r
.84205 .30171 .84893 .31188 .86574 .30638 .85892 .29615 Metetra
.664 .741 .908 r
.85892 .29615 .86574 .30638 .88264 .30085 .87589 .29056 Metetra
.664 .741 .908 r
.27069 .47854 .2797 .48693 .29347 .4824 .2845 .47397 Metetra
.664 .741 .908 r
.2845 .47397 .29347 .4824 .3073 .47784 .29838 .46936 Metetra
.664 .741 .908 r
.29838 .46936 .3073 .47784 .32121 .47326 .31234 .46474 Metetra
.664 .741 .908 r
.31234 .46474 .32121 .47326 .3352 .46865 .32636 .46009 Metetra
.664 .741 .908 r
.32636 .46009 .3352 .46865 .34926 .46402 .34047 .45541 Metetra
.664 .741 .908 r
.34047 .45541 .34926 .46402 .36339 .45937 .35465 .45071 Metetra
.664 .741 .908 r
.35465 .45071 .36339 .45937 .3776 .45469 .3689 .44598 Metetra
.664 .741 .908 r
.3689 .44598 .3776 .45469 .39188 .44998 .38323 .44123 Metetra
.664 .741 .908 r
.38323 .44123 .39188 .44998 .40624 .44525 .39764 .43645 Metetra
.664 .741 .908 r
.39764 .43645 .40624 .44525 .42068 .4405 .41213 .43165 Metetra
.664 .741 .908 r
.41213 .43165 .42068 .4405 .43519 .43572 .42669 .42682 Metetra
.664 .741 .908 r
.42669 .42682 .43519 .43572 .44978 .43091 .44133 .42197 Metetra
.664 .741 .908 r
.44133 .42197 .44978 .43091 .46446 .42608 .45606 .41709 Metetra
.948 .597 .296 r
.45606 .41709 .46446 .42608 .47837 .48061 .46968 .48296 Metetra
.929 .6 .396 r
.46968 .48296 .47837 .48061 .49248 .58013 .48373 .57319 Metetra
.872 .431 .065 r
.48373 .57319 .49248 .58013 .50797 .61065 .49918 .6055 Metetra
.949 .787 .647 r
.49918 .6055 .50797 .61065 .5239 .57728 .5153 .5575 Metetra
.941 .695 .537 r
.5153 .5575 .5239 .57728 .53923 .44802 .53089 .39228 Metetra
.591 .432 .634 r
.53089 .39228 .53923 .44802 .55455 .43712 .5461 .38723 Metetra
.893 .619 .108 r
.5461 .38723 .55455 .43712 .57165 .55196 .56306 .52773 Metetra
0 0 .242 r
.56306 .52773 .57165 .55196 .58857 .59119 .58 .57517 Metetra
.347 .474 .846 r
.58 .57517 .58857 .59119 .605 .58713 .59668 .582 Metetra
.902 .865 .794 r
.59668 .582 .605 .58713 .62108 .56719 .61284 .56049 Metetra
.86 .846 .829 r
.61284 .56049 .62108 .56719 .6372 .55003 .62907 .54323 Metetra
.842 .848 .849 r
.62907 .54323 .6372 .55003 .6534 .53534 .64535 .52784 Metetra
.815 .834 .864 r
.64535 .52784 .6534 .53534 .66966 .52202 .66169 .51436 Metetra
.799 .831 .876 r
.66169 .51436 .66966 .52202 .68599 .50998 .67811 .50201 Metetra
.785 .824 .883 r
.67811 .50201 .68599 .50998 .70239 .49874 .69459 .49053 Metetra
.889 .822 .775 r
.69459 .49053 .70239 .49874 .71666 .4503 .7105 .4682 Metetra
.969 .799 .371 r
.7105 .4682 .71666 .4503 .72902 .37757 .72204 .37625 Metetra
.988 .862 .624 r
.72204 .37625 .72902 .37757 .74315 .33914 .73616 .33501 Metetra
.874 .922 .855 r
.73616 .33501 .74315 .33914 .75912 .32902 .75182 .31903 Metetra
.664 .741 .908 r
.75182 .31903 .75912 .32902 .77552 .32362 .76828 .31357 Metetra
.664 .741 .908 r
.76828 .31357 .77552 .32362 .79201 .31819 .78484 .30808 Metetra
.664 .741 .908 r
.78484 .30808 .79201 .31819 .80859 .31273 .80149 .30256 Metetra
.664 .741 .908 r
.80149 .30256 .80859 .31273 .82527 .30723 .81824 .29701 Metetra
.664 .741 .908 r
.81824 .29701 .82527 .30723 .84205 .30171 .83509 .29142 Metetra
.664 .741 .908 r
.83509 .29142 .84205 .30171 .85892 .29615 .85203 .2858 Metetra
.664 .741 .908 r
.85203 .2858 .85892 .29615 .87589 .29056 .86907 .28015 Metetra
.664 .741 .908 r
.26159 .47007 .27069 .47854 .2845 .47397 .27545 .46545 Metetra
.664 .741 .908 r
.27545 .46545 .2845 .47397 .29838 .46936 .28937 .4608 Metetra
.664 .741 .908 r
.28937 .4608 .29838 .46936 .31234 .46474 .30337 .45613 Metetra
.664 .741 .908 r
.30337 .45613 .31234 .46474 .32636 .46009 .31744 .45143 Metetra
.664 .741 .908 r
.31744 .45143 .32636 .46009 .34047 .45541 .33159 .44671 Metetra
.664 .741 .908 r
.33159 .44671 .34047 .45541 .35465 .45071 .34582 .44196 Metetra
.664 .741 .908 r
.34582 .44196 .35465 .45071 .3689 .44598 .36012 .43719 Metetra
.664 .741 .908 r
.36012 .43719 .3689 .44598 .38323 .44123 .3745 .43239 Metetra
.664 .741 .908 r
.3745 .43239 .38323 .44123 .39764 .43645 .38896 .42757 Metetra
.664 .741 .908 r
.38896 .42757 .39764 .43645 .41213 .43165 .40349 .42272 Metetra
.664 .741 .908 r
.40349 .42272 .41213 .43165 .42669 .42682 .4181 .41784 Metetra
.664 .741 .908 r
.4181 .41784 .42669 .42682 .44133 .42197 .4328 .41294 Metetra
.664 .741 .908 r
.4328 .41294 .44133 .42197 .45606 .41709 .44757 .40801 Metetra
.953 .615 .331 r
.44757 .40801 .45606 .41709 .46968 .48296 .4608 .4871 Metetra
.918 .583 .391 r
.4608 .4871 .46968 .48296 .48373 .57319 .47489 .56578 Metetra
.878 .442 .074 r
.47489 .56578 .48373 .57319 .49918 .6055 .49029 .59955 Metetra
.952 .765 .614 r
.49029 .59955 .49918 .6055 .5153 .5575 .50667 .53749 Metetra
.939 .695 .542 r
.50667 .53749 .5153 .5575 .53089 .39228 .52267 .38294 Metetra
.664 .741 .908 r
.52267 .38294 .53089 .39228 .5461 .38723 .53793 .37785 Metetra
.962 .638 .349 r
.53793 .37785 .5461 .38723 .56306 .52773 .55447 .50595 Metetra
.808 .46 0 r
.55447 .50595 .56306 .52773 .58 .57517 .57138 .5603 Metetra
0 .215 .739 r
.57138 .5603 .58 .57517 .59668 .582 .58824 .57599 Metetra
.899 .848 .785 r
.58824 .57599 .59668 .582 .61284 .56049 .6045 .55363 Metetra
.863 .844 .824 r
.6045 .55363 .61284 .56049 .62907 .54323 .62082 .53583 Metetra
.842 .837 .841 r
.62082 .53583 .62907 .54323 .64535 .52784 .63719 .52002 Metetra
.816 .829 .859 r
.63719 .52002 .64535 .52784 .66169 .51436 .65362 .50624 Metetra
.801 .823 .869 r
.65362 .50624 .66169 .51436 .67811 .50201 .67011 .49355 Metetra
.783 .815 .878 r
.67011 .49355 .67811 .50201 .69459 .49053 .68668 .48194 Metetra
.809 .818 .857 r
.68668 .48194 .69459 .49053 .7105 .4682 .70318 .46839 Metetra
.994 .775 .496 r
.70318 .46839 .7105 .4682 .72204 .37625 .71487 .37364 Metetra
.985 .843 .619 r
.71487 .37364 .72204 .37625 .73616 .33501 .72899 .32957 Metetra
.908 .881 .796 r
.72899 .32957 .73616 .33501 .75182 .31903 .74444 .30893 Metetra
.664 .741 .908 r
.74444 .30893 .75182 .31903 .76828 .31357 .76097 .30341 Metetra
.664 .741 .908 r
.76097 .30341 .76828 .31357 .78484 .30808 .7776 .29786 Metetra
.664 .741 .908 r
.7776 .29786 .78484 .30808 .80149 .30256 .79432 .29228 Metetra
.664 .741 .908 r
.79432 .29228 .80149 .30256 .81824 .29701 .81113 .28667 Metetra
.664 .741 .908 r
.81113 .28667 .81824 .29701 .83509 .29142 .82805 .28102 Metetra
.664 .741 .908 r
.82805 .28102 .83509 .29142 .85203 .2858 .84507 .27534 Metetra
.664 .741 .908 r
.84507 .27534 .85203 .2858 .86907 .28015 .86218 .26963 Metetra
.664 .741 .908 r
.25241 .46152 .26159 .47007 .27545 .46545 .2663 .45685 Metetra
.664 .741 .908 r
.2663 .45685 .27545 .46545 .28937 .4608 .28027 .45216 Metetra
.664 .741 .908 r
.28027 .45216 .28937 .4608 .30337 .45613 .29432 .44744 Metetra
.664 .741 .908 r
.29432 .44744 .30337 .45613 .31744 .45143 .30844 .4427 Metetra
.664 .741 .908 r
.30844 .4427 .31744 .45143 .33159 .44671 .32263 .43793 Metetra
.664 .741 .908 r
.32263 .43793 .33159 .44671 .34582 .44196 .3369 .43313 Metetra
.664 .741 .908 r
.3369 .43313 .34582 .44196 .36012 .43719 .35125 .42831 Metetra
.664 .741 .908 r
.35125 .42831 .36012 .43719 .3745 .43239 .36568 .42346 Metetra
.664 .741 .908 r
.36568 .42346 .3745 .43239 .38896 .42757 .38018 .41859 Metetra
.664 .741 .908 r
.38018 .41859 .38896 .42757 .40349 .42272 .39477 .41369 Metetra
.664 .741 .908 r
.39477 .41369 .40349 .42272 .4181 .41784 .40943 .40877 Metetra
.664 .741 .908 r
.40943 .40877 .4181 .41784 .4328 .41294 .42417 .40381 Metetra
.664 .741 .908 r
.42417 .40381 .4328 .41294 .44757 .40801 .439 .39883 Metetra
.956 .627 .355 r
.439 .39883 .44757 .40801 .4608 .4871 .45176 .4912 Metetra
.91 .564 .375 r
.45176 .4912 .4608 .4871 .47489 .56578 .46595 .55784 Metetra
.881 .449 .075 r
.46595 .55784 .47489 .56578 .49029 .59955 .4813 .59265 Metetra
.952 .751 .597 r
.4813 .59265 .49029 .59955 .50667 .53749 .49798 .52015 Metetra
.942 .7 .542 r
.49798 .52015 .50667 .53749 .52267 .38294 .51436 .37351 Metetra
.664 .741 .908 r
.51436 .37351 .52267 .38294 .53793 .37785 .52969 .36836 Metetra
.961 .634 .341 r
.52969 .36836 .53793 .37785 .55447 .50595 .54589 .48803 Metetra
.892 .525 .055 r
.54589 .48803 .55447 .50595 .57138 .5603 .56272 .54719 Metetra
0 0 .514 r
.56272 .54719 .57138 .5603 .58824 .57599 .57967 .56897 Metetra
.894 .831 .777 r
.57967 .56897 .58824 .57599 .6045 .55363 .59604 .54599 Metetra
.86 .83 .816 r
.59604 .54599 .6045 .55363 .62082 .53583 .61246 .52777 Metetra
.839 .825 .834 r
.61246 .52777 .62082 .53583 .63719 .52002 .62891 .51164 Metetra
.815 .819 .853 r
.62891 .51164 .63719 .52002 .65362 .50624 .64543 .49762 Metetra
.8 .814 .863 r
.64543 .49762 .65362 .50624 .67011 .49355 .66201 .48473 Metetra
.783 .809 .874 r
.66201 .48473 .67011 .49355 .68668 .48194 .67866 .47295 Metetra
.8 .81 .86 r
.67866 .47295 .68668 .48194 .70318 .46839 .69528 .45992 Metetra
.975 .749 .532 r
.69528 .45992 .70318 .46839 .71487 .37364 .70749 .36933 Metetra
.98 .823 .617 r
.70749 .36933 .71487 .37364 .72899 .32957 .72165 .32285 Metetra
.919 .85 .759 r
.72165 .32285 .72899 .32957 .74444 .30893 .73699 .29873 Metetra
.664 .742 .908 r
.73699 .29873 .74444 .30893 .76097 .30341 .75358 .29314 Metetra
.664 .741 .908 r
.75358 .29314 .76097 .30341 .7776 .29786 .77027 .28753 Metetra
.664 .741 .908 r
.77027 .28753 .7776 .29786 .79432 .29228 .78706 .28189 Metetra
.664 .741 .908 r
.78706 .28189 .79432 .29228 .81113 .28667 .80395 .27622 Metetra
.664 .741 .908 r
.80395 .27622 .81113 .28667 .82805 .28102 .82094 .27051 Metetra
.664 .741 .908 r
.82094 .27051 .82805 .28102 .84507 .27534 .83803 .26477 Metetra
.664 .741 .908 r
.83803 .26477 .84507 .27534 .86218 .26963 .85521 .259 Metetra
.664 .741 .908 r
.24313 .45288 .25241 .46152 .2663 .45685 .25707 .44817 Metetra
.664 .741 .908 r
.25707 .44817 .2663 .45685 .28027 .45216 .27108 .44343 Metetra
.664 .741 .908 r
.27108 .44343 .28027 .45216 .29432 .44744 .28517 .43866 Metetra
.664 .741 .908 r
.28517 .43866 .29432 .44744 .30844 .4427 .29934 .43387 Metetra
.664 .741 .908 r
.29934 .43387 .30844 .4427 .32263 .43793 .31358 .42905 Metetra
.664 .741 .908 r
.31358 .42905 .32263 .43793 .3369 .43313 .3279 .42421 Metetra
.664 .741 .908 r
.3279 .42421 .3369 .43313 .35125 .42831 .34229 .41934 Metetra
.664 .741 .908 r
.34229 .41934 .35125 .42831 .36568 .42346 .35677 .41445 Metetra
.664 .741 .908 r
.35677 .41445 .36568 .42346 .38018 .41859 .37132 .40953 Metetra
.664 .741 .908 r
.37132 .40953 .38018 .41859 .39477 .41369 .38595 .40458 Metetra
.664 .741 .908 r
.38595 .40458 .39477 .41369 .40943 .40877 .40067 .3996 Metetra
.664 .741 .908 r
.40067 .3996 .40943 .40877 .42417 .40381 .41546 .3946 Metetra
.664 .741 .908 r
.41546 .3946 .42417 .40381 .439 .39883 .43034 .38956 Metetra
.957 .632 .364 r
.43034 .38956 .439 .39883 .45176 .4912 .44271 .48876 Metetra
.927 .567 .322 r
.44271 .48876 .45176 .4912 .46595 .55784 .45691 .54936 Metetra
.882 .451 .071 r
.45691 .54936 .46595 .55784 .4813 .59265 .47221 .58473 Metetra
.95 .744 .591 r
.47221 .58473 .4813 .59265 .49798 .52015 .4892 .50679 Metetra
.949 .709 .54 r
.4892 .50679 .49798 .52015 .51436 .37351 .50597 .36399 Metetra
.664 .741 .908 r
.50597 .36399 .51436 .37351 .52969 .36836 .52135 .35878 Metetra
.96 .631 .336 r
.52135 .35878 .52969 .36836 .54589 .48803 .53727 .47426 Metetra
.925 .551 .144 r
.53727 .47426 .54589 .48803 .56272 .54719 .554 .53594 Metetra
.646 .189 0 r
.554 .53594 .56272 .54719 .57967 .56897 .57098 .56084 Metetra
.887 .814 .77 r
.57098 .56084 .57967 .56897 .59604 .54599 .58747 .53748 Metetra
.855 .815 .809 r
.58747 .53748 .59604 .54599 .61246 .52777 .60399 .519 Metetra
.836 .812 .827 r
.60399 .519 .61246 .52777 .62891 .51164 .62053 .50266 Metetra
.812 .809 .847 r
.62053 .50266 .62891 .51164 .64543 .49762 .63714 .48848 Metetra
.798 .805 .858 r
.63714 .48848 .64543 .49762 .66201 .48473 .6538 .47544 Metetra
.781 .801 .869 r
.6538 .47544 .66201 .48473 .67866 .47295 .67054 .46355 Metetra
.793 .802 .859 r
.67054 .46355 .67866 .47295 .69528 .45992 .68727 .45073 Metetra
.973 .748 .537 r
.68727 .45073 .69528 .45992 .70749 .36933 .69985 .36212 Metetra
.966 .797 .622 r
.69985 .36212 .70749 .36933 .72165 .32285 .71411 .31435 Metetra
.912 .819 .741 r
.71411 .31435 .72165 .32285 .73699 .29873 .72945 .28842 Metetra
.664 .742 .908 r
.72945 .28842 .73699 .29873 .75358 .29314 .74611 .28276 Metetra
.664 .741 .908 r
.74611 .28276 .75358 .29314 .77027 .28753 .76287 .2771 Metetra
.664 .741 .908 r
.76287 .2771 .77027 .28753 .78706 .28189 .77973 .27139 Metetra
.664 .741 .908 r
.77973 .27139 .78706 .28189 .80395 .27622 .79669 .26566 Metetra
.664 .741 .908 r
.79669 .26566 .80395 .27622 .82094 .27051 .81375 .25989 Metetra
.664 .741 .908 r
.81375 .25989 .82094 .27051 .83803 .26477 .83091 .25409 Metetra
.664 .741 .908 r
.83091 .25409 .83803 .26477 .85521 .259 .84817 .24825 Metetra
.664 .741 .908 r
.23376 .44416 .24313 .45288 .25707 .44817 .24775 .4394 Metetra
.664 .741 .908 r
.24775 .4394 .25707 .44817 .27108 .44343 .2618 .43461 Metetra
.664 .741 .908 r
.2618 .43461 .27108 .44343 .28517 .43866 .27594 .4298 Metetra
.664 .741 .908 r
.27594 .4298 .28517 .43866 .29934 .43387 .29015 .42496 Metetra
.664 .741 .908 r
.29015 .42496 .29934 .43387 .31358 .42905 .30444 .42009 Metetra
.664 .741 .908 r
.30444 .42009 .31358 .42905 .3279 .42421 .3188 .4152 Metetra
.664 .741 .908 r
.3188 .4152 .3279 .42421 .34229 .41934 .33325 .41028 Metetra
.664 .741 .908 r
.33325 .41028 .34229 .41934 .35677 .41445 .34777 .40534 Metetra
.664 .741 .908 r
.34777 .40534 .35677 .41445 .37132 .40953 .36237 .40037 Metetra
.664 .741 .908 r
.36237 .40037 .37132 .40953 .38595 .40458 .37705 .39537 Metetra
.664 .741 .908 r
.37705 .39537 .38595 .40458 .40067 .3996 .39182 .39034 Metetra
.664 .741 .908 r
.39182 .39034 .40067 .3996 .41546 .3946 .40666 .38529 Metetra
.664 .741 .908 r
.40666 .38529 .41546 .3946 .43034 .38956 .42159 .3802 Metetra
.957 .632 .364 r
.42159 .3802 .43034 .38956 .44271 .48876 .43372 .47959 Metetra
.942 .578 .264 r
.43372 .47959 .44271 .48876 .45691 .54936 .44779 .54031 Metetra
.879 .449 .059 r
.44779 .54031 .45691 .54936 .47221 .58473 .46304 .57574 Metetra
.946 .74 .592 r
.46304 .57574 .47221 .58473 .4892 .50679 .48029 .49754 Metetra
.957 .718 .535 r
.48029 .49754 .4892 .50679 .50597 .36399 .49749 .35436 Metetra
.664 .741 .908 r
.49749 .35436 .50597 .36399 .52135 .35878 .51293 .3491 Metetra
.96 .631 .336 r
.51293 .3491 .52135 .35878 .53727 .47426 .52859 .46481 Metetra
.934 .557 .204 r
.52859 .46481 .53727 .47426 .554 .53594 .54521 .52661 Metetra
.712 .233 0 r
.54521 .52661 .554 .53594 .57098 .56084 .56218 .55154 Metetra
.879 .797 .766 r
.56218 .55154 .57098 .56084 .58747 .53748 .57878 .52807 Metetra
.848 .8 .804 r
.57878 .52807 .58747 .53748 .60399 .519 .5954 .5095 Metetra
.831 .8 .822 r
.5954 .5095 .60399 .519 .62053 .50266 .61204 .49307 Metetra
.808 .798 .842 r
.61204 .49307 .62053 .50266 .63714 .48848 .62874 .4788 Metetra
.794 .796 .853 r
.62874 .4788 .63714 .48848 .6538 .47544 .64549 .46569 Metetra
.779 .793 .864 r
.64549 .46569 .6538 .47544 .67054 .46355 .66231 .45372 Metetra
.791 .796 .856 r
.66231 .45372 .67054 .46355 .68727 .45073 .67912 .44082 Metetra
.971 .745 .538 r
.67912 .44082 .68727 .45073 .69985 .36212 .69196 .35194 Metetra
.95 .773 .627 r
.69196 .35194 .69985 .36212 .71411 .31435 .70638 .30402 Metetra
.897 .792 .736 r
.70638 .30402 .71411 .31435 .72945 .28842 .72184 .27799 Metetra
.664 .742 .908 r
.72184 .27799 .72945 .28842 .74611 .28276 .73856 .27227 Metetra
.664 .741 .908 r
.73856 .27227 .74611 .28276 .76287 .2771 .75539 .26654 Metetra
.664 .741 .908 r
.75539 .26654 .76287 .2771 .77973 .27139 .77232 .26078 Metetra
.664 .741 .908 r
.77232 .26078 .77973 .27139 .79669 .26566 .78935 .25498 Metetra
.664 .741 .908 r
.78935 .25498 .79669 .26566 .81375 .25989 .80648 .24915 Metetra
.664 .741 .908 r
.80648 .24915 .81375 .25989 .83091 .25409 .82371 .24328 Metetra
.664 .741 .908 r
.82371 .24328 .83091 .25409 .84817 .24825 .84105 .23738 Metetra
.664 .741 .908 r
.2243 .43535 .23376 .44416 .24775 .4394 .23833 .43054 Metetra
.664 .741 .908 r
.23833 .43054 .24775 .4394 .2618 .43461 .25243 .4257 Metetra
.664 .741 .908 r
.25243 .4257 .2618 .43461 .27594 .4298 .26661 .42084 Metetra
.664 .741 .908 r
.26661 .42084 .27594 .4298 .29015 .42496 .28087 .41596 Metetra
.664 .741 .908 r
.28087 .41596 .29015 .42496 .30444 .42009 .2952 .41104 Metetra
.664 .741 .908 r
.2952 .41104 .30444 .42009 .3188 .4152 .30961 .4061 Metetra
.664 .741 .908 r
.30961 .4061 .3188 .4152 .33325 .41028 .32411 .40113 Metetra
.664 .741 .908 r
.32411 .40113 .33325 .41028 .34777 .40534 .33868 .39614 Metetra
.664 .741 .908 r
.33868 .39614 .34777 .40534 .36237 .40037 .35333 .39112 Metetra
.664 .741 .908 r
.35333 .39112 .36237 .40037 .37705 .39537 .36806 .38606 Metetra
.664 .741 .908 r
.36806 .38606 .37705 .39537 .39182 .39034 .38288 .38099 Metetra
.664 .741 .908 r
.38288 .38099 .39182 .39034 .40666 .38529 .39777 .37588 Metetra
.664 .741 .908 r
.39777 .37588 .40666 .38529 .42159 .3802 .41275 .37074 Metetra
.956 .627 .355 r
.41275 .37074 .42159 .3802 .43372 .47959 .42483 .46364 Metetra
.948 .595 .221 r
.42483 .46364 .43372 .47959 .44779 .54031 .43858 .53069 Metetra
.873 .442 .04 r
.43858 .53069 .44779 .54031 .46304 .57574 .45378 .56567 Metetra
.941 .738 .6 r
.45378 .56567 .46304 .57574 .48029 .49754 .47121 .49245 Metetra
.964 .726 .528 r
.47121 .49245 .48029 .49754 .49749 .35436 .48892 .34463 Metetra
.664 .741 .908 r
.48892 .34463 .49749 .35436 .51293 .3491 .50442 .33932 Metetra
.961 .634 .341 r
.50442 .33932 .51293 .3491 .52859 .46481 .5198 .45971 Metetra
.929 .548 .244 r
.5198 .45971 .52859 .46481 .54521 .52661 .53632 .51921 Metetra
.703 .197 0 r
.53632 .51921 .54521 .52661 .56218 .55154 .55327 .54105 Metetra
.869 .782 .763 r
.55327 .54105 .56218 .55154 .57878 .52807 .56998 .51774 Metetra
.841 .786 .799 r
.56998 .51774 .57878 .52807 .5954 .5095 .5867 .49925 Metetra
.824 .788 .818 r
.5867 .49925 .5954 .5095 .61204 .49307 .60344 .48285 Metetra
.804 .788 .838 r
.60344 .48285 .61204 .49307 .62874 .4788 .62023 .46858 Metetra
.791 .787 .849 r
.62023 .46858 .62874 .4788 .64549 .46569 .63707 .45545 Metetra
.776 .785 .861 r
.63707 .45545 .64549 .46569 .66231 .45372 .65398 .44345 Metetra
.793 .79 .849 r
.65398 .44345 .66231 .45372 .67912 .44082 .67086 .43017 Metetra
.97 .742 .537 r
.67086 .43017 .67912 .44082 .69196 .35194 .68385 .33879 Metetra
.932 .751 .634 r
.68385 .33879 .69196 .35194 .70638 .30402 .69848 .29186 Metetra
.874 .767 .741 r
.69848 .29186 .70638 .30402 .72184 .27799 .71413 .26744 Metetra
.664 .741 .908 r
.71413 .26744 .72184 .27799 .73856 .27227 .73093 .26167 Metetra
.664 .741 .908 r
.73093 .26167 .73856 .27227 .75539 .26654 .74783 .25587 Metetra
.664 .741 .908 r
.74783 .25587 .75539 .26654 .77232 .26078 .76483 .25005 Metetra
.664 .741 .908 r
.76483 .25005 .77232 .26078 .78935 .25498 .78193 .24418 Metetra
.664 .741 .908 r
.78193 .24418 .78935 .25498 .80648 .24915 .79913 .23829 Metetra
.664 .741 .908 r
.79913 .23829 .80648 .24915 .82371 .24328 .81644 .23236 Metetra
.664 .741 .908 r
.81644 .23236 .82371 .24328 .84105 .23738 .83385 .22639 Metetra
.664 .741 .908 r
.21474 .42645 .2243 .43535 .23833 .43054 .22882 .42159 Metetra
.664 .741 .908 r
.22882 .42159 .23833 .43054 .25243 .4257 .24296 .41671 Metetra
.664 .741 .908 r
.24296 .41671 .25243 .4257 .26661 .42084 .25719 .4118 Metetra
.664 .741 .908 r
.25719 .4118 .26661 .42084 .28087 .41596 .27149 .40686 Metetra
.664 .741 .908 r
.27149 .40686 .28087 .41596 .2952 .41104 .28587 .4019 Metetra
.664 .741 .908 r
.28587 .4019 .2952 .41104 .30961 .4061 .30033 .39691 Metetra
.664 .741 .908 r
.30033 .39691 .30961 .4061 .32411 .40113 .31487 .39189 Metetra
.664 .741 .908 r
.31487 .39189 .32411 .40113 .33868 .39614 .32949 .38684 Metetra
.664 .741 .908 r
.32949 .38684 .33868 .39614 .35333 .39112 .34419 .38177 Metetra
.664 .741 .908 r
.34419 .38177 .35333 .39112 .36806 .38606 .35898 .37667 Metetra
.664 .741 .908 r
.35898 .37667 .36806 .38606 .38288 .38099 .37384 .37154 Metetra
.664 .741 .908 r
.37384 .37154 .38288 .38099 .39777 .37588 .38879 .36638 Metetra
.664 .741 .908 r
.38879 .36638 .39777 .37588 .41275 .37074 .40382 .36119 Metetra
.953 .615 .331 r
.40382 .36119 .41275 .37074 .42483 .46364 .41611 .441 Metetra
.951 .618 .211 r
.41611 .441 .42483 .46364 .43858 .53069 .42929 .5205 Metetra
.863 .429 .013 r
.42929 .5205 .43858 .53069 .45378 .56567 .44445 .55455 Metetra
.932 .738 .618 r
.44445 .55455 .45378 .56567 .47121 .49245 .46193 .49142 Metetra
.971 .732 .52 r
.46193 .49142 .47121 .49245 .48892 .34463 .48027 .3348 Metetra
.664 .741 .908 r
.48027 .3348 .48892 .34463 .50442 .33932 .49582 .32943 Metetra
.962 .638 .349 r
.49582 .32943 .50442 .33932 .5198 .45971 .51088 .45885 Metetra
.914 .53 .269 r
.51088 .45885 .5198 .45971 .53632 .51921 .52733 .51371 Metetra
.601 .052 0 r
.52733 .51371 .53632 .51921 .55327 .54105 .54426 .52941 Metetra
.858 .767 .761 r
.54426 .52941 .55327 .54105 .56998 .51774 .56108 .50653 Metetra
.832 .773 .796 r
.56108 .50653 .56998 .51774 .5867 .49925 .5779 .48827 Metetra
.817 .777 .815 r
.5779 .48827 .5867 .49925 .60344 .48285 .59473 .47201 Metetra
.798 .778 .834 r
.59473 .47201 .60344 .48285 .62023 .46858 .61161 .45782 Metetra
.786 .778 .846 r
.61161 .45782 .62023 .46858 .63707 .45545 .62854 .44474 Metetra
.772 .778 .857 r
.62854 .44474 .63707 .45545 .65398 .44345 .64554 .43275 Metetra
.798 .785 .841 r
.64554 .43275 .65398 .44345 .67086 .43017 .66249 .4188 Metetra
.969 .737 .532 r
.66249 .4188 .67086 .43017 .68385 .33879 .67551 .32267 Metetra
.912 .729 .642 r
.67551 .32267 .68385 .33879 .69848 .29186 .6904 .27787 Metetra
.839 .74 .755 r
.6904 .27787 .69848 .29186 .71413 .26744 .70635 .25677 Metetra
.664 .741 .908 r
.70635 .25677 .71413 .26744 .73093 .26167 .72322 .25095 Metetra
.664 .741 .908 r
.72322 .25095 .73093 .26167 .74783 .25587 .74019 .24509 Metetra
.664 .741 .908 r
.74019 .24509 .74783 .25587 .76483 .25005 .75726 .2392 Metetra
.664 .741 .908 r
.75726 .2392 .76483 .25005 .78193 .24418 .77443 .23327 Metetra
.664 .741 .908 r
.77443 .23327 .78193 .24418 .79913 .23829 .7917 .22731 Metetra
.664 .741 .908 r
.7917 .22731 .79913 .23829 .81644 .23236 .80908 .22131 Metetra
.664 .741 .908 r
.80908 .22131 .81644 .23236 .83385 .22639 .82657 .21527 Metetra
.664 .741 .908 r
.20509 .41746 .21474 .42645 .22882 .42159 .21921 .41256 Metetra
.664 .741 .908 r
.21921 .41256 .22882 .42159 .24296 .41671 .2334 .40762 Metetra
.664 .741 .908 r
.2334 .40762 .24296 .41671 .25719 .4118 .24767 .40267 Metetra
.664 .741 .908 r
.24767 .40267 .25719 .4118 .27149 .40686 .26202 .39768 Metetra
.664 .741 .908 r
.26202 .39768 .27149 .40686 .28587 .4019 .27645 .39266 Metetra
.664 .741 .908 r
.27645 .39266 .28587 .4019 .30033 .39691 .29096 .38762 Metetra
.664 .741 .908 r
.29096 .38762 .30033 .39691 .31487 .39189 .30555 .38255 Metetra
.664 .741 .908 r
.30555 .38255 .31487 .39189 .32949 .38684 .32021 .37745 Metetra
.664 .741 .908 r
.32021 .37745 .32949 .38684 .34419 .38177 .33497 .37233 Metetra
.664 .741 .908 r
.33497 .37233 .34419 .38177 .35898 .37667 .3498 .36717 Metetra
.664 .741 .908 r
.3498 .36717 .35898 .37667 .37384 .37154 .36472 .36199 Metetra
.664 .741 .908 r
.36472 .36199 .37384 .37154 .38879 .36638 .37972 .35677 Metetra
.664 .741 .908 r
.37972 .35677 .38879 .36638 .40382 .36119 .3948 .35153 Metetra
.948 .597 .296 r
.3948 .35153 .40382 .36119 .41611 .441 .40736 .41818 Metetra
.962 .636 .257 r
.40736 .41818 .41611 .441 .42929 .5205 .41991 .50977 Metetra
.848 .409 0 r
.41991 .50977 .42929 .5205 .44445 .55455 .43505 .54243 Metetra
.916 .74 .649 r
.43505 .54243 .44445 .55455 .46193 .49142 .45244 .49321 Metetra
.974 .735 .513 r
.45244 .49321 .46193 .49142 .48027 .3348 .47152 .32487 Metetra
.664 .741 .908 r
.47152 .32487 .48027 .3348 .49582 .32943 .48713 .31945 Metetra
.963 .643 .359 r
.48713 .31945 .49582 .32943 .51088 .45885 .50178 .462 Metetra
.89 .499 .283 r
.50178 .462 .51088 .45885 .52733 .51371 .51821 .51005 Metetra
0 .329 .663 r
.51821 .51005 .52733 .51371 .54426 .52941 .53515 .51672 Metetra
.846 .754 .761 r
.53515 .51672 .54426 .52941 .56108 .50653 .55208 .49448 Metetra
.823 .761 .794 r
.55208 .49448 .56108 .50653 .5779 .48827 .569 .47659 Metetra
.81 .766 .812 r
.569 .47659 .5779 .48827 .59473 .47201 .58593 .46059 Metetra
.792 .768 .831 r
.58593 .46059 .59473 .47201 .61161 .45782 .6029 .44655 Metetra
.78 .77 .844 r
.6029 .44655 .61161 .45782 .62854 .44474 .61992 .43365 Metetra
.77 .772 .855 r
.61992 .43365 .62854 .44474 .64554 .43275 .63699 .42163 Metetra
.871 .786 .765 r
.63699 .42163 .64554 .43275 .66249 .4188 .65367 .39858 Metetra
.944 .708 .55 r
.65367 .39858 .66249 .4188 .67551 .32267 .66705 .30476 Metetra
.896 .715 .65 r
.66705 .30476 .67551 .32267 .6904 .27787 .68219 .26256 Metetra
.793 .712 .776 r
.68219 .26256 .6904 .27787 .70635 .25677 .69848 .24599 Metetra
.664 .741 .908 r
.69848 .24599 .70635 .25677 .72322 .25095 .71542 .24011 Metetra
.664 .741 .908 r
.71542 .24011 .72322 .25095 .74019 .24509 .73246 .23418 Metetra
.664 .741 .908 r
.73246 .23418 .74019 .24509 .75726 .2392 .7496 .22823 Metetra
.664 .741 .908 r
.7496 .22823 .75726 .2392 .77443 .23327 .76684 .22223 Metetra
.664 .741 .908 r
.76684 .22223 .77443 .23327 .7917 .22731 .78419 .2162 Metetra
.664 .741 .908 r
.78419 .2162 .7917 .22731 .80908 .22131 .80164 .21014 Metetra
.664 .741 .908 r
.80164 .21014 .80908 .22131 .82657 .21527 .8192 .20404 Metetra
.664 .741 .908 r
.19534 .40839 .20509 .41746 .21921 .41256 .2095 .40343 Metetra
.664 .741 .908 r
.2095 .40343 .21921 .41256 .2334 .40762 .22374 .39845 Metetra
.664 .741 .908 r
.22374 .39845 .2334 .40762 .24767 .40267 .23806 .39344 Metetra
.664 .741 .908 r
.23806 .39344 .24767 .40267 .26202 .39768 .25245 .3884 Metetra
.664 .741 .908 r
.25245 .3884 .26202 .39768 .27645 .39266 .26693 .38333 Metetra
.664 .741 .908 r
.26693 .38333 .27645 .39266 .29096 .38762 .28149 .37824 Metetra
.664 .741 .908 r
.28149 .37824 .29096 .38762 .30555 .38255 .29612 .37312 Metetra
.664 .741 .908 r
.29612 .37312 .30555 .38255 .32021 .37745 .31084 .36797 Metetra
.664 .741 .908 r
.31084 .36797 .32021 .37745 .33497 .37233 .32564 .36279 Metetra
.664 .741 .908 r
.32564 .36279 .33497 .37233 .3498 .36717 .34053 .35758 Metetra
.664 .741 .908 r
.34053 .35758 .3498 .36717 .36472 .36199 .35549 .35234 Metetra
.664 .741 .908 r
.35549 .35234 .36472 .36199 .37972 .35677 .37055 .34707 Metetra
.664 .741 .908 r
.37055 .34707 .37972 .35677 .3948 .35153 .38569 .34178 Metetra
.94 .572 .25 r
.38569 .34178 .3948 .35153 .40736 .41818 .39853 .39707 Metetra
.968 .645 .298 r
.39853 .39707 .40736 .41818 .41991 .50977 .41045 .49852 Metetra
.826 .382 0 r
.41045 .49852 .41991 .50977 .43505 .54243 .42558 .52945 Metetra
.885 .74 .696 r
.42558 .52945 .43505 .54243 .45244 .49321 .44278 .49487 Metetra
.976 .748 .527 r
.44278 .49487 .45244 .49321 .47152 .32487 .46174 .36228 Metetra
.363 .059 .309 r
.46174 .36228 .47152 .32487 .48713 .31945 .47773 .35076 Metetra
.878 .56 .444 r
.47773 .35076 .48713 .31945 .50178 .462 .49249 .4678 Metetra
.859 .458 .276 r
.49249 .4678 .50178 .462 .51821 .51005 .50894 .50762 Metetra
.489 .873 .972 r
.50894 .50762 .51821 .51005 .53515 .51672 .52595 .50308 Metetra
.831 .741 .766 r
.52595 .50308 .53515 .51672 .55208 .49448 .54299 .48225 Metetra
.822 .76 .794 r
.54299 .48225 .55208 .49448 .569 .47659 .56 .46427 Metetra
.8 .756 .813 r
.56 .46427 .569 .47659 .58593 .46059 .57702 .44882 Metetra
.79 .764 .83 r
.57702 .44882 .58593 .46059 .6029 .44655 .59408 .43477 Metetra
.774 .762 .842 r
.59408 .43477 .6029 .44655 .61992 .43365 .61118 .42203 Metetra
.765 .764 .851 r
.61118 .42203 .61992 .43365 .63699 .42163 .62835 .41011 Metetra
.943 .765 .631 r
.62835 .41011 .63699 .42163 .65367 .39858 .64413 .36015 Metetra
.869 .637 .585 r
.64413 .36015 .65367 .39858 .66705 .30476 .65847 .28546 Metetra
.882 .704 .657 r
.65847 .28546 .66705 .30476 .68219 .26256 .67385 .24585 Metetra
.721 .669 .799 r
.67385 .24585 .68219 .26256 .69848 .24599 .69052 .2351 Metetra
.664 .741 .908 r
.69052 .2351 .69848 .24599 .71542 .24011 .70753 .22915 Metetra
.664 .741 .908 r
.70753 .22915 .71542 .24011 .73246 .23418 .72464 .22316 Metetra
.664 .741 .908 r
.72464 .22316 .73246 .23418 .7496 .22823 .74185 .21713 Metetra
.664 .741 .908 r
.74185 .21713 .7496 .22823 .76684 .22223 .75917 .21107 Metetra
.664 .741 .908 r
.75917 .21107 .76684 .22223 .78419 .2162 .77659 .20498 Metetra
.664 .741 .908 r
.77659 .20498 .78419 .2162 .80164 .21014 .79412 .19884 Metetra
.664 .741 .908 r
.79412 .19884 .80164 .21014 .8192 .20404 .81176 .19267 Metetra
.664 .741 .908 r
.18549 .39922 .19534 .40839 .2095 .40343 .1997 .39421 Metetra
.664 .741 .908 r
.1997 .39421 .2095 .40343 .22374 .39845 .21398 .38918 Metetra
.664 .741 .908 r
.21398 .38918 .22374 .39845 .23806 .39344 .22835 .38411 Metetra
.664 .741 .908 r
.22835 .38411 .23806 .39344 .25245 .3884 .24279 .37903 Metetra
.664 .741 .908 r
.24279 .37903 .25245 .3884 .26693 .38333 .25731 .37391 Metetra
.664 .741 .908 r
.25731 .37391 .26693 .38333 .28149 .37824 .27192 .36876 Metetra
.664 .741 .908 r
.27192 .36876 .28149 .37824 .29612 .37312 .2866 .36359 Metetra
.664 .741 .908 r
.2866 .36359 .29612 .37312 .31084 .36797 .30137 .35838 Metetra
.664 .741 .908 r
.30137 .35838 .31084 .36797 .32564 .36279 .31622 .35315 Metetra
.664 .741 .908 r
.31622 .35315 .32564 .36279 .34053 .35758 .33116 .34789 Metetra
.664 .741 .908 r
.33116 .34789 .34053 .35758 .35549 .35234 .34618 .34259 Metetra
.664 .741 .908 r
.34618 .34259 .35549 .35234 .37055 .34707 .36128 .33727 Metetra
.664 .741 .908 r
.36128 .33727 .37055 .34707 .38569 .34178 .37647 .33192 Metetra
.917 .52 .162 r
.37647 .33192 .38569 .34178 .39853 .39707 .38974 .37404 Metetra
.971 .655 .311 r
.38974 .37404 .39853 .39707 .41045 .49852 .40091 .48679 Metetra
.796 .347 0 r
.40091 .48679 .41045 .49852 .42558 .52945 .41605 .51575 Metetra
.801 .727 .783 r
.41605 .51575 .42558 .52945 .44278 .49487 .43289 .49857 Metetra
.985 .788 .557 r
.43289 .49857 .44278 .49487 .46174 .36228 .45131 .41191 Metetra
.409 .121 .36 r
.45131 .41191 .46174 .36228 .47773 .35076 .46767 .40063 Metetra
.784 .469 .457 r
.46767 .40063 .47773 .35076 .49249 .4678 .48301 .47203 Metetra
.844 .421 .228 r
.48301 .47203 .49249 .4678 .50894 .50762 .49953 .50549 Metetra
.868 .95 .864 r
.49953 .50549 .50894 .50762 .52595 .50308 .51668 .48862 Metetra
.819 .731 .768 r
.51668 .48862 .52595 .50308 .54299 .48225 .5338 .46877 Metetra
.808 .742 .79 r
.5338 .46877 .54299 .48225 .56 .46427 .5509 .45136 Metetra
.792 .748 .812 r
.5509 .45136 .56 .46427 .57702 .44882 .56802 .43632 Metetra
.781 .752 .827 r
.56802 .43632 .57702 .44882 .59408 .43477 .58516 .42254 Metetra
.769 .755 .84 r
.58516 .42254 .59408 .43477 .61118 .42203 .60235 .40999 Metetra
.762 .757 .849 r
.60235 .40999 .61118 .42203 .62835 .41011 .6196 .3981 Metetra
.962 .744 .561 r
.6196 .3981 .62835 .41011 .64413 .36015 .63452 .31841 Metetra
.819 .602 .609 r
.63452 .31841 .64413 .36015 .65847 .28546 .64978 .26447 Metetra
.855 .686 .672 r
.64978 .26447 .65847 .28546 .67385 .24585 .6655 .23012 Metetra
.654 .654 .837 r
.6655 .23012 .67385 .24585 .69052 .2351 .68248 .22408 Metetra
.664 .741 .908 r
.68248 .22408 .69052 .2351 .70753 .22915 .69955 .21806 Metetra
.664 .741 .908 r
.69955 .21806 .70753 .22915 .72464 .22316 .71674 .21201 Metetra
.664 .741 .908 r
.71674 .21201 .72464 .22316 .74185 .21713 .73402 .20592 Metetra
.664 .741 .908 r
.73402 .20592 .74185 .21713 .75917 .21107 .75141 .19979 Metetra
.664 .741 .908 r
.75141 .19979 .75917 .21107 .77659 .20498 .76891 .19362 Metetra
.664 .741 .908 r
.76891 .19362 .77659 .20498 .79412 .19884 .78651 .18742 Metetra
.664 .741 .908 r
.78651 .18742 .79412 .19884 .81176 .19267 .80423 .18118 Metetra
.664 .741 .908 r
.17555 .38995 .18549 .39922 .1997 .39421 .1898 .3849 Metetra
.664 .741 .908 r
.1898 .3849 .1997 .39421 .21398 .38918 .20413 .37981 Metetra
.664 .741 .908 r
.20413 .37981 .21398 .38918 .22835 .38411 .21853 .3747 Metetra
.664 .741 .908 r
.21853 .3747 .22835 .38411 .24279 .37903 .23302 .36955 Metetra
.664 .741 .908 r
.23302 .36955 .24279 .37903 .25731 .37391 .2476 .36438 Metetra
.664 .741 .908 r
.2476 .36438 .25731 .37391 .27192 .36876 .26225 .35918 Metetra
.664 .741 .908 r
.26225 .35918 .27192 .36876 .2866 .36359 .27698 .35396 Metetra
.664 .741 .908 r
.27698 .35396 .2866 .36359 .30137 .35838 .2918 .3487 Metetra
.664 .741 .908 r
.2918 .3487 .30137 .35838 .31622 .35315 .3067 .34341 Metetra
.664 .741 .908 r
.3067 .34341 .31622 .35315 .33116 .34789 .32169 .33809 Metetra
.664 .741 .908 r
.32169 .33809 .33116 .34789 .34618 .34259 .33676 .33274 Metetra
.664 .741 .908 r
.33676 .33274 .34618 .34259 .36128 .33727 .35192 .32736 Metetra
.664 .741 .908 r
.35192 .32736 .36128 .33727 .37647 .33192 .36716 .32195 Metetra
.851 .408 0 r
.36716 .32195 .37647 .33192 .38974 .37404 .38091 .3514 Metetra
.972 .66 .332 r
.38091 .3514 .38974 .37404 .40091 .48679 .39129 .47463 Metetra
.756 .302 0 r
.39129 .47463 .40091 .48679 .41605 .51575 .40644 .50147 Metetra
.527 .62 .888 r
.40644 .50147 .41605 .51575 .43289 .49857 .42285 .50097 Metetra
.985 .816 .594 r
.42285 .50097 .43289 .49857 .45131 .41191 .44106 .43668 Metetra
.334 0 .197 r
.44106 .43668 .45131 .41191 .46767 .40063 .45759 .42909 Metetra
.79 .446 .406 r
.45759 .42909 .46767 .40063 .48301 .47203 .47334 .47688 Metetra
.76 .292 .134 r
.47334 .47688 .48301 .47203 .49953 .50549 .49003 .49722 Metetra
.888 .82 .776 r
.49003 .49722 .49953 .50549 .51668 .48862 .50732 .47355 Metetra
.807 .723 .771 r
.50732 .47355 .51668 .48862 .5338 .46877 .52453 .45471 Metetra
.799 .734 .792 r
.52453 .45471 .5338 .46877 .5509 .45136 .54172 .43796 Metetra
.784 .74 .813 r
.54172 .43796 .5509 .45136 .56802 .43632 .55892 .42335 Metetra
.775 .745 .826 r
.55892 .42335 .56802 .43632 .58516 .42254 .57615 .40988 Metetra
.763 .749 .839 r
.57615 .40988 .58516 .42254 .60235 .40999 .59342 .39755 Metetra
.783 .758 .831 r
.59342 .39755 .60235 .40999 .6196 .3981 .6107 .38375 Metetra
.96 .729 .544 r
.6107 .38375 .6196 .3981 .63452 .31841 .62542 .29004 Metetra
.854 .653 .63 r
.62542 .29004 .63452 .31841 .64978 .26447 .64104 .24301 Metetra
.804 .664 .709 r
.64104 .24301 .64978 .26447 .6655 .23012 .6573 .219 Metetra
.664 .741 .907 r
.6573 .219 .6655 .23012 .68248 .22408 .67434 .21294 Metetra
.664 .741 .908 r
.67434 .21294 .68248 .22408 .69955 .21806 .69149 .20686 Metetra
.664 .741 .908 r
.69149 .20686 .69955 .21806 .71674 .21201 .70874 .20073 Metetra
.664 .741 .908 r
.70874 .20073 .71674 .21201 .73402 .20592 .7261 .19457 Metetra
.664 .741 .908 r
.7261 .19457 .73402 .20592 .75141 .19979 .74357 .18838 Metetra
.664 .741 .908 r
.74357 .18838 .75141 .19979 .76891 .19362 .76114 .18214 Metetra
.664 .741 .908 r
.76114 .18214 .76891 .19362 .78651 .18742 .77882 .17587 Metetra
.664 .741 .908 r
.77882 .17587 .78651 .18742 .80423 .18118 .79661 .16955 Metetra
.664 .741 .908 r
.1655 .38059 .17555 .38995 .1898 .3849 .17979 .37549 Metetra
.664 .741 .908 r
.17979 .37549 .1898 .3849 .20413 .37981 .19417 .37035 Metetra
.664 .741 .908 r
.19417 .37035 .20413 .37981 .21853 .3747 .20862 .36518 Metetra
.664 .741 .908 r
.20862 .36518 .21853 .3747 .23302 .36955 .22316 .35999 Metetra
.664 .741 .908 r
.22316 .35999 .23302 .36955 .2476 .36438 .23778 .35476 Metetra
.664 .741 .908 r
.23778 .35476 .2476 .36438 .26225 .35918 .25248 .34951 Metetra
.664 .741 .908 r
.25248 .34951 .26225 .35918 .27698 .35396 .26726 .34422 Metetra
.664 .741 .908 r
.26726 .34422 .27698 .35396 .2918 .3487 .28213 .33891 Metetra
.664 .741 .908 r
.28213 .33891 .2918 .3487 .3067 .34341 .29708 .33357 Metetra
.664 .741 .908 r
.29708 .33357 .3067 .34341 .32169 .33809 .31212 .32819 Metetra
.664 .741 .908 r
.31212 .32819 .32169 .33809 .33676 .33274 .32725 .32279 Metetra
.664 .741 .908 r
.32725 .32279 .33676 .33274 .35192 .32736 .34246 .31735 Metetra
.664 .741 .908 r
.34246 .31735 .35192 .32736 .36716 .32195 .35775 .31188 Metetra
.568 .078 0 r
.35775 .31188 .36716 .32195 .38091 .3514 .37207 .32839 Metetra
.973 .664 .345 r
.37207 .32839 .38091 .3514 .39129 .47463 .38158 .46208 Metetra
.716 .262 0 r
.38158 .46208 .39129 .47463 .40644 .50147 .39675 .48727 Metetra
0 .102 .649 r
.39675 .48727 .40644 .50147 .42285 .50097 .41263 .50331 Metetra
.983 .85 .631 r
.41263 .50331 .42285 .50097 .44106 .43668 .43073 .45307 Metetra
.238 0 .027 r
.43073 .45307 .44106 .43668 .45759 .42909 .44745 .44619 Metetra
.79 .412 .34 r
.44745 .44619 .45759 .42909 .47334 .47688 .46349 .48088 Metetra
.16 0 0 r
.46349 .48088 .47334 .47688 .49003 .49722 .48052 .48004 Metetra
.81 .702 .746 r
.48052 .48004 .49003 .49722 .50732 .47355 .49788 .4586 Metetra
.806 .725 .776 r
.49788 .4586 .50732 .47355 .52453 .45471 .51517 .44017 Metetra
.787 .726 .796 r
.51517 .44017 .52453 .45471 .54172 .43796 .53244 .42433 Metetra
.78 .738 .814 r
.53244 .42433 .54172 .43796 .55892 .42335 .54972 .40997 Metetra
.767 .739 .828 r
.54972 .40997 .55892 .42335 .57615 .40988 .56704 .39694 Metetra
.759 .745 .84 r
.56704 .39694 .57615 .40988 .59342 .39755 .5844 .38475 Metetra
.92 .763 .669 r
.5844 .38475 .59342 .39755 .6107 .38375 .60112 .34437 Metetra
.878 .641 .577 r
.60112 .34437 .6107 .38375 .62542 .29004 .61632 .26191 Metetra
.839 .647 .643 r
.61632 .26191 .62542 .29004 .64104 .24301 .63224 .22095 Metetra
.717 .621 .748 r
.63224 .22095 .64104 .24301 .6573 .219 .649 .2078 Metetra
.664 .741 .908 r
.649 .2078 .6573 .219 .67434 .21294 .66611 .20168 Metetra
.664 .741 .908 r
.66611 .20168 .67434 .21294 .69149 .20686 .68334 .19552 Metetra
.664 .741 .908 r
.68334 .19552 .69149 .20686 .70874 .20073 .70066 .18933 Metetra
.664 .741 .908 r
.70066 .18933 .70874 .20073 .7261 .19457 .71809 .1831 Metetra
.664 .741 .908 r
.71809 .1831 .7261 .19457 .74357 .18838 .73563 .17683 Metetra
.664 .741 .908 r
.73563 .17683 .74357 .18838 .76114 .18214 .75328 .17053 Metetra
.664 .741 .908 r
.75328 .17053 .76114 .18214 .77882 .17587 .77104 .16418 Metetra
.664 .741 .908 r
.77104 .16418 .77882 .17587 .79661 .16955 .78891 .1578 Metetra
.664 .741 .908 r
.15534 .37114 .1655 .38059 .17979 .37549 .16968 .36598 Metetra
.664 .741 .908 r
.16968 .36598 .17979 .37549 .19417 .37035 .1841 .36079 Metetra
.664 .741 .908 r
.1841 .36079 .19417 .37035 .20862 .36518 .19861 .35557 Metetra
.664 .741 .908 r
.19861 .35557 .20862 .36518 .22316 .35999 .21319 .35032 Metetra
.664 .741 .908 r
.21319 .35032 .22316 .35999 .23778 .35476 .22786 .34504 Metetra
.664 .741 .908 r
.22786 .34504 .23778 .35476 .25248 .34951 .24261 .33973 Metetra
.664 .741 .908 r
.24261 .33973 .25248 .34951 .26726 .34422 .25744 .33439 Metetra
.664 .741 .908 r
.25744 .33439 .26726 .34422 .28213 .33891 .27236 .32902 Metetra
.664 .741 .908 r
.27236 .32902 .28213 .33891 .29708 .33357 .28736 .32362 Metetra
.664 .741 .908 r
.28736 .32362 .29708 .33357 .31212 .32819 .30245 .31819 Metetra
.664 .741 .908 r
.30245 .31819 .31212 .32819 .32725 .32279 .31763 .31273 Metetra
.664 .741 .908 r
.31763 .31273 .32725 .32279 .34246 .31735 .33289 .30723 Metetra
.664 .741 .908 r
.33289 .30723 .34246 .31735 .35775 .31188 .34825 .30171 Metetra
.274 .565 .934 r
.34825 .30171 .35775 .31188 .37207 .32839 .36321 .3053 Metetra
.974 .667 .357 r
.36321 .3053 .37207 .32839 .38158 .46208 .37179 .4492 Metetra
.653 .198 0 r
.37179 .4492 .38158 .46208 .39675 .48727 .38701 .47212 Metetra
.68 .255 0 r
.38701 .47212 .39675 .48727 .41263 .50331 .40244 .49941 Metetra
.945 .841 .71 r
.40244 .49941 .41263 .50331 .43073 .45307 .42028 .46459 Metetra
.124 0 0 r
.42028 .46459 .43073 .45307 .44745 .44619 .43717 .45807 Metetra
.765 .351 .266 r
.43717 .45807 .44745 .44619 .46349 .48088 .45347 .4832 Metetra
.884 .99 .794 r
.45347 .4832 .46349 .48088 .48052 .48004 .47095 .46251 Metetra
.798 .696 .753 r
.47095 .46251 .48052 .48004 .49788 .4586 .48837 .4427 Metetra
.791 .712 .776 r
.48837 .4427 .49788 .4586 .51517 .44017 .50573 .42525 Metetra
.778 .721 .799 r
.50573 .42525 .51517 .44017 .53244 .42433 .52308 .41012 Metetra
.771 .729 .814 r
.52308 .41012 .53244 .42433 .54972 .40997 .54044 .39623 Metetra
.76 .734 .828 r
.54044 .39623 .54972 .40997 .56704 .39694 .55783 .38356 Metetra
.761 .741 .834 r
.55783 .38356 .56704 .39694 .5844 .38475 .57527 .37101 Metetra
.957 .735 .561 r
.57527 .37101 .5844 .38475 .60112 .34437 .59122 .28722 Metetra
.772 .552 .6 r
.59122 .28722 .60112 .34437 .61632 .26191 .60725 .23467 Metetra
.811 .638 .667 r
.60725 .23467 .61632 .26191 .63224 .22095 .62353 .20267 Metetra
.646 .623 .812 r
.62353 .20267 .63224 .22095 .649 .2078 .64061 .19647 Metetra
.664 .741 .908 r
.64061 .19647 .649 .2078 .66611 .20168 .6578 .19029 Metetra
.664 .741 .908 r
.6578 .19029 .66611 .20168 .68334 .19552 .67509 .18406 Metetra
.664 .741 .908 r
.67509 .18406 .68334 .19552 .70066 .18933 .69249 .1778 Metetra
.664 .741 .908 r
.69249 .1778 .70066 .18933 .71809 .1831 .70999 .1715 Metetra
.664 .741 .908 r
.70999 .1715 .71809 .1831 .73563 .17683 .72761 .16516 Metetra
.664 .741 .908 r
.72761 .16516 .73563 .17683 .75328 .17053 .74533 .15878 Metetra
.664 .741 .908 r
.74533 .15878 .75328 .17053 .77104 .16418 .76317 .15236 Metetra
.664 .741 .908 r
.76317 .15236 .77104 .16418 .78891 .1578 .78111 .1459 Metetra
.664 .741 .908 r
.14508 .36159 .15534 .37114 .16968 .36598 .15947 .35637 Metetra
.664 .741 .908 r
.15947 .35637 .16968 .36598 .1841 .36079 .17394 .35113 Metetra
.664 .741 .908 r
.17394 .35113 .1841 .36079 .19861 .35557 .18849 .34585 Metetra
.664 .741 .908 r
.18849 .34585 .19861 .35557 .21319 .35032 .20312 .34055 Metetra
.664 .741 .908 r
.20312 .34055 .21319 .35032 .22786 .34504 .21783 .33521 Metetra
.664 .741 .908 r
.21783 .33521 .22786 .34504 .24261 .33973 .23263 .32985 Metetra
.664 .741 .908 r
.23263 .32985 .24261 .33973 .25744 .33439 .24752 .32445 Metetra
.664 .741 .908 r
.24752 .32445 .25744 .33439 .27236 .32902 .26248 .31903 Metetra
.664 .741 .908 r
.26248 .31903 .27236 .32902 .28736 .32362 .27754 .31357 Metetra
.664 .741 .908 r
.27754 .31357 .28736 .32362 .30245 .31819 .29268 .30808 Metetra
.664 .741 .908 r
.29268 .30808 .30245 .31819 .31763 .31273 .30791 .30256 Metetra
.664 .741 .908 r
.30791 .30256 .31763 .31273 .33289 .30723 .32323 .29701 Metetra
.664 .741 .908 r
.32323 .29701 .33289 .30723 .34825 .30171 .33863 .29142 Metetra
.662 .741 .908 r
.33863 .29142 .34825 .30171 .36321 .3053 .35413 .28585 Metetra
.971 .664 .375 r
.35413 .28585 .36321 .3053 .37179 .4492 .36192 .43612 Metetra
.576 .124 0 r
.36192 .43612 .37179 .4492 .38701 .47212 .37719 .4567 Metetra
0 0 .404 r
.37719 .4567 .38701 .47212 .40244 .49941 .3927 .48028 Metetra
.668 .628 .8 r
.3927 .48028 .40244 .49941 .42028 .46459 .40971 .47246 Metetra
.40971 .47246 .42028 .46459 .43717 .45807 .42676 .4661 Metetra
.384 0 0 r
.42676 .4661 .43717 .45807 .45347 .4832 .44371 .46767 Metetra
.829 .725 .749 r
.44371 .46767 .45347 .4832 .47095 .46251 .46131 .44489 Metetra
.787 .694 .761 r
.46131 .44489 .47095 .46251 .48837 .4427 .47878 .42652 Metetra
.782 .707 .782 r
.47878 .42652 .48837 .4427 .50573 .42525 .49621 .41007 Metetra
.77 .717 .803 r
.49621 .41007 .50573 .42525 .52308 .41012 .51363 .39559 Metetra
.762 .724 .817 r
.51363 .39559 .52308 .41012 .54044 .39623 .53107 .38229 Metetra
.755 .731 .83 r
.53107 .38229 .54044 .39623 .55783 .38356 .54854 .36987 Metetra
.854 .757 .755 r
.54854 .36987 .55783 .38356 .57527 .37101 .5659 .34627 Metetra
.931 .694 .557 r
.5659 .34627 .57527 .37101 .59122 .28722 .58186 .25113 Metetra
.811 .609 .63 r
.58186 .25113 .59122 .28722 .60725 .23467 .59818 .20824 Metetra
.729 .6 .712 r
.59818 .20824 .60725 .23467 .62353 .20267 .61497 .19124 Metetra
.663 .74 .907 r
.61497 .19124 .62353 .20267 .64061 .19647 .63212 .18502 Metetra
.664 .741 .908 r
.63212 .18502 .64061 .19647 .6578 .19029 .64938 .17877 Metetra
.664 .741 .908 r
.64938 .17877 .6578 .19029 .67509 .18406 .66675 .17247 Metetra
.664 .741 .908 r
.66675 .17247 .67509 .18406 .69249 .1778 .68422 .16614 Metetra
.664 .741 .908 r
.68422 .16614 .69249 .1778 .70999 .1715 .7018 .15976 Metetra
.664 .741 .908 r
.7018 .15976 .70999 .1715 .72761 .16516 .71949 .15335 Metetra
.664 .741 .908 r
.71949 .15335 .72761 .16516 .74533 .15878 .73729 .1469 Metetra
.664 .741 .908 r
.73729 .1469 .74533 .15878 .76317 .15236 .7552 .1404 Metetra
.664 .741 .908 r
.7552 .1404 .76317 .15236 .78111 .1459 .77323 .13387 Metetra
.664 .741 .908 r
.13472 .35194 .14508 .36159 .15947 .35637 .14915 .34667 Metetra
.664 .741 .908 r
.14915 .34667 .15947 .35637 .17394 .35113 .16366 .34137 Metetra
.664 .741 .908 r
.16366 .34137 .17394 .35113 .18849 .34585 .17826 .33604 Metetra
.664 .741 .908 r
.17826 .33604 .18849 .34585 .20312 .34055 .19294 .33068 Metetra
.664 .741 .908 r
.19294 .33068 .20312 .34055 .21783 .33521 .2077 .32529 Metetra
.664 .741 .908 r
.2077 .32529 .21783 .33521 .23263 .32985 .22255 .31986 Metetra
.664 .741 .908 r
.22255 .31986 .23263 .32985 .24752 .32445 .23748 .31441 Metetra
.664 .741 .908 r
.23748 .31441 .24752 .32445 .26248 .31903 .2525 .30893 Metetra
.664 .741 .908 r
.2525 .30893 .26248 .31903 .27754 .31357 .26761 .30341 Metetra
.664 .741 .908 r
.26761 .30341 .27754 .31357 .29268 .30808 .2828 .29786 Metetra
.664 .741 .908 r
.2828 .29786 .29268 .30808 .30791 .30256 .29809 .29228 Metetra
.664 .741 .908 r
.29809 .29228 .30791 .30256 .32323 .29701 .31346 .28667 Metetra
.664 .741 .908 r
.31346 .28667 .32323 .29701 .33863 .29142 .32892 .28102 Metetra
.664 .741 .908 r
.32892 .28102 .33863 .29142 .35413 .28585 .34447 .27534 Metetra
.96 .65 .397 r
.34447 .27534 .35413 .28585 .36192 .43612 .35196 .42269 Metetra
0 0 .504 r
.35196 .42269 .36192 .43612 .37719 .4567 .36729 .44112 Metetra
0 0 .521 r
.36729 .44112 .37719 .4567 .3927 .48028 .3829 .46126 Metetra
.001 .239 .748 r
.3829 .46126 .3927 .48028 .40971 .47246 .39909 .47543 Metetra
.207 .723 .689 r
.39909 .47543 .40971 .47246 .42676 .4661 .41623 .47043 Metetra
.883 .991 .756 r
.41623 .47043 .42676 .4661 .44371 .46767 .43397 .44789 Metetra
.785 .675 .742 r
.43397 .44789 .44371 .46767 .46131 .44489 .45159 .42783 Metetra
.786 .7 .77 r
.45159 .42783 .46131 .44489 .47878 .42652 .46912 .41017 Metetra
.77 .704 .789 r
.46912 .41017 .47878 .42652 .49621 .41007 .48661 .39487 Metetra
.766 .717 .807 r
.48661 .39487 .49621 .41007 .51363 .39559 .50409 .38082 Metetra
.755 .72 .82 r
.50409 .38082 .51363 .39559 .53107 .38229 .5216 .36799 Metetra
.754 .728 .828 r
.5216 .36799 .53107 .38229 .54854 .36987 .53914 .35547 Metetra
.954 .733 .566 r
.53914 .35547 .54854 .36987 .5659 .34627 .55602 .27249 Metetra
.739 .515 .589 r
.55602 .27249 .5659 .34627 .58186 .25113 .57261 .2191 Metetra
.793 .611 .654 r
.57261 .2191 .58186 .25113 .59818 .20824 .5892 .18603 Metetra
.634 .58 .776 r
.5892 .18603 .59818 .20824 .61497 .19124 .60632 .17973 Metetra
.664 .741 .908 r
.60632 .17973 .61497 .19124 .63212 .18502 .62354 .17344 Metetra
.664 .741 .908 r
.62354 .17344 .63212 .18502 .64938 .17877 .64087 .16711 Metetra
.664 .741 .908 r
.64087 .16711 .64938 .17877 .66675 .17247 .65831 .16075 Metetra
.664 .741 .908 r
.65831 .16075 .66675 .17247 .68422 .16614 .67586 .15434 Metetra
.664 .741 .908 r
.67586 .15434 .68422 .16614 .7018 .15976 .69351 .14789 Metetra
.664 .741 .908 r
.69351 .14789 .7018 .15976 .71949 .15335 .71128 .14141 Metetra
.664 .741 .908 r
.71128 .14141 .71949 .15335 .73729 .1469 .72916 .13488 Metetra
.664 .741 .908 r
.72916 .13488 .73729 .1469 .7552 .1404 .74715 .12831 Metetra
.664 .741 .908 r
.74715 .12831 .7552 .1404 .77323 .13387 .76525 .1217 Metetra
.664 .741 .908 r
.12424 .34218 .13472 .35194 .14915 .34667 .13872 .33686 Metetra
.664 .741 .908 r
.13872 .33686 .14915 .34667 .16366 .34137 .15328 .3315 Metetra
.664 .741 .908 r
.15328 .3315 .16366 .34137 .17826 .33604 .16793 .32612 Metetra
.664 .741 .908 r
.16793 .32612 .17826 .33604 .19294 .33068 .18265 .3207 Metetra
.664 .741 .908 r
.18265 .3207 .19294 .33068 .2077 .32529 .19747 .31525 Metetra
.664 .741 .908 r
.19747 .31525 .2077 .32529 .22255 .31986 .21236 .30977 Metetra
.664 .741 .908 r
.21236 .30977 .22255 .31986 .23748 .31441 .22735 .30426 Metetra
.664 .741 .908 r
.22735 .30426 .23748 .31441 .2525 .30893 .24242 .29872 Metetra
.664 .741 .908 r
.24242 .29872 .2525 .30893 .26761 .30341 .25758 .29314 Metetra
.664 .741 .908 r
.25758 .29314 .26761 .30341 .2828 .29786 .27282 .28753 Metetra
.664 .741 .908 r
.27282 .28753 .2828 .29786 .29809 .29228 .28816 .28189 Metetra
.664 .741 .908 r
.28816 .28189 .29809 .29228 .31346 .28667 .30358 .27622 Metetra
.664 .741 .908 r
.30358 .27622 .31346 .28667 .32892 .28102 .3191 .27051 Metetra
.664 .741 .908 r
.3191 .27051 .32892 .28102 .34447 .27534 .33471 .26477 Metetra
.96 .649 .395 r
.33471 .26477 .34447 .27534 .35196 .42269 .34192 .40896 Metetra
0 .029 .577 r
.34192 .40896 .35196 .42269 .36729 .44112 .3573 .42566 Metetra
0 .048 .605 r
.3573 .42566 .36729 .44112 .3829 .46126 .37298 .44314 Metetra
.128 .34 .804 r
.37298 .44314 .3829 .46126 .39909 .47543 .38928 .45379 Metetra
.619 .584 .792 r
.38928 .45379 .39909 .47543 .41623 .47043 .40643 .44862 Metetra
.774 .655 .732 r
.40643 .44862 .41623 .47043 .43397 .44789 .42416 .4285 Metetra
.776 .675 .753 r
.42416 .4285 .43397 .44789 .45159 .42783 .4418 .41019 Metetra
.77 .69 .775 r
.4418 .41019 .45159 .42783 .46912 .41017 .45937 .39398 Metetra
.766 .705 .795 r
.45937 .39398 .46912 .41017 .48661 .39487 .47692 .37928 Metetra
.756 .711 .81 r
.47692 .37928 .48661 .39487 .50409 .38082 .49447 .36594 Metetra
.75 .719 .823 r
.49447 .36594 .50409 .38082 .5216 .36799 .51204 .35346 Metetra
.892 .75 .698 r
.51204 .35346 .5216 .36799 .53914 .35547 .52963 .31942 Metetra
.893 .656 .572 r
.52963 .31942 .53914 .35547 .55602 .27249 .54663 .23135 Metetra
.79 .586 .625 r
.54663 .23135 .55602 .27249 .57261 .2191 .5634 .18929 Metetra
.697 .566 .704 r
.5634 .18929 .57261 .2191 .5892 .18603 .58037 .17441 Metetra
.663 .74 .907 r
.58037 .17441 .5892 .18603 .60632 .17973 .59756 .16809 Metetra
.664 .741 .908 r
.59756 .16809 .60632 .17973 .62354 .17344 .61486 .16173 Metetra
.664 .741 .908 r
.61486 .16173 .62354 .17344 .64087 .16711 .63226 .15533 Metetra
.664 .741 .908 r
.63226 .15533 .64087 .16711 .65831 .16075 .64977 .14889 Metetra
.664 .741 .908 r
.64977 .14889 .65831 .16075 .67586 .15434 .6674 .14241 Metetra
.664 .741 .908 r
.6674 .14241 .67586 .15434 .69351 .14789 .68513 .13588 Metetra
.664 .741 .908 r
.68513 .13588 .69351 .14789 .71128 .14141 .70297 .12932 Metetra
.664 .741 .908 r
.70297 .12932 .71128 .14141 .72916 .13488 .72093 .12272 Metetra
.664 .741 .908 r
.72093 .12272 .72916 .13488 .74715 .12831 .739 .11607 Metetra
.664 .741 .908 r
.739 .11607 .74715 .12831 .76525 .1217 .75719 .10938 Metetra
.664 .741 .908 r
.11366 .33233 .12424 .34218 .13872 .33686 .12818 .32695 Metetra
.664 .741 .908 r
.12818 .32695 .13872 .33686 .15328 .3315 .14279 .32154 Metetra
.664 .741 .908 r
.14279 .32154 .15328 .3315 .16793 .32612 .15748 .31609 Metetra
.664 .741 .908 r
.15748 .31609 .16793 .32612 .18265 .3207 .17226 .31062 Metetra
.664 .741 .908 r
.17226 .31062 .18265 .3207 .19747 .31525 .18712 .30511 Metetra
.664 .741 .908 r
.18712 .30511 .19747 .31525 .21236 .30977 .20207 .29957 Metetra
.664 .741 .908 r
.20207 .29957 .21236 .30977 .22735 .30426 .2171 .294 Metetra
.664 .741 .908 r
.2171 .294 .22735 .30426 .24242 .29872 .23222 .2884 Metetra
.664 .741 .908 r
.23222 .2884 .24242 .29872 .25758 .29314 .24743 .28276 Metetra
.664 .741 .908 r
.24743 .28276 .25758 .29314 .27282 .28753 .26273 .2771 Metetra
.664 .741 .908 r
.26273 .2771 .27282 .28753 .28816 .28189 .27812 .27139 Metetra
.664 .741 .908 r
.27812 .27139 .28816 .28189 .30358 .27622 .2936 .26566 Metetra
.664 .741 .908 r
.2936 .26566 .30358 .27622 .3191 .27051 .30917 .25989 Metetra
.664 .741 .908 r
.30917 .25989 .3191 .27051 .33471 .26477 .32484 .25409 Metetra
.959 .64 .376 r
.32484 .25409 .33471 .26477 .34192 .40896 .33309 .37319 Metetra
0 0 .437 r
.33309 .37319 .34192 .40896 .3573 .42566 .34724 .40991 Metetra
0 .156 .696 r
.34724 .40991 .3573 .42566 .37298 .44314 .363 .42469 Metetra
.239 .407 .828 r
.363 .42469 .37298 .44314 .38928 .45379 .37939 .43285 Metetra
.623 .593 .8 r
.37939 .43285 .38928 .45379 .40643 .44862 .39655 .42752 Metetra
.759 .656 .747 r
.39655 .42752 .40643 .44862 .42416 .4285 .41425 .41001 Metetra
.774 .684 .764 r
.41425 .41001 .42416 .4285 .4418 .41019 .43193 .39266 Metetra
.761 .69 .783 r
.43193 .39266 .4418 .41019 .45937 .39398 .44954 .37753 Metetra
.757 .701 .799 r
.44954 .37753 .45937 .39398 .47692 .37928 .46714 .36359 Metetra
.748 .709 .814 r
.46714 .36359 .47692 .37928 .49447 .36594 .48475 .35081 Metetra
.763 .722 .814 r
.48475 .35081 .49447 .36594 .51204 .35346 .50241 .33708 Metetra
.95 .723 .559 r
.50241 .33708 .51204 .35346 .52963 .31942 .52021 .24562 Metetra
.729 .507 .59 r
.52021 .24562 .52963 .31942 .54663 .23135 .53734 .19617 Metetra
.753 .579 .66 r
.53734 .19617 .54663 .23135 .5634 .18929 .5543 .16909 Metetra
.64 .604 .798 r
.5543 .16909 .5634 .18929 .58037 .17441 .57145 .16271 Metetra
.664 .741 .908 r
.57145 .16271 .58037 .17441 .59756 .16809 .58871 .15632 Metetra
.664 .741 .908 r
.58871 .15632 .59756 .16809 .61486 .16173 .60608 .14988 Metetra
.664 .741 .908 r
.60608 .14988 .61486 .16173 .63226 .15533 .62355 .14341 Metetra
.664 .741 .908 r
.62355 .14341 .63226 .15533 .64977 .14889 .64114 .13689 Metetra
.664 .741 .908 r
.64114 .13689 .64977 .14889 .6674 .14241 .65884 .13033 Metetra
.664 .741 .908 r
.65884 .13033 .6674 .14241 .68513 .13588 .67665 .12373 Metetra
.664 .741 .908 r
.67665 .12373 .68513 .13588 .70297 .12932 .69457 .11709 Metetra
.664 .741 .908 r
.69457 .11709 .70297 .12932 .72093 .12272 .7126 .11041 Metetra
.664 .741 .908 r
.7126 .11041 .72093 .12272 .739 .11607 .73075 .10369 Metetra
.664 .741 .908 r
.73075 .10369 .739 .11607 .75719 .10938 .74902 .09692 Metetra
.664 .741 .908 r
.10296 .32237 .11366 .33233 .12818 .32695 .11753 .31693 Metetra
.664 .741 .908 r
.11753 .31693 .12818 .32695 .14279 .32154 .13219 .31146 Metetra
.664 .741 .908 r
.13219 .31146 .14279 .32154 .15748 .31609 .14693 .30596 Metetra
.664 .741 .908 r
.14693 .30596 .15748 .31609 .17226 .31062 .16175 .30043 Metetra
.664 .741 .908 r
.16175 .30043 .17226 .31062 .18712 .30511 .17666 .29486 Metetra
.664 .741 .908 r
.17666 .29486 .18712 .30511 .20207 .29957 .19166 .28926 Metetra
.664 .741 .908 r
.19166 .28926 .20207 .29957 .2171 .294 .20674 .28363 Metetra
.664 .741 .908 r
.20674 .28363 .2171 .294 .23222 .2884 .22192 .27797 Metetra
.664 .741 .908 r
.22192 .27797 .23222 .2884 .24743 .28276 .23718 .27227 Metetra
.664 .741 .908 r
.23718 .27227 .24743 .28276 .26273 .2771 .25253 .26654 Metetra
.664 .741 .908 r
.25253 .26654 .26273 .2771 .27812 .27139 .26797 .26078 Metetra
.664 .741 .908 r
.26797 .26078 .27812 .27139 .2936 .26566 .28351 .25498 Metetra
.664 .741 .908 r
.28351 .25498 .2936 .26566 .30917 .25989 .29914 .24915 Metetra
.664 .741 .908 r
.29914 .24915 .30917 .25989 .32484 .25409 .31485 .24328 Metetra
.937 .564 .233 r
.31485 .24328 .32484 .25409 .33309 .37319 .32683 .29781 Metetra
0 0 .164 r
.32683 .29781 .33309 .37319 .34724 .40991 .33708 .39414 Metetra
0 .247 .761 r
.33708 .39414 .34724 .40991 .363 .42469 .35294 .40653 Metetra
.285 .441 .842 r
.35294 .40653 .363 .42469 .37939 .43285 .36937 .41325 Metetra
.627 .611 .815 r
.36937 .41325 .37939 .43285 .39655 .42752 .38656 .40778 Metetra
.76 .668 .761 r
.38656 .40778 .39655 .42752 .41425 .41001 .40427 .39128 Metetra
.76 .678 .772 r
.40427 .39128 .41425 .41001 .43193 .39266 .42196 .37551 Metetra
.757 .694 .791 r
.42196 .37551 .43193 .39266 .44954 .37753 .43962 .36107 Metetra
.748 .7 .806 r
.43962 .36107 .44954 .37753 .46714 .36359 .45727 .34791 Metetra
.744 .709 .819 r
.45727 .34791 .46714 .36359 .48475 .35081 .47495 .33555 Metetra
.942 .733 .592 r
.47495 .33555 .48475 .35081 .50241 .33708 .49326 .26455 Metetra
.762 .532 .584 r
.49326 .26455 .50241 .33708 .52021 .24562 .51092 .20268 Metetra
.773 .572 .627 r
.51092 .20268 .52021 .24562 .53734 .19617 .52808 .16417 Metetra
.613 .508 .71 r
.52808 .16417 .53734 .19617 .5543 .16909 .5452 .1573 Metetra
.664 .741 .908 r
.5452 .1573 .5543 .16909 .57145 .16271 .56242 .15087 Metetra
.664 .741 .908 r
.56242 .15087 .57145 .16271 .58871 .15632 .57976 .1444 Metetra
.664 .741 .908 r
.57976 .1444 .58871 .15632 .60608 .14988 .5972 .1379 Metetra
.664 .741 .908 r
.5972 .1379 .60608 .14988 .62355 .14341 .61475 .13134 Metetra
.664 .741 .908 r
.61475 .13134 .62355 .14341 .64114 .13689 .63241 .12475 Metetra
.664 .741 .908 r
.63241 .12475 .64114 .13689 .65884 .13033 .65018 .11812 Metetra
.664 .741 .908 r
.65018 .11812 .65884 .13033 .67665 .12373 .66806 .11144 Metetra
.664 .741 .908 r
.66806 .11144 .67665 .12373 .69457 .11709 .68606 .10472 Metetra
.664 .741 .908 r
.68606 .10472 .69457 .11709 .7126 .11041 .70418 .09796 Metetra
.664 .741 .908 r
.70418 .09796 .7126 .11041 .73075 .10369 .72241 .09116 Metetra
.664 .741 .908 r
.72241 .09116 .73075 .10369 .74902 .09692 .74076 .08431 Metetra
.664 .741 .908 r
.09215 .3123 .10296 .32237 .11753 .31693 .10677 .30681 Metetra
.664 .741 .908 r
.10677 .30681 .11753 .31693 .13219 .31146 .12147 .30128 Metetra
.664 .741 .908 r
.12147 .30128 .13219 .31146 .14693 .30596 .13626 .29572 Metetra
.664 .741 .908 r
.13626 .29572 .14693 .30596 .16175 .30043 .15113 .29013 Metetra
.664 .741 .908 r
.15113 .29013 .16175 .30043 .17666 .29486 .16609 .2845 Metetra
.664 .741 .908 r
.16609 .2845 .17666 .29486 .19166 .28926 .18114 .27884 Metetra
.664 .741 .908 r
.18114 .27884 .19166 .28926 .20674 .28363 .19627 .27315 Metetra
.664 .741 .908 r
.19627 .27315 .20674 .28363 .22192 .27797 .2115 .26743 Metetra
.664 .741 .908 r
.2115 .26743 .22192 .27797 .23718 .27227 .22681 .26167 Metetra
.664 .741 .908 r
.22681 .26167 .23718 .27227 .25253 .26654 .24222 .25587 Metetra
.664 .741 .908 r
.24222 .25587 .25253 .26654 .26797 .26078 .25772 .25005 Metetra
.664 .741 .908 r
.25772 .25005 .26797 .26078 .28351 .25498 .27331 .24418 Metetra
.664 .741 .908 r
.27331 .24418 .28351 .25498 .29914 .24915 .28899 .23829 Metetra
.664 .741 .908 r
.28899 .23829 .29914 .24915 .31485 .24328 .30476 .23236 Metetra
.743 .269 0 r
.30476 .23236 .31485 .24328 .32683 .29781 .31873 .2549 Metetra
.959 .668 .237 r
.31873 .2549 .32683 .29781 .33708 .39414 .32682 .37848 Metetra
.024 .318 .805 r
.32682 .37848 .33708 .39414 .35294 .40653 .34277 .3889 Metetra
.349 .49 .859 r
.34277 .3889 .35294 .40653 .36937 .41325 .35928 .39363 Metetra
.628 .612 .815 r
.35928 .39363 .36937 .41325 .38656 .40778 .3765 .38803 Metetra
.746 .664 .77 r
.3765 .38803 .38656 .40778 .40427 .39128 .3942 .37313 Metetra
.755 .683 .782 r
.3942 .37313 .40427 .39128 .42196 .37551 .41192 .35825 Metetra
.747 .691 .798 r
.41192 .35825 .42196 .37551 .43962 .36107 .42962 .34474 Metetra
.743 .701 .812 r
.42962 .34474 .43962 .36107 .45727 .34791 .44732 .33209 Metetra
.883 .738 .696 r
.44732 .33209 .45727 .34791 .47495 .33555 .46548 .29779 Metetra
.888 .652 .575 r
.46548 .29779 .47495 .33555 .49326 .26455 .48416 .20925 Metetra
.749 .538 .609 r
.48416 .20925 .49326 .26455 .51092 .20268 .50167 .16692 Metetra
.676 .531 .68 r
.50167 .16692 .51092 .20268 .52808 .16417 .51881 .15187 Metetra
.663 .732 .901 r
.51881 .15187 .52808 .16417 .5452 .1573 .536 .1454 Metetra
.664 .741 .908 r
.536 .1454 .5452 .1573 .56242 .15087 .55329 .1389 Metetra
.664 .741 .908 r
.55329 .1389 .56242 .15087 .57976 .1444 .5707 .13236 Metetra
.664 .741 .908 r
.5707 .13236 .57976 .1444 .5972 .1379 .58821 .12577 Metetra
.664 .741 .908 r
.58821 .12577 .5972 .1379 .61475 .13134 .60583 .11914 Metetra
.664 .741 .908 r
.60583 .11914 .61475 .13134 .63241 .12475 .62357 .11247 Metetra
.664 .741 .908 r
.62357 .11247 .63241 .12475 .65018 .11812 .64142 .10576 Metetra
.664 .741 .908 r
.64142 .10576 .65018 .11812 .66806 .11144 .65938 .09901 Metetra
.664 .741 .908 r
.65938 .09901 .66806 .11144 .68606 .10472 .67746 .09221 Metetra
.664 .741 .908 r
.67746 .09221 .68606 .10472 .70418 .09796 .69565 .08537 Metetra
.664 .741 .908 r
.69565 .08537 .70418 .09796 .72241 .09116 .71397 .07848 Metetra
.664 .741 .908 r
.71397 .07848 .72241 .09116 .74076 .08431 .7324 .07155 Metetra
.664 .741 .908 r
.08123 .30213 .09215 .3123 .10677 .30681 .09589 .29658 Metetra
.664 .741 .908 r
.09589 .29658 .10677 .30681 .12147 .30128 .11064 .29099 Metetra
.664 .741 .908 r
.11064 .29099 .12147 .30128 .13626 .29572 .12548 .28537 Metetra
.664 .741 .908 r
.12548 .28537 .13626 .29572 .15113 .29013 .1404 .27972 Metetra
.664 .741 .908 r
.1404 .27972 .15113 .29013 .16609 .2845 .15541 .27403 Metetra
.664 .741 .908 r
.15541 .27403 .16609 .2845 .18114 .27884 .1705 .26831 Metetra
.664 .741 .908 r
.1705 .26831 .18114 .27884 .19627 .27315 .18569 .26256 Metetra
.664 .741 .908 r
.18569 .26256 .19627 .27315 .2115 .26743 .20097 .25677 Metetra
.664 .741 .908 r
.20097 .25677 .2115 .26743 .22681 .26167 .21634 .25095 Metetra
.664 .741 .908 r
.21634 .25095 .22681 .26167 .24222 .25587 .23179 .24509 Metetra
.664 .741 .908 r
.23179 .24509 .24222 .25587 .25772 .25005 .24735 .2392 Metetra
.664 .741 .908 r
.24735 .2392 .25772 .25005 .27331 .24418 .26299 .23327 Metetra
.664 .741 .908 r
.26299 .23327 .27331 .24418 .28899 .23829 .27873 .22731 Metetra
.664 .741 .908 r
.27873 .22731 .28899 .23829 .30476 .23236 .29456 .22131 Metetra
.536 .695 .941 r
.29456 .22131 .30476 .23236 .31873 .2549 .3102 .2194 Metetra
.977 .677 .314 r
.3102 .2194 .31873 .2549 .32682 .37848 .31647 .36274 Metetra
.119 .382 .839 r
.31647 .36274 .32682 .37848 .34277 .3889 .33251 .37132 Metetra
.398 .52 .864 r
.33251 .37132 .34277 .3889 .35928 .39363 .34909 .37459 Metetra
.631 .622 .823 r
.34909 .37459 .35928 .39363 .3765 .38803 .36633 .36886 Metetra
.738 .668 .781 r
.36633 .36886 .3765 .38803 .3942 .37313 .38404 .35508 Metetra
.746 .683 .79 r
.38404 .35508 .3942 .37313 .41192 .35825 .40179 .34115 Metetra
.74 .692 .805 r
.40179 .34115 .41192 .35825 .42962 .34474 .41952 .32835 Metetra
.766 .71 .799 r
.41952 .32835 .42962 .34474 .44732 .33209 .43735 .31352 Metetra
.944 .714 .558 r
.43735 .31352 .44732 .33209 .46548 .29779 .45707 .2147 Metetra
.705 .482 .584 r
.45707 .2147 .46548 .29779 .48416 .20925 .47498 .16846 Metetra
.706 .535 .654 r
.47498 .16846 .48416 .20925 .50167 .16692 .49228 .1464 Metetra
.638 .604 .799 r
.49228 .1464 .50167 .16692 .51881 .15187 .50943 .1399 Metetra
.664 .741 .908 r
.50943 .1399 .51881 .15187 .536 .1454 .52669 .13336 Metetra
.664 .741 .908 r
.52669 .13336 .536 .1454 .55329 .1389 .54406 .12679 Metetra
.664 .741 .908 r
.54406 .12679 .55329 .1389 .5707 .13236 .56153 .12016 Metetra
.664 .741 .908 r
.56153 .12016 .5707 .13236 .58821 .12577 .57912 .1135 Metetra
.664 .741 .908 r
.57912 .1135 .58821 .12577 .60583 .11914 .59682 .1068 Metetra
.664 .741 .908 r
.59682 .1068 .60583 .11914 .62357 .11247 .61463 .10005 Metetra
.664 .741 .908 r
.61463 .10005 .62357 .11247 .64142 .10576 .63255 .09326 Metetra
.664 .741 .908 r
.63255 .09326 .64142 .10576 .65938 .09901 .6506 .08642 Metetra
.664 .741 .908 r
.6506 .08642 .65938 .09901 .67746 .09221 .66875 .07954 Metetra
.664 .741 .908 r
.66875 .07954 .67746 .09221 .69565 .08537 .68703 .07262 Metetra
.664 .741 .908 r
.68703 .07262 .69565 .08537 .71397 .07848 .70542 .06565 Metetra
.664 .741 .908 r
.70542 .06565 .71397 .07848 .7324 .07155 .72394 .05863 Metetra
.664 .741 .908 r
.07019 .29185 .08123 .30213 .09589 .29658 .0849 .28624 Metetra
.664 .741 .908 r
.0849 .28624 .09589 .29658 .11064 .29099 .09969 .28059 Metetra
.664 .741 .908 r
.09969 .28059 .11064 .29099 .12548 .28537 .11458 .27491 Metetra
.664 .741 .908 r
.11458 .27491 .12548 .28537 .1404 .27972 .12955 .26919 Metetra
.664 .741 .908 r
.12955 .26919 .1404 .27972 .15541 .27403 .14461 .26344 Metetra
.664 .741 .908 r
.14461 .26344 .15541 .27403 .1705 .26831 .15975 .25766 Metetra
.664 .741 .908 r
.15975 .25766 .1705 .26831 .18569 .26256 .17499 .25184 Metetra
.664 .741 .908 r
.17499 .25184 .18569 .26256 .20097 .25677 .19032 .24599 Metetra
.664 .741 .908 r
.19032 .24599 .20097 .25677 .21634 .25095 .20574 .24011 Metetra
.664 .741 .908 r
.20574 .24011 .21634 .25095 .23179 .24509 .22125 .23418 Metetra
.664 .741 .908 r
.22125 .23418 .23179 .24509 .24735 .2392 .23686 .22823 Metetra
.664 .741 .908 r
.23686 .22823 .24735 .2392 .26299 .23327 .25256 .22223 Metetra
.664 .741 .908 r
.25256 .22223 .26299 .23327 .27873 .22731 .26835 .2162 Metetra
.664 .741 .908 r
.26835 .2162 .27873 .22731 .29456 .22131 .28424 .21014 Metetra
.664 .741 .908 r
.28424 .21014 .29456 .22131 .3102 .2194 .30023 .20404 Metetra
.965 .652 .373 r
.30023 .20404 .3102 .2194 .31647 .36274 .30636 .34204 Metetra
.088 .283 .766 r
.30636 .34204 .31647 .36274 .33251 .37132 .32214 .354 Metetra
.427 .542 .87 r
.32214 .354 .33251 .37132 .34909 .37459 .33879 .35623 Metetra
.633 .633 .832 r
.33879 .35623 .34909 .37459 .36633 .36886 .35606 .35039 Metetra
.735 .675 .792 r
.35606 .35039 .36633 .36886 .38404 .35508 .37379 .33731 Metetra
.738 .684 .799 r
.37379 .33731 .38404 .35508 .40179 .34115 .39155 .32429 Metetra
.753 .701 .803 r
.39155 .32429 .40179 .34115 .41952 .32835 .40938 .3105 Metetra
.942 .717 .569 r
.40938 .3105 .41952 .32835 .43735 .31352 .42966 .21958 Metetra
.7 .473 .576 r
.42966 .21958 .43735 .31352 .45707 .2147 .44805 .16915 Metetra
.723 .535 .636 r
.44805 .16915 .45707 .2147 .47498 .16846 .46561 .14093 Metetra
.618 .536 .74 r
.46561 .14093 .47498 .16846 .49228 .1464 .48273 .13437 Metetra
.664 .741 .908 r
.48273 .13437 .49228 .1464 .50943 .1399 .49994 .1278 Metetra
.664 .741 .908 r
.49994 .1278 .50943 .1399 .52669 .13336 .51727 .12119 Metetra
.664 .741 .908 r
.51727 .12119 .52669 .13336 .54406 .12679 .53471 .11453 Metetra
.664 .741 .908 r
.53471 .11453 .54406 .12679 .56153 .12016 .55226 .10783 Metetra
.664 .741 .908 r
.55226 .10783 .56153 .12016 .57912 .1135 .56992 .10109 Metetra
.664 .741 .908 r
.56992 .10109 .57912 .1135 .59682 .1068 .58769 .0943 Metetra
.664 .741 .908 r
.58769 .0943 .59682 .1068 .61463 .10005 .60558 .08748 Metetra
.664 .741 .908 r
.60558 .08748 .61463 .10005 .63255 .09326 .62358 .0806 Metetra
.664 .741 .908 r
.62358 .0806 .63255 .09326 .6506 .08642 .6417 .07369 Metetra
.664 .741 .908 r
.6417 .07369 .6506 .08642 .66875 .07954 .65994 .06672 Metetra
.664 .741 .908 r
.65994 .06672 .66875 .07954 .68703 .07262 .6783 .05972 Metetra
.664 .741 .908 r
.6783 .05972 .68703 .07262 .70542 .06565 .69678 .05266 Metetra
.664 .741 .908 r
.69678 .05266 .70542 .06565 .72394 .05863 .71537 .04556 Metetra
.664 .741 .908 r
.05902 .28146 .07019 .29185 .0849 .28624 .07378 .27578 Metetra
.664 .741 .908 r
.07378 .27578 .0849 .28624 .09969 .28059 .08863 .27007 Metetra
.664 .741 .908 r
.08863 .27007 .09969 .28059 .11458 .27491 .10356 .26433 Metetra
.664 .741 .908 r
.10356 .26433 .11458 .27491 .12955 .26919 .11858 .25855 Metetra
.664 .741 .908 r
.11858 .25855 .12955 .26919 .14461 .26344 .13369 .25274 Metetra
.664 .741 .908 r
.13369 .25274 .14461 .26344 .15975 .25766 .14889 .24689 Metetra
.664 .741 .908 r
.14889 .24689 .15975 .25766 .17499 .25184 .16417 .24101 Metetra
.664 .741 .908 r
.16417 .24101 .17499 .25184 .19032 .24599 .17956 .2351 Metetra
.664 .741 .908 r
.17956 .2351 .19032 .24599 .20574 .24011 .19503 .22915 Metetra
.664 .741 .908 r
.19503 .22915 .20574 .24011 .22125 .23418 .2106 .22316 Metetra
.664 .741 .908 r
.2106 .22316 .22125 .23418 .23686 .22823 .22626 .21713 Metetra
.664 .741 .908 r
.22626 .21713 .23686 .22823 .25256 .22223 .24201 .21107 Metetra
.664 .741 .908 r
.24201 .21107 .25256 .22223 .26835 .2162 .25786 .20498 Metetra
.664 .741 .908 r
.25786 .20498 .26835 .2162 .28424 .21014 .27381 .19884 Metetra
.664 .741 .908 r
.27381 .19884 .28424 .21014 .30023 .20404 .28986 .19267 Metetra
.929 .546 .197 r
.28986 .19267 .30023 .20404 .30636 .34204 .30188 .24309 Metetra
0 0 .289 r
.30188 .24309 .30636 .34204 .32214 .354 .31166 .337 Metetra
.459 .567 .876 r
.31166 .337 .32214 .354 .33879 .35623 .32838 .33806 Metetra
.635 .637 .836 r
.32838 .33806 .33879 .35623 .35606 .35039 .34569 .33211 Metetra
.726 .675 .8 r
.34569 .33211 .35606 .35039 .37379 .33731 .36343 .3199 Metetra
.741 .691 .803 r
.36343 .3199 .37379 .33731 .39155 .32429 .38125 .30684 Metetra
.939 .719 .579 r
.38125 .30684 .39155 .32429 .40938 .3105 .40203 .22163 Metetra
.715 .486 .578 r
.40203 .22163 .40938 .3105 .42966 .21958 .42093 .16813 Metetra
.725 .526 .621 r
.42093 .16813 .42966 .21958 .44805 .16915 .4388 .13542 Metetra
.603 .494 .703 r
.4388 .13542 .44805 .16915 .46561 .14093 .45588 .12881 Metetra
.664 .741 .908 r
.45588 .12881 .46561 .14093 .48273 .13437 .47306 .12221 Metetra
.664 .741 .908 r
.47306 .12221 .48273 .13437 .49994 .1278 .49034 .11556 Metetra
.664 .741 .908 r
.49034 .11556 .49994 .1278 .51727 .12119 .50774 .10886 Metetra
.664 .741 .908 r
.50774 .10886 .51727 .12119 .53471 .11453 .52525 .10213 Metetra
.664 .741 .908 r
.52525 .10213 .53471 .11453 .55226 .10783 .54287 .09535 Metetra
.664 .741 .908 r
.54287 .09535 .55226 .10783 .56992 .10109 .56061 .08853 Metetra
.664 .741 .908 r
.56061 .08853 .56992 .10109 .58769 .0943 .57846 .08166 Metetra
.664 .741 .908 r
.57846 .08166 .58769 .0943 .60558 .08748 .59643 .07475 Metetra
.664 .741 .908 r
.59643 .07475 .60558 .08748 .62358 .0806 .61451 .0678 Metetra
.664 .741 .908 r
.61451 .0678 .62358 .0806 .6417 .07369 .63271 .0608 Metetra
.664 .741 .908 r
.63271 .0608 .6417 .07369 .65994 .06672 .65103 .05375 Metetra
.664 .741 .908 r
.65103 .05375 .65994 .06672 .6783 .05972 .66946 .04666 Metetra
.664 .741 .908 r
.66946 .04666 .6783 .05972 .69678 .05266 .68802 .03952 Metetra
.664 .741 .908 r
.68802 .03952 .69678 .05266 .71537 .04556 .70671 .03234 Metetra
.664 .741 .908 r
.04774 .27095 .05902 .28146 .07378 .27578 .06255 .26522 Metetra
.664 .741 .908 r
.06255 .26522 .07378 .27578 .08863 .27007 .07744 .25944 Metetra
.664 .741 .908 r
.07744 .25944 .08863 .27007 .10356 .26433 .09242 .25364 Metetra
.664 .741 .908 r
.09242 .25364 .10356 .26433 .11858 .25855 .10749 .2478 Metetra
.664 .741 .908 r
.10749 .2478 .11858 .25855 .13369 .25274 .12265 .24192 Metetra
.664 .741 .908 r
.12265 .24192 .13369 .25274 .14889 .24689 .1379 .23601 Metetra
.664 .741 .908 r
.1379 .23601 .14889 .24689 .16417 .24101 .15324 .23006 Metetra
.664 .741 .908 r
.15324 .23006 .16417 .24101 .17956 .2351 .16867 .22408 Metetra
.664 .741 .908 r
.16867 .22408 .17956 .2351 .19503 .22915 .1842 .21806 Metetra
.664 .741 .908 r
.1842 .21806 .19503 .22915 .2106 .22316 .19982 .21201 Metetra
.664 .741 .908 r
.19982 .21201 .2106 .22316 .22626 .21713 .21553 .20592 Metetra
.664 .741 .908 r
.21553 .20592 .22626 .21713 .24201 .21107 .23135 .19979 Metetra
.664 .741 .908 r
.23135 .19979 .24201 .21107 .25786 .20498 .24725 .19362 Metetra
.664 .741 .908 r
.24725 .19362 .25786 .20498 .27381 .19884 .26326 .18742 Metetra
.664 .741 .908 r
.26326 .18742 .27381 .19884 .28986 .19267 .27936 .18118 Metetra
0 .109 .623 r
.27936 .18118 .28986 .19267 .30188 .24309 .29411 .19393 Metetra
.946 .665 .208 r
.29411 .19393 .30188 .24309 .31166 .337 .30119 .3186 Metetra
.443 .539 .86 r
.30119 .3186 .31166 .337 .32838 .33806 .31786 .32035 Metetra
.637 .646 .843 r
.31786 .32035 .32838 .33806 .34569 .33211 .3352 .31429 Metetra
.723 .681 .808 r
.3352 .31429 .34569 .33211 .36343 .3199 .35297 .30252 Metetra
.936 .719 .585 r
.35297 .30252 .36343 .3199 .38125 .30684 .37425 .22073 Metetra
.724 .494 .578 r
.37425 .22073 .38125 .30684 .40203 .22163 .39365 .16532 Metetra
.723 .518 .612 r
.39365 .16532 .40203 .22163 .42093 .16813 .41185 .12988 Metetra
.593 .471 .682 r
.41185 .12988 .42093 .16813 .4388 .13542 .42888 .12323 Metetra
.663 .74 .907 r
.42888 .12323 .4388 .13542 .45588 .12881 .44602 .11658 Metetra
.664 .741 .908 r
.44602 .11658 .45588 .12881 .47306 .12221 .46327 .1099 Metetra
.664 .741 .908 r
.46327 .1099 .47306 .12221 .49034 .11556 .48063 .10317 Metetra
.664 .741 .908 r
.48063 .10317 .49034 .11556 .50774 .10886 .4981 .0964 Metetra
.664 .741 .908 r
.4981 .0964 .50774 .10886 .52525 .10213 .51568 .08958 Metetra
.664 .741 .908 r
.51568 .08958 .52525 .10213 .54287 .09535 .53338 .08272 Metetra
.664 .741 .908 r
.53338 .08272 .54287 .09535 .56061 .08853 .55119 .07582 Metetra
.664 .741 .908 r
.55119 .07582 .56061 .08853 .57846 .08166 .56912 .06887 Metetra
.664 .741 .908 r
.56912 .06887 .57846 .08166 .59643 .07475 .58716 .06188 Metetra
.664 .741 .908 r
.58716 .06188 .59643 .07475 .61451 .0678 .60532 .05484 Metetra
.664 .741 .908 r
.60532 .05484 .61451 .0678 .63271 .0608 .6236 .04775 Metetra
.664 .741 .908 r
.6236 .04775 .63271 .0608 .65103 .05375 .642 .04062 Metetra
.664 .741 .908 r
.642 .04062 .65103 .05375 .66946 .04666 .66052 .03344 Metetra
.664 .741 .908 r
.66052 .03344 .66946 .04666 .68802 .03952 .67916 .02622 Metetra
.664 .741 .908 r
.67916 .02622 .68802 .03952 .70671 .03234 .69793 .01894 Metetra
.664 .741 .908 r
.03634 .26033 .04774 .27095 .06255 .26522 .05119 .25453 Metetra
.664 .741 .908 r
.05119 .25453 .06255 .26522 .07744 .25944 .06613 .2487 Metetra
.664 .741 .908 r
.06613 .2487 .07744 .25944 .09242 .25364 .08116 .24283 Metetra
.664 .741 .908 r
.08116 .24283 .09242 .25364 .10749 .2478 .09628 .23692 Metetra
.664 .741 .908 r
.09628 .23692 .10749 .2478 .12265 .24192 .11148 .23098 Metetra
.664 .741 .908 r
.11148 .23098 .12265 .24192 .1379 .23601 .12679 .225 Metetra
.664 .741 .908 r
.12679 .225 .1379 .23601 .15324 .23006 .14218 .21899 Metetra
.664 .741 .908 r
.14218 .21899 .15324 .23006 .16867 .22408 .15767 .21294 Metetra
.664 .741 .908 r
.15767 .21294 .16867 .22408 .1842 .21806 .17325 .20686 Metetra
.664 .741 .908 r
.17325 .20686 .1842 .21806 .19982 .21201 .18892 .20073 Metetra
.664 .741 .908 r
.18892 .20073 .19982 .21201 .21553 .20592 .20469 .19457 Metetra
.664 .741 .908 r
.20469 .19457 .21553 .20592 .23135 .19979 .22056 .18838 Metetra
.664 .741 .908 r
.22056 .18838 .23135 .19979 .24725 .19362 .23652 .18214 Metetra
.664 .741 .908 r
.23652 .18214 .24725 .19362 .26326 .18742 .25259 .17587 Metetra
.664 .741 .908 r
.25259 .17587 .26326 .18742 .27936 .18118 .26875 .16955 Metetra
.663 .741 .908 r
.26875 .16955 .27936 .18118 .29411 .19393 .28501 .16322 Metetra
.87 .553 .037 r
.28501 .16322 .29411 .19393 .30119 .3186 .29634 .22399 Metetra
0 0 .352 r
.29634 .22399 .30119 .3186 .31786 .32035 .3073 .30185 Metetra
.632 .636 .836 r
.3073 .30185 .31786 .32035 .3352 .31429 .32466 .29587 Metetra
.929 .715 .592 r
.32466 .29587 .3352 .31429 .35297 .30252 .34643 .21681 Metetra
.726 .496 .578 r
.34643 .21681 .35297 .30252 .37425 .22073 .36628 .1607 Metetra
.718 .51 .607 r
.36628 .1607 .37425 .22073 .39365 .16532 .38475 .1243 Metetra
.587 .457 .671 r
.38475 .1243 .39365 .16532 .41185 .12988 .40174 .11761 Metetra
.663 .74 .907 r
.40174 .11761 .41185 .12988 .42888 .12323 .41884 .11093 Metetra
.664 .741 .908 r
.41884 .11093 .42888 .12323 .44602 .11658 .43605 .10421 Metetra
.664 .741 .908 r
.43605 .10421 .44602 .11658 .46327 .1099 .45337 .09744 Metetra
.664 .741 .908 r
.45337 .09744 .46327 .1099 .48063 .10317 .4708 .09063 Metetra
.664 .741 .908 r
.4708 .09063 .48063 .10317 .4981 .0964 .48835 .08378 Metetra
.664 .741 .908 r
.48835 .08378 .4981 .0964 .51568 .08958 .506 .07688 Metetra
.664 .741 .908 r
.506 .07688 .51568 .08958 .53338 .08272 .52377 .06994 Metetra
.664 .741 .908 r
.52377 .06994 .53338 .08272 .55119 .07582 .54166 .06296 Metetra
.664 .741 .908 r
.54166 .06296 .55119 .07582 .56912 .06887 .55966 .05592 Metetra
.664 .741 .908 r
.55966 .05592 .56912 .06887 .58716 .06188 .57778 .04885 Metetra
.664 .741 .908 r
.57778 .04885 .58716 .06188 .60532 .05484 .59602 .04172 Metetra
.664 .741 .908 r
.59602 .04172 .60532 .05484 .6236 .04775 .61438 .03455 Metetra
.664 .741 .908 r
.61438 .03455 .6236 .04775 .642 .04062 .63286 .02733 Metetra
.664 .741 .908 r
.63286 .02733 .642 .04062 .66052 .03344 .65147 .02007 Metetra
.664 .741 .908 r
.65147 .02007 .66052 .03344 .67916 .02622 .6702 .01275 Metetra
.664 .741 .908 r
.6702 .01275 .67916 .02622 .69793 .01894 .68905 .00539 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(-1)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(-0.5)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(0.5)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
gsave
.29165 .07573 -70.3112 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{331.375, 268.812},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006N0001D2000`400?l00000o`00003ooooooonO
ooooo`00oooooonOooooo`00oooooonOooooo`00oooooolIooooo`Co000000?o410@ooooooooool0
Ooooool00?oooooo6oooool00ol0003oooooooooo`21ooooo`00oooooolKooooo`03o`000?oooooo
oooo087ooooo003ooooooa_ooooo00?o0000ooooooooool0POooool00?oooooo6oooool00ol0003o
ooooooooo`21ooooo`00oooooolKooooo`03o`000?oooooooooo087ooooo003ooooooa_ooooo00?o
0000ooooooooool04?ooool4o`000003oa0@4?oooooooooo06[ooooo003ooooooaWooooo00?oEEEE
ofIVI_l000005?ooool00ol0003oooooooooo`1/ooooo`00oooooolUooooo`Ko00001Oooool00ol0
003oooooooooo`1/ooooo`00ooooool`ooooo`03o`000?oooooooooo06cooooo003ooooooc3ooooo
00?o0000ooooooooool0K?ooool00?oooooo<?ooool00ol0003oooooooooo`1/ooooo`00ooooool`
ooooo`03o`000?oooooooooo06cooooo003ooooooaoooooo0_l0000=ooooo`03oeEEEOmVIVKo0000
06kooooo003ooooooacooooo0ol000000ooooooo0000ooooo`1mooooo`00oooooolJooooo`;o0000
0_ooool4o`0007gooooo003ooooooaOooooo0ol000001?oooooo0000o`000?l00002ojVmj003o`00
0?oooooo000007cooooo003ooooooaGooooo0_l000001?oooooo0000o`000?l00005ojVmj0?o0000
O?ooool00?oooooo4_ooool6o`000003ojVmj?l0003oZKgX00GoZKgX00Co0000ojVmj?l0003o0000
Noooool00?oooooo3oooool3o`000003ooooool0003o000000GoZKgX00?o0000ojVmj?nY_NP00onY
_NP01Ol0003oZKgXo`000?oooooo000007[ooooo003oooooo`gooooo0_l00002ooooo`;o00002?nY
_NP00ol0003oZKgXojVmj002ojVmj0Go0000N_ooool00?oooooo2_ooool3o`000006ooooool0003o
0000o`000?nY_NSo00002?nY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ooooool00000
NOooool00?oooooo2?ooool2o`0000;ooooo0_l00005ojVmj003o`000?nY_NSoZKgX00GoZKgX0ol0
0002ojVmj007o`000?nY_NSoZKgXojVmj?l0003oooooo`00001hooooo`00ooooool5ooooo`?o0000
0_ooool2o`0000SoZKgX00?o0000ojVmj?nY_NP00_nY_NP2o`000003ojVmj?l0003oZKgX00?oZKgX
00Co0000ojVmj?nY_NSoZKgX0_l0001hooooo`00ooooool3ooooo`;o000000?oooooo`000?ooool0
0_l000000onY_NSo0000ojVmj008ojVmj004o`000?nY_NSo0000o`0000CoZKgX00Go0000ojVmj?nY
_NSoZKgXo`000004ojVmj0;o0000Moooool00?oooooo0ol00003ooooo`;o00001?nY_NP00ol0003o
ZKgXojVmj006ojVmj0;o00001onY_NP01?l0003oZKgXojVmj?l00003ojVmj0?o0000Moooool00<Ko
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM027ooooo0_l00003ooooo`?o00001onY_NP00ol0003oZKgXojVmj002ojVmj0?o000000?oZKgX
o`000?nY_NP01onY_NP00ol0003oZKgXo`000003o`0000;oZKgX0_l0001fooooo`00a_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01gooooo0ol00002
ooooo`?o00000_nY_NP00ol0003oZKgXojVmj006ojVmj004o`000?nY_NSo0000o`0000GoZKgX00?o
0000ojVmj?nY_NP01OnY_NP3o`0000KoZKgX0_l0001eooooo`00a_ooool01Ol@413ooooooooooooo
oooo410@013ooooo00?o0000ooooooooool06Oooool3o`0000;ooooo0ol00006ojVmj003o`000?nY
_NSoZKgX00CoZKgX0ol00008ojVmj004o`000?nY_NSoZKgXojVmj0?o000000?oZKgXo`000?l00000
1onY_NP00ol0003oooooooooo`1cooooo`00a_ooool01Ol0003ooooooooooooooooo000000oooooo
00?oMgMgoc8b<_ooool06?ooool3o`000006ooooool0003o0000o`000?nY_NSo00002?nY_NP00ol0
003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01_nY_NP01?l0003oZKgXo`000?l00005
ojVmj003o`000?nY_NSoZKgX00GoZKgX0_l0001dooooo`00Q?ooool2o`0000;ooooo0_l0000loooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Kooooo0ol0
0002ooooo`;o00001OnY_NP00ol0003oZKgXojVmj005ojVmj0?o00001_nY_NP00ol0003oZKgXojVm
j005ojVmj0;o00001onY_NP2o`0000GoZKgX1?l0001cooooo`00Q?ooool01_o^k^ko8B4QohN7Qonj
^[[o0000omgMgCcooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo01Ko
oooo0_l00002ooooo`?o00002?nY_NP01?l0003oZKgXojVmj?nY_NP3o`000003ojVmj?l0003oZKgX
00OoZKgX00Co0000ojVmj?nY_NSoZKgX0ol000000onY_NSo0000ojVmj006ojVmj0;o00000_nY_NP3
o`0000;oZKgX0_l0001cooooo`00QOooool01?oMgMgo0000oa0@4?o<c<`mooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Cooooo`?o000000Coooooo`000?l0003o0000
0_nY_NP00ol0003oZKgXojVmj006ojVmj004o`000?nY_NSo0000o`0000GoZKgX00?o0000ojVmj?nY
_NP01OnY_NP01?l0003oZKgXo`000?l00005ojVmj003o`000?nY_NSoZKgX00CoZKgX1?l00006ojVm
j0;o0000L_ooool008Gooooo00Cok^k^ob4Q8Ol@413ok^k^?Oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo1?l0000@ooooo`;o000000Coooooo`000?l0003o00001_nY_NP00ol0003oZKgXojVm
j005ojVmj0;o00002?nY_NP00ol0003oZKgXojVmj003ojVmj0?o00002?nY_NP01?l0003oZKgXojVm
j?nY_NP3o`000003ojVmj?l0003oZKgX00OoZKgX0_l0001aooooo`00QOooool01?lQ8B7oMgMgogMg
Molb<S9Oooooo`?o000000Goooooo`000?l0003oZKgXo`000008ojVmj004o`000?nY_NSoZKgXojVm
j0?o000000?oZKgXo`000?nY_NP01onY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVm
j?nY_NP01_nY_NP01?l0003oZKgXo`000?l00002ojVmj004o`000?nY_NSoZKgXo`0000OoZKgX0_l0
001aooooo`00Q?ooool2o`0000;ooooo0_l0001Looooo`;o00000_ooool2o`0000CoZKgX00?o0000
ojVmj?nY_NP01OnY_NP01?l0003oZKgXo`000?l00005ojVmj003o`000?nY_NSoZKgX00GoZKgX0ol0
0006ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00004ojVmj005o`000?nY_NSoZKgXojVmj?l00000
0onY_NP3o`000003ojVmj?l0003o0000073ooooo003Sooooo`?o00000_ooool2o`0000OoZKgX00?o
0000ojVmj?nY_NP01?nY_NP2o`0000SoZKgX00?o0000ojVmj?nY_NP00_nY_NP2o`000003ojVmj?l0
003oZKgX00OoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX00;oZKgX00Ko
0000ojVmj?nY_NSoZKgXo`000?nY_NP2o`0000GoZKgX0_l0001_ooooo`00h?ooool3o`0000;ooooo
0ol000000onY_NSo0000ojVmj007ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP00ol0003oZKgX
ojVmj006ojVmj004o`000?nY_NSo0000o`0000CoZKgX00?o0000ojVmj?nY_NP01OnY_NP3o`0000Ko
ZKgX00Go0000ojVmj?nY_NSoZKgXo`000003ojVmj0;o00002?nY_NP00ol0003oooooooooo`1]oooo
o`00g_ooool2o`0000?ooooo0_l00005ojVmj003o`000?nY_NSoZKgX00GoZKgX0ol00006ojVmj003
o`000?nY_NSoZKgX00CoZKgX0ol00007ojVmj003o`000?nY_NSoZKgX00;oZKgX0_l000000onY_NSo
0000ojVmj007ojVmj003o`000?nY_NSoZKgX00Co000000?oZKgXo`000?nY_NP01onY_NP2o`0006ko
oooo003Kooooo`Co00000_ooool2o`0000SoZKgX00Co0000ojVmj?nY_NSoZKgX0ol000000onY_NSo
0000ojVmj007ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP00ol0003oZKgXojVmj006ojVmj004
o`000?nY_NSo0000o`0000CoZKgX00?o0000ojVmj?nY_NP01OnY_NP01?l0003oZKgXo`000?l00005
ojVmj003o`000?nY_NSoZKgX00GoZKgX0ol0001]ooooo`00fOooool2o`0000?ooooo0ol00002ojVm
j003o`000?nY_NSoZKgX00GoZKgX00Co0000ojVmj?l0003o00001OnY_NP00ol0003oZKgXojVmj005
ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj004ojVmj0?o00001onY_NP00ol0003oZKgXojVmj004
ojVmj0;o000000?oZKgXo`000?nY_NP01OnY_NP01?l0003oZKgXojVmj?nY_NP3o`000003ojVmj?l0
003o000006gooooo003Fooooo`?o00000_ooool3o`0000KoZKgX00?o0000ojVmj?nY_NP01?nY_NP2
o`0000SoZKgX00Co0000ojVmj?nY_NSoZKgX0ol000000onY_NSo0000ojVmj007ojVmj003o`000?nY
_NSoZKgX00?o00000_nY_NP00ol0003oZKgXojVmj006ojVmj003o`000?nY_NSoZKgX00?o000000Go
ZKgXo`000?nY_NSoZKgXo`000005ojVmj004o`000?nY_NSo0000o`0000GoZKgX0_l0001/ooooo`00
e?ooool2o`0000;ooooo0ol000000onY_NSo0000ojVmj007ojVmj003o`000?nY_NSoZKgX00?o0000
0_nY_NP00ol0003oZKgXojVmj005ojVmj004o`000?nY_NSo0000o`0000GoZKgX00?o0000ojVmj?nY
_NP01OnY_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP01OnY_NP3o`0000GoZKgX00?o0000ojVmj?l0
00001?nY_NP3o`0000SoZKgX0_l0001[ooooo`00dOooool3o`0000;ooooo0_l00005ojVmj003o`00
0?nY_NSoZKgX00GoZKgX0ol00006ojVmj003o`000?nY_NSoZKgX00CoZKgX0_l00008ojVmj004o`00
0?nY_NSoZKgXojVmj0?o000000?oZKgXo`000?nY_NP01onY_NP01?l0003oZKgXojVmj?nY_NP3o`00
0003ojVmj?l0003oZKgX00KoZKgX0_l000001?nY_NSo0000o`000?l00002ojVmj003o`000?nY_NSo
ZKgX00KoZKgX0_l0001[ooooo`00coooool3o`0000;ooooo0_l00008ojVmj004o`000?nY_NSoZKgX
ojVmj0?o000000?oZKgXo`000?nY_NP01onY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003o
ZKgX00OoZKgX00Co0000ojVmj?l0003o00001OnY_NP00ol0003oZKgXojVmj005ojVmj004o`000?nY
_NSo0000o`0000GoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP0
1?nY_NP4o`0006[ooooo003<ooooo`?o00000_ooool3o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY
_NP01?l0003oZKgXo`000?l00005ojVmj003o`000?nY_NSoZKgX00GoZKgX0ol00005ojVmj003o`00
0?nY_NSoZKgX00GoZKgX0_l00008ojVmj003o`000?nY_NSoZKgX00?oZKgX0ol00008ojVmj004o`00
0?nY_NSoZKgXojVmj0;o000000?oZKgXo`000?nY_NP01onY_NP00ol0003oZKgXojVmj003o`0000;o
ZKgX00?o0000ooooool00000JOooool00<Wooooo0ol00002ooooo`?o00001_nY_NP00ol0003oZKgX
ojVmj004ojVmj0;o00002?nY_NP01?l0003oZKgXojVmj?nY_NP3o`000003ojVmj?l0003oZKgX00Ko
ZKgX00?o0000ojVmj?nY_NP00_nY_NP2o`000003ojVmj?l0003oZKgX00OoZKgX00?o0000ojVmj?nY
_NP00ol00002ojVmj003o`000?nY_NSoZKgX00KoZKgX00Co0000ojVmj?l0003o00000onY_NP2o`00
00OoZKgX0ol00006ojVmj0;o0000JOooool00<Oooooo0_l00002ooooo`?o000000?oZKgXo`000?nY
_NP01onY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP01?l0003o
ZKgXo`000?l00005ojVmj003o`000?nY_NSoZKgX00GoZKgX00Co0000ojVmj?l0003o00001?nY_NP0
0ol0003oZKgXojVmj005ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj004ojVmj0?o00001OnY_NP0
0ol0003oZKgXo`000004ojVmj0;o000000?oZKgXo`000?nY_NP01onY_NP2o`0006Sooooo0034oooo
o`?o00000_ooool2o`0000GoZKgX00?o0000ojVmj?nY_NP01OnY_NP3o`0000KoZKgX00?o0000ojVm
j?nY_NP01?nY_NP2o`0000SoZKgX00?o0000ojVmj?nY_NP00onY_NP3o`0000OoZKgX00?o0000ojVm
j?nY_NP00_nY_NP2o`000003ojVmj?l0003oZKgX00OoZKgX00?o0000ojVmj?nY_NP00ol00002ojVm
j003o`000?nY_NSoZKgX00?oZKgX00Go0000ojVmj?nY_NSo0000ojVmj002o`0000CoZKgX00?o0000
ojVmj?nY_NP01OnY_NP2o`0006Sooooo0032ooooo`;o000000?oooooo`000?ooool00_l00008ojVm
j004o`000?nY_NSoZKgXojVmj0?o000000?oZKgXo`000?nY_NP01onY_NP00ol0003oZKgXojVmj003
o`000003ojVmj?l0003oZKgX00OoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSo
ZKgX00KoZKgX00Co0000ojVmj?l0003o00001?nY_NP00ol0003oZKgXojVmj005ojVmj0?o00001_nY
_NP00ol0003oZKgXojVmj002ojVmj003o`000?nY_NSo000000;o00001onY_NP00ol0003oZKgXojVm
j003ojVmj0Co0000Ioooool009Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Tooooo`?o00000_oo
ool3o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP01?l0003oZKgXo`000?l00005ojVmj003o`00
0?nY_NSoZKgX00GoZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00GoZKgX0ol00006ojVmj003o`00
0?nY_NSoZKgX00CoZKgX0ol00007ojVmj004o`000?nY_NSoZKgXojVmj0?o000000?oZKgXo`000?nY
_NP01onY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP00ol0003o
ZKgXojVmj003o`0000;oZKgX00?o0000ooooool00000I_ooool009Kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Rooooo`;o00000_ooool3o`0000KoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000So
ZKgX00Co0000ojVmj?nY_NSoZKgX0ol000000onY_NSo0000ojVmj006ojVmj003o`000?nY_NSoZKgX
00;oZKgX0_l000000onY_NSo0000ojVmj007ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP00ol0
003oZKgXojVmj005ojVmj004o`000?nY_NSo0000o`0000GoZKgX00?o0000ojVmj?nY_NP01OnY_NP3
o`000003ojVmj?l0003oZKgX00?oZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000KoZKgX0_l0001V
ooooo`00U_ooool01Ol@413ooooooooooooooooo410@01oooooo0ol000001_oooooo0000o`000?l0
003oZKgXo`0000SoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX00GoZKgX
00Co0000ojVmj?l0003o00001OnY_NP00ol0003oZKgXojVmj005ojVmj004o`000?nY_NSo0000o`00
00CoZKgX00?o0000ojVmj?nY_NP01OnY_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`00
00SoZKgX00Co0000ojVmj?nY_NSoZKgX0ol000001OnY_NSo0000ojVmj?nY_NSo000000GoZKgX00?o
0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj007ojVmj0;o0000IOooool009Kooooo00Go0000
ooooooooooooooooo`00000Mooooo`;o00000_ooool2o`0000GoZKgX00?o0000ojVmj?nY_NP01OnY
_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000SoZKgX00?o0000ojVmj?nY_NP00onY
_NP3o`0000OoZKgX00?o0000ojVmj?nY_NP00_nY_NP2o`000003ojVmj?l0003oZKgX00OoZKgX00?o
0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX00GoZKgX00Co0000ojVmj?l0003o0000
1OnY_NP00ol0003oZKgXo`000005ojVmj0?o00001OnY_NP00ol0003oZKgXojVmj005ojVmj0?o0000
4Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd0?Oooool009Kooooo00Go0000ooooooooooooooooo`00000Jooooo`?o000000Coooooo`00
0?l0003o00002?nY_NP01?l0003oZKgXojVmj?nY_NP3o`000003ojVmj?l0003oZKgX00OoZKgX00?o
0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX00GoZKgX00?o0000ojVmj?nY_NP00ol0
0002ojVmj003o`000?nY_NSoZKgX00KoZKgX00Co0000ojVmj?l0003o00001?nY_NP00ol0003oZKgX
ojVmj005ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj004ojVmj0;o00002?nY_NP2o`0000;oZKgX
0ol000000onY_NSo0000ojVmj006ojVmj004o`000?nY_NSoZKgXojVmj0?o000000?oZKgXo`000?l0
00004Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
03cooooo002Fooooo`05oa0@4?ooooooooooooooool@41005oooool3o`0000;ooooo0ol00002ojVm
j003o`000?nY_NSoZKgX00GoZKgX00Co0000ojVmj?l0003o00001OnY_NP00ol0003oZKgXojVmj005
ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj004ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj004
ojVmj0?o00001onY_NP01?l0003oZKgXojVmj?nY_NP3o`000003ojVmj?l0003oZKgX00OoZKgX00?o
0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj007ojVmj0Co00001OnY_NP00ol0003oZKgXojVm
j004ojVmj004o`000?nY_NSo0000o`0000GoZKgX0_l00008ooooo`Ko00000_ooool01Ol@413ooooo
oooooooooooo410@013ooooo00?o0000ooooooooool0>oooool009Kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Eooooo`;o00000_ooool3o`0000KoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000So
ZKgX00Co0000ojVmj?nY_NSoZKgX0ol000000onY_NSo0000ojVmj007ojVmj003o`000?nY_NSoZKgX
00?o000000?oZKgXo`000?nY_NP01onY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVm
j?nY_NP01OnY_NP01?l0003oZKgXo`000?l00005ojVmj003o`000?nY_NSoZKgX00GoZKgX0ol00005
ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00008ojVmj003o`000?nY_NSoZKgX00?oZKgX0_l00008
ojVmj0;o00003oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool0??oo
ool009Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Booooo`?o00000_ooool2o`000003oiIdZol0
003oZKgX00OoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX00GoZKgX00Co
0000ojVmj?l0003o00001OnY_NP00ol0003oZKgXojVmj005ojVmj0?o00001OnY_NP00ol0003oZKgX
ojVmj005ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj004ojVmj0;o00002?nY_NP01?l0003oZKgX
ojVmj?nY_NP3o`000003ojVmj?l0003oZKgX00KoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003
o`000?nY_NSoZKgX00KoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj007ojVmj0;o
00003oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00m
ooooo`00Zoooool2o`0000?ooooo0_l00004oiIdZ`03o`000?nY_NSoZKgX00GoZKgX0ol00006ojVm
j003o`000?nY_NSoZKgX00CoZKgX0_l00008ojVmj004o`000?nY_NSoZKgXojVmj0?o000000?oZKgX
o`000?nY_NP01_nY_NP00ol0003oZKgXojVmj002ojVmj0;o000000?oZKgXo`000?nY_NP01onY_NP0
0ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP01?l0003oZKgXo`000?l0
0005ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00005ojVmj0;o00001_nY_NP4o`0000GoZKgX00?o
0000ojVmj?nY_NP01?nY_NP4o`0000kooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`00
0?oooooooooo03oooooo002Xooooo`?o000000Goooooo`000?ooooooooooo`000007oiIdZ`03o`00
0?nY_NSoZKgX00;oZKgX0_l000000onGN:ko0000ojVmj007ojVmj003o`000?nY_NSoZKgX00?o0000
0_nY_NP00ol0003oZKgXojVmj005ojVmj004o`000?nY_NSo0000o`0000GoZKgX00?o0000ojVmj?nY
_NP01OnY_NP01?l0003oZKgXo`000?l00004ojVmj003o`000?nY_NSoZKgX00GoZKgX0ol00006ojVm
j003o`000?nY_NSoZKgX00CoZKgX0_l00008ojVmj004o`000?nY_NSoZKgXojVmj0;o000000?oZKgX
o`000?nY_NP01_nY_NP2o`0000;oZKgX0ol00002ojVmj003o`000?nY_NSoZKgX00GoZKgX00?o0000
ojVmj?nY_NP00ol00002ojVmj0?o00003Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o
0000ooooooooool0?oooool00:Kooooo0_l00007ooooo`03o`000?nFM:_oUWB[00KoUWB[00Co0000
ojVmj?l0003o00001?nGN:h00ol0003oZKgXojVmj005ojVmj0?o00001_nY_NP00ol0003oZKgXojVm
j004ojVmj0;o00002?nY_NP00ol0003oZKgXojVmj003ojVmj0?o00001onY_NP01?l0003oZKgXojVm
j?nY_NP3o`000003ojVmj?l0003oZKgX00OoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000
ojVmj007ojVmj004o`000?nY_NSo0000o`0000CoZKgX00?o0000ojVmj?nY_NP01?nY_NP4o`0000Ko
ZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000KoZKgX0_l0000=ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0003kooooo002Sooooo`?o00002?ooool2o`0000WoUWB[00?o0000oiMh[_nG
N:h01OnGN:h00ol0003oZKgXojVmj002ojVmj0;o000000?oVWjco`000?nY_NP01onY_NP00ol0003o
ZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP00ol0003oZKgXojVmj003o`0000;o
ZKgX00?o0000ojVmj?nY_NP01OnY_NP01?l0003oZKgXo`000?l00005ojVmj003o`000?nY_NSoZKgX
00GoZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00007ojVmj003o`000?nY_NSoZKgX
00;oZKgX0_l000000onY_NSo0000ojVmj007ojVmj004o`000?nY_NSoZKgXojVmj0;o000000?oZKgX
o`000?nY_NP01onY_NP2o`0005oooooo002Qooooo`;o00002oooool00ol0003o]h:Ko`000008oiId
Z`03o`000?nGN:koUgR^00KoUgR^00Co0000ojVmj?l0003o00001?nJO[<00ol0003oZKgXojVmj005
ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj004ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj004
ojVmj0;o00002?nY_NP01?l0003oZKgXojVmj?nY_NP3o`000003ojVmj?l0003oZKgX00KoZKgX00?o
0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX00KoZKgX00Ko0000ojVmj?l0003o0000
ojVmj?l00002ojVmj003o`000?nY_NSoZKgX00GoZKgX00Co0000ojVmj?l0003o00001?nY_NP00ol0
003oZKgXojVmj005ojVmj0?o0000G_ooool009kooooo0ol0000<ooooo`04o`000?ngPY_o]h:Ko`00
00OoUWB[0_l00009oiMh[P03o`000?nJO[?oVWjc00GoVWjc00?o0000ojVmj?nY_NP00_nY_NP2o`00
0003oij9_Ol0003oZKgX00OoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX
00GoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX00GoZKgX00Co0000ojVm
j?l0003o00001OnY_NP00ol0003oZKgXojVmj004ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj004
ojVmj0?o00000onY_NP01Ol0003oZKgXojVmj?nY_NSo000000GoZKgX0ol00007ojVmj004o`000?nY
_NSoZKgXojVmj0?o000000?oZKgXo`000?l00000G_ooool009cooooo0_l00002ooooo`03o`000?oo
oooooooo00[ooooo00Co0000okN2VongPY_o00001onFM:/00ol0003o^HBLo`000008oiMh[P03o`00
0?nJO[?oVWjc00KoVWjc00Co0000ojVmj?l0003o00001?nNRKd00ol0003oZKgXojVmj005ojVmj0?o
00001_nY_NP00ol0003oZKgXojVmj004ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj004ojVmj0;o
00002?nY_NP01?l0003oZKgXojVmj?nY_NP2o`000003ojVmj?l0003oZKgX00OoZKgX00?o0000ojVm
j?nY_NP00ol00002ojVmj005o`000?nY_NSoZKgXojVmj?l000000onY_NP00ol0003oZKgXojVmj003
o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP01?l0003oZKgXo`000?l00005ojVmj0;o0000GOoo
ool009Wooooo0ol00005ooooo`03o`000?oooooooooo00Sooooo00Go0000okN2VongPY_o]h:Ko`00
0006oiIdZ`04o`000?niQ9co^HBLo`0000OoUgR^0_l00009oiYn/`03o`000?nNRKgoWXVm00GoWXVm
00?o0000ojVmj?nY_NP00_nY_NP2o`000003oj>Jc?l0003oZKgX00OoZKgX00?o0000ojVmj?nY_NP0
0ol000000onY_NSo0000ojVmj007ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?nY_NP0
1onY_NP01?l0003oZKgXo`000?l00004ojVmj003o`000?nY_NSoZKgX00GoZKgX0ol00006ojVmj004
o`000?nY_NSoZKgXo`0000?oZKgX0ol00006ojVmj003o`000?nY_NSoZKgX00CoZKgX0_l00008ojVm
j0;o0000G?ooool009Kooooo0ol0000Booooo`03o`000?ngPY_o]h:K00;o]h:K00?o0000oiIdZonF
M:/01?nFM:/01?l0003o^HBLokV4W?l00007oiMh[P03o`000?niQYko000000SoVWjc00?o0000oij9
_OnNRKd01_nNRKd01?l0003oZKgXo`000?l00004oj>Jc003o`000?nY_NSoZKgX00GoZKgX0ol00005
ojVmj003o`000?nY_NSoZKgX00CoZKgX1?l00005ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00007
ojVmj003o`000?nY_NSoZKgX00;oZKgX0_l000000onY_NSo0000ojVmj007ojVmj003o`000?nY_NSo
000000?o000000?oZKgXo`000?nY_NP01onY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003o
ZKgX00OoZKgX0_l0001Looooo`00U?ooool2o`0001Gooooo00?o0000okN2VongPY/00ongPY/00ol0
003oUWB[oiIdZ`02oiIdZ`05o`000?niQ9co^HBLokV4W?l000001_nGN:h01?l0003o^HJNokV6W_l0
0007oiYn/`;o00002OnNRKd00ol0003oXi[<oj>Jc005oj>Jc004o`000?nY_NSoZKgXojVmj0?o0000
00?oZK_Vo`000?nY_NP01_nY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP0
1OnY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01_nY_NP01?l0003oZKgX
o`000?l00004ojVmj003o`000?nY_NSoZKgX00GoZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00Co
ZKgX1?l00005ojVmj003o`000?nY_NSoZKgX00CoZKgX1?l0001Kooooo`00TOooool3o`000003oooo
ool0003ooooo01?ooooo00?o0000okN2VongPY/01?ngPY/01Ol0003oUWB[oiIdZonFM:_o000000Co
^HBL00?o0000oiMh[_nGN:h00onGN:h01Ol0003o^HJNokV6W_niQYko000000KoVWjc00Co0000okV8
X_niR:;o00002?nNRKd00ol0003oXi[<oj>Jc005oj>Jc004o`000?nY_NSo0000o`0000GoZK_V00?o
0000ojVmj?nY_NP01?nY_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000KoZKgX00?o
0000ojVmj?nY_NP01?nY_NP3o`0000OoZKgX00Co0000ojVmj?nY_NSoZKgX0ol000000onY_NSo0000
o`000006ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP00ol0003oZKgXojVmj005ojVmj003o`00
0?nY_NSoZKgX00?o00000_nY_NP3o`0005[ooooo002?ooooo`;o00006Oooool00ol0003o]h:KokN2
V`04okN2V`05o`000?nFM:_oUWB[oiIdZol000001OniQ9`00ol0003oUgR^oiMh[P02oiMh[P05o`00
0?niQYko^HJNokV6W_l000001_nJO[<01?l0003o^HRRokV8X_l00007oij9_@03o`000?ndR:Oo0000
00KoXi[<0_l00008ojVkiP04o`000?nY_NSoZKgXojVmj0;o000000?oZKgXo`000?nY_NP01onY_NP0
0ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP00ol0003oZKgXojVmj003
o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP01?l0003oZKgXo`000?l00005ojVmj003o`000?nY
_NSoZKgX00CoZKgX0ol00006ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00006ojVmj0;o0000F_oo
ool008cooooo0ol0000Jooooo`03o`000?ngPY_o]h:K00Go]h:K00Co0000oiIdZonFM:_o00001_ni
Q9`01Ol0003oUgR^oiMh[_nGN:ko000000Go^HJN00?o0000oiYn/onJO[<00_nJO[<01Ol0003o^HRR
okV8X_niR:;o000000KoWXVm00Co0000okB8YondR:Oo00001OnSV/`01?l0003o[HN^ojf7[_l00007
ojVkiP04o`000?nY_NSo0000o`0000CoZKgX00?o0000ojVmj?nY_NP01OnY_NP3o`0000KoZKgX00?o
0000ojVmj?nY_NP01?nY_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000OoZKgX0_l0
0003ojVmj0;o000000?oZKgXo`000?nY_NP01onY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0
003oZKgX00OoZKgX0_l0001Iooooo`00R_ooool2o`0001gooooo00?o0000okN2VongPY/01OngPY/0
1?l0003oUWB[oiIdZol00006okV4W005o`000?nGN:koUgR^oiMh[_l000001OniQYh01Ol0003oVWjc
oiYn/onJO[?o000000Go^HRR00?o0000oij9_OnNRKd00_nNRKd00ol0003o]8RWokB8Y`02okB8Y`05
o`000?nSV/coXi[<oj>Jc?l000001?n]Qjh00ol0003oZK_VojVkiP04ojVkiP;o00001onY_NP00ol0
003oZKgXojVmj002ojVmj0;o000000?oZKgXo`000?nY_NP01onY_NP00ol0003oZKgXojVmj003o`00
0003ojVmj?l0003oZKgX00OoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj006ojVm
j0;o000000?oZKgXo`000?l000001?nY_NP00ol0003oZKgXojVmj005ojVmj0?o00001OnY_NP00ol0
003oZKgXojVmj004ojVmj0?o0000FOooool008Oooooo0ol0000Nooooo`03o`000?ngPY_o]h:K00Oo
]h:K0_l00007okV4W004o`000?nGN:koUgR^o`0000Ko^HJN00Co0000oiYn/onJO[?o00001_niR:80
1Ol0003oWXVmoij9_OnNRKgo000000Go]8RW00Co0000oj>Jc?nSV/co00001_n]Qjh00ol0003oZK_V
ojVkiP03o`000003oib2]Ol0003oZKgX00OoZKgX00Co0000ojVmj?l0003o00001?nY_NP00ol0003o
ZKgXojVmj005ojVmj0?o00001OnY_NP00ol0003oZKgXojVmj004ojVmj0Co00001OnY_NP00ol0003o
ZKgXojVmj004ojVmj0?o00001onY_NP01?l0003oZKgXojVmj?nY_NP3o`000003ojVmj?l0003oZKgX
00KoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj0;o0000F?ooool004cooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM02?ooooo0_l00002
ooooo`;o00007Oooool00ol0003o]h:KokN2V`07okN2V`;o00001oniQ9`00ol0003oUgR^o`000007
okV6WP04o`000?nJO[?oVWjco`0000Ko^HRR00Co0000oij9_OnNRKgo00001_ndR:L00ol0003oXi[<
o`000008ojf7[P;o00001OnLP[D00ol0003oZKgXojVmj004ojVmj0?o00001onY_NP01?l0003oZKgX
ojVmj?nY_NP3o`000003ojVmj?l0003oZKgX00KoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003
o`000?nY_NSoZKgX00GoZKgX00?o0000ojVmj?nY_NP01?l000000onY_NSo0000ojVmj006ojVmj004
o`000?nY_NSo0000o`0000GoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000KoZKgX0_l0001Goooo
o`00C?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
01oooooo0ol000001_oooooo0000o`000?l0003oZKgXo`0001cooooo0_l00009okN2V`03o`000?ni
Q9co^HBL00Oo^HBL0_l00008okV6WP;o00002?niR:82o`0000So]8RW00?o0000ojf7[_n]Qjh01on]
Qjh00ol0003oW8:eoib2]@05oib2]@03o`000?nY_NSoZKgX00?o00000_nSV/`00ol0003oZKgXojVm
j005ojVmj004o`000?nY_NSo0000o`0000GoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000KoZKgX
00?o0000ojVmj?nY_NP01?nY_NP3o`0000?oZKgX00Co0000ojVmj?nY_NSo00001_nY_NP2o`0000So
ZKgX00Co0000ojVmj?nY_NSoZKgX0_l000000onY_NSo0000ojVmj007ojVmj003o`000?oooooooooo
05Gooooo0014ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooo
ooooool06oooool3o`000004ooooool0003o0000o`0000CoZKgX00?o0000ooooooooool06_ooool2
o`0000Wo]h:K00?o0000okV4W?niQ9`01oniQ9`00ol0003o^HJNokV6WP07okV6WP03o`000?niR:;o
^HRR00Oo^HRR00?o0000okB8YondR:L01ondR:L00ol0003o[HN^ojf7[P06ojf7[P;o00002?nLP[D2
o`0000KoXi[<00?o0000ojVmj?nY_NP01?nY_NP2o`0000SoZKgX00Co0000ojVmj?nY_NSoZKgX0_l0
00000onY_NSo0000ojVmj007ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?nY_NP00onY
_NP01Ol0003oZKgXojVmj?nY_NSo000000;oZKgX0ol000000onY_NSo0000ojVmj007ojVmj004o`00
0?nY_NSo0000o`0000CoZKgX00?o0000ojVmj?nY_NP01OnY_NP2o`0005Kooooo001<ooooo`05o`00
0?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0Iooooo`?o00000_ooool2o`000003
ojVmj?l0003oZKgX00CoZKgX0_l0000Kooooo`;o00002?ngPY/2o`0000Wo^HBL00?o0000okV6W_ni
QYh01oniQYh00ol0003o^HRRokV8XP07okV8XP03o`000?ndR:Oo]8RW00Ko]8RW0_l00008ojf7[P03
o`000?o5TZ3o000000OoW8:e00?o0000oj>Jc?nSV/`01_nSV/`00ol0003oZKgXojVmj003o`0000;o
ZKgX00?o0000ojVmj?nY_NP01OnY_NP01?l0003oZKgXo`000?l00004ojVmj003o`000?nY_NSoZKgX
00GoZKgX0ol00005ojVmj005o`000?nY_NSoZKgXojVmj?l000000_nY_NP4o`0000GoZKgX00?o0000
ojVmj?nY_NP01?nY_NP3o`0000OoZKgX00Co0000ojVmj?nY_NSoZKgX0ol000000onY_NSo0000o`00
001Eooooo`00C?ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00Hooooo`?o00000_ooool2o`0000CoZKgX00?o0000ojVmj?nY_NP00onY_NP00ol0003ooooo
ooooo`0Hooooo`04o`000?niOY?o^GjCo`0000Oo]h:K0_l00008okV4W0;o00002?niQYh2o`0000So
^HRR0_l00008okB8Y`03o`000?noRI_o000000Ko[HN^00Co0000olFBX?o5TZ3o00001_nLP[D00ol0
003o`9BXo`000008oj>Jc0;o00001_nY_NP00ol0003oZKgXojVmj004ojVmj0;o00001onY_NP01?l0
003oZKgXojVmj?nY_NP3o`000003ojVmj?l0003oZKgX00KoZKgX00?o0000ojVmj?nY_NP00ol00002
ojVmj003o`000?nY_NSoZKgX00GoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSo
ZKgX00GoZKgX00Co0000ojVmj?l0003o00001OnY_NP00ol0003oooooooooo`1Cooooo`00C?ooool0
1Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool06?ooool2o`0000?ooooo0_l0
0007ojVmj003o`000?nY_NSoZKgX00;oZKgX00?o0000ooooooooool06?ooool01?l0003o^GjCokUn
Tol00007okN2V`03o`000?niOY?o000000Oo^HBL0_l00008okV6WP03o`000?ncNI?o000000Oo^HRR
00?o0000okAkUOl000001ondR:L00ol0003o_hVKo`000006ojf7[P04o`000?o5TZ3oaI:Po`0000Go
W8:e00Co0000ol2DZ?o0U:So00001onSV/`2o`0000SoZKgX00?o0000ojVmj?nY_NP00ol000000onY
_NSo0000ojVmj006ojVmj004o`000?nY_NSo0000o`0000GoZKgX00?o0000ojVmj?nY_NP01?nY_NP3
o`000003ojVmj?l0003oZKgX00?oZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000KoZKgX00?o0000
ojVmj?nY_NP01?nY_NP2o`0000OoZKgX0_l0001Dooooo`00C?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool05Oooool3o`0000;ooooo0ol00002ojVmj003o`000?nY_NSo
ZKgX00GoZKgX00Co0000ojVmj?nY_NSoZKgX0_l0000Iooooo`04o`000?niOY?o^GjCo`0000Ko]h:K
00Co0000okUnToniOY?o00001oniQ9`00ol0003o]gbCo`000007okV6WP03o`000?ncNI?o000000Oo
^HRR00?o0000okAkUOl000001_ndR:L01?l0003o_hVKokn9Vol00005ojf7[P05o`000?o5TZ3oaI:P
olFBX?l000001OnLP[D01Ol0003o`9BXol2DZ?o0U:So000000GoXi[<00Co0000ok:@]?nbT;Co0000
1_nY_NP4o`0000GoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000SoZKgX00Co0000ojVmj?nY_NSo
ZKgX0_l000001OnY_NSo0000ojVmj?nY_NSo000000GoZKgX00?o0000ojVmj?nY_NP00ol000000onY
_NSo0000ojVmj007ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?nY_NP01_nY_NP00ol0
003oooooo`00001Cooooo`00C?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000Boooo
o`;o00000_ooool3o`0000KoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`000003ojVmj?l0003o0000
01Sooooo00Go0000okUnToniOY?o^GjCo`000006okN2V`04o`000?niOY?o^GjCo`0000Ko^HBL00Co
0000okMlTongO9?o00001_niQYh01?l0003o/gVCok=iTol00006okV8XP04o`000?ndNiGo]7^Eo`00
00Ko]8RW00Co0000okn9VonoRI_o00001On]Qjh00ol0003oaI:PolFBX002olFBX005o`000?nLP[Go
W8:eoib2]Ol000001?o0U:P00ol0003oXi[<oj>Jc002oj>Jc003o`000?nbT;Co/Y2d00;o/Y2d00?o
0000ojVmj?nY_NP00ol00002oj:DaP03o`000?nY_NSoZKgX00GoZKgX00?o0000ojVmj?nY_NP00ol0
0002ojVmj003o`000?nY_NSoZKgX00GoZKgX00Co0000ojVmj?l0003o00001?nY_NP00ol0003oZKgX
o`000005ojVmj0?o00001OnY_NP00ol0003oZKgXojVmj004ojVmj0Co00001OnY_NP00ol0003oZKgX
ojVmj004ojVmj0?o0000Doooool0073ooooo0ol000001?oooooo0000o`000?l00002ojVmj003o`00
0?nY_NSoZKgX00GoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj0Co00006?ooool01Ol0003o^GjC
okUnToniOY?o000000Ko]h:K00Co0000okUnToniOY?o00001_niQ9`01?l0003o]gbCokMlTol00006
okV6WP04o`000?ncNI?o/gVCo`0000Ko^HRR00Co0000okAkUOndNiGo00001_ndR:L01Ol0003o_hVK
okn9VonoRI_o000000?o[HN^00?o0000olFBX?o5TZ000oo5TZ001Ol0003oW8:eoib2]OnLP[Go0000
00Go`9BX00Co0000oj>Jc?nSV/co00001_nbT;@2o`0000KoXYC600?o0000ojVmj?nY_NP01?nY_NP3
o`0000KoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000OoZKgX0_l00002ojVmj0?o000000?oZKgX
o`000?nY_NP01_nY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP0
0ol0003oZKgXojVmj003o`000004ojVmj?l0003oooooo`0005;ooooo001^ooooo`;o000000Cooooo
o`000?l0003o00001_nY_NP00ol0003oZKgXojVmj004ojVmj0?o00001_nY_NP3o`0001Sooooo00Go
0000okUnToniOY?o^GjCo`000005okN2V`05o`000?niOY?o^GjCokUnTol000001_niQ9`01?l0003o
]gbCokMlTol00006okV6WP05o`000?ncNI?o/gVCok=iTol000001OniR:801Ol0003o]7^EokAkUOnd
NiGo000000Co]8RW00?o0000okn9VonoRI/00_noRI/01Ol0003o[HN^ojf7[_n]Qjko000000GoaI:P
00Co0000oib2]OnLP[Go00001_o0U:P00ol0003oXi[<o`000007ok:@]003o`000?nRU<KoXYC600Ko
XYC600?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj007ojVmj003o`000?nY_NSoZKgX00?o
000000?oZKgXo`000?nY_NP01_nY_NP4o`0000GoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000Ko
ZKgX00?o0000ojVmj?nY_NP00onY_NP4o`0000GoZKgX00?o0000ooooool00000DOooool006_ooooo
1_l00002ojVmj003o`000?nY_NSoZKgX00GoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003o`00
0?nY_NSoZKgX00GoZKgX0ol0000Fooooo`03o`000?niOY?o^GjC00;o^GjC00?o0000okN2VongPY/0
0ongPY/01Ol0003o^GjCokUnToniOY?o000000Go^HBL00Go0000okMlTongO9?o]gbCo`000005okV6
WP03o`000?ncNI?o/gVC00;o/gVC00?o0000okV8X_niR:800_niR:800ol0003o]7^EokAkU@02okAk
U@03o`000?ndR:Oo]8RW00;o]8RW00?o0000okn9VonoRI/00_noRI/01?l0003o[HN^ojf7[_l00006
olFBX003o`000?nLP[Go000000So`9BX00?o0000ok:@]?nbT;@01OnbT;@00ol0003obibWo`000008
oj:DaP;o00001OnY_NP00ol0003oZKgXojVmj004ojVmj0Co00001OnY_NP00ol0003oZKgXojVmj004
ojVmj0;o00002?nY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00KoZKgX00?o0000
ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX00GoZKgX0_l0000Zooooo`04oa0@4?l0003o
0000o`0002?ooooo001Xooooo`?o000000?oooooo`000?l000001_nY_NP00ol0003oZKgXojVmj004
ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj004ojVmj0?o00005_ooool00ol0003o^GjCokUnT`03
okUnT`03o`000?ngPY_o]h:K00;o]h:K00Go0000okUnToniOY?o^GjCo`000005okV4W005o`000?ng
O9?o]gbCokMlTol000001OniQYh00ol0003o/gVCok=iT`02ok=iT`03o`000?niR:;o^HRR00;o^HRR
00?o0000okAkUOndNiD00_ndNiD01Ol0003o]8RWokB8YondR:Oo000000Go_hVK00Co0000ojf7[_n]
Qjko00001oo5TZ02o`0000So`9BX00?o0000ok:@]?nbT;@01OnbT;@00ol0003obibWo`000008oj:D
aP03o`000?nY_NSoZKgX00GoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX
00GoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj007ojVmj0?o00001OnY_NP00ol0
003oZKgXojVmj004ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj004ojVmj0Co0000:Oooool00ol0
003oooooooooo`0Sooooo`00IOooool3o`0000;ooooo0_l000000onY_NSo0000ojVmj006ojVmj003
o`000?nY_NSoZKgX00?o00000_nY_NP00ol0003oZKgXojVmj005ojVmj003o`000?nY_NSoZKgX00?o
000000?oZKgXo`000?l000005_ooool00ol0003o^GjCokUnT`03okUnT`05o`000?ngPY_o]h:KokN2
Vol000001OniOY<01Ol0003o^HBLokV4W?niQ9co000000Go]gbC00Go0000okV6W_niQYko^HJNo`00
0005ok=iT`03o`000?niR:;o^HRR00;o^HRR00?o0000okAkUOndNiD00ondNiD01?l0003o]8RWokB8
Yol00005okn9V`03o`000?n]Qjko000000SoaI:P00?o0000ol2DZ?o0U:P01_o0U:P2o`0000Ko/Y2d
00Go0000ol^LYoo;W:OobibWo`000006oj:DaP03o`000?njVKKo000000KoZKgX0ol00006ojVmj003
o`000?nY_NSoZKgX00CoZKgX0ol00004ojVmj0;o00001?nY_NP3o`000003ojVmj?l0003oZKgX00Ko
ZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj007ojVmj003o`000?nY_NSoZKgX00?o
000000CoZKgXo`000?oooooo0000:Oooool00ol0003oooooooooo`0Sooooo`00Hoooool4o`000003
ooooool0003o000000CoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000KoZKgX00?o0000ojVmj?nY
_NP01?nY_NP3o`0000CoZKgX0ol0000Dooooo`03o`000?niOY?o^GjC00Co^GjC00Go0000okN2Vong
PY_o]h:Ko`000005okUnT`05o`000?niQ9co^HBLokV4W?l000001OngO9<01Ol0003o^HJNokV6W_ni
QYko000000Go/gVC00Go0000okV8X_niR:;o^HRRo`000006okAkU@04o`000?ndR:Oo]8RWo`0000Ko
_hVK0_l00008olFBX003o`000?o0U:So`9BX00Ko`9BX00?o0000olZFWol000001OnbT;@01Ol0003o
bibWol^LYoo;W:Oo000000GoXYC600Go0000okZI]_njVKKo^YVfo`000002ojVmj0?o000000?oYIo?
o`000?nY_NP01onY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00CoZKgX00Co0000
ojVmj?l0003oZKgX0_l00005ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00005ojVmj003o`000?nY
_NSoZKgX00CoZKgX1?l00005ojVmj0;o0000:Oooool01_l0003oMgMgo`000?l0003oEEEEonk^kR3o
oooo001Qooooo`;o00000oooool2o`0000OoZKgX00Co0000ojVmj?nY_NSoZKgX0_l000000onY_NSo
0000ojVmj007ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP00ol0003oZKgXojVmj002ojVmj0;o
000000?okH/bo`000?ooool04_ooool00ol0003o^GjCokUnT`04okUnT`05o`000?ngPY_o]h:KokN2
Vol000001OniOY<01Ol0003o^HBLokV4W?niQ9co000000Go]gbC00Go0000okV6W_niQYko^HJNo`00
0006ok=iT`04o`000?niR:;o^HRRo`0000Ko]7^E00?o0000okB8Yol000001onoRI/00ol0003oaI:P
olFBX006olFBX0;o00002?o0U:P00ol0003obYJOo`000004ok:@]003o`000?o;W:OobibW00;obibW
00?o0000oj:Da_nRU<H00_nRU<H00ol0003o^YVfokZI]P03okZI]P;o00001OnUWll00ol0003oZKgX
ojVmj004ojVmj0Co00001OnY_NP00ol0003oZKgXojVmj002ojVmj004o`000?nY_NSo0000o`0000So
ZKgX00Co0000ojVmj?nY_NSoZKgX0_l000000onY_NSo0000ojVmj006ojVmj003o`000?nY_NSoZKgX
00?o00000_nY_NP00ol0003oZKgXojVmj005ojVmj0;o0000:?ooool01_l0003oEEEEonk^k_oooooo
MgMgoeEEEB3ooooo001Nooooo`?o00000_ooool3o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP0
0ol0003oZKgXo`000004ojVmj003o`000?nY_NSoZKgX00GoZKgX0ol00006ojVmj003o`000?nY_NSo
ZKgX00;oZKgX0_l000000oo]Rc;o0000ooooo`0Aooooo`03o`000?niOY?o^GjC00Co^GjC00Co0000
okN2VongPY_o00001_niOY<01?l0003o^HBLokV4W?l00006okMlT`04o`000?niQYko^HJNo`0000Oo
/gVC00Co0000okV8X_niR:;o00001_ndNiD00ol0003o]8RWo`000007okn9V`03o`000?o5TZ3oaI:P
00KoaI:P00?o0000okZ1Uol000001_o0U:P01?l0003obYJOolZFWol00004ok:@]003o`000?o;W:Oo
bibW00?obibW00Co0000oj:Da_nRU<Ko00001_njVKH00ol0003oYIo?ojFOc`05ojFOc`03o`000?nY
_NSoZKgX00?o00000_nY_NP00ol0003oZKgXojVmj005ojVmj003o`000?nY_NSoZKgX00?o000000?o
ZKgXo`000?nY_NP01onY_NP01?l0003oZKgXo`000?l00004ojVmj003o`000?nY_NSoZKgX00CoZKgX
0ol00006ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol0000Wooooo`03o`000?o^k^kooooo00;ooooo
00?o0000ooooooooool07_ooool005cooooo0_l00002ooooo`?o00001_nY_NP00ol0003oZKgXojVm
j004ojVmj0;o00001_nY_NP00ol0003oZKgXojVmj002ojVmj0;o00000_nY_NP00ol0003oZKgXojVm
j005ojVmj003o`000?nY_NSoZKgX00?o000000?okH/bo`000?ooool04?ooool00ol0003o^GjCokUn
T`05okUnT`04o`000?ngPY_o]h:Ko`0000Ko^GjC00Co0000okV4W?niQ9co00001_ngO9<01?l0003o
^HJNokV6W_l00007ok=iT`03o`000?niR:;o000000So]7^E0_l00007okn9V`03o`000?o5TZ3oaI:P
00KoaI:P00?o0000okZ1Uol000001_o0U:P01Ol0003obYJOolZFWoo:UYoo000000?o/Y2d00?o0000
ol^LYoo;W:L00oo;W:L00ol0003oXYC6o`000006okZI]P03o`000?o?Xj[o000000KoYIo?0ol00006
ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol000000onY_NSo0000ojVmj002ojVmj003o`000?nY_NSo
ZKgX00CoZKgX0ol00007ojVmj004o`000?nY_NSoZKgXojVmj0;o000000?oZKgXo`000?nY_NP01onY
_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003o000002Oooooo00?o0000onk^k_ooool00_oo
ool00ol0003oooooooooo`0Nooooo`00FOooool3o`000004ooooool0003o0000o`0000;oZKgX00?o
0000ojVmj?nY_NP01OnY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00KoZKgX00Co
0000ojVmj?l0003o00001OnY_NP00ol0003oZKgXojVmj004ojVmj0?o000000CoZKgXo`000?l0003o
kH/b0_l0000@ooooo`03o`000?niOY?o^GjC00Go^GjC00Co0000okN2VongPY_o00001_niOY<01?l0
003o^HBLokV4W?l00006okMlT`04o`000?niQYko^HJNo`0000Oo/gVC00?o0000okV8X_l000002?nd
NiD00ol0003o_hVKokn9V`05okn9V`03o`000?o3R9Go000000KoaI:P00Co0000okZ1UonjPIOo0000
1Oo0U:P00ol0003obYJOolZFW`02olZFW`04o`000?nbT;Co/Y2do`0000OobibW00?o0000okZI]_nj
VKH01OnjVKH00ol0003ocj>Zo`000005ojFOc`03o`000?ngW[oo000000SoZKgX00?o0000ojVmj?nY
_NP00ol000001OnY_NSo0000ojVmj?nY_NSo000000CoZKgX00?o0000ojVmj?nY_NP00ol00002ojVm
j003o`000?nY_NSoZKgX00GoZKgX00Co0000ojVmj?l0003o00001?nY_NP00ol0003oZKgXojVmj004
ojVmj0Co00001OnY_NP2o`0002Kooooo00Ko0000oeEEEOo^k^koooooogMgMomVIVHPooooo`00Eooo
ool2o`000004ooooool0003o0000o`0000KoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000GoZKgX
00?o0000ojVmj?nY_NP01?nY_NP2o`0000SoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj005o`00
0?nY_NSo0000o`000?o]Rc800_l0000@ooooo`03o`000?niOY?o^GjC00Ko^GjC0_l00007okUnT`03
o`000?niQ9co000000Oo]gbC00?o0000okV6W_l000002OncNI<2o`0000So]7^E00?o0000okn9Vono
RI/01OnoRI/00ol0003o`hREo`000006olFBX005o`000?njPIOo^X6GokZ1Uol000001?o0U:P00ol0
003obYJOolZFW`02olZFW`04o`000?nbT;Co/Y2do`0000OobibW00?o0000okZI]_njVKH01?njVKH0
1Ol0003ocj>ZolnSZ_o?Xj[o000000?oYIo?00Go0000okNN_ongW[oo]ijoo`000007ojVmj0?o0000
1OnY_NP00ol0003oZKgXo`000004ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj003ojVmj0?o0000
1onY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP2o`0002Cooooo
00?o410@o`000?mgMgL00_l000000omVIVKok^k^ooooo`0Oooooo`00E?ooool6o`0000;oZKgX00?o
0000ojVmj?nY_NP01OnY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY
_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP3o`0000KoZKgX0ol0
00001?o]Rc;o0000ooNVGol0000>ooooo`03o`000?niOY?o^GjC00Oo^GjC0_l00008okUnT`;o0000
2?ngO9<2o`0000Wo/gVC00?o0000okAkUOndNiD01ondNiD00ol0003o_hVKokn9V`05okn9V`03o`00
0?o3R9Go000000KoaI:P00Go0000okZ1UonjPIOo^X6Go`000004ol2DZ003o`000?o:UYoobYJO00;o
bYJO00?o0000ok:@]?l000001oo;W:L00ol0003oci^Qo`000005okZI]P05o`000?o?Xj[ocj>ZolnS
Z_l000000_nUWll00ol0003o]ijookNN_`03okNN_`04o`000?nY_NSoZKgXojVmj0?o000000?oZKgX
o`000?nY_NP01_nY_NP2o`000006ojVmj?l0003o0000o`000?nY_NSo00001onY_NP00ol0003oZKgX
ojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP0
0onY_NP4o`0004[ooooo001Aooooo`Ko00001_nY_NP00ol0003oZKgXojVmj004ojVmj0?o00001_nY
_NP00ol0003oZKgXojVmj003ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj002ojVmj0;o000000?o
ZKgXo`000?nY_NP01onY_NP2o`000004onf;<_l0003omjIOo`0000kooooo00?o0000okUnToniOY<0
1oniOY<2o`0000So^GjC0_l00008okMlT`;o00002OncNI<00ol0003o]7^EokAkU@06okAkU@;o0000
1onoRI/00ol0003o`hREo`000005olFBX003o`000?njPIOo^X6G00;o^X6G00Go0000ol2DZ?o0U:So
`9BXo`000006olZFW`;o00001oo;W:L00ol0003oci^Qo`000004okZI]P03o`000?o?Xj[ocj>Z00;o
cj>Z00?o0000ojFOcol000001_ngW[l01?l0003oZKgXo`000?l00005ojVmj003o`000?nY_NSoZKgX
00CoZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00006ojVmj003o`000?nY_NSoZKgX
00;oZKgX0_l000000onY_NSo0000ojVmj006ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP2o`00
04[ooooo001?ooooo`;o000000?oooooo`000?l000000_nY_NP00ol0003oZKgXojVmj005ojVmj003
o`000?nY_NSoZKgX00?o00000_nY_NP00ol0003oZKgXojVmj005ojVmj003o`000?nY_NSo000000;o
00000_nY_NP00ol0003oZKgXojVmj005ojVmj004o`000?nY_NSo0000o`0000CoZKgX00?o0000ojVm
j?nY_NP01OnY_NP4o`0000;omjIO00?o0000ooooooooool02oooool00ol0003o^GjCokUnT`07okUn
T`03o`000?niOY?o^GjC00Oo^GjC00?o0000okMlTongO9<01ongO9<00ol0003o/gVCok=iT`08ok=i
T`03o`000?ndNiGo]7^E00Ko]7^E00?o0000on>VTol000001OnoRI/01Ol0003o`hREol>8UOo3R9Go
000000CoaI:P00?o0000okZ1UonjPIL00onjPIL01?l0003o`9BXol2DZ?l00006olZFW`03o`000?o;
W:OobibW00KobibW00?o0000olnKXOl000001?njVKH00ol0003ocj>ZolnSZP03olnSZP03o`000?ng
W[oo]ijo00Ko]ijo00?o0000ojVmj?nY_NP01_nY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0
003oZKgX00KoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj007ojVmj004o`000?nY
_NSo0000o`0000CoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000KoZKgX00?o0000ooooooooool0
2?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03_ooooo000Uooooo`Co000000?o410@ooooooooool0
8?ooool3o`000003ooooool0003o000000GoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000KoZKgX
00?o0000ojVmj?nY_NP01?nY_NP2o`0000KoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000OoZKgX
00?o0000ojVmj?nY_NP00_nY_NP2o`000004ojVmj?l0003o0000o`0000;omjIO00?o0000oooooooo
ool02oooool00ol0003o^GjCokUnT`07okUnT`03o`000?niOY?o^GjC00Oo^GjC00?o0000okMlTong
O9<01ongO9<00ol0003o/gVCok=iT`07ok=iT`;o00002?ndNiD00ol0003ohjJCo`000005okn9V`05
o`000?o3R9Go`hREol>8UOl000001?o5TZ000ol0003o^X6GokZ1U`03okZ1U`03o`000?o0U:So0000
00OobYJO00?o0000ol^LYoo;W:L01Oo;W:L01Ol0003oci^QolnKXOo?Vj7o000000;o^YVf00?o0000
olnSZ_o?XjX01?o?XjX00ol0003o]ijookNN_`06okNN_`03o`000?nY_NSoZKgX00KoZKgX0ol00005
ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00007
ojVmj004o`000?nY_NSoZKgXojVmj0;o000000?oZKgXo`000?nY_NP01_nY_NP2o`0000Wooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0kooooo`009oooool00ol0003oooooooooo`0Pooooo`;o00000ooo
ool2o`0000OoZKgX00Co0000ojVmj?nY_NSoZKgX0_l00002ojVmj003o`000?nY_NSoZKgX00GoZKgX
00?o0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX00CoZKgX00?o0000ojVmj?nY_NP0
0ol00002ojVmj003o`000?nY_NSoZKgX00GoZKgX00Co0000ojVmj?l0003o00000onY_NP3o`0000;o
mjIO00?o0000ooooooooool02_ooool2o`0000Wo^GjC00?o0000okUnToniOY<01oniOY<00ol0003o
]gbCokMlT`07okMlT`03o`000?ncNI?o/gVC00Oo/gVC0_l00008okAkU@03o`000?oSYY?o000000Go
_hVK00Go0000ol>8UOo3R9Go`hREo`000003olFBX003o`000?njPIOo^X6G00Co^X6G00?o0000ol2D
Z?l000001oo:UYl2o`0000KobibW00Go0000olnKXOo?Vj7oci^Qo`000002okZI]P03o`000?o?Xj[o
cj>Z00?ocj>Z00?o0000omJUY?l000001_ngW[l00ol0003ocJVeo`000004ojVmj0?o000000?oYjOF
o`000?nY_NP01OnY_NP2o`0000;oZKgX0ol000000onY_NSo0000ojVmj006ojVmj003o`000?nY_NSo
ZKgX00?o00000_nY_NP00ol0003oZKgXojVmj005ojVmj004o`000?nY_NSo0000o`0000CoZKgX00?o
0000ojVmj?nY_NP01?nY_NP3o`0000Sooooo00Go410@oooooooooooooooooa0@400kooooo`007?oo
ool6o`0000Gooooo00?o0000ooooooooool07Oooool3o`0000;ooooo0ol00002ojVmj003o`000?nY
_NSoZKgX00GoZKgX00?o0000ojVmj?l000001OnY_NP00ol0003oZKgXojVmj004ojVmj0?o00001_nY
_NP00ol0003oZKgXojVmj003ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj004ojVmj0;o00001OnY
_NP3o`0000;omjIO0_l0000;ooooo`;o00002?niOY<2o`0000So^GjC0_l00008okMlT`;o00002Onc
NI<2o`0000So]7^E00?o0000on>VTol000001OnoRI/01Ol0003o`hREol>8UOo3R9Go000000?oaI:P
00?o0000okZ1UonjPIL01OnjPIL2o`0000KobYJO00?o0000okf3U_l000001Oo;W:L00ol0003oci^Q
olnKX@02olnKX@03o`000?njVKKo000000Kocj>Z00?o0000omJUY?l000001OngW[l01_l0003ocJVe
olfY]Oo=ZKGo0000ojVmj0;o00001OnWYmH00ol0003oZKgXojVmj003ojVmj0Co00001OnY_NP00ol0
003oZKgXojVmj004ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj003ojVmj0?o00001onY_NP00ol0
003oZKgXojVmj003o`000003ojVmj?l0003o000000Sooooo00Go0000ooooooooooooooooo`00000k
ooooo`009oooool00ol0003oooooooooo`0Jooooo`?o00000_ooool3o`0000KoZKgX00?o0000ojVm
j?nY_NP01?nY_NP2o`0000OoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX
00GoZKgX00?o0000ojVmj?l000000_l00002ojVmj003o`000?nY_NSoZKgX00GoZKgX00?o0000ojVm
j?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX00;oZKgX0ol00002ooNVG`;o00002oooool2o`00
00So^GjC0_l00008okUnT`;o00002?ngO9<2o`0000Wo/gVC00?o0000oo6fS_l000001_ndNiD01?l0
003ohjJCon>VTol00004okn9V`03o`000?o3R9Go`hRE00?o`hRE00Co0000olFBX?o5TZ3o00001onj
PIL00ol0003obYJOolZFW`05olZFW`03o`000?nmPiKo000000GobibW00?o0000olnKXOo?Vj400oo?
Vj42o`0000Kocj>Z00?o0000omJUY?l000001?ngW[l00ol0003ocJVeolfY]@03olfY]@03o`000?nW
YmKoYjOF00KoYjOF00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj006ojVmj003o`000?nY
_NSoZKgX00?o000000?oZKgXo`000?nY_NP01_nY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o
0000ojVmj?nY_NP01OnY_NP3o`0000GoZKgX0_l00007ooooo`05o`000?ooooooooooooooool00000
>oooool002Oooooo00?o0000ooooooooool06?ooool7o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY
_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000KoZKgX00?o
0000ojVmj?nY_NP01?nY_NP2o`0000KoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000KoZKgX00Co
0000ojVmj?nY_NSoZKgX0ol00002ooNVG`;o00002_ooool00ol0003okKNGo`000008okUnT`;o0000
2?niOY<2o`0000So]gbC0_l00009ok=iT`03o`000?oa]Xko000000Ko]7^E00Co0000on>VTooSYY?o
00001?noRI/00ol0003o`hREol>8U@03ol>8U@03o`000?o5TZ3o000000So^X6G00?o0000olZFWoo:
UYl01Oo:UYl01?l0003o_H>Fokf3U_l00004ol^LY`03o`000?o?Vj7oci^Q00?oci^Q00?o0000olnS
Z_o?XjX01?o?XjX01Ol0003oeZFTomJUY?oFYJCo000000?o]ijo00?o0000olfY]Oo=ZKD00oo=ZKD0
0ol0003oYjOFojNWeP06ojNWeP?o00000_nY_NP01?l0003oZKgXojVmj?l00006ojVmj0?o00001OnY
_NP00ol0003oZKgXojVmj004ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj002ojVmj0;o000000?o
ZKgXo`000?nY_NP01_nY_NP2o`0000Kooooo00Go410@oooooooooooooooooa0@400kooooo`009ooo
ool00ol0003oooooooooo`0Fooooo`;o00000_ooool2o`0000KoZKgX00?o0000ojVmj?nY_NP01?nY
_NP3o`0000KoZKgX00Co0000ojVmj?nY_NSoZKgX0_l00002ojVmj003o`000?nY_NSoZKgX00GoZKgX
00?o0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX00CoZKgX00?o0000ojVmj?nY_NP0
0ol00002ojVmj003o`000?nY_NSoZKgX00GoZKgX00?o0000ojVmj?l000000ol00002ooNVG`03o`00
0?oj[E3o000000Wooooo00?o0000onfgUol000002?niOY<00ol0003okkREo`000007okUnT`03o`00
0?o`^9Co000000Oo]gbC0_l00008ok=iT`04o`000?oa]XkolKJ>o`0000Ko]7^E00Co0000on>VTooS
YY?o00001?noRI/00ol0003o`hREol>8U@03ol>8U@03o`000?o5TZ3o000000So^X6G00?o0000olZF
Woo:UYl01?o:UYl01Ol0003o_H>Fokf3U_nmPiKo000000?obibW00?o0000olnKXOo?Vj401?o?Vj40
0ol0003ocj>ZolnSZP04olnSZP05o`000?oFYJCoeZFTomJUY?l000000_ngW[l00ol0003ocJVeolfY
]@03olfY]@03o`000?oJ[jco000000GoYjOF0_l000000onhZlco0000ojVmj002ojVmj005o`000?nY
_NSoZKgXojVmj?l000000_nY_NP3o`000003ojVmj?l0003oZKgX00KoZKgX00?o0000ojVmj?nY_NP0
0ol000000onY_NSo0000ojVmj007ojVmj004o`000?nY_NSo0000o`0000CoZKgX00?o0000ojVmj?nY
_NP01?nY_NP3o`0000Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0kooooo`009oooool00ol0003o
ooooooooo`0Cooooo`?o000000Coooooo`000?l0003o00000_nY_NP00ol0003oZKgXojVmj004ojVm
j003o`000?nY_NSoZKgX00?o00000_nY_NP00ol0003oZKgXojVmj005ojVmj003o`000?nY_NSo0000
00GoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP00onY_NP3o`00
00KoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`000004ojVmj?l0003o0000o`0000;omjIO00?o0000
ooZ]D?l000002Oooool00ol0003okKNGo`000007okUnT`04o`000?o_^9GokkREo`0000Oo^GjC00?o
0000oo2hU?l000001ongO9<00ol0003olKNAo`000007ok=iT`04o`000?oa]XkolKJ>o`0000Ko]7^E
00Go0000on>VTooSYY?ohjJCo`000002okn9V`03o`000?o3R9Go`hRE00Co`hRE00?o0000olFBX?l0
00001onjPIL00ol0003oi:NBo`000005olZFW`05o`000?nmPiKo_H>Fokf3U_l000000oo;W:L00ol0
003oci^QolnKX@04olnKX@03o`000?o?Xj[ocj>Z00?ocj>Z00?o0000omJUY?oFYJ@00_oFYJ@00ol0
003o]ijoo`000006olfY]@04o`000?oJ[jcofZn/o`0000?oYjOF00?o0000okR[c?nhZl`00_nhZl`0
1?l0003oZKgXojVmj?l00003ojVmj0?o00001OnY_NP00ol0003oZKgXojVmj004ojVmj0?o00001OnY
_NP00ol0003oZKgXojVmj004ojVmj0?o00001onY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0
003o000000Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0kooooo`009Oooool00omEEEGoIVIVo`00
000Booooo`?o000000Coooooo`000?l0003o00001_nY_NP00ol0003oZKgXojVmj003ojVmj0?o0000
1_nY_NP00ol0003oZKgXojVmj004ojVmj0;o00001onY_NP00ol0003oZKgXojVmj003o`0000;oZKgX
00?o0000ojVmj?nY_NP01OnY_NP00ol0003oZKgXo`000002o`0000;oZKgX00?o0000ojVmj?nY_NP0
1OnY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00Co000000ComjIOo`000?oj[E3o
00002Oooool01?l0003okKNGonfgUol00006okUnT`04o`000?o_^9GokkREo`0000Ko^GjC00Co0000
oo2hU?o`^9Co00001_ngO9<01?l0003olKNAoo6gTOl00007ok=iT`04o`000?oa]XkolKJ>o`0000Ko
]7^E00Go0000on>VTooSYY?ohjJCo`000002okn9V`03o`000?o3R9Go`hRE00Go`hRE00?o0000okZ1
UonjPIL01_njPIL00ol0003oi:NBo`000005olZFW`03o`000?nmPiKo_H>F00;o_H>F00?o0000ol^L
Yol000001_o?Vj400ol0003oaHfIo`000004olnSZP03o`000?oFYJCoeZFT00?oeZFT00?o0000olfY
]Oo=ZKD01Oo=ZKD01Ol0003ofZn/omZ_[?l0003oYjOF00;o00001_nhZl`00ol0003oZKgXo`000003
o`000003ojVmj?l0003oZKgX00KoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj006
ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP00ol0003oZKgXojVmj005ojVmj0?o00001OnY_NP2
o`0004Cooooo000hooooo`Ko00000_nY_NP00ol0003oZKgXojVmj005ojVmj003o`000?nY_NSo0000
00;o00000_nY_NP00ol0003oZKgXojVmj005ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP00ol0
003oZKgXojVmj004ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj004ojVmj0;o00001_nY_NP00ol0
003oZKgXojVmj004ojVmj0?o00001OnY_NP5o`000005ooNVGol0003onZe@ooZ]D?l000001oooool0
1Ol0003okKNGonfgUoo]]iOo000000Ko^GjC00Co0000onnhUOo_^9Go00001_niOY<01?l0003ol;RD
oo2hU?l00006okMlT`04o`000?oa]i7olKNAo`0000Oo/gVC00Co0000oo6fS_oa]Xko00001OndNiD0
0ol0003ohjJCon>VT`02on>VT`04o`000?noRI_o_hVKo`0000Oo`hRE00?o0000okZ1UonjPIL01_nj
PIL00ol0003oi:NBo`000004olZFW`03o`000?nmPiKo_H>F00?o_H>F00?o0000ol^LYol000001_o?
Vj400ol0003oaHfIo`000004olnSZP03o`000?oFYJCoeZFT00?oeZFT00?o0000olfY]Oo=ZKD01?o=
ZKD00ol0003ofZn/omZ_[002omZ_[003o`000?nhZlco^:_<00Oo^:_<0_l00005ojVmj003o`000?nY
_NSoZKgX00CoZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00006ojVmj004o`000?nY
_NSoZKgXojVmj0?o000000?oZKgXo`000?nY_NP01_nY_NP00ol0003oooooooooo`12ooooo`00=Ooo
ool7o`0000GoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000KoZKgX00?o0000ojVmj?nY_NP01?nY
_NP3o`0000KoZKgX00Co0000ojVmj?nY_NSoZKgX0_l00002ojVmj003o`000?nY_NSoZKgX00GoZKgX
00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj006ojVmj003o`000?nY_NSoZKgX00?o0000
0_nY_NP00ol0003oZKgXojVmj004ojVmj0Co00000_ogYUl01?l0003onZe@o`000?l00006ooooo`05
o`000?o]]iOokKNGonfgUol000001OniOY<01Ol0003okkREonnhUOo_^9Go000000Ko^GjC00Co0000
oo2hU?o`^9Co00001_ngO9<01?l0003olKNAoo6gTOl00006ok=iT`05o`000?oa]XkolKJ>oo6fS_l0
00001OndNiD00ol0003ohjJCon>VT`02on>VT`04o`000?noRI_o_hVKo`0000Oo`hRE00?o0000okZ1
UonjPIL01_njPIL00ol0003oi:NBo`000004olZFW`03o`000?nmPiKo_H>F00?o_H>F00?o0000ol^L
Yol000001_o?Vj400ol0003oaHfIo`000003olnSZP03o`000?oFYJCoeZFT00CoeZFT0_l00005olfY
]@03o`000?oJ[jcofZn/00;ofZn/00?o0000okR[c?nhZl`01?nhZl`5o`0000KoZKgX00?o0000ojVm
j?nY_NP00ol000000onY_NSo0000ojVmj006ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`00
0?nY_NP01_nY_NP01?l0003oZKgXo`000?l00005ojVmj003o`000?nY_NSoZKgX00?oZKgX0ol00013
ooooo`00<oooool2o`000003ooooool0003o000000?oZKgX00?o0000ojVmj?nY_NP01?nY_NP00ol0
003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY_NP00ol0003oZKgXojVmj003o`00
00;oZKgX00?o0000ojVmj?nY_NP01OnY_NP00ol0003oZKgXo`000005ojVmj003o`000?nY_NSoZKgX
00CoZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00006ojVmj003o`000?nY_NSoZKgX
00?oZKgX1?l00002ooNVG`05o`000?oj[E3o0000onn@>ol000001Oooool01Ol0003okKNGonfgUoo]
]iOo000000Go^GjC00Go0000onnhUOo_^9GokkREo`000006okUnT`04o`000?o`^9Col;RDo`0000Ko
]gbC00Co0000oo6gTOoa]i7o00001_ncNI<01Ol0003olKJ>oo6fS_oa]Xko000000Go]7^E00?o0000
on>VTooSYY<00_oSYY<00ol0003o_hVKo`000008ol>8U@03o`000?njPIOo^X6G00Ko^X6G00?o0000
onBWT_l000001?o:UYl00ol0003o_H>Fokf3UP04okf3UP03o`000?o?Vj7oci^Q00Coci^Q00Go0000
olF=VOo5SIWoaHfIo`000002olnSZP03o`000?oFYJCoeZFT00?oeZFT00?o0000omZWXOl000001?o=
ZKD00ol0003ofZn/omZ_[002omZ_[003o`000?oQ]:So000000;o^:_<0ol000001?nhZlco0000ol^f
a_o;]/H2o`0000CoZKgX1?l00005ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00005ojVmj003o`00
0?nY_NSoZKgX00CoZKgX0_l00007ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP2o`0004;ooooo
000`ooooo`?o00000_ooool00ol0003oZKgXojVmj004ojVmj003o`000?nY_NSoZKgX00?oZKgX0ol0
0006ojVmj003o`000?nY_NSoZKgX00?oZKgX0ol00006ojVmj003o`000?nY_NSoZKgX00CoZKgX0_l0
0007ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP00ol0003oZKgXojVmj004ojVmj003o`000?nY
_NSoZKgX00?o00000_nY_NP00ol0003oZKgXojVmj005ojVmj003o`000?nY_NSo000000Ko00000_og
YUl01_l0003onZe@ooZ]D?l0003oki0ko`0000Cooooo00Go0000onfgUoo]]iOokKNGo`000005okUn
T`05o`000?o_^9GokkREonnhUOl000001OniOY<01Ol0003ol;RDoo2hU?o`^9Co000000Ko]gbC00Co
0000oo6gTOoa]i7o00001_ncNI<01Ol0003olKJ>oo6fS_oa]Xko000000Go]7^E00?o0000on>VTooS
YY<00_oSYY<00ol0003o_hVKo`000007ol>8U@;o00001onjPIL01Ol0003oi:NBonBWT_oTYi;o0000
00;obYJO00?o0000okf3U_nmPiH01OnmPiH00ol0003oci^QolnKX@04olnKX@07o`000?o5SIWoaHfI
olF=VOl0003ocj>Zo`000006omJUY004o`000?oJYj7ofZNQo`0000?ocJVe00?o0000omZ_[?oJ[j`0
0_oJ[j`00ol0003ohKBXo`000002o`0000?o^:_<00Ko0000ol^fa_o;]/KobkK6o`000?nY_NP4o`00
00;oZKgX00?o0000ojVmj?nY_NP01OnY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX
00KoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj006ojVmj0?o00001_nY_NP00ol0
003oooooooooo`10ooooo`00;oooool2o`0000;ooooo0_l00008ojVmj003o`000?nY_NSo000000;o
00000_nY_NP00ol0003oZKgXojVmj005ojVmj003o`000?nY_NSo000000;o00000_nY_NP00ol0003o
ZKgXojVmj005ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP00ol0003oZKgXojVmj004ojVmj0?o
00001_nY_NP00ol0003oZKgXojVmj003ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj004ojVmj0;o
00000onY_NP4o`0000;omjIO00Ko0000ooZ]D?oj[E3o0000onn@>ol00003ooooo`03o`000?o]]iOo
kKNG00;okKNG00?o0000okUnToniOY<00oniOY<01Ol0003okkREonnhUOo_^9Go000000Go^GjC00Go
0000oo2hU?o`^9Col;RDo`000005okMlT`05o`000?oa]i7olKNAoo6gTOl000001_ncNI<01Ol0003o
lKJ>oo6fS_oa]Xko000000Co]7^E00?o0000on>VTooSYY<00ooSYY<00ol0003o_hVKo`000007ol>8
U@;o00001onjPIL01Ol0003oi:NBonBWT_oTYi;o000000;obYJO00?o0000okf3U_nmPiH01OnmPiH0
0ol0003oci^QolnKX@04olnKX@07o`000?o5SIWoaHfIolF=VOl0003ocj>Zo`000006omJUY004o`00
0?oJYj7ofZNQo`0000;ocJVe00?o0000omZ_[?oJ[j`00_oJ[j`3o`000003on6dZ?l0003o^:_<00;o
^:_<00?o0000ol^fa_o;]/H00oo;]/H3o`0000GoZKgX00?o0000ojVmj?nY_NP00onY_NP4o`0000Go
ZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000GoZKgX00?o0000ojVmj?nY_NP00_nY_NP2o`000003
ojVmj?l0003oZKgX00KoZKgX0_l00011ooooo`00;oooool4o`0000;oZKgX00?o0000ojVmj?nY_NP0
1OnY_NP2o`0000KoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000KoZKgX00?o0000ojVmj?nY_NP0
1?nY_NP3o`0000KoZKgX00Co0000ojVmj?nY_NSoZKgX0_l00002ojVmj003o`000?nY_NSoZKgX00Go
ZKgX00?o0000ojVmj?l000000_l00002ojVmj003o`000?nY_NSoZKgX00GoZKgX00?o0000ojVmj?nY
_NP00ol000000onY_NSo0000ojVmj003ojVmj0?o00000_ogYUl01Ol0003onZe@ooZ]D?l0003oki0k
00;o00000_ooool00ol0003okKNGonfgU`02onfgU`03o`000?niOY?o^GjC00;o^GjC00?o0000onnh
UOo_^9D00_o_^9D00ol0003o^GjCokUnT`03okUnT`05o`000?o`^9Col;RDoo2hU?l000001OngO9<0
1Ol0003olKNAoo6gTOoa]i7o000000Ko/gVC00?o0000oo6fS_oa]Xh00_oa]Xh01Ol0003o]7^EokAk
UOndNiGo000000KohjJC0_l00007ol>8U@;o00001onjPIL01Ol0003oi:NBonBWT_oTYi;o000000;o
bYJO00?o0000okf3U_nmPiH01OnmPiH2o`0000Coci^Q00?o0000olF=VOo5SIT00oo5SIT2o`0000Go
eZFT00?o0000omZWXOoJYj400_oJYj401?l0003ocJVeo`000?oJ[j`4o`0000?ohKBX00Co0000okR[
c?nhZlco00001_o;]/H00ol0003oZKgXo`000005ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP0
0ol0003oZKgXojVmj005ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?nY_NP01_nY_NP0
1?l0003oZKgXo`000?l00004ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00010ooooo`00;_ooool2
o`0000KoZKgX00?o0000ojVmj?nY_NP00_nY_NP2o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY_NP0
0ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY_NP00ol0003oZKgXojVmj003
o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP00ol0003oZKgXo`000005ojVmj003o`000?nY_NSo
ZKgX00CoZKgX0_l00006ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00005ojVmj004o`000?nY_NSo
ZKgXojVmj0?o00000_ogYUl02_l0003onZe@ooZ]D?l0003oki0ko`000?oeXf3o0000ooooool00004
onfgU`03o`000?niOY?o^GjC00;o^GjC00?o0000onnhUOo_^9D00_o_^9D00ol0003o^GjCokUnT`03
okUnT`05o`000?o`^9Col;RDoo2hU?l000001OngO9<01Ol0003olKNAoo6gTOoa]i7o000000Go/gVC
00?o0000oo6fS_oa]Xh00ooa]Xh01Ol0003o]7^EokAkUOndNiGo000000KohjJC00?o0000ol>8UOo3
R9D01_o3R9D00ol0003olkV?o`000006okZ1U`07o`000?oTYi;oi:NBonBWT_l0003obYJOo`000007
okf3UP03o`000?o^/Hko000000Coci^Q00?o0000olF=VOo5SIT00oo5SIT00ol0003oeZFTomJUY004
omJUY003o`000?oJYj7ofZNQ00;ofZNQ1?l00003omZ_[007o`000?oQ]:SohKBXon6dZ?l0003o^:_<
o`000006ol^faP05o`000?oF_L7o0000ojVmj?l000001?nY_NP3o`0000KoZKgX00?o0000ojVmj?nY
_NP00onY_NP4o`0000GoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000OoZKgX00?o0000ojVmj?nY
_NP00ol000000onY_NSo0000o`000010ooooo`00;oooool2o`0000KoZKgX00Co0000ojVmj?l0003o
00001OnY_NP00ol0003oZKgXojVmj003ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj003ojVmj0?o
00001_nY_NP00ol0003oZKgXojVmj004ojVmj0;o00001onY_NP00ol0003oZKgXojVmj003o`0000;o
ZKgX00?o0000ojVmj?nY_NP01?nY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY
_NP01?nY_NP00ol0003oZKgXojVmj003o`0000;omjIO00Ko0000ooZ]D?oj[E3o0000onn@>ol00002
ooFSH003o`000?o]]iOokKNG00?okKNG00?o0000okUnToniOY<00_niOY<00ol0003okkREonnhU@02
onnhU@03o`000?niOY?o^GjC00?o^GjC00Go0000oo2hU?o`^9Col;RDo`000005okMlT`05o`000?oa
]i7olKNAoo6gTOl000001OncNI<00ol0003olKJ>oo6fSP03oo6fSP05o`000?ndNiGo]7^EokAkUOl0
00001_oSYY<00ol0003o`hREol>8U@06ol>8U@03o`000?oc^Hoo000000Ko^X6G00Oo0000onBWT_oT
Yi;oi:NBo`000?o:UYoo000000Oo_H>F00?o0000onjaS_l000001?o?Vj400ol0003oaHfIolF=V@03
olF=V@03o`000?oFYJCoeZFT00CoeZFT00?o0000omZWXOoJYj401?l00005omZ_[003o`000?oQ]:So
hKBX00;ohKBX00?o0000ol^fa_o;]/H01?o;]/H01_l0003oe[g1omJm`OoF_L7o0000ojVmj0Co0000
00?oZKgXo`000?nY_NP01_nY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP0
1OnY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000GoZKgX
0_l0000oooooo`008oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00Co0000oooooooooooo
00001OnY_NP3o`0000OoZKgX00?o0000ojVmj?l000000_l00002ojVmj003o`000?nY_NSoZKgX00Go
ZKgX00?o0000ojVmj?l000000_l00002ojVmj003o`000?nY_NSoZKgX00GoZKgX00?o0000ojVmj?nY
_NP00ol00002ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00006ojVmj003o`000?nY_NSoZKgX00?o
ZKgX0ol00006ojVmj003o`000?nY_NSoZKgX00?oZKgX1_l00002ooNVG`03o`000?oj[E3onZe@00?o
00000_oeXf000ol0003okKNGonfgU`03onfgU`03o`000?niOY?o^GjC00;o^GjC00?o0000onnhUOo_
^9D00oo_^9D01Ol0003o^GjCokUnToniOY?o000000Gol;RD00Go0000okMlTongO9?o]gbCo`000004
oo6gT@03o`000?ncNI?o/gVC00?o/gVC00?o0000oo6fS_oa]Xh00ooa]Xh01Ol0003o]7^EokAkUOnd
NiGo000000KohjJC00?o0000ol>8UOo3R9D01Oo3R9D01?l0003olkV?oo>iSol00005okZ1U`03o`00
0?oTYi;oi:NB00?oi:NB0_l00007okf3UP03o`000?o^/Hko000000Coci^Q00?o0000olF=VOo5SIT0
0oo5SIT2o`0000GoeZFT0ol00003omZWX@03o`000?oJ[jcofZn/00;ofZn/00?o0000on6dZ?oQ]:P0
0ooQ]:P00ol0003obkK6ol^faP04ol^faP03o`000?oF_L7oe[g100;oe[g10_l00005ojVmj003o`00
0?nY_NSoZKgX00CoZKgX0ol00006ojVmj003o`000?nY_NSoZKgX00?oZKgX1?l00006ojVmj003o`00
0?nY_NSoZKgX00?o000000?oZKgXo`000?nY_NP01_nY_NP2o`0003kooooo000Sooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01_ooool01_l0003ooooooooooooooooo0000ojVmj0?o00000onY_NP00ol0
003oZKgXojVmj004ojVmj0;o00001_nY_NP00ol0003oZKgXojVmj004ojVmj0;o00001_nY_NP00ol0
003oZKgXojVmj004ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVm
j?nY_NP01OnY_NP00ol0003oZKgXo`000002o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP00ol0
003oZKgXo`000002o`0000;oZKgX1?l00002ooNVG`03o`000?oj[E3onZe@00?o00000_oeXf000ol0
003okKNGonfgU`03onfgU`05o`000?niOY?o^GjCokUnTol000001_o_^9D01Ol0003o^GjCokUnToni
OY?o000000Gol;RD00Go0000okMlTongO9?o]gbCo`000005oo6gT@03o`000?ncNI?o/gVC00;o/gVC
00?o0000oo6fS_oa]Xh00ooa]Xh01?l0003o]7^EokAkUOl00007on>VT`03o`000?o3R9Go`hRE00Go
`hRE00Co0000oo>iSooc^Hoo00001OnjPIL00ol0003oi:NBonBWTP03onBWTP03o`000?nmPiKo_H>F
00Ko_H>F00?o0000onjaS_l000000oo?Vj400ol0003oaHfIolF=V@04olF=V@;o00000ooFYJ@3o`00
00GofZNQ0_l00003omZ_[003o`000?oQ]:SohKBX00;ohKBX00?o0000onFgY_l000001?o;]/H00ol0
003oe[g1omJm`@03omJm`@03o`000?nY_NSo000000GoZKgX00?o0000ojVmj?nY_NP00ol000000onY
_NSo0000ojVmj006ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP00ol0003oZKgXojVmj005ojVm
j0?o00001OnY_NP00ol0003oZKgXojVmj004ojVmj0;o0000?_ooool002?ooooo00Go410@oooooooo
oooooooooa0@4006ooooo`03o`000?oooooooooo00;ooooo00?o0000ojVmj?nY_NP01OnY_NP00ol0
003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY_NP00ol0003oZKgXojVmj003o`00
00;oZKgX00?o0000ojVmj?nY_NP01?nY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVm
j?nY_NP01?nY_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000KoZKgX00?o0000ojVm
j?nY_NP01?nY_NP2o`0000KoZKgX0ol00002ooNVG`03o`000?oj[E3onZe@00?o00000_oeXf000ol0
003okKNGonfgU`03onfgU`05o`000?niOY?o^GjCokUnTol000001_o_^9D01Ol0003o^GjCokUnToni
OY?o000000Gol;RD00Go0000okMlTongO9?o]gbCo`000005oo6gT@05o`000?ncNI?o/gVCok=iTol0
00001_oa]Xh01?l0003o]7^EokAkUOl00006on>VT`;o00001oo3R9D01?l0003olkV?oo>iSol00005
okZ1U`03o`000?oTYi;oi:NB00?oi:NB00?o0000okf3U_nmPiH01_nmPiH01?l0003ok[6>onjaS_l0
0002olnKX@03o`000?o5SIWoaHfI00?oaHfI00?o0000on2TTol000000ol000000ooFYJCo0000omZW
X@04omZWX@03o`000?oAVY_o000000?ofZn/00?o0000on6dZ?oQ]:P00_oQ]:P01?l0003oiKNVonFg
Y_l00003ol^faP03o`000?oF_L7oe[g100;oe[g100Go0000omo4_Ol0003oZKgXo`000004ojVmj0?o
00001OnY_NP00ol0003oZKgXojVmj004ojVmj0?o00001_nY_NP01?l0003oZKgXojVmj?nY_NP3o`00
0003ojVmj?l0003oZKgX00KoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000o`00000moooo
o`008oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00oooool00ol0
003oZKgXojVmj004ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj003ojVmj0?o00001_nY_NP00ol0
003oZKgXojVmj003ojVmj0?o00001_nY_NP01?l0003oZKgXojVmj?nY_NP2o`0000;oZKgX00?o0000
ojVmj?nY_NP01OnY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00KoZKgX00?o0000
ojVmj?nY_NP00ol000000onY_NSo0000ojVmj005ojVmj003o`000?l005[o000000;omjIO00?o0000
ooZ]D?oj[E000_l000000oo_T3_o0000o`000006onfgU`05o`000?niOY?o^GjCokUnTol000001_o_
^9D01Ol0003o^GjCokUnToniOY?o000000Gol;RD00Go0000okMlTongO9?o]gbCo`000005oo6gT@05
o`000?ncNI?o/gVCok=iTol000001_oa]Xh01?l0003o]7^EokAkUOl00006on>VT`;o00001oo3R9D0
1?l0003olkV?oo>iSol00005okZ1U`03o`000?oTYi;oi:NB00?oi:NB00?o0000okf3U_nmPiH01_nm
PiH01?l0003ok[6>onjaS_l00002olnKX@03o`000?o5SIWoaHfI00?oaHfI1?l00003omJUY003o`00
0?oJYj7ofZNQ00?ofZNQ00?o0000om6JVol000000_oJ[j`00ol0003ohKBXon6dZ003on6dZ007o`00
0?oU]jKoiKNVonFgY_l0003obkK6o`000005omJm`@05o`000?oOa;goglBmo`000?nY_NP01?l00000
0onY_NSo0000ojVmj006ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?nY_NP01_nY_NP0
1?l0003oZKgXo`000?l00005ojVmj003o`000?nY_NSoZKgX00?oZKgX1?l00005ojVmj0;o0000??oo
ool002?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Cooooo00Co
0000ojVmj?nY_NSoZKgX0_l00002ojVmj003o`000?nY_NSoZKgX00GoZKgX00?o0000ojVmj?l00000
0_l00002ojVmj003o`000?nY_NSoZKgX00GoZKgX00?o0000ojVmj?l000000_l00002ojVmj003o`00
0?nY_NSoZKgX00GoZKgX00?o0000ojVmj?l000001OnY_NP00ol0003oZKgXojVmj004ojVmj0?o0000
1OnY_NP00ol0003oZKgXojVmj004ojVmj0?o00001OnY_NP00ol0003oZKgXojVmj003ojVmj003o`00
0?l005[o000000;omjIO00Ko0000ooZ]D?oj[E3onZe@o`000?o_T3/2o`0000KokKNG00Go0000okUn
ToniOY?o^GjCo`000006onnhU@05o`000?niOY?o^GjCokUnTol000001Oo`^9@01Ol0003o]gbCokMl
TongO9?o000000GolKNA00Go0000ok=iToncNI?o/gVCo`000006oo6fSP04o`000?ndNiGo]7^Eo`00
00KohjJC00?o0000oo6kUol000001_o3R9D01?l0003olkV?oo>iSol00004okZ1U`03o`000?oTYi;o
i:NB00Coi:NB00?o0000okf3U_nmPiH01OnmPiH01ol0003ok[6>onjaS_o^/Hko0000olnKXOl00000
0oo5SIT4o`0000;oh:BC00Go0000omJUY?oFYJCoeZFTo`000005omZWX@06o`000?oAVY_odIZKo`00
0?oJ[jco00001?oQ]:P00ol0003oiKNVonFgYP03onFgYP03o`000?oF_L7oe[g100?oe[g100?o0000
omo4_OoOa;d00_oOa;d2o`0000GoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000GoZKgX00?o0000
ojVmj?nY_NP01?nY_NP2o`0000OoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSo
ZKgX00CoZKgX0_l0000looooo`008oooool01Ol@413ooooooooooooooooo410@00Gooooo0ol00006
ooooo`03o`000?nY_NSo000000GoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000KoZKgX00?o0000
ojVmj?nY_NP01?nY_NP2o`0000KoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000KoZKgX00?o0000
ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX00CoZKgX00?o0000ojVmj?nY_NP00ol00002
ojVmj003o`000?nY_NSoZKgX00CoZKgX00?o0000ojVmj?nY_NP00ol000001Ol005[o0000o`000?og
YUoo000000?onZe@1?l00006onfgU`04o`000?niOY?o^GjCo`0000OokkRE00Co0000okUnToniOY?o
00001_o`^9@01?l0003o]gbCokMlTol00006oo6gT@05o`000?ncNI?o/gVCok=iTol000001_oa]Xh0
1?l0003o]7^EokAkUOl00006on>VT`03o`000?oa^iOo000000Go`hRE00Go0000oo>iSooc^HoolkV?
o`000004okZ1U`03o`000?oTYi;oi:NB00Coi:NB00?o0000okf3U_nmPiH01OnmPiH01_l0003ok[6>
onjaS_o^/Hko0000olnKX@Co00000oo5SIT01?l0003oh:BCon2TTol00002omJUY003o`000?oJYj7o
fZNQ00?ofZNQ00Oo0000om6JVooAVY_odIZKo`000?oJ[jco000000CohKBX00?o0000onFgY_oU]jH0
0ooU]jH00ol0003oe[g1omJm`@02omJm`@03o`000?oOa;goglBm00?oglBm00?o0000ojVmj?l00000
1OnY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00KoZKgX00?o0000ojVmj?nY_NP0
0ol00002ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00006ojVmj003o`000?nY_NSoZKgX00?oZKgX
0ol0000kooooo`008oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0
1oooool2o`0000KoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX00CoZKgX
00?o0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX00CoZKgX00?o0000ojVmj?nY_NP0
0ol00003ojVmj003o`000?nY_NSoZKgX00?oZKgX0ol00006ojVmj003o`000?nY_NSoZKgX00?oZKgX
0ol00006ojVmj003o`000?nY_NSoZKgX00?oZKgX0ol00002ojVmj006o`000?l005[o0000o`000?og
YUoo00000ooj[E04o`0000OokKNG00?o0000okUnTol000001oo_^9D01?l0003o^GjCokUnTol00006
oo2hU004o`000?ngO9?o]gbCo`0000KolKNA00Go0000ok=iToncNI?o/gVCo`000006oo6fSP03o`00
0?ndNiGo000000KohjJC00Co0000oo6kUooa^iOo00001Oo3R9D01Ol0003olkV?oo>iSooc^Hoo0000
00Co^X6G00?o0000onBWT_oTYi800ooTYi800ol0003om;^@o`000006okf3UP04o`000?o^/Hkok[6>
onjaSP?o00001_o5SIT01ol0003oh:BCon2TTooPY9?o0000omJUY?l000001OoJYj401?l0003odIZK
om6JVooAVY/2o`0000GohKBX00?o0000onFgY_oU]jH00_oU]jH00ol0003ojKZTo`000003omJm`@03
o`000?oOa;goglBm00;oglBm00Go0000onG:_?l0003oZKgXo`000004ojVmj0?o00001OnY_NP00ol0
003oZKgXojVmj004ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX
00KoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000o`00000kooooo`008oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool02Oooool00ol0003oZKgXojVmj003ojVm
j0?o00001_nY_NP00ol0003oZKgXojVmj003ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj003ojVm
j0?o00001onY_NP00ol0003oZKgXo`000002o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP00ol0
003oZKgXo`000002o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP00ol0003oZKgXo`000002o`00
00;oZKgX00Go0000ojVmj?nY_NSo0000o`00FP02o`000003ooNVGol0003onZe@00;onZe@0ol00008
onfgU`03o`000?niOY?o000000OokkRE00Co0000okUnToniOY?o00001_o`^9@01?l0003o]gbCokMl
Tol00006oo6gT@04o`000?ncNI?o/gVCo`0000OolKJ>00?o0000okAkUOl000001_oSYY<01?l0003o
lK^Goo6kUol00005ol>8U@03o`000?oc^HoolkV?00;olkV?00Go0000okZ1UonjPIOo^X6Go`000005
onBWTP03o`000?od^i3o000000Ko_H>F1?l000000oo^/Hko0000olF=V@06olF=V@07o`000?oPY9?o
h:BCon2TTol0003oeZFTo`000005omZWX@03o`000?oAVY_odIZK00;odIZK00?o0000on6dZ?oQ]:P0
0_oQ]:P00ol0003oiKNVonFgYP03onFgYP06o`000?oY^ZCojKZTo`000?oF_L7o00001?oOa;d01_l0
003oiLZlonG:_?oUb[co0000ojVmj0Co000000?oZKgXo`000?nY_NP01_nY_NP00ol0003oZKgXojVm
j003o`000003ojVmj?l0003oZKgX00KoZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol0
0005ojVmj0;o0000>_ooool002gooooo00?o0000ooooooooool02_ooool00ol0003oZKgXo`000002
o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP00ol0003oZKgXo`000002o`0000;oZKgX00?o0000
ojVmj?nY_NP01OnY_NP00ol0003oZKgXo`000002o`0000?oZKgX00?o0000ojVmj?nY_NP01?nY_NP2
o`0000KoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000KoZKgX00?o0000ojVmj?nY_NP01?nY_NP2
o`0000KoZKgX00Co0000ojVmj?l0003o001J0_l000000oogYUoo0000ooZ]D002ooZ]D0?o00002?o]
]iL2o`0000SokkRE00Co0000okUnToniOY?o00001_o`^9@01?l0003o]gbCokMlTol00006oo6gT@04
o`000?ncNI?o/gVCo`0000SolKJ>0_l00006on>VT`04o`000?oa^iOolK^Go`0000Go`hRE00?o0000
oo>iSooc^Hl00_oc^Hl01Ol0003o^X6GokZ1UonjPIOo000000Goi:NB00?o0000ooBkT?l000001Onm
PiH2o`0000Cok[6>00?o0000olF=VOo5SIT01?o5SIT00ol0003oh:BCon2TT`02on2TT`;o00001OoJ
Yj400ol0003odIZKom6JV`03om6JV`03o`000?oQ]:SohKBX00;ohKBX00?o0000onFgY_oU]jH00ooU
]jH01_l0003ojKZTonVjY?l0003oe[g1o`0000CoglBm00?o0000onG:_?oUb[`00_oUb[`2o`0000Go
ZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000GoZKgX00?o0000ojVmj?nY_NP00_nY_NP2o`000003
ojVmj?l0003oZKgX00KoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj006ojVmj0;o
0000>Oooool002gooooo00?o0000ooooooooool02oooool00ol0003oZKgXojVmj004ojVmj003o`00
0?nY_NSoZKgX00CoZKgX0_l00006ojVmj003o`000?nY_NSoZKgX00CoZKgX0_l00007ojVmj003o`00
0?nY_NSoZKgX00?o00000_nY_NP00ol0003oZKgXojVmj004ojVmj003o`000?nY_NSoZKgX00?o0000
00?oZKgXo`000?nY_NP01_nY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00KoZKgX
0_l000001Ol005[o0000o`000?ogYUoo000000?onZe@0ol00008onfgU`;o00002?o_^9D00ol0003o
^GjCo`000007oo2hU004o`000?ngO9?o]gbCo`0000KolKNA00Co0000ok=iToncNI?o00002?oa]Xh2
o`0000GohjJC00Go0000oo6kUooa^iOolK^Go`000005ol>8U@03o`000?oc^HoolkV?00;olkV?00Co
0000okZ1UonjPIOo00001_oTYi800ol0003om;^@o`000002okf3UP?o000000?o_H>Fo`000?o^/Hh0
0oo^/Hh00ol0003oaHfIolF=V@04olF=V@03o`000?oPY9?oh:BC00?oh:BC00?o0000omZWXOoJYj40
0ooJYj400ol0003odIZKom6JV`03om6JV`;o00000ooQ]:P00ol0003oiKNVonFgYP02onFgYP03o`00
0?oY^ZCojKZT00;ojKZT00?o0000omo4_OoOa;d00_oOa;d00ol0003oiLZlonG:_003onG:_003o`00
0?nY_NSo000000GoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj006ojVmj004o`00
0?nY_NSo0000o`0000CoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000GoZKgX00?o0000ojVmj?nY
_NP01?nY_NP2o`0003Wooooo000]ooooo`03o`000?oooooooooo00cooooo00?o0000ojVmj?nY_NP0
1?nY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY_NP00ol0003oZKgX
ojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP0
0onY_NP3o`0000GoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000GoZKgX00?o0000ojVmj?nY_NP0
1?nY_NP2o`0000;o001J00Co0000ooNVGoogYUoo00000_oj[E02o`0000WokKNG0_l00008onnhU@03
o`000?niOY?o000000Ool;RD00?o0000okMlTol000001ooa]i401?l0003o/gVCok=iTol00008oo6f
SP;o00001OoSYY<01Ol0003olK^Goo6kUooa^iOo000000Co`hRE00?o0000oo>iSooc^Hl00ooc^Hl0
1?l0003o^X6GokZ1Uol00006onBWTP03o`000?od^i3o000000;o00000onmPiH00ol0003ok[6>onja
SP03onjaSP03o`000?o5SIWoaHfI00CoaHfI00?o0000on2TTooPY9<00ooPY9<00ol0003ofZNQomZW
X@03omZWX@03o`000?oAVY_odIZK00;odIZK00?o0000omjSUOl000000_oQ]:P00ol0003oiKNVonFg
YP03onFgYP03o`000?oY^ZCojKZT00;ojKZT00?o0000omo4_OoOa;d00_oOa;d00ol0003oiLZlonG:
_002onG:_005o`000?oYdKgo0000ojVmj?l000001?nY_NP3o`0000GoZKgX00?o0000ojVmj?nY_NP0
1?nY_NP2o`0000OoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj006ojVmj003o`00
0?nY_NSoZKgX00?o000000?oZKgXo`000?l00000>?ooool002gooooo00?o0000ooooooooool03Ooo
ool00ol0003oZKgXojVmj003ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj003ojVmj0?o00001_nY
_NP01?l0003oZKgXojVmj?nY_NP2o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP00ol0003oZKgX
o`000002o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY_NP00ol0003oZKgXojVmj003o`0000;oZKgX
00?o0000ojVmj?nY_NP01?nY_NP00ol0003oZKgXojVmj003o`000005ojVmj?l0003o0000o`00F_l0
00000_ogYUl00ol0003onZe@o`000002o`0000WokKNG0_l00009onnhU@;o00002?o`^9@2o`0000Oo
lKNA00?o0000ok=iTol000002Ooa]Xh00ol0003ohjJCon>VT`04on>VT`05o`000?oa^iOolK^Goo6k
Uol000001?o3R9D00ol0003olkV?oo>iS`03oo>iS`04o`000?njPIOo^X6Go`0000Goi:NB1?l00005
okf3UP03o`000?o^/Hkok[6>00?ok[6>00?o0000olF=VOo5SIT01?o5SIT00ol0003oh:BCon2TT`03
on2TT`03o`000?oJYj7ofZNQ00?ofZNQ00?o0000om6JVooAVY/00_oAVY/01_l0003ogZ>EomjSUOl0
003ohKBXo`0000GoiKNV00Oo0000onVjY?oY^ZCojKZTo`000?o^`:;o000000;oglBm00?o0000onG:
_?oUb[`00_oUb[`01?l0003ojM6monWA_OoYdKd2o`000006ojVmj?l0003o0000o`000?nY_NSo0000
1onY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00GoZKgX1?l00005ojVmj003o`00
0?nY_NSoZKgX00?oZKgX1?l00005ojVmj0;o0000=oooool002cooooo0ol0000?ooooo`03o`000?nY
_NSo000000;o00000_nY_NP00ol0003oZKgXojVmj005ojVmj003o`000?nY_NSo000000;o00000_nY
_NP00ol0003oZKgXojVmj005ojVmj003o`000?nY_NSo000000GoZKgX00?o0000ojVmj?nY_NP01?nY
_NP2o`0000KoZKgX00?o0000ojVmj?nY_NP00onY_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP00onY
_NP3o`0000GoZKgX00Co0000o`00F_l0003omjIO0ol00002oj6ReP03o`000?o]]iOokKNG00OokKNG
00?o0000onnhUOo_^9D02?o_^9D2o`0000Sol;RD0_l00008oo6gT@;o00002Ooa]Xh00ol0003ohjJC
on>VT`04on>VT`05o`000?oa^iOolK^Goo6kUol000001?o3R9D00ol0003olkV?oo>iS`03oo>iS`04
o`000?njPIOo^X6Go`0000;oi:NB1?l00002ooBkT003o`000?nmPiKo_H>F00?o_H>F00?o0000onja
S_o^/Hh00_o^/Hh00ol0003om;b?o`000005olF=V@03o`000?oPY9?oh:BC00?oh:BC0_l00003omZW
X@03o`000?oAVY_odIZK00?odIZK00Ko0000omjSUOoNXiGo0000on6dZ?l00004onFgYP03o`000?oY
^ZCojKZT00;ojKZT00Go0000onk0X_l0003oglBmo`000005onG:_003o`000?oYdKgojM6m00;ojM6m
0_l00005ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00?o0000
0_nY_NP00ol0003oZKgXojVmj004ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP00ol0003oZKgX
ojVmj004ojVmj0?o0000=_ooool002cooooo00?o0000ooooooooool04?ooool00ol0003oZKgXojVm
j004ojVmj003o`000?nY_NSoZKgX00CoZKgX0_l00006ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol0
0006ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?nY_NP01_nY_NP00ol0003oZKgXo`00
0002o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP00ol0003oZKgXo`000002o`0000?oZKgX00?o
0000ojVmj?nY_NP00_nY_NP01?l0003o001Jo`000?l00006oj6ReP03o`000?o]]iOokKNG00GokKNG
0_l0000:onnhU@;o00002?o`^9@2o`0000SolKNA0_l00009oo6fSP03o`000?oSYY?ohjJC00?ohjJC
00?o0000oo6kUooa^iL00ooa^iL01Ol0003o`hREol>8UOo3R9Go000000GolkV?00?o0000okZ1Uonj
PIL00ol00003onBWTP05o`000?od^i3om;^@ooBkT?l000001?nmPiH00ol0003ok[6>onjaSP02onja
SP03o`000?od_8oo000000GoaHfI00?o0000on2TTooPY9<00_oPY9<00ol0003omKZ;o`000003omZW
X@03o`000?oAVY_odIZK00?odIZK00?o0000omjSUOoNXiD00_l00005onFgYP03o`000?oY^ZCojKZT
00;ojKZT00Go0000onk0X_l0003oglBmo`000004onG:_003o`000?oYdKgojM6m00?ojM6m00?o0000
ojVmj?l000001OnY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00GoZKgX0ol00006
ojVmj003o`000?nY_NSoZKgX00?oZKgX0ol00006ojVmj003o`000?nY_NSoZKgX00?oZKgX0ol0000f
ooooo`00;?ooool00ol0003oooooooooo`0Aooooo`03o`000?nY_NSoZKgX00CoZKgX00?o0000ojVm
j?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX00CoZKgX00?o0000ojVmj?nY_NP00ol00003ojVm
j003o`000?nY_NSoZKgX00?oZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00CoZKgX0_l00006ojVm
j003o`000?nY_NSoZKgX00CoZKgX0_l00007ojVmj003o`000?nY_NSoZKgX00;o000000?o001Jo`00
0?nQX]H01_nQX]H00ol0003okKNGonfgU`04onfgU`03o`000?ni[/ko000000[okkRE00?o0000oo2h
U?o`^9@01oo`^9@2o`0000SolKNA0_l00008oo6fSP;o00001OoSYY<00ol0003olK^Goo6kU`03oo6k
U`05o`000?o3R9Go`hREol>8UOl000001Ooc^Hl3o`0000Koi:NB00Go0000ooBkT?od^i3om;^@o`00
0004okf3UP03o`000?o^/Hkok[6>00;ok[6>00?o0000ooBlSol000001?o5SIT00ol0003oh:BCon2T
T`03on2TT`03o`000?oe^X_o000000?ofZNQ00?o0000om6JVooAVY/00ooAVY/01Ol0003ogZ>EomjS
UOoNXiGo000000GoiKNV00Go0000onVjY?oY^ZCojKZTo`000003onk0XP03o`000?oUb[coiLZl00?o
iLZl00?o0000onWA_OoYdKd00_oYdKd01Ol0003ojmW2o`000?nY_NSo000000?oZKgX1?l00005ojVm
j003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?nY_NP01_nY_NP00ol0003oZKgXojVmj003o`00
0003ojVmj?l0003oZKgX00KoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj0;o0000=Oooool002co
oooo00?o0000ooooooooool04_ooool00ol0003oZKgXojVmj003ojVmj0?o00001_nY_NP00ol0003o
ZKgXojVmj003ojVmj0?o00001onY_NP00ol0003oZKgXo`000002o`0000;oZKgX00?o0000ojVmj?nY
_NP01?nY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY_NP00ol0003o
ZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`000005ojVmj?l0003o001Jo`00
F_l000001onQX]H00ol0003okKNGonfgU`02onfgU`05o`000?ni[/ko^Jk>okV^c_l000002?o_^9D2
o`0000Wol;RD00?o0000oo6gTOoa]i401ooa]i42o`0000SolKJ>00?o0000on:l/_l000001?oSYY<0
0ol0003olK^Goo6kU`03oo6kU`04o`000?o3R9Go`hREo`0000?olkV?1?l000000onjPIOo0000onBW
TP05onBWTP05o`000?od^i3om;^@ooBkT?l000000onmPiH00ol0003ok[6>onjaSP03onjaSP03o`00
0?od_8oo000000CoaHfI00?o0000on2TTooPY9<00ooPY9<01_l0003omKZ;ooFjRol0003ofZNQo`00
00GodIZK00?o0000omjSUOoNXiD00_oNXiD00ol0003oiKNVonFgYP02onFgYP03o`000?oY^ZCojKZT
00;ojKZT00Go0000onk0X_o^`:;ok/2Ro`000004onG:_003o`000?oYdKgojM6m00;ojM6m00Go0000
on_I`_o[fL;o0000ojVmj004o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000GoZKgX00?o
0000ojVmj?nY_NP01?nY_NP3o`0000GoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000KoZKgX00?o
0000ooooooooool0<oooool002cooooo00?o0000ooooooooool04oooool00ol0003oZKgXo`000002
o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP00ol0003oZKgXo`000002o`0000?oZKgX00?o0000
ojVmj?nY_NP01?nY_NP2o`0000KoZKgX00?o0000ojVmj?nY_NP00onY_NP3o`0000KoZKgX00?o0000
ojVmj?nY_NP00onY_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSo
000000;o001J00?o0000oj6Re_nQX]H01_nQX]H01?l0003okKNGonfgUol00004okV^cP03o`000?o_
^9GokkRE00GokkRE00?o0000okf`cOl000002?o`^9@2o`0000WolKNA00?o0000oo6fS_oa]Xh01_oa
]Xh01?l0003oh[bbon:l/_l00004on>VT`03o`000?oa^iOolK^G00?olK^G00?o0000ol>8UOo3R9D0
1?l00004oo>iS`;o00001OoTYi800ol0003om;^@ooBkT002ooBkT005o`000?nmPiKo_H>Fokf3U_l0
00001Oo^/Hh00ol0003om;b?o`000004olF=V@03o`000?oPY9?oh:BC00?oh:BC00Ko0000ooFjRooe
^X_o0000omZWXOl00005om6JV`03o`000?oNXiGogZ>E00;ogZ>E0_l00003onFgYP03o`000?oY^ZCo
jKZT00;ojKZT00Co0000onk0X_o^`:;ok/2R0_l00002onG:_003o`000?oYdKgojM6m00?ojM6m00Co
0000on_I`_o[fL;ojmW20ol00005ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?nY_NP0
1_nY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00KoZKgX00?o0000ojVmj?nY_NP0
0ol00002ojVmj003o`000?nY_NSoZKgX00CoZKgX0_l0000dooooo`00;?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?nY_NSoZKgX00CoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000KoZKgX00?o
0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj006ojVmj003o`000?nY_NSo000000;o00000_nY
_NP00ol0003oZKgXojVmj005ojVmj003o`000?nY_NSo000000;o00000onY_NP00ol0003oZKgXojVm
j003ojVmj0?o00001_nY_NP2o`0000?o001J00?o0000oj6Re_nQX]H01OnQX]H00ol0003okKNGo`00
0006okV^cP03o`000?o_^9GokkRE00;okkRE0_l00003okf`c@03o`000?o`^9Col;RD00Col;RD00?o
0000ol2ccOl000002Ooa]i400ol0003olKJ>oo6fSP05oo6fSP05o`000?oR_;;oh[bbon:l/_l00000
0ooSYY<00ol0003olK^Goo6kU`04oo6kU`04o`000?o3R9Go0000o`0000OolkV?0_l00005onBWTP03
o`000?od^i3om;^@00;om;^@00Go0000okf3U_nmPiKo_H>Fo`000004onjaSP05o`000?od_8oom;b?
ooBlSol000000oo5SIT00ol0003oh:BCon2TT`03on2TT`06o`000?oe^X_omKZ;o`000?oJYj7o0000
1OoAVY/00ol0003ogZ>EomjSU@02omjSU@;o00000ooU]jH01Ol0003ojKZTonVjY?oY^ZCo000000?o
k/2R00Ko0000oo?5X?ocaJ3o0000onG:_?l00004onWA_@03o`000?o[fL;ojmW200;ojmW20_l00000
0onY_NSo0000ojVmj003ojVmj0?o00001OnY_NP00ol0003oZKgXojVmj004ojVmj0?o00001OnY_NP0
0ol0003oZKgXojVmj004ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003o
000003?ooooo000[ooooo`03o`000?oooooooooo01Kooooo00?o0000ojVmj?nY_NP01?nY_NP00ol0
003oZKgXojVmj003o`0000?oZKgX00?o0000ojVmj?nY_NP00onY_NP3o`0000GoZKgX00?o0000ojVm
j?nY_NP01?nY_NP2o`0000KoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000OoZKgX00?o0000ojVm
j?l000000_l00002ojVmj003o`000?nY_NSoZKgX00GoZKgX00?o0000o`00F_l005X00_l005X00ol0
003oXJ;Foj6ReP03oj6ReP?o00002?ni[/h01?l0003okkREonnhUOl00005okf`c@03o`000?o`^9Co
l;RD00;ol;RD0_l00003ol2cc@03o`000?oa]i7olKNA00GolKNA0_l00007oo6fSP05o`000?oR_;;o
h[bbon:l/_l000000ooSYY<00ol0003olK^Goo6kU`03oo6kU`?o000000?o`hREo`000?oc^Hl01_oc
^Hl2o`0000Goi:NB00?o0000ooBkT?od^i000_od^i001Ol0003o_H>Fokf3U_nmPiKo000000Cok[6>
00Go0000ooBlSood_8oom;b?o`000003olF=V@03o`000?oPY9?oh:BC00;oh:BC00?o0000ooFjRooe
^X/00_oe^X/00ol0003odIZKom6JV`04om6JV`05o`000?oNXiGogZ>EomjSUOl000000_oa]H`00ol0
003oiKNVo`000004onVjY005o`000?o^`:;ok/2Ronk0X_l000000oocaJ000ol0003ojM6monWA_@02
onWA_@03o`000?o[fL;ojmW200;ojmW200Go0000onSQbooXhL_o0000ojVmj004o`000003ojVmj?l0
003oZKgX00KoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj006ojVmj003o`000?nY
_NSoZKgX00?o000000?oZKgXo`000?nY_NP01OnY_NP4o`0000GoZKgX00?o0000ooooooooool0<Ooo
ool002_ooooo0_l0000Hooooo`03o`000?nY_NSoZKgX00?oZKgX0ol00007ojVmj003o`000?nY_NSo
000000;o00000_nY_NP00ol0003oZKgXojVmj004ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP0
0ol0003oZKgXojVmj004ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP00ol0003oZKgXojVmj004
ojVmj0;o00001_nY_NP00ol0003oZKgXojVmj004ojVmj0Co000000Co001Jo`000?nQX]KoXJ;F0ol0
0002oj>Ue`03o`000?ni[/ko^Jk>00Ko^Jk>00?o0000onnhUOl000001onm/<d01?l0003ol;RDoo2h
U?l00005ol2cc@03o`000?oa]i7olKNA00ColKNA00Co0000olBec?o4]Lco00001Ooa]Xh00ol0003o
h[bbon:l/P03on:l/P04o`000?oSYY?ohjJCo`0000;olK^G0ol000001Ooa^iOo0000ol>8UOo3R9Go
000000OolkV?00?o0000onBWT_oTYi801?oTYi800ol0003om;^@ooBkT002ooBkT005o`000?nmPiKo
_H>Fokf3U_l000001?o^/Hh01Ol0003om;b?ooBlSood_8oo000000?oaHfI00?o0000on2TTooPY9<0
0_oPY9<00ol0003omKZ;ooFjR`02ooFjR`03o`000?oAVY_odIZK00CodIZK00Go0000omjSUOoNXiGo
gZ>Eo`000002oo6eS003o`000?oU]jKo000000CojKZT00Go0000onk0X_o^`:;ok/2Ro`000003oo?5
X0;o00000ooYdKd01Ol0003ojmW2on_I`_o[fL;o000000Coj>7;0_l00005ojVmj003o`000?nY_NSo
ZKgX00CoZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00005ojVmj003o`000?nY_NSo
ZKgX00?o00000_nY_NP00ol0003oZKgXojVmj004ojVmj0?o0000<Oooool002_ooooo00?o0000oooo
ooooool06?ooool00ol0003oZKgXo`000002o`0000?oZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`00
00KoZKgX00?o0000ojVmj?nY_NP00onY_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP00onY_NP3o`00
00KoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj006ojVmj003o`000?nY_NSoZKgX
00Co00000omaRM`4o`0000KoXjGG00?o0000okV^c_ni[/h01Oni[/h2o`0000So_K3=00?o0000oo2h
U?l000001oo0/ld00ol0003olKNAoo6gT@02oo6gT@05o`000?o4]Lcoa;G<olBec?l000001Ooa]Xh0
0ol0003oh[bbon:l/P03on:l/P03o`000?oSYY?o000000?o00001?oa^iL00ol0003o`hREo`000008
oo>iS`03o`000?oTYi;oi:NB00Coi:NB00?o0000ooBkT?od^i000ood^i001?l0003o_H>Fokf3U_l0
0004onjaSP05o`000?od_8oom;b?ooBlSol000000oo5SIT00ol0003oh:BCon2TT`02on2TT`03o`00
0?oe^X_omKZ;00;omKZ;00?o0000om6JVooAVY/00ooAVY/00ol0003ogZ>EomjSU@02omjSU@06o`00
0?oa]HcolKF<o`000?oU]jKo00000ooY^Z@01Ol0003ok/2Ronk0X_o^`:;o000000CollFP00Go0000
ooO<Wol0003ojM6mo`000003on_I`P03o`000?oXhL_oj>7;00;oj>7;0_l000000onY_NSo0000ojVm
j004ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?nY_NP01_nY_NP00ol0003oZKgXojVm
j003o`000003ojVmj?l0003oZKgX00GoZKgX0ol00006ojVmj003o`000?nY_NSoZKgX00?oZKgX0ol0
0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@0Booooo`00:oooool00ol0003oooooooooo`0Iooooo`;o00001_nY_NP00ol0003oZKgX
ojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY_NP00ol0003oZKgXo`000002o`0000;oZKgX
00?o0000ojVmj?nY_NP01OnY_NP00ol0003oZKgXo`000002o`0000?oZKgX00?o0000ojVmj?nY_NP0
0onY_NP3o`0000GoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000CoZKgX00?o0000og69g?maRM`0
0_maRM`00ol0003oXjGGoj>Ue`05oj>Ue`03o`000?ni[/ko^Jk>00?o^Jk>0_l000000oni[<co0000
okf`c@07okf`c@;o00002Oo0/ld01?l0003olKNAoo6gTOl00005olBec005o`000?oa]XkolKJ>oo6f
S_l000001_oR_;83o`0000OolK^G00?o0000ol>8UOl000002?oc^Hl00ol0003oi:NBonBWTP03onBW
TP03o`000?od^i3om;^@00Com;^@00?o0000okf3U_l000001Oo^/Hh01Ol0003om;b?ooBlSood_8oo
000000;oaHfI00?o0000on2TTooPY9<00ooPY9<00ol0003omKZ;ooFjR`02ooFjR`03o`000?oAVY_o
dIZK00?odIZK00?o0000omjSUOoNXiD00_oNXiD01Ol0003olKF<oo6eS?oa]Hco000000CojKZT00Go
0000onk0X_o^`:;ok/2Ro`000003oo?5X004o`000?ogc9oomlbOooO<W`;o00000oo[fL801Ol0003o
j>7;onSQbooXhL_o000000;ogncJ00?o0000ojVmj?l000001?nY_NP3o`0000GoZKgX00?o0000ojVm
j?nY_NP01?nY_NP3o`0000GoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj006ojVm
j003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?l000002Oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo017ooooo000[ooooo`03o`000?oooooooooo
01_ooooo00?o0000ojVmj?nY_NP00onY_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP00onY_NP2o`00
00KoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000OoZKgX00?o0000ojVmj?l000000_l00002ojVm
j003o`000?nY_NSoZKgX00CoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX
00;oZKgX00?o0000og69g?maRM`00omaRM`00ol0003oXjGGoj>Ue`05oj>Ue`05o`000?ni[/ko^Jk>
okV^c_l000001?ni[<`00ol0003o_K3=okf`c@04okf`c@03o`000?nl[lco000000Wo`;?=00?o0000
oo6gTOl000001oo4]L`00ol0003olKJ>o`000004on:l/PCo000000?ohjJCo`000?oa^iL01ooa^iL2
o`0000OolkV?0_l00005onBWTP03o`000?od^i3om;^@00Com;^@00?o0000okf3U_l000001?o^/Hh0
0ol0003om;b?ooBlS`03ooBlS`03o`000?o5SIWo000000Goh:BC00Co0000ooFjRooe^X_omKZ;0_l0
0005om6JV`03o`000?oNXiGogZ>E00;ogZ>E00Go0000oo6eS?oa]HcolKF<o`000004onVjY005o`00
0?o^`:;ok/2Ronk0X_l000000oocaJ002Ol0003omlbOooO<Woogc9oo0000oo[BWOl0003ojmW2o`00
0003onSQb`03o`000?oOk=[ogncJ00;ogncJ0_l000001_nY_NSo0000o`000?l0003oZKgXo`0000Oo
ZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj005ojVmj0?o00001OnY_NP00ol0003o
ZKgXojVmj004ojVmj0?o00001OnY_NP2o`0000Sooooo00Go410@oooooooooooooooooa0@400@oooo
o`03o`000?oooooooooo013ooooo000[ooooo`03o`000?oooooooooo01cooooo00?o0000ojVmj?l0
00000_l00002ojVmj003o`000?nY_NSoZKgX00GoZKgX00?o0000ojVmj?l000000_l00002ojVmj003
o`000?nY_NSoZKgX00CoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX00Co
ZKgX0_l00006ojVmj003o`000?nY_NSoZKgX00?oZKgX0ol00006ojVmj003o`000?nY_NSoZKgX00;o
ZKgX00?o0000og69g?maRM`00omaRM`00ol0003oXjGGoj>Ue`04oj>Ue`04o`000?ni[/ko0000o`00
00Ko^Jc<00?o0000okf`cOnm/<d00_nm/<d01Ol0003o_:o<okb_c?nl[lco000000So`;?=0_l00008
olBec004o`000?oa]Xko0000on:l/P?o00000ooR_;800ol0003ohjJCo`000008oo6kU`;o00001ooc
^Hl00ol0003oi;nbo`000004onBWTP03o`000?od^i3om;^@00Com;^@00?o0000okf3U_l000001?o^
/Hh00ol0003om;b?ooBlS`03ooBlS`03o`000?o5SIWo000000Goh:BC00Oo0000ooFjRooe^X_omKZ;
o`000?of_Xoo000000CodIZK00?o0000omjSUOoNXiD00_oNXiD01?l0003olKF<oo6eS?oa]H`2o`00
00;ojKZT00Go0000onk0X_o^`:;ok/2Ro`000004oo?5X005o`000?ogc9oomlbOooO<Wol000000_oj
dYd01Ol0003oj>7;onSQbooXhL_o000000GogncJ0ol00005ojVmj003o`000?nY_NSoZKgX00CoZKgX
0ol00005ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?nY_NP01_nY_NP00ol0003oZKgX
ojVmj003o`000003ojVmj?l0003oZKgX00KoZKgX0_l00007ooooo`05o`000?ooooooooooooooool0
00003oooool00omgMgOo<S8booooo`0Aooooo`00:oooool00ol0003oooooooooo`0Mooooo`03o`00
0?nY_NSoZKgX00CoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000KoZKgX00?o0000ojVmj?nY_NP0
0onY_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX00CoZKgX
00?o0000ojVmj?l000000_l00002ojVmj003o`000?nY_NSoZKgX00GoZKgX00?o0000ojVmj?l00000
0ol00004og69g003o`000?nSYMOoXjGG00CoXjGG0_l00008okV/c005o`000?nm/<go_K3=okf`cOl0
00001?nl[l`00ol0003o`;?=ol2cc@05ol2cc@03o`000?nm/Lko000000Soa;G<1?l00007on:l/P03
o`000?oa^iOolK^G00OolK^G0_l00006oo>iS`04o`000?oT_k;oi;nbo`0000Coi:NB00?o0000ooBk
T?od^i001?od^i000ol0003o_H>Fo`000004onjaSP03o`000?od_8oom;b?00?om;b?00?o0000olF=
VOl000001?oPY9<00ol0003omKZ;ooFjR`02ooFjR`03o`000?of_Xoo000000?odIZK00?o0000omjS
UOoNXiD00ooNXiD01?l0003olKF<oo6eS?oa]H`2o`0000;ojKZT00Go0000onk0X_o^`:;ok/2Ro`00
0003oo?5X005o`000?ogc9oomlbOooO<Wol000000oojdYd2o`000003onSQbol0003ogncJ00CogncJ
00Go0000olKUkOl0003oZKgXo`000005ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?nY
_NP01OnY_NP3o`0000GoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000GoZKgX00?o0000ojVmj?nY
_NP01?nY_NP2o`0000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`04_ooool002[ooooo00?o0000ooooooooool07oooool00ol0003oZKgXojVmj004ojVm
j003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?nY_NP01_nY_NP00ol0003oZKgXo`000002o`00
00?oZKgX00?o0000ojVmj?nY_NP00onY_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP00onY_NP2o`00
00KoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000;oZKgX0_l00005og69g003o`000?nSYMOoXjGG
00?o000000?oXZ?Fo`000?ni[<`02?ni[<`00ol0003o_K3=o`000006okb_c003o`000?o0/lgo`;?=
00;o`;?=0_l00003okfacP03o`000?o4]Lcoa;G<00Coa;G<0ol00008on:l/P;o00002Ooa^iL00ol0
003olkV?oo>iS`05oo>iS`04o`000?oT_k;oi;nbo`0000Coi:NB00?o0000ooBkT?od^i001?od^i00
0ol0003o_H>Fo`000004onjaSP03o`000?od_8oom;b?00?om;b?00?o0000olF=VOl000001?oPY9<0
0ol0003omKZ;ooFjR`02ooFjR`03o`000?of_Xoo000000?odIZK00?o0000omjSUOoNXiD00_oNXiD0
1Ol0003olKF<oo6eS?oa]Hco000000;on;b800?o0000onVjY?l000000oo^`:801Ol0003ollFPoo?5
X?ocaJ3o000000?omlbO00Ko0000oo[BWOojdYgon]:Mo`000?oleih2o`0000?ogncJ0_l00003olKU
k@03o`000?nY_NSo000000CoZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`00
0?nY_NP01_nY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00KoZKgX00?o0000ojVm
j?nY_NP00ol000000onY_NSo0000o`000006ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`0Dooooo`00:_ooool00ol0003oooooooooo`0Pooooo`03o`000?nY_NSoZKgX
00?oZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00006ojVmj003o`000?nY_NSo0000
00;o00000_nY_NP00ol0003oZKgXojVmj005ojVmj003o`000?nY_NSo000000;o00000_nY_NP00ol0
003oZKgXojVmj004ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP01?l0003oZKgXo`000?l004T8
o`0000GoXZ?F00?o0000okV/c?ni[<`01_ni[<`2o`0000So_:o<00Co0000ol2ccOo0/lgo00001Onm
/Lh01?l0003oa;G<olBec?o4]L`3o`0000?o_[??00?o0000on:l/_oR_;801?oR_;800ol0003o_[GA
o`000008oo6kU`;o00001_oc^Hl00ol0003oi;nbonBo/P02onBo/P04o`000?oTYi;oi:NBo`0000Oo
m;^@00?o0000okf3U_l000001?o^/Hh00ol0003om;b?ooBlS`03ooBlS`03o`000?o5SIWo000000Co
h:BC00?o0000ooFjRooe^X/00_oe^X/00ol0003om[j?o`000003om6JV`03o`000?oNXiGogZ>E00;o
gZ>E00Go0000oo6eS?oa]HcolKF<o`000002ooRlR0;o00001?o^`:801Ol0003ollFPoo?5X?ocaJ3o
000000?omlbO00Co0000oo[BWOojdYgo00000_oleih01Ol0003oo=bOo`000?oOk=[o000000Koa^G]
0_l000001_nY_NSo0000o`000?l0003oZKgXo`0000KoZKgX0ol00005ojVmj003o`000?nY_NSoZKgX
00CoZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00?oZKgX1?l00005ojVmj0;o00001Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool05?ooool002[ooooo0ol0000Qoooo
o`03o`000?nY_NSo000000;o00000_nY_NP00ol0003oZKgXojVmj004ojVmj003o`000?nY_NSoZKgX
00?o00000onY_NP00ol0003oZKgXojVmj003ojVmj0;o00001_nY_NP00ol0003oZKgXojVmj004ojVm
j0;o00001_nY_NP00ol0003oZKgXojVmj003ojVmj0?o00001_nY_NP2o`000003o`00BOl0003oMI7P
00CoMI7P00?o0000oj:Se_nRXmH01?nRXmH00ol0003o^Jc<okV/c005okV/c003o`000?nl[<[o0000
00So_:o<00?o0000ol2ccOl000001onm/Lh4o`0000Ko_[??00?o0000on:l/_oR_;800_oR_;801Ol0
003o_[GAokjedOnn]M7o000000KolK^G00?o0000ol>hd?l000001_oc^Hl00ol0003oi;nbonBo/P02
onBo/P04o`000?oTYi;oi:NBo`0000Som;^@00?o0000onjaS_o^/Hh00_o^/Hh00ol0003om;b?ooBl
S`05ooBlS`03o`000?oPY9?oh:BC00?oh:BC00Go0000ooFjRooe^X_omKZ;o`000002ooJnS`05o`00
0?oAVY_odIZKom6JVol000001?oNXiD01Ol0003olKF<oo6eS?oa]Hco000000?on;b800Go0000onk0
X_o^`:;ok/2Ro`000003oo?5X005o`000?ogc9oomlbOooO<Wol000000oojdYd00ol0003oo=NNo`00
0003oocLW`;o00001_o6iNd3o`0000GoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVm
j006ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?nY_NP01OnY_NP00ol0003oZKgXojVm
j003o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000Gooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`Co00004oooool002[ooooo00?o0000ooooooooool08_ooool2o`0000GoZKgX00?o
0000ojVmj?nY_NP00onY_NP3o`0000OoZKgX00?o0000ojVmj?l000000_l00002ojVmj003o`000?nY
_NSoZKgX00CoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj006ojVmj003o`000?nY
_NSo000000;o00000onY_NP00ol0003oZKgXojVmj003ojVmj0?o000000?o0019o`000?meTN001?me
TN000ol0003oXZ?Foj:SeP04oj:SeP03o`000?ni[<co^Jc<00;o^Jc<0_l00003okb/bP03o`000?nl
[lco_:o<00Go_:o<0_l00005okfacPCo000000?oa;G<o`000?nn/ll01_nn/ll01Ol0003oh[bbon:l
/_oR_;;o000000Go_[GA00?o0000oo6kUooa^iL00_oa^iL01Ol0003o`kS@ol>hd?o3^=3o000000Co
lkV?00?o0000onBo/_oT_k800ooT_k801?l0003oi:NBonBWT_l00008ooBkT003o`000?o^/Hkok[6>
00;ok[6>00?o0000ooBlSood_8l01Ood_8l00ol0003oh:BCon2TT`03on2TT`05o`000?oe^X_omKZ;
ooFjRol000000oof_Xl01?l0003odIZKom6JVol00004omjSU@05o`000?oa]HcolKF<oo6eS?l00000
0ooh_8P01Ol0003ok/2Ronk0X_o^`:;o000000?ollFP00Go0000ooO<Woogc9oomlbOo`000003oo[B
W@03o`000?oleiko000000?oo=bO00?o0000oocRWol000000_o6iNd3o`000004ojZnj?l0003oZKgX
o`0000CoZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00005ojVmj003o`000?nY_NSo
ZKgX00?oZKgX0ol00006ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?l00000;?ooool0
00kooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Oooooo00?o0000ooooooooool09?ooool00ol0003oZKgXojVmj003ojVmj003o`000?nY
_NSo000000;o00000onY_NP00ol0003oZKgXojVmj004ojVmj0;o00001_nY_NP00ol0003oZKgXojVm
j003ojVmj0?o00001OnY_NP00ol0003oZKgXojVmj004ojVmj0;o00001onY_NP00ol0003oZKgXo`00
0002o`000006ojVmj?l0003o5TS4o`000?l004Wo00001?meTN000ol0003oXZ?Foj:SeP05oj:SeP04
o`000?ni[<co^Jc<o`0000Go_:c:00?o0000okb_c?nl[l`01?nl[l`00ol0003o_Zk:o`000002okfa
cP?o00000onm/Lh2o`0000Wo_[??00?o0000on:l/_l000001_nn]M401Ol0003olK^Goo6kUooa^iOo
000000Go`kS@00Go0000oo>iSooc^HoolkV?o`000006onBo/P03o`000?oTYi;o000000Som;^@00?o
0000onjaS_o^/Hh00_o^/Hh00ol0003om;b?ooBlS`05ooBlS`03o`000?oPY9?oh:BC00?oh:BC00Go
0000ooFjRooe^X_omKZ;o`000003ooJnS`03o`000?oAVY_o000000GogZ>E00Go0000oo6eS?oa]Hco
lKF<o`000003ooRlR0;o00000_o^`:801Ol0003ollFPoo?5X?ocaJ3o000000?omlbO00Co0000oo[B
WOojdYgo00000_oleih01?l0003oo=bOoocLWol00003oocRW`;o00001OnZ_^P00ol0003oZKgXo`00
0003o`000003ojVmj?l0003oZKgX00KoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVm
j005ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP00ol0003oZKgXojVmj004ojVmj0?o00001OnY
_NP00ol0003oooooooooo`0Zooooo`003_ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01oooool00ol0003o
ooooooooo`0Uooooo`04o`000?nY_NSoZKgXojVmj0Co00001_nY_NP00ol0003oZKgXojVmj003o`00
0003ojVmj?l0003oZKgX00KoZKgX00?o0000ojVmj?l000000_l00002ojVmj003o`000?nY_NSoZKgX
00CoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX00CoZKgX0_l00005ojVm
j004o`000?lFB<Co0000o`0000GoMI7P00?o0000oj:Se_nRXmH01?nRXmH00ol0003o^Jc<o`000007
okb/bP03o`000?nl[lco_:o<00;o_:o<00?o0000okj^b_nn[/X00ol00005okfacP03o`000?no/<co
000000Wo_[??0_l00008okjed@03o`000?oa^iOo000000Ko`kS@00Co0000oo>iSooc^Hoo00001ooT
_k800ol0003oi:NBo`000008ooBkT003o`000?o^/Hkok[6>00;ok[6>00?o0000ooBlSood_8l01Ood
_8l00ol0003oh:BCon2TT`02on2TT`03o`000?oe^X_omKZ;00;omKZ;00Oo0000ooJnSoof_Xoom[j?
o`000?oAVY_o000000GogZ>E00Go0000oo6eS?oa]HcolKF<o`000003ooRlR004o`000?oh_HWo0000
o`0000CollFP00Co0000ooO<Woogc9oo00000oojdYd00ol0003oo=NNo`000003oocLW`05o`000?ol
hYooo>:OoocRWol000001_nZ_^P3o`0000GoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000GoZKgX
00?o0000ojVmj?nY_NP00onY_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000
ojVmj005ojVmj0;o0000:oooool000oooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooo
oooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo02Oo
oooo0ol00004ojVmj003o`000?nY_NSoZKgX00?oZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00Co
ZKgX0_l00006ojVmj003o`000?nY_NSoZKgX00?oZKgX0ol00006ojVmj003o`000?nY_NSoZKgX00?o
000000?oZKgXo`000?nY_NP01?nY_NP01Ol0003o5TS4oaI8a?lFB<Co000000GoMI7P00?o0000oj:S
e_nRXmH00onRXmH2o`0000Wo_:c:00?o0000okb_c?nl[l`01?l00002okj^bP03o`000?nm/Lko_K7>
00;o_K7>00Go0000okn`c?no/<co_k3<o`000007okjcc`03o`000?no/lko000000So_[GA0_l00008
ol>hd003o`000?oc^Hoo000000Ooi;nb0_l00008ooBkT0;o00001?o^/Hh00ol0003om;b?ooBlS`04
ooBlS`;o00001?oPY9<00ol0003omKZ;ooFjR`02ooFjR`07o`000?of_Xoom[j?ooJnSol0003odIZK
o`000005omjSU@05o`000?oa]HcolKF<oo6eS?l000000_oh_8P01Ol0003on;f9ooRmROoh_HWo0000
00?ollFP00Go0000ooO<Woogc9oomlbOo`000003oo[BW@03o`000?oleiko000000?oo=bO00Ko0000
oocRWoolhYoo0000oo[YYol00002ojZnj0?o000000CoZKgXo`000?nY_NSo00001OnY_NP00ol0003o
ZKgXojVmj003o`000003ojVmj?l0003oZKgX00GoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003
o`000?nY_NSoZKgX00CoZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00?oZKgX0ol0000Zooooo`00
4?ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool0:?ooool00ol0003oZKgXojVmj004ojVm
j003o`000?nY_NSo000000;o00000_nY_NP00ol0003oZKgXojVmj004ojVmj003o`000?nY_NSoZKgX
00?o00000_nY_NP00ol0003oZKgXojVmj004ojVmj003o`000?nY_NSo000000;o00000onY_NP00ol0
003oZKgXojVmj003ojVmj0?o00001OnY_NP00ol0003oZKgXojVmj003ojVmj004o`000?lFB<Co5TS4
oaI8a0Co000000CoMI7Po`000?nRXmKoXZ?F0ol000000onRX]Co0000okb/bP08okb/bPCo00001Onn
[/X01Ol0003o_K7>okfac_nm/Lko000000Go_k3<00?o0000okjcconn/ll00_nn/ll2o`0000?o_k?>
00?o0000okjedOnn]M401?nn]M400ol0003o_kG@o`000008ol>hd0;o00002OoT_k800ol0003om;^@
ooBkT005ooBkT004o`000?oJ`L7of/71o`0000;ok[6>00?o0000ooBlSood_8l01Ood_8l00ol0003o
jl>[o`000003on2TT`05o`000?oe^X_omKZ;ooFjRol000001?of_Xl00ol0003odIZKo`000004omjS
U@05o`000?oa]HcolKF<oo6eS?l000000ooh_8P01Ol0003on;f9ooRmROoh_HWo000000?ollFP00Go
0000ooO<Woogc9oomlbOo`000002oo[BW@04o`000?oleikoo=NNo`0000;oo=bO00Go0000oocRWool
hYooo>:Oo`000002oo[YY`;o00001OnY_NP00ol0003oZKgXo`000004ojVmj0?o00001OnY_NP00ol0
003oZKgXojVmj003ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX
00GoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000o`00000Zooooo`004Oooool00omgMgOo
IVIVooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool0:Oooool00ol0003oZKgXojVmj003ojVmj0;o00001_nY_NP0
0ol0003oZKgXojVmj003ojVmj0?o00001_nY_NP01?l0003oZKgXojVmj?nY_NP4o`0000OoZKgX00?o
0000ojVmj?l000000_l00002ojVmj003o`000?nY_NSoZKgX00CoZKgX00?o0000ojVmj?nY_NP01?l0
0002oaI8a004o`000?m]R]koKH[Noff:gPCo00001OnRX]@00ol0003o_:c:okb/bP05okb/bP?o0000
2?nn[/X00ol0003o_K7>o`000006okn`c005o`000?nn/loo_[??okjccol000001Ono/lh00ol0003o
_[GAokjed@02okjed@;o00000ono]M000ol0003o`kS@ol>hd004ol>hd003o`000?no^=;o000000So
i;nb0_l00006ooBkT005o`000?oJ`L7of/71om[1`Ol000000_o^/Hh00ol0003om;b?ooBlS`04ooBl
S`04o`000?o[`j_ojl>[o`0000?oh:BC00Go0000ooFjRooe^X_omKZ;o`000005ooJnS`;o00001?oN
XiD01Ol0003olKF<oo6eS?oa]Hco000000?on;b800Co0000ooRmROoh_HWon;f90_l00002oo?5X005
o`000?ogc9oomlbOooO<Wol000000_ojdYd00ol0003oo=NNo`000003oocLW`04o`000?olhYooo>:O
o`0000?on^VW00?o0000ojVmj?nY_NP01OnY_NP00ol0003oZKgXo`000003o`000003ojVmj?l0003o
ZKgX00GoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00005
ojVmj003o`000?nY_NSoZKgX00?oZKgX0ol00005ojVmj0?o0000:?ooool001;ooooo00Go0000oooo
oooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413ooooooooo
o`04ooooo`03o`000?oooooooooo02[ooooo00?o0000ojVmj?l000000_l00002ojVmj003o`000?nY
_NSoZKgX00CoZKgX00?o0000ojVmj?l000000_l00003ojVmj003o`000?nY_NSoZKgX00?oZKgX1?l0
0004ojVmj003o`000?nY_NSoZKgX00CoZKgX0_l00006ojVmj003o`000?nY_NSoZKgX00?oZKgX0ol0
0003ojVmj005o`000?lFB<Co5TS4oaI8a?l000001?m]R]h00ol0003oXZ;Doj:Re004oj:Re003o`00
0?nl[<[o_:c:00;o_:c:1?l000000onlZlOo0000okj^bP07okj^bP;o00002?no/<`00ol0003o_[??
o`000007oknccP04o`000?nn]M7o_[GAo`0000Go_kG@00?o0000ol>hd?o3^=000_o3^=02o`0000?o
_kSB00?o0000onBo/_oT_k800ooT_k82o`000003ol6jdol0003om;^@00Com;^@00?o0000om[1`OoJ
`L400_oJ`L401?l0003ok[6>onjaS_l00006ooBlS`04o`000?o[`j_ojl>[o`0000?oh:BC00Go0000
ooFjRooe^X_omKZ;o`000005ooJnS`03o`000?oNXiGogZ>E00?ogZ>E00Go0000oo6eS?oa]HcolKF<
o`000003ooRlR006o`000?oh_HWon;f9ooRmROl0003on;j90_l00003ooO<W`07o`000?ojdYgon]:M
oo[BWOl0003oo=NNo`000003oocLW`04o`000?olhYooo>:Oo`0000;on^VW00?o0000ongi^_l00000
1_nY_NP3o`0000GoZKgX00Co0000ojVmj?nY_NSoZKgX1Ol00006ojVmj003o`000?nY_NSoZKgX00?o
000000?oZKgXo`000?nY_NP01OnY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00Ko
ZKgX0_l0000Xooooo`003_ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool2o`0002cooooo00?o0000
ojVmj?nY_NP01?nY_NP00ol0003oZKgXojVmj003ojVmj0?o00001_nY_NP00ol0003oZKgXo`000002
o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003o
ZKgX00KoZKgX00?o0000ojVmj?l000000_l00003ojVmj004o`000?nY_NSoZKgXojVmj0;o000000?o
5TS4o`000?m]R]h01?m]R]h00ol0003oXZ;Doj:Re004oj:Re0Co000000?o_:c:o`000?l000000onl
ZlL00ol0003o_Zk:okj^bP04okj^bP03o`000?o1[/So000000So_k3<0_l00008oknccP03o`000?nn
]M7o000000Oo_kG@00Co0000ol>hd?o3^=3o00001_no^=801Ol0003oi;nbonBo/_oT_k;o000000Co
`K[C00?o0000ooBkT?od^i000_od^i000ol0003of/71om[1`@03om[1`@03o`000?o^/Hko000000Go
m;b?00Go0000on_3Zoo[`j_ojl>[o`000002on2TT`03o`000?oe^X_omKZ;00;omKZ;00?o0000ooJn
Soof_Xl00oof_Xl00ol0003ogZ>EomjSU@03omjSU@05o`000?oa]HcolKF<oo6eS?l000000ooh_8P0
1?l0003on;f9ooRmROl00003ooRnR@05o`000?ogc9oomlbOooO<Wol000000_ojdYd01?l0003oo=NN
oocGW_l00002oocLW`04o`000?olhYooo>:Oo`0000?on^VW00Co0000ongi^_o]nK[o00000_nY_NP3
o`000004ojVmj?l0003oZKgXo`0000CoZKgX1?l00004ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol0
0005ojVmj003o`000?nY_NSoZKgX00?oZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00CoZKgX0_l0
000Xooooo`003_ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`0[ooooo`03
o`000?nY_NSoZKgX00GoZKgX00?o0000ojVmj?l000000_l00003ojVmj003o`000?nY_NSoZKgX00?o
ZKgX0_l00006ojVmj003o`000?nY_NSoZKgX00?oZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00Co
ZKgX0_l00007ojVmj008o`000?nY_NSo0000o`000?lNHMKo0000oaI8a?l00004off:gP03o`000?nR
X]CoXZ;D00;oXZ;D1?l00002okb/bP03o`000?nlZlOo_:_700?o_:_700?o0000okj^b_nn[/X00_nn
[/X2o`0000?o`Jk800?o0000okn`c?no/<`01?no/<`00ol0003o`K7:o`000008oknccP;o00002?no
]M000ol0003o`kS@o`000007oknhdP04o`000?oT_k;o0000o`0000Ko`K[C00Co0000ooBkT?od^i3o
00001_oJ`L400ol0003ok[6>o`000005ooBlS`05o`000?o[`j_ojl>[on_3Zol000000_oPY9<00ol0
003omKZ;ooFjR`02ooFjR`03o`000?of_Xoom[j?00?om[j?00?o0000omjSUOoNXiD00ooNXiD01Ol0
003olKF<oo6eS?oa]Hco000000?on;b800Co0000ooRmROoh_HWo00000ooh_XT2o`0000;omlbO00Ko
0000oo[BWOojdYgo0000oocGW_l00003oocLW`04o`000?olhYooo>:Oo`0000;on^VW00Co0000ongi
^_o]nK[okOVj0ol00005ojVmj003o`000?nY_NSo000000?o000000?oZKgXo`000?nY_NP01_nY_NP0
0ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00GoZKgX00?o0000ojVmj?nY_NP00ol00002
ojVmj003o`000?nY_NSoZKgX00CoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000o`00000W
ooooo`00:?ooool00ol0003oooooooooo`0]ooooo`03o`000?nY_NSoZKgX00CoZKgX0_l00007ojVm
j003o`000?nY_NSo000000;o00000_nY_NP00ol0003oZKgXojVmj004ojVmj003o`000?nY_NSo0000
00;o00000_nY_NP00ol0003oZKgXojVmj004ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP00ol0
003oZKgXojVmj004ojVmj0;o00000_nY_NP00ol0003o7V7Fo`000002o`0000CoKH[N1?l00003oj:R
e003o`000?nl[<[o000000Oo_:_700Co0000okj^b_nn[/[o00001_o1[/P00ol0003o_k3<okn`c002
okn`c005o`000?o1/L[o`K7:ol6ab_l000001_no/lh00ol0003o`K?<o`000008okned0;o00002?no
^=82o`0000So`K[C00?o0000ooBkT?l000001ooJ`L42o`0000Gom;b?00?o0000on_3Zoo[`j/00oo[
`j/00ol0003oh:BCo`000003ooFjR`03o`000?of_Xoom[j?00Com[j?00?o0000omjSUOoNXiD00ooN
XiD01Ol0003olKF<oo6eS?oa]Hco000000?on;b800Co0000ooRmROoh_HWo00000ooh_XT01?l0003o
nKn9o`000?l00003oo[BW@03o`000?oleiko000000?oo=bO00?o0000oocRWol000000_ojjJL01ol0
003okOVjongi^_o]nK[o0000olodj?l000001_nY_NP3o`0000GoZKgX00?o0000ojVmj?nY_NP01?nY
_NP3o`0000GoZKgX00?o0000ojVmj?nY_NP00onY_NP3o`0000KoZKgX00Co0000ojVmj?nY_NSoZKgX
1Ol00005ojVmj0;o00009_ooool002Sooooo00?o0000ooooooooool0;_ooool00ol0003oZKgXojVm
j003o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000KoZKgX00?o0000ojVmj?nY_NP00onY
_NP3o`0000GoZKgX00?o0000ojVmj?nY_NP00onY_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP00ol0
00000onY_NSo0000ojVmj002ojVmj004o`000?lNHMKo7V7Fo`0000;oKH[N1?l00005oj:Re0;o0000
2?nlZlL00ol0003o_Zk:o`000007ol6^b005o`000?no/<co_k3<okn`c?l000001Oo1/LX00ol0003o
_k?>oknccP02oknccP05o`000?o1/lco`K?<ol6cc?l000001_no]M000ol0003o`KK?o`000007oknh
dP03o`000?o1^=7o000000So`K[C0_l00009om[1`@03o`000?od_8oom;b?00?om;b?00?o0000on_3
Zoo[`j/00oo[`j/00ol0003oh:BCo`000003ooFjR`03o`000?of_Xoom[j?00?om[j?00?o0000oo73
XOl000001?oNXiD01Ol0003olKF<oo6eS?oa]Hco000000;on;b800Go0000ooRmROoh_HWon;f9o`00
0003ooRnR@03o`000?oi_hWonKn900Co00000_oleih01?l0003oo=bOoocLWol00002oocRW`05o`00
0?ojjJOon^VWo`000?o]nKX00_l00003olodj003o`000?nY_NSoZKgX00?o000000CoZKgXo`000?nY
_NSo00001OnY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00GoZKgX00?o0000ojVm
j?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX00CoZKgX1?l00003ojVmj003o`000?nY_NSoZKgX
00CoZKgX0_l0000Vooooo`00:?ooool00ol0003oooooooooo`0_ooooo`;o00001_nY_NP00ol0003o
ZKgXojVmj003o`000003ojVmj?l0003oZKgX00KoZKgX00?o0000ojVmj?l000000_l00003ojVmj003
o`000?nY_NSoZKgX00?oZKgX00?o0000ojVmj?l000000_l00003ojVmj003o`000?nY_NSoZKgX00?o
ZKgX0ol00005ojVmj004o`000?nY_NSoZKgXo`0000;o7V7F1Ol000001?m]R]ko0000oj:Re?nRX]@3
o`000003oj6Od_l0003o_:_700So_:_700?o0000ol6^b?o1[/P01oo1[/P00ol0003o_k3<o`000006
ol6abP05o`000?no/lko_k?>okncc_l000001Oo1/l`00ol0003o_kG@okned002okned005o`000?o1
]/oo`KK?ol6fcol000001Ono^=801Ol0003o`KSAol6hdOo1^=7o000000Ko`K[C00?o0000ol6ke?l0
00002?oJ`L42o`0000Gom;b?00?o0000on_3Zoo[`j/00oo[`j/00ol0003oh:BCo`000003ooFjR`03
o`000?of_Xoom[j?00?om[j?00?o0000oo73XOl000000ooNXiD01Ol0003olKF<oo6eS?oa]Hco0000
00?on;b800Go0000ooRmROoh_HWon;f9o`000002ooRnR@05o`000?oi_hWonKn9ooVoROl000000_oi
_hP3o`0000?oo=bO00?o0000oocRWol000000_ojjJL00ol0003okOVjo`000005olodj0?o00001OnY
_NP00ol0003oZKgXo`000004ojVmj0?o00001OnY_NP00ol0003oZKgXojVmj003ojVmj0?o00001_nY
_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00GoZKgX00?o0000ojVmj?nY_NP00ol0
00000onY_NSo0000o`00000Uooooo`00:?ooool00ol0003oooooooooo`0aooooo`03o`000?nY_NSo
ZKgX00?oZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00CoZKgX0_l00007ojVmj004o`000?nY_NSo
ZKgXojVmj0?o00001onY_NP00ol0003oZKgXo`000002o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY
_NP00ol0003oZKgXo`000002o`000003oaiQe_l0003oIHGM00;oIHGM1?l00005oj6OdP03o`000?nl
ZlOo_:_700Go_:_70_l00009ol6^b0;o00002?o1/LX00ol0003o_k?>o`000006ol6cc005o`000?no
]M3o_kG@okned?l000001Oo1]/l01Ol0003o_kSBoknhd_no^=;o000000Go`KSA00?o0000ol6jdoo1
^]<00_o1^]<01Ol0003o`K_Dol6ke?o1^mCo000000Kof/7100?o0000ol:meOl000001?od_8l00ol0
003ojl>[on_3Z`04on_3Z`03o`000?oPY9?o000000?omKZ;00?o0000ooJnSoof_Xl00oof_Xl00ol0
003olL>Qo`000003omjSU@05o`000?oa]HcolKF<oo6eS?l000000ooh_8P01Ol0003on;f9ooRmROoh
_HWo000000;on;j900Go0000ooVoROoi_hWonKn9o`000002ooVoR003o`000?onaWko000000;o0000
00Coo=bOo`000?olhYoo00000_ojjJL4o`000006olodj?l0003o0000o`000?nZ_^So00001onY_NP0
0ol0003oZKgXo`000003o`000003ojVmj?l0003oZKgX00GoZKgX00?o0000ojVmj?nY_NP00ol00002
ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00?oZKgX0ol00005
ojVmj0;o00009?ooool002Sooooo00?o0000ooooooooool0<_ooool00ol0003oZKgXo`000002o`00
00;oZKgX00?o0000ojVmj?nY_NP01?nY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVm
j?nY_NP01?nY_NP4o`0000?oZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000KoZKgX00?o0000ojVm
j?nY_NP00onY_NP3o`000005ojVmj?l0003o0000oaiQe_l000001?mUQMd00ol0003oXIoBoj6OdP04
oj6OdP03o`000?nlZlOo_:_700Co_:_700Co0000okjYaOnnZLGo00001oo1[/P00ol0003o`Zg5o`00
0008ol6abP;o00002?o1/l`00ol0003o_kG@o`000007ol6fc`03o`000?no^=;o000000Ko`KSA00Go
0000ol6jdoo1^]?o`K[Co`000005ol6ke004o`000?oJ`L7of/71om[1`@;o00000oo2_MD01Ol0003o
m;b?ooBlSood_8oo000000Kojl>[0_l00004ooFjR`03o`000?of_Xoom[j?00;om[j?00Go0000oo73
XOoa`j7olL>Qo`000002omjSU@05o`000?oa]HcolKF<oo6eS?l000000ooh_8P01Ol0003on;f9ooRm
ROoh_HWo000000;on;j900Go0000ooVoROoi_hWonKn9o`000002ooVoR003o`000?onaWko000000;o
n<aN1_l000001OoghX7o0000ooGWROoeihWo000000GoZ[kX00?o0000ojVmj?nY_NP01?nY_NP3o`00
00GoZKgX00Co0000ojVmj?nY_NSoZKgX1Ol00006ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgX
o`000?nY_NP01OnY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00GoZKgX0_l0000T
ooooo`00:?ooool00ol0003oooooooooo`0cooooo`03o`000?nY_NSoZKgX00CoZKgX00?o0000ojVm
j?nY_NP00onY_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj005ojVm
j003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?nY_NP01_nY_NP00ol0003oZKgXo`000002o`00
00?oZKgX0_l000000ol6DLko0000o`000005ofF5g@03o`000?nQWm;oXIoB00CoXIoB00?o0000okb[
aonlZlL00_nlZlL01Ol0003o_ZW5okjYaOnnZLGo000000Ko`Jk800Go0000ol:]aOo2[LGo`Zg5o`00
0006ol6abP03o`000?o2/<So000000So`K?<0_l00008ol6fc`;o00002?o1^=400ol0003o`K[Co`00
0007ol6ke003o`000?oJ`L7o000000Ko`[gE00?o0000ooBlSol000002?o[`j/01Ol0003omKZ;ooFj
Rooe^X_o000000Gom[j?00Go0000oo73XOoa`j7olL>Qo`000002omjSU@05o`000?oa]HcolKF<oo6e
S?l000000ooh_8P01?l0003on;f9ooRmROl00003ooRnR@04o`000?oi_hWonKn9o`0000?onKn800?o
0000ook6O_l000000_ohc5h00ol0003ohlU;o`000002oo_MOP;o00000ooeihT00ol0003oZ[kXojZn
j004ojZnj003o`000?nY_NSoZKgX00?o000000CoZKgXo`000?nY_NSo00001?nY_NP4o`0000CoZKgX
00?o0000ojVmj?nY_NP01?nY_NP3o`0000GoZKgX00?o0000ojVmj?nY_NP00onY_NP3o`0000GoZKgX
00Co0000ojVmj?nY_NSoZKgX1Ol0000Sooooo`009oooool3o`0003Gooooo00?o0000ojVmj?nY_NP0
1?nY_NP00ol0003oZKgXo`000002o`0000?oZKgX00?o0000ojVmj?nY_NP00onY_NP3o`0000GoZKgX
00?o0000ojVmj?nY_NP00onY_NP3o`0000GoZKgX00?o0000ojVmj?nY_NP00onY_NP3o`0000OoZKgX
0_l000000ol6DLko0000o`000004ofF5g@03o`000?nQWm;oXIoB00GoXIoB00Co0000okb[aonlZlOo
00001OnnZLD00ol0003o`Jk8ol6^b002ol6^b003o`000?o2[LGo`Zg500;o`Zg500?o0000ol6ab_o1
/LX00_o1/LX2o`0000?o`[3800?o0000ol6cc?o1/l`01?o1/l`00ol0003oa;C;o`000007ol6fc`03
o`000?o4]lko000000So`KSA0_l00008ol6ke0;o00001oo2_MD00ol0003om;b?o`000007on_3Z`;o
00000ooe^X/00ol0003om[j?ooJnS`03ooJnS`05o`000?oa`j7olL>Qoo73XOl000000_oNXiD01Ol0
003olKF<oo6eS?oa]Hco000000?on;b800Co0000ooRmROoh_HWo00000ooh_XT01?l0003onKn9ooVo
ROl00002ooVoR004o`000?onaWkoo/Ino`0000;on<aN00?o0000on?9Bol000000_okgGh2o`0000;o
mNN900?o0000on_`U?l000001OnZ_^P3o`0000GoZKgX00?o0000ojVmj?l000000ol000000onY_NSo
0000ojVmj006ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?nY_NP01OnY_NP00ol0003o
ZKgXojVmj003o`000003ojVmj?l0003oZKgX00GoZKgX1?l00004ojVmj0;o00008_ooool002Oooooo
00?o0000ooooooooool0=_ooool00ol0003oZKgXojVmj003ojVmj0?o00001_nY_NP00ol0003oZKgX
o`000002o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY_NP00ol0003oZKgXo`000002o`0000?oZKgX
00?o0000ojVmj?nY_NP00onY_NP00ol0003oZKgXo`000003o`0000;oZKgX00?o0000ojVmj?nY_NP0
1?nY_NP2o`0000;o1U7>00?o0000ofF5gOmUQMd00omUQMd00ol0003oXIoBoj6OdP04oj6OdP03o`00
0?nlZlOo000000Oo_ZW500Co0000ol6^b?o1[/So00001_o2[LD01?l0003o`K7:ol6ab_l00005ol:`
b003o`000?o1/lco`K?<00;o`K?<0_l00003olBdb`03o`000?o1]/oo`KK?00;o`KK?0_l00003olBg
cP03o`000?o1^=7o`KSA00Co`KSA00?o0000ol>idOl000001oo1^m@00ol0003o`[_Co`000007ol:m
e@;o00001oo[`j/00ol0003ob<;Do`000003ooFjR`03o`000?of_Xoom[j?00?om[j?00Go0000oo73
XOoa`j7olL>Qo`000002omjSU@05o`000?oa]HcolKF<oo6eS?l000000_oh_8P01Ol0003on;f9ooRm
ROoh_HWo000000?on;j900Co0000ooVoROoi_hWo00000_oi_hP01?l0003oo/Inook6O_l00002ooS<
GP;o00000_okgGh00ol0003omn:1o`000002ooGWR@03o`000?o[l9Co000000;oZ[kX0ol00002ojVm
j003o`000?nY_NSoZKgX00?oZKgX1?l00004ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00005ojVm
j003o`000?nY_NSoZKgX00?oZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`00
0?nY_NP01_nY_NP00ol0003oooooooooo`0Pooooo`009oooool00ol0003oooooooooo`0gooooo`03
o`000?nY_NSo000000;o00000onY_NP00ol0003oZKgXojVmj003ojVmj0;o00001_nY_NP00ol0003o
ZKgXojVmj003ojVmj0?o00001_nY_NP01?l0003oZKgXojVmj?nY_NP4o`0000KoZKgX00?o0000ojVm
j?nY_NP00ol000000onY_NSo0000o`000002o`IAcP?o00000omUQMd00ol0003oXIoBoj6OdP03oj6O
dP;o00002?nnZLD00ol0003o`Jk8o`000007ol:]a@03o`000?o1/L[o000000Oo`[3800Co0000ol6c
c?o1/lco00001_o4]</01?l0003o`KK?ol6fcol00005olBgcP03o`000?o1^=7o`KSA00;o`KSA0_l0
0003ol>id@03o`000?o1^mCo`K_D00;o`K_D0_l00003ol:kd`03o`000?o2_MGo`[gE00?o`[gE00Co
0000ol:neoo2_]Oo00001Oo[`j/01Ol0003ob<;DolS2e?o8`]Co000000;omKZ;00?o0000ooJnSoof
_Xl00_of_Xl00ol0003olL>Qoo73X@03oo73X@03o`000?oNXiGo000000?olKF<00Co0000ooRlR?oh
_8So00000ooh_HT01Ol0003on;j9ooRnROoh_XWo000000;onKn900Ko0000ooVoR?oi_hSo0000ook6
O_l00002ooS<GP03o`000?oSbD_o000000;onmen0_l00002ooGWR@04o`000?o[l9Cojo2Don_`U0;o
00001_nY_NP00ol0003oZKgXo`000002o`000004ojVmj?l0003oZKgXo`0000GoZKgX00?o0000ojVm
j?nY_NP00ol000000onY_NSo0000ojVmj005ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`00
0?nY_NP01OnY_NP3o`0000GoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`00027ooooo000Wooooo`03
o`000?oooooooooo03Sooooo00?o0000ojVmj?nY_NP01OnY_NP00ol0003oZKgXo`000002o`0000;o
ZKgX00?o0000ojVmj?nY_NP01?nY_NP00ol0003oZKgXo`000002o`0000?oZKgX00?o0000ojVmj?nY
_NP00onY_NP4o`0000CoZKgX00?o0000ojVmj?nY_NP00onY_NP3o`0000GoZKgX00Co0000o`IAc_l6
DLko00000_mIOM/4o`0000;oXIoB0ol000000onPW=3o0000okjYa@08okjYa@03o`000?o2[LGo`Zg5
00Oo`Zg500?o0000ol:`b?o2/<P01_o2/<P00ol0003o`K?<o`000007olBdb`03o`000?o1]/oo0000
00Ooa;O>00Co0000ol6hdOo1^=7o00001_o3^M401?l0003o`K_Dol6ke?l00006ol:kd`03o`000?o2
_MGo`[gE00;o00001?o2_]L01Ol0003ojl>[on_3Zoo[`j_o000000Cob<;D00Co0000ooFjRooe^X_o
00001?of_Xl00ol0003olL>Qoo73X@03oo73X@;o00000ooa]H`01Ol0003on;b8ooRlR?oh_8So0000
00?on;f900Co0000ooRnROoh_XWo00000ooi_hT01_l0003onKn8ooVoR?l0003oo/Ino`0000;on<aN
00?o0000on?9Bol000000_okgGh2o`0000;omNN900Ko0000on_`U?o[l9Co0000om7ocOl00006ojVm
j0;o00001OnY_NP00ol0003oZKgXo`000004ojVmj0?o00001OnY_NP01?l0003oZKgXojVmj?nY_NP5
o`0000GoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj006ojVmj003o`000?nY_NSo
ZKgX00?o000000?oZKgXo`000?l000008?ooool002Oooooo00?o0000ooooooooool0>Oooool00ol0
003oZKgXojVmj004ojVmj0;o00001_nY_NP00ol0003oZKgXojVmj003ojVmj0;o00001onY_NP00ol0
003oZKgXo`000004o`0000OoZKgX00?o0000ojVmj?l000000_l00002ojVmj003o`000?nY_NSoZKgX
00CoZKgX0_l000000ol6DLko0000oeUmf`03oeUmf`?o00001OnPW=000ol0003o_ZW5okjYa@05okjY
a@;o00002Oo2[LD00ol0003o`[38ol:`b007ol:`b003o`000?o4]<_oa;C;00Ooa;C;00?o0000olBg
c_o4]lh01_o4]lh00ol0003o`KSAo`000007ol>id@03o`000?o1^mCo000000Oo`[_C00?o0000ol:m
eOl000001oo2_]L00ol0003ojl>[o`000006olS2e0;o00001Oof_Xl00ol0003olL>Qoo73X@03oo73
X@;o00000ooa]H`01Ol0003on;b8ooRlR?oh_8So000000?on;f900Co0000ooRnROoh_XWo00000ooi
_hT01_l0003onKn8ooVoR?l0003oo/Ino`0000;on<aN00Wo0000on?9Bol0003onmeno`000?oghX7o
0000ooGWROl000000_o[l9@01Ol0003odOo=om7ocOoAolgo000000;oZKgX0ol000000onY_NSo0000
ojVmj005ojVmj003o`000?nY_NSo000000?o000000?oZKgXo`000?nY_NP01OnY_NP4o`0000?oZKgX
00?o0000ojVmj?nY_NP01?nY_NP3o`0000GoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000GoZKgX
0_l0000Oooooo`009oooool00ol0003oooooooooo`0jooooo`03o`000?nY_NSoZKgX00?o00000_nY
_NP00ol0003oZKgXojVmj004ojVmj003o`000?nY_NSo000000;o00000_nY_NP00ol0003oZKgXojVm
j004ojVmj0?o00001?nY_NP00ol0003oZKgXojVmj004ojVmj0;o00001_nY_NP00ol0003oZKgXojVm
j003ojVmj004o`000?l0?l;o0000o`0000GoFGgK00?o0000oj2Ld?nPW=001?nPW=000ol0003o_ZW5
okjYa@04okjYa@04o`000?o2Zl;o`Z_2o`0000Oo`Zg500?o0000olJ_`ol000001oo2/<P2o`0000So
a;C;0_l00008olBgcP;o00002?o3^M42o`0000So`[_C0_l00008ol:ne`;o00001oo8`]@2o`0000Go
m[j?00?o0000oo73XOoa`j401?oa`j401Ol0003olKF<oo6eS?oa]Hco000000?on;b800Co0000ooRm
ROoh_HWo00000ooh_XT01Ol0003onKn9ooVoROoi_hWo000000;onKn800?o0000ook6O_l000000_oh
c5h2o`0000;onmen0_l000001OoeihWo0000on_`U?o[l9Co000000CodOo=0ol00005ojVmj003o`00
0?nY_NSoZKgX00?oZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?nY_NP0
1OnY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00KoZKgX00?o0000ojVmj?nY_NP0
0ol000000onY_NSo0000ojVmj005ojVmj0;o00007oooool002Kooooo00?o0000ooooooooool0??oo
ool2o`0000KoZKgX00Co0000ojVmj?nY_NSoZKgX1?l00006ojVmj003o`000?nY_NSoZKgX00?o0000
00?oZKgXo`000?nY_NP01OnY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP0
1?nY_NP00ol0003oZKgXo`000002o`000003ojVmj?l0003o03o200;o00001OmIOM/00ol0003oX9c@
oj2Ld004oj2Ld003o`000?nnZLGo_ZW500;o_ZW500Go0000ol:[`_o2Zl;o`Z_2o`000006ol:]a@04
o`000?o6[l?oaZo3o`0000Ko`[3800Co0000olF`a_o5/<Ko00001_o4]</01?l0003oaKC9olFdbOl0
0006olBgcP03o`000?o5]lgo000000Oo`kWA00?o0000olFjd?l000001oo2^m<00ol0003oa;gCo`00
0007ol:ne`03o`000?o3_mKo000000Oob<;D0_l00004ooJnS`03o`000?oa`j7olL>Q00GolL>Q00Go
0000oo6eS?oa]HcolKF<o`000003ooRlR004o`000?oh_HWon;f9o`0000?on;j900Co0000ooVoROoi
_hWo00000ooi_hP00ol0003oo/Ino`000002ooS<GP;o00000_okgGh2o`000004ooGWROl0003ojo2D
o`0000;odOo=0ol000000onZ_^So0000ojVmj005ojVmj003o`000?nY_NSoZKgX00?o000000CoZKgX
o`000?nY_NSo00001?nY_NP3o`0000GoZKgX00?o0000ojVmj?nY_NP00onY_NP3o`0000GoZKgX00?o
0000ojVmj?nY_NP01?nY_NP3o`0000GoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000o`00
000Nooooo`009_ooool2o`0003oooooo00?o0000ojVmj?nY_NP00onY_NP4o`0000CoZKgX00?o0000
ojVmj?nY_NP00onY_NP4o`0000CoZKgX00?o0000ojVmj?nY_NP00onY_NP3o`0000KoZKgX00Co0000
ojVmj?nY_NSoZKgX1?l00004ojVmj0;o000000?o03o2o`000?l000001?mIOM/00ol0003oX9c@oj2L
d005oj2Ld004o`000?nnZLGo_ZW5o`0000Go`Z_200?o0000ol:]aOo2[LD00_o2[LD00ol0003oaZo3
olJ_``02olJ_``03o`000?o2/<So`[3800;o`[3800?o0000olF`a_o5/<H00_o5/<H00ol0003oa;C;
olBdb`02olBdb`03o`000?o5]<WoaKC900;oaKC900?o0000olBgc_o4]lh00_o4]lh01Ol0003oaKO=
olFgcOo5]lgo000000Go`kWA00Go0000olFjd?o5^]3oaK[@o`000005ol:kd`05o`000?o4_M?oa;gC
olBmdol000001?o2_]L2o`0000?o`koF00?o0000olS2e?o8`]@00oo8`]@01?l0003o`l7Iol?1fOl0
0003ooJnS`03o`000?oa`j7olL>Q00GolL>Q00Go0000oo6eS?oa]HcolKF<o`000003ooRlR004o`00
0?oh_HWon;f9o`0000?on;j900Co0000ooVoROoi_hWo00000_oi_hP02ol0003oo/Inook6O_l0003o
n<aNo`000?oSbD_o0000oo_MO_l0003omn:100Oo00001OnZ_^P01?l0003oZKgXojVmj?nY_NP5o`00
00GoZKgX00?o0000ojVmj?l000000ol000000onY_NSo0000ojVmj006ojVmj003o`000?nY_NSo0000
00;o00000_nY_NP00ol0003oZKgXojVmj004ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`00
0?nY_NP01OnY_NP3o`0000GoZKgX00?o0000ooooooooool07?ooool002Kooooo00?o0000oooooooo
ool0?oooool00ol0003oZKgXo`000002o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY_NP00ol0003o
ZKgXo`000003o`000003ojVmj?l0003oZKgX00GoZKgX00?o0000ojVmj?l000000_l00003ojVmj003
o`000?nY_NSoZKgX00?oZKgX1?l00004ojVmj004o`000?nY_NSoZKgXojVmj0;o00000_l0?l800ol0
003oFGgKoeUmf`03oeUmf`03o`000?nPW=3oX9c@00CoX9c@00?o0000okjYaOl000001oo2Zl801?l0
003o`Zg5ol:]aOl00006olJ_``04o`000?o2/<So`[38o`0000GoaK3600Go0000olBdboo4]<_oa;C;
o`000005olFdb@05o`000?o4]lkoa;O>olBgc_l000001Oo5]ld01Ol0003o`kWAol>idOo3^M7o0000
00GoaK[@00Go0000ol:kdoo2^m?o`[_Co`000005olBmd`04o`000?o2_]Oo`[kGo`0000Ko`koF00?o
0000olS2e?o8`]@00_l00004ol?1f@04o`000?of_Xoom[j?o`0000KolL>Q00?o0000omk9`ol00000
0_oa]H`01?l0003on;b8ooRlR?l00003ooRmR@05o`000?oh_XWon;j9ooRnROl000000_oi_hT01?l0
003onKn8ooVoR?l00002ook6OP04o`000?ohc5ko0000o`0000;onmen0_l000001_oeihWo0000omcB
Eol0003ohMe[o`0000KoZ[kX1?l00004ojVmj003o`000?nY_NSoZKgX00?oZKgX1?l00004ojVmj003
o`000?nY_NSoZKgX00CoZKgX0_l00006ojVmj004o`000?nY_NSoZKgXojVmj0Go00001OnY_NP00ol0
003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00GoZKgX0_l0000Mooooo`009_ooool00ol0003o
ooooooooo`10ooooo`03o`000?nY_NSoZKgX00CoZKgX00?o0000ojVmj?nY_NP00onY_NP3o`0000Go
ZKgX00?o0000ojVmj?nY_NP00onY_NP3o`0000KoZKgX00?o0000ojVmj?l000000_l00002ojVmj003
o`000?nY_NSoZKgX00CoZKgX00?o0000ojVmj?l000000ol00002o`0o`P?o00000_mIOM/00ol0003o
X9c@oj2Ld003oj2Ld0?o00002?o2Zl800ol0003o`Zg5o`000007olJ_``03o`000?o2/<So000000Oo
aK3600?o0000olBdbol000001oo5]<T00ol0003oa;O>o`000007olFgc@03o`000?o3^M7o000000Oo
aK[@00?o0000ol:kdol000001_o4_M<00ol0003o`[kGo`000007ol>oeP03o`000?o8`]Co000000Oo
`l7I0_l00006oo73X@04o`000?oNbL?og/W3o`0000;olKF<00Co0000ooRlR?oh_8So00000ooh_HT0
1?l0003on;j9ooRnROl00003ooVoR@04o`000?oi_hSonKn8o`0000;oo/In00Co0000ooS<G_l0003o
00000_okgGh3o`000006omcBEol0003ohMe[o`000?oEi7So00000_nZ_^P3o`000003ojVmj?l0003o
ZKgX00KoZKgX00?o0000ojVmj?l000000_l000001?nY_NSo0000ojVmj?l00005ojVmj003o`000?nY
_NSoZKgX00?o000000?oZKgXo`000?nY_NP01OnY_NP4o`0000?oZKgX00?o0000ojVmj?nY_NP01?nY
_NP3o`0000GoZKgX00?o0000ojVmj?nY_NP00onY_NP2o`0001gooooo000Vooooo`03o`000?oooooo
oooo047ooooo00?o0000ojVmj?nY_NP01?nY_NP00ol0003oZKgXo`000002o`0000?oZKgX00?o0000
ojVmj?nY_NP00onY_NP00ol0003oZKgXo`000002o`0000?oZKgX00?o0000ojVmj?nY_NP00onY_NP2
o`0000KoZKgX00?o0000ojVmj?nY_NP00onY_NP2o`0000;oZKgX00?o0000o`00Kol000000_l00002
odQ`e`?o00000_nPW=03o`0000;oX9c@00?o0000ol:[`_o2Zl801_o2Zl82o`0000WoaZo300?o0000
olF`a_o5/<H01oo5/<H00ol0003oaKC9olFdb@07olFdb@03o`000?o5]lgoaKO=00KoaKO=0_l00008
olFjd0;o00001oo4_M<2o`0000So`koF0_l00008ol?1f@;o00001Ooa`j400ol0003og/W3omk9``02
omk9``;o00000ooh_8P01Ol0003on;f9ooRmROoh_HWo000000;on;j900Go0000ooVoROoi_hWonKn9
o`000002ooVoR005o`000?onaWkoo/Ino`000?ohc5h00_l000000ookgGko0000ooORP@02o`000004
omcBEol0003ohMe[o`0000;oeNAh0_l00005ojVmj003o`000?nY_NSoZKgX00CoZKgX0_l00005ojVm
j003o`000?nY_NSo000000CoZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`00
0?nY_NP01OnY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00GoZKgX00?o0000ojVm
j?nY_NP00ol000000onY_NSo0000o`00000Looooo`009_ooool00ol0003oooooooooo`12ooooo`03
o`000?nY_NSoZKgX00;oZKgX0ol00007ojVmj004o`000?nY_NSoZKgXojVmj0?o00001onY_NP00ol0
003oZKgXo`000002o`000003ojVmj?l0003oZKgX00KoZKgX00?o0000ojVmj?l000000_l00002ojVm
j003o`000?nY_NSo000000;o000000?o02Nbo`000?l000001?m8L=L2o`0000KoX9c@00?o0000ol:[
`_o2Zl801?o2Zl800ol0003o`ZNoo`000008olJ_``;o00002?o5/<H2o`0000SoaKC90_l00007olFg
c@03o`000?o7^<co000000OoaK[@00?o0000olNld?l000001_o4_M<00ol0003oa[kCo`000007ol>o
eP03o`000?o4`MOo000000Ko`l7I0_l000000oo3`mWo0000oo73X@04oo73X@03o`000?oNbL?og/W3
00;og/W30_l00003ooRlR005o`000?oh_HWon;f9ooRmROl000000_oh_XT01Ol0003onKn9ooVoROoi
_hWo000000;onKn800?o0000ook6O_l000000_ohc5h2o`000003oo_MO_l0003o000000;o000000?o
g=9Go`000?l000000_oEi7P2o`0000OoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVm
j005ojVmj003o`000?nY_NSo000000?o000000?oZKgXo`000?nY_NP01OnY_NP3o`0000GoZKgX00?o
0000ojVmj?nY_NP00onY_NP3o`0000GoZKgX00?o0000ojVmj?nY_NP00onY_NP3o`0000GoZKgX0_l0
000:ooooo`Co000000?o410@ooooooooool02_ooool002Gooooo00?o0000ooooooooool0A?ooool5
o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY_NP4o`0000?oZKgX00?o0000ojVmj?nY_NP01?nY_NP2
o`0000GoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000KoZKgX00?o0000ojVmj?l000000_l00000
0ol09k;o0000o`000003odQ`e`03o`000?nPW=3oX9c@00GoX9c@00?o0000ol:[`_o2Zl800oo2Zl80
1Ol0003o`ZNool:W_oo2Ykoo000000KoaZo300Co0000olJ/`?o6[<3o00001_o5/<H01?l0003obK?5
olVcaOl00006olFdb@04o`000?o8]<Sob;C8o`0000GoaKO=00Go0000olNhc?o7^<coakS<o`000004
olFjd0;o00000oo7_=000ol0003oa;gColBmd`02olBmd`05o`000?o6_]?oa[kColJndol000001Oo3
_mH01Ol0003oa<7GolC1eoo4`MOo000000Co`l7I00?o0000ol?3fOo3`mT00_o3`mT01Ol0003olL>Q
oo73XOoa`j7o000000Gog/W30_l00003ooRlR004o`000?oh_HWon;f9o`0000?on;j900Co0000ooVo
ROoi_hWo00000ooi_hP01?l0003oo/Ino`000?ohc5h2o`0000;onmen0ol000001_oLdUOo0000on7M
Jol0003oeNAho`0000;od_cP00?o0000ojVmj?nY_NP01?nY_NP3o`0000GoZKgX00Co0000ojVmj?nY
_NSoZKgX1_l00004ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?nY_NP01OnY_NP00ol0
003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00GoZKgX00?o0000ojVmj?nY_NP00ol000000onY
_NSo0000ojVmj005ojVmj0;o00003?ooool00ol0003oooooooooo`0<ooooo`009Oooool00ol0003o
ooooooooo`12ooooo`Co00001_nY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00Go
ZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX00?oZKgX00?o0000ojVmj?nY
_NP00ol00002ojVmj003o`000?nY_NSoZKgX00?oZKgX1_l000000ol09k;o0000odQ`e`03odQ`e`03
o`000?nPW=3oX9c@00GoX9c@00Go0000ol:[`_o2Zl;o`Z_2o`000004ol:W_`03o`000?o6[l?oaZo3
00?oaZo300?o0000olJ/`?o6[<000_o6[<000ol0003oaK36olF`aP02olF`aP03o`000?o9/lGobK?5
00;obK?500?o0000olFdbOo5]<T00_o5]<T01Ol0003ob;C8olRdb?o8]<So000000CoaKO=00?o0000
olNhc?o7^<`00oo7^<`01?l0003oaK[@olFjd?l00006olNld004o`000?o4_M?oa;gCo`0000Goa[kC
00Go0000ol>oe_o3_mKo`koFo`000005olC1e`04o`000?o3`MWo0000o`0000Ko`l?I00?o0000oo73
XOl000001_oNbL<2o`0000?on;b800Co0000ooRmROoh_HWo00000ooh_XT01?l0003onKn9ooVoROl0
0003ooVoR004o`000?onaWko0000ooS<GP;o000000?onmeno`000?l000000_l000001OoLdUOo0000
o`000?oEi7So000000Cod_cP00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj005ojVmj0Co
00000onY_NP00ol0003oZKgXo`000004ojVmj0?o00001OnY_NP00ol0003oZKgXojVmj003ojVmj0?o
00001OnY_NP01?l0003oZKgXojVmj?nY_NP5o`0000GoZKgX00?o0000ojVmj?nY_NP00ol000000onY
_NSo0000o`00000;ooooo`03o`000?oooooooooo00cooooo000Uooooo`03o`000?oooooooooo043o
oooo0_l00004ooooo`03o`000?nY_NSoZKgX00?oZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00?o
ZKgX0ol00006ojVmj004o`000?nY_NSoZKgXojVmj0Co00001_nY_NP00ol0003oZKgXo`000002o`00
00;oZKgX00Co0000ojVmj?l0003o00000_l09k801Ol0003oB73GodQ`eom8L=Oo000000OoX9c@00Co
0000ol:[`_o2Zl;o00001_o2Ykl01Ol0003oaZo3olJ_`oo6[l?o000000GoaZc000Go0000olF`a_o5
/<KoaK36o`000005olVca@05o`000?o5]<WoaKC9olFdbOl000001Oo8]<P01?l0003oaKO=olFgcOl0
0006olNhc003o`000?o5^]3o000000Ooakc@00?o0000olBmdol000001oo6_]<00ol0003o`koFo`00
0006olC1e`;o00002?o3`mT2o`0000Kog/W300?o0000olc8eol000000ooh_8P01?l0003on;f9ooRm
ROl00003ooRnR@04o`000?oi_hWonKn9o`0000;onKn800Go0000ook6O_onaWko0000ooS<GP02o`00
0003oo_MO_l0003omlaM00;o000000Cog=9Go`000?l0003o00000ooBo>05o`0000GoZKgX00?o0000
ojVmj?nY_NP00ol000000onY_NSo0000ojVmj005ojVmj003o`000?nY_NSo000000?o000000?oZKgX
o`000?nY_NP01OnY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00GoZKgX1?l00003
ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00005ojVmj0;o00002_ooool00ol0003oooooooooo`0<
ooooo`009Oooool3o`0003gooooo0ol00007ooooo`03o`000?nY_NSo000000;o00000onY_NP00ol0
003oZKgXojVmj003ojVmj003o`000?nY_NSo000000;o00000onY_NP00ol0003oZKgXojVmj003ojVm
j0Co00001?nY_NP00ol0003oZKgXojVmj003ojVmj0;o00001_nY_NP01?l0003oZKgXo`000?l00002
o`0W/P;o00000_m8L=L00ol0003oX9c@oj2Ld004oj2Ld003o`000?o2Zl;o000000Oo`ZNo00Co0000
olJ_`oo6[l?o00001oo6[<000ol0003oaK36o`000007olVca@03o`000?o5]<Wo000000Kob;C800?o
0000olFgcOl000002?o7^<`00ol0003oakc@olNld006olNld0;o00002?o6_]<2o`0000Koa<7G00?o
0000olK3eol000001oo3`mT00ol0003oaLGJo`000005omk9``07o`000?o<b=Ooc<SGolc8eol0003o
n;b8o`000003ooRmR@05o`000?oh_XWon;j9ooRnROl000000_oi_hT01?l0003onKn8ooVoR?l00002
ook6OP03o`000?ohc5ko000000?o000000GomlaMo`000?l0003o0000on7MJ`05o`0000CoZKgX00?o
0000ojVmj?nY_NP00onY_NP3o`0000GoZKgX00?o0000ojVmj?nY_NP00onY_NP4o`0000CoZKgX00Co
0000ojVmj?nY_NSoZKgX1Ol00005ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?nY_NP0
1OnY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP00onY_NP2o`0000[ooooo
00?o0000ooooooooool03?ooool002Gooooo00?o0000ooooooooool0>_ooool3o`0000_ooooo0_l0
0006ojVmj004o`000?nY_NSoZKgXojVmj0Co00001_nY_NP00ol0003oZKgXo`000002o`000003ojVm
j?l0003oZKgX00KoZKgX00?o0000ojVmj?l000000_l00002ojVmj003o`000?nY_NSoZKgX00CoZKgX
0_l000001Ol01i?o0000o`0W/_l0003o?FSC00;o000000?oB73Go`000?nPW=001?nPW=02o`0000So
`ZNo00?o0000olJ_`ol000002Oo6[<000ol0003obK?5olVca@07olVca@03o`000?o8]<Sob;C800Ko
b;C800?o0000olNhc?o7^<`01_o7^<`2o`0000Ooakc@00?o0000olRmd?l000001oo6_]<00ol0003o
al3Co`000005olC1e`05o`000?o6`mOoa/?GolK3eol000001Oo3`mT01Ol0003oaLGJolG5f_o5aM[o
000000?og/W300?o0000olc8eoo<b=L00oo<b=L2o`0000?on;f900Co0000ooRnROoh_XWo00000ooi
_hT01?l0003onKn8ooVoR?l00002ook6OP09o`000?ohc5ko0000o`000?oja8co0000ooO<GOl0003o
g=9G00?o000000?oa<eAo`000?nY_NP01_nY_NP00ol0003oZKgXo`000002o`0000;oZKgX00?o0000
ojVmj?nY_NP00onY_NP00ol0003oZKgXojVmj003o`0000;oZKgX0_l00004ojVmj0Co00001?nY_NP0
0ol0003oZKgXojVmj003ojVmj0?o00001OnY_NP00ol0003oZKgXojVmj003ojVmj0?o00001_nY_NP0
1?l0003oZKgXojVmj?nY_NP4o`0000Wooooo00?o0000ooooooooool03?ooool000_ooooo0_l00000
2Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01oooool00ol0003oooooooooo`0gooooo`?o00004?ooool00ol0003oZKgXojVmj003ojVm
j0Co00001?nY_NP00ol0003oZKgXojVmj003ojVmj0;o00001OnY_NP00ol0003oZKgXojVmj004ojVm
j0;o00001_nY_NP01?l0003oZKgXojVmj?nY_NP7o`000004o`0W/_l0003o?FSCoceXd`;o00000_nP
W=03o`000003oinGc?l0003o`ZNo00So`ZNo00?o0000olJ/`?o6[<002?o6[<000ol0003obK?5olVc
a@06olVca@;o00001oo8]<P2o`0000OoakS<00Co0000olViboo9^L_o00001Oo7_=001Ol0003ob;g@
olRmd?o8_M3o000000Coa[kC0_l00003olO0d`05o`000?o4`MOoa<7GolC1eol000001Oo6`mL01Ol0
003o`l?Iol?3fOo3`mWo000000GoaLGJ00?o0000omk9`ol000001_o<b=L2o`0000?on;f900Co0000
ooRnROoh_XWo00000ooi_hT01?l0003onKn8ooVoR?l00002ook6OP03o`000?ohc5ko000000;on/B<
0ol000001?oLdUOo0000o`000?o4cE43o`0000KoZKgX0_l00006ojVmj004o`000?nY_NSoZKgXojVm
j0Co00001_nY_NP5o`000003ojVmj?l0003oZKgX00KoZKgX00?o0000ojVmj?l000000_l00002ojVm
j003o`000?nY_NSoZKgX00CoZKgX00?o0000ojVmj?l000000_l00002ojVmj003o`000?nY_NSoZKgX
00CoZKgX1?l00003ojVmj0;o00002?ooool00ol0003oooooooooo`0<ooooo`003?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Kooooo00?o0000ooooooooool0=Oooool3o`0001Cooooo00?o0000ojVmj?l000000_l00000
0onY_NSo0000ojVmj006ojVmj003o`000?nY_NSo000000;o00000_nY_NP00ol0003oZKgXojVmj003
ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP00ol0003oZKgXojVmj003ojVmj0Co00001?nY_NP5
o`0000Co?FSC0_l00005oinGc003o`000?o2Ykoo`ZNo00Ko`ZNo00?o0000olJ/`?o6[<001oo6[<00
0ol0003ob:bmo`000006olVca@04o`000?o9/L;obK72o`0000Gob;C800Co0000olZfa_o:]/Ko0000
1Oo7^<`00ol0003obKW;olVib`02olVib`05o`000?o7_=3oakc@olNld?l000001Oo8_M001?l0003o
a[kColJndol00006olO0d`03o`000?o4`MOo000000Ooa/?G00?o0000ol?3fOl000001_o5aMX2o`00
00Koc<SG00?o0000ol_:fOl000000ooh_HT01?l0003on;j9ooRnROl00003ooVoR@04o`000?oi_hSo
nKn8o`0000;oo/In0ol00002oo[4S0Ko000000?oa<eAo`000?l000000_l00002ojVmj0?o000000?o
ZKgXo`000?nY_NP01OnY_NP4o`0000?oZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000CoZKgX00?o
0000ojVmj?nY_NP01?nY_NP2o`0000KoZKgX00Co0000ojVmj?nY_NSoZKgX1?l00006ojVmj003o`00
0?nY_NSoZKgX00?o000000?oZKgXo`000?nY_NP01OnY_NP00ol0003oooooooooo`04ooooo`03oeEE
EOmVIVKo000000kooooo0009ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo03;ooooo0ol0000Hooooo`03
o`000?nY_NSoZKgX00?oZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000KoZKgX00Co0000ojVmj?nY
_NSoZKgX1?l00006ojVmj003o`000?nY_NSo000000;o00000_nY_NP00ol0003oZKgXojVmj004ojVm
j0Go00000olmJ=<00ol0003oWiO<oinGc004oinGc003o`000?o2Ykoo`ZNo00Go`ZNo00?o0000olJW
^ol000001oo6[<001?l0003ob:bmolR/_Ol00005olVca@05o`000?o9/L;obK72olVa`_l000001?o8
]<P00ol0003ob[K6olZfaP02olZfaP05o`000?o7^<coakS<olNhc?l000001_o9^L/00ol0003oakc@
o`000006olRmd003o`000?o6_]?o000000Ooal3C0_l00008olK3e`;o00001_o5aMX00ol0003oaLOK
o`000005olc8e`07o`000?o;b]Wobl[Iol_:fOl0003on;f9o`000003ooRnR@04o`000?oi_hWonKn9
o`0000?onKn800Co0000ook6O_l0003on<aN0_l000001Ooja8co0000ooO<GOl0003og=9G00[o0000
1OnY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00GoZKgX00?o0000ojVmj?nY_NP0
0ol000001?nY_NSo0000ojVmj?l00004ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?nY
_NP01OnY_NP4o`0000?oZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000GoZKgX00?o0000ojVmj?nY
_NP00onY_NP2o`0001Kooooo0009ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0_
ooooo`?o00007?ooool00ol0003oZKgXojVmj003ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP0
0ol0003oZKgXojVmj003ojVmj0Co00001?nY_NP00ol0003oZKgXojVmj003ojVmj0;o00001_nY_NP0
0ol0003oZKgXojVmj003ojVmj0?o000000?o00bJo`000?l000000olmJ=<00ol0003oWiO<oinGc004
oinGc003o`000?o2Ykoo`ZNo00?o`ZNo00Co0000olJW^oo6Yk_o00001_o6[<000ol0003ob:bmolR/
_@02olR/_@05o`000?o9/lGobK?5olVcaOl000001Oo9/L801?l0003ob;C8olRdb?l00006olZfaP03
o`000?o7^<co000000OobKW;0_l00007olRmd0;o00001oo7`=<00ol0003ob/?Do`000006olK3e`;o
000000?oalGHo`000?o5aMX01?o5aMX01Ol0003oaLOKolG7foo5am_o000000?oc<SG00?o0000ol_:
fOo;b]T00oo;b]T2o`0000?on;j900Co0000ooVoROoi_hWo00000ooi_hP01?l0003oo/Ino`000?oh
c5h2o`000005oo[4S?l0003omlaMo`000?oLdUL01ol000000on/`NWo0000ojVmj005ojVmj0?o0000
1OnY_NP00ol0003oZKgXojVmj003ojVmj0?o00001OnY_NP2o`0000;oZKgX1Ol00005ojVmj003o`00
0?nY_NSoZKgX00?o000000?oZKgXo`000?nY_NP01OnY_NP00ol0003oZKgXojVmj003o`000003ojVm
j?l0003oZKgX00GoZKgX00?o0000ojVmj?nY_NP01?l0000Gooooo`002Oooool01?oMgMgoEEEEoooo
ool00004ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool0;?ooool3o`00023ooooo00Co0000ojVmj?nY_NSoZKgX1?l00006
ojVmj003o`000?nY_NSo000000;o00000_nY_NP00ol0003oZKgXojVmj004ojVmj003o`000?nY_NSo
000000;o00000_nY_NP00ol0003oZKgXojVmj004ojVmj003o`000?nY_NSo000000;o000000KoZKgX
o`000?l0087o0000o`0<V_l00003oceXd`03o`000?nOUlcoWiO<00CoWiO<00?o0000ol:W_oo2Ykl0
0_o2Ykl00ol0003oaZNkolJW^`02olJW^`03o`000?o6[<3oaZc000;oaZc000?o0000olR/_Oo8[;d0
0oo8[;d01?l0003obK?5olVcaOl00006olVa`P03o`000?o8]<So000000Sob[K600?o0000olViboo9
^L/01Oo9^L/00ol0003oc;_:o`000006olRmd004o`000?o:_loob[o?o`0000Goal3C00Go0000ol[3
e?o:`mCob/?Do`000004olK3e`03o`000?o7aMSoalGH00;oalGH00Go0000olG5f_o5aM[oaLGJo`00
0005olG7f`03o`000?o<b=Oo000000Kobl[I0_l00003ooRnR@04o`000?oi_hWonKn9o`0000;onKn8
00Ko0000ook6O_onaWko0000ooS<G_l00002oo[4S003o`000?ogc5go000000Go00001On/`NT00ol0
003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00GoZKgX00?o0000ojVmj?nY_NP00ol000000onY
_NSo0000ojVmj005ojVmj0Co00000onY_NP00ol0003oZKgXojVmj004ojVmj0?o00001OnY_NP00ol0
003oZKgXojVmj003ojVmj0?o00001OnY_NP01?l0003oZKgXojVmj?nY_NP5o`0000Cooooo00?o0000
ooooooooool05?ooool000[ooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo
410@00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo02Wooooo0ol0
000Tooooo`?o00001?nY_NP00ol0003oZKgXojVmj003ojVmj0;o00001_nY_NP00ol0003oZKgXojVm
j003ojVmj0;o00001_nY_NP01?l0003oZKgXojVmj?nY_NP4o`0000GoZKgX0_l00002o`0<VP;o0000
0_lmJ=<00ol0003oWiO<oinGc004oinGc004o`000?o2Ykoo`ZNoo`0000KoaZNk00Co0000olJ/`?o6
[<3o00001_o8[;d00ol0003obK?5o`000008olVa`P03o`000?o:]/Kob[K600Oob[K600?o0000olVi
boo9^L/01?o9^L/01Ol0003oc;_:olbkb_o<^l[o000000Cob;g@00?o0000olZocoo:_ll00_o:_ll0
1Ol0003oal3ColO0doo7`=?o000000Gob/?D00Co0000olK3eol0003o00001_o7aMP00ol0003oaLGJ
o`000006olG7f`;o00001_o;b]T00ol0003ob/_Ko`000003ooRnR@04o`000?oi_hWonKn9o`0000;o
nKn800Ko0000ook6O_onaWko0000ooS<G_l00002oo[4S003o`000?ogc5go000000Go00001On/`NT3
o`0000GoZKgX00Co0000ojVmj?nY_NSoZKgX1Ol00005ojVmj003o`000?nY_NSoZKgX00?o000000Co
ZKgXo`000?nY_NSo00001?nY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00GoZKgX
00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj005ojVmj0Co00002Oooool00ol0003ooooo
ooooo`0Dooooo`002_ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool09oooool2o`0002So
oooo00?o0000ojVmj?nY_NP01?nY_NP00ol0003oZKgXo`000002o`0000;oZKgX00?o0000ojVmj?nY
_NP01?nY_NP00ol0003oZKgXo`000002o`0000;oZKgX00?o0000ojVmj?nY_NP00onY_NP4o`0000Co
ZKgX00?o0000ojVmj?nY_NP00onY_NP2o`000006o`0<V_l0003o85O=o`000?lmJ=?o00001_nOUl`0
0ol0003o`ZNoo`000007olJW^`03o`000?o6[<3o000000Sob:bm00?o0000olVa`_o9/L801oo9/L80
0ol0003ob[K6olZfaP06olZfaP03o`000?o>^LKo000000CobKW;00?o0000olbkb_o<^lX00oo<^lX0
1?l0003ob;g@olRmd?l00006olZoc`03o`000?o7`=?o000000Oob/?D00?o0000olO5f?o7aMP01_o7
aMP2o`0000KoaLOK00?o0000olK8g?l000001Oo;b]T01ol0003ob/_Kol[;foo:bm_o0000ooRnROl0
00000ooi_hT01?l0003onKn8ooVoR?l00002ook6OP?o00000_oja8`00ol0003omlaMo`000003o`00
00;o[/=500?o0000ojc1jOl000000_l00002ojVmj003o`000?nY_NSoZKgX00?oZKgX1?l00004ojVm
j003o`000?nY_NSoZKgX00?oZKgX0ol00005ojVmj003o`000?nY_NSo000000?oZKgX0ol00005ojVm
j004o`000?nY_NSoZKgXojVmj0Go00001OnY_NP00ol0003oZKgXojVmj003o`0000gooooo00?o0000
ooooooooool05?ooool000_ooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`;o00009Oooool3o`0002_ooooo00?o
0000ojVmj?nY_NP00onY_NP2o`0000KoZKgX00Co0000ojVmj?nY_NSoZKgX1?l00006ojVmj003o`00
0?nY_NSo000000;o00000_nY_NP00ol0003oZKgXojVmj004ojVmj003o`000?nY_NSo000000;o0000
00KoZKgXo`000?l0003o00bJo`000?lPEld3o`0000GoWiO<0_l00009olJW^`03o`000?o8[;gob:bm
00Oob:bm00?o0000olVa`_o9/L801_o9/L800ol0003oc;;0o`000006olZfaP05o`000?o>^LKoc[W6
oljia_l000000_o9^L/00ol0003oc;_:olbkbP04olbkbP03o`000?o8_M3o000000Oob[o?0_l00007
ol[3e0;o00001oo7aMP00ol0003obLOHo`000005olG7f`05o`000?o6b=coa/SLolK8g?l000000oo;
b]T00ol0003ob/_Kol[;f`03ol[;f`;o00000ooi_hT01?l0003onKn8ooVoR?l00002ook6OP?o0000
0_oja8`6o`0000;o[/=50_l00006ojVmj003o`000?nY_NSo000000;o000000?oZKgXo`000?nY_NP0
1_nY_NP00ol0003oZKgXo`000002o`0000;oZKgX00?o0000ojVmj?nY_NP00onY_NP00ol0003oZKgX
o`000003o`000003ojVmj?l0003oZKgX00GoZKgX1?l00003ojVmj003o`000?nY_NSoZKgX00CoZKgX
0ol0000@ooooo`03o`000?oooooooooo01Cooooo000Sooooo`03o`000?oooooooooo02;ooooo0ol0
000_ooooo`03o`000?nY_NSo000000;o00000_nY_NP00ol0003oZKgXojVmj003ojVmj0Co00001?nY
_NP00ol0003oZKgXojVmj003ojVmj0;o00001_nY_NP00ol0003oZKgXojVmj003ojVmj0;o00001OnY
_NP3o`0000?o85O=00?o0000oinGc?nOUl`00ol000000onNUL[o0000olJW^`08olJW^`03o`000?o8
[;gob:bm00Kob:bm00?o0000omBi_ol000001_o9/L801Ol0003oc;;0olbb`?o<//3o000000Cob[K6
00?o0000oljia_o>^LH00_o>^LH00ol0003obKW;o`000008olbkbP03o`000?o:_loob[o?00Gob[o?
00?o0000olc1d?l000001_o:`m@01?l0003ob/CDol[4e?l00004olO5f0;o00000oo9amP01Ol0003o
aLOKolG7foo5am_o000000Goa/SL00?o0000ol_:fOl000001_o:bm/2o`0000?onKn900Co0000ooVo
R?oi_hSo00000_onaWh3o`0000;on/B<1_l000001?n^`dGo0000om;lgol00006ojVmj0;o00001OnY
_NP00ol0003oZKgXojVmj004ojVmj0;o00001_nY_NP01?l0003oZKgXojVmj?nY_NP5o`0000CoZKgX
00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj005ojVmj003o`000?nY_NSoZKgX00?o0000
4oooool00ol0003oooooooooo`0Dooooo`008oooool00ol0003oooooooooo`0Oooooo`?o0000<ooo
ool00ol0003oZKgXojVmj004ojVmj003o`000?nY_NSo000000;o00000_nY_NP00ol0003oZKgXojVm
j004ojVmj003o`000?nY_NSo000000;o00000_nY_NP00ol0003oZKgXojVmj004ojVmj003o`000?nY
_NSo000000;o00000_nY_NP00ol0003oZKgXojVmj003ojVmj003o`000?l039[o000000?o85O=0_l0
0005oijEbP03o`000?o6Yk_oaZNk00GoaZNk00?o0000on;m`Ol000001_o8[;d01Ol0003oe;VoomBi
_ooD^Koo000000CobK7200?o0000olbb`?o<//000_o<//001Ol0003ob[K6olZfa_o:]/Ko000000Ko
c[W600?o0000olbkb_o<^lX01oo<^lX00ol0003ob[o?olZoc`04olZoc`05o`000?o<`M3oc<7@olc1
d?l000001?o:`m@00ol0003ob/CDol[4e002ol[4e004o`000?o7aMSoalGHo`0000KobLOH00?o0000
olG7fol000001_o6b=`2o`0000Kob/_K00Ko0000ol_=foo;cM_o0000ooVoROl00003ooVoR003o`00
0?onaWkoo/In00?o00000_oja8`2o`000003ooo=Ool0003o000000;o00000ooBo=l00ol0003oZKgX
ojVmj003o`000003ojVmj?l0003oZKgX00GoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000
ojVmj005ojVmj0Co00000onY_NP00ol0003oZKgXo`000003ojVmj0?o00001OnY_NP00ol0003oZKgX
ojVmj003ojVmj0?o00005_ooool00ol0003oooooooooo`0Dooooo`008oooool00ol0003ooooooooo
o`0Looooo`?o0000=oooool00ol0003oZKgXojVmj003ojVmj0?o00001OnY_NP00ol0003oZKgXojVm
j003ojVmj0;o00001_nY_NP01?l0003oZKgXojVmj?nY_NP4o`0000KoZKgX00?o0000ojVmj?l00000
0_l000000onY_NSo0000o`000003ob1Gc@03o`000?nNUL[oWYG:00CoWYG:00?o0000olJW^oo6Yk/0
1?o6Yk/01?l0003oh_g1on;m`Ol00005olR/_@03o`000?oD^Kooe;Vo00;oe;Vo00Go0000olVa`_o9
/L;obK72o`000006olbb`003o`000?o:]/Ko000000Ooc[W600?o0000olbkb_o<^lX01_o<^lX00ol0
003oc[g:o`000004olZoc`03o`000?o<`M3oc<7@00?oc<7@00Co0000ol[3e?o:`mCo00001Oo:a=@0
0ol0003oalGHo`000007olW7f0;o00001_o6b=`00ol0003oal_Mo`000005ol[;f`03o`000?o;cM_o
blgK00;oblgK0_l00003ooVoR003o`000?onaWkoo/In00?o000000?on/B<o`000?ogc5d01?l00005
om;lg`?o00001OnY_NP01?l0003oZKgXojVmj?nY_NP5o`0000GoZKgX00?o0000ojVmj?nY_NP00ol0
00000onY_NSo0000ojVmj005ojVmj0Go00000_nY_NP00ol0003oZKgXojVmj003ojVmj003o`000?nY
_NSoZKgX00?o00006Oooool00ol0003oooooooooo`0Dooooo`008oooool00ol0003oooooooooo`0I
ooooo`?o0000>oooool00ol0003oZKgXo`000002o`0000?oZKgX00?o0000ojVmj?nY_NP00onY_NP0
0ol0003oZKgXo`000002o`0000;oZKgX00?o0000ojVmj?nY_NP00onY_NP4o`0000CoZKgX00?o0000
ojVmj?nY_NP00onY_NP2o`0000CoZKgX0_l00004ob1Gc@03o`000?nNUL[oWYG:00?oWYG:00?o0000
olJW^oo6Yk/00oo6Yk/00ol0003oh_g1on;m`@02on;m`@03o`000?o8[;gob:bm00;ob:bm00?o0000
omBi_ooD^Kl00ooD^Kl00ol0003obK72o`000008olbb`003o`000?o>^LKoc[W600Goc[W600?o0000
oljiaOl000001_o<^lX01Ol0003oc[g:oljmb_o>_L[o000000;ob[o?00?o0000olc1d?o<`M001?o<
`M000ol0003ob/?Do`000006ol[4e0?o00001_o9amP01?l0003ob/WIol[9fOl00003olK8g0;o0000
0oo7bmd01Ol0003ob/_Kol[;foo:bm_o000000GoblgK0_l00002ooVoR003o`000?onaWkoo/In00?o
00000_oja8`00ol0003omlaMo`000004o`000004om;lgol0003o0000o`0000;oZKgX00?o0000ojVm
j?nY_NP00onY_NP4o`0000?oZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000GoZKgX00?o0000ojVm
j?nY_NP00onY_NP3o`0000GoZKgX00Co0000ojVmj?nY_NSoZKgX1?l0000Mooooo`03o`000?oooooo
oooo01?ooooo000Sooooo`03o`000?oooooooooo01Kooooo0ol0000oooooo`03o`000?nY_NSoZKgX
00GoZKgX00Co0000ojVmj?nY_NSoZKgX0ol00006ojVmj003o`000?nY_NSo000000;o00000_nY_NP0
0ol0003oZKgXojVmj004ojVmj003o`000?nY_NSo000000;o00000_nY_NP00ol0003oZKgXojVmj002
ojVmj0?o00000_lPEld00ol0003oWYG:oijEbP04oijEbP05o`000?o6Yk_oaZNkolJW^ol000001_oR
oL401?l0003ob:bmolR/_Ol00007omBi_`03o`000?o<//3oc;;000Ooc;;000?o0000oljia_o>^LH0
1?o>^LH01Ol0003oc[W5oljiaOo>^LGo000000Coc;_:00?o0000oljmb_o>_LX00_o>_LX00ol0003o
b[o?o`000007olc1d0;o00001_o:a=@01Ol0003oc<OEolc7eOo<amGo000000?obLOH0_l00004ol[9
f@03o`000?o6b=co000000Koal_M00?o0000ol[;fol000001Oo;cM/01_l0003oc<oLolc?g?l0003o
nKn8o`0000;oo/In0ol00002oo[4S003o`000?ogc5go000000Go00001_nY_NP00ol0003oZKgXo`00
0002o`000003ojVmj?l0003oZKgX00GoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVm
j005ojVmj003o`000?nY_NSoZKgX00?o000000CoZKgXo`000?nY_NSo00001?nY_NP4o`00027ooooo
00?o0000ooooooooool04oooool002?ooooo00?o0000ooooooooool04oooool3o`0004?ooooo00?o
0000ojVmj?nY_NP01?nY_NP4o`0000?oZKgX00?o0000ojVmj?nY_NP00onY_NP2o`0000KoZKgX00?o
0000ojVmj?nY_NP00onY_NP2o`0000KoZKgX00Co0000ojVmj?nY_NSoZKgX0_l000001?l0?Koo0000
ob1GcOl00006oijEbP04o`000?o6Yk_oaZNko`0000Ooh_g100?o0000olR/_Ol000002?oD^Kl00ol0
003oc;;0olbb`006olbb`003o`000?o?/kko000000Coc[W600?o0000oljiaOo>^LD00_o>^LD01Ol0
003oc;_:olbkb_o<^l[o000000Koc[g:00?o0000olc1d?o<`M001Oo<`M000ol0003oclC?o`000005
ol[4e003o`000?o<amGoc<OE00?oc<OE00?o0000olW7f?l000001_o:bMT2o`0000Ooal_M0_l00005
ol_=f`03o`000?o<cmcoc<oL00;oc<oL0_l00002ook6OP?o00000_oja8`00ol0003omlaMo`000005
o`0000KoZKgX0_l00005ojVmj003o`000?nY_NSoZKgX00?oZKgX0ol00005ojVmj004o`000?nY_NSo
ZKgXojVmj0Go00001OnY_NP00ol0003oZKgXo`000003o`0002Gooooo00?o0000ooooooooool04ooo
ool002;ooooo00?o0000ooooooooool04_ooool2o`0004Oooooo00?o0000ojVmj?nY_NP00ol00002
ojVmj003o`000?nY_NSoZKgX00?oZKgX00?o0000ojVmj?l000000_l00002ojVmj003o`000?nY_NSo
ZKgX00CoZKgX00?o0000ojVmj?l000000_l00002ojVmj003o`000?nY_NSoZKgX00?oZKgX1?l00000
1onY_NSo0000o`000?l0?Koo0000ob1GcOl000001OnNULX00ol0003oaZNko`00000:o`0000Soe;Vo
00?o0000on;mbol000001_o<//001Ol0003ock>nolnc__o?/kko000000;oc[W600?o0000oljiaOo>
^LD01?o>^LD00ol0003oc;_:o`000007oljmbP;o00001Oo<`M001Ol0003oclC?olo4coo?a<oo0000
00?ob/CD00?o0000olc7eOo<amD01?o<amD2o`0000Kob/WI00?o0000ol_;f_l000001_o7bmd01?l0
003oalgNolO=g_l00003ol_=f`03o`000?o<cmcoc<oL00?oc<oL1Ol000001?oebJ3o0000oo[4S?oj
a8`2o`000003ooo=Ool0003o000000;o000000Co]>R=o`000?nY_NSoZKgX0ol000000onY_NSo0000
ojVmj005ojVmj003o`000?nY_NSo000000;o00000_nY_NP00ol0003oZKgXojVmj003ojVmj0Co0000
0onY_NP00ol0003oZKgXojVmj004ojVmj0?o0000:?ooool00ol0003oooooooooo`0Cooooo`008_oo
ool3o`0000oooooo0ol0001:ooooo`;o00001_nY_NP01?l0003oZKgXojVmj?nY_NP3o`0000KoZKgX
00Co0000ojVmj?nY_NSoZKgX1?l00006ojVmj003o`000?nY_NSo000000;o00000_nY_NP01Ol0003o
ZKgXojVmj?nY_NSo000000;o03fo0_l00005oijEbPCo000000ColMNeo`000?okfJ7o00000_old9P3
o`0000Ooe;Vo00Co0000on;mbooRoL_o00001Oo<//000ol0003ock>nolnc_P02olnc_P03o`000?o>
^LKo000000Soc[W500?o0000oljmb_o>_LX01Oo>_LX01?l0003od/;;om;2bol00003olc1d003o`00
0?o?a<ooclC?00?oclC?00?o0000ol[4e?l000001_o<amD00ol0003ocLWFo`000005ol[9f@05o`00
0?o;bm[obl_Jol_;f_l000000oo7bmd2o`0000CoalgN00?o0000ol_=fol000001Oo<cm`00ol0003o
cm7KoloAf`02oloAf`03o`000?oebJ3o000000;on/B<0_l000001OoocGoo0000o`000?l0003o]>R=
00Co00001OnY_NP01?l0003oZKgXojVmj?nY_NP4o`0000KoZKgX00?o0000ojVmj?l000000_l00002
ojVmj003o`000?nY_NSoZKgX00?oZKgX00?o0000ojVmj?nY_NP00ol00003ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool04oooool002;ooooo00?o0000ooooooooool03?ooool3o`00
04oooooo00?o0000ojVmj?nY_NP00onY_NP4o`0000?oZKgX00?o0000ojVmj?nY_NP00onY_NP4o`00
00CoZKgX00?o0000ojVmj?nY_NP00onY_NP2o`0000KoZKgX00Go0000ojVmj?nY_NSoZKgXo`000002
o`0m_`03o`000?nNUL[oWYG:00Co000000CoZj3<o`000?oaekGo00000_okfJ401Ol0003oo=2Hooc@
V?l0003oo<V>00;o00001OoD^Kl00ol0003oh_g;on;mb`02on;mb`05o`000?o<//3oc;;0olbb`?l0
00001_o?/kh00ol0003oc[W5oljia@07oljia@03o`000?o>_L[oc[g:00Coc[g:00?o0000om;2booB
`//00_oB`//00ol0003oc<7@o`000007olo4c`03o`000?o<amGoc<OE00Coc<OE00Go0000olg9e_o=
bMKocLWFo`000003ol[9f@03o`000?o;bm[obl_J00?obl_J00?o0000olO;gOl000001_o7cMh2o`00
00Goc<oL00?o0000oloAfoo?dM/00_o?dM/2o`000004ooG9X?l0003on/B<oo[4S0;o000000?ooleo
o`000?l000000_l00003ojVmj003o`000?nY_NSoZKgX00?oZKgX1?l00003ojVmj003o`000?nY_NSo
ZKgX00CoZKgX0_l00006ojVmj004o`000?nY_NSoZKgXojVmj0Co00001oooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo01?ooooo000Rooooo`03o`000?oooooooooo00Wooooo0ol0001C
ooooo`03o`000?nY_NSo000000;o000000?oZKgXo`000?nY_NP01OnY_NP00ol0003oZKgXo`000002
o`0000?oZKgX00?o0000ojVmj?nY_NP00onY_NP00ol0003oZKgXo`000002o`0000;oZKgX00?o0000
ojVmj?nY_NP00onY_NP6o`0000;o03fo0ol00003oj^Pc004o`000?oaekGolMNeo`0000;onmVQ00Go
0000ooc@V?old9So0000ooc9SP02o`0000Coe;Vo00?o0000on;mbooRoL/00ooRoL/01?l0003oc;;0
olbb`?l00007olnc_P03o`000?o>^LGoc[W500Koc[W500?o0000om6ka?l000001?o>_LX00ol0003o
d/;;om;2b`04om;2b`03o`000?o?a<ooclC?00GoclC?0_l00005olc7e@03o`000?o=bMKocLWF00?o
cLWF00?o0000ol[9fOl000001_o;bmX2o`0000KoalgN00Co0000olS?goo8cmoo00000oo<cm`00ol0
003ocm7KoloAf`02oloAf`05o`000?oSd/Ko0000ooG9X?l000000_oja8`2o`000003ooo=Ool0003o
000000KoZKgX00?o0000ojVmj?l000000_l00002ojVmj003o`000?nY_NSoZKgX00?oZKgX00?o0000
ojVmj?nY_NP00ol000000onY_NSo0000ojVmj005ojVmj0Co00003?ooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo01?ooooo000Rooooo`03o`000?oooooooooo00Kooooo0ol0001Goooo
o`03o`000?nY_NSoZKgX00?oZKgX00?o0000ojVmj?nY_NP00onY_NP3o`0000KoZKgX00Co0000ojVm
j?nY_NSoZKgX0ol00006ojVmj003o`000?nY_NSo000000;o00000_nY_NP01Ol0003oZKgXojVmj?l0
003o03fo00;o00001On[X<`01?l0003olMNeoo7G]Ol00002oo_IX@05o`000?old9Soo=2Ho`000?ol
bHh00ol00002omBi_`03o`000?oRoL_oh_g;00Coh_g;00?o0000olbb`?l000001oo?/kh00ol0003o
hm76o`000006oljia@05o`000?oA^lCodK_4om6ka?l000000_o>_LX00ol0003od/;;om;2b`05om;2
b`03o`000?o?a<ooclC?00CoclC?00Co0000om76d?oAa]3o00000oo<amD00ol0003ocLWFolg9eP05
olg9eP03o`000?o;bm[obl_J00Cobl_J00Co0000olc>foo<c]_o00000oo7cMh2o`0000Cob<oO00?o
0000olc?g?l000001Oo?dM/2o`000003ooG9X?l0003on/B<00;on/B<1_l00005ojVmj0;o00001_nY
_NP01?l0003oZKgXojVmj?nY_NP4o`0000GoZKgX00?o0000ojVmj?nY_NP00ol0000@ooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool04_ooool002;ooooo00?o0000ooooooooool00ooo
ool3o`0005_ooooo00?o0000ojVmj?nY_NP00onY_NP00ol0003oZKgXo`000002o`0000?oZKgX00?o
0000ojVmj?nY_NP00onY_NP4o`0000?oZKgX00?o0000ojVmj?nY_NP00onY_NP2o`0000KoZKgX00Co
0000ojVmj?l0003o00001_n[X<`01?l0003olMNeoo7G]Ol00002oo_IX@04o`000?old9Soo=2Ho`00
00;oo<V>00Co0000ooVoQ_l0003oe;Vo2_l00007olnc_P05o`000?oSdLKohm76on?Aa_l000001?o>
^LD00ol0003odK_4om6ka002om6ka003o`000?o>_L[o000000Ood/;;00?o0000om;2bol000001?o?
a<l00ol0003odLK@om76d002om76d003o`000?o<amGo000000OocLWF0_l00005ol_;fP03o`000?o<
c]_oc<kK00;oc<kK00?o0000olO=g_l000001_o8cml2o`0000Gocm7K00Go0000on?Ba_l0003omLVP
o`000002oo[4S003o`000?ogc5go000000Co00000_nY_NP3o`000003ojVmj?l0003oZKgX00GoZKgX
1?l00003ojVmj003o`000?nY_NSoZKgX00?oZKgX0ol0000Dooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool04_ooool0027ooooo00Co0000oooooooooooooooo0ol0001Oooooo`04o`00
0?nY_NSoZKgXojVmj0Co00001_nY_NP00ol0003oZKgXo`000002o`0000;oZKgX00?o0000ojVmj?nY
_NP00onY_NP00ol0003oZKgXo`000002o`0000;oZKgX00?o0000ojVmj?nY_NP00onY_NP4o`0000Go
Zj3<00Go0000oo7G]OoaekGolMNeo`000002oo_IX@04o`000?old9Soo=2Ho`0000;oo<V>00?o0000
ooVoQ_oi_hH00_l000000ooi_8?o0000ooRkQ@02ooRkQ@04o`000?of^HOo0000o`0000Oock>n00Go
0000on?Aa_oSdLKohm76o`000003oljia@03o`000?oA^lCodK_400CodK_400?o0000om;2booB`//0
1OoB`//01Ol0003od/;;om;2booB`/_o000000;oclC?00?o0000om76d?oAa]001?oAa]000ol0003o
cLWFolg9eP05olg9eP04o`000?o>c=Ooc/cGo`0000?obl_J00?o0000olc>foo<c]/00oo<c]/2o`00
00Kob<oO00?o0000olS@h?l000001?o?dM/01_l0003ohm;6on?Ba_l0003omLVPo`0000;on/B<00?o
0000ooO<GOl000001_l00005ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?nY_NP01OnY
_NP00ol0003oZKgXo`000002o`0001Sooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`0Booooo`008Oooool4o`0006?ooooo0ol00004ojVmj003o`000?nY_NSoZKgX00?oZKgX0_l00006
ojVmj004o`000?nY_NSoZKgXojVmj0?o00001_nY_NP00ol0003oZKgXo`000002o`0000;oZKgX0ol0
0004oj^Pc005o`000?oaekGolMNeoo7G]Ol000000_okfJ401_l0003oo=2Hooc@V?l0003oo<V>o`00
00?onKn600Co0000ooVlPooi_8?o00000ooh^hD00ol0003om[V7ooJiQ`02o`0000Gock>n00?o0000
on?Aa_oSdLH00ooSdLH00ol0003oc[W5o`000007om6ka0;o00001OoB`//00ol0003od/;;om;2b`02
om;2b`03o`000?o?a<oo000000KodLK@00?o0000om;9dOl000001Oo=bMH00ol0003oc/cGolk<e`02
olk<e`03o`000?o;bm[o000000Goc<kK00?o0000olc@g?l000001Oo8cml01Ol0003ob=3PolS@h?o8
d>3o000000?ocm7K00Ko0000on?Ba_oSd/Ko0000ooG9X?l00002oo[4S0;o000000?ooleoo`000?l0
00000onZ_^P00ol0003oZKgXojVmj003ojVmj0?o00001OnY_NP01?l0003oZKgXojVmj?nY_NP4o`00
01_ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Booooo`008Oooool2o`0006Ko
oooo00?o0000ojVmj?nY_NP01?nY_NP00ol0003oZKgXo`000002o`0000;oZKgX00?o0000ojVmj?nY
_NP00onY_NP4o`0000?oZKgX00?o0000ojVmj?nY_NP00onY_NP2o`0000KoZKgX0_l00003oj^Pc005
o`000?oaekGolMNeoo7G]Ol000000_okfJ401ol0003oo=2Hooc@V?old9So0000ooc9S_l000000ooi
_hH01?l0003onKb3ooVlPol00003ooRkQ@03o`000?of^HOom[V700?o00000oo?/kh00ol0003ohm76
on?AaP04on?AaP;o00001ooA^l@01?l0003oe;g4omBma?l00003om;2b`03o`000?oB`/_od/;;00Co
d/;;00?o0000om76d?oAa]001?oAa]001Ol0003od/WAom;9dOoBbM7o000000?ocLWF00?o0000olk<
eoo>c=L00oo>c=L2o`0000Goc<kK00Go0000olc@g?o<d=coc=3Lo`000003olS?g`03o`000?o8d>3o
b=3P00?ob=3P00?o0000oloAfol000000_oSd/H01?l0003omLVPooG9X?l00002oo[4S0;o000000?o
oleoo`000?nZ_^P01?nZ_^P00ol0003oZKgXo`000002o`000003ojVmj?l0003oZKgX00GoZKgX1?l0
000Pooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool04_ooool002?ooooo00?o0000
ooooooooool0I?ooool01?l0003oZKgXojVmj?nY_NP4o`0000KoZKgX00?o0000ojVmj?l000000_l0
0002ojVmj003o`000?nY_NSoZKgX00?oZKgX00?o0000ojVmj?l000000_l00002ojVmj003o`000?nY
_NSoZKgX00CoZKgX0_l00002oj^Pc005o`000?oaekGolMNeoo7G]Ol000000_okfJ401ol0003oo=2H
ooc@V?old9So0000ooc9S_l000000ooi_hH00ol0003onKb3o`000006o`000004ooJiQol0003om;N8
o`0000?ock>n00?o0000on?Aa_oSdLH00ooSdLH00ol0003og_?Mo`000006om6ka003o`000?oD_LCo
e;g400;oe;g400?o0000om;2bol000001_oB`//2o`0000GodLK@00?o0000om;9dOoBbM400ooBbM40
0ol0003ocLWFo`000005olk<e`04o`000?o?cmSocloHo`0000?oc<kK00?o0000olc@g?o<d=`00oo<
d=`00ol0003ob<oOo`000006olS@h0;o00000ooSd/H01?l0003omLVPooG9X?l00002oo[4S0;o0000
00?ooleoo`000?nZ_^P00_nZ_^P4o`0000GoZKgX00?o0000ojVmj?nY_NP00ol0000Uooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool04_ooool002Cooooo00?o0000ooooooooool0I?oo
ool3o`0000CoZKgX00?o0000ojVmj?nY_NP00onY_NP2o`0000KoZKgX00Co0000ojVmj?nY_NSoZKgX
0ol00006ojVmj004o`000?nY_NSoZKgXojVmj0Co000000?oZj3<o`000?oaekD00_oaekD01Ol0003o
nmVQoo_IXOokfJ7o000000;oo=2H00?o0000ooc9S_l000001_l000000ooZ_JKo0000onjlWP02onjl
WP04o`000?o`_9Wo0000o`0000;om;N800?o0000olnc__l000001OoSdLH01Ol0003og_?MomkcgOoN
lmgo000000CodK_400?o0000omBma?oD_L@01?oD_L@00ol0003od/;;om;2b`04om;2b`04o`000?oD
aL_oe<G;o`0000?odLK@00?o0000om;9dOoBbM401OoBbM400ol0003oc/cGolk<e`03olk<e`03o`00
0?o?cmSocloH00;ocloH00?o0000olc>fol000001_o<d=`2o`0000Kob=3P00Co0000olSBh_o8d^;o
00000_oSd/H01?l0003omLVPooG9X?l00002oo[4S0;o000000?ooleoo`000?l000000_l00003ojVm
j003o`000?nY_NSoZKgX00?oZKgX0ol0000Yooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool04_ooool002Gooooo00?o0000ooooooooool0IOooool00ol0003oZKgXojVmj003ojVmj003
o`000?nY_NSo000000;o00000_nY_NP00ol0003oZKgXojVmj003ojVmj0Co00000onY_NP00ol0003o
ZKgXojVmj003ojVmj0Co00000onY_NP00ol0003oZj3<o`000003oo7G]@04o`000?okfJ7onmVQo`00
00?oo=2H0_l000000oo=^/So0000on:m/P02on:m/P04o`000?oZ_JKoj[fVo`0000?ok[bN00Co0000
oo2lVOo`_9Wo00000ood]hP00ol0003ohm76on?AaP03on?AaP03o`000?oNlmgog_?M00?og_?M00Co
0000om6ka?oA^lCo00001ooD_L@00ol0003od/;;om;2b`03om;2b`03o`000?oDaL_oe<G;00;oe<G;
00?o0000om76d?l000001ooBbM400ol0003oe<cBo`000003olk<e`03o`000?o?cmSocloH00?ocloH
0_l00006olc@g004o`000?o=d]kocM;No`0000?ob=3P0_l00004olSBhP;o00000_oebJ001?l0003o
n/B<oo[4S?oja8`2o`000004ooo=Ool0003oZ[kXo`0000GoZKgX00?o0000ojVmj?l000000_l0000/
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool04Oooool002Kooooo0_l0001Voooo
o`04o`000?nY_NSoZKgXojVmj0?o00001_nY_NP00ol0003oZKgXo`000002o`0000;oZKgX00?o0000
ojVmj?nY_NP00onY_NP00ol0003oZKgXo`000002o`0000?oZKgX00?o0000ojVmj?nY_NP00_nY_NP3
o`0000;olMNe2?l000000oo=^/So0000on:m/P02on:m/P04o`000?oZ_JKoj[fVo`0000?ok[bN00Go
0000oo2lVOo`_9Wol;bIo`000002ooBgR003o`000?ob]H[o000000?ohm7600?o0000omkcgOoNlmd0
1?oNlmd00ol0003odK_4o`000007omBma003o`000?oH`L;o000000?od/;;00?o0000omC5booDaL/0
1?oDaL/00ol0003od/WAom;9d@05om;9d@07o`000?oDc=;oe<cBomC<d_l0003oc/cGo`000005olo?
f004o`000?o@dM[od=7Jo`0000?oc=3L0_l00004olgBgP03o`000?o8d>3o000000Kob=;R0ol00000
0ooebJ3o0000oo[4S002oo[4S004o`000?oocGoooleoo`0000;oZ[kX00Co0000ojVmj?nY_NSoZKgX
0ol0000`ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool04Oooool002Sooooo00?o
0000ooooooooool0I?ooool3o`0000?oZKgX00?o0000ojVmj?nY_NP00onY_NP2o`0000KoZKgX00Co
0000ojVmj?nY_NSoZKgX0ol00007ojVmj004o`000?nY_NSoZKgXojVmj0Ko00001?n6W^<01Ol0003o
cK[8olfjb?o=^/So000000?oh[fb00Co0000onZmY_oZ_JKo00000oo^_9h01?l0003ol;bIoo2lVOo`
_9T2o`000007ooBgR?l0003ol[F:oo:eR_l0003ohm76o`000007omkcg@;o00001ooD_L@01ol0003o
f<72omS1`_oH`L;o0000om;2bol000001ooDaL/2o`0000God/WA00?o0000omC<d_oDc=800ooDc=80
0ol0003ocloHolo?f003olo?f003o`000?o@dM[od=7J00;od=7J00?o0000olc@g?l000001_o=d]h2
o`0000Kob=;R00Co0000olSDhoo8e>?ob=CS0_l00002oo[4S0;o000000?ooleoo`000?nZ_^P00_nZ
_^P4o`0003Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Aooooo`00:Oooool0
0ol0003oooooooooo`1Tooooo`03o`000?nY_NSoZKgX00?oZKgX00?o0000ojVmj?l000000_l00002
ojVmj003o`000?nY_NSoZKgX00?oZKgX1?l00003ojVmj003o`000?nY_NSoZKgX00CoZKgX1?l00002
ojVmj003o`000?n6W^?oQYkS00CoQYkS00Go0000olfjb?o=^/SocK[8o`000004on:m/P04o`000?oZ
_JKoj[fVo`0000?ok[bN00Co0000oo2lVOo`_9Wo00000_ob_IL2o`0000?ol[F:0ol00003omkcg@?o
000000?oOMoho`000?oD_L@01OoD_L@00ol0003of<72omS1`P03omS1`P03o`000?oDaL_oe<G;00Go
e<G;00Co0000omO9c?oGbLco00000ooBbM400ol0003oe<cBomC<dP03omC<dP03o`000?oFcm?o0000
00?ocloH00?o0000om3Af_o@dMX00oo@dMX2o`0000KocM;N00Co0000olcDh?o<e>3o00000oo8d^82
o`0000Cob=CS0ol000001?oja8co0000o`000?oocGl4o`0003Wooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0Aooooo`00:_ooool00ol0003oooooooooo`1Tooooo`04o`000?nY_NSo
ZKgXojVmj0?o00001_nY_NP00ol0003oZKgXo`000002o`0000;oZKgX00?o0000ojVmj?nY_NP00onY
_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP00_nY_NP00ol0003oQYkSohJN
h`02ohJNh`03o`000?o=^/SocK[800;ocK[800Go0000on:m/_oR_K;oh[fbo`000003onZmYP05o`00
0?o^_9kok[bNonjlW_l000000_o`_9T01Ol0003ol[fGoo:mUoob_IOo000000?ol[F:00?o0000oo6c
R_oa/hX01?l00004oggOn003o`000?oD_LCoe;g400;oe;g400?o0000omS1`_oH`L801?oH`L800ol0
003oe<G;omC5b`04omC5b`03o`000?oGbLcoelW<00;oelW<00?o0000om;9dOl000001OoDc=801ol0
003oe/oComK?dooFcm?o0000olo?f?l000001Oo@dMX01?l0003od=CKom3Dfol00003olgBgP;o0000
1?o<e>000ol0003ob=;Ro`000005olSDh`04o`000?o8e^Cob=KTolSFi0?o000000?ooleoo`000?oo
ool0>oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo017ooooo000[ooooo`;o0000
IOooool3o`0000?oZKgX00?o0000ojVmj?nY_NP00onY_NP2o`0000KoZKgX00Co0000ojVmj?nY_NSo
ZKgX1?l00006ojVmj004o`000?nY_NSoZKgXojVmj0;o00000_n6W^<00ol0003ocK[8olfjb002olfj
b003o`000?oR_K;oh[fb00;oh[fb00Co0000onZmY_oZ_JKo00000oo^_9h01Ol0003ol;bIoo2lVOo`
_9Wo000000?ol[fG0_l00002oo:eRP05o`000?oa/h[olK>:oo6cR_l000000_o`/HX3o`0000;oOMoh
00Co0000omBma?oD_LCo00001_oH`L800ol0003oflC2o`000004omC5b`03o`000?oGbLcoelW<00?o
elW<0_l00005omC<dP03o`000?oFcm?oe/oC00?oe/oC00?o0000om3Af_o@dMX00oo@dMX00ol0003o
d=CKom3Df`02om3Df`03o`000?o=d]ko000000Koc=CP0_l00005olSDh`03o`000?o8e^Cob=KT00;o
b=KT0_l00002ooo=O`03o`000?oooooooooo03_ooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Aooooo`00;Oooool00ol0003oooooooooo`1Sooooo`03o`000?nY_NSoZKgX00?oZKgX
00?o0000ojVmj?l000000_l00002ojVmj003o`000?nY_NSoZKgX00?oZKgX1?l00004ojVmj003o`00
0?nY_NSoZKgX00?oZKgX1?l000001?nY_NSo0000ohJNhol00005olfjb005o`000?oR_K;oh[fbon:m
/_l000000ooZ_JH01Ol0003ok[bNonjlW_o^_9ko000000?ol;bI00Wo0000oo:mUoob_IOol[fGo`00
0?oc_YOo0000oo:eR_l000000ooa/hX01_l0003ol;6:oo2aR_o`/H[o0000oo2aR@?o000000?oe;g4
o`000?oH`L801OoH`L801Ol0003oflC2om_4`_oKa<;o000000;oe<G;00?o0000omO9c?oGbL`00ooG
bL`01?l0003ofLc=omW<cOl00003omC<dP03o`000?oFcm?oe/oC00?oe/oC00?o0000omKCeOl00000
0oo@dMX00ol0003od=CKom3Df`03om3Df`;o00001_o<e>001?l0003oc=KQolcFhOl00003olSDh`03
o`000?o8e^Cob=KT00;ob=KT0ol00002ooo=O`03o`000?oooooooooo03cooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Aooooo`00;_ooool00ol0003oooooooooo`1Sooooo`04o`00
0?nY_NSoZKgXojVmj0?o00001_nY_NP00ol0003oZKgXo`000002o`0000;oZKgX00?o0000ojVmj?nY
_NP01?nY_NP00ol0003oZKgXo`000002o`0000;oZKgX00Go0000ojVmj?nY_NSoZKgXo`000006olfj
b005o`000?oR_K;oh[fbon:m/_l000000ooZ_JH01Ol0003ok[bNonjlW_o^_9ko000000?ol;bI00Co
0000oo:mUoob_IOo00000ooc_YL2o`0000?olK>:00Go0000oo2aR_o`/H[ol;6:o`000003oo2aR@;o
00001ooH`L801ol0003oflC2om_4`_oKa<;o0000omC5bol000001OoGbL`00ol0003ofLc=omW<c@02
omW<c@03o`000?oDc=;o000000Goe/oC00Oo0000omKCeOoFdmGoe]?Eo`000?o@dM[o000000God=CK
00Co0000om3EgOo@eMgo00000oo<e>02o`0000Coc=KQ00?o0000olSDhol000001?o8e^@01?l0003o
cmSOo`000?l00002ooo=O`03o`000?oooooooooo03cooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0@ooooo`00;oooool00ol0003oooooooooo`1Sooooo`?o00000onY_NP00ol0003o
ZKgXojVmj003ojVmj0;o00001_nY_NP01?l0003oZKgXojVmj?nY_NP4o`0000KoZKgX00Co0000ojVm
j?nY_NSo00001Oo=^/P00ol0003oh[fbon:m/P02on:m/P05o`000?oZ_JKoj[fVonZmY_l000000oo^
_9h01?l0003ol;bIoo2lVOl00003oo:mU`03o`000?oc_YOolkjG00;olkjG00Go0000oo6cR_oa/h[o
lK>:o`000002oo2aRP03o`000?o`/HWol;6900;ol;690_l00006omS1`P03o`000?oKa<;oflC200?o
flC200?o0000omO9c?oGbL`00ooGbL`00ol0003ofLc=omW<c@04omW<c@03o`000?oFcm?oe/oC00?o
e/oC00?o0000omKCeOoFdmD00ooFdmD00ol0003od=CKom3Df`03om3Df`03o`000?o@eMgod=GM00;o
d=GM00?o0000olcDh?l000001_o<e^43o`0000?ob=KT00Go0000oloHgol0003om=2[o`000002ooo=
O`03o`000?oooooooooo03gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0@oooo
o`00<?ooool00ol0003oooooooooo`1Sooooo`03o`000?nY_NSoZKgX00?oZKgX00?o0000ojVmj?l0
00000_l00002ojVmj003o`000?nY_NSoZKgX00?oZKgX1?l00004ojVmj003o`000?nY_NSoZKgX00?o
ZKgX1Ol00004olfjb005o`000?oR_K;oh[fbon:m/_l000000ooZ_JH01Ol0003ok[bNonjlW_o^_9ko
000000?ol;bI00Go0000oo:mUoob_IOol[fGo`000004oo>nU`05o`000?oa/h[olK>:oo6cR_l00000
0_o`/HX00ol0003ol;69oo2aR@02oo2aR@03o`000?o]/8ko000000Cof<7200?o0000om_4`_oKa<80
1?oKa<82o`0000?oelW<00?o0000omW<cOoIc<d01OoIc<d2o`0000?oe/oC00?o0000omKCeOoFdmD0
0ooFdmD00ol0003oemKGo`000003om3Df`03o`000?o@eMgod=GM00?od=GM0_l00006olcFh@07o`00
0?o;f>?obmSSol_Hhol0003ob=KTo`000002oloHg`03o`000?odd:_o000000;ooleo00?o0000oooo
ooooool0?_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo013ooooo000aooooo`;o
0000I?ooool01?l0003oZKgXojVmj?nY_NP3o`0000KoZKgX00?o0000ojVmj?l000000_l00003ojVm
j003o`000?nY_NSoZKgX00?oZKgX00?o0000ojVmj?l000000_l00002ojVmj004o`000?nY_NSoZKgX
o`0000;ocK[800?o0000on:m/_oR_K800_oR_K801Ol0003oj[fVonZmY_oZ_JKo000000?ok[bN00Go
0000oo2lVOo`_9Wol;bIo`000003oo:mU`03o`000?oc_YOolkjG00;olkjG0_l00002oo6cRP04o`00
0?o`/H[ol;6:o`0000Col;6900Co0000onf`S_o]/8ko00000ooH`L800ol0003oflC2om_4`P03om_4
`P06o`000?oNb<?og/S3o`000?oGbLco00001ooIc<d01_l0003of]3?om[@col0003oe/oCo`0000Go
e]?E00Oo0000omOFeooGe]OoemKGo`000?o@e=_o000000God=GM00Co0000om7Ig_oAfMko00000oo<
e^42o`0000CobmSS0_l00002oloHg`06o`000?odd:_om=2[o`000?oocGoo0000@_ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo013ooooo000cooooo`03o`000?oooooooooo06;ooooo
0ol00003ojVmj003o`000?nY_NSoZKgX00?oZKgX0_l00007ojVmj004o`000?nY_NSoZKgXojVmj0?o
00001_nY_NP01_l0003oZKgXojVmj?l0003ocK[8o`0000Coh[fb00Go0000onZmY_oZ_JKoj[fVo`00
0003onjlWP05o`000?o`_9Wol;bIoo2lVOl000000oob_IL02Ol0003olkjGoo>nUooc_YOo0000oo?0
V?l0003olK>:o`000003oo2aRP05o`000?o`/HWol;69oo2aROl000001?o]/8h00ol0003of<72o`00
0005om_4`P03o`000?oNb<?og/S300;og/S300?o0000omW<cOoIc<d01OoIc<d00ol0003of]3?om[@
c`02om[@c`03o`000?oFdmGoe]?E00?oe]?E00?o0000omOFeooGe]L00ooGe]L00ol0003od=GMom3E
g@03om3Eg@03o`000?oAfMkodMWN00;odMWN00?o0000olcFhOl000001Oo;f><00ol0003ob]WTo`00
0002oloHg`06o`000?odd:_om=2[o`000?oocGoo0000@_ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo013ooooo000dooooo`03o`000?oooooooooo06;ooooo00?o0000ojVmj?nY_NP0
0onY_NP00ol0003oZKgXo`000002o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY_NP4o`0000?oZKgX
00?o0000ojVmj?nY_NP00onY_NP5o`0000Coh[fb00Go0000onZmY_oZ_JKoj[fVo`000003onjlWP03
o`000?o`_9Wol;bI00;ol;bI00Co0000oo:mUoob_IOo00001?oc_YL00ol0003oll2Hoo?0V002o`00
00?ol;6:00Go0000oo2aROo`/HWol;69o`000005onf`SP03o`000?oKa<;oflC200?oflC200?o0000
omk8`ooNb<<00ooNb<<2o`0000GofLc=00?o0000om[@cooJd<l00ooJd<l2o`0000?oe]?E00?o0000
omOFeooGe]L00ooGe]L00ol0003oemWIo`000003om3Eg@03o`000?oAfMkodMWN00?odMWN0ol00003
ol_Hh`;o00000oo:fN@01Ol0003ocmSOo`000?odd:_o000000;ooleo00?o0000ooooooooool0@Ooo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo013ooooo000eooooo`03o`000?oooooo
oooo06;ooooo00Co0000ojVmj?nY_NSoZKgX1?l00005ojVmj003o`000?nY_NSoZKgX00?o00000_nY
_NP00ol0003oZKgXojVmj003ojVmj003o`000?nY_NSo000000;o00000_nY_NP00ol0003oZKgXo`00
0004on:m/P05o`000?oZ_JKoj[fVonZmY_l000000oo^_9h01Ol0003ol;bIoo2lVOo`_9Wo000000?o
l[fG00?o0000oo>nUooc_YL00_oc_YL00ol0003oll2Hoo?0V002o`0000?ol;6:00Go0000oo2aROo`
/HWol;69o`000005onf`SP03o`000?oKa<;oflC200?oflC200?o0000omk8`ooNb<<00_oNb<<01?l0
003ohLc4on7<a?l00003omW<c@03o`000?oJd<oof]3?00?of]3?00Ko0000omcDd?oLe=3o0000omKC
eOl00005omOFe`07o`000?oGfMWoemWIomOIfOl0003od=GMo`000005om7IgP07o`000?o@fn7od=_Q
om3KhOl0003obmSSo`000005ol[Ii0?o000000?om=2[o`000?oocGl00_l00014ooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool04?ooool003Kooooo0_l0001Sooooo`?o00001?nY_NP0
0ol0003oZKgXojVmj002ojVmj0?o00001_nY_NP01?l0003oZKgXojVmj?nY_NP3o`0000KoZKgX00?o
0000ojVmj?l000000_oR_K800ol0003oj[fVonZmYP02onZmYP05o`000?o^_9kok[bNonjlW_l00000
0oo`_9T01Ol0003ol[fGoo:mUoob_IOo000000ColkjG00?o0000oo?0V?oc`9P00_l00003oo2aRP05
o`000?o`/HWol;69oo2aROl000001Oo]/8h2o`0000?oflC200?o0000omk8`ooNb<<00_oNb<<00ol0
003ohLc4on7<a002on7<a003o`000?oIc<go000000Gof]3?00?o0000omcDd?oLe=000_oLe=000ol0
003oemKGomOFe`03omOFe`03o`000?oGfMWoemWI00;oemWI0_l00005om7IgP03o`000?o@fn7od=_Q
00;od=_Q0_l00005ol[Ii004o`000?o:fnKob]_Vol[KiP?o000000?obmcVo`000?ooool0A?ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00oooooo000hooooo`03o`000?oooooooooo
06;ooooo00?o0000ojVmj?nY_NP00onY_NP01?l0003oZKgXo`000?l00003ojVmj003o`000?nY_NSo
ZKgX00?oZKgX1?l00003ojVmj003o`000?nY_NSoZKgX00?oZKgX0_l000001?nY_NSo0000on:m/_l0
0004onZmYP05o`000?o^_9kok[bNonjlW_l000000oo`_9T01Ol0003ol[fGoo:mUoob_IOo000000?o
lkjG00?o0000oo?0V?oc`9P00_oc`9P01Ol0003ol;6:oo2aR_o`/H[o000000?ol;6900?o0000onf`
S_o]/8h00oo]/8h01Ol0003ojK2Go`000?oKa<;o000000Gog/S300?o0000on7<a?oQc<@00ooQc<@0
0ol0003of]3?om[@c`03om[@c`03o`000?oLe=3og=C@00?og=C@0_l00003omOFe`03o`000?oGfMWo
emWI00;oemWI00Co0000omKKg?oFfmco00000ooAfMh00ol0003od=_Qom3Kh@02om3Kh@03o`000?o?
g>;o000000?ob]WT0_l00004ol[KiP;o000000?obmcVo`000?ooool0AOooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo00oooooo000iooooo`03o`000?oooooooooo06;ooooo00Co0000
ojVmj?nY_NSoZKgX1?l00005ojVmj003o`000?nY_NSo000000;o00000_nY_NP00ol0003oZKgXojVm
j003ojVmj003o`000?nY_NSo000000;o00000_nY_NP2o`000003on:m/_l0003oj[fV00;oj[fV00Go
0000onjlW_o^_9kok[bNo`000004oo2lV@05o`000?ob_IOol[fGoo:mUol000000ooc_YL00ol0003o
ll2Hoo?0V002oo?0V005o`000?o`/H[ol;6:oo2aR_l000000oo`/HT00ol0003okK2>onf`SP02onf`
SP05o`000?oY/9OojK2GonV`Uol000001OoNb<<00ol0003ohLc4on7<a004on7<a0;o00000ooJd<l0
0ol0003og=C@omcDd003omcDd006o`000?oLf=;og=SBo`000?oGe]Oo00001?oGfMT00ol0003oe]_L
omKKg002omKKg003o`000?oAfMko000000Cod=_Q00Oo0000oloLh_o?g>;ocmcRo`000?o:fNCo0000
00Gob]_V00?o0000ol_Li_o;g>H00_l00017ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool03oooool003[ooooo00?o0000ooooooooool0H_ooool3o`0000CoZKgX00Co0000ojVmj?nY
_NSoZKgX0ol00006ojVmj004o`000?nY_NSoZKgXojVmj0Co00001OnY_NP2o`0000Coj[fV00Go0000
onjlW_o^_9kok[bNo`000004oo2lV@04o`000?ob_IOol[fGo`0000ColkjG00?o0000oo?0V?oc`9P0
0_oc`9P2o`0000;ol;6:00Go0000oo2aROo`/HWol;69o`000004onf`SP05o`000?oY/9OojK2GonV`
Uol000001?oNb<<00ol0003ohLc4on7<a004on7<a006o`000?oSd<Gohm35o`000?oJd<oo00001OoL
e=000ol0003og=SBomcHdP02omcHdP;o00000ooGfMT00ol0003oe]_LomKKg003omKKg0?o00000oo@
fn400ol0003ocmcRoloLhP02oloLhP?o00000oo:fnH2o`0000;obmcV0ol00018ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool03oooool003_ooooo0_l0001Sooooo`03o`000?nY_NSo
ZKgX00?oZKgX1?l00003ojVmj003o`000?nY_NSoZKgX00?oZKgX1?l00004ojVmj004o`000?nY_NSo
ZKgXojVmj0Co00000ooZ_JH01Ol0003ok[bNonjlW_o^_9ko000000?ol;bI00Go0000oo:mUoob_IOo
l[fGo`000004oo>nU`09o`000?oc`9Soll2Hoo?0V?l0003oll>Mo`000?o`/H[o000000Col;6900?o
0000onf`S_o]/8h00_o]/8h01?l0003ojK2GonV`UooY/9L2o`0000?og/S300?o0000on7<a?oQc<@0
0ooQc<@00ol0003ohm35on?@a@02on?@a@03o`000?oLe=3og=C@00?og=C@00?o0000omcHd_oLf=80
0_oLf=801_l0003og=SDomcHe?l0003oemWIo`0000Goe]_L00Oo0000omGNg_oEg]koeMkNo`000?o@
fn7o000000CocmcR00Oo0000olkNiOo>g^Goc]kUo`000?o:fnKo000000CobmcV0ol00018ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool03oooool003gooooo00?o0000ooooooooool0
HOooool00ol0003oZKgXo`000002o`0000;oZKgX00?o0000ojVmj?nY_NP00onY_NP00ol0003oZKgX
o`000002o`0000;oZKgX00?o0000ojVmj?nY_NP00onY_NP4o`0000;oZKgX00?o0000ojVmj?l00000
0_oZ_JH01Ol0003ok[bNonjlW_o^_9ko000000?ol;bI00Go0000oo:mUoob_IOol[fGo`000003oo>n
U`03o`000?oc`9Soll2H00;oll2H00?o0000oo?3WOoc`id00_l00003oo2aR@03o`000?o]/8kokK2>
00?okK2>00Wo0000onV`UooY/9OojK2Go`000?nSO:Wo0000omk8`ol000001OoQc<@00ol0003ohm35
on?@a@03on?@a@;o00000ooLe=000ol0003og=SBomcHdP02omcHdP03o`000?oLf=Cog=SD00;og=SD
00?o0000omKKg?oFfm`00ooFfm`00ol0003oeMkNomGNgP02omGNgP?o00000oo?g>800ol0003oc]kU
olkNi@02olkNi@?o00000oo;g>H01?l0003oj=c8o`000?l00019ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool03oooool003kooooo00?o0000ooooooooool0HOooool00ol0003oZKgX
ojVmj004ojVmj004o`000?nY_NSoZKgXojVmj0?o00001_nY_NP00ol0003oZKgXo`000002o`000003
ojVmj?l0003oZKgX00CoZKgX00Co0000ojVmj?l0003o00000oo^_9h00ol0003ol;bIoo2lV@02oo2l
V@05o`000?ob_IOol[fGoo:mUol000000ooc_YL00ol0003oll2Hoo?0V002oo?0V003o`000?oc`igo
ll>M00;o00000oo`/HT00ol0003okK2>onf`SP03onf`SP03o`000?oY/9OojK2G00;ojK2G00Co0000
oj=lZOl0003o00001OoQc<@00ol0003ohm35on?@a@02on?@a@06o`000?oTe<Koi=C6o`000?oLe=3o
00001?oLf=800ol0003og=SDomcHe003omcHe0;o00000ooFfm`00ol0003oeMkNomGNgP02omGNgP07
o`000?oDg]ooe=kOomCNgol0003ocmcRo`000004olkNi@08o`000?o<g^Koc=kVolcNi_l0003obmcV
o`000?oXg<P2o`0004_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0?ooooo`00
?oooool00ol0003oooooooooo`1Qooooo`03o`000?nY_NSoZKgX00?oZKgX1?l00003ojVmj003o`00
0?nY_NSoZKgX00?oZKgX0_l00005ojVmj004o`000?nY_NSoZKgXojVmj0?o000000?oZKgXo`000?o^
_9h00_o^_9h00ol0003ol;bIoo2lV@02oo2lV@04o`000?ob_IOol[fGo`0000ColkjG00?o0000oo?0
V?oc`9P00_oc`9P00ol0003oll>Moo?3W@02o`0000?ol;6900?o0000onf`S_o]/8h00_o]/8h00ol0
003ojK2GonV`U`03onV`U`03o`000?nSO:Wo000000;o00000ooQc<@00ol0003ohm35on?@a@02on?@
a@03o`000?oTe<Koi=C600;oi=C60_l00003omcHdP03o`000?oLf=Cog=SD00?og=SD00Ko0000omkN
e_oNg]Ko0000omKKg?l00004omGNgP03o`000?oDg]ooe=kO00;oe=kO0_l00003olkNi@;o00001?o<
g^H3o`000003onSLb?l0003o000004cooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0>ooooo`00@?ooool2o`0006;ooooo00?o0000ojVmj?l000000_l00002ojVmj003o`000?nY_NSo
ZKgX00?oZKgX00?o0000ojVmj?l000000_l000000onY_NSo0000ojVmj004ojVmj0Co00000onY_NP2
o`0000?ok[bN00?o0000oo2lVOo`_9T00_o`_9T01?l0003ol[fGoo:mUol00003oo>nU`03o`000?oc
`9Soll2H00;oll2H00?o0000oo?3WOoc`id00_oc`id01Ol0003ol;69oo2aROo`/HWo000000CokK2>
00?o0000onV`UooY/9L00ooY/9L2o`0000?oXH2`00?o0000on7<a?l000001?oSd<D00ol0003oi=C6
onCDaP03onCDaP05o`000?oVfLSo0000omcHd_l000001OoLf=@00ol0003og]kFomkNeP02omkNeP;o
00000ooEg]h00ol0003oe=kOomCNg`02omCNg`06o`000?oChN;odn7Ro`000?o>g^Go00001Oo<g^H0
1?l0003obn3Xol_Pj?o;h>P3o`0004cooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0>ooooo`00@_ooool00ol0003oooooooooo`1Pooooo`03o`000?nY_NSoZKgX00CoZKgX00Co0000
ojVmj?nY_NSoZKgX1?l00004ojVmj003o`000?nY_NSo000000;o00000_nY_NP00ol0003oZKgXojVm
j003ojVmj0;o00000_o^_9h01Ol0003ol;bIoo2lVOo`_9Wo000000?ol[fG00Go0000oo>nUooc_YOo
lkjGo`000004oo?0V003o`000?oc`igoll>M00;oll>M00Go0000oo2aROo`/HWol;69o`000004onf`
SP03o`000?oY/9OojK2G00?ojK2G00?o0000oj60/?nQP;000onQP;000ol0003ohm35on?@a@03on?@
a@03o`000?oTe<Koi=C600;oi=C600Go0000onKIb?oVfLSoi]W8o`000005omcHe003o`000?oNg]Ko
g]kF00;og]kF00Ko0000omgQf?oMhMSo0000omGNg_l00004omCNg`04o`000?oChN;odn7Rom?QhP?o
00000oo<g^H2o`0000Cobn3X0_l0001>ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool03_ooool004?ooooo00?o0000ooooooooool0H?ooool00ol0003oZKgXojVmj003ojVmj0Co0000
1?nY_NP00ol0003oZKgXojVmj003o`0000KoZKgX00Co0000ojVmj?nY_NSoZKgX1Ol00004oo2lV@05
o`000?ob_IOol[fGoo:mUol000000ooc_YL00ol0003oll2Hoo?0V002oo?0V007o`000?oc`igoll>M
oo?3WOl0003ol/VUo`000002oo2aR@03o`000?o]/8kokK2>00;okK2>00?o0000onV`UooY/9L00ooY
/9L00ol0003oXH2`oj60/003oj60/0;o00000ooSd<D00ol0003oi=C6onCDaP02onCDaP03o`000?oV
fLSoi]W800;oi]W80_l00003omcHe003o`000?oNg]Kog]kF00;og]kF00?o0000omgQf?oMhMP00_oM
hMP2o`0000?oe=kO00Go0000om?Qh_oChN;odn7Ro`000003om7Si003o`000?o<g^Ko000000Gobn3X
0ol0001?ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03_ooool004Cooooo00?o
0000ooooooooool0H?ooool00ol0003oZKgXo`000002o`0000;oZKgX00?o0000ojVmj?nY_NP00onY
_NP3o`0000?oZKgX00?o0000ojVmj?nY_NP00onY_NP4o`0000CoZKgX00?o0000oo2lVOo`_9T00_o`
_9T01Ol0003ol[fGoo:mUoob_IOo000000?olkjG00?o0000oo?0V?oc`9P00_oc`9P01ol0003oll>M
oo?3WOoc`igo0000oo;9YOl000000_o`/HT00ol0003okK2>onf`SP02onf`SP03o`000?oY/9OojK2G
00;ojK2G00?o0000onB_W_l000001OnQP;02o`000003on?@aOl0003oi=C600?oi=C600?o0000onKI
b?oVfLP00_oVfLP01_l0003oi]g;onKMbol0003og=SDo`0000Cog]kF00?o0000omgQf?oMhMP00_oM
hMP01_l0003og>CKomcTfol0003oe=kOo`0000?odn7R00?o0000om7Si?oAhn@00_oAhn@3o`0000?o
bn3X0_l000000oo;h>So0000o`00001@ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool03_ooool004Gooooo00?o0000ooooooooool0H?ooool2o`0000GoZKgX00?o0000ojVmj?l00000
0_l000000onY_NSo0000ojVmj004ojVmj003o`000?nY_NSo000000;o00000_nY_NP00ol0003oZKgX
ojVmj003ojVmj0;o00000oo`_9T01?l0003ol[fGoo:mUol00003oo>nU`03o`000?oc`9Soll2H00;o
ll2H00?o0000oo?3WOoc`id00_oc`id00ol0003ol/VUo`000002oo2aR@05o`000?o]/8kokK2>onf`
S_l000001OoY/9L00ol0003oi:nNo`000005oj60/003o`000?l0=kgo000000Goi=C600Go0000onKI
b?oVfLSoi]W8o`000004onKMb`;o00000ooNg]H00ol0003ogN7HomgQf002omgQf004o`000?oLi=_o
g>CKomcTf`;o00000ooChN800ol0003odN?Tom7Si002om7Si007o`000?o?hnKocn?VoloSi_l0003o
bn3Xo`000003ol_Pj0;o0000D?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00ko
oooo0016ooooo`;o0000H_ooool01?l0003oZKgXojVmj?nY_NP3o`0000GoZKgX00Co0000ojVmj?nY
_NSoZKgX1?l00005ojVmj003o`000?nY_NSo000000;o00000_nY_NP01?l0003ol;bIoo2lVOl00002
oo:mU`05o`000?oc_YOolkjGoo>nUol000001?oc`9P01Ol0003oll>Moo?3WOoc`igo000000?ol/VU
0_l00004onf`SP03o`000?oY/9OojK2G00?ojK2G00?o0000onB_W_l000001_nQP;000ol0003o03Nm
o`000003onCDaP05o`000?oVfLSoi]W8onKIb?l000001OoVgL/01Ol0003oiN;?o`000?oNg]Ko0000
00CogN7H00Go0000omcTfooLi=_og>CKo`000002omWVgP03o`000?oChN;o000000CodN?T00?o0000
oloSi_o?hnH00_o?hnH3o`0000;obn3X00?o0000ooCK]?l00000DOooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00kooooo0018ooooo`03o`000?oooooooooo063ooooo0ol00003ojVm
j003o`000?nY_NSoZKgX00;oZKgX1?l00004ojVmj004o`000?nY_NSoZKgXojVmj0?o00001_nY_NP2
o`0000?ol[fG00Go0000oo>nUooc_YOolkjGo`000004oo?0V005o`000?oc`igoll>Moo?3WOl00000
0oobbJD2o`0000CokK2>00?o0000onV`UooY/9L00ooY/9L00ol0003oi:nNo`000006oj60/006o`00
0?l0=kgo03Nmo`000?oTe<Ko00001?oVfLP00ol0003oi]g;onKMb`02onKMb`04o`000?oUh/ooiN;?
onGRc`;o00000ooMhMP01Ol0003og>CKomcTfooLi=_o000000CofNKN0_l00003om7Si003o`000?o?
hnKocn?V00;ocn?V00Ko0000olgSj?o=hnSocN?Xo`000?o;h>P2o`0005?ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0=ooooo`00BOooool00ol0003oooooooooo`1Pooooo`03o`00
0?nY_NSoZKgX00?oZKgX00Co0000ojVmj?l0003o00000_nY_NP00ol0003oZKgXojVmj003ojVmj0Co
00000onY_NP00ol0003oZKgXojVmj003ojVmj0;o00000oob_IL01Ol0003olkjGoo>nUooc_YOo0000
00?oll2H00?o0000oo?3WOoc`id00_oc`id01?l0003ol/VUoo;9YOobbJD2o`0000CokK2>00?o0000
onV`UooY/9L00_oY/9L01Ol0003oi:nNonB_W_oT[iko000000GoXH2`1_l00003onKIb003o`000?oV
gL_oi]g;00;oi]g;00?o0000onGRcooUh/l00_oUh/l01Ol0003oi>GBo`000?oMhMSo000000?og>CK
00?o0000omWVg_oIi]h00_oIi]h01_l0003oenOQomOWhOl0003odN?To`0000Cocn?V00?o0000olgS
j?o=hnP00_o=hnP2o`000003ooCK]?l0003ooooo05?ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`00B_ooool00ol0003oooooooooo`1Pooooo`04o`000?nY_NSoZKgXojVm
j0?o00001OnY_NP00ol0003oZKgXo`000002o`0000;oZKgX00?o0000ojVmj?nY_NP00onY_NP00ol0
003oZKgXo`000002o`0000;oZKgX00Co0000oo:mUoob_IOo00000_oc_YL00ol0003oll2Hoo?0V002
oo?0V005o`000?oc`igoll>Moo?3WOl000001OobbJD00ol0003okK2>onf`SP02onf`SP03o`000?oY
/9OojK2G00;ojK2G00Go0000onB_W_oT[ikoi:nNo`000005oj60/0;o00000_mHNMP3o`000003onKI
b?l0003oi]g;00?oi]g;00?o0000onGRcooUh/l00_oUh/l01?l0003oi>GBonCUd_oTiM83o`000003
omcTfol0003ofNKN00?ofNKN00Co0000omOWhOoGin7oenOQ0ol00003oloSiP03o`000?o=hnSocN?X
00;ocN?X00?o0000ol_Tj_o;i>X00_l0001Dooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool004_ooooo0_l0001Qooooo`?o00000onY_NP01?l0003oZKgXojVmj?nY_NP3o`00
00KoZKgX00Co0000ojVmj?nY_NSoZKgX1?l00005ojVmj0;o00000ooc_YL00ol0003oll2Hoo?0V002
oo?0V005o`000?oc`igoll>Moo?3WOl000001OobbJD01Ol0003okK2>onf`S_o]/8ko000000GojK2G
00Go0000onB_W_oT[ikoi:nNo`000005oj60/003o`000?l007?o000000CoF7WH0_l00003onKMb`03
o`000?oUh/ooiN;?00;oiN;?00Go0000onCUd_oTiM;oi>GBo`000003on;Ue@;o00000ooIi]h01Ol0
003oenOQomOWhOoGin7o000000?oe>KS00?o0000oloSi_l000000oo=hnP2o`0000?obnCZ0_l0001E
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool004gooooo00?o0000oooo
ooooool0Goooool00ol0003oZKgXojVmj002ojVmj0Co00000onY_NP00ol0003oZKgXojVmj003ojVm
j0Co00001?nY_NP01?l0003oZKgXojVmj?nY_NP3o`0000?olkjG00?o0000oo?0V?oc`9P00_oc`9P0
1Ol0003oll>Moo?3WOoc`igo000000Col/VU00?o0000onoB]?l000000_o]/8h00ol0003ojK2GonV`
U`03onV`U`05o`000?oT[ikoi:nNonB_W_l000001_nQP;02o`0000KoF7WH00?o0000onKMbol00000
1?oUh/l01Ol0003oi>GBonCUd_oTiM;o000000Coh^GE00Go0000on7Zf?l0003ofNKNo`000003omOW
h@03o`000?oDi^?oe>KS00;oe>KS1?l000000oo=hnSo0000ol_TjP03ol_TjP;o0000Eoooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo001>ooooo`03o`000?oooooooooo05oo
oooo00Co0000ojVmj?l0003o00000_nY_NP00ol0003oZKgXojVmj003ojVmj003o`000?nY_NSo0000
00;o00000_nY_NP00ol0003oZKgXojVmj003ojVmj0Co00000oooool01?l0003olkjGoo>nUol00003
oo?0V005o`000?oc`igoll>Moo?3WOl000001OobbJD00ol0003okm:do`000002onf`SP03o`000?oY
/9OojK2G00;ojK2G00?o0000onB_W_oT[ih00_oT[ih00ol0003oXH2`oj60/003oj60/0Co00001OmH
NMP3o`0000?oiN;?00Go0000onCUd_oTiM;oi>GBo`000004on;Ue@05o`000?oQj]SohN[Hon7Zf?l0
00000ooGin400ol0003oe>KSomCVh`02omCVh`04o`000?oBj>God^SUom;Xi@;o00000oo;i>X3o`00
05Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`00Coooool00ol0003o
ooooooooo`1Oooooo`03o`000?nY_NSoZKgX00?oZKgX00Co0000ojVmj?nY_NSoZKgX1?l00005ojVm
j003o`000?nY_NSo000000;o00002?ooool2o`0000Coll2H00Go0000oo?3WOoc`igoll>Mo`000004
oo;9Y@04o`000?o_d[Cokm:do`0000;okK2>00?o0000onV`UooY/9L00_oY/9L00ol0003oi:nNonB_
WP03onB_WP03o`000?nQP;3o000000;o000000CoXHFfo`000?l007?o00000_mHNMP3o`0000?oXIkB
00?o0000onGRcol000000ooTiM800ol0003oh^GEon;Ue@02on;Ue@09o`000?oQj]SohN[Hon7Zf?l0
003ogncKo`000?oGin7o000000?oe>KS0_l00003om;Xi@06o`000?o?j>SocnSXo`000?o;i>[o0000
0_o@i>H00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
3Oooool0053ooooo0_l0001Pooooo`03o`000?nY_NSoZKgX00;oZKgX1?l00004ojVmj004o`000?nY
_NSoZKgXojVmj0?o00003?ooool2o`0000?oll2H00Go0000oo?3WOoc`igoll>Mo`000004oo;9Y@07
o`000?o_d[Cokm:donoB]?l0003okK2>o`000004onV`U`03o`000?oT[ikoi:nN00?oi:nN0_l00004
oj65]PGo00001onQW]83o`000003onCUd_l0003oh^GE00?oh^GE00Go0000on7Zf?oQj]SohN[Ho`00
0003omo/f`?o000000?oe>KSo`000?oBj>D00ooBj>D01?l0003ocnSXoloXj?o?j>P3o`0000;od>CV
00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo
001Booooo`03o`000?oooooooooo05kooooo00Co0000ojVmj?l0003o00000_nY_NP00ol0003oZKgX
ojVmj003ojVmj0Co00004Oooool01?l0003oll2Hoo?0V?l00002oo?3W@03o`000?obbJGol/VU00;o
l/VU00?o0000onoB]?o_d[@00_o_d[@2o`0000CojK2G00?o0000onB_W_oT[ih01?oT[ih00ol0003o
XHFfoj65]P04oj65]P?o00001onQW]801?l0003odLG>om75c_oAaLh2o`0000?oh^GE00Go0000on7Z
f?oQj]SohN[Ho`000003omo/f`04o`000?oKkMkofngNom_]gP;o00000ooBj>D01Ol0003ocnSXoloX
j?o?j>So000000?oc>OZ0ol0001Kooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
3?ooool005?ooooo00?o0000ooooooooool0G_ooool00ol0003oZKgXojVmj003ojVmj003o`000?nY
_NSo000000;o00005_ooool2o`0000?oll>M00?o0000oo;9YOobbJD00_obbJD00ol0003okm:donoB
]002onoB]0;o00001?oY/9L00ol0003oi:nNonB_WP04onB_WP03o`000?nQQKKoXHFf00CoXHFf1?l0
0005oj6NdP03o`000?oAaLkodLG>00;odLG>00Go0000ong[bOl0003oh^GEo`000003on7Zf005o`00
0?oOk=_ogncKomo/fol000000ooKkMh01_l0003oencRomO/h_l0003od^SUo`0000?ocnSX00?o0000
olcWj_o<inX00_o<inX3o`0005_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<
ooooo`00E?ooool00ol0003oooooooooo`1Nooooo`04o`000?nY_NSoZKgXojVmj0?o00006_ooool2
o`0000;oll>M00Go0000oo;9YOobbJGol/VUo`000005onoB]0;o00001?oY/9L00ol0003oi:nNonB_
WP03onB_WP03o`000?oV^:Go000000GoXHFf1?l00004oj6NdP03o`000?oAaLkodLG>00;odLG>00Co
0000ong[bOo]jlWokN_90ol000000ooQj]So0000omo/f`02omo/f`05o`000?oKkMkofngNom_]g_l0
00000ooGk>84o`000003oloXj?l0003oc>OZ00;oc>OZ0ol000000oofh;?o0000ooooo`1Kooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool03?ooool005Gooooo0_l0001Oooooo`?o0000
7oooool2o`0000Col/VU00?o0000onoB]?o_d[@00_o_d[@00ol0003ogN;Ho`000004onV`U`03o`00
0?oT[ikoi:nN00?oi:nN00?o0000onJhYOl000001_nQQKH4o`0000;oXIkB00?o0000om75c_oAaLh0
0_oAaLh00ol0003okN_9ong[b@02ong[b@03o`000?oYkloojNo?00?o000000?ogncKo`000?oKkMh0
0_oKkMh01Ol0003oencRomO/h_oGk>;o000000?oeNgU0ol000000oo<in[o0000o`000002olWWk0;o
0000G_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00cooooo001Gooooo`03o`00
0?oooooooooo05cooooo00?o0000ooooooooool08?ooool2o`0000;ol/VU00?o0000onoB]?o_d[@0
0_o_d[@01Ol0003ogN;HomgRf?oMh]So000000;ojK2G00?o0000onB_W_oT[ih01?oT[ih00ol0003o
i[RUo`000006oj65]PCo000000?oXIkBo`000?oAaLh00ooAaLh00ol0003okN_9ong[b@02ong[b@05
o`000?oYkloojNo?onW_col000000_oUlM@3o`000004om_]g_l0003oencRomO/hP;o00000ooEkND0
1?l0003odNgWom7]iooAkNL2o`0000;obNO/00?o0000ooKP/ol00000Goooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00cooooo001Hooooo`03o`000?oooooooooo05_ooooo00?o0000
ooooooooool08_ooool00ol0003ol/VUo`000003onoB]003o`000?oMh]SogN;H00;ogN;H00Co0000
onV`UooY/9Oo00001OoT[ih01Ol0003oi[RUonJhYOoV^:Go000000GoXHFf00Go0000o`02T?l0003o
33>co`000005om75cP05o`000?o]jlWokN_9ong[bOl000000ooYkll01?l0003oiO7DonGae?l00003
on;_f@;o000000?oencRo`000?oEkND00_oEkND2o`0000?odNgW00So0000olg[j_o=jn[o0000olWW
k?l0003om^2co`0005oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<ooooo`00
FOooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo02?ooooo0ol000000oo_d[Co0000
omgRf005omgRf003o`000?oY/9Oo000000Goi:nN00Go0000onJhYOoV^:Goi[RUo`000005oj65]P06
o`000?l00Y3o0000o`000?l<<k?o00000ooAaLh01Ol0003okN_9ong[bOo]jlWo000000?ojNo?00Co
0000onGae?oUlMCo00000ooRkmT00ol0003ogo;Komobf`03o`000003omG]iOl0003odNgW00?odNgW
00Co0000olg[j_o=jn[ocN_Z1Ol0001Pooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02oooool005[ooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Vooooo`;o0000
1_oMh]P00ol0003ojK2Go`000005onB_WP05o`000?oV^:Goi[RUonJhYOl000001_nQQKH00ol0003o
00:@o`000002o``c/`03o`000?oAaLko000000?okN_900Go0000onW_cooYkloojNo?o`000002onGa
e005o`000?oRkmWoh^oIon;_fOl000000ooOl]/00ol0003of_?Po`000002o`0000?odNgW00Go0000
olg[j_o=jn[ocN_Zo`000002ol_[k003o`000?oooooooooo067ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0;ooooo`00Foooool2o`0005Wooooo00?o0000ooooooooool0:?ooool2
o`0000CogN;H0_l00005onB_WP03o`000?oV^:Goi[RU00;oi[RU00?o0000oj65]_nQQKH00onQQKH2
o`000003o`02T?l0003o33>c00;o33>c0ol000000oo]jlWo0000onW_c`02onW_c`04o`000?oUlMCo
iO7Do`0000?oh^oI00Oo0000omobfooOl]_ogo;Ko`000?oJln3o000000?oe_7T00?o0000om7]iol0
00000_o=jnX2o`0000;obn_/0_l0001Sooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool02oooool005gooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0Zooooo`Ko0000
1OoT[ih00ol0003oi[RUonJhY@03onJhY@03o`000?nQQKKo000000;o000000CoXXZko`000?l00Y3o
00:@2Ol000001OoYkloo0000onGae?oUlMCo000000?oh^oI00Oo0000omobfooOl]_ogo;Ko`000?oJ
ln3o000000Coe_7T0ol000000oo=jn[o0000ol_[k002ol_[k0;o0000IOooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00_ooooo001Nooooo`03o`000?oooooooooo05Gooooo00?o0000
ooooooooool0;Oooool00ol0003oDKcjo`000005onB_WP03o`000?oV^:Goi[RU00?oi[RU0_l00005
oj::^`03o`000?l00Y3o000000SoT8[91_l000000ooRkmWo0000omobf`02omobf`03o`000?oJln3o
000000Coe_7T00?o0000om?ai_oClNH01?l000001?o;jnco0000om?bi_l0001Vooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02oooool005oooooo00?o0000ooooooooool0E?ooool0
0ol0003oooooooooo`0^ooooo`03o`000?mA_?[o000000Coi:nN00?o0000onJhYOoV^:D00ooV^:D0
0ol0003oXXZkoj::^`04oj::^`;o000000?o00:@o`000?n@R/T01_n@R/T01?l0003oiNKAonGVdOl0
0002on_fb@?o000000Cogo;Ko`000?oJln3o00000ooFlN@2o`0000;odo7V00Co0000olk`j_o>l>[o
c_3Z1Ol0001Wooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool0063ooooo
0_l0001Dooooo`03o`000?oooooooooo02oooooo0_l00003onB_WP03o`000?oV^:Goi[RU00?oi[RU
00?o0000ooOR/_l000001OnRR[/2o`000003o`02T?l0003oT8[900GoT8[900Co0000onGVdOoUi]7o
00000oo[m/T00ol0003oiOSBonGhdP05o`000003omKai?l0003odo7V00;odo7V00Go0000olk`j_o>
l>[oc_3Zo`000003ol_]k0;o0000Ioooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00_ooooo001Rooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0<?ooool2o`0000;o
i:nN00?o0000onJhYOoV^:D00ooV^:D00ol0003omn:bo`000006oj::^`?o00001On@R/T01?l0003o
iNKAonGVdOl00003on_fb@04o`000?oUn=;oiOSBo`0000;ohOKI00?o0000omghg?l000000ol00000
1?oClNKo0000olk`j_o>l>X2o`0000?obng/00?o0000ooooooooool0J?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00[ooooo001Sooooo`03o`000?oooooooooo053ooooo00?o0000
ooooooooool0<Oooool2o`000003onB_W_l0003oi[RU00Coi[RU00?o0000ooOR/_l000001_nRR[/0
1?l0003o1BJXo`000?l00003oi2:b@04o`000?oUi]7oiNKAo`0000?ojoK900Co0000onGhd_oUn=;o
00000_oQm]T00ol0003ogOSLo`000003omOfhP?o000000?oc_3Zo`000?o;kN`00_o;kN`2o`0006co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`00I?ooool00ol0003ooooo
ooooo`1?ooooo`03o`000?oooooooooo03;ooooo0_l00005onJhY@05o`000?ogh[;omn:booOR/_l0
00001OnRR[/01?l0003o1BJXo`000?l00002oi2:b@05o`000?oUi]7oiNKAonGVdOl000000_o[m/T0
1?l0003oiOSBonGhd_l00002on7ff@03o`000?oMn=co000000?oeoKR00?o0000om?eiOoCmND01?l0
00001?o;kNco0000olo`jOl0001]ooooo`05o`000?ooooooooooooooool000003?ooool006Gooooo
0_l0001?ooooo`03o`000?oooooooooo03;ooooo0_l00005onJhY@05o`000?ogh[;omn:booOR/_l0
00001_nRR[/01Ol0003o1BJXo`000?n@R/Wo000000?oiNKA00Co0000on_fbOo[m/Wo00000_oUn=80
1_l0003ohOKIon7ffOl0003ogOSLo`0000?oeoKR00Co0000om?eiOoCmNGo00000oo?lnT5o`0006go
oooo00Go0000ooooooooooooooooo`00000<ooooo`00Ioooool00ol0003oooooooooo`1<ooooo`03
o`000?oooooooooo03?ooooo00?o0000onJhYOoV^:D00_oV^:D00ol0003omn:booOR/P02ooOR/P03
o`000?nRR[_oXXZk00?oXXZk1ol000001OoUi]7o0000on_fbOo[m/Wo000000;oiOSB00Ko0000on7f
fOoQm]Wo0000omghg?l00003omOfhP04o`000?oCmNGodoGUo`0000?oco?Y00Co0000ol_`k?o;l>co
bo3/0_l0001^ooooo`04o`000?ooooooooooo`0000cooooo001Xooooo`03o`000?oooooooooo04_o
oooo00?o0000ooooooooool0<oooool2o`0000?oi[RU00?o0000ooOR/_ogh[800oogh[800ol0003o
XXZko`000002o`000003ojBC`ol0003oQh7500;oQh754?l000001OoGm^;o0000om?eiOoCmNGo0000
00?oco?Y00Go0000ol_`k?o;l>cobo3/o`00001aooooo`03o`000?oooooo000000cooooo001Yoooo
o`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0=?ooool01?l0003oi[RUonJhYOl00005
ooOR/P?o00001OnTTl<00ol0003oQh75ohN1a@05ohN1a@05o`000?oVo<?o0000on3mc?l000000_oK
o=T00ol0003oe_cLomKlg007o`000004olocjOl0003obo3/ol_`k0?o0000LOooool00ol0003ooooo
o`00000<ooooo`00J_ooool2o`0004[ooooo00?o0000ooooooooool0=Oooool00ol0003oi[RUo`00
0002ooOR/P?o000000?oR>cXo`000?nTTl<01OnTTl<00ol0003oQh75ohN1a@04ohN1a@05o`000?oV
o<?o0000on3mc?l000000_oKo=T01?l0003oe_cLomKlg?l00002om3kh`04o`000?o<mnSoc?OXolcg
j0?o000000Cobo3/o`000?o;knco0000Loooool00ol0003oooooo`00000;ooooo`00K?ooool00ol0
003oooooooooo`17ooooo`03o`000?oooooooooo03Gooooo00?o0000onJhYOl000001Ol00002ohS/
j003o`000?nTTl?oY9?300?oY9?300?o0000ohN1aOn7PLD00on7PLD01Ol0003oi_c3o`000?oPoLco
000000;ofocI00Go0000omKlg?oFo=co0000om3kh`02o`0000?oc?OX00?o0000olWfjoo9m^/01Ol0
001dooooo`;o00002oooool006gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0g
ooooo`;o00001Oooool00ol0003oR>cXo`000006ojBC``09o`000?n7PLGoQh75ohN1aOl0003oi_c3
o`000?oPoLco000000;ofocI00Ko0000omKlg?oFo=co0000om3khol00003olcgj0;o000000?obOK[
o`000?l000000oo5l^l2o`0007?ooooo0ol0000;ooooo`00K_ooool00ol0003oooooooooo`14oooo
o`03o`000?oooooooooo03oooooo00?o0000ohS/j?l000001OnTTl<01Ol0003oQh75ohN1aOl0003o
i_c300go000000Goc?OXo`000?o9m^_obOK[o`000003olGbk`;o0000LOooool4o`0000kooooo001_
ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0@?ooool2o`0000GoY9?300?o0000
ohN1aOl000002ol000000omdg_;o0000o`000006o`000004olGbkol0003o0000o`0006kooooo1?l0
000Booooo`00L?ooool2o`0004?ooooo00?o0000ooooooooool0@Oooool2o`0000CoY9?33ol00002
og[PmP?o000000?oPn7jo`000?l000001?l0001[ooooo`?o00005_ooool007;ooooo00?o0000oooo
ooooool0@?ooool00ol0003oooooooooo`12ooooo`03o`000?nTTl?o000000;o00003Oooool8o`00
00;oN^3e1?l0001Wooooo`Co00006Oooool007?ooooo00?o0000ooooooooool0?oooool00ol0003o
ooooooooo`13ooooo`03o`000?oooooooooo01Gooooo0ol0001Wooooo`Co00007Oooool007Cooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`31ooooo`Co00008Oooool007Gooooo0_l0
000nooooo`03o`000?oooooooooo0;gooooo1?l0000Uooooo`00Moooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;Wooooo1?l0000Yooooo`00N?ooool00ol0003oooooooooo`0joooo
o`03o`000?oooooooooo0;Kooooo0ol0000]ooooo`00NOooool00ol0003oooooooooo`0iooooo`03
o`000?oooooooooo0;;ooooo1?l0000`ooooo`00N_ooool2o`0003Wooooo00?o0000ooooooooool0
[_ooool4o`0003Cooooo001looooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0Z_oo
ool4o`0003Sooooo001mooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0Y_ooool4
o`0003cooooo001nooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0X_ooool4o`00
043ooooo001oooooo`;o0000=?ooool00ol0003oooooooooo`2Oooooo`?o0000A?ooool0087ooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2Kooooo`Co0000Aoooool008;ooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`2Gooooo`Co0000Boooool008?ooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`2Cooooo`Co0000Coooool008Cooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`2?ooooo`Co0000Doooool008Gooooo0_l0000^ooooo`03
o`000?oooooooooo08cooooo0ol0001Gooooo`00Qoooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo08Sooooo1?l0001Jooooo`00R?ooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo08Cooooo1?l0001Nooooo`00ROooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo083ooooo1?l0001Rooooo`00R_ooool2o`0002Wooooo00?o0000ooooooooool0O?ooool4o`00
06Kooooo002<ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0N?ooool4o`0006[o
oooo002=ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0MOooool3o`0006kooooo
002>ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0LOooool4o`00077ooooo002?
ooooo`;o00009?ooool00ol0003oooooooooo`1]ooooo`Co0000MOooool0097ooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`1Yooooo`Co0000NOooool009;ooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`1Uooooo`Co0000OOooool009?ooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`1Qooooo`Co0000POooool009Cooooo0_l0000Oooooo`03o`000?oo
oooooooo05kooooo0ol00025ooooo`00U_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo05[ooooo1?l00028ooooo`00Uoooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
05Kooooo1?l0002<ooooo`00V?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05;o
oooo1?l0002@ooooo`00VOooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04kooooo
1?l0002Dooooo`00V_ooool2o`0001Wooooo00?o0000ooooooooool0B_ooool4o`0009Sooooo002L
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Aoooool3o`0009cooooo002Moooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0A?ooool4o`0009oooooo002Nooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool0@?ooool4o`000:?ooooo002Oooooo`;o0000
4oooool00ol0003oooooooooo`0looooo`Co0000Yoooool00:7ooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0hooooo`Co0000Zoooool00:;ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0dooooo`Co0000[oooool00:?ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0aooooo`?o0000/oooool00:Cooooo0_l0000>ooooo`03o`000?oooooooooo02go
oooo1?l0002fooooo`00Y_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Wooooo
1?l0002jooooo`00Yoooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Gooooo1?l0
002nooooo`00Z?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027ooooo1?l00032
ooooo`00ZOooool2o`0000Wooooo00?o0000ooooooooool07_ooool3o`000<Kooooo002[ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool06_ooool4o`000<Wooooo002/ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool05_ooool4o`000<gooooo002]ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool04_ooool4o`000=7ooooo002^ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool03_ooool4o`000=Gooooo002_ooooo`;o00000oooool00ol0
003oooooooooo`0:ooooo`Co0000fOooool00;7ooooo00Co0000oooooooooooo00002Oooool3o`00
0=gooooo002booooo`03o`000?oooooo000000Gooooo1?l0003Pooooo`00/oooool2o`000003oooo
ool0003o000000;o0000i?ooool00;Cooooo0_l0003Xooooo`00oooooonOooooo`00oooooonOoooo
o`00oooooonOooooo`00oooooonOooooo`00oooooonOooooo`00boooool3o`000=3ooooo003<oooo
o`03o`000?oooooooooo01Wooooo00Co410@o`000?l0003o0000/_ooool00<Gooooo0ol00002oooo
o`?o00002?ooool00omgMgOoIVIVooooo`09ooooo`03o`000?nj^[[ooooo00Gooooo00?o0000oooo
ooooool00oooool00omVIVKoMgMgooooo`2/ooooo`00a?ooool2o`0000?ooooo00Co0000oooooooo
oooo00001oooool00ooMgMgo410@onk^kP0:ooooo`;o<S8b1_ooool00ol0003oooooooooo`03oooo
o`03onk^k_l@413ogMgM0:cooooo002nooooo`03oa0@4?l0003o000000;o000000?o410@o`000?oo
ool00_l000001Ooooooo0000oooooooooooo000000Oooooo00?oEEEEoiRHV?ooool00_ooool2o`00
00;ooooo0_l00002ooooo`03ohN7Qol0003o^[Zj00Gooooo00Wo0000ogMgMol0003o0000oeEEEOo^
k^koooooohN7QomVIVH0[?ooool00<3ooooo00?o0000ooooooooool00_ooool2o`0000?ooooo0ol0
0007ooooo`03o`000?oooooooooo00;ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd2ooooo`03
olc<c?l0003o410@00Gooooo00Wo0000oeEEEOo^k^koooooogMgMomEEEGoooooonk^k_l00000[?oo
ool00<3ooooo00?o0000ooooooooool04Oooool00olb<S;oooooooooo`03ooooo`04omgMgOl0003o
410@olc<c0_ooooo00?o0000onk^k_ooool00_ooool01?l0003oooooooooool0002/ooooo`00`?oo
ool00ol0003oooooooooo`0Aooooo`03oc8b<_oooooooooo00?ooooo00Cok^k^ob4Q8Ol@413ok^k^
2oooool00ol0003ok^k^ooooo`02ooooo`04o`000?ooooooooooo`000:cooooo0030ooooo`03o`00
0?oooooooooo017ooooo00?o0000onk^k_ooool00oooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`09
o`000?mEEEGok^k^oooooomgMgOoIVIVooooooo^k^ko00000:cooooo002nooooo`03oa0@4?l0003o
000000?o00004?ooool00omEEEGoMgMgooooo`02ooooo`;o00000_ooool2o`0000Wooooo00?o410@
o`000?mgMgL00_l000001OmVIVKok^k^oooooomgMgOoEEEE0:cooooo0030ooooo`03o`000?oooooo
oooo017ooooo00?ogMgMoa0@4?o^k^h06?ooool00oo^k^ko410@omgMg@2/ooooo`00`?ooool00ol@
413o^[Zjooooo`0Booooo`03ogMgMomVIVKooooo01Oooooo00?oIVIVogMgMoooool0[?ooool00<3o
oooo00Co^[Zjoa0@4?l0003o410@f_ooool00?ooooooWoooool00?ooooooWoooool00001\
\>"],
  ImageRangeCache->{{{0, 413.188}, {335, 0}} -> {-0.0868418, 0.0251932, \
0.00323112, 0.00323112}}]
}, Open  ]],

Cell[TextData[{
  "Note the hole in the distribution near the origin, which is also clearly \
visible in the previous animation of the particle positions, Cell ",
  ButtonBox["7.7",
    ButtonData:>"Cell 7.7",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  "\tIt is interesting that this gas comes to an equilibrium at all, because \
we have not included interactions between the particles that would be needed \
to drive this system to a ",
  StyleBox["thermal",
    FontSlant->"Italic"],
  " equilibrium state.   The equilibrium achieved here is a ",
  StyleBox["partial",
    FontSlant->"Italic"],
  " equilibrium due to phase-mixing alone. Thermal equilibrium corresponds to \
a particular form for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(f\_eq\)(E)\)\(:\)\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(f\_eq\)(E)\  = \ 
        C\ \[ExponentialE]\^\(\(-E\)/k\_B  T\)\)\(,\)\)\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " is the temperature, ",
  Cell[BoxData[
      \(TraditionalForm\`C\)]],
  " is a constant, and ",
  Cell[BoxData[
      \(TraditionalForm\`k\_B\)]],
  "is Boltzmann's constant. We will have more to say concerning thermal \
equilibrium in Chapter ",
  ButtonBox["8",
    ButtonData:>{"Chapter8.nb", None},
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text",
  CellTags->"i:11"],

Cell["\<\
\tAnother view of the equilibration process considers only the \
particle positions. In this view,  we extract the positions, neglecting \
momenta:\
\>", "Text"],

Cell[BoxData[
    \(pos[t1_]\  := \ \((a\  = \ particlepos[t1]; \ 
        Table[a[\([n, 1]\)], {n, 1, M}])\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.18"],

Cell[TextData[{
  "Then we plot the particle positions in Cell ",
  ButtonBox["7.19",
    ButtonData:>"Cell 7.19",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Table[
        ListPlot[pos[t1], PlotRange \[Rule] {\(-1\), 1}], {t1, 0, 
          50,  .4}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.19"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .38913 Mdot
.02762 .40265 Mdot
.02952 .31257 Mdot
.03143 .32374 Mdot
.03333 .3607 Mdot
.03524 .38563 Mdot
.03714 .31198 Mdot
.03905 .45112 Mdot
.04095 .41658 Mdot
.04286 .34115 Mdot
.04476 .33937 Mdot
.04667 .44476 Mdot
.04857 .41376 Mdot
.05048 .35113 Mdot
.05238 .4102 Mdot
.05429 .3364 Mdot
.05619 .35852 Mdot
.0581 .41429 Mdot
.06 .35555 Mdot
.0619 .4267 Mdot
.06381 .4025 Mdot
.06571 .39456 Mdot
.06762 .37215 Mdot
.06952 .41333 Mdot
.07143 .42191 Mdot
.07333 .37122 Mdot
.07524 .32072 Mdot
.07714 .34383 Mdot
.07905 .42573 Mdot
.08095 .39306 Mdot
.08286 .3792 Mdot
.08476 .42989 Mdot
.08667 .44023 Mdot
.08857 .34434 Mdot
.09048 .3771 Mdot
.09238 .39454 Mdot
.09429 .41871 Mdot
.09619 .33234 Mdot
.0981 .40701 Mdot
.1 .45203 Mdot
.1019 .4448 Mdot
.10381 .36798 Mdot
.10571 .37461 Mdot
.10762 .40162 Mdot
.10952 .39791 Mdot
.11143 .36629 Mdot
.11333 .32982 Mdot
.11524 .43528 Mdot
.11714 .37464 Mdot
.11905 .41196 Mdot
.12095 .43115 Mdot
.12286 .42345 Mdot
.12476 .44988 Mdot
.12667 .36449 Mdot
.12857 .38428 Mdot
.13048 .42639 Mdot
.13238 .4499 Mdot
.13429 .36912 Mdot
.13619 .42909 Mdot
.1381 .39737 Mdot
.14 .36348 Mdot
.1419 .44894 Mdot
.14381 .39585 Mdot
.14571 .3345 Mdot
.14762 .40949 Mdot
.14952 .43354 Mdot
.15143 .33422 Mdot
.15333 .31617 Mdot
.15524 .34785 Mdot
.15714 .41057 Mdot
.15905 .38228 Mdot
.16095 .32222 Mdot
.16286 .32782 Mdot
.16476 .33681 Mdot
.16667 .3955 Mdot
.16857 .31133 Mdot
.17048 .44953 Mdot
.17238 .34131 Mdot
.17429 .42432 Mdot
.17619 .33416 Mdot
.1781 .38549 Mdot
.18 .38711 Mdot
.1819 .31223 Mdot
.18381 .37391 Mdot
.18571 .44794 Mdot
.18762 .34611 Mdot
.18952 .36145 Mdot
.19143 .3438 Mdot
.19333 .37545 Mdot
.19524 .31151 Mdot
.19714 .41465 Mdot
.19905 .44087 Mdot
.20095 .33818 Mdot
.20286 .36277 Mdot
.20476 .33496 Mdot
.20667 .45239 Mdot
.20857 .35055 Mdot
.21048 .41529 Mdot
.21238 .45262 Mdot
.21429 .38051 Mdot
.21619 .38619 Mdot
.2181 .37802 Mdot
.22 .43507 Mdot
.2219 .40068 Mdot
.22381 .40591 Mdot
.22571 .34692 Mdot
.22762 .37996 Mdot
.22952 .35806 Mdot
.23143 .33842 Mdot
.23333 .40629 Mdot
.23524 .34933 Mdot
.23714 .33479 Mdot
.23905 .42666 Mdot
.24095 .4203 Mdot
.24286 .45512 Mdot
.24476 .32864 Mdot
.24667 .35823 Mdot
.24857 .44524 Mdot
.25048 .4418 Mdot
.25238 .3962 Mdot
.25429 .41239 Mdot
.25619 .45344 Mdot
.2581 .37208 Mdot
.26 .42766 Mdot
.2619 .40894 Mdot
.26381 .31638 Mdot
.26571 .41735 Mdot
.26762 .45127 Mdot
.26952 .36813 Mdot
.27143 .31504 Mdot
.27333 .38986 Mdot
.27524 .38236 Mdot
.27714 .441 Mdot
.27905 .39244 Mdot
.28095 .37793 Mdot
.28286 .4283 Mdot
.28476 .43252 Mdot
.28667 .42094 Mdot
.28857 .32419 Mdot
.29048 .4332 Mdot
.29238 .41958 Mdot
.29429 .42717 Mdot
.29619 .33874 Mdot
.2981 .35383 Mdot
.3 .36127 Mdot
.3019 .42491 Mdot
.30381 .44686 Mdot
.30571 .46013 Mdot
.30762 .32336 Mdot
.30952 .34821 Mdot
.31143 .4627 Mdot
.31333 .37854 Mdot
.31524 .35213 Mdot
.31714 .41489 Mdot
.31905 .32241 Mdot
.32095 .37008 Mdot
.32286 .42467 Mdot
.32476 .40869 Mdot
.32667 .44134 Mdot
.32857 .41209 Mdot
.33048 .427 Mdot
.33238 .3729 Mdot
.33429 .42783 Mdot
.33619 .45789 Mdot
.3381 .38471 Mdot
.34 .35201 Mdot
.3419 .37132 Mdot
.34381 .44546 Mdot
.34571 .41017 Mdot
.34762 .34578 Mdot
.34952 .43235 Mdot
.35143 .39722 Mdot
.35333 .31437 Mdot
.35524 .33334 Mdot
.35714 .35006 Mdot
.35905 .33898 Mdot
.36095 .42888 Mdot
.36286 .45049 Mdot
.36476 .36658 Mdot
.36667 .31405 Mdot
.36857 .41993 Mdot
.37048 .43179 Mdot
.37238 .45111 Mdot
.37429 .34359 Mdot
.37619 .44576 Mdot
.3781 .31927 Mdot
.38 .40471 Mdot
.3819 .44382 Mdot
.38381 .43936 Mdot
.38571 .45685 Mdot
.38762 .3818 Mdot
.38952 .45182 Mdot
.39143 .42539 Mdot
.39333 .32904 Mdot
.39524 .43781 Mdot
.39714 .44898 Mdot
.39905 .45558 Mdot
.40095 .43872 Mdot
.40286 .35988 Mdot
.40476 .45843 Mdot
.40667 .38405 Mdot
.40857 .3106 Mdot
.41048 .31127 Mdot
.41238 .32231 Mdot
.41429 .34941 Mdot
.41619 .45679 Mdot
.4181 .37513 Mdot
.42 .31683 Mdot
.4219 .38308 Mdot
.42381 .34163 Mdot
.42571 .33222 Mdot
.42762 .34672 Mdot
.42952 .41169 Mdot
.43143 .34514 Mdot
.43333 .40943 Mdot
.43524 .33185 Mdot
.43714 .36904 Mdot
.43905 .33858 Mdot
.44095 .45743 Mdot
.44286 .33077 Mdot
.44476 .38336 Mdot
.44667 .45266 Mdot
.44857 .36016 Mdot
.45048 .41496 Mdot
.45238 .412 Mdot
.45429 .37883 Mdot
.45619 .31158 Mdot
.4581 .356 Mdot
.46 .40607 Mdot
.4619 .32644 Mdot
.46381 .41217 Mdot
.46571 .4592 Mdot
.46762 .33783 Mdot
.46952 .31555 Mdot
.47143 .44119 Mdot
.47333 .36412 Mdot
.47524 .33821 Mdot
.47714 .44881 Mdot
.47905 .33564 Mdot
.48095 .40183 Mdot
.48286 .3931 Mdot
.48476 .38441 Mdot
.48667 .44445 Mdot
.48857 .38874 Mdot
.49048 .41564 Mdot
.49238 .3822 Mdot
.49429 .43797 Mdot
.49619 .3271 Mdot
.4981 .40878 Mdot
.5 .34181 Mdot
.5019 .38215 Mdot
.50381 .40351 Mdot
.50571 .45258 Mdot
.50762 .32812 Mdot
.50952 .31715 Mdot
.51143 .40291 Mdot
.51333 .36504 Mdot
.51524 .32973 Mdot
.51714 .39059 Mdot
.51905 .31164 Mdot
.52095 .44534 Mdot
.52286 .43336 Mdot
.52476 .3722 Mdot
.52667 .33886 Mdot
.52857 .38315 Mdot
.53048 .31976 Mdot
.53238 .37501 Mdot
.53429 .38037 Mdot
.53619 .319 Mdot
.5381 .35966 Mdot
.54 .39193 Mdot
.5419 .35703 Mdot
.54381 .41012 Mdot
.54571 .3872 Mdot
.54762 .34694 Mdot
.54952 .35736 Mdot
.55143 .42732 Mdot
.55333 .34662 Mdot
.55524 .36132 Mdot
.55714 .42977 Mdot
.55905 .35134 Mdot
.56095 .37913 Mdot
.56286 .42294 Mdot
.56476 .33111 Mdot
.56667 .32183 Mdot
.56857 .40744 Mdot
.57048 .43842 Mdot
.57238 .3591 Mdot
.57429 .32011 Mdot
.57619 .3215 Mdot
.5781 .42232 Mdot
.58 .35525 Mdot
.5819 .37999 Mdot
.58381 .43965 Mdot
.58571 .42058 Mdot
.58762 .41755 Mdot
.58952 .40777 Mdot
.59143 .31913 Mdot
.59333 .43288 Mdot
.59524 .42355 Mdot
.59714 .42178 Mdot
.59905 .41107 Mdot
.60095 .46299 Mdot
.60286 .36484 Mdot
.60476 .39202 Mdot
.60667 .38872 Mdot
.60857 .43496 Mdot
.61048 .43469 Mdot
.61238 .33621 Mdot
.61429 .42458 Mdot
.61619 .36686 Mdot
.6181 .31005 Mdot
.62 .40861 Mdot
.6219 .36251 Mdot
.62381 .40915 Mdot
.62571 .4612 Mdot
.62762 .32615 Mdot
.62952 .3815 Mdot
.63143 .35471 Mdot
.63333 .41033 Mdot
.63524 .32752 Mdot
.63714 .44927 Mdot
.63905 .42418 Mdot
.64095 .44824 Mdot
.64286 .32459 Mdot
.64476 .39475 Mdot
.64667 .37897 Mdot
.64857 .39708 Mdot
.65048 .36184 Mdot
.65238 .3246 Mdot
.65429 .31614 Mdot
.65619 .37779 Mdot
.6581 .45215 Mdot
.66 .39205 Mdot
.6619 .33699 Mdot
.66381 .40734 Mdot
.66571 .32142 Mdot
.66762 .32161 Mdot
.66952 .40598 Mdot
.67143 .38806 Mdot
.67333 .35316 Mdot
.67524 .37247 Mdot
.67714 .34603 Mdot
.67905 .45821 Mdot
.68095 .35741 Mdot
.68286 .37517 Mdot
.68476 .32944 Mdot
.68667 .43136 Mdot
.68857 .31703 Mdot
.69048 .41877 Mdot
.69238 .37458 Mdot
.69429 .33973 Mdot
.69619 .33044 Mdot
.6981 .43078 Mdot
.7 .44793 Mdot
.7019 .4361 Mdot
.70381 .39954 Mdot
.70571 .36995 Mdot
.70762 .37912 Mdot
.70952 .40211 Mdot
.71143 .37111 Mdot
.71333 .44687 Mdot
.71524 .46005 Mdot
.71714 .41616 Mdot
.71905 .43862 Mdot
.72095 .4489 Mdot
.72286 .45421 Mdot
.72476 .32182 Mdot
.72667 .36369 Mdot
.72857 .4154 Mdot
.73048 .44809 Mdot
.73238 .3223 Mdot
.73429 .386 Mdot
.73619 .33896 Mdot
.7381 .38948 Mdot
.74 .38633 Mdot
.7419 .41438 Mdot
.74381 .40095 Mdot
.74571 .42369 Mdot
.74762 .38815 Mdot
.74952 .36902 Mdot
.75143 .43628 Mdot
.75333 .38445 Mdot
.75524 .423 Mdot
.75714 .46198 Mdot
.75905 .39305 Mdot
.76095 .38152 Mdot
.76286 .31574 Mdot
.76476 .43067 Mdot
.76667 .37831 Mdot
.76857 .31599 Mdot
.77048 .45369 Mdot
.77238 .4105 Mdot
.77429 .32642 Mdot
.77619 .33506 Mdot
.7781 .36695 Mdot
.78 .33661 Mdot
.7819 .43743 Mdot
.78381 .41861 Mdot
.78571 .4307 Mdot
.78762 .45147 Mdot
.78952 .3614 Mdot
.79143 .4445 Mdot
.79333 .37124 Mdot
.79524 .34302 Mdot
.79714 .35383 Mdot
.79905 .31697 Mdot
.80095 .45041 Mdot
.80286 .44389 Mdot
.80476 .322 Mdot
.80667 .33429 Mdot
.80857 .35482 Mdot
.81048 .34634 Mdot
.81238 .45694 Mdot
.81429 .36537 Mdot
.81619 .39472 Mdot
.8181 .33137 Mdot
.82 .3499 Mdot
.8219 .32342 Mdot
.82381 .36302 Mdot
.82571 .34306 Mdot
.82762 .35004 Mdot
.82952 .31778 Mdot
.83143 .45875 Mdot
.83333 .43497 Mdot
.83524 .31082 Mdot
.83714 .37862 Mdot
.83905 .37963 Mdot
.84095 .35626 Mdot
.84286 .33874 Mdot
.84476 .34186 Mdot
.84667 .43924 Mdot
.84857 .46233 Mdot
.85048 .39821 Mdot
.85238 .45357 Mdot
.85429 .40299 Mdot
.85619 .32762 Mdot
.8581 .40118 Mdot
.86 .41253 Mdot
.8619 .33058 Mdot
.86381 .36528 Mdot
.86571 .45536 Mdot
.86762 .33244 Mdot
.86952 .32514 Mdot
.87143 .33363 Mdot
.87333 .39046 Mdot
.87524 .34359 Mdot
.87714 .45099 Mdot
.87905 .32499 Mdot
.88095 .35883 Mdot
.88286 .37599 Mdot
.88476 .33727 Mdot
.88667 .31973 Mdot
.88857 .34543 Mdot
.89048 .45082 Mdot
.89238 .32931 Mdot
.89429 .4262 Mdot
.89619 .40237 Mdot
.8981 .39163 Mdot
.9 .4149 Mdot
.9019 .37566 Mdot
.90381 .36509 Mdot
.90571 .4632 Mdot
.90762 .33684 Mdot
.90952 .45249 Mdot
.91143 .45494 Mdot
.91333 .31069 Mdot
.91524 .43465 Mdot
.91714 .34801 Mdot
.91905 .34129 Mdot
.92095 .41991 Mdot
.92286 .38991 Mdot
.92476 .35326 Mdot
.92667 .33383 Mdot
.92857 .35359 Mdot
.93048 .46052 Mdot
.93238 .36463 Mdot
.93429 .3146 Mdot
.93619 .36296 Mdot
.9381 .34348 Mdot
.94 .32397 Mdot
.9419 .3112 Mdot
.94381 .36759 Mdot
.94571 .38482 Mdot
.94762 .32334 Mdot
.94952 .36 Mdot
.95143 .43327 Mdot
.95333 .36301 Mdot
.95524 .37766 Mdot
.95714 .35742 Mdot
.95905 .32371 Mdot
.96095 .32296 Mdot
.96286 .46327 Mdot
.96476 .32078 Mdot
.96667 .4047 Mdot
.96857 .39949 Mdot
.97048 .39038 Mdot
.97238 .34851 Mdot
.97429 .42064 Mdot
.97619 .44903 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooocgooooo0006
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol0003oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_oo
ool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o
0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo033ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Wooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02[ooooo0_l00000
2Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h0:Oooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool002Wooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg02Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg02Sooooo00Go410@okZj^_ooooooMgMg
oc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
02_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0/ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool00ol0003oooooooooo`0boooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo
ooooooooool@4100:_ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@4100
0oooool01Ol@413ooooooooooooooooo410@02cooooo00Go0000oooooooooooooooooa0@4003oooo
o`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Vooooo`Go00000oooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@400]ooooo`04o`00
0?oooooooooooa0@40?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo
007ooooo000Yooooo`;o0000<oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000002_ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00000[ooooo`03ojVY
ZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool00000:?ooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000002cooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`01ooooo`00:Oooool00ol0003o
ooooooooo`0booooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool00000;?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000002[ooooo00?o410@o`000?nj^[X0
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00000Xoooo
o`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool00000:Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool002Wooooo00?o0000oooo
ooooool0<_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool0
1Ol@413ooooooooooooooooo410@02gooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@
4?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Yooooo`03okZj^_lQ8B7ooooo00;o
oooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100:Oooool0
0omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooo
oooooooo410@02Wooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@4003ooooo`00:Oooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0:Oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:?ooool01Ol@413oV9RHoooooonj^[[o0000
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:Ooo
ool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg02Wooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool00ol0003oooooooooo`0`oooo
o`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h0:Oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:?ooool01OnYZJWo410@o`000?l@413o
ZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
:_ooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^02Wooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Q
oooooooo0000A?l00004ooooo`00:Oooool3o`000003ooooool0003o000000Kooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo0_l000001?oo
oooo0000o`000?l00002ooooo`;o00001Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00;ooooo0_l00005ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool2
o`0000?ooooo0_l0000;ooooo`?o00002Oooool00ol0003oooooooooo`02o`0000Oooooo00?o0000
ooooooooool02Oooool2o`0000_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03
ooooo`;o00001?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool00_l00008ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_l00005
ooooo`Co00002_ooool00ol0003oooooooooo`0:ooooo`00:Oooool3o`000003ooooool0003o0000
02?ooooo0_l00007ooooo`;o00002Oooool00ol0003oooooooooo`0<ooooo`;o000000?oooooo`00
0?l000006?ooool2o`0000?ooooo0_l0000;ooooo`04o`000?ooooooooooooooo`;o00003_ooool2
o`0000[ooooo0_l0000Kooooo`03o`000?oooooooooo00oooooo0_l00009ooooo`;o00005_ooool4
o`0000Cooooo00Co0000oooooooooooooooo0_l00007ooooo`;o00008?ooool2o`0000cooooo00?o
0000ooooooooool02_ooool002Wooooo00?o0000ooooooooool03Oooool2o`0001Oooooo0_l0000Q
ooooo`;o00008oooool2o`0000cooooo0_l0000>ooooo`;o00002_ooool2o`0000Gooooo1?l0000:
ooooo`;o00001?ooool2o`0001;ooooo0_l00009ooooo`;o00005_ooool4o`0000Sooooo0_l00007
ooooo`;o00004Oooool2o`0001Oooooo0_l0000?ooooo`00:Oooool01?l0003oooooo`000?l0000<
ooooo`;o00006Oooool2o`0002Oooooo0_l00005ooooo`;o000000?oooooo`000?l000004Oooool2
o`0000Wooooo0_l0000Tooooo`Co00002?ooool5o`0000?ooooo0_l0000Fooooo`;o00004Oooool4
o`0001Gooooo0_l00004ooooo`;o00004oooool2o`0000oooooo1?l00002ooooo`Co00003oooool0
02Wooooo1?l0000Wooooo`;o00009oooool2o`0000Gooooo0_l000000ooooooo0000o`00000Loooo
o`;o00003_ooool2o`0000Wooooo0_l0000Eooooo`;o000000?oooooo`000?l000003_ooool2o`00
00?ooooo0_l000000ooooooo0000o`000003ooooo`;o00004Oooool4o`0000cooooo0_l00007oooo
o`;o00001?ooool2o`0000gooooo0_l000000ooooooo0000o`00000Booooo`Co00000_ooool3o`00
013ooooo000Yooooo`03o`000?oooooooooo01Wooooo0_l0000>ooooo`;o00006?ooool2o`0002ko
oooo0_l0000Dooooo`;o00002Oooool2o`0000;ooooo1?l0000Rooooo`;o000000?oooooo`000?l0
00000_l000000ooooooo0000o`000009ooooo`;o000000?oooooo`000?l000006?ooool2o`0001So
oooo1_l000000ooooooo0000o`000003ooooo`;o00009_ooool002Wooooo00?o0000ooooooooool0
5?ooool2o`0000?ooooo0_l0000>ooooo`;o00006?ooool2o`0002;ooooo0_l0000:ooooo`;o0000
2?ooool2o`0000;ooooo1?l0000Cooooo`Co00003_ooool2o`0001Gooooo0_l0000>ooooo`;o0000
00?oooooo`000?l000009_ooool2o`0000[ooooo1ol00005ooooo`;o00009_ooool002Wooooo00?o
0000ooooooooool01_ooool2o`0000cooooo0_l0000=ooooo`Co00000oooool2o`000003ooooool0
003o000000Oooooo0_l00009ooooo`;o00009?ooool2o`0001Cooooo0_l00002ooooo`Co00002_oo
ool2o`0001Wooooo0_l0000>ooooo`;o0000<_ooool3o`0000Oooooo0_l00002ooooo`;o00003_oo
ool3o`00013ooooo0_l0000Kooooo`00:Oooool00ol0003oooooooooo`03ooooo`;o000000?ooooo
o`000?l000006oooool4o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`?o00001oooool4
o`00017ooooo0_l0000Booooo`;o00006?ooool2o`0000Oooooo1_l0000=ooooo`;o00006_ooool2
o`0000gooooo0_l00009ooooo`;o00002oooool2o`0000_ooooo0ol00007ooooo`;o00002_ooool2
o`0000_ooooo0_l00005ooooo`;o00001Oooool2o`0001_ooooo000Yooooo`;o00000oooool3o`00
02Oooooo0_l00007ooooo`;o00002?ooool2o`0001?ooooo0_l0000Booooo`;o00004oooool2o`00
00?ooooo0_l00007ooooo`Co00001_ooool2o`0000Oooooo0_l0000Yooooo`;o00002Oooool2o`00
00_ooooo0_l0000Aooooo`;o00003_ooool2o`0000_ooooo0_l00005ooooo`;o00000_ooool2o`00
01kooooo000Yooooo`03o`000?oooooooooo00;ooooo0_l00009ooooo`;o00000_ooool2o`0001Wo
oooo0_l00003ooooo`?o0000<?ooool2o`0000Oooooo0_l0000>ooooo`Co00005?ooool2o`0003Oo
oooo0_l0000Tooooo`;o00002?ooool2o`0000Cooooo0_l00008ooooo`;o00000_ooool2o`0000So
oooo0_l00004ooooo`;o00006?ooool002Wooooo00?o0000ooooooooool03Oooool2o`0000;ooooo
0_l0000Dooooo`;o00002?ooool3o`0000Wooooo0_l0000Iooooo`;o00002_ooool2o`0000Oooooo
0_l0000?ooooo`?o00009?ooool4o`0002Gooooo0_l0000Yooooo`;o00000oooool2o`0000kooooo
0_l00002ooooo`;o00002?ooool2o`0000Cooooo0_l00009ooooo`;o00003Oooool002Wooooo00?o
0000ooooooooool01Oooool2o`00023ooooo0_l0000?ooooo`;o00000oooool2o`000003ooooool0
003o000001Kooooo1?l00006ooooo`;o00000oooool2o`00017ooooo0_l00002ooooo`;o00009Ooo
ool5o`0004oooooo0_l000001?oooooo0000o`000?ooool2o`0001_ooooo0_l0000?ooooo`;o0000
3Oooool002Wooooo00?o0000ooooooooool01Oooool2o`00037ooooo0_l00006ooooo`;o00004_oo
ool2o`0000Cooooo0_l00006ooooo`;o00000oooool2o`00017ooooo0_l0000/ooooo`;o00001Ooo
ool2o`0000oooooo0_l0000;ooooo`;o00009_ooool2o`0000;ooooo0_l000001?oooooo0000o`00
0?ooool2o`0001gooooo0ol0000Kooooo`00:Oooool2o`0000Sooooo0ol0000dooooo`;o00001?oo
ool2o`0000kooooo0_l0000booooo`;o00006Oooool4o`0000Sooooo0_l0000?ooooo`;o00002ooo
ool2o`000003ooooool0003o000002?ooooo0_l00002ooooo`;o00002?ooool2o`0001Wooooo0ol0
0007ooooo`;o00004_ooool002Wooooo00Co0000ooooool0003o00001_ooool3o`0002Sooooo0_l0
000:ooooo`;o00001?ooool2o`0000oooooo0_l0000Oooooo`;o00003Oooool2o`000003ooooool0
003o000001Sooooo1ol00004ooooo`;o00008Oooool2o`00023ooooo0_l0000?ooooo`;o00002ooo
ool2o`0001Cooooo1?l0000Booooo`00:Oooool01?l0003oooooo`000?l0000Looooo`;o00000ooo
ool2o`0000kooooo0_l00002ooooo`;o00007Oooool2o`0001oooooo0_l0000=ooooo`;o00001_oo
ool2o`0001?ooooo0_l00003ooooo`;o00001?ooool2o`0000kooooo0_l00007ooooo`;o00005_oo
ool2o`0001;ooooo0_l0000:ooooo`;o00004?ooool2o`0000kooooo1?l00002ooooo`?o00004ooo
ool002Wooooo00?o0000ooooooooool06?ooool2o`0000?ooooo0_l00003ooooo`;o00004_ooool2
o`0003;ooooo0_l0000Qooooo`;o00002oooool2o`0001[ooooo0_l00003ooooo`Co00001oooool2
o`0001Kooooo0_l0000?ooooo`;o00002Oooool2o`0000;ooooo0_l0000:ooooo`;o00002oooool2
o`0000Oooooo1_l000000ooooooo0000o`00000Cooooo`00:Oooool00ol0003oooooooooo`0Foooo
o`Co00001_ooool2o`0002Wooooo0_l0000?ooooo`;o00003?ooool2o`0001Gooooo0_l0000Goooo
o`;o00006_ooool2o`0000?ooooo0_l0000Kooooo`;o00003?ooool2o`0000Oooooo0_l00009oooo
o`;o00003_ooool2o`0000_ooooo0_l0000;ooooo`;o00005_ooool002Wooooo0_l0000;ooooo`Co
00002?ooool2o`0000Sooooo0_l0000>ooooo`;o00005_ooool2o`000003ooooool0003o000000oo
oooo0_l000000ooooooo0000o`000002ooooo`;o00007?ooool2o`0001[ooooo0_l0000_ooooo`;o
00002?ooool3o`0000_ooooo0_l0000<ooooo`;o0000A_ooool002Wooooo00?o0000ooooooooool0
2_ooool4o`0000Cooooo0_l00003ooooo`;o000000?oooooo`000?l000005?ooool2o`000003oooo
ool0003o000001?ooooo0_l0000Eooooo`;o00000_ooool2o`0001Kooooo0_l0000Pooooo`;o0000
00?oooooo`000?l00000;?ooool4o`000003ooooool0003o000000Cooooo0_l0000Iooooo`;o0000
6_ooool2o`0000Gooooo0_l0000Sooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooooooo
ool03oooool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`00000Gooooo`;o
00001_ooool2o`000003ooooool0003o000000oooooo0_l00008ooooo`;o00008?ooool2o`0000[o
oooo0_l0000Gooooo`;o00001oooool2o`0000Gooooo0_l0000Cooooo`;o000000?oooooo`000?l0
00001_ooool2o`000003ooooool0003o000000?ooooo0_l0000Aooooo`;o00005Oooool2o`0000co
oooo0_l00005ooooo`;o00003oooool2o`0001;ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool03oooool2o`0001Oooooo0_l0000@ooooo`?o000000?oooooo`00
0?l000003Oooool4o`0000Sooooo0_l0000Fooooo`;o00002Oooool2o`0000Kooooo0_l000000ooo
oooo0000o`00000:ooooo`;o000000?oooooo`000?l000001oooool3o`0000Oooooo0_l00005oooo
o`;o00003Oooool2o`0000Cooooo0_l000000ooooooo0000o`00000>ooooo`;o00003oooool4o`00
01Gooooo0_l0000Tooooo`;o00004_ooool000Kooooo00Go410@oooooooooooooooooa0@400<oooo
o`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02o`00
01cooooo0_l00008ooooo`;o00001?ooool2o`0000[ooooo0_l0000Aooooo`;o00004_ooool2o`00
00kooooo0_l00004ooooo`;o00000oooool2o`0000Kooooo0_l0000:ooooo`;o000000Coooooo`00
0?l0003ooooo0_l00007ooooo`?o00007Oooool2o`00023ooooo1?l00002ooooo`Co0000>_ooool2
o`0001Gooooo0006ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07
ooooo`03ogMgMolb<S;ooooo00Cooooo1Ol0000Looooo`;o00003_ooool2o`0000[ooooo0_l0000U
ooooo`;o00005?ooool2o`0001Oooooo1?l0000@ooooo`;o00004_ooool2o`0001?ooooo0_l0000B
ooooo`So0000??ooool2o`0001Gooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool0
0omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool2o`0002oooooo0_l0
000Mooooo`?o0000@_ooool2o`0000Oooooo0_l00005ooooo`Co00004Oooool3o`0000oooooo0_l0
0002ooooo`;o00004oooool2o`000003ooooool0003o000002Kooooo0_l00006ooooo`;o00001_oo
ool2o`0000kooooo0_l0000=ooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo0_l0
0003ooooo`;o000000?oooooo`000?l000003oooool2o`0000Gooooo0_l0000Qooooo`?o0000@?oo
ool2o`0000Wooooo0_l00005ooooo`;o00004oooool2o`0000_ooooo0_l00003ooooo`;o00007_oo
ool2o`00013ooooo0_l0000@ooooo`;o00001_ooool2o`0000Kooooo0_l0000>ooooo`;o00003Ooo
ool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo0_l00003ooooo`;o0000
00?oooooo`000?l000001?ooool2o`0000Oooooo1?l00005ooooo`;o00006_ooool2o`0001kooooo
0_l0000Xooooo`;o0000<_ooool3o`0002;ooooo0_l0000@ooooo`;o00002Oooool2o`0003Cooooo
0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Co
oooo1?l00006ooooo`03o`000?oooooooooo01Oooooo0ol00007ooooo`;o00006Oooool2o`0000So
oooo0_l0000Nooooo`;o00009oooool2o`0003Cooooo0_l0000@ooooo`Co00002Oooool2o`00023o
oooo0_l000000ooooooo0000o`00000Qooooo`;o00003_ooool002Wooooo0_l0000:ooooo`;o0000
3?ooool2o`0002?ooooo0_l0000aooooo`;o00007_ooool2o`0000Kooooo1?l0000looooo`Co0000
2Oooool2o`00027ooooo1?l0000:ooooo`;o00005?ooool3o`0000kooooo000Yooooo`;o00002_oo
ool2o`0000Wooooo0_l0000Wooooo`;o000000?oooooo`000?l00000;Oooool2o`0001Sooooo0_l0
000<ooooo`Co00004?ooool2o`0000Gooooo0_l0000Fooooo`Co0000>Oooool2o`0000cooooo0_l0
000Dooooo`;o00003oooool002Wooooo00?o0000ooooooooool01Oooool2o`0000gooooo0_l0000>
ooooo`;o000000?oooooo`000?l000005?ooool2o`000003ooooool0003o000000Oooooo0_l0000B
ooooo`;o00001Oooool2o`0001[ooooo0_l00007ooooo`;o00002_ooool2o`0000cooooo0_l00006
ooooo`;o00001Oooool2o`000003ooooool0003o000000Gooooo0ol000000ooooooo0000o`000008
ooooo`Co00007oooool2o`0004gooooo000Yooooo`03o`000?oooooooooo00Cooooo1Ol00002oooo
o`;o00003_ooool2o`0000Oooooo0_l000000ooooooo0000o`00000Mooooo`;o000000?oooooo`00
0?l000004_ooool3o`0000Cooooo0_l0000Iooooo`?o00001?ooool2o`0000;ooooo0_l00009oooo
o`;o00003?ooool2o`00013ooooo0_l00005ooooo`?o000000?oooooo`000?l000008Oooool2o`00
00Sooooo0_l0000Jooooo`;o0000<Oooool002Wooooo00?o0000ooooooooool00_ooool4o`000003
ooooool0003o000000;ooooo0_l0000>ooooo`;o00005oooool2o`0000;ooooo0_l0000<ooooo`;o
00000_ooool2o`0000oooooo0_l000000ooooooo0000o`00000Oooooo`;o00001?ooool3o`0000;o
oooo0_l00006ooooo`;o00007_ooool2o`0002Oooooo0_l00002ooooo`;o00000_ooool2o`0002Co
oooo0_l0000;ooooo`;o00009?ooool002Wooooo0_l00003ooooo`;o00003oooool2o`0001oooooo
0_l00002ooooo`;o00002?ooool2o`0000Kooooo0_l00007ooooo`;o00001_ooool2o`0000kooooo
0_l0000Hooooo`;o00002oooool2o`0001gooooo0ol0000Oooooo`;o00001_ooool2o`0000;ooooo
0_l0000@ooooo`;o00008oooool2o`0000Gooooo0_l0000?ooooo`;o00003?ooool002Wooooo00?o
0000ooooooooool03?ooool2o`0000Gooooo0_l00007ooooo`;o00009?ooool2o`0000gooooo1?l0
000Fooooo`;o0000?Oooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool3o`0001cooooo
0_l0000?ooooo`;o000000?oooooo`000?l000002?ooool2o`0002[ooooo0_l0000?ooooo`;o0000
3?ooool002Wooooo00?o0000ooooooooool02Oooool2o`000003ooooool0003o000000;o00003?oo
ool2o`000003ooooool0003o000000cooooo0_l0000Booooo`;o00003_ooool2o`0000?ooooo0_l0
0004ooooo`;o000000?oooooo`000?l000004Oooool2o`0003Kooooo0_l00002ooooo`;o00001?oo
ool3o`0000?ooooo0_l00006ooooo`;o00008?ooool2o`000003ooooool0003o000002_ooooo0_l0
000Vooooo`00:Oooool00ol0003oooooooooo`09ooooo`;o00000oooool4o`0000gooooo0ol0000;
ooooo`;o00004_ooool2o`0000Gooooo0_l00006ooooo`;o000000Coooooo`000?l0003ooooo0_l0
0004ooooo`;o000000Coooooo`000?l0003o00001oooool2o`0000Oooooo0_l0000booooo`Co0000
4?ooool2o`0000Kooooo0_l0001@ooooo`;o00009_ooool002Wooooo00?o0000ooooooooool04?oo
ool2o`0000[ooooo0_l00002ooooo`;o00009_ooool2o`0000Kooooo1Ol0000;ooooo`;o00000ooo
ool2o`0000;ooooo0_l000000ooooooo0000o`00000hooooo`Co00002Oooool2o`0001cooooo0_l0
0002ooooo`;o00005?ooool2o`0000Cooooo0_l00019ooooo`00:Oooool2o`0001_ooooo1?l00007
ooooo`;o00005?ooool2o`0001?ooooo1?l0000Aooooo`;o00001Oooool2o`0002oooooo0_l0000D
ooooo`;o00000oooool3o`0001Kooooo0_l00002ooooo`?o00003_ooool2o`0000?ooooo0_l00004
ooooo`;o00003_ooool2o`0001Sooooo0_l0000:ooooo`;o00004oooool002Wooooo00?o0000oooo
ooooool06_ooool2o`0000Wooooo0_l0000Dooooo`;o0000<oooool2o`0000;ooooo1?l0000Loooo
o`;o00001oooool2o`0000gooooo0_l0000:ooooo`?o00006oooool2o`0000Cooooo0_l00008oooo
o`;o00002?ooool2o`0000oooooo0_l00002ooooo`;o00005?ooool2o`0000[ooooo0_l0000Coooo
o`00:Oooool00ol0003oooooooooo`0@ooooo`;o00008oooool2o`0000kooooo0_l00007ooooo`;o
00003_ooool2o`00013ooooo0_l00002ooooo`Co00005?ooool2o`0000Kooooo0_l0000Fooooo`;o
00000_ooool2o`0002[ooooo0_l0000Booooo`;o00004oooool2o`0003Gooooo000Yooooo`03o`00
0?oooooooooo00Cooooo0_l0000:ooooo`;o00000oooool2o`0001kooooo0_l0000>ooooo`;o0000
1oooool2o`0000kooooo0_l00003ooooo`;o00002_ooool2o`0001_ooooo0_l00003ooooo`;o0000
2Oooool2o`0001;ooooo0_l00011ooooo`;o00000_ooool2o`0004?ooooo000Yooooo`03o`000?oo
oooooooo00Cooooo0_l0000?ooooo`;o00006Oooool2o`0001?ooooo0_l0000?ooooo`;o00002ooo
ool2o`0000Wooooo0ol0000Pooooo`;o00002Oooool2o`0002Gooooo0_l0000Aooooo`;o00000_oo
ool2o`0000?ooooo0_l0000Booooo`;o00000_ooool2o`0004?ooooo000Yooooo`;o00000_ooool2
o`0001[ooooo1?l000000ooooooo0000o`000007ooooo`;o00000oooool2o`0001Wooooo0_l00009
ooooo`;o00004Oooool2o`000003ooooool0003o000000;o00000_ooool4o`0001Sooooo0_l0000a
ooooo`Co00004Oooool2o`0000;ooooo1?l000000ooooooo0000o`00000Aooooo`;o00000_ooool2
o`0001Oooooo0_l00002ooooo`;o00006_ooool2o`0000_ooooo000Yooooo`04o`000?oooooooooo
ooooo`;o00004_ooool2o`0000Kooooo1?l000000ooooooo0000o`000007ooooo`;o00002_ooool4
o`0000cooooo0_l00002ooooo`;o00007?ooool2o`000003ooooool0003o000000Cooooo1?l0000>
ooooo`;o00002?ooool2o`0000Oooooo0_l0000Xooooo`;o00001Oooool2o`0001;ooooo0ol0000=
ooooo`;o00001?ooool2o`0000;ooooo0_l0000?ooooo`;o00001_ooool2o`0000;ooooo0_l00004
ooooo`?o00004oooool2o`0000_ooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01Gooooo0_l0
000Pooooo`Co00002?ooool2o`0000;ooooo0_l0000Hooooo`;o00003_ooool2o`0000;ooooo0_l0
0003ooooo`;o00001_ooool4o`00017ooooo0_l0000_ooooo`;o00004oooool2o`0000gooooo0_l0
000<ooooo`;o00002oooool2o`0000;ooooo0_l0000<ooooo`?o00008?ooool000kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo04?ooooo0_l0000Booooo`;o00002?ooool2o`0000kooooo0_l00002ooooo`Co000000?o
ooooo`000?l000001_ooool2o`0000Kooooo0_l0000booooo`;o00003oooool2o`0000[ooooo0_l0
000Mooooo`;o00001?ooool2o`0000Wooooo0_l0000Cooooo`;o00006_ooool000kooooo00Go410@
oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0001Gooooo`Co00007?oo
ool2o`00017ooooo0_l0000Zooooo`;o00001_ooool2o`0000oooooo0_l0000:ooooo`;o00002ooo
ool2o`0001Kooooo0_l00003ooooo`;o00004Oooool2o`0000Kooooo0_l00008ooooo`;o00004?oo
ool000kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0FOooool2o`0005_ooooo0_l0000`ooooo`;o00006oooool2o`00017ooooo0_l0
000@ooooo`;o00004?ooool000kooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo
?Oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
00Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocgooooo0006
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@
oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00ooo
ool3o`000?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooo
oooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006
ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?oo
ooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co
00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000O
ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3oooooocgooooo000Qoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003o
ooooooooo`05ooooo`?o0000oooooolmooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Oooooo`03oeEEEOmVIVKo00000?oo
ooooAoooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .39583 Mdot
.02762 .39513 Mdot
.02952 .29391 Mdot
.03143 .34011 Mdot
.03333 .35241 Mdot
.03524 .3871 Mdot
.03714 .31524 Mdot
.03905 .42763 Mdot
.04095 .43933 Mdot
.04286 .34422 Mdot
.04476 .34933 Mdot
.04667 .44486 Mdot
.04857 .39231 Mdot
.05048 .33402 Mdot
.05238 .44644 Mdot
.05429 .34001 Mdot
.05619 .37832 Mdot
.0581 .39172 Mdot
.06 .34738 Mdot
.0619 .40289 Mdot
.06381 .40865 Mdot
.06571 .40476 Mdot
.06762 .40542 Mdot
.06952 .39871 Mdot
.07143 .45191 Mdot
.07333 .34898 Mdot
.07524 .35157 Mdot
.07714 .35507 Mdot
.07905 .41206 Mdot
.08095 .40216 Mdot
.08286 .41077 Mdot
.08476 .43808 Mdot
.08667 .44092 Mdot
.08857 .37942 Mdot
.09048 .3816 Mdot
.09238 .41951 Mdot
.09429 .4303 Mdot
.09619 .35482 Mdot
.0981 .42482 Mdot
.1 .43855 Mdot
.1019 .45157 Mdot
.10381 .38249 Mdot
.10571 .3869 Mdot
.10762 .38321 Mdot
.10952 .38478 Mdot
.11143 .34989 Mdot
.11333 .34927 Mdot
.11524 .43099 Mdot
.11714 .35778 Mdot
.11905 .42227 Mdot
.12095 .43357 Mdot
.12286 .42252 Mdot
.12476 .4826 Mdot
.12667 .38613 Mdot
.12857 .38 Mdot
.13048 .44173 Mdot
.13238 .43403 Mdot
.13429 .37613 Mdot
.13619 .43086 Mdot
.1381 .38394 Mdot
.14 .35737 Mdot
.1419 .46228 Mdot
.14381 .42441 Mdot
.14571 .32405 Mdot
.14762 .44242 Mdot
.14952 .43853 Mdot
.15143 .34671 Mdot
.15333 .3429 Mdot
.15524 .35149 Mdot
.15714 .40558 Mdot
.15905 .35943 Mdot
.16095 .30594 Mdot
.16286 .34816 Mdot
.16476 .34426 Mdot
.16667 .42435 Mdot
.16857 .30456 Mdot
.17048 .48254 Mdot
.17238 .36658 Mdot
.17429 .42013 Mdot
.17619 .36978 Mdot
.1781 .41474 Mdot
.18 .403 Mdot
.1819 .3396 Mdot
.18381 .38136 Mdot
.18571 .43024 Mdot
.18762 .3214 Mdot
.18952 .35199 Mdot
.19143 .363 Mdot
.19333 .37005 Mdot
.19524 .34251 Mdot
.19714 .45053 Mdot
.19905 .47334 Mdot
.20095 .32009 Mdot
.20286 .35464 Mdot
.20476 .32659 Mdot
.20667 .47388 Mdot
.20857 .33515 Mdot
.21048 .43677 Mdot
.21238 .48377 Mdot
.21429 .35807 Mdot
.21619 .39801 Mdot
.2181 .36166 Mdot
.22 .44809 Mdot
.2219 .38892 Mdot
.22381 .41229 Mdot
.22571 .38039 Mdot
.22762 .36999 Mdot
.22952 .34531 Mdot
.23143 .31914 Mdot
.23333 .40915 Mdot
.23524 .33597 Mdot
.23714 .33537 Mdot
.23905 .43857 Mdot
.24095 .41251 Mdot
.24286 .49109 Mdot
.24476 .30789 Mdot
.24667 .36309 Mdot
.24857 .42811 Mdot
.25048 .4319 Mdot
.25238 .4289 Mdot
.25429 .39706 Mdot
.25619 .45855 Mdot
.2581 .40719 Mdot
.26 .40748 Mdot
.2619 .40742 Mdot
.26381 .34107 Mdot
.26571 .41694 Mdot
.26762 .47198 Mdot
.26952 .39995 Mdot
.27143 .32817 Mdot
.27333 .40685 Mdot
.27524 .39988 Mdot
.27714 .44859 Mdot
.27905 .38013 Mdot
.28095 .3875 Mdot
.28286 .41145 Mdot
.28476 .41888 Mdot
.28667 .41648 Mdot
.28857 .34804 Mdot
.29048 .44511 Mdot
.29238 .4487 Mdot
.29429 .46304 Mdot
.29619 .32615 Mdot
.2981 .34746 Mdot
.3 .37817 Mdot
.3019 .40613 Mdot
.30381 .42947 Mdot
.30571 .49529 Mdot
.30762 .35669 Mdot
.30952 .3631 Mdot
.31143 .44745 Mdot
.31333 .3568 Mdot
.31524 .34485 Mdot
.31714 .39436 Mdot
.31905 .30306 Mdot
.32095 .393 Mdot
.32286 .42543 Mdot
.32476 .42567 Mdot
.32667 .43476 Mdot
.32857 .43099 Mdot
.33048 .42418 Mdot
.33238 .35218 Mdot
.33429 .41553 Mdot
.33619 .43419 Mdot
.3381 .41678 Mdot
.34 .38592 Mdot
.3419 .39808 Mdot
.34381 .43172 Mdot
.34571 .41145 Mdot
.34762 .35215 Mdot
.34952 .41549 Mdot
.35143 .42177 Mdot
.35333 .33741 Mdot
.35524 .35388 Mdot
.35714 .36069 Mdot
.35905 .35849 Mdot
.36095 .44452 Mdot
.36286 .47318 Mdot
.36476 .39254 Mdot
.36667 .32575 Mdot
.36857 .41989 Mdot
.37048 .41241 Mdot
.37238 .44321 Mdot
.37429 .33674 Mdot
.37619 .4519 Mdot
.3781 .32896 Mdot
.38 .43731 Mdot
.3819 .47107 Mdot
.38381 .43159 Mdot
.38571 .4367 Mdot
.38762 .38515 Mdot
.38952 .45704 Mdot
.39143 .40406 Mdot
.39333 .32893 Mdot
.39524 .46146 Mdot
.39714 .431 Mdot
.39905 .44837 Mdot
.40095 .44814 Mdot
.40286 .35716 Mdot
.40476 .47767 Mdot
.40667 .36437 Mdot
.40857 .32527 Mdot
.41048 .32532 Mdot
.41238 .30703 Mdot
.41429 .36006 Mdot
.41619 .4787 Mdot
.4181 .39921 Mdot
.42 .332 Mdot
.4219 .38965 Mdot
.42381 .32267 Mdot
.42571 .31679 Mdot
.42762 .3456 Mdot
.42952 .39122 Mdot
.43143 .36643 Mdot
.43333 .412 Mdot
.43524 .3437 Mdot
.43714 .39803 Mdot
.43905 .3656 Mdot
.44095 .43762 Mdot
.44286 .3179 Mdot
.44476 .39407 Mdot
.44667 .43403 Mdot
.44857 .36158 Mdot
.45048 .43453 Mdot
.45238 .40917 Mdot
.45429 .4142 Mdot
.45619 .34327 Mdot
.4581 .35479 Mdot
.46 .38404 Mdot
.4619 .33529 Mdot
.46381 .44702 Mdot
.46571 .4562 Mdot
.46762 .33724 Mdot
.46952 .30647 Mdot
.47143 .47627 Mdot
.47333 .37254 Mdot
.47524 .3514 Mdot
.47714 .45895 Mdot
.47905 .35423 Mdot
.48095 .38845 Mdot
.48286 .409 Mdot
.48476 .39926 Mdot
.48667 .46259 Mdot
.48857 .38186 Mdot
.49048 .40964 Mdot
.49238 .3597 Mdot
.49429 .43398 Mdot
.49619 .33326 Mdot
.4981 .42867 Mdot
.5 .37492 Mdot
.5019 .35874 Mdot
.50381 .42527 Mdot
.50571 .45034 Mdot
.50762 .31031 Mdot
.50952 .33386 Mdot
.51143 .42905 Mdot
.51333 .36302 Mdot
.51524 .35365 Mdot
.51714 .36785 Mdot
.51905 .30474 Mdot
.52095 .43978 Mdot
.52286 .43038 Mdot
.52476 .36534 Mdot
.52667 .35121 Mdot
.52857 .41561 Mdot
.53048 .3252 Mdot
.53238 .36605 Mdot
.53429 .39675 Mdot
.53619 .34912 Mdot
.5381 .38919 Mdot
.54 .42008 Mdot
.5419 .3688 Mdot
.54381 .4191 Mdot
.54571 .37722 Mdot
.54762 .33805 Mdot
.54952 .3721 Mdot
.55143 .42305 Mdot
.55333 .3312 Mdot
.55524 .3413 Mdot
.55714 .43506 Mdot
.55905 .33827 Mdot
.56095 .39196 Mdot
.56286 .4188 Mdot
.56476 .30746 Mdot
.56667 .3458 Mdot
.56857 .43085 Mdot
.57048 .44656 Mdot
.57238 .34304 Mdot
.57429 .3078 Mdot
.57619 .35794 Mdot
.5781 .4053 Mdot
.58 .36168 Mdot
.5819 .41313 Mdot
.58381 .47033 Mdot
.58571 .43313 Mdot
.58762 .44717 Mdot
.58952 .43342 Mdot
.59143 .30082 Mdot
.59333 .42567 Mdot
.59524 .45818 Mdot
.59714 .40217 Mdot
.59905 .44634 Mdot
.60095 .49747 Mdot
.60286 .36896 Mdot
.60476 .36864 Mdot
.60667 .39923 Mdot
.60857 .43612 Mdot
.61048 .45267 Mdot
.61238 .3488 Mdot
.61429 .43635 Mdot
.61619 .36193 Mdot
.6181 .32427 Mdot
.62 .39857 Mdot
.6219 .37853 Mdot
.62381 .40171 Mdot
.62571 .44838 Mdot
.62762 .31736 Mdot
.62952 .39524 Mdot
.63143 .38185 Mdot
.63333 .44318 Mdot
.63524 .31735 Mdot
.63714 .44563 Mdot
.63905 .45602 Mdot
.64095 .46746 Mdot
.64286 .34175 Mdot
.64476 .37323 Mdot
.64667 .37885 Mdot
.64857 .42546 Mdot
.65048 .34578 Mdot
.65238 .31451 Mdot
.65429 .31003 Mdot
.65619 .37194 Mdot
.6581 .43149 Mdot
.66 .42692 Mdot
.6619 .32157 Mdot
.66381 .39826 Mdot
.66571 .32592 Mdot
.66762 .30932 Mdot
.66952 .38587 Mdot
.67143 .38447 Mdot
.67333 .38619 Mdot
.67524 .35425 Mdot
.67714 .36045 Mdot
.67905 .48292 Mdot
.68095 .36777 Mdot
.68286 .4021 Mdot
.68476 .3305 Mdot
.68667 .44265 Mdot
.68857 .35068 Mdot
.69048 .41763 Mdot
.69238 .40361 Mdot
.69429 .31745 Mdot
.69619 .36352 Mdot
.6981 .4638 Mdot
.7 .44187 Mdot
.7019 .41969 Mdot
.70381 .4202 Mdot
.70571 .36368 Mdot
.70762 .374 Mdot
.70952 .42164 Mdot
.71143 .36942 Mdot
.71333 .44281 Mdot
.71524 .46641 Mdot
.71714 .40966 Mdot
.71905 .449 Mdot
.72095 .44646 Mdot
.72286 .44593 Mdot
.72476 .31107 Mdot
.72667 .37183 Mdot
.72857 .44799 Mdot
.73048 .43664 Mdot
.73238 .31065 Mdot
.73429 .41333 Mdot
.73619 .36844 Mdot
.7381 .38572 Mdot
.74 .39759 Mdot
.7419 .43733 Mdot
.74381 .38993 Mdot
.74571 .4302 Mdot
.74762 .42496 Mdot
.74952 .40446 Mdot
.75143 .41577 Mdot
.75333 .40663 Mdot
.75524 .45122 Mdot
.75714 .49391 Mdot
.75905 .42887 Mdot
.76095 .39249 Mdot
.76286 .31558 Mdot
.76476 .45577 Mdot
.76667 .36445 Mdot
.76857 .30986 Mdot
.77048 .44009 Mdot
.77238 .40601 Mdot
.77429 .30862 Mdot
.77619 .34548 Mdot
.7781 .358 Mdot
.78 .35218 Mdot
.7819 .42973 Mdot
.78381 .3985 Mdot
.78571 .46025 Mdot
.78762 .44334 Mdot
.78952 .3801 Mdot
.79143 .47957 Mdot
.79333 .3788 Mdot
.79524 .35786 Mdot
.79714 .35448 Mdot
.79905 .29733 Mdot
.80095 .43529 Mdot
.80286 .44511 Mdot
.80476 .35165 Mdot
.80667 .33091 Mdot
.80857 .3302 Mdot
.81048 .32637 Mdot
.81238 .45071 Mdot
.81429 .34741 Mdot
.81619 .41801 Mdot
.8181 .33564 Mdot
.82 .34782 Mdot
.8219 .32326 Mdot
.82381 .35134 Mdot
.82571 .37876 Mdot
.82762 .34578 Mdot
.82952 .33215 Mdot
.83143 .45439 Mdot
.83333 .44458 Mdot
.83524 .29157 Mdot
.83714 .38146 Mdot
.83905 .37057 Mdot
.84095 .39192 Mdot
.84286 .36885 Mdot
.84476 .35295 Mdot
.84667 .45632 Mdot
.84857 .4748 Mdot
.85048 .39483 Mdot
.85238 .48875 Mdot
.85429 .37925 Mdot
.85619 .32847 Mdot
.8581 .43737 Mdot
.86 .44761 Mdot
.8619 .3511 Mdot
.86381 .40179 Mdot
.86571 .48286 Mdot
.86762 .33314 Mdot
.86952 .31084 Mdot
.87143 .35894 Mdot
.87333 .41661 Mdot
.87524 .37079 Mdot
.87714 .47617 Mdot
.87905 .32662 Mdot
.88095 .3849 Mdot
.88286 .37961 Mdot
.88476 .31809 Mdot
.88667 .32391 Mdot
.88857 .33584 Mdot
.89048 .42958 Mdot
.89238 .3093 Mdot
.89429 .41674 Mdot
.89619 .39329 Mdot
.8981 .39204 Mdot
.9 .41773 Mdot
.9019 .41153 Mdot
.90381 .37893 Mdot
.90571 .47072 Mdot
.90762 .34514 Mdot
.90952 .43111 Mdot
.91143 .4481 Mdot
.91333 .34762 Mdot
.91524 .42309 Mdot
.91714 .36969 Mdot
.91905 .3759 Mdot
.92095 .41645 Mdot
.92286 .39697 Mdot
.92476 .35102 Mdot
.92667 .36414 Mdot
.92857 .3809 Mdot
.93048 .45781 Mdot
.93238 .3886 Mdot
.93429 .29524 Mdot
.93619 .38708 Mdot
.9381 .37152 Mdot
.94 .30179 Mdot
.9419 .34172 Mdot
.94381 .38584 Mdot
.94571 .38354 Mdot
.94762 .31912 Mdot
.94952 .3655 Mdot
.95143 .43882 Mdot
.95333 .3465 Mdot
.95524 .39632 Mdot
.95714 .33679 Mdot
.95905 .35534 Mdot
.96095 .31137 Mdot
.96286 .49246 Mdot
.96476 .31575 Mdot
.96667 .39091 Mdot
.96857 .43281 Mdot
.97048 .41789 Mdot
.97238 .35161 Mdot
.97429 .41787 Mdot
.97619 .44392 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooocgooooo0006
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol0003oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_oo
ool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o
0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo033ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Wooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02[ooooo0_l00000
2Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h0:Oooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool002Wooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg02Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg02Sooooo00Go410@okZj^_ooooooMgMg
oc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
02_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0/ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool00ol0003oooooooooo`0boooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo
ooooooooool@4100:_ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@4100
0oooool01Ol@413ooooooooooooooooo410@02cooooo00Go0000oooooooooooooooooa0@4003oooo
o`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Vooooo`Go00000oooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@400]ooooo`04o`00
0?oooooooooooa0@40?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo
007ooooo000Yooooo`;o0000<oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000002_ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00000[ooooo`03ojVY
ZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool00000:?ooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000002cooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`01ooooo`00:Oooool00ol0003o
ooooooooo`0booooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool00000;?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000002[ooooo00?o410@o`000?nj^[X0
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00000Xoooo
o`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool00000:Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool002Wooooo00?o0000oooo
ooooool0<_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool0
1Ol@413ooooooooooooooooo410@02gooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@
4?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Yooooo`03okZj^_lQ8B7ooooo00;o
oooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100:Oooool0
0omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooo
oooooooo410@02Wooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@4003ooooo`00:Oooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0:Oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:?ooool01Ol@413oV9RHoooooonj^[[o0000
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:Ooo
ool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg02Wooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool00ol0003oooooooooo`0`oooo
o`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h0:Oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:?ooool01OnYZJWo410@o`000?l@413o
ZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
:_ooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_l0000Rooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool3o`000?oooooo0_ooool2
o`0001kooooo0_l0000Iooooo`00:Oooool3o`000?Kooooo0_l0000Yooooo`;o00006Oooool002Wo
oooo00?o0000ooooooooool0/oooool2o`00047ooooo0_l0000[ooooo`;o00005oooool002Wooooo
00?o0000ooooooooool0:oooool2o`0002kooooo0_l0000oooooo`;o00005Oooool2o`0006kooooo
0_l0000Gooooo`00:Oooool00ol0003oooooooooo`0Xooooo`;o000000?oooooo`000?l000005_oo
ool2o`0001Kooooo0_l0000Looooo`;o00004Oooool2o`0000kooooo0_l0000<ooooo`;o000000?o
ooooo`000?l00000?oooool2o`0004cooooo000Qoooooooo0000A?l00004ooooo`00:Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`05ooooo`;o00000_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`?o00000_ooool3o`00
00cooooo00Co0000oooooooooooooooo1?l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool3o`0000Kooooo0_l00000
0ooooooo0000ooooo`0:ooooo`03o`000?oooooooooo00Cooooo0_l00003ooooo`03o`000?oooooo
oooo00[ooooo000Yooooo`04o`000?ooooooooooooooo`;o0000=oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`;o0000<?ooool00ol0003oooooooooo`06
ooooo`;o000000?oooooo`000?l000000oooool2o`0000cooooo0_l0000Dooooo`;o00001_ooool0
0ol0003oooooooooo`0Looooo`;o00006?ooool2o`0000;ooooo00?o0000ooooooooool02_ooool0
02Wooooo00Co0000oooooooooooooooo0_l0000booooo`;o00002?ooool2o`0003cooooo0_l00004
ooooo`;o0000>Oooool2o`000003ooooool0003o0000017ooooo0_l0000Dooooo`;o00009Oooool2
o`0001;ooooo0_l00004ooooo`;o00003oooool002Wooooo00?o0000ooooooooool08oooool2o`00
00cooooo0_l00002ooooo`;o00002?ooool2o`0003cooooo0_l0000looooo`;o00003?ooool2o`00
03;ooooo0_l0000Cooooo`;o00004Oooool2o`0001Gooooo000Yooooo`;o00009?ooool2o`0000co
oooo0_l00003ooooo`;o00007?ooool2o`0001Gooooo0_l0000;ooooo`?o00000_ooool2o`00023o
oooo0_l0000Jooooo`;o00003?ooool4o`0002cooooo0_l00002ooooo`;o00004?ooool2o`000003
ooooool0003o000002Sooooo000Yooooo`03o`000?oooooooooo03Kooooo0_l0000Dooooo`;o0000
1_ooool2o`0001Gooooo0_l000000ooooooo0000o`000003ooooo`;o00000oooool3o`0002Cooooo
0_l0000Zooooo`;o00001?ooool2o`0002Kooooo0_l0000=ooooo`;o00001Oooool2o`0002_ooooo
000Yooooo`03o`000?oooooooooo04cooooo0_l0000Pooooo`;o00000oooool2o`0000Oooooo0_l0
000Fooooo`;o00004Oooool2o`0002Sooooo0_l0000Uooooo`?o00001?ooool2o`0000Oooooo0_l0
0002ooooo`;o0000;_ooool002Wooooo00?o0000ooooooooool01Oooool2o`00037ooooo0_l00006
ooooo`?o0000:_ooool2o`0000gooooo0_l0000;ooooo`;o00002Oooool2o`0000;ooooo0_l0000=
ooooo`;o0000Coooool2o`0000;ooooo0_l000000ooooooo0000o`00000;ooooo`;o00001?ooool2
o`0001Cooooo0_l0000Booooo`00:Oooool00ol0003oooooooooo`05ooooo`;o0000:?ooool2o`00
00Oooooo0_l00006ooooo`?o00008oooool2o`0000Gooooo0_l0000Jooooo`Co00002oooool2o`00
00_ooooo0_l000000ooooooo0000o`00001Booooo`;o00005?ooool2o`0001Cooooo0_l0000Boooo
o`00:Oooool4o`0000Gooooo0_l0000Nooooo`;o00001oooool2o`0000;ooooo0_l0000Dooooo`;o
00006oooool2o`0002?ooooo0_l0000Hooooo`Go00006Oooool2o`0005kooooo0_l0000Gooooo`00
:Oooool01Ol0003oooooo`000?l0003ooooo00;o00000_ooool2o`0001kooooo0_l00002ooooo`;o
00001oooool2o`0000Wooooo0_l00009ooooo`;o00003oooool2o`0002;ooooo0_l000000ooooooo
0000o`000004ooooo`;o00007_ooool2o`0000;ooooo1?l0000Dooooo`;o000000?oooooo`000?l0
00009_ooool2o`0000oooooo0_l0000Gooooo`;o00002Oooool2o`0001Oooooo000Yooooo`03o`00
0?oooooooooo00;ooooo0_l00004ooooo`;o00000_ooool2o`0001Oooooo0_l00002ooooo`?o0000
4_ooool2o`00017ooooo0_l000000ooooooo0000o`000004ooooo`;o00008_ooool2o`000003oooo
ool0003o000000Cooooo0_l0000Hooooo`;o00002?ooool4o`0000_ooooo0_l0000:ooooo`;o0000
9_ooool2o`0000[ooooo1?l000000ooooooo0000o`00000Gooooo`Co00002oooool2o`0001?ooooo
000Yooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`;o00000_ooool3o`0000Wooooo0ol0
000:ooooo`Ko00001oooool2o`0001gooooo0_l000000ooooooo0000o`000009ooooo`;o00000ooo
ool2o`0002Oooooo0_l0000?ooooo`;o000000?oooooo`000?l000005oooool2o`0001Kooooo0_l0
000Kooooo`;o00001_ooool2o`000003ooooool0003o000000Co00002_ooool2o`0000kooooo0_l0
0002ooooo`;o00001oooool2o`0000Cooooo0_l0000=ooooo`00:Oooool01?l0003oooooo`000?l0
0002ooooo`;o00002?ooool2o`0000Gooooo0_l00002ooooo`?o00003?ooool2o`0000Wooooo0_l0
0002ooooo`;o00009oooool2o`0000?ooooo0_l000000ooooooo0000o`00000Oooooo`;o00000ooo
ool4o`0000Wooooo0_l00002ooooo`;o0000;_ooool2o`0000;ooooo0_l0000Kooooo`;o00001?oo
ool4o`0000Gooooo0_l00004ooooo`;o00001?ooool2o`0001;ooooo0_l00009ooooo`;o00000_oo
ool2o`0000gooooo000Yooooo`Co00003?ooool2o`0000Gooooo0_l00004ooooo`;o00001_ooool2
o`0001;ooooo0_l00002ooooo`;o00007?ooool3o`0000cooooo0ol0000<ooooo`;o00004?ooool2
o`0000Gooooo0_l00009ooooo`;o00004_ooool2o`0001kooooo0_l0000Oooooo`;o00000oooool3
o`0000gooooo0_l0000Sooooo`;o00004Oooool002Wooooo00?o0000ooooooooool06_ooool2o`00
00Kooooo0_l00004ooooo`;o00004?ooool3o`0001_ooooo0ol0000<ooooo`?o00003?ooool2o`00
00;ooooo0_l00009ooooo`;o00003?ooool2o`000003ooooool0003o000001Kooooo0ol0000Moooo
o`;o00007oooool2o`0000?ooooo0_l0000Gooooo`;o0000;Oooool002Wooooo00?o0000oooooooo
ool0:?ooool2o`0000Sooooo0_l00007ooooo`;o00001oooool2o`0001;ooooo0_l0000=ooooo`;o
00003_ooool2o`000003ooooool0003o000000Wooooo0_l0000<ooooo`;o000000?oooooo`000?l0
00000_ooool2o`0001?ooooo0_l0000:ooooo`;o00004Oooool2o`0000Cooooo0_l00002ooooo`;o
00004Oooool2o`00023ooooo0_l0000@ooooo`;o00006oooool002Wooooo00?o0000ooooooooool0
;?ooool2o`0000Cooooo0_l0000@ooooo`;o00004_ooool2o`0001gooooo0_l00006ooooo`;o0000
00?oooooo`000?l000005_ooool5o`000003ooooool0003o000001Wooooo0_l0000Cooooo`;o0000
0_ooool2o`0000;ooooo0_l0000Aooooo`;o0000<_ooool2o`0000Gooooo0_l0000Dooooo`00:Ooo
ool00ol0003oooooooooo`0/ooooo`?o00001?ooool2o`0000Wooooo0_l0000oooooo`;o000000?o
ooooo`000?l000005oooool4o`000004ooooool0003o0000ooooo`;o00004Oooool3o`0001Oooooo
0_l00007ooooo`;o00001_ooool2o`0001oooooo1?l00008ooooo`;o00003?ooool2o`0000Sooooo
0_l0000Dooooo`00:Oooool2o`0002kooooo0_l00004ooooo`;o00002Oooool2o`0004gooooo0_l0
000Dooooo`Co00003oooool3o`0000_ooooo0_l00002ooooo`;o00003_ooool3o`0000?ooooo0_l0
00000ooooooo0000o`00000Oooooo`Co00002?ooool2o`0000cooooo0_l00004ooooo`;o00006?oo
ool002Wooooo00?o0000ooooooooool08?ooool2o`0006_ooooo0_l00006ooooo`;o00003Oooool3
o`0001gooooo0_l00002ooooo`;o00003_ooool2o`0000Cooooo0_l0000looooo`;o00001?ooool2
o`0001Sooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`07ooooo`;o00002?oo
ool2o`0000_ooooo1?l0000/ooooo`;o00001Oooool2o`0003kooooo0_l0000=ooooo`;o00005ooo
ool2o`0000Kooooo0_l0000[ooooo`Co00002?ooool2o`0000Oooooo0_l00007ooooo`;o00001Ooo
ool2o`0000?ooooo0_l0000Nooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo00Oooooo0_l00008ooooo`?o00000_ooool3o`0000Gooooo0_l0000@ooooo`;o0000
2oooool2o`0000oooooo0_l00005ooooo`;o0000>oooool2o`0002Wooooo0_l000000ooooooo0000
o`000003ooooo`;o0000:oooool4o`0000Sooooo0_l00002ooooo`;o00000oooool2o`0000Oooooo
0_l00005ooooo`;o00001_ooool2o`0001_ooooo0006ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
4_ooool2o`0000;ooooo1?l00003ooooo`;o00000_ooool2o`0000gooooo0_l0000;ooooo`;o0000
8oooool2o`0000gooooo0_l0000Fooooo`;o00001oooool2o`0002cooooo0_l0000:ooooo`?o0000
4oooool2o`0001kooooo0_l0000<ooooo`;o00003Oooool2o`0000?ooooo0ol0000Eooooo`001_oo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8b
ooooo`04ooooo`Go00005Oooool3o`0000?ooooo0_l00002ooooo`;o00006Oooool2o`00017ooooo
0_l0000Aooooo`;o00003Oooool2o`0000Wooooo0_l0000;ooooo`;o00001?ooool2o`00017ooooo
0_l0000Xooooo`?o00004oooool2o`0002cooooo0_l0000>ooooo`Oo00005Oooool000Kooooo00Go
0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo00;o00000_ooool2o`000003ooooool0003o000000ko
oooo0_l0000Sooooo`;o00004Oooool2o`0001Wooooo0_l0000@ooooo`;o000000?oooooo`000?l0
00003_ooool2o`00017ooooo0_l00005ooooo`;o0000>Oooool2o`0000?ooooo0_l0000Hooooo`;o
00004?ooool2o`0000Wooooo1?l00007ooooo`;o00003oooool000Kooooo00Go410@oooooooooooo
oooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool2o`0000Go
oooo0_l000000ooooooo0000o`00001Booooo`?o00003?ooool2o`0001?ooooo0_l00003ooooo`;o
00008oooool2o`0001Cooooo0_l0000Sooooo`;o00000oooool2o`0001Sooooo0_l000000ooooooo
0000o`00000=ooooo`;o00005?ooool2o`0000oooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool2o`00
00cooooo0_l0000]ooooo`;o00002_ooool2o`0001?ooooo0ol00005ooooo`;o00007?ooool2o`00
0003ooooool0003o000001[ooooo0_l0000Jooooo`;o000000?oooooo`000?l000002Oooool2o`00
01Oooooo0_l0000<ooooo`;o00004oooool2o`0000gooooo0_l00006ooooo`;o00002Oooool2o`00
01;ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7o
c<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo00_ooooo0_l0000]ooooo`;o00002_ooool2
o`0000?ooooo1?l0000Dooooo`;o00005_ooool2o`0000Cooooo0_l0000=ooooo`;o00003_ooool2
o`0001Kooooo0_l00002ooooo`?o00002oooool2o`0000Cooooo0_l0000Aooooo`;o00003?ooool2
o`0001Oooooo0_l0000Aooooo`;o00002Oooool2o`0001;ooooo000Yooooo`;o00002_ooool3o`00
00?ooooo0_l0000Mooooo`;o00006oooool4o`0002?ooooo0_l00007ooooo`;o00004oooool2o`00
02?ooooo0_l000000ooooooo0000o`000003ooooo`;o00004Oooool2o`000003ooooool0003o0000
017ooooo0_l0000Rooooo`;o0000<?ooool002Wooooo00?o0000ooooooooool02Oooool3o`0000?o
oooo0_l0000Fooooo`;o00001Oooool2o`0001Sooooo0ol00002ooooo`;o00001oooool2o`0001[o
oooo0_l0000jooooo`;o00001Oooool2o`0001cooooo0_l0000Aooooo`?o00001?ooool2o`0004go
oooo000Yooooo`03o`000?oooooooooo00Wooooo0ol00003ooooo`;o00005_ooool2o`0001Oooooo
0_l00006ooooo`?o00000_ooool2o`000003ooooool0003o000000Cooooo0_l0000<ooooo`;o0000
8?ooool2o`0000Sooooo1?l0000Jooooo`;o0000:oooool2o`0000[ooooo0_l00004ooooo`;o0000
COooool002Wooooo00?o0000ooooooooool02Oooool2o`0000?ooooo0ol0000/ooooo`;o000000?o
ooooo`000?l000000_l0000<ooooo`;o00004_ooool2o`0000Kooooo0_l0000Booooo`;o00001?oo
ool3o`0000Oooooo1?l0000Looooo`;o0000:Oooool2o`0000Cooooo0_l0000dooooo`;o00008ooo
ool002Wooooo00?o0000ooooooooool03_ooool2o`0001kooooo0_l0000=ooooo`;o00000oooool2
o`0000Kooooo0_l00005ooooo`;o00003Oooool3o`0000;ooooo0_l00005ooooo`;o00004_ooool2
o`0000Gooooo0_l0000Fooooo`;o00003oooool2o`00027ooooo0_l0000<ooooo`;o00000oooool2
o`0002Gooooo0_l00005ooooo`;o000000?oooooo`000?l000001?ooool2o`0001gooooo000Yoooo
o`;o00004oooool2o`0001Wooooo0ol0000Jooooo`;o00001?ooool3o`0000gooooo0ol00002oooo
o`;o00001?ooool2o`0003;ooooo0_l000001?oooooo0000o`000?l00005ooooo`;o00009oooool2
o`000004ooooool0003o0000o`0000gooooo0_l0000Cooooo`;o00004?ooool2o`0000Gooooo1?l0
0005ooooo`;o00003_ooool3o`0000cooooo000Yooooo`03o`000?oooooooooo01;ooooo0_l00007
ooooo`?o00003oooool2o`00027ooooo0_l0000Dooooo`;o00000oooool2o`0003Gooooo0ol00000
0ooooooo0000o`000002ooooo`;o0000:_ooool5o`00023ooooo0_l0000Iooooo`;o00000oooool2
o`00013ooooo0ol0000<ooooo`00:Oooool00ol0003oooooooooo`0Dooooo`;o00001Oooool3o`00
00Gooooo0_l00005ooooo`;o0000<?ooool5o`0000Gooooo0_l0000_ooooo`;o00003Oooool2o`00
00_ooooo0_l0000@ooooo`;o00000_ooool2o`0000kooooo0_l0000:ooooo`;o0000=?ooool2o`00
01oooooo000Yooooo`04o`000?ooooooooooooooo`;o00004Oooool2o`0000gooooo0_l00005oooo
o`;o00006Oooool3o`0000kooooo0_l00004ooooo`Go0000=?ooool6o`0001Sooooo0_l0000@oooo
o`;o00000_ooool2o`0001[ooooo0_l00002ooooo`;o00001Oooool2o`00027ooooo0_l0000Woooo
o`00:Oooool01?l0003oooooooooooooool2o`00013ooooo0_l00005ooooo`;o00001?ooool2o`00
00kooooo0_l0000Cooooo`?o00003_ooool2o`0000Kooooo0_l00003ooooo`;o00002oooool2o`00
00;ooooo0_l0000Oooooo`;o00000_ooool2o`0000;ooooo0_l0000<ooooo`;o00001?ooool2o`00
01Gooooo0_l0000Jooooo`;o00000oooool2o`0000Gooooo0_l0000Qooooo`;o00001?ooool2o`00
017ooooo0_l0000>ooooo`00:Oooool2o`0001Cooooo0_l00005ooooo`Co000000Coooooo`000?l0
003o00003_ooool2o`0001?ooooo0_l0000Gooooo`;o000000?oooooo`000?l000000_l0000;oooo
o`;o00000_ooool2o`0000kooooo0ol0000=ooooo`;o00001oooool2o`0000Wooooo0_l000000ooo
oooo0000o`000004ooooo`?o00001?ooool2o`0000kooooo0_l0000Jooooo`;o00004?ooool2o`00
027ooooo0_l0000Aooooo`;o00003_ooool002Wooooo00?o0000ooooooooool00_ooool2o`0000co
oooo0_l00003ooooo`;o00001Oooool2o`000003ooooool0003o000000Cooooo0_l0000Aooooo`;o
00001oooool2o`0001_ooooo0_l000000ooooooo0000o`00000<ooooo`Co00003oooool5o`0000go
oooo0_l0000Booooo`;o00002?ooool2o`0000Cooooo1?l0000Sooooo`;o00000_ooool2o`00017o
oooo0_l0000Aooooo`;o00007?ooool2o`0001?ooooo000Yooooo`03o`000?oooooooooo00;ooooo
0_l0000<ooooo`;o00000oooool2o`0000Sooooo0_l00003ooooo`?o00004Oooool2o`0000Oooooo
0_l0000/ooooo`Co00003oooool2o`0001Sooooo0_l0000Looooo`;o00006_ooool2o`0000Oooooo
0_l00002ooooo`;o00001oooool2o`0001_ooooo0_l0000Looooo`;o00004oooool002Wooooo00?o
0000ooooooooool01?ooool2o`0000[ooooo0_l0000=ooooo`;o00000oooool2o`0002cooooo0_l0
000Eooooo`;o000000?oooooo`000?l00000;_ooool2o`0002;ooooo0ol0000>ooooo`;o00000ooo
ool2o`0000;ooooo0_l0000@ooooo`;o00001?ooool2o`0000?ooooo0_l00008ooooo`;o0000;?oo
ool2o`0000_ooooo000Yooooo`03o`000?oooooooooo00Cooooo0ol0000dooooo`;o00004Oooool2
o`0000;ooooo0ol00004ooooo`;o00003_ooool2o`000003ooooool0003o000000Oooooo0ol0000B
ooooo`;o00008?ooool2o`0000Cooooo0_l000000ooooooo0000o`000007ooooo`Go00003_ooool2
o`0000Oooooo1ol0000Aooooo`;o00000oooool2o`0000Sooooo0_l00006ooooo`;o00003oooool2
o`0001?ooooo0_l0000;ooooo`00:Oooool2o`0000Kooooo0_l0000>ooooo`;o00007Oooool2o`00
00Gooooo0_l0000Aooooo`;o00000oooool2o`0000Cooooo0_l0000Jooooo`?o00004_ooool2o`00
00_ooooo0_l0000Cooooo`;o00001?ooool2o`000003ooooool0003o000000Oooooo0_l0000Loooo
o`Go00001_ooool2o`00017ooooo0_l0000=ooooo`;o00003oooool2o`00023ooooo000Yooooo`03
o`000?oooooooooo00cooooo0_l00007ooooo`;o00007Oooool2o`0003Sooooo0_l0000Wooooo`;o
00008?ooool2o`00027ooooo0_l00009ooooo`;o00004Oooool2o`0000Cooooo0_l0000jooooo`00
3_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`0<ooooo`;o0000H?ooool2o`0000;ooooo0_l0000Foooo
o`;o0000;Oooool2o`0000Oooooo0_l0000Wooooo`;o00004oooool2o`0000?ooooo0_l0000Ioooo
o`;o00006_ooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo04Oooooo0_l0000Yooooo`;o00005_ooool2o`00
00;ooooo0_l0000Tooooo`;o00003?ooool2o`0002Oooooo0_l00004ooooo`;o00004_ooool2o`00
01Wooooo0_l0000Jooooo`003_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooo
ooooool00oooool3o`0002;ooooo0_l0000Sooooo`;o00002_ooool2o`0001oooooo0_l0000Hoooo
o`;o000000?oooooo`000?l000008Oooool2o`0001oooooo0_l0000Jooooo`;o0000BOooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool08_ooool2o`0002oooooo0_l0000Oooooo`;o00006oooool2o`0004;ooooo0_l00004oooo
o`;o0000Goooool000kooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`ooooo`;o00004Oooool2o`0001Kooooo0_l0001O
ooooo`003_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0eooooo`;o00005?ooool2o`0001cooooo0_l00004ooooo`;o0000?oooool2
o`00017ooooo0_l0001Cooooo`;o00008_ooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0=Oooool4o`0001;ooooo0_l0000L
ooooo`;o00001?ooool2o`0001_ooooo0_l0001gooooo`;o00002?ooool2o`0000Oooooo0_l0000R
ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000>?ooool2
o`0003kooooo0_l000000ooooooo0000o`00000@ooooo`;o0000IOooool2o`00013ooooo0_l00008
ooooo`;o0000:oooool002Wooooo00?o0000ooooooooool07Oooool2o`0000cooooo0_l0001:oooo
o`;o000000?oooooo`000?l00000Doooool2o`0002;ooooo0_l0000Fooooo`;o0000;oooool002Wo
oooo00?o0000ooooooooool07Oooool2o`0000cooooo0_l0000<ooooo`;o0000U?ooool2o`0003[o
oooo0_l0000_ooooo`00:Oooool00ol0003oooooooooo`0iooooo`;o0000c?ooool2o`0003?ooooo
000Yooooo`03o`000?oooooooooo04?ooooo0_l00032ooooo`;o0000<oooool002Wooooo0_l00014
ooooo`;o00004_ooool2o`0008oooooo0_l00010ooooo`;o00004?ooool002Wooooo00?o0000oooo
ooooool0Eoooool2o`0005gooooo0_l0000`ooooo`;o0000@?ooool2o`00013ooooo000Yooooo`03
o`000?oooooooooo0;Kooooo0_l00024ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEE
EOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolmooooo`001_ooool01Ol0003o
oooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00000>oooo
o`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOo
oooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool001oooooo1?l000000ol@413oooooooooo`03ooooo`03
o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo0ol0003oooooocgooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool001oooooo00?oEEEEofIVI_l00000oooooom7ooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .35309 Mdot
.02762 .33817 Mdot
.02952 .27513 Mdot
.03143 .30704 Mdot
.03333 .29493 Mdot
.03524 .33912 Mdot
.03714 .27851 Mdot
.03905 .3547 Mdot
.04095 .41265 Mdot
.04286 .29801 Mdot
.04476 .30986 Mdot
.04667 .39551 Mdot
.04857 .32141 Mdot
.05048 .27296 Mdot
.05238 .43323 Mdot
.05429 .29457 Mdot
.05619 .34868 Mdot
.0581 .31969 Mdot
.06 .29039 Mdot
.0619 .32963 Mdot
.06381 .36537 Mdot
.06571 .36552 Mdot
.06762 .38925 Mdot
.06952 .33465 Mdot
.07143 .43247 Mdot
.07333 .27938 Mdot
.07524 .33298 Mdot
.07714 .31687 Mdot
.07905 .34893 Mdot
.08095 .36182 Mdot
.08286 .3929 Mdot
.08476 .39683 Mdot
.08667 .39217 Mdot
.08857 .36505 Mdot
.09048 .33666 Mdot
.09238 .39504 Mdot
.09429 .39244 Mdot
.09619 .32786 Mdot
.0981 .39319 Mdot
.1 .37563 Mdot
.1019 .4089 Mdot
.10381 .34755 Mdot
.10571 .34973 Mdot
.10762 .31536 Mdot
.10952 .3222 Mdot
.11143 .28518 Mdot
.11333 .31928 Mdot
.11524 .37726 Mdot
.11714 .29186 Mdot
.11905 .38314 Mdot
.12095 .38653 Mdot
.12286 .37215 Mdot
.12476 .46588 Mdot
.12667 .35834 Mdot
.12857 .32628 Mdot
.13048 .40762 Mdot
.13238 .36872 Mdot
.13429 .33369 Mdot
.13619 .38318 Mdot
.1381 .32107 Mdot
.14 .30186 Mdot
.1419 .42618 Mdot
.14381 .40354 Mdot
.14571 .27265 Mdot
.14762 .4259 Mdot
.14952 .39407 Mdot
.15143 .30976 Mdot
.15333 .32019 Mdot
.15524 .30569 Mdot
.15714 .35114 Mdot
.15905 .28779 Mdot
.16095 .26871 Mdot
.16286 .31906 Mdot
.16476 .30231 Mdot
.16667 .40377 Mdot
.16857 .27458 Mdot
.17048 .46611 Mdot
.17238 .34241 Mdot
.17429 .36648 Mdot
.17619 .35595 Mdot
.1781 .39454 Mdot
.18 .36945 Mdot
.1819 .31753 Mdot
.18381 .33938 Mdot
.18571 .36311 Mdot
.18762 .26312 Mdot
.18952 .29341 Mdot
.19143 .33275 Mdot
.19333 .31521 Mdot
.19524 .32408 Mdot
.19714 .43698 Mdot
.19905 .45637 Mdot
.20095 .2668 Mdot
.20286 .2972 Mdot
.20476 .27515 Mdot
.20667 .44592 Mdot
.20857 .2749 Mdot
.21048 .40881 Mdot
.21238 .46548 Mdot
.21429 .28694 Mdot
.21619 .36039 Mdot
.2181 .29601 Mdot
.22 .41166 Mdot
.2219 .32773 Mdot
.22381 .36923 Mdot
.22571 .36441 Mdot
.22762 .31059 Mdot
.22952 .28452 Mdot
.23143 .26593 Mdot
.23333 .36256 Mdot
.23524 .27698 Mdot
.23714 .28782 Mdot
.23905 .40103 Mdot
.24095 .35529 Mdot
.24286 .47761 Mdot
.24476 .26567 Mdot
.24667 .31851 Mdot
.24857 .36153 Mdot
.25048 .37257 Mdot
.25238 .41215 Mdot
.25429 .33229 Mdot
.25619 .41422 Mdot
.2581 .39285 Mdot
.26 .33785 Mdot
.2619 .35646 Mdot
.26381 .31631 Mdot
.26571 .36709 Mdot
.26762 .44325 Mdot
.26952 .38232 Mdot
.27143 .29272 Mdot
.27333 .37439 Mdot
.27524 .36795 Mdot
.27714 .40674 Mdot
.27905 .31837 Mdot
.28095 .34763 Mdot
.28286 .34515 Mdot
.28476 .35581 Mdot
.28667 .36259 Mdot
.28857 .32245 Mdot
.29048 .40758 Mdot
.29238 .42838 Mdot
.29429 .44947 Mdot
.29619 .27211 Mdot
.2981 .29212 Mdot
.3 .34563 Mdot
.3019 .33792 Mdot
.30381 .36264 Mdot
.30571 .48101 Mdot
.30762 .34058 Mdot
.30952 .32855 Mdot
.31143 .38276 Mdot
.31333 .28643 Mdot
.31524 .28895 Mdot
.31714 .32439 Mdot
.31905 .26818 Mdot
.32095 .36649 Mdot
.32286 .37675 Mdot
.32476 .39321 Mdot
.32667 .37875 Mdot
.32857 .40045 Mdot
.33048 .37191 Mdot
.33238 .28332 Mdot
.33429 .35378 Mdot
.33619 .36105 Mdot
.3381 .3994 Mdot
.34 .37039 Mdot
.3419 .3754 Mdot
.34381 .36854 Mdot
.34571 .36329 Mdot
.34762 .30907 Mdot
.34952 .34918 Mdot
.35143 .39687 Mdot
.35333 .31101 Mdot
.35524 .32498 Mdot
.35714 .32187 Mdot
.35905 .32857 Mdot
.36095 .41072 Mdot
.36286 .44642 Mdot
.36476 .36906 Mdot
.36667 .28959 Mdot
.36857 .37041 Mdot
.37048 .34358 Mdot
.37238 .38587 Mdot
.37429 .28268 Mdot
.37619 .40859 Mdot
.3781 .29041 Mdot
.38 .42046 Mdot
.3819 .44888 Mdot
.38381 .37438 Mdot
.38571 .3671 Mdot
.38762 .33906 Mdot
.38952 .41283 Mdot
.39143 .33329 Mdot
.39333 .28249 Mdot
.39524 .43567 Mdot
.39714 .36358 Mdot
.39905 .39171 Mdot
.40095 .40811 Mdot
.40286 .305 Mdot
.40476 .44747 Mdot
.40667 .29541 Mdot
.40857 .29168 Mdot
.41048 .2912 Mdot
.41238 .26891 Mdot
.41429 .32127 Mdot
.41619 .45117 Mdot
.4181 .37385 Mdot
.42 .29798 Mdot
.4219 .34677 Mdot
.42381 .26685 Mdot
.42571 .26787 Mdot
.42762 .29532 Mdot
.42952 .32131 Mdot
.43143 .33828 Mdot
.43333 .36512 Mdot
.43524 .30611 Mdot
.43714 .37759 Mdot
.43905 .34318 Mdot
.44095 .36838 Mdot
.44286 .26949 Mdot
.44476 .35534 Mdot
.44667 .36596 Mdot
.44857 .31356 Mdot
.45048 .40466 Mdot
.45238 .35689 Mdot
.45429 .40012 Mdot
.45619 .32551 Mdot
.4581 .30416 Mdot
.46 .31256 Mdot
.4619 .29512 Mdot
.46381 .43243 Mdot
.46571 .40376 Mdot
.46762 .28837 Mdot
.46952 .2725 Mdot
.47143 .46191 Mdot
.47333 .33151 Mdot
.47524 .31515 Mdot
.47714 .41964 Mdot
.47905 .32338 Mdot
.48095 .32563 Mdot
.48286 .37546 Mdot
.48476 .36466 Mdot
.48667 .43128 Mdot
.48857 .32554 Mdot
.49048 .3542 Mdot
.49238 .28834 Mdot
.49429 .38054 Mdot
.49619 .29091 Mdot
.4981 .39913 Mdot
.5 .35858 Mdot
.5019 .28664 Mdot
.50381 .39759 Mdot
.50571 .39866 Mdot
.50762 .26676 Mdot
.50952 .30121 Mdot
.51143 .40576 Mdot
.51333 .31156 Mdot
.51524 .32814 Mdot
.51714 .29581 Mdot
.51905 .27442 Mdot
.52095 .38479 Mdot
.52286 .37797 Mdot
.52476 .30904 Mdot
.52667 .31412 Mdot
.52857 .39863 Mdot
.53048 .28428 Mdot
.53238 .30764 Mdot
.53429 .36369 Mdot
.53619 .32981 Mdot
.5381 .36929 Mdot
.54 .39878 Mdot
.5419 .33112 Mdot
.54381 .37863 Mdot
.54571 .31779 Mdot
.54762 .282 Mdot
.54952 .33741 Mdot
.55143 .36934 Mdot
.55333 .2726 Mdot
.55524 .27543 Mdot
.55714 .3909 Mdot
.55905 .27879 Mdot
.56095 .35535 Mdot
.56286 .36523 Mdot
.56476 .2642 Mdot
.56667 .32033 Mdot
.56857 .40481 Mdot
.57048 .40525 Mdot
.57238 .27989 Mdot
.57429 .27031 Mdot
.57619 .34493 Mdot
.5781 .33885 Mdot
.58 .31867 Mdot
.5819 .39682 Mdot
.58381 .45157 Mdot
.58571 .39623 Mdot
.58762 .42735 Mdot
.58952 .40963 Mdot
.59143 .26994 Mdot
.59333 .36902 Mdot
.59524 .44337 Mdot
.59714 .33311 Mdot
.59905 .43218 Mdot
.60095 .48251 Mdot
.60286 .32363 Mdot
.60476 .29596 Mdot
.60667 .36031 Mdot
.60857 .38784 Mdot
.61048 .42121 Mdot
.61238 .31194 Mdot
.61429 .39868 Mdot
.61619 .30756 Mdot
.6181 .29053 Mdot
.62 .33909 Mdot
.6219 .34511 Mdot
.62381 .34482 Mdot
.62571 .38612 Mdot
.62762 .27179 Mdot
.62952 .35955 Mdot
.63143 .35954 Mdot
.63333 .42659 Mdot
.63524 .27098 Mdot
.63714 .39255 Mdot
.63905 .43842 Mdot
.64095 .43725 Mdot
.64286 .30947 Mdot
.64476 .30229 Mdot
.64667 .32928 Mdot
.64857 .4044 Mdot
.65048 .28205 Mdot
.65238 .27076 Mdot
.65429 .27321 Mdot
.65619 .31664 Mdot
.6581 .36139 Mdot
.66 .41234 Mdot
.6619 .26873 Mdot
.66381 .33973 Mdot
.66571 .28403 Mdot
.66762 .26996 Mdot
.66952 .31633 Mdot
.67143 .33144 Mdot
.67333 .36978 Mdot
.67524 .28737 Mdot
.67714 .32543 Mdot
.67905 .45819 Mdot
.68095 .32869 Mdot
.68286 .37959 Mdot
.68476 .28448 Mdot
.68667 .4045 Mdot
.68857 .33488 Mdot
.69048 .36704 Mdot
.69238 .38319 Mdot
.69429 .26401 Mdot
.69619 .34715 Mdot
.6981 .44739 Mdot
.7 .38636 Mdot
.7019 .35383 Mdot
.70381 .39141 Mdot
.70571 .30798 Mdot
.70762 .31942 Mdot
.70952 .39172 Mdot
.71143 .31828 Mdot
.71333 .38932 Mdot
.71524 .42334 Mdot
.71714 .35372 Mdot
.71905 .40992 Mdot
.72095 .39458 Mdot
.72286 .38821 Mdot
.72476 .27052 Mdot
.72667 .33054 Mdot
.72857 .43115 Mdot
.73048 .37575 Mdot
.73238 .27008 Mdot
.73429 .39121 Mdot
.73619 .34849 Mdot
.7381 .33251 Mdot
.74 .35941 Mdot
.7419 .41083 Mdot
.74381 .32947 Mdot
.74571 .38727 Mdot
.74762 .41233 Mdot
.74952 .39047 Mdot
.75143 .34583 Mdot
.75333 .37935 Mdot
.75524 .43 Mdot
.75714 .47639 Mdot
.75905 .41525 Mdot
.76095 .35401 Mdot
.76286 .27656 Mdot
.76476 .43142 Mdot
.76667 .30118 Mdot
.76857 .27322 Mdot
.77048 .37706 Mdot
.77238 .35207 Mdot
.77429 .2671 Mdot
.77619 .30646 Mdot
.7781 .29968 Mdot
.78 .31831 Mdot
.7819 .3726 Mdot
.78381 .32893 Mdot
.78571 .44036 Mdot
.78762 .38576 Mdot
.78952 .34935 Mdot
.79143 .46521 Mdot
.79333 .33693 Mdot
.79524 .32327 Mdot
.79714 .3057 Mdot
.79905 .27144 Mdot
.80095 .37072 Mdot
.80286 .39689 Mdot
.80476 .33186 Mdot
.80667 .28128 Mdot
.80857 .26586 Mdot
.81048 .26739 Mdot
.81238 .39504 Mdot
.81429 .28174 Mdot
.81619 .39185 Mdot
.8181 .29128 Mdot
.82 .29649 Mdot
.8219 .27916 Mdot
.82381 .29073 Mdot
.82571 .36502 Mdot
.82762 .29255 Mdot
.82952 .29736 Mdot
.83143 .40058 Mdot
.83333 .40474 Mdot
.83524 .27733 Mdot
.83714 .33487 Mdot
.83905 .31207 Mdot
.84095 .37813 Mdot
.84286 .34952 Mdot
.84476 .3146 Mdot
.84667 .42395 Mdot
.84857 .43783 Mdot
.85048 .342 Mdot
.85238 .4745 Mdot
.85429 .30606 Mdot
.85619 .28292 Mdot
.8581 .42412 Mdot
.86 .43326 Mdot
.8619 .32218 Mdot
.86381 .38887 Mdot
.86571 .46091 Mdot
.86762 .28615 Mdot
.86952 .2686 Mdot
.87143 .33481 Mdot
.87333 .39333 Mdot
.87524 .34856 Mdot
.87714 .45191 Mdot
.87905 .28231 Mdot
.88095 .36152 Mdot
.88286 .33378 Mdot
.88476 .26585 Mdot
.88667 .28258 Mdot
.88857 .27982 Mdot
.89048 .3589 Mdot
.89238 .26575 Mdot
.89429 .35783 Mdot
.89619 .33477 Mdot
.8981 .34302 Mdot
.9 .37111 Mdot
.9019 .39795 Mdot
.90381 .34333 Mdot
.90571 .42881 Mdot
.90762 .304 Mdot
.90952 .36028 Mdot
.91143 .39182 Mdot
.91333 .33512 Mdot
.91524 .3621 Mdot
.91714 .34192 Mdot
.91905 .36107 Mdot
.92095 .36355 Mdot
.92286 .3546 Mdot
.92476 .29942 Mdot
.92667 .34501 Mdot
.92857 .35877 Mdot
.93048 .40566 Mdot
.93238 .36313 Mdot
.93429 .27334 Mdot
.93619 .36175 Mdot
.9381 .35011 Mdot
.94 .26719 Mdot
.9419 .32279 Mdot
.94381 .35466 Mdot
.94571 .33283 Mdot
.94762 .27493 Mdot
.94952 .32156 Mdot
.95143 .39493 Mdot
.95333 .28224 Mdot
.95524 .36554 Mdot
.95714 .27202 Mdot
.95905 .33752 Mdot
.96095 .27002 Mdot
.96286 .4722 Mdot
.96476 .27375 Mdot
.96667 .32768 Mdot
.96857 .4167 Mdot
.97048 .39596 Mdot
.97238 .30527 Mdot
.97429 .36567 Mdot
.97619 .38936 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooocgooooo0006
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol0003oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_oo
ool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o
0000<_ooool2o`0007Oooooo0_l0000Xooooo`;o0000I_ooool002Wooooo00?o0000ooooooooool0
<Oooool2o`0000;ooooo0_l00008ooooo`;o00000_ooool2o`0001Kooooo0_l0000Pooooo`;o0000
6Oooool2o`00013ooooo0_l0000Xooooo`;o00006?ooool2o`0000Wooooo0_l0000Fooooo`;o0000
00?oooooo`000?l000003Oooool2o`0001Oooooo000Yooooo`03o`000?oooooooooo02Sooooo0_l0
0006ooooo`Co000000So410@o`000?l0003ok^k^oc8b<_l0003o<S8bonk^kP?ooooo0ol000000olb
<S;o0000o`00000Fooooo`;o00004?ooool5o`0000?ooooo00Cok^k^oc8b<_l0003o<S8b0_l00002
ooooo`?o000000?o<S8bonk^k_ooool00_l0000Cooooo`;o00004?ooool00onHV9So410@o`000002
o`0000?ooooo00Gok^k^o`000?l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0_ooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`00017ooooo1?l00007ooooo`;o0000
00?o410@ooooooooool00_l000001?lb<S;o0000oc8b<_o^k^h2ooooo`;o000000Co<S8bo`000?l0
003ok^k^4?ooool2o`0000?ooooo0_l000000ooooooo0000o`00000=ooooo`;o000000GoA4A4o`00
0?l0003o<S8bomgMg@02o`000005onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo000Yooooo`03o`000?oooooooooo00Gooooo0_l0000Looooo`;o00000ooo
ool2o`000003ooooool0003o000000Gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0@ooooo`;o00005oooool01OnHV9So
8B4Qonk^k_ooooooA4A400?ooooo00CoMgMgoiRHV?ooooooV9RH0_l00002ooooo`06ogMgMonHV9So
oooooiRHV?mgMgOooooo0_l00007ooooo`;o00003_ooool2o`0000Wooooo0_l000001?oooooo410@
okZj^_ooool2o`0000?ooooo00GoMgMgo`000?l0003oV9RHogMgM`03ooooo`04ogMgMonHV9Sooooo
oiRHV0;o000000?oooooo`000?l000000oooool7o`00017ooooo1?l00008ooooo`0:o`000?oooooo
0000o`000?ooooooMgMgoiRHV?ooooooV9RHogMgM`;ooooo0_l000001?nHV9SooooooiRHV?mgMgL@
ooooo`;o00004oooool2o`0000Gooooo1Ol000001?nHV9SooooooiRHV?mgMgL3ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool002Wooooo0ol00005ooooo`;o00007?ooool2o`0000Kooooo0_l0
0005ooooo`04o`000?ooooooooooooooo`Co000000?ooooooa0@4?ooool00_ooool01Ol@413o0000
o`000?oooooo410@013ooooo0_l0000Hooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooo
oooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002_ooool2o`0000kooooo0_l00009
ooooo`;o00001Oooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooo
oa0@4003ooooo`;o00001oooool2o`0001kooooo1ol000000ooooooo410@ooooo`02ooooo`05oa0@
4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`;o00007_ooool2o`0000;o
oooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo00Go410@oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo007ooooo000Yooooo`?o000000?oooooo`000?l000002Oooool2o`00
02Cooooo00Co0000oooooooooooooooo1?l000000ooooooo0000ooooo`02ooooo`?o000000?ooooo
o`000?ooool0:_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000002Gooooo0ol00003ooooo`;o00000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00000Xooooo`03odA4A?oMgMgooooo
00;o00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Ko0000ooooooooooooooooo`00
0?ooool2o`0000;ooooo0_l0000?ooooo`;o00004Oooool2o`000003oooooomgMgOo<S8b00;ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool002Wo
oooo00Co0000oooooooooooooooo0_l00009ooooo`;o00009?ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000001_ooooo0_l0
000<ooooo`;o000000CoooooogMgMomVIVKooooo0ol00003ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`0Qooooo`;o000000?oooooo`000?l000000_ooool00ol@413o
0000o`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000Oooooo0_l0000Oooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000oooooooooooooooo
o`000003ooooo`Go000000?oooooo`000?l000002Oooool2o`0000Gooooo0_l000000ooooooo0000
o`00000Aooooo`05o`000?lQ8B7o0000o`000?o<c<`00_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`00:Oooool00ol0003oooooooooo`0Hoooo
o`;o00006?ooool00ol0003oooooooooo`02ooooo`03oa0@4?oooooooooo00;o00000_ooool2o`00
00?ooooo00?o410@ooooooooool04oooool2o`0000Cooooo0_l0000<ooooo`;o00000_ooool01Ol0
003oooooo`000?l0003o410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oo
oooooooo01;ooooo0_l00007ooooo`;o00001?ooool2o`0000Kooooo00?o^[Zjob4Q8Oooool00_oo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4007ooooo`;o
00000oooool2o`0000Cooooo0_l0000Eooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooo
oooooooooa0@4003ooooo`03oa0@4?l0003o000000;o00003?ooool2o`0000;ooooo0_l000001?oo
oooo0000o`000?ooool2o`00017ooooo00Co0000ooooool0003o00000oooool01Ol@413ooooooooo
oooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`00:Oooool00ol0003ooooo
ooooo`0Hooooo`;o00003_ooool2o`0000Sooooo00?o0000ooooooooool00_ooool00omgMgOoV9RH
ooooo`02o`0000;ooooo0_l000001?nHV9So0000o`000?mgMgLEooooo`?o00003oooool3o`000004
okZj^_ooooooV9RHoa0@40?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02Oooool2o`0000Kooooo0_l000000ooooooo0000o`000007ooooo`;o00002Ooo
ool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03?ooool2o`000004ooooool0003o0000ooooo`;o00005Oooool0
0oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg013ooooo0_l0000Gooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wooooo00?o0000oooooooo
ool02?ooool2o`00013ooooo0_l0000<ooooo`;o00001_ooool00omEEEGoIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?l0003ok^k^00Sooooo0_l00006
ooooo`;o00001?ooool2o`0000oooooo0_l000001OnHV9So0000o`000?lQ8B7oc<c<00?ooooo00?o
k^k^oc8b<_l000000ol00002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02Oooool2o`0000Kooooo
0ol0000Dooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^o`000?l0003o<S8bonk^kP0?ooooo`;o00006Oooool00omgMgOo0000ooooo`03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go0000
9?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool002Wooooo1?l00005ooooo`Co00004?ooool2o`0001Kooooo0_l00007ooooo`;o
00003oooool2o`0000Kooooo0_l0000Hooooo`;o00001oooool4o`0000?ooooo0_l00009ooooo`;o
00002Oooool2o`0000Gooooo0_l0000Jooooo`;o00000_ooool2o`0003oooooo1Ol0000kooooo`00
:Oooool01Ol0003oooooo`000?l0003ooooo00;o00000_ooool2o`0002[ooooo0_l00002ooooo`;o
00000oooool2o`0003[ooooo0_l00003ooooo`Co00002Oooool2o`00013ooooo0_l0000Jooooo`;o
0000@oooool2o`000003ooooool0003o000001gooooo0_l0000Looooo`00:Oooool00ol0003ooooo
ooooo`02ooooo`;o00007_ooool2o`0000Kooooo0_l0000:ooooo`;o0000A?ooool2o`0001[ooooo
0_l0000Zooooo`;o00009Oooool2o`0000;ooooo0_l0000;ooooo`;o000000?oooooo`000?l00000
7Oooool2o`0001cooooo000Yooooo`03o`000?oooooooooo02;ooooo0_l00003ooooo`;o000000?o
ooooo`000?l00000B_ooool2o`00013ooooo0_l0000>ooooo`;o0000:_ooool2o`0002Gooooo0_l0
0002ooooo`;o00001?ooool2o`00027ooooo0_l0000Cooooo`;o00003Oooool002Wooooo00Co0000
ooooool0003o00009_ooool2o`0004gooooo0_l00009ooooo`;o00001Oooool2o`0001Kooooo0_l0
000Iooooo`;o00006oooool2o`0001Cooooo0_l00005ooooo`;o00004?ooool2o`0000oooooo0_l0
000Cooooo`;o00003Oooool0027oooooool00014o`0000Cooooo000Yooooo`03o`000?oooooooooo
00?ooooo0_l00004ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`02o`0000Oooooo00?o0000ooooooooool02Oooool01?l0003oooooooooooooool2
o`0000Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00;ooooo1?l00003ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool3
o`0000;ooooo0_l00005ooooo`03o`000?oooooooooo00Oooooo1_l00009ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool00_ooool2o`0000Gooooo00Co0000ooooool0003o00002?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooooooo`Co00001Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0:ooooo`00:Oooool00ol0003oooooooooo`0=ooooo`;o00002?ooool2o`0001Kooooo0_l0
0002ooooo`;o00001Oooool00ol0003oooooooooo`0<ooooo`;o0000;Oooool00ol0003ooooooooo
o`0:ooooo`;o00000_ooool2o`0000;ooooo0_l0000?ooooo`;o00001?ooool2o`0000oooooo00?o
0000ooooooooool00_ooool2o`0000cooooo0_l00002ooooo`;o00009?ooool00ol0003ooooooooo
o`0=ooooo`Co0000:Oooool00ol0003oooooooooo`0:ooooo`00:Oooool00ol0003oooooooooo`07
ooooo`;o00001?ooool2o`0000Sooooo1?l00006ooooo`;o00000oooool2o`000003ooooool0003o
000000Cooooo0_l00002ooooo`;o00003oooool2o`0000?ooooo0_l00003ooooo`;o0000?Oooool2
o`0001Gooooo0_l00005ooooo`;o00000_ooool2o`0001Oooooo0_l00002ooooo`;o00002_ooool3
o`0001Cooooo0_l0001;ooooo`00:Oooool00ol0003oooooooooo`04ooooo`;o000000?oooooo`00
0?l000003oooool3o`0000Kooooo0_l00003ooooo`;o000000?oooooo`000?l000002?ooool2o`00
00oooooo0_l00008ooooo`;o000000?oooooo`000?l000005?ooool2o`00017ooooo0_l00003oooo
o`;o00003_ooool2o`0001[ooooo0_l00002ooooo`;o00001Oooool2o`00023ooooo0ol0000Doooo
o`;o00000oooool2o`0001Cooooo0_l0000Gooooo`;o000000?oooooo`000?l000005?ooool002Wo
oooo0_l00005ooooo`;o00004_ooool2o`0000Cooooo0_l0000Cooooo`;o00007?ooool2o`0000So
oooo0_l0000:ooooo`;o00004Oooool2o`0000?ooooo0_l00006ooooo`;o00001_ooool2o`000003
ooooool0003o000002;ooooo0_l0000Fooooo`;o00009?ooool2o`0001Cooooo0_l0000Gooooo`;o
000000?oooooo`000?l000005?ooool002Wooooo00?o0000ooooooooool02Oooool2o`0000Wooooo
0_l00008ooooo`;o00007?ooool2o`0001[ooooo0_l000000ooooooo0000o`00000:ooooo`?o0000
7Oooool2o`0000Kooooo0_l000000ooooooo0000o`000006ooooo`;o00001Oooool2o`0002;ooooo
0_l00007ooooo`Co00003?ooool2o`0000Cooooo0_l0000;ooooo`;o0000>?ooool2o`0000oooooo
000Yooooo`03o`000?oooooooooo00Wooooo0_l00002ooooo`;o00001Oooool2o`0000[ooooo0_l0
000@ooooo`;o00002?ooool2o`0000Sooooo0_l0000@ooooo`;o00003_ooool2o`0000Sooooo0_l0
000Iooooo`;o00002oooool2o`0000Gooooo1?l0000@ooooo`;o00003_ooool2o`0000Kooooo0_l0
00000ooooooo0000o`00000<ooooo`;o00000_ooool4o`0000_ooooo0_l00004ooooo`;o0000;?oo
ool2o`0000Cooooo0_l0000?ooooo`00:Oooool00ol0003oooooooooo`0;ooooo`Co00000oooool2
o`0000cooooo0_l0000@ooooo`;o00004_ooool2o`0002[ooooo0_l0000Iooooo`;o00005?ooool2
o`00013ooooo0_l0000Fooooo`;o00000oooool2o`0000kooooo0_l0000Cooooo`;o00002Oooool2
o`0000Wooooo0_l000000ooooooo0000o`000003ooooo`;o00000oooool2o`0000Wooooo0_l0000E
ooooo`00:Oooool2o`000003ooooool0003o000000Wooooo0_l00005ooooo`;o00007?ooool2o`00
01Kooooo0_l0000<ooooo`;o00006Oooool2o`0000cooooo0_l0000Tooooo`;o00001oooool2o`00
00cooooo0_l0000<ooooo`;o00001_ooool2o`00023ooooo0_l0000<ooooo`;o00002Oooool2o`00
0003ooooool0003o000000?ooooo0_l00003ooooo`;o00003Oooool2o`00017ooooo000Yooooo`;o
000000?oooooo`000?l00000:_ooool2o`0000;ooooo0_l0000Fooooo`;o00003?ooool4o`0001Oo
oooo0_l0000<ooooo`;o00009?ooool2o`0000Oooooo0_l0000<ooooo`;o00003?ooool2o`0002So
oooo0_l0000@ooooo`;o00003Oooool2o`0000Gooooo0_l0000;ooooo`;o00004Oooool002Wooooo
00?o0000ooooooooool0;?ooool2o`0002;ooooo0_l00003ooooo`;o000000?oooooo`000?l00000
4_ooool2o`0001Cooooo0_l0000Zooooo`;o00003Oooool2o`0002Oooooo0_l0000Nooooo`;o0000
3Oooool4o`0000?ooooo0_l000000ooooooo0000o`00000Kooooo`00:Oooool00ol0003ooooooooo
o`07ooooo`;o00001Oooool2o`0000Kooooo0_l0000gooooo`?o00000oooool2o`0000kooooo0_l0
0005ooooo`;o00003_ooool2o`0000Cooooo0_l0000Zooooo`;o00003Oooool2o`0001Gooooo0_l0
000;ooooo`;o00000oooool2o`0002Kooooo0_l00007ooooo`;o00001_ooool2o`0001_ooooo000Y
ooooo`03o`000?oooooooooo00Oooooo0_l00005ooooo`;o00001_ooool3o`0000kooooo0_l0000V
ooooo`;o00005?ooool2o`0001Gooooo0_l0001Fooooo`;o00002oooool2o`0000[ooooo0_l00003
ooooo`;o00004?ooool2o`0000Sooooo0_l0000Booooo`;o00006?ooool002Wooooo0_l00002oooo
o`;o00005?ooool2o`0000kooooo0_l0000Iooooo`;o00007?ooool2o`0002;ooooo0_l0000<oooo
o`;o00005Oooool2o`0002_ooooo0_l00003ooooo`;o00003?ooool2o`0000;ooooo0_l00003oooo
o`;o00004?ooool2o`0001Oooooo0_l00003ooooo`Co00005_ooool002Wooooo0_l00002ooooo`;o
00006_ooool2o`0000kooooo0_l0000Cooooo`;o00001Oooool2o`0000Gooooo0_l0000>ooooo`;o
00008_ooool4o`0000[ooooo0_l000000ooooooo0000o`00000Booooo`;o0000:oooool2o`0000?o
oooo0_l0000<ooooo`;o0000:Oooool2o`0000Oooooo0_l00005ooooo`;o00005_ooool002Wooooo
00?o0000ooooooooool07Oooool2o`0000kooooo0_l0000;ooooo`;o00002Oooool2o`0000;ooooo
0_l00005ooooo`;o00003oooool2o`0002?ooooo0_l0000=ooooo`;o00008Oooool2o`0000Gooooo
0ol00006ooooo`;o00006Oooool2o`0002_ooooo0_l000001?oooooo0000o`000?l00003ooooo`;o
000000Coooooo`000?l0003ooooo0_l0000Kooooo`00:Oooool00ol0003oooooooooo`0?ooooo`;o
00007oooool2o`0000Sooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l0000:oooo
o`;o00000oooool2o`0000Wooooo0_l000000ooooooo0000o`00000>ooooo`;o00006_ooool2o`00
00kooooo0_l0000Fooooo`;o00001Oooool3o`0000Kooooo0_l0000Iooooo`;o0000:oooool2o`00
0003ooooool0003o000000Cooooo2ol0000Hooooo`00:Oooool00ol0003oooooooooo`09ooooo`?o
00000oooool4o`0001[ooooo0_l000000ooooooo0000o`00000;ooooo`;o000000?oooooo`000?l0
00002?ooool2o`0000Gooooo0_l00003ooooo`;o00001?ooool2o`0000Kooooo0_l0000;ooooo`;o
000000?oooooo`000?l000002_ooool2o`0000;ooooo0_l0000:ooooo`;o00003_ooool2o`0000So
oooo0_l0000Wooooo`;o0000:Oooool2o`0001_ooooo1?l000000ooooooo0000o`000002o`0000Co
oooo0_l00004ooooo`;o00003?ooool002Wooooo00?o0000ooooooooool02Oooool3o`0000Gooooo
0_l0000<ooooo`;o00003?ooool3o`0000gooooo0_l0000;ooooo`;o000000?oooooo`000?l00000
3Oooool2o`0000Cooooo0ol00005ooooo`?o00001?ooool2o`0000gooooo1_l0000Looooo`;o0000
0_ooool2o`0000;ooooo0_l00007ooooo`;o00006?ooool2o`0000Cooooo0_l0000Qooooo`;o0000
1_ooool2o`0002Sooooo0_l00004ooooo`;o00003?ooool002Wooooo0_l0000Mooooo`;o000000?o
ooooo`000?l000003Oooool2o`0000gooooo0_l00006ooooo`;o00001_ooool2o`00013ooooo0_l0
00001?oooooo0000o`000?l00005ooooo`?o00003_ooool2o`0000Gooooo0_l0000Nooooo`;o0000
0_ooool2o`0000_ooooo0_l0000Hooooo`;o00008Oooool2o`0000Cooooo0_l0000Nooooo`;o0000
9?ooool002Wooooo00?o0000ooooooooool05Oooool2o`0000Gooooo0_l0000Wooooo`;o00001_oo
ool2o`0000gooooo0_l000000ooooooo0000o`000002ooooo`;o00002oooool2o`0000Wooooo0_l0
000Cooooo`;o0000COooool2o`0000_ooooo0_l00002ooooo`;o00009?ooool2o`0002Cooooo0006
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Eooooo`;o00000oooool2o`00037ooooo
0_l0000=ooooo`Co00000oooool2o`0000_ooooo0_l0000?ooooo`;o00003Oooool2o`0000_ooooo
0_l00004ooooo`;o0000:oooool2o`0000gooooo0_l00006ooooo`;o00000oooool2o`0001Gooooo
0_l0000gooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01[o
oooo0ol00003ooooo`;o0000:Oooool2o`0000cooooo0_l00003ooooo`;o00008Oooool2o`00017o
oooo0_l00007ooooo`;o00001?ooool2o`0002_ooooo0_l000000ooooooo0000o`00000Booooo`;o
00006_ooool2o`0003Oooooo0006ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06oooool3o`0000;o
oooo0_l0000Yooooo`;o00003?ooool2o`00017ooooo0_l0000Vooooo`;o00001_ooool2o`00023o
oooo0_l0000Cooooo`;o000000?oooooo`000?l000006_ooool2o`0004Sooooo0006ooooo`05o`00
0?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Co
oooo0ol0000:ooooo`;o00004?ooool2o`0004kooooo0_l0000^ooooo`;o00006_ooool2o`0000Co
oooo0_l0000Fooooo`;o00000_ooool2o`000003ooooool0003o000000Gooooo0_l0000<ooooo`;o
00005_ooool2o`0002?ooooo0_l0000;ooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool02_ooool2o`0000Cooooo0_l000000ooooooo0000o`00001Pooooo`;o0000<Oooool2o`00
00kooooo0_l00007ooooo`;o00005?ooool5o`000003ooooool0003o000000;ooooo0_l000000ooo
oooo0000o`000002o`0001?ooooo0_l0000=ooooo`;o00003_ooool2o`0001?ooooo0_l0000;oooo
o`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo0_l00009ooooo`Oo00003oooool2o`00
00Oooooo0_l0000Hooooo`;o00004oooool2o`0001Kooooo0_l0000aooooo`;o00005oooool2o`00
01Cooooo1?l000000ooooooo0000o`000003ooooo`;o00000oooool2o`0001;ooooo0ol0000@oooo
o`;o00002oooool2o`0000_ooooo0_l0000Cooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01?ooool2o`0000Wooooo1ol0000?ooooo`;o00001oooool2o`0001Sooooo0_l0000C
ooooo`;o00001oooool2o`0002oooooo0_l00006ooooo`;o000000?oooooo`000?l000003?ooool3
o`0000Oooooo0_l0000Pooooo`;o00006Oooool2o`000003ooooool0003o0000017ooooo0_l00008
ooooo`;o00003_ooool2o`0000Cooooo0_l0000=ooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003ooooooooo
o`0@ooooo`;o0000;oooool2o`0001_ooooo0_l000000ooooooo0000o`000003ooooo`;o00007ooo
ool2o`0000cooooo1?l00006ooooo`;o000000?oooooo`000?l000003?ooool3o`0000Oooooo0_l0
000kooooo`;o00001oooool2o`0001Gooooo0_l0000Dooooo`;o00003Oooool002Wooooo0_l0000T
ooooo`;o00001Oooool2o`0001Gooooo0_l0000Kooooo`;o000000?oooooo`000?l000008_ooool4
o`000003ooooool0003o000000Wooooo0_l0000Dooooo`;o00006?ooool2o`0000[ooooo0_l0000]
ooooo`?o0000>Oooool002Wooooo00?o0000ooooooooool07oooool2o`0000;ooooo0_l00005oooo
o`;o00008_ooool2o`0000;ooooo0_l0000Rooooo`;o00003Oooool2o`0000?ooooo0_l0000=oooo
o`;o00004?ooool3o`0001Oooooo0_l0000:ooooo`;o0000;_ooool2o`0001gooooo0_l0000Joooo
o`00:Oooool00ol0003oooooooooo`0Eooooo`;o00002?ooool2o`0001Oooooo0_l0000Dooooo`;o
00000_ooool2o`0001Gooooo0_l00003ooooo`;o00001_ooool2o`00027ooooo0_l0000Aooooo`;o
00001?ooool2o`0002Sooooo0_l00005ooooo`;o0000>oooool2o`0001[ooooo000Yooooo`03o`00
0?oooooooooo00;ooooo0_l0000Aooooo`;o00008Oooool2o`000003ooooool0003o000000Wooooo
0ol0000Pooooo`;o00000oooool2o`0000;ooooo0_l0000nooooo`;o00005Oooool2o`00017ooooo
0_l00005ooooo`Co0000EOooool002Wooooo00?o0000ooooooooool00_ooool2o`0003Oooooo0_l0
0009ooooo`?o0000:Oooool2o`0005Gooooo0_l0000Jooooo`;o00000_ooool2o`00047ooooo0_l0
000>ooooo`00:Oooool2o`00073ooooo0_l0000Mooooo`;o0000FOooool2o`00047ooooo0_l0000>
ooooo`00:Oooool00ol0003oooooooooo`1_ooooo`;o00007Oooool2o`0002Wooooo0_l0000Poooo
o`;o0000Goooool002Wooooo00?o0000ooooooooool08_ooool4o`0009?ooooo0_l00005ooooo`;o
00006Oooool2o`0002Sooooo0_l00002ooooo`;o0000<Oooool002Wooooo00?o0000ooooooooool0
8_ooool4o`0002gooooo0_l0001Mooooo`;o00003?ooool2o`0002Gooooo0_l0000Looooo`;o0000
0_ooool2o`0000gooooo0_l0000Rooooo`00:Oooool00ol0003oooooooooo`0<ooooo`;o0000AOoo
ool2o`0003Gooooo0_l00005ooooo`;o00007oooool2o`000003ooooool0003o000002Sooooo0_l0
0006ooooo`;o00000_ooool2o`0002_ooooo0_l0000Rooooo`00:Oooool2o`0000Kooooo0_l00005
ooooo`;o0000I_ooool2o`0001Cooooo0_l00005ooooo`;o00008_ooool2o`0002Sooooo0_l0000:
ooooo`;o00007?ooool2o`00037ooooo000Yooooo`03o`000?oooooooooo00Gooooo0_l0000]oooo
o`;o0000?_ooool2o`0004cooooo0ol00010ooooo`;o00000_ooool2o`00037ooooo000Yooooo`03
o`000?oooooooooo03Cooooo0_l0002<ooooo`?o0000;?ooool2o`0001;ooooo0_l0000eooooo`00
:Oooool00ol0003oooooooooo`1;ooooo`;o0000Ioooool2o`0003_ooooo0_l00019ooooo`00:Ooo
ool00ol0003oooooooooo`0gooooo`;o00004_ooool2o`0001cooooo0_l0000<ooooo`;o0000>ooo
ool2o`0001oooooo0_l0001Uooooo`00:Oooool2o`0003Sooooo0_l0000Jooooo`;o00005?ooool2
o`0000Cooooo0_l00006ooooo`;o000000?oooooo`000?l00000=?ooool2o`0002?ooooo0_l0001U
ooooo`00:Oooool00ol0003oooooooooo`1Cooooo`;o00006_ooool2o`0000Wooooo0_l0000doooo
o`;o0000GOooool2o`0002_ooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo03Gooooo0_l0003H
ooooo`;o0000:oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo03Gooooo0_l0002Hooooo`;o0000>_ooool2
o`0002oooooo000>ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03
ooooo`?o0000S?ooool2o`00047ooooo0_l0000jooooo`;o0000;oooool000kooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool07Oooool2
o`0000cooooo0_l0000<ooooo`;o0000DOooool2o`0006Gooooo0_l00017ooooo`003_ooool01Ol0
003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oo
oooooooo01gooooo0_l0000<ooooo`;o00003?ooool2o`000;Sooooo0_l00017ooooo`003_ooool0
1Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`3oooooob_ooooo0_l0000@ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`3Xooooo`;o00007Oooool2o`00027ooooo0_l0
000@ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000A?oo
ool2o`000:?ooooo0_l0000Mooooo`;o0000<oooool002Wooooo00?o0000ooooooooool0@oooool2
o`0001;ooooo0_l0001Mooooo`;o0000Q?ooool002Wooooo00?o0000ooooooooool0Eoooool2o`00
05gooooo0_l00024ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0
003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo
410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolm
ooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@
400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooo
oooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo
0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`;o0000
oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000
oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool001oooooo1?l000000ol@
413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
0ol0003oooooocgooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool001oooooo00?oEEEEofIVI_l00000oooooom7ooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .26578 Mdot
.02762 .24798 Mdot
.02952 .3012 Mdot
.03143 .25917 Mdot
.03333 .25051 Mdot
.03524 .25419 Mdot
.03714 .2786 Mdot
.03905 .24457 Mdot
.04095 .33652 Mdot
.04286 .25538 Mdot
.04476 .25501 Mdot
.04667 .29679 Mdot
.04857 .23675 Mdot
.05048 .26515 Mdot
.05238 .37058 Mdot
.05429 .25768 Mdot
.05619 .27304 Mdot
.0581 .23614 Mdot
.06 .25338 Mdot
.0619 .23601 Mdot
.06381 .27468 Mdot
.06571 .27834 Mdot
.06762 .32363 Mdot
.06952 .24247 Mdot
.07143 .36359 Mdot
.07333 .2534 Mdot
.07524 .27131 Mdot
.07714 .25502 Mdot
.07905 .24847 Mdot
.08095 .2743 Mdot
.08286 .32559 Mdot
.08476 .30613 Mdot
.08667 .2941 Mdot
.08857 .30127 Mdot
.09048 .25517 Mdot
.09238 .32112 Mdot
.09429 .30513 Mdot
.09619 .26346 Mdot
.0981 .31212 Mdot
.1 .2662 Mdot
.1019 .31679 Mdot
.10381 .26808 Mdot
.10571 .26784 Mdot
.10762 .23871 Mdot
.10952 .24144 Mdot
.11143 .25216 Mdot
.11333 .25976 Mdot
.11524 .27558 Mdot
.11714 .24729 Mdot
.11905 .29469 Mdot
.12095 .29032 Mdot
.12286 .27417 Mdot
.12476 .39972 Mdot
.12667 .28233 Mdot
.12857 .2469 Mdot
.13048 .32406 Mdot
.13238 .25895 Mdot
.13429 .25566 Mdot
.13619 .28651 Mdot
.1381 .24124 Mdot
.14 .24854 Mdot
.1419 .34064 Mdot
.14381 .33322 Mdot
.14571 .27315 Mdot
.14762 .35994 Mdot
.14952 .3002 Mdot
.15143 .25641 Mdot
.15333 .26409 Mdot
.15524 .25259 Mdot
.15714 .25577 Mdot
.15905 .24629 Mdot
.16095 .29194 Mdot
.16286 .26025 Mdot
.16476 .25587 Mdot
.16667 .33374 Mdot
.16857 .29078 Mdot
.17048 .40024 Mdot
.17238 .27294 Mdot
.17429 .26679 Mdot
.17619 .29301 Mdot
.1781 .3249 Mdot
.18 .28702 Mdot
.1819 .26414 Mdot
.18381 .25832 Mdot
.18571 .25368 Mdot
.18762 .27925 Mdot
.18952 .25069 Mdot
.19143 .26322 Mdot
.19333 .24588 Mdot
.19524 .26759 Mdot
.19714 .37397 Mdot
.19905 .38996 Mdot
.20095 .27895 Mdot
.20286 .24942 Mdot
.20476 .2702 Mdot
.20667 .36852 Mdot
.20857 .26377 Mdot
.21048 .3314 Mdot
.21238 .39774 Mdot
.21429 .24712 Mdot
.21619 .27547 Mdot
.2181 .24534 Mdot
.22 .3258 Mdot
.2219 .24276 Mdot
.22381 .27814 Mdot
.22571 .29906 Mdot
.22762 .24399 Mdot
.22952 .25507 Mdot
.23143 .28019 Mdot
.23333 .26962 Mdot
.23524 .26264 Mdot
.23714 .26096 Mdot
.23905 .31405 Mdot
.24095 .25619 Mdot
.24286 .41469 Mdot
.24476 .29131 Mdot
.24667 .25146 Mdot
.24857 .25309 Mdot
.25048 .26679 Mdot
.25238 .34595 Mdot
.25429 .24148 Mdot
.25619 .32045 Mdot
.2581 .32907 Mdot
.26 .23994 Mdot
.2619 .26169 Mdot
.26381 .26255 Mdot
.26571 .27045 Mdot
.26762 .36508 Mdot
.26952 .31525 Mdot
.27143 .26492 Mdot
.27333 .29271 Mdot
.27524 .28716 Mdot
.27714 .31545 Mdot
.27905 .24188 Mdot
.28095 .26438 Mdot
.28286 .24462 Mdot
.28476 .25219 Mdot
.28667 .26366 Mdot
.28857 .26281 Mdot
.29048 .32061 Mdot
.29238 .35862 Mdot
.29429 .38645 Mdot
.29619 .2716 Mdot
.2981 .25331 Mdot
.3 .26865 Mdot
.3019 .24082 Mdot
.30381 .25361 Mdot
.30571 .41728 Mdot
.30762 .27801 Mdot
.30952 .25892 Mdot
.31143 .27058 Mdot
.31333 .24789 Mdot
.31524 .25497 Mdot
.31714 .23737 Mdot
.31905 .29506 Mdot
.32095 .29088 Mdot
.32286 .27969 Mdot
.32476 .31131 Mdot
.32667 .27482 Mdot
.32857 .32046 Mdot
.33048 .27231 Mdot
.33238 .25091 Mdot
.33429 .252 Mdot
.33619 .24793 Mdot
.3381 .33258 Mdot
.34 .30542 Mdot
.3419 .30328 Mdot
.34381 .26054 Mdot
.34571 .26887 Mdot
.34762 .25321 Mdot
.34952 .24641 Mdot
.35143 .32253 Mdot
.35333 .26196 Mdot
.35524 .2614 Mdot
.35714 .25496 Mdot
.35905 .26182 Mdot
.36095 .32747 Mdot
.36286 .37022 Mdot
.36476 .29626 Mdot
.36667 .26693 Mdot
.36857 .27349 Mdot
.37048 .24235 Mdot
.37238 .27996 Mdot
.37429 .26088 Mdot
.37619 .31585 Mdot
.3781 .2647 Mdot
.38 .35417 Mdot
.3819 .37726 Mdot
.38381 .27008 Mdot
.38571 .25444 Mdot
.38762 .25542 Mdot
.38952 .31917 Mdot
.39143 .23811 Mdot
.39333 .26628 Mdot
.39524 .36044 Mdot
.39714 .25377 Mdot
.39905 .28604 Mdot
.40095 .31863 Mdot
.40286 .24931 Mdot
.40476 .36782 Mdot
.40667 .24375 Mdot
.40857 .2669 Mdot
.41048 .26694 Mdot
.41238 .29077 Mdot
.41429 .25491 Mdot
.41619 .3742 Mdot
.4181 .2991 Mdot
.42 .26239 Mdot
.4219 .26164 Mdot
.42381 .27659 Mdot
.42571 .28159 Mdot
.42762 .25444 Mdot
.42952 .2373 Mdot
.43143 .26742 Mdot
.43333 .2714 Mdot
.43524 .25696 Mdot
.43714 .3077 Mdot
.43905 .27485 Mdot
.44095 .25559 Mdot
.44286 .27987 Mdot
.44476 .27059 Mdot
.44667 .25485 Mdot
.44857 .24978 Mdot
.45048 .32535 Mdot
.45238 .26096 Mdot
.45429 .3366 Mdot
.45619 .26849 Mdot
.4581 .25042 Mdot
.46 .23707 Mdot
.4619 .26046 Mdot
.46381 .36839 Mdot
.46571 .30189 Mdot
.46762 .25971 Mdot
.46952 .28978 Mdot
.47143 .3981 Mdot
.47333 .2558 Mdot
.47524 .25615 Mdot
.47714 .33089 Mdot
.47905 .25986 Mdot
.48095 .24155 Mdot
.48286 .2927 Mdot
.48476 .28175 Mdot
.48667 .35053 Mdot
.48857 .24529 Mdot
.49048 .25684 Mdot
.49238 .24613 Mdot
.49429 .27873 Mdot
.49619 .26193 Mdot
.4981 .32014 Mdot
.5 .29309 Mdot
.5019 .24673 Mdot
.50381 .32046 Mdot
.50571 .29759 Mdot
.50762 .28842 Mdot
.50952 .26154 Mdot
.51143 .33301 Mdot
.51333 .24817 Mdot
.51524 .26448 Mdot
.51714 .24183 Mdot
.51905 .29067 Mdot
.52095 .28115 Mdot
.52286 .27738 Mdot
.52476 .246 Mdot
.52667 .25575 Mdot
.52857 .3322 Mdot
.53048 .2685 Mdot
.53238 .24517 Mdot
.53429 .28227 Mdot
.53619 .26923 Mdot
.5381 .29998 Mdot
.54 .32804 Mdot
.5419 .25778 Mdot
.54381 .28908 Mdot
.54571 .24319 Mdot
.54762 .26013 Mdot
.54952 .26236 Mdot
.55143 .26898 Mdot
.55333 .26741 Mdot
.55524 .25927 Mdot
.55714 .29736 Mdot
.55905 .26062 Mdot
.56095 .27233 Mdot
.56286 .26589 Mdot
.56476 .29238 Mdot
.56667 .2625 Mdot
.56857 .32934 Mdot
.57048 .31451 Mdot
.57238 .2572 Mdot
.57429 .2894 Mdot
.57619 .28398 Mdot
.5781 .24221 Mdot
.58 .25235 Mdot
.5819 .33107 Mdot
.58381 .38337 Mdot
.58571 .30989 Mdot
.58762 .35808 Mdot
.58952 .33641 Mdot
.59143 .29654 Mdot
.59333 .26626 Mdot
.59524 .37912 Mdot
.59714 .2391 Mdot
.59905 .36857 Mdot
.60095 .41811 Mdot
.60286 .25142 Mdot
.60476 .2414 Mdot
.60667 .27428 Mdot
.60857 .29036 Mdot
.61048 .3403 Mdot
.61238 .2561 Mdot
.61429 .31156 Mdot
.61619 .24739 Mdot
.6181 .26775 Mdot
.62 .24669 Mdot
.6219 .26765 Mdot
.62381 .25076 Mdot
.62571 .27568 Mdot
.62762 .27941 Mdot
.62952 .27643 Mdot
.63143 .28839 Mdot
.63333 .36055 Mdot
.63524 .27976 Mdot
.63714 .29026 Mdot
.63905 .37138 Mdot
.64095 .35759 Mdot
.64286 .25902 Mdot
.64476 .23988 Mdot
.64667 .24994 Mdot
.64857 .33389 Mdot
.65048 .25508 Mdot
.65238 .28255 Mdot
.65429 .28591 Mdot
.65619 .24553 Mdot
.6581 .25036 Mdot
.66 .34832 Mdot
.6619 .27682 Mdot
.66381 .24754 Mdot
.66571 .26805 Mdot
.66762 .28802 Mdot
.66952 .23769 Mdot
.67143 .24837 Mdot
.67333 .30394 Mdot
.67524 .24938 Mdot
.67714 .25781 Mdot
.67905 .38402 Mdot
.68095 .25616 Mdot
.68286 .30764 Mdot
.68476 .26474 Mdot
.68667 .31691 Mdot
.68857 .27444 Mdot
.69048 .26979 Mdot
.69238 .31333 Mdot
.69429 .28259 Mdot
.69619 .2829 Mdot
.6981 .38153 Mdot
.7 .28211 Mdot
.7019 .24909 Mdot
.70381 .31318 Mdot
.70571 .24656 Mdot
.70762 .24587 Mdot
.70952 .31236 Mdot
.71143 .24779 Mdot
.71333 .28678 Mdot
.71524 .33082 Mdot
.71714 .25619 Mdot
.71905 .32141 Mdot
.72095 .29339 Mdot
.72286 .28175 Mdot
.72476 .28604 Mdot
.72667 .25533 Mdot
.72857 .36486 Mdot
.73048 .26804 Mdot
.73238 .28664 Mdot
.73429 .31965 Mdot
.73619 .28091 Mdot
.7381 .24854 Mdot
.74 .2742 Mdot
.7419 .3349 Mdot
.74381 .24348 Mdot
.74571 .295 Mdot
.74762 .35026 Mdot
.74952 .32703 Mdot
.75143 .2425 Mdot
.75333 .30265 Mdot
.75524 .35934 Mdot
.75714 .40943 Mdot
.75905 .35219 Mdot
.76095 .26982 Mdot
.76286 .27909 Mdot
.76476 .35764 Mdot
.76667 .2445 Mdot
.76857 .28607 Mdot
.77048 .26726 Mdot
.77238 .25667 Mdot
.77429 .28997 Mdot
.77619 .25608 Mdot
.7781 .24783 Mdot
.78 .25749 Mdot
.7819 .26869 Mdot
.78381 .23806 Mdot
.78571 .37103 Mdot
.78762 .27964 Mdot
.78952 .27263 Mdot
.79143 .4014 Mdot
.79333 .25729 Mdot
.79524 .25763 Mdot
.79714 .25095 Mdot
.79905 .29938 Mdot
.80095 .26103 Mdot
.80286 .29926 Mdot
.80476 .26989 Mdot
.80667 .26518 Mdot
.80857 .27049 Mdot
.81048 .27314 Mdot
.81238 .29015 Mdot
.81429 .25408 Mdot
.81619 .31625 Mdot
.8181 .26042 Mdot
.82 .25323 Mdot
.8219 .27151 Mdot
.82381 .25104 Mdot
.82571 .30187 Mdot
.82762 .25429 Mdot
.82952 .2623 Mdot
.83143 .29739 Mdot
.83333 .31547 Mdot
.83524 .30259 Mdot
.83714 .25342 Mdot
.83905 .24424 Mdot
.84095 .3149 Mdot
.84286 .2823 Mdot
.84476 .25502 Mdot
.84667 .34215 Mdot
.84857 .35142 Mdot
.85048 .25221 Mdot
.85238 .4108 Mdot
.85429 .23751 Mdot
.85619 .2665 Mdot
.8581 .36143 Mdot
.86 .36947 Mdot
.8619 .26078 Mdot
.86381 .3265 Mdot
.86571 .38952 Mdot
.86762 .26265 Mdot
.86952 .2871 Mdot
.87143 .26838 Mdot
.87333 .3206 Mdot
.87524 .27903 Mdot
.87714 .3782 Mdot
.87905 .268 Mdot
.88095 .28921 Mdot
.88286 .25353 Mdot
.88476 .28121 Mdot
.88667 .26993 Mdot
.88857 .26207 Mdot
.89048 .24847 Mdot
.89238 .28987 Mdot
.89429 .25652 Mdot
.89619 .2459 Mdot
.8981 .25525 Mdot
.9 .2766 Mdot
.9019 .33494 Mdot
.90381 .26492 Mdot
.90571 .33745 Mdot
.90762 .2557 Mdot
.90952 .24917 Mdot
.91143 .2865 Mdot
.91333 .27707 Mdot
.91524 .25773 Mdot
.91714 .26988 Mdot
.91905 .29692 Mdot
.92095 .26518 Mdot
.92286 .26712 Mdot
.92476 .2517 Mdot
.92667 .27886 Mdot
.92857 .28785 Mdot
.93048 .30407 Mdot
.93238 .28874 Mdot
.93429 .30064 Mdot
.93619 .28761 Mdot
.9381 .281 Mdot
.94 .29675 Mdot
.9419 .26691 Mdot
.94381 .27633 Mdot
.94571 .25017 Mdot
.94762 .27654 Mdot
.94952 .25199 Mdot
.95143 .30161 Mdot
.95333 .2546 Mdot
.95524 .28601 Mdot
.95714 .26336 Mdot
.95905 .27459 Mdot
.96095 .28596 Mdot
.96286 .4025 Mdot
.96476 .2801 Mdot
.96667 .24156 Mdot
.96857 .35114 Mdot
.97048 .32458 Mdot
.97238 .25242 Mdot
.97429 .26735 Mdot
.97619 .28582 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooocgooooo0006
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol0003oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_oo
ool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`04ooooo`;o000000?oooooo`000?l000000_l0001nooooo`;o0000/Oooool000Kooooo00Go
410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`04ooooo`;o000000?oooooo`000?l000000_l0000<ooooo`;o0000
;oooool2o`00017ooooo0_l0000Eooooo`;o00002oooool2o`0000Sooooo0_l0000Zooooo`;o0000
3Oooool2o`0000Kooooo0_l0000Sooooo`;o00005?ooool2o`0003?ooooo0006ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0;ooooo`;o00002_ooool3o`0000Oooooo0_l0000Iooooo`;o
00002?ooool4o`0000Cooooo0_l00006ooooo`;o00000oooool2o`0000oooooo0_l00004ooooo`;o
00002oooool2o`0000kooooo0_l0000:ooooo`;o00001oooool2o`0000Sooooo0_l00005ooooo`Co
00002oooool2o`0000Kooooo0_l0000Fooooo`Co00002Oooool2o`0001Cooooo0_l0000Rooooo`;o
00003oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo00Co0000oooooooooooooooo0_l00008ooooo`;o00002oooool2
o`0000Oooooo0_l00005ooooo`;o00002Oooool2o`0000Kooooo1Ol00006ooooo`;o00001_ooool4
o`0000Cooooo0_l0000=ooooo`;o00001Oooool2o`0000Wooooo0_l0000Fooooo`;o000000Cooooo
o`000?l0003o00001_ooool4o`000003ooooool0003o000000;ooooo0_l00008ooooo`;o00001ooo
ool2o`0000oooooo0_l0000>ooooo`;o00002_ooool4o`0000?ooooo0_l0000Eooooo`;o00004Ooo
ool2o`0001Cooooo0_l0000?ooooo`00:Oooool2o`0000;ooooo0_l0000;ooooo`;o00002_ooool2
o`0000;ooooo0_l00002ooooo`;o00001?ooool2o`0000Wooooo0_l000000ooooooo0000o`000002
ooooo`?o000000?oooooo`000?l000004?ooool2o`0000Oooooo0_l00006ooooo`;o00000_ooool2
o`0000oooooo0ol0000Iooooo`?o000000?oooooo`000?l000000_ooool2o`000004ooooool0003o
0000ooooo`;o00006Oooool3o`0000[ooooo1?l000001?oooooo0000o`000?l00006ooooo`Go0000
1oooool2o`0000Oooooo0_l00002ooooo`;o00004Oooool2o`0000oooooo1?l00002ooooo`;o0000
8Oooool002Wooooo1?l0000=ooooo`;o00002?ooool4o`0000;ooooo0_l00002ooooo`;o00000ooo
ool2o`0000Wooooo0_l00002ooooo`;o00000_ooool2o`0000Sooooo0_l0000:ooooo`;o00001ooo
ool2o`0000Cooooo1?l0000Cooooo`;o00003Oooool2o`000003ooooool0003o000000cooooo0_l0
0002ooooo`;o00004oooool2o`0000Gooooo0_l00003ooooo`Co00001_ooool2o`000003ooooool0
003o000000;o000000Coooooo`000?l0003o00001_ooool2o`000003ooooool0003o000000Oooooo
0_l0000;ooooo`;o00001?ooool2o`0000Oooooo0_l00006ooooo`;o00002oooool2o`0000Cooooo
0_l00003ooooo`;o00001Oooool3o`0000Gooooo0_l0000=ooooo`00:Oooool00ol0003oooooo`00
0005o`0000?ooooo0_l00002ooooo`?o00000oooool2o`0000Cooooo0_l00006ooooo`;o00001Ooo
ool2o`000003ooooool0003o000000Cooooo1?l0000:ooooo`;o00001?ooool3o`0000Wooooo0_l0
0002ooooo`Co00000_ooool2o`0000?ooooo0ol00002ooooo`;o000000?oooooo`000?l000002?oo
ool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o00000_ooool5o`000003ooooool0
003o000000?ooooo0_l0000?ooooo`;o00003oooool2o`0000Gooooo0_l00005ooooo`;o00001_oo
ool5o`0001Cooooo0_l0000Eooooo`;o00000oooool7o`000003ooooool0003o000000Co00002?oo
ool2o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`;o00001Oooool4o`0000Cooooo0_l0
000=ooooo`00:Oooool00ol0003oooooooooo`05o`000003ooooool0003o000000;o00000_ooool3
o`0000?ooooo0_l0000;ooooo`?o00000oooool4o`000003ooooool0003o000000Cooooo0_l0000<
ooooo`;o00000_ooool2o`000003ooooool0003o000000gooooo2?l00008ooooo`;o000000?ooooo
o`000?l000002?ooool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o000000?ooooo
o`000?l000000ol00007ooooo`;o00000oooool2o`0000[ooooo0_l00003ooooo`;o00002?ooool2
o`0000_ooooo0_l00007ooooo`;o000000?oooooo`000?l000001_ooool4o`0000Wooooo0_l00000
0ooooooo0000o`00000=ooooo`Co00000oooool2o`0000Cooooo1?l000001?oooooo0000o`000?oo
ool4o`0000[ooooo0_l00002ooooo`?o000000Coooooo`000?l0003ooooo0_l0000:ooooo`;o0000
4oooool002Wooooo00Co0000ooooool0003o00001Oooool2o`00017ooooo0_l00004ooooo`;o0000
1?ooool2o`0000;ooooo0_l00005ooooo`;o00003oooool3o`0000Gooooo0_l0000=ooooo`;o0000
2Oooool2o`000003ooooool0003o000000;o00000oooool2o`0000gooooo0_l00003ooooo`;o0000
0oooool2o`000003ooooool0003o000000Ko000000?oooooo`000?l000000_l00002ooooo`;o0000
2Oooool7o`0000?ooooo0_l0000;ooooo`;o00001oooool2o`0000Wooooo1?l00009ooooo`;o0000
4?ooool4o`0000?ooooo1?l00004ooooo`;o00003?ooool2o`0000Kooooo1?l00005ooooo`;o0000
7oooool002Wooooo1?l00004ooooo`;o00003Oooool2o`0000?ooooo0_l0000;ooooo`;o000000?o
ooooo`000?l000001?ooool2o`000003ooooool0003o000000Cooooo0_l00006ooooo`?o00001_oo
ool2o`000004ooooool0003o0000ooooo`Co00004?ooool2o`000003ooooool0003o000000;o0000
0oooool3o`0000cooooo0_l00008ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o0000
0oooool2o`0000;ooooo1?l00009ooooo`Go000000?oooooo`000?l000009?ooool2o`0002?ooooo
1?l00002ooooo`;o000000?oooooo`000?l000002Oooool4o`0000Cooooo0_l00003ooooo`;o0000
1?ooool2o`0000Wooooo0_l0000Booooo`00:Oooool2o`0000Kooooo0_l0000=ooooo`Go00003Ooo
ool2o`0000Gooooo1?l000001?oooooo0000o`000?l00003ooooo`;o00001_ooool2o`0000?ooooo
0_l00002ooooo`;o000000Coooooo`000?l0003ooooo1?l0000Hooooo`;o000000?oooooo`000?l0
00000oooool2o`0000?ooooo0ol000001?oooooo0000o`000?ooool2o`0001Wooooo0_l00009oooo
o`Co000000Coooooo`000?l0003o00001_ooool2o`0000Kooooo1?l0000<ooooo`;o00001?ooool2
o`0000cooooo0_l0000;ooooo`;o00002_ooool2o`0000Gooooo0_l00007ooooo`;o00000_ooool5
o`0000Kooooo0_l00004ooooo`;o00001?ooool2o`0000?ooooo0_l00004ooooo`;o00003?ooool0
02Wooooo0_l0000>ooooo`;o00001_ooool4o`0001Cooooo0_l000000ooooooo0000o`000003o`00
0007ooooool0003o0000oc8b<_l0003o<S8bonk^kP03ooooo`06onk^k_l0003o0000oc8b<_o^k^ko
oooo0_l00003ooooo`;o00002Oooool2o`0000;ooooo0_l00009ooooo`;o00001Oooool7o`000005
ooooool0003o0000onk^k_lb<S801?l00002ooooo`03onk^k_lb<S;o000000;o00000_ooool2o`00
0003ooooool0003o000001Kooooo1?l00003ooooo`?o000000Koooooo`000?l0003o0000oc8b<_o<
c<`3ooooo`05onk^k_l0003o0000oc8b<_o^k^h00oooool00oo^k^ko0000o`000002o`0000cooooo
0_l00006ooooo`;o00002_ooool2o`0000Sooooo0_l000001Ol@413o0000o`000?ooooook^k^00;o
000000?o<S8bonk^k_ooool00_ooool4o`000003onk^k_oooooooooo00[ooooo0_l00003ooooo`Co
000000?oooooo`000?l000002?ooool3o`0000Cooooo0_l000001Om4A4Co0000o`000?lb<S;ogMgM
00;ooooo00Gok^k^oc8b<_l0003o0000onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool002Wooooo00?o0000ooooooooool01oooool2o`0000Cooooo1?l0000;ooooo`;o00001Oooool2
o`0000Oooooo0_l00004ooooo`04o`000?ooooooooooooooo`;o000000CoV9RHoooooonHV9SoMgMg
0oooool01OmgMgOo0000o`000?nHV9SoMgMg00Kooooo0_l00008ooooo`?o00000_ooool2o`0000Co
oooo0_l00003ooooo`;o00001Oooool2o`000003oiRHV?lQ8B7ok^k^00;o00000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00?oMgMgoiRHV?ooool00_l00002ooooo`;o000000?oooooo`00
0?l000005_ooool4o`0000?ooooo0_l000001ooooooo0000o`000?nj^[[oooooogMgMolb<S800ooo
ool01_mgMgOoV9RHoooooonHV9SoMgMgooooo`;o000000GoMgMgoiRHV?ooooooV9RHogMgM`0Coooo
o`?o00003_ooool2o`0000Cooooo0_l00004ooooo`03ogMgMol0003o000000;o00000oooool4o`00
0004ogMgMooooooo0000o`0001?ooooo0_l00008ooooo`;o00002_ooool02OmgMgOo0000o`000?oo
ooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wo
oooo00?o0000ooooooooool01oooool4o`0000Cooooo0_l00009ooooo`Co00001Oooool2o`0000Oo
oooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00?o410@ooooooooool00_l00003ooooo`05
oa0@4?ooooooooooooooool@41004?ooool2o`0000Sooooo0ol0000:ooooo`;o000000CooooooiRH
V?lQ8B7ok^k^1?ooool01Ol@413ooooooooooooooooo410@00?ooooo0_l00002ooooo`03oa0@4?l0
003o000001Wooooo0_l0000:ooooo`;o00000oooool01Ol0003ooooooooooooooooo410@00?ooooo
00Go410@ooooool0003o0000oa0@4003ooooo`?o00002?ooool2o`0000Oooooo0_l0000?ooooo`;o
00000_ooool5o`0000?ooooo00?o410@ooooooooool00_l00003ooooo`06oa0@4?oooooo0000o`00
0?l@413ooooo0_l0000Gooooo`;o00000_ooool2o`0000Sooooo0ol00002ooooo`;o000000?ooooo
oa0@4?ooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool00Ooo
ool002Wooooo0_l00002ooooo`;o00001_ooool3o`0000kooooo0_l0000Eooooo`;o00000_ooool3
o`0000;ooooo0_l000000ooooooo0000o`000002o`0000;ooooo00?o0000ooooooooool04_ooool2
o`0000;ooooo1?l0000<ooooo`;o000000CooooooiRHV?lQ8B7ok^k^0oooool01Ol0003ooooooooo
oooooooo000000?ooooo0_l00002ooooo`Co00003oooool2o`0000Oooooo0_l0000>ooooo`03ojVY
ZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooooooooooo
o`Go00001_ooool2o`0001cooooo00?oA4A4omgMgOooool00_l00003ooooo`03o`000?oooooooooo
00;o00000oooool01Ol0003ooooooooooooooooo000001;ooooo0_l00006ooooo`;o00000_ooool2
o`0000?ooooo0_l00003ooooo`?o000000CoooooogMgMolb<S;ooooo0_l00003ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`01ooooo`00:Oooool01?l0003ooooooooo
ooooool2o`0000Oooooo0_l0000Aooooo`;o00004_ooool2o`0000;ooooo0ol00003ooooo`03o`00
0?oooooo000000?o00000_ooool00ol0003oooooooooo`0Booooo`;o00000_ooool2o`0000kooooo
0_l00002ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`;o
00000_ooool01?l0003oooooo`000?l0000;ooooo`;o00000_ooool2o`0000Kooooo0_l00002oooo
o`;o00002_ooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000000oooool0
1?l0003oooooooooooooool2o`000003ooooool0003o000000?ooooo0_l0000<ooooo`Co00001Ooo
ool2o`0000;ooooo0_l00004ooooo`03omgMgOmEEEGooooo00;o00000oooool00ol0003ooooooooo
o`02o`0000?ooooo00Go0000ooooooooooooooooo`000008ooooo`;o00002?ooool2o`000003oooo
ool0003o000000cooooo0_l000002_oooooo0000o`000?oooooo0000ob4Q8Ol0003o<S8bolc<c?oo
ool2o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo007ooooo
000Yooooo`03o`000?oooooooooo01gooooo0_l000000ooooooo0000o`00000<ooooo`;o00000_oo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooo
oooooooooooo410@02gooooo00Co0000oooooooooooooooo0_l00002ooooo`04oa0@4?oooooooooo
ooooo`;o00000_ooool00ol@413oooooooooo`0<ooooo`;o00002_ooool2o`0000;ooooo0_l0000;
ooooo`03okZj^_l0003o000000;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oo
ooooooooooooool@41001oooool3o`0000_ooooo1?l00002ooooo`;o000000?oooooo`000?l00000
1?l00005ooooo`04ogMgMoo<c<co0000ooooo`;o000000?ooooooa0@4?ooool00_ooool01Ol@413o
oooooooooooooooo410@00?ooooo00?o410@ooooooooool01_ooool2o`0000_ooooo0_l00007oooo
o`;o00001_ooool2o`000004ooooool0003oooooooooo`Co000000?o410@ooooooooool00_l00003
ooooo`05oa0@4?ooooooooooooooool@41000oooool002Wooooo00?o0000ooooooooool08?ooool2
o`0000cooooo0_l00002ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02Oooool2o`0001kooooo00Go0000okZj^_oooooo
V9RHoa0@4003ooooo`;o000000?ooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00[ooooo0_l0000:ooooo`;o00002Oooool2o`0000Gooooo00?o410@oiRHV?ooool00ol00002oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01_mgMgOoV9RHoooooonHV9SoMgMgooooo`;o0000
1Oooool2o`0000;ooooo0_l0000=ooooo`;o00000_ooool4o`0000Kooooo00Cok^k^odA4A?l0003o
oooo1?l000001?nHV9SooooooiRHV?mgMgL3ooooo`03ogMgMonHV9Sooooo00;o00004?ooool2o`00
00;ooooo0_l00002ooooo`;o00001?ooool2o`0000?ooooo1Ol000001?oooooo0000ooooooooool4
o`000003ogMgMonHV9Sooooo00;o00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000Y
ooooo`03o`000?oooooooooo01cooooo0_l0000:ooooo`;o000000?oooooo`000?l000000_l00000
1?ooooooEEEEofIVI_l00004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01?o^k^ko<S8b
o`000?lb<S82o`0000Sooooo0_l0000=ooooo`;o00003oooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Cok^k^oc8b<_l0003o<S8b0_l00002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02_oo
ool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Gooooo0_l0
0005ooooo`Go00000oooool01_o^k^ko<S8bo`000?lb<S;ok^k^ooooo`;o000000Kok^k^oc8b<_l0
003o<S8bonk^k_ooool3o`0000Sooooo0_l0000Looooo`03ogMgMol0003ooooo00;ooooo0_l00000
1?lb<S;o0000oc8b<_o^k^h3ooooo`03onk^k_lb<S;o000000;o00004?ooool2o`0000;ooooo0_l0
0002ooooo`;o00002Oooool5o`000003ooooool0003o000000;o00000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool2o`00017ooooo
0_l00009ooooo`?o00002_ooool2o`000003ooooool0003o000000;o00005?ooool2o`0000Sooooo
0_l0000<ooooo`?o00003?ooool2o`0000gooooo0_l0000Eooooo`;o00000oooool2o`0000Gooooo
0_l0000<ooooo`;o00003?ooool2o`0000Oooooo0_l0000Iooooo`;o00001_ooool2o`0005Kooooo
000Yooooo`03o`000?oooooooooo00Cooooo0_l0000:ooooo`;o00002Oooool2o`00023ooooo0_l0
000Looooo`;o00003Oooool2o`0000oooooo0_l0000Jooooo`;o00003oooool2o`0000Wooooo0_l0
000Wooooo`;o00001_ooool2o`00013ooooo0ol00007ooooo`;o00006_ooool2o`0000Gooooo0_l0
000Gooooo`00:Oooool3o`0000Cooooo0_l0000;ooooo`;o00004_ooool2o`0001Kooooo0_l0000l
ooooo`;o00003Oooool2o`0000_ooooo0_l00009ooooo`;o00001?ooool2o`0000Wooooo0_l00011
ooooo`?o00001Oooool5o`0001Wooooo0_l00003ooooo`Co00000_ooool2o`0001?ooooo000Yoooo
o`?o00004Oooool4o`00013ooooo0_l0000kooooo`?o00009Oooool2o`0001Kooooo0_l0000Yoooo
o`;o00006?ooool2o`0001Gooooo0_l000000ooooooo0000o`00000Mooooo`?o00001?ooool2o`00
01?ooooo000Yooooo`03o`000?oooooooooo013ooooo0_l000000ooooooo0000o`00001=ooooo`?o
00007?ooool2o`0004[ooooo0_l000000ooooooo0000o`00000Eooooo`;o0000=oooool2o`0001[o
oooo000Qoooooooo0000A?l00004ooooo`00:Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Sooooo0ol0000;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`04ooooo`;o00001?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Oooooo0ol0000;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`02o`0000?ooooo0_l00002ooooo`03o`000?oooooooooo00;ooooo0_l0
0005ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool2o`0000;ooooo1?l0
000;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`02ooooo`;o00001_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`00:Oooool00ol0003oooooooooo`0D
ooooo`?o00008oooool00ol0003oooooooooo`04ooooo`;o00002?ooool2o`000003ooooool0003o
000001kooooo0_l00008ooooo`03o`000?oooooooooo037ooooo0_l00007ooooo`03o`000?oooooo
oooo01Wooooo1?l00002ooooo`Co00005oooool00ol0003oooooooooo`06ooooo`;o00001?ooool4
o`0002[ooooo00?o0000ooooooooool02_ooool002Wooooo00?o0000ooooooooool04_ooool2o`00
0003ooooool0003o0000033ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`00
00[ooooo0_l0000>ooooo`;o00000_ooool2o`0000;ooooo0_l0000Mooooo`Co0000>?ooool2o`00
00kooooo0_l0000Hooooo`;o00001?ooool2o`0000[ooooo0_l0000]ooooo`00:Oooool00ol0003o
ooooooooo`0:ooooo`;o00001_ooool2o`0000_ooooo0_l0000Vooooo`;o00002Oooool2o`0000[o
oooo0_l00006ooooo`;o00002_ooool2o`0000;ooooo0_l0000Mooooo`Co0000@oooool2o`0000?o
oooo0_l0000Zooooo`;o0000;Oooool002Wooooo0_l0000;ooooo`;o00000oooool2o`0000kooooo
0_l0000=ooooo`;o00002oooool2o`0002Wooooo0_l000000ooooooo0000o`00000Jooooo`;o0000
EOooool2o`0000Sooooo0_l0000Rooooo`;o00008Oooool2o`0000gooooo000Yooooo`03o`000?oo
oooooooo00oooooo0_l0000Mooooo`;o00002oooool2o`0000_ooooo0_l0000Oooooo`;o00006_oo
ool2o`0001_ooooo0_l00007ooooo`;o0000>Oooool2o`0002;ooooo0_l0000Qooooo`;o00003Ooo
ool002Wooooo00?o0000ooooooooool08oooool2o`0001?ooooo0_l0000>ooooo`;o00005oooool2
o`0002_ooooo0_l00009ooooo`;o00001?ooool2o`000003ooooool0003o000000Oooooo0_l00003
ooooo`;o0000:Oooool2o`0005oooooo000Yooooo`03o`000?oooooooooo00;ooooo0_l0000Ooooo
o`;o00001Oooool2o`0000cooooo0_l0000Wooooo`;o00009?ooool2o`0000Gooooo0_l00009oooo
o`;o00001?ooool2o`0000oooooo1?l0000Aooooo`;o00005?ooool2o`0000Kooooo0_l0000boooo
o`;o00008oooool002Wooooo00?o0000ooooooooool00_ooool2o`0002Kooooo0_l0001Kooooo`;o
0000:Oooool2o`00017ooooo0_l0000Looooo`;o0000<_ooool3o`0002;ooooo000Yooooo`;o0000
8oooool2o`0009Gooooo0_l0001:ooooo`;o00004Oooool2o`0002;ooooo000Yooooo`03o`000?oo
oooooooo02;ooooo0_l0000Rooooo`;o0000LOooool2o`0004[ooooo0_l0000eooooo`00:Oooool0
0ol0003oooooooooo`16ooooo`;o0000POooool2o`00077ooooo000Yooooo`03o`000?oooooooooo
097ooooo0_l0000fooooo`;o00006_ooool2o`0000;ooooo0_l0000Jooooo`;o00009Oooool2o`00
00kooooo000Yooooo`03o`000?oooooooooo06oooooo0_l0000Pooooo`;o0000D_ooool2o`0000;o
oooo0_l0000Jooooo`;o00009Oooool2o`0000kooooo000Yooooo`;o0000L?ooool2o`00047ooooo
0_l0000?ooooo`;o00009_ooool2o`0004oooooo000Yooooo`03o`000?oooooooooo02Cooooo0_l0
000]ooooo`;o00007oooool2o`0003cooooo0_l0000<ooooo`;o000000?oooooo`000?l000008_oo
ool2o`0000;ooooo0_l0000Looooo`;o0000<Oooool002Wooooo00?o0000ooooooooool03?ooool2
o`0001Kooooo0_l0000]ooooo`;o00007oooool2o`0004[ooooo0_l0000Uooooo`;o00008?ooool2
o`00037ooooo000Yooooo`03o`000?oooooooooo00cooooo0_l0000mooooo`;o0000:_ooool2o`00
06Kooooo0_l0001Kooooo`00:Oooool00ol0003oooooooooo`05ooooo`;o0000<?ooool2o`0001;o
oooo0_l0000Looooo`;o00003?ooool2o`00017ooooo0_l0000Yooooo`;o0000:?ooool2o`0002So
oooo0_l0000aooooo`00:Oooool2o`0000Kooooo0_l0000]ooooo`;o000000?oooooo`000?l00000
<?ooool2o`0001oooooo0_l0000Yooooo`;o00002oooool2o`0002gooooo0_l0000Fooooo`;o0000
<Oooool002Wooooo00?o0000ooooooooool0=?ooool2o`0004Cooooo0_l00016ooooo`;o0000;Ooo
ool2o`0004Wooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0
0004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`1_ooooo`;o0000
2Oooool2o`0003Sooooo0_l0001Iooooo`;o0000:oooool000Kooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`1_ooooo`;o0000?oooool2o`0000;ooooo0_l0000Oooooo`;o
0000>?ooool2o`0002_ooooo0006ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Doooool2o`0005_o
oooo0_l0000Mooooo`;o00001?ooool2o`0006Gooooo0006ooooo`05o`000?ooooooooooooooool0
00003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0001Cooooo`;o
0000N_ooool2o`0003[ooooo0_l0000_ooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0=Oooool2o`000=Cooooo0_l0000_ooooo`001_ooool01Ol@413ooooooooooooooooo410@
00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
03Gooooo0_l0003oooooo`Kooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0i
ooooo`;o0000DOooool2o`000:kooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo01gooooo0_l0
000<ooooo`;o00003?ooool2o`00057ooooo0_l0001Uooooo`;o0000Aoooool002Wooooo0_l0000N
ooooo`;o00003?ooool2o`000<Kooooo0_l0000eooooo`;o00004?ooool002Wooooo00?o0000oooo
ooooool0ooooool[ooooo`;o00004?ooool002Wooooo00?o0000ooooooooool0j?ooool2o`0001go
oooo0_l0000cooooo`00:Oooool00ol0003oooooooooo`3Xooooo`;o00007Oooool2o`0003?ooooo
000Yooooo`03o`000?oooooooooo04?ooooo0_l0000Booooo`;o0000hoooool002Wooooo0_l00014
ooooo`;o00004_ooool2o`0005gooooo0_l00024ooooo`00:Oooool00ol0003oooooooooo`2foooo
o`;o0000Q?ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool0oooooolmooooo`003_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000
ooooooooool00oooool3o`000?oooooo?Oooool000kooooo00Go0000ooooooooooooooooo`00000?
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Ol0
003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oo
oooooooo0?oooooo?Oooool000kooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo000>
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0003oooooockooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVY
oeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolmooooo`001_ooool01Ol0
003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00000>
ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oo
oooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmg
MgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool001oooooo1?l000000ol@413oooooooooo`03oooo
o`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo0ol0003oooooocgooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool001oooooo00?oEEEEofIVI_l00000oooooom7ooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .25326 Mdot
.02762 .27037 Mdot
.02952 .31042 Mdot
.03143 .29498 Mdot
.03333 .31083 Mdot
.03524 .2673 Mdot
.03714 .31529 Mdot
.03905 .25806 Mdot
.04095 .23562 Mdot
.04286 .30564 Mdot
.04476 .29395 Mdot
.04667 .22654 Mdot
.04857 .29041 Mdot
.05048 .32757 Mdot
.05238 .26249 Mdot
.05429 .30809 Mdot
.05619 .25471 Mdot
.0581 .29235 Mdot
.06 .31414 Mdot
.0619 .28285 Mdot
.06381 .24357 Mdot
.06571 .24311 Mdot
.06762 .23979 Mdot
.06952 .2756 Mdot
.07143 .25266 Mdot
.07333 .32561 Mdot
.07524 .26644 Mdot
.07714 .287 Mdot
.07905 .26133 Mdot
.08095 .24587 Mdot
.08286 .23897 Mdot
.08476 .22792 Mdot
.08667 .22799 Mdot
.08857 .24419 Mdot
.09048 .26898 Mdot
.09238 .23506 Mdot
.09429 .23004 Mdot
.09619 .27335 Mdot
.0981 .23189 Mdot
.1 .23813 Mdot
.1019 .22523 Mdot
.10381 .25661 Mdot
.10571 .25513 Mdot
.10762 .29552 Mdot
.10952 .28763 Mdot
.11143 .32001 Mdot
.11333 .28265 Mdot
.11524 .23612 Mdot
.11714 .31532 Mdot
.11905 .23312 Mdot
.12095 .23075 Mdot
.12286 .23938 Mdot
.12476 .28455 Mdot
.12667 .2472 Mdot
.12857 .28145 Mdot
.13048 .22969 Mdot
.13238 .24397 Mdot
.13429 .27131 Mdot
.13619 .23244 Mdot
.1381 .28882 Mdot
.14 .30476 Mdot
.1419 .23093 Mdot
.14381 .23837 Mdot
.14571 .32443 Mdot
.14762 .25256 Mdot
.14952 .22797 Mdot
.15143 .29345 Mdot
.15333 .27997 Mdot
.15524 .29918 Mdot
.15714 .25733 Mdot
.15905 .3199 Mdot
.16095 .32243 Mdot
.16286 .28265 Mdot
.16476 .30114 Mdot
.16667 .23865 Mdot
.16857 .31453 Mdot
.17048 .28532 Mdot
.17238 .25907 Mdot
.17429 .24398 Mdot
.17619 .24838 Mdot
.1781 .23759 Mdot
.18 .24041 Mdot
.1819 .28247 Mdot
.18381 .26565 Mdot
.18571 .24911 Mdot
.18762 .33451 Mdot
.18952 .31227 Mdot
.19143 .26933 Mdot
.19333 .29257 Mdot
.19524 .27505 Mdot
.19714 .26482 Mdot
.19905 .27532 Mdot
.20095 .32951 Mdot
.20286 .30904 Mdot
.20476 .3228 Mdot
.20667 .24939 Mdot
.20857 .32594 Mdot
.21048 .23385 Mdot
.21238 .2812 Mdot
.21429 .32042 Mdot
.21619 .24662 Mdot
.2181 .31199 Mdot
.22 .22844 Mdot
.2219 .28182 Mdot
.22381 .24084 Mdot
.22571 .24417 Mdot
.22762 .298 Mdot
.22952 .31941 Mdot
.23143 .33024 Mdot
.23333 .24609 Mdot
.23524 .32411 Mdot
.23714 .31344 Mdot
.23905 .22837 Mdot
.24095 .25412 Mdot
.24286 .30234 Mdot
.24476 .32725 Mdot
.24667 .28693 Mdot
.24857 .2504 Mdot
.25048 .24002 Mdot
.25238 .24503 Mdot
.25429 .27813 Mdot
.25619 .22404 Mdot
.2581 .24146 Mdot
.26 .27375 Mdot
.2619 .25186 Mdot
.26381 .28432 Mdot
.26571 .24302 Mdot
.26762 .24664 Mdot
.26952 .23915 Mdot
.27143 .3068 Mdot
.27333 .23784 Mdot
.27524 .24128 Mdot
.27714 .22583 Mdot
.27905 .29119 Mdot
.28095 .2575 Mdot
.28286 .26573 Mdot
.28476 .25487 Mdot
.28667 .24718 Mdot
.28857 .27842 Mdot
.29048 .2278 Mdot
.29238 .24896 Mdot
.29429 .27529 Mdot
.29619 .32576 Mdot
.2981 .31243 Mdot
.3 .25783 Mdot
.3019 .27335 Mdot
.30381 .24946 Mdot
.30571 .30412 Mdot
.30762 .25921 Mdot
.30952 .2745 Mdot
.31143 .23314 Mdot
.31333 .3206 Mdot
.31524 .31491 Mdot
.31714 .28726 Mdot
.31905 .32257 Mdot
.32095 .24223 Mdot
.32286 .2362 Mdot
.32476 .23158 Mdot
.32667 .23526 Mdot
.32857 .23169 Mdot
.33048 .23973 Mdot
.33238 .32251 Mdot
.33429 .25645 Mdot
.33619 .25218 Mdot
.3381 .24032 Mdot
.34 .24217 Mdot
.3419 .23891 Mdot
.34381 .24377 Mdot
.34571 .24574 Mdot
.34762 .29552 Mdot
.34952 .26183 Mdot
.35143 .23483 Mdot
.35333 .2898 Mdot
.35524 .2767 Mdot
.35714 .28222 Mdot
.35905 .27337 Mdot
.36095 .23003 Mdot
.36286 .25144 Mdot
.36476 .2412 Mdot
.36667 .30907 Mdot
.36857 .24054 Mdot
.37048 .26788 Mdot
.37238 .23078 Mdot
.37429 .31875 Mdot
.37619 .22498 Mdot
.3781 .30921 Mdot
.38 .24897 Mdot
.3819 .26018 Mdot
.38381 .23842 Mdot
.38571 .24609 Mdot
.38762 .26691 Mdot
.38952 .22418 Mdot
.39143 .27859 Mdot
.39333 .31656 Mdot
.39524 .24605 Mdot
.39714 .24876 Mdot
.39905 .22751 Mdot
.40095 .22652 Mdot
.40286 .30128 Mdot
.40476 .24724 Mdot
.40667 .31328 Mdot
.40857 .30699 Mdot
.41048 .30745 Mdot
.41238 .32247 Mdot
.41429 .2828 Mdot
.41619 .25358 Mdot
.4181 .23893 Mdot
.42 .30264 Mdot
.4219 .25889 Mdot
.42381 .33034 Mdot
.42571 .32706 Mdot
.42762 .30874 Mdot
.42952 .29028 Mdot
.43143 .26358 Mdot
.43333 .24415 Mdot
.43524 .29686 Mdot
.43714 .23889 Mdot
.43905 .25809 Mdot
.44095 .24493 Mdot
.44286 .32556 Mdot
.44476 .2507 Mdot
.44667 .24679 Mdot
.44857 .29253 Mdot
.45048 .23213 Mdot
.45238 .25173 Mdot
.45429 .24334 Mdot
.45619 .27347 Mdot
.4581 .30165 Mdot
.46 .29902 Mdot
.4619 .30634 Mdot
.46381 .25974 Mdot
.46571 .22302 Mdot
.46762 .31343 Mdot
.46952 .3177 Mdot
.47143 .28526 Mdot
.47333 .27313 Mdot
.47524 .28821 Mdot
.47714 .2272 Mdot
.47905 .27877 Mdot
.48095 .2843 Mdot
.48286 .23723 Mdot
.48476 .24338 Mdot
.48667 .23734 Mdot
.48857 .28281 Mdot
.49048 .25475 Mdot
.49238 .3194 Mdot
.49429 .23397 Mdot
.49619 .30991 Mdot
.4981 .23225 Mdot
.5 .24688 Mdot
.5019 .3209 Mdot
.50381 .23328 Mdot
.50571 .22494 Mdot
.50762 .32633 Mdot
.50952 .29978 Mdot
.51143 .23688 Mdot
.51333 .29521 Mdot
.51524 .27273 Mdot
.51714 .31371 Mdot
.51905 .31479 Mdot
.52095 .2314 Mdot
.52286 .23558 Mdot
.52476 .29867 Mdot
.52667 .28939 Mdot
.52857 .24048 Mdot
.53048 .31372 Mdot
.53238 .30044 Mdot
.53429 .24394 Mdot
.53619 .26962 Mdot
.5381 .24161 Mdot
.54 .23726 Mdot
.5419 .27271 Mdot
.54381 .23517 Mdot
.54571 .29119 Mdot
.54762 .3198 Mdot
.54952 .26586 Mdot
.55143 .24178 Mdot
.55333 .327 Mdot
.55524 .32735 Mdot
.55714 .22919 Mdot
.55905 .32302 Mdot
.56095 .25038 Mdot
.56286 .24497 Mdot
.56476 .32938 Mdot
.56667 .2805 Mdot
.56857 .23468 Mdot
.57048 .22624 Mdot
.57238 .32336 Mdot
.57429 .32087 Mdot
.57619 .25537 Mdot
.5781 .272 Mdot
.58 .28639 Mdot
.5819 .24065 Mdot
.58381 .26802 Mdot
.58571 .22943 Mdot
.58762 .24902 Mdot
.58952 .23734 Mdot
.59143 .3195 Mdot
.59333 .24241 Mdot
.59524 .2679 Mdot
.59714 .27835 Mdot
.59905 .26021 Mdot
.60095 .30427 Mdot
.60286 .28204 Mdot
.60476 .31375 Mdot
.60667 .24684 Mdot
.60857 .23002 Mdot
.61048 .23368 Mdot
.61238 .29141 Mdot
.61429 .22868 Mdot
.61619 .29955 Mdot
.6181 .30777 Mdot
.62 .27007 Mdot
.6219 .25846 Mdot
.62381 .26385 Mdot
.62571 .23075 Mdot
.62762 .3228 Mdot
.62952 .24704 Mdot
.63143 .24622 Mdot
.63333 .25288 Mdot
.63524 .32368 Mdot
.63714 .22734 Mdot
.63905 .2595 Mdot
.64095 .24136 Mdot
.64286 .29261 Mdot
.64476 .30808 Mdot
.64667 .27743 Mdot
.64857 .2384 Mdot
.65048 .32199 Mdot
.65238 .32283 Mdot
.65429 .3183 Mdot
.65619 .29131 Mdot
.6581 .25125 Mdot
.66 .24756 Mdot
.6619 .32778 Mdot
.66381 .26921 Mdot
.66571 .31418 Mdot
.66762 .32184 Mdot
.66952 .29501 Mdot
.67143 .27612 Mdot
.67333 .24214 Mdot
.67524 .31898 Mdot
.67714 .27773 Mdot
.67905 .26339 Mdot
.68095 .27547 Mdot
.68286 .23778 Mdot
.68476 .31518 Mdot
.68667 .2277 Mdot
.68857 .26409 Mdot
.69048 .24315 Mdot
.69238 .23784 Mdot
.69429 .33214 Mdot
.69619 .2541 Mdot
.6981 .26851 Mdot
.7 .23049 Mdot
.7019 .2573 Mdot
.70381 .23328 Mdot
.70571 .29949 Mdot
.70762 .28843 Mdot
.70952 .23279 Mdot
.71143 .28872 Mdot
.71333 .22892 Mdot
.71524 .22502 Mdot
.71714 .25528 Mdot
.71905 .22692 Mdot
.72095 .22655 Mdot
.72286 .2294 Mdot
.72476 .32178 Mdot
.72667 .27417 Mdot
.72857 .25549 Mdot
.73048 .23781 Mdot
.73238 .32216 Mdot
.73429 .23639 Mdot
.73619 .2535 Mdot
.7381 .27509 Mdot
.74 .24743 Mdot
.7419 .23537 Mdot
.74381 .2799 Mdot
.74571 .23085 Mdot
.74762 .24986 Mdot
.74952 .24136 Mdot
.75143 .26594 Mdot
.75333 .23659 Mdot
.75524 .24874 Mdot
.75714 .29315 Mdot
.75905 .25018 Mdot
.76095 .25175 Mdot
.76286 .31724 Mdot
.76476 .24552 Mdot
.76667 .30718 Mdot
.76857 .31821 Mdot
.77048 .23708 Mdot
.77238 .25637 Mdot
.77429 .32539 Mdot
.77619 .2969 Mdot
.7781 .30725 Mdot
.78 .28455 Mdot
.7819 .23973 Mdot
.78381 .28265 Mdot
.78571 .2574 Mdot
.78762 .23085 Mdot
.78952 .25434 Mdot
.79143 .28841 Mdot
.79333 .268 Mdot
.79524 .27979 Mdot
.79714 .29987 Mdot
.79905 .31666 Mdot
.80095 .2422 Mdot
.80286 .22623 Mdot
.80476 .26777 Mdot
.80667 .31831 Mdot
.80857 .33407 Mdot
.81048 .33101 Mdot
.81238 .22593 Mdot
.81429 .32277 Mdot
.81619 .23436 Mdot
.8181 .31019 Mdot
.82 .30809 Mdot
.8219 .31775 Mdot
.82381 .31482 Mdot
.82571 .24431 Mdot
.82762 .31158 Mdot
.82952 .3033 Mdot
.83143 .22384 Mdot
.83333 .22693 Mdot
.83524 .30668 Mdot
.83714 .27114 Mdot
.83905 .29641 Mdot
.84095 .24129 Mdot
.84286 .25267 Mdot
.84476 .28923 Mdot
.84667 .23366 Mdot
.84857 .23398 Mdot
.85048 .26563 Mdot
.85238 .2977 Mdot
.85429 .30533 Mdot
.85619 .31601 Mdot
.8581 .25597 Mdot
.86 .26072 Mdot
.8619 .2795 Mdot
.86381 .24191 Mdot
.86571 .27044 Mdot
.86762 .31439 Mdot
.86952 .32407 Mdot
.87143 .26595 Mdot
.87333 .23572 Mdot
.87524 .25373 Mdot
.87714 .25918 Mdot
.87905 .31598 Mdot
.88095 .24506 Mdot
.88286 .27203 Mdot
.88476 .32998 Mdot
.88667 .31485 Mdot
.88857 .32126 Mdot
.89048 .25363 Mdot
.89238 .32747 Mdot
.89429 .25218 Mdot
.89619 .27413 Mdot
.8981 .26377 Mdot
.9 .23981 Mdot
.9019 .24319 Mdot
.90381 .26052 Mdot
.90571 .2267 Mdot
.90762 .29951 Mdot
.90952 .2524 Mdot
.91143 .22747 Mdot
.91333 .26323 Mdot
.91524 .24883 Mdot
.91714 .26018 Mdot
.91905 .24577 Mdot
.92095 .24623 Mdot
.92286 .25191 Mdot
.92476 .30583 Mdot
.92667 .25608 Mdot
.92857 .24668 Mdot
.93048 .22252 Mdot
.93238 .24412 Mdot
.93429 .3134 Mdot
.93619 .24492 Mdot
.9381 .25245 Mdot
.94 .32394 Mdot
.9419 .27646 Mdot
.94381 .25018 Mdot
.94571 .27417 Mdot
.94762 .32025 Mdot
.94952 .28377 Mdot
.95143 .2278 Mdot
.95333 .32201 Mdot
.95524 .24271 Mdot
.95714 .32947 Mdot
.95905 .26213 Mdot
.96095 .32249 Mdot
.96286 .28382 Mdot
.96476 .32009 Mdot
.96667 .28237 Mdot
.96857 .24788 Mdot
.97048 .23658 Mdot
.97238 .29966 Mdot
.97429 .24443 Mdot
.97619 .22884 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo04Oooooo0_l0000Yooooo`;o00005_ooool2o`0007Cooooo0_l0000Nooooo`;o00006_ooool0
00Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`04ooooo`;o00002_oo
ool2o`0000?ooooo0_l0000`ooooo`;o00001Oooool2o`0000;ooooo0_l0000Jooooo`;o00000_oo
ool2o`000004ooooool0003o0000o`0001;ooooo0_l00002ooooo`;o00001oooool2o`0001?ooooo
0_l0000Cooooo`;o00003_ooool2o`0000Sooooo0ol0000Iooooo`;o000000?oooooo`000?l00000
1?ooool3o`0001Gooooo1?l00004ooooo`;o00001Oooool2o`0001?ooooo0004o`0000;ooooo00Go
410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`;o00002_ooool2o`000003ooooool0003o000000;o0000
1Oooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000005?ooool2o`0000Co
oooo0_l0000;ooooo`;o00000_ooool2o`0001Gooooo0_l000000ooooooo0000o`000002o`0000Go
oooo0ol0000Fooooo`;o00001oooool2o`0000oooooo0_l00002ooooo`;o00000oooool2o`0000Go
oooo1?l00002ooooo`;o000000?oooooo`000?l000003_ooool2o`0000?ooooo0_l00002ooooo`Go
00001Oooool2o`0000cooooo0_l00003ooooo`;o000000?oooooo`000?l000001Oooool2o`0001Go
oooo1?l0000;ooooo`;o00001_ooool2o`0000_ooooo0006ooooo`05o`000?ooooooooooooooool0
00003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000@ooooo`;o
000000Coooooo`000?l0003o00001Oooool3o`000003ooooool0003o000000?o000000?oooooo`00
0?l000004Oooool2o`000003ooooool0003o000000Cooooo0_l0000Fooooo`;o00000_ooool3o`00
00Wooooo0_l000000ooooooo0000o`00000Gooooo`;o00003Oooool5o`0000?ooooo0_l0000:oooo
o`;o00001oooool2o`0000Gooooo1?l00002ooooo`;o00005_ooool6o`000003ooooool0003o0000
00Gooooo0_l0000<ooooo`;o00004Oooool2o`0002Sooooo0_l0000;ooooo`001_ooool01Ol0003o
oooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool00_ooool2o`0000kooooo1?l00004ooooo`?o00000oooool2
o`0001Kooooo0_l0000Oooooo`;o000000?oooooo`000?l000000_l00006ooooo`;o00007Oooool2
o`0000Wooooo0_l00002ooooo`Oo000000Coooooo`000?l0003o00000oooool3o`0000Kooooo0_l0
000<ooooo`;o00007?ooool4o`0000Kooooo1?l00002ooooo`;o00000oooool2o`0000gooooo0_l0
0008ooooo`;o00001_ooool2o`0001kooooo0_l0000=ooooo`001_ooool01Ol@413ooooooooooooo
oooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00;ooooo0_l00006ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`;o0000
0oooool4o`0000Gooooo0_l00005ooooo`;o00000_ooool2o`0001Gooooo0_l00004ooooo`Co0000
3Oooool9o`000003ooooool0003o000000Sooooo0_l00009ooooo`;o00001?ooool2o`0000gooooo
0ol00006ooooo`;o00000_ooool2o`0000?ooooo0ol00006ooooo`;o00001Oooool2o`00017ooooo
0_l00009ooooo`;o000000?oooooo`000?l000002_ooool6o`0000;ooooo0_l00003ooooo`;o0000
0_ooool2o`0000Wooooo0_l0000@ooooo`;o00001oooool2o`0001Gooooo0_l0000=ooooo`001_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool2o`0000?ooooo0_l00004ooooo`;o
00001Oooool2o`0000Gooooo0_l00005ooooo`;o00000_ooool2o`0000gooooo0_l00006ooooo`;o
000000?oooooo`000?l000001Ol0000=ooooo`;o000000?oooooo`000?l000001?l00005ooooo`?o
00000oooool2o`0000Wooooo0_l00004ooooo`;o00001?ooool2o`0000Oooooo0ol0000<ooooo`;o
000000?oooooo`000?l000000_ooool2o`0000Sooooo1Ol0000>ooooo`Co00001_ooool2o`000004
ooooool0003o0000ooooo`;o00002_ooool2o`0000Gooooo0_l00008ooooo`;o00001?ooool2o`00
00_ooooo0_l00005ooooo`;o00002_ooool3o`0000oooooo0_l0000Booooo`001_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool0
0ol0003oooooooooo`09ooooo`?o00000oooool4o`0000cooooo0_l0000<ooooo`?o00002_ooool2
o`000004ooooool0003o0000ooooo`;o00001?ooool6o`000003ooooool0003o000000gooooo0_l0
0004ooooo`Co00001?ooool3o`0000Cooooo0_l000000ooooooo0000o`00000:ooooo`Co00000ooo
ool2o`0000Oooooo0_l0000=ooooo`Go00000_ooool2o`0000;ooooo0_l00004ooooo`;o000000?o
ooooo`000?l000002oooool2o`000003ooooool0003o000000Sooooo0_l00004ooooo`;o00004Ooo
ool2o`0000?ooooo0_l00009ooooo`;o00001_ooool2o`0000?ooooo0_l00005ooooo`;o00001?oo
ool2o`0000Gooooo0_l00003ooooo`?o000000?oooooo`000?l000000_l00004ooooo`;o00001?oo
ool2o`0000cooooo000Yooooo`;o00002_ooool2o`0000Cooooo1?l0000:ooooo`Co00003?ooool2
o`000003ooooool0003o000000Gooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0
003o000000Cooooo0_l00003ooooo`;o00001?ooool4o`000003ooooool0003o000000_ooooo0ol0
0009ooooo`Co000000Coooooo`000?l0003ooooo0_l00007ooooo`Ko00003oooool2o`0000Wooooo
0_l00008ooooo`;o00001_ooool2o`0000Cooooo0_l00005ooooo`?o00001oooool2o`0001Sooooo
0_l00002ooooo`;o00000_ooool2o`00017ooooo0_l0000@ooooo`;o00002Oooool9o`0000Sooooo
1?l0000<ooooo`00:Oooool00ol0003oooooooooo`0<ooooo`;o00003oooool2o`0000Gooooo0_l0
0007ooooo`;o000000?oooooo`000?l000001Oooool2o`0000cooooo0_l00002ooooo`Co00001?oo
ool4o`000003ooooool0003o000000Wooooo0_l00006ooooo`;o00001?ooool2o`0000?ooooo0_l0
00000ooooooo0000o`00000;ooooo`Co00003Oooool2o`0001;ooooo0_l00007ooooo`;o00001?oo
ool2o`0000Gooooo0_l00007ooooo`?o00006?ooool8o`0001Wooooo0_l0000>ooooo`;o00000ooo
ool8o`000003ooooool0003o000000;o00001_ooool2o`0000kooooo000Yooooo`;o00002?ooool2
o`0000?ooooo0_l00009ooooo`;o00002oooool2o`0001cooooo0_l000000ooooooo0000o`000002
ooooo`;o00001Oooool2o`0000oooooo0_l00006ooooo`;o00003oooool2o`0000Sooooo1?l0000:
ooooo`;o00005Oooool2o`0000?ooooo0_l0000@ooooo`;o00001_ooool2o`0000[ooooo0_l00005
ooooo`;o00000_ooool4o`0000;ooooo0_l00002ooooo`;o00001oooool2o`00013ooooo0_l00008
ooooo`;o00000oooool3o`0000?ooooo0_l00002ooooo`;o00000oooool4o`0001Kooooo000Yoooo
o`;o00000_ooool2o`0000Cooooo0_l0000=ooooo`?o00003_ooool2o`0001Wooooo0_l0000;oooo
o`?o00000oooool2o`0000Wooooo0_l0000Hooooo`Co00001?ooool2o`0000kooooo0_l0000Joooo
o`;o00003Oooool2o`000003ooooool0003o000001;ooooo1?l00003ooooo`;o00000_ooool4o`00
00[ooooo0_l00002ooooo`?o00005Oooool2o`0000?ooooo0_l00003ooooo`;o00002_ooool2o`00
01_ooooo000Yooooo`04o`000?ooooooooooooooo`;o00002oooool2o`0000Kooooo0_l0000?oooo
o`;o00000oooool2o`00027ooooo0_l00004ooooo`;o000000?oooooo`000?l000001_ooool2o`00
00?ooooo0_l00008ooooo`;o00002oooool2o`0000Cooooo0_l00006ooooo`;o0000:Oooool2o`00
00Kooooo0_l00003ooooo`;o00004_ooool2o`0001Gooooo0_l00002ooooo`;o00005_ooool2o`00
00Cooooo0_l00006ooooo`;o00000oooool2o`000003ooooool0003o000000Sooooo0_l0000Aoooo
o`00:Oooool2o`0000Kooooo0_l00007ooooo`;o00007?ooool2o`0000Kooooo0_l0000Rooooo`;o
00002oooool2o`0000Sooooo0_l0000>ooooo`;o00002Oooool2o`0002Wooooo0_l00006ooooo`;o
00000oooool2o`0000_ooooo0_l000000ooooooo0000o`00000eooooo`;o00001?ooool2o`0000Co
oooo1?l000000ooooooo0000o`000002o`0000_ooooo0_l0000Aooooo`00:Oooool00ol0003ooooo
ooooo`02o`0000?ooooo0_l00006ooooo`;o00008Oooool2o`0000;ooooo0_l0000Jooooo`;o0000
6_ooool2o`0000?ooooo0_l0000<ooooo`;o00009?ooool2o`0000Wooooo0_l00002ooooo`;o0000
1oooool2o`00013ooooo0_l000000ooooooo0000o`00000Booooo`;o00003?ooool2o`000003oooo
ool0003o000000gooooo0_l00005ooooo`;o00001_ooool2o`0000?ooooo0_l0000Pooooo`00:Ooo
ool2o`000003ooooool0003o000000_ooooo0_l00003ooooo`;o00003?ooool2o`0000kooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo0_l0000Jooooo`Oo00000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0Oooooo`;o00000_ooool2o`0000?ooooo00KoV9RHoa0@4?l0003o
<S8bolc<c?ooool2o`000005onk^k_lb<S;o0000o`000?o^k^h00oooool01Oo^k^ko<S8bo`000?l0
003ok^k^00_ooooo0_l00009ooooo`;o00003oooool2o`000004ooooool0003o0000oa0@40?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP02o`000006ooooool0003o0000o`000?lb<S;ok^k^1_ooool2
o`0000;ooooo0_l00003ooooo`Co00005_ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool002Wooooo
0_l0000Cooooo`Co00002_ooool2o`00013ooooo0_l00003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo0_l0000<ooooo`Co00003_ooool2o`00
00?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l00004ooooo`;o00002oooool2o`0000Gooooo
1?l00005ooooo`04oa0@4?nj^[[oooooogMgM`;o00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?l0003o0000ogMgM`0;ooooo`;o00002Oooool2o`0000Oooooo0_l0000:
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01_ooool2o`0000Oooooo0_l00003ooooo`;o00000oooool2o`0000kooooo
0_l000000oooooooMgMgoc8b<P02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo000Yooooo`03o`000?oooooooooo00_ooooo0_l00007ooooo`;o
00007?ooool5o`000005oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo
410@00Cooooo0_l00009ooooo`;o000000?oooooo`000?l000000_l0000=ooooo`?o00001?ooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooo
oooooooo410@00Gooooo0_l00004ooooo`;o00002oooool2o`0000Oooooo0_l00009ooooo`;o0000
0_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4006oooo
o`;o00001_ooool2o`000003ooooool0003o000000cooooo0_l00002ooooo`;o00000oooool5o`00
00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41005?oo
ool2o`0000?ooooo0_l0000<ooooo`Co00000_ooool01?l0003oooooooooool@4103ooooo`05oa0@
4?ooooooooooooooool@41000oooool00ol@413oooooooooo`01ooooo`00:Oooool2o`0000cooooo
0_l0000Iooooo`;o00002_ooool6o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo00;o00002Oooool4o`0001;ooooo0_l00006ooooo`03oiRHV?lQ8B7ok^k^00;o
000000?oooooo`000?ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool02oooool2o`0001[ooooo0_l000000onYZJWo410@ooooo`02ooooo`03o`000?oooooooooo
00;o00000oooool01Ol0003ooooooooooooooooo000000Kooooo0_l00006ooooo`Go00004?ooool4
o`000005oooooom4A4CogMgMooooool000001?ooool01?l0003oooooooooooooool3o`000003oooo
ool0003ooooo00;ooooo00?o0000ooooooooool03?ooool2o`0001Oooooo0_l00003ooooo`05ogMg
Molb<S;oooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool00Oooool002Wooooo00?o0000ooooooooool02Oooool2o`0000kooooo0_l00003ooooo`;o
00001_ooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000ooooo`03ooooo`03
o`000?oooooo000000Co000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`02o`0000Wo
oooo0_l0000Dooooo`;o00001oooool01_mgMgOoIVIVo`000?l0003oooooo`0000?ooooo0ol00000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo0_l000000ooooooo0000o`00000G
ooooo`?o000000Go^[Zjooooooooooooooooo`000002ooooo`?o00000_ooool01Ol0003ooooooooo
oooooooo000000oooooo0_l0000Dooooo`;o000000GoooooomgMgOmEEEGoooooo`000004ooooo`03
o`000?oooooo000000Co000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`;o
00006Oooool3o`000003oc8b<_o<c<co000000;o00000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool00Oooool002Wooooo00?o0000ooooooooool02Oooool2o`0000;o
oooo0_l0000:ooooo`;o00000_ooool3o`0000Wooooo1?l00002ooooo`;o000000?oooooo`000?oo
ool00oooool01Ol@413oooooo`000?l0003o410@00;o000000?ooooooa0@4?ooool00_ooool00ol@
413o0000o`000003ooooo`;o00007?ooool2o`0000Sooooo00Go0000oooooooooooooooooa0@4003
ooooo`05oa0@4?l0003o0000ooooool@41000oooool00ol@413oooooooooo`08ooooo`;o000000Co
ooooo`000?l0003ooooo0_l0000Iooooo`06okZj^_lQ8B7o0000o`000?oooooo410@0oooool2o`00
00;ooooo00Go410@oooooooooooooooooa0@400Yooooo`03ogMgMoo<c<co000000Cooooo1?l00000
1Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool09oooool3o`0000;ooooo0ol0
0003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`01ooooo`00:Ooo
ool00ol0003oooooooooo`0=ooooo`;o00002Oooool2o`0000?ooooo0_l00002ooooo`;o00002?oo
ool2o`0000Gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`02o`0000?ooooo0_l0000@ooooo`;o00002Oooool2o`0000Go
oooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo1Ol0000=ooooo`;o00002_ooool01?l@413oV9RHoooo
oonj^[X3o`000006oooooomgMgOoV9RHoooooonHV9SoMgMg0oooool01OmgMgOoV9RHoooooonHV9So
MgMg01Wooooo0ol0000=ooooo`03onk^k_m4A4Co000000Cooooo0_l000001?ooooooV9RHo`000?l0
0002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool2o`0001oooooo00?o0000ooooooooool0
1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`00:Oooool00ol0003oooooooooo`04ooooo`;o000000?oooooo`000?l000003oooool2o`0000Oo
oooo0_l0000=ooooo`03oeEEEOmVIVKo000000;o00000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0:ooooo`;o00002oooool2o`0000Wooooo0_l00005
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
00Gok^k^oc8b<_l0003o0000onk^kP03ooooo`;o00001_ooool2o`0000oooooo0_l00004ooooo`;o
00001?ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`?o000000?o<S8bonk^k_ooool00oooool2o`0000?ooooo0_l0000>ooooo`?o00003Oooool3
o`0000Cooooo00Cok^k^oc8b<_l0003o<S8b0_l00002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2?ooool2o`0001oooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo000Yooooo`Co00000_ooool3o`000003ooooool0003o000000ko
oooo0_l0000<ooooo`;o00003?ooool2o`0001Wooooo0_l0000Dooooo`;o00006Oooool2o`0000Co
oooo0_l0000Cooooo`;o00002?ooool2o`0001Cooooo0_l00007ooooo`;o00000oooool2o`0000;o
oooo0_l0000Jooooo`;o0000D_ooool002Wooooo00Co0000ooooool0003o00000_ooool2o`0001;o
oooo0_l0000<ooooo`Co00005Oooool2o`0002Cooooo0_l0000Kooooo`;o00001_ooool2o`0000oo
oooo0_l000000ooooooo0000o`00000]ooooo`;o00002_ooool2o`0001Cooooo0_l0000Booooo`;o
00000oooool2o`0003?ooooo000Yooooo`03o`000?oooooooooo02Oooooo0_l000000ooooooo0000
o`00000Booooo`;o00000oooool2o`00037ooooo0_l00009ooooo`;o00001Oooool3o`0000gooooo
0_l00003ooooo`;o000000?oooooo`000?l000006Oooool2o`0001_ooooo0_l0000Dooooo`;o0000
1Oooool2o`0000_ooooo0_l00003ooooo`;o00003oooool2o`0001?ooooo0_l0000=ooooo`00:Ooo
ool00ol0003oooooooooo`02ooooo`;o00007_ooool2o`0000Kooooo0_l0000Gooooo`;o00004_oo
ool2o`0001gooooo0_l00004ooooo`;o00002_ooool2o`0000kooooo0_l00006ooooo`;o00005?oo
ool2o`0000?ooooo0_l0000hooooo`;o00002?ooool2o`0000Kooooo0_l0000?ooooo`;o00004ooo
ool2o`0000gooooo000Yooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o00006_ooool2
o`0002Sooooo0_l00009ooooo`;o00007oooool3o`000003ooooool0003o000000;o00002Oooool2
o`0002_ooooo0_l00003ooooo`;o00001oooool2o`0002Gooooo0_l00002ooooo`;o00002oooool2
o`000003ooooool0003o000000;o00001?ooool2o`0001Gooooo0_l0000Looooo`008Oooooooo`00
04Co00001?ooool002Wooooo1?l00007ooooo`;o00003?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Kooooo0_l000000ooooooo0000ooooo`02ooooo`;o00000_ooool2o`0000;o
oooo0ol00004ooooo`;o00001?ooool00ol0003oooooooooo`09ooooo`?o00001?ooool2o`0000?o
oooo00?o0000ooooooooool02Oooool2o`000003ooooool0003o000000Oooooo0_l0000;ooooo`03
o`000?oooooooooo00Cooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00001Oooool3o`00
0003ooooool0003o000000Sooooo00?o0000ooooooooool02Oooool01?l0003oooooo`000?l00008
ooooo`03o`000?oooooooooo00Oooooo0ol0000<ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`07ooooo`Go00002_ooool3o`0000Cooooo0_l00003
ooooo`03o`000?oooooooooo00Oooooo0ol0000;ooooo`03o`000?oooooooooo00[ooooo000Yoooo
o`04o`000?ooooooooooooooo`;o00001Oooool2o`00013ooooo0_l0000?ooooo`;o00001Oooool2
o`0000Kooooo0ol00004ooooo`;o00004Oooool2o`0000Cooooo0_l0000Gooooo`;o00000_ooool2
o`0001;ooooo0ol0000=ooooo`?o000000?oooooo`000?l000005?ooool01?l0003oooooo`000?l0
000Booooo`;o00001?ooool2o`0001Oooooo0_l00006ooooo`04o`000?ooooooooooooooo`;o0000
1Oooool3o`0000Sooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l0000=ooooo`;o
00003?ooool00ol0003oooooooooo`0:ooooo`00:Oooool01?l0003oooooooooooooool2o`0001Go
oooo1?l0000<ooooo`;o00004?ooool2o`0000;ooooo0_l0000Iooooo`;o00004_ooool2o`0000Co
oooo0_l0000Gooooo`;o00001Oooool2o`000003ooooool0003o000000gooooo0_l00006ooooo`;o
00001?ooool2o`0001;ooooo0_l00005ooooo`;o000000?oooooo`000?l000005oooool4o`0000So
oooo1?l00003ooooo`;o00002Oooool2o`0000Gooooo0_l000000ooooooo0000o`00000Aooooo`;o
00001?ooool2o`0000oooooo000Yooooo`03o`000?oooooooooo01Sooooo0_l0000>ooooo`;o0000
3?ooool2o`0000;ooooo0_l00002ooooo`Co00005oooool4o`0000;ooooo0_l0000<ooooo`;o0000
2_ooool2o`0001Sooooo0_l000000ooooooo0000o`00000=ooooo`;o000000?oooooo`000?l00000
0oooool2o`0000Cooooo0_l00009ooooo`;o000000?oooooo`000?l000000oooool3o`0000;ooooo
0_l000000ooooooo0000o`00000>ooooo`Co00002_ooool2o`0000[ooooo1?l0000@ooooo`;o0000
1?ooool2o`0000oooooo1_l000001?oooooo0000o`000?l0000?ooooo`00:Oooool2o`0000gooooo
0_l0000Eooooo`;o00000oooool2o`0000cooooo1?l00006ooooo`;o000000?oooooo`000?l00000
3oooool2o`0000Gooooo0_l00002ooooo`;o00006?ooool2o`0000;ooooo0_l00004ooooo`;o0000
4oooool2o`0000gooooo0ol00003ooooo`;o00003oooool2o`000003ooooool0003o000000?ooooo
0_l00003ooooo`;o00004Oooool4o`0000cooooo0_l0000:ooooo`;o00004?ooool2o`0000Kooooo
0_l0000=ooooo`;o00000_ooool2o`000003ooooool0003o0000013ooooo000Yooooo`03o`000?oo
oooooooo00Gooooo0_l00005ooooo`;o00005Oooool2o`00013ooooo0_l000000ooooooo0000o`00
0005ooooo`;o00000_ooool2o`0000oooooo0_l0000Wooooo`;o00001?ooool2o`0001?ooooo0_l0
000=ooooo`;o000000?oooooo`000?l000007Oooool2o`0002?ooooo0_l0000Qooooo`;o000000?o
ooooo`000?l000004_ooool2o`0001;ooooo000Yooooo`03o`000?oooooooooo00Gooooo0_l0000^
ooooo`;o00002?ooool2o`0003cooooo0_l0000[ooooo`;o00007Oooool2o`0000Wooooo0_l0000S
ooooo`;o00005_ooool2o`0001Gooooo0_l0000Booooo`00:Oooool00ol0003oooooooooo`0aoooo
o`;o0000XOooool2o`0002?ooooo0_l00011ooooo`00:Oooool00ol0003oooooooooo`0aooooo`;o
0000a_ooool2o`00047ooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000
oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0
0004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocgooooo
0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`00
1_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`000?oo
oooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Ol@413ooooooooooooooooo
410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000kooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooooooooooooooooa0@
400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`003_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0
003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0
003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo
410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolm
ooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@
400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooo
oooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo
0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`;o0000
oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000
oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool001oooooo1?l000000ol@
413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
0ol0003oooooocgooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool001oooooo00?oEEEEofIVI_l00000oooooom7ooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .34137 Mdot
.02762 .35949 Mdot
.02952 .28175 Mdot
.03143 .33748 Mdot
.03333 .35823 Mdot
.03524 .35126 Mdot
.03714 .31191 Mdot
.03905 .36811 Mdot
.04095 .27667 Mdot
.04286 .34637 Mdot
.04476 .34456 Mdot
.04667 .31939 Mdot
.04857 .37601 Mdot
.05048 .35171 Mdot
.05238 .24203 Mdot
.05429 .34339 Mdot
.05619 .3321 Mdot
.0581 .37734 Mdot
.06 .35551 Mdot
.0619 .37694 Mdot
.06381 .33519 Mdot
.06571 .33134 Mdot
.06762 .28695 Mdot
.06952 .36696 Mdot
.07143 .24903 Mdot
.07333 .36809 Mdot
.07524 .32896 Mdot
.07714 .34499 Mdot
.07905 .36142 Mdot
.08095 .3346 Mdot
.08286 .28543 Mdot
.08476 .30941 Mdot
.08667 .32148 Mdot
.08857 .30723 Mdot
.09048 .3493 Mdot
.09238 .29142 Mdot
.09429 .30948 Mdot
.09619 .33615 Mdot
.0981 .30169 Mdot
.1 .34742 Mdot
.1019 .29993 Mdot
.10381 .33712 Mdot
.10571 .33806 Mdot
.10762 .37335 Mdot
.10952 .36769 Mdot
.11143 .36345 Mdot
.11333 .33843 Mdot
.11524 .33751 Mdot
.11714 .36759 Mdot
.11905 .31863 Mdot
.12095 .32415 Mdot
.12286 .33763 Mdot
.12476 .22284 Mdot
.12667 .32521 Mdot
.12857 .35893 Mdot
.13048 .29086 Mdot
.13238 .35382 Mdot
.13429 .34784 Mdot
.13619 .32736 Mdot
.1381 .36807 Mdot
.14 .35847 Mdot
.1419 .27485 Mdot
.14381 .27855 Mdot
.14571 .33434 Mdot
.14762 .2517 Mdot
.14952 .31532 Mdot
.15143 .34218 Mdot
.15333 .33289 Mdot
.15524 .34937 Mdot
.15714 .35263 Mdot
.15905 .37374 Mdot
.16095 .30483 Mdot
.16286 .33769 Mdot
.16476 .34395 Mdot
.16667 .27796 Mdot
.16857 .29337 Mdot
.17048 .22259 Mdot
.17238 .33028 Mdot
.17429 .34415 Mdot
.17619 .31369 Mdot
.1781 .28667 Mdot
.18 .3233 Mdot
.1819 .332 Mdot
.18381 .34603 Mdot
.18571 .35859 Mdot
.18762 .34366 Mdot
.18952 .35894 Mdot
.19143 .33801 Mdot
.19333 .36027 Mdot
.19524 .32998 Mdot
.19714 .23941 Mdot
.19905 .22846 Mdot
.20095 .3348 Mdot
.20286 .35907 Mdot
.20476 .33642 Mdot
.20667 .24632 Mdot
.20857 .35142 Mdot
.21048 .2821 Mdot
.21238 .22384 Mdot
.21429 .37282 Mdot
.21619 .33294 Mdot
.2181 .3685 Mdot
.22 .2897 Mdot
.2219 .36569 Mdot
.22381 .33256 Mdot
.22571 .30945 Mdot
.22762 .36446 Mdot
.22952 .35766 Mdot
.23143 .33448 Mdot
.23333 .33988 Mdot
.23524 .3506 Mdot
.23714 .34117 Mdot
.23905 .3013 Mdot
.24095 .3533 Mdot
.24286 .21714 Mdot
.24476 .31489 Mdot
.24667 .35083 Mdot
.24857 .35888 Mdot
.25048 .34589 Mdot
.25238 .26493 Mdot
.25429 .36818 Mdot
.25619 .29682 Mdot
.2581 .28111 Mdot
.26 .37132 Mdot
.2619 .34707 Mdot
.26381 .33378 Mdot
.26571 .34026 Mdot
.26762 .24956 Mdot
.26952 .29545 Mdot
.27143 .32948 Mdot
.27333 .31858 Mdot
.27524 .32276 Mdot
.27714 .30101 Mdot
.27905 .36712 Mdot
.28095 .34131 Mdot
.28286 .3658 Mdot
.28476 .35842 Mdot
.28667 .34658 Mdot
.28857 .33524 Mdot
.29048 .29504 Mdot
.29238 .2537 Mdot
.29429 .23057 Mdot
.29619 .33886 Mdot
.2981 .35427 Mdot
.3 .3359 Mdot
.3019 .36997 Mdot
.30381 .35854 Mdot
.30571 .21618 Mdot
.30762 .3245 Mdot
.30952 .3421 Mdot
.31143 .34449 Mdot
.31333 .37163 Mdot
.31524 .35331 Mdot
.31714 .37468 Mdot
.31905 .30153 Mdot
.32095 .31852 Mdot
.32286 .33295 Mdot
.32476 .30265 Mdot
.32667 .33873 Mdot
.32857 .29351 Mdot
.33048 .33958 Mdot
.33238 .36849 Mdot
.33429 .35811 Mdot
.33619 .3653 Mdot
.3381 .27834 Mdot
.34 .30395 Mdot
.3419 .3075 Mdot
.34381 .3519 Mdot
.34571 .34092 Mdot
.34762 .34776 Mdot
.34952 .36427 Mdot
.35143 .29014 Mdot
.35333 .3334 Mdot
.35524 .33783 Mdot
.35714 .34593 Mdot
.35905 .33839 Mdot
.36095 .28742 Mdot
.36286 .24461 Mdot
.36476 .31353 Mdot
.36667 .327 Mdot
.36857 .33789 Mdot
.37048 .36872 Mdot
.37238 .33507 Mdot
.37429 .34671 Mdot
.37619 .30097 Mdot
.3781 .33117 Mdot
.38 .25708 Mdot
.3819 .23802 Mdot
.38381 .34273 Mdot
.38571 .35877 Mdot
.38762 .34964 Mdot
.38952 .29802 Mdot
.39143 .37366 Mdot
.39333 .33474 Mdot
.39524 .25319 Mdot
.39714 .35861 Mdot
.39905 .33004 Mdot
.40095 .29754 Mdot
.40286 .35578 Mdot
.40476 .24739 Mdot
.40667 .37237 Mdot
.40857 .32596 Mdot
.41048 .3261 Mdot
.41238 .30632 Mdot
.41429 .34589 Mdot
.41619 .24136 Mdot
.4181 .31167 Mdot
.42 .33264 Mdot
.4219 .34424 Mdot
.42381 .33952 Mdot
.42571 .32676 Mdot
.42762 .34969 Mdot
.42952 .37503 Mdot
.43143 .33495 Mdot
.43333 .33867 Mdot
.43524 .34133 Mdot
.43714 .30309 Mdot
.43905 .32853 Mdot
.44095 .35773 Mdot
.44286 .32643 Mdot
.44476 .33671 Mdot
.44667 .35795 Mdot
.44857 .3535 Mdot
.45048 .28857 Mdot
.45238 .34804 Mdot
.45429 .27352 Mdot
.45619 .32946 Mdot
.4581 .3539 Mdot
.46 .3772 Mdot
.4619 .33743 Mdot
.46381 .24403 Mdot
.46571 .31578 Mdot
.46762 .34344 Mdot
.46952 .29904 Mdot
.47143 .22381 Mdot
.47333 .34705 Mdot
.47524 .343 Mdot
.47714 .28536 Mdot
.47905 .33938 Mdot
.48095 .36754 Mdot
.48286 .31886 Mdot
.48476 .32752 Mdot
.48667 .26389 Mdot
.48857 .36141 Mdot
.49048 .35218 Mdot
.49238 .37352 Mdot
.49429 .33499 Mdot
.49619 .3367 Mdot
.4981 .29359 Mdot
.5 .31425 Mdot
.5019 .37401 Mdot
.50381 .29283 Mdot
.50571 .31928 Mdot
.50762 .3166 Mdot
.50952 .33363 Mdot
.51143 .27935 Mdot
.51333 .35654 Mdot
.51524 .33501 Mdot
.51714 .3762 Mdot
.51905 .29381 Mdot
.52095 .33351 Mdot
.52286 .33575 Mdot
.52476 .36103 Mdot
.52667 .34352 Mdot
.52857 .27862 Mdot
.53048 .32781 Mdot
.53238 .363 Mdot
.53429 .32671 Mdot
.53619 .33013 Mdot
.5381 .30963 Mdot
.54 .28383 Mdot
.5419 .34432 Mdot
.54381 .32348 Mdot
.54571 .36484 Mdot
.54762 .34925 Mdot
.54952 .34051 Mdot
.55143 .34253 Mdot
.55333 .34729 Mdot
.55524 .36078 Mdot
.55714 .31765 Mdot
.55905 .35249 Mdot
.56095 .33483 Mdot
.56286 .34481 Mdot
.56476 .31781 Mdot
.56667 .335 Mdot
.56857 .28369 Mdot
.57048 .30176 Mdot
.57238 .35871 Mdot
.57429 .30505 Mdot
.57619 .31984 Mdot
.5781 .36804 Mdot
.58 .34943 Mdot
.5819 .27959 Mdot
.58381 .23301 Mdot
.58571 .30499 Mdot
.58762 .25409 Mdot
.58952 .27608 Mdot
.59143 .29466 Mdot
.59333 .34548 Mdot
.59524 .23569 Mdot
.59714 .37206 Mdot
.59905 .24382 Mdot
.60095 .21577 Mdot
.60286 .35156 Mdot
.60476 .37701 Mdot
.60667 .33418 Mdot
.60857 .32443 Mdot
.61048 .27406 Mdot
.61238 .34277 Mdot
.61429 .30365 Mdot
.61619 .35875 Mdot
.6181 .32478 Mdot
.62 .36152 Mdot
.6219 .33685 Mdot
.62381 .3573 Mdot
.62571 .3398 Mdot
.62762 .32227 Mdot
.62952 .33168 Mdot
.63143 .31932 Mdot
.63333 .25117 Mdot
.63524 .32327 Mdot
.63714 .32571 Mdot
.63905 .24206 Mdot
.64095 .25684 Mdot
.64286 .33783 Mdot
.64476 .37599 Mdot
.64667 .35479 Mdot
.64857 .27792 Mdot
.65048 .36063 Mdot
.65238 .31783 Mdot
.65429 .30514 Mdot
.65619 .36079 Mdot
.6581 .36226 Mdot
.66 .26213 Mdot
.6619 .33463 Mdot
.66381 .36046 Mdot
.66571 .32907 Mdot
.66762 .30861 Mdot
.66952 .37506 Mdot
.67143 .35753 Mdot
.67333 .30545 Mdot
.67524 .36728 Mdot
.67714 .34272 Mdot
.67905 .23314 Mdot
.68095 .34582 Mdot
.68286 .30363 Mdot
.68476 .336 Mdot
.68667 .29874 Mdot
.68857 .32633 Mdot
.69048 .34098 Mdot
.69238 .29791 Mdot
.69429 .33492 Mdot
.69619 .32153 Mdot
.6981 .23411 Mdot
.7 .33289 Mdot
.7019 .36188 Mdot
.70381 .30004 Mdot
.70571 .36023 Mdot
.70762 .36013 Mdot
.70952 .30107 Mdot
.71143 .35687 Mdot
.71333 .32864 Mdot
.71524 .28635 Mdot
.71714 .35285 Mdot
.71905 .29463 Mdot
.72095 .32284 Mdot
.72286 .33376 Mdot
.72476 .31115 Mdot
.72667 .34744 Mdot
.72857 .24742 Mdot
.73048 .34539 Mdot
.73238 .31103 Mdot
.73429 .29229 Mdot
.73619 .32391 Mdot
.7381 .35748 Mdot
.74 .33402 Mdot
.7419 .27825 Mdot
.74381 .3647 Mdot
.74571 .31931 Mdot
.74762 .25983 Mdot
.74952 .28306 Mdot
.75143 .36896 Mdot
.75333 .30913 Mdot
.75524 .25322 Mdot
.75714 .21823 Mdot
.75905 .25823 Mdot
.76095 .33716 Mdot
.76286 .31385 Mdot
.76476 .25548 Mdot
.76667 .36703 Mdot
.76857 .30476 Mdot
.77048 .34662 Mdot
.77238 .35178 Mdot
.77429 .3129 Mdot
.77619 .34288 Mdot
.7781 .36096 Mdot
.78 .34149 Mdot
.7819 .34377 Mdot
.78381 .37348 Mdot
.78571 .24272 Mdot
.78762 .33539 Mdot
.78952 .33273 Mdot
.79143 .22217 Mdot
.79333 .34662 Mdot
.79524 .34241 Mdot
.79714 .35245 Mdot
.79905 .2882 Mdot
.80095 .35195 Mdot
.80286 .31703 Mdot
.80476 .33011 Mdot
.80667 .3387 Mdot
.80857 .35465 Mdot
.81048 .34551 Mdot
.81238 .32645 Mdot
.81429 .3633 Mdot
.81619 .29652 Mdot
.8181 .33965 Mdot
.82 .35154 Mdot
.8219 .32714 Mdot
.82381 .36036 Mdot
.82571 .30658 Mdot
.82762 .35184 Mdot
.82952 .33298 Mdot
.83143 .31996 Mdot
.83333 .30051 Mdot
.83524 .27988 Mdot
.83714 .35115 Mdot
.83905 .36368 Mdot
.84095 .29486 Mdot
.84286 .3228 Mdot
.84476 .34474 Mdot
.84667 .27243 Mdot
.84857 .26437 Mdot
.85048 .35464 Mdot
.85238 .21825 Mdot
.85429 .37888 Mdot
.85619 .33374 Mdot
.8581 .24974 Mdot
.86 .24311 Mdot
.8619 .33781 Mdot
.86381 .28333 Mdot
.86571 .229 Mdot
.86762 .33897 Mdot
.86952 .31398 Mdot
.87143 .33275 Mdot
.87333 .29164 Mdot
.87524 .32584 Mdot
.87714 .23757 Mdot
.87905 .33107 Mdot
.88095 .31898 Mdot
.88286 .35072 Mdot
.88476 .33267 Mdot
.88667 .32643 Mdot
.88857 .34771 Mdot
.89048 .36403 Mdot
.89238 .31703 Mdot
.89429 .35362 Mdot
.89619 .3618 Mdot
.8981 .35096 Mdot
.9 .33473 Mdot
.9019 .27506 Mdot
.90381 .33936 Mdot
.90571 .27945 Mdot
.90762 .34391 Mdot
.90952 .36349 Mdot
.91143 .32958 Mdot
.91333 .32375 Mdot
.91524 .35339 Mdot
.91714 .3334 Mdot
.91905 .31089 Mdot
.92095 .34513 Mdot
.92286 .34032 Mdot
.92476 .35319 Mdot
.92667 .32498 Mdot
.92857 .31967 Mdot
.93048 .31381 Mdot
.93238 .31989 Mdot
.93429 .284 Mdot
.93619 .32069 Mdot
.9381 .32428 Mdot
.94 .30226 Mdot
.9419 .33032 Mdot
.94381 .3304 Mdot
.94571 .3552 Mdot
.94762 .32247 Mdot
.94952 .35037 Mdot
.95143 .31398 Mdot
.95333 .36148 Mdot
.95524 .32333 Mdot
.95714 .35748 Mdot
.95905 .32703 Mdot
.96095 .31256 Mdot
.96286 .2212 Mdot
.96476 .31671 Mdot
.96667 .36763 Mdot
.96857 .25978 Mdot
.97048 .28741 Mdot
.97238 .34977 Mdot
.97429 .34329 Mdot
.97619 .32968 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l00014ooooo`;o00004_ooool2
o`0005gooooo0_l0000`ooooo`;o00007Oooool2o`0003?ooooo000Yooooo`03o`000?oooooooooo
04?ooooo0_l0000Booooo`;o0000GOooool2o`00033ooooo0_l0000Mooooo`;o00008Oooool2o`00
013ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Mooooo`;o00003?ooool2
o`0000cooooo0_l0001Aooooo`;o0000IOooool2o`0003Gooooo0_l0000@ooooo`001_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01gooooo0_l0000<ooooo`;o00003?oo
ool2o`00057ooooo0_l0001Uooooo`;o0000Aoooool000Co00000_ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo03Gooooo0_l0000Looooo`;o0000]_ooool2o`0002oooooo0006ooooo`05o`000?oooooo
ooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0
000eooooo`;o00007?ooool2o`0005_ooooo0_l0000Mooooo`;o00001?ooool2o`0003Cooooo0_l0
000_ooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool2o`0000;ooooo
0_l0000Iooooo`;o00001?ooool2o`0006Gooooo0006ooooo`05oa0@4?ooooooooooooooool@4100
3oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
=?ooool2o`0003Wooooo0_l00013ooooo`;o0000FOooool2o`0002_ooooo0006ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`05ooooo`;o0000;Oooool2o`0003Wooooo0_l00009ooooo`;o
0000A_ooool2o`0002gooooo0_l0000Fooooo`;o00001?ooool2o`0002_ooooo0006ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006oooo
o`03o`000?oooooooooo00Gooooo0_l0000`ooooo`;o0000<?ooool2o`0000oooooo0_l0000>oooo
o`;o0000:Oooool2o`0000_ooooo0_l0000]ooooo`;o00005_ooool2o`00037ooooo000Yooooo`;o
00003Oooool2o`0002Wooooo0_l0000Booooo`;o00007?ooool2o`0000cooooo0_l0000Aooooo`;o
0000:Oooool2o`0002Sooooo0_l0001Kooooo`00:Oooool00ol0003oooooooooo`0<ooooo`;o0000
5_ooool2o`0002Gooooo0_l0000Zooooo`;o0000Aoooool2o`0001gooooo0_l0000Xooooo`;o0000
<Oooool002Wooooo00?o0000ooooooooool09?ooool2o`0002gooooo0_l0000Oooooo`;o0000??oo
ool2o`0000cooooo0_l0000Uooooo`;o00000_ooool2o`0001cooooo0_l0000aooooo`00:Oooool0
0ol0003oooooooooo`1Cooooo`;o00006_ooool2o`0000?ooooo0_l0000looooo`;o00003oooool2
o`0002;ooooo1_l0001?ooooo`00:Oooool00ol0003oooooooooo`1_ooooo`;o0000D_ooool2o`00
00Cooooo0_l0000Jooooo`;o00000_ooool2o`00047ooooo0_l0000>ooooo`00:Oooool2o`0004Oo
oooo0_l00019ooooo`;o0000=_ooool2o`0001[ooooo0_l0000Nooooo`;o00009Oooool2o`0000ko
oooo000Yooooo`03o`000?oooooooooo04Kooooo0_l00019ooooo`;o0000L_ooool2o`0003Gooooo
000Yooooo`03o`000?oooooooooo033ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb
<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Wooooo1Ol00003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo00GoV9RHoa0@4?l0003o
<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^02[ooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h0:Oooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool002Wooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg02Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l0
000Qooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00;o
oooo0_l000001?nHV9SooooooiRHV?mgMgL[ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02Oooool2o`00027ooooo00Wo
MgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo000Yooooo`03o`000?oooooooooo00;ooooo0_l0000Nooooo`;o00003_ooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@02[ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooooooooa0@4005ooooo`;o00009Oooool01?l0003oooooooooooooool2o`00
00;ooooo00?o410@ooooooooool00_l00003ooooo`03oa0@4?oooooooooo02Kooooo1Ol00003oooo
o`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Wooooo0_l0
000@ooooo`;o00004?ooool01?l0003oooooooooool@4103ooooo`05oa0@4?ooooooooooooooool@
41000oooool00ol@413oooooooooo`01ooooo`00:Oooool2o`0000?ooooo0_l0000Nooooo`?o0000
1Oooool2o`0000Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`;o00003?ooool00onHV9So8B4Qonk^kP03oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000001Oooooo0_l0
0004ooooo`;o00003?ooool00onYZJWo410@ooooo`04o`0000;ooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo00Cooooo0_l0000Looooo`;o00000_ooool01?m4A4CogMgM
ooooool00004ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000Gooooo0_l0000Dooooo`?o00003_ooool01OmgMgOo<S8boooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo007ooooo000Yooooo`?o00008ooo
ool2o`0000Gooooo0_l00006ooooo`03o`000?oooooooooo00;ooooo0ol000000ooooooo0000oooo
o`02ooooo`05o`000?ooooooooooooooool000001?ooool2o`0001Oooooo0_l0000=ooooo`03ogMg
MomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000005oooool2o`0000Cooooo0_l000000ooooooo0000o`000007ooooo`?o000000?o^[Zjoooo
ool000000_l00003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`04
ooooo`;o00007?ooool2o`000006ooooool0003o0000oeEEEOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000005ooooo`;o00001oooool2o`00
00cooooo0_l0000;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`00:Oooool3o`0000[ooooo0_l0
0003ooooo`;o00007Oooool2o`0000;ooooo00?o0000ooooooooool00_ooool01Ol@413o0000o`00
0?oooooo410@00?ooooo00Go410@oooooooooooooooooa0@4004ooooo`;o00009oooool01Ol0003o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooo
oooo00[ooooo0_l0000Booooo`;o00001oooool2o`000003okZj^_lQ8B7ooooo00;ooooo00Go410@
oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41007?ooool2o`0000Wooooo
0_l000000omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@00kooooo0_l0000Eooooo`;o00000_ooool00ol0003oooooooooo`04oooo
o`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo000Y
ooooo`03o`000?oooooooooo00[ooooo0_l00003ooooo`;o00007Oooool2o`0000;ooooo00?o0000
ooooooooool00_ooool01?mgMgOoV9RHoooooonHV9P2o`0000;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0Rooooo`;o000000?oooooo`000?l000000_ooool01Ol0003o^[ZjoooooonHV9So410@00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool2
o`0000Oooooo0_l0000Jooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`;o00002oooool00oo^k^ko
A4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool2o`000004oiRHV?ooooooV9RH
ogMgMbGooooo0_l00002ooooo`03o`000?oooooooooo00Cooooo00GoMgMgo`000?l0003oV9RHogMg
M`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wooooo00?o0000ooooooooool04_oo
ool2o`0000_ooooo0_l0000?ooooo`03oeEEEOmVIVKo000000Cooooo00Cok^k^oc8b<_l0003o<S8b
0_l00002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool2o`000003ooooool0003o000000;o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo0_l0000@ooooo`;o00004Oooool01OnYZJWo410@o`00
0?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h08_ooool2o`0000Kooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00;ooooo0_l000001?lb<S;o0000oc8b<_o^k^hAooooo`;o00005_ooool4o`0000?ooooo00Go
k^k^o`000?l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool002Wooooo
0_l0000Cooooo`;o00002oooool2o`0000[ooooo0_l0000Nooooo`;o00001Oooool2o`0000[ooooo
0_l0000eooooo`Co00000oooool2o`0001Gooooo0_l0000Wooooo`;o00000oooool2o`00023ooooo
0_l00008ooooo`;o0000;Oooool002Wooooo00?o0000ooooooooool0:oooool2o`0001[ooooo0_l0
0002ooooo`;o00001Oooool2o`0000[ooooo0_l0000Booooo`;o00000_ooool2o`0001Cooooo0_l0
0007ooooo`;o00001Oooool2o`0001Gooooo0_l0000Looooo`Co00001oooool2o`0001gooooo0_l0
0006ooooo`;o0000=oooool002Wooooo00?o0000ooooooooool05?ooool3o`0002[ooooo0_l00004
ooooo`;o00001Oooool2o`0000_ooooo0_l0000Aooooo`;o00000_ooool2o`0000;ooooo0_l0000D
ooooo`;o00007_ooool2o`0002?ooooo1?l00002ooooo`Co00008?ooool2o`0000Cooooo0_l0000P
ooooo`;o00005oooool002Wooooo00?o0000ooooooooool05?ooool3o`00017ooooo0_l0000Goooo
o`;o00002oooool2o`0000_ooooo1?l00003ooooo`;o00002_ooool2o`00017ooooo0_l0000Yoooo
o`?o00000_ooool2o`0000Oooooo0_l0000;ooooo`;o00001?ooool2o`000003ooooool0003o0000
00Gooooo1?l0000Aooooo`;o00004oooool2o`00023ooooo0_l0000Gooooo`00:Oooool00ol0003o
ooooooooo`0Aooooo`;o00005Oooool2o`0003?ooooo0_l00003ooooo`?o00005?ooool2o`0000Ko
oooo0_l0000Zooooo`;o00000_ooool2o`0000Oooooo0_l0000;ooooo`;o00000_ooool4o`000003
ooooool0003o000001[ooooo0_l0000@ooooo`;o0000??ooool0027oooooool00014o`0000Cooooo
000Yooooo`04o`000?ooooooooooooooo`;o00001_ooool00ol0003oooooooooo`04ooooo`;o0000
00Goooooo`000?l0003oooooo`00000;ooooo`03o`000?oooooooooo00Sooooo0_l0000;ooooo`03
o`000?oooooooooo00;o00001?ooool2o`0000;ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Sooooo0_l0000<ooooo`03o`000?oooooooooo00;o
00001oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo0_l00005ooooo`03
o`000?oooooooooo00?ooooo0_l00005ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooo
oooooooo1?l00004ooooo`?o000000?oooooo`000?l000000_ooool2o`0000;ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`?o00002Oooool00ol0003oooooooooo`02oooo
o`;o00000_ooool2o`000003ooooool0003ooooo00;ooooo0_l000000ooooooo0000o`000003oooo
o`03o`000?oooooooooo00[ooooo000Yooooo`03o`000?oooooooooo02Gooooo0_l00006ooooo`;o
00002oooool00ol0003oooooooooo`06ooooo`;o00009Oooool2o`0000cooooo00?o0000oooooooo
ool03oooool2o`0000Wooooo0_l000000ooooooo0000o`00000>ooooo`Co00002Oooool00ol0003o
ooooooooo`0>ooooo`;o00008_ooool2o`0000;ooooo0_l00002ooooo`03o`000?oooooooooo00;o
oooo0_l0000Cooooo`;o00001_ooool2o`0000[ooooo0_l00005ooooo`;o000000Coooooo`000?l0
003o00000_ooool00ol0003oooooooooo`0:ooooo`00:Oooool00ol0003oooooooooo`04ooooo`;o
00005Oooool2o`0000Sooooo0_l0000Vooooo`;o00003Oooool2o`0002cooooo0_l00004ooooo`;o
00001Oooool3o`0000kooooo1?l00002ooooo`;o00004?ooool2o`0000Cooooo0_l0000Looooo`;o
00004Oooool2o`0000Oooooo0_l0000>ooooo`;o00000_ooool2o`0000Wooooo1Ol00007ooooo`;o
00003oooool002Wooooo00?o0000ooooooooool01?ooool2o`0000[ooooo0_l00009ooooo`?o0000
4?ooool2o`0001gooooo0_l0000=ooooo`;o0000<_ooool2o`0000Gooooo0_l0000:ooooo`;o0000
2Oooool2o`0000kooooo1Ol0000Aooooo`;o00001_ooool2o`0000?ooooo0_l000000ooooooo0000
o`00000Jooooo`;o00000_ooool2o`0000[ooooo0_l00008ooooo`;o00000oooool5o`000004oooo
ool0003o0000ooooo`;o00004_ooool002Wooooo0_l0000Aooooo`;o00002_ooool3o`000003oooo
ool0003o000000cooooo0_l0000Mooooo`;o00002Oooool2o`00017ooooo0_l0000;ooooo`?o0000
0_ooool2o`0000Cooooo0_l0000Kooooo`;o000000?oooooo`000?l000004oooool2o`000004oooo
ool0003o0000ooooo`;o000000?oooooo`000?l000003oooool4o`0000Kooooo0_l00003ooooo`;o
00005oooool2o`000003ooooool0003o000000Gooooo0_l00008ooooo`;o00000_ooool2o`0000Ko
oooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l000001?oooooo0000o`000?l0000A
ooooo`00:Oooool00ol0003oooooooooo`0=ooooo`;o00003_ooool2o`000003ooooool0003o0000
00[ooooo0_l00005ooooo`;o00005oooool2o`0000[ooooo0_l0000Aooooo`;o00002?ooool2o`00
0004ooooool0003o0000o`0000;ooooo0_l00003ooooo`?o00000_ooool2o`0000Oooooo0_l0000=
ooooo`Co00005Oooool2o`000003ooooool0003o000000Cooooo0_l00008ooooo`;o00001Oooool2
o`0000Kooooo0_l0000Kooooo`;o000000Coooooo`000?l0003ooooo0_l0000?ooooo`;o00000_oo
ool2o`0000Kooooo0_l00003ooooo`;o00000_ooool3o`0000?ooooo0_l00004ooooo`;o00002ooo
ool002Wooooo00?o0000ooooooooool01oooool2o`000004ooooool0003o0000ooooo`;o00005ooo
ool2o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o00001Oooool2o`000003ooooool0
003o000000gooooo0_l0000>ooooo`;o00002?ooool2o`0000Kooooo0_l00005ooooo`;o00001Ooo
ool2o`0000Cooooo0_l00003ooooo`;o00001oooool2o`0000Kooooo0_l00002ooooo`;o000000?o
ooooo`000?l000000_l0000Looooo`;o00002_ooool2o`0000Wooooo0_l00002ooooo`;o00005_oo
ool2o`0000?ooooo0_l00006ooooo`;o00003?ooool6o`0000Oooooo1?l00005ooooo`?o00002Ooo
ool2o`0000_ooooo000Yooooo`03o`000?oooooooooo00Oooooo1Ol00003ooooo`;o00000oooool2
o`0000gooooo0_l000000ooooooo0000o`000007ooooo`;o00001?ooool3o`0000;ooooo0_l00000
0ooooooo0000o`000002o`0000Sooooo0_l00006ooooo`;o00000_ooool2o`0000Gooooo0_l00008
ooooo`;o00001?ooool4o`0000?ooooo0_l00007ooooo`;o000000?oooooo`000?l000000oooool2
o`0000kooooo0_l00002ooooo`Oo00002_ooool4o`0000_ooooo0_l00005ooooo`;o00002?ooool2
o`0000Kooooo0_l000000ooooooo0000o`000002o`0000Gooooo0_l00004ooooo`;o00003Oooool2
o`0000_ooooo0_l00007ooooo`;o00000oooool6o`0000?ooooo0_l00004ooooo`;o00007_ooool0
02Wooooo00Co0000ooooool0003o00002?ooool2o`0000Cooooo0_l00003ooooo`[o00001Oooool2
o`0000Cooooo0_l00007ooooo`;o000000Coooooo`000?l0003o00001oooool3o`0000Oooooo0_l0
0006ooooo`;o000000Coooooo`000?l0003o00001oooool3o`0000Kooooo0ol000001?oooooo0000
o`000?l00005ooooo`;o00002?ooool5o`0000;ooooo0_l00003ooooo`;o00001?ooool2o`0000?o
oooo0_l00004ooooo`;o000000?oooooo`000?l000002_ooool4o`0000_ooooo0_l00003ooooo`?o
00000oooool2o`0000Cooooo0_l00006ooooo`;o000000?oooooo`000?l000001oooool2o`0000Co
oooo0_l00004ooooo`;o00001oooool2o`0000Cooooo0_l00002ooooo`;o00002_ooool6o`0000So
oooo0ol0000Sooooo`00:Oooool4o`0001Gooooo2?l00007ooooo`;o00000_ooool2o`0000Oooooo
0_l0000<ooooo`?o00001oooool2o`0000?ooooo0_l00003ooooo`;o00000_ooool2o`0000Cooooo
0ol00003ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000?ooooo0_l0000;ooooo`;o
000000Coooooo`000?l0003o00001_ooool2o`0000;ooooo1?l0000Dooooo`?o00004_ooool2o`00
0004ooooool0003o0000o`0000?ooooo0_l00009ooooo`;o00000oooool2o`0001Cooooo0_l00003
ooooo`?o00000oooool2o`0000;ooooo0_l00002ooooo`;o00003?ooool4o`0000Wooooo0_l00004
ooooo`;o00007Oooool002Wooooo0_l00004ooooo`;o000000?oooooo`000?l000001Oooool2o`00
01Kooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo0ol0000>ooooo`;o00000_ooool2
o`0000?ooooo0_l00003ooooo`;o00001oooool3o`0000Wooooo0_l000000ooooooo0000o`000007
ooooo`;o00002?ooool4o`0000?ooooo0_l00008ooooo`Co00003oooool2o`0000?ooooo1Ol00002
ooooo`;o00001oooool2o`0000Gooooo0_l0000Booooo`Co000000?oooooo`000?l000002_ooool2
o`0000gooooo1?l00002ooooo`;o00000oooool2o`0000Wooooo0_l0000Booooo`;o00000oooool2
o`0000oooooo0_l0000<ooooo`00:Oooool00ol0003oooooooooo`02ooooo`?o000000?oooooo`00
0?l000001Oooool2o`0000Kooooo0_l00009ooooo`;o00002?ooool2o`000004ooooool0003o0000
ooooo`?o00004_ooool2o`0000;ooooo0_l00006ooooo`;o00001_ooool2o`0000Wooooo0_l00000
0ooooooo0000o`000004ooooo`;o00002oooool4o`0000Sooooo0_l00003ooooo`Co00003oooool2
o`0000?ooooo1_l000000ooooooo0000o`000007ooooo`;o00006oooool2o`0000cooooo0ol0000;
ooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o00002Oooool2o`0000cooooo0_l00004
ooooo`;o00000oooool2o`0000oooooo0_l0000<ooooo`00:Oooool00ol0003oooooooooo`04o`00
0003ooooool0003o000000_ooooo0_l000000ooooooo0000o`000009ooooo`;o00001Oooool2o`00
00oooooo0_l00006ooooo`;o00000_ooool2o`0000?ooooo0_l00006ooooo`;o00004?ooool3o`00
00Oooooo0_l00002ooooo`;o00002oooool2o`0000Kooooo0_l00005ooooo`;o00000oooool2o`00
017ooooo1?l00006ooooo`;o00001Oooool2o`0002Kooooo0_l0000<ooooo`?o00001Oooool4o`00
00Cooooo0_l000001?oooooo0000o`000?ooool2o`0000cooooo1?l000000ooooooo0000o`00000?
ooooo`;o00001Oooool2o`0000gooooo000Yooooo`03o`000?oooooooooo00;o00000oooool2o`00
00_ooooo0_l0000;ooooo`;o00001_ooool2o`0000oooooo0_l00006ooooo`Ko00003_ooool2o`00
00Cooooo0_l00007ooooo`;o00003?ooool2o`0000_ooooo0_l00005ooooo`;o000000?oooooo`00
0?l000002?ooool2o`0001Cooooo0_l00005ooooo`;o00001Oooool2o`0000gooooo0_l0000Doooo
o`;o00004?ooool2o`0000Kooooo0ol000001?oooooo0000o`000?ooool2o`000004ooooool0003o
0000ooooo`;o00000_ooool2o`0000Sooooo0_l00002ooooo`?o00001?ooool2o`000003ooooool0
003o000000Gooooo0ol00005ooooo`;o00003Oooool002Wooooo1?l00007ooooo`;o00005Oooool2
o`000003ooooool0003o000000?ooooo0_l0000Eooooo`;o00000_ooool2o`0000cooooo0_l00002
ooooo`Co00000_ooool2o`0000Cooooo0_l0000Dooooo`;o00002_ooool5o`000003ooooool0003o
0000013ooooo0_l0000<ooooo`;o00004oooool2o`0000Kooooo0_l00006ooooo`;o00002_ooool4
o`0000Gooooo0_l0000Aooooo`;o00000_ooool2o`0000_ooooo0_l0000<ooooo`;o00001Oooool2
o`000003ooooool0003o000000Gooooo0_l000000ooooooo0000o`00000Booooo`00:Oooool4o`00
00Oooooo0_l00004ooooo`;o00003_ooool2o`0000;ooooo0_l0000<ooooo`Go000000?oooooo`00
0?l000001_ooool2o`0000Gooooo0_l00009ooooo`;o00001?ooool2o`0000Sooooo0_l0000?oooo
o`;o000000?oooooo`000?l000000_l0000:ooooo`Co00003?ooool2o`0000Kooooo0_l000000ooo
oooo0000o`000008ooooo`;o00001?ooool2o`0000cooooo1?l00007ooooo`Ko000000?oooooo`00
0?l000002Oooool3o`0000Oooooo0_l0000;ooooo`;o00003Oooool2o`0002Oooooo0ol0000Boooo
o`00:Oooool2o`0000oooooo0_l00008ooooo`;o00001?ooool2o`00013ooooo1Ol000000ooooooo
0000o`000006ooooo`;o00001Oooool2o`0001kooooo0_l0000:ooooo`;o000000?oooooo`000?l0
00007?ooool2o`0000Wooooo0_l000000ooooooo0000o`000005ooooo`;o00001?ooool2o`0000co
oooo0ol00008ooooo`Ko00002_ooool4o`0000[ooooo0_l00009ooooo`;o00002Oooool2o`0000;o
oooo0_l00002ooooo`;o00003oooool4o`0000;ooooo0_l0000<ooooo`;o00004oooool002Wooooo
00?o0000ooooooooool02oooool2o`0000_ooooo1?l0000Pooooo`Co00003_ooool4o`0000oooooo
0_l00002ooooo`;o0000:?ooool2o`0000oooooo0_l00002ooooo`;o00008_ooool2o`0000Cooooo
0_l00006ooooo`;o00003?ooool2o`0000Gooooo0_l0000=ooooo`;o00001_ooool2o`0000oooooo
1?l00002ooooo`;o00004?ooool2o`0000oooooo000Yooooo`04o`000?ooooooooooooooo`;o0000
2?ooool3o`0000[ooooo1?l00005ooooo`;o00006?ooool3o`0000Sooooo0_l00006ooooo`Co0000
1?ooool2o`0000Oooooo1?l00009ooooo`;o00008Oooool2o`0001?ooooo0_l00008ooooo`;o0000
7_ooool2o`0001Kooooo0_l00003ooooo`;o0000?_ooool2o`0000oooooo000Yooooo`;o00000_oo
ool2o`0000Wooooo0_l00009ooooo`;o00002?ooool2o`0000Gooooo0_l0000@ooooo`?o00002Ooo
ool4o`0000cooooo0_l000000ooooooo0000o`000004ooooo`;o00002oooool2o`0000Cooooo0_l0
0003ooooo`;o00006_ooool2o`000003ooooool0003o000001Kooooo0_l00005ooooo`;o0000;ooo
ool2o`0000Wooooo0_l00019ooooo`00:Oooool00ol0003oooooooooo`04ooooo`;o00000oooool2
o`0000cooooo0_l0000?ooooo`;o00004?ooool2o`0000cooooo0_l0000?ooooo`Co00005Oooool2
o`0000?ooooo0_l00006ooooo`;o00002?ooool2o`0000Sooooo0_l000000ooooooo0000o`000003
ooooo`;o00006?ooool4o`0000_ooooo0_l00006ooooo`;o00008oooool2o`0004Wooooo0006oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`04ooooo`;o000000?oooooo`000?l000000_l0
001@ooooo`;o00008_ooool2o`0000Sooooo0_l0000@ooooo`;o00006_ooool2o`0000_ooooo0_l0
0006ooooo`;o0000>Oooool2o`0003?ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool01oooool2o`000?kooooo0_l0000cooooo`001_ooool01Ol@413ooooooooo
oooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`000?oooooo?Oooool000Kooooo00Go
0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooo
oooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o
^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooo
ocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7o
c<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003ooooo
ockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003ooooo
ockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooo
ooooool00oooool3o`000?oooooo?Oooool000kooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Ol0003o
oooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000kooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo000>oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEE
EOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolmooooo`001_ooool01Ol0003o
oooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00000>oooo
o`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOo
oooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool001oooooo1?l000000ol@413oooooooooo`03ooooo`03
o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo0ol0003oooooocgooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool001oooooo00?oEEEEofIVI_l00000oooooom7ooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .39222 Mdot
.02762 .40232 Mdot
.02952 .28183 Mdot
.03143 .33093 Mdot
.03333 .35619 Mdot
.03524 .39045 Mdot
.03714 .27451 Mdot
.03905 .434 Mdot
.04095 .37797 Mdot
.04286 .33766 Mdot
.04476 .3461 Mdot
.04667 .40874 Mdot
.04857 .41247 Mdot
.05048 .32641 Mdot
.05238 .35022 Mdot
.05429 .32924 Mdot
.05619 .37516 Mdot
.0581 .4131 Mdot
.06 .34745 Mdot
.0619 .42237 Mdot
.06381 .3977 Mdot
.06571 .39305 Mdot
.06762 .3705 Mdot
.06952 .4107 Mdot
.07143 .35998 Mdot
.07333 .36113 Mdot
.07524 .35192 Mdot
.07714 .3546 Mdot
.07905 .41721 Mdot
.08095 .39309 Mdot
.08286 .37189 Mdot
.08476 .39869 Mdot
.08667 .40806 Mdot
.08857 .36763 Mdot
.09048 .3846 Mdot
.09238 .3791 Mdot
.09429 .39485 Mdot
.09619 .35445 Mdot
.0981 .38752 Mdot
.1 .42503 Mdot
.1019 .39896 Mdot
.10381 .38015 Mdot
.10571 .38394 Mdot
.10762 .40188 Mdot
.10952 .39885 Mdot
.11143 .35745 Mdot
.11333 .34687 Mdot
.11524 .41321 Mdot
.11714 .37041 Mdot
.11905 .39616 Mdot
.12095 .40581 Mdot
.12286 .40805 Mdot
.12476 .33369 Mdot
.12667 .37816 Mdot
.12857 .38829 Mdot
.13048 .3885 Mdot
.13238 .42697 Mdot
.13429 .37889 Mdot
.13619 .40637 Mdot
.1381 .39834 Mdot
.14 .36275 Mdot
.1419 .38587 Mdot
.14381 .37325 Mdot
.14571 .29524 Mdot
.14762 .3591 Mdot
.14952 .40273 Mdot
.15143 .34191 Mdot
.15333 .3397 Mdot
.15524 .35022 Mdot
.15714 .40613 Mdot
.15905 .37814 Mdot
.16095 .2684 Mdot
.16286 .34544 Mdot
.16476 .33738 Mdot
.16667 .37284 Mdot
.16857 .27383 Mdot
.17048 .33299 Mdot
.17238 .36547 Mdot
.17429 .4108 Mdot
.17619 .36423 Mdot
.1781 .37428 Mdot
.18 .38779 Mdot
.1819 .33482 Mdot
.18381 .38289 Mdot
.18571 .42813 Mdot
.18762 .30338 Mdot
.18952 .35616 Mdot
.19143 .3633 Mdot
.19333 .37884 Mdot
.19524 .34102 Mdot
.19714 .34852 Mdot
.19905 .34121 Mdot
.20095 .29147 Mdot
.20286 .35967 Mdot
.20476 .30068 Mdot
.20667 .36543 Mdot
.20857 .32746 Mdot
.21048 .38062 Mdot
.21238 .33683 Mdot
.21429 .37577 Mdot
.21619 .38947 Mdot
.2181 .37557 Mdot
.22 .39052 Mdot
.2219 .4012 Mdot
.22381 .39851 Mdot
.22571 .36894 Mdot
.22762 .38158 Mdot
.22952 .34646 Mdot
.23143 .29026 Mdot
.23333 .40076 Mdot
.23524 .32765 Mdot
.23714 .31947 Mdot
.23905 .39377 Mdot
.24095 .41172 Mdot
.24286 .31788 Mdot
.24476 .26949 Mdot
.24667 .3662 Mdot
.24857 .42688 Mdot
.25048 .41967 Mdot
.25238 .36541 Mdot
.25429 .41024 Mdot
.25619 .40004 Mdot
.2581 .3679 Mdot
.26 .42138 Mdot
.2619 .40394 Mdot
.26381 .3359 Mdot
.26571 .40617 Mdot
.26762 .36802 Mdot
.26952 .37255 Mdot
.27143 .30278 Mdot
.27333 .3876 Mdot
.27524 .38566 Mdot
.27714 .39829 Mdot
.27905 .39395 Mdot
.28095 .38585 Mdot
.28286 .42009 Mdot
.28476 .42001 Mdot
.28667 .40997 Mdot
.28857 .3461 Mdot
.29048 .39275 Mdot
.29238 .36331 Mdot
.29429 .34031 Mdot
.29619 .30256 Mdot
.2981 .34667 Mdot
.3 .3763 Mdot
.3019 .4192 Mdot
.30381 .42756 Mdot
.30571 .31651 Mdot
.30762 .35685 Mdot
.30952 .364 Mdot
.31143 .4283 Mdot
.31333 .37321 Mdot
.31524 .34228 Mdot
.31714 .41315 Mdot
.31905 .26797 Mdot
.32095 .37964 Mdot
.32286 .40682 Mdot
.32476 .38849 Mdot
.32667 .41636 Mdot
.32857 .38544 Mdot
.33048 .41038 Mdot
.33238 .36503 Mdot
.33429 .41734 Mdot
.33619 .43627 Mdot
.3381 .37006 Mdot
.34 .36972 Mdot
.3419 .37744 Mdot
.34381 .42399 Mdot
.34571 .40294 Mdot
.34762 .3508 Mdot
.34952 .42197 Mdot
.35143 .37933 Mdot
.35333 .32866 Mdot
.35524 .35316 Mdot
.35714 .36193 Mdot
.35905 .35856 Mdot
.36095 .38744 Mdot
.36286 .36333 Mdot
.36476 .37721 Mdot
.36667 .29599 Mdot
.36857 .40656 Mdot
.37048 .42316 Mdot
.37238 .41878 Mdot
.37429 .32523 Mdot
.37619 .39981 Mdot
.3781 .30372 Mdot
.38 .36213 Mdot
.3819 .35479 Mdot
.38381 .41722 Mdot
.38571 .43264 Mdot
.38762 .38791 Mdot
.38952 .40018 Mdot
.39143 .42054 Mdot
.39333 .3035 Mdot
.39524 .36758 Mdot
.39714 .42866 Mdot
.39905 .4181 Mdot
.40095 .39578 Mdot
.40286 .36088 Mdot
.40476 .36797 Mdot
.40667 .38201 Mdot
.40857 .29601 Mdot
.41048 .29584 Mdot
.41238 .26866 Mdot
.41429 .36116 Mdot
.41619 .36179 Mdot
.4181 .37999 Mdot
.42 .31324 Mdot
.4219 .38894 Mdot
.42381 .29939 Mdot
.42571 .28097 Mdot
.42762 .3412 Mdot
.42952 .41067 Mdot
.43143 .36613 Mdot
.43333 .40194 Mdot
.43524 .3366 Mdot
.43714 .37535 Mdot
.43905 .3644 Mdot
.44095 .43242 Mdot
.44286 .28164 Mdot
.44476 .3886 Mdot
.44667 .4302 Mdot
.44857 .36541 Mdot
.45048 .38389 Mdot
.45238 .4058 Mdot
.45429 .36594 Mdot
.45619 .34234 Mdot
.4581 .35676 Mdot
.46 .40598 Mdot
.4619 .31908 Mdot
.46381 .3528 Mdot
.46571 .41211 Mdot
.46762 .324 Mdot
.46952 .27084 Mdot
.47143 .33251 Mdot
.47333 .37511 Mdot
.47524 .34932 Mdot
.47714 .39218 Mdot
.47905 .35347 Mdot
.48095 .40214 Mdot
.48286 .38896 Mdot
.48476 .3876 Mdot
.48667 .37738 Mdot
.48857 .39165 Mdot
.49048 .40886 Mdot
.49238 .37818 Mdot
.49429 .41329 Mdot
.49619 .31404 Mdot
.4981 .38446 Mdot
.5 .36743 Mdot
.5019 .37769 Mdot
.50381 .38248 Mdot
.50571 .41155 Mdot
.50762 .27113 Mdot
.50952 .31819 Mdot
.51143 .37564 Mdot
.51333 .36864 Mdot
.51524 .35323 Mdot
.51714 .38925 Mdot
.51905 .27354 Mdot
.52095 .41568 Mdot
.52286 .41165 Mdot
.52476 .37404 Mdot
.52667 .34902 Mdot
.52857 .36977 Mdot
.53048 .29327 Mdot
.53238 .37618 Mdot
.53429 .38563 Mdot
.53619 .34908 Mdot
.5381 .37374 Mdot
.54 .37481 Mdot
.5419 .37047 Mdot
.54381 .39726 Mdot
.54571 .38939 Mdot
.54762 .32925 Mdot
.54952 .37257 Mdot
.55143 .41163 Mdot
.55333 .31815 Mdot
.55524 .34476 Mdot
.55714 .40242 Mdot
.55905 .33251 Mdot
.56095 .38621 Mdot
.56286 .41036 Mdot
.56476 .27023 Mdot
.56667 .34297 Mdot
.56857 .3792 Mdot
.57048 .39783 Mdot
.57238 .34463 Mdot
.57429 .2693 Mdot
.57619 .3576 Mdot
.5781 .41698 Mdot
.58 .36403 Mdot
.5819 .36938 Mdot
.58381 .34753 Mdot
.58571 .39349 Mdot
.58762 .3631 Mdot
.58952 .37519 Mdot
.59143 .27019 Mdot
.59333 .41536 Mdot
.59524 .34648 Mdot
.59714 .41764 Mdot
.59905 .3523 Mdot
.60095 .31654 Mdot
.60286 .37315 Mdot
.60476 .39083 Mdot
.60667 .39091 Mdot
.60857 .40741 Mdot
.61048 .38143 Mdot
.61238 .34531 Mdot
.61429 .39421 Mdot
.61619 .36858 Mdot
.6181 .29328 Mdot
.62 .4066 Mdot
.6219 .37691 Mdot
.62381 .40624 Mdot
.62571 .42528 Mdot
.62762 .27845 Mdot
.62952 .387 Mdot
.63143 .37327 Mdot
.63333 .35887 Mdot
.63524 .279 Mdot
.63714 .41352 Mdot
.63905 .35392 Mdot
.64095 .37319 Mdot
.64286 .3342 Mdot
.64476 .39445 Mdot
.64667 .3848 Mdot
.64857 .37326 Mdot
.65048 .34983 Mdot
.65238 .27413 Mdot
.65429 .27074 Mdot
.65619 .38121 Mdot
.6581 .43191 Mdot
.66 .36249 Mdot
.6619 .29271 Mdot
.66381 .4056 Mdot
.66571 .29507 Mdot
.66762 .2696 Mdot
.66952 .40582 Mdot
.67143 .39167 Mdot
.67333 .37046 Mdot
.67524 .36614 Mdot
.67714 .36112 Mdot
.67905 .35295 Mdot
.68095 .36985 Mdot
.68286 .37761 Mdot
.68476 .30739 Mdot
.68667 .39404 Mdot
.68857 .35148 Mdot
.69048 .40708 Mdot
.69238 .37548 Mdot
.69429 .28936 Mdot
.69619 .36178 Mdot
.6981 .34646 Mdot
.7 .41644 Mdot
.7019 .42323 Mdot
.70381 .38438 Mdot
.70571 .37158 Mdot
.70762 .38297 Mdot
.70952 .38565 Mdot
.71143 .37617 Mdot
.71333 .414 Mdot
.71524 .39609 Mdot
.71714 .40932 Mdot
.71905 .39423 Mdot
.72095 .41197 Mdot
.72286 .41941 Mdot
.72476 .27058 Mdot
.72667 .37455 Mdot
.72857 .35687 Mdot
.73048 .42231 Mdot
.73238 .27032 Mdot
.73429 .37687 Mdot
.73619 .36572 Mdot
.7381 .39279 Mdot
.74 .38971 Mdot
.7419 .37825 Mdot
.74381 .4014 Mdot
.74571 .40088 Mdot
.74762 .35993 Mdot
.74952 .36793 Mdot
.75143 .42594 Mdot
.75333 .38263 Mdot
.75524 .3638 Mdot
.75714 .32675 Mdot
.75905 .36002 Mdot
.76095 .38767 Mdot
.76286 .27451 Mdot
.76476 .36756 Mdot
.76667 .37743 Mdot
.76857 .27073 Mdot
.77048 .42539 Mdot
.77238 .4059 Mdot
.77429 .26942 Mdot
.77619 .33964 Mdot
.7781 .36524 Mdot
.78 .35054 Mdot
.7819 .41678 Mdot
.78381 .41572 Mdot
.78571 .35631 Mdot
.78762 .41909 Mdot
.78952 .37671 Mdot
.79143 .32992 Mdot
.79333 .38086 Mdot
.79524 .358 Mdot
.79714 .35566 Mdot
.79905 .27375 Mdot
.80095 .42636 Mdot
.80286 .40728 Mdot
.80476 .3518 Mdot
.80667 .30965 Mdot
.80857 .32579 Mdot
.81048 .31058 Mdot
.81238 .41682 Mdot
.81429 .3544 Mdot
.81619 .38136 Mdot
.8181 .31966 Mdot
.82 .34554 Mdot
.8219 .28874 Mdot
.82381 .35645 Mdot
.82571 .36705 Mdot
.82762 .34265 Mdot
.82952 .31325 Mdot
.83143 .41415 Mdot
.83333 .39608 Mdot
.83524 .28637 Mdot
.83714 .38539 Mdot
.83905 .38165 Mdot
.84095 .36863 Mdot
.84286 .36578 Mdot
.84476 .35161 Mdot
.84667 .38166 Mdot
.84857 .38251 Mdot
.85048 .39894 Mdot
.85238 .32208 Mdot
.85429 .40299 Mdot
.85619 .30209 Mdot
.8581 .35531 Mdot
.86 .35196 Mdot
.8619 .34958 Mdot
.86381 .36699 Mdot
.86571 .34649 Mdot
.86762 .31411 Mdot
.86952 .27074 Mdot
.87143 .35892 Mdot
.87333 .37796 Mdot
.87524 .36784 Mdot
.87714 .35622 Mdot
.87905 .29705 Mdot
.88095 .37501 Mdot
.88286 .38346 Mdot
.88476 .28744 Mdot
.88667 .29 Mdot
.88857 .32473 Mdot
.89048 .43201 Mdot
.89238 .27078 Mdot
.89429 .41498 Mdot
.89619 .40232 Mdot
.8981 .39445 Mdot
.9 .40321 Mdot
.9019 .36591 Mdot
.90381 .37813 Mdot
.90571 .3928 Mdot
.90762 .33897 Mdot
.90952 .43264 Mdot
.91143 .41762 Mdot
.91333 .34913 Mdot
.91524 .41927 Mdot
.91714 .36866 Mdot
.91905 .36696 Mdot
.92095 .40899 Mdot
.92286 .3925 Mdot
.92476 .35111 Mdot
.92667 .36274 Mdot
.92857 .37281 Mdot
.93048 .41153 Mdot
.93238 .3776 Mdot
.93429 .27804 Mdot
.93619 .37699 Mdot
.9381 .36799 Mdot
.94 .26724 Mdot
.9419 .33966 Mdot
.94381 .38 Mdot
.94571 .38946 Mdot
.94762 .28041 Mdot
.94952 .36884 Mdot
.95143 .40201 Mdot
.95333 .35152 Mdot
.95524 .38378 Mdot
.95714 .33605 Mdot
.95905 .35567 Mdot
.96095 .27085 Mdot
.96286 .3352 Mdot
.96476 .27487 Mdot
.96667 .40443 Mdot
.96857 .36277 Mdot
.97048 .37605 Mdot
.97238 .35052 Mdot
.97429 .40874 Mdot
.97619 .41535 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooocgooooo0006
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol0003oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_oo
ool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o
0000oooooolnooooo`00:Oooool00ol0003oooooooooo`1Kooooo`;o0000a_ooool2o`0001Oooooo
000Yooooo`03o`000?oooooooooo02Sooooo0_l00006ooooo`Co000000So410@ooooooooooook^k^
oc8b<_l0003o<S8bonk^kP?ooooo00Cok^k^oc8b<_l0003o<S8b0_l0000Fooooo`;o00004?ooool5
o`0000?ooooo00Cok^k^oc8b<_l0003o<S8b0_l00002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2_ooool2o`0000[ooooo0_l0000@ooooo`Go00000oooool01Oo^k^ko0000o`000?lb<S;ok^k^00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`;o00000_ooool2o`00017ooooo1?l00007oooo
o`;o000000?o410@o`000?l000000_l000001?lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h04?ooool2o`0000Kooooo0_l0000=ooooo`;o000000GoA4A4o`000?l0003o<S8b
omgMg@02o`000005onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo000Yooooo`04o`000?ooooooooooooooo`;o00009Oooool2o`000003ooooool0003o0000
00Gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00CoMgMg
oiRHV?ooooooV9RH0_l0000Xooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01?mgMgOoV9RH
oooooonHV9P2o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0:ooooo`;o00002_ooool2o`00
00;ooooo0_l0000<ooooo`;o000000?oooooo`000?l000000oooool01OmgMgOo0000o`000?nHV9So
MgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`?o00000_ooool2o`00017ooooo1?l0
0008ooooo`Ko000000CoV9RHoooooonHV9SoMgMg0_ooool2o`000004oiRHV?ooooooV9RHogMgMa3o
oooo0_l00006ooooo`;o00004_ooool02OmgMgOo<S8bo`000?l0003oMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wooooo00Co0000oooooooooooooooo
0_l0000Xooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@02[ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@
413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@400Jooooo`;o00004?oo
ool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo00Gooooo0_l0000Oooooo`Go00000oooool01Ol@413ooooooooooooooooo410@
00;ooooo0_l00003ooooo`03oa0@4?oooooooooo02_ooooo00Co0000ooooool0003o00000oooool0
1Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool00Oooool002Wooooo0_l0000c
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool00000:oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000002_ooooo00?oZJVYoa0@4?ooool00_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Co0000oooooooooooooooo0_l000000ooooooo0000o`00
000Tooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000009Oooool2o`0000;ooooo0_l000001?ooooooMgMgoc8b<_ooool2
o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo007ooooo000Y
ooooo`?o0000<_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000002cooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooo
oooooooooooo000000?ooooo0_l00002ooooo`04o`000?oooooo0000o`0002Oooooo00?o410@o`00
0?nj^[X00oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooooooo0_l0
00000ooooooo0000o`00000Tooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000009Oooool2o`0000;ooooo0ol000001Olb
<S;oc<c<oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo007ooooo000Yooooo`?o0000<_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41000oooool01Ol@413ooooooooooooooooo410@02gooooo00Go0000oooooooooooo
oooooa0@4003ooooo`04oa0@4?ooooooooooooooo`;o00000_ooool01?l@413oooooo`000?l0000X
ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oo
ooooooooooooool@4100:Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@00Gooooo0_l0000Rooooo`03o`000?oooooooooo
00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool002Wooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg02Wooooo00Go0000okZj^_oooooo
V9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg02Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg01Gooooo0_l0000Booooo`03onk^k_m4A4Co000000Co
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`06ogMgMonHV9SooooooiRHV?mgMgOooooo0_l0
0002ooooo`;o00003_ooool3o`00017ooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool00ol0003ooooo
ooooo`0`ooooo`03oeEEEOmVIVKo000000;ooooo0_l000001Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo0ol000000olb<S;ok^k^ooooo`0Xooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Mooooo`;o00002Ooo
ool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02_ooool2o`0000Wooooo0_l0000Cooooo`03ogMgMol0003ooooo
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`06onk^k_lb<S;o0000oc8b<_o^k^kooooo
0_l0000Booooo`?o00004Oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool002Wooooo0_l0000Tooooo`;o00004?ooool2o`0000So
oooo0_l0000Zooooo`;o00002oooool3o`0002Cooooo0_l0000Jooooo`;o00003?ooool4o`0006oo
oooo000Yooooo`03o`000?oooooooooo02?ooooo0_l00016ooooo`;o00002oooool3o`0000;ooooo
0_l0000looooo`;o00003_ooool2o`0004;ooooo0_l0000[ooooo`00:Oooool00ol0003ooooooooo
o`0fooooo`;o00007?ooool2o`0002Oooooo0_l00029ooooo`;o00001Oooool2o`0002_ooooo000Y
ooooo`03o`000?oooooooooo037ooooo0_l00003ooooo`;o00005?ooool2o`0000Kooooo0_l0000H
ooooo`;o00000oooool2o`0009?ooooo0_l0000booooo`00:Oooool00ol0003oooooooooo`0aoooo
o`;o00006Oooool2o`00023ooooo0_l00003ooooo`;o0000G?ooool2o`0006Wooooo000Qoooooooo
0000A?l00004ooooo`00:Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`04o`000?ooooooooooooooo`;o
00001_ooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooooooo`;o00001_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo0ol00003ooooo`?o00002_ooool3o`00
00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00[ooooo000Yooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool01_ooool2o`0001;o
oooo0_l0000Oooooo`04o`000?ooooooooooooooo`;o00005_ooool2o`00017ooooo0_l0000<oooo
o`?o0000>_ooool00ol0003oooooooooo`0:ooooo`;o00002oooool2o`00027ooooo00?o0000oooo
ooooool02_ooool002Wooooo00?o0000ooooooooool0@Oooool4o`0001;ooooo0_l0000`ooooo`;o
00003Oooool2o`0000gooooo0_l0000=ooooo`;o0000A?ooool2o`0003kooooo000Yooooo`03o`00
0?oooooooooo047ooooo0_l00016ooooo`Co00002oooool2o`0006;ooooo0_l00009ooooo`;o0000
<oooool002Wooooo0_l00006ooooo`;o0000<Oooool2o`0003?ooooo0_l0000Looooo`;o0000Fooo
ool2o`0000oooooo0_l0000<ooooo`;o00002Oooool2o`0002Sooooo000Yooooo`03o`000?oooooo
oooo00Gooooo0ol0000`ooooo`;o00001_ooool2o`0002Cooooo0_l00005ooooo`;o0000=_ooool2
o`00047ooooo0_l00009ooooo`;o00001?ooool2o`0001Oooooo0_l0000Xooooo`00:Oooool01?l0
003oooooo`000?l00005ooooo`;o00005Oooool2o`0000cooooo0_l0000Cooooo`;o00009?ooool2
o`0002Cooooo0_l0000Gooooo`;o000000?oooooo`000?l00000BOooool2o`0004Oooooo000Yoooo
o`04o`000?oooooo0000o`0001cooooo0_l0000<ooooo`;o00000_ooool2o`0001Sooooo0_l0000f
ooooo`;o00002Oooool2o`0001[ooooo0_l0000Iooooo`;o0000Hoooool4o`00013ooooo000Yoooo
o`03o`000?oooooooooo00;ooooo0_l0000Rooooo`;o00000_ooool2o`0000?ooooo0_l00008oooo
o`;o00003_ooool2o`0003Kooooo0_l00010ooooo`;o0000:Oooool2o`0002Sooooo0_l00009oooo
o`;o00000oooool4o`00013ooooo000Yooooo`;o00000oooool2o`00027ooooo0ol00002ooooo`;o
00001oooool4o`0000;ooooo0_l0000Hooooo`;o00001Oooool2o`0002;ooooo0_l00007ooooo`;o
00008_ooool2o`00047ooooo0_l0000?ooooo`;o00005oooool2o`0000Wooooo0_l0000Gooooo`00
:Oooool00ol0003oooooooooo`03ooooo`;o00008?ooool2o`0000;ooooo0_l00008ooooo`Co0000
6_ooool4o`0000Gooooo0_l0000Rooooo`;o00001oooool2o`0001kooooo0_l00002ooooo`Co0000
2oooool2o`00043ooooo0_l000000ooooooo0000o`00000kooooo`00:Oooool00ol0003ooooooooo
o`03ooooo`;o00000oooool2o`0000oooooo0_l0000>ooooo`;o00002Oooool2o`0000Sooooo0_l0
000Aooooo`;o000000?oooooo`000?l00000B?ooool2o`000003ooooool0003o000000Cooooo0_l0
0004ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l0000Iooooo`;o00009Ooo
ool2o`0000gooooo0_l0000=ooooo`;o00008?ooool002Wooooo00?o0000ooooooooool01Oooool2
o`000003ooooool0003o000000?ooooo0_l0000:ooooo`;o00003?ooool2o`0000_ooooo0_l00008
ooooo`;o00005?ooool2o`0000kooooo0_l0000Wooooo`;o00003oooool2o`000003ooooool0003o
000000gooooo0_l00002ooooo`?o00003oooool2o`0000[ooooo0_l000000ooooooo0000o`00000H
ooooo`;o00001_ooool2o`0000_ooooo0_l00003ooooo`Co00003Oooool2o`0000;ooooo0_l00007
ooooo`;o00001?ooool2o`0000gooooo000Yooooo`03o`000?oooooooooo00Gooooo0_l00006oooo
o`;o00001Oooool2o`00017ooooo0_l0000kooooo`;o000000?oooooo`000?l000001_ooool2o`00
01Wooooo0_l000000ooooooo0000o`000002o`0000Wooooo0_l0000Iooooo`;o00002oooool2o`00
00;ooooo0_l00007ooooo`;o000000?oooooo`000?l000006oooool2o`0000Kooooo0_l000000ooo
oooo0000o`000008ooooo`;o00000oooool3o`0001;ooooo0_l00007ooooo`;o00001?ooool2o`00
00gooooo000Yooooo`Co00003?ooool2o`0000Gooooo0_l00002ooooo`;o00006?ooool2o`0002Co
oooo0_l0000=ooooo`?o00001Oooool2o`0001Oooooo1?l00003ooooo`;o00002Oooool2o`0001;o
oooo0_l0000Booooo`;o00002oooool2o`0000kooooo0_l0000@ooooo`;o000000Coooooo`000?l0
003o00000oooool2o`0000;ooooo0_l00009ooooo`;o00001?ooool2o`0001Sooooo0_l0000Aoooo
o`00:Oooool01?l0003oooooo`000?l0000;ooooo`;o00002_ooool2o`0000[ooooo0_l0000<oooo
o`;o00000_ooool2o`00023ooooo0_l0000>ooooo`;o00003?ooool2o`0000;ooooo0_l0000<oooo
o`;o00009?ooool2o`00013ooooo0_l0000<ooooo`;o00003oooool2o`0000Cooooo0_l00002oooo
o`;o00001_ooool2o`000004ooooool0003o0000o`0000Oooooo0_l0000=ooooo`Co00006?ooool2
o`00017ooooo000Yooooo`03o`000?oooooooooo00cooooo0_l0000Dooooo`Co00001oooool2o`00
00?ooooo0_l00002ooooo`;o00006oooool2o`0000?ooooo0_l0000=ooooo`Co00001?ooool2o`00
00Gooooo0_l00002ooooo`;o00001_ooool2o`0002_ooooo0_l000000ooooooo0000o`00000<oooo
o`;o00001oooool2o`0000?ooooo0_l00004ooooo`;o00003oooool6o`0002;ooooo0_l0000@oooo
o`;o00002oooool2o`0000kooooo000Yooooo`03o`000?oooooooooo017ooooo0_l0000?ooooo`;o
00002?ooool3o`0000?ooooo0_l00003ooooo`;o00002oooool6o`0000Wooooo0_l00003ooooo`;o
00001Oooool2o`0000Kooooo1?l00004ooooo`;o00000oooool2o`0000Cooooo0_l00003ooooo`;o
000000Coooooo`000?l0003ooooo1?l0000<ooooo`;o00006?ooool2o`000003ooooool0003o0000
01Gooooo0_l00003ooooo`;o00001?ooool2o`0000_ooooo0_l00004ooooo`;o00000_ooool2o`00
00;ooooo0_l0000=ooooo`;o00001?ooool2o`0000Cooooo0_l00002ooooo`;o00001oooool2o`00
00?ooooo0_l000000ooooooo0000o`00000;ooooo`;o00003_ooool002Wooooo00?o0000oooooooo
ool02_ooool2o`0000Gooooo0_l00007ooooo`;o00004?ooool2o`0000Wooooo0_l00004ooooo`;o
00001Oooool6o`000003ooooool0003o000001;ooooo1Ol0000@ooooo`;o000000?oooooo`000?l0
00001_ooool2o`0000Cooooo1?l0000<ooooo`;o00000oooool2o`0000?ooooo0_l00002ooooo`;o
00002oooool2o`0000Wooooo0_l0000@ooooo`Go00003oooool2o`0000?ooooo0_l00003ooooo`;o
00000_ooool2o`0000gooooo0_l00003ooooo`?o00001?ooool2o`0000;ooooo0_l00007ooooo`;o
00000oooool2o`0000Cooooo0_l00002ooooo`;o00005?ooool002Wooooo0_l0000;ooooo`;o0000
0oooool2o`0000Wooooo0_l00007ooooo`;o00001Oooool2o`00017ooooo0_l0000<ooooo`;o0000
3?ooool2o`0000Kooooo0ol0000Cooooo`;o00008Oooool2o`000003ooooool0003o000000;o0000
00?oooooo`000?l000000ol00009ooooo`;o00001?ooool2o`0000?ooooo0_l00003ooooo`;o0000
00?oooooo`000?l000000_l00006ooooo`;o000000?oooooo`000?l000001_ooool2o`0000cooooo
0_l0000Kooooo`;o00005oooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0001Co
oooo000Yooooo`03o`000?oooooooooo00Oooooo0_l00006ooooo`;o00004_ooool2o`0000Gooooo
0_l00002ooooo`;o00002_ooool3o`0000kooooo0_l00008ooooo`;o00000_ooool2o`0000oooooo
0_l0000Eooooo`;o00002_ooool2o`0000[ooooo0_l00002ooooo`;o000000?oooooo`000?l00000
0_l000000ooooooo0000o`00000;ooooo`;o00000_ooool2o`0000Gooooo0_l000001?oooooo0000
o`000?ooool4o`0000cooooo0_l00003ooooo`?o00000oooool2o`000003ooooool0003o000000oo
oooo0_l0000Looooo`;o00003Oooool2o`000003ooooool0003o000000Wooooo0_l0000=ooooo`00
1_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool00_ooool2o`0000?ooooo0_l00009oooo
o`;o00000_ooool2o`0000Gooooo0_l000000ooooooo0000o`000006ooooo`;o00001?ooool2o`00
00?ooooo0_l00005ooooo`?o00006?ooool2o`0000Gooooo0_l00005ooooo`;o000000?oooooo`00
0?l000000_ooool2o`0000oooooo0_l00004ooooo`;o00002_ooool2o`0000;ooooo1?l000001?oo
oooo0000o`000?ooool2o`0000Gooooo1?l00007ooooo`;o00001Oooool2o`0000Wooooo0_l0000A
ooooo`;o000000?oooooo`000?l000001?ooool2o`0000?ooooo0_l000000ooooooo0000o`000002
o`0000Kooooo0_l00005ooooo`;o00006Oooool2o`000003ooooool0003o000000Gooooo0_l00007
ooooo`Ko00001oooool2o`0000gooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool00_ooool2o`0000kooooo0_l00002ooooo`;o00001Oooool2o`000003ooooool0
003o000000Kooooo0_l00006ooooo`;o000000?oooooo`000?l000000oooool2o`0000Cooooo0_l0
000Looooo`;o00001Oooool2o`000003ooooool0003o000000oooooo0_l00002ooooo`;o00005?oo
ool4o`000004ooooool0003o0000o`0001;ooooo0_l0000<ooooo`;o00003Oooool2o`0000Kooooo
0_l00006ooooo`;o00002Oooool2o`0000;ooooo0_l00002ooooo`;o00001oooool2o`0000Gooooo
0_l00005ooooo`;o000000?oooooo`000?l000001_ooool2o`000003ooooool0003o000000Gooooo
0_l00007ooooo`;o00000_ooool2o`0001Kooooo0006ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
4_ooool2o`0000?ooooo0_l00009ooooo`;o00003?ooool2o`0000Kooooo0_l00004ooooo`;o0000
3Oooool4o`0000gooooo0_l0000Gooooo`;o00003?ooool2o`0000kooooo1?l00007ooooo`;o0000
1oooool2o`0000kooooo0_l0000:ooooo`;o000000?oooooo`000?l000003Oooool4o`0000cooooo
0_l0000;ooooo`;o00001Oooool2o`0000Gooooo0_l000000ooooooo0000o`000009ooooo`;o0000
5_ooool2o`0001;ooooo0006ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Q
onk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Booooo`Co000000?oooooo`000?l00000
1Oooool3o`000003ooooool0003o000000[ooooo0_l0000:ooooo`;o00004Oooool4o`0000cooooo
0ol00009ooooo`;o00001_ooool2o`0000Wooooo0_l00006ooooo`?o00002Oooool2o`0000?ooooo
0_l00004ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00005?ooool2o`0000Cooooo
0_l0000@ooooo`Co00003_ooool2o`0001Oooooo0_l0000Qooooo`;o000000?oooooo`000?l00000
4_ooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`;o000000?oooooo`000?l000004_ooool2o`0000So
oooo0ol0000=ooooo`;o00002_ooool3o`00013ooooo0_l00003ooooo`;o00002Oooool2o`0000[o
oooo0_l00006ooooo`;o00002Oooool2o`0000Kooooo0_l00008ooooo`Ko00001oooool2o`0000Oo
oooo0_l0000Aooooo`?o00001Oooool2o`0000cooooo0_l0000Cooooo`?o00001?ooool2o`0003;o
oooo0_l00006ooooo`;o00005Oooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool2o`000003ooooool0003o000000So
oooo0_l00003ooooo`;o00000_ooool2o`0002Kooooo0_l00004ooooo`;o00002oooool2o`0000;o
oooo0_l0000Rooooo`;o00005_ooool2o`0000;ooooo0_l0000Mooooo`;o00001?ooool5o`0000So
oooo0_l00007ooooo`;o00000_ooool2o`0000Wooooo0_l00004ooooo`?o0000<?ooool2o`000003
ooooool0003o000000?ooooo0_l0000Mooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02Oooool3o`0000?ooooo0ol000000ooooooo0000o`000002o`000004ooooool0003o0000
ooooo`;o00001?ooool2o`0001[ooooo0_l00002ooooo`;o00002oooool2o`0002Kooooo0_l0000[
ooooo`;o00001oooool2o`0000?ooooo0_l00007ooooo`;o00002?ooool2o`0000_ooooo0_l00008
ooooo`?o00008oooool2o`0000?ooooo0_l0000=ooooo`;o000000?oooooo`000?l000008_ooool0
00Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?oo
ool4o`0000Kooooo00?o0000ooooooooool02Oooool2o`0000Gooooo0_l00003ooooo`Go000000?o
ooooo`000?l000001?ooool2o`0001Wooooo0ol000000ooooooo0000o`000005ooooo`;o00001Ooo
ool2o`0001kooooo0_l00002ooooo`;o00003?ooool2o`00027ooooo0_l00007ooooo`;o0000;Ooo
ool2o`0000Oooooo0_l0000Kooooo`;o00000oooool2o`0001oooooo0_l0000Cooooo`00:Oooool2
o`0001Sooooo0_l0000<ooooo`;o00005Oooool2o`0000;ooooo0_l00005ooooo`Co00006Oooool2
o`0000Sooooo0_l00002ooooo`;o00003?ooool2o`0000gooooo0_l0000Gooooo`;o0000>_ooool2
o`00027ooooo0_l0000<ooooo`?o00003oooool2o`0000;ooooo0_l0000?ooooo`00:Oooool2o`00
017ooooo0_l0000:ooooo`;o00000_ooool2o`0000?ooooo1?l0000Pooooo`?o00004?ooool2o`00
00Kooooo0_l00005ooooo`;o00006Oooool2o`000003ooooool0003o000000Cooooo0_l0000Goooo
o`;o00003_ooool2o`0000;ooooo0ol0000;ooooo`Co00001Oooool2o`0001Sooooo0_l00008oooo
o`;o00003_ooool2o`0000cooooo0ol0000Cooooo`;o00003oooool002Wooooo00?o0000oooooooo
ool01?ooool2o`0000Gooooo0_l00003ooooo`;o00002_ooool2o`0000;ooooo0_l00005ooooo`;o
00001?ooool2o`0001Oooooo0_l00002ooooo`;o00001Oooool2o`0000Wooooo0_l000000ooooooo
0000o`00000:ooooo`;o00004_ooool2o`0000Gooooo0_l000000ooooooo0000o`000007ooooo`;o
00005_ooool2o`0000cooooo0_l00002ooooo`?o00002oooool4o`0000Gooooo0_l00006ooooo`;o
00004?ooool2o`0000Sooooo0_l0000Tooooo`;o00003oooool2o`0000cooooo000Yooooo`03o`00
0?oooooooooo00Cooooo0_l000000ooooooo0000o`000002ooooo`;o00003Oooool2o`00017ooooo
0_l0000Cooooo`;o00000_ooool2o`0000Wooooo0_l00008ooooo`;o00000_ooool2o`0001kooooo
0_l00009ooooo`;o00001_ooool4o`000003ooooool0003o000000Cooooo0_l00007ooooo`;o0000
0_ooool2o`0001Gooooo0_l0000Gooooo`Co00008_ooool2o`0001_ooooo0_l000000ooooooo0000
o`00000<ooooo`;o00003?ooool002Wooooo00?o0000ooooooooool01?ooool2o`000003ooooool0
003o000000Gooooo0_l0000:ooooo`;o00009_ooool2o`0001Oooooo0_l000000ooooooo0000o`00
0002o`0000kooooo0_l0000Hooooo`;o00002?ooool2o`000003ooooool0003o000000?ooooo0ol0
0007ooooo`;o00001_ooool2o`0000?ooooo1?l0000:ooooo`;o00004oooool2o`0000;ooooo1?l0
000Booooo`?o00001oooool2o`0000Cooooo0_l0000Booooo`;o00001?ooool2o`0000Cooooo0_l0
000=ooooo`;o00002oooool002Wooooo0_l0000?ooooo`;o0000=Oooool2o`0000Wooooo0_l00004
ooooo`;o00001_ooool4o`0000[ooooo0_l00002ooooo`Co000000?oooooo`000?l000009Oooool2
o`00013ooooo0_l00003ooooo`Co00007oooool2o`0000Gooooo0_l0000Aooooo`Co00001_ooool2
o`0001Sooooo0_l00004ooooo`?o00004_ooool2o`0000_ooooo000Yooooo`03o`000?oooooooooo
00Wooooo0_l0000jooooo`;o000000?oooooo`000?l000001_ooool2o`0000Cooooo0_l0000=oooo
o`;o00001Oooool2o`0000Cooooo0_l000000ooooooo0000o`00001Oooooo`;o00001Oooool4o`00
017ooooo0_l0000Wooooo`;o00007oooool002Wooooo00?o0000ooooooooool02Oooool2o`0000[o
oooo0_l00008ooooo`;o00009?ooool2o`000003ooooool0003o000001Wooooo1?l00005ooooo`;o
0000D?ooool2o`0001Kooooo0_l00007ooooo`;o00001Oooool2o`0000Cooooo0_l00008ooooo`;o
0000A?ooool002Wooooo00?o0000ooooooooool05Oooool2o`0000Sooooo0_l0000?ooooo`;o0000
4oooool2o`0000oooooo0_l000000ooooooo0000o`000008ooooo`;o00003oooool2o`0004Sooooo
0_l0000Vooooo`;o00001?ooool2o`0000Sooooo0_l00014ooooo`00:Oooool00ol0003ooooooooo
o`0`ooooo`;o00009?ooool2o`000003ooooool0003o000001Kooooo0_l000000ooooooo0000o`00
000<ooooo`Co0000@_ooool2o`0004Wooooo0_l00004ooooo`;o00008Oooool002Wooooo0_l00002
ooooo`;o0000G_ooool2o`0000kooooo0_l0000?ooooo`Co0000@_ooool2o`0004Wooooo0_l00004
ooooo`;o00008Oooool002Wooooo00Co0000oooooooooooooooo0_l0001Nooooo`;o0000fOooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooo
oolmooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Ol@413ooooooooooooo
oooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000kooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooo
oolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`003_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo
0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooo
oooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000oooo
oolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_oo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go0000
ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooo
oa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooo
oooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgo
oooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`;o
0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o
0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool001oooooo1?l00000
0ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Go
oooo0ol0003oooooocgooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool001oooooo00?oEEEEofIVI_l00000oooooom7ooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .39361 Mdot
.02762 .39571 Mdot
.02952 .31046 Mdot
.03143 .27889 Mdot
.03333 .30471 Mdot
.03524 .3802 Mdot
.03714 .28348 Mdot
.03905 .45044 Mdot
.04095 .43117 Mdot
.04286 .28185 Mdot
.04476 .29834 Mdot
.04667 .44865 Mdot
.04857 .3995 Mdot
.05048 .26403 Mdot
.05238 .42372 Mdot
.05429 .27248 Mdot
.05619 .36878 Mdot
.0581 .39943 Mdot
.06 .29054 Mdot
.0619 .41836 Mdot
.06381 .41076 Mdot
.06571 .40533 Mdot
.06762 .40516 Mdot
.06952 .405 Mdot
.07143 .43075 Mdot
.07333 .30473 Mdot
.07524 .32544 Mdot
.07714 .31477 Mdot
.07905 .42355 Mdot
.08095 .40215 Mdot
.08286 .40955 Mdot
.08476 .43853 Mdot
.08667 .4452 Mdot
.08857 .37858 Mdot
.09048 .37047 Mdot
.09238 .41759 Mdot
.09429 .43077 Mdot
.09619 .32332 Mdot
.0981 .42392 Mdot
.1 .45319 Mdot
.1019 .44857 Mdot
.10381 .37374 Mdot
.10571 .38037 Mdot
.10762 .38095 Mdot
.10952 .38056 Mdot
.11143 .30203 Mdot
.11333 .30588 Mdot
.11524 .43948 Mdot
.11714 .32379 Mdot
.11905 .42425 Mdot
.12095 .43803 Mdot
.12286 .42903 Mdot
.12476 .43058 Mdot
.12667 .38168 Mdot
.12857 .36821 Mdot
.13048 .43693 Mdot
.13238 .45068 Mdot
.13429 .36051 Mdot
.13619 .43595 Mdot
.1381 .37917 Mdot
.14 .31759 Mdot
.1419 .44881 Mdot
.14381 .41976 Mdot
.14571 .26101 Mdot
.14762 .42552 Mdot
.14952 .44069 Mdot
.15143 .29271 Mdot
.15333 .29728 Mdot
.15524 .30167 Mdot
.15714 .41019 Mdot
.15905 .33309 Mdot
.16095 .29319 Mdot
.16286 .30377 Mdot
.16476 .28339 Mdot
.16667 .41961 Mdot
.16857 .3023 Mdot
.17048 .43016 Mdot
.17238 .35123 Mdot
.17429 .42801 Mdot
.17619 .36534 Mdot
.1781 .41297 Mdot
.18 .40285 Mdot
.1819 .2893 Mdot
.18381 .3703 Mdot
.18571 .44822 Mdot
.18762 .25639 Mdot
.18952 .30395 Mdot
.19143 .33915 Mdot
.19333 .34797 Mdot
.19524 .30265 Mdot
.19714 .42485 Mdot
.19905 .43106 Mdot
.20095 .26092 Mdot
.20286 .31082 Mdot
.20476 .26004 Mdot
.20667 .44431 Mdot
.20857 .26523 Mdot
.21048 .43048 Mdot
.21238 .43282 Mdot
.21429 .32928 Mdot
.21619 .39655 Mdot
.2181 .3332 Mdot
.22 .44215 Mdot
.2219 .38727 Mdot
.22381 .41501 Mdot
.22571 .37898 Mdot
.22762 .34925 Mdot
.22952 .28685 Mdot
.23143 .26123 Mdot
.23333 .41219 Mdot
.23524 .26595 Mdot
.23714 .26457 Mdot
.23905 .43683 Mdot
.24095 .42069 Mdot
.24286 .42451 Mdot
.24476 .28272 Mdot
.24667 .33212 Mdot
.24857 .44544 Mdot
.25048 .44402 Mdot
.25238 .42032 Mdot
.25429 .40286 Mdot
.25619 .45387 Mdot
.2581 .40637 Mdot
.26 .422 Mdot
.2619 .41136 Mdot
.26381 .2896 Mdot
.26571 .42264 Mdot
.26762 .44477 Mdot
.26952 .40036 Mdot
.27143 .26417 Mdot
.27333 .40718 Mdot
.27524 .39912 Mdot
.27714 .44614 Mdot
.27905 .37134 Mdot
.28095 .38095 Mdot
.28286 .42494 Mdot
.28476 .43216 Mdot
.28667 .42392 Mdot
.28857 .30752 Mdot
.29048 .44111 Mdot
.29238 .43058 Mdot
.29429 .42632 Mdot
.29619 .25891 Mdot
.2981 .29027 Mdot
.3 .36726 Mdot
.3019 .41898 Mdot
.30381 .44713 Mdot
.30571 .42516 Mdot
.30762 .33975 Mdot
.30952 .33646 Mdot
.31143 .46266 Mdot
.31333 .32536 Mdot
.31524 .2835 Mdot
.31714 .40219 Mdot
.31905 .29668 Mdot
.32095 .39131 Mdot
.32286 .43124 Mdot
.32476 .4249 Mdot
.32667 .44455 Mdot
.32857 .42808 Mdot
.33048 .43173 Mdot
.33238 .31212 Mdot
.33429 .42713 Mdot
.33619 .45779 Mdot
.3381 .4137 Mdot
.34 .38607 Mdot
.3419 .39794 Mdot
.34381 .44663 Mdot
.34571 .41552 Mdot
.34762 .30442 Mdot
.34952 .43024 Mdot
.35143 .41939 Mdot
.35333 .27884 Mdot
.35524 .31906 Mdot
.35714 .32849 Mdot
.35905 .32928 Mdot
.36095 .43839 Mdot
.36286 .44285 Mdot
.36476 .39144 Mdot
.36667 .26538 Mdot
.36857 .42579 Mdot
.37048 .42814 Mdot
.37238 .45305 Mdot
.37429 .26604 Mdot
.37619 .44922 Mdot
.3781 .26337 Mdot
.38 .42399 Mdot
.3819 .43733 Mdot
.38381 .44226 Mdot
.38571 .45706 Mdot
.38762 .37674 Mdot
.38952 .45294 Mdot
.39143 .41797 Mdot
.39333 .26135 Mdot
.39524 .43921 Mdot
.39714 .44926 Mdot
.39905 .45672 Mdot
.40095 .44462 Mdot
.40286 .31654 Mdot
.40476 .44755 Mdot
.40667 .34221 Mdot
.40857 .26601 Mdot
.41048 .26593 Mdot
.41238 .29159 Mdot
.41429 .327 Mdot
.41619 .44463 Mdot
.4181 .39887 Mdot
.42 .26558 Mdot
.4219 .38421 Mdot
.42381 .25816 Mdot
.42571 .26827 Mdot
.42762 .2848 Mdot
.42952 .39686 Mdot
.43143 .34786 Mdot
.43333 .41576 Mdot
.43524 .28431 Mdot
.43714 .39818 Mdot
.43905 .35083 Mdot
.44095 .45767 Mdot
.44286 .26832 Mdot
.44476 .39104 Mdot
.44667 .453 Mdot
.44857 .32788 Mdot
.45048 .43012 Mdot
.45238 .41412 Mdot
.45429 .41111 Mdot
.45619 .30578 Mdot
.4581 .31017 Mdot
.46 .38532 Mdot
.4619 .26647 Mdot
.46381 .42513 Mdot
.46571 .459 Mdot
.46762 .26694 Mdot
.46952 .29793 Mdot
.47143 .42746 Mdot
.47333 .35373 Mdot
.47524 .3062 Mdot
.47714 .45001 Mdot
.47905 .31811 Mdot
.48095 .3873 Mdot
.48286 .40962 Mdot
.48476 .39823 Mdot
.48667 .44469 Mdot
.48857 .37245 Mdot
.49048 .41609 Mdot
.49238 .33341 Mdot
.49429 .44215 Mdot
.49619 .26373 Mdot
.4981 .42603 Mdot
.5 .37117 Mdot
.5019 .33192 Mdot
.50381 .42287 Mdot
.50571 .45438 Mdot
.50762 .2804 Mdot
.50952 .26803 Mdot
.51143 .42361 Mdot
.51333 .33129 Mdot
.51524 .32201 Mdot
.51714 .35285 Mdot
.51905 .30199 Mdot
.52095 .4484 Mdot
.52286 .43811 Mdot
.52476 .3376 Mdot
.52667 .30508 Mdot
.52857 .41282 Mdot
.53048 .26509 Mdot
.53238 .3399 Mdot
.53429 .3951 Mdot
.53619 .31859 Mdot
.5381 .38841 Mdot
.54 .41708 Mdot
.5419 .34719 Mdot
.54381 .4216 Mdot
.54571 .36451 Mdot
.54762 .26852 Mdot
.54952 .35518 Mdot
.55143 .43129 Mdot
.55333 .26015 Mdot
.55524 .28127 Mdot
.55714 .43774 Mdot
.55905 .27009 Mdot
.56095 .38814 Mdot
.56286 .42647 Mdot
.56476 .27964 Mdot
.56667 .30156 Mdot
.56857 .42595 Mdot
.57048 .44447 Mdot
.57238 .2828 Mdot
.57429 .29258 Mdot
.57619 .34593 Mdot
.5781 .41648 Mdot
.58 .32919 Mdot
.5819 .41096 Mdot
.58381 .43316 Mdot
.58571 .43255 Mdot
.58762 .42968 Mdot
.58952 .42636 Mdot
.59143 .30258 Mdot
.59333 .43579 Mdot
.59524 .42732 Mdot
.59714 .41378 Mdot
.59905 .42459 Mdot
.60095 .42593 Mdot
.60286 .34529 Mdot
.60476 .3552 Mdot
.60667 .3982 Mdot
.60857 .44095 Mdot
.61048 .44091 Mdot
.61238 .29854 Mdot
.61429 .43533 Mdot
.61619 .32896 Mdot
.6181 .26699 Mdot
.62 .40223 Mdot
.6219 .36753 Mdot
.62381 .40573 Mdot
.62571 .46133 Mdot
.62762 .27255 Mdot
.62952 .39287 Mdot
.63143 .37777 Mdot
.63333 .42581 Mdot
.63524 .27155 Mdot
.63714 .45188 Mdot
.63905 .42993 Mdot
.64095 .44517 Mdot
.64286 .28341 Mdot
.64476 .36348 Mdot
.64667 .36537 Mdot
.64857 .42047 Mdot
.65048 .29019 Mdot
.65238 .27802 Mdot
.65429 .29187 Mdot
.65619 .35218 Mdot
.6581 .45211 Mdot
.66 .41823 Mdot
.6619 .26094 Mdot
.66381 .40129 Mdot
.66571 .26417 Mdot
.66762 .28889 Mdot
.66952 .38714 Mdot
.67143 .37638 Mdot
.67333 .38604 Mdot
.67524 .31556 Mdot
.67714 .33008 Mdot
.67905 .4416 Mdot
.68095 .34443 Mdot
.68286 .40215 Mdot
.68476 .26151 Mdot
.68667 .43994 Mdot
.68857 .32719 Mdot
.69048 .42373 Mdot
.69238 .40367 Mdot
.69429 .26105 Mdot
.69619 .35259 Mdot
.6981 .42978 Mdot
.7 .45056 Mdot
.7019 .43514 Mdot
.70381 .41931 Mdot
.70571 .3335 Mdot
.70762 .35636 Mdot
.70952 .42081 Mdot
.71143 .34604 Mdot
.71333 .44992 Mdot
.71524 .45675 Mdot
.71714 .41635 Mdot
.71905 .44448 Mdot
.72095 .45166 Mdot
.72286 .45561 Mdot
.72476 .28594 Mdot
.72667 .35223 Mdot
.72857 .4274 Mdot
.73048 .44979 Mdot
.73238 .28616 Mdot
.73429 .41225 Mdot
.73619 .35809 Mdot
.7381 .37865 Mdot
.74 .39597 Mdot
.7419 .42998 Mdot
.74381 .38865 Mdot
.74571 .433 Mdot
.74762 .41631 Mdot
.74952 .40426 Mdot
.75143 .43347 Mdot
.75333 .40669 Mdot
.75524 .43212 Mdot
.75714 .4308 Mdot
.75905 .41856 Mdot
.76095 .38874 Mdot
.76286 .28159 Mdot
.76476 .43623 Mdot
.76667 .33839 Mdot
.76857 .29225 Mdot
.77048 .45472 Mdot
.77238 .41057 Mdot
.77429 .2847 Mdot
.77619 .28806 Mdot
.7781 .32007 Mdot
.78 .31016 Mdot
.7819 .44035 Mdot
.78381 .40852 Mdot
.78571 .43308 Mdot
.78762 .45334 Mdot
.78952 .37125 Mdot
.79143 .42729 Mdot
.79333 .36567 Mdot
.79524 .32416 Mdot
.79714 .30943 Mdot
.79905 .30751 Mdot
.80095 .45133 Mdot
.80286 .44808 Mdot
.80476 .32405 Mdot
.80667 .26074 Mdot
.80857 .26164 Mdot
.81048 .25736 Mdot
.81238 .45775 Mdot
.81429 .29623 Mdot
.81619 .41685 Mdot
.8181 .2656 Mdot
.82 .29073 Mdot
.8219 .26616 Mdot
.82381 .30313 Mdot
.82571 .37808 Mdot
.82762 .2854 Mdot
.82952 .26539 Mdot
.83143 .45889 Mdot
.83333 .44224 Mdot
.83524 .31038 Mdot
.83714 .37018 Mdot
.83905 .35017 Mdot
.84095 .39313 Mdot
.84286 .3593 Mdot
.84476 .30904 Mdot
.84667 .4432 Mdot
.84857 .4541 Mdot
.85048 .3938 Mdot
.85238 .42617 Mdot
.85429 .37766 Mdot
.85619 .26171 Mdot
.8581 .4214 Mdot
.86 .42504 Mdot
.8619 .31191 Mdot
.86381 .40211 Mdot
.86571 .43793 Mdot
.86762 .26251 Mdot
.86952 .28307 Mdot
.87143 .33565 Mdot
.87333 .41508 Mdot
.87524 .36039 Mdot
.87714 .44041 Mdot
.87905 .26293 Mdot
.88095 .38159 Mdot
.88286 .36676 Mdot
.88476 .26275 Mdot
.88667 .26641 Mdot
.88857 .26496 Mdot
.89048 .45055 Mdot
.89238 .28015 Mdot
.89429 .4269 Mdot
.89619 .3934 Mdot
.8981 .38851 Mdot
.9 .42225 Mdot
.9019 .40927 Mdot
.90381 .36746 Mdot
.90571 .45753 Mdot
.90762 .28603 Mdot
.90952 .45234 Mdot
.91143 .45622 Mdot
.91333 .32506 Mdot
.91524 .43571 Mdot
.91714 .35448 Mdot
.91905 .37357 Mdot
.92095 .4234 Mdot
.92286 .39524 Mdot
.92476 .29967 Mdot
.92667 .35105 Mdot
.92857 .3765 Mdot
.93048 .4598 Mdot
.93238 .38587 Mdot
.93429 .30985 Mdot
.93619 .38385 Mdot
.9381 .36224 Mdot
.94 .29627 Mdot
.9419 .29968 Mdot
.94381 .38017 Mdot
.94571 .37427 Mdot
.94762 .27173 Mdot
.94952 .33786 Mdot
.95143 .44059 Mdot
.95333 .29251 Mdot
.95524 .39478 Mdot
.95714 .271 Mdot
.95905 .33486 Mdot
.96095 .28442 Mdot
.96286 .43526 Mdot
.96476 .27874 Mdot
.96667 .3918 Mdot
.96857 .42172 Mdot
.97048 .41571 Mdot
.97238 .30187 Mdot
.97429 .42474 Mdot
.97619 .45158 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooocgooooo0006
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol0003oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_oo
ool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0<Oooool2o`00027ooooo0_l0000Wooooo`;o0000N_ooool2o`00047ooooo000Yoooo
o`03o`000?oooooooooo02?ooooo0_l0000<ooooo`;o00000_ooool3o`0000Oooooo0_l0000Coooo
o`;o00007Oooool2o`0000Sooooo0_l0000Xooooo`;o00008?ooool2o`0000Kooooo0_l000000ooo
oooo0000o`00000Rooooo`?o00003Oooool2o`0003;ooooo000Yooooo`;o00001_ooool2o`0001co
oooo0_l0000@ooooo`Go00001Oooool4o`0000Wooooo0_l0000Pooooo`;o00000oooool2o`0001oo
oooo0_l00009ooooo`;o00001_ooool2o`00023ooooo1?l00004ooooo`;o000000?oooooo`000?l0
00008_ooool3o`0000gooooo0_l00002ooooo`;o000000?oooooo`000?l000000ol0000Xooooo`00
:Oooool00ol0003oooooooooo`05ooooo`;o0000<Oooool2o`0000Kooooo0ol00009ooooo`;o0000
7Oooool5o`0000Sooooo0ol000001?oooooo0000o`000?l00004ooooo`;o00001?ooool4o`0000Oo
oooo0_l00002ooooo`;o00001Oooool2o`0001[ooooo0_l0000>ooooo`;o0000;oooool5o`0000_o
oooo0_l000000ooooooo0000o`000003o`0002Sooooo000Yooooo`03o`000?oooooooooo033ooooo
1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko0000o`000?lb
<S;ok^k^02Oooooo1ol00003ooooo`03onk^k_lb<S;o000000?o000000?oooooo`000?l000000_l0
00000olb<S;ok^k^ooooo`02o`0000Cooooo1?l0000;ooooo`;o00002oooool2o`000008ooooool0
003o0000oiRHV?l@413o0000oc8b<_o<c<`3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko0000o`000?lb<S;ok^k^02[ooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0
003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ol0000Aooooo`;o00004Oooool0
0om4A4Co0000o`000002o`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool002Wooooo00?o0000ooooooooool01_ooool2o`0002[ooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Yooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`;o000000Soooooo`000?l0003o410@
okZj^_ooooooMgMgoc8b<P?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`04ogMgMonHV9So
oooooiRHV0;o000000?oooooo`000?l000009oooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg02Wooooo0_l000000ooooooo
0000o`000002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo000Yooooo`03o`000?oooooooooo00Kooooo0_l0000Zooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100:_oo
ool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooo
oooooooooooo410@02cooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooo
ooooool@41000oooool2o`000003ooooool0003o000002Cooooo1Ol00003ooooo`05oa0@4?oooooo
ooooooooool@41000oooool01Ol@413ooooooooooooooooo410@02Wooooo0_l00002ooooo`04o`00
0?oooooooooooa0@40?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo
007ooooo000Yooooo`Co0000<Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000002;ooooo0_l00007ooooo`03oiRHV?lQ8B7o
k^k^00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
5_ooool2o`00013ooooo0_l000000oooooooZJVYoa0@4003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000Oooooo0_l0000Oooooo`04odA4A?oMgMgooooo
o`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
6?ooool2o`0001;ooooo00?oMgMgoc8b<_ooool00_l00003ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`01ooooo`00:Oooool00ol0003oooooo`000004o`0002Kooooo
0_l00006ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`04
o`000?ooooooooooooooo`;o00005Oooool2o`0000[ooooo0_l00008ooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000005_oo
ool2o`0000gooooo0_l000001?oooooo0000o`000?l@4102o`0000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000001?ooool2o`000003ooooool0003o0000
01oooooo00?ogMgMoeEEEOooool00_l00003ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo0000013ooooo0_l00006ooooo`;o00003oooool01_l0003o8B4Qo`00
0?lb<S;oc<c<ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool00Oooool002Wooooo00Co0000oooooooooooooooo0ol0000Vooooo`;o00001_ooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000_ooool2o`0000?ooooo0_l0000E
ooooo`;o00005Oooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooo
oa0@4002o`000003ooooool0003o000002Cooooo0_l00004ooooo`;o00000oooool01Ol@413ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4004ooooo`;o00006Oooool4o`00
00Kooooo00CoMgMgolc<c?l0003o00000_ooool2o`0000?ooooo00Go410@oooooooooooooooooa0@
4003ooooo`04oa0@4?ooooooooooooooo`;o00002oooool2o`0000[ooooo0_l0000;ooooo`03o`00
0?oooooooooo00;ooooo0_l000001Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooooooooa0@4003ooooo`00:Oooool00ol0003oooooooooo`0_ooooo`;o000000?oooooo`000?oo
ool00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo0_l000001?nHV9SooooooiRHV?mgMgL5
ooooo`;o00008_ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`04ogMgMol0003o0000oiRHV0;o00009oooool01Ol@413oV9RHoooooonj^[[o0000
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool2o`00017ooooo1?l00006ooooo`03onk^k_m4A4Co000000?ooooo0_l000001?nHV9SooooooiRH
V?mgMgL3ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool2o`0001Oooooo0_l0000;ooooo`03
o`000?oooooooooo00;ooooo0_l000001OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`00:Oooool00ol0003oooooooooo`08ooooo`;o00006oooool2o`00
0003ooooool0003o000000Gooooo0_l000000omVIVKo0000ooooo`03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_l00009ooooo`;o00005ooo
ool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Cok^k^oc8b<_l0003o<S8b0_l00002ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h0:?ooool00onYZJWo410@o`000002o`0000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01oooool3o`0000;ooooo0_l0
000Looooo`03ogMgMol0003ooooo00Co000000Co<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00;o00009oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool002Wooooo0_l00009ooooo`;o00006oooool2o`00
0003ooooool0003o000002[ooooo0_l0000Sooooo`;o0000<_ooool2o`0001Oooooo0ol0000Soooo
o`;o00003?ooool4o`0002Gooooo0_l00002ooooo`;o00004oooool002Wooooo00?o0000oooooooo
ool00oooool2o`00027ooooo0_l0000cooooo`;o0000;oooool2o`0002cooooo0_l0000nooooo`;o
00009oooool2o`0001Oooooo000Yooooo`03o`000?oooooooooo00?ooooo0_l0000Cooooo`;o0000
3?ooool3o`0000;ooooo0_l0000^ooooo`;o0000;oooool2o`0000kooooo0_l0000=ooooo`;o0000
1_ooool2o`0000Gooooo0_l0001Rooooo`;o00000oooool2o`0000Sooooo0_l0000=ooooo`00:Ooo
ool01?l0003oooooo`000?l0000;ooooo`;o00002_ooool2o`0000gooooo1_l00005ooooo`?o0000
;oooool2o`0003Kooooo1?l0000;ooooo`;o00001_ooool2o`0004Wooooo0_l0000Nooooo`;o0000
0oooool2o`0000Sooooo0_l0000=ooooo`00:Oooool01?l0003oooooo`000?l0000;ooooo`;o0000
2oooool2o`0000kooooo0_l00007ooooo`?o00007?ooool2o`00017ooooo0_l0000Qooooo`;o0000
1?ooool2o`0000oooooo0_l0001Fooooo`;o00001_ooool2o`0003cooooo000Qoooooooo0000A?l0
0004ooooo`00:Oooool3o`0000Wooooo00Co0000oooooooooooooooo0_l00007ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`;o00000_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Ooo
ool2o`0000[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`04o`000?oo
ooooooooooooo`;o00001_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo
0_l000001?oooooo0000ooooooooool2o`0000Oooooo00?o0000ooooooooool00_l000000ooooooo
0000o`000004ooooo`;o00002oooool00ol0003oooooooooo`07ooooo`?o00002oooool00ol0003o
ooooooooo`0:ooooo`00:Oooool00ol0003oooooooooo`0=ooooo`;o00004oooool2o`0001Kooooo
00?o0000ooooooooool08_ooool2o`0001Gooooo0ol0000Fooooo`;o00009?ooool00ol0003ooooo
ooooo`0Fooooo`;o00008_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00[ooooo
000Yooooo`03o`000?oooooooooo02;ooooo0_l00013ooooo`;o00003Oooool2o`0001Oooooo0_l0
000@ooooo`;o0000:oooool2o`0001oooooo0_l0001;ooooo`00:Oooool00ol0003oooooooooo`0D
ooooo`;o00001?ooool2o`0004_ooooo0_l0000aooooo`;o00001Oooool2o`0004cooooo0_l00003
ooooo`;o000000?oooooo`000?l00000@oooool002Wooooo0_l0000>ooooo`;o00001Oooool2o`00
00Cooooo0_l0000mooooo`;o00007oooool2o`0001kooooo0_l0000fooooo`;o00008?ooool2o`00
0003ooooool0003o0000027ooooo0_l0000Pooooo`00:Oooool00ol0003oooooooooo`0=ooooo`;o
0000:oooool2o`0001gooooo0_l0000<ooooo`?o00004?ooool2o`0000Wooooo0_l0000Xooooo`;o
00002_ooool2o`00017ooooo0_l00002ooooo`;o0000A_ooool2o`00023ooooo000Yooooo`03o`00
0?oooooooooo02Sooooo0_l0000@ooooo`?o00001oooool2o`00027ooooo0ol0000Kooooo`;o0000
3?ooool2o`000003ooooool0003o000000;ooooo0_l0000Cooooo`;o00002_ooool2o`00017ooooo
0_l00008ooooo`;o0000H_ooool002Wooooo00?o0000ooooooooool0:?ooool2o`00017ooooo0_l0
0007ooooo`;o00004_ooool2o`0003Wooooo0_l000000ooooooo0000o`000002ooooo`;o0000??oo
ool2o`0003?ooooo0_l0000Jooooo`;o00004Oooool002Wooooo00?o0000ooooooooool0<_ooool2
o`0002Cooooo0_l00013ooooo`;o000000?oooooo`000?l00000BOooool2o`00023ooooo0_l0000G
ooooo`;o000000?oooooo`000?l000004Oooool002Wooooo0_l0000cooooo`;o00009?ooool2o`00
01gooooo0_l0000Tooooo`;o000000?oooooo`000?l00000BOooool2o`0003Wooooo0_l0000Doooo
o`00:Oooool00ol0003oooooooooo`1gooooo`;o0000=Oooool2o`0000Kooooo0_l0000Hooooo`;o
00001oooool2o`00067ooooo000Yooooo`03o`000?oooooooooo03?ooooo0_l00009ooooo`;o0000
?oooool2o`0002;ooooo0_l00009ooooo`;o00001_ooool2o`0001Sooooo0_l00007ooooo`;o0000
HOooool002Wooooo00?o0000ooooooooool0;?ooool2o`0000Gooooo0_l00009ooooo`;o0000?ooo
ool2o`000003ooooool0003o000001oooooo0_l0000Sooooo`;o00005?ooool2o`0002;ooooo0_l0
000Kooooo`;o00006oooool002Wooooo00?o0000ooooooooool0;?ooool2o`0005Cooooo0_l00009
ooooo`;o00003?ooool2o`0000Sooooo0_l0000@ooooo`;o00003oooool2o`0000[ooooo0_l00008
ooooo`;o00008_ooool2o`0001Sooooo0_l000000ooooooo0000o`00000Kooooo`00:Oooool2o`00
08kooooo0_l0000<ooooo`;o00002?ooool2o`00013ooooo0_l0000Kooooo`;o00000_ooool2o`00
00Oooooo0_l0000iooooo`;o00007_ooool002Wooooo00?o0000ooooooooool08?ooool2o`000;Ko
oooo0_l00007ooooo`;o00008Oooool2o`0000Sooooo0_l0000/ooooo`00:Oooool00ol0003ooooo
ooooo`0Pooooo`;o0000P_ooool2o`0001kooooo0_l0000nooooo`;o00002?ooool2o`0001;ooooo
0_l0000Hooooo`00:Oooool00ol0003oooooooooo`0]ooooo`;o00009_ooool2o`0004gooooo0_l0
000Gooooo`;o00001Oooool3o`0002gooooo0_l0000Jooooo`;o00001Oooool2o`0000Wooooo0_l0
000Hooooo`00:Oooool00ol0003oooooooooo`07ooooo`;o00002Oooool2o`0000[ooooo0_l0000=
ooooo`;o000000?oooooo`000?l000008oooool2o`0006Kooooo0_l00006ooooo`;o0000;Oooool2
o`0000cooooo0_l0000<ooooo`;o00001Oooool2o`0002?ooooo000Yooooo`;o00002?ooool2o`00
00Wooooo0_l00002ooooo`;o00001_ooool2o`00013ooooo0_l0000Looooo`;o0000@_ooool2o`00
0003ooooool0003o000005_ooooo0_l0000>ooooo`;o00006?ooool2o`0001kooooo000Yooooo`03
o`000?oooooooooo01Kooooo0_l0000fooooo`;o00008Oooool2o`0001oooooo0_l000000ooooooo
0000o`00000fooooo`;o00008oooool2o`0002Sooooo0_l000000ooooooo0000o`000004ooooo`;o
00005Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00;o00003oooool2o`00
00kooooo0_l0000Jooooo`;o0000<_ooool2o`0004gooooo0_l0000;ooooo`;o00004oooool2o`00
01[ooooo0_l00007ooooo`;o00005_ooool2o`0000?ooooo0ol0000Eooooo`001_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00;o00003oooool2o`0000Cooooo0ol00003
ooooo`;o00000_ooool2o`0001[ooooo0_l0000@ooooo`;o0000Koooool2o`00023ooooo0_l0000J
ooooo`;o00001oooool2o`0000Oooooo0_l0000Booooo`;o00005_ooool000Kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Gooooo`?o00000oooool2o`00033ooooo0_l0000Aooooo`;o00006?ooool2
o`0000_ooooo0_l00012ooooo`;o0000@Oooool2o`0000kooooo1?l0000Hooooo`001_ooool01Ol0
003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04
ooooo`?o0000??ooool2o`0002Cooooo0_l0000Hooooo`;o00002oooool2o`0000Cooooo0_l0000A
ooooo`;o00001Oooool2o`00027ooooo0ol0000Eooooo`;o00000oooool2o`0002[ooooo0_l00009
ooooo`Co00006?ooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKo
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo03cooooo0_l0
000Nooooo`;o00003?ooool2o`0001Sooooo0_l00009ooooo`;o00004Oooool2o`0000Gooooo0_l0
000Qooooo`;o00005_ooool2o`0000?ooooo0_l0000Zooooo`;o00005?ooool2o`0000oooooo0006
ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Oooooo0_l0001Mooooo`;o00003?ooool2o`0001Sooooo0_l0000Jooooo`;o00007Ooo
ool2o`0004;ooooo0_l000000ooooooo0000o`00000=ooooo`;o00001_ooool2o`0000Wooooo0_l0
00000ooooooo0000o`00000?ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo0_l0000kooooo`;o0000
9oooool2o`0001Kooooo0_l00002ooooo`Co00003Oooool2o`0000kooooo0_l0000Fooooo`;o0000
1Oooool2o`0002;ooooo0_l0000Nooooo`;o000000?oooooo`000?l000003Oooool2o`0000Kooooo
0_l00009ooooo`;o00004_ooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool01?ooool2o`000003
ooooool0003o0000037ooooo0_l0000?ooooo`Co00005?ooool2o`0001Kooooo0_l00002ooooo`Co
00003Oooool2o`0002Kooooo0_l0000@ooooo`;o00005oooool2o`0002Gooooo0_l0000`ooooo`00
:Oooool2o`0000Gooooo0_l000001?oooooo0000o`000?ooool3o`0000;ooooo0_l0000Mooooo`;o
00005_ooool2o`0000?ooooo1?l0000<ooooo`;o0000Goooool2o`0000cooooo0_l00004ooooo`;o
000000?oooooo`000?l000004Oooool2o`0002;ooooo0_l0000`ooooo`00:Oooool00ol0003ooooo
ooooo`0:ooooo`?o00000_ooool2o`0001gooooo0_l0000Fooooo`Co00000oooool2o`0000cooooo
0_l0001Oooooo`?o00004Oooool2o`000003ooooool0003o0000017ooooo0ol0001Cooooo`00:Ooo
ool00ol0003oooooooooo`09ooooo`?o00000oooool2o`0001Kooooo0_l0000Oooooo`?o00000_oo
ool2o`0003Sooooo0_l00007ooooo`;o00007_ooool2o`0000_ooooo0_l0000Xooooo`;o00001?oo
ool2o`0000;ooooo0_l0000Tooooo`;o00008oooool002Wooooo00?o0000ooooooooool02Oooool2
o`0000Cooooo0_l0000Fooooo`;o00001Oooool2o`00013ooooo0_l00007ooooo`;o00005_ooool2
o`0002?ooooo0ol00007ooooo`;o00003Oooool2o`0000oooooo0_l00003ooooo`;o0000:_ooool2
o`0000[ooooo0_l00002ooooo`;o00009?ooool2o`0002?ooooo000Yooooo`03o`000?oooooooooo
01;ooooo0_l0000Jooooo`;o00003Oooool2o`000003ooooool0003o000001oooooo0_l000000ooo
oooo0000o`00000Jooooo`;o00001?ooool2o`0000[ooooo0_l0000;ooooo`;o000000?oooooo`00
0?l000002_ooool2o`0000Gooooo0_l0000Tooooo`;o00001?ooool2o`0000;ooooo0_l0000Doooo
o`;o00004?ooool2o`0001kooooo0_l0000=ooooo`00:Oooool2o`0000[ooooo0_l00007ooooo`;o
00003oooool2o`0000Gooooo0_l0000Aooooo`;o00000oooool2o`0000;ooooo0_l0000>ooooo`;o
00003?ooool4o`0000[ooooo0_l0000<ooooo`;o00004?ooool2o`0000kooooo0_l0000:ooooo`;o
00005Oooool2o`0000;ooooo0_l0000<ooooo`;o00000_ooool2o`0000Sooooo0_l00002ooooo`;o
00004?ooool2o`00013ooooo0_l0000Nooooo`;o00003Oooool002Wooooo00?o0000ooooooooool0
1Oooool2o`0000;ooooo0_l00003ooooo`;o00004oooool2o`0000Gooooo0_l0000Fooooo`;o0000
0_ooool6o`0000[ooooo0_l0000>ooooo`;o00002_ooool2o`0002?ooooo1?l00008ooooo`;o0000
8?ooool2o`0000;ooooo0_l00008ooooo`;o00000_ooool4o`0000kooooo0_l0000Nooooo`;o0000
2oooool2o`0000Gooooo0_l0000=ooooo`;o00003_ooool002Wooooo00?o0000ooooooooool01Ooo
ool2o`0000Oooooo0_l00004ooooo`;o00001Oooool2o`0000Oooooo0_l0000>ooooo`;o00003Ooo
ool2o`0000?ooooo1?l00004ooooo`Go00000_ooool2o`0000Cooooo0_l0000<ooooo`;o00000_oo
ool2o`0001Wooooo0_l00009ooooo`Ko00002?ooool2o`0000Gooooo0ol00005ooooo`;o000000Co
ooooo`000?l0003o00002?ooool2o`00017ooooo0_l00004ooooo`;o0000;?ooool4o`0000Wooooo
1?l00005ooooo`;o00003Oooool4o`0000cooooo000Yooooo`03o`000?oooooooooo01Cooooo0_l0
0005ooooo`?o00001_ooool2o`0000Oooooo0_l00005ooooo`;o00003Oooool2o`0000_ooooo1Ol0
0002ooooo`;o00001?ooool5o`0000Wooooo0ol000000ooooooo0000o`00000Iooooo`Co00001ooo
ool2o`0001?ooooo0ol00005ooooo`Ko00002?ooool4o`00017ooooo0_l00008ooooo`;o00000_oo
ool2o`0000kooooo0_l0000Booooo`Co00002Oooool2o`0001Sooooo0_l0000<ooooo`00:Oooool0
0ol0003oooooooooo`02ooooo`;o00002?ooool2o`0000Gooooo0_l00007ooooo`?o00003?ooool4
o`0000Kooooo0_l000001?oooooo0000o`000?l0000Eooooo`;o000000?oooooo`000?l000001ooo
ool6o`0000?ooooo0_l00005ooooo`;o00005oooool2o`0000Gooooo0_l0000Hooooo`;o00002?oo
ool6o`0000cooooo0_l0000Aooooo`;o00002?ooool2o`0000;ooooo0ol000001?oooooo0000o`00
0?l00007ooooo`Co0000Aoooool002Wooooo0_l00003ooooo`;o00002?ooool2o`0000Gooooo0_l0
0008ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Sooooo0_l000001?oooooo0000o`00
0?l0000Eooooo`;o000000?oooooo`000?l000001oooool2o`000003ooooool0003o000000Cooooo
0_l0000Nooooo`;o00007oooool2o`0000Sooooo1Ol00005ooooo`;o00006_ooool2o`0000cooooo
1_l000000ooooooo0000o`000004ooooo`;o0000:?ooool2o`0000gooooo0_l0000@ooooo`00:Ooo
ool00ol0003oooooooooo`0@ooooo`;o00002_ooool2o`000004ooooool0003o0000o`0001oooooo
0_l0000Vooooo`;o00001?ooool2o`0000?ooooo0_l0000Wooooo`;o00002Oooool2o`0000Wooooo
0_l00005ooooo`;o00006_ooool2o`0000kooooo0_l00003ooooo`;o00007_ooool2o`0000kooooo
0_l0000=ooooo`;o00004?ooool002Wooooo00?o0000ooooooooool04?ooool2o`0000Sooooo1?l0
00000ooooooo0000o`000004ooooo`;o00005?ooool2o`0000Cooooo0_l0000?ooooo`;o00005Ooo
ool2o`0000Cooooo0ol00002ooooo`;o00007_ooool2o`0000Oooooo0_l00009ooooo`;o00003_oo
ool3o`0001Cooooo1?l0000Mooooo`;o00003oooool2o`0000Sooooo0_l00002ooooo`;o00005_oo
ool2o`0001?ooooo000Yooooo`03o`000?oooooooooo013ooooo0_l00008ooooo`;o00002Oooool2
o`00013ooooo0_l00002ooooo`;o00002?ooool2o`0000Cooooo0_l00005ooooo`;o00002_ooool2
o`0000Wooooo0_l00005ooooo`;o00001?ooool2o`0000;ooooo0_l0000Eooooo`;o000000?ooooo
o`000?l000005_ooool2o`0000[ooooo0ol00008ooooo`;o00002_ooool4o`0000Wooooo0_l0000B
ooooo`;o00003oooool2o`0000;ooooo0_l00008ooooo`;o00005_ooool2o`0001?ooooo000Yoooo
o`03o`000?oooooooooo00Cooooo0_l0000:ooooo`;o00000oooool2o`0001Wooooo0_l00005oooo
o`;o00003?ooool2o`0000Cooooo0_l000000ooooooo0000o`000006ooooo`;o00001_ooool2o`00
00?ooooo0_l00004ooooo`;o00002oooool3o`000003ooooool0003o000001Gooooo0_l00009oooo
o`;o00003_ooool2o`0001Gooooo0_l0000Gooooo`;o00006Oooool2o`0000cooooo0_l0000eoooo
o`00:Oooool2o`0000;ooooo0_l000000ooooooo0000o`00000?ooooo`;o00002?ooool2o`000003
ooooool0003o000000cooooo0_l0000Looooo`;o00001_ooool2o`0000_ooooo0_l00009ooooo`;o
00001?ooool2o`000003ooooool0003o000001Gooooo0_l0000<ooooo`;o00008oooool2o`0001?o
oooo0_l00002ooooo`Co000000?oooooo`000?l000005Oooool3o`0001[ooooo0_l0000Jooooo`;o
00002oooool002Wooooo00Co0000oooooooooooooooo0_l0000Booooo`;o00002?ooool2o`000003
ooooool0003o000002?ooooo0_l0000Sooooo`Co00000_ooool4o`0000kooooo0_l00008ooooo`;o
00001oooool2o`0002Sooooo0_l00005ooooo`;o00003?ooool2o`0000;ooooo1?l000000ooooooo
0000o`00000;ooooo`;o00001?ooool2o`0000;ooooo0_l0000=ooooo`;o00003?ooool2o`0000Co
oooo0_l0000Dooooo`;o00002oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool05Oooool2o`00
033ooooo0_l0000Hooooo`;o00002Oooool2o`0000?ooooo0ol000000ooooooo0000o`00000;oooo
o`Co00004Oooool2o`0002oooooo0_l0000Aooooo`Co00003Oooool2o`0000Cooooo0_l00006oooo
o`;o00002Oooool2o`00017ooooo1?l0000Pooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0HOooool2o`00
00kooooo0_l00002ooooo`;o00002oooool2o`0000Kooooo0_l0001?ooooo`Co00006oooool2o`00
00Cooooo0_l0000Fooooo`Co00001?ooool2o`0001[ooooo000>ooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol0003oooooooooo`03ooooo`?o0000FOooool2o`0002oooooo0_l0000boooo
o`;o0000@?ooool2o`0001kooooo0_l0000Jooooo`003_ooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1Iooooo`;o0000Hoooool2o`00
07cooooo000>ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo000>oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2
o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2
o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003ooooo
ocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003o
oooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo
410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooo
oooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Ooo
ool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0
003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0
003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`007oooool4o`000003
oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Ooo
ool3o`000?oooooo?Oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`007oooool00omEEEGoIVIVo`00003oooooodOooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .34557 Mdot
.02762 .33965 Mdot
.02952 .30111 Mdot
.03143 .26578 Mdot
.03333 .24978 Mdot
.03524 .3205 Mdot
.03714 .31771 Mdot
.03905 .41744 Mdot
.04095 .43493 Mdot
.04286 .26041 Mdot
.04476 .25435 Mdot
.04667 .43912 Mdot
.04857 .33708 Mdot
.05048 .2744 Mdot
.05238 .44777 Mdot
.05429 .26899 Mdot
.05619 .31296 Mdot
.0581 .33631 Mdot
.06 .25334 Mdot
.0619 .3649 Mdot
.06381 .37439 Mdot
.06571 .36816 Mdot
.06762 .39037 Mdot
.06952 .34986 Mdot
.07143 .45208 Mdot
.07333 .24707 Mdot
.07524 .263 Mdot
.07714 .25419 Mdot
.07905 .38045 Mdot
.08095 .36176 Mdot
.08286 .39778 Mdot
.08476 .42893 Mdot
.08667 .4329 Mdot
.08857 .34009 Mdot
.09048 .30689 Mdot
.09238 .40664 Mdot
.09429 .41725 Mdot
.09619 .25968 Mdot
.0981 .41088 Mdot
.1 .43192 Mdot
.1019 .44873 Mdot
.10381 .31789 Mdot
.10571 .32736 Mdot
.10762 .31059 Mdot
.10952 .31283 Mdot
.11143 .24853 Mdot
.11333 .25517 Mdot
.11524 .4163 Mdot
.11714 .25069 Mdot
.11905 .4029 Mdot
.12095 .42081 Mdot
.12286 .40057 Mdot
.12476 .47803 Mdot
.12667 .33575 Mdot
.12857 .29875 Mdot
.13048 .43592 Mdot
.13238 .42495 Mdot
.13429 .29297 Mdot
.13619 .41608 Mdot
.1381 .31056 Mdot
.14 .25113 Mdot
.1419 .46231 Mdot
.14381 .41683 Mdot
.14571 .30598 Mdot
.14762 .44249 Mdot
.14952 .42921 Mdot
.15143 .25658 Mdot
.15333 .25792 Mdot
.15524 .25246 Mdot
.15714 .36481 Mdot
.15905 .25379 Mdot
.16095 .32261 Mdot
.16286 .25548 Mdot
.16476 .26033 Mdot
.16667 .41694 Mdot
.16857 .31248 Mdot
.17048 .47788 Mdot
.17238 .28829 Mdot
.17429 .39578 Mdot
.17619 .317 Mdot
.1781 .40222 Mdot
.18 .36846 Mdot
.1819 .26113 Mdot
.18381 .30827 Mdot
.18571 .41887 Mdot
.18762 .29983 Mdot
.18952 .24962 Mdot
.19143 .27085 Mdot
.19333 .27155 Mdot
.19524 .25773 Mdot
.19714 .45174 Mdot
.19905 .47146 Mdot
.20095 .30979 Mdot
.20286 .24972 Mdot
.20476 .30095 Mdot
.20667 .47376 Mdot
.20857 .27303 Mdot
.21048 .43091 Mdot
.21238 .47937 Mdot
.21429 .2518 Mdot
.21619 .35419 Mdot
.2181 .25552 Mdot
.22 .44434 Mdot
.2219 .32389 Mdot
.22381 .38207 Mdot
.22571 .33958 Mdot
.22762 .2713 Mdot
.22952 .25413 Mdot
.23143 .31086 Mdot
.23333 .37418 Mdot
.23524 .27259 Mdot
.23714 .28045 Mdot
.23905 .43044 Mdot
.24095 .38022 Mdot
.24286 .4817 Mdot
.24476 .32444 Mdot
.24667 .26045 Mdot
.24857 .41456 Mdot
.25048 .41892 Mdot
.25238 .42579 Mdot
.25429 .34603 Mdot
.25619 .45826 Mdot
.2581 .39539 Mdot
.26 .37317 Mdot
.2619 .36934 Mdot
.26381 .26042 Mdot
.26571 .38966 Mdot
.26762 .47208 Mdot
.26952 .37872 Mdot
.27143 .29707 Mdot
.27333 .37732 Mdot
.27524 .36313 Mdot
.27714 .44455 Mdot
.27905 .29934 Mdot
.28095 .3266 Mdot
.28286 .38034 Mdot
.28476 .39487 Mdot
.28667 .38842 Mdot
.28857 .25603 Mdot
.29048 .44003 Mdot
.29238 .44841 Mdot
.29429 .46288 Mdot
.29619 .29957 Mdot
.2981 .25382 Mdot
.3 .30878 Mdot
.3019 .36931 Mdot
.30381 .41726 Mdot
.30571 .48436 Mdot
.30762 .27665 Mdot
.30952 .26685 Mdot
.31143 .44758 Mdot
.31333 .25019 Mdot
.31524 .25712 Mdot
.31714 .34178 Mdot
.31905 .32266 Mdot
.32095 .35355 Mdot
.32286 .40622 Mdot
.32476 .41186 Mdot
.32667 .42329 Mdot
.32857 .42128 Mdot
.33048 .40364 Mdot
.33238 .24729 Mdot
.33429 .38748 Mdot
.33619 .42988 Mdot
.3381 .4079 Mdot
.34 .35297 Mdot
.3419 .369 Mdot
.34381 .41984 Mdot
.34571 .37865 Mdot
.34762 .25267 Mdot
.34952 .38906 Mdot
.35143 .41 Mdot
.35333 .26746 Mdot
.35524 .2574 Mdot
.35714 .25959 Mdot
.35905 .26248 Mdot
.36095 .43991 Mdot
.36286 .47293 Mdot
.36476 .35623 Mdot
.36667 .30334 Mdot
.36857 .39557 Mdot
.37048 .38369 Mdot
.37238 .43787 Mdot
.37429 .27464 Mdot
.37619 .44919 Mdot
.3781 .29648 Mdot
.38 .4364 Mdot
.3819 .47043 Mdot
.38381 .41786 Mdot
.38571 .43204 Mdot
.38762 .31612 Mdot
.38952 .45625 Mdot
.39143 .36596 Mdot
.39333 .29757 Mdot
.39524 .4614 Mdot
.39714 .42043 Mdot
.39905 .4459 Mdot
.40095 .44402 Mdot
.40286 .25161 Mdot
.40476 .47768 Mdot
.40667 .26127 Mdot
.40857 .30305 Mdot
.41048 .30325 Mdot
.41238 .32261 Mdot
.41429 .25871 Mdot
.41619 .47802 Mdot
.4181 .36831 Mdot
.42 .28603 Mdot
.4219 .33003 Mdot
.42381 .30306 Mdot
.42571 .31727 Mdot
.42762 .25764 Mdot
.42952 .33361 Mdot
.43143 .28185 Mdot
.43333 .38014 Mdot
.43524 .26069 Mdot
.43714 .37157 Mdot
.43905 .28854 Mdot
.44095 .43347 Mdot
.44286 .31654 Mdot
.44476 .34403 Mdot
.44667 .42636 Mdot
.44857 .25689 Mdot
.45048 .4269 Mdot
.45238 .373 Mdot
.45429 .40684 Mdot
.45619 .25763 Mdot
.4581 .25107 Mdot
.46 .31522 Mdot
.4619 .28003 Mdot
.46381 .44802 Mdot
.46571 .45644 Mdot
.46762 .27537 Mdot
.46952 .31783 Mdot
.47143 .47298 Mdot
.47333 .28406 Mdot
.47524 .25391 Mdot
.47714 .4584 Mdot
.47905 .25664 Mdot
.48095 .32302 Mdot
.48286 .38083 Mdot
.48476 .35943 Mdot
.48667 .46255 Mdot
.48857 .30381 Mdot
.49048 .37388 Mdot
.49238 .25407 Mdot
.49429 .42156 Mdot
.49619 .28603 Mdot
.4981 .41817 Mdot
.5 .32547 Mdot
.5019 .25296 Mdot
.50381 .41382 Mdot
.50571 .44776 Mdot
.50762 .32322 Mdot
.50952 .28021 Mdot
.51143 .42214 Mdot
.51333 .25805 Mdot
.51524 .2594 Mdot
.51714 .27064 Mdot
.51905 .31299 Mdot
.52095 .43168 Mdot
.52286 .41512 Mdot
.52476 .26126 Mdot
.52667 .2538 Mdot
.52857 .40642 Mdot
.53048 .30619 Mdot
.53238 .26253 Mdot
.53429 .35513 Mdot
.53619 .25942 Mdot
.5381 .35363 Mdot
.54 .40991 Mdot
.5419 .27709 Mdot
.54381 .3965 Mdot
.54571 .29057 Mdot
.54762 .27033 Mdot
.54952 .28897 Mdot
.55143 .40151 Mdot
.55333 .28357 Mdot
.55524 .25585 Mdot
.55714 .42362 Mdot
.55905 .26719 Mdot
.56095 .34063 Mdot
.56286 .39314 Mdot
.56476 .32468 Mdot
.56667 .25648 Mdot
.56857 .42327 Mdot
.57048 .44167 Mdot
.57238 .25571 Mdot
.57429 .32138 Mdot
.57619 .28597 Mdot
.5781 .36654 Mdot
.58 .25893 Mdot
.5819 .40311 Mdot
.58381 .46936 Mdot
.58571 .42216 Mdot
.58762 .44683 Mdot
.58952 .42808 Mdot
.59143 .3188 Mdot
.59333 .40678 Mdot
.59524 .45872 Mdot
.59714 .36047 Mdot
.59905 .44743 Mdot
.60095 .48588 Mdot
.60286 .27204 Mdot
.60476 .27304 Mdot
.60667 .35605 Mdot
.60857 .42505 Mdot
.61048 .45095 Mdot
.61238 .25481 Mdot
.61429 .42701 Mdot
.61619 .25591 Mdot
.6181 .30535 Mdot
.62 .34842 Mdot
.6219 .30871 Mdot
.62381 .35577 Mdot
.62571 .44793 Mdot
.62762 .31807 Mdot
.62952 .34929 Mdot
.63143 .33284 Mdot
.63333 .44332 Mdot
.63524 .31791 Mdot
.63714 .4408 Mdot
.63905 .4565 Mdot
.64095 .46772 Mdot
.64286 .26244 Mdot
.64476 .28398 Mdot
.64667 .29663 Mdot
.64857 .41825 Mdot
.65048 .25193 Mdot
.65238 .32054 Mdot
.65429 .31944 Mdot
.65619 .27619 Mdot
.6581 .42287 Mdot
.66 .42452 Mdot
.6619 .30854 Mdot
.66381 .34754 Mdot
.66571 .30478 Mdot
.66762 .32205 Mdot
.66952 .31901 Mdot
.67143 .31163 Mdot
.67333 .35218 Mdot
.67524 .2482 Mdot
.67714 .26164 Mdot
.67905 .4808 Mdot
.68095 .27336 Mdot
.68286 .37726 Mdot
.68476 .29362 Mdot
.68667 .4364 Mdot
.68857 .26492 Mdot
.69048 .39094 Mdot
.69238 .38243 Mdot
.69429 .31184 Mdot
.69619 .29424 Mdot
.6981 .46365 Mdot
.7 .43523 Mdot
.7019 .3976 Mdot
.70381 .4048 Mdot
.70571 .25838 Mdot
.70762 .28169 Mdot
.70952 .40652 Mdot
.71143 .27078 Mdot
.71333 .43639 Mdot
.71524 .46798 Mdot
.71714 .37393 Mdot
.71905 .4453 Mdot
.72095 .4419 Mdot
.72286 .44237 Mdot
.72476 .32175 Mdot
.72667 .28194 Mdot
.72857 .44848 Mdot
.73048 .42783 Mdot
.73238 .32202 Mdot
.73429 .39817 Mdot
.73619 .30106 Mdot
.7381 .31507 Mdot
.74 .35279 Mdot
.7419 .43227 Mdot
.74381 .32646 Mdot
.74571 .41568 Mdot
.74762 .42324 Mdot
.74952 .39116 Mdot
.75143 .39156 Mdot
.75333 .3813 Mdot
.75524 .451 Mdot
.75714 .4854 Mdot
.75905 .42765 Mdot
.76095 .34037 Mdot
.76286 .31853 Mdot
.76476 .45546 Mdot
.76667 .25986 Mdot
.76857 .31933 Mdot
.77048 .43461 Mdot
.77238 .3658 Mdot
.77429 .32379 Mdot
.77619 .25824 Mdot
.7781 .25118 Mdot
.78 .25446 Mdot
.7819 .41447 Mdot
.78381 .35188 Mdot
.78571 .46042 Mdot
.78762 .43814 Mdot
.78952 .31634 Mdot
.79143 .47521 Mdot
.79333 .30106 Mdot
.79524 .25824 Mdot
.79714 .25141 Mdot
.79905 .31369 Mdot
.80095 .42686 Mdot
.80286 .43944 Mdot
.80476 .26187 Mdot
.80667 .29168 Mdot
.80857 .27588 Mdot
.81048 .29222 Mdot
.81238 .44923 Mdot
.81429 .24947 Mdot
.81619 .4029 Mdot
.8181 .27984 Mdot
.82 .25447 Mdot
.8219 .31025 Mdot
.82381 .24929 Mdot
.82571 .33967 Mdot
.82762 .25664 Mdot
.82952 .28609 Mdot
.83143 .45418 Mdot
.83333 .43895 Mdot
.83524 .29466 Mdot
.83714 .30553 Mdot
.83905 .27265 Mdot
.84095 .36818 Mdot
.84286 .30341 Mdot
.84476 .25349 Mdot
.84667 .45529 Mdot
.84857 .47625 Mdot
.85048 .33921 Mdot
.85238 .48081 Mdot
.85429 .3029 Mdot
.85619 .29883 Mdot
.8581 .43804 Mdot
.86 .44869 Mdot
.8619 .25566 Mdot
.86381 .38778 Mdot
.86571 .47992 Mdot
.86762 .28649 Mdot
.86952 .32265 Mdot
.87143 .26945 Mdot
.87333 .40276 Mdot
.87524 .30352 Mdot
.87714 .47516 Mdot
.87905 .30334 Mdot
.88095 .33872 Mdot
.88286 .30065 Mdot
.88476 .31304 Mdot
.88667 .30888 Mdot
.88857 .27551 Mdot
.89048 .41965 Mdot
.89238 .32378 Mdot
.89429 .38938 Mdot
.89619 .33504 Mdot
.8981 .33312 Mdot
.9 .39185 Mdot
.9019 .40319 Mdot
.90381 .30734 Mdot
.90571 .47281 Mdot
.90762 .2589 Mdot
.90952 .42261 Mdot
.91143 .44538 Mdot
.91333 .26438 Mdot
.91524 .4027 Mdot
.91714 .2913 Mdot
.91905 .33075 Mdot
.92095 .38837 Mdot
.92286 .34854 Mdot
.92476 .25168 Mdot
.92667 .29048 Mdot
.92857 .33075 Mdot
.93048 .45864 Mdot
.93238 .3447 Mdot
.93429 .30719 Mdot
.93619 .34127 Mdot
.9381 .30706 Mdot
.94 .3239 Mdot
.9419 .25811 Mdot
.94381 .33089 Mdot
.94571 .30965 Mdot
.94762 .31633 Mdot
.94952 .26518 Mdot
.95143 .42974 Mdot
.95333 .25094 Mdot
.95524 .35635 Mdot
.95714 .2642 Mdot
.95905 .27077 Mdot
.96095 .32197 Mdot
.96286 .48588 Mdot
.96476 .31935 Mdot
.96667 .32972 Mdot
.96857 .43122 Mdot
.97048 .40593 Mdot
.97238 .25233 Mdot
.97429 .39131 Mdot
.97619 .43836 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooocgooooo0006
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol0003oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_oo
ool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`;o00003Oooool2o`0000[ooooo0_l0000Hooooo`;o
00000_ooool2o`0002Oooooo0_l0001]ooooo`;o0000:_ooool2o`0000;ooooo0_l0000looooo`00
:Oooool01?l0003oooooo`000?l0000;ooooo`;o00002_ooool4o`0000Kooooo0_l00003ooooo`;o
00002Oooool2o`0000;ooooo0_l00002ooooo`;o00007Oooool2o`0000Cooooo0_l00003ooooo`;o
00004?ooool2o`00013ooooo0_l0000looooo`;o00001_ooool2o`0001oooooo0_l00004ooooo`;o
00000oooool2o`0000;ooooo0_l0000Nooooo`;o00001oooool2o`0000Cooooo0_l0000=ooooo`00
:Oooool01?l0003oooooo`000?l00002ooooo`;o00000oooool2o`0000?ooooo0_l0000:ooooo`?o
00001_ooool2o`0000?ooooo1?l0000?ooooo`?o000000?oooooo`000?l000005?ooool2o`0000?o
oooo0_l00009ooooo`;o00004?ooool2o`00013ooooo0_l00003ooooo`;o00001?ooool2o`000003
ooooool0003o000000Kooooo0_l00007ooooo`;o00001?ooool2o`0000_ooooo0ol00009ooooo`;o
00009oooool2o`0000Cooooo0_l00005ooooo`;o00001_ooool2o`0000Cooooo0_l0000Booooo`;o
00001oooool2o`0000Cooooo0_l0000=ooooo`00:Oooool00ol0003oooooooooo`03ooooo`;o0000
0oooool2o`0000?ooooo0_l0000:ooooo`;o00002_ooool6o`0000Sooooo0_l00006ooooo`;o0000
00?oooooo`000?l000004Oooool2o`000003ooooool0003o000000Cooooo0_l0000;ooooo`;o0000
4Oooool2o`0000;ooooo0_l00005ooooo`Co00001?ooool4o`0000;ooooo0_l000000ooooooo0000
o`000002ooooo`;o00000_ooool2o`0000Oooooo0_l00002ooooo`Ko00002Oooool3o`0001_ooooo
0_l0000Dooooo`?o00000oooool2o`0000Kooooo0_l000000ooooooo0000o`000003ooooo`;o0000
1?ooool2o`0000cooooo0_l00009ooooo`;o00005oooool002Wooooo00?o0000ooooooooool00_oo
ool2o`00013ooooo0_l0000?ooooo`?o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00003ooo
ool2o`0000?ooooo0_l00006ooooo`;o00001oooool2o`0000_ooooo0_l0000>ooooo`;o000000?o
ooooo`000?l000000_ooool2o`000003ooooool0003o000000;ooooo1?l00006ooooo`;o00002Ooo
ool2o`000003ooooool0003o000000;ooooo0_l00008ooooo`;o00000_ooool2o`0001gooooo0_l0
0008ooooo`;o00004Oooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`00
0006ooooo`;o00005oooool2o`0000Wooooo0_l0000Gooooo`00:Oooool2o`0000?ooooo0_l00009
ooooo`;o00001Oooool2o`0001Cooooo0_l00003ooooo`;o00004oooool2o`0000?ooooo0_l0000L
ooooo`?o00003Oooool2o`0000Sooooo0_l0000Gooooo`;o000000Coooooo`000?l0003ooooo0ol0
000Pooooo`;o00002Oooool2o`0000;ooooo0_l0000Gooooo`;o00002_ooool2o`00027ooooo0_l0
000:ooooo`Co00004_ooool002Wooooo00Co0000ooooool0003o00003?ooool2o`0004Wooooo0_l0
000<ooooo`Co0000=_ooool2o`0000Kooooo0_l0000Iooooo`;o00003Oooool2o`0004Kooooo0_l0
000:ooooo`Co00004_ooool002Wooooo00Co0000ooooool0003o00001Oooool2o`0002Sooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0_ooool2o`000004oc8b<_l0003o<S8b
onk^kQCooooo0_l0000<ooooo`;o00001Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06Oooool2o`0000Sooooo0_l000002?oooooo0000
o`000?nHV9So410@o`000?lb<S;oc<c<0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0Jooooo`;o00003_ooool2o`000009oa0@4?ooooooooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Aooooo`;o00005_oo
ool01?m4A4Co0000o`000?lb<S82o`000006ooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Yooooo`03o`000?oooooooooo00Gooooo0ol0000Zoooo
o`?o00000_ooool01OmgMgOo0000o`000?nHV9SoMgMg00;ooooo1?l000000onHV9SoMgMgooooo`0X
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0Iooooo`;o00002?ooool2o`0000?ooooo00Go410@okZj^_oo
ooooMgMgoc8b<P03ooooo`04ogMgMonHV9SooooooiRHV0?o000000KoooooogMgMonHV9SooooooiRH
V?mgMgLAooooo`;o00001oooool2o`0000oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`;o00002Oooool2o`00
01Wooooo00WoMgMgo`000?l0003oooooogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo000Yooooo`03o`000?oooooooooo00Gooooo0_l0000[ooooo`?o0000
0_ooool01Ol@413o0000o`000?oooooo410@00?ooooo00Go410@o`000?l0003ooooooa0@400Doooo
o`;o00004oooool2o`000003ob4Q8Oo^k^kooooo00?ooooo00Go410@oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@41002Oooool2o`0001Kooooo0_l00009ooooo`05o`000?oo
ooooooooooooool@41000oooool3o`000003ooooool@413ooooo00;ooooo00?o410@ooooooooool0
1oooool2o`0000Kooooo0_l0000Eooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@ooooool0003o0000oa0@4006ooooo`;o00003_ooool2o`0001Gooooo00Co0000oooo
oooooooo410@0oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool00Ooo
ool002Wooooo0_l0000cooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooo000000;o00005?ooool2o`0001?ooooo0_l000000onHV9So8B4Qonk^
kP03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Oo
oooo1?l0000;ooooo`;o00002Oooool2o`0000Sooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000009ooooo`;o00007Oooool0
1?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
o`000004o`0001Cooooo0_l0000Dooooo`05ogMgMolb<S;oooooooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool00Oooool002Wooooo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooo`000002o`0002cooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooool000000_l00007ooooo`;o00003Oooool2o`0000gooooo0_l00003
ooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000006Oooool2o`0000Cooooo0_l00007ooooo`04omgMgOmEEEGoooooo`0000Co
oooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooooooo`?o00009oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000oooool002Wooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@
02gooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00;o000000Cooooo
o`000?l0003o410@2oooool2o`0000Gooooo0_l0000Aooooo`;o00001?ooool00onj^[[o0000o`00
0002ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Go
oooo0_l0000Booooo`;o00001?ooool2o`0000Sooooo00?oMgMgolc<c?l000001?ooool01Ol@413o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`;o00002oooool2
o`0001Oooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@4003ooooo`00:Oooool00ol0003oooooooooo`0/ooooo`;o00001?oo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg02Wooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00_ooool2o`000004oiRHV?ooooooV9RHogMgM`;o00002Oooool2o`0000Gooooo0_l0
000?ooooo`;o00000oooool01?l@413oV9RHoooooonj^[X2o`0000;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0002;ooooo00?ok^k^odA4
A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`;o00002oooool2o`0001Oooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool00ol0003ooooo
ooooo`0Pooooo`;o00002_ooool2o`0000;ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Yooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP02o`00023ooooo0ol00003ooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Zooooo`03ogMgMol0003o
oooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_l0003o0000o`000?o^k^h0
8?ooool2o`000003ooooool0003o000000Cooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Yooooo`;o00008Oooool2o`0008;o
oooo0_l0000[ooooo`;o000000?oooooo`000?l000008_ooool3o`0000Kooooo0_l0000Iooooo`;o
000000?oooooo`000?l000006oooool002Wooooo00?o0000ooooooooool07_ooool2o`0002cooooo
1?l0000Nooooo`;o00000oooool2o`00053ooooo0_l0000:ooooo`;o000000?oooooo`000?l00000
:oooool2o`0000Gooooo0_l0000booooo`00:Oooool3o`0001kooooo0_l0000Aooooo`;o00000ooo
ool2o`0001Cooooo1?l00004ooooo`;o00006?ooool2o`0000?ooooo0_l0001@ooooo`;o00006_oo
ool2o`00017ooooo0_l0000Booooo`;o00001_ooool2o`0002[ooooo000Yooooo`?o0000<Oooool2
o`0000?ooooo0_l0000Looooo`;o00005Oooool2o`0000_ooooo0ol00002ooooo`;o00004oooool2
o`0002Oooooo0_l0000>ooooo`;o00005?ooool2o`00017ooooo0_l0000<ooooo`Co000000?ooooo
o`000?l000001Oooool4o`0002[ooooo000Yooooo`03o`000?oooooooooo01;ooooo0_l0000?oooo
o`;o00002oooool2o`0002?ooooo0_l0000Dooooo`;o00002oooool3o`0000;ooooo0_l0000Coooo
o`;o00002oooool2o`0001[ooooo1?l0000:ooooo`Co0000=Oooool4o`000003ooooool0003o0000
00Gooooo0ol00006ooooo`;o00002?ooool3o`0001Sooooo000Qoooooooo0000A?l00004ooooo`00
:Oooool00ol0003oooooooooo`07ooooo`?o00003?ooool4o`0000Oooooo0_l00008ooooo`;o0000
00?oooooo`000?ooool01Oooool2o`0000?ooooo00?o0000ooooooooool00_ooool2o`0000Kooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02Oooool2o`0000_ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo0_l00005ooooo`;o00001?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooooooo0_l00005ooooo`;o
00003?ooool00ol0003oooooooooo`03ooooo`?o00000oooool00ol0003oooooooooo`09ooooo`04
o`000?oooooo0000o`0000Sooooo00?o0000ooooooooool02_ooool002Wooooo00Co0000oooooooo
oooooooo0_l00004ooooo`;o00003Oooool4o`00017ooooo1?l0000;ooooo`03o`000?oooooooooo
03Cooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`;o00001?ooool2o`00
0003ooooool0003o000000kooooo0_l0000Gooooo`03o`000?oooooooooo00Kooooo0_l000000ooo
oooo0000o`00000Oooooo`;o00003_ooool2o`0000;ooooo0_l0000Iooooo`;o00004_ooool2o`00
00Sooooo00?o0000ooooooooool02_ooool002Wooooo00?o0000ooooooooool00ol0000Cooooo`;o
00005Oooool2o`0004;ooooo0_l0000:ooooo`;o00001?ooool2o`0000Cooooo0_l000000ooooooo
0000o`00000Uooooo`;o00002Oooool2o`000003ooooool0003o000000?ooooo0ol00003ooooo`;o
00005?ooool2o`0000Kooooo1?l00004ooooo`;o0000<Oooool2o`0000Cooooo0_l0000?ooooo`00
:Oooool00ol0003oooooooooo`02o`0002Kooooo0_l0000Booooo`;o00007Oooool2o`0001cooooo
0_l0000Dooooo`;o00001oooool2o`0001?ooooo0_l00004ooooo`;o00004Oooool3o`0000;ooooo
0ol0000@ooooo`Co00002?ooool6o`0001cooooo0_l00006ooooo`;o00003Oooool2o`0000Gooooo
0ol0000?ooooo`00:Oooool2o`0001Sooooo0_l0000?ooooo`;o00004_ooool2o`0000Gooooo0_l0
000:ooooo`;o00002_ooool2o`0001cooooo0_l0000Dooooo`;o00001?ooool2o`000003ooooool0
003o0000013ooooo0_l000000ooooooo0000o`00000Looooo`;o00004Oooool4o`0000;ooooo0_l0
0008ooooo`;o00007?ooool2o`0000Kooooo0_l0000=ooooo`;o00001Oooool2o`00013ooooo000Y
ooooo`03o`000?oooooooooo01Oooooo0_l0000Zooooo`;o00002_ooool2o`0002_ooooo0_l0000G
ooooo`;o00004oooool2o`0003Sooooo0_l00015ooooo`;o00003oooool002Wooooo00?o0000oooo
ooooool0O?ooool2o`000003ooooool0003o000003oooooo0_l0001Cooooo`;o00001Oooool2o`00
0003ooooool0003o000000?ooooo0_l00005ooooo`;o00003oooool002Wooooo00?o0000oooooooo
ool01oooool2o`0001Cooooo0_l0001Pooooo`;o0000?oooool2o`0005?ooooo0_l00005ooooo`;o
000000?oooooo`000?l000000oooool2o`0001Kooooo000Yooooo`;o00001Oooool2o`000003oooo
ool0003o000001Cooooo0_l0000Nooooo`;o0000_oooool2o`0000Kooooo0_l00008ooooo`;o0000
0oooool2o`0002Gooooo000Yooooo`;o00001Oooool2o`0000_ooooo0_l0000Zooooo`;o00007?oo
ool2o`0004cooooo0_l0000nooooo`;o00004oooool2o`0000Kooooo0_l00008ooooo`;o00004?oo
ool2o`0001Sooooo000Yooooo`;o00004_ooool2o`0003?ooooo0_l0000Cooooo`;o00009oooool2
o`0002?ooooo0_l0000nooooo`;o0000=Oooool4o`0001Sooooo000Yooooo`;o0000Aoooool2o`00
03cooooo0_l0000fooooo`;o00003?ooool2o`00057ooooo0_l000000ooooooo0000o`00000Joooo
o`00:Oooool00ol0003oooooooooo`0;ooooo`;o0000[oooool2o`000003ooooool0003o000000Wo
oooo0_l000000ooooooo0000o`00000Rooooo`;o0000:_ooool2o`0001gooooo000Yooooo`03o`00
0?oooooooooo00_ooooo0_l0000]ooooo`;o00008?ooool2o`0000Cooooo0_l0000looooo`Co0000
6oooool2o`0000cooooo0_l0000Dooooo`;o00003?ooool2o`0004Wooooo000Yooooo`;o0000>ooo
ool2o`00023ooooo0_l00004ooooo`;o00001_ooool2o`0003Cooooo1?l0000Dooooo`;o00000ooo
ool2o`0002Cooooo0_l00013ooooo`;o00004_ooool002Wooooo00?o0000ooooooooool0J_ooool2
o`0002Cooooo0_l0000Sooooo`;o000000?oooooo`000?l000000oooool2o`0006Wooooo0_l0000B
ooooo`00:Oooool00ol0003oooooooooo`0?ooooo`;o0000??ooool2o`00047ooooo0_l0000Soooo
o`;o0000QOooool002Wooooo00?o0000ooooooooool02Oooool2o`0000Cooooo0_l0000Fooooo`;o
00009?ooool2o`0002?ooooo0_l0000jooooo`;o0000?Oooool2o`0004gooooo000Yooooo`03o`00
0?oooooooooo00Wooooo0ol0000Kooooo`;o00001Oooool2o`0001Wooooo0_l0000;ooooo`;o0000
2oooool2o`0000gooooo0_l00007ooooo`;o0000<Oooool2o`0003gooooo0_l0000Dooooo`;o0000
=oooool002Wooooo0_l0000;ooooo`;o00008_ooool2o`0001Sooooo0ol0000;ooooo`;o00002ooo
ool2o`0001Kooooo0_l00004ooooo`;o00000oooool2o`0000[ooooo0_l00017ooooo`;o00009_oo
ool2o`0003Oooooo000Yooooo`03o`000?oooooooooo00Wooooo0_l0000eooooo`;o00001_ooool2
o`0003Oooooo0_l00003ooooo`;o00002_ooool2o`0004Oooooo0_l0001Oooooo`001_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool02Oooool2o`0003Gooooo1?l00007ooooo`Co000000?o
ooooo`000?l000004_ooool2o`0001[ooooo0_l0001>ooooo`;o0000J_ooool000Kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0>ooooo`;o0000;Oooool2o`0000?ooooo
0_l00007ooooo`Co000000?oooooo`000?l000004_ooool2o`0001[ooooo0_l0000>ooooo`;o0000
?_ooool2o`000003ooooool0003o000001;ooooo0_l0001Cooooo`001_ooool01Ol@413ooooooooo
oooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00kooooo0_l0000]ooooo`;o0000;Oooool2o`0002;ooooo0_l00011ooooo`;o0000
4_ooool2o`0005?ooooo0006ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Q
onk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0001:ooooo`;o00001Oooool2o`0000gooooo
0_l00003ooooo`;o00001Oooool2o`0009cooooo0_l00008ooooo`;o00001oooool2o`0001gooooo
0006ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0:ooooo`;o0000?_ooool2o`0000Go
oooo0_l0000=ooooo`;o00000oooool2o`0006cooooo0_l0000Aooooo`;o00008_ooool2o`0000So
oooo1?l00005ooooo`;o00003oooool2o`0000cooooo0006ooooo`05oa0@4?ooooooooooooooool@
41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02_ooool2o`00027ooooo0_l0000Iooooo`;o00001_ooool2o`0001Wooooo0_l0000mooooo`;o
00009oooool2o`00017ooooo0_l0000^ooooo`;o00005_ooool2o`0000cooooo0006ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0?ooooo`;o00007?ooool2o`0001Wooooo0_l00006oooo
o`;o00006Oooool2o`0003Kooooo0_l00005ooooo`;o0000:_ooool2o`0000Wooooo0_l0001Ioooo
o`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004
ooooo`Co00001_ooool00ol0003oooooooooo`0?ooooo`;o00002oooool2o`0008Gooooo0_l00000
0ooooooo0000o`00000^ooooo`;o00002Oooool2o`0005Wooooo000Yooooo`;o00007?ooool3o`00
013ooooo0_l0000_ooooo`;o0000AOooool2o`0000Sooooo0_l0000Uooooo`;o00008_ooool2o`00
013ooooo0_l00008ooooo`;o00000_ooool2o`0001oooooo000Yooooo`03o`000?oooooooooo01;o
oooo0_l00007ooooo`;o00004Oooool2o`0002cooooo0_l000000ooooooo0000o`000002o`0002Co
oooo0_l0000Fooooo`;o00003oooool2o`000003ooooool0003o000002;ooooo1?l0000Pooooo`;o
00004?ooool2o`0000Sooooo0_l00002ooooo`;o00004?ooool2o`0000gooooo000Yooooo`03o`00
0?oooooooooo01;ooooo1?l00016ooooo`;o00000oooool2o`0000?ooooo0_l0000Oooooo`;o0000
5_ooool2o`000003ooooool0003o000000oooooo0_l0000Tooooo`;o0000D_ooool2o`0000gooooo
000Yooooo`03o`000?oooooooooo01Cooooo0_l0000_ooooo`;o00005_ooool2o`0000Oooooo0_l0
000_ooooo`;o00002Oooool2o`0004cooooo0_l0001:ooooo`00:Oooool01?l0003ooooooooooooo
ool2o`00013ooooo0_l00005ooooo`;o00001?ooool2o`000003ooooool0003o000000Gooooo0_l0
000Iooooo`;o00003oooool2o`0000Gooooo0_l0000hooooo`;o00001?ooool2o`0004Gooooo0_l0
000:ooooo`;o0000B_ooool002Wooooo0_l00002ooooo`;o00004?ooool2o`0000Gooooo0_l00004
ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Cooooo0_l0000Cooooo`;o00003oooool2
o`0000_ooooo0_l0000;ooooo`;o00000_ooool2o`0001oooooo0_l00006ooooo`;o00009_ooool2
o`0001gooooo0_l0000]ooooo`;o00009oooool002Wooooo00?o0000ooooooooool07?ooool2o`00
01;ooooo0_l0000Cooooo`;o00005oooool2o`0000?ooooo0_l0000;ooooo`;o00000_ooool2o`00
01kooooo0ol00002ooooo`;o00003Oooool2o`000003ooooool0003o000000Cooooo0_l0000Boooo
o`;o000000?oooooo`000?l000006oooool2o`0002cooooo0_l00004ooooo`;o00008Oooool002Wo
oooo00?o0000ooooooooool07?ooool2o`000003ooooool0003o000002Gooooo0_l0000Fooooo`;o
00009?ooool3o`0000gooooo0_l00003ooooo`;o00003Oooool2o`000003ooooool0003o000000Co
oooo0_l00005ooooo`;o00003_ooool3o`0001[ooooo0_l0000?ooooo`;o00008Oooool2o`00027o
oooo000Yooooo`03o`000?oooooooooo013ooooo0_l0000=ooooo`;o00001?ooool2o`0001oooooo
0_l0000Iooooo`;o00008Oooool3o`0002_ooooo0_l00004ooooo`Co00003Oooool2o`0001Cooooo
0_l00008ooooo`;o00002oooool2o`0002oooooo0_l0000Cooooo`00:Oooool00ol0003ooooooooo
o`0@ooooo`;o00000oooool2o`0000kooooo0_l0000Aooooo`;o00001oooool2o`0001kooooo0_l0
000>ooooo`;o0000:Oooool2o`0001Cooooo0_l00006ooooo`;o00008oooool2o`0000;ooooo0_l0
0004ooooo`;o0000??ooool2o`0000?ooooo0_l0000>ooooo`00:Oooool2o`0000?ooooo0_l0000<
ooooo`;o00000oooool2o`0000Sooooo0_l0000Gooooo`;o00001oooool2o`0002kooooo0_l0000?
ooooo`;o00006?ooool2o`0003Sooooo0_l0000;ooooo`;o00001oooool2o`0003kooooo0_l0000>
ooooo`00:Oooool00ol0003oooooooooo`02ooooo`Co00006Oooool2o`0004_ooooo0_l000000ooo
oooo0000o`00000Aooooo`;o0000COooool2o`0000?ooooo0_l00002ooooo`;o00004?ooool2o`00
00Cooooo0_l00003ooooo`;o00002?ooool2o`0000Kooooo0_l0000Tooooo`;o00002oooool002Wo
oooo00?o0000ooooooooool01?ooool2o`0001kooooo0_l0000/ooooo`;o00005Oooool2o`000004
ooooool0003o0000ooooo`;o0000>oooool2o`0001?ooooo0_l0000>ooooo`;o00001oooool5o`00
01?ooooo0_l00003ooooo`;o00002?ooool2o`0000Kooooo0_l0000Tooooo`;o00002oooool002Wo
oooo00?o0000ooooooooool09?ooool2o`0001Gooooo0_l0000Aooooo`;o00000_ooool2o`0001Go
oooo0_l0000;ooooo`;o0000=?ooool2o`0001;ooooo0ol0000Iooooo`?o0000>oooool2o`00023o
oooo000Yooooo`03o`000?oooooooooo00Gooooo0_l0000>ooooo`;o00009?ooool2o`00017ooooo
0_l00003ooooo`;o00001?ooool2o`0001[ooooo0ol0000Booooo`;o00002oooool2o`0001Wooooo
0_l000000ooooooo0000o`000007ooooo`Co00006_ooool2o`000003ooooool0003o000002Sooooo
0_l0000?ooooo`;o00008?ooool002Wooooo0_l00006ooooo`;o00003_ooool2o`0001gooooo0_l0
000Mooooo`;o00001?ooool2o`0001?ooooo0_l00005ooooo`;o00004oooool2o`0000_ooooo0_l0
000Iooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l0000Oooooo`;o00001_oo
ool2o`00017ooooo0_l0000=ooooo`;o0000<Oooool002Wooooo00?o0000ooooooooool03?ooool2
o`0002Kooooo0_l0000hooooo`;o0000BOooool2o`0002cooooo0_l0000Aooooo`;o00001?ooool2
o`0003[ooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00cooooo0_l0001Tooooo`;o00005_oo
ool2o`0003Kooooo0_l0000Wooooo`;o00004oooool2o`0000?ooooo0_l0000eooooo`003_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0Aoooool2o`0002Wooooo0_l0000Fooooo`;o00000_ooool2o`0002Cooooo0_l0
000<ooooo`;o00009oooool2o`0000Cooooo0_l0000Booooo`;o00006Oooool2o`0001[ooooo000>
ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`?o00008_oo
ool2o`0002?ooooo0_l0000:ooooo`;o00007oooool2o`0001Sooooo0_l000000ooooooo0000o`00
000Qooooo`;o00007oooool2o`0001[ooooo0_l0000]ooooo`;o00006_ooool000kooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool08_oo
ool2o`0002oooooo0_l0000Oooooo`;o00006oooool2o`0004;ooooo0_l0001Uooooo`003_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo06oooooo0_l0000oooooo`;o00004Oooool2o`0001Kooooo0_l0001Oooooo`003_oo
ool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0eooooo`;o00005?ooool2o`0001cooooo0_l00004ooooo`;o00006oooool2o`0002;ooooo
0_l0000Aooooo`;o00005_ooool2o`0003_ooooo0_l0000Rooooo`003_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0eooooo`Co0000
4_ooool2o`0001cooooo0_l0000Qooooo`;o0000IOooool2o`00013ooooo0_l00008ooooo`;o0000
1oooool2o`0002;ooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo
0_l0000Nooooo`;o00003?ooool2o`0000[ooooo1?l0000looooo`;o000000?oooooo`000?l00000
Moooool2o`00013ooooo0_l00008ooooo`;o0000:oooool002Wooooo00?o0000ooooooooool07Ooo
ool2o`0000cooooo0_l0000<ooooo`;o00002?ooool2o`0003;ooooo0_l000000ooooooo0000o`00
001Cooooo`;o0000=_ooool2o`0000;ooooo0_l0000_ooooo`00:Oooool00ol0003oooooooooo`13
ooooo`;o00004_ooool2o`0005gooooo0_l0000Gooooo`;o00005oooool2o`0001gooooo0_l00002
ooooo`;o00007Oooool2o`00013ooooo000Yooooo`03o`000?oooooooooo05Oooooo0_l0001Moooo
o`;o0000<?ooool2o`00043ooooo0_l0000@ooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmE
EEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000Kooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_oo
ool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMg
ooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Oooooo`Co000000?o410@ooooooooool00oooool0
0ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`?o0000oooooolmooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Oooooo`03oeEEEOmVIVKo00000?ooooooAoooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .25724 Mdot
.02762 .24911 Mdot
.02952 .27511 Mdot
.03143 .32061 Mdot
.03333 .30137 Mdot
.03524 .24301 Mdot
.03714 .3077 Mdot
.03905 .335 Mdot
.04095 .38924 Mdot
.04286 .31983 Mdot
.04476 .30576 Mdot
.04667 .38015 Mdot
.04857 .24417 Mdot
.05048 .33499 Mdot
.05238 .42239 Mdot
.05429 .32646 Mdot
.05619 .24558 Mdot
.0581 .24351 Mdot
.06 .31401 Mdot
.0619 .26573 Mdot
.06381 .28896 Mdot
.06571 .28251 Mdot
.06762 .32615 Mdot
.06952 .25454 Mdot
.07143 .42396 Mdot
.07333 .30252 Mdot
.07524 .27565 Mdot
.07714 .28943 Mdot
.07905 .28829 Mdot
.08095 .27421 Mdot
.08286 .33656 Mdot
.08476 .36989 Mdot
.08667 .37115 Mdot
.08857 .26108 Mdot
.09048 .24254 Mdot
.09238 .34625 Mdot
.09429 .35429 Mdot
.09619 .2789 Mdot
.0981 .3484 Mdot
.1 .3612 Mdot
.1019 .39945 Mdot
.10381 .24517 Mdot
.10571 .2475 Mdot
.10762 .23801 Mdot
.10952 .23908 Mdot
.11143 .30459 Mdot
.11333 .29787 Mdot
.11524 .34367 Mdot
.11714 .2822 Mdot
.11905 .3321 Mdot
.12095 .35414 Mdot
.12286 .32266 Mdot
.12476 .47603 Mdot
.12667 .25417 Mdot
.12857 .24201 Mdot
.13048 .38546 Mdot
.13238 .34977 Mdot
.13429 .24576 Mdot
.13619 .34677 Mdot
.1381 .23897 Mdot
.14 .28797 Mdot
.1419 .42637 Mdot
.14381 .36445 Mdot
.14571 .33625 Mdot
.14762 .41002 Mdot
.14952 .36829 Mdot
.15143 .31042 Mdot
.15333 .30527 Mdot
.15524 .30325 Mdot
.15714 .27241 Mdot
.15905 .27254 Mdot
.16095 .30369 Mdot
.16286 .29984 Mdot
.16476 .31825 Mdot
.16667 .36482 Mdot
.16857 .28225 Mdot
.17048 .47616 Mdot
.17238 .25116 Mdot
.17429 .3141 Mdot
.17619 .24937 Mdot
.1781 .34203 Mdot
.18 .28533 Mdot
.1819 .31187 Mdot
.18381 .24304 Mdot
.18571 .34008 Mdot
.18762 .34273 Mdot
.18952 .30219 Mdot
.19143 .26195 Mdot
.19333 .25551 Mdot
.19524 .29999 Mdot
.19714 .42919 Mdot
.19905 .46242 Mdot
.20095 .33846 Mdot
.20286 .29529 Mdot
.20476 .33647 Mdot
.20667 .45376 Mdot
.20857 .3339 Mdot
.21048 .38189 Mdot
.21238 .47647 Mdot
.21429 .27668 Mdot
.21619 .26685 Mdot
.2181 .27178 Mdot
.22 .39708 Mdot
.2219 .24108 Mdot
.22381 .29972 Mdot
.22571 .26019 Mdot
.22762 .25469 Mdot
.22952 .31742 Mdot
.23143 .33863 Mdot
.23333 .28723 Mdot
.23524 .33311 Mdot
.23714 .33206 Mdot
.23905 .37461 Mdot
.24095 .29059 Mdot
.24286 .48945 Mdot
.24476 .32048 Mdot
.24667 .27086 Mdot
.24857 .33423 Mdot
.25048 .34438 Mdot
.25238 .38181 Mdot
.25429 .25137 Mdot
.25619 .41321 Mdot
.2581 .33497 Mdot
.26 .27641 Mdot
.2619 .27917 Mdot
.26381 .31188 Mdot
.26571 .30724 Mdot
.26762 .44994 Mdot
.26952 .30763 Mdot
.27143 .32895 Mdot
.27333 .29808 Mdot
.27524 .27918 Mdot
.27714 .39352 Mdot
.27905 .24037 Mdot
.28095 .24659 Mdot
.28286 .28677 Mdot
.28476 .30814 Mdot
.28667 .3035 Mdot
.28857 .29585 Mdot
.29048 .38951 Mdot
.29238 .4168 Mdot
.29429 .45 Mdot
.29619 .33822 Mdot
.2981 .31408 Mdot
.3 .24486 Mdot
.3019 .27242 Mdot
.30381 .33795 Mdot
.30571 .49413 Mdot
.30762 .26007 Mdot
.30952 .26515 Mdot
.31143 .38306 Mdot
.31333 .28094 Mdot
.31524 .31956 Mdot
.31714 .24711 Mdot
.31905 .29996 Mdot
.32095 .27005 Mdot
.32286 .33175 Mdot
.32476 .34939 Mdot
.32667 .35259 Mdot
.32857 .36504 Mdot
.33048 .32611 Mdot
.33238 .29503 Mdot
.33429 .29844 Mdot
.33619 .35252 Mdot
.3381 .35265 Mdot
.34 .27341 Mdot
.3419 .29094 Mdot
.34381 .3436 Mdot
.34571 .29255 Mdot
.34762 .30041 Mdot
.34952 .29849 Mdot
.35143 .35117 Mdot
.35333 .31991 Mdot
.35524 .28387 Mdot
.35714 .2743 Mdot
.35905 .27251 Mdot
.36095 .39198 Mdot
.36286 .45356 Mdot
.36476 .27418 Mdot
.36667 .32746 Mdot
.36857 .31592 Mdot
.37048 .29008 Mdot
.37238 .37325 Mdot
.37429 .33218 Mdot
.37619 .39971 Mdot
.3781 .33033 Mdot
.38 .39937 Mdot
.3819 .45408 Mdot
.38381 .34403 Mdot
.38571 .35758 Mdot
.38762 .24263 Mdot
.38952 .41013 Mdot
.39143 .26774 Mdot
.39333 .33377 Mdot
.39524 .43415 Mdot
.39714 .34214 Mdot
.39905 .38563 Mdot
.40095 .39398 Mdot
.40286 .28879 Mdot
.40476 .45837 Mdot
.40667 .26245 Mdot
.40857 .32627 Mdot
.41048 .32645 Mdot
.41238 .30559 Mdot
.41429 .27597 Mdot
.41619 .46197 Mdot
.4181 .28876 Mdot
.42 .3288 Mdot
.4219 .24733 Mdot
.42381 .34036 Mdot
.42571 .3321 Mdot
.42762 .31798 Mdot
.42952 .2427 Mdot
.43143 .25378 Mdot
.43333 .2952 Mdot
.43524 .31714 Mdot
.43714 .29565 Mdot
.43905 .25139 Mdot
.44095 .35983 Mdot
.44286 .33115 Mdot
.44476 .25717 Mdot
.44667 .35028 Mdot
.44857 .2759 Mdot
.45048 .37425 Mdot
.45238 .28324 Mdot
.45429 .35312 Mdot
.45619 .2969 Mdot
.4581 .29535 Mdot
.46 .23748 Mdot
.4619 .32956 Mdot
.46381 .42147 Mdot
.46571 .40445 Mdot
.46762 .33071 Mdot
.46952 .2909 Mdot
.47143 .46905 Mdot
.47333 .24989 Mdot
.47524 .2981 Mdot
.47714 .41735 Mdot
.47905 .2851 Mdot
.48095 .24051 Mdot
.48286 .30262 Mdot
.48476 .27368 Mdot
.48667 .43097 Mdot
.48857 .24065 Mdot
.49048 .28303 Mdot
.49238 .27215 Mdot
.49429 .35154 Mdot
.49619 .33153 Mdot
.4981 .36086 Mdot
.5 .25147 Mdot
.5019 .27388 Mdot
.50381 .35533 Mdot
.50571 .39171 Mdot
.50762 .32157 Mdot
.50952 .32737 Mdot
.51143 .37122 Mdot
.51333 .27246 Mdot
.51524 .28023 Mdot
.51714 .25237 Mdot
.51905 .2828 Mdot
.52095 .36552 Mdot
.52286 .3427 Mdot
.52476 .26608 Mdot
.52667 .29926 Mdot
.52857 .35058 Mdot
.53048 .32892 Mdot
.53238 .26385 Mdot
.53429 .26943 Mdot
.53619 .28346 Mdot
.5381 .27254 Mdot
.54 .3533 Mdot
.5419 .25494 Mdot
.54381 .32196 Mdot
.54571 .24336 Mdot
.54762 .33072 Mdot
.54952 .24879 Mdot
.55143 .32228 Mdot
.55333 .3376 Mdot
.55524 .32248 Mdot
.55714 .36006 Mdot
.55905 .33011 Mdot
.56095 .25516 Mdot
.56286 .31036 Mdot
.56476 .3252 Mdot
.56667 .30162 Mdot
.56857 .37113 Mdot
.57048 .38943 Mdot
.57238 .32092 Mdot
.57429 .30211 Mdot
.57619 .25454 Mdot
.5781 .26993 Mdot
.58 .27395 Mdot
.5819 .34581 Mdot
.58381 .45611 Mdot
.58571 .36233 Mdot
.58762 .41453 Mdot
.58952 .38036 Mdot
.59143 .28843 Mdot
.59333 .32833 Mdot
.59524 .44068 Mdot
.59714 .26262 Mdot
.59905 .42084 Mdot
.60095 .49639 Mdot
.60286 .25726 Mdot
.60476 .25035 Mdot
.60667 .26834 Mdot
.60857 .3597 Mdot
.61048 .41155 Mdot
.61238 .30536 Mdot
.61429 .36925 Mdot
.61619 .27533 Mdot
.6181 .32514 Mdot
.62 .2547 Mdot
.6219 .24469 Mdot
.62381 .26201 Mdot
.62571 .38509 Mdot
.62762 .32579 Mdot
.62952 .26266 Mdot
.63143 .25378 Mdot
.63333 .41138 Mdot
.63524 .32727 Mdot
.63714 .38028 Mdot
.63905 .43363 Mdot
.64095 .44082 Mdot
.64286 .3173 Mdot
.64476 .24399 Mdot
.64667 .24331 Mdot
.64857 .36658 Mdot
.65048 .31498 Mdot
.65238 .32062 Mdot
.65429 .29948 Mdot
.65619 .25181 Mdot
.6581 .34419 Mdot
.66 .38137 Mdot
.6619 .33767 Mdot
.66381 .25427 Mdot
.66571 .33005 Mdot
.66762 .30787 Mdot
.66952 .23832 Mdot
.67143 .2409 Mdot
.67333 .2722 Mdot
.67524 .29123 Mdot
.67714 .27214 Mdot
.67905 .47056 Mdot
.68095 .25756 Mdot
.68286 .30293 Mdot
.68476 .33361 Mdot
.68667 .38341 Mdot
.68857 .27338 Mdot
.69048 .30871 Mdot
.69238 .31174 Mdot
.69429 .33969 Mdot
.69619 .25037 Mdot
.6981 .44808 Mdot
.7 .37046 Mdot
.7019 .31062 Mdot
.70381 .34084 Mdot
.70571 .27046 Mdot
.70762 .24847 Mdot
.70952 .3428 Mdot
.71143 .25703 Mdot
.71333 .37343 Mdot
.71524 .42976 Mdot
.71714 .2829 Mdot
.71905 .39667 Mdot
.72095 .3827 Mdot
.72286 .37969 Mdot
.72476 .31123 Mdot
.72667 .25101 Mdot
.72857 .42013 Mdot
.73048 .35643 Mdot
.73238 .3114 Mdot
.73429 .33466 Mdot
.73619 .248 Mdot
.7381 .24108 Mdot
.74 .26523 Mdot
.7419 .38512 Mdot
.74381 .24201 Mdot
.74571 .34891 Mdot
.74762 .38074 Mdot
.74952 .32861 Mdot
.75143 .30023 Mdot
.75333 .30647 Mdot
.75524 .42044 Mdot
.75714 .49056 Mdot
.75905 .3873 Mdot
.76095 .25446 Mdot
.76286 .3119 Mdot
.76476 .42524 Mdot
.76667 .26591 Mdot
.76857 .29887 Mdot
.77048 .36506 Mdot
.77238 .27375 Mdot
.77429 .31662 Mdot
.77619 .31438 Mdot
.7781 .28553 Mdot
.78 .2939 Mdot
.7819 .33915 Mdot
.78381 .25459 Mdot
.78571 .43831 Mdot
.78762 .37351 Mdot
.78952 .24576 Mdot
.79143 .47369 Mdot
.79333 .24381 Mdot
.79524 .27873 Mdot
.79714 .29594 Mdot
.79905 .27998 Mdot
.80095 .35295 Mdot
.80286 .38135 Mdot
.80476 .27734 Mdot
.80667 .33507 Mdot
.80857 .33777 Mdot
.81048 .34062 Mdot
.81238 .39127 Mdot
.81429 .30999 Mdot
.81619 .33951 Mdot
.8181 .33082 Mdot
.82 .31333 Mdot
.8219 .32918 Mdot
.82381 .30317 Mdot
.82571 .26092 Mdot
.82762 .3178 Mdot
.82952 .32905 Mdot
.83143 .40004 Mdot
.83333 .38622 Mdot
.83524 .27658 Mdot
.83714 .24232 Mdot
.83905 .25378 Mdot
.84095 .294 Mdot
.84286 .24778 Mdot
.84476 .29544 Mdot
.84667 .41794 Mdot
.84857 .44896 Mdot
.85048 .24989 Mdot
.85238 .48601 Mdot
.85429 .23758 Mdot
.85619 .33324 Mdot
.8581 .40525 Mdot
.86 .42289 Mdot
.8619 .29163 Mdot
.86381 .32402 Mdot
.86571 .47246 Mdot
.86762 .33327 Mdot
.86952 .31677 Mdot
.87143 .26497 Mdot
.87333 .34099 Mdot
.87524 .2472 Mdot
.87714 .46047 Mdot
.87905 .33186 Mdot
.88095 .25742 Mdot
.88286 .24313 Mdot
.88476 .33758 Mdot
.88667 .32784 Mdot
.88857 .33331 Mdot
.89048 .3393 Mdot
.89238 .3229 Mdot
.89429 .30242 Mdot
.89619 .24608 Mdot
.8981 .24737 Mdot
.9 .31201 Mdot
.9019 .34766 Mdot
.90381 .24431 Mdot
.90571 .43865 Mdot
.90762 .31616 Mdot
.90952 .34343 Mdot
.91143 .3851 Mdot
.91333 .27544 Mdot
.91524 .32025 Mdot
.91714 .2492 Mdot
.91905 .25444 Mdot
.92095 .30391 Mdot
.92286 .25988 Mdot
.92476 .30559 Mdot
.92667 .25121 Mdot
.92857 .25263 Mdot
.93048 .40803 Mdot
.93238 .26167 Mdot
.93429 .27578 Mdot
.93619 .25883 Mdot
.9381 .24708 Mdot
.94 .30272 Mdot
.9419 .30279 Mdot
.94381 .25051 Mdot
.94571 .24133 Mdot
.94762 .32498 Mdot
.94952 .26459 Mdot
.95143 .36944 Mdot
.95333 .31307 Mdot
.95524 .27159 Mdot
.95714 .33031 Mdot
.95905 .26517 Mdot
.96095 .31369 Mdot
.96286 .48705 Mdot
.96476 .31762 Mdot
.96667 .24257 Mdot
.96857 .39128 Mdot
.97048 .34671 Mdot
.97238 .3031 Mdot
.97429 .30842 Mdot
.97619 .3757 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooocgooooo0006
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol0003oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_oo
ool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05oooool3o`0000Oooooo
0_l0000[ooooo`;o0000>Oooool2o`00047ooooo0_l0000iooooo`;o0000<oooool000Kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00;o00001Oooool2o`0000Wooooo0_l00003ooooo`?o
00001?ooool2o`000003ooooool0003o000000gooooo0_l0000:ooooo`;o00004?ooool2o`00027o
oooo0_l0000<ooooo`;o00002?ooool2o`0000Cooooo0_l000000ooooooo0000o`00000@ooooo`;o
00007oooool2o`0000Gooooo0ol0000Cooooo`Co00007?ooool2o`0000?ooooo0_l00007ooooo`;o
00004oooool2o`0000Cooooo0_l0000?ooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`02o`00
00;ooooo0_l000000ooooooo0000o`000009ooooo`;o00000_ooool2o`0000Kooooo1?l0000>oooo
o`;o00002_ooool2o`00017ooooo0_l00004ooooo`;o00006_ooool2o`0000cooooo0_l0000>oooo
o`;o000000?oooooo`000?l000004?ooool2o`0001Oooooo0_l00005ooooo`?o00001_ooool2o`00
01?ooooo1?l0000<ooooo`Co00003?ooool2o`0000cooooo0_l00003ooooo`Co00003?ooool2o`00
00Cooooo0_l0000?ooooo`00:Oooool2o`0000Gooooo0_l000000ooooooo0000o`00000=ooooo`?o
00001oooool2o`0000_ooooo0_l0000Pooooo`;o00001?ooool2o`0000Cooooo0_l0000Oooooo`;o
00009oooool2o`0001Kooooo0_l00005ooooo`;o00004_ooool2o`0000Oooooo0_l0000?ooooo`Co
00003_ooool2o`0000Sooooo0_l00005ooooo`Co00000oooool2o`0000Cooooo0_l0000Hooooo`00
:Oooool2o`0001Sooooo0_l0000Cooooo`?o00005oooool2o`0001?ooooo0_l0000Oooooo`;o0000
1?ooool2o`0000Wooooo0_l00006ooooo`;o00001?ooool2o`0000Sooooo0_l0000@ooooo`;o0000
3oooool2o`0000[ooooo0_l00002ooooo`;o00001?ooool2o`000003ooooool0003o0000027ooooo
1?l00006ooooo`;o00001Oooool2o`0000Gooooo0_l000001?oooooo0000o`000?ooool4o`0001Ko
oooo000Yooooo`03o`000?oooooooooo00_ooooo0_l0000@ooooo`;o00003Oooool2o`0000Gooooo
0_l00009ooooo`;o00001_ooool2o`0003Oooooo0_l000000ooooooo0000o`000009ooooo`;o0000
1_ooool2o`0000Cooooo0_l00006ooooo`;o00001?ooool2o`0000?ooooo0_l00007ooooo`;o0000
0oooool2o`0000;ooooo0_l00006ooooo`Co00002?ooool2o`0000Sooooo0_l00009ooooo`;o0000
1_ooool2o`0000oooooo0_l00002ooooo`;o00005?ooool2o`000003ooooool0003o000000?ooooo
0_l0000Fooooo`00:Oooool2o`0000cooooo0_l0000@ooooo`;o00005?ooool2o`0000Wooooo0_l0
000oooooo`;o00000oooool2o`0001gooooo0_l00004ooooo`;o00000oooool2o`0000Kooooo0_l0
0004ooooo`;o00000_ooool2o`0000Sooooo0_l00004ooooo`;o00001oooool2o`0000kooooo0_l0
0006ooooo`;o00003oooool2o`0000cooooo0_l0000:ooooo`;o00001?ooool2o`0001Sooooo000Y
ooooo`;o00004_ooool2o`0001oooooo0_l00009ooooo`;o00006Oooool2o`0002[ooooo0_l0000`
ooooo`;o00001Oooool2o`00017ooooo0_l00007ooooo`;o00008oooool2o`00013ooooo0_l0000;
ooooo`;o000000?oooooo`000?l000000_l0000Hooooo`00:Oooool2o`0001;ooooo0_l0000Ooooo
o`;o00002Oooool2o`0001Wooooo0_l0000Mooooo`;o00009oooool2o`0001?ooooo0_l00006oooo
o`Co00008_ooool2o`0001Wooooo0_l0000=ooooo`;o00003_ooool2o`000003ooooool0003o0000
00Cooooo0_l000000ooooooo0000o`00000Aooooo`00:Oooool00ol0003oooooooooo`09ooooo`;o
0000;oooool2o`0001cooooo0_l0000Hooooo`;o00000oooool2o`0002Cooooo0_l000000ooooooo
0000o`00000Cooooo`;o000000?oooooo`000?l000001Oooool2o`0002;ooooo0_l00006ooooo`;o
00008?ooool2o`0001Oooooo0_l000000ooooooo0000o`00000Aooooo`00:Oooool00ol0003ooooo
ooooo`09ooooo`;o00009Oooool4o`000005oa0@4?ooooooooooonk^k_lb<S800ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00_l0000Fooooo`;o00003oooool7o`000006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo0_l000000ooooooo0000
o`000008ooooo`04oiRHV?l@413o0000oc8b<P;o00000_ooool01_o^k^ko<S8bo`000?lb<S;ok^k^
ooooo`;o000000Gok^k^oc8b<_l0003o<S8bonk^kP0Iooooo`;o00003oooool4o`0000;ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool002Wooooo00?o0000ooooooooool03oooool2o`0001Kooooo0ol00008
ooooo`03o`000?oooooooooo00;ooooo00CoMgMgoiRHV?ooooooV9RH0_l00002ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00_l0000@ooooo`;o00001?ooool2o`0000Cooooo0_l00003ooooo`Go0000
00KooooooiRHV?lQ8B7ok^k^oooooom4A4@3ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00kooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo
0_l00004ooooo`Co00001_ooool01?l@413o^[ZjoooooomgMgL3o`000006oooooomgMgOoV9RHoooo
oonHV9SoMgMg0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo0ol00002ooooo`;o00001?oo
ool2o`00013ooooo00?o0000ooooooooool00_l000001OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0/ooooo`;o00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool3o`0000gooooo1?l0000Foooo
o`?o00002?ooool00ol0003oooooooooo`02ooooo`03oa0@4?oooooooooo00?o00000_ooool01Ol@
413ooooooooooooooooo410@00Cooooo0_l0000<ooooo`;o00002_ooool2o`0000?ooooo1Ol00002
ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4002o`000003ooooool@
413ooooo00;ooooo00Co410@oooooooooooooooo0_l00009ooooo`;o000000Coooooo`000?l0003o
oooo0_l00002ooooo`;o00001_ooool2o`0000[ooooo0ol000000ooooooo410@ooooo`02ooooo`05
oa0@4?ooooooooooooooool@41000_l000000ooooooo410@ooooo`0=ooooo`?o00000_ooool2o`00
01?ooooo1Ol000001?oooooo0000o`000?l@4103ooooo`04oa0@4?ooooooooooooooo`;o00000_oo
ool00ol@413oooooooooo`03ooooo`;o00005oooool2o`0000Gooooo0_l00005ooooo`;o00000_oo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`00
:Oooool3o`0000gooooo0_l00005ooooo`;o00007?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;o00000oooool01Ol0003ooooooooooooooooo000000Cooooo0ol00002ooooo`;o
00008?ooool00onHV9So8B4Qonk^kP03ooooo`04o`000?ooooooooooooooo`?o000000?oooooo`00
0?ooool00_ooool01?l0003oooooooooooooool2o`0001?ooooo0_l0000Aooooo`03ojVYZOl@413o
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`?o000000?oooooo`000?ooool09ooo
ool01?m4A4CogMgMooooool00004ooooo`04o`000?ooooooooooooooo`Ko00000_ooool00ol0003o
ooooooooo`03ooooo`;o00005oooool2o`0000Gooooo0_l00005ooooo`05ogMgMolb<S;ooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00Oooool0
02Wooooo00?o0000ooooooooool02_ooool2o`0000Sooooo0_l00004ooooo`;o00003oooool2o`00
00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000005ooooo`;o00000_ooool2o`0000[ooooo0_l0000<ooooo`;o00001ooo
ool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000Cooooo0_l0000:ooooo`;o00001_ooool4o`0000?ooooo0_l00009ooooo`03
oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000007?ooool2o`0000[ooooo00CogMgMoeEEEOoooooo00001?ooool01?l0003ooooooooo
ooooool5o`0000?ooooo00?o0000ooooooooool09oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool0
02Wooooo00?o0000ooooooooool02_ooool2o`0000kooooo0_l0000?ooooo`;o000000?oooooo`00
0?l000000_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool0
1Ol@413ooooooooooooooooo410@00cooooo0_l00007ooooo`;o00003?ooool2o`0000Sooooo00Go
0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`02ooooo`;o00001oooool2o`000003ooooool0003o000000Sooooo0_l00003ooooo`;o
00002_ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@01cooooo0_l0000;ooooo`03ogMgMoo<c<co000000Cooooo0_l00002
ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Wooooo`03o`000?oo
oooooooo00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
41000oooool002Wooooo00?o0000ooooooooool02Oooool2o`0000;ooooo0ol0000Booooo`;o0000
2_ooool2o`0000;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgo`000?l0003oV9RHogMgM`0<ooooo`;o00006_ooool2o`000004okZj^_ooooooV9RH
oa0@40?ooooo00KoMgMgo`000?l0003oV9RHogMgMoooool2o`000005ogMgMonHV9SooooooiRHV?mg
MgL03Oooool2o`0001Wooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMol0003o0000
oiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg02Wooooo00?ok^k^odA4A?l000001?oo
ool2o`000003oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Yooooo`03o`00
0?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool002Wooooo00?o0000ooooooooool02Oooool2o`0000;ooooo0ol0000Booooo`;o
00003?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00oo^
k^ko0000o`000002o`0001oooooo0ol00006ooooo`;o000000Co410@o`000?lQ8B7oc<c<0oooool0
1_o^k^ko0000o`000?lb<S;ok^k^ooooo`;o000000Gok^k^oc8b<_l0003o<S8bonk^kP0:ooooo`;o
00007?ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^o`000?l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03oooool2o`0001Wooooo00?oMgMgo`000?ooool00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`;o
00006Oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool002Wooooo0_l0000gooooo`;o00002_ooool2o`0000gooooo0_l0000<oooo
o`;o00000_ooool3o`0001[ooooo0ol00005ooooo`;o00000_ooool2o`00043ooooo0_l0000Ooooo
o`;o00001?ooool2o`0000cooooo0ol00004ooooo`;o0000<?ooool002Wooooo00?o0000oooooooo
ool06Oooool2o`0001_ooooo0_l0000Eooooo`;o00000_ooool2o`0000cooooo0ol00003ooooo`;o
00006Oooool3o`0000Cooooo0ol00003ooooo`;o00003oooool2o`0002Oooooo0_l0000Sooooo`;o
000000?oooooo`000?l000001?ooool2o`0000cooooo0ol0000fooooo`00:Oooool01?l0003ooooo
o`000?l0000;ooooo`;o00002oooool2o`0000kooooo0_l00007ooooo`?o00002?ooool2o`0000ko
oooo0_l0000<ooooo`;o00000oooool2o`0000;ooooo0ol0000Pooooo`;o00001?ooool2o`0000oo
oooo0_l0000;ooooo`Co00006?ooool2o`0001gooooo0_l00004ooooo`;o00009_ooool2o`0002Ko
oooo000Yooooo`04o`000?oooooo0000o`0000_ooooo0_l0000:ooooo`;o00003?ooool5o`0000Oo
oooo0ol00008ooooo`;o00004_ooool2o`0000Sooooo0_l00007ooooo`;o00004oooool2o`0001Go
oooo0_l0000Iooooo`Co00002oooool2o`0001Cooooo0_l0000Dooooo`;o00005_ooool2o`0001Co
oooo0_l00007ooooo`?o00000oooool2o`0000Sooooo0_l0000=ooooo`00:Oooool01?l0003ooooo
ooooooooool4o`0001?ooooo0_l0000<ooooo`Co00008?ooool3o`0000?ooooo0ol0000Vooooo`;o
00005Oooool2o`0002Sooooo0_l0000?ooooo`;o00000oooool2o`000003ooooool0003o000001;o
oooo0_l0000Eooooo`;o00007Oooool3o`0000?ooooo0_l00008ooooo`?o00003?ooool0027ooooo
ool00014o`0000Cooooo000Yooooo`03o`000?oooooooooo00Sooooo0_l0000<ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool00_l00006ooooo`Co00002Oooool00ol0003ooooooooo
o`0:ooooo`04o`000?oooooo0000o`0000Sooooo0ol00009ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`?o00002Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00;ooooo0_l00005ooooo`03o`000?oooooooooo00?ooooo
0_l000000ooooooo0000o`000002ooooo`04o`000?ooooooooooooooo`Co00001?ooool01?l0003o
ooooooooooooool2o`0000;ooooo0_l00002ooooo`03o`000?oooooooooo00Gooooo1Ol0000<oooo
o`03o`000?oooooooooo00Sooooo0_l0000;ooooo`04o`000?ooooooooooooooo`;o000000?ooooo
o`000?l000000oooool00ol0003oooooooooo`0:ooooo`00:Oooool00ol0003oooooooooo`08oooo
o`;o00008oooool2o`0000_ooooo00Co0000oooooooooooooooo0_l0000Dooooo`;o00005Oooool2
o`0000_ooooo00?o0000ooooooooool00oooool2o`000003ooooool0003o000003;ooooo00?o0000
ooooooooool02oooool2o`000003ooooool0003o000002Kooooo0_l00002ooooo`03o`000?oooooo
oooo00Oooooo0_l000000ooooooo0000o`00000;ooooo`;o00002?ooool4o`0000gooooo0_l00000
1?oooooo0000o`000?l00002ooooo`03o`000?oooooooooo00[ooooo000Yooooo`05o`000?oooooo
0000o`000?ooool00_l0000Vooooo`;o00004_ooool2o`0000?ooooo0_l0000Eooooo`;o00002_oo
ool2o`0000?ooooo0_l0000Aooooo`;o000000?oooooo`000?l00000:_ooool2o`0001Cooooo0_l0
00000ooooooo0000o`00000Vooooo`;o00003oooool2o`0000_ooooo0_l0000:ooooo`;o000000?o
ooooo`000?l000003_ooool2o`0000oooooo000Yooooo`05o`000?oooooo0000o`000?ooool00_l0
000Hooooo`;o00003?ooool2o`0001Oooooo0_l0000Eooooo`;o00002_ooool2o`00033ooooo0_l0
0009ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`0001Oooooo0_l00012ooooo`;o0000
2?ooool2o`0000Gooooo0_l0000Oooooo`00:Oooool2o`0000Oooooo0_l00002ooooo`;o00004?oo
ool2o`00047ooooo0_l0000:ooooo`;o00002oooool3o`0001gooooo0_l00009ooooo`;o000000Go
ooooo`000?l0003o0000ooooo`02o`0000oooooo0_l000001?oooooo0000o`000?ooool2o`0004Oo
oooo0_l00008ooooo`;o00003oooool2o`0001Gooooo000Yooooo`03o`000?oooooooooo00Kooooo
0_l00002ooooo`;o0000@?ooool2o`00017ooooo0_l0000:ooooo`;o000000?oooooo`000?l00000
2?ooool3o`000003ooooool0003o000000_ooooo0_l0000=ooooo`;o00001Oooool2o`0000Oooooo
1?l00007ooooo`;o00001_ooool2o`000004ooooool0003o0000ooooo`;o00002?ooool2o`0001Wo
oooo0_l0000Eooooo`Co00004Oooool2o`00017ooooo0_l000000ooooooo0000o`00000Booooo`00
:Oooool00ol0003oooooooooo`0Kooooo`;o00008oooool3o`0000Wooooo0_l0000>ooooo`;o0000
3oooool3o`0000cooooo0ol00004ooooo`;o00001?ooool4o`0000Oooooo0_l00009ooooo`;o0000
1?ooool2o`000003ooooool0003o000000Wooooo0_l0000Fooooo`;o00001?ooool2o`0001?ooooo
0_l0000Dooooo`Go00001oooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0001Co
oooo0_l0000Booooo`00:Oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00008ooooo`;o
00002_ooool2o`0000Kooooo0_l0000Aooooo`Co00001_ooool3o`0000;ooooo0_l000000ooooooo
0000o`00000Booooo`;o00003oooool2o`0000Cooooo0_l00008ooooo`;o00001?ooool2o`0000Ko
oooo0_l00007ooooo`;o00003oooool2o`0002[ooooo0_l0000>ooooo`;o00005Oooool2o`0000;o
oooo0_l0000:ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o0000:?ooool002Wo
oooo00Co0000oooooooooooooooo0_l00002ooooo`;o00002?ooool2o`0001;ooooo0_l0000@oooo
o`Go00001Oooool2o`0000Cooooo0_l000000ooooooo0000o`00000:ooooo`Co00006oooool2o`00
03;ooooo0_l0000Pooooo`;o00002Oooool2o`0000_ooooo0_l0000=ooooo`;o00001_ooool5o`00
01Cooooo1?l0000Wooooo`00:Oooool2o`0002oooooo1Ol00002ooooo`;o00002?ooool2o`0001?o
oooo1?l0000Looooo`;o00001oooool2o`0001kooooo0_l00008ooooo`;o00008?ooool2o`0000Wo
oooo0_l000000ooooooo0000o`000002o`0001Gooooo0_l00007ooooo`Co00004?ooool2o`0000;o
oooo1?l0000Wooooo`00:Oooool00ol0003oooooooooo`0Jooooo`;o00004_ooool5o`0001;ooooo
0_l0000Looooo`;o00002oooool2o`0000;ooooo0_l00007ooooo`;o00007_ooool2o`00017ooooo
0_l0000Fooooo`;o00003Oooool4o`0001kooooo0_l0000Booooo`;o00002_ooool2o`00027ooooo
000Yooooo`03o`000?oooooooooo01;ooooo1?l00004ooooo`;o00001?ooool2o`0002?ooooo0_l0
000Looooo`;o00002oooool2o`0003kooooo0_l0000Fooooo`;o00006_ooool2o`00037ooooo1?l0
000Booooo`;o00003Oooool002Wooooo00?o0000ooooooooool04_ooool4o`0000Wooooo0ol0000k
ooooo`;o00001oooool2o`0001cooooo0_l0000>ooooo`;o00002Oooool2o`0004?ooooo0_l0000a
ooooo`;o00005?ooool2o`0000gooooo000Yooooo`03o`000?oooooooooo01?ooooo0_l00007oooo
o`;o000000?oooooo`000?l00000??ooool3o`000003ooooool0003o000000?ooooo0_l0000Loooo
o`;o000000?oooooo`000?l000002oooool2o`000003ooooool0003o000000Kooooo0_l000000ooo
oooo0000o`00001Booooo`;o0000A?ooool002Wooooo0_l0000Dooooo`;o00001oooool2o`00043o
oooo0_l000000ooooooo0000o`00000>ooooo`;o00005?ooool2o`0000kooooo0_l00009ooooo`;o
0000>oooool2o`0001Gooooo0_l00014ooooo`00:Oooool00ol0003oooooooooo`0Eooooo`;o0000
F_ooool2o`0000oooooo0_l0000Aooooo`;o00004Oooool2o`0000kooooo0_l0000Uooooo`;o0000
Foooool002Wooooo00?o0000ooooooooool05Oooool2o`0000cooooo0_l0001Mooooo`;o00004Ooo
ool2o`00017ooooo0_l00007ooooo`;o00001Oooool2o`0008;ooooo000Yooooo`03o`000?oooooo
oooo02?ooooo0_l00005ooooo`;o0000<_ooool2o`0003cooooo0_l0000Cooooo`;o00004_ooool2
o`0002Gooooo0_l0001>ooooo`00:Oooool00ol0003oooooooooo`0@ooooo`;o00004oooool2o`00
00?ooooo0_l0000booooo`;o0000??ooool2o`0001cooooo0_l00009ooooo`;o00003oooool2o`00
01Cooooo0_l0000iooooo`;o00004oooool002Wooooo0_l0000Aooooo`;o00004oooool2o`0004Go
oooo0_l0000[ooooo`;o00004?ooool2o`0000gooooo0_l0000Jooooo`;o00000_ooool2o`0001Ko
oooo0_l0000cooooo`;o00004oooool002Wooooo00?o0000ooooooooool04?ooool2o`0002oooooo
0_l0000Yooooo`;o00005oooool2o`0001;ooooo0_l0000@ooooo`;o0000;Oooool2o`0001Kooooo
0_l0000kooooo`;o00002oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00Co
oooo0_l0000kooooo`;o0000@_ooool2o`0003[ooooo0_l0000Jooooo`;o0000D?ooool2o`0000_o
oooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool01?ooool2o`00
03;ooooo0_l0000<ooooo`;o00004Oooool2o`0005Oooooo0_l0000=ooooo`;o00001_ooool2o`00
00Kooooo0_l00009ooooo`?o00001_ooool2o`00013ooooo0_l00013ooooo`001_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01oooooo0_l0000Gooooo`;o00003?ooool2o`00017ooooo0_l0000Joooo
o`;o0000>oooool2o`0000[ooooo0_l00009ooooo`;o00001_ooool2o`0000Wooooo0_l00005oooo
o`Co00004?ooool2o`0000Sooooo0_l0000Gooooo`;o00008?ooool000Kooooo00Go0000oooooooo
ooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`00
00;ooooo0_l0000Kooooo`;o0000<Oooool2o`00027ooooo0_l0000eooooo`;o00004?ooool2o`00
02?ooooo0_l00004ooooo`;o00005_ooool2o`0001Oooooo0_l0000Pooooo`001_ooool01Ol0003o
oooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool00_ooool2o`0004kooooo0_l0000Eooooo`;o0000;?ooool2
o`0001?ooooo0_l0000kooooo`;o00003oooool2o`00033ooooo0_l0000>ooooo`001_ooool01Ol@
413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo04kooooo0_l0000Iooooo`;o00002oooool2o`0001oooooo0_l0001Q
ooooo`;o0000<?ooool2o`0000kooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0kooooo`;o00004Oooool2o`0002Kooooo0_l0001Tooooo`;o0000G_ooool000Kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo
00?o0000ooooooooool05Oooool2o`0002Cooooo0_l0000aooooo`?o0000Joooool2o`0002;ooooo
0_l0000jooooo`00:Oooool2o`0001Kooooo0_l0001Gooooo`?o00006Oooool2o`0007Cooooo0_l0
000jooooo`00:Oooool00ol0003oooooooooo`2:ooooo`;o0000OOooool2o`0001Gooooo0_l0000J
ooooo`00:Oooool00ol0003oooooooooo`0Tooooo`;o0000C?ooool2o`0004cooooo0_l00017oooo
o`;o00005Oooool2o`0001[ooooo000Yooooo`03o`000?oooooooooo02Cooooo0_l0000Qooooo`;o
0000:Oooool2o`0003kooooo0_l00005ooooo`;o00001Oooool2o`0007[ooooo000Yooooo`03o`00
0?oooooooooo04Oooooo0_l0000:ooooo`;o0000>Oooool2o`0002;ooooo0_l00005ooooo`;o0000
POooool002Wooooo0_l0001Dooooo`;o0000>Oooool2o`0004oooooo0_l00006ooooo`;o00007?oo
ool2o`0003Gooooo000Yooooo`03o`000?oooooooooo00Gooooo0_l00023ooooo`;o0000:Oooool2
o`0002Sooooo0_l00006ooooo`;o00007?ooool2o`0000;ooooo0_l0000aooooo`00:Oooool00ol0
003oooooooooo`05ooooo`;o00001Oooool2o`0001Cooooo0_l0001Vooooo`;o0000:Oooool2o`00
03Cooooo0_l0000Looooo`;o0000<Oooool002Wooooo00?o0000ooooooooool03?ooool2o`0001Co
oooo0_l0000@ooooo`;o0000YOooool2o`0000kooooo0_l0001?ooooo`00:Oooool00ol0003ooooo
ooooo`0dooooo`;o0000Foooool2o`0004Sooooo0_l0001Oooooo`00:Oooool2o`0007Gooooo0_l0
000Kooooo`;o0000;oooool2o`0007Sooooo000Yooooo`03o`000?oooooooooo07Cooooo0_l0001<
ooooo`;o0000;Oooool2o`0002Gooooo0_l0000Rooooo`00:Oooool00ol0003oooooooooo`2doooo
o`;o00003Oooool2o`0002cooooo0_l0000Uooooo`;o00008_ooool002Wooooo00?o0000oooooooo
ool0]?ooool2o`0000gooooo0_l0001gooooo`00:Oooool00ol0003oooooooooo`3Eooooo`;o0000
IOooool002Wooooo0_l0001<ooooo`;o00001_ooool2o`00083ooooo0_l0000^ooooo`;o0000=Ooo
ool002Wooooo00?o0000ooooooooool0=oooool2o`0001;ooooo0_l00006ooooo`;o00005?ooool2
o`0000Cooooo0_l0002Dooooo`;o0000=Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0=ooo
ool2o`00033ooooo0_l00004ooooo`;o0000?oooool2o`0008[ooooo000>ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`1gooooo`;o0000=oooool2o`0005gooooo0_l0000[ooooo`003_ooool01Ol@413ooooooooooooo
oooo410@013ooooo00?o0000ooooooooool00oooool3o`0003Gooooo0_l00010ooooo`;o000000?o
ooooo`000?l00000Toooool2o`0002_ooooo000>ooooo`05o`000?ooooooooooooooool000003ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo03Gooooo0_l00013ooooo`;o0000`?oo
ool000kooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`2<ooooo`;o0000[_ooool000kooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0S?ooool2o`00047ooooo
0_l0000jooooo`;o0000;oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool07Oooool2o`0000cooooo0_l0000<ooooo`;o0000
U?ooool2o`0002;ooooo0_l0000Fooooo`;o0000;oooool000kooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`Co00001_ooool2o`0001kooooo0_l0000<ooooo`;o00003?ooool2o`000;Sooooo
0_l00017ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo2?ooool2o`0003?ooooo000Yooooo`03o`000?oooooooooo0?oooooo2?ooool2o`00
027ooooo0_l0000@ooooo`00:Oooool00ol0003oooooooooo`13ooooo`;o0000Xoooool2o`00043o
oooo0_l0000@ooooo`00:Oooool2o`0004Cooooo0_l0000Booooo`;o0000Soooool2o`0005;ooooo
000Yooooo`03o`000?oooooooooo05Oooooo0_l0001Mooooo`;o0000Q?ooool002Wooooo00?o0000
ooooooooool0]_ooool2o`0008Cooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEoooo
o`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`000?oooooo
ooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o
EEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool0
0oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`007oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`007oooool00omEEEGoIVIVo`00003oooooodOooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .26113 Mdot
.02762 .26869 Mdot
.02952 .29401 Mdot
.03143 .34059 Mdot
.03333 .35497 Mdot
.03524 .28861 Mdot
.03714 .2716 Mdot
.03905 .23151 Mdot
.04095 .29424 Mdot
.04286 .34878 Mdot
.04476 .34832 Mdot
.04667 .2734 Mdot
.04857 .27278 Mdot
.05048 .35094 Mdot
.05238 .34756 Mdot
.05429 .34399 Mdot
.05619 .29494 Mdot
.0581 .27371 Mdot
.06 .35548 Mdot
.0619 .24522 Mdot
.06381 .2376 Mdot
.06571 .24124 Mdot
.06762 .2408 Mdot
.06952 .25867 Mdot
.07143 .34641 Mdot
.07333 .36025 Mdot
.07524 .33594 Mdot
.07714 .3461 Mdot
.07905 .23408 Mdot
.08095 .24592 Mdot
.08286 .24476 Mdot
.08476 .26493 Mdot
.08667 .26367 Mdot
.08857 .26416 Mdot
.09048 .30232 Mdot
.09238 .24905 Mdot
.09429 .25141 Mdot
.09619 .33961 Mdot
.0981 .24864 Mdot
.1 .2498 Mdot
.1019 .30076 Mdot
.10381 .29024 Mdot
.10571 .2802 Mdot
.10762 .30058 Mdot
.10952 .29788 Mdot
.11143 .35842 Mdot
.11333 .34459 Mdot
.11524 .23994 Mdot
.11714 .35271 Mdot
.11905 .23786 Mdot
.12095 .24868 Mdot
.12286 .23283 Mdot
.12476 .42459 Mdot
.12667 .27012 Mdot
.12857 .31069 Mdot
.13048 .28603 Mdot
.13238 .24071 Mdot
.13429 .31486 Mdot
.13619 .24331 Mdot
.1381 .30019 Mdot
.14 .35129 Mdot
.1419 .34098 Mdot
.14381 .26629 Mdot
.14571 .31708 Mdot
.14762 .32811 Mdot
.14952 .26218 Mdot
.15143 .34684 Mdot
.15333 .34158 Mdot
.15524 .35073 Mdot
.15714 .24421 Mdot
.15905 .35019 Mdot
.16095 .26814 Mdot
.16286 .34435 Mdot
.16476 .3471 Mdot
.16667 .26678 Mdot
.16857 .27961 Mdot
.17048 .425 Mdot
.17238 .31725 Mdot
.17429 .23127 Mdot
.17619 .2893 Mdot
.1781 .24735 Mdot
.18 .24099 Mdot
.1819 .33958 Mdot
.18381 .30072 Mdot
.18571 .23492 Mdot
.18762 .33629 Mdot
.18952 .35552 Mdot
.19143 .33147 Mdot
.19333 .33348 Mdot
.19524 .34039 Mdot
.19714 .3572 Mdot
.19905 .40394 Mdot
.20095 .31769 Mdot
.20286 .35383 Mdot
.20476 .32263 Mdot
.20667 .38431 Mdot
.20857 .35082 Mdot
.21048 .28405 Mdot
.21238 .42414 Mdot
.21429 .35208 Mdot
.21619 .25225 Mdot
.2181 .34788 Mdot
.22 .30041 Mdot
.2219 .28616 Mdot
.22381 .2345 Mdot
.22571 .26486 Mdot
.22762 .33413 Mdot
.22952 .35721 Mdot
.23143 .31695 Mdot
.23333 .23766 Mdot
.23524 .35001 Mdot
.23714 .33751 Mdot
.23905 .27147 Mdot
.24095 .23436 Mdot
.24286 .44776 Mdot
.24476 .27551 Mdot
.24667 .3412 Mdot
.24857 .23262 Mdot
.25048 .23897 Mdot
.25238 .28875 Mdot
.25429 .26267 Mdot
.25619 .31871 Mdot
.2581 .24479 Mdot
.26 .23856 Mdot
.2619 .2407 Mdot
.26381 .34088 Mdot
.26571 .23216 Mdot
.26762 .37836 Mdot
.26952 .23825 Mdot
.27143 .31175 Mdot
.27333 .23685 Mdot
.27524 .24451 Mdot
.27714 .29319 Mdot
.27905 .31081 Mdot
.28095 .28127 Mdot
.28286 .23408 Mdot
.28476 .22959 Mdot
.28667 .23181 Mdot
.28857 .34289 Mdot
.29048 .28981 Mdot
.29238 .33575 Mdot
.29429 .38767 Mdot
.29619 .32757 Mdot
.2981 .35468 Mdot
.3 .29943 Mdot
.3019 .24135 Mdot
.30381 .23404 Mdot
.30571 .45445 Mdot
.30762 .32563 Mdot
.30952 .33499 Mdot
.31143 .27099 Mdot
.31333 .35371 Mdot
.31524 .35421 Mdot
.31714 .26764 Mdot
.31905 .26786 Mdot
.32095 .25202 Mdot
.32286 .23563 Mdot
.32476 .24914 Mdot
.32667 .24506 Mdot
.32857 .26357 Mdot
.33048 .23318 Mdot
.33238 .35806 Mdot
.33429 .23127 Mdot
.33619 .24047 Mdot
.3381 .25606 Mdot
.34 .25177 Mdot
.3419 .24079 Mdot
.34381 .23761 Mdot
.34571 .23541 Mdot
.34762 .34951 Mdot
.34952 .23041 Mdot
.35143 .25262 Mdot
.35333 .33682 Mdot
.35524 .34177 Mdot
.35714 .34121 Mdot
.35905 .3378 Mdot
.36095 .29472 Mdot
.36286 .38475 Mdot
.36476 .24949 Mdot
.36667 .30226 Mdot
.36857 .23216 Mdot
.37048 .23235 Mdot
.37238 .2629 Mdot
.37429 .34551 Mdot
.37619 .30082 Mdot
.3781 .31512 Mdot
.38 .3129 Mdot
.3819 .38829 Mdot
.38381 .23929 Mdot
.38571 .24501 Mdot
.38762 .29307 Mdot
.38952 .31456 Mdot
.39143 .24417 Mdot
.39333 .32079 Mdot
.39524 .35745 Mdot
.39714 .23585 Mdot
.39905 .27706 Mdot
.40095 .29461 Mdot
.40286 .35044 Mdot
.40476 .38961 Mdot
.40667 .34328 Mdot
.40857 .30027 Mdot
.41048 .30042 Mdot
.41238 .26843 Mdot
.41429 .34193 Mdot
.41619 .39647 Mdot
.4181 .2411 Mdot
.42 .32427 Mdot
.4219 .27781 Mdot
.42381 .32825 Mdot
.42571 .29775 Mdot
.42762 .35156 Mdot
.42952 .27644 Mdot
.43143 .32278 Mdot
.43333 .23486 Mdot
.43524 .34526 Mdot
.43714 .23972 Mdot
.43905 .31689 Mdot
.44095 .24686 Mdot
.44286 .29668 Mdot
.44476 .26234 Mdot
.44667 .24032 Mdot
.44857 .34462 Mdot
.45048 .27394 Mdot
.45238 .23834 Mdot
.45429 .25747 Mdot
.45619 .34018 Mdot
.4581 .35147 Mdot
.46 .2962 Mdot
.4619 .33345 Mdot
.46381 .34547 Mdot
.46571 .30302 Mdot
.46762 .34186 Mdot
.46952 .2721 Mdot
.47143 .41568 Mdot
.47333 .32219 Mdot
.47524 .34684 Mdot
.47714 .32685 Mdot
.47905 .34271 Mdot
.48095 .28724 Mdot
.48286 .23577 Mdot
.48476 .24749 Mdot
.48667 .34994 Mdot
.48857 .30622 Mdot
.49048 .23782 Mdot
.49238 .34989 Mdot
.49429 .245 Mdot
.49619 .3295 Mdot
.4981 .25975 Mdot
.5 .2803 Mdot
.5019 .35104 Mdot
.50381 .25528 Mdot
.50571 .2866 Mdot
.50762 .2774 Mdot
.50952 .32921 Mdot
.51143 .27291 Mdot
.51333 .34402 Mdot
.51524 .33964 Mdot
.51714 .33592 Mdot
.51905 .27891 Mdot
.52095 .25604 Mdot
.52286 .23972 Mdot
.52476 .34189 Mdot
.52667 .34724 Mdot
.52857 .25444 Mdot
.53048 .30228 Mdot
.53238 .34108 Mdot
.53429 .25107 Mdot
.53619 .33874 Mdot
.5381 .25148 Mdot
.54 .25544 Mdot
.5419 .32742 Mdot
.54381 .23471 Mdot
.54571 .31834 Mdot
.54762 .34906 Mdot
.54952 .3176 Mdot
.55143 .23209 Mdot
.55333 .34416 Mdot
.55524 .35991 Mdot
.55714 .25442 Mdot
.55905 .35267 Mdot
.56095 .26573 Mdot
.56286 .23128 Mdot
.56476 .28066 Mdot
.56667 .34299 Mdot
.56857 .27179 Mdot
.57048 .28808 Mdot
.57238 .35825 Mdot
.57429 .26868 Mdot
.57619 .31815 Mdot
.5781 .24345 Mdot
.58 .34227 Mdot
.5819 .25095 Mdot
.58381 .39342 Mdot
.58571 .25879 Mdot
.58762 .33279 Mdot
.58952 .28385 Mdot
.59143 .27206 Mdot
.59333 .23285 Mdot
.59524 .3732 Mdot
.59714 .24884 Mdot
.59905 .3448 Mdot
.60095 .45745 Mdot
.60286 .33213 Mdot
.60476 .33403 Mdot
.60667 .25067 Mdot
.60857 .25287 Mdot
.61048 .3227 Mdot
.61238 .34729 Mdot
.61429 .26551 Mdot
.61619 .34624 Mdot
.6181 .29603 Mdot
.62 .25972 Mdot
.6219 .29957 Mdot
.62381 .25227 Mdot
.62571 .27425 Mdot
.62762 .28644 Mdot
.62952 .25675 Mdot
.63143 .27276 Mdot
.63333 .33 Mdot
.63524 .28882 Mdot
.63714 .27214 Mdot
.63905 .36131 Mdot
.64095 .36448 Mdot
.64286 .34232 Mdot
.64476 .32489 Mdot
.64667 .31225 Mdot
.64857 .26852 Mdot
.65048 .35888 Mdot
.65238 .27815 Mdot
.65429 .26977 Mdot
.65619 .32983 Mdot
.6581 .23627 Mdot
.66 .28911 Mdot
.6619 .31735 Mdot
.66381 .26054 Mdot
.66571 .30589 Mdot
.66762 .26927 Mdot
.66952 .29208 Mdot
.67143 .29829 Mdot
.67333 .25252 Mdot
.67524 .35618 Mdot
.67714 .33909 Mdot
.67905 .41088 Mdot
.68095 .33046 Mdot
.68286 .23781 Mdot
.68476 .32476 Mdot
.68667 .28175 Mdot
.68857 .33417 Mdot
.69048 .23192 Mdot
.69238 .23763 Mdot
.69429 .3181 Mdot
.69619 .31158 Mdot
.6981 .38307 Mdot
.7 .26066 Mdot
.7019 .22893 Mdot
.70381 .24446 Mdot
.70571 .34423 Mdot
.70762 .32532 Mdot
.70952 .24535 Mdot
.71143 .33371 Mdot
.71333 .26442 Mdot
.71524 .34209 Mdot
.71714 .23779 Mdot
.71905 .29864 Mdot
.72095 .27542 Mdot
.72286 .26975 Mdot
.72476 .27063 Mdot
.72667 .32392 Mdot
.72857 .34233 Mdot
.73048 .24656 Mdot
.73238 .27056 Mdot
.73429 .24281 Mdot
.73619 .30579 Mdot
.7381 .29478 Mdot
.74 .2536 Mdot
.7419 .28885 Mdot
.74381 .28332 Mdot
.74571 .24597 Mdot
.74762 .28913 Mdot
.74952 .2421 Mdot
.75143 .22936 Mdot
.75333 .2365 Mdot
.75524 .34044 Mdot
.75714 .44628 Mdot
.75905 .29757 Mdot
.76095 .26618 Mdot
.76286 .27271 Mdot
.76476 .34559 Mdot
.76667 .34383 Mdot
.76857 .26985 Mdot
.77048 .25311 Mdot
.77238 .24341 Mdot
.77429 .27262 Mdot
.77619 .34693 Mdot
.7781 .35144 Mdot
.78 .34551 Mdot
.7819 .23679 Mdot
.78381 .25712 Mdot
.78571 .36675 Mdot
.78762 .26309 Mdot
.78952 .29151 Mdot
.79143 .42273 Mdot
.79333 .3076 Mdot
.79524 .3418 Mdot
.79714 .35094 Mdot
.79905 .27943 Mdot
.80095 .24302 Mdot
.80286 .27525 Mdot
.80476 .33694 Mdot
.80667 .32979 Mdot
.80857 .35411 Mdot
.81048 .34015 Mdot
.81238 .28438 Mdot
.81429 .35958 Mdot
.81619 .24435 Mdot
.8181 .33602 Mdot
.82 .35286 Mdot
.8219 .29889 Mdot
.82381 .35647 Mdot
.82571 .26455 Mdot
.82762 .35314 Mdot
.82952 .32467 Mdot
.83143 .29652 Mdot
.83333 .28459 Mdot
.83524 .29982 Mdot
.83714 .30377 Mdot
.83905 .33296 Mdot
.84095 .24146 Mdot
.84286 .30354 Mdot
.84476 .34726 Mdot
.84667 .33115 Mdot
.84857 .37222 Mdot
.85048 .26877 Mdot
.85238 .44176 Mdot
.85429 .30845 Mdot
.85619 .3184 Mdot
.8581 .323 Mdot
.86 .34765 Mdot
.8619 .3435 Mdot
.86381 .24087 Mdot
.86571 .41557 Mdot
.86762 .33229 Mdot
.86952 .27341 Mdot
.87143 .33185 Mdot
.87333 .24593 Mdot
.87524 .30367 Mdot
.87714 .39633 Mdot
.87905 .31097 Mdot
.88095 .26649 Mdot
.88286 .3083 Mdot
.88476 .31268 Mdot
.88667 .29768 Mdot
.88857 .34637 Mdot
.89048 .23376 Mdot
.89238 .2785 Mdot
.89429 .23104 Mdot
.89619 .27383 Mdot
.8981 .27502 Mdot
.9 .23258 Mdot
.9019 .25309 Mdot
.90381 .3011 Mdot
.90571 .35504 Mdot
.90762 .34743 Mdot
.90952 .2357 Mdot
.91143 .27656 Mdot
.91333 .33411 Mdot
.91524 .23033 Mdot
.91714 .31505 Mdot
.91905 .27433 Mdot
.92095 .23194 Mdot
.92286 .25808 Mdot
.92476 .35311 Mdot
.92667 .315 Mdot
.92857 .27503 Mdot
.93048 .30798 Mdot
.93238 .26044 Mdot
.93429 .28764 Mdot
.93619 .26397 Mdot
.9381 .30019 Mdot
.94 .2673 Mdot
.9419 .34037 Mdot
.94381 .27576 Mdot
.94571 .30009 Mdot
.94762 .2866 Mdot
.94952 .33735 Mdot
.95143 .26355 Mdot
.95333 .3591 Mdot
.95524 .24985 Mdot
.95714 .35753 Mdot
.95905 .33016 Mdot
.96095 .27175 Mdot
.96286 .43878 Mdot
.96476 .27605 Mdot
.96667 .28004 Mdot
.96857 .30191 Mdot
.97048 .25006 Mdot
.97238 .35093 Mdot
.97429 .23163 Mdot
.97619 .26648 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1@ooooo`;o00004ooo
ool2o`0006oooooo0_l0000>ooooo`;o0000;?ooool2o`0000Gooooo0_l0000Oooooo`001_ooool0
1Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8boooo
o`04ooooo`?o000000?oooooo`000?l000002oooool2o`0000cooooo0_l0000?ooooo`;o00005_oo
ool2o`0000?ooooo0_l00004ooooo`?o00000oooool2o`0000Oooooo0ol00003ooooo`;o00001?oo
ool3o`0003Sooooo0_l00002ooooo`;o00001oooool2o`0001kooooo0_l000000ooooooo0000o`00
000>ooooo`;o0000:oooool5o`0000?ooooo1?l0000?ooooo`;o00003?ooool000Kooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`04o`000?ooooooooooooooo`;o00002oooool2o`0000cooooo0_l0000?ooooo`;o
000000?oooooo`000?l000002oooool2o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`;o
000000Coooooo`000?l0003ooooo0ol00003ooooo`;o00001?ooool2o`000004ooooool0003o0000
o`0000;ooooo0_l00005ooooo`?o00001_ooool2o`0000[ooooo0_l0000>ooooo`;o00004Oooool2
o`000003ooooool0003o000000;ooooo0_l00007ooooo`;o00004oooool2o`0000Wooooo0_l0000B
ooooo`;o00001oooool2o`00027ooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l0
000?ooooo`;o00003?ooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`;o00003ooo
ool3o`0001?ooooo0_l0000;ooooo`;o000000?oooooo`000?l000000_l000001?oooooo0000o`00
0?ooool2o`000003ooooool0003o000000;o00003Oooool2o`0000Gooooo0ol0000:ooooo`;o0000
0_ooool2o`0000[ooooo0ol000000ooooooo0000o`000002o`0000Sooooo1?l00009ooooo`;o0000
1?ooool2o`0002?ooooo0_l00006ooooo`;o000000?oooooo`000?l000001_ooool2o`0000[ooooo
0_l00007ooooo`;o00009oooool2o`00027ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`09ooooo`?o00003_ooool3o`0000;ooooo0ol0000<ooooo`;o00004?ooool2o`0000?o
oooo0_l000000ooooooo0000o`000003o`0000Wooooo0_l00009ooooo`Co00002oooool2o`0000Wo
oooo0_l00004ooooo`;o000000?oooooo`000?l000000_l0000:ooooo`;o00002Oooool2o`0000oo
oooo0_l0000Pooooo`;o000000?oooooo`000?l000001_ooool2o`0000Cooooo0_l00003ooooo`;o
00001Oooool2o`0000Oooooo0_l0000;ooooo`;o00001Oooool2o`00033ooooo0006ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006oooo
o`03o`000?oooooooooo00Wooooo0ol00003ooooo`;o00003_ooool3o`0000Gooooo0_l00005oooo
o`;o00006?ooool3o`0000;ooooo0_l00007ooooo`;o00001_ooool2o`000003ooooool0003o0000
00;o00003?ooool3o`0000Oooooo0_l0000Gooooo`;o00006?ooool2o`0002Oooooo1?l00004oooo
o`Co000000?oooooo`000?l000000_l00005ooooo`;o00001oooool2o`0000?ooooo0_l00006oooo
o`;o00001Oooool2o`000003ooooool0003o000002gooooo000Yooooo`;o00002_ooool2o`0000Co
oooo0_l000000ooooooo0000o`000002o`0000Kooooo0_l00009ooooo`;o00001Oooool2o`0001So
oooo0_l00003ooooo`;o00003_ooool3o`0000[ooooo0_l00005ooooo`?o00003_ooool2o`0000co
oooo0_l00002ooooo`;o00007oooool2o`00023ooooo1?l00004ooooo`;o00000oooool2o`0001Go
oooo0_l0000@ooooo`;o0000;Oooool002Wooooo00?o0000ooooooooool04_ooool5o`0000Gooooo
0_l0000@ooooo`;o00002_ooool2o`00023ooooo0ol00003ooooo`;o00000_ooool2o`0000;ooooo
0_l0000Fooooo`;o00003?ooool2o`0000kooooo1?l0000<ooooo`;o00000oooool2o`000003oooo
ool0003o000000?ooooo0_l0000>ooooo`;o0000FOooool2o`0000?ooooo0_l0000=ooooo`00:Ooo
ool00ol0003oooooooooo`0Cooooo`Co00008oooool2o`00023ooooo0_l00004ooooo`;o00000_oo
ool2o`0002oooooo0_l00006ooooo`Go00001?ooool2o`0000Kooooo0_l00006ooooo`;o00000ooo
ool2o`0000kooooo0_l0000Dooooo`;o00001oooool2o`0002Wooooo0_l0000?ooooo`;o00000ooo
ool2o`0000gooooo000Yooooo`03o`000?oooooooooo00_ooooo0_l0001Dooooo`;o00009?ooool2
o`0000kooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o00001ooo
ool2o`0000Gooooo0_l00005ooooo`;o00008_ooool2o`0000Oooooo0_l00003ooooo`;o00009?oo
ool2o`0000Cooooo0_l0000Mooooo`00:Oooool2o`0000cooooo0_l0001Dooooo`;o00009?ooool2
o`0000cooooo0_l00005ooooo`;o00004oooool2o`0000Wooooo0_l000000ooooooo0000o`000009
ooooo`;o00002_ooool2o`0001Wooooo0_l0000Zooooo`;o000000?oooooo`000?l000006_ooool0
02Wooooo0_l0000Aooooo`?o00004_ooool2o`0001Kooooo0_l00007ooooo`;o00005_ooool2o`00
00cooooo0_l0000Fooooo`;o00003oooool2o`0002Gooooo0_l0000<ooooo`;o00002_ooool2o`00
00;ooooo0_l0000Fooooo`;o00002_ooool2o`00023ooooo1?l00003ooooo`;o00004oooool002Wo
oooo00?o0000ooooooooool04?ooool3o`00013ooooo1?l000000ooooooo0000o`000002o`00017o
oooo0_l00007ooooo`;o00004oooool2o`000003ooooool0003o000000cooooo0_l0000Fooooo`;o
00008oooool2o`0000oooooo0_l0000Nooooo`;o00003Oooool2o`0000Oooooo0_l0000:ooooo`;o
00004?ooool2o`00013ooooo0ol00002ooooo`;o00001_ooool2o`0000_ooooo000Yooooo`;o0000
7_ooool2o`0000Cooooo0_l00003ooooo`Co00001?ooool4o`000008oa0@4?ooooooooooonk^k_lb
<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000o`000?o^k^h05Oooool4o`00013ooooo1Ol0
0003ooooo`04onk^k_lb<S;o0000oc8b<P;o00000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Oo
oooo0_l000001?l@413o0000o`000?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool3
o`000003oc8b<_o^k^kooooo00Gooooo1?l00002ooooo`;o00004?ooool5o`0000Oooooo0_l00000
2Ol@413o0000o`000?ooooook^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02_ooool2o`0000Sooooo0_l0000Aooooo`;o000000GoA4A4o`000?l0003o<S8bomgMg@02
ooooo`03onk^k_lb<S;o000000;o00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Y
ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o00005?ooool2o`0001?ooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?l0003o
0000ogMgM`0Eooooo`;o00004_ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00CoMgMgoiRH
V?ooooooV9RH0_l00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool2o`0000Gooooo0_l0
000;ooooo`;o00003oooool00ol@413o0000o`000002o`0000?ooooo00GoMgMgo`000?l0003oV9RH
ogMgM`03ooooo`04ogMgMonHV9SooooooiRHV0Go00000_ooool4o`0000;ooooo0_l0000@ooooo`Go
00002?ooool6o`000004oiRHV?ooooooV9RHogMgM`?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0:
ooooo`;o00001?ooool2o`0000Oooooo0_l00005ooooo`;o00002_ooool02OmgMgOo<S8bo`000?l0
003oMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wo
oooo00Co0000oooooooooooooooo0_l000001?oooooo0000o`000?ooool2o`0002Wooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Co410@oooooooooooooooo
0_l0000Yooooo`03oiRHV?lQ8B7ok^k^00Cooooo0_l00002ooooo`06oa0@4?ooooooooooooooool@
413ooooo0_l000001?l@413oooooooooooooool2o`0000Gooooo0_l0000:ooooo`?o00004?ooool2
o`000003ooooool0003ooooo00;ooooo00Go410@o`000?l0003ooooooa0@4003ooooo`04oa0@4?oo
ooooooooooooo`Go00006Oooool2o`0000Wooooo1Ol00002ooooo`;o00000oooool01?l@413ooooo
ooooooooool2o`0000;ooooo00?o410@ooooooooool03_ooool2o`0000Oooooo0_l00003ooooo`Co
000000?oooooo`000?l000000oooool2o`0000?ooooo1?l00003ooooo`05oa0@4?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`01ooooo`00:Oooool2o`0001Sooooo0_l0000Booooo`;o
00001Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01?l0
003oooooooooooooool2o`0002[ooooo00?oV9RHob4Q8Oo^k^h00oooool2o`0000;ooooo00?o0000
ooooooooool00_l000001?oooooo0000o`000?l0000Cooooo`;o000000?oooooo`000?l000000_oo
ool2o`0000cooooo0_l000000oooooooZJVYoa0@4003ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000Oooooo0_l0000Dooooo`;o00002Oooool01?m4A4Co
gMgMooooool00004ooooo`05o`000?ooooooooooooooool000000_ooool3o`0000;ooooo00?o0000
ooooooooool05_ooool3o`0000?ooooo0_l00003ooooo`;o00000oooool2o`0000;ooooo00?oMgMg
oc8b<_ooool00_l00003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`01ooooo`00:Oooool00ol0003oooooooooo`0Gooooo`;o00004_ooool2o`0000Gooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`00000;ooooo`;o00007oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool0
00000_ooool2o`0000?ooooo00?o0000ooooooooool04Oooool2o`0000Gooooo0_l0000<ooooo`;o
000000?o410@o`000?nj^[X00oooool2o`0000;ooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo00Gooooo0_l00009ooooo`;o00004Oooool2o`000005oooooooMgMgoEEEE
ooooool000001?ooool01Ol0003ooooooooooooooooo000000;ooooo0_l00003ooooo`03o`000?oo
oooooooo01Kooooo0_l0000?ooooo`06o`000?lQ8B7o0000oc8b<_o<c<cooooo0_l00003ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`01ooooo`00:Oooool00ol0003o
ooooooooo`0Oooooo`;o00004Oooool00ol0003oooooooooo`02ooooo`05oa0@4?l0003o0000oooo
ool@41000_l000000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo0_l0000Poooo
o`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o
410@ooooooooool04oooool2o`0001Cooooo00?o^[Zjob4Q8Oooool00_ooool2o`0000;ooooo00Go
410@oooooooooooooooooa0@4003ooooo`;o00004Oooool2o`00017ooooo0_l00002ooooo`03ogMg
Moo<c<co000000Cooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00;o
00001Oooool2o`0002;ooooo0_l00005ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@00?ooooo000Yooooo`03o`000?oooooooooo00;o00007Oooool2o`00
00cooooo0_l00003ooooo`03o`000?oooooooooo00;ooooo00GoMgMgo`000?l0003oV9RHogMgM`02
o`000006oooooomgMgOoV9RHoooooonHV9SoMgMg0_ooool2o`0000[ooooo0_l0000Iooooo`05o`00
0?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0=ooooo`;o00001_ooool2o`00017ooooo00?o410@oiRHV?l000000_l00003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01?mgMgOoV9RHoooooonHV9P2o`000003oooo
ool0003o000000Kooooo0_l0000Hooooo`Co000000Coooooonk^k_m4A4Co00001?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00?oMgMgoiRHV?ooool00_l00005ooooo`;o00007_ooool2o`00
00;ooooo0_l00005ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo000Yooooo`03o`000?oooooooooo00;o00005?ooool2o`0001Gooooo0_l00000
1?ooooooEEEEofIVI_l00004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00;ooooo0_l00006ooooo`;o00000_ooool2o`0001Wooooo00CoV9RHoa0@4?l0
003o8B4Q0_l00002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00gooooo0_l0000Iooooo`05ojVYZOl@413o0000o`000?nYZJT00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`;o00001_ooool2o`00
0003ooooool0003o000001Gooooo1?l00002ooooo`03ogMgMol0003ooooo00?ooooo00?ok^k^oc8b
<_l000000_l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09Oooool2o`0000;ooooo1?l00003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
000Yooooo`?o00000_ooool2o`0000?ooooo0_l0000=ooooo`;o0000=_ooool2o`0001Wooooo0_l0
0006ooooo`;o00000oooool2o`00017ooooo0_l0000`ooooo`;o00003oooool2o`0001Cooooo0_l0
000>ooooo`;o0000B?ooool002Wooooo0ol00002ooooo`;o00000oooool2o`0000oooooo0_l0000k
ooooo`;o00004_ooool2o`0000_ooooo0_l00005ooooo`;o00001?ooool2o`0000Cooooo0_l0000`
ooooo`;o00004?ooool2o`0000gooooo0_l00004ooooo`;o00001Oooool2o`0001;ooooo0_l00000
0ooooooo0000o`00000@ooooo`;o0000:?ooool002Wooooo00?o0000ooooooooool04_ooool2o`00
0003ooooool0003o000000?o00001oooool2o`0000gooooo0_l00009ooooo`;o00006?ooool2o`00
01Cooooo0_l000000ooooooo0000o`000008ooooo`?o00000_ooool2o`0000Cooooo0_l0000Joooo
o`;o00007?ooool2o`0000kooooo0_l0000=ooooo`;o00002oooool2o`0001;ooooo0_l000001?oo
oooo0000o`000?l0000?ooooo`;o00000oooool2o`0000Wooooo0_l000000ooooooo0000o`000005
ooooo`;o00003_ooool002Wooooo00?o0000ooooooooool04_ooool2o`000003ooooool0003o0000
00;o00002?ooool2o`0000gooooo0_l00009ooooo`;o0000;_ooool2o`000003ooooool0003o0000
00Sooooo0ol0000?ooooo`;o00004oooool2o`0001cooooo0_l00012ooooo`Go00002?ooool2o`00
00Oooooo0_l00009ooooo`;o000000?oooooo`000?l000001Oooool2o`0000kooooo000Yooooo`03
o`000?oooooooooo08[ooooo0_l00006ooooo`;o0000=oooool2o`0001Cooooo0_l0000Aooooo`;o
00003?ooool4o`000003ooooool0003o000000Gooooo1?l0000>ooooo`;o00006_ooool0027ooooo
ool00014o`0000Cooooo000Yooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`05ooooo`Go00002oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool00_ooool4o`0000?ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooooooo`;o000000?oooooo`000?l00000
1?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool01?l0003oooooooooooooool2o`0000Kooooo00?o0000ooooooooool01?ooool2o`0000Co
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool01?l0003oooooooooooooool4o`0000Cooooo00?o0000oooo
ooooool01Oooool2o`0000;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:oooo
o`00:Oooool00ol0003oooooooooo`0Pooooo`;o000000?oooooo`000?l000001oooool2o`0000Oo
oooo0_l00003ooooo`03o`000?oooooooooo00;ooooo0_l0000]ooooo`?o000000?oooooo`000?l0
00001?ooool00ol0003oooooooooo`07ooooo`;o00008Oooool2o`0000Oooooo0_l00005ooooo`03
o`000?oooooooooo00gooooo0_l00002ooooo`;o00002Oooool2o`0001cooooo00?o0000oooooooo
ool07?ooool2o`0000Wooooo0_l000000ooooooo0000o`00000>ooooo`03o`000?oooooooooo00[o
oooo000Yooooo`03o`000?oooooooooo02?ooooo0_l00007ooooo`;o00001oooool2o`0000Sooooo
0_l00006ooooo`;o00009Oooool2o`0000?ooooo0_l0000=ooooo`;o00008?ooool3o`0000Oooooo
0_l0000Iooooo`;o00002Oooool2o`0003;ooooo0_l0000Booooo`;o00007_ooool002Wooooo00?o
0000ooooooooool0=_ooool2o`0000oooooo0_l0000Zooooo`;o00001oooool2o`000003ooooool0
003o000000cooooo0_l0000Eooooo`;o00004oooool2o`0002?ooooo0_l0000Xooooo`?o0000<Ooo
ool002Wooooo0_l0000gooooo`;o00008?ooool2o`0002;ooooo0_l000000ooooooo0000o`00000<
ooooo`?o00004oooool2o`0001Cooooo0_l00009ooooo`;o00002oooool2o`0000Gooooo0_l00004
ooooo`;o00007oooool2o`0000Sooooo0_l0000aooooo`00:Oooool00ol0003oooooooooo`0Toooo
o`;o0000;_ooool2o`0000;ooooo0_l0000Sooooo`;o00003oooool2o`0000Cooooo0_l00002oooo
o`;o00002Oooool2o`0001_ooooo0_l00002ooooo`;o00000_ooool2o`0000Kooooo0ol00005oooo
o`;o00007_ooool2o`0000Gooooo0_l0000Xooooo`;o00004Oooool002Wooooo00?o0000oooooooo
ool09?ooool2o`0000cooooo0ol0000Oooooo`;o00009oooool2o`0000[ooooo0_l00009ooooo`;o
00000_ooool2o`0001Sooooo0_l00002ooooo`;o00002?ooool2o`0000Kooooo0_l00006ooooo`;o
00009_ooool2o`0000Sooooo0_l000000ooooooo0000o`000005ooooo`?o00006_ooool2o`00017o
oooo000Yooooo`03o`000?oooooooooo00gooooo0_l0000Rooooo`Co00002Oooool2o`0001?ooooo
0_l00003ooooo`;o0000;oooool2o`00013ooooo0_l0000Eooooo`;o00000_ooool3o`0001Wooooo
0_l00005ooooo`;o00008Oooool2o`0000Cooooo0_l000000ooooooo0000o`000005ooooo`?o0000
2oooool2o`00023ooooo000Yooooo`03o`000?oooooooooo00gooooo0_l00005ooooo`;o00006Ooo
ool4o`0000_ooooo0_l000000ooooooo0000o`00000@ooooo`;o00000oooool2o`0000cooooo1?l0
000`ooooo`?o00001?ooool2o`0001Cooooo0_l0000Eooooo`;o00000_ooool2o`0000Gooooo0_l0
000Looooo`;o00000oooool2o`0001cooooo0_l0000:ooooo`;o00005?ooool002Wooooo1?l0000C
ooooo`;o00003?ooool2o`0000;ooooo0_l00007ooooo`;o00000_ooool2o`0000cooooo0_l00000
0ooooooo0000o`000003ooooo`;o00001_ooool2o`0001?ooooo1?l0000@ooooo`;o00002oooool2
o`0000;ooooo0_l00002ooooo`;o00002Oooool2o`000004ooooool0003o0000ooooo`?o00002?oo
ool2o`0000;ooooo0_l0000Booooo`;o00002Oooool2o`0000_ooooo0_l00002ooooo`;o00001_oo
ool2o`0000_ooooo0_l000000ooooooo0000o`000002o`0002Sooooo0_l000000ooooooo0000o`00
000Dooooo`00:Oooool01?l0003oooooo`000?l00005ooooo`;o00001Oooool2o`0000[ooooo0_l0
0007ooooo`;o00000_ooool2o`000003ooooool0003o000000Sooooo0_l0000?ooooo`;o00000ooo
ool2o`0000Kooooo0_l0000Dooooo`;o00001?ooool2o`0000Sooooo0_l000000ooooooo0000o`00
0005ooooo`;o00000_ooool4o`000004ooooool0003o0000o`0000;ooooo0_l00009ooooo`;o0000
00Coooooo`000?l0003ooooo0_l00005ooooo`;o00000_ooool2o`0000;ooooo0_l00004ooooo`;o
00003?ooool2o`0001?ooooo0_l000000ooooooo0000o`000002ooooo`;o00001_ooool2o`0000;o
oooo0_l00002ooooo`;o00000oooool2o`0000?ooooo0_l0000?ooooo`;o00005oooool2o`0001Oo
oooo000Yooooo`03o`000?oooooooooo00;ooooo1_l00004ooooo`?o00002_ooool2o`0000[ooooo
0_l00002ooooo`?o00003oooool2o`00033ooooo0_l00008ooooo`;o00002?ooool2o`0000;ooooo
0_l00003ooooo`;o000000?oooooo`000?l000002oooool2o`0000;ooooo0_l00005ooooo`Co0000
3?ooool2o`0000?ooooo0ol0000Kooooo`;o00004Oooool2o`000004ooooool0003o0000o`0001?o
oooo0_l00003ooooo`?o00001_ooool2o`0000Cooooo0_l0000Rooooo`00:Oooool00ol0003ooooo
ooooo`02ooooo`Go00001Oooool2o`0001Cooooo0_l000000ooooooo0000o`000005o`0000cooooo
1Ol00003ooooo`;o00008_ooool2o`00013ooooo0_l00006ooooo`;o00002?ooool2o`0000?ooooo
0_l00002ooooo`Co000000?oooooo`000?l000001_ooool2o`0000Gooooo0_l0000Cooooo`?o0000
<Oooool3o`0000Cooooo0_l0000=ooooo`;o00000oooool2o`0000Oooooo0_l00004ooooo`;o0000
4oooool2o`0000gooooo000Yooooo`04o`000?oooooo0000o`0000Cooooo0_l0000Cooooo`;o0000
1_ooool2o`0000?ooooo0ol0000<ooooo`Ko00001?ooool2o`0001;ooooo0_l00003ooooo`?o0000
2?ooool2o`00013ooooo0_l00006ooooo`;o00002?ooool2o`0000Oooooo1?l000000ooooooo0000
o`00000@ooooo`;o0000AOooool2o`0000Cooooo0_l00002ooooo`;o000000Coooooo`000?l0003o
oooo0_l0000Gooooo`;o00001?ooool2o`0000gooooo0_l0000=ooooo`00:Oooool4o`0000Oooooo
0_l0000>ooooo`Co00005_ooool6o`0000Kooooo0_l0000Dooooo`;o00000oooool3o`0000?ooooo
0_l0000Cooooo`;o0000<_ooool2o`0000?ooooo0_l0000Oooooo`;o0000:Oooool2o`000003oooo
ool0003o000000?o00005oooool2o`0000Cooooo0_l00008ooooo`;o00004_ooool002Wooooo00?o
0000ooooooooool02?ooool2o`0000;ooooo0_l0000:ooooo`;o00006?ooool4o`0000Sooooo0_l0
000Oooooo`;o00004oooool2o`00037ooooo0_l00004ooooo`;o00004oooool2o`0000;ooooo0_l0
0006ooooo`;o0000:_ooool2o`0000;ooooo0_l0000Wooooo`?o00004_ooool002Wooooo00?o0000
ooooooooool03?ooool2o`0009Wooooo0_l0000Iooooo`?o000000?oooooo`000?l00000<_ooool2
o`0002_ooooo0_l0000Cooooo`00:Oooool00ol0003oooooooooo`33ooooo`;o0000;?ooool2o`00
04Wooooo000Yooooo`03o`000?oooooooooo0?7ooooo0_l00019ooooo`00:Oooool2o`000;Gooooo
0_l0001?ooooo`;o0000=Oooool002Wooooo00?o0000ooooooooool0]?ooool2o`0004oooooo0_l0
000eooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0Boooool2o`000>oooooo
0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0Boooool2o`0008So
oooo0_l0001Uooooo`001_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^
k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Oooooo0_l0000`ooooo`;o
0000J_ooool2o`0006Gooooo0006ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So
8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000gooooo`;o00006_ooool2o`0001Co
oooo0_l00004ooooo`;o00001_ooool2o`000<?ooooo0006ooooo`05o`000?ooooooooooooooool0
00003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0
003oooooooooo`1Cooooo`;o00006_ooool2o`0000Kooooo0_l00033ooooo`001_ooool01Ol@413o
oooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo0;3ooooo0_l0002:ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0N_ooool2o`0003Cooooo0_l0001Mooooo`;o0000:oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o
0000ooooooooool0N_ooool2o`0009?ooooo0_l0000[ooooo`00:Oooool2o`0003Kooooo0_l0003o
ooooo`Kooooo000Yooooo`03o`000?oooooooooo03Gooooo0_l0003oooooo`Kooooo000Yooooo`03
o`000?oooooooooo0<oooooo0_l0001[ooooo`00:Oooool00ol0003oooooooooo`3?ooooo`;o0000
Joooool002Wooooo00?o0000ooooooooool0S?ooool2o`0007gooooo0_l0000_ooooo`00:Oooool2
o`0008gooooo0_l0001mooooo`;o0000;oooool002Wooooo00?o0000ooooooooool0loooool2o`00
04Oooooo000Yooooo`03o`000?oooooooooo01gooooo0_l0000<ooooo`;o00003?ooool2o`000;So
oooo0_l00017ooooo`00:Oooool00ol0003oooooooooo`0Mooooo`;o00003?ooool2o`0000cooooo
0_l0003oooooo`;ooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo:oooool2o`00013ooooo000Yooooo`03
o`000?oooooooooo0?oooooo2?ooool2o`00027ooooo0_l0000@ooooo`00:Oooool00ol0003ooooo
ooooo`3oooooo`Sooooo0_l0000cooooo`00:Oooool00ol0003oooooooooo`13ooooo`;o0000Xooo
ool2o`0005;ooooo000Yooooo`;o0000A?ooool2o`000:?ooooo0_l0001Booooo`00:Oooool00ol0
003oooooooooo`1Gooooo`;o0000hoooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0Eoooool2
o`0005gooooo0_l00024ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0]_ooool2o`0008Cooooo000>oooo
o`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolm
ooooo`003_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05o`000?ooooooooooooooool000003?ooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolmooooo`003_ooool0
1Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`3oooooocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^
k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolm
ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWo
oooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006oooo
o`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooo
oooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool0
0olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolm
ooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool0
1Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go0000
1?ooool4o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`007oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooolmoooo
o`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo
00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`007oooool00omEEEGoIVIV
o`00003oooooodOooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .34919 Mdot
.02762 .35825 Mdot
.02952 .31256 Mdot
.03143 .31112 Mdot
.03333 .35918 Mdot
.03524 .36502 Mdot
.03714 .28894 Mdot
.03905 .27973 Mdot
.04095 .22965 Mdot
.04286 .32829 Mdot
.04476 .34143 Mdot
.04667 .23451 Mdot
.04857 .36479 Mdot
.05048 .31744 Mdot
.05238 .24 Mdot
.05429 .31209 Mdot
.05619 .36106 Mdot
.0581 .36565 Mdot
.06 .34751 Mdot
.0619 .34489 Mdot
.06381 .32253 Mdot
.06571 .32767 Mdot
.06762 .28413 Mdot
.06952 .3538 Mdot
.07143 .23778 Mdot
.07333 .36856 Mdot
.07524 .35101 Mdot
.07714 .35408 Mdot
.07905 .32477 Mdot
.08095 .33467 Mdot
.08286 .27301 Mdot
.08476 .24206 Mdot
.08667 .24144 Mdot
.08857 .34287 Mdot
.09048 .36841 Mdot
.09238 .26328 Mdot
.09429 .25624 Mdot
.09619 .35373 Mdot
.0981 .2617 Mdot
.1 .25154 Mdot
.1019 .22513 Mdot
.10381 .36136 Mdot
.10571 .35815 Mdot
.10762 .376 Mdot
.10952 .37325 Mdot
.11143 .36281 Mdot
.11333 .34203 Mdot
.11524 .2687 Mdot
.11714 .37521 Mdot
.11905 .27979 Mdot
.12095 .25719 Mdot
.12286 .29087 Mdot
.12476 .3237 Mdot
.12667 .35037 Mdot
.12857 .37369 Mdot
.13048 .2311 Mdot
.13238 .26332 Mdot
.13429 .36997 Mdot
.13619 .26487 Mdot
.1381 .37412 Mdot
.14 .36596 Mdot
.1419 .23112 Mdot
.14381 .24542 Mdot
.14571 .26576 Mdot
.14762 .23085 Mdot
.14952 .24361 Mdot
.15143 .33381 Mdot
.15333 .32846 Mdot
.15524 .34879 Mdot
.15714 .33748 Mdot
.15905 .38183 Mdot
.16095 .29444 Mdot
.16286 .33952 Mdot
.16476 .32652 Mdot
.16667 .24509 Mdot
.16857 .31093 Mdot
.17048 .3244 Mdot
.17238 .36237 Mdot
.17429 .3 Mdot
.17619 .35418 Mdot
.1781 .26735 Mdot
.18 .3248 Mdot
.1819 .31784 Mdot
.18381 .36693 Mdot
.18571 .27376 Mdot
.18762 .28267 Mdot
.18952 .35943 Mdot
.19143 .36286 Mdot
.19333 .37601 Mdot
.19524 .33146 Mdot
.19714 .24656 Mdot
.19905 .29609 Mdot
.20095 .2649 Mdot
.20286 .36316 Mdot
.20476 .27 Mdot
.20667 .26772 Mdot
.20857 .31829 Mdot
.21048 .23312 Mdot
.21238 .32236 Mdot
.21429 .38043 Mdot
.21619 .3405 Mdot
.2181 .37839 Mdot
.22 .22636 Mdot
.2219 .36829 Mdot
.22381 .31297 Mdot
.22571 .34379 Mdot
.22762 .37832 Mdot
.22952 .34756 Mdot
.23143 .26432 Mdot
.23333 .32429 Mdot
.23524 .31747 Mdot
.23714 .294 Mdot
.23905 .23812 Mdot
.24095 .32228 Mdot
.24286 .35662 Mdot
.24476 .27513 Mdot
.24667 .36707 Mdot
.24857 .27998 Mdot
.25048 .26846 Mdot
.25238 .23333 Mdot
.25429 .35681 Mdot
.25619 .22375 Mdot
.2581 .27439 Mdot
.26 .3355 Mdot
.2619 .3315 Mdot
.26381 .32043 Mdot
.26571 .30647 Mdot
.26762 .26107 Mdot
.26952 .30343 Mdot
.27143 .2669 Mdot
.27333 .3136 Mdot
.27524 .32979 Mdot
.27714 .22712 Mdot
.27905 .37679 Mdot
.28095 .35946 Mdot
.28286 .32636 Mdot
.28476 .30667 Mdot
.28667 .31036 Mdot
.28857 .34075 Mdot
.29048 .22902 Mdot
.29238 .23249 Mdot
.29429 .27701 Mdot
.29619 .27406 Mdot
.2981 .34584 Mdot
.3 .36326 Mdot
.3019 .33874 Mdot
.30381 .27601 Mdot
.30571 .36533 Mdot
.30762 .35699 Mdot
.30952 .3639 Mdot
.31143 .23291 Mdot
.31333 .37862 Mdot
.31524 .33942 Mdot
.31714 .36154 Mdot
.31905 .2983 Mdot
.32095 .33678 Mdot
.32286 .28103 Mdot
.32476 .26075 Mdot
.32667 .25956 Mdot
.32857 .24553 Mdot
.33048 .28739 Mdot
.33238 .37185 Mdot
.33429 .31566 Mdot
.33619 .26117 Mdot
.3381 .25611 Mdot
.34 .33298 Mdot
.3419 .31909 Mdot
.34381 .26965 Mdot
.34571 .31981 Mdot
.34762 .34924 Mdot
.34952 .31599 Mdot
.35143 .25825 Mdot
.35333 .30431 Mdot
.35524 .3519 Mdot
.35714 .36258 Mdot
.35905 .35861 Mdot
.36095 .22819 Mdot
.36286 .26864 Mdot
.36476 .33312 Mdot
.36667 .26525 Mdot
.36857 .2978 Mdot
.37048 .32369 Mdot
.37238 .24019 Mdot
.37429 .30939 Mdot
.37619 .225 Mdot
.3781 .26789 Mdot
.38 .22882 Mdot
.3819 .27441 Mdot
.38381 .26864 Mdot
.38571 .25569 Mdot
.38762 .36601 Mdot
.38952 .2236 Mdot
.39143 .34294 Mdot
.39333 .27002 Mdot
.39524 .24336 Mdot
.39714 .27158 Mdot
.39905 .23098 Mdot
.40095 .22705 Mdot
.40286 .36337 Mdot
.40476 .27289 Mdot
.40667 .38226 Mdot
.40857 .26578 Mdot
.41048 .26568 Mdot
.41238 .29242 Mdot
.41429 .36183 Mdot
.41619 .28213 Mdot
.4181 .32119 Mdot
.42 .27667 Mdot
.4219 .35882 Mdot
.42381 .27339 Mdot
.42571 .26233 Mdot
.42762 .3357 Mdot
.42952 .36645 Mdot
.43143 .36385 Mdot
.43333 .31736 Mdot
.43524 .32393 Mdot
.43714 .31479 Mdot
.43905 .36161 Mdot
.44095 .25341 Mdot
.44286 .26288 Mdot
.44476 .34884 Mdot
.44667 .26304 Mdot
.44857 .36702 Mdot
.45048 .2381 Mdot
.45238 .32818 Mdot
.45429 .25536 Mdot
.45619 .33426 Mdot
.4581 .35839 Mdot
.46 .37569 Mdot
.4619 .28909 Mdot
.46381 .23844 Mdot
.46571 .22292 Mdot
.46762 .30359 Mdot
.46952 .30552 Mdot
.47143 .31287 Mdot
.47333 .36989 Mdot
.47524 .34628 Mdot
.47714 .22587 Mdot
.47905 .3523 Mdot
.48095 .36927 Mdot
.48286 .30952 Mdot
.48476 .33457 Mdot
.48667 .23691 Mdot
.48857 .37357 Mdot
.49048 .32863 Mdot
.49238 .38174 Mdot
.49429 .26042 Mdot
.49619 .28139 Mdot
.4981 .24922 Mdot
.5 .3518 Mdot
.5019 .3818 Mdot
.50381 .25434 Mdot
.50571 .22754 Mdot
.50762 .27349 Mdot
.50952 .28418 Mdot
.51143 .24009 Mdot
.51333 .37023 Mdot
.51524 .35215 Mdot
.51714 .38475 Mdot
.51905 .31068 Mdot
.52095 .24682 Mdot
.52286 .26962 Mdot
.52476 .37476 Mdot
.52667 .34588 Mdot
.52857 .25815 Mdot
.53048 .26443 Mdot
.53238 .37639 Mdot
.53429 .33792 Mdot
.53619 .34651 Mdot
.5381 .3341 Mdot
.54 .2558 Mdot
.5419 .36796 Mdot
.54381 .29075 Mdot
.54571 .37744 Mdot
.54762 .31796 Mdot
.54952 .36697 Mdot
.55143 .29156 Mdot
.55333 .30133 Mdot
.55524 .3479 Mdot
.55714 .25112 Mdot
.55905 .32578 Mdot
.56095 .35041 Mdot
.56286 .30372 Mdot
.56476 .26953 Mdot
.56667 .33497 Mdot
.56857 .24027 Mdot
.57048 .22893 Mdot
.57238 .34614 Mdot
.57429 .29578 Mdot
.57619 .35724 Mdot
.5781 .34068 Mdot
.58 .36503 Mdot
.5819 .26299 Mdot
.58381 .28192 Mdot
.58571 .24842 Mdot
.58762 .23153 Mdot
.58952 .23401 Mdot
.59143 .30801 Mdot
.59333 .28541 Mdot
.59524 .2605 Mdot
.59714 .34716 Mdot
.59905 .23816 Mdot
.60095 .36907 Mdot
.60286 .37117 Mdot
.60476 .38504 Mdot
.60667 .33939 Mdot
.60857 .2518 Mdot
.61048 .22671 Mdot
.61238 .33978 Mdot
.61429 .24238 Mdot
.61619 .37082 Mdot
.6181 .2665 Mdot
.62 .35319 Mdot
.6219 .36361 Mdot
.62381 .3465 Mdot
.62571 .23144 Mdot
.62762 .26755 Mdot
.62952 .34381 Mdot
.63143 .35015 Mdot
.63333 .23135 Mdot
.63524 .26606 Mdot
.63714 .23453 Mdot
.63905 .24868 Mdot
.64095 .24763 Mdot
.64286 .31791 Mdot
.64476 .38334 Mdot
.64667 .3724 Mdot
.64857 .24364 Mdot
.65048 .35333 Mdot
.65238 .27401 Mdot
.65429 .29795 Mdot
.65619 .37651 Mdot
.6581 .26964 Mdot
.66 .2336 Mdot
.6619 .26513 Mdot
.66381 .35349 Mdot
.66571 .2644 Mdot
.66762 .28977 Mdot
.66952 .37345 Mdot
.67143 .37009 Mdot
.67333 .33404 Mdot
.67524 .37212 Mdot
.67714 .36147 Mdot
.67905 .30177 Mdot
.68095 .36815 Mdot
.68286 .30833 Mdot
.68476 .27398 Mdot
.68667 .23221 Mdot
.68857 .35083 Mdot
.69048 .3051 Mdot
.69238 .2996 Mdot
.69429 .26446 Mdot
.69619 .35901 Mdot
.6981 .27056 Mdot
.7 .24245 Mdot
.7019 .30448 Mdot
.70381 .26942 Mdot
.70571 .37321 Mdot
.70762 .37613 Mdot
.70952 .26743 Mdot
.71143 .37401 Mdot
.71333 .23983 Mdot
.71524 .23003 Mdot
.71714 .32879 Mdot
.71905 .22623 Mdot
.72095 .23282 Mdot
.72286 .23512 Mdot
.72476 .28583 Mdot
.72667 .37 Mdot
.72857 .23621 Mdot
.73048 .25609 Mdot
.73238 .28569 Mdot
.73429 .27545 Mdot
.73619 .35992 Mdot
.7381 .36899 Mdot
.74 .3419 Mdot
.7419 .23145 Mdot
.74381 .36682 Mdot
.74571 .26219 Mdot
.74762 .23397 Mdot
.74952 .28127 Mdot
.75143 .31469 Mdot
.75333 .30535 Mdot
.75524 .23427 Mdot
.75714 .35256 Mdot
.75905 .23122 Mdot
.76095 .35124 Mdot
.76286 .28426 Mdot
.76476 .23613 Mdot
.76667 .37851 Mdot
.76857 .29853 Mdot
.77048 .24786 Mdot
.77238 .33631 Mdot
.77429 .27975 Mdot
.77619 .33003 Mdot
.7781 .36894 Mdot
.78 .34805 Mdot
.7819 .27385 Mdot
.78381 .3543 Mdot
.78571 .2527 Mdot
.78762 .23999 Mdot
.78952 .3604 Mdot
.79143 .32232 Mdot
.79333 .36853 Mdot
.79524 .35814 Mdot
.79714 .35671 Mdot
.79905 .31335 Mdot
.80095 .25996 Mdot
.80286 .23365 Mdot
.80476 .35067 Mdot
.80667 .27913 Mdot
.80857 .32101 Mdot
.81048 .29097 Mdot
.81238 .22768 Mdot
.81429 .35972 Mdot
.81619 .2706 Mdot
.8181 .29243 Mdot
.82 .34296 Mdot
.8219 .26405 Mdot
.82381 .36035 Mdot
.82571 .34293 Mdot
.82762 .33903 Mdot
.82952 .27695 Mdot
.83143 .22399 Mdot
.83333 .23061 Mdot
.83524 .30846 Mdot
.83714 .36938 Mdot
.83905 .37795 Mdot
.84095 .3157 Mdot
.84286 .35936 Mdot
.84476 .3499 Mdot
.84667 .22836 Mdot
.84857 .25238 Mdot
.85048 .35706 Mdot
.85238 .34808 Mdot
.85429 .38042 Mdot
.85619 .26842 Mdot
.8581 .23041 Mdot
.86 .23977 Mdot
.8619 .34651 Mdot
.86381 .28613 Mdot
.86571 .30923 Mdot
.86762 .28415 Mdot
.86952 .27929 Mdot
.87143 .35889 Mdot
.87333 .26874 Mdot
.87524 .36045 Mdot
.87714 .28328 Mdot
.87905 .26498 Mdot
.88095 .34697 Mdot
.88286 .37016 Mdot
.88476 .26258 Mdot
.88667 .26482 Mdot
.88857 .30999 Mdot
.89048 .27492 Mdot
.89238 .27202 Mdot
.89429 .31177 Mdot
.89619 .36159 Mdot
.8981 .35932 Mdot
.9 .30152 Mdot
.9019 .26082 Mdot
.90381 .36476 Mdot
.90571 .23742 Mdot
.90762 .32926 Mdot
.90952 .27052 Mdot
.91143 .23133 Mdot
.91333 .34793 Mdot
.91524 .29431 Mdot
.91714 .3639 Mdot
.91905 .3487 Mdot
.92095 .30989 Mdot
.92286 .34686 Mdot
.92476 .3512 Mdot
.92667 .36021 Mdot
.92857 .35122 Mdot
.93048 .22236 Mdot
.93238 .34357 Mdot
.93429 .31437 Mdot
.93619 .34596 Mdot
.9381 .35949 Mdot
.94 .29578 Mdot
.9419 .32855 Mdot
.94381 .35429 Mdot
.94571 .36983 Mdot
.94762 .26809 Mdot
.94952 .36878 Mdot
.95143 .2426 Mdot
.95333 .35568 Mdot
.95524 .33592 Mdot
.95714 .3353 Mdot
.95905 .35581 Mdot
.96095 .28292 Mdot
.96286 .34107 Mdot
.96476 .27743 Mdot
.96667 .36617 Mdot
.96857 .22988 Mdot
.97048 .26257 Mdot
.97238 .34933 Mdot
.97429 .30551 Mdot
.97619 .23805 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo04Oooooo0_l0000Yooooo`;o00005_ooool2o`0007Cooooo0_l0000Nooooo`;o00006_ooool0
00Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Eooooo`;o00009?oo
ool2o`0000[ooooo0_l00005ooooo`;o00007_ooool2o`0000;ooooo0_l00002ooooo`;o00004_oo
ool2o`0000;ooooo0_l00007ooooo`;o00008?ooool2o`00027ooooo0_l0000Looooo`;o00001?oo
ool2o`0001kooooo0_l0000Jooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool2o`00017ooooo0_l0000=ooooo`;o00005Oooool2o`00017ooooo0_l00002ooooo`;o00005Ooo
ool2o`0000?ooooo0ol00004ooooo`?o00005_ooool2o`0000Oooooo0_l0000Cooooo`;o00002ooo
ool2o`00023ooooo0ol0000Looooo`;o00001Oooool2o`0000;ooooo0_l00002ooooo`;o00008Ooo
ool2o`0000kooooo0006ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^
kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00002ooooo`;o00006oooool2o`000003ooooool0
003o000000;o00004_ooool2o`0000cooooo0_l0000:ooooo`?o00001?ooool2o`0000kooooo0_l0
0004ooooo`;o00001?ooool2o`0003Gooooo0_l00004ooooo`;o00002_ooool4o`0000Oooooo0_l0
0006ooooo`;o00002?ooool3o`0000Gooooo1?l00002ooooo`;o00003?ooool2o`0000Sooooo0_l0
0002ooooo`;o00000_ooool2o`0000oooooo0_l0000@ooooo`;o00003_ooool000Kooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`03o`000?oooooooooo00Cooooo0_l0000Iooooo`;o000000?oooooo`000?l00000
5?ooool2o`0000cooooo0_l0000;ooooo`;o00001?ooool2o`0003Kooooo0_l0000Oooooo`;o0000
2_ooool5o`0000Kooooo0_l00006ooooo`;o00002Oooool5o`0000;ooooo2_l0000:ooooo`;o0000
8Oooool2o`00023ooooo0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool3o`0000Gooooo
0_l0000cooooo`;o0000:Oooool2o`0001Oooooo0_l00003ooooo`;o00001Oooool2o`0000Kooooo
0_l0000@ooooo`;o00002?ooool2o`0000[ooooo0_l0000Gooooo`;o000000?oooooo`000?l00000
0_l00006ooooo`;o00000_ooool2o`0000Gooooo0_l0000Eooooo`;o00003Oooool2o`0001Gooooo
0_l0000;ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo
V9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool2o`0000Go
oooo0_l00002ooooo`;o0000;oooool2o`0002Wooooo0_l00006ooooo`;o00003oooool2o`0000?o
oooo0_l0000=ooooo`;o00004?ooool2o`0000Sooooo0_l00003ooooo`;o00006_ooool2o`0000;o
oooo0_l0000Fooooo`;o00005Oooool2o`0000gooooo0_l0000=ooooo`;o00001_ooool2o`0000_o
oooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
00Cooooo1?l00006ooooo`03o`000?oooooooooo013ooooo0_l0000Aooooo`Co00000oooool2o`00
00Sooooo0_l0000Xooooo`;o00005?ooool2o`0004Cooooo0_l00009ooooo`;o00003oooool2o`00
04oooooo0_l0000Cooooo`00:Oooool2o`0002Cooooo1?l00003ooooo`;o00002?ooool2o`0002So
oooo0_l0000eooooo`;o00001Oooool2o`0001?ooooo0_l0000?ooooo`Go00009Oooool2o`0004ko
oooo000Yooooo`03o`000?oooooooooo01Gooooo0_l0001nooooo`;o00001Oooool2o`0000[ooooo
0_l00007ooooo`;o00001Oooool2o`0000Sooooo0ol0000Wooooo`;o00000oooool2o`0001;ooooo
0_l0000eooooo`00:Oooool00ol0003oooooooooo`0Eooooo`;o0000F_ooool2o`0000oooooo0_l0
0003ooooo`;o00003_ooool2o`0000Wooooo0_l00004ooooo`;o00003_ooool2o`0003Oooooo0_l0
000Booooo`;o0000=Oooool002Wooooo00?o0000ooooooooool04oooool2o`0000Oooooo0_l00013
ooooo`;o00000oooool2o`0000Wooooo0_l0000?ooooo`;o00000oooool2o`0000kooooo0_l00006
ooooo`;o000000?oooooo`000?l00000>oooool2o`0005_ooooo000Yooooo`03o`000?oooooooooo
01?ooooo0ol00006ooooo`;o0000;Oooool2o`00013ooooo0ol000000ooooooo0000o`000003oooo
o`;o0000;?ooool2o`0000Wooooo0_l0000Cooooo`;o0000:Oooool2o`0001Gooooo0_l0000Ooooo
o`;o00008oooool002Wooooo0_l0000Cooooo`Co00002Oooool3o`0001?ooooo0_l00008ooooo`;o
00002_ooool2o`00013ooooo0ol000000ooooooo0000o`000008ooooo`;o00004?ooool2o`0000Co
oooo0ol0000>ooooo`;o00002Oooool2o`0000oooooo0_l00002ooooo`;o00004oooool4o`0000Oo
oooo0_l0000>ooooo`;o00004?ooool2o`0000Gooooo0_l0000@ooooo`Go00000oooool2o`0001Co
oooo0_l0000=ooooo`00:Oooool00ol0003oooooooooo`0Booooo`;o00002oooool3o`000003oooo
ool0003o000000Wooooo0_l00005ooooo`Co00001_ooool2o`0000_ooooo0_l0000Mooooo`;o0000
00?oooooo`000?l000002?ooool3o`0000;ooooo0_l00004ooooo`?o00006Oooool2o`0000oooooo
0_l00009ooooo`;o000000Coooooo`000?l0003ooooo0_l00006ooooo`Co00001oooool2o`0000?o
oooo0_l00009ooooo`;o00005oooool2o`00013ooooo1Ol0000Aooooo`;o00001_ooool2o`0000go
oooo000Yooooo`03o`000?oooooooooo01[ooooo0_l00007ooooo`;o00002Oooool6o`000003oa0@
4?oooooo000000?o000000?o<S8bonk^k_ooool00_ooool01_o^k^ko<S8bo`000?lb<S;ok^k^oooo
o`;o00001Oooool2o`0001Gooooo0_l00004ooooo`;o00000_ooool5o`000005ooooool0003o0000
onk^k_lb<S801?l00002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool2o`0000_ooooo0ol0
00000olb<S;oc<c<ooooo`02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01?o^k^ko0000
o`000?lb<S82o`000003ooooool0003o000000Gooooo0_l0000;ooooo`Ko00003_ooool2o`000009
oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Cok^k^oc8b<_l0003o<S8b
0_l0000;ooooo`;o00000oooool2o`0000[ooooo0_l0000:ooooo`?o000000Wo<S8bomgMgOoooooo
ooooonk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Y
ooooo`03o`000?oooooooooo00oooooo0_l00009ooooo`;o00005?ooool3o`0000?ooooo0_l00000
1?nHV9SooooooiRHV?mgMgL3ooooo`06ogMgMonHV9SooooooiRHV?mgMgOooooo0_l000000ooooooo
0000o`00000:ooooo`;o00003Oooool2o`0000Cooooo0_l00002ooooo`03oiRHV?lQ8B7o000000;o
000000Goooooo`000?l0003o0000oiRHV002o`000004ogMgMoooooooooooooooo`;o000000?ooooo
oiRHV?mgMgL05_ooool2o`0000?ooooo0_l0000;ooooo`;o000000?oooooogMgMolb<S800oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`Co0000
1oooool2o`0000;ooooo1?l0000Aooooo`03o`000?oooooooooo00;ooooo00GoMgMgo`000?l0003o
V9RHogMgM`03ooooo`04ogMgMonHV9SooooooiRHV0;o00002oooool2o`0000?ooooo0_l00005oooo
o`;o00000oooool2o`0000gooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000Yooooo`03o`000?oooooooooo00oooooo
0_l0000Oooooo`?o00001?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Co410@oooooooo
oooooooo0_l00003ooooo`;o00002Oooool5o`0001Kooooo00?oV9RHo`000?l000000oooool2o`00
0004ooooool0003o0000oa0@40;ooooo0ol00002ooooo`03oa0@4?oooooooooo01Cooooo0_l0000D
ooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo
00?o410@ooooooooool01Oooool2o`0000Wooooo0_l0000>ooooo`;o00001?ooool5o`0000?ooooo
00Go410@o`000?l0003ooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool2o`00
01;ooooo0ol0000Cooooo`04o`000?oooooo0000o`0000?ooooo00Go410@oooooooooooooooooa0@
4003ooooo`03oa0@4?oooooooooo007ooooo000Yooooo`;o00000_ooool2o`0001Sooooo0_l0000E
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oo
ooooooooooooo`Co00003?ooool2o`000003ooooool0003o000001Oooooo00?oV9RHob4Q8Oo^k^h0
0oooool01Ol0003ooooooooooooooooo000000;ooooo0_l00003ooooo`03o`000?oooooooooo02Wo
oooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`00000Rooooo`;o00001?ooool01?m4A4CogMgMooooool00003ooooo`;o00000ooo
ool01?l0003oooooooooooooool3o`000003ooooool0003ooooo00;ooooo0_l0000;ooooo`;o0000
1Oooool2o`0001?ooooo00?oMgMgoc8b<_ooool00_l00003ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`01ooooo`00:Oooool01?l0003oooooooooooooool2o`0001So
oooo0_l0000Dooooo`;o00001?ooool01Ol0003ooooooooooooooooo000000?ooooo00Ko0000oooo
ooooooooooooo`000?ooool2o`0001Gooooo0_l0000Booooo`03ogMgMomVIVKooooo00;ooooo00Co
0000oooooooooooooooo0ol000000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo013ooooo
0_l0000Fooooo`04oa0@4?l0003o^[Zjooooo`?o00000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool09Oooool2o`000003oeEEEOoooooo000000?ooooo0_l00003oooo
o`04o`000?ooooooooooooooo`?o000000?oooooo`000?ooool03oooool2o`000003ooooool0003o
000001Cooooo00Go0000ob4Q8Ol0003o<S8bolc<c003o`0000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo007ooooo000Yooooo`03o`000?oooooooooo00[ooooo0_l0
000Uooooo`;o00001?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@400Hooooo`;o00004oooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@o`00
0?l0003ooooooa0@4003ooooo`03oa0@4?oooooooooo013ooooo0_l00002ooooo`;o00004oooool0
0onj^[[o8B4Qooooo`02o`000005oa0@4?l0003o0000ooooool@41000oooool01Ol@413ooooooooo
oooooooo410@01oooooo1?l00004ooooo`;o000000CoMgMgolc<c?l0003o00000oooool01Ol@413o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@400>ooooo`Co000000?ooooo
o`000?l000005?ooool00ol0003oooooooooo`02ooooo`;o000000Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool002Wooooo00Co0000oooooooooooooooo
0_l00007ooooo`;o00009_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo0_l0000<ooooo`05o`000?nj^[[ooooo
oiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`07ooooo`;o00003Oooool2o`00013ooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05
ogMgMol0003o0000oiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo0_l0000A
ooooo`Co00001_ooool01?o^k^koA4A4o`000?l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo1?l0000Gooooo`03o`000?oooooooooo00Co
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0
02Wooooo00Co0000oooooooooooooooo0_l0000Iooooo`;o00004_ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo
0_l0000<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01?o^k^ko<S8bo`000?lb<S82o`00
00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`;o00006?ooool2o`000003ooooool0003o
000000;ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo0_l0000Looooo`03ogMgMol0003ooooo00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000o`000?o^k^h00_l0000W
ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`00:Oooool2o`0001gooooo0_l0000:ooooo`;o00002oooool2o`0000[ooooo0_l0
000fooooo`;o0000:?ooool2o`000003ooooool0003o000000Gooooo0_l0001:ooooo`;o000000?o
ooooo`000?l000007Oooool2o`0000Kooooo0_l0000Gooooo`00:Oooool00ol0003oooooooooo`0X
ooooo`;o00002oooool2o`0000[ooooo0_l0000Hooooo`;o00003_ooool2o`00043ooooo0_l0000H
ooooo`;o00008oooool2o`0002gooooo0_l00006ooooo`;o00005oooool002Wooooo00?o0000oooo
ooooool0;Oooool2o`0002cooooo0_l0000>ooooo`;o0000>_ooool2o`0001kooooo0_l00006oooo
o`;o00000_ooool2o`0001Oooooo0_l0000Xooooo`;o00009?ooool002Wooooo00?o0000oooooooo
ool0;Oooool2o`0001cooooo0_l0000Iooooo`;o00008oooool3o`0001Wooooo0_l000000ooooooo
0000o`00000Sooooo`;o00000_ooool2o`000003ooooool0003o000000oooooo0_l0000]ooooo`;o
00005_ooool2o`0000cooooo000Yooooo`03o`000?oooooooooo04[ooooo0ol00003ooooo`;o0000
5?ooool2o`0002?ooooo0ol0000Looooo`;o00001oooool2o`0001_ooooo0_l000001?oooooo0000
o`000?ooool2o`0000oooooo0_l0000Hooooo`;o0000:oooool2o`0000cooooo000Qoooooooo0000
A?l00004ooooo`00:Oooool4o`0000Gooooo0_l000000ooooooo0000ooooo`0;ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool01_ooool2o`000003ooooool0003ooooo00[ooooo00?o
0000ooooooooool00_l00008ooooo`03o`000?oooooooooo00?ooooo0_l00002ooooo`?o00002ooo
ool00ol0003oooooooooo`09ooooo`04o`000?oooooo0000o`0000Wooooo00?o0000ooooooooool0
1_ooool2o`000003ooooool0003ooooo00Kooooo0_l00002ooooo`;o00002_ooool2o`0000_ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`;o00002_ooool01?l0003ooooo
ooooooooool2o`0000Kooooo00?o0000ooooooooool02_ooool2o`0000Gooooo1?l000000ooooooo
0000ooooo`04ooooo`;o00000_ooool3o`0000_ooooo00?o0000ooooooooool02_ooool002Wooooo
0ol00005ooooo`?o00009oooool2o`0000Wooooo00?o0000ooooooooool00_l000000ooooooo0000
o`00000;ooooo`;o00004Oooool2o`0000?ooooo0_l0000Aooooo`03o`000?oooooooooo00Gooooo
0ol00009ooooo`;o00005oooool2o`0000kooooo00?o0000ooooooooool02oooool2o`00027ooooo
0_l0000:ooooo`04o`000?ooooooooooooooo`;o00002oooool2o`0001cooooo0_l0000<ooooo`03
o`000?oooooooooo00[ooooo000Yooooo`03o`000?oooooooooo00Gooooo0_l0000Xooooo`;o0000
1oooool2o`0000Kooooo0_l00007ooooo`;o00005Oooool2o`000003ooooool0003o000000;o0000
5?ooool2o`0000?ooooo0_l0000Sooooo`;o00007?ooool2o`0003Cooooo0_l00008ooooo`;o0000
=oooool002Wooooo00?o0000ooooooooool02Oooool2o`0001;ooooo0_l0000Iooooo`?o00001Ooo
ool4o`0000Gooooo0_l0000Hooooo`?o00001_ooool2o`0000gooooo0_l00004ooooo`;o0000L?oo
ool2o`0000Cooooo0_l00011ooooo`00:Oooool2o`0000[ooooo0_l00003ooooo`;o00003Oooool2
o`0000_ooooo0ol000000ooooooo0000o`000009ooooo`;o00001Oooool4o`0000cooooo0_l0000J
ooooo`;o00004oooool2o`0002Gooooo0_l00019ooooo`;o0000Aoooool002Wooooo00?o0000oooo
ooooool00_ooool2o`0000Kooooo0_l00002ooooo`;o00005_ooool2o`0000;ooooo0ol000000ooo
oooo0000o`00000Mooooo`;o000000?oooooo`000?l00000=?ooool2o`0000[ooooo0_l0000Doooo
o`;o0000<Oooool2o`00017ooooo0_l0000Xooooo`;o00002Oooool2o`0001Oooooo000Yooooo`03
o`000?oooooooooo00;ooooo0_l00006ooooo`;o00006_ooool2o`0000_ooooo0_l0000Dooooo`;o
00000_ooool2o`0001?ooooo0_l00006ooooo`;o00006_ooool2o`0000[ooooo0_l00017ooooo`;o
00004Oooool2o`0002Sooooo0_l00009ooooo`;o00005oooool002Wooooo00?o0000ooooooooool0
3oooool2o`0001Cooooo0_l0000<ooooo`;o00004oooool3o`00017ooooo0_l00004ooooo`;o0000
1_ooool2o`0001;ooooo0_l00007ooooo`;o00001oooool2o`00013ooooo0_l00007ooooo`;o0000
8?ooool2o`0001kooooo0_l0000iooooo`;o00004_ooool002Wooooo00?o0000ooooooooool03ooo
ool2o`0001Cooooo1_l0000Mooooo`;o00003?ooool2o`0000;ooooo1?l0000Pooooo`;o00001ooo
ool2o`0000Oooooo0_l0000>ooooo`Co00001oooool2o`0000_ooooo1?l0000Aooooo`;o00007_oo
ool2o`00013ooooo0_l0000Wooooo`;o00004_ooool002Wooooo0_l00004ooooo`;o00003?ooool2
o`0000Kooooo0_l0000<ooooo`Co00003oooool2o`0001Gooooo0_l00003ooooo`;o00000_ooool2
o`0001Kooooo0_l0000/ooooo`;o00003?ooool2o`0000Sooooo1?l0000Wooooo`;o00005oooool5
o`0002Wooooo0_l0000@ooooo`00:Oooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`00
00Kooooo0_l00006ooooo`;o00007oooool2o`000003ooooool0003o000001;ooooo0_l000000ooo
oooo0000o`00000Looooo`;o0000:_ooool2o`0000gooooo0ol0000?ooooo`;o00008_ooool2o`00
01Oooooo1?l0000Pooooo`Co00001_ooool2o`00013ooooo000Yooooo`;o00002Oooool3o`0001co
oooo0_l0000Dooooo`?o00005?ooool2o`0000kooooo0_l0000Nooooo`;o00001oooool2o`0000oo
oooo0_l000000ooooooo0000o`000004ooooo`;o00001?ooool2o`0000Kooooo0_l00006ooooo`Co
0000;_ooool2o`0001Kooooo0_l000000ooooooo0000o`000004ooooo`;o00002?ooool5o`000003
ooooool0003o000000;o00006?ooool002Wooooo0_l00009ooooo`;o00000oooool2o`0000kooooo
0_l00008ooooo`;o00005Oooool2o`0002Cooooo0_l000000ooooooo0000o`00000Kooooo`;o0000
1oooool4o`0000Cooooo0_l00003ooooo`;o00001Oooool2o`0000Cooooo1?l0000:ooooo`;o0000
1_ooool2o`000003ooooool0003o0000013ooooo0_l0000Eooooo`;o00001?ooool2o`0000Kooooo
0_l0000;ooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o00002?ooool7o`0000co
oooo0_l0000=ooooo`00:Oooool00ol0003oooooooooo`0;ooooo`Co00001Oooool2o`0000Oooooo
0_l0000>ooooo`;o0000>?ooool2o`0002Kooooo0_l00004ooooo`;o00000oooool2o`0000gooooo
0_l0000Aooooo`;o00000_ooool2o`0000Cooooo0_l00002ooooo`;o00001_ooool2o`0001Cooooo
0ol00006ooooo`;o00001?ooool2o`0000_ooooo0_l0000Hooooo`?o00000oooool2o`0000Oooooo
0_l0000=ooooo`00:Oooool2o`0000cooooo1?l00005ooooo`;o000000?oooooo`000?l000005?oo
ool2o`0001Cooooo0_l000000ooooooo0000o`00000@ooooo`;o0000;_ooool2o`0002Cooooo0_l0
000<ooooo`;o00002?ooool2o`0000;ooooo0_l0000Looooo`;o00001oooool2o`000004ooooool0
003o0000o`0000oooooo0_l0000Looooo`;o000000?oooooo`000?l000000_l0000Aooooo`00:Ooo
ool4o`0000Kooooo0_l0000=ooooo`?o00006Oooool2o`0000oooooo0_l000000ooooooo0000o`00
0007ooooo`;o00001oooool2o`000003ooooool0003o000000_ooooo0_l0000Booooo`;o00001?oo
ool2o`0000Cooooo0_l0000Tooooo`;o00007_ooool2o`0000Cooooo0_l0000;ooooo`;o00003ooo
ool5o`0000?ooooo0_l00002ooooo`;o00001?ooool4o`0000Gooooo0ol00005ooooo`;o00002?oo
ool2o`000003ooooool0003o000000?ooooo1?l0000Aooooo`00:Oooool01?l0003oooooo`000?l0
0003ooooo`;o000000?oooooo`000?l000003Oooool4o`0001;ooooo0_l00004ooooo`;o00000_oo
ool2o`0001Oooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l0000:ooooo`?o0000
3?ooool2o`0000;ooooo1?l000001?oooooo0000o`000?ooool2o`0003Wooooo0_l0000?ooooo`;o
00001?ooool2o`0000_ooooo0_l0000?ooooo`;o00001_ooool2o`0000;ooooo0_l00004ooooo`;o
00001oooool3o`0000Gooooo1?l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Hoooo
o`00:Oooool00ol0003oooooooooo`02o`0000;ooooo0_l000000ooooooo0000o`00000?ooooo`;o
00002?ooool2o`0000Sooooo0_l00002ooooo`Co00000_ooool2o`0000cooooo0_l0000?ooooo`Go
00003Oooool2o`0000Sooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00004ooooo`;o
00007_ooool2o`0000Sooooo0_l0000<ooooo`;o00009Oooool2o`00037ooooo0_l00003ooooo`;o
00003Oooool2o`0000oooooo000Yooooo`03o`000?oooooooooo00;o00001Oooool2o`0000?ooooo
0_l00004ooooo`;o00003?ooool4o`0000cooooo0_l0000:ooooo`;o00001_ooool2o`00017ooooo
0_l0000Hooooo`;o00003?ooool2o`0000Cooooo0_l00006ooooo`Co00002Oooool2o`0000Oooooo
1?l00008ooooo`;o00001Oooool2o`0000?ooooo0_l0000@ooooo`;o000000?oooooo`000?l00000
3?ooool2o`0000;ooooo1?l00009ooooo`;o00000oooool2o`0000cooooo0_l0000<ooooo`;o0000
4oooool3o`0000?ooooo0_l0000?ooooo`00:Oooool2o`0000gooooo0_l00004ooooo`;o00001?oo
ool2o`0000Cooooo1Ol0000Iooooo`;o00008Oooool2o`0002cooooo1?l000000ooooooo0000o`00
0006ooooo`;o00001oooool2o`00017ooooo0_l00003ooooo`;o00002?ooool2o`0000Gooooo1_l0
0006ooooo`?o00000oooool2o`0000;ooooo0_l0000;ooooo`;o00000oooool2o`0000cooooo0_l0
000<ooooo`;o00004oooool3o`0001Cooooo000Yooooo`03o`000?oooooooooo01Oooooo1Ol00002
ooooo`;o000000?oooooo`000?l000004?ooool2o`0001Wooooo0_l0000?ooooo`;o0000:?ooool2
o`0000Oooooo0_l00009ooooo`;o000000?oooooo`000?l000005?ooool2o`0000gooooo0_l00000
0ooooooo0000o`000002ooooo`Co00002?ooool3o`00067ooooo0006ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`0Gooooo`;o000000?oooooo`000?l000005oooool2o`0000Kooooo0_l0
00000ooooooo0000o`00000>ooooo`;o00002Oooool2o`0002kooooo0_l0000Booooo`;o000000?o
ooooo`000?l000000_ooool2o`0002;ooooo0_l0000>ooooo`;o00004Oooool2o`0001Gooooo0_l0
000hooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02Sooooo
0_l0000@ooooo`?o000000?oooooo`000?l000006Oooool2o`0001cooooo0_l0000Jooooo`;o0000
00?oooooo`000?l000003?ooool2o`0001kooooo0_l0000Uooooo`;o00005Oooool2o`0000?ooooo
0_l0000cooooo`001_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0
2Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Sooooo0_l0000@ooooo`;o0000
>oooool2o`0001[ooooo0_l000000ooooooo0000o`000003ooooo`;o00006_ooool2o`0000_ooooo
0_l00011ooooo`;o0000<oooool000Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0009_ooooo0_l0000Jooooo`;o0000
Poooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo
00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnH
V9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmoooo
o`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Ol@413ooooooooooooooooo410@
013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000kooooo00Go0000oooooooo
ooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmoooo
o`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005
ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooooooooooooooooa0@400<
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3o
ooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@
00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolmoooo
o`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005
ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400>
ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3o
ooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooo
oooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`;o0000oooo
oolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooo
oolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool001oooooo1?l000000ol@413o
ooooooooo`03ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo0ol0
003oooooocgooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool001oooooo00?oEEEEofIVI_l00000oooooom7ooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .39473 Mdot
.02762 .40198 Mdot
.02952 .28829 Mdot
.03143 .26026 Mdot
.03333 .31394 Mdot
.03524 .39249 Mdot
.03714 .31924 Mdot
.03905 .38463 Mdot
.04095 .32062 Mdot
.04286 .26779 Mdot
.04476 .28638 Mdot
.04667 .34067 Mdot
.04857 .40973 Mdot
.05048 .25766 Mdot
.05238 .2654 Mdot
.05429 .2588 Mdot
.05619 .37794 Mdot
.0581 .41032 Mdot
.06 .29069 Mdot
.0619 .41012 Mdot
.06381 .39194 Mdot
.06571 .39146 Mdot
.06762 .36881 Mdot
.06952 .40646 Mdot
.07143 .26718 Mdot
.07333 .32742 Mdot
.07524 .31664 Mdot
.07714 .31261 Mdot
.07905 .40058 Mdot
.08095 .39312 Mdot
.08286 .36383 Mdot
.08476 .34723 Mdot
.08667 .34903 Mdot
.08857 .37915 Mdot
.09048 .38508 Mdot
.09238 .35996 Mdot
.09429 .359 Mdot
.09619 .31842 Mdot
.0981 .36105 Mdot
.1 .36293 Mdot
.1019 .316 Mdot
.10381 .38347 Mdot
.10571 .38817 Mdot
.10762 .402 Mdot
.10952 .39925 Mdot
.11143 .31776 Mdot
.11333 .29072 Mdot
.11524 .37227 Mdot
.11714 .34827 Mdot
.11905 .37398 Mdot
.12095 .3625 Mdot
.12286 .38295 Mdot
.12476 .21999 Mdot
.12667 .38519 Mdot
.12857 .38725 Mdot
.13048 .32845 Mdot
.13238 .37236 Mdot
.13429 .37562 Mdot
.13619 .36801 Mdot
.1381 .39865 Mdot
.14 .33118 Mdot
.1419 .27447 Mdot
.14381 .34414 Mdot
.14571 .28221 Mdot
.14762 .28646 Mdot
.14952 .34992 Mdot
.15143 .27584 Mdot
.15333 .2728 Mdot
.15524 .29757 Mdot
.15714 .40003 Mdot
.15905 .36402 Mdot
.16095 .32274 Mdot
.16286 .28658 Mdot
.16476 .26704 Mdot
.16667 .3437 Mdot
.16857 .30521 Mdot
.17048 .22014 Mdot
.17238 .35805 Mdot
.17429 .38802 Mdot
.17619 .37021 Mdot
.1781 .36126 Mdot
.18 .38846 Mdot
.1819 .26436 Mdot
.18381 .38375 Mdot
.18571 .37944 Mdot
.18762 .26118 Mdot
.18952 .3139 Mdot
.19143 .3448 Mdot
.19333 .36911 Mdot
.19524 .27744 Mdot
.19714 .2555 Mdot
.19905 .22175 Mdot
.20095 .28199 Mdot
.20286 .32304 Mdot
.20476 .27538 Mdot
.20667 .23245 Mdot
.20857 .25825 Mdot
.21048 .32965 Mdot
.21238 .21952 Mdot
.21429 .35933 Mdot
.21619 .39229 Mdot
.2181 .35945 Mdot
.22 .31581 Mdot
.2219 .40163 Mdot
.22381 .38903 Mdot
.22571 .37986 Mdot
.22762 .37308 Mdot
.22952 .2892 Mdot
.23143 .28295 Mdot
.23333 .39374 Mdot
.23524 .2582 Mdot
.23714 .25916 Mdot
.23905 .34126 Mdot
.24095 .39745 Mdot
.24286 .23306 Mdot
.24476 .32021 Mdot
.24667 .34349 Mdot
.24857 .38275 Mdot
.25048 .37384 Mdot
.25238 .32463 Mdot
.25429 .40682 Mdot
.25619 .29866 Mdot
.2581 .36349 Mdot
.26 .40635 Mdot
.2619 .39731 Mdot
.26381 .26547 Mdot
.26571 .38924 Mdot
.26762 .23715 Mdot
.26952 .37665 Mdot
.27143 .28692 Mdot
.27333 .38521 Mdot
.27524 .38863 Mdot
.27714 .32279 Mdot
.27905 .39332 Mdot
.28095 .38953 Mdot
.28286 .40235 Mdot
.28476 .39405 Mdot
.28667 .39215 Mdot
.28857 .28999 Mdot
.29048 .32543 Mdot
.29238 .27864 Mdot
.29429 .22977 Mdot
.29619 .26979 Mdot
.2981 .28842 Mdot
.3 .37772 Mdot
.3019 .40652 Mdot
.30381 .38063 Mdot
.30571 .23882 Mdot
.30762 .33891 Mdot
.30952 .34337 Mdot
.31143 .34413 Mdot
.31333 .35409 Mdot
.31524 .27823 Mdot
.31714 .40957 Mdot
.31905 .3227 Mdot
.32095 .38664 Mdot
.32286 .37763 Mdot
.32476 .36065 Mdot
.32667 .36694 Mdot
.32857 .34739 Mdot
.33048 .38194 Mdot
.33238 .3362 Mdot
.33429 .39699 Mdot
.33619 .37328 Mdot
.3381 .3527 Mdot
.34 .38119 Mdot
.3419 .38277 Mdot
.34381 .37575 Mdot
.34571 .39313 Mdot
.34762 .2996 Mdot
.34952 .39882 Mdot
.35143 .35659 Mdot
.35333 .26034 Mdot
.35524 .31259 Mdot
.35714 .33452 Mdot
.35905 .32998 Mdot
.36095 .32077 Mdot
.36286 .23208 Mdot
.36476 .38506 Mdot
.36667 .29713 Mdot
.36857 .38568 Mdot
.37048 .4025 Mdot
.37238 .3505 Mdot
.37429 .25694 Mdot
.37619 .316 Mdot
.3781 .28319 Mdot
.38 .30225 Mdot
.3819 .2295 Mdot
.38381 .3733 Mdot
.38571 .36824 Mdot
.38762 .38976 Mdot
.38952 .30286 Mdot
.39143 .40858 Mdot
.39333 .277 Mdot
.39524 .25631 Mdot
.39714 .37824 Mdot
.39905 .33816 Mdot
.40095 .32138 Mdot
.40286 .32685 Mdot
.40476 .22878 Mdot
.40667 .37179 Mdot
.40857 .29888 Mdot
.41048 .29878 Mdot
.41238 .32274 Mdot
.41429 .33229 Mdot
.41619 .2246 Mdot
.4181 .38431 Mdot
.42 .27154 Mdot
.4219 .39222 Mdot
.42381 .26947 Mdot
.42571 .30289 Mdot
.42762 .2749 Mdot
.42952 .40875 Mdot
.43143 .35547 Mdot
.43333 .39188 Mdot
.43524 .26575 Mdot
.43714 .3809 Mdot
.43905 .35689 Mdot
.44095 .36637 Mdot
.44286 .30373 Mdot
.44476 .39245 Mdot
.44667 .37302 Mdot
.44857 .33997 Mdot
.45048 .33846 Mdot
.45238 .3971 Mdot
.45429 .35111 Mdot
.45619 .28161 Mdot
.4581 .31586 Mdot
.46 .40585 Mdot
.4619 .26202 Mdot
.46381 .26773 Mdot
.46571 .31469 Mdot
.46762 .25743 Mdot
.46952 .31597 Mdot
.47143 .21989 Mdot
.47333 .36814 Mdot
.47524 .2965 Mdot
.47714 .28979 Mdot
.47905 .31244 Mdot
.48095 .40241 Mdot
.48286 .38437 Mdot
.48476 .39043 Mdot
.48667 .26453 Mdot
.48857 .39149 Mdot
.49048 .39854 Mdot
.49238 .36414 Mdot
.49429 .36676 Mdot
.49619 .26615 Mdot
.4981 .35063 Mdot
.5 .37562 Mdot
.5019 .36311 Mdot
.50381 .35443 Mdot
.50571 .32944 Mdot
.50762 .31879 Mdot
.50952 .26569 Mdot
.51143 .33874 Mdot
.51333 .34699 Mdot
.51524 .31522 Mdot
.51714 .38414 Mdot
.51905 .30625 Mdot
.52095 .35639 Mdot
.52286 .37243 Mdot
.52476 .35818 Mdot
.52667 .29536 Mdot
.52857 .35413 Mdot
.53048 .29746 Mdot
.53238 .36226 Mdot
.53429 .38992 Mdot
.53619 .30485 Mdot
.5381 .38335 Mdot
.54 .35365 Mdot
.5419 .35906 Mdot
.54381 .37962 Mdot
.54571 .3871 Mdot
.54762 .25903 Mdot
.54952 .36689 Mdot
.55143 .38437 Mdot
.55333 .25578 Mdot
.55524 .28736 Mdot
.55714 .35682 Mdot
.55905 .26285 Mdot
.56095 .39088 Mdot
.56286 .38951 Mdot
.56476 .31704 Mdot
.56667 .28045 Mdot
.56857 .33994 Mdot
.57048 .32727 Mdot
.57238 .28576 Mdot
.57429 .32164 Mdot
.57619 .34689 Mdot
.5781 .40614 Mdot
.58 .33835 Mdot
.5819 .35732 Mdot
.58381 .22637 Mdot
.58571 .35219 Mdot
.58762 .28177 Mdot
.58952 .32946 Mdot
.59143 .31702 Mdot
.59333 .38239 Mdot
.59524 .24065 Mdot
.59714 .40849 Mdot
.59905 .26841 Mdot
.60095 .24152 Mdot
.60286 .36077 Mdot
.60476 .38661 Mdot
.60667 .39289 Mdot
.60857 .35865 Mdot
.61048 .29346 Mdot
.61238 .2845 Mdot
.61429 .3464 Mdot
.61619 .34596 Mdot
.6181 .30281 Mdot
.62 .40394 Mdot
.6219 .37827 Mdot
.62381 .40236 Mdot
.62571 .34108 Mdot
.62762 .31196 Mdot
.62952 .39124 Mdot
.63143 .38147 Mdot
.63333 .28446 Mdot
.63524 .31021 Mdot
.63714 .34209 Mdot
.63905 .25177 Mdot
.64095 .24972 Mdot
.64286 .26283 Mdot
.64476 .39235 Mdot
.64667 .3831 Mdot
.64857 .34226 Mdot
.65048 .29845 Mdot
.65238 .31773 Mdot
.65429 .31957 Mdot
.65619 .37376 Mdot
.6581 .37789 Mdot
.66 .32414 Mdot
.6619 .28222 Mdot
.66381 .40339 Mdot
.66571 .29386 Mdot
.66762 .32224 Mdot
.66952 .40563 Mdot
.67143 .39252 Mdot
.67333 .38161 Mdot
.67524 .33862 Mdot
.67714 .33441 Mdot
.67905 .21909 Mdot
.68095 .3564 Mdot
.68286 .37993 Mdot
.68476 .27208 Mdot
.68667 .3325 Mdot
.68857 .31804 Mdot
.69048 .38898 Mdot
.69238 .37636 Mdot
.69429 .28179 Mdot
.69619 .35699 Mdot
.6981 .23295 Mdot
.7 .3523 Mdot
.7019 .39414 Mdot
.70381 .3651 Mdot
.70571 .35274 Mdot
.70762 .37748 Mdot
.70952 .36425 Mdot
.71143 .36487 Mdot
.71333 .34882 Mdot
.71524 .27391 Mdot
.71714 .39879 Mdot
.71905 .31765 Mdot
.72095 .33915 Mdot
.72286 .34457 Mdot
.72476 .32172 Mdot
.72667 .36664 Mdot
.72857 .27128 Mdot
.73048 .36588 Mdot
.73238 .32187 Mdot
.73429 .36644 Mdot
.73619 .36462 Mdot
.7381 .39392 Mdot
.74 .3926 Mdot
.7419 .32536 Mdot
.74381 .40179 Mdot
.74571 .3648 Mdot
.74762 .32396 Mdot
.74952 .36682 Mdot
.75143 .3997 Mdot
.75333 .38073 Mdot
.75524 .2737 Mdot
.75714 .22967 Mdot
.75905 .31655 Mdot
.76095 .39185 Mdot
.76286 .31961 Mdot
.76476 .2685 Mdot
.76667 .36373 Mdot
.76857 .31936 Mdot
.77048 .35984 Mdot
.77238 .39959 Mdot
.77429 .32162 Mdot
.77619 .27097 Mdot
.7781 .337 Mdot
.78 .3012 Mdot
.7819 .37638 Mdot
.78381 .40946 Mdot
.78571 .24676 Mdot
.78762 .35036 Mdot
.78952 .38022 Mdot
.79143 .22029 Mdot
.79333 .38001 Mdot
.79524 .32503 Mdot
.79714 .31304 Mdot
.79905 .30805 Mdot
.80095 .36982 Mdot
.80286 .33898 Mdot
.80476 .31496 Mdot
.80667 .26654 Mdot
.80857 .25816 Mdot
.81048 .2577 Mdot
.81238 .33172 Mdot
.81429 .31043 Mdot
.81619 .36499 Mdot
.8181 .26012 Mdot
.82 .28503 Mdot
.8219 .30101 Mdot
.82381 .31478 Mdot
.82571 .37874 Mdot
.82762 .2785 Mdot
.82952 .27113 Mdot
.83143 .32078 Mdot
.83333 .33019 Mdot
.83524 .28197 Mdot
.83714 .38556 Mdot
.83905 .3735 Mdot
.84095 .37848 Mdot
.84286 .36574 Mdot
.84476 .30312 Mdot
.84667 .28463 Mdot
.84857 .24299 Mdot
.85048 .3996 Mdot
.85238 .22809 Mdot
.85429 .40295 Mdot
.85619 .27984 Mdot
.8581 .29158 Mdot
.86 .26541 Mdot
.8619 .30016 Mdot
.86381 .36865 Mdot
.86571 .21865 Mdot
.86762 .26358 Mdot
.86952 .32086 Mdot
.87143 .33648 Mdot
.87333 .36303 Mdot
.87524 .3678 Mdot
.87714 .22472 Mdot
.87905 .28853 Mdot
.88095 .3835 Mdot
.88286 .38258 Mdot
.88476 .28787 Mdot
.88667 .30189 Mdot
.88857 .25668 Mdot
.89048 .38121 Mdot
.89238 .31825 Mdot
.89429 .39451 Mdot
.89619 .40227 Mdot
.8981 .39646 Mdot
.9 .3862 Mdot
.9019 .35503 Mdot
.90381 .37902 Mdot
.90571 .26018 Mdot
.90762 .26974 Mdot
.90952 .37865 Mdot
.91143 .33855 Mdot
.91333 .31231 Mdot
.91524 .38805 Mdot
.91714 .3633 Mdot
.91905 .37677 Mdot
.92095 .39161 Mdot
.92286 .39471 Mdot
.92476 .29991 Mdot
.92667 .35598 Mdot
.92857 .38074 Mdot
.93048 .30996 Mdot
.93238 .38558 Mdot
.93429 .29682 Mdot
.93619 .38501 Mdot
.9381 .36941 Mdot
.94 .32386 Mdot
.9419 .27374 Mdot
.94381 .3858 Mdot
.94571 .39018 Mdot
.94762 .31157 Mdot
.94952 .35077 Mdot
.95143 .34868 Mdot
.95333 .30284 Mdot
.95524 .38872 Mdot
.95714 .27 Mdot
.95905 .33202 Mdot
.96095 .32139 Mdot
.96286 .22367 Mdot
.96476 .31856 Mdot
.96667 .40414 Mdot
.96857 .31278 Mdot
.97048 .35873 Mdot
.97238 .29841 Mdot
.97429 .38972 Mdot
.97619 .34712 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo01gooooo0_l0000<ooooo`;o00003?ooool2o`00057ooooo0_l00011oooo
o`;o00008_ooool2o`0001Kooooo0_l0000_ooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool07Oooool2o`0000cooooo0_l00008ooooo`;o00000_ooool2o`0003oooooo0_l0000@
ooooo`;o0000@Oooool2o`0002;ooooo0_l0000Fooooo`;o00000_ooool2o`0001Wooooo0_l0000@
ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo03Gooooo0_l0
0013ooooo`;o0000=?ooool2o`0005gooooo0_l0000Iooooo`;o00004?ooool000Co00000_ooool0
1Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo05?ooooo0_l0000Jooooo`;o00001_ooool2o`0003Oooooo0_l0
000fooooo`;o00007Oooool2o`0003?ooooo0006ooooo`05o`000?ooooooooooooooool000003Ooo
ool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000gooooo`;o00002_oo
ool2o`0000kooooo0_l0000Dooooo`;o00001?ooool2o`0000Kooooo0_l0001Looooo`;o00004Ooo
ool2o`0001gooooo0_l0000cooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
=oooool2o`0000[ooooo0_l00006ooooo`;o00007?ooool2o`0006[ooooo0_l0001Uooooo`001_oo
ool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo04_ooooo0_l0000:ooooo`;o0000hoooool000Kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo05Oooooo0_l0001Kooooo`Co0000COooool2o`0003Go
oooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
00Cooooo1?l00006ooooo`03o`000?oooooooooo0;Cooooo1?l0001=ooooo`;o0000=Oooool002Wo
oooo0_l00034ooooo`;o0000;?ooool2o`0004Wooooo000Yooooo`03o`000?oooooooooo0<;ooooo
0ol0000/ooooo`;o0000BOooool002Wooooo00?o0000ooooooooool0=?ooool2o`00077ooooo0_l0
000Iooooo`;o0000N?ooool002Wooooo00?o0000ooooooooool01Oooool3o`0002cooooo0_l00002
ooooo`;o00001_ooool2o`0002_ooooo0_l00005ooooo`;o00005Oooool2o`0001Sooooo1?l0001@
ooooo`;o00005oooool2o`0002Sooooo000Yooooo`04o`000?oooooo0000o`0000Cooooo0ol0000Y
ooooo`;o00001Oooool2o`0000Kooooo0ol0000Sooooo`;o00001Oooool2o`0000Gooooo0_l0000C
ooooo`Co00006?ooool2o`0005;ooooo0_l000000ooooooo0000o`00000Dooooo`;o00001?ooool2
o`0002;ooooo000Yooooo`Co0000;_ooool4o`0000kooooo0_l0000Sooooo`;o00008Oooool2o`00
00Kooooo0_l0000Eooooo`;o00006Oooool2o`0003Oooooo0_l0000>ooooo`;o00002_ooool2o`00
02;ooooo000Yooooo`03o`000?oooooooooo00;ooooo0_l000000ooooooo0000o`000005ooooo`;o
00007?ooool2o`0000?ooooo0_l0000Hooooo`;o0000=_ooool2o`0000Oooooo0_l00005ooooo`;o
000000?oooooo`000?l000000_ooool2o`0000kooooo0_l0000Iooooo`;o0000<oooool2o`0000oo
oooo0_l000000ooooooo0000o`00000^ooooo`00:Oooool00ol0003oooooooooo`02ooooo`;o0000
00?oooooo`000?l000001Oooool2o`0001cooooo0_l00004ooooo`Co000000So410@oooooooooooo
k^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o00002Ooo
ool2o`0001Oooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool3o`000003oc8b
<_l0003o000000Oooooo0_l00008ooooo`;o00000_ooool2o`00013ooooo00GoV9RHoa0@4?l0003o
<S8bolc<c003ooooo`03onk^k_lb<S;o000000;o00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
023ooooo0_l00008ooooo`Co000000Ooooooo`000?l0003o<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^o`000?l0003o<S8bonk^kP03ooooo`;o00002?ooool2o`0000gooooo0_l0000;ooooo`03odA4
A?l0003o000000;o00000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`00:Oooool00ol0003oooooooooo`0Rooooo`;o00000_ooool2o`0000[o
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0@ooooo`;o00005oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`02ooooo`?o000000?ooooooiRHV?mgMgL0:?ooool01Ol@413o^[Zj
oooooomgMgOo<S8b00?ooooo00?oMgMgoiRHV?ooool00_l00003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL04_ooool2o`0000Sooooo0_l00002ooooo`;o00001_ooool2o`000005ooooool0003o0000
o`000?ooool00_l000001?nHV9SooooooiRHV?mgMgL3ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool2o`0001Oooooo0_l00009ooooo`;o00000oooool2o`0000;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wooooo00?o0000oooooooo
ool08_ooool2o`000004ooooool0003o0000o`0000[ooooo0ol000000ooooooo0000o`000003oooo
o`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Xooooo`03oiRHV?lQ8B7o
k^k^00;ooooo0_l000001Ol@413ooooooooooooooooo410@00;ooooo1?l000000ooooooo410@oooo
o`0[ooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?o
oooo00?o410@ooooooooool04?ooool2o`0000Sooooo0_l0000:ooooo`Go00000oooool01Ol@413o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@400Wooooo`;o00001?ooool0
1?l0003oooooooooool@4103ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413ooooo
ooooo`01ooooo`00:Oooool2o`0002Kooooo0_l0000;ooooo`?o000000?oooooo`000?l000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool03Oooool2o`0000Gooooo
0_l0000Cooooo`04oiRHV?lQ8B7ok^k^ooooo`?o00000oooool01?l0003oooooooooooooool3o`00
0003ooooool0003ooooo02Sooooo0_l000000onYZJWo410@ooooo`02ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000002Sooooo00CoA4A4omgMgOoooooo0000
1?ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`;o00001oooool2o`0001kooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`01ooooo`00:Oooool00ol0003oooooooooo`0S
ooooo`;o00003Oooool00ol0003oooooooooo`03o`0000?ooooo00Co0000oooooooooooooooo0_l0
0002ooooo`03o`000?oooooooooo00gooooo0_l00005ooooo`;o00004_ooool2o`000003ogMgMomV
IVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00001Oooool2o`0002;ooooo0ol000001?nj^[[oooooooooooooool2o`0000;ooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo00Sooooo0_l00009ooooo`;o00004Oooool0
1?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000?ooooo1?l00005ooooo`;o00006oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool002Wooooo00?o0000ooooooooool00oooool2o`0001kooooo0ol00003ooooo`;o00001oooool0
0ol0003oooooooooo`02o`000005oa0@4?ooooooooooooooool@41000oooool2o`0000;ooooo00?o
410@ooooooooool01_ooool2o`00023ooooo0_l000000ooooooo0000ooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo0_l0000Tooooo`;o
00000oooool2o`0000;ooooo00Co410@oooooooooooooooo0_l00002ooooo`04oa0@4?oooooo0000
o`0000Oooooo0_l00009ooooo`;o00004_ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooo
ooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00;o00000oooool2o`0000;ooooo
0_l0000Nooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@41000oooool002Wooooo0ol00003ooooo`;o00007oooool2o`0000?o
oooo0_l00007ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02oooo
o`;o000000CoV9RHoooooonHV9SoMgMg2?ooool2o`0000?ooooo0_l000000ooooooo0000o`00000G
ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`;o00005oooool2o`000004ooooool@413oV9RHoooo
o`;o00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0_l000001?ooooooV9RHogMgMooo
ool2o`0002Kooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`02o`0000Oooooo0_l00008ooooo`Co00004_ooool00ol0003o
ooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo000Yooooo`?o00002?ooool2o`0000oooooo0_l0000Eooooo`03oeEEEOmVIVKo0000
00Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`;o000000Co<S8bo`000?lb<S;ok^k^3Ooo
ool2o`000003ooooool0003o000001Oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo0_l0000Goooo
o`;o000000KoooooojVYZOl@413o0000oa0@4?nYZJT3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02[ooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`;o00001?ooool4
o`0001;ooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo000Yooooo`;o00002Oooool2o`0000oooooo0_l00023ooooo`;o00006Ooo
ool2o`00013ooooo0_l0000looooo`;o0000<Oooool002Wooooo00?o0000ooooooooool09oooool2
o`0001kooooo0_l0000Rooooo`;o00002oooool3o`0001;ooooo0_l0000?ooooo`?o00006?ooool2
o`0000_ooooo0_l00003ooooo`;o0000E?ooool2o`0000[ooooo0_l0000=ooooo`00:Oooool00ol0
003oooooooooo`0Wooooo`;o00007_ooool2o`0001_ooooo0_l00005ooooo`;o00000_ooool2o`00
00Oooooo0ol0000Booooo`;o00004?ooool2o`0002Gooooo0_l0000Wooooo`;o00003?ooool2o`00
00_ooooo0_l00006ooooo`;o00002_ooool2o`000003ooooool0003o000000[ooooo0_l0000=oooo
o`00:Oooool00ol0003oooooooooo`0[ooooo`;o0000=oooool2o`0000Wooooo0_l000000ooooooo
0000o`000009ooooo`;o00001?ooool2o`0001cooooo0_l0000Hooooo`;o0000<_ooool2o`0000co
oooo0_l00005ooooo`;o00001?ooool2o`0000Kooooo0_l0000:ooooo`;o00001oooool2o`0001?o
oooo000Yooooo`03o`000?oooooooooo02_ooooo0_l00015ooooo`;o00002Oooool2o`0000Cooooo
0_l0000Gooooo`;o00000oooool2o`0001Sooooo0_l0000iooooo`;o00003?ooool2o`00027ooooo
0_l0000Cooooo`008Oooooooo`0004Co00001?ooool002Wooooo00Co0000ooooool0003o00002?oo
ool01?l0003oooooooooooooool2o`0000Oooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`04o`000?ooooooooooooooo`;o00001_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`;o
00000_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool00oooool2o`0000?ooooo0_l0000;ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`06ooooo`;o000000?oooooo`000?l000002_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`04o`000003ooooool0003o000000;ooooo0_l0000;ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool00_l00004ooooo`;o000000?oooooo`000?ooool00_l00005ooooo`;o
000000?oooooo`000?ooool02oooool002Wooooo00Co0000ooooool0003o00003?ooool2o`0000Ko
oooo0_l000000ooooooo0000o`00000Hooooo`;o00001_ooool3o`0002[ooooo0_l00005ooooo`;o
00002?ooool00ol0003oooooooooo`0=ooooo`Ko000000?oooooo`000?l000002Oooool2o`0000ko
oooo0_l00007ooooo`?o00002?ooool2o`0000Kooooo0_l0000:ooooo`;o00002?ooool2o`0000_o
oooo0_l00007ooooo`03o`000?oooooooooo00Co00001Oooool2o`0001[ooooo0_l0000@ooooo`;o
000000?oooooo`000?ooool02oooool002Wooooo00Co0000oooooooooooooooo0ol00009ooooo`;o
00001Oooool3o`000003ooooool0003o0000027ooooo0_l00006ooooo`;o00009?ooool2o`0000?o
oooo0_l0000Hooooo`;o00000_ooool2o`0000[ooooo1?l0000>ooooo`;o00001oooool2o`00017o
oooo0ol00009ooooo`;o00002?ooool2o`0000_ooooo1Ol0000Booooo`;o00002_ooool2o`0000Ko
oooo0_l0000Eooooo`;o00003oooool002Wooooo00Co0000oooooooooooooooo0ol0000@ooooo`;o
00004_ooool2o`0000cooooo0_l0000;ooooo`;o00002Oooool2o`0000_ooooo0_l0000<ooooo`;o
00002oooool2o`000003ooooool0003o000001gooooo0_l0000Cooooo`;o00006?ooool6o`00017o
oooo1?l00003ooooo`;o00000oooool6o`00013ooooo0_l0000:ooooo`;o00001_ooool2o`0000go
oooo0_l00005ooooo`?o00003oooool002Wooooo0_l0000=ooooo`;o00006_ooool2o`0000cooooo
0_l0000>ooooo`;o00001_ooool2o`0000;ooooo0_l00007ooooo`;o00006Oooool2o`000003oooo
ool0003o0000037ooooo0ol0000Jooooo`Co00004Oooool4o`000003ooooool0003o000000;o0000
1oooool2o`0000Cooooo0_l0000]ooooo`;o00001Oooool2o`00013ooooo000Yooooo`03o`000?oo
oooooooo00cooooo0_l0000Aooooo`;o00005oooool2o`0000cooooo0_l0000:ooooo`;o00005?oo
ool2o`0000cooooo0_l0000Oooooo`;o00004oooool2o`0000Cooooo0_l0000_ooooo`;o00003ooo
ool2o`0000_ooooo0_l0000iooooo`00:Oooool00ol0003oooooooooo`0Oooooo`;o000000?ooooo
o`000?l000005?ooool2o`0002kooooo0_l0000@ooooo`;o00006oooool2o`0001Wooooo0_l0000M
ooooo`;o00009oooool2o`0000Gooooo0_l0000Vooooo`;o00004Oooool002Wooooo00?o0000oooo
ooooool08_ooool2o`0003_ooooo0_l00006ooooo`;o00004Oooool2o`0005;ooooo0_l000000ooo
oooo0000o`00000Wooooo`;o00004Oooool2o`0001[ooooo0_l0000Aooooo`00:Oooool00ol0003o
ooooooooo`1Hooooo`;o00001Oooool2o`0000Kooooo0_l0000<ooooo`;o00003_ooool2o`0001;o
oooo0_l0000Dooooo`;o00007Oooool2o`0000cooooo0_l0000Aooooo`;o00001_ooool2o`0001Co
oooo0_l0000;ooooo`;o00008?ooool002Wooooo0_l00005ooooo`;o0000>oooool2o`0001Gooooo
0_l0000Kooooo`;o00003_ooool2o`0001;ooooo0_l0000@ooooo`;o00000_ooool2o`0000gooooo
0_l000000ooooooo0000o`000002ooooo`;o00001oooool2o`0000cooooo0_l0000Aooooo`;o0000
1_ooool2o`00027ooooo0_l0000Pooooo`00:Oooool00ol0003oooooooooo`04ooooo`;o00007Ooo
ool2o`0000Gooooo0_l00006ooooo`;o00003Oooool2o`000003ooooool0003o000001;ooooo0ol0
000Zooooo`;o00009?ooool2o`0000kooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo
0_l0000Fooooo`;o0000GOooool002Wooooo00?o0000ooooooooool04?ooool2o`0000Sooooo0_l0
0007ooooo`;o00001Oooool2o`0000Kooooo0_l0000@ooooo`;o00004_ooool3o`0000?ooooo0_l0
000jooooo`;o00004_ooool2o`0000[ooooo0ol0000Mooooo`;o000000?oooooo`000?l00000B?oo
ool2o`0000Kooooo0_l0000;ooooo`00:Oooool00ol0003oooooooooo`0@ooooo`;o00002?ooool2
o`0000Wooooo0_l0000gooooo`;o00003?ooool2o`0001Wooooo0_l0000<ooooo`;o00000oooool2
o`0001;ooooo0_l000000ooooooo0000o`000007ooooo`;o00006_ooool2o`0000;ooooo0_l0000F
ooooo`;o0000<_ooool3o`0000Kooooo0_l0000;ooooo`00:Oooool00ol0003oooooooooo`0Uoooo
o`;o0000<_ooool2o`0000Kooooo0_l00009ooooo`;o00004Oooool2o`0000Kooooo0_l0000<oooo
o`Co00001_ooool2o`000003ooooool0003o000000gooooo0_l0000Sooooo`Co00006?ooool2o`00
02?ooooo0_l0000=ooooo`;o00005?ooool002Wooooo0_l0000]ooooo`;o0000:oooool2o`0000Ko
oooo0_l00003ooooo`;o00005oooool2o`000003ooooool0003o000001?ooooo0_l00003ooooo`Go
000000?oooooo`000?l000001?ooool2o`0000Kooooo0_l0000Nooooo`;o00000_ooool2o`0000;o
oooo0_l0000mooooo`;o00001_ooool2o`0001_ooooo000Yooooo`03o`000?oooooooooo01;ooooo
1?l0000Fooooo`Co00002_ooool3o`00023ooooo0_l00007ooooo`;o00006_ooool2o`0001Sooooo
0ol00004ooooo`;o00000oooool2o`0000Kooooo0_l00004ooooo`Co00005_ooool2o`0000;ooooo
0_l0000Fooooo`;o0000<Oooool2o`0000cooooo0_l0000=ooooo`00:Oooool00ol0003ooooooooo
o`0?ooooo`;o000000?oooooo`000?l000000ol00005ooooo`;o00002_ooool2o`0000Cooooo0_l0
000:ooooo`?o00002oooool2o`0001?ooooo0_l0000dooooo`;o000000?oooooo`000?l000002?oo
ool2o`000003ooooool0003o0000017ooooo1?l0000Oooooo`;o00001_ooool2o`000003ooooool0
003o000000Gooooo0ol0000Oooooo`;o00003Oooool2o`0000oooooo0_l0000=ooooo`00:Oooool0
0ol0003oooooooooo`0?ooooo`;o00001?ooool2o`0000Gooooo0_l0000:ooooo`;o00007_ooool2
o`0001Cooooo0_l0000Rooooo`;o00003oooool5o`0000Sooooo0_l00003ooooo`;o0000<?ooool4
o`0000?ooooo1Ol000000ooooooo0000o`000002o`0000?ooooo0_l0000>ooooo`;o00001oooool2
o`0000Oooooo0ol0000<ooooo`;o00007_ooool002Wooooo00?o0000ooooooooool02_ooool2o`00
01Cooooo0_l0000;ooooo`;o00001?ooool2o`0002Wooooo0_l0000Aooooo`;o00003oooool2o`00
00Wooooo0_l00005ooooo`;o00003oooool2o`00033ooooo1?l00003ooooo`Go00000oooool2o`00
00kooooo0_l00003ooooo`;o00001oooool2o`0000Cooooo0_l00002ooooo`;o00004_ooool2o`00
01Sooooo000Yooooo`;o00002oooool2o`0000kooooo0ol00002ooooo`?o00002oooool2o`0000Co
oooo0_l00009ooooo`;o00001Oooool2o`0001[ooooo0_l0000=ooooo`?o00001?ooool2o`0000_o
oooo0_l00007ooooo`;o00003_ooool2o`0002Wooooo0_l0000/ooooo`;o00002_ooool2o`0000Ko
oooo0_l0000Fooooo`;o00006?ooool002Wooooo00?o0000ooooooooool06_ooool3o`0000;ooooo
0ol0000Looooo`;o00001Oooool2o`0000Cooooo0_l0000Dooooo`Co00002oooool2o`0000Gooooo
0_l0000;ooooo`;o00003oooool2o`0000Kooooo0_l0000Yooooo`;o00002Oooool2o`0001_ooooo
0_l0000@ooooo`;o00006?ooool2o`0001kooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`07ooooo`;o00002?ooool2o`0000gooooo0_l0000>ooooo`;o00002oooool2o`0000co
oooo0_l00008ooooo`;o00001Oooool2o`0000Gooooo0_l0000?ooooo`;o00007oooool2o`0000co
oooo0_l0000Hooooo`;o00002Oooool2o`0000Kooooo0_l000000ooooooo0000o`000003ooooo`;o
00005_ooool6o`0000Sooooo0_l00003ooooo`;o00004_ooool4o`000003ooooool0003o000001ko
oooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool01oooool2o`00
00Sooooo0_l00009ooooo`;o00004_ooool2o`0000_ooooo0_l00006ooooo`;o00003_ooool3o`00
00Cooooo0_l000001?oooooo0000o`000?ooool3o`0000oooooo0_l0000;ooooo`;o00007oooool3
o`0000kooooo0_l00008ooooo`;o000000?oooooo`000?l000000oooool2o`000003ooooool0003o
000000?ooooo0_l000000ooooooo0000o`000006ooooo`;o00003Oooool2o`0000Wooooo1?l00008
ooooo`;o00000oooool2o`0000_ooooo0_l000000ooooooo0000o`000002ooooo`Co00001?ooool2
o`0001_ooooo0006ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09
ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l0000?ooooo`;o00000_oo
ool2o`0000Cooooo0ol0000Aooooo`;o00004oooool2o`0000Kooooo0_l00007ooooo`;o00001ooo
ool2o`000004ooooool0003o0000o`0000Gooooo0ol0000>ooooo`;o00001?ooool2o`0000gooooo
0_l00009ooooo`;o00001Oooool2o`0000;ooooo0_l0000;ooooo`;o00002oooool2o`0000?ooooo
0_l00006ooooo`;o00006?ooool2o`0001Wooooo0_l0000<ooooo`;o000000Coooooo`000?l0003o
oooo0_l00007ooooo`Oo00005_ooool000Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03
oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`000003ooooool0003o000000oo
oooo0_l00002ooooo`?o00001?ooool3o`0000gooooo1Ol0000;ooooo`;o00002oooool2o`000003
ooooool0003o000000;o00002oooool2o`0000cooooo0ol0000>ooooo`;o00004oooool2o`0000Wo
oooo0_l00007ooooo`Co00000_ooool2o`0000_ooooo0_l0000Jooooo`;o0000;Oooool2o`0000co
oooo0_l00004ooooo`;o00000oooool2o`0000?ooooo1_l00002ooooo`;o00004_ooool000Kooooo
00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c005ooooo`03o`000?oooooooooo00;o00001oooool3o`0000_ooooo0_l00005oooo
o`;o00003Oooool3o`0000[ooooo0_l000000ooooooo0000o`00000;ooooo`;o000000?oooooo`00
0?l000001?l00009ooooo`;o00004oooool2o`0000Wooooo0_l00002ooooo`;o00000_ooool2o`00
00[ooooo1?l0000<ooooo`;o00000_ooool2o`0000?ooooo0ol0000;ooooo`;o00001_ooool2o`00
00?ooooo0_l00007ooooo`;o00001?ooool2o`0000kooooo0_l00004ooooo`;o0000<?ooool4o`00
00Kooooo0_l000000ooooooo0000o`000004ooooo`;o00003?ooool000Kooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool2o`00
0003ooooool0003o000000Oooooo0ol00003ooooo`;o0000:Oooool2o`0000Cooooo0_l0000<oooo
o`Go00004Oooool2o`0000_ooooo0_l00009ooooo`;o00000_ooool2o`0000;ooooo0_l0000:oooo
o`Co00003?ooool2o`0000Oooooo0_l0000=ooooo`;o00001Oooool2o`0000?ooooo0_l00007oooo
o`;o00001oooool2o`0000[ooooo0ol00004ooooo`;o0000:Oooool2o`0000Oooooo0_l00006oooo
o`;o00001oooool2o`0000cooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool2o`00013ooooo0_l0000@
ooooo`;o00007Oooool4o`0000Gooooo0_l00003ooooo`Co00003_ooool2o`0000;ooooo0ol0000O
ooooo`;o00002_ooool2o`0002Cooooo0_l0000Looooo`;o00000oooool2o`0000Gooooo0_l0000`
ooooo`?o00001_ooool2o`0001gooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o00003oooool2o`0000Oooooo0ol0
0007ooooo`;o00001?ooool2o`0001?ooooo0_l00004ooooo`;o00001Oooool2o`0001Gooooo0_l0
0003ooooo`;o00007oooool2o`0000[ooooo0_l00017ooooo`;o00001oooool4o`0000Gooooo0_l0
000Gooooo`;o00003Oooool2o`0002Gooooo000Yooooo`;o00003oooool2o`0000Oooooo0ol0000=
ooooo`;o00004oooool2o`0001;ooooo0_l0000Jooooo`;o00008Oooool2o`0002_ooooo0ol0000;
ooooo`;o00006?ooool4o`0000Gooooo0_l0000Gooooo`?o00003?ooool2o`0001Cooooo0_l0000?
ooooo`00:Oooool00ol0003oooooooooo`0;ooooo`;o0000>Oooool4o`0000Kooooo0_l00004oooo
o`;o00005?ooool2o`0001_ooooo0_l00004ooooo`;o00007Oooool2o`0000cooooo0ol0000;oooo
o`Co0000>Oooool2o`0000cooooo0_l0000Dooooo`;o00003oooool002Wooooo00?o0000oooooooo
ool01?ooool2o`000003ooooool0003o000000Co0000>Oooool4o`0000cooooo0_l00003ooooo`;o
00005Oooool2o`0000_ooooo0_l00008ooooo`;o00008oooool2o`0000Gooooo0_l0000Eooooo`;o
00008oooool2o`0004Wooooo000Yooooo`03o`000?oooooooooo00Cooooo0_l000000ooooooo0000
o`000002o`00053ooooo0_l0000Eooooo`;o00002oooool2o`0003Cooooo0_l0000jooooo`;o0000
BOooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3o
ooooocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolmooooo`003_ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3o
ooooocgooooo000>ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo000>
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_oo
ool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?oooooooooo
ooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003o
ooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0
003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooo
oooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oo
oooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo
?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo
0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`007oooool4o`00
0003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool0
1Oooool3o`000?oooooo?Oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`007oooool00omEEEGoIVIVo`00003oooooodOooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .39083 Mdot
.02762 .39627 Mdot
.02952 .27708 Mdot
.03143 .29042 Mdot
.03333 .25128 Mdot
.03524 .37053 Mdot
.03714 .30269 Mdot
.03905 .441 Mdot
.04095 .40426 Mdot
.04286 .27138 Mdot
.04476 .2573 Mdot
.04667 .42039 Mdot
.04857 .40523 Mdot
.05048 .28531 Mdot
.05238 .37292 Mdot
.05429 .29009 Mdot
.05619 .34538 Mdot
.0581 .40554 Mdot
.06 .2533 Mdot
.0619 .4259 Mdot
.06381 .41191 Mdot
.06571 .40581 Mdot
.06762 .40486 Mdot
.06952 .40969 Mdot
.07143 .37597 Mdot
.07333 .25459 Mdot
.07524 .25716 Mdot
.07714 .25349 Mdot
.07905 .42694 Mdot
.08095 .40213 Mdot
.08286 .40758 Mdot
.08476 .41872 Mdot
.08667 .42261 Mdot
.08857 .36599 Mdot
.09048 .35231 Mdot
.09238 .41198 Mdot
.09429 .41927 Mdot
.09619 .25667 Mdot
.0981 .41604 Mdot
.1 .43275 Mdot
.1019 .40845 Mdot
.10381 .35615 Mdot
.10571 .36875 Mdot
.10762 .37857 Mdot
.10952 .37581 Mdot
.11143 .25119 Mdot
.11333 .25658 Mdot
.11524 .42908 Mdot
.11714 .27492 Mdot
.11905 .41985 Mdot
.12095 .42452 Mdot
.12286 .42584 Mdot
.12476 .29537 Mdot
.12667 .37057 Mdot
.12857 .35137 Mdot
.13048 .40998 Mdot
.13238 .43565 Mdot
.13429 .33184 Mdot
.13619 .4254 Mdot
.1381 .37374 Mdot
.14 .25964 Mdot
.1419 .3856 Mdot
.14381 .4086 Mdot
.14571 .32977 Mdot
.14762 .38593 Mdot
.14952 .42086 Mdot
.15143 .26449 Mdot
.15333 .2695 Mdot
.15524 .25276 Mdot
.15714 .41315 Mdot
.15905 .29689 Mdot
.16095 .30253 Mdot
.16286 .25848 Mdot
.16476 .27315 Mdot
.16667 .40838 Mdot
.16857 .27487 Mdot
.17048 .29462 Mdot
.17238 .3043 Mdot
.17429 .42663 Mdot
.17619 .33681 Mdot
.1781 .4094 Mdot
.18 .40268 Mdot
.1819 .28207 Mdot
.18381 .35111 Mdot
.18571 .43732 Mdot
.18762 .31863 Mdot
.18952 .25112 Mdot
.19143 .27958 Mdot
.19333 .31276 Mdot
.19524 .26578 Mdot
.19714 .36608 Mdot
.19905 .3222 Mdot
.20095 .33107 Mdot
.20286 .25436 Mdot
.20476 .32674 Mdot
.20667 .34812 Mdot
.20857 .28424 Mdot
.21048 .4079 Mdot
.21238 .29689 Mdot
.21429 .28932 Mdot
.21619 .39463 Mdot
.2181 .29145 Mdot
.22 .40606 Mdot
.2219 .38552 Mdot
.22381 .41565 Mdot
.22571 .36648 Mdot
.22762 .31838 Mdot
.22952 .25332 Mdot
.23143 .33158 Mdot
.23333 .41375 Mdot
.23524 .28505 Mdot
.23714 .30802 Mdot
.23905 .41547 Mdot
.24095 .42319 Mdot
.24286 .26041 Mdot
.24476 .32463 Mdot
.24667 .27415 Mdot
.24857 .437 Mdot
.25048 .43243 Mdot
.25238 .40176 Mdot
.25429 .40738 Mdot
.25619 .40118 Mdot
.2581 .40532 Mdot
.26 .42776 Mdot
.2619 .41368 Mdot
.26381 .27918 Mdot
.26571 .42257 Mdot
.26762 .35406 Mdot
.26952 .40044 Mdot
.27143 .32658 Mdot
.27333 .40738 Mdot
.27524 .39803 Mdot
.27714 .41091 Mdot
.27905 .36041 Mdot
.28095 .37016 Mdot
.28286 .4289 Mdot
.28476 .43199 Mdot
.28667 .4245 Mdot
.28857 .25739 Mdot
.29048 .41025 Mdot
.29238 .38303 Mdot
.29429 .33876 Mdot
.29619 .32425 Mdot
.2981 .2544 Mdot
.3 .34273 Mdot
.3019 .42485 Mdot
.30381 .43717 Mdot
.30571 .25165 Mdot
.30762 .2753 Mdot
.30952 .27649 Mdot
.31143 .4281 Mdot
.31333 .28159 Mdot
.31524 .25995 Mdot
.31714 .40816 Mdot
.31905 .29836 Mdot
.32095 .38707 Mdot
.32286 .42572 Mdot
.32476 .41649 Mdot
.32667 .42989 Mdot
.32857 .41378 Mdot
.33048 .42747 Mdot
.33238 .26114 Mdot
.33429 .42887 Mdot
.33619 .44003 Mdot
.3381 .40792 Mdot
.34 .37997 Mdot
.3419 .39701 Mdot
.34381 .43478 Mdot
.34571 .417 Mdot
.34762 .25272 Mdot
.34952 .43222 Mdot
.35143 .41215 Mdot
.35333 .29719 Mdot
.35524 .25467 Mdot
.35714 .2655 Mdot
.35905 .26316 Mdot
.36095 .40705 Mdot
.36286 .3472 Mdot
.36476 .38756 Mdot
.36667 .32714 Mdot
.36857 .42417 Mdot
.37048 .43186 Mdot
.37238 .42693 Mdot
.37429 .29359 Mdot
.37619 .40868 Mdot
.3781 .32645 Mdot
.38 .39335 Mdot
.3819 .34177 Mdot
.38381 .43116 Mdot
.38571 .43723 Mdot
.38762 .36406 Mdot
.38952 .40314 Mdot
.39143 .42477 Mdot
.39333 .32605 Mdot
.39524 .37042 Mdot
.39714 .43742 Mdot
.39905 .4226 Mdot
.40095 .40966 Mdot
.40286 .25724 Mdot
.40476 .3438 Mdot
.40667 .31187 Mdot
.40857 .32621 Mdot
.41048 .32637 Mdot
.41238 .30485 Mdot
.41429 .26349 Mdot
.41619 .33549 Mdot
.4181 .39798 Mdot
.42 .32048 Mdot
.4219 .37618 Mdot
.42381 .32517 Mdot
.42571 .33281 Mdot
.42762 .26337 Mdot
.42952 .4016 Mdot
.43143 .29777 Mdot
.43333 .41696 Mdot
.43524 .2759 Mdot
.43714 .39756 Mdot
.43905 .30274 Mdot
.44095 .43666 Mdot
.44286 .33206 Mdot
.44476 .38661 Mdot
.44667 .43725 Mdot
.44857 .26921 Mdot
.45048 .41134 Mdot
.45238 .41656 Mdot
.45429 .40609 Mdot
.45619 .26277 Mdot
.4581 .25264 Mdot
.46 .38656 Mdot
.4619 .31169 Mdot
.46381 .37483 Mdot
.46571 .41146 Mdot
.46762 .29918 Mdot
.46952 .28311 Mdot
.47143 .30614 Mdot
.47333 .31696 Mdot
.47524 .25411 Mdot
.47714 .39507 Mdot
.47905 .25439 Mdot
.48095 .38611 Mdot
.48286 .40978 Mdot
.48476 .39685 Mdot
.48667 .37789 Mdot
.48857 .35996 Mdot
.49048 .419 Mdot
.49238 .29721 Mdot
.49429 .42848 Mdot
.49619 .31776 Mdot
.4981 .41389 Mdot
.5 .34999 Mdot
.5019 .29517 Mdot
.50381 .41346 Mdot
.50571 .41733 Mdot
.50762 .32522 Mdot
.50952 .31507 Mdot
.51143 .40853 Mdot
.51333 .27699 Mdot
.51524 .25577 Mdot
.51714 .33408 Mdot
.51905 .27515 Mdot
.52095 .42739 Mdot
.52286 .42832 Mdot
.52476 .29249 Mdot
.52667 .25428 Mdot
.52857 .40776 Mdot
.53048 .32851 Mdot
.53238 .29876 Mdot
.53429 .39249 Mdot
.53619 .25512 Mdot
.5381 .38315 Mdot
.54 .41005 Mdot
.5419 .30077 Mdot
.54381 .41933 Mdot
.54571 .34731 Mdot
.54762 .28423 Mdot
.54952 .31737 Mdot
.55143 .42795 Mdot
.55333 .30215 Mdot
.55524 .25322 Mdot
.55714 .42218 Mdot
.55905 .2754 Mdot
.56095 .38191 Mdot
.56286 .42586 Mdot
.56476 .32964 Mdot
.56667 .26253 Mdot
.56857 .41004 Mdot
.57048 .41241 Mdot
.57238 .25443 Mdot
.57429 .29904 Mdot
.57619 .28797 Mdot
.5781 .42215 Mdot
.58 .26852 Mdot
.5819 .40736 Mdot
.58381 .33493 Mdot
.58571 .41775 Mdot
.58762 .38457 Mdot
.58952 .40614 Mdot
.59143 .28255 Mdot
.59333 .43046 Mdot
.59524 .35327 Mdot
.59714 .42037 Mdot
.59905 .37512 Mdot
.60095 .24804 Mdot
.60286 .30098 Mdot
.60476 .33873 Mdot
.60667 .39695 Mdot
.60857 .42457 Mdot
.61048 .39431 Mdot
.61238 .25859 Mdot
.61429 .41688 Mdot
.61619 .2749 Mdot
.6181 .32533 Mdot
.62 .40524 Mdot
.6219 .34349 Mdot
.62381 .40878 Mdot
.62571 .42599 Mdot
.62762 .32794 Mdot
.62952 .38924 Mdot
.63143 .36334 Mdot
.63333 .38494 Mdot
.63524 .32934 Mdot
.63714 .42245 Mdot
.63905 .36439 Mdot
.64095 .36658 Mdot
.64286 .28266 Mdot
.64476 .35192 Mdot
.64667 .34436 Mdot
.64857 .40831 Mdot
.65048 .25028 Mdot
.65238 .32289 Mdot
.65429 .29345 Mdot
.65619 .32156 Mdot
.6581 .43896 Mdot
.66 .40074 Mdot
.6619 .33066 Mdot
.66381 .40386 Mdot
.66571 .32884 Mdot
.66762 .30712 Mdot
.66952 .38836 Mdot
.67143 .36551 Mdot
.67333 .37973 Mdot
.67524 .2638 Mdot
.67714 .26614 Mdot
.67905 .31761 Mdot
.68095 .29541 Mdot
.68286 .40208 Mdot
.68476 .32332 Mdot
.68667 .41301 Mdot
.68857 .25809 Mdot
.69048 .42343 Mdot
.69238 .40373 Mdot
.69429 .33175 Mdot
.69619 .30554 Mdot
.6981 .3446 Mdot
.7 .4266 Mdot
.7019 .43437 Mdot
.70381 .4143 Mdot
.70571 .28402 Mdot
.70762 .3294 Mdot
.70952 .41504 Mdot
.71143 .30629 Mdot
.71333 .42471 Mdot
.71524 .38746 Mdot
.71714 .41934 Mdot
.71905 .4078 Mdot
.72095 .42096 Mdot
.72286 .42527 Mdot
.72476 .31131 Mdot
.72667 .31384 Mdot
.72857 .3777 Mdot
.73048 .4323 Mdot
.73238 .31177 Mdot
.73429 .40986 Mdot
.73619 .31986 Mdot
.7381 .36941 Mdot
.74 .39385 Mdot
.7419 .40588 Mdot
.74381 .38731 Mdot
.74571 .42253 Mdot
.74762 .3999 Mdot
.74952 .40404 Mdot
.75143 .43527 Mdot
.75333 .40668 Mdot
.75524 .3805 Mdot
.75714 .26499 Mdot
.75905 .3978 Mdot
.76095 .38301 Mdot
.76286 .30975 Mdot
.76476 .37831 Mdot
.76667 .29958 Mdot
.76857 .2926 Mdot
.77048 .43209 Mdot
.77238 .41344 Mdot
.77429 .31977 Mdot
.77619 .26886 Mdot
.7781 .26406 Mdot
.78 .2536 Mdot
.7819 .4312 Mdot
.78381 .41517 Mdot
.78571 .36082 Mdot
.78762 .427 Mdot
.78952 .3506 Mdot
.79143 .29659 Mdot
.79333 .34205 Mdot
.79524 .25887 Mdot
.79714 .25223 Mdot
.79905 .27407 Mdot
.80095 .43488 Mdot
.80286 .41936 Mdot
.80476 .25646 Mdot
.80667 .32001 Mdot
.80857 .28168 Mdot
.81048 .31169 Mdot
.81238 .4198 Mdot
.81429 .24954 Mdot
.81619 .41269 Mdot
.8181 .30918 Mdot
.82 .25649 Mdot
.8219 .32937 Mdot
.82381 .25103 Mdot
.82571 .3651 Mdot
.82762 .26016 Mdot
.82952 .32035 Mdot
.83143 .41462 Mdot
.83333 .41289 Mdot
.83524 .28369 Mdot
.83714 .3523 Mdot
.83905 .3196 Mdot
.84095 .39182 Mdot
.84286 .32269 Mdot
.84476 .2529 Mdot
.84667 .39011 Mdot
.84857 .36271 Mdot
.85048 .3927 Mdot
.85238 .26941 Mdot
.85429 .37603 Mdot
.85619 .32699 Mdot
.8581 .38735 Mdot
.86 .37327 Mdot
.8619 .25431 Mdot
.86381 .40238 Mdot
.86571 .31032 Mdot
.86762 .31603 Mdot
.86952 .3192 Mdot
.87143 .27054 Mdot
.87333 .41111 Mdot
.87524 .32571 Mdot
.87714 .3342 Mdot
.87905 .32898 Mdot
.88095 .37059 Mdot
.88286 .34555 Mdot
.88476 .33282 Mdot
.88667 .32815 Mdot
.88857 .2931 Mdot
.89048 .43952 Mdot
.89238 .32693 Mdot
.89429 .42781 Mdot
.89619 .39351 Mdot
.8981 .38415 Mdot
.9 .42145 Mdot
.9019 .40588 Mdot
.90381 .34383 Mdot
.90571 .37817 Mdot
.90762 .2699 Mdot
.90952 .43944 Mdot
.91143 .42259 Mdot
.91333 .25673 Mdot
.91524 .43247 Mdot
.91714 .31326 Mdot
.91905 .3554 Mdot
.92095 .4239 Mdot
.92286 .39313 Mdot
.92476 .25166 Mdot
.92667 .30233 Mdot
.92857 .36081 Mdot
.93048 .40922 Mdot
.93238 .37816 Mdot
.93429 .27319 Mdot
.93619 .37461 Mdot
.9381 .32989 Mdot
.94 .30317 Mdot
.9419 .26912 Mdot
.94381 .36786 Mdot
.94571 .36109 Mdot
.94762 .32665 Mdot
.94952 .2845 Mdot
.95143 .42029 Mdot
.95333 .24966 Mdot
.95524 .39207 Mdot
.95714 .26506 Mdot
.95905 .26722 Mdot
.96095 .31477 Mdot
.96286 .27738 Mdot
.96476 .31848 Mdot
.96667 .39266 Mdot
.96857 .39735 Mdot
.97048 .41054 Mdot
.97238 .25253 Mdot
.97429 .42449 Mdot
.97619 .42468 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooocgooooo0006
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol0003oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_oo
ool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`;o0000]oooool2o`0004;ooooo0_l0000[ooooo`;o
00004oooool002Wooooo00Co0000ooooool0003o00005oooool2o`0000gooooo0_l00009ooooo`;o
00008oooool2o`0000_ooooo0_l0000Rooooo`;o0000;?ooool2o`0000kooooo0_l0000]ooooo`;o
00000oooool2o`0000;ooooo0_l0000Nooooo`;o00001oooool2o`0000Cooooo0_l0000=ooooo`00
:Oooool01?l0003oooooo`000?l00007ooooo`;o00000_ooool3o`0000Wooooo0_l0000=ooooo`;o
00002Oooool2o`0000;ooooo0_l00006ooooo`;o00005?ooool2o`000003ooooool0003o000000_o
oooo0_l000000ooooooo0000o`00000Oooooo`;o00000oooool4o`0000Wooooo0_l00002ooooo`;o
000000?oooooo`000?l000001?ooool2o`0000Cooooo0_l0000Gooooo`;o00009oooool2o`0000Co
oooo0_l00007ooooo`;o00001?ooool2o`0000Cooooo0_l0000Booooo`;o00003Oooool2o`0000go
oooo000Yooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`;o00000_ooool3o`0000Gooooo
0_l00003ooooo`;o00003_ooool2o`0000_ooooo0_l00006ooooo`;o00004Oooool2o`000003oooo
ool0003o0000017ooooo0_l0000=ooooo`;o00005Oooool4o`0000Wooooo0_l00002ooooo`;o0000
00?oooooo`000?l000001?ooool2o`0000Cooooo0_l0000;ooooo`;o00005_ooool2o`0001_ooooo
0_l00003ooooo`;o000000?oooooo`000?l000000oooool2o`0000Kooooo0_l00004ooooo`;o0000
3_ooool2o`00023ooooo000Yooooo`03o`000?oooooooooo00?ooooo0_l00008ooooo`;o00001Ooo
ool2o`0000?ooooo0_l00007ooooo`;o00001Oooool2o`0001Sooooo0_l0000<ooooo`;o00001ooo
ool2o`0000?ooooo0_l0000Eooooo`;o0000@_ooool2o`0001Kooooo0_l0000Pooooo`;o000000?o
ooooo`000?l000000oooool2o`000003ooooool0003o000001Wooooo0_l0000Pooooo`00:Oooool2
o`0002?ooooo0_l000000ooooooo0000o`00000Looooo`;o00005Oooool2o`0000?ooooo0_l00007
ooooo`;o00004?ooool2o`0000;ooooo0_l00007ooooo`;o00008_ooool2o`00027ooooo0_l0000H
ooooo`;o00001Oooool2o`0000kooooo0_l0000Wooooo`;o00004_ooool002Wooooo00?o0000oooo
ooooool09Oooool2o`0000cooooo0_l0000booooo`?o00004?ooool2o`0000;ooooo0_l00007oooo
o`;o00008_ooool2o`00027ooooo0_l0000Hooooo`;o00001Oooool2o`0003Oooooo0ol0000Aoooo
o`00:Oooool00ol0003oooooooooo`02ooooo`;o00008_ooool2o`0000Sooooo1Ol00002ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02?ooooo0_l00004
ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`;o00008oooool01OnHV9So410@o`000?lb<S;oc<c<00;o000000Koooooonk^k_lb
<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03oooool2o`0001Wooooo0_l0
00000ol@413oooooooooo`02o`000004oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`;o00001?ooool2o`0000Wooooo0_l00009ooooo`;o000000CoA4A4o`000?l0
003o<S8b0_l000001_ooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`00:Oooool00ol0003oooooooooo`02ooooo`;o00008_ooool2o`0000;ooooo0_l0
0006ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00_l0000Wooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`;o00008ooo
ool01Ol@413o^[ZjoooooomgMgOo<S8b00;o000000KoooooogMgMonHV9SooooooiRHV?mgMgL3oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL0:oooool01?l0003oooooooooooooool2o`000004oiRHV?oo
ooooV9RHogMgM`;ooooo0_l000001?nHV9SooooooiRHV?mgMgL;ooooo`;o00001?ooool2o`0000Wo
oooo0_l00007ooooo`Co00000oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wooooo0ol0000Jooooo`;o00003_oo
ool3o`0000Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooooooooa0@4002o`0001;ooooo0_l0000Dooooo`03oiRHV?lQ8B7ok^k^00Co
oooo00Go410@oooooooooooooooooa0@4003ooooo`04oa0@4?ooooooooooooooo`;o00005oooool4
o`0000[ooooo0_l00004ooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooo
oooooooo410@00;o000000?ooooooa0@4?ooool09oooool5o`0000?ooooo00Go410@oooooooooooo
oooooa0@4002ooooo`;o00000oooool00ol@413oooooooooo`0Sooooo`;o00001_ooool3o`000005
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo000Yoooo
o`?o00006_ooool2o`0000oooooo0_l00005ooooo`;o00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000005ooooo`;o00003Oooool2o`0001Gooooo00?o
V9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo
oooo0_l0000Gooooo`Co00002_ooool2o`0000?ooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003o
oooooooooooooooo000000?ooooo0ol000000ooooooo0000ooooo`0Wooooo`04odA4A?oMgMgooooo
o`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
;?ooool00omgMgOo<S8bo`000002o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo007ooooo000Yooooo`03o`000?oooooooooo02oooooo0_l000000ooooooo0000
o`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00Gooooo0_l0000>ooooo`;o00005Oooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000[ooooo0_l0000Nooooo`03oa0@4?l0
003o^[Zj00?ooooo0ol000000ooooooo0000ooooo`02ooooo`05o`000?ooooooooooooooool00000
1?ooool2o`0002;ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooool000000_l00005ooooo`;o00008_ooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool002Wooooo00?o0000ooooooooool01Oooool2o`0002Sooooo0_l000000ooooooo0000oooo
o`03ooooo`05oa0@4?l0003o0000ooooool@41000oooool01Ol@413o0000o`000?oooooo410@01Go
oooo0_l0000Fooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo
410@00?ooooo00?o410@ooooooooool02?ooool2o`0001Oooooo0_l00006ooooo`03okZj^_lQ8B7o
oooo00;ooooo00Go410@o`000?l0003ooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100
1?ooool2o`0001?ooooo0_l0000>ooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooo
oooooa0@4003ooooo`05oa0@4?oooooo0000o`000?l@41001Oooool2o`0002;ooooo0ol00004oooo
o`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo000Y
ooooo`03o`000?oooooooooo00Gooooo0ol0000Zooooo`03o`000?oooooooooo00;ooooo00?oMgMg
o`000?l000000_l00003ooooo`05ogMgMol0003o0000oiRHV?mgMgL0:Oooool01Ol0003o^[Zjoooo
oonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL08oooool2o`0000?ooooo00Co410@oiRHV?oooooo^[Zj0_l00002ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01Wooooo0_l0000>ooooo`03onk^
k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL0:Oooool3o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool002Wooooo00Co0000ooooool0003o00001Oooool2o`0002Sooooo00?o
EEEEofIVI_l000001?ooool00oo^k^ko<S8bo`000003o`0000;ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0Yooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`;o00002oooool01?nYZJWo410@o`000?l@
4102o`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h0:_ooool00omgMgOo0000ooooo`02o`000006ooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^01Kooooo0_l0000Aooooo`Co00000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool4o`0001cooooo
0_l0000<ooooo`;o00003_ooool2o`00033ooooo0_l0000Wooooo`;o00001Oooool2o`0002Sooooo
0_l00007ooooo`;o00006_ooool2o`0002Cooooo0_l0000Xooooo`00:Oooool00ol0003ooooooooo
o`0Mooooo`;o00002Oooool2o`000003ooooool0003o000000cooooo0_l0000Pooooo`;o00002Ooo
ool2o`0000Gooooo0_l0000@ooooo`;o00002_ooool2o`0000Kooooo0_l000000ooooooo0000o`00
0008ooooo`;o00002oooool2o`0001Sooooo0_l00007ooooo`;o00008Oooool2o`0004Oooooo000Y
ooooo`03o`000?oooooooooo02Sooooo0_l0000?ooooo`;o00008?ooool2o`0000Wooooo0_l0000G
ooooo`;o00002_ooool2o`0000Kooooo0_l0000;ooooo`;o000000?oooooo`000?l000000_ooool2
o`0000Cooooo0_l00007ooooo`;o0000<oooool2o`0000Kooooo0_l0000Zooooo`;o00006oooool0
02Wooooo00Co0000oooooooooooooooo0_l0000Uooooo`;o00000_ooool2o`0004_ooooo0_l00007
ooooo`;o00007oooool2o`0000;ooooo0_l0000=ooooo`;o00007?ooool2o`0001Gooooo0_l0000b
ooooo`;o00000_ooool2o`0001Oooooo000Yooooo`04o`000?ooooooooooooooo`;o0000:Oooool2
o`0001?ooooo0_l0000fooooo`;o00001oooool2o`0000Sooooo0_l0000mooooo`;o00001oooool2
o`0000?ooooo0_l00018ooooo`;o00005oooool0027oooooool00014o`0000Cooooo000Yooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool2o`0000Gooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`;o00002oooool00ol0003oooooooooo`02ooooo`;o
00001Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02_ooool01?l0003oooooooooooooool4o`0000Cooooo00Co0000oooooooooooooooo0_l00006
ooooo`03o`000?oooooooooo00Cooooo0_l000001?oooooo0000o`000?l0000<ooooo`;o00002_oo
ool00ol0003oooooooooo`02ooooo`;o00001Oooool00ol0003oooooooooo`04ooooo`;o00000ooo
ool00ol0003oooooooooo`0:ooooo`00:Oooool00ol0003oooooooooo`0cooooo`;o00001Oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo01;ooooo0_l00005ooooo`;o00000_ooool2
o`0000_ooooo0_l0000>ooooo`03o`000?oooooooooo01Oooooo0_l0000=ooooo`;o00004_ooool0
0ol0003oooooooooo`0Gooooo`;o00003_ooool2o`0000cooooo0_l00003ooooo`03o`000?oooooo
oooo00[ooooo000Yooooo`03o`000?oooooooooo037ooooo0_l0000;ooooo`;o0000??ooool2o`00
00oooooo0_l00005ooooo`;o00000_ooool2o`0000_ooooo0_l0000Xooooo`;o00004?ooool2o`00
00_ooooo0_l00008ooooo`;o00001Oooool2o`000003ooooool0003o000000Sooooo0_l0000Moooo
o`;o00003oooool002Wooooo00?o0000ooooooooool0<Oooool2o`0000;ooooo0_l00007ooooo`;o
00005?ooool2o`0002Kooooo0_l00018ooooo`Co00001oooool2o`0000kooooo0_l0000;ooooo`;o
00002?ooool2o`0000Gooooo0_l000000ooooooo0000o`000002o`0000Kooooo0_l0000Mooooo`;o
00003oooool002Wooooo0_l0000fooooo`?o00002oooool2o`0000Oooooo0_l00006ooooo`;o0000
5Oooool2o`000003ooooool0003o000000?ooooo0_l00003ooooo`?o00000_ooool2o`0001Wooooo
0_l0000Qooooo`;o00002Oooool4o`0000Oooooo0_l0000aooooo`;o00000_ooool2o`0000Cooooo
0_l00004ooooo`;o00003oooool2o`0001Gooooo000Yooooo`03o`000?oooooooooo02?ooooo0_l0
000Aooooo`;o00002oooool2o`0000Oooooo0_l0000Mooooo`;o000000?oooooo`000?l000000ooo
ool2o`0000?ooooo0ol00002ooooo`;o00006Oooool2o`0000Gooooo0_l00009ooooo`;o00003ooo
ool2o`000004ooooool0003o0000ooooo`;o00002?ooool2o`0000_ooooo0_l0000Sooooo`;o0000
2Oooool2o`0000Cooooo0ol000000ooooooo0000o`000002o`0000cooooo0_l000000ooooooo0000
o`00000Eooooo`00:Oooool00ol0003oooooooooo`0Pooooo`;o000000?oooooo`000?l000004?oo
ool2o`0000Sooooo0_l0000looooo`;o00001?ooool2o`0001[ooooo0_l00009ooooo`;o00004_oo
ool2o`000003ooooool0003o000000Kooooo1?l00007ooooo`;o00000_ooool2o`0002?ooooo0_l0
000@ooooo`Go00003_ooool2o`0001Sooooo000Yooooo`03o`000?oooooooooo023ooooo0_l0000;
ooooo`;o00001_ooool2o`0000Sooooo0_l0000iooooo`;o000000?oooooo`000?l000001?ooool2
o`0001Kooooo0_l0000Cooooo`;o00005oooool2o`0000Wooooo0_l0000iooooo`Co0000:Oooool0
02Wooooo00?o0000ooooooooool0;Oooool2o`0002Cooooo0_l0000Uooooo`;o00007oooool2o`00
01?ooooo0_l00005ooooo`;o0000E_ooool2o`0002_ooooo000Yooooo`;o0000E?ooool4o`0001So
oooo0_l00016ooooo`;o0000>oooool2o`0004Kooooo000Yooooo`03o`000?oooooooooo00Oooooo
0_l0001<ooooo`;o00006?ooool2o`0000Kooooo0_l00014ooooo`;o00001_ooool2o`0000kooooo
0_l0000Mooooo`;o00006_ooool2o`0000Gooooo0_l0000Sooooo`00:Oooool00ol0003ooooooooo
o`07ooooo`;o0000;_ooool2o`00033ooooo0_l0000<ooooo`;o0000:oooool2o`0001Oooooo0_l0
0006ooooo`;o00003_ooool2o`0003Wooooo0_l00005ooooo`;o00008oooool002Wooooo00?o0000
ooooooooool04_ooool2o`0000[ooooo0_l0000@ooooo`;o00001Oooool2o`00033ooooo0_l0000Z
ooooo`;o00003Oooool2o`0001kooooo0_l0000/ooooo`;o00003_ooool2o`0003Sooooo000Yoooo
o`03o`000?oooooooooo01;ooooo0_l0000:ooooo`;o00004?ooool2o`0001Wooooo0_l00018oooo
o`;o00007Oooool2o`0000kooooo0_l0000/ooooo`;o00003_ooool2o`0001Sooooo0_l0000Noooo
o`00:Oooool2o`0001Oooooo0_l0000cooooo`;o0000Ioooool2o`0006Kooooo0_l0000Nooooo`00
:Oooool00ol0003oooooooooo`0Fooooo`;o0000=_ooool2o`0004;ooooo0_l0001Mooooo`;o0000
;?ooool2o`0000Cooooo0_l0000Eooooo`00:Oooool00ol0003oooooooooo`1>ooooo`;o00008Ooo
ool2o`0001oooooo0_l0000/ooooo`Co0000;Oooool2o`0001;ooooo0_l0000Hooooo`;o00001?oo
ool2o`0001Gooooo000Yooooo`03o`000?oooooooooo017ooooo0_l0000Qooooo`;o00001oooool2
o`0003;ooooo0_l0001=ooooo`Go00002?ooool2o`0002oooooo0_l00005ooooo`;o00007Oooool2
o`0001Kooooo000Yooooo`03o`000?oooooooooo00;o00003oooool2o`0000Cooooo0_l00004oooo
o`;o00005Oooool2o`0000Oooooo0_l0000@ooooo`;o00008oooool2o`0004gooooo0_l00008oooo
o`;o00004oooool2o`0001[ooooo0_l0000@ooooo`;o00004_ooool2o`0001Kooooo000Yooooo`;o
000000?oooooo`000?l000000oooool2o`00013ooooo0_l00004ooooo`;o00000_ooool2o`0002co
oooo0_l0000Sooooo`;o0000K?ooool2o`0002Gooooo0_l00005ooooo`;o0000:_ooool002Wooooo
00?o0000ooooooooool01Oooool2o`0000Gooooo0_l0000:ooooo`;o00001oooool2o`0005Wooooo
0_l0000<ooooo`;o0000:Oooool2o`00053ooooo1?l0000Gooooo`;o00006?ooool000Kooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo00cooooo0_l00009ooooo`?o0000B?ooool2o`0001So
oooo0_l0000<ooooo`;o00001Oooool2o`0002;ooooo0_l0000Fooooo`;o00004?ooool2o`0000[o
oooo0_l0000Jooooo`;o00003oooool2o`0000Kooooo1?l0000Hooooo`001_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo01Oooooo0_l0000jooooo`;o00003Oooool2o`00
02gooooo0_l0000?ooooo`;o00001Oooool2o`0002;ooooo0_l0000@ooooo`;o00001_ooool6o`00
02_ooooo0_l00006ooooo`;o00006_ooool000Kooooo00Go410@oooooooooooooooooa0@400<oooo
o`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Roooo
o`Co00005_ooool2o`0001Gooooo0_l0000dooooo`;o00001?ooool2o`00017ooooo0_l00005oooo
o`;o00001oooool2o`0000cooooo0_l0000Uooooo`Co0000:_ooool2o`0002Gooooo0006ooooo`05
o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo
00Cooooo0ol0000Rooooo`Co00005_ooool2o`0001kooooo0_l0000<ooooo`;o00006?ooool2o`00
00?ooooo0_l00004ooooo`;o00008Oooool2o`0000_ooooo0ol0000:ooooo`;o00003Oooool2o`00
00Oooooo0_l0000Sooooo`;o00002_ooool2o`0002Gooooo0006ooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool2
o`0005gooooo0_l0000<ooooo`;o00006?ooool2o`0001[ooooo0_l0000Mooooo`;o00002oooool2
o`0000gooooo0_l00007ooooo`;o00007Oooool5o`000003ooooool0003o000001gooooo0_l00000
0ooooooo0000o`00000?ooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`07ooooo`;o0000>oooool2o`0003?ooooo0_l0000M
ooooo`;o00004?ooool2o`0001Oooooo0_l0000Xooooo`;o00007_ooool5o`0000gooooo0_l00006
ooooo`;o00002Oooool2o`000003ooooool0003o000000oooooo0006ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01ooo
ool2o`0003_ooooo0_l0000Aooooo`;o00005?ooool2o`0000[ooooo0_l0000:ooooo`;o00001?oo
ool2o`0000_ooooo1?l0000Vooooo`?o0000:?ooool2o`0000Cooooo0_l0000Zooooo`;o00001_oo
ool2o`0000gooooo0_l0000>ooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`0004Oooooo0ol00002ooooo`Co0000
5?ooool2o`0001Kooooo0_l00002ooooo`Co00003Oooool2o`0002Kooooo0_l0000?ooooo`;o0000
1Oooool2o`0001?ooooo0_l00002ooooo`;o0000@Oooool2o`0000kooooo000Yooooo`;o00000ooo
ool4o`0000Cooooo0_l00003ooooo`;o00007Oooool2o`0001Kooooo0ol00002ooooo`;o00009Ooo
ool2o`0000_ooooo0_l00018ooooo`?o00001?ooool2o`000003ooooool0003o0000013ooooo0ol0
000Rooooo`;o0000<?ooool002Wooooo00?o0000ooooooooool00_ooool4o`000004ooooool0003o
0000ooooo`;o00000oooool2o`0001gooooo0_l00008ooooo`;o000000?oooooo`000?l000002Ooo
ool4o`0000?ooooo0_l0000<ooooo`;o00001?ooool2o`0000Kooooo0_l00007ooooo`;o00004ooo
ool2o`0001Kooooo0_l0000?ooooo`Co00002?ooool2o`0000Oooooo0_l00003ooooo`;o00001ooo
ool2o`0000Oooooo0_l00005ooooo`;o000000Coooooo`000?l0003o00008Oooool2o`0000_ooooo
0_l0000Sooooo`00:Oooool00ol0003oooooooooo`07ooooo`;o000000Coooooo`000?l0003o0000
0_ooool2o`0000Cooooo0_l00008ooooo`;o00000_ooool2o`0000Gooooo0_l00002ooooo`;o0000
2?ooool2o`000003ooooool0003o000000Wooooo1?l00003ooooo`?o00000_ooool2o`0000Oooooo
0_l00004ooooo`;o00001_ooool2o`0000?ooooo0_l00006ooooo`;o00003Oooool4o`0000Oooooo
0_l00007ooooo`;o00001?ooool2o`000003ooooool0003o000000Oooooo0_l00003ooooo`Co0000
2?ooool3o`0000Kooooo0_l0000Eooooo`;o00000oooool4o`0000;ooooo0_l0000Tooooo`;o0000
2?ooool2o`0000Oooooo0_l0000;ooooo`;o00003Oooool002Wooooo00?o0000ooooooooool02Ooo
ool4o`0000Gooooo0_l000000ooooooo0000o`000008ooooo`;o00000_ooool2o`0000;ooooo0_l0
00000ooooooo0000o`000002ooooo`;o00004?ooool2o`0000Oooooo0_l00003ooooo`;o00000_oo
ool2o`0000[ooooo0_l00006ooooo`;o00001_ooool2o`0000Kooooo0_l0000=ooooo`;o00000ooo
ool2o`0000Cooooo0_l00003ooooo`Ko00001oooool2o`0000Oooooo0ol0000?ooooo`;o00004_oo
ool2o`0000Cooooo0_l00008ooooo`;o00002_ooool2o`0000cooooo0_l00004ooooo`;o00002_oo
ool2o`00017ooooo0_l0000;ooooo`;o00003Oooool002Wooooo00?o0000ooooooooool02Oooool2
o`0000Oooooo1?l0000Aooooo`;o00005?ooool2o`000004ooooool0003o0000o`0000Kooooo0_l0
000Booooo`?o00001?ooool4o`0001Sooooo0_l00004ooooo`;o00000_ooool2o`0000Wooooo1?l0
000Cooooo`;o00003?ooool2o`0001Gooooo0_l00004ooooo`Co00004_ooool2o`0000;ooooo0_l0
0008ooooo`;o00000oooool3o`0003Wooooo000Yooooo`;o00001Oooool2o`0000[ooooo0_l00000
1?oooooo0000o`000?l00005ooooo`;o00008?ooool2o`0000;ooooo0_l0000Jooooo`;o00001Ooo
ool2o`0001[ooooo0_l00004ooooo`;o00002_ooool2o`0000?ooooo0_l0000:ooooo`;o00003?oo
ool2o`0000;ooooo0_l00003ooooo`;o00007Oooool4o`0001Cooooo0_l00004ooooo`;o000000?o
ooooo`000?l000001?ooool2o`0002Gooooo0_l0000Cooooo`00:Oooool00ol0003oooooooooo`04
ooooo`;o00002_ooool2o`000003ooooool0003o000000Kooooo0_l00008ooooo`;o00006oooool2
o`0000Kooooo0_l0000Yooooo`;o00006oooool2o`0000oooooo0_l00003ooooo`;o00001?ooool2
o`000003ooooool0003o000000;ooooo0_l0000:ooooo`;o00004?ooool2o`0000Kooooo0ol00006
ooooo`;o00004Oooool2o`000003ooooool0003o000001[ooooo0_l00002ooooo`;o00002oooool2
o`0001?ooooo000Yooooo`03o`000?oooooooooo00Wooooo0_l00003ooooo`Co00002_ooool2o`00
00;ooooo0_l00003ooooo`;o00001_ooool2o`0001?ooooo0_l00006ooooo`;o00001Oooool2o`00
00?ooooo0_l00004ooooo`;o00003Oooool3o`0000Cooooo0_l000000ooooooo0000o`00000aoooo
o`Co00000_ooool2o`0000Sooooo0_l00004ooooo`;o000000?oooooo`000?l000004?ooool2o`00
0003ooooool0003o000000;ooooo1Ol00005ooooo`;o00003?ooool2o`0002;ooooo0_l00002oooo
o`;o000000?oooooo`000?l000003oooool3o`0000_ooooo000Yooooo`03o`000?oooooooooo00Wo
oooo0_l00003ooooo`;o00002_ooool4o`0000;ooooo0_l0000;ooooo`;o00006Oooool2o`0000Ko
oooo0ol00003ooooo`;o000000Coooooo`000?l0003ooooo1_l00009ooooo`?o00001?ooool2o`00
023ooooo0_l00006ooooo`?o00001oooool2o`0000;ooooo0_l0000<ooooo`;o00001?ooool2o`00
01Kooooo0_l00002ooooo`;o000000?oooooo`000?l000004oooool2o`00023ooooo0_l00007oooo
o`;o00003oooool3o`0000_ooooo000Yooooo`03o`000?oooooooooo01Gooooo0_l00003ooooo`;o
0000:Oooool2o`000003ooooool0003o000000Kooooo0_l00007ooooo`;o00000oooool4o`0000?o
oooo0_l00005ooooo`;o00000_ooool2o`0002;ooooo0_l00006ooooo`?o00001oooool2o`0000_o
oooo0_l0000Zooooo`;o00002oooool2o`0000;ooooo0_l0000Rooooo`;o00001Oooool2o`0001oo
oooo000Yooooo`;o00005_ooool2o`0000Sooooo0_l0000Tooooo`;o00002Oooool2o`00017ooooo
1?l00005ooooo`;o00000_ooool2o`00047ooooo0_l0000Qooooo`;o00001oooool2o`0000Gooooo
0_l00004ooooo`;o00000_ooool2o`0000Cooooo0_l0000Sooooo`;o00007oooool002Wooooo00?o
0000ooooooooool07oooool2o`0000oooooo0_l0000Cooooo`;o00003oooool2o`0000_ooooo0_l0
000<ooooo`;o000000?oooooo`000?l000003?ooool4o`0004;ooooo0_l0000<ooooo`;o00003_oo
ool2o`0000kooooo0_l0000Qooooo`;o00008Oooool002Wooooo00Co0000oooooooooooooooo0_l0
000]ooooo`;o00004oooool2o`0000oooooo0_l00009ooooo`;o00003_ooool2o`000003ooooool0
003o000000cooooo1?l00012ooooo`;o0000BOooool2o`0000Cooooo0_l0000Qooooo`00:Oooool0
1?l0003oooooooooooooool2o`0005kooooo0_l0002`ooooo`;o00009oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`3oooooocgooooo000>ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`03ooooo`?o0000oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05
o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000
ooooooooool0oooooolmooooo`003_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool0
00kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`000?oooooo?_ooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onY
ZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05
o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo0000
00kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000
ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool0
00Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`007oooool4o`000003oa0@4?oooooooooo00?o
oooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Ooo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`007oooool00omEEEGoIVIVo`00003oooooodOooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .33748 Mdot
.02762 .34112 Mdot
.02952 .30598 Mdot
.03143 .33602 Mdot
.03333 .29151 Mdot
.03524 .29917 Mdot
.03714 .26994 Mdot
.03905 .44793 Mdot
.04095 .43846 Mdot
.04286 .33121 Mdot
.04476 .31651 Mdot
.04667 .45067 Mdot
.04857 .35129 Mdot
.05048 .34105 Mdot
.05238 .43424 Mdot
.05429 .33845 Mdot
.05619 .26848 Mdot
.0581 .35132 Mdot
.06 .31388 Mdot
.0619 .39224 Mdot
.06381 .38244 Mdot
.06571 .37072 Mdot
.06762 .39146 Mdot
.06952 .36347 Mdot
.07143 .43807 Mdot
.07333 .27724 Mdot
.07524 .28631 Mdot
.07714 .29187 Mdot
.07905 .40386 Mdot
.08095 .3617 Mdot
.08286 .4019 Mdot
.08476 .44077 Mdot
.08667 .44676 Mdot
.08857 .3034 Mdot
.09048 .27318 Mdot
.09238 .41455 Mdot
.09429 .43009 Mdot
.09619 .28479 Mdot
.0981 .42158 Mdot
.1 .45312 Mdot
.1019 .45145 Mdot
.10381 .28087 Mdot
.10571 .29994 Mdot
.10762 .30569 Mdot
.10952 .30294 Mdot
.11143 .28777 Mdot
.11333 .31242 Mdot
.11524 .43645 Mdot
.11714 .25462 Mdot
.11905 .41627 Mdot
.12095 .43711 Mdot
.12286 .41928 Mdot
.12476 .4069 Mdot
.12667 .30651 Mdot
.12857 .26998 Mdot
.13048 .44207 Mdot
.13238 .4495 Mdot
.13429 .25418 Mdot
.13619 .43334 Mdot
.1381 .29944 Mdot
.14 .27196 Mdot
.1419 .4487 Mdot
.14381 .42361 Mdot
.14571 .33096 Mdot
.14762 .4364 Mdot
.14952 .44236 Mdot
.15143 .32455 Mdot
.15333 .32585 Mdot
.15524 .30723 Mdot
.15714 .37682 Mdot
.15905 .2441 Mdot
.16095 .26794 Mdot
.16286 .31579 Mdot
.16476 .33145 Mdot
.16667 .42362 Mdot
.16857 .29001 Mdot
.17048 .40641 Mdot
.17238 .24866 Mdot
.17429 .4158 Mdot
.17619 .26295 Mdot
.1781 .40809 Mdot
.18 .36745 Mdot
.1819 .33181 Mdot
.18381 .27241 Mdot
.18571 .44575 Mdot
.18762 .34604 Mdot
.18952 .29162 Mdot
.19143 .25609 Mdot
.19333 .24532 Mdot
.19524 .3222 Mdot
.19714 .43343 Mdot
.19905 .41997 Mdot
.20095 .33367 Mdot
.20286 .28137 Mdot
.20476 .33489 Mdot
.20667 .43496 Mdot
.20857 .34036 Mdot
.21048 .43671 Mdot
.21238 .40823 Mdot
.21429 .24634 Mdot
.21619 .34753 Mdot
.2181 .24631 Mdot
.22 .44686 Mdot
.2219 .31997 Mdot
.22381 .39283 Mdot
.22571 .30367 Mdot
.22762 .24581 Mdot
.22952 .31537 Mdot
.23143 .33343 Mdot
.23333 .38432 Mdot
.23524 .34026 Mdot
.23714 .34063 Mdot
.23905 .44023 Mdot
.24095 .39948 Mdot
.24286 .3848 Mdot
.24476 .28318 Mdot
.24667 .25803 Mdot
.24857 .44181 Mdot
.25048 .44156 Mdot
.25238 .42945 Mdot
.25429 .35849 Mdot
.25619 .45429 Mdot
.2581 .3977 Mdot
.26 .39973 Mdot
.2619 .3806 Mdot
.26381 .33125 Mdot
.26571 .40646 Mdot
.26762 .43739 Mdot
.26952 .37479 Mdot
.27143 .31893 Mdot
.27333 .38011 Mdot
.27524 .35798 Mdot
.27714 .44958 Mdot
.27905 .27957 Mdot
.28095 .30137 Mdot
.28286 .406 Mdot
.28476 .42049 Mdot
.28667 .40741 Mdot
.28857 .3128 Mdot
.29048 .44562 Mdot
.29238 .43901 Mdot
.29429 .42545 Mdot
.29619 .33928 Mdot
.2981 .3157 Mdot
.3 .26503 Mdot
.3019 .39374 Mdot
.30381 .44426 Mdot
.30571 .37849 Mdot
.30762 .26097 Mdot
.30952 .25762 Mdot
.31143 .46263 Mdot
.31333 .24989 Mdot
.31524 .32393 Mdot
.31714 .35731 Mdot
.31905 .26786 Mdot
.32095 .33805 Mdot
.32286 .42436 Mdot
.32476 .42288 Mdot
.32667 .4434 Mdot
.32857 .43072 Mdot
.33048 .42356 Mdot
.33238 .26724 Mdot
.33429 .41131 Mdot
.33619 .45734 Mdot
.3381 .41369 Mdot
.34 .3293 Mdot
.3419 .3618 Mdot
.34381 .44436 Mdot
.34571 .39143 Mdot
.34762 .3052 Mdot
.34952 .41617 Mdot
.35143 .41827 Mdot
.35333 .3355 Mdot
.35524 .29138 Mdot
.35714 .26711 Mdot
.35905 .27166 Mdot
.36095 .44388 Mdot
.36286 .43411 Mdot
.36476 .34062 Mdot
.36667 .30809 Mdot
.36857 .41323 Mdot
.37048 .41178 Mdot
.37238 .45391 Mdot
.37429 .34127 Mdot
.37619 .45192 Mdot
.3781 .32351 Mdot
.38 .43502 Mdot
.3819 .43015 Mdot
.38381 .43957 Mdot
.38571 .45679 Mdot
.38762 .28939 Mdot
.38952 .45398 Mdot
.39143 .39151 Mdot
.39333 .33136 Mdot
.39524 .44059 Mdot
.39714 .44717 Mdot
.39905 .45761 Mdot
.40095 .44849 Mdot
.40286 .27668 Mdot
.40476 .43426 Mdot
.40667 .2435 Mdot
.40857 .30437 Mdot
.41048 .3048 Mdot
.41238 .26823 Mdot
.41429 .26962 Mdot
.41619 .4298 Mdot
.4181 .36222 Mdot
.42 .33083 Mdot
.4219 .3107 Mdot
.42381 .34121 Mdot
.42571 .31333 Mdot
.42762 .32612 Mdot
.42952 .34501 Mdot
.43143 .24901 Mdot
.43333 .3926 Mdot
.43524 .33208 Mdot
.43714 .36478 Mdot
.43905 .24897 Mdot
.44095 .45752 Mdot
.44286 .31096 Mdot
.44476 .33134 Mdot
.44667 .45204 Mdot
.44857 .26179 Mdot
.45048 .43478 Mdot
.45238 .38659 Mdot
.45429 .41162 Mdot
.45619 .31904 Mdot
.4581 .28902 Mdot
.46 .31783 Mdot
.4619 .33782 Mdot
.46381 .4352 Mdot
.46571 .4588 Mdot
.46762 .34079 Mdot
.46952 .27612 Mdot
.47143 .41154 Mdot
.47333 .24779 Mdot
.47524 .30771 Mdot
.47714 .45115 Mdot
.47905 .29165 Mdot
.48095 .32036 Mdot
.48286 .38574 Mdot
.48476 .35383 Mdot
.48667 .44492 Mdot
.48857 .28041 Mdot
.49048 .39002 Mdot
.49238 .24407 Mdot
.49429 .44075 Mdot
.49619 .33636 Mdot
.4981 .42771 Mdot
.5 .27732 Mdot
.5019 .24444 Mdot
.50381 .42304 Mdot
.50571 .45579 Mdot
.50762 .28504 Mdot
.50952 .33419 Mdot
.51143 .42888 Mdot
.51333 .25509 Mdot
.51524 .28829 Mdot
.51714 .25096 Mdot
.51905 .28885 Mdot
.52095 .44895 Mdot
.52286 .43476 Mdot
.52476 .24708 Mdot
.52667 .30877 Mdot
.52857 .41195 Mdot
.53048 .31044 Mdot
.53238 .24533 Mdot
.53429 .34561 Mdot
.53619 .29892 Mdot
.5381 .3335 Mdot
.54 .41701 Mdot
.5419 .24741 Mdot
.54381 .4096 Mdot
.54571 .26425 Mdot
.54762 .33915 Mdot
.54952 .24871 Mdot
.55143 .42209 Mdot
.55333 .34438 Mdot
.55524 .31729 Mdot
.55714 .43809 Mdot
.55905 .33623 Mdot
.56095 .3235 Mdot
.56286 .41276 Mdot
.56476 .29351 Mdot
.56667 .32038 Mdot
.56857 .43069 Mdot
.57048 .44811 Mdot
.57238 .31841 Mdot
.57429 .26847 Mdot
.57619 .25379 Mdot
.5781 .38871 Mdot
.58 .2632 Mdot
.5819 .40796 Mdot
.58381 .42607 Mdot
.58571 .43388 Mdot
.58762 .43867 Mdot
.58952 .43337 Mdot
.59143 .27543 Mdot
.59333 .42909 Mdot
.59524 .43088 Mdot
.59714 .38282 Mdot
.59905 .43498 Mdot
.60095 .37577 Mdot
.60286 .2465 Mdot
.60476 .25409 Mdot
.60667 .35157 Mdot
.60857 .44105 Mdot
.61048 .44585 Mdot
.61238 .31788 Mdot
.61429 .43791 Mdot
.61619 .25618 Mdot
.6181 .29876 Mdot
.62 .3571 Mdot
.6219 .26562 Mdot
.62381 .36575 Mdot
.62571 .46146 Mdot
.62762 .29506 Mdot
.62952 .33779 Mdot
.63143 .29593 Mdot
.63333 .43654 Mdot
.63524 .29922 Mdot
.63714 .45337 Mdot
.63905 .43512 Mdot
.64095 .44189 Mdot
.64286 .33385 Mdot
.64476 .26678 Mdot
.64667 .26324 Mdot
.64857 .42493 Mdot
.65048 .30741 Mdot
.65238 .2827 Mdot
.65429 .27034 Mdot
.65619 .24728 Mdot
.6581 .45058 Mdot
.66 .42789 Mdot
.6619 .33262 Mdot
.66381 .35488 Mdot
.66571 .31507 Mdot
.66762 .26897 Mdot
.66952 .32165 Mdot
.67143 .2895 Mdot
.67333 .32841 Mdot
.67524 .26444 Mdot
.67714 .26698 Mdot
.67905 .42074 Mdot
.68095 .24827 Mdot
.68286 .3748 Mdot
.68476 .33423 Mdot
.68667 .44407 Mdot
.68857 .28455 Mdot
.69048 .40844 Mdot
.69238 .38165 Mdot
.69429 .33522 Mdot
.69619 .24954 Mdot
.6981 .42877 Mdot
.7 .45145 Mdot
.7019 .42515 Mdot
.70381 .41406 Mdot
.70571 .2505 Mdot
.70762 .25086 Mdot
.70952 .41638 Mdot
.71143 .24543 Mdot
.71333 .45116 Mdot
.71524 .45298 Mdot
.71714 .39045 Mdot
.71905 .44849 Mdot
.72095 .45333 Mdot
.72286 .45651 Mdot
.72476 .27068 Mdot
.72667 .24713 Mdot
.72857 .43672 Mdot
.73048 .44926 Mdot
.73238 .27081 Mdot
.73429 .40383 Mdot
.73619 .25141 Mdot
.7381 .2956 Mdot
.74 .34566 Mdot
.7419 .43695 Mdot
.74381 .3234 Mdot
.74571 .43082 Mdot
.74762 .42641 Mdot
.74952 .39183 Mdot
.75143 .42139 Mdot
.75333 .38317 Mdot
.75524 .43948 Mdot
.75714 .38922 Mdot
.75905 .42961 Mdot
.76095 .32474 Mdot
.76286 .27121 Mdot
.76476 .44111 Mdot
.76667 .24463 Mdot
.76857 .27064 Mdot
.77048 .45491 Mdot
.77238 .37784 Mdot
.77429 .2766 Mdot
.77619 .32832 Mdot
.7781 .26563 Mdot
.78 .30322 Mdot
.7819 .43658 Mdot
.78381 .37145 Mdot
.78571 .43537 Mdot
.78762 .45419 Mdot
.78952 .27447 Mdot
.79143 .40675 Mdot
.79333 .26249 Mdot
.79524 .27767 Mdot
.79714 .29199 Mdot
.79905 .28751 Mdot
.80095 .4505 Mdot
.80286 .4503 Mdot
.80476 .28826 Mdot
.80667 .3385 Mdot
.80857 .34111 Mdot
.81048 .3457 Mdot
.81238 .45844 Mdot
.81429 .29575 Mdot
.81619 .41094 Mdot
.8181 .33955 Mdot
.82 .31825 Mdot
.8219 .30841 Mdot
.82381 .29077 Mdot
.82571 .30204 Mdot
.82762 .32354 Mdot
.82952 .33132 Mdot
.83143 .45902 Mdot
.83333 .44615 Mdot
.83524 .30944 Mdot
.83714 .27278 Mdot
.83905 .24625 Mdot
.84095 .35571 Mdot
.84286 .25261 Mdot
.84476 .3016 Mdot
.84667 .44666 Mdot
.84857 .44398 Mdot
.85048 .33636 Mdot
.85238 .39112 Mdot
.85429 .29971 Mdot
.85619 .32902 Mdot
.8581 .43389 Mdot
.86 .43491 Mdot
.8619 .30396 Mdot
.86381 .38666 Mdot
.86571 .41624 Mdot
.86762 .33894 Mdot
.86952 .27654 Mdot
.87143 .26402 Mdot
.87333 .40975 Mdot
.87524 .25365 Mdot
.87714 .42797 Mdot
.87905 .32156 Mdot
.88095 .30824 Mdot
.88286 .26522 Mdot
.88476 .32978 Mdot
.88667 .30507 Mdot
.88857 .34173 Mdot
.89048 .44839 Mdot
.89238 .28801 Mdot
.89429 .41167 Mdot
.89619 .3353 Mdot
.8981 .3224 Mdot
.9 .40727 Mdot
.9019 .40728 Mdot
.90381 .26553 Mdot
.90571 .45065 Mdot
.90762 .32938 Mdot
.90952 .45079 Mdot
.91143 .45718 Mdot
.91333 .29077 Mdot
.91524 .42746 Mdot
.91714 .24871 Mdot
.91905 .28552 Mdot
.92095 .40674 Mdot
.92286 .3421 Mdot
.92476 .30535 Mdot
.92667 .24939 Mdot
.92857 .2918 Mdot
.93048 .45904 Mdot
.93238 .32129 Mdot
.93429 .29912 Mdot
.93619 .31477 Mdot
.9381 .25623 Mdot
.94 .26737 Mdot
.9419 .32491 Mdot
.94381 .30053 Mdot
.94571 .28356 Mdot
.94762 .29316 Mdot
.94952 .25168 Mdot
.95143 .44247 Mdot
.95333 .30329 Mdot
.95524 .34597 Mdot
.95714 .33114 Mdot
.95905 .26853 Mdot
.96095 .27273 Mdot
.96286 .39796 Mdot
.96476 .2773 Mdot
.96667 .33174 Mdot
.96857 .43247 Mdot
.97048 .41292 Mdot
.97238 .30648 Mdot
.97429 .40982 Mdot
.97619 .4528 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooocgooooo0006
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol0003oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_oo
ool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0Moooool2o`000<?ooooo0006ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006oooo
o`03o`000?oooooooooo02Sooooo0_l00009ooooo`;o00001Oooool3o`000003ooooool0003o0000
03Oooooo0_l0000Jooooo`;o000000?oooooo`000?l000002?ooool2o`0001Cooooo0_l0000Qoooo
o`;o00004?ooool2o`0001Gooooo0_l0000hooooo`00:Oooool2o`0002Wooooo0_l00002ooooo`;o
00001Oooool2o`0000Gooooo0ol000000ooooooo0000o`00000oooooo`;o000000?oooooo`000?l0
00002Oooool2o`0000Cooooo0_l000000ooooooo0000o`000005ooooo`;o000000Coooooo`000?l0
003ooooo1?l0000?ooooo`;o00004?ooool2o`0000Kooooo0_l00002ooooo`;o00000oooool2o`00
00?ooooo0_l0000;ooooo`;o00005Oooool2o`0001Sooooo0_l000000ooooooo0000o`00000Koooo
o`00:Oooool00ol0003oooooooooo`0/ooooo`;o0000:oooool2o`0002Cooooo0_l000000ooooooo
0000o`000009ooooo`;o00003?ooool4o`0000Cooooo1?l0000Qooooo`;o00001_ooool2o`0000;o
oooo0_l00002ooooo`;o00001?ooool2o`000003ooooool0003o0000027ooooo0_l0000Fooooo`;o
000000?oooooo`000?l000001Oooool2o`0001Cooooo000Yooooo`03o`000?oooooooooo01[ooooo
0_l00004ooooo`;o0000=oooool2o`0003oooooo0ol0000Aooooo`;o00001oooool2o`0001oooooo
0_l00007ooooo`;o00008Oooool2o`0000Sooooo0_l0000Fooooo`;o00005?ooool002Wooooo00?o
0000ooooooooool06_ooool2o`0000Cooooo0_l0000@ooooo`;o00004?ooool2o`0001;ooooo0_l0
0010ooooo`;o00004_ooool2o`0000Oooooo0_l00002ooooo`;o0000DOooool2o`0001;ooooo0_l0
000Hooooo`00:Oooool00ol0003oooooooooo`0booooo`;o00004?ooool2o`0001;ooooo0_l0000[
ooooo`;o0000=?ooool2o`0006Gooooo0_l0000Hooooo`00:Oooool2o`0002kooooo0_l0000Voooo
o`;o000000?oooooo`000?l00000:oooool2o`0001gooooo0_l00009ooooo`;o00005?ooool2o`00
00Oooooo0_l0000Tooooo`;o00005oooool2o`000003ooooool0003o000002[ooooo000Yooooo`03
o`000?oooooooooo02Sooooo0_l00003ooooo`;o00009_ooool2o`0000Cooooo0_l00002ooooo`;o
00001_ooool2o`00013ooooo0_l0000Yooooo`;o00002Oooool2o`0000cooooo0_l00005ooooo`?o
00001oooool2o`0001oooooo0_l00003ooooo`;o00005oooool2o`000003ooooool0003o000000Go
oooo0_l0000:ooooo`;o00005oooool002Wooooo00Co0000oooooooooooooooo0_l00004ooooo`;o
00005Oooool2o`0000Sooooo0_l00006ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o
<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Gooooo`;o00000_ooool2o`0000Kooooo
0_l00004ooooo`Go00000oooool01?o^k^ko<S8bo`000?lb<S83o`000006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^:?ooool00onHV9So410@o`000002o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`03onk^k_lb<S;o000000;o00001Oooool2o`000003ooooool0003o000000;ooooo0_l0
00000ooooooo0000o`00000>ooooo`Co00001oooool5o`000006ooooool0003o0000o`000?lb<S;o
k^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo0_l0000:ooooo`;o000000CoA4A4o`00
0?l0003o<S8b0_l000001_ooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`00:Oooool01?l0003oooooooooooooool2o`0000Cooooo0_l00009ooooo`;o
00002_ooool2o`0000;ooooo0_l0000<ooooo`?o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Tooooo`;o00000oooool01OnHV9So8B4Qonk^k_oo
ooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02o`000006oooooomgMgOoV9RHoooooonH
V9SoMgMg:?ooool00ol@413o^[Zjooooo`02o`0000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool2o`0000;ooooo0_l0000Aooooo`Co00002?oo
ool4o`000004oooooomgMgOoV9RHooooo`;o00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Ko
oooo0_l0000Tooooo`09ogMgMol0003o0000o`000?mgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool00ol0003oooooooooo`0<ooooo`;o00001?oo
ool2o`0000kooooo0_l0000<ooooo`?o00001?ooool01Ol@413ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooooooooa0@400Tooooo`;o00001?ooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?l0003o0000ooooool@41000oooool01Ol@413ooooooooooooooooo410@00[ooooo0_l00007
ooooo`;o00005oooool01Ol0003ooooooooooooooooo410@00;o000000?ooooooa0@4?ooool00_oo
ool01Ol@413ooooooooooooooooo410@02Sooooo1Ol00002ooooo`;o00000_ooool4o`000003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool01?ooool2o`0000Sooooo0_l0000Kooooo`Co0000
0oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool00Oooool002Wooooo
0_l0000=ooooo`;o00009?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000[ooooo0_l0000Oooooo`03oiRHV?lQ8B7ok^k^
00?ooooo0ol000000ooooooo0000ooooo`02ooooo`05o`000?ooooooooooooooool000002_ooool2
o`0000Cooooo0_l000000ooooooo0000o`00000Fooooo`03ojVYZOl@413ooooo00;ooooo0ol00000
0ooooooo0000ooooo`02ooooo`05o`000?ooooooooooooooool00000:?ooool01?m4A4CogMgMoooo
ool00003ooooo`;o00000oooool3o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
3_ooool2o`0001[ooooo00?oMgMgoc8b<_ooool00_l00003ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`01ooooo`00:Oooool00ol0003oooooooooo`0Fooooo`;o0000
6_ooool01?l0003oooooooooooooool2o`0000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`;o00002Oooool2o`00023ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`00000@ooooo`;o00006?ooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Oo
oooo0_l0000Oooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool00000:Oooool3o`000005oc8b<_o<c<coooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00Oooool002Wooooo
00?o0000ooooooooool03Oooool2o`0000Gooooo1?l0000Jooooo`04o`000?ooooooooooooooo`;o
00000oooool01Ol@413ooooooooooooooooo410@00?ooooo0_l0000/ooooo`05o`000?oooooooooo
ooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool05?oo
ool2o`0001?ooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooooooooa0@4007ooooo`;o00002_ooool2o`0001Cooooo00?oMgMgolc<c?l0
00001?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@400P
ooooo`;o00001oooool2o`0000Gooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oo
ooooooooooooool@41000oooool002Wooooo00?o0000ooooooooool03Oooool2o`0000Gooooo0_l0
0002ooooo`;o00004Oooool2o`0000Gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Yooooo`04o`000?nj^[[ooooooiRH
V0;o00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`06ooooo`;o00003_ooool6o`0000cooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo0_l00003oooo
o`;o00005?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool3
o`000003oooooonHV9SoMgMg01Sooooo0_l00006ooooo`;o00001oooool00ol0003oooooooooo`04
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
000Yooooo`04o`000?oooooo0000o`0000cooooo0_l00009ooooo`;o00004Oooool2o`0000?ooooo
00CoEEEEofIVI_l0003o00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Sooooo`;o00001?ooool01?nHV9So410@o`000?lQ8B42o`0000;ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool2o`0000Go
oooo0_l00009ooooo`Co00003?ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool2o`0001[ooooo00?o
MgMgo`000?ooool00oooool01_o^k^ko<S8bo`000?lb<S;ok^k^ooooo`Go000000Co<S8bonk^k_oo
oooooooo0_l0000Dooooo`;o00001?ooool2o`0000?ooooo0_l00004ooooo`Co00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool4
o`0000cooooo0_l0000Sooooo`;o0000<oooool2o`0002Kooooo0_l0000Iooooo`;o00004_ooool4
o`00023ooooo0_l0000Aooooo`;o00000oooool2o`0000;ooooo0_l0000Jooooo`;o00000oooool2
o`0000Cooooo0_l0000Eooooo`00:Oooool00ol0003oooooooooo`02o`0001oooooo0_l0001noooo
o`;o00001oooool2o`0000oooooo0_l000000ooooooo0000o`000003o`0001oooooo0_l0000Foooo
o`;o00009Oooool2o`0001Wooooo000Yooooo`03o`000?oooooooooo00;o00005Oooool2o`0000So
oooo0_l0000/ooooo`;o0000D?ooool2o`0001Sooooo0_l00004ooooo`;o0000>oooool2o`0000Co
oooo0_l000000ooooooo0000o`00000Hooooo`;o000000?oooooo`000?l000005_ooool002Wooooo
00?o0000ooooooooool04Oooool2o`0000Cooooo0ol0000Sooooo`;o00004?ooool2o`0001?ooooo
0_l0000Booooo`?o0000M?ooool2o`0000gooooo0_l00004ooooo`;o000000Coooooo`000?l0003o
oooo0_l00006ooooo`;o00002_ooool2o`0000Cooooo0_l000000ooooooo0000o`00000Cooooo`00
:Oooool3o`00017ooooo0_l00004ooooo`?o00000oooool2o`0000Sooooo0_l0000Dooooo`;o0000
9Oooool2o`0000Gooooo0_l0000;ooooo`?o00004_ooool2o`0000oooooo0_l0000Vooooo`;o0000
9oooool2o`0000cooooo0_l0000;ooooo`;o00001?ooool4o`0000[ooooo0_l00007ooooo`;o0000
1?ooool2o`0000gooooo000Qoooooooo0000A?l00004ooooo`00:Oooool00ol0003oooooooooo`08
ooooo`;o00003?ooool00ol0003oooooooooo`02o`0000Oooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool3
o`0000_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`04o`000?oooooo
ooooooooo`?o00001?ooool2o`0000_ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`02o`0000Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02o`0000Sooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`;o00002oooool00ol0003ooooooooo
o`0:ooooo`00:Oooool00ol0003oooooooooo`03ooooo`;o00000oooool2o`0000oooooo0_l0000>
ooooo`;o00003oooool01?l0003oooooooooooooool2o`00017ooooo0_l000000ooooooo0000o`00
000Rooooo`03o`000?oooooooooo00;ooooo0_l0000:ooooo`;o00007?ooool2o`0000cooooo00?o
0000ooooooooool00_ooool2o`0000oooooo0_l0000Uooooo`03o`000?oooooooooo02gooooo0_l0
000;ooooo`03o`000?oooooooooo00[ooooo000Yooooo`03o`000?oooooooooo00?ooooo0_l0000T
ooooo`;o00004Oooool4o`0000cooooo0_l00006ooooo`;o0000<Oooool4o`0000Cooooo0_l0000F
ooooo`;o00000_ooool4o`0000_ooooo0_l0000?ooooo`;o0000;oooool2o`0003kooooo000Yoooo
o`03o`000?oooooooooo03?ooooo0_l00007ooooo`;o00003_ooool2o`0000cooooo0_l0000Boooo
o`;o00005oooool2o`0000Kooooo0_l0000Hooooo`Ko00007Oooool2o`0001Kooooo0_l0000Foooo
o`;o000000?oooooo`000?l000003_ooool2o`0000Cooooo0_l00009ooooo`;o00006_ooool002Wo
oooo0_l0000Vooooo`?o00002oooool2o`0002Gooooo0_l0000Booooo`;o00003_ooool2o`0002Wo
oooo0_l0000Qooooo`;o00005_ooool2o`0000?ooooo0_l0000Dooooo`;o00003_ooool2o`0000Co
oooo0_l00009ooooo`;o000000?oooooo`000?l000005oooool002Wooooo00?o0000ooooooooool0
9Oooool3o`0003[ooooo0_l0000Jooooo`;o0000COooool2o`0001[ooooo0_l00003ooooo`;o0000
6?ooool2o`0000Oooooo0_l00005ooooo`;o00002Oooool2o`0001Oooooo000Yooooo`03o`000?oo
oooooooo00;ooooo0_l0000Oooooo`;o00001Oooool2o`0000?ooooo0_l00004ooooo`;o00002?oo
ool2o`0000Sooooo0_l0000Gooooo`;o00003oooool2o`0000Oooooo0_l00003ooooo`;o000000?o
ooooo`000?l000007?ooool2o`0002Gooooo0_l00002ooooo`;o00007oooool2o`0000oooooo0_l0
0007ooooo`;o00001oooool2o`0000Gooooo0_l0000>ooooo`;o000000?oooooo`000?l000003ooo
ool002Wooooo00Go0000ooooool0003o0000ooooo`02o`0001oooooo0_l00005ooooo`;o00000ooo
ool2o`0000Cooooo0ol00007ooooo`;o00002?ooool2o`0001_ooooo0_l0000;ooooo`;o00001ooo
ool2o`0000?ooooo0_l000000ooooooo0000o`00000>ooooo`;o00000_ooool2o`0000Sooooo0_l0
0004ooooo`;o00006Oooool2o`0000Cooooo0_l00006ooooo`;o000000?oooooo`000?l00000:Ooo
ool2o`0000Gooooo0_l0000=ooooo`;o00004Oooool2o`000003ooooool0003o000000oooooo000Y
ooooo`Co00001Oooool2o`0002kooooo0_l0000Looooo`;o00001_ooool2o`0000Sooooo0_l0000Q
ooooo`;o00002Oooool2o`0000;ooooo0_l0000;ooooo`;o000000?oooooo`000?l000005Oooool2
o`0000;ooooo0_l0000<ooooo`;o000000?oooooo`000?l000008_ooool2o`0000;ooooo0_l00008
ooooo`;o00001?ooool2o`0000Oooooo0_l0000Uooooo`00:Oooool2o`0000Kooooo0ol0000`oooo
o`;o00001_ooool3o`00017ooooo0_l00006ooooo`;o00003?ooool2o`000003ooooool0003o0000
00kooooo0_l0000:ooooo`Co00006?ooool2o`0001Sooooo0_l0000gooooo`?o000000?oooooo`00
0?l000003_ooool2o`0000Cooooo0_l00009ooooo`;o00007Oooool002Wooooo0_l00006ooooo`;o
0000:_ooool2o`0000Gooooo0_l00006ooooo`?o00009oooool2o`000003ooooool0003o000000ko
oooo1?l0000:ooooo`;o00004oooool2o`0000Gooooo0_l0000jooooo`;o00005?ooool2o`0001Oo
oooo0_l00009ooooo`;o00002Oooool2o`0001;ooooo000Yooooo`03o`000?oooooooooo037ooooo
0_l00007ooooo`;o0000@oooool2o`0001oooooo0_l00005ooooo`;o0000>_ooool2o`0001Cooooo
0_l0000]ooooo`;o00004_ooool002Wooooo00?o0000ooooooooool01?ooool2o`000003ooooool0
003o0000037ooooo0_l0001looooo`;o0000P_ooool002Wooooo00?o0000ooooooooool01?ooool2
o`000003ooooool0003o000008Oooooo0_l0000Vooooo`;o00004?ooool2o`00073ooooo000Yoooo
o`;o0000Aoooool2o`0000Gooooo0_l0000<ooooo`;o0000<oooool2o`0002[ooooo0_l0000<oooo
o`;o0000=oooool2o`0003Oooooo000Yooooo`03o`000?oooooooooo04Kooooo0_l00005ooooo`;o
00003?ooool2o`0005oooooo0_l00015ooooo`;o0000=oooool002Wooooo00?o0000ooooooooool0
2oooool2o`0000;ooooo0_l0001Booooo`;o00005_ooool2o`0000Cooooo0_l0002iooooo`00:Ooo
ool00ol0003oooooooooo`0;ooooo`;o00000_ooool2o`0001gooooo0_l0000cooooo`;o00005_oo
ool2o`0000Cooooo0_l0000jooooo`;o0000OOooool002Wooooo00?o0000ooooooooool02_ooool2
o`0002;ooooo0_l0002=ooooo`;o0000OOooool002Wooooo0_l0000;ooooo`;o0000iOooool2o`00
04Wooooo000Yooooo`03o`000?oooooooooo02Oooooo0_l0000Rooooo`;o0000JOooool2o`0001So
oooo0_l0000Oooooo`;o0000BOooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
02Oooooo0_l0000Rooooo`Co00002?ooool2o`0005gooooo0_l0000Hooooo`;o00006oooool2o`00
04gooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q
8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool02Oooool2
o`0003kooooo0_l00002ooooo`;o00002?ooool2o`0005cooooo0_l0000Looooo`;o00004_ooool2
o`0000Cooooo0_l0001=ooooo`001_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RH
ob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo0_l0000e
ooooo`;o000000?oooooo`000?l000001?ooool2o`0004Gooooo0_l0000Sooooo`;o00007?ooool2
o`0001;ooooo0_l0001Cooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000@?ooool2o`000003ooooool0003o
0000047ooooo0_l00008ooooo`;o00007?ooool2o`0003Sooooo0_l0000Pooooo`;o0000<?ooool0
00Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00Wooooo0ol0001Hooooo`;o00003?oo
ool2o`0000cooooo0_l00004ooooo`;o00002_ooool2o`0001[ooooo0_l0000[ooooo`;o00002Ooo
ool4o`0001gooooo0_l000000ooooooo0000o`00000`ooooo`001_ooool01Ol@413ooooooooooooo
oooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Wooooo0ol0000aooooo`;o00005oooool2o`0000cooooo0_l0000<ooooo`;o00003?oo
ool2o`00013ooooo0_l00017ooooo`;o00002Oooool2o`0001oooooo0_l0000cooooo`001_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0?Oooool2o`0000Wooooo0_l0000<ooooo`;o0000
d_ooool2o`00013ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@
o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo00oooooo0_l0000aooooo`;o
00001?ooool2o`000>3ooooo0_l0000@ooooo`00:Oooool2o`0000oooooo0ol0000aooooo`;o0000
1?ooool2o`0009Oooooo0_l0001Iooooo`00:Oooool00ol0003oooooooooo`0>ooooo`;o00003Ooo
ool2o`0000cooooo0_l000000ooooooo0000o`000009ooooo`;o00003oooool2o`0000Cooooo0ol0
001Mooooo`;o0000;oooool2o`00013ooooo0_l0000Qooooo`?o00001?ooool2o`0001gooooo000Y
ooooo`03o`000?oooooooooo01gooooo0_l0000<ooooo`;o000000?oooooo`000?l000002Oooool2
o`0000oooooo0_l00004ooooo`?o00003Oooool2o`00047ooooo0_l0000;ooooo`;o00008Oooool2
o`0001kooooo0_l00006ooooo`;o00004?ooool2o`0000Oooooo0ol00004ooooo`;o00003oooool2
o`0000cooooo000Yooooo`03o`000?oooooooooo01;ooooo0_l0001<ooooo`?o00002?ooool3o`00
01Wooooo0_l00003ooooo`;o00004Oooool2o`0000;ooooo0_l00005ooooo`;o00009oooool2o`00
00;ooooo0_l0000Rooooo`;o00004?ooool2o`0000Gooooo0_l0000Gooooo`?o00003?ooool002Wo
oooo00?o0000ooooooooool04_ooool2o`0000Oooooo0_l0000@ooooo`;o0000<_ooool2o`0000;o
oooo0_l00004ooooo`?o00006Oooool2o`0000?ooooo0_l0000Aooooo`;o000000?oooooo`000?l0
00001_ooool2o`0002_ooooo1?l0000`ooooo`;o00001oooool2o`0001Oooooo0_l0000=ooooo`00
:Oooool2o`0001cooooo0ol0000?ooooo`;o00001_ooool2o`0001Wooooo0_l0000Cooooo`?o0000
>_ooool2o`0002_ooooo0_l00008ooooo`;o0000<?ooool2o`0002oooooo000Yooooo`03o`000?oo
oooooooo01Cooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00009ooooo`;o00006Ooo
ool2o`0000_ooooo1?l00005ooooo`;o0000;oooool2o`0000gooooo0_l0000Wooooo`;o00005Ooo
ool2o`0005Cooooo000Yooooo`03o`000?oooooooooo01Cooooo0_l0000=ooooo`;o00001Oooool2
o`0002Oooooo0_l00007ooooo`Go0000=_ooool2o`0000gooooo0_l00008ooooo`;o00004oooool2
o`0000oooooo0_l0000=ooooo`?o0000E?ooool002Wooooo00?o0000ooooooooool04oooool2o`00
037ooooo0_l0000;ooooo`;o00001oooool2o`0001cooooo0_l0000Iooooo`;o00000_ooool2o`00
01Gooooo0_l000000ooooooo0000o`00000@ooooo`;o00000_ooool2o`0000[ooooo0ol0000=oooo
o`;o00000_ooool2o`0002Cooooo0_l0000:ooooo`;o00007oooool002Wooooo00?o0000oooooooo
ool04oooool2o`00037ooooo0_l0000Fooooo`;o00003oooool2o`0000Wooooo0_l0000Iooooo`;o
00000_ooool2o`00013ooooo0_l00006ooooo`?o00004oooool2o`0000[ooooo0_l0000=ooooo`;o
00000oooool2o`0002Cooooo0_l0000:ooooo`;o00003oooool2o`0000kooooo000Yooooo`;o0000
1_ooool2o`0001Wooooo0_l0000Booooo`;o000000?oooooo`000?l000009Oooool2o`0000Wooooo
0_l00004ooooo`;o00001_ooool2o`0000cooooo0_l00003ooooo`;o00004Oooool2o`0000cooooo
0_l00004ooooo`Ko00002oooool2o`00023ooooo0_l0000;ooooo`;o00005_ooool2o`00027ooooo
0_l0000>ooooo`00:Oooool00ol0003oooooooooo`02ooooo`;o000000?oooooo`000?l000001Ooo
ool2o`0000cooooo1?l00002ooooo`;o00000_ooool2o`0000kooooo0_l000001?oooooo0000o`00
0?l0000Aooooo`;o00001_ooool2o`0001Cooooo0_l00004ooooo`;o00001_ooool2o`0000cooooo
0_l00003ooooo`;o00004Oooool2o`0000Wooooo0_l00007ooooo`?o000000?oooooo`000?l00000
0oooool2o`0000Cooooo1?l0000Kooooo`;o00000_ooool2o`0000_ooooo0ol0000Fooooo`;o0000
<Oooool002Wooooo00?o0000ooooooooool00_ooool2o`0000Sooooo0_l00002ooooo`;o00002?oo
ool4o`000003ooooool0003o000000?ooooo0ol0000Aooooo`;o00001oooool2o`0000;ooooo0_l0
0004ooooo`;o00001_ooool2o`0001_ooooo0_l00002ooooo`;o00007_ooool2o`0001;ooooo0_l0
0008ooooo`;o00001?ooool4o`0000Cooooo0_l000000ooooooo0000o`00000Jooooo`;o00000_oo
ool2o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0003Gooooo0_l0000Cooooo`00:Oooool0
0ol0003oooooooooo`0@ooooo`;o00003Oooool2o`0000Cooooo0_l0000Jooooo`;o00000_ooool2
o`0000_ooooo0_l00002ooooo`;o00001_ooool2o`0000?ooooo0_l00004ooooo`;o00001Oooool2
o`0000;ooooo0_l0000Kooooo`;o000000?oooooo`000?l000008_ooool2o`0000Wooooo0_l0000<
ooooo`;o00005?ooool2o`0000;ooooo0_l0000Hooooo`;o00008?ooool2o`0001?ooooo000Yoooo
o`04o`000?ooooooooooooooo`;o00003Oooool2o`00013ooooo0_l0000<ooooo`;o00002Oooool2
o`0001Gooooo0_l00002ooooo`;o00001_ooool2o`0000?ooooo0_l00004ooooo`;o00002Oooool4
o`0001Wooooo0_l0000Iooooo`;o00002oooool2o`0001Kooooo0_l00009ooooo`;o00008oooool2
o`0000;ooooo0_l0000<ooooo`;o00009oooool002Wooooo0_l00002ooooo`;o000000?oooooo`00
0?l000002_ooool2o`0000?ooooo0_l00008ooooo`;o000000?oooooo`000?l000003?ooool2o`00
00Wooooo0_l0000Aooooo`;o00009?ooool4o`0001Kooooo0_l0000<ooooo`;o00003_ooool2o`00
00_ooooo0_l0000=ooooo`;o00003?ooool2o`0000;ooooo1?l000000ooooooo0000o`00000Eoooo
o`?o00002?ooool2o`0000;ooooo0_l0000<ooooo`;o00000oooool3o`00027ooooo000Yooooo`03
o`000?oooooooooo00Cooooo0_l0000?ooooo`;o00002?ooool2o`0002Kooooo0_l00005ooooo`;o
00007?ooool4o`0000;ooooo0_l0000@ooooo`;o00002?ooool2o`0000cooooo0_l0000Sooooo`;o
00001Oooool2o`0000cooooo0_l00002ooooo`Co000000?oooooo`000?l000002oooool2o`0000Co
oooo0_l00002ooooo`?o00007oooool3o`0001Cooooo0_l0000;ooooo`003_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`0Eooooo`;o0000<?ooool2o`0001Sooooo0_l00009ooooo`Co000000Goooooo`00
0?l0003o0000ooooo`02o`0000_ooooo1?l0000Aooooo`;o0000:?ooool2o`0001Sooooo1?l0000=
ooooo`;o00001?ooool2o`0002Kooooo0_l0000Cooooo`;o00002oooool000kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo067ooooo0_l0000>ooooo`;o00000_ooool2o`0000_ooooo0_l00006ooooo`;o00002oooool2
o`0004Cooooo0_l0000Kooooo`;o00001?ooool2o`0001Sooooo0_l00004ooooo`;o00006_ooool0
00kooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0001I
ooooo`;o0000;oooool2o`0003;ooooo0_l0000jooooo`;o00001?ooool2o`0001kooooo0_l0000J
ooooo`003_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`1Iooooo`;o0000Hoooool2o`0007cooooo000>ooooo`05o`000?oooooooooo
ooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooo
oolmooooo`003_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46
ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3o
ooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08
ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`000?oooooooooo
ooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEE
olc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooo
oolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`007oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooo
ooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
oooo?Oooool0027ooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
7oooool00omEEEGoIVIVo`00003oooooodOooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .25004 Mdot
.02762 .25028 Mdot
.02952 .30716 Mdot
.03143 .33308 Mdot
.03333 .35092 Mdot
.03524 .24079 Mdot
.03714 .29466 Mdot
.03905 .40542 Mdot
.04095 .42322 Mdot
.04286 .34839 Mdot
.04476 .35064 Mdot
.04667 .43151 Mdot
.04857 .25621 Mdot
.05048 .3488 Mdot
.05238 .44611 Mdot
.05429 .33823 Mdot
.05619 .25805 Mdot
.0581 .25603 Mdot
.06 .35545 Mdot
.0619 .30913 Mdot
.06381 .30353 Mdot
.06571 .28675 Mdot
.06762 .32862 Mdot
.06952 .27064 Mdot
.07143 .45072 Mdot
.07333 .34769 Mdot
.07524 .34166 Mdot
.07714 .34715 Mdot
.07905 .33133 Mdot
.08095 .27412 Mdot
.08286 .34677 Mdot
.08476 .41338 Mdot
.08667 .42146 Mdot
.08857 .2441 Mdot
.09048 .25225 Mdot
.09238 .36767 Mdot
.09429 .39147 Mdot
.09619 .34271 Mdot
.0981 .37768 Mdot
.1 .42405 Mdot
.1019 .44501 Mdot
.10381 .24868 Mdot
.10571 .2419 Mdot
.10762 .23777 Mdot
.10952 .2386 Mdot
.11143 .3512 Mdot
.11333 .34829 Mdot
.11524 .39438 Mdot
.11714 .33 Mdot
.11905 .36324 Mdot
.12095 .40025 Mdot
.12286 .36328 Mdot
.12476 .46907 Mdot
.12667 .24237 Mdot
.12857 .25352 Mdot
.13048 .42471 Mdot
.13238 .4139 Mdot
.13429 .27347 Mdot
.13619 .39184 Mdot
.1381 .23905 Mdot
.14 .34193 Mdot
.1419 .46234 Mdot
.14381 .38918 Mdot
.14571 .28493 Mdot
.14762 .43742 Mdot
.14952 .41442 Mdot
.15143 .34821 Mdot
.15333 .34224 Mdot
.15524 .35194 Mdot
.15714 .29131 Mdot
.15905 .31164 Mdot
.16095 .29569 Mdot
.16286 .34781 Mdot
.16476 .34629 Mdot
.16667 .38941 Mdot
.16857 .31448 Mdot
.17048 .46885 Mdot
.17238 .30227 Mdot
.17429 .35552 Mdot
.17619 .26614 Mdot
.1781 .35735 Mdot
.18 .28366 Mdot
.1819 .33496 Mdot
.18381 .25319 Mdot
.18571 .40475 Mdot
.18762 .324 Mdot
.18952 .35119 Mdot
.19143 .32418 Mdot
.19333 .29525 Mdot
.19524 .34274 Mdot
.19714 .45133 Mdot
.19905 .46831 Mdot
.20095 .28818 Mdot
.20286 .34705 Mdot
.20476 .2941 Mdot
.20667 .47235 Mdot
.20857 .34873 Mdot
.21048 .41607 Mdot
.21238 .47017 Mdot
.21429 .31832 Mdot
.21619 .25901 Mdot
.2181 .31616 Mdot
.22 .43821 Mdot
.2219 .23973 Mdot
.22381 .32057 Mdot
.22571 .24389 Mdot
.22762 .28948 Mdot
.22952 .35671 Mdot
.23143 .28734 Mdot
.23333 .30545 Mdot
.23524 .34757 Mdot
.23714 .32381 Mdot
.23905 .41554 Mdot
.24095 .32633 Mdot
.24286 .46321 Mdot
.24476 .26922 Mdot
.24667 .32935 Mdot
.24857 .39718 Mdot
.25048 .40126 Mdot
.25238 .40769 Mdot
.25429 .26472 Mdot
.25619 .45796 Mdot
.2581 .34064 Mdot
.26 .32226 Mdot
.2619 .29814 Mdot
.26381 .33768 Mdot
.26571 .34091 Mdot
.26762 .47129 Mdot
.26952 .29974 Mdot
.27143 .27279 Mdot
.27333 .3034 Mdot
.27524 .27151 Mdot
.27714 .43881 Mdot
.27905 .24615 Mdot
.28095 .24138 Mdot
.28286 .33366 Mdot
.28476 .35954 Mdot
.28667 .34088 Mdot
.28857 .34712 Mdot
.29048 .43155 Mdot
.29238 .44555 Mdot
.29429 .46271 Mdot
.29619 .30487 Mdot
.2981 .35506 Mdot
.3 .26093 Mdot
.3019 .31319 Mdot
.30381 .4019 Mdot
.30571 .46174 Mdot
.30762 .32674 Mdot
.30952 .32689 Mdot
.31143 .44772 Mdot
.31333 .3248 Mdot
.31524 .35482 Mdot
.31714 .26235 Mdot
.31905 .29989 Mdot
.32095 .25306 Mdot
.32286 .37355 Mdot
.32476 .37984 Mdot
.32667 .40746 Mdot
.32857 .39821 Mdot
.33048 .3702 Mdot
.33238 .34161 Mdot
.33429 .3443 Mdot
.33619 .42521 Mdot
.3381 .37002 Mdot
.34 .24928 Mdot
.3419 .27873 Mdot
.34381 .4045 Mdot
.34571 .31642 Mdot
.34762 .35104 Mdot
.34952 .35067 Mdot
.35143 .37494 Mdot
.35333 .32463 Mdot
.35524 .34517 Mdot
.35714 .3359 Mdot
.35905 .3372 Mdot
.36095 .43126 Mdot
.36286 .47157 Mdot
.36476 .25554 Mdot
.36667 .26655 Mdot
.36857 .35284 Mdot
.37048 .34226 Mdot
.37238 .43146 Mdot
.37429 .33997 Mdot
.37619 .44571 Mdot
.3781 .27739 Mdot
.38 .42725 Mdot
.3819 .46909 Mdot
.38381 .39854 Mdot
.38571 .4269 Mdot
.38762 .24358 Mdot
.38952 .45539 Mdot
.39143 .30882 Mdot
.39333 .28862 Mdot
.39524 .46131 Mdot
.39714 .40747 Mdot
.39905 .44317 Mdot
.40095 .43789 Mdot
.40286 .34387 Mdot
.40476 .47529 Mdot
.40667 .29693 Mdot
.40857 .26623 Mdot
.41048 .26621 Mdot
.41238 .29325 Mdot
.41429 .33754 Mdot
.41619 .47467 Mdot
.4181 .27859 Mdot
.42 .29254 Mdot
.4219 .24066 Mdot
.42381 .3078 Mdot
.42571 .26552 Mdot
.42762 .35234 Mdot
.42952 .25105 Mdot
.43143 .30864 Mdot
.43333 .31879 Mdot
.43524 .34361 Mdot
.43714 .28349 Mdot
.43905 .30368 Mdot
.44095 .42892 Mdot
.44286 .26487 Mdot
.44476 .24698 Mdot
.44667 .41738 Mdot
.44857 .33351 Mdot
.45048 .40878 Mdot
.45238 .30717 Mdot
.45429 .3677 Mdot
.45619 .34376 Mdot
.4581 .34871 Mdot
.46 .23804 Mdot
.4619 .3145 Mdot
.46381 .44613 Mdot
.46571 .45669 Mdot
.46762 .33309 Mdot
.46952 .31158 Mdot
.47143 .46749 Mdot
.47333 .29002 Mdot
.47524 .34972 Mdot
.47714 .45779 Mdot
.47905 .34563 Mdot
.48095 .23962 Mdot
.48286 .31226 Mdot
.48476 .26607 Mdot
.48667 .46251 Mdot
.48857 .24636 Mdot
.49048 .31159 Mdot
.49238 .31134 Mdot
.49429 .40359 Mdot
.49619 .30552 Mdot
.4981 .39208 Mdot
.5 .25306 Mdot
.5019 .31323 Mdot
.50381 .38318 Mdot
.50571 .4448 Mdot
.50762 .26829 Mdot
.50952 .30389 Mdot
.51143 .39979 Mdot
.51333 .32747 Mdot
.51524 .34361 Mdot
.51714 .27276 Mdot
.51905 .31462 Mdot
.52095 .42106 Mdot
.52286 .39176 Mdot
.52476 .31477 Mdot
.52667 .35 Mdot
.52857 .3667 Mdot
.53048 .2666 Mdot
.53238 .30924 Mdot
.53429 .25809 Mdot
.53619 .34483 Mdot
.5381 .25104 Mdot
.54 .37452 Mdot
.5419 .30633 Mdot
.54381 .35042 Mdot
.54571 .25776 Mdot
.54762 .34638 Mdot
.54952 .28922 Mdot
.55143 .36679 Mdot
.55333 .33721 Mdot
.55524 .35872 Mdot
.55714 .40457 Mdot
.55905 .35188 Mdot
.56095 .24388 Mdot
.56286 .35022 Mdot
.56476 .26394 Mdot
.56667 .3458 Mdot
.56857 .40191 Mdot
.57048 .43437 Mdot
.57238 .35771 Mdot
.57429 .29895 Mdot
.57619 .31642 Mdot
.5781 .30584 Mdot
.58 .33375 Mdot
.5819 .35911 Mdot
.58381 .46777 Mdot
.58571 .40056 Mdot
.58762 .44334 Mdot
.58952 .41115 Mdot
.59143 .31245 Mdot
.59333 .37827 Mdot
.59524 .45905 Mdot
.59714 .29592 Mdot
.59905 .4454 Mdot
.60095 .46118 Mdot
.60286 .30652 Mdot
.60476 .26765 Mdot
.60667 .26274 Mdot
.60857 .40809 Mdot
.61048 .44795 Mdot
.61238 .34977 Mdot
.61429 .40951 Mdot
.61619 .32932 Mdot
.6181 .26629 Mdot
.62 .26433 Mdot
.6219 .2602 Mdot
.62381 .27522 Mdot
.62571 .44748 Mdot
.62762 .26486 Mdot
.62952 .25138 Mdot
.63143 .24438 Mdot
.63333 .43869 Mdot
.63524 .26397 Mdot
.63714 .43485 Mdot
.63905 .45642 Mdot
.64095 .46775 Mdot
.64286 .33808 Mdot
.64476 .25384 Mdot
.64667 .26024 Mdot
.64857 .3921 Mdot
.65048 .35656 Mdot
.65238 .27066 Mdot
.65429 .30373 Mdot
.65619 .28576 Mdot
.6581 .41277 Mdot
.66 .40561 Mdot
.6619 .2868 Mdot
.66381 .26216 Mdot
.66571 .2687 Mdot
.66762 .29065 Mdot
.66952 .2391 Mdot
.67143 .24275 Mdot
.67333 .2487 Mdot
.67524 .33918 Mdot
.67714 .33513 Mdot
.67905 .47444 Mdot
.68095 .31133 Mdot
.68286 .29814 Mdot
.68476 .29605 Mdot
.68667 .42569 Mdot
.68857 .34055 Mdot
.69048 .344 Mdot
.69238 .31012 Mdot
.69429 .29021 Mdot
.69619 .30065 Mdot
.6981 .46349 Mdot
.7 .42686 Mdot
.7019 .36649 Mdot
.70381 .36438 Mdot
.70571 .32195 Mdot
.70762 .27695 Mdot
.70952 .36829 Mdot
.71143 .30167 Mdot
.71333 .42816 Mdot
.71524 .46906 Mdot
.71714 .31211 Mdot
.71905 .43975 Mdot
.72095 .43625 Mdot
.72286 .43832 Mdot
.72476 .28573 Mdot
.72667 .2934 Mdot
.72857 .44629 Mdot
.73048 .41679 Mdot
.73238 .28522 Mdot
.73429 .34836 Mdot
.73619 .28564 Mdot
.7381 .24093 Mdot
.74 .25719 Mdot
.7419 .41858 Mdot
.74381 .24074 Mdot
.74571 .38967 Mdot
.74762 .40347 Mdot
.74952 .33017 Mdot
.75143 .35808 Mdot
.75333 .31023 Mdot
.75524 .44902 Mdot
.75714 .4665 Mdot
.75905 .41198 Mdot
.76095 .24407 Mdot
.76286 .28706 Mdot
.76476 .45446 Mdot
.76667 .30873 Mdot
.76857 .30445 Mdot
.77048 .42828 Mdot
.77238 .293 Mdot
.77429 .27532 Mdot
.77619 .3472 Mdot
.7781 .33837 Mdot
.78 .34867 Mdot
.7819 .39251 Mdot
.78381 .27948 Mdot
.78571 .46048 Mdot
.78762 .43195 Mdot
.78952 .25315 Mdot
.79143 .46751 Mdot
.79333 .2622 Mdot
.79524 .34117 Mdot
.79714 .3493 Mdot
.79905 .31653 Mdot
.80095 .41667 Mdot
.80286 .4318 Mdot
.80476 .34249 Mdot
.80667 .30756 Mdot
.80857 .35321 Mdot
.81048 .33026 Mdot
.81238 .44764 Mdot
.81429 .35419 Mdot
.81619 .35976 Mdot
.8181 .32048 Mdot
.82 .35388 Mdot
.8219 .26543 Mdot
.82381 .35135 Mdot
.82571 .24431 Mdot
.82762 .35395 Mdot
.82952 .2935 Mdot
.83143 .45398 Mdot
.83333 .42996 Mdot
.83524 .29771 Mdot
.83714 .25233 Mdot
.83905 .2881 Mdot
.84095 .27303 Mdot
.84286 .28243 Mdot
.84476 .34942 Mdot
.84667 .45377 Mdot
.84857 .47581 Mdot
.85048 .24775 Mdot
.85238 .46521 Mdot
.85429 .23783 Mdot
.85619 .28421 Mdot
.8581 .43099 Mdot
.86 .44711 Mdot
.8619 .34764 Mdot
.86381 .3215 Mdot
.86571 .47273 Mdot
.86762 .3124 Mdot
.86952 .27584 Mdot
.87143 .33095 Mdot
.87333 .35895 Mdot
.87524 .27918 Mdot
.87714 .47229 Mdot
.87905 .27369 Mdot
.88095 .24287 Mdot
.88286 .25879 Mdot
.88476 .28081 Mdot
.88667 .26528 Mdot
.88857 .3414 Mdot
.89048 .40782 Mdot
.89238 .26644 Mdot
.89429 .34609 Mdot
.89619 .24626 Mdot
.8981 .24192 Mdot
.9 .34364 Mdot
.9019 .35925 Mdot
.90381 .25997 Mdot
.90571 .47368 Mdot
.90762 .34741 Mdot
.90952 .4127 Mdot
.91143 .44233 Mdot
.91333 .34177 Mdot
.91524 .373 Mdot
.91714 .29329 Mdot
.91905 .24878 Mdot
.92095 .34014 Mdot
.92286 .25346 Mdot
.92476 .35304 Mdot
.92667 .30392 Mdot
.92857 .24553 Mdot
.93048 .45942 Mdot
.93238 .24462 Mdot
.93429 .31386 Mdot
.93619 .24317 Mdot
.9381 .27438 Mdot
.94 .2953 Mdot
.9419 .34136 Mdot
.94381 .24249 Mdot
.94571 .24545 Mdot
.94762 .26582 Mdot
.94952 .32093 Mdot
.95143 .41521 Mdot
.95333 .35584 Mdot
.95524 .25885 Mdot
.95714 .35756 Mdot
.95905 .33311 Mdot
.96095 .28146 Mdot
.96286 .47001 Mdot
.96476 .27617 Mdot
.96667 .24367 Mdot
.96857 .41815 Mdot
.97048 .36585 Mdot
.97238 .35197 Mdot
.97429 .34571 Mdot
.97619 .43147 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooocgooooo0006
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol0003oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_oo
ool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05oooool3o`0000Oooooo
0_l0000Iooooo`;o0000Boooool2o`0000Cooooo0_l0000kooooo`;o0000>Oooool2o`0003?ooooo
0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02o`0001Gooooo0ol00003ooooo`;o
00000_ooool2o`0001Wooooo0_l0000Aooooo`;o0000:oooool2o`0000_ooooo0_l00004ooooo`;o
0000>oooool3o`0001?ooooo1?l0000Qooooo`;o00001oooool2o`0000?ooooo0_l0000;ooooo`Co
00005_ooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool00_l0000?ooooo`;o00001?ooool2o`00
00Cooooo0_l0000Nooooo`;o00003oooool3o`00023ooooo0_l00009ooooo`;o00005?ooool2o`00
01Gooooo0_l0000Eooooo`;o00002oooool2o`0001?ooooo1?l00003ooooo`;o00004oooool2o`00
013ooooo0_l00003ooooo`;o00002?ooool8o`0000Cooooo0_l0000?ooooo`00:Oooool2o`0001;o
oooo0_l00003ooooo`;o00009Oooool2o`0000oooooo0_l0000Booooo`;o00003Oooool2o`00017o
oooo0_l0000<ooooo`;o00005Oooool2o`0001Gooooo0_l0000;ooooo`;o00006_ooool2o`0001?o
oooo0_l00006ooooo`;o00003Oooool2o`0000Gooooo0_l000001?oooooo0000o`000?l00003oooo
o`;o00001?ooool2o`0000oooooo000Yooooo`;o00004oooool2o`0000;ooooo0_l0001:ooooo`;o
00006oooool2o`0000?ooooo0_l0000Looooo`;o00006oooool2o`0000cooooo0_l0000cooooo`;o
00000_ooool2o`0001Cooooo0_l0000Nooooo`00:Oooool2o`0001?ooooo0_l0000:ooooo`;o0000
4?ooool2o`0002[ooooo0_l0000<ooooo`;o00004oooool2o`0001Cooooo0_l0000;ooooo`;o0000
6oooool2o`0000?ooooo0_l0000/ooooo`;o00003_ooool2o`0001Wooooo0_l0000Mooooo`00:Ooo
ool00ol0003oooooooooo`04ooooo`;o000000?oooooo`000?l000005Oooool2o`00013ooooo0_l0
0008ooooo`;o00008?ooool2o`0000cooooo0_l0000Yooooo`;o00002Oooool2o`0000;ooooo0_l0
000Nooooo`;o00007Oooool2o`0000gooooo0_l0000Looooo`;o00002oooool2o`0000Wooooo0_l0
000Booooo`00:Oooool00ol0003oooooooooo`04ooooo`;o000000?oooooo`000?l00000<Oooool2
o`0001Wooooo0_l00019ooooo`;o00000_ooool2o`0001Oooooo0_l00006ooooo`;o00000oooool2
o`0001Oooooo0_l0000[ooooo`;o00001Oooool2o`0000oooooo0_l0000Booooo`00:Oooool2o`00
04Oooooo0_l0000=ooooo`;o00001?ooool2o`0002Kooooo0_l0000Uooooo`;o00003?ooool2o`00
00;ooooo1?l000000ooooooo0000o`000002ooooo`;o00000oooool2o`0002Sooooo0_l0000Loooo
o`;o00000oooool2o`0002?ooooo000Yooooo`03o`000?oooooooooo02gooooo0_l0000Gooooo`;o
00004oooool2o`0000kooooo0_l0000;ooooo`?o00000_ooool2o`0000Cooooo0_l0000;ooooo`;o
00001_ooool2o`0000Gooooo0_l00009ooooo`;o00002oooool3o`000003ooooool0003o000000?o
000000?oooooo`000?l00000<Oooool2o`0000Oooooo0_l0000Cooooo`Co00003oooool2o`0001Go
oooo000Yooooo`03o`000?oooooooooo00_ooooo0_l0000Pooooo`;o000000?oooooo`000?l00000
0_l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01?o^k^ko<S8bo`000?lb
<S82o`0002Kooooo1ol00003ooooo`03onk^k_lb<S;o000000?o00000_ooool3o`000003oc8b<_o^
k^kooooo00gooooo0_l00006ooooo`;o00001Oooool2o`0000Wooooo00GoV9RHoa0@4?l0003o<S8b
olc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_l000001_ooooook^k^o`000?l0003o<S8b
onk^kPOooooo0_l00003ooooo`;o00007?ooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo00Kok^k^oc8b<_l0003o<S8bonk^k_ooool2o`0001Gooooo0_l0000?
ooooo`?o000000Wo<S8bomgMgOooooooooooonk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo000Yooooo`03o`000?oooooooooo00_ooooo0_l00002ooooo`;o
00003oooool2o`00013ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00CoMgMgoiRHV?ooooooV9RH0_l00007ooooo`?o00007_ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL06Oooool2o`0000gooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo0_l00003ooooo`;o00007Ooo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Oooooo0_l0000:ooooo`;o00004Oooool2o`0000Cooooo00WoMgMgoc8b<_oo
ooooooooogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
000Yooooo`03o`000?oooooooooo00oooooo0_l0000?ooooo`;o00004?ooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00So
oooo0ol0000Oooooo`;o000000?ok^k^ooooooooool00_ooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@400Iooooo`;o00004Oooool01Ol0003ooooooooooooo
oooo410@00?ooooo00Go410@oooooooooooooooooa0@4002ooooo`;o00006Oooool2o`0000gooooo
1Ol00002ooooo`;o00000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooooooo
ool01Oooool2o`0000Oooooo0_l000000ooooooo0000o`00000Aooooo`;o00001Oooool01?l0003o
ooooo`000?l00003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`01
ooooo`00:Oooool2o`0003?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`00000Oooooo`;o00002Oooool2o`000003ob4Q8Oo^
k^kooooo00;ooooo00Ko0000ooooooooooooooooo`000?ooool3o`0000?ooooo00?o0000oooooooo
ool0:Oooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`02o`0001Wooooo0_l0000=ooooo`04odA4A?oMgMgoooooo`0000?ooooo0_l00000
1?oooooo0000o`000?l00003ooooo`05o`000?ooooooooooooooool000004?ooool4o`000003oooo
ool0003o000001Gooooo00?oMgMgoc8b<_ooool00_l00003ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`01ooooo`00:Oooool00ol0003oooooooooo`0^ooooo`;o0000
0_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000001oooooo0_l0000;ooooo`03ogMgMomVIVKooooo00;ooooo00Ko0000oooo
ooooooooooooo`000?ooool3o`0000?ooooo0_l0000Yooooo`03oa0@4?l0003o^[Zj00?ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000:?ooool01?oMgMgo
EEEEooooool00004ooooo`03o`000?oooooo000000;o00000oooool01Ol0003ooooooooooooooooo
000000Sooooo0_l00008ooooo`;o000000?oooooo`000?l000004_ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00?o00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
0Oooool002Wooooo00?o0000ooooooooool02_ooool2o`0001Oooooo0_l00009ooooo`;o00000_oo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooo
oooooooooooo410@02gooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooo
ooooool@41000oooool2o`0002[ooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooo
oooo410@00?ooooo00Go410@oooooooooooooooooa0@4009ooooo`?o00004oooool5o`0000Gooooo
00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooooooooa0@4008ooooo`;o00000_ooool2o`0001_ooooo00?o0000ooooooooool00_ooool2o`00
0005oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo000Y
ooooo`03o`000?oooooooooo00[ooooo0_l0000Gooooo`;o00003Oooool00ol0003oooooooooo`02
o`000005ogMgMonHV9SooooooiRHV?mgMgL00_ooool3o`000003oooooonHV9SoMgMg02Wooooo00Ko
0000okZj^_ooooooV9RHoa0@4?ooool2o`000005ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo0_l0000Fooooo`;o00000oooool01Ol@413oV9RHoooooonj
^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02Oooool3o`0001?ooooo1Ol00005ooooo`04onk^k_m4A4Co0000o`0000?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool2o`0000Cooooo0_l0
000Kooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool002Wooooo00?o0000ooooooooool09oooool2o`0000Oooooo
00?oEEEEofIVI_l000000_ooool2o`000005onk^k_lb<S;o0000oc8b<_o^k^h00_ooool4o`000003
oc8b<_o^k^kooooo02Sooooo00KoV9RHoa0@4?l0003o8B4Qolc<c?ooool2o`000004onk^k_lb<S;o
0000oc8b<P;o000000Ooooooo`000?l0003o<S8bo`000?lb<S;ok^k^00_ooooo0_l0000Fooooo`;o
00000oooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool2o`0000Oooooo0_l0000Cooooo`04ogMgMol0
003o0000ooooo`;o000000Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01_ooool2o`00027ooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Yooooo`;o00000_ooool2o`0002Cooooo0ol00009
ooooo`;o000000?oooooo`000?l00000@Oooool2o`000003ooooool0003o000003Oooooo0_l0000D
ooooo`;o00001?ooool2o`000003ooooool0003o000000Sooooo0_l0000=ooooo`;o00004?ooool2
o`0001_ooooo0_l00005ooooo`;o00005oooool002Wooooo00Co0000oooooooooooooooo0_l0000U
ooooo`;o00002Oooool2o`000003ooooool0003o0000017ooooo0_l0000/ooooo`;o0000=?ooool2
o`0000Kooooo0_l0000Iooooo`?o00002oooool2o`0001oooooo1?l0000Iooooo`;o00001Oooool2
o`0001Oooooo000Yooooo`03o`000?oooooooooo02cooooo0_l0000Kooooo`Co00003_ooool2o`00
01[ooooo0_l0000dooooo`;o00008Oooool2o`0000;ooooo0_l00003ooooo`;o00009_ooool2o`00
03Wooooo000Yooooo`03o`000?oooooooooo00Wooooo0_l0000Qooooo`;o00004_ooool2o`0000Wo
oooo1?l00005ooooo`;o00001Oooool2o`0002Gooooo0_l0000@ooooo`;o00000_ooool2o`0002go
oooo0_l0000;ooooo`;o00000oooool2o`00017ooooo0_l0000aooooo`;o00006oooool002Wooooo
0ol00009ooooo`;o0000=Oooool2o`0000_ooooo0_l00005ooooo`;o00007?ooool2o`0000Wooooo
1?l000000ooooooo0000o`000002ooooo`;o00003?ooool2o`0000;ooooo0_l00009ooooo`;o0000
2Oooool2o`0000Kooooo0_l0000?ooooo`;o00008_ooool3o`0000[ooooo0_l0000Uooooo`;o0000
6oooool0027oooooool00014o`0000Cooooo000Yooooo`03o`000?oooooooooo00Wooooo0_l0000;
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool2o`000005ooooool0003o
0000ooooool000002oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool00_l00007ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo0_l000000ooooooo0000o`00
0002ooooo`Go000000?oooooo`000?l000001?ooool3o`000003ooooool0003o000000Oooooo00?o
0000ooooooooool01oooool3o`0000_ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`02o`000003ooooool0003o000000Gooooo0ol00009ooooo`?o00002Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00[ooooo0ol00009ooooo`03o`000?oooooooooo00Oooooo0ol0
000;ooooo`03o`000?oooooooooo00[ooooo000Yooooo`03o`000?oooooooooo02_ooooo0_l0000=
ooooo`?o00006Oooool2o`0000cooooo0_l0000Booooo`03o`000?oooooooooo00kooooo0_l00005
ooooo`;o00001?ooool2o`0000Cooooo0ol0000?ooooo`;o00000oooool3o`0002Gooooo0_l0000E
ooooo`04o`000?ooooooooooooooo`;o00005?ooool2o`0001?ooooo0_l0000<ooooo`03o`000?oo
oooooooo00[ooooo000Yooooo`03o`000?oooooooooo03[ooooo1Ol0000Uooooo`;o00006_ooool2
o`0002cooooo0_l00016ooooo`;o00001?ooool2o`0002Sooooo0_l0000Dooooo`00:Oooool00ol0
003oooooooooo`0aooooo`?o00001_ooool2o`000003ooooool0003o000000;ooooo0_l00005oooo
o`;o0000=_ooool2o`0005Kooooo0_l0000Rooooo`;o00003?ooool2o`0001[ooooo0_l0000Doooo
o`00:Oooool2o`0003;ooooo0ol0000=ooooo`?o00001?ooool2o`0000kooooo0ol0000;ooooo`;o
0000<_ooool2o`0003cooooo0_l0000`ooooo`;o0000<?ooool002Wooooo00?o0000ooooooooool0
2_ooool2o`0000kooooo0_l0000Vooooo`Co00004_ooool3o`0000_ooooo0_l0000booooo`;o0000
7oooool2o`0002Wooooo0_l0000Aooooo`;o0000@Oooool002Wooooo00Co0000ooooool0003o0000
2Oooool2o`0000;ooooo0_l0000:ooooo`;o0000:?ooool2o`0000[ooooo0_l0000cooooo`;o0000
1?ooool2o`0002kooooo0_l0000Yooooo`;o00004Oooool2o`0001;ooooo0_l0000Jooooo`;o0000
4Oooool002Wooooo00Co0000ooooool0003o00003Oooool2o`0001oooooo0_l0000Oooooo`;o0000
5Oooool2o`0001cooooo0_l00004ooooo`;o00008_ooool2o`0001gooooo0_l0000mooooo`;o0000
6_ooool2o`00017ooooo000Yooooo`03o`000?oooooooooo00Kooooo0_l0000Wooooo`;o00006?oo
ool2o`0001cooooo0ol0000@ooooo`;o0000:oooool2o`0000Kooooo0_l0000Booooo`;o00002Ooo
ool2o`0001oooooo0_l0001;ooooo`00:Oooool2o`0000Oooooo0_l00005ooooo`;o00001Oooool2
o`0000cooooo0_l00002ooooo`;o00002oooool2o`0001?ooooo1?l00005ooooo`;o00003?ooool2
o`0000Oooooo0_l00002ooooo`?o00002oooool2o`0002_ooooo0_l0000Jooooo`;o00002Oooool2
o`0000;ooooo0_l0000Kooooo`;o00000oooool2o`000003ooooool0003o000001Wooooo0_l00006
ooooo`;o000000?oooooo`000?l000001?ooool2o`0001Oooooo000Yooooo`03o`000?oooooooooo
00gooooo0_l00005ooooo`;o00003?ooool2o`0000;ooooo0_l0000;ooooo`;o00004oooool4o`00
00Gooooo0_l0000<ooooo`?o00001Oooool2o`0000?ooooo0ol00007ooooo`;o00002Oooool2o`00
00Cooooo0_l00006ooooo`;o00002Oooool2o`0000Gooooo0_l00008ooooo`;o00009Oooool3o`00
01oooooo0_l000000ooooooo0000o`00000Iooooo`Ko00000_ooool2o`000003ooooool0003o0000
00Cooooo0_l00009ooooo`;o00003?ooool002Wooooo00?o0000ooooooooool00_ooool2o`000003
ooooool0003o000000Gooooo1Ol00008ooooo`;o00002_ooool2o`0000;ooooo0ol0000:ooooo`Co
00001_ooool2o`0000oooooo0_l0000=ooooo`;o00001Oooool2o`0000gooooo0_l00009ooooo`;o
00001?ooool3o`0000Gooooo0_l00009ooooo`;o00001Oooool2o`0000;ooooo0_l00004ooooo`;o
00009_ooool2o`0000cooooo0_l0000;ooooo`?o00006Oooool2o`0000Sooooo1_l0000Dooooo`;o
00003?ooool002Wooooo00Go0000ooooool0003o0000ooooo`05o`0000Gooooo1Ol00007ooooo`?o
00002_ooool7o`0000Kooooo0_l00002ooooo`Co00001_ooool2o`0000oooooo0_l0000Aooooo`?o
00005oooool2o`0000Sooooo0_l00003ooooo`;o00003oooool2o`0000?ooooo1?l000000ooooooo
0000o`000002o`0000kooooo0_l0000Uooooo`;o00002oooool3o`0000Cooooo0_l00007ooooo`;o
00001?ooool2o`0000Cooooo0_l0000<ooooo`;o00004oooool2o`0000gooooo000Yooooo`04o`00
0?oooooo0000o`0000;ooooo0_l00003ooooo`;o00003_ooool2o`0000gooooo0_l00009ooooo`;o
00008?ooool2o`0000Cooooo0_l00008ooooo`?o00001?ooool2o`00017ooooo0_l0000=ooooo`;o
00003oooool2o`0000?ooooo0_l00003ooooo`Co00003_ooool2o`0003Wooooo0_l00002ooooo`So
00000oooool2o`0001Sooooo0_l0000=ooooo`;o00003Oooool002Wooooo0_l00009ooooo`;o0000
8oooool3o`0000kooooo0_l0000Dooooo`;o00001?ooool2o`0000oooooo0_l00010ooooo`;o0000
5oooool2o`0001kooooo0_l0000Aooooo`Go000000?oooooo`000?l000007Oooool2o`0000Oooooo
0ol0000Booooo`00:Oooool00ol0003oooooooooo`0]ooooo`?o00003_ooool2o`00013ooooo0_l0
001Eooooo`;o00001?ooool2o`000003ooooool0003o000001Cooooo0_l0000Nooooo`;o00004ooo
ool2o`00013ooooo0_l00008ooooo`;o00003_ooool3o`0001;ooooo000Yooooo`03o`000?oooooo
oooo01_ooooo0ol0000booooo`;o0000EOooool2o`0000Oooooo0_l0000Uooooo`;o00008_ooool2
o`00013ooooo0_l00008ooooo`;o00008oooool002Wooooo00?o0000ooooooooool04_ooool2o`00
00Oooooo0ol0001Yooooo`;o00005_ooool2o`0000Gooooo0_l0000^ooooo`?o0000E?ooool2o`00
00gooooo000Yooooo`03o`000?oooooooooo01;ooooo0_l0001;ooooo`Co00009?ooool2o`0001Ko
oooo0_l00005ooooo`;o0000;_ooool2o`000003ooooool0003o000005;ooooo0_l0000=ooooo`00
:Oooool2o`0005gooooo0_l000000ooooooo0000o`000002o`0007Kooooo0_l00010ooooo`;o0000
7oooool002Wooooo00?o0000ooooooooool0G?ooool2o`0000Sooooo0_l0000jooooo`;o0000Mooo
ool2o`0001oooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0
0004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Dooooo`;o0000
Aoooool2o`0000Oooooo0_l0000jooooo`;o00003oooool2o`0008Oooooo0006ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool05?ooool2o`0004Oooooo0_l0000hooooo`;o
00006_ooool2o`0008Oooooo0006ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Uoooool2o`000:?o
oooo0006ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03
ogMgMolb<S;ooooo00Cooooo0ol0000Sooooo`;o00001Oooool2o`000;Sooooo0_l0001Fooooo`00
1_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool04oooool2o`0000_ooooo0_l000000ooo
oooo0000o`000005ooooo`;o0000JOooool2o`0000Kooooo0_l0000Vooooo`;o00007Oooool2o`00
00[ooooo0_l0001:ooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01?ooooo0_l00005oooo
o`;o00001?ooool2o`0007?ooooo0_l00006ooooo`;o00009_ooool2o`0002Wooooo0_l0001:oooo
o`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06_ooool2o`0002Wooooo0_l0000G
ooooo`;o00004?ooool2o`000<[ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo01cooooo0_l0
000Wooooo`;o00003oooool2o`0000Kooooo0_l0000@ooooo`;o00009oooool2o`00013ooooo0_l0
0004ooooo`;o0000ROooool002Wooooo0_l0000Mooooo`;o00004_ooool2o`0001?ooooo0_l0000?
ooooo`;o00002oooool2o`0002oooooo0_l00003ooooo`;o00003Oooool2o`000003ooooool0003o
000000Cooooo0_l0000booooo`;o0000EOooool002Wooooo00Co0000oooooooooooooooo0_l0000]
ooooo`;o00005?ooool2o`0001Kooooo0_l00003ooooo`;o00003oooool2o`0001kooooo0_l0000B
ooooo`;o00003_ooool2o`0000oooooo0_l0000Jooooo`;o0000;?ooool2o`0002Oooooo000Yoooo
o`04o`000?ooooooooooooooo`;o0000@oooool2o`0001Kooooo0_l0000Dooooo`;o00003oooool2
o`0002_ooooo0_l00004ooooo`Co00003Oooool2o`0004Sooooo0_l0000Wooooo`00:Oooool00ol0
003oooooooooo`0@ooooo`;o00003Oooool2o`0000Cooooo0_l0001Nooooo`;o0000:oooool2o`00
00Kooooo0_l0000<ooooo`;o00007oooool2o`0002kooooo0_l0000Qooooo`00:Oooool00ol0003o
ooooooooo`0@ooooo`;o00003Oooool2o`0000Cooooo0_l0000Aooooo`;o00001oooool2o`00047o
oooo0_l00012ooooo`;o00005Oooool2o`0000Sooooo0_l0000;ooooo`;o00008Oooool2o`0000co
oooo0_l0000Cooooo`00:Oooool2o`0003Wooooo0_l00007ooooo`;o0000@Oooool2o`0005Wooooo
0_l00002ooooo`;o00004Oooool2o`0002oooooo0_l00003ooooo`;o00003_ooool002Wooooo00?o
0000ooooooooool00_ooool2o`0000cooooo0_l0002:ooooo`;o0000AOooool2o`0004Oooooo0_l0
000>ooooo`00:Oooool00ol0003oooooooooo`02ooooo`;o00003?ooool2o`0000?ooooo0_l00008
ooooo`;o0000@?ooool2o`0000kooooo0_l0000Yooooo`;o0000<oooool2o`0000?ooooo0_l0001T
ooooo`00:Oooool00ol0003oooooooooo`0Eooooo`;o00002?ooool2o`00043ooooo0_l0000<oooo
o`Co00003oooool2o`0004gooooo0_l00003ooooo`;o00000_ooool2o`00013ooooo0_l0000Coooo
o`;o0000>Oooool002Wooooo00?o0000ooooooooool01?ooool2o`0004cooooo0_l0000Eooooo`;o
000000Coooooo`000?l0003ooooo0_l0000Aooooo`;o0000E_ooool2o`00013ooooo0_l00004oooo
o`;o00000oooool2o`0000Sooooo0_l00006ooooo`;o00009?ooool2o`0000_ooooo000Yooooo`;o
00001Oooool2o`0004cooooo0_l0000Eooooo`;o000000?oooooo`000?l00000?_ooool2o`0001?o
oooo0_l0000Iooooo`;o00005?ooool2o`0000?ooooo0_l0000@ooooo`;o00009?ooool2o`0000_o
oooo000Yooooo`03o`000?oooooooooo02Cooooo0_l0000Eooooo`;o00004Oooool2o`0002Kooooo
0_l0000dooooo`;o00004_ooool3o`0001Wooooo0ol0001Mooooo`00:Oooool00ol0003ooooooooo
o`0Tooooo`;o00005Oooool2o`00017ooooo0_l0000Vooooo`;o0000B?ooool2o`0001[ooooo0ol0
000kooooo`;o00008?ooool002Wooooo00?o0000ooooooooool05Oooool2o`0003cooooo0_l0000P
ooooo`;o00008?ooool2o`0001Wooooo0_l000000ooooooo0000o`00000Uooooo`;o0000??ooool2
o`00023ooooo000Yooooo`03o`000?oooooooooo00Gooooo0_l0000>ooooo`;o0000??ooool2o`00
00Cooooo0_l0000Cooooo`;o00001Oooool2o`0001?ooooo0_l0000;ooooo`;o00006Oooool2o`00
0003ooooool0003o000000;ooooo0_l00003ooooo`;o00007oooool2o`0001Wooooo0_l0000=oooo
o`;o0000<Oooool002Wooooo0_l00006ooooo`;o00001Oooool2o`0002Kooooo0_l0000Sooooo`;o
00004oooool2o`0001[ooooo0_l0000]ooooo`;o00000oooool2o`0001oooooo0_l00006ooooo`;o
00004Oooool2o`0000gooooo0_l0000aooooo`00:Oooool00ol0003oooooooooo`0<ooooo`;o0000
9_ooool2o`000;7ooooo0_l00002ooooo`;o00004oooool2o`0000?ooooo0_l0000eooooo`003_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01Oooool00ol0003oooooooooo`17ooooo`;o0000:Oooool2o`0001Kooooo0_l00002ooooo`;o
0000<_ooool2o`0002Oooooo0_l0000Cooooo`;o00000oooool2o`0003Gooooo000>ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`17ooooo`;o0000:Oooool2o`0001Kooooo0_l00002ooooo`;o00009?ooool4o`0000[o
oooo0_l0000]ooooo`;o0000;Oooool2o`0001[ooooo000>ooooo`05oa0@4?ooooooooooooooool@
41004?ooool00ol0003oooooooooo`03ooooo`?o00008_ooool2o`0001oooooo0_l0000>ooooo`;o
00000_ooool2o`0001_ooooo0_l0000Kooooo`;o00008Oooool4o`0001gooooo0_l0000Jooooo`;o
0000;Oooool2o`0001[ooooo000>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo02;ooooo0_l0000Oooooo`;o00003_ooool2o`0000;o
oooo0_l0000Kooooo`;o00006oooool2o`0004;ooooo0_l0000Aooooo`;o00007Oooool2o`0003?o
oooo000>ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool07Oooool2o`0000cooooo0_l00008ooooo`;o00000_ooool2o`00
03Cooooo0_l0000Kooooo`;o00008_ooool2o`00017ooooo0_l0000Fooooo`;o00002oooool2o`00
00Wooooo0_l0000Booooo`;o00008Oooool2o`00013ooooo000>ooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01gooooo0_l0000<oooo
o`;o00002?ooool6o`00013ooooo0_l0000Looooo`;o00001?ooool2o`0001_ooooo0_l0000Roooo
o`;o00004Oooool2o`0001Kooooo0_l0000Fooooo`;o00005_ooool2o`0000;ooooo0_l0000Ioooo
o`;o00004?ooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0=oooool2o`0001;ooooo0_l0000Looooo`;o00003?ooool2o`00
0003ooooool0003o000005?ooooo0_l0000dooooo`;o00001?ooool2o`0000;ooooo0_l00007oooo
o`;o00008_ooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`00
07Sooooo0_l000000ooooooo0000o`00001Cooooo`;o0000=?ooool2o`00017ooooo0_l0000Roooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400=ooooo`03
ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000Kooooo
00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05o`000?ooooooooooooooool0
00003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0
003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onY
ZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmoooo
o`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_ooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Oooooo`Co000000?o410@ooooooooool0
0oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`?o0000oooooolm
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Oooooo`03oeEEEOmVIVKo00000?ooooooAoooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .27018 Mdot
.02762 .26704 Mdot
.02952 .27792 Mdot
.03143 .28314 Mdot
.03333 .36137 Mdot
.03524 .31079 Mdot
.03714 .31988 Mdot
.03905 .31346 Mdot
.04095 .35853 Mdot
.04286 .31612 Mdot
.04476 .33533 Mdot
.04667 .36291 Mdot
.04857 .25709 Mdot
.05048 .30711 Mdot
.05238 .40854 Mdot
.05429 .28951 Mdot
.05619 .33602 Mdot
.0581 .25711 Mdot
.06 .34758 Mdot
.0619 .23135 Mdot
.06381 .2351 Mdot
.06571 .23967 Mdot
.06762 .24194 Mdot
.06952 .24533 Mdot
.07143 .41393 Mdot
.07333 .37127 Mdot
.07524 .34884 Mdot
.07714 .35349 Mdot
.07905 .2367 Mdot
.08095 .24597 Mdot
.08286 .25291 Mdot
.08476 .33654 Mdot
.08667 .34672 Mdot
.08857 .30514 Mdot
.09048 .33303 Mdot
.09238 .27348 Mdot
.09429 .30341 Mdot
.09619 .35266 Mdot
.0981 .28495 Mdot
.1 .34554 Mdot
.1019 .38912 Mdot
.10381 .32611 Mdot
.10571 .30955 Mdot
.10762 .30558 Mdot
.10952 .30797 Mdot
.11143 .36599 Mdot
.11333 .33473 Mdot
.11524 .30288 Mdot
.11714 .37218 Mdot
.11905 .26485 Mdot
.12095 .31394 Mdot
.12286 .26249 Mdot
.12476 .48179 Mdot
.12667 .30278 Mdot
.12857 .3362 Mdot
.13048 .35791 Mdot
.13238 .32886 Mdot
.13429 .34934 Mdot
.13619 .30092 Mdot
.1381 .31128 Mdot
.14 .36698 Mdot
.1419 .42655 Mdot
.14381 .30531 Mdot
.14571 .26433 Mdot
.14762 .389 Mdot
.14952 .33703 Mdot
.15143 .32243 Mdot
.15333 .30918 Mdot
.15524 .34721 Mdot
.15714 .23635 Mdot
.15905 .37052 Mdot
.16095 .32284 Mdot
.16286 .3304 Mdot
.16476 .31168 Mdot
.16667 .30577 Mdot
.16857 .29416 Mdot
.17048 .48184 Mdot
.17238 .35728 Mdot
.17429 .25408 Mdot
.17619 .33962 Mdot
.1781 .26246 Mdot
.18 .24162 Mdot
.1819 .28972 Mdot
.18381 .3335 Mdot
.18571 .3143 Mdot
.18762 .26534 Mdot
.18952 .36179 Mdot
.19143 .36166 Mdot
.19333 .36157 Mdot
.19524 .31383 Mdot
.19714 .41979 Mdot
.19905 .4672 Mdot
.20095 .26199 Mdot
.20286 .36511 Mdot
.20476 .26072 Mdot
.20667 .46031 Mdot
.20857 .30764 Mdot
.21048 .346 Mdot
.21238 .48268 Mdot
.21429 .37205 Mdot
.21619 .25909 Mdot
.2181 .37009 Mdot
.22 .38013 Mdot
.2219 .29054 Mdot
.22381 .23598 Mdot
.22571 .30495 Mdot
.22762 .36025 Mdot
.22952 .34861 Mdot
.23143 .26227 Mdot
.23333 .23456 Mdot
.23524 .30544 Mdot
.23714 .26851 Mdot
.23905 .34142 Mdot
.24095 .2357 Mdot
.24286 .49218 Mdot
.24476 .31455 Mdot
.24667 .36571 Mdot
.24857 .30312 Mdot
.25048 .31151 Mdot
.25238 .33649 Mdot
.25429 .24975 Mdot
.25619 .41218 Mdot
.2581 .24884 Mdot
.26 .23307 Mdot
.2619 .23503 Mdot
.26381 .29506 Mdot
.26571 .24347 Mdot
.26762 .45574 Mdot
.26952 .23852 Mdot
.27143 .27757 Mdot
.27333 .23635 Mdot
.27524 .24878 Mdot
.27714 .3786 Mdot
.27905 .32863 Mdot
.28095 .30834 Mdot
.28286 .23725 Mdot
.28476 .25607 Mdot
.28667 .24283 Mdot
.28857 .33199 Mdot
.29048 .36803 Mdot
.29238 .40265 Mdot
.29429 .45052 Mdot
.29619 .2591 Mdot
.2981 .34499 Mdot
.3 .33906 Mdot
.3019 .23201 Mdot
.30381 .31011 Mdot
.30571 .49555 Mdot
.30762 .35711 Mdot
.30952 .36281 Mdot
.31143 .38336 Mdot
.31333 .37303 Mdot
.31524 .33627 Mdot
.31714 .2511 Mdot
.31905 .32267 Mdot
.32095 .26859 Mdot
.32286 .27499 Mdot
.32476 .28776 Mdot
.32667 .32208 Mdot
.32857 .31627 Mdot
.33048 .26997 Mdot
.33238 .37265 Mdot
.33429 .24381 Mdot
.33619 .34363 Mdot
.3381 .27829 Mdot
.34 .27768 Mdot
.3419 .24537 Mdot
.34381 .31519 Mdot
.34571 .23467 Mdot
.34762 .34744 Mdot
.34952 .24769 Mdot
.35143 .28297 Mdot
.35333 .2726 Mdot
.35524 .35009 Mdot
.35714 .36266 Mdot
.35905 .35866 Mdot
.36095 .36921 Mdot
.36286 .4596 Mdot
.36476 .2656 Mdot
.36667 .29073 Mdot
.36857 .25244 Mdot
.37048 .24142 Mdot
.37238 .35956 Mdot
.37429 .29005 Mdot
.37619 .39007 Mdot
.3781 .27191 Mdot
.38 .37004 Mdot
.3819 .45859 Mdot
.38381 .30807 Mdot
.38571 .34757 Mdot
.38762 .31946 Mdot
.38952 .40735 Mdot
.39143 .23164 Mdot
.39333 .26342 Mdot
.39524 .43258 Mdot
.39714 .31833 Mdot
.39905 .37929 Mdot
.40095 .37784 Mdot
.40286 .36462 Mdot
.40476 .46687 Mdot
.40667 .36511 Mdot
.40857 .29459 Mdot
.41048 .29417 Mdot
.41238 .32285 Mdot
.41429 .36207 Mdot
.41619 .4701 Mdot
.4181 .24513 Mdot
.42 .26328 Mdot
.4219 .29933 Mdot
.42381 .25879 Mdot
.42571 .28595 Mdot
.42762 .3291 Mdot
.42952 .2636 Mdot
.43143 .35959 Mdot
.43333 .23518 Mdot
.43524 .3057 Mdot
.43714 .24323 Mdot
.43905 .35724 Mdot
.44095 .35089 Mdot
.44286 .28859 Mdot
.44476 .27677 Mdot
.44667 .33329 Mdot
.44857 .3664 Mdot
.45048 .33333 Mdot
.45238 .23381 Mdot
.45429 .27608 Mdot
.45619 .31903 Mdot
.4581 .35968 Mdot
.46 .29337 Mdot
.4619 .26335 Mdot
.46381 .40761 Mdot
.46571 .40513 Mdot
.46762 .27941 Mdot
.46952 .31209 Mdot
.47143 .474 Mdot
.47333 .35686 Mdot
.47524 .34229 Mdot
.47714 .41499 Mdot
.47905 .35071 Mdot
.48095 .2902 Mdot
.48286 .23602 Mdot
.48476 .25267 Mdot
.48667 .43065 Mdot
.48857 .32763 Mdot
.49048 .23343 Mdot
.49238 .37036 Mdot
.49429 .31697 Mdot
.49619 .26085 Mdot
.4981 .30701 Mdot
.5 .32801 Mdot
.5019 .37107 Mdot
.50381 .29403 Mdot
.50571 .38436 Mdot
.50762 .31304 Mdot
.50952 .26172 Mdot
.51143 .32126 Mdot
.51333 .36779 Mdot
.51524 .35041 Mdot
.51714 .35435 Mdot
.51905 .29566 Mdot
.52095 .34373 Mdot
.52286 .29936 Mdot
.52476 .3675 Mdot
.52667 .34179 Mdot
.52857 .27407 Mdot
.53048 .28836 Mdot
.53238 .36669 Mdot
.53429 .26083 Mdot
.53619 .34142 Mdot
.5381 .27324 Mdot
.54 .28337 Mdot
.5419 .36127 Mdot
.54381 .25198 Mdot
.54571 .34136 Mdot
.54762 .30418 Mdot
.54952 .35531 Mdot
.55143 .26565 Mdot
.55333 .28277 Mdot
.55524 .35071 Mdot
.55714 .3216 Mdot
.55905 .31809 Mdot
.56095 .28535 Mdot
.56286 .24952 Mdot
.56476 .30645 Mdot
.56667 .32179 Mdot
.56857 .32368 Mdot
.57048 .37119 Mdot
.57238 .34757 Mdot
.57429 .32164 Mdot
.57619 .35683 Mdot
.5781 .23227 Mdot
.58 .36468 Mdot
.5819 .26519 Mdot
.58381 .46003 Mdot
.58571 .31779 Mdot
.58762 .39857 Mdot
.58952 .3395 Mdot
.59143 .31415 Mdot
.59333 .2791 Mdot
.59524 .43778 Mdot
.59714 .23346 Mdot
.59905 .40637 Mdot
.60095 .49715 Mdot
.60286 .36303 Mdot
.60476 .35128 Mdot
.60667 .25508 Mdot
.60857 .32568 Mdot
.61048 .40061 Mdot
.61238 .33221 Mdot
.61429 .33166 Mdot
.61619 .36866 Mdot
.6181 .30017 Mdot
.62 .25079 Mdot
.6219 .33862 Mdot
.62381 .24327 Mdot
.62571 .38406 Mdot
.62762 .30449 Mdot
.62952 .26943 Mdot
.63143 .31249 Mdot
.63333 .39141 Mdot
.63524 .30071 Mdot
.63714 .36689 Mdot
.63905 .42827 Mdot
.64095 .44418 Mdot
.64286 .2934 Mdot
.64476 .33989 Mdot
.64667 .34163 Mdot
.64857 .30983 Mdot
.65048 .35627 Mdot
.65238 .3144 Mdot
.65429 .31869 Mdot
.65619 .35786 Mdot
.6581 .32551 Mdot
.66 .33388 Mdot
.6619 .26288 Mdot
.66381 .25286 Mdot
.66571 .28289 Mdot
.66762 .32241 Mdot
.66952 .28917 Mdot
.67143 .31971 Mdot
.67333 .27873 Mdot
.67524 .37221 Mdot
.67714 .3615 Mdot
.67905 .47868 Mdot
.68095 .36268 Mdot
.68286 .23825 Mdot
.68476 .26107 Mdot
.68667 .35786 Mdot
.68857 .34871 Mdot
.69048 .24537 Mdot
.69238 .23747 Mdot
.69429 .26078 Mdot
.69619 .35519 Mdot
.6981 .44877 Mdot
.7 .35283 Mdot
.7019 .26268 Mdot
.70381 .26845 Mdot
.70571 .36855 Mdot
.70762 .35347 Mdot
.70952 .27293 Mdot
.71143 .36294 Mdot
.71333 .35572 Mdot
.71524 .4357 Mdot
.71714 .23339 Mdot
.71905 .38156 Mdot
.72095 .36973 Mdot
.72286 .37069 Mdot
.72476 .32169 Mdot
.72667 .35816 Mdot
.72857 .40643 Mdot
.73048 .33487 Mdot
.73238 .32171 Mdot
.73429 .2535 Mdot
.73619 .35106 Mdot
.7381 .31432 Mdot
.74 .26108 Mdot
.7419 .35077 Mdot
.74381 .28678 Mdot
.74571 .29911 Mdot
.74762 .33109 Mdot
.74952 .2429 Mdot
.75143 .25337 Mdot
.75333 .23667 Mdot
.75524 .40911 Mdot
.75714 .49433 Mdot
.75905 .3449 Mdot
.76095 .28409 Mdot
.76286 .32047 Mdot
.76476 .41837 Mdot
.76667 .36767 Mdot
.76857 .3183 Mdot
.77048 .3522 Mdot
.77238 .23591 Mdot
.77429 .31887 Mdot
.77619 .31664 Mdot
.7781 .3691 Mdot
.78 .3447 Mdot
.7819 .29904 Mdot
.78381 .2394 Mdot
.78571 .43615 Mdot
.78762 .36026 Mdot
.78952 .33116 Mdot
.79143 .47884 Mdot
.79333 .34179 Mdot
.79524 .35826 Mdot
.79714 .35763 Mdot
.79905 .30005 Mdot
.80095 .3334 Mdot
.80286 .36385 Mdot
.80476 .34826 Mdot
.80667 .26019 Mdot
.80857 .31588 Mdot
.81048 .2721 Mdot
.81238 .3874 Mdot
.81429 .3634 Mdot
.81619 .26379 Mdot
.8181 .26629 Mdot
.82 .34007 Mdot
.8219 .2909 Mdot
.82381 .36301 Mdot
.82571 .30641 Mdot
.82762 .33492 Mdot
.82952 .26291 Mdot
.83143 .39949 Mdot
.83333 .36433 Mdot
.83524 .27638 Mdot
.83714 .33346 Mdot
.83905 .35949 Mdot
.84095 .25002 Mdot
.84286 .34959 Mdot
.84476 .34783 Mdot
.84667 .41143 Mdot
.84857 .45819 Mdot
.85048 .27202 Mdot
.85238 .48986 Mdot
.85429 .31154 Mdot
.85619 .26581 Mdot
.8581 .37864 Mdot
.86 .40987 Mdot
.8619 .34189 Mdot
.86381 .23996 Mdot
.86571 .47977 Mdot
.86762 .26171 Mdot
.86952 .31871 Mdot
.87143 .35884 Mdot
.87333 .26352 Mdot
.87524 .34864 Mdot
.87714 .46717 Mdot
.87905 .27489 Mdot
.88095 .30083 Mdot
.88286 .33972 Mdot
.88476 .2661 Mdot
.88667 .2943 Mdot
.88857 .29219 Mdot
.89048 .31781 Mdot
.89238 .31086 Mdot
.89429 .24549 Mdot
.89619 .27352 Mdot
.8981 .28724 Mdot
.9 .24575 Mdot
.9019 .26595 Mdot
.90381 .33883 Mdot
.90571 .44728 Mdot
.90762 .316 Mdot
.90952 .32516 Mdot
.91143 .37804 Mdot
.91333 .34403 Mdot
.91524 .27132 Mdot
.91714 .35541 Mdot
.91905 .32115 Mdot
.92095 .24254 Mdot
.92286 .26512 Mdot
.92476 .35128 Mdot
.92667 .35656 Mdot
.92857 .31615 Mdot
.93048 .41036 Mdot
.93238 .28716 Mdot
.93429 .28543 Mdot
.93619 .29418 Mdot
.9381 .34604 Mdot
.94 .32382 Mdot
.9419 .30837 Mdot
.94381 .3087 Mdot
.94571 .32468 Mdot
.94762 .30597 Mdot
.94952 .36532 Mdot
.95143 .3385 Mdot
.95333 .35897 Mdot
.95524 .26032 Mdot
.95714 .33454 Mdot
.95905 .35578 Mdot
.96095 .32076 Mdot
.96286 .49261 Mdot
.96476 .31771 Mdot
.96667 .27775 Mdot
.96857 .35438 Mdot
.97048 .27182 Mdot
.97238 .34802 Mdot
.97429 .2463 Mdot
.97619 .36071 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooocgooooo0006
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol00009ooooo`;o0000?Oooool2o`0000cooooo0_l0000Jooooo`;o00004_oo
ool2o`0000[ooooo0_l0000Jooooo`;o00001Oooool2o`0002Cooooo0_l0001Oooooo`001_ooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool02Oooool2o`0000?ooooo0_l0000Gooooo`;o0000
5?ooool2o`000003ooooool0003o000000;o00001?ooool3o`0000;ooooo0_l000000ooooooo0000
o`000004ooooo`;o00003?ooool2o`0000cooooo0_l0000<ooooo`;o00001?ooool2o`0000Sooooo
1?l0000Jooooo`;o00001Oooool2o`0002Cooooo0_l0000:ooooo`;o00001?ooool2o`0004gooooo
0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02Oooool3o`0000;ooooo0_l0000Gooooo`;o0000
5?ooool2o`000003ooooool0003o000000;o00001Oooool6o`000003ooooool0003o000001;ooooo
0_l0000Jooooo`;o00003_ooool2o`0003kooooo0_l000000ooooooo0000o`00000Booooo`;o0000
1?ooool2o`0000;ooooo0_l0000Gooooo`;o0000<?ooool000Kooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00[ooooo0_l0000Rooooo`;o00006_ooool3o`0000Cooooo0_l0000Iooooo`;o
00004oooool2o`0003[ooooo0_l0000Aooooo`;o000000?oooooo`000?l000004Oooool2o`0000Wo
oooo0_l0000Gooooo`;o00004Oooool2o`0001gooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo
00[ooooo0ol00002ooooo`;o00007Oooool2o`0001[ooooo0_l00005ooooo`;o00003Oooool2o`00
0003ooooool0003o000000Oooooo0_l0000=ooooo`;o00001?ooool2o`0003[ooooo0_l0000Doooo
o`;o00004Oooool2o`0002cooooo1?l00005ooooo`;o00003oooool2o`0000cooooo000Yooooo`;o
00003?ooool2o`0000;ooooo0_l0000gooooo`;o00000oooool2o`00017ooooo0_l000000ooooooo
0000o`000002o`0001Cooooo0_l0000]ooooo`;o00009oooool2o`0003oooooo1?l0000Fooooo`;o
00003?ooool002Wooooo00?o0000ooooooooool0A_ooool4o`0000?ooooo0_l0000<ooooo`;o0000
2?ooool2o`0000Cooooo0_l0000Sooooo`;o00004Oooool2o`0000Gooooo0_l0000@ooooo`;o0000
AOooool2o`0003Oooooo000Yooooo`03o`000?oooooooooo00oooooo0_l0000Looooo`;o00005ooo
ool2o`0001?ooooo0_l0000>ooooo`;o00008oooool2o`00017ooooo0_l0000Cooooo`;o00000_oo
ool2o`0000cooooo0_l0000Eooooo`;o00000oooool2o`0001_ooooo0_l0000gooooo`00:Oooool0
0ol0003oooooooooo`04ooooo`;o000000?oooooo`000?l000001_ooool2o`0001cooooo0_l0000Q
ooooo`;o0000:oooool2o`0003Wooooo0_l0000@ooooo`;o00005Oooool2o`0000?ooooo0_l0001D
ooooo`00:Oooool00ol0003oooooooooo`04ooooo`;o000000?oooooo`000?l00000;?ooool3o`00
00;ooooo0_l0000Dooooo`;o00000_ooool2o`0002Oooooo0_l0000Eooooo`;o00000_ooool2o`00
00Kooooo0_l0000_ooooo`;o000000?oooooo`000?l000003Oooool2o`0001?ooooo0_l0000Boooo
o`;o00006_ooool2o`0001;ooooo000Yooooo`;o00007?ooool3o`0000Gooooo0_l00009ooooo`;o
00001Oooool3o`0000;ooooo0_l00003ooooo`;o00004oooool2o`0001gooooo0_l00007ooooo`;o
000000?oooooo`000?l000002?ooool2o`0000Wooooo0_l00002ooooo`;o00001_ooool2o`0000ko
oooo0_l0000Gooooo`;o00001_ooool2o`000003ooooool0003o000000;o00002oooool2o`0001?o
oooo0_l000000ooooooo0000o`000002ooooo`;o00002oooool3o`0000kooooo0_l00009ooooo`;o
00004_ooool002Wooooo0_l0000Looooo`?o00001Oooool2o`0000Wooooo0_l000000ooooooo0000
o`00000<ooooo`;o0000:Oooool2o`0000Oooooo0_l00007ooooo`;o000000?oooooo`000?l00000
2?ooool2o`0001_ooooo0_l00008ooooo`;o00005oooool2o`0000_ooooo0_l0000Sooooo`?o0000
00?oooooo`000?l000001oooool2o`0000?ooooo0_l00002ooooo`;o00001?ooool2o`0000Cooooo
0_l0000Mooooo`00:Oooool2o`00037ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb
<S;ok^k^0oooool01Oo^k^ko<S8bo`000?l0003ok^k^01Sooooo0_l000000ooooooo0000o`000009
ooooo`;o000000?oooooo`000?l000000ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Cooooo0_l00002ooooo`05oiRHV?l@413o0000oc8b<_o<
c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02
o`0001Kooooo0_l0000@ooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;o00002_ooool2o`0000Oooooo0_l00004oooo
o`;o00000_ooool2o`0000Sooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Yooooo`;o00004ooo
ool2o`0001kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00GoMgMgoiRHV?l0003o0000ogMgM`0Hooooo`;o000000?oooooo`000?l000001Oooool2o`0000Go
oooo00GoV9RHo`000?l0003oooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01gooooo0_l000000ooooooo0000o`000006ooooo`05oa0@4?nj
^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`02o`0001Kooooo1?l0000?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So0000o`000?mgMgL02_ooool2o`0000gooooo0_l0
0004ooooo`;o00002oooool01OmgMgOo<S8booooooooooooMgMg00;o000000?oV9RHogMgMoooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000Yooooo`03o`000?oooooooooo01;ooooo
0_l0000Nooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@41002?ooool2o`0000kooooo0_l00004ooooo`;o00000_ooool2o`00
00Kooooo0_l000000oo^k^koooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool0
1Ol@413ooooooooooooooooo410@00;ooooo0_l000000ooooooo0000o`00000Fooooo`;o000000?o
ooooo`000?l000002_ooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`03oa0@4?oooooooooo01Sooooo0_l0000<ooooo`Go00000oooool01Ol@413o
oooooooooooooooo410@00?ooooo00Go410@ooooool0003o0000oa0@4005ooooo`;o00000oooool2
o`0000Oooooo0_l00004ooooo`;o00004_ooool01?l0003oooooooooool@4102o`000003ooooool@
413ooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`00:Oooool3o`0003;ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000008ooooo`;o00003_ooool2o`0000?ooooo0ol0000;ooooo`03oiRHV?lQ8B7ok^k^00?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool2
o`000003ooooool0003o000000;ooooo0_l0000Pooooo`03ojVYZOl@413ooooo00;ooooo0ol00000
0ooooooo0000ooooo`02ooooo`05o`000?ooooooooooooooool000003_ooool2o`0001Sooooo00Co
A4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000005ooooo`;o00003?ooool2o`0001Oooooo00?oMgMgoc8b<_ooool00_l00003oooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`01ooooo`00:Oooool4o`00
037ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`00000Mooooo`;o00000oooool2o`0000Sooooo00?oMgMgofIVI_ooool00_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000009ooooo`;o
00005Oooool2o`0000?ooooo0_l00003ooooo`03oa0@4?l0003o^[Zj00?ooooo0ol000000ooooooo
0000ooooo`02ooooo`05o`000?ooooooooooooooool000003?ooool4o`0001Sooooo00CogMgMoeEE
EOoooooo00001?ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`00000Yooooo`06o`000?lQ8B7o0000oc8b<_o<c<cooooo0_l00003ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`01ooooo`00:Oooool01?l0003oooooo`000?l0000C
ooooo`;o00007?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@02;ooooo0_l00009ooooo`05o`000?ooooooooooooooool@
41000oooool01?l@413oooooooooooooool2o`0000;ooooo00?o410@ooooooooool07_ooool2o`00
00?ooooo1?l00002ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@41003?ooool2o`0001Oooooo0_l00002ooooo`03ogMgMol0
003o000000Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
41009Oooool2o`0000;ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`00:Oooool00ol0003oooooooooo`06oooo
o`;o00003?ooool2o`0001Wooooo0_l000000ooooooo0000ooooo`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01Wooooo0_l0000>ooooo`;o000000?o
oooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0_l000001?ooooooV9RH
ogMgMoooool2o`0001[ooooo0_l00008ooooo`;o000000CoV9RHoooooonj^[[o00000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0=ooooo`;o00005_oo
ool2o`0000;ooooo00?ok^k^o`000?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0Iooooo`;o00002Oooool3o`0000;ooooo00?o0000oooooooo
ool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`00:Oooool00ol0003oooooooooo`06ooooo`;o00009oooool2o`000003ofIVI_l0003ooooo
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02o`000006ooooooo^k^ko<S8bo`000?lb<S;ok^k^
6Oooool2o`0000cooooo1Ol000000olQ8B7oc<c<ooooo`02ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01_o^k^ko<S8bo`000?lb<S;ok^k^ooooo`;o00002_ooool2o`0000kooooo0_l00009
ooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`;o00006oooool00omgMgOo0000ooooo`03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01_o^k^ko<S8bo`000?lb<S;ok^k^ooooo`;o00004ooo
ool2o`000003ooooool0003o000000Wooooo0_l00003ooooo`Co00000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool2o`0002cooooo
0_l0000?ooooo`;o00002oooool2o`00023ooooo0_l0000;ooooo`?o00003_ooool2o`0000Cooooo
0_l00006ooooo`;o00000oooool2o`0002Gooooo0_l0000hooooo`;o00004oooool2o`0000kooooo
0_l0000Hooooo`00:Oooool00ol0003oooooooooo`0[ooooo`;o00007?ooool2o`0002gooooo0ol0
00000ooooooo0000o`00000;ooooo`;o00003?ooool2o`0000?ooooo0ol0000Tooooo`;o00007ooo
ool2o`0000[ooooo0_l0000Pooooo`;o00003_ooool2o`0001Sooooo000Yooooo`03o`000?oooooo
oooo023ooooo0_l0001Jooooo`;o00007oooool2o`0001cooooo0_l00004ooooo`;o00008Oooool2
o`0000[ooooo0_l00004ooooo`;o00006?ooool2o`0002[ooooo000Yooooo`03o`000?oooooooooo
017ooooo1?l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l000001?oooooo0000o`000?oo
ool2o`0001Sooooo0_l000000ooooooo0000o`000003ooooo`;o0000>_ooool2o`0002;ooooo0_l0
000Dooooo`;o000000Coooooo`000?l0003ooooo0_l0000cooooo`;o00006?ooool2o`0002[ooooo
000Yooooo`03o`000?oooooooooo00Gooooo0_l0000:ooooo`Co00000_ooool5o`000003ooooool0
003o000000Cooooo0_l00005ooooo`;o00003?ooool2o`0000?ooooo0_l000000ooooooo0000o`00
0003ooooo`;o00002?ooool2o`0001oooooo0_l0000?ooooo`;o00004_ooool2o`0000kooooo0_l0
0003ooooo`;o00004_ooool2o`0003kooooo0_l0000Sooooo`Co00005Oooool0027oooooool00014
o`0000Cooooo000Yooooo`03o`000?oooooooooo00?o00001_ooool00ol0003oooooooooo`0:oooo
o`?o00000oooool2o`0000?ooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo00Go0000oooo
ool0003o0000ooooo`02o`0000Gooooo00?o0000ooooooooool01_ooool5o`0000_ooooo00?o0000
ooooooooool00_l00007ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo0_l00002ooooo`03o`000?oooooo
oooo00Gooooo0_l00002ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool3
o`0000[ooooo0_l00003ooooo`?o00001Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Gooooo0_l00002ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`06ooooo`;o00000_ooool00ol0003oooooooooo`06ooooo`;o000000?ooooo
o`000?ooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo000Yoooo
o`04o`000?ooooooooooooooo`?o00006?ooool2o`0001;ooooo0_l000000ooooooo0000o`000005
ooooo`03o`000?oooooooooo00Kooooo0_l0000Iooooo`;o00000oooool2o`0001?ooooo00?o0000
ooooooooool04Oooool2o`0000Kooooo0_l00002ooooo`;o00003_ooool2o`0000Oooooo1Ol0000:
ooooo`;o00001?ooool2o`0001[ooooo0_l0000:ooooo`;o00000_ooool00ol0003oooooooooo`04
ooooo`;o00006?ooool2o`0000?ooooo0_l00005ooooo`;o00002_ooool2o`0000;ooooo00?o0000
ooooooooool02_ooool002Wooooo00Co0000oooooooooooooooo0ol0001Jooooo`;o00000oooool2
o`0000cooooo0_l000000ooooooo0000o`00000Aooooo`;o00002oooool2o`0000?ooooo0_l0000=
ooooo`;o00001oooool2o`0001Cooooo0_l00004ooooo`;o00006oooool6o`0000Wooooo0_l0000A
ooooo`;o00001Oooool2o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000002Oooool3
o`0000oooooo000Yooooo`04o`000?ooooooooooooooo`;o00008_ooool2o`000003ooooool0003o
0000037ooooo0_l000000ooooooo0000o`00000Aooooo`;o000000?oooooo`000?l000000oooool2
o`0000cooooo0_l0000@ooooo`;o00003Oooool2o`000003ooooool0003o000000;o00006?ooool2
o`0000;ooooo1?l0000?ooooo`Co00002?ooool6o`0001cooooo0_l0000>ooooo`;o00001Oooool2
o`0000Gooooo0_l0000@ooooo`00:Oooool2o`0001Oooooo0_l0000=ooooo`;o000000?oooooo`00
0?l00000<Oooool2o`000003ooooool0003o000001Wooooo0_l0000]ooooo`;o000000?oooooo`00
0?l000000_l00009ooooo`;o00003_ooool2o`000003ooooool0003o0000017ooooo1?l0000goooo
o`;o00002?ooool4o`0001Gooooo000Yooooo`03o`000?oooooooooo01Kooooo0_l00007ooooo`;o
00002?ooool2o`0002?ooooo0_l0000^ooooo`;o00004_ooool2o`000003ooooool0003o0000027o
oooo0_l0000>ooooo`;o0000Coooool2o`0000[ooooo0_l0000Eooooo`00:Oooool00ol0003ooooo
ooooo`0Booooo`;o00002oooool2o`0000Sooooo0_l00005ooooo`;o00007?ooool2o`000003oooo
ool0003o000002_ooooo0_l00004ooooo`?o00002oooool2o`000003ooooool0003o000002?ooooo
0_l0000Yooooo`;o00002oooool2o`0000;ooooo0_l0000:ooooo`;o0000>?ooool002Wooooo00?o
0000ooooooooool00oooool2o`0000;ooooo0_l00007ooooo`Co00001Oooool2o`0000?ooooo0_l0
000@ooooo`;o00005?ooool2o`0000Wooooo0_l00007ooooo`;o0000:?ooool3o`0003?ooooo0_l0
000=ooooo`;o00005?ooool2o`0000Cooooo0_l0000;ooooo`;o00000_ooool2o`0000Oooooo0_l0
00000ooooooo0000o`00000Tooooo`;o00004_ooool002Wooooo00?o0000ooooooooool00oooool2
o`0000;ooooo0_l00007ooooo`;o00001oooool2o`0000?ooooo0_l00005ooooo`;o00001_ooool2
o`0001Oooooo0_l0000=ooooo`;o00000oooool2o`0005Kooooo0_l00009ooooo`;o00001Oooool2
o`0000?ooooo0_l0000Dooooo`;o00007_ooool2o`0000oooooo0_l00005ooooo`;o00003_ooool3
o`0001;ooooo000Yooooo`;o00009_ooool2o`0000Kooooo0_l0000Booooo`;o00004_ooool2o`00
03Kooooo0_l0000?ooooo`;o000000Coooooo`000?l0003ooooo0_l0000<ooooo`;o00002Oooool2
o`0000Gooooo0ol0000]ooooo`;o00001_ooool2o`0000cooooo0_l00004ooooo`;o00001Oooool2
o`0000kooooo0_l0000Cooooo`00:Oooool00ol0003oooooooooo`0Eooooo`;o00008Oooool2o`00
00Oooooo0_l0000Aooooo`;o00002oooool2o`0002[ooooo0_l0000=ooooo`Co000000Coooooo`00
0?l0003ooooo0_l0000Oooooo`;o00008_ooool2o`0000Cooooo0_l00003ooooo`;o00001_ooool2
o`0000cooooo0_l0000>ooooo`;o00001_ooool2o`0001Sooooo000Yooooo`03o`000?oooooooooo
00Sooooo0_l00003ooooo`;o000000?oooooo`000?l000000oooool2o`00013ooooo0_l0000?oooo
o`;o00001?ooool2o`0001Cooooo0_l0000;ooooo`;o000000?oooooo`000?l000002oooool2o`00
02Wooooo0_l0000?ooooo`;o00008oooool2o`0001Gooooo0_l00004ooooo`;o00001_ooool2o`00
00_ooooo0_l00008ooooo`;o00002_ooool2o`0000Kooooo0_l00009ooooo`;o00003Oooool002Wo
oooo00?o0000ooooooooool02?ooool2o`0000?ooooo0_l000000ooooooo0000o`00000>ooooo`;o
00001Oooool2o`0001Gooooo0_l0000Tooooo`;o000000?oooooo`000?l000002?ooool2o`0000oo
oooo0_l0000;ooooo`;o00002Oooool2o`0000_ooooo0_l00004ooooo`;o00002?ooool2o`0001Wo
oooo0_l0000=ooooo`Co00001oooool2o`0000Wooooo0_l0000;ooooo`;o00002?ooool2o`0000ko
oooo0_l0000=ooooo`;o00003Oooool002Wooooo00?o0000ooooooooool03Oooool2o`0000Gooooo
0_l0000:ooooo`;o0000AOooool2o`0001Wooooo0_l0000;ooooo`;o00002Oooool3o`0000Sooooo
1?l0000>ooooo`;o00006oooool6o`0000Oooooo1?l00007ooooo`;o00005_ooool2o`0001Kooooo
1?l0000<ooooo`;o00003_ooool002Wooooo0_l00003ooooo`;o00002Oooool2o`0000Gooooo0_l0
0009ooooo`;o00002oooool2o`0002[ooooo0_l0000Xooooo`;o00002Oooool2o`0000cooooo0_l0
0008ooooo`;o00001oooool2o`0001Kooooo1?l00007ooooo`;o000000?oooooo`000?l000001_l0
0002ooooo`;o00005?ooool3o`0002Gooooo0_l000000ooooooo0000o`000008ooooo`;o000000?o
ooooo`000?l000003_ooool002Wooooo00Go0000ooooool0003o0000ooooo`02o`0001_ooooo0_l0
000;ooooo`;o00001?ooool3o`0000Wooooo0_l0000Hooooo`;o00003_ooool2o`0000;ooooo0_l0
000Aooooo`;o000000?oooooo`000?l000001?ooool2o`0000?ooooo0_l0000Dooooo`;o00002Ooo
ool2o`0001Kooooo1?l00004ooooo`;o000000?oooooo`000?l000001oooool2o`0000;ooooo0_l0
000Booooo`Go00002oooool2o`0000Wooooo0_l0000@ooooo`;o00001_ooool4o`0000Cooooo0_l0
000;ooooo`00:Oooool01?l0003oooooo`000?l00003ooooo`;o0000;?ooool3o`0000Wooooo0_l0
000Hooooo`;o00003Oooool3o`0000;ooooo0_l00008ooooo`;o00000_ooool2o`0000?ooooo0_l0
0007ooooo`;o00006Oooool2o`0000[ooooo0_l00005ooooo`;o00005_ooool4o`0000Oooooo0_l0
000Gooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo0_l000001?oooooo0000o`00
0?l00009ooooo`;o00006?ooool2o`0000Kooooo0_l0000;ooooo`00:Oooool00ol0003ooooooooo
o`04ooooo`;o00004_ooool2o`0000Sooooo0_l0000>ooooo`;o00000_ooool2o`0000cooooo0_l0
000Booooo`;o00003Oooool2o`0000gooooo0ol000000ooooooo0000o`000009ooooo`;o00004ooo
ool2o`000004ooooool0003o0000ooooo`;o00003Oooool2o`0000Gooooo0_l00009ooooo`;o0000
3Oooool2o`0000Oooooo0_l0000@ooooo`;o00002_ooool2o`000003ooooool0003o000000;ooooo
0_l000000ooooooo0000o`00000Sooooo`;o00005?ooool002Wooooo00?o0000ooooooooool06?oo
ool2o`0000Sooooo0_l00004ooooo`;o00003?ooool2o`0000?ooooo0_l00007ooooo`;o00003?oo
ool2o`0001Gooooo0_l00004ooooo`;o00001_ooool2o`0000cooooo0_l0000<ooooo`;o00001Ooo
ool2o`000004ooooool0003o0000ooooo`;o00006Oooool2o`0000Cooooo0_l0000Eooooo`;o0000
0_ooool3o`0000cooooo0_l00002ooooo`;o0000=Oooool2o`0001Cooooo000Yooooo`;o00003Ooo
ool2o`0000cooooo0_l0000<ooooo`;o00004?ooool3o`0001Gooooo0_l00005ooooo`;o00001?oo
ool2o`0000Sooooo0_l00004ooooo`;o00008_ooool2o`000003ooooool0003o000001Cooooo0_l0
000=ooooo`;o00004Oooool2o`0000Sooooo0_l00002ooooo`?o00004?ooool2o`0004_ooooo000Y
ooooo`03o`000?oooooooooo00cooooo0_l0000<ooooo`;o00007_ooool2o`0001gooooo0_l00004
ooooo`;o0000=Oooool2o`0001Cooooo0_l0000Pooooo`;o0000K?ooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgM
g@05ooooo`03o`000?oooooooooo03_ooooo0_l0000Aooooo`;o00009Oooool3o`00097ooooo0_l0
000?ooooo`;o00008?ooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`0kooooo`;o00004Oooool2o`0000Wooooo0_l0000Jooooo`?o0000I?ooool2o`0002_ooooo
0_l0000?ooooo`;o00008?ooool000Kooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRH
V?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Iooooo`;o0000
??ooool2o`0002Gooooo0_l0000Looooo`;o0000G_ooool000Kooooo00Go0000oooooooooooooooo
o`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0001Gooooo
0_l0000=ooooo`;o0000LOooool2o`0002Gooooo0_l0000jooooo`;o0000@?ooool000Kooooo00Go
0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo01Gooooo0_l0000=ooooo`;o0000B?ooool2o`00053o
oooo0_l0000hooooo`;o0000@?ooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1^ooooo`;o
0000D?ooool2o`0007[ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o
^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2boooo
o`;o0000R?ooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool0/_ooool2o`0000Gooooo0_l00015
ooooo`;o0000>_ooool002Wooooo0_l0001Dooooo`;o0000=Oooool2o`0002gooooo0_l00015oooo
o`;o0000>_ooool002Wooooo00?o0000ooooooooool0Doooool2o`0001gooooo0_l0000Fooooo`;o
0000:Oooool2o`0002Sooooo0_l0001Kooooo`00:Oooool00ol0003oooooooooo`05ooooo`;o0000
Joooool2o`0001Kooooo0_l0000Yooooo`;o0000:?ooool2o`0000Kooooo0_l0000Looooo`;o0000
0_ooool2o`0001Gooooo0_l0000Jooooo`00:Oooool00ol0003oooooooooo`05ooooo`;o00001Ooo
ool2o`0003Wooooo0_l0002Nooooo`;o00007?ooool2o`0000;ooooo0_l0000Eooooo`;o00006_oo
ool002Wooooo00?o0000ooooooooool03?ooool2o`0003Wooooo0_l00015ooooo`;o0000[?ooool0
02Wooooo0_l0000eooooo`;o0000F?ooool2o`0005_ooooo0_l0001?ooooo`00:Oooool00ol0003o
ooooooooo`0dooooo`;o0000]Oooool2o`0004oooooo000Yooooo`03o`000?oooooooooo02;ooooo
0_l0003ooooooaWooooo000Yooooo`03o`000?oooooooooo02;ooooo0_l0002Nooooo`;o0000N?oo
ool002Wooooo00?o0000ooooooooool0M?ooool2o`0001_ooooo0_l0000_ooooo`;o0000N?ooool0
02Wooooo0_l0001eooooo`;o00006oooool2o`0004Sooooo0_l0000Dooooo`;o0000BOooool002Wo
oooo00?o0000ooooooooool0]?ooool2o`0002Gooooo0_l0000Dooooo`;o0000BOooool002Wooooo
00?o0000ooooooooool0]?ooool2o`0008Kooooo000Yooooo`03o`000?oooooooooo0<?ooooo0_l0
001gooooo`00:Oooool00ol0003oooooooooo`33ooooo`;o00004?ooool2o`00047ooooo0_l0000R
ooooo`00:Oooool2o`0005Cooooo0_l00020ooooo`;o0000@Oooool2o`0002;ooooo000Yooooo`03
o`000?oooooooooo05?ooooo0_l0003Wooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`1;oooo
o`;o0000koooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo03Oooooo0_l0000Booooo`;o00007?ooool2o`00
00Cooooo0_l0000oooooo`;o0000Doooool2o`0003Gooooo000>ooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol0003oooooooooo`03ooooo`?o0000=oooool2o`00033ooooo0_l00004oooo
o`;o0000?oooool2o`0005?ooooo0_l0000eooooo`003_ooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0eooooo`;o0000@?ooool2o`00
09Kooooo0_l0000[ooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo03Gooooo0_l00010ooooo`;o000000?ooooo
o`000?l00000Toooool2o`0002_ooooo000>ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo07[ooooo0_l00030ooooo`003_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2<
ooooo`;o0000[_ooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2
o`0008gooooo0_l00011ooooo`;o00008_ooool2o`0001Kooooo0_l0000_ooooo`00:Oooool00ol0
003oooooooooo`0Mooooo`;o00003?ooool2o`0000cooooo0_l0002Dooooo`;o00008_ooool2o`00
01Kooooo0_l0000_ooooo`00:Oooool00ol0003oooooooooo`0Mooooo`;o00003?ooool2o`0000co
oooo0_l0003oooooo`;ooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0@oooool2o`000<;ooooo0_l0000cooooo`00:Oooool2o`0004Cooooo0_l0002S
ooooo`;o00007Oooool2o`00027ooooo0_l0000@ooooo`00:Oooool00ol0003oooooooooo`1Goooo
o`;o0000GOooool2o`00033ooooo0_l00010ooooo`;o00004?ooool002Wooooo00?o0000oooooooo
ool0Eoooool2o`0005gooooo0_l00024ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEE
EOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolmooooo`001_ooool01Ol0003o
oooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00000>oooo
o`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOo
oooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool001oooooo1?l000000ol@413oooooooooo`03ooooo`03
o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo0ol0003oooooocgooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool001oooooo00?oEEEEofIVI_l00000oooooom7ooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .35644 Mdot
.02762 .357 Mdot
.02952 .28674 Mdot
.03143 .26326 Mdot
.03333 .32238 Mdot
.03524 .376 Mdot
.03714 .29716 Mdot
.03905 .22573 Mdot
.04095 .25264 Mdot
.04286 .25834 Mdot
.04476 .27508 Mdot
.04667 .25244 Mdot
.04857 .35212 Mdot
.05048 .25444 Mdot
.05238 .32153 Mdot
.05429 .25898 Mdot
.05619 .37616 Mdot
.0581 .35236 Mdot
.06 .29084 Mdot
.0619 .30492 Mdot
.06381 .3089 Mdot
.06571 .3239 Mdot
.06762 .28133 Mdot
.06952 .33903 Mdot
.07143 .3277 Mdot
.07333 .3454 Mdot
.07524 .30658 Mdot
.07714 .31039 Mdot
.07905 .28098 Mdot
.08095 .33475 Mdot
.08286 .26158 Mdot
.08476 .2352 Mdot
.08667 .23972 Mdot
.08857 .36674 Mdot
.09048 .3805 Mdot
.09238 .24226 Mdot
.09429 .23013 Mdot
.09619 .31317 Mdot
.0981 .23558 Mdot
.1 .23685 Mdot
.1019 .28433 Mdot
.10381 .37675 Mdot
.10571 .37316 Mdot
.10762 .37851 Mdot
.10952 .37826 Mdot
.11143 .33134 Mdot
.11333 .27601 Mdot
.11524 .2284 Mdot
.11714 .36491 Mdot
.11905 .2465 Mdot
.12095 .22875 Mdot
.12286 .24694 Mdot
.12476 .44507 Mdot
.12667 .36889 Mdot
.12857 .3834 Mdot
.13048 .25071 Mdot
.13238 .22912 Mdot
.13429 .37905 Mdot
.13619 .22935 Mdot
.1381 .37951 Mdot
.14 .34258 Mdot
.1419 .34131 Mdot
.14381 .23187 Mdot
.14571 .3149 Mdot
.14762 .29134 Mdot
.14952 .23498 Mdot
.15143 .26269 Mdot
.15333 .25865 Mdot
.15524 .29342 Mdot
.15714 .32066 Mdot
.15905 .37995 Mdot
.16095 .30134 Mdot
.16286 .2708 Mdot
.16476 .25737 Mdot
.16667 .23187 Mdot
.16857 .27367 Mdot
.17048 .44539 Mdot
.17238 .36288 Mdot
.17429 .25454 Mdot
.17619 .37058 Mdot
.1781 .25105 Mdot
.18 .32628 Mdot
.1819 .26099 Mdot
.18381 .37971 Mdot
.18571 .22643 Mdot
.18762 .276 Mdot
.18952 .32295 Mdot
.19143 .34969 Mdot
.19333 .37863 Mdot
.19524 .26028 Mdot
.19714 .33881 Mdot
.19905 .41665 Mdot
.20095 .31262 Mdot
.20286 .33372 Mdot
.20476 .30724 Mdot
.20667 .39882 Mdot
.20857 .25463 Mdot
.21048 .24248 Mdot
.21238 .44574 Mdot
.21429 .37634 Mdot
.21619 .34761 Mdot
.2181 .37458 Mdot
.22 .27418 Mdot
.2219 .3708 Mdot
.22381 .29157 Mdot
.22571 .36704 Mdot
.22762 .38207 Mdot
.22952 .29157 Mdot
.23143 .31335 Mdot
.23333 .30721 Mdot
.23524 .25468 Mdot
.23714 .27493 Mdot
.23905 .23822 Mdot
.24095 .28611 Mdot
.24286 .47171 Mdot
.24476 .32737 Mdot
.24667 .35263 Mdot
.24857 .22692 Mdot
.25048 .22726 Mdot
.25238 .2386 Mdot
.25429 .34417 Mdot
.25619 .31697 Mdot
.2581 .26796 Mdot
.26 .29117 Mdot
.2619 .31432 Mdot
.26381 .25905 Mdot
.26571 .26973 Mdot
.26762 .39076 Mdot
.26952 .31121 Mdot
.27143 .32235 Mdot
.27333 .30849 Mdot
.27524 .33649 Mdot
.27714 .27099 Mdot
.27905 .38431 Mdot
.28095 .37338 Mdot
.28286 .2786 Mdot
.28476 .25106 Mdot
.28667 .27 Mdot
.28857 .27324 Mdot
.29048 .2599 Mdot
.29238 .3103 Mdot
.29429 .38889 Mdot
.29619 .29717 Mdot
.2981 .28658 Mdot
.3 .37702 Mdot
.3019 .30058 Mdot
.30381 .2264 Mdot
.30571 .47992 Mdot
.30762 .33805 Mdot
.30952 .34929 Mdot
.31143 .27139 Mdot
.31333 .37183 Mdot
.31524 .27325 Mdot
.31714 .34655 Mdot
.31905 .29675 Mdot
.32095 .35246 Mdot
.32286 .23844 Mdot
.32476 .23441 Mdot
.32667 .22865 Mdot
.32857 .23087 Mdot
.33048 .24109 Mdot
.33238 .35426 Mdot
.33429 .26673 Mdot
.33619 .23426 Mdot
.3381 .24035 Mdot
.34 .35577 Mdot
.3419 .32989 Mdot
.34381 .22695 Mdot
.34571 .29622 Mdot
.34762 .29471 Mdot
.34952 .26021 Mdot
.35143 .23719 Mdot
.35333 .27269 Mdot
.35524 .30558 Mdot
.35714 .33997 Mdot
.35905 .33068 Mdot
.36095 .26194 Mdot
.36286 .39818 Mdot
.36476 .34991 Mdot
.36667 .32603 Mdot
.36857 .25703 Mdot
.37048 .26935 Mdot
.37238 .24795 Mdot
.37429 .25787 Mdot
.37619 .28544 Mdot
.3781 .31952 Mdot
.38 .26658 Mdot
.3819 .39864 Mdot
.38381 .22756 Mdot
.38571 .23708 Mdot
.38762 .37812 Mdot
.38952 .30987 Mdot
.39143 .30511 Mdot
.39333 .31156 Mdot
.39524 .35442 Mdot
.39714 .22673 Mdot
.39905 .26837 Mdot
.40095 .27049 Mdot
.40286 .33592 Mdot
.40476 .40901 Mdot
.40667 .38396 Mdot
.40857 .32577 Mdot
.41048 .32587 Mdot
.41238 .3041 Mdot
.41429 .33715 Mdot
.41619 .41609 Mdot
.4181 .33016 Mdot
.42 .3077 Mdot
.4219 .37082 Mdot
.42381 .29438 Mdot
.42571 .32889 Mdot
.42762 .26632 Mdot
.42952 .35697 Mdot
.43143 .3611 Mdot
.43333 .29366 Mdot
.43524 .25691 Mdot
.43714 .32574 Mdot
.43905 .36137 Mdot
.44095 .23929 Mdot
.44286 .32914 Mdot
.44476 .35958 Mdot
.44667 .23023 Mdot
.44857 .34984 Mdot
.45048 .23534 Mdot
.45238 .30581 Mdot
.45429 .24196 Mdot
.45619 .26276 Mdot
.4581 .32121 Mdot
.46 .37414 Mdot
.4619 .28574 Mdot
.46381 .31966 Mdot
.46571 .30414 Mdot
.46762 .26409 Mdot
.46952 .27666 Mdot
.47143 .43106 Mdot
.47333 .37475 Mdot
.47524 .28662 Mdot
.47714 .32274 Mdot
.47905 .30635 Mdot
.48095 .37096 Mdot
.48286 .29977 Mdot
.48476 .34126 Mdot
.48667 .34935 Mdot
.48857 .38267 Mdot
.49048 .30156 Mdot
.49238 .37993 Mdot
.49429 .22823 Mdot
.49619 .29577 Mdot
.4981 .23077 Mdot
.5 .37191 Mdot
.5019 .37947 Mdot
.50381 .23302 Mdot
.50571 .27578 Mdot
.50762 .32755 Mdot
.50952 .29702 Mdot
.51143 .23248 Mdot
.51333 .35866 Mdot
.51524 .30778 Mdot
.51714 .38952 Mdot
.51905 .27324 Mdot
.52095 .23697 Mdot
.52286 .22908 Mdot
.52476 .37078 Mdot
.52667 .28553 Mdot
.52857 .2428 Mdot
.53048 .32659 Mdot
.53238 .3747 Mdot
.53429 .34816 Mdot
.53619 .28942 Mdot
.5381 .35411 Mdot
.54 .23743 Mdot
.5419 .36676 Mdot
.54381 .25903 Mdot
.54571 .38556 Mdot
.54762 .25505 Mdot
.54952 .37254 Mdot
.55143 .24398 Mdot
.55333 .26055 Mdot
.55524 .29359 Mdot
.55714 .23 Mdot
.55905 .25752 Mdot
.56095 .36358 Mdot
.56286 .25997 Mdot
.56476 .33112 Mdot
.56667 .26361 Mdot
.56857 .23267 Mdot
.57048 .26251 Mdot
.57238 .28876 Mdot
.57429 .29587 Mdot
.57619 .34781 Mdot
.5781 .30781 Mdot
.58 .34616 Mdot
.5819 .24923 Mdot
.58381 .40285 Mdot
.58571 .23029 Mdot
.58762 .30435 Mdot
.58952 .23916 Mdot
.59143 .27744 Mdot
.59333 .23531 Mdot
.59524 .36707 Mdot
.59714 .31725 Mdot
.59905 .3179 Mdot
.60095 .48368 Mdot
.60286 .37009 Mdot
.60476 .39004 Mdot
.60667 .3444 Mdot
.60857 .23039 Mdot
.61048 .30383 Mdot
.61238 .27163 Mdot
.61429 .23363 Mdot
.61619 .35856 Mdot
.6181 .32538 Mdot
.62 .34421 Mdot
.6219 .37732 Mdot
.62381 .33472 Mdot
.62571 .27283 Mdot
.62762 .32871 Mdot
.62952 .35468 Mdot
.63143 .37062 Mdot
.63333 .29479 Mdot
.63524 .32948 Mdot
.63714 .25557 Mdot
.63905 .35067 Mdot
.64095 .37115 Mdot
.64286 .25884 Mdot
.64476 .38889 Mdot
.64667 .38246 Mdot
.64857 .23166 Mdot
.65048 .30653 Mdot
.65238 .32464 Mdot
.65429 .28742 Mdot
.65619 .38138 Mdot
.6581 .22764 Mdot
.66 .23766 Mdot
.6619 .31363 Mdot
.66381 .34605 Mdot
.66571 .32544 Mdot
.66762 .30636 Mdot
.66952 .3718 Mdot
.67143 .37987 Mdot
.67333 .35648 Mdot
.67524 .35579 Mdot
.67714 .33842 Mdot
.67905 .43349 Mdot
.68095 .36459 Mdot
.68286 .31293 Mdot
.68476 .30514 Mdot
.68667 .24994 Mdot
.68857 .30743 Mdot
.69048 .26642 Mdot
.69238 .30128 Mdot
.69429 .31111 Mdot
.69619 .36035 Mdot
.6981 .3846 Mdot
.7 .24288 Mdot
.7019 .24473 Mdot
.70381 .24509 Mdot
.70571 .3657 Mdot
.70762 .38279 Mdot
.70952 .24194 Mdot
.71143 .37479 Mdot
.71333 .24545 Mdot
.71524 .35289 Mdot
.71714 .30106 Mdot
.71905 .27534 Mdot
.72095 .25872 Mdot
.72286 .25852 Mdot
.72476 .31139 Mdot
.72667 .37377 Mdot
.72857 .31711 Mdot
.73048 .2318 Mdot
.73238 .31213 Mdot
.73429 .26014 Mdot
.73619 .36807 Mdot
.7381 .37832 Mdot
.74 .34929 Mdot
.7419 .24614 Mdot
.74381 .36887 Mdot
.74571 .23019 Mdot
.74762 .23674 Mdot
.74952 .2795 Mdot
.75143 .25285 Mdot
.75333 .30152 Mdot
.75524 .31976 Mdot
.75714 .47273 Mdot
.75905 .244 Mdot
.76095 .36333 Mdot
.76286 .30738 Mdot
.76476 .33284 Mdot
.76667 .37716 Mdot
.76857 .2864 Mdot
.77048 .2412 Mdot
.77238 .31914 Mdot
.77429 .32234 Mdot
.77619 .2593 Mdot
.7781 .35038 Mdot
.78 .29182 Mdot
.7819 .2286 Mdot
.78381 .33175 Mdot
.78571 .36238 Mdot
.78762 .24852 Mdot
.78952 .37626 Mdot
.79143 .44072 Mdot
.79333 .37995 Mdot
.79524 .3259 Mdot
.79714 .31652 Mdot
.79905 .27149 Mdot
.80095 .23074 Mdot
.80286 .25355 Mdot
.80476 .3046 Mdot
.80667 .29402 Mdot
.80857 .25552 Mdot
.81048 .2683 Mdot
.81238 .27867 Mdot
.81429 .32316 Mdot
.81619 .24908 Mdot
.8181 .2788 Mdot
.82 .27949 Mdot
.8219 .32773 Mdot
.82381 .32523 Mdot
.82571 .36698 Mdot
.82762 .27208 Mdot
.82952 .30689 Mdot
.83143 .29564 Mdot
.83333 .25565 Mdot
.83524 .29685 Mdot
.83714 .38102 Mdot
.83905 .38206 Mdot
.84095 .33419 Mdot
.84286 .36884 Mdot
.84476 .29699 Mdot
.84667 .31965 Mdot
.84857 .39113 Mdot
.85048 .35942 Mdot
.85238 .46507 Mdot
.85429 .38191 Mdot
.85619 .31499 Mdot
.8581 .27804 Mdot
.86 .32318 Mdot
.8619 .28776 Mdot
.86381 .28895 Mdot
.86571 .43737 Mdot
.86762 .28852 Mdot
.86952 .32127 Mdot
.87143 .33729 Mdot
.87333 .2497 Mdot
.87524 .37079 Mdot
.87714 .4126 Mdot
.87905 .32244 Mdot
.88095 .36728 Mdot
.88286 .38125 Mdot
.88476 .31841 Mdot
.88667 .32735 Mdot
.88857 .2569 Mdot
.89048 .22629 Mdot
.89238 .3291 Mdot
.89429 .26465 Mdot
.89619 .36138 Mdot
.8981 .36687 Mdot
.9 .26658 Mdot
.9019 .24898 Mdot
.90381 .37801 Mdot
.90571 .37143 Mdot
.90762 .25882 Mdot
.90952 .22748 Mdot
.91143 .26699 Mdot
.91333 .29705 Mdot
.91524 .23915 Mdot
.91714 .36839 Mdot
.91905 .37067 Mdot
.92095 .27075 Mdot
.92286 .35302 Mdot
.92476 .30016 Mdot
.92667 .35978 Mdot
.92857 .37149 Mdot
.93048 .31185 Mdot
.93238 .36227 Mdot
.93429 .27705 Mdot
.93619 .3652 Mdot
.9381 .37162 Mdot
.94 .30362 Mdot
.9419 .25887 Mdot
.94381 .37156 Mdot
.94571 .38056 Mdot
.94762 .32749 Mdot
.94952 .36027 Mdot
.95143 .23576 Mdot
.95333 .31265 Mdot
.95524 .34734 Mdot
.95714 .26902 Mdot
.95905 .329 Mdot
.96095 .31579 Mdot
.96286 .46577 Mdot
.96476 .31928 Mdot
.96667 .36469 Mdot
.96857 .25088 Mdot
.97048 .24363 Mdot
.97238 .29492 Mdot
.97429 .26468 Mdot
.97619 .24946 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool01?l0003ooooooooo
ooooool2o`0002gooooo0_l0000Cooooo`;o00003oooool2o`0000_ooooo0_l0000;ooooo`;o0000
0_ooool2o`0005;ooooo0_l00019ooooo`;o00001?ooool2o`00027ooooo0004o`0000;ooooo00Go
410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool0
0oooool01?l0003oooooooooooooool2o`00013ooooo0_l00005ooooo`Co000000Coooooo`000?l0
003o00003_ooool2o`0001?ooooo0_l0000?ooooo`;o00001_ooool2o`0000?ooooo0_l0000;oooo
o`;o00000_ooool2o`0000kooooo0_l0000>ooooo`?o00001_ooool2o`0000Wooooo0_l00007oooo
o`;o00001Oooool2o`0000kooooo0_l0000Jooooo`;o00002_ooool2o`0000Cooooo0_l0000Koooo
o`;o00001?ooool2o`00027ooooo0006ooooo`05o`000?ooooooooooooooool000003Oooool00onH
V9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Cooooo`;o00001Oooool4o`00
0005ooooool0003o0000o`000?ooool00_l00005ooooo`;o0000<_ooool2o`0002Cooooo0_l0000>
ooooo`Oo00000_ooool2o`0000Wooooo0_l000000ooooooo0000o`000004ooooo`;o00001Oooool4
o`0000Wooooo0_l0000Hooooo`;o00000oooool2o`0000[ooooo0_l00004ooooo`;o0000A?ooool0
00Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo013ooooo0_l00002ooooo`?o00003?oo
ool4o`0000?ooooo0_l0000aooooo`;o00000_ooool2o`0000?ooooo0_l00009ooooo`;o00004_oo
ool2o`00013ooooo1?l000000ooooooo0000o`00000=ooooo`;o00001_ooool2o`0000Gooooo0_l0
0009ooooo`;o00006?ooool2o`0000Cooooo0_l00010ooooo`;o00004oooool000Kooooo00Go410@
oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0@ooooo`;o00000_ooool3o`0000kooooo0_l0000Jooooo`;o00000ooo
ool2o`0001Cooooo0ol00002ooooo`;o00000oooool2o`0000Wooooo0_l0000?ooooo`;o000000?o
ooooo`000?l000005Oooool2o`0000Cooooo0_l0000>ooooo`?o00005?ooool2o`0001[ooooo0_l0
000dooooo`;o00002_ooool2o`0001?ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0@ooooo`Co00009?ooool2o`0000Oooooo0_l00003ooooo`;o00005?ooool2o`000003oooo
ool0003o000000;o00007oooool2o`0000?ooooo0_l0000Fooooo`;o000000?oooooo`000?l00000
3_ooool2o`0001Gooooo0_l0000;ooooo`;o000000?oooooo`000?l000004Oooool2o`0002gooooo
0_l0000Oooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`0Booooo`;o00001oooool2o`0001_o
oooo0_l0000Uooooo`;o00009_ooool2o`0001Kooooo0_l00005ooooo`;o0000;_ooool6o`0000Oo
oooo0_l00004ooooo`;o000000?oooooo`000?l00000?oooool2o`0000gooooo000Yooooo`;o0000
7?ooool3o`0004kooooo0_l0000hooooo`;o00002?ooool2o`0002Cooooo0ol000000ooooooo0000
o`000007ooooo`;o00001?ooool2o`0000Oooooo0_l00007ooooo`;o00004?ooool2o`0000Sooooo
0_l0000Dooooo`Co00002oooool002Wooooo00?o0000ooooooooool00_ooool4o`0001Kooooo0_l0
00000ooooooo0000o`00000=ooooo`;o00008?ooool2o`0001[ooooo0_l00012ooooo`;o00007ooo
ool2o`0001oooooo0_l00007ooooo`;o00004?ooool2o`0000Sooooo0_l0000Cooooo`;o000000?o
ooooo`000?l000002oooool002Wooooo00?o0000ooooooooool00_ooool5o`0001Sooooo0_l0000<
ooooo`?o00002?ooool2o`0000Kooooo0_l0000>ooooo`;o0000Doooool2o`0001[ooooo0_l0000>
ooooo`;o00004oooool2o`0000oooooo1?l00006ooooo`;o0000:Oooool2o`0000kooooo000Yoooo
o`03o`000?oooooooooo00;ooooo0_l000001?oooooo0000o`000?l0000Nooooo`;o00000_ooool2
o`000003ooooool0003o000000Wooooo0_l00006ooooo`;o00001oooool2o`00023ooooo1?l0000B
ooooo`;o00008?ooool4o`000003ooooool0003o000001Oooooo1?l0000Gooooo`?o00001oooool2
o`0000oooooo1?l00006ooooo`;o00003oooool2o`0000Cooooo0_l00009ooooo`;o00005oooool0
02Wooooo00?o0000ooooooooool00_ooool2o`0000;ooooo0_l00007ooooo`;o00005Oooool2o`00
00;ooooo0_l00003ooooo`;o00000_ooool2o`0001Cooooo0_l00007ooooo`;o00004Oooool2o`00
00;ooooo1_l0000Booooo`;o00008?ooool2o`0000;ooooo1Ol0000Gooooo`;o00005oooool3o`00
00;ooooo0_l0000;ooooo`;o00008_ooool2o`0000Cooooo0_l00009ooooo`;o00005oooool002Wo
oooo1?l0000>ooooo`;o00005?ooool2o`0000Sooooo0_l00002ooooo`;o00007Oooool2o`00017o
oooo0_l00002ooooo`;o00007?ooool2o`0000;ooooo0_l0000Jooooo`;o000000?oooooo`000?l0
00000_l0000cooooo`;o00002oooool2o`0002Cooooo0_l0000Hooooo`;o00003?ooool002Wooooo
00Co0000ooooool0003o00009?ooool2o`00027ooooo0_l0000Fooooo`;o00003Oooool2o`0000Co
oooo0_l00007ooooo`;o00001oooool2o`0000;ooooo0_l0000Nooooo`?o00009Oooool2o`0002Co
oooo0_l0000Iooooo`Co00000_ooool2o`0001;ooooo0_l0000<ooooo`00:Oooool00ol0003ooooo
ooooo`0Yooooo`;o00001Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool4o`0000;ooooo0_l000000ooooooo0000o`00
0006ooooo`;o00001Oooool2o`0000[ooooo1_l00003ooooo`?o000000?o<S8bonk^k_ooool00_oo
ool01Oo^k^ko0000o`000?lb<S;ok^k^02Sooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Cooooo0_l0000D
ooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h00_ooool2o`000004
oc8b<_l0003o0000onk^kQ[ooooo0_l00002ooooo`;o000000?oooooo`000?l000001_ooool00om4
A4Co0000o`000002o`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool002Wooooo00?o0000ooooooooool0:Oooool4o`0000Gooooo00?o0000
ooooooooool00_ooool01?mgMgOoV9RHoooooonHV9P2o`0000;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`06ooooo`;o00000_ooool2o`000003ooooool0003o000000Kooooo0ol0000:ooooo`;o0000
1?ooool2o`000004ob4Q8Oo^k^koooooodA4A0?ooooo00GoMgMgo`000?l0003oV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool2o`0000cooooo00Go410@okZj^_ooooooMgMgoc8b
<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool2o`000004oooooonHV9So0000o`0002[o
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo0_l000001?nH
V9SooooooiRHV?mgMgL3ooooo`;o00007?ooool2o`0000Wooooo0_l00002ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000Yooooo`03o`000?oo
oooooooo00?ooooo0_l0000Dooooo`;o00004?ooool2o`0000Cooooo0_l00004ooooo`04oa0@4?oo
ooooooooooooo`;o00000_ooool01Ol@413oooooo`000?l0003o410@00gooooo0_l00007ooooo`;o
00002_ooool2o`0000Kooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@400:ooooo`;o00002Oooool2o`0000?ooooo0_l0000@
ooooo`05o`000?ooooooooooooooool@41000_l000000ooooooo410@ooooo`02ooooo`;o00000_oo
ool2o`0001cooooo0_l00009ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooooooooa0@4003ooooo`;o00008?ooool2o`0000Kooooo00Co0000oooooooo
oooo410@0oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool00Oooool0
02Wooooo0_l00004ooooo`;o00005?ooool2o`0001Kooooo0_l00004ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooo`000002o`0000cooooo0_l0000Mooooo`03oiRHV?lQ8B7o
k^k^00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
2_ooool2o`0000Wooooo0_l0000Dooooo`03ojVYZOl@413ooooo00;ooooo0ol000000ooooooo0000
ooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool2o`0000Sooooo0_l000000ooMgMgo
ooooo`000004ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`04o`00
00_ooooo0_l0000Fooooo`;o00001Oooool01OmgMgOo<S8boooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo007ooooo000Yooooo`03o`000?oooooo
oooo00[ooooo0_l00002ooooo`;o00008_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000cooooo0_l0000Nooooo`03ogMg
MomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool00000:_ooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000002Oooooo0_l000000omEEEGoooooo`000004ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`04o`0000_ooooo0_l0000Jooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`00:Oooool3o`0000[ooooo0_l00002ooooo`;o00001Oooool2o`00
01_ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@
ooooooooool00_l0000@ooooo`;o00006?ooool2o`000003ooooool0003ooooo00;ooooo00Go410@
oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001oooool2o`0000;ooooo
0_l0000?ooooo`;o00003Oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@02Wooooo00CoMgMgolc<c?l0003ooooo0_l00000
0ooooooo410@ooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413ooooooooo
o`0Wooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@
4?ooooooooooooooool@41000oooool002Wooooo0ol0000Eooooo`;o00006oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool00omgMgOoV9RHooooo`02o`00013o
oooo0_l0000Gooooo`?o000000?oV9RHoa0@4?ooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`;o00000_ooool2o`0000oooooo0_l00000
0ooooooo0000o`000007ooooo`03oa0@4?nHV9Sooooo00;o00000oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`;o00007oooool01?o^k^koA4A4
o`000?ooool2o`000006oooooomgMgOoV9RHoooooonHV9SoMgMg0oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00kooooo1?l0000Gooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wooooo00?o0000ooooooooool0
2?ooool2o`0001[ooooo0_l0000:ooooo`03oeEEEOmVIVKo000000Cooooo00Kok^k^oc8b<_l0003o
<S8bonk^k_ooool3o`000004oc8b<_l0003o<S8bonk^kPCooooo0_l0000Sooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0Oooooo`;o00001oooool00onYZJWo410@o`000002o`0000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool2o`00023ooooo00?oMgMg
o`000?ooool00oooool3o`000003oc8b<_o^k^kooooo00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0>ooooo`Co00005oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool002Wooooo0_l00009ooooo`;o00006_ooool2o`000003oooo
ool0003o000001Cooooo0ol00008ooooo`;o00006_ooool2o`0001Oooooo0_l000000ooooooo0000
o`00000Booooo`;o00004Oooool2o`0000Cooooo0_l0000Aooooo`;o0000;Oooool2o`0000Oooooo
0_l00006ooooo`;o0000:oooool2o`0000gooooo000Yooooo`04o`000?ooooooooooooooo`;o0000
9?ooool2o`0002_ooooo0_l00005ooooo`;o00001oooool2o`0001Oooooo0_l000000ooooooo0000
o`00000Booooo`;o00000_ooool2o`0000gooooo0_l00004ooooo`;o00004Oooool2o`0003Kooooo
0_l00006ooooo`?o000000?oooooo`000?l000005?ooool2o`00017ooooo0_l0000=ooooo`00:Ooo
ool01?l0003oooooooooooooool2o`0002Gooooo0_l0000Zooooo`Co00000oooool2o`0003?ooooo
1?l00004ooooo`;o0000>Oooool2o`0000Kooooo0_l0000:ooooo`;o00006?ooool2o`000003oooo
ool0003o000001Cooooo0_l00002ooooo`;o00007?ooool002Wooooo00?o0000ooooooooool02Ooo
ool2o`0001gooooo0_l0000/ooooo`;o00003oooool2o`0000Wooooo0_l00005ooooo`;o00003ooo
ool2o`0000Cooooo1?l0000Nooooo`;o00001Oooool2o`0001Kooooo1?l00006ooooo`;o00002_oo
ool2o`0000kooooo0_l0000Uooooo`;o00000oooool2o`0001Oooooo000Yooooo`03o`000?oooooo
oooo00Wooooo0_l00002ooooo`;o00009oooool2o`0000Sooooo0_l0000;ooooo`;o00006?ooool2
o`0000Wooooo0_l00005ooooo`;o000000?oooooo`000?l000002?ooool2o`0000;ooooo0_l00003
ooooo`;o00002Oooool2o`0001;ooooo0_l00002ooooo`;o00001Oooool2o`0000_ooooo0_l00003
ooooo`;o00001?ooool3o`0001Kooooo0_l0000;ooooo`;o00001_ooool2o`0002;ooooo0_l0000G
ooooo`008Oooooooo`0004Co00001?ooool002Wooooo00?o0000ooooooooool02Oooool2o`0000;o
oooo0_l00005ooooo`?o00002oooool3o`0000Wooooo00?o0000ooooooooool01?ooool2o`0000?o
oooo00?o0000ooooooooool00_ooool2o`0000Kooooo00?o0000ooooool000000ol00006ooooo`;o
00002_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo0ol00003ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Gooooo0_l00002ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000Co
oooo00Co0000oooooooooooooooo1?l00004ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`07ooooo`;o000000?oooooo`000?ooool02_ooool00ol0
003oooooooooo`06ooooo`;o000000?oooooo`000?ooool00_ooool2o`0000Kooooo00?o0000oooo
ooooool02_ooool002Wooooo00?o0000ooooooooool05?ooool2o`0000gooooo0_l0000@ooooo`;o
00000oooool00ol0003oooooooooo`02ooooo`;o00001_ooool4o`0002gooooo00?o0000oooooooo
ool0>_ooool2o`0001;ooooo0_l00005ooooo`;o00003Oooool3o`00013ooooo00?o0000oooooooo
ool00_l0000Aooooo`;o00007Oooool2o`000003ooooool0003o000000?ooooo00?o0000oooooooo
ool02_ooool002Wooooo00?o0000ooooooooool09oooool2o`0001kooooo0_l0000Uooooo`;o0000
6?ooool4o`0002Wooooo0_l0000Xooooo`;o00001_ooool2o`0000Cooooo0_l00006ooooo`;o0000
3_ooool2o`0000[ooooo0_l0000Gooooo`?o00003oooool002Wooooo00Co0000ooooool0003o0000
1?ooool2o`0000?ooooo0_l0000Kooooo`;o00002Oooool2o`0001Sooooo0_l0000Pooooo`;o0000
6?ooool4o`0000;ooooo0_l0001Gooooo`;o00001?ooool3o`0000[ooooo0_l00009ooooo`;o0000
0_ooool2o`000004ooooool0003o0000ooooo`Co00006?ooool2o`0000oooooo000Yooooo`Co0000
1?ooool2o`0000?ooooo0_l0000Rooooo`;o00000_ooool2o`0000oooooo0_l00007ooooo`;o0000
7Oooool2o`0000_ooooo0ol00006ooooo`;o00002oooool2o`0000oooooo0_l0000Jooooo`;o0000
2Oooool2o`0000?ooooo0_l0000Qooooo`;o00001?ooool2o`0000Cooooo0_l00002ooooo`;o0000
2Oooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l00000:?ooool002Wooooo
00?o0000ooooooooool03?ooool2o`00023ooooo0_l0000Cooooo`;o00007_ooool2o`0000Kooooo
0_l0000;ooooo`Oo00000_ooool4o`0001?ooooo0_l00005ooooo`;o00006_ooool2o`000004oooo
ool0003o0000ooooo`;o00000oooool2o`0000?ooooo0_l0000Wooooo`;o00001oooool3o`0001;o
oooo1?l0000?ooooo`;o00000_ooool2o`00017ooooo000Yooooo`03o`000?oooooooooo00cooooo
0_l0000:ooooo`;o0000BOooool2o`0000?ooooo0_l0000Aooooo`Co00001?ooool2o`0001?ooooo
0_l0000@ooooo`;o00004_ooool2o`000003ooooool0003o000002Sooooo0_l00004ooooo`;o0000
2_ooool2o`0001Gooooo0_l0000?ooooo`;o00000_ooool2o`00017ooooo000Yooooo`03o`000?oo
oooooooo00oooooo0_l00007ooooo`;o00007?ooool2o`0001Gooooo0_l0000Iooooo`;o00003?oo
ool2o`0003;ooooo0_l0000Aooooo`;o0000;?ooool2o`0000Cooooo0_l0000@ooooo`;o0000=ooo
ool002Wooooo00?o0000ooooooooool02oooool2o`0000;ooooo0_l0000Sooooo`Co00005Oooool2
o`0000Wooooo0_l0000Looooo`;o00000_ooool2o`00047ooooo0_l0000?ooooo`;o0000<oooool2
o`0000Sooooo0_l0000]ooooo`00:Oooool2o`0000cooooo0_l0000Eooooo`;o00004?ooool2o`00
02;ooooo0_l0000=ooooo`;o00004Oooool2o`0001Cooooo0_l0000looooo`;o0000?Oooool2o`00
02gooooo000Yooooo`03o`000?oooooooooo00cooooo0_l0000Dooooo`;o00008_ooool2o`0001oo
oooo0_l0000Wooooo`;o00009_ooool2o`0000;ooooo0_l0000<ooooo`;o0000L?ooool002Wooooo
00?o0000ooooooooool03?ooool2o`0002cooooo0_l0000:ooooo`;o00004oooool2o`0004?ooooo
0_l0000<ooooo`?o00001oooool2o`0000;ooooo0_l0000<ooooo`;o0000G?ooool2o`0001;ooooo
000Yooooo`03o`000?oooooooooo00Cooooo0_l000000ooooooo0000o`00000Yooooo`;o00001_oo
ool2o`0001cooooo0_l000000ooooooo0000o`00000=ooooo`;o00006Oooool2o`0000[ooooo0_l0
000=ooooo`;o00003?ooool3o`00017ooooo0_l0000Oooooo`;o00002_ooool2o`0003Oooooo0_l0
000Booooo`00:Oooool00ol0003oooooooooo`04ooooo`;o000000?oooooo`000?l00000:Oooool2
o`00013ooooo0_l0000Booooo`;o00000_ooool2o`000003ooooool0003o000000Wooooo0_l00008
ooooo`;o00003oooool2o`0000[ooooo0_l0000?ooooo`;o00006oooool2o`000003ooooool0003o
000001Oooooo0_l00006ooooo`;o00002_ooool2o`0002cooooo0_l0000Mooooo`00:Oooool2o`00
04Gooooo0_l0000Fooooo`;o000000Coooooo`000?l0003ooooo0_l0000@ooooo`;o00002Oooool2
o`00027ooooo0_l0000Gooooo`;o00000_ooool2o`0000cooooo0ol0000;ooooo`;o0000@?ooool2
o`0001gooooo000Yooooo`;o0000Hoooool2o`0001_ooooo0_l000000ooooooo0000o`000002o`00
01Cooooo0_l0000Oooooo`;o00004?ooool3o`0000Cooooo0_l0000`ooooo`;o00003Oooool2o`00
00Sooooo0_l00005ooooo`;o00005?ooool002Wooooo00?o0000ooooooooool0;?ooool2o`00057o
oooo0_l000000ooooooo0000o`000002o`0001Cooooo0_l0000=ooooo`;o00009Oooool2o`0000;o
oooo0_l0000Cooooo`;o00001_ooool2o`0001?ooooo0_l0000=ooooo`;o00002?ooool3o`0000Co
oooo0_l00003ooooo`;o00003oooool002Wooooo00?o0000ooooooooool04Oooool2o`0000Oooooo
0_l0000@ooooo`;o00003oooool2o`0006Cooooo0_l00004ooooo`;o00002Oooool2o`0001[ooooo
0_l00006ooooo`;o00003oooool2o`0000Kooooo0_l0000;ooooo`;o00004?ooool2o`0000?ooooo
0_l00009ooooo`Co00001oooool2o`0000oooooo000Yooooo`03o`000?oooooooooo017ooooo0_l0
0007ooooo`;o000000?oooooo`000?l000003_ooool2o`0000gooooo0ol0000mooooo`;o00004Ooo
ool2o`0000cooooo0_l00004ooooo`;o00003oooool4o`0000Sooooo0_l0000Fooooo`;o00001ooo
ool2o`000003ooooool0003o000001Sooooo0_l00004ooooo`;o00002?ooool4o`0000?ooooo0_l0
0005ooooo`;o00001?ooool2o`0001Sooooo000Yooooo`;o00006?ooool2o`0000Cooooo0_l0000>
ooooo`;o00003Oooool2o`00017ooooo0_l00008ooooo`;o00008Oooool2o`00017ooooo0_l00004
ooooo`;o00001_ooool2o`0000Kooooo0_l0000?ooooo`;o00002?ooool2o`000003ooooool0003o
000000Oooooo0_l0000@ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Nooooo`;o00002?oo
ool2o`0000Sooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo1?l0000Fooooo`00:Ooo
ool00ol0003oooooooooo`02o`0000Gooooo0_l0000=ooooo`?o00008Oooool3o`0001;ooooo0_l0
0004ooooo`;o00000_ooool2o`0002kooooo0_l00002ooooo`;o00001_ooool2o`0000Wooooo0_l0
0003ooooo`;o00007?ooool2o`0000Oooooo0_l0000;ooooo`;o00000oooool2o`0000_ooooo0_l0
0005ooooo`;o00009?ooool2o`0000Gooooo0_l000000ooooooo0000o`000002o`0001Kooooo0006
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`02o`0000Gooooo0_l0000=ooooo`Co0000
1_ooool3o`0000Gooooo0_l00006ooooo`;o000000?oooooo`000?l000001Oooool3o`0001Sooooo
0_l0000Jooooo`;o00005_ooool2o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l00000
2?ooool2o`0001_ooooo0_l0000>ooooo`;o00002_ooool2o`0000Oooooo0_l00007ooooo`;o0000
1Oooool4o`00027ooooo0_l0000Sooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo01;ooooo0_l00003ooooo`?o00001?ooool5o`0000Gooooo0_l00006ooooo`;o
000000?oooooo`000?l000002Oooool2o`00037ooooo0_l0000Oooooo`?o000000?oooooo`000?l0
00009Oooool2o`0000Kooooo0_l000000ooooooo0000o`000003ooooo`;o00002Oooool2o`0000So
oooo0_l0000@ooooo`;o00003?ooool2o`0000?ooooo0_l00007ooooo`;o00001Oooool2o`0000co
oooo0_l0000Eooooo`001_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^
k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01;ooooo0_l0000:ooooo`;o
00007_ooool2o`0000kooooo0_l0000Wooooo`;o00006Oooool2o`00013ooooo0_l0000Oooooo`;o
000000?oooooo`000?l000002oooool2o`000003ooooool0003o000002Sooooo0_l00003ooooo`;o
00001oooool2o`0001?ooooo0_l0000Eooooo`001_ooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000C_ooool2o`0000?o
oooo0_l0000Rooooo`;o00008_ooool2o`0000Oooooo0_l0000Nooooo`;o00003oooool2o`0006Go
oooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`1;ooooo`;o00001_ooool2o`00
04Kooooo0_l0000Jooooo`;o00002oooool2o`0003oooooo0_l0000eooooo`001_ooool01Ol@413o
oooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo04_ooooo0_l0001Zooooo`;o0000C?ooool2o`0003Gooooo0006ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0gooooo`;o0000<?ooool2o`0000Cooooo0_l0003;
ooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c004ooooo`Co00001_ooool00ol0003oooooooooo`0gooooo`;o0000<?ooool2o`0000Cooooo0_l0
003;ooooo`00:Oooool2o`000;7ooooo0_l0002:ooooo`00:Oooool00ol0003oooooooooo`2`oooo
o`;o0000R_ooool002Wooooo00?o0000ooooooooool0Moooool2o`000<?ooooo000Yooooo`03o`00
0?oooooooooo07Oooooo0_l0002Fooooo`;o0000:oooool002Wooooo00?o0000ooooooooool0=Ooo
ool2o`0004?ooooo0_l0002Cooooo`;o0000:oooool002Wooooo0_l0000fooooo`;o0000@oooool2
o`000<3ooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo08cooooo0_l0002^ooooo`00:Oooool2o`0008gooooo0_l00011ooooo`;o0000Joooool0
02Wooooo00?o0000ooooooooool0coooool2o`0003[ooooo0_l0000_ooooo`00:Oooool00ol0003o
ooooooooo`3cooooo`;o00005_ooool2o`0002oooooo000Yooooo`03o`000?oooooooooo01gooooo
0_l0000<ooooo`;o0000a_ooool2o`0004Oooooo000Yooooo`03o`000?oooooooooo01gooooo0_l0
000<ooooo`;o00003?ooool2o`000?oooooo0_ooool002Wooooo0_l0000jooooo`;o0000ooooool2
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo000>oooo
o`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo0?oooooo2?ooool2o`00027ooooo0_l0000@ooooo`003_ooool01Ol0003ooooooooooooooooo
000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo2?oo
ool2o`00027ooooo0_l0000@ooooo`003_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`13ooooo`;o0000Xoooool2o`0005;ooooo000>
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo04?ooooo0_l0002Sooooo`;o0000D_ooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0Eoooool2
o`000>?ooooo000Yooooo`03o`000?oooooooooo05Oooooo0_l0001Mooooo`;o0000Q?ooool002Wo
oooo00?o0000ooooooooool0]_ooool2o`0008Cooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVY
oeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolmooooo`001_ooool01Ol0
003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00000>
ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oo
oooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmg
MgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool001oooooo1?l000000ol@413oooooooooo`03oooo
o`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo0ol0003oooooocgooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool001oooooo00?oEEEEofIVI_l00000oooooom7ooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .39668 Mdot
.02762 .40163 Mdot
.02952 .3123 Mdot
.03143 .31722 Mdot
.03333 .25492 Mdot
.03524 .39176 Mdot
.03714 .26964 Mdot
.03905 .30303 Mdot
.04095 .25271 Mdot
.04286 .28631 Mdot
.04476 .26359 Mdot
.04667 .24958 Mdot
.04857 .40554 Mdot
.05048 .29695 Mdot
.05238 .22775 Mdot
.05429 .31259 Mdot
.05619 .36686 Mdot
.0581 .40592 Mdot
.06 .25326 Mdot
.0619 .38994 Mdot
.06381 .38522 Mdot
.06571 .38977 Mdot
.06762 .36709 Mdot
.06952 .40062 Mdot
.07143 .22835 Mdot
.07333 .2737 Mdot
.07524 .25427 Mdot
.07714 .25293 Mdot
.07905 .37584 Mdot
.08095 .39315 Mdot
.08286 .35501 Mdot
.08476 .27682 Mdot
.08667 .26621 Mdot
.08857 .37891 Mdot
.09048 .37853 Mdot
.09238 .33713 Mdot
.09429 .31117 Mdot
.09619 .25451 Mdot
.0981 .3276 Mdot
.1 .26827 Mdot
.1019 .22892 Mdot
.10381 .37795 Mdot
.10571 .38733 Mdot
.10762 .40201 Mdot
.10952 .39911 Mdot
.11143 .25979 Mdot
.11333 .26378 Mdot
.11524 .31245 Mdot
.11714 .30821 Mdot
.11905 .34542 Mdot
.12095 .30124 Mdot
.12286 .34813 Mdot
.12476 .35891 Mdot
.12667 .38557 Mdot
.12857 .38116 Mdot
.13048 .25373 Mdot
.13238 .28648 Mdot
.13429 .35931 Mdot
.13619 .31401 Mdot
.1381 .3983 Mdot
.14 .27289 Mdot
.1419 .2313 Mdot
.14381 .30852 Mdot
.14571 .33646 Mdot
.14762 .22945 Mdot
.14952 .27647 Mdot
.15143 .27849 Mdot
.15333 .29305 Mdot
.15524 .25346 Mdot
.15714 .39227 Mdot
.15905 .33994 Mdot
.16095 .2678 Mdot
.16286 .26862 Mdot
.16476 .29112 Mdot
.16667 .30806 Mdot
.16857 .30158 Mdot
.17048 .3595 Mdot
.17238 .31904 Mdot
.17429 .35597 Mdot
.17619 .35211 Mdot
.1781 .34644 Mdot
.18 .38911 Mdot
.1819 .31151 Mdot
.18381 .37648 Mdot
.18571 .30188 Mdot
.18762 .3326 Mdot
.18952 .25509 Mdot
.19143 .28899 Mdot
.19333 .34625 Mdot
.19524 .28772 Mdot
.19714 .23324 Mdot
.19905 .31665 Mdot
.20095 .3386 Mdot
.20286 .26288 Mdot
.20476 .33737 Mdot
.20667 .28817 Mdot
.20857 .29634 Mdot
.21048 .2658 Mdot
.21238 .35936 Mdot
.21429 .33119 Mdot
.21619 .39465 Mdot
.2181 .32963 Mdot
.22 .23447 Mdot
.2219 .40196 Mdot
.22381 .37749 Mdot
.22571 .37968 Mdot
.22762 .35446 Mdot
.22952 .25264 Mdot
.23143 .33872 Mdot
.23333 .38524 Mdot
.23524 .29852 Mdot
.23714 .32884 Mdot
.23905 .2713 Mdot
.24095 .37751 Mdot
.24286 .40179 Mdot
.24476 .29179 Mdot
.24667 .29063 Mdot
.24857 .31285 Mdot
.25048 .30431 Mdot
.25238 .2755 Mdot
.25429 .40212 Mdot
.25619 .2235 Mdot
.2581 .35886 Mdot
.26 .38257 Mdot
.2619 .38907 Mdot
.26381 .30701 Mdot
.26571 .36656 Mdot
.26762 .27734 Mdot
.26952 .38043 Mdot
.27143 .32426 Mdot
.27333 .38269 Mdot
.27524 .39127 Mdot
.27714 .23568 Mdot
.27905 .39054 Mdot
.28095 .38898 Mdot
.28286 .37508 Mdot
.28476 .35465 Mdot
.28667 .36748 Mdot
.28857 .26661 Mdot
.29048 .24424 Mdot
.29238 .22607 Mdot
.29429 .27875 Mdot
.29619 .33764 Mdot
.2981 .25506 Mdot
.3 .36553 Mdot
.3019 .38688 Mdot
.30381 .30608 Mdot
.30571 .41484 Mdot
.30762 .27398 Mdot
.30952 .28723 Mdot
.31143 .2327 Mdot
.31333 .32117 Mdot
.31524 .2634 Mdot
.31714 .40414 Mdot
.31905 .26796 Mdot
.32095 .39108 Mdot
.32286 .33713 Mdot
.32476 .32518 Mdot
.32667 .29323 Mdot
.32857 .29801 Mdot
.33048 .34168 Mdot
.33238 .28721 Mdot
.33429 .36676 Mdot
.33619 .2709 Mdot
.3381 .33263 Mdot
.34 .38642 Mdot
.3419 .38731 Mdot
.34381 .30077 Mdot
.34571 .38073 Mdot
.34762 .25336 Mdot
.34952 .3629 Mdot
.35143 .32898 Mdot
.35333 .32469 Mdot
.35524 .25333 Mdot
.35714 .27247 Mdot
.35905 .26385 Mdot
.36095 .24305 Mdot
.36286 .28762 Mdot
.36476 .39013 Mdot
.36667 .31321 Mdot
.36857 .35729 Mdot
.37048 .36983 Mdot
.37238 .25329 Mdot
.37429 .31254 Mdot
.37619 .22842 Mdot
.3781 .32885 Mdot
.38 .24169 Mdot
.3819 .28949 Mdot
.38381 .30762 Mdot
.38571 .26646 Mdot
.38762 .38734 Mdot
.38952 .22335 Mdot
.39143 .3895 Mdot
.39333 .33515 Mdot
.39524 .24082 Mdot
.39714 .29776 Mdot
.39905 .23553 Mdot
.40095 .23621 Mdot
.40286 .26577 Mdot
.40476 .30171 Mdot
.40667 .35337 Mdot
.40857 .30821 Mdot
.41048 .30888 Mdot
.41238 .26805 Mdot
.41429 .2691 Mdot
.41619 .31263 Mdot
.4181 .38807 Mdot
.42 .33292 Mdot
.4219 .39291 Mdot
.42381 .33813 Mdot
.42571 .32454 Mdot
.42762 .27124 Mdot
.42952 .40593 Mdot
.43143 .31317 Mdot
.43333 .37926 Mdot
.43524 .29729 Mdot
.43714 .38568 Mdot
.43905 .31605 Mdot
.44095 .2629 Mdot
.44286 .32179 Mdot
.44476 .39492 Mdot
.44667 .28184 Mdot
.44857 .285 Mdot
.45048 .27969 Mdot
.45238 .38587 Mdot
.45429 .33434 Mdot
.45619 .28162 Mdot
.4581 .25509 Mdot
.46 .40568 Mdot
.4619 .33219 Mdot
.46381 .2273 Mdot
.46571 .22283 Mdot
.46762 .3208 Mdot
.46952 .28238 Mdot
.47143 .33869 Mdot
.47333 .34321 Mdot
.47524 .25673 Mdot
.47714 .22482 Mdot
.47905 .25319 Mdot
.48095 .40264 Mdot
.48286 .37933 Mdot
.48476 .39291 Mdot
.48667 .23649 Mdot
.48857 .38825 Mdot
.49048 .38468 Mdot
.49238 .34006 Mdot
.49429 .29845 Mdot
.49619 .33461 Mdot
.4981 .30729 Mdot
.5 .36636 Mdot
.5019 .33843 Mdot
.50381 .31936 Mdot
.50571 .2318 Mdot
.50762 .29341 Mdot
.50952 .33312 Mdot
.51143 .2924 Mdot
.51333 .30015 Mdot
.51524 .25375 Mdot
.51714 .37525 Mdot
.51905 .30026 Mdot
.52095 .26977 Mdot
.52286 .31569 Mdot
.52476 .32462 Mdot
.52667 .25717 Mdot
.52857 .33622 Mdot
.53048 .31717 Mdot
.53238 .33326 Mdot
.53429 .39325 Mdot
.53619 .25703 Mdot
.5381 .38848 Mdot
.54 .32845 Mdot
.5419 .3228 Mdot
.54381 .35721 Mdot
.54571 .38031 Mdot
.54762 .29962 Mdot
.54952 .34033 Mdot
.55143 .34553 Mdot
.55333 .3188 Mdot
.55524 .25143 Mdot
.55714 .29312 Mdot
.55905 .28474 Mdot
.56095 .39315 Mdot
.56286 .36037 Mdot
.56476 .30637 Mdot
.56667 .2787 Mdot
.56857 .28995 Mdot
.57048 .24162 Mdot
.57238 .25334 Mdot
.57429 .26867 Mdot
.57619 .28999 Mdot
.5781 .38978 Mdot
.58 .28027 Mdot
.5819 .34382 Mdot
.58381 .29629 Mdot
.58571 .29675 Mdot
.58762 .22648 Mdot
.58952 .27261 Mdot
.59143 .28006 Mdot
.59333 .33398 Mdot
.59524 .25355 Mdot
.59714 .39432 Mdot
.59905 .22713 Mdot
.60095 .42076 Mdot
.60286 .32772 Mdot
.60476 .37936 Mdot
.60667 .39467 Mdot
.60857 .28899 Mdot
.61048 .22523 Mdot
.61238 .26693 Mdot
.61429 .28195 Mdot
.61619 .29909 Mdot
.6181 .30143 Mdot
.62 .40063 Mdot
.6219 .36657 Mdot
.62381 .39751 Mdot
.62571 .23216 Mdot
.62762 .30355 Mdot
.62952 .39423 Mdot
.63143 .37931 Mdot
.63333 .22851 Mdot
.63524 .30893 Mdot
.63714 .24598 Mdot
.63905 .23949 Mdot
.64095 .25456 Mdot
.64286 .30876 Mdot
.64476 .38845 Mdot
.64667 .37385 Mdot
.64857 .30409 Mdot
.65048 .2502 Mdot
.65238 .28761 Mdot
.65429 .27244 Mdot
.65619 .35545 Mdot
.6581 .29033 Mdot
.66 .27824 Mdot
.6619 .33786 Mdot
.66381 .40073 Mdot
.66571 .32206 Mdot
.66762 .2687 Mdot
.66952 .40539 Mdot
.67143 .39059 Mdot
.67333 .38659 Mdot
.67524 .29042 Mdot
.67714 .2712 Mdot
.67905 .33885 Mdot
.68095 .31706 Mdot
.68286 .38214 Mdot
.68476 .3358 Mdot
.68667 .25399 Mdot
.68857 .25458 Mdot
.69048 .36449 Mdot
.69238 .37723 Mdot
.69429 .33964 Mdot
.69619 .31606 Mdot
.6981 .27263 Mdot
.7 .2601 Mdot
.7019 .34883 Mdot
.70381 .3417 Mdot
.70571 .31342 Mdot
.70762 .36267 Mdot
.70952 .3379 Mdot
.71143 .33721 Mdot
.71333 .25698 Mdot
.71524 .23699 Mdot
.71714 .38455 Mdot
.71905 .23352 Mdot
.72095 .24333 Mdot
.72286 .24272 Mdot
.72476 .27074 Mdot
.72667 .33994 Mdot
.72857 .22674 Mdot
.73048 .27973 Mdot
.73238 .27107 Mdot
.73429 .3547 Mdot
.73619 .33564 Mdot
.7381 .39287 Mdot
.74 .39497 Mdot
.7419 .26065 Mdot
.74381 .40211 Mdot
.74571 .31545 Mdot
.74762 .28119 Mdot
.74952 .3657 Mdot
.75143 .35756 Mdot
.75333 .37877 Mdot
.75524 .22652 Mdot
.75714 .40168 Mdot
.75905 .26617 Mdot
.76095 .39404 Mdot
.76286 .27 Mdot
.76476 .22932 Mdot
.76667 .33722 Mdot
.76857 .27305 Mdot
.77048 .26117 Mdot
.77238 .39159 Mdot
.77429 .28121 Mdot
.77619 .28539 Mdot
.7781 .28356 Mdot
.78 .25494 Mdot
.7819 .31621 Mdot
.78381 .39982 Mdot
.78571 .24826 Mdot
.78762 .2526 Mdot
.78952 .37192 Mdot
.79143 .35317 Mdot
.79333 .36868 Mdot
.79524 .25953 Mdot
.79714 .2534 Mdot
.79905 .29663 Mdot
.80095 .28153 Mdot
.80286 .24861 Mdot
.80476 .2541 Mdot
.80667 .33578 Mdot
.80857 .28776 Mdot
.81048 .3272 Mdot
.81238 .22989 Mdot
.81429 .2543 Mdot
.81619 .34561 Mdot
.8181 .33026 Mdot
.82 .25925 Mdot
.8219 .3163 Mdot
.82381 .25611 Mdot
.82571 .37811 Mdot
.82762 .26474 Mdot
.82952 .3332 Mdot
.83143 .22414 Mdot
.83333 .24775 Mdot
.83524 .30976 Mdot
.83714 .37915 Mdot
.83905 .35519 Mdot
.84095 .38581 Mdot
.84286 .33864 Mdot
.84476 .25325 Mdot
.84667 .22519 Mdot
.84857 .27578 Mdot
.85048 .40021 Mdot
.85238 .39084 Mdot
.85429 .40285 Mdot
.85619 .33389 Mdot
.8581 .23514 Mdot
.86 .22792 Mdot
.8619 .25687 Mdot
.86381 .37029 Mdot
.86571 .34552 Mdot
.86762 .33404 Mdot
.86952 .28007 Mdot
.87143 .27165 Mdot
.87333 .34568 Mdot
.87524 .34349 Mdot
.87714 .3086 Mdot
.87905 .32848 Mdot
.88095 .38432 Mdot
.88286 .37334 Mdot
.88476 .33723 Mdot
.88667 .31164 Mdot
.88857 .31081 Mdot
.89048 .29846 Mdot
.89238 .29817 Mdot
.89429 .36479 Mdot
.89619 .40222 Mdot
.8981 .39765 Mdot
.9 .36387 Mdot
.9019 .34301 Mdot
.90381 .36775 Mdot
.90571 .25253 Mdot
.90762 .28622 Mdot
.90952 .29074 Mdot
.91143 .23649 Mdot
.91333 .25543 Mdot
.91524 .34098 Mdot
.91714 .33193 Mdot
.91905 .37074 Mdot
.92095 .36778 Mdot
.92286 .39655 Mdot
.92476 .25164 Mdot
.92667 .31355 Mdot
.92857 .37739 Mdot
.93048 .22241 Mdot
.93238 .38858 Mdot
.93429 .30885 Mdot
.93619 .38699 Mdot
.9381 .34776 Mdot
.94 .26745 Mdot
.9419 .29378 Mdot
.94381 .38497 Mdot
.94571 .38699 Mdot
.94762 .29975 Mdot
.94952 .30578 Mdot
.95143 .27484 Mdot
.95333 .25083 Mdot
.95524 .39247 Mdot
.95714 .26595 Mdot
.95905 .26398 Mdot
.96095 .27379 Mdot
.96286 .38949 Mdot
.96476 .2786 Mdot
.96667 .40381 Mdot
.96857 .25633 Mdot
.97048 .33842 Mdot
.97238 .25303 Mdot
.97429 .36358 Mdot
.97619 .252 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo04Oooooo0_l0000Yooooo`;o00005_ooool2o`0000;ooooo0_l0001`ooooo`;o00007_ooool2
o`0001[ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool01Ooo
ool2o`00043ooooo0_l0000:ooooo`;o00007Oooool2o`0001Kooooo0_l00002ooooo`;o00008_oo
ool2o`000003ooooool0003o000000;ooooo0_l0000Tooooo`;o00001_ooool2o`0001Oooooo0_l0
0003ooooo`;o00000_ooool2o`0001Gooooo0_l0000Jooooo`001?l00002ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01Oooool2o`0000Gooooo0_l00007ooooo`;o00003Oooool2o`0002gooooo0_l0
000Iooooo`;o00006_ooool2o`0002Kooooo0_l000000ooooooo0000o`000002ooooo`;o00001Ooo
ool2o`0001gooooo0_l00006ooooo`;o00000_ooool2o`0000gooooo0_l00009ooooo`;o00000_oo
ool2o`00037ooooo0006ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^
kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000<ooooo`;o00001oooool2o`0000_ooooo1?l0
000>ooooo`;o00008oooool2o`0001?ooooo0_l0000Wooooo`;o00009Oooool4o`0001[ooooo0_l0
000=ooooo`;o00003Oooool2o`00043ooooo0006ooooo`05o`000?ooooooooooooooool000003_oo
ool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`0Rooooo`;o00004?ooool2o`0000Gooooo0_l0000Aooooo`;o00002Oooool2o`0001[ooooo
0ol0000Iooooo`;o00001?ooool2o`0002Gooooo0_l0000Kooooo`?o0000:oooool2o`0000oooooo
0_l0000Pooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03_ooooo0_l0000Aooooo`;o0000
9Oooool3o`0001Wooooo0_l0000_ooooo`;o00005oooool2o`0002cooooo0_l0000?ooooo`;o0000
8?ooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@
41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo06Wooooo0_l00004ooooo`;o
00000oooool2o`0003Kooooo0_l0000Dooooo`;o00006?ooool3o`0005gooooo0006ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006oooo
o`03o`000?oooooooooo05;ooooo0_l0000Eooooo`;o00001?ooool2o`0000?ooooo0_l0000foooo
o`;o00004oooool2o`0001Wooooo0ol0001Mooooo`00:Oooool2o`0000Gooooo0_l0001<ooooo`;o
0000KOooool2o`0002kooooo0_l00004ooooo`;o00002?ooool2o`0003Wooooo000Yooooo`03o`00
0?oooooooooo00;ooooo1?l0000hooooo`;o0000Ioooool2o`0001gooooo0_l0000Yooooo`?o0000
0oooool2o`0000Sooooo0_l0000Eooooo`;o00001?ooool2o`0000Oooooo0_l00006ooooo`;o0000
2oooool002Wooooo00Go0000ooooool0003o0000ooooo`02o`0000Cooooo0_l00003ooooo`;o0000
1Oooool2o`0000Wooooo0_l00006ooooo`;o00002Oooool2o`0000[ooooo0_l0000Dooooo`;o0000
3_ooool2o`000003ooooool0003o000000?ooooo0_l0000Jooooo`;o00001Oooool2o`0000Wooooo
0_l0000;ooooo`;o00001?ooool2o`0000Gooooo0_l0000=ooooo`;o000000?oooooo`000?l00000
2Oooool3o`0001_ooooo0_l000001?oooooo0000o`000?ooool4o`000003ooooool0003o000000So
oooo0_l0000Booooo`Co00000_ooool2o`0000Oooooo0_l00004ooooo`Co00002oooool002Wooooo
00Co0000ooooool0003o00001oooool2o`0000?ooooo0_l00005ooooo`;o00002Oooool2o`0000Ko
oooo0_l00009ooooo`;o00008?ooool2o`0000kooooo0_l000000ooooooo0000o`000003ooooo`;o
00006_ooool2o`0000?ooooo1?l00009ooooo`;o00000_ooool2o`000003ooooool0003o000000[o
oooo0_l00005ooooo`;o00003Oooool2o`0000cooooo0ol00006ooooo`;o00004oooool2o`0000Co
oooo1?l000000ooooooo0000o`000002ooooo`;o00001?ooool2o`0000Cooooo0_l0000>ooooo`;o
00004?ooool3o`0000gooooo000Yooooo`03o`000?oooooooooo01Sooooo0_l0001cooooo`;o0000
3oooool2o`000003ooooool0003o000003?ooooo0_l00002ooooo`;o00001oooool2o`0000Oooooo
0_l00006ooooo`;o00001_ooool4o`0000[ooooo0_l0000Pooooo`;o00003_ooool002Wooooo0_l0
0004ooooo`;o00004oooool3o`0001_ooooo0_l0000Rooooo`;o00003?ooool2o`0001Sooooo0_l0
001Booooo`;o00002oooool2o`0000Oooooo0_l00006ooooo`;o00001_ooool2o`000003ooooool0
003o000002Sooooo0_l0000Aooooo`00:Oooool00ol0003oooooooooo`03ooooo`;o00002oooool2
o`0000?ooooo0_l00002ooooo`;o00003Oooool2o`0000cooooo1?l0000Gooooo`;o00001oooool3
o`0000_ooooo0_l00007ooooo`;o00000oooool2o`000003ooooool0003o000000Oooooo0_l0000f
ooooo`;o0000;Oooool2o`0001Cooooo0_l0000Rooooo`;o00000oooool3o`00017ooooo000Yoooo
o`04o`000?ooooooooooooooo`;o00003Oooool2o`0000?ooooo0_l0000Aooooo`?o00001Oooool4
o`000004oa0@4?ooooooooooonk^kP;o000000?o<S8bonk^k_ooool00_ooool01Oo^k^ko<S8bo`00
0?l0003ok^k^00gooooo0_l00008ooooo`;o00001?ooool2o`0000[ooooo1_l00002ooooo`04onk^
k_l0003o0000oc8b<P?o000000Koooooonk^k_l0003o0000oc8b<_o^k^hJooooo`;o00003?ooool0
0onHV9So410@o`000002o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`?o000000?o
<S8bonk^k_ooool02oooool2o`000003ooooool0003o000000kooooo1?l00007ooooo`?o00000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Wooooo`;o
000000?oA4A4o`000?l000000_l00002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Yooooo`04o`000?ooooooooooooooo`;o00002Oooool2
o`0001Cooooo0_l00005ooooo`;o00001oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool01OmgMgOoV9RHo`000?l0003oMgMg01Cooooo0_l00007ooooo`;o0000
1?ooool2o`0000Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00_l000001_ooooooMgMgo`000?l0003oV9RHogMgMa[ooooo0_l0000<ooooo`03oa0@4?nj
^[[ooooo00;o00000oooool2o`000003oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`08ooooo`;o00000_ooool2o`000003ooooool0003o000000Gooooo0_l00007ooooo`Co0000
2?ooool4o`000006oooooomgMgOoV9RHoooooonHV9SoMgMg0oooool01OmgMgOoV9RHoooooonHV9So
MgMg017ooooo0_l0000Iooooo`09ogMgMolb<S;o0000o`000?mgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool00ol0003oooooooooo`0<ooooo`;o
00000_ooool2o`00013ooooo0_l000000ooooooo0000o`00000;ooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000_ooool2
o`0000?ooooo0_l0000;ooooo`;o00003Oooool2o`0000Gooooo00?oV9RHob4Q8Oo^k^h01?ooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@400/ooooo`04o`00
0?ooooooooooooooo`;o00000_ooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooo
ooooool01_ooool2o`0000cooooo0_l0000@ooooo`Oo000000?ooooooa0@4?ooool00_ooool01Ol@
413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01oooool2o`0000Kooooo0_l0000H
ooooo`Go000000Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100
0oooool002Wooooo0_l0000Aooooo`;o00004oooool2o`0000_ooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`;o
00000oooool2o`0000Kooooo0_l0000Jooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool2o`0002Cooooo0_l00000
1OnYZJWo410@o`000?l0003ooooo00?o000000?oooooo`000?ooool00_ooool01Ol0003ooooooooo
oooooooo000000[ooooo0_l0000Dooooo`;o00001_ooool01?m4A4CogMgMooooool00004ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Wooooo0_l00005
ooooo`;o00006Oooool2o`000004oc8b<_oooooo0000o`0000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo007ooooo000Yooooo`03o`000?oooooooooo02Gooooo0_l0
000;ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000003oooool2o`0001_ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`Go00000oooool2
o`0001gooooo0ol000001?nj^[[o0000o`000?ooool3o`000003ooooool0003ooooo00;ooooo0_l0
0002ooooo`03o`000?oooooooooo00Sooooo0_l0000Dooooo`;o00001?ooool2o`000004omgMgOmE
EEGoooooo`0000?ooooo0ol00002ooooo`03o`000?oooooooooo00;o00000oooool00ol0003ooooo
ooooo`0>ooooo`;o00005oooool01_l0003o8B4Qo`000?lb<S;oc<c<ooooo`;o00000oooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00Oooool002Wooooo00?o0000oooo
ooooool00_ooool2o`0001_ooooo0_l0000Aooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100;Oooool01Ol0003ooooooooo
oooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Go
00000oooool2o`0001[ooooo0_l00003ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooo
oooooooooa0@4003ooooo`;o00000_ooool00ol@413oooooooooo`0Tooooo`;o000000CoooooogMg
Moo<c<co00000oooool3o`0000;ooooo00?o410@ooooooooool00_l00003ooooo`03oa0@4?oooooo
oooo01[ooooo0_l0000;ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool002Wooooo00?o0000ooooooooool00_oo
ool2o`0001_ooooo0_l0000Aooooo`?o00000_ooool2o`000003oooooonHV9SoMgMg00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0Dooooo`;o00001Oooool2o`0000Sooooo0_l00002ooooo`05o`00
0?nj^[[o0000o`000?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`;o00008Oooool2o`000004oa0@4?l0003o0000okZj^P;o00000_oo
ool01_mgMgOoV9RHoooooonHV9SoMgMgooooo`;o000000GoMgMgoiRHV?ooooooV9RHogMgM`07oooo
o`;o00008?ooool00oo^k^koA4A4o`000003ooooo`;o000000CoV9RHoooooonHV9SoMgMg0oooool0
1OmgMgOoV9RHo`000?l0003oMgMg01cooooo0_l0000;ooooo`03o`000?oooooooooo00Cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wooooo
00?o0000ooooooooool09_ooool2o`0000;ooooo0_l00004ooooo`03oeEEEOmVIVKo000000;o0000
0_ooool3o`000003oc8b<_o^k^kooooo00;ooooo00Cok^k^oc8b<_l0003o<S8b0ol0000Booooo`;o
00001?ooool3o`0000Sooooo0_l00002ooooo`05oiRHV?l@413o0000o`000?o<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Gooooo`;o00003Ooo
ool2o`000004ojVYZOl0003o0000oa0@40;o00000_ooool01_o^k^ko<S8bo`000?lb<S;ok^k^oooo
o`;o000000Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`Co00001?ooool2o`0001Wooooo00?oMgMg
o`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o0000
onk^kP0Mooooo`;o00002_ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool002Wooooo0_l0000Wooooo`;o00000_ooool2o`0000co
oooo0_l00009ooooo`?o00006?ooool2o`0003Sooooo0ol0000=ooooo`;o00001_ooool2o`0001Ko
oooo0_l00004ooooo`;o0000BOooool2o`0000Sooooo0_l0000Gooooo`00:Oooool00ol0003ooooo
ooooo`05ooooo`;o0000<Oooool2o`0000Kooooo0_l0000Looooo`;o00005?ooool2o`0000_ooooo
0_l0000Aooooo`;o00000_ooool2o`0001Kooooo0ol00008ooooo`;o0000>Oooool2o`0001_ooooo
0ol0000=ooooo`;o00005oooool002Wooooo00?o0000ooooooooool01Oooool2o`0001Gooooo0_l0
000=ooooo`;o00000oooool2o`0000kooooo0_l0000Looooo`;o00000oooool2o`0000oooooo0_l0
00000ooooooo0000o`000008ooooo`;o00004Oooool2o`0000Cooooo1?l00007ooooo`;o00002_oo
ool2o`0000Sooooo0_l0000iooooo`;o00006oooool3o`0000oooooo0_l0000Eooooo`00:Oooool0
1?l0003oooooooooooooool2o`0001Wooooo0_l0000=ooooo`;o00000oooool2o`0001?ooooo0_l0
000Looooo`;o00004_ooool2o`00027ooooo1?l00007ooooo`;o00005?ooool2o`000003ooooool0
003o000000Gooooo0_l0001Nooooo`;o00005Oooool002Wooooo00Co0000oooooooooooooooo0_l0
000Gooooo`;o00001oooool2o`0000Gooooo0_l0000Iooooo`;o00000_ooool2o`0000_ooooo0_l0
000Hooooo`;o00001_ooool2o`0001_ooooo0_l0000Cooooo`;o00004_ooool2o`0000?ooooo1?l0
0018ooooo`;o00005Oooool2o`0001Cooooo000Qoooooooo0000A?l00004ooooo`00:Oooool3o`00
00Kooooo0_l000000ooooooo0000ooooo`08ooooo`;o000000?oooooo`000?ooool00_ooool2o`00
00Cooooo0ol0000;ooooo`?o00002Oooool00ol0003oooooooooo`08ooooo`?o00002oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo1?l00009ooooo`Co00000oooool2o`00
00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`;o00002_ooool00ol0
003oooooooooo`08ooooo`?o00002oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool00_l00008ooooo`03o`000?oooooooooo00Cooooo0_l00003oooo
o`03o`000?oooooooooo00Gooooo1Ol0000;ooooo`03o`000?oooooooooo00[ooooo000Yooooo`Co
00001Oooool2o`0001;ooooo0_l00004ooooo`;o00004oooool2o`0000?ooooo00?o0000oooooooo
ool02?ooool2o`0002Cooooo1?l00009ooooo`04o`000?oooooo0000o`0000?ooooo0_l000000ooo
oooo0000o`00000Iooooo`Co00005?ooool00ol0003oooooooooo`0Hooooo`;o00000_ooool2o`00
00;ooooo0_l0000:ooooo`;o00002_ooool3o`0000[ooooo0_l0000Pooooo`;o00003_ooool00ol0
003oooooooooo`0:ooooo`00:Oooool01?l0003oooooo`000?l0000[ooooo`;o00001oooool2o`00
02;ooooo0_l0000Wooooo`;o00001oooool2o`0000[ooooo0_l00004ooooo`Co00001_ooool2o`00
02Oooooo0_l00002ooooo`;o00003_ooool2o`0000[ooooo0_l0000;ooooo`;o0000?Oooool002Wo
oooo00?o0000ooooooooool0;?ooool2o`0001kooooo0_l0000;ooooo`;o0000:?ooool2o`0000Ko
oooo0_l0000:ooooo`;o00002_ooool2o`0000;ooooo0_l0000Rooooo`;o0000Koooool002Wooooo
0_l0001=ooooo`;o00003oooool2o`0000Oooooo0_l0000Eooooo`;o00001?ooool2o`0001Sooooo
0_l00004ooooo`;o00009_ooool2o`0002cooooo0_l00011ooooo`00:Oooool00ol0003ooooooooo
o`0Dooooo`;o00009Oooool2o`0000Cooooo0_l0000Jooooo`;o00001oooool2o`0000Kooooo0_l0
000=ooooo`;o00007_ooool2o`0000?ooooo0_l0000Booooo`;o0000@Oooool2o`000003ooooool0
003o0000017ooooo0_l0000[ooooo`00:Oooool00ol0003oooooooooo`0Dooooo`;o00006oooool2
o`0000Oooooo0ol00004ooooo`;o00007_ooool2o`0000?ooooo0_l00006ooooo`;o00003?ooool2
o`0000_ooooo0_l0000=ooooo`;o00001_ooool4o`0001;ooooo0_l00014ooooo`;o000000?ooooo
o`000?l000003_ooool2o`0000_ooooo0_l0000Nooooo`00:Oooool00ol0003oooooooooo`0Soooo
o`;o00003?ooool2o`0000Oooooo0_l0000Uooooo`;o00004?ooool2o`0000Oooooo0_l00009oooo
o`Co00002Oooool2o`0000;ooooo0_l00005ooooo`?o00004Oooool2o`0001cooooo0_l0000>oooo
o`;o00005Oooool2o`0000Gooooo0_l00007ooooo`;o00000_ooool2o`0000kooooo0_l0000Noooo
o`00:Oooool00ol0003oooooooooo`0Booooo`;o00003oooool2o`00013ooooo0ol00007ooooo`;o
00004oooool2o`0000Kooooo0_l0000Eooooo`;o00002?ooool2o`0000Sooooo0_l00003ooooo`;o
00001_ooool4o`0000Oooooo0_l0000Booooo`;o00005?ooool2o`0000Cooooo1?l000000ooooooo
0000o`000003ooooo`;o00001_ooool2o`0000Sooooo0_l0000;ooooo`;o00002_ooool2o`0000;o
oooo0_l00002ooooo`;o00000oooool2o`0001[ooooo0_l0000=ooooo`00:Oooool2o`0001?ooooo
0_l0000Dooooo`;o00002oooool3o`0000Oooooo0_l0000Cooooo`;o00001_ooool2o`000003oooo
ool0003o000001cooooo0_l0000=ooooo`;o00001Oooool2o`000003ooooool0003o000000gooooo
0_l0000Rooooo`;o00001?ooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`0000?ooooo
0_l0000;ooooo`;o00005oooool2o`0000_ooooo0_l00004ooooo`;o00000_ooool2o`00013ooooo
0_l0000=ooooo`00:Oooool00ol0003oooooooooo`0Kooooo`;o00002oooool2o`0003Gooooo0_l0
000/ooooo`;o00001?ooool2o`00013ooooo0ol00008ooooo`;o00009Oooool2o`0000Gooooo0_l0
000Kooooo`;o00003_ooool5o`0000Oooooo0_l00002ooooo`;o00007oooool002Wooooo00?o0000
ooooooooool06oooool3o`00013ooooo0_l00003ooooo`;o0000F?ooool2o`0001Oooooo0_l00008
ooooo`;o00009?ooool2o`0002?ooooo0_l0000>ooooo`Go00004_ooool2o`0001Sooooo000Yoooo
o`03o`000?oooooooooo01cooooo0_l0000?ooooo`?o00000oooool2o`000:7ooooo0_l0001:oooo
o`;o00006?ooool002Wooooo00?o0000ooooooooool03oooool2o`0001cooooo0_l0000?ooooo`;o
00004?ooool2o`0002Gooooo0_l0001?ooooo`;o00005oooool2o`00013ooooo0_l0000=ooooo`;o
0000>?ooool002Wooooo0_l0000@ooooo`;o00007?ooool2o`0000oooooo0_l0000@ooooo`;o0000
6Oooool2o`0000[ooooo0_l0000Zooooo`;o00008oooool2o`0001Oooooo0_l00003ooooo`;o0000
2oooool2o`0000gooooo0_l0000hooooo`00:Oooool00ol0003oooooooooo`0Mooooo`;o000000?o
ooooo`000?l000002Oooool4o`0000[ooooo0_l0000=ooooo`;o00008Oooool2o`0003Kooooo0_l0
0005ooooo`;o0000>_ooool2o`0005Cooooo000Yooooo`03o`000?oooooooooo01gooooo0_l00000
0ooooooo0000o`000009ooooo`;o00003?ooool2o`0000gooooo0_l0000Kooooo`;o0000@oooool2
o`0002Oooooo0_l00003ooooo`;o0000>_ooool4o`0001Kooooo0_l0000<ooooo`00:Oooool00ol0
003oooooooooo`07ooooo`;o000000?oooooo`000?l00000?_ooool2o`0000Gooooo0_l00002oooo
o`;o00002Oooool2o`0000?ooooo0_l0000^ooooo`;o00009_ooool2o`0001Cooooo0_l00003oooo
o`;o00003?ooool2o`0002cooooo1Ol00004ooooo`;o00003oooool2o`0000cooooo000Yooooo`03
o`000?oooooooooo00Oooooo0_l000000ooooooo0000o`00000nooooo`;o00001Oooool2o`0000;o
oooo0_l00009ooooo`;o00002_ooool2o`0002Oooooo0_l0000Vooooo`;o00009oooool2o`0000co
oooo0_l0000Dooooo`;o00002oooool2o`0000?ooooo0ol0000Mooooo`00:Oooool2o`0006gooooo
0_l0001Gooooo`;o0000:oooool4o`0001Cooooo0_l00004ooooo`;o00002_ooool2o`0001kooooo
000Yooooo`03o`000?oooooooooo00kooooo0_l0000Pooooo`;o00007_ooool2o`0004Wooooo0_l0
000Xooooo`;o00003?ooool2o`0001gooooo0_l0000Looooo`;o0000:_ooool000Kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8b
omgMg@05ooooo`03o`000?oooooooooo00kooooo0_l000001?oooooo0000o`000?l00002ooooo`;o
00006?ooool2o`0000_ooooo0_l00003ooooo`;o00003?ooool2o`0002kooooo0_l0000>ooooo`;o
00002Oooool2o`0000Oooooo0_l0000Aooooo`;o00001oooool2o`00017ooooo0_l0000Booooo`;o
00005Oooool2o`0000;ooooo0_l0000Kooooo`;o00006oooool000Kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`0Aooooo`?o00000_ooool2o`0000Kooooo0_l0000Moooo
o`;o00000oooool2o`0000Cooooo0_l000000ooooooo0000o`000002o`0001Gooooo0_l0000Joooo
o`;o00003_ooool2o`0001;ooooo0_l0000Aooooo`;o00001oooool2o`0000kooooo0_l0000Eoooo
o`;o00005Oooool2o`0000;ooooo0_l0000Kooooo`;o00006oooool000Kooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`09ooooo`;o00004_ooool3o`00023ooooo0_l00006ooooo`;o000000?oooooo`00
0?l000000_l0000Cooooo`Co00006oooool2o`0000?ooooo0_l0000:ooooo`;o0000??ooool2o`00
00Wooooo0_l0000Vooooo`;o00002oooool2o`0001;ooooo0_l0000Fooooo`001_ooool01Ol0003o
oooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04oooo
o`?o00002Oooool2o`0000cooooo0_l00004ooooo`;o00003oooool2o`00013ooooo0_l00007oooo
o`;o00001?ooool2o`0000Gooooo0_l0000:ooooo`?o00003?ooool3o`0000Oooooo0_l00004oooo
o`;o00000oooool2o`0000[ooooo0_l0000>ooooo`;o00008?ooool2o`0000Oooooo0_l0000<oooo
o`;o00009_ooool2o`0000_ooooo0_l0000>ooooo`Oo00000oooool2o`00013ooooo0006ooooo`05
o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01Oooool00ol0003oooooooooo`02o`0000Oooooo0ol0000;ooooo`;o00003_ooool2
o`0000Gooooo0_l0000Iooooo`;o00000_ooool4o`0000Gooooo0_l00004ooooo`;o00001Oooool2
o`0000Gooooo0_l00005ooooo`?o00001oooool2o`0001Gooooo0_l0000>ooooo`;o00002_ooool2
o`0001Cooooo0_l00007ooooo`;o00007_ooool2o`0001Sooooo0_l0000Gooooo`Co000000Cooooo
o`000?l0003ooooo1?l0000@ooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;o00001ooo
ool3o`0000?ooooo0_l0000Fooooo`;o00004Oooool2o`00017ooooo0ol0000<ooooo`;o00003?oo
ool2o`00013ooooo0_l00006ooooo`;o00002_ooool2o`0000kooooo0_l00007ooooo`;o00000ooo
ool2o`0000Gooooo0_l000000ooooooo0000o`000005ooooo`;o00003?ooool2o`0001?ooooo0ol0
0004ooooo`;o00000_ooool2o`0001Sooooo0_l0000Oooooo`;o00004_ooool000Kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooo
ooooo`07ooooo`;o00004?ooool2o`00013ooooo0_l0000Gooooo`;o0000@?ooool2o`0000Kooooo
0_l0000:ooooo`;o00003_ooool2o`0000Oooooo0_l0000:ooooo`;o000000?oooooo`000?l00000
0oooool4o`00027ooooo0ol00004ooooo`;o0000:_ooool2o`0000Kooooo0_l0000Mooooo`001_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co
00001_ooool2o`0000cooooo0_l0000:ooooo`?o00001oooool2o`0001Wooooo0_l00005ooooo`;o
000000?oooooo`000?l00000M?ooool3o`0000_ooooo0_l0000Hooooo`;o00000_ooool2o`0000Oo
oooo0_l0000Cooooo`;o00003Oooool2o`0000Kooooo0_l0000Mooooo`00:Oooool2o`0000cooooo
0_l0000:ooooo`?o00008_ooool2o`0000Gooooo0_l000000ooooooo0000o`00000Cooooo`;o0000
<_ooool2o`0002_ooooo0_l0000<ooooo`;o00006?ooool2o`0000;ooooo0_l00007ooooo`;o0000
4oooool3o`0000cooooo0_l0000Dooooo`;o00003oooool002Wooooo00?o0000ooooooooool01?oo
ool2o`000003ooooool0003o000005;ooooo0_l0000Rooooo`;o00002?ooool2o`0000Cooooo0_l0
000kooooo`;o0000>Oooool2o`0000cooooo0_l0000Dooooo`;o00003oooool002Wooooo00?o0000
ooooooooool01?ooool2o`000003ooooool0003o000007Kooooo0_l00008ooooo`;o0000@Oooool2
o`0006kooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0Eoooool2o`000>?ooooo000Yooooo`;o0000F?ooool2o`0005gooooo0_l00024ooooo`00:Ooo
ool00ol0003oooooooooo`2fooooo`;o0000Q?ooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0
oooooolmooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Ol@413ooooooooo
oooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000kooooo00Go
0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`00
3_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Ko
oooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`001_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooo
oooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000
oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool0
1_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go
0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooo
oooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413o
oooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooo
ocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006oooo
o`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool001oooooo1?l0
00000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo
00Gooooo0ol0003oooooocgooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool001oooooo00?oEEEEofIVI_l00000oooooom7oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .38748 Mdot
.02762 .39682 Mdot
.02952 .29563 Mdot
.03143 .3408 Mdot
.03333 .28175 Mdot
.03524 .35808 Mdot
.03714 .30032 Mdot
.03905 .39932 Mdot
.04095 .35861 Mdot
.04286 .33979 Mdot
.04476 .32582 Mdot
.04667 .36007 Mdot
.04857 .40952 Mdot
.05048 .34575 Mdot
.05238 .29416 Mdot
.05429 .34406 Mdot
.05619 .30812 Mdot
.0581 .41005 Mdot
.06 .31374 Mdot
.0619 .42551 Mdot
.06381 .41209 Mdot
.06571 .4062 Mdot
.06762 .40452 Mdot
.06952 .41276 Mdot
.07143 .28792 Mdot
.07333 .25681 Mdot
.07524 .29755 Mdot
.07714 .29432 Mdot
.07905 .42222 Mdot
.08095 .40212 Mdot
.08286 .40486 Mdot
.08476 .37865 Mdot
.08667 .37316 Mdot
.08857 .34164 Mdot
.09048 .32712 Mdot
.09238 .40267 Mdot
.09429 .39578 Mdot
.09619 .29087 Mdot
.0981 .40117 Mdot
.1 .37722 Mdot
.1019 .33122 Mdot
.10381 .3297 Mdot
.10571 .35206 Mdot
.10762 .37606 Mdot
.10952 .37052 Mdot
.11143 .27176 Mdot
.11333 .32468 Mdot
.11524 .39982 Mdot
.11714 .24596 Mdot
.11905 .40905 Mdot
.12095 .39305 Mdot
.12286 .41293 Mdot
.12476 .23752 Mdot
.12667 .35281 Mdot
.12857 .32948 Mdot
.13048 .36088 Mdot
.13238 .38893 Mdot
.13429 .29057 Mdot
.13619 .3992 Mdot
.1381 .36764 Mdot
.14 .25896 Mdot
.1419 .2741 Mdot
.14381 .39092 Mdot
.14571 .30857 Mdot
.14762 .32366 Mdot
.14952 .37904 Mdot
.15143 .33539 Mdot
.15333 .33841 Mdot
.15524 .31106 Mdot
.15714 .41444 Mdot
.15905 .25995 Mdot
.16095 .29694 Mdot
.16286 .32863 Mdot
.16476 .34068 Mdot
.16667 .39065 Mdot
.16857 .31278 Mdot
.17048 .238 Mdot
.17238 .25189 Mdot
.17429 .41599 Mdot
.17619 .28525 Mdot
.1781 .40402 Mdot
.18 .40249 Mdot
.1819 .33956 Mdot
.18381 .3238 Mdot
.18571 .39754 Mdot
.18762 .34443 Mdot
.18952 .28115 Mdot
.19143 .25205 Mdot
.19333 .26918 Mdot
.19524 .33645 Mdot
.19714 .27557 Mdot
.19905 .22091 Mdot
.20095 .31515 Mdot
.20286 .26865 Mdot
.20476 .31805 Mdot
.20667 .22361 Mdot
.20857 .34535 Mdot
.21048 .36902 Mdot
.21238 .23759 Mdot
.21429 .25313 Mdot
.21619 .39226 Mdot
.2181 .25282 Mdot
.22 .33982 Mdot
.2219 .38367 Mdot
.22381 .41423 Mdot
.22571 .34289 Mdot
.22762 .27922 Mdot
.22952 .31328 Mdot
.23143 .31465 Mdot
.23333 .41383 Mdot
.23524 .34554 Mdot
.23714 .33917 Mdot
.23905 .37449 Mdot
.24095 .42 Mdot
.24286 .28294 Mdot
.24476 .26554 Mdot
.24667 .25027 Mdot
.24857 .4028 Mdot
.25048 .39712 Mdot
.25238 .37322 Mdot
.25429 .41062 Mdot
.25619 .3005 Mdot
.2581 .40404 Mdot
.26 .42478 Mdot
.2619 .41438 Mdot
.26381 .34032 Mdot
.26571 .41676 Mdot
.26762 .22793 Mdot
.26952 .40021 Mdot
.27143 .28113 Mdot
.27333 .40745 Mdot
.27524 .3966 Mdot
.27714 .3429 Mdot
.27905 .34733 Mdot
.28095 .35514 Mdot
.28286 .42333 Mdot
.28476 .41837 Mdot
.28667 .41824 Mdot
.28857 .32661 Mdot
.29048 .35251 Mdot
.29238 .30604 Mdot
.29429 .22901 Mdot
.29619 .32891 Mdot
.2981 .31728 Mdot
.3 .3046 Mdot
.3019 .42377 Mdot
.30381 .39957 Mdot
.30571 .30034 Mdot
.30762 .26191 Mdot
.30952 .25238 Mdot
.31143 .34377 Mdot
.31333 .24814 Mdot
.31524 .32801 Mdot
.31714 .41229 Mdot
.31905 .30147 Mdot
.32095 .38026 Mdot
.32286 .40888 Mdot
.32476 .40044 Mdot
.32667 .39079 Mdot
.32857 .38808 Mdot
.33048 .41138 Mdot
.33238 .24938 Mdot
.33429 .42073 Mdot
.33619 .38091 Mdot
.3381 .39942 Mdot
.34 .36762 Mdot
.3419 .39528 Mdot
.34381 .39615 Mdot
.34571 .4159 Mdot
.34762 .30983 Mdot
.34952 .42143 Mdot
.35143 .40004 Mdot
.35333 .33547 Mdot
.35524 .29897 Mdot
.35714 .26092 Mdot
.35905 .27082 Mdot
.36095 .35046 Mdot
.36286 .22393 Mdot
.36476 .38091 Mdot
.36667 .26922 Mdot
.36857 .41505 Mdot
.37048 .42357 Mdot
.37238 .36486 Mdot
.37429 .34604 Mdot
.37619 .33027 Mdot
.3781 .29002 Mdot
.38 .34541 Mdot
.3819 .22383 Mdot
.38381 .39828 Mdot
.38571 .37722 Mdot
.38762 .34711 Mdot
.38952 .30764 Mdot
.39143 .42444 Mdot
.39333 .3093 Mdot
.39524 .25952 Mdot
.39714 .39547 Mdot
.39905 .346 Mdot
.40095 .34324 Mdot
.40286 .26592 Mdot
.40476 .2201 Mdot
.40667 .27581 Mdot
.40857 .26734 Mdot
.41048 .26749 Mdot
.41238 .29407 Mdot
.41429 .26394 Mdot
.41619 .21957 Mdot
.4181 .39655 Mdot
.42 .3087 Mdot
.4219 .36557 Mdot
.42381 .33288 Mdot
.42571 .27691 Mdot
.42762 .33316 Mdot
.42952 .40544 Mdot
.43143 .24988 Mdot
.43333 .4156 Mdot
.43524 .34146 Mdot
.43714 .39617 Mdot
.43905 .25109 Mdot
.44095 .37462 Mdot
.44286 .27381 Mdot
.44476 .38081 Mdot
.44667 .38678 Mdot
.44857 .2522 Mdot
.45048 .37819 Mdot
.45238 .41649 Mdot
.45429 .39912 Mdot
.45619 .33427 Mdot
.4581 .28279 Mdot
.46 .38777 Mdot
.4619 .3311 Mdot
.46381 .2962 Mdot
.46571 .3136 Mdot
.46762 .34368 Mdot
.46952 .31566 Mdot
.47143 .22635 Mdot
.47333 .26785 Mdot
.47524 .3165 Mdot
.47714 .29423 Mdot
.47905 .29825 Mdot
.48095 .38487 Mdot
.48286 .40949 Mdot
.48476 .39511 Mdot
.48667 .26518 Mdot
.48857 .3444 Mdot
.49048 .41837 Mdot
.49238 .26011 Mdot
.49429 .39298 Mdot
.49619 .32439 Mdot
.4981 .39223 Mdot
.5 .31137 Mdot
.5019 .25852 Mdot
.50381 .39702 Mdot
.50571 .33921 Mdot
.50762 .26524 Mdot
.50952 .32008 Mdot
.51143 .38382 Mdot
.51333 .24754 Mdot
.51524 .29658 Mdot
.51714 .31154 Mdot
.51905 .31361 Mdot
.52095 .37675 Mdot
.52286 .40101 Mdot
.52476 .25107 Mdot
.52667 .31744 Mdot
.52857 .40044 Mdot
.53048 .27139 Mdot
.53238 .25614 Mdot
.53429 .38891 Mdot
.53619 .31353 Mdot
.5381 .37342 Mdot
.54 .39898 Mdot
.5419 .25211 Mdot
.54381 .41229 Mdot
.54571 .32562 Mdot
.54762 .34508 Mdot
.54952 .26565 Mdot
.55143 .41304 Mdot
.55333 .34734 Mdot
.55524 .31177 Mdot
.55714 .38836 Mdot
.55905 .34139 Mdot
.56095 .37328 Mdot
.56286 .41695 Mdot
.56476 .26392 Mdot
.56667 .33401 Mdot
.56857 .3831 Mdot
.57048 .35037 Mdot
.57238 .31581 Mdot
.57429 .30203 Mdot
.57619 .25314 Mdot
.5781 .4223 Mdot
.58 .25509 Mdot
.5819 .40231 Mdot
.58381 .22239 Mdot
.58571 .38875 Mdot
.58762 .31181 Mdot
.58952 .37275 Mdot
.59143 .31582 Mdot
.59333 .40969 Mdot
.59524 .24633 Mdot
.59714 .42195 Mdot
.59905 .298 Mdot
.60095 .30841 Mdot
.60286 .25391 Mdot
.60476 .31923 Mdot
.60667 .3955 Mdot
.60857 .38698 Mdot
.61048 .31288 Mdot
.61238 .32836 Mdot
.61429 .38099 Mdot
.61619 .24744 Mdot
.6181 .26636 Mdot
.62 .4076 Mdot
.6219 .30639 Mdot
.62381 .41086 Mdot
.62571 .34237 Mdot
.62762 .26471 Mdot
.62952 .38435 Mdot
.63143 .33855 Mdot
.63333 .32056 Mdot
.63524 .26553 Mdot
.63714 .35734 Mdot
.63905 .26301 Mdot
.64095 .24324 Mdot
.64286 .34165 Mdot
.64476 .33856 Mdot
.64667 .3158 Mdot
.64857 .38898 Mdot
.65048 .29937 Mdot
.65238 .26809 Mdot
.65429 .30886 Mdot
.65619 .28151 Mdot
.6581 .39203 Mdot
.66 .37444 Mdot
.6619 .31265 Mdot
.66381 .40597 Mdot
.66571 .27647 Mdot
.66762 .29154 Mdot
.66952 .38955 Mdot
.67143 .35186 Mdot
.67333 .36726 Mdot
.67524 .24842 Mdot
.67714 .26238 Mdot
.67905 .22503 Mdot
.68095 .24982 Mdot
.68286 .4019 Mdot
.68476 .31703 Mdot
.68667 .36185 Mdot
.68857 .29657 Mdot
.69048 .41673 Mdot
.69238 .40376 Mdot
.69429 .31873 Mdot
.69619 .25166 Mdot
.6981 .23184 Mdot
.7 .36999 Mdot
.7019 .41738 Mdot
.70381 .40517 Mdot
.70571 .24746 Mdot
.70762 .29337 Mdot
.70952 .40432 Mdot
.71143 .26029 Mdot
.71333 .36718 Mdot
.71524 .26207 Mdot
.71714 .41863 Mdot
.71905 .33894 Mdot
.72095 .35438 Mdot
.72286 .35489 Mdot
.72476 .28562 Mdot
.72667 .26427 Mdot
.72857 .29896 Mdot
.73048 .38414 Mdot
.73238 .28475 Mdot
.73429 .40616 Mdot
.73619 .26306 Mdot
.7381 .35799 Mdot
.74 .39122 Mdot
.7419 .36502 Mdot
.74381 .38591 Mdot
.74571 .3988 Mdot
.74762 .37576 Mdot
.74952 .40381 Mdot
.75143 .42117 Mdot
.75333 .40659 Mdot
.75524 .29643 Mdot
.75714 .28175 Mdot
.75905 .36662 Mdot
.76095 .3753 Mdot
.76286 .28995 Mdot
.76476 .28264 Mdot
.76667 .25871 Mdot
.76857 .30961 Mdot
.77048 .37219 Mdot
.77238 .4146 Mdot
.77429 .27156 Mdot
.77619 .33848 Mdot
.7781 .252 Mdot
.78 .31202 Mdot
.7819 .40229 Mdot
.78381 .41845 Mdot
.78571 .2511 Mdot
.78762 .36432 Mdot
.78952 .31814 Mdot
.79143 .23395 Mdot
.79333 .30796 Mdot
.79524 .27662 Mdot
.79714 .28804 Mdot
.79905 .31704 Mdot
.80095 .38592 Mdot
.80286 .35896 Mdot
.80476 .29961 Mdot
.80667 .3286 Mdot
.80857 .34408 Mdot
.81048 .34624 Mdot
.81238 .33688 Mdot
.81429 .28128 Mdot
.81619 .40551 Mdot
.8181 .33637 Mdot
.82 .32287 Mdot
.8219 .27012 Mdot
.82381 .27861 Mdot
.82571 .33979 Mdot
.82762 .32879 Mdot
.82952 .31007 Mdot
.83143 .3216 Mdot
.83333 .35653 Mdot
.83524 .28442 Mdot
.83714 .32782 Mdot
.83905 .28046 Mdot
.84095 .38799 Mdot
.84286 .26615 Mdot
.84476 .30758 Mdot
.84667 .29711 Mdot
.84857 .22774 Mdot
.85048 .39154 Mdot
.85238 .26905 Mdot
.85429 .37434 Mdot
.85619 .30338 Mdot
.8581 .33523 Mdot
.86 .29247 Mdot
.8619 .31529 Mdot
.86381 .40261 Mdot
.86571 .22843 Mdot
.86762 .33139 Mdot
.86952 .2728 Mdot
.87143 .26309 Mdot
.87333 .40472 Mdot
.87524 .27126 Mdot
.87714 .22006 Mdot
.87905 .28702 Mdot
.88095 .35192 Mdot
.88286 .31599 Mdot
.88476 .3066 Mdot
.88667 .26774 Mdot
.88857 .34652 Mdot
.89048 .3965 Mdot
.89238 .26408 Mdot
.89429 .41948 Mdot
.89619 .39361 Mdot
.8981 .37898 Mdot
.9 .41534 Mdot
.9019 .40135 Mdot
.90381 .30806 Mdot
.90571 .24351 Mdot
.90762 .33905 Mdot
.90952 .3924 Mdot
.91143 .34721 Mdot
.91333 .30658 Mdot
.91524 .4134 Mdot
.91714 .25884 Mdot
.91905 .32138 Mdot
.92095 .41794 Mdot
.92286 .39064 Mdot
.92476 .30511 Mdot
.92667 .25077 Mdot
.92857 .33384 Mdot
.93048 .30607 Mdot
.93238 .36546 Mdot
.93429 .30833 Mdot
.93619 .35934 Mdot
.9381 .27706 Mdot
.94 .29481 Mdot
.9419 .33801 Mdot
.94381 .34894 Mdot
.94571 .34399 Mdot
.94762 .26506 Mdot
.94952 .24781 Mdot
.95143 .37793 Mdot
.95333 .29298 Mdot
.95524 .38816 Mdot
.95714 .33195 Mdot
.95905 .27218 Mdot
.96095 .28005 Mdot
.96286 .26609 Mdot
.96476 .27498 Mdot
.96667 .39349 Mdot
.96857 .3597 Mdot
.97048 .40239 Mdot
.97238 .30976 Mdot
.97429 .41712 Mdot
.97619 .36323 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo03Gooooo0_l00010ooooo`;o000000?oooooo`000?l00000Toooool2o`00
02_ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0eooooo`Co0000<?ooool2
o`0000Cooooo0_l00006ooooo`;o000000?oooooo`000?l00000=?ooool2o`0005gooooo0_l0000[
ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo03Oooooo0_l0
000Booooo`;o00007?ooool2o`0000Cooooo0_l0000Kooooo`;o00008_ooool2o`0001gooooo0_l0
000dooooo`;o0000=Oooool000Co00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04_ooooo0_l0
0006ooooo`;o0000=oooool2o`00047ooooo0_l0000dooooo`;o00001?ooool2o`0002oooooo0006
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol0001Cooooo`;o0000P?ooool2o`0001cooooo0_l0000Fooooo`;o0000;ooo
ool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0=Gooooo0_l0000Looooo`;o0000
Aoooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Mooooo`;o00003?ooool2o`0000cooooo
0_l0003oooooo`;ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zj
oooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Mooooo`;o
00003?ooool2o`0000cooooo0_l00028ooooo`;o0000Doooool2o`0002;ooooo0006ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006oooo
o`03o`000?oooooooooo01[ooooo0_l0002Hooooo`;o00003Oooool2o`0005?ooooo0_l0000Roooo
o`00:Oooool2o`0001_ooooo0_l0000mooooo`;o00001?ooool2o`0003Wooooo0_l0000Hooooo`;o
00001Oooool2o`00017ooooo0_l00008ooooo`;o0000C?ooool2o`0001Cooooo000Yooooo`03o`00
0?oooooooooo02cooooo0_l00004ooooo`;o00001oooool2o`0000Oooooo0_l0000Booooo`?o0000
1?ooool2o`0001kooooo0_l000001?oooooo0000o`000?ooool2o`0001?ooooo0_l000000ooooooo
0000o`000004ooooo`;o00005_ooool2o`00017ooooo1?l00002ooooo`;o00000_ooool2o`0001Go
oooo1?l0000/ooooo`;o00001Oooool2o`0001Cooooo000Yooooo`03o`000?oooooooooo02cooooo
0_l00004ooooo`;o00001_ooool3o`0000Oooooo0_l0000Booooo`;o00009Oooool2o`000004oooo
ool0003o0000ooooo`;o00005_ooool2o`0000Cooooo0_l00009ooooo`?o00001Oooool2o`0001So
oooo0_l00002ooooo`;o00006Oooool4o`0002cooooo0_l0000Kooooo`00:Oooool00ol0003ooooo
ooooo`0<ooooo`;o00005?ooool2o`0001Kooooo0_l0001Jooooo`;o00002?ooool2o`0000cooooo
0ol00005ooooo`;o0000<oooool2o`0002oooooo0_l0000Nooooo`00:Oooool00ol0003ooooooooo
o`0<ooooo`;o00005?ooool2o`0000Cooooo0_l0000^ooooo`;o00003Oooool2o`0000_ooooo0_l0
000Mooooo`;o000000?oooooo`000?l000002?ooool2o`0003Oooooo1?l0000>ooooo`;o0000;ooo
ool2o`0001kooooo000Yooooo`;o0000:Oooool2o`0002kooooo0_l0000=ooooo`;o00002oooool2
o`0000Cooooo0_l0000Eooooo`Co00000oooool2o`00013ooooo0_l0000Booooo`;o00000_ooool2
o`0000[ooooo0_l00009ooooo`Co000000Coooooo`000?l0003ooooo0_l0000Zooooo`;o00001Ooo
ool2o`0000oooooo0_l0000Eooooo`00:Oooool00ol0003oooooooooo`13ooooo`;o0000<Oooool6
o`00017ooooo0_l00002ooooo`;o00001Oooool2o`0000_ooooo0_l00003ooooo`;o00003oooool2
o`000004ooooool0003o0000ooooo`?o00000_ooool2o`0000Kooooo0_l0000>ooooo`;o000000?o
ooooo`000?l000008Oooool2o`0000Oooooo0_l00003ooooo`Co00003oooool2o`0000?ooooo0_l0
000@ooooo`00:Oooool00ol0003oooooooooo`0`ooooo`Go000000Ooooooo`000?l0003o<S8bo`00
0?lb<S;ok^k^00?ooooo00Cok^k^oc8b<_l0003o<S8b0_l0000Sooooo`;o000000?oooooo`000?l0
00001Ol00003ooooo`03onk^k_l0003o000000?o00000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo0_l0000@ooooo`;o00001?ooool2o`0000?ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko0000o`000?lb<S;ok^k^00;ooooo
0_l00003ooooo`;o00008Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Kok^k^oc8b<_l0003o<S8bonk^k_ooool2o`0000Gooooo0_l000000ooooooo0000
o`000005ooooo`;o00000_ooool2o`00017ooooo00GoA4A4o`000?l0003o<S8bomgMg@02o`000005
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Yoooo
o`03o`000?oooooooooo01Sooooo0_l00008ooooo`;o00003_ooool3o`000007ooooool0003o0000
oiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL09?ooool2o`000008oooo
ool0003o0000oiRHV?lQ8B7ok^k^oooooom4A4@3ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool01_mgMgOoV9RHoooooonHV9SoMgMgooooo`;o00006_ooool2o`0000Wooooo00Go410@okZj^_oo
ooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02_ooooo00Co0000oooooooooooooooo0_l000001?nHV9SooooooiRHV?mgMgL3ooooo`06
ogMgMonHV9SooooooiRHV?mgMgOooooo0_l00008ooooo`;o00000oooool4o`0001Sooooo00WoMgMg
o`000?l0003oooooogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo000Yooooo`03o`000?oooooooooo01Sooooo0_l00008ooooo`;o00003_ooool01_l0003o
ooooo`000?l0003ooooooa0@40?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oo
oooooooo02Sooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413oooooo`000?l0003o410@00?ooooo
0_l00002ooooo`04oa0@4?oooooo0000o`0002Wooooo00Go0000oooooooooooooooooa0@4003oooo
o`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`0:ooooo`;o00006_ooool5
o`0000;ooooo0_l00003ooooo`05oa0@4?l0003o0000ooooool@41000oooool00ol@413ooooooooo
o`0>ooooo`;o00005?ooool2o`0000Gooooo1?l00003ooooo`05oa0@4?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`01ooooo`00:Oooool2o`0003?ooooo00Ko0000ooooool0003o0000
ooooool00003ooooo`03o`000?oooooooooo00;o00000oooool00ol0003oooooooooo`0Yooooo`03
oiRHV?lQ8B7ok^k^00?ooooo00?o0000ooooool000000_l00003ooooo`;o00000_ooool00ol0003o
ooooooooo`0Yooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000003?ooool2o`0001[ooooo00CoA4A4omgMgOoooooo00001?oo
ool01?l0003oooooooooooooool3o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
0_l00002ooooo`;o00007_ooool2o`0000Cooooo00?oMgMgoc8b<_l000000_l00003ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`01ooooo`00:Oooool01?l0003ooooo
o`000?l0000aooooo`;o00000oooool01Ol0003ooooooooooooooooo000000;ooooo0_l00003oooo
o`;o00001oooool2o`0002;ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000006ooooo`;o00008_ooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Wo
oooo0_l0000Mooooo`03omgMgOl0003o000000?o00000_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool00_l00002ooooo`;o00000_ooool2o`00027ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c003o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo007ooooo000Yooooo`04o`000?oooooo0000o`0002cooooo0_l00003ooooo`;o00000ooo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Co410@oooooooooooooooo0_l00007ooooo`;o
00008oooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo00Cooooo0_l0000Sooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@
oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002Oooool2o`0001Cooooo
1?l00006ooooo`Go00000_ooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooooooo
ool00_l00005ooooo`;o00003?ooool2o`0001Cooooo00?o0000ooooooooool01?ooool01Ol@413o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`00:Oooool00ol0
003oooooooooo`0<ooooo`;o00007oooool2o`0000?ooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Yooooo`?o000000?o
V9RHoa0@4?ooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Xooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Oooooo`Co00001_ooool01?o^k^koA4A4o`00
0?l00003ooooo`06ogMgMonHV9SooooooiRHV?mgMgOooooo0_l000001OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_l0000<ooooo`;o00005?ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000Yooooo`03o`000?oo
oooooooo00cooooo0_l00006ooooo`;o00002_ooool2o`0000kooooo00?oEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Yooooo`05
oiRHV?l0003o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0Xooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`;o00007?ooool00omg
MgOo0000o`000003ooooo`06onk^k_lb<S;o0000oc8b<_o^k^kooooo0_l000001Oo^k^ko<S8bo`00
0?lb<S;ok^k^00gooooo0_l0000Jooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool3o`0000Gooooo0_l00006ooooo`;o
00001Oooool2o`0000[ooooo0_l0001Gooooo`;o00003oooool2o`0000;ooooo0_l0000kooooo`;o
00002oooool2o`0002oooooo0_l0000Hooooo`;o00000_ooool2o`0001?ooooo000Yooooo`?o0000
1Oooool2o`0000Kooooo0_l0000Iooooo`;o0000?Oooool2o`00013ooooo0_l0000?ooooo`;o0000
0_ooool3o`0000Wooooo0_l0000Iooooo`;o00003oooool2o`0000[ooooo0_l00004ooooo`;o0000
1Oooool2o`0000Kooooo0_l0000Looooo`;o00007?ooool2o`0001Oooooo000Yooooo`04o`000?oo
ooooooooooooo`;o00002_ooool2o`0001Wooooo0_l0000Mooooo`;o00003_ooool2o`0000;ooooo
0_l0000:ooooo`;o00009_ooool2o`0000Wooooo0_l0000Aooooo`;o00001_ooool2o`0000oooooo
0_l0000:ooooo`;o00002oooool2o`0000Kooooo0_l0000>ooooo`;o00003?ooool2o`0003Gooooo
000Yooooo`04o`000?ooooooooooooooo`;o0000A?ooool2o`0000cooooo1?l00002ooooo`;o0000
D?ooool2o`0004Sooooo0_l0000?ooooo`;o00005?ooool2o`0001cooooo000Yooooo`03o`000?oo
oooooooo00Oooooo0_l0000Jooooo`;o0000;_ooool4o`0001_ooooo0_l00008ooooo`;o0000>?oo
ool2o`0000Gooooo0_l0000eooooo`;o00003_ooool2o`0000;ooooo0_l00007ooooo`;o00001?oo
ool2o`000003ooooool0003o000000;ooooo1Ol0000Iooooo`008Oooooooo`0004Co00001?ooool0
02Wooooo00?o0000ooooooooool02?ooool2o`0000cooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`02ooooo`;o00000_ooool2o`000003ooooool0003ooooo00[ooooo00Co0000oooo
oooooooooooo0ol00006ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`02ooooo`;o00001Oooool00ol0003oooooooooo`05ooooo`;o00000oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03o`000?oooooo
oooo00;ooooo0_l00004ooooo`?o00000oooool2o`0000Cooooo0ol00008ooooo`;o000000?ooooo
o`000?ooool00_ooool2o`0000Kooooo00?o0000ooooooooool00oooool4o`0000;ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo0_l00000
1Ooooooo0000o`000?oooooo000000_ooooo0ol0000:ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`?o00003?ooool002Wooooo00?o0000
ooooooooool02?ooool2o`00027ooooo0_l00008ooooo`?o00000_ooool01?l0003ooooooooooooo
ool3o`0001?ooooo0_l0000Rooooo`03o`000?oooooooooo00oooooo1Ol0000=ooooo`Co000000?o
ooooo`000?l000002_ooool2o`0000Cooooo0ol00003ooooo`;o00002_ooool2o`0000;ooooo0_l0
0006ooooo`;o00007?ooool2o`000003ooooool0003o000000;ooooo0_l0000Booooo`;o00001?oo
ool2o`0001gooooo00?o0000ooooooooool02_ooool002Wooooo00?o0000ooooooooool0=Oooool3
o`0001cooooo0_l0000fooooo`?o00002Oooool2o`0000Cooooo0_l0000=ooooo`;o00001?ooool2
o`0000;ooooo0_l00007ooooo`;o00000oooool2o`0000[ooooo0_l000000ooooooo0000o`00000L
ooooo`;o00000_ooool2o`0001;ooooo0_l00004ooooo`;o0000:_ooool002Wooooo00?o0000oooo
ooooool09?ooool2o`0000[ooooo0_l0001Vooooo`;o00007Oooool2o`0000Oooooo0_l0000Boooo
o`;o00009_ooool2o`0000;ooooo0_l0000Jooooo`;o00007_ooool002Wooooo0_l00004ooooo`;o
00003Oooool2o`0000Gooooo0_l00009ooooo`;o00002_ooool2o`0001oooooo0_l00011ooooo`;o
00003_ooool2o`0005Kooooo0_l00002ooooo`;o00006_ooool2o`0001kooooo000Yooooo`03o`00
0?oooooooooo00?ooooo0_l0000=ooooo`;o00000_ooool2o`000003ooooool0003o000000?ooooo
0_l00009ooooo`;o00009_ooool2o`000003ooooool0003o000000Cooooo0_l0000Booooo`;o0000
9?ooool2o`0000kooooo0_l0000Dooooo`;o0000??ooool2o`0000Gooooo0_l000000ooooooo0000
o`00000hooooo`00:Oooool00ol0003oooooooooo`0Eooooo`?o00001_ooool2o`0000Wooooo0_l0
000Yooooo`;o00001?ooool2o`0001;ooooo0_l0000=ooooo`?o00002Oooool2o`0002oooooo0_l0
000looooo`;o00001Oooool2o`000003ooooool0003o000000Sooooo0_l0000Jooooo`;o00004_oo
ool002Wooooo00?o0000ooooooooool05Oooool2o`0000kooooo0_l0000<ooooo`;o0000<Oooool2
o`0001Gooooo0ol00007ooooo`Co00008?ooool2o`0004oooooo0_l0000;ooooo`;o000000?ooooo
o`000?l000004Oooool2o`0000Oooooo0_l0000Booooo`00:Oooool00ol0003oooooooooo`02oooo
o`;o00008Oooool3o`0000Oooooo0_l00002ooooo`;o00001_ooool2o`0000Cooooo0_l0000Soooo
o`;o00007oooool2o`0000kooooo0_l0000Booooo`;o00004oooool2o`0000;ooooo0_l0000Foooo
o`;o00004?ooool2o`0000[ooooo1_l00009ooooo`;o00003Oooool2o`0000Gooooo0_l00002oooo
o`;o00005oooool002Wooooo1?l000000ooooooo0000o`00000=ooooo`;o00004oooool2o`0000;o
oooo0_l00003ooooo`;o00002_ooool4o`0000;ooooo0_l00006ooooo`;o00000oooool2o`00037o
oooo0_l0000Dooooo`;o00003oooool2o`0001Cooooo1?l000001?oooooo0000o`000?l0000Foooo
o`;o00004?ooool2o`0000[ooooo0_l00002ooooo`;o00006?ooool2o`0000Wooooo0_l0000Goooo
o`00:Oooool01?l0003oooooo`000?l00004ooooo`?o00002Oooool2o`0001Oooooo0_l00005oooo
o`;o00001Oooool2o`0000?ooooo0_l000000ooooooo0000o`000007ooooo`;o00000oooool2o`00
00Wooooo0_l0000Booooo`Co00001?ooool3o`0000Wooooo0_l00008ooooo`;o00001Oooool2o`00
017ooooo0_l000000ooooooo0000o`00000Dooooo`;o00000oooool2o`0003Cooooo0_l0000Zoooo
o`;o00005Oooool002Wooooo00?o0000ooooooooool01Oooool3o`0002Wooooo0_l00005ooooo`;o
00001_ooool2o`0000cooooo0_l00009ooooo`;o00004_ooool6o`0000;ooooo0ol0000Cooooo`;o
00001Oooool2o`00017ooooo1?l0001@ooooo`;o00005oooool2o`0000Kooooo0_l00008ooooo`?o
00005Oooool002Wooooo00?o0000ooooooooool05oooool2o`0003Gooooo0_l0000Iooooo`;o0000
1_ooool2o`0003Cooooo0_l00003ooooo`;o00007oooool2o`0002[ooooo0_l0000Eooooo`Co0000
1_ooool2o`0000Sooooo0_l0000Fooooo`00:Oooool00ol0003oooooooooo`0Gooooo`;o00001?oo
ool2o`00033ooooo0_l000000ooooooo0000o`00000Eooooo`;o0000@Oooool2o`0001oooooo0_l0
000=ooooo`?o0000<Oooool2o`0002[ooooo000Yooooo`;o000000?oooooo`000?l000006oooool2
o`00033ooooo0_l000000ooooooo0000o`00001]ooooo`;o00006Oooool3o`0000?ooooo0_l0000M
ooooo`;o0000>Oooool002Wooooo00?o0000ooooooooool01_l0000Iooooo`;o0000X?ooool2o`00
01oooooo0_l0000Cooooo`;o00002?ooool2o`0001oooooo0_l00008ooooo`;o00003_ooool002Wo
oooo00?o0000ooooooooool00_ooool4o`0001Wooooo0_l0002`ooooo`;o00007oooool2o`0000?o
oooo0_l0000Yooooo`;o00002?ooool2o`000003ooooool0003o000000_ooooo000Yooooo`03o`00
0?oooooooooo027ooooo0_l0000oooooo`;o00002?ooool2o`0000kooooo0_l0001?ooooo`;o0000
0_ooool2o`0000Oooooo0_l00007ooooo`;o00001?ooool2o`0000Oooooo0_l0000/ooooo`;o0000
3Oooool2o`0000_ooooo000Yooooo`03o`000?oooooooooo01Sooooo0_l00007ooooo`;o00005Ooo
ool2o`0002Sooooo0_l00008ooooo`;o00003_ooool2o`0004oooooo0_l00007ooooo`;o00000_oo
ool2o`0000Oooooo0_l00004ooooo`;o0000=Oooool2o`0001[ooooo000Yooooo`;o00004Oooool2
o`0000Kooooo0_l0000Nooooo`;o00003?ooool2o`0005[ooooo0_l00005ooooo`;o00001oooool2
o`0002;ooooo0_l0000Dooooo`;o0000C_ooool002Wooooo00?o0000ooooooooool04?ooool2o`00
00?ooooo1?l0000Xooooo`;o00000oooool2o`0002Wooooo0_l0000?ooooo`;o00006?ooool2o`00
00Cooooo0_l00005ooooo`;o00001oooool2o`0001Gooooo0_l0000Jooooo`;o00000_ooool2o`00
0003ooooool0003o000001Wooooo0_l0000cooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool04?ooool2o`0000?ooooo1?l0000<ooooo`;o00006_ooool2o`0001Wooooo0_l0000C
ooooo`;o00003oooool2o`000003ooooool0003o000001Gooooo0_l0000[ooooo`;o00006_ooool2
o`0000;ooooo0_l0000Looooo`;o00003?ooool2o`00013ooooo0_l0000Cooooo`001_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo013ooooo0_l0000Cooooo`;o0000=Ooo
ool2o`0000?ooooo0_l00007ooooo`;o00006?ooool3o`0002Cooooo0_l0000=ooooo`;o0000FOoo
ool2o`00013ooooo0_l0000Cooooo`001_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03cooooo0_l0
000Sooooo`;o00001oooool2o`0001Sooooo0_l00009ooooo`;o00002?ooool2o`00013ooooo0_l0
000=ooooo`;o00000oooool2o`0001kooooo0_l00003ooooo`;o00004?ooool2o`0004Cooooo0006
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol0000Oooooo`;o00006oooool2o`00023ooooo0_l0000Tooooo`;o00000ooo
ool2o`0000Cooooo0_l00008ooooo`;o00001Oooool2o`0000Kooooo0_l00007ooooo`;o00001Ooo
ool2o`0000Gooooo0_l00004ooooo`;o00001Oooool2o`00017ooooo0_l00003ooooo`;o00004?oo
ool2o`0000_ooooo0_l0000Sooooo`;o00004_ooool000Kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`;o0000
8?ooool2o`0000;ooooo0_l00005ooooo`;o00003_ooool2o`0002;ooooo0_l0000Tooooo`;o0000
0oooool2o`0000[ooooo0_l00009ooooo`;o00001_ooool2o`0000Oooooo0_l00005ooooo`;o0000
2oooool2o`000003ooooool0003o000000;ooooo0_l0000Eooooo`;o00007_ooool2o`000003oooo
ool0003o0000017ooooo0_l00002ooooo`;o00002Oooool2o`0001;ooooo0006ooooo`05oa0@4?oo
ooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool04oooool2o`0000Oooooo0_l00005ooooo`;o00001Oooool2o`0000kooooo
0_l0000Rooooo`;o00000oooool2o`0000oooooo0_l0000Jooooo`;o00000_ooool3o`00027ooooo
0_l0000>ooooo`;o00006Oooool2o`00027ooooo0_l0000=ooooo`;o00000_ooool2o`0000;ooooo
0_l0000<ooooo`;o00003oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`;o00005?ooool2o`0000Oo
oooo0_l0000Booooo`;o00004oooool2o`0000Kooooo0_l0000Dooooo`;o00002oooool2o`0000;o
oooo0_l00005ooooo`;o00001?ooool2o`0000gooooo0_l00002ooooo`;o000000?oooooo`000?l0
00002Oooool2o`0001Cooooo0_l0000Zooooo`;o0000;Oooool4o`0001Cooooo0_l0000?ooooo`00
1_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co00001_ooool2o`0000;ooooo0_l0000<ooooo`;o00000oooool2o`0000Cooooo0_l00004oooo
o`;o00003_ooool2o`0001?ooooo0_l00004ooooo`Co00001oooool2o`0000Gooooo0_l00002oooo
o`Co000000?oooooo`000?l000002?ooool2o`0000Wooooo0_l00004ooooo`;o00001?ooool2o`00
00kooooo0_l00004ooooo`Co000000?oooooo`000?l00000;?ooool2o`0001;ooooo0_l0000]oooo
o`;o00000_ooool2o`0002?ooooo000Yooooo`;o00000_ooool2o`0000Oooooo0_l00003ooooo`;o
000000?oooooo`000?l000000_l00004ooooo`;o00001?ooool2o`0000cooooo0_l0000Eooooo`;o
000000Coooooo`000?l0003ooooo0_l00009ooooo`;o00001Oooool2o`0000;ooooo0_l00003oooo
o`;o00007oooool2o`0001Cooooo1?l0000?ooooo`;o00007_ooool2o`000003ooooool0003o0000
00;ooooo1?l0000;ooooo`;o00002?ooool2o`0001Sooooo0_l000000ooooooo0000o`000008oooo
o`;o00005?ooool2o`0000gooooo000Yooooo`03o`000?oooooooooo00[ooooo0_l00003ooooo`;o
000000?oooooo`000?l000006_ooool2o`0001Gooooo0_l000000ooooooo0000o`000003ooooo`;o
0000<?ooool2o`0002oooooo0_l0000:ooooo`;o00003?ooool2o`0000Oooooo0_l00002ooooo`Co
00001_ooool2o`0000?ooooo0ol00007ooooo`;o00002Oooool2o`0000gooooo0_l000000ooooooo
0000o`00000Nooooo`;o00003Oooool002Wooooo00?o0000ooooooooool01?ooool2o`000004oooo
ool0003o0000ooooo`;o00003oooool2o`0002Wooooo0_l00005ooooo`;o00003Oooool2o`000003
ooooool0003o000001kooooo0_l0000?ooooo`;o00008Oooool2o`0000Oooooo0ol0000;ooooo`;o
00005Oooool2o`0000Cooooo0_l0000Booooo`;o0000?oooool002Wooooo00?o0000ooooooooool0
1?ooool2o`000003ooooool0003o000000Co00003_ooool3o`0000Wooooo0_l0000Dooooo`;o0000
00?oooooo`000?l000001?ooool2o`000003ooooool0003o0000013ooooo0ol000000ooooooo0000
o`00000_ooooo`;o00004Oooool2o`000003ooooool0003o000000_ooooo0_l00008ooooo`;o0000
G?ooool2o`0001oooooo000Yooooo`03o`000?oooooooooo00Wooooo1?l0000?ooooo`;o00002Ooo
ool2o`0000Cooooo0_l0000>ooooo`;o000000?oooooo`000?l000001oooool3o`0000oooooo0_l0
0007ooooo`;o00001Oooool2o`0001?ooooo0_l00004ooooo`;o00006oooool2o`000003ooooool0
003o000000;ooooo0_l0000Wooooo`;o000000?oooooo`000?l000005Oooool2o`0002Oooooo0_l0
0003ooooo`;o00004Oooool2o`0000cooooo000Yooooo`;o0000;_ooool2o`0001?ooooo0_l00006
ooooo`;o00001?ooool3o`0000gooooo0_l00002ooooo`;o00001Oooool2o`0001?ooooo0_l00004
ooooo`;o00002_ooool2o`0001Kooooo0_l0000Wooooo`;o000000?oooooo`000?l000000oooool2
o`00013ooooo0_l00002ooooo`;o00008Oooool4o`0000Gooooo0_l0000?ooooo`;o00003?ooool0
02Wooooo00?o0000ooooooooool03_ooool2o`0003;ooooo0_l0000<ooooo`?o00000oooool2o`00
00Sooooo0_l00003ooooo`;o00001Oooool2o`0002Cooooo0_l0000Jooooo`;o00001Oooool2o`00
02Cooooo0_l00009ooooo`;o00002Oooool2o`00027ooooo0_l00007ooooo`;o00007Oooool002Wo
oooo00?o0000ooooooooool02Oooool2o`0000?ooooo0_l0000hooooo`;o00001_ooool2o`0000Co
oooo0_l0000=ooooo`;o00001Oooool2o`0000Cooooo0_l0000jooooo`;o00001Oooool2o`0002oo
oooo0_l0001Dooooo`00:Oooool00ol0003oooooooooo`09ooooo`;o0000?Oooool2o`0002Sooooo
0_l00038ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000ooooooln
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000kooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00?ooooo0ol0003oooooocgooooo000>ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`3oooooocgooooo000>ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`003_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGo
oooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000Kooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`3oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool0
0omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgoooo
o`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Oooooo`Co000000?o410@ooooooooool00oooool00ol0
003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`?o0000oooooolmooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Oooooo`03oeEEEOmVIVKo00000?ooooooAoooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .32883 Mdot
.02762 .34256 Mdot
.02952 .27486 Mdot
.03143 .31494 Mdot
.03333 .34609 Mdot
.03524 .27696 Mdot
.03714 .31962 Mdot
.03905 .44618 Mdot
.04095 .42325 Mdot
.04286 .34518 Mdot
.04476 .35152 Mdot
.04667 .43017 Mdot
.04857 .36405 Mdot
.05048 .34531 Mdot
.05238 .39261 Mdot
.05429 .32608 Mdot
.05619 .24487 Mdot
.0581 .36473 Mdot
.06 .35541 Mdot
.0619 .41165 Mdot
.06381 .38952 Mdot
.06571 .37318 Mdot
.06762 .39251 Mdot
.06952 .37546 Mdot
.07143 .39044 Mdot
.07333 .33041 Mdot
.07524 .34612 Mdot
.07714 .34815 Mdot
.07905 .41916 Mdot
.08095 .36164 Mdot
.08286 .40527 Mdot
.08476 .43235 Mdot
.08667 .43375 Mdot
.08857 .26275 Mdot
.09048 .2484 Mdot
.09238 .41875 Mdot
.09429 .43094 Mdot
.09619 .34547 Mdot
.0981 .4253 Mdot
.1 .43924 Mdot
.1019 .41706 Mdot
.10381 .25084 Mdot
.10571 .27097 Mdot
.10762 .3007 Mdot
.10952 .29273 Mdot
.11143 .3418 Mdot
.11333 .34955 Mdot
.11524 .43774 Mdot
.11714 .29952 Mdot
.11905 .42325 Mdot
.12095 .43544 Mdot
.12286 .42828 Mdot
.12476 .25705 Mdot
.12667 .27358 Mdot
.12857 .24871 Mdot
.13048 .42606 Mdot
.13238 .44236 Mdot
.13429 .24637 Mdot
.13619 .43495 Mdot
.1381 .28806 Mdot
.14 .33039 Mdot
.1419 .38533 Mdot
.14381 .42388 Mdot
.14571 .26161 Mdot
.14762 .40762 Mdot
.14952 .43352 Mdot
.15143 .34629 Mdot
.15333 .33486 Mdot
.15524 .35299 Mdot
.15714 .38717 Mdot
.15905 .26466 Mdot
.16095 .32291 Mdot
.16286 .34807 Mdot
.16476 .3415 Mdot
.16667 .42381 Mdot
.16857 .28291 Mdot
.17048 .25643 Mdot
.17238 .28623 Mdot
.17429 .42656 Mdot
.17619 .25079 Mdot
.1781 .41216 Mdot
.18 .36643 Mdot
.1819 .31816 Mdot
.18381 .24719 Mdot
.18571 .44376 Mdot
.18762 .30681 Mdot
.18952 .34596 Mdot
.19143 .31614 Mdot
.19333 .25726 Mdot
.19524 .33701 Mdot
.19714 .382 Mdot
.19905 .30193 Mdot
.20095 .26326 Mdot
.20286 .33872 Mdot
.20476 .26577 Mdot
.20667 .32953 Mdot
.20857 .34515 Mdot
.21048 .42621 Mdot
.21238 .25667 Mdot
.21429 .27445 Mdot
.21619 .34042 Mdot
.2181 .27596 Mdot
.22 .41922 Mdot
.2219 .31594 Mdot
.22381 .40152 Mdot
.22571 .2638 Mdot
.22762 .24992 Mdot
.22952 .35617 Mdot
.23143 .26293 Mdot
.23333 .39297 Mdot
.23524 .34326 Mdot
.23714 .30016 Mdot
.23905 .43039 Mdot
.24095 .41305 Mdot
.24286 .22157 Mdot
.24476 .30747 Mdot
.24667 .31526 Mdot
.24857 .4433 Mdot
.25048 .4405 Mdot
.25238 .42312 Mdot
.25429 .36968 Mdot
.25619 .40231 Mdot
.2581 .39978 Mdot
.26 .41755 Mdot
.2619 .39024 Mdot
.26381 .32418 Mdot
.26571 .41752 Mdot
.26762 .33921 Mdot
.26952 .37054 Mdot
.27143 .2701 Mdot
.27333 .38276 Mdot
.27524 .35249 Mdot
.27714 .42183 Mdot
.27905 .26173 Mdot
.28095 .27447 Mdot
.28286 .42214 Mdot
.28476 .43266 Mdot
.28667 .41955 Mdot
.28857 .34793 Mdot
.29048 .42433 Mdot
.29238 .40017 Mdot
.29429 .33719 Mdot
.29619 .2761 Mdot
.2981 .35542 Mdot
.3 .24463 Mdot
.3019 .41121 Mdot
.30381 .44362 Mdot
.30571 .21658 Mdot
.30762 .32782 Mdot
.30952 .3178 Mdot
.31143 .4279 Mdot
.31333 .28577 Mdot
.31524 .35515 Mdot
.31714 .371 Mdot
.31905 .32257 Mdot
.32095 .32 Mdot
.32286 .43118 Mdot
.32476 .42627 Mdot
.32667 .43906 Mdot
.32857 .42875 Mdot
.33048 .43165 Mdot
.33238 .31913 Mdot
.33429 .42526 Mdot
.33619 .44345 Mdot
.3381 .41677 Mdot
.34 .29944 Mdot
.3419 .35381 Mdot
.34381 .44211 Mdot
.34571 .40163 Mdot
.34762 .35235 Mdot
.34952 .43051 Mdot
.35143 .42167 Mdot
.35333 .29708 Mdot
.35524 .34802 Mdot
.35714 .33001 Mdot
.35905 .33659 Mdot
.36095 .42261 Mdot
.36286 .32997 Mdot
.36476 .32224 Mdot
.36667 .28448 Mdot
.36857 .42337 Mdot
.37048 .42786 Mdot
.37238 .43401 Mdot
.37429 .3301 Mdot
.37619 .41677 Mdot
.3781 .26483 Mdot
.38 .41634 Mdot
.3819 .32806 Mdot
.38381 .43951 Mdot
.38571 .44135 Mdot
.38762 .2638 Mdot
.38952 .40602 Mdot
.39143 .40995 Mdot
.39333 .26256 Mdot
.39524 .37321 Mdot
.39714 .4438 Mdot
.39905 .42684 Mdot
.40095 .42151 Mdot
.40286 .33605 Mdot
.40476 .31722 Mdot
.40667 .25109 Mdot
.40857 .29027 Mdot
.41048 .28954 Mdot
.41238 .32295 Mdot
.41429 .33272 Mdot
.41619 .30652 Mdot
.4181 .35558 Mdot
.42 .26358 Mdot
.4219 .28924 Mdot
.42381 .28117 Mdot
.42571 .27124 Mdot
.42762 .35201 Mdot
.42952 .35551 Mdot
.43143 .29288 Mdot
.43333 .40249 Mdot
.43524 .3364 Mdot
.43714 .35722 Mdot
.43905 .2895 Mdot
.44095 .44052 Mdot
.44286 .27465 Mdot
.44476 .31726 Mdot
.44667 .443 Mdot
.44857 .32018 Mdot
.45048 .42829 Mdot
.45238 .39767 Mdot
.45429 .41445 Mdot
.45619 .34018 Mdot
.4581 .34561 Mdot
.46 .32042 Mdot
.4619 .28321 Mdot
.46381 .39397 Mdot
.46571 .41082 Mdot
.46762 .31713 Mdot
.46952 .30622 Mdot
.47143 .27846 Mdot
.47333 .25979 Mdot
.47524 .35165 Mdot
.47714 .3979 Mdot
.47905 .34814 Mdot
.48095 .31766 Mdot
.48286 .3902 Mdot
.48476 .34787 Mdot
.48667 .37841 Mdot
.48857 .25958 Mdot
.49048 .40262 Mdot
.49238 .2645 Mdot
.49429 .43811 Mdot
.49619 .27294 Mdot
.4981 .42773 Mdot
.5 .24627 Mdot
.5019 .26634 Mdot
.50381 .42523 Mdot
.50571 .42273 Mdot
.50762 .30598 Mdot
.50952 .26981 Mdot
.51143 .42599 Mdot
.51333 .3069 Mdot
.51524 .34692 Mdot
.51714 .24147 Mdot
.51905 .28442 Mdot
.52095 .43658 Mdot
.52286 .43688 Mdot
.52476 .28126 Mdot
.52667 .35182 Mdot
.52857 .41521 Mdot
.53048 .27976 Mdot
.53238 .27149 Mdot
.53429 .33512 Mdot
.53619 .34838 Mdot
.5381 .3089 Mdot
.54 .42006 Mdot
.5419 .28253 Mdot
.54381 .41792 Mdot
.54571 .24625 Mdot
.54762 .3412 Mdot
.54952 .26255 Mdot
.55143 .4311 Mdot
.55333 .32644 Mdot
.55524 .35721 Mdot
.55714 .43432 Mdot
.55905 .35013 Mdot
.56095 .30398 Mdot
.56286 .4241 Mdot
.56476 .2936 Mdot
.56667 .34344 Mdot
.56857 .4271 Mdot
.57048 .42457 Mdot
.57238 .35709 Mdot
.57429 .32139 Mdot
.57619 .31465 Mdot
.5781 .40538 Mdot
.58 .32389 Mdot
.5819 .41135 Mdot
.58381 .32171 Mdot
.58571 .43138 Mdot
.58762 .40288 Mdot
.58952 .42549 Mdot
.59143 .31021 Mdot
.59333 .43595 Mdot
.59524 .35985 Mdot
.59714 .40014 Mdot
.59905 .39482 Mdot
.60095 .21554 Mdot
.60286 .27724 Mdot
.60476 .24277 Mdot
.60667 .34689 Mdot
.60857 .43584 Mdot
.61048 .40592 Mdot
.61238 .3502 Mdot
.61429 .43139 Mdot
.61619 .308 Mdot
.6181 .29747 Mdot
.62 .36513 Mdot
.6219 .24452 Mdot
.62381 .37476 Mdot
.62571 .4267 Mdot
.62762 .29607 Mdot
.62952 .32502 Mdot
.63143 .25877 Mdot
.63333 .40625 Mdot
.63524 .29033 Mdot
.63714 .43027 Mdot
.63905 .37429 Mdot
.64095 .35976 Mdot
.64286 .3251 Mdot
.64476 .25269 Mdot
.64667 .24406 Mdot
.64857 .42443 Mdot
.65048 .35369 Mdot
.65238 .31055 Mdot
.65429 .31679 Mdot
.65619 .24905 Mdot
.6581 .44452 Mdot
.66 .42246 Mdot
.6619 .26241 Mdot
.66381 .36176 Mdot
.66571 .27342 Mdot
.66762 .32257 Mdot
.66952 .32426 Mdot
.67143 .26808 Mdot
.67333 .29856 Mdot
.67524 .31628 Mdot
.67714 .33086 Mdot
.67905 .27885 Mdot
.68095 .28905 Mdot
.68286 .37223 Mdot
.68476 .26598 Mdot
.68667 .42752 Mdot
.68857 .34547 Mdot
.69048 .41953 Mdot
.69238 .38085 Mdot
.69429 .26493 Mdot
.69619 .28924 Mdot
.6981 .34273 Mdot
.7 .43502 Mdot
.7019 .43648 Mdot
.70381 .41921 Mdot
.70571 .29367 Mdot
.70762 .24455 Mdot
.70952 .4213 Mdot
.71143 .26672 Mdot
.71333 .4336 Mdot
.71524 .37836 Mdot
.71714 .40326 Mdot
.71905 .41952 Mdot
.72095 .42887 Mdot
.72286 .43063 Mdot
.72476 .32165 Mdot
.72667 .26327 Mdot
.72857 .39586 Mdot
.73048 .44004 Mdot
.73238 .32155 Mdot
.73429 .40818 Mdot
.73619 .26704 Mdot
.7381 .27586 Mdot
.74 .33802 Mdot
.7419 .42487 Mdot
.74381 .32027 Mdot
.74571 .4327 Mdot
.74762 .42183 Mdot
.74952 .39248 Mdot
.75143 .43533 Mdot
.75333 .38498 Mdot
.75524 .39543 Mdot
.75714 .22158 Mdot
.75905 .42114 Mdot
.76095 .30712 Mdot
.76286 .32113 Mdot
.76476 .38836 Mdot
.76667 .26726 Mdot
.76857 .31614 Mdot
.77048 .43793 Mdot
.77238 .38817 Mdot
.77429 .31555 Mdot
.77619 .3437 Mdot
.7781 .32177 Mdot
.78 .35098 Mdot
.7819 .43892 Mdot
.78381 .38764 Mdot
.78571 .36522 Mdot
.78762 .4339 Mdot
.78952 .24632 Mdot
.79143 .26293 Mdot
.79333 .24383 Mdot
.79524 .34054 Mdot
.79714 .34752 Mdot
.79905 .29095 Mdot
.80095 .44162 Mdot
.80286 .42948 Mdot
.80476 .34676 Mdot
.80667 .27705 Mdot
.80857 .35195 Mdot
.81048 .31583 Mdot
.81238 .42268 Mdot
.81429 .34715 Mdot
.81619 .41597 Mdot
.8181 .29358 Mdot
.82 .35459 Mdot
.8219 .2811 Mdot
.82381 .34501 Mdot
.82571 .26105 Mdot
.82762 .35427 Mdot
.82952 .2639 Mdot
.83143 .4151 Mdot
.83333 .42633 Mdot
.83524 .28133 Mdot
.83714 .24858 Mdot
.83905 .24932 Mdot
.84095 .34072 Mdot
.84286 .26369 Mdot
.84476 .35122 Mdot
.84667 .39806 Mdot
.84857 .34102 Mdot
.85048 .33344 Mdot
.85238 .22829 Mdot
.85429 .2965 Mdot
.85619 .26181 Mdot
.8581 .41166 Mdot
.86 .39194 Mdot
.8619 .35022 Mdot
.86381 .3855 Mdot
.86571 .27151 Mdot
.86762 .28218 Mdot
.86952 .31621 Mdot
.87143 .33002 Mdot
.87333 .41432 Mdot
.87524 .25871 Mdot
.87714 .31034 Mdot
.87905 .26559 Mdot
.88095 .27319 Mdot
.88286 .24444 Mdot
.88476 .26063 Mdot
.88667 .28667 Mdot
.88857 .33279 Mdot
.89048 .44515 Mdot
.89238 .30172 Mdot
.89429 .42472 Mdot
.89619 .33557 Mdot
.8981 .31087 Mdot
.9 .41737 Mdot
.9019 .41025 Mdot
.90381 .24437 Mdot
.90571 .36232 Mdot
.90762 .34385 Mdot
.90952 .44483 Mdot
.91143 .42723 Mdot
.91333 .34673 Mdot
.91524 .43637 Mdot
.91714 .27162 Mdot
.91905 .24888 Mdot
.92095 .41865 Mdot
.92286 .33528 Mdot
.92476 .35296 Mdot
.92667 .29211 Mdot
.92857 .255 Mdot
.93048 .40688 Mdot
.93238 .29314 Mdot
.93429 .27661 Mdot
.93619 .28333 Mdot
.9381 .25457 Mdot
.94 .32377 Mdot
.9419 .33329 Mdot
.94381 .26817 Mdot
.94571 .25996 Mdot
.94762 .29972 Mdot
.94952 .30115 Mdot
.95143 .43314 Mdot
.95333 .35172 Mdot
.95524 .33441 Mdot
.95714 .35758 Mdot
.95905 .33589 Mdot
.96095 .32007 Mdot
.96286 .22939 Mdot
.96476 .31681 Mdot
.96667 .33373 Mdot
.96857 .42044 Mdot
.97048 .41692 Mdot
.97238 .3529 Mdot
.97429 .42121 Mdot
.97619 .43268 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0001Hooooo`;o0000GOooool2
o`0008Cooooo000Yooooo`03o`000?oooooooooo04?ooooo0_l0000Booooo`;o0000GOooool2o`00
033ooooo0_l0001Booooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0@oooool2
o`000:?ooooo0_l0001Booooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0?oooooo?Oooool000Co00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo2?oo
ool2o`00027ooooo0_l0000@ooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000ooooool8ooooo`;o00008Ooo
ool2o`00013ooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo
0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0Voooool2o`0001[ooooo0_l00023ooooo`001_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0
003oooooooooo`07ooooo`;o00005oooool2o`0003?ooooo0_l0000nooooo`;o00001?ooool2o`00
00Oooooo0_l0000Aooooo`;o00001?ooool2o`0000Kooooo0_l0000Aooooo`;o00006?ooool4o`00
01[ooooo0_l00005ooooo`;o00008oooool002Wooooo0_l00008ooooo`;o00002Oooool2o`0000[o
oooo1?l0000>ooooo`;o00008oooool2o`0003kooooo0_l0000=ooooo`;o00005oooool2o`0000Ko
oooo0_l000000ooooooo0000o`00000>ooooo`;o00006?ooool4o`0000cooooo0_l0000<ooooo`;o
00001Oooool2o`0000?ooooo0_l0000Nooooo`00:Oooool00ol0003oooooooooo`0Booooo`;o0000
0_ooool2o`0000Kooooo0_l0000=ooooo`;o000000?oooooo`000?l000003?ooool2o`0003Oooooo
0_l0001;ooooo`;o00000_ooool2o`0003Sooooo0_l0000Hooooo`;o00007_ooool002Wooooo00?o
0000ooooooooool05_ooool2o`0001Gooooo0_l0000?ooooo`;o0000=oooool2o`0004_ooooo0_l0
001Iooooo`;o000000?oooooo`000?l000006?ooool002Wooooo00?o0000ooooooooool07Oooool2
o`0000cooooo0_l00006ooooo`;o00001?ooool2o`0008Gooooo0_l0001<ooooo`;o00003oooool2
o`000003ooooool0003o000001Sooooo000Yooooo`03o`000?oooooooooo01gooooo0_l00004oooo
o`;o00001_ooool2o`0000Kooooo0_l00004ooooo`;o00004oooool2o`0003gooooo0_l00003oooo
o`;o0000;?ooool2o`0003cooooo0_l00008ooooo`;o00001?ooool2o`000003ooooool0003o0000
01;ooooo0_l0000Eooooo`00:Oooool2o`0001;ooooo0_l0000@ooooo`;o00000oooool2o`0000_o
oooo0_l00006ooooo`Co00003Oooool2o`0001kooooo0_l000000ooooooo0000o`000002o`0000Oo
oooo0_l0000?ooooo`;o00000oooool3o`00013ooooo0_l0000Rooooo`;o00002Oooool2o`0000So
oooo0_l0000Cooooo`;o00002Oooool3o`0000?ooooo0_l00002ooooo`;o00001oooool2o`0001;o
oooo0_l0000Eooooo`00:Oooool00ol0003oooooooooo`0Aooooo`;o00005Oooool2o`0000_ooooo
0ol00005ooooo`Co0000;Oooool2o`000003ooooool0003o000000;o00001oooool2o`0001Gooooo
0_l000000ooooooo0000o`00000=ooooo`;o00008_ooool2o`0000;ooooo0_l00002ooooo`;o0000
00?oooooo`000?l000000oooool2o`0000?ooooo0_l000000ooooooo0000o`000008ooooo`;o0000
1_ooool2o`0000[ooooo0_l00003ooooo`;o00002Oooool2o`0001?ooooo0_l0000Fooooo`00:Ooo
ool00ol0003oooooooooo`0Gooooo`;o00005oooool4o`000008oa0@4?oooooo0000o`000?lb<S;o
0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool2o`0001oooooo1Ol00003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool3o`000003oc8b<_o^k^kooooo01?ooooo1?l0
0006ooooo`;o00002?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool2o`0000;ooooo0_l00006oooo
o`;o00001_ooool2o`0000Kooooo1?l00002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^01?ooooo0_l0000Cooooo`Co000000Wo<S8bomgMgOoooooooooo
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Yoooo
o`03o`000?oooooooooo01Oooooo0_l00004ooooo`;o00004oooool00ol0003oooooooooo`02oooo
o`03ogMgMonHV9Sooooo00;o00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo0_l00000
0ooooooo0000o`00000Looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo0_l000000oooooooV9RHogMgM`0Booooo`;o00000_ooool2o`0000Kooooo
0_l00008ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`;o00007Oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00oooooo
0_l00003ooooo`;o00002_ooool2o`0000[ooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9Sooooo
oiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000Yooooo`Go00006oooool2
o`0001?ooooo00?o0000ooooooooool00_ooool00ol@413oooooooooo`03o`0000;ooooo00Go410@
oooooooooooooooooa0@400;ooooo`;o00000oooool2o`0001Sooooo00?oV9RHob4Q8Oo^k^h01?oo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Ko410@oooooooooooooooooa0@4?ooool2o`00
00oooooo0_l0000Hooooo`05o`000?ooooooooooooooool@41000oooool2o`0000;ooooo00Go410@
oooooooooooooooooa0@400<ooooo`;o00005Oooool2o`0000?ooooo1Ol00003ooooo`05oa0@4?oo
ooooooooooooool@41000oooool01Ol@413o0000o`000?oooooo410@00oooooo0_l00003ooooo`;o
00002_ooool2o`0000?ooooo0_l00006ooooo`04o`000?oooooooooooa0@40?ooooo00Go410@oooo
oooooooooooooa0@4003ooooo`03oa0@4?oooooooooo007ooooo000Yooooo`Go0000<?ooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooooooo`;o00000_ooool01Ol0003ooooooooooooo
oooo0000013ooooo0_l0000Iooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooooooooooo
o`000003ooooo`06o`000?ooooooooooooooool0003ooooo0_l00007ooooo`;o00004Oooool2o`00
00cooooo00?oZJVYoa0@4?ooool00_ooool01?l0003oooooooooooooool2o`0000;ooooo00Go0000
ooooooooooooooooo`00000@ooooo`;o00004Oooool2o`0000?ooooo00CoA4A4omgMgOoooooo0000
1?ooool01Ol0003ooooooooooooooooo000000?ooooo0ol000000ooooooo0000ooooo`0Tooooo`;o
00001Oooool01OmgMgOo<S8boooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo007ooooo000Yooooo`03o`000?oooooooooo02_ooooo0_l00005oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool00000;?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000
0oooool2o`0000;ooooo00?o0000ooooooooool01Oooool2o`000003ooooool0003o000000oooooo
1?l00002ooooo`;o00001oooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo0000013ooooo0_l0000Fooooo`04omgMgOmEEEGooooo
o`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`06o`000?ooooooooooooooool0003o
oooo0_l00002ooooo`;o00002Oooool2o`0001Cooooo0_l000001_oooooo0000ob4Q8Ol0003o<S8b
olc<c0;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool002Wooooo00?o0000ooooooooool0:oooool3o`0000Cooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@400Eooooo`;o
00004?ooool2o`0000Cooooo00Go0000oooooooooooooooooa0@4003ooooo`04oa0@4?oooooooooo
ooooo`;o00000_ooool00ol@413oooooooooo`05ooooo`;o00004Oooool3o`0000Cooooo0_l00008
ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oo
ooooooooooooool@4100:Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@
41000oooool01_l@413ooooooooooooooooo410@ooooo`;o00000_ooool2o`0000Wooooo0_l00004
ooooo`;o00003_ooool2o`000003ooooool0003ooooo00Gooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool002Wooooo00?o0000ooooooooool08Ooo
ool2o`0000Wooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05Oooool2o`00013ooooo0ol000001?nj^[[o
oooooiRHV?l@4103ooooo`04ogMgMonHV9SooooooiRHV0;o000000Ooooooo`000?l0003oV9RHoooo
oonHV9SoMgMg00;o00006?ooool2o`0000cooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg017ooooo0_l00002
ooooo`;o00004_ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01Kooooo0_l0000Aooooo`03o`000?oooooooooo00Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wo
oooo00?o0000ooooooooool06?ooool2o`0000Oooooo0_l0000=ooooo`03oeEEEOmVIVKo000000Co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:Oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00?ok^k^oc8b<_l000000ol000001?oooooo0000o`00
0?lb<S82o`000003onk^k_l0003o000002Kooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo0_l0000=
ooooo`;o00000_ooool2o`0001?ooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00;ooooo0_l000001?lb<S;o0000oc8b<_o^k^hSooooo`?o00000oooool4o`0000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool002Wo
oooo0_l0000Iooooo`;o0000G_ooool2o`0000Gooooo0_l0000Yooooo`;o00004_ooool2o`000003
ooooool0003o000001Gooooo0_l0000Looooo`;o00001?ooool2o`00027ooooo0ol0000Jooooo`00
:Oooool00ol0003oooooooooo`1Rooooo`;o00000_ooool2o`0004;ooooo0_l0000?ooooo`;o0000
00?oooooo`000?l000003Oooool2o`0000Wooooo0_l0000Rooooo`;o00002Oooool2o`0003?ooooo
000Yooooo`03o`000?oooooooooo01Oooooo0_l000000ooooooo0000o`00000Iooooo`;o00002_oo
ool2o`0001oooooo0_l00002ooooo`;o0000Doooool2o`00013ooooo0_l0000hooooo`;o00002ooo
ool2o`0000oooooo0ol0000Dooooo`00:Oooool00ol0003oooooooooo`0Gooooo`;o000000?ooooo
o`000?l000006Oooool2o`0000[ooooo0_l0001Vooooo`;o0000JOooool2o`0000oooooo0ol0000D
ooooo`00:Oooool00ol0003oooooooooo`0aooooo`;o00004?ooool2o`0003Gooooo0_l0000@oooo
o`;o00002_ooool4o`0000gooooo0_l0000@ooooo`;o0000;?ooool2o`00057ooooo000Qoooooooo
0000A?l00004ooooo`00:Oooool01?l0003oooooo`000?l00008ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?o
oooo0_l00005ooooo`03o`000?oooooooooo00;ooooo0_l00003ooooo`?o00002oooool00ol0003o
ooooooooo`02ooooo`;o00001Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[o
oooo00Co0000oooooooooooooooo0_l00004ooooo`?o00002oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo000Yooooo`04o`000?oooooo0000o`00037ooooo0_l00006oooo
o`04o`000?oooooo0000o`0000Kooooo0_l0000Booooo`;o00007Oooool2o`0000_ooooo0_l00005
ooooo`;o00000_ooool2o`0001gooooo0_l00005ooooo`03o`000?oooooooooo00oooooo0_l00005
ooooo`;o00007?ooool4o`0000;ooooo00?o0000ooooooooool01?ooool2o`00017ooooo0_l0000M
ooooo`;o00000_ooool00ol0003oooooooooo`0:ooooo`00:Oooool01?l0003oooooooooooooool2
o`0002cooooo0_l000000ooooooo0000o`000008ooooo`;o00001_ooool2o`0001;ooooo0_l00002
ooooo`;o000000?oooooo`000?l000005_ooool2o`0000_ooooo0ol00002ooooo`Co00000_ooool2
o`0003Kooooo0_l00005ooooo`;o00005?ooool2o`0000Cooooo1_l00009ooooo`;o00004Oooool2
o`0001cooooo0ol0000?ooooo`00:Oooool01?l0003oooooooooooooool2o`0002Gooooo0_l00005
ooooo`;o00006?ooool2o`00013ooooo0ol000000ooooooo0000o`000009ooooo`;o00003Oooool2
o`0000[ooooo0_l00002ooooo`;o00008_ooool5o`0001Wooooo0ol0000@ooooo`Co00000_ooool2
o`0000Cooooo0_l00003ooooo`;o0000<_ooool2o`0000Gooooo0_l0000@ooooo`00:Oooool2o`00
00Oooooo0_l0000Pooooo`;o00007oooool2o`00013ooooo0_l0000=ooooo`;o00003Oooool2o`00
02cooooo0_l00004ooooo`Go00003Oooool2o`0000;ooooo0_l00006ooooo`?o00004?ooool4o`00
00gooooo0_l0000booooo`;o00005oooool002Wooooo0_l00007ooooo`;o00001?ooool2o`0001Co
oooo0_l0000Cooooo`;o00007oooool2o`0000gooooo1?l00002ooooo`Co0000=_ooool2o`0001Ko
oooo0_l00002ooooo`;o0000B?ooool2o`0002gooooo000Yooooo`;o00003Oooool2o`0001Cooooo
0_l0000Cooooo`;o00007oooool2o`0000gooooo1?l00002ooooo`Co00002Oooool2o`0005;ooooo
0_l0000fooooo`;o00001Oooool2o`0000?ooooo0_l0000?ooooo`;o00005oooool002Wooooo00?o
0000ooooooooool09_ooool2o`00043ooooo0_l0000<ooooo`;o00000_ooool2o`0000Gooooo0_l0
000Mooooo`;o0000;?ooool2o`0003Kooooo0_l0000:ooooo`;o000000?oooooo`000?l000001_oo
ool2o`0000Cooooo0_l00003ooooo`Go00003oooool002Wooooo00?o0000ooooooooool09_ooool2
o`0000_ooooo0_l000000ooooooo0000o`00000Cooooo`;o00001_ooool2o`0001?ooooo0_l0000<
ooooo`;o00002Oooool2o`0001gooooo0_l00011ooooo`;o0000<?ooool2o`0000Kooooo0_l00009
ooooo`Go00003oooool002Wooooo0_l0000Iooooo`;o00004?ooool2o`0000Oooooo0_l000000ooo
oooo0000o`000002ooooo`;o00003oooool2o`0000Kooooo0_l0000booooo`;o00007?ooool2o`00
02kooooo0_l0000<ooooo`;o00003oooool2o`0000gooooo1?l0000eooooo`00:Oooool4o`000004
ooooool0003o0000ooooo`;o00001_ooool2o`0000Gooooo0_l00002ooooo`;o00004?ooool2o`00
00Kooooo0_l00004ooooo`Co00001?ooool2o`0004Gooooo0ol0000Kooooo`;o00001?ooool2o`00
02Gooooo0_l000000ooooooo0000o`00000Gooooo`;o00001?ooool2o`0000Sooooo0_l00003oooo
o`Co00004Oooool2o`0002;ooooo000Yooooo`05o`000?oooooo0000o`000?ooool00_l000000ooo
oooo0000o`000006ooooo`;o00001Oooool2o`0000oooooo0_l00002ooooo`;o00001oooool2o`00
00Cooooo0_l00006ooooo`;o00003oooool2o`0001Cooooo0_l0000Oooooo`;o00001Oooool3o`00
00Sooooo0_l00005ooooo`;o00002?ooool2o`0000_ooooo0_l0000Hooooo`;o00006_ooool2o`00
00Gooooo1?l000000ooooooo0000o`000002ooooo`;o00006?ooool4o`00023ooooo000Yooooo`03
o`000?oooooooooo00?ooooo0_l00008ooooo`;o00002_ooool2o`0000[ooooo0_l00002ooooo`;o
00009_ooool2o`00017ooooo0_l000000ooooooo0000o`00000Eooooo`;o00003Oooool5o`0000So
oooo0_l00002ooooo`;o000000?oooooo`000?l000001Oooool2o`0000kooooo1?l0000cooooo`;o
00001?ooool7o`0000Sooooo0_l00004ooooo`;o00003_ooool2o`0000_ooooo0_l0000Cooooo`00
:Oooool00ol0003oooooooooo`03ooooo`;o00000oooool2o`0000oooooo0_l0000<ooooo`;o0000
9?ooool2o`0000Gooooo0_l00004ooooo`;o00001oooool3o`0001Sooooo0_l0000=ooooo`;o0000
3oooool2o`0000Sooooo0_l0000@ooooo`;o00002_ooool2o`0002Oooooo0_l00008ooooo`;o0000
00Coooooo`000?l0003ooooo0_l00003ooooo`;o00001?ooool2o`0001;ooooo0_l00007ooooo`;o
00001?ooool2o`0000gooooo000Yooooo`;o00002Oooool2o`0001gooooo0_l0000Eooooo`;o0000
3Oooool2o`0000Gooooo0_l00004ooooo`;o00001oooool2o`0001Kooooo0_l00002ooooo`Co0000
9?ooool2o`0000Cooooo0_l0000Gooooo`;o0000=?ooool2o`000003ooooool0003o000001gooooo
0_l00008ooooo`;o00000oooool2o`0000gooooo000Yooooo`03o`000?oooooooooo00oooooo0_l0
000]ooooo`;o0000>oooool2o`0000;ooooo1?l0000Tooooo`;o00001?ooool2o`0000Gooooo0_l0
000=ooooo`;o0000Hoooool2o`0001;ooooo000Yooooo`03o`000?oooooooooo00Cooooo0_l00000
0ooooooo0000o`000006ooooo`;o0000Xoooool2o`0000gooooo0_l00005ooooo`;o0000C?ooool2
o`0002;ooooo000Yooooo`03o`000?oooooooooo00Cooooo0_l000000ooooooo0000o`00000Uoooo
o`;o0000S?ooool2o`0000cooooo0_l0000Uooooo`;o00009Oooool2o`0002;ooooo000Yooooo`03
o`000?oooooooooo02kooooo0_l0000Fooooo`;o00000oooool2o`0000kooooo0_l0001Oooooo`;o
0000<oooool2o`0004Wooooo000Yooooo`;o00002oooool2o`0003[ooooo0_l00003ooooo`;o0000
3_ooool2o`0001Oooooo0_l0001Jooooo`;o0000J_ooool002Wooooo00?o0000ooooooooool02_oo
ool3o`0006Oooooo0_l00017ooooo`;o00000oooool2o`0000cooooo0_l0001Zooooo`001_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Gooooo00?o0000ooooooooool02oooool2o`0008Cooooo0_l0000Zooooo`;o0000
0oooool2o`0001Oooooo0_l0001Oooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo03Cooooo0_l0000Gooooo`;o0000@_ooool2o`00043ooooo0_l00006ooooo`;o
0000Goooool000Kooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Rooooo`;o00004?ooool2o`0001Oo
oooo0_l00024ooooo`;o00004_ooool2o`00027ooooo0_l0000`ooooo`001_ooool01Ol0003ooooo
oooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o
00002Oooool2o`0001Oooooo0_l00003ooooo`;o0000__ooool2o`0000;ooooo1?l00002ooooo`;o
00005oooool2o`00033ooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOo
IVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`05oooo
o`;o00000_ooool5o`0001Wooooo0_l0000Pooooo`;o0000AOooool2o`0005Cooooo0_l00003oooo
o`Co00000_ooool2o`0001Kooooo0_l0000aooooo`001_ooool01Ol@413ooooooooooooooooo410@
00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Gooooo0_l00003ooooo`Co0000<_ooool2o`0000Oooooo0_l0000oooooo`;o00001?ooool2o`00
02?ooooo0_l0000Xooooo`;o00001Oooool3o`00023ooooo0_l0000aooooo`001_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0@?ooool2o`0004Cooooo0_l00002ooooo`;o00000_ooool2
o`0002Gooooo0_l0000Xooooo`;o00001_ooool2o`0001cooooo0_l0000eooooo`001_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_oo
ool00ol0003oooooooooo`0mooooo`;o00002Oooool2o`0000Wooooo0_l0000?ooooo`;o00008?oo
ool2o`0000Kooooo0_l0000Uooooo`;o0000C_ooool2o`0003Gooooo000Yooooo`;o0000?_ooool2
o`0000Sooooo0ol00009ooooo`;o00003oooool2o`0001[ooooo0_l0000@ooooo`;o00007_ooool2
o`000003ooooool0003o000002Cooooo0_l0001Oooooo`00:Oooool00ol0003oooooooooo`0?oooo
o`;o00004oooool2o`00027ooooo0_l0000Yooooo`;o00003?ooool2o`00013ooooo0_l0000Joooo
o`;o00000_ooool2o`0000Gooooo0_l00005ooooo`;o00006Oooool2o`0000Cooooo0_l0000moooo
o`;o00006_ooool002Wooooo00?o0000ooooooooool03oooool2o`0001?ooooo0_l0000`ooooo`;o
00006_ooool2o`0001Kooooo0_l0000Rooooo`Co00001oooool2o`0000Gooooo0_l0000Oooooo`;o
0000=?ooool2o`0000Oooooo0_l0000Jooooo`00:Oooool00ol0003oooooooooo`09ooooo`;o0000
8oooool2o`0001;ooooo0_l0000Booooo`;o00006_ooool2o`0001?ooooo0_l000000ooooooo0000
o`00000Tooooo`;o0000Eoooool2o`0000;ooooo0_l00008ooooo`;o00008oooool002Wooooo00?o
0000ooooooooool02Oooool2o`0000[ooooo0_l0000Gooooo`;o00004_ooool2o`0000Cooooo1?l0
000Eooooo`;o00002oooool3o`0001Kooooo0_l0000Fooooo`;o0000F_ooool2o`0000?ooooo0_l0
0007ooooo`;o00000_ooool2o`0000Oooooo0_l0000Eooooo`;o00003Oooool002Wooooo0_l0000?
ooooo`;o00000_ooool2o`000003ooooool0003o000002Cooooo0_l0000;ooooo`Co00001Oooool2
o`0000kooooo0_l0000;ooooo`?o0000;_ooool2o`000004ooooool0003o0000o`0002kooooo0_l0
0002ooooo`;o00000oooool2o`0001gooooo0_l00003ooooo`;o00005?ooool2o`0000Gooooo0_l0
000=ooooo`?o00003Oooool002Wooooo00?o0000ooooooooool00_ooool2o`0000[ooooo0_l00002
ooooo`;o00001oooool2o`0000Kooooo0_l00005ooooo`;o00003oooool2o`0000Wooooo0_l00006
ooooo`Go00004oooool2o`000003ooooool0003o000000;o00002Oooool2o`0001oooooo0_l00009
ooooo`?o00009?ooool2o`0000Sooooo0_l00002ooooo`Co000000?oooooo`000?l000001oooool2
o`0000;ooooo0_l0000?ooooo`;o00008Oooool2o`0000gooooo1?l0000<ooooo`00:Oooool00ol0
003oooooooooo`02ooooo`;o00004?ooool2o`0000Gooooo0_l00002ooooo`;o00000_ooool2o`00
00Gooooo0_l000000ooooooo0000o`000009ooooo`;o00003?ooool2o`0000Kooooo1_l00009oooo
o`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000;o00002?ooool3o`00
01oooooo1?l0000?ooooo`Co00001?ooool2o`0000[ooooo0_l00005ooooo`;o00000_ooool2o`00
00kooooo0_l00008ooooo`Co00000_ooool2o`0000oooooo0_l00005ooooo`;o00004Oooool2o`00
01Sooooo0_l0000<ooooo`00:Oooool00ol0003oooooooooo`0Dooooo`;o00001_ooool2o`000003
ooooool0003o000000cooooo0_l00009ooooo`;o00006?ooool2o`0000Gooooo0_l00002ooooo`Go
00002_ooool2o`0000Oooooo0_l0000>ooooo`;o00003_ooool6o`0000oooooo1?l00004ooooo`;o
00002_ooool2o`0000Gooooo0_l0000:ooooo`;o00002Oooool2o`0000Gooooo0_l0000Booooo`;o
00002?ooool2o`00017ooooo0_l00004ooooo`;o00008?ooool002Wooooo00?o0000ooooooooool0
1?ooool2o`0000[ooooo0_l000000ooooooo0000o`000007ooooo`;o00008oooool2o`0000gooooo
0_l00007ooooo`;o000000?oooooo`000?l000000ol00004ooooo`;o00001Oooool2o`0001Oooooo
0_l0000>ooooo`;o00003oooool2o`0000?ooooo0_l00004ooooo`;o00001oooool2o`0000Gooooo
0_l0000>ooooo`;o00002Oooool3o`0000Gooooo0_l0000Aooooo`;o00008Oooool2o`0000_ooooo
0_l00006ooooo`;o00002oooool002Wooooo0_l00005ooooo`;o00002_ooool2o`000003ooooool0
003o000000Oooooo0_l00002ooooo`;o00000oooool2o`0001[ooooo0_l0000=ooooo`;o00002_oo
ool2o`000003ooooool0003o000000Cooooo0_l00005ooooo`;o0000>?ooool4o`0000Oooooo1?l0
0003ooooo`Co00001Oooool2o`0001?ooooo0_l00002ooooo`;o000000?oooooo`000?l000001Ooo
ool4o`0000[ooooo0_l0000cooooo`;o00001_ooool2o`0000_ooooo000Yooooo`03o`000?oooooo
oooo013ooooo0_l00003ooooo`;o00000oooool4o`0000;ooooo0_l00003ooooo`;o0000=oooool2
o`0000cooooo0_l0000Vooooo`;o00001_ooool3o`0000Wooooo0_l00009ooooo`;o00000oooool2
o`0001cooooo0_l00002ooooo`;o00002_ooool2o`0000Cooooo0_l00002ooooo`Co00009oooool2
o`0001oooooo000Yooooo`03o`000?oooooooooo01Gooooo0_l00003ooooo`;o00000oooool2o`00
02Cooooo0_l0000Gooooo`;o00000oooool2o`0000_ooooo0ol0000?ooooo`;o00004?ooool2o`00
00Kooooo0ol0000gooooo`;o00001oooool2o`0000_ooooo0_l00002ooooo`;o00001?ooool2o`00
02?ooooo0_l0000Oooooo`00:Oooool00ol0003oooooooooo`0Oooooo`;o00003oooool2o`0001?o
oooo0_l0000?ooooo`;o00002Oooool4o`0000_ooooo0ol000000ooooooo0000o`00000<ooooo`Co
0000@_ooool2o`0001Gooooo0_l0000Eooooo`;o00006oooool2o`0000Cooooo0_l0000Qooooo`00
:Oooool01?l0003oooooooooooooool2o`0002gooooo0_l0000Cooooo`;o00003oooool2o`0000Wo
oooo0_l0000Aooooo`;o00003_ooool2o`0004;ooooo0_l00019ooooo`;o00001?ooool2o`00027o
oooo000Yooooo`;o00000_ooool2o`000?oooooo>_ooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`3oooooocgooooo000>ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooo
ooooo`03ooooo`?o0000oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05o`000?oo
ooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool0oooooolmooooo`003_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEE
ooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`000?oo
ooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo
00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMooo
ool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`007oooool4o`000003oa0@4?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`007oooool00omEEEGoIVIVo`00003oooooodOooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .24444 Mdot
.02762 .2515 Mdot
.02952 .29959 Mdot
.03143 .26193 Mdot
.03333 .36278 Mdot
.03524 .24791 Mdot
.03714 .29142 Mdot
.03905 .44359 Mdot
.04095 .43845 Mdot
.04286 .30119 Mdot
.04476 .32779 Mdot
.04667 .45082 Mdot
.04857 .27173 Mdot
.05048 .29569 Mdot
.05238 .44175 Mdot
.05429 .26856 Mdot
.05619 .30008 Mdot
.0581 .27241 Mdot
.06 .34764 Mdot
.0619 .34834 Mdot
.06381 .31751 Mdot
.06571 .29103 Mdot
.06762 .33106 Mdot
.06952 .2891 Mdot
.07143 .44386 Mdot
.07333 .36926 Mdot
.07524 .34541 Mdot
.07714 .35286 Mdot
.07905 .36665 Mdot
.08095 .27403 Mdot
.08286 .35624 Mdot
.08476 .43661 Mdot
.08667 .4449 Mdot
.08857 .26244 Mdot
.09048 .28005 Mdot
.09238 .3854 Mdot
.09429 .41666 Mdot
.09619 .35124 Mdot
.0981 .39998 Mdot
.1 .45182 Mdot
.1019 .45345 Mdot
.10381 .27669 Mdot
.10571 .25284 Mdot
.10762 .238 Mdot
.10952 .24003 Mdot
.11143 .36699 Mdot
.11333 .32498 Mdot
.11524 .42621 Mdot
.11714 .36131 Mdot
.11905 .388 Mdot
.12095 .42838 Mdot
.12286 .39419 Mdot
.12476 .37884 Mdot
.12667 .25184 Mdot
.12857 .27775 Mdot
.13048 .4418 Mdot
.13238 .44634 Mdot
.13429 .31703 Mdot
.13619 .42126 Mdot
.1381 .24148 Mdot
.14 .36582 Mdot
.1419 .44858 Mdot
.14381 .40739 Mdot
.14571 .29239 Mdot
.14762 .44213 Mdot
.14952 .43855 Mdot
.15143 .30775 Mdot
.15333 .28397 Mdot
.15524 .34547 Mdot
.15714 .31045 Mdot
.15905 .3442 Mdot
.16095 .30014 Mdot
.16286 .31807 Mdot
.16476 .29333 Mdot
.16667 .40751 Mdot
.16857 .27905 Mdot
.17048 .37829 Mdot
.17238 .3502 Mdot
.17429 .38768 Mdot
.17619 .32054 Mdot
.1781 .37086 Mdot
.18 .28198 Mdot
.1819 .26458 Mdot
.18381 .28366 Mdot
.18571 .44054 Mdot
.18762 .25675 Mdot
.18952 .36325 Mdot
.19143 .35971 Mdot
.19333 .33551 Mdot
.19524 .28917 Mdot
.19714 .44036 Mdot
.19905 .40762 Mdot
.20095 .28515 Mdot
.20286 .36551 Mdot
.20476 .28128 Mdot
.20667 .42433 Mdot
.20857 .29577 Mdot
.21048 .43396 Mdot
.21238 .37883 Mdot
.21429 .35063 Mdot
.21619 .25218 Mdot
.2181 .3507 Mdot
.22 .44919 Mdot
.2219 .23872 Mdot
.22381 .33938 Mdot
.22571 .26117 Mdot
.22762 .32734 Mdot
.22952 .34961 Mdot
.23143 .28578 Mdot
.23333 .32267 Mdot
.23524 .29207 Mdot
.23714 .25844 Mdot
.23905 .43686 Mdot
.24095 .35666 Mdot
.24286 .33598 Mdot
.24476 .32867 Mdot
.24667 .36212 Mdot
.24857 .43436 Mdot
.25048 .43443 Mdot
.25238 .42358 Mdot
.25429 .28044 Mdot
.25619 .4547 Mdot
.2581 .34608 Mdot
.26 .36087 Mdot
.2619 .31667 Mdot
.26381 .26906 Mdot
.26571 .36883 Mdot
.26762 .42914 Mdot
.26952 .29172 Mdot
.27143 .31629 Mdot
.27333 .30864 Mdot
.27524 .26432 Mdot
.27714 .45132 Mdot
.27905 .25845 Mdot
.28095 .25016 Mdot
.28286 .3715 Mdot
.28476 .3975 Mdot
.28667 .37142 Mdot
.28857 .31981 Mdot
.29048 .44671 Mdot
.29238 .44486 Mdot
.29429 .42458 Mdot
.29619 .26808 Mdot
.2981 .34411 Mdot
.3 .3037 Mdot
.3019 .34921 Mdot
.30381 .43823 Mdot
.30571 .32014 Mdot
.30762 .35722 Mdot
.30952 .36073 Mdot
.31143 .4626 Mdot
.31333 .35644 Mdot
.31524 .33284 Mdot
.31714 .28128 Mdot
.31905 .29512 Mdot
.32095 .24269 Mdot
.32286 .40404 Mdot
.32476 .40265 Mdot
.32667 .43789 Mdot
.32857 .41999 Mdot
.33048 .40247 Mdot
.33238 .36744 Mdot
.33429 .38035 Mdot
.33619 .45654 Mdot
.3381 .38468 Mdot
.34 .24244 Mdot
.3419 .26728 Mdot
.34381 .43863 Mdot
.34571 .33792 Mdot
.34762 .34543 Mdot
.34952 .39014 Mdot
.35143 .39385 Mdot
.35333 .26036 Mdot
.35524 .34773 Mdot
.35714 .36214 Mdot
.35905 .3587 Mdot
.36095 .44532 Mdot
.36286 .42427 Mdot
.36476 .24365 Mdot
.36667 .32414 Mdot
.36857 .38225 Mdot
.37048 .38271 Mdot
.37238 .45371 Mdot
.37429 .27167 Mdot
.37619 .45384 Mdot
.3781 .30954 Mdot
.38 .43782 Mdot
.3819 .42229 Mdot
.38381 .43129 Mdot
.38571 .45604 Mdot
.38762 .25804 Mdot
.38952 .45496 Mdot
.39143 .34601 Mdot
.39333 .29124 Mdot
.39524 .44191 Mdot
.39714 .44269 Mdot
.39905 .45823 Mdot
.40095 .45034 Mdot
.40286 .36463 Mdot
.40476 .41858 Mdot
.40667 .33056 Mdot
.40857 .32496 Mdot
.41048 .32493 Mdot
.41238 .30334 Mdot
.41429 .36187 Mdot
.41619 .41231 Mdot
.4181 .26895 Mdot
.42 .2914 Mdot
.4219 .2427 Mdot
.42381 .26382 Mdot
.42571 .32034 Mdot
.42762 .32141 Mdot
.42952 .26185 Mdot
.43143 .35336 Mdot
.43333 .33994 Mdot
.43524 .28389 Mdot
.43714 .27183 Mdot
.43905 .35128 Mdot
.44095 .45697 Mdot
.44286 .3224 Mdot
.44476 .24093 Mdot
.44667 .44978 Mdot
.44857 .36355 Mdot
.45048 .42894 Mdot
.45238 .3294 Mdot
.45429 .38034 Mdot
.45619 .29688 Mdot
.4581 .36064 Mdot
.46 .23873 Mdot
.4619 .26459 Mdot
.46381 .44238 Mdot
.46571 .45859 Mdot
.46762 .26157 Mdot
.46952 .27239 Mdot
.47143 .39341 Mdot
.47333 .33603 Mdot
.47524 .33734 Mdot
.47714 .45223 Mdot
.47905 .34872 Mdot
.48095 .23888 Mdot
.48286 .32147 Mdot
.48476 .2591 Mdot
.48667 .44516 Mdot
.48857 .2613 Mdot
.49048 .33742 Mdot
.49238 .34404 Mdot
.49429 .4338 Mdot
.49619 .27276 Mdot
.4981 .41379 Mdot
.5 .29623 Mdot
.5019 .34551 Mdot
.50381 .40401 Mdot
.50571 .45681 Mdot
.50762 .32856 Mdot
.50952 .27773 Mdot
.51143 .41873 Mdot
.51333 .36132 Mdot
.51524 .34801 Mdot
.51714 .29813 Mdot
.51905 .27768 Mdot
.52095 .44697 Mdot
.52286 .42331 Mdot
.52476 .35226 Mdot
.52667 .33675 Mdot
.52857 .38054 Mdot
.53048 .32316 Mdot
.53238 .34708 Mdot
.53429 .24895 Mdot
.53619 .33379 Mdot
.5381 .24155 Mdot
.54 .3917 Mdot
.5419 .35038 Mdot
.54381 .37411 Mdot
.54571 .28233 Mdot
.54762 .28882 Mdot
.54952 .33759 Mdot
.55143 .39972 Mdot
.55333 .26681 Mdot
.55524 .35319 Mdot
.55714 .43083 Mdot
.55905 .30943 Mdot
.56095 .24023 Mdot
.56286 .3818 Mdot
.56476 .32966 Mdot
.56667 .30345 Mdot
.56857 .42166 Mdot
.57048 .44933 Mdot
.57238 .34892 Mdot
.57429 .29267 Mdot
.57619 .35639 Mdot
.5781 .33901 Mdot
.58 .36298 Mdot
.5819 .37096 Mdot
.58381 .41836 Mdot
.58571 .42457 Mdot
.58762 .44452 Mdot
.58952 .42878 Mdot
.59143 .27345 Mdot
.59333 .41277 Mdot
.59524 .43423 Mdot
.59714 .32889 Mdot
.59905 .44225 Mdot
.60095 .31249 Mdot
.60286 .34872 Mdot
.60476 .28996 Mdot
.60667 .25756 Mdot
.60857 .43526 Mdot
.61048 .44952 Mdot
.61238 .3226 Mdot
.61429 .43234 Mdot
.61619 .3621 Mdot
.6181 .32526 Mdot
.62 .27519 Mdot
.6219 .30197 Mdot
.62381 .28959 Mdot
.62571 .46158 Mdot
.62762 .3281 Mdot
.62952 .2435 Mdot
.63143 .26616 Mdot
.63333 .4425 Mdot
.63524 .32769 Mdot
.63714 .45375 Mdot
.63905 .43975 Mdot
.64095 .43838 Mdot
.64286 .26911 Mdot
.64476 .2683 Mdot
.64667 .29278 Mdot
.64857 .41043 Mdot
.65048 .35864 Mdot
.65238 .32587 Mdot
.65429 .28179 Mdot
.65619 .32525 Mdot
.6581 .44756 Mdot
.66 .42104 Mdot
.6619 .28798 Mdot
.66381 .27099 Mdot
.66571 .31987 Mdot
.66762 .30557 Mdot
.66952 .24002 Mdot
.67143 .25359 Mdot
.67333 .24251 Mdot
.67524 .36639 Mdot
.67714 .36121 Mdot
.67905 .39565 Mdot
.68095 .35343 Mdot
.68286 .29332 Mdot
.68476 .28217 Mdot
.68667 .44374 Mdot
.68857 .34514 Mdot
.69048 .37289 Mdot
.69238 .3085 Mdot
.69429 .281 Mdot
.69619 .35034 Mdot
.6981 .42774 Mdot
.7 .45061 Mdot
.7019 .40613 Mdot
.70381 .38379 Mdot
.70571 .35761 Mdot
.70762 .31499 Mdot
.70952 .38884 Mdot
.71143 .34295 Mdot
.71333 .45058 Mdot
.71524 .44874 Mdot
.71714 .33845 Mdot
.71905 .45066 Mdot
.72095 .45392 Mdot
.72286 .45692 Mdot
.72476 .31147 Mdot
.72667 .33905 Mdot
.72857 .44337 Mdot
.73048 .4465 Mdot
.73238 .31249 Mdot
.73429 .36076 Mdot
.73619 .33912 Mdot
.7381 .24811 Mdot
.74 .25034 Mdot
.7419 .43529 Mdot
.74381 .23968 Mdot
.74571 .41716 Mdot
.74762 .41846 Mdot
.74952 .33171 Mdot
.75143 .40005 Mdot
.75333 .31392 Mdot
.75524 .44507 Mdot
.75714 .33724 Mdot
.75905 .42622 Mdot
.76095 .23996 Mdot
.76286 .30483 Mdot
.76476 .44528 Mdot
.76667 .34491 Mdot
.76857 .28071 Mdot
.77048 .45423 Mdot
.77238 .3123 Mdot
.77429 .32434 Mdot
.77619 .29959 Mdot
.7781 .36573 Mdot
.78 .34049 Mdot
.7819 .42611 Mdot
.78381 .30739 Mdot
.78571 .43756 Mdot
.78762 .45404 Mdot
.78952 .28949 Mdot
.79143 .38287 Mdot
.79333 .3007 Mdot
.79524 .35836 Mdot
.79714 .35841 Mdot
.79905 .27266 Mdot
.80095 .44789 Mdot
.80286 .45056 Mdot
.80476 .34457 Mdot
.80667 .26803 Mdot
.80857 .31037 Mdot
.81048 .25938 Mdot
.81238 .45903 Mdot
.81429 .36541 Mdot
.81619 .37699 Mdot
.8181 .25985 Mdot
.82 .33687 Mdot
.8219 .32424 Mdot
.82381 .36446 Mdot
.82571 .26441 Mdot
.82762 .33031 Mdot
.82952 .28989 Mdot
.83143 .45916 Mdot
.83333 .44669 Mdot
.83524 .308 Mdot
.83714 .27932 Mdot
.83905 .32626 Mdot
.84095 .25537 Mdot
.84286 .33649 Mdot
.84476 .3454 Mdot
.84667 .44962 Mdot
.84857 .43197 Mdot
.85048 .24579 Mdot
.85238 .34841 Mdot
.85429 .23827 Mdot
.85619 .29749 Mdot
.8581 .43865 Mdot
.86 .44214 Mdot
.8619 .33572 Mdot
.86381 .31894 Mdot
.86571 .39032 Mdot
.86762 .26463 Mdot
.86952 .32298 Mdot
.87143 .35878 Mdot
.87333 .37448 Mdot
.87524 .33241 Mdot
.87714 .41368 Mdot
.87905 .31223 Mdot
.88095 .2525 Mdot
.88286 .29242 Mdot
.88476 .29478 Mdot
.88667 .32546 Mdot
.88857 .27471 Mdot
.89048 .44435 Mdot
.89238 .32943 Mdot
.89429 .38052 Mdot
.89619 .24643 Mdot
.8981 .23919 Mdot
.9 .36995 Mdot
.9019 .36971 Mdot
.90381 .30036 Mdot
.90571 .44255 Mdot
.90762 .29931 Mdot
.90952 .44782 Mdot
.91143 .45782 Mdot
.91333 .33743 Mdot
.91524 .4099 Mdot
.91714 .34318 Mdot
.91905 .28526 Mdot
.92095 .36992 Mdot
.92286 .24803 Mdot
.92476 .35137 Mdot
.92667 .35179 Mdot
.92857 .27142 Mdot
.93048 .45824 Mdot
.93238 .24295 Mdot
.93429 .28614 Mdot
.93619 .24652 Mdot
.9381 .32763 Mdot
.94 .30407 Mdot
.9419 .28187 Mdot
.94381 .2556 Mdot
.94571 .2615 Mdot
.94762 .32748 Mdot
.94952 .35846 Mdot
.95143 .4389 Mdot
.95333 .3614 Mdot
.95524 .24875 Mdot
.95714 .33377 Mdot
.95905 .35556 Mdot
.96095 .31676 Mdot
.96286 .35138 Mdot
.96476 .32002 Mdot
.96667 .24485 Mdot
.96857 .43174 Mdot
.97048 .382 Mdot
.97238 .3466 Mdot
.97429 .37587 Mdot
.97619 .45269 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooocgooooo0006
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol0003oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_oo
ool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05oooool3o`0002;ooooo
0_l0001;ooooo`;o00001?ooool2o`0001Sooooo0_l0000Qooooo`;o00005_ooool2o`0000?ooooo
0_l0000Looooo`;o00003?ooool2o`0002Gooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Gooooo`?o00001oooool2o`0001Wooooo0_l0000Nooooo`;o00001?ooool2o`0001So
oooo0_l00006ooooo`;o00000oooool2o`0000Cooooo0_l0000Aooooo`;o00001Oooool2o`0001Co
oooo0_l0000;ooooo`?o00005Oooool2o`0000?ooooo0_l0000Looooo`;o00003?ooool2o`0000Wo
oooo0_l0000Jooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c004ooooo`Co00001_ooool2o`0002;ooooo0_l0000iooooo`;o00001?ooool2o`00
00Kooooo0_l0000@ooooo`;o00001_ooool2o`0001cooooo0_l0000Kooooo`;o00003?ooool2o`00
03Oooooo0_l0000=ooooo`;o00002Oooool4o`0000Oooooo0_l0000?ooooo`00:Oooool2o`000003
ooooool0003o000006Sooooo0_l0000dooooo`;o0000@?ooool2o`0002;ooooo0_l0000=ooooo`;o
00001_ooool2o`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l000003oooool002Wooooo
0_l000000ooooooo0000o`00000Eooooo`;o00001?ooool2o`0001_ooooo0_l0000Cooooo`;o0000
Coooool2o`00043ooooo0ol0000[ooooo`;o00002oooool2o`0000Wooooo0_l0000Booooo`00:Ooo
ool2o`0001Sooooo0_l00004ooooo`;o00006oooool2o`0001?ooooo0_l0001looooo`;o00005?oo
ool2o`0001kooooo0_l0000;ooooo`;o00004_ooool2o`0001Kooooo000Yooooo`03o`000?oooooo
oooo037ooooo0_l0000>ooooo`;o00002oooool2o`00027ooooo0_l00015ooooo`;o00004oooool2
o`0003Cooooo0_l0000Oooooo`;o00005_ooool002Wooooo00Co0000ooooool0003o0000<?ooool2
o`0000[ooooo0_l00002ooooo`;o00002oooool2o`0001Kooooo0_l00009ooooo`;o00003?ooool2
o`0000[ooooo0_l00003ooooo`Co00009?ooool2o`0003oooooo0_l000000ooooooo0000o`00000W
ooooo`;o00005Oooool002Wooooo1?l0000@ooooo`;o00007?ooool2o`0000cooooo0_l0000>oooo
o`;o00005oooool2o`0001Gooooo1?l00008ooooo`Co00000oooool4o`0006Gooooo0_l000000ooo
oooo0000o`000002o`0000cooooo0_l0000Gooooo`;o00005Oooool002Wooooo00?o0000oooooooo
ool04Oooool2o`0001cooooo0_l0000Looooo`;o00001Oooool2o`0000gooooo0_l0000Hooooo`;o
00002_ooool2o`0001cooooo0_l0000Gooooo`;o00000_ooool2o`0003;ooooo0_l00004ooooo`;o
00003?ooool2o`0002kooooo000Yooooo`03o`000?oooooooooo00Kooooo0_l0000Xooooo`Co0000
00So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o00002Oooool2o`0000gooooo0_l00008ooooo`Go00000oooool01_o^k^ko<S8bo`00
0?lb<S;ok^k^ooooo`;o000000Gok^k^oc8b<_l0003o<S8bonk^kP0Uooooo`;o000000KooooooiRH
V?l@413o0000oc8b<_o<c<`3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01_o^k^ko<S8b
o`000?lb<S;ok^k^ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`0001gooooo0_l00000
2Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_l0003o0000oc8b
<_o^k^h08oooool2o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Yooooo`03o`000?oo
oooooooo00Cooooo1Ol00006ooooo`;o00008Oooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l0000Rooooo`;o
000000?ok^k^oooooom4A4@00oooool01_mgMgOoV9RHoooooonHV9SoMgMgooooo`;o000000CoMgMg
oiRHV?ooooooV9RH0_l00009ooooo`;o00001_ooool2o`0001Cooooo00Go410@okZj^_ooooooMgMg
oc8b<P03ooooo`05ogMgMol0003o0000oiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Cooooo0_l00005ooooo`;o00007_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00_ooool2o`000004oiRHV?ooooooV9RHogMgMb?ooooo0_l00007ooooo`09ogMgMolb
<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`00:Oooool00ol0003oooooooooo`04ooooo`;o000000?oooooo`000?l000001_ooool2o`00
00Gooooo0_l0000Jooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@4100:Oooool2o`000003ob4Q8Oo^k^kooooo00?ooooo00Go
410@oooooooooooooooooa0@4003ooooo`04oa0@4?ooooooooooooooo`;o00002Oooool2o`0000Ko
oooo0_l00006ooooo`;o00004?ooool01Ol0003ooooooooooooooooo410@00;o000000?ooooooa0@
4?ooool00_ooool01Ol@413oooooo`000?l0003o410@02Sooooo1Ol00003ooooo`05oa0@4?oooooo
ooooooooool@41000_ooool2o`0000?ooooo00?o410@ooooooooool05?ooool2o`0001Gooooo00Co
0000oooooooooooo410@0oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooooooo
ool00Oooool002Wooooo0_l0000Cooooo`;o00000_ooool2o`0000Kooooo0_l0000;ooooo`;o0000
1Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000;ooooo0_l0000Wooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000005_ooool2o`0000;ooooo0_l0
000?ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooo000000;o0000:?ooool01Om4A4CogMgMooooool0003ooooo00;o000000?oooooo`000?oo
ool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01?ooool2o`00
00kooooo0_l0000Dooooo`05ogMgMolb<S;oooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool00Oooool002Wooooo00?o0000ooooooooool04_ooool2
o`0000[ooooo0_l0000;ooooo`;o000000?oooooo`000?l000000ol00003ooooo`;o00000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_l0000Cooooo`;o00004ooo
ool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooo
ooooooooool2o`0001Gooooo0_l0000:ooooo`;o00001_ooool00ol@413o0000okZj^P03ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo0_l00008
ooooo`;o000000?oooooo`000?l000004Oooool01OoMgMgoEEEEooooool0003ooooo00;o000000?o
ooooo`000?ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
1?ooool2o`0001oooooo0ol000001?lQ8B7o0000oc8b<_o<c<`2ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo000Yooooo`03o`000?oooooooooo
02Kooooo0_l00006ooooo`Go00000_ooool3o`0000?ooooo00Co410@oooooooooooooooo0_l00002
ooooo`03oa0@4?oooooooooo01Gooooo0_l0000Dooooo`05o`000?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@00?ooooo0_l0000Qooooo`;o00001oooool00onj^[[o8B4Q
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@
00Sooooo0_l00008ooooo`;o000000?oooooo`000?l000004_ooool00omgMgOoc<c<o`000004oooo
o`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@023ooooo0_l0
0003ooooo`Go00001_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`00:Oooool00ol0003oooooooooo`0;ooooo`;o00006Oooool2o`0000[ooooo
1Ol000001OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0_l000000oooooooV9RHogMgM`0Yooooo`05
o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0Sooooo`;o00000oooool01Ol@413oV9RHoooooonj^[[o000000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`02o`000004oooooomgMgOoV9RHooooo`;o00002_ooool2o`00
01gooooo00?ok^k^odA4A?l000001?ooool00omgMgOoV9RHooooo`02o`0000?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`;o00006oooool2o`0000?ooooo0_l00002ooooo`03o`000?oooooo
oooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool002Wooooo00Co0000oooooooooooooooo0_l00007ooooo`?o00005_ooool2o`0000_ooooo
00?oEEEEofIVI_l000000_l00002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko
0000o`000?lb<S;ok^k^00Oooooo0_l0000Pooooo`06oiRHV?l@413o0000ob4Q8Oo<c<cooooo0_l0
00001Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo0_l000001?lb<S;o0000oc8b<_o^k^hSooooo`;o
00000oooool00onYZJWo410@o`000002o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02o`00
0003ooooooo^k^ko<S8b00?o00001_ooool2o`0000;ooooo0_l0000Nooooo`03ogMgMol0003ooooo
00?ooooo00?ok^k^oc8b<_l000000_l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool2
o`0000oooooo0_l0000Cooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool2o`0000;ooooo0_l00002ooooo`;o00000ooo
ool2o`0001Oooooo0_l00005ooooo`;o00003?ooool2o`0000Kooooo0_l00009ooooo`;o00003_oo
ool2o`0001Kooooo0_l00007ooooo`;o00005oooool2o`0001Kooooo0_l0000Fooooo`;o00002Ooo
ool2o`0003kooooo0ol0000Yooooo`00:Oooool00ol0003oooooooooo`05ooooo`;o00008oooool2
o`0000cooooo0_l0000Qooooo`;o0000:_ooool2o`0000cooooo0_l00004ooooo`;o0000<oooool2
o`0003Kooooo0_l00007ooooo`;o00001Oooool2o`0002;ooooo000Yooooo`?o00000_ooool2o`00
00?ooooo0_l0000Oooooo`;o0000GOooool2o`0001;ooooo0_l0000Pooooo`;o0000;oooool2o`00
00Cooooo0_l0000Booooo`;o00003Oooool3o`0002;ooooo000Yooooo`?o00000_ooool2o`0000?o
oooo0_l0000Oooooo`;o0000:oooool2o`0002;ooooo0_l0000`ooooo`;o00004?ooool2o`0000co
oooo0_l0000Mooooo`;o00000_ooool2o`0000Cooooo0_l0000Qooooo`;o00002_ooool2o`0001Oo
oooo000Yooooo`03o`000?oooooooooo02Gooooo0_l0000Vooooo`;o00001_ooool2o`0002;ooooo
0_l0000`ooooo`;o00007_ooool2o`0000Kooooo0_l0000Eooooo`;o00001Oooool2o`0000kooooo
0_l0000Pooooo`;o00005oooool0027oooooool00014o`0000Cooooo000Yooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00;ooooo0_l00005ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`02o`0000Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool2o`0000_ooooo0ol00009
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool3o`0000?ooooo1?l00004
ooooo`?o00001?ooool2o`0000?ooooo00?o0000ooooooooool01?ooool2o`0000?ooooo00?o0000
ooooooooool02_ooool01?l0003oooooooooooooool2o`0000Kooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo000Yooooo`03o`000?oooooo
oooo00Wooooo0_l0000Eooooo`;o00001oooool2o`0000oooooo00?o0000ooooooooool03?ooool2
o`000003ooooool0003o000002[ooooo00?o0000ooooooooool0>_ooool3o`00023ooooo0_l00006
ooooo`;o00001Oooool2o`0000Cooooo0_l00003ooooo`03o`000?oooooooooo01[ooooo0_l0000I
ooooo`;o00000oooool00ol0003oooooooooo`0:ooooo`00:Oooool00ol0003oooooooooo`09oooo
o`;o00005Oooool2o`0000Oooooo0_l00002ooooo`;o00006_ooool2o`000003ooooool0003o0000
00?ooooo0_l00004ooooo`;o00009?ooool2o`0004cooooo0_l0000mooooo`;o00007_ooool3o`00
00oooooo000Yooooo`03o`000?oooooooooo02gooooo0_l0000Aooooo`;o00003oooool2o`0000Co
oooo0_l0000Booooo`;o00004?ooool3o`0000?ooooo0_l0000;ooooo`;o00003Oooool2o`0001Wo
oooo0_l0000?ooooo`;o00008Oooool2o`0000gooooo0_l0000;ooooo`Co00007Oooool2o`0000oo
oooo000Yooooo`;o00006_ooool2o`0002?ooooo1?l0000Yooooo`;o00002oooool3o`0000?ooooo
0_l00003ooooo`;o00002oooool2o`0000gooooo0_l0000Iooooo`?o00002Oooool4o`0002Cooooo
0_l0000=ooooo`;o00000oooool2o`0000Sooooo0_l00004ooooo`;o00004Oooool2o`0001Gooooo
000Yooooo`03o`000?oooooooooo00?ooooo0_l0000Dooooo`;o00008oooool2o`0000?ooooo0_l0
000booooo`Co00002oooool2o`00013ooooo0_l0000@ooooo`;o00002Oooool2o`0000Cooooo0_l0
00001?oooooo0000o`000?ooool2o`0000?ooooo1?l0000eooooo`;o000000?oooooo`000?l00000
3_ooool4o`0000cooooo0_l000000ooooooo0000o`00000Eooooo`00:Oooool00ol0003ooooooooo
o`03ooooo`;o00001Oooool2o`0003Oooooo0_l0000Eooooo`;o00006oooool2o`0000gooooo0_l0
000@ooooo`;o00004?ooool2o`0000Wooooo0_l00007ooooo`;o000000?oooooo`000?l000008ooo
ool2o`0001Oooooo0_l0000=ooooo`;o00001?ooool2o`0000cooooo0_l0000Hooooo`00:Oooool0
0ol0003oooooooooo`0:ooooo`;o00009oooool2o`0000kooooo0_l0000Eooooo`;o0000<Oooool2
o`0000oooooo0_l000000ooooooo0000o`000013ooooo`;o00007?ooool2o`0000Cooooo0_l00002
ooooo`;o00006?ooool2o`0001;ooooo000Yooooo`03o`000?oooooooooo03?ooooo0_l00008oooo
o`;o00001?ooool2o`0001oooooo0_l0000Wooooo`;o00000oooool2o`0000[ooooo0_l000000ooo
oooo0000o`000002ooooo`;o00001oooool2o`0002_ooooo0_l000001?oooooo0000o`000?ooool2
o`0000Gooooo0_l0000Booooo`;o00001_ooool2o`0000Cooooo0_l0000>ooooo`;o00003?ooool2
o`0001;ooooo000Yooooo`;o0000?_ooool2o`0002Gooooo0_l0000Jooooo`;o00002oooool2o`00
00?ooooo0_l0000Aooooo`;o00001oooool2o`0002Wooooo1?l000001?oooooo0000o`000?ooool2
o`0000Gooooo0_l00005ooooo`;o00002oooool2o`0001cooooo0_l0000Pooooo`00:Oooool00ol0
003oooooooooo`0=ooooo`;o00006?ooool3o`0001kooooo0_l0000:ooooo`;o00003_ooool2o`00
00cooooo0_l0000<ooooo`;o00004Oooool2o`000003ooooool0003o000003[ooooo0_l00005oooo
o`;o00004?ooool2o`0000;ooooo0_l00006ooooo`;o00002oooool2o`0001Kooooo0_l0000Noooo
o`00:Oooool00ol0003oooooooooo`08ooooo`?o00000_ooool2o`0001Sooooo0ol0000Nooooo`;o
00002_ooool4o`0000cooooo0_l000000ooooooo0000o`000009ooooo`;o00006oooool2o`0000;o
oooo0_l000000ooooooo0000o`000002ooooo`;o00001?ooool2o`0000_ooooo0_l00007ooooo`;o
00006_ooool2o`0001Oooooo0_l0000:ooooo`;o00002oooool2o`000003ooooool0003o000001?o
oooo0_l0000?ooooo`;o00003Oooool002Wooooo00?o0000ooooooooool02?ooool3o`0000Wooooo
0_l0000Fooooo`;o00003?ooool3o`000003ooooool0003o000001Kooooo0_l0000?ooooo`;o0000
6Oooool2o`0000_ooooo0_l00009ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo
0000o`000008ooooo`;o00001oooool2o`0001cooooo0_l0000aooooo`;o00005Oooool3o`0000Wo
oooo0_l000000ooooooo0000o`00000=ooooo`00:Oooool00ol0003oooooooooo`0=ooooo`;o0000
1Oooool2o`0001Kooooo0_l0000<ooooo`?o000000?oooooo`000?l00000?oooool2o`000003oooo
ool0003o000001Wooooo0_l00004ooooo`;o00000_ooool2o`0002Oooooo0_l00002ooooo`;o0000
B?ooool3o`0000Wooooo0_l0000@ooooo`00:Oooool2o`0000kooooo1?l0000aooooo`;o00005?oo
ool3o`0002Cooooo0_l0000Vooooo`;o00001Oooool2o`00023ooooo0_l00006ooooo`;o00006_oo
ool3o`0002oooooo0_l000000ooooooo0000o`00000Aooooo`00:Oooool00ol0003oooooooooo`0?
ooooo`;o00002Oooool2o`0001Kooooo0_l0000>ooooo`;o00001?ooool2o`0000kooooo0ol0000=
ooooo`;o00007_ooool2o`00013ooooo0_l0000Booooo`;o00005_ooool2o`0000Kooooo0_l00008
ooooo`;o00001oooool2o`00017ooooo0ol0000Fooooo`;o00005oooool5o`00017ooooo000Yoooo
o`04o`000?oooooo0000o`0001Wooooo0_l0000Fooooo`;o00004?ooool2o`0000;ooooo0_l0000>
ooooo`;o00003Oooool3o`0000cooooo0_l00002ooooo`;o00002Oooool2o`000003ooooool0003o
0000013ooooo0_l0000Cooooo`;o00002_ooool2o`0000Wooooo0_l00006ooooo`;o00004Oooool2
o`0001_ooooo0_l0000=ooooo`;o00006?ooool2o`0001?ooooo000Yooooo`04o`000?oooooo0000
o`0000gooooo0_l00008ooooo`;o00002?ooool2o`0000kooooo0_l00002ooooo`;o00003?ooool2
o`0001Wooooo0_l00006ooooo`;o00003Oooool2o`0000;ooooo0_l00009ooooo`;o0000:?ooool2
o`0000[ooooo0_l0000Aooooo`;o00007oooool2o`0000Wooooo0_l00002ooooo`;o0000??ooool0
02Wooooo00?o0000ooooooooool03?ooool4o`0000Sooooo0_l00008ooooo`;o00002_ooool2o`00
00Kooooo0_l0000Booooo`;o00004oooool2o`0004oooooo0_l0000Looooo`;o00007oooool2o`00
00Wooooo0_l0000Jooooo`?o00001?ooool2o`0001gooooo000Yooooo`;o00003Oooool2o`00023o
oooo0_l0000Jooooo`;o00001?ooool3o`00053ooooo0_l0000;ooooo`;o00008Oooool2o`00047o
oooo0ol00004ooooo`;o00007Oooool002Wooooo00?o0000ooooooooool0D?ooool3o`00053ooooo
0_l0000^ooooo`;o00009_ooool2o`00013ooooo0_l0000Oooooo`;o00003?ooool000Kooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo01gooooo0_l0000<ooooo`;o00003?ooool2o`0002Go
oooo0_l0000Uooooo`;o0000L_ooool2o`00013ooooo0_l0000Oooooo`;o00003?ooool000Kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A4
00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Mooooo`;o00003?ooool2o`00
00cooooo0_l0000Uooooo`;o00002Oooool3o`0001Wooooo0_l0000Fooooo`;o00002Oooool2o`00
04Oooooo0_l0000Oooooo`;o00005oooool2o`0000gooooo0006ooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool04_ooool2o`0004gooooo0_l00008ooooo`?o0000<Oooool2o`0000Wooooo0_l0000[oooo
o`;o00006_ooool2o`0001oooooo0_l0000Gooooo`;o00003Oooool000Kooooo00Go0000oooooooo
ooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`00
01;ooooo0_l00007ooooo`;o00004?ooool2o`0003;ooooo0_l0001dooooo`Co0000HOooool000Ko
oooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo01_ooooo0_l0000@ooooo`;o0000=_ooool2
o`0003_ooooo0_l0000eooooo`;o0000<?ooool2o`0002oooooo0006ooooo`05oa0@4?oooooooooo
ooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool07?ooool2o`0004Oooooo0ol0000Tooooo`;o00005?ooool2o`0002_ooooo0_l0000j
ooooo`;o0000;oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01cooooo0_l0
000booooo`;o00005?ooool2o`0002Cooooo0_l00011ooooo`;o0000Joooool000Kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo
00?o0000ooooooooool05?ooool2o`0003[ooooo0_l0001Dooooo`;o0000?_ooool2o`0005Cooooo
000Yooooo`;o00005Oooool2o`0004Kooooo1Ol0000fooooo`;o00003Oooool2o`0003kooooo0_l0
001Dooooo`00:Oooool00ol0003oooooooooo`0Sooooo`;o00001Oooool2o`0000Wooooo0_l0000U
ooooo`Go0000=_ooool2o`0003gooooo0_l0001Tooooo`00:Oooool00ol0003oooooooooo`0Soooo
o`;o00001Oooool2o`0000Wooooo0_l0002>ooooo`;o00003oooool2o`0004?ooooo0_l0000Ooooo
o`00:Oooool00ol0003oooooooooo`1jooooo`;o00006Oooool2o`0001cooooo0_l0000@ooooo`;o
0000B?ooool2o`0000[ooooo0_l0000Oooooo`00:Oooool00ol0003oooooooooo`0Cooooo`;o0000
IOooool2o`0001Wooooo0_l0000Looooo`;o0000;oooool2o`0002Wooooo0_l0000[ooooo`00:Ooo
ool2o`0001Cooooo0_l00019ooooo`;o00005oooool2o`00023ooooo0_l0000Eooooo`;o0000<_oo
ool3o`0005Gooooo000Yooooo`03o`000?oooooooooo023ooooo0_l0000Tooooo`;o00005_ooool2
o`0000oooooo0_l00006ooooo`;o00008?ooool2o`0000;ooooo0_l0000<ooooo`;o00000oooool2
o`0001Oooooo0_l0000Jooooo`;o0000EOooool002Wooooo00?o0000ooooooooool06_ooool2o`00
00Cooooo0_l0000Eooooo`;o00003Oooool2o`0000_ooooo0_l0000Dooooo`;o00001?ooool2o`00
02cooooo0_l0000<ooooo`;o00001?ooool2o`0001Kooooo0_l0000Nooooo`;o00001Oooool2o`00
04[ooooo000Yooooo`03o`000?oooooooooo01[ooooo1?l0000Iooooo`;o00004_ooool2o`0000Ko
oooo0_l0000Dooooo`;o00006_ooool2o`0002[ooooo0ol0000Qooooo`;o00004_ooool2o`0000Go
oooo0_l0001:ooooo`00:Oooool00ol0003oooooooooo`0Looooo`;o0000;Oooool2o`0002?ooooo
0_l0000Cooooo`;o00008Oooool2o`0000Sooooo0_l00006ooooo`;o00006Oooool2o`0002kooooo
0_l0000Uooooo`;o00003_ooool002Wooooo0_l0000iooooo`;o00002oooool2o`0002Wooooo0_l0
000Rooooo`;o00004_ooool2o`0000[ooooo0_l00002ooooo`Co00009oooool2o`00023ooooo0_l0
000Uooooo`;o00003_ooool002Wooooo00?o0000ooooooooool00_ooool2o`0000cooooo0_l0000C
ooooo`;o00004Oooool2o`0000Oooooo0_l00002ooooo`;o00003oooool2o`0000Kooooo0_l00003
ooooo`;o00002_ooool2o`0002?ooooo0_l0000Nooooo`;o00000_ooool2o`0000Wooooo0_l0000N
ooooo`;o00003?ooool2o`0001Kooooo0_l0000Looooo`;o00004oooool002Wooooo00?o0000oooo
ooooool00_ooool2o`000003ooooool0003o000000Wooooo0_l0000=ooooo`;o00000oooool3o`00
00Wooooo0_l00002ooooo`;o00002oooool2o`0001?ooooo0_l00006ooooo`;o00000oooool2o`00
00[ooooo0_l00003ooooo`;o00005?ooool2o`0002Wooooo0_l00009ooooo`Go0000;?ooool2o`00
01Kooooo0_l0000=ooooo`;o00003Oooool2o`0001?ooooo000Yooooo`04o`000?oooooooooooooo
o`;o00000_ooool2o`0000Gooooo0_l00002ooooo`;o00003Oooool2o`0000?ooooo0_l0000:oooo
o`;o00000_ooool2o`0001gooooo0_l0000Dooooo`;o00002Oooool2o`0001Cooooo0_l00005oooo
o`;o00007oooool2o`000003ooooool0003o000000Wooooo1?l0000=ooooo`;o00003?ooool2o`00
00Kooooo0_l00002ooooo`;o00007?ooool2o`0000Sooooo0_l00003ooooo`;o00008_ooool002Wo
oooo00Co0000oooooooooooooooo0_l00009ooooo`;o00000_ooool2o`0000gooooo0_l000000ooo
oooo0000o`00000^ooooo`?o00005?ooool2o`0000Wooooo0_l0000Kooooo`;o00002Oooool2o`00
01Cooooo0_l0000Dooooo`;o00001oooool2o`0000Sooooo0_l00002ooooo`;o00001_ooool2o`00
00;ooooo0_l00009ooooo`;o00002Oooool2o`00013ooooo0_l00004ooooo`;o00008Oooool002Wo
oooo0_l00005ooooo`;o00003oooool2o`0000Sooooo0_l000000ooooooo0000o`00000Gooooo`;o
00004Oooool2o`0000;ooooo0_l0000Rooooo`;o00003?ooool2o`0001Kooooo0_l0000>ooooo`;o
00002oooool2o`0000gooooo0_l0000<ooooo`;o00000_ooool4o`000003ooooool0003o000001Go
oooo0ol00008ooooo`;o00000_ooool2o`0001;ooooo0_l0000Qooooo`00:Oooool00ol0003ooooo
ooooo`04ooooo`;o00003oooool2o`0002Cooooo0_l0000:ooooo`;o00001Oooool2o`0001cooooo
1?l00002ooooo`;o00000_ooool2o`0000cooooo0_l00008ooooo`;o00007?ooool2o`0000_ooooo
0_l00006ooooo`;o00004oooool2o`0000;ooooo1?l0000>ooooo`;o00001?ooool2o`0000?ooooo
0_l0000<ooooo`;o0000:?ooool2o`0000_ooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01Go
oooo0_l0000`ooooo`;o00006?ooool2o`0000Wooooo1?l000001?oooooo0000o`000?l0000>oooo
o`;o00002_ooool2o`0000Oooooo0_l0000Xooooo`;o00006Oooool3o`0000gooooo0_l00004oooo
o`;o00009_ooool2o`0001?ooooo0_l0000;ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0HOooool2o`00
00kooooo0_l00002ooooo`;o00002oooool2o`0000Kooooo0_l0000;ooooo`;o0000A?ooool2o`00
01_ooooo0_l00004ooooo`;o00006?ooool2o`0000Cooooo0_l0000Jooooo`003_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`0005Wooooo0_l0000Joooo
o`;o00004oooool2o`0003;ooooo0_l0000jooooo`;o00001?ooool2o`0001kooooo0_l0000Joooo
o`003_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`1Iooooo`;o0000Hoooool2o`0007cooooo000>ooooo`05o`000?oooooooooooooo
ool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2
o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2
o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46oooo
o`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooo
ocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08oooo
o`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`000?oooooooooooooo
ool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<
c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolm
ooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0
003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0
003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`007oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooooooo
ool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
?Oooool0027ooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`007ooo
ool00omEEEGoIVIVo`00003oooooodOooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .2801 Mdot
.02762 .26542 Mdot
.02952 .31113 Mdot
.03143 .28592 Mdot
.03333 .33003 Mdot
.03524 .33071 Mdot
.03714 .27072 Mdot
.03905 .39156 Mdot
.04095 .40421 Mdot
.04286 .25519 Mdot
.04476 .26549 Mdot
.04667 .42203 Mdot
.04857 .2448 Mdot
.05048 .25462 Mdot
.05238 .44144 Mdot
.05429 .27296 Mdot
.05619 .36343 Mdot
.0581 .24426 Mdot
.06 .29099 Mdot
.0619 .24805 Mdot
.06381 .23624 Mdot
.06571 .2384 Mdot
.06762 .2432 Mdot
.06952 .23699 Mdot
.07143 .44784 Mdot
.07333 .35867 Mdot
.07524 .29554 Mdot
.07714 .30812 Mdot
.07905 .26787 Mdot
.08095 .24602 Mdot
.08286 .26303 Mdot
.08476 .39142 Mdot
.08667 .4066 Mdot
.08857 .34136 Mdot
.09048 .35673 Mdot
.09238 .30262 Mdot
.09429 .35294 Mdot
.09619 .30757 Mdot
.0981 .32522 Mdot
.1 .41496 Mdot
.1019 .4404 Mdot
.10381 .35356 Mdot
.10571 .33533 Mdot
.10762 .31048 Mdot
.10952 .31761 Mdot
.11143 .34273 Mdot
.11333 .26405 Mdot
.11524 .36525 Mdot
.11714 .37373 Mdot
.11905 .30331 Mdot
.12095 .37189 Mdot
.12286 .31066 Mdot
.12476 .45573 Mdot
.12667 .33276 Mdot
.12857 .35665 Mdot
.13048 .40809 Mdot
.13238 .40089 Mdot
.13429 .37078 Mdot
.13619 .35813 Mdot
.1381 .32175 Mdot
.14 .35181 Mdot
.1419 .46238 Mdot
.14381 .34146 Mdot
.14571 .33357 Mdot
.14762 .4272 Mdot
.14952 .39414 Mdot
.15143 .25599 Mdot
.15333 .26189 Mdot
.15524 .28928 Mdot
.15714 .23457 Mdot
.15905 .38087 Mdot
.16095 .26772 Mdot
.16286 .25966 Mdot
.16476 .25681 Mdot
.16667 .34178 Mdot
.16857 .3105 Mdot
.17048 .45544 Mdot
.17238 .36573 Mdot
.17429 .29941 Mdot
.17619 .36644 Mdot
.1781 .28116 Mdot
.18 .2423 Mdot
.1819 .28168 Mdot
.18381 .35819 Mdot
.18571 .38788 Mdot
.18762 .29626 Mdot
.18952 .33109 Mdot
.19143 .35384 Mdot
.19333 .37654 Mdot
.19524 .25977 Mdot
.19714 .44927 Mdot
.19905 .46388 Mdot
.20095 .33248 Mdot
.20286 .34286 Mdot
.20476 .33008 Mdot
.20667 .46968 Mdot
.20857 .25472 Mdot
.21048 .39227 Mdot
.21238 .45618 Mdot
.21429 .38031 Mdot
.21619 .26694 Mdot
.2181 .37862 Mdot
.22 .42971 Mdot
.2219 .29494 Mdot
.22381 .2451 Mdot
.22571 .34052 Mdot
.22762 .37624 Mdot
.22952 .29394 Mdot
.23143 .33281 Mdot
.23333 .2371 Mdot
.23524 .25579 Mdot
.23714 .30217 Mdot
.23905 .39388 Mdot
.24095 .25767 Mdot
.24286 .43561 Mdot
.24476 .30058 Mdot
.24667 .35954 Mdot
.24857 .37598 Mdot
.25048 .37892 Mdot
.25238 .3746 Mdot
.25429 .24042 Mdot
.25619 .45764 Mdot
.2581 .25355 Mdot
.26 .26024 Mdot
.2619 .23544 Mdot
.26381 .27439 Mdot
.26571 .27287 Mdot
.26762 .46963 Mdot
.26952 .23995 Mdot
.27143 .32775 Mdot
.27333 .23636 Mdot
.27524 .25403 Mdot
.27714 .43137 Mdot
.27905 .3443 Mdot
.28095 .33249 Mdot
.28286 .27339 Mdot
.28476 .31289 Mdot
.28667 .27553 Mdot
.28857 .26089 Mdot
.29048 .41965 Mdot
.29238 .44011 Mdot
.29429 .46253 Mdot
.29619 .32266 Mdot
.2981 .28476 Mdot
.3 .36514 Mdot
.3019 .24938 Mdot
.30381 .38339 Mdot
.30571 .42743 Mdot
.30762 .33717 Mdot
.30952 .35421 Mdot
.31143 .44785 Mdot
.31333 .37856 Mdot
.31524 .26864 Mdot
.31714 .23959 Mdot
.31905 .26817 Mdot
.32095 .28924 Mdot
.32286 .32745 Mdot
.32476 .32959 Mdot
.32667 .38727 Mdot
.32857 .36178 Mdot
.33048 .32384 Mdot
.33238 .36629 Mdot
.33429 .28648 Mdot
.33619 .42019 Mdot
.3381 .30315 Mdot
.34 .30981 Mdot
.3419 .25242 Mdot
.34381 .38571 Mdot
.34571 .24363 Mdot
.34762 .28979 Mdot
.34952 .30036 Mdot
.35143 .31659 Mdot
.35333 .30442 Mdot
.35524 .29814 Mdot
.35714 .34483 Mdot
.35905 .33136 Mdot
.36095 .41858 Mdot
.36286 .46912 Mdot
.36476 .28666 Mdot
.36667 .31755 Mdot
.36857 .29191 Mdot
.37048 .28848 Mdot
.37238 .42397 Mdot
.37429 .26857 Mdot
.37619 .44146 Mdot
.3781 .33114 Mdot
.38 .40987 Mdot
.3819 .46707 Mdot
.38381 .37363 Mdot
.38571 .42129 Mdot
.38762 .34182 Mdot
.38952 .45445 Mdot
.39143 .24656 Mdot
.39333 .33219 Mdot
.39524 .46116 Mdot
.39714 .39213 Mdot
.39905 .44018 Mdot
.40095 .42972 Mdot
.40286 .34376 Mdot
.40476 .4705 Mdot
.40667 .37874 Mdot
.40857 .3117 Mdot
.41048 .31255 Mdot
.41238 .2679 Mdot
.41429 .34157 Mdot
.41619 .46866 Mdot
.4181 .25086 Mdot
.42 .33053 Mdot
.4219 .31999 Mdot
.42381 .31903 Mdot
.42571 .33112 Mdot
.42762 .25967 Mdot
.42952 .25249 Mdot
.43143 .36475 Mdot
.43333 .24504 Mdot
.43524 .26089 Mdot
.43714 .24923 Mdot
.43905 .36426 Mdot
.44095 .42399 Mdot
.44286 .32879 Mdot
.44476 .29268 Mdot
.44667 .40711 Mdot
.44857 .35749 Mdot
.45048 .38014 Mdot
.45238 .23888 Mdot
.45429 .29688 Mdot
.45619 .25763 Mdot
.4581 .32623 Mdot
.46 .29053 Mdot
.4619 .31655 Mdot
.46381 .44134 Mdot
.46571 .45692 Mdot
.46762 .28395 Mdot
.46952 .29008 Mdot
.47143 .45979 Mdot
.47333 .37356 Mdot
.47524 .27717 Mdot
.47714 .45712 Mdot
.47905 .29993 Mdot
.48095 .29317 Mdot
.48286 .23796 Mdot
.48476 .25881 Mdot
.48667 .46247 Mdot
.48857 .34598 Mdot
.49048 .24255 Mdot
.49238 .38079 Mdot
.49429 .38004 Mdot
.49619 .32426 Mdot
.4981 .3504 Mdot
.5 .36004 Mdot
.5019 .38099 Mdot
.50381 .33334 Mdot
.50571 .44144 Mdot
.50762 .30178 Mdot
.50952 .32602 Mdot
.51143 .36202 Mdot
.51333 .3663 Mdot
.51524 .29975 Mdot
.51714 .36901 Mdot
.51905 .30959 Mdot
.52095 .40792 Mdot
.52286 .36029 Mdot
.52476 .3754 Mdot
.52667 .27618 Mdot
.52857 .29653 Mdot
.53048 .32238 Mdot
.53238 .37723 Mdot
.53429 .27264 Mdot
.53619 .27467 Mdot
.5381 .30074 Mdot
.54 .3139 Mdot
.5419 .37026 Mdot
.54381 .28177 Mdot
.54571 .35989 Mdot
.54762 .25721 Mdot
.54952 .37213 Mdot
.55143 .3189 Mdot
.55333 .2733 Mdot
.55524 .29981 Mdot
.55714 .3779 Mdot
.55905 .25443 Mdot
.56095 .30623 Mdot
.56286 .29034 Mdot
.56476 .31698 Mdot
.56667 .25653 Mdot
.56857 .36677 Mdot
.57048 .42465 Mdot
.57238 .29179 Mdot
.57429 .26928 Mdot
.57619 .34869 Mdot
.5781 .24232 Mdot
.58 .35263 Mdot
.5819 .28207 Mdot
.58381 .46557 Mdot
.58571 .36831 Mdot
.58762 .43671 Mdot
.58952 .38264 Mdot
.59143 .28562 Mdot
.59333 .34015 Mdot
.59524 .45917 Mdot
.59714 .23707 Mdot
.59905 .44024 Mdot
.60095 .42336 Mdot
.60286 .37325 Mdot
.60476 .36549 Mdot
.60667 .26001 Mdot
.60857 .38524 Mdot
.61048 .44368 Mdot
.61238 .26164 Mdot
.61429 .38384 Mdot
.61619 .36675 Mdot
.6181 .30402 Mdot
.62 .24366 Mdot
.6219 .36468 Mdot
.62381 .23741 Mdot
.62571 .44703 Mdot
.62762 .31116 Mdot
.62952 .28406 Mdot
.63143 .34523 Mdot
.63333 .4293 Mdot
.63524 .3169 Mdot
.63714 .42778 Mdot
.63905 .45577 Mdot
.64095 .46757 Mdot
.64286 .27358 Mdot
.64476 .35309 Mdot
.64667 .36346 Mdot
.64857 .347 Mdot
.65048 .31416 Mdot
.65238 .29272 Mdot
.65429 .27591 Mdot
.65619 .37504 Mdot
.6581 .40117 Mdot
.66 .37018 Mdot
.6619 .33306 Mdot
.66381 .24639 Mdot
.66571 .32688 Mdot
.66762 .26845 Mdot
.66952 .28626 Mdot
.67143 .33843 Mdot
.67333 .31066 Mdot
.67524 .36705 Mdot
.67714 .34211 Mdot
.67905 .46382 Mdot
.68095 .36901 Mdot
.68286 .23912 Mdot
.68476 .32947 Mdot
.68667 .41052 Mdot
.68857 .29563 Mdot
.69048 .27812 Mdot
.69238 .23736 Mdot
.69429 .33136 Mdot
.69619 .36267 Mdot
.6981 .46331 Mdot
.7 .41675 Mdot
.7019 .32635 Mdot
.70381 .29899 Mdot
.70571 .37239 Mdot
.70762 .37228 Mdot
.70952 .30693 Mdot
.71143 .3758 Mdot
.71333 .41811 Mdot
.71524 .46967 Mdot
.71714 .24311 Mdot
.71905 .43236 Mdot
.72095 .42953 Mdot
.72286 .43377 Mdot
.72476 .27079 Mdot
.72667 .37363 Mdot
.72857 .44142 Mdot
.73048 .40351 Mdot
.73238 .27133 Mdot
.73429 .26756 Mdot
.73619 .36846 Mdot
.7381 .33185 Mdot
.74 .26962 Mdot
.7419 .39626 Mdot
.74381 .29027 Mdot
.74571 .35217 Mdot
.74762 .36564 Mdot
.74952 .24375 Mdot
.75143 .31532 Mdot
.75333 .23711 Mdot
.75524 .44526 Mdot
.75714 .4372 Mdot
.75905 .38185 Mdot
.76095 .3032 Mdot
.76286 .26912 Mdot
.76476 .45276 Mdot
.76667 .37868 Mdot
.76857 .2769 Mdot
.77048 .42108 Mdot
.77238 .2347 Mdot
.77429 .28627 Mdot
.77619 .25582 Mdot
.7781 .36023 Mdot
.78 .28254 Mdot
.7819 .36386 Mdot
.78381 .23331 Mdot
.78571 .46045 Mdot
.78762 .42474 Mdot
.78952 .35937 Mdot
.79143 .45648 Mdot
.79333 .3655 Mdot
.79524 .32675 Mdot
.79714 .31986 Mdot
.79905 .30523 Mdot
.80095 .40471 Mdot
.80286 .42219 Mdot
.80476 .29335 Mdot
.80667 .32163 Mdot
.80857 .25377 Mdot
.81048 .28614 Mdot
.81238 .44594 Mdot
.81429 .33422 Mdot
.81619 .28894 Mdot
.8181 .30814 Mdot
.82 .27424 Mdot
.8219 .32236 Mdot
.82381 .33446 Mdot
.82571 .34282 Mdot
.82762 .26634 Mdot
.82952 .33033 Mdot
.83143 .45377 Mdot
.83333 .41761 Mdot
.83524 .30063 Mdot
.83714 .35656 Mdot
.83905 .37585 Mdot
.84095 .26558 Mdot
.84286 .36859 Mdot
.84476 .29078 Mdot
.84667 .45174 Mdot
.84857 .47347 Mdot
.85048 .27535 Mdot
.85238 .44196 Mdot
.85429 .31457 Mdot
.85619 .33299 Mdot
.8581 .4162 Mdot
.86 .44289 Mdot
.8619 .27593 Mdot
.86381 .23919 Mdot
.86571 .46129 Mdot
.86762 .31761 Mdot
.86952 .28391 Mdot
.87143 .33809 Mdot
.87333 .28578 Mdot
.87524 .36935 Mdot
.87714 .46757 Mdot
.87905 .33173 Mdot
.88095 .3329 Mdot
.88286 .36277 Mdot
.88476 .335 Mdot
.88667 .31713 Mdot
.88857 .26556 Mdot
.89048 .39411 Mdot
.89238 .30779 Mdot
.89429 .28731 Mdot
.89619 .27322 Mdot
.8981 .29979 Mdot
.9 .27491 Mdot
.9019 .28082 Mdot
.90381 .36443 Mdot
.90571 .47334 Mdot
.90762 .25571 Mdot
.90952 .40137 Mdot
.91143 .43896 Mdot
.91333 .2812 Mdot
.91524 .33399 Mdot
.91714 .36975 Mdot
.91905 .35526 Mdot
.92095 .27373 Mdot
.92286 .27285 Mdot
.92476 .30041 Mdot
.92667 .36246 Mdot
.92857 .34875 Mdot
.93048 .46016 Mdot
.93238 .31592 Mdot
.93429 .31405 Mdot
.93619 .32445 Mdot
.9381 .36887 Mdot
.94 .26754 Mdot
.9419 .26338 Mdot
.94381 .33744 Mdot
.94571 .3454 Mdot
.94762 .306 Mdot
.94952 .36638 Mdot
.95143 .39523 Mdot
.95333 .32162 Mdot
.95524 .27333 Mdot
.95714 .26806 Mdot
.95905 .3258 Mdot
.96095 .27492 Mdot
.96286 .44485 Mdot
.96476 .27996 Mdot
.96667 .27547 Mdot
.96857 .39359 Mdot
.97048 .29771 Mdot
.97238 .29141 Mdot
.97429 .28195 Mdot
.97619 .42326 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooocgooooo0006
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol0003aooooo`;o0000BOooool000Kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo00Wooooo1?l0000Jooooo`;o00005oooool2o`0000Oooooo0_l00002ooooo`;o0000
I_ooool2o`00033ooooo0_l00004ooooo`;o00000_ooool2o`0004Wooooo0006ooooo`05oa0@4?oo
ooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02Oooool4o`0001[ooooo0_l0000Gooooo`;o00001oooool6o`0000cooooo
0_l0000Yooooo`;o00002?ooool2o`0002?ooooo0_l00006ooooo`;o00004Oooool2o`000003oooo
ool0003o000001;ooooo0_l00004ooooo`;o00006oooool2o`00033ooooo0006ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0:ooooo`;o00008_ooool2o`0001Kooooo0_l00003ooooo`;o
00003_ooool2o`0002Wooooo0_l00008ooooo`Co00006_ooool2o`0000gooooo0_l0000Aooooo`;o
000000?oooooo`000?l000001_ooool2o`0002gooooo0_l0000`ooooo`001_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0
003oooooooooo`04ooooo`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00007Oooool2
o`0000gooooo0_l00007ooooo`;o00007?ooool2o`0000cooooo0_l0000<ooooo`;o00004?ooool2
o`0001[ooooo0_l0000<ooooo`;o00003?ooool2o`0000oooooo0_l00009ooooo`;o0000E?ooool0
02Wooooo0_l00005ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o0000;?ooool2o`00
01Oooooo0_l0000<ooooo`;o00003?ooool2o`0000cooooo0ol0000iooooo`;o00003?ooool2o`00
01[ooooo0_l0001Dooooo`00:Oooool00ol0003oooooooooo`09ooooo`;o0000Boooool2o`0000_o
oooo0_l0000Fooooo`;o00000_ooool4o`000;Wooooo000Yooooo`03o`000?oooooooooo00;ooooo
0_l000000ooooooo0000o`00000aooooo`;o00001_ooool2o`0000Kooooo0_l00003ooooo`;o0000
5?ooool2o`0001Kooooo0_l00002ooooo`;o00009oooool2o`0004Cooooo0_l00009ooooo`;o0000
7Oooool2o`0002;ooooo000Yooooo`03o`000?oooooooooo00;ooooo0_l000000ooooooo0000o`00
000Nooooo`;o00000oooool2o`0000cooooo0_l00006ooooo`Co00001?ooool2o`0000?ooooo0_l0
000hooooo`;o00001oooool2o`0001?ooooo0_l000001?oooooo0000o`000?ooool2o`00047ooooo
0_l00009ooooo`;o00007Oooool2o`0002;ooooo000Yooooo`03o`000?oooooooooo02Gooooo0ol0
00001?oooooo0000o`000?l00007ooooo`;o00003Oooool2o`0000Cooooo0_l00007ooooo`;o0000
:oooool2o`000003ooooool0003o000000Cooooo0_l00007ooooo`;o00004oooool2o`0000Cooooo
0_l0000;ooooo`Co0000P?ooool002Wooooo0_l0000@ooooo`;o00002?ooool2o`0000_ooooo0_l0
00000ooooooo0000o`000008ooooo`;o00004oooool2o`0000Oooooo0_l0000[ooooo`;o000000?o
ooooo`000?l00000=Oooool4o`0006Oooooo0_l0000Gooooo`00:Oooool2o`0000Cooooo0_l00009
ooooo`?o00002?ooool2o`0000gooooo0_l0000@ooooo`;o00007oooool2o`0001cooooo0_l0001V
ooooo`;o00007?ooool2o`0000;ooooo0_l0000=ooooo`;o00003oooool2o`0000?ooooo0_l0000B
ooooo`00:Oooool2o`0000;ooooo1?l00009ooooo`;o00006?ooool2o`0000Kooooo1?l000001Ol@
413oooooooooooo^k^ko<S8b00?o00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Kooooo0ol0
000@ooooo`Go00000oooool01?o^k^ko<S8bo`000?lb<S82o`0000;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0Xooooo`03oiRHV?l@413o000000;o00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`;o00004Oooool7o`0000Cooooo0ol00003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
0_l00002ooooo`;o00003Oooool2o`0000oooooo0_l000000om4A4Co0000o`000002o`0000;ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool002Wo
oooo00Co0000oooooooooooooooo0_l00003ooooo`;o0000:_ooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0ol0
0004ooooo`;o00002?ooool2o`00017ooooo0_l000000oo^k^koooooodA4A003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo0_l00005ooooo`;o
000000Cooooooa0@4?nj^[[ooooo0_l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo0_l00006ooooo`;o00004Oooool4o`000003ooooool0
003o000000Gooooo0_l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00;o00005oooool2o`0000Kooooo0_l00009ooooo`;o00000_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool00ol0
003oooooooooo`06ooooo`;o0000:_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo0ol00004ooooo`?o00006ooo
ool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooo
oooooooooooo410@00_ooooo0_l0000?ooooo`Go00001?ooool2o`0000Gooooo00Go0000oooooooo
oooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`02
ooooo`;o00000_ooool2o`0001kooooo1ol000000ooooooo410@ooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41000oooool00ol@413o0000o`000008ooooo`;o00000_ooool2o`0000Wooooo0ol0
0005ooooo`;o00002Oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@
4?oooooooooo007ooooo000Yooooo`;o0000<oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000gooooo0_l0000Looooo`03
oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000002oooool2o`0000oooooo0_l000000ooooooo0000o`00000:ooooo`03ojVYZOl@413o
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
2?ooool2o`0000[ooooo0_l0000Booooo`05odA4A?oMgMgoooooo`000?ooool00_l000000ooooooo
0000ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`08oooo
o`;o00000_ooool2o`0000[ooooo0ol0000?ooooo`03ogMgMolb<S;o000000;o00000oooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00Oooool002Wooooo0_l0000_oooo
o`?o000000?oooooo`000?ooool00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`00000/ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000008Oooool2o`0000Oooooo00Co410@o`000?nj
^[[ooooo0ol00003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0B
ooooo`;o00004_ooool01?oMgMgoEEEEooooool00004ooooo`;o00000_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool03_ooool2o`0000Wooooo0_l000000ooooooo0000
o`000009ooooo`06o`000?lQ8B7o0000oc8b<_o<c<cooooo0_l000001?oooooo0000o`000?l00003
ooooo`05o`000?ooooooooooooooool000000oooool002Wooooo00Co0000ooooool0003o0000;Ooo
ool3o`000003ooooool0003ooooo00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@
4?ooooooooooooooool@41004?ooool2o`0000[ooooo0_l00008ooooo`;o00001Oooool01Ol0003o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooo
oooo00Oooooo0_l0000Fooooo`;o00002?ooool00onj^[[o8B4Qooooo`02o`000005oa0@4?l0003o
0000ooooool@41000oooool01Ol@413ooooooooooooooooo410@00;o00002oooool2o`0001[ooooo
00?oMgMgolc<c?l000000oooool3o`0000;ooooo00Ko410@oooooooooooooooooa0@4?ooool2o`00
0003oa0@4?oooooooooo00kooooo0ol0000;ooooo`;o00002Oooool00ol0003oooooooooo`04oooo
o`05oa0@4?oooooo0000o`000?l@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo000Y
ooooo`04o`000?oooooo0000o`0002Kooooo0_l00009ooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04?ooool2o`0000Ko
oooo0_l00002ooooo`;o00000_ooool2o`0000Cooooo1?l000001?nj^[[ooooooiRHV?l@4103oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Wooooo0ol0
000Looooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOo0000o`000?nHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`02o`0000_ooooo0_l0000Jooooo`03onk^k_m4A4Co0000
00?ooooo0_l000001?nHV9SooooooiRHV?mgMgL3ooooo`03ogMgMonHV9So000000?o00004?ooool2
o`0000Gooooo0_l0000?ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wooooo00?o0000ooooooooool02?oo
ool2o`0001gooooo0_l00007ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06?ooool2o`0000Kooooo0_l00005ooooo`?o
000000Co410@o`000?lQ8B7oc<c<0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP02ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`;o0000
6Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01oooool2o`0001cooooo0_l00003ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`04onk^k_lb<S;o0000oc8b<P;o00001oooool2o`0000kooooo0_l0
000?ooooo`Co00000oooool01Oo^k^ko0000o`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`00:Oooool2o`0000Wooooo0_l00003ooooo`;o00008_ooool2o`0000Wooooo
1?l0000[ooooo`;o00005oooool2o`0000?ooooo0_l00004ooooo`;o00006Oooool2o`000003oooo
ool0003o000001Oooooo0_l0000:ooooo`;o00004?ooool2o`00017ooooo0_l0000;ooooo`;o0000
9oooool2o`0000gooooo000Yooooo`03o`000?oooooooooo00gooooo0_l0000Nooooo`;o00000_oo
ool2o`0000Wooooo1?l0000Wooooo`;o00007_ooool2o`0001Kooooo0_l0000aooooo`;o00000ooo
ool2o`0001kooooo0_l0000dooooo`;o00003Oooool002Wooooo00?o0000ooooooooool0;Oooool2
o`0001;ooooo1?l0000Pooooo`Co00007_ooool2o`0000Kooooo0_l00007ooooo`Co00000oooool2
o`000003ooooool0003o000000?ooooo0_l0000^ooooo`;o0000:?ooool2o`0001;ooooo0_l00007
ooooo`;o00003Oooool2o`0000gooooo000Yooooo`03o`000?oooooooooo01;ooooo0_l00007oooo
o`;o00009?ooool4o`0001cooooo0_l00002ooooo`?o00009oooool2o`0000Oooooo1?l00006oooo
o`;o00000oooool2o`0001;ooooo0_l0000/ooooo`;o00002oooool2o`0000Wooooo0_l0000Boooo
o`;o00001oooool2o`0001cooooo000Yooooo`03o`000?oooooooooo00gooooo0_l00003ooooo`Co
00001Oooool2o`0004Cooooo0_l00003ooooo`;o0000@Oooool2o`00013ooooo0_l0000Looooo`;o
00003_ooool2o`0000_ooooo0_l00004ooooo`;o00005_ooool2o`0000oooooo0_l0000Eooooo`00
8Oooooooo`0004Co00001?ooool002Wooooo0ol00009ooooo`03o`000?oooooooooo00[ooooo0ol0
0003ooooo`;o00001?ooool00ol0003oooooooooo`06ooooo`;o000000?oooooo`000?ooool02_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo0_l000000ooooooo0000oooo
o`0:ooooo`03o`000?oooooooooo00;o00001oooool00ol0003oooooooooo`0:ooooo`?o00002Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo0_l00004ooooo`;o00001Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo0_l000000ooooooo0000oooo
o`03ooooo`;o00001Oooool2o`0000_ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool2o`0000;ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`?o00002oooool00ol0003ooooooooo
o`0:ooooo`00:Oooool00ol0003oooooooooo`0Hooooo`;o00008?ooool00ol0003oooooooooo`0C
ooooo`;o00005?ooool2o`0000?ooooo0_l0000;ooooo`?o00003_ooool2o`0001Oooooo0_l00006
ooooo`;o00002Oooool00ol0003oooooooooo`09ooooo`;o00000oooool2o`0001kooooo0_l0000:
ooooo`03o`000?oooooooooo01;ooooo0_l00003ooooo`;o00001?ooool2o`0000cooooo0ol0000<
ooooo`03o`000?oooooooooo00[ooooo000Yooooo`03o`000?oooooooooo01Sooooo0_l0001<oooo
o`;o00000oooool2o`0000oooooo0ol0000:ooooo`;o00006oooool2o`0000;ooooo0_l0000Eoooo
o`;o00008oooool2o`0000gooooo0_l0000Eooooo`;o00001?ooool2o`0000cooooo0_l0000Joooo
o`00:Oooool00ol0003oooooooooo`0Qooooo`;o0000<Oooool2o`0000Wooooo0_l0000Kooooo`?o
00005Oooool2o`0000Wooooo0_l00005ooooo`;o0000COooool2o`000003ooooool0003o000000?o
oooo0_l0000Xooooo`;o00004oooool002Wooooo0_l0000Eooooo`;o00002oooool2o`00037ooooo
0_l00006ooooo`;o000000?oooooo`000?l000009oooool2o`0000[ooooo0_l00002ooooo`;o0000
1Oooool2o`0002[ooooo0_l00009ooooo`;o00007?ooool2o`0000;ooooo0_l00003ooooo`;o0000
8oooool2o`0000?ooooo1?l0000Aooooo`00:Oooool01?l0003oooooo`000?l0000Cooooo`;o0000
8?ooool2o`0001Cooooo0_l0000>ooooo`?o00007Oooool2o`0000Gooooo0_l00003ooooo`;o0000
3_ooool2o`00037ooooo0_l00004ooooo`;o00000oooool2o`0001cooooo0_l00009ooooo`;o0000
8Oooool2o`0000Gooooo0_l0000Aooooo`00:Oooool00ol0003oooooo`000002o`0001_ooooo0_l0
0004ooooo`;o00003Oooool2o`000004ooooool0003o0000o`0000Oooooo0_l0000;ooooo`;o0000
00?oooooo`000?l000003?ooool2o`0000Wooooo0_l00004ooooo`;o00000oooool2o`0000Oooooo
0ol00004ooooo`;o00004_ooool2o`00033ooooo0_l00006ooooo`;o000000?oooooo`000?l00000
3?ooool2o`0001_ooooo0_l00007ooooo`;o00001Oooool3o`0002[ooooo000Yooooo`03o`000?oo
oooooooo00;o00005Oooool2o`0000Cooooo0_l00004ooooo`;o00003Oooool2o`000003ooooool0
003o000000Sooooo0_l0000>ooooo`;o00005oooool2o`0000Cooooo0_l00003ooooo`;o00002?oo
ool2o`0001Sooooo0_l0000`ooooo`;o00002Oooool2o`0000cooooo0_l0000Fooooo`;o00000_oo
ool2o`0000Sooooo0_l00005ooooo`Co00002?ooool2o`0001oooooo000Yooooo`03o`000?oooooo
oooo01Oooooo0_l0000oooooo`;o0000Loooool2o`0002_ooooo0_l00002ooooo`;o00003Oooool2
o`0000;ooooo0_l00008ooooo`;o00001oooool2o`0001Kooooo000Yooooo`;o00004_ooool2o`00
00Gooooo0_l00009ooooo`;o00001Oooool2o`0000[ooooo0_l00005ooooo`;o00006Oooool2o`00
01Oooooo0_l00007ooooo`;o0000=oooool2o`0001Sooooo0ol0000^ooooo`;o00003Oooool2o`00
01Gooooo0_l0000Fooooo`00:Oooool00ol0003oooooooooo`0Aooooo`;o00001Oooool2o`0000Wo
oooo0_l00005ooooo`;o00002_ooool2o`0000Gooooo0_l0000?ooooo`;o00005oooool2o`0000So
oooo0_l00003ooooo`;o00000_ooool2o`0001Kooooo0_l0000Oooooo`;o00002oooool2o`0000co
oooo0_l0000^ooooo`;o00009Oooool2o`0001Gooooo000Yooooo`03o`000?oooooooooo04kooooo
0_l0000Gooooo`;o00003Oooool2o`0001[ooooo0_l0000Jooooo`;o00004?ooool2o`0000?ooooo
0_l0001Hooooo`;o00001?ooool2o`0001Gooooo000Yooooo`03o`000?oooooooooo02;ooooo0_l0
001aooooo`;o00005oooool2o`0001Gooooo0_l0000Mooooo`;o0000>Oooool2o`0001_ooooo000Y
ooooo`03o`000?oooooooooo01?ooooo0_l000000ooooooo0000o`00000:ooooo`;o00003_ooool2
o`0002Cooooo0_l0000kooooo`;o00006?ooool2o`0001?ooooo0_l0000Nooooo`;o0000=_ooool2
o`0001kooooo000Yooooo`;o00004oooool3o`000003ooooool0003o000000Kooooo1?l0000>oooo
o`Co00009?ooool2o`0002_ooooo0_l0000Xooooo`;o00004oooool2o`0003cooooo0_l0000Hoooo
o`;o00007_ooool002Wooooo00?o0000ooooooooool03?ooool2o`0000Cooooo0_l0000:ooooo`Co
00003_ooool2o`0001;ooooo0_l0000oooooo`;o00003_ooool2o`0000Kooooo0_l00005ooooo`;o
0000BOooool2o`000003ooooool0003o000000kooooo0_l0000hooooo`00:Oooool00ol0003ooooo
ooooo`07ooooo`;o00000oooool2o`0003Kooooo0_l0000Hooooo`;o00007oooool2o`000003oooo
ool0003o0000017ooooo0_l00002ooooo`;o00000_ooool2o`0000Gooooo0_l0000Gooooo`;o0000
1_ooool2o`0000gooooo0_l0000Iooooo`Go00007?ooool2o`0000Gooooo0_l00006ooooo`;o0000
6oooool002Wooooo00?o0000ooooooooool01oooool2o`00017ooooo0_l0000@ooooo`?o00009_oo
ool2o`0000Oooooo0ol0000Nooooo`;o000000?oooooo`000?l000005Oooool3o`0000oooooo0_l0
000:ooooo`;o00000_ooool4o`0000Kooooo0_l00007ooooo`;o00001?ooool2o`0000oooooo0_l0
0009ooooo`;o00000_ooool2o`0001[ooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l0
000Dooooo`00:Oooool00ol0003oooooooooo`0Jooooo`;o00001?ooool2o`0000[ooooo0ol0000V
ooooo`;o00002?ooool2o`0003Wooooo0ol00006ooooo`;o00001_ooool2o`0000Cooooo0_l00004
ooooo`;o00000_ooool2o`0000cooooo0_l00003ooooo`Co00003oooool2o`0000;ooooo0_l0000=
ooooo`;o00003_ooool2o`0000Sooooo0_l0000<ooooo`;o00001?ooool2o`0000;ooooo0_l0000D
ooooo`00:Oooool2o`0001_ooooo1?l00002ooooo`;o0000C_ooool2o`0001_ooooo0_l0000<oooo
o`;o00001_ooool4o`0000[ooooo0_l00003ooooo`;o00004Oooool2o`0000Gooooo0_l00006oooo
o`;o00001?ooool2o`000003ooooool0003o0000027ooooo0_l00008ooooo`;o00003?ooool2o`00
00Cooooo0_l0000Hooooo`00:Oooool00ol0003oooooooooo`0Jooooo`Co00005Oooool2o`0000Wo
oooo0_l00005ooooo`?o0000:?ooool2o`0001_ooooo0_l0000>ooooo`;o000000?oooooo`000?l0
00000oooool2o`0000oooooo0_l0000@ooooo`;o00003_ooool3o`0000?ooooo0_l0000Rooooo`;o
0000>?ooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo03?ooooo0_l00005oooo
o`?o000000?oooooo`000?l000001Oooool3o`00017ooooo0_l0000Looooo`;o00003?ooool2o`00
00gooooo0_l00007ooooo`;o000000?oooooo`000?l000001_ooool2o`0001kooooo0_l0000?oooo
o`;o00004?ooool2o`0001Gooooo0_l0000hooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo02Sooooo0_l0000@ooooo`?o00002?ooool2o`0000oooooo0_l00000
0ooooooo0000o`00000Looooo`;o00003?ooool2o`0000cooooo1Ol0000@ooooo`;o00002?ooool2
o`0003Gooooo1?l0001?ooooo`001_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RH
ob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Sooooo0_l0000/
ooooo`;o00002oooool2o`0002kooooo0_l000000ooooooo0000o`00000Jooooo`;o00001?ooool4
o`0002gooooo0_l0001Aooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000<?ooool2o`0002cooooo0_l00003
ooooo`;o0000Doooool4o`00083ooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool0
0omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool01?l0003ooooooooo
ooooool2o`0000gooooo0_l0000Nooooo`;o00001_ooool2o`0002Cooooo0_l0000Dooooo`;o0000
a_ooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01oooool01?l0003oooooooooooooool2o`0000gooooo0_l0000Cooooo`;o
00004Oooool2o`0000Oooooo0_l0000aooooo`;o0000WOooool2o`0001;ooooo0_l00003ooooo`;o
00003_ooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRH
V?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Gooooo0_l0000Joooo
o`;o0000X?ooool2o`0002kooooo0_l0000Booooo`;o00000oooool2o`0000kooooo0006ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006
ooooo`03o`000?oooooooooo01oooooo0_l0002Wooooo`;o00006Oooool2o`0003Cooooo0_l0000Q
ooooo`00:Oooool2o`0000?ooooo0_l0000Kooooo`;o0000Yoooool2o`0001Gooooo0_l0000Eoooo
o`;o00008Oooool2o`00027ooooo000Yooooo`03o`000?oooooooooo00;ooooo0_l0000<ooooo`;o
00003Oooool2o`0006?ooooo0_l0000Fooooo`;o0000@Oooool2o`0001Gooooo0_l00014ooooo`00
:Oooool00ol0003oooooooooo`0@ooooo`;o00003Oooool2o`0004kooooo0_l0000Cooooo`;o0000
5_ooool2o`0003?ooooo0_l0001Yooooo`00:Oooool00ol0003oooooooooo`1_ooooo`;o0000H?oo
ool2o`0006Wooooo000Yooooo`03o`000?oooooooooo01Gooooo0_l0002oooooo`;o0000:Oooool2
o`0000Kooooo0_l0000aooooo`00:Oooool2o`0001Kooooo0_l0000kooooo`;o00003Oooool2o`00
00Kooooo0_l0001[ooooo`;o00000_ooool2o`0002Gooooo0_l00006ooooo`;o0000<Oooool002Wo
oooo00?o0000ooooooooool01?ooool2o`0004cooooo0_l0000=ooooo`;o00001_ooool2o`0000Ko
oooo0_l00013ooooo`;o00008_ooool2o`00013ooooo0_l00009ooooo`;o0000=_ooool2o`0000_o
oooo000Yooooo`03o`000?oooooooooo00Cooooo0_l0001Vooooo`;o00000oooool2o`0000oooooo
0_l0000Xooooo`;o00002?ooool2o`0003Cooooo0_l00004ooooo`;o00000oooool2o`0003Kooooo
0_l0000;ooooo`00:Oooool00ol0003oooooooooo`0Tooooo`;o00005Oooool2o`0001[ooooo0_l0
000Cooooo`;o00002?ooool2o`0000[ooooo0_l0000Xooooo`;o00004_ooool3o`0001Wooooo0_l0
000Dooooo`;o0000B?ooool002Wooooo00?o0000ooooooooool09?ooool2o`0001Gooooo0_l0000A
ooooo`;o00001oooool2o`0001gooooo0_l00018ooooo`?o00006Oooool2o`0005kooooo000Yoooo
o`;o0000A?ooool2o`0000Wooooo0_l0002<ooooo`?o0000GOooool002Wooooo00?o0000oooooooo
ool0@oooool2o`0006gooooo0_l0000Yooooo`;o00002Oooool2o`00033ooooo0_l0000Pooooo`00
:Oooool00ol0003oooooooooo`05ooooo`;o00003_ooool2o`0003cooooo0_l0000Iooooo`;o0000
1Oooool2o`0001?ooooo0_l0000;ooooo`;o00006Oooool2o`000003ooooool0003o000002Sooooo
0_l00007ooooo`;o00007Oooool2o`00017ooooo0_l0000Pooooo`00:Oooool00ol0003ooooooooo
o`05ooooo`;o00003_ooool2o`0003cooooo0_l0000Iooooo`;o00001Oooool2o`0001?ooooo0_l0
000;ooooo`;o00007?ooool2o`0000;ooooo0_l0000Tooooo`;o00001_ooool2o`0001kooooo1?l0
000Oooooo`;o00004?ooool002Wooooo00?o0000ooooooooool03?ooool2o`0004_ooooo0_l0001N
ooooo`;o00000oooool2o`0002Oooooo0_l0000Aooooo`;o00003Oooool2o`0001oooooo0_l0000@
ooooo`00:Oooool2o`0000gooooo0_l0000Vooooo`;o00008oooool2o`0006?ooooo0_l0000joooo
o`;o00002Oooool2o`0003Gooooo000Yooooo`03o`000?oooooooooo03Cooooo0_l0000looooo`;o
0000Moooool2o`0001?ooooo0_l00003ooooo`;o0000=Oooool000kooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool07Oooool2o`0000cooooo0_l0000<ooooo`;o00003?ooool2o`0002Wooooo0_l0000Foooo
o`;o00000_ooool2o`0003;ooooo0_l0000Wooooo`;o00001_ooool2o`0000_ooooo0_l0000joooo
o`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool07Oooool2o`0000cooooo0_l0000<ooooo`;o00003?ooool2o`00
02_ooooo0_l0000Dooooo`Ko00009?ooool2o`0000cooooo0_l0000]ooooo`Co0000:oooool2o`00
01[ooooo000>ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03oooo
o`?o00008_ooool2o`00017ooooo0_l0000Looooo`;o00007oooool2o`0001Kooooo0_l00003oooo
o`;o00008Oooool2o`0001Wooooo0_l00004ooooo`;o00006_ooool2o`0001Sooooo0_l0000Coooo
o`;o00006_ooool000kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool08_ooool2o`00017ooooo0_l0000Looooo`;o00006_ooool2o`00
023ooooo0_l0000Mooooo`;o00007Oooool2o`0000Cooooo0_l0000dooooo`;o0000;oooool000ko
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`0gooooo`;o00004_ooool2o`0001cooooo0_l00004ooooo`;o00001_ooool2
o`000003ooooool0003o000003Cooooo0_l0000Aooooo`;o00005_ooool2o`0003;ooooo0_l0000[
ooooo`003_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0gooooo`;o00004_ooool2o`0001cooooo0_l0000<ooooo`;o000000?ooooo
o`000?l00000Aoooool2o`0001Kooooo0_l0000Xooooo`;o00002?ooool2o`0000Oooooo0_l0000R
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooo`Kooooo0_l0000Aooooo`;o00008_ooool000kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2
o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2
o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46oooo
o`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooo
ocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08oooo
o`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`000?oooooooooooooo
ool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<
c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolm
ooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0
003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0
003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`007oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooooooo
ool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
?Oooool0027ooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`007ooo
ool00omEEEGoIVIVo`00003oooooodOooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .36312 Mdot
.02762 .35573 Mdot
.02952 .28314 Mdot
.03143 .3343 Mdot
.03333 .26053 Mdot
.03524 .3842 Mdot
.03714 .3056 Mdot
.03905 .29033 Mdot
.04095 .32053 Mdot
.04286 .30255 Mdot
.04476 .27265 Mdot
.04667 .34379 Mdot
.04857 .338 Mdot
.05048 .3083 Mdot
.05238 .39169 Mdot
.05429 .32958 Mdot
.05619 .37739 Mdot
.0581 .33746 Mdot
.06 .25322 Mdot
.0619 .26194 Mdot
.06381 .29446 Mdot
.06571 .32006 Mdot
.06762 .27855 Mdot
.06952 .32265 Mdot
.07143 .40238 Mdot
.07333 .29872 Mdot
.07524 .25456 Mdot
.07714 .25252 Mdot
.07905 .2437 Mdot
.08095 .33483 Mdot
.08286 .25169 Mdot
.08476 .29687 Mdot
.08667 .31886 Mdot
.08857 .37885 Mdot
.09048 .38556 Mdot
.09238 .23326 Mdot
.09429 .25011 Mdot
.09619 .25324 Mdot
.0981 .2347 Mdot
.1 .32865 Mdot
.1019 .37791 Mdot
.10381 .38329 Mdot
.10571 .38309 Mdot
.10762 .3809 Mdot
.10952 .38275 Mdot
.11143 .2731 Mdot
.11333 .27564 Mdot
.11524 .25993 Mdot
.11714 .3367 Mdot
.11905 .232 Mdot
.12095 .26866 Mdot
.12286 .23081 Mdot
.12476 .48317 Mdot
.12667 .38075 Mdot
.12857 .38806 Mdot
.13048 .32495 Mdot
.13238 .30599 Mdot
.13429 .37508 Mdot
.13619 .25355 Mdot
.1381 .38423 Mdot
.14 .28902 Mdot
.1419 .42673 Mdot
.14381 .24343 Mdot
.14571 .32604 Mdot
.14762 .36282 Mdot
.14952 .30031 Mdot
.15143 .29564 Mdot
.15333 .31696 Mdot
.15524 .25457 Mdot
.15714 .30221 Mdot
.15905 .3681 Mdot
.16095 .29818 Mdot
.16286 .28385 Mdot
.16476 .3097 Mdot
.16667 .24367 Mdot
.16857 .30585 Mdot
.17048 .48314 Mdot
.17238 .33181 Mdot
.17429 .23134 Mdot
.17619 .3629 Mdot
.1781 .23968 Mdot
.18 .32776 Mdot
.1819 .33162 Mdot
.18381 .38436 Mdot
.18571 .28621 Mdot
.18762 .34167 Mdot
.18952 .2613 Mdot
.19143 .29863 Mdot
.19333 .36812 Mdot
.19524 .31259 Mdot
.19714 .40875 Mdot
.19905 .4707 Mdot
.20095 .3324 Mdot
.20286 .27444 Mdot
.20476 .33275 Mdot
.20667 .46558 Mdot
.20857 .30817 Mdot
.21048 .30115 Mdot
.21238 .48408 Mdot
.21429 .36055 Mdot
.21619 .35427 Mdot
.2181 .35709 Mdot
.22 .3608 Mdot
.2219 .37321 Mdot
.22381 .27043 Mdot
.22571 .37919 Mdot
.22762 .37571 Mdot
.22952 .25208 Mdot
.23143 .33226 Mdot
.23333 .28904 Mdot
.23524 .31141 Mdot
.23714 .33961 Mdot
.23905 .30147 Mdot
.24095 .25272 Mdot
.24286 .4858 Mdot
.24476 .26442 Mdot
.24667 .30752 Mdot
.24857 .27039 Mdot
.25048 .27543 Mdot
.25238 .27752 Mdot
.25429 .33025 Mdot
.25619 .41115 Mdot
.2581 .26191 Mdot
.26 .2491 Mdot
.2619 .29564 Mdot
.26381 .32834 Mdot
.26571 .2416 Mdot
.26762 .46067 Mdot
.26952 .31867 Mdot
.27143 .29094 Mdot
.27333 .30325 Mdot
.27524 .34286 Mdot
.27714 .36197 Mdot
.27905 .38968 Mdot
.28095 .38306 Mdot
.28286 .23986 Mdot
.28476 .22984 Mdot
.28667 .23971 Mdot
.28857 .28167 Mdot
.29048 .34314 Mdot
.29238 .38591 Mdot
.29429 .45103 Mdot
.29619 .33961 Mdot
.2981 .2558 Mdot
.3 .37715 Mdot
.3019 .26081 Mdot
.30381 .28002 Mdot
.30571 .48529 Mdot
.30762 .27268 Mdot
.30952 .29837 Mdot
.31143 .38365 Mdot
.31333 .35123 Mdot
.31524 .2674 Mdot
.31714 .32971 Mdot
.31905 .30301 Mdot
.32095 .3656 Mdot
.32286 .23383 Mdot
.32476 .23612 Mdot
.32667 .28758 Mdot
.32857 .25968 Mdot
.33048 .23245 Mdot
.33238 .31571 Mdot
.33429 .23406 Mdot
.33619 .3344 Mdot
.3381 .23379 Mdot
.34 .37233 Mdot
.3419 .3399 Mdot
.34381 .28393 Mdot
.34571 .27226 Mdot
.34762 .25458 Mdot
.34952 .23017 Mdot
.35143 .23342 Mdot
.35333 .33684 Mdot
.35524 .25341 Mdot
.35714 .28023 Mdot
.35905 .26456 Mdot
.36095 .3424 Mdot
.36286 .46453 Mdot
.36476 .36392 Mdot
.36667 .27313 Mdot
.36857 .23332 Mdot
.37048 .2328 Mdot
.37238 .34479 Mdot
.37429 .32761 Mdot
.37619 .37965 Mdot
.3781 .30334 Mdot
.38 .33247 Mdot
.3819 .4624 Mdot
.38381 .26907 Mdot
.38571 .33709 Mdot
.38762 .38595 Mdot
.38952 .4045 Mdot
.39143 .26434 Mdot
.39333 .32463 Mdot
.39524 .43098 Mdot
.39714 .2923 Mdot
.39905 .37268 Mdot
.40095 .35966 Mdot
.40286 .2765 Mdot
.40476 .47297 Mdot
.40667 .37748 Mdot
.40857 .26908 Mdot
.41048 .26949 Mdot
.41238 .2949 Mdot
.41429 .2754 Mdot
.41619 .47557 Mdot
.4181 .33858 Mdot
.42 .32119 Mdot
.4219 .38023 Mdot
.42381 .34193 Mdot
.42571 .29317 Mdot
.42762 .28068 Mdot
.42952 .3466 Mdot
.43143 .32671 Mdot
.43333 .26997 Mdot
.43524 .31749 Mdot
.43714 .33592 Mdot
.43905 .32779 Mdot
.44095 .34156 Mdot
.44286 .28753 Mdot
.44476 .36894 Mdot
.44667 .315 Mdot
.44857 .302 Mdot
.45048 .28266 Mdot
.45238 .28187 Mdot
.45429 .23498 Mdot
.45619 .3058 Mdot
.4581 .25837 Mdot
.46 .37256 Mdot
.4619 .33771 Mdot
.46381 .39087 Mdot
.46571 .40581 Mdot
.46762 .33536 Mdot
.46952 .31773 Mdot
.47143 .47674 Mdot
.47333 .36166 Mdot
.47524 .26163 Mdot
.47714 .41257 Mdot
.47905 .25305 Mdot
.48095 .37261 Mdot
.48286 .28983 Mdot
.48476 .3476 Mdot
.48667 .43033 Mdot
.48857 .38869 Mdot
.49048 .27311 Mdot
.49238 .3681 Mdot
.49429 .27801 Mdot
.49619 .33467 Mdot
.4981 .24902 Mdot
.5 .37457 Mdot
.5019 .36704 Mdot
.50381 .23818 Mdot
.50571 .37663 Mdot
.50762 .26458 Mdot
.50952 .33026 Mdot
.51143 .26102 Mdot
.51333 .32184 Mdot
.51524 .25342 Mdot
.51714 .39052 Mdot
.51905 .30765 Mdot
.52095 .31942 Mdot
.52286 .25499 Mdot
.52476 .3491 Mdot
.52667 .26228 Mdot
.52857 .23482 Mdot
.53048 .27833 Mdot
.53238 .35793 Mdot
.53429 .35743 Mdot
.53619 .26484 Mdot
.5381 .36965 Mdot
.54 .23342 Mdot
.5419 .3407 Mdot
.54381 .23771 Mdot
.54571 .38918 Mdot
.54762 .31406 Mdot
.54952 .35724 Mdot
.55143 .23129 Mdot
.55333 .33169 Mdot
.55524 .25053 Mdot
.55714 .27686 Mdot
.55905 .29464 Mdot
.56095 .37434 Mdot
.56286 .23344 Mdot
.56476 .26947 Mdot
.56667 .29971 Mdot
.56857 .26598 Mdot
.57048 .35052 Mdot
.57238 .25245 Mdot
.57429 .30497 Mdot
.57619 .29202 Mdot
.5781 .27181 Mdot
.58 .29318 Mdot
.5819 .23958 Mdot
.58381 .46334 Mdot
.58571 .26604 Mdot
.58762 .37945 Mdot
.58952 .28746 Mdot
.59143 .3181 Mdot
.59333 .23876 Mdot
.59524 .43467 Mdot
.59714 .28311 Mdot
.59905 .38878 Mdot
.60095 .4848 Mdot
.60286 .34833 Mdot
.60476 .392 Mdot
.60667 .34919 Mdot
.60857 .28623 Mdot
.61048 .3884 Mdot
.61238 .27876 Mdot
.61429 .28637 Mdot
.61619 .32196 Mdot
.6181 .2667 Mdot
.62 .33458 Mdot
.6219 .37797 Mdot
.62381 .32197 Mdot
.62571 .38303 Mdot
.62762 .26711 Mdot
.62952 .36429 Mdot
.63143 .38073 Mdot
.63333 .36667 Mdot
.63524 .27056 Mdot
.63714 .35238 Mdot
.63905 .42234 Mdot
.64095 .44731 Mdot
.64286 .32862 Mdot
.64476 .39263 Mdot
.64667 .38498 Mdot
.64857 .24734 Mdot
.65048 .25167 Mdot
.65238 .26637 Mdot
.65429 .31303 Mdot
.65619 .37538 Mdot
.6581 .30533 Mdot
.66 .2721 Mdot
.6619 .33012 Mdot
.66381 .33816 Mdot
.66571 .28663 Mdot
.66762 .29242 Mdot
.66952 .37011 Mdot
.67143 .38688 Mdot
.67333 .37276 Mdot
.67524 .31827 Mdot
.67714 .27673 Mdot
.67905 .48256 Mdot
.68095 .33514 Mdot
.68286 .31741 Mdot
.68476 .33046 Mdot
.68667 .32786 Mdot
.68857 .25472 Mdot
.69048 .23861 Mdot
.69238 .30296 Mdot
.69429 .33551 Mdot
.69619 .32556 Mdot
.6981 .44944 Mdot
.7 .33346 Mdot
.7019 .23192 Mdot
.70381 .23341 Mdot
.70571 .33772 Mdot
.70762 .38012 Mdot
.70952 .23252 Mdot
.71143 .35921 Mdot
.71333 .3362 Mdot
.71524 .44117 Mdot
.71714 .27199 Mdot
.71905 .36461 Mdot
.72095 .35569 Mdot
.72286 .36118 Mdot
.72476 .28552 Mdot
.72667 .35877 Mdot
.72857 .39004 Mdot
.73048 .31108 Mdot
.73238 .28428 Mdot
.73429 .24765 Mdot
.73619 .34835 Mdot
.7381 .38547 Mdot
.74 .35616 Mdot
.7419 .30779 Mdot
.74381 .37087 Mdot
.74571 .24882 Mdot
.74762 .26683 Mdot
.74952 .27774 Mdot
.75143 .22944 Mdot
.75333 .29765 Mdot
.75524 .39601 Mdot
.75714 .48771 Mdot
.75905 .28842 Mdot
.76095 .37344 Mdot
.76286 .29288 Mdot
.76476 .41079 Mdot
.76667 .363 Mdot
.76857 .31371 Mdot
.77048 .33849 Mdot
.77238 .3003 Mdot
.77429 .26862 Mdot
.77619 .30388 Mdot
.7781 .30531 Mdot
.78 .25843 Mdot
.7819 .25795 Mdot
.78381 .30582 Mdot
.78571 .4339 Mdot
.78762 .346 Mdot
.78952 .38032 Mdot
.79143 .48065 Mdot
.79333 .3809 Mdot
.79524 .26021 Mdot
.79714 .25492 Mdot
.79905 .31488 Mdot
.80095 .31208 Mdot
.80286 .34438 Mdot
.80476 .25501 Mdot
.80667 .33823 Mdot
.80857 .29398 Mdot
.81048 .33819 Mdot
.81238 .38341 Mdot
.81429 .26324 Mdot
.81619 .2361 Mdot
.8181 .33943 Mdot
.82 .2627 Mdot
.8219 .27758 Mdot
.82381 .26415 Mdot
.82571 .37871 Mdot
.82762 .27023 Mdot
.82952 .32254 Mdot
.83143 .39894 Mdot
.83333 .33908 Mdot
.83524 .27674 Mdot
.83714 .38607 Mdot
.83905 .376 Mdot
.84095 .35017 Mdot
.84286 .35125 Mdot
.84476 .25455 Mdot
.84667 .40442 Mdot
.84857 .46553 Mdot
.85048 .36173 Mdot
.85238 .48606 Mdot
.85429 .38336 Mdot
.85619 .31932 Mdot
.8581 .34431 Mdot
.86 .3942 Mdot
.8619 .26309 Mdot
.86381 .29178 Mdot
.86571 .48282 Mdot
.86762 .33885 Mdot
.86952 .27024 Mdot
.87143 .27278 Mdot
.87333 .23746 Mdot
.87524 .35684 Mdot
.87714 .47202 Mdot
.87905 .30187 Mdot
.88095 .3799 Mdot
.88286 .38399 Mdot
.88476 .32624 Mdot
.88667 .27203 Mdot
.88857 .32537 Mdot
.89048 .29453 Mdot
.89238 .26521 Mdot
.89429 .234 Mdot
.89619 .36117 Mdot
.8981 .3736 Mdot
.9 .24068 Mdot
.9019 .24038 Mdot
.90381 .37911 Mdot
.90571 .45468 Mdot
.90762 .3042 Mdot
.90952 .30548 Mdot
.91143 .37066 Mdot
.91333 .2607 Mdot
.91524 .23519 Mdot
.91714 .34687 Mdot
.91905 .37678 Mdot
.92095 .24082 Mdot
.92286 .3588 Mdot
.92476 .25163 Mdot
.92667 .32368 Mdot
.92857 .38047 Mdot
.93048 .41263 Mdot
.93238 .37598 Mdot
.93429 .29838 Mdot
.93619 .37843 Mdot
.9381 .36067 Mdot
.94 .29432 Mdot
.9419 .31849 Mdot
.94381 .3822 Mdot
.94571 .38737 Mdot
.94762 .26583 Mdot
.94952 .32485 Mdot
.95143 .30212 Mdot
.95333 .25438 Mdot
.95524 .35756 Mdot
.95714 .26686 Mdot
.95905 .26108 Mdot
.96095 .27868 Mdot
.96286 .48889 Mdot
.96476 .27386 Mdot
.96667 .36319 Mdot
.96857 .30601 Mdot
.97048 .23418 Mdot
.97238 .25382 Mdot
.97429 .23666 Mdot
.97619 .34438 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Looooo`;o0000<_oo
ool2o`0001?ooooo0_l0001oooooo`;o0000E?ooool000Kooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0001;ooooo0_l0
0007ooooo`?o00003oooool2o`00027ooooo0_l0000:ooooo`;o000000?oooooo`000?l000000_l0
0002ooooo`?o00000oooool3o`0003Cooooo0_l00002ooooo`;o00000_ooool2o`0002[ooooo1Ol0
000;ooooo`;o0000;?ooool2o`0001Oooooo0_l0000=ooooo`001_ooool01Ol0003ooooooooooooo
oooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool04_ooool4o`0000Gooooo0_l0000@ooooo`;o0000;Oooool7o`0000?ooooo
0_l00003ooooo`?o00006Oooool2o`0001Kooooo0_l000000ooooooo0000o`000002ooooo`;o0000
0_ooool2o`0002[ooooo1Ol0000Pooooo`;o00005oooool2o`0000Gooooo0_l0000@ooooo`?o0000
3?ooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Dooooo`;o00006?ooool2o`00023ooooo
0ol0000:ooooo`;o0000:?ooool2o`0000kooooo0_l00006ooooo`;o00000_ooool2o`0000_ooooo
0_l000000ooooooo0000o`00000Nooooo`;o00009_ooool2o`00013ooooo0_l00008ooooo`;o0000
0_ooool2o`00017ooooo0_l0000<ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool08oooool2o`0000Wooooo0_l0000Jooooo`;o00001?ooool3o`0004Cooooo0_l0000:ooooo`;o
00002oooool2o`000003ooooool0003o000001kooooo0_l0000hooooo`;o00001oooool3o`0000Co
oooo0_l0000Mooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`0>ooooo`;o00004oooool2o`00
00Gooooo0_l0000Nooooo`;o0000b_ooool2o`0000Gooooo0_l0000Mooooo`00:Oooool2o`0000oo
oooo0_l0000Jooooo`;o00007?ooool2o`0004_ooooo0_l0000^ooooo`;o00006_ooool2o`000003
ooooool0003o000005Kooooo000Yooooo`03o`000?oooooooooo00gooooo1?l00002ooooo`;o0000
:Oooool2o`0000;ooooo0_l00004ooooo`;o0000Boooool2o`00013ooooo0_l00004ooooo`;o0000
5_ooool3o`0001Wooooo0_l000000ooooooo0000o`00000hooooo`;o00007?ooool002Wooooo00?o
0000ooooooooool02?ooool2o`0000?ooooo1?l00002ooooo`?o00002_ooool2o`0000Gooooo0_l0
000Eooooo`;o00000_ooool2o`00013ooooo0_l0000>ooooo`;o000000?oooooo`000?l000009_oo
ool2o`0000Wooooo0_l000000ooooooo0000o`000008ooooo`;o00001?ooool2o`0001Oooooo0_l0
000:ooooo`;o00008Oooool4o`0000_ooooo0_l0000Hooooo`;o00001oooool2o`0000Cooooo0_l0
000=ooooo`00:Oooool00ol0003oooooooooo`08ooooo`;o00000oooool2o`0000Gooooo0_l0000:
ooooo`;o00001Oooool2o`0002_ooooo0_l0000>ooooo`;o000000?oooooo`000?l000007oooool2
o`0000Gooooo0_l00009ooooo`;o000000?oooooo`000?l00000<oooool2o`0001_ooooo0ol00003
ooooo`Co00002oooool2o`00027ooooo0_l00004ooooo`;o00003Oooool002Wooooo00Co0000oooo
ool0003o00002?ooool2o`0000oooooo0_l0000Fooooo`;o00005?ooool2o`0000cooooo0_l00006
ooooo`;o0000:?ooool2o`0000?ooooo0_l0000:ooooo`;o0000E?ooool3o`0000;ooooo0_l0000T
ooooo`;o00003Oooool2o`00017ooooo000Yooooo`Co00002?ooool2o`0000oooooo0_l0000Foooo
o`;o00003oooool2o`0000?ooooo0_l0000<ooooo`;o00001_ooool2o`0000Sooooo0_l00008oooo
o`;o00006Oooool2o`0000Wooooo0ol00003ooooo`;o000000?oooooo`000?l00000DOooool2o`00
00Cooooo1_l0000:ooooo`;o00002?ooool2o`0000Cooooo0_l0000=ooooo`;o00004Oooool002Wo
oooo00?o0000ooooooooool0@oooool2o`0001Gooooo0_l0000<ooooo`;o00002?ooool2o`0002Co
oooo0_l00004ooooo`;o000000?oooooo`000?l000002?ooool2o`0000Cooooo0_l00008ooooo`;o
000000?oooooo`000?l000001_ooool2o`0001gooooo0_l0000Cooooo`Ko00002_ooool2o`0000So
oooo0_l0000?ooooo`;o000000?oooooo`000?l000004_ooool002Wooooo00?o0000ooooooooool0
7?ooool2o`0001;ooooo1?l000002Ol@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^ooooo`02
o`000006onk^k_lb<S;o0000oc8b<_o^k^kooooo0_l0000Cooooo`;o00004Oooool5o`0000?ooooo
00?ok^k^oc8b<_l000000ol00002ooooo`03onk^k_lb<S;o000000;o0000:?ooool3o`000004oc8b
<_o<c<coooooooooo`;o000000Co<S8bo`000?lb<S;ok^k^0oooool01?o^k^ko0000o`000?lb<S82
o`000003ooooool0003o000000?ooooo0_l0000Mooooo`;o00000_ooool2o`000003oa0@4?oooooo
oooo00;o000000Co<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
0_l0000;ooooo`;o00005oooool5o`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool002Wooooo00?o0000ooooooooool00oooool2o`0001?o
oooo0_l00002ooooo`;o00005?ooool01?l0003oooooooooooooool2o`000005oiRHV?ooooooV9RH
ogMgMoooool00_l000001_mgMgOoV9RHoooooonHV9SoMgMgooooo`;o00004Oooool2o`0000[ooooo
0_l00005ooooo`;o000000?oV9RHob4Q8Oo^k^h00_l00003ooooo`03ogMgMonHV9Sooooo00?o0000
0_ooool00omgMgOoV9RHooooo`02o`00013ooooo0_l0000Fooooo`;o000000CoooooogMgMol0003o
00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02
ooooo`;o00001_ooool2o`00013ooooo0_l0000=ooooo`04o`000?ooooooooooooooo`;o000000Co
V9RHoooooonHV9SoMgMg0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0_l0000;ooooo`?o
00000oooool2o`0001Cooooo00?oMgMgoc8b<_ooool00_l000001?nHV9SooooooiRHV?mgMgL3oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wooooo00?o0000ooooooooool00oooool2o`00
01?ooooo0ol0000Gooooo`04o`000?ooooooooooooooo`;o00000oooool01Ol@413ooooooooooooo
oooo410@00?ooooo00?o410@ooooool000000_l0000@ooooo`;o00002_ooool2o`0000Gooooo0_l0
00001?ooooooV9RHob4Q8Oo^k^h4ooooo`05oa0@4?l0003o0000ooooool@41000_l000000ooooooo
410@ooooo`02ooooo`03oa0@4?oooooooooo00kooooo0_l0000Dooooo`;o00001?ooool2o`0000;o
oooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002_ooool2
o`0000?ooooo0_l0000;ooooo`;o00002_ooool5o`0000?ooooo00Go410@oooooooooooooooooa0@
4003ooooo`06oa0@4?ooooooooooooooool@413ooooo0_l00002ooooo`;o00002_ooool2o`0000?o
oooo0_l0000Eooooo`04o`000?oooooo0000o`0000?ooooo00Go410@oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo007ooooo000Yooooo`;o00002oooool2o`0000gooooo0_l0000Goooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`06o`000?oooooo
ooooooooool0003ooooo0ol0000>ooooo`;o00003oooool2o`0000Kooooo00?oV9RHob4Q8Oo^k^h0
0oooool3o`000005ooooool0003o0000o`000?ooool00ol000000ooooooo0000ooooo`0Aooooo`;o
00002Oooool2o`0000Oooooo0_l00003ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`;o00000_ooool00ol0003oooooooooo`0=ooooo`;o00005_ooool2o`00
0003omgMgOoooooo000000Cooooo00Go0000ooooooooooooooooo`000003ooooo`06o`000?oooooo
ooooooooool0003ooooo0_l00002ooooo`;o00009Oooool00omgMgOo<S8bo`000002o`0000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo007ooooo000Yooooo`?o0000
2_ooool2o`0001gooooo0_l00007ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000003Oooool2o`0000?ooooo0_l0000;oooo
o`;o00000_ooool2o`0000Oooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo
000000?ooooo0ol000000ooooooo0000ooooo`02ooooo`?o00003?ooool2o`0000Wooooo0_l0000;
ooooo`03oa0@4?l0003o^[Zj00?ooooo00?o0000ooooooooool00_l00003ooooo`;o00000_ooool0
0ol0003oooooooooo`0Uooooo`;o000000?oEEEEooooool000001?ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`00000Yooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`00ol00003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`01oooo
o`00:Oooool3o`0002Wooooo0_l00005ooooo`?o00001?ooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@400=ooooo`;o00004?ooool2o`0000cooooo00Go0000
oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01?l@413ooooo
ooooooooool3o`0002Gooooo00?o^[Zjob4Q8Oooool00_ooool00ol@413oooooooooo`02o`000003
ooooool0003o000000;o00000_ooool00ol@413oooooooooo`0:ooooo`;o00004Oooool4o`0000Ko
oooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooo
oooooooooooooa0@400Yooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool002Wooooo00?o0000ooooooooool08_oo
ool2o`0000cooooo0ol00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOo0000
o`000?nHV9SoMgMg01[ooooo0_l0000=ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00KoMgMgoiRHV?ooooooV9RHogMgMoooool2o`0000_ooooo
0_l0000Hooooo`05oa0@4?nHV9SooooookZj^_l000000oooool2o`000004oooooonHV9SoMgMgoooo
o`Co000000?ooooooiRHV?mgMgL03?ooool2o`00017ooooo1?l00006ooooo`03onk^k_l0003o0000
00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:Ooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo000Yooooo`04o`000?ooooooooooooooo`;o00007oooool2o`0000co
oooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^o`00
0?l0003o<S8bonk^kP08ooooo`;o00004?ooool2o`0000gooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c002ooooo`;o000000Co<S8bo`000?lb<S;ok^k^0oooool3o`000003oc8b<_o^k^kooooo00;o0000
2oooool2o`0001Sooooo00CoZJVYoa0@4?l0003o410@0ol000001_oooooo0000o`000?l0003o<S8b
onk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`;o00007?ooool3o`0000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool2o`0001Wo
oooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo000Yooooo`;o00000_ooool2o`0000Kooooo0_l0000Jooooo`;o00008_ooool2o`00
0003ooooool0003o000002Kooooo0_l00003ooooo`;o00000_ooool2o`0002Wooooo0_l00004oooo
o`?o00006_ooool2o`0001gooooo0_l0000=ooooo`;o00003oooool2o`0000Oooooo0_l0000>oooo
o`;o00005oooool002Wooooo00?o0000ooooooooool02Oooool2o`000003ooooool0003o000000;o
oooo0_l0000Cooooo`;o000000?oooooo`000?l000002?ooool2o`0001Gooooo0_l0000=ooooo`;o
00007oooool2o`0002gooooo0_l0000mooooo`;o00004?ooool2o`0001Sooooo0_l0000<ooooo`Co
00005oooool002Wooooo00?o0000ooooooooool00_ooool2o`0000Sooooo0_l00002ooooo`;o0000
4oooool5o`0000Sooooo0_l00004ooooo`;o00001oooool2o`0001Gooooo0_l0000[ooooo`;o0000
9?ooool2o`0003[ooooo0_l00004ooooo`;o00008?ooool2o`00013ooooo0_l00004ooooo`;o0000
4oooool002Wooooo00Co0000oooooooooooooooo0ol0000Qooooo`Co00003oooool2o`0000Oooooo
0_l0000:ooooo`;o00003?ooool2o`00017ooooo0_l0000Eooooo`;o00009?ooool4o`0001Wooooo
0_l00009ooooo`;o00006?ooool4o`0001kooooo0_l00007ooooo`?o00003?ooool2o`0001?ooooo
000Yooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0001Sooooo0_l0000:ooooo`;o0000
2oooool2o`0000[ooooo0_l00007ooooo`;o00003?ooool2o`00017ooooo0_l0000Gooooo`;o0000
4oooool2o`0000oooooo0_l0000Iooooo`;o00002Oooool2o`0000kooooo0_l00009ooooo`Go0000
9Oooool3o`00017ooooo0_l0000>ooooo`008Oooooooo`0004Co00001?ooool002Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool01Oooool2o`0000;ooooo00?o0000ooooooooool00_ooool2o`0000Gooooo00?o0000
ooooooooool00oooool2o`0000Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09
ooooo`;o00002_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo0_l00002
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03
ooooo`;o00001?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo0_l00005
ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`04o`000?ooooooooooooooo`;o00001_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo000Yooooo`03o`000?oooooo
oooo02Kooooo0_l0000;ooooo`;o00001Oooool00ol0003oooooooooo`0Rooooo`;o00005oooool0
0ol0003oooooooooo`06ooooo`;o000000?oooooo`000?l000001_ooool2o`0001Oooooo0_l0000<
ooooo`?o00004Oooool2o`0000Oooooo0_l0000Jooooo`;o00001?ooool01?l0003ooooooooooooo
ool2o`0003Oooooo00?o0000ooooooooool02_ooool002Wooooo00?o0000ooooooooool00_ooool2
o`0000Kooooo0_l00004ooooo`;o00005?ooool2o`0002?ooooo0_l0000Booooo`;o00006oooool2
o`0000?ooooo0_l00009ooooo`;o00003_ooool2o`0001Gooooo0_l0000Iooooo`Co0000=_ooool2
o`0001Wooooo0_l0000Gooooo`00:Oooool00ol0003oooooooooo`02ooooo`;o00001_ooool3o`00
00?ooooo0_l0000iooooo`;o0000;oooool2o`0001cooooo1?l0000Mooooo`Co00003oooool2o`00
02oooooo0_l00007ooooo`;o00005Oooool2o`0000;ooooo0_l0000Gooooo`00:Oooool2o`0000co
oooo0_l0000Booooo`;o00000_ooool2o`0004kooooo0_l0000:ooooo`;o00006Oooool2o`0001oo
oooo1?l0000Eooooo`;o0000:Oooool2o`00013ooooo0ol0000;ooooo`;o00001Oooool2o`0001Co
oooo000Yooooo`03o`000?oooooooooo00Kooooo0_l0000=ooooo`;o00002?ooool2o`0000;ooooo
0_l00009ooooo`;o00005_ooool2o`000003ooooool0003o0000013ooooo0_l0000@ooooo`;o0000
1?ooool2o`0000[ooooo0_l000000ooooooo0000o`00000Dooooo`;o0000:Oooool2o`0000Cooooo
0_l00006ooooo`;o000000?oooooo`000?l00000>oooool3o`0001;ooooo0_l0000Dooooo`00:Ooo
ool00ol0003oooooooooo`06ooooo`;o00003Oooool2o`0001Gooooo1Ol00004ooooo`?o00001ooo
ool2o`0000Gooooo0_l000000ooooooo0000o`00000@ooooo`;o00004?ooool4o`00017ooooo0_l0
000Dooooo`;o00003Oooool2o`0001[ooooo0_l00004ooooo`;o00001_ooool2o`0000?ooooo0_l0
001Tooooo`00:Oooool01?l0003oooooo`000?l0000>ooooo`;o00002Oooool2o`00013ooooo0_l0
00000ooooooo0000o`000004ooooo`?o00001oooool2o`00023ooooo0_l0000<ooooo`;o00004?oo
ool2o`0000Sooooo0_l00007ooooo`;o00004Oooool2o`0001?ooooo0_l0000Booooo`;o00000_oo
ool4o`0000;ooooo0_l0001Pooooo`00:Oooool01?l0003oooooo`000?l00003ooooo`;o000000?o
ooooo`000?l000001_ooool2o`0000Wooooo0_l0000Uooooo`;o00004Oooool2o`0000_ooooo1?l0
00000ooooooo0000o`000009ooooo`;o00002?ooool2o`0000Cooooo0_l00006ooooo`Co00001ooo
ool2o`0002Kooooo0_l0000<ooooo`;o00001?ooool2o`0000;ooooo0_l00002ooooo`Co00004?oo
ool2o`0000[ooooo0ol000000ooooooo0000o`000003ooooo`;o00002Oooool2o`0002kooooo000Y
ooooo`;o00001Oooool2o`000003ooooool0003o000002Sooooo0_l0000>ooooo`;o00002_ooool2
o`0000Gooooo0_l0000=ooooo`;o000000Coooooo`000?l0003ooooo0_l00006ooooo`;o00002?oo
ool4o`0000?ooooo0_l00005ooooo`;o00006?ooool2o`0002Gooooo0_l0000<ooooo`;o00004_oo
ool2o`0000[ooooo0ol000000ooooooo0000o`000003ooooo`;o00002Oooool2o`0002kooooo000Y
ooooo`03o`000?oooooooooo00Cooooo0_l0000[ooooo`;o00006_ooool2o`0000?ooooo0_l0000E
ooooo`;o000000?oooooo`000?l000003oooool2o`0000?ooooo0_l0000Oooooo`;o0000COooool2
o`0000?ooooo0_l0000@ooooo`;o00009?ooool2o`0000_ooooo000Yooooo`03o`000?oooooooooo
00Cooooo0_l0001<ooooo`;o00006?ooool2o`00017ooooo0_l0000?ooooo`;o00002oooool2o`00
01Oooooo1?l0000Wooooo`;o00003oooool2o`0000?ooooo0_l0000@ooooo`;o00004Oooool2o`00
017ooooo0_l0000;ooooo`00:Oooool00ol0003oooooooooo`1Iooooo`;o00009?ooool2o`0000oo
oooo0_l0000;ooooo`;o00003Oooool2o`0000Sooooo1?l0000Wooooo`;o00008?ooool3o`0001Ko
oooo0_l0000Nooooo`00:Oooool00ol0003oooooooooo`0jooooo`;o00007Oooool2o`00057ooooo
0_l0000Cooooo`;o0000@?ooool3o`0003Kooooo000Yooooo`;o0000>oooool3o`0006?ooooo0_l0
0003ooooo`;o00006_ooool2o`0001Wooooo0_l00005ooooo`;o0000:Oooool2o`0001Sooooo0_l0
000Booooo`00:Oooool2o`0003_ooooo0ol0000iooooo`;o00005Oooool2o`00017ooooo0_l00003
ooooo`;o0000<_ooool2o`000003ooooool0003o000000;o00000oooool2o`0002Wooooo0_l00005
ooooo`;o00001_ooool2o`0000?ooooo0_l00004ooooo`;o00004_ooool002Wooooo0_l0000Uoooo
o`;o00001oooool2o`0000_ooooo0ol0000Aooooo`;o00006_ooool2o`0000[ooooo0_l0000Eoooo
o`;o0000<?ooool2o`0001Sooooo0_l000000ooooooo0000o`000002o`0000_ooooo0_l0000Ioooo
o`;o00003Oooool2o`0000Kooooo0_l00003ooooo`;o00001oooool2o`0000oooooo000Yooooo`;o
00009Oooool2o`0000Oooooo0_l0000Oooooo`;o00003?ooool2o`0000cooooo0_l0000Zooooo`;o
00009oooool3o`0001[ooooo0_l0000=ooooo`;o00006Oooool2o`0002?ooooo0_l0000?ooooo`00
:Oooool00ol0003oooooooooo`0Xooooo`;o00002Oooool2o`0002Oooooo0_l0000Vooooo`;o0000
3Oooool2o`000003ooooool0003o000000[ooooo0_l0000Looooo`;o00002_ooool2o`0001Kooooo
0_l0000dooooo`;o00008?ooool002Wooooo0_l0000Yooooo`;o00002Oooool2o`0000Oooooo0_l0
000Tooooo`;o00004Oooool2o`0000gooooo0_l00003ooooo`;o00001?ooool2o`0000;ooooo0_l0
000=ooooo`;o0000:?ooool3o`0001Gooooo0_l00003ooooo`;o0000:_ooool2o`0000?ooooo0_l0
000Pooooo`00:Oooool00ol0003oooooooooo`0Pooooo`;o00006_ooool4o`0001Gooooo0_l0000;
ooooo`;o00004Oooool2o`0001;ooooo0_l00004ooooo`;o00001?ooool4o`00013ooooo0_l0000M
ooooo`;o00000oooool2o`0001[ooooo0_l0000Gooooo`;o00004Oooool2o`0000Gooooo0_l00002
ooooo`;o00006_ooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00Oooooo0_l0
0008ooooo`;o00000_ooool2o`0000Wooooo0_l0000Kooooo`?o00005Oooool2o`0001Oooooo0_l0
0007ooooo`;o00000oooool2o`0001Oooooo1?l0000@ooooo`;o00001oooool2o`0000Wooooo0_l0
0009ooooo`;o00003_ooool2o`0001Sooooo0_l0000:ooooo`;o00000_ooool2o`0000cooooo0_l0
0005ooooo`;o00000oooool2o`0000;ooooo1?l0000Hooooo`001_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo00Oooooo0_l00008ooooo`;o00000_ooool5o`0000?ooooo
0_l0000Nooooo`;o00004?ooool2o`0001gooooo0_l00007ooooo`;o00000oooool2o`0003Cooooo
0_l00009ooooo`Go00005_ooool2o`0001Sooooo1?l00004ooooo`;o00000_ooool2o`0000Oooooo
0_l00007ooooo`;o00001Oooool2o`0000Kooooo0_l000000ooooooo0000o`000002o`0001Kooooo
0006ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_l0000@ooooo`;o00000_ooool4o`0000?ooooo
0_l00002ooooo`;o00003Oooool2o`0001gooooo0_l00002ooooo`;o00001?ooool2o`0001Kooooo
0_l0001;ooooo`Co00000oooool2o`0001_ooooo0_l0000@ooooo`;o00001?ooool2o`0000Kooooo
0_l00003ooooo`;o00001oooool2o`0000gooooo0_l00003ooooo`;o00005_ooool000Kooooo00Go
0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0
1?ooool5o`00013ooooo0_l0000:ooooo`;o000000?oooooo`000?l000003Oooool2o`0001cooooo
0_l00003ooooo`;o00001?ooool2o`0001Kooooo0_l0000Oooooo`;o00004?ooool2o`0000oooooo
0_l00002ooooo`;o00002_ooool2o`0000Kooooo0_l0000Cooooo`;o00007_ooool2o`0000cooooo
0_l0000Cooooo`;o00005Oooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMg
MomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00Go
oooo0_l0000Gooooo`;o0000;_ooool2o`0003[ooooo0_l00006ooooo`;o00001oooool2o`0000Oo
oooo0_l0000?ooooo`Ko00002Oooool2o`0000Oooooo0_l0000@ooooo`;o0000A?ooool2o`0001Go
oooo0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool2o`0008?ooooo0_l0000?ooooo`;o
00006_ooool2o`0000_ooooo0_l0000Iooooo`;o0000:?ooool2o`00037ooooo0006ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`3Wooooo`;o00005oooool2o`0000Oooooo0_l0000aoooo
o`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004
ooooo`Co00001_ooool00ol0003oooooooooo`3Wooooo`;o00005oooool2o`0003[ooooo000Yoooo
o`;o00003Oooool2o`0006Cooooo0_l0002Aooooo`;o0000=Oooool002Wooooo00?o0000oooooooo
ool03?ooool2o`0006Cooooo0_l0000Fooooo`;o0000NOooool2o`0003Gooooo000Yooooo`03o`00
0?oooooooooo03Cooooo0_l0000Aooooo`;o0000@Oooool2o`0005oooooo0_l0001?ooooo`00:Ooo
ool00ol0003oooooooooo`0dooooo`;o00004Oooool2o`0004Gooooo0_l0001Kooooo`;o0000<ooo
ool2o`0001[ooooo000Yooooo`03o`000?oooooooooo08kooooo0_l0002@ooooo`;o00006_ooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0<;ooooo0_l0001hooooo`00
:Oooool00ol0003oooooooooo`0Rooooo`;o0000W_ooool2o`0007Sooooo000Yooooo`03o`000?oo
oooooooo02;ooooo0_l0003ooooooaWooooo000Yooooo`03o`000?oooooooooo07Cooooo0_l0000K
ooooo`;o0000ZOooool002Wooooo0_l0001eooooo`;o00006oooool2o`00027ooooo0_l0000koooo
o`;o0000BOooool002Wooooo00?o0000ooooooooool0]?ooool2o`0003_ooooo0_l00019ooooo`00
:Oooool00ol0003oooooooooo`3Kooooo`;o0000Goooool002Wooooo00?o0000ooooooooool0fooo
ool2o`0005oooooo000Yooooo`03o`000?oooooooooo0<?ooooo0_l0001gooooo`00:Oooool2o`00
05Cooooo0_l0001^ooooo`;o00004?ooool2o`0006Gooooo000Yooooo`03o`000?oooooooooo05?o
oooo0_l00020ooooo`;o0000@Oooool2o`0002;ooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
0?oooooo6Oooool2o`0002;ooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1;ooooo`;o0000koooool000ko
oooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0001;oooo
o`;o00008_ooool2o`0003oooooo0_l0002:ooooo`003_ooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0gooooo`;o0000<?ooool2o`00
00Cooooo0_l0000oooooo`;o0000Doooool2o`0003Gooooo000>ooooo`05o`000?oooooooooooooo
ool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0=oooool2
o`00033ooooo0_l0002Jooooo`;o0000=Oooool000kooooo00Go410@oooooooooooooooooa0@400<
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0=Oooool2o`00043ooooo0_l0002F
ooooo`;o0000:oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0=Oooool2o`00043ooooo0_l000000ooooooo0000o`00000@
ooooo`;o0000POooool2o`0002_ooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0001kooooo`;o00004?ooool2o`000:kooooo000Yooooo`03o`000?oooooooooo
0<oooooo0_l0000Rooooo`;o00005_ooool2o`0002oooooo000Yooooo`03o`000?oooooooooo01go
oooo0_l0000<ooooo`;o00003?ooool2o`0000Sooooo0_l0000Booooo`;o0000GOooool2o`0001Oo
oooo0_l0000Rooooo`;o00004_ooool2o`0000;ooooo0_l0000_ooooo`00:Oooool00ol0003ooooo
ooooo`0Mooooo`;o00003?ooool2o`0000cooooo0_l00008ooooo`;o00004_ooool2o`0005gooooo
0_l0000`ooooo`;o00007Oooool2o`00027ooooo0_l0000@ooooo`00:Oooool00ol0003ooooooooo
o`3Xooooo`;o0000@?ooool2o`00013ooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooo
oooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`00
0?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo
00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05
o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?oooooooooo
ooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@
oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooo
oolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_oo
ool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Oooooo`Co
000000?o410@ooooooooool00oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003ooooooooo
o`05ooooo`?o0000oooooolmooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Oooooo`03oeEEEOmVIVKo00000?ooooooAooo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .39806 Mdot
.02762 .40126 Mdot
.02952 .28053 Mdot
.03143 .33496 Mdot
.03333 .2726 Mdot
.03524 .38825 Mdot
.03714 .31848 Mdot
.03905 .22791 Mdot
.04095 .22963 Mdot
.04286 .34556 Mdot
.04476 .3337 Mdot
.04667 .23641 Mdot
.04857 .39989 Mdot
.05048 .3491 Mdot
.05238 .29266 Mdot
.05429 .34329 Mdot
.05619 .34191 Mdot
.0581 .39993 Mdot
.06 .31361 Mdot
.0619 .36183 Mdot
.06381 .37753 Mdot
.06571 .388 Mdot
.06762 .36533 Mdot
.06952 .39316 Mdot
.07143 .30747 Mdot
.07333 .24733 Mdot
.07524 .30847 Mdot
.07714 .29677 Mdot
.07905 .343 Mdot
.08095 .39319 Mdot
.08286 .34544 Mdot
.08476 .22882 Mdot
.08667 .22747 Mdot
.08857 .36691 Mdot
.09048 .36495 Mdot
.09238 .31061 Mdot
.09429 .25767 Mdot
.09619 .29702 Mdot
.0981 .28759 Mdot
.1 .22838 Mdot
.1019 .26843 Mdot
.10381 .36357 Mdot
.10571 .3814 Mdot
.10762 .40188 Mdot
.10952 .39844 Mdot
.11143 .2588 Mdot
.11333 .3345 Mdot
.11524 .24614 Mdot
.11714 .26043 Mdot
.11905 .31046 Mdot
.12095 .24019 Mdot
.12286 .30362 Mdot
.12476 .46118 Mdot
.12667 .3793 Mdot
.12857 .37002 Mdot
.13048 .22994 Mdot
.13238 .22566 Mdot
.13429 .32995 Mdot
.13619 .25276 Mdot
.1381 .39728 Mdot
.14 .25079 Mdot
.1419 .34165 Mdot
.14381 .26927 Mdot
.14571 .27547 Mdot
.14762 .2556 Mdot
.14952 .22796 Mdot
.15143 .34294 Mdot
.15333 .34292 Mdot
.15524 .31474 Mdot
.15714 .38286 Mdot
.15905 .30588 Mdot
.16095 .32294 Mdot
.16286 .33827 Mdot
.16476 .34593 Mdot
.16667 .26892 Mdot
.16857 .27519 Mdot
.17048 .4614 Mdot
.17238 .26043 Mdot
.17429 .31466 Mdot
.17619 .30991 Mdot
.1781 .32981 Mdot
.18 .38975 Mdot
.1819 .33511 Mdot
.18381 .36108 Mdot
.18571 .22972 Mdot
.18762 .3379 Mdot
.18952 .27141 Mdot
.19143 .25002 Mdot
.19333 .31026 Mdot
.19524 .34263 Mdot
.19714 .31878 Mdot
.19905 .42808 Mdot
.20095 .28495 Mdot
.20286 .25841 Mdot
.20476 .2875 Mdot
.20667 .41204 Mdot
.20857 .34885 Mdot
.21048 .22916 Mdot
.21238 .46254 Mdot
.21429 .29171 Mdot
.21619 .39657 Mdot
.2181 .28689 Mdot
.22 .25088 Mdot
.2219 .40219 Mdot
.22381 .36388 Mdot
.22571 .36842 Mdot
.22762 .32573 Mdot
.22952 .31115 Mdot
.23143 .28447 Mdot
.23333 .37525 Mdot
.23524 .34897 Mdot
.23714 .32766 Mdot
.23905 .22835 Mdot
.24095 .35189 Mdot
.24286 .48655 Mdot
.24476 .29917 Mdot
.24667 .24869 Mdot
.24857 .23738 Mdot
.25048 .23511 Mdot
.25238 .23761 Mdot
.25429 .39614 Mdot
.25619 .31521 Mdot
.2581 .354 Mdot
.26 .35005 Mdot
.2619 .37922 Mdot
.26381 .33909 Mdot
.26571 .33812 Mdot
.26762 .40227 Mdot
.26952 .38388 Mdot
.27143 .26541 Mdot
.27333 .38003 Mdot
.27524 .39357 Mdot
.27714 .25125 Mdot
.27905 .38562 Mdot
.28095 .38419 Mdot
.28286 .33829 Mdot
.28476 .30182 Mdot
.28667 .33596 Mdot
.28857 .337 Mdot
.29048 .23729 Mdot
.29238 .28293 Mdot
.29429 .3901 Mdot
.29619 .30713 Mdot
.2981 .31884 Mdot
.3 .33972 Mdot
.3019 .36028 Mdot
.30381 .23224 Mdot
.30571 .4937 Mdot
.30762 .2629 Mdot
.30952 .24978 Mdot
.31143 .27179 Mdot
.31333 .27686 Mdot
.31524 .33181 Mdot
.31714 .39686 Mdot
.31905 .32242 Mdot
.32095 .39297 Mdot
.32286 .28583 Mdot
.32476 .28285 Mdot
.32667 .23014 Mdot
.32857 .2486 Mdot
.33048 .28988 Mdot
.33238 .24819 Mdot
.33429 .32667 Mdot
.33619 .22942 Mdot
.3381 .30985 Mdot
.34 .3854 Mdot
.3419 .39105 Mdot
.34381 .23089 Mdot
.34571 .36576 Mdot
.34762 .31423 Mdot
.34952 .3142 Mdot
.35143 .29659 Mdot
.35333 .31983 Mdot
.35524 .30636 Mdot
.35714 .25596 Mdot
.35905 .27 Mdot
.36095 .23725 Mdot
.36286 .4105 Mdot
.36476 .39241 Mdot
.36667 .27868 Mdot
.36857 .32138 Mdot
.37048 .32514 Mdot
.37238 .23615 Mdot
.37429 .34647 Mdot
.37619 .27046 Mdot
.3781 .26332 Mdot
.38 .23403 Mdot
.3819 .4083 Mdot
.38381 .23903 Mdot
.38571 .23089 Mdot
.38762 .38064 Mdot
.38952 .30511 Mdot
.39143 .3633 Mdot
.39333 .27478 Mdot
.39524 .35135 Mdot
.39714 .22779 Mdot
.39905 .2601 Mdot
.40095 .24936 Mdot
.40286 .25735 Mdot
.40476 .426 Mdot
.40667 .32677 Mdot
.40857 .28603 Mdot
.41048 .28502 Mdot
.41238 .32303 Mdot
.41429 .25908 Mdot
.41619 .43303 Mdot
.4181 .39129 Mdot
.42 .27236 Mdot
.4219 .39102 Mdot
.42381 .31539 Mdot
.42571 .26305 Mdot
.42762 .33911 Mdot
.42952 .40222 Mdot
.43143 .25628 Mdot
.43333 .36408 Mdot
.43524 .34528 Mdot
.43714 .38968 Mdot
.43905 .25752 Mdot
.44095 .2331 Mdot
.44286 .26529 Mdot
.44476 .396 Mdot
.44667 .22543 Mdot
.44857 .2485 Mdot
.45048 .23413 Mdot
.45238 .37214 Mdot
.45429 .31562 Mdot
.45619 .34234 Mdot
.4581 .27679 Mdot
.46 .40547 Mdot
.4619 .30942 Mdot
.46381 .29116 Mdot
.46571 .30526 Mdot
.46762 .33939 Mdot
.46952 .29874 Mdot
.47143 .44424 Mdot
.47333 .30036 Mdot
.47524 .32435 Mdot
.47714 .31858 Mdot
.47905 .30473 Mdot
.48095 .40282 Mdot
.48286 .37383 Mdot
.48476 .39503 Mdot
.48667 .34876 Mdot
.48857 .38195 Mdot
.49048 .36728 Mdot
.49238 .30596 Mdot
.49429 .2343 Mdot
.49619 .29599 Mdot
.4981 .25999 Mdot
.5 .33966 Mdot
.5019 .30366 Mdot
.50381 .27852 Mdot
.50571 .2654 Mdot
.50762 .29789 Mdot
.50952 .28688 Mdot
.51143 .24813 Mdot
.51333 .25171 Mdot
.51524 .30475 Mdot
.51714 .3626 Mdot
.51905 .27603 Mdot
.52095 .22701 Mdot
.52286 .2508 Mdot
.52476 .27607 Mdot
.52667 .32516 Mdot
.52857 .31604 Mdot
.53048 .2725 Mdot
.53238 .28971 Mdot
.53429 .39562 Mdot
.53619 .32574 Mdot
.5381 .38915 Mdot
.54 .29926 Mdot
.5419 .26779 Mdot
.54381 .33003 Mdot
.54571 .36903 Mdot
.54762 .34852 Mdot
.54952 .2932 Mdot
.55143 .29523 Mdot
.55333 .34649 Mdot
.55524 .30594 Mdot
.55714 .23565 Mdot
.55905 .34559 Mdot
.56095 .39302 Mdot
.56286 .32294 Mdot
.56476 .28074 Mdot
.56667 .34247 Mdot
.56857 .24393 Mdot
.57048 .24174 Mdot
.57238 .31314 Mdot
.57429 .32089 Mdot
.57619 .25258 Mdot
.5781 .36791 Mdot
.58 .25031 Mdot
.5819 .32888 Mdot
.58381 .41166 Mdot
.58571 .24291 Mdot
.58762 .27433 Mdot
.58952 .23279 Mdot
.59143 .30521 Mdot
.59333 .27219 Mdot
.59524 .36073 Mdot
.59714 .37514 Mdot
.59905 .28822 Mdot
.60095 .49679 Mdot
.60286 .27663 Mdot
.60476 .36906 Mdot
.60667 .39623 Mdot
.60857 .23124 Mdot
.61048 .28422 Mdot
.61238 .3368 Mdot
.61429 .23204 Mdot
.61619 .25153 Mdot
.6181 .29473 Mdot
.62 .39667 Mdot
.6219 .34182 Mdot
.62381 .39169 Mdot
.62571 .27142 Mdot
.62762 .28743 Mdot
.62952 .39597 Mdot
.63143 .3668 Mdot
.63333 .25962 Mdot
.63524 .28035 Mdot
.63714 .24173 Mdot
.63905 .33948 Mdot
.64095 .37761 Mdot
.64286 .34071 Mdot
.64476 .38273 Mdot
.64667 .35706 Mdot
.64857 .26327 Mdot
.65048 .29111 Mdot
.65238 .30618 Mdot
.65429 .31388 Mdot
.65619 .32628 Mdot
.6581 .22532 Mdot
.66 .24084 Mdot
.6619 .2811 Mdot
.66381 .39761 Mdot
.66571 .26676 Mdot
.66762 .32271 Mdot
.66952 .40512 Mdot
.67143 .38588 Mdot
.67333 .38541 Mdot
.67524 .24911 Mdot
.67714 .25843 Mdot
.67905 .45185 Mdot
.68095 .26185 Mdot
.68286 .38423 Mdot
.68476 .2844 Mdot
.68667 .23039 Mdot
.68857 .30831 Mdot
.69048 .33358 Mdot
.69238 .37809 Mdot
.69429 .29105 Mdot
.69619 .25658 Mdot
.6981 .38612 Mdot
.7 .23073 Mdot
.7019 .2877 Mdot
.70381 .31418 Mdot
.70571 .26253 Mdot
.70762 .33852 Mdot
.70952 .30662 Mdot
.71143 .29345 Mdot
.71333 .23207 Mdot
.71524 .36322 Mdot
.71714 .36662 Mdot
.71905 .2542 Mdot
.72095 .24445 Mdot
.72286 .2484 Mdot
.72476 .32162 Mdot
.72667 .29468 Mdot
.72857 .28949 Mdot
.73048 .22587 Mdot
.73238 .32138 Mdot
.73429 .34165 Mdot
.73619 .28067 Mdot
.7381 .38965 Mdot
.74 .39684 Mdot
.7419 .22872 Mdot
.74381 .40238 Mdot
.74571 .25867 Mdot
.74762 .24453 Mdot
.74952 .36456 Mdot
.75143 .29956 Mdot
.75333 .37673 Mdot
.75524 .29738 Mdot
.75714 .48877 Mdot
.75905 .23329 Mdot
.76095 .39424 Mdot
.76286 .32157 Mdot
.76476 .31938 Mdot
.76667 .29798 Mdot
.76857 .31289 Mdot
.77048 .23218 Mdot
.77238 .38189 Mdot
.77429 .31166 Mdot
.77619 .34486 Mdot
.7781 .24771 Mdot
.78 .31998 Mdot
.7819 .24754 Mdot
.78381 .38681 Mdot
.78571 .35791 Mdot
.78762 .23686 Mdot
.78952 .35182 Mdot
.79143 .45538 Mdot
.79333 .34686 Mdot
.79524 .27559 Mdot
.79714 .28415 Mdot
.79905 .28229 Mdot
.80095 .22559 Mdot
.80286 .23689 Mdot
.80476 .31046 Mdot
.80667 .30539 Mdot
.80857 .34669 Mdot
.81048 .34225 Mdot
.81238 .27306 Mdot
.81429 .26812 Mdot
.81619 .32321 Mdot
.8181 .32128 Mdot
.82 .32718 Mdot
.8219 .27278 Mdot
.82381 .26762 Mdot
.82571 .36517 Mdot
.82762 .33355 Mdot
.82952 .2738 Mdot
.83143 .29477 Mdot
.83333 .23481 Mdot
.83524 .29378 Mdot
.83714 .36613 Mdot
.83905 .3267 Mdot
.84095 .39062 Mdot
.84286 .28552 Mdot
.84476 .31325 Mdot
.84667 .30765 Mdot
.84857 .40815 Mdot
.85048 .40075 Mdot
.85238 .48073 Mdot
.85429 .4027 Mdot
.85619 .26927 Mdot
.8581 .24064 Mdot
.86 .29614 Mdot
.8619 .32508 Mdot
.86381 .37188 Mdot
.86571 .45491 Mdot
.86762 .31063 Mdot
.86952 .31335 Mdot
.87143 .2622 Mdot
.87333 .32589 Mdot
.87524 .29511 Mdot
.87714 .42702 Mdot
.87905 .2628 Mdot
.88095 .37745 Mdot
.88286 .35575 Mdot
.88476 .27471 Mdot
.88667 .27953 Mdot
.88857 .34768 Mdot
.89048 .22697 Mdot
.89238 .29161 Mdot
.89429 .32583 Mdot
.89619 .40217 Mdot
.8981 .39802 Mdot
.9 .33622 Mdot
.9019 .32986 Mdot
.90381 .34434 Mdot
.90571 .38659 Mdot
.90762 .34518 Mdot
.90952 .22525 Mdot
.91143 .25796 Mdot
.91333 .3204 Mdot
.91524 .27915 Mdot
.91714 .27719 Mdot
.91905 .34887 Mdot
.92095 .33748 Mdot
.92286 .398 Mdot
.92476 .30487 Mdot
.92667 .25524 Mdot
.92857 .36275 Mdot
.93048 .31566 Mdot
.93238 .3866 Mdot
.93429 .27316 Mdot
.93619 .38296 Mdot
.9381 .30304 Mdot
.94 .32372 Mdot
.9419 .34204 Mdot
.94381 .37752 Mdot
.94571 .37989 Mdot
.94762 .29313 Mdot
.94952 .25382 Mdot
.95143 .22776 Mdot
.95333 .28269 Mdot
.95524 .39504 Mdot
.95714 .33276 Mdot
.95905 .27609 Mdot
.96095 .31932 Mdot
.96286 .48348 Mdot
.96476 .31585 Mdot
.96667 .40346 Mdot
.96857 .22965 Mdot
.97048 .31512 Mdot
.97238 .31293 Mdot
.97429 .33031 Mdot
.97619 .23621 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool01?l0003ooooooooo
ooooool2o`0000gooooo0_l0000=ooooo`;o00001?ooool2o`0004gooooo0_l0000>ooooo`;o0000
5_ooool2o`0002[ooooo0_l0000Eooooo`;o00005Oooool2o`0001_ooooo0_l00004ooooo`;o0000
3?ooool2o`0001?ooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRH
V?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool01?l0003oooooooooooooool3o`0000co
oooo0_l00003ooooo`;o00002?ooool2o`0000Cooooo0_l00009ooooo`;o00001_ooool2o`0000Oo
oooo0_l0000Kooooo`;o000000?oooooo`000?l000000_l0000<ooooo`;o000000?oooooo`000?l0
00003_ooool2o`0001Kooooo0_l0000Zooooo`;o00001oooool2o`0000?ooooo0_l00007ooooo`;o
00000_ooool2o`00017ooooo0_l0000Kooooo`;o00001?ooool2o`0000cooooo0_l00003ooooo`;o
00003_ooool000Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo00?oMgMgoc8b<_ooool01?ooool3o`0000;ooooo0_l0000<ooooo`;o00000oooool2o`0000So
oooo0_l0000?ooooo`;o00001_ooool2o`0000Oooooo0_l0000Cooooo`;o00001_ooool2o`000003
ooooool0003o000000;o00002_ooool4o`0000oooooo0_l000000ooooooo0000o`00000[ooooo`;o
00001?ooool4o`0001Gooooo0_l00003ooooo`;o00000_ooool2o`0000Oooooo0_l00004ooooo`;o
000000?oooooo`000?l00000?_ooool2o`0000kooooo0006ooooo`05o`000?ooooooooooooooool0
00003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0
003oooooooooo`04ooooo`;o0000?oooool2o`0000_ooooo0_l00002ooooo`;o00004Oooool2o`00
0004ooooool0003o0000ooooo`;o00004Oooool2o`000003ooooool0003o000000gooooo0_l0000B
ooooo`;o00002?ooool2o`0000Cooooo1?l0000Nooooo`;o00003Oooool2o`000003ooooool0003o
000000Cooooo0_l00003ooooo`;o00002?ooool2o`0002cooooo0_l0000;ooooo`001_ooool01Ol@
413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Cooooo0_l0000Fooooo`;o00009oooool3o`0000[ooooo0_l0000E
ooooo`;o000000?oooooo`000?l000000_ooool2o`0002;ooooo0_l0000Booooo`;o0000B?ooool2
o`0000?ooooo0_l00008ooooo`;o0000;?ooool2o`0000_ooooo0006ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Looooo`;o00009oooool3o`0002Sooooo0_l0000jooooo`;o00000ooo
ool2o`0000kooooo0_l00006ooooo`;o0000?_ooool2o`00037ooooo0006ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`00
0?oooooooooo01[ooooo0_l0002?ooooo`?o00000oooool2o`0000kooooo0_l00006ooooo`;o0000
4Oooool2o`0000Oooooo0_l0000Rooooo`;o0000<Oooool002Wooooo0_l0000=ooooo`;o00003?oo
ool2o`0002Sooooo0_l0000Hooooo`?o00005Oooool2o`0000gooooo0_l0000Booooo`;o00004?oo
ool2o`00027ooooo0_l0000<ooooo`?o00001_ooool2o`0000Sooooo0ol0001:ooooo`00:Oooool0
0ol0003oooooooooo`0<ooooo`;o00004_ooool4o`0000kooooo0_l00007ooooo`;o00001oooool2
o`0000Sooooo0_l00008ooooo`;o00001?ooool3o`0001Gooooo0_l0000=ooooo`;o00004_ooool3
o`000003ooooool0003o000000oooooo0ol0000:ooooo`;o00004Oooool2o`0000gooooo0_l0000@
ooooo`?o0000B_ooool002Wooooo00?o0000ooooooooool08?ooool6o`0000cooooo0_l00007oooo
o`;o00004Oooool2o`0000Sooooo0_l00010ooooo`;o000000?oooooo`000?l000003oooool3o`00
00[ooooo0_l0000Oooooo`;o0000@Oooool2o`0000Gooooo0_l0000Dooooo`00:Oooool00ol0003o
ooooooooo`0Cooooo`;o00000oooool2o`0000[ooooo0_l0000@ooooo`;o0000;oooool2o`0000go
oooo0_l00007ooooo`;o000000?oooooo`000?l00000B_ooool2o`0000Cooooo0_l00006ooooo`;o
00001_ooool2o`0003Cooooo0_l00003ooooo`;o00001Oooool2o`0001Cooooo000Yooooo`03o`00
0?oooooooooo01?ooooo0_l00003ooooo`Co00004?ooool2o`0000Sooooo0_l0000_ooooo`;o0000
3?ooool3o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000004Oooool2o`0002Wooooo
0_l0000<ooooo`Co00000_ooool2o`0000kooooo0_l0000dooooo`;o00008?ooool002Wooooo0_l0
000Kooooo`;o00004?ooool2o`0002[ooooo0_l0000Dooooo`;o00001Oooool2o`0000?ooooo0_l0
00000ooooooo0000o`00000Fooooo`;o0000:Oooool2o`0000?ooooo0_l00009ooooo`;o00001_oo
ool2o`0003?ooooo1?l0000[ooooo`00:Oooool00ol0003oooooooooo`1<ooooo`;o00002_ooool2
o`0001Cooooo0_l0000=ooooo`;o00001?ooool2o`0001;ooooo0_l0000:ooooo`;o00008?ooool2
o`0000Cooooo0_l0000;ooooo`;o00008?ooool2o`0000;ooooo0_l0000=ooooo`Co0000:oooool0
02Wooooo00?o0000ooooooooool05Oooool2o`0000cooooo0_l00005ooooo`;o00001?ooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02?ooool2o`0001[ooooo0_l00003ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Kok^k^oc8b<_l0003o<S8bonk^k_ooool2o`0001;ooooo0_l0000:ooooo`;o00001Ooo
ool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`04
onk^k_lb<S;o0000oc8b<P;o00002oooool2o`0001cooooo0_l000002Ol@413ooooooooooooooooo
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`03onk^k_lb<S;o000000;o00000_ooool2o`0000Sooooo
0_l0000Kooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool01?l0003oooooo`000?l0000D
ooooo`;o00003?ooool2o`0000Gooooo0_l00006ooooo`;o00000oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Eooooo`;o00003Oooool2o`0000?ooooo
00GoV9RHo`000?l0003oooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool2o`00
0004oiRHV?ooooooV9RHogMgMagooooo0_l00009ooooo`05oa0@4?nj^[[oooooogMgMolb<S800ooo
ool3o`000003oiRHV?mgMgOooooo00;ooooo00CoMgMgoiRHV?ooooooV9RH0_l0000Zooooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03ogMgMonHV9Sooooo00;o
000000?oooooo`000?l000000_l00007ooooo`;o00005oooool2o`0000Gooooo00WoMgMgoc8b<_oo
ooooooooogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
000Yooooo`04o`000?oooooo0000o`0002;ooooo0_l00006ooooo`;o00001Oooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@
01Gooooo0_l0000Cooooo`03oiRHV?lQ8B7ok^k^00;ooooo0_l000001Ol@413ooooooooooooooooo
410@00;ooooo0_l00003ooooo`03oa0@4?oooooooooo00Cooooo0_l0000Booooo`Go00003Oooool0
1?l0003oooooooooooooool3o`000003ooooool0003o000000;ooooo00Go410@oooooooooooooooo
oa0@400Xooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00;o000000Cooooooa0@4?oo
oooooooo0_l000000ooooooo0000o`000002o`00013ooooo0_l00009ooooo`;o00000oooool2o`00
00Kooooo0_l000000ooooooo410@ooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool0
0ol@413oooooooooo`01ooooo`00:Oooool3o`0002?ooooo0_l00006ooooo`;o00001Oooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000001Gooooo0_l0000@ooooo`;o00000_ooool01?nHV9So8B4Qonk^k_ooool3o`0000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Cooooo0_l0000=ooooo`;o
00000oooool3o`0000_ooooo0_l000000oooooooZJVYoa0@4003ooooo`04o`000?oooooooooooooo
o`;o00000_ooool01Ol0003ooooooooooooooooo000000;ooooo0_l0000Nooooo`;o00001?ooool0
1?m4A4CogMgMooooool00004ooooo`04o`000?ooooooooooooooo`?o000000?oooooo`000?ooool0
0_ooool00ol0003oooooooooo`0Cooooo`?o00001oooool3o`0000[ooooo00GoMgMgo`000?l0003o
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`01oooo
o`00:Oooool3o`0003;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`00000?ooooo`;o00002?ooool2o`0000cooooo0_l00003
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000005Oooool2o`00017ooooo0_l000000ol@413o0000okZj^P03ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo0_l00006oooo
o`;o00005_ooool2o`0000Cooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooo
oooo000000;ooooo0_l00003ooooo`03o`000?oooooooooo01Cooooo0_l00007ooooo`;o00002?oo
ool01Ol0003o8B4Qo`000?l0003oc<c<00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool002Wooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`02o`000004oa0@4?ooooooooooooooo`;o00000_ooool2o`0000;ooooo00?o410@oooo
ooooool03Oooool2o`0000Oooooo0ol0000Booooo`05o`000?ooooooooooooooool@41000_ooool3
o`0000;ooooo00Go410@oooooooooooooooooa0@400Fooooo`;o00004oooool00onj^[[o8B4Qoooo
o`02ooooo`05oa0@4?ooooooooooooooool@41000_ooool2o`0000?ooooo00?o410@ooooooooool0
2?ooool2o`0000Kooooo0_l0000Eooooo`03ogMgMoo<c<co000000Cooooo00Ko410@oooooooooooo
oooooa0@4?ooool3o`0000?ooooo00?o410@ooooooooool01_ooool2o`0001oooooo00Co0000oooo
ool0003o00000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooo
oa0@4003ooooo`00:Oooool00ol0003oooooooooo`0Dooooo`;o00007?ooool00ol0003ooooooooo
o`03o`000003oiRHV?ooooooV9RH00;o00000_ooool2o`000003oooooonHV9SoMgMg01Sooooo0_l0
00000ooooooo0000o`00000<ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool00omgMgOoV9RH
ooooo`03o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Fooooo`;o00001_ooool2o`0000So
oooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`03ogMgMonHV9Sooooo00;o00000_ooool2o`00
0003oiRHV?ooooooV9RH00;o00004Oooool2o`0000?ooooo0_l00007ooooo`;o00001oooool00oo^
k^koA4A4o`000004ooooo`06ogMgMonHV9SooooooiRHV?mgMgOooooo0_l000001OmgMgOoV9RHoooo
oonHV9SoMgMg00Sooooo0_l0000Oooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wooooo00?o0000oooooooo
ool01Oooool2o`0000gooooo0_l0000Jooooo`03oeEEEOmVIVKo000000?ooooo0_l000001?lb<S;o
0000o`000?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool2o`0000cooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Sooooo0_l0000Dooooo`;o00000oooool2o`0000?ooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@03ooooo`03onk^k_lb<S;o000000;o00000oooool01?o^k^ko<S8bo`000?lb<S82
o`0000Kooooo0_l0000<ooooo`Co00001oooool2o`0000Sooooo00?oMgMgo`000?ooool00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Hooooo`;o0000
3oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool002Wooooo0_l00006ooooo`;o0000<oooool2o`0004kooooo0_l00008ooooo`;o
00003oooool3o`0001?ooooo0_l00009ooooo`;o00003?ooool2o`0000?ooooo0_l00003ooooo`;o
00008?ooool3o`0000Kooooo0_l00003ooooo`;o00001?ooool2o`0000oooooo0_l0000Eooooo`00
:Oooool00ol0003oooooooooo`0=ooooo`;o00001Oooool2o`0002gooooo0_l0000Qooooo`;o0000
9?ooool2o`0000Kooooo0_l00002ooooo`;o00002?ooool2o`0000;ooooo0_l0000Cooooo`;o0000
7?ooool2o`0000?ooooo0_l00007ooooo`;o00000_ooool2o`0001?ooooo0ol00006ooooo`;o0000
0oooool2o`0002cooooo000Yooooo`03o`000?oooooooooo00gooooo0_l00005ooooo`;o0000;Ooo
ool2o`0000_ooooo0_l0000Dooooo`;o00009?ooool3o`0000Wooooo0_l00008ooooo`;o0000@_oo
ool3o`0000;ooooo0_l0001?ooooo`00:Oooool00ol0003oooooooooo`0Looooo`;o0000<_ooool2
o`00023ooooo0_l0000Fooooo`;o000000?oooooo`000?l000000_l00005ooooo`;o00000_ooool2
o`0001Oooooo0_l0000aooooo`;o00004?ooool2o`0002Cooooo0_l00002ooooo`;o00006?ooool0
02Wooooo00?o0000ooooooooool03?ooool3o`0000gooooo0_l0000:ooooo`;o0000:_ooool2o`00
017ooooo0_l00009ooooo`;o00005_ooool2o`0000?ooooo0_l00002ooooo`;o000000?oooooo`00
0?l000000_ooool2o`0000_ooooo0_l0000:ooooo`;o00004Oooool2o`0000[ooooo0_l00005oooo
o`;o00007Oooool2o`0000_ooooo0_l0000Gooooo`;o00000_ooool2o`0001Sooooo000Qoooooooo
0000A?l00004ooooo`00:Oooool00ol0003oooooooooo`08ooooo`;o00002?ooool2o`0000;ooooo
00?o0000ooooooooool00_ooool2o`0000Gooooo00?o0000ooooooooool00_ooool2o`0000Cooooo
0_l00004ooooo`;o00001Oooool01?l0003oooooooooooooool2o`0000Oooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`05o`000?oooooo0000o`000?ooool00ol00004oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02oooo
o`;o00001Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00Co0000oooo
oooooooooooo0_l00006ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool2
o`0000Cooooo00?o0000ooooooooool01oooool2o`000003ooooool0003ooooo00[ooooo00?o0000
ooooooooool00oooool4o`0000;ooooo00?o0000ooooooooool00_ooool2o`0000Gooooo00?o0000
ooooooooool00oooool2o`0000Gooooo0ol00009ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool01oooool3o`0000cooooo000Yooooo`03o`000?oooooooooo00Sooooo0_l0000Moooo
o`;o00001?ooool2o`0000_ooooo00?o0000ooooooooool02_ooool2o`0001_ooooo0ol0000Aoooo
o`03o`000?oooooooooo00;ooooo0_l00008ooooo`;o00005_ooool2o`0000cooooo0_l00006oooo
o`03o`000?oooooooooo00oooooo0_l0000>ooooo`;o00004oooool2o`0000Cooooo00?o0000oooo
ooooool03oooool2o`0000Kooooo0_l0000Booooo`;o00002Oooool5o`0000cooooo000Yooooo`04
o`000?ooooooooooooooo`;o0000<Oooool2o`00017ooooo0_l0000;ooooo`;o00004?ooool2o`00
01Gooooo0_l00008ooooo`;o00001Oooool2o`0000oooooo0_l0000<ooooo`;o0000??ooool2o`00
00;ooooo0_l0000Yooooo`;o00001?ooool2o`0000Sooooo1Ol0000=ooooo`00:Oooool01?l0003o
ooooooooooooool2o`0002Gooooo0_l0000:ooooo`;o00007_ooool2o`0000Gooooo0_l00009oooo
o`;o00000oooool2o`0000cooooo0_l0000Booooo`?o00006_ooool2o`000003ooooool0003o0000
01cooooo0_l0000Aooooo`Co00002?ooool3o`0000;ooooo0_l0000:ooooo`?o00007?ooool2o`00
00Oooooo0_l00005ooooo`;o00004?ooool002Wooooo0_l0000Yooooo`;o00005?ooool2o`0001_o
oooo0_l00003ooooo`;o00002Oooool3o`0000Wooooo1?l0000Booooo`;o00003oooool2o`000003
ooooool0003o000000Oooooo0_l0000Looooo`;o000000?oooooo`000?l000004Oooool4o`0000So
oooo0_l0000?ooooo`?o00001?ooool2o`0000Kooooo0_l000000ooooooo0000o`000005ooooo`;o
00003Oooool2o`0001Oooooo000Yooooo`03o`000?oooooooooo023ooooo0_l0000<ooooo`;o0000
3_ooool2o`000003ooooool0003o000001gooooo0_l0000:ooooo`;o00002Oooool2o`0002Gooooo
0_l000000ooooooo0000o`000002o`0000_ooooo0_l0000Fooooo`;o0000<_ooool2o`0000Cooooo
0_l00006ooooo`;o000000?oooooo`000?l000001Oooool2o`000003ooooool0003o000001Gooooo
0_l0000<ooooo`00:Oooool00ol0003oooooooooo`03ooooo`;o00006oooool2o`0000cooooo0_l0
000Aooooo`;o00005oooool2o`0004Oooooo0_l0000;ooooo`;o00008Oooool2o`0002[ooooo0_l0
000Fooooo`;o00003oooool2o`0000Cooooo0_l0000<ooooo`00:Oooool01?l0003oooooo`000?l0
0002ooooo`;o00005?ooool2o`0001Cooooo0_l0000Pooooo`;o00001oooool2o`0005kooooo0_l0
000Gooooo`;o0000:_ooool2o`0001Gooooo0_l0000@ooooo`;o00004_ooool002Wooooo00Co0000
ooooool0003o00006?ooool2o`0000kooooo0_l00004ooooo`Co00005_ooool3o`0000Cooooo0ol0
0002ooooo`;o00009oooool2o`0000_ooooo0_l00008ooooo`;o00008oooool2o`0000Kooooo0_l0
000Dooooo`;o0000??ooool2o`0000Gooooo0_l0000Mooooo`00:Oooool2o`0000Sooooo0_l00005
ooooo`;o00004_ooool2o`000005ooooool0003o0000o`000?ooool00_l00006ooooo`Co00005?oo
ool3o`0000Cooooo0ol00002ooooo`;o00009oooool2o`0000Oooooo0_l00002ooooo`;o00002?oo
ool2o`0001Cooooo0_l0000@ooooo`;o00000oooool3o`0001?ooooo0_l00007ooooo`;o00005_oo
ool2o`0002;ooooo0_l00004ooooo`;o00005oooool002Wooooo00?o0000ooooooooool00_ooool2
o`0000;ooooo0ol00005ooooo`?o00004Oooool2o`000004ooooool0003o0000o`0000;ooooo0_l0
0007ooooo`;o0000C?ooool2o`0000Cooooo0_l0000Oooooo`;o000000?oooooo`000?l000004?oo
ool2o`0000Cooooo0_l0000Looooo`;o00002oooool2o`0000Wooooo0_l0000Looooo`?o00002Ooo
ool2o`0001Oooooo000Yooooo`03o`000?oooooooooo00;ooooo0_l000001?oooooo0000o`000?l0
0007ooooo`;o00006Oooool2o`0000cooooo0_l00006ooooo`;o0000:oooool2o`0001;ooooo0_l0
000>ooooo`;o00004_ooool5o`0004Cooooo0_l00004ooooo`;o00000oooool2o`0001Oooooo0_l0
0003ooooo`?o00000_ooool2o`0001kooooo000Yooooo`03o`000?oooooooooo00Gooooo0_l0000a
ooooo`;o00001_ooool4o`0000Cooooo0_l0000Sooooo`;o00001Oooool2o`0001_ooooo0_l0000B
ooooo`Co0000BOooool4o`0000?ooooo0_l0000Gooooo`;o00002?ooool2o`0001kooooo000Yoooo
o`03o`000?oooooooooo04;ooooo0_l00004ooooo`;o0000:_ooool2o`0007cooooo0_l00018oooo
o`00:Oooool2o`0004Wooooo0_l0001kooooo`;o0000:_ooool2o`0001gooooo0_l0000Zooooo`00
:Oooool00ol0003oooooooooo`0`ooooo`;o00009?ooool2o`0005cooooo0_l0000?ooooo`;o0000
:_ooool2o`0001gooooo0_l0000Zooooo`00:Oooool00ol0003oooooooooo`09ooooo`;o00002ooo
ool2o`0001Sooooo0_l0000;ooooo`;o00005oooool2o`0001[ooooo0_l0000<ooooo`;o00006Ooo
ool2o`0001Oooooo0_l0000Uooooo`;o00002Oooool2o`0003Oooooo0_l0000Kooooo`00:Oooool0
0ol0003oooooooooo`09ooooo`?o00001Oooool3o`0000;ooooo0_l0000Uooooo`;o00009Oooool2
o`0000cooooo0_l0000<ooooo`;o00004?ooool2o`0000Oooooo0_l0000Aooooo`;o00004?ooool2
o`0001Wooooo0_l00009ooooo`;o00005_ooool2o`0000;ooooo0_l0000Kooooo`;o00006oooool0
02Wooooo00?o0000ooooooooool02_ooool2o`0000Gooooo0ol0000:ooooo`;o00007Oooool2o`00
02Gooooo0_l0000/ooooo`;o00004?ooool2o`0000Sooooo0_l00007ooooo`;o00001oooool2o`00
01Wooooo0_l0000Qooooo`;o00000_ooool2o`0003Sooooo000Yooooo`;o00007oooool2o`0001go
oooo0_l00017ooooo`;o00002?ooool2o`0001;ooooo0_l0000Aooooo`;o0000DOooool2o`00033o
oooo000Yooooo`03o`000?oooooooooo043ooooo0_l00014ooooo`;o00002?ooool2o`0002?ooooo
0_l0000`ooooo`;o00008Oooool2o`00033ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`09ooooo`;o00004_ooool2o`00027ooooo0_l00007ooooo`;o00000_ooool2o`0006Ko
oooo0_l0000<ooooo`;o00003_ooool2o`0001;ooooo0_l0000Wooooo`;o00004_ooool3o`0001Go
oooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool02Oooool2o`00
00cooooo0_l00004ooooo`;o00002?ooool2o`00023ooooo0_l00002ooooo`;o00008_ooool2o`00
01oooooo0_l0000_ooooo`?o00003Oooool2o`0001Sooooo0_l0000Qooooo`;o00004?ooool5o`00
01Gooooo0006ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05oooool2o`0000kooooo0_l0000Roooo
o`;o000000Coooooo`000?l0003o00004Oooool2o`0000gooooo0_l0000Oooooo`;o0000<?ooool2
o`0000Oooooo0_l000000ooooooo0000o`000003ooooo`;o00005_ooool2o`0003?ooooo0_l0000H
ooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool0
0omgMgOo<S8booooo`04ooooo`Go00002?ooool2o`0003oooooo0_l000001?oooooo0000o`000?l0
000Aooooo`;o00007Oooool2o`0001oooooo0_l0000Yooooo`;o000000?oooooo`000?l000000ooo
ool2o`0000_ooooo0_l0000=ooooo`;o00009Oooool2o`0000Kooooo0_l0000Jooooo`001_ooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool00_l00008ooooo`;o00008_ooool2o`0002?ooooo
0_l0000>ooooo`;o00001Oooool2o`0000oooooo0ol00003ooooo`;o00007oooool2o`0001Wooooo
0_l0000Sooooo`;o00003Oooool2o`00013ooooo0_l0000Cooooo`;o00001_ooool2o`0001[ooooo
0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02oooool2o`0000;ooooo0_l0000Mooooo`;o0000
7Oooool2o`0000Cooooo0_l00007ooooo`;o00001Oooool2o`0000Gooooo0_l0000?ooooo`?o0000
4_ooool2o`0000kooooo0_l00007ooooo`;o00004_ooool2o`0002[ooooo0_l0000Hooooo`;o0000
8oooool2o`0001;ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zj
oooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool2o`0000cooooo0_l00002ooooo`;o
00001oooool2o`0000Oooooo0_l0000Gooooo`;o00002_ooool2o`0000Gooooo0_l0000<ooooo`?o
00009_ooool2o`0000[ooooo0_l0000>ooooo`;o00001oooool2o`0000gooooo0_l00002ooooo`;o
000000?oooooo`000?l000002Oooool2o`0001Oooooo0_l00004ooooo`;o0000:_ooool2o`0000Ko
oooo0_l00009ooooo`;o00004_ooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l00005ooooo`;o000000?oooooo`00
0?l000003_ooool3o`0000Oooooo0_l0000Gooooo`;o00002_ooool2o`0001?ooooo0_l0000Woooo
o`;o0000<_ooool2o`0000;ooooo0_l000000ooooooo0000o`000009ooooo`;o00005oooool2o`00
027ooooo0_l0000=ooooo`;o00001_ooool2o`0001gooooo000Yooooo`;o00001Oooool2o`000003
ooooool0003o000000kooooo0_l0000Sooooo`;o00003Oooool2o`0003;ooooo0_l0000>ooooo`;o
0000>oooool2o`0001Kooooo0_l0000Pooooo`?o00003?ooool2o`0001Cooooo0_l0000?ooooo`00
:Oooool00ol0003oooooooooo`0looooo`;o00003Oooool2o`0002;ooooo0_l0000>ooooo`;o0000
2?ooool2o`0000Cooooo0_l0000kooooo`;o00005_ooool2o`0001oooooo1?l0000<ooooo`;o0000
5?ooool2o`0000oooooo000Yooooo`03o`000?oooooooooo06Wooooo0_l00004ooooo`;o00006?oo
ool2o`0007[ooooo0_l0000eooooo`00:Oooool00ol0003oooooooooo`0gooooo`;o0000<?ooool2
o`0004Gooooo0_l0002:ooooo`00:Oooool00ol0003oooooooooo`0gooooo`;o0000Moooool2o`00
08[ooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo07Oooooo0_l00033ooooo`00:Oooool00ol0003oooooooooo`0e
ooooo`;o0000@?ooool2o`0009Kooooo0_l0000[ooooo`00:Oooool00ol0003oooooooooo`0eoooo
o`;o0000@oooool2o`0009?ooooo0_l0000[ooooo`00:Oooool2o`0007_ooooo0_l00030ooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0S?ooool2o`000:kooooo000Yooooo`03o`000?oooooooooo
08cooooo0_l0002^ooooo`00:Oooool2o`000=3ooooo0_l0001[ooooo`00:Oooool00ol0003ooooo
ooooo`3?ooooo`;o0000>_ooool2o`0002oooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0??o
oooo0_l0000Fooooo`;o0000;oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01gooooo0_l0003Dooooo`;o
0000Aoooool000kooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?o
oooo0ol0000Mooooo`;o00003?ooool2o`0000cooooo0_l0003oooooo`;ooooo000>ooooo`05o`00
0?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02_o
oooo0_l0000<ooooo`;o0000ooooool2ooooo`003_ooool01Ol0003ooooooooooooooooo000000co
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000ko
oooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oo
oooo2?ooool2o`0003?ooooo000Yooooo`03o`000?oooooooooo0?oooooo2?ooool2o`00027ooooo
0_l0000@ooooo`00:Oooool00ol0003oooooooooo`13ooooo`;o0000Xoooool2o`00043ooooo0_l0
000@ooooo`00:Oooool00ol0003oooooooooo`13ooooo`;o0000Xoooool2o`0005;ooooo000Yoooo
o`;o0000F?ooool2o`000>?ooooo000Yooooo`03o`000?oooooooooo05Oooooo0_l0001Mooooo`;o
0000Q?ooool002Wooooo00?o0000ooooooooool0]_ooool2o`0008Cooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`00
0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000
o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@
41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgo
oooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooo
oooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@
00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooo
oooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool0
00Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`007oooool4o`000003oa0@
4?oooooooooo00?ooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool3
o`000?oooooo?Oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`007oooool00omEEEGoIVIVo`00003oooooodOooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .38355 Mdot
.02762 .39734 Mdot
.02952 .30963 Mdot
.03143 .28757 Mdot
.03333 .34046 Mdot
.03524 .34286 Mdot
.03714 .2858 Mdot
.03905 .32539 Mdot
.04095 .29434 Mdot
.04286 .33917 Mdot
.04476 .35097 Mdot
.04667 .26993 Mdot
.04857 .41235 Mdot
.05048 .34046 Mdot
.05238 .22808 Mdot
.05429 .30755 Mdot
.05619 .26419 Mdot
.0581 .41296 Mdot
.06 .35538 Mdot
.0619 .41721 Mdot
.06381 .41131 Mdot
.06571 .40651 Mdot
.06762 .40415 Mdot
.06952 .41423 Mdot
.07143 .22528 Mdot
.07333 .30842 Mdot
.07524 .34932 Mdot
.07714 .3491 Mdot
.07905 .4094 Mdot
.08095 .4021 Mdot
.08286 .40139 Mdot
.08476 .31831 Mdot
.08667 .29691 Mdot
.08857 .30552 Mdot
.09048 .29508 Mdot
.09238 .38966 Mdot
.09429 .3603 Mdot
.09619 .34787 Mdot
.0981 .37932 Mdot
.1 .28699 Mdot
.1019 .2364 Mdot
.10381 .29461 Mdot
.10571 .33028 Mdot
.10762 .37341 Mdot
.10952 .36469 Mdot
.11143 .33022 Mdot
.11333 .34836 Mdot
.11524 .35168 Mdot
.11714 .26708 Mdot
.11905 .39187 Mdot
.12095 .34361 Mdot
.12286 .39032 Mdot
.12476 .38974 Mdot
.12667 .3284 Mdot
.12857 .30256 Mdot
.13048 .28989 Mdot
.13238 .31053 Mdot
.13429 .25279 Mdot
.13619 .35736 Mdot
.1381 .36087 Mdot
.14 .31667 Mdot
.1419 .23149 Mdot
.14381 .36673 Mdot
.14571 .27053 Mdot
.14762 .24883 Mdot
.14952 .31522 Mdot
.15143 .34108 Mdot
.15333 .31945 Mdot
.15524 .35388 Mdot
.15714 .41408 Mdot
.15905 .24355 Mdot
.16095 .29892 Mdot
.16286 .34512 Mdot
.16476 .33273 Mdot
.16667 .36645 Mdot
.16857 .28924 Mdot
.17048 .39022 Mdot
.17238 .27113 Mdot
.17429 .39608 Mdot
.17619 .24763 Mdot
.1781 .39684 Mdot
.18 .40229 Mdot
.1819 .29013 Mdot
.18381 .28889 Mdot
.18571 .32888 Mdot
.18762 .28616 Mdot
.18952 .33983 Mdot
.19143 .30735 Mdot
.19333 .2449 Mdot
.19524 .32322 Mdot
.19714 .22624 Mdot
.19905 .33602 Mdot
.20095 .26336 Mdot
.20286 .32885 Mdot
.20476 .26269 Mdot
.20667 .30907 Mdot
.20857 .3401 Mdot
.21048 .31385 Mdot
.21238 .39156 Mdot
.21429 .24568 Mdot
.21619 .38943 Mdot
.2181 .2477 Mdot
.22 .25154 Mdot
.2219 .38173 Mdot
.22381 .41074 Mdot
.22571 .3082 Mdot
.22762 .24901 Mdot
.22952 .35558 Mdot
.23143 .26354 Mdot
.23333 .41241 Mdot
.23524 .33708 Mdot
.23714 .27322 Mdot
.23905 .31388 Mdot
.24095 .41114 Mdot
.24286 .43786 Mdot
.24476 .32856 Mdot
.24667 .29903 Mdot
.24857 .34283 Mdot
.25048 .33812 Mdot
.25238 .3347 Mdot
.25429 .41259 Mdot
.25619 .22331 Mdot
.2581 .40254 Mdot
.26 .41305 Mdot
.2619 .41347 Mdot
.26381 .30048 Mdot
.26571 .40519 Mdot
.26762 .29453 Mdot
.26952 .39964 Mdot
.27143 .30837 Mdot
.27333 .40738 Mdot
.27524 .39484 Mdot
.27714 .25057 Mdot
.27905 .33211 Mdot
.28095 .33587 Mdot
.28286 .40824 Mdot
.28476 .39131 Mdot
.28667 .40512 Mdot
.28857 .34533 Mdot
.29048 .27016 Mdot
.29238 .23075 Mdot
.29429 .28049 Mdot
.29619 .25946 Mdot
.2981 .35573 Mdot
.3 .26162 Mdot
.3019 .41572 Mdot
.30381 .33435 Mdot
.30571 .45266 Mdot
.30762 .32889 Mdot
.30952 .30771 Mdot
.31143 .23248 Mdot
.31333 .25232 Mdot
.31524 .35519 Mdot
.31714 .41457 Mdot
.31905 .29348 Mdot
.32095 .3709 Mdot
.32286 .38071 Mdot
.32476 .37676 Mdot
.32667 .32726 Mdot
.32857 .35098 Mdot
.33048 .38347 Mdot
.33238 .29108 Mdot
.33429 .40273 Mdot
.33619 .28114 Mdot
.3381 .38821 Mdot
.34 .34904 Mdot
.3419 .39276 Mdot
.34381 .33077 Mdot
.34571 .41222 Mdot
.34762 .35343 Mdot
.34952 .39786 Mdot
.35143 .38308 Mdot
.35333 .26739 Mdot
.35524 .35032 Mdot
.35714 .32354 Mdot
.35905 .33597 Mdot
.36095 .27082 Mdot
.36286 .30702 Mdot
.36476 .37146 Mdot
.36667 .32146 Mdot
.36857 .39842 Mdot
.37048 .40325 Mdot
.37238 .26918 Mdot
.37429 .31589 Mdot
.37619 .23508 Mdot
.3781 .29688 Mdot
.38 .28103 Mdot
.3819 .30475 Mdot
.38381 .34364 Mdot
.38571 .27807 Mdot
.38762 .32589 Mdot
.38952 .22344 Mdot
.39143 .41701 Mdot
.39333 .27191 Mdot
.39524 .23843 Mdot
.39714 .32341 Mdot
.39905 .24107 Mdot
.40095 .25281 Mdot
.40286 .327 Mdot
.40476 .32959 Mdot
.40667 .24875 Mdot
.40857 .32378 Mdot
.41048 .32357 Mdot
.41238 .30257 Mdot
.41429 .32747 Mdot
.41619 .34106 Mdot
.4181 .39456 Mdot
.42 .27572 Mdot
.4219 .35237 Mdot
.42381 .26154 Mdot
.42571 .30717 Mdot
.42762 .35058 Mdot
.42952 .40839 Mdot
.43143 .2772 Mdot
.43333 .41167 Mdot
.43524 .32362 Mdot
.43714 .39401 Mdot
.43905 .27573 Mdot
.44095 .27317 Mdot
.44286 .31184 Mdot
.44476 .37362 Mdot
.44667 .30162 Mdot
.44857 .30463 Mdot
.45048 .33068 Mdot
.45238 .4139 Mdot
.45429 .3902 Mdot
.45619 .32945 Mdot
.4581 .34218 Mdot
.46 .38893 Mdot
.4619 .26121 Mdot
.46381 .22838 Mdot
.46571 .22276 Mdot
.46762 .29439 Mdot
.46952 .27083 Mdot
.47143 .3623 Mdot
.47333 .2459 Mdot
.47524 .35262 Mdot
.47714 .22403 Mdot
.47905 .35024 Mdot
.48095 .38359 Mdot
.48286 .40873 Mdot
.48476 .39301 Mdot
.48667 .23608 Mdot
.48857 .32577 Mdot
.49048 .4142 Mdot
.49238 .24357 Mdot
.49429 .33564 Mdot
.49619 .26082 Mdot
.4981 .36107 Mdot
.5 .26336 Mdot
.5019 .24358 Mdot
.50381 .37355 Mdot
.50571 .2376 Mdot
.50762 .32825 Mdot
.50952 .26443 Mdot
.51143 .34947 Mdot
.51333 .28362 Mdot
.51524 .34957 Mdot
.51714 .28597 Mdot
.51905 .28707 Mdot
.52095 .29655 Mdot
.52286 .35619 Mdot
.52476 .25386 Mdot
.52667 .35268 Mdot
.52857 .39085 Mdot
.53048 .31821 Mdot
.53238 .24716 Mdot
.53429 .38436 Mdot
.53619 .34941 Mdot
.5381 .35921 Mdot
.54 .38387 Mdot
.5419 .26166 Mdot
.54381 .40047 Mdot
.54571 .29949 Mdot
.54762 .33353 Mdot
.54952 .24765 Mdot
.55143 .38655 Mdot
.55333 .31185 Mdot
.55524 .35537 Mdot
.55714 .3363 Mdot
.55905 .34742 Mdot
.56095 .36225 Mdot
.56286 .39977 Mdot
.56476 .32524 Mdot
.56667 .33591 Mdot
.56857 .34515 Mdot
.57048 .26235 Mdot
.57238 .35639 Mdot
.57429 .28948 Mdot
.57619 .31285 Mdot
.5781 .41694 Mdot
.58 .31268 Mdot
.5819 .39581 Mdot
.58381 .31054 Mdot
.58571 .34553 Mdot
.58762 .23487 Mdot
.58952 .32621 Mdot
.59143 .27086 Mdot
.59333 .37347 Mdot
.59524 .24715 Mdot
.59714 .41852 Mdot
.59905 .22931 Mdot
.60095 .45934 Mdot
.60286 .25427 Mdot
.60476 .2968 Mdot
.60667 .39384 Mdot
.60857 .32819 Mdot
.61048 .22934 Mdot
.61238 .34859 Mdot
.61429 .32768 Mdot
.61619 .28358 Mdot
.6181 .32498 Mdot
.62 .40931 Mdot
.6219 .26366 Mdot
.62381 .41196 Mdot
.62571 .2329 Mdot
.62762 .32612 Mdot
.62952 .37821 Mdot
.63143 .30343 Mdot
.63333 .24523 Mdot
.63524 .32398 Mdot
.63714 .26085 Mdot
.63905 .23226 Mdot
.64095 .26205 Mdot
.64286 .3034 Mdot
.64476 .32338 Mdot
.64667 .28112 Mdot
.64857 .36247 Mdot
.65048 .35025 Mdot
.65238 .32657 Mdot
.65429 .27693 Mdot
.65619 .24961 Mdot
.6581 .31133 Mdot
.66 .33934 Mdot
.6619 .26578 Mdot
.66381 .40762 Mdot
.66571 .31211 Mdot
.66762 .30478 Mdot
.66952 .39069 Mdot
.67143 .33544 Mdot
.67333 .34863 Mdot
.67524 .28817 Mdot
.67714 .32627 Mdot
.67905 .3717 Mdot
.68095 .26786 Mdot
.68286 .40161 Mdot
.68476 .26478 Mdot
.68667 .2869 Mdot
.68857 .34893 Mdot
.69048 .40362 Mdot
.69238 .40379 Mdot
.69429 .26053 Mdot
.69619 .27812 Mdot
.6981 .27472 Mdot
.7 .28148 Mdot
.7019 .38417 Mdot
.70381 .39193 Mdot
.70571 .26556 Mdot
.70762 .25819 Mdot
.70952 .38867 Mdot
.71143 .24653 Mdot
.71333 .2784 Mdot
.71524 .24569 Mdot
.71714 .41422 Mdot
.71905 .24791 Mdot
.72095 .25733 Mdot
.72286 .25195 Mdot
.72476 .31155 Mdot
.72667 .24687 Mdot
.72857 .22869 Mdot
.73048 .30534 Mdot
.73238 .31284 Mdot
.73429 .40115 Mdot
.73619 .25362 Mdot
.7381 .34439 Mdot
.74 .38808 Mdot
.7419 .3074 Mdot
.74381 .38445 Mdot
.74571 .3618 Mdot
.74762 .34387 Mdot
.74952 .40356 Mdot
.75143 .39117 Mdot
.75333 .40644 Mdot
.75524 .22636 Mdot
.75714 .4404 Mdot
.75905 .325 Mdot
.76095 .36561 Mdot
.76286 .30212 Mdot
.76476 .22541 Mdot
.76667 .24481 Mdot
.76857 .27592 Mdot
.77048 .27628 Mdot
.77238 .41407 Mdot
.77429 .32577 Mdot
.77619 .33643 Mdot
.7781 .30167 Mdot
.78 .35242 Mdot
.7819 .35363 Mdot
.78381 .41835 Mdot
.78571 .24411 Mdot
.78762 .26787 Mdot
.78952 .27635 Mdot
.79143 .38067 Mdot
.79333 .26832 Mdot
.79524 .33989 Mdot
.79714 .34561 Mdot
.79905 .27739 Mdot
.80095 .30446 Mdot
.80286 .26924 Mdot
.80476 .34975 Mdot
.80667 .25979 Mdot
.80857 .35032 Mdot
.81048 .29708 Mdot
.81238 .23254 Mdot
.81429 .33845 Mdot
.81619 .39532 Mdot
.8181 .26701 Mdot
.82 .35499 Mdot
.8219 .31891 Mdot
.82381 .33745 Mdot
.82571 .3022 Mdot
.82762 .3541 Mdot
.82952 .274 Mdot
.83143 .22431 Mdot
.83333 .2747 Mdot
.83524 .31055 Mdot
.83714 .29687 Mdot
.83905 .24957 Mdot
.84095 .38163 Mdot
.84286 .2513 Mdot
.84476 .35265 Mdot
.84667 .22423 Mdot
.84857 .30134 Mdot
.85048 .39033 Mdot
.85238 .42595 Mdot
.85429 .3726 Mdot
.85619 .27864 Mdot
.8581 .2679 Mdot
.86 .22716 Mdot
.8619 .35126 Mdot
.86381 .40281 Mdot
.86571 .37756 Mdot
.86762 .26103 Mdot
.86952 .32433 Mdot
.87143 .32908 Mdot
.87333 .39589 Mdot
.87524 .24799 Mdot
.87714 .33259 Mdot
.87905 .29858 Mdot
.88095 .32556 Mdot
.88286 .27975 Mdot
.88476 .27063 Mdot
.88667 .32245 Mdot
.88857 .32056 Mdot
.89048 .32149 Mdot
.89238 .32791 Mdot
.89429 .4019 Mdot
.89619 .39372 Mdot
.8981 .37299 Mdot
.9 .40391 Mdot
.9019 .39569 Mdot
.90381 .26615 Mdot
.90571 .27084 Mdot
.90762 .33674 Mdot
.90952 .31121 Mdot
.91143 .24285 Mdot
.91333 .34898 Mdot
.91524 .37847 Mdot
.91714 .25514 Mdot
.91905 .27457 Mdot
.92095 .40551 Mdot
.92286 .38777 Mdot
.92476 .35288 Mdot
.92667 .2804 Mdot
.92857 .29575 Mdot
.93048 .22269 Mdot
.93238 .34777 Mdot
.93429 .29758 Mdot
.93619 .33805 Mdot
.9381 .24695 Mdot
.94 .30451 Mdot
.9419 .31614 Mdot
.94381 .32339 Mdot
.94571 .32297 Mdot
.94762 .32664 Mdot
.94952 .27991 Mdot
.95143 .31349 Mdot
.95333 .34674 Mdot
.95524 .38307 Mdot
.95714 .35759 Mdot
.95905 .33848 Mdot
.96095 .31767 Mdot
.96286 .42862 Mdot
.96476 .32071 Mdot
.96667 .3943 Mdot
.96857 .30878 Mdot
.97048 .39125 Mdot
.97238 .35372 Mdot
.97429 .40261 Mdot
.97619 .2695 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo04Oooooo0_l0000Yooooo`;o00005_ooool2o`0000;ooooo0_l0001`ooooo`;o00000oooool2
o`0001Wooooo0_l0000Jooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo00cooooo0_l0000Vooooo`;o00004Oooool2o`0002Wooooo0_l0000Fooooo`;o00000_oo
ool2o`0005Oooooo0_l00002ooooo`;o00004oooool2o`0000?ooooo0_l00002ooooo`;o00005Ooo
ool2o`0001[ooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`;o00001Ooo
ool2o`0002Kooooo0_l0000Mooooo`;o0000=Oooool2o`0002Wooooo0_l00002ooooo`;o00009?oo
ool2o`0000Kooooo0_l00002ooooo`;o00007?ooool2o`00037ooooo0006ooooo`05o`000?oooooo
ooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0
0005ooooo`;o00006oooool2o`0002oooooo0_l00004ooooo`;o0000;oooool2o`0002Wooooo0_l0
0002ooooo`;o00000oooool2o`0000;ooooo0_l0000Kooooo`;o00006Oooool2o`00043ooooo0006
ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Eooooo`;o00002oooool2o`0003Gooooo
0_l0000Cooooo`;o00008Oooool2o`0001oooooo0_l0000:ooooo`;o00000_ooool2o`0003Kooooo
0_l00010ooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Gooooo0_l0001Gooooo`;o0000
1?ooool2o`0001_ooooo0_l00004ooooo`;o00006Oooool2o`0008Sooooo0006ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`1dooooo`?o00008?ooool2o`00087ooooo0_l0000Pooooo`00
1_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co00001_ooool00ol0003oooooooooo`0Xooooo`;o00002Oooool2o`0000Gooooo0_l0000ioooo
o`;o00005_ooool2o`0000Cooooo0_l000000ooooooo0000o`00000Xooooo`;o00005oooool4o`00
00kooooo0_l00004ooooo`;o00009oooool2o`00023ooooo000Yooooo`;o00009Oooool2o`0000;o
oooo0_l00003ooooo`;o00001?ooool2o`0000Gooooo0ol000000ooooooo0000o`00000gooooo`;o
00005?ooool2o`0000Cooooo0_l000000ooooooo0000o`000008ooooo`;o00000oooool2o`0000go
oooo0_l0000:ooooo`;o00001_ooool2o`0000oooooo1ol0000;ooooo`;o00001?ooool2o`0000oo
oooo0_l0000:ooooo`;o00004_ooool2o`0001Sooooo000Yooooo`03o`000?oooooooooo023ooooo
0_l00002ooooo`;o00001oooool2o`0000cooooo0_l000000ooooooo0000o`00000>ooooo`;o0000
2Oooool2o`0001_ooooo0ol0000Wooooo`;o00000oooool2o`0000gooooo0_l0000Booooo`;o0000
4_ooool4o`0002;ooooo1?l00008ooooo`;o00004_ooool2o`0001Sooooo000Yooooo`03o`000?oo
oooooooo023ooooo0_l0000Iooooo`;o00004Oooool2o`0000Wooooo0_l0000Kooooo`;o00009Ooo
ool2o`0001Oooooo0_l0000Uooooo`;o00000_ooool2o`00027ooooo0_l0000Fooooo`;o00007_oo
ool002Wooooo00?o0000ooooooooool0WOooool2o`0001Oooooo0_l0000Pooooo`;o00000_ooool2
o`0000?ooooo0_l0000iooooo`;o00007_ooool002Wooooo00?o0000ooooooooool0E?ooool3o`00
02Kooooo0_l0000:ooooo`;o00002Oooool2o`0000gooooo0_l0000Looooo`Co00003oooool2o`00
00;ooooo0_l00002ooooo`;o00006_ooool2o`0001;ooooo0_l0000^ooooo`00:Oooool2o`0000So
oooo0_l0000/ooooo`?o00001oooool2o`0001?ooooo0ol0000Vooooo`;o00002_ooool2o`0000Wo
oooo0ol000000ooooooo0000o`000009ooooo`;o00001oooool2o`0000oooooo0_l00002ooooo`Co
00003?ooool2o`000003ooooool0003o000002;ooooo0_l0000Booooo`;o0000;_ooool002Wooooo
00?o0000ooooooooool01oooool2o`00017ooooo0_l0000Iooooo`?o00001oooool2o`0002Gooooo
0_l0000]ooooo`;o000000?oooooo`000?l000004_ooool2o`0000oooooo0_l0000:ooooo`;o0000
1Oooool3o`0000Gooooo0_l0000Hooooo`Co00001_ooool2o`0000_ooooo0_l0000<ooooo`;o0000
8oooool002Wooooo00?o0000ooooooooool01?ooool2o`0001Cooooo0_l00007ooooo`;o00001ooo
ool2o`0000;ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00kooooo0_l0000Booooo`;o000000Coooooo`000?l0003ooooo1_l0
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00[o
oooo0_l0000Looooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko0000o`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0:ooooo`;o00001Oooool2o`0000Kooooo0_l0
000?ooooo`;o000000Ko410@ooooooooooooooooonk^k_lb<S85o`000006ooooool0003o0000o`00
0?lb<S;ok^k^0_l0000;ooooo`;o00001_ooool2o`0000Cooooo0ol0000;ooooo`05odA4A?l0003o
0000oc8b<_oMgMd00_ooool00oo^k^ko<S8bo`000002o`0000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`00:Oooool00ol0003oooooooooo`04ooooo`;o00007Oooool2o`0000Oooooo0_l0
0004ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMg
MonHV9So0000o`000?mgMgL03_ooool2o`0001Gooooo0_l000002?oooooo0000o`000?lQ8B7ok^k^
oooooom4A4Cooooo0_l000001OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`02o`0000Sooooo0_l0000Looooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01Omg
MgOo0000o`000?nHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`;o000000?ooooooiRHV?mgMgL0
0oooool2o`00013ooooo0_l00005ooooo`;o00000_ooool2o`0000[ooooo00OoMgMgoc8b<_oooooo
ooooogMgMonHV9Sooooo00;o00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000Yoooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@00?ooooo00Go410@ooooool0003o0000oa0@400Zooooo`03oiRHV?lQ8B7ok^k^00;ooooo0_l0
00001Ol@413ooooooooooooooooo410@00;ooooo0_l000001?oooooo0000o`000?l@4102o`0002[o
oooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool0
0ol@413oooooooooo`06ooooo`;o00003?ooool2o`00013ooooo1ol000001?oooooo410@oooooooo
ool2o`0000;ooooo0_l00003ooooo`04oa0@4?ooooooooooooooo`Co00006Oooool2o`0000_ooooo
00Co0000oooooooooooo410@0oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooo
ooooool00Oooool002Wooooo0_l0000cooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000003oooool2o`0001[ooooo00CoV9RH
ob4Q8Ol0003o00000_ooool01Ol0003ooooooooooooooooo000000;ooooo0_l000000ooooooo0000
o`000003o`0002Wooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000008ooooo`;o00002oooool3o`0000?ooooo0_l0000;oooo
o`05odA4A?oMgMgoooooo`000?ooool00_l000001?oooooo0000ooooooooool2o`0000;ooooo0_l0
0003ooooo`03o`000?oooooooooo00?ooooo0_l00005ooooo`;o00001_ooool2o`0000gooooo0_l0
0005ooooo`;o000000GoMgMgoc8b<_ooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`01ooooo`00:Oooool00ol0003oooooooooo`0booooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000003oooool2o`0000cooooo0_l0000<ooooo`Co00000_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`00000Hooooo`;o00004?ooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000000oooool3o`000003ooooool0003ooooo00Gooooo
0_l0000=ooooo`Co00000_ooool2o`0000_ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00000<ooooo`;o00001_ooool2
o`0000gooooo0_l00004ooooo`?o000000Go<S8bolc<c?ooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`01ooooo`00:Oooool01?l0003ooooooooo
ooooool2o`0001;ooooo0_l0000Jooooo`;o00001?ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400Mooooo`;o00003?ooool3o`0000?ooooo00Go410@oooo
oooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41006?ooool3o`00013ooooo00?o
^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@o`000?l0003o
oooooa0@4006ooooo`;o00002_ooool2o`0000?ooooo0_l0000@ooooo`03ogMgMoo<c<co000000Co
oooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100:Oooool0
0ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooo
oooooooo410@00?ooooo000Yooooo`03o`000?oooooo000000?o00004_ooool2o`0000Sooooo0_l0
000:ooooo`;o00000_ooool4o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0:Oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06Oooool3o`0000cooooo00?o
410@oiRHV?ooool00_l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00oooooo0_l000000ooooooo0000o`00000Eooooo`03onk^k_m4A4Co000000Co
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:Oooool0
0ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo000Yooooo`04o`000?oooooo0000o`0001kooooo0_l0000:ooooo`;o0000
0_ooool4o`0000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h06oooool2o`0000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo0_l0000<ooooo`03ojVY
ZOl@413o000000;o00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0?ooooo`;o00006Oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Wooooo1?l00003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Yooooo`;o0000
0oooool2o`0000kooooo0_l00002ooooo`;o0000<oooool2o`0000kooooo0_l00002ooooo`;o0000
:_ooool2o`0009;ooooo0_l0000Kooooo`00:Oooool00ol0003oooooooooo`02ooooo`;o00003?oo
ool4o`0000;ooooo0_l0000@ooooo`;o00006_ooool2o`0000Gooooo0_l0000>ooooo`;o00004Ooo
ool2o`0001_ooooo0_l0000?ooooo`;o00001_ooool2o`00017ooooo0_l00010ooooo`;o00001ooo
ool2o`0000_ooooo0_l0000>ooooo`Co00006Oooool002Wooooo00?o0000ooooooooool04?ooool2
o`0000cooooo0_l00008ooooo`;o00006_ooool2o`0000?ooooo0_l0000Sooooo`;o00002Oooool2
o`0000Wooooo0_l0000Fooooo`;o00001_ooool2o`00017ooooo0_l0000aooooo`;o00000oooool2
o`0000Sooooo0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o000000Sooooo0_l0000@
ooooo`;o00006Oooool002Wooooo00?o0000ooooooooool04Oooool2o`0000_ooooo0_l0000Yoooo
o`;o00009?ooool2o`0000Sooooo0_l00009ooooo`?o0000>Oooool2o`000003ooooool0003o0000
00Kooooo0_l0000Booooo`;o00002Oooool2o`0000?ooooo0_l00005ooooo`;o00001_ooool2o`00
00Gooooo0_l0000Looooo`;o00005oooool002Wooooo00?o0000ooooooooool01_ooool2o`0000Co
oooo0_l00003ooooo`;o00007oooool2o`0000Wooooo0_l0000=ooooo`;o00002_ooool2o`0000oo
oooo0_l00004ooooo`;o00003?ooool2o`0000Kooooo0_l0000iooooo`;o000000?oooooo`000?l0
00001_ooool2o`0001;ooooo0_l00002ooooo`;o00004Oooool2o`0002_ooooo0_l00007ooooo`;o
00003_ooool0027oooooool00014o`0000Cooooo000Yooooo`?o00002Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Kooooo0_l000000ooooooo0000ooooo`0:ooooo`03o`000?oo
oooooooo00Kooooo1?l00006ooooo`;o00001?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Sooooo0_l0000;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?oo
ool3o`0000Cooooo1?l00003ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?oo
ool2o`000004ooooool0003o0000o`0000cooooo00Co0000oooooooooooooooo1?l00004ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02o`0000So
oooo00?o0000ooooooooool02Oooool01?l0003oooooo`000?l00008ooooo`04o`000?oooooooooo
ooooo`;o00001_ooool00ol0003oooooooooo`0:ooooo`00:Oooool00ol0003oooooooooo`0Roooo
o`;o000000?oooooo`000?l000004Oooool3o`0000Kooooo0_l0000Zooooo`;o00002Oooool00ol0
003oooooooooo`0cooooo`?o00001?ooool00ol0003oooooooooo`0Cooooo`;o00004oooool2o`00
013ooooo00?o0000ooooooooool0;_ooool2o`0000;ooooo0_l000000ooooooo0000o`000003oooo
o`03o`000?oooooooooo00[ooooo000Yooooo`03o`000?oooooooooo013ooooo0_l0000@ooooo`;o
000000Coooooo`000?l0003o0000AOooool2o`00033ooooo0_l0001Looooo`;o00004oooool2o`00
00oooooo0_l00005ooooo`?o00003oooool002Wooooo00?o0000ooooooooool04?ooool2o`0001Co
oooo0_l0000;ooooo`;o0000<_ooool2o`0000;ooooo0_l00007ooooo`;o00000_ooool3o`0000Ko
oooo0_l0000Looooo`;o00008?ooool2o`000003ooooool0003o000003Oooooo0_l0000=ooooo`;o
00001?ooool3o`0000oooooo0ol00004ooooo`;o00003oooool002Wooooo0_l00002ooooo`;o0000
<?ooool2o`0002Wooooo0_l00007ooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000
o`000006o`0000Gooooo0_l0000?ooooo`;o00005_ooool2o`0000Kooooo0_l00007ooooo`;o0000
00Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000002o`0000Kooooo0_l0000Iooooo`;o
00000oooool2o`0001cooooo0_l00002ooooo`Go00003oooool3o`0001Gooooo000Yooooo`04o`00
0?ooooooooooooooo`;o00005?ooool3o`0000?ooooo0_l0000Aooooo`;o00001?ooool2o`0000_o
oooo0_l0000Cooooo`;o00001?ooool2o`00017ooooo0_l00003ooooo`?o000000?oooooo`000?l0
00002oooool2o`0000Wooooo0_l00004ooooo`;o00004?ooool2o`0000Kooooo0_l00004ooooo`Go
000000?oooooo`000?l000001_ooool2o`0000Kooooo0_l0000Iooooo`;o00000oooool2o`0001go
oooo0_l000000ooooooo0000o`000002ooooo`;o00003oooool2o`0001Gooooo000Yooooo`03o`00
0?oooooooooo01Oooooo0ol00003ooooo`;o00002oooool2o`0000Cooooo0_l00004ooooo`;o0000
2oooool2o`0000Wooooo0_l00008ooooo`;o00002Oooool2o`0001;ooooo0_l0000<ooooo`Co0000
3oooool2o`0000_ooooo0_l0000Aooooo`Co0000DOooool4o`0000?ooooo0_l0000Vooooo`00:Ooo
ool00ol0003oooooooooo`0Zooooo`;o00002Oooool2o`0000oooooo0_l00006ooooo`?o00001Ooo
ool2o`0000_ooooo0_l00003ooooo`;o00006oooool2o`0000gooooo0_l0000?ooooo`;o000000Co
ooooo`000?l0003ooooo0_l0000Pooooo`;o00007oooool2o`0001oooooo0_l00007ooooo`;o0000
8_ooool002Wooooo00?o0000ooooooooool00_ooool2o`0002kooooo0_l000000ooooooo0000o`00
0009ooooo`;o00000oooool3o`0000Oooooo0_l00005ooooo`;o00004?ooool2o`0002[ooooo0_l0
000Booooo`;o000000?oooooo`000?l000007?ooool2o`0000;ooooo0_l0000Oooooo`;o00001?oo
ool2o`0000Cooooo0_l00002ooooo`;o00006?ooool2o`0000Sooooo0_l00005ooooo`;o00004Ooo
ool002Wooooo1ol000000ooooooo0000o`00000Nooooo`;o00002oooool2o`0000Cooooo0_l00006
ooooo`;o00000oooool2o`0003?ooooo0_l0000<ooooo`;o0000?oooool2o`0002Wooooo0_l00004
ooooo`;o00000_ooool2o`0002;ooooo0_l00005ooooo`;o00004Oooool002Wooooo00?o0000oooo
ool000000_l00003ooooo`;o00005Oooool2o`0000Oooooo0_l00002ooooo`;o00003Oooool2o`00
00_ooooo0_l0000:ooooo`;o00007Oooool2o`0000Sooooo0_l0000<ooooo`;o00008Oooool2o`00
00Cooooo0_l0000_ooooo`;o000000?oooooo`000?l000003_ooool2o`0004Gooooo000Yooooo`03
o`000?oooooooooo00gooooo0_l00005ooooo`;o00000oooool2o`000003ooooool0003o000000_o
oooo0_l0000Vooooo`;o00003oooool2o`0000cooooo0_l0000fooooo`;o000000?oooooo`000?l0
00001?ooool2o`0000Oooooo0_l0000Aooooo`;o00000oooool2o`0000kooooo0_l000000ooooooo
0000o`00000>ooooo`;o00008oooool2o`0000Cooooo0_l00005ooooo`;o00004oooool002Wooooo
00?o0000ooooooooool00oooool2o`0000Sooooo0_l00005ooooo`;o00000oooool3o`0004;ooooo
0_l00002ooooo`;o00000oooool2o`0001Gooooo0_l0000?ooooo`;o00002?ooool3o`0000Gooooo
0_l00005ooooo`;o00004?ooool2o`0000[ooooo0_l00005ooooo`;o00000oooool2o`0002?ooooo
1?l0000?ooooo`;o00003_ooool2o`0000Cooooo0_l00005ooooo`;o00004oooool002Wooooo00?o
0000ooooooooool00oooool2o`0000?ooooo0_l00003ooooo`;o00002oooool2o`0000_ooooo0_l0
000aooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`00000Cooooo`Co00003Ooo
ool4o`0000Sooooo0ol00002ooooo`;o000000?oooooo`000?l000001?ooool2o`0001gooooo0_l0
000Wooooo`?o00001Oooool4o`000004ooooool0003o0000ooooo`;o00000oooool2o`0000Cooooo
0_l0000Booooo`;o00003Oooool2o`0000gooooo000Yooooo`;o00002Oooool2o`0001Kooooo0_l0
0005ooooo`;o00005Oooool2o`0001Cooooo0_l00004ooooo`;o00002?ooool2o`0001Kooooo0_l0
000?ooooo`;o00003_ooool3o`0000Oooooo0_l00004ooooo`;o0000@?ooool3o`0000[ooooo0_l0
00000ooooooo0000o`000003ooooo`;o00006?ooool2o`0000Sooooo0_l00003ooooo`;o00003Ooo
ool002Wooooo00?o0000ooooooooool04oooool2o`0000_ooooo0ol0000Kooooo`;o00005?ooool2
o`0003oooooo0_l00006ooooo`;o00000oooool2o`0000Wooooo0_l0001iooooo`;o00004_ooool0
02Wooooo00?o0000ooooooooool04oooool2o`0000?ooooo0_l00007ooooo`;o0000JOooool2o`00
00Oooooo0_l0000;ooooo`;o00001Oooool2o`0001[ooooo0_l0000Mooooo`;o0000E_ooool002Wo
oooo00?o0000ooooooooool06?ooool2o`0000Wooooo0_l00005ooooo`;o0000H?ooool2o`0001_o
oooo0_l0000Jooooo`;o00007Oooool2o`0000?ooooo0_l0001Aooooo`00:Oooool00ol0003ooooo
ooooo`0Sooooo`;o00001Oooool2o`00033ooooo0_l0002;ooooo`;o0000DOooool002Wooooo0_l0
000Hooooo`;o0000@oooool2o`0000cooooo0_l0000Hooooo`;o00004Oooool2o`0001[ooooo0_l0
000Jooooo`;o0000=_ooool2o`0000cooooo0_l0000Uooooo`00:Oooool00ol0003oooooooooo`0G
ooooo`;o0000A?ooool2o`0000_ooooo0_l0000Hooooo`;o00004Oooool2o`0001[ooooo0_l0000J
ooooo`;o0000=_ooool2o`0000cooooo0_l0000Uooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool05?ooool2o`0004Oooooo0_l0001Pooooo`;o0000B_ooool2o`0000kooooo0_l0
000Oooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01Cooooo
0_l0000Vooooo`;o00007_ooool2o`0000Sooooo0_l0001Gooooo`;o0000<_ooool2o`0000kooooo
0_l00006ooooo`;o00003_ooool2o`0000_ooooo0_l0000Booooo`001_ooool01Ol@413ooooooooo
oooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`;o0000
?Oooool2o`0001kooooo0_l000000ooooooo0000o`000005ooooo`;o00009oooool2o`0000oooooo
1?l00002ooooo`;o0000;_ooool2o`0000cooooo0_l0000=ooooo`;o00003_ooool2o`0002?ooooo
0_l0000Booooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o00004_ooool2o`0002Kooooo0_l0000Sooooo`Co0000
9_ooool2o`0000Cooooo0_l0000?ooooo`Co00000_ooool2o`0002kooooo0_l000000ooooooo0000
o`000008ooooo`?o0000=oooool2o`0001gooooo0006ooooo`05o`000?ooooooooooooooool00000
3_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003o
ooooooooo`0Booooo`;o00001oooool4o`0000cooooo0_l0000<ooooo`?o00005?ooool2o`0000oo
oooo1?l0000Rooooo`Co00005?ooool2o`0002_ooooo0_l00009ooooo`Co00002?ooool2o`000003
ooooool0003o000001kooooo0_l0000Eooooo`;o00003_ooool2o`0000gooooo0006ooooo`05oa0@
4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool06oooool4o`0000cooooo0_l0000<ooooo`;o00004_ooool2o`000003
ooooool0003o0000017ooooo0_l0000Fooooo`;o00001?ooool2o`0000Cooooo0_l00007ooooo`;o
00003Oooool2o`0000oooooo0_l00006ooooo`;o00004_ooool2o`0000Wooooo0_l0000=ooooo`;o
00004oooool2o`0000Wooooo0_l00005ooooo`;o00001_ooool4o`0001;ooooo1?l0000=ooooo`00
1_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004oooo
o`03o`000?oooooooooo00Oooooo0_l0000^ooooo`?o00007Oooool2o`0001Kooooo0_l00004oooo
o`;o00003_ooool2o`0000Cooooo0_l0000=ooooo`;o00007_ooool2o`0000Kooooo0_l00011oooo
o`;o00004?ooool2o`0000Kooooo1?l0000Booooo`;o00003oooool000Kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0000@
ooooo`;o00007?ooool3o`0001_ooooo0_l0000Hooooo`;o00001?ooool2o`0003Kooooo0_l00005
ooooo`;o00009?ooool2o`0000oooooo0_l0000aooooo`;o00009_ooool002Wooooo0_l0000;oooo
o`;o00000oooool2o`0001gooooo0_l0000Hooooo`Go00001?ooool2o`0000gooooo0_l0000:oooo
o`;o0000=Oooool2o`0000Gooooo0_l0000Tooooo`;o000000?oooooo`000?l000003?ooool2o`00
00?ooooo0_l0000Rooooo`;o00002?ooool4o`0001Kooooo0_l0000<ooooo`00:Oooool00ol0003o
ooooooooo`0:ooooo`;o00008_ooool2o`0001Sooooo1?l000001?oooooo0000o`000?ooool3o`00
00gooooo0_l0000:ooooo`;o0000G?ooool2o`0000Oooooo0_l0000Aooooo`?o00008Oooool2o`00
00[ooooo0_l00005ooooo`;o00003oooool2o`0000cooooo000Yooooo`03o`000?oooooooooo00Wo
oooo0ol00002ooooo`;o0000;Oooool2o`0000?ooooo0_l00009ooooo`;o000000?oooooo`000?l0
0000;Oooool2o`0000oooooo0_l0000Zooooo`;o00003?ooool2o`0001_ooooo0_l0000dooooo`;o
00007Oooool002Wooooo00?o0000ooooooooool01?ooool2o`000003ooooool0003o000000Co0000
00?oooooo`000?l000005oooool2o`0001Cooooo0_l000000ooooooo0000o`000002o`0000;ooooo
1Ol0000Iooooo`;o00006Oooool3o`0000Cooooo0_l00008ooooo`Co0000:?ooool3o`0001cooooo
0_l0000@ooooo`;o0000COooool002Wooooo00?o0000ooooooooool01?ooool2o`000003ooooool0
003o000000Co00006_ooool2o`0001Oooooo0_l00004ooooo`Go00002oooool2o`0000?ooooo0_l0
0007ooooo`;o00003?ooool2o`0000cooooo0_l00004ooooo`;o00002_ooool2o`0001[ooooo0_l0
000=ooooo`;o00007?ooool2o`00013ooooo0_l0001=ooooo`00:Oooool2o`0000[ooooo0_l0001;
ooooo`;o00000oooool2o`0001Gooooo0_l0000jooooo`;o00001Oooool2o`0003[ooooo0_l00019
ooooo`00:Oooool00ol0003oooooooooo`2eooooo`;o0000>_ooool2o`0004Wooooo000Yooooo`03
o`000?oooooooooo0?oooooo2?ooool2o`0003?ooooo000Yooooo`03o`000?oooooooooo0?oooooo
2?ooool2o`00027ooooo0_l0000@ooooo`00:Oooool00ol0003oooooooooo`3oooooob_ooooo0_l0
000@ooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0@oooool2o`00
0?Oooooo000Yooooo`03o`000?oooooooooo04?ooooo0_l0002Sooooo`;o0000D_ooool002Wooooo
00?o0000ooooooooool0j?ooool2o`0005;ooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo05Oooooo0_l0003Soooo
o`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool00ol0003oooooooooo`1Gooooo`;o0000hoooool000kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo0;Kooooo0_l00024ooooo`003_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000
ooooooooool00oooool3o`000;Kooooo0_l00024ooooo`003_ooool01Ol0003ooooooooooooooooo
000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo000>oooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool0oooooolmooooo`003_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Ooo
ool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003Oooool0
0onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006oooo
o`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo
000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?o
ZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Ooo
ool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S80
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`007oooool4o`000003oa0@4?oooooooooo
00?ooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool3o`000?oooooo
?Oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`007oooool00omEEEGoIVIVo`00003oooooodOooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .31961 Mdot
.02762 .34399 Mdot
.02952 .30265 Mdot
.03143 .26125 Mdot
.03333 .3634 Mdot
.03524 .25768 Mdot
.03714 .2731 Mdot
.03905 .41218 Mdot
.04095 .3893 Mdot
.04286 .28496 Mdot
.04476 .31881 Mdot
.04667 .3776 Mdot
.04857 .37536 Mdot
.05048 .28408 Mdot
.05238 .32291 Mdot
.05429 .25758 Mdot
.05619 .2618 Mdot
.0581 .37654 Mdot
.06 .34771 Mdot
.0619 .42314 Mdot
.06381 .39565 Mdot
.06571 .37557 Mdot
.06762 .39352 Mdot
.06952 .38585 Mdot
.07143 .3092 Mdot
.07333 .36254 Mdot
.07524 .34073 Mdot
.07714 .35217 Mdot
.07905 .42635 Mdot
.08095 .36157 Mdot
.08286 .40789 Mdot
.08476 .40367 Mdot
.08667 .39388 Mdot
.08857 .24411 Mdot
.09048 .24339 Mdot
.09238 .41927 Mdot
.09429 .41981 Mdot
.09619 .34946 Mdot
.0981 .42203 Mdot
.1 .39028 Mdot
.1019 .34555 Mdot
.10381 .24413 Mdot
.10571 .24923 Mdot
.10762 .29564 Mdot
.10952 .28254 Mdot
.11143 .3658 Mdot
.11333 .31278 Mdot
.11524 .42014 Mdot
.11714 .34262 Mdot
.11905 .42383 Mdot
.12095 .4158 Mdot
.12286 .42758 Mdot
.12476 .27059 Mdot
.12667 .24895 Mdot
.12857 .2417 Mdot
.13048 .3879 Mdot
.13238 .40354 Mdot
.13429 .27569 Mdot
.13619 .42093 Mdot
.1381 .27692 Mdot
.14 .36248 Mdot
.1419 .27373 Mdot
.14381 .41763 Mdot
.14571 .3223 Mdot
.14762 .35615 Mdot
.14952 .40267 Mdot
.15143 .29052 Mdot
.15333 .26354 Mdot
.15524 .34357 Mdot
.15714 .39586 Mdot
.15905 .30289 Mdot
.16095 .2677 Mdot
.16286 .30257 Mdot
.16476 .27505 Mdot
.16667 .41751 Mdot
.16857 .31441 Mdot
.17048 .27124 Mdot
.17238 .34113 Mdot
.17429 .42805 Mdot
.17619 .2971 Mdot
.1781 .41443 Mdot
.18 .3654 Mdot
.1819 .26086 Mdot
.18381 .24532 Mdot
.18571 .41289 Mdot
.18762 .25956 Mdot
.18952 .3638 Mdot
.19143 .35701 Mdot
.19333 .29793 Mdot
.19524 .26673 Mdot
.19714 .29752 Mdot
.19905 .22601 Mdot
.20095 .3153 Mdot
.20286 .36438 Mdot
.20476 .31301 Mdot
.20667 .22052 Mdot
.20857 .28369 Mdot
.21048 .39943 Mdot
.21238 .27259 Mdot
.21429 .31617 Mdot
.21619 .33285 Mdot
.2181 .32021 Mdot
.22 .36144 Mdot
.2219 .31182 Mdot
.22381 .40815 Mdot
.22571 .24405 Mdot
.22762 .28108 Mdot
.22952 .35057 Mdot
.23143 .31572 Mdot
.23333 .40013 Mdot
.23524 .27888 Mdot
.23714 .26999 Mdot
.23905 .40094 Mdot
.24095 .42095 Mdot
.24286 .33972 Mdot
.24476 .30871 Mdot
.24667 .35631 Mdot
.24857 .41903 Mdot
.25048 .41573 Mdot
.25238 .40682 Mdot
.25429 .37959 Mdot
.25619 .30233 Mdot
.2581 .40164 Mdot
.26 .42661 Mdot
.2619 .39827 Mdot
.26381 .25852 Mdot
.26571 .42281 Mdot
.26762 .22242 Mdot
.26952 .36596 Mdot
.27143 .32938 Mdot
.27333 .38528 Mdot
.27524 .34667 Mdot
.27714 .3613 Mdot
.27905 .24825 Mdot
.28095 .25268 Mdot
.28286 .42875 Mdot
.28476 .43138 Mdot
.28667 .42484 Mdot
.28857 .30422 Mdot
.29048 .37617 Mdot
.29238 .33189 Mdot
.29429 .22829 Mdot
.29619 .29476 Mdot
.2981 .34319 Mdot
.3 .26429 Mdot
.3019 .42172 Mdot
.30381 .41536 Mdot
.30571 .36219 Mdot
.30762 .3573 Mdot
.30952 .35765 Mdot
.31143 .3434 Mdot
.31333 .32884 Mdot
.31524 .32913 Mdot
.31714 .38284 Mdot
.31905 .26848 Mdot
.32095 .29944 Mdot
.32286 .42667 Mdot
.32476 .42202 Mdot
.32667 .41028 Mdot
.32857 .41539 Mdot
.33048 .42791 Mdot
.33238 .3562 Mdot
.33429 .42935 Mdot
.33619 .38816 Mdot
.3381 .41714 Mdot
.34 .26798 Mdot
.3419 .34503 Mdot
.34381 .4131 Mdot
.34571 .40925 Mdot
.34762 .34319 Mdot
.34952 .43207 Mdot
.35143 .42021 Mdot
.35333 .27895 Mdot
.35524 .34483 Mdot
.35714 .36104 Mdot
.35905 .35873 Mdot
.36095 .37612 Mdot
.36286 .22072 Mdot
.36476 .3011 Mdot
.36667 .3211 Mdot
.36857 .42601 Mdot
.37048 .43192 Mdot
.37238 .37815 Mdot
.37429 .25929 Mdot
.37619 .34377 Mdot
.3781 .3304 Mdot
.38 .38034 Mdot
.3819 .22126 Mdot
.38381 .41767 Mdot
.38571 .38573 Mdot
.38762 .24625 Mdot
.38952 .31237 Mdot
.39143 .42127 Mdot
.39333 .32247 Mdot
.39524 .26284 Mdot
.39714 .41032 Mdot
.39905 .35359 Mdot
.40095 .36308 Mdot
.40286 .3634 Mdot
.40476 .22269 Mdot
.40667 .28022 Mdot
.40857 .31482 Mdot
.41048 .31579 Mdot
.41238 .26778 Mdot
.41429 .36124 Mdot
.41619 .22713 Mdot
.4181 .34839 Mdot
.42 .32367 Mdot
.4219 .2685 Mdot
.42381 .28565 Mdot
.42571 .33307 Mdot
.42762 .31261 Mdot
.42952 .36512 Mdot
.43143 .34515 Mdot
.43333 .40982 Mdot
.43524 .26546 Mdot
.43714 .34889 Mdot
.43905 .34375 Mdot
.44095 .38249 Mdot
.44286 .33197 Mdot
.44476 .30182 Mdot
.44667 .39925 Mdot
.44857 .35848 Mdot
.45048 .40742 Mdot
.45238 .40623 Mdot
.45429 .41534 Mdot
.45619 .27345 Mdot
.4581 .36127 Mdot
.46 .32296 Mdot
.4619 .29171 Mdot
.46381 .32433 Mdot
.46571 .31251 Mdot
.46762 .25805 Mdot
.46952 .29823 Mdot
.47143 .24228 Mdot
.47333 .3074 Mdot
.47524 .33144 Mdot
.47714 .29867 Mdot
.47905 .34631 Mdot
.48095 .31492 Mdot
.48286 .3942 Mdot
.48476 .34155 Mdot
.48667 .26583 Mdot
.48857 .2454 Mdot
.49048 .41167 Mdot
.49238 .3028 Mdot
.49429 .41363 Mdot
.49619 .30531 Mdot
.4981 .41825 Mdot
.5 .26377 Mdot
.5019 .3051 Mdot
.50381 .4204 Mdot
.50571 .3486 Mdot
.50762 .30946 Mdot
.50952 .31288 Mdot
.51143 .41347 Mdot
.51333 .35084 Mdot
.51524 .34495 Mdot
.51714 .24445 Mdot
.51905 .31432 Mdot
.52095 .39459 Mdot
.52286 .42149 Mdot
.52476 .32904 Mdot
.52667 .33076 Mdot
.52857 .41621 Mdot
.53048 .32608 Mdot
.53238 .31755 Mdot
.53429 .32366 Mdot
.53619 .32363 Mdot
.5381 .28118 Mdot
.54 .41909 Mdot
.5419 .33531 Mdot
.54381 .42146 Mdot
.54571 .24167 Mdot
.54762 .27422 Mdot
.54952 .31381 Mdot
.55143 .42854 Mdot
.55333 .25733 Mdot
.55524 .35536 Mdot
.55714 .41229 Mdot
.55905 .29989 Mdot
.56095 .28308 Mdot
.56286 .42715 Mdot
.56476 .32464 Mdot
.56667 .28229 Mdot
.56857 .41249 Mdot
.57048 .37105 Mdot
.57238 .35019 Mdot
.57429 .27028 Mdot
.57619 .35592 Mdot
.5781 .41652 Mdot
.58 .35993 Mdot
.5819 .41331 Mdot
.58381 .22123 Mdot
.58571 .41467 Mdot
.58762 .33946 Mdot
.58952 .40446 Mdot
.59143 .29174 Mdot
.59333 .42737 Mdot
.59524 .25265 Mdot
.59714 .41245 Mdot
.59905 .32696 Mdot
.60095 .37245 Mdot
.60286 .32824 Mdot
.60476 .24126 Mdot
.60667 .342 Mdot
.60857 .40943 Mdot
.61048 .33115 Mdot
.61238 .31094 Mdot
.61429 .40743 Mdot
.61619 .35113 Mdot
.6181 .30651 Mdot
.62 .37251 Mdot
.6219 .26202 Mdot
.62381 .3828 Mdot
.62571 .34364 Mdot
.62762 .31742 Mdot
.62952 .311 Mdot
.63143 .24366 Mdot
.63333 .35245 Mdot
.63524 .32295 Mdot
.63714 .37148 Mdot
.63905 .27536 Mdot
.64095 .23748 Mdot
.64286 .25802 Mdot
.64476 .24334 Mdot
.64667 .24809 Mdot
.64857 .41675 Mdot
.65048 .36047 Mdot
.65238 .29786 Mdot
.65429 .28053 Mdot
.65619 .28032 Mdot
.6581 .40468 Mdot
.66 .40823 Mdot
.6619 .31824 Mdot
.66381 .36819 Mdot
.66571 .32951 Mdot
.66762 .26824 Mdot
.66952 .32682 Mdot
.67143 .25117 Mdot
.67333 .26738 Mdot
.67524 .35467 Mdot
.67714 .36059 Mdot
.67905 .24938 Mdot
.68095 .34041 Mdot
.68286 .36954 Mdot
.68476 .31525 Mdot
.68667 .38675 Mdot
.68857 .3401 Mdot
.69048 .42422 Mdot
.69238 .38004 Mdot
.69429 .31038 Mdot
.69619 .34444 Mdot
.6981 .23079 Mdot
.7 .38593 Mdot
.7019 .43159 Mdot
.70381 .42023 Mdot
.70571 .3404 Mdot
.70762 .26638 Mdot
.70952 .42128 Mdot
.71143 .31404 Mdot
.71333 .38374 Mdot
.71524 .25121 Mdot
.71714 .41238 Mdot
.71905 .35837 Mdot
.72095 .36852 Mdot
.72286 .36471 Mdot
.72476 .27085 Mdot
.72667 .31266 Mdot
.72857 .32591 Mdot
.73048 .40017 Mdot
.73238 .27161 Mdot
.73429 .41122 Mdot
.73619 .32411 Mdot
.7381 .25858 Mdot
.74 .32988 Mdot
.7419 .39604 Mdot
.74381 .31707 Mdot
.74571 .42131 Mdot
.74762 .40951 Mdot
.74952 .39312 Mdot
.75143 .43337 Mdot
.75333 .38671 Mdot
.75524 .31887 Mdot
.75714 .34258 Mdot
.75905 .40223 Mdot
.76095 .28806 Mdot
.76286 .26857 Mdot
.76476 .29728 Mdot
.76667 .31025 Mdot
.76857 .28192 Mdot
.77048 .38369 Mdot
.77238 .39681 Mdot
.77429 .2916 Mdot
.77619 .28116 Mdot
.7781 .35881 Mdot
.78 .33542 Mdot
.7819 .42152 Mdot
.78381 .40046 Mdot
.78571 .25571 Mdot
.78762 .37727 Mdot
.78952 .25202 Mdot
.79143 .26026 Mdot
.79333 .25704 Mdot
.79524 .35846 Mdot
.79714 .35906 Mdot
.79905 .31186 Mdot
.80095 .40025 Mdot
.80286 .37698 Mdot
.80476 .33959 Mdot
.80667 .29636 Mdot
.80857 .30451 Mdot
.81048 .25645 Mdot
.81238 .34193 Mdot
.81429 .36576 Mdot
.81619 .41799 Mdot
.8181 .27777 Mdot
.82 .33336 Mdot
.8219 .32657 Mdot
.82381 .36468 Mdot
.82571 .2443 Mdot
.82762 .32521 Mdot
.82952 .32269 Mdot
.83143 .32241 Mdot
.83333 .37951 Mdot
.83524 .28718 Mdot
.83714 .24292 Mdot
.83905 .27995 Mdot
.84095 .3232 Mdot
.84286 .32004 Mdot
.84476 .34261 Mdot
.84667 .30948 Mdot
.84857 .22048 Mdot
.85048 .33046 Mdot
.85238 .32172 Mdot
.85429 .29327 Mdot
.85619 .32635 Mdot
.8581 .37135 Mdot
.86 .31977 Mdot
.8619 .32799 Mdot
.86381 .3843 Mdot
.86571 .25572 Mdot
.86762 .29058 Mdot
.86952 .28797 Mdot
.87143 .3587 Mdot
.87333 .41646 Mdot
.87524 .31175 Mdot
.87714 .22412 Mdot
.87905 .33132 Mdot
.88095 .24787 Mdot
.88286 .24904 Mdot
.88476 .32312 Mdot
.88667 .32151 Mdot
.88857 .26157 Mdot
.89048 .40991 Mdot
.89238 .31583 Mdot
.89429 .42852 Mdot
.89619 .33583 Mdot
.8981 .29859 Mdot
.9 .42215 Mdot
.9019 .41208 Mdot
.90381 .25943 Mdot
.90571 .23076 Mdot
.90762 .28139 Mdot
.90952 .40473 Mdot
.91143 .35554 Mdot
.91333 .32812 Mdot
.91524 .42944 Mdot
.91714 .32723 Mdot
.91905 .25428 Mdot
.92095 .4241 Mdot
.92286 .32808 Mdot
.92476 .35146 Mdot
.92667 .3459 Mdot
.92857 .24469 Mdot
.93048 .30215 Mdot
.93238 .26526 Mdot
.93429 .31423 Mdot
.93619 .25576 Mdot
.9381 .30426 Mdot
.94 .26763 Mdot
.9419 .26191 Mdot
.94381 .24632 Mdot
.94571 .24469 Mdot
.94762 .31159 Mdot
.94952 .34821 Mdot
.95143 .40173 Mdot
.95333 .36295 Mdot
.95524 .32166 Mdot
.95714 .33298 Mdot
.95905 .35517 Mdot
.96095 .27611 Mdot
.96286 .32433 Mdot
.96476 .28137 Mdot
.96667 .33569 Mdot
.96857 .39514 Mdot
.97048 .41793 Mdot
.97238 .34507 Mdot
.97429 .42548 Mdot
.97619 .37801 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo03Oooooo0_l0000`ooooo`;o00001?ooool2o`0003oooooo0_l0001Coooo
o`;o0000=Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`00
00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo03Oooooo0_l0000B
ooooo`;o00007?ooool2o`0000Cooooo0_l00006ooooo`;o0000=oooool2o`0005?ooooo0_l00008
ooooo`;o0000:oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`0eooooo`;o00005?ooool2o`0002[ooooo0_l000000ooooooo0000o`00002Cooooo`;o0000:ooo
ool000Co00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Gooooo0_l0000Looooo`;o00009Ooo
ool2o`0005Wooooo0_l00011ooooo`;o00008_ooool000Kooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0005?ooooo0_l0
0020ooooo`;o0000@Oooool2o`0002;ooooo0006ooooo`05o`000?ooooooooooooooool000003_oo
ool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0`oooool2o`0007Oooooo
0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`;o00002_ooool2o`0006co
oooo0_l0000Fooooo`;o00004Oooool2o`0000[ooooo0ol0000looooo`;o0000>?ooool000Kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`00
00Kooooo00?o0000ooooooooool04Oooool3o`0000;ooooo0_l00006ooooo`;o00004?ooool2o`00
00_ooooo0_l0000booooo`;o00006Oooool2o`0000Cooooo0_l00007ooooo`;o00001oooool2o`00
017ooooo0_l00007ooooo`;o00000_ooool2o`0003Sooooo0_l00002ooooo`;o00006oooool2o`00
00?ooooo0ol0000Eooooo`00:Oooool2o`0001;ooooo0_l00003ooooo`?o00001?ooool2o`00017o
oooo0_l0000;ooooo`;o00003oooool2o`00027ooooo0_l0000Oooooo`;o00001oooool2o`0002?o
oooo0_l00003ooooo`;o00002?ooool2o`0002gooooo0_l0000@ooooo`;o00003Oooool2o`0000?o
oooo0ol0000Eooooo`00:Oooool00ol0003oooooooooo`0Gooooo`;o00001?ooool2o`0002oooooo
0ol0001Sooooo`;o00003oooool2o`0000Kooooo1?l0000:ooooo`;o00005Oooool2o`0001cooooo
0_l0000Zooooo`00:Oooool00ol0003oooooooooo`1?ooooo`;o0000Hoooool2o`0001Oooooo0_l0
000<ooooo`;o00005?ooool3o`0001Oooooo0_l0000?ooooo`;o00001?ooool2o`0001Sooooo000Y
ooooo`03o`000?oooooooooo00;o00001?ooool2o`00047ooooo0_l00010ooooo`;o00006_ooool2
o`0001[ooooo0_l0000Mooooo`;o00003Oooool2o`000003ooooool0003o000000?ooooo0_l0000@
ooooo`;o00003oooool2o`0000Cooooo0_l0000Hooooo`00:Oooool00ol0003oooooo`000002o`00
00Cooooo0ol0000Vooooo`Co00005_ooool2o`0002;ooooo0_l0000Looooo`;o00006_ooool2o`00
01Cooooo0_l00004ooooo`;o00007Oooool2o`0000oooooo0ol00003ooooo`;o00005oooool2o`00
00?ooooo0_l0000:ooooo`;o00005oooool002Wooooo1?l00006ooooo`;o00007Oooool2o`0000Oo
oooo1?l0000Rooooo`;o00005_ooool2o`0000Gooooo0_l0000Oooooo`;o00009_ooool2o`0003Co
oooo0_l0000Mooooo`;o00000oooool2o`0000Oooooo0_l000000ooooooo0000o`00000Gooooo`00
:Oooool00ol0003oooooooooo`0Vooooo`Co00002Oooool2o`00023ooooo0_l0000;ooooo`;o0000
4?ooool2o`0000?ooooo0_l00006ooooo`;o00003_ooool2o`0000;ooooo0_l0000dooooo`Co0000
2Oooool2o`0004Kooooo0_l000000ooooooo0000o`00000Gooooo`00:Oooool00ol0003ooooooooo
o`0Mooooo`;o00002Oooool2o`000003ooooool0003o000000?ooooo1Ol00002ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?l0003ok^k^01Oooooo0_l00005ooooo`;o
00002Oooool5o`0000?ooooo00Cok^k^oc8b<_l0003o<S8b0_l000001_oooooo0000o`000?lb<S;o
0000oc8b<P;o00003_ooool2o`0001Oooooo00?oV9RHoa0@4?l000000_l00003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00009ooooo`;o
00001?ooool2o`0000Wooooo0ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Oooooo0_l000001Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool002Wooooo
00Co0000oooooooooooooooo0_l0000Jooooo`;o00000oooool2o`0000Oooooo0_l00005ooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?l0003o0000ogMgM`03ooooo`05ogMgMonHV9So0000
o`000?mgMgL05oooool2o`00013ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00_ooool2o`000004oiRHV?ooooooV9RHogMgM`Gooooo0_l0000Looooo`;o
00000oooool00ol@413o^[Zjooooo`02o`0000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL07oooool4o`0000Sooooo0_l00003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg02cooooo00WoMgMgoc8b<_oooooo
ooooogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000Y
ooooo`04o`000?ooooooooooooooo`;o00007Oooool4o`0000Kooooo0_l00006ooooo`03o`000?oo
oooooooo00;ooooo00Go410@ooooool0003o0000oa0@4003ooooo`05oa0@4?ooooooooooooooool@
4100:_ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@00Gooooo0_l0000Looooo`;o00001oooool01Ol0003ooooooooooooo
oooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`04oa0@4?ooooooooooooooo`;o
00007?ooool2o`0000Gooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@02gooooo0ol000001Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@4003ooooo`00:Oooool2o`00027ooooo0ol00007ooooo`;o00001_oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool3o`000003oooo
ool0003ooooo027ooooo0_l00007ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00?o0000ooooool00000
0_l00003ooooo`05o`000?ooooooooooooooool00000:oooool00onYZJWo410@ooooo`02ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo0_l00003
ooooo`?o00007Oooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool00000
0oooool01?l0003oooooooooooooool3o`0000Cooooo0_l0000Tooooo`03ogMgMolb<S;o000000;o
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00Oooool002Wo
oooo00?o0000ooooooooool06?ooool2o`0001Sooooo00?o0000ooooooooool00_ooool3o`000004
ooooool0003oooooooooo`Co000000?oooooo`000?ooool08Oooool2o`0000Sooooo00?oMgMgofIV
I_ooool00_ooool00ol0003oooooo`000002o`0000?ooooo00Go0000ooooooooooooooooo`00000P
ooooo`;o00001Oooool5o`000005okZj^_ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool01_ooool3o`0001gooooo00GogMgMoeEEEOoooooo
0000ooooo`04o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`?o00001?ooool2o`00
01Cooooo0_l0000;ooooo`06o`000?lQ8B7o0000oc8b<_o<c<cooooo0_l00003ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`01ooooo`00:Oooool00ol0003ooooooooo
o`02ooooo`;o000000?oooooo`000?l000004Oooool2o`0001Sooooo00?o0000ooooooooool00_oo
ool01Ol@413o0000o`000?oooooo410@00;ooooo0_l00003ooooo`03oa0@4?oooooooooo02_ooooo
00Go0000oooooooooooooooooa0@4003ooooo`04oa0@4?ooooooooooooooo`;o00000_ooool00ol@
413oooooooooo`0Nooooo`;o00001Oooool4o`000003okZj^_lQ8B7ooooo00;ooooo00Go410@oooo
oooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100:Oooool01?mgMgOoc<c<o`00
0?ooool4o`0000?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01[o
oooo0_l0000;ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`05oa0@4?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`01ooooo`00:Oooool00ol0003oooooooooo`02ooooo`;o
000000?oooooo`000?l00000:oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg02Wooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool2o`000003oooooonHV9SoMgMg02Sooooo
00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg02Wooooo00?ok^k^o`000?l000001?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o00002Oooool2o`0001Oooooo
00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`00:Oooool00ol0003oooooooooo`0Uooooo`;o00002Oooool00omEEEGo
IVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^02Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo0_l0000Oooooo`05ojVYZOl@413o0000oa0@
4?nYZJT00oooool01Oo^k^ko0000o`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0Zooooo`;o00000oooool2o`000004oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o00001?ooool2o`0000?ooooo0_l0000Gooooo`Co00000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool2o`00
01Sooooo0_l0000<ooooo`;o0000;Oooool2o`0003?ooooo0_l0000Xooooo`;o0000>Oooool2o`00
00Sooooo0_l0000=ooooo`;o00000oooool2o`0002kooooo000Yooooo`03o`000?oooooooooo01Oo
oooo0_l0000Dooooo`;o00001?ooool3o`0001kooooo0_l00006ooooo`;o0000;_ooool4o`0003Ko
oooo0_l0000Sooooo`;o00002oooool2o`0001_ooooo0_l0000Uooooo`00:Oooool00ol0003ooooo
ooooo`0Yooooo`;o00000_ooool2o`0000Cooooo0ol0000Aooooo`;o00004oooool2o`0000cooooo
0_l0000Hooooo`;o00001_ooool4o`0001Sooooo0_l0000Looooo`;o00008oooool2o`0002Sooooo
0_l00009ooooo`;o00006_ooool002Wooooo0ol0000Xooooo`?o00007?ooool2o`0000Sooooo0_l0
000Gooooo`;o00006?ooool2o`0000gooooo1Ol0000@ooooo`;o0000Coooool2o`0002Gooooo1?l0
000Hooooo`00:Oooool3o`0002Sooooo0_l0000Iooooo`;o00003?ooool2o`0003[ooooo0_l00004
ooooo`Go00008oooool2o`0003cooooo0_l0000Wooooo`;o00006?ooool0027oooooool00014o`00
00Cooooo000Yooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_l00008ooooo`03
o`000?oooooooooo00;o00001oooool00ol0003oooooooooo`06ooooo`;o000000?oooooo`000?oo
ool01_ooool2o`0000;ooooo00Co0000ooooool0003o00002Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04oooo
o`;o00001?ooool2o`0000Cooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00003oooo
o`;o00001oooool2o`0000;ooooo0_l00007ooooo`;o00000_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00;ooooo0_l00003ooooo`?o00002oooool00ol0003oooooooooo`04oooo
o`;o00000oooool2o`0000?ooooo0_l00006ooooo`03o`000?oooooooooo00;ooooo0_l00005oooo
o`04o`000?ooooooooooooooo`;o00001_ooool00ol0003oooooooooo`04ooooo`;o00001?ooool0
0ol0003oooooooooo`02o`0000Oooooo00?o0000ooooooooool01oooool3o`000003ooooool0003o
000000Sooooo00?o0000ooooooooool02_ooool002Wooooo00?o0000ooooooooool06Oooool2o`00
013ooooo0_l00008ooooo`?o00000_ooool2o`0000?ooooo0_l0000aooooo`;o00001?ooool3o`00
00?ooooo0_l0000:ooooo`;o00000oooool2o`0000Oooooo0_l00002ooooo`;o00000_ooool2o`00
00?ooooo0_l0000>ooooo`03o`000?oooooooooo00Kooooo0_l0000Aooooo`;o00001_ooool2o`00
00?ooooo0_l00004ooooo`;o00003?ooool00ol0003oooooooooo`0Oooooo`;o00002oooool2o`00
00cooooo00?o0000ooooooooool02_ooool002Wooooo0_l00004ooooo`;o0000<?ooool2o`0000?o
oooo0ol00002ooooo`;o0000:_ooool2o`0000cooooo0_l0000Uooooo`;o00007?ooool2o`0000Wo
oooo0_l00006ooooo`;o00004Oooool2o`000003ooooool0003o000001_ooooo0_l00003ooooo`;o
00002Oooool2o`0002Kooooo000Yooooo`;o00001?ooool4o`0001cooooo0_l0000Fooooo`;o0000
;_ooool2o`0000Kooooo0_l00007ooooo`;o00002oooool3o`0001Cooooo0ol0000Nooooo`;o0000
1_ooool2o`0001Kooooo0_l00004ooooo`;o00005_ooool3o`000005ooooool0003o0000o`000?oo
ool01?l00006ooooo`?o00005?ooool4o`00013ooooo000Yooooo`;o00001_ooool2o`0001cooooo
0_l0001>ooooo`;o00001oooool2o`0000_ooooo0ol0000Cooooo`Co00001oooool2o`0000Wooooo
0_l0000:ooooo`;o00002Oooool2o`00017ooooo1?l0000Jooooo`Go000000?oooooo`000?l00000
0_ooool3o`0000Oooooo0ol00008ooooo`;o00002_ooool4o`00013ooooo000Yooooo`03o`000?oo
oooooooo04cooooo0_l0000;ooooo`?o00004_ooool2o`0002gooooo1?l00009ooooo`;o00002Ooo
ool3o`0001?ooooo0ol0000Aooooo`;o00000_ooool2o`0001Sooooo1?l00005ooooo`Ko00003_oo
ool5o`0001gooooo000Yooooo`03o`000?oooooooooo03[ooooo0_l0000@ooooo`;o00001Oooool2
o`0000Cooooo0ol0000Booooo`;o00003Oooool2o`0000Cooooo0_l00008ooooo`;o00003_ooool3
o`0001Kooooo0_l000000ooooooo0000o`00000@ooooo`;o00005_ooool2o`0001Oooooo0_l00008
ooooo`;o00000_ooool2o`0000?ooooo0_l00009ooooo`;o000000?oooooo`000?l000002Oooool2
o`0001;ooooo000Yooooo`03o`000?oooooooooo03[ooooo0_l0000Gooooo`;o0000:?ooool2o`00
00Cooooo0_l00008ooooo`;o00003oooool2o`0000?ooooo0_l0000Dooooo`;o0000=?ooool2o`00
00_ooooo0_l0000Aooooo`;o00001?ooool2o`00017ooooo0_l000000ooooooo0000o`00000?oooo
o`00:Oooool00ol0003oooooooooo`13ooooo`;o0000G_ooool2o`0000gooooo0_l0000kooooo`;o
00001_ooool2o`0001cooooo0_l0000Dooooo`;o00003oooool002Wooooo0_l0000>ooooo`;o0000
2oooool2o`00013ooooo0_l0000Eooooo`;o0000Boooool2o`00023ooooo0_l00004ooooo`;o0000
5_ooool4o`0000Cooooo0_l0000>ooooo`;o00003Oooool2o`000003ooooool0003o000000Sooooo
0_l0000fooooo`00:Oooool2o`0000kooooo0_l00006ooooo`;o00000oooool2o`0000_ooooo0_l0
0003ooooo`;o00009_ooool2o`0000?ooooo0_l00008ooooo`?o000000?oooooo`000?l000001Ooo
ool2o`0000oooooo0_l000000ooooooo0000o`00000<ooooo`;o00002?ooool2o`0001cooooo0_l0
0004ooooo`;o00004?ooool6o`0000;ooooo0_l0000>ooooo`;o00004?ooool2o`0000Sooooo0_l0
000Iooooo`;o00003?ooool2o`0000gooooo000Yooooo`;o00002Oooool2o`0000_ooooo0_l0000@
ooooo`;o00009?ooool2o`0000Gooooo0_l00003ooooo`;o00002?ooool3o`000003ooooool0003o
000000Gooooo0_l0000;ooooo`;o00000_ooool5o`0000_ooooo0_l00006ooooo`;o000000?ooooo
o`000?l000008_ooool2o`0001Cooooo0_l00019ooooo`;o00001Oooool2o`0000Gooooo0_l0000=
ooooo`00:Oooool00ol0003oooooooooo`08ooooo`;o00000oooool2o`0000Gooooo0_l0000Xoooo
o`;o00003Oooool2o`0002cooooo0_l00004ooooo`;o00003?ooool2o`0000Kooooo0_l000000ooo
oooo0000o`00000Aooooo`;o00003?ooool2o`00067ooooo0_l00006ooooo`;o00005?ooool002Wo
oooo00?o0000ooooooooool03Oooool2o`0000Gooooo0_l0000Xooooo`;o0000=Oooool2o`0002?o
oooo0_l0000;ooooo`;o00001?ooool2o`0000cooooo0_l00003ooooo`;o00003?ooool2o`0004ko
oooo0_l00009ooooo`;o00004Oooool002Wooooo0_l0000Uooooo`;o00003?ooool2o`00013ooooo
0_l0000Booooo`;o00001Oooool2o`0001Cooooo0_l0000>ooooo`;o00008?ooool2o`0000Gooooo
0_l0000@ooooo`;o00003?ooool2o`0000cooooo0_l0000Fooooo`;o00009?ooool2o`0000gooooo
0_l0000Aooooo`00:Oooool00ol0003oooooooooo`0?ooooo`;o00004oooool2o`0000cooooo0_l0
0007ooooo`;o00001oooool2o`0000Sooooo0_l00008ooooo`;o00001Oooool2o`0000Kooooo0ol0
000@ooooo`;o00002Oooool2o`000003ooooool0003o000002Cooooo0ol0000Eooooo`;o00001_oo
ool2o`0000cooooo0_l0000Aooooo`;o00000oooool3o`0001Kooooo0_l0000;ooooo`;o00008?oo
ool002Wooooo00Co0000ooooool0003o00002oooool2o`000003ooooool0003o0000017ooooo0_l0
000>ooooo`;o00000_ooool2o`0000?ooooo0_l0000Aooooo`;o00001oooool2o`0000kooooo0ol0
000<ooooo`;o00000_ooool2o`0000cooooo0_l0000Uooooo`;o00005Oooool2o`0000Kooooo0_l0
000=ooooo`;o00004?ooool2o`0000Cooooo0_l00007ooooo`;o00003Oooool2o`0001Sooooo0_l0
000Cooooo`00:Oooool01?l0003oooooo`000?l0000;ooooo`;o00002_ooool2o`0000Sooooo0_l0
000:ooooo`;o00000_ooool2o`0000;ooooo0_l0000Cooooo`;o00002_ooool2o`0001gooooo0_l0
0007ooooo`;o0000G?ooool2o`0001_ooooo0_l00002ooooo`;o00009oooool2o`0001?ooooo000Y
ooooo`03o`000?oooooooooo01Sooooo0_l0000Dooooo`;o00006oooool2o`0003;ooooo0_l00019
ooooo`;o00001?ooool2o`0000[ooooo0_l0000Looooo`;o0000@?ooool002Wooooo0_l0002]oooo
o`;o00002?ooool2o`0000Cooooo0_l00003ooooo`;o00001oooool2o`0000Cooooo0_l0000:oooo
o`;o0000:oooool2o`00037ooooo000Yooooo`03o`000?oooooooooo00Cooooo0_l000001?oooooo
0000o`000?ooool2o`0004Kooooo0_l0000Eooooo`;o0000@Oooool2o`0000Sooooo0_l00004oooo
o`;o00000oooool2o`0003Cooooo0_l0000@ooooo`;o0000<Oooool000Kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo00Cooooo0_l000001?oooooo0000o`000?ooool2o`0003[ooooo0_l0
000:ooooo`;o00005Oooool2o`000004ooooool0003o0000ooooo`;o0000H_ooool2o`0001gooooo
0_l00003ooooo`;o00002?ooool2o`0002cooooo0_l0000;ooooo`001_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo00Cooooo0_l00010ooooo`;o00004oooool2o`0000oo
oooo0_l000000ooooooo0000o`00000Aooooo`;o0000>Oooool2o`0001Cooooo0_l0000Mooooo`;o
00003Oooool2o`0002cooooo0_l0000;ooooo`001_ooool01Ol@413ooooooooooooooooo410@00co
oooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_o
oooo0_l00010ooooo`;o00003?ooool2o`0001Cooooo0_l0000?ooooo`;o0000>Oooool2o`0001Oo
oooo0_l00002ooooo`;o00004?ooool2o`0001cooooo0_l0000`ooooo`001_ooool01Ol0003ooooo
oooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o
00000_ooool2o`0000Oooooo0_l0000Booooo`;o0000;?ooool2o`0001;ooooo0_l0000>ooooo`;o
0000G_ooool2o`0000?ooooo0_l00002ooooo`;o00002oooool2o`0000?ooooo0_l0000Looooo`;o
0000<?ooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00;ooooo0_l0000Aoooo
o`;o00002?ooool2o`00043ooooo0_l0001^ooooo`;o00005?ooool2o`0005?ooooo0006ooooo`05
oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02Oooool3o`0000Cooooo0_l00003ooooo`;o00004?ooool2o`00
06Oooooo0_l0000:ooooo`;o0000B?ooool2o`0004Cooooo0_l0000>ooooo`001_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02Oooool3o`0000Cooooo0_l0000Eooooo`;o00008?ooool2
o`0004Gooooo0_l0000:ooooo`;o0000AOooool2o`000003ooooool0003o000000Gooooo0_l0000m
ooooo`;o00003_ooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool0>?ooool2o`0000Kooooo0ol0
0005ooooo`?o0000>Oooool2o`0005Wooooo0_l00002ooooo`;o00002?ooool2o`0000;ooooo0_l0
0003ooooo`;o0000;oooool2o`0001?ooooo000Yooooo`;o00004Oooool2o`0000gooooo0_l00004
ooooo`;o00004Oooool2o`0000Kooooo0ol00005ooooo`;o0000>_ooool2o`0002cooooo0_l0000D
ooooo`;o00005Oooool2o`0000Sooooo0_l00006ooooo`;o00000oooool2o`00027ooooo0_l0000<
ooooo`;o00004oooool002Wooooo00?o0000ooooooooool03oooool3o`0000gooooo0_l00004oooo
o`;o00005_ooool2o`0000Oooooo0_l0000mooooo`?o0000:_ooool2o`0000Kooooo0_l0000<oooo
o`?o00007_ooool2o`0002kooooo0_l0000Qooooo`00:Oooool00ol0003oooooooooo`0?ooooo`;o
0000;?ooool2o`0000Oooooo0_l0000Fooooo`;o00001?ooool2o`0000kooooo0_l0000:ooooo`;o
00000oooool3o`00033ooooo1?l0000=ooooo`;o00005_ooool2o`0000;ooooo0_l0000/ooooo`;o
00009oooool002Wooooo00Co0000oooooooooooooooo0_l0000[ooooo`Co0000;?ooool2o`0000?o
oooo0ol0000>ooooo`;o00002_ooool2o`00013ooooo1?l00003ooooo`;o00003Oooool2o`000003
ooooool0003o000000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000008Oooool2o`0000Co
oooo0_l00002ooooo`;o0000;?ooool2o`0000;ooooo0_l0000Sooooo`00:Oooool01?l0003ooooo
ooooooooool2o`0001Wooooo0_l00005ooooo`;o00001Oooool2o`0000;ooooo1?l0000Cooooo`;o
00003oooool2o`0000Kooooo0_l000000ooooooo0000o`000002o`0000_ooooo0_l0000Eooooo`;o
00002Oooool4o`0000?ooooo0_l00004ooooo`;o00001oooool2o`000004ooooool0003o0000oooo
o`Go00000_ooool2o`0000kooooo0_l0000Dooooo`;o0000<?ooool2o`0000Sooooo0_l0000Soooo
o`00:Oooool2o`0001?ooooo0ol00005ooooo`Co00001Oooool2o`0000Gooooo0_l0000Iooooo`;o
00003oooool2o`0000Kooooo0_l000000ooooooo0000o`000003ooooo`;o00002?ooool2o`0001Go
oooo0_l0000<ooooo`Co00001_ooool2o`000003ooooool0003o000000[ooooo0_l000000ooooooo
0000o`00000Booooo`;o00004?ooool2o`0002;ooooo0_l0000@ooooo`;o00007_ooool2o`0000go
oooo000Yooooo`03o`000?oooooooooo00Wooooo0_l00007ooooo`Co00001?ooool3o`0000?ooooo
0_l0000Pooooo`;o000000?oooooo`000?l000000oooool2o`0000[ooooo0_l00005ooooo`;o0000
1oooool2o`0000[ooooo0_l0000Qooooo`Co00001?ooool2o`0000?ooooo0ol0000booooo`Co0000
2Oooool2o`0000[ooooo0_l00009ooooo`;o00006Oooool2o`0001Gooooo0_l0000=ooooo`00:Ooo
ool00ol0003oooooooooo`09ooooo`;o00000oooool2o`0000Cooooo0_l00005ooooo`;o00000ooo
ool2o`00023ooooo0_l00004ooooo`Co00001Oooool2o`0000?ooooo0_l00004ooooo`?o00003?oo
ool2o`0000Gooooo0_l0000Yooooo`;o00001?ooool2o`0002kooooo0_l00004ooooo`;o00002Ooo
ool2o`0000[ooooo0_l0000Tooooo`;o00001Oooool2o`0000oooooo0_l0000<ooooo`00:Oooool0
0ol0003oooooooooo`0>ooooo`;o00003?ooool2o`0000oooooo0_l0000Iooooo`;o00001_ooool3
o`0000Wooooo0_l000001?oooooo0000o`000?l00009ooooo`;o0000>Oooool2o`0000;ooooo0_l0
0007ooooo`;o00007_ooool2o`0003oooooo0_l00005ooooo`Co00003oooool2o`0000cooooo000Y
ooooo`03o`000?oooooooooo01cooooo0_l0000?ooooo`;o00008Oooool2o`0000gooooo0ol00003
ooooo`;o00001Oooool2o`0003Sooooo0_l00002ooooo`;o00001oooool2o`00027ooooo0_l0000l
ooooo`;o00001Oooool2o`0001oooooo000Yooooo`;o0000DOooool2o`0001?ooooo0_l00005oooo
o`;o0000J?ooool2o`0000kooooo0_l0001Dooooo`00:Oooool00ol0003oooooooooo`3Vooooo`;o
0000E?ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003ooooo
ockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
1_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413o
oooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03oooo
o`?o0000oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qoooo
ooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooo
oooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0
0006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool001oo
oooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oo
oooooooo00Gooooo0ol0003oooooocgooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001oooooo00?oEEEEofIVI_l00000oooo
oom7ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .24063 Mdot
.02762 .25277 Mdot
.02952 .27552 Mdot
.03143 .31356 Mdot
.03333 .3369 Mdot
.03524 .2631 Mdot
.03714 .31019 Mdot
.03905 .44952 Mdot
.04095 .43494 Mdot
.04286 .25891 Mdot
.04476 .25848 Mdot
.04667 .43807 Mdot
.04857 .28929 Mdot
.05048 .25821 Mdot
.05238 .40931 Mdot
.05429 .29515 Mdot
.05619 .33977 Mdot
.0581 .29096 Mdot
.06 .29114 Mdot
.0619 .37963 Mdot
.06381 .33054 Mdot
.06571 .29532 Mdot
.06762 .33345 Mdot
.06952 .30803 Mdot
.07143 .40339 Mdot
.07333 .36722 Mdot
.07524 .28433 Mdot
.07714 .3058 Mdot
.07905 .39386 Mdot
.08095 .27394 Mdot
.08286 .36495 Mdot
.08476 .43958 Mdot
.08667 .44147 Mdot
.08857 .30301 Mdot
.09048 .31378 Mdot
.09238 .39943 Mdot
.09429 .42987 Mdot
.09619 .30165 Mdot
.0981 .4153 Mdot
.1 .44451 Mdot
.1019 .42478 Mdot
.10381 .31392 Mdot
.10571 .27682 Mdot
.10762 .23869 Mdot
.10952 .24332 Mdot
.11143 .35194 Mdot
.11333 .2567 Mdot
.11524 .43917 Mdot
.11714 .37471 Mdot
.11905 .40636 Mdot
.12095 .43855 Mdot
.12286 .4154 Mdot
.12476 .22885 Mdot
.12667 .27864 Mdot
.12857 .30701 Mdot
.13048 .43673 Mdot
.13238 .4471 Mdot
.13429 .35081 Mdot
.13619 .43505 Mdot
.1381 .24614 Mdot
.14 .35885 Mdot
.1419 .38507 Mdot
.14381 .41909 Mdot
.14571 .33513 Mdot
.14762 .42416 Mdot
.14952 .44068 Mdot
.15143 .25716 Mdot
.15333 .2809 Mdot
.15524 .28519 Mdot
.15714 .32819 Mdot
.15905 .36678 Mdot
.16095 .2994 Mdot
.16286 .25544 Mdot
.16476 .26552 Mdot
.16667 .41913 Mdot
.16857 .29495 Mdot
.17048 .22851 Mdot
.17238 .36658 Mdot
.17429 .41058 Mdot
.17619 .35779 Mdot
.1781 .38257 Mdot
.18 .28032 Mdot
.1819 .31116 Mdot
.18381 .3192 Mdot
.18571 .44745 Mdot
.18762 .31573 Mdot
.18952 .33833 Mdot
.19143 .35723 Mdot
.19333 .36282 Mdot
.19524 .27615 Mdot
.19714 .39628 Mdot
.19905 .28106 Mdot
.20095 .3386 Mdot
.20286 .35046 Mdot
.20476 .33766 Mdot
.20667 .30967 Mdot
.20857 .2585 Mdot
.21048 .43556 Mdot
.21238 .22762 Mdot
.21429 .37125 Mdot
.21619 .24656 Mdot
.2181 .37155 Mdot
.22 .43002 Mdot
.2219 .23804 Mdot
.22381 .35612 Mdot
.22571 .30035 Mdot
.22762 .35558 Mdot
.22952 .29631 Mdot
.23143 .33869 Mdot
.23333 .33841 Mdot
.23524 .26142 Mdot
.23714 .32514 Mdot
.23905 .43855 Mdot
.24095 .38131 Mdot
.24286 .22312 Mdot
.24476 .26597 Mdot
.24667 .36423 Mdot
.24857 .44578 Mdot
.25048 .4439 Mdot
.25238 .42949 Mdot
.25429 .29723 Mdot
.25619 .40343 Mdot
.2581 .35129 Mdot
.26 .39073 Mdot
.2619 .33364 Mdot
.26381 .30182 Mdot
.26571 .391 Mdot
.26762 .32349 Mdot
.26952 .28373 Mdot
.27143 .30107 Mdot
.27333 .31375 Mdot
.27524 .25775 Mdot
.27714 .43105 Mdot
.27905 .27557 Mdot
.28095 .27057 Mdot
.28286 .39981 Mdot
.28476 .422 Mdot
.28667 .39511 Mdot
.28857 .25564 Mdot
.29048 .435 Mdot
.29238 .41473 Mdot
.29429 .33561 Mdot
.29619 .33698 Mdot
.2981 .28295 Mdot
.3 .34211 Mdot
.3019 .37827 Mdot
.30381 .44692 Mdot
.30571 .23619 Mdot
.30762 .33627 Mdot
.30952 .35815 Mdot
.31143 .4277 Mdot
.31333 .37428 Mdot
.31524 .26449 Mdot
.31714 .30168 Mdot
.31905 .30451 Mdot
.32095 .24063 Mdot
.32286 .42319 Mdot
.32476 .41783 Mdot
.32667 .44387 Mdot
.32857 .43037 Mdot
.33048 .42291 Mdot
.33238 .37231 Mdot
.33429 .40653 Mdot
.33619 .44649 Mdot
.3381 .39662 Mdot
.34 .25558 Mdot
.3419 .25718 Mdot
.34381 .446 Mdot
.34571 .35683 Mdot
.34762 .28493 Mdot
.34952 .41684 Mdot
.35143 .4079 Mdot
.35333 .32872 Mdot
.35524 .29055 Mdot
.35714 .34911 Mdot
.35905 .33204 Mdot
.36095 .43414 Mdot
.36286 .31163 Mdot
.36476 .24061 Mdot
.36667 .27806 Mdot
.36857 .40416 Mdot
.37048 .41115 Mdot
.37238 .44001 Mdot
.37429 .28612 Mdot
.37619 .4241 Mdot
.3781 .31482 Mdot
.38 .43108 Mdot
.3819 .31367 Mdot
.38381 .44226 Mdot
.38571 .44499 Mdot
.38762 .28208 Mdot
.38952 .40883 Mdot
.39143 .37609 Mdot
.39333 .33318 Mdot
.39524 .37596 Mdot
.39714 .44779 Mdot
.39905 .43081 Mdot
.40095 .43134 Mdot
.40286 .35035 Mdot
.40476 .28851 Mdot
.40667 .35613 Mdot
.40857 .27141 Mdot
.41048 .27216 Mdot
.41238 .29573 Mdot
.41429 .34556 Mdot
.41619 .276 Mdot
.4181 .26018 Mdot
.42 .3292 Mdot
.4219 .25314 Mdot
.42381 .33496 Mdot
.42571 .30954 Mdot
.42762 .25541 Mdot
.42952 .27448 Mdot
.43143 .36643 Mdot
.43333 .35853 Mdot
.43524 .27629 Mdot
.43714 .26125 Mdot
.43905 .36557 Mdot
.44095 .44399 Mdot
.44286 .30271 Mdot
.44476 .23957 Mdot
.44667 .44746 Mdot
.44857 .36291 Mdot
.45048 .43473 Mdot
.45238 .34911 Mdot
.45429 .39103 Mdot
.45619 .2685 Mdot
.4581 .33092 Mdot
.46 .23955 Mdot
.4619 .33431 Mdot
.46381 .41022 Mdot
.46571 .41017 Mdot
.46762 .30811 Mdot
.46952 .3178 Mdot
.47143 .25291 Mdot
.47333 .36457 Mdot
.47524 .26873 Mdot
.47714 .40066 Mdot
.47905 .29335 Mdot
.48095 .2383 Mdot
.48286 .33022 Mdot
.48476 .25293 Mdot
.48667 .37892 Mdot
.48857 .28255 Mdot
.49048 .35971 Mdot
.49238 .36671 Mdot
.49429 .44217 Mdot
.49619 .33634 Mdot
.4981 .42599 Mdot
.5 .34003 Mdot
.5019 .36768 Mdot
.50381 .41781 Mdot
.50571 .42774 Mdot
.50762 .26639 Mdot
.50952 .3344 Mdot
.51143 .42803 Mdot
.51333 .36992 Mdot
.51524 .29147 Mdot
.51714 .32259 Mdot
.51905 .29749 Mdot
.52095 .44325 Mdot
.52286 .43734 Mdot
.52476 .37205 Mdot
.52667 .26791 Mdot
.52857 .39212 Mdot
.53048 .28675 Mdot
.53238 .36984 Mdot
.53429 .24259 Mdot
.53619 .26296 Mdot
.5381 .24675 Mdot
.54 .40486 Mdot
.5419 .36957 Mdot
.54381 .39301 Mdot
.54571 .31009 Mdot
.54762 .26516 Mdot
.54952 .36566 Mdot
.55143 .42108 Mdot
.55333 .29096 Mdot
.55524 .30591 Mdot
.55714 .43884 Mdot
.55905 .25377 Mdot
.56095 .24477 Mdot
.56286 .40509 Mdot
.56476 .27956 Mdot
.56667 .26151 Mdot
.56857 .43039 Mdot
.57048 .43431 Mdot
.57238 .29483 Mdot
.57429 .30773 Mdot
.57619 .34955 Mdot
.5781 .36667 Mdot
.58 .35775 Mdot
.5819 .38137 Mdot
.58381 .30789 Mdot
.58571 .43437 Mdot
.58762 .41805 Mdot
.58952 .43326 Mdot
.59143 .31931 Mdot
.59333 .43182 Mdot
.59524 .36622 Mdot
.59714 .35694 Mdot
.59905 .4114 Mdot
.60095 .24471 Mdot
.60286 .37023 Mdot
.60476 .31297 Mdot
.60667 .25287 Mdot
.60857 .44123 Mdot
.61048 .41626 Mdot
.61238 .25582 Mdot
.61429 .43773 Mdot
.61619 .37054 Mdot
.6181 .26732 Mdot
.62 .28682 Mdot
.6219 .34035 Mdot
.62381 .3042 Mdot
.62571 .42739 Mdot
.62762 .27186 Mdot
.62952 .23966 Mdot
.63143 .3053 Mdot
.63333 .42279 Mdot
.63524 .27842 Mdot
.63714 .43696 Mdot
.63905 .38363 Mdot
.64095 .35271 Mdot
.64286 .29911 Mdot
.64476 .28569 Mdot
.64667 .3261 Mdot
.64857 .4216 Mdot
.65048 .32124 Mdot
.65238 .26557 Mdot
.65429 .31618 Mdot
.65619 .35474 Mdot
.6581 .44859 Mdot
.66 .42767 Mdot
.6619 .33757 Mdot
.66381 .28049 Mdot
.66571 .29775 Mdot
.66762 .29331 Mdot
.66952 .24108 Mdot
.67143 .2715 Mdot
.67333 .25602 Mdot
.67524 .37241 Mdot
.67714 .34548 Mdot
.67905 .24406 Mdot
.68095 .36965 Mdot
.68286 .2885 Mdot
.68476 .336 Mdot
.68667 .43758 Mdot
.68857 .28364 Mdot
.69048 .39537 Mdot
.69238 .30686 Mdot
.69429 .33958 Mdot
.69619 .36395 Mdot
.6981 .34084 Mdot
.7 .4417 Mdot
.7019 .42956 Mdot
.70381 .39909 Mdot
.70571 .37279 Mdot
.70762 .34595 Mdot
.70952 .40444 Mdot
.71143 .36789 Mdot
.71333 .44068 Mdot
.71524 .36877 Mdot
.71714 .36109 Mdot
.71905 .4294 Mdot
.72095 .43569 Mdot
.72286 .43549 Mdot
.72476 .28542 Mdot
.72667 .36621 Mdot
.72857 .41134 Mdot
.73048 .44555 Mdot
.73238 .28382 Mdot
.73429 .37184 Mdot
.73619 .36577 Mdot
.7381 .26162 Mdot
.74 .2449 Mdot
.7419 .43524 Mdot
.74381 .23883 Mdot
.74571 .43138 Mdot
.74762 .4257 Mdot
.74952 .33323 Mdot
.75143 .42612 Mdot
.75333 .31753 Mdot
.75524 .4086 Mdot
.75714 .22396 Mdot
.75905 .43002 Mdot
.76095 .24266 Mdot
.76286 .29583 Mdot
.76476 .39771 Mdot
.76667 .36829 Mdot
.76857 .31672 Mdot
.77048 .44291 Mdot
.77238 .3301 Mdot
.77429 .26659 Mdot
.77619 .26138 Mdot
.7781 .36654 Mdot
.78 .27387 Mdot
.7819 .43996 Mdot
.78381 .33312 Mdot
.78571 .36953 Mdot
.78762 .4398 Mdot
.78952 .32955 Mdot
.79143 .23577 Mdot
.79333 .33665 Mdot
.79524 .32759 Mdot
.79714 .32307 Mdot
.79905 .31005 Mdot
.80095 .4466 Mdot
.80286 .43763 Mdot
.80476 .28212 Mdot
.80667 .33642 Mdot
.80857 .25296 Mdot
.81048 .30611 Mdot
.81238 .42545 Mdot
.81429 .34363 Mdot
.81619 .39121 Mdot
.8181 .32968 Mdot
.82 .26937 Mdot
.8219 .28693 Mdot
.82381 .34246 Mdot
.82571 .30625 Mdot
.82762 .26147 Mdot
.82952 .33025 Mdot
.83143 .41557 Mdot
.83333 .43641 Mdot
.83524 .27937 Mdot
.83714 .31218 Mdot
.83905 .35488 Mdot
.84095 .24385 Mdot
.84286 .365 Mdot
.84476 .28463 Mdot
.84667 .4055 Mdot
.84857 .31743 Mdot
.85048 .24403 Mdot
.85238 .21819 Mdot
.85429 .2389 Mdot
.85619 .32954 Mdot
.8581 .42824 Mdot
.86 .40796 Mdot
.8619 .26587 Mdot
.86381 .31634 Mdot
.86571 .23863 Mdot
.86762 .33476 Mdot
.86952 .26823 Mdot
.87143 .33887 Mdot
.87333 .38758 Mdot
.87524 .36348 Mdot
.87714 .28506 Mdot
.87905 .31484 Mdot
.88095 .28172 Mdot
.88286 .32715 Mdot
.88476 .33621 Mdot
.88667 .27785 Mdot
.88857 .28068 Mdot
.89048 .44888 Mdot
.89238 .2697 Mdot
.89429 .4057 Mdot
.89619 .24661 Mdot
.8981 .23933 Mdot
.9 .39095 Mdot
.9019 .37903 Mdot
.90381 .33829 Mdot
.90571 .34525 Mdot
.90762 .26112 Mdot
.90952 .44881 Mdot
.91143 .43156 Mdot
.91333 .26748 Mdot
.91524 .43096 Mdot
.91714 .36737 Mdot
.91905 .33054 Mdot
.92095 .39324 Mdot
.92286 .2437 Mdot
.92476 .30065 Mdot
.92667 .36401 Mdot
.92857 .31253 Mdot
.93048 .40448 Mdot
.93238 .25717 Mdot
.93429 .28691 Mdot
.93619 .26762 Mdot
.9381 .36115 Mdot
.94 .29384 Mdot
.9419 .28475 Mdot
.94381 .28442 Mdot
.94571 .28551 Mdot
.94762 .2681 Mdot
.94952 .36909 Mdot
.95143 .44053 Mdot
.95333 .32973 Mdot
.95524 .24208 Mdot
.95714 .26712 Mdot
.95905 .32241 Mdot
.96095 .27736 Mdot
.96286 .21808 Mdot
.96476 .27281 Mdot
.96667 .24612 Mdot
.96857 .43206 Mdot
.97048 .39517 Mdot
.97238 .28792 Mdot
.97429 .3989 Mdot
.97619 .43935 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooo`Wooooo0_l0000Q
ooooo`;o00004?ooool002Wooooo00?o0000ooooooooool0ooooool8ooooo`;o00008Oooool2o`00
013ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`13ooooo`;o0000Xoooool2
o`0005;ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0>Ooo
ool2o`0000Sooooo0_l0002Sooooo`;o0000D_ooool000Co00000_ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo01gooooo0_l0000<ooooo`;o00003?ooool2o`000?oooooo0_ooool000Kooooo00Go0000
ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?oo
ool3o`0001gooooo0_l0000<ooooo`;o0000ooooool@ooooo`001_ooool01Ol0003ooooooooooooo
oooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool0Eoooool2o`0009[ooooo0_l00017ooooo`001_ooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01Oooooo0_l0000Sooooo`;o00006Oooool2o`0002_ooooo0_l00003ooooo`;o0000
1?ooool2o`0002kooooo0_l0000Sooooo`;o00003Oooool2o`0001;ooooo0_l00002ooooo`;o0000
2?ooool2o`0002Gooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zj
oooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool2o`0001Sooooo0ol0000Rooooo`;o
00007_ooool2o`0000cooooo0_l0000Hooooo`;o00000oooool2o`0000Cooooo0_l0000?ooooo`;o
00007Oooool2o`0000_ooooo0_l0000Fooooo`;o00000oooool2o`0001cooooo0_l00002ooooo`;o
00002?ooool2o`00017ooooo0_l0000Booooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`0001Wooooo0_l00007oooo
o`;o00005oooool2o`00023ooooo0_l0000<ooooo`;o0000=?ooool2o`0000Oooooo0_l0000;oooo
o`;o00005?ooool2o`000003ooooool0003o000001;ooooo0_l00004ooooo`;o00006?ooool2o`00
0003ooooool0003o000000gooooo0_l00006ooooo`;o00002Oooool2o`000003ooooool0003o0000
00oooooo000Yooooo`;o00008_ooool2o`0001Oooooo0_l0001Vooooo`;o00001Oooool2o`0000_o
oooo0_l0000Gooooo`;o00004_ooool2o`0001kooooo0_l000000ooooooo0000o`00000=ooooo`;o
00001_ooool2o`0000cooooo0_l0000?ooooo`00:Oooool2o`000:?ooooo0_l0002Hooooo`00:Ooo
ool2o`0002[ooooo0_l0000Vooooo`;o00003oooool2o`0001Sooooo1?l0000<ooooo`;o00000_oo
ool2o`0001Kooooo0_l0000>ooooo`Co0000?Oooool2o`00047ooooo000Yooooo`03o`000?oooooo
oooo00;ooooo1Ol0000Booooo`;o00002_ooool2o`0000;ooooo0_l0000=ooooo`;o00004oooool2
o`0000;ooooo0_l0000?ooooo`?o00005oooool4o`0000cooooo0_l00002ooooo`;o00005_ooool2
o`0000kooooo1?l0000Aooooo`;o0000:_ooool2o`0002Gooooo0_l0000Jooooo`00:Oooool00ol0
003oooooooooo`02ooooo`Go00004_ooool2o`0000[ooooo0_l0000Aooooo`;o00001_ooool2o`00
00_ooooo0_l0000Dooooo`;o00005_ooool2o`0000Cooooo0_l0000Xooooo`;o00008?ooool2o`00
01?ooooo0_l0000:ooooo`;o00003oooool2o`0001Oooooo0_l00006ooooo`;o00006_ooool002Wo
oooo0_l000000ooooooo0000o`00000nooooo`;o00006?ooool2o`0001oooooo0_l00004ooooo`;o
00007_ooool2o`0000;ooooo0_l00004ooooo`;o0000=Oooool2o`0000[ooooo0_l0000?ooooo`;o
00005oooool2o`0002;ooooo000Yooooo`03o`000?oooooooooo00;o0000:?ooool2o`0001Oooooo
0_l0000Eooooo`;o0000??ooool2o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o0000
5?ooool2o`0000Wooooo0_l0000Vooooo`;o00006_ooool4o`0000cooooo0_l00006ooooo`;o0000
00Coooooo`000?l0003ooooo0_l0000Booooo`00:Oooool00ol0003oooooooooo`0Zooooo`;o0000
1?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`04onk^k_lb<S;o
0000oc8b<P;o00002_ooool2o`0001cooooo1Ol00003ooooo`03onk^k_lb<S;o000000;o00000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_l00004ooooo`;o00002Oooool2o`0000Cooooo
0_l0000:ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^o`000?l0003o<S8bonk^kP07ooooo`;o00001Oooool2o`0001[ooooo0_l00000
0ol@413oooooooooo`02o`000004oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP02o`0000cooooo1?l00006ooooo`;o00001?ooool2o`0000Kooooo0_l000000ooooooo0000
o`000003o`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool002Wooooo00?o0000ooooooooool03oooool2o`00027ooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`;o00007?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00?oMgMgoiRHV?ooool00ol0
0002ooooo`05ogMgMonHV9So0000o`000?mgMgL01Oooool2o`0000Cooooo0_l0000Kooooo`05oa0@
4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00CoMgMgoiRH
V?ooooooV9RH0_l0000=ooooo`;o00006oooool00ol0003oooooooooo`02ooooo`;o000000?ooooo
oiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00;o00005_ooool2o`0001;ooooo00?o
MgMgoc8b<_ooool00_l000001?nHV9SooooooiRHV?mgMgL3ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool002Wooooo0ol0000?ooooo`;o00001_ooool2o`0001Wooooo0ol00002ooooo`05oa0@
4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00[ooooo0_l0000Noooo
o`03oiRHV?lQ8B7ok^k^00Cooooo00Co410@oooooooooooooooo0ol000000ooooooo410@ooooo`04
o`0002_ooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100
0oooool2o`0002Oooooo1Ol00003ooooo`;o00000_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00?o410@ooooooooool0:oooool4o`0000?ooooo00Go410@oooooooooooooooooa0@4003oooo
o`03oa0@4?oooooooooo007ooooo000Yooooo`?o00005oooool2o`0000Cooooo0_l0000?ooooo`;o
00000_ooool3o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000002_ooool2o`0001_ooooo0_l00002ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Co0000
oooooooooooooooo0ol000000ooooooo0000ooooo`02ooooo`;o00009oooool2o`000003oooooonY
ZJWo410@00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000_ooool2o`0000Oooooo0_l0000Kooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001Oooool2o`0000oooooo0_l0
000Dooooo`03ogMgMolb<S;o000000;o00000oooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool00Oooool002Wooooo00?o0000ooooooooool07Oooool2o`0000Oooooo0_l0
0006ooooo`;o00000_ooool00ol0003oooooooooo`03o`0000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo00Gooooo0_l00007ooooo`;o00005Oooool2o`0000?ooooo
00?oMgMgo`000?l000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`00000@ooooo`;o00005_ooool2o`000003oa0@4?l0003o^[Zj00?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000Oooooo0_l0
0006ooooo`;o00003?ooool2o`0000Gooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000000?ooooo0_l00002ooooo`03o`000?oooooooooo00?ooooo0_l0000=ooooo`Co
00004Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000oooool002Wooooo00?o0000ooooooooool03Oooool2
o`0001Oooooo0ol00009ooooo`03o`000?oooooooooo00;o000000Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41001oooool2o`0000Oooooo0_l0000>ooooo`;o0000
1oooool2o`0000;ooooo0_l00002ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@013ooooo0_l0000;ooooo`;o00003?ooool00onj^[[o8B4Qooooo`02oooo
o`05oa0@4?ooooooooooooooool@41000oooool01Ol@413oooooo`000?l0003o410@00Gooooo0_l0
000<ooooo`;o00002_ooool4o`0000Kooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooo
oooooooo410@00?ooooo0_l00002ooooo`04oa0@4?oooooo0000o`0000Gooooo0_l00009ooooo`?o
00003oooool6o`0000Gooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooo
ooooool@41000oooool002Wooooo00?o0000ooooooooool01?ooool2o`0000Oooooo0_l0000Hoooo
o`;o00002Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg023ooooo0_l00007ooooo`;o000000?ooooooiRHV?l@41000ooo
ool01OmgMgOoV9RHo`000?l0003oMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`;o
00002Oooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`05ogMgMonHV9So0000o`000?mgMgL01Oooool2o`0000[ooooo0_l0000<ooooo`;o00002?oo
ool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01_mgMgOoV9RH
oooooonHV9SoMgMgooooo`;o00001Oooool2o`0000Wooooo0_l0000@ooooo`Ko00001Oooool01Omg
MgOo0000o`000?nHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool0
0ol0003oooooooooo`04ooooo`;o000000Coooooo`000?l0003o00009_ooool00omEEEGoIVIVo`00
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02?o
oooo0_l00004ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?l0003o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Hooooo`;o00002oooool2o`000006oooooonY
ZJWo410@o`000?l@413oZJVY0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Aooooo`;o00005oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Wooooo1?l00003ooooo`05onk^
k_l0003o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Yooooo`;o
00001oooool6o`0001oooooo0_l0000Aooooo`;o00009oooool2o`00013ooooo0_l0000Dooooo`;o
00002Oooool2o`0000_ooooo0_l00004ooooo`;o00007?ooool2o`0001gooooo0_l0000gooooo`;o
00005oooool002Wooooo00?o0000ooooooooool01_ooool2o`0000;ooooo0_l0000Looooo`;o0000
00?oooooo`000?l000004Oooool2o`0000Kooooo0_l0000aooooo`;o00005?ooool2o`0000_ooooo
0_l0000?ooooo`;o00005?ooool2o`0000Kooooo0_l0000Mooooo`;o0000=oooool2o`0001Oooooo
000Yooooo`03o`000?oooooooooo01Cooooo0_l0000Booooo`;o00004oooool2o`0000Oooooo0_l0
00001?oooooo0000o`000?ooool2o`0000gooooo0_l0000oooooo`;o00009Oooool2o`0000Kooooo
0_l0001Aooooo`;o00007?ooool002Wooooo00?o0000ooooooooool04Oooool2o`000003ooooool0
003o000002Oooooo0_l0000:ooooo`;o000000?oooooo`000?l000003Oooool2o`0002Kooooo0_l0
000hooooo`;o000000?oooooo`000?l00000G?ooool2o`0001cooooo000Yooooo`03o`000?oooooo
oooo00_ooooo1?l00002ooooo`;o00002oooool2o`0003_ooooo0_l0000Vooooo`;o00001_ooool2
o`0001[ooooo0_l00004ooooo`;o000000?oooooo`000?l000002oooool2o`000003ooooool0003o
0000017ooooo0_l0000Tooooo`;o00000oooool2o`0003cooooo000Qoooooooo0000A?l00004oooo
o`00:Oooool00ol0003oooooo`000003o`0000Kooooo00?o0000ooooooooool01_ooool2o`0000;o
oooo0_l0000:ooooo`03o`000?oooooooooo00Wooooo0ol00006ooooo`;o000000?oooooo`000?oo
ool02oooool00ol0003oooooooooo`03ooooo`;o00001?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Oooooo0ol00002ooooo`?o00001oooool00ol0003oooooooooo`02ooooo`;o
00001Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool01Oooool2o`0000?ooooo00?o0000ooooooooool02Oooool01?l0003oooooo`000?l00008oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00Co0000oooooooooooooooo0_l00006ooooo`04o`000?oooooo
ooooooooo`;o00001oooool01?l0003oooooooooooooool2o`0000Kooooo00?o0000ooooooooool0
1Oooool2o`0000;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`00:Ooo
ool01?l0003oooooo`000?l0000Aooooo`;o00000_ooool2o`0001Wooooo0_l00007ooooo`03o`00
0?oooooooooo013ooooo0_l0000Oooooo`?o00001oooool00ol0003oooooooooo`0Aooooo`;o0000
9oooool01?l0003oooooo`000?l0000>ooooo`;o00007_ooool2o`0000?ooooo0_l00004ooooo`03
o`000?oooooooooo00gooooo0_l000000ooooooo0000o`000003ooooo`;o00000oooool2o`0000ko
oooo0_l0000>ooooo`03o`000?oooooooooo00[ooooo000Yooooo`03o`000?oooooooooo033ooooo
0ol0001Iooooo`;o00009Oooool2o`00017ooooo0ol0000Nooooo`;o00000oooool2o`0001Oooooo
0_l00003ooooo`;o0000<?ooool002Wooooo00?o0000ooooooooool0<?ooool2o`0001Wooooo0_l0
001>ooooo`;o00005_ooool2o`00017ooooo0_l0000]ooooo`;o0000<_ooool2o`00017ooooo000Y
ooooo`;o0000@_ooool2o`0000Sooooo0_l0001>ooooo`;o0000:?ooool2o`0002kooooo0_l0000I
ooooo`;o00005oooool2o`00017ooooo000Yooooo`03o`000?oooooooooo00Wooooo0_l0000Loooo
o`;o00006?ooool2o`0002?ooooo0_l0000Dooooo`;o00004_ooool2o`0003?ooooo0_l0000Voooo
o`;o00000oooool4o`0000Kooooo0_l000000ooooooo0000o`000007ooooo`;o00001_ooool2o`00
00[ooooo0_l00009ooooo`;o00004oooool002Wooooo00?o0000ooooooooool02Oooool3o`0001_o
oooo0_l0000Pooooo`;o00006oooool4o`0000Wooooo0_l00007ooooo`;o00002_ooool2o`0000Ko
oooo0_l0001Dooooo`;o00001Oooool2o`0000;ooooo1Ol00006ooooo`;o000000?oooooo`000?l0
00001oooool2o`0001;ooooo0_l00009ooooo`;o00004oooool002Wooooo00?o0000ooooooooool0
2_ooool2o`0001Oooooo0_l0000Tooooo`;o00002?ooool2o`0000?ooooo0_l0000>ooooo`;o0000
2Oooool2o`0000Sooooo0_l00009ooooo`?o00002Oooool2o`0000;ooooo0_l0000gooooo`;o0000
4oooool2o`0000Wooooo0_l000000ooooooo0000o`000002ooooo`;o00004_ooool2o`0000?ooooo
0_l0000Yooooo`00:Oooool01?l0003oooooo`000?l00006ooooo`;o00006_ooool2o`0000gooooo
0_l000001?oooooo0000o`000?l00007ooooo`?o00004Oooool3o`0000;ooooo0_l0000Sooooo`;o
00002_ooool2o`0000Wooooo0_l00002ooooo`;o0000;oooool2o`0000Kooooo0_l000000ooooooo
0000o`00000Nooooo`;o00000_ooool2o`0001;ooooo0ol00002ooooo`;o00001?ooool2o`0002?o
oooo000Yooooo`Co00001_ooool2o`0002Wooooo0_l000001?oooooo0000o`000?l00007ooooo`?o
00004_ooool3o`0003kooooo0_l0000Vooooo`;o00002_ooool2o`0000Wooooo0ol0000Wooooo`;o
00003Oooool2o`0000Sooooo0_l0000Sooooo`00:Oooool00ol0003oooooooooo`1Eooooo`;o0000
8oooool2o`0001Wooooo0_l0000Vooooo`;o00003oooool2o`0000Gooooo0_l000000ooooooo0000
o`00000Pooooo`;o00000_ooool2o`0001Sooooo0_l0000Rooooo`00:Oooool00ol0003ooooooooo
o`1Wooooo`;o00004Oooool2o`0000[ooooo0_l00016ooooo`;o00002?ooool2o`00023ooooo0_l0
000Looooo`;o00008_ooool002Wooooo00?o0000ooooooooool06?ooool2o`0000Kooooo0_l0000D
ooooo`;o00004?ooool2o`0001gooooo0_l0000=ooooo`;o00003_ooool2o`0002Kooooo0_l0002<
ooooo`00:Oooool00ol0003oooooooooo`0Hooooo`;o00001_ooool2o`0001Cooooo0_l0000@oooo
o`;o0000;?ooool2o`0003Kooooo0_l0000Cooooo`;o00000oooool2o`0003Sooooo0_l0000hoooo
o`00:Oooool2o`0002kooooo0_l00003ooooo`;o00002Oooool3o`0001Sooooo0_l0000:ooooo`;o
00004Oooool2o`0000Oooooo0_l0000]ooooo`;o00001?ooool2o`0000cooooo0_l00003ooooo`;o
0000>?ooool2o`0003Sooooo000Yooooo`03o`000?oooooooooo02;ooooo0_l00009ooooo`;o0000
0oooool2o`0000Wooooo0ol0000Hooooo`;o00002_ooool2o`00017ooooo0_l00007ooooo`;o0000
4?ooool2o`0001_ooooo0_l00004ooooo`;o00009?ooool2o`0004Gooooo0_l0000Hooooo`00:Ooo
ool00ol0003oooooooooo`0Rooooo`;o00003oooool2o`0000oooooo0_l0000oooooo`;o00001_oo
ool2o`0000?ooooo0_l00010ooooo`;o00001Oooool2o`00037ooooo0_l0000?ooooo`;o000000?o
ooooo`000?l000006?ooool002Wooooo00?o0000ooooooooool03?ooool2o`000003ooooool0003o
000001Oooooo0_l00002ooooo`;o00001Oooool2o`0000oooooo0_l0000iooooo`;o000000Cooooo
o`000?l0003ooooo0_l00006ooooo`;o00001?ooool2o`000003ooooool0003o000000gooooo0_l0
0007ooooo`;o00001?ooool2o`0001kooooo0_l00003ooooo`;o00000oooool2o`000003ooooool0
003o000000cooooo0_l0000Cooooo`;o00002?ooool2o`0000cooooo0_l000000ooooooo0000o`00
000Kooooo`00:Oooool00ol0003oooooooooo`0<ooooo`;o000000?oooooo`000?l000005oooool2
o`0000;ooooo0_l0001Aooooo`;o000000?oooooo`000?l000003oooool2o`000003ooooool0003o
000000;ooooo0_l00004ooooo`;o000000?oooooo`000?l000000_l00007ooooo`;o00001?ooool4
o`0000?ooooo0_l0000Cooooo`;o00001oooool4o`000004ooooool0003o0000ooooo`;o00002?oo
ool2o`0000;ooooo1?l0000Aooooo`;o00005_ooool2o`0000Sooooo0_l0000Dooooo`00:Oooool2
o`0003_ooooo0ol0000Rooooo`;o0000>Oooool2o`000004ooooool0003o0000ooooo`;o000000?o
ooooo`000?l000004Oooool2o`0000?ooooo0_l0000Aooooo`Co00001_ooool2o`000003ooooool0
003o000000Cooooo0_l00008ooooo`;o00001?ooool2o`0003?ooooo0_l0000Dooooo`00:Oooool0
0ol0003oooooooooo`0Jooooo`;o00007_ooool3o`0001cooooo0_l00004ooooo`;o00004Oooool4
o`0002Oooooo0_l0000_ooooo`;o00002?ooool2o`0000Oooooo0_l0001Iooooo`001_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool02Oooool2o`0000oooooo0_l0000jooooo`;o000000?o
ooooo`000?l000005oooool4o`0001_ooooo0_l00024ooooo`;o00008oooool000Kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`09ooooo`;o00008oooool2o`0001;ooooo
0_l0000Booooo`;o0000>Oooool2o`0001gooooo0_l0001Uooooo`;o00008oooool000Kooooo00Go
410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Rooooo`;o00002_ooool2o`0001;ooooo0_l0001/ooooo`;o0000
4?ooool2o`0007Sooooo0006ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Q
onk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Rooooo`;o0000W_ooool2o`0004Wooooo
0_l0000]ooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool0
0oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0B?ooool4o`0003_o
oooo0_l0000Fooooo`;o0000F_ooool2o`00013ooooo0_l00007ooooo`;o00009?ooool000Kooooo
00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0>ooooo`;o0000>?ooool4o`0000Gooooo0_l0000dooooo`;o
00005_ooool2o`0000;ooooo0_l0000^ooooo`;o00009_ooool2o`0001Wooooo0_l00005ooooo`;o
00003_ooool2o`0000gooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o
^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0>oooo
o`;o00009?ooool2o`0001_ooooo0_l0000>ooooo`;o0000@?ooool2o`0002kooooo0_l0000Foooo
o`;o0000<?ooool2o`0000kooooo0ol0000<ooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`0B
ooooo`;o00008?ooool2o`0001[ooooo0_l0000?ooooo`;o0000:oooool2o`0004Oooooo0_l0000B
ooooo`;o0000@Oooool2o`0000cooooo000Yooooo`;o00003Oooool2o`0000Cooooo0_l0000coooo
o`;o00001oooool2o`0001Wooooo0_l0000Qooooo`;o00004_ooool2o`0000Kooooo0_l0000[oooo
o`Co0000AOooool2o`0001[ooooo000Yooooo`03o`000?oooooooooo00cooooo0_l0000=ooooo`;o
0000:_ooool2o`0001Oooooo0_l00004ooooo`;o00000oooool2o`0003Gooooo0_l00006ooooo`;o
0000;Oooool2o`0002[ooooo0_l00002ooooo`;o00002Oooool2o`0000[ooooo0_l0000Jooooo`00
:Oooool00ol0003oooooooooo`05ooooo`;o00005?ooool2o`00013ooooo0_l0000aooooo`;o0000
1?ooool2o`0000Cooooo0_l00004ooooo`;o00005_ooool2o`0002Wooooo0_l0000Xooooo`;o0000
1_ooool2o`0001cooooo0_l00002ooooo`;o00002Oooool2o`0002Kooooo000Yooooo`03o`000?oo
oooooooo00Gooooo0_l0000Vooooo`;o0000?Oooool2o`0000Cooooo0_l0000Fooooo`;o0000:Ooo
ool2o`0002Sooooo0_l00006ooooo`;o0000Doooool002Wooooo00?o0000ooooooooool05?ooool2
o`0000Kooooo0_l0000eooooo`;o00004?ooool2o`0005;ooooo0_l00015ooooo`;o0000>_ooool0
02Wooooo0_l0000Eooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00009oooool2o`00
00Sooooo0_l00006ooooo`;o0000<?ooool2o`0001Wooooo0_l00005ooooo`;o0000AOooool2o`00
03[ooooo000Yooooo`03o`000?oooooooooo02?ooooo0_l00005ooooo`;o00009?ooool2o`0000[o
oooo1Ol0000fooooo`;o00003Oooool2o`0000[ooooo0_l0000<ooooo`;o00000oooool2o`0007Go
oooo000Yooooo`03o`000?oooooooooo01Gooooo0_l0000=ooooo`;o0000:_ooool2o`0000[ooooo
0_l000000ooooooo0000o`00000=ooooo`;o00009Oooool2o`0000oooooo0_l0000Hooooo`;o0000
0oooool2o`0001kooooo0ol0000Booooo`;o0000@?ooool002Wooooo00?o0000ooooooooool04ooo
ool4o`0000gooooo0_l0000Eooooo`;o00002Oooool2o`00017ooooo0_l0000Cooooo`;o00009Ooo
ool6o`0002?ooooo0_l00009ooooo`;o00002oooool2o`0000Cooooo0_l00007ooooo`?o000000?o
ooooo`000?l000003oooool2o`0000gooooo0_l0000aooooo`00:Oooool00ol0003oooooooooo`0C
ooooo`;o00009_ooool2o`0000Wooooo0_l00006ooooo`;o00002Oooool2o`0000?ooooo0_l0000?
ooooo`;o00001?ooool3o`0001oooooo1?l0000@ooooo`;o00001_ooool2o`0000Wooooo0_l00009
ooooo`;o00002oooool2o`0000Cooooo0_l00006ooooo`;o00000oooool2o`0001kooooo0_l0000?
ooooo`?o00003oooool2o`0000kooooo000Yooooo`;o00000oooool2o`0001cooooo0_l0000Foooo
o`;o00005?ooool2o`0000;ooooo0_l0000:ooooo`;o00002Oooool2o`0000Cooooo0_l00004oooo
o`?o00003Oooool2o`0002Cooooo0ol00003ooooo`Co00009oooool3o`0000Cooooo0ol0000doooo
o`?o00003oooool2o`0000kooooo000Yooooo`03o`000?oooooooooo00;ooooo1?l0000Dooooo`Co
000000Coooooo`000?l0003o00005_ooool2o`0000Oooooo0_l0000?ooooo`;o00005Oooool2o`00
01[ooooo0_l0000Fooooo`;o00002Oooool2o`0000;ooooo0_l00003ooooo`?o00001_ooool2o`00
00Gooooo0_l0000>ooooo`;o00002Oooool3o`0000Cooooo0_l0000Booooo`;o00002?ooool2o`00
02cooooo0_l0000;ooooo`00:Oooool00ol0003oooooooooo`04ooooo`;o00002_ooool2o`0000So
oooo1?l000000ooooooo0000o`000004ooooo`;o00006_ooool2o`0002Wooooo0_l00002ooooo`;o
00008_ooool2o`0000Oooooo0_l00009ooooo`;o00003_ooool4o`0000Gooooo0_l0000>ooooo`;o
00000oooool2o`0000;ooooo0_l0000Dooooo`Co00000oooool2o`0000Sooooo0_l0000Tooooo`;o
00001_ooool2o`0000_ooooo000Yooooo`03o`000?oooooooooo013ooooo0_l00003ooooo`;o0000
3_ooool2o`0001kooooo0_l0000Gooooo`;o00003?ooool2o`0000;ooooo0ol0000?ooooo`;o0000
4?ooool2o`0000Kooooo0_l0000Jooooo`;o00007?ooool2o`0000;ooooo0_l00003ooooo`;o0000
2oooool2o`0000;ooooo1?l0000cooooo`;o00004oooool002Wooooo00?o0000ooooooooool05Ooo
ool2o`0000Sooooo0_l0000?ooooo`;o00004oooool2o`0000oooooo0_l00006ooooo`;o000000?o
ooooo`000?l000000_l0000<ooooo`;o000000?oooooo`000?l000003?ooool4o`0001Kooooo0_l0
000Zooooo`;o00005Oooool2o`0000_ooooo0_l00008ooooo`;o0000A?ooool002Wooooo0_l00002
ooooo`;o00007?ooool2o`0000oooooo0_l0000Cooooo`;o00003oooool2o`0000Wooooo1?l0000?
ooooo`;o00003_ooool2o`0004;ooooo0_l0000/ooooo`;o00006oooool2o`0000Cooooo0_l0000Q
ooooo`00:Oooool01?l0003oooooooooooooool2o`000?oooooo4Oooool2o`0000Cooooo0_l0000Q
ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo000>ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`03ooooo`?o0000oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
oooooolmooooo`003_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEoooo
o`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`000?oooooo
ooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o
EEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool0
0oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`007oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`007oooool00omEEEGoIVIVo`00003oooooodOooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .2905 Mdot
.02762 .26383 Mdot
.02952 .29229 Mdot
.03143 .34075 Mdot
.03333 .26783 Mdot
.03524 .34785 Mdot
.03714 .31645 Mdot
.03905 .43742 Mdot
.04095 .43114 Mdot
.04286 .31726 Mdot
.04476 .28364 Mdot
.04667 .44909 Mdot
.04857 .23706 Mdot
.05048 .31848 Mdot
.05238 .44626 Mdot
.05429 .34019 Mdot
.05619 .37699 Mdot
.0581 .23648 Mdot
.06 .25317 Mdot
.0619 .28713 Mdot
.06381 .24093 Mdot
.06571 .23744 Mdot
.06762 .2446 Mdot
.06952 .23448 Mdot
.07143 .44814 Mdot
.07333 .32245 Mdot
.07524 .258 Mdot
.07714 .25225 Mdot
.07905 .31193 Mdot
.08095 .24608 Mdot
.08286 .27463 Mdot
.08476 .42604 Mdot
.08667 .43962 Mdot
.08857 .36582 Mdot
.09048 .37341 Mdot
.09238 .33016 Mdot
.09429 .39049 Mdot
.09619 .25288 Mdot
.0981 .35912 Mdot
.1 .4493 Mdot
.1019 .45457 Mdot
.10381 .37217 Mdot
.10571 .35603 Mdot
.10762 .31526 Mdot
.10952 .32671 Mdot
.11143 .28928 Mdot
.11333 .29031 Mdot
.11524 .40875 Mdot
.11714 .35736 Mdot
.11905 .33944 Mdot
.12095 .41186 Mdot
.12286 .35377 Mdot
.12476 .34639 Mdot
.12667 .3561 Mdot
.12857 .37206 Mdot
.13048 .43612 Mdot
.13238 .44122 Mdot
.13429 .37916 Mdot
.13619 .39972 Mdot
.1381 .33155 Mdot
.14 .30578 Mdot
.1419 .44846 Mdot
.14381 .37111 Mdot
.14571 .2987 Mdot
.14762 .44271 Mdot
.14952 .42925 Mdot
.15143 .31237 Mdot
.15333 .33338 Mdot
.15524 .25608 Mdot
.15714 .23906 Mdot
.15905 .38125 Mdot
.16095 .32293 Mdot
.16286 .30106 Mdot
.16476 .325 Mdot
.16667 .3713 Mdot
.16857 .27354 Mdot
.17048 .34579 Mdot
.17238 .34258 Mdot
.17429 .34367 Mdot
.17619 .36918 Mdot
.1781 .3013 Mdot
.18 .24303 Mdot
.1819 .33953 Mdot
.18381 .37476 Mdot
.18571 .43258 Mdot
.18762 .34582 Mdot
.18952 .26939 Mdot
.19143 .30801 Mdot
.19333 .37837 Mdot
.19524 .33068 Mdot
.19714 .44565 Mdot
.19905 .394 Mdot
.20095 .31245 Mdot
.20286 .2879 Mdot
.20476 .31288 Mdot
.20667 .41242 Mdot
.20857 .31875 Mdot
.21048 .42225 Mdot
.21238 .34465 Mdot
.21429 .37688 Mdot
.21619 .27558 Mdot
.2181 .37345 Mdot
.22 .44915 Mdot
.2219 .29933 Mdot
.22381 .26064 Mdot
.22571 .365 Mdot
.22762 .38213 Mdot
.22952 .25165 Mdot
.23143 .31222 Mdot
.23333 .24504 Mdot
.23524 .32256 Mdot
.23714 .34035 Mdot
.23905 .42672 Mdot
.24095 .29244 Mdot
.24286 .27883 Mdot
.24476 .29036 Mdot
.24667 .3227 Mdot
.24857 .42309 Mdot
.25048 .42262 Mdot
.25238 .40272 Mdot
.25429 .23545 Mdot
.25619 .4551 Mdot
.2581 .25885 Mdot
.26 .30541 Mdot
.2619 .24187 Mdot
.26381 .33938 Mdot
.26571 .30974 Mdot
.26762 .42001 Mdot
.26952 .24251 Mdot
.27143 .26405 Mdot
.27333 .23687 Mdot
.27524 .26012 Mdot
.27714 .45135 Mdot
.27905 .35783 Mdot
.28095 .35241 Mdot
.28286 .32143 Mdot
.28476 .36318 Mdot
.28667 .31594 Mdot
.28857 .29932 Mdot
.29048 .44439 Mdot
.29238 .44813 Mdot
.29429 .4237 Mdot
.29619 .33017 Mdot
.2981 .25661 Mdot
.3 .37761 Mdot
.3019 .28593 Mdot
.30381 .42904 Mdot
.30571 .25491 Mdot
.30762 .27142 Mdot
.30952 .3092 Mdot
.31143 .46256 Mdot
.31333 .37028 Mdot
.31524 .27189 Mdot
.31714 .23446 Mdot
.31905 .3222 Mdot
.32095 .3106 Mdot
.32286 .37027 Mdot
.32476 .36419 Mdot
.32667 .42801 Mdot
.32857 .3959 Mdot
.33048 .36846 Mdot
.33238 .33898 Mdot
.33429 .33427 Mdot
.33619 .45537 Mdot
.3381 .32666 Mdot
.34 .33769 Mdot
.3419 .26157 Mdot
.34381 .42945 Mdot
.34571 .26081 Mdot
.34762 .25636 Mdot
.34952 .35216 Mdot
.35143 .34615 Mdot
.35333 .33336 Mdot
.35524 .2549 Mdot
.35714 .2885 Mdot
.35905 .26528 Mdot
.36095 .44272 Mdot
.36286 .41332 Mdot
.36476 .30895 Mdot
.36667 .27364 Mdot
.36857 .33287 Mdot
.37048 .34093 Mdot
.37238 .45243 Mdot
.37429 .33834 Mdot
.37619 .455 Mdot
.3781 .26768 Mdot
.38 .43238 Mdot
.3819 .41373 Mdot
.38381 .41741 Mdot
.38571 .45481 Mdot
.38762 .35992 Mdot
.38952 .45586 Mdot
.39143 .2823 Mdot
.39333 .29493 Mdot
.39524 .44319 Mdot
.39714 .43582 Mdot
.39905 .45859 Mdot
.40095 .45015 Mdot
.40286 .2886 Mdot
.40476 .4005 Mdot
.40667 .3842 Mdot
.40857 .28198 Mdot
.41048 .28073 Mdot
.41238 .3231 Mdot
.41429 .2822 Mdot
.41619 .39216 Mdot
.4181 .2581 Mdot
.42 .28713 Mdot
.4219 .33812 Mdot
.42381 .33656 Mdot
.42571 .26378 Mdot
.42762 .29104 Mdot
.42952 .24375 Mdot
.43143 .33827 Mdot
.43333 .26284 Mdot
.43524 .33232 Mdot
.43714 .25743 Mdot
.43905 .33795 Mdot
.44095 .45604 Mdot
.44286 .26277 Mdot
.44476 .30868 Mdot
.44667 .44622 Mdot
.44857 .31788 Mdot
.45048 .41259 Mdot
.45238 .25273 Mdot
.45429 .31729 Mdot
.45619 .32552 Mdot
.4581 .2624 Mdot
.46 .28771 Mdot
.4619 .32826 Mdot
.46381 .44666 Mdot
.46571 .45838 Mdot
.46762 .34273 Mdot
.46952 .2906 Mdot
.47143 .37308 Mdot
.47333 .37231 Mdot
.47524 .26849 Mdot
.47714 .45325 Mdot
.47905 .25398 Mdot
.48095 .29614 Mdot
.48286 .24154 Mdot
.48476 .26575 Mdot
.48667 .44539 Mdot
.48857 .36125 Mdot
.49048 .26314 Mdot
.49238 .38119 Mdot
.49429 .42128 Mdot
.49619 .31792 Mdot
.4981 .38428 Mdot
.5 .37463 Mdot
.5019 .38081 Mdot
.50381 .36578 Mdot
.50571 .45744 Mdot
.50762 .28943 Mdot
.50952 .30648 Mdot
.51143 .39314 Mdot
.51333 .33957 Mdot
.51524 .2548 Mdot
.51714 .3799 Mdot
.51905 .27311 Mdot
.52095 .44247 Mdot
.52286 .40375 Mdot
.52476 .3656 Mdot
.52667 .26931 Mdot
.52857 .3186 Mdot
.53048 .26728 Mdot
.53238 .37268 Mdot
.53429 .28575 Mdot
.53619 .27728 Mdot
.5381 .32663 Mdot
.54 .34118 Mdot
.5419 .3544 Mdot
.54381 .31512 Mdot
.54571 .37392 Mdot
.54762 .32611 Mdot
.54952 .36808 Mdot
.55143 .36419 Mdot
.55333 .34076 Mdot
.55524 .25053 Mdot
.55714 .41595 Mdot
.55905 .30446 Mdot
.56095 .32549 Mdot
.56286 .33358 Mdot
.56476 .2703 Mdot
.56667 .31888 Mdot
.56857 .39885 Mdot
.57048 .44813 Mdot
.57238 .25178 Mdot
.57429 .32013 Mdot
.57619 .29405 Mdot
.5781 .27011 Mdot
.58 .30612 Mdot
.5819 .30001 Mdot
.58381 .41005 Mdot
.58571 .40462 Mdot
.58762 .44721 Mdot
.58952 .41262 Mdot
.59143 .2994 Mdot
.59333 .38684 Mdot
.59524 .43737 Mdot
.59714 .25852 Mdot
.59905 .4464 Mdot
.60095 .2447 Mdot
.60286 .36278 Mdot
.60476 .37667 Mdot
.60667 .26541 Mdot
.60857 .42359 Mdot
.61048 .45192 Mdot
.61238 .29252 Mdot
.61429 .41859 Mdot
.61619 .3405 Mdot
.6181 .29198 Mdot
.62 .23862 Mdot
.6219 .37768 Mdot
.62381 .23507 Mdot
.62571 .4617 Mdot
.62762 .27932 Mdot
.62952 .29945 Mdot
.63143 .36761 Mdot
.63333 .44369 Mdot
.63524 .27201 Mdot
.63714 .453 Mdot
.63905 .44382 Mdot
.64095 .43465 Mdot
.64286 .33973 Mdot
.64476 .36447 Mdot
.64667 .37775 Mdot
.64857 .37699 Mdot
.65048 .25465 Mdot
.65238 .30138 Mdot
.65429 .30995 Mdot
.65619 .38136 Mdot
.6581 .44306 Mdot
.66 .39767 Mdot
.6619 .30745 Mdot
.66381 .24132 Mdot
.66571 .26384 Mdot
.66762 .32283 Mdot
.66952 .28338 Mdot
.67143 .35438 Mdot
.67333 .33823 Mdot
.67524 .34071 Mdot
.67714 .28261 Mdot
.67905 .3663 Mdot
.68095 .34944 Mdot
.68286 .24038 Mdot
.68476 .3073 Mdot
.68667 .43897 Mdot
.68857 .2585 Mdot
.69048 .31708 Mdot
.69238 .2373 Mdot
.69429 .31935 Mdot
.69619 .33401 Mdot
.6981 .4267 Mdot
.7 .44803 Mdot
.7019 .37809 Mdot
.70381 .32851 Mdot
.70571 .35574 Mdot
.70762 .38176 Mdot
.70952 .33817 Mdot
.71143 .3723 Mdot
.71333 .44819 Mdot
.71524 .44401 Mdot
.71714 .26467 Mdot
.71905 .45098 Mdot
.72095 .45343 Mdot
.72286 .45683 Mdot
.72476 .32159 Mdot
.72667 .37031 Mdot
.72857 .44733 Mdot
.73048 .44149 Mdot
.73238 .32121 Mdot
.73429 .2838 Mdot
.73619 .35799 Mdot
.7381 .3472 Mdot
.74 .27894 Mdot
.7419 .42499 Mdot
.74381 .29377 Mdot
.74571 .39201 Mdot
.74762 .39245 Mdot
.74952 .24465 Mdot
.75143 .36944 Mdot
.75333 .23781 Mdot
.75524 .4489 Mdot
.75714 .2759 Mdot
.75905 .40837 Mdot
.76095 .32122 Mdot
.76286 .3218 Mdot
.76476 .44875 Mdot
.76667 .37687 Mdot
.76857 .30853 Mdot
.77048 .45269 Mdot
.77238 .23991 Mdot
.77429 .3072 Mdot
.77619 .32013 Mdot
.7781 .32483 Mdot
.78 .26386 Mdot
.7819 .40897 Mdot
.78381 .24013 Mdot
.78571 .43965 Mdot
.78762 .45288 Mdot
.78952 .37578 Mdot
.79143 .35565 Mdot
.79333 .37873 Mdot
.79524 .26091 Mdot
.79714 .25678 Mdot
.79905 .27555 Mdot
.80095 .44351 Mdot
.80286 .44885 Mdot
.80476 .25909 Mdot
.80667 .32734 Mdot
.80857 .30019 Mdot
.81048 .34464 Mdot
.81238 .45952 Mdot
.81429 .2754 Mdot
.81619 .31499 Mdot
.8181 .3367 Mdot
.82 .26676 Mdot
.8219 .26691 Mdot
.82381 .2745 Mdot
.82571 .36691 Mdot
.82762 .27646 Mdot
.82952 .28964 Mdot
.83143 .45929 Mdot
.83333 .44387 Mdot
.83524 .3061 Mdot
.83714 .37307 Mdot
.83905 .38204 Mdot
.84095 .28565 Mdot
.84286 .36052 Mdot
.84476 .25676 Mdot
.84667 .45207 Mdot
.84857 .41806 Mdot
.85048 .27876 Mdot
.85238 .29809 Mdot
.85429 .31756 Mdot
.85619 .2855 Mdot
.8581 .43568 Mdot
.86 .44671 Mdot
.8619 .27234 Mdot
.86381 .23856 Mdot
.86571 .36015 Mdot
.86762 .33044 Mdot
.86952 .31013 Mdot
.87143 .27394 Mdot
.87333 .30925 Mdot
.87524 .36577 Mdot
.87714 .39753 Mdot
.87905 .26717 Mdot
.88095 .35733 Mdot
.88286 .37748 Mdot
.88476 .29998 Mdot
.88667 .27338 Mdot
.88857 .3363 Mdot
.89048 .43841 Mdot
.89238 .28173 Mdot
.89429 .33344 Mdot
.89619 .27292 Mdot
.8981 .31201 Mdot
.9 .31031 Mdot
.9019 .29663 Mdot
.90381 .37789 Mdot
.90571 .43323 Mdot
.90762 .32001 Mdot
.90952 .44344 Mdot
.91143 .45813 Mdot
.91333 .27164 Mdot
.91524 .38304 Mdot
.91714 .35808 Mdot
.91905 .37352 Mdot
.92095 .31294 Mdot
.92286 .28109 Mdot
.92476 .25162 Mdot
.92667 .33269 Mdot
.92857 .37007 Mdot
.93048 .45738 Mdot
.93238 .34035 Mdot
.93429 .27617 Mdot
.93619 .34891 Mdot
.9381 .36861 Mdot
.94 .32366 Mdot
.9419 .33463 Mdot
.94381 .35956 Mdot
.94571 .36221 Mdot
.94762 .28657 Mdot
.94952 .34052 Mdot
.95143 .42989 Mdot
.95333 .26013 Mdot
.95524 .28789 Mdot
.95714 .2678 Mdot
.95905 .25856 Mdot
.96095 .31852 Mdot
.96286 .29558 Mdot
.96476 .31484 Mdot
.96667 .27324 Mdot
.96857 .41953 Mdot
.97048 .32297 Mdot
.97238 .2549 Mdot
.97429 .32288 Mdot
.97619 .45125 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooocgooooo0006
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol0003oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_oo
ool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`04ooooo`;o000000?oooooo`000?l000000_ooool2o`0003Wooooo0_l00005ooooo`;o0000
3?ooool2o`00063ooooo0_l0001mooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo
0_l000001?oooooo0000o`000?ooool3o`0001[ooooo0_l0000Mooooo`;o00001Oooool2o`0000co
oooo0_l0001Oooooo`?o00004Oooool2o`000003ooooool0003o000001;ooooo0_l00004ooooo`;o
00000_ooool2o`0001Oooooo0_l0000`ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02Oooool3o`0001_ooooo0_l00005ooooo`;o00006Oooool4o`0004?ooooo0_l0000Zoooo
o`;o00003?ooool2o`0000Cooooo0_l000000ooooooo0000o`00000Booooo`;o00001?ooool2o`00
00;ooooo0_l0000Gooooo`;o0000<?ooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool02Oooool3
o`0000?ooooo0_l0000Mooooo`;o00004?ooool2o`0000Oooooo1?l0000booooo`;o00003oooool2
o`0002Cooooo0_l0000Booooo`;o00006_ooool2o`0005Cooooo000Yooooo`;o00002oooool2o`00
00?ooooo0_l0000_ooooo`;o0000?Oooool2o`0003Gooooo0_l0000^ooooo`;o0000E?ooool002Wo
oooo00?o0000ooooooooool03Oooool2o`0002oooooo0_l00016ooooo`;o00007oooool2o`0000Co
oooo0_l0001_ooooo`;o00007?ooool002Wooooo00?o0000ooooooooool02?ooool2o`0000?ooooo
0_l00005ooooo`;o0000:?ooool2o`0001Oooooo0_l0000>ooooo`;o00007Oooool2o`0000Oooooo
0_l00009ooooo`;o00002oooool2o`0000Cooooo0_l0000Gooooo`;o0000E_ooool2o`0000gooooo
0_l0000=ooooo`00:Oooool00ol0003oooooooooo`08ooooo`;o00000oooool2o`0000Gooooo0_l0
000Aooooo`;o00007oooool2o`0000[ooooo0_l000000ooooooo0000o`00000;ooooo`;o000000?o
ooooo`000?l000004_ooool2o`0000Cooooo0_l0000<ooooo`;o00002Oooool2o`0001Wooooo0_l0
000?ooooo`;o00002_ooool2o`00027ooooo0_l0000=ooooo`;o00008oooool2o`0000;ooooo0_l0
000=ooooo`00:Oooool00ol0003oooooooooo`0=ooooo`;o00006?ooool2o`0001Cooooo0_l00009
ooooo`;o00000oooool2o`0000Gooooo0_l0000=ooooo`?o00005Oooool2o`0000Cooooo0_l0000b
ooooo`;o00006oooool2o`00023ooooo1Ol0000;ooooo`;o00008Oooool4o`00017ooooo000Yoooo
o`;o0000?_ooool2o`0000gooooo0ol0000Dooooo`?o00000_ooool2o`0001?ooooo0_l000001?oo
oooo0000o`000?ooool2o`0000?ooooo0_l00008ooooo`;o0000=oooool2o`0000kooooo0_l0000B
ooooo`;o00000oooool2o`000003ooooool0003o000002kooooo0_l0000Cooooo`00:Oooool4o`00
04_ooooo0_l0000Jooooo`;o00001?ooool2o`0000gooooo0_l000001?oooooo0000o`000?ooool2
o`0000?ooooo0_l00006ooooo`Co00002oooool2o`0001Oooooo0_l0000Aooooo`;o00003_ooool2
o`0001;ooooo0_l0000;ooooo`?o00004?ooool2o`0001Oooooo0_l0000Booooo`00:Oooool01?l0
003oooooo`000?l0000_ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Dooooo`;o00004oooool5o`0000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool2o`000003ooooool0
003o000000cooooo0ol00009ooooo`?o000000?o<S8bo`000?l000000_ooool01_o^k^ko<S8bo`00
0?lb<S;ok^k^ooooo`;o000000Gok^k^oc8b<_l0003o<S8bonk^kP0Zooooo`;o000000Wo410@oooo
ooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
00004?ooool2o`0001Cooooo00?oA4A4o`000?l000000_l00002ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Yooooo`03o`000?oooooooooo
02_ooooo0_l00005ooooo`;o00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0Dooooo`Co00003oooool2o`000005oiRHV?lQ8B7ok^k^oooooom4A4@0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`;o00003Oooool4o`0000[ooooo0_l000001?ooooooMgMgo`000?l00002ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo0_l0000Wooooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00_ooool2o`0000[ooooo0_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`00
0?l000000oooool2o`0000cooooo00?oMgMgoc8b<_ooool00_l000001?nHV9SooooooiRHV?mgMgL3
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wooooo00?o0000ooooooooool03oooool2
o`0001[ooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo00?o410@ooooooooool00_l00003
ooooo`05oa0@4?ooooooooooooooool@41005_ooool2o`0000oooooo0_l000001?ooooooV9RHob4Q
8Oo^k^h4ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@
01[ooooo0_l00003ooooo`;o00002oooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@
oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00;o00009?ooool5o`0000?ooooo00Go
410@oooooooooooooooooa0@4002ooooo`;o00000_ooool2o`0000;ooooo0ol00009ooooo`;o0000
00?oooooo`000?l000000oooool2o`000003ooooool0003o000000?ooooo0_l00005ooooo`;o0000
1_ooool01?l0003oooooo`000?l00003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@
413oooooooooo`01ooooo`00:Oooool2o`00013ooooo0_l0000Qooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_l00003ooooo`04o`000?ooooooooooooooo`;o0000:_ooool00onH
V9So8B4Qonk^kP03ooooo`04o`000?ooooooooooooooo`;o00000_ooool01Ol0003ooooooooooooo
oooo000001oooooo0_l0000:ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oooooooooooooooo
o`000003ooooo`04o`000?ooooooooooooooo`;o00008oooool2o`0000;ooooo00CoA4A4o`000?l0
003o00001?ooool01Ol0003ooooooooooooooooo000000;ooooo0_l00002ooooo`;o00000oooool2
o`0000Gooooo0_l0000Iooooo`;o00001Oooool01OmgMgOo<S8boooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo007ooooo000Yooooo`03o`000?oo
oooooooo00?ooooo0_l0000]ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`000003ooooo`04o`000?ooooooooooooooo`;o0000:oooool01_mgMgOoIVIVo`000?l0003ooooo
o`0000;ooooo1?l000000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo02Sooooo00?o410@
o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooooooo
0_l0000<ooooo`Co00004Oooool4o`0000;ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00000:ooooo`;o00003?ooool2
o`0000Oooooo0_l00006ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`00:Oooool00ol0003ooooo
ooooo`03ooooo`;o0000;Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@01;ooooo0_l0000Iooooo`?o000000Cooooooa0@
4?oooooooooo1?l000000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo01cooooo0_l0000;
ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oo
ooooooooooooool@41003Oooool4o`00017ooooo0_l00005ooooo`03ogMgMoo<c<co000000Cooooo
00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001oooool2o`00
00?ooooo0_l0000:ooooo`;o00001oooool2o`0000Kooooo0_l00005ooooo`05oa0@4?oooooooooo
ooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo000Yooooo`03o`000?oooooo
oooo00Wooooo0_l0000=ooooo`;o00006?ooool01?l0003oooooooooooooool2o`000004oiRHV?oo
ooooV9RHogMgM`?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Booooo`;o00003oooool2o`0000Co
oooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMol0003o0000oiRHV?mgMgL00_ooool2
o`000004oiRHV?ooooooV9RHogMgM`Oooooo0_l0000=ooooo`;o00001_ooool2o`0000Sooooo00Go
410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Wooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`;o00000_ooool2o`0000?ooooo0_l0
000Kooooo`;o000000?oooooo`000?l000000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool3o`0000Wooooo0_l0000=ooooo`?o0000
5Oooool00omEEEGoIVIVo`000003ooooo`;o000000Co<S8bo`000?lb<S;ok^k^0oooool00oo^k^ko
<S8bo`000003o`0002;ooooo0_l00004ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko0000o`000?lb<S;ok^k^00;ooooo1?l000000olb<S;ok^k^ooooo`06ooooo`;o000000?ooooo
o`000?l000002_ooool2o`00013ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool3o`000003oc8b<_o^k^kooooo02Wooooo00?oMgMgo`000?ooool0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`;o00009?ooool5o`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool002Wooooo0ol0000Iooooo`;o00009oooool3o`0002kooooo0_l00009
ooooo`;o00003?ooool2o`000003ooooool0003o000001gooooo0_l0000:ooooo`?o00009oooool2
o`0004Cooooo0_l0000@ooooo`00:Oooool00ol0003oooooooooo`0Sooooo`;o00005oooool2o`00
01?ooooo0_l0000Pooooo`;o00006_ooool2o`0001gooooo0_l00003ooooo`;o00002_ooool2o`00
02?ooooo0_l0000Qooooo`;o00003_ooool2o`00017ooooo0_l0000@ooooo`00:Oooool00ol0003o
ooooooooo`0Sooooo`;o00001?ooool2o`0000?ooooo0_l0000<ooooo`;o00004oooool2o`0005go
oooo0_l000000ooooooo0000o`00000:ooooo`;o00001Oooool2o`00037ooooo0_l0000<ooooo`;o
00002?ooool2o`0000Cooooo0_l0000Sooooo`00:Oooool00ol0003oooooooooo`0Yooooo`;o0000
0oooool2o`0001Sooooo0_l0001Nooooo`;o00001_ooool2o`0001Cooooo0_l0000aooooo`;o0000
5_ooool2o`0002Wooooo000Yooooo`03o`000?oooooooooo02;ooooo0_l0000>ooooo`;o00005?oo
ool2o`0003[ooooo0_l0000Booooo`;o00003_ooool2o`0000Gooooo0_l0000Hooooo`;o00001_oo
ool2o`0001Wooooo1?l0000Aooooo`;o0000>Oooool0027oooooool00014o`0000Cooooo000Yoooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool2o`0000Kooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`02o`0000Oooooo00?o0000ooooooooool01?ooool3o`00
00;ooooo00?o0000ooooooooool00_ooool2o`0000Kooooo00?o0000ooooooooool00_l00007oooo
o`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o000000?oooooo`000?ooool02Oooool2o`00
00cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool00oooool2o`0000Cooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool2o`00
0003ooooool0003ooooo00_ooooo1?l00006ooooo`?o00001Oooool2o`0000Cooooo00?o0000oooo
ooooool01Oooool2o`0000;ooooo00?o0000ooooooooool02_ooool002Wooooo00Co0000oooooooo
oooooooo0ol0000Cooooo`;o00003?ooool2o`0000kooooo0ol00002ooooo`03o`000?oooooooooo
00;ooooo0_l0000@ooooo`;o00009Oooool00ol0003oooooooooo`0:ooooo`Co00002oooool2o`00
00gooooo0_l0000@ooooo`03o`000?oooooooooo01_ooooo0_l0000Mooooo`03o`000?oooooooooo
00Kooooo0_l0000:ooooo`;o00003?ooool2o`0000Kooooo0_l0000<ooooo`;o00000_ooool00ol0
003oooooooooo`0:ooooo`00:Oooool01?l0003oooooooooooooool3o`000003ooooool0003o0000
013ooooo0_l0000Oooooo`;o00005oooool2o`0003;ooooo1?l0000;ooooo`;o00002Oooool2o`00
00;ooooo0_l00006ooooo`Co00009?ooool3o`0000[ooooo0_l00007ooooo`;o00000oooool2o`00
01Oooooo0_l0000?ooooo`;o00004?ooool2o`00013ooooo000Yooooo`03o`000?oooooooooo00Go
oooo0_l00005ooooo`;o00006_ooool2o`0000kooooo0_l00006ooooo`;o00000_ooool2o`0000[o
oooo0_l00009ooooo`;o00007?ooool2o`0002Cooooo0_l0000:ooooo`Co00007?ooool2o`0000Oo
oooo0_l00008ooooo`Co00001oooool3o`0000;ooooo0_l0000Xooooo`;o00002Oooool2o`0000Go
oooo0_l000001?oooooo0000o`000?l0000<ooooo`00:Oooool2o`0000gooooo0_l0000:ooooo`;o
00003_ooool4o`0001Cooooo0_l00002ooooo`;o00002_ooool2o`0000Wooooo0_l00004ooooo`;o
00005_ooool2o`0000cooooo0_l0000Iooooo`;o000000?oooooo`000?l000000_ooool2o`00023o
oooo0_l0000Aooooo`;o00002_ooool2o`0000?ooooo0_l00007ooooo`;o0000:Oooool2o`0000So
oooo0ol0000<ooooo`00:Oooool00ol0003oooooooooo`0Booooo`;o00001?ooool2o`00013ooooo
0_l0000Xooooo`;o00002oooool2o`0002Cooooo1?l0000Gooooo`;o000000?oooooo`000?l00000
0_ooool2o`0002cooooo0_l0000Fooooo`;o00001oooool2o`0001;ooooo0_l0000^ooooo`00:Ooo
ool00ol0003oooooooooo`0Booooo`;o00003Oooool2o`0000?ooooo0_l0000;ooooo`;o00007ooo
ool2o`00013ooooo0_l00003ooooo`;o00005?ooool2o`0000Kooooo0_l0000Oooooo`;o0000:ooo
ool2o`0003?ooooo0_l00006ooooo`;o00002Oooool2o`0001_ooooo000Yooooo`03o`000?oooooo
oooo027ooooo0_l00003ooooo`;o00002oooool2o`0002_ooooo0_l00004ooooo`;o00000oooool2
o`00013ooooo0_l00002ooooo`;o00009oooool2o`0002Sooooo0_l0000Vooooo`;o00005?ooool4
o`0000Wooooo0_l00002ooooo`;o00005oooool002Wooooo00?o0000ooooooooool06oooool2o`00
01;ooooo0_l0000Hooooo`;o00005?ooool5o`0000Wooooo0_l0000=ooooo`Go000000?oooooo`00
0?l000005_ooool2o`0002Oooooo0_l00008ooooo`;o00001Oooool2o`0000?ooooo0_l0000Qoooo
o`;o00005?ooool2o`0000oooooo0_l0000Gooooo`00:Oooool4o`0000Gooooo0_l0000Cooooo`;o
00003oooool2o`000003ooooool0003o0000013ooooo0_l00006ooooo`;o00005?ooool2o`000003
ooooool0003o000000Sooooo0ol0000=ooooo`;o000000Coooooo`000?l0003ooooo0_l00007oooo
o`;o00003Oooool2o`0000Kooooo0_l00003ooooo`;o00004_ooool2o`0000Kooooo0_l00008oooo
o`?o00002Oooool2o`0004Gooooo0_l00004ooooo`;o00005?ooool002Wooooo00Co0000ooooool0
003o00001Oooool2o`0002?ooooo1?l00002ooooo`;o00001_ooool2o`0000Kooooo0_l0000Yoooo
o`;o00007Oooool2o`0001Gooooo0_l00003ooooo`;o00004_ooool2o`00017ooooo0_l0000Yoooo
o`;o00009Oooool2o`0000Cooooo0_l0000Dooooo`00:Oooool00ol0003oooooooooo`02o`0001_o
oooo0_l0000<ooooo`Co00000_ooool2o`0000Kooooo0_l0000[ooooo`;o0000N_ooool2o`0001Go
oooo0_l0000Wooooo`;o00006?ooool002Wooooo00?o0000ooooooooool00_l0000Kooooo`;o0000
A_ooool3o`0006Sooooo0_l0000@ooooo`;o0000?_ooool2o`0001Sooooo000Yooooo`03o`000?oo
oooooooo01cooooo0_l0000aooooo`;o00005?ooool2o`0003cooooo0_l0000Xooooo`;o000000?o
ooooo`000?l00000J_ooool002Wooooo0_l0000Hooooo`;o000000?oooooo`000?l000000ol0000_
ooooo`?o0000D_ooool2o`0002Sooooo0_l00009ooooo`;o00001oooool2o`00013ooooo0_l0000K
ooooo`;o00002_ooool2o`0001kooooo000Yooooo`03o`000?oooooooooo01Cooooo0_l000001?oo
oooo0000o`000?ooool2o`000003ooooool0003o000002oooooo0_l0000Qooooo`;o00007oooool2
o`0004Cooooo0_l00007ooooo`;o00004?ooool2o`0000oooooo0_l00005ooooo`;o00000oooool2
o`0000[ooooo0_l00006ooooo`;o00005_ooool002Wooooo00?o0000ooooooooool05?ooool2o`00
03[ooooo0_l0000;ooooo`;o00004_ooool2o`0001oooooo0_l0000Booooo`;o00003_ooool2o`00
00cooooo0_l0000nooooo`;o00001Oooool2o`0001Oooooo0ol0000Eooooo`00:Oooool00ol0003o
ooooooooo`0Aooooo`;o0000:_ooool2o`00017ooooo0_l0000;ooooo`;o0000>?ooool2o`0000Co
oooo0_l00007ooooo`;o00003_ooool2o`0000Sooooo0_l00002ooooo`;o00002Oooool2o`0002go
oooo0_l0000>ooooo`;o00005Oooool2o`0001Gooooo000Yooooo`03o`000?oooooooooo017ooooo
0_l0000Jooooo`;o00003_ooool2o`0001[ooooo0_l000001?oooooo0000o`000?ooool2o`0003Ko
oooo0_l00004ooooo`;o00001_ooool2o`0001Wooooo0_l0000=ooooo`;o00003Oooool2o`0000Ko
oooo0_l0000Fooooo`;o00003_ooool2o`0000oooooo0_l000000ooooooo0000o`00000Hooooo`00
:Oooool2o`0001?ooooo0_l00002ooooo`;o00001_ooool2o`0000?ooooo0_l00005ooooo`;o0000
00?oooooo`000?l000003?ooool2o`0001cooooo0_l000001?oooooo0000o`000?ooool2o`0002_o
oooo0ol0000Aooooo`;o00000_ooool3o`0003;ooooo0_l00003ooooo`;o00001_ooool2o`0001[o
oooo0_l0000Hooooo`;o000000Coooooo`000?l0003ooooo0_l0000Hooooo`00:Oooool00ol0003o
ooooooooo`07ooooo`;o00002Oooool2o`0000;ooooo0_l00006ooooo`;o00000oooool2o`0000Go
oooo0_l00004ooooo`;o00002?ooool3o`0004oooooo0ol00006ooooo`;o00002Oooool2o`0000;o
oooo0_l0000Aooooo`;o00003?ooool2o`0001;ooooo0_l0000@ooooo`;o00001Oooool2o`0000ko
oooo0_l0000Hooooo`;o00007_ooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
00Oooooo0_l0000Gooooo`;o00003_ooool2o`000003ooooool0003o000000Gooooo0_l0000Ioooo
o`;o0000?_ooool2o`0000Cooooo0_l0000Jooooo`;o00001?ooool2o`0000Kooooo0_l0000?oooo
o`;o00004oooool2o`0000Gooooo1?l0000Jooooo`;o00001Oooool2o`0002?ooooo0006ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool08?ooool2o`0000Kooooo0_l00009
ooooo`;o00002Oooool2o`0001Gooooo0_l0000looooo`;o000000?oooooo`000?l000000oooool2
o`00023ooooo0_l00006ooooo`;o000000?oooooo`000?l000003?ooool4o`0001[ooooo0_l0000<
ooooo`;o00003?ooool2o`0000Gooooo0_l00002ooooo`;o00007oooool000Kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Xooooo`;o00005?ooool2o`0003Oooooo0_l0000Jooooo`Go0000<?ooool2
o`0000kooooo0_l0000Xooooo`;o00005oooool2o`0001oooooo0006ooooo`05o`000?oooooooooo
ooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0001g
ooooo`;o00007?ooool2o`0001cooooo0_l00027ooooo`001_ooool01Ol0003ooooooooooooooooo
000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool04oooool2o`0006Gooooo0_l0000gooooo`;o0000;oooool3o`0005Gooooo0006
ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool04oooool2o`00023ooooo0_l0000Wooooo`;o00006_oo
ool2o`0001gooooo0_l00019ooooo`?o0000EOooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo03Gooooo0_l0000Wooooo`;o0000>Oooool2o`00013ooooo0_l0000Looooo`;o0000
A?ooool2o`0002_ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@
o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo023ooooo0_l0001Eooooo`;o
0000<_ooool2o`0001cooooo0_l00014ooooo`;o0000:oooool002Wooooo0_l0000Qooooo`;o0000
9?ooool2o`0002oooooo0_l0000Tooooo`;o00004_ooool2o`0008Wooooo000Yooooo`03o`000?oo
oooooooo04Kooooo0_l0001Eooooo`;o00004_ooool2o`0008Wooooo000Yooooo`03o`000?oooooo
oooo01[ooooo0_l0002Dooooo`;o0000=oooool2o`0000Gooooo0_l0001:ooooo`00:Oooool00ol0
003oooooooooo`0Jooooo`Co00006Oooool2o`00033ooooo0_l00004ooooo`;o00005?ooool2o`00
02Wooooo1?l0000eooooo`;o00001Oooool2o`0004[ooooo000Yooooo`03o`000?oooooooooo01co
oooo0_l0000Iooooo`;o0000<?ooool2o`0000Cooooo0ol0000Cooooo`;o00008Oooool2o`0000So
oooo0_l00028ooooo`00:Oooool2o`0004cooooo0_l0000Sooooo`;o0000=_ooool2o`00013ooooo
0_l00019ooooo`;o00009Oooool2o`0000kooooo000Yooooo`03o`000?oooooooooo03Sooooo0_l0
000;ooooo`;o00001?ooool2o`0000Kooooo0_l0000oooooo`;o00008_ooool4o`0004Wooooo0_l0
000Uooooo`;o00003_ooool002Wooooo00?o0000ooooooooool04?ooool2o`0002Kooooo0_l00007
ooooo`;o00000_ooool2o`0000cooooo0_l0000oooooo`;o00008_ooool2o`0001_ooooo0_l0000<
ooooo`;o0000Eoooool002Wooooo00?o0000ooooooooool04?ooool2o`0001?ooooo0_l0000Joooo
o`;o00004oooool2o`0000Kooooo0_l00003ooooo`;o0000L?ooool2o`0000cooooo0_l00012oooo
o`;o00004oooool002Wooooo00?o0000ooooooooool00_ooool2o`00027ooooo0_l00009ooooo`;o
00009?ooool2o`0000Kooooo0_l00003ooooo`;o00002_ooool2o`000;Kooooo0_l0000Cooooo`00
:Oooool2o`0000?ooooo0_l0000Kooooo`;o00003oooool2o`0003gooooo0_l00003ooooo`;o0000
COooool2o`0004Cooooo0_l0000=ooooo`;o00008_ooool002Wooooo00Co0000oooooooooooooooo
0_l0000Looooo`;o0000Doooool2o`0003kooooo0_l0000=ooooo`;o00003?ooool2o`0003Kooooo
0_l00008ooooo`;o00000oooool2o`0002;ooooo000Yooooo`04o`000?ooooooooooooooo`;o0000
3Oooool2o`0000gooooo0_l0001kooooo`;o00005_ooool2o`0001_ooooo0_l0000<ooooo`;o0000
4?ooool2o`00023ooooo0_l0000Wooooo`00:Oooool00ol0003oooooooooo`0@ooooo`;o00003Ooo
ool2o`0000?ooooo0_l0000>ooooo`;o00007?ooool2o`0001Gooooo0_l00009ooooo`;o00006ooo
ool2o`0000Wooooo0_l0000Rooooo`Co00001?ooool2o`00017ooooo0_l00002ooooo`;o00004?oo
ool2o`0000?ooooo0_l00009ooooo`;o00005_ooool2o`00027ooooo000Yooooo`03o`000?oooooo
oooo00Gooooo0_l00005ooooo`;o00005?ooool4o`0000kooooo0_l0000Looooo`?o00005?ooool2
o`0000Wooooo0_l0000>ooooo`;o00001?ooool2o`0000Gooooo0_l0000Iooooo`;o00001?ooool2
o`000003ooooool0003o000000Wooooo1?l00004ooooo`;o00003?ooool2o`0000;ooooo0ol00002
ooooo`;o00002_ooool2o`0000Wooooo0_l00009ooooo`;o00001_ooool2o`0000kooooo0_l0000Q
ooooo`00:Oooool2o`0000Gooooo0ol00005ooooo`;o00001oooool2o`0000_ooooo0_l0000Goooo
o`;o00004Oooool2o`0000?ooooo0_l0000Qooooo`;o00003?ooool2o`0000Cooooo0_l0000Poooo
o`;o00001?ooool2o`000003ooooool0003o000001oooooo0_l00002ooooo`Co000000?oooooo`00
0?l000001_ooool2o`0000;ooooo0_l0000:ooooo`;o00004?ooool2o`0002Cooooo0_l0000;oooo
o`00:Oooool00ol0003oooooooooo`04ooooo`;o00003oooool2o`0002Cooooo0_l0000Aooooo`;o
00007?ooool2o`0000?ooooo0_l00003ooooo`;o00005_ooool2o`0002Wooooo0_l00006ooooo`;o
00006Oooool2o`0000Wooooo0_l00003ooooo`;o00001?ooool2o`0000?ooooo0_l0000<ooooo`;o
0000:?ooool2o`0000_ooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Go
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01Gooooo0_l0000`oooo
o`;o00006?ooool2o`0000Wooooo1?l000001?oooooo0000o`000?l0000>ooooo`;o00002_ooool2
o`0000Oooooo0_l0000Pooooo`;o00001_ooool2o`0001Wooooo0ol0000=ooooo`;o00001?ooool2
o`00017ooooo0_l0000Iooooo`;o00006_ooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo04Oooooo0_l0000H
ooooo`;o00002oooool2o`0000;ooooo0_l000000ooooooo0000o`00000;ooooo`;o00001_ooool2
o`0000_ooooo0_l00014ooooo`;o00006oooool2o`0000Cooooo0_l0000Hooooo`;o00001?ooool2
o`0001[ooooo000>ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03
ooooo`?o0000FOooool2o`0001[ooooo0_l0000Cooooo`;o0000<_ooool2o`0003[ooooo0_l00004
ooooo`;o00006?ooool2o`00023ooooo000>ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo05Wooooo0_l0001Sooooo`;o0000O?ooool0
00kooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooo
oolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000oooo
oolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooo
oolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400=
ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool0
00Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05o`000?oooooooooo
ooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003_oo
ool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooo
oolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooo
oc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo
?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo
?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Oooooo`Co000000?o410@oooo
ooooool00oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`?o0000
oooooolmooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Oooooo`03oeEEEOmVIVKo00000?ooooooAoooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .36923 Mdot
.02762 .35444 Mdot
.02952 .31271 Mdot
.03143 .3185 Mdot
.03333 .26451 Mdot
.03524 .38963 Mdot
.03714 .28063 Mdot
.03905 .37588 Mdot
.04095 .3779 Mdot
.04286 .34853 Mdot
.04476 .34014 Mdot
.04667 .41066 Mdot
.04857 .32242 Mdot
.05048 .35108 Mdot
.05238 .43377 Mdot
.05429 .33614 Mdot
.05619 .36476 Mdot
.0581 .32096 Mdot
.06 .31348 Mdot
.0619 .2345 Mdot
.06381 .27996 Mdot
.06571 .31612 Mdot
.06762 .27582 Mdot
.06952 .30467 Mdot
.07143 .44344 Mdot
.07333 .2516 Mdot
.07524 .31831 Mdot
.07714 .29921 Mdot
.07905 .23145 Mdot
.08095 .33491 Mdot
.08286 .24384 Mdot
.08476 .36307 Mdot
.08667 .38832 Mdot
.08857 .3792 Mdot
.09048 .3836 Mdot
.09238 .23841 Mdot
.09429 .30168 Mdot
.09619 .30308 Mdot
.0981 .25945 Mdot
.1 .40464 Mdot
.1019 .43491 Mdot
.10381 .38098 Mdot
.10571 .38794 Mdot
.10762 .38316 Mdot
.10952 .38669 Mdot
.11143 .2507 Mdot
.11333 .34186 Mdot
.11524 .32889 Mdot
.11714 .291 Mdot
.11905 .24211 Mdot
.12095 .33572 Mdot
.12286 .25208 Mdot
.12476 .438 Mdot
.12667 .38596 Mdot
.12857 .38767 Mdot
.13048 .38607 Mdot
.13238 .3859 Mdot
.13429 .35807 Mdot
.13619 .31496 Mdot
.1381 .38829 Mdot
.14 .24858 Mdot
.1419 .46241 Mdot
.14381 .27539 Mdot
.14571 .26062 Mdot
.14762 .41183 Mdot
.14952 .36837 Mdot
.15143 .34719 Mdot
.15333 .33941 Mdot
.15524 .31826 Mdot
.15714 .28293 Mdot
.15905 .34627 Mdot
.16095 .29769 Mdot
.16286 .34471 Mdot
.16476 .34721 Mdot
.16667 .2757 Mdot
.16857 .30085 Mdot
.17048 .43765 Mdot
.17238 .2732 Mdot
.17429 .24362 Mdot
.17619 .33112 Mdot
.1781 .23453 Mdot
.18 .32921 Mdot
.1819 .31846 Mdot
.18381 .38088 Mdot
.18571 .36826 Mdot
.18762 .32646 Mdot
.18952 .26296 Mdot
.19143 .2501 Mdot
.19333 .34448 Mdot
.19524 .34074 Mdot
.19714 .44558 Mdot
.19905 .45819 Mdot
.20095 .26192 Mdot
.20286 .25164 Mdot
.20476 .26263 Mdot
.20667 .46572 Mdot
.20857 .35088 Mdot
.21048 .3595 Mdot
.21238 .43739 Mdot
.21429 .33306 Mdot
.21619 .36047 Mdot
.2181 .32591 Mdot
.22 .41884 Mdot
.2219 .37553 Mdot
.22381 .25236 Mdot
.22571 .38025 Mdot
.22762 .35923 Mdot
.22952 .30896 Mdot
.23143 .26176 Mdot
.23333 .27129 Mdot
.23524 .35053 Mdot
.23714 .30612 Mdot
.23905 .36544 Mdot
.24095 .2339 Mdot
.24286 .3989 Mdot
.24476 .32702 Mdot
.24667 .2535 Mdot
.24857 .35096 Mdot
.25048 .35191 Mdot
.25238 .32652 Mdot
.25429 .31506 Mdot
.25619 .45732 Mdot
.2581 .25633 Mdot
.26 .23105 Mdot
.2619 .27675 Mdot
.26381 .32756 Mdot
.26571 .23223 Mdot
.26762 .46709 Mdot
.26952 .32581 Mdot
.27143 .29884 Mdot
.27333 .29792 Mdot
.27524 .34889 Mdot
.27714 .42222 Mdot
.27905 .39291 Mdot
.28095 .38851 Mdot
.28286 .23256 Mdot
.28476 .26017 Mdot
.28667 .23243 Mdot
.28857 .34398 Mdot
.29048 .40433 Mdot
.29238 .43209 Mdot
.29429 .46234 Mdot
.29619 .27823 Mdot
.2981 .32036 Mdot
.3 .36367 Mdot
.3019 .23525 Mdot
.30381 .36172 Mdot
.30571 .38144 Mdot
.30762 .26392 Mdot
.30952 .24998 Mdot
.31143 .44798 Mdot
.31333 .31684 Mdot
.31524 .33532 Mdot
.31714 .31103 Mdot
.31905 .29185 Mdot
.32095 .37617 Mdot
.32286 .2704 Mdot
.32476 .26506 Mdot
.32667 .36271 Mdot
.32857 .31198 Mdot
.33048 .26766 Mdot
.33238 .26411 Mdot
.33429 .23743 Mdot
.33619 .41481 Mdot
.3381 .23756 Mdot
.34 .38264 Mdot
.3419 .34912 Mdot
.34381 .36346 Mdot
.34571 .25181 Mdot
.34762 .31842 Mdot
.34952 .24903 Mdot
.35143 .24808 Mdot
.35333 .28968 Mdot
.35524 .31332 Mdot
.35714 .25242 Mdot
.35905 .26918 Mdot
.36095 .40186 Mdot
.36286 .46556 Mdot
.36476 .37515 Mdot
.36667 .318 Mdot
.36857 .23771 Mdot
.37048 .24052 Mdot
.37238 .41541 Mdot
.37429 .34257 Mdot
.37619 .43645 Mdot
.3781 .28357 Mdot
.38 .38424 Mdot
.3819 .46435 Mdot
.38381 .34311 Mdot
.38571 .41519 Mdot
.38762 .38952 Mdot
.38952 .45344 Mdot
.39143 .23652 Mdot
.39333 .26171 Mdot
.39524 .46098 Mdot
.39714 .3744 Mdot
.39905 .43692 Mdot
.40095 .41953 Mdot
.40286 .25167 Mdot
.40476 .46331 Mdot
.40667 .36281 Mdot
.40857 .32222 Mdot
.41048 .32178 Mdot
.41238 .30178 Mdot
.41429 .2552 Mdot
.41619 .45999 Mdot
.4181 .34645 Mdot
.42 .26509 Mdot
.4219 .38705 Mdot
.42381 .28971 Mdot
.42571 .29048 Mdot
.42762 .34395 Mdot
.42952 .33534 Mdot
.43143 .2674 Mdot
.43333 .25014 Mdot
.43524 .34352 Mdot
.43714 .34533 Mdot
.43905 .26761 Mdot
.44095 .41866 Mdot
.44286 .29775 Mdot
.44476 .37691 Mdot
.44667 .39554 Mdot
.44857 .25121 Mdot
.45048 .34101 Mdot
.45238 .2598 Mdot
.45429 .2353 Mdot
.45619 .34326 Mdot
.4581 .27115 Mdot
.46 .37093 Mdot
.4619 .27766 Mdot
.46381 .43366 Mdot
.46571 .45716 Mdot
.46762 .3279 Mdot
.46952 .2722 Mdot
.47143 .4499 Mdot
.47333 .3306 Mdot
.47524 .33124 Mdot
.47714 .45639 Mdot
.47905 .31091 Mdot
.48095 .37422 Mdot
.48286 .28001 Mdot
.48476 .35357 Mdot
.48667 .46243 Mdot
.48857 .39163 Mdot
.49048 .24925 Mdot
.49238 .34623 Mdot
.49429 .35094 Mdot
.49619 .26628 Mdot
.4981 .2933 Mdot
.5 .3598 Mdot
.5019 .3445 Mdot
.50381 .26758 Mdot
.50571 .4377 Mdot
.50762 .32662 Mdot
.50952 .26215 Mdot
.51143 .30882 Mdot
.51333 .26656 Mdot
.51524 .31244 Mdot
.51714 .38776 Mdot
.51905 .29849 Mdot
.52095 .39225 Mdot
.52286 .32072 Mdot
.52476 .30972 Mdot
.52667 .33192 Mdot
.52857 .23534 Mdot
.53048 .31176 Mdot
.53238 .32608 Mdot
.53429 .36575 Mdot
.53619 .33542 Mdot
.5381 .38071 Mdot
.54 .24477 Mdot
.5419 .2903 Mdot
.54381 .23322 Mdot
.54571 .38831 Mdot
.54762 .34945 Mdot
.54952 .32104 Mdot
.55143 .26242 Mdot
.55333 .34183 Mdot
.55524 .29984 Mdot
.55714 .34362 Mdot
.55905 .34881 Mdot
.56095 .38271 Mdot
.56286 .23773 Mdot
.56476 .31787 Mdot
.56667 .34576 Mdot
.56857 .31786 Mdot
.57048 .4125 Mdot
.57238 .31039 Mdot
.57429 .28635 Mdot
.57619 .25212 Mdot
.5781 .24334 Mdot
.58 .24928 Mdot
.5819 .23494 Mdot
.58381 .46276 Mdot
.58571 .32543 Mdot
.58762 .42692 Mdot
.58952 .34253 Mdot
.59143 .26985 Mdot
.59333 .29259 Mdot
.59524 .45908 Mdot
.59714 .2523 Mdot
.59905 .43195 Mdot
.60095 .37244 Mdot
.60286 .30588 Mdot
.60476 .39092 Mdot
.60667 .35377 Mdot
.60857 .3565 Mdot
.61048 .43813 Mdot
.61238 .3432 Mdot
.61429 .35001 Mdot
.61619 .26733 Mdot
.6181 .32455 Mdot
.62 .3243 Mdot
.6219 .36557 Mdot
.62381 .30824 Mdot
.62571 .44656 Mdot
.62762 .32275 Mdot
.62952 .37265 Mdot
.63143 .38049 Mdot
.63333 .41515 Mdot
.63524 .31834 Mdot
.63714 .41959 Mdot
.63905 .45456 Mdot
.64095 .46716 Mdot
.64286 .33104 Mdot
.64476 .39456 Mdot
.64667 .37996 Mdot
.64857 .28366 Mdot
.65048 .28295 Mdot
.65238 .32676 Mdot
.65429 .27315 Mdot
.65619 .35853 Mdot
.6581 .38808 Mdot
.66 .31823 Mdot
.6619 .26067 Mdot
.66381 .3298 Mdot
.66571 .30224 Mdot
.66762 .30397 Mdot
.66952 .36837 Mdot
.67143 .39111 Mdot
.67333 .38287 Mdot
.67524 .26624 Mdot
.67714 .2552 Mdot
.67905 .44897 Mdot
.68095 .28147 Mdot
.68286 .32177 Mdot
.68476 .26149 Mdot
.68667 .39091 Mdot
.68857 .3188 Mdot
.69048 .23281 Mdot
.69238 .30462 Mdot
.69429 .26541 Mdot
.69619 .26398 Mdot
.6981 .46312 Mdot
.7 .40491 Mdot
.7019 .27835 Mdot
.70381 .23741 Mdot
.70571 .28979 Mdot
.70762 .36813 Mdot
.70952 .2421 Mdot
.71143 .32726 Mdot
.71333 .40625 Mdot
.71524 .46981 Mdot
.71714 .24799 Mdot
.71905 .42312 Mdot
.72095 .42172 Mdot
.72286 .42872 Mdot
.72476 .31163 Mdot
.72667 .32497 Mdot
.72857 .43387 Mdot
.73048 .38799 Mdot
.73238 .31318 Mdot
.73429 .23901 Mdot
.73619 .30081 Mdot
.7381 .39045 Mdot
.74 .36253 Mdot
.7419 .3653 Mdot
.74381 .37281 Mdot
.74571 .3032 Mdot
.74762 .30976 Mdot
.74952 .27599 Mdot
.75143 .26655 Mdot
.75333 .29377 Mdot
.75524 .43974 Mdot
.75714 .39749 Mdot
.75905 .33728 Mdot
.76095 .38156 Mdot
.76286 .29929 Mdot
.76476 .45035 Mdot
.76667 .33602 Mdot
.76857 .27237 Mdot
.77048 .41302 Mdot
.77238 .28079 Mdot
.77429 .32662 Mdot
.77619 .34747 Mdot
.7781 .25371 Mdot
.78 .32709 Mdot
.7819 .32853 Mdot
.78381 .27793 Mdot
.78571 .46032 Mdot
.78762 .41653 Mdot
.78952 .37257 Mdot
.79143 .44211 Mdot
.79333 .37138 Mdot
.79524 .27457 Mdot
.79714 .28033 Mdot
.79905 .28488 Mdot
.80095 .39097 Mdot
.80286 .41062 Mdot
.80476 .32013 Mdot
.80667 .27504 Mdot
.80857 .34894 Mdot
.81048 .33373 Mdot
.81238 .44414 Mdot
.81429 .25767 Mdot
.81619 .23415 Mdot
.8181 .29472 Mdot
.82 .33117 Mdot
.8219 .31175 Mdot
.82381 .25867 Mdot
.82571 .37813 Mdot
.82762 .33781 Mdot
.82952 .26398 Mdot
.83143 .45356 Mdot
.83333 .40189 Mdot
.83524 .30332 Mdot
.83714 .38452 Mdot
.83905 .35977 Mdot
.84095 .36362 Mdot
.84286 .3066 Mdot
.84476 .31855 Mdot
.84667 .44921 Mdot
.84857 .46924 Mdot
.85048 .36396 Mdot
.85238 .41105 Mdot
.85429 .38475 Mdot
.85619 .26517 Mdot
.8581 .39368 Mdot
.86 .43601 Mdot
.8619 .33332 Mdot
.86381 .29461 Mdot
.86571 .44561 Mdot
.86762 .28025 Mdot
.86952 .32532 Mdot
.87143 .26133 Mdot
.87333 .23393 Mdot
.87524 .31861 Mdot
.87714 .461 Mdot
.87905 .28376 Mdot
.88095 .38484 Mdot
.88286 .37837 Mdot
.88476 .26009 Mdot
.88667 .31835 Mdot
.88857 .34522 Mdot
.89048 .3785 Mdot
.89238 .32454 Mdot
.89429 .23725 Mdot
.89619 .36096 Mdot
.8981 .37951 Mdot
.9 .23245 Mdot
.9019 .23568 Mdot
.90381 .36805 Mdot
.90571 .47178 Mdot
.90762 .34777 Mdot
.90952 .38864 Mdot
.91143 .43527 Mdot
.91333 .33151 Mdot
.91524 .28615 Mdot
.91714 .29941 Mdot
.91905 .36705 Mdot
.92095 .23218 Mdot
.92286 .36421 Mdot
.92476 .30463 Mdot
.92667 .26247 Mdot
.92857 .37818 Mdot
.93048 .46084 Mdot
.93238 .38471 Mdot
.93429 .30775 Mdot
.93619 .38563 Mdot
.9381 .32663 Mdot
.94 .30495 Mdot
.9419 .337 Mdot
.94381 .38623 Mdot
.94571 .39026 Mdot
.94762 .32497 Mdot
.94952 .26842 Mdot
.95143 .3698 Mdot
.95333 .27302 Mdot
.95524 .36661 Mdot
.95714 .33355 Mdot
.95905 .2802 Mdot
.96095 .31852 Mdot
.96286 .41041 Mdot
.96476 .32134 Mdot
.96667 .36165 Mdot
.96857 .35756 Mdot
.97048 .23604 Mdot
.97238 .31599 Mdot
.97429 .23389 Mdot
.97619 .41371 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`18ooooo`;o0000l_oo
ool000Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o
MgMgoc8b<_ooool01?ooool3o`0000kooooo0_l0000booooo`;o00001?ooool4o`0000Cooooo0ol0
001@ooooo`;o0000;_ooool2o`0002Kooooo0_l0000@ooooo`;o00001oooool2o`0000Gooooo0_l0
000?ooooo`;o00003?ooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00Wooooo
0_l00003ooooo`;o00007_ooool2o`0001;ooooo0_l00006ooooo`;o00001?ooool3o`0000?ooooo
0_l0000Jooooo`;o00004oooool2o`0001Kooooo0_l00002ooooo`;o00002oooool2o`00027ooooo
0_l0000Vooooo`;o00004?ooool2o`0000Gooooo1Ol00004ooooo`;o00003_ooool3o`0000cooooo
0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02Oooool2o`0000Oooooo0_l0000Jooooo`;o0000
9_ooool2o`0000Sooooo0ol00008ooooo`;o00001Oooool2o`0001?ooooo0_l0000Fooooo`;o0000
2Oooool2o`0000Cooooo0_l0000Uooooo`;o00002?ooool2o`00037ooooo0_l000000ooooooo0000
o`00000Dooooo`;o00003Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01;o
oooo0_l00007ooooo`;o0000@oooool3o`0000Sooooo0ol0000looooo`;o00000_ooool2o`0002Oo
oooo1?l00006ooooo`;o0000FOooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool03oooool2o`00
00[ooooo0_l0000@ooooo`;o0000?Oooool2o`0003Cooooo0_l0000:ooooo`;o0000:Oooool2o`00
067ooooo000Yooooo`;o00004?ooool2o`00017ooooo0_l00009ooooo`;o0000=_ooool3o`0002[o
oooo0_l0000>ooooo`;o00002oooool2o`0002[ooooo0_l0001Oooooo`00:Oooool00ol0003ooooo
ooooo`0<ooooo`;o00002_ooool2o`0000;ooooo0_l00004ooooo`;o00003_ooool2o`0000;ooooo
0_l00005ooooo`;o00006Oooool2o`0000[ooooo1Ol0000=ooooo`;o00002?ooool2o`0000?ooooo
0_l0000;ooooo`;o00006_ooool3o`0000Cooooo0_l0000Tooooo`;o0000Goooool002Wooooo00?o
0000ooooooooool03?ooool2o`0000[ooooo0_l00002ooooo`;o00005?ooool2o`0000;ooooo0_l0
0005ooooo`;o00001Oooool2o`0001;ooooo0_l0000:ooooo`;o000000?oooooo`000?l000003Ooo
ool2o`0000;ooooo0_l00004ooooo`;o00000oooool2o`0002Oooooo0_l00005ooooo`;o00005ooo
ool2o`0001oooooo0_l0001;ooooo`00:Oooool00ol0003oooooooooo`14ooooo`;o00000_ooool2
o`00033ooooo0_l0001Booooo`;o00007oooool2o`0000Wooooo0_l00002ooooo`;o0000??ooool0
02Wooooo00?o0000ooooooooool05?ooool2o`0000gooooo0_l0000@ooooo`;o00002?ooool2o`00
00Oooooo0_l00006ooooo`;o00008Oooool2o`00017ooooo0_l0000@ooooo`;o0000;oooool2o`00
00Kooooo0_l0000Wooooo`;o00000_ooool2o`0000gooooo0_l00002ooooo`;o0000:Oooool002Wo
oooo1?l0000Cooooo`;o00003Oooool2o`0000gooooo0_l000001?oooooo0000o`000?l00007oooo
o`;o00003oooool2o`0000Kooooo0_l00003ooooo`Co00004_ooool2o`0000Oooooo0_l00008oooo
o`;o00004?ooool2o`0000cooooo0_l0000Qooooo`;o00001_ooool2o`000003ooooool0003o0000
02Wooooo0_l00007ooooo`;o00000oooool2o`0000;ooooo0_l0000<ooooo`;o00006oooool002Wo
oooo00Co0000ooooool0003o0000<Oooool2o`0000;ooooo0_l0000Pooooo`;o00000oooool4o`00
01_ooooo0_l000001?oooooo0000o`000?ooool2o`00013ooooo0_l000001?oooooo0000o`000?oo
ool2o`0000[ooooo0_l0000Cooooo`;o00004Oooool2o`0000Cooooo0_l0000@ooooo`;o00005ooo
ool2o`0000Oooooo0_l0000Eooooo`;o00006oooool002Wooooo00?o0000ooooooooool0<?ooool4
o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_l0003o0000oc8b
<_o^k^h06?ooool2o`000003ooooool0003o000000Oooooo0_l00003ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o0000onk^kP02o`0000Cooooo0_l0
000:ooooo`;o000000Coooooo`000?l0003ooooo0_l0000>ooooo`05oiRHV?l@413o0000oc8b<_o<
c<`00oooool01Oo^k^ko0000o`000?lb<S;ok^k^00?ooooo00Gok^k^o`000?l0003o<S8bonk^kP0?
ooooo`;o00001?ooool2o`00013ooooo0_l000001?oooooo0000o`000?l@4103ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Wooooo00GoA4A4o`000?l0
003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo000Yooooo`03o`000?oooooooooo02cooooo0_l00004ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMol0003o0000oiRHV?mgMgL0
6?ooool2o`0000[ooooo0_l00003ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`;o00000_ooool2
o`0001cooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMol0003o0000oiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo0_l0000Qooooo`0:o`000?oooooo0000o`00
0?ooooooMgMgoiRHV?ooooooV9RHogMgM`;o000000KoooooogMgMonHV9SooooooiRHV?mgMgLZoooo
o`?o000000So<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`00:Oooool00ol0003oooooooooo`0:ooooo`;o00005oooool2o`0000Gooooo
1?l00004ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@41001Oooool2o`0002?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@
413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4007ooooo`;o000000?o
ooooo`000?l000008?ooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`03oa0@4?oooooooooo00Kooooo0_l0000Mooooo`So000000?ooooooa0@4?oo
ool00_ooool01Ol@413o0000o`000?oooooo410@00;o000000?ooooooa0@4?ooool0:_ooool3o`00
00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool002Wooooo0_l00002ooooo`;o00001_ooool3o`0001Oooooo0_l00005ooooo`;o00001_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000Gooooo0_l00009ooooo`;o00006Oooool00onHV9So8B4Qonk^kP03ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Oooooo0_l00005oooo
o`;o00006oooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000001Oooooo0_l0000>ooooo`;o000000?ogMgMooooool000000_oo
ool3o`000005ooooool0003o0000o`000?ooool01Ol000000ooooooo0000ooooo`0?ooooo`;o0000
6_ooool01OmgMgOo0000o`000?oooooo000000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo007ooooo000Yooooo`04o`000?ooooooooooooooo`;o00001_ooool2o`00
01cooooo0_l00009ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000004?ooool2o`0001Sooooo0_l000000omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000ko
oooo0_l0000Jooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001_ooool3o`0000Sooooo0_l00004ooooo`;o00003oooool0
1?oMgMgoEEEEooooool00002ooooo`?o000000Goooooo`000?l0003o0000ooooo`03o`0000?ooooo
00?o0000ooooooooool03_ooool2o`000003ooooool0003o000001Cooooo00Co0000ob4Q8Ol0003o
<S8b0_l000000ooooooo0000ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`01ooooo`00:Oooool00ol0003oooooooooo`0Wooooo`;o00002Oooool00ol0003o
ooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo
410@02[ooooo0_l000000ooooooo0000ooooo`02ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@02_ooooo0_l00003ooooo`05oa0@4?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@00Kooooo0ol00008ooooo`;o00005_ooool00omg
MgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41000_ooool2o`0000?ooooo00?o410@
ooooooooool04Oooool2o`0000[ooooo0_l00008ooooo`03o`000?oooooooooo00Cooooo00Go410@
oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool002Wooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg02;ooooo0_l00005ooooo`05o`000?nj^[[ooooooiRH
V?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0_l000000oooooooV9RHogMgM`0X
ooooo`03oa0@4?nHV9Sooooo00;o00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0Iooooo`;o00003_ooool00oo^k^koA4A4o`000004ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00_ooool2o`000004oiRHV?ooooooV9RHogMgMaoooooo0_l00008oooo
o`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool002Wooooo00?o0000ooooooooool06_ooool2o`0001Cooooo00?oEEEE
ofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0Gooooo`;o00002Oooool2o`0000Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool3o`000003oc8b<_o^k^kooooo023ooooo0_l00005oooo
o`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko0000o`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0Iooooo`;o00003oooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Wooooo1?l00003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Y
ooooo`;o00006oooool2o`0003oooooo0_l0000Pooooo`;o00005_ooool2o`0000cooooo0_l0000>
ooooo`;o0000<_ooool2o`0001?ooooo0_l0000<ooooo`;o0000<?ooool002Wooooo00?o0000oooo
ooooool03Oooool2o`0001Wooooo0_l0000Rooooo`?o0000=?ooool2o`00013ooooo0_l00005oooo
o`;o0000BOooool2o`000003ooooool0003o0000013ooooo0_l0000<ooooo`;o00004?ooool2o`00
01kooooo000Yooooo`03o`000?oooooooooo00gooooo0_l00004ooooo`;o00004oooool2o`000003
ooooool0003o000001oooooo0ol0000Zooooo`;o00002?ooool2o`0001Oooooo0_l00009ooooo`;o
00008_ooool2o`0001Cooooo0_l00007ooooo`;o0000<?ooool2o`0001kooooo000Yooooo`03o`00
0?oooooooooo00_ooooo0_l00006ooooo`?o00005Oooool2o`0004cooooo0_l0000/ooooo`;o0000
8_ooool2o`0000Kooooo0_l0000<ooooo`;o000000?oooooo`000?l000006oooool2o`0001_ooooo
0_l00003ooooo`;o00005oooool002Wooooo00?o0000ooooooooool02oooool2o`0000Oooooo0_l0
000[ooooo`;o0000E_ooool2o`0001_ooooo0_l00005ooooo`;o00003?ooool2o`0000Kooooo0_l0
000?ooooo`;o00006oooool2o`000003ooooool0003o000001Sooooo0_l000000ooooooo0000o`00
0002o`0001Oooooo000Qoooooooo0000A?l00004ooooo`00:Oooool3o`0000Sooooo0_l0000<oooo
o`03o`000?oooooooooo00Oooooo0ol0000;ooooo`03o`000?oooooooooo00Wooooo00Co0000oooo
oooooooooooo0_l00007ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool2
o`000003ooooool0003o000000Oooooo0_l00002ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`08ooooo`;o00002Oooool7o`0000Sooooo00Co0000
oooooooooooooooo0_l00006ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0:ooooo`04o`000?ooooooooooooooo`Co00000oooool2o`0000_ooooo
00?o0000ooooooooool02?ooool2o`0000cooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool002Wooooo0ol0
0008ooooo`Co00005?ooool2o`0001Sooooo00?o0000ooooooooool02Oooool2o`00017ooooo0_l0
0003ooooo`;o00001oooool2o`0000;ooooo0_l0000;ooooo`03o`000?oooooooooo01oooooo0_l0
000>ooooo`?o00002?ooool00ol0003oooooooooo`0Xooooo`;o00004?ooool00ol0003ooooooooo
o`0hooooo`?o00003?ooool002Wooooo00Co0000ooooool0003o00001_ooool2o`000004ooooool0
003o0000ooooo`;o00006?ooool2o`0000Kooooo0_l0000Eooooo`;o00003?ooool2o`0000?ooooo
0_l00009ooooo`;o00001Oooool2o`00033ooooo0_l00006ooooo`;o00000oooool3o`0001Cooooo
0_l00006ooooo`;o00001oooool2o`0002?ooooo0_l0000;ooooo`;o00002?ooool2o`0000;ooooo
0_l0000Fooooo`;o000000?oooooo`000?l000003Oooool002Wooooo00Co0000ooooool0003o0000
0oooool2o`000003ooooool0003o000000Cooooo0_l0000Hooooo`;o00001_ooool2o`0002?ooooo
0_l0000>ooooo`;o00004_ooool3o`0002;ooooo0_l00006ooooo`;o00005Oooool4o`000003oooo
ool0003o000000Kooooo0_l00005ooooo`Co00008oooool2o`0000_ooooo0_l00008ooooo`;o0000
0_ooool2o`0001Kooooo0ol0000?ooooo`00:Oooool2o`0000Gooooo0_l0000[ooooo`;o00002?oo
ool2o`0000Kooooo0_l000000ooooooo0000o`000003ooooo`;o0000:oooool3o`0001gooooo0_l0
0006ooooo`;o00003oooool2o`0000Sooooo1Ol00006ooooo`;o00002?ooool2o`0000Oooooo0_l0
0003ooooo`;o00003_ooool3o`0001_ooooo0_l00006ooooo`;o00003?ooool2o`000003ooooool0
003o000000Cooooo0_l0000?ooooo`00:Oooool00ol0003oooooooooo`0Jooooo`;o00004_ooool2
o`000003ooooool0003o000000Sooooo0_l00006ooooo`;o000000Coooooo`000?l0003ooooo1?l0
000nooooo`;o00002oooool2o`0000Kooooo0_l0000?ooooo`;o00002?ooool2o`0000Wooooo0_l0
0002ooooo`;o00003Oooool2o`0000?ooooo0_l0000>ooooo`Co00006_ooool2o`0000Kooooo0_l0
000<ooooo`;o000000?oooooo`000?l000005Oooool002Wooooo00?o0000ooooooooool06_ooool2
o`00017ooooo0ol0000:ooooo`;o00003Oooool2o`00043ooooo1?l0000?ooooo`;o00008oooool2
o`0000Gooooo0_l0000Tooooo`;o00002_ooool2o`0000cooooo0_l0000>ooooo`;o00003?ooool2
o`0001;ooooo000Yooooo`03o`000?oooooooooo00Kooooo0_l00007ooooo`;o00002oooool2o`00
00oooooo0_l0000;ooooo`;o00007_ooool2o`0002?ooooo0_l0000<ooooo`;o00003oooool2o`00
0003ooooool0003o0000023ooooo0_l0000Vooooo`;o00003?ooool2o`000003ooooool0003o0000
00cooooo0_l0000>ooooo`;o00003?ooool2o`0001;ooooo000Yooooo`03o`000?oooooooooo00Ko
oooo0_l00007ooooo`;o00002oooool2o`0000Sooooo0_l0000booooo`;o00008oooool2o`00023o
oooo0_l00016ooooo`Co00003?ooool2o`0000Cooooo0_l0000Rooooo`;o00005oooool002Wooooo
0_l00004ooooo`;o00005?ooool2o`0000_ooooo0_l0000;ooooo`;o0000>?ooool2o`0001Kooooo
0_l0000Pooooo`;o00002Oooool2o`0003Gooooo0_l0000Dooooo`;o00008_ooool2o`0001Oooooo
000Yooooo`03o`000?oooooooooo00?ooooo0_l0000Dooooo`;o00003_ooool2o`0000Sooooo0_l0
000Looooo`;o00006_ooool2o`000003ooooool0003o000000cooooo0_l000000ooooooo0000o`00
0002ooooo`Co00003Oooool2o`0000oooooo0ol000000ooooooo0000o`000005ooooo`;o00001_oo
ool2o`0005Kooooo0_l0000Xooooo`00:Oooool00ol0003oooooooooo`02ooooo`;o00008Oooool2
o`000003ooooool0003o000000;o00001oooool2o`0001Sooooo0_l00002ooooo`;o00004?ooool2
o`0000_ooooo0_l00009ooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o00002_oo
ool2o`000003ooooool0003o0000013ooooo0_l000000ooooooo0000o`00000=ooooo`;o0000<_oo
ool2o`0000Wooooo0_l0000Gooooo`;o00001?ooool2o`0002;ooooo000Yooooo`03o`000?oooooo
oooo00;ooooo0_l000000ooooooo0000o`00000Nooooo`;o000000?oooooo`000?l000000_l0000<
ooooo`;o00001_ooool2o`0000?ooooo0_l00006ooooo`;o00005?ooool2o`0001Kooooo0_l0000F
ooooo`?o00003oooool2o`000003ooooool0003o0000013ooooo0_l0000booooo`;o00002Oooool2
o`0001gooooo0_l0000Rooooo`00:Oooool2o`0000Kooooo0_l0000aooooo`;o00001_ooool2o`00
00?ooooo0_l00019ooooo`;o00000_ooool2o`0000oooooo0_l0000Aooooo`Co0000P?ooool002Wo
oooo0_l0000Qooooo`;o0000K_ooool2o`0002Kooooo0_l0000>ooooo`;o0000H_ooool2o`0000ko
oooo000Yooooo`03o`000?oooooooooo023ooooo0_l0000Fooooo`Co00000_ooool2o`0005Gooooo
0_l0000Qooooo`;o00003_ooool2o`0003Sooooo0_l0000Aooooo`;o00005?ooool3o`0000kooooo
000Yooooo`03o`000?oooooooooo00Oooooo0_l00007ooooo`;o00009_ooool4o`0000;ooooo0_l0
000Eooooo`?o00001_ooool2o`0000?ooooo0_l0000Booooo`;o00007?ooool2o`0004cooooo0_l0
000Mooooo`?o000000?oooooo`000?l000003Oooool2o`0000Kooooo0_l0000<ooooo`;o00003ooo
ool002Wooooo00?o0000ooooooooool01oooool2o`0000Oooooo0_l0000_ooooo`;o00004_ooool3
o`0000Kooooo0_l00003ooooo`;o00004_ooool2o`0002Oooooo0_l0000Kooooo`;o00009?ooool2
o`0001kooooo0_l000000ooooooo0000o`00000Dooooo`?o00002Oooool2o`0001;ooooo000Yoooo
o`;o00009_ooool2o`0000Wooooo0_l0000?ooooo`;o0000A_ooool2o`0001Gooooo0_l0000Koooo
o`;o00003Oooool2o`0000[ooooo0_l00009ooooo`;o0000<_ooool2o`0000?ooooo0_l00009oooo
o`?o00004_ooool002Wooooo0_l0000Vooooo`;o00002Oooool2o`0005Oooooo0_l0000[ooooo`;o
00001oooool2o`0000_ooooo0_l0000:ooooo`;o00002_ooool2o`0000cooooo1?l0000Qooooo`;o
00003_ooool2o`0001?ooooo000Yooooo`04o`000?ooooooooooooooo`;o0000>Oooool2o`0001ko
oooo0_l0000<ooooo`;o00002?ooool2o`0000kooooo0_l00009ooooo`;o00009Oooool2o`0000Oo
oooo0_l0000Sooooo`;o00003?ooool4o`0004Kooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool01?l0
003oooooooooooooool3o`0000gooooo0_l0000Yooooo`?o00007Oooool2o`0000cooooo0_l00008
ooooo`;o00003_ooool2o`0000Wooooo0_l0000dooooo`;o0000=oooool2o`00013ooooo0_l00000
0ooooooo0000o`000002o`0000Sooooo0_l0000Kooooo`001_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo00;ooooo0_l0000=ooooo`;o00000oooool3o`0001Oooooo0_l0
000;ooooo`;o00006?ooool2o`0000Wooooo0_l0000nooooo`;o00001Oooool2o`0001Gooooo0_l0
0003ooooo`;o00001_ooool2o`0001[ooooo0_l0000Cooooo`;o00004?ooool2o`000003ooooool0
003o000000;o00002?ooool2o`0001_ooooo0006ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04_oo
ool2o`0000;ooooo0ol00004ooooo`Co00003oooool2o`0002Gooooo0_l00009ooooo`;o00002ooo
ool2o`00037ooooo0_l00005ooooo`;o00005Oooool2o`0000_ooooo0_l0000Jooooo`;o00005ooo
ool2o`0000?ooooo0_l00007ooooo`;o00003_ooool6o`0001Kooooo0006ooooo`05o`000?oooooo
ooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo1Ol0
000>ooooo`Co00000oooool3o`0000?ooooo1_l0000/ooooo`;o00007_ooool4o`0000Wooooo0_l0
000Mooooo`;o00001oooool2o`0002;ooooo0_l0000Eooooo`;o00008Oooool2o`0000?ooooo0_l0
0007ooooo`;o00001oooool2o`0000Gooooo1_l0000Fooooo`001_ooool01Ol0003ooooooooooooo
oooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool00_l0000>ooooo`;o00001Oooool3o`0000Cooooo0_l000000ooooooo0000
o`00000/ooooo`;o00008?ooool2o`0000Wooooo0_l0000Dooooo`;o00001oooool3o`0000Kooooo
0_l0000Aooooo`;o00003oooool2o`0000?ooooo0_l00002ooooo`;o00003?ooool2o`000003oooo
ool0003o000001;ooooo0_l0000Qooooo`;o00002_ooool2o`0001Gooooo0006ooooo`05oa0@4?oo
ooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0C_ooool2o`0003Cooooo0_l0000<ooooo`;o00002?ooool2o`0001Wooooo
0_l0000;ooooo`;o00001oooool2o`0000;ooooo0_l0000?ooooo`;o00004_ooool2o`00017ooooo
0_l0000Jooooo`;o00005Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04?o
oooo0_l00009ooooo`;o0000=?ooool2o`0003kooooo0_l0000Rooooo`;o00007oooool2o`00037o
oooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
00Cooooo1?l00006ooooo`03o`000?oooooooooo04?ooooo0_l0000Tooooo`;o0000OOooool2o`00
01Oooooo0_l0000iooooo`00:Oooool2o`0001Kooooo0_l0000kooooo`;o00005Oooool2o`0006_o
oooo0_l0000Yooooo`;o0000>Oooool002Wooooo00?o0000ooooooooool05Oooool2o`0003_ooooo
0_l00022ooooo`;o00000_ooool2o`00063ooooo000Yooooo`03o`000?oooooooooo00Cooooo0_l0
003Dooooo`;o00006oooool2o`0000kooooo0_l0000Qooooo`;o00004?ooool002Wooooo00?o0000
ooooooooool01?ooool2o`0001kooooo0_l00026ooooo`;o0000?_ooool2o`0000Wooooo0_l0000>
ooooo`;o00008Oooool2o`0000?ooooo0_l0000;ooooo`00:Oooool00ol0003oooooooooo`0Toooo
o`;o0000>oooool2o`0000Wooooo0_l00003ooooo`;o0000>Oooool2o`0001;ooooo0_l0000Zoooo
o`;o00001?ooool2o`0003_ooooo0_l0000;ooooo`00:Oooool2o`0003cooooo0_l0000Tooooo`;o
00002Oooool2o`0000?ooooo0_l00003ooooo`;o00002_ooool2o`0003cooooo0ol0000_ooooo`;o
0000B?ooool002Wooooo00?o0000ooooooooool0>oooool2o`00017ooooo0_l0000Vooooo`;o0000
2_ooool2o`0003gooooo0_l0000Iooooo`;o0000G_ooool002Wooooo00?o0000ooooooooool0C_oo
ool2o`0006;ooooo0_l0000Xooooo`;o0000G_ooool002Wooooo00?o0000ooooooooool0/_ooool2
o`0002Wooooo0_l0001Mooooo`00:Oooool00ol0003oooooooooo`1Cooooo`;o0000H?ooool2o`00
02Kooooo0_l0001Mooooo`00:Oooool2o`0000Kooooo0_l0000>ooooo`;o0000??ooool2o`0003Go
oooo0_l0000Yooooo`;o0000:?ooool2o`0002Sooooo0_l0000?ooooo`;o00008?ooool002Wooooo
00?o0000ooooooooool01Oooool2o`0000kooooo0_l00006ooooo`;o00003?ooool2o`0000cooooo
0_l0000cooooo`;o00001Oooool2o`0001?ooooo0_l0000;ooooo`;o00008?ooool2o`0002Cooooo
0_l0000Xooooo`;o00003oooool2o`00023ooooo000Yooooo`03o`000?oooooooooo01gooooo0_l0
000<ooooo`;o00003?ooool2o`0003?ooooo0_l00005ooooo`;o00008?ooool2o`00023ooooo0_l0
000/ooooo`;o00002_ooool2o`0004Oooooo000Yooooo`03o`000?oooooooooo00cooooo0_l0000V
ooooo`;o0000/Oooool2o`0000[ooooo0_l00005ooooo`;o00003oooool2o`0002oooooo000Yoooo
o`03o`000?oooooooooo00cooooo0_l0000Vooooo`;o00008oooool2o`0006?ooooo0_l0000joooo
o`;o00003oooool2o`0002oooooo000Yooooo`;o0000F_ooool2o`00037ooooo0_l0000`ooooo`;o
00003oooool2o`0001[ooooo0_l0000Hooooo`;o0000=Oooool002Wooooo00?o0000ooooooooool0
L_ooool2o`0001Sooooo0_l0000dooooo`;o00002oooool2o`0001[ooooo0_l0000Cooooo`;o0000
0oooool2o`0003Gooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo04Oooooo0_l0000Yooooo`;o
00005_ooool2o`0000;ooooo0_l0000booooo`;o0000??ooool2o`0003[ooooo000>ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`0eooooo`;o00004?ooool2o`0002_ooooo0_l00004ooooo`;o00003_ooool2o`0000;o
oooo0_l0000Tooooo`;o0000>oooool2o`0001cooooo0_l0000?ooooo`;o00006_ooool000kooooo
00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0000Rooooo`;o
00004Oooool2o`0001cooooo0_l0000Oooooo`;o000000Coooooo`000?l0003ooooo0_l0000Eoooo
o`;o00007Oooool2o`0000;ooooo0_l0000Oooooo`;o00006_ooool2o`0001cooooo0_l0000?oooo
o`;o00006_ooool000kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool08_ooool2o`0001?ooooo0_l0000Booooo`;o00001_ooool2o`00
01Cooooo0_l00004ooooo`;o00001_ooool2o`0001Sooooo0_l0000Mooooo`;o00004Oooool2o`00
013ooooo0_l0001Uooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo03Oooooo0_l0000Booooo`;o00007?ooool2
o`0000Cooooo0_l0001Booooo`;o00005_ooool2o`0002Sooooo0_l0000eooooo`003_ooool01Ol@
413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3K
ooooo`;o0000:?ooool2o`00017ooooo0_l0000Rooooo`003_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooooaWooooo0_l0000R
ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000ooooooln
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000ooooooln
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400=oooo
o`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000Ko
oooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b
<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Oooooo`Co000000?o410@oooooooo
ool00oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`?o0000oooo
oolmooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Oooooo`03oeEEEOmVIVKo00000?ooooooAoooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .39887 Mdot
.02762 .40087 Mdot
.02952 .28996 Mdot
.03143 .26413 Mdot
.03333 .33405 Mdot
.03524 .38197 Mdot
.03714 .27665 Mdot
.03905 .26758 Mdot
.04095 .27658 Mdot
.04286 .33036 Mdot
.04476 .34898 Mdot
.04667 .3228 Mdot
.04857 .3928 Mdot
.05048 .33425 Mdot
.05238 .37184 Mdot
.05429 .28453 Mdot
.05619 .30311 Mdot
.0581 .39233 Mdot
.06 .35534 Mdot
.0619 .3258 Mdot
.06381 .36887 Mdot
.06571 .38614 Mdot
.06762 .36353 Mdot
.06952 .38409 Mdot
.07143 .3893 Mdot
.07333 .28308 Mdot
.07524 .35126 Mdot
.07714 .34999 Mdot
.07905 .30208 Mdot
.08095 .39322 Mdot
.08286 .33513 Mdot
.08476 .25685 Mdot
.08667 .28794 Mdot
.08857 .34314 Mdot
.09048 .34435 Mdot
.09238 .28136 Mdot
.09429 .23026 Mdot
.09619 .34992 Mdot
.0981 .25052 Mdot
.1 .31054 Mdot
.1019 .36581 Mdot
.10381 .34034 Mdot
.10571 .3704 Mdot
.10762 .40162 Mdot
.10952 .39723 Mdot
.11143 .31644 Mdot
.11333 .34472 Mdot
.11524 .2321 Mdot
.11714 .24751 Mdot
.11905 .27152 Mdot
.12095 .23543 Mdot
.12286 .25643 Mdot
.12476 .48017 Mdot
.12667 .36637 Mdot
.12857 .35384 Mdot
.13048 .28699 Mdot
.13238 .28187 Mdot
.13429 .28817 Mdot
.13619 .22946 Mdot
.1381 .39558 Mdot
.14 .30081 Mdot
.1419 .42691 Mdot
.14381 .23991 Mdot
.14571 .30268 Mdot
.14762 .3315 Mdot
.14952 .26228 Mdot
.15143 .33257 Mdot
.15333 .29628 Mdot
.15524 .35461 Mdot
.15714 .37179 Mdot
.15905 .26722 Mdot
.16095 .26775 Mdot
.16286 .33897 Mdot
.16476 .31998 Mdot
.16667 .23977 Mdot
.16857 .31306 Mdot
.17048 .48007 Mdot
.17238 .25889 Mdot
.17429 .26734 Mdot
.17619 .25754 Mdot
.1781 .31138 Mdot
.18 .39037 Mdot
.1819 .26481 Mdot
.18381 .33755 Mdot
.18571 .25942 Mdot
.18762 .26781 Mdot
.18952 .33279 Mdot
.19143 .29793 Mdot
.19333 .26689 Mdot
.19524 .30141 Mdot
.19714 .39607 Mdot
.19905 .47294 Mdot
.20095 .28839 Mdot
.20286 .31744 Mdot
.20476 .28766 Mdot
.20667 .46958 Mdot
.20857 .33356 Mdot
.21048 .25468 Mdot
.21238 .48069 Mdot
.21429 .25456 Mdot
.21619 .39803 Mdot
.2181 .25047 Mdot
.22 .33909 Mdot
.2219 .40233 Mdot
.22381 .3482 Mdot
.22571 .34606 Mdot
.22762 .28755 Mdot
.22952 .35494 Mdot
.23143 .28868 Mdot
.23333 .36378 Mdot
.23524 .32905 Mdot
.23714 .2588 Mdot
.23905 .25983 Mdot
.24095 .32059 Mdot
.24286 .47032 Mdot
.24476 .31556 Mdot
.24667 .28204 Mdot
.24857 .24329 Mdot
.25048 .2447 Mdot
.25238 .23397 Mdot
.25429 .38889 Mdot
.25619 .4101 Mdot
.2581 .34891 Mdot
.26 .30877 Mdot
.2619 .36774 Mdot
.26381 .27326 Mdot
.26571 .30393 Mdot
.26762 .46472 Mdot
.26952 .387 Mdot
.27143 .32918 Mdot
.27333 .37723 Mdot
.27524 .39554 Mdot
.27714 .34364 Mdot
.27905 .37855 Mdot
.28095 .37516 Mdot
.28286 .29218 Mdot
.28476 .24751 Mdot
.28667 .29766 Mdot
.28857 .33931 Mdot
.29048 .31483 Mdot
.29238 .3666 Mdot
.29429 .45154 Mdot
.29619 .26651 Mdot
.2981 .35602 Mdot
.3 .30034 Mdot
.3019 .32672 Mdot
.30381 .25265 Mdot
.30571 .46333 Mdot
.30762 .32994 Mdot
.30952 .2968 Mdot
.31143 .38395 Mdot
.31333 .24655 Mdot
.31524 .35494 Mdot
.31714 .38774 Mdot
.31905 .26889 Mdot
.32095 .39229 Mdot
.32286 .24099 Mdot
.32476 .24582 Mdot
.32667 .25482 Mdot
.32857 .23036 Mdot
.33048 .24255 Mdot
.33238 .26406 Mdot
.33429 .27798 Mdot
.33619 .32481 Mdot
.3381 .285 Mdot
.34 .37814 Mdot
.3419 .394 Mdot
.34381 .25478 Mdot
.34571 .3482 Mdot
.34762 .35429 Mdot
.34952 .25861 Mdot
.35143 .2637 Mdot
.35333 .262 Mdot
.35524 .35207 Mdot
.35714 .31648 Mdot
.35905 .33535 Mdot
.36095 .31156 Mdot
.36286 .46835 Mdot
.36476 .39192 Mdot
.36667 .32387 Mdot
.36857 .27914 Mdot
.37048 .27083 Mdot
.37238 .32894 Mdot
.37429 .29755 Mdot
.37619 .36845 Mdot
.3781 .3266 Mdot
.38 .28707 Mdot
.3819 .46553 Mdot
.38381 .23868 Mdot
.38571 .32612 Mdot
.38762 .36969 Mdot
.38952 .40158 Mdot
.39143 .32999 Mdot
.39333 .30598 Mdot
.39524 .42933 Mdot
.39714 .2665 Mdot
.39905 .36581 Mdot
.40095 .33946 Mdot
.40286 .31671 Mdot
.40476 .47667 Mdot
.40667 .2923 Mdot
.40857 .31756 Mdot
.41048 .3186 Mdot
.41238 .26768 Mdot
.41429 .32178 Mdot
.41619 .47837 Mdot
.4181 .39396 Mdot
.42 .31233 Mdot
.4219 .38655 Mdot
.42381 .25999 Mdot
.42571 .3304 Mdot
.42762 .34806 Mdot
.42952 .39761 Mdot
.43143 .26359 Mdot
.43333 .34634 Mdot
.43524 .30529 Mdot
.43714 .39292 Mdot
.43905 .26377 Mdot
.44095 .33183 Mdot
.44286 .33134 Mdot
.44476 .3957 Mdot
.44667 .29551 Mdot
.44857 .28765 Mdot
.45048 .23968 Mdot
.45238 .35588 Mdot
.45429 .29509 Mdot
.45619 .31156 Mdot
.4581 .33842 Mdot
.46 .40522 Mdot
.4619 .26811 Mdot
.46381 .37122 Mdot
.46571 .40648 Mdot
.46762 .27138 Mdot
.46952 .30578 Mdot
.47143 .47728 Mdot
.47333 .25509 Mdot
.47524 .35263 Mdot
.47714 .41009 Mdot
.47905 .35193 Mdot
.48095 .40296 Mdot
.48286 .36787 Mdot
.48476 .39678 Mdot
.48667 .43002 Mdot
.48857 .37257 Mdot
.49048 .34634 Mdot
.49238 .2672 Mdot
.49429 .2445 Mdot
.49619 .28119 Mdot
.4981 .23231 Mdot
.5 .29569 Mdot
.5019 .26511 Mdot
.50381 .24432 Mdot
.50571 .36851 Mdot
.50762 .31591 Mdot
.50952 .29425 Mdot
.51143 .23075 Mdot
.51333 .26286 Mdot
.51524 .35156 Mdot
.51714 .34617 Mdot
.51905 .3141 Mdot
.52095 .29274 Mdot
.52286 .22999 Mdot
.52476 .24608 Mdot
.52667 .35259 Mdot
.52857 .29377 Mdot
.53048 .32827 Mdot
.53238 .25105 Mdot
.53429 .39702 Mdot
.53619 .3479 Mdot
.5381 .38535 Mdot
.54 .26901 Mdot
.5419 .24924 Mdot
.54381 .29813 Mdot
.54571 .35326 Mdot
.54762 .32336 Mdot
.54952 .25018 Mdot
.55143 .24634 Mdot
.55333 .29387 Mdot
.55524 .35321 Mdot
.55714 .24011 Mdot
.55905 .34373 Mdot
.56095 .39048 Mdot
.56286 .27848 Mdot
.56476 .32935 Mdot
.56667 .32319 Mdot
.56857 .23126 Mdot
.57048 .32743 Mdot
.57238 .35561 Mdot
.57429 .27166 Mdot
.57619 .31102 Mdot
.5781 .34052 Mdot
.58 .30018 Mdot
.5819 .31249 Mdot
.58381 .46603 Mdot
.58571 .2322 Mdot
.58762 .35719 Mdot
.58952 .24116 Mdot
.59143 .29799 Mdot
.59333 .2308 Mdot
.59524 .43135 Mdot
.59714 .35095 Mdot
.59905 .36806 Mdot
.60095 .45933 Mdot
.60286 .24646 Mdot
.60476 .35574 Mdot
.60667 .39759 Mdot
.60857 .24969 Mdot
.61048 .37491 Mdot
.61238 .34494 Mdot
.61429 .24526 Mdot
.61619 .26194 Mdot
.6181 .30886 Mdot
.62 .39206 Mdot
.6219 .30403 Mdot
.62381 .38489 Mdot
.62571 .38198 Mdot
.62762 .32231 Mdot
.62952 .39645 Mdot
.63143 .34393 Mdot
.63333 .33716 Mdot
.63524 .32707 Mdot
.63714 .33674 Mdot
.63905 .41586 Mdot
.64095 .45022 Mdot
.64286 .27736 Mdot
.64476 .3752 Mdot
.64667 .33273 Mdot
.64857 .23598 Mdot
.65048 .34626 Mdot
.65238 .30286 Mdot
.65429 .28601 Mdot
.65619 .28699 Mdot
.6581 .28421 Mdot
.66 .23209 Mdot
.6619 .29391 Mdot
.66381 .39403 Mdot
.66571 .32995 Mdot
.66762 .26805 Mdot
.66952 .4048 Mdot
.67143 .3784 Mdot
.67333 .37807 Mdot
.67524 .26209 Mdot
.67714 .32135 Mdot
.67905 .48219 Mdot
.68095 .25282 Mdot
.68286 .38621 Mdot
.68476 .29371 Mdot
.68667 .29355 Mdot
.68857 .35093 Mdot
.69048 .29637 Mdot
.69238 .37893 Mdot
.69429 .28021 Mdot
.69619 .26804 Mdot
.6981 .45009 Mdot
.7 .31235 Mdot
.7019 .23545 Mdot
.70381 .28332 Mdot
.70571 .24845 Mdot
.70762 .30506 Mdot
.70952 .27263 Mdot
.71143 .25221 Mdot
.71333 .31487 Mdot
.71524 .44616 Mdot
.71714 .34499 Mdot
.71905 .34581 Mdot
.72095 .34056 Mdot
.72286 .35117 Mdot
.72476 .2709 Mdot
.72667 .2516 Mdot
.72857 .37098 Mdot
.73048 .28552 Mdot
.73238 .27189 Mdot
.73429 .32729 Mdot
.73619 .24801 Mdot
.7381 .38425 Mdot
.74 .3982 Mdot
.7419 .26099 Mdot
.74381 .40259 Mdot
.74571 .22978 Mdot
.74762 .23144 Mdot
.74952 .36341 Mdot
.75143 .24209 Mdot
.75333 .37462 Mdot
.75524 .38115 Mdot
.75714 .47068 Mdot
.75905 .23887 Mdot
.76095 .39247 Mdot
.76286 .26837 Mdot
.76476 .40251 Mdot
.76667 .25758 Mdot
.76857 .28777 Mdot
.77048 .32392 Mdot
.77238 .37049 Mdot
.77429 .297 Mdot
.77619 .32538 Mdot
.7781 .27996 Mdot
.78 .35301 Mdot
.7819 .23173 Mdot
.78381 .37042 Mdot
.78571 .43155 Mdot
.78762 .33073 Mdot
.78952 .31992 Mdot
.79143 .47913 Mdot
.79333 .31457 Mdot
.79524 .33924 Mdot
.79714 .34356 Mdot
.79905 .31585 Mdot
.80095 .28927 Mdot
.80286 .32295 Mdot
.80476 .35145 Mdot
.80667 .26964 Mdot
.80857 .34833 Mdot
.81048 .27738 Mdot
.81238 .37933 Mdot
.81429 .3281 Mdot
.81619 .29786 Mdot
.8181 .25963 Mdot
.82 .35508 Mdot
.8219 .32894 Mdot
.82381 .32867 Mdot
.82571 .33991 Mdot
.82762 .35344 Mdot
.82952 .31029 Mdot
.83143 .39839 Mdot
.83333 .31046 Mdot
.83524 .27764 Mdot
.83714 .34652 Mdot
.83905 .28862 Mdot
.84095 .39291 Mdot
.84286 .24789 Mdot
.84476 .35373 Mdot
.84667 .3969 Mdot
.84857 .47098 Mdot
.85048 .40122 Mdot
.85238 .47461 Mdot
.85429 .4025 Mdot
.85619 .31394 Mdot
.8581 .30225 Mdot
.86 .37587 Mdot
.8619 .35074 Mdot
.86381 .37343 Mdot
.86571 .48164 Mdot
.86762 .26578 Mdot
.86952 .29217 Mdot
.87143 .32813 Mdot
.87333 .30368 Mdot
.87524 .25002 Mdot
.87714 .47501 Mdot
.87905 .32724 Mdot
.88095 .3629 Mdot
.88286 .32981 Mdot
.88476 .30164 Mdot
.88667 .32479 Mdot
.88857 .3047 Mdot
.89048 .27116 Mdot
.89238 .32202 Mdot
.89429 .27881 Mdot
.89619 .40212 Mdot
.8981 .39757 Mdot
.9 .30327 Mdot
.9019 .31557 Mdot
.90381 .30877 Mdot
.90571 .46087 Mdot
.90762 .32609 Mdot
.90952 .28489 Mdot
.91143 .36296 Mdot
.91333 .34853 Mdot
.91524 .2325 Mdot
.91714 .24775 Mdot
.91905 .31114 Mdot
.92095 .30076 Mdot
.92286 .39908 Mdot
.92476 .35281 Mdot
.92667 .26965 Mdot
.92857 .33684 Mdot
.93048 .41486 Mdot
.93238 .37962 Mdot
.93429 .30938 Mdot
.93619 .3729 Mdot
.9381 .2539 Mdot
.94 .26774 Mdot
.9419 .29077 Mdot
.94381 .36345 Mdot
.94571 .36887 Mdot
.94762 .31635 Mdot
.94952 .26161 Mdot
.95143 .26401 Mdot
.95333 .34089 Mdot
.95524 .39642 Mdot
.95714 .35759 Mdot
.95905 .34089 Mdot
.96095 .27737 Mdot
.96286 .47587 Mdot
.96476 .28281 Mdot
.96667 .40309 Mdot
.96857 .25406 Mdot
.97048 .2892 Mdot
.97238 .35443 Mdot
.97429 .29021 Mdot
.97619 .32672 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`;o00002ooo
ool2o`0003cooooo0_l0000iooooo`;o00000_ooool2o`0001Cooooo0_l0000_ooooo`;o0000E_oo
ool000Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o
MgMgoc8b<_ooool01?ooool3o`0001?ooooo0_l00005ooooo`;o00001?ooool2o`0002Cooooo0_l0
000Fooooo`;o0000=Oooool2o`0000;ooooo0_l00002ooooo`;o00003?ooool2o`0000Cooooo1?l0
000Dooooo`;o00006Oooool3o`0000Wooooo0_l0000Yooooo`;o00007oooool000Kooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`03o`000?oooooooooo01[ooooo1?l0000Xooooo`;o0000COooool2o`0001Cooooo
0_l00004ooooo`;o00004_ooool2o`0000;ooooo0_l0000;ooooo`;o00003Oooool2o`0000Wooooo
0_l0000Yooooo`;o00007oooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Looooo`;o0000
1Oooool2o`0000Gooooo0_l00014ooooo`;o00004oooool2o`00027ooooo0_l0000Kooooo`;o0000
3oooool2o`00017ooooo0_l0001Aooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool08oooool2o`0000Gooooo0_l0000Iooooo`;o00005Oooool2o`000003ooooool0003o000000oo
oooo0_l0000Cooooo`;o00008Oooool2o`0000Sooooo0_l0000booooo`;o000000?oooooo`000?l0
0000DOooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool0AOooool2o`0001;ooooo0_l000000ooo
oooo0000o`000003o`0003?ooooo0_l000000ooooooo0000o`000004ooooo`;o00001oooool2o`00
00[ooooo0_l00002ooooo`;o00000_ooool2o`0002[ooooo0_l0001Dooooo`00:Oooool2o`0001_o
oooo0_l0000Yooooo`;o00002Oooool2o`0000Oooooo0_l00002ooooo`;o0000=Oooool2o`000003
ooooool0003o000000Cooooo0_l00004ooooo`;o000000?oooooo`000?l000003_ooool6o`0001co
oooo0_l00007ooooo`;o00008Oooool2o`0001Kooooo0_l0000Nooooo`00:Oooool00ol0003ooooo
ooooo`0Dooooo`;o00001?ooool2o`0001oooooo0_l0000Cooooo`;o00001?ooool2o`0004Sooooo
0_l000000ooooooo0000o`000002o`00017ooooo0_l0000Fooooo`;o00001_ooool3o`0000?ooooo
0_l000000ooooooo0000o`00000Qooooo`;o00002?ooool2o`0000cooooo0_l0000Nooooo`00:Ooo
ool00ol0003oooooooooo`0Dooooo`;o00008_ooool5o`0001Wooooo0_l00006ooooo`;o00000ooo
ool2o`0002Sooooo0_l0000Aooooo`;o00000oooool2o`0002Wooooo0_l00007ooooo`;o00000ooo
ool2o`0002kooooo0_l0000Booooo`;o00002?ooool2o`0000kooooo000Yooooo`03o`000?oooooo
oooo013ooooo0_l0000:ooooo`;o00003_ooool3o`0000Wooooo1?l00005ooooo`;o00006oooool2
o`0000?ooooo1?l0000Vooooo`;o0000G?ooool2o`0003Gooooo0_l00008ooooo`;o00003_ooool0
02Wooooo00?o0000ooooooooool04?ooool2o`0000[ooooo0_l0000>ooooo`?o000000?oooooo`00
0?l000003oooool2o`0002;ooooo0ol0000Eooooo`;o0000??ooool2o`00017ooooo0_l0000Coooo
o`;o00001_ooool2o`0000oooooo0_l0000Xooooo`;o00005?ooool002Wooooo1?l0000Tooooo`;o
00002?ooool3o`0000oooooo0_l0000Looooo`;o00001Oooool2o`0001Gooooo1?l000000ooooooo
0000o`00000Booooo`;o00000_ooool2o`0001oooooo0_l0000Aooooo`;o00004oooool2o`0001Oo
oooo0_l0000Xooooo`?o00004oooool002Wooooo00?o0000ooooool000000ol0000Rooooo`;o0000
00?oooooo`000?l000000oooool8o`0001oooooo0_l00009ooooo`;o00001Oooool2o`0000cooooo
0_l00003ooooo`;o00001?ooool2o`000003ooooool0003o000000Gooooo0_l00008ooooo`;o0000
00?oooooo`000?l000000_ooool2o`0002oooooo0_l00007ooooo`;o00005?ooool2o`00023ooooo
0_l0000Eooooo`;o00000_ooool2o`0001?ooooo000Yooooo`04o`000?ooooooooooooooo`;o0000
9Oooool2o`0000?ooooo0_l000000ooooooo0000o`000003o`0000;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04?ooool2o`0000Gooooo0_l0000?oooo
o`Ko00000_ooool2o`000003oc8b<_l0003o<S8b00;o00000_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Oooooo1?l00006ooooo`;o00003Oooool2o`0000Kooooo00GoV9RHoa0@4?l0003o<S8bolc<
c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo0_l00007ooooo`;o00002?ooool2o`0000Wooooo0ol00003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko0000o`000?lb<S;ok^k^013ooooo0_l00005ooooo`;o00002_ooool2
o`0000;ooooo0_l000001Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool002Wooooo00?o0000ooooooooool0
6oooool2o`0001Gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o00004?ooool2o`0000oooooo0_l000001?lQ
8B7ok^k^oooooom4A4@3ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Wooooo0_l0000Eooooo`;o00001_ooool00ol@413o^[Zjooooo`02o`0000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool2o`00
00?ooooo1?l00008ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`05ogMgMol0003o0000oiRHV?mgMgL05oooool2o`0000[ooooo0_l00007ooooo`09ogMgMolb
<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`00:Oooool01?l0003oooooooooooooool3o`0001Oooooo0_l0000Eooooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100
1Oooool2o`0002?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400[ooooo`;o00000oooool01Ol@413ooooooooooooooooo
410@00?ooooo00Go410@oooooooooooooooooa0@4004ooooo`;o00005?ooool2o`0000Gooooo0_l0
0005ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@ooooool0003o
0000oa0@4005ooooo`;o00009_ooool3o`000005oa0@4?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@00?ooooo000Yooooo`;o00000_ooool3o`0002kooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
000Looooo`;o00002Oooool2o`0000;ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`00000Xooooo`;o000000?oooooojVYZOl@
41000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000004
ooooo`;o00003oooool2o`00017ooooo00CoA4A4omgMgOoooooo00001?ooool2o`0000;ooooo00Ko
0000ooooooooooooooooo`000?ooool3o`0000Gooooo0_l0000Aooooo`;o00004_ooool00omgMgOo
<S8bo`000002o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
007ooooo000Yooooo`03o`000?oooooooooo00cooooo0_l00004ooooo`;o00002oooool2o`00017o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooo
oooooooooooo0ol0000Jooooo`;o00002Oooool2o`0000?ooooo00?oMgMgofIVI_ooool00_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00000Booooo`;o0000
5?ooool2o`000003oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000005Oooool2o`000003ooooool0003o000000kooooo00CogMgMoeEE
EOoooooo00001?ooool2o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo01Kooooo0_l0000?ooooo`06o`000?lQ8B7o0000oc8b<_o<c<cooooo0_l00003ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`01ooooo`00:Oooool00ol0003o
ooooooooo`06ooooo`;o00001?ooool2o`0000Cooooo0_l0000;ooooo`;o00004Oooool00ol0003o
ooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo
410@00;o00006oooool2o`0000kooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?oo
ooooooooooooool@41000oooool00ol@413oooooooooo`0@ooooo`;o00005oooool00onj^[[o8B4Q
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@
00Sooooo0ol0000=ooooo`;o00001_ooool2o`0000Oooooo00?oMgMgolc<c?l000001?ooool01Ol@
413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@400Mooooo`;o00002_oo
ool00ol0003oooooooooo`03ooooo`;o00000oooool01Ol@413ooooooooooooooooo410@00?ooooo
00?o410@ooooooooool00Oooool002Wooooo0ol00006ooooo`;o00002?ooool2o`0000gooooo0ol0
000@ooooo`03o`000?oooooooooo00?o000000CoV9RHoooooonHV9SoMgMg0_ooool3o`000003oooo
oonHV9SoMgMg01gooooo0_l0000:ooooo`05o`000?nj^[[o0000o`000?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`;o00008oooool0
1Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02?ooool3o`0001Gooooo0_l00007ooooo`04onk^k_m4A4Co0000oooo
o`;o000000KoooooogMgMonHV9SooooooiRHV?mgMgL2ooooo`;o000000CoV9RHoooooonHV9SoMgMg
1_ooool2o`0001Gooooo0_l0000:ooooo`03o`000?oooooooooo00Cooooo00GoMgMgo`000?l0003o
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wooooo0ol0000@ooooo`;o
00003_ooool2o`0000kooooo00?oEEEEofIVI_l000000_ooool3o`000004oc8b<_l0003o<S8bonk^
kP;ooooo1?l000000olb<S;ok^k^ooooo`0;ooooo`;o00006oooool01OnHV9So410@o`000?l0003o
c<c<00?ooooo00Gok^k^oc8b<_l0003o0000onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool2o`0001Gooooo0_l0000<ooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Zooooo`03ogMgMol0003o
oooo00;o000000Koooooonk^k_lb<S;o0000oc8b<_o^k^h2ooooo`;o000000Co<S8bo`000?lb<S;o
k^k^1_ooool2o`0000Sooooo0_l0000Eooooo`Ko00000oooool01Oo^k^ko0000o`000?l0003ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool2o`0002Oooooo0_l0000Xoooo
o`;o00009Oooool2o`0000_ooooo0_l000000ooooooo0000o`00000<ooooo`;o000000?oooooo`00
0?l000000_ooool2o`000003ooooool0003o000000Kooooo0_l0000Pooooo`;o00001_ooool4o`00
03Oooooo0_l0000Eooooo`;o00002Oooool2o`0000cooooo000Yooooo`03o`000?oooooooooo02Ko
oooo0_l0000:ooooo`;o00007Oooool2o`0000Gooooo0_l0000Cooooo`;o00005Oooool2o`000003
ooooool0003o000000cooooo0_l000000ooooooo0000o`000005ooooo`;o00000_ooool2o`0000;o
oooo0_l0000:ooooo`;o00005?ooool2o`0000Kooooo1?l0000Iooooo`;o00002oooool2o`0003oo
oooo000Yooooo`03o`000?oooooooooo00kooooo0_l0000Booooo`;o00003_ooool3o`0001cooooo
0_l00002ooooo`;o000000?oooooo`000?l000004oooool2o`0003Cooooo0_l0000:ooooo`;o0000
0_ooool2o`0003Wooooo0_l0000;ooooo`;o00003?ooool2o`0000Kooooo0_l0000:ooooo`;o0000
7Oooool002Wooooo00?o0000ooooooooool01oooool2o`0000Gooooo0_l0000Booooo`?o00003_oo
ool2o`0001Gooooo0_l00009ooooo`;o0000:_ooool2o`0002cooooo0_l0000<ooooo`;o00001ooo
ool2o`00013ooooo0_l0000_ooooo`;o00000_ooool2o`0000;ooooo0ol00002ooooo`;o00001Ooo
ool2o`0001gooooo000Yooooo`03o`000?oooooooooo00Oooooo0_l0000Jooooo`;o00008oooool4
o`0002Oooooo0_l0000<ooooo`;o00002Oooool2o`0002oooooo0_l00007ooooo`;o00004?ooool2
o`0003?ooooo0_l00003ooooo`;o00000_ooool3o`0002?ooooo000Qoooooooo0000A?l00004oooo
o`00:Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo0_l0000;ooooo`03
o`000?oooooooooo00Kooooo0_l000000ooooooo0000o`00000:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02?ooool2o`0000_ooooo00?o0000ooooooooool01oooool3o`0000co
oooo00Co0000oooooooooooooooo0_l00006ooooo`03o`000?oooooooooo00;o00001oooool00ol0
003oooooooooo`09ooooo`;o00002oooool00ol0003oooooooooo`02ooooo`Co00000oooool00ol0
003oooooooooo`03ooooo`;o00001?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Kooooo0_l00002ooooo`;o00002_ooool00ol0003oooooooooo`09ooooo`04o`000?oooooo0000
o`0000Sooooo1Ol00005ooooo`;o000000?oooooo`000?ooool02_ooool00ol0003oooooooooo`02
ooooo`;o00000oooool3o`0000_ooooo00?o0000ooooooooool02_ooool002Wooooo00?o0000oooo
ooooool06?ooool2o`00017ooooo0_l00009ooooo`;o00000_ooool00ol0003oooooooooo`06oooo
o`;o00003Oooool2o`0001?ooooo0_l0000=ooooo`Co00000_ooool2o`0001[ooooo0_l00002oooo
o`;o00004_ooool2o`0000?ooooo00?o0000ooooooooool07_ooool2o`0000;ooooo0_l0000Foooo
o`03o`000?oooooo000000?o00004?ooool2o`0000gooooo0_l0000<ooooo`;o00002?ooool00ol0
003oooooooooo`0:ooooo`00:Oooool00ol0003oooooooooo`0Hooooo`;o00004?ooool2o`0000[o
oooo0_l0000:ooooo`?o00008_ooool2o`0000gooooo1Ol0000Mooooo`;o0000F?ooool2o`0000;o
oooo0_l0000Oooooo`;o00003?ooool2o`0001Gooooo000Yooooo`03o`000?oooooooooo00Cooooo
0_l0000Tooooo`;o00005_ooool2o`0002Oooooo0_l0000<ooooo`?o0000:Oooool2o`0000Cooooo
0_l0000Aooooo`;o00003_ooool2o`0001cooooo0_l00004ooooo`;o00000oooool2o`0001_ooooo
0_l0000Vooooo`00:Oooool2o`0000Gooooo0_l00003ooooo`;o0000Boooool2o`0000Wooooo0_l0
0008ooooo`;o000000Coooooo`000?l0003ooooo0_l00007ooooo`;o0000:Oooool2o`0000Cooooo
0ol0000@ooooo`;o000000?oooooo`000?l000002oooool2o`00017ooooo0_l00009ooooo`Co0000
1oooool2o`0001Kooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l0000Eooooo`;o0000
2oooool002Wooooo00?o0000ooooooooool00_ooool2o`0000Gooooo0_l0000eooooo`;o00002_oo
ool2o`0000Sooooo1?l00007ooooo`;o00002Oooool4o`000004ooooool0003o0000o`0000Wooooo
0_l0000Pooooo`;o00002Oooool4o`0001?ooooo0_l00008ooooo`;o00005?ooool2o`0000_ooooo
0_l0000:ooooo`;o000000Coooooo`000?l0003o00003Oooool7o`0000Cooooo0_l0000Eooooo`;o
00002oooool002Wooooo00?o0000ooooooooool00_ooool2o`00023ooooo0ol0000;ooooo`;o0000
1?ooool2o`0000Kooooo0_l0000:ooooo`;o00002_ooool2o`0001;ooooo0_l00004ooooo`;o0000
2Oooool2o`0000?ooooo0ol0000Jooooo`;o00002Oooool2o`0001Wooooo0_l00004ooooo`;o0000
9Oooool2o`0000Kooooo0_l000001?oooooo0000o`000?l0000=ooooo`;o000000?oooooo`000?l0
0000:_ooool002Wooooo00Co0000ooooool0003o00001?ooool2o`0000Sooooo0_l0000Cooooo`?o
00002oooool2o`0000Cooooo0_l0000^ooooo`;o00006?ooool3o`0003cooooo0_l00002ooooo`;o
0000:oooool2o`0004Sooooo000Yooooo`04o`000?oooooo0000o`0000Cooooo0_l00008ooooo`;o
00006?ooool2o`0000Gooooo0_l00009ooooo`;o00005?ooool2o`0001Gooooo0_l0000<ooooo`;o
00004?ooool2o`0003Kooooo0ol0000aooooo`;o00002?ooool2o`0001oooooo0_l0000Kooooo`00
:Oooool2o`0001Oooooo0_l0000Aooooo`;o00001Oooool2o`0000Wooooo0_l0000Dooooo`;o0000
8oooool2o`00013ooooo0_l0000Tooooo`;o00004?ooool2o`0001[ooooo0_l0000Fooooo`;o0000
2?ooool2o`0001oooooo0_l00006ooooo`Co00004Oooool002Wooooo00?o0000ooooooooool04Ooo
ool3o`0000;ooooo0_l000000ooooooo0000o`00000Rooooo`;o00003oooool2o`0005Sooooo0_l0
0004ooooo`;o00002_ooool2o`0000Cooooo0_l0000Iooooo`?o00005oooool2o`00033ooooo1?l0
000Aooooo`00:Oooool00ol0003oooooooooo`03ooooo`;o00003?ooool3o`0000Gooooo0_l0000R
ooooo`;o00002Oooool2o`0000Cooooo0_l0000Dooooo`;o00006?ooool4o`00013ooooo0_l00007
ooooo`;o00001?ooool2o`0000Gooooo0_l0000@ooooo`;o00001?ooool2o`0000Cooooo0_l0000C
ooooo`?o00005oooool2o`0000;ooooo0_l00007ooooo`;o00005_ooool2o`00023ooooo000Yoooo
o`03o`000?oooooooooo00?ooooo0_l00008ooooo`;o00001Oooool2o`0002Oooooo0_l00009oooo
o`;o00006_ooool2o`000003ooooool0003o000001Gooooo1?l0000=ooooo`;o000000?oooooo`00
0?l000001_ooool3o`0000Cooooo0_l0000Booooo`;o00003oooool2o`0000[ooooo0_l00009oooo
o`;o00006?ooool4o`0000Oooooo0_l00006ooooo`;o00003_ooool2o`00023ooooo000Yooooo`03
o`000?oooooooooo00Sooooo0_l00003ooooo`;o00001Oooool2o`0000Sooooo0_l00007ooooo`;o
00005Oooool2o`0001[ooooo0_l00008ooooo`;o000000?oooooo`000?l000009?ooool4o`0000Wo
oooo0_l00002ooooo`;o00001?ooool2o`000003ooooool0003o000000cooooo0_l0000Kooooo`;o
00002Oooool2o`00013ooooo0_l00006ooooo`;o00000oooool2o`000003ooooool0003o000000?o
oooo0_l00004ooooo`;o00004_ooool2o`0000gooooo0_l0000=ooooo`00:Oooool2o`0000Wooooo
0_l0000Dooooo`;o00001oooool2o`0001Gooooo0_l0000Dooooo`;o00001?ooool2o`0000Sooooo
0_l0000Pooooo`;o00001Oooool2o`0000oooooo0_l00004ooooo`;o000000?oooooo`000?l00000
1?ooool2o`0000?ooooo0_l00003ooooo`;o0000=_ooool2o`0000_ooooo0_l000000ooooooo0000
o`000003ooooo`;o00006?ooool2o`0000Sooooo0_l00003ooooo`;o00003Oooool002Wooooo00?o
0000ooooooooool0E?ooool2o`00033ooooo0_l0000Uooooo`;o00000oooool2o`0000?ooooo0_l0
001_ooooo`;o00004_ooool002Wooooo00?o0000ooooooooool02_ooool2o`0003Cooooo0_l0002T
ooooo`;o0000:?ooool2o`0000Sooooo0_l00008ooooo`;o00005_ooool002Wooooo00?o0000oooo
ooooool02_ooool2o`0000Wooooo0_l00006ooooo`;o00008Oooool2o`0000Oooooo0_l00008oooo
o`;o00008?ooool2o`0001Wooooo0_l0001Dooooo`;o0000:?ooool2o`0000Sooooo0_l00008oooo
o`;o00005_ooool002Wooooo00?o0000ooooooooool02Oooool2o`0000[ooooo1?l00004ooooo`;o
0000:_ooool2o`0000Sooooo0_l0000Iooooo`;o000000?oooooo`000?l000000_ooool2o`0001Wo
oooo0_l00005ooooo`;o00007?ooool2o`0002Sooooo0_l0000<ooooo`;o00000_ooool2o`0003;o
oooo0_l0000Eooooo`00:Oooool2o`0000Kooooo0_l00002ooooo`;o00003?ooool2o`0000kooooo
0_l00015ooooo`;o000000?oooooo`000?l000005oooool2o`0000Kooooo0_l00003ooooo`;o0000
7?ooool2o`0002Sooooo0_l0000<ooooo`;o00000_ooool2o`0001Oooooo0_l0000Fooooo`;o0000
00?oooooo`000?l000005Oooool002Wooooo00?o0000ooooooooool01Oooool2o`00023ooooo0_l0
000Tooooo`Co0000>Oooool2o`0000Kooooo0_l0000Uooooo`;o00002Oooool2o`00027ooooo0_l0
000Pooooo`?o00005_ooool2o`0001Sooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`1=ooooo`Co00004Oooool2o`0005Gooooo0_l00009ooooo`;o00001oooool2o`0000Cooooo
0_l0000Booooo`;o00004Oooool2o`0000gooooo0_l0000Eooooo`;o00006_ooool000Kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oo
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`02o`0004cooooo0_l0000Booooo`;o
0000F_ooool2o`0000gooooo0_l00004ooooo`;o00004_ooool2o`00017ooooo0_l0000Tooooo`;o
00006_ooool000Kooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02o`0000Sooooo0ol0001<ooooo`;o
00008Oooool2o`0002Cooooo0_l0000Iooooo`?o00004?ooool2o`00013ooooo0_l00003ooooo`;o
0000Doooool000Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo00?oMgMgoc8b<_ooool01?ooool3o`0000[ooooo1?l0000hooooo`;o00000oooool2o`0000co
oooo1?l0000Oooooo`;o00009?ooool2o`0001Wooooo0_l0000Aooooo`;o00004?ooool2o`0005So
oooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`07ooooo`;o00000oooool2o`00
023ooooo0_l0000Fooooo`;o00000oooool2o`0000kooooo0ol0000<ooooo`;o0000?Oooool2o`00
017ooooo0_l0000[ooooo`;o0000DOooool000Kooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04oooo
o`;o000000?oooooo`000?l000001_ooool2o`00013ooooo0_l0000;ooooo`;o00007Oooool2o`00
00gooooo0_l00005ooooo`;o00001Oooool2o`0000oooooo0_l00004ooooo`;o000000?oooooo`00
0?l000008oooool2o`00017ooooo0_l0000<ooooo`;o00007Oooool2o`0001Sooooo0_l0000goooo
o`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004
ooooo`03o`000?oooooooooo00Oooooo0_l00005ooooo`;o00002Oooool2o`0000Oooooo0_l00007
ooooo`;o00004Oooool2o`0000Cooooo0_l0000Aooooo`;o00005?ooool2o`0001Kooooo0_l00002
ooooo`Co000000?oooooo`000?l000002_ooool2o`0000kooooo0_l0000Fooooo`;o00001Oooool2
o`0000Wooooo0_l0000Gooooo`;o00006oooool2o`000003ooooool0003o000000;o00003_ooool2
o`00017ooooo0_l0000Booooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`0001Sooooo0ol0000Jooooo`;o00001?oo
ool2o`0003Kooooo0_l0000;ooooo`;o00003oooool2o`0000kooooo0_l0000Fooooo`;o00001Ooo
ool2o`0002;ooooo0_l0000Kooooo`;o00000oooool3o`0000gooooo0_l00006ooooo`;o00002Ooo
ool2o`0001;ooooo000Yooooo`;o00006?ooool2o`0002?ooooo0_l0000dooooo`;o00005Oooool2
o`0000Cooooo0_l0000kooooo`;o00005_ooool2o`0000Gooooo0_l0000Iooooo`?o00003?ooool2
o`0000Kooooo0_l0000<ooooo`;o00003oooool002Wooooo00?o0000ooooooooool0??ooool2o`00
04_ooooo0ol00003ooooo`;o0000>oooool2o`0001Kooooo0_l00005ooooo`;o00006_ooool2o`00
02;ooooo0_l0000?ooooo`00:Oooool00ol0003oooooooooo`17ooooo`;o0000@Oooool2o`0000;o
oooo0_l0002/ooooo`00:Oooool00ol0003oooooooooo`17ooooo`;o0000AOooool2o`000:cooooo
000Yooooo`03o`000?oooooooooo0<;ooooo0_l0001Looooo`;o00006_ooool002Wooooo0_l00033
ooooo`;o0000G?ooool2o`0001[ooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool08_ooool2o`000?oooooo6Oooool002Wooooo00?o0000ooooooooool0
8_ooool2o`00053ooooo0_l0000Kooooo`;o0000ZOooool002Wooooo00?o0000ooooooooool0M?oo
ool2o`0001_ooooo0_l0000Qooooo`;o0000>oooool2o`0004Wooooo000Yooooo`;o0000]Oooool2
o`0003_ooooo0_l00019ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3Kooooo`;o0000Goooool002Wooooo0_l0001Dooooo`;o0000K_ooool2
o`00013ooooo0_l00004ooooo`;o0000Goooool002Wooooo00?o0000ooooooooool0Doooool2o`00
06kooooo0_l0000@ooooo`;o0000IOooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0]_ooool2o`00063ooooo0_l0000Rooooo`003_ooool01Ol@
413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`0005Oooooo0_l0001M
ooooo`;o0000H?ooool2o`0002;ooooo000>ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo04_ooooo0_l0000:ooooo`;o00005_ooool2
o`0003oooooo0_l0002:ooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo03Oooooo0_l0000:ooooo`;o00001_oo
ool2o`0001cooooo0_l00004ooooo`;o0000?oooool2o`0008[ooooo000>ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Gooooo1?l0
000:ooooo`;o00009?ooool2o`0007gooooo0_l0000Kooooo`;o0000=Oooool000kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0=Ooo
ool2o`00043ooooo0_l0001_ooooo`;o00006oooool4o`0000Kooooo0_l0000Iooooo`;o00004?oo
ool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`0007Sooooo0_l0
00000ooooooo0000o`00000@ooooo`;o0000IOooool2o`0001;ooooo0_l00006ooooo`;o00006Ooo
ool2o`00013ooooo000Yooooo`03o`000?oooooooooo01gooooo0_l0000<ooooo`;o00003?ooool2
o`0003oooooo0_l0000@ooooo`;o0000@Oooool2o`0002;ooooo0_l0000Fooooo`;o0000;oooool0
02Wooooo00?o0000ooooooooool07Oooool2o`0000cooooo0_l0000<ooooo`;o0000U?ooool2o`00
03[ooooo0_l0000_ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0
003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo
410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolm
ooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@
400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooo
oooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo
0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`;o0000
oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000
oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool001oooooo1?l000000ol@
413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
0ol0003oooooocgooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool001oooooo00?oEEEEofIVI_l00000oooooom7ooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .37906 Mdot
.02762 .39786 Mdot
.02952 .27632 Mdot
.03143 .28154 Mdot
.03333 .36323 Mdot
.03524 .32486 Mdot
.03714 .3139 Mdot
.03905 .23779 Mdot
.04095 .23566 Mdot
.04286 .27026 Mdot
.04476 .30839 Mdot
.04667 .22726 Mdot
.04857 .41372 Mdot
.05048 .27329 Mdot
.05238 .26405 Mdot
.05429 .26095 Mdot
.05619 .24471 Mdot
.0581 .41426 Mdot
.06 .34777 Mdot
.0619 .40097 Mdot
.06381 .40956 Mdot
.06571 .40672 Mdot
.06762 .40373 Mdot
.06952 .41408 Mdot
.07143 .28615 Mdot
.07333 .3511 Mdot
.07524 .33478 Mdot
.07714 .35142 Mdot
.07905 .38847 Mdot
.08095 .40208 Mdot
.08286 .39717 Mdot
.08476 .24836 Mdot
.08667 .22956 Mdot
.08857 .26448 Mdot
.09048 .26286 Mdot
.09238 .37295 Mdot
.09429 .31285 Mdot
.09619 .34733 Mdot
.0981 .35048 Mdot
.1 .22506 Mdot
.1019 .25395 Mdot
.10381 .25972 Mdot
.10571 .30343 Mdot
.10762 .37064 Mdot
.10952 .35833 Mdot
.11143 .36242 Mdot
.11333 .29827 Mdot
.11524 .28519 Mdot
.11714 .31609 Mdot
.11905 .36829 Mdot
.12095 .27747 Mdot
.12286 .358 Mdot
.12476 .4729 Mdot
.12667 .29744 Mdot
.12857 .27347 Mdot
.13048 .23079 Mdot
.13238 .23075 Mdot
.13429 .24709 Mdot
.13619 .29992 Mdot
.1381 .35344 Mdot
.14 .35696 Mdot
.1419 .34198 Mdot
.14381 .33602 Mdot
.14571 .33583 Mdot
.14762 .23216 Mdot
.14952 .24354 Mdot
.15143 .27393 Mdot
.15333 .25805 Mdot
.15524 .34152 Mdot
.15714 .41206 Mdot
.15905 .25774 Mdot
.16095 .30062 Mdot
.16286 .28535 Mdot
.16476 .26143 Mdot
.16667 .33575 Mdot
.16857 .28359 Mdot
.17048 .47304 Mdot
.17238 .33006 Mdot
.17429 .3669 Mdot
.17619 .2728 Mdot
.1781 .38786 Mdot
.18 .40208 Mdot
.1819 .2813 Mdot
.18381 .2566 Mdot
.18571 .24419 Mdot
.18762 .27291 Mdot
.18952 .36345 Mdot
.19143 .35356 Mdot
.19333 .25913 Mdot
.19524 .2577 Mdot
.19714 .29718 Mdot
.19905 .43824 Mdot
.20095 .33375 Mdot
.20286 .3617 Mdot
.20476 .33281 Mdot
.20667 .42399 Mdot
.20857 .27254 Mdot
.21048 .25146 Mdot
.21238 .47455 Mdot
.21429 .27226 Mdot
.21619 .38614 Mdot
.2181 .28031 Mdot
.22 .23406 Mdot
.2219 .37969 Mdot
.22381 .40517 Mdot
.22571 .26767 Mdot
.22762 .24642 Mdot
.22952 .35147 Mdot
.23143 .33393 Mdot
.23333 .40951 Mdot
.23524 .26745 Mdot
.23714 .29606 Mdot
.23905 .24603 Mdot
.24095 .3966 Mdot
.24286 .49229 Mdot
.24476 .27004 Mdot
.24667 .34826 Mdot
.24857 .26146 Mdot
.25048 .26022 Mdot
.25238 .28667 Mdot
.25429 .41328 Mdot
.25619 .31344 Mdot
.2581 .40081 Mdot
.26 .39257 Mdot
.2619 .41093 Mdot
.26381 .27006 Mdot
.26571 .38786 Mdot
.26762 .41291 Mdot
.26952 .39875 Mdot
.27143 .3103 Mdot
.27333 .40717 Mdot
.27524 .39275 Mdot
.27714 .23615 Mdot
.27905 .31474 Mdot
.28095 .31237 Mdot
.28286 .38363 Mdot
.28476 .3508 Mdot
.28667 .38516 Mdot
.28857 .28654 Mdot
.29048 .22688 Mdot
.29238 .25731 Mdot
.29429 .39129 Mdot
.29619 .321 Mdot
.2981 .34224 Mdot
.3 .24478 Mdot
.3019 .40071 Mdot
.30381 .25038 Mdot
.30571 .49578 Mdot
.30762 .35736 Mdot
.30952 .35358 Mdot
.31143 .27219 Mdot
.31333 .29068 Mdot
.31524 .32513 Mdot
.31714 .415 Mdot
.31905 .30597 Mdot
.32095 .35898 Mdot
.32286 .34123 Mdot
.32476 .34545 Mdot
.32667 .24911 Mdot
.32857 .3025 Mdot
.33048 .34375 Mdot
.33238 .33894 Mdot
.33429 .37485 Mdot
.33619 .22608 Mdot
.3381 .3743 Mdot
.34 .3242 Mdot
.3419 .38945 Mdot
.34381 .24858 Mdot
.34571 .40597 Mdot
.34762 .34073 Mdot
.34952 .36152 Mdot
.35143 .36124 Mdot
.35333 .31111 Mdot
.35524 .34137 Mdot
.35714 .35936 Mdot
.35905 .35875 Mdot
.36095 .22694 Mdot
.36286 .42171 Mdot
.36476 .35924 Mdot
.36667 .28378 Mdot
.36857 .37427 Mdot
.37048 .37093 Mdot
.37238 .22831 Mdot
.37429 .25629 Mdot
.37619 .25663 Mdot
.3781 .3233 Mdot
.38 .23185 Mdot
.3819 .41726 Mdot
.38381 .26965 Mdot
.38571 .22665 Mdot
.38762 .30045 Mdot
.38952 .3003 Mdot
.39143 .40245 Mdot
.39333 .33498 Mdot
.39524 .34823 Mdot
.39714 .23888 Mdot
.39905 .25241 Mdot
.40095 .23396 Mdot
.40286 .36093 Mdot
.40476 .44059 Mdot
.40667 .24441 Mdot
.40857 .27427 Mdot
.41048 .27542 Mdot
.41238 .29655 Mdot
.41429 .36017 Mdot
.41619 .44732 Mdot
.4181 .39203 Mdot
.42 .33273 Mdot
.4219 .33659 Mdot
.42381 .31196 Mdot
.42571 .32199 Mdot
.42762 .30275 Mdot
.42952 .41044 Mdot
.43143 .33496 Mdot
.43333 .40519 Mdot
.43524 .25686 Mdot
.43714 .39108 Mdot
.43905 .33462 Mdot
.44095 .22843 Mdot
.44286 .31577 Mdot
.44476 .36504 Mdot
.44667 .22632 Mdot
.44857 .35119 Mdot
.45048 .27109 Mdot
.45238 .4088 Mdot
.45429 .37934 Mdot
.45619 .25898 Mdot
.4581 .36157 Mdot
.46 .39006 Mdot
.4619 .32092 Mdot
.46381 .26315 Mdot
.46571 .30637 Mdot
.46762 .27042 Mdot
.46952 .31585 Mdot
.47143 .45522 Mdot
.47333 .27421 Mdot
.47524 .32458 Mdot
.47714 .31435 Mdot
.47905 .3435 Mdot
.48095 .38227 Mdot
.48286 .40753 Mdot
.48476 .39055 Mdot
.48667 .34816 Mdot
.48857 .30406 Mdot
.49048 .40649 Mdot
.49238 .25777 Mdot
.49429 .26107 Mdot
.49619 .3294 Mdot
.4981 .32041 Mdot
.5 .24636 Mdot
.5019 .2596 Mdot
.50381 .34307 Mdot
.50571 .25573 Mdot
.50762 .2705 Mdot
.50952 .33249 Mdot
.51143 .30549 Mdot
.51333 .33633 Mdot
.51524 .34124 Mdot
.51714 .26223 Mdot
.51905 .28611 Mdot
.52095 .22778 Mdot
.52286 .29399 Mdot
.52476 .29796 Mdot
.52667 .32382 Mdot
.52857 .37899 Mdot
.53048 .29583 Mdot
.53238 .27991 Mdot
.53429 .37884 Mdot
.53619 .31095 Mdot
.5381 .34054 Mdot
.54 .36473 Mdot
.5419 .31604 Mdot
.54381 .38387 Mdot
.54571 .27203 Mdot
.54762 .2627 Mdot
.54952 .28502 Mdot
.55143 .34847 Mdot
.55333 .25661 Mdot
.55524 .3572 Mdot
.55714 .26868 Mdot
.55905 .28995 Mdot
.56095 .34881 Mdot
.56286 .3743 Mdot
.56476 .29228 Mdot
.56667 .26479 Mdot
.56857 .29626 Mdot
.57048 .22899 Mdot
.57238 .35139 Mdot
.57429 .31026 Mdot
.57619 .35541 Mdot
.5781 .40606 Mdot
.58 .35554 Mdot
.5819 .38788 Mdot
.58381 .41986 Mdot
.58571 .28846 Mdot
.58762 .24817 Mdot
.58952 .26922 Mdot
.59143 .31943 Mdot
.59333 .3218 Mdot
.59524 .35418 Mdot
.59714 .41007 Mdot
.59905 .25962 Mdot
.60095 .49679 Mdot
.60286 .30163 Mdot
.60476 .27381 Mdot
.60667 .39196 Mdot
.60857 .25508 Mdot
.61048 .26537 Mdot
.61238 .29742 Mdot
.61429 .26155 Mdot
.61619 .33576 Mdot
.6181 .2682 Mdot
.62 .41037 Mdot
.6219 .24447 Mdot
.62381 .4121 Mdot
.62571 .27002 Mdot
.62762 .27853 Mdot
.62952 .37081 Mdot
.63143 .26457 Mdot
.63333 .23465 Mdot
.63524 .28816 Mdot
.63714 .23163 Mdot
.63905 .32771 Mdot
.64095 .38383 Mdot
.64286 .26612 Mdot
.64476 .3064 Mdot
.64667 .2523 Mdot
.64857 .32878 Mdot
.65048 .36173 Mdot
.65238 .26571 Mdot
.65429 .31832 Mdot
.65619 .24684 Mdot
.6581 .22952 Mdot
.66 .29554 Mdot
.6619 .33498 Mdot
.66381 .40881 Mdot
.66571 .30829 Mdot
.66762 .29421 Mdot
.66952 .39179 Mdot
.67143 .31625 Mdot
.67333 .32383 Mdot
.67524 .33704 Mdot
.67714 .35966 Mdot
.67905 .46597 Mdot
.68095 .32361 Mdot
.68286 .4012 Mdot
.68476 .33363 Mdot
.68667 .22863 Mdot
.68857 .33361 Mdot
.69048 .38411 Mdot
.69238 .4038 Mdot
.69429 .33096 Mdot
.69619 .3375 Mdot
.6981 .38762 Mdot
.7 .22558 Mdot
.7019 .33474 Mdot
.70381 .37456 Mdot
.70571 .31691 Mdot
.70762 .24332 Mdot
.70952 .36808 Mdot
.71143 .27835 Mdot
.71333 .22585 Mdot
.71524 .37307 Mdot
.71714 .40611 Mdot
.71905 .23772 Mdot
.72095 .2336 Mdot
.72286 .23974 Mdot
.72476 .28531 Mdot
.72667 .28071 Mdot
.72857 .26258 Mdot
.73048 .22962 Mdot
.73238 .28336 Mdot
.73429 .39484 Mdot
.73619 .30603 Mdot
.7381 .32862 Mdot
.74 .38444 Mdot
.7419 .24588 Mdot
.74381 .38293 Mdot
.74571 .31153 Mdot
.74762 .30425 Mdot
.74952 .4033 Mdot
.75143 .34527 Mdot
.75333 .40621 Mdot
.75524 .27461 Mdot
.75714 .49442 Mdot
.75905 .27468 Mdot
.76095 .35392 Mdot
.76286 .29874 Mdot
.76476 .30523 Mdot
.76667 .26864 Mdot
.76857 .31863 Mdot
.77048 .22657 Mdot
.77238 .41184 Mdot
.77429 .26556 Mdot
.77619 .2657 Mdot
.7781 .34837 Mdot
.78 .32949 Mdot
.7819 .28569 Mdot
.78381 .41489 Mdot
.78571 .35334 Mdot
.78762 .22888 Mdot
.78952 .24696 Mdot
.79143 .4667 Mdot
.79333 .24486 Mdot
.79524 .35855 Mdot
.79714 .35958 Mdot
.79905 .30267 Mdot
.80095 .22815 Mdot
.80286 .22737 Mdot
.80476 .33333 Mdot
.80667 .32318 Mdot
.80857 .2984 Mdot
.81048 .26415 Mdot
.81238 .26759 Mdot
.81429 .36446 Mdot
.81619 .38211 Mdot
.8181 .3071 Mdot
.82 .32954 Mdot
.8219 .29706 Mdot
.82381 .36367 Mdot
.82571 .26117 Mdot
.82762 .31962 Mdot
.82952 .33319 Mdot
.83143 .2939 Mdot
.83333 .22654 Mdot
.83524 .29071 Mdot
.83714 .2651 Mdot
.83905 .24609 Mdot
.84095 .37276 Mdot
.84286 .3003 Mdot
.84476 .33946 Mdot
.84667 .29524 Mdot
.84857 .42327 Mdot
.85048 .38904 Mdot
.85238 .48872 Mdot
.85429 .37081 Mdot
.85619 .33401 Mdot
.8581 .22863 Mdot
.86 .26878 Mdot
.8619 .31872 Mdot
.86381 .40296 Mdot
.86571 .46822 Mdot
.86762 .31915 Mdot
.86952 .2668 Mdot
.87143 .35861 Mdot
.87333 .38464 Mdot
.87524 .28745 Mdot
.87714 .43959 Mdot
.87905 .32423 Mdot
.88095 .29185 Mdot
.88286 .25067 Mdot
.88476 .33652 Mdot
.88667 .28478 Mdot
.88857 .2558 Mdot
.89048 .23573 Mdot
.89238 .27702 Mdot
.89429 .37507 Mdot
.89619 .39383 Mdot
.8981 .36618 Mdot
.9 .38716 Mdot
.9019 .38889 Mdot
.90381 .24443 Mdot
.90571 .40053 Mdot
.90762 .2662 Mdot
.90952 .22922 Mdot
.91143 .24969 Mdot
.91333 .31611 Mdot
.91524 .3277 Mdot
.91714 .30754 Mdot
.91905 .24581 Mdot
.92095 .38663 Mdot
.92286 .38452 Mdot
.92476 .35155 Mdot
.92667 .33889 Mdot
.92857 .25761 Mdot
.93048 .31944 Mdot
.93238 .3251 Mdot
.93429 .27755 Mdot
.93619 .31074 Mdot
.9381 .27823 Mdot
.94 .29335 Mdot
.9419 .25963 Mdot
.94381 .29157 Mdot
.94571 .29812 Mdot
.94762 .27174 Mdot
.94952 .33456 Mdot
.95143 .24228 Mdot
.95333 .36365 Mdot
.95524 .37679 Mdot
.95714 .33218 Mdot
.95905 .35459 Mdot
.96095 .27611 Mdot
.96286 .49189 Mdot
.96476 .27183 Mdot
.96667 .39508 Mdot
.96857 .25304 Mdot
.97048 .37712 Mdot
.97238 .34343 Mdot
.97429 .38099 Mdot
.97619 .22786 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`04ooooo`;o00003oooool2o`0003_ooooo0_l0000=ooooo`;o00001_ooool2o`0000Kooooo0_l0
000Aooooo`;o00005_ooool2o`0003Sooooo0_l00002ooooo`;o00004?ooool2o`0000Wooooo0_l0
0008ooooo`;o0000;?ooool2o`0000_ooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`;o00002_ooool2o`0000?ooooo0_l00008ooooo`;o0000<Oooool2o`0000gooooo0_l0
0006ooooo`;o000000?oooooo`000?l000000oooool2o`0000oooooo1?l0000Fooooo`;o00003_oo
ool2o`0001[ooooo0_l00007ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00002ooo
ool2o`0000Cooooo0_l00002ooooo`?o00002?ooool2o`0000Kooooo0_l0000>ooooo`;o00005?oo
ool2o`0000_ooooo0006ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^
kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000@ooooo`;o00003Oooool2o`0000?ooooo0_l0
000Eooooo`;o0000;oooool2o`000003ooooool0003o000000Gooooo0_l0000:ooooo`;o0000:?oo
ool2o`0001?ooooo0_l00005ooooo`;o00001oooool2o`0000Wooooo0_l000000ooooooo0000o`00
000Aooooo`;o00000_ooool2o`00017ooooo0_l0000>ooooo`;o00008Oooool000Kooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`03o`000?oooooooooo00;ooooo0_l0000Pooooo`;o00005Oooool2o`00017ooooo
0_l0000Oooooo`;o00001Oooool2o`0004Sooooo0ol0000Iooooo`;o0000=Oooool2o`0002Oooooo
0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Oooooo00Co0000oooooooooooooooo0ol0001:ooooo`;o00009?ooool2o`0004[o
oooo0_l0000Jooooo`?o0000=?ooool2o`0002Oooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool01?l0
003oooooooooooooool2o`00077ooooo0_l0001Rooooo`;o00000_ooool3o`0004Sooooo0_l0000C
ooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c004ooooo`Co00001_ooool00ol0003oooooooooo`07ooooo`;o00007?ooool2o`0000Wooooo0_l0
000<ooooo`;o000000?oooooo`000?l000004_ooool2o`00023ooooo0_l0000Looooo`;o00009_oo
ool2o`0001Wooooo0_l00009ooooo`;o00003oooool2o`0000cooooo0_l0000Cooooo`;o00000ooo
ool2o`0000Wooooo0_l0000Cooooo`00:Oooool2o`0000Sooooo0_l00007ooooo`;o00003_ooool2
o`0000?ooooo0_l00009ooooo`;o00003?ooool2o`000003ooooool0003o000001;ooooo0_l00007
ooooo`;o00000oooool2o`0001;ooooo0_l0000Looooo`;o00006oooool2o`0000Wooooo0_l00009
ooooo`;o00006Oooool2o`0000gooooo1?l0000<ooooo`;o00004oooool2o`000003ooooool0003o
000000;o00007_ooool002Wooooo00?o0000ooooooooool04?ooool2o`0000kooooo0_l0000Foooo
o`;o00007?ooool2o`0000Kooooo0_l00003ooooo`;o00004?ooool2o`0003_ooooo0_l0000Aoooo
o`;o000000?oooooo`000?l00000:?ooool2o`0001cooooo0_l00008ooooo`;o00008?ooool002Wo
oooo00?o0000ooooooooool05Oooool2o`00027ooooo0_l0000Looooo`;o00007Oooool2o`00023o
oooo0_l0000Oooooo`;o00002oooool2o`0004Wooooo1?l0000Hooooo`;o00003_ooool002Wooooo
00?o0000ooooooooool05Oooool2o`0000oooooo1?l00006ooooo`;o000000?oooooo`000?l00000
7_ooool2o`0001Sooooo0ol0000Aooooo`;o00001?ooool2o`0000[ooooo0_l00002ooooo`;o0000
3_ooool2o`0000oooooo0_l0001Hooooo`;o00002oooool2o`0000_ooooo0_l0000>ooooo`00:Ooo
ool00ol0003oooooooooo`06ooooo`;o00003_ooool2o`0000kooooo1_l00004ooooo`;o000000?o
ooooo`000?l000004?ooool2o`0000cooooo0_l0000Hooooo`?o00004Oooool2o`0000Cooooo0_l0
000:ooooo`Go00003oooool2o`0000cooooo0_l00003ooooo`;o0000@_ooool2o`0001oooooo0_l0
0002ooooo`;o00005oooool002Wooooo0_l00006ooooo`?o00002Oooool3o`0000;ooooo0_l0000B
ooooo`;o00001oooool2o`00013ooooo0_l00013ooooo`;o00002?ooool4o`0000?ooooo0_l00008
ooooo`;o00001?ooool2o`0000Sooooo0_l00003ooooo`;o00001?ooool2o`0001gooooo0_l0000H
ooooo`;o00000oooool2o`0000;ooooo0_l0000Oooooo`;o00005oooool002Wooooo00?o0000oooo
ooooool01Oooool2o`0000[ooooo0ol0000Yooooo`;o000000?oooooo`000?l00000B?ooool2o`00
00oooooo0_l00008ooooo`;o00001?ooool2o`0000cooooo1?l00003ooooo`;o000000Coooooo`00
0?l0003ooooo0_l0000Gooooo`;o00003Oooool2o`0000Wooooo0ol00006ooooo`;o00002?ooool2
o`0000[ooooo0_l0000Rooooo`00:Oooool00ol0003oooooooooo`02ooooo`;o0000;?ooool4o`00
0009oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^kooooo00;o000000Cok^k^o`000?l0003o
<S8b0_l00004ooooo`;o00008_ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool2o`0000Cooooo0_l0000;ooooo`;o00003_ooool2
o`000005oiRHV?l@413o0000oc8b<_o<c<`00oooool3o`000004oc8b<_o^k^koooooooooo`Co0000
00?o<S8bo`000?l000000oooool2o`000003ooooool0003o0000027ooooo1?l000001ooooooo0000
o`000?lb<S;o0000oc8b<_o^k^h00oooool00oo^k^ko<S8bo`000002o`0000gooooo0_l000000ooo
oooo0000o`00000:ooooo`;o00002oooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool002Wooooo00?o
0000ooooooooool00_ooool2o`000003ooooool0003o000001Oooooo0_l00005ooooo`;o00001_oo
ool2o`0000;ooooo0_l00004ooooo`03ogMgMol0003o000000;o00000oooool01?mgMgOoV9RHoooo
oonHV9P2o`0000Cooooo0_l0000>ooooo`;o00004_ooool00onHV9So8B4Qonk^kP02o`0000?ooooo
00?oMgMgoiRHV?ooool00_l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool2o`0000Co
oooo1?l00009ooooo`;o00002_ooool2o`0000;ooooo0_l000001Ol@413o^[ZjoooooomgMgOo<S8b
00?ooooo0_l000000oooooooV9RHogMgM`02o`000005oooooomgMgOoV9RHoooooonHV9P00_l0000W
ooooo`;o000000Coooooo`000?l0003o00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0=ooooo`;o00006_ooool2o`000004oooooomgMgOo<S8boooo
o`;o000000CoV9RHoooooonHV9SoMgMg0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000Y
ooooo`?o00001Oooool2o`0001Gooooo1?l00005ooooo`;o00001_ooool2o`0000;ooooo0_l00004
ooooo`03oa0@4?l0003o000000;o00000oooool01Ol@413ooooooooooooooooo410@01Gooooo0_l0
000Cooooo`03oiRHV?lQ8B7ok^k^00Cooooo00?o410@ooooooooool00ol00002ooooo`05oa0@4?oo
ooooooooooooool@41002oooool2o`0001Gooooo0_l00008ooooo`05o`000?ooooooooooooooool@
41000oooool01Ol@413o0000o`000?oooooo410@00?ooooo00?o410@ooooooooool09_ooool5o`00
00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41006?oo
ool2o`0000_ooooo0_l00002ooooo`;o00000_ooool4o`0000?ooooo00Go410@oooooooooooooooo
oa0@4003ooooo`03oa0@4?oooooooooo007ooooo000Yooooo`?o00007?ooool2o`0001Cooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooooooool2o`0000;ooooo00Go0000oooooooooooo
ooooo`00000[ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Co0000oooooooooooooooo0_l00002oooo
o`05o`000?ooooooooooooooool000007_ooool2o`0000_ooooo00?oZJVYoa0@4?ooool00_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooooooo0_l0000Iooooo`;o0000
0oooool2o`0000Oooooo00CoA4A4omgMgOl0003o00001?ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`00000Hooooo`;o00002oooool3o`0000Cooooo00?oMgMg
oc8b<_l000000_l00003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`01ooooo`00:Oooool01?l0003oooooo`000?l0000Zooooo`;o00000_ooool2o`000003ooooool0
003ooooo00?ooooo00Co0000oooooooooooooooo0_l00002ooooo`05o`000?ooooooooooooooool0
00009oooool2o`0000?ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`;o00002_ooool00ol@413o0000okZj^P03
ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooooooool2o`0001Wooooo
0_l00003ooooo`Co00001Oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000002Kooooo0_l000001_oooooo0000ob4Q8Ol0
003o<S8bolc<c0;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool002Wooooo00Co0000ooooool0003o00002oooool2o`0000cooooo0_l0000=oooo
o`Co00000_ooool2o`000003ooooool0003ooooo00?ooooo00Go410@oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@41000_ooool2o`0000Wooooo0_l0000Hooooo`;o00001?oo
ool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo01Sooooo0_l00007ooooo`;o00001_ooool00onj^[[o8B4Qooooo`02ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@01oooooo1?l00006
ooooo`03ogMgMoo<c<co000000Cooooo00Go410@o`000?l0003ooooooa0@4003ooooo`05oa0@4?oo
ooooooooooooool@41005_ooool2o`00017ooooo00?o0000ooooooooool01?ooool01Ol@413ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`00:Oooool00ol0003o
ooooooooo`0<ooooo`;o00003?ooool2o`0000gooooo0_l00007ooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool2
o`0000Wooooo0_l0000Jooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`;o00001oooool2o`000008
ooooool0003o0000oa0@4?nHV9SooooookZj^_l00002ooooo`;o000000CoV9RHoooooonHV9SoMgMg
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo0_l0000Kooooo`;o00002?ooool00oo^k^ko
A4A4o`000004ooooo`05ogMgMol0003o0000oiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg01;ooooo0_l00002ooooo`;o00004Oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000Yooooo`03o`000?oo
oooooooo033ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Eooooo`;o00004_ooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_oo
ool5o`000004oa0@4?nYZJWoooooooooo`;o000000Co<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00;ooooo0_l0000Vooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2o`0000_ooooo1?l0
000Booooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`00:Oooool2o`0004;ooooo0_l0000Fooooo`;o0000@_ooool4o`0000Wooooo
0ol0000Looooo`Co0000<oooool3o`0000;ooooo0_l00009ooooo`;o00004Oooool3o`0001Kooooo
000Yooooo`03o`000?oooooooooo01Wooooo0_l00002ooooo`;o00005Oooool2o`0000_ooooo0_l0
000fooooo`;o00008_ooool4o`0000[ooooo0_l0000=ooooo`;o00003Oooool4o`0001gooooo0_l0
000=ooooo`;o00000_ooool2o`000003ooooool0003o000000?ooooo0_l0000Looooo`Co00005Ooo
ool002Wooooo00?o0000ooooooooool06Oooool2o`0000;ooooo0_l000000ooooooo0000o`000006
ooooo`;o00002_ooool2o`0002Sooooo0_l0000Aooooo`?o00001Oooool2o`0002;ooooo0_l0000G
ooooo`;o00000_ooool2o`0002kooooo0_l0000=ooooo`;o00000_ooool2o`0000Gooooo0_l0000O
ooooo`;o00005Oooool002Wooooo00?o0000ooooooooool05oooool2o`0000Oooooo0_l00006oooo
o`;o0000=?ooool2o`00017ooooo0ol0000:ooooo`;o00004_ooool2o`0000Gooooo0_l0000Koooo
o`;o0000;Oooool2o`0000Cooooo0_l00009ooooo`;o00003?ooool2o`0003Kooooo000Yooooo`03
o`000?oooooooooo00?ooooo0_l0000Booooo`;o0000@_ooool2o`00027ooooo0_l0000:ooooo`;o
00001_ooool2o`0000Gooooo0_l0000Yooooo`;o00001Oooool2o`0001Cooooo0_l00002ooooo`;o
00001?ooool2o`0000Wooooo0_l00004ooooo`;o00007_ooool2o`0001kooooo000Qoooooooo0000
A?l00004ooooo`00:Oooool01?l0003oooooooooooooool2o`0000Kooooo00?o0000ooooooooool0
1oooool2o`000003ooooool0003ooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00[ooooo0_l00003ooooo`Go00000_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Cooooo0_l00003ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool00_ooool2o`0000Gooooo00?o0000ooooooooool01oooool3o`0000_ooooo
00?o0000ooooooooool00_ooool2o`0000Kooooo00Co0000oooooooooooooooo0_l00006ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Oooooo0ol0000;ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo0_l0000;ooooo`03
o`000?oooooooooo00[ooooo000Yooooo`04o`000?ooooooooooooooo`;o00004?ooool2o`0000Go
oooo0_l0000Nooooo`03o`000?oooooooooo00[ooooo0_l00005ooooo`?o00009oooool00ol0003o
ooooooooo`02ooooo`;o00001?ooool2o`0000Oooooo1?l0000Cooooo`;o00004?ooool00ol0003o
ooooooooo`0Eooooo`;o00002Oooool2o`0001Sooooo00?o0000ooooooooool09Oooool2o`0001?o
oooo00?o0000ooooooooool02_ooool002Wooooo00?o0000ooooooooool06_ooool2o`0003Sooooo
0_l0000]ooooo`;o00001?ooool2o`000003ooooool0003o000000Oooooo0_l0000<ooooo`;o0000
3_ooool2o`0001;ooooo0_l00004ooooo`;o00002Oooool2o`0001;ooooo0_l0000Aooooo`;o0000
2Oooool4o`0000cooooo0_l00004ooooo`;o00006_ooool002Wooooo00?o0000ooooooooool0E?oo
ool2o`0000cooooo0_l0000:ooooo`;o00003Oooool2o`0000[ooooo0_l0000:ooooo`;o00001ooo
ool2o`0001?ooooo0_l0000Booooo`;o00001?ooool2o`000003ooooool0003o000001[ooooo0_l0
000:ooooo`;o00001Oooool2o`0000Wooooo1?l000000ooooooo0000o`00000?ooooo`;o00006_oo
ool002Wooooo0_l000000ooooooo0000o`00001Hooooo`;o00001_ooool2o`0000[ooooo0_l0000=
ooooo`;o00003_ooool2o`0000oooooo0_l0000Cooooo`;o00006?ooool2o`000003ooooool0003o
000002Kooooo0_l0000Eooooo`;o00003oooool2o`0001[ooooo000Yooooo`03o`000?oooooooooo
00;o0000:_ooool2o`0002cooooo0_l0000aooooo`;o00001Oooool2o`0002cooooo0_l000000ooo
oooo0000o`00000Kooooo`;o00002oooool2o`0000_ooooo0_l0000Mooooo`;o00000oooool2o`00
01[ooooo000Yooooo`03o`000?oooooooooo02cooooo0_l00008ooooo`;o0000A?ooool2o`0001Ko
oooo0_l00002ooooo`;o0000:?ooool2o`000003ooooool0003o000000[ooooo1Ol0000<ooooo`;o
00002oooool2o`0000Kooooo0_l00003ooooo`;o000000?oooooo`000?l000006_ooool2o`0000_o
oooo0_l0000Booooo`00:Oooool00ol0003oooooooooo`0=ooooo`;o00005?ooool2o`0000Gooooo
0_l00009ooooo`?o00001oooool2o`0003;ooooo0_l00007ooooo`;o000000Coooooo`000?l0003o
oooo0_l0000Dooooo`Co00007oooool2o`0000cooooo0_l00006ooooo`Oo00007oooool2o`0000Ko
oooo0_l00007ooooo`;o00001oooool2o`0001?ooooo1?l0000Booooo`00:Oooool00ol0003ooooo
ooooo`0=ooooo`;o00005?ooool2o`0000Gooooo0_l00009ooooo`;o00002?ooool2o`0001kooooo
0_l0000Booooo`;o00001oooool2o`000004ooooool0003o0000ooooo`;o00005_ooool2o`0001oo
oooo0_l0000<ooooo`;o00000oooool2o`0000Cooooo1?l0000/ooooo`;o00000_ooool2o`0000Oo
oooo0_l0000<ooooo`;o00001Oooool2o`0001Cooooo000Yooooo`;o00008oooool2o`0000?ooooo
0_l0000[ooooo`;o00001_ooool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000
o`00000aooooo`;o00001_ooool2o`0002[ooooo0_l00004ooooo`;o0000;_ooool2o`0001Wooooo
0_l0000Kooooo`00:Oooool00ol0003oooooooooo`0Rooooo`;o00000oooool2o`0002_ooooo0_l0
0006ooooo`Go00000oooool2o`000003ooooool0003o000002Kooooo0_l00006ooooo`;o000000?o
ooooo`000?l000001_ooool2o`0004;ooooo0_l00015ooooo`;o00003Oooool002Wooooo00?o0000
ooooooooool02?ooool2o`0000[ooooo0_l0000^ooooo`;o00005oooool4o`0001?ooooo0_l0000I
ooooo`Co00001?ooool2o`0000gooooo0_l000000ooooooo0000o`00000kooooo`;o00001oooool2
o`0003cooooo0_l0000=ooooo`00:Oooool00ol0003oooooooooo`08ooooo`;o00000_ooool3o`00
00Gooooo0_l0000Xooooo`;o00001?ooool2o`0000[ooooo0_l0000Rooooo`;o00003oooool2o`00
00[ooooo0_l0000Cooooo`;o000000?oooooo`000?l000000_ooool2o`00043ooooo0_l0000]oooo
o`;o00007?ooool002Wooooo00?o0000ooooooooool03?ooool3o`0000Gooooo0_l0000;ooooo`;o
00003oooool2o`0000[ooooo0_l0000@ooooo`;o00001_ooool2o`0002_ooooo0_l0000Vooooo`?o
00001?ooool2o`0003?ooooo0_l00006ooooo`;o0000:oooool2o`0000Wooooo0_l0000Aooooo`00
:Oooool2o`0001Wooooo0_l00002ooooo`;o00000oooool3o`0000kooooo0_l0000Tooooo`;o0000
COooool2o`0000Gooooo0ol00003ooooo`;o0000<oooool2o`0000Kooooo0_l000000ooooooo0000
o`00000cooooo`;o00004Oooool002Wooooo00?o0000ooooooooool06?ooool2o`0000;ooooo0_l0
0004ooooo`;o0000=?ooool2o`0000;ooooo0_l00007ooooo`Oo00002_ooool2o`0000;ooooo0_l0
000<ooooo`;o00007Oooool2o`0000Kooooo0_l0000Mooooo`;o00009?ooool3o`0001Kooooo0_l0
000]ooooo`00:Oooool01?l0003oooooo`000?l0000Gooooo`;o00006?ooool2o`0000;ooooo0_l0
000Tooooo`;o00001oooool7o`0000[ooooo0_l00002ooooo`;o00003?ooool2o`0001Sooooo0_l0
000Rooooo`;o00001_ooool2o`0002Gooooo0_l00003ooooo`;o00000_ooool2o`0000gooooo0_l0
000Hooooo`;o00004oooool002Wooooo00Co0000ooooool0003o00005oooool2o`0001?ooooo0_l0
0003ooooo`;o00000_ooool2o`0004cooooo0_l0000Looooo`;o00008_ooool2o`0003;ooooo0_l0
0002ooooo`;o00005Oooool2o`00013ooooo0_l0000Cooooo`00:Oooool00ol0003oooooooooo`0G
ooooo`;o00000_ooool2o`00013ooooo0_l0000mooooo`;o00005_ooool2o`0003Wooooo0_l0000H
ooooo`;o0000;?ooool2o`0000cooooo0_l0000Uooooo`00:Oooool2o`0001?ooooo0_l00003oooo
o`;o00000_ooool2o`0004oooooo0_l0001Aooooo`;o00006?ooool4o`0002Kooooo0_l00002oooo
o`;o0000<oooool002Wooooo00?o0000ooooooooool04_ooool2o`0004cooooo0ol00008ooooo`;o
0000?Oooool2o`0002_ooooo0_l00002ooooo`;o00009_ooool2o`0000oooooo0_l0000Booooo`;o
00000oooool2o`0000gooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool2o`0003gooooo0_l0000Roooo
o`?o00002?ooool2o`0001[ooooo0_l0000Fooooo`?o00002?ooool2o`0002_ooooo0_l0000koooo
o`;o00004_ooool2o`0000?ooooo0_l0000=ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04
ooooo`;o0000?Oooool2o`0004Wooooo0_l00006ooooo`;o00003_ooool3o`0004;ooooo0_l0000E
ooooo`;o0000<Oooool2o`0000cooooo0006ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0>_ooool2
o`0001Cooooo0ol0000looooo`;o00004_ooool2o`0001kooooo0_l0000>ooooo`;o00003_ooool3
o`0001Gooooo0_l0000@ooooo`;o00003_ooool2o`0000oooooo0_l0000<ooooo`001_ooool01Ol0
003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04
ooooo`?o00003_ooool2o`0001kooooo0_l0000:ooooo`;o00003_ooool2o`0000Cooooo0ol0000@
ooooo`;o0000?_ooool2o`0000_ooooo0_l0000Aooooo`;o00003_ooool4o`0000cooooo0_l0000Q
ooooo`;o00001Oooool2o`0000Oooooo0ol00004ooooo`;o00007Oooool000Kooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo00kooooo0_l0000Nooooo`;o00006?ooool4o`000003ooooool0
003o000000Cooooo0_l0000>ooooo`;o00005_ooool2o`0000Cooooo0_l00006ooooo`;o00001Ooo
ool2o`0001kooooo0_l00006ooooo`;o00004_ooool2o`0000Oooooo0_l0000_ooooo`;o00003_oo
ool3o`0000Cooooo0_l0000Mooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Sooooo0_l0
0003ooooo`;o00001?ooool2o`0002Kooooo0_l00004ooooo`;o00001_ooool2o`0000Gooooo0_l0
000Vooooo`;o00004_ooool2o`0001?ooooo0_l0000booooo`;o00005?ooool2o`0000oooooo0006
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo
00?o0000ooooooooool01oooool2o`00013ooooo0_l0000aooooo`;o00001oooool2o`0009Cooooo
0_l0000booooo`;o00005?ooool2o`0000oooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o00002_ooool2o`0000Co
oooo0_l0000Mooooo`;o00004_ooool2o`0000Cooooo0_l000000ooooooo0000o`000009ooooo`;o
0000N?ooool2o`0004Kooooo0_l0000Rooooo`00:Oooool2o`0000[ooooo0ol00003ooooo`;o0000
7Oooool2o`0000gooooo0_l00009ooooo`;o00003?ooool2o`0001[ooooo0_l0000<ooooo`;o0000
C_ooool2o`000003ooooool0003o0000017ooooo0_l0000Rooooo`;o00003?ooool2o`0002;ooooo
000Yooooo`03o`000?oooooooooo00[ooooo0_l0000aooooo`;o00003_ooool2o`0001Gooooo0_l0
000<ooooo`;o00003?ooool2o`0000kooooo1?l0000Jooooo`;o00008oooool2o`0000Kooooo0_l0
0009ooooo`?o00008Oooool2o`00033ooooo000Yooooo`03o`000?oooooooooo00Wooooo0ol0000d
ooooo`;o00001oooool2o`0000;ooooo0_l0000Eooooo`;o00006Oooool2o`0000Gooooo0_l00008
ooooo`Co00006_ooool2o`0000Gooooo0_l00005ooooo`;o00003?ooool2o`0000oooooo0_l0000:
ooooo`;o0000Doooool002Wooooo00?o0000ooooooooool01?ooool2o`000003ooooool0003o0000
00Co00006_ooool2o`0001Oooooo0_l00004ooooo`;o000000?oooooo`000?l000000_l0000boooo
o`;o00001Oooool2o`0002gooooo0_l00005ooooo`?o00002oooool2o`00027ooooo0_l0001=oooo
o`00:Oooool00ol0003oooooooooo`04ooooo`;o000000?oooooo`000?l000000_ooool2o`0001[o
oooo0_l0000Mooooo`;o00000oooool2o`0000kooooo0_l0000Booooo`;o0000C?ooool2o`0002ko
oooo0_l00002ooooo`;o0000BOooool002Wooooo0_l0001Looooo`;o00004_ooool2o`0003oooooo
0_l0000oooooo`;o0000BOooool002Wooooo00?o0000ooooooooool0JOooool2o`0004Gooooo0_l0
001Cooooo`;o0000=Oooool002Wooooo00?o0000ooooooooool0=oooool2o`00033ooooo0_l0002J
ooooo`;o0000=Oooool002Wooooo00?o0000ooooooooool0=oooool2o`000?oooooo1?ooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o
0000ooooooooool0=Oooool2o`000?oooooo1_ooool002Wooooo00?o0000ooooooooool0=Oooool2
o`00043ooooo0_l0002Fooooo`;o0000:oooool002Wooooo00?o0000ooooooooool0Moooool2o`00
09Kooooo0_l0000[ooooo`00:Oooool00ol0003oooooooooo`1jooooo`;o0000`?ooool002Wooooo
0_l0001kooooo`;o0000`?ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`003_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1Oooool00ol0003oooooooooo`2<ooooo`;o0000[_ooool000kooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo08cooooo
0_l0002^ooooo`003_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool0
0oooool3o`000?oooooo?Oooool000kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0coooool2o`0002;ooooo0_l00017ooooo`003_oo
ool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0<oooooo0_l0000Rooooo`;o00005_ooool2o`0002oooooo000>ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01go
oooo0_l0000<ooooo`;o0000g_ooool2o`0002oooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01gooooo0_l0000<ooooo`;o
00003?ooool2o`000?oooooo0_ooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co
00001_ooool2o`0003[ooooo0_l0003oooooo`;ooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooo`Sooooo0_l0000cooooo`00:Oooool00ol0003oooooooooo`13ooooo`;o0000`_ooool2o`00
027ooooo0_l0000@ooooo`00:Oooool2o`0004Cooooo0_l0002Sooooo`;o0000@?ooool2o`00013o
oooo000Yooooo`03o`000?oooooooooo05Oooooo0_l0001Mooooo`;o0000<?ooool2o`0005;ooooo
000Yooooo`03o`000?oooooooooo05Oooooo0_l0001Mooooo`;o0000Q?ooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o
0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooo
oa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo
?Oooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05o`000?oo
ooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@
41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooo
oooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmoooo
o`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`00
0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`00
0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Oooooo`Co000000?o
410@ooooooooool00oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05oooo
o`?o0000oooooolmooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Oooooo`03oeEEEOmVIVKo00000?ooooooAoooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .30982 Mdot
.02762 .3454 Mdot
.02952 .30464 Mdot
.03143 .33231 Mdot
.03333 .34297 Mdot
.03524 .24476 Mdot
.03714 .31353 Mdot
.03905 .34594 Mdot
.04095 .3366 Mdot
.04286 .26883 Mdot
.04476 .25472 Mdot
.04667 .29313 Mdot
.04857 .38521 Mdot
.05048 .26489 Mdot
.05238 .24093 Mdot
.05429 .3168 Mdot
.05619 .30516 Mdot
.0581 .38674 Mdot
.06 .29129 Mdot
.0619 .4267 Mdot
.06381 .4008 Mdot
.06571 .37786 Mdot
.06762 .39449 Mdot
.06952 .39462 Mdot
.07143 .22889 Mdot
.07333 .37105 Mdot
.07524 .27387 Mdot
.07714 .30343 Mdot
.07905 .42544 Mdot
.08095 .36151 Mdot
.08286 .40976 Mdot
.08476 .35472 Mdot
.08667 .32714 Mdot
.08857 .26078 Mdot
.09048 .26035 Mdot
.09238 .41608 Mdot
.09429 .39669 Mdot
.09619 .29555 Mdot
.0981 .41177 Mdot
.1 .30624 Mdot
.1019 .24712 Mdot
.10381 .26441 Mdot
.10571 .24169 Mdot
.10762 .29056 Mdot
.10952 .27273 Mdot
.11143 .35896 Mdot
.11333 .25513 Mdot
.11524 .38368 Mdot
.11714 .36786 Mdot
.11905 .41803 Mdot
.12095 .3782 Mdot
.12286 .41717 Mdot
.12476 .41618 Mdot
.12667 .24285 Mdot
.12857 .25118 Mdot
.13048 .32759 Mdot
.13238 .33303 Mdot
.13429 .31916 Mdot
.13619 .39126 Mdot
.1381 .26649 Mdot
.14 .36372 Mdot
.1419 .23167 Mdot
.14381 .40487 Mdot
.14571 .31958 Mdot
.14762 .28271 Mdot
.14952 .34984 Mdot
.15143 .26596 Mdot
.15333 .30622 Mdot
.15524 .28118 Mdot
.15714 .40289 Mdot
.15905 .33769 Mdot
.16095 .32289 Mdot
.16286 .25899 Mdot
.16476 .28128 Mdot
.16667 .40472 Mdot
.16857 .27852 Mdot
.17048 .41657 Mdot
.17238 .36543 Mdot
.17429 .42028 Mdot
.17619 .34463 Mdot
.1781 .41489 Mdot
.18 .36435 Mdot
.1819 .33143 Mdot
.18381 .26773 Mdot
.18571 .35314 Mdot
.18762 .33056 Mdot
.18952 .34467 Mdot
.19143 .35988 Mdot
.19333 .3375 Mdot
.19524 .30123 Mdot
.19714 .2263 Mdot
.19905 .35411 Mdot
.20095 .33097 Mdot
.20286 .35651 Mdot
.20476 .33 Mdot
.20667 .32896 Mdot
.20857 .26562 Mdot
.21048 .35634 Mdot
.21238 .41897 Mdot
.21429 .34914 Mdot
.21619 .32482 Mdot
.2181 .35339 Mdot
.22 .27498 Mdot
.2219 .30761 Mdot
.22381 .4127 Mdot
.22571 .25777 Mdot
.22762 .32009 Mdot
.22952 .29867 Mdot
.23143 .33098 Mdot
.23333 .40581 Mdot
.23524 .27088 Mdot
.23714 .33811 Mdot
.23905 .35186 Mdot
.24095 .42316 Mdot
.24286 .46482 Mdot
.24476 .28184 Mdot
.24667 .36668 Mdot
.24857 .36899 Mdot
.25048 .36725 Mdot
.25238 .38053 Mdot
.25429 .38822 Mdot
.25619 .22316 Mdot
.2581 .40326 Mdot
.26 .42693 Mdot
.2619 .40468 Mdot
.26381 .32506 Mdot
.26571 .42236 Mdot
.26762 .31166 Mdot
.26952 .36105 Mdot
.27143 .26618 Mdot
.27333 .38767 Mdot
.27524 .34051 Mdot
.27714 .27017 Mdot
.27905 .24099 Mdot
.28095 .24185 Mdot
.28286 .42584 Mdot
.28476 .41665 Mdot
.28667 .42328 Mdot
.28857 .25862 Mdot
.29048 .30116 Mdot
.29238 .24578 Mdot
.29429 .28225 Mdot
.29619 .33988 Mdot
.2981 .28117 Mdot
.3 .3079 Mdot
.3019 .42526 Mdot
.30381 .35948 Mdot
.30571 .4788 Mdot
.30762 .33535 Mdot
.30952 .36108 Mdot
.31143 .23227 Mdot
.31333 .35901 Mdot
.31524 .26088 Mdot
.31714 .39283 Mdot
.31905 .32192 Mdot
.32095 .27802 Mdot
.32286 .41085 Mdot
.32476 .41013 Mdot
.32667 .35707 Mdot
.32857 .39064 Mdot
.33048 .41236 Mdot
.33238 .3723 Mdot
.33429 .42357 Mdot
.33619 .29167 Mdot
.3381 .4148 Mdot
.34 .24651 Mdot
.3419 .33545 Mdot
.34381 .35733 Mdot
.34571 .41429 Mdot
.34762 .28019 Mdot
.34952 .42086 Mdot
.35143 .41388 Mdot
.35333 .33741 Mdot
.35524 .28307 Mdot
.35714 .3528 Mdot
.35905 .33271 Mdot
.36095 .3044 Mdot
.36286 .32562 Mdot
.36476 .27879 Mdot
.36667 .26961 Mdot
.36857 .42114 Mdot
.37048 .42397 Mdot
.37238 .28674 Mdot
.37429 .30571 Mdot
.37619 .24465 Mdot
.3781 .27705 Mdot
.38 .32703 Mdot
.3819 .31955 Mdot
.38381 .37406 Mdot
.38571 .29016 Mdot
.38762 .24147 Mdot
.38952 .22386 Mdot
.39143 .42547 Mdot
.39333 .31454 Mdot
.39524 .23619 Mdot
.39714 .34674 Mdot
.39905 .2475 Mdot
.40095 .2747 Mdot
.40286 .35571 Mdot
.40476 .35507 Mdot
.40667 .31613 Mdot
.40857 .27821 Mdot
.41048 .27681 Mdot
.41238 .32315 Mdot
.41429 .34913 Mdot
.41619 .36682 Mdot
.4181 .34066 Mdot
.42 .30372 Mdot
.4219 .25189 Mdot
.42381 .34171 Mdot
.42571 .27321 Mdot
.42762 .25385 Mdot
.42952 .37382 Mdot
.43143 .36613 Mdot
.43333 .41459 Mdot
.43524 .29773 Mdot
.43714 .33978 Mdot
.43905 .36529 Mdot
.44095 .28396 Mdot
.44286 .26771 Mdot
.44476 .28567 Mdot
.44667 .32078 Mdot
.44857 .3661 Mdot
.45048 .3722 Mdot
.45238 .41228 Mdot
.45429 .41428 Mdot
.45619 .29054 Mdot
.4581 .33528 Mdot
.46 .32546 Mdot
.4619 .3371 Mdot
.46381 .24149 Mdot
.46571 .22271 Mdot
.46762 .32714 Mdot
.46952 .28284 Mdot
.47143 .38371 Mdot
.47333 .34778 Mdot
.47524 .26181 Mdot
.47714 .22353 Mdot
.47905 .28677 Mdot
.48095 .31213 Mdot
.48286 .39774 Mdot
.48476 .33487 Mdot
.48667 .23567 Mdot
.48857 .24064 Mdot
.49048 .4172 Mdot
.49238 .33769 Mdot
.49429 .36731 Mdot
.49619 .33162 Mdot
.4981 .39927 Mdot
.5 .31187 Mdot
.5019 .33952 Mdot
.50381 .40855 Mdot
.50571 .24481 Mdot
.50762 .28132 Mdot
.50952 .32185 Mdot
.51143 .39132 Mdot
.51333 .36952 Mdot
.51524 .28327 Mdot
.51714 .25917 Mdot
.51905 .27658 Mdot
.52095 .32297 Mdot
.52286 .38858 Mdot
.52476 .36071 Mdot
.52667 .2612 Mdot
.52857 .41494 Mdot
.53048 .26462 Mdot
.53238 .35254 Mdot
.53429 .31123 Mdot
.53619 .2562 Mdot
.5381 .25695 Mdot
.54 .41407 Mdot
.5419 .3647 Mdot
.54381 .42023 Mdot
.54571 .25182 Mdot
.54762 .27764 Mdot
.54952 .35313 Mdot
.55143 .41439 Mdot
.55333 .30925 Mdot
.55524 .31175 Mdot
.55714 .37202 Mdot
.55905 .25559 Mdot
.56095 .26378 Mdot
.56286 .42192 Mdot
.56476 .26423 Mdot
.56667 .27694 Mdot
.56857 .38686 Mdot
.57048 .28791 Mdot
.57238 .29785 Mdot
.57429 .31912 Mdot
.57619 .35036 Mdot
.5781 .42216 Mdot
.58 .36151 Mdot
.5819 .41382 Mdot
.58381 .32425 Mdot
.58571 .38375 Mdot
.58762 .25502 Mdot
.58952 .37027 Mdot
.59143 .29319 Mdot
.59333 .40333 Mdot
.59524 .24138 Mdot
.59714 .41975 Mdot
.59905 .24428 Mdot
.60095 .4848 Mdot
.60286 .36105 Mdot
.60476 .24987 Mdot
.60667 .33689 Mdot
.60857 .36181 Mdot
.61048 .23872 Mdot
.61238 .25493 Mdot
.61429 .36604 Mdot
.61619 .36992 Mdot
.6181 .28925 Mdot
.62 .37924 Mdot
.6219 .30435 Mdot
.62381 .38987 Mdot
.62571 .23367 Mdot
.62762 .27248 Mdot
.62952 .29586 Mdot
.63143 .26017 Mdot
.63333 .27648 Mdot
.63524 .26632 Mdot
.63714 .27808 Mdot
.63905 .22726 Mdot
.64095 .27 Mdot
.64286 .32214 Mdot
.64476 .23981 Mdot
.64667 .27342 Mdot
.64857 .4019 Mdot
.65048 .32775 Mdot
.65238 .29633 Mdot
.65429 .30504 Mdot
.65619 .32049 Mdot
.6581 .33108 Mdot
.66 .38518 Mdot
.6619 .32713 Mdot
.66381 .37415 Mdot
.66571 .26508 Mdot
.66762 .32293 Mdot
.66952 .32934 Mdot
.67143 .24177 Mdot
.67333 .24629 Mdot
.67524 .37187 Mdot
.67714 .34852 Mdot
.67905 .40031 Mdot
.68095 .36651 Mdot
.68286 .36674 Mdot
.68476 .3247 Mdot
.68667 .32177 Mdot
.68857 .27258 Mdot
.69048 .4225 Mdot
.69238 .37922 Mdot
.69429 .33578 Mdot
.69619 .36418 Mdot
.6981 .27683 Mdot
.7 .3042 Mdot
.7019 .41048 Mdot
.70381 .41714 Mdot
.70571 .36692 Mdot
.70762 .30382 Mdot
.70952 .41631 Mdot
.71143 .35106 Mdot
.71333 .30157 Mdot
.71524 .25587 Mdot
.71714 .41779 Mdot
.71905 .26771 Mdot
.72095 .27385 Mdot
.72286 .26252 Mdot
.72476 .32155 Mdot
.72667 .35151 Mdot
.72857 .24175 Mdot
.73048 .32965 Mdot
.73238 .32103 Mdot
.73429 .41295 Mdot
.73619 .36001 Mdot
.7381 .24618 Mdot
.74 .32123 Mdot
.7419 .35046 Mdot
.74381 .31382 Mdot
.74571 .39666 Mdot
.74762 .38945 Mdot
.74952 .39374 Mdot
.75143 .41551 Mdot
.75333 .38836 Mdot
.75524 .23381 Mdot
.75714 .46872 Mdot
.75905 .37289 Mdot
.76095 .2697 Mdot
.76286 .32182 Mdot
.76476 .22456 Mdot
.76667 .34598 Mdot
.76857 .30317 Mdot
.77048 .29234 Mdot
.77238 .40374 Mdot
.77429 .30225 Mdot
.77619 .27465 Mdot
.7781 .36932 Mdot
.78 .26629 Mdot
.7819 .38434 Mdot
.78381 .4099 Mdot
.78571 .24028 Mdot
.78762 .28481 Mdot
.78952 .28748 Mdot
.79143 .40484 Mdot
.79333 .29365 Mdot
.79524 .32842 Mdot
.79714 .32615 Mdot
.79905 .27188 Mdot
.80095 .32638 Mdot
.80286 .29294 Mdot
.80476 .27184 Mdot
.80667 .33788 Mdot
.80857 .25309 Mdot
.81048 .32299 Mdot
.81238 .2356 Mdot
.81429 .35138 Mdot
.81619 .41699 Mdot
.8181 .33931 Mdot
.82 .26499 Mdot
.8219 .26418 Mdot
.82381 .34923 Mdot
.82571 .26428 Mdot
.82762 .25761 Mdot
.82952 .30666 Mdot
.83143 .22449 Mdot
.83333 .30567 Mdot
.83524 .31085 Mdot
.83714 .25811 Mdot
.83905 .31914 Mdot
.84095 .30317 Mdot
.84286 .35806 Mdot
.84476 .27868 Mdot
.84667 .22552 Mdot
.84857 .32613 Mdot
.85048 .32742 Mdot
.85238 .4534 Mdot
.85429 .29004 Mdot
.85619 .30465 Mdot
.8581 .31297 Mdot
.86 .23764 Mdot
.8619 .25856 Mdot
.86381 .38306 Mdot
.86571 .40535 Mdot
.86762 .3387 Mdot
.86952 .30655 Mdot
.87143 .33964 Mdot
.87333 .41616 Mdot
.87524 .35318 Mdot
.87714 .35472 Mdot
.87905 .27768 Mdot
.88095 .24434 Mdot
.88286 .27666 Mdot
.88476 .32202 Mdot
.88667 .26867 Mdot
.88857 .29877 Mdot
.89048 .34267 Mdot
.89238 .27326 Mdot
.89429 .42307 Mdot
.89619 .33609 Mdot
.8981 .28604 Mdot
.9 .42162 Mdot
.9019 .41278 Mdot
.90381 .29962 Mdot
.90571 .29093 Mdot
.90762 .27384 Mdot
.90952 .33049 Mdot
.91143 .25028 Mdot
.91333 .25826 Mdot
.91524 .40666 Mdot
.91714 .36127 Mdot
.91905 .29665 Mdot
.92095 .42309 Mdot
.92286 .32051 Mdot
.92476 .3009 Mdot
.92667 .36445 Mdot
.92857 .26796 Mdot
.93048 .22318 Mdot
.93238 .24627 Mdot
.93429 .28469 Mdot
.93619 .24246 Mdot
.9381 .34848 Mdot
.94 .32359 Mdot
.9419 .31105 Mdot
.94381 .24401 Mdot
.94571 .24155 Mdot
.94762 .28038 Mdot
.94952 .36839 Mdot
.95143 .34826 Mdot
.95333 .33697 Mdot
.95524 .30772 Mdot
.95714 .2662 Mdot
.95905 .31885 Mdot
.96095 .31767 Mdot
.96286 .45846 Mdot
.96476 .31377 Mdot
.96667 .33762 Mdot
.96857 .35656 Mdot
.97048 .41595 Mdot
.97238 .28447 Mdot
.97429 .42262 Mdot
.97619 .28907 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo04Oooooo0_l0000Yooooo`;o00005_ooool2o`0000;ooooo0_l0001Kooooo`;o00004oooool2
o`0001kooooo0_l0000Jooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo03Cooooo0_l0000Aooooo`;o0000:Oooool2o`0001Kooooo0_l00002ooooo`;o0000<_oo
ool2o`0002Oooooo0_l0000Cooooo`;o00000oooool2o`0001Wooooo0_l0000Jooooo`001?l00002
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool03?ooool2o`0002Kooooo0_l0002<ooooo`;o0000@Ooo
ool2o`0003Gooooo0006ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^
kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000<ooooo`;o00005?ooool2o`0003Gooooo0_l0
001Sooooo`;o00009oooool2o`0005?ooooo0006ooooo`05o`000?ooooooooooooooool000003_oo
ool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`0Rooooo`;o0000=Oooool2o`0001Wooooo0_l0000Kooooo`;o0000:oooool2o`0002Oooooo
0_l0000Aooooo`;o0000@?ooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1dooooo`;o0000
6oooool2o`0002Kooooo0_l00009ooooo`;o0000:oooool2o`0000Oooooo0_l0000=ooooo`;o0000
<Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@
41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo0_l0000@ooooo`;o
00001?ooool2o`0002oooooo0ol0000Pooooo`;o00005oooool2o`0000Kooooo0_l0000Pooooo`;o
00000oooool2o`0000Wooooo0_l00007ooooo`;o00004?ooool2o`00013ooooo0_l0000Fooooo`;o
00005oooool2o`000003ooooool0003o000001Gooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo
00;o00000oooool2o`00013ooooo0_l00004ooooo`;o0000;oooool3o`0000;ooooo0_l0000=oooo
o`;o00002_ooool2o`000003ooooool0003o000001Oooooo0_l00006ooooo`;o00000oooool2o`00
01_ooooo0ol0000Fooooo`;o00004?ooool2o`000003ooooool0003o000002cooooo0_l0000>oooo
o`Oo00005Oooool002Wooooo0_l000000ooooooo0000o`00000Cooooo`;o0000??ooool2o`0000go
oooo0_l0000:ooooo`;o00001Oooool2o`00023ooooo0_l0000Looooo`;o00005_ooool2o`0001?o
oooo0_l0000/ooooo`;o00003_ooool2o`0000;ooooo0_l0000Fooooo`00:Oooool00ol0003ooooo
ooooo`0Eooooo`;o00001oooool2o`0005Gooooo0_l00005ooooo`;o00009_ooool2o`00017ooooo
0_l0001Qooooo`;o00008?ooool002Wooooo00?o0000ooooooooool00oooool2o`0001Cooooo0_l0
0003ooooo`;o0000G?ooool4o`0002Cooooo0_l00002ooooo`;o00002?ooool2o`0000?ooooo0_l0
00000ooooooo0000o`00000Oooooo`;o00007?ooool2o`0001oooooo0_l0000Pooooo`00:Oooool0
0ol0003oooooooooo`03ooooo`;o00005?ooool2o`0000kooooo0_l0000Booooo`;o00004_ooool2
o`0002_ooooo0_l0000Qooooo`?o00001?ooool2o`0000Sooooo0_l00006ooooo`;o00007oooool2
o`0001cooooo0_l00004ooooo`;o000000?oooooo`000?l000001_ooool2o`0000kooooo0_l0000P
ooooo`00:Oooool00ol0003oooooooooo`0Aooooo`?o00005Oooool2o`0001;ooooo0_l0000Boooo
o`;o00001oooool2o`00037ooooo0_l0000<ooooo`;o000000Coooooo`000?l0003ooooo0ol0000L
ooooo`;o0000?Oooool2o`000003ooooool0003o000000Kooooo0_l0000>ooooo`;o00008?ooool0
02Wooooo0_l00006ooooo`;o00002_ooool3o`0000;ooooo0_l00012ooooo`;o0000<Oooool2o`00
00cooooo0_l000001?oooooo0000o`000?l00008ooooo`?o00005?ooool2o`0000Wooooo0_l0000@
ooooo`;o00007Oooool4o`0003cooooo000Yooooo`03o`000?oooooooooo00Gooooo0_l0000?oooo
o`;o00002Oooool2o`0000;ooooo0_l00009ooooo`;o00001_ooool2o`0001;ooooo0_l0000eoooo
o`;o00006_ooool2o`0000Sooooo0ol0000Eooooo`;o00002?ooool2o`0000oooooo0ol0000@oooo
o`;o00002oooool4o`0001oooooo0_l00007ooooo`;o00004_ooool002Wooooo00?o0000oooooooo
ool00_ooool2o`0001gooooo0_l00002ooooo`;o00002Oooool4o`000004oa0@4?ooooooooooonk^
kP;o000000?o<S8bonk^k_ooool00_ooool01Oo^k^ko0000o`000?lb<S;ok^k^00Sooooo1?l0000K
ooooo`Oo00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Kok^k^oc8b<_l0003o<S8b
onk^k_ooool2o`0002Gooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo1?l0000Gooooo`;o00002ooo
ool2o`000004oa0@4?ooooooooooooooo`?o000000?o<S8bonk^k_ooool00_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01Kooooo0_l0000;ooooo`;o00001?ooool00om4A4Co0000o`000002o`0000;o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
02Wooooo00?o0000ooooooooool00_ooool2o`0000Wooooo0_l00009ooooo`;o00006?ooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOo0000o`000?nH
V9SoMgMg00[ooooo0_l0000Kooooo`;o000000GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool2o`000003oooooonHV9SoMgMg02Sooooo00Go410@okZj^_oo
ooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01?mgMgOoV9RHoooooonH
V9P2o`0000?ooooo1?l0000;ooooo`;o00002?ooool2o`0000_ooooo0_l00004ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00_ooool3o`000003oooooonHV9SoMgMg01Kooooo1?l00002ooooo`;o0000
3_ooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool002Wooooo00?o0000ooooooooool03Oooool2o`0000Wooooo0_l0000H
ooooo`03o`000?oooooooooo00;ooooo00Co410@oooooooooooooooo0_l00002ooooo`05oa0@4?oo
ooooooooooooool@4100:_ooool2o`000003onk^k_oooooooooo00;ooooo00Co410@o`000?l0003o
oooo0_l00002ooooo`;o00000_ooool00ol@413oooooooooo`0Hooooo`;o00001oooool2o`0000Co
oooo0_l000000ooooooo0000ooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01?l@
413oooooooooooooool4o`0000?ooooo0_l0000;ooooo`;o000000?oooooo`000?l000001Oooool2
o`0000Wooooo1Ol00002ooooo`;o00000oooool00ol@413oooooooooo`03o`0000;ooooo00?o410@
ooooooooool04Oooool3o`0000;ooooo0_l00002ooooo`;o00003oooool01?l0003oooooooooool@
4103ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`01ooooo`00:Ooo
ool2o`0002cooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo
0_l00002ooooo`05o`000?ooooooooooooooool000006?ooool2o`0000Kooooo0_l00004ooooo`;o
00000_ooool2o`000003ob4Q8Oo^k^kooooo00;ooooo1_l00002ooooo`05o`000?oooooooooooooo
ool000006_ooool2o`0000Oooooo0_l00004ooooo`;o000000?oZJVYoa0@4?ooool00_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Ko0000ooooooooooooooooo`000?ooool3o`0001;ooooo
0_l0000@ooooo`04odA4A?oMgMgoooooo`0000?ooooo0_l00003ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`06ooooo`;o00002Oooool3o`0001?ooooo0_l000000ooo
ooooMgMgoc8b<P02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo000Yooooo`03o`000?oooooooooo02Cooooo0_l000001?oooooo0000o`000?oo
ool3o`0000Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Co0000oooooooooooooooo0_l0000>ooooo`?o00001_ooool2o`0000Kooooo0_l000001?oooooo
0000o`000?ooool2o`0000Cooooo00?oMgMgofIVI_ooool00_ooool00ol0003oooooooooo`02o`00
00?ooooo00Go0000ooooooooooooooooo`00000:ooooo`;o00002_ooool4o`00013ooooo00?o410@
o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000002ooooo`;o00009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000Sooooo0_l0000Oooooo`?o000000Go<S8b
olc<c?ooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`01ooooo`00:Oooool00ol0003oooooooooo`0Tooooo`;o000000Coooooo`000?l0003ooooo
0_l00006ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`04
oa0@4?ooooooooooooooo`;o00003_ooool3o`00017ooooo0_l00003ooooo`;o00000oooool01Ol0
003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?l0
003o000000;o00001_ooool2o`000003ooooool0003o000000Oooooo1?l0000Aooooo`03okZj^_lQ
8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
4100:Oooool00omgMgOoc<c<o`000004ooooo`03oa0@4?oooooooooo00;o00000oooool01Ol@413o
oooooooooooooooo410@01Wooooo0_l0000:ooooo`;o00000_ooool00ol0003oooooooooo`04oooo
o`05oa0@4?l0003o0000ooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo000Y
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Xooooo`;o000000?o^[ZjoooooonHV9P0
0_l00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Co00002Oooool2o`0001Wooooo00?o410@oiRHV?l000000_l00003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool01OmgMgOo0000o`000?nHV9SoMgMg02Wooooo00?ok^k^odA4A?l000001?oo
ool00omgMgOoV9RHooooo`02o`0000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`;o0000
3?ooool2o`0000[ooooo0_l00002ooooo`03o`000?oooooooooo00Cooooo00?oMgMgo`000?l00000
0_l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wooooo00?o0000ooooooooool0
1?ooool2o`0000;ooooo0_l0000=ooooo`;o00005oooool00omEEEGoIVIVo`000004ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo0_l0000:oooo
o`04oiRHV?l@413o0000ob4Q8@;o00000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o00008Oooool01OnYZJWo410@o`000?l0003oZJVY00?o
oooo00Gok^k^o`000?l0003o<S8bonk^kP03ooooo`05onk^k_l0003o0000oc8b<_o^k^h0:_ooool0
0omgMgOo0000ooooo`02o`000003ooooooo^k^ko<S8b00?o00000oooool3o`000003oc8b<_o^k^ko
oooo00[ooooo0_l0000?ooooo`;o00002oooool4o`0000?ooooo00?ok^k^oc8b<_l000000_l00003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool002Wooooo0_l00005ooooo`;o00000_ooool2
o`0000[ooooo0_l000000ooooooo0000o`000018ooooo`;o00009?ooool2o`0002[ooooo0_l0000:
ooooo`;o00001Oooool2o`0002Cooooo0_l00006ooooo`;o000000?oooooo`000?l000007oooool2
o`0002;ooooo000Yooooo`03o`000?oooooooooo01Cooooo0_l0000Xooooo`;o0000@Oooool2o`00
02[ooooo0_l0000@ooooo`;o00001Oooool2o`0002cooooo0_l0000Looooo`;o00002?ooool2o`00
01kooooo000Yooooo`03o`000?oooooooooo03?ooooo0_l00009ooooo`;o00004_ooool2o`0002go
oooo0_l0000Zooooo`;o0000:oooool2o`0001;ooooo0_l0000Rooooo`;o00000oooool2o`0000?o
oooo1?l0000Looooo`00:Oooool3o`0000Oooooo0_l00004ooooo`;o00009?ooool2o`0001gooooo
0_l0000Eooooo`;o00000_ooool2o`0000gooooo0_l0000oooooo`;o00002?ooool2o`0000gooooo
1_l0000@ooooo`Co00004Oooool4o`0000?ooooo0_l0000=ooooo`;o00001Oooool2o`0001cooooo
000Yooooo`?o00001oooool2o`0000Cooooo0_l00006ooooo`;o00003oooool2o`0001Cooooo0_l0
000Gooooo`;o00004_ooool2o`0000;ooooo0_l0000=ooooo`;o0000?oooool2o`0000Sooooo0_l0
000=ooooo`Co00004_ooool2o`00017ooooo1_l00003ooooo`;o00000_ooool2o`0001[ooooo0_l0
000Booooo`008Oooooooo`0004Co00001?ooool002Wooooo0_l00002ooooo`;o00001_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooooooo0_l00006
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05
ooooo`;o00000oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo0_l00004
ooooo`;o00001Oooool01?l0003oooooooooooooool2o`0000Gooooo0ol0000;ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Oooooo0ol0000;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_l0
0006ooooo`?o00002oooool00ol0003oooooooooo`09ooooo`;o00001_ooool2o`0000;ooooo00?o
0000ooooooooool02_ooool002Wooooo00Co0000oooooooooooooooo0_l00003ooooo`;o0000<_oo
ool00ol0003oooooooooo`0fooooo`;o00000_ooool2o`0001Kooooo0_l0000Tooooo`03o`000?oo
oooooooo02cooooo0_l0000<ooooo`03o`000?oooooooooo01Cooooo0_l0000Oooooo`?o00000_oo
ool00ol0003oooooooooo`0:ooooo`00:Oooool00ol0003oooooooooo`06ooooo`;o00006?ooool2
o`000003ooooool0003o000001Wooooo0_l0000_ooooo`;o00001_ooool2o`0000_ooooo0_l0000W
ooooo`;o00006Oooool2o`0001Kooooo0_l000000ooooooo0000o`00000Mooooo`;o00006Oooool2
o`0000[ooooo0ol0000@ooooo`00:Oooool00ol0003oooooooooo`0Pooooo`;o000000?oooooo`00
0?l000000oooool2o`0001Cooooo0_l0000Kooooo`;o00004_ooool2o`0000Sooooo0_l00009oooo
o`;o00004_ooool2o`0000;ooooo0_l0000?ooooo`;o000000?oooooo`000?l000004Oooool2o`00
00?ooooo0_l000000ooooooo0000o`000004ooooo`;o00002oooool4o`000003ooooool0003o0000
00Gooooo0_l0000=ooooo`;o00001oooool2o`0000gooooo0_l0000:ooooo`;o00001?ooool2o`00
00Cooooo0_l0000Aooooo`00:Oooool2o`00017ooooo0_l0000Fooooo`;o00004?ooool2o`0000go
oooo0_l0000@ooooo`;o00003?ooool2o`0000Cooooo0_l00008ooooo`;o00003_ooool4o`0000_o
oooo0_l00002ooooo`;o00004_ooool2o`00017ooooo0_l00004ooooo`Co00001?ooool2o`0000_o
oooo0_l0000:ooooo`;o00002Oooool3o`000003ooooool0003o000000[ooooo0ol00009ooooo`;o
00004?ooool2o`0001Oooooo000Yooooo`03o`000?oooooooooo013ooooo0_l0000=ooooo`;o0000
4?ooool2o`0000?ooooo0ol000000ooooooo0000o`00000=ooooo`;o00007_ooool2o`0000Cooooo
0_l0000Hooooo`Co0000>Oooool2o`000004ooooool0003o0000ooooo`;o00000oooool2o`0000co
oooo0_l0000Cooooo`Co00003Oooool3o`00017ooooo0_l0000Qooooo`00:Oooool01?l0003ooooo
o`000?l0000Nooooo`;o00003_ooool4o`0000;ooooo1?l00006ooooo`;o00009oooool2o`0002[o
oooo0_l0000`ooooo`Co00000_ooool2o`00017ooooo0_l0000Cooooo`;o00008oooool2o`00027o
oooo000Yooooo`05o`000?oooooo0000o`000?ooool00_l0000Kooooo`;o00003_ooool2o`0000Co
oooo0_l00008ooooo`;o00005oooool2o`0000Wooooo0_l00003ooooo`;o00007_ooool2o`0000Ko
oooo0_l00002ooooo`;o0000<_ooool2o`0000[ooooo0_l0000oooooo`;o00009Oooool002Wooooo
00?o0000ooooooooool00_ooool2o`0002Cooooo0_l00009ooooo`;o00003?ooool2o`00017ooooo
0_l00002ooooo`;o00002Oooool2o`000003ooooool0003o000001Wooooo0_l00005ooooo`?o0000
1Oooool2o`000004ooooool0003o0000ooooo`;o00008?ooool2o`0001[ooooo0_l0000Rooooo`;o
00000_ooool2o`0000kooooo0ol00006ooooo`;o00004?ooool2o`0000;ooooo0_l0000?ooooo`00
:Oooool4o`0002Oooooo0_l00009ooooo`;o00003?ooool2o`0000[ooooo0_l00005ooooo`;o0000
4?ooool2o`0001?ooooo1?l00002ooooo`;o00001_ooool2o`0000Sooooo0_l000000ooooooo0000
o`00000Pooooo`;o0000?_ooool2o`0000;ooooo0_l0000>ooooo`?o00001?ooool2o`0001;ooooo
0_l00002ooooo`;o00003oooool002Wooooo1_l0000Zooooo`;o00000oooool2o`0001Wooooo0_l0
000/ooooo`Co0000K?ooool2o`0002Kooooo0_l0000Wooooo`00:Oooool2o`0000;ooooo0_l0000Z
ooooo`;o00000oooool2o`0000Kooooo0_l0000hooooo`;o00001?ooool2o`00017ooooo0_l0000o
ooooo`;o00006oooool2o`00017ooooo0_l0000Rooooo`;o00000oooool2o`0001?ooooo000Yoooo
o`03o`000?oooooooooo02Gooooo0_l0000Cooooo`;o00001Oooool2o`00037ooooo0_l00004oooo
o`;o00004Oooool2o`0001oooooo0_l0000Nooooo`;o00002Oooool2o`0000?ooooo0_l00003oooo
o`;o00005Oooool2o`0000;ooooo0_l0000Rooooo`;o00000oooool2o`0001?ooooo000Yooooo`03
o`000?oooooooooo013ooooo0_l0000Cooooo`;o00002Oooool2o`0000?ooooo0_l00004ooooo`;o
00001?ooool2o`0002Cooooo0_l0000>ooooo`;o00009oooool2o`0000?ooooo0_l00007ooooo`;o
0000:Oooool2o`0000?ooooo0_l00003ooooo`;o00005Oooool2o`0001;ooooo0ol0000[ooooo`00
:Oooool2o`00017ooooo0_l0000Nooooo`;o00000oooool5o`000003ooooool0003o0000027ooooo
0_l00003ooooo`;o00000_ooool2o`0000gooooo0ol0000Wooooo`;o00000oooool2o`0005gooooo
0_l00008ooooo`?o00006oooool2o`0000kooooo000Yooooo`03o`000?oooooooooo00oooooo0_l0
0007ooooo`;o00006?ooool2o`0000;ooooo1?l0000Aooooo`;o00002Oooool5o`0000?ooooo0_l0
0003ooooo`;o00004Oooool2o`0002Gooooo0_l0000@ooooo`;o00001Oooool2o`0002Wooooo0_l0
000Qooooo`;o00005_ooool2o`0000kooooo0_l0000>ooooo`00:Oooool00ol0003oooooooooo`0?
ooooo`;o00001oooool2o`0000Sooooo0_l0000:ooooo`;o00000_ooool2o`0001Oooooo0_l00009
ooooo`Go0000@_ooool2o`0000Cooooo0_l0000:ooooo`;o00001Oooool4o`0001[ooooo0_l0000;
ooooo`;o0000>Oooool2o`000003ooooool0003o000001_ooooo000Yooooo`03o`000?oooooooooo
01[ooooo0_l00006ooooo`;o00002?ooool4o`0001Cooooo0ol0000cooooo`;o00000oooool2o`00
0004ooooool0003o0000ooooo`;o00003Oooool2o`0000gooooo0_l0000Cooooo`Co00005?ooool2
o`0000;ooooo0_l00002ooooo`;o0000AOooool2o`0001_ooooo000Yooooo`03o`000?oooooooooo
01[ooooo0_l0000@ooooo`;o00005_ooool3o`0003?ooooo0_l00003ooooo`;o000000Coooooo`00
0?l0003ooooo0_l0000=ooooo`;o00001?ooool2o`0001Kooooo0_l00006ooooo`?o00004oooool2
o`0000Kooooo0_l0000Eooooo`;o0000=Oooool2o`0001Cooooo000Yooooo`;o00003Oooool2o`00
03Oooooo0_l0000Hooooo`;o00003oooool2o`0000gooooo0_l00004ooooo`;o00004oooool2o`00
00cooooo0_l00008ooooo`;o00001oooool2o`00017ooooo0_l0000Iooooo`;o00001?ooool2o`00
03Gooooo0_l0000Dooooo`00:Oooool00ol0003oooooooooo`0<ooooo`;o0000DOooool2o`0000oo
oooo0_l0000=ooooo`;o00001?ooool2o`00027ooooo0_l0000Pooooo`;o00000_ooool2o`0001Wo
oooo0_l0001Aooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go
00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool02_ooool2o`00
013ooooo0_l0002Nooooo`;o00003?ooool2o`0000Oooooo0_l0001Wooooo`001_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00[ooooo0_l0000@ooooo`;o0000:?ooool2
o`0007Cooooo0_l0000Eooooo`;o0000=Oooool2o`00033ooooo0006ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01?ooool2o`0001Cooooo0_l0000Zooooo`;o0000A?ooool2o`0002?ooooo0_l0000F
ooooo`;o00009Oooool2o`0001Sooooo0_l0000`ooooo`001_ooool01Ol0003ooooooooooooooooo
000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o00001?ooool2
o`000003ooooool0003o0000017ooooo0_l0000Zooooo`;o00001Oooool2o`0003gooooo0_l0000?
ooooo`;o00003?ooool2o`0000Cooooo0_l0000Fooooo`;o00006_ooool4o`0000Oooooo0_l0001:
ooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool01oooool2o`0001Oooooo0_l0
000Tooooo`;o00001Oooool2o`0000oooooo0_l0000iooooo`;o00000_ooool2o`0000cooooo0_l0
000@ooooo`;o00009_ooool4o`0005?ooooo0006ooooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_oo
ool3o`0001?ooooo0_l0000iooooo`;o000000?oooooo`000?l00000>Oooool2o`0002;ooooo0_l0
000Wooooo`;o0000E?ooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj
^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo
0ol00006ooooo`;o0000A_ooool2o`0003?ooooo0_l0001Booooo`Co0000E?ooool000Kooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Ko
oooo00?o0000ooooooooool02Oooool2o`0000Sooooo0_l0001kooooo`;o00000oooool2o`0002ko
oooo0_l00008ooooo`;o00004oooool2o`0005Kooooo000Yooooo`;o00002_ooool2o`0001Sooooo
0_l00002ooooo`;o000000?oooooo`000?l000007?ooool3o`0004[ooooo0_l0000Looooo`;o0000
4?ooool2o`0000Sooooo0_l0000Looooo`;o00001?ooool2o`0004Oooooo000Yooooo`03o`000?oo
oooooooo02?ooooo0_l00002ooooo`;o000000?oooooo`000?l000005?ooool2o`0000Kooooo0ol0
001Xooooo`;o0000>?ooool2o`0000Cooooo0_l0000Fooooo`;o00003_ooool2o`0001oooooo000Y
ooooo`03o`000?oooooooooo00oooooo0_l0000_ooooo`;o00006_ooool3o`0003Sooooo0_l0000m
ooooo`;o00006Oooool2o`0001Sooooo0_l0000>ooooo`;o00007oooool002Wooooo00?o0000oooo
ooooool03oooool2o`0000?ooooo0_l0000Wooooo`;o00007Oooool5o`0000?ooooo1?l0000Noooo
o`?o00003_ooool2o`0000Wooooo0_l00002ooooo`;o00002?ooool2o`0002Cooooo0_l00009oooo
o`;o00003_ooool2o`0002Cooooo0_l0000Sooooo`00:Oooool00ol0003oooooooooo`0Booooo`Co
00001_ooool3o`0000cooooo0_l000000ooooooo0000o`00000=ooooo`;o00004Oooool2o`0000go
oooo1?l000000ooooooo0000o`000002o`0001Sooooo0_l00004ooooo`?o00002Oooool2o`0000_o
oooo0_l000000ooooooo0000o`000002ooooo`;o00002?ooool2o`0002Gooooo1?l00006ooooo`;o
00000oooool2o`0001?ooooo0_l0000@ooooo`;o00002?ooool2o`0001Cooooo0_l0000=ooooo`00
:Oooool2o`0001?ooooo0_l00007ooooo`Co00003?ooool5o`0000Wooooo0_l0000Eooooo`;o0000
3oooool2o`0001gooooo0_l0000@ooooo`;o00002oooool2o`0000;ooooo0_l0000@ooooo`;o0000
8?ooool6o`0000Wooooo0_l0000Cooooo`;o00004?ooool2o`0001kooooo0_l0000=ooooo`00:Ooo
ool00ol0003oooooooooo`0Kooooo`;o00004?ooool2o`0000[ooooo0_l00007ooooo`;o00001_oo
ool2o`0000Gooooo0_l0000=ooooo`;o00000oooool2o`0000Cooooo0_l0000fooooo`;o00001Ooo
ool2o`0000;ooooo0_l00005ooooo`;o00007?ooool2o`0000Kooooo0_l0000gooooo`Co00001Ooo
ool2o`0000oooooo0_l0000<ooooo`00:Oooool00ol0003oooooooooo`09ooooo`;o00000oooool2
o`0003;ooooo0_l00004ooooo`Co00001?ooool3o`0000?ooooo0_l00008ooooo`;o00000oooool2
o`0000Cooooo0ol00004ooooo`;o0000=_ooool2o`0000;ooooo0_l0000Sooooo`;o0000?oooool4
o`0000Gooooo0_l0000?ooooo`;o00003?ooool002Wooooo00?o0000ooooooooool02Oooool2o`00
00?ooooo0_l0000hooooo`;o00001_ooool2o`0000Cooooo0_l0000Dooooo`;o00001?ooool2o`00
0<Sooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo2?oo
ool2o`0003?ooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo2?ooool2o`0003?ooooo
000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`3oooooob_ooooo0_l0000@ooooo`003_ooool01Ol@413ooooooooo
oooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo:oooool2o`00013ooooo
000>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo04?ooooo0_l0003gooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo04?ooooo0_l0002Sooooo`;o
0000D_ooool000kooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0j?ooool2o`0005;ooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`0005Sooooo0_l0003Sooooo`00
:Oooool00ol0003oooooooooo`1Gooooo`;o0000hoooool002Wooooo00?o0000ooooooooool0]_oo
ool2o`0008Cooooo000Yooooo`03o`000?oooooooooo0;Kooooo0_l00024ooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o
0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooo
oa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo
?Oooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05o`000?oo
ooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@
41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooo
oooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmoooo
o`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`00
0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`00
0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Oooooo`Co000000?o
410@ooooooooool00oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05oooo
o`?o0000oooooolmooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Oooooo`03oeEEEOmVIVKo00000?ooooooAoooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .23877 Mdot
.02762 .25407 Mdot
.02952 .30828 Mdot
.03143 .33659 Mdot
.03333 .27643 Mdot
.03524 .28368 Mdot
.03714 .2762 Mdot
.03905 .42321 Mdot
.04095 .41269 Mdot
.04286 .3292 Mdot
.04476 .29555 Mdot
.04667 .39326 Mdot
.04857 .30725 Mdot
.05048 .3273 Mdot
.05238 .34879 Mdot
.05429 .34443 Mdot
.05619 .36564 Mdot
.0581 .30978 Mdot
.06 .25313 Mdot
.0619 .40299 Mdot
.06381 .3426 Mdot
.06571 .2996 Mdot
.06762 .33581 Mdot
.06952 .32572 Mdot
.07143 .32931 Mdot
.07333 .34156 Mdot
.07524 .26433 Mdot
.07714 .25212 Mdot
.07905 .41297 Mdot
.08095 .27385 Mdot
.08286 .37291 Mdot
.08476 .42228 Mdot
.08667 .41118 Mdot
.08857 .33981 Mdot
.09048 .34207 Mdot
.09238 .40977 Mdot
.09429 .43109 Mdot
.09619 .25346 Mdot
.0981 .42362 Mdot
.1 .40211 Mdot
.1019 .35901 Mdot
.10381 .3446 Mdot
.10571 .30615 Mdot
.10762 .23983 Mdot
.10952 .24835 Mdot
.11143 .30606 Mdot
.11333 .30549 Mdot
.11524 .43325 Mdot
.11714 .37019 Mdot
.11905 .41833 Mdot
.12095 .43076 Mdot
.12286 .4269 Mdot
.12476 .31002 Mdot
.12667 .31164 Mdot
.12857 .33317 Mdot
.13048 .40952 Mdot
.13238 .41617 Mdot
.13429 .37155 Mdot
.13619 .43319 Mdot
.1381 .25285 Mdot
.14 .32103 Mdot
.1419 .27336 Mdot
.14381 .42428 Mdot
.14571 .26779 Mdot
.14762 .3835 Mdot
.14952 .42082 Mdot
.15143 .32609 Mdot
.15333 .34176 Mdot
.15524 .25798 Mdot
.15714 .34428 Mdot
.15905 .3794 Mdot
.16095 .29644 Mdot
.16286 .31682 Mdot
.16476 .33632 Mdot
.16667 .42425 Mdot
.16857 .31006 Mdot
.17048 .31066 Mdot
.17238 .35136 Mdot
.17429 .42421 Mdot
.17619 .37095 Mdot
.1781 .39248 Mdot
.18 .27867 Mdot
.1819 .33525 Mdot
.18381 .34768 Mdot
.18571 .42549 Mdot
.18762 .34505 Mdot
.18952 .27888 Mdot
.19143 .31675 Mdot
.19333 .37701 Mdot
.19524 .34069 Mdot
.19714 .3191 Mdot
.19905 .23663 Mdot
.20095 .2818 Mdot
.20286 .30191 Mdot
.20476 .28113 Mdot
.20667 .22343 Mdot
.20857 .32785 Mdot
.21048 .42086 Mdot
.21238 .31394 Mdot
.21429 .38016 Mdot
.21619 .24233 Mdot
.2181 .37872 Mdot
.22 .3807 Mdot
.2219 .23771 Mdot
.22381 .37078 Mdot
.22571 .33711 Mdot
.22762 .37371 Mdot
.22952 .25135 Mdot
.23143 .28167 Mdot
.23333 .35266 Mdot
.23524 .33186 Mdot
.23714 .33104 Mdot
.23905 .42061 Mdot
.24095 .40029 Mdot
.24286 .3879 Mdot
.24476 .32405 Mdot
.24667 .33566 Mdot
.24857 .43143 Mdot
.25048 .42966 Mdot
.25238 .42542 Mdot
.25429 .31373 Mdot
.25619 .30416 Mdot
.2581 .35627 Mdot
.26 .41185 Mdot
.2619 .34899 Mdot
.26381 .34012 Mdot
.26571 .40741 Mdot
.26762 .22095 Mdot
.26952 .27594 Mdot
.27143 .28868 Mdot
.27333 .31872 Mdot
.27524 .25196 Mdot
.27714 .37799 Mdot
.27905 .29515 Mdot
.28095 .29714 Mdot
.28286 .4186 Mdot
.28476 .43306 Mdot
.28667 .41195 Mdot
.28857 .31577 Mdot
.29048 .39642 Mdot
.29238 .35517 Mdot
.29429 .22761 Mdot
.29619 .30931 Mdot
.2981 .2575 Mdot
.3 .3669 Mdot
.3019 .40037 Mdot
.30381 .428 Mdot
.30571 .41236 Mdot
.30762 .27017 Mdot
.30952 .31914 Mdot
.31143 .34304 Mdot
.31333 .37833 Mdot
.31524 .27677 Mdot
.31714 .32121 Mdot
.31905 .29022 Mdot
.32095 .24721 Mdot
.32286 .43103 Mdot
.32476 .42537 Mdot
.32667 .42542 Mdot
.32857 .42935 Mdot
.33048 .43153 Mdot
.33238 .35622 Mdot
.33429 .42284 Mdot
.33619 .39505 Mdot
.3381 .40586 Mdot
.34 .28356 Mdot
.3419 .24893 Mdot
.34381 .4266 Mdot
.34571 .37317 Mdot
.34762 .25868 Mdot
.34952 .43076 Mdot
.35143 .41708 Mdot
.35333 .31427 Mdot
.35524 .25777 Mdot
.35714 .29695 Mdot
.35905 .26602 Mdot
.36095 .39774 Mdot
.36286 .22268 Mdot
.36476 .24696 Mdot
.36667 .31375 Mdot
.36857 .41856 Mdot
.37048 .42757 Mdot
.37238 .39037 Mdot
.37429 .34474 Mdot
.37619 .3565 Mdot
.3781 .2722 Mdot
.38 .40703 Mdot
.3819 .22191 Mdot
.38381 .43146 Mdot
.38571 .39376 Mdot
.38762 .30923 Mdot
.38952 .31701 Mdot
.39143 .39905 Mdot
.39333 .26495 Mdot
.39524 .26624 Mdot
.39714 .42279 Mdot
.39905 .3609 Mdot
.40095 .38089 Mdot
.40286 .30109 Mdot
.40476 .23614 Mdot
.40667 .37352 Mdot
.40857 .32029 Mdot
.41048 .31956 Mdot
.41238 .30099 Mdot
.41429 .28932 Mdot
.41619 .24597 Mdot
.4181 .25259 Mdot
.42 .2625 Mdot
.4219 .27025 Mdot
.42381 .32202 Mdot
.42571 .2747 Mdot
.42762 .30157 Mdot
.42952 .28821 Mdot
.43143 .34785 Mdot
.43333 .37455 Mdot
.43524 .34159 Mdot
.43714 .25228 Mdot
.43905 .34652 Mdot
.44095 .38996 Mdot
.44286 .28264 Mdot
.44476 .24301 Mdot
.44667 .41042 Mdot
.44857 .33157 Mdot
.45048 .42615 Mdot
.45238 .36632 Mdot
.45429 .39978 Mdot
.45619 .33809 Mdot
.4581 .26711 Mdot
.46 .24051 Mdot
.4619 .30386 Mdot
.46381 .34964 Mdot
.46571 .31142 Mdot
.46762 .34291 Mdot
.46952 .27632 Mdot
.47143 .26543 Mdot
.47333 .37515 Mdot
.47524 .27689 Mdot
.47714 .30309 Mdot
.47905 .25597 Mdot
.48095 .23787 Mdot
.48286 .33852 Mdot
.48476 .2477 Mdot
.48667 .26648 Mdot
.48857 .30597 Mdot
.49048 .37846 Mdot
.49238 .37935 Mdot
.49429 .42871 Mdot
.49619 .28624 Mdot
.4981 .42868 Mdot
.5 .36655 Mdot
.5019 .37974 Mdot
.50381 .42459 Mdot
.50571 .3576 Mdot
.50762 .32367 Mdot
.50952 .27176 Mdot
.51143 .4277 Mdot
.51333 .35327 Mdot
.51524 .25783 Mdot
.51714 .34336 Mdot
.51905 .30837 Mdot
.52095 .4099 Mdot
.52286 .43386 Mdot
.52476 .37413 Mdot
.52667 .27783 Mdot
.52857 .40144 Mdot
.53048 .30383 Mdot
.53238 .37752 Mdot
.53429 .2394 Mdot
.53619 .29236 Mdot
.5381 .26518 Mdot
.54 .41397 Mdot
.5419 .36392 Mdot
.54381 .40715 Mdot
.54571 .33454 Mdot
.54762 .33566 Mdot
.54952 .37286 Mdot
.55143 .43086 Mdot
.55333 .34602 Mdot
.55524 .25143 Mdot
.55714 .42861 Mdot
.55905 .31362 Mdot
.56095 .2568 Mdot
.56286 .42009 Mdot
.56476 .30755 Mdot
.56667 .33299 Mdot
.56857 .4281 Mdot
.57048 .38932 Mdot
.57238 .25132 Mdot
.57429 .28334 Mdot
.57619 .29608 Mdot
.5781 .38881 Mdot
.58 .31805 Mdot
.5819 .39033 Mdot
.58381 .22293 Mdot
.58571 .42995 Mdot
.58762 .36396 Mdot
.58952 .42457 Mdot
.59143 .27048 Mdot
.59333 .43543 Mdot
.59524 .25953 Mdot
.59714 .37998 Mdot
.59905 .35285 Mdot
.60095 .42337 Mdot
.60286 .37106 Mdot
.60476 .33336 Mdot
.60667 .24874 Mdot
.60857 .42599 Mdot
.61048 .34815 Mdot
.61238 .30642 Mdot
.61429 .4257 Mdot
.61619 .35464 Mdot
.6181 .32397 Mdot
.62 .29873 Mdot
.6219 .36571 Mdot
.62381 .31819 Mdot
.62571 .34491 Mdot
.62762 .318 Mdot
.62952 .24017 Mdot
.63143 .33995 Mdot
.63333 .37958 Mdot
.63524 .31077 Mdot
.63714 .3845 Mdot
.63905 .28837 Mdot
.64095 .23253 Mdot
.64286 .3421 Mdot
.64476 .30399 Mdot
.64667 .35216 Mdot
.64857 .42558 Mdot
.65048 .25904 Mdot
.65238 .32642 Mdot
.65429 .27071 Mdot
.65619 .37337 Mdot
.6581 .41585 Mdot
.66 .42549 Mdot
.6619 .27579 Mdot
.66381 .29038 Mdot
.66571 .29116 Mdot
.66762 .30314 Mdot
.66952 .24228 Mdot
.67143 .29333 Mdot
.67333 .28402 Mdot
.67524 .35726 Mdot
.67714 .28871 Mdot
.67905 .28559 Mdot
.68095 .35997 Mdot
.68286 .28372 Mdot
.68476 .27391 Mdot
.68667 .4072 Mdot
.68857 .26557 Mdot
.69048 .41145 Mdot
.69238 .30521 Mdot
.69429 .29189 Mdot
.69619 .34142 Mdot
.6981 .2298 Mdot
.7 .40014 Mdot
.7019 .43677 Mdot
.70381 .41027 Mdot
.70571 .36749 Mdot
.70762 .36758 Mdot
.70952 .41511 Mdot
.71143 .37646 Mdot
.71333 .39848 Mdot
.71524 .24164 Mdot
.71714 .38003 Mdot
.71905 .37596 Mdot
.72095 .38158 Mdot
.72286 .37404 Mdot
.72476 .31171 Mdot
.72667 .37458 Mdot
.72857 .35022 Mdot
.73048 .41396 Mdot
.73238 .31352 Mdot
.73429 .38162 Mdot
.73619 .36455 Mdot
.7381 .27958 Mdot
.74 .24105 Mdot
.7419 .41843 Mdot
.74381 .23819 Mdot
.74571 .43234 Mdot
.74762 .4252 Mdot
.74952 .33474 Mdot
.75143 .4363 Mdot
.75333 .32107 Mdot
.75524 .33962 Mdot
.75714 .39357 Mdot
.75905 .4234 Mdot
.76095 .25183 Mdot
.76286 .29639 Mdot
.76476 .31176 Mdot
.76667 .37884 Mdot
.76857 .27032 Mdot
.77048 .39432 Mdot
.77238 .3462 Mdot
.77429 .32691 Mdot
.77619 .33263 Mdot
.7781 .34083 Mdot
.78 .27093 Mdot
.7819 .43405 Mdot
.78381 .35548 Mdot
.78571 .26057 Mdot
.78762 .38922 Mdot
.78952 .35831 Mdot
.79143 .29364 Mdot
.79333 .36216 Mdot
.79524 .26164 Mdot
.79714 .25894 Mdot
.79905 .29385 Mdot
.80095 .41281 Mdot
.80286 .39302 Mdot
.80476 .26601 Mdot
.80667 .30316 Mdot
.80857 .30625 Mdot
.81048 .34655 Mdot
.81238 .34689 Mdot
.81429 .28949 Mdot
.81619 .40242 Mdot
.8181 .32207 Mdot
.82 .27136 Mdot
.8219 .30279 Mdot
.82381 .28636 Mdot
.82571 .3427 Mdot
.82762 .28324 Mdot
.82952 .26285 Mdot
.83143 .32323 Mdot
.83333 .39912 Mdot
.83524 .29013 Mdot
.83714 .34015 Mdot
.83905 .37332 Mdot
.84095 .24033 Mdot
.84286 .36644 Mdot
.84476 .25983 Mdot
.84667 .32141 Mdot
.84857 .2221 Mdot
.85048 .24246 Mdot
.85238 .36863 Mdot
.85429 .23971 Mdot
.85619 .26196 Mdot
.8581 .39976 Mdot
.86 .34459 Mdot
.8619 .28369 Mdot
.86381 .31371 Mdot
.86571 .29317 Mdot
.86762 .30881 Mdot
.86952 .32595 Mdot
.87143 .27511 Mdot
.87333 .39824 Mdot
.87524 .37027 Mdot
.87714 .23642 Mdot
.87905 .27123 Mdot
.88095 .31662 Mdot
.88286 .35382 Mdot
.88476 .26942 Mdot
.88667 .31315 Mdot
.88857 .3436 Mdot
.89048 .42142 Mdot
.89238 .31933 Mdot
.89429 .42163 Mdot
.89619 .24679 Mdot
.8981 .24233 Mdot
.9 .40663 Mdot
.9019 .38721 Mdot
.90381 .3641 Mdot
.90571 .22292 Mdot
.90762 .33229 Mdot
.90952 .41565 Mdot
.91143 .36354 Mdot
.91333 .28635 Mdot
.91524 .43617 Mdot
.91714 .36556 Mdot
.91905 .36094 Mdot
.92095 .4101 Mdot
.92286 .2406 Mdot
.92476 .25161 Mdot
.92667 .34057 Mdot
.92857 .34619 Mdot
.93048 .29819 Mdot
.93238 .28282 Mdot
.93429 .31363 Mdot
.93619 .29851 Mdot
.9381 .3716 Mdot
.94 .30539 Mdot
.9419 .3417 Mdot
.94381 .31705 Mdot
.94571 .31152 Mdot
.94762 .32245 Mdot
.94952 .35279 Mdot
.95143 .42009 Mdot
.95333 .26774 Mdot
.95524 .23933 Mdot
.95714 .26875 Mdot
.95905 .25645 Mdot
.96095 .31932 Mdot
.96286 .3756 Mdot
.96476 .32192 Mdot
.96667 .24747 Mdot
.96857 .4191 Mdot
.97048 .40535 Mdot
.97238 .25626 Mdot
.97429 .41481 Mdot
.97619 .39146 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo04_ooooo0_l0003_ooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool0=oooool2o`0001;ooooo0_l0000Looooo`;o00001?ooool2o`0003oooooo0_l0001C
ooooo`;o00004Oooool2o`0002;ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0=oooool2o`0001[ooooo0_l0000Dooooo`;o00001?ooool2o`0003oooooo0_l0
001Cooooo`;o00004Oooool2o`0002;ooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1Cooooo`;o0000P?ooool2o`0006Gooooo0006ooooo`05o`000?ooooooooooooooool000003Ooo
ool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00033ooooo`;o00004?oo
ool2o`0006Gooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0eooooo`;o0000
@?ooool2o`0004[ooooo0_l0001:ooooo`;o0000:oooool000Kooooo00Go410@oooooooooooooooo
oa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool2o`0001Sooooo
0_l0000Looooo`;o00001Oooool2o`0003Wooooo0_l0000Fooooo`;o00003oooool2o`0001gooooo
0_l0000Sooooo`;o00007Oooool2o`0000;ooooo0_l00006ooooo`;o00005oooool2o`0001;ooooo
0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Co
oooo00?o0000ooooooooool01oooool2o`0001Sooooo0_l0000Qooooo`Co0000A_ooool2o`0000?o
oooo0_l00004ooooo`;o00003oooool2o`0001gooooo0_l0000;ooooo`;o00003Oooool2o`0000Ko
oooo0ol0000Mooooo`;o000000Coooooo`000?l0003o00003?ooool2o`0000Kooooo0_l00009oooo
o`;o00004_ooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool0>_ooool2o`0003kooooo0_l00008
ooooo`;o00000oooool2o`00047ooooo0_l0000=ooooo`;o00001_ooool2o`00027ooooo0_l0000=
ooooo`;o00001_ooool2o`0001gooooo000Yooooo`;o00006Oooool2o`0004;ooooo0_l00005oooo
o`;o00001Oooool2o`0000kooooo0_l0000Dooooo`;o00009_ooool2o`0005_ooooo0_l0000Doooo
o`;o00003oooool002Wooooo00?o0000ooooooooool03Oooool2o`0000Wooooo0_l0000Tooooo`;o
00003Oooool2o`0000gooooo0_l00005ooooo`;o00001Oooool2o`0000oooooo0_l00004ooooo`;o
00003Oooool2o`0001Gooooo0_l00004ooooo`;o00002Oooool2o`0002oooooo0_l0000Zooooo`;o
00001oooool2o`0000_ooooo0_l0000?ooooo`00:Oooool2o`0000Wooooo0_l00003ooooo`;o0000
1Oooool2o`0000_ooooo0_l0000Kooooo`;o00003Oooool2o`0002cooooo0_l00004ooooo`;o0000
9?ooool2o`0000Cooooo0_l0000jooooo`;o0000<oooool2o`0001cooooo000Yooooo`;o00002Ooo
ool2o`0000[ooooo0_l0000;ooooo`;o00001?ooool2o`0002_ooooo0_l0000>ooooo`;o000000?o
ooooo`000?l000009_ooool2o`0000Wooooo0_l0000=ooooo`;o00006oooool2o`0002gooooo0_l0
000booooo`;o00000_ooool2o`0000gooooo000Yooooo`03o`000?oooooooooo02Oooooo0_l0000[
ooooo`;o00003_ooool2o`000003ooooool0003o000002Kooooo0_l00009ooooo`;o00003Oooool2
o`0000Wooooo0_l0000@ooooo`;o0000:Oooool2o`000004ooooool0003o0000o`0000gooooo0_l0
0002ooooo`;o00007oooool2o`0000;ooooo0_l0000=ooooo`00:Oooool2o`0000kooooo0_l0001T
ooooo`;o00001oooool2o`0002Cooooo0_l0000@ooooo`;o0000>oooool2o`000003ooooool0003o
000000Wooooo0_l00003ooooo`;o00000_ooool2o`0003;ooooo000Yooooo`03o`000?oooooooooo
00gooooo0_l0000Dooooo`;o0000@oooool2o`0000Wooooo0ol00006ooooo`;o00002_ooool2o`00
00;ooooo0_l00003ooooo`;o00003oooool2o`0002kooooo0_l0000Sooooo`;o00001_ooool2o`00
02Kooooo0_l0000Cooooo`00:Oooool00ol0003oooooooooo`0Sooooo`;o00002oooool4o`000008
oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
5?ooool2o`0000kooooo0_l00003ooooo`Go00000_ooool2o`000004oc8b<_l0003o<S8bonk^kP;o
oooo0_l000001?lb<S;o0000oc8b<_o^k^h6ooooo`;o00000_ooool2o`0000?ooooo0_l0000Goooo
o`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko0000o`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP08ooooo`;o00002Oooool2o`0001Gooooo0_l000001?l@413o0000
o`000?ooool3o`000003oc8b<_o^k^kooooo00;ooooo0ol000001?lb<S;ok^k^o`000?l0000Aoooo
o`Co00004_ooool00om4A4Co0000o`000002o`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool002Wooooo00?o0000ooooooooool03oooool2
o`00017ooooo0_l0000>ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05?ooool2o`0001?ooooo00GoV9RHo`000?l0003o
ooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool2o`000004oiRHV?ooooooV9RH
ogMgMaKooooo0_l0000@ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOo0000o`00
0?nHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`;o00002?ooool2o`0001Oo
oooo00Go0000ooooool0003o0000ooooo`02o`000003oooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`02o`00017ooooo1?l0000Eooooo`;o00000_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool00ol0003oooooo`00
0003o`0000cooooo0_l0000Aooooo`;o00003_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Oooooo0_l0000=ooooo`;o
00004_ooool2o`000003onk^k_oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003oooo
o`;o00000_ooool00ol@413oooooooooo`08ooooo`?o00002Oooool2o`0001Cooooo00Go0000oooo
oooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413ooooooooo
o`08ooooo`;o00001_ooool2o`0001Cooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@4100
0oooool01Ol@413ooooooooooooooooo410@017ooooo0_l0000Jooooo`04o`000?oooooooooooa0@
40?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo007ooooo000Yoooo
o`Ko0000:oooool2o`0000;ooooo0_l00003ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000Oooooo0_l0000=ooooo`;o00004oooool00onHV9So8B4Qonk^
kP03ooooo`05o`000?ooooooooooooooool000000oooool2o`0000;ooooo00?o0000ooooooooool0
2?ooool3o`0000oooooo0_l0000=ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000002_ooool2o`0001Oooooo0_l00003oooo
o`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000004Oooool2o`0001Wooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`01ooooo`00:Oooool00ol0003o
ooooooooo`02o`0002cooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00000oooool01?l0
003oooooooooooooool2o`0000;ooooo00?o0000ooooooooool07?ooool2o`0000cooooo00?oMgMg
ofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Ko0000oooooooooooooooo
o`000?ooool2o`0001Wooooo0_l0000<ooooo`03oa0@4?l0003o000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000004Oooool2o`00013ooooo0_l00003
ooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000oooool2o`0000Wooooo0_l0000Dooooo`;o00000oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool002Wooooo00?o0000ooooooooool00_l0000`ooooo`03o`000?oooooo
oooo00?o00000oooool01?l@413oooooooooooooool2o`0000;ooooo00?o410@ooooooooool07?oo
ool2o`0000gooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
41000oooool01?l@413oooooo`000?l0000?ooooo`;o00005oooool2o`0000?ooooo00Go410@oooo
oooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41003_ooool5o`0001Kooooo00?o
MgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@4002ooooo`?o00002Oooool2o`0000kooooo0_l00004ooooo`;o00000oooool00ol0003o
ooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo
410@00?ooooo000Yooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`;o00007ooo
ool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02o`000003
oooooomgMgOoV9RH00;o000000?oMgMgooooooooool04?ooool2o`0001Cooooo00Go410@oiRHV?oo
oooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo0_l00009ooooo`Co00005oooool00oo^k^koA4A4o`000004ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool00omgMgOoV9RHooooo`02o`0000;ooooo0_l000000ooooooo0000
o`00000Gooooo`;o00002Oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000Yooooo`03o`000?oooooooooo033o
oooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP08ooooo`;o00003Oooool2o`00013ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_l000000oooooook^k^oc8b<P02o`000003onk^
k_oooooooooo01gooooo0_l00007ooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`;o00001_ooool3
o`000003ooooool0003o000000Cooooo0_l0000Cooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP03ooooo`03onk^k_lb<S;o000000;o00001Oooool2o`0000Sooooo0_l0
000Hooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`00:Oooool2o`0000Cooooo0_l00019ooooo`;o00002oooool2o`0004Cooooo
0_l0000;ooooo`;o00006_ooool5o`0000Gooooo0_l0000Mooooo`;o000000?oooooo`000?l00000
4oooool2o`0002oooooo000Yooooo`03o`000?oooooooooo00?ooooo0_l0000Sooooo`;o00009?oo
ool3o`0001Kooooo0_l00015ooooo`;o00003?ooool2o`0000oooooo0_l0000Kooooo`;o00001ooo
ool2o`000003ooooool0003o000002Sooooo1?l0000Hooooo`00:Oooool00ol0003oooooooooo`0:
ooooo`;o00007?ooool2o`0000cooooo0_l0000Gooooo`;o00005_ooool2o`0000gooooo0_l00000
0ooooooo0000o`000003ooooo`;o0000??ooool2o`0002cooooo0_l0000dooooo`Co00006?ooool0
02Wooooo00?o0000ooooooooool02_ooool2o`0000gooooo0_l0000Kooooo`;o00003oooool2o`00
02gooooo0_l000000ooooooo0000o`000003ooooo`;o00002Oooool2o`0000?ooooo0_l0000?oooo
o`;o00008oooool2o`0000Gooooo0_l00006ooooo`;o00008oooool2o`0000?ooooo0_l0000Toooo
o`;o00005oooool002Wooooo0ol00004ooooo`;o00004Oooool4o`0002cooooo0_l00010ooooo`;o
00000oooool2o`0000;ooooo0_l00008ooooo`;o000000?oooooo`000?l000002Oooool2o`0000ko
oooo0_l00008ooooo`;o00001Oooool2o`0000Kooooo0_l0000Sooooo`?o00000_ooool2o`0000go
oooo0_l0000Eooooo`;o00005oooool0027oooooool00014o`0000Cooooo000Yooooo`03o`000?oo
oooooooo00Oooooo0ol0000<ooooo`03o`000?oooooooooo00Cooooo0_l00003ooooo`03o`000?oo
oooooooo00Kooooo0_l000000ooooooo0000ooooo`09ooooo`;o00002oooool2o`0000_ooooo0ol0
0009ooooo`03o`000?oooooooooo00Cooooo0_l00003ooooo`;o00001?ooool2o`0000Gooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`;o00001?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo0_l0000;ooooo`03o`000?oooooooooo00Wooooo0_l0
000:ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooooooo1?l00004ooooo`03o`00
0?oooooooooo00;ooooo0_l00005ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool2o`0000Kooooo0_l00003ooooo`03o`000?oooooooooo00Oooooo0ol000000ooooooo0000
o`000008ooooo`03o`000?oooooooooo00[ooooo000Yooooo`03o`000?oooooooooo02Wooooo0_l0
0007ooooo`;o00001Oooool2o`0000_ooooo0_l00009ooooo`;o00004oooool2o`0000?ooooo0_l0
0005ooooo`;o00001?ooool00ol0003oooooooooo`0]ooooo`;o00001Oooool2o`0000Cooooo00?o
0000ooooooooool01_ooool2o`00023ooooo0_l0000@ooooo`03o`000?oooooooooo01Gooooo0_l0
0004ooooo`Co00003Oooool2o`000003ooooool0003o000000Wooooo00?o0000ooooooooool02_oo
ool002Wooooo00?o0000ooooooooool08_ooool2o`0000Gooooo0_l00007ooooo`Co00005oooool2
o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l000005Oooool2o`0000Cooooo0ol0000d
ooooo`;o00003?ooool3o`0002Oooooo0_l0000Wooooo`;o00000_ooool2o`0000kooooo0_l00004
ooooo`;o00004?ooool002Wooooo00?o0000ooooooooool08_ooool2o`00013ooooo0_l0000=oooo
o`;o00002?ooool2o`0000Wooooo0_l000000ooooooo0000o`00000Kooooo`?o00000_ooool2o`00
01Wooooo0_l0000Qooooo`Co0000:?ooool2o`0001?ooooo0_l00002ooooo`;o00000oooool2o`00
00gooooo0_l0000?ooooo`;o00000oooool3o`0000oooooo000Yooooo`;o00001_ooool2o`0000Co
oooo0_l0000Hooooo`;o00007?ooool2o`0003Sooooo0_l0000Iooooo`;o00008Oooool2o`0000Wo
oooo0_l0000Vooooo`;o00003?ooool2o`0000;ooooo0_l00003ooooo`;o00001Oooool2o`0001Oo
oooo0_l00004ooooo`;o00003oooool002Wooooo00?o0000ooooooooool00_ooool2o`000003oooo
ool0003o000000Cooooo0ol0000Gooooo`;o00004Oooool2o`0008cooooo0_l0000Vooooo`;o0000
7?ooool2o`0002kooooo000Yooooo`03o`000?oooooooooo00;ooooo0_l00008ooooo`;o00004?oo
ool2o`0001Sooooo0_l00006ooooo`?o0000@_ooool2o`0002Cooooo0_l0000:ooooo`;o0000=Ooo
ool2o`0002Sooooo0_l0000Rooooo`00:Oooool01?l0003oooooo`000?l00009ooooo`;o00004_oo
ool2o`0000[ooooo0_l00003ooooo`;o00003oooool3o`000003ooooool0003o000003oooooo0_l0
000Mooooo`?o00001?ooool2o`0000[ooooo0_l0000]ooooo`;o00001_ooool2o`0002Sooooo0_l0
000Rooooo`00:Oooool01?l0003oooooo`000?l00009ooooo`;o00001Oooool2o`0001Oooooo0_l0
0003ooooo`;o00003?ooool2o`0000Gooooo0_l00011ooooo`;o00001oooool2o`0001;ooooo0ol0
000oooooo`?o0000Doooool002Wooooo0_l0000:ooooo`;o000000?oooooo`000?l000000oooool3
o`0001;ooooo0_l0000;ooooo`;o00002?ooool2o`0000[ooooo0_l0000fooooo`;o00001?ooool2
o`0000;ooooo0_l00003ooooo`;o0000;_ooool2o`000003ooooool0003o000000oooooo0_l0000A
ooooo`;o00001_ooool2o`0000gooooo0_l00002ooooo`;o00006oooool2o`0000;ooooo0_l0000G
ooooo`00:Oooool00ol0003oooooooooo`06ooooo`;o000000Coooooo`000?l0003ooooo0_l00004
ooooo`;o00000_ooool2o`0000kooooo0ol00008ooooo`Co00005?ooool2o`0000kooooo0_l0000B
ooooo`;o00004_ooool2o`0000Sooooo0_l0000>ooooo`;o00002_ooool2o`0001Gooooo1?l00000
0ooooooo0000o`00000?ooooo`;o00006Oooool2o`0000gooooo0_l00002ooooo`;o00001Oooool2
o`0000Oooooo0_l0000;ooooo`;o00000_ooool2o`0001Oooooo000Yooooo`03o`000?oooooooooo
00Gooooo0ol0000>ooooo`;o00003oooool2o`0000Oooooo0ol0000Fooooo`;o00003_ooool2o`00
01;ooooo0_l0000@ooooo`;o000000?oooooo`000?l000005oooool2o`0000[ooooo0_l0000@oooo
o`;o00000oooool2o`0002gooooo0_l0000:ooooo`?o00003Oooool2o`0000Oooooo0_l0000;oooo
o`;o00006oooool002Wooooo00?o0000ooooooooool01Oooool2o`0002Gooooo0_l00002ooooo`;o
00005oooool2o`0003Cooooo0_l000000ooooooo0000o`000006ooooo`;o0000;Oooool2o`0000[o
oooo0_l0000Hooooo`;o00003?ooool2o`0000[ooooo0ol0000Sooooo`;o00006oooool002Wooooo
00?o0000ooooooooool0;?ooool2o`0001;ooooo0_l0000Aooooo`;o0000=Oooool2o`0000kooooo
0_l0000Iooooo`;o00001?ooool2o`0000Sooooo0_l0000Hooooo`;o0000;oooool2o`0001Cooooo
0_l0000Dooooo`00:Oooool2o`00047ooooo0_l00006ooooo`;o00002Oooool2o`0000[ooooo0_l0
000=ooooo`;o00009oooool2o`000003ooooool0003o000001Wooooo0_l00004ooooo`;o00004Ooo
ool2o`00027ooooo0ol0000Looooo`;o00005?ooool2o`0001Cooooo000Yooooo`03o`000?oooooo
oooo01Gooooo0_l0000aooooo`;o00005Oooool2o`0000gooooo0_l00005ooooo`;o00008?ooool2
o`0003Gooooo1?l0000Oooooo`?o0000:?ooool2o`0001kooooo000Yooooo`03o`000?oooooooooo
01Gooooo0_l0001Nooooo`;o0000;?ooool2o`0000gooooo0_l0000Looooo`;o00003oooool2o`00
017ooooo0_l0000Qooooo`;o000000?oooooo`000?l000000_l0000Nooooo`00:Oooool00ol0003o
ooooooooo`07ooooo`;o0000C?ooool2o`0002oooooo0_l0000=ooooo`;o00003?ooool2o`0000go
oooo0_l00009ooooo`;o00006Oooool2o`0000Oooooo0_l0000Aooooo`;o00003_ooool2o`00017o
oooo0_l000000ooooooo0000o`000002o`0001kooooo000Yooooo`03o`000?oooooooooo00Oooooo
0_l0000Aooooo`;o00004Oooool2o`0000kooooo0_l0000Fooooo`;o0000;oooool2o`0000gooooo
0_l0000Vooooo`;o00006Oooool2o`0002[ooooo0_l000000ooooooo0000o`000005ooooo`;o0000
3?ooool2o`0001kooooo000Yooooo`;o00004?ooool2o`0000Wooooo0_l00004ooooo`;o00002ooo
ool2o`0000kooooo0ol0000Tooooo`;o00004Oooool2o`0002Cooooo0_l00006ooooo`;o00003ooo
ool2o`00013ooooo0_l0000Cooooo`;o00008oooool2o`0000?ooooo0_l00005ooooo`;o00004_oo
ool2o`0001Sooooo000Yooooo`03o`000?oooooooooo00oooooo0_l0000?ooooo`;o00004Oooool2
o`0000Wooooo0_l0000Tooooo`;o00004Oooool2o`0000Oooooo0_l0000;ooooo`;o00003_ooool2
o`0000Kooooo0_l0000?ooooo`;o00004?ooool2o`0000oooooo0_l000000ooooooo0000o`000002
o`0002;ooooo0_l0000Nooooo`;o00001_ooool2o`00013ooooo0006ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`0Xooooo`;o00002Oooool2o`0000Gooooo0ol0000Aooooo`;o00002Ooo
ool2o`0002Gooooo0_l0000;ooooo`;o00000oooool3o`000003ooooool0003o000000Sooooo0_l0
000Cooooo`;o00002Oooool2o`0001Oooooo1ol0000;ooooo`;o0000?Oooool2o`00013ooooo0006
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0:?ooool2o`00013ooooo
0ol0000Aooooo`;o00002Oooool2o`0001_ooooo0_l0000Jooooo`?o000000?oooooo`000?l00000
2?ooool2o`0001?ooooo0_l00009ooooo`;o00006Oooool3o`0000?ooooo0_l00008ooooo`;o0000
Coooool000Kooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Tooooo`;o00005Oooool2o`0003Wooooo
0_l00019ooooo`;o00006Oooool2o`0000?ooooo0_l0001Iooooo`001_ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000
9?ooool2o`0001gooooo0_l0001Wooooo`Co00004Oooool2o`0002oooooo0_l0000Sooooo`;o0000
8oooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo02kooooo0_l0000Cooooo`;o
00009oooool2o`0001Cooooo0_l0000Xooooo`Ko0000@?ooool2o`0002?ooooo0_l0000Fooooo`;o
00002oooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`;o0000:?ooool2o`00037o
oooo0_l00009ooooo`;o00000oooool2o`0000oooooo0_l0000/ooooo`;o0000=_ooool2o`0000;o
oooo0_l00009ooooo`;o0000=_ooool2o`0000_ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`04ooooo`;o0000C?ooool2o`0000gooooo0_l00006ooooo`;o00001_ooool2o`00
06Oooooo0_l0000<ooooo`;o00000_ooool2o`0000Wooooo0_l0000Dooooo`;o0000;Oooool000Ko
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4
o`0000Kooooo00?o0000ooooooooool05Oooool2o`0002_ooooo0_l0000>ooooo`;o00000_ooool2
o`00017ooooo0_l00007ooooo`;o00004oooool2o`0001Kooooo0_l0000eooooo`;o00000_ooool2
o`0002Gooooo0_l00006ooooo`;o00000_ooool2o`0002gooooo000Yooooo`;o00002_ooool2o`00
00[ooooo0_l0000[ooooo`;o00004_ooool2o`0001[ooooo0_l0000Cooooo`;o00005_ooool2o`00
03Gooooo0_l0000Sooooo`;o00001?ooool2o`0000Kooooo0_l0000aooooo`00:Oooool00ol0003o
ooooooooo`09ooooo`;o0000?oooool2o`0001Gooooo0_l0000<ooooo`;o0000<_ooool2o`0002co
oooo0_l0000Xooooo`;o00006Oooool2o`0001Gooooo0_l0000=ooooo`00:Oooool00ol0003ooooo
ooooo`0@ooooo`Co00002oooool2o`0002Wooooo0_l0000Eooooo`;o00003?ooool2o`0001?ooooo
0_l0000Fooooo`;o00001Oooool2o`0002cooooo1?l00002ooooo`;o0000?Oooool2o`0000Gooooo
0_l0000>ooooo`;o00003Oooool002Wooooo00?o0000ooooooooool00_ooool2o`0000[ooooo1_l0
000;ooooo`;o00009oooool2o`0000Oooooo0_l00004ooooo`;o0000:oooool2o`0001Kooooo0_l0
0004ooooo`;o0000;oooool2o`0000;ooooo0_l00006ooooo`;o00005Oooool2o`0002Gooooo0_l0
000Mooooo`00:Oooool00ol0003oooooooooo`02ooooo`;o00002_ooool2o`0000oooooo0_l0000W
ooooo`;o00001oooool2o`0000Cooooo0_l0000=ooooo`;o0000>_ooool2o`0002Cooooo0_l0000?
ooooo`;o00001?ooool2o`0001Gooooo0_l0000Qooooo`;o00004oooool2o`0000cooooo000Yoooo
o`;o00007?ooool2o`0000;ooooo0_l0000Pooooo`;o00003Oooool2o`0001Cooooo0_l00003oooo
o`;o0000?Oooool2o`0001cooooo0_l0000?ooooo`;o00002?ooool2o`0003Cooooo0_l0000<oooo
o`;o00000oooool4o`0000cooooo000Yooooo`04o`000?ooooooooooooooo`;o00003Oooool2o`00
00;ooooo0_l00005ooooo`;o00002?ooool2o`00017ooooo0_l00007ooooo`;o00003Oooool2o`00
00kooooo0_l00009ooooo`;o00001oooool2o`0003Cooooo0_l0000:ooooo`;o0000:oooool2o`00
00Cooooo0_l0000Xooooo`?o00004Oooool2o`0000?ooooo0_l0000>ooooo`00:Oooool01?l0003o
ooooooooooooool2o`0000gooooo0_l00002ooooo`;o00001_ooool2o`0000Gooooo1?l00003oooo
o`;o000000Coooooo`000?l0003ooooo0_l00006ooooo`;o00003?ooool2o`0001Gooooo1Ol00000
0ooooooo0000o`00000?ooooo`;o00003oooool2o`00013ooooo0_l0000Iooooo`;o00000_ooool6
o`0000Wooooo0_l00002ooooo`;o00006_ooool2o`0000;ooooo0_l0000Xooooo`?o00009_ooool0
02Wooooo00?o0000ooooooooool07?ooool2o`0000Gooooo0_l00005ooooo`;o000000Coooooo`00
0?l0003ooooo0_l0000Cooooo`?o00003_ooool2o`0000Gooooo0ol00003ooooo`;o00001oooool2
o`0001Oooooo0_l0000=ooooo`Oo00003Oooool2o`000003ooooool0003o000000Cooooo0ol00004
ooooo`Co00002Oooool2o`0000;ooooo0_l0000Jooooo`;o0000EOooool002Wooooo00?o0000oooo
ooooool04oooool2o`0000Oooooo0_l00002ooooo`;o00008oooool2o`0000Wooooo0_l00004oooo
o`;o00001?ooool5o`0000Cooooo0_l00005ooooo`;o00000_ooool2o`0002;ooooo0ol00002oooo
o`;o00002oooool4o`000003ooooool0003o000000Cooooo0_l0000aooooo`;o0000E_ooool002Wo
oooo0_l0000Dooooo`;o00001Oooool4o`0000;ooooo0_l0000Sooooo`;o00002Oooool2o`0000[o
oooo0_l000000ooooooo0000o`000004ooooo`;o00002Oooool2o`0002_ooooo0_l00007ooooo`;o
00002oooool2o`0002oooooo1?l00008ooooo`;o0000:Oooool2o`0001oooooo000Yooooo`03o`00
0?oooooooooo01[ooooo0_l00021ooooo`;o00005?ooool2o`00027ooooo0_l0000>ooooo`;o0000
2?ooool2o`0002Wooooo0_l0000Oooooo`00:Oooool00ol0003oooooooooo`3Fooooo`;o0000I?oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oo
oooo?Oooool000kooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?o
oooo0ol0003oooooocgooooo000>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo0?oooooo?Oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Ko
oooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oo
oooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00So
oooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000Kooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`3oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGo
c<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3ooooo
ocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2
o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2
o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Oooooo`Co000000?o410@ooooooooool00oooool00ol0003ooooo
ooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooo
oolmooooo`008Oooool00ol0003oooooooooo`05ooooo`?o0000oooooolmooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000O
ooooo`03oeEEEOmVIVKo00000?ooooooAoooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .30103 Mdot
.02762 .26228 Mdot
.02952 .27894 Mdot
.03143 .2921 Mdot
.03333 .2579 Mdot
.03524 .36222 Mdot
.03714 .28118 Mdot
.03905 .45103 Mdot
.04095 .43933 Mdot
.04286 .34869 Mdot
.04476 .34514 Mdot
.04667 .44409 Mdot
.04857 .23459 Mdot
.05048 .35171 Mdot
.05238 .423 Mdot
.05429 .32262 Mdot
.05619 .37667 Mdot
.0581 .23457 Mdot
.06 .31335 Mdot
.0619 .32983 Mdot
.06381 .2489 Mdot
.06571 .2368 Mdot
.06762 .24611 Mdot
.06952 .23808 Mdot
.07143 .41482 Mdot
.07333 .26836 Mdot
.07524 .32688 Mdot
.07714 .30163 Mdot
.07905 .35106 Mdot
.08095 .24613 Mdot
.08286 .28714 Mdot
.08476 .4404 Mdot
.08667 .44577 Mdot
.08857 .37852 Mdot
.09048 .38306 Mdot
.09238 .35402 Mdot
.09429 .41605 Mdot
.09619 .30893 Mdot
.0981 .38603 Mdot
.1 .44855 Mdot
.1019 .43163 Mdot
.10381 .38193 Mdot
.10571 .37164 Mdot
.10762 .31991 Mdot
.10952 .33527 Mdot
.11143 .2486 Mdot
.11333 .34678 Mdot
.11524 .43338 Mdot
.11714 .32307 Mdot
.11905 .36919 Mdot
.12095 .43387 Mdot
.12286 .38718 Mdot
.12476 .21858 Mdot
.12667 .3728 Mdot
.12857 .38243 Mdot
.13048 .442 Mdot
.13238 .44987 Mdot
.13429 .37451 Mdot
.13619 .42568 Mdot
.1381 .34068 Mdot
.14 .25265 Mdot
.1419 .3848 Mdot
.14381 .39424 Mdot
.14571 .27901 Mdot
.14762 .43555 Mdot
.14952 .44236 Mdot
.15143 .34815 Mdot
.15333 .32786 Mdot
.15524 .32163 Mdot
.15714 .24935 Mdot
.15905 .37166 Mdot
.16095 .26785 Mdot
.16286 .34794 Mdot
.16476 .34451 Mdot
.16667 .39434 Mdot
.16857 .30646 Mdot
.17048 .21859 Mdot
.17238 .28857 Mdot
.17429 .3787 Mdot
.17619 .34783 Mdot
.1781 .32062 Mdot
.18 .2438 Mdot
.1819 .29054 Mdot
.18381 .3832 Mdot
.18571 .4484 Mdot
.18762 .3101 Mdot
.18952 .2563 Mdot
.19143 .25228 Mdot
.19333 .36708 Mdot
.19524 .33078 Mdot
.19714 .40893 Mdot
.19905 .26121 Mdot
.20095 .26501 Mdot
.20286 .24902 Mdot
.20476 .26586 Mdot
.20667 .2888 Mdot
.20857 .35142 Mdot
.21048 .43593 Mdot
.21238 .21851 Mdot
.21429 .36174 Mdot
.21619 .28474 Mdot
.2181 .3546 Mdot
.22 .43844 Mdot
.2219 .30369 Mdot
.22381 .28053 Mdot
.22571 .37839 Mdot
.22762 .37789 Mdot
.22952 .30672 Mdot
.23143 .26504 Mdot
.23333 .2576 Mdot
.23524 .35022 Mdot
.23714 .27856 Mdot
.23905 .43993 Mdot
.24095 .32797 Mdot
.24286 .26421 Mdot
.24476 .32099 Mdot
.24667 .26403 Mdot
.24857 .44443 Mdot
.25048 .44262 Mdot
.25238 .42087 Mdot
.25429 .23525 Mdot
.25619 .40454 Mdot
.2581 .26466 Mdot
.26 .34732 Mdot
.2619 .25367 Mdot
.26381 .30574 Mdot
.26571 .34302 Mdot
.26762 .30689 Mdot
.26952 .24615 Mdot
.27143 .32713 Mdot
.27333 .23787 Mdot
.27524 .26694 Mdot
.27714 .43856 Mdot
.27905 .36922 Mdot
.28095 .3681 Mdot
.28286 .36193 Mdot
.28476 .40002 Mdot
.28667 .35118 Mdot
.28857 .34754 Mdot
.29048 .44226 Mdot
.29238 .42672 Mdot
.29429 .33402 Mdot
.29619 .25999 Mdot
.2981 .32185 Mdot
.3 .37646 Mdot
.3019 .32604 Mdot
.30381 .44708 Mdot
.30571 .29654 Mdot
.30762 .26498 Mdot
.30952 .25297 Mdot
.31143 .42751 Mdot
.31333 .34821 Mdot
.31524 .33855 Mdot
.31714 .23634 Mdot
.31905 .2694 Mdot
.32095 .32986 Mdot
.32286 .40176 Mdot
.32476 .39116 Mdot
.32667 .44432 Mdot
.32857 .41862 Mdot
.33048 .40126 Mdot
.33238 .29114 Mdot
.33429 .37266 Mdot
.33619 .44917 Mdot
.3381 .34748 Mdot
.34 .35933 Mdot
.3419 .27235 Mdot
.34381 .44643 Mdot
.34571 .28339 Mdot
.34762 .32238 Mdot
.34952 .39121 Mdot
.35143 .37084 Mdot
.35333 .26345 Mdot
.35524 .31972 Mdot
.35714 .25043 Mdot
.35905 .26838 Mdot
.36095 .44164 Mdot
.36286 .29234 Mdot
.36476 .32912 Mdot
.36667 .32585 Mdot
.36857 .36654 Mdot
.37048 .38173 Mdot
.37238 .44495 Mdot
.37429 .33434 Mdot
.37619 .43066 Mdot
.3781 .31977 Mdot
.38 .43758 Mdot
.3819 .29862 Mdot
.38381 .43942 Mdot
.38571 .44815 Mdot
.38762 .37375 Mdot
.38952 .41157 Mdot
.39143 .32319 Mdot
.39333 .28501 Mdot
.39524 .37867 Mdot
.39714 .4494 Mdot
.39905 .43451 Mdot
.40095 .43914 Mdot
.40286 .24932 Mdot
.40476 .26059 Mdot
.40667 .38146 Mdot
.40857 .31992 Mdot
.41048 .32098 Mdot
.41238 .26761 Mdot
.41429 .25238 Mdot
.41619 .24846 Mdot
.4181 .2666 Mdot
.42 .29685 Mdot
.4219 .35367 Mdot
.42381 .26625 Mdot
.42571 .32309 Mdot
.42762 .3477 Mdot
.42952 .23789 Mdot
.43143 .28184 Mdot
.43333 .28567 Mdot
.43524 .3362 Mdot
.43714 .26743 Mdot
.43905 .28034 Mdot
.44095 .44706 Mdot
.44286 .32689 Mdot
.44476 .32355 Mdot
.44667 .45061 Mdot
.44857 .25995 Mdot
.45048 .43067 Mdot
.45238 .27315 Mdot
.45429 .33584 Mdot
.45619 .33703 Mdot
.4581 .26599 Mdot
.46 .2849 Mdot
.4619 .26011 Mdot
.46381 .42357 Mdot
.46571 .40952 Mdot
.46762 .30923 Mdot
.46952 .31178 Mdot
.47143 .23309 Mdot
.47333 .35308 Mdot
.47524 .33717 Mdot
.47714 .40337 Mdot
.47905 .31669 Mdot
.48095 .2991 Mdot
.48286 .24666 Mdot
.48476 .27334 Mdot
.48667 .37943 Mdot
.48857 .37346 Mdot
.49048 .29057 Mdot
.49238 .37157 Mdot
.49429 .44067 Mdot
.49619 .26364 Mdot
.4981 .40866 Mdot
.5 .37179 Mdot
.5019 .37052 Mdot
.50381 .39119 Mdot
.50571 .43237 Mdot
.50762 .32104 Mdot
.50952 .27538 Mdot
.51143 .41464 Mdot
.51333 .28828 Mdot
.51524 .31949 Mdot
.51714 .38701 Mdot
.51905 .30893 Mdot
.52095 .4474 Mdot
.52286 .4297 Mdot
.52476 .33811 Mdot
.52667 .33774 Mdot
.52857 .3385 Mdot
.53048 .32895 Mdot
.53238 .35306 Mdot
.53429 .29934 Mdot
.53619 .34257 Mdot
.5381 .34809 Mdot
.54 .36442 Mdot
.5419 .31369 Mdot
.54381 .34462 Mdot
.54571 .38347 Mdot
.54762 .3479 Mdot
.54952 .34313 Mdot
.55143 .39789 Mdot
.55333 .33335 Mdot
.55524 .29362 Mdot
.55714 .43575 Mdot
.55905 .35108 Mdot
.56095 .34236 Mdot
.56286 .36883 Mdot
.56476 .33111 Mdot
.56667 .34387 Mdot
.56857 .4199 Mdot
.57048 .44163 Mdot
.57238 .30756 Mdot
.57429 .27341 Mdot
.57619 .25175 Mdot
.5781 .30603 Mdot
.58 .25208 Mdot
.5819 .31739 Mdot
.58381 .29357 Mdot
.58571 .42672 Mdot
.58762 .43008 Mdot
.58952 .42944 Mdot
.59143 .30393 Mdot
.59333 .41808 Mdot
.59524 .37238 Mdot
.59714 .29104 Mdot
.59905 .42485 Mdot
.60095 .3125 Mdot
.60286 .33162 Mdot
.60476 .38481 Mdot
.60667 .27118 Mdot
.60857 .44073 Mdot
.61048 .42532 Mdot
.61238 .34756 Mdot
.61429 .43592 Mdot
.61619 .29042 Mdot
.6181 .31106 Mdot
.62 .23588 Mdot
.6219 .37764 Mdot
.62381 .23638 Mdot
.62571 .42808 Mdot
.62762 .32582 Mdot
.62952 .31438 Mdot
.63143 .37964 Mdot
.63333 .43458 Mdot
.63524 .32926 Mdot
.63714 .44254 Mdot
.63905 .39241 Mdot
.64095 .34544 Mdot
.64286 .31261 Mdot
.64476 .37405 Mdot
.64667 .3845 Mdot
.64857 .39981 Mdot
.65048 .27516 Mdot
.65238 .30754 Mdot
.65429 .29198 Mdot
.65619 .37681 Mdot
.6581 .45117 Mdot
.66 .41636 Mdot
.6619 .26956 Mdot
.66381 .2378 Mdot
.66571 .32822 Mdot
.66762 .26789 Mdot
.66952 .28052 Mdot
.67143 .36755 Mdot
.67333 .35964 Mdot
.67524 .29349 Mdot
.67714 .25276 Mdot
.67905 .22256 Mdot
.68095 .304 Mdot
.68286 .24204 Mdot
.68476 .27215 Mdot
.68667 .44319 Mdot
.68857 .32784 Mdot
.69048 .35095 Mdot
.69238 .23729 Mdot
.69429 .2603 Mdot
.69619 .27337 Mdot
.6981 .33894 Mdot
.7 .44665 Mdot
.7019 .41362 Mdot
.70381 .35396 Mdot
.70571 .31861 Mdot
.70762 .38191 Mdot
.70952 .36446 Mdot
.71143 .35243 Mdot
.71333 .44595 Mdot
.71524 .35871 Mdot
.71714 .29301 Mdot
.71905 .43742 Mdot
.72095 .44144 Mdot
.72286 .43986 Mdot
.72476 .27096 Mdot
.72667 .34821 Mdot
.72857 .42414 Mdot
.73048 .44883 Mdot
.73238 .27218 Mdot
.73429 .30087 Mdot
.73619 .31965 Mdot
.7381 .36037 Mdot
.74 .28874 Mdot
.7419 .43697 Mdot
.74381 .29728 Mdot
.74571 .41857 Mdot
.74762 .41152 Mdot
.74952 .2456 Mdot
.75143 .40765 Mdot
.75333 .23876 Mdot
.75524 .42001 Mdot
.75714 .27061 Mdot
.75905 .42446 Mdot
.76095 .33727 Mdot
.76286 .26851 Mdot
.76476 .40637 Mdot
.76667 .36225 Mdot
.76857 .29402 Mdot
.77048 .44702 Mdot
.77238 .25097 Mdot
.77429 .30228 Mdot
.77619 .34631 Mdot
.7781 .26867 Mdot
.78 .33333 Mdot
.7819 .43431 Mdot
.78381 .25841 Mdot
.78571 .37374 Mdot
.78762 .44469 Mdot
.78952 .38039 Mdot
.79143 .22087 Mdot
.79333 .38149 Mdot
.79524 .27357 Mdot
.79714 .27663 Mdot
.79905 .31716 Mdot
.80095 .44981 Mdot
.80286 .44382 Mdot
.80476 .32852 Mdot
.80667 .25956 Mdot
.80857 .35083 Mdot
.81048 .32067 Mdot
.81238 .42811 Mdot
.81429 .25103 Mdot
.81619 .33841 Mdot
.8181 .26775 Mdot
.82 .33486 Mdot
.8219 .32947 Mdot
.82381 .25247 Mdot
.82571 .37869 Mdot
.82762 .34159 Mdot
.82952 .29376 Mdot
.83143 .41605 Mdot
.83333 .44312 Mdot
.83524 .27787 Mdot
.83714 .38298 Mdot
.83905 .37807 Mdot
.84095 .30699 Mdot
.84286 .32538 Mdot
.84476 .32349 Mdot
.84667 .41244 Mdot
.84857 .2921 Mdot
.85048 .28223 Mdot
.85238 .24391 Mdot
.85429 .32049 Mdot
.85619 .29616 Mdot
.8581 .43709 Mdot
.86 .42133 Mdot
.8619 .34001 Mdot
.86381 .23807 Mdot
.86571 .22051 Mdot
.86762 .26046 Mdot
.86952 .29639 Mdot
.87143 .2605 Mdot
.87333 .33088 Mdot
.87524 .33791 Mdot
.87714 .26078 Mdot
.87905 .3195 Mdot
.88095 .37408 Mdot
.88286 .38383 Mdot
.88476 .27614 Mdot
.88667 .32697 Mdot
.88857 .33912 Mdot
.89048 .45072 Mdot
.89238 .32637 Mdot
.89429 .37075 Mdot
.89619 .27262 Mdot
.8981 .32347 Mdot
.9 .3422 Mdot
.9019 .31221 Mdot
.90381 .37919 Mdot
.90571 .32697 Mdot
.90762 .34681 Mdot
.90952 .45137 Mdot
.91143 .43555 Mdot
.91333 .33992 Mdot
.91524 .41624 Mdot
.91714 .3204 Mdot
.91905 .37593 Mdot
.92095 .34767 Mdot
.92286 .28964 Mdot
.92476 .30439 Mdot
.92667 .27195 Mdot
.92857 .38011 Mdot
.93048 .40204 Mdot
.93238 .35979 Mdot
.93429 .2999 Mdot
.93619 .36734 Mdot
.9381 .34528 Mdot
.94 .26785 Mdot
.9419 .3229 Mdot
.94381 .37506 Mdot
.94571 .3751 Mdot
.94762 .32026 Mdot
.94952 .28845 Mdot
.95143 .44248 Mdot
.95333 .26449 Mdot
.95524 .30288 Mdot
.95714 .33433 Mdot
.95905 .28447 Mdot
.96095 .27868 Mdot
.96286 .24991 Mdot
.96476 .2843 Mdot
.96667 .27103 Mdot
.96857 .43219 Mdot
.97048 .34529 Mdot
.97238 .31893 Mdot
.97429 .35755 Mdot
.97619 .44469 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0000Nooooo`;o00003?ooool2
o`0000cooooo0_l0003oooooo`;ooooo000Yooooo`03o`000?oooooooooo01gooooo0_l0000<oooo
o`;o00003?ooool2o`000;Sooooo0_l0000Fooooo`;o0000;oooool000Kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo0<oooooo0_l0000Rooooo`;o00005_ooool2o`0002oooooo0006oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4
A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0coooool2o`0006_ooooo0004
o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05o`000?oooooo
ooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0
002<ooooo`;o0000[_ooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00Cooooo
0_l000001?oooooo0000o`000?ooool2o`0003[ooooo0_l0000Cooooo`;o0000;oooool2o`0002ko
oooo0ol0000Dooooo`;o0000Ioooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`;o
000000Coooooo`000?l0003ooooo0ol0000iooooo`;o00001Oooool2o`0000cooooo0_l0000Roooo
o`;o0000>oooool3o`0000_ooooo0_l00007ooooo`;o00004_ooool2o`00027ooooo0_l0000`oooo
o`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02oooool2o`00043ooooo0_l0000`
ooooo`;o0000BOooool2o`0000Cooooo0_l0000Eooooo`;o00008Oooool2o`00033ooooo0006oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0
0006ooooo`03o`000?oooooooooo00[ooooo0_l00003ooooo`;o00007Oooool2o`0001_ooooo0_l0
0023ooooo`;o00005?ooool2o`0001oooooo0_l0000cooooo`00:Oooool2o`0000[ooooo0ol00003
ooooo`;o00001oooool2o`0000gooooo0_l00005ooooo`;o00001_ooool2o`0001?ooooo0_l0000Y
ooooo`;o00000_ooool2o`0001Cooooo0_l0001Dooooo`;o00007oooool2o`0003?ooooo000Yoooo
o`03o`000?oooooooooo00Wooooo0_l0000=ooooo`;o00002?ooool2o`0000?ooooo0_l00009oooo
o`;o00000_ooool2o`0002oooooo0_l0000=ooooo`;o00000_ooool2o`0001Cooooo0_l0000Loooo
o`?o00007Oooool2o`0001gooooo0_l0000;ooooo`;o00000_ooool2o`0002[ooooo0_l0000@oooo
o`00:Oooool00ol0003oooooooooo`0Rooooo`;o00003_ooool2o`0001Gooooo0_l0000=ooooo`;o
00003Oooool2o`00017ooooo0_l0000booooo`?o00007Oooool2o`0001gooooo0_l0000;ooooo`;o
00000_ooool2o`0002[ooooo0_l0000@ooooo`00:Oooool01?l0003oooooo`000?l0000aooooo`;o
00003?ooool2o`0000Oooooo0_l0000=ooooo`;o0000Uoooool2o`0004Wooooo000Yooooo`04o`00
0?oooooo0000o`00037ooooo0_l000000ooooooo0000o`000009ooooo`;o00004_ooool2o`00027o
oooo0_l0000<ooooo`;o00000_ooool2o`0004Wooooo0_l0000Kooooo`;o00001Oooool2o`0001;o
oooo1Ol0000[ooooo`00:Oooool2o`0003Kooooo0_l00008ooooo`;o00000_ooool3o`0000;ooooo
0_l0000:ooooo`;o00000_ooool2o`0000cooooo0_l0000?ooooo`;o00003?ooool2o`0000;ooooo
0_l00009ooooo`;o0000?_ooool2o`0002;ooooo0_l0000Booooo`Go00005_ooool2o`0001?ooooo
000Yooooo`;o00003Oooool2o`0001[ooooo0_l0000;ooooo`?o00001oooool2o`0000;ooooo0ol0
0002ooooo`;o00000oooool2o`0000Wooooo0_l0000<ooooo`Co00003oooool6o`0000;ooooo0_l0
0005ooooo`;o00002_ooool2o`0003Gooooo0_l0000_ooooo`;o00009Oooool2o`0000;ooooo0_l0
000Cooooo`00:Oooool00ol0003oooooooooo`0<ooooo`;o00006_ooool2o`0000Kooooo1?l00000
2?l@413oooooo`000?l0003o<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Wooooo0_l0000<ooooo`;o00002oooool2o`0000?ooooo1Ol00003ooooo`04onk^k_lb<S;o0000
oc8b<POo000000?o<S8bo`000?l000001Oooool2o`00023ooooo00GoV9RHoa0@4?l0003o<S8bolc<
c003ooooo`06onk^k_lb<S;o0000oc8b<_o^k^kooooo0_l000001Oo^k^ko<S8bo`000?lb<S;ok^k^
00[ooooo1?l0000Aooooo`;o00002?ooool4o`0000?ooooo0ol000000olb<S;ok^k^ooooo`02oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00_l0000Uooooo`;o000000KoA4A4o`000?l0003o<S8bomgM
gOooool2o`000004oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`00:Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05oooool2o`0000Kooooo0_l00008
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`;o00002?ooool2o`0001Sooooo00?o410@okZj^_oo
ool00_l00003ooooo`06ogMgMonHV9SooooooiRHV?mgMgOooooo0_l000001OmgMgOoV9RHoooooonH
V9SoMgMg00[ooooo0_l00006ooooo`;o000000?oooooo`000?l000002?ooool4o`0000Kooooo1?l0
0003ooooo`;o000000?ooooooiRHV?mgMgL00_l000001_ooooooMgMgoiRHV?ooooooV9RHogMgMaWo
oooo0_l00008ooooo`;o00001oooool00omgMgOo<S8booooo`02o`000004oiRHV?ooooooV9RHogMg
M`?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool00ol0003oooooooooo`0boooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo
ooooooooool@41007oooool2o`0000Wooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooo
oooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4004ooooo`;o00002?ooool2o`0000Ko
oooo0_l0000Cooooo`;o00000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooo
oooooooooooooa0@4007ooooo`;o00002Oooool2o`000003ooooool0003o000000[ooooo0_l00005
ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00?o000000Go410@oooooooooooooooo
oa0@400Eooooo`;o00000_ooool2o`0000Sooooo0_l00008ooooo`04o`000?oooooooooooa0@40?o
oooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo007ooooo000Yooooo`?o
00008oooool2o`0000gooooo00?o0000ooooooooool00_ooool01_l0003ooooooooooooooooo0000
ooooo`?o000000Coooooo`000?l0003o0000:oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oo
ooooooooooooool000000oooool01?l0003oooooooooooooool3o`0001Cooooo0_l0000Cooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000001oooool2o`0000Cooooo0_l0000Iooooo`04odA4A?oMgMgoooooo`0000Cooooo00Ko
0000ooooooooooooooooo`000?ooool3o`0000?ooooo00?o0000ooooooooool00oooool2o`0000ko
oooo0_l0000Eooooo`03ogMgMolb<S;o000000;o00000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool00Oooool002Wooooo0ol000000ooooooo0000o`00000Pooooo`;o
00003Oooool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooooooool0003ooooo0ol00000
1?oooooo0000o`000?l0000Pooooo`;o00002_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooo`000004o`0002Sooooo00?o410@o`000?nj^[X0
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00000=oooo
o`;o00006Oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000Gooooo0_l00003ooooo`;o00007Oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00?o00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool00Oooool002Wooooo00Co0000oooooooooooooooo0_l0000_ooooo`03o`000?oooooooooo
00;ooooo00?o410@ooooooooool00_l00003ooooo`05oa0@4?ooooooooooooooool@41008?ooool2
o`0000_ooooo00Go0000ooooool0003o0000oa0@4003ooooo`06oa0@4?ooooooooooooooool@413o
oooo0ol00007ooooo`;o00008_ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41000oooool01Ol@413ooooooooooooooooo410@02Wooooo00?oMgMgolc<c?l000001?ooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@400:ooooo`;o0000
7Oooool01?l0003oooooooooooooool4o`0000?ooooo00Go410@oooooooooooooooooa0@4003oooo
o`03oa0@4?oooooooooo007ooooo000Yooooo`03o`000?oooooooooo00oooooo0_l0000Kooooo`;o
00001?ooool00ol0003oooooooooo`02ooooo`;o000000?oooooo`000?l000000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Wooooo00Ko0000okZj^_ooooooV9RHoa0@4?ooool2o`000005ogMgMonH
V9SooooooiRHV?mgMgL00oooool00omgMgOoV9RHooooo`02o`0000Oooooo0_l0000?ooooo`;o0000
3_ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL09?ooool2o`0000?ooooo00?ok^k^odA4A?l000001?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Qooooo`;o0000
1_ooool3o`000003ooooool0003o000000;o000000CoV9RHoooooonHV9SoMgMg0oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo000Yooooo`04o`000?oooooo0000o`0000kooooo0_l0000Koooo
o`;o000000Goooooo`000?l0003oIVIVo`000004ooooo`?o000000?o<S8bonk^k_ooool00_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo0_l00008ooooo`;o00000_ooool01OnHV9So410@o`00
0?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h04?ooool2o`0000Kooooo0_l0000>ooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool0
0oo^k^ko<S8bo`000002o`0000?ooooo00Gok^k^o`000?l0003o<S8bonk^kP08ooooo`;o00004_oo
ool2o`0000Kooooo0_l00004ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02Oooool2o`0001Kooooo0_l00006ooooo`Co
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`00:Oooool4o`0002kooooo0_l0000^ooooo`;o00002?ooool2o`0002Oooooo0_l0000Coooo
o`;o00001oooool2o`0000?ooooo0_l00004ooooo`;o00002_ooool2o`0000Gooooo0_l0000;oooo
o`;o00003oooool2o`00017ooooo0_l00004ooooo`;o000000?oooooo`000?l00000<_ooool002Wo
oooo00?o0000ooooooooool0Eoooool2o`0001Kooooo0_l0000;ooooo`;o00004Oooool2o`0000oo
oooo0_l00005ooooo`;o00001oooool2o`0001cooooo0_l0000Dooooo`;o00001_ooool2o`00017o
oooo0_l00007ooooo`;o00000_ooool2o`0002kooooo000Yooooo`;o00003_ooool2o`0004Sooooo
0_l0000Fooooo`;o00002oooool2o`00017ooooo0_l0000?ooooo`;o0000?oooool2o`000003oooo
ool0003o000000Sooooo0_l0000Looooo`;o00004oooool2o`0001Wooooo000Yooooo`;o00003_oo
ool2o`0002gooooo0_l0001eooooo`;o00006oooool2o`0000oooooo0_l0000;ooooo`;o0000;_oo
ool2o`000003ooooool0003o000000Gooooo0_l0000Booooo`00:Oooool00ol0003oooooooooo`0[
ooooo`;o00003oooool4o`0000Wooooo1?l0001Pooooo`?o00000oooool2o`00017ooooo0_l00008
ooooo`;o0000<Oooool2o`0001Wooooo0_l00008ooooo`;o00004_ooool0027oooooool00014o`00
00Cooooo000Yooooo`03o`000?oooooooooo00Sooooo0_l0000:ooooo`?o00002oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00;o00001oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`?o
00000_ooool00ol0003oooooooooo`09ooooo`;o00001Oooool2o`0000Cooooo00?o0000oooooooo
ool02Oooool3o`0000?ooooo0_l00002ooooo`?o000000?oooooo`000?l000002?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool2o`0000[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`00:Oooool00ol0003ooooo
ooooo`08ooooo`;o0000<?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Cooooo
0_l0000Booooo`;o00002oooool2o`0000?ooooo0ol00007ooooo`;o00000_ooool2o`0002gooooo
00Co0000oooooooooooooooo0_l0000Oooooo`;o00005_ooool00ol0003oooooooooo`0:ooooo`00
:Oooool00ol0003oooooooooo`0Gooooo`;o00005Oooool2o`0001?ooooo0_l0000Rooooo`;o0000
1Oooool2o`0000Sooooo0ol0000Dooooo`;o00001oooool4o`0001Cooooo0_l0000Vooooo`;o0000
1oooool2o`0001?ooooo0_l000000ooooooo0000o`00000<ooooo`;o00001_ooool2o`0000_ooooo
0_l00007ooooo`;o00001_ooool2o`0000gooooo000Yooooo`03o`000?oooooooooo00Kooooo0_l0
000?ooooo`;o000000?oooooo`000?l000002oooool2o`0000Gooooo0_l0000Cooooo`;o00003ooo
ool2o`0000kooooo0_l000000ooooooo0000o`000005ooooo`;o00000_ooool2o`0000Cooooo0ol0
0002ooooo`;o00001Oooool2o`0001;ooooo1?l0000looooo`;o00001oooool2o`0001Kooooo0_l0
0009ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Cooooo0_l00005ooooo`;o00001Ooo
ool4o`0000Kooooo0_l0000=ooooo`00:Oooool2o`0000Oooooo0_l00005ooooo`;o00002oooool2
o`0000_ooooo0_l0000Sooooo`;o00001_ooool4o`0000cooooo0_l00005ooooo`;o00001Oooool2
o`0000Wooooo0_l00004ooooo`?o0000>?ooool2o`0004Cooooo0_l0000<ooooo`Go000000?ooooo
o`000?l000002Oooool2o`0001Oooooo000Yooooo`03o`000?oooooooooo00Wooooo0_l00002oooo
o`;o00005oooool2o`0001[ooooo0_l00008ooooo`;o00002?ooool2o`0000Cooooo0_l0000<oooo
o`?o00005_ooool2o`0001[ooooo0_l0000Mooooo`;o000000?oooooo`000?l000002?ooool2o`00
00Gooooo0_l0000Sooooo`;o00001?ooool2o`0000Gooooo0_l0000<ooooo`Co00000_ooool2o`00
02;ooooo000Yooooo`03o`000?oooooooooo00Wooooo0_l0000Kooooo`;o00002oooool2o`0000go
oooo0_l0000Hooooo`;o00003?ooool2o`0003?ooooo0_l00006ooooo`;o000000?oooooo`000?l0
00002_ooool2o`0000Wooooo0_l00008ooooo`;o00001Oooool2o`0001_ooooo0_l00006ooooo`;o
00001?ooool2o`0000kooooo0_l0000]ooooo`00:Oooool00ol0003oooooooooo`0Hooooo`;o0000
6Oooool2o`0001kooooo0_l0000Hooooo`;o00004_ooool2o`0000Cooooo0_l0000Nooooo`;o0000
00?oooooo`000?l000002_ooool2o`0003Oooooo0_l0000;ooooo`;o00003oooool2o`0001Wooooo
0_l0000Booooo`00:Oooool00ol0003oooooooooo`0Hooooo`;o0000>Oooool2o`0000Gooooo0_l0
000Aooooo`;o00004_ooool2o`0000Cooooo0_l00004ooooo`;o00003_ooool4o`0003Cooooo0_l0
000Booooo`;o00004?ooool3o`00013ooooo0_l00002ooooo`;o00001_ooool2o`0000cooooo0_l0
000Booooo`00:Oooool2o`0002;ooooo0_l0000Wooooo`;o00003_ooool2o`0002_ooooo0_l00004
ooooo`;o00003_ooool6o`0000Kooooo0_l0000Zooooo`;o00004_ooool2o`00013ooooo0_l00002
ooooo`;o00002Oooool2o`0000;ooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo0_l0000P
ooooo`00:Oooool00ol0003oooooooooo`03ooooo`;o00007?ooool2o`0000Oooooo0_l0000Noooo
o`;o0000EOooool6o`0000;ooooo1?l0000Fooooo`;o0000>_ooool2o`0000Wooooo0_l0000:oooo
o`;o00002_ooool2o`0000Wooooo0_l0000=ooooo`00:Oooool00ol0003oooooooooo`02ooooo`?o
00005?ooool2o`0000[ooooo0_l00002ooooo`?o000000?oooooo`000?l000006Oooool2o`0000Oo
oooo0_l00006ooooo`;o00001_ooool2o`0001_ooooo0_l0000Rooooo`Go00001?ooool2o`0000go
oooo0_l00007ooooo`;o00006Oooool2o`0000kooooo0_l0000Xooooo`;o00000oooool2o`0000?o
oooo0_l00009ooooo`;o00003Oooool002Wooooo00?o0000ooooooooool00_ooool2o`000003oooo
ool0003o000000Oooooo0_l00009ooooo`;o00002_ooool2o`0000;ooooo0_l00002ooooo`;o0000
2Oooool2o`0000Kooooo0_l00006ooooo`;o00001oooool2o`0000Kooooo0_l00006ooooo`;o0000
6oooool2o`0002;ooooo0_l000001?oooooo0000o`000?ooool2o`00013ooooo0_l0000Gooooo`;o
00002Oooool2o`0000kooooo0_l00009ooooo`;o00007Oooool2o`0000?ooooo0_l0000Mooooo`00
:Oooool00ol0003oooooooooo`05ooooo`;o00001oooool2o`0000;ooooo0_l0000Tooooo`;o0000
00?oooooo`000?l000000oooool2o`0000oooooo0_l0000Yooooo`;o00003oooool2o`00017ooooo
0_l00006ooooo`;o0000:Oooool2o`0000;ooooo1?l0000Nooooo`;o0000@Oooool002Wooooo0_l0
000Cooooo`;o00009oooool2o`0003oooooo0_l0000?ooooo`;o00004Oooool2o`0003Gooooo1?l0
001Cooooo`;o00003?ooool002Wooooo00?o0000ooooooooool0H_ooool2o`0006Wooooo0_l0000<
ooooo`;o00001Oooool2o`0003cooooo0_l0000<ooooo`;o00003?ooool002Wooooo00?o0000oooo
ooooool00_l0000hooooo`;o00005?ooool2o`00013ooooo0_l0000nooooo`;o0000:Oooool2o`00
00[ooooo1?l00005ooooo`;o00001oooool2o`0003?ooooo0_l0000Jooooo`00:Oooool00ol0003o
ooooooooo`02o`00037ooooo0_l00005ooooo`;o00005?ooool2o`0001Wooooo0_l0000eooooo`;o
0000:Oooool2o`0000[ooooo0_l0000@ooooo`;o0000=Oooool2o`0001Sooooo000Yooooo`03o`00
0?oooooooooo01_ooooo0_l0000Fooooo`;o00006Oooool3o`0001Gooooo0_l00003ooooo`;o0000
:Oooool2o`0001;ooooo0_l0000Qooooo`;o0000AOooool2o`0000cooooo0_l0000Hooooo`00:Ooo
ool2o`0001Sooooo0_l00002ooooo`Co00002Oooool2o`0002Cooooo0ol0000?ooooo`;o00001?oo
ool2o`0000Wooooo0_l0000Oooooo`Ko00004_ooool2o`0000Sooooo0_l0000>ooooo`;o0000:ooo
ool2o`0001gooooo0_l00002ooooo`;o00009_ooool002Wooooo00?o0000ooooooooool01oooool2
o`0000kooooo0_l00004ooooo`;o000000?oooooo`000?l000001_ooool2o`0002_ooooo0_l00009
ooooo`;o00003oooool2o`0001oooooo1Ol0000Mooooo`;o00003_ooool2o`0000;ooooo0_l0000W
ooooo`;o00007Oooool2o`0000[ooooo0_l00006ooooo`?o00005Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgM
g@05ooooo`03o`000?oooooooooo00Oooooo0_l00008ooooo`;o00003Oooool2o`0000_ooooo0_l0
000>ooooo`?o00005Oooool2o`0001gooooo0_l0000Kooooo`;o0000:_ooool2o`000003ooooool0
003o000000Kooooo0_l0000dooooo`;o00000_ooool2o`0001?ooooo0_l00003ooooo`;o000000?o
ooooo`000?l000000oooool3o`0001Gooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool04Oooool3o`0000;ooooo0_l00006ooooo`;o00003Oooool2o`000003oooo
ool0003o000000_ooooo0ol0000/ooooo`;o00001_ooool2o`000003ooooool0003o000001Sooooo
0_l0000Zooooo`;o000000?oooooo`000?l000005_ooool2o`0001Sooooo1?l00008ooooo`;o0000
0_ooool2o`0001?ooooo0_l00006ooooo`;o00006oooool000Kooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Booooo`Ko00001_ooool2o`0000;ooooo0_l0000<ooooo`;o0000>_ooool2o`0000Wooooo
0_l0000[ooooo`;o00004Oooool2o`0000cooooo0_l0000Aooooo`;o00006?ooool4o`0000cooooo
0_l0000<ooooo`;o0000:_ooool000Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0001Cooooo0_l00006ooooo`;o0000
1?ooool2o`0007Oooooo0_l00007ooooo`;o00004Oooool2o`0000cooooo0_l00019ooooo`;o0000
:_ooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo01cooooo0_l0000oooooo`;o
00001_ooool2o`00033ooooo0_l00002ooooo`;o00009Oooool2o`0007Sooooo0006ooooo`05oa0@
4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool08oooool2o`0000Gooooo0_l0000aooooo`;o00001_ooool2o`00033o
oooo0_l0000Yooooo`;o0000N?ooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
02?ooooo0_l00005ooooo`;o0000N_ooool2o`0009Cooooo0006ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooo
oooo053ooooo0_l0000:ooooo`;o000000?oooooo`000?l00000AOooool2o`0001gooooo0_l0001I
ooooo`;o00006_ooool002Wooooo0_l00018ooooo`;o00001oooool2o`0000[ooooo0_l000000ooo
oooo0000o`00000]ooooo`;o0000=Oooool2o`0005Wooooo0_l0000Jooooo`00:Oooool00ol0003o
ooooooooo`17ooooo`;o0000AOooool2o`0005Kooooo0_l00003ooooo`;o0000Coooool002Wooooo
00?o0000ooooooooool0=?ooool2o`0005Cooooo0_l00009ooooo`;o0000Coooool2o`0000?ooooo
0_l0001?ooooo`00:Oooool00ol0003oooooooooo`0dooooo`;o0000??ooool2o`0001Kooooo0_l0
0009ooooo`;o0000?oooool2o`0000gooooo0_l0000Nooooo`;o0000=Oooool002Wooooo00?o0000
ooooooooool03?ooool2o`0000Gooooo0_l0001Mooooo`;o00009Oooool2o`0002kooooo0_l0000;
ooooo`;o00003Oooool2o`0001Wooooo0_l00003ooooo`;o00005?ooool2o`0001oooooo000Yoooo
o`;o00003Oooool2o`0000Gooooo0_l00019ooooo`;o0000>Oooool2o`00013ooooo0_l00006oooo
o`;o00005?ooool2o`0001Wooooo0_l000000ooooooo0000o`00000Gooooo`;o00006Oooool2o`00
01oooooo000Yooooo`03o`000?oooooooooo00Gooooo0_l0000oooooo`;o00005_ooool2o`0002[o
oooo0_l0000Oooooo`;o00001_ooool2o`0002oooooo0_l000000ooooooo0000o`00000Pooooo`;o
0000<Oooool002Wooooo00?o0000ooooooooool01Oooool2o`0001Wooooo0_l0000Tooooo`;o0000
2oooool2o`0003Gooooo0_l0000Uooooo`;o00000_ooool2o`0000;ooooo0_l0000Tooooo`;o0000
2?ooool2o`0001kooooo0_l0000aooooo`00:Oooool00ol0003oooooooooo`0Pooooo`;o0000<Ooo
ool2o`0000Cooooo0_l00012ooooo`;o00004_ooool3o`000003ooooool0003o000000;ooooo0_l0
0003ooooo`;o00007oooool2o`0000Sooooo0_l0000?ooooo`;o0000@?ooool002Wooooo00?o0000
ooooooooool05Oooool2o`0004;ooooo0_l0000Cooooo`;o00005Oooool2o`00013ooooo0_l00004
ooooo`;o00004oooool2o`0000[ooooo0_l0000jooooo`;o0000<?ooool2o`0000kooooo000Yoooo
o`;o00005_ooool2o`0000?ooooo1?l00006ooooo`;o00004_ooool2o`0003Cooooo0_l00005oooo
o`;o00003_ooool2o`00013ooooo0_l0000?ooooo`;o00004?ooool2o`0000Cooooo0_l0000^oooo
o`;o0000:?ooool2o`00013ooooo0_l0000>ooooo`00:Oooool00ol0003oooooooooo`02ooooo`;o
00005_ooool4o`0000Kooooo0_l0000Booooo`;o000000?oooooo`000?l000004Oooool2o`0001oo
oooo0ol00003ooooo`?o0000<?ooool2o`00013ooooo0_l00004ooooo`;o00006_ooool2o`0000Go
oooo0_l0000;ooooo`;o00005oooool2o`0000oooooo0_l0000Pooooo`00:Oooool00ol0003ooooo
ooooo`02ooooo`;o00003?ooool2o`0000gooooo0_l00004ooooo`;o00005?ooool2o`0000Cooooo
0_l0000;ooooo`;o00000_ooool2o`0001Gooooo0_l00004ooooo`?o00001?ooool2o`0001cooooo
0_l0000Fooooo`;o00002_ooool2o`0000Oooooo0_l0000Iooooo`?o00001?ooool2o`0002Cooooo
0_l0000Looooo`;o00004oooool002Wooooo00?o0000ooooooooool01?ooool2o`0000[ooooo0_l0
000=ooooo`;o00001?ooool2o`0001[ooooo0_l00002ooooo`;o00002oooool2o`0000[ooooo0_l0
0009ooooo`;o000000?oooooo`000?l000009_ooool2o`0001Kooooo0_l0000:ooooo`;o00001ooo
ool2o`0000kooooo0_l00009ooooo`?o00004oooool2o`0000?ooooo0_l00008ooooo`;o00009?oo
ool2o`0000Kooooo0_l0000;ooooo`00:Oooool00ol0003oooooooooo`04ooooo`;o00002_ooool2
o`0000?ooooo0_l0000Iooooo`;o00004oooool2o`0000oooooo0_l00006ooooo`;o00000oooool2
o`0000Oooooo0_l00003ooooo`;o00003oooool2o`0001Sooooo0_l0000cooooo`;o00000oooool2
o`0000;ooooo0_l0000@ooooo`;o00001?ooool2o`0000?ooooo0_l00008ooooo`;o0000;?ooool2
o`0000_ooooo000Yooooo`;o00000_ooool2o`0000gooooo0_l00003ooooo`;o00002?ooool2o`00
00oooooo0_l0000Tooooo`;o00002Oooool4o`0000cooooo0_l000000ooooooo0000o`00000<oooo
o`Co00005_ooool2o`0002[ooooo0_l0000<ooooo`;o00000_ooool2o`0000?ooooo0_l0000;oooo
o`;o00002?ooool2o`0001_ooooo0_l00004ooooo`;o00008Oooool002Wooooo00Co0000oooooooo
oooooooo0_l0000Looooo`;o0000@?ooool2o`00017ooooo0_l0000>ooooo`;o0000@_ooool2o`00
01Gooooo0_l0000Eooooo`;o00006oooool2o`0000Cooooo0_l0000Qooooo`003_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo000>oooo
o`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolm
ooooo`003_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05o`000?ooooooooooooooool000003?ooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolmooooo`003_ooool0
1Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`3oooooocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^
k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolm
ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWo
oooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006oooo
o`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooo
oooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool0
0olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolm
ooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool0
1Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go0000
1?ooool4o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`007oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooolmoooo
o`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo
00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`007oooool00omEEEGoIVIV
o`00003oooooodOooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .37477 Mdot
.02762 .35314 Mdot
.02952 .28518 Mdot
.03143 .25979 Mdot
.03333 .32684 Mdot
.03524 .39228 Mdot
.03714 .31672 Mdot
.03905 .42942 Mdot
.04095 .41653 Mdot
.04286 .31873 Mdot
.04476 .34556 Mdot
.04667 .44548 Mdot
.04857 .3054 Mdot
.05048 .32668 Mdot
.05238 .44777 Mdot
.05429 .26511 Mdot
.05619 .33826 Mdot
.0581 .30288 Mdot
.06 .35531 Mdot
.0619 .2361 Mdot
.06381 .26631 Mdot
.06571 .3121 Mdot
.06762 .27314 Mdot
.06952 .28568 Mdot
.07143 .45089 Mdot
.07333 .26086 Mdot
.07524 .35195 Mdot
.07714 .35083 Mdot
.07905 .25039 Mdot
.08095 .33499 Mdot
.08286 .23839 Mdot
.08476 .40908 Mdot
.08667 .43092 Mdot
.08857 .36779 Mdot
.09048 .37461 Mdot
.09238 .2565 Mdot
.09429 .35157 Mdot
.09619 .35161 Mdot
.0981 .29904 Mdot
.1 .44554 Mdot
.1019 .4548 Mdot
.10381 .36982 Mdot
.10571 .3877 Mdot
.10762 .3853 Mdot
.10952 .3901 Mdot
.11143 .30053 Mdot
.11333 .33862 Mdot
.11524 .38407 Mdot
.11714 .25031 Mdot
.11905 .27277 Mdot
.12095 .38753 Mdot
.12286 .29807 Mdot
.12476 .30955 Mdot
.12667 .38451 Mdot
.12857 .38223 Mdot
.13048 .42504 Mdot
.13238 .43413 Mdot
.13429 .32802 Mdot
.13619 .36872 Mdot
.1381 .39168 Mdot
.14 .28399 Mdot
.1419 .44834 Mdot
.14381 .31476 Mdot
.14571 .32815 Mdot
.14762 .43815 Mdot
.14952 .41447 Mdot
.15143 .32077 Mdot
.15333 .27199 Mdot
.15524 .35519 Mdot
.15714 .26477 Mdot
.15905 .31448 Mdot
.16095 .30182 Mdot
.16286 .32961 Mdot
.16476 .30328 Mdot
.16667 .31498 Mdot
.16857 .27553 Mdot
.17048 .30892 Mdot
.17238 .25107 Mdot
.17429 .28439 Mdot
.17619 .27772 Mdot
.1781 .23621 Mdot
.18 .33066 Mdot
.1819 .26073 Mdot
.18381 .36927 Mdot
.18571 .42187 Mdot
.18762 .25744 Mdot
.18952 .32485 Mdot
.19143 .2883 Mdot
.19333 .3077 Mdot
.19524 .27631 Mdot
.19714 .44932 Mdot
.19905 .37911 Mdot
.20095 .31785 Mdot
.20286 .30449 Mdot
.20476 .31817 Mdot
.20667 .39923 Mdot
.20857 .32554 Mdot
.21048 .40156 Mdot
.21238 .30568 Mdot
.21429 .2941 Mdot
.21619 .36621 Mdot
.2181 .28238 Mdot
.22 .44674 Mdot
.2219 .37775 Mdot
.22381 .23975 Mdot
.22571 .37022 Mdot
.22762 .33263 Mdot
.22952 .35425 Mdot
.23143 .31797 Mdot
.23333 .25567 Mdot
.23524 .31915 Mdot
.23714 .26578 Mdot
.23905 .4098 Mdot
.24095 .23634 Mdot
.24286 .23059 Mdot
.24476 .27626 Mdot
.24667 .2667 Mdot
.24857 .40799 Mdot
.25048 .40614 Mdot
.25238 .36687 Mdot
.25429 .29864 Mdot
.25619 .45549 Mdot
.2581 .2513 Mdot
.26 .24675 Mdot
.2619 .25961 Mdot
.26381 .25883 Mdot
.26571 .24501 Mdot
.26762 .41 Mdot
.26952 .33263 Mdot
.27143 .3178 Mdot
.27333 .29256 Mdot
.27524 .35458 Mdot
.27714 .44968 Mdot
.27905 .39399 Mdot
.28095 .38972 Mdot
.28286 .26098 Mdot
.28476 .31754 Mdot
.28667 .25126 Mdot
.28857 .32988 Mdot
.29048 .43865 Mdot
.29238 .44882 Mdot
.29429 .4228 Mdot
.29619 .29235 Mdot
.2981 .35628 Mdot
.3 .33658 Mdot
.3019 .235 Mdot
.30381 .41671 Mdot
.30571 .21717 Mdot
.30762 .33097 Mdot
.30952 .28567 Mdot
.31143 .46253 Mdot
.31333 .27231 Mdot
.31524 .35441 Mdot
.31714 .29079 Mdot
.31905 .30737 Mdot
.32095 .38418 Mdot
.32286 .32306 Mdot
.32476 .30752 Mdot
.32667 .41378 Mdot
.32857 .35844 Mdot
.33048 .32155 Mdot
.33238 .24818 Mdot
.33429 .27478 Mdot
.33619 .45384 Mdot
.3381 .25101 Mdot
.34 .3867 Mdot
.3419 .35754 Mdot
.34381 .41682 Mdot
.34571 .23824 Mdot
.34762 .35493 Mdot
.34952 .30224 Mdot
.35143 .2767 Mdot
.35333 .28592 Mdot
.35524 .35327 Mdot
.35714 .30884 Mdot
.35905 .33471 Mdot
.36095 .43609 Mdot
.36286 .40127 Mdot
.36476 .3836 Mdot
.36667 .28999 Mdot
.36857 .26818 Mdot
.37048 .28689 Mdot
.37238 .45009 Mdot
.37429 .27817 Mdot
.37619 .45538 Mdot
.3781 .32873 Mdot
.38 .41869 Mdot
.3819 .40449 Mdot
.38381 .39793 Mdot
.38571 .4531 Mdot
.38762 .38882 Mdot
.38952 .45668 Mdot
.39143 .23399 Mdot
.39333 .33002 Mdot
.39524 .44443 Mdot
.39714 .42657 Mdot
.39905 .45867 Mdot
.40095 .44794 Mdot
.40286 .30519 Mdot
.40476 .38002 Mdot
.40667 .33996 Mdot
.40857 .27761 Mdot
.41048 .27919 Mdot
.41238 .29737 Mdot
.41429 .31566 Mdot
.41619 .36934 Mdot
.4181 .35378 Mdot
.42 .3318 Mdot
.4219 .3913 Mdot
.42381 .27741 Mdot
.42571 .32981 Mdot
.42762 .34443 Mdot
.42952 .32317 Mdot
.43143 .25378 Mdot
.43333 .23741 Mdot
.43524 .28347 Mdot
.43714 .35397 Mdot
.43905 .25485 Mdot
.44095 .45472 Mdot
.44286 .32505 Mdot
.44476 .3835 Mdot
.44667 .44136 Mdot
.44857 .27151 Mdot
.45048 .38574 Mdot
.45238 .24315 Mdot
.45429 .24287 Mdot
.45619 .28777 Mdot
.4581 .33432 Mdot
.46 .36927 Mdot
.4619 .29775 Mdot
.46381 .44805 Mdot
.46571 .45817 Mdot
.46762 .2583 Mdot
.46952 .3119 Mdot
.47143 .35055 Mdot
.47333 .28289 Mdot
.47524 .35169 Mdot
.47714 .4542 Mdot
.47905 .35321 Mdot
.48095 .37578 Mdot
.48286 .27058 Mdot
.48476 .35919 Mdot
.48667 .44563 Mdot
.48857 .3915 Mdot
.49048 .23536 Mdot
.49238 .31434 Mdot
.49429 .40319 Mdot
.49619 .31387 Mdot
.4981 .33919 Mdot
.5 .32758 Mdot
.5019 .31185 Mdot
.50381 .30834 Mdot
.50571 .45769 Mdot
.50762 .27656 Mdot
.50952 .32456 Mdot
.51143 .35213 Mdot
.51333 .24994 Mdot
.51524 .35289 Mdot
.51714 .38121 Mdot
.51905 .27706 Mdot
.52095 .43545 Mdot
.52286 .37609 Mdot
.52476 .26179 Mdot
.52667 .35155 Mdot
.52857 .2443 Mdot
.53048 .30469 Mdot
.53238 .28078 Mdot
.53429 .37309 Mdot
.53619 .34387 Mdot
.5381 .3873 Mdot
.54 .26861 Mdot
.5419 .24856 Mdot
.54381 .24689 Mdot
.54571 .38295 Mdot
.54762 .31069 Mdot
.54952 .26918 Mdot
.55143 .31548 Mdot
.55333 .27582 Mdot
.55524 .35072 Mdot
.55714 .39346 Mdot
.55905 .33908 Mdot
.56095 .38867 Mdot
.56286 .27065 Mdot
.56476 .30524 Mdot
.56667 .30531 Mdot
.56857 .36226 Mdot
.57048 .4445 Mdot
.57238 .35475 Mdot
.57429 .31253 Mdot
.57619 .30915 Mdot
.5781 .23227 Mdot
.58 .28711 Mdot
.5819 .23573 Mdot
.58381 .40112 Mdot
.58571 .37404 Mdot
.58762 .44675 Mdot
.58952 .38486 Mdot
.59143 .31848 Mdot
.59333 .35128 Mdot
.59524 .4403 Mdot
.59714 .23453 Mdot
.59905 .44742 Mdot
.60095 .21554 Mdot
.60286 .25684 Mdot
.60476 .38681 Mdot
.60667 .35814 Mdot
.60857 .40603 Mdot
.61048 .45304 Mdot
.61238 .33925 Mdot
.61429 .39669 Mdot
.61619 .2491 Mdot
.6181 .26934 Mdot
.62 .31337 Mdot
.6219 .34012 Mdot
.62381 .29373 Mdot
.62571 .46181 Mdot
.62762 .28653 Mdot
.62952 .37975 Mdot
.63143 .36989 Mdot
.63333 .44013 Mdot
.63524 .29856 Mdot
.63714 .45113 Mdot
.63905 .44732 Mdot
.64095 .4307 Mdot
.64286 .26007 Mdot
.64476 .39468 Mdot
.64667 .3674 Mdot
.64857 .32461 Mdot
.65048 .34171 Mdot
.65238 .26679 Mdot
.65429 .31945 Mdot
.65619 .33081 Mdot
.6581 .43706 Mdot
.66 .35779 Mdot
.6619 .32236 Mdot
.66381 .32098 Mdot
.66571 .31695 Mdot
.66762 .2951 Mdot
.66952 .3666 Mdot
.67143 .39257 Mdot
.67333 .38682 Mdot
.67524 .24766 Mdot
.67714 .31612 Mdot
.67905 .33271 Mdot
.68095 .24754 Mdot
.68286 .32602 Mdot
.68476 .32338 Mdot
.68667 .42973 Mdot
.68857 .35147 Mdot
.69048 .25133 Mdot
.69238 .30627 Mdot
.69429 .30964 Mdot
.69619 .25966 Mdot
.6981 .42565 Mdot
.7 .44372 Mdot
.7019 .34103 Mdot
.70381 .25606 Mdot
.70571 .24906 Mdot
.70762 .3468 Mdot
.70952 .26772 Mdot
.71143 .28063 Mdot
.71333 .44398 Mdot
.71524 .43881 Mdot
.71714 .23468 Mdot
.71905 .44944 Mdot
.72095 .45185 Mdot
.72286 .45624 Mdot
.72476 .28521 Mdot
.72667 .27534 Mdot
.72857 .44861 Mdot
.73048 .43425 Mdot
.73238 .28291 Mdot
.73429 .23497 Mdot
.73619 .25131 Mdot
.7381 .39325 Mdot
.74 .36839 Mdot
.7419 .40606 Mdot
.74381 .37468 Mdot
.74571 .35537 Mdot
.74762 .34839 Mdot
.74952 .27427 Mdot
.75143 .32955 Mdot
.75333 .28988 Mdot
.75524 .45095 Mdot
.75714 .22651 Mdot
.75905 .37608 Mdot
.76095 .38771 Mdot
.76286 .30159 Mdot
.76476 .45153 Mdot
.76667 .29636 Mdot
.76857 .31945 Mdot
.77048 .45029 Mdot
.77238 .26267 Mdot
.77429 .26556 Mdot
.77619 .31055 Mdot
.7781 .26131 Mdot
.78 .35274 Mdot
.7819 .38513 Mdot
.78381 .25339 Mdot
.78571 .44164 Mdot
.78762 .45072 Mdot
.78952 .35302 Mdot
.79143 .32509 Mdot
.79333 .35137 Mdot
.79524 .33857 Mdot
.79714 .34139 Mdot
.79905 .29374 Mdot
.80095 .43735 Mdot
.80286 .44517 Mdot
.80476 .35187 Mdot
.80667 .29869 Mdot
.80857 .34597 Mdot
.81048 .26231 Mdot
.81238 .4599 Mdot
.81429 .31608 Mdot
.81619 .2436 Mdot
.8181 .27676 Mdot
.82 .35486 Mdot
.8219 .30677 Mdot
.82381 .31865 Mdot
.82571 .36524 Mdot
.82762 .35229 Mdot
.82952 .33138 Mdot
.83143 .45942 Mdot
.83333 .43768 Mdot
.83524 .30379 Mdot
.83714 .37637 Mdot
.83905 .33337 Mdot
.84095 .37456 Mdot
.84286 .25419 Mdot
.84476 .35444 Mdot
.84667 .45403 Mdot
.84857 .40225 Mdot
.85048 .36614 Mdot
.85238 .2477 Mdot
.85429 .38609 Mdot
.85619 .33272 Mdot
.8581 .42499 Mdot
.86 .44863 Mdot
.8619 .34867 Mdot
.86381 .29744 Mdot
.86571 .32573 Mdot
.86762 .29264 Mdot
.86952 .26599 Mdot
.87143 .32716 Mdot
.87333 .23966 Mdot
.87524 .26423 Mdot
.87714 .37954 Mdot
.87905 .32995 Mdot
.88095 .38209 Mdot
.88286 .36439 Mdot
.88476 .32717 Mdot
.88667 .29234 Mdot
.88857 .28655 Mdot
.89048 .43058 Mdot
.89238 .28629 Mdot
.89429 .27256 Mdot
.89619 .36075 Mdot
.8981 .38461 Mdot
.9 .24467 Mdot
.9019 .23519 Mdot
.90381 .34484 Mdot
.90571 .42271 Mdot
.90762 .31189 Mdot
.90952 .43765 Mdot
.91143 .45812 Mdot
.91333 .34538 Mdot
.91524 .34686 Mdot
.91714 .25121 Mdot
.91905 .34147 Mdot
.92095 .24833 Mdot
.92286 .36923 Mdot
.92476 .35273 Mdot
.92667 .26062 Mdot
.92857 .36459 Mdot
.93048 .45648 Mdot
.93238 .38845 Mdot
.93429 .27326 Mdot
.93619 .3868 Mdot
.9381 .27325 Mdot
.94 .29287 Mdot
.9419 .26702 Mdot
.94381 .38362 Mdot
.94571 .38924 Mdot
.94762 .27656 Mdot
.94952 .25022 Mdot
.95143 .41543 Mdot
.95333 .33417 Mdot
.95524 .37446 Mdot
.95714 .35757 Mdot
.95905 .34313 Mdot
.96095 .27492 Mdot
.96286 .2412 Mdot
.96476 .27093 Mdot
.96667 .36009 Mdot
.96857 .39584 Mdot
.97048 .24884 Mdot
.97238 .35503 Mdot
.97429 .25759 Mdot
.97619 .44848 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0001Hooooo`;o0000GOooool2
o`0008Cooooo000Yooooo`03o`000?oooooooooo05Oooooo0_l0001Mooooo`;o0000Q?ooool000Ko
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3Xooooo`;o0000D_ooool000Co00000_ooool0
1Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo04?ooooo0_l0002Sooooo`;o0000D_ooool000Kooooo00Go0000
ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?oo
ool3o`0004?ooooo0_l0000]ooooo`;o0000>_ooool2o`0008cooooo0006ooooo`05o`000?oooooo
ooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`09ooooo`;o00008oooool2o`0001;ooooo0_l0000Booooo`;o0000
6_ooool2o`0001kooooo0_l0000Jooooo`Co00000oooool2o`0002Cooooo0_l00004ooooo`;o0000
=?ooool2o`0002?ooooo0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool2o`0000Cooooo
0_l0000Mooooo`;o00003Oooool2o`0000?ooooo0_l0000Booooo`;o00003?ooool2o`0001[ooooo
0_l0000@ooooo`;o00007?ooool2o`0000?ooooo0_l0000Tooooo`;o00001?ooool2o`0002[ooooo
0_l00008ooooo`;o00008oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oo
oooo0_l0000/ooooo`;o00009Oooool2o`0001[ooooo0_l00004ooooo`?o0000Q?ooool2o`0001_o
oooo0_l0000@ooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`1:ooooo`;o0000>_ooool3o`00
01Kooooo0_l0001Jooooo`;o00006Oooool2o`0001;ooooo0_l0000@ooooo`00:Oooool2o`0004Wo
oooo1?l0000Cooooo`;o0000?_ooool2o`0000;ooooo0_l0000Fooooo`;o00004Oooool4o`0000Ko
oooo0_l0000Qooooo`;o00002_ooool2o`0000gooooo0_l00005ooooo`;o00003_ooool2o`0000go
oooo000Yooooo`03o`000?oooooooooo00kooooo0_l0000:ooooo`;o00004?ooool2o`0001[ooooo
0_l00007ooooo`;o00003?ooool4o`0003Oooooo0_l00007ooooo`;o00005_ooool2o`00017ooooo
1?l000000ooooooo0000o`000003ooooo`;o00001oooool2o`0002Cooooo0_l0000Cooooo`?o0000
1oooool2o`0000Gooooo0_l0000=ooooo`00:Oooool00ol0003oooooooooo`0>ooooo`;o00002_oo
ool2o`00013ooooo0_l0000Booooo`;o00001_ooool2o`0000Oooooo0_l0000>ooooo`;o00007?oo
ool2o`000003ooooool0003o000001Kooooo0_l0000gooooo`;o00003?ooool2o`0000kooooo0_l0
000Aooooo`;o00005_ooool2o`0000Sooooo0_l0000Dooooo`00:Oooool00ol0003oooooooooo`0B
ooooo`;o00007Oooool2o`0000gooooo0_l00007ooooo`;o0000=?ooool2o`000003ooooool0003o
000000Oooooo0_l0000Yooooo`;o00007oooool2o`0001Sooooo0_l0000Aooooo`;o0000:?ooool2
o`0000cooooo000Yooooo`04o`000?oooooo0000o`0000_ooooo0_l00004ooooo`;o00006oooool4
o`0001Kooooo0_l00005ooooo`;o0000>Oooool2o`00013ooooo0_l0000Gooooo`;o00002oooool2
o`0000oooooo0_l000000ooooooo0000o`00000Fooooo`;o0000;_ooool2o`0000gooooo0_l0000<
ooooo`00:Oooool4o`0000Gooooo0_l00004ooooo`;o00006Oooool2o`0000Kooooo0_l0000Hoooo
o`;o00001Oooool2o`0004_ooooo0_l0000Tooooo`;o00003oooool2o`0001Oooooo1?l00008oooo
o`;o00004oooool2o`0000oooooo0_l0000Kooooo`00:Oooool00ol0003oooooooooo`06ooooo`;o
000000?oooooo`000?l000007?ooool2o`0001Sooooo0_l000000ooooooo0000o`00000Uooooo`;o
0000FOooool2o`00017ooooo0_l0000Booooo`?o00002Oooool2o`00017ooooo1?l0000Cooooo`;o
00005oooool002Wooooo00?o0000ooooooooool02Oooool2o`0002Gooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?l0003ok^k^00;o00009Ooo
ool7o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03_ooool2o`00013ooooo0_l000000ooooooo0000o`000003ooooo`?o000000?o<S8bolc<c?oo
ool00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^o`000?l0003o<S8bonk^kP07
ooooo`;o00004Oooool2o`0000kooooo0_l000000ol@413oooooooooo`02o`000004oc8b<_l0003o
<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0@ooooo`;o00005Oooool2o`000006odA4
A?l0003o0000oc8b<_oMgMgooooo0_l000001?lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool002Wooooo00?o0000ooooooooool02_ooool2o`0000oooooo0_l00009
ooooo`;o00002_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01Gooooo0_l0000Booooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`;o00002Oooool2o`00013ooooo0_l000000ooooooo0000o`000003ooooo`;o000000?ooooo
ogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgo`000?l0003oV9RH
ogMgM`0Wooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01Sooooo0_l0000;ooooo`?o00001?ooool00omg
MgOo<S8booooo`02o`000004oiRHV?ooooooV9RHogMgM`?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`00:Oooool00ol0003oooooooooo`0:ooooo`;o00003oooool2o`0000Wooooo0_l00003
ooooo`Co00000oooool3o`0000;ooooo00Go410@oooooooooooooooooa0@4003ooooo`04oa0@4?oo
ooooooooooooo`;o00005?ooool2o`0000Gooooo0_l00004ooooo`;o00001_ooool00onHV9So8B4Q
onk^kP04ooooo`03oa0@4?oooooooooo00;o00000oooool2o`0000;ooooo00Co410@oooooooooooo
oooo0_l0000Aooooo`;o00000_ooool2o`0000Wooooo0_l00005ooooo`05o`000?oooooooooooooo
ool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool07Oooool2
o`0000Kooooo1_l00003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooo
oooooooo410@00;o00005_ooool2o`0000_ooooo0ol000000ooooooo0000o`000002ooooo`?o0000
00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool002Wo
oooo0_l0000/ooooo`Co00000oooool3o`0000;ooooo00Go0000ooooooooooooooooo`000003oooo
o`04o`000?ooooooooooooooo`;o00006oooool2o`0000Cooooo0_l00005ooooo`;o000000?oV9RH
ob4Q8Oo^k^h00oooool00ol0003oooooooooo`03o`0000;ooooo0_l00002ooooo`03o`000?oooooo
oooo01Cooooo0_l00002ooooo`;o00000_ooool2o`0000Gooooo0_l00004ooooo`03ojVYZOl@413o
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
6_ooool2o`0000?ooooo0_l00007ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000oooooooo
ooooooooo`000003ooooo`04o`000?ooooooooooooooo`?o00009oooool2o`000003oooooomgMgOo
<S8b00?o00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00Ooo
ool002Wooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooooooo`;o00000_ooool01Ol0003ooooooooooooooooo000002Wooooo0_l000000oooooooMgMg
ofIVIP03ooooo`04o`000?ooooooooooooooo`;o00000_ooool01?l0003oooooooooooooool2o`00
00[ooooo0_l0000Aooooo`;o00002_ooool00ol@413o0000okZj^P03ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000001[ooooo0_l00005ooooo`;o00001Ooo
ool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000002Wooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo000Yooooo`?o00002ooo
ool2o`0001Gooooo0_l00009ooooo`;o00000oooool00ol0003oooooooooo`02ooooo`04oa0@4?oo
ooooooooooooo`;o00000_ooool01Ol@413ooooooooooooooooo410@01Cooooo0_l0000<ooooo`;o
00001?ooool2o`0000?ooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooo
ooooool@41000oooool2o`0000[ooooo0_l0000Nooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@
oooooooooooooooooa0@4003ooooo`04oa0@4?ooooooooooooooo`;o00007_ooool4o`0000Kooooo
00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooooooooa0@400Fooooo`Co00003oooool00ol0003oooooooooo`04ooooo`05oa0@4?oooooooooo
ooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo000Yooooo`?o00002oooool2
o`0001Gooooo0_l00009ooooo`;o00000oooool2o`0000?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05?ooool2o`0000cooooo0_l00003ooooo`?o0000
00Co^[ZjoooooonHV9So410@0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o00008Oooool01?l@413oV9RHoooooonj^[X3o`000006oooooomg
MgOoV9RHoooooonHV9SoMgMg0oooool01?mgMgOoV9RHoooooonHV9P2o`0001kooooo0_l00007oooo
o`;o000000?oA4A4o`000?ooool00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0Fooooo`Co00003oooool00ol0003oooooooooo`04ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000Yooooo`03o`00
0?oooooooooo033ooooo00CoEEEEofIVI_l0003o00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP09ooooo`;o00001Oooool2o`0000Gooooo0_l0000>
ooooo`;o000000GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_l0000Qooooo`05ojVYZOl@413o0000oa0@
4?nYZJT00_l000001_ooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0Xooooo`;o000000?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0@ooooo`;o00001?ooool2o`0000oooooo1_l00003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Y
ooooo`;o0000>oooool2o`00017ooooo0_l00005ooooo`;o00001Oooool2o`00063ooooo0_l0000<
ooooo`;o00007_ooool2o`0000Wooooo0_l0000Dooooo`;o00001?ooool2o`0000oooooo0_l0000G
ooooo`00:Oooool00ol0003oooooooooo`0Dooooo`;o00001_ooool2o`0001cooooo0_l0000:oooo
o`;o0000<Oooool2o`0000kooooo0_l0000booooo`;o00000_ooool2o`0000Sooooo0_l0000Noooo
o`;o00002Oooool4o`00013ooooo0_l0000`ooooo`00:Oooool00ol0003oooooooooo`0Dooooo`;o
00000_ooool2o`0000;ooooo0_l0000:ooooo`;o00007?ooool2o`0001gooooo0_l0000Booooo`;o
00003_ooool2o`0003Kooooo0_l0000Wooooo`;o00003?ooool2o`00013ooooo0_l0000`ooooo`00
:Oooool00ol0003oooooooooo`04ooooo`;o000000?oooooo`000?l000003oooool2o`0000kooooo
1?l0000:ooooo`;o000000?oooooo`000?l00000:_ooool2o`0000oooooo0_l0000Wooooo`;o0000
2Oooool3o`0003gooooo0_l0000Eooooo`;o0000>Oooool002Wooooo00?o0000ooooooooool01?oo
ool2o`000003ooooool0003o0000027ooooo0_l00007ooooo`;o000000Coooooo`000?l0003ooooo
0_l0000Pooooo`Co00005oooool2o`0001oooooo0_l00006ooooo`;o00002Oooool3o`0002Kooooo
0_l0000Xooooo`;o00000_ooool2o`0003Wooooo000Qoooooooo0000A?l00004ooooo`00:Oooool0
0ol0003oooooooooo`09ooooo`?o00002_ooool00ol0003oooooooooo`04ooooo`;o00000oooool3
o`0000?ooooo1Ol000000ooooooo0000ooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo0_l00002
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05
ooooo`;o00000_ooool00ol0003oooooooooo`05o`0000Cooooo00?o0000ooooooooool01_ooool2
o`0000;ooooo00Co0000oooooooooooooooo0ol00005ooooo`03o`000?oooooooooo00Cooooo0_l0
0003ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool2o`0000Cooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`;o00000_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool3o`0000Wooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`00:Oooool01?l0003ooooooooooooo
ool2o`0000Oooooo0_l0000Gooooo`;o00000oooool4o`0000Wooooo0_l00003ooooo`03o`000?oo
oooooooo00;ooooo0_l0000;ooooo`;o00000_ooool2o`0002Kooooo00Co0000ooooool0003o0000
5oooool3o`00013ooooo0_l00005ooooo`;o00001_ooool00ol0003oooooooooo`04ooooo`;o0000
3Oooool2o`000003ooooool0003o000002;ooooo00?o0000ooooooooool01Oooool2o`0003?ooooo
00?o0000ooooooooool02_ooool002Wooooo00Co0000oooooooooooooooo0ol0000Qooooo`;o0000
3_ooool3o`0000Oooooo0ol0000:ooooo`;o00000_ooool2o`0002Sooooo0_l0000Zooooo`;o0000
2oooool2o`0001;ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00007?ooool2o`0000co
oooo0_l00002ooooo`;o0000??ooool002Wooooo00?o0000ooooooooool00_ooool2o`00027ooooo
0_l0000?ooooo`;o00002?ooool2o`0001[ooooo0_l000000ooooooo0000o`00000Nooooo`;o0000
<_ooool2o`0001;ooooo1Ol00005ooooo`;o00006Oooool2o`00013ooooo0_l0000looooo`00:Ooo
ool4o`0000Cooooo0_l0000[ooooo`;o00001?ooool2o`0002;ooooo0_l000000ooooooo0000o`00
000Nooooo`;o00000_ooool2o`0001?ooooo0_l0000[ooooo`;o00000_ooool2o`0000Gooooo0ol0
000Pooooo`;o00005_ooool4o`0000;ooooo0_l0000Yooooo`00:Oooool01?l0003oooooo`000?l0
0004ooooo`;o00006Oooool2o`000003ooooool0003o000000Cooooo0_l00007ooooo`;o00001?oo
ool2o`0001Oooooo0_l0000Kooooo`;o00000oooool2o`0000Sooooo0_l00004ooooo`;o00004?oo
ool2o`000003ooooool0003o000002_ooooo0_l00009ooooo`;o00005?ooool2o`0000_ooooo0_l0
000Fooooo`So0000:Oooool002Wooooo00?o0000ooooooooool08?ooool2o`000003ooooool0003o
000000Cooooo0_l00003ooooo`;o00003_ooool2o`0000_ooooo0_l00004ooooo`;o00001Oooool2
o`0001Cooooo0_l00003ooooo`;o00001oooool3o`0001Kooooo0_l0000aooooo`;o00001Oooool2
o`0001Gooooo0_l0000Gooooo`;o000000?oooooo`000?l000001?ooool2o`0000Gooooo0_l0000[
ooooo`00:Oooool00ol0003oooooooooo`0?ooooo`;o00007Oooool2o`0000kooooo0_l0000;oooo
o`;o00002?ooool2o`000003ooooool0003o000000kooooo0_l0000Booooo`;o00002_ooool2o`00
03kooooo0_l00005ooooo`;o0000;_ooool2o`000003ooooool0003o000000Cooooo0_l0000Moooo
o`;o00004oooool002Wooooo00?o0000ooooooooool01oooool2o`0000Kooooo0_l00008ooooo`;o
0000>_ooool2o`00017ooooo0_l0000Nooooo`;o00002oooool2o`00017ooooo0_l0000@ooooo`;o
0000>?ooool2o`00037ooooo0_l0000Cooooo`00:Oooool2o`0000Sooooo0_l0000@ooooo`;o0000
G?ooool2o`0001cooooo0_l0000Aooooo`;o00004?ooool2o`000003ooooool0003o000000Oooooo
0_l0000>ooooo`;o00007?ooool3o`0002Gooooo0_l0000Nooooo`00:Oooool00ol0003ooooooooo
o`03ooooo`;o0000L_ooool2o`0000Gooooo0_l0000Qooooo`;o00006_ooool2o`0000Oooooo0_l0
000>ooooo`;o00007Oooool2o`0000;ooooo0_l0000Looooo`;o000000?oooooo`000?l000000_l0
000;ooooo`;o00004Oooool002Wooooo00?o0000ooooooooool00oooool2o`0007Wooooo0_l0000Q
ooooo`;o0000=Oooool2o`0000_ooooo0_l0000Booooo`;o00003oooool2o`0000_ooooo0_l00000
1?oooooo0000o`000?l0000<ooooo`;o00004Oooool002Wooooo00?o0000ooooooooool03Oooool2
o`0000Cooooo0ol0001fooooo`?o00002_ooool2o`0000?ooooo0_l00007ooooo`;o00002_ooool2
o`0001gooooo0_l00004ooooo`;o00002oooool2o`0000gooooo0_l000000ooooooo0000o`000006
ooooo`;o00002Oooool2o`0000oooooo0_l0000Oooooo`00:Oooool2o`0000Wooooo0_l00003oooo
o`;o00001?ooool3o`00017ooooo0_l0000Eooooo`;o00003Oooool2o`0000_ooooo0_l00008oooo
o`;o000000?oooooo`000?l000004_ooool2o`0000Cooooo0_l00009ooooo`Go00002?ooool3o`00
00;ooooo0_l00007ooooo`;o00001?ooool2o`0000Cooooo0_l0000Mooooo`;o00004?ooool2o`00
00Wooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000?ooooo0_l000000ooo
oooo0000o`000003ooooo`;o00006?ooool2o`0000gooooo0_l0000=ooooo`00:Oooool2o`0000Wo
oooo0_l0000Mooooo`;o00005Oooool2o`0000gooooo0_l00005ooooo`;o00001?ooool2o`0000;o
oooo0_l00003ooooo`?o000000?oooooo`000?l000004_ooool2o`0000Cooooo0_l0000<ooooo`;o
00002Oooool2o`00017ooooo0_l00009ooooo`;o00003oooool2o`0001Wooooo0_l00009ooooo`;o
000000?oooooo`000?l000002?ooool2o`0000Kooooo0_l0000Hooooo`;o00002?ooool2o`0000?o
oooo0_l0000=ooooo`00:Oooool00ol0003oooooooooo`1Dooooo`;o00002?ooool2o`0000?ooooo
0_l0000[ooooo`;o00009_ooool2o`0000oooooo0_l0001:ooooo`;o00004Oooool2o`000003oooo
ool0003o000000oooooo000Yooooo`03o`000?oooooooooo093ooooo0_l0000Iooooo`;o0000Hooo
ool2o`0000?ooooo0_l00008ooooo`;o00002_ooool2o`0000oooooo000Yooooo`03o`000?oooooo
oooo017ooooo0_l0000Wooooo`;o00002_ooool2o`0006?ooooo0_l0000Hooooo`;o00001Oooool2
o`00033ooooo0_l00006ooooo`;o00002?ooool2o`0000gooooo0_l0000Kooooo`00:Oooool00ol0
003oooooooooo`0Aooooo`;o00000oooool2o`0000Sooooo0_l0000>ooooo`;o00002?ooool2o`00
0003ooooool0003o000000Oooooo0_l0000booooo`;o00003Oooool2o`0003Gooooo0_l00003oooo
o`;o00001Oooool2o`0001Gooooo0_l0000Iooooo`;o00001_ooool2o`0001Gooooo0_l0000Moooo
o`00:Oooool2o`0001Oooooo0_l00008ooooo`;o00003_ooool2o`0000_ooooo0_l0000kooooo`;o
00003Oooool2o`0001Gooooo0_l0000?ooooo`;o00003Oooool2o`00027ooooo0_l0000hooooo`;o
00007Oooool002Wooooo0_l0000Cooooo`;o0000Noooool2o`0000cooooo0_l000000ooooooo0000
o`00000?ooooo`;o0000<Oooool2o`0000?ooooo0_l0000Gooooo`?o00008oooool2o`0001;ooooo
0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool2o`0001?ooooo0_l0000Qooooo`;o00001Oooool2o`0003Wo
oooo0_l0000Fooooo`;o00003?ooool2o`00023ooooo0_l0000Sooooo`;o00000oooool2o`0001Oo
oooo0ol0000:ooooo`;o00005oooool2o`0001;ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool07_ooool2o`0001Gooooo0_l00005ooooo`;o0000>Oooool2o`00
02;ooooo0_l00007ooooo`;o00006Oooool2o`0004kooooo0ol0000Zooooo`001_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01Oooooo0_l000001?oooooo0000o`000?ooool3o`0003cooooo0_l0000<
ooooo`;o00006?ooool3o`0001Cooooo0_l00007ooooo`;o00003?ooool2o`0003cooooo0_l0000E
ooooo`;o00001oooool2o`0000?ooooo0_l0000=ooooo`;o00005_ooool000Kooooo00Go0000oooo
ooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3
o`0001Oooooo0_l000000ooooooo0000o`000003o`0003gooooo0_l00004ooooo`;o00001_ooool2
o`0000Gooooo0_l0000Aooooo`?o00006oooool2o`0000Gooooo0_l00007ooooo`;o00000oooool2
o`0001Cooooo0_l0000Jooooo`;o00001Oooool2o`0001Gooooo0_l0000<ooooo`;o00002Oooool7
o`0001Gooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`02o`0001Gooooo0ol0
0002ooooo`;o00000oooool2o`0002cooooo0_l0000Aooooo`;o00003Oooool2o`0000Wooooo0_l0
000Dooooo`;o00003_ooool2o`0000Gooooo0_l0000<ooooo`;o00005?ooool2o`0001[ooooo0_l0
000eooooo`Co000000?oooooo`000?l000005Oooool000Kooooo00Go410@oooooooooooooooooa0@
400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`02o`0001Kooooo0_l00007ooooo`;o0000:oooool3o`0002_ooooo0_l0000Dooooo`;o00005?oo
ool2o`0001[ooooo0_l00007ooooo`;o00004oooool2o`0004Sooooo0_l0000>ooooo`001_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0C_ooool2o`00023ooooo0_l0000fooooo`;o0000
4?ooool2o`0000Sooooo0_l0000Looooo`;o0000B?ooool2o`0000kooooo0006ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03
o`000?oooooooooo03Oooooo0ol0000_ooooo`;o00001Oooool2o`0003kooooo0_l00008ooooo`;o
0000P?ooool002Wooooo0_l0000hooooo`?o0000;oooool2o`0000Cooooo0_l0000Sooooo`;o0000
6_ooool2o`0005?ooooo0_l0000eooooo`00:Oooool00ol0003oooooooooo`15ooooo`;o0000:?oo
ool2o`0002?ooooo0_l0000Rooooo`;o0000:Oooool2o`00023ooooo0_l0000eooooo`00:Oooool0
0ol0003oooooooooo`0@ooooo`;o0000;oooool2o`0000;ooooo0_l00004ooooo`;o0000Joooool2
o`0002Wooooo0_l0001Gooooo`00:Oooool00ol0003oooooooooo`0@ooooo`;o00004oooool2o`00
01[ooooo0_l00008ooooo`;o00004Oooool2o`000=cooooo000Yooooo`03o`000?oooooooooo00;o
oooo0_l0000Qooooo`;o0000;oooool2o`0000Kooooo0_l00003ooooo`;o0000`_ooool2o`0001?o
oooo000Yooooo`;o00000oooool2o`0005;ooooo0_l0000;ooooo`;o00002_ooool2o`000;Kooooo
0_l0000Cooooo`00:Oooool00ol0003oooooooooo`0`ooooo`;o00008Oooool2o`0001[ooooo0_l0
002Wooooo`;o00008_ooool002Wooooo00?o0000ooooooooool07oooool2o`0000oooooo0_l0000Q
ooooo`;o00007oooool2o`0005oooooo0_l0000booooo`;o00003Oooool2o`0002;ooooo000Yoooo
o`04o`000?ooooooooooooooo`;o00007?ooool2o`0005?ooooo0_l0001Kooooo`;o00000_ooool2
o`0003;ooooo0_l0000aooooo`00:Oooool01?l0003oooooooooooooool2o`0000gooooo0_l0002a
ooooo`;o00003?ooool2o`00043ooooo0_l0000Wooooo`00:Oooool2o`00017ooooo0_l0000=oooo
o`;o0000B?ooool2o`00037ooooo0_l0000Uooooo`;o00006_ooool2o`0003;ooooo0_l0000Woooo
o`00:Oooool00ol0003oooooooooo`0Oooooo`;o00000oooool2o`0002cooooo0_l0000Eooooo`;o
0000<Oooool2o`0002[ooooo0_l0000Aooooo`;o00000_ooool2o`0001Gooooo0_l00009ooooo`;o
00005_ooool2o`00027ooooo000Yooooo`03o`000?oooooooooo02Cooooo0_l0000/ooooo`;o0000
<?ooool2o`0002kooooo0_l0000:ooooo`;o00001_ooool2o`00017ooooo0_l0000Dooooo`;o0000
0oooool2o`0000Wooooo0_l0000Fooooo`;o00008Oooool002Wooooo00?o0000ooooooooool01?oo
ool2o`0000oooooo0_l0001Mooooo`;o00003_ooool2o`0000_ooooo0_l0000Iooooo`;o00001_oo
ool2o`0000[ooooo0_l0000Dooooo`;o00000_ooool2o`0001Gooooo0_l00004ooooo`;o0000@ooo
ool002Wooooo00?o0000ooooooooool01?ooool3o`0000kooooo0_l0000;ooooo`;o00005oooool2
o`0003Oooooo1?l0000Booooo`;o00001Oooool2o`0001Wooooo0_l00004ooooo`;o000000?ooooo
o`000?l000002oooool2o`0001;ooooo0_l00002ooooo`;o00000oooool2o`0001Kooooo0_l0000@
ooooo`;o00009?ooool2o`0000_ooooo000Yooooo`;o00001_ooool2o`0000Gooooo0_l0000Doooo
o`;o00004?ooool2o`0000Gooooo0_l0000Aooooo`;o00000oooool2o`0001Oooooo0_l00008oooo
o`;o00004_ooool2o`0002Kooooo0_l000000ooooooo0000o`00000:ooooo`?o00006?ooool2o`00
0003ooooool0003o000000Kooooo0_l00002ooooo`?o00001?ooool2o`0001Gooooo0_l0000Toooo
o`;o00002oooool002Wooooo00?o0000ooooooooool03?ooool2o`0000Oooooo0_l0000Mooooo`;o
00006?ooool2o`0000?ooooo0_l0000<ooooo`;o00002Oooool2o`0000?ooooo0_l0000?ooooo`;o
00002_ooool2o`0002Wooooo0_l00006ooooo`;o00006Oooool2o`0000Wooooo0_l00002ooooo`?o
00001?ooool2o`00017ooooo0_l0000eooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Eoooo
o`;o0000<?ooool2o`0001Sooooo0_l0000;ooooo`;o000000Coooooo`000?l0003o00003_ooool2
o`0000[ooooo0_l00007ooooo`;o00008?ooool2o`0002;ooooo0_l0000Vooooo`;o00006Oooool2
o`0001[ooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`17ooooo`;o00009Oooool2o`0000;ooooo0_l00000
0ooooooo0000o`00000Cooooo`;o00002oooool2o`0004Cooooo0_l0000Kooooo`;o00001?ooool2
o`0001Sooooo0_l00004ooooo`;o00006_ooool000kooooo00Go410@oooooooooooooooooa0@400@
ooooo`03o`000?oooooooooo00?ooooo0ol0001Iooooo`;o00006_ooool2o`0001?ooooo0_l0000b
ooooo`;o0000>_ooool2o`0000Cooooo0_l0000Hooooo`;o00008?ooool000kooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0FOooool2
o`0006?ooooo0_l0001looooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@
oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooo
oolmooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?oo
ool4o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo
00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo?Oooool0
00Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@
413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03
ooooo`?o0000oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Q
ooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool0
00Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@
oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo
1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
01oooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo?Oooool0027o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`00
0?oooooooooo00Gooooo0ol0003oooooocgooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001oooooo00?oEEEEofIVI_l00000
oooooom7ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .39911 Mdot
.02762 .40047 Mdot
.02952 .31189 Mdot
.03143 .30964 Mdot
.03333 .36227 Mdot
.03524 .37291 Mdot
.03714 .30971 Mdot
.03905 .35836 Mdot
.04095 .34429 Mdot
.04286 .25974 Mdot
.04476 .29674 Mdot
.04667 .39742 Mdot
.04857 .38424 Mdot
.05048 .26428 Mdot
.05238 .4231 Mdot
.05429 .27733 Mdot
.05619 .26023 Mdot
.0581 .38313 Mdot
.06 .34783 Mdot
.0619 .28263 Mdot
.06381 .35926 Mdot
.06571 .3842 Mdot
.06762 .36169 Mdot
.06952 .37342 Mdot
.07143 .43752 Mdot
.07333 .33494 Mdot
.07524 .32757 Mdot
.07714 .35063 Mdot
.07905 .25904 Mdot
.08095 .39325 Mdot
.08286 .32406 Mdot
.08476 .32831 Mdot
.08667 .36663 Mdot
.08857 .30761 Mdot
.09048 .31671 Mdot
.09238 .25497 Mdot
.09429 .24885 Mdot
.09619 .34484 Mdot
.0981 .23218 Mdot
.1 .39309 Mdot
.1019 .42853 Mdot
.10381 .30827 Mdot
.10571 .3543 Mdot
.10762 .40124 Mdot
.10952 .39548 Mdot
.11143 .35686 Mdot
.11333 .28304 Mdot
.11524 .28581 Mdot
.11714 .28304 Mdot
.11905 .24139 Mdot
.12095 .29195 Mdot
.12286 .23137 Mdot
.12476 .41589 Mdot
.12667 .34679 Mdot
.12857 .3326 Mdot
.13048 .35865 Mdot
.13238 .36895 Mdot
.13429 .2515 Mdot
.13619 .26577 Mdot
.1381 .39323 Mdot
.14 .34926 Mdot
.1419 .46244 Mdot
.14381 .23239 Mdot
.14571 .33226 Mdot
.14762 .39131 Mdot
.14952 .33712 Mdot
.15143 .26145 Mdot
.15333 .27025 Mdot
.15524 .33931 Mdot
.15714 .35906 Mdot
.15905 .24466 Mdot
.16095 .32281 Mdot
.16286 .2698 Mdot
.16476 .2559 Mdot
.16667 .23243 Mdot
.16857 .28847 Mdot
.17048 .41549 Mdot
.17238 .31701 Mdot
.17429 .23498 Mdot
.17619 .25441 Mdot
.1781 .29141 Mdot
.18 .39098 Mdot
.1819 .3108 Mdot
.18381 .3059 Mdot
.18571 .34589 Mdot
.18762 .29266 Mdot
.18952 .36219 Mdot
.19143 .34936 Mdot
.19333 .24463 Mdot
.19524 .26661 Mdot
.19714 .44026 Mdot
.19905 .45123 Mdot
.20095 .33845 Mdot
.20286 .35747 Mdot
.20476 .33735 Mdot
.20667 .46048 Mdot
.20857 .2634 Mdot
.21048 .31775 Mdot
.21238 .41381 Mdot
.21429 .24513 Mdot
.21619 .39903 Mdot
.2181 .24949 Mdot
.22 .4056 Mdot
.2219 .40237 Mdot
.22381 .33045 Mdot
.22571 .31261 Mdot
.22762 .2535 Mdot
.22952 .35233 Mdot
.23143 .33855 Mdot
.23333 .35081 Mdot
.23524 .25913 Mdot
.23714 .32096 Mdot
.23905 .33024 Mdot
.24095 .28428 Mdot
.24286 .35309 Mdot
.24476 .2744 Mdot
.24667 .33798 Mdot
.24857 .32211 Mdot
.25048 .32021 Mdot
.25238 .2668 Mdot
.25429 .38036 Mdot
.25619 .45699 Mdot
.2581 .34359 Mdot
.26 .26321 Mdot
.2619 .35465 Mdot
.26381 .29642 Mdot
.26571 .26737 Mdot
.26762 .46367 Mdot
.26952 .3898 Mdot
.27143 .27156 Mdot
.27333 .3743 Mdot
.27524 .39717 Mdot
.27714 .41136 Mdot
.27905 .36933 Mdot
.28095 .3619 Mdot
.28286 .2482 Mdot
.28476 .23046 Mdot
.28667 .25867 Mdot
.28857 .27038 Mdot
.29048 .38559 Mdot
.29238 .42149 Mdot
.29429 .46214 Mdot
.29619 .33624 Mdot
.2981 .34127 Mdot
.3 .25846 Mdot
.3019 .28669 Mdot
.30381 .3369 Mdot
.30571 .32374 Mdot
.30762 .35741 Mdot
.30952 .34851 Mdot
.31143 .44811 Mdot
.31333 .25519 Mdot
.31524 .32084 Mdot
.31714 .37676 Mdot
.31905 .32158 Mdot
.32095 .38907 Mdot
.32286 .23239 Mdot
.32476 .23142 Mdot
.32667 .3338 Mdot
.32857 .25595 Mdot
.33048 .23182 Mdot
.33238 .31566 Mdot
.33429 .239 Mdot
.33619 .40908 Mdot
.3381 .26164 Mdot
.34 .36463 Mdot
.3419 .39616 Mdot
.34381 .33776 Mdot
.34571 .32806 Mdot
.34762 .33805 Mdot
.34952 .22999 Mdot
.35143 .23997 Mdot
.35333 .33198 Mdot
.35524 .33737 Mdot
.35714 .3571 Mdot
.35905 .35876 Mdot
.36095 .3811 Mdot
.36286 .46089 Mdot
.36476 .38864 Mdot
.36667 .26679 Mdot
.36857 .24372 Mdot
.37048 .23329 Mdot
.37238 .40578 Mdot
.37429 .26351 Mdot
.37619 .43065 Mdot
.3781 .28962 Mdot
.38 .35036 Mdot
.3819 .46095 Mdot
.38381 .307 Mdot
.38571 .40861 Mdot
.38762 .35446 Mdot
.38952 .45236 Mdot
.39143 .28987 Mdot
.39333 .32786 Mdot
.39524 .46075 Mdot
.39714 .35429 Mdot
.39905 .4334 Mdot
.40095 .4073 Mdot
.40286 .35723 Mdot
.40476 .45372 Mdot
.40667 .25893 Mdot
.40857 .27481 Mdot
.41048 .27334 Mdot
.41238 .32318 Mdot
.41429 .35868 Mdot
.41619 .44864 Mdot
.4181 .39609 Mdot
.42 .31763 Mdot
.4219 .37948 Mdot
.42381 .33083 Mdot
.42571 .28859 Mdot
.42762 .29224 Mdot
.42952 .3921 Mdot
.43143 .3228 Mdot
.43333 .32603 Mdot
.43524 .26109 Mdot
.43714 .39539 Mdot
.43905 .32392 Mdot
.44095 .41294 Mdot
.44286 .27891 Mdot
.44476 .39401 Mdot
.44667 .38267 Mdot
.44857 .34167 Mdot
.45048 .29158 Mdot
.45238 .33711 Mdot
.45429 .27438 Mdot
.45619 .25991 Mdot
.4581 .36153 Mdot
.46 .40493 Mdot
.4619 .33594 Mdot
.46381 .42309 Mdot
.46571 .45738 Mdot
.46762 .29316 Mdot
.46952 .27645 Mdot
.47143 .4378 Mdot
.47333 .25039 Mdot
.47524 .31677 Mdot
.47714 .4556 Mdot
.47905 .34028 Mdot
.48095 .40306 Mdot
.48286 .36146 Mdot
.48476 .39818 Mdot
.48667 .46238 Mdot
.48857 .36011 Mdot
.49048 .32186 Mdot
.49238 .24465 Mdot
.49429 .31627 Mdot
.49619 .3367 Mdot
.4981 .24043 Mdot
.5 .25278 Mdot
.5019 .24418 Mdot
.50381 .23166 Mdot
.50571 .43357 Mdot
.50762 .27425 Mdot
.50952 .33119 Mdot
.51143 .25054 Mdot
.51333 .31779 Mdot
.51524 .33686 Mdot
.51714 .32598 Mdot
.51905 .28534 Mdot
.52095 .37406 Mdot
.52286 .27468 Mdot
.52476 .2655 Mdot
.52667 .31593 Mdot
.52857 .27149 Mdot
.53048 .26476 Mdot
.53238 .25062 Mdot
.53429 .39745 Mdot
.53619 .296 Mdot
.5381 .37707 Mdot
.54 .24504 Mdot
.5419 .29293 Mdot
.54381 .26536 Mdot
.54571 .33299 Mdot
.54762 .2561 Mdot
.54952 .25949 Mdot
.55143 .23069 Mdot
.55333 .26484 Mdot
.55524 .35872 Mdot
.55714 .30173 Mdot
.55905 .28024 Mdot
.56095 .38554 Mdot
.56286 .24188 Mdot
.56476 .26368 Mdot
.56667 .25668 Mdot
.56857 .26045 Mdot
.57048 .39793 Mdot
.57238 .3525 Mdot
.57429 .31786 Mdot
.57619 .35486 Mdot
.5781 .30763 Mdot
.58 .34979 Mdot
.5819 .2948 Mdot
.58381 .45934 Mdot
.58571 .27374 Mdot
.58762 .41398 Mdot
.58952 .29108 Mdot
.59143 .287 Mdot
.59333 .2471 Mdot
.59524 .45878 Mdot
.59714 .32175 Mdot
.59905 .42054 Mdot
.60095 .30839 Mdot
.60286 .27263 Mdot
.60476 .33938 Mdot
.60667 .39873 Mdot
.60857 .32188 Mdot
.61048 .43131 Mdot
.61238 .2834 Mdot
.61429 .30803 Mdot
.61619 .31599 Mdot
.6181 .28656 Mdot
.62 .3868 Mdot
.6219 .26177 Mdot
.62381 .37713 Mdot
.62571 .44609 Mdot
.62762 .26751 Mdot
.62952 .39568 Mdot
.63143 .3107 Mdot
.63333 .39623 Mdot
.63524 .264 Mdot
.63714 .41028 Mdot
.63905 .45279 Mdot
.64095 .46652 Mdot
.64286 .28902 Mdot
.64476 .36586 Mdot
.64667 .30089 Mdot
.64857 .23441 Mdot
.65048 .36243 Mdot
.65238 .29118 Mdot
.65429 .29937 Mdot
.65619 .2525 Mdot
.6581 .3735 Mdot
.66 .25674 Mdot
.6619 .33679 Mdot
.66381 .38998 Mdot
.66571 .27028 Mdot
.66762 .32301 Mdot
.66952 .40445 Mdot
.67143 .36814 Mdot
.67333 .36456 Mdot
.67524 .31352 Mdot
.67714 .3584 Mdot
.67905 .42987 Mdot
.68095 .30305 Mdot
.68286 .38807 Mdot
.68476 .3342 Mdot
.68667 .36684 Mdot
.68857 .32566 Mdot
.69048 .25882 Mdot
.69238 .37975 Mdot
.69429 .33952 Mdot
.69619 .32953 Mdot
.6981 .46291 Mdot
.7 .39134 Mdot
.7019 .23906 Mdot
.70381 .25514 Mdot
.70571 .28786 Mdot
.70762 .26746 Mdot
.70952 .24516 Mdot
.71143 .25104 Mdot
.71333 .39257 Mdot
.71524 .46946 Mdot
.71714 .31966 Mdot
.71905 .41203 Mdot
.72095 .41282 Mdot
.72286 .42317 Mdot
.72476 .32152 Mdot
.72667 .25458 Mdot
.72857 .42364 Mdot
.73048 .37023 Mdot
.73238 .32085 Mdot
.73429 .31162 Mdot
.73619 .28588 Mdot
.7381 .37667 Mdot
.74 .39906 Mdot
.7419 .32571 Mdot
.74381 .40273 Mdot
.74571 .25184 Mdot
.74762 .2482 Mdot
.74952 .36224 Mdot
.75143 .23319 Mdot
.75333 .37244 Mdot
.75524 .43246 Mdot
.75714 .3474 Mdot
.75905 .27937 Mdot
.76095 .3887 Mdot
.76286 .32163 Mdot
.76476 .44725 Mdot
.76667 .24504 Mdot
.76857 .29712 Mdot
.77048 .40411 Mdot
.77238 .35739 Mdot
.77429 .29697 Mdot
.77619 .25692 Mdot
.7781 .33438 Mdot
.78 .3227 Mdot
.7819 .28692 Mdot
.78381 .35066 Mdot
.78571 .46009 Mdot
.78762 .4073 Mdot
.78952 .27826 Mdot
.79143 .4244 Mdot
.79333 .27465 Mdot
.79524 .35862 Mdot
.79714 .35996 Mdot
.79905 .27191 Mdot
.80095 .37546 Mdot
.80286 .39708 Mdot
.80476 .32578 Mdot
.80667 .33698 Mdot
.80857 .29217 Mdot
.81048 .28027 Mdot
.81238 .44224 Mdot
.81429 .3615 Mdot
.81619 .27184 Mdot
.8181 .32908 Mdot
.82 .32541 Mdot
.8219 .26492 Mdot
.82381 .36144 Mdot
.82571 .30237 Mdot
.82762 .31354 Mdot
.82952 .32018 Mdot
.83143 .45335 Mdot
.83333 .3828 Mdot
.83524 .30569 Mdot
.83714 .32032 Mdot
.83905 .2541 Mdot
.84095 .39268 Mdot
.84286 .27926 Mdot
.84476 .33594 Mdot
.84667 .44617 Mdot
.84857 .46311 Mdot
.85048 .40164 Mdot
.85238 .37249 Mdot
.85429 .40225 Mdot
.85619 .32021 Mdot
.8581 .36344 Mdot
.86 .42648 Mdot
.8619 .3079 Mdot
.86381 .37494 Mdot
.86571 .42569 Mdot
.86762 .33543 Mdot
.86952 .30267 Mdot
.87143 .3585 Mdot
.87333 .28017 Mdot
.87524 .26486 Mdot
.87714 .45257 Mdot
.87905 .29188 Mdot
.88095 .34066 Mdot
.88286 .29567 Mdot
.88476 .33453 Mdot
.88667 .26572 Mdot
.88857 .25874 Mdot
.89048 .36099 Mdot
.89238 .26719 Mdot
.89429 .24042 Mdot
.89619 .40206 Mdot
.8981 .3963 Mdot
.9 .26819 Mdot
.9019 .30018 Mdot
.90381 .26678 Mdot
.90571 .469 Mdot
.90762 .25717 Mdot
.90952 .37449 Mdot
.91143 .43125 Mdot
.91333 .30145 Mdot
.91524 .24331 Mdot
.91714 .28521 Mdot
.91905 .26468 Mdot
.92095 .26239 Mdot
.92286 .39978 Mdot
.92476 .35163 Mdot
.92667 .33075 Mdot
.92857 .29969 Mdot
.93048 .46148 Mdot
.93238 .36767 Mdot
.93429 .29602 Mdot
.93619 .35682 Mdot
.9381 .257 Mdot
.94 .32353 Mdot
.9419 .27631 Mdot
.94381 .34275 Mdot
.94571 .35393 Mdot
.94762 .27491 Mdot
.94952 .3175 Mdot
.95143 .33893 Mdot
.95333 .36347 Mdot
.95524 .39661 Mdot
.95714 .33137 Mdot
.95905 .35384 Mdot
.96095 .31676 Mdot
.96286 .36669 Mdot
.96476 .31265 Mdot
.96667 .40268 Mdot
.96857 .31005 Mdot
.97048 .26413 Mdot
.97238 .34168 Mdot
.97429 .2521 Mdot
.97619 .40283 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1@ooooo`;o00004ooo
ool2o`0003oooooo0_l0002Dooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o00005?ooool2o`0000Kooooo0_l0
0005ooooo`;o00001Oooool2o`0002Cooooo0_l0000:ooooo`Go00001?ooool2o`0000Gooooo0_l0
000Yooooo`;o00003Oooool2o`0003kooooo0_l0001Dooooo`001_ooool01Ol0003ooooooooooooo
oooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool05?ooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`000003oooo
ool0003o000002gooooo1Ol0000;ooooo`;o0000:Oooool2o`0002cooooo0_l0000Oooooo`;o0000
E?ooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0]ooooo`;o0000<Oooool2o`0000Cooooo
0_l0001Mooooo`;o00003oooool2o`0006Cooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Kooooo`;o0000@oooool2o`0000Cooooo0_l0000]ooooo`;o00004oooool2o`0002[o
oooo0_l0000looooo`;o00001Oooool2o`0001oooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo
01_ooooo0_l0000;ooooo`;o00002Oooool2o`0000Gooooo0_l0000_ooooo`;o00009_ooool5o`00
00[ooooo0_l00006ooooo`;o0000;Oooool2o`00013ooooo0_l0000Wooooo`;o00001Oooool2o`00
01oooooo000Yooooo`;o00005?ooool2o`0001?ooooo0_l00009ooooo`;o00001Oooool3o`0001?o
oooo0_l0000Iooooo`;o00009_ooool2o`000003ooooool0003o000000[ooooo0_l0000?ooooo`;o
00009?ooool2o`0000[ooooo0_l00004ooooo`;o0000Coooool002Wooooo00?o0000ooooooooool0
4oooool2o`0000_ooooo0_l0000Iooooo`;o00004oooool2o`0003_ooooo0_l00006ooooo`;o0000
0_ooool2o`0000Gooooo0_l0000Aooooo`;o00004oooool2o`0000oooooo0_l00009ooooo`?o0000
Aoooool2o`0000cooooo000Yooooo`03o`000?oooooooooo01;ooooo0_l0000<ooooo`;o00002?oo
ool2o`000003ooooool0003o000000oooooo0_l0000Iooooo`;o00000oooool2o`0002gooooo0_l0
0006ooooo`;o00000_ooool2o`0000Gooooo0_l0000Vooooo`;o00003Oooool4o`0000?ooooo0_l0
0004ooooo`;o00007?ooool2o`0002[ooooo0_l0000<ooooo`00:Oooool00ol0003oooooooooo`0>
ooooo`;o00000_ooool2o`0001Kooooo0_l000000ooooooo0000o`00000?ooooo`;o00004Oooool2
o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0001Oooooo0_l0000/ooooo`;o00001?ooool2
o`0001cooooo0_l00008ooooo`;o00000_ooool2o`0000Gooooo0_l0000>ooooo`;o00004_ooool2
o`0000kooooo0_l00004ooooo`;o00002?ooool2o`0001Sooooo000Yooooo`03o`000?oooooooooo
00;ooooo0_l00003ooooo`;o00001Oooool2o`0001Gooooo0_l0000Iooooo`;o00003oooool2o`00
00;ooooo0_l0000:ooooo`;o00005?ooool2o`0000Sooooo0_l00004ooooo`;o00007?ooool2o`00
00Cooooo0_l0000@ooooo`;o00002_ooool2o`0000Sooooo0_l0000Iooooo`;o00008_ooool2o`00
00Cooooo0_l00008ooooo`;o00006?ooool002Wooooo0_l00003ooooo`;o000000?oooooo`000?l0
00000_l0000Looooo`;o00004Oooool2o`0000Kooooo0_l00006ooooo`;o00005oooool2o`0000[o
oooo0_l0000Booooo`;o00001?ooool2o`0001Kooooo0_l00004ooooo`Co000000Coooooo`000?l0
003o00004?ooool2o`0000;ooooo0_l0000jooooo`;o00003oooool2o`0000cooooo0ol0000>oooo
o`;o00003Oooool002Wooooo00?o0000ooooooooool01Oooool2o`0001Wooooo0_l0000Aooooo`;o
00000oooool2o`0000cooooo1_l0000Oooooo`Co0000;_ooool4o`0000;ooooo0_l00002ooooo`;o
000000?oooooo`000?l000004_ooool2o`000003ooooool0003o000001Gooooo0_l0000Sooooo`;o
00003oooool2o`0000;ooooo1ol00003ooooo`?o00003_ooool2o`0000gooooo000Yooooo`03o`00
0?oooooooooo023ooooo0_l00004ooooo`;o000000?oooooo`000?l000001Oooool5o`0000;ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool2o`00
00;ooooo0_l00005ooooo`;o00006?ooool7o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool4o`0000;ooooo0_l00005ooooo`05oiRHV?l@
413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Cok^k^oc8b<_l0
003o<S8b0_l0000;ooooo`;o00002oooool2o`0000oooooo0_l000002Ol@413ooooooooooooooooo
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h05_ooool7o`0000co
oooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Yooooo`03o`000?oooooooooo02Kooooo0_l00000
0ooooooo0000o`000007ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`04ogMgMonHV9SooooooiRHV0;o00001oooool2o`0000?ooooo0_l0000Jooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@00oooool01?mgMgOoV9RHoooooonHV9P2o`0000;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o00003oooool2o`0000Gooooo0_l00009ooooo`05oa0@4?nj^[[o
ooooogMgMolb<S800_ooool2o`000003oiRHV?ooooooV9RH00;o00000_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo0_l0000Mooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`02ooooo`;o000000?oV9RHoooooonHV9P00_l0000[ooooo`09ogMgMolb<S;ooooooooo
oomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Ooo
ool00ol0003oooooooooo`06ooooo`;o0000:_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41000oooool01?l@413oooooooooooooool2o`0000Oooooo0_l0000Pooooo`03
oiRHV?lQ8B7ok^k^00Cooooo00?o410@ooooooooool00ol00002ooooo`05oa0@4?oooooooooooooo
ool@41001Oooool2o`0000?ooooo0_l0000:ooooo`;o00000oooool2o`0000oooooo00?o0000oooo
ooooool00_l00003ooooo`;o00000_ooool01Ol@413ooooooooooooooooo410@02Sooooo1Ol00003
ooooo`05oa0@4?ooooooooooooooool@41001?l00003ooooo`;o00009_ooool4o`0000;ooooo00Co
0000oooooooooooo410@0oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooooooo
ool00Oooool002Wooooo0_l00007ooooo`;o0000:_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000002_ooooo00?oV9RHob4Q
8Oo^k^h00oooool00ol0003oooooooooo`02o`0000?ooooo00Ko0000ooooooooooooooooo`000?oo
ool2o`0000Oooooo0_l0000?ooooo`;o00002Oooool2o`0000?ooooo00?oZJVYoa0@4?ooool00_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00000Xooooo`04
odA4A?oMgMgo0000o`0000Cooooo00?o0000ooooooooool01?l000000ooooooo0000ooooo`03o`00
00Sooooo0_l00007ooooo`;o00005?ooool4o`000003oooooomgMgOo<S8b00;ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool002Wooooo00?o0000
ooooooooool02Oooool2o`0000kooooo0ol0000Fooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000;?ooool00omgMgOoIVIV
ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01_l0003ooooooooooooooooo0000
ooooo`;o00008oooool2o`0000;ooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooo
oooo000000?ooooo0_l00002ooooo`03o`000?oooooooooo02Kooooo00CogMgMoeEEEOl0003o0000
1?ooool00ol0003oooooooooo`02o`0000?ooooo00?o0000ooooool000000_l00008ooooo`;o0000
1oooool2o`0001Kooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo000Yooooo`03o`000?oooooooooo
00Wooooo0_l0000>ooooo`?o00005_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41000oooool00ol@413oooooooooo`02o`0001;ooooo0_l0000Iooooo`05o`000?oooooo
ooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0
6?ooool2o`0000oooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413o0000o`000?oooooo410@00?o
oooo0ol000000ooooooo410@ooooo`0Qooooo`;o00001Oooool00omgMgOoc<c<o`000004ooooo`05
oa0@4?l0003o0000ooooool@41000oooool01Ol@413ooooooooooooooooo410@023ooooo0_l00007
ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oo
ooooooooooooool@41000oooool002Wooooo00?o0000ooooooooool06_ooool2o`0000oooooo0_l0
0005ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03ogMg
MonHV9Sooooo00;o00004_ooool2o`0001Gooooo0ol000002_nHV9So410@o`000?l0003oooooogMg
MonHV9SooooooiRHV?mgMgL3ooooo`;o000000?ooooooiRHV?mgMgL06_ooool2o`0000cooooo00Go
410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMol0003o0000oiRHV?mgMgL00oooool01OmgMgOo
0000o`000?nHV9SoMgMg00Cooooo0_l0000Cooooo`;o00001oooool2o`0000Gooooo00?ok^k^odA4
A?l000001?ooool01OmgMgOo0000o`000?nHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Pooooo`;o00001oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000Yooooo`03o`000?oooooooooo01cooooo
0_l0000=ooooo`;o000000Coooooo`000?l0003oEEEE0_l00004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Wooooo00GoV9RHo`000?l0003o8B4Qolc<
c002o`000006ooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool3o`000003oc8b<_o^k^kooooo00;o
oooo0_l00004ooooo`;o00005_ooool2o`0000Gooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03oooo
o`?o000000?o<S8bonk^k_ooool00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo0_l00000
0ooooooo0000o`00000@ooooo`;o00003oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?l0003ok^k^01?ooooo0_l0000Dooooo`Co0000
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`00:Oooool2o`0001gooooo0_l0000@ooooo`;o000000?oooooo`000?l00000Boooool2o`0000Go
oooo0_l00004ooooo`;o00005?ooool4o`0000_ooooo1?l0000Booooo`;o0000<Oooool2o`0001Co
oooo0ol0000?ooooo`;o00006Oooool002Wooooo00?o0000ooooooooool00oooool2o`0004Cooooo
0_l0001Fooooo`;o00003Oooool2o`0001Gooooo0_l0000Sooooo`Co00008?ooool2o`0000oooooo
0_l0000Iooooo`00:Oooool00ol0003oooooooooo`03ooooo`;o0000A?ooool2o`0005gooooo0_l0
000Kooooo`Co00008oooool4o`0000kooooo0_l0000Gooooo`;o000000?oooooo`000?l000000ooo
ool2o`0001_ooooo000Yooooo`03o`000?oooooooooo0:Sooooo0_l0000Kooooo`;o00002Oooool2
o`0002cooooo0_l000000ooooooo0000o`000009ooooo`;o00002Oooool2o`000003ooooool0003o
000000?ooooo0_l0000Kooooo`00:Oooool00ol0003oooooooooo`0Aooooo`;o00000oooool2o`00
01Sooooo0_l0000nooooo`;o0000??ooool2o`0000Kooooo0_l00002ooooo`;o00005?ooool2o`00
02oooooo0_l00007ooooo`Co0000;_ooool0027oooooool00014o`0000Cooooo000Yooooo`Ko0000
1_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool3o`0000Wooooo00?o0000ooooooooool00_l00008ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo
0_l0000;ooooo`?o00002_ooool00ol0003oooooooooo`04ooooo`;o00000oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo0ol0000:ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`?o000000?oooooo`000?ooool0
2oooool002Wooooo00?o0000ooooooooool04_ooool2o`0001Sooooo0_l0000:ooooo`?o00000_oo
ool2o`00023ooooo0_l0000Gooooo`04o`000?ooooooooooooooo`;o00003oooool2o`0000Gooooo
0_l00004ooooo`;o00000_ooool2o`0000gooooo0_l00006ooooo`03o`000?oooooooooo00?ooooo
0_l0000Aooooo`;o00008_ooool00ol0003oooooooooo`0:ooooo`;o00009Oooool2o`0000;ooooo
0ol00002ooooo`03o`000?oooooooooo00[ooooo000Yooooo`03o`000?oooooooooo01;ooooo0_l0
000Hooooo`;o00002_ooool2o`0000Oooooo0_l00002ooooo`;o00004oooool2o`0000?ooooo0_l0
000Kooooo`;o00003oooool2o`0000Gooooo0_l00004ooooo`;o00000_ooool2o`0000gooooo0_l0
000<ooooo`;o00007_ooool2o`0000?ooooo0_l0000Mooooo`;o000000?oooooo`000?l000001?oo
ool2o`0001cooooo0_l00002ooooo`;o00004?ooool002Wooooo00?o0000ooooooooool03oooool2
o`0001Oooooo0_l0000Gooooo`;o00000_ooool2o`00013ooooo0_l000001?oooooo0000o`000?l0
000Looooo`;o00001?ooool2o`000003ooooool0003o000000kooooo0_l0000Qooooo`;o000000?o
ooooo`000?l000004Oooool2o`0000kooooo0_l000000ooooooo0000o`000002o`0000Sooooo0_l0
0003ooooo`;o00003_ooool2o`000003ooooool0003o000000Cooooo0_l0000Iooooo`;o00005ooo
ool002Wooooo0_l0000@ooooo`;o00005oooool2o`0001_ooooo0_l0000@ooooo`;o00000_ooool2
o`0001cooooo0_l00004ooooo`Go00003_ooool2o`0000Oooooo0_l0000Hooooo`;o000000?ooooo
o`000?l000004Oooool2o`0000Gooooo0_l0000:ooooo`;o00000oooool2o`0000Gooooo0_l00003
ooooo`;o00001_ooool2o`0000?ooooo0_l0000Uooooo`;o00005oooool002Wooooo00?o0000oooo
ooooool03Oooool2o`000003ooooool0003o000002_ooooo0_l00002ooooo`;o00008Oooool2o`00
00gooooo0_l0000;ooooo`;o00006Oooool2o`0003Gooooo1?l0000=ooooo`;o00004_ooool2o`00
00?ooooo0_l0000nooooo`00:Oooool00ol0003oooooooooo`0=ooooo`;o000000?oooooo`000?l0
00003?ooool2o`0000?ooooo0_l0000Hooooo`;o00000_ooool2o`00027ooooo1?l0000;ooooo`;o
00002?ooool2o`0001Wooooo0_l0000:ooooo`;o0000;_ooool2o`0002Kooooo0_l0000Qooooo`;o
00001oooool2o`0001;ooooo000Yooooo`03o`000?oooooooooo00cooooo0_l0000@ooooo`;o0000
0oooool2o`0002oooooo0_l00008ooooo`;o00001_ooool2o`0001Gooooo0_l0000:ooooo`;o0000
2Oooool2o`0000;ooooo0_l0000:ooooo`;o00008oooool2o`0000Kooooo0_l0000Looooo`;o0000
4oooool2o`0000Kooooo0_l00003ooooo`;o00003?ooool2o`0000Oooooo0_l0000Booooo`00:Ooo
ool00ol0003oooooooooo`0<ooooo`;o00005oooool4o`0000cooooo0ol00007ooooo`;o00000ooo
ool2o`0000kooooo1?l00006ooooo`;o00000oooool3o`000003ooooool0003o000001gooooo0_l0
00000ooooooo0000o`000009ooooo`;o00001?ooool2o`0001_ooooo0_l0000@ooooo`;o00001_oo
ool2o`000003ooooool0003o000001Wooooo0_l00007ooooo`;o00002_ooool2o`0000Kooooo0_l0
0003ooooo`;o00005?ooool2o`0001?ooooo000Yooooo`;o00009_ooool4o`0000cooooo0ol00007
ooooo`;o00000oooool2o`0000kooooo1?l0000;ooooo`?o000000?oooooo`000?l000007?ooool3
o`0000Oooooo0_l00009ooooo`;o00006oooool2o`0001_ooooo0_l0000Rooooo`;o00005_ooool2
o`0001;ooooo0_l000000ooooooo0000o`000004ooooo`;o00003Oooool002Wooooo00?o0000oooo
ooooool00_ooool2o`00013ooooo0_l0000Jooooo`;o00005_ooool2o`0000[ooooo0_l0000_oooo
o`;o00002?ooool2o`0007oooooo0_l0000Booooo`;o00001oooool2o`0000gooooo000Yooooo`03
o`000?oooooooooo00;ooooo0_l00004ooooo`;o00002_ooool2o`0000Oooooo0_l0000Aooooo`;o
00005_ooool2o`0000kooooo0_l0002>ooooo`;o0000D_ooool002Wooooo00?o0000ooooooooool0
2?ooool2o`0000?ooooo0_l0000>ooooo`;o00000oooool2o`0000kooooo0_l0000:ooooo`Co0000
5_ooool2o`0001Gooooo0_l0000nooooo`;o0000=oooool2o`0000Oooooo0_l0000[ooooo`;o0000
7?ooool002Wooooo00?o0000ooooooooool03Oooool2o`0000Sooooo0_l00009ooooo`;o00003_oo
ool2o`0000[ooooo1?l000000ooooooo0000o`000004ooooo`;o00009?ooool4o`000003ooooool0
003o000003Oooooo1?l00010ooooo`;o0000:oooool2o`0000Gooooo0_l00002ooooo`;o00004Ooo
ool002Wooooo0_l00002ooooo`;o00005?ooool3o`0001cooooo0_l0000;ooooo`;o00001?ooool2
o`0000gooooo0_l0000=ooooo`;o00002?ooool2o`000003ooooool0003o000000;o0000=Oooool3
o`0001kooooo0_l0000Mooooo`;o00007_ooool2o`0001?ooooo0_l000000ooooooo0000o`000002
ooooo`;o00004Oooool002Wooooo00Co0000oooooooooooooooo0_l00006ooooo`?o00003?ooool2
o`0000Gooooo0_l00006ooooo`;o00003Oooool2o`00023ooooo0_l0000=ooooo`?o00003?ooool2
o`0000;ooooo0_l0000<ooooo`;o00001_ooool4o`0001?ooooo0_l0000Uooooo`;o00007Oooool2
o`0000Gooooo0ol00003ooooo`;o00000_ooool2o`0000gooooo0_l00004ooooo`;o00003Oooool2
o`0001Sooooo000Yooooo`04o`000?oooooo0000o`0000Sooooo0ol0000Cooooo`;o00001_ooool2
o`0000Wooooo0_l0000Kooooo`;o00004Oooool2o`0000Cooooo0_l0000@ooooo`;o00003?ooool2
o`0000Kooooo1?l0000Cooooo`;o00007Oooool2o`0000Gooooo0_l0000Gooooo`;o00003?ooool3
o`0000?ooooo0_l00002ooooo`;o00002Oooool2o`0000Sooooo0_l0000Booooo`;o00004oooool0
02Wooooo00Co0000ooooool0003o00003oooool2o`00023ooooo0_l0000Kooooo`;o00004Oooool2
o`00063ooooo1?l00005ooooo`;o00000_ooool2o`0001?ooooo0_l0000Qooooo`;o00005Oooool2
o`0000Gooooo0_l000000ooooooo0000o`00000@ooooo`00:Oooool00ol0003oooooooooo`0@oooo
o`;o00003Oooool2o`0002gooooo0_l0001dooooo`;o00001oooool2o`0000;ooooo0_l0000<oooo
o`;o0000?oooool2o`0000Sooooo0_l0000@ooooo`00:Oooool2o`000003ooooool0003o000000Wo
oooo0_l0000Booooo`;o0000;Oooool2o`0004cooooo0_l0000Zooooo`;o00000oooool2o`00013o
oooo0_l00006ooooo`;o00007_ooool2o`0003?ooooo000Yooooo`03o`000?oooooooooo00;o0000
2Oooool2o`00043ooooo0_l0000<ooooo`;o0000?oooool2o`0000Cooooo0_l0000Iooooo`;o0000
2Oooool2o`0001Sooooo0_l00003ooooo`;o00003Oooool2o`0000oooooo0_l000000ooooooo0000
o`00000=ooooo`;o00008Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo04go
oooo0_l0000<ooooo`;o00007oooool2o`0002Cooooo0_l0000Iooooo`;o00005?ooool2o`0000go
oooo0_l0000Booooo`;o00004_ooool2o`0000gooooo0_l0000Qooooo`001_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo00Oooooo0_l0000mooooo`;o00008Oooool2o`00
017ooooo0_l00006ooooo`;o0000COooool2o`0002cooooo0_l0000iooooo`001_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo0_l000001?oooooo0000o`000?ooool2o`0003[ooooo0_l0000:
ooooo`;o00005Oooool2o`0001Wooooo0_l0000Sooooo`;o0000E_ooool2o`0003Wooooo0006oooo
o`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;o
oooo00Cooooo0ol00004ooooo`;o00001?ooool2o`0004Kooooo0_l00008ooooo`;o00003?ooool2
o`0003gooooo0_l0000Aooooo`;o00004_ooool2o`0001Oooooo0_l0001Aooooo`001_ooool01Ol0
003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Gooooo00?o0000ooooooooool09?ooool2o`0000Sooooo0_l0000Kooooo`;o00003ooo
ool2o`0000cooooo0_l0000Cooooo`;o0000>oooool2o`0000cooooo0_l00004ooooo`;o00001?oo
ool2o`0000;ooooo0_l0000=ooooo`;o00006?ooool2o`0003Oooooo0006ooooo`05oa0@4?oooooo
ooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool03oooool2o`0000Cooooo0_l000000ooooooo0000o`000007ooooo`;o000000?o
ooooo`000?l000002?ooool2o`0001_ooooo0_l0000booooo`Co000000?oooooo`000?l00000>Ooo
ool2o`0000Wooooo0_l0000:ooooo`;o00000_ooool2o`0002Oooooo0_l0000gooooo`001_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01?ooool2o`0000Wooooo0_l00004ooooo`;o0000
00?oooooo`000?l000001oooool2o`0002[ooooo0_l0000Dooooo`;o00005_ooool2o`0000Cooooo
0_l000000ooooooo0000o`00000:ooooo`;o00003_ooool2o`0000[ooooo0_l0000:ooooo`;o0000
1Oooool3o`0003Gooooo0_l0000Looooo`;o00004Oooool2o`0001;ooooo0006ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o
00001Oooool2o`00017ooooo0_l0000Qooooo`;o00004Oooool2o`0001Cooooo0_l0000Fooooo`;o
00004oooool2o`0000kooooo0_l0000:ooooo`;o00002_ooool2o`0000Kooooo0_l0000Qooooo`;o
00004_ooool2o`0000gooooo0_l0000=ooooo`;o00001_ooool2o`0000Wooooo0_l0000Booooo`00
:Oooool2o`0001Sooooo0_l0000Qooooo`Co0000Boooool2o`0000Cooooo0_l0000kooooo`;o0000
5Oooool3o`0000Kooooo0_l0000Hooooo`?o00003?ooool2o`0000Kooooo0_l0000<ooooo`;o0000
0_ooool2o`0000_ooooo000Yooooo`03o`000?oooooooooo03_ooooo0ol0000^ooooo`;o00002?oo
ool2o`00017ooooo0_l00004ooooo`;o0000>oooool2o`0001Kooooo0_l00006ooooo`;o00001?oo
ool2o`0001?ooooo0_l0000Rooooo`;o00000_ooool2o`0000_ooooo000Yooooo`03o`000?oooooo
oooo03_ooooo0_l0000Aooooo`;o00004Oooool2o`0000Wooooo0_l00003ooooo`;o00000oooool2
o`0004Wooooo0_l0000_ooooo`;o0000B?ooool002Wooooo00?o0000ooooooooool0>Oooool2o`00
01?ooooo0_l0000Aooooo`;o00003_ooool2o`0000oooooo0_l0000^ooooo`;o00003Oooool2o`00
01Wooooo0_l0001Nooooo`00:Oooool00ol0003oooooooooo`0Mooooo`;o00003?ooool2o`0000co
oooo0_l00017ooooo`;o0000;_ooool2o`0002Sooooo0_l0001Nooooo`00:Oooool2o`0001kooooo
0_l0000<ooooo`;o0000R?ooool2o`0008Gooooo000Yooooo`03o`000?oooooooooo00Gooooo0_l0
001<ooooo`;o0000=Oooool2o`0002Wooooo0_l0000Vooooo`Co0000Foooool002Wooooo00?o0000
ooooooooool01Oooool2o`0004cooooo0_l0000eooooo`;o0000DOooool4o`0001;ooooo0_l0000D
ooooo`Co0000;oooool002Wooooo00?o0000ooooooooool05Oooool2o`000;Sooooo0_l0000Roooo
o`;o00005?ooool4o`0002oooooo000Yooooo`03o`000?oooooooooo01Gooooo0_l0001Gooooo`;o
0000BOooool2o`0001Cooooo0_l0000Fooooo`;o0000<Oooool2o`00023ooooo000Yooooo`;o0000
Koooool2o`0000Gooooo0_l0000Pooooo`;o00008?ooool2o`0002cooooo0_l0000aooooo`;o0000
8?ooool002Wooooo00?o0000ooooooooool03?ooool2o`0006Oooooo0_l0000Eooooo`;o00002Ooo
ool2o`000:?ooooo000Yooooo`03o`000?oooooooooo00cooooo0_l0000Vooooo`;o0000E_ooool2
o`0006cooooo0_l00010ooooo`00:Oooool00ol0003oooooooooo`0dooooo`;o0000a?ooool2o`00
043ooooo000Yooooo`03o`000?oooooooooo05Wooooo0_l0000Oooooo`;o0000@_ooool2o`0002_o
oooo0_l0000Hooooo`;o0000=Oooool002Wooooo0_l0000fooooo`;o00008_ooool2o`0001oooooo
0_l00012ooooo`;o0000:oooool2o`0001Sooooo0_l0000eooooo`00:Oooool00ol0003ooooooooo
o`0eooooo`;o0000>oooool2o`0000?ooooo0_l00019ooooo`;o0000??ooool2o`0000gooooo0_l0
000[ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`17ooooo`;o0000:Oooool2o`0000?ooooo
0_l0000Aooooo`;o00000_ooool2o`0003;ooooo0_l0000looooo`;o00003Oooool2o`0002_ooooo
000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`0gooooo`;o00003_ooool2o`00023ooooo0_l00004ooooo`;o0000
0oooool2o`0001Cooooo0_l00002ooooo`;o00008?ooool2o`0000;ooooo0_l0000kooooo`;o0000
BOooool000kooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo
0ol0000Rooooo`;o00004oooool2o`0001;ooooo0_l00006ooooo`;o00005?ooool2o`0000Cooooo
0_l00003ooooo`;o00006oooool2o`0001gooooo0_l00002ooooo`;o00007oooool2o`0001[ooooo
0_l0000Booooo`;o00006Oooool2o`0001[ooooo000>ooooo`05o`000?ooooooooooooooool00000
3oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02;ooooo0_l0000Wooooo`;o0000
1_ooool2o`0003cooooo0_l0000`ooooo`;o00004?ooool2o`0002kooooo0_l0000Iooooo`;o0000
6_ooool000kooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`33ooooo`;o00005_ooool2o`0003_ooooo0_l0000Rooooo`00
3_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`3Kooooo`;o0000>oooool2o`0002;ooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEE
ooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`000?oo
ooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo
00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMooo
ool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`007oooool4o`000003oa0@4?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`007oooool00omEEEGoIVIVo`00003oooooodOooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .374 Mdot
.02762 .39835 Mdot
.02952 .29732 Mdot
.03143 .34044 Mdot
.03333 .34826 Mdot
.03524 .30409 Mdot
.03714 .27277 Mdot
.03905 .24788 Mdot
.04095 .24042 Mdot
.04286 .28318 Mdot
.04476 .25453 Mdot
.04667 .29995 Mdot
.04857 .41365 Mdot
.05048 .27406 Mdot
.05238 .34899 Mdot
.05429 .33241 Mdot
.05619 .2659 Mdot
.0581 .41396 Mdot
.06 .29144 Mdot
.0619 .3768 Mdot
.06381 .40685 Mdot
.06571 .40685 Mdot
.06762 .40328 Mdot
.06952 .41233 Mdot
.07143 .37471 Mdot
.07333 .37017 Mdot
.07524 .265 Mdot
.07714 .30103 Mdot
.07905 .35945 Mdot
.08095 .40207 Mdot
.08286 .39219 Mdot
.08476 .23152 Mdot
.08667 .25827 Mdot
.08857 .24421 Mdot
.09048 .24409 Mdot
.09238 .35255 Mdot
.09429 .25913 Mdot
.09619 .28941 Mdot
.0981 .31466 Mdot
.1 .29139 Mdot
.1019 .35282 Mdot
.10381 .2433 Mdot
.10571 .2742 Mdot
.10762 .36775 Mdot
.10952 .35142 Mdot
.11143 .3638 Mdot
.11333 .25957 Mdot
.11524 .23189 Mdot
.11714 .35318 Mdot
.11905 .33833 Mdot
.12095 .23034 Mdot
.12286 .31598 Mdot
.12476 .47278 Mdot
.12667 .26547 Mdot
.12857 .25077 Mdot
.13048 .25144 Mdot
.13238 .25922 Mdot
.13429 .27795 Mdot
.13619 .24269 Mdot
.1381 .34534 Mdot
.14 .3664 Mdot
.1419 .42709 Mdot
.14381 .29885 Mdot
.14571 .28833 Mdot
.14762 .29514 Mdot
.14952 .23503 Mdot
.15143 .28053 Mdot
.15333 .32649 Mdot
.15524 .27729 Mdot
.15714 .40838 Mdot
.15905 .29383 Mdot
.16095 .29519 Mdot
.16286 .26959 Mdot
.16476 .30015 Mdot
.16667 .29862 Mdot
.16857 .31431 Mdot
.17048 .47261 Mdot
.17238 .3623 Mdot
.17429 .32846 Mdot
.17619 .32697 Mdot
.1781 .37707 Mdot
.18 .40185 Mdot
.1819 .33951 Mdot
.18381 .24292 Mdot
.18571 .23861 Mdot
.18762 .34046 Mdot
.18952 .3501 Mdot
.19143 .36177 Mdot
.19333 .3006 Mdot
.19524 .32309 Mdot
.19714 .38176 Mdot
.19905 .4739 Mdot
.20095 .30961 Mdot
.20286 .36102 Mdot
.20476 .30709 Mdot
.20667 .47229 Mdot
.20857 .2754 Mdot
.21048 .22971 Mdot
.21238 .47251 Mdot
.21429 .31399 Mdot
.21619 .38241 Mdot
.2181 .32413 Mdot
.22 .31501 Mdot
.2219 .37756 Mdot
.22381 .39754 Mdot
.22571 .24465 Mdot
.22762 .27305 Mdot
.22952 .30102 Mdot
.23143 .30968 Mdot
.23333 .40512 Mdot
.23524 .28304 Mdot
.23714 .34105 Mdot
.23905 .23243 Mdot
.24095 .37637 Mdot
.24286 .44572 Mdot
.24476 .31967 Mdot
.24667 .3669 Mdot
.24857 .22837 Mdot
.25048 .2284 Mdot
.25238 .24373 Mdot
.25429 .41269 Mdot
.25619 .40904 Mdot
.2581 .39885 Mdot
.26 .36335 Mdot
.2619 .40679 Mdot
.26381 .33807 Mdot
.26571 .36478 Mdot
.26762 .46789 Mdot
.26952 .39753 Mdot
.27143 .2791 Mdot
.27333 .40683 Mdot
.27524 .39032 Mdot
.27714 .3236 Mdot
.27905 .29537 Mdot
.28095 .28544 Mdot
.28286 .34949 Mdot
.28476 .29692 Mdot
.28667 .35834 Mdot
.28857 .26918 Mdot
.29048 .28371 Mdot
.29238 .34471 Mdot
.29429 .45203 Mdot
.29619 .33136 Mdot
.2981 .27941 Mdot
.3 .26787 Mdot
.3019 .37874 Mdot
.30381 .23349 Mdot
.30571 .42968 Mdot
.30762 .3344 Mdot
.30952 .36303 Mdot
.31143 .38424 Mdot
.31333 .33273 Mdot
.31524 .25787 Mdot
.31714 .41359 Mdot
.31905 .2886 Mdot
.32095 .34451 Mdot
.32286 .29068 Mdot
.32476 .3065 Mdot
.32667 .23274 Mdot
.32857 .25189 Mdot
.33048 .29239 Mdot
.33238 .36628 Mdot
.33429 .33711 Mdot
.33619 .31487 Mdot
.3381 .35767 Mdot
.34 .29337 Mdot
.3419 .38534 Mdot
.34381 .23415 Mdot
.34571 .39712 Mdot
.34762 .27564 Mdot
.34952 .31241 Mdot
.35143 .33455 Mdot
.35333 .33049 Mdot
.35524 .27595 Mdot
.35714 .35591 Mdot
.35905 .33337 Mdot
.36095 .27783 Mdot
.36286 .47108 Mdot
.36476 .34423 Mdot
.36667 .30872 Mdot
.36857 .34262 Mdot
.37048 .32658 Mdot
.37238 .31203 Mdot
.37429 .32241 Mdot
.37619 .35649 Mdot
.3781 .26497 Mdot
.38 .24559 Mdot
.3819 .46796 Mdot
.38381 .22757 Mdot
.38571 .31468 Mdot
.38762 .27351 Mdot
.38952 .39858 Mdot
.39143 .38078 Mdot
.39333 .28026 Mdot
.39524 .42763 Mdot
.39714 .24482 Mdot
.39905 .35867 Mdot
.40095 .31722 Mdot
.40286 .35983 Mdot
.40476 .47797 Mdot
.40667 .26498 Mdot
.40857 .31798 Mdot
.41048 .31691 Mdot
.41238 .30019 Mdot
.41429 .35225 Mdot
.41619 .47851 Mdot
.4181 .38895 Mdot
.42 .2687 Mdot
.4219 .31823 Mdot
.42381 .33929 Mdot
.42571 .26443 Mdot
.42762 .25509 Mdot
.42952 .41159 Mdot
.43143 .36385 Mdot
.43333 .39613 Mdot
.43524 .31783 Mdot
.43714 .38737 Mdot
.43905 .36344 Mdot
.44095 .32171 Mdot
.44286 .27018 Mdot
.44476 .35508 Mdot
.44667 .27586 Mdot
.44857 .36707 Mdot
.45048 .23132 Mdot
.45238 .40118 Mdot
.45429 .36654 Mdot
.45619 .31394 Mdot
.4581 .3393 Mdot
.46 .39115 Mdot
.4619 .32491 Mdot
.46381 .34868 Mdot
.46571 .40715 Mdot
.46762 .33899 Mdot
.46952 .28265 Mdot
.47143 .47562 Mdot
.47333 .32319 Mdot
.47524 .25685 Mdot
.47714 .40755 Mdot
.47905 .28037 Mdot
.48095 .38091 Mdot
.48286 .40586 Mdot
.48476 .38773 Mdot
.48667 .4297 Mdot
.48857 .28066 Mdot
.49048 .39524 Mdot
.49238 .29397 Mdot
.49429 .22813 Mdot
.49619 .3101 Mdot
.4981 .27239 Mdot
.5 .27783 Mdot
.5019 .29665 Mdot
.50381 .30557 Mdot
.50571 .36001 Mdot
.50762 .3194 Mdot
.50952 .28961 Mdot
.51143 .25816 Mdot
.51333 .36509 Mdot
.51524 .27551 Mdot
.51714 .24598 Mdot
.51905 .3139 Mdot
.52095 .26624 Mdot
.52286 .2369 Mdot
.52476 .34141 Mdot
.52667 .25647 Mdot
.52857 .36487 Mdot
.53048 .29491 Mdot
.53238 .32533 Mdot
.53429 .37236 Mdot
.53619 .25546 Mdot
.5381 .31739 Mdot
.54 .34154 Mdot
.5419 .35564 Mdot
.54381 .36251 Mdot
.54571 .25068 Mdot
.54762 .29265 Mdot
.54952 .33455 Mdot
.55143 .29887 Mdot
.55333 .32442 Mdot
.55524 .31727 Mdot
.55714 .22864 Mdot
.55905 .25977 Mdot
.56095 .33297 Mdot
.56286 .34055 Mdot
.56476 .29482 Mdot
.56667 .29779 Mdot
.56857 .24809 Mdot
.57048 .30193 Mdot
.57238 .30087 Mdot
.57429 .2805 Mdot
.57619 .35114 Mdot
.5781 .38968 Mdot
.58 .36394 Mdot
.5819 .3785 Mdot
.58381 .46812 Mdot
.58571 .23825 Mdot
.58762 .33177 Mdot
.58952 .23177 Mdot
.59143 .27272 Mdot
.59333 .25992 Mdot
.59524 .42782 Mdot
.59714 .39661 Mdot
.59905 .34421 Mdot
.60095 .42075 Mdot
.60286 .3457 Mdot
.60476 .25465 Mdot
.60667 .38988 Mdot
.60857 .22934 Mdot
.61048 .36015 Mdot
.61238 .2591 Mdot
.61429 .22856 Mdot
.61619 .3649 Mdot
.6181 .32322 Mdot
.62 .41078 Mdot
.6219 .26392 Mdot
.62381 .41127 Mdot
.62571 .38093 Mdot
.62762 .31188 Mdot
.62952 .36216 Mdot
.63143 .24409 Mdot
.63333 .30291 Mdot
.63524 .30137 Mdot
.63714 .31999 Mdot
.63905 .40881 Mdot
.64095 .4529 Mdot
.64286 .33655 Mdot
.64476 .28814 Mdot
.64667 .24282 Mdot
.64857 .28831 Mdot
.65048 .33371 Mdot
.65238 .32556 Mdot
.65429 .26976 Mdot
.65619 .27504 Mdot
.6581 .26398 Mdot
.66 .25215 Mdot
.6619 .30183 Mdot
.66381 .40954 Mdot
.66571 .28043 Mdot
.66762 .30231 Mdot
.66952 .39285 Mdot
.67143 .29446 Mdot
.67333 .29312 Mdot
.67524 .36543 Mdot
.67714 .35125 Mdot
.67905 .47758 Mdot
.68095 .3596 Mdot
.68286 .40066 Mdot
.68476 .29595 Mdot
.68667 .25953 Mdot
.68857 .26348 Mdot
.69048 .35819 Mdot
.69238 .40379 Mdot
.69429 .31995 Mdot
.69619 .36338 Mdot
.6981 .45073 Mdot
.7 .28977 Mdot
.7019 .27132 Mdot
.70381 .35308 Mdot
.70571 .35477 Mdot
.70762 .2573 Mdot
.70952 .34254 Mdot
.71143 .32532 Mdot
.71333 .2919 Mdot
.71524 .45067 Mdot
.71714 .39431 Mdot
.71905 .32516 Mdot
.72095 .32435 Mdot
.72286 .34066 Mdot
.72476 .31179 Mdot
.72667 .32954 Mdot
.72857 .34923 Mdot
.73048 .26111 Mdot
.73238 .31385 Mdot
.73429 .38722 Mdot
.73619 .35118 Mdot
.7381 .31066 Mdot
.74 .38029 Mdot
.7419 .23156 Mdot
.74381 .38134 Mdot
.74571 .2553 Mdot
.74762 .26185 Mdot
.74952 .40302 Mdot
.75143 .28411 Mdot
.75333 .40591 Mdot
.75524 .36452 Mdot
.75714 .44326 Mdot
.75905 .23662 Mdot
.76095 .34026 Mdot
.76286 .29344 Mdot
.76476 .39353 Mdot
.76667 .31177 Mdot
.76857 .26991 Mdot
.77048 .30848 Mdot
.77238 .40791 Mdot
.77429 .32662 Mdot
.77619 .29244 Mdot
.7781 .36856 Mdot
.78 .26021 Mdot
.7819 .23133 Mdot
.78381 .40804 Mdot
.78571 .4291 Mdot
.78762 .31445 Mdot
.78952 .25096 Mdot
.79143 .47426 Mdot
.79333 .25261 Mdot
.79524 .32923 Mdot
.79714 .3291 Mdot
.79905 .30277 Mdot
.80095 .26694 Mdot
.80286 .29958 Mdot
.80476 .26334 Mdot
.80667 .326 Mdot
.80857 .25418 Mdot
.81048 .33535 Mdot
.81238 .37514 Mdot
.81429 .35747 Mdot
.81619 .36589 Mdot
.8181 .33703 Mdot
.82 .26117 Mdot
.8219 .29276 Mdot
.82381 .35478 Mdot
.82571 .24429 Mdot
.82762 .25489 Mdot
.82952 .27095 Mdot
.83143 .39784 Mdot
.83333 .27945 Mdot
.83524 .27905 Mdot
.83714 .24505 Mdot
.83905 .27217 Mdot
.84095 .36137 Mdot
.84286 .34778 Mdot
.84476 .27309 Mdot
.84667 .38887 Mdot
.84857 .47453 Mdot
.85048 .3877 Mdot
.85238 .4555 Mdot
.85429 .36896 Mdot
.85619 .27016 Mdot
.8581 .25821 Mdot
.86 .3549 Mdot
.8619 .25474 Mdot
.86381 .40308 Mdot
.86571 .4762 Mdot
.86762 .32942 Mdot
.86952 .32622 Mdot
.87143 .34039 Mdot
.87333 .37096 Mdot
.87524 .33846 Mdot
.87714 .47616 Mdot
.87905 .2639 Mdot
.88095 .25933 Mdot
.88286 .24376 Mdot
.88476 .29308 Mdot
.88667 .30684 Mdot
.88857 .3157 Mdot
.89048 .25051 Mdot
.89238 .31226 Mdot
.89429 .33899 Mdot
.89619 .39393 Mdot
.8981 .35855 Mdot
.9 .36509 Mdot
.9019 .38096 Mdot
.90381 .25889 Mdot
.90571 .46585 Mdot
.90762 .29099 Mdot
.90952 .26509 Mdot
.91143 .35493 Mdot
.91333 .25512 Mdot
.91524 .26479 Mdot
.91714 .35144 Mdot
.91905 .26198 Mdot
.92095 .36129 Mdot
.92286 .38089 Mdot
.92476 .30114 Mdot
.92667 .36376 Mdot
.92857 .24417 Mdot
.93048 .41704 Mdot
.93238 .29754 Mdot
.93429 .3145 Mdot
.93619 .27912 Mdot
.9381 .33085 Mdot
.94 .30582 Mdot
.9419 .33023 Mdot
.94381 .2608 Mdot
.94571 .27234 Mdot
.94762 .3191 Mdot
.94952 .3643 Mdot
.95143 .23601 Mdot
.95333 .34334 Mdot
.95524 .36932 Mdot
.95714 .26531 Mdot
.95905 .3151 Mdot
.96095 .32006 Mdot
.96286 .45357 Mdot
.96476 .32244 Mdot
.96667 .39583 Mdot
.96857 .22969 Mdot
.97048 .36 Mdot
.97238 .28108 Mdot
.97429 .35224 Mdot
.97619 .30773 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`1`ooooo`;o0000b_ooool000Co00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01cooooo0_l0
000Jooooo`;o00002oooool2o`0002Wooooo0_l0000Rooooo`;o00004_ooool2o`0000kooooo1?l0
001`ooooo`;o00003_ooool000Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ
8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`00013ooooo0_l00008ooooo`Co00006_oo
ool2o`0000Oooooo0_l00002ooooo`;o00003oooool2o`0000Kooooo0_l00003ooooo`;o00008?oo
ool2o`0000gooooo0_l0000Booooo`;o00002?ooool2o`0000Cooooo1?l0000Wooooo`;o00002ooo
ool2o`0003[ooooo0_l0000>ooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
4?ooool2o`0000Sooooo0_l00009ooooo`;o00006_ooool2o`0001?ooooo0_l00006ooooo`;o0000
0oooool2o`00023ooooo0_l0000Fooooo`;o00004oooool2o`0002oooooo0_l00004ooooo`;o0000
1Oooool2o`0003Gooooo0_l0000Cooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Gooooo
0_l00009ooooo`;o0000Joooool2o`0001;ooooo0_l0000fooooo`;o0000??ooool2o`0001?ooooo
0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`;o00004_ooool2o`0000So
oooo0_l0000>ooooo`;o0000Ooooool2o`0001;ooooo0_l0001eooooo`001_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0
003oooooooooo`02ooooo`;o00003Oooool3o`0000;ooooo0_l00008ooooo`;o00003_ooool2o`00
00_ooooo0_l00007ooooo`;o00009oooool2o`0000?ooooo0_l0000Uooooo`;o00008oooool2o`00
00?ooooo0_l0000gooooo`;o00000_ooool2o`0000cooooo0_l0000=ooooo`;o00006oooool002Wo
oooo0_l00002ooooo`;o00003_ooool3o`0002Wooooo0_l00007ooooo`;o00009oooool2o`0000?o
oooo0_l0000Uooooo`;o00003_ooool2o`0001?ooooo0_l0000looooo`;o00000_ooool2o`0000co
oooo0_l0000=ooooo`;o00006oooool002Wooooo00Co0000oooooooooooooooo0_l0000Kooooo`?o
0000?Oooool2o`0004Cooooo0_l00005ooooo`;o00007?ooool2o`0002Oooooo1?l0000Mooooo`;o
00009oooool002Wooooo00?o0000ooooooooool00oooool2o`0001Wooooo0ol0000mooooo`;o0000
7_ooool2o`00027ooooo0_l000000ooooooo0000o`00000Aooooo`;o00004?ooool2o`0001Wooooo
0_l0000<ooooo`Co00000oooool2o`0000Cooooo0_l00009ooooo`;o00001oooool2o`0000Gooooo
0_l0000Pooooo`00:Oooool00ol0003oooooooooo`03ooooo`;o00002oooool2o`0004Sooooo0_l0
000Rooooo`;o00003Oooool2o`0000[ooooo0_l00003ooooo`;o000000?oooooo`000?l000005?oo
ool2o`0001oooooo0_l0000:ooooo`;o00004oooool2o`0000Cooooo0_l00008ooooo`?o00002ooo
ool2o`000003ooooool0003o0000023ooooo000Yooooo`03o`000?oooooooooo013ooooo0_l00000
0ooooooo0000o`000004ooooo`;o00001?ooool2o`0003Wooooo0_l0000aooooo`;o00002_ooool2
o`0000?ooooo0_l00008ooooo`;o00002Oooool2o`0000Gooooo0_l0000Eooooo`;o00001Oooool2
o`0000Gooooo0_l00004ooooo`;o00002?ooool2o`0000_ooooo0_l0000;ooooo`;o00001Oooool2
o`0000Gooooo0_l00003ooooo`;o00001_ooool2o`0001Kooooo000Yooooo`;o00003_ooool2o`00
00Cooooo0_l00004ooooo`;o00001?ooool2o`0004gooooo0_l00007ooooo`;o00001?ooool2o`00
02Wooooo0_l00009ooooo`;o00001Oooool2o`000003ooooool0003o000000Wooooo0_l00007oooo
o`?o00002oooool2o`0000Cooooo0_l00008ooooo`;o00001_ooool2o`0000?ooooo0_l0000Aoooo
o`?o00001oooool5o`0000Kooooo0_l0000Fooooo`00:Oooool00ol0003oooooooooo`07ooooo`;o
00001?ooool2o`0000kooooo0_l0000fooooo`;o00005oooool2o`0000Oooooo0_l00004ooooo`;o
00007Oooool2o`0001oooooo0_l00009ooooo`;o00002?ooool2o`0002;ooooo0ol0000Fooooo`;o
00002?ooool4o`0000_ooooo0_l0000Booooo`00:Oooool00ol0003oooooooooo`07ooooo`;o0000
5?ooool2o`0000[ooooo0_l00005ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`;o00000_ooool2o`0001Kooooo1Ol0
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool2o`000005oc8b<_l0003o<S8bonk^k_oo
ool00_l0000Gooooo`;o00003?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool2o`0000gooooo0_l0
000Aooooo`;o000000Wo410@o`000?l0003oooooonk^k_lb<S;o0000oc8b<_o^k^h00_ooool2o`00
0004oc8b<_l0003o<S8bonk^kP?ooooo0_l00007ooooo`;o00006oooool00om4A4Co0000o`000002
o`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool002Wooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00004?ooool2o`00013ooooo
0_l00007ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`;o
000000CoV9RHoooooonHV9SoMgMg3Oooool2o`0001[ooooo00CoV9RHob4Q8Oo^k^kooooo0_l00002
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool2o`000005oiRHV?ooooooV9RHogMgMoooool0
0_l0000@ooooo`;o00004oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgo`000?l0
003oV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool2o`0000gooooo0_l0000B
ooooo`0:o`000?oooooo0000o`000?ooooooMgMgoiRHV?ooooooV9RHogMgM`?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00006oooool2
o`000003oooooomgMgOo<S8b00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool002Wooooo00Co0000oooooooooooooooo0_l00002ooooo`;o0000
4?ooool2o`0000kooooo0_l00009ooooo`03o`000?oooooooooo00;ooooo00Go410@o`000?l0003o
oooooa0@4002ooooo`;o00000oooool00ol@413oooooooooo`0Nooooo`;o000000?oooooo`000?l0
00001Oooool00onHV9So8B4Qonk^kP02o`0000;ooooo00Go410@oooooooooooooooooa0@4003oooo
o`05oa0@4?ooooooooooooooool@41000_ooool2o`0000oooooo0_l00003ooooo`;o00004_ooool0
1Ol0003ooooooooooooooooo410@00;o000000?ooooooa0@4?ooool00_ooool01Ol@413ooooooooo
oooooooo410@00Wooooo0_l0000Mooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@4006ooooo`Co00007oooool2o`0000;ooooo00Co0000oooo
oooooooo410@0oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool00Ooo
ool002Wooooo0_l0000Qooooo`;o00000oooool4o`0000Wooooo00?o0000ooooooooool00_ooool3
o`000003ooooool0003ooooo00;ooooo00Go0000ooooooooooooooooo`000008ooooo`;o00001_oo
ool2o`0000kooooo0_l000000ooooooo0000o`000002o`0000Cooooo00CoV9RHob4Q8Oo^k^kooooo
0ol00003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02o`0000Wo
oooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l0000Aooooo`;o00000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000009ooooo`;o000000?o
ooooo`000?l000006_ooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000Gooooo0_l0000Oooooo`;o00001?ooool01Omg
MgOo<S8boooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo007ooooo000Yooooo`03o`000?oooooooooo00;ooooo0_l0000Looooo`;o00000oooool2
o`0000_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo0ol0
00000ooooooo0000ooooo`07ooooo`;o00001?ooool4o`0001?ooooo0_l00005ooooo`03ogMgMomV
IVKooooo00?o00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
2?ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000005Oooool00ol@413o
0000o`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000cooooo0_l0000Jooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000001Oooool2o`0001oooooo0_l000001_oooooo
0000ob4Q8Ol0003o<S8bolc<c0;ooooo0ol000000ooooooo0000ooooo`02ooooo`05o`000?oooooo
ooooooooool000000oooool002Wooooo00?o0000ooooooooool00_ooool2o`0002kooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@o`000?l0003ooooo
oa0@400;ooooo`;o000000?oooooo`000?l000007Oooool01Ol0003ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Sooooo0_l0000Ooooo
o`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo
ooooooooool@41009oooool2o`000003ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooo
oa0@4003ooooo`05oa0@4?ooooooooooooooool@4100:Oooool00ol0003oooooooooo`04ooooo`05
oa0@4?l0003o0000ooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo000Yoooo
o`03o`000?oooooooooo01Cooooo0_l0000=ooooo`;o00003Oooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo0_l0
000:ooooo`;o00004?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05_ooool2o`00013ooooo00Go410@oiRH
V?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0ol0000?ooooo`;o00003_ooool2o`000003onk^k_m4A4Co000000Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:Oooool00ol0
003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo000Yooooo`03o`000?oooooooooo00Sooooo0_l0000:ooooo`?o00003?ooool2
o`0000_ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0Gooooo`?o000000?oooooo`000?l000003?ooool01OnHV9So410@
o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h05_ooool2o`0000_ooooo0_l00003ooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`?o
00001_ooool2o`0000Oooooo0_l00002ooooo`;o00003Oooool00omgMgOo0000ooooo`02ooooo`;o
000000Co<S8bo`000?lb<S;ok^k^0oooool01_o^k^ko<S8bo`000?lb<S;ok^k^ooooo`;o00004_oo
ool2o`0000Gooooo0_l0000;ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool2o`0000Wooooo0_l0000;ooooo`;o0000
3Oooool2o`0000;ooooo0_l0000Tooooo`;o00003?ooool2o`000004ooooool0003o0000ooooo`;o
0000;oooool2o`0000[ooooo0_l00004ooooo`;o00000oooool2o`00027ooooo0_l00002ooooo`;o
00001oooool2o`0000kooooo0_l00002ooooo`;o00003Oooool2o`0001;ooooo0_l00005ooooo`;o
00008_ooool002Wooooo0ol0000Sooooo`?o00000_ooool4o`0002;ooooo1?l0000@ooooo`;o0000
;oooool2o`000003ooooool0003o000000Oooooo0_l00005ooooo`;o00000_ooool3o`00023ooooo
0_l00002ooooo`;o00005oooool2o`0003Cooooo0_l0000Jooooo`00:Oooool3o`0000Cooooo0_l0
0007ooooo`;o00005?ooool2o`0000Gooooo0_l00007ooooo`;o00002Oooool2o`00013ooooo0_l0
000Wooooo`;o00006oooool2o`0000kooooo0_l00003ooooo`Co00004_ooool2o`0000Kooooo1?l0
000Zooooo`;o00009Oooool4o`0001[ooooo000Yooooo`03o`000?oooooooooo00;o00000_ooool2
o`0000Oooooo0_l0000Kooooo`;o00001oooool2o`0000Wooooo0_l0000iooooo`;o00007?ooool2
o`0001?ooooo0ol0000Aooooo`?o00001_ooool4o`0002Wooooo0ol0000Uooooo`;o00007?ooool0
02Wooooo00?o0000ooooooooool00_l0000dooooo`;o00009Oooool2o`0000cooooo0_l0000Zoooo
o`;o00009oooool2o`0002[ooooo0_l00008ooooo`;o00006_ooool2o`0000oooooo0_l0000:oooo
o`;o00002oooool0027oooooool00014o`0000Cooooo000Yooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02?ooool3o`0000_ooooo00?o0000ooooooooool01_ooool2o`000003oooo
ool0003ooooo00Gooooo0_l00003ooooo`?o00000_ooool2o`0000Kooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`04o`000?oooooo0000o`0000;ooooo0_l00004ooooo`?o
00000oooool2o`0000Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02o`0000Oo
oooo00Co0000oooooooooooooooo0_l00006ooooo`;o00002oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Kooooo0_l000000ooooooo0000ooooo`0:ooooo`03o`000?oooooooooo
00[ooooo00Co0000oooooooooooooooo1_l00002ooooo`03o`000?oooooooooo00;ooooo0_l00005
ooooo`;o00002_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo0_l00000
0ooooooo0000ooooo`08ooooo`?o00002oooool00ol0003oooooooooo`0:ooooo`00:Oooool00ol0
003oooooooooo`0Dooooo`;o00001_ooool2o`0000gooooo0_l0000=ooooo`?o00009?ooool2o`00
00;ooooo0_l00005ooooo`;o00000oooool2o`0000?ooooo1Ol00006ooooo`;o00001?ooool2o`00
01?ooooo0_l00004ooooo`;o00000oooool2o`0000cooooo00?o0000ooooooooool0:?ooool2o`00
013ooooo0_l0000Nooooo`Co00002oooool2o`0000Kooooo0_l00004ooooo`03o`000?oooooooooo
00[ooooo000Yooooo`03o`000?oooooooooo01cooooo0_l0000Uooooo`;o0000<Oooool5o`000003
ooooool0003o000000?ooooo0_l0000Eooooo`;o00002?ooool2o`0000?ooooo0_l0000Hooooo`;o
00004Oooool2o`0003cooooo0_l0000Aooooo`;o00000_ooool3o`00013ooooo000Yooooo`03o`00
0?oooooooooo03?ooooo0_l00006ooooo`;o00001_ooool2o`0000Wooooo0_l0000Mooooo`;o0000
3Oooool2o`0000Cooooo0_l00009ooooo`;o00002Oooool2o`00027ooooo0_l00004ooooo`;o0000
4Oooool2o`0000Kooooo0_l00017ooooo`;o00000oooool3o`0000oooooo000Yooooo`;o00009ooo
ool2o`0000Gooooo0_l00004ooooo`;o00001_ooool2o`00017ooooo0_l0000Looooo`?o00004ooo
ool2o`0000Gooooo0_l00002ooooo`;o00004Oooool2o`0000Gooooo0_l0000Booooo`;o00002Ooo
ool2o`00017ooooo0_l000000ooooooo0000o`00000@ooooo`;o00002?ooool2o`0001;ooooo0_l0
000Mooooo`;o00003oooool002Wooooo00?o0000ooooooooool09_ooool2o`0000Gooooo0_l0000g
ooooo`;o00001?ooool2o`0001_ooooo0_l0000Eooooo`;o00001Oooool2o`0001gooooo0_l0000A
ooooo`;o000000?oooooo`000?l000000_l0000>ooooo`;o00001?ooool3o`000003ooooool0003o
000001;ooooo0_l0000Eooooo`;o00005oooool002Wooooo00?o0000ooooooooool01_ooool2o`00
02Gooooo0_l0000Uooooo`;o00000oooool2o`0000_ooooo1?l0000oooooo`;o00001oooool2o`00
02[ooooo0_l0000Dooooo`?o00005Oooool2o`0001Cooooo0ol0000Gooooo`00:Oooool00ol0003o
ooooooooo`06ooooo`;o0000C?ooool2o`0000;ooooo0ol0000;ooooo`Co0000>oooool2o`0000;o
oooo0_l00007ooooo`;o00003oooool2o`000003ooooool0003o0000037ooooo0_l0000Wooooo`;o
00006?ooool002Wooooo00?o0000ooooooooool06oooool2o`0001;ooooo0_l0000Hooooo`;o0000
3Oooool2o`0000Kooooo0_l00004ooooo`;o00005Oooool2o`0000Wooooo0_l000000ooooooo0000
o`00000Hooooo`;o00007?ooool2o`000003ooooool0003o0000037ooooo0_l000000ooooooo0000
o`00000@ooooo`;o00001?ooool2o`0002Kooooo000Yooooo`Co00006_ooool2o`0001;ooooo1?l0
000>ooooo`;o00001_ooool2o`0001Gooooo0_l00009ooooo`;o00004?ooool2o`0000Wooooo0_l0
00000ooooooo0000o`00000@ooooo`;o00000oooool2o`0000Kooooo0_l0000]ooooo`;o00000_oo
ool2o`0000[ooooo0_l0000Aooooo`;o00003oooool3o`0000Cooooo0_l0000Vooooo`00:Oooool0
1?l0003oooooo`000?l0000Pooooo`;o00003_ooool2o`0000kooooo0_l0000@ooooo`;o00001ooo
ool2o`0000cooooo0ol0000`ooooo`;o00000oooool2o`0000Kooooo0_l00009ooooo`?o00008Ooo
ool2o`0000;ooooo0_l0000:ooooo`;o00008_ooool2o`0001Sooooo0_l0000Cooooo`00:Oooool0
1?l0003oooooo`000?l00004ooooo`;o00006_ooool2o`00033ooooo0_l00007ooooo`;o00003?oo
ool2o`0001kooooo0_l0000Yooooo`?o00009oooool2o`0002?ooooo0_l0000Qooooo`;o00004ooo
ool002Wooooo00Co0000ooooool0003o00001?ooool2o`00017ooooo0_l0000Hooooo`;o00007?oo
ool2o`0002Sooooo0_l0000>ooooo`;o00008_ooool2o`0001kooooo0_l0000?ooooo`Co00008Ooo
ool2o`0001Kooooo0_l0000@ooooo`;o00003?ooool002Wooooo00?o0000ooooooooool04_ooool2
o`000004ooooool0003o0000ooooo`Co00005_ooool2o`0001cooooo0_l0000Xooooo`;o00002?oo
ool2o`0002Sooooo0_l0000Nooooo`;o00001oooool3o`0000Oooooo0_l0000Kooooo`;o00002Ooo
ool2o`0000oooooo1?l0000@ooooo`;o00003?ooool002Wooooo0_l0000Cooooo`;o000000?ooooo
o`000?l000000oooool2o`0003Gooooo0_l0000>ooooo`;o00001?ooool2o`0000Gooooo0_l0000D
ooooo`;o00007Oooool2o`0002kooooo0_l00002ooooo`?o00008?ooool2o`0000;ooooo0_l00009
ooooo`;o00002_ooool2o`0000?ooooo0_l0000Pooooo`00:Oooool00ol0003oooooooooo`0>oooo
o`;o00009_ooool2o`0001Wooooo0_l0000>ooooo`;o00001?ooool2o`0000Gooooo0_l00005oooo
o`?o00007oooool2o`0000[ooooo0_l0000Dooooo`;o00005Oooool2o`000003ooooool0003o0000
02Gooooo0_l00007ooooo`;o00004?ooool2o`0000Kooooo0_l0000>ooooo`;o00003Oooool002Wo
oooo00?o0000ooooooooool03_ooool2o`0000Sooooo0_l0000Booooo`;o00001?ooool2o`0000;o
oooo0_l0000@ooooo`Co00003?ooool2o`0001_ooooo0ol00007ooooo`;o000000?oooooo`000?l0
00004oooool2o`0000[ooooo0_l0000:ooooo`;o00002?ooool2o`0000Cooooo0_l0000?ooooo`;o
00000_ooool2o`00017ooooo0_l0000Jooooo`;o00006?ooool4o`0000Gooooo0_l00005ooooo`;o
00003Oooool002Wooooo00?o0000ooooooooool05oooool3o`0000Sooooo0_l00008ooooo`;o0000
1?ooool2o`00013ooooo0_l00002ooooo`Co00003?ooool2o`0000Gooooo0_l0000Nooooo`;o0000
00Coooooo`000?l0003ooooo1?l0000Aooooo`;o00000oooool2o`0000;ooooo0_l0000:ooooo`;o
00002_ooool2o`0000;ooooo0_l0000=ooooo`;o00001?ooool2o`00017ooooo0_l0000Booooo`;o
00006Oooool2o`0000Oooooo0_l00005ooooo`;o00005?ooool002Wooooo00?o0000ooooooooool0
3?ooool2o`0000Wooooo0_l00009ooooo`;o00008?ooool2o`0001Wooooo0_l0000Tooooo`Co0000
4Oooool2o`0000?ooooo0_l0000Jooooo`;o00004Oooool2o`0001oooooo0_l0000:ooooo`;o0000
2_ooool2o`0000Cooooo0_l00007ooooo`;o00004?ooool2o`0001;ooooo000Yooooo`;o00003Ooo
ool2o`0009;ooooo0_l0001=ooooo`;o00005_ooool2o`0000Cooooo0_l0000Iooooo`;o00004_oo
ool002Wooooo0_l0000:ooooo`;o000000?oooooo`000?l000008?ooool2o`0001;ooooo0_l0001L
ooooo`;o0000F?ooool2o`00043ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooooooo
o`09ooooo`;o000000?oooooo`000?l000008?ooool2o`0000cooooo0_l00004ooooo`;o00004_oo
ool2o`0005Sooooo0_l0000aooooo`;o00005Oooool2o`00043ooooo0006ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0=?ooool2o`0000Cooooo1?l0000Hooooo`;o0000
6_ooool2o`0001_ooooo0_l0000Oooooo`;o00003?ooool2o`0002?ooooo0ol0000aooooo`;o0000
1?ooool2o`0001gooooo0006ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Q
onk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0=?ooool2o`0000Cooooo
0_l0000Mooooo`;o00002?ooool2o`0000gooooo0_l0000Kooooo`;o0000;Oooool2o`0002Cooooo
0_l0000aooooo`;o00001?ooool2o`0001gooooo0006ooooo`05o`000?ooooooooooooooool00000
3Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0001Iooooo`;o0000
2?ooool2o`0001Kooooo0_l00004ooooo`;o00003Oooool2o`0001cooooo0_l0000aooooo`;o0000
8_ooool3o`0003Cooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIV
ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0?ooooo`;o
0000??ooool2o`0002cooooo0_l00004ooooo`;o00001_ooool2o`0000Gooooo0_l0000Looooo`;o
00002?ooool2o`0002Oooooo0_l0000Rooooo`?o0000=?ooool000Kooooo00Go410@oooooooooooo
oooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0?ooooo`;o0000??ooool2o`0003[ooooo0_l00007ooooo`;o00009?ooool2o`0001;o
oooo0_l0000=ooooo`;o00003_ooool2o`0002Sooooo0_l0000Dooooo`;o00003oooool000Kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`;o0000?_ooool2o`0000Wooooo0_l000000ooooooo0000o`00000Goooo
o`;o00003?ooool2o`0000cooooo0_l0000@ooooo`;o00008Oooool2o`0001Gooooo0_l0000=oooo
o`;o00003_ooool2o`0001?ooooo0_l0000Cooooo`;o00005?ooool2o`0000oooooo0006ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006
ooooo`;o00004?ooool2o`0001gooooo0_l0000=ooooo`;o00002Oooool2o`000003ooooool0003o
000001Oooooo0_l0000<ooooo`;o00003?ooool2o`0000Cooooo0_l0000]ooooo`;o00006Oooool2
o`0002kooooo0_l0000jooooo`00:Oooool2o`0000_ooooo0_l00003ooooo`;o00007Oooool2o`00
013ooooo0_l00014ooooo`;o0000B?ooool2o`000003ooooool0003o0000017ooooo0_l0000Roooo
o`;o0000<?ooool002Wooooo00?o0000ooooooooool02Oooool3o`0003Cooooo0_l00007ooooo`;o
00000_ooool2o`0003_ooooo0_l00002ooooo`Co0000@Oooool2o`00017ooooo0ol00004ooooo`;o
00000_ooool2o`0001Oooooo0_l0000`ooooo`00:Oooool00ol0003oooooooooo`09ooooo`?o0000
6oooool2o`0001kooooo1?l00002ooooo`;o0000>oooool2o`0000;ooooo1?l0000Zooooo`?o0000
0oooool2o`0000Kooooo0_l0000Kooooo`;o00001?ooool2o`0000;ooooo0_l00019ooooo`00:Ooo
ool00ol0003oooooooooo`04ooooo`;o000000?oooooo`000?l000000_ooool2o`0001[ooooo0_l0
000Mooooo`?o00004_ooool2o`0002;ooooo0_l0000kooooo`?o00000oooool2o`0000Kooooo0_l0
001`ooooo`00:Oooool00ol0003oooooooooo`04ooooo`;o000000?oooooo`000?l000000_ooool2
o`0003Wooooo0_l0000Cooooo`;o00008_ooool2o`0009oooooo0_l0000Jooooo`00:Oooool2o`00
0;Oooooo0_l0001Xooooo`;o00006_ooool002Wooooo00?o0000ooooooooool0]_ooool2o`0008Co
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool08_oo
ool2o`0003?ooooo0_l0000Kooooo`;o00006oooool2o`00027ooooo0_l0000kooooo`;o0000BOoo
ool002Wooooo00?o0000ooooooooool08_ooool2o`0003?ooooo0_l0000Kooooo`;o00006oooool2
o`00027ooooo0_l0000kooooo`;o0000BOooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3Xooooo`;o0000D_ooool002Wooooo00?o0000ooooooooool0@oooool2
o`000:?ooooo0_l0001Booooo`00:Oooool2o`0004Cooooo0_l0002@ooooo`;o00001?ooool2o`00
05oooooo000Yooooo`03o`000?oooooooooo05?ooooo0_l0001^ooooo`;o00004?ooool2o`0000Co
oooo0_l0001=ooooo`;o00004?ooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0Doooool2o`00
06kooooo0_l00012ooooo`;o00008Oooool2o`00013ooooo000>ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooo
o`Sooooo0_l0000cooooo`003_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooo
ooooool00oooool3o`000?oooooo?Oooool000kooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolIooooo`;o00008_ooool000ko
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`1;ooooo`;o00008_ooool2o`0003oooooo0_l0001Vooooo`;o00008_ooool0
00kooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool07Oooool2o`0000cooooo0_l0000:ooooo`Co00004?ooool2o`0001cooooo0_l00004
ooooo`;o0000?oooool2o`0008[ooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo01gooooo0_l0000<ooooo`;o00002?ooool6
o`0002kooooo0_l0000Qooooo`;o0000IOooool2o`00013ooooo0_l00004ooooo`;o00000_ooool2
o`0002_ooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0000f
ooooo`;o0000@?ooool2o`000003ooooool0003o0000013ooooo0_l00011ooooo`;o00008_ooool2
o`00013ooooo0_l00004ooooo`;o00000_ooool2o`0002_ooooo000Yooooo`03o`000?oooooooooo
07Oooooo0_l000000ooooooo0000o`00001Cooooo`;o0000Joooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@
00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolmoooo
o`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005
ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400>
ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3o
ooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooo
oooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`;o0000oooo
oolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooo
oolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool001oooooo1?l000000ol@413o
ooooooooo`03ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo0ol0
003oooooocgooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool001oooooo00?oEEEEofIVI_l00000oooooom7ooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .2995 Mdot
.02762 .34679 Mdot
.02952 .27476 Mdot
.03143 .3218 Mdot
.03333 .2859 Mdot
.03524 .24047 Mdot
.03714 .28642 Mdot
.03905 .25422 Mdot
.04095 .26799 Mdot
.04286 .33833 Mdot
.04476 .30728 Mdot
.04667 .22608 Mdot
.04857 .39361 Mdot
.05048 .33477 Mdot
.05238 .24107 Mdot
.05429 .34228 Mdot
.05619 .34334 Mdot
.0581 .39534 Mdot
.06 .25309 Mdot
.0619 .42233 Mdot
.06381 .405 Mdot
.06571 .38007 Mdot
.06762 .39542 Mdot
.06952 .4018 Mdot
.07143 .26556 Mdot
.07333 .35595 Mdot
.07524 .27302 Mdot
.07714 .25214 Mdot
.07905 .41643 Mdot
.08095 .36145 Mdot
.08286 .41088 Mdot
.08476 .28599 Mdot
.08667 .24555 Mdot
.08857 .30087 Mdot
.09048 .29186 Mdot
.09238 .4092 Mdot
.09429 .36159 Mdot
.09619 .25495 Mdot
.0981 .39453 Mdot
.1 .22715 Mdot
.1019 .24173 Mdot
.10381 .30061 Mdot
.10571 .25075 Mdot
.10762 .28551 Mdot
.10952 .26365 Mdot
.11143 .32129 Mdot
.11333 .31896 Mdot
.11524 .32833 Mdot
.11714 .37518 Mdot
.11905 .40585 Mdot
.12095 .32265 Mdot
.12286 .39706 Mdot
.12476 .48023 Mdot
.12667 .25782 Mdot
.12857 .27413 Mdot
.13048 .25297 Mdot
.13238 .24376 Mdot
.13429 .35225 Mdot
.13619 .34595 Mdot
.1381 .25723 Mdot
.14 .33409 Mdot
.1419 .3423 Mdot
.14381 .3856 Mdot
.14571 .26288 Mdot
.14762 .22861 Mdot
.14952 .27636 Mdot
.15143 .33652 Mdot
.15333 .3421 Mdot
.15524 .26023 Mdot
.15714 .40827 Mdot
.15905 .36253 Mdot
.16095 .26801 Mdot
.16286 .32943 Mdot
.16476 .34367 Mdot
.16667 .38545 Mdot
.16857 .29573 Mdot
.17048 .4803 Mdot
.17238 .35815 Mdot
.17429 .40324 Mdot
.17619 .36821 Mdot
.1781 .41355 Mdot
.18 .36328 Mdot
.1819 .31877 Mdot
.18381 .30314 Mdot
.18571 .26731 Mdot
.18762 .33937 Mdot
.18952 .28924 Mdot
.19143 .32473 Mdot
.19333 .36403 Mdot
.19524 .34264 Mdot
.19714 .27523 Mdot
.19905 .44714 Mdot
.20095 .26087 Mdot
.20286 .31513 Mdot
.20476 .26069 Mdot
.20667 .43466 Mdot
.20857 .33547 Mdot
.21048 .29704 Mdot
.21238 .48177 Mdot
.21429 .3704 Mdot
.21619 .31634 Mdot
.2181 .37288 Mdot
.22 .22627 Mdot
.2219 .30331 Mdot
.22381 .41518 Mdot
.22571 .29569 Mdot
.22762 .35047 Mdot
.22952 .25119 Mdot
.23143 .26084 Mdot
.23333 .40999 Mdot
.23524 .33929 Mdot
.23714 .31169 Mdot
.23905 .28378 Mdot
.24095 .4197 Mdot
.24286 .48891 Mdot
.24476 .32499 Mdot
.24667 .34638 Mdot
.24857 .29332 Mdot
.25048 .29518 Mdot
.25238 .34426 Mdot
.25429 .39558 Mdot
.25619 .31166 Mdot
.2581 .40466 Mdot
.26 .4185 Mdot
.2619 .40948 Mdot
.26381 .33056 Mdot
.26571 .41615 Mdot
.26762 .42268 Mdot
.26952 .35582 Mdot
.27143 .32323 Mdot
.27333 .38992 Mdot
.27524 .33402 Mdot
.27714 .22732 Mdot
.27905 .24095 Mdot
.28095 .24488 Mdot
.28286 .4134 Mdot
.28476 .38848 Mdot
.28667 .41486 Mdot
.28857 .32891 Mdot
.29048 .23095 Mdot
.29238 .23766 Mdot
.29429 .39248 Mdot
.29619 .28043 Mdot
.2981 .25846 Mdot
.3 .34503 Mdot
.3019 .42185 Mdot
.30381 .27719 Mdot
.30571 .48618 Mdot
.30762 .26896 Mdot
.30952 .3281 Mdot
.31143 .27259 Mdot
.31333 .37538 Mdot
.31524 .28197 Mdot
.31714 .40097 Mdot
.31905 .27001 Mdot
.32095 .25914 Mdot
.32286 .3837 Mdot
.32476 .39061 Mdot
.32667 .28033 Mdot
.32857 .35449 Mdot
.33048 .38499 Mdot
.33238 .36745 Mdot
.33429 .40791 Mdot
.33619 .2243 Mdot
.3381 .40975 Mdot
.34 .24343 Mdot
.3419 .32508 Mdot
.34381 .27614 Mdot
.34571 .41674 Mdot
.34762 .2615 Mdot
.34952 .39688 Mdot
.35143 .40269 Mdot
.35333 .28246 Mdot
.35524 .2619 Mdot
.35714 .30528 Mdot
.35905 .26678 Mdot
.36095 .23367 Mdot
.36286 .43182 Mdot
.36476 .2591 Mdot
.36667 .32705 Mdot
.36857 .40875 Mdot
.37048 .404 Mdot
.37238 .22498 Mdot
.37429 .34682 Mdot
.37619 .24463 Mdot
.3781 .30988 Mdot
.38 .26116 Mdot
.3819 .42553 Mdot
.38381 .30869 Mdot
.38571 .22447 Mdot
.38762 .25076 Mdot
.38952 .29546 Mdot
.39143 .42256 Mdot
.39333 .26765 Mdot
.39524 .34507 Mdot
.39714 .25831 Mdot
.39905 .24543 Mdot
.40095 .2263 Mdot
.40286 .31298 Mdot
.40476 .45279 Mdot
.40667 .34545 Mdot
.40857 .32192 Mdot
.41048 .32293 Mdot
.41238 .26756 Mdot
.41429 .29657 Mdot
.41619 .45893 Mdot
.4181 .33237 Mdot
.42 .28045 Mdot
.4219 .24216 Mdot
.42381 .29848 Mdot
.42571 .31116 Mdot
.42762 .31154 Mdot
.42952 .38163 Mdot
.43143 .35546 Mdot
.43333 .4168 Mdot
.43524 .34529 Mdot
.43714 .32991 Mdot
.43905 .35351 Mdot
.44095 .2254 Mdot
.44286 .31862 Mdot
.44476 .27024 Mdot
.44667 .23282 Mdot
.44857 .34302 Mdot
.45048 .3226 Mdot
.45238 .41582 Mdot
.45429 .41129 Mdot
.45619 .34352 Mdot
.4581 .27239 Mdot
.46 .32793 Mdot
.4619 .27262 Mdot
.46381 .24075 Mdot
.46571 .30748 Mdot
.46762 .33589 Mdot
.46952 .31578 Mdot
.47143 .46399 Mdot
.47333 .3702 Mdot
.47524 .28632 Mdot
.47714 .31005 Mdot
.47905 .25894 Mdot
.48095 .30931 Mdot
.48286 .40083 Mdot
.48476 .32783 Mdot
.48667 .34757 Mdot
.48857 .24624 Mdot
.49048 .41918 Mdot
.49238 .36257 Mdot
.49429 .29919 Mdot
.49619 .262 Mdot
.4981 .37077 Mdot
.5 .35031 Mdot
.5019 .36383 Mdot
.50381 .38968 Mdot
.50571 .24701 Mdot
.50762 .32484 Mdot
.50952 .26339 Mdot
.51143 .35953 Mdot
.51333 .36294 Mdot
.51524 .26238 Mdot
.51714 .28212 Mdot
.51905 .29929 Mdot
.52095 .23914 Mdot
.52286 .33816 Mdot
.52476 .37468 Mdot
.52667 .2873 Mdot
.52857 .4114 Mdot
.53048 .32812 Mdot
.53238 .37245 Mdot
.53429 .29791 Mdot
.53619 .30762 Mdot
.5381 .24307 Mdot
.54 .40501 Mdot
.5419 .36925 Mdot
.54381 .41423 Mdot
.54571 .27382 Mdot
.54762 .34272 Mdot
.54952 .37158 Mdot
.55143 .38867 Mdot
.55333 .34746 Mdot
.55524 .25321 Mdot
.55714 .31349 Mdot
.55905 .32183 Mdot
.56095 .24906 Mdot
.56286 .4084 Mdot
.56476 .32992 Mdot
.56667 .34192 Mdot
.56857 .35021 Mdot
.57048 .22623 Mdot
.57238 .25107 Mdot
.57429 .27548 Mdot
.57619 .2981 Mdot
.5781 .42228 Mdot
.58 .32864 Mdot
.5819 .41289 Mdot
.58381 .42745 Mdot
.58571 .33862 Mdot
.58762 .2311 Mdot
.58952 .32292 Mdot
.59143 .30915 Mdot
.59333 .36385 Mdot
.59524 .34741 Mdot
.59714 .42203 Mdot
.59905 .23777 Mdot
.60095 .48367 Mdot
.60286 .37317 Mdot
.60476 .26692 Mdot
.60667 .33158 Mdot
.60857 .29313 Mdot
.61048 .24884 Mdot
.61238 .31879 Mdot
.61429 .30723 Mdot
.61619 .36437 Mdot
.6181 .3131 Mdot
.62 .38532 Mdot
.6219 .34205 Mdot
.62381 .39596 Mdot
.62571 .26862 Mdot
.62762 .32796 Mdot
.62952 .28053 Mdot
.63143 .29784 Mdot
.63333 .22739 Mdot
.63524 .32953 Mdot
.63714 .22599 Mdot
.63905 .31539 Mdot
.64095 .38984 Mdot
.64286 .33572 Mdot
.64476 .24251 Mdot
.64667 .3082 Mdot
.64857 .37988 Mdot
.65048 .26467 Mdot
.65238 .31175 Mdot
.65429 .29806 Mdot
.65619 .35143 Mdot
.6581 .23985 Mdot
.66 .35334 Mdot
.6619 .25997 Mdot
.66381 .37966 Mdot
.66571 .3243 Mdot
.66762 .26777 Mdot
.66952 .33182 Mdot
.67143 .24153 Mdot
.67333 .24345 Mdot
.67524 .3679 Mdot
.67714 .2949 Mdot
.67905 .47584 Mdot
.68095 .36673 Mdot
.68286 .36382 Mdot
.68476 .26109 Mdot
.68667 .24514 Mdot
.68857 .27526 Mdot
.69048 .41438 Mdot
.69238 .37839 Mdot
.69429 .2659 Mdot
.69619 .34779 Mdot
.6981 .38911 Mdot
.7 .22798 Mdot
.7019 .37315 Mdot
.70381 .40992 Mdot
.70571 .37295 Mdot
.70762 .33758 Mdot
.70952 .40641 Mdot
.71143 .37172 Mdot
.71333 .2275 Mdot
.71524 .38244 Mdot
.71714 .41951 Mdot
.71905 .22786 Mdot
.72095 .22693 Mdot
.72286 .2328 Mdot
.72476 .27101 Mdot
.72667 .37158 Mdot
.72857 .24098 Mdot
.73048 .24252 Mdot
.73238 .27247 Mdot
.73429 .41337 Mdot
.73619 .36805 Mdot
.7381 .24037 Mdot
.74 .31207 Mdot
.7419 .28846 Mdot
.74381 .31051 Mdot
.74571 .35874 Mdot
.74762 .36164 Mdot
.74952 .39435 Mdot
.75143 .38175 Mdot
.75333 .38995 Mdot
.75524 .25399 Mdot
.75714 .48967 Mdot
.75905 .33311 Mdot
.76095 .25437 Mdot
.76286 .26899 Mdot
.76476 .29059 Mdot
.76667 .36889 Mdot
.76857 .30024 Mdot
.77048 .22466 Mdot
.77238 .40898 Mdot
.77429 .30723 Mdot
.77619 .34135 Mdot
.7781 .3533 Mdot
.78 .27925 Mdot
.7819 .32742 Mdot
.78381 .41597 Mdot
.78571 .34867 Mdot
.78762 .2251 Mdot
.78952 .32792 Mdot
.79143 .47468 Mdot
.79333 .3312 Mdot
.79524 .26239 Mdot
.79714 .26141 Mdot
.79905 .31581 Mdot
.80095 .23814 Mdot
.80286 .22619 Mdot
.80476 .27521 Mdot
.80667 .27311 Mdot
.80857 .31201 Mdot
.81048 .34393 Mdot
.81238 .2623 Mdot
.81429 .30402 Mdot
.81619 .41297 Mdot
.8181 .29587 Mdot
.82 .2764 Mdot
.8219 .32816 Mdot
.82381 .29878 Mdot
.82571 .30608 Mdot
.82762 .29034 Mdot
.82952 .27718 Mdot
.83143 .29302 Mdot
.83333 .2326 Mdot
.83524 .28772 Mdot
.83714 .28791 Mdot
.83905 .34984 Mdot
.84095 .28181 Mdot
.84286 .36902 Mdot
.84476 .26368 Mdot
.84667 .28276 Mdot
.84857 .4365 Mdot
.85048 .32431 Mdot
.85238 .48907 Mdot
.85429 .28682 Mdot
.85619 .27747 Mdot
.8581 .24778 Mdot
.86 .24561 Mdot
.8619 .29604 Mdot
.86381 .38177 Mdot
.86571 .47727 Mdot
.86762 .27837 Mdot
.86952 .30055 Mdot
.87143 .2763 Mdot
.87333 .41344 Mdot
.87524 .37034 Mdot
.87714 .4503 Mdot
.87905 .30809 Mdot
.88095 .26429 Mdot
.88286 .31301 Mdot
.88476 .26098 Mdot
.88667 .32805 Mdot
.88857 .34727 Mdot
.89048 .2515 Mdot
.89238 .32886 Mdot
.89429 .40838 Mdot
.89619 .33636 Mdot
.8981 .27388 Mdot
.9 .41576 Mdot
.9019 .41233 Mdot
.90381 .33774 Mdot
.90571 .41325 Mdot
.90762 .34102 Mdot
.90952 .23904 Mdot
.91143 .24234 Mdot
.91333 .30232 Mdot
.91524 .36803 Mdot
.91714 .3693 Mdot
.91905 .33906 Mdot
.92095 .41561 Mdot
.92286 .31255 Mdot
.92476 .2516 Mdot
.92667 .34733 Mdot
.92857 .30882 Mdot
.93048 .32316 Mdot
.93238 .24214 Mdot
.93429 .28843 Mdot
.93619 .24844 Mdot
.9381 .36963 Mdot
.94 .26797 Mdot
.9419 .3397 Mdot
.94381 .26219 Mdot
.94571 .25132 Mdot
.94762 .32335 Mdot
.94952 .36167 Mdot
.95143 .27435 Mdot
.95333 .27679 Mdot
.95524 .29283 Mdot
.95714 .26973 Mdot
.95905 .25478 Mdot
.96095 .28004 Mdot
.96286 .49102 Mdot
.96476 .28581 Mdot
.96667 .33953 Mdot
.96857 .30472 Mdot
.97048 .41099 Mdot
.97238 .25789 Mdot
.97429 .41264 Mdot
.97619 .22512 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo067ooooo0_l0000>ooooo`;o0000NOooool2o`0004kooooo0006ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool01?ooool2o`0000oooooo0_l0000Tooooo`;o00004Ooo
ool2o`00017ooooo0_l00009ooooo`;o00000oooool2o`0000?ooooo0_l0000:ooooo`;o0000:?oo
ool2o`0001;ooooo0ol0000Gooooo`Co00003_ooool2o`0000Cooooo0_l00003ooooo`;o0000=_oo
ool2o`0000_ooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`;o00003ooo
ool2o`0000gooooo0_l0000Eooooo`;o00004Oooool2o`0000;ooooo0_l0000Hooooo`;o00002?oo
ool2o`0000[ooooo0_l0000Xooooo`;o00004_ooool3o`0001?ooooo0_l00002ooooo`Co00005?oo
ool2o`0000?ooooo0_l0000fooooo`;o00002oooool000Kooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0002Cooooo0_l0
000/ooooo`;o00005Oooool2o`0001Wooooo0_l0000/ooooo`;o00008_ooool2o`0000Gooooo0_l0
000Rooooo`;o0000>Oooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo06Wooooo
0_l0000Iooooo`;o0000;?ooool2o`0002Wooooo0_l0000Rooooo`;o0000>Oooool000Kooooo00Go
410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`1Cooooo`;o0000Aoooool2o`0001Oooooo0_l0000Aooooo`;o0000
6?ooool2o`0001;ooooo0_l0000Qooooo`;o00008Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00;o00000oooool2o`0000kooooo0_l0000gooooo`;o00000oooool2o`0000go
oooo0_l0000Hooooo`;o00003?ooool2o`00013ooooo0_l00004ooooo`;o00004Oooool2o`0000go
oooo0_l00002ooooo`;o00000oooool2o`00013ooooo0_l000000ooooooo0000o`00000Booooo`;o
00008Oooool3o`0000Cooooo0_l0000Jooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`02o`00
00?ooooo0_l00009ooooo`;o00000oooool2o`0000Sooooo0_l0000]ooooo`?o00004Oooool2o`00
00[ooooo0_l00005ooooo`;o00001Oooool2o`0000cooooo0_l00006ooooo`;o00003_ooool2o`00
023ooooo0_l00007ooooo`;o00000_ooool2o`0000cooooo0_l0000Xooooo`;o00003oooool2o`00
00Cooooo0_l0000Jooooo`00:Oooool2o`00017ooooo0_l0000=ooooo`;o0000;_ooool2o`0001go
oooo0_l00005ooooo`;o00006oooool2o`0000?ooooo0_l0000@ooooo`;o00003_ooool2o`0001Ko
oooo0_l0000fooooo`;o00005oooool2o`0001Sooooo000Yooooo`03o`000?oooooooooo00gooooo
0_l00008ooooo`;o00009Oooool2o`00037ooooo0_l0000Tooooo`;o00004?ooool2o`0000;ooooo
0_l0000:ooooo`;o0000C_ooool2o`0000Sooooo0_l00009ooooo`;o00000_ooool2o`000003oooo
ool0003o000001Gooooo000Yooooo`04o`000?ooooooooooooooo`;o00001Oooool2o`0000?ooooo
0_l00005ooooo`;o000000?oooooo`000?l000001_ooool2o`0001gooooo0_l0000aooooo`;o0000
=?ooool2o`0000Cooooo0_l0000hooooo`Co0000:?ooool2o`0000Wooooo0_l00005ooooo`;o0000
0_ooool2o`00017ooooo000Yooooo`04o`000?ooooooooooooooo`;o00001Oooool2o`0000[ooooo
0_l00007ooooo`Ko0000<Oooool2o`0001kooooo0_l0000Iooooo`;o00005_ooool2o`0003kooooo
1?l0000nooooo`;o00000_ooool2o`0000gooooo000Yooooo`03o`000?oooooooooo01gooooo0_l0
0002ooooo`;o00001?ooool2o`0000cooooo0ol00007ooooo`;o00004oooool2o`0000Kooooo0_l0
0006ooooo`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00000oooool2o`0001Wooooo
0_l00003ooooo`;o0000<oooool2o`0000Kooooo0_l0000Rooooo`;o00006_ooool2o`0001[ooooo
0_l0000=ooooo`00:Oooool2o`0001Wooooo0_l00009ooooo`;o00000_ooool2o`0000cooooo0ol0
0007ooooo`;o00006oooool2o`0000Kooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo
0_l0000Sooooo`;o00000_ooool4o`0002[ooooo0_l000000ooooooo0000o`000006ooooo`;o0000
8Oooool3o`0000?ooooo0_l00008ooooo`;o00002_ooool3o`00017ooooo0_l0000Fooooo`00:Ooo
ool00ol0003oooooooooo`02ooooo`;o00002?ooool2o`0000[ooooo0_l00009ooooo`;o00000ooo
ool2o`0000Kooooo0_l0000fooooo`;o00002Oooool2o`0000Cooooo0_l0000Mooooo`Co00006ooo
ool2o`0000gooooo0_l00003ooooo`;o00001oooool2o`0001kooooo0_l00004ooooo`;o00002?oo
ool2o`0000[ooooo0_l0000Aooooo`?o00005_ooool002Wooooo00?o0000ooooooooool00_ooool2
o`0000Sooooo0_l0000Jooooo`;o00001_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h05?ooool2o`000003ooooool0003o0000
00_ooooo0_l00003ooooo`Go000000Ooooooo`000?l0003ok^k^oc8b<_l0003o<S8b00;o00000_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo0_l0000Tooooo`05oiRHV?l@413o0000oc8b<_o<
c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;o000000Goooooonk^k_lb<S;o0000oc8b<P02
o`0000_ooooo0_l00007ooooo`;o00002?ooool2o`0000Wooooo0ol00003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Oooooo0_l000000om4A4Co0000
o`000002o`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool002Wooooo00?o0000ooooooooool03Oooool2o`0000oooooo0_l0000Booooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL05?ooool5o`00013ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo0_l00002ooooo`?o
00006Oooool2o`0000Cooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool01?mgMgOoV9RHoooooonHV9P2o`0001kooooo1?l00008ooooo`;o00000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgo`000?l0003oV9RHogMgM`0Iooooo`;o
00004?ooool3o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool002Wooooo0ol0000=ooooo`;o00003oooool2o`0000Gooooo0_l0000;oooo
o`06o`000?oooooo0000o`000?oooooo410@0oooool01Ol@413ooooooooooooooooo410@00?ooooo
00?o410@ooooooooool04?ooool2o`000003ooooool0003o000000Sooooo0_l00009ooooo`03oiRH
V?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41001_ooool3o`0001Wooooo0_l00007ooooo`;o00000oooool01Ol@413ooooooooooooooooo
410@00?ooooo00Go410@oooooooooooooooooa0@400Cooooo`;o00003?ooool2o`0000Gooooo1Ol0
0003ooooo`05oa0@4?ooooooooooooooool@41000oooool3o`000005ooooool@413o0000o`000?oo
ool00_l00007ooooo`;o00000oooool2o`0000Kooooo0_l0000@ooooo`?o00000_ooool01Ol@413o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`00:Oooool3o`00
02Gooooo0_l0000;ooooo`06o`000?oooooo0000o`000?oooooo00000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool03_ooool4o`0000Kooooo0_l00003ooooo`;o0000
2_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000?o
oooo00?o0000ooooooooool0:Oooool2o`0000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`04o`000?ooooooooooooooo`?o00004Oooool2o`0001?ooooo00CoA4A4omgMgOoooooo00001?oo
ool2o`0000;ooooo00Co0000oooooooooooooooo0_l00002ooooo`?o000000?oooooo`000?l00000
1oooool2o`0000;ooooo0ol0000Hooooo`;o000000Co<S8bo`000?l0003o00000oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool00Oooool002Wooooo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooo`000002o`00013ooooo0_l00004ooooo`;o00000_ooool2o`0000Kooooo0_l00008oooo
o`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`;o00000oooool0
0ol0003oooooooooo`0Gooooo`;o00003oooool00ol@413o0000okZj^P03ooooo`05o`000?oooooo
ooooooooool000000oooool01?l0003oooooooooooooool3o`0002Kooooo00CogMgMoeEEEOoooooo
00001?ooool2o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
00Gooooo1?l00005ooooo`;o00005oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00?o00000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00Oooool002Wooooo00?o0000
ooooool000000ol0000=ooooo`;o00001Oooool2o`0001Wooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@ooooool0003o0000oa0@400Fooooo`;o0000
2_ooool2o`0000Wooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`09ooooo`;o00003?ooool2o`00013ooooo00?o^[Zjob4Q
8Oooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
400Yooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@
4?ooooooooooooooool@41001oooool6o`0001cooooo00?o0000ooooooooool00oooool2o`0000?o
oooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo007ooooo000Yooooo`03
o`000?oooooo000000?o00003Oooool2o`0000Gooooo0_l0000Iooooo`;o00000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Yooooo`05o`000?nj^[[o
oooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`;o00003oooool2o`0000[ooooo00Go410@oiRHV?oooooo^[Zjo`000003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg02Cooooo0_l0
0003ooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool3o`0000?ooooo0_l0000Hooooo`;o00000_ooool00ol0003o
ooooooooo`03ooooo`;o000000CoV9RHoooooonHV9SoMgMg0oooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo000Yooooo`03o`000?oooooooooo01;ooooo0_l0000Looooo`04oeEEEOmVIVKo0000
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
:Oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool2o`0000[ooooo00GoZJVYoa0@4?l0003o410@ojVY
Z@03ooooo`06onk^k_lb<S;o0000oc8b<_o^k^kooooo0_l000001Oo^k^ko<S8bo`000?lb<S;ok^k^
02Cooooo0_l00004ooooo`04ogMgMol0003o0000o`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool5o`0001gooooo0_l00002ooooo`Go0000
0_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`00:Oooool2o`0001?ooooo0_l0000Gooooo`;o00004?ooool2o`0000Kooooo0_l0000[ooooo`;o
0000A?ooool2o`0001Cooooo0_l0000Kooooo`;o00003oooool2o`000004ooooool0003o0000o`00
00Sooooo0_l0000Looooo`;o00004_ooool002Wooooo00?o0000ooooooooool0:oooool2o`0000_o
oooo0_l00003ooooo`;o00001_ooool2o`0002_ooooo0_l00006ooooo`;o000000?oooooo`000?l0
00005Oooool2o`0000Kooooo0_l00002ooooo`;o00003?ooool2o`00013ooooo0_l00005ooooo`;o
00001Oooool2o`0002cooooo1?l0000:ooooo`;o0000<?ooool002Wooooo0_l0000Booooo`;o0000
0oooool2o`00023ooooo0_l00010ooooo`;o000000?oooooo`000?l000005Oooool2o`0000Kooooo
0_l00002ooooo`;o00003?ooool2o`00013ooooo0_l00005ooooo`;o00008oooool2o`00013ooooo
0_l0000<ooooo`;o00003?ooool2o`00023ooooo000Yooooo`;o00004_ooool2o`0000?ooooo0_l0
000Hooooo`;o00002_ooool2o`0002Wooooo0_l00023ooooo`;o00003?ooool2o`00013ooooo0_l0
000<ooooo`;o00004?ooool2o`0000kooooo000Yooooo`03o`000?oooooooooo00?ooooo0_l0000[
ooooo`;o00002_ooool2o`0002Wooooo0_l00007ooooo`;o00006?ooool2o`0001Gooooo0_l0000G
ooooo`;o00002Oooool2o`0002Oooooo0_l0000:ooooo`;o00000_ooool2o`0000oooooo0_l0000>
ooooo`;o00002oooool2o`0000kooooo000Qoooooooo0000A?l00004ooooo`00:Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool2o`0000Co
oooo0_l0000:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`02o`0000Kooooo0ol00004ooooo`?o00001?ooool00ol0003oooooooooo`07ooooo`?o
00002oooool00ol0003oooooooooo`09ooooo`;o00002Oooool3o`0000Gooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo0_l00005ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool01_ooool4o`0000_ooooo00?o0000ooooooooool01?ooool2o`0000?ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`02ooooo`;o00001Oooool00ol0003oooooooooo`03ooooo`;o
00001?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo000Yooooo`03o`00
0?oooooooooo03Kooooo0_l00002ooooo`;o0000>_ooool3o`0001?ooooo0_l0000Jooooo`;o0000
2oooool00ol0003oooooooooo`03ooooo`;o00001Oooool2o`0001oooooo0_l0000=ooooo`04o`00
0?ooooooooooooooo`;o000000?oooooo`000?l000005Oooool2o`0000_ooooo0_l0000@ooooo`03
o`000?oooooooooo00[ooooo000Yooooo`03o`000?oooooooooo01Wooooo0_l0000Dooooo`;o0000
1Oooool2o`0000;ooooo0_l00017ooooo`;o00001oooool2o`0002cooooo0_l00006ooooo`;o0000
<_ooool2o`0004Cooooo000Yooooo`04o`000?oooooo0000o`0001Oooooo0ol000000ooooooo0000
o`00000Aooooo`;o00006oooool2o`0002[ooooo0ol00008ooooo`Co00008Oooool2o`0000Sooooo
0_l00006ooooo`;o00003oooool2o`0003Wooooo0_l0000Hooooo`;o00000oooool2o`0001Gooooo
000Yooooo`Co00005oooool2o`0000;ooooo0_l0000Dooooo`;o00003oooool2o`0000Oooooo0_l0
000Eooooo`;o00001_ooool2o`0000_ooooo0ol0000:ooooo`;o00004Oooool2o`0000kooooo0_l0
0008ooooo`;o00005oooool2o`0002?ooooo0_l0000Dooooo`;o00006?ooool2o`0000?ooooo0_l0
000Eooooo`00:Oooool00ol0003oooooooooo`0Jooooo`;o00003Oooool2o`0000Oooooo0_l0000?
ooooo`;o00001?ooool2o`0000Kooooo0_l00005ooooo`;o00002Oooool2o`0000Kooooo0_l0000D
ooooo`;o00001_ooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Wooooo0_l00003
ooooo`;o00003Oooool2o`000003ooooool0003o000002gooooo1?l00009ooooo`;o00004oooool4
o`0002Kooooo000Yooooo`03o`000?oooooooooo01[ooooo0_l0000=ooooo`;o00007_ooool2o`00
00Kooooo0_l00005ooooo`;o00008Oooool2o`0000Cooooo0_l00006ooooo`;o00001Oooool2o`00
00gooooo0_l00009ooooo`;o00000oooool2o`0000Oooooo0_l00004ooooo`;o000000?oooooo`00
0?l000002Oooool2o`0001_ooooo0_l00007ooooo`Co00001oooool2o`0001?ooooo1?l0000Voooo
o`00:Oooool00ol0003oooooooooo`05ooooo`;o00006oooool2o`000003ooooool0003o0000017o
oooo0_l0000Cooooo`;o0000;?ooool2o`0000kooooo0_l0000[ooooo`;o00002Oooool2o`0000Oo
oooo0_l0000Kooooo`;o00002Oooool2o`0001oooooo0_l0000Uooooo`00:Oooool00ol0003ooooo
ooooo`02ooooo`;o000000?oooooo`000?l000006oooool2o`000003ooooool0003o000000[ooooo
0_l00005ooooo`;o00001_ooool2o`0000_ooooo0_l0000looooo`;o00004?ooool2o`0001;ooooo
0_l0000@ooooo`;o00004oooool2o`0003_ooooo1?l00003ooooo`;o00001Oooool2o`0000Kooooo
0_l0000?ooooo`00:Oooool2o`0000?ooooo0_l00002ooooo`;o00006_ooool2o`0000;ooooo0_l0
0009ooooo`Co00002oooool2o`0004?ooooo0_l0000Fooooo`;o00001_ooool2o`0000Cooooo0_l0
0004ooooo`;o00002_ooool2o`0001Wooooo0_l0000Dooooo`;o00009oooool3o`0000;ooooo0_l0
0005ooooo`;o00001_ooool2o`0000oooooo000Yooooo`03o`000?oooooooooo00Kooooo0ol0000G
ooooo`Co00000_ooool2o`0000;ooooo0_l00007ooooo`;o00004Oooool2o`0000gooooo0_l0000M
ooooo`;o000000?oooooo`000?l000002?ooool2o`0000;ooooo1?l0000Looooo`;o00001?ooool2
o`00013ooooo0_l0000_ooooo`;o00002Oooool2o`0001gooooo0_l0000Rooooo`00:Oooool2o`00
00Sooooo0_l0000Gooooo`;o00002?ooool2o`0001Sooooo1?l0000=ooooo`;o00005_ooool2o`00
00Gooooo0_l000000ooooooo0000o`000008ooooo`;o00001?ooool2o`0000Sooooo0_l0000Doooo
o`;o00002oooool2o`0001kooooo0_l0000Kooooo`;o00001_ooool2o`0001Oooooo0_l0000;oooo
o`;o00006oooool002Wooooo0_l0000Qooooo`;o00007?ooool2o`0000Cooooo0_l0000Wooooo`;o
00008_ooool2o`0000;ooooo0_l0000@ooooo`;o00000_ooool2o`0000Oooooo0_l0000Booooo`;o
00002_ooool2o`0001_ooooo0_l0000?ooooo`;o00003_ooool2o`0000_ooooo0_l0000Kooooo`00
:Oooool00ol0003oooooooooo`0Pooooo`;o00007?ooool2o`0001kooooo0_l0000Oooooo`;o0000
00?oooooo`000?l000004Oooool2o`0001Cooooo0_l0000Kooooo`?o00009?ooool2o`00017ooooo
0_l0000hooooo`00:Oooool2o`0000gooooo0_l0000Nooooo`;o00007Oooool2o`00017ooooo0_l0
000Oooooo`;o000000?oooooo`000?l00000AOooool2o`0002Cooooo0_l0001;ooooo`00:Oooool0
0ol0003oooooooooo`0<ooooo`;o000000?oooooo`000?l000000_ooool2o`0001Oooooo0_l0000M
ooooo`;o0000C?ooool2o`0004Wooooo0ol0000oooooo`;o00005?ooool002Wooooo00?o0000oooo
ooooool03oooool2o`0000;ooooo0_l0000Cooooo`;o00001?ooool2o`0000?ooooo0_l0001Noooo
o`;o000000Coooooo`000?l0003ooooo0ol0000Gooooo`;o00001_ooool2o`0001?ooooo0_l0000B
ooooo`?o0000?oooool2o`0001Cooooo000Yooooo`03o`000?oooooooooo02Sooooo0_l00004oooo
o`;o00000oooool2o`0002[ooooo0_l0000booooo`;o000000?oooooo`000?l000000_ooool2o`00
01Oooooo0_l00006ooooo`;o00004Oooool4o`0006[ooooo000Yooooo`03o`000?oooooooooo02go
oooo0_l0000;ooooo`;o00008oooool2o`0002cooooo0_l00006ooooo`;o00003?ooool2o`0002Wo
oooo1?l0000?ooooo`;o00002?ooool2o`0001Oooooo0_l00008ooooo`;o00002oooool3o`0000Co
oooo0_l0000Hooooo`00:Oooool2o`0002kooooo0_l0000;ooooo`?o0000D?ooool2o`0000Kooooo
0_l00009ooooo`;o000000?oooooo`000?l000000_l0000?ooooo`;o00007_ooool5o`0000?ooooo
0_l000000ooooooo0000o`000008ooooo`;o00005oooool2o`0000Sooooo0_l0000;ooooo`?o0000
1?ooool2o`0001Sooooo000Yooooo`03o`000?oooooooooo01[ooooo0_l0000Oooooo`;o00007?oo
ool2o`0004;ooooo0_l000000ooooooo0000o`000003ooooo`;o00003oooool2o`0001kooooo1Ol0
0003ooooo`;o0000G?ooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00[ooooo
0_l0000>ooooo`;o0000?Oooool2o`0004;ooooo0_l0000Vooooo`;o00000oooool2o`0000Oooooo
0_l0001Wooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00[o
oooo0_l0001cooooo`;o0000A?ooool2o`0000?ooooo0_l00007ooooo`;o00001_ooool2o`0000Wo
oooo0_l0000Rooooo`;o0000<?ooool000Kooooo00Go410@oooooooooooooooooa0@400<ooooo`03
oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Sooooo`;o
00001Oooool2o`00033ooooo0_l000000ooooooo0000o`00000Nooooo`;o0000>oooool2o`0001go
oooo0_l00009ooooo`;o00008_ooool2o`00033ooooo0006ooooo`05o`000?ooooooooooooooool0
00003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Sooooo`;o
00001Oooool2o`0002Cooooo0_l0000:ooooo`;o000000?oooooo`000?l00000=_ooool2o`0000go
oooo0_l0000Dooooo`;o00005oooool2o`0006Gooooo0006ooooo`05o`000?ooooooooooooooool0
00003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0
003oooooooooo`1=ooooo`;o000000Coooooo`000?l0003ooooo0_l00008ooooo`;o0000>?ooool2
o`0000gooooo0_l0000Kooooo`;o00004?ooool2o`00013ooooo0_l0001Cooooo`001_ooool01Ol@
413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Cooooo0_l000001?oooooo0000o`000?ooool2o`0000Sooooo0_l0
000`ooooo`;o00001Oooool2o`0000Cooooo0_l00008ooooo`;o0000I?ooool2o`00027ooooo0ol0
001Cooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RH
oa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool2o`000004oooo
ool0003o0000ooooo`;o00002?ooool2o`0000Kooooo0_l0000Xooooo`;o00007Oooool2o`0005Ko
oooo0_l0000Wooooo`;o0000E?ooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool02oooool2o`00
00oooooo0_l0000mooooo`;o00002?ooool2o`0002Wooooo0_l0000[ooooo`;o0000OOooool002Wo
oooo0_l0000:ooooo`Co00008?ooool2o`0001Wooooo0_l0000Aooooo`;o00002Oooool2o`0000Co
oooo0_l0000Rooooo`;o00004?ooool2o`0009Sooooo000Yooooo`03o`000?oooooooooo00Wooooo
0_l0000@ooooo`;o00002_ooool2o`0000Cooooo0_l0000Iooooo`;o00005_ooool2o`0000Cooooo
0_l00004ooooo`;o0000=?ooool2o`0003Gooooo0_l0001Qooooo`00:Oooool00ol0003ooooooooo
o`0?ooooo`;o000000?oooooo`000?l000001oooool2o`0000[ooooo0_l0000Gooooo`;o00001ooo
ool2o`0001Gooooo0ol00008ooooo`;o00006_ooool2o`0001Kooooo0_l00009ooooo`;o0000:ooo
ool4o`0001;ooooo0_l0000Uooooo`;o00005oooool2o`0000gooooo000Yooooo`03o`000?oooooo
oooo00oooooo0_l000000ooooooo0000o`00000Jooooo`;o00004?ooool2o`0000Oooooo0_l00005
ooooo`;o00003oooool2o`0000Sooooo0_l0000Jooooo`;o00005_ooool2o`0000;ooooo0_l00005
ooooo`;o00001?ooool2o`00027ooooo0_l00002ooooo`;o00002?ooool2o`0000[ooooo0_l0000<
ooooo`;o00004?ooool2o`0000Gooooo0_l000001?oooooo0000o`000?l0000Cooooo`?o00003?oo
ool002Wooooo00?o0000ooooooooool03_ooool2o`0001kooooo0_l0000=ooooo`;o00002oooool2
o`0000Cooooo0ol0000Aooooo`;o00006_ooool2o`0000Cooooo0_l0000Kooooo`;o00002oooool2
o`00027ooooo0_l0000<ooooo`;o00003_ooool2o`0000Sooooo0_l0000@ooooo`;o00001oooool4
o`0000?ooooo0_l0000?ooooo`;o00003?ooool002Wooooo0_l0000?ooooo`;o0000;Oooool2o`00
00?ooooo0_l00004ooooo`Co00001Oooool2o`00017ooooo0_l0000Jooooo`;o00001?ooool2o`00
00[ooooo0_l00017ooooo`;o00005?ooool2o`0002?ooooo0_l00005ooooo`;o00007Oooool002Wo
oooo00?o0000ooooooooool02Oooool2o`0003Oooooo0_l00004ooooo`;o000000?oooooo`000?l0
00002Oooool2o`0001[ooooo0_l0000Nooooo`;o00006_ooool2o`0000Gooooo0_l0000Tooooo`;o
0000Goooool002Wooooo00?o0000ooooooooool02Oooool2o`00043ooooo0_l00009ooooo`;o0000
5oooool2o`000003ooooool0003o000003[ooooo0_l00005ooooo`;o0000QOooool002Wooooo00?o
0000ooooooooool0Koooool2o`0003oooooo0_l0002:ooooo`00:Oooool00ol0003oooooooooo`1Y
ooooo`;o0000AOooool2o`0008[ooooo000Yooooo`;o0000>?ooool2o`00033ooooo0_l0003Aoooo
o`00:Oooool00ol0003oooooooooo`0gooooo`;o0000c?ooool2o`0003Gooooo000Yooooo`03o`00
0?oooooooooo0?oooooo1_ooool2o`0003Gooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0=Oooool2o`000?oooooo1_ooool002Wooooo0_l0000foooo
o`;o0000f?ooool2o`0002_ooooo000Yooooo`03o`000?oooooooooo07Oooooo0_l0002Fooooo`;o
0000:oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0Moooool2o`000<?ooooo000>ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`1jooooo`;o0000`?ooool000kooooo00Go410@oooooooooooooooooa0@400@oooo
o`03o`000?oooooooooo00?ooooo0ol0001jooooo`;o00004?ooool2o`000:kooooo000>ooooo`05
o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
08cooooo0_l0002^ooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3?ooooo`;o00008_ooool2o`0004Oooooo000>ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0003@ooooo`;o00008_ooool2o`0001Kooooo0_l0000_
ooooo`00:Oooool00ol0003oooooooooo`0Mooooo`;o00003?ooool2o`0000cooooo0_l0003@oooo
o`;o0000;oooool002Wooooo00?o0000ooooooooool07Oooool2o`0000cooooo0_l0000<ooooo`;o
0000Noooool2o`0008Cooooo000Yooooo`03o`000?oooooooooo04?ooooo0_l0000Booooo`;o0000
GOooool2o`0004oooooo0_l0000cooooo`00:Oooool00ol0003oooooooooo`13ooooo`;o00004_oo
ool2o`0008oooooo0_l0000Mooooo`;o00008Oooool2o`00013ooooo000Yooooo`;o0000jOooool2
o`00043ooooo0_l0000@ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo
00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000Kooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`3oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omE
EEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3o
ooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Oooooo`Co000000?o410@ooooooooool00oooool00ol0003o
ooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`?o0000oooooolmooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Oooooo`03oeEEEOmVIVKo00000?ooooooAoooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .23892 Mdot
.02762 .25542 Mdot
.02952 .29795 Mdot
.03143 .26683 Mdot
.03333 .2531 Mdot
.03524 .30602 Mdot
.03714 .31865 Mdot
.03905 .36465 Mdot
.04095 .37169 Mdot
.04286 .34604 Mdot
.04476 .34871 Mdot
.04667 .3164 Mdot
.04857 .32413 Mdot
.05048 .35098 Mdot
.05238 .26384 Mdot
.05429 .30275 Mdot
.05619 .37764 Mdot
.0581 .32728 Mdot
.06 .31321 Mdot
.0619 .41842 Mdot
.06381 .3537 Mdot
.06571 .30385 Mdot
.06762 .33812 Mdot
.06952 .34182 Mdot
.07143 .23882 Mdot
.07333 .29263 Mdot
.07524 .3342 Mdot
.07714 .30403 Mdot
.07905 .42398 Mdot
.08095 .27376 Mdot
.08286 .38013 Mdot
.08476 .38473 Mdot
.08667 .35403 Mdot
.08857 .36487 Mdot
.09048 .36333 Mdot
.09238 .41641 Mdot
.09429 .42034 Mdot
.09619 .31445 Mdot
.0981 .42497 Mdot
.1 .32463 Mdot
.1019 .26049 Mdot
.10381 .36643 Mdot
.10571 .33254 Mdot
.10762 .24141 Mdot
.10952 .25495 Mdot
.11143 .25278 Mdot
.11333 .34924 Mdot
.11524 .40846 Mdot
.11714 .34774 Mdot
.11905 .42392 Mdot
.12095 .405 Mdot
.12286 .42869 Mdot
.12476 .43824 Mdot
.12667 .33982 Mdot
.12857 .35428 Mdot
.13048 .36015 Mdot
.13238 .35357 Mdot
.13429 .37924 Mdot
.13619 .41569 Mdot
.1381 .2613 Mdot
.14 .26243 Mdot
.1419 .23185 Mdot
.14381 .42295 Mdot
.14571 .31209 Mdot
.14762 .32016 Mdot
.14952 .37897 Mdot
.15143 .34582 Mdot
.15333 .30827 Mdot
.15524 .32484 Mdot
.15714 .35871 Mdot
.15905 .38204 Mdot
.16095 .303 Mdot
.16286 .34796 Mdot
.16476 .33783 Mdot
.16667 .42289 Mdot
.16857 .27344 Mdot
.17048 .43854 Mdot
.17238 .30457 Mdot
.17429 .42858 Mdot
.17619 .36002 Mdot
.1781 .40058 Mdot
.18 .27704 Mdot
.1819 .26504 Mdot
.18381 .36804 Mdot
.18571 .37465 Mdot
.18762 .28971 Mdot
.18952 .2518 Mdot
.19143 .25646 Mdot
.19333 .37807 Mdot
.19524 .31275 Mdot
.19714 .2334 Mdot
.19905 .37092 Mdot
.20095 .29167 Mdot
.20286 .25082 Mdot
.20476 .29427 Mdot
.20667 .34758 Mdot
.20857 .35047 Mdot
.21048 .38987 Mdot
.21238 .44158 Mdot
.21429 .37737 Mdot
.21619 .2396 Mdot
.2181 .37219 Mdot
.22 .30125 Mdot
.2219 .23773 Mdot
.22381 .38338 Mdot
.22571 .36283 Mdot
.22762 .38173 Mdot
.22952 .30445 Mdot
.23143 .29161 Mdot
.23333 .36542 Mdot
.23524 .34806 Mdot
.23714 .26024 Mdot
.23905 .38306 Mdot
.24095 .41358 Mdot
.24286 .48266 Mdot
.24476 .28407 Mdot
.24667 .27877 Mdot
.24857 .39132 Mdot
.25048 .39171 Mdot
.25238 .41137 Mdot
.25429 .32902 Mdot
.25619 .22306 Mdot
.2581 .36103 Mdot
.26 .42421 Mdot
.2619 .36272 Mdot
.26381 .27794 Mdot
.26571 .41806 Mdot
.26762 .32802 Mdot
.26952 .26853 Mdot
.27143 .32346 Mdot
.27333 .32357 Mdot
.27524 .24706 Mdot
.27714 .29232 Mdot
.27905 .31454 Mdot
.28095 .32296 Mdot
.28286 .42787 Mdot
.28476 .43067 Mdot
.28667 .42194 Mdot
.28857 .34769 Mdot
.29048 .33098 Mdot
.29238 .26867 Mdot
.29429 .28401 Mdot
.29619 .26507 Mdot
.2981 .32331 Mdot
.3 .37808 Mdot
.3019 .41551 Mdot
.30381 .38145 Mdot
.30571 .49323 Mdot
.30762 .26608 Mdot
.30952 .25855 Mdot
.31143 .23206 Mdot
.31333 .36858 Mdot
.31524 .34149 Mdot
.31714 .3389 Mdot
.31905 .30873 Mdot
.32095 .26136 Mdot
.32286 .42754 Mdot
.32476 .42528 Mdot
.32667 .38253 Mdot
.32857 .41693 Mdot
.33048 .42834 Mdot
.33238 .31918 Mdot
.33429 .42927 Mdot
.33619 .30225 Mdot
.3381 .41239 Mdot
.34 .31547 Mdot
.3419 .24297 Mdot
.34381 .38044 Mdot
.34571 .38692 Mdot
.34762 .32611 Mdot
.34952 .4319 Mdot
.35143 .4214 Mdot
.35333 .26519 Mdot
.35524 .32558 Mdot
.35714 .25007 Mdot
.35905 .2676 Mdot
.36095 .33611 Mdot
.36286 .34312 Mdot
.36476 .26158 Mdot
.36667 .29639 Mdot
.36857 .42544 Mdot
.37048 .43197 Mdot
.37238 .30478 Mdot
.37429 .32178 Mdot
.37619 .25665 Mdot
.3781 .33112 Mdot
.38 .36567 Mdot
.3819 .33366 Mdot
.38381 .39889 Mdot
.38571 .30236 Mdot
.38762 .33332 Mdot
.38952 .22462 Mdot
.39143 .41489 Mdot
.39333 .31829 Mdot
.39524 .23411 Mdot
.39714 .36768 Mdot
.39905 .25472 Mdot
.40095 .29903 Mdot
.40286 .2505 Mdot
.40476 .37816 Mdot
.40667 .38272 Mdot
.40857 .28132 Mdot
.41048 .28334 Mdot
.41238 .29819 Mdot
.41429 .25071 Mdot
.41619 .38991 Mdot
.4181 .24645 Mdot
.42 .32638 Mdot
.4219 .2912 Mdot
.42381 .25822 Mdot
.42571 .333 Mdot
.42762 .35035 Mdot
.42952 .30225 Mdot
.43143 .29775 Mdot
.43333 .38801 Mdot
.43524 .32331 Mdot
.43714 .24535 Mdot
.43905 .29441 Mdot
.44095 .29499 Mdot
.44286 .33052 Mdot
.44476 .25094 Mdot
.44667 .33867 Mdot
.44857 .27347 Mdot
.45048 .40321 Mdot
.45238 .38101 Mdot
.45429 .40659 Mdot
.45619 .32365 Mdot
.4581 .26143 Mdot
.46 .24161 Mdot
.4619 .27245 Mdot
.46381 .2642 Mdot
.46571 .22268 Mdot
.46762 .28514 Mdot
.46952 .30595 Mdot
.47143 .40292 Mdot
.47333 .36777 Mdot
.47524 .34215 Mdot
.47714 .22331 Mdot
.47905 .32206 Mdot
.48095 .23759 Mdot
.48286 .34636 Mdot
.48476 .24354 Mdot
.48667 .23527 Mdot
.48857 .32742 Mdot
.49048 .39367 Mdot
.49238 .38196 Mdot
.49429 .39342 Mdot
.49619 .2907 Mdot
.4981 .42187 Mdot
.5 .37562 Mdot
.5019 .38169 Mdot
.50381 .42435 Mdot
.50571 .25323 Mdot
.50762 .28406 Mdot
.50952 .31058 Mdot
.51143 .41774 Mdot
.51333 .31136 Mdot
.51524 .32587 Mdot
.51714 .36036 Mdot
.51905 .27315 Mdot
.52095 .34693 Mdot
.52286 .41287 Mdot
.52476 .35852 Mdot
.52667 .34261 Mdot
.52857 .40849 Mdot
.53048 .31248 Mdot
.53238 .37013 Mdot
.53429 .23958 Mdot
.53619 .34719 Mdot
.5381 .29163 Mdot
.54 .41904 Mdot
.5419 .33341 Mdot
.54381 .41651 Mdot
.54571 .35449 Mdot
.54762 .34385 Mdot
.54952 .35916 Mdot
.55143 .42906 Mdot
.55333 .32105 Mdot
.55524 .28739 Mdot
.55714 .40012 Mdot
.55905 .35237 Mdot
.56095 .27448 Mdot
.56286 .42682 Mdot
.56476 .31612 Mdot
.56667 .3368 Mdot
.56857 .41479 Mdot
.57048 .31435 Mdot
.57238 .30465 Mdot
.57429 .31456 Mdot
.57619 .25148 Mdot
.5781 .40545 Mdot
.58 .25848 Mdot
.5819 .39784 Mdot
.58381 .33735 Mdot
.58571 .41133 Mdot
.58762 .2829 Mdot
.58952 .40273 Mdot
.59143 .31644 Mdot
.59333 .42358 Mdot
.59524 .23632 Mdot
.59714 .39801 Mdot
.59905 .26905 Mdot
.60095 .49715 Mdot
.60286 .3512 Mdot
.60476 .35072 Mdot
.60667 .24521 Mdot
.60857 .38954 Mdot
.61048 .25259 Mdot
.61238 .34987 Mdot
.61429 .39625 Mdot
.61619 .3144 Mdot
.6181 .27073 Mdot
.62 .31042 Mdot
.6219 .37801 Mdot
.62381 .33121 Mdot
.62571 .23447 Mdot
.62762 .29515 Mdot
.62952 .24499 Mdot
.63143 .36425 Mdot
.63333 .31286 Mdot
.63524 .30834 Mdot
.63714 .29643 Mdot
.63905 .22467 Mdot
.64095 .27829 Mdot
.64286 .2869 Mdot
.64476 .32121 Mdot
.64667 .37067 Mdot
.64857 .42239 Mdot
.65048 .26804 Mdot
.65238 .26877 Mdot
.65429 .31956 Mdot
.65619 .38114 Mdot
.6581 .34934 Mdot
.66 .41451 Mdot
.6619 .29984 Mdot
.66381 .30036 Mdot
.66571 .32342 Mdot
.66762 .29599 Mdot
.66952 .24362 Mdot
.67143 .31521 Mdot
.67333 .31572 Mdot
.67524 .32092 Mdot
.67714 .25118 Mdot
.67905 .42467 Mdot
.68095 .32441 Mdot
.68286 .27901 Mdot
.68476 .30523 Mdot
.68667 .3526 Mdot
.68857 .33541 Mdot
.69048 .42112 Mdot
.69238 .30355 Mdot
.69429 .27944 Mdot
.69619 .2841 Mdot
.6981 .27896 Mdot
.7 .32593 Mdot
.7019 .42776 Mdot
.70381 .41733 Mdot
.70571 .3417 Mdot
.70762 .37988 Mdot
.70952 .42084 Mdot
.71143 .36867 Mdot
.71333 .32396 Mdot
.71524 .26721 Mdot
.71714 .39527 Mdot
.71905 .29057 Mdot
.72095 .29176 Mdot
.72286 .27409 Mdot
.72476 .28511 Mdot
.72667 .36417 Mdot
.72857 .26367 Mdot
.73048 .35172 Mdot
.73238 .28246 Mdot
.73429 .39008 Mdot
.73619 .33547 Mdot
.7381 .29949 Mdot
.74 .23893 Mdot
.7419 .38487 Mdot
.74381 .23777 Mdot
.74571 .42003 Mdot
.74762 .41697 Mdot
.74952 .33624 Mdot
.75143 .43058 Mdot
.75333 .32454 Mdot
.75524 .24803 Mdot
.75714 .48664 Mdot
.75905 .40633 Mdot
.76095 .2663 Mdot
.76286 .30432 Mdot
.76476 .22682 Mdot
.76667 .37657 Mdot
.76857 .31917 Mdot
.77048 .30846 Mdot
.77238 .36061 Mdot
.77429 .2666 Mdot
.77619 .34137 Mdot
.7781 .28921 Mdot
.78 .33872 Mdot
.7819 .40838 Mdot
.78381 .37447 Mdot
.78571 .23679 Mdot
.78762 .30232 Mdot
.78952 .37528 Mdot
.79143 .42566 Mdot
.79333 .3772 Mdot
.79524 .27258 Mdot
.79714 .27307 Mdot
.79905 .28478 Mdot
.80095 .34653 Mdot
.80286 .31673 Mdot
.80476 .33562 Mdot
.80667 .27137 Mdot
.80857 .35235 Mdot
.81048 .3031 Mdot
.81238 .23905 Mdot
.81429 .24892 Mdot
.81619 .41061 Mdot
.8181 .25943 Mdot
.82 .33825 Mdot
.8219 .315 Mdot
.82381 .24951 Mdot
.82571 .36684 Mdot
.82762 .34487 Mdot
.82952 .3248 Mdot
.83143 .22468 Mdot
.83333 .33482 Mdot
.83524 .31065 Mdot
.83714 .36153 Mdot
.83905 .3816 Mdot
.84095 .24538 Mdot
.84286 .34081 Mdot
.84476 .32807 Mdot
.84667 .22903 Mdot
.84857 .34903 Mdot
.85048 .24111 Mdot
.85238 .4732 Mdot
.85429 .24069 Mdot
.85619 .32568 Mdot
.8581 .3532 Mdot
.86 .25757 Mdot
.8619 .34514 Mdot
.86381 .31103 Mdot
.86571 .4289 Mdot
.86762 .26703 Mdot
.86952 .26582 Mdot
.87143 .2597 Mdot
.87333 .40648 Mdot
.87524 .35277 Mdot
.87714 .375 Mdot
.87905 .332 Mdot
.88095 .34517 Mdot
.88286 .37214 Mdot
.88476 .30815 Mdot
.88667 .29998 Mdot
.88857 .32939 Mdot
.89048 .36197 Mdot
.89238 .29643 Mdot
.89429 .42832 Mdot
.89619 .24698 Mdot
.8981 .24803 Mdot
.9 .41699 Mdot
.9019 .39426 Mdot
.90381 .37776 Mdot
.90571 .31122 Mdot
.90762 .34231 Mdot
.90952 .34836 Mdot
.91143 .25861 Mdot
.91333 .34562 Mdot
.91524 .42553 Mdot
.91714 .33773 Mdot
.91905 .3755 Mdot
.92095 .4205 Mdot
.92286 .23879 Mdot
.92476 .30415 Mdot
.92667 .28299 Mdot
.92857 .36856 Mdot
.93048 .2239 Mdot
.93238 .31185 Mdot
.93429 .2754 Mdot
.93619 .3281 Mdot
.9381 .35897 Mdot
.94 .29239 Mdot
.9419 .29985 Mdot
.94381 .34402 Mdot
.94571 .33442 Mdot
.94762 .28229 Mdot
.94952 .30958 Mdot
.95143 .37758 Mdot
.95333 .25758 Mdot
.95524 .24072 Mdot
.95714 .33509 Mdot
.95905 .28884 Mdot
.96095 .27379 Mdot
.96286 .47902 Mdot
.96476 .2701 Mdot
.96667 .24891 Mdot
.96857 .39287 Mdot
.97048 .41253 Mdot
.97238 .32177 Mdot
.97429 .42359 Mdot
.97619 .30901 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo04Oooooo0_l0000Yooooo`;o00005_ooool2o`0000;ooooo0_l0000booooo`;o0000??ooool2
o`0001kooooo0_l0000Jooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo04Oooooo0_l0000Yooooo`;o00005_ooool2o`0000;ooooo0_l0000booooo`;o00009ooo
ool2o`0001?ooooo0_l0000Nooooo`;o00006_ooool000Co00000_ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo0>_ooooo0_l0000Hooooo`;o0000=Oooool000Kooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0002;ooooo0_l0
000@ooooo`;o00008oooool2o`0001Wooooo0_l0002?ooooo`;o0000=Oooool000Kooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`03o`000?oooooooooo02;ooooo0_l0000@ooooo`;o00008oooool2o`0001Wooooo
0_l0000Kooooo`;o00008Oooool2o`0000Sooooo0_l0000aooooo`;o0000BOooool000Kooooo00Go
410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1oooool2o`0000gooooo0_l0000/ooooo`Co0000DOooool4o`0000gooooo0_l0000Booooo`;o0000
2?ooool2o`0002?ooooo0ol0000;ooooo`;o00001oooool2o`00027ooooo0_l0000Mooooo`001_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03
o`000?oooooooooo00Oooooo0_l0000=ooooo`;o00002Oooool2o`00027ooooo1?l0000Uooooo`;o
00009?ooool2o`0000Cooooo0_l0000?ooooo`;o0000@Oooool3o`0001Cooooo0_l0000:ooooo`?o
00005?ooool2o`0000Wooooo0_l0000Booooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`0Goooo
o`;o0000B_ooool2o`0001Kooooo0_l00004ooooo`;o00001_ooool2o`0000Gooooo0_l0000Voooo
o`;o00001Oooool2o`0000_ooooo0_l0000eooooo`;o000000Coooooo`000?l0003o00007oooool2
o`0001;ooooo000Yooooo`;o0000C_ooool2o`0002cooooo0_l00004ooooo`;o00003Oooool2o`00
02Kooooo0_l00005ooooo`;o00002oooool2o`0001Wooooo0_l0000Aooooo`;o00000_ooool2o`00
00?ooooo0_l0000@ooooo`;o00005?ooool2o`0000oooooo000Yooooo`03o`000?oooooooooo01So
oooo0_l0000Hooooo`;o00000_ooool2o`0001Gooooo0_l0000Hooooo`;o00003Oooool2o`0000;o
oooo0_l00008ooooo`;o0000:?ooool2o`0000Wooooo0_l0000Cooooo`;o00005oooool2o`00017o
oooo0_l00002ooooo`;o00005Oooool2o`0001Cooooo0_l0000?ooooo`00:Oooool4o`0001Oooooo
0_l0000Hooooo`;o00000_ooool2o`0002oooooo0_l0000<ooooo`?o00000_ooool2o`0000Sooooo
0_l0000Aooooo`;o00005Oooool2o`0000Wooooo0_l0000Cooooo`;o0000K?ooool002Wooooo1?l0
000Gooooo`;o00006?ooool2o`0002Cooooo0_l0000Dooooo`;o00001Oooool2o`0000Kooooo0_l0
000Hooooo`;o00005_ooool2o`0005Sooooo0_l0000?ooooo`;o00002oooool2o`0001?ooooo000Y
ooooo`03o`000?oooooooooo01Gooooo0_l0000:ooooo`;o00003oooool2o`0000gooooo0_l0000E
ooooo`;o00000_ooool2o`0000cooooo0_l00002ooooo`;o00003Oooool2o`0000Wooooo0_l0000U
ooooo`;o0000Boooool2o`0000_ooooo0_l00002ooooo`;o00002oooool2o`0000_ooooo0_l0000C
ooooo`00:Oooool2o`0000Kooooo0_l0000>ooooo`;o00002_ooool3o`0000_ooooo0_l0000@oooo
o`;o00004Oooool2o`0000Kooooo0_l00008ooooo`;o00000_ooool2o`0001cooooo1?l0001Coooo
o`;o00006oooool2o`0000oooooo0_l0000]ooooo`00:Oooool01?l0003oooooo`000?l00004oooo
o`;o00006oooool2o`0000_ooooo0_l0000Sooooo`;o00000_ooool2o`0000cooooo1?l0000Poooo
o`;o0000>_ooool2o`0001?ooooo0_l00002ooooo`;o00002?ooool2o`0000?ooooo0_l0000Loooo
o`;o0000;_ooool002Wooooo00Co0000ooooool0003o0000;oooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01oooool2o`0000Ko
oooo0_l00003ooooo`;o00003_ooool2o`0000?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo00GoV9RHoa0@4?l0003o<S8bolc<
c003ooooo`03onk^k_lb<S;o000000;o00000oooool01Oo^k^ko0000o`000?lb<S;ok^k^00Oooooo
0_l0000Cooooo`;o00003?ooool2o`000003oa0@4?oooooooooo00;o000000Co<S8bo`000?lb<S;o
k^k^0oooool01Oo^k^ko0000o`000?lb<S;ok^k^013ooooo0_l0000Gooooo`06odA4A?l0003o0000
oc8b<_oMgMgooooo0_l000001?lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool002Wooooo00?o0000ooooooooool03oooool2o`0001[ooooo0_l00005ooooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01oooool2o`0000Kooooo0_l0000Hooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`;o0000
0_ooool2o`00017ooooo0_l0000;ooooo`;o000000Co^[ZjoooooomgMgOo<S8b0oooool00omgMgOo
V9RHooooo`02o`0000?ooooo00GoMgMgo`000?l0003oV9RHogMgM`07ooooo`;o00005Oooool2o`00
00_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o000000GoMgMg
o`000?l0003oV9RHogMgM`0/ooooo`03ogMgMolb<S;o000000;o000000CoV9RHoooooonHV9SoMgMg
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000Yooooo`03o`000?oooooooooo00oooooo
0_l0000Jooooo`;o000000?oooooo`000?l000000_ooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@02[ooooo00?oV9RHob4Q
8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
4003ooooo`;o00000_ooool2o`00017ooooo0_l0000;ooooo`;o00000oooool01Ol0003ooooooooo
oooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01co
oooo0_l00008ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00?o000000Go410@oooo
oooooooooooooa0@400Uooooo`;o00001_ooool3o`000005oa0@4?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@00?ooooo000Yooooo`;o0000;oooool2o`0000;ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo
oooo0ol00003ooooo`;o00009?ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000002_ooooo00?oZJVYoa0@4?ooool00_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000004ooooo`;o0000
2oooool2o`0000;ooooo0ol0000@ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000009Oooool2o`0000Gooooo00GoMgMg
oc8b<_ooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`01ooooo`00:Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooooooo`?o00000oooool2o`0002Go
oooo00?oMgMgofIVI_ooool00_ooool00ol0003oooooooooo`03o`0000;ooooo00Go0000oooooooo
ooooooooo`00000Zooooo`03oa0@4?l0003o^[Zj00?ooooo0_l00002ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`02ooooo`;o00002oooool2o`0000;ooooo0ol00009
ooooo`;o00001Oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000002?ooooo0_l00004ooooo`?o000000Go<S8bolc<c?oo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`01
ooooo`00:Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@4003ooooo`04oa0@4?ooooooooooooooo`;o00003_ooool2o`0001cooooo00Go
0000oooooooooooooooooa0@4002ooooo`?o00000_ooool01Ol@413ooooooooooooooooo410@00Wo
oooo0_l0000;ooooo`;o00004oooool00onj^[[o8B4Qooooo`02ooooo`;o00000_ooool01Ol@413o
oooooooooooooooo410@00?ooooo00?o410@ooooooooool00_ooool2o`0000oooooo0_l00008oooo
o`Co00001_ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41000_ooool2
o`0000?ooooo00?o410@ooooooooool08Oooool2o`0000Cooooo0_l00005ooooo`05oa0@4?oooooo
ooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo000Yooooo`03o`000?oo
oooooooo037ooooo0_l00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01?mgMgOoV9RH
oooooonHV9P2o`0000kooooo0_l0000Hooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`09ooooo`;o00002ooo
ool2o`0000gooooo0_l000001_oooooo410@oiRHV?oooooo^[Zjo`0000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool2o`0000oooooo0_l00008
ooooo`;o00002?ooool00oo^k^koA4A4o`000004ooooo`;o000000?ooooooiRHV?mgMgL00_ooool2
o`000004oiRHV?ooooooV9RHogMgMbWooooo00Co0000oooooooooooooooo0_l000001_ooooooMgMg
oiRHV?ooooooV9RHogMgM`?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool00ol0
003oooooooooo`0<ooooo`;o00008_ooool00omEEEGo0000o`000002ooooo`;o000000Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`?o000000?o<S8bonk^k_ooool02Oooool2o`0001gooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool2o`000004oc8b
<_l0003o<S8bonk^kQ;ooooo0_l0000<ooooo`;o00000oooool2o`000006oooooonYZJWo410@o`00
0?l@413oZJVY0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0Mooooo`;o00002oooool00omgMgOo0000ooooo`03ooooo`?o000000?o<S8bonk^k_ooool0
0_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Oooooo2?l000001_ooooook^k^oc8b<_l0003o<S8b
onk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool2o`0000gooooo0_l0000W
ooooo`?o00001oooool2o`0000gooooo0_l0000/ooooo`;o00001?ooool2o`00013ooooo0_l0000<
ooooo`;o00006_ooool2o`0000_ooooo0_l0000?ooooo`;o0000AOooool2o`0001Oooooo000Yoooo
o`?o0000=_ooool2o`0003?ooooo0_l00009ooooo`;o000000?oooooo`000?l000001?ooool2o`00
0003ooooool0003o000003[ooooo0_l000000ooooooo0000o`000008ooooo`;o00005Oooool2o`00
033ooooo0_l0000Vooooo`00:Oooool3o`0003_ooooo0_l0000Tooooo`;o00002?ooool2o`0000Co
oooo0_l00003ooooo`;o000000?oooooo`000?l000001?ooool2o`00043ooooo0_l00006ooooo`?o
00005_ooool2o`0000kooooo0_l0000Nooooo`Co00003Oooool2o`0001Oooooo000Yooooo`03o`00
0?oooooooooo00Kooooo0_l00002ooooo`;o000000?oooooo`000?l000006Oooool2o`0000;ooooo
0_l0000=ooooo`;o000000?oooooo`000?l000008Oooool2o`0000Wooooo0_l00003ooooo`;o0000
3?ooool2o`0002cooooo0_l0000Jooooo`?o00001Oooool4o`0001Gooooo0_l00006ooooo`;o0000
1Oooool2o`0001Oooooo0_l0000:ooooo`;o00000oooool2o`0001Oooooo000Yooooo`03o`000?oo
oooooooo00;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000Gooooo`Co00000_oo
ool2o`00013ooooo0_l0000Kooooo`;o00003oooool2o`0001kooooo0_l0000Oooooo`;o00004_oo
ool2o`0000kooooo1?l0000Eooooo`Co00002oooool2o`0001Kooooo0_l0000;ooooo`;o00007?oo
ool0027oooooool00014o`0000Cooooo000Yooooo`03o`000?oooooooooo00Sooooo0_l0000:oooo
o`?o00002oooool3o`0000Wooooo00?o0000ooooooooool00_ooool2o`0000Gooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`04ooooo`;o00000oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool5o`0000;ooooo0_l00008oooo
o`03o`000?oooooooooo00?o00001_ooool00ol0003oooooooooo`03ooooo`?o00000_ooool2o`00
00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02?ooool2o`0000;ooooo0_l00007ooooo`;o00002oooool3o`00
00Kooooo0_l000001?oooooo0000ooooooooool2o`0000Oooooo0_l0000;ooooo`00:Oooool00ol0
003oooooooooo`04ooooo`;o00000_ooool2o`0000[ooooo0_l0000=ooooo`;o00003_ooool2o`00
00Gooooo00?o0000ooooooooool04Oooool2o`0001;ooooo0_l0000Dooooo`03o`000?oooooooooo
02Cooooo0_l00009ooooo`Go00001?ooool3o`0000Gooooo0_l00003ooooo`;o00002oooool2o`00
02?ooooo00?o0000ooooooooool00_ooool2o`0000Cooooo0_l0000`ooooo`03o`000?oooooooooo
00[ooooo000Yooooo`04o`000?ooooooooooooooo`;o000000?oooooo`000?l000007_ooool2o`00
03Wooooo0_l000000ooooooo0000o`00000?ooooo`;o0000<_ooool2o`000003ooooool0003o0000
00Oooooo0_l0000?ooooo`;o000000?oooooo`000?l000001?ooool3o`0001cooooo0_l00009oooo
o`;o0000@oooool002Wooooo00Co0000oooooooooooooooo0_l000000ooooooo0000o`00000Noooo
o`;o00009_ooool5o`0000?ooooo0_l00009ooooo`;o00003?ooool2o`0000Cooooo0_l0000<oooo
o`;o00001?ooool2o`0000Kooooo0_l0000Fooooo`;o00006oooool2o`000003ooooool0003o0000
00;ooooo0_l000000ooooooo0000o`00000:ooooo`;o00004?ooool2o`0003oooooo0_l0000=oooo
o`00:Oooool2o`0000Gooooo0_l000000ooooooo0000o`00000<ooooo`;o00004?ooool2o`0002?o
oooo1Ol00003ooooo`;o00003_ooool2o`000003ooooool0003o000000Cooooo0_l0000=ooooo`;o
00000oooool2o`0000Cooooo0_l00006ooooo`;o000000?oooooo`000?l000001_ooool2o`0002oo
oooo0_l00003ooooo`;o00001?ooool2o`0000;ooooo0_l0000;ooooo`;o00005_ooool2o`0000Oo
oooo0_l0000Sooooo`;o00003Oooool002Wooooo00?o0000ooooooooool01oooool2o`0000cooooo
0_l0000@ooooo`;o00007Oooool2o`0000?ooooo0_l0000Gooooo`;o000000?oooooo`000?l00000
4oooool2o`0000Gooooo0_l0000=ooooo`;o00001_ooool2o`0003Cooooo0_l00004ooooo`;o0000
3oooool2o`0001Kooooo0_l00003ooooo`;o00000_ooool2o`0000Sooooo0_l0000>ooooo`;o0000
6?ooool002Wooooo00?o0000ooooooooool05oooool2o`0002gooooo0_l00003ooooo`;o00001Ooo
ool2o`0001[ooooo1Ol0000:ooooo`;o00001?ooool2o`0001kooooo0_l0000Hooooo`;o0000AOoo
ool2o`0000Wooooo0_l000000ooooooo0000o`00000>ooooo`;o00006?ooool002Wooooo00?o0000
ooooooooool03Oooool2o`0000Sooooo0_l0000iooooo`;o00005Oooool2o`0000?ooooo1Ol0000:
ooooo`;o00009?ooool2o`0000Kooooo0_l0000@ooooo`;o00004oooool2o`0000gooooo0_l00003
ooooo`;o00003oooool2o`0000Sooooo0_l0000<ooooo`;o00005?ooool2o`000003ooooool0003o
000001;ooooo000Yooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo0000o`00000>oooo
o`;o00002oooool2o`0002oooooo0_l0000<ooooo`;o00006Oooool2o`0002Gooooo0_l00003oooo
o`;o00008?ooool2o`0000gooooo0_l00003ooooo`;o00001oooool2o`0000Kooooo0_l00003oooo
o`;o00000oooool2o`0001Wooooo0_l00007ooooo`;o000000?oooooo`000?l000004_ooool002Wo
oooo0_l0000;ooooo`?o00004?ooool2o`0000_ooooo0_l0000^ooooo`?o00009oooool2o`0000Oo
oooo0_l0000?ooooo`;o00004?ooool2o`0002Kooooo0_l0000Dooooo`?o00002oooool2o`0000Ko
oooo0_l0000Booooo`;o00000_ooool2o`0001kooooo000Yooooo`03o`000?oooooooooo00;ooooo
0_l00007ooooo`;o00006?ooool2o`0003?ooooo0_l0000=ooooo`;o00008_ooool2o`0000oooooo
0_l00005ooooo`;o0000<Oooool2o`0001Cooooo0_l0000?ooooo`;o00000oooool2o`0000Cooooo
0_l00004ooooo`;o00001_ooool4o`0000Sooooo0_l0000Fooooo`00:Oooool00ol0003ooooooooo
o`02ooooo`?o00005?ooool3o`0000Wooooo0_l00002ooooo`;o00003?ooool2o`0000Oooooo0_l0
000?ooooo`;o00005_ooool2o`0002Gooooo0_l0000:ooooo`;o00000oooool2o`0000;ooooo0_l0
001?ooooo`;o00001oooool2o`0000Cooooo0_l00003ooooo`;o00001?ooool2o`0000Oooooo0ol0
0008ooooo`;o00005_ooool002Wooooo00?o0000ooooooooool00oooool4o`0001;ooooo0ol0000=
ooooo`;o00003?ooool3o`0000Kooooo0_l0000?ooooo`;o0000:oooool2o`00013ooooo0_l0000:
ooooo`;o00000oooool2o`0001?ooooo0ol000000ooooooo0000o`00000<ooooo`;o00005Oooool2
o`0001Gooooo0_l000000ooooooo0000o`00000:ooooo`;o00004_ooool2o`00027ooooo000Yoooo
o`03o`000?oooooooooo00Gooooo0_l00002ooooo`;o00001Oooool2o`0000cooooo0ol0000Goooo
o`;o0000A?ooool2o`0002Cooooo0_l00002ooooo`;o00003?ooool3o`000003ooooool0003o0000
00cooooo0_l00007ooooo`;o00003?ooool2o`0001Sooooo0_l0000>ooooo`;o00000oooool2o`00
02cooooo000Yooooo`;o00002_ooool2o`0000Gooooo0_l0000<ooooo`?o0000O?ooool2o`0000Go
oooo0_l00002ooooo`;o00009oooool2o`0003Kooooo0_l00003ooooo`;o0000;?ooool002Wooooo
00?o0000ooooooooool07oooool2o`0000Kooooo0_l00004ooooo`;o00006Oooool2o`00057ooooo
1?l00006ooooo`;o0000A_ooool2o`0001?ooooo0_l0000Nooooo`;o00006?ooool002Wooooo00Co
0000oooooooooooooooo0_l0000?ooooo`;o00002oooool2o`0000Kooooo0_l00004ooooo`;o0000
3_ooool2o`0000Wooooo0ol0001@ooooo`;o00002?ooool2o`0001Wooooo0_l0000Looooo`;o0000
3Oooool2o`0001?ooooo0_l0000?ooooo`;o00003Oooool2o`0001Sooooo000Yooooo`04o`000?oo
ooooooooooooo`;o00003_ooool3o`0000;ooooo0_l0000Uooooo`;o000000?oooooo`000?l00000
1oooool2o`0002Cooooo0_l00003ooooo`;o00005oooool2o`00037ooooo0_l0000Looooo`;o0000
7_ooool2o`0001?ooooo0_l0000Wooooo`00:Oooool00ol0003oooooooooo`0Aooooo`;o00000ooo
ool2o`0001Sooooo0_l00003ooooo`;o00002Oooool2o`0001Oooooo0_l0000Dooooo`;o00000ooo
ool2o`0001Oooooo0_l0000Aooooo`;o00008oooool2o`0001;ooooo0_l0000Sooooo`;o00007ooo
ool2o`0001_ooooo000Yooooo`;o00000oooool2o`0002cooooo0_l00003ooooo`;o00001?ooool2
o`0001cooooo0_l00015ooooo`;o00008oooool2o`0001;ooooo0_l0000eooooo`;o00003Oooool2
o`0001_ooooo000Yooooo`03o`000?oooooooooo00;ooooo0_l0000/ooooo`;o00002Oooool2o`00
05Sooooo0_l0001Dooooo`;o00001?ooool5o`0001Wooooo0ol0000:ooooo`;o00007_ooool000Ko
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00Oooooo0_l00006ooooo`;o00003oooool2
o`0000?ooooo0_l00009ooooo`;o000000?oooooo`000?l000001Oooool2o`0001Wooooo0_l0000P
ooooo`;o00007?ooool2o`0002Kooooo0_l0000Iooooo`;o00004Oooool2o`0000Cooooo1Ol0000I
ooooo`;o00001_ooool2o`0000?ooooo0_l00009ooooo`;o00004oooool000Kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`07ooooo`;o00001_ooool2o`0000oooooo0_l0
0003ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Gooooo0_l000001Ooooooo0000o`00
0?l0003ooooo00;o00004_ooool3o`0000Kooooo0_l00003ooooo`;o00004_ooool2o`0000gooooo
0_l0000;ooooo`;o000000?oooooo`000?l000009Oooool2o`0000Wooooo0_l0000>ooooo`;o0000
:?ooool2o`0001?ooooo0_l0000>ooooo`;o00004oooool000Kooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0@ooooo`;o00005_ooool2o`0001?ooooo0ol000000ooooooo0000o`00000Cooooo`;o0000
1_ooool2o`0000?ooooo0_l0000Booooo`;o00003Oooool2o`0000_ooooo0_l000000ooooooo0000
o`00000`ooooo`;o00006Oooool2o`0001gooooo0_l0000hooooo`001_ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000
4?ooool2o`0005;ooooo0_l0000Jooooo`;o0000=_ooool2o`0002Wooooo0_l0001Gooooo`001_oo
ool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0>?ooool2o`0000_ooooo0_l0000Mooooo`;o
00005?ooool2o`0000Cooooo0_l0000fooooo`;o00009oooool2o`0005Wooooo0006ooooo`05oa0@
4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0>?ooool2o`0000_ooooo0_l0000cooooo`;o00005_ooool4o`0004Go
oooo0_l00004ooooo`;o0000=?ooool2o`0001?ooooo0_l0000>ooooo`001_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0L?ooool2o`00023ooooo1?l0000Jooooo`;o00000oooool2o`00
00?ooooo0_l0000Oooooo`;o0000>_ooool2o`0001?ooooo0_l0000>ooooo`001_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool0
0ol0003oooooooooo`0^ooooo`;o0000@?ooool2o`0003Kooooo0_l00006ooooo`;o00000oooool2
o`0000?ooooo0_l00020ooooo`00:Oooool2o`0001gooooo0_l0000@ooooo`;o0000EOooool2o`00
00Gooooo0_l0000Jooooo`;o00002?ooool2o`0008Sooooo000Yooooo`03o`000?oooooooooo01co
oooo0_l0001Wooooo`Co00000oooool2o`00023ooooo0_l00002ooooo`;o0000=Oooool2o`0002;o
oooo0_l0000]ooooo`00:Oooool00ol0003oooooooooo`0Jooooo`;o0000:_ooool2o`0003oooooo
0_l0000Fooooo`;o00003Oooool2o`000003ooooool0003o000003Kooooo0_l00005ooooo`;o0000
2Oooool2o`00013ooooo0_l0000]ooooo`00:Oooool00ol0003oooooooooo`0Jooooo`;o00009_oo
ool2o`0000;ooooo0_l0000Iooooo`;o0000>_ooool4o`00013ooooo0_l0000Fooooo`;o00009Ooo
ool2o`0000Wooooo0_l0000`ooooo`;o00003Oooool002Wooooo00?o0000ooooooooool04_ooool2
o`0000cooooo0_l0000Pooooo`;o00004_ooool2o`0000Kooooo0_l000000ooooooo0000o`00000?
ooooo`;o0000:Oooool2o`0000Cooooo0_l00006ooooo`;o00007?ooool2o`0000cooooo0_l0000<
ooooo`;o0000;oooool2o`0001Gooooo0_l0000=ooooo`00:Oooool2o`0000[ooooo0_l00007oooo
o`?o00002oooool2o`0002Sooooo0_l0000:ooooo`;o00001_ooool2o`0001;ooooo0_l0000Uoooo
o`;o00001oooool3o`0000Kooooo0_l0000Zooooo`;o00002oooool3o`0002oooooo0_l00005oooo
o`;o00007Oooool002Wooooo00?o0000ooooooooool02Oooool2o`0000Sooooo0_l0000>ooooo`;o
00001Oooool2o`0001kooooo0_l00005ooooo`;o00004oooool2o`0002gooooo0_l00002ooooo`;o
00001oooool2o`0000oooooo0_l0000@ooooo`;o00003?ooool2o`0000Cooooo0_l00009ooooo`;o
0000=oooool2o`0000oooooo0_l0000<ooooo`00:Oooool00ol0003oooooooooo`0>ooooo`;o0000
1?ooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0001cooooo0_l00007ooooo`;o0000
2_ooool2o`0000Oooooo0_l00003ooooo`;o0000:?ooool4o`00017ooooo0_l00007ooooo`;o0000
4?ooool2o`0000Sooooo0_l00002ooooo`;o00001?ooool2o`0001Sooooo0_l0000Vooooo`;o0000
4Oooool2o`0000cooooo000Yooooo`03o`000?oooooooooo00kooooo0_l00004ooooo`;o00001Ooo
ool3o`0000oooooo0_l0000Iooooo`;o00001_ooool2o`0000[ooooo1_l00009ooooo`;o0000:_oo
ool2o`0000gooooo0_l00002ooooo`;o00008oooool2o`0000Gooooo0_l0000Kooooo`;o00005_oo
ool2o`0000Oooooo0_l00005ooooo`;o00007oooool002Wooooo00?o0000ooooooooool07?ooool2
o`0000oooooo0_l0000Qooooo`;o00002_ooool2o`000004ooooool0003o0000o`0000?ooooo0_l0
0005ooooo`;o0000>?ooool2o`0002kooooo0_l0000>ooooo`;o00008oooool2o`0000Oooooo0_l0
000Vooooo`00:Oooool2o`00057ooooo0_l0000Cooooo`;o00001Oooool2o`0007Sooooo0_l0001D
ooooo`00:Oooool00ol0003oooooooooo`0Mooooo`;o00003?ooool2o`000?oooooo4?ooool002Wo
oooo00?o0000ooooooooool07Oooool2o`0000cooooo0_l0000<ooooo`;o0000ooooool2ooooo`00
:Oooool00ol0003oooooooooo`0iooooo`;o0000ooooool2ooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000kooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00?ooooo0ol0003oooooocgooooo000>ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`3oooooocgooooo000>ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0?oooooo2?ooool2o`0003?ooooo000>ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo2?oo
ool2o`0003?ooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0
003oooooobcooooo0_l0000@ooooo`00:Oooool00ol0003oooooooooo`13ooooo`;o0000iOooool2
o`00013ooooo000Yooooo`03o`000?oooooooooo04?ooooo0_l0003gooooo`00:Oooool00ol0003o
ooooooooo`3Xooooo`;o0000D_ooool002Wooooo00?o0000ooooooooool0j?ooool2o`0005;ooooo
000Yooooo`;o0000F?ooool2o`000>?ooooo000Yooooo`03o`000?oooooooooo05Oooooo0_l0001M
ooooo`;o0000Q?ooool002Wooooo00?o0000ooooooooool0]_ooool2o`0008Cooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?oooooooooo
ooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003o
ooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0
003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooo
oooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oo
oooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo
?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo
0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`007oooool4o`00
0003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool0
1Oooool3o`000?oooooo?Oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`007oooool00omEEEGoIVIVo`00003oooooodOooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .31128 Mdot
.02762 .26075 Mdot
.02952 .31171 Mdot
.03143 .27738 Mdot
.03333 .31885 Mdot
.03524 .37381 Mdot
.03714 .30504 Mdot
.03905 .4324 Mdot
.04095 .42878 Mdot
.04286 .30432 Mdot
.04476 .3407 Mdot
.04667 .40704 Mdot
.04857 .23763 Mdot
.05048 .31775 Mdot
.05238 .37167 Mdot
.05429 .25704 Mdot
.05619 .36249 Mdot
.0581 .23872 Mdot
.06 .35528 Mdot
.0619 .36506 Mdot
.06381 .25963 Mdot
.06571 .23648 Mdot
.06762 .24774 Mdot
.06952 .24741 Mdot
.07143 .34789 Mdot
.07333 .24837 Mdot
.07524 .35137 Mdot
.07714 .35161 Mdot
.07905 .38208 Mdot
.08095 .24618 Mdot
.08286 .29997 Mdot
.08476 .4345 Mdot
.08667 .42506 Mdot
.08857 .37947 Mdot
.09048 .38568 Mdot
.09238 .37417 Mdot
.09429 .42963 Mdot
.09619 .35295 Mdot
.0981 .40596 Mdot
.1 .41271 Mdot
.1019 .37158 Mdot
.10381 .38284 Mdot
.10571 .38218 Mdot
.10762 .32443 Mdot
.10952 .3433 Mdot
.11143 .28368 Mdot
.11333 .33008 Mdot
.11524 .43914 Mdot
.11714 .27412 Mdot
.11905 .39255 Mdot
.12095 .43791 Mdot
.12286 .41088 Mdot
.12476 .3468 Mdot
.12667 .38284 Mdot
.12857 .38774 Mdot
.13048 .42573 Mdot
.13238 .42685 Mdot
.13429 .3568 Mdot
.13619 .43598 Mdot
.1381 .34914 Mdot
.14 .26851 Mdot
.1419 .273 Mdot
.14381 .41086 Mdot
.14571 .33656 Mdot
.14762 .40569 Mdot
.14952 .43349 Mdot
.15143 .30568 Mdot
.15333 .25844 Mdot
.15524 .35561 Mdot
.15714 .26434 Mdot
.15905 .3521 Mdot
.16095 .32269 Mdot
.16286 .31705 Mdot
.16476 .28436 Mdot
.16667 .41088 Mdot
.16857 .30011 Mdot
.17048 .34734 Mdot
.17238 .24867 Mdot
.17429 .40447 Mdot
.17619 .30241 Mdot
.1781 .33817 Mdot
.18 .24462 Mdot
.1819 .28091 Mdot
.18381 .38351 Mdot
.18571 .43535 Mdot
.18762 .25826 Mdot
.18952 .316 Mdot
.19143 .27892 Mdot
.19333 .34266 Mdot
.19524 .25983 Mdot
.19714 .33911 Mdot
.19905 .2519 Mdot
.20095 .33487 Mdot
.20286 .29053 Mdot
.20476 .33493 Mdot
.20667 .23211 Mdot
.20857 .31603 Mdot
.21048 .43332 Mdot
.21238 .35195 Mdot
.21429 .3349 Mdot
.21619 .29417 Mdot
.2181 .32205 Mdot
.22 .39758 Mdot
.2219 .30799 Mdot
.22381 .30216 Mdot
.22571 .38068 Mdot
.22762 .36354 Mdot
.22952 .35351 Mdot
.23143 .33492 Mdot
.23333 .2736 Mdot
.23524 .30739 Mdot
.23714 .28987 Mdot
.23905 .43352 Mdot
.24095 .35802 Mdot
.24286 .42697 Mdot
.24476 .26871 Mdot
.24667 .25519 Mdot
.24857 .44001 Mdot
.25048 .43891 Mdot
.25238 .42903 Mdot
.25429 .23983 Mdot
.25619 .30598 Mdot
.2581 .27089 Mdot
.26 .38048 Mdot
.2619 .26961 Mdot
.26381 .26631 Mdot
.26571 .37054 Mdot
.26762 .22358 Mdot
.26952 .25078 Mdot
.27143 .27953 Mdot
.27333 .23937 Mdot
.27524 .27433 Mdot
.27714 .39298 Mdot
.27905 .37846 Mdot
.28095 .37955 Mdot
.28286 .39289 Mdot
.28476 .42342 Mdot
.28667 .37957 Mdot
.28857 .31703 Mdot
.29048 .41326 Mdot
.29238 .37586 Mdot
.29429 .22697 Mdot
.29619 .31927 Mdot
.2981 .35651 Mdot
.3 .36169 Mdot
.3019 .35972 Mdot
.30381 .43748 Mdot
.30571 .45084 Mdot
.30762 .33197 Mdot
.30952 .27505 Mdot
.31143 .34268 Mdot
.31333 .31234 Mdot
.31524 .3536 Mdot
.31714 .24499 Mdot
.31905 .32117 Mdot
.32095 .34655 Mdot
.32286 .42193 Mdot
.32476 .4105 Mdot
.32667 .4362 Mdot
.32857 .42994 Mdot
.33048 .42224 Mdot
.33238 .2494 Mdot
.33429 .40119 Mdot
.33619 .40158 Mdot
.3381 .36558 Mdot
.34 .37472 Mdot
.3419 .28423 Mdot
.34381 .43665 Mdot
.34571 .30765 Mdot
.34762 .35535 Mdot
.34952 .41749 Mdot
.35143 .39066 Mdot
.35333 .31707 Mdot
.35524 .35392 Mdot
.35714 .30067 Mdot
.35905 .33407 Mdot
.36095 .41533 Mdot
.36286 .22967 Mdot
.36476 .34652 Mdot
.36667 .26533 Mdot
.36857 .39269 Mdot
.37048 .4105 Mdot
.37238 .40151 Mdot
.37429 .263 Mdot
.37619 .36847 Mdot
.3781 .30296 Mdot
.38 .42548 Mdot
.3819 .22575 Mdot
.38381 .43966 Mdot
.38571 .40131 Mdot
.38762 .38331 Mdot
.38952 .32158 Mdot
.39143 .35779 Mdot
.39333 .33442 Mdot
.39524 .26971 Mdot
.39714 .43287 Mdot
.39905 .36796 Mdot
.40095 .39668 Mdot
.40286 .29279 Mdot
.40476 .25839 Mdot
.40667 .37054 Mdot
.40857 .27186 Mdot
.41048 .27044 Mdot
.41238 .3232 Mdot
.41429 .30911 Mdot
.41619 .27291 Mdot
.4181 .27605 Mdot
.42 .32709 Mdot
.4219 .36663 Mdot
.42381 .30395 Mdot
.42571 .30542 Mdot
.42762 .33971 Mdot
.42952 .23525 Mdot
.43143 .24901 Mdot
.43333 .30979 Mdot
.43524 .26518 Mdot
.43714 .27873 Mdot
.43905 .24985 Mdot
.44095 .39704 Mdot
.44286 .29365 Mdot
.44476 .33702 Mdot
.44667 .42029 Mdot
.44857 .25851 Mdot
.45048 .43437 Mdot
.45238 .29684 Mdot
.45429 .35245 Mdot
.45619 .26657 Mdot
.4581 .32989 Mdot
.46 .28211 Mdot
.4619 .32478 Mdot
.46381 .37207 Mdot
.46571 .31032 Mdot
.46762 .26101 Mdot
.46952 .27227 Mdot
.47143 .29254 Mdot
.47333 .31589 Mdot
.47524 .34979 Mdot
.47714 .30748 Mdot
.47905 .35408 Mdot
.48095 .30204 Mdot
.48286 .25315 Mdot
.48476 .2814 Mdot
.48667 .26713 Mdot
.48857 .38258 Mdot
.49048 .31872 Mdot
.49238 .35191 Mdot
.49429 .43824 Mdot
.49619 .33319 Mdot
.4981 .42352 Mdot
.5 .3515 Mdot
.5019 .35011 Mdot
.50381 .40958 Mdot
.50571 .36621 Mdot
.50762 .26882 Mdot
.50952 .33449 Mdot
.51143 .4265 Mdot
.51333 .24813 Mdot
.51524 .35357 Mdot
.51714 .39035 Mdot
.51905 .29667 Mdot
.52095 .4227 Mdot
.52286 .43813 Mdot
.52476 .2932 Mdot
.52667 .34957 Mdot
.52857 .35613 Mdot
.53048 .2677 Mdot
.53238 .31836 Mdot
.53429 .31258 Mdot
.53619 .33731 Mdot
.5381 .36509 Mdot
.54 .38363 Mdot
.5419 .25981 Mdot
.54381 .36934 Mdot
.54571 .38851 Mdot
.54762 .2958 Mdot
.54952 .29743 Mdot
.55143 .42002 Mdot
.55333 .26207 Mdot
.55524 .34791 Mdot
.55714 .43731 Mdot
.55905 .33347 Mdot
.56095 .35682 Mdot
.56286 .39579 Mdot
.56476 .26874 Mdot
.56667 .28414 Mdot
.56857 .42993 Mdot
.57048 .40516 Mdot
.57238 .35382 Mdot
.57429 .31635 Mdot
.57619 .30724 Mdot
.5781 .33917 Mdot
.58 .2746 Mdot
.5819 .33335 Mdot
.58381 .22742 Mdot
.58571 .4346 Mdot
.58762 .38531 Mdot
.58952 .4331 Mdot
.59143 .28127 Mdot
.59333 .43387 Mdot
.59524 .26687 Mdot
.59714 .32454 Mdot
.59905 .37561 Mdot
.60095 .46118 Mdot
.60286 .2814 Mdot
.60476 .38991 Mdot
.60667 .27726 Mdot
.60857 .43666 Mdot
.61048 .36388 Mdot
.61238 .33152 Mdot
.61429 .43582 Mdot
.61619 .24863 Mdot
.6181 .28394 Mdot
.62 .23557 Mdot
.6219 .36453 Mdot
.62381 .24127 Mdot
.62571 .34617 Mdot
.62762 .26485 Mdot
.62952 .32811 Mdot
.63143 .38132 Mdot
.63333 .40195 Mdot
.63524 .26532 Mdot
.63714 .3964 Mdot
.63905 .30156 Mdot
.64095 .22845 Mdot
.64286 .26086 Mdot
.64476 .38182 Mdot
.64667 .3837 Mdot
.64857 .41546 Mdot
.65048 .3366 Mdot
.65238 .28611 Mdot
.65429 .29333 Mdot
.65619 .36141 Mdot
.6581 .42553 Mdot
.66 .42624 Mdot
.6619 .33641 Mdot
.66381 .23595 Mdot
.66571 .27874 Mdot
.66762 .32308 Mdot
.66952 .27769 Mdot
.67143 .37795 Mdot
.67333 .37489 Mdot
.67524 .25021 Mdot
.67714 .31057 Mdot
.67905 .32405 Mdot
.68095 .25328 Mdot
.68286 .24409 Mdot
.68476 .33581 Mdot
.68667 .42319 Mdot
.68857 .35055 Mdot
.69048 .37842 Mdot
.69238 .23733 Mdot
.69429 .33055 Mdot
.69619 .25356 Mdot
.6981 .22887 Mdot
.7 .41262 Mdot
.7019 .43293 Mdot
.70381 .37529 Mdot
.70571 .26714 Mdot
.70762 .37274 Mdot
.70952 .38582 Mdot
.71143 .31619 Mdot
.71333 .4114 Mdot
.71524 .23368 Mdot
.71714 .32159 Mdot
.71905 .39169 Mdot
.72095 .39356 Mdot
.72286 .38287 Mdot
.72476 .32148 Mdot
.72667 .30733 Mdot
.72857 .37186 Mdot
.73048 .42552 Mdot
.73238 .32067 Mdot
.73429 .31735 Mdot
.73619 .26287 Mdot
.7381 .37137 Mdot
.74 .29871 Mdot
.7419 .43219 Mdot
.74381 .30077 Mdot
.74571 .43187 Mdot
.74762 .42285 Mdot
.74952 .2466 Mdot
.75143 .42996 Mdot
.75333 .23997 Mdot
.75524 .3586 Mdot
.75714 .43417 Mdot
.75905 .43011 Mdot
.76095 .35133 Mdot
.76286 .32123 Mdot
.76476 .3256 Mdot
.76667 .3348 Mdot
.76857 .29083 Mdot
.77048 .4041 Mdot
.77238 .26667 Mdot
.77429 .29157 Mdot
.77619 .29249 Mdot
.7781 .2499 Mdot
.78 .35161 Mdot
.7819 .43989 Mdot
.78381 .28422 Mdot
.78571 .26564 Mdot
.78762 .40016 Mdot
.78952 .3732 Mdot
.79143 .3272 Mdot
.79333 .37376 Mdot
.79524 .3379 Mdot
.79714 .33907 Mdot
.79905 .27562 Mdot
.80095 .42361 Mdot
.80286 .4071 Mdot
.80476 .35101 Mdot
.80667 .32466 Mdot
.80857 .34326 Mdot
.81048 .25619 Mdot
.81238 .35173 Mdot
.81429 .30244 Mdot
.81619 .35881 Mdot
.8181 .30603 Mdot
.82 .35433 Mdot
.8219 .26904 Mdot
.82381 .30742 Mdot
.82571 .37816 Mdot
.82762 .35064 Mdot
.82952 .32895 Mdot
.83143 .32404 Mdot
.83333 .41537 Mdot
.83524 .2932 Mdot
.83714 .3863 Mdot
.83905 .36392 Mdot
.84095 .32657 Mdot
.84286 .26886 Mdot
.84476 .35479 Mdot
.84667 .33284 Mdot
.84857 .23238 Mdot
.85048 .28575 Mdot
.85238 .40788 Mdot
.85429 .32338 Mdot
.85619 .33003 Mdot
.8581 .42043 Mdot
.86 .36676 Mdot
.8619 .34505 Mdot
.86381 .23772 Mdot
.86571 .33109 Mdot
.86762 .32062 Mdot
.86952 .29859 Mdot
.87143 .32618 Mdot
.87333 .35008 Mdot
.87524 .28665 Mdot
.87714 .2555 Mdot
.87905 .30647 Mdot
.88095 .38314 Mdot
.88286 .38182 Mdot
.88476 .33737 Mdot
.88667 .26475 Mdot
.88857 .27001 Mdot
.89048 .43104 Mdot
.89238 .26424 Mdot
.89429 .39882 Mdot
.89619 .27232 Mdot
.8981 .33411 Mdot
.9 .36878 Mdot
.9019 .32675 Mdot
.90381 .36834 Mdot
.90571 .2206 Mdot
.90762 .29452 Mdot
.90952 .42516 Mdot
.91143 .37122 Mdot
.91333 .33952 Mdot
.91524 .43359 Mdot
.91714 .26468 Mdot
.91905 .36249 Mdot
.92095 .37594 Mdot
.92286 .29828 Mdot
.92476 .35265 Mdot
.92667 .25397 Mdot
.92857 .37887 Mdot
.93048 .29422 Mdot
.93238 .37425 Mdot
.93429 .30657 Mdot
.93619 .37975 Mdot
.9381 .29895 Mdot
.94 .32345 Mdot
.9419 .2581 Mdot
.94381 .38393 Mdot
.94571 .38408 Mdot
.94762 .27044 Mdot
.94952 .24819 Mdot
.95143 .433 Mdot
.95333 .32658 Mdot
.95524 .3172 Mdot
.95714 .35754 Mdot
.95905 .34518 Mdot
.96095 .31579 Mdot
.96286 .41758 Mdot
.96476 .31148 Mdot
.96667 .26887 Mdot
.96857 .43158 Mdot
.97048 .36463 Mdot
.97238 .35551 Mdot
.97429 .3851 Mdot
.97619 .40358 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo6Oooool2o`0002;ooooo0006ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`1;ooooo`;o0000boooool2o`0002;ooooo0006ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0Boooool2o`0000Kooooo0_l0000Jooooo`;o0000?ooo
ool2o`0008[ooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Cooooo`;o00005?oo
ool2o`0000Cooooo0_l0000oooooo`;o00004Oooool2o`00013ooooo0_l0001Uooooo`001_ooool0
1Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8boooo
o`04ooooo`?o0000=oooool2o`00033ooooo0_l0001Hooooo`;o00004?ooool2o`0000Cooooo0_l0
000Xooooo`;o0000=Oooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00[ooooo
0_l0000[ooooo`;o0000A_ooool2o`0003_ooooo0_l0000<ooooo`;o00003oooool2o`0002Sooooo
0_l0000eooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo0_l000001?oooooo0000
o`000?ooool2o`0003[ooooo0_l00005ooooo`;o0000<?ooool2o`0003_ooooo0_l0000<ooooo`;o
00001oooool2o`0001;ooooo0_l0000Qooooo`;o0000<?ooool000Kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Cooooo0_l000000ooooooo0000o`00000mooooo`;o00001Oooool2o`00
06kooooo0_l0000Dooooo`;o00004_ooool2o`00027ooooo0_l0000`ooooo`001_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool0
0ol0003oooooooooo`0?ooooo`;o00007Oooool2o`0002_ooooo0_l0001Pooooo`;o00004Oooool2
o`0001Cooooo0_l0001Dooooo`00:Oooool2o`0000_ooooo1?l000000ooooooo0000o`00000Koooo
o`Co0000:oooool2o`0000;ooooo0_l0000Nooooo`;o00006Oooool2o`0001oooooo0_l0000Coooo
o`;o00005?ooool2o`0003kooooo0_l0000Dooooo`00:Oooool00ol0003oooooooooo`0:ooooo`Co
00007_ooool2o`0000Oooooo0_l0000Dooooo`;o00004_ooool2o`0001kooooo0_l000000ooooooo
0000o`00000Fooooo`;o00007oooool2o`00017ooooo0_l0000Oooooo`;o0000=Oooool2o`0001Co
oooo000Yooooo`03o`000?oooooooooo03Gooooo0_l0000=ooooo`;o00001Oooool2o`0003Gooooo
0_l0000<ooooo`;o0000??ooool4o`0000;ooooo0_l0000Iooooo`;o00007_ooool2o`0000kooooo
0_l0000Kooooo`00:Oooool00ol0003oooooooooo`06ooooo`;o00007_ooool2o`0000Wooooo0_l0
000Aooooo`;o0000<Oooool2o`0000cooooo0_l00009ooooo`;o0000?_ooool2o`0000;ooooo0_l0
000Sooooo`;o00005?ooool2o`0000kooooo0_l00002ooooo`;o00005oooool002Wooooo0_l00007
ooooo`;o000000?oooooo`000?l000006oooool2o`0000Wooooo1?l00012ooooo`;o00003?ooool2
o`0000Cooooo0_l0000Fooooo`;o00000_ooool2o`0001[ooooo0_l0000dooooo`;o0000:?ooool2
o`0001Oooooo000Yooooo`;o00002_ooool2o`0001cooooo0_l0000:ooooo`;o0000>?ooool2o`00
01;ooooo0_l00008ooooo`;o00005_ooool2o`0000;ooooo0_l0000Eooooo`;o00000oooool2o`00
01cooooo0_l0000_ooooo`Co00001_ooool2o`0001kooooo000Yooooo`03o`000?oooooooooo02Oo
oooo0_l0000Pooooo`;o00008?ooool4o`0001;ooooo0_l00004ooooo`;o00002?ooool2o`0000co
oooo0_l0000Cooooo`;o00002?ooool2o`000003ooooool0003o000001Gooooo0_l00007ooooo`;o
00002_ooool2o`0000;ooooo0_l0000Oooooo`Co00001_ooool2o`0001kooooo000Yooooo`03o`00
0?oooooooooo02;ooooo0_l0000<ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kP?ooooo00Cok^k^oc8b<_l0003o<S8b0_l00003ooooo`?o00008?ooool7o`0000;ooooo0_l0
00000olb<S;o0000oc8b<P02o`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o0000
2?ooool2o`0000Gooooo0_l00005ooooo`;o00002Oooool3o`000003oc8b<_o<c<cooooo00;ooooo
00Gok^k^oc8b<_l0003o0000onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool2o`00
01Gooooo0_l0000?ooooo`;o000000Ko410@ooooool0003o0000onk^k_lb<S82o`00000:onk^k_oo
ooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^ooooo`;o00001Oooool2o`0000cooooo0_l0000A
ooooo`?o000000?o<S8bomgMgOooool00_l000001?lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool002Wooooo00?o0000ooooooooool06_ooool2o`0000Kooooo0_l0
000>ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`04ogMg
Mol0003o0000oiRHV0;o00000oooool3o`0000;ooooo0_l0000Nooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@00_ooool2o`000003oiRHV?oooooo000000?o000000KoooooogMgMonHV9SooooooiRHV?mg
MgL:ooooo`;o00002_ooool2o`00013ooooo0_l000000oooooooMgMgoc8b<P02o`000006oooooomg
MgOoV9RHoooooonHV9SoMgMg0oooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00KoMgMgoiRHV?ooooooV9RHogMg
Moooool2o`0000Gooooo0_l0000<ooooo`;o000000?oooooo`000?l000003_ooool2o`000004oooo
oomgMgOo<S8booooo`;o000000CoV9RHoooooonHV9SoMgMg0oooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo000Yooooo`04o`000?oooooo0000o`0001Wooooo0_l00006ooooo`;o00003_ooool0
0ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413o0000o`00
0?oooooo410@00Wooooo0_l00009ooooo`;o00005?ooool00onHV9So8B4Qonk^kP04ooooo`03oa0@
4?oooooooooo00Go000000Go410@oooooooooooooooooa0@400:ooooo`;o00008?ooool3o`000003
ooooool@413ooooo00;ooooo00Go410@ooooool0003o0000oa0@4003ooooo`03oa0@4?oooooooooo
00_ooooo0_l0000Iooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00;ooooo0_l00003
ooooo`03oa0@4?oooooooooo01Oooooo0_l0000Booooo`04o`000?oooooooooooa0@40?ooooo00Go
410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo007ooooo000Yooooo`Co0000<Ooo
ool2o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00002?ooool2o`0000[ooooo0_l0000Eooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Ko0000oooooooo
ooooooooo`000?ooool3o`0000?ooooo0_l0000Zooooo`03ojVYZOl@413ooooo00;ooooo00Ko0000
ooooooooooooooooo`000?ooool3o`0000?ooooo00?o0000ooooooooool02_ooool3o`0001Wooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000000;ooooo0_l00003oooo
o`03o`000?oooooooooo02[ooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`01ooooo`00:Oooool00ol0003oooooooooo`0H
ooooo`;o00005Oooool2o`000003ooooool0003o000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000002?ooool2o`0002;ooooo00?oMgMgofIVI_ooool0
0_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooooooo0_l00006oooo
o`;o00001Oooool2o`0001[ooooo00?o410@o`000?nj^[X00oooool3o`000003ooooool0003o0000
00;ooooo0ol000000ooooooo0000ooooo`0;ooooo`;o00006_ooool01?oMgMgoEEEEooooool00004
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000002Wooooo
00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo000Yooooo`03o`000?oooooooooo01Sooooo0_l0000@oooo
o`;o00000oooool2o`000003ooooool0003ooooo00?ooooo00Go410@oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@41007oooool2o`0000cooooo00Go0000oooooooooooooooo
oa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`05ooooo`;o
00001Oooool2o`0001Wooooo0_l000000onj^[[o8B4Qooooo`02ooooo`04oa0@4?l0003o0000oooo
o`;o00000_ooool01Ol@413o0000o`000?oooooo410@00Oooooo0_l0000Pooooo`03ogMgMoo<c<co
000000Cooooo00Go410@ooooool0003o0000oa0@4003ooooo`05oa0@4?ooooooooooooooool@4100
2_ooool2o`0000Kooooo0_l0000Eooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool002Wooooo00?o0000oooooooo
ool0:_ooool2o`0000Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?l0003o0000ogMgM`0Oooooo`;o00002?ooool01Ol0003o^[ZjoooooonH
V9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0:?ooool01Ol@413o0000o`000?nj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01oooool2o`00023ooooo00?ok^k^odA4A?l000001?oo
ool01OmgMgOoV9RHo`000?l0003oMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0:ooooo`;o
00001_ooool2o`0001Gooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool00ol0003oooooooooo`0`oooo
o`03oeEEEOmVIVKo000000?ooooo0_l000001?lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o
0000o`000?o^k^h0:Oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^o`000?l0003o
<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02_ooool2o`0000oooooo0_l0000;oooo
o`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0Zooooo`03ogMgMol0003ooooo00Co000000Co<S8bo`000?lb<S;o
k^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_l0000Rooooo`Co00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool2
o`0003Oooooo0_l00002ooooo`;o0000>_ooool2o`0000_ooooo0_l00007ooooo`;o00003oooool2
o`0000Kooooo0_l0000Pooooo`;o00008oooool4o`00017ooooo0_l0000Eooooo`;o00001_ooool2
o`0001[ooooo000Yooooo`03o`000?oooooooooo03[ooooo0_l00017ooooo`;o000000?oooooo`00
0?l000005?ooool2o`0000Oooooo0_l0000Pooooo`;o00006_ooool2o`0002Oooooo0_l0000:oooo
o`;o00000oooool2o`000003ooooool0003o000000;o00006?ooool002Wooooo00?o0000oooooooo
ool03oooool2o`0001[ooooo1?l0000>ooooo`;o0000:?ooool2o`0001gooooo0_l00007ooooo`;o
00002oooool2o`0000Oooooo0_l0000Kooooo`;o00007oooool3o`0001Cooooo0_l0000@ooooo`;o
00003oooool2o`0000?ooooo0_l0000Hooooo`00:Oooool01?l0003oooooooooooooool3o`0000_o
oooo0_l0000Dooooo`;o00001?ooool4o`0000kooooo0_l0000Xooooo`;o00001Oooool2o`0000go
oooo0_l0000@ooooo`;o0000<Oooool2o`00023ooooo0_l0000Dooooo`;o0000@?ooool002Wooooo
00Co0000oooooooooooooooo0ol0000Qooooo`;o00005Oooool2o`0000;ooooo0_l00005ooooo`;o
00006oooool2o`0000Sooooo0_l0000=ooooo`;o00003oooool2o`0001kooooo0_l0000^ooooo`;o
00007?ooool4o`0000oooooo0_l0000@ooooo`;o00006Oooool0027oooooool00014o`0000Cooooo
000Yooooo`?o00002Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`;o00001?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00[ooooo00Co0000ooooool0003o00001?ooool2o`0000;ooooo
00?o0000ooooooooool00oooool2o`0000Cooooo00?o0000ooooooooool02Oooool01?l0003ooooo
ooooooooool2o`0000Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo0ol0000:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo0_l00002ooooo`03
o`000?oooooooooo00[ooooo000Yooooo`03o`000?oooooooooo00Gooooo0_l0000Rooooo`;o0000
1oooool2o`0000Cooooo0ol0000Fooooo`;o00001_ooool2o`0000_ooooo0_l0000@ooooo`03o`00
0?oooooooooo01;ooooo0_l0000Aooooo`;o00002oooool2o`0000Kooooo00?o0000ooooooooool0
8Oooool2o`0000Kooooo0_l0000?ooooo`03o`000?oooooooooo03?ooooo1?l00003ooooo`03o`00
0?oooooooooo00[ooooo000Yooooo`04o`000?oooooo0000o`0000Cooooo0_l0000Rooooo`;o0000
1oooool2o`0000Cooooo0_l0000Gooooo`;o000000?oooooo`000?l000001Oooool2o`0000Wooooo
0_l0000Uooooo`;o00000oooool2o`0000cooooo0_l0000;ooooo`;o0000:_ooool2o`0000Gooooo
0ol00007ooooo`;o00008?ooool2o`0001[ooooo1?l0000@ooooo`00:Oooool01?l0003oooooo`00
0?l0000Wooooo`;o00004Oooool2o`0001Oooooo0_l00005ooooo`;o00005Oooool2o`0000Gooooo
0_l0000Gooooo`;o00003?ooool2o`0002Wooooo0_l00002ooooo`;o00002_ooool2o`000003oooo
ool0003o000000;o00002?ooool2o`0001Cooooo0_l00005ooooo`;o00000oooool2o`0001Gooooo
0_l0000Gooooo`00:Oooool2o`0001Sooooo0_l0000?ooooo`;o00004Oooool2o`0003Gooooo0_l0
0005ooooo`;o000000?oooooo`000?l000002oooool2o`0002[ooooo0_l0000Dooooo`;o00000_oo
ool2o`0000[ooooo0_l000000ooooooo0000o`00000;ooooo`;o00001_ooool2o`0000?ooooo0_l0
0006ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l00008ooooo`;o00002_oo
ool2o`0000;ooooo0_l0000Cooooo`00:Oooool00ol0003oooooooooo`0Gooooo`Co0000HOooool2
o`0000[ooooo0ol0000Zooooo`;o00002?ooool2o`0001?ooooo0_l0000Eooooo`;o00001_ooool2
o`0000?ooooo0_l00005ooooo`;o00000_ooool2o`0000?ooooo0_l00003ooooo`;o00002?ooool2
o`0000kooooo0_l0000Cooooo`00:Oooool00ol0003oooooooooo`0Iooooo`;o0000?Oooool2o`00
02kooooo0_l0000:ooooo`;o00004_ooool2o`0000Kooooo0_l00008ooooo`;o00000oooool2o`00
01?ooooo0_l0000Yooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`;o0000;oooool0
02Wooooo00?o0000ooooooooool08oooool2o`00013ooooo0ol00002ooooo`;o00000oooool2o`00
01Oooooo0_l0000>ooooo`;o00002Oooool2o`0001oooooo0_l00002ooooo`;o00003_ooool2o`00
00Kooooo0_l00008ooooo`;o00002_ooool2o`000003ooooool0003o000000Kooooo0_l0000Hoooo
o`;o00006?ooool2o`0000Cooooo0_l00008ooooo`;o00009Oooool002Wooooo00?o0000oooooooo
ool08oooool2o`0000Wooooo0_l00004ooooo`Co00000_ooool2o`0000?ooooo0_l0000Wooooo`;o
00002Oooool2o`0000Wooooo0_l00004ooooo`;o00004_ooool2o`0000Oooooo0_l0000;ooooo`;o
00005_ooool2o`000003ooooool0003o000000Kooooo0_l0000Hooooo`;o00001oooool3o`0001[o
oooo0_l00002ooooo`;o00000oooool2o`00023ooooo000Yooooo`;o00001?ooool2o`0002Wooooo
0_l00003ooooo`?o00008oooool2o`0002?ooooo0_l00004ooooo`;o00006oooool2o`0000_ooooo
0_l00014ooooo`?o00006_ooool2o`0000Oooooo0_l0000Pooooo`00:Oooool00ol0003ooooooooo
o`03ooooo`;o00004oooool2o`0001Wooooo0_l0000Tooooo`;o0000W_ooool2o`0000oooooo0_l0
000Mooooo`;o00004Oooool002Wooooo00?o0000ooooooooool03?ooool2o`0000[ooooo0_l00003
ooooo`;o00000_ooool2o`0000Sooooo0_l0000_ooooo`;o00003?ooool2o`0003_ooooo0_l0000E
ooooo`;o0000>Oooool2o`0000oooooo0_l0000Mooooo`;o00004Oooool002Wooooo00?o0000oooo
ooooool03?ooool3o`0000kooooo0_l00002ooooo`;o00001Oooool2o`000003ooooool0003o0000
00cooooo0_l0000Qooooo`;o00003?ooool2o`00027ooooo0_l00004ooooo`Go00001_ooool2o`00
00Oooooo0_l0000Eooooo`;o00004_ooool2o`0001Gooooo0_l00004ooooo`;o00001_ooool2o`00
0003ooooool0003o000000?ooooo0_l0000<ooooo`;o0000;Oooool002Wooooo00?o0000oooooooo
ool02?ooool2o`0000?ooooo0_l00005ooooo`;o00004_ooool2o`0000oooooo0_l00003ooooo`;o
00006_ooool2o`0000Sooooo0_l000000ooooooo0000o`00000Nooooo`;o00001?ooool4o`0000;o
oooo1Ol00002ooooo`;o00000_ooool2o`0000gooooo0_l0000Sooooo`;o00005Oooool2o`0000Co
oooo0_l00006ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000003ooooo`;o
00001oooool2o`0000oooooo0_l0000Looooo`00:Oooool2o`0000Wooooo0_l0000:ooooo`;o0000
2_ooool2o`0000Gooooo0_l0000Eooooo`;o00000_ooool2o`00013ooooo0_l00004ooooo`;o0000
2?ooool2o`000003ooooool0003o000000Wooooo0_l0000Cooooo`;o00001_ooool2o`0000Wooooo
0_l00003ooooo`;o00002?ooool2o`0000;ooooo0_l0001=ooooo`;o00001_ooool2o`0001Sooooo
0_l00008ooooo`;o00000oooool2o`0000gooooo000Yooooo`03o`000?oooooooooo023ooooo0_l0
0005ooooo`;o00006Oooool2o`00013ooooo1?l0000Jooooo`;o0000:oooool2o`0000Sooooo0_l0
000Mooooo`;o00007Oooool2o`0001;ooooo0_l0000[ooooo`;o00000oooool2o`0000gooooo000Y
ooooo`03o`000?oooooooooo00Oooooo0_l0000eooooo`;o00005Oooool3o`00067ooooo0_l00002
ooooo`;o00002Oooool2o`0001gooooo0_l0000Booooo`;o00001Oooool2o`0001Sooooo0_l0000?
ooooo`;o00003Oooool002Wooooo00?o0000ooooooooool01oooool4o`0003?ooooo0_l0000Qoooo
o`;o00006Oooool2o`0001Wooooo0_l00009ooooo`;o00005Oooool2o`0000;ooooo0_l00013oooo
o`;o00001Oooool2o`00017ooooo0_l0000?ooooo`;o00003Oooool002Wooooo00?o0000oooooooo
ool02Oooool2o`0003oooooo0_l0000Eooooo`;o00002oooool2o`0000Gooooo1?l00003ooooo`;o
00006Oooool2o`0000Wooooo0ol0001Tooooo`;o00002oooool3o`0002?ooooo000Yooooo`;o0000
00?oooooo`000?l000000oooool2o`0000kooooo0_l0000cooooo`;o00008_ooool2o`0000Gooooo
1?l0000Aooooo`;o00005oooool2o`0003?ooooo0_l00005ooooo`;o000000?oooooo`000?l00000
3_ooool4o`00023ooooo0ol000000ooooooo0000o`00000Pooooo`00:Oooool00ol0003ooooooooo
o`02o`0000?ooooo0_l0000;ooooo`;o000000?oooooo`000?l00000??ooool2o`0000gooooo0_l0
000Vooooo`;o0000:Oooool2o`0001Kooooo0_l00008ooooo`?o00001Oooool2o`000003ooooool0
003o000000kooooo1?l0000Tooooo`;o000000Coooooo`000?l0003ooooo0_l0000Jooooo`001_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000
o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool04Oooool3o`0003[ooooo1ol0000=ooooo`;o
0000DOooool2o`0001Kooooo0_l00004ooooo`;o00000_ooool2o`0002Gooooo0_l0000Mooooo`Oo
00006?ooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0>oooo
o`;o000000?oooooo`000?l000000oooool3o`0000Cooooo0_l0000Nooooo`;o00002Oooool2o`00
00Cooooo1Ol0000Nooooo`;o00007oooool2o`0002cooooo0_l00002ooooo`;o00001oooool2o`00
00Cooooo0_l00008ooooo`;o00007oooool2o`00013ooooo0_l0000=ooooo`;o000000?oooooo`00
0?l000006?ooool000Kooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^
00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`;o00000_ooool2o`00
00;ooooo0ol00004ooooo`;o00004Oooool2o`0000_ooooo0_l00009ooooo`;o00009oooool2o`00
01oooooo0_l0000>ooooo`;o00003_ooool2o`0000cooooo0_l00002ooooo`?o00004_ooool2o`00
00;ooooo0_l0000Sooooo`;o00003?ooool2o`0001;ooooo0ol00007ooooo`;o00003?ooool000Ko
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b
<_ooool01?ooool3o`0001;ooooo0_l0000:ooooo`;o00004?ooool2o`00073ooooo1?l0000<oooo
o`;o00004Oooool2o`0001;ooooo0_l0000Wooooo`;o00008?ooool3o`0000Oooooo0_l0000<oooo
o`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool06oooool2o`000003ooooool0003o
000004Kooooo0_l00003ooooo`;o0000;_ooool2o`0000Oooooo0_l0000Aooooo`;o00008oooool2
o`0005kooooo0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06oooool2o`00037ooooo1?l0000D
ooooo`;o00000oooool2o`0002kooooo0_l0000=ooooo`;o00002oooool2o`0002?ooooo0_l0001N
ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@
4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>oooool2o`00017ooooo1?l0
000Tooooo`;o00002_ooool2o`0002Kooooo0_l0000Eooooo`;o00006Oooool2o`0003Kooooo0_l0
000Vooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c004ooooo`Co00001_ooool00ol0003oooooooooo`0kooooo`;o00008oooool3o`0000Wooooo
0_l00003ooooo`;o00000oooool2o`0000[ooooo0_l0000looooo`?o0000;oooool2o`00023ooooo
0_l0000Vooooo`00:Oooool2o`0002kooooo0_l0000aooooo`?o00002Oooool2o`0000?ooooo0_l0
000iooooo`;o00004_ooool2o`0002[ooooo0_l00004ooooo`;o0000>oooool2o`0000_ooooo000Y
ooooo`03o`000?oooooooooo00Cooooo0_l0000>ooooo`;o00003_ooool2o`0000Oooooo0_l0001m
ooooo`;o0000?_ooool2o`0000Wooooo0_l0000>ooooo`;o00009_ooool2o`0000_ooooo000Yoooo
o`03o`000?oooooooooo00Cooooo0_l0000>ooooo`;o00001_ooool2o`0000Gooooo0ol00004oooo
o`;o0000<Oooool2o`0000gooooo0_l0000Yooooo`;o0000@Oooool2o`0001_ooooo0_l0000>oooo
o`;o0000<oooool002Wooooo00?o0000ooooooooool05Oooool2o`0000Gooooo0_l00005ooooo`;o
00001Oooool2o`0002Kooooo0_l00009ooooo`;o00003Oooool2o`0002Wooooo0_l0000mooooo`;o
00000_ooool2o`00063ooooo000Yooooo`03o`000?oooooooooo01Gooooo0_l0000kooooo`;o0000
4Oooool2o`0000;ooooo0_l0001Jooooo`;o00003oooool2o`0002Wooooo0_l0000Wooooo`;o0000
4?ooool002Wooooo0_l0001Vooooo`;o00000_ooool2o`0001Wooooo0_l0000Pooooo`;o00007Ooo
ool2o`0003[ooooo0_l00006ooooo`;o00007oooool2o`00013ooooo000Yooooo`03o`000?oooooo
oooo053ooooo0_l0000:ooooo`;o000000?oooooo`000?l000008oooool2o`0000oooooo0_l00005
ooooo`;o00002?ooool2o`0002Wooooo0_l0000Booooo`;o00003oooool2o`00017ooooo0_l0000a
ooooo`00:Oooool00ol0003oooooooooo`0@ooooo`;o00003Oooool2o`0002;ooooo0_l0000;oooo
o`;o00002_ooool2o`000003ooooool0003o000000kooooo0_l0000Tooooo`;o00000_ooool2o`00
0003ooooool0003o000002[ooooo0ol00006ooooo`;o00003?ooool2o`0000Cooooo0_l0000?oooo
o`;o00008Oooool2o`00027ooooo000Yooooo`03o`000?oooooooooo00;ooooo0_l0000<ooooo`;o
000000?oooooo`000?l000002_ooool2o`0002;ooooo0_l000000ooooooo0000o`00000Fooooo`;o
00003oooool2o`0002Sooooo0_l0000@ooooo`;o00006oooool3o`0001Cooooo0_l00005ooooo`;o
000000?oooooo`000?l00000;_ooool2o`00027ooooo000Yooooo`04o`000?ooooooooooooooo`?o
00003oooool2o`00037ooooo0_l0000Fooooo`;o00005?ooool2o`0003Gooooo0_l00005ooooo`;o
00008_ooool2o`0000_ooooo1Ol000000ooooooo0000o`00000Xooooo`;o00004_ooool2o`0000?o
oooo0_l0000>ooooo`00:Oooool2o`0000;ooooo0_l0000=ooooo`;o00003_ooool2o`0000?ooooo
0_l00009ooooo`;o00001_ooool2o`0000Oooooo0_l0000Kooooo`;o00005?ooool2o`0000oooooo
0_l0000Zooooo`Co00001Oooool2o`0001[ooooo0_l0000;ooooo`?o00000_ooool2o`0002Wooooo
0_l00006ooooo`;o00002_ooool2o`0000?ooooo0_l0000>ooooo`00:Oooool00ol0003ooooooooo
o`0@ooooo`;o00002?ooool4o`0000;ooooo0_l00003ooooo`;o00002Oooool2o`0000Kooooo0_l0
0007ooooo`;o00000_ooool2o`0000oooooo0_l00006ooooo`;o00000oooool2o`00023ooooo0_l0
000=ooooo`;o00001oooool2o`0000Wooooo0_l00007ooooo`Co00000oooool4o`0002cooooo0_l0
000aooooo`;o00007oooool002Wooooo00?o0000ooooooooool06_ooool4o`0002Oooooo0_l0000?
ooooo`;o00002oooool2o`0000_ooooo0_l0000Rooooo`;o00001oooool2o`0000Wooooo0_l0000>
ooooo`;o0000=_ooool2o`0004[ooooo000Yooooo`03o`000?oooooooooo04Gooooo0_l0000Yoooo
o`;o0000O_ooool2o`0004[ooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
0_l0001Hooooo`;o0000hoooool002Wooooo00?o0000ooooooooool0Eoooool2o`000>?ooooo000>
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8b
omgMg@05ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;Kooooo
0_l00024ooooo`003_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool0
0oooool3o`000;Kooooo0_l00024ooooo`003_ooool01Ol0003ooooooooooooooooo000000oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05o`000?oo
ooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool0oooooolmooooo`003_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEE
ooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`000?oo
ooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo
00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMooo
ool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`007oooool4o`000003oa0@4?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`007oooool00omEEEGoIVIVo`00003oooooodOooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .37975 Mdot
.02762 .35182 Mdot
.02952 .28461 Mdot
.03143 .33007 Mdot
.03333 .36053 Mdot
.03524 .39216 Mdot
.03714 .27053 Mdot
.03905 .45071 Mdot
.04095 .43642 Mdot
.04286 .25527 Mdot
.04476 .28481 Mdot
.04667 .44824 Mdot
.04857 .2874 Mdot
.05048 .25782 Mdot
.05238 .4337 Mdot
.05429 .30019 Mdot
.05619 .29799 Mdot
.0581 .28393 Mdot
.06 .3479 Mdot
.0619 .26594 Mdot
.06381 .25435 Mdot
.06571 .30798 Mdot
.06762 .2705 Mdot
.06952 .2675 Mdot
.07143 .42472 Mdot
.07333 .31407 Mdot
.07524 .31911 Mdot
.07714 .34977 Mdot
.07905 .29099 Mdot
.08095 .33507 Mdot
.08286 .23561 Mdot
.08476 .43482 Mdot
.08667 .44666 Mdot
.08857 .34462 Mdot
.09048 .35858 Mdot
.09238 .28328 Mdot
.09429 .38949 Mdot
.09619 .34201 Mdot
.0981 .33751 Mdot
.1 .45135 Mdot
.1019 .43759 Mdot
.10381 .34982 Mdot
.10571 .38237 Mdot
.10762 .3873 Mdot
.10952 .39297 Mdot
.11143 .3491 Mdot
.11333 .26945 Mdot
.11524 .42038 Mdot
.11714 .25513 Mdot
.11905 .31174 Mdot
.12095 .42138 Mdot
.12286 .34362 Mdot
.12476 .22909 Mdot
.12667 .37641 Mdot
.12857 .37175 Mdot
.13048 .44187 Mdot
.13238 .45068 Mdot
.13429 .28579 Mdot
.13619 .40684 Mdot
.1381 .39439 Mdot
.14 .33938 Mdot
.1419 .38454 Mdot
.14381 .34932 Mdot
.14571 .31158 Mdot
.14762 .44179 Mdot
.14952 .43856 Mdot
.15143 .2557 Mdot
.15333 .29406 Mdot
.15524 .33694 Mdot
.15714 .24968 Mdot
.15905 .27536 Mdot
.16095 .29394 Mdot
.16286 .25911 Mdot
.16476 .25987 Mdot
.16667 .34943 Mdot
.16857 .31331 Mdot
.17048 .22941 Mdot
.17238 .30199 Mdot
.17429 .33092 Mdot
.17619 .24718 Mdot
.1781 .24453 Mdot
.18 .33209 Mdot
.1819 .33124 Mdot
.18381 .34954 Mdot
.18571 .4466 Mdot
.18762 .3127 Mdot
.18952 .36004 Mdot
.19143 .34441 Mdot
.19333 .26467 Mdot
.19524 .28899 Mdot
.19714 .41995 Mdot
.19905 .24401 Mdot
.20095 .3294 Mdot
.20286 .35171 Mdot
.20476 .32665 Mdot
.20667 .26831 Mdot
.20857 .25713 Mdot
.21048 .42734 Mdot
.21238 .23209 Mdot
.21429 .25608 Mdot
.21619 .3715 Mdot
.2181 .24849 Mdot
.22 .44449 Mdot
.2219 .37988 Mdot
.22381 .23427 Mdot
.22571 .3491 Mdot
.22762 .29606 Mdot
.22952 .35314 Mdot
.23143 .32958 Mdot
.23333 .24367 Mdot
.23524 .25492 Mdot
.23714 .33613 Mdot
.23905 .43454 Mdot
.24095 .25918 Mdot
.24286 .32183 Mdot
.24476 .31386 Mdot
.24667 .32547 Mdot
.24857 .43926 Mdot
.25048 .43666 Mdot
.25238 .39725 Mdot
.25429 .28183 Mdot
.25619 .40564 Mdot
.2581 .24688 Mdot
.26 .28772 Mdot
.2619 .24598 Mdot
.26381 .32141 Mdot
.26571 .27531 Mdot
.26762 .28964 Mdot
.26952 .33912 Mdot
.27143 .27123 Mdot
.27333 .2872 Mdot
.27524 .35995 Mdot
.27714 .44436 Mdot
.27905 .39293 Mdot
.28095 .38669 Mdot
.28286 .30847 Mdot
.28476 .36672 Mdot
.28667 .28816 Mdot
.28857 .25925 Mdot
.29048 .44609 Mdot
.29238 .43612 Mdot
.29429 .33242 Mdot
.29619 .34007 Mdot
.2981 .34026 Mdot
.3 .29602 Mdot
.3019 .26016 Mdot
.30381 .44407 Mdot
.30571 .35901 Mdot
.30762 .35743 Mdot
.30952 .34245 Mdot
.31143 .42731 Mdot
.31333 .24544 Mdot
.31524 .31627 Mdot
.31714 .27088 Mdot
.31905 .287 Mdot
.32095 .38964 Mdot
.32286 .36688 Mdot
.32476 .34628 Mdot
.32667 .44041 Mdot
.32857 .3935 Mdot
.33048 .3667 Mdot
.33238 .28716 Mdot
.33429 .32366 Mdot
.33619 .45149 Mdot
.3381 .27182 Mdot
.34 .38452 Mdot
.3419 .36517 Mdot
.34381 .44341 Mdot
.34571 .23378 Mdot
.34762 .33514 Mdot
.34952 .35363 Mdot
.35143 .31048 Mdot
.35333 .33723 Mdot
.35524 .33282 Mdot
.35714 .35425 Mdot
.35905 .35877 Mdot
.36095 .4451 Mdot
.36286 .27314 Mdot
.36476 .38927 Mdot
.36667 .30296 Mdot
.36857 .3105 Mdot
.37048 .33959 Mdot
.37238 .44881 Mdot
.37429 .27895 Mdot
.37619 .43645 Mdot
.3781 .26328 Mdot
.38 .43584 Mdot
.3819 .28336 Mdot
.38381 .43098 Mdot
.38571 .45084 Mdot
.38762 .38385 Mdot
.38952 .41423 Mdot
.39143 .25785 Mdot
.39333 .30118 Mdot
.39524 .38133 Mdot
.39714 .44862 Mdot
.39905 .43795 Mdot
.40095 .44491 Mdot
.40286 .35228 Mdot
.40476 .23773 Mdot
.40667 .30892 Mdot
.40857 .3153 Mdot
.41048 .31384 Mdot
.41238 .29939 Mdot
.41429 .35675 Mdot
.41619 .2286 Mdot
.4181 .36056 Mdot
.42 .28192 Mdot
.4219 .39296 Mdot
.42381 .34054 Mdot
.42571 .26267 Mdot
.42762 .28182 Mdot
.42952 .31011 Mdot
.43143 .30866 Mdot
.43333 .23388 Mdot
.43524 .27668 Mdot
.43714 .36184 Mdot
.43905 .31164 Mdot
.44095 .44975 Mdot
.44286 .26338 Mdot
.44476 .3887 Mdot
.44667 .45247 Mdot
.44857 .32992 Mdot
.45048 .4161 Mdot
.45238 .2346 Mdot
.45429 .25675 Mdot
.45619 .27583 Mdot
.4581 .36116 Mdot
.46 .36758 Mdot
.4619 .33599 Mdot
.46381 .43403 Mdot
.46571 .40886 Mdot
.46762 .31615 Mdot
.46952 .29039 Mdot
.47143 .22178 Mdot
.47333 .24747 Mdot
.47524 .30799 Mdot
.47714 .40601 Mdot
.47905 .33665 Mdot
.48095 .37729 Mdot
.48286 .26183 Mdot
.48476 .36444 Mdot
.48667 .37993 Mdot
.48857 .3883 Mdot
.49048 .23455 Mdot
.49238 .27512 Mdot
.49429 .43361 Mdot
.49619 .3272 Mdot
.4981 .37573 Mdot
.5 .27979 Mdot
.5019 .27252 Mdot
.50381 .34537 Mdot
.50571 .4366 Mdot
.50762 .31381 Mdot
.50952 .30896 Mdot
.51143 .38582 Mdot
.51333 .29544 Mdot
.51524 .33182 Mdot
.51714 .3709 Mdot
.51905 .31447 Mdot
.52095 .44902 Mdot
.52286 .41395 Mdot
.52476 .24692 Mdot
.52667 .30708 Mdot
.52857 .2604 Mdot
.53048 .28586 Mdot
.53238 .24744 Mdot
.53429 .37947 Mdot
.53619 .28065 Mdot
.5381 .38942 Mdot
.54 .29882 Mdot
.5419 .27001 Mdot
.54381 .27462 Mdot
.54571 .37309 Mdot
.54762 .25547 Mdot
.54952 .24689 Mdot
.55143 .36153 Mdot
.55333 .28001 Mdot
.55524 .35991 Mdot
.55714 .42505 Mdot
.55905 .27136 Mdot
.56095 .39223 Mdot
.56286 .31532 Mdot
.56476 .28187 Mdot
.56667 .26058 Mdot
.56857 .39563 Mdot
.57048 .44653 Mdot
.57238 .35354 Mdot
.57429 .27788 Mdot
.57619 .35428 Mdot
.5781 .24242 Mdot
.58 .3427 Mdot
.5819 .24189 Mdot
.58381 .27925 Mdot
.58571 .40843 Mdot
.58762 .43895 Mdot
.58952 .41403 Mdot
.59143 .27641 Mdot
.59333 .39471 Mdot
.59524 .37832 Mdot
.59714 .2354 Mdot
.59905 .43518 Mdot
.60095 .37577 Mdot
.60286 .25172 Mdot
.60476 .37967 Mdot
.60667 .36229 Mdot
.60857 .43434 Mdot
.61048 .4331 Mdot
.61238 .27071 Mdot
.61429 .42594 Mdot
.61619 .29219 Mdot
.6181 .32232 Mdot
.62 .30181 Mdot
.6219 .30164 Mdot
.62381 .2792 Mdot
.62571 .42876 Mdot
.62762 .30441 Mdot
.62952 .3856 Mdot
.63143 .34894 Mdot
.63333 .44159 Mdot
.63524 .29101 Mdot
.63714 .44699 Mdot
.63905 .40063 Mdot
.64095 .33794 Mdot
.64286 .31441 Mdot
.64476 .39299 Mdot
.64667 .34729 Mdot
.64857 .35908 Mdot
.65048 .36258 Mdot
.65238 .32417 Mdot
.65429 .27037 Mdot
.65619 .29254 Mdot
.6581 .45227 Mdot
.66 .38853 Mdot
.6619 .32366 Mdot
.66381 .3117 Mdot
.66571 .27152 Mdot
.66762 .30146 Mdot
.66952 .36478 Mdot
.67143 .39125 Mdot
.67333 .38461 Mdot
.67524 .28514 Mdot
.67714 .35683 Mdot
.67905 .22013 Mdot
.68095 .28054 Mdot
.68286 .33016 Mdot
.68476 .31695 Mdot
.68667 .44434 Mdot
.68857 .31625 Mdot
.69048 .28676 Mdot
.69238 .30791 Mdot
.69429 .33605 Mdot
.69619 .32051 Mdot
.6981 .33702 Mdot
.7 .44986 Mdot
.7019 .38865 Mdot
.70381 .28448 Mdot
.70571 .2611 Mdot
.70762 .31615 Mdot
.70952 .30138 Mdot
.71143 .24711 Mdot
.71333 .4494 Mdot
.71524 .34818 Mdot
.71714 .23519 Mdot
.71905 .4436 Mdot
.72095 .44609 Mdot
.72286 .44373 Mdot
.72476 .31187 Mdot
.72667 .2461 Mdot
.72857 .43426 Mdot
.73048 .44987 Mdot
.73238 .31417 Mdot
.73429 .23585 Mdot
.73619 .26724 Mdot
.7381 .39387 Mdot
.74 .37375 Mdot
.7419 .43007 Mdot
.74381 .3765 Mdot
.74571 .39428 Mdot
.74762 .37929 Mdot
.74952 .27257 Mdot
.75143 .3799 Mdot
.75333 .28602 Mdot
.75524 .42965 Mdot
.75714 .33226 Mdot
.75905 .40444 Mdot
.76095 .39187 Mdot
.76286 .2905 Mdot
.76476 .41433 Mdot
.76667 .2565 Mdot
.76857 .27116 Mdot
.77048 .45028 Mdot
.77238 .24792 Mdot
.77429 .32576 Mdot
.77619 .2569 Mdot
.7781 .31686 Mdot
.78 .31505 Mdot
.7819 .42197 Mdot
.78381 .23746 Mdot
.78571 .37784 Mdot
.78762 .44858 Mdot
.78952 .32167 Mdot
.79143 .22139 Mdot
.79333 .32087 Mdot
.79524 .35869 Mdot
.79714 .36022 Mdot
.79905 .31012 Mdot
.80095 .45124 Mdot
.80286 .44803 Mdot
.80476 .31695 Mdot
.80667 .33745 Mdot
.80857 .28597 Mdot
.81048 .3002 Mdot
.81238 .43067 Mdot
.81429 .35688 Mdot
.81619 .26263 Mdot
.8181 .33916 Mdot
.82 .32097 Mdot
.8219 .28282 Mdot
.82381 .35798 Mdot
.82571 .34003 Mdot
.82762 .30697 Mdot
.82952 .28583 Mdot
.83143 .41651 Mdot
.83333 .44647 Mdot
.83524 .27687 Mdot
.83714 .36163 Mdot
.83905 .29692 Mdot
.84095 .38297 Mdot
.84286 .26127 Mdot
.84476 .33207 Mdot
.84667 .41888 Mdot
.84857 .26697 Mdot
.85048 .36825 Mdot
.85238 .29323 Mdot
.85429 .38738 Mdot
.85619 .2868 Mdot
.8581 .43822 Mdot
.86 .43205 Mdot
.8619 .29578 Mdot
.86381 .30027 Mdot
.86571 .22201 Mdot
.86762 .3385 Mdot
.86952 .32614 Mdot
.87143 .35838 Mdot
.87333 .25376 Mdot
.87524 .2503 Mdot
.87714 .2404 Mdot
.87905 .26346 Mdot
.88095 .37166 Mdot
.88286 .34206 Mdot
.88476 .31715 Mdot
.88667 .29962 Mdot
.88857 .26969 Mdot
.89048 .45067 Mdot
.89238 .30339 Mdot
.89429 .31988 Mdot
.89619 .36054 Mdot
.8981 .38888 Mdot
.9 .27323 Mdot
.9019 .23897 Mdot
.90381 .30948 Mdot
.90571 .30749 Mdot
.90762 .25633 Mdot
.90952 .45253 Mdot
.91143 .43922 Mdot
.91333 .28548 Mdot
.91524 .39221 Mdot
.91714 .26486 Mdot
.91905 .3001 Mdot
.92095 .28274 Mdot
.92286 .37388 Mdot
.92476 .35172 Mdot
.92667 .32149 Mdot
.92857 .33973 Mdot
.93048 .39954 Mdot
.93238 .38721 Mdot
.93429 .31033 Mdot
.93619 .38196 Mdot
.9381 .24719 Mdot
.94 .30624 Mdot
.9419 .30263 Mdot
.94381 .3744 Mdot
.94571 .3843 Mdot
.94762 .31492 Mdot
.94952 .29718 Mdot
.95143 .43898 Mdot
.95333 .36243 Mdot
.95524 .38113 Mdot
.95714 .33054 Mdot
.95905 .3529 Mdot
.96095 .32075 Mdot
.96286 .3067 Mdot
.96476 .32291 Mdot
.96667 .3585 Mdot
.96857 .42085 Mdot
.97048 .27015 Mdot
.97238 .33981 Mdot
.97429 .29724 Mdot
.97619 .4487 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0<oooooo0_l0000Rooooo`;o0000Aoooool000Kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo08cooooo0_l00011ooooo`;o00008_ooool2o`0001Kooooo0_l0000_
ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo08cooooo0_l0
001mooooo`;o0000;oooool000Co00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01gooooo0_l0
000<ooooo`;o0000COooool2o`000<3ooooo0006ooooo`05o`000?ooooooooooooooool000003Ooo
ool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Mooooo`;o00003?oo
ool2o`0000cooooo0_l0000Yooooo`;o00005?ooool2o`0000Cooooo0_l0002jooooo`001_ooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool03oooool2o`0002Sooooo0_l00002ooooo`;o0000
9Oooool2o`0001[ooooo0_l00004ooooo`;o00002_ooool2o`00027ooooo0_l0000Tooooo`;o0000
1?ooool2o`0005Wooooo0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03oooool2o`0002cooooo
0_l0000hooooo`;o00003Oooool2o`0000[ooooo0_l0000Qooooo`;o00009?ooool2o`0000Cooooo
0_l0000>ooooo`;o00007?ooool2o`0000Kooooo0_l0000Sooooo`001_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0Moooool2o`0003Gooooo1?l0000oooooo`;o00007?ooool2o`0000Ko
oooo0_l0000Sooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`0^ooooo`;o00001Oooool2o`00
00Wooooo0_l00007ooooo`;o00003_ooool2o`0005?ooooo1?l0000/ooooo`;o0000G?ooool002Wo
oooo0_l0000Xooooo`;o00001?ooool3o`0000Gooooo0_l00004ooooo`;o00000oooool2o`0000Ko
oooo0ol0000>ooooo`;o0000<_ooool2o`0000kooooo0_l000000ooooooo0000o`000003ooooo`;o
0000<_ooool2o`0000?ooooo0_l0000=ooooo`;o0000<oooool2o`0001Sooooo000Yooooo`03o`00
0?oooooooooo02Oooooo0_l00004ooooo`;o00003?ooool2o`0000_ooooo0_l00013ooooo`;o0000
3_ooool2o`000003ooooool0003o000000?ooooo0_l0000?ooooo`;o00008Oooool2o`0001;ooooo
0_l0000Oooooo`;o00004_ooool2o`0001Sooooo000Yooooo`03o`000?oooooooooo00;ooooo0_l0
0005ooooo`;o00003oooool2o`0000Wooooo0_l0000Iooooo`;o0000Hoooool2o`0000oooooo0_l0
001Eooooo`?o0000;?ooool002Wooooo00?o0000ooooooooool00_ooool2o`000003ooooool0003o
000000;ooooo0_l0000?ooooo`;o00002Oooool2o`00017ooooo1?l00004ooooo`;o0000<?ooool2
o`0001?ooooo0_l0000Looooo`;o0000A?ooool2o`000003ooooool0003o000001gooooo0_l00009
ooooo`;o00008_ooool002Wooooo00?o0000ooooooooool01Oooool2o`0002;ooooo0ol0000<oooo
o`Co00001_ooool2o`0000gooooo0_l00003ooooo`;o00006_ooool2o`0001?ooooo0_l00007oooo
o`;o00003Oooool2o`0000[ooooo0_l0000[ooooo`;o00004Oooool2o`000003ooooool0003o0000
01Cooooo0_l0000Booooo`;o00008_ooool002Wooooo0_l0000Zooooo`?o00001oooool2o`0000go
oooo0_l0000=ooooo`;o00000oooool2o`0001Kooooo0_l0000=ooooo`;o00001?ooool2o`0000_o
oooo0_l0000=ooooo`;o00002_ooool2o`0002_ooooo0_l0000Qooooo`;o00001oooool2o`0000Wo
oooo0_l0000;ooooo`;o00007_ooool002Wooooo00?o0000ooooooooool02Oooool4o`0002Kooooo
0_l00002ooooo`;o0000=Oooool2o`0000gooooo0_l00004ooooo`;o0000G?ooool2o`0001Sooooo
0_l00008ooooo`;o00002?ooool2o`0000_ooooo0_l0000Nooooo`00:Oooool01?l0003ooooooooo
ooooool2o`0000Kooooo1?l0000<ooooo`;o00005Oooool4o`000003oa0@4?oooooooooo00?o0000
00?o<S8bonk^k_ooool00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo0_l0000=ooooo`;o
00004?ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h08Oooool2o`0000?ooooo0_l000001OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`?o000000?o<S8bonk^k_ooool01oooool2o`0001Sooooo
0_l00006ooooo`;o000000Wo410@o`000?l0003oooooonk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Wooooo0_l0000;ooooo`;o00004Oooool01Om4A4Co0000o`00
0?lb<S;ogMgM00;ooooo00Gok^k^o`000?l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool002Wooooo00Co0000oooooooooooooooo0_l00007ooooo`;o00003Oooool2o`00
01Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`08ooooo`;o00003Oooool2o`0000Cooooo0_l00006ooooo`;o00000_oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL05?ooool2o`0000_ooooo0_l00003ooooo`;o000000Go410@okZj
^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool2o`000003oooooonH
V9SoMgMg00Sooooo0_l00002ooooo`;o00006Oooool2o`0000;ooooo00[o0000ooooool0003o0000
oooooomgMgOoV9RHoooooonHV9SoMgMg0oooool01OmgMgOoV9RHoooooonHV9SoMgMg01Kooooo0_l0
0002ooooo`;o00004?ooool01OmgMgOo<S8booooooooooooMgMg00;o000000?oV9RHogMgMoooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000Yooooo`03o`000?oooooooooo02Sooooo
0_l00008ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@41001_ooool2o`0001Gooooo0_l00006ooooo`;o00000oooool00onH
V9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool01?l@413ooooooooooooo
ool2o`0000Cooooo0_l0000:ooooo`;o000000?oooooo`000?l000002oooool2o`0000Wooooo00Go
0000oooooooooooooooooa0@4002o`000003ooooool@413ooooo00;ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`;o00006Oooool6o`0000?ooooo00Go410@oooooooooooooooooa0@4003oooo
o`05oa0@4?ooooooooooooooool@41001Oooool2o`0001?ooooo0_l0000Aooooo`04o`000?oooooo
oooooa0@40?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo007ooooo
000Yooooo`;o0000:Oooool2o`0000Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000006ooooo`;o00008Oooool2o`000003
oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooooooo
ooooo`;o00001?ooool2o`0000[ooooo1?l0000:ooooo`Co00000_ooool2o`0000Cooooo0_l00000
0ooooooo0000o`000003o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool00_l0000A
ooooo`;o00005Oooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000Gooooo0_l0000Uooooo`05ogMgMolb<S;ooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00Oooool0
02Wooooo00?o0000ooooooooool01oooool2o`0000Wooooo0_l0000Nooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_oo
ool2o`0002Gooooo1?l000001OmVIVKooooooooooooooooo000000?ooooo00?o0000ooooooooool0
1?l000000ooooooo0000ooooo`0Booooo`;o00002_ooool2o`0000Cooooo0_l000001?oooooo0000
o`000?l@4102o`000004ooooool0003o0000o`0000?ooooo00Go0000ooooooooooooooooo`000002
ooooo`;o00004Oooool2o`0001Gooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Ko0000ooooooooooooooooo`000?ooool2o`0001kooooo0_l00006oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`00:Oooool3o`0000?ooooo0_l00002ooooo`;o00002Ooo
ool2o`0000cooooo0_l0000@ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@4003ooooo`05oa0@4?ooooooooooooooool@41000_ooool2o`0001?ooooo0_l0000Booooo`?o
00000oooool01Ol@413ooooooooooooooooo410@00;ooooo1?l000000ooooooo410@ooooo`0Loooo
o`;o00002Oooool2o`000003oooooonj^[[o8B4Q00?ooooo00Go410@oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@41003oooool2o`0000?ooooo0_l00002ooooo`;o00003_oo
ool2o`000003olc<c?l0003ooooo00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`06oa0@
4?oooooo0000o`000?l@413ooooo1?l00007ooooo`;o00004?ooool2o`000003ooooool0003o0000
00Kooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@
oooooooooooooooooa0@4003ooooo`00:Oooool3o`0000?ooooo0ol0000Jooooo`;o00004?ooool3
o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1?ooool2o`000003ooooool0003o000000;o00000_ooool2o`0000Sooooo0_l00002ooooo`;o0000
3?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL07Oooool2o`0000Wooooo00Go410@oiRHV?oooooo^[Zjo`00
0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00oo
oooo0_l00003ooooo`;o00000_ooool2o`0000kooooo0_l000000om4A4Co0000ooooo`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHo`000?l0003oMgMg00?ooooo0_l00007
ooooo`;o00004?ooool2o`0000Wooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool00ol0003ooooooooo
o`04ooooo`;o00002?ooool2o`00023ooooo00?oEEEEofIVI_l000000_l00002ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo0_l000000ooooooo
0000o`000002o`0000;ooooo0_l0000<ooooo`;o00003?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02_oo
ool2o`0001cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko0000o`000?lb<S;ok^k^00;ooooo0_l00005ooooo`;o00007oooool00omg
MgOo0000o`000003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo0_l0000Looooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool2o`0000oooooo0_l0000Fooooo`Co0000
5?ooool2o`0001Gooooo0_l0000eooooo`;o00003?ooool2o`0001oooooo0_l00004ooooo`;o0000
1Oooool2o`00023ooooo0_l0000Kooooo`;o000000?oooooo`000?l00000<?ooool002Wooooo00?o
0000ooooooooool01oooool2o`0001gooooo1?l0000Dooooo`;o00005Oooool2o`0002;ooooo0_l0
000Oooooo`;o00001_ooool2o`0005kooooo0_l00006ooooo`;o00006_ooool2o`0000Kooooo0_l0
000<ooooo`00:Oooool00ol0003oooooooooo`06ooooo`?o00008oooool2o`0004Gooooo0_l00004
ooooo`;o00009oooool2o`0001Sooooo0ol0000<ooooo`;o00003?ooool2o`0001kooooo0_l00007
ooooo`;o00001_ooool2o`0000Kooooo0_l00008ooooo`;o00002?ooool2o`0000Kooooo0_l0000<
ooooo`00:Oooool00ol0003oooooooooo`06ooooo`;o00009?ooool2o`0003gooooo0_l00006oooo
o`;o0000Aoooool4o`0000_ooooo0_l0000<ooooo`;o00007_ooool2o`0000oooooo0_l00006oooo
o`Co00001_ooool2o`0000Gooooo0_l0000Gooooo`00:Oooool00ol0003oooooooooo`0:ooooo`;o
0000A?ooool2o`0001Wooooo0_l0000Booooo`;o00003?ooool2o`0000oooooo0_l0000Nooooo`;o
00004oooool2o`0002[ooooo0_l0000Cooooo`;o00000_ooool2o`0000Wooooo0_l00005ooooo`;o
00004?ooool0027oooooool00014o`0000Cooooo000Yooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool00_l00008ooooo`03o`000?oooooooooo00;ooooo0_l00005ooooo`?o00001_oo
ool2o`000004ooooool0003oooooooooo`;o00001oooool00ol0003oooooooooo`06ooooo`;o0000
0_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
1?ooool2o`0000?ooooo0_l0000:ooooo`Co00001?ooool2o`000004ooooool0003o0000o`0000_o
oooo00?o0000ooooooooool01Oooool2o`0000;ooooo0_l0000;ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool01?l0003oooooo`000?l00005ooooo`;o000000?oooooo`00
0?ooool02oooool01?l0003oooooooooooooool4o`0000Cooooo00?o0000ooooooooool02Oooool0
1?l0003oooooooooooooool2o`0000Kooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`09ooooo`;o00002?ooool3o`000003ooooool0003o000000Sooooo00?o0000ooooooooool02_oo
ool002Wooooo00?o0000ooooooooool03?ooool2o`0001gooooo0_l00004ooooo`;o00001oooool0
0ol0003oooooooooo`06ooooo`;o00005Oooool2o`0001cooooo0ol0000@ooooo`;o00002oooool2
o`0000;ooooo0_l0000<ooooo`;o00002Oooool00ol0003oooooooooo`0;ooooo`;o00003?ooool3
o`0000Cooooo0_l00006ooooo`;o00003Oooool2o`000003ooooool0003ooooo00?ooooo0_l0000H
ooooo`;o00004_ooool2o`0000Sooooo00?o0000ooooooooool02_ooool002Wooooo00?o0000oooo
ooooool03Oooool2o`0004_ooooo0_l0000Looooo`;o00004Oooool2o`0001gooooo0_l0000Uoooo
o`Go00000_ooool2o`0001Gooooo0_l00003ooooo`;o000000?oooooo`000?l000000oooool2o`00
01?ooooo0_l000000ooooooo0000o`00000Dooooo`;o00004?ooool002Wooooo00?o0000oooooooo
ool03Oooool2o`0003Cooooo0_l00004ooooo`;o00005Oooool2o`0005Wooooo0_l00009ooooo`;o
000000?oooooo`000?l000002Oooool2o`0001cooooo1?l00006ooooo`;o00005_ooool2o`0000Wo
oooo0_l00009ooooo`?o00003oooool002Wooooo0_l0000gooooo`;o00002oooool3o`0000?ooooo
0_l0000Eooooo`;o0000<_ooool2o`0002Gooooo0_l00009ooooo`;o000000?oooooo`000?l00000
8oooool2o`0000;ooooo0_l0000Hooooo`;o00004Oooool2o`0000[ooooo0_l0000?ooooo`00:Ooo
ool01?l0003oooooo`000?l0000dooooo`?o00001oooool2o`0000?ooooo0_l0000oooooo`;o0000
3Oooool2o`0003[ooooo0_l0000Looooo`;o00007?ooool2o`0001[ooooo0_l0000Booooo`00:Ooo
ool01?l0003oooooo`000?l0000/ooooo`Co00001?ooool2o`0000Sooooo0_l0000Booooo`;o0000
4_ooool2o`0001cooooo0_l0000Cooooo`;o0000=?ooool2o`0001Kooooo0_l0000Jooooo`;o0000
8_ooool2o`0001;ooooo000Yooooo`03o`000?oooooooooo00oooooo0_l0000Looooo`Co00004?oo
ool2o`00013ooooo0_l0000?ooooo`;o000000?oooooo`000?l000008?ooool2o`0000Cooooo0_l0
0009ooooo`;o0000>?ooool2o`0001;ooooo0_l0000Jooooo`;o0000=_ooool002Wooooo00?o0000
ooooooooool03oooool2o`0000?ooooo0_l0000<ooooo`;o00000oooool2o`0001Sooooo0_l00008
ooooo`;o00005oooool4o`0000Cooooo0_l0000Kooooo`;o00001?ooool2o`0003;ooooo0_l0000?
ooooo`?o00008Oooool2o`0000;ooooo0_l0000>ooooo`;o00004Oooool2o`0000cooooo0_l0000=
ooooo`00:Oooool2o`0001Gooooo0_l0000<ooooo`;o00000oooool2o`0002;ooooo0_l00007oooo
o`;o00000_ooool2o`0000cooooo0_l00004ooooo`;o00003oooool2o`00033ooooo0_l0000Boooo
o`;o00004?ooool2o`00027ooooo0_l00002ooooo`Co00003?ooool2o`0000;ooooo0_l0000=oooo
o`;o00003?ooool2o`0000gooooo000Yooooo`03o`000?oooooooooo017ooooo0_l000000ooooooo
0000o`000006ooooo`;o00005?ooool2o`00023ooooo0_l00002ooooo`;o00008oooool2o`0001So
oooo0_l0000Fooooo`;o0000COooool2o`00013ooooo0_l0000Zooooo`00:Oooool00ol0003ooooo
ooooo`08ooooo`;o00001oooool2o`0000Gooooo0_l00002ooooo`;o00005?ooool2o`0000Wooooo
0_l0000Nooooo`;o0000>?ooool2o`0002Oooooo0_l00003ooooo`;o00005?ooool2o`0005oooooo
000Yooooo`;o00002Oooool2o`0000?ooooo0_l00007ooooo`Co00002Oooool2o`0000Gooooo0_l0
0004ooooo`;o00001?ooool2o`0000Gooooo0_l0000Nooooo`;o00005oooool2o`0004Sooooo0_l0
0003ooooo`;o00005?ooool2o`00047ooooo0_l0000Looooo`00:Oooool2o`0000kooooo0_l00007
ooooo`;o00002oooool2o`0000Gooooo0_l00004ooooo`;o00001?ooool2o`0000Kooooo0_l0000U
ooooo`Co00003Oooool2o`0003Gooooo0ol0001^ooooo`;o00002Oooool2o`00017ooooo000Yoooo
o`;o00004oooool2o`0002[ooooo0_l0000Hooooo`;o00002oooool4o`00017ooooo0_l0000aoooo
o`?o00007_ooool2o`0002[ooooo0_l00002ooooo`;o00003Oooool2o`0001[ooooo1?l0000?oooo
o`00:Oooool01?l0003oooooo`000?l0000Aooooo`;o00007_ooool2o`0001Wooooo0_l00008oooo
o`?o00003_ooool2o`00013ooooo0ol0000;ooooo`;o00007?ooool3o`0001cooooo0_l00007oooo
o`;o00009?ooool3o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`0000Wooooo0_l00006oooo
o`;o00005?ooool2o`0000oooooo000Yooooo`04o`000?oooooo0000o`00037ooooo0_l0000Ioooo
o`;o00002?ooool2o`0000oooooo0_l0000Aooooo`;o00001?ooool2o`0000Gooooo0_l00006oooo
o`;o00005?ooool3o`0000oooooo0_l0000;ooooo`?o00001?ooool2o`0002Kooooo0ol0000;oooo
o`;o00004Oooool2o`00013ooooo0_l0000Cooooo`00:Oooool00ol0003oooooooooo`1@ooooo`;o
00002_ooool2o`000003ooooool0003o000000;ooooo0_l0000Looooo`;o00001_ooool2o`0000Go
oooo0_l0000Vooooo`;o00003?ooool2o`0000Cooooo0_l0001Iooooo`;o00004oooool002Wooooo
00?o0000ooooooooool0D?ooool2o`0000[ooooo0_l000000ooooooo0000o`000002ooooo`;o0000
9?ooool2o`00013ooooo0_l0001Yooooo`;o0000=?ooool002Wooooo0_l0000Oooooo`;o00006_oo
ool2o`0005oooooo0_l00007ooooo`;o0000?Oooool2o`00027ooooo0_l00008ooooo`;o00002ooo
ool2o`0001gooooo000Yooooo`03o`000?oooooooooo01gooooo0ol0000Jooooo`;o0000FOooool2
o`0000gooooo0_l0000@ooooo`;o0000:oooool3o`0002[ooooo0_l0000;ooooo`;o00001Oooool2
o`0001Kooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool2o`0001kooooo0_l0000Mooooo`;o0000DOoo
ool4o`0000;ooooo0_l00009ooooo`;o00004_ooool5o`0002_ooooo1?l00009ooooo`;o0000<Ooo
ool2o`0001Kooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo0_l0000Hooooo`;o0000
8oooool2o`0003Kooooo0_l0000Iooooo`Co00003Oooool2o`0001;ooooo0_l000000ooooooo0000
o`00000/ooooo`?o00002Oooool2o`00013ooooo0_l0000Mooooo`;o00001?ooool2o`0001;ooooo
0006ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool05oooool2o`0000Wooooo0_l0000nooooo`;o0000
3Oooool2o`000003ooooool0003o000002?ooooo0_l0000Tooooo`;o00003?ooool2o`0003Cooooo
0_l0000Mooooo`;o000000Coooooo`000?l0003ooooo0_l0000Booooo`001_ooool01Ol0003ooooo
oooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o
00004oooool2o`0000;ooooo0_l00009ooooo`;o0000:oooool2o`0000_ooooo0_l00004ooooo`;o
00001_ooool2o`0000Gooooo0_l0000Aooooo`;o00003?ooool2o`0000Gooooo0_l00007ooooo`;o
00006oooool2o`0000Sooooo0_l00002ooooo`;o00001oooool2o`0002oooooo0_l0000<ooooo`;o
00002Oooool2o`0000?ooooo0_l0000Eooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool00_l0000Aooooo`;o00000_ooool2o`0003Kooooo0_l0000;ooooo`;o00003?ooool2o`00
01Sooooo0_l0000<ooooo`;o00003_ooool2o`0000Gooooo0_l0000Nooooo`;o00000_ooool2o`00
00Oooooo0_l0000Aooooo`;o00007?ooool2o`0000cooooo0_l00004ooooo`;o00000oooool2o`00
01[ooooo0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_l0000Fooooo`;o00001oooool2o`00
02_ooooo0_l0000>ooooo`;o00007?ooool2o`0002_ooooo1?l00006ooooo`;o00003oooool2o`00
00Oooooo0_l0000Cooooo`Co00000oooool2o`00033ooooo0_l0000Oooooo`001_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool06?ooool2o`0000Oooooo0_l0000Sooooo`;o00001_ooool2
o`0000kooooo0_l0000Looooo`;o0000;Oooool2o`0000Kooooo0_l0000?ooooo`;o00007?ooool4
o`0005Kooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo04Kooooo0_l0001jooooo`;o0000G?oo
ool2o`0001[ooooo000Yooooo`;o0000`oooool2o`0002Gooooo0_l0000eooooo`;o00006_ooool0
02Wooooo00?o0000ooooooooool08?ooool2o`0002Gooooo0_l00015ooooo`;o0000FOooool2o`00
057ooooo000Yooooo`03o`000?oooooooooo023ooooo0_l0000Uooooo`;o0000@Oooool2o`0000;o
oooo0_l0000Qooooo`;o0000ROooool002Wooooo00?o0000ooooooooool0L_ooool2o`0001Kooooo
0_l0000Aooooo`;o00004_ooool3o`0003Oooooo0_l0001?ooooo`00:Oooool00ol0003ooooooooo
o`1booooo`;o00004Oooool2o`0001Kooooo0_l0000Cooooo`;o0000=oooool2o`0001?ooooo0_l0
000jooooo`00:Oooool2o`0001_ooooo0_l0000Hooooo`;o0000Coooool2o`0007Wooooo0_l00003
ooooo`;o0000=Oooool002Wooooo00?o0000ooooooooool06_ooool4o`0001Kooooo0_l0002joooo
o`;o00004oooool2o`0002Gooooo0_l0000>ooooo`00:Oooool00ol0003oooooooooo`0<ooooo`;o
00003_ooool2o`0008[ooooo0_l0000@ooooo`;o0000=?ooool2o`0003[ooooo0_l0000>ooooo`00
:Oooool00ol0003oooooooooo`0<ooooo`;o0000:_ooool2o`0001oooooo0_l0001=ooooo`;o0000
4?ooool2o`0000;ooooo0_l0000Sooooo`;o00000_ooool2o`0005?ooooo000Yooooo`03o`000?oo
oooooooo03Sooooo0_l0000Oooooo`;o00005Oooool2o`0004Oooooo0_l00003ooooo`;o00008ooo
ool2o`0000;ooooo0_l0000Aooooo`;o00003Oooool2o`00037ooooo000Yooooo`;o00001_ooool2
o`0000Wooooo0_l0000_ooooo`;o00004?ooool2o`0001[ooooo0ol0000Hooooo`;o00002?ooool2
o`0001oooooo0_l000001?oooooo0000o`000?l0000Tooooo`;o00006Oooool2o`0000gooooo0_l0
000aooooo`00:Oooool00ol0003oooooooooo`02ooooo`;o000000?oooooo`000?l000002Oooool2
o`0000?ooooo0_l0000>ooooo`;o00006_ooool2o`0000;ooooo0_l0000<ooooo`;o00006Oooool3
o`0000Cooooo0_l0000Cooooo`;o00002?ooool2o`000003ooooool0003o000001Wooooo0_l00000
1?oooooo0000o`000?ooool2o`0002Gooooo0_l0000Xooooo`;o00003oooool2o`0000_ooooo0_l0
000Cooooo`00:Oooool00ol0003oooooooooo`02ooooo`;o00004Oooool2o`0000Sooooo0_l00003
ooooo`?o00007_ooool2o`0001Oooooo0_l0000>ooooo`;o00001Oooool2o`00023ooooo0_l0000I
ooooo`;o00003?ooool2o`0004Oooooo0_l0000?ooooo`;o00002oooool2o`0001?ooooo000Yoooo
o`03o`000?oooooooooo01oooooo0_l00003ooooo`;o00005Oooool2o`00017ooooo0_l00006oooo
o`;o00001_ooool2o`0000?ooooo0_l00004ooooo`;o00002oooool2o`0004Sooooo0_l0000?oooo
o`;o00002Oooool3o`0005gooooo000Yooooo`03o`000?oooooooooo00Cooooo0_l0000:ooooo`;o
00007_ooool2o`0000Wooooo0_l0000Aooooo`;o00000_ooool2o`0000;ooooo0_l0000;ooooo`;o
00001?ooool2o`0000Wooooo1?l0000dooooo`;o00004oooool2o`0000kooooo0_l00009ooooo`?o
00004oooool2o`0000?ooooo0_l00008ooooo`;o0000;?ooool2o`0000_ooooo000Yooooo`;o0000
0_ooool2o`000003ooooool0003o000000[ooooo0_l00003ooooo`;o00002?ooool2o`0000oooooo
0_l0000Pooooo`;o00003Oooool2o`0000Wooooo0_l00003ooooo`;o000000?oooooo`000?l00000
3?ooool2o`0001Sooooo0_l0000>ooooo`;o00004oooool2o`0001?ooooo0_l00002ooooo`Co0000
00?oooooo`000?l000002oooool2o`0000Cooooo0_l00002ooooo`?o00002?ooool2o`00013ooooo
0_l0000Jooooo`;o00002oooool002Wooooo00Co0000oooooooooooooooo0_l0000Booooo`;o0000
2?ooool2o`00043ooooo0_l00009ooooo`;o00000oooool2o`0000oooooo1?l0000Fooooo`;o0000
:_ooool2o`0000cooooo0_l00002ooooo`;o00000oooool2o`0000_ooooo0_l00008ooooo`;o0000
6oooool2o`0000Cooooo0_l0000Qooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`24ooooo`;o
0000@_ooool2o`0004oooooo0_l0000Qooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`00
3_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oo
oooo?Oooool000kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000co
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000ko
oooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003ooooo
ockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003ooooo
ockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`00
0?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oo
oooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGo
ZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`00
1_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003o
ooooooooo`03ooooo`?o0000oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oo
oooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5
o`0000Cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000ooooooln
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000ooooooln
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool001oooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo
?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000Q
ooooo`03o`000?oooooooooo00Gooooo0ol0003oooooocgooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001oooooo00?oEEEE
ofIVI_l00000oooooom7ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .39878 Mdot
.02762 .40005 Mdot
.02952 .27935 Mdot
.03143 .33795 Mdot
.03333 .35276 Mdot
.03524 .36107 Mdot
.03714 .29206 Mdot
.03905 .41958 Mdot
.04095 .39462 Mdot
.04286 .29939 Mdot
.04476 .25795 Mdot
.04667 .43999 Mdot
.04857 .37424 Mdot
.05048 .28494 Mdot
.05238 .44629 Mdot
.05429 .34165 Mdot
.05619 .2451 Mdot
.0581 .37234 Mdot
.06 .29159 Mdot
.0619 .24507 Mdot
.06381 .34868 Mdot
.06571 .38216 Mdot
.06762 .35982 Mdot
.06952 .36113 Mdot
.07143 .45212 Mdot
.07333 .36456 Mdot
.07524 .25845 Mdot
.07714 .2986 Mdot
.07905 .23333 Mdot
.08095 .39328 Mdot
.08286 .31224 Mdot
.08476 .38571 Mdot
.08667 .41881 Mdot
.08857 .26626 Mdot
.09048 .28317 Mdot
.09238 .23764 Mdot
.09429 .29994 Mdot
.09619 .28336 Mdot
.0981 .24056 Mdot
.1 .44055 Mdot
.1019 .45415 Mdot
.10381 .27115 Mdot
.10571 .33313 Mdot
.10762 .40073 Mdot
.10952 .3932 Mdot
.11143 .36644 Mdot
.11333 .26933 Mdot
.11524 .35217 Mdot
.11714 .33067 Mdot
.11905 .2321 Mdot
.12095 .3554 Mdot
.12286 .24338 Mdot
.12476 .27014 Mdot
.12667 .32055 Mdot
.12857 .30632 Mdot
.13048 .40857 Mdot
.13238 .42507 Mdot
.13429 .24792 Mdot
.13619 .32824 Mdot
.1381 .39021 Mdot
.14 .3669 Mdot
.1419 .44822 Mdot
.14381 .24975 Mdot
.14571 .26266 Mdot
.14762 .42844 Mdot
.14952 .3942 Mdot
.15143 .29784 Mdot
.15333 .33873 Mdot
.15524 .27357 Mdot
.15714 .34467 Mdot
.15905 .252 Mdot
.16095 .26824 Mdot
.16286 .28508 Mdot
.16476 .31745 Mdot
.16667 .24987 Mdot
.16857 .28428 Mdot
.17048 .26955 Mdot
.17238 .35718 Mdot
.17429 .23603 Mdot
.17619 .30479 Mdot
.1781 .27169 Mdot
.18 .39157 Mdot
.1819 .33539 Mdot
.18381 .2702 Mdot
.18571 .40841 Mdot
.18762 .34545 Mdot
.18952 .35462 Mdot
.19143 .36291 Mdot
.19333 .26109 Mdot
.19524 .33694 Mdot
.19714 .45135 Mdot
.19905 .36295 Mdot
.20095 .27875 Mdot
.20286 .36399 Mdot
.20476 .27524 Mdot
.20667 .38477 Mdot
.20857 .28691 Mdot
.21048 .37191 Mdot
.21238 .26462 Mdot
.21429 .27013 Mdot
.21619 .39958 Mdot
.2181 .28478 Mdot
.22 .44195 Mdot
.2219 .40232 Mdot
.22381 .31063 Mdot
.22571 .27178 Mdot
.22762 .24428 Mdot
.22952 .30334 Mdot
.23143 .27895 Mdot
.23333 .33636 Mdot
.23524 .29647 Mdot
.23714 .33393 Mdot
.23905 .38612 Mdot
.24095 .25137 Mdot
.24286 .21768 Mdot
.24476 .32757 Mdot
.24667 .3649 Mdot
.24857 .38907 Mdot
.25048 .38497 Mdot
.25238 .31603 Mdot
.25429 .37056 Mdot
.25619 .45586 Mdot
.2581 .33805 Mdot
.26 .23404 Mdot
.2619 .33994 Mdot
.26381 .34077 Mdot
.26571 .24027 Mdot
.26762 .39911 Mdot
.26952 .39227 Mdot
.27143 .31748 Mdot
.27333 .37123 Mdot
.27524 .39847 Mdot
.27714 .4463 Mdot
.27905 .35796 Mdot
.28095 .34439 Mdot
.28286 .23078 Mdot
.28476 .26445 Mdot
.28667 .23458 Mdot
.28857 .28504 Mdot
.29048 .42949 Mdot
.29238 .44694 Mdot
.29429 .4219 Mdot
.29619 .31143 Mdot
.2981 .27768 Mdot
.3 .24532 Mdot
.3019 .24992 Mdot
.30381 .40122 Mdot
.30571 .23369 Mdot
.30762 .33344 Mdot
.30952 .36398 Mdot
.31143 .46249 Mdot
.31333 .29562 Mdot
.31524 .25551 Mdot
.31714 .36394 Mdot
.31905 .27071 Mdot
.32095 .38328 Mdot
.32286 .26594 Mdot
.32476 .24649 Mdot
.32667 .39519 Mdot
.32857 .30762 Mdot
.33048 .26539 Mdot
.33238 .35423 Mdot
.33429 .23307 Mdot
.33619 .45196 Mdot
.3381 .2438 Mdot
.34 .34488 Mdot
.3419 .39753 Mdot
.34381 .40073 Mdot
.34571 .30535 Mdot
.34762 .27136 Mdot
.34952 .2504 Mdot
.35143 .23267 Mdot
.35333 .30794 Mdot
.35524 .26946 Mdot
.35714 .35843 Mdot
.35905 .33402 Mdot
.36095 .42542 Mdot
.36286 .38811 Mdot
.36476 .38258 Mdot
.36667 .32746 Mdot
.36857 .23157 Mdot
.37048 .23965 Mdot
.37238 .44667 Mdot
.37429 .33479 Mdot
.37619 .45499 Mdot
.3781 .29727 Mdot
.38 .39677 Mdot
.3819 .39456 Mdot
.38381 .37285 Mdot
.38571 .45092 Mdot
.38762 .33496 Mdot
.38952 .45743 Mdot
.39143 .25187 Mdot
.39333 .26122 Mdot
.39524 .44563 Mdot
.39714 .41493 Mdot
.39905 .4585 Mdot
.40095 .44371 Mdot
.40286 .36271 Mdot
.40476 .35713 Mdot
.40667 .24312 Mdot
.40857 .32354 Mdot
.41048 .32446 Mdot
.41238 .26754 Mdot
.41429 .35495 Mdot
.41619 .34386 Mdot
.4181 .39766 Mdot
.42 .26776 Mdot
.4219 .36984 Mdot
.42381 .3277 Mdot
.42571 .29508 Mdot
.42762 .25906 Mdot
.42952 .3857 Mdot
.43143 .3596 Mdot
.43333 .30317 Mdot
.43524 .33256 Mdot
.43714 .39709 Mdot
.43905 .36 Mdot
.44095 .45301 Mdot
.44286 .30654 Mdot
.44476 .39094 Mdot
.44667 .43521 Mdot
.44857 .36581 Mdot
.45048 .34838 Mdot
.45238 .31582 Mdot
.45429 .25606 Mdot
.45619 .33102 Mdot
.4581 .34299 Mdot
.46 .40461 Mdot
.4619 .29797 Mdot
.46381 .44654 Mdot
.46571 .45796 Mdot
.46762 .34364 Mdot
.46952 .31777 Mdot
.47143 .32581 Mdot
.47333 .29122 Mdot
.47524 .25415 Mdot
.47714 .45509 Mdot
.47905 .27432 Mdot
.48095 .40312 Mdot
.48286 .35458 Mdot
.48476 .39922 Mdot
.48667 .44586 Mdot
.48857 .34458 Mdot
.49048 .29399 Mdot
.49238 .25216 Mdot
.49429 .37955 Mdot
.49619 .27713 Mdot
.4981 .2796 Mdot
.5 .25173 Mdot
.5019 .25384 Mdot
.50381 .24609 Mdot
.50571 .45755 Mdot
.50762 .32733 Mdot
.50952 .26281 Mdot
.51143 .2958 Mdot
.51333 .35664 Mdot
.51524 .26852 Mdot
.51714 .30203 Mdot
.51905 .28786 Mdot
.52095 .4259 Mdot
.52286 .34033 Mdot
.52476 .31412 Mdot
.52667 .25401 Mdot
.52857 .25241 Mdot
.53048 .32578 Mdot
.53238 .2888 Mdot
.53429 .39691 Mdot
.53619 .26089 Mdot
.5381 .36432 Mdot
.54 .23347 Mdot
.5419 .34239 Mdot
.54381 .24108 Mdot
.54571 .30823 Mdot
.54762 .30781 Mdot
.54952 .3099 Mdot
.55143 .25929 Mdot
.55333 .33578 Mdot
.55524 .32246 Mdot
.55714 .36334 Mdot
.55905 .26605 Mdot
.56095 .3782 Mdot
.56286 .23178 Mdot
.56476 .32577 Mdot
.56667 .31736 Mdot
.56857 .31188 Mdot
.57048 .43845 Mdot
.57238 .30384 Mdot
.57429 .27784 Mdot
.57619 .35189 Mdot
.5781 .27163 Mdot
.58 .36501 Mdot
.5819 .277 Mdot
.58381 .39157 Mdot
.58571 .33281 Mdot
.58762 .44314 Mdot
.58952 .34551 Mdot
.59143 .31334 Mdot
.59333 .30611 Mdot
.59524 .44302 Mdot
.59714 .28795 Mdot
.59905 .44531 Mdot
.60095 .24805 Mdot
.60286 .32418 Mdot
.60476 .31998 Mdot
.60667 .39966 Mdot
.60857 .38258 Mdot
.61048 .45288 Mdot
.61238 .26777 Mdot
.61429 .36663 Mdot
.61619 .35548 Mdot
.6181 .31498 Mdot
.62 .38089 Mdot
.6219 .24454 Mdot
.62381 .3684 Mdot
.62571 .46191 Mdot
.62762 .32871 Mdot
.62952 .39365 Mdot
.63143 .27104 Mdot
.63333 .43179 Mdot
.63524 .32787 Mdot
.63714 .44814 Mdot
.63905 .45026 Mdot
.64095 .42652 Mdot
.64286 .34223 Mdot
.64476 .35472 Mdot
.64667 .26678 Mdot
.64857 .25927 Mdot
.65048 .33911 Mdot
.65238 .31545 Mdot
.65429 .30384 Mdot
.65619 .24523 Mdot
.6581 .42957 Mdot
.66 .3014 Mdot
.6619 .27103 Mdot
.66381 .38548 Mdot
.66571 .3182 Mdot
.66762 .26767 Mdot
.66952 .40405 Mdot
.67143 .3551 Mdot
.67333 .34489 Mdot
.67524 .35308 Mdot
.67714 .35365 Mdot
.67905 .29497 Mdot
.68095 .34891 Mdot
.68286 .38981 Mdot
.68476 .26593 Mdot
.68667 .41605 Mdot
.68857 .2572 Mdot
.69048 .23519 Mdot
.69238 .38056 Mdot
.69429 .29273 Mdot
.69619 .36153 Mdot
.6981 .42457 Mdot
.7 .43766 Mdot
.7019 .29504 Mdot
.70381 .23698 Mdot
.70571 .33634 Mdot
.70762 .24485 Mdot
.70952 .23276 Mdot
.71143 .29107 Mdot
.71333 .43796 Mdot
.71524 .43313 Mdot
.71714 .29091 Mdot
.71905 .44607 Mdot
.72095 .44919 Mdot
.72286 .45515 Mdot
.72476 .27107 Mdot
.72667 .30034 Mdot
.72857 .44721 Mdot
.73048 .42478 Mdot
.73238 .27277 Mdot
.73429 .29478 Mdot
.73619 .33928 Mdot
.7381 .36692 Mdot
.74 .39941 Mdot
.7419 .3785 Mdot
.74381 .40282 Mdot
.74571 .30724 Mdot
.74762 .28676 Mdot
.74952 .36106 Mdot
.75143 .28126 Mdot
.75333 .37019 Mdot
.75524 .45125 Mdot
.75714 .21978 Mdot
.75905 .32933 Mdot
.76095 .38296 Mdot
.76286 .26981 Mdot
.76476 .45361 Mdot
.76667 .27005 Mdot
.76857 .306 Mdot
.77048 .44703 Mdot
.77238 .34259 Mdot
.77429 .31168 Mdot
.77619 .31051 Mdot
.7781 .36426 Mdot
.78 .25599 Mdot
.7819 .3546 Mdot
.78381 .32753 Mdot
.78571 .44352 Mdot
.78762 .44755 Mdot
.78952 .24767 Mdot
.79143 .29136 Mdot
.79333 .24686 Mdot
.79524 .33004 Mdot
.79714 .33192 Mdot
.79905 .31179 Mdot
.80095 .42943 Mdot
.80286 .43952 Mdot
.80476 .25734 Mdot
.80667 .30089 Mdot
.80857 .2562 Mdot
.81048 .34317 Mdot
.81238 .46017 Mdot
.81429 .36191 Mdot
.81619 .24999 Mdot
.8181 .32285 Mdot
.82 .25801 Mdot
.8219 .32501 Mdot
.82381 .35911 Mdot
.82571 .2613 Mdot
.82762 .25339 Mdot
.82952 .26551 Mdot
.83143 .45955 Mdot
.83333 .42813 Mdot
.83524 .30116 Mdot
.83714 .28811 Mdot
.83905 .24416 Mdot
.84095 .38993 Mdot
.84286 .33416 Mdot
.84476 .26797 Mdot
.84667 .45548 Mdot
.84857 .38456 Mdot
.85048 .40199 Mdot
.85238 .21911 Mdot
.85429 .40195 Mdot
.85619 .26459 Mdot
.8581 .40656 Mdot
.86 .4479 Mdot
.8619 .25478 Mdot
.86381 .37642 Mdot
.86571 .28736 Mdot
.86762 .30693 Mdot
.86952 .30455 Mdot
.87143 .34113 Mdot
.87333 .25874 Mdot
.87524 .31931 Mdot
.87714 .3597 Mdot
.87905 .29369 Mdot
.88095 .31074 Mdot
.88286 .26122 Mdot
.88476 .26516 Mdot
.88667 .32802 Mdot
.88857 .32914 Mdot
.89048 .42085 Mdot
.89238 .32951 Mdot
.89429 .23228 Mdot
.89619 .40201 Mdot
.8981 .39421 Mdot
.9 .24159 Mdot
.9019 .28432 Mdot
.90381 .24451 Mdot
.90571 .41097 Mdot
.90762 .30872 Mdot
.90952 .43045 Mdot
.91143 .45778 Mdot
.91333 .25862 Mdot
.91524 .3014 Mdot
.91714 .33788 Mdot
.91905 .2454 Mdot
.92095 .23661 Mdot
.92286 .4001 Mdot
.92476 .30139 Mdot
.92667 .36195 Mdot
.92857 .26044 Mdot
.93048 .45553 Mdot
.93238 .35072 Mdot
.93429 .27858 Mdot
.93619 .33472 Mdot
.9381 .30825 Mdot
.94 .2681 Mdot
.9419 .34034 Mdot
.94381 .31542 Mdot
.94571 .33508 Mdot
.94762 .32559 Mdot
.94952 .35682 Mdot
.95143 .39552 Mdot
.95333 .34884 Mdot
.95524 .39562 Mdot
.95714 .26444 Mdot
.95905 .31118 Mdot
.96095 .28146 Mdot
.96286 .21675 Mdot
.96476 .28735 Mdot
.96667 .40225 Mdot
.96857 .36068 Mdot
.97048 .24465 Mdot
.97238 .27779 Mdot
.97429 .23239 Mdot
.97619 .44438 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l00014ooooo`;o0000iOooool2
o`00013ooooo000Yooooo`03o`000?oooooooooo04?ooooo0_l0002Sooooo`;o00007Oooool2o`00
027ooooo0_l0000@ooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0j?ooool2
o`0001gooooo0_l0000cooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0?oooooo?Oooool000Co00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo053ooooo0_l0
003Zooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00omgMgOo<S8booooo`04ooooo`?o00003_ooool2o`0000_ooooo0_l0000[ooooo`;o00001_oo
ool2o`0000Gooooo0_l00007ooooo`;o00001?ooool2o`0000?ooooo0_l0000eooooo`;o00001_oo
ool2o`0002gooooo0_l0000iooooo`;o00006?ooool2o`0000cooooo0006ooooo`05o`000?oooooo
ooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`0>ooooo`;o00002oooool2o`00013ooooo0_l0000Iooooo`;o0000
1oooool2o`0000Cooooo0_l00007ooooo`;o00001?ooool2o`0000?ooooo0_l0000eooooo`;o0000
1_ooool2o`0002Oooooo0_l00002ooooo`Co0000>Oooool2o`0000Oooooo0_l0000?ooooo`;o0000
3?ooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`;o00006Oooool2o`0001_ooooo
0_l00005ooooo`;o00006Oooool2o`0006Gooooo0_l00002ooooo`;o0000A?ooool2o`0001gooooo
0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`Co00001_ooool2o`0002co
oooo0_l0000Pooooo`;o00002Oooool2o`0002[ooooo0_l0001aooooo`;o00009?ooool000Kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`00
00Kooooo00?o0000ooooooooool01oooool4o`0000Wooooo0_l00006ooooo`;o00008?ooool2o`00
01Gooooo0_l00006ooooo`;o00000_ooool2o`0001Cooooo0_l0000Nooooo`;o00002_ooool2o`00
01Sooooo0_l00009ooooo`;o00003_ooool2o`0002Sooooo0_l0000Booooo`?o00000oooool2o`00
00oooooo0_l0000=ooooo`00:Oooool2o`0000Sooooo1?l0000Eooooo`;o00007?ooool2o`0001Go
oooo0_l00006ooooo`;o00000_ooool2o`0003Cooooo0_l0000Mooooo`;o00001Oooool2o`0000Wo
oooo0_l0000>ooooo`;o00006?ooool4o`0000cooooo0_l0000Cooooo`;o00000oooool2o`0000oo
oooo0_l0000=ooooo`00:Oooool00ol0003oooooooooo`0Pooooo`;o000000?oooooo`000?l00000
0oooool4o`0001Kooooo0_l0000Booooo`;o00003Oooool2o`0000_ooooo0_l0000Oooooo`Co0000
2?ooool2o`0001Gooooo0_l0000jooooo`Co00001Oooool2o`0003oooooo000Yooooo`03o`000?oo
oooooooo02?ooooo0_l00003ooooo`Co00005_ooool2o`0001;ooooo0_l00002ooooo`;o00002Ooo
ool2o`0000_ooooo0_l0000Iooooo`;o00001?ooool5o`0000Kooooo0ol0001Jooooo`;o00000_oo
ool2o`0000Wooooo0_l0000`ooooo`00:Oooool00ol0003oooooooooo`03ooooo`;o00002?ooool2
o`0004_ooooo0_l0000Rooooo`;o00001oooool2o`0000Cooooo0_l00007ooooo`;o00001_ooool2
o`0003;ooooo0_l0000Kooooo`;o00001_ooool4o`000004ooooool0003o0000ooooo`;o00002Ooo
ool2o`000003ooooool0003o000000_ooooo0_l0000Pooooo`00:Oooool00ol0003oooooooooo`03
ooooo`;o00002?ooool2o`0002Cooooo0_l0000nooooo`;o00002Oooool2o`0000Oooooo0_l0000H
ooooo`;o00000oooool2o`0001gooooo0_l0000;ooooo`;o00006oooool2o`0000Kooooo1?l00000
0ooooooo0000o`000002o`0000gooooo0_l000000ooooooo0000o`000008ooooo`;o00000oooool2
o`0001_ooooo000Yooooo`;o00009?ooool2o`0000kooooo0_l00004ooooo`;o00005Oooool2o`00
027ooooo0_l0000Sooooo`;o00001oooool2o`0000?ooooo0_l0000Mooooo`;o0000=oooool2o`00
00Sooooo0_l00006ooooo`?o00003?ooool2o`0000Oooooo0_l0000Booooo`00:Oooool00ol0003o
ooooooooo`0Aooooo`;o00004?ooool2o`0000?ooooo0_l0000?ooooo`;o00005Oooool2o`0000[o
oooo0_l000000ooooooo0000o`00000Hooooo`;o000000?oooooo`000?l000006_ooool2o`0000ko
oooo0_l0000@ooooo`;o00002Oooool2o`0000Cooooo0_l00004ooooo`;o0000;?ooool2o`0000?o
oooo0_l00002ooooo`;o00001oooool2o`00013ooooo0_l00003ooooo`;o00004_ooool002Wooooo
00?o0000ooooooooool04Oooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o0000
2Oooool2o`000003ooooool0003o000000?ooooo1?l000001Ol@413oooooooooooo^k^ko<S8b00?o
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Oooooo0ol000000ooooooo0000o`000003oooo
o`;o000000?oooooo`000?l000001?ooool5o`0000?ooooo00Cok^k^oc8b<_l0003o<S8b0_l00000
1ooooooo0000o`000?lb<S;o0000oc8b<_o^k^h06?ooool2o`0000cooooo0_l000001OnHV9So410@
o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`?o000000?o<S8bonk^
k_ooool00_l00003ooooo`;o00000_ooool4o`0000Cooooo0_l0000;ooooo`;o00002Oooool4o`00
00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool2o`0000?ooooo0_l0000Mooooo`;o000000GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Yooooo`03
o`000?oooooooooo01Kooooo0_l000000ooooooo0000o`000002ooooo`;o00002?ooool2o`0000;o
oooo0_l000000ooooooo0000o`000003o`0000Cooooo00?oMgMgoiRHV?ooool00_l000002?oooooo
0000o`000?mgMgOoV9RHoooooonHV9SoMgMg5oooool2o`0000Oooooo0_l000000ooooooo0000o`00
0004ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0=ooooo`;o00002Oooool2o`0000kooooo00Co410@okZj
^_ooooooMgMg0_l00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01_mgMgOoV9RHoooo
oonHV9SoMgMgooooo`;o00001oooool2o`0001?ooooo1?l00008ooooo`?o00000_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0/ooooo`09ogMgMolb<S;o
oooooooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`00:Oooool00ol0003oooooooooo`0Wooooo`;o00001Oooool2o`0000;ooooo00Co0000oooooooo
oooooooo0_l00003ooooo`05oa0@4?oooooo0000o`000?l@41000oooool00ol@413oooooooooo`0>
ooooo`;o00006?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@00gooooo0_l00003ooooo`;o00006?ooool4o`000005oa0@
4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@027ooooo0_l00005oooo
o`Go00000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
400]ooooo`04o`000?oooooooooooa0@40?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo007ooooo000Yooooo`?o0000<_ooool00ol0003oooooooooo`03o`0000?ooooo
00Co0000oooooooooooooooo0_l00002ooooo`03o`000?oooooooooo00kooooo0_l0000Iooooo`03
oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000004_ooool3o`0001Kooooo0_l000001?oooooo0000o`000?l00003ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`0Vooooo`04odA4A?oMgMgoooooo`0000Co
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000009Oooool2
o`0000Gooooo00CoMgMgoc8b<_oooooooooo0ol000000ooooooo0000ooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool002Wooooo0ol0000Booooo`Co00007?ooool00ol0003ooooooooo
o`03o`0000?ooooo00Co0000oooooooooooooooo0_l00002ooooo`03o`000?oooooooooo02[ooooo
00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`00000Cooooo`;o00005Oooool00ol@413o0000o`000003ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000002Oooooo0_l000000omEEEGoooooo`00
0004ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000002Go
oooo0_l00002ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ol000000ooooooo0000ooooo`02oooo
o`05o`000?ooooooooooooooool000000oooool002Wooooo00?o0000ooooooooool01Oooool2o`00
00_ooooo1?l0000Cooooo`Co00001Oooool00ol0003oooooooooo`02ooooo`04oa0@4?l0003o0000
ooooo`;o00000_ooool01Ol@413ooooooooooooooooo410@00gooooo0_l0000Nooooo`05o`000?oo
ooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooooooo
ool0:Oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@02Kooooo0ol000000omgMgOoc<c<o`000004ooooo`05oa0@4?oooooo
ooooooooool@41000oooool01Ol@413ooooooooooooooooo410@01_ooooo0_l0000<ooooo`03o`00
0?oooooooooo00;ooooo0_l000001Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooooooooa0@4003ooooo`00:Oooool00ol0003oooooooooo`05ooooo`;o00008_ooool4o`0000Go
oooo00?o0000ooooooooool00_ooool01?mgMgOo0000o`000?nHV9P2o`0000;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0=ooooo`;o00006_ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool2o`0000;o
oooo0_l00008ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool00omgMgOoV9RHooooo`02o`00
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`;o000000Coooooonk^k_m4A4Co00001?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`;o
00001oooool2o`0000[ooooo0_l0000<ooooo`03o`000?oooooooooo00?ooooo0_l000001?nHV9So
oooooiRHV?mgMgL3ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wooooo00Co0000oooo
oooooooooooo0_l00005ooooo`;o00009_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Wooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00_ooooo0_l0000=ooooo`;o00000_ooool2o`0000Sooooo00GoZJVYoa0@4?l0003o410@ojVY
Z@03ooooo`03onk^k_lb<S;o000000;o00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Gooooo
0_l00003ooooo`Co00003?ooool00omgMgOo0000ooooo`03ooooo`04onk^k_lb<S;o0000oc8b<P;o
00000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo0_l00007ooooo`;o00006?ooool4o`00
00;ooooo0_l000001?lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool002Wooooo0_l00002ooooo`;o00001Oooool2o`0004oooooo0_l0000Rooooo`;o00003_ooool2
o`0000?ooooo0_l00005ooooo`;o0000=?ooool2o`0000?ooooo1?l000000ooooooo0000o`000002
o`0000Cooooo0_l0000@ooooo`;o00006_ooool2o`0002_ooooo000Yooooo`03o`000?oooooooooo
00;ooooo0_l00009ooooo`;o00005_ooool2o`0001Wooooo0_l0000Gooooo`;o00004oooool2o`00
00gooooo0_l0000:ooooo`;o00001oooool2o`0000Gooooo0_l0000dooooo`;o00001Oooool2o`00
00Wooooo0_l0000/ooooo`;o0000:oooool002Wooooo00?o0000ooooooooool00_ooool2o`0000Wo
oooo0_l00004ooooo`;o00004?ooool2o`0001Wooooo0_l0000/ooooo`;o00006Oooool2o`00013o
oooo0_l0000/ooooo`;o00004oooool2o`0001Sooooo0_l00007ooooo`;o00006?ooool2o`000003
ooooool0003o000001cooooo000Yooooo`03o`000?oooooooooo01?ooooo0_l0000Hooooo`;o0000
3oooool2o`0002Cooooo0_l0000Jooooo`;o00006Oooool2o`00013ooooo0_l0000Hooooo`Co0000
4oooool2o`0001Sooooo0_l00007ooooo`;o00002Oooool2o`0000gooooo0_l000000ooooooo0000
o`00000Looooo`00:Oooool00ol0003oooooooooo`0Nooooo`;o00003Oooool2o`0000oooooo0_l0
000Nooooo`;o00001?ooool4o`0001Sooooo0_l000000ooooooo0000o`00000Oooooo`?o00001_oo
ool2o`0000Cooooo0_l0000Booooo`;o00006oooool2o`0000Kooooo0_l0000Nooooo`;o00002_oo
ool2o`0000Sooooo0_l0000Hooooo`008Oooooooo`0004Co00001?ooool002Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`03ooooo`;o00001Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02o`00
00Sooooo00?o0000ooooooooool02Oooool3o`0000Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`?o00001_ooool2o`0000;ooooo00Co0000ooooool0003o00001_ooool3
o`0000Gooooo0_l00004ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo0_l00002ooooo`04o`000?oooooo
ooooooooo`;o00001_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo0_l0
0005ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool2o`0000Cooooo00?o
0000ooooooooool02_ooool002Wooooo00?o0000ooooooooool03oooool2o`0001Wooooo0_l0000>
ooooo`03o`000?oooooooooo00Wooooo0_l00004ooooo`;o0000:_ooool00ol0003oooooooooo`0;
ooooo`;o00001?ooool2o`0000oooooo0_l0000<ooooo`;o00001_ooool3o`0000Gooooo0_l00009
ooooo`;o0000:_ooool00ol0003oooooooooo`0_ooooo`;o00002Oooool00ol0003oooooooooo`0:
ooooo`00:Oooool00ol0003oooooooooo`0Mooooo`;o00002oooool2o`0001[ooooo0_l00004oooo
o`;o0000>?ooool2o`0000Cooooo0_l0000Mooooo`;o00002_ooool2o`0000gooooo0_l00003oooo
o`;o0000@Oooool2o`0001Cooooo0_l0000Fooooo`00:Oooool00ol0003oooooooooo`0Mooooo`;o
0000FOooool2o`0002gooooo0_l0000=ooooo`?o00004_ooool2o`0002oooooo0_l0000@ooooo`;o
0000;?ooool002Wooooo0_l0001/ooooo`;o00002oooool3o`00017ooooo0_l0000:ooooo`;o0000
1Oooool2o`0000Kooooo0_l000000ooooooo0000o`00000:ooooo`;o0000A?ooool3o`0002Kooooo
0_l0000Eooooo`00:Oooool00ol0003oooooooooo`0Pooooo`;o00008Oooool2o`0002Kooooo0_l0
000<ooooo`;o00000_ooool2o`0000gooooo0_l0000:ooooo`;o00001Oooool2o`0000Wooooo0_l0
000Booooo`;o000000?oooooo`000?l000009_ooool2o`0000Kooooo0_l000000ooooooo0000o`00
0007ooooo`;o00004oooool4o`0000oooooo0_l0000Eooooo`00:Oooool00ol0003oooooooooo`0G
ooooo`;o000000?oooooo`000?l000001?ooool2o`00027ooooo0_l0000Cooooo`;o00008oooool2
o`0000;ooooo0_l00004ooooo`;o0000:?ooool2o`0000_ooooo0_l000000ooooooo0000o`00000V
ooooo`;o00001_ooool2o`000004ooooool0003o0000o`0001_ooooo1?l0000Vooooo`00:Oooool0
0ol0003oooooooooo`0Gooooo`;o000000?oooooo`000?l000004oooool2o`0000oooooo0ol0000E
ooooo`;o00003_ooool2o`0000?ooooo0_l00002ooooo`;o00003_ooool2o`0000Cooooo0_l0000N
ooooo`;o00002?ooool2o`0002Gooooo0_l0000Kooooo`;o00003Oooool2o`0001cooooo0_l00000
0ooooooo0000o`00000Eooooo`00:Oooool01?l0003oooooo`000?l0000Uooooo`;o00001oooool2
o`0000;ooooo0_l0000;ooooo`?o00001Oooool2o`0001kooooo0_l00003ooooo`;o00000_ooool2
o`0003Cooooo0_l0000Mooooo`;o00004?ooool2o`0000Oooooo0_l0000Qooooo`;o00005_ooool2
o`0000Cooooo0_l000000ooooooo0000o`00000Eooooo`00:Oooool4o`0000Gooooo0_l0000Noooo
o`;o00002oooool2o`0001?ooooo0ol0000mooooo`;o00004oooool2o`0000Cooooo0_l0000Noooo
o`;o000000?oooooo`000?l000006Oooool2o`0000[ooooo0_l0000Nooooo`;o00003Oooool2o`00
00Gooooo0_l0000Gooooo`00:Oooool00ol0003oooooooooo`06ooooo`;o00007oooool2o`0000So
oooo0_l0000Fooooo`;o00001?ooool2o`00017ooooo0_l0000Fooooo`;o00003?ooool2o`000003
ooooool0003o000000Gooooo0_l00009ooooo`;o00001?ooool2o`0000gooooo0_l0000?ooooo`;o
00002?ooool2o`0001kooooo0_l0000:ooooo`;o00004_ooool2o`0001Cooooo0_l0000Gooooo`00
:Oooool00ol0003oooooooooo`09ooooo`;o00007?ooool2o`0000Sooooo0_l0000Looooo`;o0000
4Oooool2o`0001Kooooo0_l00009ooooo`;o00001?ooool2o`0000Gooooo0_l0000Nooooo`;o0000
6Oooool2o`000003ooooool0003o000002Oooooo0_l0000/ooooo`;o00004oooool002Wooooo00?o
0000ooooooooool02Oooool2o`0000oooooo0_l0001Yooooo`;o00009oooool2o`00023ooooo0_l0
001>ooooo`;o00001Oooool2o`0001?ooooo000Yooooo`04o`000?oooooo0000o`0001Wooooo1?l0
000Dooooo`;o0000:oooool2o`0001Wooooo0_l0000Dooooo`;o00007?ooool2o`0001Cooooo0_l0
0007ooooo`?o00008?ooool2o`0002kooooo0_l0000Jooooo`00:Oooool4o`0001_ooooo0_l0000>
ooooo`;o00001?ooool2o`0001[ooooo0_l0000?ooooo`;o00001_ooool2o`0000kooooo0_l00000
0ooooooo0000o`00000Dooooo`;o00002?ooool2o`0001oooooo0_l00007ooooo`;o00001oooool3
o`00023ooooo0_l0000dooooo`;o00005?ooool002Wooooo00?o0000ooooooooool00_l00008oooo
o`?o00007oooool2o`00023ooooo0_l0000Gooooo`;o00003_ooool2o`0000Kooooo0_l000000ooo
oooo0000o`00000Fooooo`;o00007oooool2o`0001Oooooo0_l0000@ooooo`;o00005_ooool2o`00
00oooooo0_l0000Eooooo`;o00001?ooool2o`0000kooooo000Yooooo`03o`000?oooooooooo00;o
00002?ooool4o`0002Cooooo0_l000001?oooooo0000o`000?l0000Pooooo`;o000000?oooooo`00
0?l000006Oooool2o`0000Oooooo0_l000000ooooooo0000o`00000Nooooo`;o00001?ooool2o`00
02[ooooo0_l0000@ooooo`;o00001oooool2o`0000Wooooo0_l00002ooooo`;o00003oooool2o`00
00kooooo0_l0000;ooooo`;o00003_ooool002Wooooo00?o0000ooooooooool03?ooool2o`0000[o
oooo0_l00008ooooo`;o00003_ooool2o`000004ooooool0003o0000o`0000cooooo0_l0000Boooo
o`;o000000?oooooo`000?l000006Oooool2o`0000gooooo0_l0000Kooooo`;o00001?ooool2o`00
00Gooooo0_l00009ooooo`;o00009_ooool2o`0000_ooooo0_l00009ooooo`;o00008oooool2o`00
01_ooooo000Yooooo`03o`000?oooooooooo01Sooooo0_l00008ooooo`;o00008?ooool4o`0003Co
oooo0_l00007ooooo`;o0000:?ooool2o`0000Wooooo0_l000000ooooooo0000o`00000Sooooo`;o
00000oooool2o`0005?ooooo000Yooooo`;o00002?ooool2o`0002oooooo0_l0000<ooooo`;o0000
1Oooool2o`00027ooooo0_l0000:ooooo`;o0000?oooool2o`0002Sooooo0_l0001Cooooo`00:Ooo
ool00ol0003oooooooooo`04ooooo`;o000000?oooooo`000?l00000;oooool2o`0001?ooooo0_l0
000Qooooo`;o0000V?ooool2o`00033ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`04ooooo`;o0000S_ooool2o`0001?ooooo0_l0000hooooo`;o00009Oooool2o`00033ooooo
0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool02_ooool2o`00053o
oooo0_l0000<ooooo`;o0000:?ooool2o`0001?ooooo0_l0000=ooooo`;o00000_ooool2o`0001Go
oooo0_l0000>ooooo`;o00001?ooool2o`00057ooooo0006ooooo`05oa0@4?ooooooooooooooool@
41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02_ooool2o`0000Cooooo0_l0000Uooooo`;o00002?ooool2o`0000;ooooo0_l0000Eooooo`;o
00003?ooool2o`0001?ooooo0_l0000gooooo`;o00000_ooool2o`0000cooooo0_l00007ooooo`;o
00005?ooool2o`0001[ooooo0_l0000eooooo`001_ooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o00004?ooool2o`0002Go
oooo0_l00008ooooo`;o00000_ooool2o`0002;ooooo0_l0000Dooooo`;o0000BOooool2o`0003Wo
oooo0_l0000eooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_oo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool08Oooool2o`00
00_ooooo0_l0000Eooooo`;o00001?ooool2o`0001cooooo0_l0000Iooooo`;o0000:_ooool2o`00
01kooooo0_l0000aooooo`;o0000=oooool000Kooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02oooo
o`;o00002oooool2o`0000Oooooo0_l00007ooooo`;o00000_ooool2o`0000Oooooo0_l0000Koooo
o`;o00004Oooool2o`0000oooooo0_l0000Cooooo`;o0000:_ooool2o`0000gooooo0_l0000?oooo
o`;o0000<Oooool2o`00013ooooo0_l0000@ooooo`?o00004_ooool000Kooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07
ooooo`;o00000oooool2o`0000_ooooo0_l00007ooooo`;o00002oooool2o`0002Kooooo0_l0000?
ooooo`;o00000oooool2o`0000[ooooo0_l0000:ooooo`;o00001?ooool2o`0001gooooo0_l0000M
ooooo`;o0000E?ooool2o`00013ooooo0ol0000Booooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`0001Sooooo0_l0
000Qooooo`;o00003oooool4o`0000Oooooo0_l0000;ooooo`;o00002_ooool2o`0000[ooooo0_l0
0004ooooo`;o00003Oooool2o`0000kooooo0_l0000Fooooo`;o0000:Oooool2o`00027ooooo0ol0
000<ooooo`;o00001_ooool2o`0001gooooo000Yooooo`;o00006?ooool2o`00027ooooo1?l0000=
ooooo`;o00002Oooool2o`0000_ooooo0_l0000Tooooo`;o00001?ooool3o`0002Kooooo0_l0000B
ooooo`;o00005Oooool3o`00023ooooo0ol0000<ooooo`;o00001_ooool2o`0000cooooo0_l0000?
ooooo`00:Oooool00ol0003oooooooooo`0looooo`;o0000Boooool2o`0000Cooooo0_l0000koooo
o`;o00005_ooool2o`0002?ooooo0_l0000Pooooo`;o00003oooool002Wooooo00?o0000oooooooo
ool07oooool2o`0000oooooo0_l0003Gooooo`;o00003Oooool2o`0002;ooooo000Yooooo`03o`00
0?oooooooooo01oooooo0_l0000?ooooo`;o0000i_ooool2o`0002;ooooo000Yooooo`03o`000?oo
oooooooo07Cooooo0_l0001Kooooo`;o0000JOooool002Wooooo0_l00002ooooo`;o00003Oooool2
o`0006;ooooo0_l0001Kooooo`;o0000JOooool002Wooooo00Co0000oooooooooooooooo0_l0000=
ooooo`;o0000@Oooool2o`000;kooooo0_l0000Wooooo`00:Oooool00ol0003oooooooooo`0Ooooo
o`;o0000<_ooool2o`0001Cooooo0_l0000aooooo`;o00009Oooool2o`00013ooooo0_l00008oooo
o`;o0000<_ooool2o`0002Oooooo000Yooooo`03o`000?oooooooooo01oooooo0_l00003ooooo`;o
0000;?ooool2o`0001Gooooo0_l0000aooooo`;o00009Oooool2o`0000?ooooo0_l0000;ooooo`;o
00002?ooool2o`0001Gooooo0_l00009ooooo`;o0000>Oooool002Wooooo00?o0000ooooooooool0
9?ooool2o`0002cooooo0_l0001/ooooo`;o00001_ooool2o`00017ooooo0_l0000Iooooo`;o0000
2Oooool2o`0001Kooooo0_l0000Qooooo`00:Oooool2o`0008Gooooo0_l0000jooooo`;o00006Ooo
ool2o`0003cooooo0_l0000Qooooo`00:Oooool00ol0003oooooooooo`24ooooo`;o00009_ooool2
o`0002Sooooo0_l00002ooooo`;o0000H?ooool002Wooooo00?o0000ooooooooool01?ooool2o`00
00oooooo0_l0000Tooooo`;o0000Koooool2o`0002Sooooo0_l00002ooooo`;o00006oooool2o`00
04?ooooo000Yooooo`03o`000?oooooooooo00Cooooo0_l0000?ooooo`;o00009?ooool2o`0003Oo
oooo1?l0000jooooo`Go0000>_ooool2o`0000Cooooo0_l0000fooooo`;o00002oooool002Wooooo
00?o0000ooooooooool01Oooool2o`0001_ooooo0_l0000Zooooo`;o00000oooool2o`0001Oooooo
0_l00006ooooo`Co00004_ooool2o`0000Gooooo0_l0000Oooooo`Go00002_ooool2o`0001Wooooo
0_l000000ooooooo0000o`00000;ooooo`;o00000oooool3o`0001Gooooo0_l0000Tooooo`;o0000
2oooool002Wooooo0_l00006ooooo`;o00006oooool2o`00013ooooo0_l0000Hooooo`;o00000ooo
ool2o`0001Oooooo0_l00003ooooo`;o00005oooool2o`0000Gooooo0_l0000^ooooo`?o00006?oo
ool2o`000003ooooool0003o000000Kooooo0_l00003ooooo`;o00001?ooool2o`0001Gooooo0_l0
000aooooo`00:Oooool00ol0003oooooooooo`0<ooooo`;o00001oooool2o`0001gooooo0_l0000[
ooooo`;o00002oooool2o`000003ooooool0003o000000oooooo0_l0000eooooo`;o00001oooool2
o`0001Sooooo0_l00009ooooo`;o00000_ooool2o`0004oooooo000>ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo00cooooo0_l00007ooooo`;o0000<?ooool2o`0001Sooooo0_l0000;ooooo`;o00000_oo
ool2o`0000kooooo0_l00006ooooo`;o00000_ooool2o`0000Oooooo0_l0000Pooooo`;o00008_oo
ool2o`0000cooooo0_l0000Hooooo`;o00004oooool2o`0000Cooooo0_l0000Jooooo`003_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0Aoooool2o`0002Wooooo0_l000000ooooooo0000o`00000Cooooo`;o00000_oo
ool2o`0000Oooooo0_l00014ooooo`;o00006oooool2o`0000Cooooo0_l00003ooooo`;o00004ooo
ool2o`0000Cooooo0_l0000Jooooo`003_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o
0000ooooooooool00oooool3o`0005Wooooo0_l0000Jooooo`;o0000Aoooool2o`0003[ooooo0_l0
0004ooooo`;o0000>_ooool000kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0FOooool2o`0006?ooooo0_l0001looooo`003_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo
000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgM
g@05ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00gooooo00?o
ZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolmooooo`001_ooool0
1Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVY
ZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo
0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`;o0000oooooolnooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool001oooooo1?l000000ol@413oooooooooo`03
ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo0ol0003oooooocgo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool001oooooo00?oEEEEofIVI_l00000oooooom7ooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .36837 Mdot
.02762 .39883 Mdot
.02952 .30867 Mdot
.03143 .29666 Mdot
.03333 .29576 Mdot
.03524 .28175 Mdot
.03714 .31969 Mdot
.03905 .339 Mdot
.04095 .30339 Mdot
.04286 .34465 Mdot
.04476 .31783 Mdot
.04667 .38231 Mdot
.04857 .41212 Mdot
.05048 .34087 Mdot
.05238 .40943 Mdot
.05429 .33376 Mdot
.05619 .31011 Mdot
.0581 .41206 Mdot
.06 .25305 Mdot
.0619 .3447 Mdot
.06381 .40317 Mdot
.06571 .4069 Mdot
.06762 .40278 Mdot
.06952 .40896 Mdot
.07143 .43007 Mdot
.07333 .36562 Mdot
.07524 .28337 Mdot
.07714 .2523 Mdot
.07905 .32232 Mdot
.08095 .40206 Mdot
.08286 .38647 Mdot
.08476 .28754 Mdot
.08667 .34152 Mdot
.08857 .25919 Mdot
.09048 .24699 Mdot
.09238 .32845 Mdot
.09429 .23044 Mdot
.09619 .25732 Mdot
.0981 .27381 Mdot
.1 .3803 Mdot
.1019 .42127 Mdot
.10381 .25433 Mdot
.10571 .25117 Mdot
.10762 .36472 Mdot
.10952 .34399 Mdot
.11143 .33434 Mdot
.11333 .32998 Mdot
.11524 .24657 Mdot
.11714 .37235 Mdot
.11905 .30199 Mdot
.12095 .24987 Mdot
.12286 .26746 Mdot
.12476 .3894 Mdot
.12667 .24517 Mdot
.12857 .24167 Mdot
.13048 .32582 Mdot
.13238 .35002 Mdot
.13429 .32125 Mdot
.13619 .23276 Mdot
.1381 .33658 Mdot
.14 .34498 Mdot
.1419 .46247 Mdot
.14381 .2606 Mdot
.14571 .28893 Mdot
.14762 .36565 Mdot
.14952 .30041 Mdot
.15143 .34365 Mdot
.15333 .33441 Mdot
.15524 .26282 Mdot
.15714 .40305 Mdot
.15905 .33067 Mdot
.16095 .30415 Mdot
.16286 .33885 Mdot
.16476 .34703 Mdot
.16667 .26047 Mdot
.16857 .27801 Mdot
.17048 .38894 Mdot
.17238 .36295 Mdot
.17429 .28164 Mdot
.17619 .36097 Mdot
.1781 .36447 Mdot
.18 .40161 Mdot
.1819 .29095 Mdot
.18381 .25473 Mdot
.18571 .32077 Mdot
.18762 .32876 Mdot
.18952 .29984 Mdot
.19143 .33197 Mdot
.19333 .33944 Mdot
.19524 .33651 Mdot
.19714 .4333 Mdot
.19905 .44299 Mdot
.20095 .26693 Mdot
.20286 .32683 Mdot
.20476 .27012 Mdot
.20667 .45397 Mdot
.20857 .34161 Mdot
.21048 .26959 Mdot
.21238 .38544 Mdot
.21429 .34761 Mdot
.21619 .37821 Mdot
.2181 .35594 Mdot
.22 .38998 Mdot
.2219 .37532 Mdot
.22381 .38783 Mdot
.22571 .25469 Mdot
.22762 .3124 Mdot
.22952 .25116 Mdot
.23143 .26675 Mdot
.23333 .39925 Mdot
.23524 .34486 Mdot
.23714 .28437 Mdot
.23905 .28859 Mdot
.24095 .35047 Mdot
.24286 .2982 Mdot
.24476 .29274 Mdot
.24667 .35488 Mdot
.24857 .28971 Mdot
.25048 .28441 Mdot
.25238 .23129 Mdot
.25429 .41083 Mdot
.25619 .45664 Mdot
.2581 .39666 Mdot
.26 .32539 Mdot
.2619 .40102 Mdot
.26381 .31069 Mdot
.26571 .33595 Mdot
.26762 .45937 Mdot
.26952 .39599 Mdot
.27143 .32727 Mdot
.27333 .40636 Mdot
.27524 .38756 Mdot
.27714 .3988 Mdot
.27905 .27577 Mdot
.28095 .26069 Mdot
.28286 .30583 Mdot
.28476 .24424 Mdot
.28667 .32469 Mdot
.28857 .33863 Mdot
.29048 .36344 Mdot
.29238 .40831 Mdot
.29429 .46193 Mdot
.29619 .26067 Mdot
.2981 .25949 Mdot
.3 .31199 Mdot
.3019 .34981 Mdot
.30381 .30892 Mdot
.30571 .25826 Mdot
.30762 .26778 Mdot
.30952 .33606 Mdot
.31143 .44824 Mdot
.31333 .36142 Mdot
.31524 .28738 Mdot
.31714 .41032 Mdot
.31905 .31002 Mdot
.32095 .32748 Mdot
.32286 .24387 Mdot
.32476 .26414 Mdot
.32667 .30054 Mdot
.32857 .23018 Mdot
.33048 .24409 Mdot
.33238 .37266 Mdot
.33429 .2898 Mdot
.33619 .40298 Mdot
.3381 .33834 Mdot
.34 .26289 Mdot
.3419 .38044 Mdot
.34381 .30861 Mdot
.34571 .3857 Mdot
.34762 .26478 Mdot
.34952 .25705 Mdot
.35143 .303 Mdot
.35333 .261 Mdot
.35524 .26715 Mdot
.35714 .31317 Mdot
.35905 .26754 Mdot
.36095 .35631 Mdot
.36286 .45512 Mdot
.36476 .32644 Mdot
.36667 .30264 Mdot
.36857 .30346 Mdot
.37048 .27234 Mdot
.37238 .39508 Mdot
.37429 .34456 Mdot
.37619 .42409 Mdot
.3781 .33046 Mdot
.38 .30825 Mdot
.3819 .45685 Mdot
.38381 .26805 Mdot
.38571 .40155 Mdot
.38762 .25198 Mdot
.38952 .4512 Mdot
.39143 .35199 Mdot
.39333 .29994 Mdot
.39524 .46048 Mdot
.39714 .33179 Mdot
.39905 .42961 Mdot
.40095 .39306 Mdot
.40286 .32369 Mdot
.40476 .44173 Mdot
.40667 .30004 Mdot
.40857 .28533 Mdot
.41048 .28778 Mdot
.41238 .29901 Mdot
.41429 .30372 Mdot
.41619 .43464 Mdot
.4181 .38532 Mdot
.42 .3165 Mdot
.4219 .29737 Mdot
.42381 .27264 Mdot
.42571 .33157 Mdot
.42762 .32047 Mdot
.42952 .41185 Mdot
.43143 .3611 Mdot
.43333 .38452 Mdot
.43524 .34343 Mdot
.43714 .3829 Mdot
.43905 .35892 Mdot
.44095 .40683 Mdot
.44286 .33218 Mdot
.44476 .34374 Mdot
.44667 .3685 Mdot
.44857 .35226 Mdot
.45048 .24508 Mdot
.45238 .39105 Mdot
.45429 .35179 Mdot
.45619 .34178 Mdot
.4581 .27812 Mdot
.46 .3922 Mdot
.4619 .26009 Mdot
.46381 .40961 Mdot
.46571 .45761 Mdot
.46762 .32169 Mdot
.46952 .29843 Mdot
.47143 .4235 Mdot
.47333 .35745 Mdot
.47524 .29619 Mdot
.47714 .45474 Mdot
.47905 .26284 Mdot
.48095 .3795 Mdot
.48286 .40374 Mdot
.48476 .38455 Mdot
.48667 .46234 Mdot
.48857 .25977 Mdot
.49048 .38045 Mdot
.49238 .33086 Mdot
.49429 .27728 Mdot
.49619 .26908 Mdot
.4981 .23681 Mdot
.5 .32591 Mdot
.5019 .33308 Mdot
.50381 .26503 Mdot
.50571 .42905 Mdot
.50762 .29237 Mdot
.50952 .29148 Mdot
.51143 .23177 Mdot
.51333 .3686 Mdot
.51524 .26825 Mdot
.51714 .24111 Mdot
.51905 .27562 Mdot
.52095 .35334 Mdot
.52286 .23819 Mdot
.52476 .36726 Mdot
.52667 .29716 Mdot
.52857 .34849 Mdot
.53048 .31878 Mdot
.53238 .35747 Mdot
.53429 .36491 Mdot
.53619 .3209 Mdot
.5381 .29018 Mdot
.54 .31432 Mdot
.5419 .37039 Mdot
.54381 .33637 Mdot
.54571 .24151 Mdot
.54762 .34728 Mdot
.54952 .36424 Mdot
.55143 .24886 Mdot
.55333 .34508 Mdot
.55524 .25583 Mdot
.55714 .25802 Mdot
.55905 .32907 Mdot
.56095 .31473 Mdot
.56286 .29856 Mdot
.56476 .32405 Mdot
.56667 .34567 Mdot
.56857 .23047 Mdot
.57048 .38094 Mdot
.57238 .25104 Mdot
.57429 .31633 Mdot
.57619 .30011 Mdot
.5781 .36778 Mdot
.58 .33787 Mdot
.5819 .36767 Mdot
.58381 .4553 Mdot
.58571 .23514 Mdot
.58762 .39789 Mdot
.58952 .24331 Mdot
.59143 .31332 Mdot
.59333 .22907 Mdot
.59524 .45827 Mdot
.59714 .37814 Mdot
.59905 .406 Mdot
.60095 .24151 Mdot
.60286 .36912 Mdot
.60476 .24301 Mdot
.60667 .38758 Mdot
.60857 .28213 Mdot
.61048 .42322 Mdot
.61238 .32911 Mdot
.61429 .26225 Mdot
.61619 .3697 Mdot
.6181 .27234 Mdot
.62 .41054 Mdot
.6219 .3067 Mdot
.62381 .40946 Mdot
.62571 .44561 Mdot
.62762 .30363 Mdot
.62952 .35225 Mdot
.63143 .25495 Mdot
.63333 .37255 Mdot
.63524 .31644 Mdot
.63714 .39985 Mdot
.63905 .45045 Mdot
.64095 .46566 Mdot
.64286 .3206 Mdot
.64476 .2705 Mdot
.64667 .25712 Mdot
.64857 .25059 Mdot
.65048 .27134 Mdot
.65238 .27159 Mdot
.65429 .31866 Mdot
.65619 .31553 Mdot
.6581 .35743 Mdot
.66 .23127 Mdot
.6619 .27409 Mdot
.66381 .40981 Mdot
.66571 .32771 Mdot
.66762 .29687 Mdot
.66952 .39387 Mdot
.67143 .27253 Mdot
.67333 .26284 Mdot
.67524 .37263 Mdot
.67714 .30107 Mdot
.67905 .40652 Mdot
.68095 .3697 Mdot
.68286 .40002 Mdot
.68476 .28226 Mdot
.68667 .33831 Mdot
.68857 .28667 Mdot
.69048 .32587 Mdot
.69238 .40377 Mdot
.69429 .26008 Mdot
.69619 .35311 Mdot
.6981 .46269 Mdot
.7 .37602 Mdot
.7019 .23009 Mdot
.70381 .32748 Mdot
.70571 .37214 Mdot
.70762 .29209 Mdot
.70952 .31206 Mdot
.71143 .35805 Mdot
.71333 .37707 Mdot
.71524 .46864 Mdot
.71714 .3788 Mdot
.71905 .39909 Mdot
.72095 .40284 Mdot
.72286 .41712 Mdot
.72476 .28501 Mdot
.72667 .3613 Mdot
.72857 .41073 Mdot
.73048 .35024 Mdot
.73238 .28202 Mdot
.73429 .37828 Mdot
.73619 .36847 Mdot
.7381 .29088 Mdot
.74 .37563 Mdot
.7419 .27862 Mdot
.74381 .3797 Mdot
.74571 .22964 Mdot
.74762 .23469 Mdot
.74952 .40272 Mdot
.75143 .23429 Mdot
.75333 .40554 Mdot
.75524 .4234 Mdot
.75714 .2872 Mdot
.75905 .2349 Mdot
.76095 .32461 Mdot
.76286 .30691 Mdot
.76476 .44346 Mdot
.76667 .34703 Mdot
.76857 .3178 Mdot
.77048 .39433 Mdot
.77238 .40227 Mdot
.77429 .26863 Mdot
.77619 .3463 Mdot
.7781 .36222 Mdot
.78 .28837 Mdot
.7819 .24843 Mdot
.78381 .39782 Mdot
.78571 .45976 Mdot
.78762 .39708 Mdot
.78952 .28549 Mdot
.79143 .40335 Mdot
.79333 .28661 Mdot
.79524 .26316 Mdot
.79714 .26415 Mdot
.79905 .27731 Mdot
.80095 .35818 Mdot
.80286 .38157 Mdot
.80476 .28592 Mdot
.80667 .25948 Mdot
.80857 .3174 Mdot
.81048 .33678 Mdot
.81238 .44022 Mdot
.81429 .31749 Mdot
.81619 .34666 Mdot
.8181 .26853 Mdot
.82 .28179 Mdot
.8219 .32139 Mdot
.82381 .31079 Mdot
.82571 .26414 Mdot
.82762 .29754 Mdot
.82952 .31346 Mdot
.83143 .45314 Mdot
.83333 .36035 Mdot
.83524 .30767 Mdot
.83714 .24499 Mdot
.83905 .31159 Mdot
.84095 .34745 Mdot
.84286 .36825 Mdot
.84476 .26824 Mdot
.84667 .44263 Mdot
.84857 .45509 Mdot
.85048 .38629 Mdot
.85238 .32628 Mdot
.85429 .36707 Mdot
.85619 .31288 Mdot
.8581 .32546 Mdot
.86 .4143 Mdot
.8619 .30814 Mdot
.86381 .40316 Mdot
.86571 .40151 Mdot
.86762 .26002 Mdot
.86952 .2663 Mdot
.87143 .2775 Mdot
.87333 .35485 Mdot
.87524 .36598 Mdot
.87714 .4423 Mdot
.87905 .33039 Mdot
.88095 .24314 Mdot
.88286 .26259 Mdot
.88476 .2824 Mdot
.88667 .30717 Mdot
.88857 .34731 Mdot
.89048 .34159 Mdot
.89238 .30622 Mdot
.89429 .29383 Mdot
.89619 .39404 Mdot
.8981 .3501 Mdot
.9 .33771 Mdot
.9019 .37189 Mdot
.90381 .29888 Mdot
.90571 .46501 Mdot
.90762 .34621 Mdot
.90952 .35892 Mdot
.91143 .4269 Mdot
.91333 .31684 Mdot
.91524 .22925 Mdot
.91714 .36932 Mdot
.91905 .30788 Mdot
.92095 .32949 Mdot
.92286 .37688 Mdot
.92476 .25159 Mdot
.92667 .35297 Mdot
.92857 .26466 Mdot
.93048 .46207 Mdot
.93238 .26905 Mdot
.93429 .28329 Mdot
.93619 .25296 Mdot
.9381 .3627 Mdot
.94 .29191 Mdot
.9419 .32864 Mdot
.94381 .24358 Mdot
.94571 .25182 Mdot
.94762 .28864 Mdot
.94952 .36714 Mdot
.95143 .30262 Mdot
.95333 .28677 Mdot
.95524 .36067 Mdot
.95714 .27072 Mdot
.95905 .25355 Mdot
.96095 .27274 Mdot
.96286 .31368 Mdot
.96476 .26937 Mdot
.96667 .39655 Mdot
.96857 .2574 Mdot
.97048 .3399 Mdot
.97238 .25978 Mdot
.97429 .31638 Mdot
.97619 .39062 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`;o0000BOoo
ool2o`0004_ooooo0_l00006ooooo`;o00008Oooool2o`0000cooooo0_l0000eooooo`;o00007ooo
ool000Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o
MgMgoc8b<_ooool01?ooool3o`0001?ooooo0_l0000;ooooo`;o00009?ooool2o`0001Kooooo0_l0
000iooooo`;o00004?ooool2o`0000Kooooo0_l0000Dooooo`;o00002oooool2o`0000cooooo0_l0
000eooooo`;o00007oooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo023ooooo
0_l0000Tooooo`;o0000COooool2o`0000;ooooo0_l0000Fooooo`;o00005_ooool2o`0001[ooooo
0ol000000ooooooo0000o`00001Aooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo09Gooooo
0_l00006ooooo`;o00004_ooool2o`0003;ooooo0ol000000ooooooo0000o`00001Aooooo`001_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool07_ooool2o`0007_ooooo1?l00005ooooo`;o
00003?ooool2o`0000;ooooo0ol0001Gooooo`;o0000:_ooool000Kooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000oooo
ooooool06_ooool2o`000004ooooool0003o0000o`00033ooooo0_l0000:ooooo`;o000000?ooooo
o`000?l000009?ooool2o`0001Cooooo0_l00007ooooo`;o00003?ooool2o`0000;ooooo0ol00019
ooooo`;o00003?ooool2o`0001;ooooo0_l0000Fooooo`00:Oooool2o`0001?ooooo0_l00006oooo
o`;o000000?oooooo`000?l00000<Oooool2o`0000[ooooo0_l000000ooooooo0000o`00000Toooo
o`;o00007oooool2o`0004Sooooo0_l0000@ooooo`;o00008?ooool2o`0001Kooooo000Yooooo`03
o`000?oooooooooo00gooooo0_l00003ooooo`;o00000oooool2o`0000?ooooo0_l0000Pooooo`;o
0000<Oooool2o`0003?ooooo0_l00005ooooo`;o00005_ooool2o`0002Wooooo0_l0000/ooooo`;o
00001Oooool2o`0001Gooooo000Yooooo`03o`000?oooooooooo00Sooooo0_l00003ooooo`;o0000
1oooool3o`0000?ooooo0_l0000Booooo`;o00002oooool3o`00037ooooo0_l0000dooooo`;o0000
1?ooool2o`00017ooooo0_l00003ooooo`;o0000Eoooool2o`0000;ooooo0_l000000ooooooo0000
o`000002ooooo`;o00004Oooool002Wooooo00?o0000ooooooooool02?ooool2o`0000[ooooo1?l0
000Hooooo`;o00002oooool2o`0001Sooooo0_l0000<ooooo`;o0000@?ooool3o`0001Kooooo0_l0
0003ooooo`;o0000Foooool2o`0000Gooooo0_l000000ooooooo0000o`00000>ooooo`00:Oooool0
0ol0003oooooooooo`0Aooooo`;o000000?oooooo`000?l000003Oooool2o`0000Gooooo0_l0000S
ooooo`;o00000oooool2o`000003ooooool0003o000000cooooo0ol0000Qooooo`;o00001oooool2
o`0001Cooooo0_l0000Kooooo`;o00003Oooool2o`0002;ooooo0_l0000Booooo`;o00007_ooool3
o`0000gooooo000Yooooo`;o00004_ooool2o`00013ooooo0_l00002ooooo`;o000000?oooooo`00
0?l000008oooool2o`0000?ooooo0_l00007ooooo`;o00000oooool6o`00027ooooo0_l00004oooo
o`;o000000?oooooo`000?l000000oooool2o`00027ooooo0_l0000Aooooo`;o00001Oooool2o`00
01kooooo0ol000000ooooooo0000o`000004ooooo`;o00003?ooool2o`0000;ooooo0_l0000=oooo
o`;o00003?ooool2o`0000gooooo000Yooooo`03o`000?oooooooooo01cooooo0_l00009ooooo`;o
00003?ooool2o`0000Sooooo0_l0000Gooooo`;o00000oooool2o`0000?ooooo1?l000001?oooooo
0000o`000?l00006ooooo`;o00007Oooool2o`0000Kooooo0_l000000ooooooo0000o`00000Noooo
o`;o00004Oooool2o`0002Gooooo0ol00007ooooo`;o00001?ooool2o`0000Kooooo0_l00002oooo
o`;o00003Oooool2o`0001_ooooo000Yooooo`03o`000?oooooooooo01cooooo0_l0000Booooo`Co
000000?o410@o`000?l000000ol000000olb<S;ok^k^ooooo`02ooooo`?o000000?o<S8bonk^k_oo
ool04oooool2o`0000gooooo0ol00003ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Booooo`;o00001?ooool2o`0000kooooo00GoV9RH
oa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo1?l0000Qooooo`;o000000?o410@ooooooooool00_l000001?lb<S;o
0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_l00006ooooo`;o00001_ooool2
o`0001;ooooo0_l00003ooooo`03odA4A?l0003o000000;o000000Ooooooo`000?l0003o<S8bo`00
0?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool00ol0003ooooo
ooooo`0Dooooo`;o00007?ooool01?l0003oooooooooooooool4o`000003oiRHV?mgMgOooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Xooooo`;o000000Co8B4Qonk^k_ooooooA4A40oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0_l000000oooooooV9RHogMgM`0Booooo`;o00005?oo
ool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMol0003o0000oiRHV?mgMgL01Oooool4o`000003ooooool0003o000000;ooooo0_l0000Koooo
o`04o`000?ooooooooooooooo`;o000000CoV9RHoooooonHV9SoMgMg0oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00;o00008_ooool2o`0000Kooooo1Ol000001?nHV9SooooooiRHV?mgMgL3ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wooooo00?o0000ooooooooool05?ooool2o`0001co
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooo
oooooooooooooa0@400:ooooo`;o00007?ooool2o`000003oiRHV?lQ8B7ok^k^00Cooooo00Go410@
oooooooooooooooooa0@4003ooooo`;o00000_ooool00ol@413oooooooooo`0@ooooo`;o00001_oo
ool2o`00013ooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
41000_l000000ooooooo410@ooooo`06ooooo`;o000000?oooooo`000?l000000_ooool2o`0001So
oooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41000_ooool2o`0000?ooooo00?o410@oooo
ooooool03oooool2o`0001[ooooo0ol000001Ol@413ooooooooooooooooo410@00?ooooo00Go410@
oooooooooooooooooa0@4003ooooo`00:Oooool2o`0002cooooo0_l00005ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
2_ooool2o`0001oooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000006ooooo`;o00002_ooool2o`0000Kooooo0_l0000?oooo
o`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000009?ooool2o`0000;ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000000;ooooo0_l00003ooooo`03o`000?oooooooooo00oooooo0_l0000Iooooo`05
ogMgMolb<S;oooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool00Oooool002Wooooo00?o0000ooooooooool00_l0000;ooooo`;o00007?ooool4o`00
00?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`00000/ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000001_ooool2o`0002;ooooo00?o410@o`000?nj
^[X00oooool01_l0003ooooooooooooooooo0000ooooo`?o00000oooool00ol0003oooooooooo`0@
ooooo`;o00003Oooool2o`000003ooooool0003o000000;ooooo00CogMgMoeEEEOoooooo00001?oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooooooo0ol0000Cooooo`;o
00003_ooool2o`0000;ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo000Yooooo`03o`000?oooooo
oooo00;o00002oooool2o`0001kooooo0_l00003ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@4003ooooo`06oa0@4?oooooo0000o`000?l@413ooooo0_l0000Zooooo`05
o`000?ooooooooooooooool@41000_ooool2o`0000?ooooo00Go410@oooooooooooooooooa0@400[
ooooo`03okZj^_lQ8B7ooooo00;ooooo00Ko410@oooooooooooooooooa0@4?ooool2o`000005oa0@
4?ooooooooooooooool@41004_ooool3o`0000[ooooo1?l00006ooooo`03ogMgMoo<c<co000000Co
oooo00?o410@ooooooooool01?l000000ooooooo0000o`000002ooooo`03oa0@4?l0003o000001?o
oooo0_l0000>ooooo`;o00000_ooool01?l0003oooooo`000?l00003ooooo`05oa0@4?oooooooooo
ooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo000Yooooo`03o`000?oooooo
oooo013ooooo0_l0000Aooooo`;o00003Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool01_mgMgOoV9RHo`000?l0003oMgMgooooo`;o00004oooool2o`0000Co
oooo0_l0000;ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool00omgMgOoV9RHooooo`03o`00
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Xooooo`05oa0@4?nHV9SooooookZj^_l000000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Cooooo`;o
00002_ooool2o`0000Sooooo0ol00004ooooo`;o000000?oooooo`000?l000000_l000001_oooooo
0000o`000?ooooooV9RHogMgMbWooooo1?l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000Yooooo`03o`000?oooooooooo013ooooo0_l0
000Aooooo`;o00002_ooool2o`000003ofIVI_l0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`03onk^k_lb<S;o000000Go00004oooool2o`0000Cooooo0_l0000;ooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`00oooool01?o^k^ko<S8bo`000?lb<S82o`0000;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Fooooo`;o00002?ooool2o`0000Kooooo00GoZJVYoa0@4?l0003o410@ojVY
Z@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Wo
oooo0_l00008ooooo`;o00001?ooool3o`0000Cooooo0ol000000olb<S;ok^k^ooooo`02ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h09oooool6o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool002Wooooo1?l0000^ooooo`;o00004_ooool2
o`0004Sooooo0_l00009ooooo`;o00002?ooool2o`0003Cooooo0_l00008ooooo`;o0000<?ooool2
o`0000gooooo0_l0000Gooooo`00:Oooool01?l0003oooooo`000?l00012ooooo`;o0000=?ooool2
o`000003ooooool0003o000000kooooo0ol0000?ooooo`;o00002_ooool2o`0001oooooo0_l0000b
ooooo`;o00004oooool2o`000003ooooool0003o000002?ooooo000Yooooo`04o`000?oooooo0000
o`0001[ooooo0_l00008ooooo`;o00002oooool2o`0000oooooo0_l0000Iooooo`;o00004oooool2
o`0000;ooooo1?l000000ooooooo0000o`00000>ooooo`;o00004?ooool2o`0000[ooooo0_l00002
ooooo`;o00006oooool2o`000003ooooool0003o000002oooooo0_l0000Fooooo`;o00008oooool0
02Wooooo00?o0000ooooooooool00_ooool2o`0001Oooooo0_l00008ooooo`;o000000?oooooo`00
0?l000002?ooool2o`0002[ooooo0_l00006ooooo`;o00000oooool2o`0000Kooooo0_l00002oooo
o`;o000000?oooooo`000?l00000<_ooool2o`0000kooooo0_l0000>ooooo`;o0000Eoooool2o`00
01?ooooo000Yooooo`?o00000_ooool2o`0002Cooooo0_l0000Vooooo`;o00004Oooool2o`000003
ooooool0003o000000?ooooo0_l00002ooooo`;o00002Oooool2o`00047ooooo0ol0000Zooooo`;o
00005Oooool2o`0000Oooooo0_l00006ooooo`Co00001_ooool2o`0000Wooooo0_l0000Cooooo`00
8Oooooooo`0004Co00001?ooool002Wooooo00?o0000ooooooooool01oooool3o`0000cooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00Co
0000oooooooooooooooo0_l00007ooooo`04o`000?oooooo0000o`0000Sooooo00?o0000ooooool0
00000_l00003ooooo`;o00000_ooool00ol0003oooooooooo`05ooooo`;o00000_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00?ooooo0_l00005ooooo`;o00002?ooool3o`0000_o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`;o00002oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo0ol000000ooooooo0000o`000004ooooo`;o
000000?oooooo`000?ooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Co
oooo0_l00003ooooo`03o`000?oooooooooo00[ooooo000Yooooo`03o`000?oooooooooo00?ooooo
0_l0000eooooo`04o`000?ooooooooooooooo`;o00005Oooool2o`00013ooooo0_l0000?ooooo`04
o`000?ooooooooooooooo`;o00009?ooool2o`0000Gooooo0_l00002ooooo`;o00001?ooool3o`00
00_ooooo0_l00005ooooo`;o00003oooool2o`00017ooooo0_l00004ooooo`03o`000?oooooooooo
00Cooooo0ol00003ooooo`;o00001oooool2o`00013ooooo0_l0000>ooooo`;o00000_ooool2o`00
00cooooo000Yooooo`04o`000?ooooooooooooooo`Co00006oooool2o`0000kooooo0_l0001:oooo
o`Co00007oooool4o`0000[ooooo0_l0000Booooo`Co00000_ooool3o`0002;ooooo0_l0000;oooo
o`?o00007_ooool2o`0001;ooooo0_l0000<ooooo`00:Oooool01?l0003oooooooooooooool2o`00
00_ooooo0_l0000@ooooo`;o00003_ooool2o`0004Cooooo0_l00006ooooo`;o00002oooool2o`00
01;ooooo1?l00007ooooo`;o00005oooool2o`0000;ooooo0_l0000dooooo`;o0000?Oooool002Wo
oooo0_l0000?ooooo`;o00003oooool2o`0001Gooooo0_l0000@ooooo`;o00000_ooool2o`0000?o
oooo0_l00009ooooo`;o00003?ooool2o`0000[ooooo0_l0000Cooooo`;o00002?ooool2o`0001?o
oooo0_l0000Wooooo`;o00000_ooool2o`00013ooooo0_l0000Booooo`;o00002?ooool4o`00037o
oooo000Yooooo`03o`000?oooooooooo01;ooooo0_l00005ooooo`;o00001?ooool2o`00013ooooo
0_l00003ooooo`;o00004?ooool2o`0000;ooooo0_l00003ooooo`;o00002Oooool2o`0000cooooo
0_l00002ooooo`;o00009Oooool2o`00017ooooo0_l0000@ooooo`;o00003oooool2o`0000Kooooo
0_l00002ooooo`;o00004?ooool2o`0001cooooo1?l00004ooooo`;o00003?ooool2o`0000Cooooo
0_l0000Gooooo`00:Oooool00ol0003oooooooooo`0Booooo`;o00001Oooool2o`0000gooooo0_l0
0007ooooo`?o0000>_ooool2o`0000Cooooo0_l00007ooooo`;o00001?ooool2o`0000kooooo0_l0
00000ooooooo0000o`00000@ooooo`;o00004?ooool2o`0000oooooo0_l00012ooooo`;o00003?oo
ool2o`0000Cooooo0_l0000Gooooo`00:Oooool00ol0003oooooooooo`06ooooo`;o00004?ooool2
o`0000Oooooo0_l00003ooooo`Co00002?ooool3o`0001Gooooo0_l0000<ooooo`;o00006_ooool2
o`0000Oooooo0_l00004ooooo`;o00003_ooool2o`000003ooooool0003o000000_ooooo0_l0001D
ooooo`;o0000@Oooool002Wooooo00Co0000oooooooooooooooo0_l00003ooooo`;o00004?ooool2
o`0000Oooooo0_l00003ooooo`;o000000?oooooo`000?l000002?ooool2o`0001Gooooo0_l00005
ooooo`;o00001Oooool2o`0000Oooooo0_l00010ooooo`;o00002_ooool2o`00023ooooo0_l0000V
ooooo`;o00006oooool2o`0001Gooooo0_l0000=ooooo`00:Oooool2o`0000;ooooo0_l00002oooo
o`;o00002Oooool2o`0001Oooooo0_l00008ooooo`;o00000oooool2o`0001Oooooo0_l0000>oooo
o`;o00009?ooool2o`0002Kooooo0_l0000Pooooo`;o0000@?ooool2o`000003ooooool0003o0000
01Gooooo0_l0000=ooooo`00:Oooool00ol0003oooooooooo`02ooooo`;o000000?oooooo`000?l0
00000_ooool2o`0000Gooooo0_l00006ooooo`;o00002?ooool2o`000003ooooool0003o0000017o
oooo0_l00006ooooo`;o0000:oooool2o`0001;ooooo0_l000001?oooooo0000o`000?ooool2o`00
01kooooo0_l00002ooooo`;o0000I_ooool2o`0002Oooooo000Yooooo`03o`000?oooooooooo00;o
oooo0_l00005ooooo`;o00003Oooool2o`0000Sooooo0_l000000ooooooo0000o`000003ooooo`;o
00003_ooool2o`0000Cooooo0_l0000[ooooo`;o00004_ooool2o`000003ooooool0003o000001Wo
oooo0_l00004ooooo`Co00000_ooool2o`0003kooooo0_l000000ooooooo0000o`00000;ooooo`;o
00001_ooool2o`0000gooooo0_l00004ooooo`;o00008_ooool002Wooooo00?o0000ooooooooool0
7oooool2o`0000Wooooo0_l0000>ooooo`;o00001_ooool2o`0001;ooooo0_l0000Jooooo`;o0000
4Oooool4o`0001Kooooo0_l00004ooooo`;o00006?ooool2o`0001kooooo0_l0000:ooooo`;o0000
00?oooooo`000?l000002oooool2o`0000Kooooo0_l0000=ooooo`;o000000Coooooo`000?l0003o
oooo0_l0000Rooooo`00:Oooool00ol0003oooooooooo`0Oooooo`;o00008Oooool4o`00013ooooo
0_l0000Jooooo`;o00004Oooool4o`0001?ooooo0_l0000Qooooo`;o00004oooool2o`0000Wooooo
0_l0000/ooooo`;o00001_ooool2o`0000Sooooo0_l0000Kooooo`00:Oooool2o`0003cooooo0_l0
0007ooooo`;o00008oooool2o`0002;ooooo0_l0000=ooooo`;o00000_ooool2o`0002Kooooo0_l0
000:ooooo`;o00000oooool2o`0001_ooooo0_l0000Eooooo`;o00004?ooool2o`0001_ooooo000Y
ooooo`03o`000?oooooooooo02gooooo0_l0000<ooooo`;o00007?ooool2o`0000kooooo0_l0000D
ooooo`;o000000?oooooo`000?l000002Oooool2o`00017ooooo0_l0000Vooooo`;o00003oooool2
o`0000?ooooo0_l0000Fooooo`;o00002Oooool2o`0001Kooooo0_l0000=ooooo`;o00004_ooool0
02Wooooo00?o0000ooooooooool05oooool2o`0001?ooooo1?l0000Rooooo`;o00001Oooool2o`00
02Cooooo0_l000000ooooooo0000o`00000Qooooo`;o0000=oooool2o`0000oooooo0_l0000@oooo
o`;o00005_ooool2o`0000Oooooo0_l00004ooooo`;o00004_ooool002Wooooo00?o0000oooooooo
ool03?ooool2o`0000Wooooo0_l0000;ooooo`;o00001_ooool4o`0002;ooooo0_l00019ooooo`;o
000000?oooooo`000?l000000oooool2o`0000Oooooo1?l0000mooooo`;o00005_ooool2o`0000Go
oooo0_l0000Booooo`;o00000_ooool2o`0001Cooooo000Yooooo`;o00003Oooool2o`0001Kooooo
0_l0001Nooooo`;o00005?ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l0
00002Oooool4o`0000Cooooo0_l00003ooooo`;o00004oooool2o`0000oooooo0_l0000Qooooo`;o
000000?oooooo`000?l000001Oooool2o`0000cooooo0_l00008ooooo`;o00005?ooool002Wooooo
0_l0000Kooooo`;o0000@oooool2o`0002?ooooo0_l0000Dooooo`;o00001oooool2o`00017ooooo
0_l00003ooooo`;o00000oooool2o`0000cooooo1?l00006ooooo`;o00001oooool2o`00027ooooo
0_l0000Aooooo`;o00000oooool2o`0001kooooo000Yooooo`03o`000?oooooooooo01[ooooo0_l0
000Pooooo`;o00008Oooool2o`0005oooooo0_l0000<ooooo`;o00001_ooool6o`0000Oooooo0_l0
000booooo`;o00001?ooool2o`0001gooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`0Eooooo`;o00008oooool4o`00057ooooo0_l0000Tooooo`;o00007oooool2o`0000;ooooo
0ol00004ooooo`Go0000=oooool2o`0001gooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool01?ooool2o`0000oooooo0_l0000Sooooo`;o00009oooool2o`0001co
oooo0_l0000<ooooo`;o000000?oooooo`000?l000006?ooool2o`0000Oooooo0_l0000Tooooo`;o
00001?ooool2o`000003ooooool0003o0000017ooooo0_l00013ooooo`001_ooool01Ol@413ooooo
oooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Cooooo0_l00009ooooo`;o0000:?ooool2o`0002Sooooo0ol0000Eooooo`;o
00000oooool3o`0000gooooo1?l0000Hooooo`;o0000BOooool2o`0000gooooo0_l0000dooooo`00
1_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo
<S8booooo`04ooooo`?o00003oooool2o`0000cooooo0_l0000<ooooo`;o00003?ooool2o`0000;o
oooo0_l0000>ooooo`;o00005Oooool2o`0001Gooooo0_l00003ooooo`;o00003_ooool2o`0002Ko
oooo0_l0001<ooooo`;o0000=?ooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo
01gooooo0_l0000<ooooo`;o00003_ooool4o`0000kooooo0_l0000gooooo`;o000000?oooooo`00
0?l00000;Oooool2o`0007Gooooo0_l0000;ooooo`001_ooool01Ol@413ooooooooooooooooo410@
00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
03_ooooo0_l0000_ooooo`;o00002?ooool2o`0000kooooo0_l000000ooooooo0000o`000011oooo
o`;o00007_ooool2o`0002Oooooo0_l0000Hooooo`;o00002oooool000Kooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07
ooooo`;o0000BOooool2o`000004ooooool0003o0000ooooo`;o00007?ooool2o`0000Sooooo0_l0
000jooooo`;o00006?ooool2o`0001kooooo0_l00003ooooo`?o00008Oooool2o`0001Cooooo0_l0
000?ooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c004ooooo`Co00001_ooool2o`00013ooooo0_l0000Mooooo`;o00004?ooool2o`0000Kooooo
1Ol000000ooooooo0000o`00000Qooooo`;o0000?oooool2o`0000gooooo0_l0000=ooooo`;o0000
2_ooool2o`0001?ooooo0ol0000Gooooo`;o00007_ooool2o`0000oooooo000Yooooo`;o00002_oo
ool3o`0000?ooooo0_l0000Fooooo`;o00001Oooool2o`00013ooooo0_l00007ooooo`;o00005_oo
ool2o`0000kooooo0_l0000Mooooo`;o0000;oooool2o`0000gooooo0_l000000ooooooo0000o`00
0007ooooo`;o00002?ooool2o`0000Gooooo0_l00004ooooo`;o00005Oooool3o`0002oooooo000Y
ooooo`03o`000?oooooooooo00Wooooo0ol0000Kooooo`;o00009?ooool2o`0000Cooooo0_l0000<
ooooo`;o00007oooool2o`0000cooooo0_l0000Sooooo`;o00006?ooool2o`0000;ooooo0_l00007
ooooo`;o00002?ooool3o`0000Cooooo0_l00004ooooo`;o00005Oooool2o`00033ooooo000Yoooo
o`03o`000?oooooooooo00Gooooo0_l00003ooooo`?o0000>Oooool2o`0000Gooooo0_l00004oooo
o`;o00001_ooool2o`0002Gooooo0_l00006ooooo`;o0000:Oooool2o`0000Gooooo0ol0000;oooo
o`;o00000oooool2o`0000kooooo0_l00006ooooo`;o0000Doooool002Wooooo00?o0000oooooooo
ool01?ooool5o`0000;ooooo0_l0000iooooo`;o00004oooool2o`0002;ooooo0_l00009ooooo`;o
0000<?ooool3o`0000_ooooo0_l0000Cooooo`;o0000:?ooool2o`00037ooooo000Yooooo`03o`00
0?oooooooooo00Cooooo0_l000000ooooooo0000o`00001fooooo`;o0000G?ooool2o`0002[ooooo
0_l0000aooooo`00:Oooool2o`000=kooooo0_l0001Mooooo`00:Oooool00ol0003oooooooooo`0E
ooooo`;o0000MOooool2o`0002_ooooo0_l0000/ooooo`;o0000Doooool002Wooooo00?o0000oooo
ooooool05Oooool2o`0005Oooooo0_l0000Looooo`;o0000:oooool2o`0002cooooo0_l0000aoooo
o`;o00008?ooool002Wooooo00?o0000ooooooooool03?ooool2o`00063ooooo0_l00005ooooo`;o
00008?ooool2o`00087ooooo0_l0000Pooooo`00:Oooool00ol0003oooooooooo`0<ooooo`;o0000
Ioooool2o`00023ooooo0_l0002Sooooo`00:Oooool2o`0003Gooooo0_l00014ooooo`;o0000`?oo
ool002Wooooo00?o0000ooooooooool0=?ooool2o`0004Cooooo0_l00030ooooo`00:Oooool00ol0
003oooooooooo`1gooooo`;o0000POooool2o`0001?ooooo0_l0000[ooooo`00:Oooool00ol0003o
ooooooooo`0eooooo`;o0000@?ooool2o`0004Gooooo0_l0000[ooooo`;o00003Oooool2o`0000Wo
oooo0_l00008ooooo`;o0000:oooool002Wooooo00?o0000ooooooooool0=Oooool2o`0002;ooooo
0_l0001Sooooo`;o0000:oooool2o`0001Sooooo0_l0000eooooo`00:Oooool2o`0005[ooooo0_l0
000Gooooo`;o0000C_ooool2o`0007Sooooo000Yooooo`03o`000?oooooooooo03Oooooo0_l0000i
ooooo`;o00006_ooool2o`0003;ooooo0_l0000looooo`;o0000>_ooool000kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool0=oooool2o`0000kooooo0_l0000Pooooo`;o00001?ooool2o`0001Wooooo0_l0
0002ooooo`;o00008?ooool2o`0004kooooo0_l00003ooooo`;o0000=Oooool000kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo04Oooooo0_l00002ooooo`;o00007?ooool2o`0000Cooooo0_l00003ooooo`;o00005?oo
ool2o`0002Cooooo0_l00002ooooo`;o0000>oooool2o`0001;ooooo0_l0000eooooo`003_ooool0
1Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`0002;ooooo0_l0
000Wooooo`;o00001_ooool2o`0001oooooo0_l0000Kooooo`;o00008Oooool2o`0001oooooo0_l0
000Jooooo`;o0000;Oooool2o`0001[ooooo000>ooooo`05o`000?ooooooooooooooool000003ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02;ooooo0_l0000_ooooo`;o0000??oo
ool2o`00033ooooo0_l0000@ooooo`;o0000@Oooool2o`0000Kooooo0_l0000Jooooo`003_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0<?ooooo0_l0000Fooooo`;o0000>oooool2o`0002;ooooo000>ooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0=_ooooo
0_l0001Oooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool4o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^ko
oooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo?Ooo
ool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYoooo
o`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool0
1Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003ooooooooo
o`03ooooo`?o0000oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o
8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Ooo
ool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go
410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Co
oooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool001oooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo?Oooool0
027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03
o`000?oooooooooo00Gooooo0ol0003oooooocgooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001oooooo00?oEEEEofIVI_l0
0000oooooom7ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .28897 Mdot
.02762 .34817 Mdot
.02952 .30411 Mdot
.03143 .25891 Mdot
.03333 .25036 Mdot
.03524 .24557 Mdot
.03714 .2997 Mdot
.03905 .23354 Mdot
.04095 .22839 Mdot
.04286 .34058 Mdot
.04476 .35084 Mdot
.04667 .27645 Mdot
.04857 .40056 Mdot
.05048 .34889 Mdot
.05238 .32313 Mdot
.05429 .27972 Mdot
.05619 .36766 Mdot
.0581 .40234 Mdot
.06 .31308 Mdot
.0619 .41003 Mdot
.06381 .40822 Mdot
.06571 .38219 Mdot
.06762 .39631 Mdot
.06952 .40735 Mdot
.07143 .35858 Mdot
.07333 .31723 Mdot
.07524 .34026 Mdot
.07714 .30639 Mdot
.07905 .39932 Mdot
.08095 .36138 Mdot
.08286 .41125 Mdot
.08476 .23103 Mdot
.08667 .23627 Mdot
.08857 .33824 Mdot
.09048 .32441 Mdot
.09238 .39862 Mdot
.09429 .31452 Mdot
.09619 .31962 Mdot
.0981 .37031 Mdot
.1 .27241 Mdot
.1019 .33895 Mdot
.10381 .33447 Mdot
.10571 .27351 Mdot
.10762 .28053 Mdot
.10952 .25561 Mdot
.11143 .26267 Mdot
.11333 .34925 Mdot
.11524 .2594 Mdot
.11714 .36458 Mdot
.11905 .38727 Mdot
.12095 .25586 Mdot
.12286 .36724 Mdot
.12476 .46101 Mdot
.12667 .28765 Mdot
.12857 .30327 Mdot
.13048 .23021 Mdot
.13238 .2409 Mdot
.13429 .37229 Mdot
.13619 .28553 Mdot
.1381 .24954 Mdot
.14 .27655 Mdot
.1419 .42727 Mdot
.14381 .35982 Mdot
.14571 .33247 Mdot
.14762 .25877 Mdot
.14952 .22795 Mdot
.15143 .34019 Mdot
.15333 .283 Mdot
.15524 .32789 Mdot
.15714 .41199 Mdot
.15905 .37741 Mdot
.16095 .32254 Mdot
.16286 .34478 Mdot
.16476 .32718 Mdot
.16667 .35969 Mdot
.16857 .30959 Mdot
.17048 .46078 Mdot
.17238 .31928 Mdot
.17429 .37694 Mdot
.17619 .36771 Mdot
.1781 .4104 Mdot
.18 .3622 Mdot
.1819 .26061 Mdot
.18381 .33541 Mdot
.18571 .22743 Mdot
.18762 .27052 Mdot
.18952 .24974 Mdot
.19143 .26243 Mdot
.19333 .37744 Mdot
.19524 .2879 Mdot
.19714 .36582 Mdot
.19905 .47359 Mdot
.20095 .32024 Mdot
.20286 .25685 Mdot
.20476 .32273 Mdot
.20667 .47373 Mdot
.20857 .34805 Mdot
.21048 .24006 Mdot
.21238 .45953 Mdot
.21429 .37997 Mdot
.21619 .3074 Mdot
.2181 .37868 Mdot
.22 .28885 Mdot
.2219 .29894 Mdot
.22381 .41559 Mdot
.22571 .33357 Mdot
.22762 .37073 Mdot
.22952 .30214 Mdot
.23143 .32011 Mdot
.23333 .41269 Mdot
.23524 .34403 Mdot
.23714 .26244 Mdot
.23905 .23086 Mdot
.24095 .41055 Mdot
.24286 .41202 Mdot
.24476 .26529 Mdot
.24667 .29562 Mdot
.24857 .22926 Mdot
.25048 .23133 Mdot
.25238 .29807 Mdot
.25429 .40166 Mdot
.25619 .40797 Mdot
.2581 .40583 Mdot
.26 .40133 Mdot
.2619 .41265 Mdot
.26381 .26 Mdot
.26571 .40418 Mdot
.26762 .47018 Mdot
.26952 .35026 Mdot
.27143 .28916 Mdot
.27333 .39204 Mdot
.27524 .3272 Mdot
.27714 .30187 Mdot
.27905 .24814 Mdot
.28095 .26096 Mdot
.28286 .39144 Mdot
.28476 .34687 Mdot
.28667 .39961 Mdot
.28857 .34442 Mdot
.29048 .25473 Mdot
.29238 .32024 Mdot
.29429 .45252 Mdot
.29619 .28994 Mdot
.2981 .32475 Mdot
.3 .36854 Mdot
.3019 .41147 Mdot
.30381 .22638 Mdot
.30571 .38434 Mdot
.30762 .26721 Mdot
.30952 .26638 Mdot
.31143 .38454 Mdot
.31333 .37795 Mdot
.31524 .34414 Mdot
.31714 .40726 Mdot
.31905 .3207 Mdot
.32095 .24588 Mdot
.32286 .34523 Mdot
.32476 .36346 Mdot
.32667 .22743 Mdot
.32857 .30694 Mdot
.33048 .3458 Mdot
.33238 .34164 Mdot
.33429 .38239 Mdot
.33619 .30456 Mdot
.3381 .40199 Mdot
.34 .25995 Mdot
.3419 .31391 Mdot
.34381 .22654 Mdot
.34571 .41662 Mdot
.34762 .32963 Mdot
.34952 .36012 Mdot
.35143 .38664 Mdot
.35333 .29328 Mdot
.35524 .3309 Mdot
.35714 .25135 Mdot
.35905 .26683 Mdot
.36095 .24812 Mdot
.36286 .47269 Mdot
.36476 .24552 Mdot
.36667 .26529 Mdot
.36857 .38886 Mdot
.37048 .37202 Mdot
.37238 .29416 Mdot
.37429 .30489 Mdot
.37619 .34375 Mdot
.3781 .31453 Mdot
.38 .22859 Mdot
.3819 .46971 Mdot
.38381 .23966 Mdot
.38571 .30276 Mdot
.38762 .27161 Mdot
.38952 .39552 Mdot
.39143 .41253 Mdot
.39333 .33422 Mdot
.39524 .42589 Mdot
.39714 .23057 Mdot
.39905 .35127 Mdot
.40095 .29311 Mdot
.40286 .2551 Mdot
.40476 .47687 Mdot
.40667 .36658 Mdot
.40857 .26943 Mdot
.41048 .26818 Mdot
.41238 .32321 Mdot
.41429 .25024 Mdot
.41619 .47598 Mdot
.4181 .32354 Mdot
.42 .33208 Mdot
.4219 .24091 Mdot
.42381 .27015 Mdot
.42571 .3191 Mdot
.42762 .3519 Mdot
.42952 .38855 Mdot
.43143 .31315 Mdot
.43333 .41644 Mdot
.43524 .30487 Mdot
.43714 .31927 Mdot
.43905 .3084 Mdot
.44095 .3112 Mdot
.44286 .30837 Mdot
.44476 .25688 Mdot
.44667 .25769 Mdot
.44857 .28985 Mdot
.45048 .26293 Mdot
.45238 .41683 Mdot
.45429 .40634 Mdot
.45619 .30314 Mdot
.4581 .25756 Mdot
.46 .33035 Mdot
.4619 .30365 Mdot
.46381 .32324 Mdot
.46571 .40782 Mdot
.46762 .26482 Mdot
.46952 .27083 Mdot
.47143 .47175 Mdot
.47333 .37465 Mdot
.47524 .34617 Mdot
.47714 .40494 Mdot
.47905 .32702 Mdot
.48095 .30644 Mdot
.48286 .40346 Mdot
.48476 .32043 Mdot
.48667 .42937 Mdot
.48857 .2611 Mdot
.49048 .41761 Mdot
.49238 .37743 Mdot
.49429 .23463 Mdot
.49619 .32107 Mdot
.4981 .33278 Mdot
.5 .3713 Mdot
.5019 .37803 Mdot
.50381 .36379 Mdot
.50571 .35111 Mdot
.50762 .26549 Mdot
.50952 .33176 Mdot
.51143 .31811 Mdot
.51333 .33111 Mdot
.51524 .3316 Mdot
.51714 .3078 Mdot
.51905 .30703 Mdot
.52095 .24414 Mdot
.52286 .27226 Mdot
.52476 .37095 Mdot
.52667 .34653 Mdot
.52857 .4056 Mdot
.53048 .27314 Mdot
.53238 .37728 Mdot
.53429 .28433 Mdot
.53619 .34928 Mdot
.5381 .24346 Mdot
.54 .39192 Mdot
.5419 .34894 Mdot
.54381 .40345 Mdot
.54571 .30143 Mdot
.54762 .3373 Mdot
.54952 .36913 Mdot
.55143 .35136 Mdot
.55333 .30495 Mdot
.55524 .28129 Mdot
.55714 .24789 Mdot
.55905 .3527 Mdot
.56095 .24117 Mdot
.56286 .3866 Mdot
.56476 .27848 Mdot
.56667 .32455 Mdot
.56857 .30255 Mdot
.57048 .27539 Mdot
.57238 .30169 Mdot
.57429 .31458 Mdot
.57619 .2513 Mdot
.5781 .41689 Mdot
.58 .26792 Mdot
.5819 .41052 Mdot
.58381 .46959 Mdot
.58571 .28025 Mdot
.58762 .3032 Mdot
.58952 .26591 Mdot
.59143 .27639 Mdot
.59333 .30893 Mdot
.59524 .42407 Mdot
.59714 .4193 Mdot
.59905 .31724 Mdot
.60095 .36907 Mdot
.60286 .36461 Mdot
.60476 .28912 Mdot
.60667 .32606 Mdot
.60857 .2327 Mdot
.61048 .34411 Mdot
.61238 .35014 Mdot
.61429 .24472 Mdot
.61619 .33449 Mdot
.6181 .28142 Mdot
.62 .39075 Mdot
.6219 .3667 Mdot
.62381 .40108 Mdot
.62571 .37987 Mdot
.62762 .26472 Mdot
.62952 .26625 Mdot
.63143 .33432 Mdot
.63333 .26686 Mdot
.63524 .27013 Mdot
.63714 .30212 Mdot
.63905 .4012 Mdot
.64095 .45536 Mdot
.64286 .2648 Mdot
.64476 .25114 Mdot
.64667 .33849 Mdot
.64857 .35068 Mdot
.65048 .26184 Mdot
.65238 .2813 Mdot
.65429 .2873 Mdot
.65619 .37151 Mdot
.6581 .24658 Mdot
.66 .31269 Mdot
.6619 .326 Mdot
.66381 .3847 Mdot
.66571 .28927 Mdot
.66762 .32313 Mdot
.66952 .33425 Mdot
.67143 .2505 Mdot
.67333 .25995 Mdot
.67524 .34274 Mdot
.67714 .25046 Mdot
.67905 .46872 Mdot
.68095 .34105 Mdot
.68286 .36079 Mdot
.68476 .32951 Mdot
.68667 .23509 Mdot
.68857 .34153 Mdot
.69048 .39985 Mdot
.69238 .37754 Mdot
.69429 .30889 Mdot
.69619 .29547 Mdot
.6981 .45136 Mdot
.7 .26761 Mdot
.7019 .31961 Mdot
.70381 .39859 Mdot
.70571 .3585 Mdot
.70762 .36203 Mdot
.70952 .39156 Mdot
.71143 .37601 Mdot
.71333 .26913 Mdot
.71524 .4547 Mdot
.71714 .41753 Mdot
.71905 .30268 Mdot
.72095 .30705 Mdot
.72286 .32965 Mdot
.72476 .32145 Mdot
.72667 .37286 Mdot
.72857 .3248 Mdot
.73048 .24134 Mdot
.73238 .32047 Mdot
.73429 .41248 Mdot
.73619 .34822 Mdot
.7381 .24198 Mdot
.74 .30242 Mdot
.7419 .2352 Mdot
.74381 .30713 Mdot
.74571 .30755 Mdot
.74762 .3261 Mdot
.74952 .39494 Mdot
.75143 .33211 Mdot
.75333 .39146 Mdot
.75524 .34612 Mdot
.75714 .40544 Mdot
.75905 .2836 Mdot
.76095 .24402 Mdot
.76286 .32061 Mdot
.76476 .38386 Mdot
.76667 .37898 Mdot
.76857 .28473 Mdot
.77048 .29235 Mdot
.77238 .41251 Mdot
.77429 .28625 Mdot
.77619 .33266 Mdot
.7781 .31074 Mdot
.78 .34325 Mdot
.7819 .25692 Mdot
.78381 .41867 Mdot
.78571 .42656 Mdot
.78762 .29722 Mdot
.78952 .35724 Mdot
.79143 .46606 Mdot
.79333 .35852 Mdot
.79524 .27161 Mdot
.79714 .26969 Mdot
.79905 .28239 Mdot
.80095 .24763 Mdot
.80286 .27555 Mdot
.80476 .34144 Mdot
.80667 .30099 Mdot
.80857 .35351 Mdot
.81048 .28309 Mdot
.81238 .37084 Mdot
.81429 .25155 Mdot
.81619 .40595 Mdot
.8181 .27576 Mdot
.82 .34132 Mdot
.8219 .27605 Mdot
.82381 .25001 Mdot
.82571 .34258 Mdot
.82762 .34767 Mdot
.82952 .33295 Mdot
.83143 .39728 Mdot
.83333 .25146 Mdot
.83524 .28093 Mdot
.83714 .32015 Mdot
.83905 .37037 Mdot
.84095 .26233 Mdot
.84286 .3529 Mdot
.84476 .33229 Mdot
.84667 .38034 Mdot
.84857 .47618 Mdot
.85048 .32115 Mdot
.85238 .42874 Mdot
.85429 .28363 Mdot
.85619 .3341 Mdot
.8581 .23112 Mdot
.86 .33127 Mdot
.8619 .34873 Mdot
.86381 .38045 Mdot
.86571 .46652 Mdot
.86762 .29471 Mdot
.86952 .29438 Mdot
.87143 .25893 Mdot
.87333 .40829 Mdot
.87524 .36321 Mdot
.87714 .47545 Mdot
.87905 .31832 Mdot
.88095 .29821 Mdot
.88286 .3433 Mdot
.88476 .33055 Mdot
.88667 .26582 Mdot
.88857 .31604 Mdot
.89048 .23507 Mdot
.89238 .26477 Mdot
.89429 .38444 Mdot
.89619 .33662 Mdot
.8981 .26276 Mdot
.9 .4046 Mdot
.9019 .41076 Mdot
.90381 .36376 Mdot
.90571 .46961 Mdot
.90762 .33426 Mdot
.90952 .24786 Mdot
.91143 .34657 Mdot
.91333 .34862 Mdot
.91524 .31357 Mdot
.91714 .35132 Mdot
.91905 .36577 Mdot
.92095 .40168 Mdot
.92286 .30423 Mdot
.92476 .30391 Mdot
.92667 .29479 Mdot
.92857 .34353 Mdot
.93048 .41917 Mdot
.93238 .25416 Mdot
.93429 .31313 Mdot
.93619 .27145 Mdot
.9381 .36769 Mdot
.94 .32337 Mdot
.9419 .27388 Mdot
.94381 .29336 Mdot
.94571 .27157 Mdot
.94762 .26722 Mdot
.94952 .32802 Mdot
.95143 .22772 Mdot
.95333 .25268 Mdot
.95524 .27801 Mdot
.95714 .33585 Mdot
.95905 .29327 Mdot
.96095 .31477 Mdot
.96286 .42199 Mdot
.96476 .31025 Mdot
.96667 .34141 Mdot
.96857 .24992 Mdot
.97048 .40304 Mdot
.97238 .32449 Mdot
.97429 .39554 Mdot
.97619 .28776 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`0Uooooo`;o00002Oooool2o`0002Cooooo0_l00006ooooo`;o00000oooool2o`000<;ooooo0_l0
000Cooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^
kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool2o`0000cooooo0_l0
000=ooooo`;o00001?ooool2o`0000Wooooo0_l0000?ooooo`;o00000_ooool2o`0000oooooo0_l0
0006ooooo`;o00000oooool2o`0000[ooooo0_l00003ooooo`;o0000/Oooool2o`0001?ooooo0006
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol000001?oooooo0000o`000?l0000<ooooo`;o00003Oooool2o`00023ooooo
0_l00002ooooo`;o0000:?ooool2o`0000?ooooo0_l00012ooooo`;o0000Coooool2o`00037ooooo
0006ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool01?l0003oooooooooooooool2o`0000gooooo0_l0000coooo
o`;o0000COooool2o`0002;ooooo0_l0000Gooooo`;o00004?ooool2o`0002Cooooo0_l00008oooo
o`;o00009oooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0@ooooo`;o00009_ooool2o`00
03Kooooo0_l0000Rooooo`;o0000>oooool2o`00013ooooo0_l0000^ooooo`;o00009oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo01oooooo0_l0000Gooooo`;o0000=_ooool2
o`0000[ooooo0_l0000Tooooo`;o00001Oooool2o`0003Cooooo0_l000000ooooooo0000o`00001H
ooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c004ooooo`Co00001_ooool00ol0003oooooooooo`02o`0001gooooo0_l0000kooooo`;o00003?oo
ool2o`00013ooooo0_l0000Nooooo`;o00001?ooool2o`0000Gooooo0_l0000?ooooo`;o00003?oo
ool2o`0001Gooooo0_l000000ooooooo0000o`000005ooooo`;o0000DOooool002Wooooo0_l00000
0ooooooo0000o`00000Oooooo`;o0000:oooool2o`0000cooooo0_l0000;ooooo`?o0000<?ooool2
o`0000[ooooo0_l0000@ooooo`;o00003?ooool2o`0001oooooo0_l0000;ooooo`;o00008Oooool2
o`00027ooooo000Yooooo`04o`000?oooooo0000o`00023ooooo0_l0000?ooooo`;o00006_ooool2
o`0001Oooooo1?l0000?ooooo`;o0000;?ooool2o`0000Cooooo0_l0000Dooooo`;o00001oooool3
o`0002Kooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o000001Kooooo0_l0000<
ooooo`;o00000oooool2o`0000kooooo000Yooooo`04o`000?oooooo0000o`0001Oooooo0_l00002
ooooo`;o00005?ooool2o`0001kooooo0_l0000Cooooo`;o00003Oooool2o`0000;ooooo0_l0000b
ooooo`;o00005?ooool2o`0000Oooooo0ol0000Zooooo`;o00000_ooool2o`000003ooooool0003o
000001gooooo0_l00005ooooo`;o00000oooool2o`0000kooooo000Yooooo`04o`000?oooooo0000
o`0001Oooooo0_l00002ooooo`;o00001_ooool2o`00013ooooo0_l0000Jooooo`;o00008_ooool2
o`0000cooooo0_l00002ooooo`;o0000I_ooool2o`0001_ooooo0_l0000Aooooo`;o00006_ooool0
02Wooooo00Co0000ooooool0003o00006Oooool2o`0000Sooooo0_l00009ooooo`;o00001Oooool2
o`00017ooooo0_l00004ooooo`;o00004Oooool2o`00023ooooo0_l00002ooooo`;o00002?ooool2
o`0003;ooooo0_l00005ooooo`;o00008Oooool2o`0001_ooooo0_l0000]ooooo`00:Oooool2o`00
01Wooooo1?l0000Cooooo`;o000000?oooooo`000?l000003Oooool2o`0000Kooooo0_l00004oooo
o`;o00004Oooool2o`00027ooooo0_l00004ooooo`;o00001Oooool2o`0002[ooooo0_l00003oooo
o`;o000000?oooooo`000?l000001Oooool2o`0003Cooooo0_l0000?ooooo`?o00009Oooool002Wo
oooo00?o0000ooooooooool06?ooool2o`0001Sooooo0_l0000=ooooo`Co00004oooool2o`0000ko
oooo0_l000000ooooooo0000o`00000<ooooo`;o00002_ooool2o`0000Cooooo0_l0000;ooooo`;o
00005Oooool2o`000003ooooool0003o000000[ooooo1?l000000ooooooo0000o`00000Aooooo`;o
0000:oooool2o`0000gooooo1Ol0000>ooooo`;o00005Oooool002Wooooo00?o0000ooooooooool0
<?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`04onk^k_lb<S;o
0000oc8b<P;o00004oooool2o`0000kooooo0_l000000ooooooo0000o`000005o`0000?ooooo00?o
k^k^oc8b<_l000000ol00002ooooo`?o000000?o<S8bonk^k_ooool02Oooool2o`0000[ooooo0_l0
000@ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00_l000001_oooooo0000o`000?l0003o<S8bonk^
kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04o`0001?ooooo0_l00002ooooo`;o00003Oooool2
o`00000:oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^ooooo`;o000000Gok^k^oc8b
<_l0003o<S8bonk^kP0Fooooo`;o00003_ooool2o`000006ooooool0003o0000o`000?lb<S;ogMgM
0_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`00:Oooool00ol0003oooooooooo`0Eooooo`Co00006?ooool2o`0000Cooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:Oooool01?nHV9So8B4Qonk^k_oo
ool2o`0000;ooooo00?oMgMgoiRHV?ooool00_l00003ooooo`;o000000?ooooooiRHV?mgMgL02_oo
ool2o`0000oooooo1?l00009ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`;o00005oooool2o`00
00kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o000000GoMgMg
oiRHV?ooooooV9RHogMgM`0Vooooo`Go000000?oooooogMgMolb<S800_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool00ol0003ooooo
ooooo`04ooooo`;o00003oooool4o`0000Wooooo0_l0000>ooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100:_ooool00onH
V9So8B4Qonk^kP02o`0000;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo
ooooooooool@41006oooool4o`0000_ooooo0ol00003ooooo`05oa0@4?l0003o0000ooooool@4100
0oooool01Ol@413ooooooooooooooooo410@02Sooooo1Ol00003ooooo`05oa0@4?oooooooooooooo
ool@41000_l000000ooooooo0000o`000002ooooo`04oa0@4?l0003o0000o`0002Cooooo1?l00002
ooooo`04o`000?oooooooooooa0@40?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@
4?oooooooooo007ooooo000Yooooo`;o00001Oooool4o`0000oooooo0_l00009ooooo`;o00003_oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000002_ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`00000Xooooo`Co000000?o410@ooooooooool01?l00000
0ooooooo0000ooooo`02ooooo`05o`000?ooooooooooooooool00000:?ooool01?m4A4CogMgMoooo
ool00004ooooo`05o`000?ooooooooooooooool000000oooool2o`0000;ooooo1?l0000Yooooo`;o
00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`00:Oooool00ol0003oooooooooo`06ooooo`;o00003oooool2o`0000gooooo0_l0000:oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool00000;?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000002Gooooo0_l000001_oooooo0000o`000?l@413o0000
okZj^P;ooooo0_l00003ooooo`04o`000?ooooooooooooooo`?o000000?oooooo`000?ooool01_oo
ool2o`0001oooooo00CogMgMoeEEEOl0003o00001?ooool01Ol0003ooooooooooooooooo000000;o
oooo0_l000001?oooooo0000o`000?l00005ooooo`;o00001?ooool2o`0001cooooo00?o0000ob4Q
8Ol000000_l00002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo000Yooooo`03o`000?oooooooooo023ooooo0_l00004ooooo`;o00002_ooool0
0ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooo
oooooooo410@02gooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0Looooo`;o00001Oooool2o`0000Cooooo00?o^[Zjob4Q
8Oooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@o`000?l0003ooooooa0@
4007ooooo`;o00008?ooool01?mgMgOo0000o`000?ooool4o`0000?ooooo00?o410@ooooooooool0
0_l000001?oooooo0000o`000?l@4105ooooo`;o00001?ooool2o`0001cooooo00?o0000oooooooo
ool01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003
ooooo`00:Oooool2o`0001kooooo0_l000000ooooooo0000o`00000@ooooo`?o00000_ooool01?mg
MgOoV9RHoooooonHV9P2o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`;o00001_oo
ool2o`0001Oooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0_l0000Iooooo`;o00002?ooool01Ol@
413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02o`000006oooooomg
MgOoV9RHoooooonHV9SoMgMg2?ooool2o`0000;ooooo0_l0000Kooooo`04onk^k_m4A4Co0000oooo
o`Co000000CoV9RHoooooonHV9SoMgMg0oooool01OmgMgOoV9RHoooooonHV9SoMgMg02Wooooo00?o
0000ooooooooool01?ooool00omgMgOoV9RHooooo`02o`0000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`00:Oooool2o`0001kooooo0_l0000Aooooo`03oeEEEOmVIVKo000000;o00000_oo
ool01?o^k^ko<S8bo`000?lb<S82o`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`;o
00001_ooool2o`0001Oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_l0003o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo0_l0000Sooooo`05ojVYZOl@
413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;o000000Koooooonk^k_lb
<S;o0000oc8b<_o^k^h8ooooo`;o00000_ooool2o`0001cooooo00?oMgMgo`000?ooool00_l00000
1_ooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Yooooo`Ko
000000?oooooonk^k_lb<S800ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool002Wo
oooo0_l00015ooooo`;o00008?ooool2o`0000Cooooo0_l00008ooooo`;o0000G?ooool2o`0001Ko
oooo0_l0000Nooooo`;o00004Oooool2o`0000?ooooo0_l00003ooooo`;o00004Oooool002Wooooo
00?o0000ooooooooool0??ooool2o`0000Kooooo1?l0000Nooooo`;o00001?ooool2o`0006Kooooo
0_l0000Looooo`;o00006?ooool2o`0000;ooooo0_l0000=ooooo`;o00000oooool2o`0001Kooooo
000Yooooo`04o`000?ooooooooooooooo`;o0000>Oooool4o`0000Kooooo0_l00006ooooo`;o0000
E?ooool2o`0000Gooooo1?l0000Booooo`;o00008?ooool2o`0000gooooo0_l00004ooooo`;o0000
5_ooool2o`0002[ooooo000Yooooo`?o000000?oooooo`000?l000006oooool2o`0001kooooo0_l0
000>ooooo`;o00004Oooool2o`0000[ooooo0_l00002ooooo`;o00003_ooool2o`0000Cooooo1?l0
000Iooooo`;o000000?oooooo`000?l000000_ooool4o`0000?ooooo0_l0000=ooooo`;o00006Ooo
ool2o`0000Gooooo0_l0000Cooooo`;o00008oooool3o`0001cooooo000Yooooo`?o00003Oooool2
o`0000oooooo0_l0000Jooooo`;o00008_ooool2o`000003ooooool0003o000000[ooooo0_l00002
ooooo`;o00003_ooool4o`0000;ooooo1?l00004ooooo`;o00002_ooool3o`0000Wooooo0_l00009
ooooo`;o0000:?ooool2o`0000Kooooo0_l0000gooooo`?o00007?ooool0027oooooool00014o`00
00Cooooo000Yooooo`03o`000?oooooooooo00Sooooo0_l00009ooooo`;o000000?oooooo`000?oo
ool02_ooool00ol0003oooooooooo`06ooooo`;o000000?oooooo`000?ooool02_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool01?l0003o
ooooooooooooool2o`0000Kooooo00?o0000ooooooooool00_l00008ooooo`03o`000?oooooooooo
00Cooooo0_l000001?oooooo0000o`000?l0000;ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02_ooool01?l0003oooooooooooooool2o`0000Cooooo0ol0000;ooooo`03o`000?oo
oooooooo00Gooooo0_l00002ooooo`03o`000?oooooooooo00Cooooo0_l00004ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool01_ooool2o`000003ooooool0003ooooo00[ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooooooo`;o0000
1?ooool3o`0000Kooooo0ol00002ooooo`03o`000?oooooooooo00[ooooo000Yooooo`03o`000?oo
oooooooo00Sooooo0_l00002ooooo`;o00001Oooool2o`0002Gooooo00?o0000ooooooooool09_oo
ool2o`0000Wooooo0_l00008ooooo`03o`000?oooooooooo00Cooooo0_l0000Hooooo`;o00004_oo
ool2o`0000Kooooo0_l0000Booooo`;o00009oooool00ol0003oooooooooo`0Mooooo`;o00001ooo
ool2o`0000Cooooo0_l00007ooooo`;o00000oooool00ol0003oooooooooo`0:ooooo`00:Oooool0
0ol0003oooooooooo`0<ooooo`;o00001_ooool2o`0001Kooooo0_l00007ooooo`;o00002?ooool2
o`0001;ooooo0_l00006ooooo`;o00008?ooool2o`0000;ooooo0_l0000=ooooo`;o00000_ooool2
o`0000?ooooo0_l0000Jooooo`;o00007oooool2o`0000Sooooo0_l00008ooooo`;o00005_ooool2
o`0000;ooooo0_l00007ooooo`;o000000?oooooo`000?l00000:?ooool002Wooooo00?o0000oooo
ooooool01Oooool2o`0000gooooo0_l0000Booooo`;o00000_ooool2o`0000Oooooo0ol00007oooo
o`;o00004_ooool2o`0000Kooooo0_l0000Looooo`Ko00000_ooool2o`0000Oooooo0_l00004oooo
o`;o00000_ooool2o`0003Gooooo0_l00009ooooo`;o00001_ooool4o`0000Sooooo0_l0000Foooo
o`;o00000_ooool2o`0000Oooooo0_l0000Booooo`;o00005oooool002Wooooo0_l00006ooooo`;o
00002oooool2o`0001Cooooo1?l0000:ooooo`;o00005Oooool2o`0000Gooooo0_l0000Sooooo`Co
00003Oooool2o`0000?ooooo0_l0000Jooooo`;o00002oooool2o`0000oooooo1?l0000Aooooo`?o
00001?ooool2o`0003cooooo0_l00008ooooo`;o00003Oooool002Wooooo00?o0000ooooooooool0
4_ooool2o`0001?ooooo0_l000000ooooooo0000o`00000Qooooo`;o00001Oooool2o`0000kooooo
0_l0000Sooooo`;o00001?ooool2o`0001[ooooo0_l0000;ooooo`;o00003oooool2o`0000Kooooo
0_l0000:ooooo`Co00001?ooool2o`0002[ooooo0_l0000Cooooo`;o00001Oooool2o`0000gooooo
000Yooooo`03o`000?oooooooooo02?ooooo0_l00002ooooo`;o00005?ooool2o`0002Gooooo0_l0
00000ooooooo0000o`00000Cooooo`;o00002oooool2o`0000[ooooo0_l000000ooooooo0000o`00
0002o`0003Gooooo0_l0000:ooooo`;o00001oooool2o`0000Kooooo0_l0000?ooooo`;o00000ooo
ool2o`0000?ooooo0_l00006ooooo`;o00004oooool2o`0001Cooooo000Yooooo`03o`000?oooooo
oooo01Kooooo0_l0000;ooooo`;o00002oooool2o`0000_ooooo0_l0000Xooooo`;o00002_ooool2
o`0000Oooooo0_l0000Gooooo`;o000000?oooooo`000?l000000_l0000Oooooo`;o00000oooool2
o`0000[ooooo0_l0000Hooooo`;o00001_ooool2o`0000oooooo0_l00003ooooo`;o00000_ooool3
o`0000[ooooo0_l000000ooooooo0000o`00000>ooooo`;o00004_ooool002Wooooo00?o0000oooo
ooooool04Oooool2o`0000;ooooo0ol0000Hooooo`;o0000@Oooool2o`00033ooooo0_l0000Doooo
o`;o00000oooool2o`0000?ooooo0_l00005ooooo`;o0000>_ooool2o`0000_ooooo0_l000000ooo
oooo0000o`00000>ooooo`;o00004_ooool002Wooooo0_l00003ooooo`;o00002Oooool2o`0000;o
oooo0_l00002ooooo`;o00003_ooool2o`0003Sooooo0_l00014ooooo`;o00007_ooool2o`0000Oo
oooo1_l0000Sooooo`;o00000oooool4o`0002_ooooo0_l0000?ooooo`00:Oooool00ol0003ooooo
ooooo`02ooooo`;o00002Oooool2o`0001Kooooo0_l00002ooooo`;o00005Oooool2o`0000oooooo
0_l00007ooooo`Co000000?oooooo`000?l000003Oooool2o`0004Wooooo0_l0000Cooooo`Ko0000
4oooool2o`0000Kooooo0_l00006ooooo`;o00000oooool4o`00013ooooo0_l0000=ooooo`;o0000
2_ooool2o`0000oooooo000Yooooo`;o00001_ooool2o`0001;ooooo0_l0000>ooooo`;o00003Ooo
ool2o`0000Kooooo0_l0000>ooooo`?o00001oooool4o`000003ooooool0003o000000gooooo0_l0
000Mooooo`;o00003oooool2o`0000?ooooo0_l0000Dooooo`;o00009_ooool2o`0000Cooooo0_l0
0006ooooo`;o00003_ooool2o`0000Wooooo0_l00004ooooo`;o00002?ooool2o`0000?ooooo0_l0
000Kooooo`00:Oooool2o`0000Cooooo1?l0000Booooo`;o00007Oooool2o`00017ooooo0_l00003
ooooo`;o00008oooool2o`0000Oooooo0_l0000=ooooo`;o00002?ooool2o`0000Gooooo0_l00000
0ooooooo0000o`000002o`000003ooooool0003o000001;ooooo0_l00009ooooo`;o00006_ooool2
o`0001cooooo0_l00009ooooo`;o00003_ooool4o`0001kooooo000Yooooo`03o`000?oooooooooo
00?ooooo0_l00016ooooo`;o0000:?ooool2o`0000Oooooo0_l0000Gooooo`;o00002?ooool2o`00
00?ooooo1?l0000@ooooo`;o00002Oooool2o`0003;ooooo0_l00009ooooo`;o00005_ooool2o`00
01kooooo000Yooooo`;o00003Oooool2o`0009[ooooo0_l0000^ooooo`;o00006?ooool4o`0000?o
oooo0_l00009ooooo`;o0000=_ooool002Wooooo00?o0000ooooooooool03?ooool2o`000003oooo
ool0003o000001;ooooo0_l00005ooooo`;o0000>Oooool2o`0006Wooooo0_l00006ooooo`;o0000
6?ooool4o`0004Kooooo000Yooooo`03o`000?oooooooooo00oooooo0_l00009ooooo`;o00001ooo
ool2o`0000Gooooo0_l00002ooooo`;o0000;Oooool2o`0000Kooooo0_l0000`ooooo`;o00007Ooo
ool2o`0001Sooooo0_l00006ooooo`;o0000=?ooool2o`0000Oooooo0_l0000Sooooo`00:Oooool0
0ol0003oooooooooo`07ooooo`;o00004Oooool4o`0000oooooo0ol00004ooooo`;o00009oooool2
o`0001Sooooo0_l0000Nooooo`;o00007Oooool2o`0000Gooooo0_l0000Iooooo`;o0000=?ooool2
o`0000Oooooo0_l00003ooooo`;o00001?ooool2o`0001Sooooo000Yooooo`03o`000?oooooooooo
00Oooooo0_l0000;ooooo`;o00001_ooool2o`0000oooooo0_l00005ooooo`;o00002?ooool2o`00
01Gooooo0_l0000Pooooo`;o00009?ooool2o`0000Kooooo0_l0000?ooooo`;o00001Oooool2o`00
03_ooooo0_l00006ooooo`;o00006?ooool2o`0000Cooooo0_l0000Hooooo`00:Oooool2o`0001Go
oooo0_l0000:ooooo`;o00007?ooool2o`0001Gooooo0_l0000Eooooo`;o00009oooool2o`0000Ko
oooo0_l00006ooooo`;o00003oooool2o`00013ooooo0_l0000Dooooo`;o00006_ooool2o`0000Ko
oooo0_l0000hooooo`00:Oooool00ol0003oooooooooo`0Pooooo`;o00002oooool2o`0003gooooo
0_l0000Oooooo`;o00001_ooool2o`00037ooooo0_l0000?ooooo`;o00000oooool2o`0005cooooo
0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Xooooo`;o00000oooool2o`0000Co
oooo0_l00005ooooo`?o00007?ooool2o`0003;ooooo0_l00004ooooo`;o000000?oooooo`000?l0
00002?ooool2o`0001cooooo0_l0000Cooooo`;o00001?ooool2o`00013ooooo0_l0000Hooooo`;o
0000=Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0:oooo
o`;o00007?ooool2o`0000Wooooo0_l00005ooooo`?o00007?ooool2o`0000Gooooo0_l0000aoooo
o`;o000000?oooooo`000?l000002?ooool2o`0001cooooo0_l0000Cooooo`;o00005_ooool2o`00
01Sooooo0_l00003ooooo`;o0000<?ooool000Kooooo00Go410@oooooooooooooooooa0@400<oooo
o`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:oooo
o`;o0000Boooool4o`0000Gooooo0_l0001Xooooo`;o00007oooool2o`0001gooooo0_l00008oooo
o`;o00009_ooool000Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^
00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0001_ooooo0_l0000jooooo`Co00002oooool2o`00
00?ooooo0_l0000Booooo`;o0000:Oooool2o`0001kooooo0_l0000Oooooo`;o00009oooool2o`00
02Kooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Kooooo`;o0000<?ooool2
o`000003ooooool0003o000001Cooooo0_l00003ooooo`;o00004_ooool2o`00027ooooo0_l00006
ooooo`;o00004?ooool2o`0001_ooooo0_l0000<ooooo`;o0000Doooool000Kooooo00Go410@oooo
oooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1=ooooo`;o000000?oooooo`000?l000008?ooool2o`0002kooooo0_l0000H
ooooo`;o00006oooool2o`0000_ooooo0ol00015ooooo`;o00003?ooool000Kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00[ooooo0_l00006ooooo`;o0000G_ooool2o`0006?ooooo0_l0
000=ooooo`;o00006?ooool2o`0002cooooo0_l0000<ooooo`001_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003ooooo
ooooo`04ooooo`;o00001?ooool2o`0000;ooooo0_l00002ooooo`;o0000<_ooool4o`0000Oooooo
0_l0000>ooooo`;o0000F_ooool2o`0000?ooooo0_l0000?ooooo`;o00000_ooool2o`0002Oooooo
0_l0000Kooooo`;o00007Oooool002Wooooo0_l00005ooooo`;o000000?oooooo`000?l000001Ooo
ool2o`0003Kooooo1_l00005ooooo`;o00003_ooool2o`0002_ooooo1?l0000Aooooo`;o00006?oo
ool2o`0000?ooooo0_l0000?ooooo`;o0000@Oooool2o`0000Gooooo0_l0000>ooooo`;o00003Ooo
ool002Wooooo00?o0000ooooooooool01oooool6o`0003[ooooo1Ol0000?ooooo`;o0000:_ooool2
o`000003ooooool0003o000000;ooooo1?l0000=ooooo`;o00000_ooool2o`0004?ooooo0_l0000A
ooooo`;o00004?ooool2o`0000Oooooo0_l0000Eooooo`;o00003Oooool002Wooooo00?o0000oooo
ooooool02Oooool4o`0000;ooooo0_l0000Mooooo`;o00004_ooool2o`0000?ooooo0ol0000Aoooo
o`;o0000:_ooool2o`000003ooooool0003o000001?ooooo0_l0000?ooooo`;o0000=_ooool2o`00
017ooooo0_l0000@ooooo`;o00002?ooool2o`0002?ooooo000Yooooo`03o`000?oooooooooo00Wo
oooo0_l00004ooooo`;o00005_ooool2o`0000Gooooo0_l0000@ooooo`Go00001?ooool2o`0000_o
oooo0_l0000Jooooo`;o0000??ooool2o`0002oooooo0_l0000:ooooo`;o0000:?ooool2o`0002?o
oooo000Yooooo`03o`000?oooooooooo02Oooooo0_l0000Dooooo`;o000000Coooooo`000?l0003o
oooo0_l00004ooooo`;o00002oooool2o`0000cooooo0_l0000<ooooo`;o00003?ooool2o`0000Co
oooo0_l0000:ooooo`;o00006_ooool2o`0002_ooooo0_l00004ooooo`;o00002_ooool2o`0004go
oooo000Yooooo`;o0000?_ooool2o`0002Gooooo0_l0000Jooooo`;o00001?ooool2o`0000[ooooo
0_l0000Jooooo`;o00001Oooool2o`0002Cooooo0_l0000Dooooo`;o0000;Oooool2o`0001[ooooo
000Yooooo`03o`000?oooooooooo0;Gooooo0_l0000jooooo`;o0000;Oooool2o`0000Sooooo0_l0
000@ooooo`00:Oooool00ol0003oooooooooo`1dooooo`;o0000?_ooool2o`0003_ooooo0_l0000g
ooooo`;o00004?ooool002Wooooo00?o0000ooooooooool08_ooool2o`00053ooooo0_l0000Koooo
o`;o00008Oooool2o`0003_ooooo0_l0000Dooooo`;o0000<oooool002Wooooo00?o0000oooooooo
ool08_ooool2o`0006gooooo0_l0001dooooo`;o0000<oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo0_l0003Fooooo`;o0000IOooool002Wooooo00?o0000ooooooooool0Dooo
ool2o`00083ooooo0_l00004ooooo`;o0000Goooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0
Doooool2o`0006kooooo0_l0000Fooooo`;o0000Goooool000kooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01gooooo
0_l0000<ooooo`;o00003?ooool2o`0008Sooooo0_l0001gooooo`003_ooool01Ol@413ooooooooo
oooooooo410@013ooooo00?o0000ooooooooool00oooool3o`0001gooooo0_l0000<ooooo`;o0000
3?ooool2o`000?oooooo0_ooool000kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0loooool2o`0001Kooooo0_l0000_ooooo`003_oo
ool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo04_ooooo0_l0000Rooooo`;o0000?oooool2o`0001gooooo0_l0000Rooooo`;o
00005_ooool2o`0000_ooooo0_l0000Rooooo`003_ooool01Ol@413ooooooooooooooooo410@00co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0eooooo`;o00005?ooool2o`0001co
oooo0_l00004ooooo`;o00006oooool2o`0002;ooooo0_l0000Mooooo`;o0000Aoooool2o`0002;o
oooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo03Gooooo1?l0000`ooooo`;o00003oooool2o`00013ooooo0_l0001gooooo`;o
00002?ooool2o`0002_ooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Ko
oooo0_l0000hooooo`;o0000?_ooool2o`000003ooooool0003o000008Wooooo0_l00008ooooo`;o
0000:oooool002Wooooo00?o0000ooooooooool0Moooool2o`000<?ooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o
0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooo
oa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo
?Oooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05o`000?oo
ooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@
41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooo
oooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmoooo
o`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`00
0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`00
0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Oooooo`Co000000?o
410@ooooooooool00oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05oooo
o`?o0000oooooolmooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Oooooo`03oeEEEOmVIVKo00000?ooooooAoooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .24107 Mdot
.02762 .25681 Mdot
.02952 .27608 Mdot
.03143 .30547 Mdot
.03333 .31007 Mdot
.03524 .32655 Mdot
.03714 .26961 Mdot
.03905 .27527 Mdot
.04095 .31194 Mdot
.04286 .28812 Mdot
.04476 .3344 Mdot
.04667 .23301 Mdot
.04857 .33955 Mdot
.05048 .30746 Mdot
.05238 .22813 Mdot
.05429 .26354 Mdot
.05619 .37577 Mdot
.0581 .34319 Mdot
.06 .35524 Mdot
.0619 .42592 Mdot
.06381 .36383 Mdot
.06571 .30804 Mdot
.06762 .34039 Mdot
.06952 .3563 Mdot
.07143 .24769 Mdot
.07333 .24934 Mdot
.07524 .34954 Mdot
.07714 .35234 Mdot
.07905 .42688 Mdot
.08095 .27367 Mdot
.08286 .38659 Mdot
.08476 .32691 Mdot
.08667 .27196 Mdot
.08857 .37817 Mdot
.09048 .37756 Mdot
.09238 .41935 Mdot
.09429 .3976 Mdot
.09619 .35394 Mdot
.0981 .41933 Mdot
.1 .23449 Mdot
.1019 .23246 Mdot
.10381 .37941 Mdot
.10571 .35384 Mdot
.10762 .24343 Mdot
.10952 .26289 Mdot
.11143 .26822 Mdot
.11333 .31908 Mdot
.11524 .36479 Mdot
.11714 .30738 Mdot
.11905 .42311 Mdot
.12095 .36128 Mdot
.12286 .42077 Mdot
.12476 .48318 Mdot
.12667 .36134 Mdot
.12857 .37035 Mdot
.13048 .28893 Mdot
.13238 .26305 Mdot
.13429 .37389 Mdot
.13619 .38255 Mdot
.1381 .27115 Mdot
.14 .25652 Mdot
.1419 .34263 Mdot
.14381 .41511 Mdot
.14571 .32785 Mdot
.14762 .24611 Mdot
.14952 .31512 Mdot
.15143 .28832 Mdot
.15333 .26238 Mdot
.15524 .35587 Mdot
.15714 .37148 Mdot
.15905 .37471 Mdot
.16095 .29268 Mdot
.16286 .30133 Mdot
.16476 .26776 Mdot
.16667 .41503 Mdot
.16857 .30706 Mdot
.17048 .48317 Mdot
.17238 .252 Mdot
.17429 .42368 Mdot
.17619 .325 Mdot
.1781 .40688 Mdot
.18 .27542 Mdot
.1819 .31044 Mdot
.18381 .38027 Mdot
.18571 .29504 Mdot
.18762 .27003 Mdot
.18952 .30626 Mdot
.19143 .27026 Mdot
.19333 .36599 Mdot
.19524 .26022 Mdot
.19714 .25521 Mdot
.19905 .45475 Mdot
.20095 .33815 Mdot
.20286 .27686 Mdot
.20476 .33643 Mdot
.20667 .44405 Mdot
.20857 .30506 Mdot
.21048 .34258 Mdot
.21238 .48418 Mdot
.21429 .36288 Mdot
.21619 .23846 Mdot
.2181 .35197 Mdot
.22 .22868 Mdot
.2219 .23809 Mdot
.22381 .39391 Mdot
.22571 .37745 Mdot
.22762 .37962 Mdot
.22952 .35272 Mdot
.23143 .33829 Mdot
.23333 .37669 Mdot
.23524 .29414 Mdot
.23714 .3163 Mdot
.23905 .32589 Mdot
.24095 .42119 Mdot
.24286 .47643 Mdot
.24476 .30663 Mdot
.24667 .24915 Mdot
.24857 .32543 Mdot
.25048 .33007 Mdot
.25238 .38733 Mdot
.25429 .34305 Mdot
.25619 .30987 Mdot
.2581 .36556 Mdot
.26 .42784 Mdot
.2619 .37484 Mdot
.26381 .29096 Mdot
.26571 .42297 Mdot
.26762 .43155 Mdot
.26952 .26165 Mdot
.27143 .266 Mdot
.27333 .32828 Mdot
.27524 .24317 Mdot
.27714 .22574 Mdot
.27905 .33193 Mdot
.28095 .34465 Mdot
.28286 .4276 Mdot
.28476 .41484 Mdot
.28667 .42508 Mdot
.28857 .30083 Mdot
.29048 .24861 Mdot
.29238 .22721 Mdot
.29429 .39366 Mdot
.29619 .33543 Mdot
.2981 .3567 Mdot
.3 .37565 Mdot
.3019 .42368 Mdot
.30381 .30728 Mdot
.30571 .46488 Mdot
.30762 .33297 Mdot
.30952 .26561 Mdot
.31143 .27299 Mdot
.31333 .34503 Mdot
.31524 .3525 Mdot
.31714 .35476 Mdot
.31905 .28543 Mdot
.32095 .28075 Mdot
.32286 .41273 Mdot
.32476 .41755 Mdot
.32667 .31521 Mdot
.32857 .39312 Mdot
.33048 .41332 Mdot
.33238 .26728 Mdot
.33429 .42584 Mdot
.33619 .22412 Mdot
.3381 .4162 Mdot
.34 .3422 Mdot
.3419 .23959 Mdot
.34381 .30752 Mdot
.34571 .39809 Mdot
.34762 .35554 Mdot
.34952 .42028 Mdot
.35143 .42085 Mdot
.35333 .33448 Mdot
.35524 .35403 Mdot
.35714 .29223 Mdot
.35905 .33342 Mdot
.36095 .2557 Mdot
.36286 .44082 Mdot
.36476 .28187 Mdot
.36667 .29673 Mdot
.36857 .42482 Mdot
.37048 .42436 Mdot
.37238 .22638 Mdot
.37429 .25621 Mdot
.37619 .23507 Mdot
.3781 .26747 Mdot
.38 .307 Mdot
.3819 .43312 Mdot
.38381 .34456 Mdot
.38571 .22444 Mdot
.38762 .35314 Mdot
.38952 .2906 Mdot
.39143 .42362 Mdot
.39333 .31918 Mdot
.39524 .34186 Mdot
.39714 .2831 Mdot
.39905 .23926 Mdot
.40095 .22737 Mdot
.40286 .28045 Mdot
.40476 .46258 Mdot
.40667 .38373 Mdot
.40857 .31225 Mdot
.41048 .31034 Mdot
.41238 .29857 Mdot
.41429 .30216 Mdot
.41619 .46788 Mdot
.4181 .24197 Mdot
.42 .29843 Mdot
.4219 .31255 Mdot
.42381 .32576 Mdot
.42571 .26994 Mdot
.42762 .33389 Mdot
.42952 .31581 Mdot
.43143 .24987 Mdot
.43333 .39892 Mdot
.43524 .25682 Mdot
.43714 .24081 Mdot
.43905 .2493 Mdot
.44095 .2241 Mdot
.44286 .26389 Mdot
.44476 .26267 Mdot
.44667 .24438 Mdot
.44857 .2505 Mdot
.45048 .3659 Mdot
.45238 .39317 Mdot
.45429 .41145 Mdot
.45619 .25739 Mdot
.4581 .32512 Mdot
.46 .24283 Mdot
.4619 .33706 Mdot
.46381 .2281 Mdot
.46571 .30859 Mdot
.46762 .27829 Mdot
.46952 .29854 Mdot
.47143 .47056 Mdot
.47333 .34241 Mdot
.47524 .34694 Mdot
.47714 .3057 Mdot
.47905 .35453 Mdot
.48095 .23747 Mdot
.48286 .35374 Mdot
.48476 .24054 Mdot
.48667 .34697 Mdot
.48857 .3458 Mdot
.49048 .40534 Mdot
.49238 .37455 Mdot
.49429 .33628 Mdot
.49619 .33571 Mdot
.4981 .40555 Mdot
.5 .36726 Mdot
.5019 .37354 Mdot
.50381 .4171 Mdot
.50571 .23945 Mdot
.50762 .30691 Mdot
.50952 .3235 Mdot
.51143 .39814 Mdot
.51333 .2579 Mdot
.51524 .35358 Mdot
.51714 .37358 Mdot
.51905 .31009 Mdot
.52095 .25927 Mdot
.52286 .37436 Mdot
.52476 .3252 Mdot
.52667 .34663 Mdot
.52857 .41327 Mdot
.53048 .27756 Mdot
.53238 .34766 Mdot
.53429 .24312 Mdot
.53619 .32822 Mdot
.5381 .3187 Mdot
.54 .42008 Mdot
.5419 .28 Mdot
.54381 .42109 Mdot
.54571 .36996 Mdot
.54762 .28055 Mdot
.54952 .32459 Mdot
.55143 .41569 Mdot
.55333 .25593 Mdot
.55524 .34478 Mdot
.55714 .35339 Mdot
.55905 .32689 Mdot
.56095 .29509 Mdot
.56286 .42526 Mdot
.56476 .27111 Mdot
.56667 .26605 Mdot
.56857 .39046 Mdot
.57048 .23389 Mdot
.57238 .3528 Mdot
.57429 .27551 Mdot
.57619 .3053 Mdot
.5781 .41657 Mdot
.58 .26374 Mdot
.5819 .40392 Mdot
.58381 .43443 Mdot
.58571 .3785 Mdot
.58762 .22656 Mdot
.58952 .36774 Mdot
.59143 .2813 Mdot
.59333 .39629 Mdot
.59524 .34043 Mdot
.59714 .41102 Mdot
.59905 .22703 Mdot
.60095 .45745 Mdot
.60286 .31066 Mdot
.60476 .36504 Mdot
.60667 .24235 Mdot
.60857 .33188 Mdot
.61048 .23597 Mdot
.61238 .32174 Mdot
.61429 .34936 Mdot
.61619 .26066 Mdot
.6181 .32126 Mdot
.62 .32152 Mdot
.6219 .37726 Mdot
.62381 .34326 Mdot
.62571 .26724 Mdot
.62762 .29598 Mdot
.62952 .25374 Mdot
.63143 .3782 Mdot
.63333 .24002 Mdot
.63524 .28097 Mdot
.63714 .22522 Mdot
.63905 .30251 Mdot
.64095 .39562 Mdot
.64286 .2793 Mdot
.64476 .33663 Mdot
.64667 .38165 Mdot
.64857 .41202 Mdot
.65048 .33094 Mdot
.65238 .32227 Mdot
.65429 .2725 Mdot
.65619 .37805 Mdot
.6581 .25531 Mdot
.66 .39473 Mdot
.6619 .33552 Mdot
.66381 .31015 Mdot
.66571 .2657 Mdot
.66762 .30061 Mdot
.66952 .24508 Mdot
.67143 .33455 Mdot
.67333 .34226 Mdot
.67524 .2688 Mdot
.67714 .30471 Mdot
.67905 .48147 Mdot
.68095 .26868 Mdot
.68286 .27441 Mdot
.68476 .33042 Mdot
.68667 .27527 Mdot
.68857 .34818 Mdot
.69048 .42439 Mdot
.69238 .30188 Mdot
.69429 .33944 Mdot
.69619 .25014 Mdot
.6981 .39058 Mdot
.7 .23769 Mdot
.7019 .40254 Mdot
.70381 .42027 Mdot
.70571 .2956 Mdot
.70762 .38285 Mdot
.70952 .42162 Mdot
.71143 .34452 Mdot
.71333 .23684 Mdot
.71524 .39133 Mdot
.71714 .40681 Mdot
.71905 .22577 Mdot
.72095 .2249 Mdot
.72286 .22781 Mdot
.72476 .31194 Mdot
.72667 .33498 Mdot
.72857 .22837 Mdot
.73048 .26271 Mdot
.73238 .31449 Mdot
.73429 .39724 Mdot
.73619 .28044 Mdot
.7381 .31864 Mdot
.74 .23859 Mdot
.7419 .33456 Mdot
.74381 .23757 Mdot
.74571 .39445 Mdot
.74762 .40099 Mdot
.74952 .33771 Mdot
.75143 .40896 Mdot
.75333 .32793 Mdot
.75524 .23785 Mdot
.75714 .47452 Mdot
.75905 .37884 Mdot
.76095 .28423 Mdot
.76286 .28759 Mdot
.76476 .27608 Mdot
.76667 .36148 Mdot
.76857 .274 Mdot
.77048 .22656 Mdot
.77238 .37331 Mdot
.77429 .32433 Mdot
.77619 .27469 Mdot
.7781 .24829 Mdot
.78 .34962 Mdot
.7819 .36295 Mdot
.78381 .39008 Mdot
.78571 .34391 Mdot
.78762 .22575 Mdot
.78952 .38044 Mdot
.79143 .47933 Mdot
.79333 .38176 Mdot
.79524 .33721 Mdot
.79714 .33663 Mdot
.79905 .31492 Mdot
.80095 .25443 Mdot
.80286 .2335 Mdot
.80476 .34886 Mdot
.80667 .33747 Mdot
.80857 .34017 Mdot
.81048 .26078 Mdot
.81238 .25722 Mdot
.81429 .28789 Mdot
.81619 .41579 Mdot
.8181 .32846 Mdot
.82 .35349 Mdot
.8219 .27414 Mdot
.82381 .29519 Mdot
.82571 .37867 Mdot
.82762 .34851 Mdot
.82952 .30303 Mdot
.83143 .29215 Mdot
.83333 .2517 Mdot
.83524 .28493 Mdot
.83714 .37631 Mdot
.83905 .37971 Mdot
.84095 .25819 Mdot
.84286 .28878 Mdot
.84476 .35478 Mdot
.84667 .27064 Mdot
.84857 .44783 Mdot
.85048 .23997 Mdot
.85238 .48176 Mdot
.85429 .24185 Mdot
.85619 .30588 Mdot
.8581 .28889 Mdot
.86 .23055 Mdot
.8619 .33988 Mdot
.86381 .30831 Mdot
.86571 .48208 Mdot
.86762 .33603 Mdot
.86952 .32569 Mdot
.87143 .32518 Mdot
.87333 .41229 Mdot
.87524 .311 Mdot
.87714 .45917 Mdot
.87905 .27002 Mdot
.88095 .36604 Mdot
.88286 .3821 Mdot
.88476 .33218 Mdot
.88667 .29197 Mdot
.88857 .2589 Mdot
.89048 .27236 Mdot
.89238 .29337 Mdot
.89429 .42577 Mdot
.89619 .24716 Mdot
.8981 .25613 Mdot
.9 .42204 Mdot
.9019 .40018 Mdot
.90381 .37927 Mdot
.90571 .42476 Mdot
.90762 .27693 Mdot
.90952 .2538 Mdot
.91143 .23606 Mdot
.91333 .33096 Mdot
.91524 .39906 Mdot
.91714 .28499 Mdot
.91905 .37421 Mdot
.92095 .42444 Mdot
.92286 .23832 Mdot
.92476 .35257 Mdot
.92667 .25018 Mdot
.92857 .37965 Mdot
.93048 .32683 Mdot
.93238 .33702 Mdot
.93429 .30139 Mdot
.93619 .35174 Mdot
.9381 .32325 Mdot
.94 .30666 Mdot
.9419 .26899 Mdot
.94381 .36436 Mdot
.94571 .35339 Mdot
.94762 .30989 Mdot
.94952 .25596 Mdot
.95143 .31301 Mdot
.95333 .31813 Mdot
.95524 .24615 Mdot
.95714 .35749 Mdot
.95905 .34705 Mdot
.96095 .32138 Mdot
.96286 .48086 Mdot
.96476 .32332 Mdot
.96667 .25042 Mdot
.96857 .35337 Mdot
.97048 .41674 Mdot
.97238 .35588 Mdot
.97429 .42526 Mdot
.97619 .22824 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo067ooooo0_l0000>ooooo`;o00003oooool2o`000;Sooooo0006ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0C_ooool2o`0000?ooooo0_l0000<ooooo`;o00002Ooo
ool2o`0000?ooooo0_l00003ooooo`;o00002_ooool2o`0002kooooo0_l000000ooooooo0000o`00
000:ooooo`;o00006Oooool3o`0000gooooo0_l00004ooooo`;o0000B?ooool000Co00000_ooool0
1Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Gooooo0_l0000dooooo`;o00004Oooool2o`0000?ooooo0_l0
000Gooooo`;o00002?ooool2o`0001;ooooo0_l0000Vooooo`;o000000?oooooo`000?l000002_oo
ool2o`0001Wooooo1Ol0000;ooooo`;o00001?ooool2o`0001Gooooo0_l0000Tooooo`;o00002ooo
ool000Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o
MgMgoc8b<_ooool01?ooool3o`0000Cooooo0ol0000>ooooo`;o00009?ooool2o`0004gooooo0_l0
000Pooooo`;o0000<Oooool2o`0001Kooooo0_l0000@ooooo`;o00009?ooool2o`0000_ooooo0006
ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`04ooooo`;o00003oooool2o`0005Oooooo
0_l0000looooo`;o00002oooool2o`0001oooooo0_l0000Kooooo`;o00008Oooool2o`00023ooooo
0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool05Oooool2o`0002?ooooo1?l0000Uooooo`;o0000
2Oooool2o`0000Gooooo0_l0000Hooooo`;o00001_ooool2o`00023ooooo0_l00005ooooo`;o0000
5?ooool2o`0000;ooooo0_l00007ooooo`?o000000?oooooo`000?l000007Oooool2o`0001;ooooo
0_l000000ooooooo0000o`00000Mooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo0_l0000Hooooo`;o
00008Oooool4o`0000oooooo0_l0000Dooooo`;o00004?ooool2o`0000Cooooo0_l00004ooooo`;o
00001_ooool2o`0000Cooooo0ol00005ooooo`;o00001oooool2o`0001Kooooo0_l00006ooooo`;o
00005?ooool2o`0000_ooooo0ol000000ooooooo0000o`00000Mooooo`?o00005?ooool2o`0001go
oooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
00Cooooo1?l00006ooooo`;o00006?ooool2o`0000_ooooo0_l0000Wooooo`;o0000;?ooool2o`00
00Cooooo0_l000000ooooooo0000o`000003ooooo`;o00001Oooool2o`0000kooooo0_l0000Foooo
o`;o00004_ooool2o`0003Wooooo0_l0000Oooooo`;o00004_ooool002Wooooo0_l0000=ooooo`;o
00005_ooool2o`0001kooooo0_l0000<ooooo`;o0000;_ooool4o`0004Kooooo0_l0000Qooooo`;o
00009?ooool2o`00017ooooo0_l0000Booooo`00:Oooool00ol0003oooooooooo`0<ooooo`;o0000
7_ooool2o`0001Kooooo0_l0000<ooooo`;o0000:oooool2o`000004ooooool0003o0000ooooo`;o
0000COooool2o`0001Wooooo0_l0000@ooooo`;o00004_ooool2o`0000Sooooo0_l0000:ooooo`;o
00003oooool002Wooooo00?o0000ooooooooool0;?ooool2o`0000Kooooo0_l0000cooooo`;o0000
5?ooool2o`0000Cooooo0_l0000Pooooo`;o00005_ooool2o`0000Oooooo0_l0000:ooooo`;o0000
8?ooool2o`0000Wooooo0_l0000Fooooo`;o00001?ooool2o`0000[ooooo0_l0000?ooooo`00:Ooo
ool2o`0002?ooooo0_l0000@ooooo`;o0000<oooool2o`0000;ooooo0_l0000Booooo`;o00001?oo
ool2o`00017ooooo0_l0000;ooooo`;o00005_ooool2o`0000Oooooo0_l0000/ooooo`;o00000_oo
ool2o`0000Oooooo0_l0000=ooooo`;o000000?oooooo`000?l000000_ooool2o`0000_ooooo0_l0
000Dooooo`00:Oooool2o`0002?ooooo0_l0000?ooooo`;o00005_ooool2o`00023ooooo0_l0000B
ooooo`;o00001?ooool2o`00017ooooo1?l0000Mooooo`;o0000??ooool3o`0000Oooooo0_l0000=
ooooo`;o000000?oooooo`000?l000003oooool2o`0001Cooooo000Yooooo`;o00001oooool2o`00
013ooooo0_l00005ooooo`;o00001Oooool2o`0000_ooooo0_l0000Fooooo`;o0000=_ooool3o`00
01Kooooo0_l0000Aooooo`;o00002_ooool2o`0002;ooooo0_l0000Hooooo`;o0000@Oooool002Wo
oooo00?o0000ooooooooool01_ooool2o`00013ooooo0_l00005ooooo`;o00001Oooool2o`0000;o
oooo0_l0000Pooooo`;o00002_ooool2o`0000Gooooo0_l0000=ooooo`;o00004oooool3o`0002Go
oooo0_l00002ooooo`;o00003Oooool2o`0000_ooooo0_l0000Booooo`;o0000Foooool002Wooooo
00Co0000oooooooooooooooo0_l0000Eooooo`;o00001oooool2o`0000Oooooo0_l00004ooooo`Co
000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP08ooooo`;o00002_ooool2o`0000Gooooo0_l0000<ooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo0ol000000olb<S;ok^k^ooooo`0Wooooo`?o000000?o<S8bolc<c?oo
ool00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Cok^k^oc8b<_l0003o<S8b0_l0000;
ooooo`;o000000?oooooo`000?l000000_l0000Gooooo`;o000000Wo410@ooooooooooooooooonk^
k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Wooooo0_l00008oooo
o`;o00004_ooool2o`000005odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool01?l0003ooooooooo
ooooool2o`0000cooooo0ol0000?ooooo`;o00003_ooool3o`0000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05Oooool2o`0001;ooooo00GoV9RHob4Q
8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool2o`000003oooooonH
V9SoMgMg02Sooooo0_l000000oooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo0_l00005ooooo`Co00006?ooool02_l0003o
ooooo`000?l0003oooooogMgMonHV9SooooooiRHV?mgMgL3ooooo`06ogMgMonHV9SooooooiRHV?mg
MgOooooo0_l00006ooooo`;o00002?ooool2o`0000;ooooo0_l0000>ooooo`;o00000oooool02Omg
MgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool002Wooooo0ol000000ooooooo0000o`00000<ooooo`?o00007?ooool2o`0000;ooooo
00Co0000oooooooooooooooo0_l00003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@
413oooooooooo`0Cooooo`;o00004oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?oooooooooo
ooooool@41000oooool01Ol@413ooooooooooooooooo410@01gooooo0_l0000<ooooo`;o00000ooo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`;o
00001oooool3o`0001Cooooo2Ol00003ooooo`05oa0@4?ooooooooooooooool@41000oooool01?l@
413oooooo`000?l0000Dooooo`;o00000oooool2o`0000oooooo00Co0000oooooooooooo410@0ooo
ool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool00Oooool002Wooooo0ol0
00000ooooooo0000o`00000[ooooo`;o00000_ooool01?l0003oooooooooooooool2o`0000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo01Kooooo0_l0000Aooooo`03
oiRHV?lQ8B7ok^k^00?ooooo0ol000000ooooooo0000ooooo`02ooooo`05o`000?oooooooooooooo
ool000002Oooool2o`0001;ooooo0_l00002ooooo`Co00001_ooool2o`0000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001?ooool2o`0000cooooo0_l0
000>ooooo`;o00001?ooool00om4A4CogMgMooooo`03o`000003ooooool0003o000000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo01[ooooo0_l0000>ooooo`05ogMg
Molb<S;oooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool00Oooool002Wooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000001Sooooo0_l0000<
ooooo`;o00001?ooool01?mgMgOoIVIVooooooooool4o`000003ooooool0003ooooo00;ooooo00Go
0000ooooooooooooooooo`000009ooooo`;o00005_ooool4o`0000Gooooo00?o410@o`000?nj^[X0
0oooool3o`000003ooooool0003ooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`Co
00007?ooool2o`0000Cooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`00000Yooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
0_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`00:Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00;ooooo00Go410@oooooooo
oooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41005oooool2o`0000gooooo0_l00005
ooooo`03o`000?oooooooooo00;o00000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o
410@ooooooooool0:Oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?l0003o0000ooooool@4100
0oooool01Ol@413ooooooooooooooooo410@00;ooooo0_l0000Uooooo`03ogMgMol0003o000000Co
oooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001Oooool2
o`0001Wooooo0_l00007ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool002Wooooo00?o0000ooooooooool00_oo
ool2o`0001_ooooo0_l00004ooooo`;o00002oooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01Oooooo0_l0000@ooooo`05
o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0Xooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Yooooo`04onk^k_l0003o0000
o`0000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03ogMgMonHV9Sooooo00;o00001Ooo
ool2o`000003ooooool0003o000000?ooooo0_l0000Aooooo`;o00001oooool00ol0003ooooooooo
o`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo000Yooooo`03o`000?oooooooooo00;ooooo0_l0000Kooooo`;o00001?ooool2o`000003oooo
ool0003o000000Kooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o00007?ooool2o`0000Cooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c002o`000006ooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^02Sooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02[ooooo00?oMgMgo`000?l000000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?ok^k^oc8b<_l000000_l00004ooooo`;o0000
0_ooool2o`0000?ooooo0_l00007ooooo`;o00004Oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool002Wooooo0_l0000Yooooo`;o
00001_ooool2o`0000kooooo0_l00007ooooo`;o00007?ooool2o`0000Wooooo0_l0000eooooo`;o
00004oooool2o`0001Sooooo0_l0000Tooooo`Co00004?ooool4o`0002Kooooo000Yooooo`03o`00
0?oooooooooo033ooooo0_l0000>ooooo`;o0000:Oooool2o`0000cooooo0_l000000ooooooo0000
o`00000>ooooo`;o00006oooool2o`0001?ooooo0_l0000Hooooo`;o00009?ooool2o`0001Cooooo
0_l0000Vooooo`00:Oooool00ol0003oooooooooo`0Yooooo`;o00009_ooool2o`0001Sooooo0_l0
000<ooooo`Go00003_ooool2o`0003Cooooo0_l00007ooooo`;o00001_ooool2o`0004cooooo0_l0
000Iooooo`00:Oooool01?l0003oooooo`000?l0000Xooooo`;o00003Oooool2o`0001Oooooo0_l0
000Wooooo`;o00004_ooool2o`0001kooooo0_l0000Booooo`;o00001oooool2o`000003ooooool0
003o000000?ooooo0_l0000Zooooo`;o00008?ooool2o`0001Wooooo000Yooooo`04o`000?oooooo
0000o`0000Cooooo0_l00003ooooo`;o00003_ooool2o`0000oooooo0_l00005ooooo`;o00001?oo
ool2o`0000Wooooo0_l0000Aooooo`;o00002oooool2o`0000[ooooo0_l0000Iooooo`;o00000_oo
ool2o`0000Sooooo0_l0000Dooooo`;o00007_ooool2o`0002oooooo0_l00007ooooo`Co00005ooo
ool2o`0001Oooooo000Qoooooooo0000A?l00004ooooo`00:Oooool01Ol0003oooooo`000?l0003o
oooo00;o00001Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool3o`0000Wooooo00?o0000ooooooooool02_ooool2o`0000[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo0ol00000
0ooooooo0000o`000006ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool2
o`0000_ooooo00?o0000ooooooooool02Oooool3o`0000Wooooo00?o0000ooooooooool01_ooool2
o`000003ooooool0003ooooo00_ooooo00Co0000oooooooooooooooo1?l00004ooooo`03o`000?oo
oooooooo00Wooooo00Co0000oooooooooooooooo0_l00006ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool00_l00007ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooool00000
0ol00006ooooo`03o`000?oooooooooo00[ooooo000Yooooo`03o`000?oooooooooo00;ooooo0_l0
000Qooooo`;o00004oooool00ol0003oooooooooo`04ooooo`;o00006oooool2o`0001Sooooo0_l0
0002ooooo`;o000000?oooooo`000?l00000=?ooool00ol0003oooooooooo`0Vooooo`Co00004?oo
ool01?l0003oooooooooooooool2o`0002oooooo0_l00006ooooo`03o`000?oooooooooo00[ooooo
000Yooooo`03o`000?oooooooooo01Wooooo0_l0000:ooooo`;o00006_ooool2o`0001_ooooo0_l0
000Cooooo`;o00002_ooool2o`00027ooooo0_l0000Gooooo`;o00009Oooool2o`0004?ooooo0_l0
000Cooooo`00:Oooool00ol0003oooooooooo`0Iooooo`;o0000F?ooool2o`0002?ooooo0_l00008
ooooo`;o00005_ooool4o`0000Sooooo0_l0000Jooooo`;o00002_ooool2o`0003;ooooo0_l00006
ooooo`?o00003oooool002Wooooo0_l000000ooooooo0000o`00000>ooooo`;o00006oooool2o`00
01;ooooo0_l00002ooooo`;o0000=_ooool2o`0000Wooooo0_l0000>ooooo`;o00000oooool2o`00
00Kooooo0_l000000ooooooo0000o`00000@ooooo`Co00002?ooool2o`0002Kooooo0_l0000Loooo
o`?o00004Oooool4o`0000Kooooo0ol0000?ooooo`00:Oooool00ol0003oooooooooo`02o`0000ko
oooo0_l0000Aooooo`;o00002?ooool2o`0001;ooooo0_l00002ooooo`;o00001_ooool2o`0002ko
oooo0_l00009ooooo`;o00004oooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l0
00009oooool2o`0001Cooooo0_l0000Cooooo`;o00003_ooool3o`00017ooooo0_l0000Jooooo`00
:Oooool00ol0003oooooooooo`0Sooooo`;o00008?ooool2o`0000Kooooo0ol00008ooooo`;o0000
3_ooool2o`0003Oooooo0_l0000Eooooo`;o00003?ooool2o`0000Wooooo0_l0000Dooooo`;o0000
4oooool2o`0001?ooooo0_l00007ooooo`;o00008?ooool002Wooooo00?o0000ooooooooool00ooo
ool2o`00037ooooo0_l0000Fooooo`;o00001?ooool2o`0000;ooooo0_l0000<ooooo`Co00005?oo
ool2o`0001Cooooo0_l0000Rooooo`;o00002_ooool4o`000003ooooool0003o000000;ooooo0_l0
000?ooooo`;o00000oooool2o`00013ooooo0_l0000Eooooo`;o00000oooool2o`0000Oooooo0_l0
000Pooooo`00:Oooool00ol0003oooooooooo`03ooooo`?o0000;oooool3o`0000Oooooo0_l0000C
ooooo`;o00004?ooool2o`0001Kooooo0_l00009ooooo`;o00002Oooool2o`0002kooooo0_l00003
ooooo`;o00000_ooool2o`0000Gooooo0_l00008ooooo`;o00000oooool2o`000003ooooool0003o
000000cooooo0ol000000ooooooo0000o`00000@ooooo`Co00004_ooool2o`0001[ooooo000Yoooo
o`;o00001Oooool2o`0000Cooooo0_l0000Fooooo`;o00004Oooool2o`000003ooooool0003o0000
00Gooooo0_l0000Qooooo`;o00004?ooool2o`0001?ooooo0_l00002ooooo`;o00009Oooool2o`00
01Oooooo0_l00005ooooo`;o00004?ooool2o`0000cooooo0_l00002ooooo`?o00003oooool2o`00
01Cooooo0_l0000Jooooo`00:Oooool00ol0003oooooooooo`07ooooo`;o000000?oooooo`000?l0
00005_ooool2o`0001Cooooo0_l0000<ooooo`;o00001oooool2o`0000Sooooo0_l00007ooooo`;o
00003?ooool2o`0000;ooooo0_l0000Gooooo`;o00000oooool2o`0001?ooooo0_l0000;ooooo`;o
00001oooool2o`0000kooooo0_l0000:ooooo`;o00005_ooool2o`0000Kooooo0_l00011ooooo`00
:Oooool00ol0003oooooooooo`07ooooo`;o0000?Oooool2o`0000Oooooo0_l00008ooooo`;o0000
5Oooool2o`0001_ooooo0_l00002ooooo`?o00002_ooool4o`0000Gooooo0_l0000Dooooo`;o0000
4oooool2o`0000Gooooo0_l0000Fooooo`;o00001?ooool2o`0000Kooooo0_l0000Xooooo`;o0000
4Oooool002Wooooo00?o0000ooooooooool03Oooool2o`0002cooooo0_l0001@ooooo`;o00000_oo
ool2o`0000_ooooo1?l0000Hooooo`;o00005_ooool2o`0001_ooooo0_l00006ooooo`;o00001_oo
ool2o`00027ooooo0_l00005ooooo`;o00004Oooool002Wooooo00?o0000ooooooooool02?ooool2
o`0000?ooooo0_l00005ooooo`;o000000?oooooo`000?l000008_ooool2o`000003ooooool0003o
000001[ooooo0ol0000:ooooo`;o00002?ooool2o`0001cooooo0ol00008ooooo`;o00003?ooool2
o`0000?ooooo0_l0000;ooooo`;o0000<oooool2o`0000_ooooo0_l00006ooooo`;o00006?ooool2
o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`;o00003_ooool002Wooooo0_l00009oooo
o`;o000000?oooooo`000?l000001oooool2o`000003ooooool0003o000000kooooo0_l0000Eoooo
o`;o00005?ooool2o`0000Cooooo0ol00007ooooo`;o000000?oooooo`000?l000002?ooool2o`00
01cooooo0ol00008ooooo`;o00003?ooool2o`0000?ooooo0_l0001=ooooo`;o00001_ooool2o`00
01Sooooo0_l00005ooooo`;o000000?oooooo`000?l000000_ooool3o`0000gooooo000Yooooo`03
o`000?oooooooooo00_ooooo0_l0000?ooooo`?o00002?ooool2o`0002_ooooo0_l0000>ooooo`;o
0000QOooool2o`0003_ooooo0_l00003ooooo`;o00003Oooool002Wooooo00?o0000ooooooooool0
2Oooool2o`0000oooooo1Ol0000Kooooo`;o0000[oooool2o`0000?ooooo0_l0000booooo`;o0000
5_ooool002Wooooo00?o0000ooooooooool02Oooool2o`0000oooooo0_l0000Gooooo`;o00001Ooo
ool2o`0000cooooo0_l0000kooooo`;o00003_ooool2o`0001_ooooo0_l00003ooooo`;o0000=ooo
ool2o`0001kooooo0_l0000Booooo`;o00005_ooool002Wooooo00?o0000ooooooooool07_ooool2
o`0001?ooooo0_l0000Cooooo`;o0000>oooool2o`0000kooooo0_l0000=ooooo`;o00003?ooool2
o`0000?ooooo0_l0001Gooooo`;o0000:_ooool002Wooooo0_l0000Oooooo`Co00001Oooool2o`00
06gooooo0_l00003ooooo`;o00001oooool2o`0004Oooooo0_l0001=ooooo`00:Oooool00ol0003o
ooooooooo`07ooooo`;o00005oooool2o`0000Gooooo0ol0000Fooooo`;o00001oooool2o`0000[o
oooo0_l0000looooo`;o000000?oooooo`000?l000000oooool4o`0004kooooo0_l0000Cooooo`;o
00006?ooool2o`0001kooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`07oooo
o`;o00002?ooool3o`0000;ooooo0_l0000@ooooo`;o00001_ooool2o`0000_ooooo1Ol00007oooo
o`;o00002_ooool2o`0003cooooo0_l00008ooooo`;o00004_ooool2o`0000[ooooo0_l000000ooo
oooo0000o`000006ooooo`;o00007oooool2o`0001?ooooo0_l00002ooooo`;o00004oooool2o`00
00?ooooo0_l000000ooooooo0000o`00000Kooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo017ooooo0ol00002ooooo`;o00002?ooool2o`0000kooooo0_l0000;
ooooo`?o0000LOooool2o`0000[ooooo0_l000000ooooooo0000o`000003ooooo`;o000000?ooooo
o`000?l000003_ooool2o`0000oooooo0_l00007ooooo`Co00002?ooool2o`0000;ooooo0_l0000<
ooooo`;o00001Oooool2o`0000Kooooo0_l0000Kooooo`001_ooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo023ooooo0_l0001Eooooo`;o0000C?ooool2o`00017ooooo0_l0000Hooooo`Co00006_ooool2
o`0002[ooooo0006ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07
ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000?ooooo`;o0000=Oooool2o`0002oooooo0_l00033
ooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool03oooool2o`0003Gooooo0_l0
001Sooooo`;o0000:?ooool2o`0000Cooooo0_l0000Dooooo`;o0000BOooool000Kooooo00Go410@
oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0mooooo`;o00005?ooool2o`0000Wooooo0_l0000Vooooo`;o00008ooo
ool2o`0001Kooooo0_l00004ooooo`;o00002_ooool2o`0000Cooooo0_l00007ooooo`;o00002ooo
ool2o`0004Wooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooo
oonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`;o0000
:?ooool2o`0001Cooooo0_l00009ooooo`;o00001?ooool2o`0001[ooooo0_l00004ooooo`;o0000
4Oooool2o`0001Sooooo0_l0000>ooooo`;o00001?ooool2o`0001Kooooo0_l000000ooooooo0000
o`00001Fooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`0Cooooo`;o0000Coooool2o`0001[o
oooo0_l0000Gooooo`;o00006?ooool2o`0002cooooo0_l00002ooooo`;o0000<?ooool2o`0000;o
oooo0_l0000Oooooo`00:Oooool2o`000;7ooooo0_l0000Tooooo`;o00003Oooool2o`00033ooooo
0_l00002ooooo`;o00007oooool002Wooooo00?o0000ooooooooool0;_ooool2o`0006;ooooo0_l0
00000ooooooo0000o`00000Iooooo`;o00009?ooool2o`0000?ooooo0_l0001Oooooo`00:Oooool0
0ol0003oooooooooo`0^ooooo`;o0000Eoooool2o`0000Wooooo0_l000000ooooooo0000o`00000N
ooooo`;o00009?ooool2o`0000Wooooo0_l0001Dooooo`00:Oooool00ol0003oooooooooo`1Loooo
o`;o000000?oooooo`000?l000009_ooool2o`0001Kooooo0_l0000Dooooo`;o00003_ooool2o`00
01oooooo0_l0000Uooooo`;o0000;Oooool002Wooooo00?o0000ooooooooool08oooool2o`0000Go
oooo0_l0000Tooooo`;o00002_ooool7o`0003Cooooo0_l00006ooooo`;o00001Oooool2o`0000Ko
oooo0_l0000Eooooo`;o0000=?ooool2o`00013ooooo0_l0000Nooooo`;o00003Oooool002Wooooo
0_l0000Cooooo`Co00001_ooool2o`0000Gooooo0_l00005ooooo`;o00009?ooool2o`0000_ooooo
0_l00002ooooo`;o00000_ooool2o`00033ooooo0_l00009ooooo`;o00000_ooool2o`0000Kooooo
0_l0000Wooooo`;o00008_ooool2o`00033ooooo0_l0000=ooooo`00:Oooool00ol0003ooooooooo
o`0Booooo`Co00001Oooool3o`0000oooooo0_l0000Cooooo`;o00001_ooool2o`0000[ooooo0_l0
000=ooooo`?o00002_ooool2o`0002kooooo0ol0000booooo`Co0000>oooool2o`0002Cooooo000Y
ooooo`03o`000?oooooooooo00Wooooo0_l00003ooooo`;o00002oooool2o`00013ooooo0_l0000C
ooooo`;o00001_ooool2o`0000Gooooo0_l00003ooooo`;o00002?ooool2o`0000Cooooo0_l00003
ooooo`?o00001?ooool2o`0002oooooo0_l00005ooooo`;o00009oooool2o`0000Cooooo0_l0000i
ooooo`Ko00000oooool2o`0000oooooo0_l0000<ooooo`00:Oooool00ol0003oooooooooo`09oooo
o`;o00000oooool2o`0003Sooooo0_l00006ooooo`?o00003Oooool2o`0000Wooooo0ol0000loooo
o`;o00009oooool2o`0003oooooo0_l00002ooooo`;o00000oooool2o`0000oooooo0_l0000<oooo
o`00:Oooool00ol0003oooooooooo`18ooooo`;o000000?oooooo`000?l000000oooool2o`0001go
oooo0_l0003;ooooo`00:Oooool2o`0004cooooo0_l0000Rooooo`;o0000?oooool2o`0008[ooooo
000Yooooo`03o`000?oooooooooo0;3ooooo0_l0002:ooooo`00:Oooool00ol0003oooooooooo`1Y
ooooo`;o0000dOooool002Wooooo00?o0000ooooooooool0=oooool2o`00033ooooo0_l0003Aoooo
o`00:Oooool00ol0003oooooooooo`0gooooo`;o0000c?ooool2o`0003Gooooo000Yooooo`;o0000
ooooool7ooooo`;o0000=Oooool002Wooooo00?o0000ooooooooool0=Oooool2o`000?oooooo1_oo
ool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Gooooo00?o0000ooooooooool0=Oooool2o`0007oooooo0_l00024ooooo`003_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0]_ooool2o`0005Oooooo0_l0000[ooooo`003_ooool01Ol@413ooooooooo
oooooooo410@013ooooo00?o0000ooooooooool00oooool3o`0007Oooooo0_l0002Fooooo`;o0000
:oooool000kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0Eoooool2o`0001kooooo0_l00033ooooo`003_ooool01Ol0003ooooooooo
oooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo05Oo
oooo0_l0000Qooooo`;o0000`?ooool000kooooo00Go410@oooooooooooooooooa0@400<ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0N_ooool2o`00013ooooo0_l0002^ooooo`00
3_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`13ooooo`;o0000Aoooool2o`0005[ooooo0_l0001Booooo`003_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000A?ooool2o`000:?ooooo0_l00009ooooo`;o
0000Aoooool002Wooooo00?o0000ooooooooool0coooool2o`0002;ooooo0_l0000Booooo`;o0000
0_ooool2o`0001gooooo0_l0000@ooooo`00:Oooool00ol0003oooooooooo`0Mooooo`;o00003?oo
ool2o`0000cooooo0_l0002Dooooo`;o0000=_ooool2o`0000;ooooo0_l0000Mooooo`;o00004?oo
ool002Wooooo00?o0000ooooooooool07Oooool2o`0000cooooo0_l0000<ooooo`;o0000ooooool2
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^oooo
o`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocgooooo
0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool0
1oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go
410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool0
0oooool3o`000?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q
8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo
0006ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@
4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004oooo
o`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Oooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3oooooocgooooo000Q
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0
003oooooooooo`05ooooo`?o0000oooooolmooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Oooooo`03oeEEEOmVIVKo0000
0?ooooooAoooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .32099 Mdot
.02762 .25926 Mdot
.02952 .29059 Mdot
.03143 .33987 Mdot
.03333 .35799 Mdot
.03524 .38263 Mdot
.03714 .2978 Mdot
.03905 .38153 Mdot
.04095 .39947 Mdot
.04286 .25765 Mdot
.04476 .27368 Mdot
.04667 .33793 Mdot
.04857 .24589 Mdot
.05048 .25449 Mdot
.05238 .29243 Mdot
.05429 .32071 Mdot
.05619 .33444 Mdot
.0581 .24851 Mdot
.06 .34796 Mdot
.0619 .39237 Mdot
.06381 .27247 Mdot
.06571 .23648 Mdot
.06762 .24949 Mdot
.06952 .26151 Mdot
.07143 .2541 Mdot
.07333 .28909 Mdot
.07524 .30938 Mdot
.07714 .34886 Mdot
.07905 .405 Mdot
.08095 .24623 Mdot
.08286 .31249 Mdot
.08476 .40833 Mdot
.08667 .37749 Mdot
.08857 .36864 Mdot
.09048 .38127 Mdot
.09238 .39063 Mdot
.09429 .43124 Mdot
.09619 .33881 Mdot
.0981 .4189 Mdot
.1 .3418 Mdot
.1019 .27575 Mdot
.10381 .37491 Mdot
.10571 .38763 Mdot
.10762 .32882 Mdot
.10952 .35079 Mdot
.11143 .33917 Mdot
.11333 .25964 Mdot
.11524 .42602 Mdot
.11714 .24589 Mdot
.11905 .40952 Mdot
.12095 .42399 Mdot
.12286 .42487 Mdot
.12476 .45591 Mdot
.12667 .38622 Mdot
.12857 .388 Mdot
.13048 .3873 Mdot
.13238 .37214 Mdot
.13429 .32604 Mdot
.13619 .43065 Mdot
.1381 .35693 Mdot
.14 .32732 Mdot
.1419 .23204 Mdot
.14381 .42096 Mdot
.14571 .27846 Mdot
.14762 .35316 Mdot
.14952 .40262 Mdot
.15143 .25788 Mdot
.15333 .31775 Mdot
.15524 .33442 Mdot
.15714 .28244 Mdot
.15905 .32256 Mdot
.16095 .26852 Mdot
.16286 .25544 Mdot
.16476 .27232 Mdot
.16667 .42094 Mdot
.16857 .2759 Mdot
.17048 .45613 Mdot
.17238 .28595 Mdot
.17429 .42097 Mdot
.17619 .25315 Mdot
.1781 .35392 Mdot
.18 .24548 Mdot
.1819 .33948 Mdot
.18381 .3757 Mdot
.18571 .39342 Mdot
.18762 .32837 Mdot
.18952 .35697 Mdot
.19143 .33871 Mdot
.19333 .30511 Mdot
.19524 .31368 Mdot
.19714 .24681 Mdot
.19905 .38647 Mdot
.20095 .30662 Mdot
.20286 .3444 Mdot
.20476 .30078 Mdot
.20667 .36492 Mdot
.20857 .25432 Mdot
.21048 .41442 Mdot
.21238 .45939 Mdot
.21429 .29649 Mdot
.21619 .30357 Mdot
.2181 .27797 Mdot
.22 .32658 Mdot
.2219 .3122 Mdot
.22381 .32279 Mdot
.22571 .37189 Mdot
.22762 .33907 Mdot
.22952 .3539 Mdot
.23143 .30702 Mdot
.23333 .29151 Mdot
.23524 .25532 Mdot
.23714 .34126 Mdot
.23905 .4075 Mdot
.24095 .38238 Mdot
.24286 .4914 Mdot
.24476 .32873 Mdot
.24667 .31074 Mdot
.24857 .40982 Mdot
.25048 .41149 Mdot
.25238 .42721 Mdot
.25429 .24881 Mdot
.25619 .22301 Mdot
.2581 .27746 Mdot
.26 .4049 Mdot
.2619 .28803 Mdot
.26381 .33638 Mdot
.26571 .39231 Mdot
.26762 .34348 Mdot
.26952 .25632 Mdot
.27143 .30989 Mdot
.27333 .24135 Mdot
.27524 .28214 Mdot
.27714 .31462 Mdot
.27905 .38555 Mdot
.28095 .38676 Mdot
.28286 .41433 Mdot
.28476 .43336 Mdot
.28667 .40112 Mdot
.28857 .25557 Mdot
.29048 .35739 Mdot
.29238 .29566 Mdot
.29429 .28578 Mdot
.29619 .33247 Mdot
.2981 .33922 Mdot
.3 .33331 Mdot
.3019 .38645 Mdot
.30381 .40027 Mdot
.30571 .49598 Mdot
.30762 .35743 Mdot
.30952 .3354 Mdot
.31143 .23186 Mdot
.31333 .26798 Mdot
.31524 .31141 Mdot
.31714 .25939 Mdot
.31905 .27151 Mdot
.32095 .36069 Mdot
.32286 .43078 Mdot
.32476 .4222 Mdot
.32667 .40363 Mdot
.32857 .42987 Mdot
.33048 .4314 Mdot
.33238 .2611 Mdot
.33429 .41985 Mdot
.33619 .31262 Mdot
.3381 .38097 Mdot
.34 .38387 Mdot
.3419 .29658 Mdot
.34381 .4001 Mdot
.34571 .33011 Mdot
.34762 .332 Mdot
.34952 .431 Mdot
.35143 .40562 Mdot
.35333 .32685 Mdot
.35524 .32772 Mdot
.35714 .35081 Mdot
.35905 .35876 Mdot
.36095 .36379 Mdot
.36286 .35951 Mdot
.36476 .36113 Mdot
.36667 .32709 Mdot
.36857 .41133 Mdot
.37048 .42726 Mdot
.37238 .32213 Mdot
.37429 .2984 Mdot
.37619 .27049 Mdot
.3781 .28395 Mdot
.38 .39606 Mdot
.3819 .34709 Mdot
.38381 .41813 Mdot
.38571 .31429 Mdot
.38762 .3886 Mdot
.38952 .2257 Mdot
.39143 .38527 Mdot
.39333 .26843 Mdot
.39524 .2322 Mdot
.39714 .38624 Mdot
.39905 .2626 Mdot
.40095 .32277 Mdot
.40286 .3461 Mdot
.40476 .39884 Mdot
.40667 .35143 Mdot
.40857 .32478 Mdot
.41048 .32556 Mdot
.41238 .26755 Mdot
.41429 .35439 Mdot
.41619 .41034 Mdot
.4181 .28612 Mdot
.42 .26236 Mdot
.4219 .37701 Mdot
.42381 .34107 Mdot
.42571 .27857 Mdot
.42762 .27224 Mdot
.42952 .23597 Mdot
.43143 .29289 Mdot
.43333 .33196 Mdot
.43524 .29816 Mdot
.43714 .29076 Mdot
.43905 .29789 Mdot
.44095 .30599 Mdot
.44286 .2916 Mdot
.44476 .34912 Mdot
.44667 .35526 Mdot
.44857 .31595 Mdot
.45048 .42372 Mdot
.45238 .32007 Mdot
.45429 .36712 Mdot
.45619 .29965 Mdot
.4581 .36045 Mdot
.46 .27936 Mdot
.4619 .32106 Mdot
.46381 .29234 Mdot
.46571 .22267 Mdot
.46762 .33246 Mdot
.46952 .31776 Mdot
.47143 .41992 Mdot
.47333 .26685 Mdot
.47524 .2984 Mdot
.47714 .22336 Mdot
.47905 .3326 Mdot
.48095 .30497 Mdot
.48286 .26084 Mdot
.48476 .28974 Mdot
.48667 .23487 Mdot
.48857 .38864 Mdot
.49048 .34362 Mdot
.49238 .32223 Mdot
.49429 .41396 Mdot
.49619 .30099 Mdot
.4981 .42889 Mdot
.5 .31377 Mdot
.5019 .3196 Mdot
.50381 .42095 Mdot
.50571 .26267 Mdot
.50762 .3285 Mdot
.50952 .27386 Mdot
.51143 .42872 Mdot
.51333 .27267 Mdot
.51524 .32612 Mdot
.51714 .38992 Mdot
.51905 .27821 Mdot
.52095 .36837 Mdot
.52286 .42905 Mdot
.52476 .2514 Mdot
.52667 .29746 Mdot
.52857 .3715 Mdot
.53048 .32193 Mdot
.53238 .27231 Mdot
.53429 .32491 Mdot
.53619 .26739 Mdot
.5381 .37761 Mdot
.54 .39879 Mdot
.5419 .25334 Mdot
.54381 .38929 Mdot
.54571 .38907 Mdot
.54762 .26092 Mdot
.54952 .25201 Mdot
.55143 .43057 Mdot
.55333 .29847 Mdot
.55524 .36077 Mdot
.55714 .42061 Mdot
.55905 .26386 Mdot
.56095 .36888 Mdot
.56286 .41446 Mdot
.56476 .31868 Mdot
.56667 .27524 Mdot
.56857 .42894 Mdot
.57048 .33871 Mdot
.57238 .3545 Mdot
.57429 .28047 Mdot
.57619 .35367 Mdot
.5781 .3668 Mdot
.58 .33426 Mdot
.5819 .34787 Mdot
.58381 .34983 Mdot
.58571 .42827 Mdot
.58762 .31293 Mdot
.58952 .42361 Mdot
.59143 .31645 Mdot
.59333 .43421 Mdot
.59524 .23204 Mdot
.59714 .3533 Mdot
.59905 .2987 Mdot
.60095 .49638 Mdot
.60286 .24696 Mdot
.60476 .39198 Mdot
.60667 .28356 Mdot
.60857 .41139 Mdot
.61048 .26982 Mdot
.61238 .261 Mdot
.61429 .41829 Mdot
.61619 .26881 Mdot
.6181 .31671 Mdot
.62 .23768 Mdot
.6219 .33838 Mdot
.62381 .24943 Mdot
.62571 .23529 Mdot
.62762 .32809 Mdot
.62952 .34059 Mdot
.63143 .37263 Mdot
.63333 .34581 Mdot
.63524 .32428 Mdot
.63714 .31459 Mdot
.63905 .22458 Mdot
.64095 .28679 Mdot
.64286 .33213 Mdot
.64476 .38778 Mdot
.64667 .37537 Mdot
.64857 .42393 Mdot
.65048 .36217 Mdot
.65238 .31862 Mdot
.65429 .30895 Mdot
.65619 .33514 Mdot
.6581 .36611 Mdot
.66 .42732 Mdot
.6619 .29595 Mdot
.66381 .23581 Mdot
.66571 .30992 Mdot
.66762 .26761 Mdot
.66952 .27491 Mdot
.67143 .38557 Mdot
.67333 .38397 Mdot
.67524 .25988 Mdot
.67714 .35494 Mdot
.67905 .44478 Mdot
.68095 .26115 Mdot
.68286 .24651 Mdot
.68476 .2843 Mdot
.68667 .37898 Mdot
.68857 .30538 Mdot
.69048 .39948 Mdot
.69238 .23742 Mdot
.69429 .32055 Mdot
.69619 .31045 Mdot
.6981 .2811 Mdot
.7 .34594 Mdot
.7019 .43602 Mdot
.70381 .3925 Mdot
.70571 .24709 Mdot
.70762 .35423 Mdot
.70952 .40223 Mdot
.71143 .26873 Mdot
.71333 .34454 Mdot
.71524 .27935 Mdot
.71714 .34665 Mdot
.71905 .31379 Mdot
.72095 .30979 Mdot
.72286 .28628 Mdot
.72476 .27112 Mdot
.72667 .25911 Mdot
.72857 .29071 Mdot
.73048 .37156 Mdot
.73238 .27308 Mdot
.73429 .33255 Mdot
.73619 .25374 Mdot
.7381 .38019 Mdot
.74 .3085 Mdot
.7419 .41066 Mdot
.74381 .30423 Mdot
.74571 .43191 Mdot
.74762 .42643 Mdot
.74952 .24765 Mdot
.75143 .43638 Mdot
.75333 .24143 Mdot
.75524 .26741 Mdot
.75714 .49417 Mdot
.75905 .42533 Mdot
.76095 .36341 Mdot
.76286 .27096 Mdot
.76476 .23209 Mdot
.76667 .29474 Mdot
.76857 .31088 Mdot
.77048 .3239 Mdot
.77238 .2853 Mdot
.77429 .31557 Mdot
.77619 .26567 Mdot
.7781 .29598 Mdot
.78 .30654 Mdot
.7819 .42572 Mdot
.78381 .31204 Mdot
.78571 .23367 Mdot
.78762 .3193 Mdot
.78952 .35419 Mdot
.79143 .44315 Mdot
.79333 .35555 Mdot
.79524 .35874 Mdot
.79714 .36034 Mdot
.79905 .30512 Mdot
.80095 .36492 Mdot
.80286 .3387 Mdot
.80476 .30684 Mdot
.80667 .32459 Mdot
.80857 .27996 Mdot
.81048 .31837 Mdot
.81238 .24289 Mdot
.81429 .35061 Mdot
.81619 .37619 Mdot
.8181 .33733 Mdot
.82 .31622 Mdot
.8219 .32002 Mdot
.82381 .3533 Mdot
.82571 .36531 Mdot
.82762 .29998 Mdot
.82952 .26227 Mdot
.83143 .22488 Mdot
.83333 .3606 Mdot
.83524 .30994 Mdot
.83714 .38302 Mdot
.83905 .33961 Mdot
.84095 .34363 Mdot
.84286 .25014 Mdot
.84476 .32783 Mdot
.84667 .23463 Mdot
.84857 .37004 Mdot
.85048 .28929 Mdot
.85238 .48534 Mdot
.85429 .32621 Mdot
.85619 .26217 Mdot
.8581 .38569 Mdot
.86 .2836 Mdot
.8619 .28344 Mdot
.86381 .23751 Mdot
.86571 .4482 Mdot
.86762 .32835 Mdot
.86952 .30829 Mdot
.87143 .35824 Mdot
.87333 .36685 Mdot
.87524 .24785 Mdot
.87714 .39344 Mdot
.87905 .27926 Mdot
.88095 .38452 Mdot
.88286 .37146 Mdot
.88476 .28619 Mdot
.88667 .32689 Mdot
.88857 .28615 Mdot
.89048 .37937 Mdot
.89238 .32831 Mdot
.89429 .41765 Mdot
.89619 .27202 Mdot
.8981 .34393 Mdot
.9 .39004 Mdot
.9019 .34016 Mdot
.90381 .34534 Mdot
.90571 .33048 Mdot
.90762 .26388 Mdot
.90952 .36482 Mdot
.91143 .26768 Mdot
.91333 .27091 Mdot
.91524 .4351 Mdot
.91714 .2513 Mdot
.91905 .33322 Mdot
.92095 .39775 Mdot
.92286 .30681 Mdot
.92476 .3518 Mdot
.92667 .31111 Mdot
.92857 .36633 Mdot
.93048 .22483 Mdot
.93238 .38372 Mdot
.93429 .27347 Mdot
.93619 .38614 Mdot
.9381 .25188 Mdot
.94 .26824 Mdot
.9419 .3248 Mdot
.94381 .38618 Mdot
.94571 .38914 Mdot
.94762 .327 Mdot
.94952 .27615 Mdot
.95143 .40146 Mdot
.95333 .36053 Mdot
.95524 .33034 Mdot
.95714 .3297 Mdot
.95905 .35178 Mdot
.96095 .28291 Mdot
.96286 .49029 Mdot
.96476 .28892 Mdot
.96667 .26675 Mdot
.96857 .41769 Mdot
.97048 .38099 Mdot
.97238 .33783 Mdot
.97429 .40553 Mdot
.97619 .32791 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo04Oooooo0_l00011ooooo`;o00000_ooool2o`0003;ooooo0_l0001Looooo`;o00006_ooool0
00Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`17ooooo`;o0000:Ooo
ool2o`0001Kooooo0_l00002ooooo`;o0000<_ooool2o`0003cooooo0_l0000Nooooo`;o00006_oo
ool000Co00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo0_l0002<ooooo`;o0000>_oo
ool000Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o
MgMgoc8b<_ooool01?ooool3o`0002;ooooo0_l0000eooooo`;o00006Oooool2o`0003kooooo0_l0
000eooooo`;o00001?ooool2o`0004Wooooo0006ooooo`05o`000?ooooooooooooooool000003_oo
ool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`0:ooooo`;o00005_ooool2o`0003Gooooo0_l0000Iooooo`;o00002Oooool2o`00013ooooo
0_l0000Qooooo`;o00002?ooool2o`0000[ooooo0_l0000Oooooo`;o00001?ooool2o`0001;ooooo
0_l0000eooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo0_l0001cooooo`;o0000
4?ooool2o`0002Wooooo1?l0000:ooooo`;o00001oooool2o`00033ooooo0_l00003ooooo`;o0000
<?ooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@
41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04gooooo0_l0001]ooooo`;o
00005Oooool2o`0001;ooooo0_l0000Aooooo`;o00003_ooool2o`00033ooooo0006ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006oooo
o`03o`000?oooooooooo00Cooooo0_l00009ooooo`;o00002Oooool2o`0001;ooooo0_l0000Moooo
o`;o0000POooool2o`0001Gooooo0_l0000Aooooo`;o0000@?ooool002Wooooo0_l00005ooooo`;o
000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00002Oooool2o`0001;ooooo0_l00004oooo
o`;o00004?ooool2o`0006kooooo0_l00005ooooo`;o00004Oooool2o`0000Kooooo0_l0000<oooo
o`;o00009_ooool2o`0002cooooo000Yooooo`03o`000?oooooooooo00Oooooo0_l000000ooooooo
0000o`00000Xooooo`;o00004?ooool2o`0005Gooooo0_l00006ooooo`;o00003oooool2o`0000Go
oooo0_l0000Iooooo`;o00003?ooool2o`0001cooooo0_l00008ooooo`;o00003?ooool2o`0000Co
oooo0_l0000Hooooo`00:Oooool00ol0003oooooooooo`05ooooo`;o00001Oooool2o`0001_ooooo
0_l00002ooooo`;o00002Oooool2o`0000Kooooo0_l0000?ooooo`;o0000B_ooool2o`0000Cooooo
1?l0000jooooo`;o00008Oooool2o`0001Kooooo0_l00004ooooo`;o00006?ooool002Wooooo00?o
0000ooooooooool00_ooool2o`000003ooooool0003o000000Gooooo0_l0000Gooooo`;o00000_oo
ool2o`0000;ooooo0_l00009ooooo`;o00001_ooool2o`0000Wooooo0_l00004ooooo`;o0000D?oo
ool2o`0003cooooo0_l0001Iooooo`00:Oooool2o`0000?ooooo0_l00007ooooo`;o00003?ooool2
o`0000[ooooo0_l0000Tooooo`;o00003_ooool2o`0000;ooooo0_l0000_ooooo`;o00004oooool2
o`0001?ooooo0_l0000Booooo`Co00003?ooool2o`0002Sooooo0_l0000booooo`00:Oooool2o`00
00cooooo0_l0000<ooooo`;o0000@?ooool2o`0000;ooooo0_l0000Dooooo`;o00001Oooool2o`00
01;ooooo0_l00005ooooo`;o00003?ooool2o`000003ooooool0003o0000013ooooo0_l0000Boooo
o`Co00003?ooool2o`0001oooooo0_l00007ooooo`;o00003_ooool2o`0002;ooooo000Yooooo`03
o`000?oooooooooo05Wooooo0_l0000Jooooo`;o00000_ooool2o`000003ooooool0003o000000oo
oooo0_l00008ooooo`;o00002?ooool2o`0000Gooooo0_l0000Qooooo`;o00006_ooool2o`0000Go
oooo0_l0000?ooooo`;o00005oooool4o`0000Oooooo0_l00006ooooo`;o00003oooool002Wooooo
00?o0000ooooooooool0:?ooool2o`0000Kooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Gooooo0_l0000Booooo`Go000000Oo
ooooo`000?l0003ok^k^oc8b<_l0003o<S8b00;o00000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo0_l0000Booooo`;o00001oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP02ooooo`Co000000?o<S8bonk^k_ooool02oooool2o`0000cooooo0_l0
0003ooooo`;o00001oooool5o`0000;ooooo0_l000001?lb<S;o0000oc8b<_o^k^h3ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h07_ooool2o`0000Oooooo0_l000001_m4A4Co0000o`000?lb<S;ogMgM
ooooo`;o000000Co<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
000Yooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o00007Oooool4o`0000Kooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Gooooo`;o00004?ooool01_nHV9So0000o`000?ooooooA4A4ooooo`;o000000GoMgMg
oiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMol0003o0000oiRHV?mgMgL05_ooool4o`0000Cooooo
0_l00008ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00;ooooo1?l000000onHV9SoMgMgooooo`0Iooooo`;o00000oooool4o`0000Sooooo0_l00003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01Wooooo0_l0
0003ooooo`;o00001Oooool2o`0000Gooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000Yooooo`03o`000?oooooooooo
00?ooooo0_l00004ooooo`;o00002_ooool2o`0001?ooooo0ol00005ooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001?oo
ool2o`00017ooooo0_l0000Aooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooo
oa0@4003ooooo`05oa0@4?l0003o0000ooooool@41005_ooool4o`0000Cooooo0_l00009ooooo`;o
000000?oooooo`000?ooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooo
oooooooooooooa0@400=ooooo`;o00004_ooool2o`0000Gooooo1Ol00003ooooo`05oa0@4?oooooo
ooooooooool@41000oooool01Ol@413ooooooooooooooooo410@01Wooooo0_l0000:ooooo`;o0000
0oooool2o`000005ooooool0003oooooooooool@41000oooool01Ol@413ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool00Oooool002Wooooo0_l0000Fooooo`;o00003?ooool2o`0000Ko
oooo0_l00005ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0_l00002oooo
o`05o`000?ooooooooooooooool000001?ooool2o`0002Gooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000000?ooooo0_l00002ooooo`03o`000?oooooooooo00Gooooo0_l0
000Aooooo`;o00003Oooool4o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000003Oooool2o`0000gooooo0_l0000:ooooo`04odA4A?oMgMgoooooo`00
00Cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000;o00004oooool2
o`0001Gooooo0_l000001OmgMgOo<S8boooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo007ooooo000Yooooo`03o`000?oooooooooo02?ooooo0_l0
0002ooooo`;o00002Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`;o0000
0_ooool01Ol0003ooooooooooooooooo000000Wooooo0_l0000Qooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`000003ooooo`;o00000_ooool00ol0003oooooooooo`05oooo
o`;o00004Oooool2o`0000kooooo00?o410@o`000?l000000oooool01_l0003ooooooooooooooooo
0000ooooo`?o00000oooool00ol0003oooooooooo`0Dooooo`;o00001?ooool2o`0000[ooooo00Co
gMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool0
00000_l0000=ooooo`?o00000oooool2o`0001Cooooo00Go0000ob4Q8Ol0003o<S8bolc<c003o`00
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo007ooooo000Yoooo
o`03o`000?oooooooooo02Oooooo0_l00003ooooo`;o00001?ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Wooooo0_l0
0004ooooo`;o00006Oooool2o`000003ooooool0003ooooo00;ooooo00Ko410@oooooooooooooooo
oa0@4?ooool2o`000005oa0@4?ooooooooooooooool@4100:oooool00onj^[[o8B4Qooooo`02oooo
o`06oa0@4?ooooooooooooooool@413ooooo0_l000001Ol@413ooooooooooooooooo410@00Cooooo
0_l0000<ooooo`;o00000_ooool2o`0000Kooooo0_l00009ooooo`03ogMgMoo<c<co000000;ooooo
0_l000001Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@400=oooo
o`?o00001Oooool3o`00017ooooo00?o0000ooooooooool00_ooool2o`000005oa0@4?oooooooooo
ooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo000Yooooo`03o`000?oooooo
oooo00cooooo0_l0000Nooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l00008ooooo`;o0000
6?ooool3o`000003oiRHV?l@413ooooo00;ooooo00KoMgMgoiRHV?ooooooV9RHogMgMoooool2o`00
0005ogMgMonHV9SooooooiRHV?mgMgL03_ooool2o`0001Sooooo00Go410@oiRHV?oooooo^[Zjo`00
0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Co
oooo0_l0000<ooooo`;o00002_ooool2o`0000Wooooo00?ok^k^odA4A?l000000_ooool2o`000005
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo0_l00009
ooooo`?o00004Oooool00ol0003oooooooooo`03ooooo`;o000000CoV9RHoooooonHV9SoMgMg0ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000Yooooo`?o00001Oooool2o`0000Gooooo0_l0
000Rooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^
k_l0003o0000oc8b<_o^k^h01Oooool2o`0002;ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00oo^k^ko<S8bo`000005o`0000Gooooo0_l00004
ooooo`;o00006?ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08?ooool2o`0000Sooooo00?oMgMgo`000?oo
ool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0:
ooooo`;o00007Oooool4o`0000;ooooo0_l000001?lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool002Wooooo0ol00005ooooo`;o0000>Oooool2o`00017ooooo0_l0
000Zooooo`Ko00001Oooool2o`0003gooooo0_l0000Dooooo`;o00002_ooool2o`0000;ooooo0_l0
001;ooooo`00:Oooool01?l0003oooooooooooooool2o`0003Oooooo0_l0000Gooooo`;o00003_oo
ool2o`0000Sooooo0_l0000Booooo`?o00002Oooool2o`0000oooooo0_l00007ooooo`;o00003?oo
ool2o`0001;ooooo0_l0000Pooooo`;o00000_ooool2o`0004_ooooo000Yooooo`04o`000?oooooo
ooooooooo`;o0000<oooool2o`0000;ooooo0_l0000Wooooo`;o00002?ooool2o`0001;ooooo0ol0
0003ooooo`;o00001?ooool2o`0000Gooooo0_l00008ooooo`;o00001oooool2o`0000cooooo0_l0
0018ooooo`;o0000>oooool002Wooooo00?o0000ooooooooool0<oooool2o`000003ooooool0003o
000000;ooooo0_l0001;ooooo`;o00001_ooool2o`0000?ooooo0_l0000looooo`;o00004?ooool2
o`00013ooooo0_l00007ooooo`;o0000>oooool002Wooooo00?o0000ooooooooool0<oooool4o`00
00?ooooo0_l00003ooooo`;o0000@Oooool2o`0000_ooooo0_l00011ooooo`;o00003oooool3o`00
00Wooooo0_l00005ooooo`?o00004oooool2o`0000oooooo0_l0000Mooooo`008Oooooooo`0004Co
00001?ooool002Wooooo00?o0000ooooooooool02Oooool01?l0003oooooooooooooool4o`0000Go
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;o
oooo0_l00005ooooo`04o`000?oooooo0000o`0000Kooooo0_l000000ooooooo0000ooooo`03oooo
o`Co00000oooool00ol0003oooooooooo`04ooooo`;o00000oooool01?l0003oooooo`000?l00008
ooooo`03o`000?oooooooooo00?ooooo0_l00005ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`02ooooo`;o00001Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Kooooo0_l000000ooooooo0000ooooo`0:ooooo`;o00001?ooool2
o`0000;ooooo0ol00006ooooo`;o00001?ooool01?l0003oooooo`000?l00008ooooo`03o`000?oo
oooooooo00?ooooo0_l00003ooooo`;o00002oooool00ol0003oooooooooo`02o`0000Sooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`;o00000_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00[ooooo000Yooooo`03o`000?oooooooooo00oooooo0_l0000E
ooooo`;o00002oooool2o`0000Gooooo00Co0000ooooool0003o00004?ooool2o`00017ooooo0_l0
000>ooooo`;o00001Oooool00ol0003oooooooooo`0:ooooo`;o00001Oooool2o`0000Oooooo0_l0
000Kooooo`Co00001Oooool2o`0000Cooooo0_l0000Iooooo`;o00004?ooool2o`000003ooooool0
003o000000Wooooo0_l0000aooooo`03o`000?oooooooooo00[ooooo000Yooooo`;o00001oooool2
o`0001kooooo0_l0001Mooooo`?o000000Coooooo`000?l0003ooooo0_l00008ooooo`;o00004_oo
ool2o`0000Oooooo0_l00006ooooo`;o00002Oooool2o`0000cooooo0_l0000Hooooo`;o00000_oo
ool2o`0000Gooooo0_l000001?oooooo0000o`000?l0000mooooo`00:Oooool2o`0000Oooooo0_l0
000Pooooo`;o00004oooool2o`0002gooooo0_l00008ooooo`;o00003_ooool2o`000003ooooool0
003o000000Sooooo0_l000000ooooooo0000o`000007ooooo`;o00002Oooool2o`0001Gooooo0_l0
0003ooooo`;o00003?ooool2o`0001Kooooo0_l00004ooooo`;o00001Oooool2o`0000;ooooo0_l0
000mooooo`00:Oooool2o`00027ooooo1?l00004ooooo`;o00004Oooool4o`0002Oooooo0_l00003
ooooo`?o00002?ooool5o`0001Sooooo0_l00005ooooo`;o00000oooool3o`0001oooooo0_l0000Y
ooooo`;o00002_ooool2o`0000gooooo0_l00009ooooo`;o00003oooool4o`0001Gooooo000Yoooo
o`03o`000?oooooooooo01Oooooo0_l00007ooooo`Co00003Oooool2o`0000Sooooo0_l00006oooo
o`;o00007oooool5o`0000;ooooo0_l0000;ooooo`?o00007Oooool4o`0000Cooooo0_l0000Loooo
o`;o0000>?ooool2o`0000[ooooo0_l000000ooooooo0000o`000003ooooo`;o00001?ooool4o`00
00;ooooo0_l00009ooooo`Co000000?oooooo`000?l000001Oooool2o`0000_ooooo000Yooooo`03
o`000?oooooooooo01Oooooo0_l0000Hooooo`;o00004?ooool2o`0000oooooo0ol0000=ooooo`;o
000000?oooooo`000?l000005oooool2o`0000Wooooo0_l00002ooooo`;o00001oooool2o`0002Co
oooo0_l00003ooooo`;o00007?ooool2o`00027ooooo0_l00006ooooo`;o00001_ooool2o`0000;o
oooo0_l00002ooooo`;o00002_ooool2o`0000Gooooo0_l0000;ooooo`00:Oooool00ol0003ooooo
ooooo`07ooooo`;o00007_ooool2o`00023ooooo0_l00009ooooo`?o000000?oooooo`000?l00000
2_ooool2o`0001[ooooo0_l00009ooooo`;o00000_ooool2o`0001kooooo0_l0000Booooo`;o0000
0oooool2o`0001Oooooo0_l0000iooooo`;o00007_ooool002Wooooo00Co0000ooooool0003o0000
0oooool2o`000003ooooool0003o000000_ooooo0_l00002ooooo`;o00003Oooool2o`0000Kooooo
0_l000000ooooooo0000o`00000:ooooo`;o00002Oooool2o`0000Wooooo0_l00002ooooo`;o0000
D_ooool2o`000003ooooool0003o000000cooooo0_l00009ooooo`;o0000;Oooool2o`0000?ooooo
0_l00004ooooo`;o0000:Oooool2o`0000gooooo000Yooooo`Co00000oooool2o`0000kooooo0ol0
00000ooooooo0000o`00000Eooooo`;o000000?oooooo`000?l000002_ooool2o`000003ooooool0
003o0000017ooooo0_l0000Wooooo`;o0000;Oooool2o`0000oooooo1?l0000fooooo`;o00000ooo
ool2o`0000Cooooo0_l0000Cooooo`;o00005?ooool2o`0000gooooo000Yooooo`03o`000?oooooo
oooo01Gooooo0_l0000Oooooo`;o00002Oooool2o`0000Sooooo0_l0000Yooooo`;o00001Oooool2
o`0001?ooooo0_l0000[ooooo`?o00005?ooool2o`0000;ooooo0_l0000Wooooo`;o00004?ooool4
o`0002?ooooo000Yooooo`03o`000?oooooooooo00Sooooo0_l00003ooooo`;o00009oooool2o`00
01?ooooo0_l0000Rooooo`;o00001Oooool2o`0000cooooo0_l0000<ooooo`;o00007?ooool2o`00
00kooooo0_l0000Dooooo`;o00000_ooool3o`0002Kooooo0_l0000@ooooo`Co00008oooool002Wo
oooo00?o0000ooooooooool02?ooool2o`0000?ooooo0_l00009ooooo`;o0000COooool2o`0000Ko
oooo0_l00006ooooo`;o00002oooool2o`0002[ooooo0_l0000Yooooo`;o00007Oooool2o`0002;o
oooo0_l00009ooooo`;o00004Oooool002Wooooo00?o0000ooooooooool06?ooool2o`0000[ooooo
0_l00008ooooo`;o00003_ooool2o`0002Oooooo0_l0000>ooooo`;o000000?oooooo`000?l00000
2?ooool2o`0002Oooooo1Ol00003ooooo`;o00005oooool2o`0000Sooooo0_l0000Hooooo`;o0000
1_ooool2o`0000;ooooo0_l0000Nooooo`;o00002Oooool2o`00017ooooo000Yooooo`Co00008?oo
ool2o`000003ooooool0003o000000Sooooo0_l00002ooooo`;o00002_ooool2o`0001;ooooo0_l0
0004ooooo`;o00008?ooool2o`0000Sooooo0_l0000Wooooo`?o00001Oooool2o`0001Oooooo0_l0
0008ooooo`;o00006?ooool4o`0000Sooooo0_l0000=ooooo`;o0000;Oooool002Wooooo00Co0000
ooooool0003o00008?ooool2o`0000oooooo0_l0000Nooooo`;o00001?ooool2o`0000;ooooo0_l0
000:ooooo`Co00007?ooool2o`0001gooooo0_l0001;ooooo`?o00002_ooool2o`0000[ooooo0_l0
000Hooooo`;o00004oooool002Wooooo00?o0000ooooooooool0G?ooool2o`0000[ooooo1?l0000L
ooooo`;o00007Oooool2o`0001gooooo0_l0000Qooooo`;o00002Oooool3o`0000[ooooo0_l0000T
ooooo`;o00004oooool002Wooooo00?o0000ooooooooool0=oooool2o`00033ooooo0_l0000Loooo
o`;o00009Oooool2o`0001Kooooo1?l0000Oooooo`;o00002oooool2o`0000Kooooo0_l0000=oooo
o`;o00002_ooool2o`0000Cooooo0_l0000Kooooo`00:Oooool00ol0003oooooooooo`0Aooooo`;o
00009?ooool2o`0004kooooo0_l0000Cooooo`;o00002oooool2o`0000?ooooo0_l0000Hooooo`;o
0000;?ooool2o`0000Kooooo0_l00005ooooo`;o00001_ooool2o`0000[ooooo0_l00004ooooo`;o
00006oooool002Wooooo0_l0000Booooo`;o00003?ooool2o`0001cooooo0_l0001Mooooo`;o0000
00?oooooo`000?l000002?ooool2o`0001Gooooo0_l0000Mooooo`;o00009?ooool2o`0000Wooooo
0_l0000Zooooo`00:Oooool00ol0003oooooooooo`0Fooooo`;o00001oooool2o`0000oooooo0_l0
000;ooooo`;o0000?Oooool2o`00027ooooo0_l0000Oooooo`;o00000oooool2o`0001Sooooo0_l0
000Jooooo`;o00004oooool2o`0002[ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`0@ooooo`;o00001?ooool2o`0001Sooooo0_l0001:ooooo`;o00009?ooool2o`00027ooooo
0_l0000:ooooo`;o00003oooool2o`0001Oooooo0_l0000Fooooo`;o00009oooool000Kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oo
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`03o`0000gooooo1?l0000^ooooo`;o
00007Oooool2o`0003oooooo0_l0000]ooooo`;o00003oooool2o`0001kooooo0_l0000?ooooo`;o
00006?ooool2o`0000gooooo0006ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ol0000?ooooo`;o
00002Oooool2o`0001Kooooo0_l0000;ooooo`;o00002_ooool2o`0000Kooooo0_l00009ooooo`?o
00003_ooool4o`0005Oooooo0_l0000cooooo`;o00001Oooool2o`0000Gooooo0_l0000>ooooo`Ko
00001oooool2o`0000gooooo0006ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So
8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Gooooo`;o00001?ooool4o`0001Co
oooo0_l0000Gooooo`?o00001Oooool2o`0000[ooooo0_l0000=ooooo`Go00007?ooool2o`0000oo
oooo0ol0000Nooooo`;o00001oooool2o`0003[ooooo0_l00005ooooo`;o00003_ooool7o`0001Go
oooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`09ooooo`;o00001oooool2o`00
00?ooooo0_l00005ooooo`?o0000:Oooool2o`0000?ooooo0_l0000Pooooo`;o00007oooool2o`00
00Oooooo0_l00006ooooo`?o00004Oooool2o`0000_ooooo0_l0000Aooooo`;o0000?Oooool2o`00
00gooooo0_l0000Eooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo0_l00007oooo
o`;o00007?ooool2o`0001Sooooo0_l0001?ooooo`;o00006_ooool2o`0001kooooo0_l0000foooo
o`;o00001Oooool2o`0002Cooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0`
ooooo`;o0000?Oooool2o`0000Kooooo0_l0000Yooooo`;o0000Joooool2o`0000cooooo0_l0000M
ooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c004ooooo`Co00001_ooool00ol0003oooooooooo`02ooooo`;o0000COooool2o`0000?ooooo0_l0
000;ooooo`;o00002_ooool2o`0000Kooooo0_l0000Yooooo`;o0000;oooool2o`0004Sooooo0_l0
0008ooooo`;o00004oooool002Wooooo0_l00003ooooo`;o00002_ooool2o`0001Gooooo0_l0000Q
ooooo`;o00001oooool2o`0000?ooooo0_l00006ooooo`;o00000oooool2o`0006kooooo0_l00004
ooooo`;o0000C?ooool2o`0001?ooooo000Yooooo`03o`000?oooooooooo00kooooo1?l0000Coooo
o`;o00006_ooool2o`0000Gooooo0_l0000Dooooo`;o00001_ooool2o`00077ooooo0_l0001Coooo
o`;o00003?ooool002Wooooo00?o0000ooooooooool04?ooool2o`0000Wooooo0_l0000Tooooo`;o
00000_ooool2o`0001oooooo0_l00003ooooo`;o00003Oooool2o`0003cooooo0_l0000Yooooo`;o
0000BOooool2o`0000cooooo000Yooooo`03o`000?oooooooooo01_ooooo0_l0000Kooooo`;o0000
2oooool2o`0000Wooooo0_l0000Iooooo`;o00003Oooool2o`0001Sooooo0_l0000Dooooo`;o0000
3?ooool2o`0002Wooooo0_l0001Gooooo`00:Oooool00ol0003oooooooooo`0hooooo`;o00002ooo
ool2o`0000Wooooo0_l00012ooooo`;o00005?ooool2o`0006Sooooo0_l0000Vooooo`00:Oooool2
o`0001Gooooo0_l0001:ooooo`;o00003_ooool2o`0001[ooooo0_l0000Jooooo`;o00004?ooool2
o`0005Sooooo0_l0000Fooooo`;o00003_ooool002Wooooo00?o0000ooooooooool05?ooool2o`00
00gooooo0_l00005ooooo`;o000000?oooooo`000?l00000;_ooool2o`000003ooooool0003o0000
00kooooo0_l0000Cooooo`;o00001Oooool2o`0000Wooooo0_l0000?ooooo`;o00002?ooool2o`00
00Kooooo0_l0001`ooooo`;o00003_ooool002Wooooo00?o0000ooooooooool06_ooool4o`0000Go
oooo0_l00005ooooo`;o000000?oooooo`000?l00000;_ooool2o`0002Kooooo0_l0000@ooooo`;o
00006Oooool2o`00017ooooo0_l0000Nooooo`;o00000_ooool2o`0000Gooooo0_l0001:ooooo`00
:Oooool00ol0003oooooooooo`0Jooooo`Co0000:?ooool2o`0001Kooooo0_l0000<ooooo`;o0000
9oooool2o`0000;ooooo0_l00002ooooo`;o00003?ooool2o`0000Cooooo0_l0000Booooo`;o0000
0_ooool2o`0001[ooooo0_l00002ooooo`;o00001Oooool2o`0004[ooooo000Yooooo`03o`000?oo
oooooooo01?ooooo0_l0000;ooooo`;o00009?ooool2o`0001Cooooo1Ol00004ooooo`;o00001Ooo
ool2o`0002Oooooo0_l00002ooooo`;o00000_ooool2o`0000Oooooo0_l00003ooooo`;o00001?oo
ool2o`0001Kooooo0_l0000Iooooo`;o0000E_ooool002Wooooo0_l0000Dooooo`;o00002oooool2
o`0002kooooo0_l0000:ooooo`;o000000?oooooo`000?l000001?ooool2o`0003oooooo0_l0000;
ooooo`;o00008Oooool2o`0000cooooo0_l0000eooooo`;o00007oooool002Wooooo00?o0000oooo
ooooool0D?ooool2o`00067ooooo0_l0000Qooooo`;o00003_ooool2o`0003?ooooo0_l0000Ooooo
o`00:Oooool00ol0003oooooooooo`3Vooooo`;o0000E?ooool002Wooooo00?o0000ooooooooool0
coooool2o`0002;ooooo0_l00017ooooo`00:Oooool00ol0003oooooooooo`3?ooooo`;o00008_oo
ool2o`0001Kooooo0_l0000_ooooo`00:Oooool2o`000?oooooo3Oooool2o`0002oooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool07Oooool2
o`0000cooooo0_l0003ooooooa3ooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Mooooo`;o00003?ooool2
o`0000cooooo0_l0003oooooo`;ooooo000>ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`03ooooo`?o0000>Oooool2o`000?oooooo0_ooool000kooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooooooooooooooooa0@
400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`003_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0
003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0ooooool8ooooo`;o0000<oooool002Wooooo00?o0000ooooooooool0ooooool8ooooo`;o
0000<oooool002Wooooo00?o0000ooooooooool0@oooool2o`000>Gooooo0_l0000@ooooo`00:Ooo
ool2o`0004Cooooo0_l0002Sooooo`;o0000@?ooool2o`00013ooooo000Yooooo`03o`000?oooooo
oooo05Oooooo0_l0001Mooooo`;o0000<?ooool2o`0005;ooooo000Yooooo`03o`000?oooooooooo
05Oooooo0_l0001Mooooo`;o0000Q?ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGo
oooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000Kooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`3oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool0
0omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgoooo
o`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Oooooo`Co000000?o410@ooooooooool00oooool00ol0
003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`?o0000oooooolmooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Oooooo`03oeEEEOmVIVKo00000?ooooooAoooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .38416 Mdot
.02762 .35049 Mdot
.02952 .31274 Mdot
.03143 .32483 Mdot
.03333 .35646 Mdot
.03524 .38926 Mdot
.03714 .31984 Mdot
.03905 .43977 Mdot
.04095 .43756 Mdot
.04286 .31457 Mdot
.04476 .26466 Mdot
.04667 .41894 Mdot
.04857 .26998 Mdot
.05048 .29658 Mdot
.05238 .39155 Mdot
.05429 .34451 Mdot
.05619 .25664 Mdot
.0581 .26597 Mdot
.06 .29174 Mdot
.0619 .30937 Mdot
.06381 .24483 Mdot
.06571 .30379 Mdot
.06762 .26793 Mdot
.06952 .25201 Mdot
.07143 .36495 Mdot
.07333 .35424 Mdot
.07524 .25474 Mdot
.07714 .29615 Mdot
.07905 .33368 Mdot
.08095 .33515 Mdot
.08286 .23564 Mdot
.08476 .44031 Mdot
.08667 .43553 Mdot
.08857 .30968 Mdot
.09048 .33554 Mdot
.09238 .31248 Mdot
.09429 .41543 Mdot
.09619 .27754 Mdot
.0981 .36903 Mdot
.1 .42209 Mdot
.1019 .38327 Mdot
.10381 .32096 Mdot
.10571 .37197 Mdot
.10762 .38918 Mdot
.10952 .3953 Mdot
.11143 .3669 Mdot
.11333 .28289 Mdot
.11524 .43781 Mdot
.11714 .30038 Mdot
.11905 .34648 Mdot
.12095 .43726 Mdot
.12286 .37952 Mdot
.12476 .3792 Mdot
.12667 .36166 Mdot
.12857 .35621 Mdot
.13048 .43654 Mdot
.13238 .43555 Mdot
.13429 .25031 Mdot
.13619 .42931 Mdot
.1381 .39644 Mdot
.14 .36522 Mdot
.1419 .27264 Mdot
.14381 .37737 Mdot
.14571 .26818 Mdot
.14762 .42274 Mdot
.14952 .44067 Mdot
.15143 .31427 Mdot
.15333 .34294 Mdot
.15524 .27006 Mdot
.15714 .23926 Mdot
.15905 .24738 Mdot
.16095 .30529 Mdot
.16286 .3023 Mdot
.16476 .33086 Mdot
.16667 .3774 Mdot
.16857 .28772 Mdot
.17048 .37964 Mdot
.17238 .35006 Mdot
.17429 .36882 Mdot
.17619 .28004 Mdot
.1781 .25852 Mdot
.18 .33351 Mdot
.1819 .31907 Mdot
.18381 .32168 Mdot
.18571 .44245 Mdot
.18762 .34553 Mdot
.18952 .35825 Mdot
.19143 .3633 Mdot
.19333 .2445 Mdot
.19524 .34272 Mdot
.19714 .35748 Mdot
.19905 .27058 Mdot
.20095 .26013 Mdot
.20286 .36542 Mdot
.20476 .26004 Mdot
.20667 .24584 Mdot
.20857 .29906 Mdot
.21048 .43682 Mdot
.21238 .38515 Mdot
.21429 .2447 Mdot
.21619 .37634 Mdot
.2181 .25168 Mdot
.22 .41209 Mdot
.2219 .38191 Mdot
.22381 .23664 Mdot
.22571 .31688 Mdot
.22762 .25915 Mdot
.22952 .30564 Mdot
.23143 .26016 Mdot
.23333 .23643 Mdot
.23524 .30954 Mdot
.23714 .31678 Mdot
.23905 .43966 Mdot
.24095 .29428 Mdot
.24286 .45693 Mdot
.24476 .30148 Mdot
.24667 .36066 Mdot
.24857 .44477 Mdot
.25048 .44348 Mdot
.25238 .41764 Mdot
.25429 .26597 Mdot
.25619 .3078 Mdot
.2581 .24316 Mdot
.26 .33252 Mdot
.2619 .2373 Mdot
.26381 .33318 Mdot
.26571 .31221 Mdot
.26762 .23017 Mdot
.26952 .34528 Mdot
.27143 .32923 Mdot
.27333 .28189 Mdot
.27524 .36498 Mdot
.27714 .40626 Mdot
.27905 .38972 Mdot
.28095 .37943 Mdot
.28286 .35161 Mdot
.28476 .40245 Mdot
.28667 .32771 Mdot
.28857 .30275 Mdot
.29048 .42668 Mdot
.29238 .39398 Mdot
.29429 .22638 Mdot
.29619 .28269 Mdot
.2981 .27597 Mdot
.3 .25558 Mdot
.3019 .29981 Mdot
.30381 .44381 Mdot
.30571 .47763 Mdot
.30762 .33246 Mdot
.30952 .36394 Mdot
.31143 .34232 Mdot
.31333 .25844 Mdot
.31524 .25386 Mdot
.31714 .25365 Mdot
.31905 .31125 Mdot
.32095 .39253 Mdot
.32286 .39939 Mdot
.32476 .37741 Mdot
.32667 .44261 Mdot
.32857 .41717 Mdot
.33048 .40003 Mdot
.33238 .33617 Mdot
.33429 .36441 Mdot
.33619 .40776 Mdot
.3381 .29639 Mdot
.34 .37609 Mdot
.3419 .37201 Mdot
.34381 .44324 Mdot
.34571 .23917 Mdot
.34762 .26739 Mdot
.34952 .39227 Mdot
.35143 .34094 Mdot
.35333 .27579 Mdot
.35524 .26382 Mdot
.35714 .36037 Mdot
.35905 .33467 Mdot
.36095 .42888 Mdot
.36286 .2412 Mdot
.36476 .39215 Mdot
.36667 .30843 Mdot
.36857 .34841 Mdot
.37048 .38072 Mdot
.37238 .41159 Mdot
.37429 .34283 Mdot
.37619 .37966 Mdot
.3781 .32676 Mdot
.38 .43568 Mdot
.3819 .2326 Mdot
.38381 .44225 Mdot
.38571 .40838 Mdot
.38762 .37461 Mdot
.38952 .32608 Mdot
.39143 .29755 Mdot
.39333 .27912 Mdot
.39524 .27326 Mdot
.39714 .44057 Mdot
.39905 .37475 Mdot
.40095 .41044 Mdot
.40286 .36435 Mdot
.40476 .28604 Mdot
.40667 .27292 Mdot
.40857 .28954 Mdot
.41048 .29238 Mdot
.41238 .29982 Mdot
.41429 .35721 Mdot
.41619 .30336 Mdot
.4181 .36679 Mdot
.42 .3022 Mdot
.4219 .39203 Mdot
.42381 .30695 Mdot
.42571 .32551 Mdot
.42762 .26546 Mdot
.42952 .29626 Mdot
.43143 .35337 Mdot
.43333 .24011 Mdot
.43524 .34172 Mdot
.43714 .36894 Mdot
.43905 .35498 Mdot
.44095 .40373 Mdot
.44286 .33001 Mdot
.44476 .39252 Mdot
.44667 .42887 Mdot
.44857 .36233 Mdot
.45048 .43209 Mdot
.45238 .23553 Mdot
.45429 .27522 Mdot
.45619 .34094 Mdot
.4581 .34634 Mdot
.46 .36584 Mdot
.4619 .26825 Mdot
.46381 .3916 Mdot
.46571 .30922 Mdot
.46762 .3411 Mdot
.46952 .29028 Mdot
.47143 .31984 Mdot
.47333 .26065 Mdot
.47524 .25388 Mdot
.47714 .31181 Mdot
.47905 .26878 Mdot
.48095 .37877 Mdot
.48286 .25401 Mdot
.48476 .36934 Mdot
.48667 .26779 Mdot
.48857 .38203 Mdot
.49048 .247 Mdot
.49238 .24726 Mdot
.49429 .4422 Mdot
.49619 .26047 Mdot
.4981 .40278 Mdot
.5 .24676 Mdot
.5019 .24623 Mdot
.50381 .37537 Mdot
.50571 .37444 Mdot
.50762 .30078 Mdot
.50952 .27317 Mdot
.51143 .40987 Mdot
.51333 .34416 Mdot
.51524 .26259 Mdot
.51714 .35682 Mdot
.51905 .28369 Mdot
.52095 .43297 Mdot
.52286 .4343 Mdot
.52476 .28058 Mdot
.52667 .25397 Mdot
.52857 .2813 Mdot
.53048 .32357 Mdot
.53238 .25556 Mdot
.53429 .38488 Mdot
.53619 .27158 Mdot
.5381 .38707 Mdot
.54 .32806 Mdot
.5419 .32496 Mdot
.54381 .30805 Mdot
.54571 .35874 Mdot
.54762 .32099 Mdot
.54952 .2809 Mdot
.55143 .39601 Mdot
.55333 .34333 Mdot
.55524 .32733 Mdot
.55714 .43839 Mdot
.55905 .27404 Mdot
.56095 .39338 Mdot
.56286 .35423 Mdot
.56476 .32904 Mdot
.56667 .33193 Mdot
.56857 .41798 Mdot
.57048 .41858 Mdot
.57238 .30676 Mdot
.57429 .31784 Mdot
.57619 .35259 Mdot
.5781 .27028 Mdot
.58 .36473 Mdot
.5819 .25284 Mdot
.58381 .23453 Mdot
.58571 .42861 Mdot
.58762 .40352 Mdot
.58952 .43004 Mdot
.59143 .30912 Mdot
.59333 .42269 Mdot
.59524 .27459 Mdot
.59714 .25463 Mdot
.59905 .39524 Mdot
.60095 .48588 Mdot
.60286 .29664 Mdot
.60476 .36949 Mdot
.60667 .36624 Mdot
.60857 .44145 Mdot
.61048 .37833 Mdot
.61238 .27982 Mdot
.61429 .43777 Mdot
.61619 .34166 Mdot
.6181 .27417 Mdot
.62 .28991 Mdot
.6219 .25996 Mdot
.62381 .26558 Mdot
.62571 .34743 Mdot
.62762 .31122 Mdot
.62952 .39019 Mdot
.63143 .31763 Mdot
.63333 .41955 Mdot
.63524 .32261 Mdot
.63714 .40718 Mdot
.63905 .31448 Mdot
.64095 .22532 Mdot
.64286 .33916 Mdot
.64476 .38949 Mdot
.64667 .31964 Mdot
.64857 .38639 Mdot
.65048 .34396 Mdot
.65238 .27514 Mdot
.65429 .31674 Mdot
.65619 .25589 Mdot
.6581 .43372 Mdot
.66 .41047 Mdot
.6619 .26032 Mdot
.66381 .30198 Mdot
.66571 .32981 Mdot
.66762 .29776 Mdot
.66952 .36293 Mdot
.67143 .38715 Mdot
.67333 .37624 Mdot
.67524 .33484 Mdot
.67714 .35574 Mdot
.67905 .35865 Mdot
.68095 .33444 Mdot
.68286 .33418 Mdot
.68476 .26483 Mdot
.68667 .43474 Mdot
.68857 .25433 Mdot
.69048 .32513 Mdot
.69238 .30955 Mdot
.69429 .26641 Mdot
.69619 .35865 Mdot
.6981 .22801 Mdot
.7 .42336 Mdot
.7019 .42006 Mdot
.70381 .31528 Mdot
.70571 .31164 Mdot
.70762 .27816 Mdot
.70952 .33341 Mdot
.71143 .25861 Mdot
.71333 .42251 Mdot
.71524 .22757 Mdot
.71714 .2494 Mdot
.71905 .40559 Mdot
.72095 .40445 Mdot
.72286 .39121 Mdot
.72476 .28491 Mdot
.72667 .26896 Mdot
.72857 .39081 Mdot
.73048 .43484 Mdot
.73238 .28158 Mdot
.73429 .24159 Mdot
.73619 .32431 Mdot
.7381 .39231 Mdot
.74 .3786 Mdot
.7419 .43731 Mdot
.74381 .37826 Mdot
.74571 .41992 Mdot
.74762 .40243 Mdot
.74952 .27089 Mdot
.75143 .41435 Mdot
.75333 .28219 Mdot
.75524 .37582 Mdot
.75714 .46437 Mdot
.75905 .42237 Mdot
.76095 .39404 Mdot
.76286 .30932 Mdot
.76476 .33874 Mdot
.76667 .24533 Mdot
.76857 .31533 Mdot
.77048 .41301 Mdot
.77238 .23814 Mdot
.77429 .27158 Mdot
.77619 .32534 Mdot
.7781 .35643 Mdot
.78 .25384 Mdot
.7819 .43905 Mdot
.78381 .23356 Mdot
.78571 .27089 Mdot
.78762 .4101 Mdot
.78952 .28018 Mdot
.79143 .35754 Mdot
.79333 .28135 Mdot
.79524 .33083 Mdot
.79714 .3346 Mdot
.79905 .27262 Mdot
.80095 .43263 Mdot
.80286 .41921 Mdot
.80476 .25433 Mdot
.80667 .27128 Mdot
.80857 .25909 Mdot
.81048 .34645 Mdot
.81238 .35647 Mdot
.81429 .36469 Mdot
.81619 .28761 Mdot
.8181 .29702 Mdot
.82 .25555 Mdot
.8219 .32594 Mdot
.82381 .36221 Mdot
.82571 .30253 Mdot
.82762 .25317 Mdot
.82952 .29764 Mdot
.83143 .32485 Mdot
.83333 .42825 Mdot
.83524 .29627 Mdot
.83714 .3403 Mdot
.83905 .25972 Mdot
.84095 .38887 Mdot
.84286 .3172 Mdot
.84476 .26345 Mdot
.84667 .34377 Mdot
.84857 .25008 Mdot
.85048 .3703 Mdot
.85238 .43948 Mdot
.85429 .38862 Mdot
.85619 .29483 Mdot
.8581 .43337 Mdot
.86 .38628 Mdot
.8619 .25868 Mdot
.86381 .30308 Mdot
.86571 .36488 Mdot
.86762 .27654 Mdot
.86952 .2674 Mdot
.87143 .34185 Mdot
.87333 .27403 Mdot
.87524 .29592 Mdot
.87714 .2791 Mdot
.87905 .32511 Mdot
.88095 .35355 Mdot
.88286 .31138 Mdot
.88476 .26327 Mdot
.88667 .31342 Mdot
.88857 .33895 Mdot
.89048 .43877 Mdot
.89238 .31457 Mdot
.89429 .36009 Mdot
.89619 .36033 Mdot
.8981 .39234 Mdot
.9 .3086 Mdot
.9019 .24674 Mdot
.90381 .26741 Mdot
.90571 .22398 Mdot
.90762 .32361 Mdot
.90952 .43326 Mdot
.91143 .37858 Mdot
.91333 .26814 Mdot
.91524 .42171 Mdot
.91714 .32059 Mdot
.91905 .2564 Mdot
.92095 .32162 Mdot
.92286 .37815 Mdot
.92476 .30163 Mdot
.92667 .35902 Mdot
.92857 .30358 Mdot
.93048 .29026 Mdot
.93238 .38098 Mdot
.93429 .29444 Mdot
.93619 .37109 Mdot
.9381 .28221 Mdot
.94 .29143 Mdot
.9419 .34138 Mdot
.94381 .35855 Mdot
.94571 .37545 Mdot
.94762 .29524 Mdot
.94952 .34593 Mdot
.95143 .44047 Mdot
.95333 .35348 Mdot
.95524 .38661 Mdot
.95714 .26359 Mdot
.95905 .30707 Mdot
.96095 .27176 Mdot
.96286 .45028 Mdot
.96476 .26871 Mdot
.96667 .35689 Mdot
.96857 .43258 Mdot
.97048 .2959 Mdot
.97238 .27461 Mdot
.97429 .33636 Mdot
.97619 .41437 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo6Oooool2o`0002;ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0Doooool2o`0006kooooo0_l0000Fooooo`;o0000>oooool2o`0002;ooooo0004
o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`1;ooooo`;o00001_ooool2o`0006kooooo0_l0
000@ooooo`;o00001?ooool2o`0005oooooo0006ooooo`05o`000?ooooooooooooooool000003Ooo
ool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0001;ooooo`;o00008_oo
ool2o`0006Cooooo0_l0000Jooooo`;o0000BOooool000Kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo00oooooo0_l0000/ooooo`;o000000?oooooo`000?l00000;Oooool2o`0001Gooooo
0_l0000Xooooo`;o0000?oooool2o`0004Wooooo0006ooooo`05oa0@4?ooooooooooooooool@4100
3oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
3oooool2o`0001Kooooo0_l0000Dooooo`;o000000?oooooo`000?l000001oooool2o`0001Wooooo
0_l0000Jooooo`;o00001?ooool2o`0002Sooooo0_l0000kooooo`;o0000COooool000Kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo02Oooooo0_l0000Oooooo`?o00006Oooool2o`0000?o
oooo0_l0000Eooooo`;o0000Goooool2o`0000[ooooo0_l0001=ooooo`001_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0
003oooooooooo`09ooooo`;o0000:?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000<oooo
o`;o00007oooool2o`0002_ooooo0_l00019ooooo`;o00002?ooool2o`0004oooooo000Yooooo`;o
00002_ooool2o`0001gooooo0_l00009ooooo`;o00000_ooool2o`000003ooooool0003o000005Ko
oooo1_l00013ooooo`;o00003_ooool2o`0002[ooooo0_l0000Sooooo`00:Oooool00ol0003ooooo
ooooo`0;ooooo`;o00004oooool2o`0000Kooooo0_l0000Aooooo`;o0000EOooool5o`0001Wooooo
0_l0000Yooooo`;o0000:?ooool2o`00013ooooo0_l0000Sooooo`00:Oooool00ol0003ooooooooo
o`0;ooooo`Co00004Oooool2o`0001Wooooo0_l0000Hooooo`;o00000oooool3o`00033ooooo0_l0
00000ooooooo0000o`00000<ooooo`Co00003_ooool2o`0000?ooooo0_l0000Aooooo`;o00002?oo
ool2o`0001_ooooo0_l00006ooooo`;o00000oooool2o`000003ooooool0003o000000Cooooo0_l0
000eooooo`00:Oooool00ol0003oooooooooo`07ooooo`;o00001?ooool2o`0001oooooo0_l0000U
ooooo`;o00000_ooool4o`00033ooooo0_l000000ooooooo0000o`00000<ooooo`Co00004oooool2
o`00017ooooo0_l00008ooooo`;o00001Oooool2o`0001Cooooo0_l00006ooooo`;o00000oooool2
o`000003ooooool0003o000000Wooooo0_l0000@ooooo`;o00007_ooool002Wooooo00?o0000oooo
ooooool01oooool2o`0002Gooooo0_l00005ooooo`?o00001_ooool3o`0001Sooooo0_l0000boooo
o`;o00001Oooool2o`0002Oooooo0_l0000:ooooo`;o00003_ooool2o`0001kooooo0_l00007oooo
o`;o00001_ooool2o`00013ooooo0_l0000Nooooo`00:Oooool2o`0000Cooooo0_l0000`ooooo`?o
00001_ooool3o`0002Kooooo0_l0000Tooooo`;o00001Oooool2o`0000Cooooo0_l0000Qooooo`;o
00002_ooool2o`0000Kooooo0_l0000Vooooo`;o00001oooool4o`0000_ooooo0_l0000Eooooo`;o
00004_ooool002Wooooo00?o0000ooooooooool00oooool2o`0000;ooooo0_l000000ooooooo0000
o`00000Gooooo`;o00008Oooool2o`0001cooooo0_l000000ooooooo0000o`00000Eooooo`;o0000
2Oooool2o`0000Kooooo0_l00007ooooo`;o00008Oooool2o`0001;ooooo0_l000000ooooooo0000
o`00000^ooooo`;o00001_ooool2o`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l00000
3?ooool2o`0001;ooooo000Yooooo`03o`000?oooooooooo00Cooooo0_l000001?oooooo0000o`00
0?ooool2o`0001Oooooo0_l00002ooooo`;o00001oooool4o`000008oa0@4?l0003o0000onk^k_lb
<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool2o`0001cooooo0_l0
0007ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^o`000?l0003o
<S8bonk^kP07ooooo`;o00001?ooool4o`0001Oooooo00CoV9RHoa0@4?l0003o<S8b0_l00002oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00oo^k^ko<S8bo`000002o`0001Gooooo0_l00008
ooooo`;o00001_ooool2o`000004ooooool0003o0000oa0@40?ooooo00Gok^k^oc8b<_l0003o0000
onk^kP03ooooo`05onk^k_l0003o0000oc8b<_o^k^h04?ooool2o`0000Wooooo0_l000000ooooooo
0000o`000009ooooo`06odA4A?l0003o0000oc8b<_oMgMgooooo0_l000001?lb<S;o0000oc8b<_o^
k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool002Wooooo00?o0000ooooooooool01?oo
ool2o`0001cooooo0_l00003ooooo`;o00002Oooool00ol0003oooooooooo`02o`000005ogMgMonH
V9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg02Wooooo00GoV9RHob4Q8Oo^
k^koooooodA4A002ooooo`;o000000CoV9RHo`000?l0003oMgMg0oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00gooooo0_l00007ooooo`;o00001oooool2o`0000Gooooo0_l000001?l@413o^[Zjoooo
oomgMgL2o`0000;ooooo00GoMgMgoiRHV?l0003o0000ogMgM`03ooooo`05ogMgMol0003o0000oiRH
V?mgMgL07oooool2o`0000Kooooo0_l00002ooooo`04o`000?ooooooooooooooo`;o000000CoV9RH
o`000?l0003oMgMg0_ooool4o`000003oiRHV?mgMgOooooo013ooooo0_l0000Iooooo`03ogMgMolb
<S;o000000Co000000?oV9RHogMgMoooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
000Yooooo`03o`000?oooooooooo01Cooooo0_l0000<ooooo`;o00003_ooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@013o
oooo0_l0000@ooooo`;o00001_ooool00onHV9So8B4Qonk^kP03ooooo`;o000000Coooooo`000?l0
003o410@0oooool01Ol@413ooooooooooooooooo410@00Gooooo0_l0000?ooooo`;o00001oooool2
o`0000Gooooo0_l00004ooooo`06o`000?ooooooooooooooool@413ooooo0_l000001Ol@413ooooo
oooooooooooo410@00;o000000?ooooooa0@4?ooool01_ooool2o`0001oooooo1Ol00002ooooo`;o
00000oooool00ol@413oooooooooo`02o`0000?ooooo00?o410@ooooooooool03_ooool3o`0001[o
oooo0ol000001Ol@413o0000o`000?oooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003
ooooo`00:Oooool2o`0001Gooooo0_l0000Gooooo`;o00000oooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000013ooooo0_l0
000@ooooo`;o00001oooool01?nHV9So8B4Qonk^k_ooool3o`0000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo00?ooooo0_l0000Dooooo`;o00003_ooool00onYZJWo
410@ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool2o`0000;ooooo00?o0000oooo
ooooool01Oooool2o`00013ooooo0_l0000=ooooo`04odA4A?oMgMgoooooo`0000Cooooo00?o0000
ooooooooool00_l00003ooooo`05o`000?ooooooooooooooool000004?ooool2o`000003ooooool0
003o000001Oooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`01ooooo`00:Oooool00ol0003oooooooooo`0Iooooo`;o0000
4_ooool2o`0000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000009ooooo`;o00001Oooool2o`0001[ooooo00?oMgMgofIV
I_ooool00ol00003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0H
ooooo`Go00001?ooool2o`0000Gooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooo
oooo000000?ooooo0_l00002ooooo`03o`000?oooooooooo01Oooooo0_l00006ooooo`;o00001Ooo
ool2o`000003ooooool0003ooooo00?ooooo00?o0000ooooooooool01?l000000ooooooo0000oooo
o`02ooooo`03o`000?oooooooooo017ooooo0_l0000Aooooo`;o000000Koooooo`000?lQ8B7o0000
oc8b<_o<c<`2ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000?ooooo000Yooooo`03o`000?oooooooooo01Wooooo0_l0000Gooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002Ooo
ool2o`0000Gooooo0_l0000Kooooo`06o`000?ooooooooooooooool@413ooooo0_l000001Ol@413o
oooooooooooooooo410@00?ooooo00?o410@ooooooooool06?ooool2o`000003ooooool0003o0000
00Cooooo0_l00006ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@41007oooool4o`0000Gooooo0_l000000oo<c<co0000oooo
o`03ooooo`05oa0@4?ooooooooooooooool@41000_l000000ooooooo410@ooooo`02ooooo`03oa0@
4?oooooooooo02Cooooo0_l000000ooooooo0000ooooo`05ooooo`05oa0@4?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@00?ooooo000Yooooo`03o`000?oooooooooo02_o
oooo0_l00005ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL0:Oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00?o
MgMgoiRHV?l000000_l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:?ooool01Ol@413oV9RH
oooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So0000
o`000?mgMgL07oooool2o`0000Sooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00CoMgMgoiRHV?ooooooV9RH0_l0000Xooooo`03o`000?oooooooooo00Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wo
oooo00?o0000ooooooooool02?ooool2o`00027ooooo0_l00003ooooo`03oeEEEOmVIVKo000000Co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:Oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00?ok^k^oc8b<_l000000ol00002ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02_ooool2o`0001cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?l0003ok^k^02[ooooo00?oMgMg
o`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Cok^k^oc8b<_l0003o<S8b
0_l0000Sooooo`;o000000?oooooo`000?l000001?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Yooooo`;o00002Oooool2o`0000?o
oooo0_l0000cooooo`;o0000=Oooool2o`0000Cooooo0_l0000;ooooo`;o0000Loooool2o`0000Go
oooo0_l00004ooooo`;o00004?ooool7o`0000Kooooo0_l0000=ooooo`00:Oooool00ol0003ooooo
ooooo`05ooooo`;o00001_ooool2o`0002Wooooo0_l00008ooooo`;o00007Oooool2o`0000oooooo
0_l0000;ooooo`;o0000=Oooool2o`0001?ooooo0_l0000_ooooo`;o000000?oooooo`000?l00000
0_l00005ooooo`;o00001?ooool2o`00017ooooo0_l00002ooooo`;o00001_ooool2o`0000gooooo
000Yooooo`03o`000?oooooooooo00Gooooo0_l0000Cooooo`;o00003Oooool2o`0000gooooo0_l0
0009ooooo`;o00004Oooool2o`0000Wooooo0_l0000?ooooo`;o00001Oooool2o`000003ooooool0
003o000001[ooooo0_l0000Looooo`;o00004_ooool3o`0002oooooo1Ol0000Mooooo`;o00007?oo
ool002Wooooo00?o0000ooooooooool02_ooool2o`0000kooooo0_l0000<ooooo`?o00004oooool2
o`0000?ooooo0_l0000<ooooo`;o00000oooool2o`00027ooooo1Ol0000Jooooo`;o0000<?ooool2
o`0003;ooooo0_l0000:ooooo`;o00004_ooool3o`0001_ooooo000Yooooo`03o`000?oooooooooo
00[ooooo0_l0000Looooo`;o00005?ooool2o`0000Oooooo0_l00008ooooo`;o00006?ooool2o`00
00gooooo0_l000000ooooooo0000o`00000Tooooo`;o00002?ooool2o`0005_ooooo0_l0000:oooo
o`;o00001oooool2o`0000Sooooo0_l0000Aooooo`008Oooooooo`0004Co00001?ooool002Wooooo
0ol00002ooooo`;o00001Oooool2o`0000Kooooo0ol00002ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool00_l00007ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
0oooool2o`0000Gooooo00?o0000ooooooooool00_l00007ooooo`03o`000?oooooooooo00Gooooo
0_l00002ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00?ooooo0_l00002ooooo`?o00002oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Oooooo0ol00008ooooo`;o000000Coooooo`000?l0003o
00002Oooool00ol0003oooooooooo`03ooooo`;o00000oooool3o`0000_ooooo00Co0000oooooooo
oooooooo0_l00006ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`02ooooo`Ko000000?oooooo`000?ooool02_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo000Yooooo`?o00000_ooool2o`0000kooooo0_l0000Aooooo`;o
00004oooool00ol0003oooooooooo`02o`0000;ooooo0_l00007ooooo`;o0000;?ooool00ol0003o
ooooooooo`0booooo`;o00001_ooool00ol0003oooooooooo`08ooooo`Co00000oooool2o`0000ko
oooo0_l0000Cooooo`;o00001?ooool00ol0003oooooooooo`0?ooooo`;o00003?ooool4o`0001Wo
oooo00?o0000ooooooooool02_ooool002Wooooo00Co0000oooooooooooooooo0_l0000Cooooo`;o
00005oooool2o`0000cooooo0_l00002ooooo`;o0000BOooool2o`0001Oooooo0_l00006ooooo`;o
00004Oooool2o`0000?ooooo1?l0000>ooooo`;o00004oooool2o`0001Kooooo0_l0000Fooooo`;o
00007_ooool002Wooooo00Co0000oooooooooooooooo0_l0000Cooooo`;o00005oooool3o`0005[o
oooo0_l0000Aooooo`;o00001?ooool2o`0001[ooooo0_l00002ooooo`;o00006_ooool2o`0003Go
oooo0_l00002ooooo`?o00007Oooool002Wooooo1?l0000_ooooo`;o0000??ooool2o`0000;ooooo
0_l00009ooooo`;o00008?ooool2o`0000;ooooo0_l00002ooooo`;o00006?ooool2o`00013ooooo
0_l0000<ooooo`;o00002oooool2o`0000gooooo0_l000000ooooooo0000o`00000=ooooo`;o0000
1oooool2o`0000?ooooo0_l0000Mooooo`00:Oooool01?l0003oooooo`000?l0001;ooooo`;o0000
0oooool2o`0001_ooooo0_l00002ooooo`;o00002Oooool2o`0000Cooooo0_l0000Mooooo`?o0000
0_ooool2o`000003ooooool0003o000001oooooo0_l00006ooooo`;o00006Oooool2o`0000gooooo
0_l000000ooooooo0000o`00000=ooooo`;o0000:oooool002Wooooo00?o0000ooooooooool03_oo
ool2o`0001[ooooo0_l00002ooooo`;o00006?ooool3o`000003ooooool0003o000000?ooooo0_l0
0005ooooo`;o0000:Oooool2o`0001gooooo0_l00006ooooo`?o00007_ooool2o`0000cooooo0_l0
000Iooooo`;o0000A_ooool002Wooooo00?o0000ooooooooool03_ooool3o`000003ooooool0003o
000001Kooooo0_l00002ooooo`;o00006?ooool3o`0000gooooo0_l00005ooooo`;o00001oooool2
o`00047ooooo0_l0000Qooooo`Co00001oooool2o`0001Wooooo0ol0000gooooo`;o00003?ooool0
02Wooooo00?o0000ooooooooool03oooool2o`000003ooooool0003o000004_ooooo0_l00007oooo
o`;o0000FOooool2o`0000Wooooo1?l0000Iooooo`;o00002?ooool2o`0001_ooooo0_l0000Joooo
o`;o00003?ooool002Wooooo0_l0000Wooooo`;o00002oooool2o`0002Cooooo0_l0000;ooooo`;o
00001Oooool2o`0001;ooooo0_l00004ooooo`;o00000_ooool2o`0002kooooo0_l00006ooooo`;o
00009_ooool2o`0001Gooooo0_l00009ooooo`;o00000oooool2o`0000oooooo0_l0000Gooooo`00
:Oooool00ol0003oooooooooo`06ooooo`;o00007_ooool2o`0000Wooooo1?l0000Fooooo`;o0000
3?ooool2o`0000_ooooo0_l00005ooooo`;o00004_ooool2o`0000Cooooo0_l00002ooooo`;o0000
3Oooool2o`0000_ooooo0_l0000Booooo`;o00002Oooool2o`0003[ooooo0_l000000ooooooo0000
o`000006ooooo`;o00005?ooool2o`000003ooooool0003o000001Cooooo000Yooooo`03o`000?oo
oooooooo00Kooooo0_l0000Cooooo`;o00005?ooool2o`0001Sooooo0_l0000Nooooo`;o00006ooo
ool2o`00013ooooo0_l0000;ooooo`;o00005Oooool2o`0000Kooooo0_l0000aooooo`;o00002_oo
ool2o`0001oooooo0_l0000Dooooo`00:Oooool2o`0001cooooo0_l0000?ooooo`;o00008_ooool2
o`0001Wooooo0_l0000Kooooo`;o0000=?ooool2o`0003Wooooo0_l00011ooooo`00:Oooool2o`00
00gooooo0_l0000Nooooo`;o00008_ooool2o`0002gooooo0_l000000ooooooo0000o`00000Voooo
o`;o00000_ooool2o`00063ooooo0_l0000Eooooo`;o00004oooool002Wooooo1?l0000;ooooo`;o
00004?ooool2o`0001;ooooo1?l00014ooooo`;o00000oooool2o`000003ooooool0003o000001Oo
oooo0_l0000=ooooo`;o00000_ooool2o`0001kooooo0_l0000Oooooo`;o00000_ooool2o`0000Go
oooo0_l0000Dooooo`;o00004_ooool2o`000003ooooool0003o000000;ooooo0_l0000?ooooo`00
:Oooool01?l0003oooooo`000?l0000Looooo`?o00004_ooool4o`0000kooooo0_l0000Qooooo`;o
00004Oooool2o`0001oooooo0_l00007ooooo`;o0000:?ooool3o`0000?ooooo0_l0000Iooooo`;o
00000_ooool2o`0000Gooooo0_l0000Hooooo`?o00002?ooool2o`0000?ooooo0_l00005ooooo`;o
00003oooool002Wooooo00?o0000ooooooooool07Oooool2o`0001?ooooo0_l0000@ooooo`;o0000
4_ooool2o`0000Kooooo0_l00005ooooo`;o00003Oooool2o`0000gooooo0_l0000Mooooo`;o0000
2Oooool2o`0001_ooooo0_l000000ooooooo0000o`000003ooooo`;o00009?ooool2o`0000;ooooo
0_l0000Dooooo`?o00002?ooool2o`0001_ooooo000Yooooo`03o`000?oooooooooo00cooooo0_l0
000:ooooo`;o00002?ooool2o`0000kooooo0_l00002ooooo`;o00005Oooool2o`0000Wooooo0_l0
0006ooooo`;o00005?ooool2o`0000?ooooo0_l00008ooooo`;o00000_ooool2o`0002Cooooo0_l0
0007ooooo`;o00004_ooool2o`0002cooooo0_l00002ooooo`;o00002oooool2o`0002oooooo000Y
ooooo`03o`000?oooooooooo00cooooo0_l00006ooooo`;o00000_ooool2o`0000Sooooo0_l00009
ooooo`;o00001oooool2o`0001Gooooo0_l0000/ooooo`;o00001?ooool2o`0000Kooooo0_l00005
ooooo`;o00009Oooool3o`0004cooooo0_l00003ooooo`;o0000;oooool002Wooooo0_l0000Eoooo
o`;o000000?oooooo`000?l000005?ooool2o`0003Cooooo0_l0000Looooo`;o00003Oooool2o`00
02Gooooo0_l0001=ooooo`;o00006_ooool2o`0001Sooooo000Yooooo`03o`000?oooooooooo01Oo
oooo0_l0000Qooooo`;o00009_ooool3o`0000cooooo0_l00002ooooo`;o00008?ooool2o`0003Co
oooo0_l0000Hooooo`;o0000>Oooool2o`000003ooooool0003o000001Gooooo0006ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`0Looooo`?o00001?ooool2o`0000Gooooo0ol0000=oooo
o`;o00004oooool2o`0000cooooo0_l00003ooooo`;o00002_ooool2o`000003ooooool0003o0000
00;ooooo0_l0000Hooooo`;o00001_ooool2o`00023ooooo0_l0000Booooo`;o00005?ooool3o`00
0003ooooool0003o0000037ooooo0_l000000ooooooo0000o`000006ooooo`;o00005Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Eooooo`;o00001Oooool3
o`0000Cooooo0_l00005ooooo`?o00003oooool2o`00017ooooo0_l0000<ooooo`;o00003Oooool4
o`0001oooooo0_l000000ooooooo0000o`00000Uooooo`;o0000:?ooool3o`0003Cooooo0_l00000
1?oooooo0000o`000?ooool2o`0001[ooooo0006ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0_l0000Fooooo`;o00008_oo
ool2o`000003ooooool0003o000002kooooo0_l0000Tooooo`;o00003?ooool2o`0002?ooooo0_l0
0012ooooo`;o00005Oooool2o`0001[ooooo0006ooooo`05o`000?ooooooooooooooool000003Ooo
ool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo1Ol0000Eooooo`;o00008?oo
ool2o`0006Gooooo1?l0000Pooooo`?o00001_ooool2o`0003Cooooo0_l00002ooooo`Co00007Ooo
ool2o`0001;ooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`02o`0000?ooooo
0_l0000@ooooo`;o0000=Oooool2o`0000cooooo0_l00007ooooo`;o00000oooool2o`00013ooooo
0_l00006ooooo`;o00001?ooool2o`0001Kooooo0_l0000Kooooo`;o00000oooool2o`0000Oooooo
0_l0000>ooooo`Co000000?oooooo`000?l000007oooool2o`0000;ooooo0_l0000<ooooo`;o0000
4Oooool2o`0001;ooooo0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool2o`00017ooooo
0_l0000dooooo`;o00000oooool2o`0000Oooooo0_l00007ooooo`;o00000oooool2o`00013ooooo
0_l00006ooooo`;o00001?ooool2o`0001gooooo0_l0000:ooooo`;o00002?ooool2o`0001cooooo
1?l000000ooooooo0000o`000005ooooo`;o0000:_ooool2o`0002Gooooo0006ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Hooooo`;o00001oooool2o`00033ooooo0_l0001Aooooo`;o
000000?oooooo`000?l000002_ooool2o`0003;ooooo0_l0001Aooooo`001_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0
003oooooooooo`0Qooooo`;o0000>Oooool2o`000003ooooool0003o000004Gooooo0_l0002Doooo
o`00:Oooool2o`00057ooooo0_l0000:ooooo`;o000000?oooooo`000?l000008Oooool2o`00017o
oooo0_l0000Kooooo`;o0000:?ooool2o`0000Oooooo0_l0001Eooooo`00:Oooool00ol0003ooooo
ooooo`1>ooooo`Co00003oooool2o`0001oooooo0_l0000Aooooo`;o00006oooool2o`0000gooooo
0_l0000Iooooo`;o00001oooool2o`0005Gooooo000Yooooo`03o`000?oooooooooo04kooooo0_l0
000Aooooo`;o00003_ooool2o`0000?ooooo0_l0000Qooooo`;o00009_ooool2o`0000Kooooo0_l0
000Aooooo`;o00005?ooool2o`0004Sooooo000Yooooo`03o`000?oooooooooo03_ooooo0_l0000_
ooooo`;o00000oooool2o`0000?ooooo0_l0000Qooooo`;o0000;_ooool2o`0001_ooooo0_l00004
ooooo`;o00001?ooool2o`0003_ooooo0_l0000;ooooo`00:Oooool00ol0003oooooooooo`0Coooo
o`;o00009_ooool2o`0000Wooooo0_l0000Fooooo`;o00003?ooool2o`0007Sooooo0_l00004oooo
o`;o0000@Oooool2o`0000_ooooo000Yooooo`;o00001Oooool2o`0000gooooo0_l0000aooooo`;o
00005_ooool2o`0004_ooooo0ol0000Booooo`;o00005?ooool2o`0000cooooo0_l0000Aooooo`;o
0000@oooool002Wooooo00?o0000ooooooooool01?ooool2o`0000oooooo0_l0000=ooooo`;o0000
QOooool3o`0000Gooooo0_l0000;ooooo`;o00005?ooool2o`0000;ooooo0_l00008ooooo`;o0000
0oooool2o`0000cooooo0_l0000Rooooo`;o00007oooool002Wooooo00?o0000ooooooooool05Ooo
ool2o`0000gooooo0_l0000/ooooo`;o0000Goooool2o`00027ooooo0_l00002ooooo`;o00003Ooo
ool2o`00033ooooo0_l0000Oooooo`00:Oooool00ol0003oooooooooo`0Pooooo`;o0000<?ooool2
o`0001Gooooo0_l0000Iooooo`;o0000:oooool3o`0004gooooo0_l0000iooooo`00:Oooool00ol0
003oooooooooo`0Pooooo`;o0000Aoooool2o`0001Wooooo0ol0000Eooooo`;o00004oooool3o`00
04;ooooo0_l00009ooooo`;o0000:Oooool2o`0000kooooo000Yooooo`;o00004Oooool2o`0000go
oooo0_l0001>ooooo`;o00005?ooool2o`0001Gooooo0ol0000Yooooo`;o00001oooool2o`0000co
oooo0_l0000Eooooo`;o00004Oooool2o`0000kooooo0_l0000Aooooo`;o00003_ooool002Wooooo
00?o0000ooooooooool00_ooool2o`0000cooooo0_l00008ooooo`Co000000?oooooo`000?l00000
5oooool2o`0003Gooooo0_l0000/ooooo`;o00002Oooool2o`00013ooooo0_l0000<ooooo`;o0000
1oooool2o`0000cooooo0_l00002ooooo`;o00002oooool2o`0001Oooooo0_l00008ooooo`;o0000
1?ooool2o`00027ooooo000Yooooo`04o`000?ooooooooooooooo`?o00003?ooool2o`0000Sooooo
1?l000000ooooooo0000o`000004ooooo`;o00002Oooool2o`0000Kooooo0_l00007ooooo`;o0000
;Oooool2o`0000;ooooo0_l0000Nooooo`;o00004_ooool2o`0000kooooo1?l0000Wooooo`;o0000
2oooool2o`0001Gooooo0_l0000:ooooo`;o00004_ooool2o`0001?ooooo000Yooooo`04o`000?oo
ooooooooooooo`;o00003Oooool2o`0001?ooooo0_l00009ooooo`;o00003oooool2o`0000;ooooo
0_l0000?ooooo`;o00001_ooool2o`0000?ooooo0_l0000;ooooo`;o00000_ooool2o`0001kooooo
0_l0000Rooooo`;o0000COooool2o`0001kooooo0_l0000Cooooo`00:Oooool00ol0003ooooooooo
o`15ooooo`;o00003oooool2o`0000Kooooo0_l00003ooooo`;o0000eoooool002Wooooo0_l0003o
ooooobcooooo0_l0000@ooooo`00:Oooool00ol0003oooooooooo`3oooooob_ooooo0_l0000@oooo
o`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool00ol0003oooooooooo`13ooooo`;o0000moooool000kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo04?ooooo0_l0003gooooo`003_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000
ooooooooool00oooool3o`000?oooooo?Oooool000kooooo00Go0000ooooooooooooooooo`00000?
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0j?ooool2o`0005;ooooo000>oooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool0j?ooool2o`0005;ooooo000>ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooo
oolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000F?oo
ool2o`000>?ooooo000Yooooo`03o`000?oooooooooo05Oooooo0_l0003Sooooo`00:Oooool00ol0
003oooooooooo`2fooooo`;o0000Q?ooool002Wooooo00?o0000ooooooooool0]_ooool2o`0008Co
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo
00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo?Oooool0
00Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@
413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03
ooooo`?o0000oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Q
ooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool0
00Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@
oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo
1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
01oooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo?Oooool0027o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`00
0?oooooooooo00Gooooo0ol0003oooooocgooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001oooooo00?oEEEEofIVI_l00000
oooooom7ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .39789 Mdot
.02762 .39961 Mdot
.02952 .29165 Mdot
.03143 .26998 Mdot
.03333 .3055 Mdot
.03524 .34646 Mdot
.03714 .29401 Mdot
.03905 .44856 Mdot
.04095 .42621 Mdot
.04286 .34817 Mdot
.04476 .32696 Mdot
.04667 .45051 Mdot
.04857 .36278 Mdot
.05048 .34562 Mdot
.05238 .44139 Mdot
.05429 .31886 Mdot
.05619 .27031 Mdot
.0581 .35993 Mdot
.06 .25302 Mdot
.0619 .23136 Mdot
.06381 .33713 Mdot
.06571 .38004 Mdot
.06762 .3579 Mdot
.06952 .34723 Mdot
.07143 .43311 Mdot
.07333 .37057 Mdot
.07524 .29455 Mdot
.07714 .25261 Mdot
.07905 .23786 Mdot
.08095 .39332 Mdot
.08286 .29971 Mdot
.08476 .42284 Mdot
.08667 .44413 Mdot
.08857 .24441 Mdot
.09048 .25421 Mdot
.09238 .23343 Mdot
.09429 .35018 Mdot
.09619 .26052 Mdot
.0981 .27201 Mdot
.1 .45293 Mdot
.1019 .44266 Mdot
.10381 .24626 Mdot
.10571 .30687 Mdot
.10762 .4001 Mdot
.10952 .39038 Mdot
.11143 .34519 Mdot
.11333 .33855 Mdot
.11524 .40015 Mdot
.11714 .36169 Mdot
.11905 .24737 Mdot
.12095 .40109 Mdot
.12286 .2853 Mdot
.12476 .25747 Mdot
.12667 .28823 Mdot
.12857 .27706 Mdot
.13048 .43633 Mdot
.13238 .44952 Mdot
.13429 .28025 Mdot
.13619 .37853 Mdot
.1381 .38652 Mdot
.14 .35368 Mdot
.1419 .38428 Mdot
.14381 .28495 Mdot
.14571 .32 Mdot
.14762 .44289 Mdot
.14952 .42928 Mdot
.15143 .34749 Mdot
.15333 .31868 Mdot
.15524 .26573 Mdot
.15714 .32863 Mdot
.15905 .28476 Mdot
.16095 .32235 Mdot
.16286 .34505 Mdot
.16476 .34643 Mdot
.16667 .28503 Mdot
.16857 .31419 Mdot
.17048 .25798 Mdot
.17238 .36576 Mdot
.17429 .26989 Mdot
.17619 .34922 Mdot
.1781 .25449 Mdot
.18 .39215 Mdot
.1819 .26527 Mdot
.18381 .24626 Mdot
.18571 .44205 Mdot
.18762 .31325 Mdot
.18952 .31008 Mdot
.19143 .33845 Mdot
.19333 .30326 Mdot
.19524 .32232 Mdot
.19714 .42933 Mdot
.19905 .23085 Mdot
.20095 .29498 Mdot
.20286 .33699 Mdot
.20476 .30086 Mdot
.20667 .2499 Mdot
.20857 .34626 Mdot
.21048 .40977 Mdot
.21238 .26426 Mdot
.21429 .31179 Mdot
.21619 .39967 Mdot
.2181 .32792 Mdot
.22 .44816 Mdot
.2219 .40217 Mdot
.22381 .28912 Mdot
.22571 .24568 Mdot
.22762 .26561 Mdot
.22952 .25126 Mdot
.23143 .29457 Mdot
.23333 .32042 Mdot
.23524 .34856 Mdot
.23714 .26272 Mdot
.23905 .42239 Mdot
.24095 .23349 Mdot
.24286 .37302 Mdot
.24476 .26446 Mdot
.24667 .36114 Mdot
.24857 .43027 Mdot
.25048 .42602 Mdot
.25238 .35863 Mdot
.25429 .35948 Mdot
.25619 .40674 Mdot
.2581 .33227 Mdot
.26 .237 Mdot
.2619 .32362 Mdot
.26381 .283 Mdot
.26571 .23241 Mdot
.26762 .27262 Mdot
.26952 .39442 Mdot
.27143 .29932 Mdot
.27333 .36802 Mdot
.27524 .39944 Mdot
.27714 .44846 Mdot
.27905 .34445 Mdot
.28095 .32265 Mdot
.28286 .25011 Mdot
.28476 .32209 Mdot
.28667 .23568 Mdot
.28857 .34494 Mdot
.29048 .44652 Mdot
.29238 .44295 Mdot
.29429 .33082 Mdot
.29619 .26376 Mdot
.2981 .26059 Mdot
.3 .27166 Mdot
.3019 .23209 Mdot
.30381 .43791 Mdot
.30571 .40984 Mdot
.30762 .26663 Mdot
.30952 .34303 Mdot
.31143 .42711 Mdot
.31333 .33646 Mdot
.31524 .2929 Mdot
.31714 .34927 Mdot
.31905 .32017 Mdot
.32095 .37493 Mdot
.32286 .31856 Mdot
.32476 .28387 Mdot
.32667 .43214 Mdot
.32857 .35503 Mdot
.33048 .31922 Mdot
.33238 .37184 Mdot
.33429 .26376 Mdot
.33619 .45346 Mdot
.3381 .23456 Mdot
.34 .31888 Mdot
.3419 .3981 Mdot
.34381 .43694 Mdot
.34571 .28109 Mdot
.34762 .26849 Mdot
.34952 .3041 Mdot
.35143 .24404 Mdot
.35333 .26978 Mdot
.35524 .27334 Mdot
.35714 .32049 Mdot
.35905 .26833 Mdot
.36095 .44452 Mdot
.36286 .25539 Mdot
.36476 .37373 Mdot
.36667 .26668 Mdot
.36857 .24835 Mdot
.37048 .28529 Mdot
.37238 .4516 Mdot
.37429 .33796 Mdot
.37619 .44147 Mdot
.3781 .32309 Mdot
.38 .42585 Mdot
.3819 .26855 Mdot
.38381 .41694 Mdot
.38571 .45304 Mdot
.38762 .31118 Mdot
.38952 .41682 Mdot
.39143 .23234 Mdot
.39333 .32726 Mdot
.39524 .38395 Mdot
.39714 .44546 Mdot
.39905 .44113 Mdot
.40095 .44866 Mdot
.40286 .33315 Mdot
.40476 .22343 Mdot
.40667 .25288 Mdot
.40857 .26759 Mdot
.41048 .26661 Mdot
.41238 .32319 Mdot
.41429 .31059 Mdot
.41619 .21978 Mdot
.4181 .39869 Mdot
.42 .33259 Mdot
.4219 .35761 Mdot
.42381 .25862 Mdot
.42571 .32816 Mdot
.42762 .32829 Mdot
.42952 .3784 Mdot
.43143 .36475 Mdot
.43333 .279 Mdot
.43524 .336 Mdot
.43714 .39802 Mdot
.43905 .36275 Mdot
.44095 .45204 Mdot
.44286 .31994 Mdot
.44476 .38649 Mdot
.44667 .45303 Mdot
.44857 .35926 Mdot
.45048 .39102 Mdot
.45238 .29225 Mdot
.45429 .24241 Mdot
.45619 .3329 Mdot
.4581 .28418 Mdot
.46 .40425 Mdot
.4619 .27747 Mdot
.46381 .44159 Mdot
.46571 .4082 Mdot
.46762 .30039 Mdot
.46952 .27231 Mdot
.47143 .22059 Mdot
.47333 .33689 Mdot
.47524 .30591 Mdot
.47714 .40859 Mdot
.47905 .26755 Mdot
.48095 .40313 Mdot
.48286 .34726 Mdot
.48476 .39989 Mdot
.48667 .38044 Mdot
.48857 .32597 Mdot
.49048 .26614 Mdot
.49238 .28513 Mdot
.49429 .42099 Mdot
.49619 .30046 Mdot
.4981 .32722 Mdot
.5 .29362 Mdot
.5019 .28811 Mdot
.50381 .28128 Mdot
.50571 .44045 Mdot
.50762 .26453 Mdot
.50952 .32298 Mdot
.51143 .34157 Mdot
.51333 .37023 Mdot
.51524 .27521 Mdot
.51714 .27643 Mdot
.51905 .31335 Mdot
.52095 .44812 Mdot
.52286 .3901 Mdot
.52476 .35186 Mdot
.52667 .3068 Mdot
.52857 .23929 Mdot
.53048 .28057 Mdot
.53238 .33256 Mdot
.53429 .39541 Mdot
.53619 .33164 Mdot
.5381 .34709 Mdot
.54 .23727 Mdot
.5419 .36734 Mdot
.54381 .23261 Mdot
.54571 .28043 Mdot
.54762 .34934 Mdot
.54952 .35084 Mdot
.55143 .31201 Mdot
.55333 .33889 Mdot
.55524 .25925 Mdot
.55714 .40672 Mdot
.55905 .33535 Mdot
.56095 .36845 Mdot
.56286 .25334 Mdot
.56476 .29105 Mdot
.56667 .34425 Mdot
.56857 .35758 Mdot
.57048 .449 Mdot
.57238 .25123 Mdot
.57429 .31256 Mdot
.57619 .30211 Mdot
.5781 .24324 Mdot
.58 .34576 Mdot
.5819 .26074 Mdot
.58381 .2655 Mdot
.58571 .3795 Mdot
.58762 .44467 Mdot
.58952 .38703 Mdot
.59143 .27271 Mdot
.59333 .36173 Mdot
.59524 .38406 Mdot
.59714 .25604 Mdot
.59905 .44238 Mdot
.60095 .42593 Mdot
.60286 .35889 Mdot
.60476 .29764 Mdot
.60667 .40038 Mdot
.60857 .42207 Mdot
.61048 .43961 Mdot
.61238 .33739 Mdot
.61429 .4078 Mdot
.61619 .37064 Mdot
.6181 .27903 Mdot
.62 .37432 Mdot
.6219 .26589 Mdot
.62381 .35869 Mdot
.62571 .42944 Mdot
.62762 .26715 Mdot
.62952 .39036 Mdot
.63143 .24565 Mdot
.63333 .44384 Mdot
.63524 .27783 Mdot
.63714 .45033 Mdot
.63905 .40828 Mdot
.64095 .33023 Mdot
.64286 .29698 Mdot
.64476 .34176 Mdot
.64667 .24523 Mdot
.64857 .29944 Mdot
.65048 .27882 Mdot
.65238 .2769 Mdot
.65429 .28168 Mdot
.65619 .26999 Mdot
.6581 .45188 Mdot
.66 .34418 Mdot
.6619 .30557 Mdot
.66381 .38051 Mdot
.66571 .30039 Mdot
.66762 .32316 Mdot
.66952 .40361 Mdot
.67143 .33929 Mdot
.67333 .31906 Mdot
.67524 .37147 Mdot
.67714 .30709 Mdot
.67905 .23742 Mdot
.68095 .3689 Mdot
.68286 .39144 Mdot
.68476 .31533 Mdot
.68667 .44104 Mdot
.68857 .29873 Mdot
.69048 .23493 Mdot
.69238 .38136 Mdot
.69429 .27869 Mdot
.69619 .3574 Mdot
.6981 .33508 Mdot
.7 .45134 Mdot
.7019 .35465 Mdot
.70381 .23357 Mdot
.70571 .36506 Mdot
.70762 .2502 Mdot
.70952 .2393 Mdot
.71143 .33547 Mdot
.71333 .45104 Mdot
.71524 .33717 Mdot
.71714 .26284 Mdot
.71905 .44793 Mdot
.72095 .44967 Mdot
.72286 .44711 Mdot
.72476 .32141 Mdot
.72667 .34374 Mdot
.72857 .44169 Mdot
.73048 .44867 Mdot
.73238 .32028 Mdot
.73429 .27785 Mdot
.73619 .36582 Mdot
.7381 .35498 Mdot
.74 .39925 Mdot
.7419 .41453 Mdot
.74381 .40284 Mdot
.74571 .35849 Mdot
.74762 .32899 Mdot
.74952 .35986 Mdot
.75143 .34288 Mdot
.75333 .36786 Mdot
.75524 .43752 Mdot
.75714 .38513 Mdot
.75905 .36998 Mdot
.76095 .37523 Mdot
.76286 .31978 Mdot
.76476 .42159 Mdot
.76667 .31327 Mdot
.76857 .27925 Mdot
.77048 .45268 Mdot
.77238 .3261 Mdot
.77429 .28119 Mdot
.77619 .34748 Mdot
.7781 .36761 Mdot
.78 .29778 Mdot
.7819 .40294 Mdot
.78381 .30105 Mdot
.78571 .38185 Mdot
.78762 .45145 Mdot
.78952 .24997 Mdot
.79143 .23722 Mdot
.79333 .249 Mdot
.79524 .26396 Mdot
.79714 .26715 Mdot
.79905 .29107 Mdot
.80095 .45091 Mdot
.80286 .45028 Mdot
.80476 .29727 Mdot
.80667 .2732 Mdot
.80857 .32244 Mdot
.81048 .32509 Mdot
.81238 .43313 Mdot
.81429 .32932 Mdot
.81619 .23651 Mdot
.8181 .25928 Mdot
.82 .28741 Mdot
.8219 .28513 Mdot
.82381 .32167 Mdot
.82571 .24429 Mdot
.82762 .30463 Mdot
.82952 .33219 Mdot
.83143 .41698 Mdot
.83333 .44645 Mdot
.83524 .27641 Mdot
.83714 .25826 Mdot
.83905 .265 Mdot
.84095 .38466 Mdot
.84286 .36415 Mdot
.84476 .27339 Mdot
.84667 .42482 Mdot
.84857 .24507 Mdot
.85048 .40228 Mdot
.85238 .34417 Mdot
.85429 .4016 Mdot
.85619 .33242 Mdot
.8581 .43161 Mdot
.86 .44012 Mdot
.8619 .31893 Mdot
.86381 .37785 Mdot
.86571 .24274 Mdot
.86762 .26838 Mdot
.86952 .29016 Mdot
.87143 .27872 Mdot
.87333 .24271 Mdot
.87524 .3572 Mdot
.87714 .22633 Mdot
.87905 .3265 Mdot
.88095 .27564 Mdot
.88286 .24348 Mdot
.88476 .31407 Mdot
.88667 .26885 Mdot
.88857 .34372 Mdot
.89048 .44872 Mdot
.89238 .26871 Mdot
.89429 .25903 Mdot
.89619 .40195 Mdot
.8981 .39131 Mdot
.9 .23237 Mdot
.9019 .26915 Mdot
.90381 .25836 Mdot
.90571 .28712 Mdot
.90762 .34786 Mdot
.90952 .45227 Mdot
.91143 .44257 Mdot
.91333 .3287 Mdot
.91524 .35887 Mdot
.91714 .36561 Mdot
.91905 .27143 Mdot
.92095 .23382 Mdot
.92286 .40004 Mdot
.92476 .25158 Mdot
.92667 .35748 Mdot
.92857 .24395 Mdot
.93048 .397 Mdot
.93238 .3288 Mdot
.93429 .31467 Mdot
.93619 .3066 Mdot
.9381 .3508 Mdot
.94 .32329 Mdot
.9419 .30852 Mdot
.94381 .28266 Mdot
.94571 .31231 Mdot
.94762 .26542 Mdot
.94952 .36922 Mdot
.95143 .43003 Mdot
.95333 .29714 Mdot
.95524 .39344 Mdot
.95714 .27174 Mdot
.95905 .2528 Mdot
.96095 .3137 Mdot
.96286 .36082 Mdot
.96476 .30897 Mdot
.96667 .40179 Mdot
.96857 .39802 Mdot
.97048 .23448 Mdot
.97238 .26191 Mdot
.97429 .23981 Mdot
.97619 .45138 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo07[ooooo0_l0000@ooooo`;o0000[_ooool000Kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo07Oooooo0_l000000ooooooo0000o`00000@ooooo`;o0000[_ooool0
00Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1gooooo`;o0000U_oo
ool2o`0002_ooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0eooooo`;o0000f?oo
ool2o`0002_ooooo0006ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^
kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00009ooooo`;o00001oooool2o`00027ooooo0_l0
000;ooooo`;o00001_ooool2o`0000[ooooo0_l0000Jooooo`;o0000;oooool2o`0003;ooooo0_l0
000mooooo`;o00001Oooool2o`0001gooooo0006ooooo`05o`000?ooooooooooooooool000003_oo
ool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`09ooooo`;o00001oooool2o`0002kooooo0_l00004ooooo`Co00001Oooool2o`0000?ooooo
0_l00009ooooo`;o00003oooool2o`0002kooooo0ol0000^ooooo`;o00000_ooool2o`0001[ooooo
0_l00006ooooo`;o00006Oooool2o`0000Gooooo0_l0000>ooooo`;o00003Oooool000Kooooo00Go
410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0>ooooo`;o0000>?ooool2o`0000Oooooo0_l0000>ooooo`;o0000
??ooool2o`000003ooooool0003o000002_ooooo0_l00002ooooo`;o00001?ooool2o`0001Sooooo
0_l00006ooooo`;o0000<?ooool3o`0000cooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0>ooooo`;o0000Moooool2o`0001Kooooo0_l0000=ooooo`;o00007oooool2o`0000So
oooo0_l0000`ooooo`Co000000?oooooo`000?l000007?ooool2o`0000cooooo0006ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006oooo
o`03o`000?oooooooooo017ooooo0_l00003ooooo`;o00006?ooool2o`0000_ooooo0_l0000Woooo
o`;o00007oooool2o`0002Gooooo0_l0000@ooooo`;o00000oooool2o`0003Oooooo0_l00005oooo
o`;o00001?ooool4o`000003ooooool0003o000000gooooo0_l0000Kooooo`00:Oooool2o`0001;o
oooo0_l00003ooooo`;o00000oooool2o`0001?ooooo0_l0000;ooooo`;o00009oooool2o`0000?o
oooo0_l0001Cooooo`;o00000oooool2o`0002gooooo0_l00008ooooo`;o00001Oooool2o`0001So
oooo0_l0000Kooooo`00:Oooool00ol0003oooooooooo`0=ooooo`;o00003?ooool2o`0001[ooooo
0_l00005ooooo`;o00004?ooool2o`0001Wooooo0_l00010ooooo`;o0000:Oooool2o`0001Sooooo
1?l0000Xooooo`;o00002Oooool2o`00017ooooo000Yooooo`03o`000?oooooooooo00Sooooo0_l0
0003ooooo`;o00000oooool2o`0001[ooooo0_l00007ooooo`;o00001Oooool2o`00013ooooo0_l0
000Gooooo`;o00003?ooool2o`00037ooooo0_l000000ooooooo0000o`00000Yooooo`;o00006?oo
ool2o`0002[ooooo0_l00009ooooo`;o00004Oooool002Wooooo00?o0000ooooooooool02?ooool2
o`0000Sooooo0_l00009ooooo`;o00003?ooool2o`000003ooooool0003o000003Wooooo0_l0000<
ooooo`;o00001?ooool2o`0002_ooooo0_l00009ooooo`;o0000Boooool2o`00013ooooo0_l00000
0ooooooo0000o`00000Sooooo`00:Oooool00ol0003oooooooooo`0Dooooo`;o00001oooool2o`00
00cooooo0_l0000Wooooo`;o00009oooool2o`0002Sooooo0_l00007ooooo`;o00000oooool2o`00
04Gooooo0_l00004ooooo`;o00004?ooool2o`000003ooooool0003o000001Cooooo0_l0000=oooo
o`00:Oooool2o`0001Gooooo0_l0000Iooooo`;o00002?ooool2o`0000Kooooo1?l0000?ooooo`;o
00002_ooool2o`0003Kooooo0_l0000=ooooo`;o00001oooool2o`0002Wooooo0_l0000Gooooo`;o
00001_ooool2o`0000Cooooo0_l0000Yooooo`;o00003Oooool002Wooooo00?o0000ooooooooool0
9oooool2o`0000Kooooo0_l00008ooooo`;o00000oooool2o`000003ooooool0003o000000;o0000
3oooool2o`0000;ooooo0_l00006ooooo`;o00001_ooool2o`000003ooooool0003o000000_ooooo
0ol0000Dooooo`;o000000?oooooo`000?l000001?ooool2o`0001Kooooo0_l0000;ooooo`?o0000
6oooool2o`0001Oooooo0ol0000;ooooo`;o00002?ooool2o`0001Oooooo0_l0000Eooooo`00:Ooo
ool01?l0003oooooo`000?l00006ooooo`;o00007_ooool2o`0000Cooooo0_l000000ooooooo0000
o`000002o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h2ooooo`;o000000Co<S8b
o`000?lb<S;ok^k^5?ooool2o`0000[ooooo1_l000000ooooooo0000o`000005o`0000?ooooo00?o
k^k^oc8b<_l000000ol00002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool2o`000003oooo
ool0003o000001Kooooo00KoV9RHoa0@4?l0003o<S8bolc<c?ooool2o`000005onk^k_lb<S;o0000
oc8b<_o^k^h00oooool00oo^k^ko<S8bo`000003o`0000Sooooo0_l0000Oooooo`;o000000[o410@
ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^kooooo0_l000001Oo^k^ko<S8bo`000?lb<S;o
k^k^013ooooo0_l00004ooooo`Co000000?oooooo`000?l000000oooool2o`0000Oooooo0ol00000
2Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool002Wooooo00Co0000ooooool0003o00001_ooool2o`0000_ooooo0_l0000Goooo
o`;o00000oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo0_l00008ooooo`;o00003Oooool5o`0000Cooooo00Go
V9RHob4Q8Ol0003o0000odA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00[ooooo0_l0000Looooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool0
1OmgMgOo0000o`000?nHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`09ooooo`;o0000
8?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOo
0000o`000?nHV9SoMgMg00Sooooo0_l0000<ooooo`Co000000?oooooo`000?l000000oooool2o`00
00[ooooo0_l00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo000Yooooo`03o`000?oooooooooo01Cooooo0_l00008ooooo`;o00004_ooool0
0ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooo
oooooooo410@00Oooooo0_l00008ooooo`;o00004?ooool2o`0000Gooooo00?oV9RHob4Q8Oo^k^h0
1?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4007oooo
o`;o000000?oooooo`000?l000003?ooool3o`00017ooooo00Go0000oooooooooooooooooa0@4002
o`000003ooooool@413ooooo00;ooooo00Go410@oooooooooooooooooa0@4007ooooo`;o00007ooo
ool5o`0000?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?l0003o0000ooooool@
41001Oooool2o`000003ooooool0003o000000[ooooo0_l0000Fooooo`;o00000_ooool01Ol@413o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`00:Oooool2o`00
01oooooo1?l0000@ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool00000:oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`02o`0000Oooooo0_l0000?ooooo`?o0000
0_ooool2o`0000?ooooo0_l00007ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`?o000000Coooooo`000?oooooooooo0_l00003ooooo`;o00003?ooool2o`00
00_ooooo0_l00004ooooo`05odA4A?oMgMgoooooo`000?ooool00_l000000ooooooo0000ooooo`02
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`03ooooo`;o00002_oo
ool2o`000003ooooool0003o000001Kooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`01ooooo`00:Oooool00ol0003ooooo
ooooo`0Pooooo`;o00004?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000Gooooo0_l0000Booooo`;o00001Oooool2o`00
00[ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool00_l0000Eooooo`;o00001_ooool2o`0000?ooooo0_l00006ooooo`03oa0@4?l0003o
^[Zj00?ooooo00Go0000ooooooooooooooooo`000003ooooo`?o000000Coooooo`000?oooooooooo
0_l00003ooooo`?o00002oooool2o`0000_ooooo0_l00004ooooo`05omgMgOmEEEGoooooo`000?oo
ool01?l00003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0?oooo
o`;o00005Oooool2o`000004ob4Q8Ol0003o<S8bolc<c0;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool002Wooooo00?o0000ooooooooool07?oo
ool2o`0000Gooooo0_l00003ooooo`Co00001_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo0_l0000Booooo`;o
00001Oooool2o`0000Kooooo0_l00003ooooo`05o`000?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01?ooool2o`0000Wooooo0_l00002
ooooo`;o00005?ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@00Sooooo0_l0000Oooooo`03ogMgMoo<c<co000000?ooooo
0_l00003ooooo`05oa0@4?ooooooooooooooool@41000oooool01?l@413oooooo`000?l0000Uoooo
o`;o00001_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
4003ooooo`00:Oooool00ol0003oooooooooo`0Looooo`?o00001?ooool2o`0000?ooooo1?l00006
ooooo`03o`000?oooooooooo00;ooooo00KoMgMgoiRHV?ooooooV9RHogMgMoooool2o`000005ogMg
MonHV9SooooooiRHV?mgMgL0:?ooool2o`000004okZj^_ooooooV9RHoa0@40?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool2o`0000Wooooo0_l0
00000ooooooo0000o`00000Booooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Yooooo`03onk^k_m4A4Co0000
00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ol0
000=ooooo`;o00002_ooool2o`0000_ooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool3o`0001gooooo
0_l0000Aooooo`03oeEEEOmVIVKo000000Cooooo00Kok^k^oc8b<_l0003o<S8bonk^k_ooool2o`00
0005onk^k_lb<S;o0000oc8b<_o^k^h05_ooool2o`00017ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Co
oooo0_l0000>ooooo`;o00004_ooool3o`000003oa0@4?nYZJWooooo00;ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:_ooool00omgMgOo0000ooooo`03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool2o`000004oc8b<_l0003o<S8bonk^kP;o0000
3_ooool2o`0000[ooooo0_l0000;ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool3o`000003ooooool0003o000000[o
oooo0_l0000Vooooo`;o00002?ooool2o`0001Wooooo0_l0000Zooooo`;o00003Oooool2o`0001?o
oooo0_l0001:ooooo`;o0000A?ooool002Wooooo00Co0000oooooooooooooooo0_l0000:ooooo`;o
00009_ooool2o`0000Sooooo0_l0000;ooooo`;o0000Aoooool2o`00023ooooo0_l0000:ooooo`Co
00002oooool2o`0001_ooooo0_l00006ooooo`;o0000;_ooool2o`0001?ooooo000Yooooo`03o`00
0?oooooooooo00oooooo0_l0000Uooooo`;o00005?ooool2o`0003gooooo0_l00007ooooo`;o0000
6?ooool2o`0000Oooooo0_l0000:ooooo`Co00001?ooool2o`0000Gooooo0_l0000Kooooo`Co0000
1?ooool2o`0002kooooo0_l0000Cooooo`00:Oooool01?l0003oooooo`000?l0000>ooooo`;o0000
8_ooool2o`000003ooooool0003o000002gooooo0_l0000Tooooo`;o00001oooool2o`0001Sooooo
0_l0000Iooooo`Co00009?ooool2o`0000cooooo0_l0000kooooo`00:Oooool01?l0003oooooo`00
0?l0000Fooooo`;o00006_ooool2o`00033ooooo0_l0000Vooooo`;o00003oooool2o`0002Wooooo
0_l00003ooooo`;o0000;oooool2o`00027ooooo0ol0000Gooooo`008Oooooooo`0004Co00001?oo
ool002Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool01_ooool2o`000004ooooool0003oooooooooo`?o00001_oo
ool2o`0000_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool00oooool2o`0000Gooooo00Co0000ooooool0003o0000
2?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo0_l00008ooooo`;o0000
00?oooooo`000?ooool00_ooool2o`0000Kooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`02ooooo`;o00001Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool00oooool2o`0000Cooooo00?o0000ooooooooool01oooool3o`000003oooo
ool0003o000000?ooooo0ol00002ooooo`03o`000?oooooooooo00[ooooo000Yooooo`03o`000?oo
oooooooo02_ooooo0_l00004ooooo`;o00001oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo027ooooo0_l00008ooooo`;o00001Oooool2o`0000Kooooo00?o0000ooooooooool06Ooo
ool2o`0001Sooooo0_l00005ooooo`03o`000?oooooooooo01cooooo0_l0000>ooooo`;o00000_oo
ool2o`0000?ooooo0_l00003ooooo`03o`000?oooooooooo00[ooooo000Yooooo`03o`000?oooooo
oooo00Kooooo0_l0000Kooooo`;o000000?oooooo`000?l000006?ooool2o`0001Wooooo0ol00000
1?oooooo0000o`000?ooool2o`0000?ooooo0_l0000Jooooo`;o0000B?ooool2o`0000;ooooo0_l0
000=ooooo`;o00002?ooool2o`0001kooooo0_l0000`ooooo`00:Oooool00ol0003oooooooooo`06
ooooo`;o00006oooool2o`000003ooooool0003o000000;o00002Oooool2o`0000_ooooo0_l00007
ooooo`;o00001?ooool3o`0000Wooooo0ol000001?oooooo0000o`000?ooool2o`0000?ooooo0_l0
0005ooooo`;o00002Oooool2o`0000Sooooo0_l0000Cooooo`;o0000<Oooool4o`0000oooooo1?l0
0008ooooo`;o00003Oooool2o`0000?ooooo0_l0000:ooooo`;o00005oooool2o`0001Oooooo000Y
ooooo`;o00001?ooool2o`0002?ooooo0_l00009ooooo`;o00005?ooool2o`0000Cooooo0ol0000L
ooooo`;o00000oooool2o`0000Cooooo0_l0000Gooooo`;o000000Coooooo`000?l0003ooooo0_l0
000aooooo`;o00004Oooool2o`0000gooooo0_l0000:ooooo`;o00000oooool2o`0000oooooo0_l0
000Booooo`;o00005oooool002Wooooo00?o0000ooooooooool00oooool2o`0002;ooooo0_l0000B
ooooo`;o0000=_ooool2o`0000Sooooo0ol0000Booooo`;o000000?oooooo`000?l00000;?ooool2
o`00023ooooo0_l00006ooooo`;o00002_ooool3o`0001?ooooo0_l00009ooooo`;o00001?ooool2
o`0001[ooooo000Yooooo`03o`000?oooooooooo02Oooooo0_l0000Booooo`;o00002oooool2o`00
00Wooooo0_l0000Qooooo`;o00001?ooool4o`0000Oooooo0_l0000Gooooo`?o00008?ooool2o`00
023ooooo0_l0000Cooooo`;o00000oooool2o`0000Oooooo0_l0000@ooooo`;o00001?ooool2o`00
01[ooooo000Yooooo`03o`000?oooooooooo04Sooooo0_l00009ooooo`;o00001?ooool2o`0001_o
oooo0_l00004ooooo`;o00000oooool2o`0000Cooooo0_l0000Gooooo`?o00001Oooool2o`0002_o
oooo0_l00002ooooo`;o00009?ooool2o`0000Oooooo0_l0000booooo`00:Oooool00ol0003ooooo
ooooo`09ooooo`;o00003_ooool2o`0001Oooooo0_l00002ooooo`;o00008Oooool2o`0001;ooooo
0_l0000Booooo`;o00002_ooool2o`0001Sooooo0ol0000@ooooo`;o00004Oooool2o`0000Kooooo
0_l00002ooooo`Co0000Goooool002Wooooo0_l0000:ooooo`;o00003_ooool2o`0001Oooooo0_l0
0002ooooo`;o00008?ooool2o`0001?ooooo0_l0000Nooooo`;o00002_ooool2o`0000cooooo0_l0
000Aooooo`;o00002?ooool2o`0000Oooooo0_l0000<ooooo`;o00002Oooool2o`0005Cooooo000Y
ooooo`03o`000?oooooooooo00Gooooo0_l0000Aooooo`;o00003oooool2o`0002?ooooo0_l00000
0ooooooo0000o`000005ooooo`;o0000?oooool2o`00013ooooo0_l00002ooooo`;o00004oooool2
o`0000?ooooo0_l0000Cooooo`;o00001_ooool2o`0001oooooo0_l00009ooooo`;o0000:?ooool0
02Wooooo00?o0000ooooooooool01?l000000ooooooo0000o`000004ooooo`;o00002oooool2o`00
00_ooooo0_l00002ooooo`?o000000?oooooo`000?l000002Oooool2o`0000Kooooo0_l0000<oooo
o`;o000000?oooooo`000?l00000?Oooool2o`00013ooooo0_l00007ooooo`;o00000_ooool2o`00
01Sooooo0_l0000Cooooo`;o00003_ooool2o`0001Oooooo0_l00009ooooo`;o00001?ooool2o`00
02;ooooo000Yooooo`03o`000?oooooooooo00Co00001oooool2o`0000Kooooo0_l0000@ooooo`;o
00000oooool2o`000003ooooool0003o000000Wooooo0_l00006ooooo`;o00006Oooool2o`0003?o
oooo0_l0000;ooooo`;o00000oooool2o`000003ooooool0003o000004Oooooo0_l0000Xooooo`;o
00002?ooool2o`0001Sooooo000Yooooo`03o`000?oooooooooo01?ooooo0_l0000=ooooo`;o0000
=oooool2o`000003ooooool0003o000003gooooo0_l00006ooooo`;o0000;oooool2o`0000[ooooo
0_l0000nooooo`;o00006?ooool002Wooooo0_l0000;ooooo`;o00005_ooool2o`0003[ooooo0_l0
000Looooo`;o0000;Oooool2o`0002Oooooo1?l0000:ooooo`Co0000:?ooool2o`0000oooooo0_l0
000Kooooo`00:Oooool00ol0003oooooooooo`07ooooo`;o000000?oooooo`000?l000003_ooool2
o`0002Sooooo1?l0000dooooo`;o00001oooool2o`0002Cooooo0_l00009ooooo`;o00001Oooool2
o`0001Gooooo0_l0000>ooooo`Co00009_ooool2o`0000_ooooo0_l00002ooooo`;o00002Oooool2
o`00013ooooo000Yooooo`03o`000?oooooooooo00Cooooo0_l000000ooooooo0000o`00000Aoooo
o`;o0000:?ooool4o`0003Oooooo0_l000001?oooooo0000o`000?ooool2o`0002cooooo0_l00000
0ooooooo0000o`000005ooooo`;o00009oooool2o`0001cooooo0_l0000Eooooo`;o00003Oooool2
o`00013ooooo000Yooooo`03o`000?oooooooooo00Cooooo0_l0000Vooooo`;o0000DOooool2o`00
0003ooooool0003o000001oooooo0_l0000>ooooo`;o00008oooool2o`0000Oooooo0_l00004oooo
o`;o00001_ooool2o`0001?ooooo0_l0000Fooooo`;o00007_ooool002Wooooo00?o0000oooooooo
ool03?ooool2o`0001kooooo0_l0000Oooooo`;o0000Boooool2o`0000Oooooo0_l00004ooooo`;o
00004?ooool2o`0001?ooooo0_l00006ooooo`;o00001oooool2o`0000Cooooo1?l00004ooooo`;o
0000:oooool2o`0000Sooooo0_l0000Dooooo`00:Oooool2o`0000gooooo0_l0000eooooo`;o0000
2?ooool2o`00013ooooo0_l00009ooooo`;o0000;_ooool2o`0000gooooo0_l0000@ooooo`;o0000
4Oooool4o`0001Oooooo0_l0000kooooo`;o00005?ooool002Wooooo00?o0000ooooooooool0@ooo
ool2o`0001Oooooo0_l000000ooooooo0000o`000009ooooo`;o0000D?ooool2o`00013ooooo0_l0
000Iooooo`;o0000DOooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00[ooooo
0_l0000Dooooo`;o0000>_ooool2o`00027ooooo0_l0000`ooooo`;o00002Oooool2o`0002_ooooo
0_l0000Oooooo`;o0000<?ooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`0:ooooo`;o00005?ooool2o`0005gooooo0_l0000@ooooo`;o00007_ooool2o`0001Oo
oooo0_l00007ooooo`;o00007?ooool2o`0001Oooooo0_l0000`ooooo`001_ooool01Ol@413ooooo
oooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo027ooooo0ol0001@ooooo`;o00003_ooool2o`0000_ooooo0_l0000Qooooo`;o
00005?ooool2o`0000Oooooo0_l0000Cooooo`;o00001oooool2o`00013ooooo0_l0000gooooo`00
1_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo
<S8booooo`04ooooo`?o00008Oooool3o`00053ooooo0_l0000>ooooo`;o0000;?ooool4o`0003;o
oooo0_l0000Iooooo`;o0000=oooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo
01Sooooo0_l0000Dooooo`;o0000EOooool2o`0001Kooooo0_l0000Cooooo`;o00002oooool2o`00
00oooooo0_l00013ooooo`;o00009Oooool000Kooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?oooo
o`;o00001oooool2o`0001Cooooo0_l0000Kooooo`;o0000>?ooool2o`0001Kooooo0_l000000ooo
oooo0000o`00000Mooooo`;o00003oooool2o`0004?ooooo0_l0000Aooooo`;o00004_ooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool0
0ol0003oooooooooo`07ooooo`;o00004?ooool2o`0003[ooooo0_l0000Fooooo`;o00005_ooool2
o`0000Cooooo0_l0000Mooooo`;o0000O_ooool2o`0000Kooooo0_l00002ooooo`;o00003_ooool0
00Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?oo
ool4o`0000Kooooo0_l0000Hooooo`;o000000?oooooo`000?l000000_l0000Looooo`;o00004Ooo
ool2o`0001Cooooo0_l0000Fooooo`;o00001?ooool2o`0000gooooo0_l0000Vooooo`;o0000:Ooo
ool2o`0002;ooooo0_l0000<ooooo`;o00001_ooool2o`000003ooooool0003o000000Wooooo0ol0
000>ooooo`00:Oooool2o`0001Sooooo0_l000000ooooooo0000o`000002o`0001cooooo1?l0000?
ooooo`;o0000>_ooool2o`0000Cooooo0ol0000Vooooo`;o00004_ooool2o`0001Gooooo0ol0000:
ooooo`;o00005?ooool3o`0000cooooo0_l00006ooooo`;o00003?ooool2o`0000oooooo000Yoooo
o`03o`000?oooooooooo03cooooo0_l00009ooooo`;o0000@?ooool3o`0000?ooooo0_l0000Goooo
o`;o00004?ooool2o`0000Kooooo0_l00008ooooo`;o00005_ooool2o`0000[ooooo0_l0000Doooo
o`;o0000=?ooool002Wooooo00?o0000ooooooooool0>?ooool2o`0000gooooo0_l0000>ooooo`;o
0000<Oooool2o`0000;ooooo0_l0000Hooooo`;o00004?ooool2o`0000Kooooo0_l0001hooooo`00
:Oooool00ol0003oooooooooo`0hooooo`;o00007Oooool2o`0003Gooooo0_l0001Cooooo`;o0000
Eoooool002Wooooo00?o0000ooooooooool0L?ooool4o`0006oooooo0_l0000Kooooo`;o0000>_oo
ool002Wooooo0_l0001aooooo`Co0000S?ooool2o`0003[ooooo000Yooooo`03o`000?oooooooooo
013ooooo0_l0000_ooooo`;o0000DOooool2o`0002;ooooo0_l0000aooooo`;o0000Coooool002Wo
oooo00?o0000ooooooooool00_ooool2o`0000cooooo0_l0000_ooooo`;o00000_ooool2o`0002So
oooo0_l0000Sooooo`;o00008?ooool4o`00037ooooo0_l0000Hooooo`;o0000=Oooool002Wooooo
00?o0000ooooooooool00_ooool2o`00027ooooo0_l0000=ooooo`;o00003oooool2o`0001;ooooo
0_l0000Dooooo`;o0000AOooool2o`0000Kooooo0_l00015ooooo`;o00008?ooool2o`0001?ooooo
000Yooooo`03o`000?oooooooooo00cooooo0_l0000Gooooo`;o00003Oooool2o`0000oooooo0_l0
000Booooo`;o00000oooool2o`0005kooooo0_l0000jooooo`;o00003Oooool2o`0001cooooo0_l0
000Cooooo`00:Oooool2o`0000gooooo0_l0000Aooooo`;o00009?ooool2o`0001Oooooo0_l0002J
ooooo`;o00003Oooool2o`00037ooooo000Yooooo`03o`000?oooooooooo01oooooo0_l0000eoooo
o`;o00002oooool2o`0008;ooooo0_l0001Cooooo`00:Oooool00ol0003oooooooooo`05ooooo`;o
0000:Oooool2o`0002Cooooo0_l0000;ooooo`;o00002Oooool2o`0000Gooooo0_l0000Cooooo`;o
00002oooool2o`0001cooooo0_l00002ooooo`;o00005_ooool2o`0000cooooo0_l00006ooooo`;o
00008?ooool2o`00037ooooo000Yooooo`03o`000?oooooooooo00Gooooo0_l00009ooooo`;o0000
0oooool2o`0000gooooo0_l0000:ooooo`;o00008Oooool2o`0001Cooooo0_l00003ooooo`;o0000
1?ooool3o`0001?ooooo0_l0000;ooooo`;o00006Oooool2o`000003ooooool0003o000000;ooooo
0_l00005ooooo`;o00003oooool2o`0000cooooo0_l0000Xooooo`;o00003oooool2o`00023ooooo
000Yooooo`04o`000?ooooooooooooooo`;o00003Oooool2o`0000?ooooo0_l0000=ooooo`;o0000
5Oooool2o`00017ooooo0_l00002ooooo`?o00005?ooool2o`0000Wooooo1?l0000Tooooo`;o0000
5?ooool2o`0000cooooo0_l0000Jooooo`Go00008?ooool2o`00013ooooo0_l00005ooooo`;o0000
8?ooool002Wooooo0_l00002ooooo`;o000000?oooooo`000?l000006Oooool2o`0001[ooooo0_l0
000Aooooo`;o00000_ooool2o`0001Sooooo0_l00008ooooo`;o00009?ooool2o`0000kooooo0_l0
000Cooooo`;o00001Oooool2o`0000cooooo0_l00002ooooo`Oo00004Oooool2o`0000;ooooo0ol0
0008ooooo`;o00004?ooool2o`0001[ooooo0_l0000;ooooo`00:Oooool00ol0003oooooooooo`04
ooooo`;o00003oooool2o`0000Sooooo0_l00010ooooo`;o00002Oooool2o`0000?ooooo0_l0000?
ooooo`Co00009_ooool2o`0001?ooooo0_l00005ooooo`;o00003?ooool2o`0000;ooooo1?l0000>
ooooo`;o00001?ooool2o`0000;ooooo0ol0000Pooooo`;o00005?ooool2o`0000_ooooo000>oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@05ooooo`03o`000?oooooooooo01Gooooo0_l0001:ooooo`;o00003_ooool2o`0000oooooo1?l0
001Vooooo`;o0000:oooool2o`00027ooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo000>
ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`?o0000oooo
oolmooooo`003_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05o`000?ooooooooooooooool000003?oo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolmooooo`003_oo
ool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3oooooocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo
?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo
?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000
onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooo
oolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnY
ZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006
ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oo
oooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_oo
ool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooo
oolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolmooooo`001_oo
ool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go
00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooocko
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooocko
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`007oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooolm
ooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo?Oooool0027o
oooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`007oooool00omEEEGo
IVIVo`00003oooooodOooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .36218 Mdot
.02762 .39929 Mdot
.02952 .27571 Mdot
.03143 .27349 Mdot
.03333 .24982 Mdot
.03524 .26151 Mdot
.03714 .27007 Mdot
.03905 .40791 Mdot
.04095 .36541 Mdot
.04286 .33231 Mdot
.04476 .35153 Mdot
.04667 .43263 Mdot
.04857 .40914 Mdot
.05048 .34544 Mdot
.05238 .44179 Mdot
.05429 .26221 Mdot
.05619 .34675 Mdot
.0581 .40856 Mdot
.06 .31295 Mdot
.0619 .30468 Mdot
.06381 .39853 Mdot
.06571 .40685 Mdot
.06762 .40226 Mdot
.06952 .40399 Mdot
.07143 .45183 Mdot
.07333 .33745 Mdot
.07524 .34505 Mdot
.07714 .3087 Mdot
.07905 .27834 Mdot
.08095 .40204 Mdot
.08286 .37999 Mdot
.08476 .35594 Mdot
.08667 .40328 Mdot
.08857 .29872 Mdot
.09048 .27028 Mdot
.09238 .30068 Mdot
.09429 .24762 Mdot
.09619 .32444 Mdot
.0981 .24157 Mdot
.1 .43433 Mdot
.1019 .45262 Mdot
.10381 .28677 Mdot
.10571 .24171 Mdot
.10762 .36157 Mdot
.10952 .33601 Mdot
.11143 .27688 Mdot
.11333 .34681 Mdot
.11524 .31305 Mdot
.11714 .3736 Mdot
.11905 .26368 Mdot
.12095 .31547 Mdot
.12286 .23451 Mdot
.12476 .23721 Mdot
.12667 .24498 Mdot
.12857 .24908 Mdot
.13048 .38669 Mdot
.13238 .41404 Mdot
.13429 .35365 Mdot
.13619 .27936 Mdot
.1381 .32715 Mdot
.14 .29304 Mdot
.1419 .44811 Mdot
.14381 .23576 Mdot
.14571 .33574 Mdot
.14762 .41359 Mdot
.14952 .36845 Mdot
.15143 .33126 Mdot
.15333 .26299 Mdot
.15524 .33078 Mdot
.15714 .39606 Mdot
.15905 .35777 Mdot
.16095 .29143 Mdot
.16286 .33839 Mdot
.16476 .31254 Mdot
.16667 .23575 Mdot
.16857 .2965 Mdot
.17048 .23683 Mdot
.17238 .33201 Mdot
.17429 .24199 Mdot
.17619 .37088 Mdot
.1781 .35008 Mdot
.18 .40135 Mdot
.1819 .28053 Mdot
.18381 .28609 Mdot
.18571 .3922 Mdot
.18762 .25847 Mdot
.18952 .25023 Mdot
.19143 .26991 Mdot
.19333 .3652 Mdot
.19524 .26589 Mdot
.19714 .45174 Mdot
.19905 .34551 Mdot
.20095 .33584 Mdot
.20286 .26651 Mdot
.20476 .33645 Mdot
.20667 .36902 Mdot
.20857 .34414 Mdot
.21048 .33328 Mdot
.21238 .23232 Mdot
.21429 .36953 Mdot
.21619 .37356 Mdot
.2181 .37407 Mdot
.22 .43479 Mdot
.2219 .373 Mdot
.22381 .37606 Mdot
.22571 .29101 Mdot
.22762 .34491 Mdot
.22952 .2998 Mdot
.23143 .33581 Mdot
.23333 .39189 Mdot
.23524 .33814 Mdot
.23714 .28379 Mdot
.23905 .35567 Mdot
.24095 .31889 Mdot
.24286 .24736 Mdot
.24476 .29824 Mdot
.24667 .31218 Mdot
.24857 .36633 Mdot
.25048 .35912 Mdot
.25238 .25696 Mdot
.25429 .4077 Mdot
.25619 .45623 Mdot
.2581 .39424 Mdot
.26 .27976 Mdot
.2619 .39363 Mdot
.26381 .26322 Mdot
.26571 .30139 Mdot
.26762 .38735 Mdot
.26952 .39412 Mdot
.27143 .26404 Mdot
.27333 .40574 Mdot
.27524 .38446 Mdot
.27714 .44122 Mdot
.27905 .25861 Mdot
.28095 .24475 Mdot
.28286 .2587 Mdot
.28476 .23146 Mdot
.28667 .2848 Mdot
.28857 .33773 Mdot
.29048 .41692 Mdot
.29238 .44247 Mdot
.29429 .42098 Mdot
.29619 .31746 Mdot
.2981 .32615 Mdot
.3 .34783 Mdot
.3019 .31392 Mdot
.30381 .38257 Mdot
.30571 .29273 Mdot
.30762 .26838 Mdot
.30952 .27594 Mdot
.31143 .46246 Mdot
.31333 .37631 Mdot
.31524 .34651 Mdot
.31714 .40521 Mdot
.31905 .28389 Mdot
.32095 .30789 Mdot
.32286 .2313 Mdot
.32476 .23573 Mdot
.32667 .37224 Mdot
.32857 .25242 Mdot
.33048 .23128 Mdot
.33238 .35808 Mdot
.33429 .24592 Mdot
.33619 .44971 Mdot
.3381 .31629 Mdot
.34 .2444 Mdot
.3419 .37474 Mdot
.34381 .3812 Mdot
.34571 .37171 Mdot
.34762 .33292 Mdot
.34952 .22986 Mdot
.35143 .26949 Mdot
.35333 .32226 Mdot
.35524 .33566 Mdot
.35714 .25421 Mdot
.35905 .26607 Mdot
.36095 .41072 Mdot
.36286 .37386 Mdot
.36476 .30587 Mdot
.36667 .29034 Mdot
.36857 .26179 Mdot
.37048 .23382 Mdot
.37238 .44217 Mdot
.37429 .28528 Mdot
.37619 .45383 Mdot
.3781 .27671 Mdot
.38 .36659 Mdot
.3819 .38394 Mdot
.38381 .34218 Mdot
.38571 .44825 Mdot
.38762 .24169 Mdot
.38952 .45811 Mdot
.39143 .31609 Mdot
.39333 .3305 Mdot
.39524 .44678 Mdot
.39714 .4009 Mdot
.39905 .45806 Mdot
.40095 .43744 Mdot
.40286 .26276 Mdot
.40476 .33185 Mdot
.40667 .33305 Mdot
.40857 .30883 Mdot
.41048 .30641 Mdot
.41238 .29775 Mdot
.41429 .25098 Mdot
.41619 .31571 Mdot
.4181 .38115 Mdot
.42 .3136 Mdot
.4219 .27595 Mdot
.42381 .29531 Mdot
.42571 .2841 Mdot
.42762 .35235 Mdot
.42952 .41121 Mdot
.43143 .3267 Mdot
.43333 .37034 Mdot
.43524 .28305 Mdot
.43714 .37766 Mdot
.43905 .32107 Mdot
.44095 .4509 Mdot
.44286 .27157 Mdot
.44476 .33101 Mdot
.44667 .42776 Mdot
.44857 .30675 Mdot
.45048 .30054 Mdot
.45238 .3784 Mdot
.45429 .3351 Mdot
.45619 .27903 Mdot
.4581 .25446 Mdot
.46 .39322 Mdot
.4619 .32815 Mdot
.46381 .44214 Mdot
.46571 .45774 Mdot
.46762 .25737 Mdot
.46952 .30605 Mdot
.47143 .29891 Mdot
.47333 .37374 Mdot
.47524 .34924 Mdot
.47714 .45592 Mdot
.47905 .33157 Mdot
.48095 .37805 Mdot
.48286 .40117 Mdot
.48476 .381 Mdot
.48667 .44609 Mdot
.48857 .2455 Mdot
.49048 .36211 Mdot
.49238 .35795 Mdot
.49429 .35034 Mdot
.49619 .33561 Mdot
.4981 .23441 Mdot
.5 .35883 Mdot
.5019 .35953 Mdot
.50381 .23697 Mdot
.50571 .45702 Mdot
.50762 .29892 Mdot
.50952 .332 Mdot
.51143 .24195 Mdot
.51333 .34685 Mdot
.51524 .33666 Mdot
.51714 .24878 Mdot
.51905 .30104 Mdot
.52095 .41383 Mdot
.52286 .29654 Mdot
.52476 .37541 Mdot
.52667 .34949 Mdot
.52857 .32984 Mdot
.53048 .27081 Mdot
.53238 .37452 Mdot
.53429 .35649 Mdot
.53619 .34885 Mdot
.5381 .26397 Mdot
.54 .2838 Mdot
.5419 .36028 Mdot
.54381 .30546 Mdot
.54571 .24711 Mdot
.54762 .32825 Mdot
.54952 .37304 Mdot
.55143 .23031 Mdot
.55333 .28639 Mdot
.55524 .27546 Mdot
.55714 .32562 Mdot
.55905 .35207 Mdot
.56095 .29427 Mdot
.56286 .25571 Mdot
.56476 .26457 Mdot
.56667 .30712 Mdot
.56857 .25523 Mdot
.57048 .42998 Mdot
.57238 .29869 Mdot
.57429 .27343 Mdot
.57619 .25122 Mdot
.5781 .34037 Mdot
.58 .27958 Mdot
.5819 .35541 Mdot
.58381 .38141 Mdot
.58571 .28177 Mdot
.58762 .43638 Mdot
.58952 .2947 Mdot
.59143 .28704 Mdot
.59333 .2575 Mdot
.59524 .44553 Mdot
.59714 .35465 Mdot
.59905 .44008 Mdot
.60095 .31654 Mdot
.60286 .37185 Mdot
.60476 .24114 Mdot
.60667 .38507 Mdot
.60857 .35325 Mdot
.61048 .45145 Mdot
.61238 .34837 Mdot
.61429 .3284 Mdot
.61619 .35017 Mdot
.6181 .32005 Mdot
.62 .40965 Mdot
.6219 .34371 Mdot
.62381 .40669 Mdot
.62571 .462 Mdot
.62762 .28734 Mdot
.62952 .34108 Mdot
.63143 .29029 Mdot
.63333 .41869 Mdot
.63524 .27249 Mdot
.63714 .44403 Mdot
.63905 .45264 Mdot
.64095 .42213 Mdot
.64286 .25822 Mdot
.64476 .25554 Mdot
.64667 .2885 Mdot
.64857 .23206 Mdot
.65048 .25678 Mdot
.65238 .31984 Mdot
.65429 .276 Mdot
.65619 .34792 Mdot
.6581 .4206 Mdot
.66 .24423 Mdot
.6619 .33735 Mdot
.66381 .40962 Mdot
.66571 .26376 Mdot
.66762 .29974 Mdot
.66952 .39485 Mdot
.67143 .25433 Mdot
.67333 .24442 Mdot
.67524 .35866 Mdot
.67714 .25064 Mdot
.67905 .25729 Mdot
.68095 .35391 Mdot
.68286 .39926 Mdot
.68476 .33599 Mdot
.68667 .39791 Mdot
.68857 .34619 Mdot
.69048 .28758 Mdot
.69238 .40374 Mdot
.69429 .33014 Mdot
.69619 .30672 Mdot
.6981 .42349 Mdot
.7 .42988 Mdot
.7019 .24986 Mdot
.70381 .29782 Mdot
.70571 .36903 Mdot
.70762 .32836 Mdot
.70952 .278 Mdot
.71143 .37442 Mdot
.71333 .43012 Mdot
.71524 .42698 Mdot
.71714 .3596 Mdot
.71905 .44084 Mdot
.72095 .44545 Mdot
.72286 .45357 Mdot
.72476 .31202 Mdot
.72667 .37427 Mdot
.72857 .44313 Mdot
.73048 .41307 Mdot
.73238 .31481 Mdot
.73429 .36804 Mdot
.73619 .35789 Mdot
.7381 .27147 Mdot
.74 .37046 Mdot
.7419 .3423 Mdot
.74381 .37799 Mdot
.74571 .25504 Mdot
.74762 .23582 Mdot
.74952 .40241 Mdot
.75143 .2404 Mdot
.75333 .4051 Mdot
.75524 .44977 Mdot
.75714 .25997 Mdot
.75905 .27061 Mdot
.76095 .30697 Mdot
.76286 .28477 Mdot
.76476 .455 Mdot
.76667 .36948 Mdot
.76857 .27822 Mdot
.77048 .44291 Mdot
.77238 .39494 Mdot
.77429 .32233 Mdot
.77619 .32017 Mdot
.7781 .32935 Mdot
.78 .34692 Mdot
.7819 .31738 Mdot
.78381 .38424 Mdot
.78571 .44531 Mdot
.78762 .44337 Mdot
.78952 .32627 Mdot
.79143 .25824 Mdot
.79333 .32545 Mdot
.79524 .27065 Mdot
.79714 .26651 Mdot
.79905 .31704 Mdot
.80095 .41973 Mdot
.80286 .43191 Mdot
.80476 .34598 Mdot
.80667 .32607 Mdot
.80857 .3543 Mdot
.81048 .26607 Mdot
.81238 .46034 Mdot
.81429 .25865 Mdot
.81619 .32441 Mdot
.8181 .30495 Mdot
.82 .34408 Mdot
.8219 .26776 Mdot
.82381 .25395 Mdot
.82571 .30592 Mdot
.82762 .34997 Mdot
.82952 .31758 Mdot
.83143 .45967 Mdot
.83333 .41522 Mdot
.83524 .29828 Mdot
.83714 .26493 Mdot
.83905 .34438 Mdot
.84095 .33101 Mdot
.84286 .36165 Mdot
.84476 .33615 Mdot
.84667 .45642 Mdot
.84857 .36497 Mdot
.85048 .38482 Mdot
.85238 .22591 Mdot
.85429 .36513 Mdot
.85619 .32106 Mdot
.8581 .3804 Mdot
.86 .44452 Mdot
.8619 .35076 Mdot
.86381 .40319 Mdot
.86571 .25082 Mdot
.86762 .32204 Mdot
.86952 .32489 Mdot
.87143 .2582 Mdot
.87333 .3363 Mdot
.87524 .36922 Mdot
.87714 .338 Mdot
.87905 .28206 Mdot
.88095 .25101 Mdot
.88286 .29742 Mdot
.88476 .33756 Mdot
.88667 .28444 Mdot
.88857 .29917 Mdot
.89048 .40923 Mdot
.89238 .28337 Mdot
.89429 .24994 Mdot
.89619 .39414 Mdot
.8981 .34084 Mdot
.9 .30501 Mdot
.9019 .36169 Mdot
.90381 .33719 Mdot
.90571 .39802 Mdot
.90762 .32267 Mdot
.90952 .42183 Mdot
.91143 .45712 Mdot
.91333 .34892 Mdot
.91524 .25422 Mdot
.91714 .36119 Mdot
.91905 .34672 Mdot
.92095 .29147 Mdot
.92286 .3725 Mdot
.92476 .30367 Mdot
.92667 .30651 Mdot
.92857 .30502 Mdot
.93048 .45453 Mdot
.93238 .24826 Mdot
.93429 .28997 Mdot
.93619 .24211 Mdot
.9381 .37146 Mdot
.94 .30708 Mdot
.9419 .25891 Mdot
.94381 .24705 Mdot
.94571 .24167 Mdot
.94762 .30407 Mdot
.94952 .34306 Mdot
.95143 .37016 Mdot
.95333 .25007 Mdot
.95524 .35083 Mdot
.95714 .33659 Mdot
.95905 .2977 Mdot
.96095 .32196 Mdot
.96286 .2362 Mdot
.96476 .32368 Mdot
.96667 .39725 Mdot
.96857 .31403 Mdot
.97048 .31682 Mdot
.97238 .3271 Mdot
.97429 .27513 Mdot
.97619 .43895 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooo`Sooooo0_l0000cooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0IOoo
ool2o`0003oooooo0_l0001Oooooo`;o0000<oooool000Kooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0003Wooooo0_l0
000Eooooo`;o00002_ooool2o`000003ooooool0003o000000Cooooo0_l00005ooooo`;o0000>?oo
ool2o`0001gooooo0_l0001eooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
7?ooool3o`0000Cooooo0_l00005ooooo`?o00003?ooool2o`0001Gooooo0_l0000:ooooo`Go0000
2oooool2o`0002Oooooo1?l0000/ooooo`;o00007_ooool2o`0004?ooooo0_l0000@ooooo`001_oo
ool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo01cooooo0ol00004ooooo`;o00001Oooool3o`00033ooooo
0_l0000fooooo`Co0000C?ooool3o`0004;ooooo0_l0000@ooooo`001_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool05?ooool2o`000003ooooool0003o000001Cooooo0_l00012ooooo`;o
00009_ooool2o`0001cooooo0_l0000]ooooo`;o0000>_ooool2o`000003ooooool0003o000001Go
oooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
00Cooooo1?l00006ooooo`03o`000?oooooooooo01Cooooo0_l000000ooooooo0000o`000004oooo
o`;o00003_ooool2o`00023ooooo0_l0000?ooooo`Co00003Oooool2o`0001oooooo0_l00005oooo
o`;o00007?ooool2o`00013ooooo0_l00002ooooo`;o0000Doooool2o`000003ooooool0003o0000
01Gooooo000Yooooo`;o00005?ooool2o`0000Sooooo0ol0000Sooooo`;o00002_ooool2o`0000oo
oooo1?l0000^ooooo`;o00001oooool2o`0000Oooooo0_l0000Sooooo`;o00000_ooool2o`00057o
oooo0_l00002ooooo`;o00005_ooool002Wooooo00Co0000ooooool0003o00004_ooool2o`0000Wo
oooo0_l0000Booooo`;o00003oooool2o`0001Wooooo0_l0000Jooooo`;o00007oooool2o`0000Oo
oooo0_l00008ooooo`;o00007_ooool2o`0000Kooooo0_l0000cooooo`;o00000oooool2o`0000;o
oooo0_l0000:ooooo`;o00000_ooool2o`000003ooooool0003o000001?ooooo000Yooooo`04o`00
0?oooooo0000o`00037ooooo0_l0000Zooooo`;o00001oooool2o`00017ooooo0_l0000<ooooo`;o
00008?ooool3o`000003ooooool0003o000001Cooooo0_l00007ooooo`?o00001_ooool2o`0000co
oooo0_l0000Hooooo`;o00002oooool2o`0000?ooooo0_l00002ooooo`;o00001Oooool2o`0000[o
oooo0_l0000Cooooo`00:Oooool00ol0003oooooooooo`0aooooo`;o00004oooool2o`0000Kooooo
1?l0000Eooooo`;o00007oooool2o`000003ooooool0003o000001gooooo0ol00006ooooo`;o0000
3_ooool5o`0000Gooooo1?l0000Cooooo`;o00003Oooool2o`0000Gooooo0_l00002ooooo`;o0000
3Oooool2o`0000cooooo0_l00006ooooo`;o00005oooool002Wooooo00?o0000ooooooooool00_l0
000_ooooo`;o00004oooool2o`0000Kooooo1?l0000Iooooo`;o00007_ooool2o`0002Kooooo0_l0
000>ooooo`;o000000?oooooo`000?l000001oooool2o`0001Oooooo0_l00009ooooo`;o00001Ooo
ool2o`00017ooooo0_l0000Dooooo`;o00005oooool002Wooooo0_l000000ooooooo0000o`000004
ooooo`;o00004oooool2o`0000Wooooo0_l0000Qooooo`;o000000?oooooo`000?l000007Oooool2
o`0000Wooooo0_l0000Zooooo`;o00001_ooool2o`0001oooooo0_l0000Kooooo`;o00006?ooool2
o`0003Sooooo000Yooooo`03o`000?oooooooooo00Kooooo0_l0000Cooooo`;o00002Oooool2o`00
00_ooooo0_l000000ooooooo0000o`00000Aooooo`;o000000?oooooo`000?l000002_ooool2o`00
00kooooo0_l0000<ooooo`;o0000:_ooool2o`0000Kooooo0_l0000Oooooo`;o0000:?ooool2o`00
00;ooooo0_l00002ooooo`;o00000oooool2o`0003Sooooo000Yooooo`04o`000?oooooooooooooo
o`;o00003oooool2o`0001cooooo1Ol000001ooooooo0000o`000?lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Cooooo0_l0000<ooooo`Co00000oooool5o`0000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Oooool2o`00
00Wooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^02?ooooo0_l00005ooooo`;o000000Wo410@oooooooooooo
ooooonk^k_lb<S;o0000oc8b<_o^k^h00ol000001_o^k^ko<S8bo`000?l0003ok^k^ooooo`;o0000
9_ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool002Wooooo00?o0000ooooool000000ol0000?oooo
o`;o00007_ooool2o`0000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL08_ooool2o`0000Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01_mgMgOoV9RHoooooonHV9SoMgMgooooo`;o00006_ooool2
o`0000Wooooo00?o410@okZj^_ooool00_l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo0_l0000Oooooo`;o00001Oooool2o`0000Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`02o`000006oooooomgMgOoV9RHoooooonHV9SoMgMg;?ooool0
2OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool002Wooooo1?l0000Gooooo`;o00006?ooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@01Cooooo0_l0000D
ooooo`;o000000?ok^k^ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00;ooooo0_l0
0003ooooo`04oa0@4?oooooo0000o`0002;ooooo0_l00004ooooo`;o00000oooool01Ol@413ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4002ooooo`;o00001?ooool2o`00
01kooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@02gooooo00Go0000oooooooooooo410@ooooo`02o`000005oa0@4?ooooooooooooooool@
41000oooool00ol@413oooooooooo`01ooooo`00:Oooool3o`0000kooooo0_l00008ooooo`;o0000
1_ooool2o`0000gooooo0_l000000ooooooo0000ooooo`03ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000Cooooo0_l0000>ooooo`;o00005?ooool2o`00
0003ob4Q8Oo^k^kooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`;o00000oooool0
0ol0003oooooooooo`03ooooo`;o00007_ooool2o`0000Cooooo00KoZJVYoa0@4?l0003o0000oooo
ool00003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`06ooooo`;o
00004?ooool2o`0000cooooo00GoA4A4omgMgOoooooo0000ooooo`02o`000003ooooool0003ooooo
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo02[ooooo00KoMgMg
oc8b<_ooooooooooo`000?ooool3o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`00
:Oooool00ol0003oooooooooo`0>ooooo`;o00004?ooool2o`0000gooooo0_l000000ooooooo0000
ooooo`03ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooo`000002o`0000Co
oooo0_l0000Aooooo`;o00004oooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooooooooooo
ool000000oooool01?l0003oooooooooooooool2o`0000Cooooo0_l0000Iooooo`;o00002?ooool0
0ol@413o0000okZj^P04o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo01Sooooo0_l0000<ooooo`05omgMgOmEEEGoooooo`000?ooool00_l000000ooooooo0000
ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Aooooo`;o
00000oooool2o`0000oooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo000Yooooo`03o`000?oooooo
oooo01Kooooo0_l0000Hooooo`?o00001?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@ooooool0003o0000oa0@400=ooooo`;o00002?ooool2o`00013ooooo0_l00002ooooo`05o`00
0?ooooooooooooooool@41000oooool01?l@413oooooooooooooool2o`0000;ooooo0_l0000Ooooo
o`;o00000oooool2o`0000Cooooo00Co^[Zjob4Q8Ooooooooooo1?l000000ooooooo410@ooooo`02
ooooo`05oa0@4?ooooooooooooooool@4100:Oooool01?mgMgOoc<c<o`000?l00003ooooo`05oa0@
4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@01?ooooo0_l000000ooo
oooo0000o`000002o`0000oooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo
410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`00:Oooool00ol0003oooooooooo`0F
ooooo`;o00006?ooool3o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03Oooool2o`0001[ooooo0_l000000oooooooV9RHoa0@4003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool2o`000003oooooonHV9SoMgMg02Gooooo0_l000001_oooooo
410@oiRHV?oooooo^[Zjo`0000?ooooo00GoMgMgo`000?l0003oV9RHogMgM`03ooooo`04ogMgMonH
V9SooooooiRHV0;o00001Oooool2o`0000cooooo0_l0000Cooooo`04onk^k_m4A4Co0000o`0000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05_ooool2
o`0000gooooo0_l00002ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wooooo00?o0000ooooooooool08_oo
ool2o`0000Cooooo0_l00006ooooo`03oeEEEOmVIVKo000000Cooooo00Kok^k^oc8b<_l0003o<S8b
onk^k_ooool2o`000005onk^k_lb<S;o0000oc8b<_o^k^h04oooool2o`0001;ooooo0_l000001OnH
V9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h0:?ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`04onk^k_lb<S;o0000oc8b<PCo00000oooool2o`0000cooooo0_l0000D
ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h08Oooool2o`0000;ooooo0_l00002ooooo`Co00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool2o`0002?o
oooo0_l00004ooooo`;o00004oooool2o`0001Sooooo0_l0000Booooo`;o00004?ooool2o`0002[o
oooo0_l00007ooooo`;o00003?ooool2o`0005_ooooo0_l0000Mooooo`00:Oooool00ol0003ooooo
ooooo`0Aooooo`;o00006?ooool2o`0001Kooooo0_l0000dooooo`;o00000_ooool2o`0000gooooo
0_l0000:ooooo`;o00000oooool2o`0000[ooooo0_l00002ooooo`;o00000oooool2o`0002?ooooo
0_l0000Xooooo`;o00003Oooool4o`0001Gooooo0_l0000Aooooo`00:Oooool00ol0003ooooooooo
o`0Aooooo`?o00005oooool2o`00017ooooo0_l00003ooooo`;o00001Oooool2o`0002gooooo0_l0
000:ooooo`;o00001Oooool2o`0000[ooooo0_l00002ooooo`?o00003_ooool2o`0001cooooo0_l0
000:ooooo`;o0000:?ooool2o`0000gooooo1?l0000Eooooo`;o00004Oooool002Wooooo00?o0000
ooooooooool02Oooool2o`0000Oooooo0_l0000Zooooo`;o00002_ooool2o`0003Wooooo0_l0000E
ooooo`;o00001Oooool2o`0002Kooooo0_l0000_ooooo`;o00006?ooool2o`0000Kooooo0ol00004
ooooo`;o00005Oooool002Wooooo00?o0000ooooooooool02Oooool2o`0000;ooooo0_l0001=oooo
o`;o00003?ooool2o`0000gooooo0_l0000:ooooo`;o00001Oooool2o`0001Gooooo0_l00006oooo
o`;o00009oooool2o`0001?ooooo0_l0000Aooooo`Co00005_ooool2o`0000Kooooo0ol00002oooo
o`Co00005Oooool0027oooooool00014o`0000Cooooo000Yooooo`03o`000?oooooooooo00Sooooo
0_l0000<ooooo`04o`000?ooooooooooooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`;o
00000_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo0_l000000ooooooo
0000ooooo`0:ooooo`03o`000?oooooooooo00;o00001oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00[ooooo0_l00002ooooo`;o00001_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`04
o`000?ooooooooooooooo`Co00001?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01_ooool2o`000003ooooool0003ooooo00_ooooo000Yooooo`03
o`000?oooooooooo00Sooooo0_l0000@ooooo`Co00003?ooool2o`0000kooooo00?o0000oooooooo
ool01oooool2o`0000kooooo1?l00009ooooo`;o00003oooool2o`0000Cooooo00?o0000ooooool0
00000ol0000gooooo`?o00009_ooool4o`0000kooooo0ol00003ooooo`;o00001oooool2o`0002_o
oooo1?l0000<ooooo`00:Oooool00ol0003oooooooooo`0Looooo`;o00009?ooool2o`00013ooooo
0_l0000;ooooo`;o00003oooool2o`0000Kooooo0_l00006ooooo`;o0000<_ooool2o`0000?ooooo
0_l00009ooooo`;o00009_ooool4o`0000Cooooo0_l00007ooooo`;o00001oooool2o`0002?ooooo
0_l0000=ooooo`00:Oooool00ol0003oooooooooo`12ooooo`;o00008_ooool2o`0001[ooooo0_l0
000gooooo`;o00002Oooool2o`0002Kooooo0_l0000Hooooo`;o00000_ooool2o`0000[ooooo0_l0
000@ooooo`?o00003oooool002Wooooo0_l0000Eooooo`;o00002oooool2o`00037ooooo0_l0000@
ooooo`;o00005oooool2o`0002Oooooo0_l00014ooooo`;o00000_ooool4o`0000;ooooo0_l00000
0ooooooo0000o`00000?ooooo`;o00002_ooool2o`00013ooooo1Ol0000=ooooo`00:Oooool00ol0
003oooooooooo`0Dooooo`;o00002oooool2o`00037ooooo0_l0000Mooooo`;o00002_ooool2o`00
00Sooooo0_l0000Dooooo`;o00001?ooool2o`000003ooooool0003o0000013ooooo0_l0000Hoooo
o`;o00000_ooool2o`0001Gooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l000000ooo
oooo0000o`00000?ooooo`;o00007oooool2o`0000gooooo000Yooooo`03o`000?oooooooooo00;o
oooo0_l0000Qooooo`Co00000oooool2o`0000[ooooo0_l0000Zooooo`;o00003Oooool2o`0000;o
oooo0_l0000;ooooo`;o00000oooool2o`0000Cooooo0_l00007ooooo`;o00001Oooool2o`0000Co
oooo0_l0000Cooooo`;o00006?ooool2o`0000;ooooo0_l0000Eooooo`;o00004_ooool2o`0003Oo
oooo000Yooooo`03o`000?oooooooooo00;ooooo0_l0000Dooooo`;o00002Oooool6o`0000?ooooo
0_l00007ooooo`Go00001Oooool2o`0002?ooooo0_l000000ooooooo0000o`00000>ooooo`;o0000
2oooool2o`000003ooooool0003o000000Kooooo0_l00003ooooo`;o00000_ooool4o`0003Gooooo
0_l0000`ooooo`?o00001oooool2o`0001Wooooo0_l0000Booooo`00:Oooool00ol0003ooooooooo
o`0<ooooo`;o00002_ooool2o`0000Wooooo0_l00004ooooo`;o00002_ooool3o`0000Oooooo0ol0
000?ooooo`;o00005?ooool2o`0001kooooo0_l0000;ooooo`;o00001?ooool2o`0002gooooo0_l0
0006ooooo`;o0000<Oooool2o`0000Oooooo1_l00004ooooo`;o00003oooool2o`0001;ooooo000Y
ooooo`;o00003Oooool2o`0001_ooooo0_l0000Eooooo`;o00003oooool2o`0001gooooo0_l0000l
ooooo`;o00003oooool2o`0000Sooooo0_l0000Hooooo`;o0000:_ooool4o`0000;ooooo1?l0000S
ooooo`00:Oooool00ol0003oooooooooo`05ooooo`;o00001_ooool2o`0002Kooooo0_l000000ooo
oooo0000o`000004ooooo`;o0000<?ooool2o`0003cooooo0_l0000=ooooo`Co00008_ooool2o`00
01;ooooo0_l00003ooooo`;o00001?ooool2o`00017ooooo0_l0000?ooooo`;o00005?ooool002Wo
oooo00?o0000ooooooooool01Oooool4o`0000Cooooo0_l0000:ooooo`;o00006_ooool2o`000003
ooooool0003o000000Cooooo0_l0000Eooooo`;o00000oooool2o`00037ooooo0_l0000;ooooo`;o
00001Oooool2o`0001Oooooo0_l000000ooooooo0000o`000009ooooo`;o00002?ooool2o`0001_o
oooo0_l00006ooooo`;o00000oooool2o`0000Cooooo0_l0000Fooooo`Co00002?ooool2o`0001Co
oooo000Yooooo`03o`000?oooooooooo00?ooooo0_l00002ooooo`;o00004?ooool2o`0001?ooooo
0_l0000Uooooo`;o00000oooool2o`0002;ooooo0_l0000=ooooo`;o00001Oooool2o`0000Cooooo
0_l00002ooooo`;o000000?oooooo`000?l000001Oooool2o`00013ooooo0ol0000;ooooo`;o0000
2?ooool2o`0001_ooooo0_l0000>ooooo`;o00002Oooool2o`0000kooooo1?l0000:ooooo`;o0000
4_ooool002Wooooo00?o0000ooooooooool00oooool2o`0001_ooooo0_l0000<ooooo`;o0000C_oo
ool2o`0001Cooooo0_l00008ooooo`;o00002?ooool2o`0000Kooooo0_l00003ooooo`;o000000Co
ooooo`000?l0003ooooo0_l0000Cooooo`;o00009oooool2o`0000Cooooo0_l00009ooooo`;o0000
7?ooool2o`0001;ooooo000Yooooo`;o00004Oooool2o`0000kooooo0_l00006ooooo`;o00005ooo
ool2o`0001cooooo0_l0000booooo`;o00002oooool2o`0000kooooo0_l00003ooooo`;o000000?o
ooooo`000?l000005_ooool2o`0000oooooo0_l0000Fooooo`;o0000@Oooool002Wooooo00?o0000
ooooooooool04?ooool2o`0000Gooooo0_l0000?ooooo`;o00005oooool2o`0000;ooooo0_l0000H
ooooo`;o0000<_ooool5o`0000Sooooo0_l000000ooooooo0000o`00000Yooooo`;o00002oooool2
o`0000Cooooo0_l0000Qooooo`;o00004Oooool2o`0000?ooooo0_l0000Nooooo`00:Oooool2o`00
01Sooooo0_l0000/ooooo`;o0000Boooool2o`000004ooooool0003o0000o`0000_ooooo0_l0000Y
ooooo`;o00002oooool2o`0002Oooooo0_l0000Aooooo`;o00000oooool2o`0001kooooo000Yoooo
o`;o00000oooool2o`0002oooooo0_l0000@ooooo`;o0000:?ooool2o`00027ooooo0_l0001aoooo
o`Co0000<oooool002Wooooo00?o0000ooooooooool00_ooool2o`00027ooooo0_l00006ooooo`;o
00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000009ooooo`;o0000:?ooool2o`0000oo
oooo0_l0001Fooooo`;o00001oooool4o`0000Kooooo0_l0000Hooooo`Co00001Oooool2o`0001Oo
oooo0_l0000Cooooo`00:Oooool2o`0001_ooooo0_l00009ooooo`;o00001_ooool2o`0000Sooooo
0_l000000ooooooo0000o`000002o`00023ooooo0_l00004ooooo`;o00000oooool2o`0001Gooooo
0_l0000;ooooo`;o00005_ooool2o`0000oooooo0_l0000Pooooo`;o00001oooool4o`0000Kooooo
0_l0000Qooooo`;o00003Oooool2o`0000?ooooo0_l00003ooooo`;o00004oooool002Wooooo00?o
0000ooooooooool06_ooool2o`0001kooooo1Ol0000Jooooo`;o00000oooool2o`0000?ooooo0ol0
0003ooooo`;o00008_ooool2o`0000kooooo0_l000000ooooooo0000o`000003ooooo`;o00003ooo
ool2o`00027ooooo0_l00003ooooo`;o0000?Oooool2o`0000?ooooo0_l0000Hooooo`001_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Gooooo00?o0000ooooooooool03oooool2o`0002cooooo0_l0000Jooooo`;o0000
2?ooool2o`0001cooooo0_l00003ooooo`;o00001oooool2o`0000cooooo0_l000000ooooooo0000
o`00000gooooo`;o00000oooool2o`0000Cooooo0_l0001Fooooo`001_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo00oooooo0_l00015ooooo`;o00002oooool2o`0001Ko
oooo0_l00004ooooo`;o00000oooool2o`0000Oooooo0ol0000Nooooo`;o0000<_ooool2o`0002?o
oooo0_l0000aooooo`001_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^
k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04gooooo0_l00007ooooo`;o
00002oooool2o`0000[ooooo0_l0000:ooooo`;o00004oooool2o`0001kooooo0_l00006ooooo`;o
0000=oooool2o`0001?ooooo0_l000000ooooooo0000o`00000aooooo`001_ooool01Ol0003ooooo
oooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o
00007oooool2o`0002[ooooo1?l0000Pooooo`;o0000Aoooool2o`0003Oooooo0_l0000Cooooo`;o
0000=?ooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo01oooooo0_l0000?oooo
o`;o00003_ooool2o`0000Wooooo0_l0003_ooooo`001_ooool01Ol@413ooooooooooooooooo410@
00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
033ooooo0_l0000>ooooo`;o00001_ooool5o`0003cooooo0_l00011ooooo`;o00007oooool2o`00
02Kooooo0_l0000Uooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool2
o`0001cooooo0_l0000Oooooo`Go0000??ooool2o`00047ooooo0_l00003ooooo`;o00006_ooool2
o`0002Kooooo0_l000000ooooooo0000o`00000Aooooo`;o00003oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0
000:ooooo`;o00001?ooool2o`0001Kooooo0_l00005ooooo`;o0000A?ooool2o`0001[ooooo0_l0
000nooooo`?o0000AOooool2o`00017ooooo0_l0000?ooooo`00:Oooool2o`0000_ooooo0ol00002
ooooo`?o00007?ooool2o`0002_ooooo0_l0000Gooooo`;o00006_ooool2o`0003kooooo0_l00000
0ooooooo0000o`00000Aooooo`?o00008Oooool2o`00033ooooo000Yooooo`04o`000?oooooooooo
ooooo`;o00001oooool3o`0000?ooooo0_l0000dooooo`;o00001Oooool2o`0000cooooo0_l0001P
ooooo`;o00005?ooool2o`00017ooooo0ol0000Qooooo`;o0000<?ooool002Wooooo00Co0000oooo
oooooooooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000003[ooooo0_l0
0005ooooo`;o00006_ooool2o`0001Cooooo0_l0000kooooo`?o00002oooool2o`0004Oooooo0_l0
000Wooooo`00:Oooool00ol0003oooooooooo`04ooooo`;o000000?oooooo`000?l000005_ooool2
o`0000?ooooo0_l00013ooooo`;o00005?ooool2o`0001_ooooo0_l0000Nooooo`;o00003?ooool2
o`0001?ooooo0_l0000booooo`;o00009oooool002Wooooo00?o0000ooooooooool07oooool2o`00
00?ooooo0_l0000/ooooo`;o0000B?ooool2o`00047ooooo0_l0000Pooooo`;o0000>Oooool002Wo
oooo0_l0001Cooooo`;o0000K?ooool2o`0000Kooooo0_l0000/ooooo`;o00002Oooool2o`0003Wo
oooo000Yooooo`03o`000?oooooooooo05?ooooo0_l0001[ooooo`;o000000?oooooo`000?l00000
0oooool2o`0000_ooooo0_l0000Oooooo`;o00008Oooool2o`00027ooooo000Yooooo`03o`000?oo
oooooooo05?ooooo0_l0001^ooooo`;o00004?ooool2o`0000Cooooo0_l0000looooo`;o00008Ooo
ool002Wooooo00?o0000ooooooooool0Q?ooool2o`0002Kooooo0_l0000Xooooo`;o00000oooool2
o`0005oooooo000Yooooo`03o`000?oooooooooo00Cooooo0_l0001nooooo`;o00009_ooool2o`00
02Sooooo0_l00002ooooo`;o00006oooool2o`0004?ooooo000Yooooo`;o00001Oooool2o`0000oo
oooo0_l0000Tooooo`;o0000WOooool2o`0001_ooooo0_l00013ooooo`00:Oooool00ol0003ooooo
ooooo`0Eooooo`;o00009?ooool2o`0003Wooooo0_l0000jooooo`;o0000Noooool2o`0000_ooooo
000Yooooo`03o`000?oooooooooo00Gooooo0_l00017ooooo`;o00000oooool2o`0001Oooooo0_l0
0008ooooo`;o00004_ooool2o`0002Kooooo0_l000000ooooooo0000o`00000Uooooo`;o0000DOoo
ool2o`0000_ooooo000Yooooo`03o`000?oooooooooo00Gooooo0_l00017ooooo`;o00000oooool2
o`0001Oooooo0_l0000Looooo`;o0000:?ooool3o`0000[ooooo0_l0000Iooooo`;o000000?ooooo
o`000?l000002oooool2o`0000?ooooo0ol0000Eooooo`;o0000<Oooool002Wooooo00?o0000oooo
ooooool08_ooool2o`0004gooooo0_l000000ooooooo0000o`00000Kooooo`;o00008Oooool2o`00
00_ooooo0_l0000Iooooo`;o000000?oooooo`000?l000002oooool2o`0000?ooooo0ol0000Eoooo
o`;o0000<Oooool002Wooooo0_l0000=ooooo`;o00005?ooool2o`00013ooooo0_l0000[ooooo`;o
00003_ooool2o`000003ooooool0003o000000cooooo0_l0000=ooooo`;o00009_ooool2o`0002co
oooo0_l0001Cooooo`00:Oooool00ol0003oooooooooo`0<ooooo`;o00001oooool2o`0001gooooo
0_l0000[ooooo`;o00002oooool2o`0001;ooooo0_l0000eooooo`;o00001oooool2o`0001Wooooo
0_l00008ooooo`;o0000=oooool2o`0001[ooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01Go
oooo0_l0000`ooooo`;o00009Oooool2o`0000Gooooo0_l0000Cooooo`;o00000_ooool2o`0000Oo
oooo0_l0000Yooooo`;o00006Oooool2o`0000cooooo0_l0000Hooooo`;o00004oooool2o`0000Co
oooo0_l0000Jooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0Aoooool2o`0002Wooooo0_l000000ooooooo
0000o`00000Cooooo`;o00000_ooool2o`0000Oooooo0_l0001Booooo`;o00003Oooool2o`0000Co
oooo0_l00003ooooo`;o00004oooool2o`00023ooooo000>ooooo`05oa0@4?ooooooooooooooool@
41004?ooool00ol0003oooooooooo`03ooooo`?o0000FOooool2o`0001Oooooo0_l0001:ooooo`;o
0000>_ooool2o`0000Cooooo0_l0000jooooo`003_ooool01Ol0003ooooooooooooooooo000000oo
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1Iooooo`;o0000Hoooool2o`0007co
oooo000>ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`00
0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`00
0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000
o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@
41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgo
oooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooo
oooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@
00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooo
oooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool0
00Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`007oooool4o`000003oa0@
4?oooooooooo00?ooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool3
o`000?oooooo?Oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`007oooool00omEEEGoIVIVo`00003oooooodOooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .27861 Mdot
.02762 .34953 Mdot
.02952 .30321 Mdot
.03143 .32756 Mdot
.03333 .30056 Mdot
.03524 .25916 Mdot
.03714 .30329 Mdot
.03905 .31782 Mdot
.04095 .26018 Mdot
.04286 .2729 Mdot
.04476 .32666 Mdot
.04667 .36532 Mdot
.04857 .40605 Mdot
.05048 .29605 Mdot
.05238 .39275 Mdot
.05429 .28202 Mdot
.05619 .37812 Mdot
.0581 .40774 Mdot
.06 .35521 Mdot
.0619 .38981 Mdot
.06381 .41049 Mdot
.06571 .38422 Mdot
.06762 .39716 Mdot
.06952 .4113 Mdot
.07143 .4211 Mdot
.07333 .26347 Mdot
.07524 .34645 Mdot
.07714 .35302 Mdot
.07905 .3741 Mdot
.08095 .36132 Mdot
.08286 .41087 Mdot
.08476 .2495 Mdot
.08667 .31299 Mdot
.08857 .36389 Mdot
.09048 .35025 Mdot
.09238 .38434 Mdot
.09429 .26062 Mdot
.09619 .35457 Mdot
.0981 .33911 Mdot
.1 .36629 Mdot
.1019 .41313 Mdot
.10381 .35951 Mdot
.10571 .3027 Mdot
.10762 .27566 Mdot
.10952 .24888 Mdot
.11143 .25631 Mdot
.11333 .30563 Mdot
.11524 .22845 Mdot
.11714 .33606 Mdot
.11905 .3623 Mdot
.12095 .22894 Mdot
.12286 .32771 Mdot
.12476 .35852 Mdot
.12667 .32003 Mdot
.12857 .33008 Mdot
.13048 .28795 Mdot
.13238 .32913 Mdot
.13429 .37929 Mdot
.13619 .23515 Mdot
.1381 .24374 Mdot
.14 .24969 Mdot
.1419 .4625 Mdot
.14381 .32752 Mdot
.14571 .30209 Mdot
.14762 .33485 Mdot
.14952 .26237 Mdot
.15143 .27207 Mdot
.15333 .28186 Mdot
.15524 .35598 Mdot
.15714 .41405 Mdot
.15905 .38231 Mdot
.16095 .26887 Mdot
.16286 .28411 Mdot
.16476 .25766 Mdot
.16667 .32745 Mdot
.16857 .27337 Mdot
.17048 .35803 Mdot
.17238 .26062 Mdot
.17429 .34138 Mdot
.17619 .34311 Mdot
.1781 .40544 Mdot
.18 .36111 Mdot
.1819 .33104 Mdot
.18381 .35956 Mdot
.18571 .29306 Mdot
.18762 .28909 Mdot
.18952 .29581 Mdot
.19143 .26272 Mdot
.19333 .37771 Mdot
.19524 .27729 Mdot
.19714 .42471 Mdot
.19905 .43349 Mdot
.20095 .32768 Mdot
.20286 .26485 Mdot
.20476 .32268 Mdot
.20667 .44617 Mdot
.20857 .29303 Mdot
.21048 .23471 Mdot
.21238 .35227 Mdot
.21429 .37783 Mdot
.21619 .29809 Mdot
.2181 .37078 Mdot
.22 .37198 Mdot
.2219 .29454 Mdot
.22381 .41394 Mdot
.22571 .36051 Mdot
.22762 .38088 Mdot
.22952 .35189 Mdot
.23143 .32806 Mdot
.23333 .4139 Mdot
.23524 .28082 Mdot
.23714 .33367 Mdot
.23905 .24948 Mdot
.24095 .39573 Mdot
.24286 .24362 Mdot
.24476 .32846 Mdot
.24667 .24944 Mdot
.24857 .25834 Mdot
.25048 .25136 Mdot
.25238 .25149 Mdot
.25429 .40647 Mdot
.25619 .45628 Mdot
.2581 .40677 Mdot
.26 .37541 Mdot
.2619 .41421 Mdot
.26381 .31738 Mdot
.26571 .38646 Mdot
.26762 .45419 Mdot
.26952 .34438 Mdot
.27143 .30059 Mdot
.27333 .39402 Mdot
.27524 .32004 Mdot
.27714 .38453 Mdot
.27905 .26156 Mdot
.28095 .28579 Mdot
.28286 .35995 Mdot
.28476 .29202 Mdot
.28667 .3775 Mdot
.28857 .28313 Mdot
.29048 .33787 Mdot
.29238 .39254 Mdot
.29429 .46171 Mdot
.29619 .34018 Mdot
.2981 .35687 Mdot
.3 .37844 Mdot
.3019 .39413 Mdot
.30381 .27882 Mdot
.30571 .21794 Mdot
.30762 .33394 Mdot
.30952 .25796 Mdot
.31143 .44836 Mdot
.31333 .36672 Mdot
.31524 .35111 Mdot
.31714 .41171 Mdot
.31905 .2724 Mdot
.32095 .2404 Mdot
.32286 .29556 Mdot
.32476 .32867 Mdot
.32667 .26605 Mdot
.32857 .25539 Mdot
.33048 .29492 Mdot
.33238 .29508 Mdot
.33429 .34699 Mdot
.33619 .39652 Mdot
.3381 .39152 Mdot
.34 .2896 Mdot
.3419 .30197 Mdot
.34381 .27722 Mdot
.34571 .41391 Mdot
.34762 .35551 Mdot
.34952 .31059 Mdot
.35143 .36573 Mdot
.35333 .33628 Mdot
.35524 .35359 Mdot
.35714 .28384 Mdot
.35905 .33276 Mdot
.36095 .32747 Mdot
.36286 .44826 Mdot
.36476 .24047 Mdot
.36667 .32594 Mdot
.36857 .36145 Mdot
.37048 .32802 Mdot
.37238 .3833 Mdot
.37429 .25965 Mdot
.37619 .41675 Mdot
.3781 .27248 Mdot
.38 .26226 Mdot
.3819 .45207 Mdot
.38381 .23807 Mdot
.38571 .39401 Mdot
.38762 .29839 Mdot
.38952 .44996 Mdot
.39143 .39538 Mdot
.39333 .28624 Mdot
.39524 .46017 Mdot
.39714 .30691 Mdot
.39905 .42556 Mdot
.40095 .37678 Mdot
.40286 .26916 Mdot
.40476 .42734 Mdot
.40667 .37952 Mdot
.40857 .32566 Mdot
.41048 .32623 Mdot
.41238 .26759 Mdot
.41429 .29497 Mdot
.41619 .41798 Mdot
.4181 .31416 Mdot
.42 .26578 Mdot
.4219 .24834 Mdot
.42381 .33841 Mdot
.42571 .26644 Mdot
.42762 .32697 Mdot
.42952 .39457 Mdot
.43143 .25627 Mdot
.43333 .41352 Mdot
.43524 .2613 Mdot
.43714 .30785 Mdot
.43905 .25324 Mdot
.44095 .40032 Mdot
.44286 .27714 Mdot
.44476 .24678 Mdot
.44667 .35304 Mdot
.44857 .24862 Mdot
.45048 .22972 Mdot
.45238 .41533 Mdot
.45429 .39946 Mdot
.45619 .26432 Mdot
.4581 .32003 Mdot
.46 .33274 Mdot
.4619 .33437 Mdot
.46381 .39324 Mdot
.46571 .45784 Mdot
.46762 .30241 Mdot
.46952 .31574 Mdot
.47143 .407 Mdot
.47333 .36114 Mdot
.47524 .34313 Mdot
.47714 .45382 Mdot
.47905 .35458 Mdot
.48095 .30353 Mdot
.48286 .40564 Mdot
.48476 .31267 Mdot
.48667 .46229 Mdot
.48857 .28232 Mdot
.49048 .41251 Mdot
.49238 .38225 Mdot
.49429 .244 Mdot
.49619 .32143 Mdot
.4981 .28581 Mdot
.5 .37487 Mdot
.5019 .38212 Mdot
.50381 .33088 Mdot
.50571 .42415 Mdot
.50762 .32835 Mdot
.50952 .29236 Mdot
.51143 .26974 Mdot
.51333 .27676 Mdot
.51524 .35293 Mdot
.51714 .33091 Mdot
.51905 .27336 Mdot
.52095 .3301 Mdot
.52286 .2295 Mdot
.52476 .34952 Mdot
.52667 .34274 Mdot
.52857 .39753 Mdot
.53048 .31657 Mdot
.53238 .36704 Mdot
.53429 .27131 Mdot
.53619 .3166 Mdot
.5381 .25801 Mdot
.54 .37479 Mdot
.5419 .30379 Mdot
.54381 .3879 Mdot
.54571 .32728 Mdot
.54762 .26738 Mdot
.54952 .3458 Mdot
.55143 .3025 Mdot
.55333 .2589 Mdot
.55524 .34132 Mdot
.55714 .23112 Mdot
.55905 .31934 Mdot
.56095 .24134 Mdot
.56286 .35653 Mdot
.56476 .30863 Mdot
.56667 .25693 Mdot
.56857 .25271 Mdot
.57048 .36152 Mdot
.57238 .3517 Mdot
.57429 .28331 Mdot
.57619 .30334 Mdot
.5781 .40599 Mdot
.58 .25546 Mdot
.5819 .4067 Mdot
.58381 .45065 Mdot
.58571 .23452 Mdot
.58762 .37864 Mdot
.58952 .23095 Mdot
.59143 .31848 Mdot
.59333 .24915 Mdot
.59524 .45754 Mdot
.59714 .41156 Mdot
.59905 .38833 Mdot
.60095 .21577 Mdot
.60286 .33536 Mdot
.60476 .31218 Mdot
.60667 .32032 Mdot
.60857 .24669 Mdot
.61048 .41385 Mdot
.61238 .30991 Mdot
.61429 .23231 Mdot
.61619 .28185 Mdot
.6181 .31828 Mdot
.62 .39553 Mdot
.6219 .3783 Mdot
.62381 .40524 Mdot
.62571 .44513 Mdot
.62762 .32609 Mdot
.62952 .25418 Mdot
.63143 .36053 Mdot
.63333 .34409 Mdot
.63524 .31877 Mdot
.63714 .38829 Mdot
.63905 .44755 Mdot
.64095 .46459 Mdot
.64286 .30544 Mdot
.64476 .26468 Mdot
.64667 .36123 Mdot
.64857 .31431 Mdot
.65048 .32471 Mdot
.65238 .32127 Mdot
.65429 .3131 Mdot
.65619 .38073 Mdot
.6581 .33988 Mdot
.66 .26668 Mdot
.6619 .3197 Mdot
.66381 .38928 Mdot
.66571 .29964 Mdot
.66762 .26757 Mdot
.66952 .33665 Mdot
.67143 .2671 Mdot
.67333 .28941 Mdot
.67524 .29655 Mdot
.67714 .29862 Mdot
.67905 .37893 Mdot
.68095 .29003 Mdot
.68286 .35764 Mdot
.68476 .3072 Mdot
.68667 .30533 Mdot
.68857 .34434 Mdot
.69048 .37892 Mdot
.69238 .37667 Mdot
.69429 .3363 Mdot
.69619 .24963 Mdot
.6981 .46245 Mdot
.7 .35897 Mdot
.7019 .25644 Mdot
.70381 .38314 Mdot
.70571 .32357 Mdot
.70762 .37715 Mdot
.70952 .37177 Mdot
.71143 .36393 Mdot
.71333 .35976 Mdot
.71524 .46734 Mdot
.71714 .41185 Mdot
.71905 .3843 Mdot
.72095 .39178 Mdot
.72286 .41058 Mdot
.72476 .27118 Mdot
.72667 .35535 Mdot
.72857 .39513 Mdot
.73048 .32802 Mdot
.73238 .27339 Mdot
.73429 .41029 Mdot
.73619 .30057 Mdot
.7381 .25078 Mdot
.74 .29248 Mdot
.7419 .23971 Mdot
.74381 .3037 Mdot
.74571 .25209 Mdot
.74762 .28353 Mdot
.74952 .39551 Mdot
.75143 .2692 Mdot
.75333 .3929 Mdot
.75524 .41258 Mdot
.75714 .23292 Mdot
.75905 .24115 Mdot
.76095 .23996 Mdot
.76286 .27242 Mdot
.76476 .43896 Mdot
.76667 .37624 Mdot
.76857 .31467 Mdot
.77048 .3837 Mdot
.77238 .41435 Mdot
.77429 .31888 Mdot
.77619 .26141 Mdot
.7781 .25686 Mdot
.78 .34677 Mdot
.7819 .22878 Mdot
.78381 .418 Mdot
.78571 .45933 Mdot
.78762 .38584 Mdot
.78952 .37475 Mdot
.79143 .37897 Mdot
.79333 .37536 Mdot
.79524 .33651 Mdot
.79714 .33405 Mdot
.79905 .29651 Mdot
.80095 .33912 Mdot
.80286 .36409 Mdot
.80476 .34543 Mdot
.80667 .33695 Mdot
.80857 .33672 Mdot
.81048 .27475 Mdot
.81238 .43811 Mdot
.81429 .27394 Mdot
.81619 .3959 Mdot
.8181 .33899 Mdot
.82 .35234 Mdot
.8219 .31319 Mdot
.82381 .28283 Mdot
.82571 .36677 Mdot
.82762 .34588 Mdot
.82952 .26843 Mdot
.83143 .45292 Mdot
.83333 .33454 Mdot
.83524 .3092 Mdot
.83714 .34639 Mdot
.83905 .38073 Mdot
.84095 .24788 Mdot
.84286 .30971 Mdot
.84476 .35441 Mdot
.84667 .43859 Mdot
.84857 .44518 Mdot
.85048 .31792 Mdot
.85238 .2737 Mdot
.85429 .28047 Mdot
.85619 .27108 Mdot
.8581 .28066 Mdot
.86 .39947 Mdot
.8619 .33316 Mdot
.86381 .37909 Mdot
.86571 .37309 Mdot
.86762 .33823 Mdot
.86952 .3117 Mdot
.87143 .32417 Mdot
.87333 .40071 Mdot
.87524 .3318 Mdot
.87714 .43017 Mdot
.87905 .26815 Mdot
.88095 .3308 Mdot
.88286 .36524 Mdot
.88476 .3116 Mdot
.88667 .32466 Mdot
.88857 .25577 Mdot
.89048 .3203 Mdot
.89238 .32526 Mdot
.89429 .35126 Mdot
.89619 .33688 Mdot
.8981 .25327 Mdot
.9 .38811 Mdot
.9019 .40805 Mdot
.90381 .37763 Mdot
.90571 .45981 Mdot
.90762 .26309 Mdot
.90952 .34195 Mdot
.91143 .42223 Mdot
.91333 .3197 Mdot
.91524 .25204 Mdot
.91714 .30732 Mdot
.91905 .37662 Mdot
.92095 .3813 Mdot
.92286 .29564 Mdot
.92476 .35249 Mdot
.92667 .24953 Mdot
.92857 .36696 Mdot
.93048 .46261 Mdot
.93238 .27856 Mdot
.93429 .27473 Mdot
.93619 .3028 Mdot
.9381 .34268 Mdot
.94 .26838 Mdot
.9419 .29361 Mdot
.94381 .32493 Mdot
.94571 .29728 Mdot
.94762 .32757 Mdot
.94952 .27185 Mdot
.95143 .26445 Mdot
.95333 .30881 Mdot
.95524 .26436 Mdot
.95714 .35744 Mdot
.95905 .34874 Mdot
.96095 .28441 Mdot
.96286 .25598 Mdot
.96476 .29049 Mdot
.96667 .34327 Mdot
.96857 .23 Mdot
.97048 .39211 Mdot
.97238 .35614 Mdot
.97429 .37132 Mdot
.97619 .37708 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0001Hooooo`;o0000GOooool2
o`0008Cooooo000Yooooo`03o`000?oooooooooo05Oooooo0_l0001Mooooo`;o0000Q?ooool000Ko
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0004o`0000;ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Jooooo`Co0000Ioooool2o`0001Kooooo0_l0000Cooooo`;o0000??oo
ool2o`0003[ooooo0_l0000>ooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o00006_ooool4o`0006Oooooo0_l0
000Fooooo`;o00002Oooool2o`0000Sooooo0_l00006ooooo`;o0000;?ooool2o`0000Kooooo0_l0
000jooooo`;o00003_ooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo023ooooo
0_l0000Fooooo`;o0000K_ooool2o`0000Oooooo0_l00007ooooo`;o0000;?ooool2o`0005;ooooo
0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool08?ooool2o`0001Kooooo0_l0000Rooooo`;o0000
4_ooool2o`0003oooooo0_l0000`ooooo`;o00001?ooool2o`00057ooooo0006ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`1Looooo`;o00003?ooool2o`0000Cooooo0_l0000gooooo`;o
0000>?ooool2o`0000Cooooo0_l0001Aooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`0Qoooo
o`;o00008?ooool2o`0002Gooooo0_l0000Xooooo`;o00004oooool2o`0003kooooo0_l0001Aoooo
o`00:Oooool2o`00017ooooo0_l00006ooooo`;o00001oooool3o`0001gooooo1Ol0000fooooo`;o
00001_ooool3o`0000gooooo0_l0000Mooooo`;o00000oooool2o`0001[ooooo0_l0000]ooooo`;o
00006_ooool2o`0001_ooooo000Yooooo`03o`000?oooooooooo013ooooo0_l00006ooooo`;o0000
2?ooool2o`0001gooooo0_l000000ooooooo0000o`000002o`0003Cooooo0_l00006ooooo`?o0000
9?ooool2o`0000Kooooo0_l00003ooooo`;o00006_ooool2o`0000cooooo1?l0000Mooooo`;o0000
5_ooool2o`0000;ooooo0_l0000Kooooo`00:Oooool00ol0003oooooooooo`15ooooo`?o00005_oo
ool2o`0002;ooooo0_l0000Wooooo`;o00000_ooool2o`0000kooooo0_l0000Qooooo`Co0000;?oo
ool2o`000003ooooool0003o000000Cooooo0_l0000Oooooo`00:Oooool00ol0003oooooooooo`0H
ooooo`;o00004?ooool2o`0001Wooooo0_l0000Aooooo`;o00001?ooool2o`0001oooooo0_l00000
0ooooooo0000o`00000Nooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`;o00003_ooool2
o`0001Gooooo0_l0000Gooooo`;o00008Oooool2o`000003ooooool0003o000001?ooooo0_l0000@
ooooo`00:Oooool00ol0003oooooooooo`04o`0000oooooo0_l00003ooooo`;o00004?ooool4o`00
01Oooooo0_l00007ooooo`;o00002?ooool2o`0001?ooooo0_l0000@ooooo`Co00007oooool2o`00
00?ooooo0_l00002ooooo`;o0000:Oooool2o`0001Kooooo0ol0000iooooo`;o00004?ooool002Wo
oooo0_l000000ooooooo0000o`000002o`0000Sooooo0_l00005ooooo`;o00004?ooool2o`0000Go
oooo0_l00004ooooo`;o00000_ooool2o`0001Kooooo0_l0000Mooooo`Co00004?ooool2o`0000Co
oooo0_l0000kooooo`;o0000:?ooool2o`0002Sooooo0_l0000=ooooo`?o00004_ooool002Wooooo
00?o0000ooooooooool03?ooool2o`0001Oooooo0_l0000;ooooo`;o00000_ooool2o`0002Kooooo
0_l0000?ooooo`;o00002?ooool2o`000004ooooool0003o0000o`0000Sooooo0_l0000Looooo`;o
00007Oooool2o`0000?ooooo1_l00010ooooo`;o00001oooool2o`0000Wooooo0_l00002ooooo`?o
00004_ooool002Wooooo00?o0000ooooooooool0:?ooool2o`0000Kooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo0_l0
000=ooooo`Go00000oooool01?o^k^ko0000o`000?lb<S82o`000003ooooool0003o000000;o0000
00?o<S8bonk^k_ooool05_ooool2o`0000Gooooo0_l00003ooooo`;o00000oooool01OnHV9So410@
o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02_ooool6o`0000oooooo0_l00006ooooo`;o000000Coooooo`000?l0003o410@0ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`;o
00001oooool2o`0000Gooooo0_l0000Booooo`;o000000GoA4A4o`000?l0003o<S8bomgMg@02oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Y
ooooo`03o`000?oooooooooo00;ooooo0_l0000Qooooo`;o000000Coooooo`000?l0003ooooo0_l0
0005ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL05oooool2o`00013ooooo00GoV9RHo`000?l0003oooooodA4A003oooo
o`05ogMgMol0003o0000oiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01Oooooo0_l0
00000ooooooo0000o`000002ooooo`;o00002?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07oooool4o`00
00Cooooo0_l00002ooooo`;o00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?oMgMg
oiRHV?ooool00_l00003ooooo`;o00001_ooool3o`0001cooooo0_l000002OmgMgOo<S8boooooooo
ooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wo
oooo00?o0000ooooooooool00_ooool2o`0001?ooooo0_l0000<ooooo`;o00001?ooool2o`0000Go
oooo0ol00002ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo
410@01Oooooo0_l00006ooooo`;o00002Oooool2o`000003onk^k_oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@4003ooooo`06oa0@4?ooooooooooooooool@413ooooo0_l0000Eooooo`Co
00004?ooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01oooooo0_l00005ooooo`Go00000oooool01Ol@413ooooooooooooo
oooo410@00?ooooo00?o410@ooooool000000_l0000;ooooo`;o00006?ooool2o`0000?ooooo0_l0
00001Ooooooo0000oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo007ooooo000Yooooo`;o00006?ooool2o`0001Wooooo0ol00002ooooo`05o`00
0?ooooooooooooooool000000oooool3o`000003ooooool0003ooooo017ooooo0_l0000;ooooo`;o
00002_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000000oooool01_l0
003ooooooooooooooooo0000ooooo`;o00005Oooool2o`00017ooooo00?oZJVYoa0@4?ooool00_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00000Xooooo`04
odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
000000;o00002oooool4o`0001Gooooo0ol00005ooooo`05ogMgMolb<S;oooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00Oooool002Wooooo0_l0
0007ooooo`;o00007_ooool2o`0000[ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000?ooooo0ol000000ooooooo0000ooooo`0<ooooo`;o00000oooool2o`0000oooooo
0_l00007ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000004?ooool2o`0001Sooooo00?o410@o`000?l000000oooool01Ol0
003ooooooooooooooooo000000?ooooo0ol000000ooooooo0000ooooo`0Uooooo`;o000000CogMgM
oeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000002ooooo`;o00001oooool4o`0001Gooooo0_l00003ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`00:Oooool00ol0003oooooooooo`06ooooo`;o00007_ooool2o`000003ooooool0003o
000000Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@400;ooooo`Co00005?ooool2o`0000Sooooo00Go0000ooooool0003o
0000oa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`0>oooo
o`;o000000?oooooo`000?l000005_ooool2o`0000?ooooo00Go410@oooooooooooooooooa0@4003
ooooo`05oa0@4?l0003o0000ooooool@41009_ooool2o`000004oooooomgMgOoc<c<o`0000Cooooo
00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000_ooool2o`00
02Gooooo00?o0000ooooooooool00_ooool2o`000005oa0@4?ooooooooooooooool@41000oooool0
1Ol@413ooooooooooooooooo410@00?ooooo000Yooooo`03o`000?oooooooooo01oooooo0_l00008
ooooo`;o00001_ooool2o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool2o`00017ooooo0_l00009ooooo`06o`000?nj^[[ooooooiRHV?l@
413ooooo0_l000001OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Cooooo`;o00004oooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool2o`000003ooooool0003o0000
01Kooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0Yooooo`03o`000?oooooooooo00;ooooo0_l000001OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool00ol0003ooooo
ooooo`0Oooooo`;o00003oooool3o`0000Cooooo00Gok^k^o`000?l0003o<S8bonk^kP03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool2o`00013ooooo0_l00009ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0Fooooo`;o00004?ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool2o`000003ooooool0003o
0000017ooooo0_l00004ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:Oooool4o`0000;ooooo0_l000001?lb<S;o0000
oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool002Wooooo0_l00006ooooo`;o
0000:Oooool4o`0000Cooooo0_l00002ooooo`;o00004_ooool2o`0000[ooooo0_l000000ooooooo
0000o`00000Iooooo`;o00007?ooool2o`0004Wooooo0_l0000hooooo`;o00001?ooool2o`0000Ko
oooo0_l0000?ooooo`00:Oooool00ol0003oooooooooo`05ooooo`;o0000:oooool2o`0000Kooooo
1?l0000Nooooo`;o000000?oooooo`000?l000004?ooool2o`0000Oooooo0_l0001Booooo`;o0000
9_ooool2o`0002Gooooo0_l00004ooooo`Co00005Oooool002Wooooo00Co0000ooooool0003o0000
8_ooool2o`0001Gooooo0_l0000@ooooo`;o00005Oooool2o`0000cooooo0_l0000Hooooo`;o0000
6Oooool2o`0002?ooooo0_l000000ooooooo0000o`00000Aooooo`;o00004oooool2o`0002gooooo
0_l0000Eooooo`00:Oooool6o`0001Cooooo1?l00008ooooo`;o00009oooool2o`0001Gooooo0_l0
000Vooooo`;o00000_ooool2o`0001;ooooo0_l000000ooooooo0000o`000006ooooo`;o00004ooo
ool2o`0000Kooooo0_l00004ooooo`;o00003_ooool2o`000003ooooool0003o000003cooooo0_l0
000Hooooo`00:Oooool3o`000003ooooool0003o000001Cooooo1?l0001Iooooo`;o00002oooool2
o`0000cooooo0_l0000Booooo`;o00001Oooool2o`0000;ooooo0_l0000Cooooo`;o00003?ooool2
o`00017ooooo0_l0000fooooo`;o00001?ooool2o`0000?ooooo0_l0000Cooooo`008Oooooooo`00
04Co00001?ooool002Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`;o
00001?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`03ooooo`;o00001?ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00;o00001oooool00ol0003oooooooooo`09ooooo`;o00002_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00Go0000ooooool0003o0000ooooo`02o`00
00Gooooo00Co0000oooooooooooooooo1?l00004ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`03ooooo`;o00001?ooool00ol0003oooooooooo`08
ooooo`;o00000_ooool2o`000003ooooool0003o000000Gooooo0ol00003ooooo`;o00001?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
02Wooooo00Co0000oooooooooooooooo0_l0000=ooooo`;o0000:?ooool00ol0003oooooooooo`0<
ooooo`;o0000;Oooool00ol0003oooooooooo`02o`0000oooooo0_l00002ooooo`;o00003Oooool4
o`0001;ooooo00Co0000ooooool0003o00003?ooool4o`0002?ooooo0_l00004ooooo`03o`000?oo
oooooooo00Sooooo0_l00007ooooo`;o00009oooool00ol0003oooooooooo`0:ooooo`00:Oooool0
1?l0003oooooooooooooool2o`0001[ooooo0_l0000Zooooo`;o00000_ooool2o`0003Wooooo0_l0
0002ooooo`;o00004Oooool4o`0000Gooooo0_l00009ooooo`;o00000oooool2o`000003ooooool0
003o000000Cooooo0_l00006ooooo`;o00008oooool2o`0001Kooooo0_l0000;ooooo`;o00001Ooo
ool2o`00023ooooo000Yooooo`03o`000?oooooooooo01gooooo0_l0000Gooooo`;o00005Oooool2
o`0003Wooooo0_l0000:ooooo`;o00004_ooool2o`0000Wooooo0_l00003ooooo`;o000000?ooooo
o`000?l000001?ooool2o`0000?ooooo0_l000000ooooooo0000o`00000=ooooo`;o00005?ooool2
o`0001gooooo0_l00004ooooo`;o00001Oooool2o`00023ooooo000Yooooo`;o00001?ooool2o`00
02Gooooo0_l0000:ooooo`;o0000<Oooool4o`0000_ooooo0ol00003ooooo`;o00005?ooool2o`00
00kooooo0_l0000Hooooo`;o00001_ooool2o`00013ooooo0_l0000cooooo`;o00000oooool4o`00
00kooooo0_l0000Fooooo`00:Oooool01?l0003oooooo`000?l00002ooooo`;o00005oooool5o`00
00;ooooo0_l00005ooooo`;o00002Oooool2o`0000Sooooo0_l00002ooooo`;o00006?ooool2o`00
00[ooooo1Ol0000:ooooo`?o00000oooool2o`0001Sooooo0_l00002ooooo`;o00001_ooool2o`00
01Sooooo0_l00006ooooo`;o00005oooool2o`00037ooooo1?l0000>ooooo`?o00005Oooool002Wo
oooo00Co0000ooooool0003o00006oooool5o`0000;ooooo0_l0000:ooooo`;o00001?ooool2o`00
00Sooooo1_l0000Hooooo`;o00002Oooool2o`0000;ooooo0_l0000Kooooo`;o00003?ooool3o`00
0004ooooool0003o0000o`00047ooooo0_l0000Yooooo`;o00000_ooool4o`0001?ooooo0_l0000E
ooooo`00:Oooool00ol0003oooooooooo`0Jooooo`;o00002?ooool2o`0000Wooooo0_l0000@oooo
o`;o00005Oooool2o`0000cooooo1?l0000Oooooo`;o00003?ooool2o`0000;ooooo0_l0000Ioooo
o`;o00005?ooool2o`0000Kooooo0_l0000Nooooo`?o00000_ooool2o`0000Kooooo0_l00007oooo
o`;o00000_ooool4o`0002[ooooo000Yooooo`03o`000?oooooooooo01Cooooo0_l00004ooooo`;o
00002?ooool2o`0002cooooo0_l00004ooooo`;o00003?ooool2o`0001Gooooo0_l0000:ooooo`;o
0000:oooool2o`00013ooooo0_l00002ooooo`;o00001_ooool2o`0001kooooo1ol000000ooooooo
0000o`000003ooooo`;o00002Oooool2o`0000Oooooo0_l0000Uooooo`00:Oooool2o`0001Gooooo
0_l0000Gooooo`;o00008oooool4o`0002Oooooo0_l0000Oooooo`;o00001oooool2o`0001oooooo
0_l0000/ooooo`Co00000_ooool2o`0000kooooo0_l00007ooooo`;o00000_ooool2o`0000Oooooo
0_l0000Hooooo`00:Oooool00ol0003oooooooooo`0]ooooo`;o00007?ooool2o`0000Oooooo0_l0
000gooooo`;o00003oooool2o`0000Gooooo1?l0000Gooooo`;o00004?ooool2o`0002?ooooo0_l0
0006ooooo`;o00006?ooool2o`0000Oooooo0_l00007ooooo`;o00003oooool002Wooooo00?o0000
ooooooooool03Oooool2o`0001kooooo0_l0000Looooo`;o00004oooool2o`0002_ooooo0_l0000F
ooooo`;o00006Oooool2o`00013ooooo0_l0000Kooooo`;o00001_ooool2o`0000Kooooo0_l00000
0ooooooo0000o`00000Uooooo`Co00003oooool002Wooooo0_l0000>ooooo`;o00000oooool2o`00
02Gooooo0_l00003ooooo`;o00006_ooool2o`0000Cooooo0_l0000kooooo`;o00003_ooool2o`00
043ooooo0_l0000;ooooo`;o00001?ooool2o`00013ooooo0_l0000Cooooo`;o00004Oooool002Wo
oooo0_l00009ooooo`;o00000oooool2o`0000?ooooo1?l0000Sooooo`;o00000oooool2o`0001[o
oooo0_l0000;ooooo`;o00006oooool2o`0000Wooooo0_l00009ooooo`;o000000?oooooo`000?l0
00003_ooool2o`0002oooooo0_l0000Looooo`;o00001_ooool2o`0000kooooo0_l00008ooooo`;o
00007?ooool002Wooooo0_l00009ooooo`;o00000oooool2o`0000Gooooo0_l00007ooooo`;o0000
2?ooool2o`0000;ooooo0_l0000Wooooo`;o00003_ooool2o`000003ooooool0003o000001_ooooo
0_l00009ooooo`;o00002Oooool2o`0000kooooo0_l0000Tooooo`;o00003?ooool2o`0002Cooooo
0_l0000Hooooo`;o00002?ooool2o`0000?ooooo0_l0000=ooooo`00:Oooool00ol0003ooooooooo
o`0?ooooo`;o00001Oooool2o`0000Gooooo0_l00008ooooo`;o00000_ooool2o`000003ooooool0
003o000000;o00002oooool2o`00017ooooo0_l00002ooooo`;o00003_ooool2o`0000Gooooo0_l0
000Pooooo`;o00006oooool4o`0001;ooooo0_l00003ooooo`;o00002Oooool2o`0000Cooooo0_l0
0002ooooo`;o0000C?ooool2o`0000?ooooo0_l0000=ooooo`00:Oooool00ol0003oooooooooo`0?
ooooo`Co00000oooool2o`0000?ooooo0_l0000Aooooo`Co00002oooool2o`00017ooooo0_l0000I
ooooo`;o00008?ooool2o`0001gooooo0_l0000Booooo`;o00000oooool2o`0000oooooo0_l00000
1?oooooo0000o`000?l0000Kooooo`;o0000@oooool002Wooooo00?o0000ooooooooool01?ooool2
o`0000_ooooo0_l00002ooooo`;o00001?ooool2o`0003cooooo0_l0000;ooooo`;o0000>?ooool2
o`0003Oooooo0_l0000Looooo`;o00001Oooool2o`00013ooooo0_l0000=ooooo`;o00006oooool0
02Wooooo00?o0000ooooooooool01?ooool2o`0000oooooo0_l0000Tooooo`;o00007?ooool2o`00
00_ooooo0_l0000hooooo`;o0000G?ooool2o`00013ooooo0_l0000=ooooo`;o00006oooool002Wo
oooo0_l0000?ooooo`;o0000:oooool2o`0009cooooo0_l0000`ooooo`;o00008Oooool2o`0000co
oooo000Yooooo`03o`000?oooooooooo00kooooo0_l0000[ooooo`;o00002oooool2o`0002cooooo
0_l0000Mooooo`;o00002oooool2o`0002oooooo0_l00003ooooo`?o00004?ooool2o`0000Gooooo
1?l0000Eooooo`;o00003oooool2o`00013ooooo0ol0000;ooooo`001_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Go
oooo00?o0000ooooooooool01oooool2o`0001Oooooo0_l0000Aooooo`;o00001Oooool2o`0000co
oooo0_l00007ooooo`;o00000_ooool2o`0001oooooo0ol0000Looooo`;o00002oooool2o`0000ko
oooo0_l00009ooooo`;o00004?ooool2o`0000;ooooo0_l00003ooooo`;o00004Oooool2o`0000Go
oooo1?l0000Dooooo`;o00002oooool2o`0000?ooooo0_l0000Aooooo`;o00002oooool000Kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A4
00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`07ooooo`;o00005oooool2o`00
00Kooooo0_l00009ooooo`;o00001Oooool2o`0000;ooooo0_l0000Aooooo`;o00000_ooool2o`00
01Gooooo0_l00009ooooo`;o00006_ooool2o`000003ooooool0003o000001[ooooo0_l00009oooo
o`;o00002Oooool2o`0000Gooooo0_l00002ooooo`;o00000_ooool2o`0001[ooooo0_l0000=oooo
o`;o00001_ooool2o`0000_ooooo0_l00004ooooo`;o00007Oooool000Kooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0:ooooo`;o00001_ooool2o`0001Cooooo0_l0000Dooooo`;o00002_ooool2o`00
00;ooooo0_l0000Looooo`;o00009Oooool2o`000003ooooool0003o0000033ooooo0_l0000=oooo
o`;o00000oooool2o`0000kooooo0_l00004ooooo`;o00003_ooool2o`0001Wooooo0_l0000Moooo
o`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omg
MgOo<S8booooo`04ooooo`?o00002_ooool2o`0000Kooooo0_l0000fooooo`;o00000_ooool2o`00
05?ooooo0_l0000@ooooo`;o00002_ooool2o`0000Oooooo0_l0000@ooooo`;o00003_ooool2o`00
00Cooooo0_l0000Rooooo`;o00009?ooool000Kooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo00Gooooo0_l00002ooooo`;o0000B?ooool2o`0000cooooo0_l00010ooooo`;o00004?ooool2
o`0000[ooooo0_l00007ooooo`;o00004?ooool2o`0003Sooooo0_l0000Eooooo`;o00003Oooool0
00Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`05ooooo`;o00000_ooool2o`0003Oooooo0_l00009
ooooo`;o00001?ooool2o`000003ooooool0003o000000Wooooo0_l0000>ooooo`?o00002oooool2
o`0000Wooooo0_l0000`ooooo`;o00007_ooool2o`000003ooooool0003o000000Gooooo0ol0000B
ooooo`;o0000<?ooool2o`0000gooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0:ooooo`;o0000=_ooool2o`0000Wooooo0_l00007ooooo`;o00002Oooool2o`0000kooooo0ol0
000;ooooo`;o00002Oooool2o`0001?ooooo0_l0000Kooooo`;o00008Oooool2o`0000Gooooo0ol0
000Booooo`;o0000?oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool02_ooool2o`0005Gooooo
0_l0000Oooooo`;o00000oooool2o`0001Kooooo0_l0001Xooooo`;o00000_ooool2o`0002gooooo
000Yooooo`;o0000Poooool2o`0000?ooooo0_l00020ooooo`;o00000_ooool2o`0002gooooo000Y
ooooo`03o`000?oooooooooo00Cooooo0_l000000ooooooo0000o`00000Uooooo`;o00005_ooool4
o`0004;ooooo0_l00002ooooo`;o00007?ooool4o`0000_ooooo0_l0001Hooooo`;o00008oooool0
02Wooooo00?o0000ooooooooool01?ooool2o`000003ooooool0003o000000Co00000_ooool2o`00
01gooooo0_l0000Fooooo`Co0000@_ooool2o`0000;ooooo0_l0000Looooo`Co00002oooool2o`00
01kooooo0_l00002ooooo`;o0000=?ooool2o`0002?ooooo000Yooooo`03o`000?oooooooooo00Wo
oooo1?l00002ooooo`;o00001?ooool2o`00013ooooo0_l0000Dooooo`;o000000?oooooo`000?l0
00001oooool2o`00013ooooo0_l00007ooooo`;o00006_ooool2o`00013ooooo0_l0000Qooooo`;o
00000_ooool2o`00023ooooo1?l00002ooooo`;o00001?ooool2o`0000Cooooo0_l0001=ooooo`00
:Oooool00ol0003oooooooooo`0Eooooo`;o00004?ooool2o`0001Cooooo0_l000000ooooooo0000
o`000007ooooo`;o00004?ooool2o`0000Oooooo0_l00008ooooo`;o00004?ooool2o`0000Cooooo
0_l0000:ooooo`;o00008Oooool2o`0000;ooooo0_l0000Pooooo`;o00002_ooool2o`0000Cooooo
0_l0001=ooooo`00:Oooool2o`0006oooooo0_l0000:ooooo`;o00002_ooool2o`0006Wooooo0_l0
0019ooooo`00:Oooool00ol0003oooooooooo`0<ooooo`;o0000K?ooool2o`0007Gooooo0_l0000W
ooooo`;o00008?ooool002Wooooo00?o0000ooooooooool03?ooool2o`0002Kooooo0_l0000ooooo
o`;o00008?ooool2o`00087ooooo0_l0000Pooooo`00:Oooool00ol0003oooooooooo`0dooooo`;o
0000?oooool4o`0001kooooo0_l0002Sooooo`00:Oooool00ol0003oooooooooo`1gooooo`;o0000
U_ooool2o`0002_ooooo000Yooooo`;o0000=_ooool2o`000=Sooooo0_l0000[ooooo`00:Oooool0
0ol0003oooooooooo`0eooooo`;o0000]?ooool2o`0000gooooo0_l00009ooooo`;o0000=Oooool0
02Wooooo00?o0000ooooooooool0joooool2o`0000gooooo0_l00009ooooo`;o0000=Oooool002Wo
oooo00?o0000ooooooooool0__ooool2o`0004Gooooo0_l0000eooooo`00:Oooool00ol0003ooooo
ooooo`0gooooo`;o00008?ooool2o`0000kooooo0_l0001Cooooo`;o00000_ooool2o`00047ooooo
0_l0000eooooo`00:Oooool2o`0003Sooooo0_l0000Pooooo`;o00003_ooool2o`0000Oooooo0_l0
000looooo`;o00004?ooool2o`0007Sooooo000Yooooo`03o`000?oooooooooo04_ooooo0_l0000R
ooooo`;o000000?oooooo`000?l000006_ooool2o`00023ooooo0_l0001>ooooo`;o0000>_ooool0
00kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0Aoooool2o`0000;ooooo0_l0000Rooooo`;o00006Ooo
ool2o`0000;ooooo0_l0000Tooooo`;o0000B_ooool2o`0003[ooooo000>ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`17ooooo`;o0000:oooool2o`0001Cooooo0_l0000Xooooo`;o0000>oooool2o`0002Gooooo0_l0
000Rooooo`003_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00ooo
ool3o`0002;ooooo0_l0000_ooooo`;o00007oooool2o`0001_ooooo0_l00012ooooo`;o00006_oo
ool2o`0002Gooooo0_l00006ooooo`;o00006_ooool000kooooo00Go0000ooooooooooooooooo`00
000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool08_ooool2o`0002oooooo0_l0
000looooo`;o0000<?ooool2o`00013ooooo0_l00004ooooo`;o0000@oooool2o`0001[ooooo000>
ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool0`oooool2o`0001Kooooo0_l0001Oooooo`003_ooool01Ol@413ooooooooo
oooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo
000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co0000
1_ooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`007oooool4
o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`007oooool00omEEEGoIVIVo`00003oooooodOo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .24515 Mdot
.02762 .25823 Mdot
.02952 .30928 Mdot
.03143 .33904 Mdot
.03333 .35467 Mdot
.03524 .3443 Mdot
.03714 .3191 Mdot
.03905 .22624 Mdot
.04095 .24597 Mdot
.04286 .26646 Mdot
.04476 .26438 Mdot
.04667 .255 Mdot
.04857 .35352 Mdot
.05048 .25457 Mdot
.05238 .29438 Mdot
.05429 .33495 Mdot
.05619 .36004 Mdot
.0581 .35748 Mdot
.06 .34803 Mdot
.0619 .42549 Mdot
.06381 .373 Mdot
.06571 .31215 Mdot
.06762 .34263 Mdot
.06952 .36917 Mdot
.07143 .34094 Mdot
.07333 .26546 Mdot
.07524 .29852 Mdot
.07714 .3479 Mdot
.07905 .42168 Mdot
.08095 .27358 Mdot
.08286 .3923 Mdot
.08476 .25557 Mdot
.08667 .22671 Mdot
.08857 .3797 Mdot
.09048 .38476 Mdot
.09238 .41859 Mdot
.09429 .36288 Mdot
.09619 .33527 Mdot
.0981 .40671 Mdot
.1 .2551 Mdot
.1019 .3242 Mdot
.10381 .38354 Mdot
.10571 .37006 Mdot
.10762 .24585 Mdot
.10952 .27189 Mdot
.11143 .32704 Mdot
.11333 .25514 Mdot
.11524 .30226 Mdot
.11714 .25981 Mdot
.11905 .41592 Mdot
.12095 .29964 Mdot
.12286 .40315 Mdot
.12476 .44486 Mdot
.12667 .37621 Mdot
.12857 .38137 Mdot
.13048 .23049 Mdot
.13238 .22922 Mdot
.13429 .35549 Mdot
.13619 .33377 Mdot
.1381 .28195 Mdot
.14 .31308 Mdot
.1419 .42745 Mdot
.14381 .40076 Mdot
.14571 .26059 Mdot
.14762 .23368 Mdot
.14952 .24348 Mdot
.15143 .26753 Mdot
.15333 .33385 Mdot
.15524 .33173 Mdot
.15714 .3826 Mdot
.15905 .3574 Mdot
.16095 .30639 Mdot
.16286 .25954 Mdot
.16476 .29013 Mdot
.16667 .4007 Mdot
.16857 .29937 Mdot
.17048 .44458 Mdot
.17238 .27088 Mdot
.17429 .40951 Mdot
.17619 .27064 Mdot
.1781 .41137 Mdot
.18 .27381 Mdot
.1819 .33552 Mdot
.18381 .38438 Mdot
.18571 .22784 Mdot
.18762 .33912 Mdot
.18952 .35301 Mdot
.19143 .33226 Mdot
.19333 .34079 Mdot
.19524 .33137 Mdot
.19714 .34823 Mdot
.19905 .47201 Mdot
.20095 .27585 Mdot
.20286 .33555 Mdot
.20476 .27007 Mdot
.20667 .47389 Mdot
.20857 .25526 Mdot
.21048 .28 Mdot
.21238 .44176 Mdot
.21429 .33669 Mdot
.21619 .23893 Mdot
.2181 .31805 Mdot
.22 .26342 Mdot
.2219 .2388 Mdot
.22381 .40237 Mdot
.22571 .38098 Mdot
.22762 .3674 Mdot
.22952 .35461 Mdot
.23143 .27634 Mdot
.23333 .38648 Mdot
.23524 .26029 Mdot
.23714 .33635 Mdot
.23905 .25578 Mdot
.24095 .42312 Mdot
.24286 .36921 Mdot
.24476 .30951 Mdot
.24667 .29405 Mdot
.24857 .24574 Mdot
.25048 .25264 Mdot
.25238 .35332 Mdot
.25429 .35579 Mdot
.25619 .40689 Mdot
.2581 .36986 Mdot
.26 .42272 Mdot
.2619 .38534 Mdot
.26381 .34105 Mdot
.26571 .42211 Mdot
.26762 .4716 Mdot
.26952 .25544 Mdot
.27143 .32935 Mdot
.27333 .33285 Mdot
.27524 .24037 Mdot
.27714 .27935 Mdot
.27905 .34718 Mdot
.28095 .36209 Mdot
.28286 .41782 Mdot
.28476 .38557 Mdot
.28667 .42138 Mdot
.28857 .26014 Mdot
.29048 .23418 Mdot
.29238 .29332 Mdot
.29429 .45299 Mdot
.29619 .31346 Mdot
.2981 .33815 Mdot
.3 .3596 Mdot
.3019 .4249 Mdot
.30381 .23276 Mdot
.30571 .32731 Mdot
.30762 .35742 Mdot
.30952 .32735 Mdot
.31143 .38482 Mdot
.31333 .30769 Mdot
.31524 .30627 Mdot
.31714 .36876 Mdot
.31905 .31242 Mdot
.32095 .30224 Mdot
.32286 .38661 Mdot
.32476 .4022 Mdot
.32667 .24035 Mdot
.32857 .35791 Mdot
.33048 .38649 Mdot
.33238 .24729 Mdot
.33429 .41254 Mdot
.33619 .29401 Mdot
.3381 .41731 Mdot
.34 .36267 Mdot
.3419 .23898 Mdot
.34381 .23364 Mdot
.34571 .40667 Mdot
.34762 .32865 Mdot
.34952 .39588 Mdot
.35143 .41545 Mdot
.35333 .30094 Mdot
.35524 .32207 Mdot
.35714 .34679 Mdot
.35905 .35875 Mdot
.36095 .23003 Mdot
.36286 .47321 Mdot
.36476 .30424 Mdot
.36667 .3135 Mdot
.36857 .41668 Mdot
.37048 .40474 Mdot
.37238 .27626 Mdot
.37429 .3166 Mdot
.37619 .33023 Mdot
.3781 .32001 Mdot
.38 .24475 Mdot
.3819 .47076 Mdot
.38381 .27069 Mdot
.38571 .29056 Mdot
.38762 .36869 Mdot
.38952 .39237 Mdot
.39143 .42523 Mdot
.39333 .26439 Mdot
.39524 .42411 Mdot
.39714 .22592 Mdot
.39905 .34361 Mdot
.40095 .26908 Mdot
.40286 .33869 Mdot
.40476 .47338 Mdot
.40667 .37655 Mdot
.40857 .29385 Mdot
.41048 .29701 Mdot
.41238 .30062 Mdot
.41429 .3516 Mdot
.41619 .4708 Mdot
.4181 .23931 Mdot
.42 .28558 Mdot
.4219 .33164 Mdot
.42381 .33243 Mdot
.42571 .31482 Mdot
.42762 .26416 Mdot
.42952 .32849 Mdot
.43143 .27721 Mdot
.43333 .40726 Mdot
.43524 .31818 Mdot
.43714 .2389 Mdot
.43905 .2837 Mdot
.44095 .30032 Mdot
.44286 .32403 Mdot
.44476 .27714 Mdot
.44667 .24251 Mdot
.44857 .29983 Mdot
.45048 .31422 Mdot
.45238 .40283 Mdot
.45429 .41437 Mdot
.45619 .32111 Mdot
.4581 .35942 Mdot
.46 .24417 Mdot
.4619 .29193 Mdot
.46381 .29501 Mdot
.46571 .40849 Mdot
.46762 .34159 Mdot
.46952 .28255 Mdot
.47143 .46569 Mdot
.47333 .29917 Mdot
.47524 .28851 Mdot
.47714 .40227 Mdot
.47905 .32815 Mdot
.48095 .23751 Mdot
.48286 .36066 Mdot
.48476 .23877 Mdot
.48667 .42905 Mdot
.48857 .36111 Mdot
.49048 .41347 Mdot
.49238 .35711 Mdot
.49429 .26172 Mdot
.49619 .26945 Mdot
.4981 .37973 Mdot
.5 .34146 Mdot
.5019 .35527 Mdot
.50381 .40282 Mdot
.50571 .34183 Mdot
.50762 .30858 Mdot
.50952 .26258 Mdot
.51143 .36891 Mdot
.51333 .25523 Mdot
.51524 .31976 Mdot
.51714 .38304 Mdot
.51905 .29484 Mdot
.52095 .23 Mdot
.52286 .31835 Mdot
.52476 .27673 Mdot
.52667 .2876 Mdot
.52857 .41579 Mdot
.53048 .32684 Mdot
.53238 .31011 Mdot
.53429 .2498 Mdot
.53619 .25835 Mdot
.5381 .34162 Mdot
.54 .41708 Mdot
.5419 .24732 Mdot
.54381 .42091 Mdot
.54571 .38093 Mdot
.54762 .27156 Mdot
.54952 .27289 Mdot
.55143 .39074 Mdot
.55333 .31579 Mdot
.55524 .36132 Mdot
.55714 .28874 Mdot
.55905 .2582 Mdot
.56095 .31548 Mdot
.56286 .41541 Mdot
.56476 .33107 Mdot
.56667 .29586 Mdot
.56857 .35512 Mdot
.57048 .25167 Mdot
.57238 .35538 Mdot
.57429 .31911 Mdot
.57619 .35302 Mdot
.5781 .42217 Mdot
.58 .32447 Mdot
.5819 .40855 Mdot
.58381 .47044 Mdot
.58571 .33145 Mdot
.58762 .27321 Mdot
.58952 .31958 Mdot
.59143 .30389 Mdot
.59333 .35355 Mdot
.59524 .42012 Mdot
.59714 .41902 Mdot
.59905 .28751 Mdot
.60095 .30427 Mdot
.60286 .2602 Mdot
.60476 .37632 Mdot
.60667 .24018 Mdot
.60857 .25852 Mdot
.61048 .3268 Mdot
.61238 .25556 Mdot
.61429 .28557 Mdot
.61619 .25231 Mdot
.6181 .2762 Mdot
.62 .33197 Mdot
.6219 .36346 Mdot
.62381 .35434 Mdot
.62571 .37881 Mdot
.62762 .31748 Mdot
.62952 .26569 Mdot
.63143 .38179 Mdot
.63333 .23883 Mdot
.63524 .32685 Mdot
.63714 .28369 Mdot
.63905 .39302 Mdot
.64095 .4576 Mdot
.64286 .34111 Mdot
.64476 .35024 Mdot
.64667 .38508 Mdot
.64857 .39449 Mdot
.65048 .3612 Mdot
.65238 .27932 Mdot
.65429 .3138 Mdot
.65619 .3641 Mdot
.6581 .23368 Mdot
.66 .36614 Mdot
.6619 .26698 Mdot
.66381 .3195 Mdot
.66571 .32974 Mdot
.66762 .29864 Mdot
.66952 .24668 Mdot
.67143 .35111 Mdot
.67333 .36263 Mdot
.67524 .24708 Mdot
.67714 .35273 Mdot
.67905 .45562 Mdot
.68095 .24952 Mdot
.68286 .26995 Mdot
.68476 .26147 Mdot
.68667 .2271 Mdot
.68857 .29346 Mdot
.69048 .42125 Mdot
.69238 .3002 Mdot
.69429 .29357 Mdot
.69619 .29943 Mdot
.6981 .45197 Mdot
.7 .24834 Mdot
.7019 .36109 Mdot
.70381 .41908 Mdot
.70571 .25133 Mdot
.70762 .37649 Mdot
.70952 .41746 Mdot
.71143 .30401 Mdot
.71333 .2492 Mdot
.71524 .45826 Mdot
.71714 .41466 Mdot
.71905 .27928 Mdot
.72095 .28896 Mdot
.72286 .31815 Mdot
.72476 .28481 Mdot
.72667 .28771 Mdot
.72857 .29774 Mdot
.73048 .22904 Mdot
.73238 .28114 Mdot
.73429 .40309 Mdot
.73619 .24803 Mdot
.7381 .33566 Mdot
.74 .24005 Mdot
.7419 .26997 Mdot
.74381 .23758 Mdot
.74571 .35561 Mdot
.74762 .37727 Mdot
.74952 .33917 Mdot
.75143 .37145 Mdot
.75333 .33125 Mdot
.75524 .32595 Mdot
.75714 .35722 Mdot
.75905 .34091 Mdot
.76095 .30336 Mdot
.76286 .31152 Mdot
.76476 .37348 Mdot
.76667 .33357 Mdot
.76857 .31176 Mdot
.77048 .27629 Mdot
.77238 .38431 Mdot
.77429 .27533 Mdot
.77619 .28112 Mdot
.7781 .27461 Mdot
.78 .29735 Mdot
.7819 .29781 Mdot
.78381 .40232 Mdot
.78571 .42391 Mdot
.78762 .27976 Mdot
.78952 .37379 Mdot
.79143 .45452 Mdot
.79333 .37583 Mdot
.79524 .35879 Mdot
.79714 .36032 Mdot
.79905 .2715 Mdot
.80095 .23354 Mdot
.80286 .2538 Mdot
.80476 .29571 Mdot
.80667 .29857 Mdot
.80857 .27426 Mdot
.81048 .33209 Mdot
.81238 .36643 Mdot
.81429 .34267 Mdot
.81619 .41796 Mdot
.8181 .3236 Mdot
.82 .31116 Mdot
.8219 .32865 Mdot
.82381 .3474 Mdot
.82571 .37818 Mdot
.82762 .29279 Mdot
.82952 .28061 Mdot
.83143 .39673 Mdot
.83333 .23247 Mdot
.83524 .28321 Mdot
.83714 .38449 Mdot
.83905 .36765 Mdot
.84095 .2767 Mdot
.84286 .24824 Mdot
.84476 .32323 Mdot
.84667 .37131 Mdot
.84857 .47594 Mdot
.85048 .23904 Mdot
.85238 .39433 Mdot
.85429 .24318 Mdot
.85619 .27634 Mdot
.8581 .234 Mdot
.86 .30499 Mdot
.8619 .27211 Mdot
.86381 .30555 Mdot
.86571 .45259 Mdot
.86762 .305 Mdot
.86952 .26911 Mdot
.87143 .35809 Mdot
.87333 .41567 Mdot
.87524 .25818 Mdot
.87714 .47289 Mdot
.87905 .31617 Mdot
.88095 .37923 Mdot
.88286 .38372 Mdot
.88476 .26212 Mdot
.88667 .31857 Mdot
.88857 .30432 Mdot
.89048 .22673 Mdot
.89238 .32108 Mdot
.89429 .41396 Mdot
.89619 .24735 Mdot
.8981 .26621 Mdot
.9 .42177 Mdot
.9019 .40496 Mdot
.90381 .36863 Mdot
.90571 .47215 Mdot
.90762 .2781 Mdot
.90952 .23479 Mdot
.91143 .3379 Mdot
.91333 .26025 Mdot
.91524 .35673 Mdot
.91714 .24773 Mdot
.91905 .35708 Mdot
.92095 .42192 Mdot
.92286 .2392 Mdot
.92476 .35188 Mdot
.92667 .29968 Mdot
.92857 .37946 Mdot
.93048 .42125 Mdot
.93238 .35721 Mdot
.93429 .30531 Mdot
.93619 .36936 Mdot
.9381 .2696 Mdot
.94 .29095 Mdot
.9419 .33796 Mdot
.94381 .37808 Mdot
.94571 .36845 Mdot
.94762 .30176 Mdot
.94952 .25887 Mdot
.95143 .24197 Mdot
.95333 .35775 Mdot
.95524 .2552 Mdot
.95714 .32885 Mdot
.95905 .35048 Mdot
.96095 .27086 Mdot
.96286 .38112 Mdot
.96476 .26815 Mdot
.96667 .252 Mdot
.96857 .30061 Mdot
.97048 .41795 Mdot
.97238 .33574 Mdot
.97429 .4198 Mdot
.97619 .26828 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool01?l0003ooooooooo
ooooool2o`0000gooooo0_l0000Nooooo`;o0000@_ooool2o`0005_ooooo0_l00010ooooo`;o0000
9oooool000Co00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0
2Oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00003Oooool2o`0000go
oooo0_l0000?ooooo`;o0000=oooool2o`0000Wooooo0_l0000Vooooo`;o0000<oooool2o`0000co
oooo0_l0000booooo`;o00009oooool000Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03
oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0001oooooo0_l00003ooooo`;o
0000;?ooool2o`0000;ooooo0_l0000;ooooo`;o00001?ooool2o`00037ooooo0_l0000Zooooo`;o
00005Oooool2o`0001Gooooo0_l00009ooooo`;o00001_ooool2o`00037ooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`0Tooooo`;o0000;?ooool2o`0000;ooooo0_l0000;oooo
o`;o0000Hoooool2o`0002cooooo0_l00009ooooo`;o00001_ooool2o`0000kooooo0_l0000Qoooo
o`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo03[ooooo1?l0000?ooooo`;o00003oooool2o`00
00?ooooo0_l0000Fooooo`;o00001?ooool2o`0000cooooo0ol0000Vooooo`;o00001_ooool2o`00
027ooooo0ol0000Pooooo`;o00004Oooool2o`0000;ooooo0_l0000Mooooo`001_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool09Oooool2o`0001?ooooo1?l0000?ooooo`;o00003oooool2
o`0000?ooooo0_l0000Fooooo`;o00001?ooool2o`000003ooooool0003o000000Wooooo0ol0000V
ooooo`;o00001_ooool2o`00027ooooo0ol0000Pooooo`?o00005?ooool2o`0000Sooooo0_l0000C
ooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c004ooooo`Co00001_ooool2o`0000?ooooo0_l0000Cooooo`;o00003?ooool2o`0001kooooo0_l0
000Xooooo`;o00004oooool2o`0000?ooooo0_l0001looooo`;o00007_ooool2o`0001?ooooo000Y
ooooo`;o00000oooool2o`0001?ooooo0_l0000/ooooo`;o00006?ooool2o`0000kooooo0_l0000H
ooooo`;o00006?ooool2o`0002Oooooo1_l00004ooooo`;o00000_ooool2o`0000Gooooo0_l0000Q
ooooo`;o00003oooool2o`0000Gooooo0_l0000Nooooo`00:Oooool00ol0003oooooooooo`15oooo
o`;o00006?ooool2o`0003oooooo0_l000000ooooooo0000o`000007ooooo`;o00003Oooool2o`00
00oooooo1_l00004ooooo`Ko00001Oooool2o`00027ooooo0_l0000?ooooo`;o00001Oooool2o`00
00gooooo0_l0000?ooooo`00:Oooool00ol0003oooooooooo`04ooooo`?o00002Oooool2o`0000?o
oooo0_l00002ooooo`;o00007Oooool2o`0000Oooooo0_l00002ooooo`;o00001?ooool2o`0004go
oooo0_l00004ooooo`;o00002_ooool2o`0000cooooo0ol0000Kooooo`;o00007Oooool2o`0002oo
oooo0_l000000ooooooo0000o`00000?ooooo`00:Oooool2o`0000Gooooo0ol00009ooooo`;o0000
0oooool2o`0000;ooooo0_l0000Mooooo`;o00001oooool2o`0000Sooooo0_l0001=ooooo`;o0000
1Oooool2o`0000Gooooo0_l0000>ooooo`Co0000>oooool2o`0001Gooooo0_l0000Fooooo`Co0000
4_ooool002Wooooo0_l0000Kooooo`;o00001oooool2o`0000Cooooo0_l0000Eooooo`;o00003ooo
ool2o`00047ooooo0_l0000;ooooo`;o00001Oooool2o`0000cooooo1?l0000Gooooo`;o0000>ooo
ool2o`000003ooooool0003o000000Oooooo0_l0000:ooooo`;o00005?ooool002Wooooo0_l00004
ooooo`;o00005Oooool2o`0000Oooooo0_l00004ooooo`;o00004?ooool2o`0000?ooooo0_l0000?
ooooo`;o00008?ooool2o`0000Wooooo0_l0000Dooooo`;o00000_ooool2o`0001cooooo0_l0000I
ooooo`;o0000?_ooool2o`0000Oooooo0_l0000Pooooo`00:Oooool00ol0003oooooooooo`02oooo
o`?o00001oooool2o`0001Oooooo0_l0000Dooooo`;o0000=_ooool2o`0000Wooooo0_l0000Hoooo
o`;o00009Oooool2o`0000Sooooo0_l0001:ooooo`;o00005?ooool2o`0000;ooooo0_l0000;oooo
o`00:Oooool00ol0003oooooooooo`02ooooo`;o00002?ooool2o`0001Oooooo0_l00005ooooo`?o
000000?oooooo`000?l000000_l000002?l@413oooooo`000?l0003o<S8bo`000?lb<S;ok^k^0ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Wooooo1Ol00003ooooo`05onk^k_l0003o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo0_l0000Dooooo`05oiRHV?l@413o0000
oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP02o`0000Sooooo0_l00005ooooo`;o00004Oooool2o`0000Cooooo0_l000002Ol@413ooooo
ooooooooooook^k^oc8b<_l0003o<S8bonk^kP02ooooo`;o000000Co<S8bo`000?lb<S;ok^k^4?oo
ool2o`0000Oooooo0_l0000;ooooo`;o000000KoooooodA4A?l0003o0000oc8b<_oMgMd3o`000004
oc8b<_l0003o0000o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool00ol0
003oooooooooo`0?ooooo`;o00001oooool2o`0001;ooooo1?l00002ooooo`04o`000?oooooooooo
ooooo`;o000000CoV9RHoooooonHV9SoMgMg0oooool01OmgMgOoV9RHoooooonHV9SoMgMg02Wooooo
00?oV9RHob4Q8Oo^k^h00_l00003ooooo`05ogMgMol0003o0000oiRHV?mgMgL00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg01;ooooo0_l0000?ooooo`;o00000oooool01Ol@413o^[ZjoooooomgMgOo
<S8b00?ooooo0_l000000oooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04Ooo
ool2o`00017ooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo0_l000000oooooooV9RHogMg
M`02ooooo`;o000000CoV9RHo`000?l0003oMgMg3_ooool4o`0001Cooooo0_l00004ooooo`09ogMg
Molb<S;o0000o`000?mgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`00:Oooool00ol0003oooooooooo`0?ooooo`;o00001oooool2o`0001Cooooo0_l00002
ooooo`03o`000?oooooooooo00;o000000Go410@oooooooooooooooooa0@4003ooooo`;o00000_oo
ool00ol@413oooooooooo`0Vooooo`;o000000?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooo
oooooooo410@00?ooooo00Go410@ooooool0003o0000oa0@4002ooooo`;o00005oooool2o`0000Ko
oooo0_l00007ooooo`04o`000?ooooooooooooooo`;o00000_ooool01Ol@413ooooooooooooooooo
410@00;o000000?ooooooa0@4?ooool09oooool:o`0000;ooooo00Ko410@oooooooooooooooooa0@
4?ooool2o`000003oa0@4?oooooooooo00Gooooo0_l00003ooooo`Co00007Oooool01?l0003ooooo
ooooool@4103ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`01oooo
o`00:Oooool2o`0003?ooooo00?o0000ooooooooool01Ol000000ooooooo0000ooooo`02ooooo`;o
00000_ooool00ol0003oooooooooo`08ooooo`;o00007?ooool2o`000004oooooonHV9So8B4Qonk^
kP?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000;o00000_ooool2
o`0001Oooooo0_l0000>ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`?o000000?oooooo`000?ooool01_ooool2o`0001Cooooo0_l00009ooooo`05odA4A?oM
gMgoooooo`000?ooool01?l00002ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000?o
oooo0_l00002ooooo`;o00000oooool2o`0000kooooo0_l0000>ooooo`05ogMgMolb<S;ooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00Oooool0
02Wooooo00?o0000ooooooooool08Oooool2o`0000oooooo00?o0000ooooooooool00_ooool3o`00
0003ooooool0003ooooo00;ooooo00Go0000ooooooooooooooooo`00000:ooooo`;o00008?ooool0
0omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooooooo
ooooool3o`0000Sooooo0_l0000Nooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000?ooooo0_l0000Doooo
o`;o00000_ooool2o`0000Gooooo00CogMgMoeEEEOoooooo00000oooool2o`0000;ooooo0_l00003
ooooo`05o`000?ooooooooooooooool000000oooool4o`0001Gooooo0_l0000;ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`00:Oooool00ol0003oooooooooo`0Qooooo`;o00003oooool00ol0003o
ooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo
410@02gooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00;o00000ooo
ool00ol@413o0000o`000008ooooo`;o00007oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41000oooool2o`0000;ooooo00?o410@ooooooooool00_l0000Kooooo`Co0000
1_ooool00omgMgOoc<c<o`000003ooooo`;o00000oooool01Ol@413ooooooooooooooooo410@00?o
oooo00?o410@ooooooooool00oooool2o`0002;ooooo00?o0000ooooooooool01?ooool01Ol@413o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`00:Oooool00ol0
003oooooooooo`0Zooooo`;o00001_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg02Wooooo00Go0000okZj^_ooooooV9RH
oa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool2o`000004oiRHV?ooooooV9RHogMg
M`_ooooo0_l0000?ooooo`;o00002?ooool2o`000005oa0@4?nHV9SooooookZj^_l000000oooool0
0omgMgOoV9RHooooo`02o`0000?ooooo0_l000000oooooooV9RHogMgM`0Mooooo`Co00002?ooool0
0oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg02Wooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool00ol0003oooooooooo`0Zooooo`;o
00001?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Wooooo00CoV9RHoa0@4?l0003o8B4Q0_l00002ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo0_l00002ooooo`;o
00003oooool2o`0000Sooooo0_l000001OnYZJWo410@o`000?l@413oZJVY00?ooooo00?ok^k^oc8b
<_l000000_l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Oooool4o`0000Wooooo00?oMgMg
o`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`;o00008_ooool6o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool002Wooooo0_l00006ooooo`;o0000?Oooool2o`0000go
oooo0_l0000<ooooo`;o00003_ooool2o`0000Gooooo0_l0000?ooooo`?o00004?ooool2o`0000go
oooo0_l0000Uooooo`Co00008Oooool2o`0000Kooooo0_l0000Rooooo`;o00005oooool002Wooooo
00?o0000ooooooooool01Oooool2o`0000Kooooo0_l0000Looooo`;o00005oooool2o`0000gooooo
0_l0000<ooooo`;o00005Oooool3o`0000oooooo0_l000000ooooooo0000o`00000=ooooo`;o0000
3Oooool2o`0001kooooo0_l00005ooooo`Co00002Oooool2o`0000kooooo0ol00005ooooo`?o0000
@_ooool002Wooooo00?o0000ooooooooool03Oooool2o`0000_ooooo1?l0000=ooooo`;o0000;ooo
ool2o`0000Sooooo0_l0000Aooooo`;o00001oooool2o`000003ooooool0003o000000Kooooo0_l0
000looooo`;o00001_ooool3o`0000Wooooo0_l0000>ooooo`?o00001_ooool2o`0002Gooooo0_l0
0004ooooo`;o00001Oooool2o`0000kooooo000Yooooo`03o`000?oooooooooo01[ooooo1?l0000n
ooooo`;o00002?ooool2o`0000;ooooo0_l0000=ooooo`;o00001oooool2o`000003ooooool0003o
000002cooooo0_l000000ooooooo0000o`00000Kooooo`;o00001?ooool2o`0000kooooo0_l0000N
ooooo`Go00001?ooool2o`0000_ooooo1?l00002ooooo`;o00001Oooool2o`0000kooooo000Yoooo
o`03o`000?oooooooooo02Sooooo0_l0000_ooooo`?o00003_ooool2o`0002cooooo0_l0000Ioooo
o`;o000000?oooooo`000?l000008Oooool2o`0000kooooo0_l0000Nooooo`Go00001?ooool2o`00
00gooooo0_l0000Iooooo`008Oooooooo`0004Co00001?ooool002Wooooo0ol00009ooooo`?o0000
2_ooool00ol0003oooooooooo`09ooooo`;o00002_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Kooooo0_l00002ooooo`03o`000?oooooooooo00Wooooo0ol00005ooooo`;o0000
0_ooool00ol0003oooooooooo`09ooooo`;o00002oooool00ol0003oooooooooo`02ooooo`;o0000
1Oooool3o`0000Wooooo00?o0000ooooooooool02Oooool01?l0003oooooooooooooool2o`0000Oo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?o
oooo0_l00004ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool01?l0003o
ooooooooooooool4o`0000Cooooo00?o0000ooooooooool01oooool3o`0000cooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool002Wooooo00?o0000ooooooooool02_ooool2o`0001Kooooo0_l0000Fooooo`?o
00005oooool2o`0000Gooooo0_l0000>ooooo`Co00002Oooool00ol0003oooooooooo`02ooooo`;o
00001_ooool2o`00023ooooo1?l0000:ooooo`03o`000?oooooooooo00Kooooo0_l00007ooooo`;o
00005?ooool2o`0001?ooooo00?o0000ooooooooool06_ooool2o`0001kooooo00?o0000oooooooo
ool02_ooool002Wooooo00Co0000oooooooooooooooo0_l0000hooooo`;o0000<?ooool3o`00017o
oooo0_l00004ooooo`;o00004Oooool2o`000003ooooool0003o000000Sooooo1?l00002ooooo`;o
00000oooool2o`0000[ooooo0_l0000:ooooo`;o00004Oooool2o`00033ooooo0_l000000ooooooo
0000o`000002o`0002Kooooo000Yooooo`04o`000?ooooooooooooooo`;o00004_ooool2o`00053o
oooo0_l00005ooooo`;o00004Oooool4o`0000;ooooo0_l0000Aooooo`;o000000?oooooo`000?l0
00003_ooool2o`0000?ooooo0_l0000Fooooo`;o0000<?ooool2o`0000Kooooo0_l0000<ooooo`Co
00009_ooool002Wooooo0_l0000Fooooo`;o000000?oooooo`000?l00000?Oooool3o`0000gooooo
0_l0000Jooooo`;o00006_ooool2o`0000kooooo0_l00008ooooo`;o00001_ooool2o`0002Cooooo
0_l0000Cooooo`;o00001_ooool2o`0003Kooooo000Yooooo`03o`000?oooooooooo01Sooooo0_l0
000booooo`;o00002Oooool3o`0000[ooooo0_l00008ooooo`;o00003oooool2o`0000kooooo0_l0
000>ooooo`;o00003_ooool2o`0000Sooooo0_l00006ooooo`;o00002?ooool2o`0001[ooooo0_l0
000Dooooo`;o0000:Oooool2o`0001;ooooo000Yooooo`03o`000?oooooooooo02Oooooo0_l00009
ooooo`?o00005oooool3o`0001Gooooo0_l00008ooooo`;o00003?ooool5o`0000kooooo0_l0000I
ooooo`;o00001Oooool2o`0000Wooooo0_l0000=ooooo`;o00006_ooool2o`0000;ooooo0_l0000<
ooooo`;o00000_ooool2o`0002Wooooo0_l0000Booooo`00:Oooool00ol0003oooooooooo`06oooo
o`;o00003?ooool2o`0000[ooooo0_l00004ooooo`?o00001_ooool2o`000005ooooool0003o0000
o`000?ooool00_l00002ooooo`;o00001Oooool2o`0000[ooooo0_l0000]ooooo`?o0000:oooool2
o`0000Gooooo0_l00009ooooo`;o00009?ooool2o`0000?ooooo0_l00002ooooo`;o00003?ooool2
o`0003;ooooo0_l0000=ooooo`00:Oooool01?l0003oooooo`000?l00005ooooo`;o00003?ooool2
o`0000[ooooo0_l00004ooooo`;o00001oooool4o`0000?ooooo0_l00002ooooo`;o00001Oooool2
o`00017ooooo0_l0000Pooooo`;o0000J_ooool2o`0000;ooooo0_l0000booooo`;o00001oooool2
o`0000Sooooo0_l0000=ooooo`00:Oooool4o`0000Wooooo1?l0000Sooooo`Co00005?ooool2o`00
00Wooooo0_l0000Pooooo`;o00004oooool2o`0000Sooooo1?l00009ooooo`;o00007oooool2o`00
027ooooo0_l000000ooooooo0000o`00000?ooooo`;o00007_ooool2o`0000Oooooo0_l0000Goooo
o`00:Oooool00ol0003oooooooooo`02o`0000Sooooo1?l0000Uooooo`;o00005?ooool2o`0002[o
oooo0_l0000Dooooo`;o00002?ooool4o`0000Wooooo0_l0000Oooooo`;o00009?ooool2o`0000oo
oooo0_l00010ooooo`00:Oooool00ol0003oooooooooo`02o`0000Kooooo0_l00003ooooo`;o0000
9Oooool2o`0001Sooooo0_l0000Gooooo`;o00003?ooool2o`0008Oooooo0_l0000looooo`00:Ooo
ool00ol0003oooooooooo`08ooooo`;o00000oooool2o`0002Gooooo0_l0000Hooooo`;o00005ooo
ool2o`00017ooooo0_l00018ooooo`;o00001oooool2o`0002oooooo0_l0000Nooooo`;o00002Ooo
ool2o`00017ooooo000Yooooo`04o`000?oooooo0000o`0000?ooooo0_l0000/ooooo`;o00002_oo
ool2o`0000Kooooo0_l0000booooo`;o00006_ooool2o`0001?ooooo1Ol00003ooooo`;o00002?oo
ool2o`0000Gooooo0_l00007ooooo`?o0000C_ooool2o`0000Wooooo0_l0000Aooooo`00:Oooool4
o`0000?ooooo0_l000000ooooooo0000o`00000Gooooo`;o00001_ooool2o`0000Sooooo0_l0000:
ooooo`;o00001_ooool2o`00013ooooo0_l00004ooooo`;o0000<oooool2o`000003ooooool0003o
000001?ooooo1Ol00003ooooo`;o00002?ooool2o`0000oooooo0_l0000Dooooo`;o00000_ooool2
o`0002?ooooo0_l0000<ooooo`?o00000_ooool2o`0000Gooooo0_l0000Cooooo`00:Oooool00ol0
003oooooooooo`07ooooo`;o00005oooool2o`0000Kooooo0_l0000Looooo`;o00003Oooool2o`00
0003ooooool0003o000000Cooooo0_l00008ooooo`;o00007_ooool2o`0000Kooooo1Ol0000Boooo
o`;o00007Oooool2o`0000kooooo0_l0000<ooooo`;o00000_ooool2o`0000[ooooo0ol0000Foooo
o`;o00003?ooool3o`0000;ooooo0_l00005ooooo`;o00004oooool002Wooooo00?o0000oooooooo
ool01oooool2o`0000[ooooo0_l0000jooooo`;o00001?ooool2o`0000_ooooo0_l00004ooooo`;o
00007_ooool2o`0000Kooooo1?l0000Cooooo`;o00005?ooool2o`0000Oooooo1?l00003ooooo`;o
00001oooool2o`0001cooooo0ol00015ooooo`00:Oooool00ol0003oooooooooo`0Cooooo`;o0000
:Oooool2o`0000oooooo0_l0000Aooooo`;o0000FOooool2o`0000Wooooo0ol00002ooooo`;o0000
:oooool2o`0000Kooooo0_l0000hooooo`00:Oooool00ol0003oooooooooo`0;ooooo`;o00002_oo
ool2o`0002Gooooo0_l00003ooooo`;o00000oooool2o`00017ooooo0_l0000Dooooo`;o00009_oo
ool2o`0002kooooo0_l0000_ooooo`;o00001_ooool2o`0001?ooooo0_l00009ooooo`;o000000?o
ooooo`000?l000005Oooool002Wooooo0_l0000:ooooo`Co00002_ooool2o`0002[ooooo0_l00003
ooooo`;o00004Oooool2o`0001Cooooo0_l0000Vooooo`;o0000Boooool2o`0000?ooooo0_l00005
ooooo`;o00004Oooool2o`00013ooooo0_l00009ooooo`;o000000?oooooo`000?l000005Oooool0
02Wooooo00?o0000ooooooooool02Oooool2o`0001;ooooo0_l0001Hooooo`;o0000?_ooool2o`00
01oooooo0_l0000<ooooo`;o00000oooool2o`0000Gooooo1?l0000?ooooo`;o0000=Oooool000Ko
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo017ooooo0_l0000:ooooo`;o0000F?ooool2
o`0001cooooo0_l0000Pooooo`;o00001Oooool2o`0001Sooooo0_l0000;ooooo`;o00003Oooool2
o`0000Sooooo0_l0000@ooooo`;o00003Oooool2o`0000?ooooo0_l0000Fooooo`001_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo017ooooo0_l0000;ooooo`;o00001ooo
ool2o`0001Cooooo0_l0001Fooooo`;o00001?ooool2o`0000Oooooo0_l0000Hooooo`Co00008ooo
ool2o`0001Oooooo0_l0000@ooooo`;o00003Oooool2o`0000?ooooo0_l00004ooooo`;o00004?oo
ool000Kooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Booooo`;o00000_ooool2o`0000Kooooo0_l0
0007ooooo`;o00001oooool2o`0000_ooooo0_l000000ooooooo0000o`000007ooooo`;o00001Ooo
ool2o`0000Oooooo0_l00004ooooo`;o0000>_ooool2o`0000Oooooo0_l0000Jooooo`;o00000ooo
ool2o`0002Kooooo0_l0000Cooooo`;o00003?ooool2o`0001Sooooo0_l0000@ooooo`001_ooool0
1Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8boooo
o`04ooooo`?o00004_ooool2o`0000;ooooo0_l0000Hooooo`;o00003_ooool2o`0000Oooooo0_l0
0005ooooo`;o00001oooool2o`000004ooooool0003o0000ooooo`;o0000I?ooool2o`0002Kooooo
0_l0000Cooooo`;o00003?ooool2o`0002[ooooo0006ooooo`05o`000?ooooooooooooooool00000
3_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003o
ooooooooo`0?ooooo`;o0000Boooool2o`0001Cooooo0_l0000booooo`;o0000U?ooool000Kooooo
00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0?ooooo`;o0000E?ooool2o`0000_ooooo0_l0000booooo`;o
00006_ooool2o`000003ooooool0003o0000043ooooo0_l0000cooooo`001_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0IOooool2o`0005_ooooo0_l000000ooooooo0000o`00000ioooo
o`;o00001Oooool2o`0003?ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnH
V9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo02?ooooo0_l00005
ooooo`;o0000e?ooool2o`0003[ooooo000Yooooo`;o00007Oooool2o`0000Gooooo0_l00005oooo
o`;o00004Oooool2o`0001kooooo0_l0000=ooooo`;o00006?ooool2o`0000Kooooo0_l00007oooo
o`;o0000B?ooool2o`0000kooooo0_l0000Tooooo`;o00008oooool002Wooooo00?o0000oooooooo
ool05?ooool2o`0000Kooooo0_l0000Oooooo`;o00002?ooool2o`0001Cooooo0_l00005ooooo`;o
00001_ooool2o`0001;ooooo0_l00004ooooo`;o00001_ooool2o`0000Oooooo0_l00018ooooo`;o
00003_ooool2o`0002Cooooo0_l0000Sooooo`00:Oooool00ol0003oooooooooo`0Dooooo`;o0000
5oooool3o`0001Oooooo0_l0000Kooooo`;o00006_ooool2o`0000Sooooo0_l0000Tooooo`;o0000
R_ooool002Wooooo00?o0000ooooooooool0;Oooool3o`00033ooooo0_l0000Uooooo`;o000000?o
ooooo`000?l000001_ooool2o`0001cooooo0_l0001Rooooo`;o00009_ooool002Wooooo00?o0000
ooooooooool06oooool2o`0004?ooooo0ol00003ooooo`;o00000oooool2o`0001[ooooo0_l00009
ooooo`;o00002oooool2o`000003ooooool0003o000000Kooooo0_l0000]ooooo`Co0000<?ooool2
o`0000Gooooo0_l0000Vooooo`00:Oooool2o`0001?ooooo0_l00007ooooo`;o0000<oooool2o`00
00oooooo0_l00003ooooo`;o00000oooool2o`0003;ooooo0_l000000ooooooo0000o`000006oooo
o`;o00002?ooool3o`00023ooooo1_l0000Nooooo`;o00004?ooool2o`0001kooooo0ol0000<oooo
o`00:Oooool00ol0003oooooooooo`0>ooooo`;o00000_ooool2o`0002kooooo0_l00004ooooo`Co
00001?ooool3o`00053ooooo0_l00009ooooo`;o00001?ooool3o`0001cooooo0_l00002ooooo`;o
00008_ooool2o`0001Wooooo0_l00005ooooo`;o000000?oooooo`000?l000002oooool3o`0000co
oooo000Yooooo`03o`000?oooooooooo00Wooooo0_l00003ooooo`;o0000<_ooool2o`0000Cooooo
1?l00005ooooo`;o00000oooool2o`0001[ooooo1?l0000]ooooo`;o00002Oooool2o`0002?ooooo
0_l0000Looooo`;o00008oooool2o`0000Gooooo0_l000000ooooooo0000o`00000Jooooo`00:Ooo
ool00ol0003oooooooooo`09ooooo`;o00005oooool2o`0003;ooooo0_l0000Jooooo`Co00006ooo
ool2o`0005kooooo0_l00019ooooo`00:Oooool00ol0003oooooooooo`0Rooooo`;o0000KOooool2
o`000:Wooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo03Wooooo0_l0003oooooo`;ooooo000Yooooo`03o`000?oo
oooooooo01gooooo0_l0000<ooooo`;o00003?ooool2o`000?oooooo0_ooool002Wooooo00?o0000
ooooooooool07Oooool2o`0000cooooo0_l0003ooooooa3ooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`1Cooooo`;o0000P?ooool2o`0001cooooo0_l0000Fooooo`;o
0000;oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0Doooool2o`0006kooooo0_l0000:oooo
o`;o00001?ooool2o`0001cooooo0_l0000Fooooo`;o0000;oooool000kooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
0<?ooooo0_l0000:ooooo`;o00002_ooool2o`0005oooooo000>ooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol0003oooooooooo`03ooooo`?o0000foooool2o`0005oooooo000>ooooo`05
o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
08cooooo0_l0002^ooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo08cooooo0_l0000Rooooo`;o0000R_ooool0
00kooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0=Oooool2o`0001Cooooo0_l0000Looooo`;o00001?ooool2o`0000Kooooo0_l00000
0ooooooo0000o`00000dooooo`;o0000GOooool2o`0000Oooooo0_l0000Rooooo`003_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0e
ooooo`Co00004_ooool2o`0001cooooo0_l00004ooooo`;o00001_ooool2o`000003ooooool0003o
000008Wooooo0_l00008ooooo`;o00001oooool2o`0002;ooooo000>ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0000hooooo`;o0000c?ooool2o`0003Gooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEE
EOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolmooooo`001_ooool01Ol0003o
oooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00000>oooo
o`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOo
oooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool001oooooo1?l000000ol@413oooooooooo`03ooooo`03
o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo0ol0003oooooocgooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool001oooooo00?oEEEEofIVI_l00000oooooom7ooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .33013 Mdot
.02762 .25781 Mdot
.02952 .28008 Mdot
.03143 .30116 Mdot
.03333 .35938 Mdot
.03524 .38867 Mdot
.03714 .28829 Mdot
.03905 .29847 Mdot
.04095 .35143 Mdot
.04286 .32707 Mdot
.04476 .27404 Mdot
.04667 .24722 Mdot
.04857 .2586 Mdot
.05048 .30795 Mdot
.05238 .22771 Mdot
.05429 .34098 Mdot
.05619 .29282 Mdot
.0581 .26293 Mdot
.06 .29189 Mdot
.0619 .41174 Mdot
.06381 .28662 Mdot
.06571 .23681 Mdot
.06762 .25135 Mdot
.06952 .27893 Mdot
.07143 .23432 Mdot
.07333 .3392 Mdot
.07524 .25417 Mdot
.07714 .29369 Mdot
.07905 .41982 Mdot
.08095 .24629 Mdot
.08286 .32429 Mdot
.08476 .3619 Mdot
.08667 .30307 Mdot
.08857 .34606 Mdot
.09048 .36983 Mdot
.09238 .4034 Mdot
.09429 .42086 Mdot
.09619 .27209 Mdot
.0981 .42486 Mdot
.1 .2465 Mdot
.1019 .22667 Mdot
.10381 .35812 Mdot
.10571 .38799 Mdot
.10762 .33308 Mdot
.10952 .35773 Mdot
.11143 .36517 Mdot
.11333 .29812 Mdot
.11524 .39402 Mdot
.11714 .26782 Mdot
.11905 .4201 Mdot
.12095 .39212 Mdot
.12286 .42915 Mdot
.12476 .48175 Mdot
.12667 .38295 Mdot
.12857 .38321 Mdot
.13048 .32671 Mdot
.13238 .28619 Mdot
.13429 .28342 Mdot
.13619 .40968 Mdot
.1381 .36405 Mdot
.14 .36136 Mdot
.1419 .34295 Mdot
.14381 .42455 Mdot
.14571 .29931 Mdot
.14762 .27898 Mdot
.14952 .34975 Mdot
.15143 .32758 Mdot
.15333 .3391 Mdot
.15524 .26678 Mdot
.15714 .30172 Mdot
.15905 .2841 Mdot
.16095 .32212 Mdot
.16286 .31785 Mdot
.16476 .3403 Mdot
.16667 .42451 Mdot
.16857 .31354 Mdot
.17048 .48168 Mdot
.17238 .34095 Mdot
.17429 .42821 Mdot
.17619 .25914 Mdot
.1781 .36785 Mdot
.18 .24639 Mdot
.1819 .29136 Mdot
.18381 .35976 Mdot
.18571 .32262 Mdot
.18762 .34068 Mdot
.18952 .36097 Mdot
.19143 .36294 Mdot
.19333 .26254 Mdot
.19524 .34043 Mdot
.19714 .2392 Mdot
.19905 .4611 Mdot
.20095 .26911 Mdot
.20286 .3653 Mdot
.20476 .2753 Mdot
.20667 .45216 Mdot
.20857 .31068 Mdot
.21048 .37923 Mdot
.21238 .48181 Mdot
.21429 .25768 Mdot
.21619 .31269 Mdot
.2181 .24691 Mdot
.22 .24094 Mdot
.2219 .31631 Mdot
.22381 .34136 Mdot
.22571 .352 Mdot
.22762 .30449 Mdot
.22952 .30789 Mdot
.23143 .26867 Mdot
.23333 .30961 Mdot
.23524 .32099 Mdot
.23714 .29047 Mdot
.23905 .36185 Mdot
.24095 .40107 Mdot
.24286 .45484 Mdot
.24476 .26629 Mdot
.24667 .35419 Mdot
.24857 .35387 Mdot
.25048 .36038 Mdot
.25238 .41541 Mdot
.25429 .26146 Mdot
.25619 .30806 Mdot
.2581 .28427 Mdot
.26 .42057 Mdot
.2619 .30703 Mdot
.26381 .31528 Mdot
.26571 .40832 Mdot
.26762 .43955 Mdot
.26952 .26264 Mdot
.27143 .30879 Mdot
.27333 .24378 Mdot
.27524 .29019 Mdot
.27714 .23158 Mdot
.27905 .3905 Mdot
.28095 .38973 Mdot
.28286 .42624 Mdot
.28476 .42987 Mdot
.28667 .41581 Mdot
.28857 .31861 Mdot
.29048 .27603 Mdot
.29238 .22768 Mdot
.29429 .39483 Mdot
.29619 .26152 Mdot
.2981 .27431 Mdot
.3 .29168 Mdot
.3019 .40622 Mdot
.30381 .33544 Mdot
.30571 .43189 Mdot
.30762 .33146 Mdot
.30952 .3629 Mdot
.31143 .27339 Mdot
.31333 .24482 Mdot
.31524 .25295 Mdot
.31714 .27784 Mdot
.31905 .31957 Mdot
.32095 .37227 Mdot
.32286 .42831 Mdot
.32476 .42627 Mdot
.32667 .34663 Mdot
.32857 .4184 Mdot
.33048 .42874 Mdot
.33238 .31208 Mdot
.33429 .42864 Mdot
.33619 .22555 Mdot
.3381 .39365 Mdot
.34 .38677 Mdot
.3419 .30878 Mdot
.34381 .33679 Mdot
.34571 .34999 Mdot
.34762 .2638 Mdot
.34952 .43173 Mdot
.35143 .41572 Mdot
.35333 .26015 Mdot
.35524 .25924 Mdot
.35714 .36173 Mdot
.35905 .3353 Mdot
.36095 .28742 Mdot
.36286 .44872 Mdot
.36476 .37297 Mdot
.36667 .26943 Mdot
.36857 .42247 Mdot
.37048 .43201 Mdot
.37238 .23242 Mdot
.37429 .34654 Mdot
.37619 .22841 Mdot
.3781 .32861 Mdot
.38 .34934 Mdot
.3819 .44001 Mdot
.38381 .37483 Mdot
.38571 .22655 Mdot
.38762 .38961 Mdot
.38952 .28577 Mdot
.39143 .40564 Mdot
.39333 .31354 Mdot
.39524 .33861 Mdot
.39714 .3095 Mdot
.39905 .23401 Mdot
.40095 .23703 Mdot
.40286 .36475 Mdot
.40476 .46998 Mdot
.40667 .32414 Mdot
.40857 .26637 Mdot
.41048 .2658 Mdot
.41238 .32316 Mdot
.41429 .35904 Mdot
.41619 .47418 Mdot
.4181 .29645 Mdot
.42 .32863 Mdot
.4219 .3848 Mdot
.42381 .2803 Mdot
.42571 .3326 Mdot
.42762 .27386 Mdot
.42952 .24002 Mdot
.43143 .34516 Mdot
.43333 .35156 Mdot
.43524 .34531 Mdot
.43714 .30293 Mdot
.43905 .34837 Mdot
.44095 .22456 Mdot
.44286 .3277 Mdot
.44476 .35982 Mdot
.44667 .26005 Mdot
.44857 .35662 Mdot
.45048 .39869 Mdot
.45238 .34087 Mdot
.45429 .37984 Mdot
.45619 .34371 Mdot
.4581 .34936 Mdot
.46 .27663 Mdot
.4619 .26115 Mdot
.46381 .22752 Mdot
.46571 .3097 Mdot
.46762 .33137 Mdot
.46952 .27653 Mdot
.47143 .47493 Mdot
.47333 .24601 Mdot
.47524 .25605 Mdot
.47714 .30129 Mdot
.47905 .26389 Mdot
.48095 .30785 Mdot
.48286 .26949 Mdot
.48476 .29818 Mdot
.48667 .34637 Mdot
.48857 .39161 Mdot
.49048 .36498 Mdot
.49238 .28363 Mdot
.49429 .36785 Mdot
.49619 .27666 Mdot
.4981 .42474 Mdot
.5 .26543 Mdot
.5019 .28055 Mdot
.50381 .4253 Mdot
.50571 .23325 Mdot
.50762 .26604 Mdot
.50952 .30818 Mdot
.51143 .42132 Mdot
.51333 .32766 Mdot
.51524 .25798 Mdot
.51714 .38572 Mdot
.51905 .31471 Mdot
.52095 .28493 Mdot
.52286 .40246 Mdot
.52476 .25347 Mdot
.52667 .25636 Mdot
.52857 .3846 Mdot
.53048 .28925 Mdot
.53238 .24544 Mdot
.53429 .33627 Mdot
.53619 .28583 Mdot
.5381 .38565 Mdot
.54 .40992 Mdot
.5419 .30336 Mdot
.54381 .40447 Mdot
.54571 .38513 Mdot
.54762 .33166 Mdot
.54952 .25671 Mdot
.55143 .42954 Mdot
.55333 .34705 Mdot
.55524 .33187 Mdot
.55714 .38567 Mdot
.55905 .28325 Mdot
.56095 .37853 Mdot
.56286 .42486 Mdot
.56476 .30409 Mdot
.56667 .34133 Mdot
.56857 .41694 Mdot
.57048 .25079 Mdot
.57238 .30962 Mdot
.57429 .31028 Mdot
.57619 .35327 Mdot
.5781 .38891 Mdot
.58 .36311 Mdot
.5819 .36095 Mdot
.58381 .44079 Mdot
.58571 .40773 Mdot
.58762 .23545 Mdot
.58952 .40096 Mdot
.59143 .27048 Mdot
.59333 .41911 Mdot
.59524 .33325 Mdot
.59714 .37704 Mdot
.59905 .22953 Mdot
.60095 .41811 Mdot
.60286 .26826 Mdot
.60476 .39102 Mdot
.60667 .29 Mdot
.60857 .3649 Mdot
.61048 .22783 Mdot
.61238 .29367 Mdot
.61429 .38334 Mdot
.61619 .32343 Mdot
.6181 .27678 Mdot
.62 .24214 Mdot
.6219 .29924 Mdot
.62381 .26035 Mdot
.62571 .26588 Mdot
.62762 .27192 Mdot
.62952 .3518 Mdot
.63143 .3536 Mdot
.63333 .26875 Mdot
.63524 .28748 Mdot
.63714 .22938 Mdot
.63905 .28932 Mdot
.64095 .40117 Mdot
.64286 .32734 Mdot
.64476 .39193 Mdot
.64667 .35949 Mdot
.64857 .42522 Mdot
.65048 .34824 Mdot
.65238 .27305 Mdot
.65429 .27683 Mdot
.65619 .29811 Mdot
.6581 .27443 Mdot
.66 .4196 Mdot
.6619 .27924 Mdot
.66381 .23739 Mdot
.66571 .31057 Mdot
.66762 .32317 Mdot
.66952 .27218 Mdot
.67143 .39042 Mdot
.67333 .38688 Mdot
.67524 .31069 Mdot
.67714 .3575 Mdot
.67905 .48286 Mdot
.68095 .31619 Mdot
.68286 .24929 Mdot
.68476 .29382 Mdot
.68667 .31056 Mdot
.68857 .25514 Mdot
.69048 .41414 Mdot
.69238 .23757 Mdot
.69429 .25989 Mdot
.69619 .35472 Mdot
.6981 .39204 Mdot
.7 .25362 Mdot
.7019 .42289 Mdot
.70381 .40559 Mdot
.70571 .28214 Mdot
.70762 .3264 Mdot
.70952 .41371 Mdot
.71143 .24537 Mdot
.71333 .25278 Mdot
.71524 .39974 Mdot
.71714 .36802 Mdot
.71905 .23172 Mdot
.72095 .22766 Mdot
.72286 .22493 Mdot
.72476 .32138 Mdot
.72667 .24871 Mdot
.72857 .22692 Mdot
.73048 .28732 Mdot
.73238 .32007 Mdot
.73429 .34645 Mdot
.73619 .30627 Mdot
.7381 .38684 Mdot
.74 .31785 Mdot
.7419 .37238 Mdot
.74381 .30765 Mdot
.74571 .41868 Mdot
.74762 .42227 Mdot
.74952 .24874 Mdot
.75143 .4269 Mdot
.75333 .24313 Mdot
.75524 .22802 Mdot
.75714 .44898 Mdot
.75905 .41011 Mdot
.76095 .37351 Mdot
.76286 .31874 Mdot
.76476 .26236 Mdot
.76667 .25546 Mdot
.76857 .27478 Mdot
.77048 .23218 Mdot
.77238 .30483 Mdot
.77429 .27659 Mdot
.77619 .3364 Mdot
.7781 .34506 Mdot
.78 .25389 Mdot
.7819 .39178 Mdot
.78381 .33719 Mdot
.78571 .33904 Mdot
.78762 .2308 Mdot
.78952 .32338 Mdot
.79143 .48064 Mdot
.79333 .32686 Mdot
.79524 .33162 Mdot
.79714 .33715 Mdot
.79905 .30017 Mdot
.80095 .27516 Mdot
.80286 .24838 Mdot
.80476 .25455 Mdot
.80667 .25957 Mdot
.80857 .2628 Mdot
.81048 .3452 Mdot
.81238 .25239 Mdot
.81429 .3658 Mdot
.81619 .39056 Mdot
.8181 .26934 Mdot
.82 .25385 Mdot
.8219 .2952 Mdot
.82381 .36409 Mdot
.82571 .34015 Mdot
.82762 .25424 Mdot
.82952 .32668 Mdot
.83143 .29128 Mdot
.83333 .27976 Mdot
.83524 .28242 Mdot
.83714 .37315 Mdot
.83905 .30512 Mdot
.84095 .35817 Mdot
.84286 .29703 Mdot
.84476 .25964 Mdot
.84667 .25926 Mdot
.84857 .45727 Mdot
.85048 .29285 Mdot
.85238 .4668 Mdot
.85429 .32899 Mdot
.85619 .32499 Mdot
.8581 .33288 Mdot
.86 .22615 Mdot
.8619 .26606 Mdot
.86381 .23745 Mdot
.86571 .48264 Mdot
.86762 .25971 Mdot
.86952 .28602 Mdot
.87143 .34255 Mdot
.87333 .38119 Mdot
.87524 .27197 Mdot
.87714 .46618 Mdot
.87905 .33102 Mdot
.88095 .37821 Mdot
.88286 .35275 Mdot
.88476 .28914 Mdot
.88667 .27364 Mdot
.88857 .34512 Mdot
.89048 .29581 Mdot
.89238 .27558 Mdot
.89429 .42723 Mdot
.89619 .27172 Mdot
.8981 .35293 Mdot
.9 .40598 Mdot
.9019 .35242 Mdot
.90381 .3102 Mdot
.90571 .43506 Mdot
.90762 .33495 Mdot
.90952 .27217 Mdot
.91143 .23099 Mdot
.91333 .28205 Mdot
.91524 .42077 Mdot
.91714 .29964 Mdot
.91905 .2887 Mdot
.92095 .4131 Mdot
.92286 .31503 Mdot
.92476 .30187 Mdot
.92667 .35496 Mdot
.92857 .34251 Mdot
.93048 .33045 Mdot
.93238 .38821 Mdot
.93429 .31119 Mdot
.93619 .3865 Mdot
.9381 .25971 Mdot
.94 .3232 Mdot
.9419 .33336 Mdot
.94381 .3818 Mdot
.94571 .39029 Mdot
.94762 .26514 Mdot
.94952 .33164 Mdot
.95143 .34785 Mdot
.95333 .35725 Mdot
.95524 .3423 Mdot
.95714 .26277 Mdot
.95905 .30281 Mdot
.96095 .31257 Mdot
.96286 .46142 Mdot
.96476 .30764 Mdot
.96667 .26468 Mdot
.96857 .39054 Mdot
.97048 .39436 Mdot
.97238 .27157 Mdot
.97429 .41884 Mdot
.97619 .23694 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo08;ooooo0_l0002hooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo00Gooooo0_l0000>ooooo`;o0000??ooool2o`0000cooooo0_l0000>ooooo`;o00003ooo
ool2o`0000Kooooo0_l0000]ooooo`;o00008Oooool5o`0002Sooooo0_l0000aooooo`001?l00002
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01Oooool2o`0000kooooo0_l0000looooo`;o00003?oo
ool2o`0000_ooooo0_l000000ooooooo0000o`00000Gooooo`;o0000:Oooool2o`0000;ooooo0_l0
0006ooooo`;o00006Oooool5o`0000Kooooo0_l00009ooooo`;o00005Oooool2o`0000oooooo0_l0
000Pooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00omgMgOo<S8booooo`04ooooo`?o0000C_ooool2o`0001cooooo1?l00005ooooo`;o00008?oo
ool2o`0001cooooo0_l0000:ooooo`;o00006Oooool2o`0000Wooooo0_l00003ooooo`;o00001?oo
ool2o`0002Kooooo0_l0000Pooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
2_ooool4o`00043ooooo0_l0000Looooo`;o00001oooool3o`0001oooooo0_l0000Iooooo`;o0000
:?ooool2o`0000kooooo0_l00011ooooo`;o00002oooool000Kooooo00Go410@oooooooooooooooo
oa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0:ooooo`Co00009_ooool2o`00043ooooo0_l00007ooooo`;o0000<Oooool2o`0001Kooooo
0_l00007ooooo`;o0000=Oooool2o`0002?ooooo0_l0000;ooooo`001_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0=?ooool2o`0000Gooooo0_l00012ooooo`;o0000>oooool2o`0000co
oooo0_l00007ooooo`;o00004_ooool2o`00027ooooo0_l0000`ooooo`001_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0
003oooooooooo`0?ooooo`;o00001?ooool2o`0001Oooooo0_l0000;ooooo`;o00004?ooool2o`00
00[ooooo0_l0000booooo`;o00004Oooool2o`0001[ooooo0_l0000Kooooo`;o00003?ooool2o`00
05?ooooo000Yooooo`;o00001Oooool2o`0000Wooooo0_l00004ooooo`;o00005oooool2o`0000_o
oooo0_l0000@ooooo`;o00002_ooool2o`0003;ooooo0_l0000Aooooo`;o0000;_ooool2o`0000Oo
oooo0_l00003ooooo`;o00001_ooool2o`0000oooooo0_l00013ooooo`00:Oooool00ol0003ooooo
ooooo`04ooooo`;o00001?ooool2o`0002oooooo0_l0001_ooooo`;o00008_ooool2o`0000Sooooo
0_l00002ooooo`;o00001_ooool2o`0000oooooo0_l000000ooooooo0000o`000010ooooo`00:Ooo
ool00ol0003oooooooooo`0:ooooo`;o000000?oooooo`000?l00000Boooool2o`00047ooooo0_l0
000=ooooo`;o00009?ooool2o`0000;ooooo0_l00002ooooo`;o00003oooool2o`0000;ooooo0_l0
0006ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`00000kooooo`00:Oooool2
o`0000Gooooo0_l00007ooooo`;o0000:oooool2o`0001kooooo0_l0000aooooo`;o00002oooool2
o`000004ooooool0003o0000o`0000Gooooo0_l0000[ooooo`;o00000_ooool2o`0001?ooooo0_l0
0002ooooo`;o00001_ooool2o`0000?ooooo0_l000000ooooooo0000o`00000kooooo`00:Oooool2
o`0000Gooooo0_l0000Wooooo`;o00002oooool2o`0000[ooooo0_l0000<ooooo`;o00004?ooool3
o`0001_ooooo0_l00003ooooo`;o00000_ooool2o`0000_ooooo0_l00002ooooo`;o00001Oooool2
o`0001Kooooo0_l0000Eooooo`;o00008_ooool2o`0000[ooooo0ol00005ooooo`;o00005?ooool2
o`0001Sooooo000Yooooo`;o00002?ooool2o`0002Cooooo0_l00004ooooo`;o00004Oooool2o`00
00?ooooo0_l00007ooooo`;o00003_ooool5o`0001_ooooo0_l00003ooooo`;o00001?ooool2o`00
02cooooo0_l0000Eooooo`;o00005Oooool2o`0000_ooooo0ol00009ooooo`?o00001Oooool2o`00
01Cooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000oooooo000Yoooo
o`03o`000?oooooooooo00Oooooo0_l0000Aooooo`;o00002oooool2o`0000[ooooo0_l0000>oooo
o`;o00001_ooool2o`0001Oooooo0_l0000Booooo`?o00005?ooool2o`0000Cooooo0_l000000ooo
oooo0000o`00000Looooo`;o00001_ooool2o`0002_ooooo0_l0000<ooooo`;o00003oooool2o`00
01Wooooo0_l000001?oooooo0000o`000?ooool2o`0000oooooo000Yooooo`03o`000?oooooooooo
01[ooooo0_l0000;ooooo`;o00001oooool4o`000008oa0@4?l0003o0000onk^k_lb<S;o0000oc8b
<_o^k^h3ooooo`?o000000?o<S8bo`000?l000009_ooool7o`0000?ooooo00?ok^k^oc8b<_l00000
0ol00002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool2o`0000?ooooo0_l000000ooooooo
0000o`00000@ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01?o^k^ko0000o`000?lb<S82
o`0000;ooooo00Cok^k^oc8b<_l0003o<S8b1?l0000Wooooo`;o000000Wo410@oooooooooooooooo
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;o00003?ooool2
o`0001Wooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Yooooo`03o`000?oooooooooo00?ooooo
0_l0000?ooooo`;o00007?ooool00ol0003oooooooooo`02o`000005ogMgMonHV9SooooooiRHV?mg
MgL00oooool2o`000003oooooonHV9SoMgMg013ooooo0_l00003ooooo`;o00004?ooool2o`000005
oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMg
o`000?l0003oV9RHogMgM`0>ooooo`;o00006?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo
00GoMgMgo`000?l0003oV9RHogMgM`03ooooo`04ogMgMonHV9SooooooiRHV0Co00001?ooool4o`00
00;ooooo0_l0000Looooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_l0000@ooooo`;o00000_ooool2o`000003ooooool0
003o000000;ooooo0_l0000=ooooo`05ogMgMolb<S;ooooooooooomgMgL00_l000000onHV9SoMgMg
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wooooo00?o0000ooooooooool0
0oooool2o`0000oooooo0_l0000Looooo`04o`000?ooooooooooooooo`;o00000oooool01Ol@413o
oooooooooooooooo410@00?ooooo00?o410@ooooooooool03?ooool4o`0000?ooooo0_l0000Coooo
o`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?l0003o
0000ooooool@41001oooool2o`000003ooooool0003o000000Kooooo0_l0000Hooooo`05o`000?oo
ooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00;o000000?oooooo`000?l0
00001_ooool4o`0000;ooooo0_l0000Iooooo`Wo00000oooool00ol@413oooooooooo`02o`0000?o
oooo00?o410@ooooooooool04?ooool2o`0000;ooooo1Ol00002ooooo`;o00003_ooool01?l0003o
ooooooooool@4102o`000003ooooool@413ooooo00;ooooo00Go410@oooooooooooooooooa0@4003
ooooo`00:Oooool3o`0000_ooooo0_l0000Gooooo`;o00003?ooool01?l0003oooooooooooooool2
o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00cooooo0_l0
0007ooooo`;o00004_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool00000
0oooool2o`0000;ooooo00?o0000ooooooooool01Oooool2o`000003ooooool0003o000000Kooooo
1?l0000Eooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`?o
000000?oooooo`000?ooool01oooool4o`0001cooooo00GoA4A4omgMgOoooooo0000ooooo`04o`00
00?ooooo00?o0000ooooooooool00_l00003ooooo`03o`000?oooooooooo00?ooooo0_l0000Aoooo
o`;o00004_ooool01OmgMgOo<S8boooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo007ooooo000Yooooo`?o00002oooool2o`0001?ooooo0_l00002
ooooo`;o00003?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000001Oooooo0_l0000Cooooo`03ogMgMomVIVKooooo00;ooooo
00Go0000ooooooooooooooooo`000003ooooo`;o00000_ooool00ol0003oooooooooo`0?ooooo`;o
000000?oooooo`000?l000004?ooool2o`0000;ooooo00?o410@o`000?nj^[X00oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00000:ooooo`;o00003Oooool2
o`0000gooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000005ooooo`;o00005oooool2o`0000Wooooo00Go0000ob4Q8Ol0
003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo000Yooooo`03o`000?oooooooooo00Wooooo0_l0000Dooooo`?o00001_ooool2
o`0000Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@4004ooooo`;o00009oooool3o`000003ooooool@413ooooo00;ooooo
00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00oooooo0_l00007ooooo`;o
00000oooool2o`0000Gooooo0_l00003ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooo
oooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41006Oooool2o`0000kooooo00?oMgMg
olc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooo
oa0@4005ooooo`;o00002Oooool2o`0000cooooo0_l00009ooooo`03o`000?oooooooooo00Cooooo
00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool002Wo
oooo00Co0000oooooooooooooooo0_l00006ooooo`;o00005?ooool2o`0000Oooooo0_l00008oooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01?ooool2o`0001oooooo0_l00002ooooo`05o`000?nj^[[ooooooiRHV?l@4100
0_l000001_ooooooMgMgoiRHV?ooooooV9RHogMgM`?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0J
ooooo`;o000000?oooooo`000?l000000_l00007ooooo`05oa0@4?nHV9SooooookZj^_l000000ooo
ool01_mgMgOoV9RHoooooonHV9SoMgMgooooo`;o000000GoMgMgoiRHV?ooooooV9RHogMgM`02oooo
o`?o00006oooool2o`0000Oooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0@ooooo`;o00000oooool2o`0000Wooooo0_l0
0007ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool002Wooooo00Co0000oooooooooooooooo0_l00004ooooo`?o
00009Oooool2o`000003ofIVI_l0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`05onk^k_lb<S;o0000o`000?o^k^h02Oooool2o`0000Kooooo0_l0000Booooo`;o00000_ooool0
1OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h07Oooool2o`0000Wooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03oooo
o`06onk^k_lb<S;o0000oc8b<_o^k^kooooo0_l000001Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo
0ol0000Kooooo`;o00002?ooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo0_l00004ooooo`;o00002Oooool2o`00
00Wooooo0_l00007ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool2o`0000Sooooo0ol00003ooooo`;o00008?ooool2
o`00013ooooo0_l0000:ooooo`;o00001_ooool2o`0006?ooooo0_l0000Eooooo`;o0000:_ooool2
o`000003ooooool0003o000000Cooooo0_l0000;ooooo`;o00009oooool002Wooooo00Co0000oooo
oooooooooooo0_l0000:ooooo`;o00002_ooool2o`0000Sooooo0_l0001Fooooo`;o00004oooool2
o`0002Sooooo0_l000000ooooooo0000o`000009ooooo`;o00001oooool2o`0002[ooooo0_l00005
ooooo`;o00003Oooool2o`0002Oooooo000Yooooo`03o`000?oooooo000000?o00005_ooool2o`00
00Sooooo0_l00002ooooo`;o0000D_ooool2o`00017ooooo1?l0000[ooooo`;o00002Oooool2o`00
02cooooo0_l0000<ooooo`;o00005_ooool4o`0001cooooo000Yooooo`04o`000?oooooo0000o`00
00oooooo0_l0000Eooooo`;o00005Oooool2o`00047ooooo0_l0000;ooooo`;o00004oooool2o`00
00Gooooo0_l00011ooooo`;o00001oooool2o`0000[ooooo0_l0000Hooooo`Co00002Oooool2o`00
017ooooo000Yooooo`03o`000?oooooooooo00Gooooo0_l00009ooooo`;o0000;?ooool2o`0000Oo
oooo1?l000000ooooooo0000o`00000Eooooo`;o00007?ooool2o`0000cooooo0_l00007ooooo`;o
00002Oooool2o`0000Gooooo0_l0000eooooo`;o000000?oooooo`000?l000001oooool2o`0001?o
oooo0_l0000Uooooo`Co00003oooool0027oooooool00014o`0000Cooooo000Yooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Kooooo0_l000000ooooooo0000ooooo`08ooooo`Co00001?ooool2o`0000Gooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`;o00002_ooool00ol0003ooooooooo
o`05ooooo`?o00000_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo0_l0
0004ooooo`03o`000?oooooooooo00Wooooo0_l0000;ooooo`04o`000?ooooooooooooooo`;o0000
1_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo1Ol000000ooooooo0000
o`000007ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool2o`0000Cooooo
0_l00002ooooo`?o00001_ooool2o`0000?ooooo00?o0000ooooooooool02_ooool002Wooooo00?o
0000ooooooooool0:Oooool4o`0000gooooo1?l0000;ooooo`;o00005?ooool2o`0001;ooooo0_l0
0003ooooo`03o`000?oooooooooo027ooooo0_l0000Gooooo`03o`000?oooooooooo01Sooooo0_l0
000Aooooo`;o00003Oooool00ol0003oooooooooo`0Xooooo`;o00002oooool2o`0000?ooooo00?o
0000ooooooooool02_ooool002Wooooo00?o0000ooooooooool0:Oooool2o`00017ooooo0_l00002
ooooo`;o00001oooool2o`0000Kooooo0_l00008ooooo`;o0000Loooool2o`0000kooooo0_l00000
0ooooooo0000o`000005ooooo`;o0000D?ooool002Wooooo00?o0000ooooooooool03oooool2o`00
01Oooooo0_l00006ooooo`;o00003_ooool2o`0000oooooo0_l00008ooooo`;o00006_ooool4o`00
043ooooo0_l0000>ooooo`;o00004Oooool4o`0000Sooooo0_l00006ooooo`;o0000;oooool2o`00
01Oooooo000Yooooo`;o00000oooool2o`0000_ooooo0_l0000>ooooo`;o00001oooool2o`0000Ko
oooo0_l00015ooooo`Co0000@?ooool2o`0000Kooooo0_l00006ooooo`;o00002oooool2o`0000Co
oooo0_l0000Booooo`Co00002Oooool2o`0000Oooooo0_l0000Iooooo`;o00005oooool002Wooooo
0_l00003ooooo`;o00006oooool2o`0000Cooooo0_l00017ooooo`;o00003?ooool2o`0000Gooooo
0_l0000Eooooo`;o00009oooool2o`0001?ooooo0_l0000Jooooo`;o00002Oooool2o`0000Kooooo
0ol0000Fooooo`;o00006_ooool002Wooooo0_l0000Hooooo`;o00003?ooool2o`00037ooooo0_l0
000Dooooo`;o00003?ooool3o`0000Cooooo0_l00006ooooo`;o00003Oooool2o`0000Wooooo1?l0
000;ooooo`;o0000?_ooool2o`00017ooooo1?l00004ooooo`;o00003oooool2o`000004ooooool0
003o0000ooooo`;o00005?ooool002Wooooo00?o0000ooooooooool05oooool2o`0003gooooo1?l0
0009ooooo`;o00000oooool2o`0001?ooooo0_l0000<ooooo`;o00004oooool2o`0000?ooooo1?l0
000;ooooo`;o0000>?ooool2o`0000Cooooo0_l0000Cooooo`;o00001?ooool2o`0000Oooooo0_l0
0009ooooo`;o000000?oooooo`000?l000005?ooool002Wooooo00?o0000ooooooooool03?ooool2
o`0001Sooooo0_l0000^ooooo`;o00002oooool2o`0000?ooooo0_l0000:ooooo`;o0000:_ooool2
o`0004cooooo0_l000000ooooooo0000o`000002ooooo`;o00008Oooool2o`0002;ooooo000Yoooo
o`;o00001oooool2o`0000Cooooo0_l0000Dooooo`;o00000_ooool2o`0000;ooooo1?l00003oooo
o`Co00002?ooool2o`0003Gooooo0_l0000@ooooo`;o00008oooool2o`0004Cooooo0_l00002oooo
o`;o00001oooool2o`0000gooooo0_l0000@ooooo`;o00001oooool2o`0001;ooooo000Yooooo`03
o`000?oooooooooo00Kooooo0_l00009ooooo`;o00003oooool2o`0000Kooooo1?l00003ooooo`Co
00002?ooool2o`00043ooooo1?l00003ooooo`?o00008_ooool2o`0004;ooooo0_l00008ooooo`;o
00000oooool2o`0000gooooo0_l00003ooooo`;o00002oooool2o`0000Oooooo0_l0000Booooo`00
:Oooool00ol0003oooooooooo`0Aooooo`;o0000Boooool2o`0000gooooo0_l0000@ooooo`Go0000
0oooool2o`0000Sooooo0_l0000Dooooo`;o00007Oooool2o`0001Wooooo0_l0000<ooooo`;o0000
2?ooool2o`0001Oooooo0_l0000Cooooo`;o00004oooool002Wooooo00?o0000ooooooooool00_oo
ool2o`00027ooooo0_l0000Fooooo`;o00007oooool2o`0000Cooooo0_l00007ooooo`Co00003ooo
ool4o`0000Cooooo0_l00007ooooo`;o00005?ooool2o`0001Kooooo0_l00005ooooo`;o00006Ooo
ool2o`0004Cooooo0_l0000Cooooo`00:Oooool00ol0003oooooooooo`02ooooo`;o00008Oooool2
o`0001Kooooo0_l00005ooooo`?o00007Oooool2o`0000Wooooo0_l0000?ooooo`;o00001_ooool2
o`0002Cooooo0_l0000?ooooo`?o00004_ooool2o`0003[ooooo0_l00003ooooo`Co00001_ooool2
o`0001_ooooo000Yooooo`;o00005oooool4o`0002[ooooo0ol0000nooooo`;o00009oooool2o`00
013ooooo0_l0000<ooooo`;o00001?ooool2o`0002gooooo0_l0000;ooooo`;o00000oooool4o`00
00Kooooo0_l00006ooooo`;o00004oooool002Wooooo00Co0000ooooool0003o00005Oooool4o`00
00Sooooo0_l0000<ooooo`Co00004Oooool2o`0003?ooooo0_l00008ooooo`?o0000:Oooool2o`00
01?ooooo0_l00007ooooo`;o0000<oooool2o`0002;ooooo0_l0000Cooooo`00:Oooool01?l0003o
ooooo`000?l0000?ooooo`;o00003oooool3o`0000cooooo1?l0000=ooooo`;o00000_ooool2o`00
017ooooo0_l0000=ooooo`;o00003Oooool2o`0000;ooooo0_l00008ooooo`;o0000:Oooool3o`00
01?ooooo0_l0000gooooo`;o0000??ooool002Wooooo00?o0000ooooooooool04?ooool2o`0000Ko
oooo0_l00007ooooo`;o00002oooool2o`0000;ooooo0_l00002ooooo`;o00002Oooool2o`0001Go
oooo0_l0000=ooooo`;o00003Oooool2o`0001[ooooo1?l0000Iooooo`;o00001oooool2o`00043o
oooo0_l00002ooooo`;o0000??ooool002Wooooo00?o0000ooooooooool04_ooool2o`0000Cooooo
0_l0000Dooooo`;o00001_ooool2o`0005[ooooo1?l0000Rooooo`;o00008Oooool2o`0001gooooo
0_l00010ooooo`00:Oooool2o`0001?ooooo0_l00018ooooo`;o00003?ooool2o`0006oooooo0_l0
0006ooooo`;o00001?ooool2o`0001Oooooo0_l0000hooooo`00:Oooool00ol0003oooooooooo`1L
ooooo`;o00003?ooool2o`0000Cooooo0_l00013ooooo`;o0000;?ooool2o`0000Cooooo0_l0000G
ooooo`;o0000>?ooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo03Sooooo0_l0
000fooooo`;o00005Oooool2o`00023ooooo0_l0000:ooooo`;o0000FOooool2o`0002[ooooo0006
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool07Oooool3o`0001Sooooo
0_l0001=ooooo`;o00008?ooool2o`0000oooooo0_l0001Aooooo`;o000000?oooooo`000?l00000
4_ooool2o`0001Kooooo0006ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Q
onk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool07Oooool3o`0005cooooo
0_l0000Mooooo`;o00000_ooool2o`000003ooooool0003o000000;o00000_ooool2o`00013ooooo
0_l0001Aooooo`;o00004oooool4o`0001Kooooo0006ooooo`05o`000?ooooooooooooooool00000
3Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo1Ol0000Eooooo`;o0000
BOooool2o`0000gooooo0_l00009ooooo`;o00007Oooool2o`0000;ooooo0_l000000ooooooo0000
o`000002o`0000;ooooo0_l00004ooooo`;o00007Oooool2o`0001?ooooo0_l0000looooo`Co0000
6?ooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00;o00005Oooool2o`0000?o
oooo0_l0000`ooooo`?o00004Oooool2o`0000gooooo0_l0000Oooooo`;o00006_ooool2o`0000Oo
oooo0_l0000;ooooo`;o00001oooool2o`0000Kooooo0_l0000;ooooo`;o00003?ooool2o`0000Wo
oooo0_l0000Sooooo`;o00000oooool2o`0000Gooooo0_l0000>ooooo`001_ooool01Ol@413ooooo
oooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo01[ooooo1?l0000`ooooo`?o00000_ooool2o`0000cooooo0_l0000_ooooo`;o
00008oooool2o`0000_ooooo0_l00007ooooo`;o00001_ooool2o`0001Wooooo0_l00009ooooo`;o
0000:?ooool2o`0000Gooooo0ol0000=ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool06_ooool2o`0003Oooooo0_l0000<ooooo`;o00008_ooool2o`000:Kooooo0_l0000=oooo
o`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004
ooooo`Co00001_ooool00ol0003oooooooooo`12ooooo`;o0000@Oooool2o`0002_ooooo0_l0000?
ooooo`;o00005_ooool2o`0005oooooo000Yooooo`;o00004oooool2o`0002kooooo0_l0001Ioooo
o`;o00001?ooool2o`0000gooooo0_l0000?ooooo`;o00005_ooool2o`0005oooooo000Yooooo`03
o`000?oooooooooo01;ooooo0_l0000fooooo`;o00002_ooool2o`0001[ooooo0_l0000Yooooo`;o
00001?ooool2o`0000cooooo0_l0000Tooooo`;o0000?Oooool2o`0002Cooooo000Yooooo`03o`00
0?oooooooooo023ooooo0_l0000Xooooo`;o00002_ooool2o`0001[ooooo0_l0000^ooooo`;o0000
3Oooool2o`0002Cooooo0_l0000@ooooo`;o0000:oooool2o`0002Cooooo000Yooooo`03o`000?oo
oooooooo00Wooooo0_l0000Eooooo`;o0000P?ooool2o`0002oooooo0_l00004ooooo`;o00003_oo
ool2o`0003;ooooo0_l0000Mooooo`00:Oooool00ol0003oooooooooo`09ooooo`;o0000>oooool2
o`0000Wooooo0_l0000Cooooo`;o0000@oooool2o`0002Kooooo0_l00004ooooo`;o0000@_ooool2
o`0001gooooo000Yooooo`;o00003oooool2o`0000_ooooo0_l0000Yooooo`Co00001oooool2o`00
00_ooooo0_l00006ooooo`;o0000@oooool2o`0000Kooooo0_l000000ooooooo0000o`00000Aoooo
o`;o00006Oooool2o`0003Gooooo0_l0000Aooooo`;o00003?ooool002Wooooo00?o0000oooooooo
ool03_ooool2o`0000?ooooo0_l00006ooooo`;o0000:oooool2o`0001Cooooo0_l0000;ooooo`;o
0000;?ooool2o`0001Sooooo0_l000000ooooooo0000o`00000Aooooo`;o00002oooool2o`0000co
oooo0ol0000dooooo`;o00004Oooool2o`0000cooooo000Yooooo`03o`000?oooooooooo01?ooooo
0ol0000=ooooo`;o00001Oooool2o`0002Cooooo0_l0000;ooooo`;o00003?ooool2o`0002Sooooo
1_l0000?ooooo`;o00006Oooool2o`0000oooooo0_l0000=ooooo`?o0000E?ooool002Wooooo00?o
0000ooooooooool05?ooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`000003ooooool0
003o0000027ooooo0_l0000:ooooo`Ko0000<oooool4o`0000gooooo0_l00002ooooo`;o00006Ooo
ool2o`0001oooooo0_l0000/ooooo`;o00009_ooool002Wooooo00?o0000ooooooooool07?ooool2
o`0000oooooo0_l0000Qooooo`;o00001Oooool2o`0000?ooooo0_l000001?oooooo0000o`000?l0
0003ooooo`;o00001Oooool2o`0003Sooooo0_l0001/ooooo`;o00009_ooool002Wooooo0_l0001H
ooooo`;o00003?ooool2o`0000Gooooo0_l0002Zooooo`;o00008_ooool002Wooooo00?o0000oooo
ooooool0oooooolIooooo`;o00008_ooool002Wooooo00?o0000ooooooooool0Boooool2o`0002;o
oooo0_l0000oooooo`;o0000R_ooool002Wooooo00?o0000ooooooooool0Boooool2o`0002;ooooo
0_l0000oooooo`;o0000R_ooool002Wooooo00?o0000ooooooooool0JOooool2o`000=7ooooo000Y
ooooo`;o0000J_ooool2o`0007gooooo0_l0001Booooo`00:Oooool00ol0003oooooooooo`0goooo
o`;o00002_ooool2o`000:?ooooo0_l0001Booooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0g
ooooo`;o00002_ooool2o`000<3ooooo0_l0000eooooo`003_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0=Oooool2
o`000<kooooo0_l0000eooooo`003_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000
ooooooooool00oooool3o`0003Gooooo0_l0003cooooo`;o00004?ooool000kooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0ooooool8
ooooo`;o00001_ooool2o`0001Wooooo0_l0000@ooooo`003_ooool01Ol0003ooooooooooooooooo
000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo07Oooooo0_l0
002>ooooo`;o00001_ooool2o`0002_ooooo000>ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07Oooooo0_l00033ooooo`003_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1jooooo`;o00004?ooool2o`000:kooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?oo
ool4o`0000Kooooo0_l0001kooooo`;o00004?ooool2o`000:kooooo000Yooooo`03o`000?oooooo
oooo01gooooo0_l0000<ooooo`;o00003?ooool2o`0009Cooooo0_l0000Rooooo`;o00005_ooool2
o`0002oooooo000Yooooo`03o`000?oooooooooo01gooooo0_l0000<ooooo`;o00003?ooool2o`00
09Cooooo0_l0000Rooooo`;o00005_ooool2o`0002oooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^
k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolm
ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWo
oooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006oooo
o`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooo
oooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool0
0olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolm
ooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool0
1Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go0000
1?ooool4o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`007oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooolmoooo
o`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo
00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`007oooool00omEEEGoIVIV
o`00003oooooodOooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .388 Mdot
.02762 .34914 Mdot
.02952 .28369 Mdot
.03143 .25862 Mdot
.03333 .31466 Mdot
.03524 .3836 Mdot
.03714 .27187 Mdot
.03905 .39659 Mdot
.04095 .41996 Mdot
.04286 .34888 Mdot
.04476 .33464 Mdot
.04667 .35759 Mdot
.04857 .25476 Mdot
.05048 .34901 Mdot
.05238 .32132 Mdot
.05429 .29776 Mdot
.05619 .24603 Mdot
.0581 .25085 Mdot
.06 .25298 Mdot
.0619 .34854 Mdot
.06381 .23833 Mdot
.06571 .29954 Mdot
.06762 .26542 Mdot
.06952 .24082 Mdot
.07143 .27324 Mdot
.07333 .3708 Mdot
.07524 .30565 Mdot
.07714 .25307 Mdot
.07905 .36851 Mdot
.08095 .33523 Mdot
.08286 .23848 Mdot
.08476 .42553 Mdot
.08667 .39754 Mdot
.08857 .2681 Mdot
.09048 .30546 Mdot
.09238 .33876 Mdot
.09429 .42939 Mdot
.09619 .26447 Mdot
.0981 .39357 Mdot
.1 .35774 Mdot
.1019 .29202 Mdot
.10381 .28427 Mdot
.10571 .35648 Mdot
.10762 .39093 Mdot
.10952 .3971 Mdot
.11143 .35386 Mdot
.11333 .34467 Mdot
.11524 .43636 Mdot
.11714 .3432 Mdot
.11905 .37483 Mdot
.12095 .43518 Mdot
.12286 .40571 Mdot
.12476 .4692 Mdot
.12667 .34025 Mdot
.12857 .33562 Mdot
.13048 .40905 Mdot
.13238 .38874 Mdot
.13429 .24886 Mdot
.13619 .43615 Mdot
.1381 .39783 Mdot
.14 .36021 Mdot
.1419 .23223 Mdot
.14381 .3989 Mdot
.14571 .33525 Mdot
.14762 .38101 Mdot
.14952 .42078 Mdot
.15143 .34803 Mdot
.15333 .29527 Mdot
.15524 .26892 Mdot
.15714 .23461 Mdot
.15905 .24765 Mdot
.16095 .29018 Mdot
.16286 .34805 Mdot
.16476 .34184 Mdot
.16667 .39888 Mdot
.16857 .28498 Mdot
.17048 .46934 Mdot
.17238 .36657 Mdot
.17429 .39746 Mdot
.17619 .33295 Mdot
.1781 .27656 Mdot
.18 .33492 Mdot
.1819 .26049 Mdot
.18381 .28645 Mdot
.18571 .40944 Mdot
.18762 .29329 Mdot
.18952 .31948 Mdot
.19143 .34418 Mdot
.19333 .26316 Mdot
.19524 .30015 Mdot
.19714 .26513 Mdot
.19905 .40074 Mdot
.20095 .32249 Mdot
.20286 .34561 Mdot
.20476 .32669 Mdot
.20667 .38098 Mdot
.20857 .34944 Mdot
.21048 .43001 Mdot
.21238 .47241 Mdot
.21429 .26806 Mdot
.21619 .38072 Mdot
.2181 .28933 Mdot
.22 .34955 Mdot
.2219 .38384 Mdot
.22381 .24655 Mdot
.22571 .27608 Mdot
.22762 .24358 Mdot
.22952 .25149 Mdot
.23143 .32214 Mdot
.23333 .23465 Mdot
.23524 .35041 Mdot
.23714 .26006 Mdot
.23905 .42517 Mdot
.24095 .32958 Mdot
.24286 .49103 Mdot
.24476 .28943 Mdot
.24667 .36517 Mdot
.24857 .4245 Mdot
.25048 .4266 Mdot
.25238 .42806 Mdot
.25429 .25238 Mdot
.25619 .223 Mdot
.2581 .24018 Mdot
.26 .36899 Mdot
.2619 .23445 Mdot
.26381 .26197 Mdot
.26571 .34509 Mdot
.26762 .35807 Mdot
.26952 .35111 Mdot
.27143 .26556 Mdot
.27333 .27669 Mdot
.27524 .36967 Mdot
.27714 .33538 Mdot
.27905 .38437 Mdot
.28095 .36792 Mdot
.28286 .38523 Mdot
.28476 .42474 Mdot
.28667 .36081 Mdot
.28857 .34784 Mdot
.29048 .3804 Mdot
.29238 .32241 Mdot
.29429 .28755 Mdot
.29619 .28756 Mdot
.2981 .26176 Mdot
.3 .24623 Mdot
.3019 .3381 Mdot
.30381 .41593 Mdot
.30571 .48703 Mdot
.30762 .26551 Mdot
.30952 .349 Mdot
.31143 .23165 Mdot
.31333 .30054 Mdot
.31524 .29844 Mdot
.31714 .24115 Mdot
.31905 .28239 Mdot
.32095 .39287 Mdot
.32286 .42058 Mdot
.32476 .40091 Mdot
.32667 .42037 Mdot
.32857 .42943 Mdot
.33048 .42154 Mdot
.33238 .36501 Mdot
.33429 .39529 Mdot
.33619 .32265 Mdot
.3381 .32055 Mdot
.34 .36142 Mdot
.3419 .37805 Mdot
.34381 .41631 Mdot
.34571 .25351 Mdot
.34762 .27255 Mdot
.34952 .41813 Mdot
.35143 .36654 Mdot
.35333 .30066 Mdot
.35524 .28024 Mdot
.35714 .32722 Mdot
.35905 .26913 Mdot
.36095 .38744 Mdot
.36286 .37479 Mdot
.36476 .39226 Mdot
.36667 .28411 Mdot
.36857 .37881 Mdot
.37048 .40984 Mdot
.37238 .33841 Mdot
.37429 .32704 Mdot
.37619 .28548 Mdot
.3781 .28922 Mdot
.38 .41821 Mdot
.3819 .35982 Mdot
.38381 .43176 Mdot
.38571 .32576 Mdot
.38762 .3611 Mdot
.38952 .22711 Mdot
.39143 .3366 Mdot
.39333 .33506 Mdot
.39524 .23046 Mdot
.39714 .40241 Mdot
.39905 .27102 Mdot
.40095 .34452 Mdot
.40286 .34138 Mdot
.40476 .41713 Mdot
.40667 .24738 Mdot
.40857 .30505 Mdot
.41048 .30213 Mdot
.41238 .29693 Mdot
.41429 .31705 Mdot
.41619 .42811 Mdot
.4181 .37248 Mdot
.42 .32451 Mdot
.4219 .38852 Mdot
.42381 .26434 Mdot
.42571 .30103 Mdot
.42762 .33501 Mdot
.42952 .28225 Mdot
.43143 .36643 Mdot
.43333 .25509 Mdot
.43524 .323 Mdot
.43714 .37527 Mdot
.43905 .36499 Mdot
.44095 .31669 Mdot
.44286 .28457 Mdot
.44476 .39496 Mdot
.44667 .37054 Mdot
.44857 .36405 Mdot
.45048 .43372 Mdot
.45238 .24576 Mdot
.45429 .29597 Mdot
.45619 .31686 Mdot
.4581 .29045 Mdot
.46 .36407 Mdot
.4619 .30923 Mdot
.46381 .32077 Mdot
.46571 .22267 Mdot
.46762 .27644 Mdot
.46952 .31197 Mdot
.47143 .43472 Mdot
.47333 .30854 Mdot
.47524 .31489 Mdot
.47714 .2237 Mdot
.47905 .27295 Mdot
.48095 .3802 Mdot
.48286 .24736 Mdot
.48476 .37388 Mdot
.48667 .23448 Mdot
.48857 .37267 Mdot
.49048 .26993 Mdot
.49238 .24786 Mdot
.49429 .42894 Mdot
.49619 .32692 Mdot
.4981 .42031 Mdot
.5 .26177 Mdot
.5019 .24926 Mdot
.50381 .39835 Mdot
.50571 .27287 Mdot
.50762 .29047 Mdot
.50952 .33447 Mdot
.51143 .42429 Mdot
.51333 .36783 Mdot
.51524 .28294 Mdot
.51714 .33896 Mdot
.51905 .28966 Mdot
.52095 .38729 Mdot
.52286 .43713 Mdot
.52476 .32848 Mdot
.52667 .31567 Mdot
.52857 .30397 Mdot
.53048 .26627 Mdot
.53238 .29784 Mdot
.53429 .38933 Mdot
.53619 .33986 Mdot
.5381 .38024 Mdot
.54 .35332 Mdot
.5419 .36011 Mdot
.54381 .33858 Mdot
.54571 .33989 Mdot
.54762 .34891 Mdot
.54952 .33138 Mdot
.55143 .41891 Mdot
.55333 .32888 Mdot
.55524 .26338 Mdot
.55714 .43348 Mdot
.55905 .34066 Mdot
.56095 .39213 Mdot
.56286 .38486 Mdot
.56476 .26349 Mdot
.56667 .33764 Mdot
.56857 .42932 Mdot
.57048 .36065 Mdot
.57238 .25163 Mdot
.57429 .27168 Mdot
.57619 .30409 Mdot
.5781 .30621 Mdot
.58 .35231 Mdot
.5819 .26756 Mdot
.58381 .3617 Mdot
.58571 .43458 Mdot
.58762 .34047 Mdot
.58952 .4329 Mdot
.59143 .29323 Mdot
.59333 .43523 Mdot
.59524 .22861 Mdot
.59714 .28616 Mdot
.59905 .32761 Mdot
.60095 .4825 Mdot
.60286 .3425 Mdot
.60476 .35628 Mdot
.60667 .36998 Mdot
.60857 .42735 Mdot
.61048 .28901 Mdot
.61238 .34363 Mdot
.61429 .43217 Mdot
.61619 .36716 Mdot
.6181 .31868 Mdot
.62 .27816 Mdot
.6219 .24473 Mdot
.62381 .2537 Mdot
.62571 .23614 Mdot
.62762 .27925 Mdot
.62952 .39353 Mdot
.63143 .27802 Mdot
.63333 .374 Mdot
.63524 .2666 Mdot
.63714 .33169 Mdot
.63905 .22699 Mdot
.64095 .29539 Mdot
.64286 .27184 Mdot
.64476 .38419 Mdot
.64667 .28532 Mdot
.64857 .40651 Mdot
.65048 .28682 Mdot
.65238 .3169 Mdot
.65429 .28065 Mdot
.65619 .24421 Mdot
.6581 .38139 Mdot
.66 .42361 Mdot
.6619 .32916 Mdot
.66381 .292 Mdot
.66571 .26598 Mdot
.66762 .29887 Mdot
.66952 .36104 Mdot
.67143 .38028 Mdot
.67333 .3617 Mdot
.67524 .36441 Mdot
.67714 .31283 Mdot
.67905 .46065 Mdot
.68095 .36432 Mdot
.68286 .33809 Mdot
.68476 .33366 Mdot
.68667 .40091 Mdot
.68857 .3103 Mdot
.69048 .35759 Mdot
.69238 .31117 Mdot
.69429 .30814 Mdot
.69619 .36065 Mdot
.6981 .28324 Mdot
.7 .36421 Mdot
.7019 .43525 Mdot
.70381 .34264 Mdot
.70571 .3517 Mdot
.70762 .24905 Mdot
.70952 .36051 Mdot
.71143 .30398 Mdot
.71333 .36331 Mdot
.71524 .29194 Mdot
.71714 .27397 Mdot
.71905 .3354 Mdot
.72095 .32692 Mdot
.72286 .29871 Mdot
.72476 .31209 Mdot
.72667 .31891 Mdot
.72857 .31827 Mdot
.73048 .38915 Mdot
.73238 .31512 Mdot
.73429 .2517 Mdot
.73619 .3601 Mdot
.7381 .38857 Mdot
.74 .38294 Mdot
.7419 .42781 Mdot
.74381 .37995 Mdot
.74571 .4323 Mdot
.74762 .41784 Mdot
.74952 .26924 Mdot
.75143 .43291 Mdot
.75333 .27841 Mdot
.75524 .28974 Mdot
.75714 .4913 Mdot
.75905 .42987 Mdot
.76095 .39423 Mdot
.76286 .28207 Mdot
.76476 .24013 Mdot
.76667 .27149 Mdot
.76857 .28352 Mdot
.77048 .33847 Mdot
.77238 .23441 Mdot
.77429 .31976 Mdot
.77619 .34487 Mdot
.7781 .36946 Mdot
.78 .30695 Mdot
.7819 .43637 Mdot
.78381 .24253 Mdot
.78571 .23094 Mdot
.78762 .33528 Mdot
.78952 .24845 Mdot
.79143 .45731 Mdot
.79333 .24979 Mdot
.79524 .26478 Mdot
.79714 .27037 Mdot
.79905 .3165 Mdot
.80095 .38153 Mdot
.80286 .35872 Mdot
.80476 .30831 Mdot
.80667 .30327 Mdot
.80857 .32711 Mdot
.81048 .30887 Mdot
.81238 .24706 Mdot
.81429 .33949 Mdot
.81619 .31373 Mdot
.8181 .27479 Mdot
.82 .29315 Mdot
.8219 .26442 Mdot
.82381 .33133 Mdot
.82571 .26143 Mdot
.82762 .31136 Mdot
.82952 .3274 Mdot
.83143 .2251 Mdot
.83333 .38301 Mdot
.83524 .30874 Mdot
.83714 .31237 Mdot
.83905 .2436 Mdot
.84095 .39224 Mdot
.84286 .35669 Mdot
.84476 .279 Mdot
.84667 .24215 Mdot
.84857 .38915 Mdot
.85048 .37229 Mdot
.85238 .48983 Mdot
.85429 .38981 Mdot
.85619 .33049 Mdot
.8581 .41045 Mdot
.86 .31131 Mdot
.8619 .32817 Mdot
.86381 .30587 Mdot
.86571 .46325 Mdot
.86762 .29679 Mdot
.86952 .32373 Mdot
.87143 .27995 Mdot
.87333 .29734 Mdot
.87524 .344 Mdot
.87714 .41002 Mdot
.87905 .29678 Mdot
.88095 .32776 Mdot
.88286 .27501 Mdot
.88476 .33328 Mdot
.88667 .27755 Mdot
.88857 .3365 Mdot
.89048 .39489 Mdot
.89238 .27458 Mdot
.89429 .39105 Mdot
.89619 .36012 Mdot
.8981 .39498 Mdot
.9 .34075 Mdot
.9019 .25792 Mdot
.90381 .2446 Mdot
.90571 .34852 Mdot
.90762 .34596 Mdot
.90952 .37986 Mdot
.91143 .27729 Mdot
.91333 .33786 Mdot
.91524 .43536 Mdot
.91714 .35817 Mdot
.91905 .24767 Mdot
.92095 .35484 Mdot
.92286 .38204 Mdot
.92476 .25158 Mdot
.92667 .36088 Mdot
.92857 .26348 Mdot
.93048 .22597 Mdot
.93238 .36977 Mdot
.93429 .27969 Mdot
.93619 .3542 Mdot
.9381 .33395 Mdot
.94 .30749 Mdot
.9419 .28203 Mdot
.94381 .33607 Mdot
.94571 .36268 Mdot
.94762 .29767 Mdot
.94952 .36789 Mdot
.95143 .41989 Mdot
.95333 .30731 Mdot
.95524 .39091 Mdot
.95714 .27277 Mdot
.95905 .25252 Mdot
.96095 .32248 Mdot
.96286 .49227 Mdot
.96476 .32398 Mdot
.96667 .35525 Mdot
.96857 .43104 Mdot
.97048 .32132 Mdot
.97238 .26426 Mdot
.97429 .36843 Mdot
.97619 .34549 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo04Oooooo0_l00011ooooo`;o00000_ooool2o`000:cooooo0006ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0Aoooool2o`0002Wooooo0_l0000Fooooo`;o00000_oo
ool2o`0003;ooooo0_l0000looooo`;o00007_ooool2o`0001[ooooo0004o`0000;ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1booooo`Co0000?_ooool2o`0000cooooo0_l0000]ooooo`;o00003Ooo
ool2o`0001kooooo0_l0000Jooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o00008_ooool2o`0003Gooooo0_l0
000Iooooo`;o0000?_ooool2o`0003_ooooo0_l00019ooooo`001_ooool01Ol0003ooooooooooooo
oooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool08_ooool2o`0000?ooooo0_l0000Gooooo`;o00001oooool2o`0000kooooo
0_l0000fooooo`;o0000:oooool2o`0002gooooo0_l0001=ooooo`001_ooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Wooooo0_l00004ooooo`;o00005_ooool2o`0001Oooooo0_l00006ooooo`?o0000
A_ooool2o`0002_ooooo0_l0000[ooooo`Co0000COooool000Kooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Wooooo1?l00002ooooo`;o0000=oooool2o`00017ooooo0_l0002>ooooo`;o
00001?ooool2o`0001;ooooo0_l0000eooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`07oooo
o`;o00000_ooool2o`00033ooooo0ol0000Eooooo`;o00001?ooool2o`0002Wooooo0_l0000eoooo
o`;o00002Oooool2o`0002Oooooo0_l0000?ooooo`;o000000?oooooo`000?l000004?ooool2o`00
02?ooooo000Yooooo`;o00002?ooool2o`0001Oooooo0_l00006ooooo`;o00004oooool3o`0001Go
oooo0_l0000Pooooo`;o00003Oooool2o`0000Sooooo0_l000001?oooooo0000o`000?ooool2o`00
02Gooooo0_l00009ooooo`;o00003_ooool2o`0001Sooooo0_l00006ooooo`;o00001_ooool2o`00
01?ooooo0_l00003ooooo`;o00007_ooool002Wooooo00?o0000ooooooooool01oooool2o`0001Oo
oooo0_l00006ooooo`;o00005?ooool2o`0000Kooooo0_l0000_ooooo`;o00005oooool2o`000004
ooooool0003o0000ooooo`;o00005Oooool2o`0002Wooooo0_l00007ooooo`;o00003oooool4o`00
00Cooooo0_l0000Pooooo`Co00002Oooool2o`00017ooooo000Yooooo`03o`000?oooooooooo00Co
oooo0_l000001?oooooo0000o`000?l00003ooooo`;o0000;oooool2o`0000Kooooo0_l0000Loooo
o`;o00006_ooool2o`0002_ooooo0_l0000>ooooo`;o00008_ooool2o`00017ooooo0_l0000Xoooo
o`;o00002Oooool2o`00017ooooo000Yooooo`04o`000?oooooo0000o`0000?ooooo0_l00002oooo
o`;o00000oooool2o`0005Gooooo0_l0000Jooooo`;o0000>oooool2o`0005Sooooo0_l0000Soooo
o`00:Oooool01?l0003oooooo`000?l0000^ooooo`;o00004?ooool2o`0000Kooooo0_l00009oooo
o`;o0000?oooool2o`0006Oooooo0_l0000Gooooo`;o00008oooool002Wooooo0_l0000Eooooo`;o
00006Oooool2o`0000;ooooo0ol0000;ooooo`;o00001_ooool2o`0000Wooooo0_l0000Wooooo`;o
00005_ooool2o`00013ooooo0_l000000ooooooo0000o`000018ooooo`;o00001oooool3o`0001oo
oooo0_l0000<ooooo`;o00003Oooool002Wooooo00?o0000ooooooooool02_ooool2o`0000Gooooo
0_l000000ooooooo0000o`00000Mooooo`?o00001?ooool2o`00013ooooo0_l0000:ooooo`;o0000
8oooool2o`00023ooooo0_l00006ooooo`;o000000?oooooo`000?l000001?ooool2o`0000oooooo
0_l00008ooooo`;o00009oooool2o`0000Oooooo0_l0000Pooooo`;o00003?ooool2o`0000gooooo
000Yooooo`03o`000?oooooooooo00[ooooo0_l00005ooooo`;o00005?ooool2o`0000Oooooo1?l0
00001Ol@413oooooooooooo^k^ko<S8b00?o00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00So
oooo0_l0000:ooooo`;o00003_ooool2o`0000?ooooo1Ol00003ooooo`?o000000?o<S8bonk^k_oo
ool00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^013ooooo0_l0000;ooooo`;o00002Oooool01_nH
V9So410@o`000?lb<S;oc<c<ooooo`;o000000Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00_ooool2o`0000Sooooo0_l0000Iooooo`;o000000?oooooo`000?l0
00000_l00002ooooo`06onk^k_lb<S;o0000oc8b<_o^k^kooooo0_l000001Oo^k^ko<S8bo`000?lb
<S;ok^k^02Wooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Yooooo`04o`000?oooooooooooooo
o`;o00002Oooool2o`0001Wooooo0_l00009ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL08?ooool2o`0000;ooooo0_l0
0003ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool2o`000003oooooonHV9SoMgMg00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0=ooooo`;o000000?oooooo`000?l000000oooool2o`00017o
oooo00?o410@okZj^_ooool00_l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Cooooo0_l0000Fooooo`;o00002Oooool2o`0000;ooooo0ol00002
ooooo`06ogMgMonHV9SooooooiRHV?mgMgOooooo0_l000001OmgMgOoV9RHoooooonHV9SoMgMg01So
oooo0_l0000Booooo`;o00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`00:Oooool01?l0003oooooooooooooool2o`0000Wooooo0_l0000P
ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`06oa0@4?ooooooooooooooool@413ooooo
0_l000001Ol@413ooooooooooooooooo410@00Wooooo0_l0000Eooooo`;o00002?ooool00onHV9So
8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo
410@00Wooooo0_l00002ooooo`;o00001_ooool2o`0001Cooooo0_l00003ooooo`05oa0@4?oooooo
ooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Cooooo0_l0000Fooooo`;o0000
2_ooool5o`0000?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41000_l0000Booooo`Ko00001?ooool2o`0000cooooo0_l00002ooooo`05oa0@4?oooooooooo
ooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo000Yooooo`;o0000;oooool2
o`0000;ooooo00?o0000ooooooooool00_ooool01_l0003ooooooooooooooooo0000ooooo`?o0000
0oooool00ol0003oooooooooo`07ooooo`;o00006?ooool2o`0000Kooooo00?oV9RHob4Q8Oo^k^h0
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000009oooo
o`;o00008?ooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooo`000005o`0000Gooooo0_l0000Nooooo`;o000000?oooooo`000?ooool00oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooooooo0ol00006ooooo`;o0000
1oooool2o`000003ooooool0003o000000;o00001_ooool2o`0000Gooooo0_l00005ooooo`05ogMg
Molb<S;oooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool00Oooool002Wooooo0ol0000booooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000005oooool2o`0000[ooooo0_l00007
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooo000000;o00006?ooool2o`00013ooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooool000001Ol00005ooooo`;o00003?ooool2o`00013ooooo
0_l000000ooooooo0000o`000002o`000003ooooool0003ooooo00;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo00Kooooo0_l00007ooooo`;o00004_ooool5o`000004
ob4Q8Ol0003o<S8bolc<c0;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool002Wooooo0ol0000Fooooo`;o00004oooool2o`0000?ooooo0ol00004
ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@01Oooooo
0_l0000>ooooo`;o000000Goooooo`000?l0003oooooo`000003ooooo`05oa0@4?oooooooooooooo
ool@41000oooool01_l@413oooooo`000?l0003o410@ooooo`;o00005Oooool2o`00017ooooo00?o
^[Zjob4Q8Oooool00_ooool00ol@413oooooooooo`02o`0000?ooooo00Go410@oooooooooooooooo
oa0@4006ooooo`?o00003Oooool2o`00017ooooo00?oMgMgolc<c?l000000ol000000ooooooo410@
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Uooooo`?o
00001_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003
ooooo`00:Oooool00ol0003oooooooooo`0Fooooo`;o00004oooool2o`0000?ooooo0ol00004oooo
o`04ogMgMonHV9SooooooiRHV0;o00000_ooool01?mgMgOoV9RHoooooonHV9P2o`0000kooooo0ol0
000Eooooo`Go000000?oV9RHoa0@4?ooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00KoMgMgoiRHV?ooooooV9RHogMgMoooool2o`0001Oooooo0_l0000<ooooo`05oa0@4?nHV9Sooooo
okZj^_l000000oooool00omgMgOoV9RHooooo`02o`0000;ooooo0_l000001?nHV9SooooooiRHV?mg
MgL6ooooo`?o00007oooool2o`000003odA4A?l0003ooooo00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:Oooool00ol0003oooooooooo`04ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000Yoooo
o`03o`000?oooooooooo01Gooooo0_l0000Aooooo`;o00001_ooool00omEEEGoIVIVo`000004oooo
o`04onk^k_lb<S;o0000oc8b<P;o00000_ooool01?o^k^ko<S8bo`000?lb<S82o`0000kooooo0ol0
000Gooooo`05oiRHV?l0003o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`;o00003_ooool2o`0000;ooooo0_l0000<oooo
o`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko0000o`000?lb<S;ok^k^00;ooooo0_l0
00001?lb<S;o0000oc8b<_o^k^h;ooooo`;o00003oooool2o`0000[ooooo0_l000000omgMgOo0000
ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00;o00009oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool002Wooooo0_l0000Fooooo`;o00003oooool4o`0000Oooooo0_l0001D
ooooo`?o00003_ooool2o`0001Wooooo0_l0000>ooooo`;o00001Oooool2o`0000oooooo0_l0000O
ooooo`;o0000?_ooool002Wooooo00?o0000ooooooooool01_ooool2o`0001kooooo0_l00009oooo
o`;o00009oooool2o`0001gooooo0_l0000<ooooo`;o00005oooool2o`00027ooooo0_l00006oooo
o`;o00004?ooool2o`0002gooooo1Ol0000Dooooo`;o00005Oooool002Wooooo00?o0000oooooooo
ool01_ooool2o`0000;ooooo0_l0000Wooooo`;o00009?ooool3o`0000[ooooo0_l0000Aooooo`;o
00000_ooool2o`00027ooooo0_l0000Yooooo`;o00004?ooool2o`0002gooooo1Ol0000Dooooo`;o
00005Oooool002Wooooo00?o0000ooooooooool02_ooool2o`000003ooooool0003o000000?ooooo
0_l0000Oooooo`;o00009?ooool2o`0000_ooooo0_l0000@ooooo`?o00000_ooool2o`00023ooooo
0_l0000=ooooo`;o0000:Oooool2o`0001gooooo0_l00012ooooo`00:Oooool00ol0003ooooooooo
o`0=ooooo`;o00000oooool2o`0006Cooooo0_l0000Cooooo`;o00004?ooool2o`0000gooooo0_l0
000Tooooo`;o00000oooool2o`0001Cooooo0_l00006ooooo`?o00001oooool2o`0000Oooooo0_l0
000Gooooo`;o00000_ooool2o`0001?ooooo000Qoooooooo0000A?l00004ooooo`00:Oooool01?l0
003oooooo`000?l00008ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool2
o`000006ooooool0003o0000o`000?oooooo00002oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`?o0000
0_ooool3o`0000Gooooo00Co0000oooooooooooooooo0_l00006ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01?ooool4o`000005ooooool0003o0000o`000?ooool00_l00005oooo
o`?o00002oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool002Wooooo00Co0000ooooool0003o0000>Oooool00ol0003oooooooooo`0koooo
o`04o`000?oooooo0000o`0000Kooooo0_l00003ooooo`;o00000oooool3o`0000oooooo0_l0000E
ooooo`03o`000?oooooooooo00kooooo0_l00006ooooo`;o00003_ooool4o`00013ooooo00Co0000
oooooooooooooooo0_l00003ooooo`;o00001Oooool2o`0002_ooooo00?o0000ooooooooool02_oo
ool002Wooooo00?o0000ooooooooool0<_ooool2o`0002gooooo0_l0000Gooooo`;o00001_ooool2
o`0000?ooooo0_l000000ooooooo0000o`00000Booooo`;o00006oooool2o`0000Wooooo0_l0000F
ooooo`Co00003?ooool2o`0000Kooooo0_l00014ooooo`00:Oooool00ol0003oooooooooo`05oooo
o`;o0000:oooool2o`000003ooooool0003o000000Sooooo0_l0000Booooo`;o00003?ooool2o`00
01kooooo0_l00007ooooo`;o0000;oooool2o`00027ooooo0ol0000=ooooo`;o00007?ooool2o`00
01cooooo1Ol0000=ooooo`00:Oooool2o`0000Kooooo0_l0000^ooooo`?o00001oooool2o`0001;o
oooo0_l0000<ooooo`;o00001?ooool2o`0000Cooooo0_l00002ooooo`;o00002Oooool2o`0000?o
oooo0_l0000Aooooo`;o0000A_ooool2o`0001_ooooo0_l00004ooooo`;o00002oooool2o`0001co
oooo1Ol0000=ooooo`00:Oooool00ol0003oooooooooo`0fooooo`;o00002_ooool2o`0002?ooooo
0_l00004ooooo`;o00000_ooool2o`0000Wooooo0_l0000Fooooo`;o00001oooool2o`0000Sooooo
0_l0000<ooooo`;o00004_ooool2o`00017ooooo0_l0000Kooooo`;o00001?ooool2o`0000Oooooo
1?l00004ooooo`;o0000:_ooool002Wooooo00?o0000ooooooooool0;Oooool2o`0001?ooooo0_l0
001Iooooo`;o00001_ooool4o`0000cooooo0_l0000:ooooo`;o00001_ooool2o`0000Kooooo0_l0
000[ooooo`;o00002?ooool4o`0000Cooooo0ol0000Yooooo`00:Oooool00ol0003oooooooooo`03
ooooo`;o00002_ooool2o`0000gooooo0_l00003ooooo`;o00002?ooool3o`0001kooooo0_l0000R
ooooo`?o00002Oooool2o`0001Sooooo0_l0000;ooooo`;o00006_ooool2o`0000kooooo0_l00009
ooooo`;o00005?ooool2o`0000[ooooo0_l0000Aooooo`?o00003_ooool4o`0001Kooooo000Yoooo
o`03o`000?oooooooooo00?ooooo0_l0000:ooooo`;o000000?oooooo`000?l000002_ooool2o`00
00?ooooo0_l00009ooooo`;o00007_ooool2o`0000Kooooo0_l0000Dooooo`;o00001?ooool3o`00
00Wooooo0_l0000Hooooo`;o000000?oooooo`000?l000001?ooool5o`0000Gooooo0_l0000Soooo
o`;o00002_ooool2o`0000kooooo0_l00004ooooo`;o00001_ooool2o`0001Kooooo0_l00006oooo
o`;o00001_ooool4o`0001Kooooo000Yooooo`;o00004oooool2o`0000Wooooo0_l0000;ooooo`;o
0000:_ooool2o`0001Cooooo0_l00008ooooo`;o00008oooool2o`0000Cooooo1Ol00002ooooo`;o
000000?oooooo`000?l000001Oooool2o`0000;ooooo0_l0000Hooooo`;o00001Oooool2o`0001?o
oooo0_l0000<ooooo`;o00006_ooool2o`0000;ooooo0_l0000Pooooo`00:Oooool00ol0003ooooo
ooooo`0Iooooo`?o000000?oooooo`000?l000002oooool2o`0000Kooooo0_l00002ooooo`;o0000
4_ooool2o`0002[ooooo0_l0000`ooooo`;o00002?ooool2o`0000;ooooo0_l00002ooooo`;o0000
6oooool2o`0001Gooooo0_l0000Nooooo`;o00001_ooool4o`0001Gooooo0_l0000;ooooo`00:Ooo
ool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o00003_ooool3o`0000Wooooo0_l0
0002ooooo`;o00001oooool2o`0000;ooooo0_l0000Booooo`;o00001Oooool2o`0000Gooooo0_l0
000Looooo`;o0000;Oooool2o`0001?ooooo0_l0000booooo`;o00007_ooool2o`0000Sooooo0_l0
000Eooooo`;o00002oooool002Wooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2
o`0001[ooooo0_l00002ooooo`;o00003Oooool2o`000003ooooool0003o000000?ooooo0_l00009
ooooo`;o00001?ooool2o`0000Gooooo0_l0001;ooooo`;o00002?ooool2o`0002Oooooo0_l0000n
ooooo`;o00008_ooool002Wooooo00?o0000ooooooooool06?ooool2o`0001kooooo0_l000000ooo
oooo0000o`000003ooooo`;o00002Oooool2o`0005Gooooo0_l0000;ooooo`;o00009oooool2o`00
04?ooooo0_l00003ooooo`;o00001oooool2o`0000oooooo000Yooooo`;o00001Oooool2o`0000oo
oooo1Ol0000aooooo`;o0000EOooool2o`0001?ooooo0_l0000Jooooo`;o0000;oooool2o`0001Ko
oooo0ol00003ooooo`;o00001oooool2o`0000oooooo000Yooooo`03o`000?oooooooooo00Cooooo
0_l0000?ooooo`Co00002Oooool2o`0002Oooooo0_l00004ooooo`;o00003oooool2o`0000_ooooo
1?l0000`ooooo`;o00001oooool2o`0000Wooooo0_l0000Cooooo`;o00001Oooool3o`0000?ooooo
0_l00006ooooo`;o00005?ooool2o`0000_ooooo0_l0000?ooooo`;o00001Oooool2o`000003oooo
ool0003o000001_ooooo000Yooooo`03o`000?oooooooooo02;ooooo0_l0000]ooooo`;o00003ooo
ool2o`0000_ooooo1?l0000Booooo`;o00000_ooool2o`0001Sooooo0_l00007ooooo`;o00000_oo
ool2o`0001[ooooo1_l00002ooooo`Co000000Coooooo`000?l0003o00001Oooool2o`0001Cooooo
0_l0000Looooo`;o00002?ooool2o`0000Cooooo0_l0000Eooooo`00:Oooool00ol0003ooooooooo
o`0/ooooo`;o00005_ooool2o`0001Wooooo0_l00005ooooo`;o00005oooool2o`000004ooooool0
003o0000ooooo`;o00000_ooool2o`0000oooooo0_l0000Dooooo`;o00002Oooool2o`00013ooooo
1Ol00004ooooo`;o00000_ooool2o`0004Wooooo0ol0000Dooooo`00:Oooool00ol0003ooooooooo
o`0<ooooo`Co00007?ooool2o`0001Kooooo0_l00002ooooo`;o00000oooool4o`0000kooooo0_l0
0005ooooo`;o00005oooool2o`000003ooooool0003o000000;o00005?ooool2o`0001cooooo0_l0
00000ooooooo0000o`00000booooo`;o0000;oooool2o`0000Cooooo0_l00006ooooo`;o00003?oo
ool002Wooooo0_l0000=ooooo`Co0000>?ooool2o`0000?ooooo1?l0000Zooooo`;o00001oooool2
o`0000[ooooo1?l0000Tooooo`;o00001_ooool2o`0002gooooo0_l0000Eooooo`;o00006?ooool2
o`0000cooooo0_l0000<ooooo`00:Oooool00ol0003oooooooooo`0Kooooo`;o0000C?ooool2o`00
013ooooo0_l00004ooooo`;o00003Oooool4o`0002cooooo0_l00014ooooo`;o0000=?ooool000Ko
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01_ooooo0_l00016ooooo`;o00001?ooool4
o`0001Cooooo0_l0000<ooooo`;o00004Oooool2o`0002Wooooo0_l0000Eooooo`;o0000<oooool2
o`00027ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool09?oo
ool2o`00017ooooo0_l000000ooooooo0000o`00000Fooooo`;o00003oooool2o`0000Kooooo0_l0
000Rooooo`;o00004Oooool2o`0002Cooooo0_l00003ooooo`;o00005?ooool3o`00013ooooo0_l0
0009ooooo`;o00005_ooool2o`0000;ooooo0_l0000Mooooo`001_ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;o00008_ooool2o`00017ooooo0_l000000ooooooo0000o`000002o`00013ooooo1_l0
001Fooooo`;o00006?ooool2o`0000;ooooo0_l0000Iooooo`;o00004Oooool2o`0000Wooooo0_l0
000Jooooo`;o00007Oooool000Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ
8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool5o`0001gooooo0_l0000Kooooo`;o00004?oo
ool4o`0001Oooooo0_l0000Aooooo`;o00007_ooool2o`0000;ooooo0_l00008ooooo`;o00006?oo
ool2o`0001Wooooo0_l000000ooooooo0000o`00000Qooooo`;o0000=Oooool000Kooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`;o00006?ooool2o`0000Kooooo0_l00018ooooo`?o00004?ooool2o`0001kooooo
0_l00002ooooo`;o00001oooool2o`0003Cooooo0_l000000ooooooo0000o`00000Oooooo`Ko0000
2oooool2o`0001;ooooo0_l0000Booooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Cooooo
0_l000000ooooooo0000o`000013ooooo`;o00000_ooool2o`0000Sooooo0_l0000Hooooo`;o0000
8oooool2o`0001Cooooo0_l0000Xooooo`;o00006?ooool2o`0000;ooooo0_l0000:ooooo`Co0000
4Oooool2o`0001;ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zj
oooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool01?l0003oooooooooooooool2o`00
00gooooo0_l00002ooooo`;o00000_ooool2o`0000Oooooo1?l00005ooooo`;o000000?oooooo`00
0?l00000;Oooool2o`0000;ooooo0_l0000Rooooo`;o00004Oooool2o`0002Kooooo0_l0000Xoooo
o`;o0000:?ooool4o`0002Gooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnH
V9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`04o`000?ooooooooooooooo`;o00003Ooo
ool2o`0000Kooooo0_l00007ooooo`Co00001Oooool2o`000003ooooool0003o000000Kooooo0_l0
000Vooooo`;o0000>?ooool2o`0003Sooooo0_l0001Yooooo`00:Oooool2o`0003Kooooo0_l0000V
ooooo`;o00005Oooool2o`0005_ooooo0_l0001Yooooo`00:Oooool00ol0003oooooooooo`0Loooo
o`;o0000E_ooool2o`0004oooooo0_l0001eooooo`00:Oooool00ol0003oooooooooo`0Looooo`;o
000000?oooooo`000?l000003oooool2o`0003[ooooo0_l0001Gooooo`;o0000@_ooool2o`0000Co
oooo0_l0000[ooooo`00:Oooool00ol0003oooooooooo`0Oooooo`;o00003oooool2o`0003[ooooo
0_l0002Kooooo`;o00001?ooool2o`0002_ooooo000Yooooo`03o`000?oooooooooo05Kooooo0_l0
000;ooooo`;o00004_ooool2o`000<?ooooo000Yooooo`;o00000oooool2o`00027ooooo0_l0000_
ooooo`;o00001?ooool4o`0000?ooooo1?l00008ooooo`;o00001_ooool2o`0001cooooo0_l0000?
ooooo`;o0000?Oooool2o`00043ooooo0_l0000Cooooo`00:Oooool00ol0003oooooooooo`02oooo
o`;o00008Oooool2o`0003Gooooo1Ol00004ooooo`;o00002?ooool2o`0002Cooooo0_l0000?oooo
o`;o00008Oooool2o`0001[ooooo0_l00010ooooo`;o00004oooool002Wooooo00?o0000oooooooo
ool04?ooool2o`0002oooooo0_l00002ooooo`;o00002Oooool2o`0000gooooo0_l0000hooooo`;o
0000;_ooool2o`00077ooooo000Yooooo`03o`000?oooooooooo013ooooo0_l000000ooooooo0000
o`00000Sooooo`;o00001oooool2o`0000;ooooo0ol00008ooooo`;o00003?ooool2o`0001[ooooo
0_l0000Hooooo`;o00000oooool2o`00013ooooo0_l0000;ooooo`;o0000:Oooool2o`0000Cooooo
0_l0001Aooooo`00:Oooool00ol0003oooooooooo`0Cooooo`;o00008oooool2o`0000cooooo0_l0
000Fooooo`;o00004?ooool2o`0000Sooooo0_l0000Hooooo`;o00005Oooool2o`0000Gooooo0_l0
0004ooooo`Co00009oooool5o`000003ooooool0003o0000047ooooo0_l0000>ooooo`00:Oooool2
o`0001gooooo0_l00002ooooo`;o0000C_ooool2o`0001?ooooo0_l00005ooooo`;o00006_ooool2
o`0000Oooooo1?l00005ooooo`;o00006_ooool2o`0000cooooo1?l0000cooooo`;o00003oooool2
o`0000kooooo000Yooooo`03o`000?oooooooooo01[ooooo1?l00002ooooo`;o0000Hoooool2o`00
00Gooooo0_l0000?ooooo`;o00002Oooool2o`0000Oooooo1?l0000Qooooo`;o00006?ooool2o`00
02Wooooo0_l0000Oooooo`00:Oooool00ol0003oooooooooo`0Jooooo`;o0000POooool2o`00057o
oooo0_l0001:ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0loooool2o`0004Oooooo000>oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`3?ooooo`;o00008_ooool2o`0004Oooooo000>ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`03ooooo`?o0000coooool2o`0003[ooooo0_l0000_
ooooo`003_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`3oooooo`cooooo0_l0000_ooooo`003_ooool01Ol0003ooooooooooooooooo
000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo01gooooo0_l0
000<ooooo`;o0000ooooool@ooooo`003_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Mooooo`;o00003?ooool2o`0000cooooo0_l0
003oooooo`;ooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo03Wooooo0_l0003oooooo`;ooooo000>ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooo
oooo0;Kooooo0_l00024ooooo`00:Oooool00ol0003oooooooooo`2fooooo`;o0000Q?ooool002Wo
oooo00?o0000ooooooooool0Eoooool2o`000>?ooooo000Yooooo`03o`000?oooooooooo04?ooooo
0_l0000Booooo`;o0000Soooool2o`0001gooooo0_l0000Qooooo`;o00004?ooool002Wooooo0_l0
0014ooooo`;o0000Xoooool2o`0001gooooo0_l0000Qooooo`;o00004?ooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?oooooooooo
ooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003o
ooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0
003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooo
oooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oo
oooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo
?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo
0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`007oooool4o`00
0003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool0
1Oooool3o`000?oooooo?Oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`007oooool00omEEEGoIVIVo`00003oooooodOooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .39642 Mdot
.02762 .39916 Mdot
.02952 .31136 Mdot
.03143 .3011 Mdot
.03333 .2515 Mdot
.03524 .32908 Mdot
.03714 .30823 Mdot
.03905 .4453 Mdot
.04095 .43905 Mdot
.04286 .32124 Mdot
.04476 .35079 Mdot
.04667 .42897 Mdot
.04857 .34986 Mdot
.05048 .34063 Mdot
.05238 .40842 Mdot
.05429 .25721 Mdot
.05619 .3149 Mdot
.0581 .34593 Mdot
.06 .31281 Mdot
.0619 .24822 Mdot
.06381 .32463 Mdot
.06571 .37783 Mdot
.06762 .35595 Mdot
.06952 .33171 Mdot
.07143 .38049 Mdot
.07333 .35296 Mdot
.07524 .34859 Mdot
.07714 .31097 Mdot
.07905 .27035 Mdot
.08095 .39335 Mdot
.08286 .28689 Mdot
.08476 .43972 Mdot
.08667 .44258 Mdot
.08857 .25767 Mdot
.09048 .24249 Mdot
.09238 .24332 Mdot
.09429 .38848 Mdot
.09619 .3289 Mdot
.0981 .31284 Mdot
.1 .43023 Mdot
.1019 .39407 Mdot
.10381 .2472 Mdot
.10571 .27752 Mdot
.10762 .39933 Mdot
.10952 .38702 Mdot
.11143 .29343 Mdot
.11333 .34192 Mdot
.11524 .42925 Mdot
.11714 .37478 Mdot
.11905 .28109 Mdot
.12095 .42881 Mdot
.12286 .33283 Mdot
.12476 .40721 Mdot
.12667 .25825 Mdot
.12857 .25305 Mdot
.13048 .44194 Mdot
.13238 .44228 Mdot
.13429 .32331 Mdot
.13619 .41318 Mdot
.1381 .38216 Mdot
.14 .30961 Mdot
.1419 .27228 Mdot
.14381 .32381 Mdot
.14571 .3219 Mdot
.14762 .43464 Mdot
.14952 .44237 Mdot
.15143 .31904 Mdot
.15333 .25821 Mdot
.15524 .33352 Mdot
.15714 .31092 Mdot
.15905 .32314 Mdot
.16095 .26927 Mdot
.16286 .3288 Mdot
.16476 .29432 Mdot
.16667 .32381 Mdot
.16857 .27752 Mdot
.17048 .40756 Mdot
.17238 .34275 Mdot
.17429 .31727 Mdot
.17619 .36955 Mdot
.1781 .24182 Mdot
.18 .39272 Mdot
.1819 .31008 Mdot
.18381 .24613 Mdot
.18571 .44681 Mdot
.18762 .25729 Mdot
.18952 .25324 Mdot
.19143 .27854 Mdot
.19333 .34135 Mdot
.19524 .25773 Mdot
.19714 .37422 Mdot
.19905 .29112 Mdot
.20095 .3377 Mdot
.20286 .27886 Mdot
.20476 .33491 Mdot
.20667 .26349 Mdot
.20857 .33875 Mdot
.21048 .43134 Mdot
.21238 .41357 Mdot
.21429 .34606 Mdot
.21619 .39931 Mdot
.2181 .35837 Mdot
.22 .42423 Mdot
.2219 .40193 Mdot
.22381 .2682 Mdot
.22571 .25195 Mdot
.22762 .30427 Mdot
.22952 .29744 Mdot
.23143 .33791 Mdot
.23333 .30301 Mdot
.23524 .33038 Mdot
.23714 .31117 Mdot
.23905 .43903 Mdot
.24095 .23703 Mdot
.24286 .47778 Mdot
.24476 .32677 Mdot
.24667 .32671 Mdot
.24857 .44569 Mdot
.25048 .44338 Mdot
.25238 .39126 Mdot
.25429 .34713 Mdot
.25619 .3096 Mdot
.2581 .32627 Mdot
.26 .2705 Mdot
.2619 .30568 Mdot
.26381 .28557 Mdot
.26571 .24662 Mdot
.26762 .24034 Mdot
.26952 .39624 Mdot
.27143 .29046 Mdot
.27333 .36468 Mdot
.27524 .40007 Mdot
.27714 .41784 Mdot
.27905 .32879 Mdot
.28095 .29679 Mdot
.28286 .29489 Mdot
.28476 .37016 Mdot
.28667 .26151 Mdot
.28857 .32763 Mdot
.29048 .43668 Mdot
.29238 .40953 Mdot
.29429 .22582 Mdot
.29619 .33455 Mdot
.2981 .32752 Mdot
.3 .31596 Mdot
.3019 .24094 Mdot
.30381 .44699 Mdot
.30571 .49273 Mdot
.30762 .26958 Mdot
.30952 .28664 Mdot
.31143 .34196 Mdot
.31333 .36367 Mdot
.31524 .3486 Mdot
.31714 .33276 Mdot
.31905 .27337 Mdot
.32095 .36404 Mdot
.32286 .3634 Mdot
.32476 .3261 Mdot
.32667 .44466 Mdot
.32857 .39103 Mdot
.33048 .3649 Mdot
.33238 .3685 Mdot
.33429 .31251 Mdot
.33619 .41358 Mdot
.3381 .23552 Mdot
.34 .28729 Mdot
.3419 .39787 Mdot
.34381 .44638 Mdot
.34571 .25888 Mdot
.34762 .33599 Mdot
.34952 .35509 Mdot
.35143 .27059 Mdot
.35333 .33622 Mdot
.35524 .33988 Mdot
.35714 .25856 Mdot
.35905 .26533 Mdot
.36095 .43839 Mdot
.36286 .25645 Mdot
.36476 .3621 Mdot
.36667 .324 Mdot
.36857 .28623 Mdot
.37048 .33823 Mdot
.37238 .42058 Mdot
.37429 .26794 Mdot
.37619 .39009 Mdot
.3781 .26511 Mdot
.38 .43764 Mdot
.3819 .24216 Mdot
.38381 .43925 Mdot
.38571 .41498 Mdot
.38762 .2841 Mdot
.38952 .3305 Mdot
.39143 .23995 Mdot
.39333 .30714 Mdot
.39524 .27686 Mdot
.39714 .44588 Mdot
.39905 .38128 Mdot
.40095 .42217 Mdot
.40286 .27287 Mdot
.40476 .31484 Mdot
.40667 .28326 Mdot
.40857 .32615 Mdot
.41048 .32647 Mdot
.41238 .26765 Mdot
.41429 .2529 Mdot
.41619 .33261 Mdot
.4181 .39917 Mdot
.42 .27706 Mdot
.4219 .3428 Mdot
.42381 .31973 Mdot
.42571 .26223 Mdot
.42762 .3517 Mdot
.42952 .37021 Mdot
.43143 .33826 Mdot
.43333 .25721 Mdot
.43524 .2649 Mdot
.43714 .39818 Mdot
.43905 .33216 Mdot
.44095 .41003 Mdot
.44286 .26665 Mdot
.44476 .38065 Mdot
.44667 .43614 Mdot
.44857 .32202 Mdot
.45048 .41931 Mdot
.45238 .2689 Mdot
.45429 .23513 Mdot
.45619 .26139 Mdot
.4581 .25221 Mdot
.46 .40385 Mdot
.4619 .33769 Mdot
.46381 .40823 Mdot
.46571 .3081 Mdot
.46762 .26613 Mdot
.46952 .3117 Mdot
.47143 .34508 Mdot
.47333 .36502 Mdot
.47524 .35135 Mdot
.47714 .31608 Mdot
.47905 .33572 Mdot
.48095 .4031 Mdot
.48286 .33947 Mdot
.48476 .40021 Mdot
.48667 .26845 Mdot
.48857 .3043 Mdot
.49048 .24446 Mdot
.49238 .32354 Mdot
.49429 .44059 Mdot
.49619 .33335 Mdot
.4981 .36643 Mdot
.5 .3382 Mdot
.5019 .32619 Mdot
.50381 .32195 Mdot
.50571 .38228 Mdot
.50762 .32689 Mdot
.50952 .31132 Mdot
.51143 .37781 Mdot
.51333 .35855 Mdot
.51524 .34107 Mdot
.51714 .25492 Mdot
.51905 .27481 Mdot
.52095 .44071 Mdot
.52286 .42236 Mdot
.52476 .37189 Mdot
.52667 .35151 Mdot
.52857 .23403 Mdot
.53048 .30969 Mdot
.53238 .36184 Mdot
.53429 .39294 Mdot
.53619 .34588 Mdot
.5381 .32539 Mdot
.54 .25546 Mdot
.5419 .36743 Mdot
.54381 .24248 Mdot
.54571 .25636 Mdot
.54762 .31671 Mdot
.54952 .37089 Mdot
.55143 .35883 Mdot
.55333 .26957 Mdot
.55524 .27 Mdot
.55714 .43185 Mdot
.55905 .35046 Mdot
.56095 .3563 Mdot
.56286 .29553 Mdot
.56476 .29606 Mdot
.56667 .28602 Mdot
.56857 .39225 Mdot
.57048 .42957 Mdot
.57238 .29566 Mdot
.57429 .28632 Mdot
.57619 .25124 Mdot
.5781 .23227 Mdot
.58 .29245 Mdot
.5819 .24751 Mdot
.58381 .24398 Mdot
.58571 .41197 Mdot
.58762 .41858 Mdot
.58952 .41539 Mdot
.59143 .31943 Mdot
.59333 .4019 Mdot
.59524 .28255 Mdot
.59714 .23597 Mdot
.59905 .41175 Mdot
.60095 .49746 Mdot
.60286 .37292 Mdot
.60476 .27461 Mdot
.60667 .40089 Mdot
.60857 .44035 Mdot
.61048 .3915 Mdot
.61238 .34456 Mdot
.61429 .43155 Mdot
.61619 .36145 Mdot
.6181 .31969 Mdot
.62 .36711 Mdot
.6219 .30903 Mdot
.62381 .34802 Mdot
.62571 .34868 Mdot
.62762 .32271 Mdot
.62952 .38582 Mdot
.63143 .25062 Mdot
.63333 .43238 Mdot
.63524 .31133 Mdot
.63714 .41683 Mdot
.63905 .32684 Mdot
.64095 .22317 Mdot
.64286 .27072 Mdot
.64476 .32699 Mdot
.64667 .24633 Mdot
.64857 .33836 Mdot
.65048 .25305 Mdot
.65238 .32341 Mdot
.65429 .31624 Mdot
.65619 .31038 Mdot
.6581 .44041 Mdot
.66 .37818 Mdot
.6619 .33377 Mdot
.66381 .37508 Mdot
.66571 .2885 Mdot
.66762 .26757 Mdot
.66952 .40314 Mdot
.67143 .3207 Mdot
.67333 .28768 Mdot
.67524 .36868 Mdot
.67714 .25171 Mdot
.67905 .38901 Mdot
.68095 .363 Mdot
.68286 .39296 Mdot
.68476 .32463 Mdot
.68667 .44182 Mdot
.68857 .34939 Mdot
.69048 .25815 Mdot
.69238 .38215 Mdot
.69429 .33936 Mdot
.69619 .31713 Mdot
.6981 .2272 Mdot
.7 .43237 Mdot
.7019 .39816 Mdot
.70381 .2458 Mdot
.70571 .37329 Mdot
.70762 .28045 Mdot
.70952 .26273 Mdot
.71143 .36392 Mdot
.71333 .4318 Mdot
.71524 .22348 Mdot
.71714 .24198 Mdot
.71905 .41763 Mdot
.72095 .41426 Mdot
.72286 .39905 Mdot
.72476 .27123 Mdot
.72667 .3684 Mdot
.72857 .40708 Mdot
.73048 .44192 Mdot
.73238 .27372 Mdot
.73429 .26223 Mdot
.73619 .36449 Mdot
.7381 .34087 Mdot
.74 .39858 Mdot
.7419 .43381 Mdot
.74381 .40281 Mdot
.74571 .39648 Mdot
.74762 .36396 Mdot
.74952 .35865 Mdot
.75143 .38947 Mdot
.75333 .36547 Mdot
.75524 .39128 Mdot
.75714 .48417 Mdot
.75905 .40018 Mdot
.76095 .36551 Mdot
.76286 .27416 Mdot
.76476 .35119 Mdot
.76667 .34807 Mdot
.76857 .31737 Mdot
.77048 .42107 Mdot
.77238 .3079 Mdot
.77429 .32162 Mdot
.77619 .30391 Mdot
.7781 .34443 Mdot
.78 .34973 Mdot
.7819 .43151 Mdot
.78381 .27332 Mdot
.78571 .27628 Mdot
.78762 .41903 Mdot
.78952 .28352 Mdot
.79143 .38453 Mdot
.79333 .27971 Mdot
.79524 .26971 Mdot
.79714 .26356 Mdot
.79905 .28739 Mdot
.80095 .43989 Mdot
.80286 .42936 Mdot
.80476 .34923 Mdot
.80667 .33789 Mdot
.80857 .35474 Mdot
.81048 .25693 Mdot
.81238 .36111 Mdot
.81429 .26946 Mdot
.81619 .23397 Mdot
.8181 .32783 Mdot
.82 .34654 Mdot
.8219 .30454 Mdot
.82381 .261 Mdot
.82571 .26401 Mdot
.82762 .35178 Mdot
.82952 .28213 Mdot
.83143 .32565 Mdot
.83333 .43776 Mdot
.83524 .29925 Mdot
.83714 .24295 Mdot
.83905 .30363 Mdot
.84095 .37687 Mdot
.84286 .36706 Mdot
.84476 .33964 Mdot
.84667 .35419 Mdot
.84857 .27306 Mdot
.85048 .40251 Mdot
.85238 .46342 Mdot
.85429 .40119 Mdot
.85619 .2881 Mdot
.8581 .43858 Mdot
.86 .40315 Mdot
.8619 .35125 Mdot
.86381 .37925 Mdot
.86571 .39442 Mdot
.86762 .33658 Mdot
.86952 .31474 Mdot
.87143 .25751 Mdot
.87333 .23458 Mdot
.87524 .37081 Mdot
.87714 .30442 Mdot
.87905 .26296 Mdot
.88095 .24908 Mdot
.88286 .25163 Mdot
.88476 .32918 Mdot
.88667 .32133 Mdot
.88857 .28106 Mdot
.89048 .44461 Mdot
.89238 .32036 Mdot
.89429 .30542 Mdot
.89619 .4019 Mdot
.8981 .38759 Mdot
.9 .24362 Mdot
.9019 .25575 Mdot
.90381 .29813 Mdot
.90571 .23279 Mdot
.90762 .30753 Mdot
.90952 .43995 Mdot
.91143 .38561 Mdot
.91333 .34652 Mdot
.91524 .40051 Mdot
.91714 .36733 Mdot
.91905 .31836 Mdot
.92095 .25515 Mdot
.92286 .39961 Mdot
.92476 .30343 Mdot
.92667 .31735 Mdot
.92857 .26155 Mdot
.93048 .2863 Mdot
.93238 .30191 Mdot
.93429 .28196 Mdot
.93619 .27502 Mdot
.9381 .37027 Mdot
.94 .26854 Mdot
.9419 .26329 Mdot
.94381 .25442 Mdot
.94571 .28634 Mdot
.94762 .32731 Mdot
.94952 .3547 Mdot
.95143 .44249 Mdot
.95333 .24988 Mdot
.95524 .39007 Mdot
.95714 .33731 Mdot
.95905 .30208 Mdot
.96095 .28593 Mdot
.96286 .47369 Mdot
.96476 .29208 Mdot
.96667 .40131 Mdot
.96857 .4221 Mdot
.97048 .23555 Mdot
.97238 .3296 Mdot
.97429 .27106 Mdot
.97619 .42383 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0<?ooooo0_l0000Fooooo`;o0000Goooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`1Cooooo`;o0000K_ooool2o`00013ooooo0_l00004ooooo`;o0000Gooo
ool000Co00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05?ooooo0_l00020ooooo`;o0000IOoo
ool000Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o
MgMgoc8b<_ooool01?ooool3o`0009oooooo0_l0000=ooooo`;o0000Boooool2o`0001_ooooo0_l0
000Rooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0@_ooool2o`0001gooooo
0_l0000Tooooo`;o00005_ooool2o`0000gooooo0_l00005ooooo`;o0000A?ooool2o`00013ooooo
0_l00009ooooo`;o00004oooool2o`0000gooooo0006ooooo`05oa0@4?ooooooooooooooool@4100
3oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
@_ooool2o`0000Oooooo0_l0000Dooooo`;o00003oooool2o`0001?ooooo0_l0000/ooooo`;o0000
E_ooool2o`0001kooooo0_l0000=ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool04_ooool2o`0001[ooooo0_l0000Kooooo`;o00002Oooool2o`0001Oooooo0_l000000ooooooo
0000o`00000_ooooo`;o0000=_ooool2o`0002Gooooo0_l0000hooooo`001_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0
003oooooooooo`0Booooo`;o00006_ooool4o`0001Sooooo0_l0000:ooooo`;o00005oooool2o`00
027ooooo0_l0000?ooooo`;o00002oooool2o`0001?ooooo0_l0000@ooooo`;o00000_ooool2o`00
02Gooooo0_l0000Booooo`;o00009?ooool002Wooooo0_l0000:ooooo`;o00002oooool2o`0001So
oooo0_l0000Hooooo`;o0000A_ooool2o`0001cooooo0_l0000Cooooo`;o00004?ooool2o`0003Oo
oooo0_l00004ooooo`;o00009?ooool002Wooooo00Co0000ooooool0003o00002?ooool2o`0000_o
oooo0_l0000Uooooo`;o0000BOooool2o`0002Cooooo1?l0000>ooooo`;o00003?ooool2o`00043o
oooo0_l0000Eooooo`;o00004oooool002Wooooo00Co0000ooooool0003o00007Oooool2o`0001;o
oooo0_l00009ooooo`;o0000>oooool2o`0000cooooo0_l0000Aooooo`;o00001Oooool2o`0000[o
oooo0_l0000@ooooo`;o00001?ooool2o`0000Kooooo0_l00010ooooo`;o00001Oooool2o`0000Co
oooo0_l00005ooooo`;o000000?oooooo`000?l000004oooool002Wooooo00?o0000ooooooooool0
1_ooool2o`0000Wooooo0_l0000:ooooo`?o00001_ooool2o`0000Wooooo1?l0000_ooooo`;o0000
00?oooooo`000?l000000_l0000?ooooo`;o00001?ooool2o`0001Wooooo0_l00005ooooo`Co0000
8?ooool2o`0000_ooooo0_l0000Tooooo`;o00004_ooool2o`0000Sooooo0_l00004ooooo`;o0000
1Oooool2o`0001Kooooo000Yooooo`03o`000?oooooooooo00Kooooo0_l00009ooooo`;o00002_oo
ool2o`0000Oooooo0_l00009ooooo`Co00007?ooool2o`00017ooooo0_l000000ooooooo0000o`00
0002o`0001Gooooo0_l00005ooooo`;o00006oooool2o`0002gooooo0_l0000Tooooo`;o00000ooo
ool2o`0000gooooo0_l0000@ooooo`;o00006oooool002Wooooo0_l0000hooooo`;o00006?ooool2
o`0001_ooooo0_l0000=ooooo`;o00000_ooool2o`0000Cooooo0_l0001@ooooo`;o00001_ooool2
o`0001;ooooo0_l00007ooooo`;o00003oooool2o`0000kooooo0_l00002ooooo`;o00005oooool0
02Wooooo00?o0000ooooooooool0=oooool2o`0000Cooooo0_l0000Yooooo`;o00000oooool3o`00
00Wooooo0_l00002ooooo`;o00000_ooool4o`0000Kooooo0_l0000nooooo`;o00003?ooool2o`00
00Kooooo0_l0000Booooo`;o00001oooool2o`0000oooooo0_l0000Booooo`;o00005oooool002Wo
oooo00?o0000ooooooooool03_ooool2o`0001Sooooo0_l00006ooooo`Co000000Wo410@oooooooo
ooook^k^oc8b<_l0003o<S8bonk^k_ooool00_l000001Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo
0_l0000>ooooo`;o00003?ooool4o`0000?ooooo1Ol00003ooooo`04onk^k_lb<S;o0000oc8b<P;o
00000_ooool01_o^k^ko<S8bo`000?lb<S;ok^k^ooooo`;o000000?oooooo`000?l000000oooool2
o`0000Cooooo0_l0000Dooooo`;o000000KooooooiRHV?l@413o0000oc8b<_o<c<`3ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo0_l00006oooo
o`;o00004Oooool2o`0000Wooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8b
onk^kP02o`000003ooooooo^k^ko<S8b00?o00009oooool2o`000005odA4A?l0003o0000oc8b<_oM
gMd00_ooool01Oo^k^ko<S8bo`000?l0003ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`00:Oooool00ol0003oooooooooo`0>ooooo`;o00004_ooool2o`0000Cooooo0_l00008oooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01?ooool2o`0000kooooo0_l000000ooooooo0000o`000009ooooo`;o00001Ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgo`000?l0003oV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01?ooool2o`0000Wooooo0_l0000Dooooo`;o000000Kooooooa0@
4?nj^[[oooooogMgMolb<S83ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_l000001_ooooooMgMg
oiRHV?ooooooV9RHogMgM`Cooooo0_l0000Iooooo`Co00002?ooool2o`0000?ooooo00GoMgMgoiRH
V?l0003o0000ogMgM`02o`000004oooooomgMgOoV9RHooooo`;o00002Oooool2o`0001cooooo0_l0
0003ooooo`06ogMgMolb<S;ooooooooooomgMgOoV9RH0_l000002OmgMgOoooooooooooooooooMgMg
oiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool00ol0003oooooooooo`0Gooooo`;o00002Oooool2
o`0000Oooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41005oooool2o`00017ooooo00?oV9RHob4Q8Oo^k^h0
0oooool4o`000004ooooool@413oooooooooo`;o00000oooool00ol@413oooooooooo`0Hooooo`;o
00004?ooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@o`000?l0003ooooooa0@4003
ooooo`03oa0@4?oooooooooo01oooooo0_l00005ooooo`Go00000oooool01Ol@413oooooo`000?l0
003o410@00?ooooo00Go410@oooooooooooooooooa0@4009ooooo`;o00006oooool2o`0000Gooooo
00Co0000oooooooooooo410@0oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooo
ooooool00Oooool002Wooooo0_l0000Hooooo`;o00004_ooool2o`0000Gooooo0_l00002ooooo`;o
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0:Oooool00onH
V9So8B4Qonk^kP02ooooo`;o00000oooool00ol0003oooooooooo`02o`0000?ooooo00?o0000oooo
ooooool06?ooool2o`0000oooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`00000Iooooo`;o00003Oooool01?m4A4CogMgMoooo
ool00004ooooo`03o`000?oooooo000000Co000000?oooooo`000?ooool00_ooool00ol0003ooooo
ooooo`0Tooooo`;o00001?ooool01OmgMgOo<S8boooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo007ooooo000Yooooo`03o`000?oooooooooo01_o
oooo0_l0000Eooooo`;o00000_ooool2o`0000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo02[ooooo00?oMgMgofIVI_ooool00_ooool00ol0003oooooo`000002o`00
00?ooooo00Go0000ooooooooooooooooo`00000Zooooo`03oa0@4?l0003o^[Zj00?ooooo00?o0000
ooooool000000_l00003ooooo`05o`000?ooooooooooooooool000006Oooool2o`0000gooooo00Co
gMgMoeEEEOoooooo00001?ooool00ol0003oooooooooo`04o`000003ooooool0003ooooo00;ooooo
00Co0000oooooooooooooooo0_l0000Aooooo`;o00003Oooool2o`0000;ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo000Yooooo`03o`000?oooooooooo00oooooo0_l0000:ooooo`;o00005Oooool0
0ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooo
oooooooo410@00Gooooo0_l0000=ooooo`;o00004Oooool2o`0000Cooooo0_l00002ooooo`05oa0@
4?oooooo0000o`000?l@41000oooool01Ol@413ooooooooooooooooo410@02Wooooo1?l00003oooo
o`05oa0@4?oooooo0000o`000?l@41000oooool01Ol@413ooooooooooooooooo410@02Wooooo00?o
MgMgolc<c?l000001?ooool00ol@413oooooooooo`02o`0000?ooooo00Go410@oooooooooooooooo
oa0@4003ooooo`;o00004Oooool2o`0000cooooo0ol00002ooooo`;o00000oooool2o`000005oa0@
4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo000Yooooo`03
o`000?oooooooooo00oooooo0_l0000Qooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0000gooooo0_l00008
ooooo`;o00001oooool3o`000003okZj^_ooooooV9RH00;o00000_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Xooooo`03oa0@4?l0003o000000;o0000
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`Co00006Oooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool2
o`000004oiRHV?ooooooV9RHogMgM`cooooo0_l0000Fooooo`;o00000oooool2o`0000?ooooo0_l0
00001OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00
:Oooool00ol0003oooooooooo`0`ooooo`03oeEEEOmVIVKo000000;ooooo0_l000001Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`;o00005?ooool2o`00
00Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo00GoZJVYoa0@4?l0003o410@ojVYZ@02o`000006
ooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0
000Jooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`;o0000
00Co<S8bo`000?lb<S;ok^k^3?ooool2o`0001_ooooo1?l00002ooooo`;o000000Co<S8bo`000?lb
<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Yooooo`;o00006Oooool2o`00
013ooooo0_l00009ooooo`;o00005Oooool2o`0000;ooooo0_l0001Hooooo`;o000000?oooooo`00
0?l000000_l0001jooooo`;o00003oooool002Wooooo00?o0000ooooooooool06?ooool2o`00013o
oooo0_l0000Booooo`;o00003oooool3o`0005Sooooo0_l000000ooooooo0000o`00001Booooo`;o
00005?ooool2o`0002?ooooo000Yooooo`04o`000?oooooo0000o`0003gooooo0_l0000?ooooo`;o
0000/?ooool2o`0001Cooooo0_l00007ooooo`;o00001oooool2o`00017ooooo000Yooooo`04o`00
0?oooooo0000o`0003gooooo1?l00007ooooo`;o0000Aoooool2o`0005[ooooo0_l0000=ooooo`;o
00000oooool2o`0000_ooooo0_l00003ooooo`;o00002?ooool4o`0000Oooooo0_l0000Aooooo`00
:Oooool01?l0003oooooooooooooool2o`0003_ooooo1?l00007ooooo`;o0000:?ooool2o`0001Go
oooo0_l00006ooooo`;o0000FOooool3o`0000gooooo0_l00003ooooo`;o00002oooool2o`0000?o
oooo0_l00002ooooo`;o00001?ooool2o`0001cooooo000Qoooooooo0000A?l00004ooooo`00:Ooo
ool3o`0000Oooooo0ol00003ooooo`;o00001Oooool3o`0000_ooooo0_l00003ooooo`;o00001Ooo
ool3o`0000Wooooo00?o0000ooooooooool01?ooool2o`0000Cooooo0_l0000:ooooo`03o`000?oo
oooooooo00Wooooo0ol00009ooooo`03o`000?oooooooooo00Wooooo0_l0000;ooooo`03o`000?oo
oooooooo00Gooooo0_l00002ooooo`03o`000?oooooooooo00Gooooo0_l00002ooooo`03o`000?oo
oooooooo00;o00002?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo0_l0
0002ooooo`;o00001Oooool2o`0000?ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0:ooooo`?o00002Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02_ooool002Wooooo00?o0000ooooooooool01oooool3o`0000[ooooo0_l0000G
ooooo`;o00002oooool00ol0003oooooooooo`0Hooooo`;o00002Oooool2o`0001Gooooo0_l0000E
ooooo`;o00005Oooool2o`0000kooooo00?o0000ooooooooool03oooool2o`0000_ooooo0_l0000F
ooooo`;o00001?ooool00ol0003oooooooooo`0Gooooo`;o00004Oooool2o`0000kooooo00?o0000
ooooooooool02_ooool002Wooooo00?o0000ooooooooool00_ooool2o`00027ooooo0_l00006oooo
o`;o00009_ooool2o`0002Kooooo0_l0000?ooooo`;o00005Oooool2o`0000cooooo0_l00006oooo
o`;o00002_ooool2o`0000Cooooo0_l00005ooooo`;o00005_ooool2o`0002Kooooo0_l00006oooo
o`;o000000?oooooo`000?l000006oooool002Wooooo00?o0000ooooooooool00_ooool2o`0001co
oooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000;o0000?oooool2o`00013o
oooo0_l00006ooooo`;o00003?ooool2o`0000;ooooo0_l0000Jooooo`;o00001_ooool2o`000003
ooooool0003o000000Kooooo0_l00005ooooo`;o00007oooool2o`0002;ooooo1?l00006ooooo`;o
00007_ooool002Wooooo0_l0000:ooooo`;o00005Oooool2o`000003ooooool0003o000000?ooooo
1?l0000Gooooo`?o00000_ooool2o`0001?ooooo0_l0000<ooooo`;o00002oooool3o`0000[ooooo
0_l0000<ooooo`;o000000?oooooo`000?l000000_l00008ooooo`;o00006_ooool2o`0000;ooooo
1_l00009ooooo`;o00006oooool2o`00013ooooo0_l0000@ooooo`;o00004Oooool2o`0001Gooooo
000Yooooo`03o`000?oooooooooo00;o00001oooool2o`0000Wooooo0_l0000Cooooo`;o00005Ooo
ool2o`000004ooooool0003o0000o`0000;ooooo0_l00004ooooo`;o000000Coooooo`000?l0003o
oooo0_l00007ooooo`;o00004oooool2o`0000Cooooo0ol0000Kooooo`Co00002?ooool2o`0001ko
oooo1?l0000;ooooo`;o0000:Oooool2o`0000;ooooo0_l0000?ooooo`;o00004_ooool2o`0000Ko
oooo0_l0000=ooooo`00:Oooool00ol0003oooooooooo`02o`0000Wooooo0_l00007ooooo`;o0000
1_ooool2o`0000Wooooo1?l0000Eooooo`;o00003?ooool2o`000004ooooool0003o0000ooooo`;o
00001Oooool2o`0001Gooooo0_l00006ooooo`;o00001_ooool2o`00013ooooo0_l0001Vooooo`;o
00004oooool2o`0001[ooooo0_l0000=ooooo`00:Oooool00ol0003oooooooooo`0;ooooo`;o0000
3oooool2o`0000Wooooo0_l0000=ooooo`;o00007?ooool2o`0000Gooooo0_l00007ooooo`Co0000
4_ooool2o`0000Kooooo0_l0000;ooooo`;o00000oooool2o`0003?ooooo0_l00011ooooo`;o0000
;_ooool002Wooooo00?o0000ooooooooool0=Oooool5o`0000Gooooo0_l0000Cooooo`;o00003_oo
ool5o`0000?ooooo0_l0000Aooooo`;o00002?ooool2o`0000Cooooo0ol00003ooooo`;o0000;_oo
ool2o`0000;ooooo0_l00009ooooo`;o00008_ooool2o`0000[ooooo0_l00006ooooo`;o00006_oo
ool2o`0001;ooooo000Yooooo`;o00001_ooool2o`0001;ooooo0_l0000Aooooo`;o00001Oooool4
o`000003ooooool0003o000000Gooooo0_l0000Hooooo`;o00003?ooool2o`0000?ooooo0_l0000>
ooooo`;o000000?oooooo`000?l000002?ooool2o`0000Gooooo0_l00003ooooo`;o00000oooool2
o`0002Wooooo0_l0000=ooooo`;o00003?ooool2o`0001Cooooo0_l0000:ooooo`;o00008_ooool2
o`0001;ooooo000Yooooo`03o`000?oooooooooo00Gooooo1?l0000@ooooo`;o00004Oooool2o`00
00Gooooo0_l00005ooooo`;o00007Oooool2o`00027ooooo0_l0000>ooooo`;o00003?ooool2o`00
00Gooooo0_l0000Gooooo`;o00009_ooool2o`0000_ooooo0_l0001;ooooo`00:Oooool00ol0003o
ooooooooo`07ooooo`;o00001?ooool2o`0002_ooooo0_l0000:ooooo`;o00004_ooool2o`00033o
oooo0_l0000Cooooo`;o00005oooool2o`000004ooooool0003o0000o`0002_ooooo0_l00002oooo
o`;o00001_ooool2o`0000?ooooo0_l0000Looooo`;o00008?ooool002Wooooo00?o0000oooooooo
ool00oooool3o`0000Oooooo0_l0000gooooo`;o00004_ooool2o`0002;ooooo0_l0000=ooooo`;o
00003oooool2o`0000Sooooo0_l0000Cooooo`?o00004_ooool2o`0001Oooooo0_l00002ooooo`;o
00001_ooool2o`0000?ooooo0_l000000ooooooo0000o`000009ooooo`;o00003_ooool2o`00023o
oooo000Yooooo`03o`000?oooooooooo00?ooooo0ol00006ooooo`;o0000Eoooool2o`0001Oooooo
0_l0000=ooooo`;o00003oooool2o`0000Sooooo0_l0000Xooooo`;o00005oooool2o`0000;ooooo
0_l00008ooooo`;o00001?ooool2o`0000Cooooo0_l00003ooooo`;o00006_ooool2o`0001Cooooo
000Yooooo`;o00002oooool4o`0002gooooo0_l0000Xooooo`;o0000<oooool2o`0000gooooo0_l0
001>ooooo`;o00002_ooool2o`0001oooooo0_l0000Dooooo`00:Oooool00ol0003oooooooooo`0:
ooooo`;o0000;oooool2o`0005gooooo0_l0000:ooooo`;o000000?oooooo`000?l000004?ooool2
o`0002Wooooo0_l0000Booooo`;o0000@?ooool002Wooooo00?o0000ooooooooool0COooool2o`00
00[ooooo0_l000000ooooooo0000o`00000<ooooo`;o0000=?ooool2o`0000Cooooo0_l0000Coooo
o`;o00004oooool2o`0000Oooooo0_l00006ooooo`;o00000_ooool3o`0001;ooooo0_l00010oooo
o`00:Oooool00ol0003oooooooooo`1=ooooo`;o00002_ooool2o`000004ooooool0003o0000oooo
o`;o00002Oooool2o`00027ooooo0_l00006ooooo`;o00002Oooool2o`000003ooooool0003o0000
01Oooooo0_l0000Booooo`;o00001oooool2o`0000Kooooo0_l00002ooooo`Ko00006Oooool2o`00
01Kooooo0_l0000Nooooo`00:Oooool00ol0003oooooooooo`0]ooooo`;o00008Oooool2o`0000go
oooo0_l0000Nooooo`;o00003?ooool2o`0000Kooooo0_l0000<ooooo`Co00005Oooool2o`00013o
oooo0_l0000>ooooo`;o00001oooool4o`0001Wooooo0_l00008ooooo`;o00003?ooool2o`0000Co
oooo0_l0000Hooooo`00:Oooool2o`0002kooooo0_l0000Qooooo`;o00003Oooool2o`0001kooooo
0_l0000Looooo`;o00001_ooool2o`0000oooooo0_l0000Fooooo`;o00002?ooool2o`0000Cooooo
0_l0000^ooooo`;o00004_ooool2o`0001Sooooo000Yooooo`03o`000?oooooooooo01[ooooo0_l0
000Hooooo`;o0000Ioooool2o`0001Oooooo0_l0000Booooo`;o00003?ooool2o`0002Wooooo0_l0
000gooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool02_ooool2o`0000kooooo
0_l0000Hooooo`;o0000Hoooool2o`0002kooooo0ol0000gooooo`;o00001Oooool2o`00033ooooo
0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool02_ooool4o`0001?o
oooo0_l0001Booooo`;o00003Oooool2o`00017ooooo1?l0000^ooooo`;o00002?ooool2o`0003Go
oooo0_l0000`ooooo`001_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^
k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo0_l0000Cooooo`;o
0000D_ooool2o`0000gooooo0_l0000Aooooo`;o00009_ooool2o`0001;ooooo0_l0000Nooooo`;o
00009Oooool2o`00023ooooo0006ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So
8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Cooooo`;o00000oooool2o`000:Go
oooo0_l0000>ooooo`;o00005Oooool2o`0000_ooooo0_l0000Pooooo`;o00000oooool2o`00023o
oooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Cooooo`;o00000oooool2o`00
01Cooooo0_l0000Fooooo`;o00005_ooool2o`0000kooooo0_l0000kooooo`;o00003?ooool2o`00
01Cooooo0_l0000Eooooo`?o0000;?ooool2o`00017ooooo0_l0000Booooo`001_ooool01Ol@413o
oooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00oooooo0_l00004ooooo`;o00005oooool2o`0001Kooooo0_l0000Foooo
o`;o00003_ooool2o`00033ooooo0_l00009ooooo`;o00003?ooool2o`0001Gooooo0_l0000Eoooo
o`;o00008_ooool2o`0001_ooooo0_l0000Booooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo0_l0000@
ooooo`;o00001?ooool2o`0003Cooooo0_l0000Fooooo`;o00007?ooool2o`0001gooooo0_l0000^
ooooo`;o00001?ooool2o`0000_ooooo0ol0000Uooooo`;o0000;oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0
000Hooooo`;o00008Oooool4o`0000gooooo1?l0000Dooooo`;o00005_ooool2o`0000Cooooo0_l0
000=ooooo`;o00008Oooool2o`0000?ooooo0_l0000Looooo`;o00001Oooool2o`0000Cooooo0ol0
0003ooooo`;o00007?ooool2o`0000cooooo0_l00004ooooo`Co00003?ooool2o`0000oooooo000Y
ooooo`;o00006?ooool2o`00027ooooo1?l0000?ooooo`;o0000;?ooool2o`0000cooooo0_l00004
ooooo`?o00008Oooool2o`0000?ooooo0_l0000Booooo`;o00003oooool2o`0000Gooooo0_l00003
ooooo`;o00006oooool5o`0000[ooooo0_l00004ooooo`Co00003?ooool2o`0000oooooo000Yoooo
o`03o`000?oooooooooo01gooooo0_l0000<ooooo`;o0000G?ooool3o`0000?ooooo0_l0000koooo
o`;o00004Oooool2o`0000?ooooo0_l0000Pooooo`;o000000?oooooo`000?l00000<Oooool002Wo
oooo00?o0000ooooooooool01Oooool2o`0001Kooooo0_l0000<ooooo`;o00009_ooool2o`0002go
oooo0_l00006ooooo`;o0000Doooool2o`0005_ooooo000Yooooo`03o`000?oooooooooo00Gooooo
0_l0000Iooooo`;o00005oooool2o`0001Sooooo0_l0000<ooooo`;o00007oooool2o`0002gooooo
0_l00002ooooo`;o00009Oooool2o`0005kooooo000Yooooo`03o`000?oooooooooo023ooooo0_l0
000Gooooo`;o00009_ooool2o`0000kooooo0_l0000nooooo`?o000000?oooooo`000?l000002_oo
ool2o`0001Wooooo0_l0001Nooooo`00:Oooool2o`0004oooooo0_l0000Looooo`;o00000oooool2
o`0001;ooooo0_l0000[ooooo`;o00003Oooool2o`0001Wooooo0_l0000Dooooo`;o0000B?ooool0
02Wooooo00?o0000ooooooooool0C_ooool2o`0001cooooo0_l00008ooooo`;o00003Oooool2o`00
01Kooooo0_l0000Cooooo`;o0000>?ooool2o`0000Cooooo0_l0000hooooo`;o000000?oooooo`00
0?l000002oooool002Wooooo00?o0000ooooooooool0>oooool2o`0003Wooooo0_l0000Uooooo`;o
0000COooool2o`0003kooooo0_l000000ooooooo0000o`00000;ooooo`00:Oooool00ol0003ooooo
ooooo`04ooooo`;o00005?ooool4o`0001gooooo0_l0001_ooooo`;o0000BOooool2o`0004?ooooo
000Yooooo`03o`000?oooooooooo00Cooooo0_l0000?ooooo`;o00000oooool4o`0001[ooooo0_l0
001^ooooo`;o00000_ooool2o`0000cooooo0_l00004ooooo`;o00005?ooool2o`0000;ooooo0_l0
000Dooooo`;o00001Oooool2o`0004?ooooo000Yooooo`;o00005_ooool2o`0000gooooo0_l0000B
ooooo`;o0000B_ooool2o`0002;ooooo0_l0000@ooooo`;o00001?ooool2o`0001Cooooo0_l00002
ooooo`;o00001oooool2o`0000_ooooo0_l0001:ooooo`00:Oooool00ol0003oooooooooo`02oooo
o`;o00008?ooool2o`0001_ooooo0_l0000?ooooo`;o00005Oooool2o`0000Cooooo0ol0000Boooo
o`;o0000GOooool2o`0001cooooo0_l00006ooooo`;o0000<Oooool002Wooooo00?o0000oooooooo
ool00_ooool2o`0000cooooo0_l0000=ooooo`;o00001?ooool2o`0001[ooooo0_l0000?ooooo`;o
00005Oooool2o`0000Cooooo0ol0000Rooooo`;o00001_ooool2o`0001[ooooo0_l0000>ooooo`;o
00001oooool2o`0000cooooo0_l0000Eooooo`;o00002Oooool2o`0000Kooooo0_l0000>ooooo`;o
00003?ooool2o`0001?ooooo000Yooooo`04o`000?ooooooooooooooo`;o00003Oooool2o`0000go
oooo0_l00004ooooo`;o00007_ooool2o`0001Oooooo0_l0000dooooo`;o00001_ooool2o`0001[o
oooo0_l0000>ooooo`;o00001oooool2o`0000cooooo0_l0000Eooooo`;o00006oooool2o`0000Co
oooo0_l0000<ooooo`;o00004oooool002Wooooo00Co0000oooooooooooooooo0_l0000=ooooo`;o
00007_ooool2o`0001?ooooo0_l0000?ooooo`;o00001_ooool2o`0000?ooooo0_l0000?ooooo`;o
0000WOooool2o`0002Oooooo000Yooooo`;o0000<Oooool2o`0001?ooooo0_l0000?ooooo`;o0000
2oooool2o`0000oooooo0_l00036ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000>
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8b
omgMg@05ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo
?Oooool000kooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo
0ol0003oooooo`Sooooo0_l0000cooooo`003_ooool01Ol0003ooooooooooooooooo000000oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooo`Sooooo0_l0000cooooo`003_oo
ool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooooooooooooooooa0@400<ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooob_o
oooo0_l0000@ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o
0000A?ooool2o`000>Gooooo0_l0000@ooooo`00:Oooool00ol0003oooooooooo`13ooooo`;o0000
moooool002Wooooo00?o0000ooooooooool0j?ooool2o`0005;ooooo000Yooooo`03o`000?oooooo
oooo0>Sooooo0_l0001Booooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o
0000F?ooool2o`000>?ooooo000Yooooo`03o`000?oooooooooo05Oooooo0_l0001Mooooo`;o0000
Q?ooool002Wooooo00?o0000ooooooooool0]_ooool2o`0008Cooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oo
oooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@4100
3Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo
0006ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooo
oooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00ko
oooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooo
oolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003ooooo
ockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003ooooo
ockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`007oooool4o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool3o`00
0?oooooo?Oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`007oooool00omEEEGoIVIVo`00003oooooodOooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .35541 Mdot
.02762 .39974 Mdot
.02952 .29898 Mdot
.03143 .33903 Mdot
.03333 .29069 Mdot
.03524 .24693 Mdot
.03714 .31747 Mdot
.03905 .44458 Mdot
.04095 .4087 Mdot
.04286 .26138 Mdot
.04476 .31749 Mdot
.04667 .4509 Mdot
.04857 .4047 Mdot
.05048 .28443 Mdot
.05238 .44608 Mdot
.05429 .3051 Mdot
.05619 .36952 Mdot
.0581 .40345 Mdot
.06 .35517 Mdot
.0619 .26173 Mdot
.06381 .39293 Mdot
.06571 .40672 Mdot
.06762 .40169 Mdot
.06952 .3974 Mdot
.07143 .43997 Mdot
.07333 .28655 Mdot
.07524 .34209 Mdot
.07714 .35364 Mdot
.07905 .24212 Mdot
.08095 .40203 Mdot
.08286 .37276 Mdot
.08476 .40446 Mdot
.08667 .43818 Mdot
.08857 .33665 Mdot
.09048 .30377 Mdot
.09238 .27164 Mdot
.09429 .29818 Mdot
.09619 .35485 Mdot
.0981 .23196 Mdot
.1 .45328 Mdot
.1019 .44686 Mdot
.10381 .32316 Mdot
.10571 .24885 Mdot
.10762 .3583 Mdot
.10952 .3275 Mdot
.11143 .24961 Mdot
.11333 .29046 Mdot
.11524 .3727 Mdot
.11714 .35692 Mdot
.11905 .2373 Mdot
.12095 .37299 Mdot
.12286 .23676 Mdot
.12476 .29584 Mdot
.12667 .26498 Mdot
.12857 .27064 Mdot
.13048 .42539 Mdot
.13238 .44639 Mdot
.13429 .373 Mdot
.13619 .34076 Mdot
.1381 .31705 Mdot
.14 .24899 Mdot
.1419 .38401 Mdot
.14381 .23444 Mdot
.14571 .27009 Mdot
.14762 .43884 Mdot
.14952 .41451 Mdot
.15143 .26031 Mdot
.15333 .30716 Mdot
.15524 .35593 Mdot
.15714 .38741 Mdot
.15905 .37491 Mdot
.16095 .30747 Mdot
.16286 .26882 Mdot
.16476 .25661 Mdot
.16667 .23445 Mdot
.16857 .3091 Mdot
.17048 .29639 Mdot
.17238 .27345 Mdot
.17429 .23174 Mdot
.17619 .3567 Mdot
.1781 .33387 Mdot
.18 .40108 Mdot
.1819 .33945 Mdot
.18381 .32136 Mdot
.18571 .43475 Mdot
.18762 .30953 Mdot
.18952 .28523 Mdot
.19143 .25668 Mdot
.19333 .37782 Mdot
.19524 .3025 Mdot
.19714 .43708 Mdot
.19905 .22282 Mdot
.20095 .3035 Mdot
.20286 .25568 Mdot
.20476 .29419 Mdot
.20667 .23508 Mdot
.20857 .28106 Mdot
.21048 .38323 Mdot
.21238 .30528 Mdot
.21429 .37974 Mdot
.21619 .36846 Mdot
.2181 .3785 Mdot
.22 .44946 Mdot
.2219 .37057 Mdot
.22381 .36222 Mdot
.22571 .32988 Mdot
.22762 .36731 Mdot
.22952 .35101 Mdot
.23143 .30426 Mdot
.23333 .38304 Mdot
.23524 .26901 Mdot
.23714 .341 Mdot
.23905 .40346 Mdot
.24095 .28247 Mdot
.24286 .41509 Mdot
.24476 .3162 Mdot
.24667 .25603 Mdot
.24857 .41745 Mdot
.25048 .41071 Mdot
.25238 .30503 Mdot
.25429 .40329 Mdot
.25619 .40781 Mdot
.2581 .3916 Mdot
.26 .2418 Mdot
.2619 .38464 Mdot
.26381 .33432 Mdot
.26571 .26507 Mdot
.26762 .25679 Mdot
.26952 .39192 Mdot
.27143 .32762 Mdot
.27333 .40499 Mdot
.27524 .38103 Mdot
.27714 .45085 Mdot
.27905 .24625 Mdot
.28095 .2419 Mdot
.28286 .23198 Mdot
.28476 .2689 Mdot
.28667 .24886 Mdot
.28857 .2677 Mdot
.29048 .44353 Mdot
.29238 .44719 Mdot
.29429 .3292 Mdot
.29619 .33351 Mdot
.2981 .357 Mdot
.3 .37006 Mdot
.3019 .27314 Mdot
.30381 .4286 Mdot
.30571 .44899 Mdot
.30762 .33489 Mdot
.30952 .2526 Mdot
.31143 .42691 Mdot
.31333 .3774 Mdot
.31524 .34944 Mdot
.31714 .39825 Mdot
.31905 .31352 Mdot
.32095 .28644 Mdot
.32286 .26163 Mdot
.32476 .23474 Mdot
.32667 .41951 Mdot
.32857 .30319 Mdot
.33048 .26315 Mdot
.33238 .32254 Mdot
.33429 .23089 Mdot
.33619 .45506 Mdot
.3381 .29178 Mdot
.34 .24512 Mdot
.3419 .36826 Mdot
.34381 .42702 Mdot
.34571 .35513 Mdot
.34762 .35525 Mdot
.34952 .2518 Mdot
.35143 .24335 Mdot
.35333 .32245 Mdot
.35524 .3526 Mdot
.35714 .27582 Mdot
.35905 .33209 Mdot
.36095 .4399 Mdot
.36286 .24035 Mdot
.36476 .2835 Mdot
.36667 .31779 Mdot
.36857 .23495 Mdot
.37048 .23882 Mdot
.37238 .45332 Mdot
.37429 .27238 Mdot
.37619 .44572 Mdot
.3781 .31022 Mdot
.38 .40762 Mdot
.3819 .25485 Mdot
.38381 .3973 Mdot
.38571 .45476 Mdot
.38762 .24541 Mdot
.38952 .41933 Mdot
.39143 .27486 Mdot
.39333 .26196 Mdot
.39524 .38653 Mdot
.39714 .43991 Mdot
.39905 .44404 Mdot
.40095 .45039 Mdot
.40286 .25981 Mdot
.40476 .21988 Mdot
.40667 .35793 Mdot
.40857 .29814 Mdot
.41048 .30155 Mdot
.41238 .30142 Mdot
.41429 .28774 Mdot
.41619 .2235 Mdot
.4181 .37643 Mdot
.42 .27122 Mdot
.4219 .25743 Mdot
.42381 .3419 Mdot
.42571 .29966 Mdot
.42762 .31895 Mdot
.42952 .40967 Mdot
.43143 .26739 Mdot
.43333 .35359 Mdot
.43524 .27707 Mdot
.43714 .37164 Mdot
.43905 .26128 Mdot
.44095 .45394 Mdot
.44286 .31424 Mdot
.44476 .3169 Mdot
.44667 .4523 Mdot
.44857 .25313 Mdot
.45048 .35545 Mdot
.45238 .36324 Mdot
.45429 .31647 Mdot
.45619 .28428 Mdot
.4581 .3146 Mdot
.46 .39419 Mdot
.4619 .31671 Mdot
.46381 .44626 Mdot
.46571 .40753 Mdot
.46762 .32316 Mdot
.46952 .27624 Mdot
.47143 .22967 Mdot
.47333 .37206 Mdot
.47524 .33837 Mdot
.47714 .41111 Mdot
.47905 .35422 Mdot
.48095 .37655 Mdot
.48286 .39814 Mdot
.48476 .3771 Mdot
.48667 .38094 Mdot
.48857 .24064 Mdot
.49048 .34024 Mdot
.49238 .37501 Mdot
.49429 .4028 Mdot
.49619 .29124 Mdot
.4981 .26656 Mdot
.5 .37432 Mdot
.5019 .37587 Mdot
.50381 .23367 Mdot
.50571 .44391 Mdot
.50762 .31518 Mdot
.50952 .26369 Mdot
.51143 .28267 Mdot
.51333 .2999 Mdot
.51524 .35162 Mdot
.51714 .26717 Mdot
.51905 .30559 Mdot
.52095 .4447 Mdot
.52286 .35814 Mdot
.52476 .36586 Mdot
.52667 .3379 Mdot
.52857 .30892 Mdot
.53048 .32861 Mdot
.53238 .3765 Mdot
.53429 .34711 Mdot
.53619 .30249 Mdot
.5381 .24612 Mdot
.54 .25578 Mdot
.5419 .32532 Mdot
.54381 .27212 Mdot
.54571 .26591 Mdot
.54762 .25838 Mdot
.54952 .36096 Mdot
.55143 .25627 Mdot
.55333 .27026 Mdot
.55524 .33754 Mdot
.55714 .38078 Mdot
.55905 .31082 Mdot
.56095 .27371 Mdot
.56286 .23227 Mdot
.56476 .33015 Mdot
.56667 .25975 Mdot
.56857 .30575 Mdot
.57048 .44905 Mdot
.57238 .35053 Mdot
.57429 .32012 Mdot
.57619 .30136 Mdot
.5781 .30745 Mdot
.58 .25048 Mdot
.5819 .3417 Mdot
.58381 .25285 Mdot
.58571 .33993 Mdot
.58762 .44724 Mdot
.58952 .34844 Mdot
.59143 .29795 Mdot
.59333 .31913 Mdot
.59524 .38959 Mdot
.59714 .32616 Mdot
.59905 .44645 Mdot
.60095 .46297 Mdot
.60286 .3539 Mdot
.60476 .24939 Mdot
.60667 .38235 Mdot
.60857 .40391 Mdot
.61048 .44484 Mdot
.61238 .29628 Mdot
.61429 .3815 Mdot
.61619 .3063 Mdot
.6181 .2784 Mdot
.62 .40811 Mdot
.6219 .36766 Mdot
.62381 .40294 Mdot
.62571 .43011 Mdot
.62762 .32235 Mdot
.62952 .32866 Mdot
.63143 .32833 Mdot
.63333 .44132 Mdot
.63524 .32917 Mdot
.63714 .45254 Mdot
.63905 .41537 Mdot
.64095 .32229 Mdot
.64286 .32646 Mdot
.64476 .24499 Mdot
.64667 .32244 Mdot
.64857 .241 Mdot
.65048 .31792 Mdot
.65238 .28397 Mdot
.65429 .30985 Mdot
.65619 .36946 Mdot
.6581 .45 Mdot
.66 .28398 Mdot
.6619 .28999 Mdot
.66381 .40896 Mdot
.66571 .32748 Mdot
.66762 .29951 Mdot
.66952 .39579 Mdot
.67143 .24308 Mdot
.67333 .24496 Mdot
.67524 .32351 Mdot
.67714 .29242 Mdot
.67905 .26977 Mdot
.68095 .31224 Mdot
.68286 .39839 Mdot
.68476 .27382 Mdot
.68667 .43329 Mdot
.68857 .33904 Mdot
.69048 .25193 Mdot
.69238 .40369 Mdot
.69429 .32114 Mdot
.69619 .25206 Mdot
.6981 .33314 Mdot
.7 .45108 Mdot
.7019 .31163 Mdot
.70381 .2674 Mdot
.70571 .34544 Mdot
.70762 .35563 Mdot
.70952 .24879 Mdot
.71143 .37442 Mdot
.71333 .45086 Mdot
.71524 .32569 Mdot
.71714 .3367 Mdot
.71905 .45042 Mdot
.72095 .45216 Mdot
.72286 .44999 Mdot
.72476 .28471 Mdot
.72667 .36845 Mdot
.72857 .44644 Mdot
.73048 .44524 Mdot
.73238 .28071 Mdot
.73429 .35649 Mdot
.73619 .31944 Mdot
.7381 .25514 Mdot
.74 .36479 Mdot
.7419 .39035 Mdot
.74381 .37622 Mdot
.74571 .31122 Mdot
.74762 .26469 Mdot
.74952 .40208 Mdot
.75143 .29667 Mdot
.75333 .40459 Mdot
.75524 .44362 Mdot
.75714 .4276 Mdot
.75905 .32106 Mdot
.76095 .2879 Mdot
.76286 .31351 Mdot
.76476 .42815 Mdot
.76667 .3791 Mdot
.76857 .3071 Mdot
.77048 .45422 Mdot
.77238 .38591 Mdot
.77429 .27976 Mdot
.77619 .25583 Mdot
.7781 .27366 Mdot
.78 .34306 Mdot
.7819 .37722 Mdot
.78381 .36727 Mdot
.78571 .38576 Mdot
.78762 .45333 Mdot
.78952 .35614 Mdot
.79143 .26501 Mdot
.79333 .35457 Mdot
.79524 .3358 Mdot
.79714 .33135 Mdot
.79905 .27414 Mdot
.80095 .4488 Mdot
.80286 .45056 Mdot
.80476 .34072 Mdot
.80667 .3231 Mdot
.80857 .33291 Mdot
.81048 .29412 Mdot
.81238 .43547 Mdot
.81429 .26208 Mdot
.81619 .2992 Mdot
.8181 .33762 Mdot
.82 .35089 Mdot
.8219 .32951 Mdot
.82381 .27132 Mdot
.82571 .34247 Mdot
.82762 .34276 Mdot
.82952 .26748 Mdot
.83143 .41745 Mdot
.83333 .44307 Mdot
.83524 .2765 Mdot
.83714 .29667 Mdot
.83905 .36699 Mdot
.84095 .31206 Mdot
.84286 .32798 Mdot
.84476 .35367 Mdot
.84667 .43025 Mdot
.84857 .22905 Mdot
.85048 .38329 Mdot
.85238 .38756 Mdot
.85429 .36313 Mdot
.85619 .26407 Mdot
.8581 .41727 Mdot
.86 .44554 Mdot
.8619 .32488 Mdot
.86381 .40319 Mdot
.86571 .27713 Mdot
.86762 .32722 Mdot
.86952 .27139 Mdot
.87143 .32315 Mdot
.87333 .31533 Mdot
.87524 .34818 Mdot
.87714 .22023 Mdot
.87905 .3036 Mdot
.88095 .27918 Mdot
.88286 .33122 Mdot
.88476 .27963 Mdot
.88667 .32261 Mdot
.88857 .26136 Mdot
.89048 .44489 Mdot
.89238 .32574 Mdot
.89429 .23088 Mdot
.89619 .39424 Mdot
.8981 .33075 Mdot
.9 .26981 Mdot
.9019 .35036 Mdot
.90381 .36341 Mdot
.90571 .26725 Mdot
.90762 .25611 Mdot
.90952 .45059 Mdot
.91143 .44559 Mdot
.91333 .30574 Mdot
.91524 .31622 Mdot
.91714 .32704 Mdot
.91905 .36972 Mdot
.92095 .25475 Mdot
.92286 .36773 Mdot
.92476 .35241 Mdot
.92667 .25204 Mdot
.92857 .34078 Mdot
.93048 .39442 Mdot
.93238 .24171 Mdot
.93429 .31253 Mdot
.93619 .25068 Mdot
.9381 .35714 Mdot
.94 .29047 Mdot
.9419 .31836 Mdot
.94381 .26975 Mdot
.94571 .24439 Mdot
.94762 .30783 Mdot
.94952 .29244 Mdot
.95143 .41564 Mdot
.95333 .29873 Mdot
.95524 .3398 Mdot
.95714 .35737 Mdot
.95905 .35025 Mdot
.96095 .27004 Mdot
.96286 .40566 Mdot
.96476 .26767 Mdot
.96667 .39792 Mdot
.96857 .36372 Mdot
.97048 .29102 Mdot
.97238 .35629 Mdot
.97429 .24208 Mdot
.97619 .45273 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo07Oooooo0_l0002Fooooo`;o0000:oooool000Kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo03Gooooo0_l00010ooooo`;o000000?oooooo`000?l00000Toooool2
o`0002_ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0=Ooo
ool2o`0004?ooooo0_l00030ooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0H?oo
ool2o`0002[ooooo0_l0001gooooo`;o00003Oooool2o`0002Kooooo0006ooooo`05o`000?oooooo
ooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0
000Dooooo`;o00005oooool2o`00027ooooo0_l0000>ooooo`;o0000:_ooool2o`0000Wooooo0_l0
000Aooooo`;o0000FOooool2o`0000gooooo0_l0000Vooooo`001_ooool01Ol0003ooooooooooooo
oooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool05?ooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`000003oooo
ool0003o000000Sooooo0_l0000Gooooo`;o00002oooool2o`0000cooooo0_l0000Zooooo`;o0000
4Oooool2o`00093ooooo0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06oooool3o`0000Gooooo
0_l00005ooooo`;o00002oooool2o`0002Cooooo0_l0000:ooooo`Go0000c_ooool000Kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00kooooo0_l0000;ooooo`;o0000:oooool2o`0000Go
oooo0_l0000Eooooo`;o000000Coooooo`000?l0003ooooo0_l0000Tooooo`;o0000<Oooool2o`00
00Kooooo0_l0001Aooooo`;o00003?ooool2o`0000cooooo0006ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooo
oooo00kooooo0_l0000hooooo`;o00001?ooool3o`00017ooooo0_l00002ooooo`;o00002Oooool2
o`0001oooooo0_l0000>ooooo`;o00008?ooool3o`0000Kooooo0_l0001Aooooo`;o00000oooool2
o`0000Oooooo0_l0000<ooooo`00:Oooool2o`000003ooooool0003o000001Gooooo0ol00008oooo
o`;o0000:_ooool2o`000003ooooool0003o000000oooooo0_l0000=ooooo`;o0000;oooool2o`00
01?ooooo0_l0000;ooooo`;o00001oooool2o`0000[ooooo0_l0001:ooooo`;o00005Oooool002Wo
oooo00?o0000ooooooooool00_l0000Eooooo`?o00002?ooool2o`0002gooooo0_l00005ooooo`;o
00002oooool2o`0004Sooooo0_l00006ooooo`;o00006_ooool3o`0000?ooooo0_l00014ooooo`;o
000000?oooooo`000?l000006?ooool002Wooooo00?o0000ooooooooool0=_ooool2o`00023ooooo
0_l0000;ooooo`;o00002?ooool2o`0001Cooooo0_l0000Kooooo`;o00002oooool3o`00027ooooo
0ol0000<ooooo`;o00002_ooool2o`0002gooooo1?l000000ooooooo0000o`00000Hooooo`00:Ooo
ool00ol0003oooooooooo`0Zooooo`;o00001_ooool2o`0000;ooooo0_l0000<ooooo`;o00001Ooo
ool2o`0002;ooooo0_l0000;ooooo`;o00001oooool2o`0001_ooooo0_l000001?oooooo0000o`00
0?l00008ooooo`;o0000<?ooool2o`0000[ooooo0_l0000Xooooo`;o00000oooool2o`0001gooooo
000Yooooo`03o`000?oooooooooo00;ooooo0_l00005ooooo`;o00006_ooool2o`0000?ooooo0_l0
0006ooooo`;o00004?ooool2o`0000Gooooo0_l0000?ooooo`;o00005Oooool2o`000003ooooool0
003o000000Cooooo0_l00004ooooo`;o00008Oooool3o`0000?ooooo0_l0001=ooooo`;o00005_oo
ool2o`0000Cooooo0_l0000Rooooo`00:Oooool2o`0000?ooooo0_l00005ooooo`;o00004_ooool2
o`0000Kooooo0_l0000Sooooo`;o00004?ooool2o`000003ooooool0003o000001;ooooo0_l00000
0ooooooo0000o`00000:ooooo`;o00005?ooool2o`00017ooooo0_l0000hooooo`;o00003?ooool2
o`0000Gooooo0_l0000<ooooo`;o00002?ooool2o`0002Sooooo000Yooooo`03o`000?oooooooooo
01gooooo0_l0000[ooooo`;o00001Oooool2o`0000cooooo0_l0000Nooooo`;o00005?ooool2o`00
0004ooooool0003o0000ooooo`;o00001oooool2o`00037ooooo0_l0000<ooooo`;o00003?ooool2
o`0000[ooooo0_l00007ooooo`;o00003_ooool2o`00017ooooo0_l0000?ooooo`00:Oooool00ol0
003oooooooooo`0Nooooo`;o00000oooool2o`0000Cooooo0_l00005ooooo`Co000000So410@oooo
ooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^o`000?l0003o<S8bonk^kP0<ooooo`?o
00006_ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`;o000000Co<S8bo`00
0?l0003ok^k^4oooool2o`0000Cooooo0_l00007ooooo`;o000000Woooooo`000?l0003ooooooiRH
V?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0@ooooo`;o00001_ooool2o`00013ooooo0_l000002Ol@413ooooooooooooo
ooook^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool3o`00
00_ooooo0_l00008ooooo`Co00002_ooool4o`000003oc8b<_oMgMgo000000;o000000Co<S8bo`00
0?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Yooooo`03o`000?oooooo
oooo01;ooooo0_l0000:ooooo`;o00000oooool2o`0000Cooooo0_l000000ooooooo0000o`000004
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMol0
003o0000oiRHV?mgMgL03?ooool2o`0000Cooooo0_l0000Eooooo`;o000000?ok^k^oooooom4A4@0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo0_l000001?nHV9SooooooiRHV?mgMgLQoooo
o`;o00000_ooool4o`000004okZj^_ooooooMgMgoc8b<P?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04?ooool4o`0001Oooooo00?o0000ooooooooool0
0_ooool2o`000003oooooonHV9SoMgMg00;ooooo0_l000001?nHV9SooooooiRHV?mgMgL2ooooo`;o
00003?ooool2o`0000Sooooo0_l0000<ooooo`;o00000_ooool02OmgMgOo<S8bo`000?l0003oMgMg
oiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wooooo00?o
0000ooooooooool04_ooool2o`0001Sooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41004_ooool2o`0000oo
oooo0_l00004ooooo`;o000000?o8B4Qonk^k_ooool00_l000000ooooooo410@ooooo`02ooooo`05
oa0@4?ooooooooooooooool@41000oooool2o`0000Wooooo0_l0000Eooooo`;o00001?ooool2o`00
00?ooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool00ol@413oooooooooo`0@ooooo`;o00005?ooool5o`0000?ooooo0_l00002ooooo`03oa0@4?oo
oooooooo00;o00000oooool00ol@413oooooooooo`03ooooo`;o00002?ooool2o`0001cooooo00Co
0000oooooooooooo410@0oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooooooo
ool00Oooool002Wooooo0_l0000cooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000008oooool2o`0000Kooooo00?oV9RHob4Q
8Oo^k^h00_l000000ooooooo0000ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool2
o`0000Wooooo0_l0000Oooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`?o000000?oooooo`000?ooool08?ooool2o`0000Gooooo00CoA4A4omgMgOoooooo0000
0oooool2o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?o
oooo0_l00008ooooo`;o00000oooool3o`0001Gooooo00GoMgMgoc8b<_ooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`01ooooo`00:Oooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo00;ooooo0ol000000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00;o00009_ooool2o`0000Cooooo00?oMgMgofIVI_ooool00_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00000Gooooo`;o00004Ooo
ool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000000oooool3o`000003oooo
ool0003ooooo023ooooo0_l00005ooooo`04omgMgOmEEEGoooooo`0000?ooooo0_l00003ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Booooo`?o00004_ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool002Wooooo00?o0000ooooooooool01Oooool2o`0000Gooooo0_l0
000Tooooo`;o00000oooool01Ol@413o0000o`000?oooooo410@00?ooooo00?o410@ooooooooool0
0_l0000Hooooo`;o00003?ooool2o`0000Gooooo00Go0000oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`;o00004?ooool2o`00
01;ooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@
oooooooooooooooooa0@4007ooooo`;o000000?oooooo`000?l000004oooool2o`0000Sooooo00?o
MgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@400Yooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@4003oooo
o`05oa0@4?ooooooooooooooool@41000oooool002Wooooo00?o0000ooooooooool01Oooool2o`00
00Gooooo0_l0000Tooooo`;o00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0Hooooo`;o00003oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`02o`000006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2
o`00027ooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo0_l000000ooooooo0000o`00000Cooooo`;o
00002?ooool00oo^k^ko0000o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg02Wooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool01?l0003oooooo`00
0?l0000Hooooo`;o00005Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo0_l0000:ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;o000000Koooooonk^k_lb<S;o0000
oc8b<_o^k^hBooooo`;o00005?ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02_ooool2o`0000?ooooo0_l0
000Iooooo`;o00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0Wooooo`Ko00000oooool01Oo^k^ko0000o`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`00:Oooool4o`0001Sooooo0_l00002ooooo`;o00005oooool2o`00
02Wooooo0_l0000aooooo`;o00009?ooool2o`0001;ooooo0_l0000Yooooo`;o0000:?ooool2o`00
0003ooooool0003o000000Gooooo0_l0000=ooooo`00:Oooool3o`0001?ooooo0_l00008ooooo`;o
00003?ooool2o`0000Wooooo0_l00010ooooo`;o0000>Oooool2o`0000Gooooo0_l0000Zooooo`;o
00004Oooool4o`0000Gooooo0_l0000Sooooo`;o00004oooool002Wooooo0ol0000Cooooo`;o0000
5_ooool2o`0000Kooooo0_l00013ooooo`?o00000_ooool2o`0001_ooooo0_l00005ooooo`;o0000
2oooool2o`0000?ooooo0_l0000Fooooo`;o00006Oooool2o`0001?ooooo0_l00005ooooo`;o0000
8oooool2o`0001?ooooo000Yooooo`03o`000?oooooooooo00Kooooo0_l0000:ooooo`;o00007ooo
ool4o`0000;ooooo0_l00004ooooo`;o00001Oooool2o`0001Kooooo0_l0000Iooooo`;o00000_oo
ool2o`0001_ooooo1?l00003ooooo`;o00002oooool2o`0001_ooooo0_l00012ooooo`;o0000:ooo
ool002Wooooo00?o0000ooooooooool01_ooool2o`0000[ooooo0_l0000Booooo`Co00002oooool2
o`0000;ooooo0_l00004ooooo`;o00001Oooool2o`0001Kooooo0_l0000looooo`;o00003Oooool2
o`000003ooooool0003o000000_ooooo0_l0000_ooooo`;o00008Oooool2o`0000Wooooo0_l00009
ooooo`;o00005Oooool0027oooooool00014o`0000Cooooo000Yooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Ko
oooo0_l000001?oooooo0000ooooooooool2o`0000Oooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo0_l00002ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool00_l00008ooooo`03o`000?oooooooooo00Sooooo0_l00003oooo
o`;o00001_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;o00001oooool2o`00
00_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`;o00001?ooool00ol0
003oooooooooo`02o`0000Cooooo0_l00002ooooo`03o`000?oooooooooo00Oooooo0ol00003oooo
o`;o00001_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo0_l00006oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool3o`0000_ooooo00?o0000oooo
ooooool02_ooool002Wooooo00Co0000oooooooooooooooo1?l0000Looooo`;o00005oooool00ol0
003oooooooooo`06ooooo`;o00005_ooool2o`0000kooooo0_l0000;ooooo`03o`000?oooooooooo
00Sooooo0ol000000ooooooo0000o`000002o`0000gooooo0_l0000Kooooo`03o`000?oooooooooo
00kooooo0_l00008ooooo`;o00006?ooool2o`0000Kooooo00?o0000ooooooooool03_ooool2o`00
00Sooooo0_l0000<ooooo`;o00001?ooool2o`0000cooooo00?o0000ooooooooool02_ooool002Wo
oooo00Co0000oooooooooooooooo1?l0000Looooo`;o00008?ooool2o`0002Kooooo0_l0000Aoooo
o`;o00001?ooool2o`000003ooooool0003o000000;o00003Oooool2o`0001?ooooo0_l00004oooo
o`;o00004Oooool2o`0000cooooo0_l0000;ooooo`;o00001_ooool2o`0002;ooooo0_l0000<oooo
o`;o00001_ooool2o`0001Oooooo000Yooooo`03o`000?oooooooooo01Kooooo0_l0000Hooooo`;o
0000;Oooool2o`0000Gooooo0_l0000Fooooo`;o00002oooool2o`00023ooooo0_l00004ooooo`;o
00002Oooool2o`0000?ooooo1?l00007ooooo`;o00001?ooool2o`0000_ooooo0_l00006ooooo`;o
00003Oooool2o`0001?ooooo0_l00003ooooo`;o00003oooool2o`0001Oooooo000Yooooo`;o0000
5oooool2o`0001Sooooo0_l0000]ooooo`;o00001Oooool2o`0002?ooooo0_l0000Fooooo`;o0000
4?ooool2o`0000Oooooo0_l00003ooooo`Co00001?ooool2o`000003ooooool0003o000000_ooooo
0_l0000Kooooo`;o00004?ooool5o`0000?ooooo1?l00006ooooo`;o00007_ooool002Wooooo00?o
0000ooooooooool06?ooool2o`0002?ooooo0_l0000=ooooo`;o00001Oooool2o`0004[ooooo0_l0
0002ooooo`;o00001Oooool2o`0000Wooooo0_l00008ooooo`Ko00001_ooool2o`0000kooooo0_l0
000Pooooo`;o00001Oooool2o`0000Cooooo1?l00006ooooo`;o00001_ooool2o`0001kooooo000Y
ooooo`03o`000?oooooooooo01Sooooo0_l0000Sooooo`;o00003Oooool2o`0000Gooooo0ol0000B
ooooo`;o0000=Oooool2o`0000Wooooo0_l0000Cooooo`Co00004_ooool2o`0001kooooo0_l00002
ooooo`;o00000_ooool2o`0000Gooooo0_l0000:ooooo`;o00000oooool2o`0002Gooooo000Yoooo
o`03o`000?oooooooooo017ooooo0_l0000Kooooo`;o00006Oooool2o`0000Wooooo0_l00002oooo
o`;o00003_ooool2o`0006_ooooo0_l00004ooooo`;o00005oooool3o`0000;ooooo0_l0000Eoooo
o`;o00000oooool2o`0002Gooooo000Yooooo`04o`000?oooooo0000o`00013ooooo0_l0000Koooo
o`?o00006?ooool2o`0000gooooo0_l0000cooooo`;o00003oooool2o`0000Oooooo0_l0000Yoooo
o`;o00001oooool2o`0001Oooooo0_l00006ooooo`;o0000:_ooool2o`0001;ooooo000Yooooo`Co
00003?ooool2o`00017ooooo0_l0000=ooooo`;o00004?ooool2o`0003[ooooo0_l0000>ooooo`;o
00000oooool2o`0000[ooooo0_l00007ooooo`;o00001oooool3o`0001oooooo0_l0000Sooooo`;o
00000oooool5o`0001kooooo0_l00007ooooo`;o00004_ooool002Wooooo00?o0000ooooooooool0
3Oooool2o`00017ooooo0_l0000Oooooo`;o0000>_ooool2o`0001?ooooo0_l0000Looooo`?o0000
9Oooool2o`0001Gooooo0_l00006ooooo`;o00001Oooool3o`0001kooooo0_l0000Kooooo`00:Ooo
ool00ol0003oooooooooo`2Pooooo`;o00004?ooool2o`0002Cooooo0_l0000Eooooo`;o00007Ooo
ool2o`0002cooooo000Yooooo`03o`000?oooooooooo03kooooo0_l0000Jooooo`;o0000?_ooool2
o`0000Cooooo0_l0000;ooooo`;o00000oooool2o`0004Sooooo0_l0000@ooooo`;o00001oooool2
o`00013ooooo0_l0000Aooooo`00:Oooool2o`0000Wooooo0_l00003ooooo`;o00001Oooool2o`00
02Sooooo0_l0000Jooooo`;o00002?ooool2o`000003ooooool0003o000001Oooooo0_l00003oooo
o`;o00002?ooool2o`0000Wooooo0_l0000Aooooo`;o00001oooool2o`0003cooooo0_l00006oooo
o`;o00001_ooool2o`00017ooooo0_l00005ooooo`;o00002Oooool2o`00017ooooo000Yooooo`;o
00002Oooool2o`0000?ooooo0_l00005ooooo`;o000000Coooooo`000?l0003ooooo0_l0000;oooo
o`;o00001?ooool2o`0002Gooooo0_l0000>ooooo`;o000000?oooooo`000?l000003_ooool2o`00
00Oooooo0_l00003ooooo`;o00002?ooool2o`0000cooooo0_l0000Gooooo`;o00008?ooool2o`00
00Oooooo0_l0000?ooooo`Co00003_ooool2o`0001Sooooo0_l00002ooooo`;o00001?ooool2o`00
00?ooooo0_l0000=ooooo`00:Oooool00ol0003oooooooooo`0Gooooo`;o000000?oooooo`000?l0
00002oooool2o`0000Cooooo0_l0000Uooooo`;o00008Oooool2o`0002Cooooo0_l00006ooooo`;o
0000<Oooool2o`0000Oooooo0_l0000?ooooo`;o0000;_ooool2o`0000Cooooo0_l00003ooooo`;o
00003Oooool002Wooooo00?o0000ooooooooool0?Oooool2o`0004Oooooo0_l0000Mooooo`;o0000
??ooool2o`0002;ooooo0_l0000>ooooo`;o00004oooool2o`0000kooooo000Yooooo`03o`000?oo
oooooooo03gooooo0ol00016ooooo`;o00005Oooool2o`0001kooooo0_l0000Tooooo`;o00003?oo
ool2o`0000oooooo0_l00003ooooo`;o00003_ooool2o`0000Cooooo0_l0000=ooooo`;o00003_oo
ool002Wooooo00?o0000ooooooooool01oooool2o`00037ooooo1_l0000Eooooo`;o00003?ooool2
o`0003Sooooo0_l0000Nooooo`;o00002Oooool2o`0001Cooooo0_l0000Aooooo`;o00003oooool2
o`0001Sooooo0ol0000Mooooo`00:Oooool2o`0000Sooooo0_l00006ooooo`;o00002Oooool4o`00
00;ooooo0_l0000Hooooo`Co00005oooool2o`0000cooooo0_l0000Looooo`;o00002_ooool2o`00
03Wooooo0_l0000Dooooo`;o0000??ooool2o`0001kooooo000Yooooo`03o`000?oooooooooo00oo
oooo0_l00009ooooo`Co00000_ooool2o`0000Kooooo0_l0001Aooooo`;o00001?ooool2o`0000[o
oooo1Ol000000ooooooo0000o`000003o`0000Sooooo0_l0000gooooo`;o00002Oooool2o`0000[o
oooo0_l0001:ooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go
00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0:?ooool2o`00
00Wooooo0_l00005ooooo`?o00007?ooool2o`00023ooooo0_l0000Booooo`?o000000?oooooo`00
0?l000000ol00008ooooo`;o0000=oooool2o`0000Wooooo0_l00005ooooo`;o00000oooool2o`00
04[ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q
8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0<oooool2
o`0000?ooooo1Ol00003ooooo`;o00002oooool2o`0000[ooooo0_l0000fooooo`;o00005Oooool2
o`0000kooooo1?l0000_ooooo`;o00006Oooool2o`0003Cooooo0006ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool08_ooool2o`0001Cooooo0_l00006ooooo`;o00001oooool2o`0000;ooooo0_l0000U
ooooo`;o00006oooool2o`0001Gooooo0_l0000>ooooo`Co0000<Oooool2o`0000;ooooo0_l0000C
ooooo`;o0000=?ooool000Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0002;ooooo0_l00003ooooo`;o00008?ooool2
o`0002Wooooo0_l0000nooooo`;o0000=oooool2o`0000;ooooo0_l0000Dooooo`;o0000<oooool0
00Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo02Oooooo0_l0000Oooooo`;o000000?o
ooooo`000?l00000Ioooool2o`0002gooooo0_l0000Rooooo`;o0000<oooool000Kooooo00Go410@
oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`09ooooo`;o0000?Oooool2o`000003ooooool0003o000003cooooo0_l0
0011ooooo`;o00005Oooool2o`00033ooooo0_l00009ooooo`;o00006_ooool000Kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Wooooo1?l0001>ooooo`;o00004oooool2o`0001Oooooo
0_l00005ooooo`;o0000>_ooool2o`0000;ooooo0_l00013ooooo`;o00002Oooool2o`0000Wooooo
0_l0000?ooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c004ooooo`Co00001_ooool2o`0000_ooooo0ol00002ooooo`;o00007Oooool2o`0002_o
oooo0_l0000Cooooo`;o00007_ooool2o`0003kooooo0_l0000Dooooo`;o0000@oooool2o`0000oo
oooo000Yooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`;o00000oooool3o`0001co
oooo0_l0000Aooooo`;o00000oooool2o`0000Gooooo0_l00015ooooo`;o00008_ooool2o`0000?o
oooo0_l0000Dooooo`;o00004Oooool3o`00027ooooo0_l0000`ooooo`00:Oooool00ol0003ooooo
ooooo`04ooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o0000;oooool2o`0000?o
oooo0ol00004ooooo`;o00008?ooool2o`0001Wooooo0_l00008ooooo`;o00008_ooool2o`0000;o
oooo0ol0000Dooooo`;o00004_ooool2o`00027ooooo0_l0000Nooooo`;o00004?ooool002Wooooo
00?o0000ooooooooool00_ooool2o`0000Kooooo0_l0000iooooo`Co00009_ooool2o`0000kooooo
0_l00009ooooo`;o00000_ooool2o`0002cooooo0_l0000<ooooo`;o0000G_ooool2o`00013ooooo
000Yooooo`03o`000?oooooooooo00;ooooo0_l0000Qooooo`;o00007_ooool2o`0003Sooooo0_l0
000=ooooo`;o0000>_ooool2o`00073ooooo000Yooooo`03o`000?oooooooooo02Gooooo0_l0000L
ooooo`Co0000Noooool2o`0003cooooo0_l00007ooooo`;o00007?ooool2o`0001?ooooo000Yoooo
o`;o0000A?ooool4o`0001Oooooo0_l0000Booooo`;o0000C_ooool2o`0003cooooo0_l00007oooo
o`;o00007?ooool2o`0001?ooooo000Yooooo`03o`000?oooooooooo05kooooo0_l0000Booooo`;o
0000b?ooool002Wooooo00?o0000ooooooooool07oooool2o`0003Sooooo0_l0003Qooooo`00:Ooo
ool00ol0003oooooooooo`0Oooooo`;o0000=Oooool2o`000003ooooool0003o000000Sooooo0_l0
001Iooooo`;o0000:?ooool2o`000003ooooool0003o000004oooooo000Yooooo`03o`000?oooooo
oooo05Kooooo0_l0000;ooooo`;o0000FOooool2o`0002Sooooo0_l000000ooooooo0000o`00000H
ooooo`;o0000=Oooool002Wooooo0_l0000aooooo`;o0000Woooool2o`0002Oooooo0_l00009oooo
o`;o0000=Oooool002Wooooo00?o0000ooooooooool04?ooool2o`0001;ooooo0_l0000:ooooo`;o
00000_ooool2o`0009_ooooo0_l0000Wooooo`;o0000@?ooool002Wooooo00?o0000ooooooooool0
3?ooool2o`0000;ooooo0_l0000Booooo`;o00003_ooool2o`0003?ooooo0_l00009ooooo`;o0000
B_ooool2o`0007[ooooo000Yooooo`04o`000?ooooooooooooooo`;o00002Oooool2o`0004Cooooo
0_l0000Eooooo`;o00002Oooool3o`00023ooooo0_l00003ooooo`;o00006oooool2o`0000Gooooo
0_l0000Mooooo`;o00001_ooool2o`0001Sooooo0_l00006ooooo`;o00002?ooool2o`0000Gooooo
0_l0000Pooooo`00:Oooool01?l0003oooooooooooooool2o`0000;ooooo0_l0000>ooooo`;o0000
2?ooool2o`00037ooooo0ol0000Iooooo`;o00001Oooool2o`0001?ooooo0_l0000;ooooo`;o0000
0oooool2o`0001Cooooo0_l000000ooooooo0000o`000002ooooo`;o00009?ooool2o`0000Kooooo
0_l0000Hooooo`;o00001_ooool2o`0000Sooooo0_l00005ooooo`;o00008?ooool002Wooooo0_l0
0005ooooo`?o00003_ooool2o`0000Sooooo0_l0000Jooooo`;o00004Oooool2o`0000?ooooo0_l0
0002ooooo`;o00005Oooool2o`0000Kooooo0_l0000Booooo`;o00008?ooool2o`0000Cooooo0_l0
00000ooooooo0000o`00000Aooooo`;o00003?ooool2o`0000;ooooo1ol0000Eooooo`?o00008?oo
ool2o`00027ooooo000Yooooo`03o`000?oooooooooo00Cooooo0_l0000?ooooo`;o00009?ooool2
o`00017ooooo0_l00007ooooo`;o00004oooool2o`0000?ooooo0_l00003ooooo`;o00002_ooool4
o`0002Kooooo0_l0000Cooooo`;o00001Oooool2o`0000cooooo0_l00002ooooo`Go00003Oooool2
o`0000Cooooo0_l00002ooooo`?o00008?ooool2o`0001Cooooo0_l0000;ooooo`003_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`0Eooooo`;o0000B_ooool2o`0000Wooooo0_l00003ooooo`;o00003ooo
ool4o`0003_ooooo0_l0000Iooooo`;o00003_ooool2o`0000Cooooo0_l0000kooooo`;o00002ooo
ool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo067ooooo0_l0003Iooooo`003_ooool01Ol@413ooooooooooooo
oooo410@013ooooo00?o0000ooooooooool00oooool3o`000;Kooooo0_l00024ooooo`003_ooool0
1Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`2fooooo`;o0000Q?ooool000kooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo
?Oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
00Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocgooooo0006
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@
oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00ooo
ool3o`000?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooo
oooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006
ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?oo
ooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co
00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000O
ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3oooooocgooooo000Qoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003o
ooooooooo`05ooooo`?o0000oooooolmooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Oooooo`03oeEEEOmVIVKo00000?oo
ooooAoooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .26879 Mdot
.02762 .35088 Mdot
.02952 .27481 Mdot
.03143 .32759 Mdot
.03333 .35055 Mdot
.03524 .27884 Mdot
.03714 .28288 Mdot
.03905 .39441 Mdot
.04095 .3289 Mdot
.04286 .28012 Mdot
.04476 .25778 Mdot
.04667 .4234 Mdot
.04857 .41009 Mdot
.05048 .25805 Mdot
.05238 .4343 Mdot
.05429 .34281 Mdot
.05619 .3747 Mdot
.0581 .41154 Mdot
.06 .34809 Mdot
.0619 .36165 Mdot
.06381 .41179 Mdot
.06571 .38617 Mdot
.06762 .39798 Mdot
.06952 .41364 Mdot
.07143 .45002 Mdot
.07333 .2502 Mdot
.07524 .28727 Mdot
.07714 .34688 Mdot
.07905 .34078 Mdot
.08095 .36126 Mdot
.08286 .40973 Mdot
.08476 .31976 Mdot
.08667 .38433 Mdot
.08857 .37778 Mdot
.09048 .36907 Mdot
.09238 .36637 Mdot
.09429 .23067 Mdot
.09619 .33137 Mdot
.0981 .30095 Mdot
.1 .42689 Mdot
.1019 .4502 Mdot
.10381 .37571 Mdot
.10571 .32967 Mdot
.10762 .27094 Mdot
.10952 .2437 Mdot
.11143 .31273 Mdot
.11333 .25666 Mdot
.11524 .26927 Mdot
.11714 .29011 Mdot
.11905 .33094 Mdot
.12095 .27014 Mdot
.12286 .27957 Mdot
.12476 .2199 Mdot
.12667 .34638 Mdot
.12857 .35185 Mdot
.13048 .3594 Mdot
.13238 .40104 Mdot
.13429 .37324 Mdot
.13619 .23908 Mdot
.1381 .24008 Mdot
.14 .29681 Mdot
.1419 .44799 Mdot
.14381 .28907 Mdot
.14571 .27599 Mdot
.14762 .39359 Mdot
.14952 .33721 Mdot
.15143 .28264 Mdot
.15333 .34192 Mdot
.15524 .32889 Mdot
.15714 .41445 Mdot
.15905 .37724 Mdot
.16095 .32186 Mdot
.16286 .27059 Mdot
.16476 .3088 Mdot
.16667 .28907 Mdot
.16857 .30762 Mdot
.17048 .2198 Mdot
.17238 .25871 Mdot
.17429 .29663 Mdot
.17619 .29465 Mdot
.1781 .39869 Mdot
.18 .36 Mdot
.1819 .31937 Mdot
.18381 .37558 Mdot
.18571 .37324 Mdot
.18762 .34495 Mdot
.18952 .34813 Mdot
.19143 .32506 Mdot
.19333 .36486 Mdot
.19524 .34098 Mdot
.19714 .4505 Mdot
.19905 .32682 Mdot
.20095 .25971 Mdot
.20286 .32516 Mdot
.20476 .26071 Mdot
.20667 .352 Mdot
.20857 .25984 Mdot
.21048 .28616 Mdot
.21238 .21853 Mdot
.21429 .36399 Mdot
.21619 .28863 Mdot
.2181 .34919 Mdot
.22 .42526 Mdot
.2219 .29013 Mdot
.22381 .41021 Mdot
.22571 .37637 Mdot
.22762 .38091 Mdot
.22952 .35528 Mdot
.23143 .25973 Mdot
.23333 .41363 Mdot
.23524 .26923 Mdot
.23714 .32139 Mdot
.23905 .31844 Mdot
.24095 .37523 Mdot
.24286 .30296 Mdot
.24476 .2706 Mdot
.24667 .2773 Mdot
.24857 .33975 Mdot
.25048 .3286 Mdot
.25238 .23065 Mdot
.25429 .41 Mdot
.25619 .45659 Mdot
.2581 .40749 Mdot
.26 .34075 Mdot
.2619 .41415 Mdot
.26381 .33542 Mdot
.26571 .36299 Mdot
.26762 .37471 Mdot
.26952 .33817 Mdot
.27143 .31661 Mdot
.27333 .39587 Mdot
.27524 .31255 Mdot
.27714 .43442 Mdot
.27905 .27938 Mdot
.28095 .3127 Mdot
.28286 .31894 Mdot
.28476 .24127 Mdot
.28667 .34855 Mdot
.28857 .27197 Mdot
.29048 .40093 Mdot
.29238 .43542 Mdot
.29429 .42006 Mdot
.29619 .285 Mdot
.2981 .33705 Mdot
.3 .37471 Mdot
.3019 .36983 Mdot
.30381 .36077 Mdot
.30571 .3558 Mdot
.30762 .35738 Mdot
.30952 .31831 Mdot
.31143 .46242 Mdot
.31333 .34169 Mdot
.31524 .3009 Mdot
.31714 .41431 Mdot
.31905 .31891 Mdot
.32095 .24359 Mdot
.32286 .24704 Mdot
.32476 .28673 Mdot
.32667 .34492 Mdot
.32857 .23031 Mdot
.33048 .24571 Mdot
.33238 .25092 Mdot
.33429 .30174 Mdot
.33619 .44711 Mdot
.3381 .37834 Mdot
.34 .32094 Mdot
.3419 .28961 Mdot
.34381 .3582 Mdot
.34571 .40863 Mdot
.34762 .32507 Mdot
.34952 .25552 Mdot
.35143 .33996 Mdot
.35333 .26999 Mdot
.35524 .31588 Mdot
.35714 .34219 Mdot
.35905 .35873 Mdot
.36095 .39197 Mdot
.36286 .3585 Mdot
.36476 .24483 Mdot
.36667 .2734 Mdot
.36857 .32654 Mdot
.37048 .27386 Mdot
.37238 .43661 Mdot
.37429 .33062 Mdot
.37619 .4519 Mdot
.3781 .33109 Mdot
.38 .32816 Mdot
.3819 .37263 Mdot
.38381 .30591 Mdot
.38571 .4451 Mdot
.38762 .32413 Mdot
.38952 .45871 Mdot
.39143 .37113 Mdot
.39333 .29367 Mdot
.39524 .44789 Mdot
.39714 .3845 Mdot
.39905 .45736 Mdot
.40095 .42916 Mdot
.40286 .33004 Mdot
.40476 .30418 Mdot
.40667 .38428 Mdot
.40857 .26581 Mdot
.41048 .26575 Mdot
.41238 .32312 Mdot
.41429 .34838 Mdot
.41619 .2853 Mdot
.4181 .30424 Mdot
.42 .32019 Mdot
.4219 .26323 Mdot
.42381 .31463 Mdot
.42571 .33241 Mdot
.42762 .25816 Mdot
.42952 .39969 Mdot
.43143 .2636 Mdot
.43333 .40803 Mdot
.43524 .3328 Mdot
.43714 .2958 Mdot
.43905 .27052 Mdot
.44095 .4484 Mdot
.44286 .33164 Mdot
.44476 .24084 Mdot
.44667 .41901 Mdot
.44857 .28284 Mdot
.45048 .25142 Mdot
.45238 .41132 Mdot
.45429 .39063 Mdot
.45619 .33553 Mdot
.4581 .35805 Mdot
.46 .33509 Mdot
.4619 .2647 Mdot
.46381 .43484 Mdot
.46571 .45751 Mdot
.46762 .34353 Mdot
.46952 .28294 Mdot
.47143 .27142 Mdot
.47333 .32965 Mdot
.47524 .27892 Mdot
.47714 .45669 Mdot
.47905 .32328 Mdot
.48095 .3006 Mdot
.48286 .40735 Mdot
.48476 .30455 Mdot
.48667 .44631 Mdot
.48857 .30573 Mdot
.49048 .40387 Mdot
.49238 .37705 Mdot
.49429 .31556 Mdot
.49619 .26184 Mdot
.4981 .24406 Mdot
.5 .36099 Mdot
.5019 .3761 Mdot
.50381 .2912 Mdot
.50571 .45611 Mdot
.50762 .26987 Mdot
.50952 .28874 Mdot
.51143 .2355 Mdot
.51333 .24756 Mdot
.51524 .31274 Mdot
.51714 .35025 Mdot
.51905 .31112 Mdot
.52095 .39924 Mdot
.52286 .25275 Mdot
.52476 .31038 Mdot
.52667 .2781 Mdot
.52857 .3872 Mdot
.53048 .29835 Mdot
.53238 .34172 Mdot
.53429 .25968 Mdot
.53619 .25501 Mdot
.5381 .28261 Mdot
.54 .35363 Mdot
.5419 .25356 Mdot
.54381 .36758 Mdot
.54571 .34866 Mdot
.54762 .28572 Mdot
.54952 .30162 Mdot
.55143 .25152 Mdot
.55333 .32944 Mdot
.55524 .36154 Mdot
.55714 .28113 Mdot
.55905 .25475 Mdot
.56095 .24952 Mdot
.56286 .31817 Mdot
.56476 .31522 Mdot
.56667 .3158 Mdot
.56857 .23031 Mdot
.57048 .41909 Mdot
.57238 .35618 Mdot
.57429 .30776 Mdot
.57619 .35233 Mdot
.5781 .38958 Mdot
.58 .31333 Mdot
.5819 .40144 Mdot
.58381 .37064 Mdot
.58571 .23905 Mdot
.58762 .42647 Mdot
.58952 .24563 Mdot
.59143 .26985 Mdot
.59333 .2302 Mdot
.59524 .44782 Mdot
.59714 .39881 Mdot
.59905 .43171 Mdot
.60095 .37905 Mdot
.60286 .28632 Mdot
.60476 .33268 Mdot
.60667 .31438 Mdot
.60857 .31802 Mdot
.61048 .44874 Mdot
.61238 .25508 Mdot
.61429 .28273 Mdot
.61619 .2473 Mdot
.6181 .2747 Mdot
.62 .39966 Mdot
.6219 .37685 Mdot
.62381 .40842 Mdot
.62571 .46209 Mdot
.62762 .2786 Mdot
.62952 .24528 Mdot
.63143 .3764 Mdot
.63333 .40082 Mdot
.63524 .29787 Mdot
.63714 .4388 Mdot
.63905 .45445 Mdot
.64095 .41751 Mdot
.64286 .34135 Mdot
.64476 .28158 Mdot
.64667 .37643 Mdot
.64857 .27289 Mdot
.65048 .35967 Mdot
.65238 .2699 Mdot
.65429 .27308 Mdot
.65619 .37909 Mdot
.6581 .41014 Mdot
.66 .23528 Mdot
.6619 .26171 Mdot
.66381 .3934 Mdot
.66571 .31869 Mdot
.66762 .32316 Mdot
.66952 .33901 Mdot
.67143 .28839 Mdot
.67333 .3206 Mdot
.67524 .25149 Mdot
.67714 .35019 Mdot
.67905 .22936 Mdot
.68095 .24845 Mdot
.68286 .35437 Mdot
.68476 .27225 Mdot
.68667 .37531 Mdot
.68857 .28155 Mdot
.69048 .35159 Mdot
.69238 .37579 Mdot
.69429 .26693 Mdot
.69619 .28802 Mdot
.6981 .42239 Mdot
.7 .42035 Mdot
.7019 .22899 Mdot
.70381 .36357 Mdot
.70571 .27215 Mdot
.70762 .38294 Mdot
.70952 .34704 Mdot
.71143 .33548 Mdot
.71333 .42047 Mdot
.71524 .42035 Mdot
.71714 .40247 Mdot
.71905 .43376 Mdot
.72095 .44062 Mdot
.72286 .45148 Mdot
.72476 .32134 Mdot
.72667 .31906 Mdot
.72857 .43637 Mdot
.73048 .39911 Mdot
.73238 .31987 Mdot
.73429 .40678 Mdot
.73619 .25122 Mdot
.7381 .26554 Mdot
.74 .28258 Mdot
.7419 .29752 Mdot
.74381 .30023 Mdot
.74571 .22976 Mdot
.74762 .24604 Mdot
.74952 .39607 Mdot
.75143 .22987 Mdot
.75333 .39427 Mdot
.75524 .44653 Mdot
.75714 .32159 Mdot
.75905 .23215 Mdot
.76095 .24272 Mdot
.76286 .31749 Mdot
.76476 .45568 Mdot
.76667 .36069 Mdot
.76857 .27163 Mdot
.77048 .43794 Mdot
.77238 .41448 Mdot
.77429 .27262 Mdot
.77619 .29955 Mdot
.7781 .25749 Mdot
.78 .28794 Mdot
.7819 .27503 Mdot
.78381 .41395 Mdot
.78571 .447 Mdot
.78762 .43819 Mdot
.78952 .38046 Mdot
.79143 .23262 Mdot
.79333 .38172 Mdot
.79524 .35882 Mdot
.79714 .36018 Mdot
.79905 .30815 Mdot
.80095 .40826 Mdot
.80286 .42232 Mdot
.80476 .28439 Mdot
.80667 .26956 Mdot
.80857 .26901 Mdot
.81048 .34128 Mdot
.81238 .4604 Mdot
.81429 .33308 Mdot
.81619 .38285 Mdot
.8181 .29816 Mdot
.82 .3058 Mdot
.8219 .30507 Mdot
.82381 .34027 Mdot
.82571 .37865 Mdot
.82762 .28563 Mdot
.82952 .3164 Mdot
.83143 .4598 Mdot
.83333 .39894 Mdot
.83524 .29526 Mdot
.83714 .36604 Mdot
.83905 .38093 Mdot
.84095 .24079 Mdot
.84286 .25597 Mdot
.84476 .31826 Mdot
.84667 .45687 Mdot
.84857 .34349 Mdot
.85048 .31463 Mdot
.85238 .26485 Mdot
.85429 .27735 Mdot
.85619 .31181 Mdot
.8581 .34652 Mdot
.86 .43848 Mdot
.8619 .26292 Mdot
.86381 .37769 Mdot
.86571 .22576 Mdot
.86762 .27478 Mdot
.86952 .28206 Mdot
.87143 .35792 Mdot
.87333 .3907 Mdot
.87524 .27841 Mdot
.87714 .31445 Mdot
.87905 .33188 Mdot
.88095 .3558 Mdot
.88286 .37882 Mdot
.88476 .26686 Mdot
.88667 .27984 Mdot
.88857 .32025 Mdot
.89048 .39573 Mdot
.89238 .28459 Mdot
.89429 .30883 Mdot
.89619 .33714 Mdot
.8981 .2459 Mdot
.9 .36631 Mdot
.9019 .4042 Mdot
.90381 .37935 Mdot
.90571 .38385 Mdot
.90762 .29581 Mdot
.90952 .4118 Mdot
.91143 .45614 Mdot
.91333 .25533 Mdot
.91524 .22958 Mdot
.91714 .25501 Mdot
.91905 .37163 Mdot
.92095 .35445 Mdot
.92286 .287 Mdot
.92476 .35197 Mdot
.92667 .28781 Mdot
.92857 .3791 Mdot
.93048 .45348 Mdot
.93238 .30767 Mdot
.93429 .30282 Mdot
.93619 .33163 Mdot
.9381 .29481 Mdot
.94 .3231 Mdot
.9419 .34204 Mdot
.94381 .35012 Mdot
.94571 .32224 Mdot
.94762 .26639 Mdot
.94952 .24909 Mdot
.95143 .33935 Mdot
.95333 .35411 Mdot
.95524 .25295 Mdot
.95714 .32798 Mdot
.95905 .349 Mdot
.96095 .31138 Mdot
.96286 .28843 Mdot
.96476 .30625 Mdot
.96667 .3451 Mdot
.96857 .2609 Mdot
.97048 .37819 Mdot
.97238 .33354 Mdot
.97429 .33998 Mdot
.97619 .43219 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0000jooooo`;o0000ooooool2
ooooo`00:Oooool00ol0003oooooooooo`0Mooooo`;o00003?ooool2o`0000cooooo0_l0003ooooo
o`;ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Mooooo`;o00003?ooool2
o`000?oooooo4?ooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooo`cooooo0_l0000_ooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04ooo
ool2o`00037ooooo0_l0000Fooooo`;o0000Boooool2o`0000Kooooo0_l0000Jooooo`;o00001Ooo
ool2o`0000cooooo1?l0000Sooooo`;o00003_ooool2o`0001oooooo0006ooooo`05o`000?oooooo
ooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0
000Cooooo`;o0000<Oooool2o`0001Kooooo0_l0001;ooooo`;o00001_ooool2o`0001[ooooo0_l0
0005ooooo`;o00003?ooool4o`000003ooooool0003o000000Sooooo0_l0000Vooooo`;o00007ooo
ool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo09Wooooo0_l0000^ooooo`;o0000
7_ooool2o`0000Sooooo0_l00017ooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo023ooooo
0ol0001fooooo`;o00005_ooool2o`0001Kooooo0_l0001aooooo`001_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool08?ooool3o`0002gooooo0_l0000booooo`;o0000:oooool2o`0003Ko
oooo0_l0000Hooooo`;o0000=oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool06?ooool2o`00
03Kooooo0_l0000:ooooo`;o000000?oooooo`000?l000002Oooool2o`0001Sooooo0_l0000?oooo
o`;o00006oooool2o`0000_ooooo0_l0000Tooooo`;o00000_ooool2o`0001Sooooo0_l0000@oooo
o`;o00009Oooool002Wooooo0_l0000Iooooo`;o0000@_ooool2o`000003ooooool0003o000000Wo
oooo0_l0000Yooooo`;o00000oooool2o`0000gooooo0_l00007ooooo`;o00001oooool2o`0000;o
oooo0_l0000?ooooo`;o00004oooool2o`0002kooooo0_l0000?ooooo`;o00005?ooool002Wooooo
00?o0000ooooooooool03?ooool2o`0004kooooo0_l000000ooooooo0000o`00000Tooooo`;o0000
4oooool2o`000003ooooool0003o000000Oooooo0_l000000ooooooo0000o`00000@ooooo`;o0000
4Oooool4o`0000oooooo0_l00013ooooo`;o00005?ooool002Wooooo00?o0000ooooooooool03?oo
ool2o`00057ooooo0_l00004ooooo`;o00007_ooool2o`0001Kooooo0_l00002ooooo`Co000000?o
ooooo`000?l000000_l0000@ooooo`;o00004_ooool2o`00017ooooo0_l0000gooooo`Co00002_oo
ool2o`0001;ooooo000Yooooo`03o`000?oooooooooo00?ooooo1?l0000Booooo`;o00004Oooool2
o`0003Oooooo0_l0000Gooooo`;o00008Oooool4o`0000?ooooo0_l0000@ooooo`;o0000<oooool2
o`0001?ooooo0_l0000Dooooo`Co00002_ooool2o`0001;ooooo000Yooooo`03o`000?oooooooooo
00?ooooo1?l0000Booooo`;o00004Oooool2o`0000Oooooo1Ol00005ooooo`;o0000?Oooool2o`00
01Cooooo0_l0000:ooooo`;o00009oooool2o`0002Cooooo0_l0000Cooooo`;o00009_ooool2o`00
00kooooo000Yooooo`;o0000=_ooool5o`0000Gooooo0_l0000kooooo`;o000000?oooooo`000?l0
00002?ooool2o`0000Wooooo0_l0000:ooooo`;o00009oooool2o`0003cooooo0_l000000ooooooo
0000o`00000Pooooo`;o00003_ooool002Wooooo00?o0000ooooooooool0N?ooool3o`000004oooo
ool0003o0000ooooo`;o00002?ooool2o`0004Wooooo0_l0000<ooooo`;o00008oooool2o`000003
ooooool0003o000000Gooooo0_l0000Booooo`;o00005Oooool002Wooooo0_l0000Hooooo`;o0000
00?oooooo`000?l000000_l0000;ooooo`;o00001Oooool4o`000008oa0@4?ooooooooooonk^k_lb
<S;o0000oc8b<_o^k^h3ooooo`04onk^k_l0003o0000oc8b<P;o00008Oooool2o`0000Gooooo1Ol0
0003ooooo`03onk^k_lb<S;o000000?o00000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;o0000
2?ooool2o`0000[ooooo0_l0000@ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko
0000o`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`;o00003?ooool2
o`0000cooooo0_l00005ooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko0000o`000?l0003ok^k^01Gooooo0_l0000Booooo`?o000000Wo<S8bomgM
gOooooooooooonk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo000Yooooo`;o00006?ooool2o`000003ooooool0003o000000;o00002oooool2o`0000Oooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00CoMgMgo`000?l0
003oV9RH0_l0000<ooooo`;o00004oooool2o`0000?ooooo0ol000001?lQ8B7ok^k^oooooom4A4@3
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00;o0000
2?ooool2o`0000[ooooo0_l0000@ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOo
0000o`000?nHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`Co00002?ooool2
o`0000Gooooo0_l0000@ooooo`03o`000?oooooo000000?o000000CoV9RHoooooonHV9SoMgMg0ooo
ool01OmgMgOo0000o`000?l0003oMgMg02cooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9Sooooo
oiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000Yooooo`?o00008oooool2
o`0000gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@4002o`0000_ooooo0_l0000Hooooo`?o000000?oV9RHob4Q8Oo^k^h0
1?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@400/oooo
o`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00;o000000?o
oooooa0@4?ooool01Oooool4o`0000Sooooo0_l00005ooooo`;o00003Oooool;o`000003ooooool@
413ooooo00;ooooo00Go410@oooooooooooooooooa0@400;ooooo`;o00000oooool2o`0001_ooooo
00Co0000oooooooooooo410@0oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooo
ooooool00Oooool002Wooooo1ol0000Hooooo`;o00001Oooool2o`0000gooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooooooo0ol00008
ooooo`;o00007oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000_ooooo0_l0000?ooooo`;o00003Oooool00onYZJWo410@
ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool3o`000003ooooool0003o000002Oo
oooo00CoA4A4omgMgOoooooo00001?ooool3o`000003ooooool0003ooooo00;ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`;o00000oooool4o`0000;ooooo0_l0000Dooooo`05ogMgMolb<S;o
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
0Oooool002Wooooo00?o0000ooooooooool01?l0000Hooooo`;o00001oooool2o`0000_ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`00000:ooooo`;o00008?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo0_l00005ooooo`?o00003oooool2
o`0000;ooooo0_l00004ooooo`;o00000_ooool00ol@413o0000okZj^P03ooooo`05o`000?oooooo
ooooooooool000000oooool2o`0000;ooooo0_l00004ooooo`;o00003?ooool2o`0000oooooo0_l0
0002ooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000004?ooool4o`0000;ooooo0_l0000Aooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`00:Oooool01?l0003oooooooooooooool2o`0002;ooooo0_l0000;ooooo`03o`00
0?oooooooooo00;ooooo00Go410@o`000?l0003ooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41004?ooool2o`0000Oooooo0_l0000Booooo`05o`000?ooooooooooooooool@41000oooool0
1Ol@413o0000o`000?oooooo410@00?ooooo00Co410@oooooooooooooooo0_l00005ooooo`;o0000
5?ooool2o`000004ooooool0003o0000ooooo`;o00000oooool00onj^[[o8B4Qooooo`02ooooo`04
oa0@4?ooooooooooooooo`;o00000_ooool2o`0000;ooooo00?o410@ooooooooool00oooool2o`00
00cooooo0_l0000?ooooo`;o00000oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41000oooool2o`0000;ooooo00Co410@oooooooooooooooo0_l0000;ooooo`;o00001_oo
ool2o`0000Oooooo0_l00006ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooo
oa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool002Wooooo00?o0000ooooooooool0
3Oooool2o`0000_ooooo0_l00007ooooo`;o00001Oooool2o`0000Kooooo00?o0000ooooooooool0
0_ooool00omgMgOo0000o`000004o`000006oooooomgMgOoV9RHoooooonHV9SoMgMg4?ooool2o`00
00Oooooo0_l00004ooooo`;o00002?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`02o`000006oooooomgMgOoV9RHoooooonHV9SoMgMg5_ooool2o`0000_o
oooo0_l00003ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01?mgMgOoV9RHoooooonHV9P2
o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`;o00001Oooool2o`0001;ooooo00?o
k^k^odA4A?l000001?ooool2o`000003oooooonHV9SoMgMg00?ooooo0_l000000oooooooV9RHogMg
M`03ooooo`;o00004oooool2o`0000Oooooo1?l00004ooooo`03o`000?oooooooooo00;ooooo0_l0
00001OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00
:Oooool00ol0003oooooooooo`0=ooooo`;o00002oooool2o`0000Oooooo0_l00005ooooo`;o0000
1?ooool00omEEEGoIVIVo`000004ooooo`03onk^k_lb<S;o000000Co000000Koooooonk^k_lb<S;o
0000oc8b<_o^k^hOooooo`;o00002?ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h05Oooool3o`00013ooooo
00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00kooooo0_l00005ooooo`;o00004oooool00omgMgOo0000ooooo`03
ooooo`?o000000?o<S8bonk^k_ooool00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02?ooooo0_l0
0004ooooo`Co000000Soooooo`000?l0003ok^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`00:Oooool2o`0002kooooo0_l00014ooooo`;o00003?ooool2o`00
01Cooooo0_l0001Xooooo`;o00005Oooool2o`0000Sooooo0_l0000Hooooo`00:Oooool00ol0003o
ooooooooo`0Rooooo`;o00002Oooool2o`0004Cooooo0_l0000<ooooo`;o00007?ooool2o`00023o
oooo0_l0000Pooooo`;o00005oooool2o`0000?ooooo0_l0000Eooooo`;o00002?ooool2o`0001So
oooo000Yooooo`03o`000?oooooooooo01Cooooo0_l0000<ooooo`;o00002Oooool2o`0002_ooooo
0_l00004ooooo`;o0000;Oooool2o`0000kooooo0_l00004ooooo`;o00006_ooool2o`00023ooooo
0ol00008ooooo`;o00003?ooool2o`0003kooooo000Yooooo`03o`000?oooooooooo01Cooooo0_l0
000]ooooo`;o00005Oooool2o`0000Cooooo0_l0000Eooooo`;o00000_ooool2o`0001;ooooo0ol0
000Cooooo`;o0000?Oooool2o`0000Sooooo0_l0000=ooooo`;o00008_ooool2o`0001Wooooo000Y
ooooo`03o`000?oooooooooo02[ooooo0ol0000Fooooo`;o0000:oooool2o`0000Gooooo0_l00002
ooooo`;o00004oooool4o`0001Wooooo0_l00017ooooo`;o00001?ooool3o`00027ooooo0ol00008
ooooo`;o00003oooool0027oooooool00014o`0000Cooooo000Yooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool01?l0003oooooo`000?l00008ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00?ooooo1?l00002ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo0_l00005ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01oooool5o`0000[ooooo00?o0000ooooooooool00oooool2o`00
00Cooooo00?o0000ooooooooool00_l00007ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`05ooooo`Co000000?oooooo`000?ooool00_ooool2o`00
00?ooooo0_l000000ooooooo0000ooooo`0:ooooo`03o`000?oooooooooo00Cooooo0_l00003oooo
o`03o`000?oooooooooo00[ooooo000Yooooo`03o`000?oooooooooo01Sooooo0_l0000Pooooo`03
o`000?oooooooooo00oooooo1Ol0000Fooooo`;o00003oooool00ol0003oooooooooo`02ooooo`;o
00005Oooool2o`0000Cooooo0_l0000>ooooo`?o00000_ooool2o`0000Cooooo00?o0000oooooooo
ool00_l0000`ooooo`;o00001_ooool00ol0003oooooooooo`0:ooooo`;o00001Oooool2o`0000Oo
oooo0_l0000Nooooo`03o`000?oooooooooo00[ooooo000Yooooo`03o`000?oooooooooo013ooooo
0_l0000Mooooo`;o00004?ooool2o`0000Wooooo0_l00002ooooo`;o00001_ooool2o`000003oooo
ool0003o000000Gooooo0_l00003ooooo`;o00004oooool2o`0001Kooooo0_l0000Dooooo`?o0000
2oooool2o`00017ooooo1?l0000?ooooo`Co00002?ooool2o`0001?ooooo0_l00003ooooo`;o0000
3?ooool2o`0002Sooooo000Yooooo`03o`000?oooooooooo013ooooo0_l0000Fooooo`;o00001Ooo
ool2o`00013ooooo0_l0000=ooooo`;o00001_ooool2o`000003ooooool0003o000000Gooooo0_l0
000=ooooo`;o00001_ooool2o`000003ooooool0003o0000017ooooo0_l0000Iooooo`;o00007ooo
ool4o`0000oooooo1?l00006ooooo`;o00006_ooool2o`0000cooooo0_l0000?ooooo`Co00005Ooo
ool002Wooooo0_l0000Yooooo`;o00002?ooool2o`000004ooooool0003o0000o`0000Wooooo0_l0
000Qooooo`;o00001Oooool2o`0000Cooooo0_l00006ooooo`;o00005?ooool2o`0003[ooooo0_l0
000Aooooo`;o00002?ooool2o`0003Wooooo1?l0000Eooooo`00:Oooool01Ol0003oooooo`000?l0
003ooooo00;o00004oooool2o`0000kooooo0_l00009ooooo`;o000000Coooooo`000?l0003o0000
3Oooool2o`0001gooooo0_l00005ooooo`;o00000_ooool2o`0000Gooooo0_l0000Eooooo`;o0000
6?ooool2o`0007oooooo0_l0000Booooo`00:Oooool01Ol0003oooooo`000?l0003ooooo00;o0000
4?ooool2o`000003ooooool0003o000000;ooooo0_l0000:ooooo`;o00007?ooool2o`0002Kooooo
1?l00005ooooo`;o00001Oooool2o`0000;ooooo1?l00008ooooo`;o00006?ooool2o`0000kooooo
0_l00011ooooo`;o00004oooool2o`00017ooooo0_l00004ooooo`;o00000oooool2o`0000gooooo
000Yooooo`03o`000?oooooooooo01Cooooo0_l00005ooooo`;o0000;?ooool2o`0002;ooooo0ol0
000=ooooo`;o00000_ooool4o`0000;ooooo1?l0000/ooooo`;o00008?ooool2o`0001oooooo0_l0
000Cooooo`;o00004Oooool2o`0000Wooooo0_l0000=ooooo`00:Oooool00ol0003oooooooooo`0U
ooooo`;o00007_ooool2o`0000;ooooo1?l00007ooooo`;o0000<Oooool4o`00047ooooo0_l0000;
ooooo`;o0000>_ooool2o`00013ooooo0_l0000Cooooo`00:Oooool2o`0000Oooooo0_l00006oooo
o`;o00005Oooool3o`0000_ooooo0_l0000@ooooo`;o000000Coooooo`000?l0003ooooo0_l00007
ooooo`;o00000oooool2o`0000_ooooo0ol0000gooooo`;o00008Oooool2o`0000Oooooo0_l0000[
ooooo`;o00000oooool2o`0001Gooooo0_l0000<ooooo`;o00000_ooool2o`0000Gooooo0_l0000<
ooooo`00:Oooool00ol0003oooooooooo`06ooooo`;o00001_ooool2o`0001Kooooo0_l00009oooo
o`Co00004oooool2o`0000oooooo0_l00003ooooo`;o00001_ooool3o`0002;ooooo0_l0000Coooo
o`;o00008Oooool2o`0003Cooooo0_l00003ooooo`;o00001Oooool2o`0001cooooo0_l00006oooo
o`;o000000?oooooo`000?l000003?ooool002Wooooo00?o0000ooooooooool02?ooool2o`0000?o
oooo0_l0000>ooooo`;o00004_ooool3o`0000Oooooo0_l0000Dooooo`;o00002oooool2o`0001[o
oooo0_l0000?ooooo`;o00005oooool2o`0003?ooooo0_l0000Zooooo`;o00000_ooool2o`0001ko
oooo1?l0000?ooooo`00:Oooool4o`0000Oooooo0_l00003ooooo`;o00003_ooool3o`0001;ooooo
0_l00003ooooo`;o00000_ooool2o`0001Cooooo0_l0000Wooooo`;o00007oooool2o`0000Oooooo
0_l00008ooooo`;o00007_ooool2o`0000?ooooo0_l00004ooooo`;o0000;_ooool2o`0001?ooooo
0_l00004ooooo`;o00000oooool2o`00017ooooo000Yooooo`Co00007Oooool2o`0001Oooooo0_l0
0005ooooo`;o0000Foooool2o`0000Gooooo0_l0000:ooooo`;o00007_ooool4o`000003ooooool0
003o000004Sooooo0ol00004ooooo`;o000000?oooooo`000?l000004oooool002Wooooo0_l0000o
ooooo`;o00005oooool3o`0000Wooooo0_l00004ooooo`;o00007Oooool2o`0001Sooooo0_l00009
ooooo`;o00008Oooool2o`0003_ooooo0_l000000ooooooo0000o`00000;ooooo`;o00002?ooool2
o`0001?ooooo000Yooooo`03o`000?oooooooooo00Wooooo0_l00004ooooo`;o00003_ooool2o`00
00gooooo0_l0000Vooooo`Co00002Oooool2o`0000?ooooo0ol0000Mooooo`;o00002oooool2o`00
013ooooo0_l00004ooooo`;o00005oooool2o`0002?ooooo0_l00007ooooo`?o00005_ooool2o`00
0003ooooool0003o000002[ooooo000Yooooo`03o`000?oooooooooo00Wooooo0_l00004ooooo`;o
00003_ooool2o`0000gooooo0_l0000:ooooo`;o00003_ooool2o`0000[ooooo0_l0000@ooooo`;o
0000:oooool2o`00013ooooo0_l0000Mooooo`;o00003oooool2o`0001;ooooo0_l00007ooooo`?o
0000AOooool002Wooooo00?o0000ooooooooool04_ooool2o`0001oooooo0_l00005ooooo`;o0000
3_ooool2o`0005Oooooo0_l0000booooo`;o0000:Oooool2o`0001;ooooo0_l0000Tooooo`00:Ooo
ool00ol0003oooooooooo`0Booooo`;o00007oooool2o`00027ooooo0_l0001;ooooo`;o00002ooo
ool2o`00053ooooo0_l0000Booooo`;o00009?ooool002Wooooo0_l0000Cooooo`;o00003?ooool2
o`0000kooooo0_l0000Tooooo`;o00005oooool2o`000003ooooool0003o000003cooooo0_l0001Z
ooooo`;o00007_ooool002Wooooo00?o0000ooooooooool01oooool2o`0000gooooo0_l00008oooo
o`;o00001_ooool2o`0000Kooooo0_l0000;ooooo`;o00000oooool2o`0000Oooooo0_l00008oooo
o`;o00006?ooool2o`000003ooooool0003o000001oooooo0_l000000ooooooo0000o`00000Uoooo
o`;o000000?oooooo`000?l000000oooool2o`0000[ooooo1?l00017ooooo`;o00007_ooool000Ko
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00Oooooo0_l00008ooooo`;o00000oooool2
o`00013ooooo0_l00006ooooo`;o00002oooool2o`0000?ooooo0_l00007ooooo`;o00002?ooool2
o`0000[ooooo0_l0000`ooooo`;o000000?oooooo`000?l000007_ooool2o`0000Gooooo0_l00000
0ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000001oooool4o`0002Wooooo0_l0000:
ooooo`;o00001?ooool2o`0000Gooooo0_l00006ooooo`;o00003?ooool2o`0000gooooo0006oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4
A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool04Oooool2o`0002_ooooo0_l0
000Qooooo`;o0000Doooool2o`00013ooooo0_l0000>ooooo`;o00006?ooool4o`0000Gooooo0_l0
00000ooooooo0000o`000002ooooo`;o00001_ooool2o`0000Cooooo0_l00005ooooo`;o00001_oo
ool2o`0000cooooo0_l0000=ooooo`001_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo0_l0
0004ooooo`;o0000;?ooool2o`0003Cooooo0_l000000ooooooo0000o`00001Oooooo`;o00006?oo
ool4o`0000Gooooo0_l00005ooooo`;o00005?ooool2o`0002;ooooo0006ooooo`05o`000?oooooo
ooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0
000:ooooo`;o00001?ooool2o`0006;ooooo0_l000000ooooooo0000o`00000Vooooo`;o00003Ooo
ool2o`0006Sooooo0_l0000Rooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
JOooool2o`0001cooooo0_l0000Fooooo`;o00003Oooool2o`0005gooooo0_l0000]ooooo`001_oo
ool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`04o`000?ooooooooooooooo`;o00008Oooool2o`0002Oooooo0_l0000Jooooo`;o
00007?ooool2o`00047ooooo0_l0000Kooooo`;o00009?ooool2o`0000Cooooo0_l0000Wooooo`00
1_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004oooo
o`03o`000?oooooooooo00Oooooo00Co0000oooooooooooooooo0_l00007ooooo`;o00006?ooool2
o`0000Sooooo0_l0000Mooooo`;o0000I_ooool2o`0001?ooooo0_l0000Jooooo`?o00006?ooool2
o`00013ooooo0_l0000Wooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`0:ooooo`;o00004ooo
ool2o`0000gooooo0_l0000Rooooo`;o0000:oooool2o`0001_ooooo0_l0000Booooo`;o00000ooo
ool2o`0000Gooooo0_l00002ooooo`;o00007Oooool2o`0000Gooooo0_l0000Iooooo`;o0000>Ooo
ool002Wooooo0_l0000Pooooo`;o0000<Oooool2o`0002_ooooo0_l0000Aooooo`;o00002?ooool2
o`0001;ooooo0_l0000:ooooo`;o00000_ooool2o`0001Wooooo0_l00002ooooo`;o0000=_ooool2
o`0002?ooooo000Yooooo`03o`000?oooooooooo04Sooooo0_l0000fooooo`;o00003_ooool4o`00
04Oooooo0_l00004ooooo`;o00004oooool2o`0001oooooo0_l0000Sooooo`00:Oooool00ol0003o
ooooooooo`04ooooo`;o00002Oooool2o`0002cooooo0_l00007ooooo`Co00006_ooool2o`0001[o
oooo0_l00004ooooo`;o00002?ooool2o`0002_ooooo0_l00009ooooo`;o00005oooool2o`0001?o
oooo0_l00014ooooo`00:Oooool00ol0003oooooooooo`04ooooo`;o000000?oooooo`000?l00000
1?l00002ooooo`;o00005_ooool2o`0001Cooooo0_l000000ooooooo0000o`000004ooooo`;o0000
00?oooooo`000?l000004?ooool2o`0000Oooooo0_l0000Pooooo`;o0000=Oooool2o`0000Wooooo
0_l0000Sooooo`;o00000_ooool2o`0002Kooooo0_l0000Qooooo`00:Oooool00ol0003ooooooooo
o`07ooooo`Ko00006_ooool2o`0001Oooooo0_l00007ooooo`;o00004?ooool2o`0006Kooooo0_l0
000Xooooo`;o00000_ooool2o`0002Kooooo0_l0000Qooooo`00:Oooool2o`0005Cooooo0_l0000_
ooooo`;o00009_ooool2o`0001Gooooo0_l0000Aooooo`;o00000_ooool3o`0005oooooo000Yoooo
o`03o`000?oooooooooo00Cooooo0_l0001=ooooo`;o0000;oooool2o`0002Kooooo0_l0000Woooo
o`?o00000_ooool3o`0001[ooooo0_l00013ooooo`00:Oooool00ol0003oooooooooo`04ooooo`;o
00003oooool2o`0002Cooooo0_l0001eooooo`;o00008Oooool2o`00023ooooo0_l00013ooooo`00
:Oooool00ol0003oooooooooo`0Eooooo`;o00009?ooool2o`0003Wooooo0_l0000jooooo`;o0000
R?ooool002Wooooo00?o0000ooooooooool0M_ooool2o`0003gooooo0_l0001hooooo`;o00002ooo
ool002Wooooo0_l00006ooooo`;o0000Aoooool2o`0000?ooooo0_l0000eooooo`;o0000:Oooool2
o`0002Gooooo0_l0001Aooooo`;o00002oooool002Wooooo00?o0000ooooooooool01Oooool2o`00
04Oooooo0_l00003ooooo`;o00005oooool2o`0001cooooo0_l0000eooooo`;o00006Oooool2o`00
0003ooooool0003o000000_ooooo0_l00004ooooo`;o00005Oooool2o`00037ooooo000Yooooo`03
o`000?oooooooooo06cooooo0_l0001Cooooo`;o00006Oooool2o`000003ooooool0003o000000_o
oooo0_l00004ooooo`;o00005Oooool2o`00037ooooo000Yooooo`03o`000?oooooooooo077ooooo
0_l0001Yooooo`;o0000G_ooool002Wooooo00?o0000ooooooooool08_ooool2o`0003gooooo0_l0
000>ooooo`;o000000?oooooo`000?l000003?ooool2o`0000gooooo0_l0000Qooooo`;o00000ooo
ool2o`0002cooooo0_l00008ooooo`;o0000BOooool002Wooooo0_l0000=ooooo`;o00001oooool2
o`0000_ooooo0_l0000@ooooo`;o0000:oooool2o`00017ooooo0_l0000<ooooo`;o00003Oooool2
o`00027ooooo0_l00003ooooo`;o00008_ooool2o`0000Sooooo0_l00008ooooo`;o0000BOooool0
02Wooooo00?o0000ooooooooool03?ooool2o`0000Oooooo0_l0000Mooooo`;o0000>?ooool2o`00
05;ooooo0_l0000Iooooo`;o0000@Oooool2o`0001[ooooo000>ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo04Oooooo0_l0000Uooooo`;o00001Oooool2o`0001?ooooo0_l00002ooooo`;o00001oooool2
o`0002Wooooo0_l0000Wooooo`;o00006?ooool2o`0001?ooooo0_l00004ooooo`;o00006_ooool0
00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo04Oooooo0_l0000Yooooo`;o000000?oooooo`000?l000004oooool2
o`0000;ooooo0_l00007ooooo`;o0000D_ooool2o`0000gooooo0_l00004ooooo`;o00000oooool2
o`0001?ooooo0_l0000Pooooo`003_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000
ooooooooool00oooool3o`0005Wooooo0_l0000Gooooo`;o0000B_ooool2o`0003[ooooo0_l00004
ooooo`;o0000>_ooool000kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0FOooool2o`0006?ooooo0_l0001looooo`003_ooool01Ol0
003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oo
oooooooo0?oooooo?Oooool000kooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo000>
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0003oooooockooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVY
oeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolmooooo`001_ooool01Ol0
003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00000>
ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oo
oooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmg
MgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool001oooooo1?l000000ol@413oooooooooo`03oooo
o`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo0ol0003oooooocgooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool001oooooo00?oEEEEofIVI_l00000oooooom7ooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .25101 Mdot
.02762 .2597 Mdot
.02952 .29627 Mdot
.03143 .27354 Mdot
.03333 .36152 Mdot
.03524 .35928 Mdot
.03714 .27492 Mdot
.03905 .2949 Mdot
.04095 .23214 Mdot
.04286 .33675 Mdot
.04476 .28521 Mdot
.04667 .34645 Mdot
.04857 .36604 Mdot
.05048 .31818 Mdot
.05238 .37307 Mdot
.05429 .33108 Mdot
.05619 .33044 Mdot
.0581 .37018 Mdot
.06 .29204 Mdot
.0619 .41714 Mdot
.06381 .38121 Mdot
.06571 .31617 Mdot
.06762 .34483 Mdot
.06952 .38044 Mdot
.07143 .41062 Mdot
.07333 .31945 Mdot
.07524 .25679 Mdot
.07714 .29123 Mdot
.07905 .40837 Mdot
.08095 .27349 Mdot
.08286 .39726 Mdot
.08476 .2291 Mdot
.08667 .2818 Mdot
.08857 .36947 Mdot
.09048 .38494 Mdot
.09238 .41414 Mdot
.09429 .31618 Mdot
.09619 .26713 Mdot
.0981 .3871 Mdot
.1 .35105 Mdot
.1019 .4041 Mdot
.10381 .37882 Mdot
.10571 .38119 Mdot
.10762 .24867 Mdot
.10952 .28164 Mdot
.11143 .36126 Mdot
.11333 .31265 Mdot
.11524 .2396 Mdot
.11714 .24776 Mdot
.11905 .40234 Mdot
.12095 .2393 Mdot
.12286 .37583 Mdot
.12476 .32326 Mdot
.12667 .38442 Mdot
.12857 .38733 Mdot
.13048 .2522 Mdot
.13238 .30626 Mdot
.13429 .32404 Mdot
.13619 .27154 Mdot
.1381 .29326 Mdot
.14 .35533 Mdot
.1419 .46253 Mdot
.14381 .3799 Mdot
.14571 .32638 Mdot
.14762 .29893 Mdot
.14952 .23507 Mdot
.15143 .3376 Mdot
.15333 .32723 Mdot
.15524 .26377 Mdot
.15714 .39206 Mdot
.15905 .33013 Mdot
.16095 .28893 Mdot
.16286 .33023 Mdot
.16476 .34576 Mdot
.16667 .37988 Mdot
.16857 .27629 Mdot
.17048 .32274 Mdot
.17238 .32985 Mdot
.17429 .38609 Mdot
.17619 .24804 Mdot
.1781 .41406 Mdot
.18 .27222 Mdot
.1819 .2655 Mdot
.18381 .38036 Mdot
.18571 .26549 Mdot
.18762 .33092 Mdot
.18952 .36278 Mdot
.19143 .36183 Mdot
.19333 .30247 Mdot
.19524 .33006 Mdot
.19714 .41448 Mdot
.19905 .42271 Mdot
.20095 .29828 Mdot
.20286 .36364 Mdot
.20476 .30716 Mdot
.20667 .4371 Mdot
.20857 .32093 Mdot
.21048 .23239 Mdot
.21238 .31432 Mdot
.21429 .29886 Mdot
.21619 .24101 Mdot
.2181 .27368 Mdot
.22 .35161 Mdot
.2219 .23985 Mdot
.22381 .40876 Mdot
.22571 .37342 Mdot
.22762 .34506 Mdot
.22952 .31011 Mdot
.23143 .29751 Mdot
.23333 .39478 Mdot
.23524 .33056 Mdot
.23714 .26615 Mdot
.23905 .229 Mdot
.24095 .41938 Mdot
.24286 .21708 Mdot
.24476 .281 Mdot
.24667 .34549 Mdot
.24857 .2355 Mdot
.25048 .23078 Mdot
.25238 .30933 Mdot
.25429 .36727 Mdot
.25619 .45591 Mdot
.2581 .37393 Mdot
.26 .40884 Mdot
.2619 .39422 Mdot
.26381 .28832 Mdot
.26571 .41551 Mdot
.26762 .44814 Mdot
.26952 .25003 Mdot
.27143 .2704 Mdot
.27333 .33729 Mdot
.27524 .23871 Mdot
.27714 .36855 Mdot
.27905 .36029 Mdot
.28095 .37531 Mdot
.28286 .39851 Mdot
.28476 .34285 Mdot
.28667 .41082 Mdot
.28857 .33108 Mdot
.29048 .30889 Mdot
.29238 .3742 Mdot
.29429 .46148 Mdot
.29619 .2626 Mdot
.2981 .27268 Mdot
.3 .32993 Mdot
.3019 .41915 Mdot
.30381 .25167 Mdot
.30571 .23134 Mdot
.30762 .33044 Mdot
.30952 .36087 Mdot
.31143 .44849 Mdot
.31333 .2639 Mdot
.31524 .25278 Mdot
.31714 .38092 Mdot
.31905 .28094 Mdot
.32095 .32249 Mdot
.32286 .34916 Mdot
.32476 .3792 Mdot
.32667 .23913 Mdot
.32857 .31131 Mdot
.33048 .34784 Mdot
.33238 .28328 Mdot
.33429 .38936 Mdot
.33619 .38971 Mdot
.3381 .4157 Mdot
.34 .3769 Mdot
.3419 .24116 Mdot
.34381 .24942 Mdot
.34571 .41268 Mdot
.34762 .26064 Mdot
.34952 .35871 Mdot
.35143 .40518 Mdot
.35333 .27554 Mdot
.35524 .25586 Mdot
.35714 .3625 Mdot
.35905 .33593 Mdot
.36095 .2947 Mdot
.36286 .44028 Mdot
.36476 .32501 Mdot
.36667 .27836 Mdot
.36857 .40104 Mdot
.37048 .3731 Mdot
.37238 .37045 Mdot
.37429 .34592 Mdot
.37619 .40865 Mdot
.3781 .30257 Mdot
.38 .23226 Mdot
.3819 .4466 Mdot
.38381 .2276 Mdot
.38571 .38599 Mdot
.38762 .37997 Mdot
.38952 .44865 Mdot
.39143 .41973 Mdot
.39333 .33286 Mdot
.39524 .45981 Mdot
.39714 .28049 Mdot
.39905 .42124 Mdot
.40095 .35848 Mdot
.40286 .36392 Mdot
.40476 .41055 Mdot
.40667 .36119 Mdot
.40857 .301 Mdot
.41048 .29762 Mdot
.41238 .2961 Mdot
.41429 .36044 Mdot
.41619 .39863 Mdot
.4181 .23857 Mdot
.42 .33095 Mdot
.4219 .34815 Mdot
.42381 .26115 Mdot
.42571 .31587 Mdot
.42762 .28364 Mdot
.42952 .34027 Mdot
.43143 .33497 Mdot
.43333 .41304 Mdot
.43524 .34333 Mdot
.43714 .2397 Mdot
.43905 .34019 Mdot
.44095 .39343 Mdot
.44286 .29975 Mdot
.44476 .29308 Mdot
.44667 .33628 Mdot
.44857 .34869 Mdot
.45048 .25537 Mdot
.45238 .40996 Mdot
.45429 .41534 Mdot
.45619 .33932 Mdot
.4581 .35205 Mdot
.46 .24564 Mdot
.4619 .28302 Mdot
.46381 .37398 Mdot
.46571 .45805 Mdot
.46762 .31445 Mdot
.46952 .31589 Mdot
.47143 .3883 Mdot
.47333 .25438 Mdot
.47524 .26052 Mdot
.47714 .45284 Mdot
.47905 .25979 Mdot
.48095 .23771 Mdot
.48286 .36713 Mdot
.48476 .23828 Mdot
.48667 .46224 Mdot
.48857 .37335 Mdot
.49048 .41806 Mdot
.49238 .32964 Mdot
.49429 .22804 Mdot
.49619 .30962 Mdot
.4981 .3444 Mdot
.5 .29831 Mdot
.5019 .3269 Mdot
.50381 .38152 Mdot
.50571 .41886 Mdot
.50762 .28228 Mdot
.50952 .3309 Mdot
.51143 .33005 Mdot
.51333 .30714 Mdot
.51524 .25489 Mdot
.51714 .38872 Mdot
.51905 .2795 Mdot
.52095 .30434 Mdot
.52286 .25297 Mdot
.52476 .24618 Mdot
.52667 .26103 Mdot
.52857 .41604 Mdot
.53048 .26437 Mdot
.53238 .26459 Mdot
.53429 .25921 Mdot
.53619 .30133 Mdot
.5381 .36006 Mdot
.54 .41004 Mdot
.5419 .27958 Mdot
.54381 .41595 Mdot
.54571 .3874 Mdot
.54762 .33984 Mdot
.54952 .24651 Mdot
.55143 .35421 Mdot
.55333 .34696 Mdot
.55524 .3361 Mdot
.55714 .23377 Mdot
.55905 .2931 Mdot
.56095 .33364 Mdot
.56286 .39729 Mdot
.56476 .26805 Mdot
.56667 .34555 Mdot
.56857 .30876 Mdot
.57048 .33968 Mdot
.57238 .3124 Mdot
.57429 .27029 Mdot
.57619 .3539 Mdot
.5781 .42227 Mdot
.58 .36014 Mdot
.5819 .41173 Mdot
.58381 .44538 Mdot
.58571 .27227 Mdot
.58762 .35625 Mdot
.58952 .26269 Mdot
.59143 .29944 Mdot
.59333 .29547 Mdot
.59524 .45661 Mdot
.59714 .42201 Mdot
.59905 .36753 Mdot
.60095 .25151 Mdot
.60286 .24964 Mdot
.60476 .38457 Mdot
.60667 .23874 Mdot
.60857 .22855 Mdot
.61048 .4032 Mdot
.61238 .3075 Mdot
.61429 .23333 Mdot
.61619 .30085 Mdot
.6181 .31715 Mdot
.62 .34176 Mdot
.6219 .3366 Mdot
.62381 .36445 Mdot
.62571 .44464 Mdot
.62762 .27243 Mdot
.62952 .2799 Mdot
.63143 .37502 Mdot
.63333 .31088 Mdot
.63524 .26404 Mdot
.63714 .37562 Mdot
.63905 .44409 Mdot
.64095 .46328 Mdot
.64286 .30679 Mdot
.64476 .36204 Mdot
.64667 .38097 Mdot
.64857 .36978 Mdot
.65048 .35197 Mdot
.65238 .31343 Mdot
.65429 .28615 Mdot
.65619 .33928 Mdot
.6581 .32084 Mdot
.66 .32876 Mdot
.6619 .31093 Mdot
.66381 .3284 Mdot
.66571 .27205 Mdot
.66762 .29799 Mdot
.66952 .2484 Mdot
.67143 .3649 Mdot
.67333 .37684 Mdot
.67524 .28213 Mdot
.67714 .35894 Mdot
.67905 .3471 Mdot
.68095 .29442 Mdot
.68286 .26567 Mdot
.68476 .32345 Mdot
.68667 .27019 Mdot
.68857 .25955 Mdot
.69048 .41171 Mdot
.69238 .29851 Mdot
.69429 .27793 Mdot
.69619 .34975 Mdot
.6981 .4622 Mdot
.7 .34018 Mdot
.7019 .30344 Mdot
.70381 .41379 Mdot
.70571 .25713 Mdot
.70762 .36081 Mdot
.70952 .40836 Mdot
.71143 .25863 Mdot
.71333 .34063 Mdot
.71524 .46556 Mdot
.71714 .4188 Mdot
.71905 .36767 Mdot
.72095 .37964 Mdot
.72286 .40353 Mdot
.72476 .31217 Mdot
.72667 .24877 Mdot
.72857 .37685 Mdot
.73048 .30356 Mdot
.73238 .31542 Mdot
.73429 .40763 Mdot
.73619 .28613 Mdot
.7381 .3505 Mdot
.74 .24326 Mdot
.7419 .22952 Mdot
.74381 .23782 Mdot
.74571 .30352 Mdot
.74762 .3458 Mdot
.74952 .34061 Mdot
.75143 .31805 Mdot
.75333 .3345 Mdot
.75524 .39999 Mdot
.75714 .21721 Mdot
.75905 .29273 Mdot
.76095 .32137 Mdot
.76286 .27953 Mdot
.76476 .43376 Mdot
.76667 .29312 Mdot
.76857 .28952 Mdot
.77048 .37221 Mdot
.77238 .39361 Mdot
.77429 .31661 Mdot
.77619 .34369 Mdot
.7781 .33015 Mdot
.78 .25614 Mdot
.7819 .23618 Mdot
.78381 .41118 Mdot
.78571 .4588 Mdot
.78762 .3736 Mdot
.78952 .35533 Mdot
.79143 .35124 Mdot
.79333 .35942 Mdot
.79524 .33239 Mdot
.79714 .33956 Mdot
.79905 .31328 Mdot
.80095 .31829 Mdot
.80286 .34464 Mdot
.80476 .258 Mdot
.80667 .27514 Mdot
.80857 .26722 Mdot
.81048 .33941 Mdot
.81238 .43588 Mdot
.81429 .36527 Mdot
.81619 .41711 Mdot
.8181 .25916 Mdot
.82 .25295 Mdot
.8219 .26452 Mdot
.82381 .36474 Mdot
.82571 .36538 Mdot
.82762 .25655 Mdot
.82952 .33247 Mdot
.83143 .4527 Mdot
.83333 .30536 Mdot
.83524 .31023 Mdot
.83714 .38608 Mdot
.83905 .34542 Mdot
.84095 .29791 Mdot
.84286 .27618 Mdot
.84476 .25661 Mdot
.84667 .43404 Mdot
.84857 .43338 Mdot
.85048 .23834 Mdot
.85238 .23073 Mdot
.85429 .24468 Mdot
.85619 .33417 Mdot
.8581 .24225 Mdot
.86 .38199 Mdot
.8619 .27618 Mdot
.86381 .30275 Mdot
.86571 .34042 Mdot
.86762 .26983 Mdot
.86952 .32221 Mdot
.87143 .34324 Mdot
.87333 .41662 Mdot
.87524 .25407 Mdot
.87714 .41619 Mdot
.87905 .31074 Mdot
.88095 .38473 Mdot
.88286 .37697 Mdot
.88476 .31933 Mdot
.88667 .2718 Mdot
.88857 .34767 Mdot
.89048 .29718 Mdot
.89238 .26803 Mdot
.89429 .39292 Mdot
.89619 .24753 Mdot
.8981 .27774 Mdot
.9 .41618 Mdot
.9019 .4086 Mdot
.90381 .34585 Mdot
.90571 .45339 Mdot
.90762 .34274 Mdot
.90952 .32356 Mdot
.91143 .41724 Mdot
.91333 .29794 Mdot
.91524 .29862 Mdot
.91714 .27741 Mdot
.91905 .3241 Mdot
.92095 .41294 Mdot
.92286 .24141 Mdot
.92476 .30211 Mdot
.92667 .34979 Mdot
.92857 .36797 Mdot
.93048 .4631 Mdot
.93238 .37241 Mdot
.93429 .27381 Mdot
.93619 .38096 Mdot
.9381 .2478 Mdot
.94 .30789 Mdot
.9419 .31628 Mdot
.94381 .38518 Mdot
.94571 .3796 Mdot
.94762 .29106 Mdot
.94952 .31395 Mdot
.95143 .23625 Mdot
.95333 .36016 Mdot
.95524 .26718 Mdot
.95714 .26197 Mdot
.95905 .29844 Mdot
.96095 .32295 Mdot
.96286 .21977 Mdot
.96476 .32423 Mdot
.96667 .25366 Mdot
.96857 .24698 Mdot
.97048 .41618 Mdot
.97238 .26869 Mdot
.97429 .40722 Mdot
.97619 .3622 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l00014ooooo`;o0000Xoooool2
o`0005;ooooo000Yooooo`03o`000?oooooooooo04?ooooo0_l0002Sooooo`;o0000@?ooool2o`00
013ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooob_ooooo0_l0000@
ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo073ooooo0_l0
003:ooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^
kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04?ooool2o`0002oooooo0_l0
0002ooooo`;o0000:Oooool2o`0002;ooooo0_l0000Rooooo`;o0000:Oooool2o`0002;ooooo0_l0
000cooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00omgMgOo<S8booooo`04ooooo`?o00000_ooool2o`0000cooooo0_l0000Vooooo`;o00001ooo
ool2o`0000;ooooo0_l0000@ooooo`;o00005_ooool2o`0002?ooooo0_l0000Booooo`;o00003_oo
ool4o`0002Oooooo0_l0000Rooooo`;o0000<oooool000Kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo00;ooooo0_l0000Qooooo`;o00004Oooool2o`0000_ooooo0_l0000@ooooo`;o0000
5_ooool2o`0003Oooooo0_l0000@ooooo`;o0000=?ooool2o`0003Gooooo0_l0000Cooooo`001_oo
ool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo01[ooooo1?l00007ooooo`;o00005Oooool2o`0000Oooooo
0_l00006ooooo`;o00003oooool2o`0001_ooooo0_l00004ooooo`;o00003?ooool3o`0002Kooooo
0_l0000Zooooo`;o00002_ooool2o`0001Cooooo0_l0000Oooooo`;o00004oooool000Kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo01[ooooo1?l0000Looooo`Co00003oooool2o`0000oo
oooo0_l00003ooooo`;o00005_ooool2o`0000Cooooo0_l0000<ooooo`?o00009_ooool2o`0002Wo
oooo0ol0000Pooooo`;o000000?oooooo`000?l000004_ooool2o`0001gooooo0006ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006oooo
o`03o`000?oooooooooo03[ooooo0_l0000Wooooo`;o00009?ooool2o`0001;ooooo0_l00006oooo
o`;o0000??ooool2o`0002;ooooo1?l0000Booooo`;o00007Oooool002Wooooo0_l0000Hooooo`;o
000000?oooooo`000?l000004Oooool2o`0003Cooooo0_l0000Tooooo`;o00004_ooool2o`0000Ko
oooo0_l0000?ooooo`;o00005?ooool2o`00013ooooo0_l0000Wooooo`;o00003?ooool2o`0000_o
oooo0_l00008ooooo`;o00003_ooool002Wooooo0_l0000Hooooo`;o000000?oooooo`000?l00000
0oooool2o`0000cooooo0_l0000Looooo`;o00002Oooool2o`0000;ooooo0_l00007ooooo`;o0000
DOooool2o`0001Cooooo0_l0000@ooooo`;o0000=Oooool2o`0000_ooooo0_l00008ooooo`;o0000
3_ooool002Wooooo0_l0000Pooooo`;o0000:_ooool2o`0000Wooooo0_l00002ooooo`;o00002ooo
ool2o`0001cooooo0_l00006ooooo`;o00002oooool2o`000003ooooool0003o000001Oooooo0_l0
0014ooooo`;o00004?ooool2o`0001_ooooo0_l0000?ooooo`00:Oooool00ol0003oooooooooo`0=
ooooo`;o0000F?ooool2o`0001cooooo0_l00006ooooo`;o00002oooool2o`000003ooooool0003o
000003Wooooo0ol0000Dooooo`;o00001_ooool2o`0000?ooooo0_l000000ooooooo0000o`000003
ooooo`;o00002?ooool2o`0001_ooooo0_l0000?ooooo`00:Oooool2o`0000kooooo0_l0001Eoooo
o`;o00005oooool2o`0000kooooo1?l0000=ooooo`Co0000<?ooool2o`0000Cooooo0ol0000Doooo
o`;o00001_ooool2o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`;o00008_ooool2o`00
01;ooooo000Yooooo`;o0000:?ooool2o`0002_ooooo0_l00003ooooo`;o00002Oooool2o`0001Oo
oooo0_l0000>ooooo`Co00003Oooool4o`00013ooooo0_l0000=ooooo`;o00003oooool2o`0002So
oooo0ol0000Yooooo`;o00004_ooool002Wooooo00?o0000ooooooooool05?ooool2o`00017ooooo
0_l00006ooooo`?o00003oooool2o`00017ooooo0_l00003ooooo`;o0000A?ooool3o`0000Sooooo
0_l00006ooooo`;o00003Oooool2o`0000gooooo0_l0000Wooooo`;o00000_ooool2o`0001Gooooo
0_l0000Booooo`;o00004_ooool002Wooooo00?o0000ooooooooool05?ooool2o`0001Wooooo1Ol0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?l0003o
k^k^00Sooooo0_l0000Oooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0Xooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Aooooo`?o00005_ooool2o`000009oa0@4?oooooooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o0000onk^kP0@ooooo`;o
00001_ooool2o`0000oooooo00?oA4A4o`000?l000000_l00002ooooo`05onk^k_l0003o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Yooooo`04o`000?oooooo0000
o`0000kooooo0_l0000?ooooo`;o00003?ooool2o`0000;ooooo00?o0000ooooooooool00_ooool0
1?mgMgOoV9RHoooooonHV9P2o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`;o0000
1_ooool2o`0001Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg02Sooooo00?o410@okZj^_ooool00_l00002
ooooo`;o000000CoV9RHoooooonHV9SoMgMg0oooool01?mgMgOoV9RHoooooonHV9P2o`0000_ooooo
0_l00004ooooo`;o00005oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg013ooooo0_l00004ooooo`;o00003Oooool2o`00
00Gooooo00GoMgMgoc8b<_ooooooooooogMgM`02o`000003oiRHV?mgMgOooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool00ol0003oooooo`000003o`0000cooooo0_l0000?
ooooo`;o00002Oooool2o`000003ooooool0003o000000;ooooo00?o0000ooooooooool00_ooool0
1?l@413oooooooooooooool2o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`;o0000
4?ooool2o`0000Kooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400/ooooo`03o`000?oooooooooo00;o00000oooool01Ol@
413ooooooooooooooooo410@00?ooooo0_l0000;ooooo`;o00006_ooool5o`0000?ooooo00Go410@
oooooooooooooooooa0@4003ooooo`05oa0@4?l0003o0000ooooool@41002?ooool2o`0000Cooooo
0_l00006ooooo`;o00002?ooool2o`0000?ooooo0_l00006ooooo`04o`000?oooooooooooa0@40?o
oooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo007ooooo000Yooooo`;o
00000_ooool2o`0002Sooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000008_ooool2o`0000?ooooo0_l00002
ooooo`03oiRHV?lQ8B7ok^k^00;ooooo0_l00003ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`0Hooooo`;o00001Oooool2o`0000Sooooo00?oZJVYoa0@4?ooool00_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooooooo0ol0000Cooooo`;o
00004Oooool00om4A4CogMgMooooo`02o`0000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`?o000000?oooooo`000?ooool01oooool2o`0000Cooooo0_l00009ooooo`;o00001Oooool2o`00
00[ooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`01ooooo`00:Oooool00ol0003oooooooooo`0@ooooo`;o00001_ooool2
o`0001Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co
0000oooooooooooooooo0_l0000Fooooo`;o00000_ooool2o`0000[ooooo0_l00003ooooo`04ogMg
MomVIVKoooooooooo`;o00000oooool01?l0003oooooooooooooool3o`000003ooooool0003ooooo
00Kooooo0_l0000=ooooo`;o00000_ooool2o`0000Gooooo0_l00007ooooo`03oa0@4?l0003o^[Zj
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooooooo`?o00003Ooo
ool2o`0000Cooooo0_l0000Aooooo`03omgMgOmEEEGooooo00;o00000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`00000Iooooo`;o00003_ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool002Wooooo00?o0000ooooooooool00oooool2o`0000_ooooo0_l00006
ooooo`;o00006?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool01?l@413oooooooooooooool2o`0001Kooooo0_l00002ooooo`;o00004?ooool01Ol0003ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4002o`000003ooooool@413ooooo
00Kooooo0_l0000=ooooo`;o00004oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo0_l00005ooooo`;o00004Ooo
ool2o`0000Gooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooooooooa0@400Yooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooo
oooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool002Wooooo00?o0000oooo
ooooool00oooool2o`0002?ooooo0_l00008ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0002;ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo0_l0000Hooooo`;o0000
1Oooool01?o^k^koA4A4o`000?ooool2o`000006oooooomgMgOoV9RHoooooonHV9SoMgMg0oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg02Wooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool00ol0003ooooo
ooooo`08ooooo`;o00000oooool2o`0001;ooooo0_l00005ooooo`;o00001_ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_l0000Rooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`;o00008_ooool2o`000005ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Zooooo`Go000000Koooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0:Oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool002Wooooo0ol000000ooooooo0000o`000005oooo
o`;o00000oooool2o`0001;ooooo0_l00016ooooo`;o00003_ooool2o`0000Wooooo0_l0000Roooo
o`;o00002Oooool2o`0001_ooooo0_l0000Gooooo`Co0000>?ooool2o`0001Gooooo000Yooooo`?o
000000?oooooo`000?l000008Oooool2o`0000oooooo0_l00003ooooo`;o00000oooool2o`0002So
oooo0_l0000>ooooo`;o00006_ooool2o`0001cooooo0_l0000Fooooo`;o00000oooool2o`000003
ooooool0003o000002kooooo0_l0000>ooooo`;o00001Oooool3o`0000cooooo0_l0000Aooooo`00
:Oooool00ol0003oooooooooo`0Tooooo`;o00003Oooool4o`0000?ooooo0_l00003ooooo`;o0000
;Oooool2o`0000Sooooo0ol00008ooooo`;o00004?ooool2o`0000[ooooo0_l0000@ooooo`;o0000
1_ooool2o`0000kooooo0_l00006ooooo`;o0000;_ooool2o`0000kooooo0_l00005ooooo`?o0000
00?oooooo`000?l000002Oooool2o`00017ooooo000Yooooo`03o`000?oooooooooo03?ooooo0_l0
000iooooo`;o00002?ooool2o`0000Wooooo0_l0000Gooooo`;o00000oooool2o`0001Sooooo0_l0
000Iooooo`;o00001oooool2o`0000?ooooo0_l0000Kooooo`;o00001oooool2o`0001;ooooo0_l0
000Looooo`00:Oooool00ol0003oooooooooo`0Oooooo`;o00005Oooool2o`0006;ooooo1?l0000=
ooooo`;o00003Oooool2o`0000Oooooo0_l0000Aooooo`;o00001oooool2o`0000?ooooo0_l0000K
ooooo`;o00001oooool2o`0001Oooooo0_l0000Gooooo`008Oooooooo`0004Co00001?ooool002Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;o
00001oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo0_l00003ooooo`;o
00001_ooool2o`0000[ooooo0_l0000:ooooo`;o00002oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool2o`0000?ooooo00Co0000oooooooo
oooooooo0_l00006ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooooooo0_l00006
ooooo`03o`000?oooooooooo00Sooooo0_l00004ooooo`;o000000?oooooo`000?l000000_ooool0
0ol0003oooooooooo`0:ooooo`04o`000?ooooooooooooooo`;o00001_ooool00ol0003ooooooooo
o`09ooooo`04o`000?ooooooooooooooo`;o00001_ooool00ol0003oooooooooo`02o`0000Sooooo
00Co0000oooooooooooooooo0_l00006ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool00_l00007ooooo`03o`000?oooooooooo00[ooooo000Yooooo`03o`000?oooooooooo00[ooooo
0_l00007ooooo`;o00001?ooool2o`0001kooooo0_l0000mooooo`03o`000?oooooooooo00;ooooo
0_l0000<ooooo`?o00007oooool2o`0000Kooooo00?o0000ooooooooool00oooool2o`0000Wooooo
0_l0000Fooooo`Co00001?ooool2o`0000Kooooo0_l00002ooooo`04o`000?ooooooooooooooo`;o
0000:oooool2o`000003ooooool0003o000000Oooooo00?o0000ooooooooool02_ooool002Wooooo
00?o0000ooooooooool01Oooool2o`0000?ooooo1?l00005ooooo`;o00008oooool2o`0004?ooooo
0_l0000=ooooo`;o0000;Oooool2o`0000_ooooo0_l0000Fooooo`;o00001?ooool2o`0000Kooooo
0_l00006ooooo`;o00006Oooool2o`00013ooooo0_l0000Gooooo`00:Oooool00ol0003ooooooooo
o`05ooooo`;o00001Oooool2o`0000oooooo0_l000000ooooooo0000o`000009ooooo`;o00002ooo
ool2o`0002;ooooo0_l0001Zooooo`;o00001oooool2o`0001Kooooo0_l0000;ooooo`;o00005?oo
ool2o`0000?ooooo0_l00006ooooo`;o000000?oooooo`000?l000003?ooool3o`0000oooooo000Y
ooooo`;o00007_ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000000ooo
ool2o`0002oooooo0_l0000<ooooo`;o0000:_ooool2o`0003Wooooo0_l0000Fooooo`;o00008Ooo
ool2o`0000_ooooo0_l000000ooooooo0000o`00000<ooooo`?o00003oooool002Wooooo00?o0000
ooooooooool01oooool2o`0001[ooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o
000000Gooooo0_l0000;ooooo`;o00004oooool2o`000003ooooool0003o0000013ooooo0_l0000W
ooooo`;o000000Coooooo`000?l0003ooooo0_l0000^ooooo`?o00008oooool2o`0004_ooooo000Y
ooooo`03o`000?oooooooooo00Kooooo0ol0000Oooooo`?o000000?oooooo`000?l000000oooool4
o`0000_ooooo0_l0000?ooooo`;o00000_ooool2o`000003ooooool0003o000001Wooooo0_l00007
ooooo`;o00005Oooool2o`0000?ooooo0ol0000>ooooo`;o00007_ooool3o`0002?ooooo0_l00003
ooooo`;o00002Oooool2o`0003_ooooo000Yooooo`03o`000?oooooooooo00;ooooo0_l00002oooo
o`;o0000:Oooool2o`0001kooooo0_l0000Eooooo`;o00002Oooool2o`0000Oooooo0_l000000ooo
oooo0000o`000003ooooo`;o00004_ooool2o`0000gooooo1?l0000Booooo`;o0000:?ooool2o`00
00_ooooo0_l00009ooooo`;o00001oooool2o`0003;ooooo000Yooooo`03o`000?oooooooooo00;o
oooo0_l0000Qooooo`;o00009_ooool2o`0001Wooooo0_l0000Eooooo`;o00000oooool2o`000003
ooooool0003o000001cooooo1?l00003ooooo`;o00003oooool2o`0000Wooooo0_l0000Mooooo`;o
00003?ooool2o`0000;ooooo0_l0000=ooooo`;o0000<_ooool002Wooooo0_l0000Vooooo`;o0000
9_ooool2o`000003ooooool0003o000002gooooo0_l000000ooooooo0000o`000003ooooo`;o0000
7?ooool2o`0000Gooooo0_l0000>ooooo`;o00002_ooool2o`0000cooooo0_l00002ooooo`;o0000
2_ooool2o`0000gooooo0_l00002ooooo`;o00004?ooool2o`0000_ooooo0_l0000Rooooo`00:Ooo
ool00ol0003oooooooooo`0:ooooo`;o00007_ooool2o`0001;ooooo0_l00004ooooo`;o00002_oo
ool2o`0001_ooooo0_l0000@ooooo`Go00004Oooool2o`0001Cooooo0_l0000?ooooo`;o00006?oo
ool2o`0000;ooooo0_l00009ooooo`?o00001_ooool2o`0000Oooooo0_l00009ooooo`;o00001ooo
ool4o`0000Sooooo0ol0000Rooooo`00:Oooool00ol0003oooooooooo`04ooooo`;o00001?ooool2
o`0001kooooo0_l0000Booooo`;o00001?ooool2o`0001Kooooo0_l000000ooooooo0000o`00000<
ooooo`;o00003Oooool2o`0000?ooooo0_l00002ooooo`;o00003_ooool2o`00013ooooo0_l00002
ooooo`;o00008_ooool2o`0001Cooooo0_l00007ooooo`;o00001oooool2o`0000Wooooo0_l00009
ooooo`;o00000oooool2o`0000?ooooo0_l0000Sooooo`00:Oooool00ol0003oooooooooo`04oooo
o`;o00003oooool2o`0002Cooooo0_l0000Oooooo`;o000000?oooooo`000?l000006oooool2o`00
00Oooooo0_l000000ooooooo0000o`00000Mooooo`;o00007Oooool2o`0000Oooooo0_l00003oooo
o`;o00003?ooool2o`0000oooooo0_l0000Mooooo`;o00002oooool2o`0001_ooooo000Yooooo`03
o`000?oooooooooo01Gooooo0_l0000;ooooo`;o00005oooool2o`0004_ooooo0_l0000Looooo`;o
00001_ooool2o`0001Kooooo0_l0000<ooooo`;o00003?ooool2o`0000kooooo0ol0000Zooooo`;o
00006oooool002Wooooo0_l0000Sooooo`;o0000D_ooool2o`0002kooooo0_l00006ooooo`;o0000
0_ooool2o`0003kooooo0_l00018ooooo`00:Oooool00ol0003oooooo`000002o`0001Kooooo0_l0
000dooooo`;o00002?ooool2o`0000_ooooo0_l0000?ooooo`?o000000?oooooo`000?l000009_oo
ool2o`0000_ooooo0_l000000ooooooo0000o`00000Jooooo`;o00002?ooool2o`0001[ooooo0_l0
000aooooo`;o00004oooool002Wooooo00?o0000ooooool000000_l0000Fooooo`;o00006?ooool2
o`0000;ooooo0_l0000Fooooo`;o00002?ooool2o`0000_ooooo1?l0000=ooooo`?o000000?ooooo
o`000?l000009_ooool2o`0000_ooooo0_l0000<ooooo`;o00001Oooool2o`0000Sooooo0_l00008
ooooo`;o00006_ooool2o`0000Sooooo0_l0000Wooooo`;o00001_ooool2o`0000_ooooo000Yoooo
o`03o`000?oooooooooo00Cooooo0_l0000/ooooo`;o00000_ooool2o`0000kooooo0_l0000Ooooo
o`;o00003Oooool2o`0001Sooooo0_l0000Sooooo`;o00001_ooool2o`0000Gooooo0_l00007oooo
o`;o00003Oooool2o`0001cooooo0_l00002ooooo`;o0000;oooool2o`0000_ooooo000Yooooo`03
o`000?oooooooooo00Cooooo0_l000000ooooooo0000o`000008ooooo`;o0000<oooool2o`0000Ko
oooo0_l0000Looooo`;o00008_ooool2o`0002?ooooo0_l0000>ooooo`;o00001_ooool2o`0000go
oooo0_l0000Looooo`;o00000_ooool2o`0001oooooo0_l0000Kooooo`00:Oooool2o`0000Kooooo
1?l00008ooooo`;o0000:_ooool2o`0000Wooooo0_l00004ooooo`;o00007?ooool2o`0001cooooo
0_l00006ooooo`;o0000<Oooool2o`0002Gooooo0_l00004ooooo`;o0000:oooool3o`0001[ooooo
000Yooooo`03o`000?oooooooooo00Gooooo0_l0000Eooooo`;o00007oooool2o`0000Wooooo0_l0
0005ooooo`;o00000_ooool2o`0000gooooo0_l00008ooooo`;o00007?ooool2o`0000Kooooo0_l0
000/ooooo`?o00002_ooool2o`00013ooooo0_l0000;ooooo`;o00001?ooool2o`0001cooooo0_l0
000>ooooo`;o00006_ooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01Kooooo
0_l00004ooooo`;o00001Oooool2o`0000Gooooo0_l0000Sooooo`;o00000_ooool2o`0000Sooooo
0_l00003ooooo`;o00003Oooool2o`0004gooooo0ol0000:ooooo`;o00003Oooool2o`000003oooo
ool0003o000002oooooo0_l0000Cooooo`;o00005Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`09ooooo`Co00002Oooool3o`0000[ooooo0_l00005ooooo`;o
00001?ooool2o`0002Wooooo1?l0000Booooo`;o00009?ooool2o`0002cooooo0_l0000Eooooo`;o
0000:oooool2o`0001Oooooo0_l000000ooooooo0000o`00000Eooooo`001_ooool01Ol@413ooooo
oooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Wooooo1?l00005ooooo`;o00000oooool2o`0000Cooooo0_l0000>ooooo`;o
000000?oooooo`000?l00000:Oooool2o`0001Cooooo0_l0000Tooooo`;o00007_ooool2o`0000co
oooo0_l0000kooooo`;o00001Oooool2o`0000Gooooo0_l0000@ooooo`Co00005_ooool000Kooooo
00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_oo
ool01?ooool3o`0001;ooooo1?l00007ooooo`?o00003Oooool2o`00037ooooo0_l0000?ooooo`;o
00006Oooool2o`0000gooooo0_l00007ooooo`;o00004Oooool2o`0004Wooooo0_l0000<ooooo`;o
00004_ooool2o`0001Kooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOo
IVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Doooo
o`;o00002?ooool2o`0000Oooooo0_l0000gooooo`?o0000:Oooool2o`0000gooooo0_l00007oooo
o`;o0000U_ooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Wooooo`;o00005oooool2o`00
00Oooooo0_l0000Fooooo`;o00007oooool2o`0006Wooooo0_l0000Uooooo`;o00009_ooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo0_l0000_ooooo`;o00001oooool2
o`0000Gooooo0_l0000Xooooo`;o00001_ooool2o`0002Kooooo0_l00011ooooo`;o00009Oooool2
o`0002Kooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo00oooooo0_l0000oooooo`;o00006Ooo
ool2o`0000gooooo0_l0000^ooooo`;o0000>oooool2o`0005?ooooo000Yooooo`;o00005_ooool2
o`0000Cooooo0_l00019ooooo`;o00000oooool2o`0004cooooo0_l0000Rooooo`;o00002?ooool2
o`0005?ooooo000Yooooo`03o`000?oooooooooo01Gooooo0_l00004ooooo`;o0000BOooool2o`00
057ooooo0_l0000Rooooo`;o00000_ooool2o`0004_ooooo0_l0000<ooooo`00:Oooool00ol0003o
ooooooooo`0<ooooo`Co0000;Oooool2o`0000Wooooo0_l00007ooooo`;o00006oooool2o`0000Oo
oooo0_l0000=ooooo`;o00006_ooool2o`0003Gooooo0_l00006ooooo`;o00003_ooool2o`0002Co
oooo0_l0000Eooooo`;o00003?ooool002Wooooo00?o0000ooooooooool03?ooool4o`0000;ooooo
0_l0000Jooooo`;o00001?ooool2o`0000Oooooo0_l00009ooooo`;o00001oooool2o`00017ooooo
0_l00008ooooo`;o00001oooool2o`0000Oooooo0_l00004ooooo`;o00006_ooool2o`0000cooooo
0_l0000Qooooo`;o00000_ooool4o`0001Kooooo0_l0000Tooooo`;o00001?ooool2o`0001gooooo
000Yooooo`03o`000?oooooooooo00Wooooo0_l00007ooooo`;o00006_ooool2o`0000Cooooo0_l0
000Dooooo`;o00005Oooool2o`000003ooooool0003o000001[ooooo0_l00005ooooo`;o00005_oo
ool2o`0000;ooooo0_l0000;ooooo`;o00008Oooool2o`0000;ooooo0_l0000Rooooo`;o00004?oo
ool4o`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l000003_ooool2o`0000gooooo000Y
ooooo`;o00002_ooool2o`0003Oooooo0_l00006ooooo`;o00002_ooool2o`0000Wooooo0_l0000?
ooooo`;o00004oooool2o`0000Wooooo0_l00003ooooo`;o00001_ooool2o`0000;ooooo0_l0000f
ooooo`;o00007_ooool2o`00013ooooo1?l00005ooooo`;o00000_ooool2o`00017ooooo0_l0000=
ooooo`00:Oooool00ol0003oooooooooo`0eooooo`;o00002oooool2o`0001;ooooo0_l0000Joooo
o`;o000000?oooooo`000?l000006oooool2o`0000?ooooo0_l0000Eooooo`;o00001Oooool2o`00
02Cooooo0_l0001Oooooo`00:Oooool00ol0003oooooooooo`0eooooo`;o0000?_ooool2o`0003Oo
oooo0_l00005ooooo`;o0000QOooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000k?ooool2o`0000gooooo0_l00009
ooooo`;o0000=Oooool002Wooooo00?o0000ooooooooool0=oooool2o`000;;ooooo0_l0000=oooo
o`;o00002Oooool2o`0003Gooooo000Yooooo`03o`000?oooooooooo03Oooooo0_l0000`ooooo`;o
0000dOooool002Wooooo00?o0000ooooooooool0JOooool2o`0004Gooooo0_l0000<ooooo`;o0000
0_ooool2o`0007Sooooo000Yooooo`03o`000?oooooooooo04_ooooo0_l0000<ooooo`;o00005?oo
ool2o`000003ooooool0003o000003cooooo0_l0000<ooooo`;o00000_ooool2o`0007Sooooo000Y
ooooo`;o0000C?ooool2o`0000cooooo0_l0000Dooooo`;o000000?oooooo`000?l00000b?ooool0
02Wooooo00?o0000ooooooooool0S_ooool2o`00073ooooo0_l0000Fooooo`;o00008_ooool000ko
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool0Aoooool2o`00047ooooo0_l00002ooooo`;o00009?ooool2
o`0004[ooooo0_l0000Fooooo`;o00008_ooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo04Oooooo0_l0000[
ooooo`;o00005?ooool2o`0002Sooooo0_l0000kooooo`;o0000BOooool000kooooo00Go410@oooo
oooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0000Rooooo`;o0000;oooool2
o`0001oooooo0_l0000Kooooo`;o0000<?ooool2o`00013ooooo0_l0000Jooooo`;o0000;Oooool2
o`0001[ooooo000>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo02;ooooo0_l0000_ooooo`;o0000??ooool2o`00033ooooo0_l0000@
ooooo`;o00001?ooool2o`0004?ooooo0_l0000Jooooo`003_ooool01Ol0003ooooooooooooooooo
000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0=_ooooo0_l0
001Oooooo`003_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46
ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3o
ooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08
ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`000?oooooooooo
ooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEE
olc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooo
oolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`007oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooo
ooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
oooo?Oooool0027ooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
7oooool00omEEEGoIVIVo`00003oooooodOooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .33871 Mdot
.02762 .2564 Mdot
.02952 .31216 Mdot
.03143 .26994 Mdot
.03333 .32304 Mdot
.03524 .39194 Mdot
.03714 .31234 Mdot
.03905 .22686 Mdot
.04095 .28517 Mdot
.04286 .34678 Mdot
.04476 .34089 Mdot
.04667 .23819 Mdot
.04857 .27457 Mdot
.05048 .35104 Mdot
.05238 .2656 Mdot
.05429 .27517 Mdot
.05619 .25346 Mdot
.0581 .2805 Mdot
.06 .25294 Mdot
.0619 .42318 Mdot
.06381 .3012 Mdot
.06571 .23745 Mdot
.06762 .25331 Mdot
.06952 .29786 Mdot
.07143 .32177 Mdot
.07333 .36632 Mdot
.07524 .31582 Mdot
.07714 .25366 Mdot
.07905 .42653 Mdot
.08095 .24634 Mdot
.08286 .33534 Mdot
.08476 .29532 Mdot
.08667 .23167 Mdot
.08857 .31171 Mdot
.09048 .35136 Mdot
.09238 .41246 Mdot
.09429 .39849 Mdot
.09619 .26909 Mdot
.0981 .42384 Mdot
.1 .24083 Mdot
.1019 .30856 Mdot
.10381 .33248 Mdot
.10571 .38327 Mdot
.10762 .33721 Mdot
.10952 .36414 Mdot
.11143 .36035 Mdot
.11333 .34833 Mdot
.11524 .34316 Mdot
.11714 .31688 Mdot
.11905 .42429 Mdot
.12095 .34228 Mdot
.12286 .42373 Mdot
.12476 .42432 Mdot
.12667 .37302 Mdot
.12857 .37338 Mdot
.13048 .2522 Mdot
.13238 .22565 Mdot
.13429 .24922 Mdot
.13619 .37307 Mdot
.1381 .37051 Mdot
.14 .36455 Mdot
.1419 .42762 Mdot
.14381 .42163 Mdot
.14571 .33338 Mdot
.14762 .22799 Mdot
.14952 .27627 Mdot
.15143 .34528 Mdot
.15333 .27118 Mdot
.15524 .27236 Mdot
.15714 .32022 Mdot
.15905 .25163 Mdot
.16095 .26973 Mdot
.16286 .34784 Mdot
.16476 .33327 Mdot
.16667 .4216 Mdot
.16857 .28698 Mdot
.17048 .424 Mdot
.17238 .3654 Mdot
.17429 .42618 Mdot
.17619 .31219 Mdot
.1781 .37999 Mdot
.18 .24735 Mdot
.1819 .28015 Mdot
.18381 .33569 Mdot
.18571 .23978 Mdot
.18762 .27344 Mdot
.18952 .32798 Mdot
.19143 .34917 Mdot
.19333 .24452 Mdot
.19524 .27518 Mdot
.19714 .32902 Mdot
.19905 .46917 Mdot
.20095 .33667 Mdot
.20286 .35268 Mdot
.20476 .33736 Mdot
.20667 .47276 Mdot
.20857 .35112 Mdot
.21048 .32775 Mdot
.21238 .4192 Mdot
.21429 .24438 Mdot
.21619 .32136 Mdot
.2181 .25424 Mdot
.22 .24256 Mdot
.2219 .32033 Mdot
.22381 .35786 Mdot
.22571 .32102 Mdot
.22762 .2658 Mdot
.22952 .25186 Mdot
.23143 .33657 Mdot
.23333 .32649 Mdot
.23524 .35039 Mdot
.23714 .27802 Mdot
.23905 .29667 Mdot
.24095 .41408 Mdot
.24286 .31728 Mdot
.24476 .32366 Mdot
.24667 .36698 Mdot
.24857 .27382 Mdot
.25048 .28603 Mdot
.25238 .39363 Mdot
.25429 .27675 Mdot
.25619 .4058 Mdot
.2581 .29122 Mdot
.26 .4275 Mdot
.2619 .32485 Mdot
.26381 .26086 Mdot
.26571 .41858 Mdot
.26762 .47213 Mdot
.26952 .26961 Mdot
.27143 .2807 Mdot
.27333 .24665 Mdot
.27524 .29832 Mdot
.27714 .25839 Mdot
.27905 .3933 Mdot
.28095 .38846 Mdot
.28286 .42863 Mdot
.28476 .41294 Mdot
.28667 .42366 Mdot
.28857 .34732 Mdot
.29048 .22652 Mdot
.29238 .26651 Mdot
.29429 .45345 Mdot
.29619 .31558 Mdot
.2981 .26298 Mdot
.3 .253 Mdot
.3019 .41903 Mdot
.30381 .25134 Mdot
.30571 .26169 Mdot
.30762 .26443 Mdot
.30952 .35398 Mdot
.31143 .38511 Mdot
.31333 .26205 Mdot
.31524 .30388 Mdot
.31714 .29814 Mdot
.31905 .27443 Mdot
.32095 .3813 Mdot
.32286 .41453 Mdot
.32476 .42271 Mdot
.32667 .26794 Mdot
.32857 .39553 Mdot
.33048 .41426 Mdot
.33238 .35216 Mdot
.33429 .42755 Mdot
.33619 .28345 Mdot
.3381 .40362 Mdot
.34 .38342 Mdot
.3419 .3203 Mdot
.34381 .25388 Mdot
.34571 .3673 Mdot
.34762 .27692 Mdot
.34952 .41969 Mdot
.35143 .42095 Mdot
.35333 .32669 Mdot
.35524 .28761 Mdot
.35714 .33337 Mdot
.35905 .26994 Mdot
.36095 .22819 Mdot
.36286 .47262 Mdot
.36476 .38202 Mdot
.36667 .32127 Mdot
.36857 .42609 Mdot
.37048 .42475 Mdot
.37238 .25954 Mdot
.37429 .31178 Mdot
.37619 .31595 Mdot
.3781 .26325 Mdot
.38 .28582 Mdot
.3819 .47113 Mdot
.38381 .30977 Mdot
.38571 .27845 Mdot
.38762 .38636 Mdot
.38952 .38915 Mdot
.39143 .41889 Mdot
.39333 .32322 Mdot
.39524 .42228 Mdot
.39714 .23158 Mdot
.39905 .33568 Mdot
.40095 .24823 Mdot
.40286 .34837 Mdot
.40476 .46748 Mdot
.40667 .28917 Mdot
.40857 .32628 Mdot
.41048 .32628 Mdot
.41238 .26773 Mdot
.41429 .32307 Mdot
.41619 .46294 Mdot
.4181 .30669 Mdot
.42 .29299 Mdot
.4219 .39001 Mdot
.42381 .28656 Mdot
.42571 .26717 Mdot
.42762 .34064 Mdot
.42952 .24717 Mdot
.43143 .36613 Mdot
.43333 .3686 Mdot
.43524 .30444 Mdot
.43714 .31466 Mdot
.43905 .36565 Mdot
.44095 .28927 Mdot
.44286 .26267 Mdot
.44476 .36915 Mdot
.44667 .2316 Mdot
.44857 .3666 Mdot
.45048 .3593 Mdot
.45238 .35916 Mdot
.45429 .39061 Mdot
.45619 .29411 Mdot
.4581 .29678 Mdot
.46 .27396 Mdot
.4619 .33101 Mdot
.46381 .26663 Mdot
.46571 .40915 Mdot
.46762 .26016 Mdot
.46952 .30568 Mdot
.47143 .45742 Mdot
.47333 .27532 Mdot
.47524 .32292 Mdot
.47714 .39953 Mdot
.47905 .27889 Mdot
.48095 .3107 Mdot
.48286 .27885 Mdot
.48476 .3065 Mdot
.48667 .42872 Mdot
.48857 .39152 Mdot
.49048 .3828 Mdot
.49238 .25133 Mdot
.49429 .29993 Mdot
.49619 .33668 Mdot
.4981 .41109 Mdot
.5 .24598 Mdot
.5019 .24966 Mdot
.50381 .42263 Mdot
.50571 .33217 Mdot
.50762 .3241 Mdot
.50952 .32502 Mdot
.51143 .40428 Mdot
.51333 .36141 Mdot
.51524 .29114 Mdot
.51714 .37774 Mdot
.51905 .28211 Mdot
.52095 .22611 Mdot
.52286 .35836 Mdot
.52476 .29725 Mdot
.52667 .3236 Mdot
.52857 .39543 Mdot
.53048 .30141 Mdot
.53238 .26182 Mdot
.53429 .34667 Mdot
.53619 .34555 Mdot
.5381 .38922 Mdot
.54 .41701 Mdot
.5419 .34869 Mdot
.54381 .41487 Mdot
.54571 .3767 Mdot
.54762 .34598 Mdot
.54952 .30587 Mdot
.55143 .41694 Mdot
.55333 .31505 Mdot
.55524 .26814 Mdot
.55714 .33248 Mdot
.55905 .345 Mdot
.56095 .38578 Mdot
.56286 .42697 Mdot
.56476 .28302 Mdot
.56667 .32586 Mdot
.56857 .39392 Mdot
.57048 .23443 Mdot
.57238 .25225 Mdot
.57429 .28945 Mdot
.57619 .30604 Mdot
.5781 .40551 Mdot
.58 .3575 Mdot
.5819 .37259 Mdot
.58381 .47068 Mdot
.58571 .37299 Mdot
.58762 .2473 Mdot
.58952 .36516 Mdot
.59143 .3193 Mdot
.59333 .38856 Mdot
.59524 .41596 Mdot
.59714 .39577 Mdot
.59905 .259 Mdot
.60095 .23847 Mdot
.60286 .31994 Mdot
.60476 .38702 Mdot
.60667 .29649 Mdot
.60857 .29727 Mdot
.61048 .30821 Mdot
.61238 .34782 Mdot
.61429 .33096 Mdot
.61619 .35929 Mdot
.6181 .32095 Mdot
.62 .24875 Mdot
.6219 .25823 Mdot
.62381 .27334 Mdot
.62571 .37774 Mdot
.62762 .31796 Mdot
.62952 .36177 Mdot
.63143 .3242 Mdot
.63333 .22727 Mdot
.63524 .30204 Mdot
.63714 .26597 Mdot
.63905 .38428 Mdot
.64095 .45962 Mdot
.64286 .25843 Mdot
.64476 .39428 Mdot
.64667 .33606 Mdot
.64857 .41935 Mdot
.65048 .29507 Mdot
.65238 .32501 Mdot
.65429 .31836 Mdot
.65619 .25976 Mdot
.6581 .2265 Mdot
.66 .40307 Mdot
.6619 .33781 Mdot
.66381 .24064 Mdot
.66571 .27808 Mdot
.66762 .2676 Mdot
.66952 .2695 Mdot
.67143 .39248 Mdot
.67333 .38364 Mdot
.67524 .35143 Mdot
.67714 .31825 Mdot
.67905 .43827 Mdot
.68095 .35596 Mdot
.68286 .25239 Mdot
.68476 .33417 Mdot
.68667 .23782 Mdot
.68857 .32054 Mdot
.69048 .4224 Mdot
.69238 .23776 Mdot
.69429 .32971 Mdot
.69619 .36285 Mdot
.6981 .45256 Mdot
.7 .2341 Mdot
.7019 .39355 Mdot
.70381 .41456 Mdot
.70571 .33205 Mdot
.70762 .28971 Mdot
.70952 .42024 Mdot
.71143 .26871 Mdot
.71333 .23443 Mdot
.71524 .46134 Mdot
.71714 .38569 Mdot
.71905 .25758 Mdot
.72095 .27119 Mdot
.72286 .30614 Mdot
.72476 .27129 Mdot
.72667 .28755 Mdot
.72857 .27012 Mdot
.73048 .22597 Mdot
.73238 .27404 Mdot
.73429 .35903 Mdot
.73619 .35131 Mdot
.7381 .3913 Mdot
.74 .32669 Mdot
.7419 .31735 Mdot
.74381 .31102 Mdot
.74571 .39219 Mdot
.74762 .41038 Mdot
.74952 .24988 Mdot
.75143 .40153 Mdot
.75333 .24506 Mdot
.75524 .30402 Mdot
.75714 .29865 Mdot
.75905 .38446 Mdot
.76095 .38162 Mdot
.76286 .27618 Mdot
.76476 .3624 Mdot
.76667 .24567 Mdot
.76857 .31897 Mdot
.77048 .26119 Mdot
.77238 .32329 Mdot
.77429 .32379 Mdot
.77619 .33849 Mdot
.7781 .36778 Mdot
.78 .31542 Mdot
.7819 .33809 Mdot
.78381 .35897 Mdot
.78571 .42116 Mdot
.78762 .2632 Mdot
.78952 .28212 Mdot
.79143 .43964 Mdot
.79333 .28829 Mdot
.79524 .26562 Mdot
.79714 .27379 Mdot
.79905 .27932 Mdot
.80095 .22627 Mdot
.80286 .23705 Mdot
.80476 .31824 Mdot
.80667 .32741 Mdot
.80857 .33142 Mdot
.81048 .28907 Mdot
.81238 .36192 Mdot
.81429 .34801 Mdot
.81619 .40192 Mdot
.8181 .30386 Mdot
.82 .29891 Mdot
.8219 .29462 Mdot
.82381 .33976 Mdot
.82571 .3027 Mdot
.82762 .31761 Mdot
.82952 .29926 Mdot
.83143 .39617 Mdot
.83333 .22655 Mdot
.83524 .28582 Mdot
.83714 .35668 Mdot
.83905 .26627 Mdot
.84095 .37018 Mdot
.84286 .3459 Mdot
.84476 .28496 Mdot
.84667 .36177 Mdot
.84857 .47382 Mdot
.85048 .29641 Mdot
.85238 .35227 Mdot
.85429 .33172 Mdot
.85619 .30709 Mdot
.8581 .26545 Mdot
.86 .27724 Mdot
.8619 .33587 Mdot
.86381 .23753 Mdot
.86571 .43441 Mdot
.86762 .3234 Mdot
.86952 .31743 Mdot
.87143 .2812 Mdot
.87333 .3931 Mdot
.87524 .32636 Mdot
.87714 .46848 Mdot
.87905 .26488 Mdot
.88095 .36422 Mdot
.88286 .32568 Mdot
.88476 .33708 Mdot
.88667 .3169 Mdot
.88857 .32564 Mdot
.89048 .22649 Mdot
.89238 .31362 Mdot
.89429 .42756 Mdot
.89619 .27143 Mdot
.8981 .36111 Mdot
.9 .41661 Mdot
.9019 .36356 Mdot
.90381 .26806 Mdot
.90571 .47349 Mdot
.90762 .34052 Mdot
.90952 .22705 Mdot
.91143 .32889 Mdot
.91333 .34432 Mdot
.91524 .39059 Mdot
.91714 .347 Mdot
.91905 .2502 Mdot
.92095 .42199 Mdot
.92286 .32287 Mdot
.92476 .25157 Mdot
.92667 .36315 Mdot
.92857 .30741 Mdot
.93048 .42328 Mdot
.93238 .38771 Mdot
.93429 .29286 Mdot
.93619 .38085 Mdot
.9381 .31213 Mdot
.94 .2687 Mdot
.9419 .26198 Mdot
.94381 .3708 Mdot
.94571 .38751 Mdot
.94762 .32621 Mdot
.94952 .36317 Mdot
.95143 .27388 Mdot
.95333 .31675 Mdot
.95524 .35307 Mdot
.95714 .27382 Mdot
.95905 .25272 Mdot
.96095 .28749 Mdot
.96286 .33096 Mdot
.96476 .29368 Mdot
.96667 .26265 Mdot
.96857 .35011 Mdot
.97048 .40474 Mdot
.97238 .26684 Mdot
.97429 .42502 Mdot
.97619 .25096 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool01?l0003ooooooooo
ooooool2o`0001cooooo0_l0000aooooo`;o0000B?ooool2o`0002;ooooo0_l00006ooooo`;o0000
5Oooool2o`0001Gooooo0_l00009ooooo`;o00004?ooool2o`0000Cooooo0_l0000Qooooo`001?l0
0002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`00
0?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l0000Looooo`;o00000oooool2o`0002co
oooo0_l0000Eooooo`;o0000<Oooool2o`0002;ooooo0_l00006ooooo`;o00005Oooool2o`0001Go
oooo0_l00009ooooo`;o00004?ooool2o`0000Cooooo0_l0000Qooooo`001_ooool01Ol0003ooooo
oooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o
00004?ooool2o`0001;ooooo0_l00013ooooo`;o00002Oooool2o`0000kooooo0_l0001@ooooo`;o
0000I?ooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo013ooooo0_l0001Roooo
o`;o00003_ooool2o`0002Kooooo0_l0000Xooooo`;o00000_ooool2o`0001_ooooo0_l00013oooo
o`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo0_l00004ooooo`;o00009?ooool2o`00
07[ooooo0_l00008ooooo`;o00006Oooool4o`0000Gooooo0_l0000Kooooo`;o00004Oooool2o`00
033ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`;o00001?ooool2
o`0000Wooooo0_l0000Iooooo`;o00002Oooool2o`0007Wooooo0_l0000Booooo`;o00001Oooool4
o`0003Gooooo0_l0000`ooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`0?ooooo`;o00001?oo
ool2o`0001cooooo0_l00005ooooo`?o0000F?ooool2o`0003?ooooo0_l0000Kooooo`;o00000_oo
ool2o`0004oooooo000Yooooo`;o00004?ooool2o`0000oooooo0_l0000<ooooo`;o00000oooool2
o`0000Gooooo0_l0000Aooooo`;o00009oooool2o`0000Oooooo0_l0000Dooooo`?o00006_ooool2
o`0000Sooooo0_l0000Yooooo`;o00000_ooool2o`0004oooooo000Yooooo`03o`000?oooooooooo
01oooooo0ol00006ooooo`;o00001?ooool2o`0000kooooo0_l0000=ooooo`;o00001oooool2o`00
01kooooo0_l00007ooooo`;o00004_ooool2o`000003ooooool0003o000001Gooooo0_l00003oooo
o`;o00002?ooool2o`0001;ooooo0_l0000Dooooo`;o0000=?ooool4o`0000Wooooo0_l00004oooo
o`;o00002oooool002Wooooo00?o0000ooooooooool01oooool5o`000003ooooool0003o0000013o
oooo0_l00007ooooo`;o00004Oooool2o`000003ooooool0003o000001Gooooo0ol0000;ooooo`;o
0000;_ooool2o`0001Sooooo0_l0000Qooooo`;o00005?ooool2o`0003Cooooo1?l00009ooooo`;o
00001?ooool2o`0000_ooooo000Yooooo`;o00002?ooool5o`000003ooooool0003o000002cooooo
0_l0000Aooooo`;o00001Oooool2o`0000cooooo0_l0001@ooooo`;o00001_ooool2o`0000Cooooo
0_l0000Gooooo`;o0000G_ooool002Wooooo0_l0001:ooooo`;o00000oooool2o`0000Oooooo1?l0
000Aooooo`;o00007Oooool2o`0001?ooooo0_l0000Cooooo`;o00001_ooool2o`0000Cooooo0_l0
0003ooooo`;o00004_ooool2o`0000kooooo0_l0000eooooo`;o00005oooool002Wooooo0_l0001:
ooooo`;o00002Oooool2o`000003ooooool0003o000000;o00004Oooool4o`0001?ooooo0_l00006
ooooo`;o00004oooool2o`0002Kooooo0_l0000Rooooo`;o00001?ooool2o`0001_ooooo0_l0000B
ooooo`;o00001_ooool2o`0000oooooo000Yooooo`03o`000?oooooooooo00Gooooo0_l0000goooo
o`;o00004oooool3o`0000;ooooo0_l00004ooooo`;o00003_ooool2o`0000Wooooo0_l00002oooo
o`;o00001?ooool2o`0000Gooooo0_l0000Kooooo`;o00006?ooool2o`0000Sooooo0_l0000Uoooo
o`Co00003?ooool2o`0000Gooooo0_l00004ooooo`;o00001_ooool2o`0001;ooooo1?l0000=oooo
o`00:Oooool01?l0003oooooo`000?l00004ooooo`;o00003Oooool2o`00013ooooo1?l00006oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP;ooooo0_l000001?lb<S;o0000
oc8b<_o^k^h7ooooo`;o00001_ooool2o`0000Wooooo0_l00008ooooo`;o00000oooool5o`0000?o
oooo00Cok^k^oc8b<_l0003o<S8b0_l00002ooooo`?o000000?o<S8bonk^k_ooool01oooool2o`00
01_ooooo0_l000001_ooooooV9RHoa0@4?l0003o<S8bolc<c0?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool2o`0000Sooooo0ol0000;ooooo`;o
000000?oooooo`000?l000000ol00008ooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o
0000oc8b<_o^k^h00_l000001_ooooook^k^oc8b<_l0003o<S8bonk^kPKooooo0_l00005ooooo`;o
00002_ooool4o`0000[ooooo0_l000001Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^o`00
0?l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool002Wooooo00Co0000
ooooool0003o00000oooool2o`0000kooooo0_l0000@ooooo`Co00001oooool2o`0000Cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`03ooooo`06ogMgMonHV9SooooooiRHV?mgMgOooooo0_l00004oooo
o`;o00003_ooool2o`0000_ooooo0_l00003ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`;o0000
7oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`03ogMgMonHV9Sooooo00;o00003Oooool2o`0000_ooooo0_l000000ooooooo0000o`000004o`00
00Sooooo00?o0000ooooooooool00_ooool01_mgMgOoV9RHoooooonHV9SoMgMgooooo`;o000000Go
MgMgoiRHV?ooooooV9RHogMgM`0Iooooo`;o00003?ooool2o`0000;ooooo0ol00002ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000Yooooo`03
o`000?oooooooooo00Cooooo1?l0000Mooooo`Co00002?ooool4o`0000;ooooo00Go410@oooooooo
oooooooooa0@4003ooooo`06oa0@4?ooooooooooooooool@413ooooo0ol0000Cooooo`;o00001ooo
ool2o`0000Sooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooooooooa0@4007ooooo`;o00000_ooool2o`0001oooooo00Go0000oooooooo
oooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000_ooool2o`00027ooooo0_l00005
ooooo`Go00000oooool01_l@413ooooooooooooooooo410@ooooo`;o000000Go410@oooooooooooo
oooooa0@400=ooooo`;o00007?ooool3o`0000;ooooo00Go410@oooooooooooooooooa0@4003oooo
o`05oa0@4?ooooooooooooooool@41000oooool002Wooooo0_l00007ooooo`?o00007?ooool2o`00
00Sooooo0_l000001?oooooo0000o`000?l00002ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooo`000002o`0000;ooooo0_l00004ooooo`;o00005_ooool2o`0000Wooooo00Co
V9RHob4Q8Ol0003o00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`Go00006oooool00onYZJWo410@ooooo`02ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000cooooo0_l0000Jooooo`03odA4A?oM
gMgooooo00;o00000oooool01Ol0003ooooooooooooooooo000000;ooooo0_l00003ooooo`03o`00
0?oooooooooo00_ooooo0_l0000Mooooo`05ogMgMolb<S;oooooooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool00Oooool002Wooooo00?o0000oooooooo
ool01oooool2o`0002Kooooo0_l000000ooooooo0000ooooo`03ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooo`000002o`0000Sooooo0_l0000Cooooo`;o00003Oooool00omg
MgOo0000o`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000gooooo0ol0000:ooooo`;o00003?ooool2o`000003oa0@4?l0003o^[Zj00?ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000003?ooool2o`0001[o
oooo00CogMgMoeEEEOoooooo00001?ooool00ol0003oooooooooo`02o`0000;ooooo0_l00003oooo
o`03o`000?oooooooooo00oooooo0_l0000Fooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`00:Ooo
ool00ol0003oooooooooo`02ooooo`;o00009oooool2o`0000Gooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Ko410@oooooooooooooooooa0@4?ooool2o`00
01[ooooo0_l0000<ooooo`?o00000oooool01Ol@413ooooooooooooooooo410@00?ooooo0_l00002
ooooo`03oa0@4?oooooooooo01Sooooo0_l0000<ooooo`;o000000?ooooookZj^_lQ8B400oooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@400Yooooo`03ogMg
Moo<c<co000000Cooooo00?o410@ooooooooool00_l00003ooooo`05oa0@4?ooooooooooooooool@
41001Oooool2o`000003ooooool0003o000000Oooooo0_l0000Fooooo`03o`000?oooooooooo00Co
oooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool0
02Wooooo00?o0000ooooooooool00_ooool2o`0002Oooooo0_l00005ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`06ogMgMonHV9SooooooiRHV?mgMgOooooo
0_l0000Pooooo`;o00001?ooool01Ol0003o^[Zjo`000?l0003o410@00?ooooo00GoMgMgoiRHV?l0
003o0000ogMgM`03ooooo`;o000000?ooooooiRHV?mgMgL00_l0000Vooooo`03oa0@4?nHV9Sooooo
00;o00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Iooooo`;o00001?ooool2o`0000Sooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00;o000000?oooooogMgMonHV9P00_l000000omgMgOoooooooooo`03ooooo`;o0000
00?oooooo`000?l000007oooool00ol0003oooooooooo`02ooooo`;o000000GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wooooo00?o0000oooooooo
ool0<?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Cooooo0_l0000Mooooo`;o00001?ooool01OnHV9So410@o`000?lQ
8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o0000onk^kP02ooooo`;o000000Co<S8bo`000?lb<S;o
k^k^0_l0000Fooooo`;o00003_ooool00onYZJWo410@o`000002o`0000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06Oooool2o`0000Cooooo0_l00009
ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02o`000003ooooooo^
k^ko<S8b00;o000000?ok^k^ooooooooool08oooool2o`0000;ooooo1?l000002?oooooo0000o`00
0?o^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Yoooo
o`;o00004Oooool2o`0003Kooooo0_l0000booooo`;o00002Oooool2o`00017ooooo0_l0000Zoooo
o`;o0000=Oooool2o`0002;ooooo0_l00008ooooo`;o00003oooool002Wooooo00?o0000oooooooo
ool02oooool2o`0000?ooooo0_l0000_ooooo`;o00002_ooool2o`0000cooooo0_l0000Zooooo`?o
00004oooool2o`0001Wooooo0_l0000<ooooo`;o00008?ooool2o`0001;ooooo1Ol00005ooooo`;o
00008oooool2o`0000oooooo000Yooooo`03o`000?oooooooooo00Wooooo1?l0000dooooo`;o0000
2_ooool2o`0000cooooo0_l0000[ooooo`;o00002_ooool2o`0000Oooooo1?l0000Gooooo`;o0000
1oooool2o`0002Gooooo0_l0000Booooo`;o000000?oooooo`000?l000001Oooool2o`0003Cooooo
000Yooooo`03o`000?oooooooooo00Wooooo0_l0001?ooooo`;o00009Oooool2o`0000Wooooo0_l0
0006ooooo`;o00002Oooool2o`00023ooooo0_l0000Tooooo`;o00004oooool4o`0003cooooo000Y
ooooo`03o`000?oooooooooo01Gooooo0_l00013ooooo`;o00007oooool2o`0000Cooooo0_l00009
ooooo`;o00000_ooool2o`0001?ooooo0_l00007ooooo`;o00002Oooool2o`0002;ooooo0_l00008
ooooo`;o00004oooool4o`0000Sooooo0_l0000Eooooo`;o00006oooool0027oooooool00014o`00
00Cooooo000Yooooo`?o000000?oooooo`000?l000001_ooool00ol0003oooooooooo`05ooooo`;o
00000oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo0_l0000;ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00Go0000ooooool0003o0000ooooo`02o`0000Kooooo00?o0000oooo
ooooool01_ooool2o`000003ooooool0003ooooo00Wooooo0_l0000;ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`?o00002oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool2o`00
0003ooooool0003ooooo00Wooooo0_l0000;ooooo`03o`000?oooooooooo00[ooooo000Yooooo`?o
000000?oooooo`000?l000002_ooool2o`0000_ooooo0_l0000Aooooo`;o00002oooool00ol0003o
ooooooooo`06ooooo`;o00003oooool2o`0001Sooooo0_l00008ooooo`03o`000?oooooooooo00Ko
oooo0_l0000Tooooo`;o00003?ooool00ol0003oooooooooo`06ooooo`;o00008oooool2o`0000[o
oooo0_l000000ooooooo0000ooooo`0;ooooo`;o00002oooool2o`0000Cooooo1?l0000<ooooo`;o
00000oooool2o`0000Kooooo00?o0000ooooooooool02_ooool002Wooooo00?o0000ooooooooool0
3Oooool2o`0000_ooooo0_l0000;ooooo`;o00004oooool3o`0000Cooooo0_l0000?ooooo`;o0000
3Oooool2o`0000Wooooo0_l0000gooooo`;o00002_ooool2o`000003ooooool0003o000000?ooooo
0_l000000ooooooo0000o`000007ooooo`;o00001Oooool2o`0000;ooooo0_l0000?ooooo`;o0000
1oooool2o`000003ooooool0003o000000Kooooo0_l00006ooooo`;o00002oooool2o`0000Cooooo
0_l0000Cooooo`;o00004oooool002Wooooo00Co0000ooooool0003o00002oooool2o`0001Wooooo
0_l0000Aooooo`Go00001?ooool2o`0001kooooo0_l00006ooooo`;o00001_ooool2o`0000Gooooo
0_l0000Aooooo`;o00002Oooool2o`0000Cooooo0_l0000Cooooo`;o000000?oooooo`000?l00000
0oooool2o`0000?ooooo0_l00005ooooo`;o00001Oooool2o`0000;ooooo0_l0000Hooooo`Co0000
1oooool2o`0001?ooooo0_l0000?ooooo`;o00007Oooool002Wooooo1?l0000;ooooo`;o0000;?oo
ool2o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`;o00006oooool2o`0000?ooooo0_l0
0006ooooo`;o00000oooool4o`00017ooooo0_l00009ooooo`;o00001?ooool2o`0000_ooooo0_l0
000Cooooo`;o00001?ooool2o`0001_ooooo0_l00008ooooo`?o00002?ooool2o`0001;ooooo2?l0
0009ooooo`;o00001_ooool2o`0001Gooooo000Yooooo`03o`000?oooooooooo03;ooooo1?l00002
ooooo`;o00001_ooool2o`0000Oooooo0_l0000Kooooo`;o00004?ooool3o`0001gooooo0_l0000A
ooooo`;o00006Oooool2o`0000cooooo0_l0000=ooooo`;o00004oooool2o`0001Cooooo1_l00006
ooooo`;o00002Oooool2o`0001Gooooo000Yooooo`03o`000?oooooooooo01Kooooo0_l0000;oooo
o`;o00001Oooool2o`0000Kooooo1?l00002ooooo`;o0000;Oooool2o`00023ooooo0_l0000<oooo
o`;o00003oooool2o`00013ooooo0_l0000Hooooo`;o00000_ooool2o`0001oooooo0_l0000<oooo
o`;o00004Oooool2o`0000kooooo0_l0000@ooooo`00:Oooool00ol0003oooooooooo`0?ooooo`;o
00001Oooool2o`0000_ooooo0_l00005ooooo`;o00001?ooool2o`0000?ooooo0_l00008ooooo`;o
00009_ooool2o`0000cooooo0_l0000Booooo`;o00002Oooool2o`000003ooooool0003o000000oo
oooo0_l0000@ooooo`;o00002Oooool2o`0000[ooooo0_l00005ooooo`;o00007oooool2o`0000co
oooo0_l000000ooooooo0000o`00000Nooooo`;o00004?ooool002Wooooo0_l0000@ooooo`;o0000
1_ooool2o`0001Oooooo0_l00003ooooo`?o00001oooool2o`0003Cooooo0_l0000Mooooo`;o0000
;oooool2o`0000;ooooo0_l00006ooooo`;o00006oooool4o`0000cooooo0_l0000:ooooo`;o0000
1Oooool2o`0002Wooooo000Yooooo`;o00001?ooool2o`0001;ooooo0_l00003ooooo`;o00006?oo
ool2o`0004Kooooo0_l00019ooooo`;o00008oooool4o`0000cooooo0_l0000Aooooo`;o00001Ooo
ool2o`0002;ooooo000Yooooo`03o`000?oooooooooo00?ooooo0_l0000Eooooo`Co00001oooool2
o`0005Oooooo0_l0000Qooooo`;o00000_ooool2o`000003ooooool0003o000005[ooooo0_l0000B
ooooo`Co00008?ooool002Wooooo00?o0000ooooooooool00_ooool2o`0001Gooooo0ol00009oooo
o`;o00000_ooool2o`0000Oooooo0_l0000Mooooo`;o00008oooool2o`0002Sooooo1ol000000ooo
oooo0000o`00000@ooooo`;o0000?_ooool2o`0000Sooooo0_l0000Dooooo`Co00007_ooool002Wo
oooo00?o0000ooooooooool00_ooool2o`000003ooooool0003o000000_ooooo0_l00005ooooo`;o
00003_ooool2o`0000Oooooo0_l00004ooooo`;o00001_ooool2o`0000oooooo0_l0000<ooooo`;o
00005Oooool2o`0002Sooooo0_l000000ooooooo0000o`00000Eooooo`;o00004_ooool2o`00017o
oooo0_l0000Gooooo`;o00002oooool2o`0001?ooooo0_l0000>ooooo`;o00003_ooool002Wooooo
00?o0000ooooooooool01Oooool2o`0000_ooooo0_l0000Rooooo`Co00001_ooool2o`0001Kooooo
0_l00005ooooo`;o0000KOooool2o`00017ooooo0_l0000Tooooo`;o00007oooool2o`0000;ooooo
0_l0000>ooooo`00:Oooool2o`0003Oooooo0_l00005ooooo`;o00006Oooool2o`0004?ooooo0_l0
000@ooooo`;o00007oooool2o`00033ooooo0_l0000Tooooo`;o00004_ooool002Wooooo00?o0000
ooooooooool06?ooool2o`0002?ooooo0_l00016ooooo`?o00004_ooool2o`000003ooooool0003o
0000013ooooo0_l0000:ooooo`;o00004oooool2o`0000oooooo0_l0000>ooooo`;o00003oooool2
o`00017ooooo0_l0000Uooooo`00:Oooool00ol0003oooooooooo`0Hooooo`;o00002?ooool2o`00
067ooooo0ol0000Booooo`;o00007oooool2o`0000;ooooo0_l0000Cooooo`;o00002oooool2o`00
00Sooooo0_l00004ooooo`;o00001oooool2o`0000Wooooo0_l00009ooooo`;o00000oooool4o`00
00Kooooo0_l00005ooooo`;o00005?ooool002Wooooo00?o0000ooooooooool03?ooool2o`0000[o
oooo0_l00008ooooo`;o00002?ooool2o`0001Kooooo0_l0000Nooooo`;o00006Oooool2o`000004
ooooool0003o0000ooooo`;o0000:oooool2o`0000_ooooo0_l0000Cooooo`;o00005Oooool2o`00
00;ooooo0_l00009ooooo`;o00002Oooool2o`0000Wooooo0_l00005ooooo`;o00001_ooool2o`00
00Gooooo0_l0000Dooooo`00:Oooool00ol0003oooooooooo`0<ooooo`;o00004oooool2o`0000Wo
oooo0_l0000Fooooo`;o00007_ooool2o`0001Wooooo2?l0000[ooooo`;o0000>oooool2o`0001;o
oooo0_l0000Oooooo`;o00005_ooool002Wooooo0_l0000Nooooo`Ko0000GOooool2o`0000;ooooo
0_l0000Zooooo`?o0000D?ooool2o`0001oooooo0_l0000Fooooo`00:Oooool00ol0003ooooooooo
o`0Mooooo`Go0000P_ooool2o`0000[ooooo0ol00029ooooo`001_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo
00?o0000ooooooooool0;_ooool2o`0006_ooooo0_l00007ooooo`;o00006?ooool2o`0007cooooo
0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool05oooool2o`0001Go
oooo0_l0000/ooooo`;o00001?ooool2o`0000Kooooo0_l0000Vooooo`;o00001oooool2o`00027o
oooo0_l0000Yooooo`;o0000=oooool2o`0001Sooooo0006ooooo`05oa0@4?ooooooooooooooool@
41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool05oooool2o`00043ooooo0_l000000ooooooo0000o`000004ooooo`;o00001_ooool2o`0000Go
oooo0_l0000Oooooo`;o00005Oooool2o`0001Oooooo0_l00009ooooo`;o00003?ooool2o`0000co
oooo0_l0000gooooo`;o00006?ooool000Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03
oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0004oooooo0_l00008ooooo`;o
00005_ooool3o`0002kooooo0_l00005ooooo`;o00002?ooool2o`0000;ooooo0_l00009ooooo`;o
00002Oooool2o`0000cooooo0_l0000<ooooo`;o0000=Oooool2o`0000?ooooo0_l0000Eooooo`00
1_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool00_l0001=ooooo`;o00008Oooool2o`00
00Sooooo0_l00009ooooo`;o00002Oooool2o`0000kooooo0_l0000?ooooo`;o00000_ooool2o`00
01Cooooo0_l0000Cooooo`Co0000=Oooool2o`0000?ooooo0_l00003ooooo`;o00005Oooool000Ko
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`02o`0004Cooooo0_l00006ooooo`;o00003_ooool2o`00
01cooooo0_l00009ooooo`;o00002Oooool2o`0000_ooooo0_l0000:ooooo`;o00002?ooool2o`00
00gooooo0_l00007ooooo`;o00001oooool2o`0000[ooooo1?l0000Wooooo`;o00003?ooool2o`00
01oooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`;o0000<Oooool2
o`0000Kooooo0_l0000>ooooo`;o0000?oooool2o`0000[ooooo0_l00008ooooo`;o00003Oooool2
o`00013ooooo0_l0000Xooooo`;o00002oooool2o`0002gooooo0006ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oo
oooooooo01?ooooo0_l0001iooooo`;o0000E_ooool2o`0001?ooooo0_l00003ooooo`;o0000>_oo
ool002Wooooo0_l0001Rooooo`;o0000:oooool2o`0000Wooooo0_l0000^ooooo`;o00006oooool2
o`0001?ooooo0_l0000`ooooo`;o00003Oooool002Wooooo00?o0000ooooooooool0Aoooool2o`00
01Sooooo0_l0000fooooo`;o00004oooool2o`0001Wooooo0_l0001Rooooo`;o00003Oooool002Wo
oooo00?o0000ooooooooool0Aoooool2o`00047ooooo0_l00009ooooo`;o00005oooool2o`0003Go
oooo0_l0001Eooooo`00:Oooool00ol0003oooooooooo`0Booooo`;o0000;_ooool2o`0000cooooo
0_l0000:ooooo`;o000000?oooooo`000?l00000:Oooool2o`0000Wooooo0_l00010ooooo`;o0000
3?ooool2o`0005Gooooo000Yooooo`03o`000?oooooooooo01;ooooo0_l0000^ooooo`;o00003?oo
ool2o`0000[ooooo0_l000000ooooooo0000o`000011ooooo`?o000000?oooooo`000?l000003?oo
ool2o`00027ooooo0_l0000mooooo`;o00009?ooool002Wooooo0_l0000jooooo`;o00003oooool2
o`0000[ooooo0_l0000=ooooo`;o00002oooool2o`0002kooooo0ol000000ooooooo0000o`00000<
ooooo`;o00003oooool2o`0001;ooooo0_l0000kooooo`;o00009?ooool002Wooooo00?o0000oooo
ooooool02Oooool2o`0000Wooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l0000=oooo
o`;o00003oooool2o`0000Gooooo0_l00003ooooo`;o00001Oooool2o`0000Kooooo0ol0000:oooo
o`Co00008Oooool2o`0002cooooo0_l0000<ooooo`;o00001?ooool2o`0001Kooooo0_l0000Zoooo
o`;o000000?oooooo`000?l000006_ooool002Wooooo00?o0000ooooooooool02Oooool2o`0000?o
oooo0_l00004ooooo`;o00001Oooool4o`0000Cooooo0_l00005ooooo`Go00008_ooool2o`0000[o
oooo0_l00007ooooo`;o00000oooool3o`0000Kooooo0_l0000Qooooo`;o00004Oooool2o`0002Oo
oooo0_l0000Looooo`;o0000:_ooool2o`000003ooooool0003o000000cooooo0_l0000<ooooo`00
:Oooool00ol0003oooooooooo`0>ooooo`;o00002oooool4o`0000?ooooo0_l00007ooooo`Co0000
6Oooool2o`0000Kooooo0_l0000>ooooo`;o00002Oooool3o`0002?ooooo0_l0000Gooooo`;o0000
J?ooool2o`0001Sooooo0_l0000<ooooo`00:Oooool00ol0003oooooooooo`0Rooooo`;o00009?oo
ool2o`0000Kooooo0_l0000>ooooo`;o0000;oooool2o`00087ooooo0_l0000Vooooo`00:Oooool2
o`000?oooooo3Oooool2o`0002oooooo000Yooooo`03o`000?oooooooooo0<oooooo0_l0000joooo
o`;o0000;oooool002Wooooo00?o0000ooooooooool0coooool2o`0002;ooooo0_l00017ooooo`00
:Oooool00ol0003oooooooooo`3cooooo`;o0000Aoooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0Doooool2o`00
083ooooo0_l0001Uooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`1Cooooo`;o0000=oooool2
o`0004Oooooo0_l0001Uooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0S?ooool2o`0003Gooooo0_l0001g
ooooo`003_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3
o`0007[ooooo0_l00017ooooo`;o00005_ooool2o`0005oooooo000>ooooo`05o`000?oooooooooo
ooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo07[ooooo0_l0001O
ooooo`;o0000Goooool000kooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0eooooo`;o0000@?ooool2o`0009Kooooo0_l0
000[ooooo`003_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0eooooo`Co00004_ooool2o`0001cooooo0_l00004ooooo`;o00001_oo
ool2o`0003Oooooo0_l0001Mooooo`;o00001oooool2o`0002;ooooo000>ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Oooooo0_l0
000Booooo`;o00007?ooool2o`0000Cooooo0_l0000oooooo`;o0000Doooool2o`00017ooooo0_l0
000Rooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000oooo
ool7ooooo`;o0000=Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?oooooooooo
ooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003o
ooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0
003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooo
oooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oo
oooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo
?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo
0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`007oooool4o`00
0003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool0
1Oooool3o`000?oooooo?Oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`007oooool00omEEEGoIVIVo`00003oooooodOooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .39127 Mdot
.02762 .34777 Mdot
.02952 .28614 Mdot
.03143 .32479 Mdot
.03333 .25531 Mdot
.03524 .37515 Mdot
.03714 .31495 Mdot
.03905 .32116 Mdot
.04095 .38361 Mdot
.04286 .30736 Mdot
.04476 .34861 Mdot
.04667 .267 Mdot
.04857 .24316 Mdot
.05048 .33445 Mdot
.05238 .23987 Mdot
.05429 .26672 Mdot
.05619 .27498 Mdot
.0581 .24012 Mdot
.06 .31268 Mdot
.0619 .37978 Mdot
.06381 .23526 Mdot
.06571 .29526 Mdot
.06762 .26298 Mdot
.06952 .23508 Mdot
.07143 .22673 Mdot
.07333 .36374 Mdot
.07524 .35087 Mdot
.07714 .31318 Mdot
.07905 .39524 Mdot
.08095 .33531 Mdot
.08286 .24397 Mdot
.08476 .3905 Mdot
.08667 .33269 Mdot
.08857 .2447 Mdot
.09048 .27183 Mdot
.09238 .36134 Mdot
.09429 .43137 Mdot
.09619 .333 Mdot
.0981 .41113 Mdot
.1 .26223 Mdot
.1019 .22469 Mdot
.10381 .25279 Mdot
.10571 .33591 Mdot
.10762 .39254 Mdot
.10952 .39836 Mdot
.11143 .30999 Mdot
.11333 .33458 Mdot
.11524 .41604 Mdot
.11714 .36814 Mdot
.11905 .3968 Mdot
.12095 .41515 Mdot
.12286 .4222 Mdot
.12476 .47593 Mdot
.12667 .31218 Mdot
.12857 .30998 Mdot
.13048 .3594 Mdot
.13238 .31026 Mdot
.13429 .28258 Mdot
.13619 .42735 Mdot
.1381 .39855 Mdot
.14 .32434 Mdot
.1419 .34327 Mdot
.14381 .41392 Mdot
.14571 .29176 Mdot
.14762 .31659 Mdot
.14952 .3789 Mdot
.15143 .30355 Mdot
.15333 .27104 Mdot
.15524 .3361 Mdot
.15714 .23622 Mdot
.15905 .27599 Mdot
.16095 .30851 Mdot
.16286 .316 Mdot
.16476 .27591 Mdot
.16667 .41388 Mdot
.16857 .31405 Mdot
.17048 .47581 Mdot
.17238 .3515 Mdot
.17429 .41684 Mdot
.17619 .36371 Mdot
.1781 .29657 Mdot
.18 .33631 Mdot
.1819 .33085 Mdot
.18381 .25496 Mdot
.18571 .34754 Mdot
.18762 .26736 Mdot
.18952 .2586 Mdot
.19143 .28789 Mdot
.19333 .30588 Mdot
.19524 .26748 Mdot
.19714 .22889 Mdot
.19905 .46618 Mdot
.20095 .32582 Mdot
.20286 .29266 Mdot
.20476 .31811 Mdot
.20667 .45898 Mdot
.20857 .33188 Mdot
.21048 .40691 Mdot
.21238 .47464 Mdot
.21429 .30955 Mdot
.21619 .38465 Mdot
.2181 .33157 Mdot
.22 .26119 Mdot
.2219 .38568 Mdot
.22381 .26269 Mdot
.22571 .24714 Mdot
.22762 .25899 Mdot
.22952 .29507 Mdot
.23143 .32642 Mdot
.23333 .2385 Mdot
.23524 .32077 Mdot
.23714 .33073 Mdot
.23905 .39105 Mdot
.24095 .35935 Mdot
.24286 .42414 Mdot
.24476 .32148 Mdot
.24667 .33901 Mdot
.24857 .37848 Mdot
.25048 .38602 Mdot
.25238 .42849 Mdot
.25429 .24217 Mdot
.25619 .30624 Mdot
.2581 .23798 Mdot
.26 .39671 Mdot
.2619 .23774 Mdot
.26381 .31298 Mdot
.26571 .37221 Mdot
.26762 .44668 Mdot
.26952 .35662 Mdot
.27143 .32405 Mdot
.27333 .27163 Mdot
.27524 .37404 Mdot
.27714 .2442 Mdot
.27905 .37686 Mdot
.28095 .35218 Mdot
.28286 .40932 Mdot
.28476 .43358 Mdot
.28667 .38705 Mdot
.28857 .31411 Mdot
.29048 .30725 Mdot
.29238 .23901 Mdot
.29429 .39599 Mdot
.29619 .34022 Mdot
.2981 .32885 Mdot
.3 .27562 Mdot
.3019 .36946 Mdot
.30381 .36044 Mdot
.30571 .38721 Mdot
.30762 .27081 Mdot
.30952 .29777 Mdot
.31143 .27378 Mdot
.31333 .34003 Mdot
.31524 .3504 Mdot
.31714 .23486 Mdot
.31905 .31457 Mdot
.32095 .39066 Mdot
.32286 .43045 Mdot
.32476 .41677 Mdot
.32667 .37369 Mdot
.32857 .43031 Mdot
.33048 .43123 Mdot
.33238 .3729 Mdot
.33429 .4163 Mdot
.33619 .22856 Mdot
.3381 .34209 Mdot
.34 .3405 Mdot
.3419 .3833 Mdot
.34381 .36261 Mdot
.34571 .27445 Mdot
.34762 .33884 Mdot
.34952 .43122 Mdot
.35143 .38728 Mdot
.35333 .33456 Mdot
.35524 .34355 Mdot
.35714 .26424 Mdot
.35905 .26461 Mdot
.36095 .32078 Mdot
.36286 .45552 Mdot
.36476 .38958 Mdot
.36667 .32129 Mdot
.36857 .4017 Mdot
.37048 .42695 Mdot
.37238 .24267 Mdot
.37429 .25761 Mdot
.37619 .225 Mdot
.3781 .29768 Mdot
.38 .38344 Mdot
.3819 .44622 Mdot
.38381 .39951 Mdot
.38571 .23073 Mdot
.38762 .34331 Mdot
.38952 .28096 Mdot
.39143 .36861 Mdot
.39333 .27286 Mdot
.39524 .33532 Mdot
.39714 .33414 Mdot
.39905 .22979 Mdot
.40095 .25402 Mdot
.40286 .28462 Mdot
.40476 .47497 Mdot
.40667 .24525 Mdot
.40857 .30233 Mdot
.41048 .30587 Mdot
.41238 .30221 Mdot
.41429 .25596 Mdot
.41619 .4778 Mdot
.4181 .37762 Mdot
.42 .26317 Mdot
.4219 .38243 Mdot
.42381 .33534 Mdot
.42571 .28277 Mdot
.42762 .34995 Mdot
.42952 .26889 Mdot
.43143 .34785 Mdot
.43333 .27638 Mdot
.43524 .25678 Mdot
.43714 .38083 Mdot
.43905 .34167 Mdot
.44095 .22676 Mdot
.44286 .30075 Mdot
.44476 .39601 Mdot
.44667 .27852 Mdot
.44857 .33507 Mdot
.45048 .42098 Mdot
.45238 .26367 Mdot
.45429 .31644 Mdot
.45619 .25809 Mdot
.4581 .25084 Mdot
.46 .36225 Mdot
.4619 .33226 Mdot
.46381 .23914 Mdot
.46571 .3108 Mdot
.46762 .28717 Mdot
.46952 .27216 Mdot
.47143 .47709 Mdot
.47333 .34851 Mdot
.47524 .3525 Mdot
.47714 .29685 Mdot
.47905 .33945 Mdot
.48095 .38158 Mdot
.48286 .24208 Mdot
.48476 .37806 Mdot
.48667 .34577 Mdot
.48857 .36025 Mdot
.49048 .29816 Mdot
.49238 .27655 Mdot
.49429 .39385 Mdot
.49619 .31429 Mdot
.4981 .42834 Mdot
.5 .30942 Mdot
.5019 .27973 Mdot
.50381 .41431 Mdot
.50571 .22855 Mdot
.50762 .32047 Mdot
.50952 .2761 Mdot
.51143 .42907 Mdot
.51333 .36624 Mdot
.51524 .34482 Mdot
.51714 .31733 Mdot
.51905 .31267 Mdot
.52095 .31198 Mdot
.52286 .42246 Mdot
.52476 .3604 Mdot
.52667 .35257 Mdot
.52857 .32539 Mdot
.53048 .32887 Mdot
.53238 .33925 Mdot
.53429 .39281 Mdot
.53619 .34038 Mdot
.5381 .36894 Mdot
.54 .37454 Mdot
.5419 .3704 Mdot
.54381 .36434 Mdot
.54571 .31655 Mdot
.54762 .3027 Mdot
.54952 .36269 Mdot
.55143 .43023 Mdot
.55333 .25856 Mdot
.55524 .26503 Mdot
.55714 .41033 Mdot
.55905 .34789 Mdot
.56095 .38849 Mdot
.56286 .4072 Mdot
.56476 .32628 Mdot
.56667 .26738 Mdot
.56857 .42964 Mdot
.57048 .27431 Mdot
.57238 .29262 Mdot
.57429 .32088 Mdot
.57619 .25136 Mdot
.5781 .33932 Mdot
.58 .30542 Mdot
.5819 .2847 Mdot
.58381 .44654 Mdot
.58571 .42633 Mdot
.58762 .256 Mdot
.58952 .4226 Mdot
.59143 .2917 Mdot
.59333 .43231 Mdot
.59524 .32586 Mdot
.59714 .32009 Mdot
.59905 .24477 Mdot
.60095 .36566 Mdot
.60286 .36782 Mdot
.60476 .34003 Mdot
.60667 .3735 Mdot
.60857 .39203 Mdot
.61048 .22507 Mdot
.61238 .3387 Mdot
.61429 .40914 Mdot
.61619 .36833 Mdot
.6181 .28076 Mdot
.62 .26706 Mdot
.6219 .26793 Mdot
.62381 .24432 Mdot
.62571 .26452 Mdot
.62762 .32584 Mdot
.62952 .39561 Mdot
.63143 .24831 Mdot
.63333 .30494 Mdot
.63524 .32957 Mdot
.63714 .23817 Mdot
.63905 .27628 Mdot
.64095 .40651 Mdot
.64286 .29555 Mdot
.64476 .37707 Mdot
.64667 .25495 Mdot
.64857 .41947 Mdot
.65048 .25077 Mdot
.65238 .28895 Mdot
.65429 .30491 Mdot
.65619 .26524 Mdot
.6581 .29537 Mdot
.66 .42795 Mdot
.6619 .31524 Mdot
.66381 .28208 Mdot
.66571 .32304 Mdot
.66762 .30038 Mdot
.66952 .3591 Mdot
.67143 .37063 Mdot
.67333 .34099 Mdot
.67524 .37279 Mdot
.67714 .25364 Mdot
.67905 .47999 Mdot
.68095 .36831 Mdot
.68286 .34188 Mdot
.68476 .29583 Mdot
.68667 .34287 Mdot
.68857 .35113 Mdot
.69048 .38364 Mdot
.69238 .31277 Mdot
.69429 .33655 Mdot
.69619 .32651 Mdot
.6981 .39349 Mdot
.7 .274 Mdot
.7019 .43422 Mdot
.70381 .36589 Mdot
.70571 .37126 Mdot
.70762 .24548 Mdot
.70952 .38267 Mdot
.71143 .3445 Mdot
.71333 .27346 Mdot
.71524 .40767 Mdot
.71714 .30315 Mdot
.71905 .24498 Mdot
.72095 .23502 Mdot
.72286 .22426 Mdot
.72476 .28461 Mdot
.72667 .35527 Mdot
.72857 .23687 Mdot
.73048 .31282 Mdot
.73238 .28029 Mdot
.73429 .26534 Mdot
.73619 .36802 Mdot
.7381 .38266 Mdot
.74 .38677 Mdot
.7419 .40156 Mdot
.74381 .38159 Mdot
.74571 .43142 Mdot
.74762 .42551 Mdot
.74952 .26761 Mdot
.75143 .43557 Mdot
.75333 .2747 Mdot
.75524 .22561 Mdot
.75714 .41304 Mdot
.75905 .42693 Mdot
.76095 .39243 Mdot
.76286 .31528 Mdot
.76476 .25005 Mdot
.76667 .31475 Mdot
.76857 .30149 Mdot
.77048 .24118 Mdot
.77238 .23712 Mdot
.77429 .2847 Mdot
.77619 .28542 Mdot
.7781 .35597 Mdot
.78 .35168 Mdot
.7819 .41393 Mdot
.78381 .26243 Mdot
.78571 .33407 Mdot
.78762 .23991 Mdot
.78952 .24906 Mdot
.79143 .4786 Mdot
.79333 .24629 Mdot
.79524 .26878 Mdot
.79714 .26088 Mdot
.79905 .28009 Mdot
.80095 .29799 Mdot
.80286 .26896 Mdot
.80476 .3512 Mdot
.80667 .33638 Mdot
.80857 .3548 Mdot
.81048 .25829 Mdot
.81238 .24784 Mdot
.81429 .28284 Mdot
.81619 .33729 Mdot
.8181 .33881 Mdot
.82 .34868 Mdot
.8219 .32854 Mdot
.82381 .27062 Mdot
.82571 .24428 Mdot
.82762 .3531 Mdot
.82952 .26217 Mdot
.83143 .2904 Mdot
.83333 .31077 Mdot
.83524 .28026 Mdot
.83714 .27951 Mdot
.83905 .25861 Mdot
.84095 .39309 Mdot
.84286 .36912 Mdot
.84476 .34278 Mdot
.84667 .249 Mdot
.84857 .46482 Mdot
.85048 .37421 Mdot
.85238 .44419 Mdot
.85429 .39095 Mdot
.85619 .26243 Mdot
.8581 .36946 Mdot
.86 .23316 Mdot
.8619 .35018 Mdot
.86381 .30862 Mdot
.86571 .47895 Mdot
.86762 .33791 Mdot
.86952 .27418 Mdot
.87143 .25684 Mdot
.87333 .32014 Mdot
.87524 .36797 Mdot
.87714 .47133 Mdot
.87905 .2888 Mdot
.88095 .29447 Mdot
.88286 .24823 Mdot
.88476 .3054 Mdot
.88667 .32556 Mdot
.88857 .26584 Mdot
.89048 .31902 Mdot
.89238 .32856 Mdot
.89429 .41276 Mdot
.89619 .35991 Mdot
.8981 .3968 Mdot
.9 .36759 Mdot
.9019 .2717 Mdot
.90381 .25783 Mdot
.90571 .44414 Mdot
.90762 .2897 Mdot
.90952 .29248 Mdot
.91143 .22724 Mdot
.91333 .34141 Mdot
.91524 .43317 Mdot
.91714 .36973 Mdot
.91905 .28211 Mdot
.92095 .3816 Mdot
.92286 .38555 Mdot
.92476 .30319 Mdot
.92667 .32706 Mdot
.92857 .24405 Mdot
.93048 .33402 Mdot
.93238 .35357 Mdot
.93429 .31476 Mdot
.93619 .33129 Mdot
.9381 .36411 Mdot
.94 .29 Mdot
.9419 .28459 Mdot
.94381 .30697 Mdot
.94571 .34599 Mdot
.94762 .31316 Mdot
.94952 .36294 Mdot
.95143 .37725 Mdot
.95333 .25212 Mdot
.95524 .39402 Mdot
.95714 .33803 Mdot
.95905 .30637 Mdot
.96095 .2693 Mdot
.96286 .43269 Mdot
.96476 .26729 Mdot
.96667 .35358 Mdot
.96857 .41623 Mdot
.97048 .34385 Mdot
.97238 .33199 Mdot
.97429 .39338 Mdot
.97619 .25048 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo01Gooooo0_l00036ooooo`;o0000GOooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`0<ooooo`;o00001oooool2o`0005Oooooo0_l0000Booooo`;o0000=Ooo
ool2o`0002;ooooo0_l00008ooooo`;o0000<Oooool2o`00023ooooo0004o`0000;ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0<ooooo`;o00009_ooool2o`0002_ooooo0_l0000;ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0000_ooooo0_l0000Cooooo`;o00008?ooool2o`0002cooooo0_l0
000aooooo`;o00008?ooool000Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ
8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0003Cooooo0_l0000[ooooo`;o00003_oo
ool2o`0000;ooooo0_l0000Pooooo`;o0000L?ooool2o`00037ooooo0006ooooo`05o`000?oooooo
ooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`09ooooo`Co00006_ooool2o`0003;ooooo0_l0001oooooo`;o0000
00?oooooo`000?l000003?ooool2o`0001[ooooo0_l0000aooooo`001_ooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Gooooo2?l0000Jooooo`;o00005oooool2o`0000Kooooo0ol00008ooooo`;o0000
1_ooool2o`0002gooooo0_l0000eooooo`;o00006Oooool2o`000003ooooool0003o000000cooooo
0_l00003ooooo`;o0000B?ooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Co
oooo1Ol0000gooooo`;o00001?ooool5o`0000Sooooo0_l0000Gooooo`;o00007?ooool2o`0000Co
oooo0_l0000_ooooo`;o0000:Oooool2o`0000Cooooo0_l00018ooooo`001_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0
003oooooooooo`04ooooo`;o00002Oooool4o`0003?ooooo0_l00006ooooo`;o00007?ooool2o`00
00Wooooo0_l0000Gooooo`;o00008oooool2o`0000Kooooo0_l0000Iooooo`;o00000_ooool2o`00
00kooooo0_l00006ooooo`;o00002?ooool2o`0001oooooo0_l0000Kooooo`00:Oooool2o`00013o
oooo1?l0000Zooooo`;o00003oooool2o`0002Oooooo0_l0000looooo`;o00001_ooool2o`000003
ooooool0003o000001Kooooo0_l00002ooooo`;o00005?ooool4o`0000Cooooo0_l00002ooooo`;o
00001Oooool2o`0000Wooooo0_l0000=ooooo`;o00006oooool002Wooooo00?o0000ooooooooool0
5_ooool2o`0002Gooooo0_l00019ooooo`;o00009?ooool2o`00013ooooo0_l00004ooooo`;o0000
8oooool2o`0000Gooooo0_l00006ooooo`;o00002Oooool2o`0000Wooooo0_l0000Eooooo`;o0000
1_ooool2o`0000_ooooo000Yooooo`04o`000?oooooo0000o`0001Gooooo0_l0000Hooooo`;o0000
A?ooool2o`00013ooooo0_l0000Tooooo`;o00005Oooool3o`0000Kooooo0_l0000Kooooo`;o0000
>_ooool2o`0000Kooooo0_l0000;ooooo`00:Oooool01?l0003oooooo`000?l0000_ooooo`Co0000
2_ooool2o`0002gooooo0_l00007ooooo`;o00000_ooool2o`0000Gooooo0_l00004ooooo`;o0000
7_ooool2o`0000Wooooo0_l0000Aooooo`;o00001oooool2o`0002Wooooo0_l00007ooooo`;o0000
2Oooool2o`0000Sooooo0_l0000Sooooo`00:Oooool00ol0003oooooooooo`0booooo`;o00001ooo
ool2o`000003ooooool0003o000002gooooo0_l0000;ooooo`;o00001Oooool2o`0000Cooooo0_l0
000Nooooo`;o00002Oooool2o`00047ooooo0_l00002ooooo`;o00001?ooool2o`000003ooooool0
003o000000Wooooo0_l00008ooooo`;o00008oooool002Wooooo0_l0000;ooooo`;o00002Oooool2
o`0002Cooooo1?l0000Xooooo`?o00004_ooool2o`0000Sooooo0_l0000Oooooo`;o00005Oooool2
o`0000Sooooo0_l0000Wooooo`;o00000_ooool2o`0000Sooooo0_l00007ooooo`;o0000<_ooool0
02Wooooo00?o0000ooooooooool01?ooool4o`0000;ooooo0_l00009ooooo`;o00006_ooool4o`00
00Sooooo0_l0000Xooooo`?o00004_ooool2o`0000Sooooo0_l0000Oooooo`;o00000_ooool2o`00
00oooooo1?l00008ooooo`;o00005oooool2o`0000?ooooo0_l00009ooooo`;o00005Oooool2o`00
00Sooooo0_l0000Gooooo`;o00003oooool002Wooooo00?o0000ooooooooool01?ooool4o`0001ko
oooo0_l00008ooooo`Go00000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Dooooo`;o00004oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`05onk^k_lb<S;o0000o`000?o^k^h0:?ooool01OnHV9So0000o`000?lb<S;oc<c<00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`03onk^k_lb<S;o000000;o00008_ooool2o`00
00?ooooo0_l000001?oooooo0000o`000?l@4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_l0
00001_oooooo0000o`000?l0003o<S8bonk^kP;ooooo0_l0000Booooo`;o00004Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00?o000000Co<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo000Yooooo`03o`000?oooooooooo01;ooooo0_l0000Booooo`;o00002_ooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Wooooo0_l00009ooooo`?o00002Oooool2o`0000Oooooo00KoV9RHob4Q8Oo^k^ko
ooooodA4A?ooool2o`000005ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHo`000?l0
003oMgMg00[ooooo0_l0000Looooo`05oa0@4?nj^[[o0000o`000?lb<S800oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Gooooo`;o00000_ooool2o`00
00kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00;o000000Kooooo
o`000?l0003ooooooiRHV?mgMgL2ooooo`;o00003?ooool2o`0000Wooooo0_l0000?ooooo`09ogMg
Molb<S;o0000o`000?mgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`00:Oooool00ol0003oooooooooo`07ooooo`;o00002Oooool2o`0001Cooooo1?l00006
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oo
ooooooooooooool@41002Oooool2o`0000Kooooo0_l00002ooooo`;o00002Oooool2o`0000Sooooo
00?oV9RHob4Q8Oo^k^h00_ooool2o`000005oa0@4?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`02o`0000[ooooo0_l00005ooooo`;o00000oooool2o`0001;ooooo0ol00003ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo0_l0000B
ooooo`;o00000_ooool2o`0000_ooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@013ooooo0_l00009ooooo`;o00004?ooool01?l0003ooooo
ooooool@4103ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`01oooo
o`00:Oooool2o`0000Sooooo0_l0000Oooooo`Co00001_ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000017ooooo0_l0000H
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo00;o00000_ooool2o`0000gooooo0_l000000ooooooo0000o`000002o`0001?ooooo00?o
ZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo0ol000000ooooooo0000
ooooo`02ooooo`;o00007?ooool2o`0000Gooooo0_l000000ooooooo0000ooooo`03ooooo`05o`00
0?ooooooooooooooool000000_ooool2o`0000?ooooo00?o0000ooooooooool00oooool3o`0002Co
oooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`01ooooo`00:Oooool00ol0003oooooooooo`0Pooooo`;o00004?ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000002cooooo00KoMgMgofIVI_l0003o0000ooooool00003ooooo`04o`000?oooooooooooooo
o`;o00000_ooool00ol0003oooooooooo`02o`00013ooooo0_l0000Dooooo`03oa0@4?l0003o^[Zj
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`?o000000?oooooo`000?ooool02_ooool2
o`0001Cooooo0_l00005ooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000oooooooooooooooo
o`000002ooooo`;o00000_ooool2o`0000Gooooo0ol0000Hooooo`;o00001oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool002Wooooo0ol0000Pooooo`;o00004?ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@02gooooo0ol0
00001_oooooo410@o`000?l0003ooooooa0@40?ooooo0_l00002ooooo`03oa0@4?oooooooooo02Wo
oooo00?o^[Zjob4Q8Oooool00_l000001Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooo
oooooooooooooa0@400;ooooo`;o00004_ooool2o`0000Sooooo00?oMgMgolc<c?l000000oooool2
o`0000?ooooo00Go410@oooooooooooooooooa0@4002ooooo`;o00008?ooool2o`0000Gooooo0ol0
0006ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?o
oooo000Yooooo`?o0000<_ooool2o`0000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0:Oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMg
o`000?l0003oV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02Oooool2o`0001gooooo
00Ko410@oiRHV?oooooo^[Zjo`000?ooool2o`000005ogMgMonHV9SooooooiRHV?mgMgL00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo0_l0000Fooooo`;o00002?ooool00oo^k^koA4A4o`00
0003ooooo`;o000000CoV9RHoooooonHV9SoMgMg0oooool01OmgMgOoV9RHoooooonHV9SoMgMg01?o
oooo0_l00007ooooo`;o00002Oooool3o`0000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wooooo00?o0000ooooooooool08oooool2o`00
00_ooooo00CoEEEEofIVI_l0003o00000_ooool2o`000004oc8b<_l0003o<S8bonk^kP?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0Yooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP09ooooo`;o00007Oooool0
0onYZJWo410@o`000002o`0000?ooooo00Gok^k^o`000?l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01oooool2o`00027ooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`;o00003Oooool2o`00
00Oooooo0ol00008ooooo`Ko00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool2o`0000_ooooo0_l0000Gooooo`;o00004Oooool2
o`0000Kooooo0_l0001]ooooo`;o00001?ooool2o`0000kooooo0_l00003ooooo`;o00001oooool2
o`0002gooooo0_l0000>ooooo`;o00001oooool2o`00027ooooo000Yooooo`03o`000?oooooooooo
00[ooooo0_l0000Rooooo`;o00003_ooool2o`0001Sooooo0_l0000Dooooo`;o00007_ooool2o`00
00;ooooo0_l0000_ooooo`;o00000oooool2o`0000Oooooo0_l0000Sooooo`;o00006?ooool2o`00
02[ooooo000Yooooo`03o`000?oooooooooo02kooooo0_l0000Xooooo`;o00005?ooool2o`0000So
oooo0ol00008ooooo`;o00002Oooool2o`0000;ooooo0_l0000gooooo`;o00007oooool2o`0000So
oooo0_l00014ooooo`00:Oooool00ol0003oooooooooo`0Uooooo`;o0000DOooool3o`0000Sooooo
0_l0000Pooooo`;o00002?ooool2o`0000oooooo0_l00005ooooo`;o00000_ooool2o`0000kooooo
0_l0000?ooooo`;o00008oooool2o`0000_ooooo0_l0000Looooo`00:Oooool00ol0003ooooooooo
o`02ooooo`;o00008Oooool2o`000003ooooool0003o000000Wooooo0_l0000Booooo`;o00002Ooo
ool2o`0002Gooooo0_l0000Zooooo`;o00002?ooool2o`0000oooooo0_l00005ooooo`;o00004_oo
ool2o`0002gooooo0_l00005ooooo`;o00002oooool2o`0000Cooooo0_l00003ooooo`;o00004Ooo
ool0027oooooool00014o`0000Cooooo000Yooooo`04o`000?ooooooooooooooo`;o00001Oooool2
o`0000?ooooo0_l00007ooooo`04o`000?oooooo0000o`0000?ooooo1?l000000ooooooo0000oooo
o`07ooooo`;o000000?oooooo`000?ooool02_ooool2o`0000_ooooo00Co0000ooooool0003o0000
1_ooool3o`0000Oooooo0_l00002ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`04o`00
0?ooooooooooooooo`?o00001Oooool2o`0000_ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool2o`0000Go
oooo00?o0000ooooooooool00_ooool2o`0000Gooooo00?o0000ooooooooool00_ooool2o`0000Go
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02o`0000Sooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`07ooooo`?o000000?oooooo`000?l000002?ooool00ol0003o
ooooooooo`0:ooooo`00:Oooool01?l0003oooooooooooooool2o`0000Gooooo0_l00003ooooo`;o
00003_ooool2o`0000Gooooo0_l00003ooooo`Co00002Oooool2o`0000;ooooo00?o0000oooooooo
ool03?ooool2o`0000Kooooo0_l00008ooooo`;o00006oooool00ol0003oooooooooo`0<ooooo`;o
00002oooool2o`0000Gooooo0ol00006ooooo`;o00003oooool00ol0003oooooooooo`0Aooooo`;o
00002?ooool2o`0000[ooooo0_l00009ooooo`?o00001Oooool00ol0003oooooooooo`0/ooooo`;o
00000_ooool2o`0000Sooooo00?o0000ooooooooool02_ooool002Wooooo00Co0000oooooooooooo
oooo0_l0000Qooooo`;o00000oooool2o`0000_ooooo0_l00008ooooo`;o00009oooool2o`0001co
oooo0_l0000?ooooo`;o000000?oooooo`000?l000001oooool2o`0000Oooooo0_l00006ooooo`;o
00004_ooool2o`0001oooooo0_l0000Qooooo`;o00001?ooool2o`0002Oooooo000Yooooo`04o`00
0?ooooooooooooooo`;o00007oooool2o`0001cooooo0_l000000ooooooo0000o`000007ooooo`;o
00006oooool4o`0002_ooooo0_l0000Cooooo`;o00001_ooool2o`0001Cooooo0_l00010ooooo`;o
00001?ooool2o`0002Oooooo000Yooooo`Co00008Oooool2o`00017ooooo0_l00008ooooo`;o0000
0_ooool2o`0000Oooooo0_l0000Mooooo`;o0000<_ooool2o`0000Wooooo0_l00008ooooo`;o0000
2?ooool2o`0000_ooooo0_l00007ooooo`;o0000??ooool2o`0000_ooooo0_l0000Kooooo`00:Ooo
ool01?l0003oooooo`000?l0000dooooo`;o00002?ooool2o`0001?ooooo0_l00019ooooo`;o0000
2Oooool2o`0000Sooooo0_l00008ooooo`;o000000?oooooo`000?l000004Oooool2o`0002Oooooo
0_l0000Cooooo`Co00002Oooool2o`0001_ooooo000Yooooo`03o`000?oooooooooo013ooooo0_l0
0002ooooo`;o00006Oooool2o`0000Oooooo0_l000000ooooooo0000o`000004ooooo`;o00004Ooo
ool2o`0003?ooooo0_l0000Dooooo`;o00008?ooool2o`0003[ooooo0_l0000Eooooo`;o00003?oo
ool2o`0000Wooooo0_l0000=ooooo`00:Oooool00ol0003oooooooooo`05ooooo`;o00002?ooool3
o`0000;ooooo0_l000000ooooooo0000o`000002o`0000cooooo0_l00005ooooo`?o00001oooool2
o`000003ooooool0003o000000Cooooo0_l0000Sooooo`;o00003?ooool2o`0000Oooooo0_l00006
ooooo`;o00000_ooool2o`0004Wooooo0_l0000Kooooo`;o00001Oooool2o`0002Kooooo1?l00009
ooooo`;o00003Oooool002Wooooo00?o0000ooooooooool01Oooool2o`0000Sooooo0_l00006oooo
o`Co00003?ooool2o`0000Gooooo0_l0000Dooooo`;o00007_ooool4o`0000cooooo0_l00007oooo
o`;o00001_ooool2o`0000Sooooo0_l0000?ooooo`;o00003?ooool2o`0000[ooooo0_l0000Hoooo
o`;o00006oooool2o`0000Gooooo0_l000001?oooooo0000o`000?l0000>ooooo`;o00004_ooool2
o`0000Kooooo0_l0000Booooo`00:Oooool2o`0004Gooooo0_l0000>ooooo`;o00000oooool2o`00
00Kooooo1Ol0000Looooo`;o00002oooool2o`0000oooooo0ol0000;ooooo`;o00001oooool2o`00
0003ooooool0003o0000017ooooo0_l000001?oooooo0000o`000?l0000Xooooo`?o00001_ooool2
o`0000Kooooo0_l0000<ooooo`;o00003?ooool2o`0001;ooooo000Yooooo`03o`000?oooooooooo
02;ooooo0_l0000`ooooo`;o00000oooool2o`0000Kooooo0ol00003ooooo`;o00002?ooool2o`00
00oooooo0_l0000=ooooo`;o00001oooool2o`0000Gooooo0_l0000Dooooo`;o00005?ooool2o`00
0004ooooool0003o0000o`0000Kooooo0_l0000Yooooo`;o00005?ooool2o`0000Wooooo0_l00006
ooooo`;o00003Oooool002Wooooo0_l00004ooooo`;o00007Oooool2o`0000cooooo0_l0000eoooo
o`;o00002?ooool2o`0000cooooo0_l0000<ooooo`;o00000_ooool2o`0000Oooooo0_l0000<oooo
o`;o0000;oooool2o`00027ooooo0_l0000Wooooo`;o00001_ooool2o`0000gooooo000Yooooo`;o
00001?ooool2o`0000Sooooo0_l0000Mooooo`;o00000_ooool2o`0001gooooo0_l00009ooooo`;o
00008_ooool3o`0000cooooo0_l0000Iooooo`;o0000:?ooool2o`0001_ooooo0_l00006ooooo`;o
00000oooool2o`0000cooooo0_l0000`ooooo`00:Oooool00ol0003oooooooooo`0=ooooo`;o0000
7Oooool2o`00027ooooo0_l00009ooooo`;o00008_ooool2o`0000gooooo0_l0000?ooooo`;o0000
<_ooool2o`0000[ooooo0_l0000?ooooo`;o00001_ooool4o`0000Cooooo0_l00009ooooo`;o0000
5?ooool2o`0000Wooooo0_l0000?ooooo`00:Oooool2o`0004cooooo0_l00010ooooo`;o00003ooo
ool2o`0003kooooo0_l0000?ooooo`;o00002?ooool2o`0000Cooooo0_l0000Oooooo`;o00002Ooo
ool2o`0000oooooo000Yooooo`03o`000?oooooooooo01;ooooo0_l0000;ooooo`;o00008Oooool2
o`0000Oooooo0_l00009ooooo`;o0000>_ooool2o`0000Wooooo0_l0000]ooooo`;o00008Oooool2
o`0002Cooooo0_l0000Uooooo`00:Oooool00ol0003oooooooooo`0<ooooo`;o00001?ooool2o`00
00_ooooo0_l0000<ooooo`;o00004oooool2o`0001;ooooo0_l0000;ooooo`;o00009?ooool2o`00
00Oooooo0_l00009ooooo`;o00001?ooool4o`0002Gooooo0_l00017ooooo`;o00002oooool2o`00
00;ooooo0_l0000Dooooo`00:Oooool00ol0003oooooooooo`0<ooooo`;o00007oooool2o`0003Co
oooo0_l0000Tooooo`;o00003oooool2o`0000Oooooo1?l0000?ooooo`;o00007oooool2o`0003go
oooo0_l0000:ooooo`;o00000_ooool2o`0001Cooooo000Yooooo`03o`000?oooooooooo01[ooooo
0_l0000jooooo`;o00006_ooool2o`0002Kooooo0_l00006ooooo`?o00004Oooool2o`0000?ooooo
0_l0000@ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Sooooo0_l0000Qooooo`;o0000
0oooool2o`0000?ooooo0_l00006ooooo`;o00001?ooool2o`0001kooooo000Yooooo`;o00006ooo
ool2o`0002kooooo0_l000000ooooooo0000o`000007ooooo`;o00001_ooool3o`00017ooooo0_l0
000^ooooo`?o00004oooool2o`000003ooooool0003o0000013ooooo1Ol00006ooooo`;o00001ooo
ool2o`00027ooooo0_l00003ooooo`;o00000oooool2o`0000cooooo0_l0000Nooooo`00:Oooool0
0ol0003oooooooooo`02o`0004Sooooo0_l000001?oooooo0000o`000?l0000>ooooo`?o0000@Ooo
ool2o`0001Cooooo0_l0000:ooooo`;o00002?ooool2o`0000Sooooo0_l0000/ooooo`;o0000=?oo
ool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00;o00001oooool2o`0001[ooooo
0_l0000Nooooo`;o00001oooool2o`0002_ooooo0_l0000Cooooo`;o00004?ooool2o`00023ooooo
0_l00010ooooo`;o00007oooool2o`0001?ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool02Oooool2o`0001[ooooo0_l0000Nooooo`;o00007?ooool2o`0000[o
oooo0_l0000:ooooo`?o00000oooool2o`0000cooooo0ol00017ooooo`;o00001oooool4o`0003Oo
oooo0_l00008ooooo`;o00004oooool000Kooooo00Go410@oooooooooooooooooa0@400<ooooo`03
oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`;o
0000=_ooool4o`0000Oooooo0_l0000Looooo`;o00002_ooool2o`0000_ooooo0_l00003ooooo`;o
00003?ooool2o`0004;ooooo0_l00004ooooo`;o00001oooool4o`0003Oooooo0_l0000Mooooo`00
1_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo
<S8booooo`04ooooo`?o00000_ooool2o`0003Kooooo1?l00007ooooo`;o00002_ooool2o`0000Co
oooo0_l0000=ooooo`;o00000_ooool2o`0003gooooo0_l0000Xooooo`;o00003_ooool2o`0003So
oooo0_l0000Mooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_oo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo0_l0000Aooooo`;o00001Oooool2o`00
02Sooooo0_l0000>ooooo`;o00001?ooool2o`0000?ooooo0_l00008ooooo`;o00000_ooool2o`00
03gooooo0_l0000=ooooo`;o0000:Oooool2o`0000Cooooo0_l0000Looooo`;o0000<oooool000Ko
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01oooool2o`0000oooooo1?l00005ooooo`;o0000:?ooool2o`0001Wooooo0_l0000foooo
o`;o00002_ooool2o`0001Kooooo0_l00005ooooo`;o00005?ooool2o`0001;ooooo0_l0000Hoooo
o`;o00000_ooool2o`0001oooooo0_l00004ooooo`;o00003?ooool000Kooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00kooooo0_l00008ooooo`;o000000?oooooo`000?l000001?ooool2
o`0002Gooooo0_l00009ooooo`;o0000;oooool2o`0000kooooo0_l0000:ooooo`;o00007Oooool2
o`0001Cooooo0_l0000/ooooo`;o00004?ooool2o`00017ooooo0_l00004ooooo`;o00003?ooool0
00Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?oo
ool4o`0000Kooooo00?o0000ooooooooool06?ooool2o`000003ooooool0003o000000Cooooo0_l0
000Uooooo`;o00002Oooool2o`0001Kooooo0_l00003ooooo`;o00004_ooool2o`0005gooooo0_l0
000`ooooo`;o00009Oooool002Wooooo0_l0001/ooooo`;o00000oooool2o`00077ooooo0_l0001G
ooooo`00:Oooool00ol0003oooooooooo`0hooooo`;o0000L?ooool2o`0001Oooooo0_l0000Foooo
o`;o0000Goooool002Wooooo00?o0000ooooooooool05?ooool2o`0002;ooooo0_l0000Fooooo`;o
0000E_ooool4o`0000kooooo0_l00007ooooo`;o00005_ooool2o`0005oooooo000Yooooo`03o`00
0?oooooooooo01Cooooo0_l0000=ooooo`;o00001Oooool2o`0002Cooooo0_l00015ooooo`;o0000
3oooool2o`00013ooooo0_l0000/ooooo`;o00001_ooool2o`0002;ooooo0_l0000Vooooo`00:Ooo
ool00ol0003oooooooooo`0Jooooo`Co00001Oooool2o`0000Gooooo0_l000000ooooooo0000o`00
000^ooooo`;o000000?oooooo`000?l00000=Oooool2o`0004oooooo0_l00006ooooo`;o00008_oo
ool2o`0001Kooooo0_l0000>ooooo`00:Oooool2o`0001_ooooo1?l0000?ooooo`;o0000;_ooool2
o`000003ooooool0003o000006?ooooo0_l0001Uooooo`;o00003_ooool002Wooooo00?o0000oooo
ooooool07?ooool2o`0006Oooooo0_l0000Fooooo`;o00004oooool2o`00017ooooo0_l0001eoooo
o`00:Oooool00ol0003oooooooooo`0Looooo`;o00009Oooool2o`0002Oooooo0_l0000Gooooo`;o
00005_ooool2o`0001;ooooo0ol0000aooooo`;o00000_ooool2o`00057ooooo000Yooooo`03o`00
0?oooooooooo023ooooo0_l0000Qooooo`;o000000?oooooo`000?l000009?ooool2o`0002Oooooo
0_l00002ooooo`;o00004?ooool2o`0000Cooooo0_l0000Fooooo`;o00006_ooool2o`0000;ooooo
0_l0001Aooooo`00:Oooool00ol0003oooooooooo`0Cooooo`;o00002oooool2o`0002Cooooo0_l0
000Dooooo`Go00001?ooool2o`0002kooooo0_l00002ooooo`;o00002oooool2o`0000?ooooo0_l0
0006ooooo`;o00005?ooool2o`0001Wooooo0_l0000eooooo`;o00003Oooool2o`00013ooooo000Y
ooooo`;o00005?ooool2o`0003_ooooo0_l0000:ooooo`Go00001?ooool2o`0003oooooo0_l0000;
ooooo`;o00008Oooool2o`0000cooooo1?l0000cooooo`;o00003Oooool2o`00013ooooo000Yoooo
o`03o`000?oooooooooo053ooooo0_l00024ooooo`;o00003_ooool2o`0005Cooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0ooooool8ooooo`;o0000
3oooool2o`0002;ooooo000Yooooo`03o`000?oooooooooo04_ooooo0_l0000Rooooo`;o0000?ooo
ool2o`0005Gooooo0_l0000?ooooo`;o00008_ooool002Wooooo0_l0001<ooooo`;o00008_ooool2
o`0003oooooo0_l0002:ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo06Wooooo0_l0003Aooooo`003_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0=oooool2
o`00033ooooo0_l0003Aooooo`003_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000
ooooooooool00oooool3o`0003Oooooo0_l0003oooooo`Cooooo000>ooooo`05o`000?oooooooooo
ooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo03Gooooo0_l0003>
ooooo`;o0000=Oooool000kooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0eooooo`;o0000c_ooool2o`0003Gooooo000>
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0?oooooo4?ooool2o`0002_ooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01gooooo0_l0000<ooooo`;o00003?oo
ool2o`0003cooooo0_l0002Fooooo`;o0000:oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`Co00001_ooool2o`0001kooooo0_l0000<ooooo`;o00003?ooool2o`0003cooooo0_l0
00000ooooooo0000o`00000@ooooo`;o0000IOooool2o`0001Kooooo0_l0000_ooooo`00:Oooool0
0ol0003oooooooooo`1jooooo`;o00004?ooool2o`00047ooooo0_l0000Rooooo`;o00005_ooool2
o`0002oooooo000Yooooo`03o`000?oooooooooo0<oooooo0_l0001[ooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0
003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0
003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool0
0omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolm
ooooo`001_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool0
0ol0003oooooooooo`03ooooo`?o0000oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo
000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<co
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Ooo
ool000Kooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool5o`0000Cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000
oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000
oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool001oooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgo
oooo000Qooooo`03o`000?oooooooooo00Gooooo0ol0003oooooocgooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001oooooo
00?oEEEEofIVI_l00000oooooom7ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .39439 Mdot
.02762 .39869 Mdot
.02952 .2783 Mdot
.03143 .33987 Mdot
.03333 .28097 Mdot
.03524 .30893 Mdot
.03714 .27808 Mdot
.03905 .40981 Mdot
.04095 .43314 Mdot
.04286 .25561 Mdot
.04476 .30688 Mdot
.04667 .37537 Mdot
.04857 .3355 Mdot
.05048 .2736 Mdot
.05238 .34738 Mdot
.05429 .32433 Mdot
.05619 .34999 Mdot
.0581 .33032 Mdot
.06 .35514 Mdot
.0619 .28738 Mdot
.06381 .31116 Mdot
.06571 .37553 Mdot
.06762 .35396 Mdot
.06952 .31459 Mdot
.07143 .29436 Mdot
.07333 .31173 Mdot
.07524 .33648 Mdot
.07714 .35421 Mdot
.07905 .31451 Mdot
.08095 .39338 Mdot
.08286 .27439 Mdot
.08476 .43633 Mdot
.08667 .41417 Mdot
.08857 .29656 Mdot
.09048 .25314 Mdot
.09238 .26499 Mdot
.09429 .4148 Mdot
.09619 .35478 Mdot
.0981 .34898 Mdot
.1 .37246 Mdot
.1019 .30837 Mdot
.10381 .27345 Mdot
.10571 .25331 Mdot
.10762 .39844 Mdot
.10952 .38312 Mdot
.11143 .24905 Mdot
.11333 .27577 Mdot
.11524 .43948 Mdot
.11714 .36995 Mdot
.11905 .31986 Mdot
.12095 .43857 Mdot
.12286 .37122 Mdot
.12476 .47811 Mdot
.12667 .24294 Mdot
.12857 .24193 Mdot
.13048 .42539 Mdot
.13238 .40338 Mdot
.13429 .35501 Mdot
.13619 .43218 Mdot
.1381 .37714 Mdot
.14 .2545 Mdot
.1419 .23242 Mdot
.14381 .35677 Mdot
.14571 .26178 Mdot
.14762 .40372 Mdot
.14952 .43346 Mdot
.15143 .25553 Mdot
.15333 .32713 Mdot
.15524 .35572 Mdot
.15714 .2918 Mdot
.15905 .35251 Mdot
.16095 .32156 Mdot
.16286 .25858 Mdot
.16476 .26487 Mdot
.16667 .35671 Mdot
.16857 .29727 Mdot
.17048 .47818 Mdot
.17238 .28885 Mdot
.17429 .35805 Mdot
.17619 .36579 Mdot
.1781 .23513 Mdot
.18 .39327 Mdot
.1819 .33565 Mdot
.18381 .26988 Mdot
.18571 .4227 Mdot
.18762 .32604 Mdot
.18952 .27513 Mdot
.19143 .25242 Mdot
.19333 .36632 Mdot
.19524 .32397 Mdot
.19714 .28643 Mdot
.19905 .41375 Mdot
.20095 .27311 Mdot
.20286 .25026 Mdot
.20476 .26582 Mdot
.20667 .39576 Mdot
.20857 .27027 Mdot
.21048 .43662 Mdot
.21238 .48063 Mdot
.21429 .36862 Mdot
.21619 .39849 Mdot
.2181 .37513 Mdot
.22 .37014 Mdot
.2219 .40159 Mdot
.22381 .25064 Mdot
.22571 .28634 Mdot
.22762 .33891 Mdot
.22952 .35007 Mdot
.23143 .27386 Mdot
.23333 .28478 Mdot
.23524 .26015 Mdot
.23714 .33828 Mdot
.23905 .43606 Mdot
.24095 .26072 Mdot
.24286 .48155 Mdot
.24476 .27702 Mdot
.24667 .26797 Mdot
.24857 .43536 Mdot
.25048 .43703 Mdot
.25238 .41391 Mdot
.25429 .3335 Mdot
.25619 .22305 Mdot
.2581 .32004 Mdot
.26 .31648 Mdot
.2619 .28666 Mdot
.26381 .34096 Mdot
.26571 .27778 Mdot
.26762 .37178 Mdot
.26952 .39773 Mdot
.27143 .32259 Mdot
.27333 .3612 Mdot
.27524 .40037 Mdot
.27714 .35444 Mdot
.27905 .31099 Mdot
.28095 .27025 Mdot
.28286 .34056 Mdot
.28476 .40478 Mdot
.28667 .30103 Mdot
.28857 .25789 Mdot
.29048 .39998 Mdot
.29238 .34667 Mdot
.29429 .28933 Mdot
.29619 .31542 Mdot
.2981 .35711 Mdot
.3 .35051 Mdot
.3019 .27263 Mdot
.30381 .42844 Mdot
.30571 .46639 Mdot
.30762 .33582 Mdot
.30952 .24985 Mdot
.31143 .23145 Mdot
.31333 .37709 Mdot
.31524 .34748 Mdot
.31714 .3144 Mdot
.31905 .31819 Mdot
.32095 .35058 Mdot
.32286 .39693 Mdot
.32476 .36139 Mdot
.32667 .43274 Mdot
.32857 .41564 Mdot
.33048 .39877 Mdot
.33238 .3442 Mdot
.33429 .35561 Mdot
.33619 .33232 Mdot
.3381 .24651 Mdot
.34 .25822 Mdot
.3419 .39686 Mdot
.34381 .42906 Mdot
.34571 .24238 Mdot
.34762 .35477 Mdot
.34952 .39331 Mdot
.35143 .30417 Mdot
.35333 .29357 Mdot
.35524 .35106 Mdot
.35714 .26847 Mdot
.35905 .33141 Mdot
.36095 .40705 Mdot
.36286 .38898 Mdot
.36476 .34769 Mdot
.36667 .27838 Mdot
.36857 .32787 Mdot
.37048 .37971 Mdot
.37238 .35362 Mdot
.37429 .29091 Mdot
.37619 .30087 Mdot
.3781 .33053 Mdot
.38 .43212 Mdot
.3819 .37186 Mdot
.38381 .4398 Mdot
.38571 .33674 Mdot
.38762 .25957 Mdot
.38952 .22884 Mdot
.39143 .27132 Mdot
.39333 .27378 Mdot
.39524 .22889 Mdot
.39714 .41619 Mdot
.39905 .27981 Mdot
.40095 .36423 Mdot
.40286 .25315 Mdot
.40476 .43302 Mdot
.40667 .31894 Mdot
.40857 .26592 Mdot
.41048 .26646 Mdot
.41238 .32306 Mdot
.41429 .28067 Mdot
.41619 .44322 Mdot
.4181 .39911 Mdot
.42 .30729 Mdot
.4219 .3254 Mdot
.42381 .33621 Mdot
.42571 .32759 Mdot
.42762 .30983 Mdot
.42952 .36111 Mdot
.43143 .28183 Mdot
.43333 .24138 Mdot
.43524 .29861 Mdot
.43714 .39757 Mdot
.43905 .2726 Mdot
.44095 .32699 Mdot
.44286 .33177 Mdot
.44476 .37343 Mdot
.44667 .38452 Mdot
.44857 .2634 Mdot
.45048 .43322 Mdot
.45238 .24952 Mdot
.45429 .23513 Mdot
.45619 .30837 Mdot
.4581 .30884 Mdot
.46 .40341 Mdot
.4619 .28594 Mdot
.46381 .34647 Mdot
.46571 .22269 Mdot
.46762 .33676 Mdot
.46952 .29072 Mdot
.47143 .44732 Mdot
.47333 .37518 Mdot
.47524 .33265 Mdot
.47714 .22432 Mdot
.47905 .35345 Mdot
.48095 .40302 Mdot
.48286 .33124 Mdot
.48476 .40017 Mdot
.48667 .2341 Mdot
.48857 .28088 Mdot
.49048 .23381 Mdot
.49238 .35284 Mdot
.49429 .43836 Mdot
.49619 .26387 Mdot
.4981 .39614 Mdot
.5 .36561 Mdot
.5019 .35478 Mdot
.50381 .35655 Mdot
.50571 .28359 Mdot
.50762 .27571 Mdot
.50952 .27113 Mdot
.51143 .40442 Mdot
.51333 .32163 Mdot
.51524 .34966 Mdot
.51714 .24266 Mdot
.51905 .30273 Mdot
.52095 .40368 Mdot
.52286 .43711 Mdot
.52476 .37422 Mdot
.52667 .33211 Mdot
.52857 .23739 Mdot
.53048 .30699 Mdot
.53238 .37605 Mdot
.53429 .3895 Mdot
.53619 .287 Mdot
.5381 .29927 Mdot
.54 .28339 Mdot
.5419 .34268 Mdot
.54381 .26773 Mdot
.54571 .24285 Mdot
.54762 .25499 Mdot
.54952 .37006 Mdot
.55143 .39407 Mdot
.55333 .28727 Mdot
.55524 .33343 Mdot
.55714 .43874 Mdot
.55905 .30139 Mdot
.56095 .34174 Mdot
.56286 .338 Mdot
.56476 .32343 Mdot
.56667 .27359 Mdot
.56857 .41591 Mdot
.57048 .38017 Mdot
.57238 .34928 Mdot
.57429 .305 Mdot
.57619 .29936 Mdot
.5781 .24252 Mdot
.58 .24923 Mdot
.5819 .23856 Mdot
.58381 .37295 Mdot
.58571 .43024 Mdot
.58762 .36486 Mdot
.58952 .43059 Mdot
.59143 .27088 Mdot
.59333 .42662 Mdot
.59524 .22606 Mdot
.59714 .23409 Mdot
.59905 .35342 Mdot
.60095 .45552 Mdot
.60286 .36627 Mdot
.60476 .25524 Mdot
.60667 .40119 Mdot
.60857 .43742 Mdot
.61048 .30856 Mdot
.61238 .2823 Mdot
.61429 .43788 Mdot
.61619 .32793 Mdot
.6181 .27282 Mdot
.62 .35926 Mdot
.6219 .34533 Mdot
.62381 .33638 Mdot
.62571 .23702 Mdot
.62762 .2866 Mdot
.62952 .38002 Mdot
.63143 .28281 Mdot
.63333 .39742 Mdot
.63524 .30773 Mdot
.63714 .34767 Mdot
.63905 .23182 Mdot
.64095 .30396 Mdot
.64286 .33874 Mdot
.64476 .31042 Mdot
.64667 .26956 Mdot
.64857 .37015 Mdot
.65048 .31058 Mdot
.65238 .26755 Mdot
.65429 .27067 Mdot
.65619 .34422 Mdot
.6581 .39517 Mdot
.66 .40338 Mdot
.6619 .26376 Mdot
.66381 .36919 Mdot
.66571 .32464 Mdot
.66762 .32313 Mdot
.66952 .40262 Mdot
.67143 .29938 Mdot
.67333 .25865 Mdot
.67524 .34471 Mdot
.67714 .28625 Mdot
.67905 .47228 Mdot
.68095 .33121 Mdot
.68286 .39436 Mdot
.68476 .26111 Mdot
.68667 .41838 Mdot
.68857 .33228 Mdot
.69048 .29554 Mdot
.69238 .38292 Mdot
.69429 .2944 Mdot
.69619 .25726 Mdot
.6981 .2854 Mdot
.7 .38075 Mdot
.7019 .42545 Mdot
.70381 .27049 Mdot
.70571 .36103 Mdot
.70762 .31829 Mdot
.70952 .29577 Mdot
.71143 .376 Mdot
.71333 .38026 Mdot
.71524 .30456 Mdot
.71714 .23323 Mdot
.71905 .35515 Mdot
.72095 .34297 Mdot
.72286 .31098 Mdot
.72476 .32131 Mdot
.72667 .37428 Mdot
.72857 .34337 Mdot
.73048 .40451 Mdot
.73238 .31966 Mdot
.73429 .24925 Mdot
.73619 .3353 Mdot
.7381 .32457 Mdot
.74 .39741 Mdot
.7419 .43633 Mdot
.74381 .40271 Mdot
.74571 .42121 Mdot
.74762 .39119 Mdot
.74952 .35743 Mdot
.75143 .42017 Mdot
.75333 .36301 Mdot
.75524 .31252 Mdot
.75714 .47803 Mdot
.75905 .41996 Mdot
.76095 .35381 Mdot
.76286 .31602 Mdot
.76476 .25059 Mdot
.76667 .37005 Mdot
.76857 .27004 Mdot
.77048 .35219 Mdot
.77238 .28843 Mdot
.77429 .26942 Mdot
.77619 .25929 Mdot
.7781 .29494 Mdot
.78 .33849 Mdot
.7819 .44033 Mdot
.78381 .24992 Mdot
.78571 .22861 Mdot
.78762 .35026 Mdot
.78952 .3246 Mdot
.79143 .46812 Mdot
.79333 .31939 Mdot
.79524 .33507 Mdot
.79714 .3285 Mdot
.79905 .31375 Mdot
.80095 .39638 Mdot
.80286 .37676 Mdot
.80476 .33472 Mdot
.80667 .29623 Mdot
.80857 .32874 Mdot
.81048 .31334 Mdot
.81238 .25156 Mdot
.81429 .25356 Mdot
.81619 .24286 Mdot
.8181 .32434 Mdot
.82 .34912 Mdot
.8219 .31363 Mdot
.82381 .26156 Mdot
.82571 .30576 Mdot
.82762 .33915 Mdot
.82952 .30146 Mdot
.83143 .22532 Mdot
.83333 .40206 Mdot
.83524 .30706 Mdot
.83714 .24849 Mdot
.83905 .33849 Mdot
.84095 .36656 Mdot
.84286 .3429 Mdot
.84476 .35258 Mdot
.84667 .25134 Mdot
.84857 .40637 Mdot
.85048 .40267 Mdot
.85238 .48667 Mdot
.85429 .40074 Mdot
.85619 .29352 Mdot
.8581 .42748 Mdot
.86 .33698 Mdot
.8619 .31505 Mdot
.86381 .38061 Mdot
.86571 .47406 Mdot
.86762 .30302 Mdot
.86952 .27836 Mdot
.87143 .32211 Mdot
.87333 .2356 Mdot
.87524 .36013 Mdot
.87714 .42474 Mdot
.87905 .32907 Mdot
.88095 .24375 Mdot
.88286 .28145 Mdot
.88476 .26042 Mdot
.88667 .28701 Mdot
.88857 .27436 Mdot
.89048 .40851 Mdot
.89238 .29466 Mdot
.89429 .34851 Mdot
.89619 .40185 Mdot
.8981 .38304 Mdot
.9 .27157 Mdot
.9019 .24512 Mdot
.90381 .33662 Mdot
.90571 .36535 Mdot
.90762 .25756 Mdot
.90952 .39349 Mdot
.91143 .28725 Mdot
.91333 .28987 Mdot
.91524 .42631 Mdot
.91714 .34302 Mdot
.91905 .35351 Mdot
.92095 .29198 Mdot
.92286 .39879 Mdot
.92476 .35233 Mdot
.92667 .25756 Mdot
.92857 .30115 Mdot
.93048 .22732 Mdot
.93238 .27301 Mdot
.93429 .29154 Mdot
.93619 .25044 Mdot
.9381 .36665 Mdot
.94 .32301 Mdot
.9419 .33456 Mdot
.94381 .24238 Mdot
.94571 .26216 Mdot
.94762 .2691 Mdot
.94952 .31328 Mdot
.95143 .43287 Mdot
.95333 .28836 Mdot
.95524 .38552 Mdot
.95714 .35729 Mdot
.95905 .35158 Mdot
.96095 .31014 Mdot
.96286 .48497 Mdot
.96476 .30483 Mdot
.96667 .40079 Mdot
.96857 .4329 Mdot
.97048 .24765 Mdot
.97238 .35633 Mdot
.97429 .31229 Mdot
.97619 .36173 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo04Oooooo0_l00011ooooo`;o00000_ooool2o`000:cooooo0006ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0Aoooool2o`00047ooooo0_l00002ooooo`;o00009?oo
ool2o`0004[ooooo0_l0000Nooooo`;o00006_ooool000Co00000_ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo07;ooooo1?l0000nooooo`;o0000>oooool2o`0000gooooo0_l0000Nooooo`;o00006_oo
ool000Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o
MgMgoc8b<_ooool01?ooool3o`0002;ooooo0_l0000eooooo`;o00005oooool4o`0001_ooooo0ol0
000Qooooo`;o00002oooool2o`0001Oooooo0_l0000Dooooo`;o0000BOooool000Kooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`03o`000?oooooooooo02;ooooo0_l0000:ooooo`;o0000:Oooool2o`0002cooooo
0_l00008ooooo`?o00008Oooool2o`0000Oooooo0_l00002ooooo`;o00005oooool2o`00033ooooo
0_l0000]ooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02kooooo0_l0001Gooooo`;o0000
5_ooool2o`0000oooooo0_l0000<ooooo`;o0000COooool2o`0002gooooo0006ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Mooooo`?o0000A?ooool2o`0001[ooooo0_l0000Iooooo`;o
00000_ooool2o`0000?ooooo0_l00008ooooo`Co0000BOooool2o`0002Oooooo0_l0000Fooooo`00
1_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co00001_ooool00ol0003oooooooooo`0Mooooo`?o0000@Oooool2o`000003ooooool0003o0000
01[ooooo0_l0000Iooooo`;o00001oooool2o`0000Sooooo0_l0001;ooooo`;o00004oooool2o`00
00Gooooo0_l0000;ooooo`;o00005_ooool002Wooooo0_l0000Iooooo`;o0000Aoooool2o`0002?o
oooo0_l0000Wooooo`;o0000<?ooool2o`0001oooooo0_l0000<ooooo`;o00001Oooool2o`0001Co
oooo0_l0000=ooooo`00:Oooool00ol0003oooooooooo`0Hooooo`;o00006?ooool2o`0000;ooooo
0_l00005ooooo`;o00006Oooool2o`0002cooooo0_l0000Wooooo`;o0000<?ooool2o`0000Sooooo
0_l00004ooooo`;o00001oooool2o`0000Kooooo0_l000000ooooooo0000o`00000Kooooo`;o0000
2Oooool2o`0000gooooo000Yooooo`03o`000?oooooooooo00;ooooo0_l0000>ooooo`;o00000ooo
ool2o`0000Wooooo0_l000000ooooooo0000o`00000;ooooo`;o00000_ooool2o`0000Gooooo0_l0
000Iooooo`;o00007?ooool2o`0002gooooo0_l0000@ooooo`;o0000<_ooool2o`0000Cooooo0_l0
0007ooooo`;o00002Oooool2o`0001_ooooo0_l0000Hooooo`00:Oooool00ol0003oooooooooo`02
ooooo`;o00003_ooool2o`0000?ooooo0_l00009ooooo`;o000000?oooooo`000?l000000_ooool2
o`0002Kooooo0_l0000?ooooo`;o00004_ooool2o`0002gooooo0_l0000@ooooo`;o00005?ooool2
o`0000Gooooo0_l0000Tooooo`;o00007?ooool2o`0000Gooooo0_l0000Kooooo`00:Oooool00ol0
003oooooooooo`0Sooooo`;o00001?ooool2o`0001Gooooo1?l0000=ooooo`;o00003oooool2o`00
00gooooo0_l0001Jooooo`;o00000_ooool2o`000003ooooool0003o000001Sooooo0_l0000>oooo
o`;o00004Oooool2o`0000Gooooo0_l00005ooooo`;o00001?ooool2o`0001Gooooo000Yooooo`;o
00004oooool2o`0000oooooo0_l00005ooooo`;o00005?ooool4o`0002gooooo0_l0000Booooo`;o
00003Oooool2o`0003?ooooo0_l00006ooooo`;o00006oooool2o`0000kooooo0_l0000Aooooo`;o
00004_ooool2o`0001Gooooo000Yooooo`03o`000?oooooooooo01;ooooo0_l0000Fooooo`;o0000
2_ooool2o`0000cooooo0_l0000booooo`?o00002_ooool2o`0000gooooo0_l0000=ooooo`;o0000
8Oooool2o`000003ooooool0003o0000077ooooo000Yooooo`03o`000?oooooooooo033ooooo1?l0
00000ol@413oooooo`000003o`000003oc8b<_o^k^kooooo00;ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP02o`0000Wooooo0_l0000Fooooo`;o00001?ooool7o`000003ooooooo^k^ko<S8b00Co0000
0_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Kooooo0_l00009ooooo`;o00001Oooool01OnHV9So
410@o`000?lb<S;oc<c<00?ooooo00Gok^k^o`000?l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01_ooool4o`0000kooooo0_l0000@ooooo`;o000000?o410@o`000?l000000_l0
00001?lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:Oooool3o`000009
oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`00:Oooool00ol0003oooooooooo`05ooooo`;o00002?ooool2o`0000Gooooo0_l0
000Hooooo`?o00000_ooool2o`000005ogMgMol0003o0000oiRHV?mgMgL00oooool2o`000003oooo
oonHV9SoMgMg00_ooooo0_l00005ooooo`;o00003oooool2o`0000Cooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A003o`000005ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00;o00005?ooool2o`00013ooooo00Go410@o`000?l0003oMgMgoc8b<P03ooooo`05ogMgMol0
003o0000oiRHV?mgMgL00oooool01OmgMgOo0000o`000?nHV9SoMgMg00Kooooo1?l0000>ooooo`;o
00004Oooool00ol0003oooooo`000003o`000004oiRHV?ooooooV9RHogMgM`?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Fooooo`;o00000_ooool2o`0000Sooooo0_l00003ooooo`;o000000?ooooo
ogMgMolb<S800_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`00:Oooool00ol0003oooooooooo`05ooooo`;o00002?ooool2o`0000Gooooo0_l0
00000ooooooo0000o`00000Gooooo`;o000000Coooooo`000?l0003o410@0oooool01?l@413ooooo
ooooooooool2o`0000;ooooo0_l0000Aooooo`;o00005_ooool00onHV9So8B4Qonk^kP02ooooo`;o
000000Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000_l0000D
ooooo`;o00004Oooool2o`000003ooooool0003ooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?l0003o0000ooooool@4100:?ooool5o`0000?ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41005_ooool2o`0000;ooooo0_l00008oooo
o`;o00001oooool01?l0003oooooooooool@4103ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool00ol@413oooooooooo`01ooooo`00:Oooool3o`000003ooooool0003o000001Kooooo0_l0000G
ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooooooo
0_l00005ooooo`;o00007oooool2o`0000;ooooo00?oV9RHob4Q8Oo^k^h00oooool2o`0000;ooooo
0ol000000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo01Cooooo0_l0000Cooooo`03ojVY
ZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool00000:?ooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo0000013ooooo0_l0000Jooooo`05ogMgMolb<S;oooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00Oooool002Wo
oooo1_l0000_ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001_ooool2o`0001oooooo0_l00003ooooo`03ogMgMomVIVKo
oooo00;ooooo0_l00002ooooo`?o000000?oooooo`000?ooool00ol0000@ooooo`;o00000oooool2
o`0000Wooooo0_l00008ooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`;o00000_ooool01?l0003oooooo`000?l0000Uooooo`04omgMgOmEEEGoooooo`0000Co
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000004?ooool2
o`0000;ooooo0_l0000Cooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`00:Oooool01?l0003ooooo
o`000?l0000aooooo`06o`000?oooooo0000o`000?oooooo410@0oooool01Ol@413oooooo`000?l0
003o410@00;o000000?ooooooa0@4?ooool01?ooool2o`0002Kooooo00Go0000oooooooooooooooo
oa0@4003ooooo`06oa0@4?ooooooooooooooool@413ooooo0_l000000ol@413oooooooooo`05oooo
o`;o00001oooool2o`0000?ooooo0_l00008ooooo`?o00002Oooool00onj^[[o8B4Qooooo`02oooo
o`05oa0@4?ooooooooooooooool@41000oooool2o`0000;ooooo1?l0000<ooooo`;o00001Oooool2
o`00017ooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@400Dooooo`Co00004Oooool00ol0003oooooooooo`04ooooo`05oa0@
4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo000Yooooo`03
o`000?oooooooooo00Wooooo0_l0000Qooooo`;o00001?ooool02ol0003oooooo`000?l0003ooooo
ogMgMonHV9SooooooiRHV?mgMgOooooo00;o000000GoMgMgo`000?l0003oV9RHogMgM`05ooooo`;o
00002?ooool2o`0001Sooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo0_l0000Fooooo`;o00001?oo
ool2o`000006ooooool@413oV9RHoooooonj^[[o00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00CoMgMgoiRHV?ooooooV9RH0_l0000>ooooo`;o00001Oooool2o`00017ooooo00?ok^k^
odA4A?l000000_ooool2o`000005ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg01Kooooo0_l00006ooooo`;o00002Oooool01?l0003oooooo`000?l00003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000Yoooo
o`03o`000?oooooooooo00Wooooo0_l0000Looooo`;o00000oooool2o`0000;ooooo00?oEEEEofIV
I_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0?ooooo`;o00006?ooool3o`000003ob4Q8Oo<c<cooooo00;ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02_ooool2o`0001Wooooo0_l000001_oooooo
ZJVYoa0@4?l0003o410@ojVYZ@?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h0:_ooool01?mgMgOo0000ooooooooool2o`000005onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01kooooo0_l000000ooooooo0000o`000002
ooooo`;o00000_ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool002Wooooo0_l0000=ooooo`;o00006Oooool2o`0003gooooo0_l0
0005ooooo`;o00007Oooool2o`0004Gooooo0ol00003ooooo`;o00005?ooool2o`0000Oooooo0_l0
000>ooooo`;o00002_ooool2o`0000Oooooo0_l00002ooooo`;o00006Oooool002Wooooo00?o0000
ooooooooool03?ooool2o`0000?ooooo0_l0000Hooooo`;o0000>Oooool2o`0001Wooooo0_l0000O
ooooo`;o00002_ooool2o`0001gooooo0_l00004ooooo`?o00000oooool2o`0001Cooooo0_l00007
ooooo`;o00003_ooool2o`0000[ooooo0_l0000Vooooo`00:Oooool00ol0003oooooooooo`0Aoooo
o`;o00006?ooool2o`0002Cooooo0_l0000Kooooo`;o00004Oooool2o`0001oooooo0_l00004oooo
o`;o00001?ooool2o`0001gooooo0_l0000`ooooo`;o00007_ooool2o`0001_ooooo000Yooooo`03
o`000?oooooooooo057ooooo0_l0000Cooooo`;o00001_ooool2o`0002cooooo0_l0000:ooooo`;o
00000oooool2o`0001Cooooo0_l0000Fooooo`;o00008_ooool2o`0000_ooooo0_l0000Aooooo`;o
00002_ooool2o`0000oooooo000Yooooo`03o`000?oooooooooo00?ooooo0_l0000@ooooo`;o0000
Coooool2o`0001Cooooo0_l00009ooooo`;o00004oooool2o`000003ooooool0003o000000cooooo
0_l0000:ooooo`;o00001_ooool4o`0001Kooooo0_l0000Qooooo`;o000000?oooooo`000?l00000
2Oooool2o`0001gooooo0_l0000?ooooo`008Oooooooo`0004Co00001?ooool002Wooooo00?o0000
ooooooooool00_l00007ooooo`Oo00001_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Cooooo0_l00003ooooo`03o`000?oooooooooo00Gooooo0_l00002ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`;o00001?ooool0
1?l0003oooooooooooooool2o`0000Kooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`04o`0000Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02o`0000Oooooo0ol0
0009ooooo`04o`000?ooooooooooooooo`;o000000?oooooo`000?l000000_ooool2o`0000cooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;o0000
0_ooool2o`0000;ooooo0_l0000<ooooo`00:Oooool00ol0003oooooooooo`0;ooooo`;o000000?o
ooooo`000?l00000:_ooool00ol0003oooooooooo`0;ooooo`;o00002_ooool2o`0000Gooooo0_l0
000Kooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0;oooool2o`000003ooooool0
003o000000Kooooo00Co0000oooooooooooooooo0_l000000ooooooo0000o`000002ooooo`;o0000
2oooool2o`0001[ooooo0_l00006ooooo`;o00003?ooool002Wooooo00?o0000ooooooooool06ooo
ool2o`0002_ooooo0_l0000:ooooo`;o00001Oooool2o`0001[ooooo0_l0001Oooooo`;o00001_oo
ool2o`0000Sooooo0_l00008ooooo`;o00005?ooool2o`00033ooooo000Yooooo`03o`000?oooooo
oooo00Kooooo0_l0000Cooooo`;o00002oooool2o`0000Wooooo0_l0000Cooooo`;o00000_ooool2
o`0000gooooo0_l0000Jooooo`Co00007oooool2o`0000kooooo0_l0000Oooooo`;o00002oooool2
o`0000Cooooo1?l0000Booooo`;o00001_ooool2o`0000oooooo0_l0000Dooooo`;o00005oooool0
02Wooooo0_l00007ooooo`;o00007_ooool4o`0000Oooooo1?l0000Gooooo`;o0000:oooool2o`00
0003ooooool0003o000000Cooooo0_l0000Fooooo`;o00003_ooool2o`0001oooooo0_l0000Aoooo
o`;o00000_ooool2o`0000kooooo0_l00008ooooo`;o00003oooool2o`0001Cooooo0_l0000Goooo
o`00:Oooool00ol0003oooooooooo`07ooooo`;o00007Oooool2o`0000Wooooo0_l0000hooooo`;o
000000?oooooo`000?l000003?ooool3o`0000?ooooo0_l0000gooooo`;o00003_ooool2o`0001Go
oooo0_l0000>ooooo`;o000000?oooooo`000?l000000_ooool2o`0001Cooooo0_l0000[ooooo`00
:Oooool00ol0003oooooooooo`07ooooo`;o0000?Oooool2o`0001Wooooo0_l00005ooooo`;o0000
00Coooooo`000?l0003ooooo0_l0000=ooooo`;o00001?ooool2o`0000Sooooo0_l000000ooooooo
0000o`00000<ooooo`;o00001oooool2o`0001;ooooo0_l0000Cooooo`Co00008Oooool2o`0000;o
oooo0_l0000Dooooo`;o0000:oooool002Wooooo00?o0000ooooooooool01?ooool2o`0000Oooooo
0_l0000Pooooo`;o00005Oooool2o`00013ooooo0_l00007ooooo`;o00001Oooool2o`0000Oooooo
0_l0000:ooooo`;o00001?ooool2o`0000Kooooo1?l000000ooooooo0000o`00000<ooooo`;o0000
1oooool2o`0001Cooooo0_l0000Aooooo`Co00003Oooool2o`00017ooooo0_l000000ooooooo0000
o`00000Nooooo`;o00002_ooool2o`0001Oooooo000Yooooo`04o`000?oooooo0000o`0000?ooooo
0_l00007ooooo`;o00008?ooool2o`0000gooooo0_l000000ooooooo0000o`00000Eooooo`;o0000
5oooool2o`0000[ooooo0_l0000<ooooo`;o00007Oooool2o`00017ooooo0_l00004ooooo`;o0000
7?ooool2o`0000cooooo0_l00003ooooo`;o000000?oooooo`000?l000001_ooool2o`000003oooo
ool0003o000000Gooooo0_l0000<ooooo`;o00002_ooool2o`0001Oooooo000Yooooo`Co0000?Ooo
ool2o`000003ooooool0003o000000Kooooo0_l00005ooooo`;o0000DOooool2o`0000Cooooo0ol0
000Gooooo`;o00005oooool2o`00017ooooo0_l0000>ooooo`;o000000?oooooo`000?l000000_l0
0003ooooo`;o00004Oooool2o`0001kooooo000Yooooo`03o`000?oooooooooo04Wooooo0_l00005
ooooo`;o00003Oooool2o`0004;ooooo0_l00004ooooo`;o00004_ooool2o`0000Wooooo0_l00004
ooooo`;o00003?ooool2o`000003ooooool0003o000002?ooooo0_l0000Fooooo`;o00007_ooool0
02Wooooo00?o0000ooooooooool01Oooool2o`0000gooooo0_l0000mooooo`;o00001Oooool2o`00
00?ooooo0_l00009ooooo`;o00007_ooool2o`00037ooooo0_l00002ooooo`;o00001Oooool2o`00
00Cooooo0_l0000?ooooo`;o00006oooool2o`0001Kooooo0_l0000Vooooo`00:Oooool00ol0003o
ooooooooo`05ooooo`Co00002oooool2o`0002Sooooo0_l0000Cooooo`Co00000oooool4o`0000Wo
oooo0_l000000ooooooo0000o`00000Nooooo`;o00003_ooool2o`00017ooooo0_l0000Booooo`;o
0000:Oooool2o`0000Cooooo0_l00008ooooo`;o00005_ooool2o`0000Sooooo0_l00009ooooo`;o
00004Oooool002Wooooo00?o0000ooooooooool01oooool5o`000003ooooool0003o000000Gooooo
0_l0000:ooooo`;o00001_ooool2o`0001Cooooo0_l0000>ooooo`;o00001Oooool2o`0000Gooooo
0_l00006ooooo`;o000000?oooooo`000?l000000oooool2o`00027ooooo0_l00002ooooo`;o0000
00?oooooo`000?l000000_ooool2o`00017ooooo0_l00006ooooo`;o00009Oooool2o`0000_ooooo
0_l000000ooooooo0000o`000004ooooo`;o00004?ooool2o`0001Kooooo1?l00009ooooo`;o0000
4Oooool002Wooooo0_l00009ooooo`Co000000?oooooo`000?l000001Oooool2o`0000[ooooo0_l0
00000ooooooo0000o`000002ooooo`Go000000?oooooo`000?l000007oooool2o`0000Cooooo0_l0
000:ooooo`;o00000_ooool2o`0000Kooooo0_l0000Qooooo`;o00000_ooool2o`000004ooooool0
003o0000o`0001cooooo0_l0000Uooooo`;o00002?ooool2o`000003ooooool0003o000001Wooooo
0_l0000Fooooo`;o00002_ooool2o`0000?ooooo0_l0000=ooooo`00:Oooool00ol0003ooooooooo
o`0Sooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o00007_ooool2o`0000Gooooo
0_l00007ooooo`;o000000?oooooo`000?l000007Oooool2o`0001Kooooo0_l0000Sooooo`;o0000
6_ooool2o`0000cooooo0_l0000Vooooo`;o00006?ooool2o`0000?ooooo0_l0000=ooooo`00:Ooo
ool00ol0003oooooooooo`1=ooooo`;o00003_ooool2o`0001Oooooo0_l00007ooooo`;o0000>ooo
ool2o`0001[ooooo0_l0000=ooooo`;o00009Oooool2o`0001oooooo0_l0000;ooooo`00:Oooool0
0ol0003oooooooooo`0]ooooo`;o00001?ooool2o`00047ooooo0_l0000Mooooo`;o00006oooool2
o`0000;ooooo0_l0000_ooooo`;o00006_ooool2o`0001?ooooo0_l00008ooooo`;o00002oooool2
o`0000_ooooo000Yooooo`03o`000?oooooooooo01[ooooo0_l0000Aooooo`;o00001?ooool2o`00
00Gooooo0ol0001Hooooo`;o00003_ooool2o`0000_ooooo0_l00002ooooo`;o00003Oooool2o`00
00?ooooo0_l0000Oooooo`;o00005_ooool2o`0001?ooooo0_l00008ooooo`;o00006?ooool002Wo
oooo0_l0000Fooooo`;o00000oooool4o`0001cooooo0ol0000>ooooo`;o00008_ooool2o`0001?o
oooo0_l0000Oooooo`;o00002Oooool2o`0001?ooooo0_l00003ooooo`;o00007oooool2o`0004oo
oooo000Yooooo`03o`000?oooooooooo00Cooooo0_l00004ooooo`;o00002Oooool2o`0000Gooooo
0_l00003ooooo`;o00006?ooool2o`0000kooooo0_l0000<ooooo`;o00005?ooool2o`0001?ooooo
0_l00007ooooo`;o00003_ooool2o`000003ooooool0003o000000kooooo0_l0000Wooooo`;o0000
0oooool2o`0001Oooooo0_l00013ooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooooooo
ool01?ooool2o`0000Cooooo0_l0000Eooooo`;o00006?ooool2o`0001cooooo0_l0000Aooooo`;o
00007oooool2o`0000kooooo0_l000000ooooooo0000o`00000:ooooo`;o00004Oooool2o`0001So
oooo0ol00002ooooo`;o00005oooool2o`0004?ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool06?ooool2o`0005;ooooo0_l0000nooooo`;o00004Oooool2o`00
01;ooooo0_l000000ooooooo0000o`000002ooooo`;o0000;_ooool2o`0000Wooooo0_l0000Uoooo
o`001_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo01Sooooo0_l0001Zooooo`;o0000COooool2o`00
0003ooooool0003o000003;ooooo0_l00009ooooo`;o00004Oooool2o`0001;ooooo0006ooooo`05
o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo
00Cooooo0ol0001Yooooo`;o00006Oooool2o`0001[ooooo0_l00026ooooo`;o00004_ooool000Ko
oooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo06Wooooo0_l0000eooooo`;o0000@oooool2
o`0005Gooooo0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Oooooo0_l0000@ooooo`;o00007Oooool2o`0000Oooooo0_l0000/
ooooo`;o0000?oooool2o`00023ooooo0_l00006ooooo`;o00004oooool2o`0003;ooooo0_l0000Q
ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@
4004ooooo`03o`000?oooooooooo00Oooooo0_l0000@ooooo`;o00001_ooool2o`0001Gooooo0_l0
0007ooooo`;o000000?oooooo`000?l000003oooool2o`0000oooooo0_l000000ooooooo0000o`00
0002ooooo`Co00006_ooool2o`0001;ooooo0_l0000?ooooo`;o00006?ooool2o`0000Kooooo0_l0
0006ooooo`;o00004Oooool2o`00017ooooo0_l0000Qooooo`;o00000_ooool2o`0001gooooo0006
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo
1?l00006ooooo`;o00006?ooool2o`00027ooooo1?l0000=ooooo`Co00000oooool2o`0000Sooooo
0_l000000ooooooo0000o`000002ooooo`;o00005_ooool2o`0000Cooooo0_l0000=ooooo`;o0000
0oooool2o`00027ooooo0_l00006ooooo`;o00008Oooool2o`00017ooooo0_l00009ooooo`;o0000
1?ooool2o`0000cooooo0_l00006ooooo`;o00003?ooool2o`0000oooooo000Yooooo`;o00008?oo
ool2o`0000?ooooo0_l0000Fooooo`;o00003oooool2o`000003ooooool0003o000000;o00009ooo
ool2o`0000cooooo0_l00004ooooo`?o00001oooool2o`000003ooooool0003o000001[ooooo0_l0
000?ooooo`;o000000?oooooo`000?l000004Oooool2o`0000?ooooo0_l0000Kooooo`;o00000ooo
ool3o`0000cooooo0_l0000Dooooo`;o00003oooool002Wooooo00?o0000ooooooooool07oooool2
o`0000?ooooo0_l0000Zooooo`;o00005oooool2o`0001kooooo0_l00004ooooo`;o00002?ooool2
o`000003ooooool0003o000002_ooooo0_l000000ooooooo0000o`00000Aooooo`;o00000oooool2
o`0001oooooo0ol0000dooooo`00:Oooool01?l0003oooooooooooooool2o`0006Kooooo0_l0002J
ooooo`;o00003?ooool2o`0002Oooooo000Yooooo`04o`000?ooooooooooooooo`;o00003Oooool2
o`0002?ooooo0_l0000?ooooo`;o0000boooool2o`0002Oooooo000Yooooo`03o`000?oooooooooo
013ooooo0_l000000ooooooo0000o`00000Pooooo`;o00003oooool2o`0001Kooooo0_l0000Doooo
o`;o0000=Oooool2o`0008oooooo000Yooooo`;o00005?ooool2o`0004Wooooo0_l0000Dooooo`;o
0000=Oooool2o`0002Cooooo0_l0000Cooooo`;o000000?oooooo`000?l00000DOooool002Wooooo
00?o0000ooooooooool0<?ooool2o`0009oooooo0_l0000Aooooo`Co000000?oooooo`000?l00000
DOooool002Wooooo00?o0000ooooooooool07oooool2o`0000oooooo0_l00021ooooo`;o00008Ooo
ool2o`0000cooooo0_l0000Yooooo`;o00002_ooool2o`0001oooooo000Yooooo`03o`000?oooooo
oooo01oooooo0_l0000eooooo`;o00002oooool2o`0004kooooo0_l0000Qooooo`;o0000<Oooool2
o`0000Cooooo0_l0000:ooooo`;o00007oooool002Wooooo00?o0000ooooooooool00_ooool2o`00
01cooooo0_l0000dooooo`;o00001_ooool2o`0000?ooooo0_l0000:ooooo`;o00001_ooool2o`00
00cooooo0_l0000Zooooo`?o0000EOooool2o`0001cooooo0_l00003ooooo`;o00003_ooool002Wo
oooo0_l00003ooooo`;o00003?ooool2o`0000kooooo0_l00003ooooo`;o00006_ooool2o`0000;o
oooo0_l0000Gooooo`;o00003oooool2o`0000Kooooo0_l0000<ooooo`;o0000:_ooool3o`0002oo
oooo0_l00012ooooo`;o00000oooool2o`0000kooooo000Yooooo`03o`000?oooooooooo013ooooo
0_l0000:ooooo`;o00001oooool2o`00017ooooo0_l00007ooooo`;o00000_ooool2o`0004gooooo
0_l00007ooooo`;o00002Oooool2o`0000kooooo1?l0000Wooooo`;o0000Eoooool002Wooooo00?o
0000ooooooooool06_ooool4o`0001[ooooo0_l0000;ooooo`;o0000:Oooool2o`0002;ooooo0_l0
0007ooooo`;o00002Oooool2o`0000kooooo1?l0000dooooo`;o0000B_ooool002Wooooo00?o0000
ooooooooool06_ooool2o`0005Cooooo0_l00008ooooo`;o0000M?ooool2o`0004[ooooo000Yoooo
o`03o`000?oooooooooo07[ooooo0_l0000@ooooo`;o0000[_ooool002Wooooo0_l0002=ooooo`;o
0000[_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`2fooooo`;o0000Q?ooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;Kooooo0_l00024ooooo`00
3_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oo
oooo?Oooool000kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0Eoooool2o`000>?ooooo000>ooooo`05o`000?ooooooooooooooool0
00003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0Eoooool2o`00
09[ooooo0_l00017ooooo`003_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`3?ooooo`;o00008_ooool2o`0004Oooooo000>ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
0<oooooo0_l0000jooooo`;o0000;oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`Co00001_ooool2o`0001kooooo0_l0000<ooooo`;o0000^oooool2o`00027ooooo0_l0000_oooo
o`00:Oooool00ol0003oooooooooo`0Mooooo`;o00003?ooool2o`0000cooooo0_l00008ooooo`;o
0000Xoooool2o`0005;ooooo000Yooooo`03o`000?oooooooooo03Wooooo0_l00008ooooo`;o0000
iOooool2o`00013ooooo000Yooooo`03o`000?oooooooooo0?oooooo2?ooool2o`00027ooooo0_l0
000@ooooo`00:Oooool00ol0003oooooooooo`3oooooo`Sooooo0_l0000cooooo`00:Oooool2o`00
0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`00
0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo
00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooooooo
ool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03
oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgo
oooo0006ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03
o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`000?ooooooooooooooool0
00003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?oo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolmoooo
o`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`007oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0
oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo?Ooo
ool0027ooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`007oooool0
0omEEEGoIVIVo`00003oooooodOooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .34807 Mdot
.02762 .40017 Mdot
.02952 .3076 Mdot
.03143 .30552 Mdot
.03333 .34565 Mdot
.03524 .24061 Mdot
.03714 .27905 Mdot
.03905 .44901 Mdot
.04095 .43323 Mdot
.04286 .29619 Mdot
.04476 .25448 Mdot
.04667 .43712 Mdot
.04857 .39881 Mdot
.05048 .26464 Mdot
.05238 .42229 Mdot
.05429 .34428 Mdot
.05619 .37842 Mdot
.0581 .39675 Mdot
.06 .34815 Mdot
.0619 .23443 Mdot
.06381 .38636 Mdot
.06571 .4065 Mdot
.06762 .40108 Mdot
.06952 .3892 Mdot
.07143 .3945 Mdot
.07333 .24784 Mdot
.07524 .27652 Mdot
.07714 .3458 Mdot
.07905 .23173 Mdot
.08095 .40201 Mdot
.08286 .36478 Mdot
.08476 .43273 Mdot
.08667 .44622 Mdot
.08857 .36289 Mdot
.09048 .33419 Mdot
.09238 .24775 Mdot
.09429 .34878 Mdot
.09619 .32712 Mdot
.0981 .24916 Mdot
.1 .43715 Mdot
.1019 .40399 Mdot
.10381 .35142 Mdot
.10571 .2703 Mdot
.10762 .35489 Mdot
.10952 .31845 Mdot
.11143 .29641 Mdot
.11333 .26395 Mdot
.11524 .41347 Mdot
.11714 .32232 Mdot
.11905 .2334 Mdot
.12095 .41255 Mdot
.12286 .27286 Mdot
.12476 .43084 Mdot
.12667 .29686 Mdot
.12857 .2995 Mdot
.13048 .44194 Mdot
.13238 .44705 Mdot
.13429 .3793 Mdot
.13619 .38757 Mdot
.1381 .30629 Mdot
.14 .2801 Mdot
.1419 .27193 Mdot
.14381 .25717 Mdot
.14571 .30913 Mdot
.14762 .4414 Mdot
.14952 .43858 Mdot
.15143 .30005 Mdot
.15333 .34195 Mdot
.15524 .32589 Mdot
.15714 .3771 Mdot
.15905 .38207 Mdot
.16095 .2877 Mdot
.16286 .28632 Mdot
.16476 .32431 Mdot
.16667 .25712 Mdot
.16857 .27333 Mdot
.17048 .4311 Mdot
.17238 .25098 Mdot
.17429 .25675 Mdot
.17619 .31843 Mdot
.1781 .31586 Mdot
.18 .4008 Mdot
.1819 .29176 Mdot
.18381 .3493 Mdot
.18571 .44842 Mdot
.18762 .34586 Mdot
.18952 .34236 Mdot
.19143 .3171 Mdot
.19333 .37731 Mdot
.19524 .34252 Mdot
.19714 .38933 Mdot
.19905 .31187 Mdot
.20095 .27152 Mdot
.20286 .31322 Mdot
.20476 .2812 Mdot
.20667 .28361 Mdot
.20857 .26763 Mdot
.21048 .41689 Mdot
.21238 .43719 Mdot
.21429 .37826 Mdot
.21619 .3629 Mdot
.2181 .36924 Mdot
.22 .43399 Mdot
.2219 .36805 Mdot
.22381 .34632 Mdot
.22571 .35806 Mdot
.22762 .37958 Mdot
.22952 .35589 Mdot
.23143 .27077 Mdot
.23333 .3727 Mdot
.23524 .28108 Mdot
.23714 .29665 Mdot
.23905 .43163 Mdot
.24095 .25005 Mdot
.24286 .48952 Mdot
.24476 .27371 Mdot
.24667 .26286 Mdot
.24857 .4428 Mdot
.25048 .43859 Mdot
.25238 .34988 Mdot
.25429 .3976 Mdot
.25619 .3114 Mdot
.2581 .38873 Mdot
.26 .23179 Mdot
.2619 .37402 Mdot
.26381 .31949 Mdot
.26571 .23904 Mdot
.26762 .25352 Mdot
.26952 .3894 Mdot
.27143 .27797 Mdot
.27333 .40411 Mdot
.27524 .37727 Mdot
.27714 .42771 Mdot
.27905 .24039 Mdot
.28095 .2529 Mdot
.28286 .24131 Mdot
.28476 .32654 Mdot
.28667 .23201 Mdot
.28857 .28848 Mdot
.29048 .44327 Mdot
.29238 .42249 Mdot
.29429 .22531 Mdot
.29619 .26251 Mdot
.2981 .33592 Mdot
.3 .37867 Mdot
.3019 .24123 Mdot
.30381 .44701 Mdot
.30571 .49613 Mdot
.30762 .35733 Mdot
.30952 .30828 Mdot
.31143 .3416 Mdot
.31333 .3647 Mdot
.31524 .29539 Mdot
.31714 .38945 Mdot
.31905 .27953 Mdot
.32095 .26614 Mdot
.32286 .31396 Mdot
.32476 .26163 Mdot
.32667 .44235 Mdot
.32857 .35153 Mdot
.33048 .31686 Mdot
.33238 .27065 Mdot
.33429 .25382 Mdot
.33619 .41904 Mdot
.3381 .2676 Mdot
.34 .26478 Mdot
.3419 .36097 Mdot
.34381 .44607 Mdot
.34571 .33598 Mdot
.34762 .32126 Mdot
.34952 .30596 Mdot
.35143 .23261 Mdot
.35333 .26094 Mdot
.35524 .30913 Mdot
.35714 .337 Mdot
.35905 .3587 Mdot
.36095 .44387 Mdot
.36286 .27433 Mdot
.36476 .26292 Mdot
.36667 .27338 Mdot
.36857 .23546 Mdot
.37048 .2837 Mdot
.37238 .42851 Mdot
.37429 .3403 Mdot
.37619 .39974 Mdot
.3781 .31422 Mdot
.38 .43135 Mdot
.3819 .25401 Mdot
.38381 .43066 Mdot
.38571 .4211 Mdot
.38762 .26214 Mdot
.38952 .33486 Mdot
.39143 .24193 Mdot
.39333 .32391 Mdot
.39524 .28051 Mdot
.39714 .44881 Mdot
.39905 .38754 Mdot
.40095 .43187 Mdot
.40286 .32015 Mdot
.40476 .34162 Mdot
.40667 .37462 Mdot
.40857 .29676 Mdot
.41048 .29299 Mdot
.41238 .29527 Mdot
.41429 .34472 Mdot
.41619 .3592 Mdot
.4181 .37115 Mdot
.42 .33291 Mdot
.4219 .24487 Mdot
.42381 .28878 Mdot
.42571 .32618 Mdot
.42762 .25467 Mdot
.42952 .40724 Mdot
.43143 .25379 Mdot
.43333 .33427 Mdot
.43524 .34185 Mdot
.43714 .36486 Mdot
.43905 .25967 Mdot
.44095 .41594 Mdot
.44286 .31346 Mdot
.44476 .30143 Mdot
.44667 .44211 Mdot
.44857 .26738 Mdot
.45048 .39601 Mdot
.45238 .34557 Mdot
.45429 .296 Mdot
.45619 .3428 Mdot
.4581 .35634 Mdot
.46 .39513 Mdot
.4619 .26327 Mdot
.46381 .42197 Mdot
.46571 .307 Mdot
.46762 .33827 Mdot
.46952 .31781 Mdot
.47143 .36811 Mdot
.47333 .35241 Mdot
.47524 .27024 Mdot
.47714 .32029 Mdot
.47905 .318 Mdot
.48095 .37501 Mdot
.48286 .39465 Mdot
.48476 .37284 Mdot
.48667 .26911 Mdot
.48857 .24614 Mdot
.49048 .31483 Mdot
.49238 .38205 Mdot
.49429 .43343 Mdot
.49619 .28572 Mdot
.4981 .3145 Mdot
.5 .37236 Mdot
.5019 .3821 Mdot
.50381 .25657 Mdot
.50571 .38972 Mdot
.50762 .27506 Mdot
.50952 .32131 Mdot
.51143 .33032 Mdot
.51333 .25161 Mdot
.51524 .30506 Mdot
.51714 .29187 Mdot
.51905 .27373 Mdot
.52095 .44594 Mdot
.52286 .40231 Mdot
.52476 .33861 Mdot
.52667 .26955 Mdot
.52857 .28629 Mdot
.53048 .2653 Mdot
.53238 .36341 Mdot
.53429 .33675 Mdot
.53619 .25789 Mdot
.5381 .24169 Mdot
.54 .23743 Mdot
.5419 .27039 Mdot
.54381 .24524 Mdot
.54571 .29256 Mdot
.54762 .30112 Mdot
.54952 .328 Mdot
.55143 .30848 Mdot
.55333 .33927 Mdot
.55524 .36143 Mdot
.55714 .4177 Mdot
.55905 .25371 Mdot
.56095 .25621 Mdot
.56286 .24024 Mdot
.56476 .27741 Mdot
.56667 .33084 Mdot
.56857 .35274 Mdot
.57048 .43814 Mdot
.57238 .35691 Mdot
.57429 .26929 Mdot
.57619 .35161 Mdot
.5781 .27147 Mdot
.58 .30089 Mdot
.5819 .32654 Mdot
.58381 .25539 Mdot
.58571 .3847 Mdot
.58762 .43048 Mdot
.58952 .38915 Mdot
.59143 .30525 Mdot
.59333 .37148 Mdot
.59524 .29066 Mdot
.59714 .29285 Mdot
.59905 .42513 Mdot
.60095 .49593 Mdot
.60286 .31527 Mdot
.60476 .26618 Mdot
.60667 .37943 Mdot
.60857 .43336 Mdot
.61048 .4034 Mdot
.61238 .25965 Mdot
.61429 .41718 Mdot
.61619 .25515 Mdot
.6181 .31547 Mdot
.62 .40592 Mdot
.6219 .37856 Mdot
.62381 .39822 Mdot
.62571 .34992 Mdot
.62762 .26748 Mdot
.62952 .31498 Mdot
.63143 .35646 Mdot
.63333 .44045 Mdot
.63524 .26512 Mdot
.63714 .42537 Mdot
.63905 .33865 Mdot
.64095 .22203 Mdot
.64286 .33284 Mdot
.64476 .24007 Mdot
.64667 .34941 Mdot
.64857 .27342 Mdot
.65048 .35758 Mdot
.65238 .30944 Mdot
.65429 .29213 Mdot
.65619 .38013 Mdot
.6581 .44562 Mdot
.66 .32937 Mdot
.6619 .28484 Mdot
.66381 .40785 Mdot
.66571 .28112 Mdot
.66762 .29711 Mdot
.66952 .39669 Mdot
.67143 .24077 Mdot
.67333 .26425 Mdot
.67524 .27147 Mdot
.67714 .34734 Mdot
.67905 .41511 Mdot
.68095 .25818 Mdot
.68286 .39739 Mdot
.68476 .30535 Mdot
.68667 .44445 Mdot
.68857 .27076 Mdot
.69048 .23295 Mdot
.69238 .40363 Mdot
.69429 .25972 Mdot
.69619 .27698 Mdot
.6981 .22646 Mdot
.7 .43964 Mdot
.7019 .36724 Mdot
.70381 .24379 Mdot
.70571 .30138 Mdot
.70762 .37356 Mdot
.70952 .23352 Mdot
.71143 .35806 Mdot
.71333 .43928 Mdot
.71524 .22156 Mdot
.71714 .31009 Mdot
.71905 .42782 Mdot
.72095 .42299 Mdot
.72286 .4064 Mdot
.72476 .31224 Mdot
.72667 .34385 Mdot
.72857 .42066 Mdot
.73048 .44676 Mdot
.73238 .31572 Mdot
.73429 .34363 Mdot
.73619 .26269 Mdot
.7381 .24416 Mdot
.74 .35861 Mdot
.7419 .42166 Mdot
.74381 .3744 Mdot
.74571 .36156 Mdot
.74762 .30744 Mdot
.74952 .40174 Mdot
.75143 .35532 Mdot
.75333 .40401 Mdot
.75524 .40496 Mdot
.75714 .49357 Mdot
.75905 .36354 Mdot
.76095 .26954 Mdot
.76286 .27717 Mdot
.76476 .36293 Mdot
.76667 .3759 Mdot
.76857 .29582 Mdot
.77048 .42827 Mdot
.77238 .37518 Mdot
.77429 .3129 Mdot
.77619 .31661 Mdot
.7781 .24848 Mdot
.78 .27885 Mdot
.7819 .41729 Mdot
.78381 .34694 Mdot
.78571 .28179 Mdot
.78762 .42695 Mdot
.78952 .3742 Mdot
.79143 .40819 Mdot
.79333 .37321 Mdot
.79524 .35884 Mdot
.79714 .3599 Mdot
.79905 .30739 Mdot
.80095 .44537 Mdot
.80286 .43754 Mdot
.80476 .27384 Mdot
.80667 .25981 Mdot
.80857 .26434 Mdot
.81048 .34594 Mdot
.81238 .36563 Mdot
.81429 .32184 Mdot
.81619 .2731 Mdot
.8181 .27017 Mdot
.82 .30019 Mdot
.8219 .26805 Mdot
.82381 .33192 Mdot
.82571 .36671 Mdot
.82762 .27871 Mdot
.82952 .33277 Mdot
.83143 .32646 Mdot
.83333 .44391 Mdot
.83524 .30205 Mdot
.83714 .32766 Mdot
.83905 .37944 Mdot
.84095 .29094 Mdot
.84286 .27169 Mdot
.84476 .31294 Mdot
.84667 .36411 Mdot
.84857 .29852 Mdot
.85048 .3817 Mdot
.85238 .4797 Mdot
.85429 .36108 Mdot
.85619 .3321 Mdot
.8581 .43606 Mdot
.86 .41736 Mdot
.8619 .25678 Mdot
.86381 .40315 Mdot
.86571 .41972 Mdot
.86762 .25951 Mdot
.86952 .32033 Mdot
.87143 .35774 Mdot
.87333 .29215 Mdot
.87524 .30288 Mdot
.87714 .32871 Mdot
.87905 .3214 Mdot
.88095 .31422 Mdot
.88286 .35677 Mdot
.88476 .29607 Mdot
.88667 .26759 Mdot
.88857 .33256 Mdot
.89048 .44855 Mdot
.89238 .26451 Mdot
.89429 .2475 Mdot
.89619 .39434 Mdot
.8981 .31984 Mdot
.9 .24255 Mdot
.9019 .3379 Mdot
.90381 .37749 Mdot
.90571 .24634 Mdot
.90762 .31302 Mdot
.90952 .44522 Mdot
.91143 .39231 Mdot
.91333 .257 Mdot
.91524 .37 Mdot
.91714 .2714 Mdot
.91905 .37687 Mdot
.92095 .23369 Mdot
.92286 .36258 Mdot
.92476 .35205 Mdot
.92667 .27636 Mdot
.92857 .36525 Mdot
.93048 .28237 Mdot
.93238 .25144 Mdot
.93429 .27418 Mdot
.93619 .27542 Mdot
.9381 .31975 Mdot
.94 .30829 Mdot
.9419 .33706 Mdot
.94381 .3023 Mdot
.94571 .25933 Mdot
.94762 .28458 Mdot
.94952 .24891 Mdot
.95143 .43905 Mdot
.95333 .34961 Mdot
.95524 .32758 Mdot
.95714 .3271 Mdot
.95905 .34734 Mdot
.96095 .32336 Mdot
.96286 .48781 Mdot
.96476 .32443 Mdot
.96667 .39856 Mdot
.96857 .40014 Mdot
.97048 .26573 Mdot
.97238 .33123 Mdot
.97429 .23186 Mdot
.97619 .43196 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0=_ooooo0_l0001Oooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool0`oooool2o`0001Kooooo0_l0001Oooooo`001_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo05?ooooo0_l0001^ooooo`;o00004?ooool2o`0006Gooooo0004
o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`1Cooooo`;o0000P?ooool2o`0006Gooooo0006
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol0000>ooooo`;o00002oooool2o`0002_ooooo0_l00007ooooo`;o00004ooo
ool2o`0006_ooooo0_l00004ooooo`;o0000@_ooool2o`0000oooooo0_l0000<ooooo`001_ooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool02Oooool2o`0000?ooooo0_l0000;ooooo`;o0000
:oooool2o`0000Oooooo0_l0000Cooooo`;o00000oooool2o`0006Kooooo0_l00004ooooo`;o0000
@_ooool2o`0000oooooo0_l0000<ooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo
0_l0000oooooo`;o00000_ooool2o`0001_ooooo0_l0000eooooo`;o00001_ooool2o`0001Sooooo
0_l0001fooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo
V9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_l00018ooooo`;o
00000_ooool4o`0000Cooooo0_l0000Jooooo`;o0000;_ooool2o`0000Kooooo0_l0000Hooooo`;o
00001oooool2o`0004Oooooo0_l0000Tooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`02o`00
04kooooo0_l00004ooooo`;o00006_ooool2o`0000Sooooo0_l0000Dooooo`;o00003_ooool3o`00
02Sooooo0_l00008ooooo`;o00002Oooool2o`0003;ooooo1?l0000Rooooo`00:Oooool2o`0000go
oooo0_l00004ooooo`Co0000I_ooool2o`0001Cooooo0_l0000?ooooo`;o0000<_ooool2o`0000Wo
oooo0_l0000;ooooo`;o00008oooool2o`0000;ooooo0_l0000<ooooo`;o00005?ooool002Wooooo
00?o0000ooooooooool03?ooool2o`0000Cooooo1?l0000Fooooo`;o00005?ooool2o`0005Kooooo
0_l0001Cooooo`;o00008oooool2o`0000[ooooo0_l00004ooooo`;o00005?ooool002Wooooo00?o
0000ooooooooool00oooool2o`0002Oooooo0_l0000Dooooo`;o00001oooool2o`0000;ooooo0_l0
000?ooooo`;o00003Oooool2o`0000gooooo0ol0000Iooooo`;o00003?ooool2o`0000Kooooo0_l0
0009ooooo`;o0000Hoooool2o`0001[ooooo000Yooooo`03o`000?oooooooooo00?ooooo0_l0000N
ooooo`;o00001Oooool2o`000003ooooool0003o000001cooooo0_l00002ooooo`;o00003oooool2
o`0000gooooo0_l0000=ooooo`?o00005_ooool2o`0000Sooooo0_l00005ooooo`?o00001Oooool2
o`0000Wooooo0_l0000Cooooo`;o0000>?ooool2o`0000kooooo0_l0000Pooooo`00:Oooool00ol0
003oooooooooo`0Sooooo`;o00001Oooool2o`000003ooooool0003o000002kooooo0_l00007oooo
o`;o00002Oooool2o`0000oooooo0_l0000Cooooo`;o00002?ooool2o`0000Kooooo0_l0000?oooo
o`;o00005?ooool2o`0000;ooooo0_l0000Rooooo`;o00004?ooool4o`0000cooooo0_l00009oooo
o`;o00005Oooool002Wooooo0_l00006ooooo`;o00004_ooool2o`0002Wooooo0_l0000>ooooo`;o
00001oooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`0000Gooooo0_l0000?ooooo`;o
00001Oooool2o`0002oooooo0_l00005ooooo`;o00002_ooool2o`0000Gooooo0_l0000;ooooo`;o
00005Oooool3o`00017ooooo0_l00006ooooo`;o00003oooool2o`0001Gooooo000Yooooo`03o`00
0?oooooooooo00Gooooo0_l0000Booooo`;o00007Oooool2o`0000[ooooo0_l0000>ooooo`;o0000
1_ooool2o`0000?ooooo0ol00006ooooo`;o00006Oooool2o`0000;ooooo0_l0000Dooooo`;o0000
5_ooool2o`0000Gooooo0_l000000ooooooo0000o`00000:ooooo`;o00004_ooool2o`0001Kooooo
0_l00002ooooo`;o00004oooool4o`0001Oooooo0_l0000=ooooo`00:Oooool00ol0003ooooooooo
o`0Gooooo`;o00005oooool4o`000004oa0@4?ooooooooooonk^kP;o000000?o<S8bonk^k_ooool0
0_ooool3o`000003oc8b<_o^k^kooooo01Oooooo0_l000000ooooooo0000o`000002o`0000[ooooo
1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo0_l00006ooooo`;o00000_ooool2o`0000_ooooo0ol00002ooooo`;o00001Oooool00onH
V9So410@o`000003o`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02o`000005ooooooo^k^ko
<S8bo`000?lb<S800_l0000>ooooo`;o00000_ooool2o`0001Gooooo0_l000002Ol@413ooooooooo
ooooooook^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ol0000C
ooooo`;o00002?ooool2o`0000Oooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_l0
003o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Yooooo`03o`00
0?oooooooooo01Oooooo0_l00003ooooo`;o00001?ooool2o`0000Oooooo0_l00005ooooo`03o`00
0?oooooooooo00;o000000GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`;o000000CooooooiRHV?l0
003o00006_ooool2o`0000Sooooo1?l000001OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool2o`0000;ooooo
0_l00009ooooo`Co00000oooool2o`0000Gooooo00?o410@okZj^_ooool00ol00002ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo0_l00007oooo
o`;o00000_ooool2o`0001Gooooo0_l00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool2
o`000003oooooonHV9So000000;o00001_ooool2o`0001Kooooo0_l00003ooooo`;o00001Oooool0
2OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool002Wooooo00?o0000ooooooooool03Oooool2o`0000gooooo0_l00004ooooo`;o
00001oooool2o`0000Gooooo00?o0000ooooooooool00_l000001Ol@413ooooooooooooooooo410@
00?ooooo00Co410@oooooooooooooooo0_l0000Tooooo`Co000000CooooooiRHV?lQ8B7ok^k^1?oo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@400Fooooo`;o
00000_ooool2o`0000cooooo0_l00002ooooo`05o`000?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01?ooool2o`0000gooooo0_l0000A
ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00?ooooo0_l00002ooooo`;o00001ooo
ool2o`0001Wooooo1Ol00005ooooo`04o`000?oooooooooooa0@40?ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`03oa0@4?oooooooooo007ooooo000Yooooo`;o00000_ooool2o`0000[ooooo
0_l0000Cooooo`;o00003_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000Sooooo0_l0000=ooooo`;o00004_ooool00onH
V9So8B4Qonk^kP02ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool05?ooool2o`00013ooooo0_l000000oooooooZJVYoa0@4003ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000001Gooooo0_l0000Aooooo`03odA4
A?oMgMgooooo00;o00000oooool2o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04
o`000?ooooooooooooooo`;o00007_ooool2o`000003ooooool0003o000000Cooooo00GoMgMgoc8b
<_ooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`01ooooo`00:Oooool01?l0003oooooooooooooool2o`0001oooooo0_l0000>ooooo`04o`000?oo
ooooooooooooo`?o00000_ooool01?l0003oooooooooooooool3o`000003ooooool0003ooooo00Oo
oooo0_l0000=ooooo`;o00003oooool2o`0000;ooooo00CoMgMgofIVI_oooooooooo0_l00003oooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Xooooo`03oa0@4?l0003o
^[Zj00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
3?ooool2o`0001[ooooo00CogMgMoeEEEOoooooo00001?ooool5o`0000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`;o00007oooool2o`0000?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
000Yooooo`03o`000?oooooooooo02Wooooo0_l00007ooooo`04o`000?ooooooooooooooo`?o0000
0_ooool01Ol@413ooooooooooooooooo410@00;o000000?ooooooa0@4?ooool09oooool2o`0000?o
oooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool0
0ol@413oooooooooo`0@ooooo`;o00002Oooool2o`0000cooooo00?o^[Zjob4Q8Oooool00_ooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@400:ooooo`Co0000
6oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooo0000o`000?l@41000oooool01Ol@413o
oooooooooooooooo410@02Cooooo0_l00003ooooo`;o00001Oooool01Ol@413ooooooooooooooooo
410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`00:Oooool00ol0003oooooooooo`0X
ooooo`?o00001oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00gooooo0_l0000Jooooo`05o`000?nj^[[ooooooiRHV?l@
41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0_l000000oooooooV9RHogMgM`0Boooo
o`;o00002Oooool2o`0000Wooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo0_l0000Mooooo`03onk^
k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL0:Oooool2o`0000Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool002Wooooo00?o0000ooooooooool0:?ooool2o`0000Gooooo0_l00000
0omVIVKo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00gooooo0_l0000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01?o^k^ko
<S8bo`000?lb<S82o`0000;ooooo0ol000000olb<S;ok^k^ooooo`0Hooooo`;o00001oooool2o`00
00Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`03onk^k_lb<S;o000000;o00000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo0_l0000Pooooo`03ogMgMol0003ooooo00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01oooool2o`0000So
oooo0_l0000Fooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`00:Oooool2o`0000?ooooo0_l0000[ooooo`;o0000:Oooool2o`00
01gooooo0_l0000<ooooo`;o00004_ooool2o`0000Oooooo0_l0000>ooooo`?o00004?ooool2o`00
02?ooooo0_l0000Eooooo`;o00002?ooool2o`0000;ooooo0_l0000Yooooo`00:Oooool00ol0003o
ooooooooo`02ooooo`;o00005?ooool2o`0000?ooooo0_l0000Rooooo`;o00005oooool2o`0001co
oooo0ol0000<ooooo`;o0000@_ooool2o`0001oooooo0_l0000Gooooo`;o00002_ooool2o`0002Wo
oooo000Yooooo`03o`000?oooooooooo01Sooooo0_l00003ooooo`?o00001Oooool2o`0001[ooooo
0_l0000eooooo`;o00002_ooool2o`0001oooooo0_l00008ooooo`;o00006_ooool2o`0000_ooooo
0_l0000Rooooo`;o00000oooool2o`0000;ooooo0_l0000Mooooo`;o00005_ooool002Wooooo00Co
0000ooooool0003o00007Oooool2o`0000Gooooo0_l0001Mooooo`;o00005?ooool2o`0000Wooooo
0_l00008ooooo`;o00000_ooool2o`0001cooooo0_l00005ooooo`;o00008_ooool2o`0000?ooooo
0_l0000;ooooo`;o00005?ooool2o`0001Kooooo000Yooooo`Co00008?ooool2o`0003Gooooo0_l0
000;ooooo`;o00008oooool2o`0000kooooo0_l0000:ooooo`;o00002oooool2o`0001cooooo0_l0
000Booooo`;o00003oooool2o`0001Kooooo0_l0000Cooooo`;o00005oooool0027oooooool00014
o`0000Cooooo000Yooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`09ooooo`?o00002Oooool00ol0003oooooooooo`04ooooo`?o00000_ooool00ol0
003oooooooooo`0:ooooo`;o00002_ooool00ol0003oooooooooo`06ooooo`;o000000?oooooo`00
0?ooool01_ooool2o`0000;ooooo00?o0000ooooooooool00_l00008ooooo`03o`000?oooooooooo
00Sooooo0_l0000;ooooo`05o`000?oooooo0000o`000?ooool00_l00005ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`?o00001?ooool2
o`0000Gooooo00?o0000ooooooooool02_ooool3o`000003ooooool0003o000000Kooooo00?o0000
ooooooooool01Oooool2o`0000;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03
ooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`;o00001Oooool3o`0000Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`00:Oooool00ol0003oooooooooo`0^oooo
o`;o00000_ooool2o`0000;ooooo0_l00002ooooo`03o`000?oooooooooo01oooooo0_l000000ooo
oooo0000o`00000=ooooo`;o00002?ooool00ol0003oooooooooo`08ooooo`;o00001oooool2o`00
0004ooooool0003o0000ooooo`;o000000?oooooo`000?l000007_ooool3o`0000?ooooo0_l00002
ooooo`;o00007Oooool4o`0000cooooo0_l00002ooooo`03o`000?oooooooooo00oooooo0_l0000:
ooooo`;o00001_ooool2o`0001Gooooo00?o0000ooooooooool02_ooool002Wooooo00?o0000oooo
ooooool06?ooool2o`0001?ooooo0ol00002ooooo`;o00005Oooool2o`0001Cooooo0_l00003oooo
o`;o00004?ooool2o`0001Cooooo1Ol0000Uooooo`;o00000oooool2o`0002?ooooo0_l0000<oooo
o`;o00007?ooool2o`0000Oooooo0_l0000;ooooo`;o00006?ooool002Wooooo00?o0000oooooooo
ool06?ooool4o`0000kooooo0_l000000ooooooo0000o`00000Jooooo`;o00006Oooool2o`0000go
oooo0_l000000ooooooo0000o`00000Fooooo`;o00002?ooool2o`00063ooooo0_l0000@ooooo`;o
000000?oooooo`000?l000001?ooool2o`0000_ooooo0_l00006ooooo`;o00004?ooool002Wooooo
0_l0000Eooooo`;o00001?ooool2o`0000_ooooo0_l000000ooooooo0000o`00000Tooooo`;o0000
8Oooool2o`0000Sooooo0_l0000Iooooo`;o00005_ooool2o`0004Sooooo0_l00004ooooo`;o0000
3Oooool2o`0001Oooooo1Ol0000?ooooo`00:Oooool00ol0003oooooooooo`0Dooooo`;o00004Ooo
ool2o`0002Oooooo0_l0000[ooooo`;o00006_ooool2o`0000[ooooo0_l00009ooooo`;o00005ooo
ool2o`0003Gooooo1?l0000;ooooo`;o00005oooool2o`000003ooooool0003o000000oooooo000Y
ooooo`03o`000?oooooooooo07cooooo0_l0000Kooooo`;o00002_ooool2o`0000Cooooo0_l0000F
ooooo`;o00001?ooool2o`0003?ooooo0ol000000ooooooo0000o`000004ooooo`;o00001Oooool2
o`000003ooooool0003o000001Cooooo0_l00003ooooo`;o00003Oooool002Wooooo00?o0000oooo
ooooool04_ooool2o`00043ooooo0_l0000>ooooo`;o00003?ooool2o`0000Sooooo0_l00002oooo
o`;o00007_ooool2o`0000Wooooo0_l0000Fooooo`;o0000>Oooool3o`0000Oooooo0_l00008oooo
o`;o00006Oooool2o`0000gooooo000Yooooo`03o`000?oooooooooo01;ooooo0_l00010ooooo`;o
00003_ooool2o`000003ooooool0003o000000Wooooo0_l0000<ooooo`;o00002Oooool2o`00013o
oooo0_l000000ooooooo0000o`000005ooooo`;o00006Oooool2o`0005?ooooo0_l0000:ooooo`;o
00005oooool002Wooooo0_l0000Wooooo`;o00002_ooool3o`0002Cooooo0_l0000<ooooo`;o0000
1?ooool2o`0000Sooooo0_l00008ooooo`;o00001?ooool2o`0000;ooooo0_l0000@ooooo`;o0000
2?ooool2o`0001Wooooo0_l0001Cooooo`;o00002_ooool2o`0001Oooooo000Yooooo`04o`000?oo
oooo0000o`0000Gooooo0_l00005ooooo`;o00005oooool2o`0000Wooooo1?l0000Tooooo`;o0000
4_ooool2o`0000Sooooo0_l000000ooooooo0000o`000005ooooo`;o00000oooool3o`0005Gooooo
0_l000000ooooooo0000o`00000Fooooo`;o0000@Oooool002Wooooo1?l00005ooooo`Co00000ooo
ool2o`0000Cooooo0_l0000Looooo`;o00002_ooool2o`0003_ooooo0_l0000:ooooo`;o0000A_oo
ool2o`0000kooooo0_l000000ooooooo0000o`00000>ooooo`;o00001_ooool2o`0002kooooo0_l0
000Aooooo`00:Oooool2o`0000Wooooo0_l00009ooooo`;o000000?oooooo`000?l000006?ooool2
o`0000_ooooo0_l00007ooooo`;o00005_ooool2o`0004kooooo0_l0000>ooooo`;o00001Oooool2
o`0000Oooooo0_l0000Qooooo`;o0000:oooool2o`0000Oooooo1?l0000Aooooo`00:Oooool00ol0
003oooooooooo`0Fooooo`?o00005oooool2o`0001Cooooo0_l0000Fooooo`;o0000;Oooool2o`00
01cooooo0_l000000ooooooo0000o`00000>ooooo`;o00001Oooool2o`0001oooooo0_l0000foooo
o`;o00001oooool2o`0001?ooooo000Yooooo`;o00006?ooool2o`0002Cooooo0ol0000Hooooo`;o
0000;_ooool2o`0000?ooooo0_l0000Looooo`Co00004Oooool2o`0000Cooooo0_l0000Aooooo`;o
00002oooool2o`0002Gooooo0_l000000ooooooo0000o`00000Zooooo`00:Oooool00ol0003ooooo
ooooo`0mooooo`?o00006?ooool2o`0000Wooooo0_l00003ooooo`;o00004?ooool2o`0000cooooo
0_l0000Mooooo`;o00001?ooool2o`00017ooooo0_l00004ooooo`;o00004Oooool2o`0000Sooooo
0ol0000>ooooo`?o00004?ooool2o`0000Cooooo0_l000000ooooooo0000o`00000Zooooo`00:Ooo
ool00ol0003oooooooooo`0?ooooo`Co00009oooool2o`0001gooooo0_l00008ooooo`;o00000ooo
ool2o`00013ooooo0_l0000Tooooo`;o00001Oooool2o`0003[ooooo0ol00003ooooo`Co00001ooo
ool3o`0000kooooo1?l0000Dooooo`;o00007Oooool002Wooooo00?o0000ooooooooool03oooool4
o`0002Oooooo0_l0000Mooooo`;o00009_ooool2o`0001gooooo0_l0000dooooo`;o00004Oooool4
o`0000gooooo0_l00002ooooo`;o00001Oooool2o`0001Kooooo1?l0000Kooooo`00:Oooool00ol0
003oooooooooo`0kooooo`?o0000@oooool2o`0000Wooooo0_l00018ooooo`;o00008_ooool2o`00
00;ooooo0_l0000Kooooo`;o00000_ooool2o`0001_ooooo000Yooooo`;o0000??ooool3o`0000;o
oooo0_l00007ooooo`;o0000<?ooool2o`0000oooooo0_l00002ooooo`;o00000oooool2o`0001co
oooo0_l0000Sooooo`;o00006_ooool2o`0002Gooooo0_l0000Oooooo`00:Oooool00ol0003ooooo
ooooo`0Wooooo`;o00005oooool2o`0000Oooooo0_l0000/ooooo`;o00000_ooool2o`0001;ooooo
0ol00003ooooo`;o00007?ooool2o`0002?ooooo0_l0000:ooooo`;o00001Oooool4o`0000?ooooo
1?l0000Vooooo`;o00007_ooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00Oo
oooo0_l0000Gooooo`;o00001Oooool2o`0000[ooooo0_l00005ooooo`;o00000_ooool2o`0000go
oooo0_l00006ooooo`;o00008?ooool2o`0001Kooooo0_l0000Wooooo`;o00000oooool2o`0000Wo
oooo0_l0000Jooooo`;o00001Oooool4o`0000?ooooo0_l0000>ooooo`;o00004oooool2o`0000?o
oooo0_l0000Nooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
00Oooooo0_l0000Gooooo`;o00001_ooool2o`0000Wooooo0_l00005ooooo`;o00000_ooool2o`00
00gooooo0_l00006ooooo`;o0000??ooool2o`000003ooooool0003o0000023ooooo0_l00003oooo
o`;o00002Oooool2o`0003Sooooo0_l00002ooooo`;o00003oooool2o`0002?ooooo0006ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool02Oooool2o`0001gooooo0_l0001Yooooo`;o000000?oooooo`00
0?l000006Oooool2o`0005?ooooo0_l0000dooooo`001_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o00002Oooool4o`00
01?ooooo0_l0000Booooo`;o00004_ooool2o`000003ooooool0003o000000kooooo0_l0000Hoooo
o`;o0000>_ooool3o`0008Sooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omg
MgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0;
ooooo`;o00004oooool2o`0001;ooooo0_l0000Booooo`;o000000?oooooo`000?l000003_ooool2
o`0001Sooooo0_l0000Pooooo`;o00006Oooool2o`0006Kooooo0_l0000Pooooo`001_ooool01Ol@
413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00cooooo0_l0001kooooo`;o00001Oooool2o`0000Gooooo0_l0001l
ooooo`;o00000oooool2o`00023ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`04ooooo`;o000000?oooooo`000?l000000oooool2o`0003Sooooo0_l0000mooooo`;o00000_oo
ool2o`0000Gooooo0_l0000[ooooo`;o00003Oooool2o`0000;ooooo0_l00013ooooo`;o00005?oo
ool2o`0000oooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`00
0?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`;o
00000oooool2o`0001gooooo0_l0000Fooooo`;o00009_ooool2o`0001Gooooo0_l0000fooooo`;o
00003Oooool2o`0000;ooooo0_l0000Dooooo`;o0000@oooool3o`0000kooooo000Yooooo`;o0000
2oooool2o`0000?ooooo0_l00004ooooo`;o00005oooool2o`0001gooooo0_l0000Oooooo`;o0000
;Oooool2o`0001[ooooo0_l0000Hooooo`;o00004Oooool3o`00027ooooo0_l0000Pooooo`;o0000
3_ooool002Wooooo00?o0000ooooooooool02_ooool2o`0000Wooooo0_l0000fooooo`;o0000<?oo
ool2o`0001cooooo0_l0000Jooooo`;o000000?oooooo`000?l000003?ooool2o`0000Oooooo0_l0
0008ooooo`;o00002?ooool2o`0000[ooooo0_l0000Eooooo`;o0000<?ooool002Wooooo00?o0000
ooooooooool02_ooool2o`0007?ooooo0_l0000kooooo`;o00003?ooool2o`00017ooooo0_l0000D
ooooo`;o0000Aoooool002Wooooo00?o0000ooooooooool06_ooool4o`000?oooooo7oooool002Wo
oooo00?o0000ooooooooool06_ooool4o`0001[ooooo0_l00018ooooo`;o0000=_ooool2o`0001?o
oooo0_l0000Oooooo`;o00005oooool2o`00037ooooo000Yooooo`;o0000>Oooool2o`0002Oooooo
0_l0000Oooooo`;o00009?ooool2o`00013ooooo0_l0000Cooooo`;o00003_ooool2o`0000oooooo
0_l0000Gooooo`Co0000;oooool002Wooooo00?o0000ooooooooool01Oooool2o`0004cooooo0_l0
000<ooooo`;o00003_ooool2o`0001Oooooo0_l0000Looooo`;o0000<_ooool2o`000003ooooool0
003o000000;ooooo0_l0000Vooooo`;o0000;oooool002Wooooo00?o0000ooooooooool01Oooool2
o`0004cooooo0_l0000Looooo`;o00005oooool2o`0002Wooooo0_l0000:ooooo`;o00006Oooool2
o`0000Gooooo0_l0000=ooooo`;o0000B?ooool002Wooooo00?o0000ooooooooool0C_ooool2o`00
01cooooo0_l00017ooooo`;o00002_ooool2o`0001Wooooo0_l0000>ooooo`;o00001?ooool2o`00
04Sooooo000Yooooo`03o`000?oooooooooo013ooooo0_l0000;ooooo`;o00003?ooool2o`0001Co
oooo0_l0000;ooooo`;o00007?ooool2o`000004ooooool0003o0000o`0000Cooooo0_l0000joooo
o`;o0000:?ooool2o`0000kooooo0_l00011ooooo`;o00002oooool002Wooooo0_l00003ooooo`;o
00003?ooool2o`0000_ooooo0_l0000<ooooo`;o00003_ooool2o`0000Cooooo0_l0000/ooooo`?o
00001?ooool2o`0001cooooo0_l0000Looooo`;o00001?ooool2o`0004oooooo0_l0000Tooooo`;o
00002oooool002Wooooo00?o0000ooooooooool00_ooool4o`0000oooooo0_l0000>ooooo`;o0000
4_ooool4o`0000Sooooo0_l0001=ooooo`;o00005_ooool2o`0000[ooooo0_l0000Pooooo`;o0000
6oooool2o`00013ooooo0_l0000Looooo`;o00004oooool002Wooooo00?o0000ooooooooool01?oo
ool2o`0000oooooo0_l00008ooooo`;o00000oooool3o`0001;ooooo0_l0000:ooooo`;o00005ooo
ool2o`0002Cooooo0_l0000Vooooo`;o00004_ooool2o`0001Cooooo0_l00002ooooo`;o00006ooo
ool2o`0002kooooo0_l0000Cooooo`00:Oooool00ol0003oooooooooo`0Oooooo`;o00000oooool2
o`0001oooooo0_l0000;ooooo`;o00002_ooool2o`0000Wooooo0_l0000Iooooo`;o0000>_ooool2
o`0000Kooooo0_l00007ooooo`;o00000oooool2o`0001kooooo0_l00009ooooo`;o00005_ooool2
o`00027ooooo000Yooooo`03o`000?oooooooooo013ooooo0_l0000=ooooo`;o00003oooool2o`00
01?ooooo0_l0000;ooooo`;o00000_ooool2o`0000_ooooo0_l00004ooooo`;o0000<Oooool2o`00
02[ooooo0_l00007ooooo`;o00003?ooool2o`0001Gooooo0_l00009ooooo`;o00004?ooool2o`00
00Cooooo0_l0000Qooooo`00:Oooool2o`0000;ooooo0_l0000=ooooo`;o00003Oooool2o`0000oo
oooo0_l0000Tooooo`;o00002oooool2o`0000oooooo0_l0000Vooooo`;o0000@Oooool2o`0003;o
oooo0_l0000Wooooo`00:Oooool01?l0003oooooooooooooool2o`00077ooooo0_l00036ooooo`00
3_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03oooo
o`?o0000oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05o`000?oooooooooooooo
ool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`000?oooooo2Oooool2o`0003?ooooo000Yoooo
o`03o`000?oooooooooo0?oooooo2?ooool2o`0003?ooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0ooooool[ooooo`;o00004?ooool002Wooooo00?o
0000ooooooooool0@oooool2o`000>Gooooo0_l0000@ooooo`00:Oooool2o`0004Cooooo0_l0002S
ooooo`;o0000D_ooool002Wooooo00?o0000ooooooooool0Eoooool2o`0005gooooo0_l0000`oooo
o`;o0000D_ooool002Wooooo00?o0000ooooooooool0Eoooool2o`0005gooooo0_l00024ooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
1_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413o
oooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03oooo
o`?o0000oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qoooo
ooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooo
oooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0
0006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool001oo
oooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oo
oooooooo00Gooooo0ol0003oooooocgooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001oooooo00?oEEEEofIVI_l00000oooo
oom7ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .25988 Mdot
.02762 .35221 Mdot
.02952 .30547 Mdot
.03143 .25892 Mdot
.03333 .36286 Mdot
.03524 .30112 Mdot
.03714 .31556 Mdot
.03905 .43876 Mdot
.04095 .38388 Mdot
.04286 .34363 Mdot
.04476 .29716 Mdot
.04667 .44942 Mdot
.04857 .41268 Mdot
.05048 .32705 Mdot
.05238 .44777 Mdot
.05429 .31479 Mdot
.05619 .35742 Mdot
.0581 .41373 Mdot
.06 .29218 Mdot
.0619 .32557 Mdot
.06381 .41213 Mdot
.06571 .38803 Mdot
.06762 .39875 Mdot
.06952 .41436 Mdot
.07143 .44531 Mdot
.07333 .29519 Mdot
.07524 .2624 Mdot
.07714 .28877 Mdot
.07905 .29939 Mdot
.08095 .3612 Mdot
.08286 .40785 Mdot
.08476 .37968 Mdot
.08667 .42881 Mdot
.08857 .3799 Mdot
.09048 .38086 Mdot
.09238 .3447 Mdot
.09429 .24642 Mdot
.09619 .26277 Mdot
.0981 .26106 Mdot
.1 .4524 Mdot
.1019 .45017 Mdot
.10381 .38306 Mdot
.10571 .35157 Mdot
.10762 .2664 Mdot
.10952 .24025 Mdot
.11143 .35516 Mdot
.11333 .32487 Mdot
.11524 .33802 Mdot
.11714 .24994 Mdot
.11905 .29337 Mdot
.12095 .33709 Mdot
.12286 .2401 Mdot
.12476 .33412 Mdot
.12667 .36608 Mdot
.12857 .36857 Mdot
.13048 .40904 Mdot
.13238 .44129 Mdot
.13429 .35414 Mdot
.13619 .29367 Mdot
.1381 .23872 Mdot
.14 .34711 Mdot
.1419 .38375 Mdot
.14381 .25277 Mdot
.14571 .33649 Mdot
.14762 .42964 Mdot
.14952 .39425 Mdot
.15143 .34432 Mdot
.15333 .30732 Mdot
.15524 .26107 Mdot
.15714 .4132 Mdot
.15905 .3622 Mdot
.16095 .27025 Mdot
.16286 .33941 Mdot
.16476 .34724 Mdot
.16667 .25283 Mdot
.16857 .29862 Mdot
.17048 .33459 Mdot
.17238 .31676 Mdot
.17429 .25197 Mdot
.17619 .2499 Mdot
.1781 .39012 Mdot
.18 .35887 Mdot
.1819 .26038 Mdot
.18381 .38347 Mdot
.18571 .4247 Mdot
.18762 .31624 Mdot
.18952 .36369 Mdot
.19143 .35997 Mdot
.19333 .33887 Mdot
.19524 .31163 Mdot
.19714 .4432 Mdot
.19905 .22057 Mdot
.20095 .32459 Mdot
.20286 .36044 Mdot
.20476 .33004 Mdot
.20667 .22507 Mdot
.20857 .3297 Mdot
.21048 .34772 Mdot
.21238 .3443 Mdot
.21429 .33844 Mdot
.21619 .27932 Mdot
.2181 .31391 Mdot
.22 .44839 Mdot
.2219 .28575 Mdot
.22381 .40442 Mdot
.22571 .38113 Mdot
.22762 .37082 Mdot
.22952 .31227 Mdot
.23143 .32405 Mdot
.23333 .41187 Mdot
.23524 .33828 Mdot
.23714 .25872 Mdot
.23905 .37776 Mdot
.24095 .34905 Mdot
.24286 .44805 Mdot
.24476 .31912 Mdot
.24667 .33457 Mdot
.24857 .4008 Mdot
.25048 .39071 Mdot
.25238 .24831 Mdot
.25429 .41225 Mdot
.25619 .40889 Mdot
.2581 .40798 Mdot
.26 .29741 Mdot
.2619 .41247 Mdot
.26381 .26471 Mdot
.26571 .33377 Mdot
.26762 .24304 Mdot
.26952 .33163 Mdot
.27143 .27245 Mdot
.27333 .39757 Mdot
.27524 .30472 Mdot
.27714 .45154 Mdot
.27905 .29915 Mdot
.28095 .33615 Mdot
.28286 .27085 Mdot
.28476 .23281 Mdot
.28667 .31274 Mdot
.28857 .34014 Mdot
.29048 .43712 Mdot
.29238 .44886 Mdot
.29429 .32757 Mdot
.29619 .28521 Mdot
.2981 .2711 Mdot
.3 .35738 Mdot
.3019 .33856 Mdot
.30381 .41613 Mdot
.30571 .47643 Mdot
.30762 .3294 Mdot
.30952 .35784 Mdot
.31143 .42671 Mdot
.31333 .30289 Mdot
.31524 .25336 Mdot
.31714 .41506 Mdot
.31905 .27556 Mdot
.32095 .25494 Mdot
.32286 .23058 Mdot
.32476 .24842 Mdot
.32667 .40252 Mdot
.32857 .24909 Mdot
.33048 .23083 Mdot
.33238 .25836 Mdot
.33429 .25455 Mdot
.33619 .45631 Mdot
.3381 .36246 Mdot
.34 .34649 Mdot
.3419 .27744 Mdot
.34381 .41364 Mdot
.34571 .40077 Mdot
.34762 .25796 Mdot
.34952 .22979 Mdot
.35143 .30933 Mdot
.35333 .30768 Mdot
.35524 .25382 Mdot
.35714 .36269 Mdot
.35905 .33655 Mdot
.36095 .43125 Mdot
.36286 .22909 Mdot
.36476 .25785 Mdot
.36667 .31777 Mdot
.36857 .28474 Mdot
.37048 .23439 Mdot
.37238 .45396 Mdot
.37429 .34096 Mdot
.37619 .44919 Mdot
.3781 .26726 Mdot
.38 .38114 Mdot
.3819 .24287 Mdot
.38381 .37207 Mdot
.38571 .456 Mdot
.38762 .34567 Mdot
.38952 .42177 Mdot
.39143 .33975 Mdot
.39333 .33255 Mdot
.39524 .38906 Mdot
.39714 .43198 Mdot
.39905 .44669 Mdot
.40095 .45008 Mdot
.40286 .36186 Mdot
.40476 .22762 Mdot
.40667 .38085 Mdot
.40857 .32603 Mdot
.41048 .32567 Mdot
.41238 .26785 Mdot
.41429 .36141 Mdot
.41619 .23915 Mdot
.4181 .29395 Mdot
.42 .30909 Mdot
.4219 .28312 Mdot
.42381 .26031 Mdot
.42571 .27982 Mdot
.42762 .29413 Mdot
.42952 .40392 Mdot
.43143 .3228 Mdot
.43333 .39998 Mdot
.43524 .33579 Mdot
.43714 .28363 Mdot
.43905 .33041 Mdot
.44095 .45545 Mdot
.44286 .26617 Mdot
.44476 .23959 Mdot
.44667 .45026 Mdot
.44857 .33854 Mdot
.45048 .30936 Mdot
.45238 .4048 Mdot
.45429 .37985 Mdot
.45619 .32779 Mdot
.4581 .3544 Mdot
.46 .3374 Mdot
.4619 .31434 Mdot
.46381 .44803 Mdot
.46571 .40686 Mdot
.46762 .29109 Mdot
.46952 .29811 Mdot
.47143 .24775 Mdot
.47333 .28171 Mdot
.47524 .26704 Mdot
.47714 .41357 Mdot
.47905 .25659 Mdot
.48095 .29764 Mdot
.48286 .40861 Mdot
.48476 .29618 Mdot
.48667 .38145 Mdot
.48857 .32722 Mdot
.49048 .39169 Mdot
.49238 .36181 Mdot
.49429 .37905 Mdot
.49619 .33141 Mdot
.4981 .23123 Mdot
.5 .32967 Mdot
.5019 .35997 Mdot
.50381 .2531 Mdot
.50571 .44699 Mdot
.50762 .32 Mdot
.50952 .3327 Mdot
.51143 .23562 Mdot
.51333 .28386 Mdot
.51524 .25344 Mdot
.51714 .36582 Mdot
.51905 .29299 Mdot
.52095 .43875 Mdot
.52286 .31808 Mdot
.52476 .26232 Mdot
.52667 .26768 Mdot
.52857 .3746 Mdot
.53048 .29237 Mdot
.53238 .30136 Mdot
.53429 .25016 Mdot
.53619 .31562 Mdot
.5381 .31031 Mdot
.54 .32843 Mdot
.5419 .25951 Mdot
.54381 .34249 Mdot
.54571 .36555 Mdot
.54762 .34553 Mdot
.54952 .25416 Mdot
.55143 .23013 Mdot
.55333 .34306 Mdot
.55524 .33999 Mdot
.55714 .34723 Mdot
.55905 .30298 Mdot
.56095 .26447 Mdot
.56286 .27351 Mdot
.56476 .27196 Mdot
.56667 .34459 Mdot
.56857 .2504 Mdot
.57048 .44668 Mdot
.57238 .31509 Mdot
.57429 .29264 Mdot
.57619 .35451 Mdot
.5781 .36766 Mdot
.58 .35582 Mdot
.5819 .39473 Mdot
.58381 .24182 Mdot
.58571 .29 Mdot
.58762 .44666 Mdot
.58952 .29831 Mdot
.59143 .31809 Mdot
.59333 .26949 Mdot
.59524 .3949 Mdot
.59714 .38104 Mdot
.59905 .4474 Mdot
.60095 .48691 Mdot
.60286 .24799 Mdot
.60476 .35014 Mdot
.60667 .30822 Mdot
.60857 .37985 Mdot
.61048 .4488 Mdot
.61238 .3197 Mdot
.61429 .34703 Mdot
.61619 .27655 Mdot
.6181 .32205 Mdot
.62 .40314 Mdot
.6219 .36235 Mdot
.62381 .41063 Mdot
.62571 .43077 Mdot
.62762 .31183 Mdot
.62952 .24029 Mdot
.63143 .3819 Mdot
.63333 .43404 Mdot
.63524 .29171 Mdot
.63714 .45363 Mdot
.63905 .42189 Mdot
.64095 .31413 Mdot
.64286 .28063 Mdot
.64476 .29986 Mdot
.64667 .38408 Mdot
.64857 .24071 Mdot
.65048 .35513 Mdot
.65238 .3261 Mdot
.65429 .31946 Mdot
.65619 .36659 Mdot
.6581 .44663 Mdot
.66 .23554 Mdot
.6619 .33182 Mdot
.66381 .39706 Mdot
.66571 .26981 Mdot
.66762 .26765 Mdot
.66952 .34133 Mdot
.67143 .31059 Mdot
.67333 .3461 Mdot
.67524 .2578 Mdot
.67714 .36007 Mdot
.67905 .30851 Mdot
.68095 .27247 Mdot
.68286 .35099 Mdot
.68476 .33582 Mdot
.68667 .42108 Mdot
.68857 .26715 Mdot
.69048 .31785 Mdot
.69238 .3749 Mdot
.69429 .30737 Mdot
.69619 .34375 Mdot
.6981 .33118 Mdot
.7 .44909 Mdot
.7019 .2636 Mdot
.70381 .33989 Mdot
.70571 .24643 Mdot
.70762 .3794 Mdot
.70952 .31737 Mdot
.71143 .29109 Mdot
.71333 .44886 Mdot
.71524 .31373 Mdot
.71714 .38939 Mdot
.71905 .45105 Mdot
.72095 .45357 Mdot
.72286 .45237 Mdot
.72476 .27135 Mdot
.72667 .2691 Mdot
.72857 .44851 Mdot
.73048 .43956 Mdot
.73238 .27438 Mdot
.73429 .40197 Mdot
.73619 .26744 Mdot
.7381 .28421 Mdot
.74 .27303 Mdot
.7419 .35754 Mdot
.74381 .29674 Mdot
.74571 .2584 Mdot
.74762 .23138 Mdot
.74952 .39661 Mdot
.75143 .25063 Mdot
.75333 .39556 Mdot
.75524 .44796 Mdot
.75714 .45967 Mdot
.75905 .26234 Mdot
.76095 .25194 Mdot
.76286 .27843 Mdot
.76476 .43402 Mdot
.76667 .33232 Mdot
.76857 .31948 Mdot
.77048 .45491 Mdot
.77238 .41292 Mdot
.77429 .32539 Mdot
.77619 .34719 Mdot
.7781 .3117 Mdot
.78 .26046 Mdot
.7819 .3448 Mdot
.78381 .40653 Mdot
.78571 .38956 Mdot
.78762 .45419 Mdot
.78952 .37436 Mdot
.79143 .29885 Mdot
.79333 .37759 Mdot
.79524 .33316 Mdot
.79714 .34185 Mdot
.79905 .27369 Mdot
.80095 .44491 Mdot
.80286 .44887 Mdot
.80476 .26438 Mdot
.80667 .30551 Mdot
.80857 .27227 Mdot
.81048 .32909 Mdot
.81238 .43772 Mdot
.81429 .36307 Mdot
.81619 .36679 Mdot
.8181 .27383 Mdot
.82 .25286 Mdot
.8219 .28458 Mdot
.82381 .36417 Mdot
.82571 .37821 Mdot
.82762 .26004 Mdot
.82952 .31473 Mdot
.83143 .41791 Mdot
.83333 .43632 Mdot
.83524 .27714 Mdot
.83714 .37909 Mdot
.83905 .37095 Mdot
.84095 .24219 Mdot
.84286 .25903 Mdot
.84476 .25445 Mdot
.84667 .43518 Mdot
.84857 .22086 Mdot
.85048 .31127 Mdot
.85238 .42329 Mdot
.85429 .27429 Mdot
.85619 .32188 Mdot
.8581 .3952 Mdot
.86 .4483 Mdot
.8619 .28803 Mdot
.86381 .37624 Mdot
.86571 .31594 Mdot
.86762 .29885 Mdot
.86952 .31976 Mdot
.87143 .34392 Mdot
.87333 .37825 Mdot
.87524 .24721 Mdot
.87714 .22284 Mdot
.87905 .27347 Mdot
.88095 .37311 Mdot
.88286 .38404 Mdot
.88476 .33533 Mdot
.88667 .31137 Mdot
.88857 .34658 Mdot
.89048 .43916 Mdot
.89238 .30505 Mdot
.89429 .26199 Mdot
.89619 .33739 Mdot
.8981 .24105 Mdot
.9 .33918 Mdot
.9019 .39922 Mdot
.90381 .36892 Mdot
.90571 .24944 Mdot
.90762 .347 Mdot
.90952 .44751 Mdot
.91143 .44829 Mdot
.91333 .31309 Mdot
.91524 .26731 Mdot
.91714 .25901 Mdot
.91905 .35079 Mdot
.92095 .32115 Mdot
.92286 .27852 Mdot
.92476 .30235 Mdot
.92667 .34349 Mdot
.92857 .37995 Mdot
.93048 .39179 Mdot
.93238 .33358 Mdot
.93429 .30398 Mdot
.93619 .35446 Mdot
.9381 .25019 Mdot
.94 .26887 Mdot
.9419 .29093 Mdot
.94381 .36869 Mdot
.94571 .34338 Mdot
.94762 .32427 Mdot
.94952 .29318 Mdot
.95143 .39579 Mdot
.95333 .36219 Mdot
.95524 .24464 Mdot
.95714 .2612 Mdot
.95905 .29401 Mdot
.96095 .28906 Mdot
.96286 .44121 Mdot
.96476 .29527 Mdot
.96667 .34689 Mdot
.96857 .31793 Mdot
.97048 .36128 Mdot
.97238 .26598 Mdot
.97429 .30154 Mdot
.97619 .45275 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo03Gooooo0_l0003>ooooo`;o0000=Oooool000Kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo03Gooooo0_l0003>ooooo`;o00002?ooool2o`0002_ooooo0006oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4
A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0=oooool2o`0003kooooo0_l0
002Fooooo`;o0000:oooool000Co00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Oooooo0_l0
000Sooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo0_l0000<ooooo`;o0000;Ooo
ool2o`0009Cooooo0006ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^
kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0001@ooooo`;o00002_ooool2o`000003ooooool0
003o000000Cooooo0_l00002ooooo`;o0000:_ooool2o`0000oooooo0_l0000mooooo`;o0000EOoo
ool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo053ooooo0_l0000Jooooo`;o0000
9oooool2o`0000;ooooo0_l0000^ooooo`;o00006_ooool2o`0005Gooooo0006ooooo`05oa0@4?oo
ooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool06?ooool2o`0000;ooooo0_l00003ooooo`;o0000BOooool2o`0000cooooo
0_l00008ooooo`;o00004oooool2o`0002Cooooo0_l00008ooooo`;o0000LOooool000Kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo01Sooooo0_l00002ooooo`;o00000oooool2o`0002So
oooo0_l0000Rooooo`;o00002Oooool2o`0000Sooooo0_l0000Zooooo`;o00003Oooool2o`0000Co
oooo0_l0000looooo`;o00004?ooool2o`0002Gooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo
01?ooooo0_l0000fooooo`;o00008_ooool2o`0003oooooo0_l0000Cooooo`;o00004Oooool2o`00
02Wooooo0_l0000@ooooo`;o00004Oooool2o`0001;ooooo000Yooooo`;o00005?ooool2o`00037o
oooo0_l0000Eooooo`?o0000;?ooool2o`0002Sooooo0_l0000Pooooo`;o0000=?ooool2o`0000So
oooo0_l0000>ooooo`;o00004_ooool002Wooooo00?o0000ooooooooool06_ooool2o`0000Oooooo
0_l00005ooooo`;o000000?oooooo`000?l000005oooool2o`0001Gooooo0ol0000/ooooo`;o0000
4_ooool2o`0000Wooooo0_l00009ooooo`;o0000;_ooool2o`000003ooooool0003o000002?ooooo
0_l00008ooooo`;o00002?ooool2o`0001Sooooo000Yooooo`03o`000?oooooooooo01[ooooo0_l0
0007ooooo`;o00001Oooool2o`000003ooooool0003o000002_ooooo1?l00002ooooo`;o00001Ooo
ool2o`0002kooooo0_l000000ooooooo0000o`000004ooooo`;o00000oooool2o`0000Cooooo0_l0
000iooooo`;o000000?oooooo`000?l000004Oooool2o`0000Kooooo0_l0000Looooo`;o00006?oo
ool002Wooooo00Co0000ooooool0003o0000@?ooool2o`0001Oooooo1?l000001?oooooo0000o`00
0?l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Sooooo`;o00001_ooool2o`000003
ooooool0003o000000Wooooo0_l0000Wooooo`;o00005?ooool2o`0001Kooooo0_l00006ooooo`;o
00005_ooool2o`0001kooooo000Yooooo`Co00004oooool2o`00017ooooo0_l00006ooooo`;o0000
4?ooool2o`0001cooooo0_l00003ooooo`;o00001?ooool2o`00017ooooo0_l0000@ooooo`;o0000
4_ooool2o`0002Wooooo0_l0000Dooooo`;o00002Oooool2o`0000kooooo0_l00003ooooo`;o0000
3_ooool2o`0000Kooooo0_l0000:ooooo`;o00004_ooool002Wooooo0_l0000>ooooo`;o00001Ooo
ool2o`00017ooooo0_l00006ooooo`;o00006?ooool2o`0003;ooooo0_l0000Nooooo`;o00001?oo
ool2o`0000Cooooo0_l0000[ooooo`;o00004Oooool2o`0000Cooooo0_l00006ooooo`;o00001_oo
ool2o`0001?ooooo0_l0000Booooo`;o00004_ooool002Wooooo00?o0000ooooooooool03Oooool2
o`0000Gooooo0_l000000ooooooo0000o`00000`ooooo`;o00008oooool2o`0000Wooooo0_l00008
ooooo`;o00002?ooool2o`0000kooooo0ol00009ooooo`;o00008?ooool2o`0000Gooooo0_l00002
ooooo`;o00002Oooool2o`0000Kooooo0_l0000<ooooo`;o00008_ooool2o`00013ooooo0_l0000=
ooooo`00:Oooool00ol0003oooooooooo`0Gooooo`;o00003oooool2o`0000Kooooo1?l000002?l@
413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo0_l00002ooooo`;o00005oooool5o`0000?ooooo00Cok^k^oc8b<_l0003o<S8b0_l00002oooo
o`06onk^k_lb<S;o0000oc8b<_o^k^kooooo0_l00008ooooo`;o00003oooool2o`0000[ooooo00Go
V9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_l0003o0000oc8b<_o^k^h00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00cooooo0_l00005ooooo`;o00002_ooool2o`000003ooooool0003o0000
00Kooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h07oooool2o`0000Kooooo0_l000001Om4A4Co0000o`000?lb<S;ogMgM
00;ooooo00Gok^k^o`000?l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool002Wooooo00?o0000ooooooooool0:?ooool2o`0000Sooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`;o0000
0_ooool2o`0000;ooooo0_l0000Gooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Xooooo`;o000000?ooooo
ogMgMolb<S800oooool01OmgMgOo0000o`000?nHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0<ooooo`;o00000oooool2o`0000cooooo1?l000000ooooooo0000o`000005ooooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`;o000000CoV9RHo`000?l0
003oMgMg0_l00009ooooo`;o00001_ooool2o`0001;ooooo0_l00003ooooo`09ogMgMolb<S;ooooo
oooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00
:Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?ooool2o`0000gooooo0_l00006oooo
o`;o00002Oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool0
1Ol@413ooooooooooooooooo410@02Sooooo0_l00002ooooo`05o`000?ooooooooooooooool@4100
0oooool01Ol@413ooooooooooooooooo410@00;o000000?ooooooa0@4?ooool04?ooool2o`0000ko
oooo0_l000000ooooooo0000o`000002ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@
00;ooooo0_l000001?oooooo0000o`000?l@4102o`0000?ooooo0_l00004ooooo`;o00001_ooool2
o`0001Sooooo00Co0000oooooooooooo410@0oooool01Ol@413ooooooooooooooooo410@00?ooooo
00?o410@ooooooooool00Oooool002Wooooo0_l0000cooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_l00003ooooo`05o`000?ooooooooooooooool000005oooool2o`0000Kooooo
0_l0000:ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003ooooo`;o
00000_ooool00ol0003oooooooooo`0Yooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`?o000000?oooooo`000?ooool00oooool2o`0002;ooooo00?oA4A4omgM
gOooool00_l00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000Gooooo0_l0000Jooooo`;o00002Oooool01OmgMgOo<S8boooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo007ooooo000Yooooo`03o`00
0?oooooooooo03;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02o`0000?ooooo
00Go0000ooooooooooooooooo`00000/ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`?o00000_ooool2o`0000[ooooo0_l0000;ooooo`;o00004?ooool00ol@
413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000Cooooo0_l0000Rooooo`03omgMgOmEEEGooooo00;o00000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`00000Qooooo`;o00001_ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool002Wooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41000_l000000ooooooo410@ooooo`02ooooo`03oa0@4?oo
oooooooo00kooooo0_l0000Eooooo`;o00001?ooool01Ol0003ooooooooooooooooo410@00?ooooo
00?o410@ooooooooool00_l00003ooooo`;o00002_ooool2o`0000_ooooo0_l0000Aooooo`03okZj
^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41008oooool2o`0000Cooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo
410@00?ooooo00Ko410@oooooooooooooooooa0@4?ooool2o`0002Kooooo00?o0000ooooooooool0
1?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003oooo
o`00:Oooool00ol0003oooooooooo`0=ooooo`;o00008oooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00_l000001_ooooooMgMgoiRHV?ooooooV9RHogMgMa3ooooo0_l0
000Eooooo`?o000000Co^[ZjoooooonHV9So410@0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Xooooo`05oa0@4?nHV9SooooookZj^_l000000_ooool2
o`000004oiRHV?ooooooV9RHogMgM`?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`;o0000
1?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01_mgMgOo
V9RHoooooonHV9SoMgMgooooo`;o00002oooool2o`0001Wooooo00?o0000ooooooooool00_ooool2
o`000005ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
000Yooooo`03o`000?oooooooooo00Sooooo0_l00003ooooo`;o00008Oooool00omEEEGoIVIVo`00
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Wo
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Wooooo0_l0000?ooooo`;o000000?oooooo`000?l000002Ooo
ool00onYZJWo410@o`000002o`0000;ooooo0_l000001?lb<S;o0000oc8b<_o^k^h3ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00_ooool2o`0001Kooooo0_l0000>ooooo`03ogMgMol0003ooooo00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool2
o`0001Oooooo1_l000002?oooooo0000o`000?o^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo000Yooooo`;o00002Oooool2o`0000;ooooo0_l0000=ooooo`;o
00000oooool2o`0005Wooooo0_l000000ooooooo0000o`00000;ooooo`;o00000oooool2o`0000[o
oooo0_l000000ooooooo0000o`00000<ooooo`;o00004_ooool2o`0001Kooooo0_l00018ooooo`;o
000000Coooooo`000?l0003ooooo1?l0000?ooooo`00:Oooool00ol0003oooooooooo`03ooooo`;o
00001oooool4o`0000_ooooo0_l00003ooooo`;o00002Oooool2o`0001_ooooo0_l00004ooooo`;o
0000:oooool2o`000003ooooool0003o000000cooooo0_l000001?oooooo0000o`000?l0000Poooo
o`;o0000<?ooool2o`0000gooooo0_l0000Gooooo`;o00006oooool4o`0000oooooo000Yooooo`03
o`000?oooooooooo00;o000000?oooooo`000?l000002Oooool2o`0001_ooooo0_l0000Kooooo`;o
00001?ooool2o`0003cooooo0_l000000ooooooo0000o`00000?ooooo`;o00004?ooool2o`00013o
oooo0_l0000Nooooo`;o00003Oooool2o`0001Oooooo0_l0000@ooooo`;o00003_ooool2o`0000co
oooo000Yooooo`Go0000Boooool2o`0000[ooooo0_l00015ooooo`;o00001_ooool2o`0001[ooooo
0_l0000booooo`;o00006_ooool2o`0000Sooooo0_l000000ooooooo0000o`00000;ooooo`;o0000
3?ooool002Wooooo0ol0000Vooooo`;o00009Oooool2o`0000[ooooo0_l0000;ooooo`;o0000@?oo
ool2o`0000kooooo0_l0000Eooooo`;o00000oooool2o`0002;ooooo0_l0000Jooooo`;o00002ooo
ool2o`0001Wooooo000Qoooooooo0000A?l00004ooooo`00:Oooool00ol0003oooooooooo`06oooo
o`;o000000?oooooo`000?ooool02oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool00_ooool2o`0000Gooooo0ol000000ooooooo0000o`000007oooo
o`03o`000?oooooooooo00Oooooo0ol0000;ooooo`03o`000?oooooooooo00Cooooo0_l00003oooo
o`03o`000?oooooooooo00[ooooo00Co0000oooooooooooooooo0_l00006ooooo`?o00000_ooool2
o`0000Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`;o00001Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo0_l000000ooooooo0000ooooo`02
o`0000Sooooo0_l0000;ooooo`?o00002Oooool00ol0003oooooooooo`06ooooo`;o000000?ooooo
o`000?ooool02_ooool3o`0000Gooooo0_l00003ooooo`03o`000?oooooooooo00Cooooo0_l00003
ooooo`03o`000?oooooooooo00;o00001oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo000Yooooo`04o`000?ooooooooooooooo`;o00000oooool2o`0002Cooooo0_l00003
ooooo`;o00001oooool3o`000003ooooool0003o0000017ooooo0_l0000Hooooo`;o00002oooool0
0ol0003oooooooooo`0>ooooo`;o00004_ooool2o`0000;ooooo0_l0000:ooooo`;o00001?ooool3
o`0000gooooo0_l0000>ooooo`;o00001?ooool4o`0001Gooooo00?o0000ooooooooool02_ooool2
o`0000[ooooo0_l0000=ooooo`;o00004?ooool2o`000003ooooool0003ooooo00_ooooo000Yoooo
o`04o`000?ooooooooooooooo`;o0000:Oooool2o`0000?ooooo0_l0000@ooooo`;o00009_ooool2
o`0002_ooooo0_l00003ooooo`;o00000_ooool2o`0000[ooooo0_l00004ooooo`;o00001Oooool2
o`0000_ooooo0_l0000:ooooo`;o00001?ooool2o`00017ooooo0_l0000Mooooo`?o00003oooool2
o`0000gooooo0_l0000>ooooo`00:Oooool00ol0003oooooooooo`0oooooo`;o00000_ooool2o`00
03[ooooo0_l0000Gooooo`;o00008?ooool3o`0000[ooooo0_l0000Sooooo`;o00006_ooool2o`00
00;ooooo0_l0000?ooooo`;o00001_ooool2o`0001Gooooo000Yooooo`;o00001_ooool2o`0000;o
oooo0_l0000>ooooo`;o00006_ooool2o`0000Sooooo0_l0000gooooo`?o00001?ooool2o`00017o
oooo0_l0000Wooooo`;o00002Oooool2o`0002Kooooo0_l0000Hooooo`;o00006oooool2o`0001Go
oooo000Yooooo`03o`000?oooooooooo00Gooooo0_l00002ooooo`;o00003_ooool2o`0001[ooooo
1Ol0000Iooooo`;o00000oooool2o`0001kooooo0ol00007ooooo`;o00000oooool2o`0000Wooooo
0_l000000ooooooo0000o`00000;ooooo`;o00008_ooool2o`0002Kooooo0_l00009ooooo`;o0000
@Oooool002Wooooo00?o0000ooooooooool0=_ooool4o`00017ooooo0_l00006ooooo`;o00000ooo
ool2o`0001Wooooo0_l0000=ooooo`;o00000oooool2o`0000_ooooo0ol000000ooooooo0000o`00
0008ooooo`;o00009Oooool2o`0000[ooooo0_l0000Dooooo`;o00001oooool2o`0000?ooooo0_l0
000Uooooo`;o00006_ooool002Wooooo00?o0000ooooooooool07Oooool2o`0000Cooooo0_l00006
ooooo`;o00005oooool2o`0000Cooooo0ol00002ooooo`;o00005oooool2o`0000Wooooo0_l0000<
ooooo`;o00004Oooool2o`0000;ooooo0_l0000_ooooo`;o00001_ooool2o`0000;ooooo0_l0000D
ooooo`;o00001oooool2o`0001_ooooo0_l0000=ooooo`;o00006_ooool002Wooooo00?o0000oooo
ooooool06_ooool5o`0000Cooooo0_l00004ooooo`Co00001_ooool2o`0000Gooooo0_l00004oooo
o`;o00000_ooool2o`0000Cooooo0_l00003ooooo`;o00001Oooool2o`00013ooooo0_l00008oooo
o`;o00003Oooool2o`0000;ooooo0_l00002ooooo`;o0000A_ooool2o`0000Cooooo0_l0000hoooo
o`;o00000_ooool3o`0002Cooooo000Yooooo`;o00006oooool4o`0000_ooooo0_l00008ooooo`;o
00001Oooool2o`0000Cooooo0_l0000?ooooo`;o00000oooool2o`0001Gooooo0_l00003ooooo`;o
00004Oooool2o`0000;ooooo0_l0000Hooooo`;o00000_ooool2o`0002?ooooo0_l00009ooooo`;o
00007?ooool2o`0001kooooo0ol0000Tooooo`00:Oooool00ol0003oooooooooo`02ooooo`;o0000
3_ooool2o`00017ooooo0_l0000Booooo`;o00005_ooool2o`0001[ooooo0_l00002ooooo`;o0000
<?ooool6o`0000;ooooo0_l0000Oooooo`?o00001Oooool2o`0001[ooooo0_l00003ooooo`;o0000
5_ooool2o`00013ooooo0_l00004ooooo`;o00005Oooool002Wooooo00?o0000ooooooooool00_oo
ool2o`0000kooooo0_l0000>ooooo`;o000000?oooooo`000?l000000oooool2o`0000cooooo0ol0
0007ooooo`;o00007_ooool2o`0000gooooo0_l0000booooo`Go000000?oooooo`000?l000003Ooo
ool2o`00017ooooo0_l00005ooooo`;o00006?ooool4o`0001_ooooo0_l00003ooooo`;o00001?oo
ool2o`0000Gooooo0_l00004ooooo`;o00001?ooool2o`0000oooooo000Yooooo`;o00006?ooool2
o`0000Wooooo0_l00006ooooo`;o00003?ooool2o`0000Sooooo0_l0000Nooooo`;o0000A?ooool2
o`0000gooooo0_l000000ooooooo0000o`00000Dooooo`;o00007?ooool2o`0002;ooooo0_l00004
ooooo`;o00000_ooool2o`0000gooooo0_l0000?ooooo`00:Oooool2o`0001Sooooo0ol00006oooo
o`;o0000I_ooool2o`0002Cooooo0_l00007ooooo`;o00003Oooool2o`0000Sooooo0_l0001:oooo
o`;o00001?ooool2o`0001Sooooo000Yooooo`;o00002?ooool2o`0000oooooo0_l00006ooooo`;o
0000<oooool2o`000003ooooool0003o000002kooooo0_l0000Tooooo`?o00005Oooool2o`0001_o
oooo0_l0000mooooo`;o00006?ooool002Wooooo00?o0000ooooooooool01oooool2o`0000Kooooo
0_l0000Mooooo`;o00000_ooool2o`0000;ooooo0_l0000Mooooo`;o000000?oooooo`000?l00000
8?ooool2o`0001[ooooo0_l0000Gooooo`;o00007Oooool2o`0001?ooooo0_l00018ooooo`;o0000
3Oooool002Wooooo00Co0000ooooool0003o00003_ooool2o`0001Oooooo0_l00004ooooo`;o0000
0_ooool2o`0000;ooooo0_l0000Yooooo`;o00001?ooool2o`0000gooooo0_l00002ooooo`;o0000
5oooool2o`000003ooooool0003o000002Gooooo0_l0000?ooooo`;o0000:_ooool2o`0000;ooooo
0_l0000Wooooo`;o00001?ooool2o`0000gooooo000Yooooo`04o`000?oooooo0000o`0001cooooo
0_l00009ooooo`;o00002?ooool2o`0002gooooo0_l00004ooooo`;o00003Oooool2o`0001_ooooo
0_l00006ooooo`;o00001oooool2o`0000Sooooo0_l0000=ooooo`;o00002Oooool2o`00033ooooo
0ol000000ooooooo0000o`00000Wooooo`;o00004oooool002Wooooo00?o0000ooooooooool07Ooo
ool3o`0001kooooo0_l0001Kooooo`;o00001oooool2o`0000Sooooo0_l0000Hooooo`;o0000<Ooo
ool2o`0000Gooooo0_l0000Cooooo`;o00002oooool2o`0001Kooooo000Yooooo`;o00007oooool2
o`0001kooooo0_l0000`ooooo`;o0000T?ooool2o`0000cooooo0_l00005ooooo`;o00002oooool2
o`0001Kooooo000Yooooo`03o`000?oooooooooo073ooooo0_l0000]ooooo`;o0000<_ooool2o`00
01gooooo0_l0000Fooooo`;o00001?ooool2o`0002[ooooo0006ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`0@ooooo`?o0000;_ooool2o`0004Cooooo0_l0000;ooooo`;o00002Oooool2
o`0001Oooooo0_l0000Iooooo`;o00000oooool2o`0001Sooooo1?l00008ooooo`;o00000_ooool2
o`0000Kooooo0_l000000ooooooo0000o`00000@ooooo`;o00006oooool000Kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0@ooooo`Co00000_ooool2o`0002Gooooo0_l0
0002ooooo`;o0000;?ooool2o`0000Kooooo0_l0000>ooooo`;o00002?ooool2o`000003ooooool0
003o000001oooooo0_l000000ooooooo0000o`000006ooooo`;o00005_ooool2o`0001[ooooo0_l0
0008ooooo`;o00000_ooool2o`0000Wooooo0_l0000@ooooo`;o00006oooool000Kooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`;o00003_ooool2o`0000;ooooo0_l0000:ooooo`;o00003?oo
ool2o`0000_ooooo0_l0000`ooooo`;o00001_ooool2o`0001Sooooo0_l0000Rooooo`;o00002Ooo
ool2o`0000?ooooo0_l00019ooooo`;o0000:_ooool000Kooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0000;ooooo0_l0
0006ooooo`;o00005_ooool2o`0000cooooo0_l00012ooooo`;o0000Coooool2o`0001Cooooo0_l0
000Dooooo`;o00007Oooool2o`0002[ooooo0006ooooo`05o`000?ooooooooooooooool000003_oo
ool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`0:ooooo`;o00008_ooool2o`0001Gooooo0_l0000]ooooo`;o00007?ooool2o`0004Oooooo
0_l0000Dooooo`;o0000;Oooool2o`0001[ooooo0006ooooo`05oa0@4?ooooooooooooooool@4100
3oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
9Oooool2o`0000Oooooo0_l0000Eooooo`;o0000Boooool2o`0001cooooo0_l00002ooooo`;o0000
<Oooool2o`00023ooooo0_l0000Eooooo`;o00001Oooool2o`0001?ooooo0006ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0:ooooo`;o00006Oooool2o`0002Kooooo0_l0001Qooooo`;o
00000_ooool2o`0001Cooooo0_l0000Jooooo`?o00008?ooool2o`0001cooooo0_l0000Cooooo`00
1_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co00001_ooool00ol0003oooooooooo`0:ooooo`;o0000>Oooool2o`0000Kooooo0_l0000Eoooo
o`;o00006_ooool2o`0004Sooooo0_l0000Eooooo`;o00000oooool2o`0002oooooo0_l0000Soooo
o`00:Oooool2o`0003kooooo0_l00006ooooo`;o00005oooool2o`0000Cooooo0_l0000Iooooo`?o
00001?ooool2o`0003Cooooo0_l0000Sooooo`;o0000=?ooool2o`0002?ooooo000Yooooo`03o`00
0?oooooooooo00oooooo0_l0000/ooooo`;o00002Oooool2o`0001Cooooo0_l0000Oooooo`;o0000
1Oooool2o`0000;ooooo0_l0000`ooooo`;o0000<oooool2o`0004Wooooo000Yooooo`03o`000?oo
oooooooo00oooooo0_l0000>ooooo`;o00009_ooool3o`00043ooooo0_l00004ooooo`;o0000:ooo
ool2o`0003;ooooo0_l00019ooooo`00:Oooool00ol0003oooooooooo`04ooooo`;o000000?ooooo
o`000?l000001?l0000Booooo`;o00001_ooool2o`0001Oooooo0_l00004ooooo`Go00006?ooool2
o`0002Wooooo1?l0000[ooooo`;o0000;_ooool2o`0004gooooo000Yooooo`03o`000?oooooooooo
00Cooooo0_l000000ooooooo0000o`000004o`0001[ooooo0_l0000Gooooo`;o00001?ooool2o`00
0003ooooool0003o000000_ooooo0_l00003ooooo`;o00001_ooool2o`0002Wooooo0_l0001Moooo
o`;o0000COooool002Wooooo0_l0001Gooooo`;o00000oooool2o`000:?ooooo0_l0000jooooo`00
:Oooool00ol0003oooooooooo`1booooo`;o0000C_ooool2o`0000gooooo0_l0000]ooooo`;o0000
1Oooool2o`0003?ooooo000Yooooo`03o`000?oooooooooo033ooooo0_l0000Wooooo`;o00005ooo
ool2o`0004kooooo0_l0000=ooooo`;o0000=?ooool2o`0003?ooooo000Yooooo`03o`000?oooooo
oooo013ooooo0_l0000Booooo`;o00002_ooool2o`0002Oooooo0_l0003Qooooo`00:Oooool00ol0
003oooooooooo`0@ooooo`;o00004_ooool2o`0004?ooooo0_l00009ooooo`;o0000B?ooool2o`00
07cooooo000Yooooo`;o0000J_ooool2o`0000Wooooo0_l00018ooooo`Co0000:Oooool2o`0001Co
oooo0_l00002ooooo`;o0000=Oooool002Wooooo00Co0000oooooooooooooooo0_l0001?ooooo`;o
0000B?ooool2o`0002;ooooo0_l0000Yooooo`;o00003Oooool2o`0000Gooooo0_l00002ooooo`;o
00003?ooool2o`0002Oooooo000Yooooo`04o`000?ooooooooooooooo`;o00007?ooool2o`00037o
oooo0_l00018ooooo`;o0000@Oooool2o`0001Wooooo0_l0000Gooooo`;o00005Oooool2o`00013o
oooo000Yooooo`03o`000?oooooooooo00cooooo0_l0000Aooooo`;o00004oooool2o`000:Wooooo
0_l0000Eooooo`;o0000<_ooool2o`00013ooooo000Yooooo`03o`000?oooooooooo00Gooooo0_l0
0005ooooo`;o00009_ooool2o`0000Gooooo0_l00006ooooo`;o0000<?ooool2o`0001?ooooo0_l0
000;ooooo`;o00004oooool2o`0000Cooooo0_l000000ooooooo0000o`00000Aooooo`;o00005Ooo
ool2o`0000Kooooo0_l0000=ooooo`;o00004Oooool2o`0000kooooo0ol0000Pooooo`00:Oooool2
o`0000Gooooo0ol0000>ooooo`;o00009?ooool2o`0000Kooooo0_l00009ooooo`;o00000oooool2
o`0001Wooooo0_l00005ooooo`?o00003?ooool2o`0000Cooooo0_l0000;ooooo`;o00004oooool2
o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o00003Oooool2o`0000cooooo0_l00002
ooooo`Co000000?oooooo`000?l000001_ooool2o`0000kooooo0_l0000@ooooo`;o00003_ooool3
o`00023ooooo000Yooooo`03o`000?oooooooooo00Cooooo0_l0000?ooooo`;o0000=oooool2o`00
00?ooooo0_l0000Gooooo`Co00001_ooool2o`0000cooooo0_l0000cooooo`;o00001_ooool2o`00
01?ooooo0_l00002ooooo`Go00003Oooool2o`0000Cooooo0_l00003ooooo`;o0000=_ooool2o`00
00_ooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01Gooooo0_l0001:ooooo`;o00002Oooool2
o`0000?ooooo0_l0000?ooooo`;o0000?Oooool2o`0001Wooooo0ol0000=ooooo`;o00001?ooool2
o`0003_ooooo0_l0000;ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0HOooool2o`0000kooooo0_l0000?
ooooo`;o0000I?ooool2o`0005;ooooo000>ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`03ooooo`?o0000j?ooool2o`0005;ooooo000>ooooo`05o`000?oooooooooo
ooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool0
00kooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Eooo
ool2o`000>?ooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0
001Hooooo`;o0000hoooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0;Kooooo0_l00024ooooo`00
:Oooool00ol0003oooooooooo`2fooooo`;o0000Q?ooool002Wooooo0_l0003oooooockooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo
00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo?Oooool0
00Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@
413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03
ooooo`?o0000oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Q
ooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool0
00Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@
oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo
1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
01oooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo?Oooool0027o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`00
0?oooooooooo00Gooooo0ol0003oooooocgooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001oooooo00?oEEEEofIVI_l00000
oooooom7ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .25843 Mdot
.02762 .2612 Mdot
.02952 .27678 Mdot
.03143 .2966 Mdot
.03333 .33062 Mdot
.03524 .37148 Mdot
.03714 .31153 Mdot
.03905 .37908 Mdot
.04095 .28559 Mdot
.04286 .34187 Mdot
.04476 .34571 Mdot
.04667 .41228 Mdot
.04857 .3771 Mdot
.05048 .35171 Mdot
.05238 .4238 Mdot
.05429 .25991 Mdot
.05619 .28766 Mdot
.0581 .38127 Mdot
.06 .2529 Mdot
.0619 .40085 Mdot
.06381 .38845 Mdot
.06571 .32011 Mdot
.06762 .34698 Mdot
.06952 .39009 Mdot
.07143 .44668 Mdot
.07333 .35712 Mdot
.07524 .32473 Mdot
.07714 .2544 Mdot
.07905 .38696 Mdot
.08095 .2734 Mdot
.08286 .40146 Mdot
.08476 .27832 Mdot
.08667 .36197 Mdot
.08857 .34747 Mdot
.09048 .37809 Mdot
.09238 .40599 Mdot
.09429 .26214 Mdot
.09619 .27427 Mdot
.0981 .36051 Mdot
.1 .41821 Mdot
.1019 .4469 Mdot
.10381 .36525 Mdot
.10571 .38725 Mdot
.10762 .25186 Mdot
.10952 .2918 Mdot
.11143 .36464 Mdot
.11333 .34955 Mdot
.11524 .23641 Mdot
.11714 .28391 Mdot
.11905 .38236 Mdot
.12095 .23616 Mdot
.12286 .33879 Mdot
.12476 .223 Mdot
.12667 .38598 Mdot
.12857 .38825 Mdot
.13048 .32671 Mdot
.13238 .38608 Mdot
.13429 .28108 Mdot
.13619 .23051 Mdot
.1381 .30458 Mdot
.14 .36672 Mdot
.1419 .44788 Mdot
.14381 .35252 Mdot
.14571 .3144 Mdot
.14762 .36843 Mdot
.14952 .30051 Mdot
.15143 .33923 Mdot
.15333 .25824 Mdot
.15524 .27601 Mdot
.15714 .39986 Mdot
.15905 .29315 Mdot
.16095 .30952 Mdot
.16286 .34442 Mdot
.16476 .32073 Mdot
.16667 .35257 Mdot
.16857 .31374 Mdot
.17048 .22318 Mdot
.17238 .36223 Mdot
.17429 .35341 Mdot
.17619 .28767 Mdot
.1781 .41494 Mdot
.18 .27065 Mdot
.1819 .30973 Mdot
.18381 .3682 Mdot
.18571 .35153 Mdot
.18762 .25982 Mdot
.18952 .33558 Mdot
.19143 .3534 Mdot
.19333 .2605 Mdot
.19524 .25941 Mdot
.19714 .44763 Mdot
.19905 .30685 Mdot
.20095 .33711 Mdot
.20286 .35822 Mdot
.20476 .33277 Mdot
.20667 .3337 Mdot
.20857 .35133 Mdot
.21048 .24381 Mdot
.21238 .22743 Mdot
.21429 .25936 Mdot
.21619 .24464 Mdot
.2181 .24573 Mdot
.22 .41334 Mdot
.2219 .24123 Mdot
.22381 .41308 Mdot
.22571 .35476 Mdot
.22762 .31261 Mdot
.22952 .25235 Mdot
.23143 .33741 Mdot
.23333 .40159 Mdot
.23524 .3485 Mdot
.23714 .30556 Mdot
.23905 .27588 Mdot
.24095 .40995 Mdot
.24286 .35714 Mdot
.24476 .32533 Mdot
.24667 .36655 Mdot
.24857 .30936 Mdot
.25048 .29353 Mdot
.25238 .26063 Mdot
.25429 .37746 Mdot
.25619 .45693 Mdot
.2581 .37778 Mdot
.26 .38623 Mdot
.2619 .40148 Mdot
.26381 .28037 Mdot
.26571 .40315 Mdot
.26762 .3612 Mdot
.26952 .24554 Mdot
.27143 .31863 Mdot
.27333 .3416 Mdot
.27524 .23823 Mdot
.27714 .42592 Mdot
.27905 .37125 Mdot
.28095 .38428 Mdot
.28286 .36967 Mdot
.28476 .28713 Mdot
.28667 .39342 Mdot
.28857 .34338 Mdot
.29048 .38152 Mdot
.29238 .42579 Mdot
.29429 .41913 Mdot
.29619 .3336 Mdot
.2981 .26427 Mdot
.3 .28736 Mdot
.3019 .40643 Mdot
.30381 .33581 Mdot
.30571 .40729 Mdot
.30762 .26338 Mdot
.30952 .35796 Mdot
.31143 .46239 Mdot
.31333 .2447 Mdot
.31524 .30914 Mdot
.31714 .39123 Mdot
.31905 .31555 Mdot
.32095 .34021 Mdot
.32286 .30043 Mdot
.32476 .34858 Mdot
.32667 .31324 Mdot
.32857 .25908 Mdot
.33048 .29744 Mdot
.33238 .33328 Mdot
.33429 .35632 Mdot
.33619 .44414 Mdot
.3381 .41139 Mdot
.34 .38488 Mdot
.3419 .24602 Mdot
.34381 .33176 Mdot
.34571 .41611 Mdot
.34762 .28153 Mdot
.34952 .30877 Mdot
.35143 .39005 Mdot
.35333 .3372 Mdot
.35524 .2952 Mdot
.35714 .33893 Mdot
.35905 .27076 Mdot
.36095 .36918 Mdot
.36286 .34204 Mdot
.36476 .34301 Mdot
.36667 .324 Mdot
.36857 .37789 Mdot
.37048 .32945 Mdot
.37238 .42996 Mdot
.37429 .29272 Mdot
.37619 .4492 Mdot
.3781 .28433 Mdot
.38 .28226 Mdot
.3819 .36063 Mdot
.38381 .26702 Mdot
.38571 .44147 Mdot
.38762 .38698 Mdot
.38952 .45924 Mdot
.39143 .40711 Mdot
.39333 .29249 Mdot
.39524 .44895 Mdot
.39714 .3657 Mdot
.39905 .4564 Mdot
.40095 .41884 Mdot
.40286 .35412 Mdot
.40476 .27529 Mdot
.40667 .33764 Mdot
.40857 .3063 Mdot
.41048 .30984 Mdot
.41238 .30299 Mdot
.41429 .32865 Mdot
.41619 .2563 Mdot
.4181 .23978 Mdot
.42 .26371 Mdot
.4219 .36208 Mdot
.42381 .31276 Mdot
.42571 .26903 Mdot
.42762 .34516 Mdot
.42952 .35116 Mdot
.43143 .36386 Mdot
.43333 .41624 Mdot
.43524 .28262 Mdot
.43714 .24317 Mdot
.43905 .36472 Mdot
.44095 .44552 Mdot
.44286 .28556 Mdot
.44476 .30905 Mdot
.44667 .40896 Mdot
.44857 .36693 Mdot
.45048 .22937 Mdot
.45238 .41459 Mdot
.45429 .41437 Mdot
.45619 .2712 Mdot
.4581 .30304 Mdot
.46 .24722 Mdot
.4619 .33782 Mdot
.46381 .42464 Mdot
.46571 .45728 Mdot
.46762 .25883 Mdot
.46952 .27084 Mdot
.47143 .24704 Mdot
.47333 .25092 Mdot
.47524 .32999 Mdot
.47714 .4574 Mdot
.47905 .28523 Mdot
.48095 .23806 Mdot
.48286 .37314 Mdot
.48476 .23908 Mdot
.48667 .44654 Mdot
.48857 .38251 Mdot
.49048 .41911 Mdot
.49238 .29244 Mdot
.49429 .27656 Mdot
.49619 .32964 Mdot
.4981 .29961 Mdot
.5 .25422 Mdot
.5019 .28895 Mdot
.50381 .3532 Mdot
.50571 .45481 Mdot
.50762 .32444 Mdot
.50952 .29511 Mdot
.51143 .28237 Mdot
.51333 .35097 Mdot
.51524 .29943 Mdot
.51714 .39063 Mdot
.51905 .31482 Mdot
.52095 .38212 Mdot
.52286 .22945 Mdot
.52476 .26493 Mdot
.52667 .33057 Mdot
.52857 .41402 Mdot
.53048 .32762 Mdot
.53238 .24511 Mdot
.53429 .27077 Mdot
.53619 .34871 Mdot
.5381 .37404 Mdot
.54 .39897 Mdot
.5419 .33308 Mdot
.54381 .40622 Mdot
.54571 .38938 Mdot
.54762 .34056 Mdot
.54952 .27689 Mdot
.55143 .3061 Mdot
.55333 .29759 Mdot
.55524 .27344 Mdot
.55714 .24273 Mdot
.55905 .34838 Mdot
.56095 .34939 Mdot
.56286 .37088 Mdot
.56476 .31946 Mdot
.56667 .30889 Mdot
.56857 .25773 Mdot
.57048 .40577 Mdot
.57238 .25307 Mdot
.57429 .32138 Mdot
.57619 .30796 Mdot
.5781 .41685 Mdot
.58 .36134 Mdot
.5819 .41348 Mdot
.58381 .35926 Mdot
.58571 .23177 Mdot
.58762 .4134 Mdot
.58952 .23033 Mdot
.59143 .28557 Mdot
.59333 .24034 Mdot
.59524 .4499 Mdot
.59714 .41999 Mdot
.59905 .42022 Mdot
.60095 .42844 Mdot
.60286 .29161 Mdot
.60476 .38978 Mdot
.60667 .23805 Mdot
.60857 .27807 Mdot
.61048 .44476 Mdot
.61238 .34997 Mdot
.61429 .24287 Mdot
.61619 .34701 Mdot
.6181 .28324 Mdot
.62 .35091 Mdot
.6219 .29682 Mdot
.62381 .37359 Mdot
.62571 .46217 Mdot
.62762 .32796 Mdot
.62952 .29522 Mdot
.63143 .3579 Mdot
.63333 .37818 Mdot
.63524 .32804 Mdot
.63714 .43245 Mdot
.63905 .4557 Mdot
.64095 .41267 Mdot
.64286 .26397 Mdot
.64476 .37203 Mdot
.64667 .36931 Mdot
.64857 .33789 Mdot
.65048 .30326 Mdot
.65238 .29408 Mdot
.65429 .29923 Mdot
.65619 .30362 Mdot
.6581 .39819 Mdot
.66 .2833 Mdot
.6619 .33152 Mdot
.66381 .33683 Mdot
.66571 .31642 Mdot
.66762 .30124 Mdot
.66952 .25023 Mdot
.67143 .3759 Mdot
.67333 .38489 Mdot
.67524 .33256 Mdot
.67714 .32336 Mdot
.67905 .21866 Mdot
.68095 .34382 Mdot
.68286 .26159 Mdot
.68476 .31685 Mdot
.68667 .34826 Mdot
.68857 .32931 Mdot
.69048 .39577 Mdot
.69238 .29682 Mdot
.69429 .33927 Mdot
.69619 .36402 Mdot
.6981 .42128 Mdot
.7 .40909 Mdot
.7019 .24405 Mdot
.70381 .40437 Mdot
.70571 .30614 Mdot
.70762 .33579 Mdot
.70952 .39432 Mdot
.71143 .24711 Mdot
.71333 .409 Mdot
.71524 .41324 Mdot
.71714 .41925 Mdot
.71905 .42483 Mdot
.72095 .43471 Mdot
.72286 .4489 Mdot
.72476 .28452 Mdot
.72667 .259 Mdot
.72857 .42692 Mdot
.73048 .38293 Mdot
.73238 .27987 Mdot
.73429 .41086 Mdot
.73619 .33945 Mdot
.7381 .36317 Mdot
.74 .24812 Mdot
.7419 .25246 Mdot
.74381 .23828 Mdot
.74571 .24905 Mdot
.74762 .3066 Mdot
.74952 .34203 Mdot
.75143 .25569 Mdot
.75333 .33768 Mdot
.75524 .44152 Mdot
.75714 .37633 Mdot
.75905 .2468 Mdot
.76095 .3374 Mdot
.76286 .31684 Mdot
.76476 .45566 Mdot
.76667 .25445 Mdot
.76857 .29533 Mdot
.77048 .4321 Mdot
.77238 .40121 Mdot
.77429 .28996 Mdot
.77619 .32833 Mdot
.7781 .36256 Mdot
.78 .32303 Mdot
.7819 .24045 Mdot
.78381 .41668 Mdot
.78571 .44859 Mdot
.78762 .43199 Mdot
.78952 .32507 Mdot
.79143 .21992 Mdot
.79333 .33253 Mdot
.79524 .26647 Mdot
.79714 .27738 Mdot
.79905 .28834 Mdot
.80095 .39502 Mdot
.80286 .41076 Mdot
.80476 .3269 Mdot
.80667 .33824 Mdot
.80857 .33537 Mdot
.81048 .27057 Mdot
.81238 .46035 Mdot
.81429 .35486 Mdot
.81619 .41325 Mdot
.8181 .32718 Mdot
.82 .30456 Mdot
.8219 .32573 Mdot
.82381 .34697 Mdot
.82571 .34027 Mdot
.82762 .32337 Mdot
.82952 .26629 Mdot
.83143 .45992 Mdot
.83333 .37929 Mdot
.83524 .29218 Mdot
.83714 .38107 Mdot
.83905 .31302 Mdot
.84095 .31848 Mdot
.84286 .33176 Mdot
.84476 .29113 Mdot
.84667 .45681 Mdot
.84857 .32012 Mdot
.85048 .23785 Mdot
.85238 .31744 Mdot
.85429 .24634 Mdot
.85619 .27203 Mdot
.8581 .3049 Mdot
.86 .4298 Mdot
.8619 .34201 Mdot
.86381 .29994 Mdot
.86571 .21892 Mdot
.86762 .33708 Mdot
.86952 .27742 Mdot
.87143 .28246 Mdot
.87333 .41514 Mdot
.87524 .30432 Mdot
.87714 .28929 Mdot
.87905 .27511 Mdot
.88095 .38255 Mdot
.88286 .36187 Mdot
.88476 .3255 Mdot
.88667 .32741 Mdot
.88857 .31116 Mdot
.89048 .38032 Mdot
.89238 .32952 Mdot
.89429 .36262 Mdot
.89619 .24772 Mdot
.8981 .2901 Mdot
.9 .40527 Mdot
.9019 .41111 Mdot
.90381 .31091 Mdot
.90571 .36848 Mdot
.90762 .33153 Mdot
.90952 .40036 Mdot
.91143 .45482 Mdot
.91333 .34806 Mdot
.91524 .2416 Mdot
.91714 .33211 Mdot
.91905 .27757 Mdot
.92095 .39751 Mdot
.92286 .2449 Mdot
.92476 .25157 Mdot
.92667 .3643 Mdot
.92857 .3452 Mdot
.93048 .45239 Mdot
.93238 .38262 Mdot
.93429 .31196 Mdot
.93619 .38654 Mdot
.9381 .28628 Mdot
.94 .28953 Mdot
.9419 .25958 Mdot
.94381 .38566 Mdot
.94571 .38683 Mdot
.94762 .31765 Mdot
.94952 .35505 Mdot
.95143 .3031 Mdot
.95333 .32533 Mdot
.95524 .28118 Mdot
.95714 .27489 Mdot
.95905 .25339 Mdot
.96095 .26865 Mdot
.96286 .34517 Mdot
.96476 .267 Mdot
.96667 .25539 Mdot
.96857 .23058 Mdot
.97048 .41143 Mdot
.97238 .2696 Mdot
.97429 .38753 Mdot
.97619 .4241 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0<oooooo0_l0000Rooooo`;o00005_ooool2o`0002oooooo0006ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Mooooo`;o00003?ooool2o`000:;ooooo0_l0000R
ooooo`;o00005_ooool2o`0002oooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool07Oooool2o`0000cooooo0_l0000<ooooo`;o0000ooooool2ooooo`001?l00002
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool08?ooool2o`0001Oooooo0_l0001:ooooo`;o00005_oo
ool2o`0001?ooooo0_l0001hooooo`;o00003_ooool000Kooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`00023ooooo0_l0
001Sooooo`;o00005_ooool2o`0001;ooooo0ol0001hooooo`;o00003_ooool000Kooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`03o`000?oooooooooo01[ooooo1?l0002Cooooo`;o0000ROooool000Kooooo00Go
410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Jooooo`Co0000;oooool2o`0002cooooo0_l0000Booooo`?o0000
8Oooool2o`0000?ooooo0_l0000Zooooo`;o00008?ooool2o`0003Cooooo0006ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0looooo`;o00003oooool2o`0002cooooo0_l00004ooooo`;o
00003?ooool3o`0001Kooooo0_l00009ooooo`;o00000oooool4o`0002Sooooo0_l0000:ooooo`;o
00005?ooool2o`0001?ooooo0_l0000Oooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`0hoooo
o`Ko00003Oooool2o`0000cooooo0_l00008ooooo`;o00007?ooool2o`0001gooooo0_l00006oooo
o`;o00004?ooool2o`0001[ooooo0_l0000Hooooo`;o00005Oooool2o`0001;ooooo1?l0000Moooo
o`00:Oooool2o`0003Wooooo1Ol0000>ooooo`;o00003?ooool2o`0000Sooooo0_l0000Tooooo`;o
000000?oooooo`000?l000004_ooool2o`0003Cooooo0_l000000ooooooo0000o`000008ooooo`?o
00000oooool2o`0001cooooo0_l0000<ooooo`;o00001_ooool2o`0001gooooo000Yooooo`03o`00
0?oooooooooo01Oooooo0_l0000Uooooo`;o0000BOooool2o`000004ooooool0003o0000o`0003go
oooo0_l0000;ooooo`;o00002?ooool3o`0000?ooooo0_l0000Zooooo`;o00001oooool2o`0001co
oooo000Yooooo`03o`000?oooooooooo00Sooooo0_l00003ooooo`;o00002?ooool2o`0002Gooooo
0_l0001=ooooo`;o00001_ooool2o`0001Kooooo0_l0000Mooooo`;o00005Oooool2o`000003oooo
ool0003o000000?ooooo0_l0000aooooo`;o00002Oooool4o`0000oooooo000Yooooo`;o00002Ooo
ool2o`0000?ooooo0_l0000Gooooo`;o0000D_ooool2o`0000oooooo0_l00008ooooo`;o00005?oo
ool4o`0002oooooo0_l00006ooooo`;o00000oooool2o`0003cooooo1?l0000?ooooo`00:Oooool2
o`0000Oooooo0_l0000;ooooo`;o00004Oooool2o`0000Wooooo1?l00005ooooo`;o00002_ooool2
o`0001Kooooo0_l0000Jooooo`;o00003oooool2o`0001kooooo0_l0000Sooooo`;o00003?ooool2
o`0004?ooooo0_l0000Gooooo`00:Oooool2o`0000Oooooo0_l0000;ooooo`;o00007?ooool4o`00
00Gooooo0_l0000:ooooo`;o00003?ooool2o`0000;ooooo0_l00004ooooo`;o00007?ooool2o`00
01oooooo0_l0000Tooooo`;o00002oooool2o`00057ooooo0_l0000Gooooo`00:Oooool00ol0003o
ooooooooo`1Dooooo`;o00000_ooool2o`0001Kooooo0_l0000:ooooo`;o00007oooool2o`0002Co
oooo0_l0000_ooooo`;o00002Oooool2o`0002[ooooo0_l0000?ooooo`00:Oooool00ol0003ooooo
ooooo`0^ooooo`Ko000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0Tooooo`;o00000oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`?o000000?o<S8bonk^k_ooool01?ooool2o`0000?ooooo0_l0000Booooo`;o0000
2?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h0:_ooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^00;o000000?oooooonk^k_lb<S800_l000001?o^k^koooooooooooooool2o`00
02Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05o`000003oc8b<_o^k^kooooo00;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool00ol0003oooooooooo`0?ooooo`;o00000oooool2
o`0001Sooooo0_l00002ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL09?ooool2o`0000?ooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool2o`000003oooooonHV9SoMgMg
00Gooooo0_l00003ooooo`;o00004_ooool2o`0000Gooooo0_l000001_oooooo410@okZj^_oooooo
MgMgoc8b<P?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0:oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHo`000?l0003oMgMg00cooooo0_l0000Nooooo`05ogMgMolb<S;o0000o`000?mgMgL00_l0
00000onHV9SoMgMgooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wooooo0ol0
000?ooooo`;o00000oooool2o`00017ooooo0_l00009ooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo0000o`000?l@4100:_ooool00onHV9So
8B4Qonk^kP04ooooo`05oa0@4?oooooo0000o`000?l@41000oooool01Ol@413ooooooooooooooooo
410@01;ooooo0_l0000?ooooo`Co00001Oooool01Ol0003ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo02Kooooo1Ol00003ooooo`06oa0@
4?ooooooooooooooool@413ooooo0_l000001Ol@413ooooooooooooooooo410@00cooooo0_l00002
ooooo`;o000000?oooooo`000?l000002oooool2o`0000[ooooo0_l00002ooooo`05oa0@4?oooooo
ooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo000Yooooo`?o00004?oo
ool2o`0001Gooooo0_l00009ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooo000000;o00001Oooool2o`0002Cooooo00?oV9RHob4Q8Oo^k^h0
0oooool00ol0003oooooo`000002o`0000?ooooo00Go0000ooooooooooooooooo`00000Booooo`;o
00003oooool2o`0000Kooooo00?oZJVYoa0@4?ooool00_ooool01_l0003ooooooooooooooooo0000
ooooo`?o00000oooool00ol0003oooooooooo`0Oooooo`;o00001Oooool01?m4A4CogMgMooooool0
0004ooooo`06o`000?ooooooooooooooool0003ooooo0ol00003ooooo`03o`000?oooooooooo00ko
oooo0_l000000ooooooo0000o`00000;ooooo`;o00002_ooool2o`0000;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool002Wooooo00?o0000oooo
ooooool04?ooool2o`0000Sooooo0_l00004ooooo`;o00004?ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Gooooo0_l0
000Iooooo`;o00002Oooool2o`000005ofIVI_ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000?ooooo0_l0000Fooooo`;o00004Oooool00ol@413o0000okZj^P03ooooo`06
o`000?ooooooooooooooool0003ooooo1Ol000000ooooooo0000ooooo`09ooooo`;o00005Oooool2
o`0000Gooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`00000Aooooo`;o00005_ooool00ol0003o8B4Qo`000002o`0000;o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool0
02Wooooo00?o0000ooooooooool00_ooool2o`0001Kooooo0_l00004ooooo`;o00004?ooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@023ooooo0_l00008ooooo`Co00000oooool01Ol@413ooooooooooooooooo410@00?ooooo
00Co410@oooooooooooooooo1?l0000:ooooo`;o00002?ooool2o`0001;ooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413o0000o`000?oooooo410@00?ooooo00Go410@o`000?l0003ooooooa0@400:
ooooo`;o00004oooool2o`0000Sooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooo
oooo410@00?ooooo00Go410@oooooooooooooooooa0@400Aooooo`;o00004oooool2o`000004oooo
ool0003oooooooooo`;o00000_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooo
oooooooooooooa0@4003ooooo`00:Oooool00ol0003oooooooooo`02ooooo`;o00000oooool2o`00
02Cooooo0_l00003ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool2o`0000?ooooo0_l0000Fooooo`?o000000?o
V9RHoa0@4?ooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00KoMgMgoiRHV?oooooo
V9RHogMgMoooool2o`0000[ooooo0_l00005ooooo`;o00004_ooool01Ol@413oV9RHoooooonj^[[o
000000?ooooo00GoMgMgo`000?l0003oV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
7oooool2o`0000Sooooo00?ok^k^odA4A?l000000oooool2o`000004oiRHV?ooooooV9RHogMgM`;o
oooo0_l000001?nHV9SooooooiRHV?mgMgLCooooo`;o00001?ooool2o`0000_ooooo1?l00006oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000Y
ooooo`03o`000?oooooooooo00Oooooo0_l0000?ooooo`;o00003_ooool2o`0000?ooooo0_l00000
1?ooooooEEEEofIVI_l00004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo0_l00003ooooo`;o00005_ooool3o`000003ob4Q8Oo<c<cooooo00;o
000000Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04Oooool2
o`000003ooooool0003o000001;ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`04onk^k_lb
<S;o0000oc8b<P;o00000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02[ooooo00?oMgMgo`000?oo
ool00_ooool2o`000004oc8b<_l0003o<S8bonk^kP;ooooo0_l000001?lb<S;o0000oc8b<_o^k^h5
ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Cooooo0_l0000<ooooo`Ko00000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Ooo
ool2o`0001Wooooo0_l0000>ooooo`;o00006oooool2o`00023ooooo0_l00004ooooo`;o00001?oo
ool2o`0001kooooo0_l00003ooooo`;o00007?ooool2o`0000Oooooo0_l00005ooooo`;o00009?oo
ool2o`0001?ooooo0_l000000ooooooo0000o`00000fooooo`00:Oooool01?l0003oooooo`000?l0
0014ooooo`;o00006?ooool2o`0000Kooooo0_l0000_ooooo`Co00002oooool2o`0001Cooooo1?l0
0005ooooo`?o00002_ooool2o`0001Oooooo0_l0001>ooooo`00:Oooool01?l0003oooooo`000?l0
000Tooooo`;o0000=Oooool2o`000003ooooool0003o000003Cooooo0_l00003ooooo`;o00002ooo
ool2o`0001Cooooo0_l00008ooooo`;o00000_ooool2o`0000Kooooo0_l0000eooooo`;o0000<?oo
ool002Wooooo00?o0000ooooooooool08Oooool2o`0000;ooooo0_l0000Jooooo`;o00006Oooool2
o`0001_ooooo0_l0000=ooooo`;o00002oooool2o`0002oooooo1?l000000ooooooo0000o`00000_
ooooo`;o00002oooool3o`0000;ooooo0_l0000Gooooo`;o00004oooool002Wooooo00?o0000oooo
ooooool08Oooool2o`0001;ooooo0_l0000:ooooo`;o00008_ooool2o`00017ooooo0ol0000=oooo
o`;o00007?ooool2o`0000Kooooo0_l0000Fooooo`Co00003_ooool2o`0000_ooooo0_l0000Eoooo
o`;o00002oooool2o`0000?ooooo0_l0000Gooooo`;o00004oooool0027oooooool00014o`0000Co
oooo000Yooooo`04o`000?ooooooooooooooo`;o00001_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Wooooo0ol00003ooooo`;o000000Coooooo`000?l0003ooooo0ol00009oooo
o`04o`000?ooooooooooooooo`;o00001Oooool3o`0000_ooooo00?o0000ooooooooool01?ooool2
o`0000;ooooo0_l0000;ooooo`03o`000?oooooooooo00[ooooo0ol00002ooooo`;o00001Oooool2
o`0000[ooooo00?o0000ooooooooool02Oooool2o`0000_ooooo00Co0000ooooool0003o00002?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Ooo
ool01?l0003oooooooooooooool2o`0000Oooooo00?o0000ooooooooool01?ooool2o`0000?ooooo
0_l00008ooooo`?o00002oooool00ol0003oooooooooo`0:ooooo`00:Oooool00ol0003ooooooooo
o`0Sooooo`;o00001_ooool2o`0000gooooo00Co0000oooooooooooooooo0_l0000Kooooo`;o0000
00?oooooo`000?l000006?ooool00ol0003oooooooooo`02ooooo`;o00007Oooool2o`0001Oooooo
00?o0000ooooooooool04oooool2o`0000Cooooo0_l0000Gooooo`;o00001_ooool00ol0003ooooo
ooooo`0=ooooo`;o00000oooool2o`0001Sooooo0_l00002ooooo`;o00002?ooool00ol0003ooooo
ooooo`0:ooooo`00:Oooool00ol0003oooooooooo`0:ooooo`;o00007_ooool2o`00023ooooo0_l0
000=ooooo`;o0000COooool2o`0001oooooo0_l00004ooooo`;o00005oooool2o`0001Oooooo1_l0
000Looooo`;o00005Oooool002Wooooo00?o0000ooooooooool02_ooool2o`0001kooooo0_l0000P
ooooo`;o00007Oooool2o`0003gooooo0_l000000ooooooo0000o`00000Oooooo`;o00007oooool2
o`0000kooooo0_l00002ooooo`Co0000=Oooool002Wooooo0_l0000>ooooo`;o00004?ooool2o`00
02;ooooo0_l0000Vooooo`;o0000:oooool2o`0001?ooooo0_l0000Oooooo`;o00007oooool2o`00
0003ooooool0003o000000?ooooo0_l00003ooooo`Go00004?ooool3o`0001?ooooo0_l0000Coooo
o`00:Oooool00ol0003oooooooooo`0=ooooo`;o00004?ooool2o`0002;ooooo0_l0000Wooooo`;o
00003?ooool2o`00017ooooo0_l00005ooooo`;o00000_ooool2o`0000Cooooo0ol0000Mooooo`;o
000000?oooooo`000?l000003oooool2o`0001[ooooo0_l00002ooooo`;o00000oooool2o`0000?o
oooo0ol0000Booooo`Go00004Oooool2o`0001?ooooo000Yooooo`04o`000?oooooo0000o`0003Go
oooo0ol0000Kooooo`;o00002Oooool2o`0000;ooooo0_l00007ooooo`;o00003?ooool2o`00017o
oooo0_l00005ooooo`;o00002?ooool3o`0000;ooooo0_l0000Iooooo`;o000000?oooooo`000?l0
00001_ooool2o`0000?ooooo0_l00002ooooo`;o00006_ooool2o`0000Cooooo0_l0000>ooooo`;o
00003_ooool2o`0000;ooooo0_l00002ooooo`;o00007_ooool002Wooooo00Co0000ooooool0003o
0000<Oooool2o`0000;ooooo0ol0000Kooooo`Co00001oooool2o`0000;ooooo0_l0000nooooo`;o
00009?ooool2o`0000?ooooo0_l00008ooooo`;o00006_ooool2o`0000?ooooo0_l00009ooooo`;o
00004_ooool2o`0000;ooooo0_l0000Nooooo`00:Oooool00ol0003oooooooooo`0Looooo`;o0000
1oooool2o`0000_ooooo0_l000000ooooooo0000o`000008ooooo`;o00005Oooool2o`0000kooooo
0ol0000>ooooo`;o00004?ooool2o`0003[ooooo0_l00003ooooo`;o00002?ooool2o`0000;ooooo
0_l00007ooooo`;o00001?ooool4o`0000gooooo0ol0000Aooooo`;o0000;_ooool002Wooooo0_l0
0003ooooo`;o00006?ooool2o`0000Oooooo0_l0000>ooooo`;o00002?ooool2o`0000cooooo0_l0
000=ooooo`;o00002?ooool6o`0000_ooooo0_l0000@ooooo`;o00006_ooool2o`0001kooooo0_l0
0003ooooo`;o00002?ooool2o`0000_ooooo0_l00003ooooo`Go00003Oooool2o`0000Cooooo0_l0
000:ooooo`Co0000;_ooool002Wooooo00?o0000ooooooooool00_ooool3o`0002Cooooo0_l0000R
ooooo`;o00000_ooool2o`0000Wooooo0_l0000;ooooo`?o00004_ooool2o`0002Gooooo0_l0000Y
ooooo`;o00005?ooool2o`0001Kooooo0_l0000:ooooo`;o00004oooool2o`0000Wooooo0_l0000@
ooooo`00:Oooool00ol0003oooooooooo`03ooooo`;o00001Oooool2o`0000Gooooo0_l0000Foooo
o`;o00005Oooool2o`0000oooooo0_l0000:ooooo`;o00007oooool2o`00027ooooo0_l00005oooo
o`;o00004Oooool2o`0001?ooooo0ol0000[ooooo`;o00006_ooool2o`0000?ooooo0_l00009oooo
o`;o00004?ooool002Wooooo00?o0000ooooooooool01Oooool2o`0000?ooooo0_l00005ooooo`;o
00001_ooool2o`0001Gooooo0_l00006ooooo`;o00001_ooool2o`0001_ooooo0_l0000Pooooo`;o
00006Oooool2o`0000Gooooo0_l00005ooooo`?o00003oooool4o`0001?ooooo0_l0000[ooooo`;o
00006_ooool2o`00023ooooo000Yooooo`03o`000?oooooooooo00Gooooo0_l0000Booooo`;o0000
2?ooool2o`0000Gooooo0_l000001?oooooo0000o`000?ooool4o`0000Cooooo0_l00003ooooo`;o
0000=oooool2o`0000Oooooo0_l0000Fooooo`;o000000?oooooo`000?l000003Oooool2o`0000oo
oooo1?l0000looooo`;o0000:_ooool2o`0001Cooooo000Yooooo`;o00003Oooool2o`0001Gooooo
0_l00005ooooo`;o000000?oooooo`000?l000000oooool2o`0000;ooooo0_l00005ooooo`;o0000
1?ooool2o`0001?ooooo0_l00006ooooo`;o00005?ooool2o`0001oooooo0_l0000Wooooo`;o0000
>?ooool2o`0002[ooooo0_l0000Dooooo`00:Oooool00ol0003oooooooooo`0<ooooo`;o00001_oo
ool2o`00023ooooo0_l0000;ooooo`;o00001_ooool2o`0000_ooooo0_l00006ooooo`;o00003Ooo
ool2o`0003kooooo0ol0000>ooooo`;o0000N_ooool002Wooooo00?o0000ooooooooool04?ooool2
o`0000;ooooo0_l00002ooooo`;o00004_ooool2o`0001gooooo0_l0000Rooooo`;o00002oooool2
o`000004ooooool0003o0000ooooo`;o0000:oooool3o`0002;ooooo0_l0000<ooooo`;o00002ooo
ool2o`0001oooooo0_l00002ooooo`;o00002Oooool2o`0001_ooooo000Yooooo`03o`000?oooooo
oooo013ooooo0_l00004ooooo`Co00002?ooool2o`0000Sooooo0_l0000Fooooo`;o0000;_ooool2
o`0000Kooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000004gooooo0_l0
000<ooooo`;o00002oooool2o`0001oooooo0_l00002ooooo`;o00002Oooool2o`0001_ooooo000Y
ooooo`03o`000?oooooooooo01Kooooo0_l0000:ooooo`Co00002_ooool2o`0001;ooooo0_l0000:
ooooo`;o00005oooool2o`0000Wooooo0_l0000?ooooo`;o00008oooool2o`0001Wooooo0_l0001A
ooooo`;o00008_ooool002Wooooo0_l000000ooooooo0000o`00000Rooooo`;o00002_ooool2o`00
01cooooo1?l0000Gooooo`;o00009Oooool2o`00013ooooo0_l00006ooooo`;o00004Oooool2o`00
00Gooooo0ol0001Aooooo`;o00008_ooool002Wooooo00?o0000ooooooooool00_l00002ooooo`;o
0000B?ooool2o`00043ooooo0_l0000@ooooo`;o00006Oooool2o`0000Gooooo0_l00007ooooo`;o
00006Oooool2o`0005;ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool01?l0003oooooooooooooool2
o`000003ooooool0003o000000cooooo0_l0000booooo`Co00008Oooool2o`0005?ooooo0_l0000;
ooooo`;o00006Oooool2o`0001Oooooo0_l0000@ooooo`;o00009oooool000Kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool01?l0003oooooooooooooool2o`0000Cooooo0_l00009ooooo`;o0000
1oooool2o`0002Wooooo1?l00008ooooo`;o00005oooool2o`0002Gooooo0_l00008ooooo`;o0000
8_ooool2o`0001gooooo0_l0000Pooooo`?o00003?ooool2o`000003ooooool0003o000000_ooooo
0_l0000Jooooo`001_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0
2Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo0_l0000Booooo`Ko0000
9oooool2o`0000Gooooo0_l000000ooooooo0000o`00000>ooooo`;o0000;_ooool2o`0000Sooooo
0_l0000_ooooo`;o00004?ooool2o`00027ooooo0_l0000<ooooo`;o00003_ooool6o`0001Kooooo
0006ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMg
Molb<S;ooooo00Cooooo0ol00009ooooo`;o00000oooool2o`0000Oooooo0_l00004ooooo`Co0000
9oooool2o`0000Gooooo0_l0000Aooooo`;o00003Oooool2o`00037ooooo0_l0000Wooooo`;o0000
Doooool5o`0000Oooooo0_l0000<ooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo
00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool02Oooool4o`000003ooooool0003o000000Oooooo0_l00005ooooo`;o0000>oooool2o`0000Wo
oooo0_l00009ooooo`;o0000:?ooool2o`0000Oooooo0_l0000Aooooo`;o0000K?ooool2o`0000Oo
oooo0_l0000<ooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo0_l00014ooooo`;o
00002?ooool2o`0000Wooooo0_l0000cooooo`;o00006_ooool2o`0001[ooooo0_l00004ooooo`;o
00006oooool2o`0004Cooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o
^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Aoooo
o`;o0000Coooool2o`0002Cooooo0_l00009ooooo`;o00001?ooool2o`0001_ooooo0_l0000Uoooo
o`;o00007Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool02Oooool2o`0000Cooooo0_l0000F
ooooo`;o00005oooool2o`0000Oooooo0_l0001Gooooo`;o00009?ooool2o`0002?ooooo0_l0000Z
ooooo`;o00000_ooool2o`0001gooooo000Yooooo`;o00002_ooool2o`0000Cooooo0_l0000Foooo
o`;o00005oooool2o`0000Oooooo0ol0002;ooooo`;o00005?ooool2o`0002[ooooo0_l0000Qoooo
o`00:Oooool00ol0003oooooooooo`0Booooo`;o0000=_ooool2o`0000[ooooo0ol0000Iooooo`;o
0000;oooool2o`0000Oooooo0_l0000Yooooo`;o0000?Oooool2o`0002Cooooo000Yooooo`03o`00
0?oooooooooo01;ooooo0_l0000^ooooo`;o00004_ooool3o`0000Sooooo0_l0000?ooooo`;o0000
4?ooool2o`0001gooooo0_l00007ooooo`;o0000:?ooool2o`0000;ooooo0_l00005ooooo`;o0000
5?ooool2o`0001gooooo0ol0000Dooooo`;o00003Oooool002Wooooo00?o0000ooooooooool01?oo
ool2o`0003Gooooo1?l00003ooooo`;o00007Oooool2o`00027ooooo0_l000000ooooooo0000o`00
000Fooooo`;o00003oooool4o`0000oooooo0_l0000Aooooo`;o00000_ooool3o`0000Cooooo0_l0
000Dooooo`;o00000_ooool2o`0001[ooooo0_l0000Dooooo`;o00003Oooool002Wooooo00?o0000
ooooooooool01?ooool2o`0002Sooooo0_l0000;ooooo`Co00009Oooool2o`0001[ooooo0_l00004
ooooo`?o00005_ooool2o`0000gooooo1_l0000?ooooo`;o00005_ooool2o`0001Cooooo0_l00008
ooooo`;o00004?ooool2o`0002gooooo000Yooooo`;o00005_ooool2o`0001Oooooo0_l0000Soooo
o`;o00003oooool2o`00013ooooo0_l00008ooooo`;o00001?ooool2o`0000[ooooo0_l0000Joooo
o`;o00001Oooool2o`0002Cooooo0_l0000Dooooo`;o00006_ooool2o`0002gooooo000Yooooo`03
o`000?oooooooooo00Gooooo0_l0000>ooooo`;o0000??ooool2o`00027ooooo0_l0000Jooooo`;o
00008Oooool2o`0001kooooo0_l00004ooooo`;o0000Goooool002Wooooo00?o0000ooooooooool0
1Oooool2o`0004Oooooo0_l00003ooooo`;o0000=Oooool2o`0004Wooooo0_l00005ooooo`;o0000
00?oooooo`000?l00000C_ooool2o`0000_ooooo000Yooooo`03o`000?oooooooooo04kooooo0_l0
0003ooooo`;o00005oooool2o`0001cooooo0_l0000Zooooo`;o00009?ooool2o`000003ooooool0
003o000002Sooooo0_l0000Tooooo`;o00002oooool002Wooooo00?o0000ooooooooool0K?ooool2
o`0004Sooooo0_l00009ooooo`;o0000:Oooool2o`0000Cooooo0_l0000Eooooo`;o0000<Oooool0
02Wooooo0_l00032ooooo`;o00006Oooool2o`0000kooooo0_l00004ooooo`;o0000B?ooool002Wo
oooo00?o0000ooooooooool0g?ooool2o`0005kooooo000Yooooo`03o`000?oooooooooo077ooooo
0_l0001dooooo`;o0000Doooool002Wooooo00?o0000ooooooooool0HOooool2o`0000kooooo0_l0
000?ooooo`;o0000=Oooool2o`0002cooooo0_l0001Cooooo`00:Oooool00ol0003oooooooooo`0<
ooooo`;o00001oooool2o`0000_ooooo0_l0000@ooooo`;o0000:oooool2o`0001oooooo0_l0000=
ooooo`;o00009_ooool2o`0003Kooooo0_l00019ooooo`00:Oooool2o`0000gooooo0_l00007oooo
o`;o00002oooool2o`00013ooooo0_l0000hooooo`;o00001?ooool2o`0001_ooooo0_l0000Qoooo
o`;o00009oooool2o`0001;ooooo0_l00019ooooo`00:Oooool00ol0003oooooooooo`1^ooooo`;o
00001?ooool2o`00027ooooo0_l0000Kooooo`;o00009oooool2o`0003_ooooo0_l00004ooooo`;o
00006_ooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0Aoooool2o`0002cooooo0_l0000Coooo
o`;o00000_ooool2o`0000Oooooo0_l0000Yooooo`;o00009oooool2o`0001Sooooo0_l0000Coooo
o`;o00001?ooool2o`0001[ooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`17ooooo`;o0000:Oooool2o`00
0003ooooool0003o000001?ooooo0_l00002ooooo`;o0000<_ooool2o`0002Oooooo0_l0000=oooo
o`;o00001?ooool2o`0000?ooooo0_l0000eooooo`003_ooool01Ol@413ooooooooooooooooo410@
013ooooo00?o0000ooooooooool00oooool3o`0005Wooooo0_l0000Gooooo`;o0000B_ooool2o`00
03[ooooo0_l00004ooooo`;o0000>_ooool000kooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0FOooool2o`0006?ooooo0_l0001loooo
o`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005
ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooooooooooooooooa0@400<
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3o
ooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@
00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolmoooo
o`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005
ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400>
ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3o
ooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooo
oooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`;o0000oooo
oolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooo
oolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool001oooooo1?l000000ol@413o
ooooooooo`03ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo0ol0
003oooooocgooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool001oooooo00?oEEEEofIVI_l00000oooooom7ooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .34671 Mdot
.02762 .25502 Mdot
.02952 .28892 Mdot
.03143 .33793 Mdot
.03333 .26107 Mdot
.03524 .39243 Mdot
.03714 .27417 Mdot
.03905 .27186 Mdot
.04095 .232 Mdot
.04286 .29132 Mdot
.04476 .34499 Mdot
.04667 .3257 Mdot
.04857 .29231 Mdot
.05048 .32692 Mdot
.05238 .35039 Mdot
.05429 .28693 Mdot
.05619 .24749 Mdot
.0581 .29941 Mdot
.06 .31255 Mdot
.0619 .4267 Mdot
.06381 .31532 Mdot
.06571 .23841 Mdot
.06762 .25537 Mdot
.06952 .31637 Mdot
.07143 .3986 Mdot
.07333 .36982 Mdot
.07524 .35189 Mdot
.07714 .31534 Mdot
.07905 .42513 Mdot
.08095 .24639 Mdot
.08286 .34564 Mdot
.08476 .2345 Mdot
.08667 .25317 Mdot
.08857 .26998 Mdot
.09048 .32587 Mdot
.09238 .41783 Mdot
.09429 .36415 Mdot
.09619 .33676 Mdot
.0981 .41583 Mdot
.1 .33458 Mdot
.1019 .3942 Mdot
.10381 .29808 Mdot
.10571 .37347 Mdot
.10762 .34121 Mdot
.10952 .37002 Mdot
.11143 .32468 Mdot
.11333 .32478 Mdot
.11524 .275 Mdot
.11714 .35367 Mdot
.11905 .42209 Mdot
.12095 .27594 Mdot
.12286 .40861 Mdot
.12476 .28408 Mdot
.12667 .35644 Mdot
.12857 .35849 Mdot
.13048 .23049 Mdot
.13238 .28213 Mdot
.13429 .24991 Mdot
.13619 .32082 Mdot
.1381 .37631 Mdot
.14 .33689 Mdot
.1419 .46256 Mdot
.14381 .4122 Mdot
.14571 .26404 Mdot
.14762 .26206 Mdot
.14952 .22794 Mdot
.15143 .28612 Mdot
.15333 .29509 Mdot
.15524 .33852 Mdot
.15714 .33707 Mdot
.15905 .24481 Mdot
.16095 .32122 Mdot
.16286 .30008 Mdot
.16476 .26195 Mdot
.16667 .4122 Mdot
.16857 .28568 Mdot
.17048 .28357 Mdot
.17238 .35825 Mdot
.17429 .4149 Mdot
.17619 .35336 Mdot
.1781 .39032 Mdot
.18 .24834 Mdot
.1819 .33942 Mdot
.18381 .3035 Mdot
.18571 .24285 Mdot
.18762 .28556 Mdot
.18952 .26599 Mdot
.19143 .29752 Mdot
.19333 .26532 Mdot
.19524 .29028 Mdot
.19714 .40262 Mdot
.19905 .41067 Mdot
.20095 .30029 Mdot
.20286 .30656 Mdot
.20476 .28757 Mdot
.20667 .42675 Mdot
.20857 .32352 Mdot
.21048 .26391 Mdot
.21238 .27298 Mdot
.21429 .26605 Mdot
.21619 .32958 Mdot
.2181 .29393 Mdot
.22 .32886 Mdot
.2219 .32425 Mdot
.22381 .37229 Mdot
.22571 .28055 Mdot
.22762 .24432 Mdot
.22952 .2927 Mdot
.23143 .30141 Mdot
.23333 .34187 Mdot
.23524 .30928 Mdot
.23714 .34025 Mdot
.23905 .23579 Mdot
.24095 .42142 Mdot
.24286 .23345 Mdot
.24476 .28495 Mdot
.24667 .34909 Mdot
.24857 .22675 Mdot
.25048 .22874 Mdot
.25238 .36187 Mdot
.25429 .29341 Mdot
.25619 .45554 Mdot
.2581 .29821 Mdot
.26 .42568 Mdot
.2619 .34105 Mdot
.26381 .33188 Mdot
.26571 .42309 Mdot
.26762 .44121 Mdot
.26952 .27709 Mdot
.27143 .32672 Mdot
.27333 .24994 Mdot
.27524 .30635 Mdot
.27714 .35087 Mdot
.27905 .39395 Mdot
.28095 .38296 Mdot
.28286 .4215 Mdot
.28476 .38257 Mdot
.28667 .42466 Mdot
.28857 .29736 Mdot
.29048 .27765 Mdot
.29238 .35328 Mdot
.29429 .46124 Mdot
.29619 .33447 Mdot
.2981 .33016 Mdot
.3 .24752 Mdot
.3019 .42487 Mdot
.30381 .23294 Mdot
.30571 .28893 Mdot
.30762 .27207 Mdot
.30952 .30864 Mdot
.31143 .44862 Mdot
.31333 .30539 Mdot
.31524 .35191 Mdot
.31714 .31795 Mdot
.31905 .3174 Mdot
.32095 .38777 Mdot
.32286 .38942 Mdot
.32476 .41151 Mdot
.32667 .22723 Mdot
.32857 .36126 Mdot
.33048 .38796 Mdot
.33238 .37128 Mdot
.33429 .4166 Mdot
.33619 .38253 Mdot
.3381 .41088 Mdot
.34 .37383 Mdot
.3419 .33102 Mdot
.34381 .2313 Mdot
.34571 .38202 Mdot
.34762 .34146 Mdot
.34952 .39487 Mdot
.35143 .42133 Mdot
.35333 .31728 Mdot
.35524 .34667 Mdot
.35714 .27101 Mdot
.35905 .2639 Mdot
.36095 .26192 Mdot
.36286 .43121 Mdot
.36476 .38828 Mdot
.36667 .28413 Mdot
.36857 .42221 Mdot
.37048 .40547 Mdot
.37238 .35653 Mdot
.37429 .25714 Mdot
.37619 .39977 Mdot
.3781 .32692 Mdot
.38 .23354 Mdot
.3819 .44044 Mdot
.38381 .24031 Mdot
.38571 .37749 Mdot
.38762 .37884 Mdot
.38952 .44727 Mdot
.39143 .42503 Mdot
.39333 .26223 Mdot
.39524 .4594 Mdot
.39714 .25608 Mdot
.39905 .41667 Mdot
.40095 .33816 Mdot
.40286 .29709 Mdot
.40476 .39136 Mdot
.40667 .25671 Mdot
.40857 .2667 Mdot
.41048 .26793 Mdot
.41238 .32299 Mdot
.41429 .26007 Mdot
.41619 .37662 Mdot
.4181 .31648 Mdot
.42 .29096 Mdot
.4219 .39264 Mdot
.42381 .34178 Mdot
.42571 .31815 Mdot
.42762 .34711 Mdot
.42952 .257 Mdot
.43143 .35546 Mdot
.43333 .38307 Mdot
.43524 .26152 Mdot
.43714 .32562 Mdot
.43905 .34959 Mdot
.44095 .38614 Mdot
.44286 .32808 Mdot
.44476 .37709 Mdot
.44667 .31822 Mdot
.44857 .34589 Mdot
.45048 .30555 Mdot
.45238 .37494 Mdot
.45429 .39944 Mdot
.45619 .27058 Mdot
.4581 .2504 Mdot
.46 .27133 Mdot
.4619 .31185 Mdot
.46381 .35181 Mdot
.46571 .45826 Mdot
.46762 .31107 Mdot
.46952 .29886 Mdot
.47143 .3674 Mdot
.47333 .3242 Mdot
.47524 .3527 Mdot
.47714 .45179 Mdot
.47905 .34277 Mdot
.48095 .31351 Mdot
.48286 .28864 Mdot
.48476 .31454 Mdot
.48667 .46219 Mdot
.48857 .38835 Mdot
.49048 .39708 Mdot
.49238 .24499 Mdot
.49429 .23497 Mdot
.49619 .28168 Mdot
.4981 .38794 Mdot
.5 .27537 Mdot
.5019 .24597 Mdot
.50381 .41295 Mdot
.50571 .41318 Mdot
.50762 .28307 Mdot
.50952 .262 Mdot
.51143 .37761 Mdot
.51333 .36991 Mdot
.51524 .3479 Mdot
.51714 .366 Mdot
.51905 .29149 Mdot
.52095 .27724 Mdot
.52286 .29683 Mdot
.52476 .34093 Mdot
.52667 .35269 Mdot
.52857 .40401 Mdot
.53048 .31437 Mdot
.53238 .30674 Mdot
.53429 .3561 Mdot
.53619 .33236 Mdot
.5381 .38832 Mdot
.54 .42006 Mdot
.5419 .36919 Mdot
.54381 .42049 Mdot
.54571 .36376 Mdot
.54762 .28731 Mdot
.54952 .34842 Mdot
.55143 .39276 Mdot
.55333 .25602 Mdot
.55524 .26066 Mdot
.55714 .26469 Mdot
.55905 .34436 Mdot
.56095 .39063 Mdot
.56286 .4208 Mdot
.56476 .32869 Mdot
.56667 .25728 Mdot
.56857 .35988 Mdot
.57048 .31543 Mdot
.57238 .28959 Mdot
.57429 .30205 Mdot
.57619 .25157 Mdot
.5781 .4166 Mdot
.58 .31743 Mdot
.5819 .38278 Mdot
.58381 .4395 Mdot
.58571 .32403 Mdot
.58762 .33069 Mdot
.58952 .3162 Mdot
.59143 .27348 Mdot
.59333 .34257 Mdot
.59524 .45546 Mdot
.59714 .40949 Mdot
.59905 .3436 Mdot
.60095 .32053 Mdot
.60286 .35656 Mdot
.60476 .37998 Mdot
.60667 .30293 Mdot
.60857 .23441 Mdot
.61048 .39128 Mdot
.61238 .33079 Mdot
.61429 .26481 Mdot
.61619 .37081 Mdot
.6181 .27115 Mdot
.62 .25725 Mdot
.6219 .24504 Mdot
.62381 .2876 Mdot
.62571 .44414 Mdot
.62762 .29522 Mdot
.62952 .37047 Mdot
.63143 .28535 Mdot
.63333 .27449 Mdot
.63524 .31595 Mdot
.63714 .36182 Mdot
.63905 .44006 Mdot
.64095 .46176 Mdot
.64286 .31954 Mdot
.64476 .39481 Mdot
.64667 .3051 Mdot
.64857 .40629 Mdot
.65048 .25004 Mdot
.65238 .26607 Mdot
.65429 .26976 Mdot
.65619 .24382 Mdot
.6581 .30033 Mdot
.66 .37775 Mdot
.6619 .28413 Mdot
.66381 .24546 Mdot
.66571 .3284 Mdot
.66762 .32309 Mdot
.66952 .26689 Mdot
.67143 .39177 Mdot
.67333 .37423 Mdot
.67524 .371 Mdot
.67714 .2564 Mdot
.67905 .31103 Mdot
.68095 .36984 Mdot
.68286 .2558 Mdot
.68476 .26586 Mdot
.68667 .24162 Mdot
.68857 .35141 Mdot
.69048 .42425 Mdot
.69238 .23801 Mdot
.69429 .32172 Mdot
.69619 .33485 Mdot
.6981 .46193 Mdot
.7 .31965 Mdot
.7019 .34799 Mdot
.70381 .41941 Mdot
.70571 .36296 Mdot
.70762 .25569 Mdot
.70952 .42183 Mdot
.71143 .31618 Mdot
.71333 .31969 Mdot
.71524 .46331 Mdot
.71714 .39966 Mdot
.71905 .34918 Mdot
.72095 .36641 Mdot
.72286 .39599 Mdot
.72476 .32128 Mdot
.72667 .33486 Mdot
.72857 .35588 Mdot
.73048 .27795 Mdot
.73238 .31944 Mdot
.73429 .3703 Mdot
.73619 .36848 Mdot
.7381 .39358 Mdot
.74 .33503 Mdot
.7419 .2535 Mdot
.74381 .31433 Mdot
.74571 .35243 Mdot
.74762 .39074 Mdot
.74952 .25106 Mdot
.75143 .36027 Mdot
.75333 .24722 Mdot
.75524 .38564 Mdot
.75714 .25005 Mdot
.75905 .34838 Mdot
.76095 .38775 Mdot
.76286 .31434 Mdot
.76476 .42786 Mdot
.76667 .27295 Mdot
.76857 .2701 Mdot
.77048 .35986 Mdot
.77238 .34006 Mdot
.77429 .26711 Mdot
.77619 .26888 Mdot
.7781 .36397 Mdot
.78 .35277 Mdot
.7819 .26755 Mdot
.78381 .37738 Mdot
.78571 .45817 Mdot
.78762 .36036 Mdot
.78952 .24931 Mdot
.79143 .32019 Mdot
.79333 .2536 Mdot
.79524 .26787 Mdot
.79714 .25847 Mdot
.79905 .31668 Mdot
.80095 .29576 Mdot
.80286 .32321 Mdot
.80476 .35189 Mdot
.80667 .32153 Mdot
.80857 .3545 Mdot
.81048 .26975 Mdot
.81238 .43355 Mdot
.81429 .29735 Mdot
.81619 .41026 Mdot
.8181 .33789 Mdot
.82 .35052 Mdot
.8219 .32035 Mdot
.82381 .28204 Mdot
.82571 .26156 Mdot
.82762 .35393 Mdot
.82952 .28425 Mdot
.83143 .45248 Mdot
.83333 .27439 Mdot
.83524 .31076 Mdot
.83714 .33362 Mdot
.83905 .24442 Mdot
.84095 .37967 Mdot
.84286 .36784 Mdot
.84476 .34555 Mdot
.84667 .42899 Mdot
.84857 .41968 Mdot
.85048 .29996 Mdot
.85238 .21761 Mdot
.85429 .3344 Mdot
.85619 .27525 Mdot
.8581 .22846 Mdot
.86 .36185 Mdot
.8619 .34756 Mdot
.86381 .23776 Mdot
.86571 .3035 Mdot
.86762 .32603 Mdot
.86952 .27501 Mdot
.87143 .25622 Mdot
.87333 .40258 Mdot
.87524 .36071 Mdot
.87714 .40035 Mdot
.87905 .32259 Mdot
.88095 .34255 Mdot
.88286 .29067 Mdot
.88476 .27366 Mdot
.88667 .29464 Mdot
.88857 .257 Mdot
.89048 .27367 Mdot
.89238 .30459 Mdot
.89429 .41865 Mdot
.89619 .27114 Mdot
.8981 .36848 Mdot
.9 .42191 Mdot
.9019 .37355 Mdot
.90381 .2447 Mdot
.90571 .44576 Mdot
.90762 .27274 Mdot
.90952 .30376 Mdot
.91143 .41192 Mdot
.91333 .33359 Mdot
.91524 .34458 Mdot
.91714 .36842 Mdot
.91905 .2525 Mdot
.92095 .42443 Mdot
.92286 .33033 Mdot
.92476 .30295 Mdot
.92667 .33566 Mdot
.92857 .2667 Mdot
.93048 .46355 Mdot
.93238 .38223 Mdot
.93429 .28089 Mdot
.93619 .36917 Mdot
.9381 .353 Mdot
.94 .3229 Mdot
.9419 .3109 Mdot
.94381 .35318 Mdot
.94571 .38083 Mdot
.94762 .27313 Mdot
.94952 .36779 Mdot
.95143 .22768 Mdot
.95333 .25668 Mdot
.95524 .36266 Mdot
.95714 .33873 Mdot
.95905 .3105 Mdot
.96095 .30885 Mdot
.96286 .22573 Mdot
.96476 .30336 Mdot
.96667 .26069 Mdot
.96857 .29648 Mdot
.97048 .41214 Mdot
.97238 .33427 Mdot
.97429 .42409 Mdot
.97619 .346 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooo`Wooooo0_l0000c
ooooo`00:Oooool00ol0003oooooooooo`3oooooo`Sooooo0_l0000cooooo`001_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo02Gooooo0_l0000Nooooo`;o00005oooool2o`000<Oooooo0_l0
00000ooooooo0000o`00000@ooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool07ooo
ool2o`0000Cooooo0_l0000Nooooo`;o00005oooool2o`000:Wooooo0_l0000Looooo`;o000000?o
ooooo`000?l000004?ooool000Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ
8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0000;ooooo0_l0000Kooooo`;o00008_oo
ool4o`0000oooooo0_l0000;ooooo`;o00002_ooool2o`0009Sooooo0_l0000aooooo`001_ooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool00_ooool2o`0000cooooo0_l0000_ooooo`Co0000
4Oooool2o`0000_ooooo0_l0000:ooooo`;o00008oooool2o`0002;ooooo0_l00022ooooo`001_oo
ool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00[ooooo0_l00004ooooo`;o0000;oooool2o`0002gooooo
0_l0000Rooooo`;o00008_ooool2o`0001Wooooo0_l0000eooooo`;o0000<?ooool000Kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00[ooooo0_l0000Tooooo`;o0000?_ooool2o`0005oo
oooo1?l0000eooooo`;o0000<?ooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool03oooool2o`00
01Oooooo0_l00006ooooo`;o00003?ooool2o`0005?ooooo0_l000000ooooooo0000o`00000Uoooo
o`;o00002Oooool4o`0000Gooooo0_l0000_ooooo`;o00004oooool2o`0002?ooooo000Yooooo`;o
00002?ooool2o`0000Kooooo0_l0000Gooooo`;o00001?ooool2o`0000kooooo0_l0000Eooooo`;o
0000??ooool2o`000003ooooool0003o000002Gooooo0_l00009ooooo`Co00006oooool2o`0000Wo
oooo0_l0000>ooooo`;o00004oooool2o`0002?ooooo000Yooooo`03o`000?oooooooooo00Oooooo
0_l0000Gooooo`;o00003?ooool2o`0001gooooo0_l00006ooooo`;o0000<Oooool2o`0002Cooooo
0_l0000Fooooo`;o00007_ooool4o`0000Sooooo0_l0000Xooooo`;o00007_ooool002Wooooo0_l0
000;ooooo`;o00001?ooool2o`0000kooooo0_l0000[ooooo`;o0000>Oooool2o`0002Cooooo0_l0
000Fooooo`;o00002?ooool2o`0000Kooooo0_l00009ooooo`;o000000?oooooo`000?l000000_l0
000:ooooo`;o00009_ooool2o`0001kooooo000Yooooo`;o00002oooool2o`0000Cooooo0_l0001K
ooooo`;o00001Oooool2o`000003ooooool0003o000000Kooooo0_l0000Vooooo`;o00000_ooool2
o`0000oooooo0_l0000@ooooo`Co00001_ooool2o`0000Wooooo0_l0000?ooooo`?o00005_ooool2
o`0000?ooooo0_l0000Cooooo`;o00004oooool002Wooooo00Co0000ooooool0003o00008oooool2
o`0000Cooooo0_l0000mooooo`;o00000_ooool2o`0000Gooooo0_l000001?oooooo0000o`000?oo
ool2o`0000?ooooo1?l0000Eooooo`;o00003Oooool2o`0000;ooooo0_l0000?ooooo`;o00004?oo
ool2o`0002Gooooo0_l00007ooooo`;o00003Oooool2o`0000?ooooo0_l0000Cooooo`;o00000_oo
ool2o`0000oooooo000Yooooo`Co00008_ooool3o`0000Cooooo0_l0000<ooooo`;o0000;_ooool3
o`0000Sooooo0_l00005ooooo`;o00001Oooool2o`0001Gooooo0_l0000=ooooo`?o00004?ooool2
o`0004;ooooo0_l0000[ooooo`;o00003oooool002Wooooo00?o0000ooooooooool08oooool2o`00
00gooooo0ol00003ooooo`Co0000;?ooool2o`0000Wooooo0_l00003ooooo`?o0000;Oooool2o`00
013ooooo0_l0000:ooooo`;o00001?ooool2o`0000?ooooo0_l0000Kooooo`Co00000_ooool2o`00
02Wooooo0_l0000Kooooo`00:Oooool00ol0003oooooooooo`0Aooooo`;o00007Oooool5o`0000;o
oooo00?ok^k^oc8b<_l000000_l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08oooool2o`00
00Cooooo1Ol00003ooooo`03onk^k_lb<S;o000000?o00000_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo1?l0000Oooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00Gok^k^o`000?l0003o<S8bonk^kP07ooooo`?o00000oooool2o`0000?o
oooo0_l0000Fooooo`;o000000?o410@o`000?l000001?l000001olb<S;ok^k^o`000?l0003ooooo
onk^k_lb<S800_l000000oo^k^koooooooooo`0Gooooo`;o00002?ooool2o`0000Cooooo00GoA4A4
o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo000Yooooo`04o`000?ooooooooooooooo`;o00003_ooool2o`0001oo
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHo`000?l0003oMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Dooooo`;o00003Oooool2o`0000Cooooo00GoV9RHob4Q8Oo^k^koooooodA4
A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo1?l0000Oooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOo0000o`000?nHV9So
MgMg00?ooooo00KoMgMgo`000?l0003oV9RHogMgMoooool2o`0000Gooooo0_l0000Qooooo`Ko0000
00CoV9RHoooooonHV9SoMgMg0oooool01OmgMgOoV9RHo`000?l0003oMgMg00Gooooo0_l0000>oooo
o`Ko000000?oooooo`000?l000002oooool2o`000003oooooomgMgOo<S8b00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wooooo00Co0000
oooooooooooooooo0_l0000Gooooo`Co00005?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
oooo0000o`000?l@41000oooool01Ol@413ooooooooooooooooo410@00Oooooo0_l00005ooooo`;o
00001?ooool2o`0001Cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@400Cooooo`;o00001Oooool2o`00013ooooo00Go0000
oooooooooooooooooa0@4002o`000003ooooool@413ooooo00;ooooo00Ko410@oooooooooooooooo
oa0@4?ooool2o`0002Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@00Gooooo0_l00005ooooo`;o00000_ooool2o`0000?ooooo1?l00003
ooooo`;o00002oooool2o`0000;ooooo00Co0000oooooooooooo410@0oooool01Ol@413ooooooooo
oooooooo410@00?ooooo00?o410@ooooooooool00Oooool002Wooooo0_l0000Kooooo`Co00005?oo
ool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooooooool0003ooooo0ol00003ooooo`03
o`000?oooooooooo00Gooooo0_l00005ooooo`;o00006oooool00onHV9So8B4Qonk^kP03ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000001?ooooo0_l00005
ooooo`;o00003oooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo0000023ooooo0_l00006ooooo`04odA4A?oMgMgoooooo`0000Co
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000003?ooool2
o`0000;ooooo0_l0000Jooooo`05ogMgMolb<S;oooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool00Oooool002Wooooo00?o0000ooooooooool07ooo
ool2o`0000[ooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooooooooooooooo
o`000?ooool3o`0000?ooooo00?o0000ooooooooool0:_ooool00omgMgOoIVIVooooo`02ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000001;ooooo0_l00002
ooooo`;o00004_ooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo0000023ooooo0_l00006ooooo`04omgMgOmEEEGoooooo`0000Co
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool2
o`00027ooooo0_l00002ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`00:Oooool00ol0003ooooo
ooooo`06ooooo`;o00005Oooool4o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`0000Cooooo
00Go410@oooooooooooooooooa0@4003ooooo`04oa0@4?ooooooooooooooo`;o00009_ooool2o`00
00Cooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool00ol@413oooooooooo`0@ooooo`;o00000_ooool2o`0001?ooooo00?o^[Zjob4Q8Oooool00_oo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Ko410@oooooooooooooooooa0@4?ooool2o`00
00Oooooo0_l0000Mooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@41000_ooool3o`00023ooooo0_l00002ooooo`03o`000?oo
oooooooo00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
41000oooool002Wooooo0ol00006ooooo`;o00005Oooool2o`0000Kooooo0_l00004ooooo`;o0000
1?ooool2o`0000?ooooo0_l000001?nHV9SooooooiRHV?mgMgL3ooooo`04ogMgMonHV9SooooooiRH
V0;o00004_ooool2o`0001;ooooo0ol000001?nj^[[ooooooiRHV?l@4103ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo0_l0000Cooooo`;o0000
0oooool00ol@413oV9RHooooo`02o`0000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03
ogMgMonHV9Sooooo00;o000000?oooooo`000?l000001oooool2o`0001gooooo00?ok^k^odA4A?l0
00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`;o00009?ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000Yooooo`?o00000_ooool4o`0002[ooooo00?o
EEEEofIVI_l000000_l000001ooooooo0000o`000?lb<S;o0000oc8b<_o^k^h00_ooool2o`000004
oc8b<_l0003o<S8bonk^kQ?ooooo0_l0000Dooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo0_l000001?lb<S;o0000oc8b<_o^k^h>ooooo`;o0000
2_ooool2o`0000Oooooo0_l00003ooooo`03ojVYZOl@413o000000;o00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo00?ok^k^oc8b<_l000000_l0000Zooooo`03ogMgMol0003ooooo00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h05?ooool2
o`0001?ooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo000Yooooo`;o00000oooool4o`00023ooooo0_l0000;ooooo`;o00001_oo
ool2o`000003ooooool0003o000000Kooooo0_l0000dooooo`;o00007_ooool2o`00023ooooo0_l0
000fooooo`;o00006?ooool4o`0002Sooooo000Yooooo`03o`000?oooooooooo00Oooooo0_l0000=
ooooo`;o00003_ooool2o`0000[ooooo0_l00007ooooo`;o00002Oooool4o`0000Oooooo0_l0000S
ooooo`;o00005?ooool2o`0000oooooo0_l0000Oooooo`;o0000=_ooool2o`0000;ooooo0_l0000F
ooooo`;o00006?ooool2o`0000kooooo000Yooooo`03o`000?oooooooooo00Oooooo0_l0000=oooo
o`;o00004Oooool2o`0000Oooooo0_l000000ooooooo0000o`000008ooooo`;o00001oooool2o`00
00Oooooo0_l0000Sooooo`;o00005?ooool2o`0000oooooo0_l0000>ooooo`;o00006Oooool2o`00
033ooooo0_l0000:ooooo`;o00009?ooool2o`0000kooooo000Yooooo`03o`000?oooooooooo02Wo
oooo0_l00005ooooo`;o00000oooool2o`0000Sooooo0_l0000Hooooo`;o0000:_ooool2o`0002Ko
oooo0_l00009ooooo`;o00002oooool2o`000003ooooool0003o000003cooooo0_l00003ooooo`;o
00001oooool2o`0000?ooooo0_l00003ooooo`;o00002oooool2o`0000oooooo000Yooooo`03o`00
0?oooooooooo033ooooo0_l00004ooooo`;o00005Oooool2o`0000Wooooo0ol0000Zooooo`;o0000
6Oooool2o`0001Kooooo0_l0000;ooooo`;o0000A?ooool2o`0000Oooooo0_l00003ooooo`;o0000
0oooool2o`0000_ooooo0_l0000?ooooo`008Oooooooo`0004Co00001?ooool002Wooooo00?o0000
ooooooooool02?ooool2o`0000cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool2o`0000Gooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo1?l00002
ooooo`?o00002_ooool00ol0003oooooooooo`02o`0000Sooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00Co0000ooooool0003o00002Ooo
ool00ol0003oooooooooo`07ooooo`?o00000oooool2o`0000Kooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`02o`0000Sooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`;o00001?ooool3o`0000?ooooo00?o0000ooooooooool02_ooool002Wooooo00?o0000
ooooooooool02?ooool7o`0002_ooooo00?o0000ooooooooool07_ooool2o`0000Wooooo0_l0000@
ooooo`03o`000?oooooooooo00Co00004?ooool3o`0000gooooo0_l0000;ooooo`;o000000Cooooo
o`000?l0003ooooo0_l000000ooooooo0000ooooo`0:ooooo`;o00005_ooool2o`0000Wooooo0_l0
0004ooooo`;o00001_ooool01?l0003oooooooooooooool2o`0003Oooooo00?o0000ooooooooool0
2_ooool002Wooooo00?o0000ooooooooool02Oooool6o`00017ooooo0_l00006ooooo`;o0000<Ooo
ool2o`0000Wooooo0_l0000Cooooo`Co00001Oooool2o`0002Kooooo0_l000001?oooooo0000o`00
0?ooool2o`0000;ooooo0_l00009ooooo`Co00004Oooool2o`000004ooooool0003o0000o`0000Co
oooo0_l0000Aooooo`;o000000?oooooo`000?l000001Oooool2o`0003gooooo000Yooooo`03o`00
0?oooooooooo023ooooo0_l00006ooooo`;o00003_ooool2o`0000;ooooo0_l0000kooooo`;o0000
2Oooool2o`0000Oooooo0_l0000Rooooo`;o00000oooool2o`0000_ooooo0_l00006ooooo`;o0000
1oooool4o`0000;ooooo0_l00002ooooo`Co00004Oooool2o`0000;ooooo0ol00003ooooo`;o0000
4?ooool2o`0001;ooooo0_l0000Gooooo`00:Oooool2o`0000Gooooo0ol0000;ooooo`;o00001?oo
ool3o`0001gooooo0_l00002ooooo`;o00003_ooool2o`00023ooooo0_l00009ooooo`;o00001_oo
ool2o`0000[ooooo0_l0000Rooooo`;o00006?ooool2o`0000Oooooo0_l00008ooooo`;o00005ooo
ool3o`0001;ooooo0_l000000ooooooo0000o`00000Booooo`;o00005oooool002Wooooo00?o0000
ooooooooool01?ooool3o`0000_ooooo0_l00004ooooo`?o00007oooool3o`0000oooooo0_l00006
ooooo`;o00006?ooool2o`00017ooooo1?l0000Uooooo`;o00007oooool2o`0003oooooo0_l0000?
ooooo`;o00007Oooool002Wooooo00?o0000ooooooooool0>_ooool3o`0000cooooo0_l00009oooo
o`;o00003Oooool2o`0001kooooo0_l0000Looooo`;o00001oooool2o`0000Kooooo0_l00006oooo
o`;o00003oooool2o`0003Gooooo0_l0000Fooooo`;o000000?oooooo`000?l000007Oooool002Wo
oooo00?o0000ooooooooool05?ooool3o`0003;ooooo0_l00009ooooo`;o00003Oooool2o`0003co
oooo0_l0000?ooooo`;o00001_ooool2o`0001Sooooo0_l00008ooooo`;o00000oooool2o`0001go
oooo0_l00003ooooo`;o00004Oooool2o`0000?ooooo0_l0000<ooooo`;o00003Oooool002Wooooo
00Co0000ooooool0003o00004oooool3o`0000_ooooo0_l00003ooooo`;o00001_ooool2o`0002?o
oooo0_l0000Pooooo`;o0000G?ooool2o`0000Sooooo0_l00003ooooo`;o00005oooool2o`0000Wo
oooo0_l0000Fooooo`;o00001oooool2o`0000?ooooo0_l0000=ooooo`00:Oooool4o`0001Kooooo
0_l00009ooooo`;o00000oooool2o`0000Kooooo0_l0000?ooooo`?o00001_ooool2o`0001Wooooo
0_l0000@ooooo`;o00001Oooool2o`00013ooooo0_l0000<ooooo`;o00005?ooool2o`0003Sooooo
0_l0000=ooooo`;o00004_ooool2o`0001Kooooo0_l0000Booooo`00:Oooool00ol0003ooooooooo
o`03ooooo`;o00002_ooool2o`0000Kooooo0_l0000Wooooo`?o00001_ooool2o`0001Wooooo0_l0
000Gooooo`;o00001_ooool2o`0000Sooooo0_l0000<ooooo`;o00002Oooool2o`0000Wooooo1?l0
000fooooo`;o00005Oooool2o`0000[ooooo0_l00009ooooo`;o00004_ooool2o`0000_ooooo000Y
ooooo`;o00001?ooool2o`0000[ooooo0_l0000cooooo`;o00008Oooool2o`0001Gooooo0_l00005
ooooo`;o00004oooool2o`0000Wooooo0_l000000ooooooo0000o`00000;ooooo`;o00007oooool2
o`0000Cooooo0_l0000;ooooo`;o00006Oooool2o`0000Cooooo0_l0000?ooooo`;o00004_ooool2
o`0000_ooooo000Yooooo`;o00001_ooool2o`0000Kooooo0_l0000eooooo`;o00002?ooool2o`00
00[ooooo0_l0000;ooooo`;o00005Oooool2o`0000;ooooo0_l00006ooooo`;o00003_ooool2o`00
00Wooooo0_l0000[ooooo`;o00000_ooool2o`0000Cooooo0_l0000;ooooo`;o00003?ooool2o`00
00?ooooo0_l0000<ooooo`;o0000<?ooool002Wooooo00?o0000ooooooooool01Oooool2o`0000Ko
oooo0_l0000;ooooo`;o00004Oooool2o`0001oooooo0_l00003ooooo`;o00001Oooool2o`0002?o
oooo0_l000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l000003oooool2o`0003;o
oooo0_l0000@ooooo`;o00002Oooool2o`0000Kooooo1?l000001?oooooo0000o`000?ooool2o`00
027ooooo1?l0000Fooooo`00:Oooool2o`0001_ooooo0_l000001?oooooo0000o`000?l0000<oooo
o`?o00009?ooool2o`0001Oooooo0_l0000Aooooo`;o00003?ooool2o`0000oooooo1?l0000Doooo
o`;o00009oooool2o`0000?ooooo0_l00009ooooo`;o00002?ooool2o`0000Cooooo0_l0000Qoooo
o`Co00005_ooool002Wooooo00?o0000ooooooooool07Oooool3o`0000cooooo0_l0000`ooooo`;o
00003?ooool2o`0003;ooooo0_l00009ooooo`;o00002Oooool2o`0002Oooooo0_l00005ooooo`;o
00001?ooool2o`0000Cooooo0_l0000Jooooo`;o0000;?ooool002Wooooo00?o0000ooooooooool0
4oooool2o`00037ooooo0_l0000Fooooo`;o0000A?ooool2o`0000Gooooo0_l0000Dooooo`;o0000
5Oooool2o`0000cooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Eooooo`;o
00000oooool2o`0001Sooooo0_l0000Booooo`00:Oooool00ol0003oooooooooo`0Cooooo`;o0000
<Oooool2o`0004Cooooo0_l0000=ooooo`;o00001oooool2o`0001_ooooo0_l0000Eooooo`;o0000
0_ooool2o`00017ooooo0_l0000Cooooo`;o00000oooool2o`0001_ooooo1?l0000Booooo`00:Ooo
ool00ol0003oooooooooo`0<ooooo`;o00002_ooool2o`0007;ooooo0_l0000<ooooo`?o00001_oo
ool2o`0001Kooooo0_l00002ooooo`;o00003Oooool4o`0000[ooooo0_l00003ooooo`;o00008Ooo
ool2o`0000oooooo0_l00005ooooo`;o00001?ooool2o`0000;ooooo0_l0000Dooooo`00:Oooool2
o`0000gooooo0_l00009ooooo`?o00008oooool2o`00023ooooo0_l000000ooooooo0000o`00000f
ooooo`;o00001oooool2o`0001Kooooo0_l00002ooooo`;o00003Oooool4o`0000oooooo0_l0000b
ooooo`Co00000oooool2o`0000Cooooo0_l0000Hooooo`00:Oooool00ol0003oooooooooo`0Goooo
o`;o00002?ooool2o`0001[ooooo0_l0000Pooooo`;o000000?oooooo`000?l000005_ooool2o`00
00Sooooo1?l00015ooooo`;o0000B?ooool2o`0002?ooooo0006ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`0Qooooo`;o0000C_ooool2o`0000Oooooo0_l00008ooooo`Co00004Oooool2
o`0001cooooo0_l0000@ooooo`;o00000_ooool2o`0002;ooooo0_l0000@ooooo`;o0000=oooool0
00Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1?ooooo`?o00003ooo
ool2o`000003ooooool0003o000000_ooooo0_l0000=ooooo`;o00005oooool2o`0001Gooooo0_l0
0005ooooo`;o00004?ooool2o`0002Kooooo0_l0000@ooooo`;o00006oooool2o`0000?ooooo0_l0
000Eooooo`001_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04oooooo0ol0000?ooooo`;o000000?o
ooooo`000?l000006_ooool4o`0002cooooo0_l0000eooooo`;o0000=oooool2o`0000?ooooo0_l0
000Eooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00omgMgOo<S8booooo`04ooooo`?o0000G?ooool2o`000003ooooool0003o000000Wooooo0_l0
000Fooooo`;o00003_ooool2o`000003ooooool0003o000000_ooooo0_l00013ooooo`Co0000DOoo
ool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00;o0000;?ooool2o`0002cooooo
0_l000000ooooooo0000o`000009ooooo`;o00002oooool2o`0000?ooooo0_l0000Dooooo`;o0000
00?oooooo`000?l000002oooool2o`0000;ooooo0_l000000ooooooo0000o`00000>ooooo`;o0000
4_ooool2o`0001Kooooo0_l00002ooooo`;o0000DOooool000Kooooo00Go410@oooooooooooooooo
oa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`02o`0001?ooooo0_l0000Gooooo`;o00007_ooool2o`0001Gooooo0_l0000@ooooo`;o0000
0oooool2o`0002Sooooo0_l000000ooooooo0000o`00000>ooooo`;o00002Oooool2o`0000Oooooo
0_l0000Cooooo`;o000000?oooooo`000?l00000EOooool000Kooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00cooooo0_l00007ooooo`;o0000=oooool2o`0001Gooooo0_l0000[ooooo`;o
0000<?ooool2o`0001Oooooo0_l00003ooooo`;o0000F?ooool000Kooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000oooo
ooooool03?ooool2o`00063ooooo0_l0000Gooooo`;o00002Oooool2o`0004Oooooo1?l0000`oooo
o`;o0000:oooool002Wooooo0_l0000eooooo`;o0000>?ooool2o`0001Oooooo0_l0000Fooooo`;o
0000>_ooool2o`00033ooooo1?l0000[ooooo`00:Oooool00ol0003oooooooooo`0dooooo`;o0000
=_ooool2o`00037ooooo0_l0000Tooooo`;o0000A_ooool2o`0002gooooo000Yooooo`03o`000?oo
oooooooo01cooooo0_l0000Gooooo`;o0000:_ooool2o`0000Wooooo0_l00017ooooo`;o00003_oo
ool2o`0003Cooooo0_l0000oooooo`00:Oooool00ol0003oooooooooo`0Looooo`;o00001Oooool2
o`0000Gooooo0_l00009ooooo`;o00009_ooool2o`0000;ooooo0_l0000dooooo`;o00007?ooool2
o`0004Cooooo0_l0000Mooooo`;o00004Oooool2o`0000gooooo000Yooooo`03o`000?oooooooooo
01Cooooo0_l0000=ooooo`;o00001Oooool2o`000003ooooool0003o000002kooooo0_l000000ooo
oooo0000o`00000Cooooo`;o00008?ooool2o`0001Gooooo0_l0001Zooooo`;o00004Oooool2o`00
00gooooo000Yooooo`;o00004oooool4o`0001Oooooo0_l0000aooooo`;o00004oooool2o`0002_o
oooo0ol00009ooooo`;o00009oooool2o`0002cooooo0_l0000=ooooo`;o00009_ooool002Wooooo
00?o0000ooooooooool04_ooool2o`0000Oooooo0_l0000Uooooo`;o00001_ooool2o`0000Cooooo
0_l0000Dooooo`;o00000oooool2o`0003Gooooo0ol00005ooooo`;o0000:oooool4o`0002[ooooo
0_l0000=ooooo`Co00009?ooool002Wooooo00?o0000ooooooooool02Oooool2o`0000?ooooo0_l0
000;ooooo`;o00006_ooool2o`0000Wooooo0_l00004ooooo`Co00001?ooool3o`0000?ooooo0_l0
000>ooooo`;o00000oooool2o`0000Gooooo0_l0000fooooo`;o00009oooool2o`0000Cooooo0_l0
000kooooo`;o00001Oooool2o`0000oooooo0_l0000<ooooo`00:Oooool00ol0003oooooooooo`09
ooooo`;o00000oooool2o`0002Oooooo0_l0000?ooooo`;o00001oooool2o`0000?ooooo0_l0000J
ooooo`;o0000Goooool2o`0001Kooooo0_l0000Hooooo`;o00005_ooool2o`0000oooooo0_l0000<
ooooo`00:Oooool00ol0003oooooooooo`1Yooooo`;o0000P?ooool2o`0001Sooooo0_l0000eoooo
o`00:Oooool2o`0006[ooooo0_l0002?ooooo`;o0000@?ooool002Wooooo00?o0000ooooooooool0
n_ooool2o`00043ooooo000Yooooo`03o`000?oooooooooo04_ooooo0_l0000Rooooo`;o0000?ooo
ool2o`00013ooooo0_l0001hooooo`00:Oooool00ol0003oooooooooo`1;ooooo`;o00008_ooool2
o`0003oooooo0_l0000<ooooo`;o00000_ooool2o`0007Sooooo000Yooooo`03o`000?oooooooooo
05Wooooo0_l0000Gooooo`;o0000B_ooool2o`0005Sooooo0_l0000Rooooo`00:Oooool2o`0005[o
oooo0_l0000Gooooo`;o00006_ooool2o`0008Sooooo0_l0000Rooooo`00:Oooool00ol0003ooooo
ooooo`2>ooooo`;o0000L?ooool2o`0003[ooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo04Oo
oooo0_l0001[ooooo`;o0000B_ooool2o`0003[ooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`17ooooo`;o
0000:oooool2o`0001Cooooo0_l0000Xooooo`;o0000>oooool2o`0004Wooooo000>ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`?o00008_ooool2o`0002oo
oooo0_l0000Oooooo`;o00005?ooool2o`0000Gooooo0_l0000`ooooo`;o00004?ooool2o`0000Co
oooo0_l0000Dooooo`;o0000;Oooool2o`0001[ooooo000>ooooo`05o`000?ooooooooooooooool0
00003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02;ooooo0_l0000_ooooo`;o
0000??ooool2o`00033ooooo0_l0000@ooooo`;o00001?ooool2o`0004?ooooo0_l0000Jooooo`00
3_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005oooo
o`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooooooooooooooooa0@400<oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0003ooooo
ockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003ooooo
ockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00go
oooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolmooooo`00
1_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005oooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400>oooo
o`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooo
ocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo
<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`;o0000ooooooln
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000ooooooln
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool001oooooo1?l000000ol@413ooooo
ooooo`03ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo0ol0003o
ooooocgooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool001oooooo00?oEEEEofIVI_l00000oooooom7ooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .39397 Mdot
.02762 .34639 Mdot
.02952 .31263 Mdot
.03143 .33009 Mdot
.03333 .27189 Mdot
.03524 .36393 Mdot
.03714 .28401 Mdot
.03905 .2353 Mdot
.04095 .32852 Mdot
.04286 .25665 Mdot
.04476 .29513 Mdot
.04667 .22803 Mdot
.04857 .23627 Mdot
.05048 .26452 Mdot
.05238 .24216 Mdot
.05429 .33719 Mdot
.05619 .31951 Mdot
.0581 .23488 Mdot
.06 .3551 Mdot
.0619 .4031 Mdot
.06381 .23581 Mdot
.06571 .29097 Mdot
.06762 .26062 Mdot
.06952 .23538 Mdot
.07143 .3011 Mdot
.07333 .33307 Mdot
.07524 .3296 Mdot
.07714 .35473 Mdot
.07905 .41386 Mdot
.08095 .33539 Mdot
.08286 .25187 Mdot
.08476 .3352 Mdot
.08667 .25007 Mdot
.08857 .25621 Mdot
.09048 .24772 Mdot
.09238 .38023 Mdot
.09429 .42136 Mdot
.09619 .35436 Mdot
.0981 .4217 Mdot
.1 .23073 Mdot
.1019 .29221 Mdot
.10381 .24357 Mdot
.10571 .31026 Mdot
.10762 .39404 Mdot
.10952 .39908 Mdot
.11143 .25472 Mdot
.11333 .26387 Mdot
.11524 .37685 Mdot
.11714 .37515 Mdot
.11905 .41237 Mdot
.12095 .37715 Mdot
.12286 .42898 Mdot
.12476 .39939 Mdot
.12667 .27918 Mdot
.12857 .28072 Mdot
.13048 .28796 Mdot
.13238 .23065 Mdot
.13429 .32533 Mdot
.13619 .40291 Mdot
.1381 .3986 Mdot
.14 .26547 Mdot
.1419 .4278 Mdot
.14381 .42244 Mdot
.14571 .28554 Mdot
.14762 .24354 Mdot
.14952 .31503 Mdot
.15143 .25872 Mdot
.15333 .33905 Mdot
.15524 .35535 Mdot
.15714 .24394 Mdot
.15905 .3151 Mdot
.16095 .28648 Mdot
.16286 .25547 Mdot
.16476 .28036 Mdot
.16667 .42238 Mdot
.16857 .27706 Mdot
.17048 .39904 Mdot
.17238 .30484 Mdot
.17429 .42695 Mdot
.17619 .37038 Mdot
.1781 .31625 Mdot
.18 .33769 Mdot
.1819 .31966 Mdot
.18381 .24291 Mdot
.18571 .26115 Mdot
.18762 .33763 Mdot
.18952 .26611 Mdot
.19143 .25015 Mdot
.19333 .3432 Mdot
.19524 .33742 Mdot
.19714 .30816 Mdot
.19905 .46505 Mdot
.20095 .25961 Mdot
.20286 .24914 Mdot
.20476 .26266 Mdot
.20667 .47036 Mdot
.20857 .26171 Mdot
.21048 .36752 Mdot
.21238 .39184 Mdot
.21429 .34447 Mdot
.21619 .38812 Mdot
.2181 .36066 Mdot
.22 .22944 Mdot
.2219 .38742 Mdot
.22381 .28291 Mdot
.22571 .24957 Mdot
.22762 .29584 Mdot
.22952 .3491 Mdot
.23143 .25956 Mdot
.23333 .2476 Mdot
.23524 .25527 Mdot
.23714 .32551 Mdot
.23905 .33731 Mdot
.24095 .38343 Mdot
.24286 .25985 Mdot
.24476 .26824 Mdot
.24667 .28356 Mdot
.24857 .30669 Mdot
.25048 .32174 Mdot
.25238 .41895 Mdot
.25429 .23617 Mdot
.25619 .4047 Mdot
.2581 .23661 Mdot
.26 .41568 Mdot
.2619 .24681 Mdot
.26381 .33729 Mdot
.26571 .39359 Mdot
.26762 .47179 Mdot
.26952 .3618 Mdot
.27143 .28738 Mdot
.27333 .26677 Mdot
.27524 .37807 Mdot
.27714 .24127 Mdot
.27905 .36721 Mdot
.28095 .3322 Mdot
.28286 .42388 Mdot
.28476 .42899 Mdot
.28667 .40645 Mdot
.28857 .25582 Mdot
.29048 .23342 Mdot
.29238 .24414 Mdot
.29429 .45391 Mdot
.29619 .28735 Mdot
.2981 .35718 Mdot
.3 .3198 Mdot
.3019 .39386 Mdot
.30381 .2784 Mdot
.30571 .2189 Mdot
.30762 .33673 Mdot
.30952 .2499 Mdot
.31143 .3854 Mdot
.31333 .36577 Mdot
.31524 .34524 Mdot
.31714 .23551 Mdot
.31905 .27818 Mdot
.32095 .38589 Mdot
.32286 .429 Mdot
.32476 .425 Mdot
.32667 .3026 Mdot
.32857 .41978 Mdot
.33048 .42911 Mdot
.33238 .35983 Mdot
.33429 .42744 Mdot
.33619 .27311 Mdot
.3381 .36093 Mdot
.34 .31334 Mdot
.3419 .38775 Mdot
.34381 .28283 Mdot
.34571 .29854 Mdot
.34762 .35407 Mdot
.34952 .43154 Mdot
.35143 .40316 Mdot
.35333 .26535 Mdot
.35524 .34897 Mdot
.35714 .26206 Mdot
.35905 .33073 Mdot
.36095 .24307 Mdot
.36286 .47094 Mdot
.36476 .38411 Mdot
.36667 .26942 Mdot
.36857 .41709 Mdot
.37048 .43204 Mdot
.37238 .24517 Mdot
.37429 .31018 Mdot
.37619 .30091 Mdot
.3781 .32288 Mdot
.38 .33137 Mdot
.3819 .47081 Mdot
.38381 .34549 Mdot
.38571 .26681 Mdot
.38762 .32126 Mdot
.38952 .38586 Mdot
.39143 .39351 Mdot
.39333 .3082 Mdot
.39524 .42041 Mdot
.39714 .24669 Mdot
.39905 .32749 Mdot
.40095 .23326 Mdot
.40286 .2497 Mdot
.40476 .45919 Mdot
.40667 .26762 Mdot
.40857 .29245 Mdot
.41048 .28838 Mdot
.41238 .29444 Mdot
.41429 .27397 Mdot
.41619 .45241 Mdot
.4181 .38221 Mdot
.42 .3304 Mdot
.4219 .37375 Mdot
.42381 .32136 Mdot
.42571 .33186 Mdot
.42762 .2997 Mdot
.42952 .25695 Mdot
.43143 .29775 Mdot
.43333 .30048 Mdot
.43524 .31853 Mdot
.43714 .38562 Mdot
.43905 .28605 Mdot
.44095 .27833 Mdot
.44286 .3235 Mdot
.44476 .39568 Mdot
.44667 .22586 Mdot
.44857 .27795 Mdot
.45048 .39388 Mdot
.45238 .28639 Mdot
.45429 .33508 Mdot
.45619 .32729 Mdot
.4581 .30277 Mdot
.46 .36041 Mdot
.4619 .26208 Mdot
.46381 .24321 Mdot
.46571 .4098 Mdot
.46762 .34317 Mdot
.46952 .31771 Mdot
.47143 .44695 Mdot
.47333 .37051 Mdot
.47524 .32597 Mdot
.47714 .39674 Mdot
.47905 .35227 Mdot
.48095 .38293 Mdot
.48286 .23831 Mdot
.48476 .38187 Mdot
.48667 .42839 Mdot
.48857 .34474 Mdot
.49048 .32561 Mdot
.49238 .31573 Mdot
.49429 .33693 Mdot
.49619 .26598 Mdot
.4981 .42686 Mdot
.5 .34875 Mdot
.5019 .31885 Mdot
.50381 .42325 Mdot
.50571 .32212 Mdot
.50762 .26939 Mdot
.50952 .30568 Mdot
.51143 .42423 Mdot
.51333 .3394 Mdot
.51524 .34703 Mdot
.51714 .29221 Mdot
.51905 .27415 Mdot
.52095 .23308 Mdot
.52286 .39027 Mdot
.52476 .37461 Mdot
.52667 .32537 Mdot
.52857 .34454 Mdot
.53048 .26898 Mdot
.53238 .36568 Mdot
.53429 .39532 Mdot
.53619 .27257 Mdot
.5381 .35316 Mdot
.54 .39172 Mdot
.5419 .35585 Mdot
.54381 .38533 Mdot
.54571 .28919 Mdot
.54762 .25775 Mdot
.54952 .37311 Mdot
.55143 .42997 Mdot
.55333 .30579 Mdot
.55524 .32901 Mdot
.55714 .36893 Mdot
.55905 .29147 Mdot
.56095 .38243 Mdot
.56286 .42127 Mdot
.56476 .28981 Mdot
.56667 .29394 Mdot
.56857 .41893 Mdot
.57048 .22635 Mdot
.57238 .34794 Mdot
.57429 .26868 Mdot
.57619 .29734 Mdot
.5781 .36691 Mdot
.58 .25183 Mdot
.5819 .30265 Mdot
.58381 .47031 Mdot
.58571 .40388 Mdot
.58762 .23067 Mdot
.58952 .39914 Mdot
.59143 .31025 Mdot
.59333 .41395 Mdot
.59524 .41158 Mdot
.59714 .34955 Mdot
.59905 .23737 Mdot
.60095 .21622 Mdot
.60286 .37246 Mdot
.60476 .32074 Mdot
.60667 .37682 Mdot
.60857 .33552 Mdot
.61048 .28865 Mdot
.61238 .26978 Mdot
.61429 .36869 Mdot
.61619 .34516 Mdot
.6181 .31363 Mdot
.62 .25706 Mdot
.6219 .31131 Mdot
.62381 .23801 Mdot
.62571 .37666 Mdot
.62762 .26484 Mdot
.62952 .39644 Mdot
.63143 .24728 Mdot
.63333 .23563 Mdot
.63524 .26971 Mdot
.63714 .25024 Mdot
.63905 .37498 Mdot
.64095 .46141 Mdot
.64286 .34228 Mdot
.64476 .36814 Mdot
.64667 .24268 Mdot
.64857 .42525 Mdot
.65048 .3027 Mdot
.65238 .30495 Mdot
.65429 .2982 Mdot
.65619 .30504 Mdot
.6581 .22573 Mdot
.66 .42348 Mdot
.6619 .26411 Mdot
.66381 .2725 Mdot
.66571 .29193 Mdot
.66762 .29622 Mdot
.66952 .35712 Mdot
.67143 .3582 Mdot
.67333 .31413 Mdot
.67524 .36001 Mdot
.67714 .28022 Mdot
.67905 .41668 Mdot
.68095 .34641 Mdot
.68286 .34556 Mdot
.68476 .28239 Mdot
.68667 .26424 Mdot
.68857 .32407 Mdot
.69048 .40328 Mdot
.69238 .31436 Mdot
.69429 .26747 Mdot
.69619 .2649 Mdot
.6981 .45314 Mdot
.7 .22648 Mdot
.7019 .41698 Mdot
.70381 .38501 Mdot
.70571 .37034 Mdot
.70762 .26952 Mdot
.70952 .39989 Mdot
.71143 .36867 Mdot
.71333 .22655 Mdot
.71524 .46394 Mdot
.71714 .33063 Mdot
.71905 .24013 Mdot
.72095 .25497 Mdot
.72286 .29377 Mdot
.72476 .31232 Mdot
.72667 .37283 Mdot
.72857 .24652 Mdot
.73048 .23257 Mdot
.73238 .31601 Mdot
.73429 .28134 Mdot
.73619 .34808 Mdot
.7381 .37456 Mdot
.74 .3901 Mdot
.7419 .35856 Mdot
.74381 .38316 Mdot
.74571 .41727 Mdot
.74762 .42543 Mdot
.74952 .26601 Mdot
.75143 .42234 Mdot
.75333 .27108 Mdot
.75524 .2811 Mdot
.75714 .24066 Mdot
.75905 .41356 Mdot
.76095 .38865 Mdot
.76286 .27505 Mdot
.76476 .35061 Mdot
.76667 .34909 Mdot
.76857 .30196 Mdot
.77048 .24788 Mdot
.77238 .24598 Mdot
.77429 .30862 Mdot
.77619 .27096 Mdot
.7781 .31594 Mdot
.78 .33306 Mdot
.7819 .37173 Mdot
.78381 .28901 Mdot
.78571 .41831 Mdot
.78762 .24861 Mdot
.78952 .28157 Mdot
.79143 .42143 Mdot
.79333 .27309 Mdot
.79524 .33434 Mdot
.79714 .32553 Mdot
.79905 .29922 Mdot
.80095 .22665 Mdot
.80286 .22743 Mdot
.80476 .32744 Mdot
.80667 .26794 Mdot
.80857 .3242 Mdot
.81048 .32843 Mdot
.81238 .3573 Mdot
.81429 .2493 Mdot
.81619 .35784 Mdot
.8181 .29929 Mdot
.82 .34704 Mdot
.8219 .27458 Mdot
.82381 .25432 Mdot
.82571 .26387 Mdot
.82762 .33504 Mdot
.82952 .32832 Mdot
.83143 .39561 Mdot
.83333 .23496 Mdot
.83524 .28868 Mdot
.83714 .25244 Mdot
.83905 .29539 Mdot
.84095 .39142 Mdot
.84286 .35447 Mdot
.84476 .35112 Mdot
.84667 .35174 Mdot
.84857 .4698 Mdot
.85048 .37607 Mdot
.85238 .30257 Mdot
.85429 .39203 Mdot
.85619 .32428 Mdot
.8581 .3104 Mdot
.86 .25226 Mdot
.8619 .30369 Mdot
.86381 .31134 Mdot
.86571 .41198 Mdot
.86762 .27308 Mdot
.86952 .3181 Mdot
.87143 .32106 Mdot
.87333 .34058 Mdot
.87524 .36766 Mdot
.87714 .46222 Mdot
.87905 .32838 Mdot
.88095 .26131 Mdot
.88286 .24488 Mdot
.88476 .27159 Mdot
.88667 .26522 Mdot
.88857 .2918 Mdot
.89048 .23438 Mdot
.89238 .26443 Mdot
.89429 .42522 Mdot
.89619 .3597 Mdot
.8981 .3978 Mdot
.9 .38912 Mdot
.9019 .28707 Mdot
.90381 .29737 Mdot
.90571 .4736 Mdot
.90762 .26712 Mdot
.90952 .22535 Mdot
.91143 .31957 Mdot
.91333 .27464 Mdot
.91524 .41514 Mdot
.91714 .35528 Mdot
.91905 .32799 Mdot
.92095 .4019 Mdot
.92286 .38869 Mdot
.92476 .35225 Mdot
.92667 .26567 Mdot
.92857 .25865 Mdot
.93048 .42527 Mdot
.93238 .33238 Mdot
.93429 .2807 Mdot
.93619 .30237 Mdot
.9381 .3712 Mdot
.94 .30868 Mdot
.9419 .34168 Mdot
.94381 .27409 Mdot
.94571 .32538 Mdot
.94762 .27859 Mdot
.94952 .33108 Mdot
.95143 .31254 Mdot
.95333 .27828 Mdot
.95524 .39594 Mdot
.95714 .35719 Mdot
.95905 .35272 Mdot
.96095 .32372 Mdot
.96286 .27288 Mdot
.96476 .32457 Mdot
.96667 .35188 Mdot
.96857 .38814 Mdot
.97048 .3634 Mdot
.97238 .35626 Mdot
.97429 .41121 Mdot
.97619 .23728 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0002gooooo`;o0000Q?ooool0
02Wooooo00?o0000ooooooooool0Eoooool2o`0005gooooo0_l00024ooooo`001_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool0Eoooool2o`000>?ooooo0006ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0Q?ooool2o`0002Kooooo0_l0000Jooooo`;o00003?oo
ool2o`0000;ooooo0_l0000Jooooo`?o00008?ooool2o`00027ooooo0004o`0000;ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`;o00003oooool2o`0000Sooooo0_l0000Jooooo`;o0000Aooo
ool2o`0002Kooooo0_l00004ooooo`;o00005?ooool2o`0000cooooo0_l00002ooooo`;o00006_oo
ool3o`00023ooooo0_l0000Qooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o00001?ooool2o`0000oooooo0_l0
0008ooooo`;o00006_ooool2o`0001Gooooo0_l0000Rooooo`;o00009?ooool2o`0001Cooooo0_l0
000[ooooo`;o0000Foooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`04o`000?ooooooooooooooo`;o
000000Coooooo`000?l0003ooooo1_l0000iooooo`Co00002?ooool2o`0000Oooooo0_l0000Ioooo
o`;o00009?ooool2o`0002;ooooo0_l0000Mooooo`;o00008?ooool2o`00013ooooo0_l0000Joooo
o`;o00002oooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01oooool01?l0003oooooooooooooool2o`000004ooooool0003o
0000ooooo`Ko0000>Oooool4o`00017ooooo0_l0000cooooo`;o00008oooool2o`0000Kooooo0_l0
00000ooooooo0000o`00000Jooooo`;o00008oooool2o`00013ooooo0_l0000Jooooo`;o00002ooo
ool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo0_l0000Yooooo`;o0000
7?ooool2o`0001Wooooo0_l0000Oooooo`;o00001?ooool2o`0002?ooooo0_l00006ooooo`;o0000
1_ooool2o`0001Gooooo0_l0000:ooooo`;o0000D_ooool000Kooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000oooooooo
ool01Oooool2o`0000oooooo0_l0000<ooooo`;o000000?oooooo`000?l000001oooool2o`0001co
oooo0_l00003ooooo`;o00005?ooool2o`000003ooooool0003o000001cooooo0_l0000iooooo`;o
00006?ooool2o`0000Oooooo0_l00003ooooo`;o00008Oooool2o`0002[ooooo000Yooooo`;o0000
4oooool2o`0000;ooooo0_l0000<ooooo`;o000000?oooooo`000?l000003Oooool2o`0000Gooooo
0_l000000ooooooo0000o`000007ooooo`;o00002?ooool2o`0001Oooooo0_l00006ooooo`Co0000
B?ooool2o`0001gooooo0_l0000;ooooo`?o00000oooool2o`0000Kooooo0_l0000Dooooo`;o0000
:_ooool002Wooooo00?o0000ooooooooool03oooool5o`0001kooooo0_l00002ooooo`;o00001Ooo
ool2o`000003ooooool0003o000000Oooooo0_l0000=ooooo`;o00006_ooool4o`0003Oooooo0_l0
000?ooooo`?o0000:Oooool2o`0000Cooooo0_l00006ooooo`;o00001_ooool2o`0000Gooooo0_l0
000aooooo`00:Oooool00ol0003oooooooooo`0?ooooo`?o00001_ooool2o`0000oooooo0_l00007
ooooo`;o00003?ooool2o`0000oooooo0_l00005ooooo`;o0000EOooool2o`00013ooooo0_l0000I
ooooo`;o00008?ooool2o`0000;ooooo0_l00005ooooo`;o0000<Oooool002Wooooo00?o0000oooo
ooooool00_ooool2o`0000gooooo0_l00005ooooo`;o00002oooool2o`0000;ooooo0_l0000Eoooo
o`;o00003oooool2o`0002cooooo0_l0000Tooooo`;o00005Oooool2o`0001kooooo0_l0000Poooo
o`;o00007oooool2o`0001_ooooo000Yooooo`03o`000?oooooooooo00;ooooo0_l00006ooooo`;o
00001Oooool2o`0001;ooooo0_l00009ooooo`;o00000oooool2o`000003ooooool0003o000000Go
oooo0_l00002ooooo`;o00008_ooool2o`0001Kooooo0_l00008ooooo`;o00006_ooool2o`0001Go
oooo0_l0001Booooo`;o00003Oooool2o`0001_ooooo000Yooooo`;o00001_ooool2o`0000?ooooo
0_l0000=ooooo`;o00005Oooool2o`0000?ooooo1Ol00005ooooo`;o00000_ooool2o`0002;ooooo
0_l0000Pooooo`;o0000<oooool2o`0000Wooooo0_l00006ooooo`;o000000?oooooo`000?l00000
:?ooool2o`00013ooooo1_l0000Vooooo`00:Oooool00ol0003oooooooooo`05ooooo`;o00004_oo
ool2o`0000Oooooo0_l0000>ooooo`;o00000_ooool2o`0000_ooooo0_l00008ooooo`;o00005ooo
ool2o`0000Wooooo0_l00004ooooo`;o00006oooool2o`0002Sooooo0_l00009ooooo`;o00001_oo
ool2o`000003ooooool0003o0000013ooooo0_l0000@ooooo`;o00001?ooool2o`0001;ooooo1?l0
0002ooooo`;o00001Oooool2o`0001_ooooo000Yooooo`03o`000?oooooooooo02;ooooo0_l0000<
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Cok^k^oc8b<_l0
003o<S8b0_l00008ooooo`;o00005oooool2o`0000?ooooo2?l00002ooooo`05onk^k_lb<S;o0000
o`000?o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo0_l00002ooooo`;o00001Ooo
ool2o`0000Wooooo00?oV9RHoa0@4?l000000_l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool3o`000004oc8b<_o^k^koooooooooo`;o00004Oooool2o`0000;ooooo0_l0000<ooooo`Go
000000?o410@ooooooooool00_l000001?lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_l0003o0000
oc8b<_o^k^h07?ooool2o`0000Gooooo0_l00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00
:Oooool01?l0003oooooo`000?l0000aooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07Oooool2o`0000Sooooo0_l00000
1OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02o`000006oooo
oomgMgOoV9RHoooooonHV9SoMgMg5_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`00
00Oooooo00?o410@okZj^_ooool00_l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool2
o`000003oooooonHV9SoMgMg00;ooooo0_l00007ooooo`;o00003?ooool2o`0000gooooo0_l00000
0ooooooo0000ooooo`02ooooo`;o000000CoV9RHoooooonHV9SoMgMg0_l000001oooooooMgMgoiRH
V?ooooooV9RHogMgMoooool00_l0000=ooooo`;o00000oooool2o`00017ooooo0_l00002ooooo`09
ogMgMolb<S;o0000o`000?mgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`00:Oooool01?l0003oooooo`000?l0000Zooooo`;o00001Oooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@
01gooooo0_l0000;ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4002
o`000003ooooool@413ooooo00;ooooo00?o410@ooooooooool06?ooool2o`0000?ooooo0_l0000;
ooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo
00?o410@ooooooooool02Oooool2o`0001_ooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@
41000_l000000ooooooo410@ooooo`02ooooo`04oa0@4?oooooo0000o`0000gooooo0_l00003oooo
o`;o00001oooool2o`0000Sooooo0_l00003ooooo`?o000000Go410@oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@41000oooool002Wooooo0_l0000Nooooo`?o00002_ooool3
o`0000Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`00000Booooo`;o00000oooool2o`0001;ooooo00?oV9RHob4Q8Oo^k^h0
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooooooo0ol000000ooo
oooo0000o`00000Vooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000003oooool2o`0001Oooooo00?oA4A4omgMgOooool00_l0
0003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000001ko
oooo0_l00005ooooo`;o00000_ooool4o`000004oc8b<_ooooooooooo`0000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo007ooooo000Yooooo`03o`000?oooooooooo
01gooooo0ol0000:ooooo`;o00001_ooool00ol0003oooooooooo`02ooooo`06o`000?oooooooooo
ooooool0003ooooo0ol00003ooooo`?o00004?ooool2o`0000?ooooo0_l00006ooooo`;o00002ooo
ool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooo
ooooooooool3o`000003ooooool0003o000002Gooooo00?o410@o`000?nj^[X00oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00000?ooooo`;o000000?ooooo
o`000?l000003_ooool2o`0000Cooooo0_l000000ooooooo0000ooooo`03ooooo`03o`000?oooooo
oooo00;o00000oooool01Ol0003ooooooooooooooooo000002Gooooo0_l00002ooooo`Co000000Co
c<c<oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool00Oooool002Wooooo00Co0000oooooooooooooooo0_l0000Pooooo`;o00000oooool2o`0000So
oooo00?o0000ooooooooool00_ooool01_l@413ooooooooooooooooo410@ooooo`;o000000Go410@
oooooooooooooooooa0@4002o`0001gooooo0_l0000<ooooo`05o`000?ooooooooooooooool@4100
0oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@o`000?l000000_ooool2o`0002Go
oooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooo
oooooooooooooa0@400Booooo`;o00003_ooool2o`0000Cooooo0_l000000oo<c<co0000ooooo`03
ooooo`03oa0@4?oooooooooo00;o00000oooool01Ol@413ooooooooooooooooo410@02Wooooo00?o
0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`00:Oooool01?l0003oooooooooooooool2o`0001cooooo0_l00002ooooo`;o
00000oooool2o`0000Sooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`;o00001_ooool2o`0001Oooooo00Go0000
okZj^_ooooooV9RHoa0@4003ooooo`04ogMgMonHV9SooooooiRHV0;o00000_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00;o00000_ooool2o`0001cooooo0_l00004ooooo`;o000000?ooooookZj^_l0
00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo0_l000001?nHV9SooooooiRHV?mgMgLY
ooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?l0003o0000ogMgM`03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2o`0001Cooooo0_l0000<ooooo`03o`000?oooooooooo00Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wo
oooo00?o0000ooooooooool02_ooool2o`0000Wooooo0_l00008ooooo`;o00003oooool00omEEEGo
IVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Sooooo0_l00006ooooo`;o00005oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00?o
k^k^oc8b<_l000000ol00002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06Oooool2o`0000Oooooo
0_l00002ooooo`Go000000?o410@ojVYZOooool00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;o
oooo0_l000001?lb<S;o0000oc8b<_o^k^h<ooooo`;o00007?ooool00omgMgOo0000ooooo`03oooo
o`05onk^k_lb<S;o0000o`000?o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_l0
000?ooooo`;o00000oooool2o`0000cooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Yooooo`;o00001?ooool2o`0000Gooooo
0_l00009ooooo`;o00009oooool2o`0003Sooooo0ol0000Pooooo`;o00002oooool2o`000003oooo
ool0003o000001kooooo0_l0000@ooooo`;o00008oooool2o`0000kooooo0_l0000Xooooo`00:Ooo
ool00ol0003oooooooooo`03ooooo`;o0000>Oooool2o`0002Cooooo0_l0000Cooooo`;o00001?oo
ool2o`0002[ooooo0_l000000ooooooo0000o`00000Gooooo`;o00000_ooool2o`00013ooooo0_l0
000Gooooo`;o00001?ooool2o`0000Cooooo0_l0000Cooooo`;o00008oooool002Wooooo00?o0000
ooooooooool03?ooool2o`00053ooooo0_l00004ooooo`;o00002?ooool2o`0000kooooo1?l0000/
ooooo`;o00005oooool2o`0002?ooooo0_l00008ooooo`;o00001?ooool2o`0000Wooooo0_l0000>
ooooo`;o00002Oooool2o`0001Sooooo000Yooooo`03o`000?oooooooooo00cooooo0_l0000Noooo
o`;o0000<?ooool2o`0000kooooo0_l0000>ooooo`Co00001_ooool2o`0000kooooo0_l0000Foooo
o`;o00005?ooool4o`0002;ooooo0_l0000Iooooo`;o000000?oooooo`000?l000005_ooool2o`00
01Sooooo000Yooooo`03o`000?oooooooooo02cooooo0_l00006ooooo`;o00003oooool2o`0002co
oooo0_l0000Cooooo`;o00003_ooool2o`0000gooooo0_l00007ooooo`;o00005?ooool4o`0002Co
oooo0_l0000Jooooo`;o00005oooool2o`0001Oooooo000Qoooooooo0000A?l00004ooooo`00:Ooo
ool3o`0000Wooooo00?o0000ooooooooool02_ooool3o`0000Wooooo00?o0000ooooooooool00_l0
0007ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_l00007ooooo`04o`000?oo
oooo0000o`0000Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`?o0000
1Oooool4o`0000;ooooo00?o0000ooooooooool02Oooool2o`0000Cooooo0_l00005ooooo`04o`00
0?ooooooooooooooo`;o00001_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02?ooool3o`0000_ooooo00?o0000ooooooooool02Oooool01?l0003o
ooooooooooooool2o`0000Kooooo00?o0000ooooooooool02_ooool002Wooooo0ol0000Uooooo`;o
000000?oooooo`000?l000001?ooool2o`0000[ooooo00?o0000ooooooooool09Oooool2o`0001Co
oooo00?o0000ooooooooool04Oooool2o`0000Gooooo0_l0000Pooooo`03o`000?oooooooooo00?o
oooo0_l0000@ooooo`;o00001?ooool2o`0000Wooooo1?l0000=ooooo`;o000000?oooooo`000?oo
ool06?ooool2o`0001Wooooo0_l00006ooooo`03o`000?oooooooooo00[ooooo000Yooooo`03o`00
0?oooooooooo00Oooooo0_l0000Oooooo`;o00001?ooool3o`0002Cooooo0_l0000Jooooo`;o0000
3_ooool2o`0000Wooooo0_l00005ooooo`;o000000?oooooo`000?l000007oooool2o`0002Oooooo
0_l0000=ooooo`;o00006oooool3o`0000_ooooo0_l0000Pooooo`00:Oooool00ol0003ooooooooo
o`07ooooo`;o00009_ooool2o`0001Cooooo0_l0000>ooooo`;o00005oooool2o`000003ooooool0
003o000000[ooooo0_l00002ooooo`Co00004Oooool3o`0001kooooo0_l0000Iooooo`;o00009Ooo
ool2o`0000gooooo0_l00003ooooo`;o00002oooool2o`0000kooooo0_l0000@ooooo`00:Oooool2
o`00027ooooo0_l0000Oooooo`;o00000_ooool2o`0002Oooooo0_l0000=ooooo`;o00001?ooool2
o`0000;ooooo0_l00004ooooo`;o00000oooool2o`0000?ooooo0_l00005ooooo`;o0000<_ooool2
o`00027ooooo1_l0000=ooooo`;o00006oooool2o`0000?ooooo0ol0000?ooooo`00:Oooool01Ol0
003oooooo`000?l0003ooooo00;o00002Oooool2o`00017ooooo0_l0000Oooooo`;o0000<_ooool2
o`0000Gooooo0_l00009ooooo`;o00001?ooool2o`0000?ooooo0_l0000:ooooo`;o00001oooool2
o`0004cooooo1_l00004ooooo`;o00003_ooool2o`0000_ooooo0_l00007ooooo`;o00001?ooool2
o`0000oooooo000Yooooo`05o`000?oooooo0000o`000?ooool00_l00008ooooo`?o0000@?ooool2
o`0001Oooooo0_l00005ooooo`;o00001?ooool2o`0000Gooooo0ol0000Xooooo`;o0000<_ooool2
o`0001;ooooo0_l00008ooooo`;o00001?ooool2o`0000kooooo0_l0000;ooooo`;o00000_ooool2
o`0000Cooooo0_l0000Dooooo`00:Oooool00ol0003oooooooooo`0<ooooo`;o000000Coooooo`00
0?l0003o0000?Oooool2o`0000Oooooo0_l0000>ooooo`;o00001Oooool2o`0000cooooo0_l00008
ooooo`;o0000;oooool2o`00027ooooo0_l0000Booooo`;o00000oooool2o`0000Wooooo0_l0000O
ooooo`;o00001?ooool2o`0001Cooooo000Yooooo`03o`000?oooooooooo00Kooooo0_l00007oooo
o`?o00005?ooool2o`0000Kooooo0_l000000ooooooo0000o`000002o`0000cooooo0_l00006oooo
o`;o00003Oooool2o`0002gooooo0_l0000;ooooo`;o00001?ooool2o`0001cooooo0_l0000joooo
o`;o00002Oooool2o`0003_ooooo000Yooooo`;o00001oooool2o`0001kooooo0_l00006ooooo`;o
000000?oooooo`000?l000000_l0000<ooooo`;o00001_ooool2o`0004Wooooo0_l00004ooooo`;o
00009oooool2o`0004Sooooo0_l0000Dooooo`;o00005oooool002Wooooo00?o0000ooooooooool0
<oooool2o`0000Gooooo0_l0000Nooooo`;o00005?ooool2o`0001Wooooo0_l00005ooooo`;o0000
2oooool2o`0001[ooooo0_l00006ooooo`;o00002oooool2o`0003_ooooo0_l0000Dooooo`;o0000
5oooool002Wooooo0_l0000dooooo`;o00001Oooool2o`0000;ooooo0_l0000Jooooo`;o00002ooo
ool2o`0000Oooooo0_l0000Iooooo`;o00001Oooool2o`000003ooooool0003o000000?ooooo0_l0
0003ooooo`;o00003?ooool2o`0000cooooo0_l0000Cooooo`;o00003oooool2o`0000Sooooo0_l0
000?ooooo`;o0000?_ooool002Wooooo0_l0000oooooo`;o00009oooool2o`0002Kooooo0_l00004
ooooo`;o00000oooool2o`00017ooooo0_l00006ooooo`;o00006Oooool2o`0000oooooo0_l00008
ooooo`;o00003oooool2o`0000Kooooo0ol0000Gooooo`;o00002oooool2o`0000oooooo000Yoooo
o`03o`000?oooooooooo00Sooooo0_l00003ooooo`;o00001Oooool2o`00017ooooo0_l0000koooo
o`;o0000:Oooool2o`00017ooooo0_l0000Aooooo`;o0000=?ooool2o`0001Oooooo0ol0000Eoooo
o`Co00002Oooool4o`0000oooooo000Yooooo`;o00002Oooool2o`0000?ooooo0_l00005ooooo`;o
00004Oooool2o`0002_ooooo0_l0000>ooooo`;o0000??ooool3o`0002Oooooo0ol0000Dooooo`;o
00005Oooool3o`0000Oooooo0_l0000Fooooo`;o00002_ooool3o`0000;ooooo0_l0000=ooooo`00
:Oooool00ol0003oooooooooo`0kooooo`;o00005oooool2o`0000Wooooo1?l0000Vooooo`;o0000
6?ooool2o`0002Oooooo1?l0000Cooooo`;o00005Oooool3o`0001Sooooo0_l0000Aooooo`;o0000
0oooool2o`0000gooooo000Yooooo`03o`000?oooooooooo00;o0000>Oooool2o`0000kooooo0_l0
000Booooo`Co00009_ooool2o`0004?ooooo0_l00015ooooo`;o00005_ooool2o`0000gooooo000Y
ooooo`03o`000?oooooooooo00;o0000=_ooool2o`00017ooooo0_l000000ooooooo0000o`000009
ooooo`;o0000AOooool2o`0000cooooo0_l0001Nooooo`;o00007Oooool2o`0000gooooo000Yoooo
o`03o`000?oooooooooo02gooooo0_l00009ooooo`;o00005?ooool2o`0000Wooooo0_l0000boooo
o`;o00004Oooool2o`0000Kooooo0_l00004ooooo`;o00002_ooool2o`0000Sooooo0_l0000Boooo
o`?o0000<oooool2o`0002cooooo000Yooooo`;o0000;_ooool2o`0004gooooo0_l0000?ooooo`;o
00005_ooool2o`000003ooooool0003o000000cooooo0_l00002ooooo`;o00002?ooool2o`0001;o
oooo0ol00003ooooo`;o00004?ooool2o`00033ooooo0_l0000Hooooo`00:Oooool00ol0003ooooo
ooooo`0Jooooo`Co0000G_ooool2o`0001oooooo0_l00006ooooo`;o00003oooool4o`0000Cooooo
0_l00002ooooo`;o00006_ooool2o`0000;ooooo0_l0000<ooooo`;o00005?ooool2o`0001[ooooo
0_l0000Hooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000
1?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool04_ooool2o`0000Ko
oooo1?l0000_ooooo`;o0000C_ooool2o`0001Wooooo0_l00004ooooo`;o00000_ooool2o`0001ko
oooo0_l0000Rooooo`;o0000=?ooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`0Booooo`;o0000;_ooool2o`0000Wooooo0_l0000/ooooo`;o00004_ooool3o`00
01Oooooo0_l0000iooooo`;o0000E_ooool000Kooooo00Go410@oooooooooooooooooa0@400<oooo
o`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`12oooo
o`;o00005Oooool2o`000003ooooool0003o000000cooooo0_l00006ooooo`;o00001oooool2o`00
00Cooooo0_l0000<ooooo`?o00004Oooool2o`0000Cooooo0_l0000/ooooo`;o00002oooool2o`00
05Kooooo0006ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07oooo
o`03ogMgMolb<S;ooooo00Cooooo0ol0000jooooo`Co00006oooool2o`000003ooooool0003o0000
00Gooooo0_l00005ooooo`;o00001_ooool2o`0000gooooo0_l0000Pooooo`;o0000<_ooool2o`00
013ooooo0_l0000[ooooo`;o00001Oooool2o`0000gooooo0_l0000>ooooo`001_ooool01Ol0003o
oooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool0>Oooool5o`0002Gooooo0_l0000hooooo`;o00000oooool2
o`0003oooooo0_l00004ooooo`;o00006?ooool2o`0000;ooooo0_l0000=ooooo`;o00001Oooool2
o`0000gooooo0_l0000>ooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`07ooooo`;o00006?ooool2o`00023ooooo0_l0000?
ooooo`;o00002_ooool2o`0001[ooooo0_l0000@ooooo`?o00005_ooool2o`000003ooooool0003o
000000;o0000?oooool2o`0001_ooooo0_l000000ooooooo0000o`000002ooooo`;o0000<oooool0
00Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?oo
ool00ol0003oooooooooo`07ooooo`;o00006?ooool2o`0000Sooooo0_l0000Wooooo`;o00002_oo
ool2o`0001[ooooo0_l0000@ooooo`?o00001oooool2o`00013ooooo0_l0000Mooooo`;o0000?ooo
ool2o`0001?ooooo0_l0000Aooooo`;o00004_ooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool0
6?ooool2o`0000?ooooo0_l00002ooooo`;o00002?ooool2o`00067ooooo0_l0000Rooooo`;o0000
2oooool2o`0001Sooooo0_l0000jooooo`;o00001_ooool2o`0000Wooooo0_l0000Booooo`00:Ooo
ool2o`0000[ooooo0_l0000=ooooo`;o00000oooool2o`000003ooooool0003o000000Wooooo0_l0
000Jooooo`;o00007Oooool2o`0004Wooooo0ol0000Oooooo`;o00001?ooool2o`0004;ooooo0_l0
000Mooooo`00:Oooool00ol0003oooooooooo`09ooooo`;o00005Oooool2o`0002Gooooo0_l00008
ooooo`;o00004oooool2o`0004Wooooo0_l0000Pooooo`;o0000Ioooool002Wooooo00?o0000oooo
ooooool0DOooool2o`0003Oooooo0_l0002Rooooo`;o00003?ooool002Wooooo00?o0000oooooooo
ool03_ooool2o`0000_ooooo0_l0001]ooooo`;o00009oooool3o`0003?ooooo0_l0000Pooooo`;o
00008Oooool2o`0000cooooo000Yooooo`03o`000?oooooooooo00kooooo0_l0000;ooooo`;o0000
:oooool2o`00027ooooo0_l00016ooooo`?o00006Oooool2o`0000Gooooo0_l0000<ooooo`;o0000
0oooool2o`00023ooooo0_l0000>ooooo`;o00007oooool002Wooooo0_l00017ooooo`Co00005?oo
ool2o`0000_ooooo0_l00007ooooo`;o0000=Oooool2o`0002;ooooo0_l00005ooooo`;o00003?oo
ool2o`0000_ooooo0_l0000Xooooo`;o00007oooool002Wooooo00?o0000ooooooooool04oooool3
o`0000gooooo0_l00005ooooo`;o00006_ooool2o`0000Sooooo0_l0000<ooooo`;o00005?ooool2
o`00027ooooo0_l0000Aooooo`?o00007?ooool2o`0001_ooooo0_l00009ooooo`Co0000Aoooool0
02Wooooo00?o0000ooooooooool04oooool3o`0000gooooo0_l00005ooooo`;o000000?oooooo`00
0?l000008Oooool2o`0000_ooooo0_l0000fooooo`Ko00003oooool2o`0001Wooooo0_l00002oooo
o`;o00006_ooool3o`0000_ooooo0_l0000Oooooo`;o00002_ooool2o`0001[ooooo000Yooooo`03
o`000?oooooooooo01cooooo0_l00004ooooo`;o00002Oooool2o`00027ooooo0_l0000:ooooo`Ko
0000;oooool2o`0000;ooooo0_l00002ooooo`;o00002oooool2o`0001gooooo0_l0000Nooooo`;o
0000;Oooool2o`0000[ooooo0_l0000Jooooo`00:Oooool00ol0003oooooooooo`0Looooo`;o0000
1?ooool2o`0002cooooo0_l0000:ooooo`;o000000Coooooo`000?l0003o00000oooool2o`0000Go
oooo0_l0000Sooooo`;o00004oooool2o`0009Cooooo000Yooooo`;o0000I_ooool2o`0000Gooooo
0_l0003>ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`2<ooooo`;o0000[_ooool002Wooooo0_l0002=ooooo`;o0000[_ooool002Wooooo00?o
0000ooooooooool0Doooool2o`0002Gooooo0_l0001Iooooo`;o0000IOooool000kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo
00?o0000ooooooooool0Doooool2o`0002Gooooo0_l0001Iooooo`;o0000IOooool000kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo07Oooooo0_l00033ooooo`003_ooool01Ol@413ooooooooooooooooo410@013ooooo
00?o0000ooooooooool00oooool3o`0007Oooooo0_l0001:ooooo`;o00005_ooool2o`0003;ooooo
0_l0000[ooooo`003_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`0eooooo`;o0000S?ooool2o`0001Kooooo0_l0000booooo`;o0000
:oooool000kooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`0eooooo`Co0000Moooool2o`0005?ooooo0_l0000eooooo`00
3_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0gooooo`;o00004_ooool2o`0001cooooo0_l00004ooooo`;o0000?oooool2o`0005?o
oooo0_l0000Aooooo`;o00008_ooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0Boooool2o`0001cooooo0_l00004ooooo`;o
0000Yoooool2o`0002;ooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Ko
oooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`001_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooo
oooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000
oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool0
1_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go
0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooo
oooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413o
oooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooo
ocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006oooo
o`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool001oooooo1?l0
00000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo
00Gooooo0ol0003oooooocgooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool001oooooo00?oEEEEofIVI_l00000oooooom7oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .39179 Mdot
.02762 .39821 Mdot
.02952 .29334 Mdot
.03143 .27743 Mdot
.03333 .33996 Mdot
.03524 .28666 Mdot
.03714 .3179 Mdot
.03905 .34207 Mdot
.04095 .40849 Mdot
.04286 .31179 Mdot
.04476 .25479 Mdot
.04667 .28998 Mdot
.04857 .31968 Mdot
.05048 .27376 Mdot
.05238 .26231 Mdot
.05429 .33938 Mdot
.05619 .3712 Mdot
.0581 .31311 Mdot
.06 .34821 Mdot
.0619 .33006 Mdot
.06381 .29681 Mdot
.06571 .37315 Mdot
.06762 .35194 Mdot
.06952 .29596 Mdot
.07143 .22567 Mdot
.07333 .25908 Mdot
.07524 .26715 Mdot
.07714 .34467 Mdot
.07905 .35314 Mdot
.08095 .39341 Mdot
.08286 .26281 Mdot
.08476 .41268 Mdot
.08667 .35891 Mdot
.08857 .33502 Mdot
.09048 .28149 Mdot
.09238 .29336 Mdot
.09429 .42913 Mdot
.09619 .32251 Mdot
.0981 .37813 Mdot
.1 .28044 Mdot
.1019 .22662 Mdot
.10381 .31068 Mdot
.10571 .24198 Mdot
.10762 .39742 Mdot
.10952 .37869 Mdot
.11143 .27969 Mdot
.11333 .27589 Mdot
.11524 .43084 Mdot
.11714 .34719 Mdot
.11905 .35321 Mdot
.12095 .43037 Mdot
.12286 .39991 Mdot
.12476 .46573 Mdot
.12667 .24868 Mdot
.12857 .24724 Mdot
.13048 .38669 Mdot
.13238 .33279 Mdot
.13429 .37366 Mdot
.13619 .43555 Mdot
.1381 .37144 Mdot
.14 .26526 Mdot
.1419 .3436 Mdot
.14381 .38323 Mdot
.14571 .33121 Mdot
.14762 .35011 Mdot
.14952 .40256 Mdot
.15143 .31615 Mdot
.15333 .33393 Mdot
.15524 .32273 Mdot
.15714 .27287 Mdot
.15905 .3719 Mdot
.16095 .27082 Mdot
.16286 .30354 Mdot
.16476 .33584 Mdot
.16667 .38313 Mdot
.16857 .30859 Mdot
.17048 .46556 Mdot
.17238 .24868 Mdot
.17429 .38956 Mdot
.17619 .33795 Mdot
.1781 .2352 Mdot
.18 .39381 Mdot
.1819 .26574 Mdot
.18381 .30555 Mdot
.18571 .36972 Mdot
.18762 .34186 Mdot
.18952 .33568 Mdot
.19143 .3084 Mdot
.19333 .37816 Mdot
.19524 .33599 Mdot
.19714 .22537 Mdot
.19905 .46998 Mdot
.20095 .30153 Mdot
.20286 .2998 Mdot
.20476 .31295 Mdot
.20667 .46453 Mdot
.20857 .27789 Mdot
.21048 .42561 Mdot
.21238 .46268 Mdot
.21429 .37949 Mdot
.21619 .39722 Mdot
.2181 .37819 Mdot
.22 .28635 Mdot
.2219 .40115 Mdot
.22381 .23876 Mdot
.22571 .32605 Mdot
.22762 .36343 Mdot
.22952 .35646 Mdot
.23143 .30043 Mdot
.23333 .26738 Mdot
.23524 .29442 Mdot
.23714 .27043 Mdot
.23905 .41347 Mdot
.24095 .29611 Mdot
.24286 .38434 Mdot
.24476 .31317 Mdot
.24667 .25281 Mdot
.24857 .39926 Mdot
.25048 .40698 Mdot
.25238 .42658 Mdot
.25429 .3186 Mdot
.25619 .30442 Mdot
.2581 .31358 Mdot
.26 .35624 Mdot
.2619 .26836 Mdot
.26381 .29377 Mdot
.26571 .31465 Mdot
.26762 .45292 Mdot
.26952 .3989 Mdot
.27143 .26671 Mdot
.27333 .35758 Mdot
.27524 .40034 Mdot
.27714 .26223 Mdot
.27905 .29136 Mdot
.28095 .24996 Mdot
.28286 .37682 Mdot
.28476 .42597 Mdot
.28667 .33881 Mdot
.28857 .3061 Mdot
.29048 .33642 Mdot
.29238 .25932 Mdot
.29429 .39713 Mdot
.29619 .2616 Mdot
.2981 .33476 Mdot
.3 .37145 Mdot
.3019 .31341 Mdot
.30381 .38229 Mdot
.30571 .33083 Mdot
.30762 .35726 Mdot
.30952 .29739 Mdot
.31143 .27419 Mdot
.31333 .3767 Mdot
.31524 .28984 Mdot
.31714 .29434 Mdot
.31905 .27678 Mdot
.32095 .33457 Mdot
.32286 .41913 Mdot
.32476 .38905 Mdot
.32667 .3964 Mdot
.32857 .42885 Mdot
.33048 .42082 Mdot
.33238 .29902 Mdot
.33429 .38883 Mdot
.33619 .23307 Mdot
.3381 .26563 Mdot
.34 .24297 Mdot
.3419 .39504 Mdot
.34381 .38498 Mdot
.34571 .23431 Mdot
.34762 .31724 Mdot
.34952 .41876 Mdot
.35143 .33555 Mdot
.35333 .28219 Mdot
.35524 .30187 Mdot
.35714 .33123 Mdot
.35905 .35866 Mdot
.36095 .35049 Mdot
.36286 .46122 Mdot
.36476 .3305 Mdot
.36667 .31348 Mdot
.36857 .36252 Mdot
.37048 .40917 Mdot
.37238 .25645 Mdot
.37429 .34565 Mdot
.37619 .22499 Mdot
.3781 .27637 Mdot
.38 .40929 Mdot
.3819 .45173 Mdot
.38381 .41859 Mdot
.38571 .23686 Mdot
.38762 .24422 Mdot
.38952 .27622 Mdot
.39143 .31254 Mdot
.39333 .33511 Mdot
.39524 .33198 Mdot
.39714 .3564 Mdot
.39905 .22666 Mdot
.40095 .27614 Mdot
.40286 .30902 Mdot
.40476 .47757 Mdot
.40667 .34757 Mdot
.40857 .32541 Mdot
.41048 .32463 Mdot
.41238 .26799 Mdot
.41429 .34064 Mdot
.41619 .47876 Mdot
.4181 .39849 Mdot
.42 .32145 Mdot
.4219 .30543 Mdot
.42381 .26566 Mdot
.42571 .29649 Mdot
.42762 .25392 Mdot
.42952 .35112 Mdot
.43143 .24901 Mdot
.43333 .23409 Mdot
.43524 .34533 Mdot
.43714 .39618 Mdot
.43905 .25227 Mdot
.44095 .23065 Mdot
.44286 .27628 Mdot
.44476 .36482 Mdot
.44667 .29824 Mdot
.44857 .25565 Mdot
.45048 .43277 Mdot
.45238 .2372 Mdot
.45429 .2424 Mdot
.45619 .34291 Mdot
.4581 .35431 Mdot
.46 .40294 Mdot
.4619 .28891 Mdot
.46381 .2608 Mdot
.46571 .3119 Mdot
.46762 .32582 Mdot
.46952 .28995 Mdot
.47143 .47705 Mdot
.47333 .36737 Mdot
.47524 .263 Mdot
.47714 .2924 Mdot
.47905 .31232 Mdot
.48095 .4029 Mdot
.48286 .32254 Mdot
.48476 .39976 Mdot
.48667 .34516 Mdot
.48857 .25995 Mdot
.49048 .2366 Mdot
.49238 .37211 Mdot
.49429 .41429 Mdot
.49619 .31754 Mdot
.4981 .41634 Mdot
.5 .37558 Mdot
.5019 .37325 Mdot
.50381 .38412 Mdot
.50571 .22548 Mdot
.50762 .31458 Mdot
.50952 .33434 Mdot
.51143 .4214 Mdot
.51333 .26635 Mdot
.51524 .2969 Mdot
.51714 .24258 Mdot
.51905 .30405 Mdot
.52095 .33703 Mdot
.52286 .43434 Mdot
.52476 .35885 Mdot
.52667 .26247 Mdot
.52857 .2489 Mdot
.53048 .28345 Mdot
.53238 .37518 Mdot
.53429 .38509 Mdot
.53619 .26653 Mdot
.5381 .27188 Mdot
.54 .31393 Mdot
.5419 .29337 Mdot
.54381 .30075 Mdot
.54571 .24375 Mdot
.54762 .31536 Mdot
.54952 .34835 Mdot
.55143 .41774 Mdot
.55333 .34528 Mdot
.55524 .36101 Mdot
.55714 .42737 Mdot
.55905 .25515 Mdot
.56095 .32479 Mdot
.56286 .3723 Mdot
.56476 .26496 Mdot
.56667 .3407 Mdot
.56857 .42855 Mdot
.57048 .3008 Mdot
.57238 .35755 Mdot
.57429 .29585 Mdot
.57619 .35085 Mdot
.5781 .27045 Mdot
.58 .28783 Mdot
.5819 .23471 Mdot
.58381 .45167 Mdot
.58571 .43429 Mdot
.58762 .28409 Mdot
.58952 .43264 Mdot
.59143 .31579 Mdot
.59333 .4359 Mdot
.59524 .31826 Mdot
.59714 .25098 Mdot
.59905 .26973 Mdot
.60095 .30011 Mdot
.60286 .33893 Mdot
.60476 .24327 Mdot
.60667 .40127 Mdot
.60857 .41328 Mdot
.61048 .22793 Mdot
.61238 .26865 Mdot
.61429 .42678 Mdot
.61619 .2737 Mdot
.6181 .32299 Mdot
.62 .35074 Mdot
.6219 .36858 Mdot
.62381 .32376 Mdot
.62571 .26317 Mdot
.62762 .30435 Mdot
.62952 .37296 Mdot
.63143 .32199 Mdot
.63333 .33895 Mdot
.63524 .28162 Mdot
.63714 .25096 Mdot
.63905 .26387 Mdot
.64095 .41162 Mdot
.64286 .31559 Mdot
.64476 .2923 Mdot
.64667 .30404 Mdot
.64857 .39477 Mdot
.65048 .35493 Mdot
.65238 .32667 Mdot
.65429 .31955 Mdot
.65619 .36721 Mdot
.6581 .31616 Mdot
.66 .41977 Mdot
.6619 .31581 Mdot
.66381 .36284 Mdot
.66571 .26486 Mdot
.66762 .26774 Mdot
.66952 .40206 Mdot
.67143 .27715 Mdot
.67333 .24309 Mdot
.67524 .29963 Mdot
.67714 .34417 Mdot
.67905 .47289 Mdot
.68095 .2764 Mdot
.68286 .39564 Mdot
.68476 .32957 Mdot
.68667 .37073 Mdot
.68857 .26212 Mdot
.69048 .33287 Mdot
.69238 .38368 Mdot
.69429 .27719 Mdot
.69619 .26705 Mdot
.6981 .39491 Mdot
.7 .29655 Mdot
.7019 .43652 Mdot
.70381 .30119 Mdot
.70571 .32828 Mdot
.70762 .34837 Mdot
.70952 .32852 Mdot
.71143 .37171 Mdot
.71333 .29649 Mdot
.71524 .41513 Mdot
.71714 .23864 Mdot
.71905 .26401 Mdot
.72095 .24645 Mdot
.72286 .22581 Mdot
.72476 .2714 Mdot
.72667 .36136 Mdot
.72857 .25652 Mdot
.73048 .33647 Mdot
.73238 .27471 Mdot
.73429 .24 Mdot
.73619 .2802 Mdot
.7381 .30609 Mdot
.74 .39573 Mdot
.7419 .4221 Mdot
.74381 .40256 Mdot
.74571 .43267 Mdot
.74762 .41068 Mdot
.74952 .35618 Mdot
.75143 .43497 Mdot
.75333 .36047 Mdot
.75524 .2309 Mdot
.75714 .36671 Mdot
.75905 .4293 Mdot
.76095 .34012 Mdot
.76286 .28089 Mdot
.76476 .2397 Mdot
.76667 .37921 Mdot
.76857 .31889 Mdot
.77048 .25309 Mdot
.77238 .26952 Mdot
.77429 .32642 Mdot
.77619 .33001 Mdot
.7781 .24959 Mdot
.78 .27057 Mdot
.7819 .42939 Mdot
.78381 .23588 Mdot
.78571 .32901 Mdot
.78762 .2525 Mdot
.78952 .35501 Mdot
.79143 .47324 Mdot
.79333 .35031 Mdot
.79524 .35884 Mdot
.79714 .35948 Mdot
.79905 .27144 Mdot
.80095 .32038 Mdot
.80286 .29265 Mdot
.80476 .26491 Mdot
.80667 .27717 Mdot
.80857 .26036 Mdot
.81048 .34605 Mdot
.81238 .2436 Mdot
.81429 .30893 Mdot
.81619 .26149 Mdot
.8181 .25908 Mdot
.82 .29445 Mdot
.8219 .27559 Mdot
.82381 .32234 Mdot
.82571 .34235 Mdot
.82762 .27227 Mdot
.82952 .32562 Mdot
.83143 .28953 Mdot
.83333 .33936 Mdot
.83524 .27854 Mdot
.83714 .2726 Mdot
.83905 .36319 Mdot
.84095 .35373 Mdot
.84286 .29206 Mdot
.84476 .30725 Mdot
.84667 .24018 Mdot
.84857 .47047 Mdot
.85048 .40278 Mdot
.85238 .41393 Mdot
.85429 .40023 Mdot
.85619 .33092 Mdot
.8581 .39831 Mdot
.86 .25039 Mdot
.8619 .2543 Mdot
.86381 .38192 Mdot
.86571 .47102 Mdot
.86762 .27136 Mdot
.86952 .32174 Mdot
.87143 .35754 Mdot
.87333 .24563 Mdot
.87524 .32518 Mdot
.87714 .47464 Mdot
.87905 .28674 Mdot
.88095 .26219 Mdot
.88286 .31758 Mdot
.88476 .32392 Mdot
.88667 .30476 Mdot
.88857 .34125 Mdot
.89048 .34042 Mdot
.89238 .29515 Mdot
.89429 .38236 Mdot
.89619 .40179 Mdot
.8981 .37768 Mdot
.9 .30688 Mdot
.9019 .23802 Mdot
.90381 .36306 Mdot
.90571 .452 Mdot
.90762 .32697 Mdot
.90952 .31289 Mdot
.91143 .22487 Mdot
.91333 .26499 Mdot
.91524 .43627 Mdot
.91714 .29303 Mdot
.91905 .3728 Mdot
.92095 .32994 Mdot
.92286 .39759 Mdot
.92476 .35213 Mdot
.92667 .26615 Mdot
.92857 .33793 Mdot
.93048 .33754 Mdot
.93238 .25058 Mdot
.93429 .31184 Mdot
.93619 .24213 Mdot
.9381 .33995 Mdot
.94 .26905 Mdot
.9419 .32302 Mdot
.94381 .25151 Mdot
.94571 .24578 Mdot
.94762 .3215 Mdot
.94952 .25839 Mdot
.95143 .4012 Mdot
.95333 .34424 Mdot
.95524 .37977 Mdot
.95714 .32621 Mdot
.95905 .3455 Mdot
.96095 .29065 Mdot
.96286 .39468 Mdot
.96476 .29686 Mdot
.96667 .40025 Mdot
.96857 .43043 Mdot
.97048 .26848 Mdot
.97238 .32881 Mdot
.97429 .34888 Mdot
.97619 .26772 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`0<ooooo`;o00001oooool2o`0001gooooo0_l0000hooooo`;o00001Oooool2o`00023ooooo0_l0
000Pooooo`;o00008_ooool2o`0003_ooooo0_l0000Pooooo`001?l00002ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool03?ooool2o`0000Oooooo0_l0000Mooooo`;o0000>?ooool2o`0000Gooooo0_l0
000;ooooo`;o00004oooool2o`00023ooooo0_l0000Rooooo`;o00002?ooool2o`00037ooooo0_l0
000Pooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00omgMgOo<S8booooo`04ooooo`?o0000HOooool2o`0001gooooo1?l0001Sooooo`;o0000Dooo
ool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo02kooooo0_l0000aooooo`;o0000
00?oooooo`000?l000002oooool2o`0000gooooo0_l00004ooooo`;o00002_ooool2o`0001cooooo
0_l0000oooooo`;o0000BOooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0^ooooo`;o0000
3Oooool2o`0002Gooooo0_l0000;ooooo`;o00004oooool2o`0000[ooooo0_l0000Looooo`;o0000
:Oooool2o`0000Cooooo0_l00008ooooo`;o00001?ooool2o`0001;ooooo0_l0000@ooooo`;o0000
8oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@
41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Oooooo0_l0000Tooooo`;o
00008oooool2o`0002?ooooo0_l0000Booooo`;o00006_ooool2o`0001Cooooo0_l0000<ooooo`;o
00001?ooool2o`0000Sooooo0_l0000Hooooo`;o00004?ooool2o`0000Wooooo0_l0000Hooooo`00
1_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co00001_ooool00ol0003oooooooooo`0Gooooo`;o0000BOooool2o`0000gooooo0_l0000Doooo
o`;o00004_ooool2o`0000Oooooo0_l0000Aooooo`;o00005?ooool2o`0000gooooo0_l0000Loooo
o`;o00004Oooool2o`0001?ooooo0_l000000ooooooo0000o`00000Eooooo`00:Oooool2o`0001ko
oooo0ol0000<ooooo`;o0000@oooool2o`0000cooooo0_l0000Nooooo`;o00000oooool2o`0003Ko
oooo0_l0000Aooooo`;o00002Oooool2o`00017ooooo0_l0000Fooooo`;o00005Oooool002Wooooo
00?o0000ooooooooool07Oooool3o`0000cooooo0_l0000Fooooo`;o00002Oooool2o`0002kooooo
0_l000000ooooooo0000o`00000Kooooo`;o00005?ooool2o`0000[ooooo0_l0000/ooooo`;o0000
00?oooooo`000?l000005Oooool2o`0001Gooooo0_l00002ooooo`;o00005_ooool002Wooooo00?o
0000ooooooooool00oooool2o`0003oooooo0_l00009ooooo`;o0000;Oooool2o`0000;ooooo0_l0
00000ooooooo0000o`00000Qooooo`;o00002oooool2o`0000[ooooo0_l0000Yooooo`;o00001?oo
ool2o`0001Gooooo0ol0000Dooooo`;o00000_ooool2o`0001Kooooo000Yooooo`03o`000?oooooo
oooo00?ooooo0_l0001Wooooo`;o00004?ooool2o`0000Gooooo0_l0000Qooooo`;o0000=Oooool2
o`0000_ooooo0_l0000Looooo`;o00006_ooool2o`0001Cooooo000Yooooo`03o`000?oooooooooo
00cooooo0_l00015ooooo`?o00005_ooool2o`0001cooooo0_l00006ooooo`;o0000?_ooool2o`00
00_ooooo0_l0000Hooooo`Go0000:?ooool2o`0001Cooooo000Yooooo`;o00001_ooool2o`0000Go
oooo0_l000000ooooooo0000o`00000Aooooo`;o0000:_ooool2o`0000?ooooo0ol0000dooooo`;o
000000?oooooo`000?l000000oooool2o`0000[ooooo0_l0000:ooooo`;o00004_ooool2o`0000;o
oooo0_l00007ooooo`;o00001Oooool2o`0000Sooooo0_l0000Iooooo`Oo00004_ooool2o`0000So
oooo0_l0000Pooooo`00:Oooool00ol0003oooooooooo`05ooooo`;o00001_ooool4o`00017ooooo
0_l0000;ooooo`;o00003oooool2o`0000Oooooo0_l000000ooooooo0000o`000002o`00017ooooo
0_l0000Fooooo`;o00000_ooool2o`0000kooooo0_l0000;ooooo`;o00000_ooool2o`000003oooo
ool0003o000000Oooooo0_l0000Booooo`;o00000_ooool2o`0000Oooooo0_l00007ooooo`;o0000
1_ooool2o`0001Wooooo0_l0000Gooooo`;o00002?ooool2o`0000?ooooo0_l0000>ooooo`;o0000
2oooool002Wooooo00?o0000ooooooooool03Oooool2o`0001Wooooo0_l00005ooooo`Go000000So
410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^o`000?l0003o0000onk^kP05
ooooo`;o000000?oooooo`000?l000004oooool2o`0000[ooooo1Ol00003ooooo`04onk^k_lb<S;o
0000oc8b<P;o00000_ooool3o`000003oc8b<_o^k^kooooo01Oooooo0_l00005ooooo`;o00001ooo
ool01?nHV9So410@o`000?lb<S82o`0000;ooooo00?ok^k^oc8b<_l000000_l00003ooooo`?o0000
00?o<S8bonk^k_ooool02oooool2o`0000Oooooo0_l00008ooooo`;o00002Oooool2o`000003oa0@
4?oooooo000000Co000000Co<S8bonk^k_oooooooooo0_l000001?lb<S;o0000oc8b<_o^k^h@oooo
o`;o00004Oooool2o`0000;ooooo0_l000001Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00?ok^k^
o`000?l000000_l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool002Wooooo00?o0000
ooooooooool01Oooool2o`00023ooooo0ol00008ooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So0000o`000?mgMgL05Oooool2o`0001;ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg023ooooo0_l00006ooooo`04oa0@4?nj^[[oooooogMgM`;o00000_oo
ool00omgMgOoV9RHooooo`02o`0000?ooooo0ol000000onHV9SoMgMgooooo`0Nooooo`;o00002_oo
ool00ol0003oooooooooo`04o`000003oooooonHV9SoMgMg00;ooooo0_l000001?nHV9SooooooiRH
V?mgMgL3ooooo`;o000000?oooooo`000?l000002?ooool2o`0001Gooooo0_l00003ooooo`05ogMg
Molb<S;ooooooooooomgMgL00_l000000onHV9SoMgMgooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool002Wooooo00Co0000ooooool0003o00001?ooool2o`0001;ooooo0_l0000<oooo
o`;o00002Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool0
1Ol@413ooooooooooooooooo410@01Gooooo1?l0000Aooooo`;o000000Kok^k^ooooool0003o0000
ooooool@4102o`000003ooooool@413ooooo00;ooooo00Ko410@oooooooooooooooooa0@4?ooool2
o`0001gooooo0_l0000:ooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooo
oooooooo410@00;o000000?ooooooa0@4?ooool03Oooool2o`000003ooooool0003o000000;ooooo
0_l0000:ooooo`;o00001Oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@4003ooooo`06
oa0@4?l0003o0000ooooool@413ooooo1?l000000ooooooo0000o`00000Uooooo`04o`000?oooooo
oooooa0@40?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo007ooooo
000Yooooo`Co00005?ooool2o`000004ooooool0003o0000o`0001Oooooo00?o0000ooooooooool0
0_ooool3o`000003ooooool0003ooooo00;ooooo00Go0000ooooooooooooooooo`00000Gooooo`;o
00004Oooool2o`000005ob4Q8Oo^k^ko0000o`000?ooool00ol000000ooooooo0000ooooo`02oooo
o`06o`000?ooooooooooooooool0003ooooo0_l0000Xooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000003_ooool2o`000003
ooooool0003o000000;ooooo0_l0000:ooooo`?o00001?ooool01?m4A4CogMgMooooool00004oooo
o`05o`000?ooooooooooooooool000000oooool3o`000003ooooool0003ooooo00;o00000_ooool2
o`0002Gooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`01ooooo`00:Oooool00ol0003oooooooooo`0Booooo`;o000000Co
ooooo`000?l0003ooooo0_l0000Hooooo`03o`000?oooooooooo00;ooooo0ol000000ooooooo0000
ooooo`02ooooo`05o`000?ooooooooooooooool000008_ooool2o`0000Sooooo00?oMgMgofIVI_oo
ool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00000M
ooooo`;o00002oooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000;ooooo0_l0000Nooooo`;o00001?ooool00ooMgMgoEEEE
ooooo`02o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000001Oooool2o`0002;ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo000Yooooo`03o`000?oo
oooooooo00;o00004?ooool2o`0001kooooo00?o0000ooooooooool00_ooool01?l@413ooooooooo
ooooool2o`0000;ooooo00Go410@oooooooooooooooooa0@400Rooooo`;o00002Oooool01Ol0003o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooo
oooo01_ooooo0_l0000<ooooo`03okZj^_lQ8B7ooooo00;ooooo0_l00002ooooo`05oa0@4?oooooo
ooooooooool@41000oooool00ol@413oooooooooo`02o`0002Gooooo00CoMgMgolc<c?l0003o0000
0oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@400Coooo
o`;o00005?ooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41000oooool0
1Ol@413ooooooooooooooooo410@00?ooooo000Yooooo`03o`000?oooooooooo00;o00000_ooool2
o`0002cooooo00?o0000ooooooooool00_ooool01?mgMgOoV9RHoooooonHV9P2o`0000;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0Fooooo`;o00004Oooool01Ol0003o^[ZjoooooonHV9So410@00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01oooool2
o`000003ooooool0003o000001cooooo00Co410@oiRHV?oooooo^[Zj0ol000001_oooooo0000o`00
0?ooooooV9RHogMgM`?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Yooooo`03onk^k_m4A4Co0000
00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?oo
ool2o`0000gooooo0_l0000Dooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wooooo00?o0000ooooooooool0
1?ooool2o`0002[ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0:ooooo`;o00002_ooool2o`00017ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Oooooo0_l000000ooooooo0000o`000002o`0001[ooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@02o`000006ooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_l0000Sooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`?o000000?o<S8bonk^k_ooool00oooool2o`0000;ooooo0_l0000Fooooo`;o0000
1oooool4o`000008ooooool0003o0000onk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool002Wooooo0ol0000;ooooo`;o00001Oooool2o`0002cooooo1?l00005
ooooo`;o00000oooool2o`0000_ooooo0_l0000aooooo`;o00004oooool2o`0000Sooooo0_l0000E
ooooo`;o0000<Oooool2o`0000?ooooo0_l00006ooooo`;o00003_ooool2o`0000Kooooo0_l0000<
ooooo`;o00004?ooool002Wooooo0ol00009ooooo`Co00001Oooool2o`0002cooooo1?l00005oooo
o`;o00003Oooool2o`000003ooooool0003o000000;ooooo0_l0000Looooo`;o00001Oooool2o`00
01Cooooo0_l00007ooooo`;o00002?ooool2o`0002Oooooo0_l00002ooooo`;o00008?ooool2o`00
01Kooooo0_l0000Eooooo`;o00003oooool002Wooooo00?o0000ooooooooool02Oooool2o`0002[o
oooo0ol00007ooooo`;o00005oooool2o`0000Gooooo0_l00006ooooo`;o00005?ooool2o`0000Go
oooo0_l0000Dooooo`;o00001oooool2o`0000Oooooo0_l00008ooooo`;o00005_ooool2o`0000Ko
oooo0ol000000ooooooo0000o`00001?ooooo`;o00003oooool002Wooooo00?o0000ooooooooool0
:Oooool2o`0000Gooooo0_l00003ooooo`?o00001oooool2o`0000Kooooo0_l0000Nooooo`;o0000
4oooool2o`0001kooooo0_l00005ooooo`;o00001oooool2o`0000Sooooo0_l00006ooooo`;o0000
1Oooool2o`0000Oooooo0_l00007ooooo`;o0000>Oooool2o`0002Sooooo000Yooooo`03o`000?oo
oooooooo02Wooooo1?l00003ooooo`Co00004oooool2o`0000Sooooo0_l0000Yooooo`;o00007_oo
ool2o`00023ooooo0_l00005ooooo`;o00006oooool2o`00023ooooo0_l0000<ooooo`;o00000_oo
ool2o`0002Cooooo000Qoooooooo0000A?l00004ooooo`00:Oooool00ol0003oooooooooo`02oooo
o`;o00000oooool3o`0000cooooo0_l0000:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool01Oooool2o`0000;ooooo00?o0000ooooooooool01_ooool2o`0000;ooooo1Ol00007oooo
o`03o`000?oooooooooo00;o00001oooool00ol0003oooooooooo`09ooooo`;o00001Oooool2o`00
00;ooooo0ol0000;ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`;o00001oooool2o`00
00;ooooo00?o0000ooooooooool00oooool2o`0000Gooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool2o`00
00;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`04o`000?oooooo0000
o`0000Kooooo0ol0000;ooooo`03o`000?oooooooooo00[ooooo000Yooooo`04o`000?oooooooooo
ooooo`;o00001?ooool2o`0001cooooo0_l0000?ooooo`;o00000_ooool00ol0003oooooooooo`06
ooooo`;o00000oooool4o`0000[ooooo0_l0000<ooooo`;o00001Oooool2o`0000Gooooo0_l00004
ooooo`03o`000?oooooooooo01Cooooo0_l00003ooooo`;o00000_ooool2o`0000Sooooo0_l00000
0ooooooo0000o`00000<ooooo`?o00003Oooool2o`0000?ooooo0ol0000Wooooo`03o`000?oooooo
oooo01_ooooo0_l00007ooooo`;o00005?ooool00ol0003oooooooooo`0:ooooo`00:Oooool01?l0
003oooooooooooooool2o`000003ooooool0003o000001oooooo0_l0000Oooooo`;o00007?ooool2
o`0002kooooo0_l0000?ooooo`;o00003?ooool3o`0000gooooo0_l00002ooooo`Co00008Oooool2
o`0000Sooooo0_l0000Hooooo`;o0000:_ooool002Wooooo00?o0000ooooooooool01?ooool2o`00
00kooooo0_l0000Aooooo`;o00007Oooool2o`0003Cooooo0_l0000Booooo`;o00008_ooool2o`00
00Gooooo1?l000000ooooooo0000o`000005ooooo`;o00008oooool2o`0000Sooooo0_l00006oooo
o`;o00003?ooool2o`0000?ooooo0_l0000@ooooo`Co00005Oooool002Wooooo0_l0000Eooooo`;o
00004Oooool2o`0001Cooooo0_l0000iooooo`?o000000?oooooo`000?l000003Oooool2o`0000?o
oooo0_l0000Gooooo`;o00004?ooool4o`000003ooooool0003o000000Cooooo0_l0000Vooooo`;o
00003_ooool3o`0000_ooooo1?l000000ooooooo0000o`000005ooooo`;o00002Oooool4o`000003
ooooool0003o000001;ooooo000Yooooo`03o`000?oooooooooo00Wooooo0_l0000booooo`;o0000
:oooool2o`0000cooooo0ol0000@ooooo`;o00007?ooool2o`0001_ooooo0_l00009ooooo`;o0000
1Oooool3o`0001?ooooo0_l000000ooooooo0000o`00000<ooooo`;o00003Oooool2o`0000Sooooo
0_l00003ooooo`;o00002Oooool2o`0000?ooooo0_l0000=ooooo`00:Oooool00ol0003ooooooooo
o`09ooooo`;o00005?ooool2o`0000;ooooo0_l0000booooo`;o00003_ooool2o`000003ooooool0
003o000000Sooooo0_l0001Kooooo`Co00000oooool3o`0001?ooooo0_l000000ooooooo0000o`00
000Eooooo`;o00004oooool2o`0000kooooo0_l0000=ooooo`00:Oooool00ol0003oooooooooo`0A
ooooo`;o00003?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00001_ooool3
o`0001gooooo1?l000000ooooooo0000o`000003ooooo`;o00002?ooool3o`0000[ooooo0ol0000R
ooooo`;o0000>Oooool2o`0000[ooooo0_l0000Wooooo`;o0000<_ooool002Wooooo00?o0000oooo
ooooool01_ooool2o`0000Wooooo0_l0000Cooooo`;o00000_ooool2o`000003ooooool0003o0000
00?ooooo0ol0000Looooo`Go00001_ooool2o`0000Sooooo0_l0000;ooooo`;o00008oooool2o`00
00;ooooo0_l0000Hooooo`;o00002?ooool2o`0001gooooo0_l0000Pooooo`;o00007?ooool3o`00
01[ooooo000Yooooo`Ko00000oooool2o`0002Gooooo0_l00002ooooo`;o00007_ooool2o`0002Oo
oooo0_l0000;ooooo`;o00004oooool2o`0000gooooo0_l00009ooooo`;o00002?ooool2o`0002Oo
oooo0_l0000Cooooo`;o000000?oooooo`000?l000003oooool3o`0000[ooooo1Ol0000Hooooo`00
:Oooool00ol0003oooooo`000003o`0000[ooooo0_l0000Cooooo`;o00003Oooool2o`0003[ooooo
0_l0000;ooooo`;o00001Oooool2o`0000Cooooo0_l00008ooooo`;o00005?ooool2o`0000;ooooo
0_l0000Qooooo`;o00006Oooool2o`0000kooooo0_l00003ooooo`;o00004_ooool3o`0000gooooo
0_l00003ooooo`Co00004Oooool002Wooooo00?o0000ooooooooool02?ooool2o`0000?ooooo0_l0
000;ooooo`;o00001_ooool2o`0004Wooooo0_l00008ooooo`;o00002?ooool2o`0000kooooo0_l0
000Booooo`Co00009Oooool2o`0000Sooooo0_l0000Oooooo`;o0000;?ooool4o`0000?ooooo0_l0
000<ooooo`00:Oooool00ol0003oooooooooo`08ooooo`Co00003_ooool2o`0000Sooooo0_l00013
ooooo`;o00003?ooool2o`0000Kooooo0_l0000Tooooo`;o00001oooool2o`0000cooooo0_l0000J
ooooo`;o00006_ooool2o`0002Sooooo0_l0000>ooooo`;o00003?ooool002Wooooo00?o0000oooo
ooooool02_ooool2o`0000;ooooo0_l0000;ooooo`;o00001oooool2o`0004?ooooo0_l0000Doooo
o`;o00001oooool2o`0002Cooooo0_l0000<ooooo`;o00002?ooool2o`0002[ooooo1?l0000=oooo
o`;o00006Oooool2o`0001cooooo000Yooooo`;o00003oooool2o`0000_ooooo0_l0000Qooooo`;o
00002?ooool2o`0000?ooooo0_l00009ooooo`;o00006_ooool2o`0001;ooooo0_l0000Sooooo`;o
00005oooool2o`0001kooooo0_l0000:ooooo`;o00003oooool2o`0000Sooooo0_l0000]ooooo`00
:Oooool00ol0003oooooooooo`0@ooooo`;o0000;?ooool2o`0000Sooooo0_l00003ooooo`;o0000
2Oooool2o`0000kooooo0_l0000:ooooo`;o00009oooool2o`0000Sooooo0_l00004ooooo`;o0000
;oooool2o`0000Kooooo0ol0000;ooooo`?o00005_ooool2o`0002gooooo000Yooooo`03o`000?oo
oooooooo013ooooo0_l0000/ooooo`;o0000:?ooool2o`000003ooooool0003o0000033ooooo0_l0
0008ooooo`;o00008Oooool2o`0001;ooooo0_l00007ooooo`;o00002oooool3o`0000_ooooo0_l0
000Cooooo`;o00008oooool002Wooooo00?o0000ooooooooool0?_ooool2o`0002_ooooo0_l0000G
ooooo`;o00001oooool2o`0003Wooooo1?l0000Looooo`;o00006?ooool2o`0001?ooooo0_l0000S
ooooo`00:Oooool00ol0003oooooooooo`0`ooooo`;o0000D_ooool2o`0000Oooooo0_l0000^oooo
o`;o00002Oooool2o`0000Oooooo0_l0000Eooooo`;o0000D_ooool002Wooooo0_l00008ooooo`;o
000000?oooooo`000?l000005?ooool3o`0000Gooooo0_l00006ooooo`;o00008oooool2o`0003co
oooo0_l000000ooooooo0000o`00000Booooo`;o00004Oooool4o`00013ooooo0_l00006ooooo`;o
0000@Oooool2o`0001kooooo000Yooooo`03o`000?oooooooooo00Oooooo0_l000000ooooooo0000
o`00000Dooooo`?o00001Oooool2o`0002Kooooo0_l00003ooooo`;o00000_ooool2o`0003Sooooo
1Ol00008ooooo`;o00002?ooool2o`0001?ooooo0_l0000Hooooo`;o0000@Oooool2o`0001kooooo
0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Dooooo`;o00000_ooool2o`0001Wo
oooo0_l00005ooooo`?o00004oooool2o`0000Oooooo0_l0000jooooo`;o00002Oooool2o`0004Wo
oooo0_l0000Xooooo`;o00004Oooool2o`0001;ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool05?ooool2o`0000;ooooo0_l00009ooooo`;o00001Oooool2o`00
00Oooooo0_l00005ooooo`?o00006Oooool2o`0009?ooooo0_l0000Mooooo`;o00002?ooool3o`00
017ooooo0_l0000Booooo`001_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q
8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02?ooooo0_l00005oooo
o`;o00005oooool2o`00017ooooo0_l0000;ooooo`;o0000<_ooool2o`0000Oooooo0_l0000aoooo
o`;o0000=Oooool2o`0000Sooooo0_l0000Vooooo`001_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o00007oooool2o`00
00cooooo0_l0000Dooooo`;o00006?ooool2o`000004ooooool0003o0000ooooo`;o0000<_ooool2
o`0000Oooooo0_l0000aooooo`;o0000Ioooool000Kooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`;o00008?oo
ool2o`0000cooooo0_l0000^ooooo`;o000000?oooooo`000?l00000f_ooool000Kooooo00Go410@
oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01ooo
ool2o`00013ooooo0_l0000Mooooo`;o0000<oooool2o`00063ooooo0_l00009ooooo`;o00000ooo
ool2o`0000cooooo0_l00015ooooo`;o00004?ooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`;o0000
4?ooool2o`0000Kooooo0_l0000Eooooo`;o00002_ooool2o`0000oooooo0_l00006ooooo`;o0000
2Oooool2o`0000?ooooo0_l0000Fooooo`;o00001?ooool2o`0004;ooooo0_l00009ooooo`;o0000
0oooool2o`0000cooooo0_l0000Tooooo`;o00004_ooool2o`0000_ooooo0_l0000@ooooo`001_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co
00001_ooool2o`0001Sooooo0_l00003ooooo`;o00007?ooool4o`0000Oooooo0_l00004ooooo`Co
00001?ooool2o`0000Wooooo0_l0000Kooooo`;o00001?ooool2o`0000gooooo0_l0000Vooooo`;o
00004_ooool2o`0003Wooooo1?l0000:ooooo`;o00001_ooool2o`0000Sooooo0_l00002ooooo`;o
00003oooool002Wooooo0_l0000Mooooo`;o00001oooool2o`0001Gooooo0_l00007ooooo`;o0000
1_ooool2o`0003[ooooo0_l00004ooooo`?o00009_ooool2o`0001;ooooo0_l0000Fooooo`;o0000
8?ooool3o`0000cooooo0_l0000@ooooo`;o00000_ooool2o`0000oooooo000Yooooo`03o`000?oo
oooooooo02Gooooo0_l0000Nooooo`;o0000@_ooool2o`0000Cooooo0_l0001Cooooo`;o00008?oo
ool2o`0003Cooooo000Yooooo`03o`000?oooooooooo00;ooooo0_l00011ooooo`;o00009Oooool2
o`000003ooooool0003o000007Cooooo0_l0001Eooooo`00:Oooool00ol0003oooooooooo`02oooo
o`;o00003?ooool2o`0002oooooo0_l0000Yooooo`;o000000?oooooo`000?l000008oooool2o`00
02;ooooo0_l00009ooooo`;o00008?ooool2o`00023ooooo0_l0000cooooo`00:Oooool00ol0003o
ooooooooo`0@ooooo`;o0000;oooool2o`00057ooooo0ol0000Qooooo`;o00002Oooool2o`0001Ko
oooo0_l0000Zooooo`;o0000<oooool002Wooooo0_l0001Mooooo`;o00001oooool2o`0000Wooooo
0_l0000Sooooo`;o00003oooool2o`00027ooooo0_l0000@ooooo`;o0000Goooool002Wooooo00?o
0000ooooooooool0G?ooool2o`000003ooooool0003o000000Cooooo0_l00009ooooo`;o00009ooo
ool2o`0000_ooooo0_l0000Qooooo`;o00006?ooool2o`0005Oooooo000Yooooo`03o`000?oooooo
oooo03Sooooo0_l0000<ooooo`;o00002?ooool2o`0000gooooo0_l0000hooooo`;o00007oooool2
o`0002Oooooo0_l0001Gooooo`00:Oooool00ol0003oooooooooo`0Cooooo`;o00008oooool2o`00
00cooooo0_l00008ooooo`;o00003?ooool2o`0004Sooooo0_l000000ooooooo0000o`00000=oooo
o`;o0000;Oooool2o`0000Gooooo0_l0001:ooooo`00:Oooool00ol0003oooooooooo`0Cooooo`;o
00001Oooool4o`00043ooooo0_l0000Uooooo`;o00008Oooool2o`000003ooooool0003o000000Go
oooo0_l0000`ooooo`;o00000oooool2o`0000Gooooo0_l0000jooooo`;o00003_ooool002Wooooo
0_l0000Kooooo`Co00000_ooool2o`0006?ooooo0_l0000Fooooo`;o00004_ooool4o`0002oooooo
1?l0000cooooo`;o00003oooool2o`0000kooooo000Yooooo`03o`000?oooooooooo023ooooo0_l0
001kooooo`;o00004_ooool4o`00027ooooo0_l0000>ooooo`;o0000<oooool2o`0001oooooo000Y
ooooo`03o`000?oooooooooo0=Kooooo0_l0001Tooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0001`ooooo`;o0000
?oooool2o`0008[ooooo000Yooooo`03o`000?oooooooooo04_ooooo0_l0000Rooooo`;o0000?ooo
ool2o`0006Kooooo0_l0000Rooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`1;ooooo`;o0000
boooool2o`0002;ooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@4?oo
ooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`?o0000>Oooool2o`0002kooooo
0_l0003Aooooo`003_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`0Mooooo`;o00003?ooool2o`0000[ooooo1?l0000^ooooo`;o0000
dOooool000kooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`0Mooooo`;o00003?ooool2o`0000Sooooo1?l0003<ooooo`;o
0000=Oooool000kooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0=Oooool2o`0009Sooooo0_l0000Rooooo`;o00004?ooool2o`0000Co
oooo0_l0000_ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`3?ooooo`;o00008_ooool2o`0001Kooooo0_l00002ooooo`;o
0000:oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`0007So
oooo0_l000000ooooooo0000o`00000@ooooo`;o0000POooool2o`0002_ooooo000Yooooo`03o`00
0?oooooooooo07Oooooo0_l000000ooooooo0000o`00000@ooooo`;o0000[_ooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`001_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooo
oooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000
oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool0
1_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go
0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooo
oooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413o
oooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooo
ocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006oooo
o`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool001oooooo1?l0
00000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo
00Gooooo0ol0003oooooocgooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool001oooooo00?oEEEEofIVI_l00000oooooom7oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .34016 Mdot
.02762 .40059 Mdot
.02952 .27525 Mdot
.03143 .2668 Mdot
.03333 .36341 Mdot
.03524 .24365 Mdot
.03714 .30722 Mdot
.03905 .4212 Mdot
.04095 .43903 Mdot
.04286 .3477 Mdot
.04476 .30878 Mdot
.04667 .39128 Mdot
.04857 .39147 Mdot
.05048 .33456 Mdot
.05238 .37043 Mdot
.05429 .29269 Mdot
.05619 .37346 Mdot
.0581 .38844 Mdot
.06 .29233 Mdot
.0619 .2362 Mdot
.06381 .37883 Mdot
.06571 .4062 Mdot
.06762 .40044 Mdot
.06952 .37939 Mdot
.07143 .31542 Mdot
.07333 .27056 Mdot
.07524 .27053 Mdot
.07714 .28633 Mdot
.07905 .25237 Mdot
.08095 .40199 Mdot
.08286 .35606 Mdot
.08476 .44073 Mdot
.08667 .42739 Mdot
.08857 .37737 Mdot
.09048 .3576 Mdot
.09238 .2346 Mdot
.09429 .38746 Mdot
.09619 .25911 Mdot
.0981 .28568 Mdot
.1 .38594 Mdot
.1019 .32402 Mdot
.10381 .37084 Mdot
.10571 .2992 Mdot
.10762 .35136 Mdot
.10952 .30886 Mdot
.11143 .34688 Mdot
.11333 .33465 Mdot
.11524 .43538 Mdot
.11714 .27331 Mdot
.11905 .25353 Mdot
.12095 .43415 Mdot
.12286 .32139 Mdot
.12476 .48262 Mdot
.12667 .32793 Mdot
.12857 .32691 Mdot
.13048 .43634 Mdot
.13238 .41604 Mdot
.13429 .37255 Mdot
.13619 .41874 Mdot
.1381 .295 Mdot
.14 .3367 Mdot
.1419 .23261 Mdot
.14381 .29471 Mdot
.14571 .32948 Mdot
.14762 .42128 Mdot
.14952 .44066 Mdot
.15143 .34774 Mdot
.15333 .28202 Mdot
.15524 .2587 Mdot
.15714 .36513 Mdot
.15905 .37926 Mdot
.16095 .3105 Mdot
.16286 .34538 Mdot
.16476 .34474 Mdot
.16667 .29456 Mdot
.16857 .30817 Mdot
.17048 .48264 Mdot
.17238 .30171 Mdot
.17429 .30273 Mdot
.17619 .2642 Mdot
.1781 .29616 Mdot
.18 .4005 Mdot
.1819 .27978 Mdot
.18381 .36912 Mdot
.18571 .43322 Mdot
.18762 .29687 Mdot
.18952 .36369 Mdot
.19143 .35736 Mdot
.19333 .36368 Mdot
.19524 .28662 Mdot
.19714 .30848 Mdot
.19905 .42548 Mdot
.20095 .33736 Mdot
.20286 .35569 Mdot
.20476 .33766 Mdot
.20667 .40926 Mdot
.20857 .33699 Mdot
.21048 .43426 Mdot
.21238 .48407 Mdot
.21429 .36506 Mdot
.21619 .35688 Mdot
.2181 .34628 Mdot
.22 .38837 Mdot
.2219 .36543 Mdot
.22381 .32834 Mdot
.22571 .37515 Mdot
.22762 .38174 Mdot
.22952 .31438 Mdot
.23143 .33722 Mdot
.23333 .36088 Mdot
.23524 .34413 Mdot
.23714 .27274 Mdot
.23905 .44019 Mdot
.24095 .23315 Mdot
.24286 .46297 Mdot
.24476 .32776 Mdot
.24667 .32141 Mdot
.24857 .44239 Mdot
.25048 .44277 Mdot
.25238 .38476 Mdot
.25429 .39064 Mdot
.25619 .22314 Mdot
.2581 .38563 Mdot
.26 .25513 Mdot
.2619 .36179 Mdot
.26381 .2593 Mdot
.26571 .23269 Mdot
.26762 .3846 Mdot
.26952 .38655 Mdot
.27143 .31137 Mdot
.27333 .40308 Mdot
.27524 .37317 Mdot
.27714 .37179 Mdot
.27905 .24183 Mdot
.28095 .27481 Mdot
.28286 .28123 Mdot
.28476 .3735 Mdot
.28667 .24145 Mdot
.28857 .34578 Mdot
.29048 .41615 Mdot
.29238 .36835 Mdot
.29429 .29111 Mdot
.29619 .31363 Mdot
.2981 .26956 Mdot
.3 .37366 Mdot
.3019 .23203 Mdot
.30381 .4378 Mdot
.30571 .43406 Mdot
.30762 .32834 Mdot
.30952 .35382 Mdot
.31143 .23125 Mdot
.31333 .3382 Mdot
.31524 .25469 Mdot
.31714 .3788 Mdot
.31905 .31647 Mdot
.32095 .25032 Mdot
.32286 .35982 Mdot
.32476 .30366 Mdot
.32667 .44076 Mdot
.32857 .38848 Mdot
.33048 .36308 Mdot
.33238 .24672 Mdot
.33429 .30081 Mdot
.33619 .34163 Mdot
.3381 .2479 Mdot
.34 .29569 Mdot
.3419 .35289 Mdot
.34381 .43837 Mdot
.34571 .31424 Mdot
.34762 .25579 Mdot
.34952 .35653 Mdot
.35143 .24054 Mdot
.35333 .33036 Mdot
.35524 .25319 Mdot
.35714 .36229 Mdot
.35905 .33715 Mdot
.36095 .42262 Mdot
.36286 .40206 Mdot
.36476 .24778 Mdot
.36667 .32594 Mdot
.36857 .26308 Mdot
.37048 .33686 Mdot
.37238 .36776 Mdot
.37429 .33168 Mdot
.37619 .31591 Mdot
.3781 .27278 Mdot
.38 .43778 Mdot
.3819 .38322 Mdot
.38381 .44224 Mdot
.38571 .34725 Mdot
.38762 .28736 Mdot
.38952 .23088 Mdot
.39143 .23188 Mdot
.39333 .31258 Mdot
.39524 .22751 Mdot
.39714 .42759 Mdot
.39905 .28883 Mdot
.40095 .38191 Mdot
.40286 .35855 Mdot
.40476 .44651 Mdot
.40667 .38312 Mdot
.40857 .30997 Mdot
.41048 .3134 Mdot
.41238 .30376 Mdot
.41429 .36195 Mdot
.41619 .45566 Mdot
.4181 .36533 Mdot
.42 .27269 Mdot
.4219 .24034 Mdot
.42381 .27825 Mdot
.42571 .26247 Mdot
.42762 .30459 Mdot
.42952 .4039 Mdot
.43143 .30866 Mdot
.43333 .31239 Mdot
.43524 .32268 Mdot
.43714 .3573 Mdot
.43905 .31906 Mdot
.44095 .33691 Mdot
.44286 .2723 Mdot
.44476 .2853 Mdot
.44667 .39721 Mdot
.44857 .32616 Mdot
.45048 .42221 Mdot
.45238 .32537 Mdot
.45429 .27525 Mdot
.45619 .30909 Mdot
.4581 .35642 Mdot
.46 .39602 Mdot
.4619 .33338 Mdot
.46381 .36928 Mdot
.46571 .22273 Mdot
.46762 .26887 Mdot
.46952 .27244 Mdot
.47143 .45772 Mdot
.47333 .31479 Mdot
.47524 .27518 Mdot
.47714 .22522 Mdot
.47905 .25436 Mdot
.48095 .37343 Mdot
.48286 .3907 Mdot
.48476 .36821 Mdot
.48667 .23371 Mdot
.48857 .26092 Mdot
.49048 .28641 Mdot
.49238 .37905 Mdot
.49429 .44222 Mdot
.49619 .33639 Mdot
.4981 .35638 Mdot
.5 .35297 Mdot
.5019 .37821 Mdot
.50381 .29564 Mdot
.50571 .29456 Mdot
.50762 .32709 Mdot
.50952 .31356 Mdot
.51143 .36912 Mdot
.51333 .26305 Mdot
.51524 .25371 Mdot
.51714 .31702 Mdot
.51905 .31203 Mdot
.52095 .41755 Mdot
.52286 .42897 Mdot
.52476 .29391 Mdot
.52667 .27592 Mdot
.52857 .26472 Mdot
.53048 .32486 Mdot
.53238 .33524 Mdot
.53429 .32543 Mdot
.53619 .32743 Mdot
.5381 .25192 Mdot
.54 .23342 Mdot
.5419 .24846 Mdot
.54381 .2329 Mdot
.54571 .31958 Mdot
.54762 .34872 Mdot
.54952 .27677 Mdot
.55143 .35607 Mdot
.55333 .33533 Mdot
.55524 .34357 Mdot
.55714 .43638 Mdot
.55905 .31228 Mdot
.56095 .24444 Mdot
.56286 .27553 Mdot
.56476 .3097 Mdot
.56667 .33844 Mdot
.56857 .38872 Mdot
.57048 .39726 Mdot
.57238 .31771 Mdot
.57429 .32163 Mdot
.57619 .35507 Mdot
.5781 .24314 Mdot
.58 .35015 Mdot
.5819 .30994 Mdot
.58381 .38359 Mdot
.58571 .41526 Mdot
.58762 .38609 Mdot
.58952 .4167 Mdot
.59143 .28001 Mdot
.59333 .4084 Mdot
.59524 .22443 Mdot
.59714 .26003 Mdot
.59905 .37611 Mdot
.60095 .41542 Mdot
.60286 .26394 Mdot
.60476 .28827 Mdot
.60667 .37628 Mdot
.60857 .4416 Mdot
.61048 .32712 Mdot
.61238 .32986 Mdot
.61429 .43543 Mdot
.61619 .25698 Mdot
.6181 .28583 Mdot
.62 .40308 Mdot
.6219 .37641 Mdot
.62381 .39254 Mdot
.62571 .23792 Mdot
.62762 .32871 Mdot
.62952 .30008 Mdot
.63143 .37424 Mdot
.63333 .41607 Mdot
.63524 .32458 Mdot
.63714 .36253 Mdot
.63905 .2389 Mdot
.64095 .31238 Mdot
.64286 .26145 Mdot
.64476 .24136 Mdot
.64667 .36884 Mdot
.64857 .31484 Mdot
.65048 .35774 Mdot
.65238 .29919 Mdot
.65429 .29317 Mdot
.65619 .37994 Mdot
.6581 .40747 Mdot
.66 .36662 Mdot
.6619 .33778 Mdot
.66381 .40627 Mdot
.66571 .30763 Mdot
.66762 .30209 Mdot
.66952 .39755 Mdot
.67143 .24781 Mdot
.67333 .29486 Mdot
.67524 .24671 Mdot
.67714 .36087 Mdot
.67905 .47965 Mdot
.68095 .25558 Mdot
.68286 .39629 Mdot
.68476 .33036 Mdot
.68667 .4314 Mdot
.68857 .27723 Mdot
.69048 .23824 Mdot
.69238 .40356 Mdot
.69429 .32928 Mdot
.69619 .3367 Mdot
.6981 .28757 Mdot
.7 .39555 Mdot
.7019 .40663 Mdot
.70381 .23317 Mdot
.70571 .25423 Mdot
.70762 .38217 Mdot
.70952 .23695 Mdot
.71143 .32532 Mdot
.71333 .39541 Mdot
.71524 .31687 Mdot
.71714 .28083 Mdot
.71905 .37306 Mdot
.72095 .35793 Mdot
.72286 .32278 Mdot
.72476 .28442 Mdot
.72667 .3005 Mdot
.72857 .36579 Mdot
.73048 .41764 Mdot
.73238 .27946 Mdot
.73429 .32947 Mdot
.73619 .25386 Mdot
.7381 .24008 Mdot
.74 .35192 Mdot
.7419 .43621 Mdot
.74381 .37251 Mdot
.74571 .39863 Mdot
.74762 .34649 Mdot
.74952 .40138 Mdot
.75143 .39816 Mdot
.75333 .40335 Mdot
.75524 .33379 Mdot
.75714 .45437 Mdot
.75905 .3956 Mdot
.76095 .25424 Mdot
.76286 .31819 Mdot
.76476 .26299 Mdot
.76667 .35989 Mdot
.76857 .28904 Mdot
.77048 .36504 Mdot
.77238 .36276 Mdot
.77429 .29535 Mdot
.77619 .34693 Mdot
.7781 .29025 Mdot
.78 .26661 Mdot
.7819 .4376 Mdot
.78381 .32324 Mdot
.78571 .2267 Mdot
.78762 .36422 Mdot
.78952 .38045 Mdot
.79143 .47559 Mdot
.79333 .38137 Mdot
.79524 .33391 Mdot
.79714 .344 Mdot
.79905 .29749 Mdot
.80095 .40945 Mdot
.80286 .39284 Mdot
.80476 .27317 Mdot
.80667 .32867 Mdot
.80857 .27782 Mdot
.81048 .31423 Mdot
.81238 .25634 Mdot
.81429 .35922 Mdot
.81619 .25093 Mdot
.8181 .30276 Mdot
.82 .25358 Mdot
.8219 .32108 Mdot
.82381 .36237 Mdot
.82571 .37863 Mdot
.82762 .26459 Mdot
.82952 .27859 Mdot
.83143 .22555 Mdot
.83333 .41775 Mdot
.83524 .30495 Mdot
.83714 .35217 Mdot
.83905 .38172 Mdot
.84095 .27024 Mdot
.84286 .24921 Mdot
.84476 .25321 Mdot
.84667 .2619 Mdot
.84857 .4217 Mdot
.85048 .38004 Mdot
.85238 .47586 Mdot
.85429 .35898 Mdot
.85619 .28939 Mdot
.8581 .43679 Mdot
.86 .36 Mdot
.8619 .30043 Mdot
.86381 .40306 Mdot
.86571 .48062 Mdot
.86762 .32471 Mdot
.86952 .28103 Mdot
.87143 .34458 Mdot
.87333 .2692 Mdot
.87524 .25331 Mdot
.87714 .43762 Mdot
.87905 .26571 Mdot
.88095 .34334 Mdot
.88286 .37397 Mdot
.88476 .33594 Mdot
.88667 .32815 Mdot
.88857 .34187 Mdot
.89048 .42023 Mdot
.89238 .32864 Mdot
.89429 .29033 Mdot
.89619 .39444 Mdot
.8981 .30812 Mdot
.9 .23235 Mdot
.9019 .3243 Mdot
.90381 .37943 Mdot
.90571 .38096 Mdot
.90762 .3477 Mdot
.90952 .40571 Mdot
.91143 .29733 Mdot
.91333 .3257 Mdot
.91524 .40795 Mdot
.91714 .24877 Mdot
.91905 .36818 Mdot
.92095 .23681 Mdot
.92286 .35706 Mdot
.92476 .30259 Mdot
.92667 .33608 Mdot
.92857 .37844 Mdot
.93048 .22888 Mdot
.93238 .2744 Mdot
.93429 .3042 Mdot
.93619 .30701 Mdot
.9381 .26613 Mdot
.94 .28906 Mdot
.9419 .26713 Mdot
.94381 .33232 Mdot
.94571 .28276 Mdot
.94762 .32131 Mdot
.94952 .27251 Mdot
.95143 .44041 Mdot
.95333 .36337 Mdot
.95524 .31416 Mdot
.95714 .26045 Mdot
.95905 .28958 Mdot
.96095 .26809 Mdot
.96286 .46839 Mdot
.96476 .2668 Mdot
.96667 .39918 Mdot
.96857 .42329 Mdot
.97048 .24573 Mdot
.97238 .26348 Mdot
.97429 .24899 Mdot
.97619 .37665 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo04Oooooo0_l00011ooooo`;o0000:?ooool2o`0008Kooooo0006ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0Aoooool2o`0002_ooooo0_l0000Dooooo`;o00000_oo
ool2o`0002Cooooo0_l0000kooooo`;o00003Oooool2o`0003[ooooo0004o`0000;ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1booooo`Co00006?ooool2o`00067ooooo0_l0000=ooooo`;o00007_oo
ool2o`0001[ooooo0006ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^
kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Rooooo`;o00007_ooool2o`0000Kooooo0_l0
000:ooooo`;o000000?oooooo`000?l000005oooool2o`0001gooooo0_l0000?ooooo`?o0000<_oo
ool2o`0003gooooo0_l00008ooooo`;o00006_ooool000Kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo00Wooooo0_l00007ooooo`;o00003_ooool2o`0001kooooo0_l00006ooooo`;o0000
2_ooool2o`000003ooooool0003o000001Oooooo0_l0000Mooooo`;o00003oooool3o`0003;ooooo
1?l0000kooooo`;o00001Oooool2o`0001gooooo0006ooooo`05oa0@4?ooooooooooooooool@4100
3oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2Oooool2o`0000Oooooo0_l0001Xooooo`;o0000@?ooool2o`0000;ooooo0_l0000?ooooo`;o0000
1?ooool2o`0000Oooooo0_l0000iooooo`;o00007Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo04kooooo0_l000000ooooooo0000o`00000Cooooo`;o00005?ooool2o`00033o
oooo0_l0000>ooooo`;o00000_ooool4o`0000gooooo0_l0000=ooooo`;o0000F?ooool000Kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`00
00Kooooo00?o0000ooooooooool00_l0001<ooooo`;o000000?oooooo`000?l000004oooool2o`00
047ooooo0_l00003ooooo`;o00005?ooool2o`0006Oooooo0_l0000=ooooo`00:Oooool2o`000003
ooooool0003o000005gooooo1?l00007ooooo`;o0000=oooool2o`0000Cooooo0_l0000Rooooo`?o
0000=?ooool2o`0001Kooooo0_l0000?ooooo`?o00003?ooool002Wooooo00?o0000ooooooooool0
3_ooool2o`0004cooooo0_l000000ooooooo0000o`000002o`0000Oooooo0_l0000fooooo`?o0000
:?ooool3o`0002_ooooo0_l00007ooooo`;o00005_ooool2o`00013ooooo0_l0000<ooooo`00:Ooo
ool00ol0003oooooooooo`0>ooooo`;o00002oooool2o`0002_ooooo0_l0000@ooooo`Co00001_oo
ool2o`000003ooooool0003o000002Kooooo0_l00009ooooo`;o00001_ooool2o`0002cooooo0_l0
0006ooooo`;o00001oooool2o`0000Kooooo0_l0000@ooooo`?o00001_ooool2o`0000Sooooo0_l0
000/ooooo`00:Oooool00ol0003oooooooooo`0Kooooo`;o00002_ooool2o`0001oooooo0_l0000@
ooooo`;o00002?ooool2o`000003ooooool0003o000002Kooooo0_l00009ooooo`;o00007oooool2
o`0001?ooooo0_l00006ooooo`;o00001oooool2o`0000Kooooo0_l0000?ooooo`Co00001_ooool2
o`0000Sooooo0_l0000/ooooo`00:Oooool00ol0003oooooooooo`0Dooooo`;o00004Oooool2o`00
023ooooo0_l00017ooooo`;o00008Oooool2o`0000Cooooo0_l00006ooooo`;o0000=Oooool2o`00
00Wooooo0_l0000Qooooo`;o00004_ooool002Wooooo0_l0000Eooooo`;o00005oooool2o`0001[o
oooo0_l0000Pooooo`;o00004?ooool2o`0001?ooooo0_l00006ooooo`;o00000oooool2o`0001Co
oooo0ol0000;ooooo`;o00009_ooool2o`0001;ooooo0_l00004ooooo`;o00008Oooool2o`0000?o
oooo0_l0000=ooooo`00:Oooool01?l0003oooooo`000?l0000/ooooo`;o0000??ooool2o`00013o
oooo0_l0000Kooooo`;o00000oooool2o`0001Gooooo0_l0000cooooo`;o00000_ooool2o`0000ko
oooo0_l0000>ooooo`;o00004Oooool3o`0000Gooooo1Ol0000=ooooo`00:Oooool01?l0003ooooo
o`000?l0000;ooooo`?o00008Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04?ooool2o`0001Oooooo1Ol00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Wooooo0_l0000Moooo
o`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0Zooooo`;o000000Co410@oooooooooooooooo0ol000000olb<S;o
k^k^ooooo`02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01oooool2o`0000Sooooo1?l0000Aoooo
o`?o000000GoA4A4o`000?l0003o<S8bomgMg@03o`000004oc8b<_l0003o<S8bonk^kP?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool00ol0003oooooooooo`0<ooooo`?o00002ooo
ool2o`0001Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00GoMgMgoiRHV?l0003o0000ogMgM`0@ooooo`;o00005oooool01OnHV9So0000o`000?ooooooA4A4
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`;o000000GoV9RHoooooonHV9SoMgMgoooo
o`02o`0000Kooooo0ol0000Looooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`;o000000?ooooooiRHV?mgMgL01oooool2
o`0000Sooooo0_l0000Aooooo`;o00001?ooool2o`000009ogMgMolb<S;ooooooooooomgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool3o`0001[o
oooo0_l0000Fooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003oooo
o`05oa0@4?oooooo0000o`000?l@41002oooool2o`0001gooooo0_l000000oo^k^koooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41000_ooool2o`0000?ooooo00Co410@ooooool0003o0000
0_ooool2o`0000?ooooo0ol0000?ooooo`;o00001Oooool2o`0000?ooooo0_l00002ooooo`05o`00
0?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooo
ooooool04Oooool2o`0001?ooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41000oooool2
o`0000;ooooo00?o410@ooooooooool08_ooool2o`0000Cooooo0_l000001Ooooooo0000oooooooo
oooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo007ooooo
000Yooooo`?o0000;oooool2o`000003ooooool0003ooooo00?ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000002oooool2o`0001kooooo00?oV9RHob4Q8Oo^
k^h00oooool01Ol0003ooooooooooooooooo000000?ooooo0_l00002ooooo`03o`000?oooooooooo
00?ooooo0_l00004ooooo`;o00003oooool2o`0000Gooooo0_l00003ooooo`;o000000?oooooojVY
ZOl@41000oooool3o`000003ooooool0003ooooo00;ooooo00Go0000ooooooooooooooooo`00000C
ooooo`;o00001oooool2o`0000?ooooo0_l00005ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000;o00000oooool2o`0002Oooooo
00GoMgMgoc8b<_ooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`01ooooo`00:Oooool00ol0003oooooooooo`0Vooooo`;o00001oooool2o`000003
ooooool0003ooooo00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000003?ooool2o`0001kooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooo
oooo000000?ooooo0_l00002ooooo`03o`000?oooooooooo02Sooooo00?o410@o`000?nj^[X00ooo
ool3o`000003ooooool0003ooooo00;ooooo00Go0000ooooooooooooooooo`00000Looooo`;o0000
0oooool2o`0000Gooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooool000000_l00003ooooo`;o00002oooool2o`0001Oooooo0ol000001Olb
<S;oc<c<oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo007ooooo000Yooooo`03o`000?oooooooooo00gooooo0_l00005ooooo`;o00004?ooool2
o`0000[ooooo0ol00002ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooo
oooooooo410@00cooooo0_l0000Oooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@00?ooooo00?o410@ooooooooool00_l0000<ooooo`;o00006Oooool00onj
^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413o0000o`000?oo
oooo410@01oooooo0_l00008ooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooo
oa0@4003ooooo`05oa0@4?ooooooooooooooool@41004?ooool2o`0001Oooooo0_l00005ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo000Yoooo
o`03o`000?oooooooooo00gooooo0_l00005ooooo`;o00007?ooool3o`0000;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:Oooool01?l0003o^[Zjoooo
oonHV9P2o`0000;ooooo0_l000000oooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00_ooool2o`0000cooooo0_l0000Fooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00;o000000KoooooogMgMol0003o0000oiRHV?mgMgLFooooo`;o0000
1oooool2o`0000Sooooo00Cok^k^odA4A?l0003ooooo0_l000001_ooooooMgMgoiRHV?ooooooV9RH
ogMgM`?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`;o00006Oooool3o`0000?ooooo0_l0
00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`00:Oooool00ol0003oooooooooo`06ooooo`Co00009_ooool00omEEEGoIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00oooooo0_l0000H
ooooo`04oiRHV?l@413o0000ob4Q8@;o00000_ooool3o`000003oc8b<_o^k^kooooo00;ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0Xooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00;o000000Koooooonk^k_lb<S;o0000oc8b<_o^k^h8ooooo`;o00003?oo
ool2o`0001;ooooo00?oMgMgo`000?ooool00_l000001_oooooo0000o`000?l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`;o00002_ooool2o`0000gooooo2?l000001_oo
ooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Ooo
ool2o`0000Oooooo1?l0000Gooooo`Co00001Oooool2o`0000;ooooo0_l0000Sooooo`;o00003Ooo
ool2o`0003?ooooo0_l00004ooooo`;o0000:?ooool2o`0000Cooooo0_l0000Oooooo`?o00008ooo
ool2o`0002Kooooo000Yooooo`03o`000?oooooooooo01Oooooo0_l00008ooooo`Co00001Oooool2
o`0000;ooooo0_l000000ooooooo0000o`00000_ooooo`;o0000<oooool2o`0000Cooooo0_l0000W
ooooo`;o00001Oooool2o`0001oooooo0_l00006ooooo`;o00008_ooool2o`00023ooooo000Yoooo
o`03o`000?oooooooooo01Oooooo0_l0000Cooooo`;o00000oooool2o`0002gooooo0_l0001Moooo
o`;o00001Oooool2o`0000?ooooo0_l0000Aooooo`;o00005_ooool2o`0001;ooooo0_l0000>oooo
o`;o00000_ooool2o`0001cooooo000Yooooo`03o`000?oooooooooo02cooooo0ol0000^ooooo`;o
000000?oooooo`000?l000005oooool2o`0000?ooooo0_l0000oooooo`;o00002_ooool2o`00017o
oooo0_l0000Looooo`;o00000oooool2o`0000Oooooo0_l0000Booooo`;o000000?oooooo`000?l0
00006Oooool002Wooooo00Co0000oooooooooooooooo1?l0000Vooooo`Co00001Oooool2o`0002Oo
oooo0_l0000Jooooo`;o00000oooool3o`0004[ooooo0_l0000_ooooo`;o00000oooool2o`0001;o
oooo0_l0000:ooooo`?o00006?ooool0027oooooool00014o`0000Cooooo000Yooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02_ooool01?l0003oooooo`000?l00008ooooo`03o`00
0?oooooooooo00?ooooo0_l00004ooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo
oooo0_l00007ooooo`03o`000?oooooooooo00;ooooo0_l00005ooooo`?o00002Oooool00ol0003o
ooooooooo`02ooooo`;o00001Oooool00ol0003oooooooooo`05ooooo`;o00000oooool3o`0000Go
oooo0_l00002ooooo`03o`000?oooooooooo00;o00001?ooool2o`000003ooooool0003ooooo00Ko
oooo0_l00002ooooo`;o00002_ooool4o`0000Cooooo0_l00003ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooool000000ol00006ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo0_l00003ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00;ooooo0_l00005ooooo`03o`000?oooooooooo00[ooooo000Yooooo`03o`00
0?oooooooooo00cooooo0_l0000/ooooo`04o`000?ooooooooooooooo`;o00005?ooool2o`0000Go
oooo0_l00007ooooo`;o00002?ooool2o`0000?ooooo0_l00003ooooo`?o00001Oooool2o`0000_o
oooo0_l00009ooooo`;o000000Coooooo`000?l0003o00002_ooool2o`0000?ooooo0_l00006oooo
o`03o`000?oooooooooo00_ooooo1?l0000Dooooo`;o00005Oooool00ol0003oooooooooo`04oooo
o`;o0000;Oooool2o`0000Gooooo00?o0000ooooooooool02_ooool002Wooooo00?o0000oooooooo
ool03?ooool2o`0004gooooo0_l0000Aooooo`;o00004_ooool2o`0001Oooooo0_l00007ooooo`;o
00001oooool2o`0002cooooo0_l0000=ooooo`;o00004Oooool2o`0003gooooo000Yooooo`03o`00
0?oooooooooo01Gooooo0_l00005ooooo`;o00009_ooool2o`0003_ooooo0ol0000Pooooo`;o0000
1oooool2o`0002kooooo0_l0000;ooooo`;o00001Oooool2o`0000[ooooo0_l0000Hooooo`;o0000
3?ooool2o`0001Gooooo000Yooooo`;o00005_ooool2o`0000Gooooo1?l0000Tooooo`;o00009Ooo
ool2o`0001Cooooo0_l00002ooooo`?o00004?ooool2o`0000Gooooo1?l0000:ooooo`;o00002_oo
ool2o`0000Kooooo0_l0000Fooooo`;o00000_ooool2o`0001;ooooo0_l0000Iooooo`;o00002Ooo
ool2o`000003ooooool0003o000000Wooooo0_l0000Eooooo`00:Oooool00ol0003oooooooooo`0M
ooooo`?o00000oooool2o`0001Sooooo0_l00004ooooo`;o00004oooool2o`0000cooooo0_l00003
ooooo`;o00006?ooool3o`00013ooooo0_l00005ooooo`Co00005_ooool3o`0000;ooooo0_l00000
0ooooooo0000o`00000>ooooo`;o000000?oooooo`000?l000000oooool2o`0000Kooooo0_l0000E
ooooo`;o00004_ooool2o`0000Cooooo1?l00004ooooo`;o00008?ooool002Wooooo00?o0000oooo
ooooool07Oooool2o`0000Cooooo0_l0000Hooooo`;o00001?ooool2o`0001?ooooo0_l0000<oooo
o`;o00001Oooool2o`0001[ooooo0_l0000_ooooo`;o00000_ooool2o`00017ooooo0_l000000ooo
oooo0000o`00000;ooooo`;o00005Oooool2o`0001Sooooo1?l0000>ooooo`;o00005_ooool002Wo
oooo00?o0000ooooooooool01Oooool2o`0001;ooooo0_l00007ooooo`;o0000BOooool2o`0001[o
oooo0_l00009ooooo`;o00002_ooool2o`0000Gooooo0_l0000[ooooo`;o00004Oooool2o`0000_o
oooo0_l0000Kooooo`;o00003?ooool2o`0000?ooooo0_l0000Fooooo`00:Oooool00ol0003ooooo
ooooo`05ooooo`;o00004_ooool2o`0000Oooooo0_l0000Aooooo`Go00001Oooool2o`0001Sooooo
0_l0000=ooooo`;o00000_ooool2o`0001Cooooo0_l0000@ooooo`;o00002_ooool2o`0000Gooooo
0_l00002ooooo`;o00007?ooool2o`0000Wooooo0_l0000Aooooo`;o00002oooool2o`0001_ooooo
0_l0000<ooooo`;o00006oooool002Wooooo0_l0000fooooo`Go00001Oooool2o`0001Sooooo0_l0
0006ooooo`;o00001Oooool2o`0000;ooooo0_l0000Dooooo`;o00009oooool2o`0001cooooo0_l0
0017ooooo`;o0000:?ooool002Wooooo0_l0000Zooooo`?o00005?ooool2o`0000oooooo0_l0000>
ooooo`;o0000A?ooool2o`0004cooooo0_l0000Fooooo`;o000000?oooooo`000?l000000_l0000X
ooooo`00:Oooool00ol0003oooooooooo`02ooooo`;o00005?ooool2o`0000_ooooo0_l00002oooo
o`?o00003oooool2o`0000?ooooo0_l0000?ooooo`;o00007_ooool2o`0003;ooooo1?l0000loooo
o`;o00001oooool2o`0000Gooooo0_l0000Fooooo`;o000000?oooooo`000?l000001_ooool2o`00
02;ooooo000Yooooo`03o`000?oooooooooo00;ooooo0_l0000Cooooo`?o00002oooool2o`0001Co
oooo0_l0000dooooo`;o0000<_ooool2o`0000Sooooo0_l0000booooo`Co00001oooool2o`0001;o
oooo0_l0000Dooooo`;o00008_ooool002Wooooo00?o0000ooooooooool05oooool2o`0003oooooo
0_l00009ooooo`;o0000<?ooool2o`0001Oooooo0ol0000booooo`;o00007Oooool2o`0003Sooooo
000Yooooo`;o00004?ooool2o`000003ooooool0003o000001kooooo0_l00002ooooo`;o00000_oo
ool2o`0001cooooo0_l00009ooooo`Co00003oooool2o`0000Wooooo0_l00005ooooo`;o00002ooo
ool2o`0000oooooo0_l00006ooooo`;o00005_ooool2o`0001Cooooo0_l0000oooooo`;o00007Ooo
ool002Wooooo00?o0000ooooooooool03oooool2o`000003ooooool0003o000001kooooo0_l00002
ooooo`;o00000_ooool2o`0000Cooooo0_l0000Jooooo`;o00001oooool2o`0000oooooo0_l00009
ooooo`;o00001Oooool2o`0000_ooooo0_l0000?ooooo`;o00007_ooool2o`0000Kooooo0_l0000<
ooooo`;o00003Oooool2o`0000gooooo0_l0000;ooooo`Co00004_ooool2o`0001gooooo000Yoooo
o`04o`000?oooooo0000o`00037ooooo0ol0000;ooooo`;o00001oooool2o`00017ooooo0_l00000
0ooooooo0000o`000006ooooo`;o00004Oooool2o`0004Gooooo0_l0000;ooooo`;o00006oooool4
o`0000?ooooo0_l00006ooooo`;o00000_ooool2o`0000Oooooo1?l0000Looooo`;o00004oooool0
02Wooooo00Co0000ooooool0003o00009_ooool2o`0000Wooooo0ol00005ooooo`Co00002oooool2
o`0001Cooooo0_l00006ooooo`;o00000oooool2o`0000cooooo0ol00014ooooo`;o00001_ooool2
o`0001Cooooo0_l0000;ooooo`?o00000oooool2o`0000[ooooo0_l0000Wooooo`;o00004oooool0
02Wooooo00?o0000ooooooooool01Oooool2o`0000oooooo0_l0000?ooooo`;o00001oooool2o`00
00Sooooo1?l0000Eooooo`;o00005oooool2o`0000gooooo0_l0000=ooooo`;o00001?ooool2o`00
00Oooooo0_l0000Zooooo`;o00000_ooool2o`0001Cooooo0_l0000;ooooo`;o0000;_ooool2o`00
01kooooo000Yooooo`;o00001_ooool4o`0000gooooo0_l00008ooooo`;o00003_ooool2o`0001_o
oooo1Ol000000ooooooo0000o`000002o`0003?ooooo0_l00003ooooo`?o00001oooool2o`0002[o
oooo0_l0000Eooooo`;o00001_ooool2o`0002[ooooo0_l0000:ooooo`;o00007_ooool002Wooooo
00?o0000ooooooooool01oooool2o`0001Oooooo0_l0000Kooooo`;o00003_ooool5o`0000?ooooo
0_l0000hooooo`;o00009?ooool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000
o`00000Jooooo`;o00001_ooool2o`0002[ooooo0_l0000Mooooo`;o00002oooool000Kooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo00Wooooo1?l00004ooooo`;o00005Oooool2o`0001?o
oooo0_l0000Looooo`;o0000=_ooool2o`000003ooooool0003o000001gooooo0_l000000ooooooo
0000o`000003ooooo`;o000000?oooooo`000?l000001_ooool2o`0003Cooooo0_l00006ooooo`;o
00003oooool2o`0000Kooooo0_l0000>ooooo`;o00002oooool000Kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`09ooooo`Co00001?ooool2o`0001Gooooo0_l0000Doooo
o`;o00006oooool2o`0001;ooooo0_l00005ooooo`?o00006_ooool2o`000003ooooool0003o0000
033ooooo0_l0000>ooooo`;o00006?ooool4o`0000Sooooo0_l00002ooooo`;o00000_ooool2o`00
00oooooo0ol00005ooooo`;o00006oooool000Kooooo00Go410@oooooooooooooooooa0@400<oooo
o`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Eoooo
o`;o00009oooool2o`0000Kooooo1?l000000ooooooo0000o`00000Rooooo`;o00001Oooool3o`00
03Oooooo1?l0000Tooooo`;o00006?ooool4o`0000cooooo0_l0000Dooooo`;o00008_ooool000Ko
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b
<_ooool01?ooool3o`0000Oooooo0_l0000:ooooo`Co00009?ooool2o`0000Wooooo1?l000000ooo
oooo0000o`00000Aooooo`;o0000Boooool2o`0000?ooooo1?l00028ooooo`001_ooool01Ol0003o
oooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool01?ooool2o`000003ooooool0003o000000[ooooo0_l0000V
ooooo`;o00002Oooool2o`0001Kooooo0_l0000`ooooo`;o00006Oooool2o`00013ooooo0_l0001m
ooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo0_l00010ooooo`;o0000B?ooool2
o`0002_ooooo0_l0000Gooooo`;o00000_ooool2o`0000gooooo0_l0000<ooooo`;o00007?ooool2
o`0002Gooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonH
V9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`24ooooo`;o00000ooo
ool2o`00027ooooo0_l0000Nooooo`;o00000_ooool2o`0000Cooooo0_l00002ooooo`;o00002?oo
ool4o`000003ooooool0003o000000cooooo0_l0000Looooo`;o00009Oooool000Kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo
0_l0000;ooooo`;o00000oooool2o`0001gooooo0_l0000iooooo`;o00006Oooool2o`0000?ooooo
0_l0000Qooooo`;o00007_ooool2o`0000;ooooo0_l0000Booooo`Co0000@oooool2o`0000oooooo
000Yooooo`;o00002oooool2o`0000?ooooo0_l0000Mooooo`;o00007Oooool2o`0001[ooooo0_l0
000Dooooo`;o0000>oooool2o`0001Gooooo0_l0000Aooooo`?o00008Oooool2o`0001oooooo0_l0
000?ooooo`00:Oooool00ol0003oooooooooo`0:ooooo`;o0000@Oooool2o`00033ooooo0_l0000k
ooooo`;o00002_ooool4o`0000Oooooo0_l000000ooooooo0000o`00000?ooooo`;o00008Oooool2
o`0000gooooo1?l0000Oooooo`00:Oooool00ol0003oooooooooo`0:ooooo`;o0000:oooool2o`00
07[ooooo0_l0000Cooooo`Co00002_ooool2o`0001kooooo0_l0000Qooooo`Co00007oooool002Wo
oooo00?o0000ooooooooool0=oooool2o`0007[ooooo0_l00011ooooo`;o0000A?ooool002Wooooo
00?o0000ooooooooool07oooool2o`00037ooooo0_l00018ooooo`;o00004oooool3o`0000;ooooo
0_l00008ooooo`;o00007Oooool2o`0005_ooooo000Yooooo`;o00008?ooool3o`00033ooooo0_l0
0018ooooo`;o00004oooool3o`0000;ooooo0_l00008ooooo`;o00007Oooool2o`00023ooooo0_l0
000@ooooo`;o00009oooool002Wooooo00Co0000oooooooooooooooo0_l0000Mooooo`;o00000_oo
ool2o`0004?ooooo0_l0000Jooooo`;o0000N_ooool2o`0000;ooooo0_l0000<ooooo`;o00005ooo
ool2o`0000kooooo000Yooooo`04o`000?ooooooooooooooo`;o00008Oooool2o`0000oooooo0_l0
000booooo`;o00006_ooool2o`0007kooooo0_l0000Uooooo`;o00003_ooool002Wooooo00?o0000
ooooooooool04?ooool2o`0002?ooooo0_l0000mooooo`;o00009oooool2o`0009gooooo000Yoooo
o`03o`000?oooooooooo013ooooo0_l0000Nooooo`;o0000@_ooool2o`0002Oooooo0_l0000boooo
o`;o0000JOooool002Wooooo0_l0000Kooooo`Co00004_ooool2o`0000Kooooo0_l0000Mooooo`;o
0000HOooool2o`0001Gooooo0_l0000@ooooo`;o0000Eoooool002Wooooo00?o0000ooooooooool0
0_ooool2o`0001Kooooo1?l000000ooooooo0000o`00000Gooooo`;o00007?ooool3o`0000[ooooo
0_l0000:ooooo`;o0000=oooool2o`00013ooooo0_l0000Wooooo`;o00002oooool2o`0001Oooooo
0_l00004ooooo`;o0000:oooool002Wooooo00?o0000ooooooooool00_ooool2o`0000cooooo0_l0
000=ooooo`;o00001?ooool2o`0001[ooooo0_l00002ooooo`;o00003oooool2o`0000Kooooo0_l0
0003ooooo`;o00002_ooool3o`0002;ooooo0_l0000Booooo`;o00003_ooool2o`0003Kooooo0_l0
000Gooooo`;o00001?ooool2o`0001Kooooo0_l0000Cooooo`00:Oooool00ol0003oooooooooo`0@
ooooo`;o00004oooool2o`0001[ooooo0_l00002ooooo`;o00005oooool2o`00013ooooo0_l0000R
ooooo`;o00008_ooool2o`0006gooooo0_l0000Cooooo`00:Oooool00ol0003oooooooooo`15oooo
o`;o0000<?ooool2o`000<?ooooo000Yooooo`;o0000N?ooool2o`000<?ooooo000Yooooo`03o`00
0?oooooooooo0>Sooooo0_l0001Booooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`1jooooo`;o
00004?ooool2o`0005[ooooo0_l0001Booooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0N_ooool2o`00013o
oooo0_l0002^ooooo`003_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooooooo
ool00oooool3o`0004?ooooo0_l0003gooooo`003_ooool01Ol0003ooooooooooooooooo000000oo
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`13ooooo`;o0000moooool000kooooo
00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0
003oooooooooo`3oooooob_ooooo0_l0000@ooooo`003_ooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooob_ooooo0_l0000@oooo
o`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`3cooooo`;o00004_ooool2o`0003?ooooo000>ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0000Kooooo0_l0003@ooooo`;o00008_ooool2o`0001;ooooo0_l0000coooo
o`00:Oooool00ol0003oooooooooo`0Mooooo`;o00003?ooool2o`000:;ooooo0_l0000jooooo`;o
0000;oooool002Wooooo00?o0000ooooooooool07Oooool2o`0000cooooo0_l0000<ooooo`;o0000
d?ooool2o`0002oooooo000Yooooo`03o`000?oooooooooo03Wooooo0_l0003oooooo`;ooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`001_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooo
oooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o
0000oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qoooooooo
ool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo
00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooo
oooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@
413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3o
ooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006
ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool001oooooo
1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooo
oooo00Gooooo0ol0003oooooocgooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool001oooooo00?oEEEEofIVI_l00000oooooom7
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .25221 Mdot
.02762 .35352 Mdot
.02952 .30172 Mdot
.03143 .32176 Mdot
.03333 .33742 Mdot
.03524 .32223 Mdot
.03714 .27137 Mdot
.03905 .45088 Mdot
.04095 .42012 Mdot
.04286 .33416 Mdot
.04476 .34908 Mdot
.04667 .44339 Mdot
.04857 .41381 Mdot
.05048 .35102 Mdot
.05238 .43316 Mdot
.05429 .25809 Mdot
.05619 .32627 Mdot
.0581 .41432 Mdot
.06 .25287 Mdot
.0619 .28238 Mdot
.06381 .4115 Mdot
.06571 .3898 Mdot
.06762 .39949 Mdot
.06952 .41348 Mdot
.07143 .40699 Mdot
.07333 .34321 Mdot
.07524 .33238 Mdot
.07714 .25528 Mdot
.07905 .25682 Mdot
.08095 .36113 Mdot
.08286 .40521 Mdot
.08476 .41933 Mdot
.08667 .44643 Mdot
.08857 .37027 Mdot
.09048 .38562 Mdot
.09238 .31934 Mdot
.09429 .29642 Mdot
.09619 .27988 Mdot
.0981 .23533 Mdot
.1 .44284 Mdot
.1019 .41303 Mdot
.10381 .38156 Mdot
.10571 .3684 Mdot
.10762 .26209 Mdot
.10952 .23865 Mdot
.11143 .36675 Mdot
.11333 .34831 Mdot
.11524 .39047 Mdot
.11714 .25567 Mdot
.11905 .25643 Mdot
.12095 .38849 Mdot
.12286 .23249 Mdot
.12476 .45007 Mdot
.12667 .37913 Mdot
.12857 .38023 Mdot
.13048 .43654 Mdot
.13238 .44985 Mdot
.13429 .322 Mdot
.13619 .3525 Mdot
.1381 .23972 Mdot
.14 .3667 Mdot
.1419 .27157 Mdot
.14381 .23307 Mdot
.14571 .28161 Mdot
.14762 .44301 Mdot
.14952 .42931 Mdot
.15143 .32989 Mdot
.15333 .26291 Mdot
.15524 .27985 Mdot
.15714 .41029 Mdot
.15905 .33718 Mdot
.16095 .32084 Mdot
.16286 .3378 Mdot
.16476 .30422 Mdot
.16667 .23311 Mdot
.16857 .27671 Mdot
.17048 .45027 Mdot
.17238 .35707 Mdot
.17429 .23101 Mdot
.17619 .26484 Mdot
.1781 .37976 Mdot
.18 .35773 Mdot
.1819 .33065 Mdot
.18381 .38324 Mdot
.18571 .44728 Mdot
.18762 .25666 Mdot
.18952 .34227 Mdot
.19143 .35688 Mdot
.19333 .2998 Mdot
.19524 .26072 Mdot
.19714 .4028 Mdot
.19905 .33153 Mdot
.20095 .3238 Mdot
.20286 .36221 Mdot
.20476 .31293 Mdot
.20667 .30454 Mdot
.20857 .35006 Mdot
.21048 .39346 Mdot
.21238 .45601 Mdot
.21429 .30123 Mdot
.21619 .27043 Mdot
.2181 .26957 Mdot
.22 .44137 Mdot
.2219 .28142 Mdot
.22381 .39656 Mdot
.22571 .37481 Mdot
.22762 .35061 Mdot
.22952 .25298 Mdot
.23143 .32467 Mdot
.23333 .40862 Mdot
.23524 .34476 Mdot
.23714 .32731 Mdot
.23905 .41746 Mdot
.24095 .31719 Mdot
.24286 .49216 Mdot
.24476 .29366 Mdot
.24667 .36389 Mdot
.24857 .43608 Mdot
.25048 .42913 Mdot
.25238 .29366 Mdot
.25429 .41323 Mdot
.25619 .31319 Mdot
.2581 .40823 Mdot
.26 .25371 Mdot
.2619 .40918 Mdot
.26381 .30819 Mdot
.26571 .29883 Mdot
.26762 .26896 Mdot
.26952 .32476 Mdot
.27143 .32901 Mdot
.27333 .39914 Mdot
.27524 .29666 Mdot
.27714 .43588 Mdot
.27905 .31821 Mdot
.28095 .35536 Mdot
.28286 .23611 Mdot
.28476 .27348 Mdot
.28667 .27233 Mdot
.28857 .33602 Mdot
.29048 .44644 Mdot
.29238 .43287 Mdot
.29429 .22485 Mdot
.29619 .34019 Mdot
.2981 .26562 Mdot
.3 .32642 Mdot
.3019 .30036 Mdot
.30381 .44387 Mdot
.30571 .48785 Mdot
.30762 .26238 Mdot
.30952 .36095 Mdot
.31143 .34124 Mdot
.31333 .26013 Mdot
.31524 .31413 Mdot
.31714 .41396 Mdot
.31905 .31655 Mdot
.32095 .27259 Mdot
.32286 .2575 Mdot
.32476 .23151 Mdot
.32667 .43568 Mdot
.32857 .29871 Mdot
.33048 .26095 Mdot
.33238 .30838 Mdot
.33429 .23098 Mdot
.33619 .42414 Mdot
.3381 .34386 Mdot
.34 .3658 Mdot
.3419 .26611 Mdot
.34381 .44231 Mdot
.34571 .39032 Mdot
.34762 .28631 Mdot
.34952 .25325 Mdot
.35143 .27556 Mdot
.35333 .33209 Mdot
.35524 .30273 Mdot
.35714 .3439 Mdot
.35905 .2716 Mdot
.36095 .44531 Mdot
.36286 .29357 Mdot
.36476 .2772 Mdot
.36667 .29036 Mdot
.36857 .24734 Mdot
.37048 .23802 Mdot
.37238 .43536 Mdot
.37429 .27389 Mdot
.37619 .40862 Mdot
.3781 .32026 Mdot
.38 .41682 Mdot
.3819 .26761 Mdot
.38381 .41646 Mdot
.38571 .42673 Mdot
.38762 .36295 Mdot
.38952 .33914 Mdot
.39143 .30128 Mdot
.39333 .26389 Mdot
.39524 .28421 Mdot
.39714 .44935 Mdot
.39905 .39353 Mdot
.40095 .43955 Mdot
.40286 .35864 Mdot
.40476 .366 Mdot
.40667 .36923 Mdot
.40857 .26812 Mdot
.41048 .2701 Mdot
.41238 .32289 Mdot
.41429 .33381 Mdot
.41619 .38312 Mdot
.4181 .28364 Mdot
.42 .27536 Mdot
.4219 .30474 Mdot
.42381 .33132 Mdot
.42571 .3041 Mdot
.42762 .34859 Mdot
.42952 .40725 Mdot
.43143 .3596 Mdot
.43333 .38936 Mdot
.43524 .26462 Mdot
.43714 .27195 Mdot
.43905 .36222 Mdot
.44095 .42146 Mdot
.44286 .32058 Mdot
.44476 .24314 Mdot
.44667 .44679 Mdot
.44857 .36504 Mdot
.45048 .36221 Mdot
.45238 .39576 Mdot
.45429 .36713 Mdot
.45619 .25826 Mdot
.4581 .3091 Mdot
.46 .33967 Mdot
.4619 .32964 Mdot
.46381 .43281 Mdot
.46571 .30588 Mdot
.46762 .27306 Mdot
.46952 .30632 Mdot
.47143 .38894 Mdot
.47333 .24716 Mdot
.47524 .33611 Mdot
.47714 .32444 Mdot
.47905 .29178 Mdot
.48095 .29467 Mdot
.48286 .40942 Mdot
.48476 .28774 Mdot
.48667 .26978 Mdot
.48857 .34564 Mdot
.49048 .37597 Mdot
.49238 .33655 Mdot
.49429 .42069 Mdot
.49619 .3058 Mdot
.4981 .25482 Mdot
.5 .28233 Mdot
.5019 .33373 Mdot
.50381 .2327 Mdot
.50571 .39678 Mdot
.50762 .29131 Mdot
.50952 .26479 Mdot
.51143 .27003 Mdot
.51333 .3365 Mdot
.51524 .30748 Mdot
.51714 .37761 Mdot
.51905 .2809 Mdot
.52095 .44863 Mdot
.52286 .37416 Mdot
.52476 .24676 Mdot
.52667 .33659 Mdot
.52857 .35974 Mdot
.53048 .32025 Mdot
.53238 .25787 Mdot
.53429 .24335 Mdot
.53619 .34934 Mdot
.5381 .33468 Mdot
.54 .29924 Mdot
.5419 .31329 Mdot
.54381 .31264 Mdot
.54571 .37794 Mdot
.54762 .33264 Mdot
.54952 .25423 Mdot
.55143 .25338 Mdot
.55333 .27918 Mdot
.55524 .27915 Mdot
.55714 .39594 Mdot
.55905 .35079 Mdot
.56095 .28388 Mdot
.56286 .23916 Mdot
.56476 .331 Mdot
.56667 .28791 Mdot
.56857 .29949 Mdot
.57048 .44429 Mdot
.57238 .25411 Mdot
.57429 .29896 Mdot
.57619 .30985 Mdot
.5781 .34022 Mdot
.58 .36384 Mdot
.5819 .38658 Mdot
.58381 .2683 Mdot
.58571 .34679 Mdot
.58762 .43923 Mdot
.58952 .35131 Mdot
.59143 .27749 Mdot
.59333 .33145 Mdot
.59524 .29882 Mdot
.59714 .35827 Mdot
.59905 .43539 Mdot
.60095 .48129 Mdot
.60286 .26416 Mdot
.60476 .36457 Mdot
.60667 .30187 Mdot
.60857 .42048 Mdot
.61048 .41403 Mdot
.61238 .35007 Mdot
.61429 .39463 Mdot
.61619 .33034 Mdot
.6181 .2697 Mdot
.62 .40597 Mdot
.6219 .33479 Mdot
.62381 .41187 Mdot
.62571 .35115 Mdot
.62762 .30369 Mdot
.62952 .2396 Mdot
.63143 .37705 Mdot
.63333 .44375 Mdot
.63524 .32225 Mdot
.63714 .43279 Mdot
.63905 .34988 Mdot
.64095 .22192 Mdot
.64286 .28549 Mdot
.64476 .31746 Mdot
.64667 .3842 Mdot
.64857 .23213 Mdot
.65048 .31111 Mdot
.65238 .26552 Mdot
.65429 .27041 Mdot
.65619 .34323 Mdot
.6581 .44934 Mdot
.66 .26731 Mdot
.6619 .3103 Mdot
.66381 .40025 Mdot
.66571 .32999 Mdot
.66762 .32303 Mdot
.66952 .3436 Mdot
.67143 .33054 Mdot
.67333 .36544 Mdot
.67524 .30777 Mdot
.67714 .32814 Mdot
.67905 .43698 Mdot
.68095 .32791 Mdot
.68286 .34749 Mdot
.68476 .28417 Mdot
.68667 .44263 Mdot
.68857 .33663 Mdot
.69048 .27892 Mdot
.69238 .37399 Mdot
.69429 .33679 Mdot
.69619 .36414 Mdot
.6981 .22578 Mdot
.7 .44517 Mdot
.7019 .32729 Mdot
.70381 .31208 Mdot
.70571 .27661 Mdot
.70762 .36653 Mdot
.70952 .28351 Mdot
.71143 .25104 Mdot
.71333 .44495 Mdot
.71524 .22184 Mdot
.71714 .37261 Mdot
.71905 .43617 Mdot
.72095 .43063 Mdot
.72286 .41324 Mdot
.72476 .32124 Mdot
.72667 .24609 Mdot
.72857 .43157 Mdot
.73048 .44937 Mdot
.73238 .31922 Mdot
.73429 .39584 Mdot
.73619 .32451 Mdot
.7381 .30418 Mdot
.74 .26416 Mdot
.7419 .40087 Mdot
.74381 .29323 Mdot
.74571 .31514 Mdot
.74762 .2466 Mdot
.74952 .39713 Mdot
.75143 .3119 Mdot
.75333 .39679 Mdot
.75524 .41688 Mdot
.75714 .49258 Mdot
.75905 .31245 Mdot
.76095 .26646 Mdot
.76286 .31245 Mdot
.76476 .37398 Mdot
.76667 .2915 Mdot
.76857 .27182 Mdot
.77048 .43461 Mdot
.77238 .40966 Mdot
.77429 .26577 Mdot
.77619 .3144 Mdot
.7781 .3538 Mdot
.78 .32978 Mdot
.7819 .39637 Mdot
.78381 .39574 Mdot
.78571 .28737 Mdot
.78762 .43386 Mdot
.78952 .35645 Mdot
.79143 .42851 Mdot
.79333 .36299 Mdot
.79524 .26735 Mdot
.79714 .28111 Mdot
.79905 .31694 Mdot
.80095 .44907 Mdot
.80286 .44375 Mdot
.80476 .33427 Mdot
.80667 .33573 Mdot
.80857 .33895 Mdot
.81048 .25865 Mdot
.81238 .37006 Mdot
.81429 .36006 Mdot
.81619 .34771 Mdot
.8181 .33861 Mdot
.82 .30999 Mdot
.8219 .32524 Mdot
.82381 .35295 Mdot
.82571 .36546 Mdot
.82762 .32864 Mdot
.82952 .26984 Mdot
.83143 .32726 Mdot
.83333 .4467 Mdot
.83524 .30458 Mdot
.83714 .38554 Mdot
.83905 .3508 Mdot
.84095 .25185 Mdot
.84286 .31428 Mdot
.84476 .29735 Mdot
.84667 .37352 Mdot
.84857 .32349 Mdot
.85048 .30786 Mdot
.85238 .48834 Mdot
.85429 .27129 Mdot
.85619 .26359 Mdot
.8581 .42582 Mdot
.86 .42893 Mdot
.8619 .3466 Mdot
.86381 .37476 Mdot
.86571 .44077 Mdot
.86762 .33754 Mdot
.86952 .2721 Mdot
.87143 .28372 Mdot
.87333 .36337 Mdot
.87524 .27981 Mdot
.87714 .35115 Mdot
.87905 .31246 Mdot
.88095 .38273 Mdot
.88286 .38091 Mdot
.88476 .2987 Mdot
.88667 .3022 Mdot
.88857 .29349 Mdot
.89048 .4506 Mdot
.89238 .31325 Mdot
.89429 .23312 Mdot
.89619 .33765 Mdot
.8981 .23897 Mdot
.9 .30675 Mdot
.9019 .39312 Mdot
.90381 .34635 Mdot
.90571 .26358 Mdot
.90762 .31899 Mdot
.90952 .44908 Mdot
.91143 .39869 Mdot
.91333 .34911 Mdot
.91524 .33018 Mdot
.91714 .31349 Mdot
.91905 .31411 Mdot
.92095 .28224 Mdot
.92286 .27041 Mdot
.92476 .25157 Mdot
.92667 .36433 Mdot
.92857 .36952 Mdot
.93048 .27848 Mdot
.93238 .35451 Mdot
.93429 .27426 Mdot
.93619 .37127 Mdot
.9381 .2627 Mdot
.94 .32279 Mdot
.9419 .27616 Mdot
.94381 .38064 Mdot
.94571 .36061 Mdot
.94762 .27826 Mdot
.94952 .34352 Mdot
.95143 .43017 Mdot
.95333 .33305 Mdot
.95524 .24007 Mdot
.95714 .27597 Mdot
.95905 .25454 Mdot
.96095 .3075 Mdot
.96286 .49265 Mdot
.96476 .30186 Mdot
.96667 .34866 Mdot
.96857 .3667 Mdot
.97048 .34138 Mdot
.97238 .27254 Mdot
.97429 .2612 Mdot
.97619 .43877 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo05?ooooo0_l0001^ooooo`;o00005_ooool2o`0005oooooo0006ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0Doooool2o`0006kooooo0_l0000@ooooo`;o00001?oo
ool2o`0005oooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0]ooooo`;o0000<Ooo
ool2o`0007?ooooo0_l0001Uooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o00007?ooool2o`0000Gooooo0_l0
0005ooooo`;o000000?oooooo`000?l00000;_ooool2o`000003ooooool0003o000003Gooooo0_l0
000/ooooo`;o0000COooool2o`0002Kooooo0006ooooo`05o`000?ooooooooooooooool000003_oo
ool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`0Dooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00009?ooool2o`0000_ooooo
0_l0000hooooo`;o0000;?ooool2o`0004gooooo0_l0000Vooooo`001_ooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01Cooooo0_l00002ooooo`;o00001oooool2o`0002gooooo0_l0000Jooooo`;o0000
??ooool2o`0001?ooooo0_l0001Dooooo`;o00004Oooool2o`0001;ooooo0006ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Hooooo`;o00001oooool2o`0004Wooooo0_l0000Fooooo`;o
00006_ooool2o`0000Sooooo0_l0000Cooooo`;o0000E?ooool2o`00017ooooo0_l0000Booooo`00
1_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co00001_ooool00ol0003oooooooooo`24ooooo`;o00006_ooool2o`0003cooooo0_l00005oooo
o`;o0000EOooool002Wooooo0_l0001/ooooo`;o00008?ooool2o`0000kooooo0_l0000oooooo`;o
00001Oooool2o`0005Gooooo000Yooooo`;o0000K?ooool2o`00023ooooo0_l0000>ooooo`;o0000
>_ooool2o`0002Sooooo0_l0000Iooooo`;o00007?ooool002Wooooo0_l00009ooooo`;o00000ooo
ool2o`0000_ooooo0_l0000Rooooo`;o00002?ooool2o`0001_ooooo0_l0000^ooooo`;o00003_oo
ool3o`0000Gooooo0_l0000Zooooo`;o0000:?ooool2o`0001Wooooo0_l00009ooooo`;o00004Ooo
ool002Wooooo00?o0000ooooooooool01_ooool4o`0000?ooooo0ol0000:ooooo`?o00005?ooool2
o`0000_ooooo0_l00008ooooo`;o00004_ooool2o`0000Oooooo0_l0000Pooooo`;o00003?ooool2
o`0000Wooooo0_l00003ooooo`?o00001Oooool2o`0004[ooooo0_l0000^ooooo`;o00004Oooool0
02Wooooo00?o0000ooooooooool01_ooool2o`0000Kooooo0_l00007ooooo`;o00000_ooool2o`00
01Cooooo1?l0000Tooooo`;o000000Coooooo`000?l0003ooooo0_l0000Vooooo`;o00005oooool2
o`0005Oooooo0_l0000cooooo`;o00003?ooool002Wooooo0_l0000Hooooo`;o00003Oooool2o`00
00Gooooo0_l00004ooooo`;o00008oooool3o`0000Cooooo0_l0000Booooo`;o00003?ooool2o`00
01Gooooo0_l0000Looooo`;o0000:oooool2o`0002?ooooo0_l0000>ooooo`;o00002?ooool2o`00
00[ooooo0_l0000<ooooo`00:Oooool00ol0003oooooooooo`0Vooooo`;o00001Oooool2o`0002Go
oooo0_l00002ooooo`;o00002Oooool2o`0000[ooooo0_l00002ooooo`;o00000oooool2o`0000Oo
oooo0_l0000Eooooo`;o00005_ooool2o`0000Cooooo0_l0000>ooooo`;o000000?oooooo`000?l0
00006?ooool2o`0000Cooooo0_l00003ooooo`;o00001?ooool2o`0001;ooooo0_l0000>ooooo`;o
00002?ooool2o`0001Sooooo000Yooooo`04o`000?ooooooooooooooo`;o0000;Oooool4o`000005
oa0@4?ooooooooooonk^k_lb<S801?l00002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01oooool2
o`0000Oooooo0_l0000=ooooo`;o00002?ooool5o`0000?ooooo00?ok^k^oc8b<_l000000ol00002
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03oooool2o`0000Kooooo0_l0000?ooooo`06oiRHV?l@
413o0000oc8b<_o<c<cooooo0_l000001Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^o`00
0?l0003o<S8bonk^kP07ooooo`Go00007_ooool2o`000003oa0@4?oooooooooo00;o000000Co<S8b
o`000?lb<S;ok^k^0_l000001_ooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo0_l00006ooooo`;o
00005?ooool2o`0000Kooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Yooooo`04o`000?oooooo
ooooooooo`;o00007oooool2o`0000kooooo00?o0000ooooooooool00_ooool00omgMgOoV9RHoooo
o`03o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`;o00000oooool3o`0000Wooooo
0_l0000:ooooo`;o00000oooool2o`000003onk^k_ooooooA4A400?ooooo00CoMgMgoiRHV?oooooo
V9RH0_l00002ooooo`04ogMgMonHV9SooooooiRHV0;o00002?ooool2o`0000Cooooo0_l00006oooo
o`;o00003oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05ogMgMol0003o0000oiRHV?mgMgL02?ooool2o`00027ooooo00[o0000ooooool0003o
0000oooooomgMgOoV9RHoooooonHV9SoMgMg0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
0_l00006ooooo`;o00000oooool2o`0000oooooo0_l00002ooooo`;o00001Oooool01OmgMgOo<S8b
ooooooooooooMgMg00;o000000?oV9RHogMgMoooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo000Yooooo`03o`000?oooooooooo02;ooooo0_l00007ooooo`;o00001Oooool00ol0003o
ooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo
410@00cooooo0ol00009ooooo`;o00002?ooool6o`000005ooooool0003o0000ob4Q8Oo^k^h01?oo
ool01Ol@413ooooooooooooooooo410@00;ooooo0_l00003ooooo`;o00002?ooool2o`00027ooooo
00Go0000oooooooooooooooooa0@4002o`000003ooooool@413ooooo00;ooooo00Go410@oooooooo
oooooooooa0@400Iooooo`;o00003Oooool7o`000003ooooool@413ooooo00;ooooo00Go410@oooo
oooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00kooooo0_l0000Cooooo`Co00000oooool2
o`0000;ooooo00Go410@o`000?l0003ooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100
0oooool002Wooooo0_l0000Eooooo`;o00004Oooool2o`0000;ooooo0_l00005ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00008_ooool2o`0000;ooooo0_l00003ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`000002ooooo`;o00000oooool00ol0003oooooooooo`0Sooooo`;o00001?ooool00onY
ZJWo410@ooooo`02ooooo`?o000000?oooooo`000?ooool00_ooool01Ol0003ooooooooooooooooo
000001Cooooo0_l00003ooooo`;o00003Oooool01?m4A4CogMgMooooool00004ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000001;ooooo0_l0000@ooooo`;o
000000?oooooo`000?l000000_l000000ooooooo0000o`000002ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo000Yooooo`03o`000?oooooooooo
00Wooooo0_l00009ooooo`;o00003Oooool2o`0000;ooooo0_l00009ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooooooo0ol000000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo02[ooooo00?oMgMgofIVI_ooool00_ooool01_l0003ooooooooooooooooo0000ooooo`?o0000
0oooool00ol0003oooooooooo`0Aooooo`;o00001Oooool2o`0000Wooooo1?l000001?oooooo410@
o`000?nj^[X3ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000001Cooooo0_l00004ooooo`;o00003?ooool01?oMgMgoEEEEooooool00004ooooo`06o`000?oo
ooooooooooooool0003ooooo0ol00003ooooo`03o`000?oooooooooo00oooooo0ol0000=ooooo`;o
000000?oooooo`000?l000000oooool3o`000005oc8b<_o<c<coooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00Oooool002Wooooo00?o0000oooo
ooooool02Oooool2o`0001Sooooo0_l0000=ooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@4002o`000003ooooool@413ooooo00;ooooo00?o410@ooooooooool07_ooool2
o`0000_ooooo00?o0000ooooooooool00_l00003ooooo`05oa0@4?oooooo0000o`000?l@41000ooo
ool00ol@413oooooooooo`0Aooooo`;o00001Oooool2o`0000_ooooo0_l00002ooooo`03okZj^_lQ
8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
41001?ooool2o`0000cooooo0_l00006ooooo`;o00003Oooool00omgMgOoc<c<o`000004ooooo`06
oa0@4?ooooooooooooooool@413ooooo0_l000001Ol@413ooooooooooooooooo410@017ooooo0_l0
000>ooooo`;o00001_ooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100
0oooool01Ol@413ooooooooooooooooo410@00?ooooo000Yooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0Pooooo`;o00001oooool01Ol0003o^[ZjoooooonHV9So410@00;ooooo0_l00000
1?nHV9SooooooiRHV?mgMgL3ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool2o`0001Sooooo
00Go410@o`000?l0003o^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Cooooo0_l0000<ooooo`;o00005Oooool00oo^k^koA4A4o`000004
ooooo`05ogMgMonHV9So0000o`000?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg02Wooooo
00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`00:Oooool00ol0003oooooooooo`0`ooooo`03oeEEEOmVIVKo000000Co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09oooool2
o`000005oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`?o00001_ooool2o`00013ooooo00GoZJVYo`000?l0
003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^02Gooooo0_l00003ooooo`04ogMgMol0003o0000o`0000;ooooo00Gok^k^oc8b<_l0003o
0000onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:Oooool4o`0000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool002Wooooo0_l00014
ooooo`;o000000?oooooo`000?l000008Oooool4o`0002;ooooo0_l00007ooooo`;o0000B_ooool2
o`0000Gooooo0_l0000Uooooo`;o0000:?ooool002Wooooo00?o0000ooooooooool04oooool2o`00
02kooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000003oooool2o`00
00Wooooo0_l0000Tooooo`;o00004Oooool2o`0000Oooooo1?l00005ooooo`;o0000C_ooool2o`00
00_ooooo0ol0000Xooooo`00:Oooool3o`0001?ooooo0_l0000Nooooo`;o00001Oooool2o`0000ko
oooo0_l000000ooooooo0000o`000007ooooo`;o00001_ooool2o`0001;ooooo0_l0000^ooooo`;o
00001oooool4o`0000Gooooo0_l00002ooooo`;o0000B_ooool2o`0000_ooooo0ol0000Gooooo`;o
00003oooool002Wooooo0ol0000Zooooo`;o00001oooool2o`0000;ooooo0_l000000ooooooo0000
o`00000Jooooo`;o00003oooool2o`0000Wooooo0_l00008ooooo`?o0000>Oooool2o`0000Cooooo
0_l0000Rooooo`;o00007Oooool2o`0000oooooo0_l0000Gooooo`;o00003oooool002Wooooo00?o
0000ooooooooool0:_ooool2o`0000_ooooo0_l0000@ooooo`;o00005?ooool2o`0000Kooooo0_l0
000Cooooo`?o00002oooool4o`0000Kooooo0_l00004ooooo`;o00008_ooool2o`0000kooooo0_l0
000Booooo`;o00007Oooool2o`0000?ooooo0_l0000>ooooo`;o00004_ooool2o`00013ooooo000Q
oooooooo0000A?l00004ooooo`00:Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Gooooo0_l00002ooooo`03o`000?oooooooooo00[ooooo0_l0000:ooooo`03o`000?oooooooooo
00Cooooo0_l00003ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`09ooooo`04o`000?ooooooooooooooo`;o00001_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Cooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0_l00005
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool2o`000003ooooool0003o
000000;ooooo00?o0000ooooooooool01oooool2o`000003ooooool0003ooooo00[ooooo0_l00000
1?oooooo0000o`000?l00002ooooo`;o00000_ooool00ol0003oooooooooo`07ooooo`?o00001Ooo
ool2o`0000Gooooo00Co0000oooooooooooooooo0_l00003ooooo`;o000000?oooooo`000?ooool0
0oooool2o`0000Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`00:Ooo
ool00ol0003oooooooooo`0fooooo`;o00000_ooool00ol0003oooooooooo`05ooooo`;o00000ooo
ool2o`00017ooooo0ol0000Kooooo`03o`000?oooooooooo02Sooooo0_l0000@ooooo`03o`000?oo
oooooooo00cooooo0_l0000Aooooo`;o00002oooool2o`0000?ooooo0ol00002ooooo`;o00000_oo
ool01?l0003oooooooooooooool2o`0000cooooo0_l00009ooooo`;o00000oooool2o`0000Kooooo
0_l0000Aooooo`03o`000?oooooooooo00[ooooo000Yooooo`03o`000?oooooooooo01;ooooo0_l0
000Dooooo`;o00006?ooool2o`0000[ooooo0_l0000;ooooo`;o00004Oooool2o`0001?ooooo0_l0
000Jooooo`;o00008oooool2o`0001Sooooo1?l00002ooooo`;o00004?ooool2o`00023ooooo0_l0
000Rooooo`00:Oooool00ol0003oooooo`000002o`00013ooooo0_l0000<ooooo`;o00001_ooool2
o`0000_ooooo0_l0000Gooooo`;o00007_ooool2o`0000Wooooo0_l00008ooooo`;o00006_ooool2
o`00023ooooo0_l00008ooooo`;o00004Oooool4o`0002?ooooo0_l0000Aooooo`;o00002Oooool2
o`0001Oooooo000Yooooo`Go00001Oooool2o`0001Oooooo0_l0000Cooooo`;o00002?ooool4o`00
00Sooooo0_l00008ooooo`;o00008_ooool2o`0001?ooooo0_l0000aooooo`;o00002?ooool2o`00
00Wooooo0_l00009ooooo`;o00006_ooool2o`000003ooooool0003o000000?ooooo0_l0000Loooo
o`;o00005oooool002Wooooo00?o0000ooooooooool01oooool2o`0001cooooo0_l0000Hooooo`Co
00002?ooool3o`0000Oooooo0_l0000booooo`;o00000oooool2o`0002_ooooo0_l0000>ooooo`Oo
00001?ooool2o`0000Wooooo0_l0000<ooooo`;o00003?ooool5o`0001Wooooo0_l0000Oooooo`00
:Oooool00ol0003oooooooooo`0=ooooo`;o00005_ooool2o`0000Sooooo0_l00004ooooo`;o0000
5Oooool2o`0001Sooooo0_l0000Eooooo`;o00002_ooool2o`0001[ooooo0_l00003ooooo`;o0000
1oooool2o`0000Kooooo0_l0000>ooooo`Oo00007Oooool2o`0000kooooo0_l0000Jooooo`;o0000
2_ooool2o`0001?ooooo000Yooooo`03o`000?oooooooooo00;ooooo0_l00009ooooo`;o00008?oo
ool2o`0000Cooooo0_l0000Jooooo`;o00004oooool2o`0001;ooooo0_l000000ooooooo0000o`00
000>ooooo`;o00001?ooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o00000_oo
ool2o`000003ooooool0003o000000?ooooo0_l00007ooooo`;o00002?ooool2o`0001?ooooo1?l0
000Qooooo`?o0000;Oooool2o`0001?ooooo000Yooooo`05o`000?oooooo0000o`000?ooool00_l0
000Tooooo`?o00009_ooool2o`0001oooooo0_l00006ooooo`;o00003Oooool2o`0000;ooooo0_l0
0004ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00002ooooo`;o00006Ooo
ool2o`0001?ooooo1?l0000Qooooo`Co000000?oooooo`000?l000003_ooool2o`0000Oooooo0_l0
000Uooooo`00:Oooool4o`0002Oooooo0ol00007ooooo`;o00008?ooool2o`0000?ooooo0_l0000G
ooooo`;o00005Oooool2o`0002?ooooo0_l00019ooooo`;o000000?oooooo`000?l000003_ooool2
o`0000Oooooo0_l0000Fooooo`;o00003Oooool002Wooooo00?o0000ooooooooool03?ooool2o`00
02Cooooo0_l0000<ooooo`;o00004_ooool2o`0000?ooooo0_l00006ooooo`;o00001?ooool2o`00
02Wooooo0_l0000Jooooo`;o00006?ooool2o`0000;ooooo0_l0001Hooooo`;o00001Oooool2o`00
00gooooo000Yooooo`03o`000?oooooooooo00?ooooo0_l00007ooooo`;o00002oooool2o`0002Go
oooo0_l0000Oooooo`;o00001?ooool2o`0001Gooooo0_l0000Booooo`;o00007Oooool2o`0001Go
oooo0_l00002ooooo`;o00000_ooool2o`0002Wooooo0_l0000=ooooo`;o00002oooool2o`000003
ooooool0003o000000[ooooo0_l00003ooooo`;o00003oooool002Wooooo00?o0000ooooooooool0
0oooool4o`0001;ooooo0_l0000Mooooo`;o00001?ooool2o`0003kooooo0_l0000Qooooo`;o0000
1Oooool2o`0000Oooooo0ol00006ooooo`;o00000_ooool2o`0000;ooooo0_l0000<ooooo`;o0000
:Oooool2o`0000Gooooo0_l00006ooooo`;o00000oooool2o`0000Kooooo0_l000000ooooooo0000
o`00000?ooooo`;o00003oooool002Wooooo0_l00006ooooo`;o00006Oooool2o`0001Kooooo0_l0
0004ooooo`;o00003oooool2o`00053ooooo0_l00005ooooo`;o00002?ooool2o`0000Kooooo0_l0
0002ooooo`;o00000_ooool2o`0002_ooooo0_l0000=ooooo`;o00000_ooool2o`0000_ooooo0_l0
000?ooooo`;o00006_ooool002Wooooo0_l0000Qooooo`;o00002_ooool4o`0000;ooooo0_l0000K
ooooo`;o0000I?ooool2o`0003Sooooo0_l000000ooooooo0000o`00000:ooooo`;o00008?ooool2
o`0001[ooooo000Yooooo`03o`000?oooooooooo00oooooo0_l0000Kooooo`Co00000_ooool2o`00
02Cooooo0_l0000Looooo`;o00001oooool2o`0001kooooo0_l0000Dooooo`;o0000>oooool2o`00
00Kooooo0_l0000Yooooo`;o00005Oooool002Wooooo00?o0000ooooooooool03oooool2o`0002Go
oooo0_l0000<ooooo`;o00004_ooool2o`0001Oooooo0_l00003ooooo`;o00001oooool2o`000004
ooooool0003o0000ooooo`;o00006?ooool2o`0000kooooo0_l00006ooooo`;o00006oooool2o`00
01kooooo0_l00004ooooo`;o00004Oooool2o`00013ooooo0_l00004ooooo`;o00005Oooool002Wo
oooo00?o0000ooooooooool06?ooool2o`0000Sooooo0_l0000Booooo`;o00003?ooool2o`0001co
oooo0_l0000=ooooo`;o00001?ooool2o`0000Wooooo0_l000000ooooooo0000o`000002o`0002Ko
oooo0_l00006ooooo`;o00005?ooool2o`0000Gooooo0_l00002ooooo`;o00006_ooool2o`0000So
oooo0_l0000=ooooo`;o00004?ooool2o`0000_ooooo0_l0000>ooooo`00:Oooool00ol0003ooooo
ooooo`0Aooooo`;o00001?ooool3o`0000Sooooo0_l0000nooooo`;o00004oooool2o`0000cooooo
1?l00014ooooo`;o00002Oooool2o`00023ooooo0_l00002ooooo`;o00007oooool2o`0000_ooooo
0_l0000>ooooo`00:Oooool2o`0001;ooooo0_l00004ooooo`;o0000G_ooool2o`0005[ooooo0_l0
0006ooooo`;o00003_ooool2o`0000gooooo0_l00009ooooo`;o00006?ooool2o`000003ooooool0
003o000001Sooooo000Yooooo`03o`000?oooooooooo03gooooo0_l0001Cooooo`;o00002Oooool2
o`00027ooooo0_l0000Aooooo`;o00001_ooool2o`0000kooooo0_l0000Hooooo`;o00000oooool2
o`0001Kooooo0_l0000Hooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool07Ooo
ool3o`0000kooooo0_l0000=ooooo`;o0000Doooool2o`0000Oooooo1?l00005ooooo`;o00006_oo
ool2o`0004Sooooo0_l0000`ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo01Kooooo0_l00005ooooo`?o00003_ooool4o`0004Sooooo0_l0000Oooooo`;o0000
1oooool2o`0006[ooooo0_l0000Booooo`;o00005_ooool000Kooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Booooo`;o00000_ooool2o`0001Sooooo0_l00018ooooo`;o0000BOooool2o`0003_ooooo
0_l0000<ooooo`;o00004_ooool2o`0001Kooooo0006ooooo`05o`000?ooooooooooooooool00000
3Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Booooo`;o0000
2?ooool2o`0006;ooooo0_l0000:ooooo`;o00008_ooool2o`0001?ooooo0_l0000kooooo`;o0000
>?ooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00[ooooo0_l0000>ooooo`Co
0000A_ooool2o`0001[ooooo0_l0000:ooooo`;o00008_ooool2o`0008[ooooo0006ooooo`05oa0@
4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool02_ooool2o`0000kooooo0_l0000Looooo`;o0000:_ooool2o`0000oo
oooo0_l0000?ooooo`;o0000<_ooool2o`0002Gooooo0_l0000>ooooo`;o00009?ooool2o`0002?o
oooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0hooooo`;o00000oooool2o`00
03Kooooo0_l0000?ooooo`;o00003oooool2o`0000oooooo0_l0000@ooooo`;o00009Oooool2o`00
00?ooooo0ol00007ooooo`?o00009?ooool2o`000003ooooool0003o0000023ooooo0006ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006
ooooo`03o`000?oooooooooo00[ooooo0_l0000aooooo`;o00003_ooool2o`0004Sooooo0_l0000?
ooooo`;o00008?ooool2o`0001Oooooo0_l000001?oooooo0000o`000?l00007ooooo`;o0000:?oo
ool2o`00023ooooo000Yooooo`;o00002oooool2o`0000?ooooo0_l0000Sooooo`;o00005oooool2
o`0007_ooooo0_l0000Gooooo`;o0000Eoooool002Wooooo00?o0000ooooooooool03?ooool2o`00
0003ooooool0003o000002?ooooo0_l0000Booooo`;o0000=Oooool2o`0003_ooooo0_l0001noooo
o`00:Oooool00ol0003oooooooooo`0<ooooo`;o00006Oooool2o`0001Oooooo0_l00006ooooo`?o
00008oooool2o`0000oooooo0_l0000?ooooo`;o0000:_ooool2o`0002oooooo0_l0001=ooooo`00
:Oooool00ol0003oooooooooo`04ooooo`;o000000?oooooo`000?l000001?l00008ooooo`;o0000
4?ooool2o`0001Oooooo0_l00004ooooo`;o000000?oooooo`000?l000004?ooool2o`00017ooooo
0_l0000Pooooo`;o00009oooool2o`0000;ooooo0_l0000Nooooo`;o00003_ooool2o`0004gooooo
000Yooooo`03o`000?oooooooooo00Cooooo0_l000000ooooooo0000o`000004o`0000Sooooo0_l0
000Zooooo`;o00000oooool2o`0001?ooooo0_l0000Booooo`?o0000Aoooool2o`0000;ooooo0_l0
000Nooooo`;o00002?ooool2o`0005?ooooo000Yooooo`;o00000oooool2o`0000cooooo0_l0000_
ooooo`;o0000;?ooool3o`0002;ooooo0_l0000Rooooo`;o0000;Oooool2o`0005?ooooo000Yoooo
o`03o`000?oooooooooo00;ooooo0_l0000<ooooo`;o0000L?ooool2o`00013ooooo0_l0000Roooo
o`;o0000P_ooool002Wooooo00?o0000ooooooooool0HOooool2o`0000kooooo0_l0000?ooooo`;o
0000QOooool2o`00037ooooo000Yooooo`03o`000?oooooooooo02Gooooo0_l0000Nooooo`;o0000
6_ooool2o`0000kooooo0_l00020ooooo`;o00005?ooool2o`00037ooooo000Yooooo`03o`000?oo
oooooooo00Gooooo0_l0000Nooooo`;o00007_ooool2o`0000cooooo0_l0000eooooo`;o0000=Ooo
ool2o`0001Wooooo0_l000000ooooooo0000o`00000Booooo`;o00005?ooool2o`0001cooooo0_l0
000Cooooo`00:Oooool2o`0000Kooooo0_l0000nooooo`;o00001oooool2o`0000?ooooo0_l00009
ooooo`;o00003?ooool2o`0001cooooo0_l0000Yooooo`;o00002_ooool2o`0001Wooooo0_l00000
0ooooooo0000o`00000;ooooo`;o00001?ooool2o`0003?ooooo0_l0000Cooooo`00:Oooool00ol0
003oooooooooo`0Oooooo`;o00009?ooool2o`0000Oooooo0_l0000>ooooo`;o00003?ooool2o`00
04Cooooo0_l000000ooooooo0000o`00000Hooooo`;o00002oooool2o`0000kooooo0_l00004oooo
o`;o0000>oooool2o`0000_ooooo000Yooooo`03o`000?oooooooooo01oooooo0_l0000Jooooo`;o
00009_ooool2o`00017ooooo0_l0000jooooo`;o00006oooool2o`0003[ooooo0_l0000Rooooo`;o
00002oooool002Wooooo00?o0000ooooooooool01?ooool2o`0000oooooo0_l0000=ooooo`;o0000
5Oooool2o`0001Wooooo0_l0000;ooooo`;o00001?ooool2o`0000_ooooo0_l0000dooooo`;o0000
4_ooool2o`0000oooooo0_l00003ooooo`;o00000_ooool2o`0001_ooooo0_l0000Booooo`;o0000
;oooool002Wooooo00?o0000ooooooooool01?ooool2o`0000[ooooo0_l00003ooooo`;o00003Ooo
ool2o`0000[ooooo0_l0000Pooooo`;o00000_ooool2o`00017ooooo0_l0000Iooooo`;o00005_oo
ool2o`0000kooooo0_l0000Booooo`;o00003oooool2o`0000?ooooo0_l00002ooooo`;o00006ooo
ool2o`0000Sooooo0_l0000iooooo`00:Oooool2o`0000;ooooo0_l0000=ooooo`;o00002oooool4
o`0000[ooooo0_l00003ooooo`;o00008?ooool2o`00023ooooo0_l0000>ooooo`;o00005_ooool2
o`0002[ooooo0_l0000Eooooo`;o00005Oooool2o`0000Wooooo0_l0000@ooooo`;o00001?ooool2
o`00027ooooo000Yooooo`04o`000?ooooooooooooooo`;o00006_ooool4o`0000[ooooo0_l00017
ooooo`;o0000D_ooool2o`0001Gooooo0_l0000Eooooo`;o00006oooool2o`0000Cooooo0_l0000Q
ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0iooooo`;o0000ooooool2ooooo`003_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0>Oooool2o`000?oooooo0_ooool000kooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo000>ooooo`05o`000?oooooo
ooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Ooo
ool000kooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000
oooooolnooooo`00:Oooool00ol0003oooooooooo`2fooooo`;o0000Q?ooool002Wooooo00?o0000
ooooooooool0]_ooool2o`0008Cooooo000Yooooo`03o`000?oooooooooo05Oooooo0_l0002^oooo
o`;o0000<oooool002Wooooo00?o0000ooooooooool0@oooool2o`0001;ooooo0_l0002^ooooo`;o
0000<oooool002Wooooo0_l00014ooooo`;o0000Xoooool2o`00043ooooo0_l0000@ooooo`00:Ooo
ool00ol0003oooooooooo`3Xooooo`;o0000@?ooool2o`00013ooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000
oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool0
0ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?o
EEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Ooo
ool000Kooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o
0000ooooooooool00oooool3o`000?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<oooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo
0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oo
oooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oo
oooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Oooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3o
ooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolmoooo
o`008Oooool00ol0003oooooooooo`05ooooo`?o0000oooooolmooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Oooooo`03
oeEEEOmVIVKo00000?ooooooAoooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .26714 Mdot
.02762 .26273 Mdot
.02952 .31015 Mdot
.03143 .34045 Mdot
.03333 .26848 Mdot
.03524 .38091 Mdot
.03714 .28951 Mdot
.03905 .43112 Mdot
.04095 .35176 Mdot
.04286 .27567 Mdot
.04476 .33994 Mdot
.04667 .44606 Mdot
.04857 .38671 Mdot
.05048 .31803 Mdot
.05238 .44645 Mdot
.05429 .30979 Mdot
.05619 .25073 Mdot
.0581 .39077 Mdot
.06 .31241 Mdot
.0619 .37664 Mdot
.06381 .39472 Mdot
.06571 .32396 Mdot
.06762 .3491 Mdot
.06952 .39812 Mdot
.07143 .44913 Mdot
.07333 .37117 Mdot
.07524 .35164 Mdot
.07714 .31744 Mdot
.07905 .35745 Mdot
.08095 .27331 Mdot
.08286 .40492 Mdot
.08476 .34849 Mdot
.08667 .41603 Mdot
.08857 .31373 Mdot
.09048 .3642 Mdot
.09238 .39414 Mdot
.09429 .23095 Mdot
.09619 .34016 Mdot
.0981 .32695 Mdot
.1 .4503 Mdot
.1019 .4526 Mdot
.10381 .34283 Mdot
.10571 .38821 Mdot
.10762 .2554 Mdot
.10952 .30203 Mdot
.11143 .33719 Mdot
.11333 .31253 Mdot
.11524 .29621 Mdot
.11714 .33136 Mdot
.11905 .356 Mdot
.12095 .29353 Mdot
.12286 .29226 Mdot
.12476 .36808 Mdot
.12667 .38088 Mdot
.12857 .38411 Mdot
.13048 .3873 Mdot
.13238 .43421 Mdot
.13429 .24825 Mdot
.13619 .2481 Mdot
.1381 .31544 Mdot
.14 .34725 Mdot
.1419 .38349 Mdot
.14381 .31864 Mdot
.14571 .26611 Mdot
.14762 .41529 Mdot
.14952 .36852 Mdot
.15143 .27026 Mdot
.15333 .31855 Mdot
.15524 .34079 Mdot
.15714 .406 Mdot
.15905 .25726 Mdot
.16095 .28527 Mdot
.16286 .28288 Mdot
.16476 .25596 Mdot
.16667 .31877 Mdot
.16857 .28626 Mdot
.17048 .36847 Mdot
.17238 .36302 Mdot
.17429 .31147 Mdot
.17619 .33851 Mdot
.1781 .41402 Mdot
.18 .26909 Mdot
.1819 .33578 Mdot
.18381 .34793 Mdot
.18571 .4119 Mdot
.18762 .30623 Mdot
.18952 .275 Mdot
.19143 .30695 Mdot
.19333 .24469 Mdot
.19524 .31476 Mdot
.19714 .44769 Mdot
.19905 .22428 Mdot
.20095 .27057 Mdot
.20286 .31928 Mdot
.20476 .26265 Mdot
.20667 .22068 Mdot
.20857 .31368 Mdot
.21048 .30323 Mdot
.21238 .37852 Mdot
.21429 .24417 Mdot
.21619 .2497 Mdot
.2181 .25715 Mdot
.22 .44494 Mdot
.2219 .24293 Mdot
.22381 .41533 Mdot
.22571 .32502 Mdot
.22762 .27325 Mdot
.22952 .29033 Mdot
.23143 .27152 Mdot
.23333 .40692 Mdot
.23524 .29618 Mdot
.23714 .33973 Mdot
.23905 .34529 Mdot
.24095 .39485 Mdot
.24286 .47191 Mdot
.24476 .26508 Mdot
.24667 .35693 Mdot
.24857 .38033 Mdot
.25048 .36604 Mdot
.25238 .23209 Mdot
.25429 .38638 Mdot
.25619 .40995 Mdot
.2581 .3814 Mdot
.26 .35487 Mdot
.2619 .40713 Mdot
.26381 .34048 Mdot
.26571 .38504 Mdot
.26762 .23215 Mdot
.26952 .24206 Mdot
.27143 .29753 Mdot
.27333 .34576 Mdot
.27524 .23895 Mdot
.27714 .45052 Mdot
.27905 .38005 Mdot
.28095 .38901 Mdot
.28286 .33132 Mdot
.28476 .23861 Mdot
.28667 .36917 Mdot
.28857 .27981 Mdot
.29048 .42729 Mdot
.29238 .44795 Mdot
.29429 .32594 Mdot
.29619 .31729 Mdot
.2981 .33144 Mdot
.3 .25074 Mdot
.3019 .38676 Mdot
.30381 .4005 Mdot
.30571 .49219 Mdot
.30762 .27336 Mdot
.30952 .31864 Mdot
.31143 .42651 Mdot
.31333 .26598 Mdot
.31524 .35314 Mdot
.31714 .39969 Mdot
.31905 .2769 Mdot
.32095 .35536 Mdot
.32286 .2505 Mdot
.32476 .31032 Mdot
.32667 .38116 Mdot
.32857 .23077 Mdot
.33048 .24741 Mdot
.33238 .36363 Mdot
.33429 .3134 Mdot
.33619 .4572 Mdot
.3381 .40437 Mdot
.34 .38662 Mdot
.3419 .25332 Mdot
.34381 .3968 Mdot
.34571 .41696 Mdot
.34762 .34386 Mdot
.34952 .25403 Mdot
.35143 .37006 Mdot
.35333 .2862 Mdot
.35524 .34924 Mdot
.35714 .27863 Mdot
.35905 .26321 Mdot
.36095 .41855 Mdot
.36286 .2224 Mdot
.36476 .35823 Mdot
.36667 .26667 Mdot
.36857 .34723 Mdot
.37048 .2754 Mdot
.37238 .45353 Mdot
.37429 .26664 Mdot
.37619 .4519 Mdot
.3781 .32849 Mdot
.38 .34641 Mdot
.3819 .23315 Mdot
.38381 .34123 Mdot
.38571 .45677 Mdot
.38762 .38972 Mdot
.38952 .42414 Mdot
.39143 .38738 Mdot
.39333 .2874 Mdot
.39524 .39155 Mdot
.39714 .42166 Mdot
.39905 .44908 Mdot
.40095 .44775 Mdot
.40286 .30928 Mdot
.40476 .24547 Mdot
.40667 .3059 Mdot
.40857 .28817 Mdot
.41048 .28392 Mdot
.41238 .2936 Mdot
.41429 .26511 Mdot
.41619 .26405 Mdot
.4181 .24289 Mdot
.42 .32343 Mdot
.4219 .37343 Mdot
.42381 .33904 Mdot
.42571 .33291 Mdot
.42762 .34316 Mdot
.42952 .36115 Mdot
.43143 .3611 Mdot
.43333 .41689 Mdot
.43524 .27747 Mdot
.43714 .24916 Mdot
.43905 .35593 Mdot
.44095 .45657 Mdot
.44286 .32973 Mdot
.44476 .32388 Mdot
.44667 .44692 Mdot
.44857 .35448 Mdot
.45048 .25858 Mdot
.45238 .4167 Mdot
.45429 .41145 Mdot
.45619 .29332 Mdot
.4581 .25088 Mdot
.46 .24892 Mdot
.4619 .28019 Mdot
.46381 .4469 Mdot
.46571 .40619 Mdot
.46762 .32915 Mdot
.46952 .31561 Mdot
.47143 .27228 Mdot
.47333 .29243 Mdot
.47524 .35194 Mdot
.47714 .41597 Mdot
.47905 .34569 Mdot
.48095 .23857 Mdot
.48286 .37869 Mdot
.48476 .24114 Mdot
.48667 .38195 Mdot
.48857 .38859 Mdot
.49048 .41662 Mdot
.49238 .25672 Mdot
.49429 .34973 Mdot
.49619 .2609 Mdot
.4981 .2537 Mdot
.5 .25051 Mdot
.5019 .25436 Mdot
.50381 .31786 Mdot
.50571 .44967 Mdot
.50762 .26578 Mdot
.50952 .28605 Mdot
.51143 .24178 Mdot
.51333 .36954 Mdot
.51524 .35033 Mdot
.51714 .38877 Mdot
.51905 .28063 Mdot
.52095 .43027 Mdot
.52286 .27198 Mdot
.52476 .31348 Mdot
.52667 .35185 Mdot
.52857 .40974 Mdot
.53048 .27503 Mdot
.53238 .26919 Mdot
.53429 .28374 Mdot
.53619 .3218 Mdot
.5381 .38353 Mdot
.54 .38386 Mdot
.5419 .36378 Mdot
.54381 .39171 Mdot
.54571 .38686 Mdot
.54762 .27291 Mdot
.54952 .3281 Mdot
.55143 .25433 Mdot
.55333 .26257 Mdot
.55524 .25698 Mdot
.55714 .30606 Mdot
.55905 .33985 Mdot
.56095 .36273 Mdot
.56286 .3362 Mdot
.56476 .30291 Mdot
.56667 .259 Mdot
.56857 .23078 Mdot
.57048 .44189 Mdot
.57238 .28657 Mdot
.57429 .26848 Mdot
.57619 .25188 Mdot
.5781 .40593 Mdot
.58 .32809 Mdot
.5819 .41378 Mdot
.58381 .23284 Mdot
.58571 .24387 Mdot
.58762 .44293 Mdot
.58952 .24809 Mdot
.59143 .31418 Mdot
.59333 .23413 Mdot
.59524 .4 Mdot
.59714 .41295 Mdot
.59905 .44522 Mdot
.60095 .49773 Mdot
.60286 .33912 Mdot
.60476 .39196 Mdot
.60667 .23811 Mdot
.60857 .34991 Mdot
.61048 .45148 Mdot
.61238 .32084 Mdot
.61429 .3044 Mdot
.61619 .36889 Mdot
.6181 .31163 Mdot
.62 .35941 Mdot
.6219 .25659 Mdot
.62381 .38176 Mdot
.62571 .43142 Mdot
.62762 .26473 Mdot
.62952 .3104 Mdot
.63143 .33042 Mdot
.63333 .42199 Mdot
.63524 .27724 Mdot
.63714 .4536 Mdot
.63905 .42786 Mdot
.64095 .30575 Mdot
.64286 .33513 Mdot
.64476 .38022 Mdot
.64667 .35012 Mdot
.64857 .29889 Mdot
.65048 .25088 Mdot
.65238 .30008 Mdot
.65429 .30398 Mdot
.65619 .26406 Mdot
.6581 .44176 Mdot
.66 .24381 Mdot
.6619 .26148 Mdot
.66381 .3448 Mdot
.66571 .30296 Mdot
.66762 .29533 Mdot
.66952 .25218 Mdot
.67143 .38414 Mdot
.67333 .38677 Mdot
.67524 .36331 Mdot
.67714 .25992 Mdot
.67905 .34485 Mdot
.68095 .36759 Mdot
.68286 .25776 Mdot
.68476 .2649 Mdot
.68667 .40441 Mdot
.68857 .35023 Mdot
.69048 .37342 Mdot
.69238 .29512 Mdot
.69429 .29524 Mdot
.69619 .34214 Mdot
.6981 .3292 Mdot
.7 .44535 Mdot
.7019 .23224 Mdot
.70381 .39083 Mdot
.70571 .34839 Mdot
.70762 .30147 Mdot
.70952 .37534 Mdot
.71143 .28062 Mdot
.71333 .44505 Mdot
.71524 .30131 Mdot
.71714 .41599 Mdot
.71905 .44983 Mdot
.72095 .4539 Mdot
.72286 .45425 Mdot
.72476 .31239 Mdot
.72667 .30717 Mdot
.72857 .4479 Mdot
.73048 .43166 Mdot
.73238 .31629 Mdot
.73429 .41278 Mdot
.73619 .36587 Mdot
.7381 .37365 Mdot
.74 .25447 Mdot
.7419 .31609 Mdot
.74381 .23895 Mdot
.74571 .23014 Mdot
.74762 .26393 Mdot
.74952 .34345 Mdot
.75143 .2291 Mdot
.75333 .34079 Mdot
.75524 .45054 Mdot
.75714 .48135 Mdot
.75905 .2307 Mdot
.76095 .35146 Mdot
.76286 .27318 Mdot
.76476 .43918 Mdot
.76667 .24606 Mdot
.76857 .3075 Mdot
.77048 .45473 Mdot
.77238 .40711 Mdot
.77429 .30381 Mdot
.77619 .25825 Mdot
.7781 .36844 Mdot
.78 .353 Mdot
.7819 .3057 Mdot
.78381 .4188 Mdot
.78571 .39327 Mdot
.78762 .45405 Mdot
.78952 .28408 Mdot
.79143 .33198 Mdot
.79333 .29534 Mdot
.79524 .26698 Mdot
.79714 .25637 Mdot
.79905 .29008 Mdot
.80095 .43926 Mdot
.80286 .44522 Mdot
.80476 .35129 Mdot
.80667 .29387 Mdot
.80857 .35384 Mdot
.81048 .28803 Mdot
.81238 .43985 Mdot
.81429 .31147 Mdot
.81619 .40637 Mdot
.8181 .32505 Mdot
.82 .35204 Mdot
.8219 .28334 Mdot
.82381 .29437 Mdot
.82571 .30287 Mdot
.82762 .35426 Mdot
.82952 .31911 Mdot
.83143 .41837 Mdot
.83333 .42621 Mdot
.83524 .27831 Mdot
.83714 .36947 Mdot
.83905 .27357 Mdot
.84095 .33662 Mdot
.84286 .36321 Mdot
.84476 .34796 Mdot
.84667 .4396 Mdot
.84857 .22148 Mdot
.85048 .2376 Mdot
.85238 .45138 Mdot
.85429 .24816 Mdot
.85619 .31071 Mdot
.8581 .3654 Mdot
.86 .44841 Mdot
.8619 .34339 Mdot
.86381 .2971 Mdot
.86571 .35148 Mdot
.86762 .30101 Mdot
.86952 .31551 Mdot
.87143 .25562 Mdot
.87333 .41122 Mdot
.87524 .34902 Mdot
.87714 .23384 Mdot
.87905 .3317 Mdot
.88095 .37268 Mdot
.88286 .33842 Mdot
.88476 .26015 Mdot
.88667 .26485 Mdot
.88857 .25659 Mdot
.89048 .43153 Mdot
.89238 .26779 Mdot
.89429 .32309 Mdot
.89619 .2479 Mdot
.8981 .30264 Mdot
.9 .38905 Mdot
.9019 .41249 Mdot
.90381 .26871 Mdot
.90571 .23508 Mdot
.90762 .26047 Mdot
.90952 .44301 Mdot
.91143 .45066 Mdot
.91333 .32307 Mdot
.91524 .23347 Mdot
.91714 .36337 Mdot
.91905 .24641 Mdot
.92095 .37562 Mdot
.92286 .24959 Mdot
.92476 .30272 Mdot
.92667 .34314 Mdot
.92857 .31114 Mdot
.93048 .38911 Mdot
.93238 .38786 Mdot
.93429 .29129 Mdot
.93619 .38609 Mdot
.9381 .33693 Mdot
.94 .30907 Mdot
.9419 .33014 Mdot
.94381 .3795 Mdot
.94571 .39014 Mdot
.94762 .2734 Mdot
.94952 .36923 Mdot
.95143 .3705 Mdot
.95333 .2633 Mdot
.95524 .29612 Mdot
.95714 .33942 Mdot
.95905 .31446 Mdot
.96095 .32402 Mdot
.96286 .46748 Mdot
.96476 .32466 Mdot
.96667 .25718 Mdot
.96857 .26452 Mdot
.97048 .40368 Mdot
.97238 .33643 Mdot
.97429 .36071 Mdot
.97619 .45144 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo03Oooooo0_l0003<ooooo`;o0000=Oooool000Kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo03Gooooo1?l0000`ooooo`;o0000V_ooool2o`0003Gooooo0006oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4
A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0=Oooool2o`0003;ooooo0_l0
003Aooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^
kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool2o`0004Wooooo0_l0
001;ooooo`;o0000=oooool4o`000003ooooool0003o0000057ooooo0006ooooo`05o`000?oooooo
ooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0
000Cooooo`;o0000<Oooool2o`0000?ooooo0_l0000Aooooo`;o00003oooool2o`0003[ooooo0_l0
0003ooooo`;o000000?oooooo`000?l000008Oooool2o`0000cooooo1?l000000ooooooo0000o`00
000Tooooo`;o00002_ooool2o`0001oooooo0006ooooo`05o`000?ooooooooooooooool000003_oo
ool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`16ooooo`;o00000oooool2o`0002;ooooo0_l0000oooooo`;o000000?oooooo`000?l00000
8Oooool2o`0003Oooooo0_l00007ooooo`;o000000?oooooo`000?l000007oooool000Kooooo00Go
410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`1=ooooo`;o000000?oooooo`000?l00000?Oooool2o`0002Oooooo
0_l0000Zooooo`;o00008?ooool2o`00013ooooo0_l0000Rooooo`001_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0??ooool2o`0000gooooo1?l000000ooooooo0000o`00000Yooooo`;o
00004_ooool3o`0000Oooooo0_l0000Mooooo`;o0000:_ooool2o`00023ooooo0_l0000dooooo`00
1_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co00001_ooool00ol0003oooooooooo`0cooooo`;o00001Oooool4o`0000gooooo0_l0000Zoooo
o`;o00000_ooool2o`0001?ooooo0_l00007ooooo`;o00005_ooool2o`0001Kooooo0_l0000Poooo
o`;o0000;oooool2o`0001kooooo000Yooooo`;o00008Oooool2o`00017ooooo0_l00005ooooo`;o
00008oooool2o`0001Kooooo0_l00008ooooo`;o00001_ooool2o`0002Kooooo0ol0000Eooooo`;o
00008?ooool2o`0001[ooooo0_l0000<ooooo`;o00001Oooool3o`0001gooooo000Yooooo`03o`00
0?oooooooooo00Oooooo0_l0000Gooooo`;o00006?ooool2o`0001Wooooo0_l00005ooooo`;o0000
00?oooooo`000?l000008?ooool2o`0000Gooooo0ol0000:ooooo`;o00005oooool2o`0000;ooooo
0_l0000Booooo`;o00001?ooool2o`0003Wooooo0_l0000<ooooo`;o00001_ooool2o`0001gooooo
000Yooooo`03o`000?oooooooooo00Oooooo0_l0000>ooooo`;o0000??ooool2o`0000Gooooo0_l0
0005ooooo`Co00008Oooool2o`0000_ooooo0ol0000>ooooo`;o00001_ooool2o`0001Kooooo0_l0
0004ooooo`;o00005Oooool2o`0002Sooooo0_l0000]ooooo`00:Oooool00ol0003oooooooooo`0G
ooooo`;o00003oooool4o`0000oooooo0_l0000Vooooo`Co00007_ooool2o`0000cooooo1Ol0000>
ooooo`?o00000_ooool2o`00013ooooo0_l0000Aooooo`;o00004Oooool2o`0000Wooooo0_l00005
ooooo`;o00005_ooool2o`0000?ooooo0_l0000Gooooo`;o00003oooool002Wooooo00?o0000oooo
ooooool0:?ooool4o`0000oooooo0_l00018ooooo`;o00003?ooool3o`00017ooooo0_l00002oooo
o`;o00004?ooool2o`0000[ooooo0_l00003ooooo`Co00007?ooool2o`0000Gooooo0_l0000Joooo
o`?o00001?ooool2o`00017ooooo0_l0000?ooooo`00:Oooool2o`0003Oooooo0_l0000;ooooo`;o
00008oooool2o`00013ooooo0_l0000Hooooo`;o00004Oooool2o`0001Gooooo0_l00008ooooo`?o
00000oooool2o`000003ooooool0003o000001;ooooo0_l0000Zooooo`?o00001?ooool2o`0000go
oooo0_l00003ooooo`;o00003_ooool002Wooooo0_l0000Tooooo`;o00004Oooool2o`0000_ooooo
0_l0000Dooooo`;o00003Oooool2o`000003ooooool0003o000000;o00002oooool2o`0001cooooo
0_l0000=ooooo`;o00005Oooool2o`0000Sooooo0_l00007ooooo`;o00004_ooool2o`0000gooooo
0_l0000Looooo`Co00004Oooool2o`0000?ooooo0_l0000>ooooo`00:Oooool4o`0002;ooooo1?l0
0007ooooo`Ko000000So410@o`000?l0003ok^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Eooooo`;o00004?ooool7o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h05_ooool2o`0000Kooooo0_l00008ooooo`03oiRH
V?l@413o000000;o00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0Zooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h0
0_l000001_ooooook^k^oc8b<_l0003o<S8bonk^kQSooooo0_l000000ooooooo0000o`00000<oooo
o`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool01?l0003oooooo`000?l0000>ooooo`;o0000
5?ooool2o`0000Oooooo0_l00002ooooo`03o`000?oooooooooo00;o000000GoMgMgoiRHV?oooooo
V9RHogMgM`02ooooo`?o000000?ooooooiRHV?mgMgL05?ooool2o`0001?ooooo00GoV9RHob4Q8Oo^
k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00[ooooo0_l0000?ooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo00?o
410@okZj^_ooool00_l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg02_ooooo0_l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Kooooo0_l0000Cooooo`;o00003?ooool2o`000003oooooomgMgOo
<S8b00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool002Wooooo00?o0000ooooooooool00_ooool2o`0000_ooooo0_l0000Qooooo`;o00000ooo
ool01Ol@413ooooooooooooooooo410@00;ooooo0ol00002ooooo`03oa0@4?oooooooooo01;ooooo
0_l000000ooooooo0000o`00000?ooooo`;o000000?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooo
oooooooooooo410@00?ooooo00Co410@oooooooooooooooo0_l00009ooooo`;o00003oooool4o`00
00Cooooo0_l00007ooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@00?ooooo00?o410@ooooooooool00_l0000Tooooo`Go00000oooool01Ol@413ooooooooo
oooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`;o00008Oooool2o`0000;o
oooo00Co0000oooooooooooo410@0oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@
ooooooooool00Oooool002Wooooo0_l00003ooooo`;o0000;_ooool2o`0000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000003Oooool2o`0000Sooooo0_l0
000:ooooo`;o00000oooool2o`000004oooooonHV9So8B4Qonk^kP?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`04o`000?ooooooooooooooo`;o00001_ooool2o`00017ooooo0_l000000ooo
oooo0000o`00000<ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000_ooool2o`0001Kooooo0_l0000<ooooo`04odA4A?oM
gMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000001Oooool2o`0002Gooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`01ooooo`00:Oooool00ol0003oooooooooo`0Y
ooooo`;o00001oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000gooooo0_l0000Dooooo`;o00001oooool00omgMgOoIVIV
ooooo`02ooooo`04o`000?ooooooooooooooo`;o00000_ooool01Ol0003ooooooooooooooooo0000
00Oooooo0_l0000Aooooo`;o00000_ooool2o`0000[ooooo00?o410@o`000?nj^[X00oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00000Jooooo`;o00003?oo
ool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000000oooool01_l0003o
oooooooooooooooo0000ooooo`;o00000_ooool2o`0002;ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?o
oooo000Yooooo`03o`000?oooooooooo02Sooooo1Ol00005ooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41008_ooool2o`00
00Wooooo00Go0000oooooooooooooooooa0@4003ooooo`;o00000_ooool01Ol@413ooooooooooooo
oooo410@01Kooooo0_l00006ooooo`;o00002oooool2o`0000?ooooo00Go410@oooooooooooooooo
oa0@4003ooooo`05oa0@4?ooooooooooooooool@4100:Oooool00omgMgOoc<c<o`000004ooooo`03
oa0@4?oooooooooo00;o00000oooool01_l@413ooooooooooooooooo410@ooooo`;o00009_ooool0
0ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooo
oooooooo410@00?ooooo000Yooooo`04o`000?ooooooooooooooo`;o00009Oooool2o`000003oooo
ool0003o000000Gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Rooooo`;o00001Oooool01_l0003o^[ZjoooooonHV9So
410@ooooo`;o000000?oMgMgoiRHV?ooool00_l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
5_ooool2o`00013ooooo00?o410@oiRHV?ooool00_l00003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg02Wooooo00?ok^k^odA4A?l000001?ooool00omg
MgOoV9RHooooo`02o`0000;ooooo0_l000001?nHV9So0000o`000?mgMgLYooooo`03o`000?oooooo
oooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool002Wooooo00Co0000oooooooooooooooo0_l0000Iooooo`;o00004_ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool2o`000004oc8b<_l0003o<S8bonk^
kRWooooo00KoV9RHoa0@4?l0003o8B4Qolc<c?ooool2o`000003onk^k_lb<S;o000000;o00000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo0_l0000Kooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Z
ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`;o000000Co
<S8bo`000?l0003ok^k^9Oooool2o`0000;ooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Yooooo`;o00006oooool4o`00023o
oooo1?l0000gooooo`;o00003?ooool2o`0000Cooooo0_l0000looooo`;o00001_ooool3o`0001ko
oooo0_l00002ooooo`;o00001?ooool2o`00027ooooo0_l00005ooooo`;o00004_ooool002Wooooo
00?o0000ooooooooool06_ooool4o`0002;ooooo0_l0000:ooooo`;o0000:oooool2o`0000cooooo
0_l0000looooo`;o00001?ooool2o`0000Kooooo0ol0000Nooooo`;o00000_ooool2o`0000Cooooo
0_l0000:ooooo`;o00007?ooool2o`0001;ooooo000Yooooo`03o`000?oooooooooo01Sooooo0_l0
000booooo`;o0000Moooool3o`00013ooooo0_l000000ooooooo0000o`00000]ooooo`Co0000;_oo
ool002Wooooo00?o0000ooooooooool06?ooool2o`0001kooooo0_l0001`ooooo`;o00003_ooool2
o`0000[ooooo0ol00002ooooo`;o00002oooool2o`000003ooooool0003o0000017ooooo1?l0000<
ooooo`;o00003?ooool2o`0000Oooooo0_l00007ooooo`;o00007?ooool002Wooooo00?o0000oooo
ooooool0<Oooool3o`0000Cooooo0_l0000mooooo`;o0000;oooool4o`0000kooooo0_l00007oooo
o`;o00000_ooool2o`0000;ooooo0_l0000Aooooo`;o00003?ooool6o`0000cooooo0_l0000Eoooo
o`;o00001oooool2o`0001cooooo000Qoooooooo0000A?l00004ooooo`00:Oooool3o`0000Kooooo
1?l00007ooooo`;o00000oooool00ol0003oooooooooo`02o`0000Oooooo00?o0000ooooooooool0
2?ooool2o`0000Cooooo0_l00003ooooo`?o00003?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Oooooo1Ol00009ooooo`03o`000?oooooooooo00Sooooo0ol0000;ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool3o`0000[ooooo00?o0000ooooooooool0
1oooool3o`0000Gooooo0_l00002ooooo`?o00002oooool00ol0003oooooooooo`0:ooooo`04o`00
0?ooooooooooooooo`;o00001_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Go
oooo0_l00002ooooo`03o`000?oooooooooo00Oooooo0_l000000ooooooo0000ooooo`0:ooooo`03
o`000?oooooooooo00Gooooo0_l00002ooooo`;o00001?ooool2o`0000Cooooo00?o0000oooooooo
ool02_ooool002Wooooo00?o0000ooooooooool01Oooool2o`000003ooooool0003o000000?ooooo
0_l00002ooooo`;o00001_ooool2o`0000Kooooo0_l0000@ooooo`;o00000oooool3o`0001Wooooo
0_l0000:ooooo`;o00005_ooool00ol0003oooooooooo`0Aooooo`;o00002Oooool2o`0000Cooooo
0_l0000Dooooo`?o0000:?ooool4o`000003ooooool0003o000000gooooo00?o0000ooooooooool0
5oooool2o`0001_ooooo0_l00004ooooo`03o`000?oooooooooo00[ooooo000Yooooo`03o`000?oo
oooooooo00Gooooo0_l00006ooooo`;o00004_ooool4o`000003ooooool0003o000000;ooooo0_l0
000:ooooo`;o00007?ooool2o`0000;ooooo0_l0000booooo`;o00002Oooool2o`00027ooooo0_l0
000Tooooo`;o000000?oooooo`000?l000006_ooool2o`0000_ooooo0_l0000^ooooo`00:Oooool0
0ol0003oooooooooo`0:ooooo`;o00005oooool2o`000003ooooool0003o000000;ooooo0_l0000:
ooooo`;o00008?ooool2o`0002;ooooo0_l00006ooooo`;o00006oooool2o`0001Oooooo0_l00013
ooooo`;o00004oooool2o`0000Cooooo0_l0000>ooooo`;o00004?ooool002Wooooo0_l0000;oooo
o`;o00002?ooool2o`0002Oooooo0_l0000Dooooo`;o00009oooool2o`0000Kooooo0_l0000Koooo
o`;o0000FOooool2o`0001Kooooo0_l00004ooooo`;o00003_ooool3o`0000oooooo000Yooooo`03
o`000?oooooooooo01Cooooo0_l0000Wooooo`;o00005?ooool2o`0001Wooooo0_l0000Cooooo`;o
00001_ooool2o`0001Sooooo0_l00008ooooo`;o00003oooool2o`0001?ooooo0_l0000Uooooo`;o
00009Oooool2o`0000Kooooo0_l0000?ooooo`00:Oooool00ol0003oooooooooo`0Jooooo`;o0000
=?ooool2o`0000;ooooo0_l0000Hooooo`;o00003Oooool2o`0000Cooooo0_l00006ooooo`;o0000
6?ooool2o`0000Sooooo0_l0000?ooooo`;o00004oooool2o`0001cooooo0_l0000Jooooo`;o0000
4_ooool2o`0001Oooooo000Yooooo`03o`000?oooooooooo01[ooooo0_l0000Cooooo`;o00007ooo
ool2o`0000;ooooo0_l0000Wooooo`;o0000:oooool2o`0001Oooooo0_l0000^ooooo`;o00003_oo
ool2o`0000[ooooo0_l0000Looooo`;o00003Oooool002Wooooo00?o0000ooooooooool06?ooool2
o`0001?ooooo1?l0000@ooooo`;o0000>_ooool2o`0002Wooooo1?l0000:ooooo`;o00002oooool2
o`0003kooooo0_l0000;ooooo`;o00004?ooool2o`0000Cooooo0_l00003ooooo`;o00003Oooool0
02Wooooo1?l00002ooooo`;o00003oooool6o`0000gooooo0_l00004ooooo`;o00004_ooool2o`00
00Kooooo0_l0000Uooooo`;o00002oooool2o`0002Wooooo0_l0000<ooooo`;o00007?ooool2o`00
017ooooo0_l0000Wooooo`;o00004?ooool2o`0000Cooooo0_l0000Booooo`00:Oooool01?l0003o
ooooo`000?l00002ooooo`;o00003oooool4o`0000oooooo0_l0000Hooooo`;o00001_ooool2o`00
00;ooooo0_l0000Eooooo`;o00002_ooool2o`0000cooooo0_l0000?ooooo`;o0000>Oooool2o`00
00?ooooo0_l00003ooooo`;o00004?ooool3o`00027ooooo0_l0000Cooooo`;o00006oooool002Wo
oooo00?o0000ooooooooool02_ooool2o`0000Cooooo0_l0000@ooooo`;o00003?ooool2o`0000oo
oooo0_l0000:ooooo`;o00005Oooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o
00003Oooool2o`0000oooooo0_l0000iooooo`;o00000oooool2o`0000Oooooo0_l0000<ooooo`;o
00007?ooool2o`0000Cooooo0_l00002ooooo`;o00003oooool2o`0001_ooooo000Yooooo`03o`00
0?oooooooooo00;ooooo0_l00006ooooo`;o000000Coooooo`000?l0003ooooo0_l0000@ooooo`;o
00003?ooool2o`0003Gooooo0_l00002ooooo`;o00000_ooool2o`0001cooooo0_l00005ooooo`;o
00001?ooool2o`0000;ooooo0_l0000Hooooo`;o00002oooool2o`0000_ooooo0_l00004ooooo`;o
00003oooool2o`0000cooooo0_l00003ooooo`;o00001_ooool2o`0000Gooooo0_l000000ooooooo
0000o`00000/ooooo`00:Oooool00ol0003oooooooooo`02ooooo`;o00002Oooool2o`0003Wooooo
0_l0000@ooooo`Co00009oooool2o`0000Kooooo0_l00005ooooo`;o00001?ooool2o`0000;ooooo
0_l0000Hooooo`;o00002oooool2o`0000_ooooo0_l0000Eooooo`;o00001?ooool2o`0000Kooooo
1?l000001?oooooo0000o`000?ooool2o`0000[ooooo0_l0000_ooooo`00:Oooool2o`0000oooooo
0_l0000;ooooo`;o00009oooool2o`0000;ooooo0_l0000@ooooo`Co00003?ooool2o`0001Kooooo
0_l000000ooooooo0000o`00001Xooooo`;o00002?ooool2o`0000Cooooo0_l0000kooooo`00:Ooo
ool00ol0003oooooooooo`0>ooooo`;o00002oooool2o`0002Oooooo0_l0000Tooooo`;o00004ooo
ool2o`000003ooooool0003o000003Sooooo0_l0001`ooooo`;o00003?ooool002Wooooo00?o0000
ooooooooool04_ooool2o`0001Sooooo0_l0000aooooo`;o00007_ooool2o`0002;ooooo0_l00004
ooooo`;o00004Oooool2o`00013ooooo0_l0000dooooo`;o00005_ooool2o`00013ooooo0_l0000<
ooooo`00:Oooool00ol0003oooooooooo`0Booooo`;o00006?ooool2o`0001Oooooo0_l0000Hoooo
o`;o0000@_ooool2o`0000Cooooo0_l0000Sooooo`Co00003oooool2o`00027ooooo0_l00003oooo
o`;o00004Oooool2o`0001kooooo000Yooooo`03o`000?oooooooooo01gooooo0_l00006ooooo`;o
00001?ooool2o`0001Sooooo0_l0000:ooooo`;o00004oooool2o`0003;ooooo0_l0000Oooooo`;o
00004oooool2o`0000oooooo0_l0000<ooooo`;o00004Oooool2o`0000Gooooo0_l0000Kooooo`?o
00004oooool002Wooooo0_l0000=ooooo`;o00003oooool2o`0000Kooooo0_l00004ooooo`;o0000
9?ooool2o`0001?ooooo0_l0000Dooooo`;o00007?ooool2o`0001oooooo0_l0000Fooooo`;o0000
3Oooool2o`0000_ooooo0_l0000Aooooo`;o00003?ooool2o`0001Cooooo0ol0000Cooooo`00:Ooo
ool00ol0003oooooooooo`09ooooo`;o000000?oooooo`000?l00000K_ooool2o`0005Gooooo0_l0
0004ooooo`;o00001oooool2o`0002cooooo0_l0000;ooooo`;o00007Oooool000Kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8b
omgMg@05ooooo`03o`000?oooooooooo00Wooooo0_l0000^ooooo`;o00002_ooool2o`0000Oooooo
0_l00010ooooo`;o0000<_ooool2o`0001?ooooo0_l00012ooooo`;o00001Oooool2o`0001Kooooo
0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool00_l0000Kooooo`;o
00006_ooool2o`0000[ooooo0_l000000ooooooo0000o`000004ooooo`;o00003_ooool2o`00033o
oooo0ol0000Zooooo`;o00001Oooool2o`0005kooooo0_l0000Fooooo`001_ooool01Ol@413ooooo
oooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;o00006oooool3o`0000;ooooo0_l0000Rooooo`Ko00004_ooool2o`00037o
oooo0_l0000?ooooo`;o00006Oooool2o`0000kooooo0_l0001Cooooo`;o00006?ooool000Kooooo
00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_oo
ool01?ooool3o`0000Cooooo0_l0000Aooooo`;o00001Oooool3o`000003ooooool0003o000002;o
oooo0_l00002ooooo`;o00000oooool2o`0000Gooooo0_l0000:ooooo`;o00003_ooool2o`0001ko
oooo0_l00007ooooo`;o00001Oooool4o`0002Oooooo0_l00017ooooo`;o00002?ooool4o`0001So
oooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`04ooooo`;o000000?oooooo`00
0?l000003_ooool2o`0000Kooooo0_l0000^ooooo`;o00001Oooool2o`0000[ooooo0_l0000=oooo
o`Go00007?ooool2o`0000Oooooo0_l00006ooooo`?o00004Oooool2o`0001Cooooo0_l00008oooo
o`;o0000?Oooool2o`0000Sooooo0_l00003ooooo`;o00005Oooool000Kooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`Co00001oooool2o`0002kooooo0_l0000]ooooo`;o000000?oooooo`00
0?l00000;Oooool2o`0001;ooooo0_l0000Nooooo`;o00006?ooool2o`0003;ooooo0_l0000Eoooo
o`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool4o`0000Gooooo0_l0000^
ooooo`;o00007oooool2o`0008cooooo0_l00019ooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003ooooooooo
o`0;ooooo`;o0000BOooool2o`0000?ooooo0_l00006ooooo`;o0000Coooool2o`0008Kooooo000Y
ooooo`;o00004?ooool2o`0004Gooooo0_l00003ooooo`;o00001?ooool2o`00057ooooo0_l0000K
ooooo`;o0000F_ooool2o`0000gooooo000Yooooo`03o`000?oooooooooo00oooooo0_l0000Foooo
o`;o00005oooool2o`0000Oooooo0_l0000Fooooo`;o00009oooool2o`0002;ooooo0_l0000Qoooo
o`;o00006_ooool2o`0000cooooo0_l0000`ooooo`;o00003Oooool002Wooooo00?o0000oooooooo
ool09oooool2o`0001Oooooo0_l00005ooooo`Co0000??ooool2o`000003ooooool0003o000001?o
oooo0_l0000=ooooo`;o0000?Oooool2o`0000cooooo0_l0000@ooooo`;o0000;Oooool002Wooooo
00?o0000ooooooooool0;_ooool4o`0001Gooooo0_l0000nooooo`;o00005_ooool2o`0000oooooo
0_l00003ooooo`;o0000:_ooool2o`0002[ooooo0_l00008ooooo`;o00008oooool002Wooooo00?o
0000ooooooooool04?ooool2o`0001;ooooo0_l00008ooooo`Co00002oooool2o`0002Gooooo0_l0
000Jooooo`;o00001?ooool2o`0000Kooooo0_l00002ooooo`;o00007?ooool2o`0000?ooooo0_l0
000Tooooo`;o00001?ooool2o`0003Cooooo0_l0000Sooooo`00:Oooool2o`00017ooooo0_l0000B
ooooo`;o00005oooool2o`0002Gooooo0_l00003ooooo`;o00005Oooool2o`0000Cooooo0_l00006
ooooo`;o00000_ooool2o`0004Oooooo0_l0000Dooooo`;o00003Oooool2o`0003[ooooo000Yoooo
o`03o`000?oooooooooo06Wooooo0_l00009ooooo`;o0000B_ooool2o`0002oooooo0_l0000=oooo
o`;o0000>_ooool002Wooooo00?o0000ooooooooool0FOooool2o`0001Oooooo1?l0001:ooooo`;o
0000?oooool2o`0003Wooooo000Yooooo`03o`000?oooooooooo05;ooooo0_l00005ooooo`;o0000
5oooool2o`0004kooooo0_l0000mooooo`;o0000>Oooool002Wooooo00Co0000oooooooooooooooo
0_l0001?ooooo`;o0000B?ooool2o`00023ooooo0_l00002ooooo`;o00006oooool2o`0003;ooooo
0_l0000Wooooo`00:Oooool2o`0000;ooooo0_l0000Looooo`;o0000Noooool2o`00023ooooo0_l0
000Oooooo`;o0000<_ooool2o`0002Oooooo000Yooooo`03o`000?oooooooooo01oooooo0_l0003:
ooooo`;o00002Oooool2o`0004Cooooo000Yooooo`03o`000?oooooooooo0:cooooo0_l0000Joooo
o`;o00008Oooool2o`0000Wooooo0_l00002ooooo`;o00002Oooool2o`0003Gooooo000Yooooo`03
o`000?oooooooooo03_ooooo0_l0001_ooooo`;o00001?ooool2o`000003ooooool0003o0000017o
oooo0_l0000<ooooo`;o00000_ooool2o`0001_ooooo0_l000000ooooooo0000o`000009ooooo`;o
00004_ooool2o`00027ooooo000Yooooo`03o`000?oooooooooo00Cooooo0ol0000]ooooo`;o0000
1Oooool2o`0001Kooooo0_l0000Qooooo`;o00003?ooool2o`0000Cooooo0_l0000Vooooo`;o0000
00?oooooo`000?l000007oooool2o`0000;ooooo0_l00003ooooo`;o00005_ooool2o`00013ooooo
0_l0000>ooooo`;o00008Oooool002Wooooo0_l00005ooooo`?o00001Oooool2o`0000Oooooo0_l0
000Mooooo`;o00006?ooool2o`0000?ooooo0_l0000Pooooo`?o00003?ooool2o`0000Cooooo0_l0
000;ooooo`;o00008?ooool2o`00027ooooo0_l000000ooooooo0000o`000006ooooo`;o00007_oo
ool4o`0000oooooo0_l0000Cooooo`;o00002oooool002Wooooo00?o0000ooooooooool03?ooool2
o`0000Oooooo0_l0000gooooo`;o00007?ooool4o`0000Gooooo0_l0000Pooooo`;o00008?ooool2
o`0000Kooooo0_l0000Iooooo`?o00002?ooool2o`0000?ooooo0_l00004ooooo`;o00004oooool2
o`00017ooooo0_l0000Cooooo`;o00002oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool05Ooo
ool2o`0004[ooooo0_l00009ooooo`Co000000?oooooo`000?l000003oooool2o`0003gooooo0_l0
000Iooooo`?o00003Oooool2o`0000Cooooo0_l00018ooooo`003_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0HOoo
ool2o`0000kooooo0_l0000?ooooo`;o0000^?ooool000kooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo000>ooooo`05o`000?oooooo
ooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Ooo
ool000kooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`3oooooob_ooooo0_l0000@ooooo`003_ooool01Ol@413ooooooooo
oooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`13ooooo`;o0000
iOooool2o`00013ooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo04?ooooo0_l0003gooooo`003_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooooooo
o`3Xooooo`;o0000D_ooool002Wooooo00?o0000ooooooooool0j?ooool2o`0005;ooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0Eoooool2o`000>?o
oooo000Yooooo`;o0000F?ooool2o`000>?ooooo000Yooooo`03o`000?oooooooooo0;Kooooo0_l0
0024ooooo`00:Oooool00ol0003oooooooooo`2fooooo`;o0000Q?ooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000
oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@
400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo?Ooo
ool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05o`000?oooooo
ooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@4100
3_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooo
oooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`00
1_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000?oo
oooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oo
oooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Oooooo`Co000000?o410@
ooooooooool00oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`?o
0000oooooolmooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Oooooo`03oeEEEOmVIVKo00000?ooooooAoooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .35415 Mdot
.02762 .25368 Mdot
.02952 .28131 Mdot
.03143 .30969 Mdot
.03333 .26391 Mdot
.03524 .39015 Mdot
.03714 .31934 Mdot
.03905 .36191 Mdot
.04095 .24626 Mdot
.04286 .26429 Mdot
.04476 .28324 Mdot
.04667 .39929 Mdot
.04857 .31017 Mdot
.05048 .25797 Mdot
.05238 .4103 Mdot
.05429 .34367 Mdot
.05619 .27987 Mdot
.0581 .31776 Mdot
.06 .35507 Mdot
.0619 .42228 Mdot
.06381 .3285 Mdot
.06571 .23969 Mdot
.06762 .25753 Mdot
.06952 .33333 Mdot
.07143 .44182 Mdot
.07333 .3497 Mdot
.07524 .32146 Mdot
.07714 .35519 Mdot
.07905 .41564 Mdot
.08095 .24645 Mdot
.08286 .35519 Mdot
.08476 .24304 Mdot
.08667 .33618 Mdot
.08857 .24509 Mdot
.09048 .29358 Mdot
.09238 .4195 Mdot
.09429 .31783 Mdot
.09619 .35358 Mdot
.0981 .40084 Mdot
.1 .40831 Mdot
.1019 .44272 Mdot
.10381 .26237 Mdot
.10571 .35859 Mdot
.10762 .34508 Mdot
.10952 .37536 Mdot
.11143 .26582 Mdot
.11333 .25662 Mdot
.11524 .22924 Mdot
.11714 .37252 Mdot
.11905 .4135 Mdot
.12095 .22998 Mdot
.12286 .38378 Mdot
.12476 .24564 Mdot
.12667 .33319 Mdot
.12857 .33855 Mdot
.13048 .28893 Mdot
.13238 .36914 Mdot
.13429 .28493 Mdot
.13619 .25865 Mdot
.1381 .38143 Mdot
.14 .28035 Mdot
.1419 .44776 Mdot
.14381 .39626 Mdot
.14571 .31755 Mdot
.14762 .33814 Mdot
.14952 .26246 Mdot
.15143 .26921 Mdot
.15333 .34294 Mdot
.15524 .35483 Mdot
.15714 .35227 Mdot
.15905 .2678 Mdot
.16095 .27145 Mdot
.16286 .26014 Mdot
.16476 .29919 Mdot
.16667 .39631 Mdot
.16857 .31389 Mdot
.17048 .24602 Mdot
.17238 .31952 Mdot
.17429 .39436 Mdot
.17619 .37045 Mdot
.1781 .39884 Mdot
.18 .24938 Mdot
.1819 .29217 Mdot
.18381 .26804 Mdot
.18571 .32707 Mdot
.18762 .3443 Mdot
.18952 .25869 Mdot
.19143 .24998 Mdot
.19333 .30847 Mdot
.19524 .3428 Mdot
.19714 .44312 Mdot
.19905 .28599 Mdot
.20095 .27414 Mdot
.20286 .25241 Mdot
.20476 .28759 Mdot
.20667 .31413 Mdot
.20857 .25618 Mdot
.21048 .22899 Mdot
.21238 .25631 Mdot
.21429 .30728 Mdot
.21619 .33734 Mdot
.2181 .3351 Mdot
.22 .39905 Mdot
.2219 .32808 Mdot
.22381 .38466 Mdot
.22571 .24902 Mdot
.22762 .25337 Mdot
.22952 .34807 Mdot
.23143 .27305 Mdot
.23333 .35577 Mdot
.23524 .25496 Mdot
.23714 .30274 Mdot
.23905 .24084 Mdot
.24095 .42307 Mdot
.24286 .40221 Mdot
.24476 .3058 Mdot
.24667 .30058 Mdot
.24857 .27645 Mdot
.25048 .25881 Mdot
.25238 .32014 Mdot
.25429 .31009 Mdot
.25619 .45727 Mdot
.2581 .30512 Mdot
.26 .41511 Mdot
.2619 .35564 Mdot
.26381 .32333 Mdot
.26571 .42185 Mdot
.26762 .34681 Mdot
.26952 .28491 Mdot
.27143 .26413 Mdot
.27333 .25361 Mdot
.27524 .31411 Mdot
.27714 .41572 Mdot
.27905 .39246 Mdot
.28095 .37322 Mdot
.28286 .40484 Mdot
.28476 .33876 Mdot
.28667 .41881 Mdot
.28857 .26195 Mdot
.29048 .3587 Mdot
.29238 .41358 Mdot
.29429 .41818 Mdot
.29619 .26365 Mdot
.2981 .35722 Mdot
.3 .27972 Mdot
.3019 .42375 Mdot
.30381 .30769 Mdot
.30571 .44709 Mdot
.30762 .33763 Mdot
.30952 .25274 Mdot
.31143 .46235 Mdot
.31333 .34344 Mdot
.31524 .34271 Mdot
.31714 .33597 Mdot
.31905 .27805 Mdot
.32095 .39168 Mdot
.32286 .353 Mdot
.32476 .39268 Mdot
.32667 .2783 Mdot
.32857 .3156 Mdot
.33048 .34985 Mdot
.33238 .36944 Mdot
.33429 .39578 Mdot
.33619 .44082 Mdot
.3381 .41543 Mdot
.34 .35799 Mdot
.3419 .34094 Mdot
.34381 .30187 Mdot
.34571 .39416 Mdot
.34762 .35314 Mdot
.34952 .35729 Mdot
.35143 .41684 Mdot
.35333 .26333 Mdot
.35524 .34634 Mdot
.35714 .25685 Mdot
.35905 .33004 Mdot
.36095 .34236 Mdot
.36286 .32448 Mdot
.36476 .39177 Mdot
.36667 .30841 Mdot
.36857 .41081 Mdot
.37048 .37418 Mdot
.37238 .42225 Mdot
.37429 .32583 Mdot
.37619 .44573 Mdot
.3781 .28882 Mdot
.38 .24244 Mdot
.3819 .34794 Mdot
.38381 .23747 Mdot
.38571 .43736 Mdot
.38762 .36704 Mdot
.38952 .4597 Mdot
.39143 .42405 Mdot
.39333 .33092 Mdot
.39524 .44998 Mdot
.39714 .34453 Mdot
.39905 .45517 Mdot
.40095 .4065 Mdot
.40286 .24974 Mdot
.40476 .2492 Mdot
.40667 .24294 Mdot
.40857 .32442 Mdot
.41048 .32316 Mdot
.41238 .26815 Mdot
.41429 .26781 Mdot
.41619 .23364 Mdot
.4181 .32573 Mdot
.42 .32934 Mdot
.4219 .39268 Mdot
.42381 .29754 Mdot
.42571 .31231 Mdot
.42762 .28913 Mdot
.42952 .26894 Mdot
.43143 .31315 Mdot
.43333 .39497 Mdot
.43524 .33303 Mdot
.43714 .33582 Mdot
.43905 .30026 Mdot
.44095 .44224 Mdot
.44286 .29058 Mdot
.44476 .38364 Mdot
.44667 .39762 Mdot
.44857 .29473 Mdot
.45048 .24855 Mdot
.45238 .38821 Mdot
.45429 .40633 Mdot
.45619 .33906 Mdot
.4581 .2965 Mdot
.46 .26875 Mdot
.4619 .26636 Mdot
.46381 .41155 Mdot
.46571 .45705 Mdot
.46762 .34238 Mdot
.46952 .28226 Mdot
.47143 .22922 Mdot
.47333 .35804 Mdot
.47524 .31833 Mdot
.47714 .45805 Mdot
.47905 .35068 Mdot
.48095 .31628 Mdot
.48286 .29858 Mdot
.48476 .32222 Mdot
.48667 .44677 Mdot
.48857 .3821 Mdot
.49048 .40782 Mdot
.49238 .26851 Mdot
.49429 .24351 Mdot
.49619 .29547 Mdot
.4981 .35528 Mdot
.5 .32373 Mdot
.5019 .27176 Mdot
.50381 .39624 Mdot
.50571 .45312 Mdot
.50762 .30785 Mdot
.50952 .32994 Mdot
.51143 .34131 Mdot
.51333 .35314 Mdot
.51524 .34374 Mdot
.51714 .35048 Mdot
.51905 .31187 Mdot
.52095 .36247 Mdot
.52286 .23835 Mdot
.52476 .36703 Mdot
.52667 .31767 Mdot
.52857 .41031 Mdot
.53048 .27551 Mdot
.53238 .3454 Mdot
.53429 .36456 Mdot
.53619 .26153 Mdot
.5381 .38294 Mdot
.54 .41908 Mdot
.5419 .36483 Mdot
.54381 .42135 Mdot
.54571 .34634 Mdot
.54762 .26621 Mdot
.54952 .3701 Mdot
.55143 .357 Mdot
.55333 .32172 Mdot
.55524 .32425 Mdot
.55714 .22838 Mdot
.55905 .28168 Mdot
.56095 .39307 Mdot
.56286 .40635 Mdot
.56476 .26334 Mdot
.56667 .3142 Mdot
.56857 .31482 Mdot
.57048 .39004 Mdot
.57238 .34653 Mdot
.57429 .29903 Mdot
.57619 .29532 Mdot
.5781 .42218 Mdot
.58 .25804 Mdot
.5819 .39153 Mdot
.58381 .34726 Mdot
.58571 .26465 Mdot
.58762 .39718 Mdot
.58952 .25958 Mdot
.59143 .31241 Mdot
.59333 .28193 Mdot
.59524 .45177 Mdot
.59714 .41819 Mdot
.59905 .40561 Mdot
.60095 .46472 Mdot
.60286 .37249 Mdot
.60476 .36991 Mdot
.60667 .30925 Mdot
.60857 .24386 Mdot
.61048 .4395 Mdot
.61238 .26038 Mdot
.61429 .22864 Mdot
.61619 .35799 Mdot
.6181 .32377 Mdot
.62 .26726 Mdot
.6219 .27003 Mdot
.62381 .30223 Mdot
.62571 .46225 Mdot
.62762 .29592 Mdot
.62952 .37793 Mdot
.63143 .252 Mdot
.63333 .35078 Mdot
.63524 .27299 Mdot
.63714 .42497 Mdot
.63905 .45639 Mdot
.64095 .4076 Mdot
.64286 .33708 Mdot
.64476 .39353 Mdot
.64667 .27052 Mdot
.64857 .38607 Mdot
.65048 .2945 Mdot
.65238 .32671 Mdot
.65429 .31862 Mdot
.65619 .26084 Mdot
.6581 .38474 Mdot
.66 .34362 Mdot
.6619 .29071 Mdot
.66381 .25172 Mdot
.66571 .26391 Mdot
.66762 .26786 Mdot
.66952 .26434 Mdot
.67143 .38828 Mdot
.67333 .35865 Mdot
.67524 .3694 Mdot
.67714 .27448 Mdot
.67905 .22806 Mdot
.68095 .35783 Mdot
.68286 .2595 Mdot
.68476 .31543 Mdot
.68667 .31675 Mdot
.68857 .31439 Mdot
.69048 .41969 Mdot
.69238 .2383 Mdot
.69429 .25957 Mdot
.69619 .27446 Mdot
.6981 .42015 Mdot
.7 .39609 Mdot
.7019 .28666 Mdot
.70381 .42014 Mdot
.70571 .37338 Mdot
.70762 .24341 Mdot
.70952 .41848 Mdot
.71143 .35242 Mdot
.71333 .39571 Mdot
.71524 .40566 Mdot
.71714 .40993 Mdot
.71905 .41406 Mdot
.72095 .42771 Mdot
.72286 .44582 Mdot
.72476 .27146 Mdot
.72667 .36411 Mdot
.72857 .41479 Mdot
.73048 .3645 Mdot
.73238 .27506 Mdot
.73429 .38027 Mdot
.73619 .35779 Mdot
.7381 .39369 Mdot
.74 .34286 Mdot
.7419 .22933 Mdot
.74381 .31757 Mdot
.74571 .29944 Mdot
.74762 .36336 Mdot
.74952 .25229 Mdot
.75143 .30313 Mdot
.75333 .24959 Mdot
.75524 .43475 Mdot
.75714 .42067 Mdot
.75905 .30189 Mdot
.76095 .39189 Mdot
.76286 .28353 Mdot
.76476 .45494 Mdot
.76667 .31622 Mdot
.76857 .3172 Mdot
.77048 .42541 Mdot
.77238 .35512 Mdot
.77429 .32688 Mdot
.77619 .28804 Mdot
.7781 .33363 Mdot
.78 .32677 Mdot
.7819 .22804 Mdot
.78381 .39241 Mdot
.78571 .45008 Mdot
.78762 .4248 Mdot
.78952 .24823 Mdot
.79143 .22284 Mdot
.79333 .24452 Mdot
.79524 .3336 Mdot
.79714 .32242 Mdot
.79905 .27297 Mdot
.80095 .38 Mdot
.80286 .39724 Mdot
.80476 .31887 Mdot
.80667 .26022 Mdot
.80857 .3193 Mdot
.81048 .33899 Mdot
.81238 .46021 Mdot
.81429 .24975 Mdot
.81619 .4156 Mdot
.8181 .27103 Mdot
.82 .34466 Mdot
.8219 .26873 Mdot
.82381 .25017 Mdot
.82571 .24428 Mdot
.82762 .33045 Mdot
.82952 .33175 Mdot
.83143 .46004 Mdot
.83333 .35627 Mdot
.83524 .28915 Mdot
.83714 .30396 Mdot
.83905 .25318 Mdot
.84095 .38665 Mdot
.84286 .36271 Mdot
.84476 .3493 Mdot
.84667 .45624 Mdot
.84857 .29493 Mdot
.85048 .30349 Mdot
.85238 .36498 Mdot
.85429 .33702 Mdot
.85619 .33421 Mdot
.8581 .26048 Mdot
.86 .41846 Mdot
.8619 .29135 Mdot
.86381 .23812 Mdot
.86571 .23213 Mdot
.86762 .25945 Mdot
.86952 .32335 Mdot
.87143 .31999 Mdot
.87333 .40963 Mdot
.87524 .37076 Mdot
.87714 .26464 Mdot
.87905 .30159 Mdot
.88095 .31319 Mdot
.88286 .25753 Mdot
.88476 .30289 Mdot
.88667 .29736 Mdot
.88857 .30964 Mdot
.89048 .36302 Mdot
.89238 .28506 Mdot
.89429 .40049 Mdot
.89619 .27085 Mdot
.8981 .37502 Mdot
.9 .4219 Mdot
.9019 .38241 Mdot
.90381 .25731 Mdot
.90571 .35189 Mdot
.90762 .28263 Mdot
.90952 .3875 Mdot
.91143 .45319 Mdot
.91333 .26267 Mdot
.91524 .2834 Mdot
.91714 .36381 Mdot
.91905 .29344 Mdot
.92095 .4204 Mdot
.92286 .33742 Mdot
.92476 .35217 Mdot
.92667 .2758 Mdot
.92857 .24446 Mdot
.93048 .45125 Mdot
.93238 .37176 Mdot
.93429 .31475 Mdot
.93619 .35147 Mdot
.9381 .37078 Mdot
.94 .26923 Mdot
.9419 .33974 Mdot
.94381 .32893 Mdot
.94571 .37022 Mdot
.94762 .31789 Mdot
.94952 .34549 Mdot
.95143 .26488 Mdot
.95333 .26906 Mdot
.95524 .37106 Mdot
.95714 .35709 Mdot
.95905 .35369 Mdot
.96095 .29226 Mdot
.96286 .39286 Mdot
.96476 .29844 Mdot
.96667 .25878 Mdot
.96857 .24424 Mdot
.97048 .41654 Mdot
.97238 .35607 Mdot
.97429 .41603 Mdot
.97619 .41467 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0??ooooo0_l00017ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0??ooooo0_l00017ooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06_oo
ool4o`0001[ooooo0_l0001Booooo`;o00006_ooool2o`00013ooooo0_l0000Cooooo`;o00004_oo
ool2o`0000_ooooo0_l0001:ooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o00006_ooool4o`0001[ooooo0_l0
0010ooooo`;o00004?ooool2o`0001[ooooo0_l0000@ooooo`;o00004oooool2o`0001;ooooo0_l0
000;ooooo`;o00006Oooool2o`0002oooooo0006ooooo`05o`000?ooooooooooooooool000003_oo
ool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`1jooooo`;o0000Soooool2o`0002oooooo0006ooooo`05oa0@4?ooooooooooooooool@4100
3oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2_ooool2o`0006Cooooo0_l0000[ooooo`;o0000=?ooool2o`0003Gooooo0_l0000`ooooo`001_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool2o`0000Cooooo0_l0000_ooooo`;o
0000;?ooool3o`0000Gooooo0_l0000Kooooo`;o00001oooool2o`0003Cooooo0_l00003ooooo`;o
0000<?ooool2o`00033ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So
410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo00;ooooo0_l0000;oooo
o`Co00002_ooool2o`0000cooooo0_l0000Dooooo`;o0000;?ooool2o`0000Kooooo0_l0000Koooo
o`;o00008_ooool2o`0001kooooo0_l0000Jooooo`;o00002?ooool2o`0001oooooo0_l0000;oooo
o`;o00003_ooool002Wooooo0_l00003ooooo`;o00002oooool4o`0000[ooooo0_l0000<ooooo`;o
000000?oooooo`000?l000003Oooool2o`0003Sooooo0_l0000<ooooo`;o0000<Oooool2o`0002go
oooo0_l00009ooooo`Co00002?ooool2o`0001oooooo0_l0000;ooooo`;o00003_ooool002Wooooo
00?o0000ooooooooool0;_ooool2o`0000;ooooo0_l00002ooooo`;o00001Oooool2o`0001Wooooo
0_l0000Looooo`?o00003?ooool2o`0003Wooooo0_l00008ooooo`;o00006_ooool3o`0000Wooooo
0_l00006ooooo`;o00000_ooool2o`0003cooooo000Yooooo`;o0000<oooool2o`0000;ooooo0_l0
0006ooooo`Co00002oooool2o`0000Wooooo0_l0000Looooo`;o0000B?ooool2o`0000Sooooo0_l0
000Jooooo`;o00004_ooool2o`0000;ooooo0_l00002ooooo`;o0000>?ooool002Wooooo0_l00006
ooooo`;o00000oooool2o`0000gooooo0_l00005ooooo`;o00004?ooool2o`0000Cooooo0ol00003
ooooo`Co00000oooool2o`0000Kooooo0_l0000Hooooo`;o0000A_ooool2o`00057ooooo0_l0000<
ooooo`;o00001Oooool2o`0001;ooooo0_l0000?ooooo`00:Oooool00ol0003oooooooooo`05oooo
o`;o00000oooool2o`0000gooooo0_l00005ooooo`;o00001oooool2o`0000Oooooo0_l00004oooo
o`?o00002_ooool2o`0000[ooooo0_l0000Dooooo`;o0000>?ooool2o`0000cooooo0_l000000ooo
oooo0000o`000006ooooo`;o00003?ooool2o`0000Kooooo0_l00002ooooo`;o00008_ooool2o`00
00oooooo0_l000000ooooooo0000o`000002ooooo`;o00001Oooool2o`0001;ooooo0_l0000?oooo
o`00:Oooool4o`000003ooooool0003o000001;ooooo0_l0000=ooooo`;o00000_ooool2o`00027o
oooo0_l00003ooooo`;o000000?oooooo`000?l000004?ooool2o`0003Wooooo0_l00007ooooo`;o
00001Oooool3o`0000Kooooo0_l0000<ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`00
00;ooooo0_l0000Rooooo`;o00003oooool2o`000004ooooool0003o0000ooooo`;o00002Oooool2
o`0000_ooooo0_l0000Cooooo`00:Oooool01Ol0003oooooo`000?l0003ooooo00;o00004_ooool4
o`0000_ooooo0_l000000ooooooo0000o`000006ooooo`;o00006_ooool2o`0000Kooooo0_l0000@
ooooo`;o00004Oooool3o`0000gooooo0_l0000Jooooo`;o00000oooool2o`0000Gooooo0_l00009
ooooo`;o00003Oooool3o`00047ooooo0_l00009ooooo`;o00002oooool2o`0001?ooooo000Yoooo
o`03o`000?oooooooooo01Sooooo0_l0000;ooooo`;o000000?oooooo`000?l000001_ooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h0:Oooool5o`0000?ooooo00Cok^k^oc8b<_l0003o<S8b0ol000000oooooook^k^oc8b<P02o`00
0003onk^k_oooooooooo00Gooooo0_l00008ooooo`;o00004?ooool2o`0000?ooooo00GoV9RHoa0@
4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00oo^k^ko<S8bo`00
0002o`0000Kooooo0_l00004ooooo`;o00004Oooool2o`0000Wooooo0_l000002Ol@413ooooooooo
ooooooook^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ol0000F
ooooo`;o00003?ooool2o`000005odA4A?l0003o0000o`000?oMgMd00_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool00ol0003ooooo
ooooo`0Uooooo`;o000000?oooooo`000?l000002?ooool00ol0003oooooooooo`02o`000005ogMg
MonHV9SooooooiRHV?mgMgL00oooool2o`000003oooooonHV9SoMgMg02Wooooo00GoV9RHob4Q8Oo^
k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHo`000?l0
003oMgMg00Oooooo0_l00008ooooo`;o000000?oooooo`000?l000004_ooool01Ol@413o^[Zjoooo
oomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03ogMgMonHV9Sooooo00;o
00000_ooool2o`0000;ooooo0_l00007ooooo`;o00001?ooool2o`0000Sooooo0_l0000:ooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`;o000000CoV9RHoooo
oonHV9SoMgMg0ol0000Fooooo`;o00003?ooool2o`0000;ooooo0_l000002?lb<S;ooooooooooomg
MgOoV9RHoooooonHV9SoMgMg0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000Yooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool00_l000001Ol@413ooooooooooooooooo410@
00?ooooo0_l00002ooooo`04oa0@4?oooooo0000o`0002Oooooo00?oV9RHob4Q8Oo^k^h01?ooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@400Dooooo`;o0000
1oooool2o`0000gooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`02o`0000_ooooo0_l00004ooooo`;o00002_ooool2o`00
00Gooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41000_ooool2o`0000?ooooo00?o410@
ooooooooool08Oooool2o`0000Sooooo00Co0000oooooooooooo410@0oooool01Ol@413ooooooooo
oooooooo410@00?ooooo00?o410@ooooooooool00Oooool002Wooooo0_l00008ooooo`;o00006Ooo
ool2o`0000kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Ko0000ooooooooooooooooo`000?ooool2o`0000kooooo0_l00004ooooo`;o000000?oooooo`00
0?l000003oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000001gooooo0_l0000<ooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000008Oooool2o`0000Go
oooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`00000Sooooo`;o00001oooool01OmgMgOo<S8boooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo007ooooo000Yooooo`?o0000
0oooool2o`0000;ooooo0_l0000Iooooo`;o00003_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000017ooooo0_l00004oooo
o`;o000000?oooooo`000?l000004?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000[ooooo0_l0000Jooooo`;o00000_oo
ool00ol@413o0000okZj^P03ooooo`?o000000?oooooo`000?ooool00_ooool01Ol0003ooooooooo
oooooooo000002Sooooo00?ogMgMoeEEEOooool00_l00003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000001cooooo0_l000000ooooooo0000o`000008oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`00:Oooool3o`0000?ooooo0_l0000Kooooo`;o00004?oo
ool00ol0003oooooooooo`02o`000005oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooo
oooooooooooo410@00Oooooo0_l0000Tooooo`05o`000?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool02?ooool2o`0001[ooooo0_l00003
ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@o`000?l0003ooooooa0@4003ooooo`05oa0@4?oo
ooooooooooooool@41005oooool2o`00013ooooo00CoMgMgolc<c?l0003o00000oooool01Ol@413o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@400Hooooo`;o00000_ooool2
o`000003ooooool0003o000000Sooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooo
oooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`00:Oooool00ol0003ooooooooo
o`0Oooooo`?o00004?ooool00ol0003oooooooooo`03o`000004oiRHV?ooooooV9RHogMgM`?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`;o00008?ooool3o`000003oiRHV?l@413ooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMol0003o0000oiRHV?mgMgL0:?ooool0
1Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL05oooool2o`00013ooooo00?ok^k^odA4A?l000000oooool2o`000004
oiRHV?ooooooV9RHogMgM`?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o00004Oooool2
o`0000oooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool00ol0003oooooooooo`0Oooooo`;o00003_oo
ool2o`000003ofIVI_l0003ooooo00;ooooo0_l000001?lb<S;o0000oc8b<_o^k^h3ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0:Oooool01OnHV9So0000o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`06onk^k_l0003o0000oc8b<_o^k^kooooo0_l0000Uooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0:ooooo`;o00007_ooool00omgMgOo0000ooooo`02ooooo`;o000000Co<S8b
o`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_l00007ooooo`;o0000
6Oooool4o`000008ooooool0003o0000onk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool002Wooooo0_l0000Cooooo`;o00006oooool2o`0005;ooooo1?l0000=
ooooo`;o00006?ooool2o`0000kooooo0_l00006ooooo`;o000000?oooooo`000?l00000>_ooool2
o`0000?ooooo0_l0000@ooooo`;o00003?ooool2o`00013ooooo000Yooooo`03o`000?oooooooooo
01;ooooo0_l0000Fooooo`;o0000DOooool2o`0000Kooooo0_l000000ooooooo0000o`000006oooo
o`;o00000_ooool2o`0001Oooooo0ol0000>ooooo`;o00001_ooool2o`0001cooooo0_l0000Ooooo
o`;o00002oooool2o`0000Sooooo0_l0000=ooooo`;o00003oooool002Wooooo00?o0000oooooooo
ool0:_ooool2o`0001Sooooo0_l0000Mooooo`;o00006?ooool2o`0000?ooooo0_l00004ooooo`;o
00001_ooool2o`0001_ooooo0_l0000>ooooo`;o00009Oooool2o`0000?ooooo0_l0000Tooooo`;o
000000?oooooo`000?l000005oooool2o`0000oooooo000Yooooo`03o`000?oooooooooo047ooooo
0_l000000ooooooo0000o`000002ooooo`;o00006Oooool2o`0001gooooo0_l0000iooooo`;o0000
9oooool2o`000003ooooool0003o000001Oooooo0_l00002ooooo`;o00001oooool4o`0002Wooooo
000Yooooo`03o`000?oooooooooo03?ooooo0_l00005ooooo`;o00001Oooool4o`0000?ooooo0_l0
000<ooooo`;o00004oooool2o`0002_ooooo0_l0001<ooooo`;o00006_ooool2o`0000;ooooo0_l0
0009ooooo`;o0000:Oooool0027oooooool00014o`0000Cooooo000Yooooo`04o`000?oooooo0000
o`0000?ooooo0_l00003ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`06ooooo`;o000000?oooooo`000?ooool01oooool2o`000003ooooool0003o
oooo00[ooooo0_l00005ooooo`;o00001?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`Co00000oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo0_l0000;ooooo`04o`000?oooooo
0000o`0000Kooooo0ol00002ooooo`;o00001oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00;ooooo0_l00006ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_oo
ool4o`0000?ooooo00?o0000ooooooooool01oooool3o`0000_ooooo00?o0000ooooooooool02_oo
ool002Wooooo00?o0000ooooooooool01oooool2o`0000[ooooo0_l0000>ooooo`;o00001_ooool2
o`0000[ooooo0_l000000ooooooo0000ooooo`0Aooooo`;o00003oooool2o`0001Sooooo00?o0000
ooooooooool00_ooool4o`0000kooooo0_l0000=ooooo`;o00002oooool2o`0000Kooooo0ol0000K
ooooo`?o00004?ooool2o`0000Gooooo0ol00004ooooo`03o`000?oooooooooo01_ooooo0_l0000?
ooooo`;o00000_ooool2o`0000Sooooo00?o0000ooooooooool02_ooool002Wooooo00Co0000oooo
oooooooooooo0_l00004ooooo`;o00002_ooool2o`0000kooooo0_l00007ooooo`;o00006?ooool2
o`0001Kooooo0_l0000]ooooo`Co00003Oooool2o`0002Oooooo0_l00008ooooo`;o00004Oooool2
o`0000Gooooo0ol00009ooooo`Co00004_ooool2o`0001Kooooo0_l0000Eooooo`00:Oooool01?l0
003oooooooooooooool2o`0000[ooooo0_l0000Mooooo`;o00006?ooool2o`000003ooooool0003o
000002kooooo0_l0000Booooo`;o000000?oooooo`000?l000000oooool2o`00013ooooo0_l0000B
ooooo`;o00002_ooool2o`0002cooooo1_l0000Aooooo`?o0000;Oooool002Wooooo0_l0000>oooo
o`;o00008Oooool2o`0001Oooooo0_l0000Nooooo`;o00000_ooool2o`0000Wooooo1Ol0000Coooo
o`;o00000oooool2o`00013ooooo0_l0000Booooo`;o00002Oooool2o`0002Kooooo0ol00004oooo
o`;o00005Oooool2o`0002kooooo000Yooooo`03o`000?oooooooooo00Wooooo0_l0000Uooooo`;o
00002_ooool2o`0002[ooooo0ol00002ooooo`;o00002Oooool2o`000004ooooool0003o0000o`00
01[ooooo0_l0000/ooooo`;o00009_ooool3o`0000kooooo0_l0000Sooooo`;o00005_ooool002Wo
oooo00?o0000ooooooooool02Oooool4o`00013ooooo0_l0000Mooooo`;o0000:_ooool2o`0000Wo
oooo0_l00007ooooo`;o00000oooool2o`0001Gooooo0_l0001Eooooo`;o00000oooool2o`0000Wo
oooo0_l0000Sooooo`;o00005_ooool002Wooooo00?o0000ooooooooool02oooool2o`0000?ooooo
0_l0000;ooooo`;o00007?ooool2o`0001kooooo0_l0000Fooooo`;o00003?ooool2o`0006cooooo
0_l00003ooooo`;o00002Oooool2o`0000Oooooo0_l0000booooo`00:Oooool00ol0003ooooooooo
o`0@ooooo`;o00003?ooool2o`0000Cooooo0_l0000Dooooo`?o00004oooool2o`0000Kooooo0_l0
00000ooooooo0000o`00000Tooooo`;o00001?ooool2o`0003[ooooo0_l0000dooooo`;o00003?oo
ool3o`0001?ooooo0_l00004ooooo`;o00005oooool002Wooooo0_l0000Oooooo`;o00001?ooool4
o`0000_ooooo0_l00005ooooo`;o00005?ooool2o`0000Kooooo1?l00007ooooo`;o00001?ooool2
o`0001cooooo0_l00002ooooo`;o00003?ooool2o`0002Sooooo0_l0000Nooooo`;o00005?ooool2
o`0000cooooo0_l0000Dooooo`;o00001?ooool2o`0001Oooooo000Yooooo`03o`000?oooooooooo
00Kooooo0_l0000?ooooo`;o00003Oooool2o`0000Wooooo1?l0000Tooooo`?o00001oooool2o`00
00Cooooo0_l00009ooooo`;o00005Oooool2o`0000cooooo0ol00004ooooo`;o00009oooool2o`00
01Sooooo0_l0000Gooooo`;o0000:?ooool2o`0001Cooooo000Yooooo`03o`000?oooooooooo00Ko
oooo0_l0000?ooooo`;o00006?ooool2o`0000_ooooo0_l0000;ooooo`;o00003?ooool2o`0000co
oooo0_l00006ooooo`;o00000oooool2o`0002Cooooo0_l00004ooooo`;o00000_ooool2o`0000Oo
oooo0_l000000ooooooo0000o`00000Gooooo`;o0000<Oooool2o`0002Sooooo0_l0000Dooooo`00
:Oooool00ol0003oooooooooo`0<ooooo`;o00006Oooool2o`0001Gooooo0_l0000;ooooo`;o0000
4_ooool2o`0000Kooooo0_l00006ooooo`;o00007_ooool2o`0000[ooooo0_l00007ooooo`;o0000
1oooool2o`000003ooooool0003o000000kooooo0_l00012ooooo`;o00004_ooool2o`0000Cooooo
0_l00002ooooo`;o00006?ooool002Wooooo0_l00009ooooo`;o00000_ooool5o`0000?ooooo0_l0
000Aooooo`;o0000<oooool2o`000003ooooool0003o000000?ooooo0_l0000Yooooo`;o00001?oo
ool2o`0000?ooooo0ol0000Sooooo`;o00005oooool2o`0001;ooooo0_l0000Eooooo`;o00004_oo
ool2o`0000Cooooo0_l00002ooooo`;o00001Oooool2o`00017ooooo000Yooooo`;o00002Oooool2
o`0000?ooooo1?l00003ooooo`;o00004Oooool2o`0001Oooooo0_l00007ooooo`;o00002Oooool2
o`0000Kooooo0_l00004ooooo`Go00009_ooool2o`0000Kooooo0_l00003ooooo`;o00002_ooool2
o`0001?ooooo0_l0000Cooooo`;o00001oooool2o`0000Kooooo0_l0000:ooooo`;o00004_ooool2
o`0002Gooooo0ol00002ooooo`;o00003Oooool002Wooooo00?o0000ooooooooool05oooool2o`00
02Oooooo0_l00007ooooo`;o00001oooool4o`0000cooooo0_l000000ooooooo0000o`00000Voooo
o`;o00005oooool2o`0001?ooooo0_l0000@ooooo`;o000000?oooooo`000?l000003oooool2o`00
01kooooo0_l0000Uooooo`;o00000oooool2o`0000gooooo000Yooooo`04o`000?oooooooooooooo
o`;o00005?ooool2o`0003Wooooo0_l00018ooooo`;o00000_ooool2o`0002_ooooo0_l0000?oooo
o`?o00001?ooool2o`0001gooooo0_l0000=ooooo`;o00001oooool2o`0001kooooo000Yooooo`04
o`000?ooooooooooooooo`;o0000K_ooool2o`0002Wooooo0ol000001?oooooo0000o`000?ooool2
o`0003Wooooo0ol00004ooooo`;o00007Oooool2o`000003ooooool0003o000000[ooooo0_l00007
ooooo`;o00007_ooool002Wooooo00?o0000ooooooooool07oooool2o`0000cooooo0_l0000`oooo
o`;o00004?ooool2o`0002[ooooo0_l00004ooooo`Co00004?ooool2o`0001Gooooo0_l0000goooo
o`;o00001Oooool2o`0001;ooooo0_l000000ooooooo0000o`00000Eooooo`00:Oooool2o`0001_o
oooo0_l00003ooooo`;o00003?ooool2o`00023ooooo0_l0000>ooooo`;o0000A?ooool2o`0000oo
oooo0ol0000Eooooo`;o00002?ooool2o`0003Cooooo0_l0000@ooooo`Co000000Coooooo`000?l0
003ooooo0_l0000Booooo`00:Oooool00ol0003oooooooooo`0Hooooo`Co0000<oooool2o`0001_o
oooo0_l00018ooooo`;o00008?ooool2o`0003_ooooo0_l00009ooooo`;o00001_ooool2o`0001;o
oooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Hooooo`;o0000D_ooool2o`00
057ooooo0_l0000Pooooo`;o00004oooool2o`0001gooooo0_l0000Uooooo`001_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo027ooooo0_l0001_ooooo`;o00003_ooool2
o`0001_ooooo0_l0000Pooooo`;o00004oooool2o`0001oooooo0_l0000Sooooo`001_ooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01cooooo0_l00003ooooo`;o00006_ooool2o`0004Gooooo0_l0000<
ooooo`;o00003_ooool2o`00027ooooo0_l000000ooooooo0000o`00001=ooooo`;o00008oooool0
00Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMg
oc8b<_ooool01?ooool3o`0001cooooo0_l0000Oooooo`;o0000AOooool4o`0003gooooo0_l00000
0ooooooo0000o`000003ooooo`;o0000=?ooool2o`0001Cooooo0_l0000Qooooo`001_ooool01Ol0
003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Gooooo00?o0000ooooooooool00_l0001<ooooo`;o00003?ooool3o`0000_ooooo0_l0
000@ooooo`;o00002?ooool2o`0002Cooooo0_l00002ooooo`;o00006oooool2o`0001[ooooo0_l0
0006ooooo`;o00004?ooool2o`0001Cooooo0_l0000Qooooo`001_ooool01Ol@413ooooooooooooo
oooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00;o0000:oooool2o`0001oooooo0_l0000<ooooo`?o000000?oooooo`000?l000000_oo
ool2o`0000Cooooo0_l0000@ooooo`;o00000_ooool2o`0002Oooooo0_l000000ooooooo0000o`00
0002ooooo`;o00004_ooool2o`0001Cooooo0_l00006ooooo`;o00001Oooool2o`0000Kooooo0_l0
000gooooo`;o00004?ooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj
^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02?ooooo
0_l00005ooooo`;o000000Coooooo`000?l0003o0000<?ooool2o`0000;ooooo0_l0000Jooooo`;o
00000_ooool2o`00017ooooo0_l0000@ooooo`;o00001oooool2o`00013ooooo0_l0000@ooooo`;o
00000_ooool2o`0000Kooooo0_l0000Cooooo`;o0000<Oooool2o`00013ooooo0006ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006oooo
o`03o`000?oooooooooo00Cooooo0_l0000>ooooo`;o00003Oooool2o`0000Gooooo0_l00002oooo
o`;o00002oooool2o`0004Oooooo0_l0000Aooooo`;o00006Oooool2o`0002;ooooo0_l0000Ooooo
o`;o00006oooool2o`0002Kooooo000Yooooo`;o00001Oooool2o`0000kooooo0_l0000Uooooo`;o
00001_ooool2o`0000_ooooo0_l00032ooooo`;o00009_ooool002Wooooo00?o0000ooooooooool0
5Oooool2o`0002cooooo0_l0000;ooooo`;o00009?ooool2o`0000oooooo0_l00009ooooo`;o0000
5_ooool2o`0000Wooooo0_l0000<ooooo`;o00005_ooool2o`0005oooooo000Yooooo`03o`000?oo
oooooooo00Gooooo0_l0000>ooooo`;o0000E?ooool2o`0000Wooooo0_l0000?ooooo`;o00002Ooo
ool2o`0000_ooooo0_l00009ooooo`;o00002Oooool2o`0000cooooo0_l0000Fooooo`;o0000<?oo
ool2o`0002gooooo000Yooooo`03o`000?oooooooooo00Gooooo0_l0000Dooooo`;o0000=_ooool2
o`0001Kooooo0_l0000Mooooo`;o00004oooool2o`0003[ooooo0ol0000_ooooo`;o0000;Oooool0
02Wooooo00?o0000ooooooooool03_ooool2o`0000_ooooo0_l0000[ooooo`;o00001?ooool2o`00
00?ooooo0_l0000<ooooo`;o00000oooool2o`0002;ooooo0_l0001@ooooo`;o000000?oooooo`00
0?l000006_ooool2o`00033ooooo1?l0000;ooooo`00:Oooool2o`0000oooooo0_l00002ooooo`;o
0000=?ooool2o`0000Cooooo0_l000000ooooooo0000o`000002o`0000cooooo0_l00003ooooo`;o
0000>_ooool2o`00017ooooo0_l0000Looooo`So00001?ooool2o`0000Oooooo0_l0000Aooooo`;o
00003?ooool2o`0001;ooooo0_l0000>ooooo`Co00002oooool002Wooooo00?o0000ooooooooool0
2Oooool2o`0000Oooooo0_l0000^ooooo`;o00001_ooool2o`0000Gooooo1?l000000ooooooo0000
o`00000Dooooo`;o0000=?ooool3o`0000Wooooo0_l00005ooooo`;o00007?ooool8o`0000gooooo
0_l0000Oooooo`;o00002oooool2o`0000Gooooo0_l0000Mooooo`00:Oooool00ol0003ooooooooo
o`09ooooo`;o0000=oooool2o`0000Kooooo0_l0000:ooooo`;o00005?ooool2o`0000Cooooo0_l0
000_ooooo`;o00002Oooool2o`00017ooooo0_l0000Yooooo`;o00001?ooool2o`0002;ooooo0_l0
000Tooooo`00:Oooool00ol0003oooooooooo`1booooo`;o0000COooool2o`0001Wooooo0_l0000>
ooooo`;o00001?ooool2o`0004Sooooo000Yooooo`03o`000?oooooooooo0=cooooo0_l0001Noooo
o`00:Oooool2o`000>Sooooo0_l0001Cooooo`00:Oooool00ol0003oooooooooo`1aooooo`;o0000
M?ooool2o`0005?ooooo000Yooooo`03o`000?oooooooooo00cooooo0_l0001Cooooo`;o00003_oo
ool2o`0000oooooo0_l0000eooooo`;o0000POooool002Wooooo00?o0000ooooooooool03?ooool2
o`0000Oooooo0_l0000Mooooo`;o0000:oooool2o`0001oooooo0_l0000eooooo`;o0000POooool0
02Wooooo00?o0000ooooooooool05Oooool2o`0000_ooooo0_l0000@ooooo`;o00008Oooool2o`00
01Gooooo0_l0000Qooooo`;o0000B_ooool2o`0005gooooo000Yooooo`;o00008oooool2o`0003?o
oooo0_l0000Eooooo`;o00001?ooool2o`0001_ooooo0_l0000Qooooo`;o00009oooool2o`0001;o
oooo0_l0000]ooooo`;o00006_ooool002Wooooo00?o0000ooooooooool0M?ooool2o`00027ooooo
0_l0000Kooooo`;o0000=Oooool2o`0000Cooooo0_l0000Wooooo`;o00001?ooool2o`0001[ooooo
000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo04Oooooo0_l0000/ooooo`;o00004oooool2o`0000;o
oooo0_l00007ooooo`;o0000:Oooool2o`0002Oooooo0_l0000Hooooo`;o00004oooool2o`00023o
oooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`17ooooo`;o0000:Oooool2o`000003ooooool0003o000001?o
oooo0_l00002ooooo`;o0000<_ooool2o`0003Kooooo0_l00004ooooo`;o00000oooool2o`0003Go
oooo000>ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`?o
0000FOooool2o`0001Oooooo0_l0001:ooooo`;o0000>_ooool2o`0000Cooooo0_l0000jooooo`00
3_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`1Iooooo`;o0000Foooool2o`0000Kooooo0_l0001looooo`003_ooool01Ol0003ooooo
oooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo
0;Kooooo0_l00024ooooo`003_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000ko
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Go
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`007oooool4o`000003oa0@4?oooooooooo00?ooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`007oooool00omEEEGoIVIVo`00003oooooodOooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .39611 Mdot
.02762 .34499 Mdot
.02952 .28229 Mdot
.03143 .25981 Mdot
.03333 .33349 Mdot
.03524 .34994 Mdot
.03714 .30214 Mdot
.03905 .25136 Mdot
.04095 .25982 Mdot
.04286 .32484 Mdot
.04476 .25868 Mdot
.04667 .30308 Mdot
.04857 .23472 Mdot
.05048 .28461 Mdot
.05238 .3247 Mdot
.05429 .32809 Mdot
.05619 .35305 Mdot
.0581 .23568 Mdot
.06 .34828 Mdot
.0619 .41848 Mdot
.06381 .23995 Mdot
.06571 .28669 Mdot
.06762 .25834 Mdot
.06952 .2417 Mdot
.07143 .38506 Mdot
.07333 .28059 Mdot
.07524 .25992 Mdot
.07714 .34349 Mdot
.07905 .42438 Mdot
.08095 .33547 Mdot
.08286 .26179 Mdot
.08476 .26355 Mdot
.08667 .2333 Mdot
.08857 .29439 Mdot
.09048 .24369 Mdot
.09238 .39542 Mdot
.09429 .39938 Mdot
.09619 .31755 Mdot
.0981 .42529 Mdot
.1 .31688 Mdot
.1019 .3834 Mdot
.10381 .26165 Mdot
.10571 .28092 Mdot
.10762 .3954 Mdot
.10952 .39926 Mdot
.11143 .26491 Mdot
.11333 .29059 Mdot
.11524 .31879 Mdot
.11714 .36424 Mdot
.11905 .42156 Mdot
.12095 .32119 Mdot
.12286 .42605 Mdot
.12476 .24763 Mdot
.12667 .25216 Mdot
.12857 .25554 Mdot
.13048 .23021 Mdot
.13238 .25944 Mdot
.13429 .35633 Mdot
.13619 .36283 Mdot
.1381 .39798 Mdot
.14 .25437 Mdot
.1419 .46259 Mdot
.14381 .42444 Mdot
.14571 .33618 Mdot
.14762 .23539 Mdot
.14952 .24341 Mdot
.15143 .32904 Mdot
.15333 .31788 Mdot
.15524 .31942 Mdot
.15714 .25694 Mdot
.15905 .34673 Mdot
.16095 .31144 Mdot
.16286 .31887 Mdot
.16476 .34339 Mdot
.16667 .4244 Mdot
.16857 .29802 Mdot
.17048 .24724 Mdot
.17238 .2521 Mdot
.17429 .4278 Mdot
.17619 .35295 Mdot
.1781 .33422 Mdot
.18 .33906 Mdot
.1819 .26028 Mdot
.18381 .25635 Mdot
.18571 .2291 Mdot
.18762 .33293 Mdot
.18952 .3281 Mdot
.19143 .29904 Mdot
.19333 .36739 Mdot
.19524 .32139 Mdot
.19714 .38912 Mdot
.19905 .39735 Mdot
.20095 .32655 Mdot
.20286 .28577 Mdot
.20476 .33278 Mdot
.20667 .41513 Mdot
.20857 .28964 Mdot
.21048 .31184 Mdot
.21238 .23788 Mdot
.21429 .36768 Mdot
.21619 .39114 Mdot
.2181 .37605 Mdot
.22 .30374 Mdot
.2219 .38907 Mdot
.22381 .30455 Mdot
.22571 .28174 Mdot
.22762 .33245 Mdot
.22952 .35698 Mdot
.23143 .32584 Mdot
.23333 .26109 Mdot
.23524 .30765 Mdot
.23714 .25846 Mdot
.23905 .267 Mdot
.24095 .40184 Mdot
.24286 .28355 Mdot
.24476 .32876 Mdot
.24667 .24856 Mdot
.24857 .2342 Mdot
.25048 .24584 Mdot
.25238 .39942 Mdot
.25429 .23487 Mdot
.25619 .45514 Mdot
.2581 .23607 Mdot
.26 .42591 Mdot
.2619 .26073 Mdot
.26381 .26816 Mdot
.26571 .40922 Mdot
.26762 .43342 Mdot
.26952 .36666 Mdot
.27143 .30234 Mdot
.27333 .26215 Mdot
.27524 .38176 Mdot
.27714 .33147 Mdot
.27905 .35541 Mdot
.28095 .30798 Mdot
.28286 .42892 Mdot
.28476 .41095 Mdot
.28667 .419 Mdot
.28857 .32132 Mdot
.29048 .24986 Mdot
.29238 .32977 Mdot
.29429 .46099 Mdot
.29619 .2829 Mdot
.2981 .33356 Mdot
.3 .35307 Mdot
.3019 .41129 Mdot
.30381 .22638 Mdot
.30571 .35255 Mdot
.30762 .35716 Mdot
.30952 .28625 Mdot
.31143 .44874 Mdot
.31333 .3777 Mdot
.31524 .28437 Mdot
.31714 .24304 Mdot
.31905 .31732 Mdot
.32095 .37856 Mdot
.32286 .41623 Mdot
.32476 .4256 Mdot
.32667 .23362 Mdot
.32857 .39786 Mdot
.33048 .41517 Mdot
.33238 .32581 Mdot
.33429 .42871 Mdot
.33619 .37499 Mdot
.3381 .37705 Mdot
.34 .28129 Mdot
.3419 .39141 Mdot
.34381 .22683 Mdot
.34571 .32191 Mdot
.34762 .31299 Mdot
.34952 .41908 Mdot
.35143 .41418 Mdot
.35333 .31404 Mdot
.35524 .29433 Mdot
.35714 .32488 Mdot
.35905 .35862 Mdot
.36095 .23722 Mdot
.36286 .42103 Mdot
.36476 .37586 Mdot
.36667 .32709 Mdot
.36857 .42496 Mdot
.37048 .42512 Mdot
.37238 .34153 Mdot
.37429 .34667 Mdot
.37619 .39012 Mdot
.3781 .26526 Mdot
.38 .26547 Mdot
.3819 .43359 Mdot
.38381 .27175 Mdot
.38571 .36851 Mdot
.38762 .29509 Mdot
.38952 .44582 Mdot
.39143 .41129 Mdot
.39333 .32667 Mdot
.39524 .45896 Mdot
.39714 .23737 Mdot
.39905 .41183 Mdot
.40095 .31581 Mdot
.40286 .29682 Mdot
.40476 .36978 Mdot
.40667 .30314 Mdot
.40857 .31327 Mdot
.41048 .31653 Mdot
.41238 .30453 Mdot
.41429 .33612 Mdot
.41619 .35195 Mdot
.4181 .38625 Mdot
.42 .28756 Mdot
.4219 .36249 Mdot
.42381 .25831 Mdot
.42571 .26498 Mdot
.42762 .25599 Mdot
.42952 .24713 Mdot
.43143 .24987 Mdot
.43333 .32361 Mdot
.43524 .34324 Mdot
.43714 .38964 Mdot
.43905 .24907 Mdot
.44095 .37846 Mdot
.44286 .26419 Mdot
.44476 .39396 Mdot
.44667 .2989 Mdot
.44857 .24931 Mdot
.45048 .35241 Mdot
.45238 .31027 Mdot
.45429 .35177 Mdot
.45619 .33587 Mdot
.4581 .35194 Mdot
.46 .35852 Mdot
.4619 .31894 Mdot
.46381 .32675 Mdot
.46571 .45847 Mdot
.46762 .30618 Mdot
.46952 .27675 Mdot
.47143 .34429 Mdot
.47333 .37454 Mdot
.47524 .25764 Mdot
.47714 .45069 Mdot
.47905 .30623 Mdot
.48095 .38423 Mdot
.48286 .23616 Mdot
.48476 .38533 Mdot
.48667 .46214 Mdot
.48857 .32616 Mdot
.49048 .34958 Mdot
.49238 .34724 Mdot
.49429 .26237 Mdot
.49619 .33453 Mdot
.4981 .41588 Mdot
.5 .37065 Mdot
.5019 .34958 Mdot
.50381 .42517 Mdot
.50571 .40712 Mdot
.50762 .32842 Mdot
.50952 .32643 Mdot
.51143 .40975 Mdot
.51333 .28803 Mdot
.51524 .2886 Mdot
.51714 .26746 Mdot
.51905 .30434 Mdot
.52095 .25276 Mdot
.52286 .34058 Mdot
.52476 .37112 Mdot
.52667 .25729 Mdot
.52857 .36143 Mdot
.53048 .32059 Mdot
.53238 .37704 Mdot
.53429 .39686 Mdot
.53619 .27954 Mdot
.5381 .33291 Mdot
.54 .40486 Mdot
.5419 .31644 Mdot
.54381 .40154 Mdot
.54571 .2631 Mdot
.54762 .32716 Mdot
.54952 .36265 Mdot
.55143 .41814 Mdot
.55333 .34747 Mdot
.55524 .36026 Mdot
.55714 .30928 Mdot
.55905 .25899 Mdot
.56095 .37397 Mdot
.56286 .42705 Mdot
.56476 .2973 Mdot
.56667 .34538 Mdot
.56857 .39722 Mdot
.57048 .28904 Mdot
.57238 .35811 Mdot
.57429 .32163 Mdot
.57619 .35006 Mdot
.5781 .389 Mdot
.58 .27526 Mdot
.5819 .31984 Mdot
.58381 .43302 Mdot
.58571 .36722 Mdot
.58762 .302 Mdot
.58952 .36254 Mdot
.59143 .27539 Mdot
.59333 .38015 Mdot
.59524 .4541 Mdot
.59714 .37399 Mdot
.59905 .31655 Mdot
.60095 .38227 Mdot
.60286 .35642 Mdot
.60476 .29849 Mdot
.60667 .37992 Mdot
.60857 .26211 Mdot
.61048 .37807 Mdot
.61238 .28091 Mdot
.61429 .31083 Mdot
.61619 .29776 Mdot
.6181 .2885 Mdot
.62 .2486 Mdot
.6219 .34691 Mdot
.62381 .23517 Mdot
.62571 .44363 Mdot
.62762 .32808 Mdot
.62952 .39601 Mdot
.63143 .27558 Mdot
.63333 .24383 Mdot
.63524 .3192 Mdot
.63714 .3469 Mdot
.63905 .43549 Mdot
.64095 .46001 Mdot
.64286 .29045 Mdot
.64476 .3574 Mdot
.64667 .25426 Mdot
.64857 .42386 Mdot
.65048 .35173 Mdot
.65238 .30411 Mdot
.65429 .28715 Mdot
.65619 .34033 Mdot
.6581 .27924 Mdot
.66 .41021 Mdot
.6619 .33401 Mdot
.66381 .26354 Mdot
.66571 .297 Mdot
.66762 .30293 Mdot
.66952 .3551 Mdot
.67143 .34299 Mdot
.67333 .28232 Mdot
.67524 .32605 Mdot
.67714 .34068 Mdot
.67905 .27224 Mdot
.68095 .29872 Mdot
.68286 .34912 Mdot
.68476 .33597 Mdot
.68667 .22768 Mdot
.68857 .25642 Mdot
.69048 .41652 Mdot
.69238 .31594 Mdot
.69429 .3066 Mdot
.69619 .2589 Mdot
.6981 .46165 Mdot
.7 .29744 Mdot
.7019 .38352 Mdot
.70381 .40001 Mdot
.70571 .34893 Mdot
.70762 .30736 Mdot
.70952 .41217 Mdot
.71143 .37646 Mdot
.71333 .29699 Mdot
.71524 .46059 Mdot
.71714 .35442 Mdot
.71905 .32884 Mdot
.72095 .35209 Mdot
.72286 .38795 Mdot
.72476 .28432 Mdot
.72667 .3716 Mdot
.72857 .33223 Mdot
.73048 .25458 Mdot
.73238 .27905 Mdot
.73429 .29838 Mdot
.73619 .30032 Mdot
.7381 .36428 Mdot
.74 .39292 Mdot
.7419 .29885 Mdot
.74381 .38468 Mdot
.74571 .38986 Mdot
.74762 .41761 Mdot
.74952 .26444 Mdot
.75143 .39322 Mdot
.75333 .26757 Mdot
.75524 .36952 Mdot
.75714 .31056 Mdot
.75905 .38976 Mdot
.76095 .38289 Mdot
.76286 .31933 Mdot
.76476 .42126 Mdot
.76667 .37061 Mdot
.76857 .28307 Mdot
.77048 .34665 Mdot
.77238 .26002 Mdot
.77429 .30068 Mdot
.77619 .33963 Mdot
.7781 .26058 Mdot
.78 .26356 Mdot
.7819 .30978 Mdot
.78381 .31659 Mdot
.78571 .45744 Mdot
.78762 .3461 Mdot
.78952 .3229 Mdot
.79143 .28616 Mdot
.79333 .31302 Mdot
.79524 .35884 Mdot
.79714 .35894 Mdot
.79905 .30596 Mdot
.80095 .27302 Mdot
.80286 .29985 Mdot
.80476 .25834 Mdot
.80667 .30769 Mdot
.80857 .25716 Mdot
.81048 .34163 Mdot
.81238 .43111 Mdot
.81429 .29463 Mdot
.81619 .37538 Mdot
.8181 .27291 Mdot
.82 .28869 Mdot
.8219 .31459 Mdot
.82381 .31154 Mdot
.82571 .30559 Mdot
.82762 .2665 Mdot
.82952 .29539 Mdot
.83143 .45226 Mdot
.83333 .24752 Mdot
.83524 .3108 Mdot
.83714 .24232 Mdot
.83905 .33217 Mdot
.84095 .38724 Mdot
.84286 .31275 Mdot
.84476 .30124 Mdot
.84667 .42344 Mdot
.84857 .40408 Mdot
.85048 .37787 Mdot
.85238 .24057 Mdot
.85429 .39307 Mdot
.85619 .30826 Mdot
.8581 .24592 Mdot
.86 .33906 Mdot
.8619 .25573 Mdot
.86381 .31402 Mdot
.86571 .26499 Mdot
.86762 .30089 Mdot
.86952 .28493 Mdot
.87143 .35733 Mdot
.87333 .3586 Mdot
.87524 .34307 Mdot
.87714 .38267 Mdot
.87905 .26279 Mdot
.88095 .24354 Mdot
.88286 .26669 Mdot
.88476 .33673 Mdot
.88667 .3278 Mdot
.88857 .3463 Mdot
.89048 .25258 Mdot
.89238 .32592 Mdot
.89429 .42845 Mdot
.89619 .35949 Mdot
.8981 .39798 Mdot
.9 .40532 Mdot
.9019 .30291 Mdot
.90381 .33605 Mdot
.90571 .43692 Mdot
.90762 .33737 Mdot
.90952 .28317 Mdot
.91143 .40627 Mdot
.91333 .27791 Mdot
.91524 .38127 Mdot
.91714 .31481 Mdot
.91905 .35943 Mdot
.92095 .41575 Mdot
.92286 .39144 Mdot
.92476 .35221 Mdot
.92667 .25792 Mdot
.92857 .29723 Mdot
.93048 .46395 Mdot
.93238 .30622 Mdot
.93429 .29311 Mdot
.93619 .27106 Mdot
.9381 .3552 Mdot
.94 .28859 Mdot
.9419 .30002 Mdot
.94381 .24925 Mdot
.94571 .30089 Mdot
.94762 .32413 Mdot
.94952 .27546 Mdot
.95143 .24167 Mdot
.95333 .33801 Mdot
.95524 .39667 Mdot
.95714 .32531 Mdot
.95905 .34348 Mdot
.96095 .26762 Mdot
.96286 .27046 Mdot
.96476 .26669 Mdot
.96667 .35016 Mdot
.96857 .34678 Mdot
.97048 .37996 Mdot
.97238 .32627 Mdot
.97429 .42192 Mdot
.97619 .32846 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`1Fooooo`;o00002oooool2o`0006cooooo0_l0001Yooooo`001?l00002ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool07oooool2o`0000oooooo0_l0000Tooooo`;o00002oooool2o`0006cooooo0_l0
001Yooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00omgMgOo<S8booooo`04ooooo`?o00004?ooool2o`0000gooooo0_l0000?ooooo`;o0000;?oo
ool2o`000=cooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`04ooooo`;o0000
00?oooooo`000?l000001oooool2o`0001;ooooo0_l0000Oooooo`Go00005?ooool2o`0000Wooooo
0_l0000Uooooo`;o0000:oooool2o`0007gooooo0006ooooo`05oa0@4?ooooooooooooooool@4100
3oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1?ooool2o`000003ooooool0003o000000;o00006Oooool2o`0001?ooooo0_l0000:ooooo`Go0000
7oooool2o`0000Wooooo0_l0000Jooooo`;o0000:oooool2o`0007gooooo0006ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`09ooooo`Co00006?ooool2o`0001;ooooo0_l0000Pooooo`;o
00005oooool2o`0008cooooo0_l00003ooooo`;o00007_ooool2o`0001?ooooo0006ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006oooo
o`03o`000?oooooooooo00_ooooo0_l00005ooooo`;o00004Oooool2o`0001kooooo0_l0000Doooo
o`;o0000Hoooool2o`00043ooooo0_l00003ooooo`Co00001Oooool2o`0001Gooooo0_l0000Coooo
o`00:Oooool2o`0001?ooooo0_l00009ooooo`;o00003?ooool2o`0001Oooooo0ol0000hooooo`;o
000000Coooooo`000?l0003ooooo0_l0000eooooo`;o00000_ooool2o`0003oooooo0_l00006oooo
o`;o00001Oooool2o`0001;ooooo0_l0000Fooooo`00:Oooool01?l0003oooooooooooooool2o`00
01[ooooo0_l0000<ooooo`?o00005_ooool2o`0000cooooo0_l0000[ooooo`;o000000Coooooo`00
0?l0003ooooo0_l0000Eooooo`;o00007_ooool2o`0004?ooooo0_l0000@ooooo`;o00003oooool2
o`0001Kooooo000Yooooo`04o`000?ooooooooooooooo`;o00006_ooool3o`0000;ooooo0_l00008
ooooo`;o00009?ooool2o`0002_ooooo0_l0000Kooooo`;o00009oooool2o`0001Sooooo0_l0000Y
ooooo`;o00001oooool2o`0002Oooooo000Yooooo`03o`000?oooooooooo00?ooooo0_l00005oooo
o`;o00004_ooool2o`0000;ooooo0_l00003ooooo`;o00001oooool2o`0000oooooo0_l0000joooo
o`?o00003Oooool2o`0000oooooo0_l00008ooooo`;o00006oooool2o`0000_ooooo1?l00009oooo
o`;o00005_ooool4o`0000oooooo0_l0000Cooooo`;o00006oooool002Wooooo00Go0000ooooool0
003o0000ooooo`03o`0000Gooooo0_l000000ooooooo0000o`000002o`0000Gooooo0_l00007oooo
o`;o00001_ooool2o`0000Kooooo0ol0000>ooooo`?o00001_ooool2o`0000;ooooo0_l0000^oooo
o`?o00003Oooool2o`0000oooooo0_l00008ooooo`;o00003_ooool2o`0001Sooooo1?l0000Goooo
o`Co00001_ooool4o`0002Cooooo0_l0000Kooooo`00:Oooool4o`000003ooooool0003o000000Wo
oooo1Ol00004ooooo`Co00001Oooool2o`0000kooooo0_l0000?ooooo`;o00001oooool2o`0000;o
oooo0_l0000Oooooo`;o00003Oooool2o`0000Cooooo0_l0000?ooooo`;o00003_ooool2o`0001;o
oooo0_l0000@ooooo`;o00006_ooool2o`0000Gooooo1?l0000Jooooo`;o00000_ooool2o`0002_o
oooo000Yooooo`03o`000?oooooooooo013ooooo0_l00006ooooo`;o00009oooool2o`0000Kooooo
0_l0000Sooooo`?o00003?ooool2o`0000Cooooo0_l0000?ooooo`;o00001Oooool2o`0000Oooooo
0_l0000Tooooo`;o00006_ooool3o`0000Kooooo0_l0000>ooooo`;o00002_ooool2o`0000;ooooo
0ol0000Hooooo`?o00003oooool002Wooooo00?o0000ooooooooool0<?ooool4o`000008oa0@4?oo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000o`000?o^k^h01Oooool2
o`0002;ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^01Wooooo0_l0000=ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Xooooo`Co000000Wo410@
ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo0_l0000?ooooo`;o00004?ooool2o`000006oooooom4A4Co0000o`000?lb<S;ogMgM0ol0
00001?lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool002Wooooo
00?o0000ooooooooool0<_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg02Wooooo00?oV9RHob4Q8Oo^k^h00_l00003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg02Sooooo00Go
410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg013ooooo0_l0000Iooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`02ooooo`;o000000CoV9RHoooooonHV9SoMgMg0_l0000Tooooo`;o00001?oo
ool02OmgMgOo<S8bo`000?l0003oMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool002Wooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@02[ooooo00Co
V9RHob4Q8Ol0003o00000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooooooooa0@400:ooooo`;o00008?ooool3o`000006ooooool@413o0000o`000?oooooo410@0ooo
ool01_l@413ooooooooooooooooo410@ooooo`;o00003Oooool2o`0001Kooooo1Ol00003ooooo`05
oa0@4?ooooooooooooooool@41000_ooool2o`0000?ooooo00?o410@o`000?l00000:?ooool2o`00
0005ooooool0003oooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o
410@ooooooooool00Oooool002Wooooo0_l0000=ooooo`;o00009?ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000002_ooooo
00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`00000:ooooo`;o00004oooool2o`0000[ooooo00GoZJVYoa0@4?l0003o0000ooooo`03
o`000003ooooool0003ooooo00;ooooo00Ko0000ooooooooooooooooo`000?ooool2o`0000Kooooo
0_l0000Fooooo`;o00001Oooool01?m4A4CogMgMooooool00004ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000001kooooo0_l0000:ooooo`;o000000GoMgMg
oc8b<_ooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`01ooooo`00:Oooool3o`0000cooooo0_l00009ooooo`;o00006Oooool00ol0003ooooooooo
o`02ooooo`06o`000?ooooooooooooooool0003ooooo0ol00003ooooo`;o00003oooool2o`0000co
oooo0_l0000<ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000007oooool2o`0000Wooooo00?o410@o`000?nj^[X00oooool0
1Ol0003ooooooooooooooooo000000?ooooo0_l00002ooooo`03o`000?oooooooooo00Oooooo0_l0
0003ooooo`;o00004Oooool2o`0000Gooooo00GogMgMoeEEEOoooooo0000ooooo`02o`000003oooo
ool0003ooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo01_o
oooo0ol00009ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`00:Oooool3o`0000Gooooo0_l00003
ooooo`;o00002oooool2o`0001Wooooo00Co0000oooooooooooooooo0_l00003ooooo`05oa0@4?oo
oooo0000o`000?l@41000oooool2o`0000oooooo0_l00002ooooo`Co00001_ooool2o`0000gooooo
00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@
413oooooooooo`0Yooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4003
ooooo`;o00000_ooool00ol@413oooooooooo`0<ooooo`;o00003oooool2o`0000Sooooo00CoMgMg
olc<c?l0003ooooo0_l000000ooooooo410@ooooo`02ooooo`;o00000_ooool01Ol@413ooooooooo
oooooooo410@013ooooo0_l0000;ooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`05oa0@
4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo000Yooooo`03
o`000?oooooooooo00Gooooo0_l00003ooooo`;o00009_ooool01?l0003oooooooooooooool4o`00
0003oiRHV?mgMgOooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Dooooo`Co00004Oooool0
1Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`;o0000
00CoV9RHoooooonHV9SoMgMg6?ooool2o`0000kooooo00?o410@oiRHV?l000000_l00003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOo0000o`000?nHV9SoMgMg00Sooooo0_l0000E
ooooo`;o00002?ooool00oo^k^koA4A4o`000004ooooo`04ogMgMonHV9SooooooiRHV0;o00000_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00;o00003_ooool2o`0001Gooooo0ol00006ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000Yooooo`03
o`000?oooooooooo01Wooooo0_l0000Eooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^o`000?l0
003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:Oooool01OnHV9So410@o`000?lQ
8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`;o000000Co<S8bo`000?lb<S;o
k^k^6?ooool2o`0000kooooo00GoZJVYoa0@4?l0003o0000ojVYZ@03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko0000o`000?lb<S;ok^k^00Cooooo0_l00002ooooo`;o00008?oo
ool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00;o00008oooool8o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool002Wooooo0_l0000Booooo`;o00001_ooool2o`00
04cooooo0_l00008ooooo`;o0000D?ooool2o`0003Gooooo0_l00003ooooo`;o00008?ooool2o`00
01Wooooo000Yooooo`03o`000?oooooooooo017ooooo0_l0000Hooooo`;o00001Oooool2o`0003?o
oooo0_l00008ooooo`;o00000oooool2o`0000cooooo0_l0000Tooooo`;o00002oooool2o`0000;o
oooo0_l0000>ooooo`;o00000oooool2o`0000Cooooo0_l00002ooooo`;o00001Oooool4o`0001Go
oooo0_l00003ooooo`;o00007_ooool2o`0001_ooooo000Yooooo`04o`000?ooooooooooooooo`;o
0000:?ooool2o`0000Gooooo0_l0000Hooooo`;o0000:?ooool2o`0000cooooo0_l0000Tooooo`;o
00001_ooool2o`0000?ooooo0_l00002ooooo`;o00003_ooool2o`0000?ooooo0_l00004ooooo`;o
00000_ooool2o`0000Gooooo1?l00009ooooo`;o00001oooool2o`0000_ooooo0_l00006ooooo`;o
00004Oooool2o`0000;ooooo1?l0000Eooooo`00:Oooool01?l0003oooooooooooooool2o`000003
ooooool0003o000003Gooooo1?l0000=ooooo`;o0000:Oooool4o`00027ooooo0_l0000Dooooo`;o
00004_ooool2o`0000?ooooo0_l0000Dooooo`;o00002oooool2o`0000Oooooo0_l00005ooooo`;o
00001?ooool2o`0000Kooooo0_l00009ooooo`;o00002_ooool4o`0001Gooooo000Yooooo`03o`00
0?oooooooooo00Cooooo0_l0000eooooo`Co000000?oooooo`000?l000003Oooool2o`0002Kooooo
1?l0000@ooooo`;o00000_ooool2o`0000_ooooo0_l0000Xooooo`;o00000oooool2o`0000Oooooo
0_l00002ooooo`;o00007?ooool4o`0000Cooooo0_l00008ooooo`;o00003Oooool2o`0000Oooooo
0_l0000Jooooo`008Oooooooo`0004Co00001?ooool002Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool2
o`0000Cooooo00?o0000ooooooooool01oooool3o`0000cooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo1?l00003ooooo`03o`000?oooooo
oooo00[ooooo0_l0000:ooooo`04o`000?oooooo0000o`0000Sooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`;o00002oooool00ol0003oooooooooo`02ooooo`;o00001Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Ooo
ool01?l0003oooooo`000?l00006ooooo`?o000000?oooooo`000?l000001oooool3o`000004oooo
ool0003o0000ooooo`;o00001?ooool2o`0000_ooooo00?o0000ooooooooool00_ooool2o`0000Go
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`00:Oooool00ol0003ooooo
ooooo`0Dooooo`?o00003oooool2o`0001;ooooo00?o0000ooooooooool07_ooool2o`0000Oooooo
1?l0000>ooooo`Go0000:?ooool2o`00013ooooo0_l0000Looooo`;o00007?ooool2o`000003oooo
ool0003o000000Oooooo0_l00005ooooo`;o00001?ooool2o`00013ooooo0_l0000Aooooo`03o`00
0?oooooooooo00[ooooo000Yooooo`03o`000?oooooooooo01Cooooo0ol00003ooooo`Co00002?oo
ool5o`00033ooooo0_l0000Iooooo`;o000000?oooooo`000?l000003_ooool2o`0001Cooooo0_l0
0002ooooo`;o00002oooool2o`0000?ooooo0_l0000:ooooo`;o00004?ooool2o`0001Gooooo0_l0
0005ooooo`;o0000BOooool002Wooooo00?o0000ooooooooool06_ooool4o`0000Wooooo1?l00008
ooooo`;o00007?ooool2o`00017ooooo0_l0000Jooooo`;o00001oooool2o`0001Cooooo0_l0000<
ooooo`;o000000?oooooo`000?l000003oooool2o`0002Oooooo0_l00006ooooo`;o0000<Oooool2
o`0001Gooooo000Yooooo`;o00000oooool2o`000003ooooool0003o000002cooooo1?l00008oooo
o`;o00004?ooool2o`0000cooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`00
00Kooooo0_l0000;ooooo`;o00002?ooool2o`0000Kooooo0_l00004ooooo`;o00002oooool2o`00
00Kooooo0_l0000Oooooo`;o00008_ooool2o`00023ooooo0_l0000?ooooo`;o000000?oooooo`00
0?l000000oooool2o`0000gooooo000Yooooo`03o`000?oooooooooo00;ooooo0_l000001?oooooo
0000o`000?l0000Mooooo`;o00002oooool2o`000003ooooool0003o000000Sooooo0_l00002oooo
o`;o00003_ooool2o`0000[ooooo0_l00006ooooo`;o00000_ooool2o`0000Kooooo0_l0000Eoooo
o`;o00001_ooool2o`0000Cooooo0_l0000;ooooo`;o00005oooool2o`0000kooooo0_l0000<oooo
o`;o0000=?ooool4o`0001;ooooo0_l00003ooooo`Co00002oooool002Wooooo00Co0000ooooool0
003o00001Oooool2o`0001gooooo0_l0000:ooooo`?o00000_ooool2o`0000Kooooo0_l00003oooo
o`;o00002Oooool2o`0000?ooooo0ol00012ooooo`;o00002?ooool2o`0001[ooooo0_l0000Loooo
o`;o000000?oooooo`000?l000008Oooool2o`0000kooooo0_l0000Kooooo`;o00002oooool002Wo
oooo00Co0000ooooool0003o00003_ooool2o`0001;ooooo0_l00009ooooo`;o000000?oooooo`00
0?l000000oooool2o`0000Kooooo0_l0000>ooooo`;o00001?ooool2o`0002Cooooo0_l0000;oooo
o`;o00002oooool2o`0000cooooo0_l0000Uooooo`;o00001_ooool2o`0000cooooo0_l0000Qoooo
o`;o00003Oooool2o`0000Cooooo0_l0000Sooooo`00:Oooool00ol0003oooooooooo`0?ooooo`;o
00004_ooool2o`0000Wooooo0_l0001:ooooo`;o00002oooool2o`0000_ooooo0_l0000cooooo`;o
00001_ooool2o`0001_ooooo0_l0000Iooooo`;o00001_ooool2o`0000Cooooo0ol0000=ooooo`;o
00004oooool002Wooooo0_l0000_ooooo`;o0000??ooool2o`0002oooooo0_l0000Yooooo`;o0000
0oooool3o`0001kooooo0_l00009ooooo`;o00003_ooool2o`0000gooooo0_l0000=ooooo`;o0000
4oooool002Wooooo0_l0000>ooooo`;o00006oooool2o`00043ooooo0_l0000Cooooo`;o00002Ooo
ool2o`0000oooooo0_l0000<ooooo`;o00006oooool2o`0000?ooooo0ol0000Rooooo`;o00001Ooo
ool2o`0001?ooooo0_l0000Iooooo`;o00004Oooool002Wooooo0_l00009ooooo`;o00000oooool2
o`0001Wooooo1?l00011ooooo`;o00004_ooool2o`0000Wooooo0_l00005ooooo`;o00004_ooool2
o`0000;ooooo0_l0000@ooooo`;o00000_ooool2o`0000gooooo0_l00006ooooo`;o00004_ooool2
o`0000Cooooo0_l0000Jooooo`;o00000_ooool2o`0001Gooooo0_l000000ooooooo0000o`00000>
ooooo`00:Oooool00ol0003oooooooooo`02o`0000Kooooo0_l0000Nooooo`;o0000@oooool2o`00
00_ooooo0_l0000;ooooo`?o00002?ooool3o`000003ooooool0003o000000oooooo0_l00005oooo
o`;o00003Oooool2o`0000;ooooo0_l00003ooooo`;o00002?ooool2o`0000Kooooo0_l00002oooo
o`;o00003_ooool2o`0002Cooooo0_l0000:ooooo`;o00002oooool3o`0000kooooo000Yooooo`03
o`000?oooooooooo00;o00001Oooool2o`0002Cooooo0_l0000Oooooo`;o00001Oooool4o`00027o
oooo0_l00009ooooo`Go00002?ooool2o`0000;ooooo0_l0000Fooooo`;o00005_ooool2o`0000Co
oooo0_l0000=ooooo`?o0000@?ooool2o`0000;ooooo0_l00007ooooo`;o00003oooool002Wooooo
0_l00008ooooo`;o00005oooool2o`0000_ooooo0_l0000?ooooo`;o00003_ooool2o`0000Gooooo
1Ol0000[ooooo`;o00000_ooool2o`0002;ooooo0_l00007ooooo`;o00003?ooool2o`0000Kooooo
0_l0000=ooooo`;o0000<?ooool2o`0001?ooooo0_l0000Hooooo`00:Oooool00ol0003ooooooooo
o`0Pooooo`;o00007?ooool2o`0001Sooooo0_l0000>ooooo`;o00007oooool2o`0001Cooooo0_l0
0006ooooo`;o00001?ooool2o`0000Oooooo0_l0000<ooooo`;o0000;_ooool3o`0001Kooooo0_l0
0006ooooo`;o00001Oooool2o`0001kooooo000Yooooo`03o`000?oooooooooo01[ooooo0_l00004
ooooo`;o0000A_ooool2o`0001;ooooo0_l0000Qooooo`;o00001?ooool4o`0000Wooooo0_l0000^
ooooo`;o00004?ooool3o`0001Kooooo0_l00006ooooo`;o00001Oooool2o`0001kooooo000Yoooo
o`03o`000?oooooooooo01[ooooo0_l00004ooooo`;o00004Oooool2o`0000Gooooo0_l0000?oooo
o`;o0000;oooool2o`0002Oooooo0_l0000:ooooo`?o0000;_ooool2o`0005Sooooo000Yooooo`03
o`000?oooooooooo03?ooooo0_l00005ooooo`;o00003oooool2o`0002Cooooo0_l00004ooooo`;o
00007?ooool2o`0001[ooooo0_l0000dooooo`;o00000_ooool2o`0004oooooo000Yooooo`;o0000
L_ooool2o`0000Cooooo0_l0000Looooo`;o00001_ooool2o`0000[ooooo0_l0000:ooooo`;o0000
9oooool2o`0000Oooooo0_l00002ooooo`;o0000Coooool002Wooooo00?o0000ooooooooool0>ooo
ool2o`0002Cooooo0_l00007ooooo`;o00008Oooool2o`0000kooooo0_l000000ooooooo0000o`00
0007ooooo`;o00002_ooool2o`0002;ooooo0_l00003ooooo`;o00006oooool2o`0003oooooo0006
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0kooooo`;o00007?ooool2o`000003oooo
ool0003o000000?ooooo0_l00007ooooo`;o00005_ooool2o`0000Wooooo0_l0000Aooooo`;o0000
4Oooool2o`0000?ooooo0ol0000Nooooo`;o00008?ooool2o`0000Wooooo0_l0000Uooooo`;o0000
3Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Q
onk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Eooooo`;o
0000=_ooool2o`0000[ooooo0_l000000ooooooo0000o`00000Tooooo`;o0000;oooool2o`000003
ooooool0003o000000?o0000;_ooool2o`0001_ooooo0_l00007ooooo`;o00002_ooool2o`00013o
oooo0_l0000=ooooo`001_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^
k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo0_l00007ooooo`;o
0000=_ooool2o`0002cooooo0_l0000Booooo`?o00009?ooool2o`0001kooooo0_l0000<ooooo`;o
00000oooool2o`0002Cooooo0_l0000:ooooo`;o00007oooool000Kooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0000co
oooo0_l0000Vooooo`;o00001_ooool2o`0003gooooo0_l00004ooooo`;o00003?ooool3o`0001co
oooo0_l0000Vooooo`;o00001Oooool2o`0000Gooooo0_l0000Mooooo`;o0000=oooool000Kooooo
00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c005ooooo`03o`000?oooooooooo03Cooooo0_l00004ooooo`Co00009Oooool2o`00
00Wooooo0_l0000Aooooo`;o0000:oooool2o`0002gooooo0_l00005ooooo`;o00000oooool2o`00
01Sooooo0_l0000Hooooo`;o00007Oooool000Kooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Boooo
o`;o00000oooool2o`00027ooooo0_l0000Wooooo`;o00002Oooool2o`0001Cooooo0_l0001Moooo
o`Go000000?oooooo`000?l000007?ooool2o`0001Cooooo0_l0000Mooooo`001_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooo
oooo00Oooooo0_l0000Cooooo`;o00000oooool2o`0000Sooooo0_l0000Booooo`;o00009oooool2
o`0002Cooooo0_l0000Jooooo`;o00002Oooool2o`0001;ooooo0_l0000Rooooo`;o000000?ooooo
o`000?l000007oooool2o`0000cooooo0_l0000Aooooo`;o00004_ooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0
000Dooooo`;o00000oooool2o`0000Oooooo0_l0000Booooo`;o00002oooool2o`0000;ooooo0_l0
000Fooooo`;o0000@?ooool2o`000003ooooool0003o000000Kooooo0_l0000Booooo`;o00005_oo
ool2o`0003cooooo0_l0000Aooooo`;o00004_ooool002Wooooo0_l0000Dooooo`;o00000oooool2
o`0002Sooooo0_l00002ooooo`;o0000F_ooool3o`0003;ooooo0_l0000/ooooo`;o0000=Oooool0
02Wooooo00?o0000ooooooooool0Uoooool2o`0000Wooooo0_l0001Qooooo`;o00003oooool2o`00
00;ooooo0_l0000Pooooo`00:Oooool00ol0003oooooooooo`1:ooooo`;o00001?ooool2o`0000Co
oooo0_l0000Jooooo`;o00008oooool4o`0002kooooo0_l0001;ooooo`;o00000_ooool2o`00023o
oooo000Yooooo`03o`000?oooooooooo04[ooooo0_l00004ooooo`;o00001?ooool2o`0000kooooo
0_l0000:ooooo`;o000000?oooooo`000?l000008_ooool2o`0002kooooo0_l0000>ooooo`;o0000
HOooool002Wooooo00?o0000ooooooooool0=oooool2o`0002?ooooo0_l000000ooooooo0000o`00
0005ooooo`;o00003Oooool2o`0001kooooo0_l0000looooo`;o00001?ooool2o`0000[ooooo0_l0
000fooooo`;o00007Oooool002Wooooo0_l0000:ooooo`;o0000;?ooool2o`0001Sooooo0_l00009
ooooo`;o000000?oooooo`000?l000001?ooool2o`0002kooooo0_l0000?ooooo`;o0000:oooool2
o`00013ooooo0_l0000fooooo`;o00007Oooool002Wooooo00?o0000ooooooooool02Oooool2o`00
013ooooo0_l0000dooooo`;o00004_ooool2o`0000;ooooo0_l0000kooooo`;o00007Oooool2o`00
02Cooooo0_l0000Hooooo`;o00009oooool2o`0000cooooo000Yooooo`03o`000?oooooooooo00ko
oooo0_l00004ooooo`;o00001Oooool3o`0000Gooooo0_l00005ooooo`;o00007?ooool2o`0001?o
oooo0_l0000:ooooo`Go0000:Oooool2o`0002cooooo0_l0000Tooooo`;o00006?ooool2o`0002Oo
oooo0_l0000<ooooo`00:Oooool00ol0003oooooooooo`0>ooooo`;o00001?ooool2o`0000Kooooo
0_l00005ooooo`;o00001Oooool2o`000003ooooool0003o000001Wooooo0_l00006ooooo`;o0000
2oooool2o`000003ooooool0003o000000Wooooo0ol0000Yooooo`;o00004Oooool2o`0006Sooooo
0_l0000Vooooo`00:Oooool00ol0003oooooooooo`0]ooooo`;o00008Oooool2o`0000kooooo0_l0
0018ooooo`;o00001?ooool2o`0004Sooooo0_l0000Hooooo`;o00009_ooool002Wooooo0_l0001<
ooooo`;o00008_ooool2o`0003oooooo0_l0000@ooooo`;o0000=_ooool2o`00043ooooo000Yoooo
o`03o`000?oooooooooo04_ooooo0_l0000Rooooo`;o0000DOooool2o`0005Cooooo0_l0000Roooo
o`00:Oooool00ol0003oooooooooo`3ooooooaWooooo0_l0000Rooooo`00:Oooool00ol0003ooooo
ooooo`2nooooo`;o0000O?ooool002Wooooo00?o0000ooooooooool0FOooool2o`0001Oooooo0_l0
001:ooooo`;o0000O?ooool002Wooooo0_l0001Jooooo`;o00005oooool2o`0001[ooooo0_l0002/
ooooo`00:Oooool00ol0003oooooooooo`2>ooooo`;o00009?ooool2o`0004[ooooo0_l0000joooo
o`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool00ol0003oooooooooo`17ooooo`;o0000Joooool2o`0003_ooooo0_l0000=
ooooo`;o0000>_ooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo04Oooooo0_l0000:ooooo`;o00007oooool2
o`0001Cooooo0_l0000gooooo`;o00005_ooool2o`0001Cooooo0_l00019ooooo`003_ooool01Ol@
413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`0002;ooooo0_l0000_
ooooo`;o00007oooool2o`0001Cooooo0_l00005ooooo`;o0000<?ooool2o`00013ooooo0_l00004
ooooo`;o0000@oooool2o`0001[ooooo000>ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02;ooooo0_l0001]ooooo`;o0000@_ooool2
o`0004Wooooo0_l0000Jooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@
oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooo
oolmooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?oo
ool4o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo
00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo?Oooool0
00Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@
413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03
ooooo`?o0000oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Q
ooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool0
00Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@
oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo
1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
01oooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo?Oooool0027o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`00
0?oooooooooo00Gooooo0ol0003oooooocgooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001oooooo00?oEEEEofIVI_l00000
oooooom7ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .38862 Mdot
.02762 .39771 Mdot
.02952 .31071 Mdot
.03143 .29205 Mdot
.03333 .36318 Mdot
.03524 .26562 Mdot
.03714 .26985 Mdot
.03905 .25059 Mdot
.04095 .3651 Mdot
.04286 .34896 Mdot
.04476 .31914 Mdot
.04667 .22576 Mdot
.04857 .30242 Mdot
.05048 .34071 Mdot
.05238 .22855 Mdot
.05429 .27097 Mdot
.05619 .37856 Mdot
.0581 .29445 Mdot
.06 .29248 Mdot
.0619 .36524 Mdot
.06381 .28227 Mdot
.06571 .37068 Mdot
.06762 .34987 Mdot
.06952 .2771 Mdot
.07143 .27977 Mdot
.07333 .25277 Mdot
.07524 .28052 Mdot
.07714 .28392 Mdot
.07905 .38368 Mdot
.08095 .39344 Mdot
.08286 .25273 Mdot
.08476 .36878 Mdot
.08667 .27791 Mdot
.08857 .36185 Mdot
.09048 .31515 Mdot
.09238 .32189 Mdot
.09429 .43149 Mdot
.09619 .25625 Mdot
.0981 .4003 Mdot
.1 .22559 Mdot
.1019 .27594 Mdot
.10381 .34217 Mdot
.10571 .24716 Mdot
.10762 .39627 Mdot
.10952 .37372 Mdot
.11143 .3364 Mdot
.11333 .34197 Mdot
.11524 .40332 Mdot
.11714 .30652 Mdot
.11905 .38017 Mdot
.12095 .40421 Mdot
.12286 .41889 Mdot
.12476 .3701 Mdot
.12667 .27307 Mdot
.12857 .26728 Mdot
.13048 .32582 Mdot
.13238 .24358 Mdot
.13429 .37927 Mdot
.13619 .42328 Mdot
.1381 .36508 Mdot
.14 .32412 Mdot
.1419 .42798 Mdot
.14381 .40317 Mdot
.14571 .30538 Mdot
.14762 .27531 Mdot
.14952 .34967 Mdot
.15143 .34787 Mdot
.15333 .26246 Mdot
.15524 .25668 Mdot
.15714 .25615 Mdot
.15905 .38132 Mdot
.16095 .32043 Mdot
.16286 .34814 Mdot
.16476 .33826 Mdot
.16667 .40306 Mdot
.16857 .27332 Mdot
.17048 .36971 Mdot
.17238 .28567 Mdot
.17429 .41181 Mdot
.17619 .28686 Mdot
.1781 .24202 Mdot
.18 .39434 Mdot
.1819 .30937 Mdot
.18381 .33728 Mdot
.18571 .2882 Mdot
.18762 .27653 Mdot
.18952 .3628 Mdot
.19143 .354 Mdot
.19333 .37687 Mdot
.19524 .26508 Mdot
.19714 .28611 Mdot
.19905 .45966 Mdot
.20095 .33637 Mdot
.20286 .3494 Mdot
.20476 .33002 Mdot
.20667 .46669 Mdot
.20857 .34279 Mdot
.21048 .39831 Mdot
.21238 .3597 Mdot
.21429 .37865 Mdot
.21619 .3955 Mdot
.2181 .36756 Mdot
.22 .22605 Mdot
.2219 .40062 Mdot
.22381 .23414 Mdot
.22571 .35547 Mdot
.22762 .37784 Mdot
.22952 .31645 Mdot
.23143 .3368 Mdot
.23333 .25249 Mdot
.23524 .34812 Mdot
.23714 .29958 Mdot
.23905 .37126 Mdot
.24095 .33117 Mdot
.24286 .22135 Mdot
.24476 .30236 Mdot
.24667 .30602 Mdot
.24857 .3374 Mdot
.25048 .35322 Mdot
.25238 .42926 Mdot
.25429 .30244 Mdot
.25619 .40358 Mdot
.2581 .30688 Mdot
.26 .38727 Mdot
.2619 .25267 Mdot
.26381 .27548 Mdot
.26571 .34714 Mdot
.26762 .47057 Mdot
.26952 .39974 Mdot
.27143 .32946 Mdot
.27333 .35383 Mdot
.27524 .39997 Mdot
.27714 .22988 Mdot
.27905 .27203 Mdot
.28095 .24136 Mdot
.28286 .40356 Mdot
.28476 .43371 Mdot
.28667 .36975 Mdot
.28857 .348 Mdot
.29048 .25338 Mdot
.29238 .22992 Mdot
.29429 .45435 Mdot
.29619 .33257 Mdot
.2981 .26806 Mdot
.3 .37878 Mdot
.3019 .3494 Mdot
.30381 .30852 Mdot
.30571 .22914 Mdot
.30762 .32726 Mdot
.30952 .34881 Mdot
.31143 .38569 Mdot
.31333 .36252 Mdot
.31524 .25673 Mdot
.31714 .2742 Mdot
.31905 .31564 Mdot
.32095 .316 Mdot
.32286 .43002 Mdot
.32476 .40907 Mdot
.32667 .33562 Mdot
.32857 .43066 Mdot
.33048 .43105 Mdot
.33238 .25275 Mdot
.33429 .41219 Mdot
.33619 .26325 Mdot
.3381 .28958 Mdot
.34 .2475 Mdot
.3419 .39243 Mdot
.34381 .31414 Mdot
.34571 .23599 Mdot
.34762 .25417 Mdot
.34952 .43143 Mdot
.35143 .36207 Mdot
.35333 .33742 Mdot
.35524 .25399 Mdot
.35714 .36131 Mdot
.35905 .33776 Mdot
.36095 .27086 Mdot
.36286 .46814 Mdot
.36476 .31052 Mdot
.36667 .29675 Mdot
.36857 .38966 Mdot
.37048 .42662 Mdot
.37238 .23414 Mdot
.37429 .31806 Mdot
.37619 .28552 Mdot
.3781 .31057 Mdot
.38 .36917 Mdot
.3819 .4698 Mdot
.38381 .37561 Mdot
.38571 .256 Mdot
.38762 .24221 Mdot
.38952 .38249 Mdot
.39143 .34908 Mdot
.39333 .27807 Mdot
.39524 .41849 Mdot
.39714 .26894 Mdot
.39905 .31904 Mdot
.40095 .22611 Mdot
.40286 .35401 Mdot
.40476 .44849 Mdot
.40667 .368 Mdot
.40857 .27015 Mdot
.41048 .27292 Mdot
.41238 .32278 Mdot
.41429 .36205 Mdot
.41619 .43922 Mdot
.4181 .39733 Mdot
.42 .26491 Mdot
.4219 .28381 Mdot
.42381 .30485 Mdot
.42571 .2872 Mdot
.42762 .31428 Mdot
.42952 .34022 Mdot
.43143 .2929 Mdot
.43333 .23654 Mdot
.43524 .30401 Mdot
.43714 .39403 Mdot
.43905 .30612 Mdot
.44095 .26777 Mdot
.44286 .30926 Mdot
.44476 .35483 Mdot
.44667 .22576 Mdot
.44857 .31155 Mdot
.45048 .41795 Mdot
.45238 .23394 Mdot
.45429 .25603 Mdot
.45619 .28504 Mdot
.4581 .35811 Mdot
.46 .40242 Mdot
.4619 .33744 Mdot
.46381 .2291 Mdot
.46571 .41045 Mdot
.46762 .2577 Mdot
.46952 .31217 Mdot
.47143 .43428 Mdot
.47333 .34159 Mdot
.47524 .28446 Mdot
.47714 .39389 Mdot
.47905 .25317 Mdot
.48095 .40274 Mdot
.48286 .31339 Mdot
.48476 .399 Mdot
.48667 .42806 Mdot
.48857 .2456 Mdot
.49048 .25219 Mdot
.49238 .38136 Mdot
.49429 .36839 Mdot
.49619 .32456 Mdot
.4981 .42704 Mdot
.5 .36812 Mdot
.5019 .38162 Mdot
.50381 .40467 Mdot
.50571 .31168 Mdot
.50762 .29974 Mdot
.50952 .27846 Mdot
.51143 .42874 Mdot
.51333 .25002 Mdot
.51524 .25567 Mdot
.51714 .25469 Mdot
.51905 .27426 Mdot
.52095 .24981 Mdot
.52286 .41407 Mdot
.52476 .32578 Mdot
.52667 .28525 Mdot
.52857 .26687 Mdot
.53048 .32462 Mdot
.53238 .35924 Mdot
.53429 .37972 Mdot
.53619 .33671 Mdot
.5381 .25061 Mdot
.54 .3412 Mdot
.5419 .24936 Mdot
.54381 .3323 Mdot
.54571 .2588 Mdot
.54762 .34941 Mdot
.54952 .30576 Mdot
.55143 .42983 Mdot
.55333 .32378 Mdot
.55524 .34681 Mdot
.55714 .39776 Mdot
.55905 .32064 Mdot
.56095 .30543 Mdot
.56286 .39832 Mdot
.56476 .33036 Mdot
.56667 .32712 Mdot
.56857 .43017 Mdot
.57048 .22866 Mdot
.57238 .32025 Mdot
.57429 .29578 Mdot
.57619 .3556 Mdot
.5781 .30638 Mdot
.58 .34313 Mdot
.5819 .23632 Mdot
.58381 .46932 Mdot
.58571 .42414 Mdot
.58762 .22666 Mdot
.58952 .42154 Mdot
.59143 .28261 Mdot
.59333 .42973 Mdot
.59524 .40699 Mdot
.59714 .28131 Mdot
.59905 .22693 Mdot
.60095 .25509 Mdot
.60286 .29133 Mdot
.60476 .24103 Mdot
.60667 .40115 Mdot
.60857 .36794 Mdot
.61048 .26949 Mdot
.61238 .33798 Mdot
.61429 .39826 Mdot
.61619 .24759 Mdot
.6181 .26849 Mdot
.62 .34158 Mdot
.6219 .37878 Mdot
.62381 .31017 Mdot
.62571 .37557 Mdot
.62762 .31127 Mdot
.62952 .36465 Mdot
.63143 .35204 Mdot
.63333 .26141 Mdot
.63524 .32662 Mdot
.63714 .23764 Mdot
.63905 .36513 Mdot
.64095 .46298 Mdot
.64286 .25961 Mdot
.64476 .27433 Mdot
.64667 .33523 Mdot
.64857 .41221 Mdot
.65048 .35979 Mdot
.65238 .26591 Mdot
.65429 .27257 Mdot
.65619 .37933 Mdot
.6581 .23145 Mdot
.66 .42737 Mdot
.6619 .32879 Mdot
.66381 .35603 Mdot
.66571 .32939 Mdot
.66762 .32295 Mdot
.66952 .40146 Mdot
.67143 .25782 Mdot
.67333 .247 Mdot
.67524 .25297 Mdot
.67714 .36136 Mdot
.67905 .39086 Mdot
.68095 .24779 Mdot
.68286 .39681 Mdot
.68476 .30708 Mdot
.68667 .29891 Mdot
.68857 .28884 Mdot
.69048 .3639 Mdot
.69238 .38443 Mdot
.69429 .33916 Mdot
.69619 .32862 Mdot
.6981 .45371 Mdot
.7 .22633 Mdot
.7019 .43138 Mdot
.70381 .33044 Mdot
.70571 .27748 Mdot
.70762 .36913 Mdot
.70952 .35643 Mdot
.71143 .35106 Mdot
.71333 .22646 Mdot
.71524 .46607 Mdot
.71714 .25694 Mdot
.71905 .22902 Mdot
.72095 .24145 Mdot
.72286 .28138 Mdot
.72476 .32121 Mdot
.72667 .32966 Mdot
.72857 .23097 Mdot
.73048 .2479 Mdot
.73238 .31899 Mdot
.73429 .23526 Mdot
.73619 .24805 Mdot
.7381 .28613 Mdot
.74 .39354 Mdot
.7419 .39113 Mdot
.74381 .40234 Mdot
.74571 .43087 Mdot
.74762 .42243 Mdot
.74952 .35493 Mdot
.75143 .43388 Mdot
.75333 .35786 Mdot
.75524 .2596 Mdot
.75714 .21631 Mdot
.75905 .42821 Mdot
.76095 .32444 Mdot
.76286 .31034 Mdot
.76476 .33813 Mdot
.76667 .37555 Mdot
.76857 .27508 Mdot
.77048 .23709 Mdot
.77238 .25322 Mdot
.77429 .26545 Mdot
.77619 .34288 Mdot
.7781 .26954 Mdot
.78 .27426 Mdot
.7819 .39869 Mdot
.78381 .2342 Mdot
.78571 .41536 Mdot
.78762 .23693 Mdot
.78952 .37362 Mdot
.79143 .39989 Mdot
.79333 .37076 Mdot
.79524 .33465 Mdot
.79714 .34601 Mdot
.79905 .31452 Mdot
.80095 .23463 Mdot
.80286 .22616 Mdot
.80476 .28364 Mdot
.80667 .33851 Mdot
.80857 .28373 Mdot
.81048 .29516 Mdot
.81238 .35258 Mdot
.81429 .35371 Mdot
.81619 .28626 Mdot
.8181 .32651 Mdot
.82 .2551 Mdot
.8219 .32828 Mdot
.82381 .35935 Mdot
.82571 .36663 Mdot
.82762 .27006 Mdot
.82952 .26255 Mdot
.83143 .39504 Mdot
.83333 .25591 Mdot
.83524 .2917 Mdot
.83714 .30534 Mdot
.83905 .37772 Mdot
.84095 .33838 Mdot
.84286 .24882 Mdot
.84476 .25291 Mdot
.84667 .3412 Mdot
.84857 .46388 Mdot
.85048 .40282 Mdot
.85238 .25139 Mdot
.85429 .39967 Mdot
.85619 .26274 Mdot
.8581 .35108 Mdot
.86 .23427 Mdot
.8619 .31215 Mdot
.86381 .3832 Mdot
.86571 .3853 Mdot
.86762 .33751 Mdot
.86952 .26968 Mdot
.87143 .34523 Mdot
.87333 .26309 Mdot
.87524 .27068 Mdot
.87714 .45411 Mdot
.87905 .29885 Mdot
.88095 .2956 Mdot
.88286 .34674 Mdot
.88476 .32116 Mdot
.88667 .30915 Mdot
.88857 .33352 Mdot
.89048 .24946 Mdot
.89238 .32007 Mdot
.89429 .40696 Mdot
.89619 .40174 Mdot
.8981 .3715 Mdot
.9 .33929 Mdot
.9019 .23497 Mdot
.90381 .37736 Mdot
.90571 .47251 Mdot
.90762 .34486 Mdot
.90952 .22983 Mdot
.91143 .30991 Mdot
.91333 .33561 Mdot
.91524 .43038 Mdot
.91714 .24913 Mdot
.91905 .37626 Mdot
.92095 .36165 Mdot
.92286 .39602 Mdot
.92476 .30282 Mdot
.92667 .32754 Mdot
.92857 .36345 Mdot
.93048 .4272 Mdot
.93238 .24164 Mdot
.93429 .27375 Mdot
.93619 .25322 Mdot
.9381 .29065 Mdot
.94 .32268 Mdot
.9419 .2581 Mdot
.94381 .27803 Mdot
.94571 .24126 Mdot
.94762 .28421 Mdot
.94952 .25639 Mdot
.95143 .34746 Mdot
.95333 .36368 Mdot
.95524 .37284 Mdot
.95714 .25973 Mdot
.95905 .2852 Mdot
.96095 .3061 Mdot
.96286 .22696 Mdot
.96476 .30032 Mdot
.96667 .39969 Mdot
.96857 .41469 Mdot
.97048 .29409 Mdot
.97238 .26119 Mdot
.97429 .37835 Mdot
.97619 .22842 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003Yooooo`;o0000D_ooool0
02Wooooo00?o0000ooooooooool0@oooool2o`000:?ooooo0_l0001Booooo`001_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool0@oooool2o`000?Oooooo0006ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool01?ooool2o`0000oooooo0_l0000Tooooo`;o0000>Ooo
ool2o`0000cooooo0_l0000/ooooo`;o000000?oooooo`000?l000007oooool2o`0000;ooooo0_l0
000Kooooo`;o0000<Oooool2o`00013ooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`?o00003_ooool2o`0002Cooooo0_l0000Aooooo`;o00000oooool2o`0000;ooooo0_l0
000Mooooo`;o00003?ooool2o`0000Cooooo0_l0000Pooooo`;o00001?ooool2o`000003ooooool0
003o000001oooooo0_l00002ooooo`Co000000?oooooo`000?l000005_ooool2o`00023ooooo0_l0
000?ooooo`;o00000oooool2o`0000_ooooo0006ooooo`05o`000?ooooooooooooooool000003Ooo
ool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00005ooooo`;o0000=_oo
ool2o`0000oooooo0_l00003ooooo`;o00000_ooool2o`0001?ooooo0_l0000Hooooo`;o00000_oo
ool2o`00023ooooo0_l0000Jooooo`;o00004_ooool2o`000003ooooool0003o000003Sooooo0_l0
000Dooooo`;o00002oooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo03gooooo
0_l0000Uooooo`;o00001_ooool2o`0001;ooooo0_l00004ooooo`;o0000:?ooool2o`0001Kooooo
0_l0000Gooooo`;o00002Oooool2o`0000?ooooo0ol00002ooooo`;o00004Oooool2o`0000cooooo
0_l0000Sooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo06Cooooo0_l0000Jooooo`;o0000
;_ooool2o`0000oooooo0_l0000Nooooo`;o00002Oooool2o`0000?ooooo0ol00002ooooo`;o0000
4Oooool2o`0000cooooo0_l0000Sooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0;_ooool2o`0001oooooo0_l0000Pooooo`;o0000A?ooool2o`0000Sooooo0_l0000Iooooo`;o
0000@_ooool2o`0000?ooooo0_l0000Eooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`0Ooooo
o`;o00003Oooool2o`0001oooooo0_l0000Pooooo`;o00007oooool2o`0002?ooooo0_l0000Soooo
o`;o0000@_ooool2o`0000?ooooo0_l0000Eooooo`00:Oooool2o`0001Sooooo0_l00006ooooo`;o
0000@Oooool2o`0002kooooo0_l0000?ooooo`;o00005_ooool2o`00013ooooo0_l000000ooooooo
0000o`00000=ooooo`Co00008Oooool2o`0000gooooo0_l00007ooooo`;o00007_ooool002Wooooo
00Co0000oooooooooooooooo0_l00009ooooo`;o000000?oooooo`000?l000001_ooool2o`0002Oo
oooo0_l00007ooooo`;o00005?ooool2o`000003ooooool0003o000002kooooo0_l00006ooooo`Co
00001?ooool3o`0001Kooooo0_l0000@ooooo`;o000000?oooooo`000?l000003Oooool4o`00027o
oooo0_l000000ooooooo0000o`00000:ooooo`;o00001oooool2o`0001kooooo000Yooooo`04o`00
0?ooooooooooooooo`;o00002Oooool2o`000003ooooool0003o000002oooooo0_l00007ooooo`;o
00001oooool2o`0000_ooooo0_l00003ooooo`;o000000?oooooo`000?l000009_ooool2o`000003
ooooool0003o000000Kooooo1?l00004ooooo`;o00004_ooool2o`0001Kooooo0_l0000Mooooo`;o
00003Oooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0001Wooooo0_l0000Hoooo
o`00:Oooool00ol0003oooooooooo`0Dooooo`;o00004Oooool2o`0002Wooooo0_l00006ooooo`;o
00002?ooool2o`000003ooooool0003o000000Sooooo0_l0000Dooooo`;o00000_ooool2o`0000;o
oooo0_l00009ooooo`?o00001oooool2o`00013ooooo0_l0000Eooooo`?o00002oooool2o`00013o
oooo0_l0000=ooooo`;o00000oooool2o`000003ooooool0003o000001cooooo0ol000000ooooooo
0000o`00000Dooooo`00:Oooool00ol0003oooooooooo`0Dooooo`;o00004Oooool2o`00037ooooo
0_l0000Eooooo`;o00005?ooool2o`0000;ooooo0_l0000Gooooo`;o00006_ooool2o`000003oooo
ool0003o000000Sooooo0_l0000<ooooo`;o00002_ooool2o`0003[ooooo0_l000000ooooooo0000
o`000002o`0000?ooooo0_l0000=ooooo`00:Oooool2o`0002Oooooo0_l0000;ooooo`;o0000;?oo
ool2o`0001Wooooo0_l00012ooooo`;o000000?oooooo`000?l000008_ooool2o`0001Kooooo0_l0
0007ooooo`;o00000oooool2o`0001Wooooo0_l00003ooooo`;o00003Oooool002Wooooo00?o0000
ooooooooool00_l0000Looooo`;o00001_ooool2o`0000_ooooo0_l0000Oooooo`;o00002oooool2
o`0001Wooooo0_l00004ooooo`;o00006oooool2o`0002Gooooo0_l0000Vooooo`;o00003oooool2
o`0000Oooooo0_l00003ooooo`;o0000;Oooool002Wooooo00?o0000ooooooooool00ol00003oooo
o`;o00005_ooool2o`00013ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^013ooooo0_l0000Cooooo`;o00000_ooool5o`0000;o
oooo0_l000001?lb<S;o0000o`000?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_l0000K
ooooo`;o00002Oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP02ooooo`Co000000?o<S8bonk^k_ooool01_ooool2o`00027ooooo0_l000000ol@413ooooo
ooooo`04o`000003oc8b<_o^k^kooooo00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`;o
00002oooool4o`0001Gooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Yooooo`04o`000?oooooo
ooooooooo`;o00000oooool2o`0001Gooooo0_l0000<ooooo`;o00001Oooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00[o
oooo0_l0000;ooooo`;o00003?ooool2o`0000;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A002oooo
o`;o000000?oV9RHooooool000000_l00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool2
o`0000cooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0_ooool4o`000003oiRHV?mgMgOooooo00Cooooo0_l000000ooooooo0000o`00000Qooooo`03o`00
0?oooooooooo00;ooooo0_l000000oooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool2o`0000_ooooo1?l0000Aooooo`;o00001Oooool02OmgMgOo<S8booooooooooooMgMg
oiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wooooo00?o
0000ooooooooool02oooool2o`0000Sooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l0
0004ooooo`;o00001?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@4005ooooo`;o00000oooool2o`0000_ooooo0_l0000Aooooo`03oiRHV?lQ8B7ok^k^00Co
oooo00Co410@oooooooooooooooo0_l00002ooooo`05oa0@4?ooooooooooooooool@41006_ooool2
o`00013ooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`03ooooo`;o000000?oooooo`000?l000003oooool2o`0000gooooo
1ol000000ooooooo0000o`000002ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`0Sooooo`;o00001_ooool01?l0003oooooooooool@4103ooooo`05oa0@4?oooooooooo
ooooool@41000oooool00ol@413oooooooooo`01ooooo`00:Oooool2o`0000cooooo1?l000000ooo
oooo0000o`000003ooooo`;o00003Oooool2o`0000_ooooo0_l00004ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000Gooooo0_l0000Tooooo`04oiRHV?lQ
8B7ok^k^ooooo`?o00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool05?ooool2o`0001?ooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`00000Iooooo`;o00003Oooool01Om4A4CogMgMooooool0
003ooooo00;o000000?oooooo`000?ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool09_ooool2o`0000;ooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`01ooooo`00:Oooool00ol0003o
ooooooooo`09ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`00023ooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
000/ooooo`03ogMgMomVIVKooooo00?o00000oooool00ol0003oooooooooo`02o`0000?ooooo00?o
0000ooooooooool05?ooool2o`0001;ooooo00?o410@o`000?nj^[X00oooool5o`0000?ooooo00Go
0000ooooooooooooooooo`00000Nooooo`;o00002?ooool01?oMgMgoEEEEooooool00004ooooo`05
o`000?ooooooooooooooool000000oooool5o`0002Sooooo0_l000001?lQ8B7o0000oc8b<_o<c<`2
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
000Yooooo`03o`000?oooooooooo00Wooooo0_l00002ooooo`;o00007Oooool3o`0000?ooooo00Ko
0000ooooool0003o0000ooooool@4103ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@
413oooooooooo`0Xooooo`;o000000?oooooo`000?ooool00_ooool01Ol@413ooooooooooooooooo
410@00;ooooo0_l00003ooooo`03oa0@4?oooooooooo00?ooooo0_l00004ooooo`;o00003oooool2
o`0000gooooo00?o^[Zjob4Q8Oooool00_ooool00ol@413o0000o`000002o`0000?ooooo00Go410@
oooooooooooooooooa0@400Nooooo`;o00000oooool2o`0000Cooooo00?oMgMgolc<c?l000001?oo
ool01Ol@413ooooooooooooooooo410@00?ooooo1_l0000Xooooo`;o00000_ooool2o`000003oooo
ool@413ooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo007o
oooo000Yooooo`03o`000?oooooooooo02cooooo0ol000001Ooooooo0000o`000?l0003ooooo00;o
000000KoooooogMgMonHV9SooooooiRHV?mgMgL3ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07Ooo
ool2o`0000[ooooo0ol000000onHV9So410@ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool2o`000003oooooonHV9SoMgMg00Gooooo0_l00004ooooo`;o00003oooool2o`0000[ooooo
00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01?ooooo0_l0000>ooooo`;o00001?ooool00oo^k^koA4A4o`000004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01?mgMgOoV9RHoooooonHV9P2o`0002Sooooo
0_l00002ooooo`;o000000KoooooogMgMonHV9SooooooiRHV?mgMgL3ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool002Wooooo00Co0000ooooool0003o00001oooool2o`0002Kooooo0ol00004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo
0_l0000:ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo1?l000000oo^k^koooooooooo`0Vooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool0
1?o^k^ko<S8bo`000?lb<S82o`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Cooooo`;o0000
5Oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_l0000Oooooo`;o000000?oooooo`000?l000000_l00003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Y
ooooo`Co00001_ooool3o`0007Gooooo0_l0000/ooooo`;o00001oooool2o`00047ooooo0_l00006
ooooo`;o00003Oooool2o`00013ooooo0_l00009ooooo`;o00003Oooool002Wooooo00?o0000oooo
ooooool01oooool2o`0006;ooooo0_l00010ooooo`;o00008_ooool2o`0002Kooooo0_l0000Doooo
o`?o00006oooool2o`0000gooooo000Yooooo`03o`000?oooooooooo00Cooooo0_l0000kooooo`Co
000000?oooooo`000?l000008oooool2o`0002_ooooo0_l0000gooooo`;o0000??ooool2o`0001[o
oooo0_l0000?ooooo`00:Oooool00ol0003oooooooooo`04ooooo`;o00007Oooool2o`0001cooooo
1?l000000ooooooo0000o`00000eooooo`;o00000_ooool2o`0001Gooooo0_l0000?ooooo`;o0000
Eoooool2o`0001[ooooo0_l0000;ooooo`;o00003oooool002Wooooo00?o0000ooooooooool06_oo
ool2o`0000Oooooo0_l0000Oooooo`;o00000_ooool2o`0000cooooo0_l0000Uooooo`;o00000_oo
ool3o`00027ooooo0_l00002ooooo`;o00000oooool2o`00027ooooo0_l0000_ooooo`;o00006_oo
ool2o`0000[ooooo0_l0000@ooooo`008Oooooooo`0004Co00001?ooool002Wooooo0ol00009oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`?o00002Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool01?l0003oooooooooooooool2o`0000Gooooo0_l00002ooooo`;o00002?ooool0
0ol0003oooooooooo`03ooooo`;o00000oooool4o`0000Gooooo0_l00002ooooo`;o00001Oooool2
o`0000?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Gooooo0ol000000ooooooo0000ooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool01?l0003oooooooooooooool2o`0000Kooooo00Co0000oooooooooooooooo
0_l00006ooooo`03o`000?oooooooooo00Wooooo0_l00006ooooo`;o00000oooool00ol0003ooooo
ooooo`02o`0000Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`00:Ooo
ool00ol0003oooooooooo`0Booooo`;o00009_ooool01?l0003oooooooooooooool2o`0001_ooooo
0ol00005ooooo`;o00002?ooool2o`0000Wooooo00?o0000ooooooooool00oooool2o`0000cooooo
0_l00002ooooo`;o00008oooool00ol0003oooooooooo`0jooooo`04o`000?ooooooooooooooo`;o
00004_ooool2o`0002?ooooo00?o0000ooooooooool02_ooool002Wooooo00?o0000ooooooooool0
0oooool2o`0000gooooo0_l0000Dooooo`;o00005?ooool2o`0001_ooooo0ol0000?ooooo`;o0000
1_ooool2o`00037ooooo0_l00003ooooo`;o0000;oooool4o`0002oooooo0_l000000ooooooo0000
o`00000Vooooo`00:Oooool00ol0003oooooooooo`03ooooo`;o00003Oooool2o`0000kooooo0_l0
0004ooooo`;o0000Boooool2o`0000;ooooo0_l0000/ooooo`?o00000oooool2o`0001cooooo0_l0
000Aooooo`Co0000;oooool2o`000003ooooool0003o000000gooooo0_l0000Gooooo`00:Oooool2
o`0001?ooooo0_l0000;ooooo`;o000000?oooooo`000?l00000=?ooool2o`0001oooooo0_l0000I
ooooo`;o00001oooool4o`0000Kooooo0_l00002ooooo`;o00005?ooool2o`0000Sooooo0_l0000L
ooooo`;o00004Oooool2o`0002Gooooo0_l0000Gooooo`00:Oooool00ol0003oooooooooo`0Ooooo
o`;o00005Oooool2o`0001Cooooo0_l0000:ooooo`;o0000>_ooool2o`0000Oooooo1?l00009oooo
o`?o00005?ooool2o`0000Kooooo1?l00007ooooo`;o000000?oooooo`000?l000001Oooool2o`00
00Wooooo0_l0000Aooooo`?o00008?ooool2o`0001_ooooo000Yooooo`03o`000?oooooooooo03Ko
oooo0_l0000:ooooo`;o00002?ooool2o`0000Kooooo0_l0001=ooooo`;o00001Oooool2o`0001go
oooo1?l00007ooooo`;o000000?oooooo`000?l000001Oooool2o`0001gooooo0_l0000Cooooo`;o
00002oooool2o`0001_ooooo000Yooooo`03o`000?oooooooooo01Sooooo0_l0000Kooooo`;o0000
2?ooool2o`000003ooooool0003o0000013ooooo0_l00008ooooo`;o0000@Oooool4o`00023ooooo
0_l0000]ooooo`;o00007?ooool2o`0000Kooooo0_l0000Pooooo`00:Oooool00ol0003ooooooooo
o`0Hooooo`;o00004?ooool2o`0000Cooooo0_l00003ooooo`;o00002?ooool2o`0000Cooooo0_l0
000Gooooo`;o00001_ooool4o`0001oooooo0_l0000Fooooo`;o00005oooool2o`0000Wooooo0_l0
000=ooooo`;o00005Oooool2o`0000Oooooo0_l00002ooooo`;o00002Oooool2o`0000Oooooo0_l0
0008ooooo`;o00000_ooool2o`00023ooooo000Yooooo`;o00001_ooool2o`0000oooooo0_l00000
0ooooooo0000o`00000?ooooo`;o00001?ooool2o`0000Kooooo0_l0000;ooooo`;o00007oooool4
o`0001Gooooo0_l00008ooooo`;o00000_ooool2o`0001?ooooo0_l0000Fooooo`Co00005_ooool2
o`0001Gooooo0_l000000ooooooo0000o`000008ooooo`;o00002Oooool4o`0000Gooooo0_l00008
ooooo`;o00009?ooool002Wooooo00?o0000ooooooooool01Oooool2o`0000oooooo0_l000000ooo
oooo0000o`00000Mooooo`;o0000AOooool2o`0000cooooo0_l0000Cooooo`;o00002oooool2o`00
00_ooooo0_l0000`ooooo`;o00001Oooool2o`0000kooooo0_l00006ooooo`;o00002Oooool2o`00
02;ooooo000Yooooo`03o`000?oooooooooo00;ooooo0_l0000Qooooo`;o00000_ooool2o`0001Go
oooo0_l00008ooooo`;o00001Oooool2o`0000Gooooo0_l0000Hooooo`;o0000<oooool2o`0000Ko
oooo0_l00014ooooo`;o00005_ooool2o`000003ooooool0003o000000Kooooo0_l0000=ooooo`;o
00004oooool002Wooooo00?o0000ooooooooool00_ooool2o`0000Kooooo0_l0000Iooooo`;o0000
0_ooool2o`0000_ooooo0_l00008ooooo`;o00002?ooool2o`0000Gooooo0_l00003ooooo`Co0000
6?ooool2o`00037ooooo1?l0000Gooooo`;o00005oooool2o`0002kooooo0_l00005ooooo`;o0000
5Oooool2o`0001?ooooo000Yooooo`03o`000?oooooooooo00[ooooo0_l0000Iooooo`;o00002ooo
ool2o`0000;ooooo0_l00005ooooo`;o00001_ooool2o`0000Kooooo0_l00007ooooo`;o00007_oo
ool2o`0000cooooo0_l0000Oooooo`;o00006Oooool2o`0001Oooooo0_l0000;ooooo`;o00004_oo
ool2o`0000gooooo0_l0000aooooo`00:Oooool2o`0003?ooooo0_l00009ooooo`;o00001_ooool2
o`0000Kooooo0_l0000Wooooo`;o00003?ooool2o`0000;ooooo0_l0000Tooooo`;o00006_ooool2
o`0000gooooo0_l0000;ooooo`?o00004Oooool2o`00043ooooo000Yooooo`03o`000?oooooooooo
03Wooooo0_l0000/ooooo`;o00007oooool2o`0001Kooooo0_l0000<ooooo`;o00005_ooool2o`00
00;ooooo0_l00002ooooo`;o00002Oooool2o`0000cooooo0_l0000Eooooo`;o00007Oooool2o`00
01gooooo000Yooooo`04o`000?oooooo0000o`00013ooooo0_l0000Oooooo`;o00001Oooool2o`00
01kooooo0_l0000;ooooo`?o00004Oooool2o`0002Cooooo0_l0000Mooooo`;o00001Oooool2o`00
00Kooooo0_l00003ooooo`;o0000:Oooool2o`0001gooooo1?l00006ooooo`;o00004oooool002Wo
oooo00Go0000ooooool0003o0000ooooo`02o`0000Gooooo0_l00006ooooo`;o00003_ooool2o`00
00oooooo0_l00007ooooo`;o00007?ooool2o`0000_ooooo0_l0000Booooo`;o0000@oooool2o`00
0003ooooool0003o000000oooooo0_l0000Yooooo`;o00007oooool2o`0000Kooooo0_l0000Coooo
o`00:Oooool00ol0003oooooooooo`02ooooo`;o00001Oooool3o`0000Cooooo0_l0000;ooooo`;o
00000_ooool2o`0000Sooooo0_l0000>ooooo`;o00005?ooool2o`0001cooooo0_l00006ooooo`;o
00006oooool3o`00027ooooo0_l00008ooooo`;o00005?ooool2o`0001[ooooo0_l00008ooooo`;o
0000??ooool002Wooooo0_l0000;ooooo`;o00001?ooool2o`0000Kooooo0_l00003ooooo`;o0000
3?ooool2o`0001Cooooo0_l0000>ooooo`;o00007?ooool2o`0000Kooooo0_l0000Kooooo`?o0000
8Oooool2o`0001kooooo0_l0000Hooooo`Co00007oooool2o`00017ooooo0_l0000Booooo`00:Ooo
ool00ol0003oooooooooo`0Hooooo`;o00006Oooool2o`0000cooooo0_l0000]ooooo`;o0000C?oo
ool2o`0002_ooooo0_l00005ooooo`;o00008Oooool2o`0000Gooooo0_l0000:ooooo`;o00004_oo
ool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00Oooooo0_l0000Booooo`;o0000
0oooool2o`00017ooooo0_l00005ooooo`;o00000_ooool2o`0001Gooooo0_l0000Iooooo`;o0000
;_ooool2o`0001_ooooo0ol00008ooooo`;o00008Oooool2o`0001Gooooo0_l0000Cooooo`;o0000
0oooool2o`00013ooooo0_l0000<ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo00Oooooo0_l0000Booooo`;o00000oooool2o`0000Kooooo0_l0000@ooooo`;o
00000_ooool2o`0001Gooooo0_l0000Kooooo`;o00007oooool2o`000003ooooool0003o000000So
oooo0_l0000Kooooo`;o00002Oooool2o`0003Sooooo0_l00006ooooo`;o00002oooool2o`0001Go
oooo0_l0000<ooooo`001_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^
k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo0_l0000Hooooo`;o
0000;oooool2o`0001Oooooo0_l0000Oooooo`;o000000?oooooo`000?l00000>oooool2o`0003Go
oooo0ol0000_ooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^
k^h01oooool00omgMgOo<S8booooo`04ooooo`?o00003_ooool2o`0003Sooooo0_l0000?ooooo`;o
00004?ooool2o`0006Kooooo0_l0000fooooo`;o0000;oooool000Kooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005oooo
o`;o0000BOooool2o`0001Wooooo0_l00006ooooo`;o0000H_ooool2o`0001;ooooo0_l0001Goooo
o`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo0_l0000Mooooo`;o00002_ooool2o`00
02Oooooo0_l0000Looooo`;o00002oooool2o`0003oooooo0_l0000Booooo`;o00006oooool2o`00
03[ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@00Cooooo00?o0000ooooooooool01oooool2o`00013ooooo0_l00006ooooo`;o00005Oooool2
o`0000Sooooo1?l0000oooooo`;o00001?ooool2o`0000_ooooo1?l0000Fooooo`Co00003_ooool2
o`0001Cooooo0_l0000Aooooo`;o00002oooool2o`0000kooooo0_l0000Kooooo`;o00007Oooool0
00Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?oo
ool4o`0000Kooooo0_l0000Eooooo`;o000000?oooooo`000?l000007oooool2o`0000;ooooo0_l0
000=ooooo`Co0000;?ooool2o`0001?ooooo0_l0000Fooooo`Co00003?ooool4o`00013ooooo0_l0
0002ooooo`;o00007_ooool2o`000003ooooool0003o000001;ooooo0_l0000<ooooo`;o00001_oo
ool2o`0000cooooo0_l0000?ooooo`00:Oooool2o`0001Gooooo0_l00004ooooo`Co00001Oooool2
o`0000Gooooo0_l0000@ooooo`;o00002Oooool2o`0000;ooooo1?l000000ooooooo0000o`00000g
ooooo`;o00001?ooool2o`0000Kooooo0_l0000Oooooo`;o00004_ooool2o`0001Kooooo0_l0000=
ooooo`;o00004Oooool3o`0000cooooo0_l0000Dooooo`;o00003oooool002Wooooo00?o0000oooo
ooooool06_ooool4o`0000Gooooo0_l00005ooooo`;o00006oooool2o`0000Oooooo0_l0000goooo
o`;o00001?ooool2o`0000Kooooo0_l0000Kooooo`;o0000;_ooool2o`00023ooooo0_l0000<oooo
o`;o00009_ooool002Wooooo00?o0000ooooooooool0GOooool2o`0002_ooooo0_l0000Xooooo`;o
0000G_ooool2o`0002Kooooo000Yooooo`03o`000?oooooooooo02gooooo0_l0000^ooooo`;o0000
00?oooooo`000?l00000:?ooool2o`00017ooooo0_l0000Vooooo`;o0000MOooool002Wooooo00?o
0000ooooooooool0;Oooool2o`00037ooooo0_l0000kooooo`;o00009_ooool2o`0002[ooooo0_l0
000iooooo`;o00003_ooool002Wooooo0_l0000Mooooo`;o0000E_ooool2o`0000oooooo0_l0001Z
ooooo`;o0000>Oooool2o`0000kooooo000Yooooo`03o`000?oooooooooo01cooooo0_l00002oooo
o`;o0000D_ooool2o`0000oooooo0_l0000[ooooo`;o0000<Oooool2o`0005Gooooo000Yooooo`03
o`000?oooooooooo023ooooo0_l0001:ooooo`;o0000@oooool3o`00037ooooo0_l0001Eooooo`00
:Oooool00ol0003oooooooooo`0Rooooo`;o00008_ooool2o`0001Cooooo0_l0000>ooooo`;o0000
8oooool2o`0000;ooooo0_l00002ooooo`;o00002oooool2o`0000Wooooo1?l0000Dooooo`;o0000
7_ooool2o`0003Gooooo0_l0000Jooooo`00:Oooool00ol0003oooooooooo`0Cooooo`;o00003Ooo
ool2o`0002;ooooo0_l0000Dooooo`Go00001?ooool2o`0002[ooooo0_l00002ooooo`;o00000_oo
ool2o`0000_ooooo0_l00003ooooo`;o00001_ooool2o`0001Cooooo0_l0000;ooooo`;o00003?oo
ool2o`0000?ooooo0_l0000`ooooo`;o00000oooool2o`0001[ooooo000Yooooo`;o00005?ooool2
o`0003_ooooo0_l0000<ooooo`?o00001?ooool2o`0002Gooooo0_l0000Mooooo`;o0000:Oooool2
o`0000cooooo1?l0000cooooo`;o00007oooool002Wooooo00?o0000ooooooooool0D?ooool2o`00
02Sooooo0_l0000@ooooo`;o0000F?ooool2o`0005Cooooo000Yooooo`03o`000?oooooooooo07[o
oooo0_l00030ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo07Oooooo0_l00033ooooo`00:Oooool2o`0007Sooooo0_l00033ooooo`00:Oooool00ol0
003oooooooooo`1Cooooo`;o0000P?ooool2o`0003Sooooo0_l0000[ooooo`003_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`1Cooooo`;o0000P?ooool2o`0003Sooooo0_l0000[ooooo`003_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool0=Oooool2o`000?oooooo1_ooool000kooooo00Go410@oooooooooooooooooa0@400@
ooooo`03o`000?oooooooooo00?ooooo0ol0000eooooo`;o0000S?ooool2o`00043ooooo0_l0000e
ooooo`003_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`0gooooo`;o0000R_ooool2o`0001Kooooo0_l0000Xooooo`;o0000=Oooool0
00kooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`0gooooo`;o0000<?ooool2o`0000Cooooo0_l0000oooooo`;o0000:Ooo
ool2o`0005oooooo000>ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo04_ooooo0_l0000Looooo`;o00001?ooool2o`0003oooooo0_l0
001Vooooo`;o00008_ooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0Boooool2o`000<_ooooo0_l0000Rooooo`003_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGo
oooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000Kooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`3oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool0
0omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgoooo
o`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Oooooo`Co000000?o410@ooooooooool00oooool00ol0
003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`?o0000oooooolmooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Oooooo`03oeEEEOmVIVKo00000?ooooooAoooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .33169 Mdot
.02762 .40098 Mdot
.02952 .30057 Mdot
.03143 .33657 Mdot
.03333 .34343 Mdot
.03524 .25551 Mdot
.03714 .29526 Mdot
.03905 .36115 Mdot
.04095 .42608 Mdot
.04286 .32363 Mdot
.04476 .35102 Mdot
.04667 .31339 Mdot
.04857 .38267 Mdot
.05048 .34896 Mdot
.05238 .29072 Mdot
.05429 .27041 Mdot
.05619 .35462 Mdot
.0581 .37853 Mdot
.06 .25283 Mdot
.0619 .26617 Mdot
.06381 .37034 Mdot
.06571 .4058 Mdot
.06762 .39975 Mdot
.06952 .36797 Mdot
.07143 .23125 Mdot
.07333 .32458 Mdot
.07524 .33878 Mdot
.07714 .25629 Mdot
.07905 .29369 Mdot
.08095 .40198 Mdot
.08286 .34658 Mdot
.08476 .42847 Mdot
.08667 .3817 Mdot
.08857 .38008 Mdot
.09048 .37397 Mdot
.09238 .23528 Mdot
.09429 .41415 Mdot
.09619 .28581 Mdot
.0981 .32587 Mdot
.1 .29968 Mdot
.1019 .23237 Mdot
.10381 .38141 Mdot
.10571 .32673 Mdot
.10762 .3477 Mdot
.10952 .2988 Mdot
.11143 .36668 Mdot
.11333 .34462 Mdot
.11524 .43841 Mdot
.11714 .24583 Mdot
.11905 .28966 Mdot
.12095 .43779 Mdot
.12286 .36228 Mdot
.12476 .45115 Mdot
.12667 .35246 Mdot
.12857 .34933 Mdot
.13048 .40857 Mdot
.13238 .35336 Mdot
.13429 .35276 Mdot
.13619 .43428 Mdot
.1381 .28366 Mdot
.14 .3645 Mdot
.1419 .34392 Mdot
.14381 .33246 Mdot
.14571 .26091 Mdot
.14762 .37847 Mdot
.14952 .42074 Mdot
.15143 .31725 Mdot
.15333 .28284 Mdot
.15524 .28382 Mdot
.15714 .35151 Mdot
.15905 .36648 Mdot
.16095 .28409 Mdot
.16286 .32796 Mdot
.16476 .2853 Mdot
.16667 .33226 Mdot
.16857 .29787 Mdot
.17048 .45094 Mdot
.17238 .34992 Mdot
.17429 .34637 Mdot
.17619 .25019 Mdot
.1781 .27616 Mdot
.18 .40018 Mdot
.1819 .33938 Mdot
.18381 .3808 Mdot
.18571 .38915 Mdot
.18762 .26495 Mdot
.18952 .34806 Mdot
.19143 .3596 Mdot
.19333 .3369 Mdot
.19524 .27846 Mdot
.19714 .229 Mdot
.19905 .47252 Mdot
.20095 .29702 Mdot
.20286 .36465 Mdot
.20476 .28118 Mdot
.20667 .4688 Mdot
.20857 .3473 Mdot
.21048 .43534 Mdot
.21238 .44592 Mdot
.21429 .34017 Mdot
.21619 .35041 Mdot
.2181 .30962 Mdot
.22 .31261 Mdot
.2219 .36272 Mdot
.22381 .30829 Mdot
.22571 .38115 Mdot
.22762 .37378 Mdot
.22952 .25373 Mdot
.23143 .2985 Mdot
.23333 .34757 Mdot
.23524 .33915 Mdot
.23714 .33903 Mdot
.23905 .42912 Mdot
.24095 .23777 Mdot
.24286 .33542 Mdot
.24476 .26453 Mdot
.24667 .359 Mdot
.24857 .41622 Mdot
.25048 .42325 Mdot
.25238 .40966 Mdot
.25429 .3824 Mdot
.25619 .30258 Mdot
.2581 .38229 Mdot
.26 .29922 Mdot
.2619 .34795 Mdot
.26381 .32906 Mdot
.26571 .24832 Mdot
.26762 .45829 Mdot
.26952 .38338 Mdot
.27143 .3072 Mdot
.27333 .40193 Mdot
.27524 .36873 Mdot
.27714 .28369 Mdot
.27905 .25039 Mdot
.28095 .30174 Mdot
.28286 .32875 Mdot
.28476 .40703 Mdot
.28667 .27314 Mdot
.28857 .32524 Mdot
.29048 .36217 Mdot
.29238 .28528 Mdot
.29429 .39827 Mdot
.29619 .33535 Mdot
.2981 .26702 Mdot
.3 .35504 Mdot
.3019 .24954 Mdot
.30381 .40098 Mdot
.30571 .26519 Mdot
.30762 .26141 Mdot
.30952 .36295 Mdot
.31143 .27459 Mdot
.31333 .298 Mdot
.31524 .31883 Mdot
.31714 .3663 Mdot
.31905 .27568 Mdot
.32095 .24156 Mdot
.32286 .39437 Mdot
.32476 .3431 Mdot
.32667 .41474 Mdot
.32857 .41403 Mdot
.33048 .39748 Mdot
.33238 .27946 Mdot
.33429 .34623 Mdot
.33619 .23899 Mdot
.3381 .2361 Mdot
.34 .32618 Mdot
.3419 .34402 Mdot
.34381 .4039 Mdot
.34571 .29024 Mdot
.34762 .2912 Mdot
.34952 .39433 Mdot
.35143 .26473 Mdot
.35333 .31135 Mdot
.35524 .30993 Mdot
.35714 .3483 Mdot
.35905 .27244 Mdot
.36095 .37615 Mdot
.36286 .46581 Mdot
.36476 .24076 Mdot
.36667 .26529 Mdot
.36857 .30493 Mdot
.37048 .37868 Mdot
.37238 .27279 Mdot
.37429 .26046 Mdot
.37619 .2284 Mdot
.3781 .33106 Mdot
.38 .4269 Mdot
.3819 .45656 Mdot
.38381 .43207 Mdot
.38571 .24475 Mdot
.38762 .31427 Mdot
.38952 .27156 Mdot
.39143 .24917 Mdot
.39333 .26919 Mdot
.39524 .32859 Mdot
.39714 .37627 Mdot
.39905 .22467 Mdot
.40095 .30052 Mdot
.40286 .36191 Mdot
.40476 .47777 Mdot
.40667 .38343 Mdot
.40857 .28402 Mdot
.41048 .27972 Mdot
.41238 .29277 Mdot
.41429 .33854 Mdot
.41619 .47705 Mdot
.4181 .35896 Mdot
.42 .31197 Mdot
.4219 .24459 Mdot
.42381 .34071 Mdot
.42571 .32934 Mdot
.42762 .35092 Mdot
.42952 .39967 Mdot
.43143 .35337 Mdot
.43333 .28837 Mdot
.43524 .25675 Mdot
.43714 .34897 Mdot
.43905 .35813 Mdot
.44095 .23612 Mdot
.44286 .33215 Mdot
.44476 .26989 Mdot
.44667 .31759 Mdot
.44857 .36092 Mdot
.45048 .43404 Mdot
.45238 .30267 Mdot
.45429 .25678 Mdot
.45619 .26104 Mdot
.4581 .31484 Mdot
.46 .39688 Mdot
.4619 .30649 Mdot
.46381 .28851 Mdot
.46571 .31299 Mdot
.46762 .29647 Mdot
.46952 .31149 Mdot
.47143 .47482 Mdot
.47333 .26585 Mdot
.47524 .34127 Mdot
.47714 .28796 Mdot
.47905 .29838 Mdot
.48095 .3718 Mdot
.48286 .3863 Mdot
.48476 .36323 Mdot
.48667 .34455 Mdot
.48857 .2821 Mdot
.49048 .25961 Mdot
.49238 .36603 Mdot
.49429 .42917 Mdot
.49619 .27316 Mdot
.4981 .38875 Mdot
.5 .31615 Mdot
.5019 .36422 Mdot
.50381 .33472 Mdot
.50571 .22412 Mdot
.50762 .26452 Mdot
.50952 .26926 Mdot
.51143 .39829 Mdot
.51333 .31801 Mdot
.51524 .31496 Mdot
.51714 .3387 Mdot
.51905 .29114 Mdot
.52095 .35955 Mdot
.52286 .43812 Mdot
.52476 .25174 Mdot
.52667 .34166 Mdot
.52857 .24732 Mdot
.53048 .28288 Mdot
.53238 .29234 Mdot
.53429 .31314 Mdot
.53619 .34743 Mdot
.5381 .27392 Mdot
.54 .24478 Mdot
.5419 .28986 Mdot
.54381 .23881 Mdot
.54571 .34239 Mdot
.54762 .32222 Mdot
.54952 .2465 Mdot
.55143 .39209 Mdot
.55333 .26426 Mdot
.55524 .28517 Mdot
.55714 .4368 Mdot
.55905 .35223 Mdot
.56095 .24022 Mdot
.56286 .32014 Mdot
.56476 .3143 Mdot
.56667 .26877 Mdot
.56857 .41369 Mdot
.57048 .3264 Mdot
.57238 .25535 Mdot
.57429 .26869 Mdot
.57619 .31171 Mdot
.5781 .23226 Mdot
.58 .36499 Mdot
.5819 .29213 Mdot
.58381 .45619 Mdot
.58571 .43161 Mdot
.58762 .31409 Mdot
.58952 .4311 Mdot
.59143 .31704 Mdot
.59333 .42986 Mdot
.59524 .31044 Mdot
.59714 .23779 Mdot
.59905 .29943 Mdot
.60095 .23559 Mdot
.60286 .24806 Mdot
.60476 .31137 Mdot
.60667 .37293 Mdot
.60857 .42864 Mdot
.61048 .23617 Mdot
.61238 .34814 Mdot
.61429 .43626 Mdot
.61619 .30926 Mdot
.6181 .30949 Mdot
.62 .39958 Mdot
.6219 .36119 Mdot
.62381 .38588 Mdot
.62571 .26184 Mdot
.62762 .26718 Mdot
.62952 .28468 Mdot
.63143 .38167 Mdot
.63333 .36819 Mdot
.63524 .28678 Mdot
.63714 .26682 Mdot
.63905 .25255 Mdot
.64095 .4165 Mdot
.64286 .31137 Mdot
.64476 .24871 Mdot
.64667 .38072 Mdot
.64857 .35111 Mdot
.65048 .31841 Mdot
.65238 .29499 Mdot
.65429 .30907 Mdot
.65619 .36889 Mdot
.6581 .33556 Mdot
.66 .39508 Mdot
.6619 .27858 Mdot
.66381 .40423 Mdot
.66571 .3127 Mdot
.66762 .29443 Mdot
.66952 .39837 Mdot
.67143 .26295 Mdot
.67333 .32531 Mdot
.67524 .27915 Mdot
.67714 .3326 Mdot
.67905 .46155 Mdot
.68095 .30822 Mdot
.68286 .39507 Mdot
.68476 .26144 Mdot
.68667 .39414 Mdot
.68857 .34249 Mdot
.69048 .26568 Mdot
.69238 .40347 Mdot
.69429 .32228 Mdot
.69619 .36323 Mdot
.6981 .39632 Mdot
.7 .31882 Mdot
.7019 .4298 Mdot
.70381 .23828 Mdot
.70571 .25373 Mdot
.70762 .38145 Mdot
.70952 .25801 Mdot
.71143 .27835 Mdot
.71333 .31922 Mdot
.71524 .42211 Mdot
.71714 .25455 Mdot
.71905 .28655 Mdot
.72095 .26118 Mdot
.72286 .22955 Mdot
.72476 .31247 Mdot
.72667 .25467 Mdot
.72857 .28252 Mdot
.73048 .35788 Mdot
.73238 .31657 Mdot
.73429 .31399 Mdot
.73619 .30651 Mdot
.7381 .24345 Mdot
.74 .34472 Mdot
.7419 .43401 Mdot
.74381 .37056 Mdot
.74571 .42243 Mdot
.74762 .3778 Mdot
.74952 .40101 Mdot
.75143 .4251 Mdot
.75333 .40263 Mdot
.75524 .2433 Mdot
.75714 .31 Mdot
.75905 .41722 Mdot
.76095 .24394 Mdot
.76286 .27158 Mdot
.76476 .23177 Mdot
.76667 .33104 Mdot
.76857 .31208 Mdot
.77048 .26724 Mdot
.77238 .34864 Mdot
.77429 .29862 Mdot
.77619 .2969 Mdot
.7781 .3415 Mdot
.78 .33567 Mdot
.7819 .43816 Mdot
.78381 .29625 Mdot
.78571 .32384 Mdot
.78762 .26776 Mdot
.78952 .3749 Mdot
.79143 .46453 Mdot
.79333 .37905 Mdot
.79524 .26825 Mdot
.79714 .28495 Mdot
.79905 .28154 Mdot
.80095 .34105 Mdot
.80286 .31647 Mdot
.80476 .34035 Mdot
.80667 .31989 Mdot
.80857 .34216 Mdot
.81048 .25674 Mdot
.81238 .23971 Mdot
.81429 .36361 Mdot
.81619 .23694 Mdot
.8181 .33814 Mdot
.82 .31512 Mdot
.8219 .29331 Mdot
.82381 .35771 Mdot
.82571 .37824 Mdot
.82762 .33341 Mdot
.82952 .30516 Mdot
.83143 .28867 Mdot
.83333 .36458 Mdot
.83524 .27729 Mdot
.83714 .37009 Mdot
.83905 .37382 Mdot
.84095 .2533 Mdot
.84286 .29374 Mdot
.84476 .30348 Mdot
.84667 .23311 Mdot
.84857 .47423 Mdot
.85048 .37832 Mdot
.85238 .37602 Mdot
.85429 .35682 Mdot
.85619 .29221 Mdot
.8581 .41944 Mdot
.86 .27493 Mdot
.8619 .34963 Mdot
.86381 .40294 Mdot
.86571 .45884 Mdot
.86762 .32478 Mdot
.86952 .31256 Mdot
.87143 .285 Mdot
.87333 .25004 Mdot
.87524 .25915 Mdot
.87714 .47609 Mdot
.87905 .33136 Mdot
.88095 .36478 Mdot
.88286 .38281 Mdot
.88476 .26854 Mdot
.88667 .26652 Mdot
.88857 .27584 Mdot
.89048 .35993 Mdot
.89238 .2742 Mdot
.89429 .33603 Mdot
.89619 .39454 Mdot
.8981 .29571 Mdot
.9 .24262 Mdot
.9019 .30958 Mdot
.90381 .36921 Mdot
.90571 .45865 Mdot
.90762 .30294 Mdot
.90952 .33204 Mdot
.91143 .22395 Mdot
.91333 .34745 Mdot
.91524 .43005 Mdot
.91714 .29157 Mdot
.91905 .34365 Mdot
.92095 .26283 Mdot
.92286 .35115 Mdot
.92476 .25157 Mdot
.92667 .36323 Mdot
.92857 .38035 Mdot
.93048 .34101 Mdot
.93238 .30338 Mdot
.93429 .3026 Mdot
.93619 .33506 Mdot
.9381 .24877 Mdot
.94 .30946 Mdot
.9419 .30246 Mdot
.94381 .35574 Mdot
.94571 .30887 Mdot
.94762 .2693 Mdot
.94952 .3286 Mdot
.95143 .4197 Mdot
.95333 .3399 Mdot
.95524 .29961 Mdot
.95714 .27707 Mdot
.95905 .25614 Mdot
.96095 .32427 Mdot
.96286 .34738 Mdot
.96476 .32469 Mdot
.96667 .39977 Mdot
.96857 .43316 Mdot
.97048 .23483 Mdot
.97238 .27563 Mdot
.97429 .28589 Mdot
.97619 .28716 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo07Gooooo0_l0000Pooooo`;o0000POooool2o`00023ooooo0006ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0MOooool2o`00023ooooo0_l00021ooooo`;o00008?oo
ool000Co00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Cooooo0_l0000hooooo`;o0000KOoo
ool2o`0005gooooo0006ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^
kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000<ooooo`;o00001oooool2o`0001gooooo0_l0
000hooooo`;o0000?_ooool2o`0002gooooo0_l0000<ooooo`;o00006?ooool2o`0003Gooooo0006
ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0<ooooo`;o00001?ooool2o`000003oooo
ool0003o000004[ooooo0_l0000Oooooo`;o0000:_ooool2o`0000Kooooo0_l000000ooooooo0000
o`00000`ooooo`;o00003_ooool2o`0000Sooooo0_l0000Vooooo`;o00003Oooool000Kooooo00Go
410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Booooo`;o0000;_ooool2o`0001gooooo0_l0000Oooooo`;o0000
7oooool2o`0000Cooooo0_l0000:ooooo`?o000000?oooooo`000?l000007?ooool2o`00027ooooo
0ol0000`ooooo`;o00003Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04;o
oooo0_l0000Hooooo`;o00000oooool2o`0000Oooooo0_l0000gooooo`;o00001?ooool2o`0000[o
oooo0_l0000Pooooo`;o00002Oooool2o`0000?ooooo0_l0000Aooooo`;o00006_ooool2o`0002Co
oooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
00Cooooo1?l00006ooooo`03o`000?oooooooooo01[ooooo0_l00010ooooo`;o00003?ooool2o`00
00Gooooo0_l00009ooooo`;o00009?ooool2o`000003ooooool0003o000003_ooooo0_l00003oooo
o`Co0000:oooool2o`0002Cooooo000Yooooo`;o00006oooool2o`0002kooooo0_l0000:ooooo`;o
00006Oooool3o`0000Sooooo0_l0000Qooooo`;o000000Coooooo`000?l0003ooooo0_l0000?oooo
o`;o00003?ooool2o`0002?ooooo0_l0000gooooo`;o00006?ooool002Wooooo00?o0000oooooooo
ool02?ooool2o`0002?ooooo0_l0000Kooooo`;o00000_ooool2o`0000Kooooo0_l0000Jooooo`;o
0000:Oooool4o`0001Gooooo0_l0000:ooooo`Co0000Aoooool2o`0000oooooo0_l00002ooooo`;o
00006?ooool002Wooooo00?o0000ooooooooool00_l00006ooooo`;o00008oooool2o`0000oooooo
0_l0000>ooooo`;o0000COooool2o`0000kooooo0_l0000Cooooo`;o00005?ooool2o`000004oooo
ool0003o0000ooooo`;o00008oooool2o`0000Sooooo0_l0000?ooooo`;o00007?ooool002Wooooo
00?o0000ooooooooool00_l0000;ooooo`;o0000;oooool2o`00047ooooo0_l00004ooooo`;o0000
9?ooool2o`0002Wooooo1Ol000000ooooooo0000o`00000Iooooo`;o00002?ooool2o`0002Cooooo
0_l0000Aooooo`00:Oooool00ol0003oooooooooo`0=ooooo`;o00005?ooool2o`0003?ooooo0_l0
000Cooooo`;o00004_ooool2o`0000Cooooo0_l00009ooooo`;o0000:_ooool2o`00017ooooo0_l0
0006ooooo`;o000000?oooooo`000?l000006oooool2o`0001?ooooo0_l0000Iooooo`;o00004Ooo
ool002Wooooo0_l0000Tooooo`;o00003?ooool2o`00013ooooo0_l0000Booooo`?o00003?ooool2
o`0000Gooooo0_l0000Hooooo`;o00002Oooool2o`0000Cooooo0_l0000=ooooo`;o00005Oooool2
o`0000gooooo0_l00002ooooo`;o00002Oooool2o`00033ooooo0_l0000=ooooo`;o00007Oooool0
02Wooooo00?o0000ooooooooool02Oooool2o`0002Kooooo0_l0000@ooooo`;o00003oooool2o`00
0003ooooool0003o000000gooooo0_l00003ooooo`;o00008?ooool2o`0000Wooooo0_l0000=oooo
o`;o00005Oooool2o`000003ooooool0003o000000[ooooo0_l00004ooooo`;o00005oooool2o`00
00Cooooo1?l0000Looooo`;o00002Oooool2o`0001gooooo000Yooooo`03o`000?oooooooooo00Ko
oooo0_l000000ooooooo0000o`00000Uooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o
<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0@ooooo`;o00005Oooool7o`000008oooo
ool0003o0000onk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_oo
ool2o`0000Oooooo0_l00009ooooo`;o00004?ooool00onHV9So0000o`000002o`0000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`04onk^k_lb<S;o0000oc8b<P;o000000?oooooo`000?l0
00004?ooool2o`0001Cooooo0_l000001_l@413o0000o`000?ooooook^k^oc8b<PGo000000Kooooo
onk^k_lb<S;o0000oc8b<_o^k^hEooooo`?o00004Oooool3o`000009oc8b<_oMgMgoooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool0
0ol0003oooooooooo`06ooooo`;o0000:_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00gooooo0_l00006ooooo`;o0000
3Oooool2o`0000;ooooo0_l000001?lQ8B7ok^k^oooooom4A4@3o`000005ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo0_l0000>ooooo`;o00000_ooool2
o`0000Sooooo0_l00006ooooo`03oa0@4?l0003o000000;o00000oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[ooooo`;o00000oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Eooooo`;o000000?oooooo`00
0?l000003oooool2o`000003oooooomgMgOo<S8b00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wooooo00?o0000ooooooooool0;_ooool2
o`0000;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@400=ooooo`;o00001_ooool4o`0000_ooooo0_l00002ooooo`;o0000
00CoV9RHob4Q8Oo^k^kooooo0_l000000ooooooo410@ooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0@ooooo`;o00003?ooool2o`0000[ooooo00Go0000oooo
oooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413ooooooooo
o`0Vooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@4005ooooo`;o00001_ooool2o`0000Oooooo1?l0000Booooo`;o00000_ooool01Ol@413o
0000o`000?oooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`00:Oooool2o`00
02oooooo0_l00002ooooo`?o00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`00000Gooooo`;o00000_ooool2o`0000kooooo00?oV9RHob4Q8Oo^k^h00ooo
ool01?l0003oooooooooooooool2o`0000;ooooo00Go0000ooooooooooooooooo`00000[ooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000002_ooool2o`0000?ooooo0_l00009ooooo`;o00003?ooool01?m4A4CogMgMooooool0
0004ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Go
oooo0_l00006ooooo`;o00001oooool2o`0001Cooooo0_l00002ooooo`?o000000?oooooo`000?oo
ool00_ooool01Ol0003ooooooooooooooooo000000?ooooo000Yooooo`03o`000?oooooooooo027o
oooo0_l00003ooooo`?o00002Oooool3o`000003ooooool0003o000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo00Sooooo0_l0000?ooooo`;o00003oooool00omg
MgOoIVIVooooo`02ooooo`04o`000?ooooooooooooooo`;o00000_ooool01Ol0003ooooooooooooo
oooo0000013ooooo0_l0000;ooooo`;o00002oooool00ol@413o0000okZj^P03ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000[ooooo0_l00003ooooo`;o
00002Oooool2o`0000Cooooo0_l00006ooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000oooo
ooooooooooooo`000002ooooo`;o00000oooool00ol0003oooooooooo`0Wooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`00:Oooool00ol0003oooooooooo`0Dooooo`;o00002oooool2o`0000?ooooo
1_l00006ooooo`04o`000?ooooooooooooooo`;o00000oooool01Ol@413ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool02?ooool2o`0000?ooooo0_l0000Looooo`05o`000?oooooooooo
ooooool@41000_ooool2o`0000?ooooo00Go410@oooooooooooooooooa0@400@ooooo`;o00002ooo
ool2o`0000Kooooo0_l00004ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooo
oa0@4003ooooo`05oa0@4?ooooooooooooooool@41001?l0000Iooooo`;o000000?oooooo`000?l0
00001oooool00omgMgOoc<c<o`000004ooooo`06oa0@4?ooooooooooooooool@413ooooo0ol00003
ooooo`03oa0@4?oooooooooo00oooooo0_l0000Fooooo`03o`000?oooooooooo00Cooooo00Go410@
ooooool0003o0000oa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool002Wooooo00?o
0000ooooooooool05?ooool2o`0000Gooooo0_l0000;ooooo`Co00001_ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00oo
oooo0_l0000Hooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool00omgMgOoV9RHooooo`02o`00
00?ooooo00?oMgMgoiRHV?ooool00_l00008ooooo`;o00000_ooool2o`0001?ooooo0_l00002oooo
o`;o000000Kooooooa0@4?nHV9SooooookZj^_l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Co00006Oooool2o`0000[ooooo00?ok^k^odA4A?l0
00001?ooool01_mgMgOoV9RHoooooonHV9SoMgMgooooo`;o000000GoMgMgoiRHV?ooooooV9RHogMg
M`04ooooo`;o00002oooool2o`0001Kooooo00?o0000ooooooooool01?ooool00omgMgOoV9RHo`00
0002o`0000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool00ol0003ooooooooo
o`05ooooo`;o00005?ooool2o`0001?ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Pooooo`;o00001oooool01OnHV9So
410@o`000?lQ8B7oc<c<00?ooooo00Cok^k^oc8b<_l0003o<S8b0_l00002ooooo`03onk^k_lb<S;o
000000;o00002?ooool2o`0000;ooooo0_l0000<ooooo`;o00000_ooool2o`000003ooooool0003o
000000Gooooo00KoZJVYoa0@4?l0003o410@ojVYZOooool2o`000005onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02[ooooo00?oMgMgo`000?ooool00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`;o00001_oo
ool2o`0001;ooooo0_l00007ooooo`Co00000oooool00oo^k^ko<S8bo`000002o`0000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool2o`0000;ooooo0_l00002ooooo`;o00001ooo
ool2o`0005Cooooo0_l0000Cooooo`;o00008Oooool2o`0000;ooooo0_l0000>ooooo`;o00005?oo
ool2o`0000?ooooo0_l0000Tooooo`;o00002_ooool2o`0000Gooooo0_l00002ooooo`;o00002ooo
ool2o`0000Gooooo0_l0000Nooooo`00:Oooool01?l0003oooooooooooooool2o`0000_ooooo0_l0
0008ooooo`;o00004Oooool2o`0000Sooooo0_l00008ooooo`;o00001oooool2o`0000oooooo0_l0
000`ooooo`;o00000_ooool2o`0002Cooooo0_l0000?ooooo`;o00000oooool2o`00027ooooo0_l0
00000ooooooo0000o`00000:ooooo`;o00001Oooool2o`0000oooooo0_l0000Uooooo`00:Oooool3
o`0001Gooooo0_l000000ooooooo0000o`00000Aooooo`;o00002?ooool2o`0000Sooooo0_l00006
ooooo`?o00001Oooool2o`0000Sooooo0_l0000Kooooo`;o00004oooool2o`0000;ooooo0_l0000T
ooooo`;o0000=oooool2o`00037ooooo1?l00003ooooo`;o00004_ooool002Wooooo0ol0000Eoooo
o`;o0000<?ooool2o`0000Kooooo0_l0000Jooooo`;o00002Oooool2o`0000kooooo0_l0001goooo
o`;o00000oooool2o`0001;ooooo0_l00006ooooo`Go00000oooool2o`0001;ooooo000Yooooo`03
o`000?oooooooooo03gooooo0_l0000=ooooo`;o00007Oooool2o`0001Wooooo0_l000000ooooooo
0000o`000015ooooo`;o00003oooool2o`0001cooooo0_l00003ooooo`;o00004_ooool2o`0000Ko
oooo0_l0000Jooooo`008Oooooooo`0004Co00001?ooool002Wooooo00?o0000ooooooooool01?oo
ool2o`0000?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool3o`0000[ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo0ol00002ooooo`03o`000?oo
oooooooo00?ooooo0_l00005ooooo`04o`000?ooooooooooooooo`;o00001_ooool01?l0003ooooo
ooooooooool6o`0000;ooooo00?o0000ooooooooool01oooool3o`0000?ooooo0_l00007ooooo`?o
00000_ooool2o`0000;ooooo1?l000000ooooooo0000o`000002ooooo`;o00001?ooool01?l0003o
ooooo`000?l00002ooooo`;o00000_ooool3o`0000cooooo00Co0000oooooooooooooooo0_l00000
0ooooooo0000o`000003ooooo`04o`000?oooooo0000o`0000;ooooo0_l00004ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02_ooool3o`0000Wooooo0_l0000:ooooo`Co00002?oo
ool00ol0003oooooooooo`0:ooooo`00:Oooool00ol0003oooooooooo`04ooooo`;o00007oooool2
o`0001?ooooo0ol0000dooooo`;o00001Oooool01?l0003oooooooooooooool2o`0000Kooooo0_l0
0002ooooo`Co00002Oooool2o`0000?ooooo0_l00004ooooo`;o00002?ooool2o`0000Kooooo1?l0
000Eooooo`;o00004Oooool5o`0000Wooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0_l0
0003ooooo`;o00003_ooool2o`00027ooooo00?o0000ooooooooool02_ooool002Wooooo00?o0000
ooooooooool09Oooool2o`0003?ooooo0_l0000Xooooo`;o00003oooool2o`0000?ooooo0_l0000>
ooooo`;o00001oooool2o`00017ooooo0_l0000>ooooo`;o00000_ooool2o`0000Cooooo0_l0000E
ooooo`?o00000_ooool2o`0003kooooo000Yooooo`03o`000?oooooooooo00;ooooo0_l0001Foooo
o`;o0000BOooool2o`0000?ooooo0_l0000Jooooo`;o00003?ooool4o`0000;ooooo0_l0000Eoooo
o`;o00001Oooool2o`00033ooooo0_l0000@ooooo`00:Oooool2o`0000?ooooo0_l00008ooooo`;o
00001_ooool2o`000003ooooool0003o000003Sooooo0_l0000?ooooo`;o0000@Oooool2o`0000Go
oooo0_l0000Oooooo`;o00001Oooool2o`0001_ooooo0_l0000Iooooo`;o00007?ooool3o`0000oo
oooo000Yooooo`03o`000?oooooooooo00cooooo0_l00006ooooo`;o000000?oooooo`000?l00000
4?ooool2o`0001kooooo0_l00005ooooo`?o00003oooool2o`00013ooooo0_l00007ooooo`;o0000
;Oooool2o`0001oooooo0_l0000mooooo`;o00006?ooool2o`0000?ooooo0_l0000?ooooo`00:Ooo
ool2o`0002Cooooo0_l00004ooooo`?o00007Oooool2o`0000Gooooo0_l0000Looooo`;o00001?oo
ool2o`0000Oooooo0_l00004ooooo`;o0000BOooool2o`0001_ooooo0_l0000Booooo`;o00003_oo
ool2o`0000Sooooo0_l0000;ooooo`;o00005?ooool002Wooooo1?l0000Rooooo`;o00001Oooool2
o`0001Oooooo0_l0000?ooooo`;o00006?ooool2o`0001?ooooo0_l0000Booooo`;o0000;oooool2
o`0000Cooooo0_l0000Kooooo`;o00000_ooool2o`0000kooooo0_l0000>ooooo`;o00000oooool2
o`0000?ooooo0_l00007ooooo`;o00006?ooool002Wooooo00Co0000ooooool0003o00003?ooool2
o`00023ooooo0_l00002ooooo`;o00002oooool5o`0000oooooo0_l0000Tooooo`;o00006oooool2
o`0000;ooooo0_l0000[ooooo`;o00009Oooool2o`0000_ooooo0_l0000Fooooo`;o00003?ooool2
o`0000?ooooo0_l0000Cooooo`00:Oooool2o`0000kooooo0_l0000Pooooo`;o00000_ooool2o`00
00Gooooo0_l00004ooooo`?o0000=oooool2o`000003ooooool0003o000000kooooo0_l0000<oooo
o`;o000000?oooooo`000?l000001?ooool2o`0002cooooo0_l0000Kooooo`;o00001Oooool5o`00
0003ooooool0003o000002;ooooo0_l00005ooooo`;o00004oooool002Wooooo00Co0000ooooool0
003o00006?ooool2o`0000Oooooo0_l0000Fooooo`;o00008Oooool2o`0000Cooooo0_l0000Hoooo
o`;o00003_ooool2o`0000;ooooo0_l0000;ooooo`;o00001?ooool2o`0002cooooo0_l0000?oooo
o`;o00002_ooool2o`0000Gooooo1Ol0000Qooooo`;o00000_ooool2o`0001[ooooo000Yooooo`04
o`000?oooooo0000o`0000Cooooo0_l00008ooooo`;o00001_ooool4o`0000Oooooo0_l00009oooo
o`;o00000oooool2o`0000Cooooo0_l00006ooooo`;o00001oooool2o`0001;ooooo0_l000001?oo
oooo0000o`000?ooool2o`0000;ooooo0_l0000Hooooo`;o00003_ooool2o`0000kooooo0_l0000G
ooooo`;o00009oooool2o`0000Sooooo0_l0000[ooooo`Co00003?ooool2o`00013ooooo000Yoooo
o`03o`000?oooooooooo00?ooooo1?l00008ooooo`;o00001_ooool2o`0000Gooooo0_l00007oooo
o`;o00000oooool3o`0000?ooooo0_l00004ooooo`Co00001?ooool2o`0000Oooooo0_l0000Eoooo
o`;o00001Oooool2o`0001Gooooo0_l000000ooooooo0000o`00000Nooooo`;o00001Oooool2o`00
013ooooo0_l00009ooooo`;o00009_ooool2o`0001_ooooo0_l0000>ooooo`;o000000?oooooo`00
0?l000002oooool2o`00013ooooo000Yooooo`03o`000?oooooooooo00?ooooo0_l00002ooooo`;o
00005?ooool5o`0000Gooooo0_l00003ooooo`;o00003?ooool2o`0001Wooooo0_l0000Wooooo`?o
00009oooool2o`0001_ooooo0_l00013ooooo`;o00004Oooool2o`0001gooooo000Yooooo`;o0000
2?ooool2o`0001Cooooo1Ol0000cooooo`;o0000:?ooool2o`000003ooooool0003o000005_ooooo
0_l0000Mooooo`;o00001oooool2o`0001_ooooo0_l0000Fooooo`00:Oooool01?l0003ooooooooo
ooooool2o`0002oooooo0_l0000@ooooo`;o0000=Oooool2o`0000Gooooo0_l000000ooooooo0000
o`00000Eooooo`;o00007oooool2o`00023ooooo0_l0000Mooooo`;o00001oooool2o`0000[ooooo
0_l0000?ooooo`;o00005_ooool002Wooooo00Co0000oooooooooooooooo0_l0000Iooooo`;o0000
1?ooool2o`0000kooooo0_l00002ooooo`;o00001?ooool2o`0000Kooooo0_l0000<ooooo`;o0000
1?ooool2o`0001cooooo0_l00003ooooo`;o00002?ooool2o`0000Wooooo0_l00004ooooo`;o0000
1?ooool2o`0001oooooo0_l0000Eooooo`;o00009?ooool2o`0000Gooooo0_l0000=ooooo`;o0000
00?oooooo`000?l000002_ooool2o`0001_ooooo000Yooooo`03o`000?oooooooooo01Sooooo0_l0
0002ooooo`;o00001?ooool2o`0000Cooooo0_l0000<ooooo`;o00001?ooool2o`0001Cooooo0_l0
0004ooooo`;o000000?oooooo`000?l000006Oooool2o`0001Sooooo0_l000001?oooooo0000o`00
0?ooool2o`0001Oooooo0_l0000Sooooo`;o00009?ooool2o`0000Gooooo0_l0000=ooooo`;o0000
3Oooool2o`0001_ooooo000Yooooo`03o`000?oooooooooo00Wooooo1?l0000;ooooo`;o00003_oo
ool2o`0002?ooooo0_l0000<ooooo`;o0000=_ooool2o`0001[ooooo0_l0000?ooooo`;o00001_oo
ool2o`0001[ooooo0_l0000Looooo`;o00004oooool2o`0002?ooooo000Yooooo`;o00002_ooool4
o`0000Gooooo0_l0000Zooooo`;o00003Oooool2o`00043ooooo0_l0000Wooooo`;o00001_ooool2
o`0000Kooooo0_l0000Jooooo`;o00007?ooool2o`0001?ooooo0_l0000Sooooo`00:Oooool00ol0
003oooooooooo`0Booooo`;o0000:_ooool2o`0002Wooooo0_l00009ooooo`;o00006Oooool2o`00
02Oooooo0_l0000hooooo`;o00003_ooool2o`0000?ooooo0_l0000cooooo`001_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool01oooool2o`0000Sooooo0_l0000Aooooo`;o0000@oooool2
o`000003ooooool0003o000000Kooooo0_l0001_ooooo`;o00002oooool4o`0000Sooooo0_l00006
ooooo`?o00005_ooool2o`0001_ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool01?ooool2o`000003ooooool0003o000000Oooooo0ol00003ooooo`;o00003?oo
ool2o`0000[ooooo0_l0000;ooooo`;o00001oooool4o`000003ooooool0003o000001oooooo0_l0
0009ooooo`;o0000Aoooool2o`0000?ooooo0_l0000Aooooo`;o00002oooool2o`0000gooooo0_l0
0008ooooo`;o00001_ooool2o`0000Sooooo0_l0000=ooooo`;o00006oooool000Kooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`;o00002_ooool2o`0000Cooooo0_l0000Hooooo`;o00002ooo
ool2o`0000Oooooo1?l000000ooooooo0000o`00000Zooooo`;o00005oooool2o`0002_ooooo0_l0
00000ooooooo0000o`000003ooooo`;o00004Oooool2o`0003Kooooo0_l0000Zooooo`001_ooool0
1Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8boooo
o`04ooooo`?o0000<?ooool2o`0005kooooo0_l00003ooooo`;o00009_ooool2o`0007gooooo0006
ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0`ooooo`;o0000Hoooool2o`0000oooooo
0_l0002Dooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05cooooo0_l00007ooooo`;o0000
?oooool2o`00027ooooo0_l00005ooooo`?o0000@_ooool2o`0002Gooooo0006ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`1Cooooo`;o00001oooool2o`000003ooooool0003o000000Co
oooo0_l0000Rooooo`;o00003_ooool2o`0002kooooo0_l000000ooooooo0000o`000002ooooo`?o
00000_ooool2o`0003kooooo0_l0000Uooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`0000_ooooo0_l00003oooo
o`;o00007Oooool2o`0001gooooo0_l00004ooooo`;o000000?oooooo`000?l000001oooool2o`00
01kooooo0_l00008ooooo`;o00003_ooool2o`00027ooooo0_l0000>ooooo`;o00001oooool2o`00
00oooooo0_l00013ooooo`;o00003oooool002Wooooo0_l0000;ooooo`;o00000oooool2o`0001go
oooo0_l0000Mooooo`;o00001oooool2o`0000_ooooo0_l0000Jooooo`;o0000>oooool2o`0000co
oooo0_l00007ooooo`;o00004Oooool3o`00027ooooo0_l0000Oooooo`;o00003oooool002Wooooo
00?o0000ooooooooool02_ooool2o`0004Cooooo0_l0000Aooooo`;o0000IOooool2o`0000Oooooo
0_l0000Booooo`;o00008Oooool2o`00033ooooo000Yooooo`03o`000?oooooooooo00[ooooo0_l0
000Cooooo`;o00009Oooool2o`0000Sooooo0_l0003Zooooo`00:Oooool00ol0003oooooooooo`0C
ooooo`;o00002_ooool2o`0002Gooooo0_l0000Fooooo`;o0000Boooool2o`0008oooooo000Yoooo
o`03o`000?oooooooooo01?ooooo0_l0000`ooooo`;o00005oooool2o`0004_ooooo0_l0000Foooo
o`;o00009?ooool2o`00057ooooo000Yooooo`;o00009_ooool2o`0001kooooo0_l0000Gooooo`;o
0000Hoooool2o`0002Cooooo0_l0000Nooooo`;o00007?ooool2o`0001?ooooo000Yooooo`03o`00
0?oooooooooo02Gooooo0_l0000Nooooo`;o0000U?ooool2o`0000Oooooo0_l0000Sooooo`;o0000
7?ooool2o`0001?ooooo000Yooooo`03o`000?oooooooooo00;ooooo0_l00011ooooo`;o0000:?oo
ool2o`0006[ooooo0_l00007ooooo`Co0000E?ooool002Wooooo00?o0000ooooooooool00_ooool2
o`0000cooooo0_l0000_ooooo`;o0000;?ooool2o`0002?ooooo0_l0000Mooooo`;o00000oooool2
o`0001cooooo0_l0000>ooooo`;o0000<oooool2o`0001oooooo000Yooooo`03o`000?oooooooooo
013ooooo0_l0000_ooooo`;o0000;Oooool2o`0002;ooooo0_l0000Kooooo`Co00000oooool2o`00
01cooooo0_l00013ooooo`;o00003oooool2o`0000kooooo000Yooooo`;o00008Oooool2o`0001Ko
oooo0_l0000fooooo`;o00004oooool2o`0002[ooooo0ol00006ooooo`;o00009oooool2o`0004Oo
oooo0_l0000>ooooo`00:Oooool00ol0003oooooooooo`0Jooooo`Co00000_ooool2o`0001Kooooo
0_l0001;ooooo`;o00005_ooool2o`0000Wooooo0_l0000@ooooo`;o00009oooool2o`0000_ooooo
0_l0001:ooooo`00:Oooool00ol0003oooooooooo`0Jooooo`Co0000Ooooool2o`0000Wooooo0_l0
0016ooooo`;o0000B_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`0iooooo`;o0000ooooool2ooooo`00:Oooool2o`0001kooooo0_l0000<ooooo`;o
00003?ooool2o`000?oooooo0_ooool002Wooooo00?o0000ooooooooool07Oooool2o`0000cooooo
0_l0003ooooooa3ooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo06oooooo0_l0000oooooo`;o
0000R_ooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo04_ooooo0_l0000Rooooo`;o0000?oooool2o`0005Wo
oooo0_l0000;ooooo`;o00008_ooool000kooooo00Go410@oooooooooooooooooa0@400@ooooo`03
o`000?oooooooooo00?ooooo0ol0001;ooooo`;o0000P_ooool2o`0003[ooooo0_l0000;ooooo`;o
00008_ooool000kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0JOooool2o`0006Cooooo0_l0000Rooooo`;o0000Aoooool000kooooo
00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0
003oooooooooo`0gooooo`;o0000<?ooool2o`0008Sooooo0_l00017ooooo`003_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0eoooo
o`Co0000ooooool4ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0eooooo`;o0000EOooool2o`0007Oooooo0_l00008oooo
o`;o0000:oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`00
07Sooooo0_l000000ooooooo0000o`00000@ooooo`;o0000Moooool2o`0000Sooooo0_l0000[oooo
o`00:Oooool00ol0003oooooooooo`1gooooo`;o000000?oooooo`000?l00000`?ooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`001_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooo
oooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o
0000oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qoooooooo
ool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo
00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooo
oooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@
413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3o
ooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006
ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool001oooooo
1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooo
oooo00Gooooo0ol0003oooooocgooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool001oooooo00?oEEEEofIVI_l00000oooooom7
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .24606 Mdot
.02762 .35482 Mdot
.02952 .27501 Mdot
.03143 .33234 Mdot
.03333 .27717 Mdot
.03524 .3406 Mdot
.03714 .31988 Mdot
.03905 .43075 Mdot
.04095 .43761 Mdot
.04286 .26323 Mdot
.04476 .33345 Mdot
.04667 .40531 Mdot
.04857 .41349 Mdot
.05048 .30777 Mdot
.05238 .39048 Mdot
.05429 .32765 Mdot
.05619 .28256 Mdot
.0581 .41331 Mdot
.06 .31228 Mdot
.0619 .24491 Mdot
.06381 .40991 Mdot
.06571 .39148 Mdot
.06762 .40019 Mdot
.06952 .41098 Mdot
.07143 .33507 Mdot
.07333 .36781 Mdot
.07524 .35014 Mdot
.07714 .31949 Mdot
.07905 .2327 Mdot
.08095 .36107 Mdot
.08286 .40182 Mdot
.08476 .43872 Mdot
.08667 .43719 Mdot
.08857 .34887 Mdot
.09048 .38335 Mdot
.09238 .29057 Mdot
.09429 .34737 Mdot
.09619 .34321 Mdot
.0981 .23493 Mdot
.1 .3982 Mdot
.1019 .33878 Mdot
.10381 .3712 Mdot
.10571 .38014 Mdot
.10762 .25804 Mdot
.10952 .23896 Mdot
.11143 .34751 Mdot
.11333 .29799 Mdot
.11524 .42405 Mdot
.11714 .30126 Mdot
.11905 .23432 Mdot
.12095 .42193 Mdot
.12286 .26128 Mdot
.12476 .48276 Mdot
.12667 .38551 Mdot
.12857 .38685 Mdot
.13048 .44187 Mdot
.13238 .42674 Mdot
.13429 .27877 Mdot
.13619 .39585 Mdot
.1381 .24304 Mdot
.14 .35544 Mdot
.1419 .2328 Mdot
.14381 .23798 Mdot
.14571 .29588 Mdot
.14762 .43369 Mdot
.14952 .44237 Mdot
.15143 .25928 Mdot
.15333 .33433 Mdot
.15524 .3429 Mdot
.15714 .40572 Mdot
.15905 .30221 Mdot
.16095 .27213 Mdot
.16286 .26786 Mdot
.16476 .25945 Mdot
.16667 .23789 Mdot
.16857 .31392 Mdot
.17048 .48272 Mdot
.17238 .36579 Mdot
.17429 .24571 Mdot
.17619 .31914 Mdot
.1781 .36759 Mdot
.18 .35658 Mdot
.1819 .31995 Mdot
.18381 .37488 Mdot
.18571 .44099 Mdot
.18762 .32358 Mdot
.18952 .28508 Mdot
.19143 .31577 Mdot
.19333 .25855 Mdot
.19524 .33204 Mdot
.19714 .32931 Mdot
.19905 .43594 Mdot
.20095 .25983 Mdot
.20286 .33046 Mdot
.20476 .26583 Mdot
.20667 .42147 Mdot
.20857 .3024 Mdot
.21048 .42292 Mdot
.21238 .48271 Mdot
.21429 .26112 Mdot
.21619 .26222 Mdot
.2181 .24498 Mdot
.22 .40422 Mdot
.2219 .27715 Mdot
.22381 .38662 Mdot
.22571 .3574 Mdot
.22762 .32028 Mdot
.22952 .28797 Mdot
.23143 .25965 Mdot
.23333 .40388 Mdot
.23524 .28276 Mdot
.23714 .32916 Mdot
.23905 .43754 Mdot
.24095 .28069 Mdot
.24286 .43528 Mdot
.24476 .29733 Mdot
.24667 .36254 Mdot
.24857 .4456 Mdot
.25048 .44384 Mdot
.25238 .34062 Mdot
.25429 .41294 Mdot
.25619 .22329 Mdot
.2581 .40826 Mdot
.26 .23153 Mdot
.2619 .40428 Mdot
.26381 .33879 Mdot
.26571 .26281 Mdot
.26762 .39656 Mdot
.26952 .31757 Mdot
.27143 .26504 Mdot
.27333 .40058 Mdot
.27524 .28853 Mdot
.27714 .38744 Mdot
.27905 .33518 Mdot
.28095 .37033 Mdot
.28286 .235 Mdot
.28476 .3309 Mdot
.28667 .24099 Mdot
.28857 .26525 Mdot
.29048 .42891 Mdot
.29238 .38745 Mdot
.29429 .29289 Mdot
.29619 .28972 Mdot
.2981 .33269 Mdot
.3 .28309 Mdot
.3019 .26061 Mdot
.30381 .444 Mdot
.30571 .39003 Mdot
.30762 .27467 Mdot
.30952 .32765 Mdot
.31143 .23106 Mdot
.31333 .24508 Mdot
.31524 .35408 Mdot
.31714 .41102 Mdot
.31905 .2794 Mdot
.32095 .29366 Mdot
.32286 .30927 Mdot
.32476 .24401 Mdot
.32667 .44441 Mdot
.32857 .34795 Mdot
.33048 .31447 Mdot
.33238 .34997 Mdot
.33429 .24531 Mdot
.33619 .35059 Mdot
.3381 .32255 Mdot
.34 .37886 Mdot
.3419 .25617 Mdot
.34381 .44421 Mdot
.34571 .37731 Mdot
.34762 .34603 Mdot
.34952 .30779 Mdot
.35143 .24731 Mdot
.35333 .26209 Mdot
.35524 .35126 Mdot
.35714 .28682 Mdot
.35905 .26253 Mdot
.36095 .43415 Mdot
.36286 .41403 Mdot
.36476 .29946 Mdot
.36667 .30262 Mdot
.36857 .2315 Mdot
.37048 .28211 Mdot
.37238 .38083 Mdot
.37429 .28352 Mdot
.37619 .33019 Mdot
.3781 .30218 Mdot
.38 .43519 Mdot
.3819 .39388 Mdot
.38381 .43908 Mdot
.38571 .35728 Mdot
.38762 .37595 Mdot
.38952 .23322 Mdot
.39143 .26099 Mdot
.39333 .31998 Mdot
.39524 .22632 Mdot
.39714 .43661 Mdot
.39905 .29794 Mdot
.40095 .39757 Mdot
.40286 .32038 Mdot
.40476 .4576 Mdot
.40667 .34942 Mdot
.40857 .32306 Mdot
.41048 .32126 Mdot
.41238 .26835 Mdot
.41429 .27095 Mdot
.41619 .46543 Mdot
.4181 .27369 Mdot
.42 .33276 Mdot
.4219 .3248 Mdot
.42381 .32713 Mdot
.42571 .32386 Mdot
.42762 .33811 Mdot
.42952 .40968 Mdot
.43143 .36475 Mdot
.43333 .37618 Mdot
.43524 .29905 Mdot
.43714 .26135 Mdot
.43905 .36069 Mdot
.44095 .34644 Mdot
.44286 .30559 Mdot
.44476 .25118 Mdot
.44667 .4086 Mdot
.44857 .36085 Mdot
.45048 .4007 Mdot
.45238 .3842 Mdot
.45429 .35248 Mdot
.45619 .31623 Mdot
.4581 .25229 Mdot
.46 .3419 Mdot
.4619 .26049 Mdot
.46381 .3892 Mdot
.46571 .22279 Mdot
.46762 .34003 Mdot
.46952 .27603 Mdot
.47143 .46591 Mdot
.47333 .26155 Mdot
.47524 .35023 Mdot
.47714 .22639 Mdot
.47905 .34819 Mdot
.48095 .2917 Mdot
.48286 .40977 Mdot
.48476 .27945 Mdot
.48667 .23334 Mdot
.48857 .36098 Mdot
.49048 .35671 Mdot
.49238 .30129 Mdot
.49429 .44051 Mdot
.49619 .27254 Mdot
.4981 .30105 Mdot
.5 .2474 Mdot
.5019 .29749 Mdot
.50381 .23892 Mdot
.50571 .3055 Mdot
.50762 .29996 Mdot
.50952 .31952 Mdot
.51143 .3184 Mdot
.51333 .36516 Mdot
.51524 .35209 Mdot
.51714 .38564 Mdot
.51905 .31481 Mdot
.52095 .4289 Mdot
.52286 .41273 Mdot
.52476 .2799 Mdot
.52667 .35006 Mdot
.52857 .34261 Mdot
.53048 .26931 Mdot
.53238 .24646 Mdot
.53429 .23966 Mdot
.53619 .30871 Mdot
.5381 .35457 Mdot
.54 .26899 Mdot
.5419 .35419 Mdot
.54381 .27922 Mdot
.54571 .38584 Mdot
.54762 .26181 Mdot
.54952 .30174 Mdot
.55143 .3049 Mdot
.55333 .27662 Mdot
.55524 .25406 Mdot
.55714 .4264 Mdot
.55905 .33438 Mdot
.56095 .30479 Mdot
.56286 .2327 Mdot
.56476 .2674 Mdot
.56667 .272 Mdot
.56857 .34776 Mdot
.57048 .41193 Mdot
.57238 .28359 Mdot
.57429 .30212 Mdot
.57619 .25228 Mdot
.5781 .30728 Mdot
.58 .3374 Mdot
.5819 .37699 Mdot
.58381 .39361 Mdot
.58571 .38965 Mdot
.58762 .40418 Mdot
.58952 .39121 Mdot
.59143 .30795 Mdot
.59333 .38055 Mdot
.59524 .22374 Mdot
.59714 .33049 Mdot
.59905 .39568 Mdot
.60095 .36221 Mdot
.60286 .31552 Mdot
.60476 .37596 Mdot
.60667 .29542 Mdot
.60857 .4399 Mdot
.61048 .34442 Mdot
.61238 .30885 Mdot
.61429 .42481 Mdot
.61619 .36256 Mdot
.6181 .3244 Mdot
.62 .40814 Mdot
.6219 .29439 Mdot
.62381 .41214 Mdot
.62571 .23884 Mdot
.62762 .28729 Mdot
.62952 .24326 Mdot
.63143 .36185 Mdot
.63333 .42996 Mdot
.63524 .2669 Mdot
.63714 .37627 Mdot
.63905 .24795 Mdot
.64095 .32058 Mdot
.64286 .34197 Mdot
.64476 .33329 Mdot
.64667 .37677 Mdot
.64857 .25099 Mdot
.65048 .25326 Mdot
.65238 .32624 Mdot
.65429 .31667 Mdot
.65619 .30901 Mdot
.6581 .41828 Mdot
.66 .31334 Mdot
.6619 .26743 Mdot
.66381 .40299 Mdot
.66571 .2671 Mdot
.66762 .26801 Mdot
.66952 .34584 Mdot
.67143 .34772 Mdot
.67333 .37862 Mdot
.67524 .34971 Mdot
.67714 .26414 Mdot
.67905 .48279 Mdot
.68095 .36157 Mdot
.68286 .34388 Mdot
.68476 .29396 Mdot
.68667 .43996 Mdot
.68857 .34759 Mdot
.69048 .24589 Mdot
.69238 .37307 Mdot
.69429 .26803 Mdot
.69619 .3484 Mdot
.6981 .28974 Mdot
.7 .40862 Mdot
.7019 .37878 Mdot
.70381 .28115 Mdot
.70571 .32754 Mdot
.70762 .34433 Mdot
.70952 .2528 Mdot
.71143 .25221 Mdot
.71333 .40873 Mdot
.71524 .3287 Mdot
.71714 .35214 Mdot
.71905 .38912 Mdot
.72095 .37181 Mdot
.72286 .33409 Mdot
.72476 .27151 Mdot
.72667 .2752 Mdot
.72857 .38553 Mdot
.73048 .42853 Mdot
.73238 .27541 Mdot
.73429 .38841 Mdot
.73619 .36019 Mdot
.7381 .32287 Mdot
.74 .25625 Mdot
.7419 .42746 Mdot
.74381 .28972 Mdot
.74571 .36455 Mdot
.74762 .28438 Mdot
.74952 .39765 Mdot
.75143 .36687 Mdot
.75333 .39795 Mdot
.75524 .35329 Mdot
.75714 .42032 Mdot
.75905 .35678 Mdot
.76095 .28443 Mdot
.76286 .2863 Mdot
.76476 .27677 Mdot
.76667 .25349 Mdot
.76857 .31441 Mdot
.77048 .37704 Mdot
.77238 .4047 Mdot
.77429 .32676 Mdot
.77619 .25608 Mdot
.7781 .36937 Mdot
.78 .35237 Mdot
.7819 .42819 Mdot
.78381 .38157 Mdot
.78571 .22522 Mdot
.78762 .37718 Mdot
.78952 .32674 Mdot
.79143 .47974 Mdot
.79333 .3379 Mdot
.79524 .26611 Mdot
.79714 .25458 Mdot
.79905 .27801 Mdot
.80095 .42075 Mdot
.80286 .40695 Mdot
.80476 .34941 Mdot
.80667 .26644 Mdot
.80857 .35282 Mdot
.81048 .3079 Mdot
.81238 .26138 Mdot
.81429 .32406 Mdot
.81619 .32562 Mdot
.8181 .30041 Mdot
.82 .35326 Mdot
.8219 .26479 Mdot
.82381 .30664 Mdot
.82571 .34039 Mdot
.82762 .35411 Mdot
.82952 .33312 Mdot
.83143 .22579 Mdot
.83333 .43007 Mdot
.83524 .30247 Mdot
.83714 .3854 Mdot
.83905 .32048 Mdot
.84095 .26823 Mdot
.84286 .35524 Mdot
.84476 .35001 Mdot
.84667 .27349 Mdot
.84857 .43514 Mdot
.85048 .30439 Mdot
.85238 .4574 Mdot
.85429 .26836 Mdot
.85619 .33175 Mdot
.8581 .43836 Mdot
.86 .38037 Mdot
.8619 .33767 Mdot
.86381 .37324 Mdot
.86571 .48293 Mdot
.86762 .27145 Mdot
.86952 .32461 Mdot
.87143 .25507 Mdot
.87333 .34607 Mdot
.87524 .3329 Mdot
.87714 .44864 Mdot
.87905 .31463 Mdot
.88095 .38467 Mdot
.88286 .36943 Mdot
.88476 .27727 Mdot
.88667 .28969 Mdot
.88857 .26471 Mdot
.89048 .43007 Mdot
.89238 .27598 Mdot
.89429 .23865 Mdot
.89619 .3379 Mdot
.8981 .23977 Mdot
.9 .27145 Mdot
.9019 .38587 Mdot
.90381 .31163 Mdot
.90571 .39535 Mdot
.90762 .25565 Mdot
.90952 .41651 Mdot
.91143 .30734 Mdot
.91333 .30985 Mdot
.91524 .38027 Mdot
.91714 .3546 Mdot
.91905 .26733 Mdot
.92095 .24799 Mdot
.92286 .26286 Mdot
.92476 .30248 Mdot
.92667 .34949 Mdot
.92857 .34779 Mdot
.93048 .23064 Mdot
.93238 .37046 Mdot
.93429 .31263 Mdot
.93619 .38206 Mdot
.9381 .31589 Mdot
.94 .26942 Mdot
.9419 .3403 Mdot
.94381 .38596 Mdot
.94571 .37392 Mdot
.94762 .31345 Mdot
.94952 .36727 Mdot
.95143 .4425 Mdot
.95333 .2716 Mdot
.95524 .23958 Mdot
.95714 .3401 Mdot
.95905 .31823 Mdot
.96095 .29386 Mdot
.96286 .44251 Mdot
.96476 .3 Mdot
.96667 .3504 Mdot
.96857 .40219 Mdot
.97048 .3185 Mdot
.97238 .33848 Mdot
.97429 .2352 Mdot
.97619 .39023 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo04Oooooo0_l00011ooooo`;o0000:?ooool2o`0008Kooooo0006ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0Aoooool2o`0002_ooooo0_l0000Dooooo`;o00000_oo
ool2o`0002Cooooo0_l0000kooooo`;o00003Oooool2o`0003[ooooo0004o`0000;ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1Iooooo`;o00006Oooool2o`0001Sooooo0_l0001Qooooo`;o00003Ooo
ool2o`0001kooooo0_l0000Jooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o00003_ooool2o`0001;ooooo0_l0
000Tooooo`;o00003oooool2o`00013ooooo0_l00005ooooo`;o00007Oooool2o`0001Oooooo0_l0
001dooooo`;o00006_ooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00kooooo
0_l00004ooooo`;o00001Oooool2o`0000Gooooo0_l0000Tooooo`;o00001_ooool2o`0001Wooooo
0_l00005ooooo`;o00007Oooool2o`0001Oooooo0_l00022ooooo`;o00003?ooool000Kooooo00Go
410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Dooooo`;o00000_ooool2o`000003ooooool0003o000000Kooooo
0_l00005ooooo`;o00009?ooool2o`0004Gooooo0_l00007ooooo`;o00007?ooool2o`0005Cooooo
0ol0000Aooooo`;o00001?ooool2o`0000cooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Hooooo`;o00001oooool4o`0000Gooooo0_l0000Uooooo`;o0000A?ooool2o`0000Oo
oooo0_l0000Looooo`?o0000Doooool3o`00017ooooo0_l0000Booooo`001_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`00
00[ooooo0_l0000Fooooo`;o00002_ooool2o`0000cooooo0_l0000Dooooo`;o00001_ooool2o`00
00;ooooo0_l000000ooooooo0000o`00000nooooo`;o00007Oooool2o`0001;ooooo0_l0001Woooo
o`00:Oooool2o`0000[ooooo0_l0000Rooooo`;o00003?ooool2o`0001cooooo0_l00002ooooo`;o
000000?oooooo`000?l000001?ooool2o`0002gooooo0_l00009ooooo`;o00008?ooool2o`0000oo
oooo0_l00018ooooo`;o00007Oooool002Wooooo00?o0000ooooooooool0I_ooool2o`0001cooooo
0_l00002ooooo`;o00002oooool2o`0001Oooooo0_l0000Booooo`;o000000?oooooo`000?l00000
4_ooool2o`0004;ooooo0_l0000Mooooo`00:Oooool00ol0003oooooooooo`24ooooo`;o00000_oo
ool2o`0001gooooo0_l00005ooooo`;o00005Oooool3o`00017ooooo0_l0000@ooooo`;o00002?oo
ool2o`0001Kooooo0_l00009ooooo`;o00008_ooool002Wooooo00?o0000ooooooooool05oooool2
o`0001[ooooo0_l0000^ooooo`;o0000@_ooool2o`0001gooooo0_l0000Kooooo`;o00001_ooool2
o`000003ooooool0003o000000Gooooo0_l0000Fooooo`;o00002Oooool2o`0002;ooooo000Yoooo
o`03o`000?oooooooooo01Oooooo0_l00003ooooo`;o00001oooool2o`0000?ooooo0_l00007oooo
o`Co00000oooool2o`0000?ooooo0_l0000Eooooo`;o00002oooool2o`000003ooooool0003o0000
00[ooooo0_l0000=ooooo`;o00001_ooool2o`0000;ooooo0_l0000Fooooo`;o0000??ooool2o`00
00Wooooo0_l0000:ooooo`;o0000@?ooool002Wooooo0_l00003ooooo`;o00006?ooool2o`0000Oo
oooo0_l00003ooooo`;o00002Oooool2o`0000?ooooo0_l00003ooooo`;o00002Oooool4o`0000?o
oooo0_l00003ooooo`;o00003_ooool4o`0000Sooooo0_l0000=ooooo`;o00001_ooool2o`0000;o
oooo0_l0000Fooooo`;o00009oooool2o`0002[ooooo0_l000000ooooooo0000o`00000Cooooo`;o
00002Oooool2o`0001gooooo000Yooooo`03o`000?oooooooooo00;ooooo0_l0000Uooooo`;o0000
2oooool2o`0000;ooooo0_l0000>ooooo`Co00000oooool2o`0001Gooooo0_l0000?ooooo`;o0000
;oooool2o`0001Gooooo0_l00006ooooo`Co000000?oooooo`000?l000001?ooool2o`0001kooooo
0_l00002ooooo`;o00000oooool2o`0000Cooooo0_l00002ooooo`;o00002Oooool2o`0000Sooooo
0ol0000Mooooo`00:Oooool00ol0003oooooooooo`0Yooooo`;o00001Oooool4o`000008oa0@4?oo
oooo0000o`000?lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:Oooool5
o`0000?ooooo00Cok^k^oc8b<_l0003o<S8b0ol000001_ooooook^k^oc8b<_l0003o<S8bonk^kQgo
oooo0_l000000ooooooo0000o`000006ooooo`?o000000?o<S8bolc<c?ooool00_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`;o00001_ooool4
o`0000Oooooo0_l0000Cooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h00_l000001_ooooook^k^o`000?l0003o<S8bonk^kPOooooo0_l00002ooooo`;o00000oooool2
o`0000Sooooo0_l00004ooooo`;o00001Oooool2o`000005odA4A?l0003o0000oc8b<_oMgMd00_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00
:Oooool00ol0003oooooooooo`0Xooooo`;o00002?ooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg02Wooooo00GoV9RHob4Q
8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ol000001OmgMgOoV9RHoooo
oonHV9SoMgMg01;ooooo0_l00009ooooo`;o000000?oooooo`000?l000001_ooool01Ol@413o0000
o`000?mgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL07oooool2o`0000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`09ooooo`;o00001Oooool2o`0000Sooooo
0_l0000;ooooo`;o00000_ooool2o`000008oc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL3
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wooooo1?l0000Wooooo`;o00002?ooool0
0ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000_l000000ooooooo410@oooo
o`02ooooo`03oa0@4?oooooooooo01;ooooo0_l0000Dooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Ko
410@oooooooooooooooooa0@4?ooool2o`000005oa0@4?ooooooooooooooool@41002_ooool2o`00
00Kooooo0_l0000Aooooo`;o00000_ooool2o`000003ooooool0003ooooo00;ooooo00Go410@oooo
oooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41007oooool4o`0000Gooooo1_l0
0002ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Wo
oooo0_l0000:ooooo`;o000000?oooooo`000?l000004Oooool3o`0000;ooooo00Go410@oooooooo
oooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool002Wooooo1?l0000Ooooo
o`;o00004?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`?o000000Cooooo
o`000?oooooooooo0_l0000Dooooo`;o000000?oooooo`000?l000004_ooool00onHV9So8B4Qonk^
kP03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000[o
oooo0_l00002ooooo`;o00002oooool2o`0000Cooooo0_l00002ooooo`;o00001?ooool00onYZJWo
410@ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000001oooooo1?l00005ooooo`03odA4A?oMgMgooooo00?o00000_ooool01Ol0003ooooooooooooo
oooo000000;ooooo0_l00003ooooo`03o`000?oooooooooo01?ooooo0_l000000ooooooo0000o`00
000Booooo`05ogMgMolb<S;oooooooooool000000oooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool00Oooool002Wooooo00?o0000ooooooooool01oooool2o`0001Oooooo
0_l0000@ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`Go
00004Oooool2o`0000Cooooo0_l0000?ooooo`?o000000?oooooogMgMomVIVH00oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00000>ooooo`;o00002oooool2
o`0000Cooooo0_l00007ooooo`03oa0@4?l0003o000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000006?ooool2o`0000kooooo00CogMgMoeEEEOoooooo
00001?ooool01Ol0003ooooooooooooooooo000000;ooooo0_l00003ooooo`03o`000?oooooooooo
02Oooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo000Yooooo`03o`000?oooooooooo00Oooooo0_l0
000Yooooo`;o00000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@o`000?l0003o
oooooa0@400Aooooo`;o00004?ooool2o`0000?ooooo0ol00002ooooo`05o`000?oooooooooooooo
ool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0:Oooool2
o`0000?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100
6?ooool2o`0000cooooo0_l000000oooooooMgMgo`000002o`0000?ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100:Oooool00ol0003oooooooooo`04oooo
o`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo000Y
ooooo`03o`000?oooooooooo03;ooooo0_l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_oo
ool2o`000004oiRHV?ooooooV9RHogMgM`Wooooo0_l00005ooooo`;o00004Oooool2o`0000Cooooo
00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg02Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01?mgMgOoV9RHoooooonHV9P2o`0001Gooooo0_l0000=ooooo`?o
000000?oooooonk^k_l000000_l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01Kooooo0_l0000Aooooo`03o`000?oooooooooo00Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wooooo00?o
0000ooooooooool04_ooool2o`0001cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00;ooooo0_l000001?lb<S;o0000oc8b<_o^k^h9ooooo`;o00001?ooool3o`0001Oo
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo0_l0000Iooooo`05ojVYZOl@413o0000oa0@4?nYZJT0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Cok^k^oc8b<_l0003o<S8b0_l0000Eoooo
o`;o00003Oooool2o`0000?ooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Fooooo`;o00004Oooool4o`0000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool002Wooooo
0_l0000Cooooo`;o00003oooool2o`0002kooooo0_l00007ooooo`;o0000<Oooool2o`0002Oooooo
0_l00003ooooo`;o00004_ooool2o`0005Oooooo0_l0000@ooooo`00:Oooool00ol0003ooooooooo
o`0Iooooo`;o00002?ooool2o`0001kooooo0_l0000Gooooo`;o00003?ooool2o`0000Wooooo0_l0
000:ooooo`;o00004oooool2o`00023ooooo0_l00003ooooo`;o00004_ooool2o`0005Oooooo0_l0
000@ooooo`00:Oooool00ol0003oooooooooo`0Iooooo`?o00003?ooool2o`0000kooooo0_l00009
ooooo`;o00009Oooool2o`0000;ooooo0_l00005ooooo`;o00002_ooool2o`00013ooooo1ol0000;
ooooo`;o00001_ooool2o`0004gooooo0_l00003ooooo`;o00006oooool2o`0000_ooooo0_l0000?
ooooo`00:Oooool00ol0003oooooooooo`0Jooooo`;o00003?ooool2o`0000kooooo0_l0000aoooo
o`;o000000?oooooo`000?l000004oooool2o`0000kooooo1ol0000;ooooo`?o000000?oooooo`00
0?l000000_ooool2o`0004gooooo0_l00003ooooo`;o00000oooool2o`0001Kooooo0_l0000;oooo
o`;o00003oooool002Wooooo00?o0000ooooooooool01Oooool2o`0005kooooo0_l00004ooooo`;o
00005_ooool2o`0001;ooooo0_l00008ooooo`;o00000oooool2o`000003ooooool0003o000000?o
oooo0_l00003ooooo`;o0000A?ooool2o`0000?ooooo0_l00006ooooo`;o00004_ooool2o`00023o
oooo000Qoooooooo0000A?l00004ooooo`00:Oooool00ol0003oooooooooo`08ooooo`;o00003?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo0_l000000ooooooo0000oooo
o`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`06ooooo`;o000000?oooooo`000?l000002_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`;o00002ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo0_l00005ooooo`03o`000?oo
oooooooo00Cooooo0ol00002ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`03ooooo`;o00001?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00[ooooo00Co0000oooooooooooooooo0_l00006ooooo`;o000000?oooooo`000?l00000
1Oooool3o`000003ooooool0003o000000Sooooo00?o0000ooooooooool02_ooool002Wooooo00?o
0000ooooooooool02?ooool2o`00027ooooo0_l00005ooooo`;o00001_ooool00ol0003ooooooooo
o`0>ooooo`;o00004_ooool2o`0001Oooooo00?o0000ooooooooool03?ooool2o`0001?ooooo0_l0
000Gooooo`?o00003oooool4o`00027ooooo0_l00004ooooo`03o`000?oooooooooo01[ooooo0_l0
000@ooooo`?o000000?oooooo`000?l000002?ooool00ol0003oooooooooo`0:ooooo`00:Oooool0
1?l0003oooooooooooooool2o`0000[ooooo0_l0000Nooooo`Co000000?oooooo`000?l000002_oo
ool2o`0000_ooooo0_l0000Vooooo`;o000000Coooooo`000?l0003ooooo0_l0000<ooooo`;o0000
3oooool3o`0001_ooooo0_l0000;ooooo`;o00000_ooool2o`0003Wooooo0_l0000Nooooo`;o0000
1Oooool2o`0000;ooooo0_l0000=ooooo`00:Oooool01?l0003oooooooooooooool2o`0000[ooooo
0_l0000Nooooo`Ko00002oooool2o`00027ooooo0_l0000@ooooo`;o000000?oooooo`000?l00000
0ol00002ooooo`;o00006Oooool3o`0002Sooooo0_l0000Mooooo`;o00005_ooool2o`0000Kooooo
0_l0000Uooooo`;o00000_ooool2o`0000gooooo000Yooooo`;o0000<_ooool2o`0002kooooo0_l0
000Eooooo`;o00000_ooool3o`0003cooooo0_l00009ooooo`;o00006_ooool2o`0000[ooooo0_l0
0002ooooo`;o00001_ooool3o`0000oooooo0_l0000^ooooo`00:Oooool00ol0003oooooooooo`06
ooooo`;o0000;?ooool4o`0000Wooooo0_l0000Eooooo`;o00005?ooool2o`0000cooooo0ol0000f
ooooo`;o00001?ooool2o`0000Wooooo0_l0000@ooooo`;o000000?oooooo`000?l000004Oooool2
o`0000;ooooo0_l00007ooooo`;o00003oooool2o`0002kooooo000Yooooo`04o`000?oooooo0000
o`0000;ooooo0_l000000ooooooo0000o`00000[ooooo`Go00002Oooool2o`0000gooooo0_l00002
ooooo`;o00000_ooool2o`0001Cooooo0_l0000<ooooo`;o0000=oooool2o`0000gooooo0_l0000B
ooooo`;o000000?oooooo`000?l000008_ooool2o`0000Oooooo0_l00004ooooo`;o0000;?ooool0
02Wooooo00Co0000ooooool0003o00000_ooool2o`0000Oooooo0_l0000Hooooo`;o00002oooool2
o`0001Wooooo1?l00002ooooo`;o00009_ooool2o`0002[ooooo0_l0000Jooooo`;o00005oooool2
o`00023ooooo0_l00007ooooo`;o00001?ooool2o`0002cooooo000Yooooo`03o`000?oooooooooo
00cooooo0_l00007ooooo`;o00003oooool2o`00027ooooo0_l00003ooooo`;o0000;_ooool2o`00
02Sooooo0_l00005ooooo`;o0000;?ooool2o`0001Gooooo0_l0000Dooooo`;o00002Oooool2o`00
01Kooooo0_l0000=ooooo`00:Oooool2o`000003ooooool0003o000001?ooooo0_l0000@ooooo`;o
00007Oooool2o`000003ooooool0003o000003?ooooo0_l00009ooooo`Co00004_ooool2o`0000ko
oooo0_l0000Booooo`;o0000;oooool2o`0000Sooooo0_l0000:ooooo`;o00002Oooool2o`0000co
oooo0_l00003ooooo`;o00000oooool2o`0000gooooo000Yooooo`03o`000?oooooooooo00;o0000
4_ooool2o`00017ooooo0_l0000Mooooo`;o00007?ooool2o`0002?ooooo1?l0000Booooo`;o0000
6?ooool2o`0000Sooooo0_l00007ooooo`;o00000_ooool2o`0000Kooooo0_l0000Tooooo`;o0000
3Oooool2o`0001Cooooo0_l00003ooooo`;o00004_ooool002Wooooo00?o0000ooooooooool04Ooo
ool5o`0000;ooooo0_l00014ooooo`;o00001?ooool2o`0001cooooo0_l0000;ooooo`;o00006_oo
ool2o`0000cooooo0_l0000Aooooo`?o000000?oooooo`000?l000001?l00002ooooo`;o0000<ooo
ool2o`00013ooooo0_l0000Kooooo`00:Oooool00ol0003oooooooooo`0=ooooo`;o00000_ooool4
o`0000?ooooo0_l00014ooooo`Go00001?ooool2o`0000kooooo0_l00009ooooo`;o00002Oooool4
o`0000Wooooo0_l00002ooooo`;o00002oooool2o`00023ooooo0ol00002ooooo`Co00001Oooool2
o`0001[ooooo0_l0000;ooooo`;o00006Oooool2o`0000[ooooo0_l0000?ooooo`00:Oooool2o`00
00kooooo0_l0000Cooooo`;o0000=_ooool2o`0000?ooooo1?l00004ooooo`;o00003_ooool2o`00
00kooooo0_l00004ooooo`;o00002oooool2o`0000;ooooo0_l00002ooooo`?o0000:Oooool2o`00
00_ooooo0_l0000:ooooo`;o00001_ooool2o`0000Kooooo1?l000001?oooooo0000o`000?ooool2
o`0000?ooooo0_l0000Fooooo`;o000000?oooooo`000?l000002_ooool2o`0000oooooo000Yoooo
o`;o00008oooool2o`0000[ooooo0_l0000=ooooo`;o00006oooool2o`0001Gooooo0_l0000Doooo
o`;o00002Oooool2o`0000kooooo0ol00012ooooo`Co00001?ooool2o`0000Sooooo0_l000001?oo
oooo0000o`000?ooool2o`0000?ooooo0_l0000Fooooo`;o00007_ooool002Wooooo00?o0000oooo
ooooool03oooool2o`0001gooooo0_l0000=ooooo`;o0000<_ooool2o`0000oooooo0_l000000ooo
oooo0000o`00000;ooooo`;o0000??ooool2o`0000oooooo0_l00006ooooo`;o0000DOooool002Wo
oooo00?o0000ooooooooool03oooool2o`0003?ooooo0_l0000iooooo`;o000000Coooooo`000?l0
003ooooo0_l0000;ooooo`;o00008_ooool2o`0000?ooooo0_l00003ooooo`;o00003_ooool2o`00
00oooooo0_l000000ooooooo0000o`00001Fooooo`00:Oooool00ol0003oooooooooo`0<ooooo`;o
00007_ooool4o`0001Cooooo0_l0000iooooo`;o00006Oooool2o`0001[ooooo0_l00003ooooo`;o
00000oooool2o`0002;ooooo1?l0000nooooo`;o00005?ooool002Wooooo00?o0000ooooooooool0
3?ooool2o`0001kooooo1?l0000Oooooo`;o0000BOooool2o`0004[ooooo0_l00007ooooo`;o0000
7oooool2o`0000kooooo0_l00004ooooo`;o00005?ooool002Wooooo0_l0000Gooooo`;o0000=ooo
ool2o`0008;ooooo0_l00007ooooo`;o00004Oooool2o`0001Wooooo0_l00004ooooo`;o00003_oo
ool2o`0000?ooooo0_l0000Eooooo`00:Oooool00ol0003oooooooooo`0Fooooo`;o00006?ooool2
o`0003oooooo0_l0000=ooooo`;o0000;_ooool2o`0000Gooooo0_l00008ooooo`;o00000_ooool2
o`0000cooooo0_l00007ooooo`;o00003_ooool2o`0000Cooooo0_l0000Fooooo`;o00006Oooool2
o`0001Gooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Gooooo`;o00005ooo
ool2o`00033ooooo1?l0000;ooooo`;o00003Oooool2o`0002kooooo0_l00005ooooo`;o00002?oo
ool2o`0000;ooooo0_l00006ooooo`;o00001oooool2o`0001Cooooo0_l00004ooooo`;o00009ooo
ool2o`0001oooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
4_ooool2o`0000?ooooo0_l00019ooooo`Co00001_ooool2o`0004Gooooo0_l0000Hooooo`;o0000
1oooool2o`0001Wooooo0_l0000Fooooo`;o00004?ooool2o`0000Gooooo0_l0000Hooooo`001_oo
ool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo01;ooooo0_l00009ooooo`;o0000COooool2o`0001Sooooo
0_l0000Cooooo`;o00001oooool2o`0000gooooo0_l0000Zooooo`;o00004?ooool2o`0000oooooo
0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00009ooooo`Co00005_ooool000Kooooo00Go
0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0
1?ooool3o`0001gooooo0ol0000Mooooo`;o00003oooool2o`0000?ooooo0_l0000aooooo`;o0000
0_ooool2o`0000oooooo0_l00007ooooo`;o00002oooool2o`0002Wooooo0_l000000ooooooo0000
o`000002o`0001oooooo0_l0000<ooooo`;o00001Oooool2o`0000_ooooo0_l0000Fooooo`001_oo
ool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool01Oooool2o`0000?ooooo0_l0000Booooo`;o
00007Oooool2o`0000oooooo0_l00003ooooo`;o00000_ooool2o`00037ooooo0_l0000Uooooo`?o
0000:?ooool2o`0000?ooooo0_l0001<ooooo`;o00002oooool000Kooooo00Go410@oooooooooooo
oooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`05ooooo`;o00000oooool2o`0001Cooooo0_l0000eooooo`;o00005_ooool2o`0003oo
oooo1?l000000ooooooo0000o`00001Qooooo`;o00005Oooool2o`0000_ooooo0006ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Eooooo`;o00002Oooool2o`0002Wooooo0_l0000Roooo
o`;o00001Oooool2o`0003Sooooo0_l00003ooooo`;o0000;oooool3o`0002oooooo0_l0000Roooo
o`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004
ooooo`Co00001_ooool00ol0003oooooooooo`0:ooooo`;o00000oooool2o`0000Cooooo0_l0000d
ooooo`Co00009oooool2o`0000gooooo0_l0001Oooooo`?o0000Doooool002Wooooo0_l0000;oooo
o`;o00000oooool2o`0002[ooooo0_l00003ooooo`;o00001oooool2o`0000;ooooo0_l0000foooo
o`;o0000:oooool2o`0001Kooooo0_l0000Qooooo`;o0000?Oooool2o`0000kooooo000Yooooo`03
o`000?oooooooooo00Cooooo0_l0000Qooooo`;o00004_ooool2o`0000?ooooo0_l00006ooooo`?o
0000Ioooool2o`0000Sooooo0_l0000<ooooo`;o00008Oooool2o`0000Sooooo0_l0000cooooo`;o
00003_ooool002Wooooo00?o0000ooooooooool01?ooool2o`0000?ooooo1?l0000Jooooo`;o0000
7oooool2o`00017ooooo0_l0000Rooooo`;o00000oooool2o`0000[ooooo0_l0000Zooooo`;o0000
6?ooool2o`0000;ooooo0_l0000Kooooo`;o0000@oooool002Wooooo00?o0000ooooooooool01?oo
ool2o`000003ooooool0003o000000Co0000>Oooool2o`0001?ooooo0_l0000<ooooo`;o00005?oo
ool2o`0000?ooooo0_l0000:ooooo`;o00002oooool2o`0000gooooo0_l0000?ooooo`;o00005ooo
ool2o`0000;ooooo0_l0001Pooooo`00:Oooool00ol0003oooooooooo`04ooooo`;o000000?ooooo
o`000?l00000?Oooool2o`00027ooooo0_l0000booooo`;o00003Oooool2o`0000oooooo0_l0001J
ooooo`;o00008Oooool002Wooooo0_l00039ooooo`;o00007_ooool2o`0000cooooo0_l0000Qoooo
o`;o00008Oooool002Wooooo00?o0000ooooooooool07?ooool2o`0001Wooooo0ol0002>ooooo`;o
00007_ooool2o`0000cooooo0_l00014ooooo`00:Oooool00ol0003oooooooooo`0Jooooo`Co0000
00?oooooo`000?l000005_ooool3o`0006kooooo0_l0000@ooooo`;o0000P?ooool002Wooooo00?o
0000ooooooooool06_ooool2o`0000?ooooo0_l0000aooooo`;o0000B?ooool2o`0000[ooooo0_l0
000@ooooo`;o00001?ooool2o`0001gooooo0_l00002ooooo`;o00002oooool2o`0000oooooo0_l0
000@ooooo`;o00009oooool002Wooooo00Co0000oooooooooooooooo0_l0001?ooooo`;o0000B?oo
ool2o`0002;ooooo0_l0000Mooooo`;o00000_ooool2o`0000_ooooo0_l0000?ooooo`;o00004?oo
ool2o`0002Oooooo000Yooooo`;o00000_ooool2o`00027ooooo0_l0000?ooooo`;o00003?ooool2
o`0002Cooooo0_l00004ooooo`;o0000U?ooool2o`0003Gooooo000Yooooo`03o`000?oooooooooo
00;ooooo0_l0000<ooooo`;o00004_ooool2o`0000oooooo0_l0000:ooooo`Co00009?ooool2o`00
00Cooooo0ol00002ooooo`;o0000Soooool2o`0000;ooooo0_l0000aooooo`00:Oooool00ol0003o
ooooooooo`02ooooo`;o00003?ooool2o`0000gooooo0_l00004ooooo`;o00002Oooool2o`0000oo
oooo0_l0000]ooooo`;o00000_ooool2o`0001kooooo0_l0000Rooooo`;o00005oooool2o`0003Ko
oooo0_l0000Looooo`;o000000?oooooo`000?l000004?ooool002Wooooo00?o0000ooooooooool0
7oooool2o`0000Cooooo0_l00009ooooo`;o00004oooool2o`0000oooooo0_l00006ooooo`;o0000
0oooool2o`0002oooooo0_l0000Rooooo`;o00005oooool2o`0005Cooooo0_l000000ooooooo0000
o`00000@ooooo`00:Oooool00ol0003oooooooooo`15ooooo`;o00003oooool2o`0000Kooooo0_l0
0003ooooo`;o0000Z_ooool2o`0002_ooooo000Yooooo`;o0000oooooolAooooo`;o0000:oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`1g
ooooo`;o0000S_ooool2o`0003?ooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1gooooo`;o0000S_ooool2
o`0003?ooooo000>ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03
ooooo`?o0000oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`1jooooo`;o00004?ooool2o`000:kooooo000>oooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool0N_ooool2o`00013ooooo0_l0002^ooooo`003_ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo000>
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_oo
ool2o`000?Cooooo0_l00017ooooo`00:Oooool00ol0003oooooooooo`0Mooooo`;o00003?ooool2
o`0000cooooo0_l0002Dooooo`;o00008_ooool2o`0001Kooooo0_l0000_ooooo`00:Oooool00ol0
003oooooooooo`0Mooooo`;o00003?ooool2o`0000cooooo0_l0002Dooooo`;o0000>_ooool2o`00
02oooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003Oooool0
0onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006oooo
o`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo
000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?o
ZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Ooo
ool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S80
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`007oooool4o`000003oa0@4?oooooooooo
00?ooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool3o`000?oooooo
?Oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`007oooool00omEEEGoIVIVo`00003oooooodOooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .27682 Mdot
.02762 .2643 Mdot
.02952 .29459 Mdot
.03143 .28159 Mdot
.03333 .25744 Mdot
.03524 .38757 Mdot
.03714 .29656 Mdot
.03905 .45092 Mdot
.04095 .3997 Mdot
.04286 .27717 Mdot
.04476 .2723 Mdot
.04667 .44779 Mdot
.04857 .39487 Mdot
.05048 .25454 Mdot
.05238 .44103 Mdot
.05429 .34376 Mdot
.05619 .24946 Mdot
.0581 .39866 Mdot
.06 .35503 Mdot
.0619 .3445 Mdot
.06381 .40004 Mdot
.06571 .32772 Mdot
.06762 .35118 Mdot
.06952 .40455 Mdot
.07143 .41796 Mdot
.07333 .36161 Mdot
.07524 .31206 Mdot
.07714 .35559 Mdot
.07905 .31984 Mdot
.08095 .27321 Mdot
.08286 .40763 Mdot
.08476 .39953 Mdot
.08667 .44323 Mdot
.08857 .27192 Mdot
.09048 .34329 Mdot
.09238 .3786 Mdot
.09429 .24526 Mdot
.09619 .35244 Mdot
.0981 .28688 Mdot
.1 .4473 Mdot
.1019 .42118 Mdot
.10381 .31156 Mdot
.10571 .3841 Mdot
.10762 .25925 Mdot
.10952 .31197 Mdot
.11143 .2808 Mdot
.11333 .25516 Mdot
.11524 .36025 Mdot
.11714 .36207 Mdot
.11905 .32325 Mdot
.12095 .35662 Mdot
.12286 .24789 Mdot
.12476 .46493 Mdot
.12667 .36912 Mdot
.12857 .37493 Mdot
.13048 .42574 Mdot
.13238 .45068 Mdot
.13429 .25106 Mdot
.13619 .30797 Mdot
.1381 .32565 Mdot
.14 .29708 Mdot
.1419 .27121 Mdot
.14381 .27941 Mdot
.14571 .3345 Mdot
.14762 .43947 Mdot
.14952 .41455 Mdot
.15143 .28481 Mdot
.15333 .33878 Mdot
.15524 .35414 Mdot
.15714 .41048 Mdot
.15905 .24358 Mdot
.16095 .31234 Mdot
.16286 .27163 Mdot
.16476 .31666 Mdot
.16667 .27962 Mdot
.16857 .2864 Mdot
.17048 .46507 Mdot
.17238 .33222 Mdot
.17429 .26434 Mdot
.17619 .36601 Mdot
.1781 .41129 Mdot
.18 .26756 Mdot
.1819 .26598 Mdot
.18381 .31952 Mdot
.18571 .44339 Mdot
.18762 .34605 Mdot
.18952 .2533 Mdot
.19143 .25192 Mdot
.19333 .26757 Mdot
.19524 .3401 Mdot
.19714 .41464 Mdot
.19905 .34991 Mdot
.20095 .30471 Mdot
.20286 .25977 Mdot
.20476 .31813 Mdot
.20667 .3247 Mdot
.20857 .25421 Mdot
.21048 .36106 Mdot
.21238 .47005 Mdot
.21429 .26409 Mdot
.21619 .25605 Mdot
.2181 .29853 Mdot
.22 .44638 Mdot
.2219 .24496 Mdot
.22381 .41551 Mdot
.22571 .28513 Mdot
.22762 .24649 Mdot
.22952 .34699 Mdot
.23143 .30331 Mdot
.23333 .41076 Mdot
.23524 .25927 Mdot
.23714 .27543 Mdot
.23905 .39651 Mdot
.24095 .37408 Mdot
.24286 .48569 Mdot
.24476 .32835 Mdot
.24667 .31664 Mdot
.24857 .42554 Mdot
.25048 .41498 Mdot
.25238 .24116 Mdot
.25429 .39403 Mdot
.25619 .31497 Mdot
.2581 .38479 Mdot
.26 .31476 Mdot
.2619 .41116 Mdot
.26381 .29921 Mdot
.26571 .36117 Mdot
.26762 .28579 Mdot
.26952 .23967 Mdot
.27143 .29227 Mdot
.27333 .34979 Mdot
.27524 .24085 Mdot
.27714 .44234 Mdot
.27905 .38672 Mdot
.28095 .38951 Mdot
.28286 .2841 Mdot
.28476 .23452 Mdot
.28667 .33808 Mdot
.28857 .27494 Mdot
.29048 .4462 Mdot
.29238 .44067 Mdot
.29429 .22442 Mdot
.29619 .26074 Mdot
.2981 .35723 Mdot
.3 .24916 Mdot
.3019 .36012 Mdot
.30381 .43758 Mdot
.30571 .46786 Mdot
.30762 .3385 Mdot
.30952 .25819 Mdot
.31143 .34087 Mdot
.31333 .31012 Mdot
.31524 .3399 Mdot
.31714 .4063 Mdot
.31905 .31811 Mdot
.32095 .36797 Mdot
.32286 .23023 Mdot
.32476 .26767 Mdot
.32667 .42464 Mdot
.32857 .24599 Mdot
.33048 .23049 Mdot
.33238 .37303 Mdot
.33429 .2646 Mdot
.33619 .42888 Mdot
.3381 .39463 Mdot
.34 .38211 Mdot
.3419 .26268 Mdot
.34381 .43509 Mdot
.34571 .41524 Mdot
.34762 .35199 Mdot
.34952 .22978 Mdot
.35143 .34521 Mdot
.35333 .2894 Mdot
.35524 .34315 Mdot
.35714 .25301 Mdot
.35905 .32933 Mdot
.36095 .44271 Mdot
.36286 .31281 Mdot
.36476 .37066 Mdot
.36667 .32746 Mdot
.36857 .30906 Mdot
.37048 .235 Mdot
.37238 .44115 Mdot
.37429 .33715 Mdot
.37619 .41673 Mdot
.3781 .26322 Mdot
.38 .39403 Mdot
.3819 .28237 Mdot
.38381 .39666 Mdot
.38571 .43189 Mdot
.38762 .38818 Mdot
.38952 .34334 Mdot
.39143 .36053 Mdot
.39333 .334 Mdot
.39524 .28793 Mdot
.39714 .4475 Mdot
.39905 .39926 Mdot
.40095 .4452 Mdot
.40286 .25326 Mdot
.40476 .38799 Mdot
.40667 .27009 Mdot
.40857 .3162 Mdot
.41048 .31923 Mdot
.41238 .30528 Mdot
.41429 .26237 Mdot
.41619 .40437 Mdot
.4181 .24779 Mdot
.42 .30413 Mdot
.4219 .38219 Mdot
.42381 .27188 Mdot
.42571 .27584 Mdot
.42762 .27888 Mdot
.42952 .37025 Mdot
.43143 .32669 Mdot
.43333 .41497 Mdot
.43524 .34197 Mdot
.43714 .25735 Mdot
.43905 .31381 Mdot
.44095 .42659 Mdot
.44286 .26318 Mdot
.44476 .33732 Mdot
.44667 .45017 Mdot
.44857 .31134 Mdot
.45048 .31791 Mdot
.45238 .4163 Mdot
.45429 .4066 Mdot
.45619 .34368 Mdot
.4581 .29017 Mdot
.46 .25073 Mdot
.4619 .29495 Mdot
.46381 .44076 Mdot
.46571 .30477 Mdot
.46762 .3344 Mdot
.46952 .28324 Mdot
.47143 .40757 Mdot
.47333 .33777 Mdot
.47524 .30974 Mdot
.47714 .32853 Mdot
.47905 .34868 Mdot
.48095 .23923 Mdot
.48286 .38379 Mdot
.48476 .24442 Mdot
.48667 .27046 Mdot
.48857 .3916 Mdot
.49048 .41058 Mdot
.49238 .24365 Mdot
.49429 .4024 Mdot
.49619 .32409 Mdot
.4981 .23108 Mdot
.5 .29099 Mdot
.5019 .24406 Mdot
.50381 .27697 Mdot
.50571 .40346 Mdot
.50762 .32844 Mdot
.50952 .33328 Mdot
.51143 .23183 Mdot
.51333 .36286 Mdot
.51524 .33979 Mdot
.51714 .38313 Mdot
.51905 .29333 Mdot
.52095 .44881 Mdot
.52286 .33789 Mdot
.52476 .35146 Mdot
.52667 .30903 Mdot
.52857 .4032 Mdot
.53048 .31482 Mdot
.53238 .3152 Mdot
.53429 .29732 Mdot
.53619 .25567 Mdot
.5381 .38855 Mdot
.54 .36471 Mdot
.5419 .36962 Mdot
.54381 .37245 Mdot
.54571 .37985 Mdot
.54762 .27904 Mdot
.54952 .36101 Mdot
.55143 .23017 Mdot
.55333 .33384 Mdot
.55524 .31918 Mdot
.55714 .36655 Mdot
.55905 .27263 Mdot
.56095 .37367 Mdot
.56286 .2934 Mdot
.56476 .2842 Mdot
.56667 .3297 Mdot
.56857 .246 Mdot
.57048 .44802 Mdot
.57238 .34504 Mdot
.57429 .32137 Mdot
.57619 .29329 Mdot
.5781 .38949 Mdot
.58 .26733 Mdot
.5819 .41263 Mdot
.58381 .28221 Mdot
.58571 .29829 Mdot
.58762 .44483 Mdot
.58952 .3019 Mdot
.59143 .27203 Mdot
.59333 .28255 Mdot
.59524 .30691 Mdot
.59714 .40091 Mdot
.59905 .44251 Mdot
.60095 .45355 Mdot
.60286 .36635 Mdot
.60476 .3911 Mdot
.60667 .23893 Mdot
.60857 .40171 Mdot
.61048 .42337 Mdot
.61238 .25533 Mdot
.61429 .36392 Mdot
.61619 .36641 Mdot
.6181 .29121 Mdot
.62 .36726 Mdot
.6219 .24546 Mdot
.62381 .38896 Mdot
.62571 .35238 Mdot
.62762 .32607 Mdot
.62952 .32447 Mdot
.63143 .29287 Mdot
.63333 .44229 Mdot
.63524 .3119 Mdot
.63714 .43909 Mdot
.63905 .36055 Mdot
.64095 .22284 Mdot
.64286 .32313 Mdot
.64476 .38659 Mdot
.64667 .32338 Mdot
.64857 .25881 Mdot
.65048 .28626 Mdot
.65238 .30868 Mdot
.65429 .28154 Mdot
.65619 .24405 Mdot
.6581 .45157 Mdot
.66 .23134 Mdot
.6619 .32021 Mdot
.66381 .3523 Mdot
.66571 .2859 Mdot
.66762 .30376 Mdot
.66952 .25424 Mdot
.67143 .38959 Mdot
.67333 .38249 Mdot
.67524 .37289 Mdot
.67714 .26913 Mdot
.67905 .4546 Mdot
.68095 .36547 Mdot
.68286 .25419 Mdot
.68476 .3337 Mdot
.68667 .43635 Mdot
.68857 .30327 Mdot
.69048 .34467 Mdot
.69238 .29342 Mdot
.69429 .27646 Mdot
.69619 .28529 Mdot
.6981 .22516 Mdot
.7 .44897 Mdot
.7019 .27936 Mdot
.70381 .37318 Mdot
.70571 .37015 Mdot
.70762 .26441 Mdot
.70952 .35141 Mdot
.71143 .32726 Mdot
.71333 .4488 Mdot
.71524 .22434 Mdot
.71714 .40904 Mdot
.71905 .44267 Mdot
.72095 .4372 Mdot
.72286 .41959 Mdot
.72476 .28423 Mdot
.72667 .34812 Mdot
.72857 .43979 Mdot
.73048 .44974 Mdot
.73238 .27865 Mdot
.73429 .41339 Mdot
.73619 .36443 Mdot
.7381 .38196 Mdot
.74 .2621 Mdot
.7419 .37145 Mdot
.74381 .23983 Mdot
.74571 .2619 Mdot
.74762 .23551 Mdot
.74952 .34484 Mdot
.75143 .26332 Mdot
.75333 .34383 Mdot
.75524 .42703 Mdot
.75714 .4812 Mdot
.75905 .25472 Mdot
.76095 .36352 Mdot
.76286 .32026 Mdot
.76476 .38433 Mdot
.76667 .27444 Mdot
.76857 .27784 Mdot
.77048 .44009 Mdot
.77238 .41131 Mdot
.77429 .30575 Mdot
.77619 .30645 Mdot
.7781 .34779 Mdot
.78 .31963 Mdot
.7819 .36877 Mdot
.78381 .41754 Mdot
.78571 .29299 Mdot
.78762 .43976 Mdot
.78952 .25025 Mdot
.79143 .4455 Mdot
.79333 .2582 Mdot
.79524 .33284 Mdot
.79714 .31918 Mdot
.79905 .31235 Mdot
.80095 .45101 Mdot
.80286 .44799 Mdot
.80476 .30902 Mdot
.80667 .27928 Mdot
.80857 .31403 Mdot
.81048 .34501 Mdot
.81238 .37438 Mdot
.81429 .25485 Mdot
.81619 .39649 Mdot
.8181 .25904 Mdot
.82 .34196 Mdot
.8219 .30627 Mdot
.82381 .24943 Mdot
.82571 .26169 Mdot
.82762 .32536 Mdot
.82952 .31164 Mdot
.83143 .32805 Mdot
.83333 .44612 Mdot
.83524 .30676 Mdot
.83714 .35127 Mdot
.83905 .24659 Mdot
.84095 .35223 Mdot
.84286 .36759 Mdot
.84476 .34712 Mdot
.84667 .38243 Mdot
.84857 .34661 Mdot
.85048 .23757 Mdot
.85238 .48933 Mdot
.85429 .25014 Mdot
.85619 .32266 Mdot
.8581 .40784 Mdot
.86 .43784 Mdot
.8619 .27924 Mdot
.86381 .29426 Mdot
.86571 .45757 Mdot
.86762 .27298 Mdot
.86952 .28903 Mdot
.87143 .31891 Mdot
.87333 .40488 Mdot
.87524 .36944 Mdot
.87714 .37174 Mdot
.87905 .26702 Mdot
.88095 .35513 Mdot
.88286 .30661 Mdot
.88476 .32785 Mdot
.88667 .32634 Mdot
.88857 .32446 Mdot
.89048 .45076 Mdot
.89238 .32135 Mdot
.89429 .27589 Mdot
.89619 .24809 Mdot
.8981 .31471 Mdot
.9 .3675 Mdot
.9019 .41273 Mdot
.90381 .24481 Mdot
.90571 .28316 Mdot
.90762 .3006 Mdot
.90952 .45153 Mdot
.91143 .40474 Mdot
.91333 .25604 Mdot
.91524 .28186 Mdot
.91714 .36862 Mdot
.91905 .25961 Mdot
.92095 .34727 Mdot
.92286 .25535 Mdot
.92476 .35209 Mdot
.92667 .2872 Mdot
.92857 .2701 Mdot
.93048 .27463 Mdot
.93238 .3881 Mdot
.93429 .28216 Mdot
.93619 .37962 Mdot
.9381 .36541 Mdot
.94 .28812 Mdot
.9419 .32874 Mdot
.94381 .36673 Mdot
.94571 .38953 Mdot
.94762 .32612 Mdot
.94952 .3565 Mdot
.95143 .41585 Mdot
.95333 .2612 Mdot
.95524 .31088 Mdot
.95714 .35697 Mdot
.95905 .35448 Mdot
.96095 .26725 Mdot
.96286 .48821 Mdot
.96476 .26668 Mdot
.96667 .25904 Mdot
.96857 .32177 Mdot
.97048 .39295 Mdot
.97238 .35577 Mdot
.97429 .32678 Mdot
.97619 .44424 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo05?ooooo0_l0001^ooooo`;o00005_ooool2o`0005oooooo0006ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0Doooool2o`0006kooooo0_l0000@ooooo`;o00001?oo
ool2o`0005oooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Looooo`;o000000?o
ooooo`000?l000001?ooool2o`0003oooooo0_l0000]ooooo`;o0000IOooool000Kooooo00Go0000
ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?oo
ool3o`0005cooooo0_l000000ooooooo0000o`000004ooooo`;o0000;_ooool2o`0000;ooooo0_l0
000;ooooo`;o00008Oooool2o`00077ooooo0006ooooo`05o`000?ooooooooooooooool000003_oo
ool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`1@ooooo`;o00006_ooool2o`0002Oooooo0_l00002ooooo`;o0000;_ooool2o`0001[ooooo
0_l0001Eooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04_ooooo0_l00003ooooo`;o0000
6_ooool2o`00027ooooo0_l0000Wooooo`;o0000:_ooool3o`0001oooooo0_l0000dooooo`001_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0A_ooool2o`0000?ooooo1?l00010ooooo`;o
00009oooool2o`0002[ooooo0_l0000Pooooo`;o0000=?ooool000Kooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000oooo
ooooool04oooool2o`0001?ooooo0_l0000Booooo`Co00001_ooool2o`0000Gooooo0_l0000?oooo
o`;o0000<?ooool2o`000004ooooool0003o0000ooooo`;o00004oooool2o`00013ooooo0_l00009
ooooo`;o0000>?ooool2o`0001?ooooo0_l0000Sooooo`00:Oooool2o`0000Sooooo0_l0000:oooo
o`;o00001oooool2o`0000[ooooo0_l0000Booooo`Co00005Oooool2o`0000Oooooo0_l0000Koooo
o`;o00004oooool2o`000004ooooool0003o0000ooooo`;o00004oooool2o`00013ooooo0_l00009
ooooo`;o0000=?ooool2o`0000;ooooo0_l0000Aooooo`Co00008oooool002Wooooo00?o0000oooo
ooooool01oooool2o`0001?ooooo0_l00002ooooo`;o00004?ooool2o`00027ooooo0_l0000Toooo
o`;o00003?ooool2o`0006Oooooo0_l0000:ooooo`;o00001oooool2o`0000cooooo0_l0000Uoooo
o`00:Oooool00ol0003oooooooooo`05ooooo`;o00004_ooool2o`0000Gooooo0_l0000@ooooo`;o
00001?ooool2o`0002gooooo0_l0000=ooooo`;o00004Oooool2o`0001Kooooo0_l0000Gooooo`;o
00004?ooool2o`0000;ooooo0_l0000Gooooo`;o00001oooool2o`0000Kooooo0_l0000;ooooo`;o
00005?ooool2o`0001gooooo000Yooooo`04o`000?oooooo0000o`0000Cooooo0_l0000Booooo`;o
00005oooool2o`0000Cooooo1?l0000Looooo`;o00003Oooool2o`0000gooooo0_l00009ooooo`;o
00007_ooool2o`0001Oooooo0_l00009ooooo`;o00001Oooool2o`0000;ooooo0_l0000Gooooo`;o
00002Oooool2o`0000Cooooo1?l0000Looooo`;o000000?oooooo`000?l000003?ooool2o`0000oo
oooo000Yooooo`04o`000?oooooo0000o`0001Kooooo0_l0000Mooooo`;o00000_ooool2o`0000Co
oooo0_l0000Booooo`;o00000_ooool2o`0002Oooooo0_l00012ooooo`;o00007?ooool3o`0000ko
oooo0_l00006ooooo`Co00006_ooool4o`0000Wooooo0_l00002ooooo`;o00003oooool002Wooooo
0_l0000Hooooo`;o00005?ooool2o`0000Oooooo0_l00002ooooo`;o00001?ooool2o`0001;ooooo
0_l0000:ooooo`;o000000?oooooo`000?l000002Oooool2o`0000[ooooo0_l00007ooooo`;o0000
Doooool2o`0000Wooooo1Ol0000Fooooo`;o00007?ooool2o`0000Wooooo0_l0000Cooooo`00:Ooo
ool2o`0002kooooo1?l00002ooooo`;o00001Oooool2o`00027ooooo0_l000001?oooooo0000o`00
0?ooool2o`0000Wooooo0_l0000:ooooo`;o00001oooool2o`0002[ooooo0_l0000Wooooo`;o0000
3?ooool2o`0002Oooooo0_l0000Iooooo`?o00003oooool002Wooooo00?o0000ooooooooool08_oo
ool2o`0000[ooooo1ol00002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01Wooooo0_l0000>ooooo`Go00000oooool01Oo^k^ko<S8bo`000?l0003ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0?ooooo`;o00005oooool01OnHV9So410@o`000?lb
<S;oc<c<00;o000000Koooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03oooool2o`0001Wooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8b
onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool2o`0000kooooo0_l00004ooooo`05
odA4A?l0003o0000oc8b<_oMgMd00ol000001?lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool002Wooooo00?o0000ooooooooool00oooool2o`0000[ooooo1?l0000?
ooooo`;o00001Oooool2o`0000Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Yooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@00oooool01OmgMgOoV9RHo`000?l0003oMgMg00?ooooo0_l000000oooooooV9RHogMgM`0?oooo
o`;o00005Oooool2o`000005oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOo0000o`000?nH
V9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0?ooooo`;o00006_ooool3o`0000;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04?ooool2o`00
017ooooo0_l00007ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool2o`0000?ooooo0ol0000:ooooo`Co0000
5_ooool2o`0000Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@ooooool0003o0000oa0@400=ooooo`;o00006oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41000oooool2o`0000;ooooo00?o410@ooooooooool04oooool2
o`0000oooooo0_l00004ooooo`05o`000?ooooooooooooooool@41000_l000000ooooooo410@oooo
o`02ooooo`05oa0@4?ooooooooooooooool@41005Oooool2o`00017ooooo1_l00002ooooo`05oa0@
4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@013ooooo0_l00006oooo
o`;o00002_ooool2o`0000Oooooo00Co0000oooooooooooo410@0oooool01Ol@413ooooooooooooo
oooo410@00?ooooo00?o410@ooooooooool00Oooool002Wooooo0_l00003ooooo`;o00005?ooool2
o`0000Wooooo0_l00005ooooo`;o00001_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooo`000002o`0000gooooo0_l0000Looooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003ooooo`?o000000?oooooo`000?ooool0
5?ooool2o`0000cooooo0_l00006ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000005Oooool4o`0000Sooooo0_l00005oooo
o`05odA4A?oMgMgoooooo`000?ooool00_l000000ooooooo0000ooooo`02ooooo`04o`000?oooooo
ooooooooo`?o000000?oooooo`000?ooool03Oooool2o`0000Sooooo0_l0000:ooooo`;o00001_oo
ool01OmgMgOo<S8boooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo007ooooo000Yooooo`04o`000?oooooo0000o`0001Oooooo0_l00009ooooo`;o
00001Oooool2o`0000Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`00000[ooooo`;o000000GoIVIVooooooooooooooooo`00
0003ooooo`04o`000?ooooooooooooooo`?o000000?oooooo`000?ooool02Oooool2o`0001Oooooo
0_l00005ooooo`04oa0@4?l0003o^[Zjooooo`Go000000?oooooo`000?ooool00_ooool01Ol0003o
oooooooooooooooo000000Sooooo0_l0000=ooooo`;o00002?ooool2o`0000Gooooo00GogMgMoeEE
EOoooooo0000ooooo`02o`000003ooooool0003ooooo00;ooooo00Co0000oooooooooooooooo0ol0
00000ooooooo0000ooooo`0=ooooo`;o00003?ooool2o`000003ooooool0003o000000Cooooo0_l0
0002ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`00:Oooool01?l0003oooooo`000?l0000Coooo
o`;o00003oooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo00Ko410@oooo
oooooooooooooa0@4?ooool2o`000005oa0@4?ooooooooooooooool@41001oooool2o`0000?ooooo
0_l0000Mooooo`?o00000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooooooooa0@400:ooooo`;o00007?ooool2o`000004oooooonj^[[o8B4Qooooo`;o000000Go410@
o`000?l0003ooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001oooool3o`0000;ooooo
0_l00007ooooo`;o00002?ooool2o`0000Sooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@400Looooo`;o000000?oooooo`00
0?l000001?ooool2o`0000;ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo
410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`00:Oooool00ol0003oooooooooo`0D
ooooo`;o00003oooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo00KoMgMg
oiRHV?ooooooV9RHogMgMoooool2o`000005ogMgMonHV9SooooooiRHV?mgMgL01oooool2o`0000?o
oooo0_l0000Dooooo`;o00001Oooool01Ol0003o^[ZjoooooonHV9So410@00;ooooo0_l000001?nH
V9SooooooiRHV?mgMgL3ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:?ooool2o`000003oooooonj
^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01oooool2o`0000?ooooo0_l00007ooooo`;o00002?ooool2o`0000Sooooo00?ok^k^odA4A?l0
00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0@
ooooo`;o00004Oooool2o`0000;ooooo0ol00006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000Yooooo`03o`000?oooooooooo033ooooo00?o
EEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP08ooooo`;o00006?ooool2o`0000Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c002oooo
o`;o000000Co<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo0_l0
000;ooooo`;o00004oooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`06onk^k_l0003o0000oc8b<_o^k^kooooo0_l0000Wooooo`03ogMgMol0003o
oooo00?ooooo00Gok^k^oc8b<_l0003o0000onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
4?ooool2o`00017ooooo0_l00002ooooo`Ko00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool3o`0004cooooo0_l0000jooooo`?o
00002_ooool2o`0000Gooooo0_l0000<ooooo`;o00000_ooool2o`0000_ooooo0_l00003ooooo`;o
00004Oooool2o`0001cooooo0_l0000Gooooo`;o0000<?ooool002Wooooo0ol000000ooooooo0000
o`00000Oooooo`;o00005oooool2o`0000cooooo0_l0000nooooo`;o00004Oooool2o`0000;ooooo
0_l00008ooooo`;o00000_ooool2o`000003ooooool0003o0000023ooooo0_l0000eooooo`;o0000
<?ooool002Wooooo00Co0000oooooooooooooooo0_l0000Oooooo`;o00005oooool2o`0000cooooo
0_l0001Eooooo`;o00003oooool3o`0006Cooooo0_l0000Rooooo`00:Oooool00ol0003ooooooooo
o`0eooooo`;o00002?ooool2o`0003Sooooo0_l000000ooooooo0000o`00000<ooooo`;o00009_oo
ool2o`0001Oooooo0_l00005ooooo`;o0000A?ooool2o`0002;ooooo000Yooooo`03o`000?oooooo
oooo023ooooo0_l0000Cooooo`;o00002?ooool2o`0003Sooooo0_l000000ooooooo0000o`00000<
ooooo`;o0000:?ooool2o`00013ooooo0_l00003ooooo`;o00001Oooool2o`0001[ooooo0_l0000=
ooooo`;o00000_ooool2o`0000gooooo0_l0000Zooooo`008Oooooooo`0004Co00001?ooool002Wo
oooo00?o0000ooooooooool02Oooool01?l0003oooooooooooooool2o`0000Oooooo1?l00008oooo
o`03o`000?oooooooooo00?ooooo0_l00004ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool3o`0000Wooooo00?o0000ooooooooool00oooool2o`0000Cooooo00?o0000oooo
ooooool01oooool4o`0000_ooooo00?o0000ooooooooool01oooool5o`0000Kooooo0_l000000ooo
oooo0000ooooo`0:ooooo`03o`000?oooooo000000;o00002?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo0_l0000:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooooooo`Go00000oooool3
o`0000[ooooo00?o0000ooooooooool01oooool3o`0000_ooooo00?o0000ooooooooool00_ooool2
o`0000Gooooo00?o0000ooooooooool02_ooool002Wooooo00?o0000ooooooooool03Oooool2o`00
00Wooooo0_l0000>ooooo`Co00002_ooool2o`0000;ooooo00?o0000ooooooooool01oooool2o`00
0004ooooool0003o0000o`00017ooooo0_l0000<ooooo`;o00003Oooool2o`0000Sooooo0_l00000
0ooooooo0000o`00000Hooooo`?o00004oooool00ol0003oooooooooo`0jooooo`04o`000?oooooo
ooooooooo`;o000000?oooooo`000?l000006_ooool2o`0001Sooooo00?o0000ooooooooool02_oo
ool002Wooooo00?o0000ooooooooool03_ooool2o`0001[ooooo0_l00004ooooo`;o00001?ooool2
o`0000cooooo0_l0000Eooooo`;o00006oooool3o`0000[ooooo0_l0000Iooooo`;o00001Oooool2
o`00023ooooo0_l0000Oooooo`;o00000oooool2o`0000Cooooo0_l0000Fooooo`;o0000;Oooool0
02Wooooo00?o0000ooooooooool03_ooool2o`0000_ooooo0_l0000Cooooo`;o0000Aoooool2o`00
01Wooooo0_l0000Aooooo`;o00001?ooool2o`0001Cooooo1?l00002ooooo`;o00007oooool2o`00
00?ooooo0_l00004ooooo`;o00004Oooool2o`0000?ooooo0_l00005ooooo`;o00005_ooool2o`00
00kooooo000Yooooo`;o00007?ooool2o`0000Cooooo0_l0000Dooooo`;o0000<_ooool2o`0001;o
oooo0_l0000Cooooo`;o00005oooool2o`0000oooooo0ol00002ooooo`Co00004_ooool2o`0002Co
oooo0_l00007ooooo`;o00002?ooool4o`0000oooooo0_l00005ooooo`Co00003?ooool002Wooooo
00?o0000ooooooooool02_ooool2o`0001Gooooo0_l0000Dooooo`;o00002_ooool2o`0002?ooooo
0_l000000ooooooo0000o`00000Booooo`;o00003Oooool2o`0000Sooooo0_l0000Aooooo`;o0000
4Oooool3o`0001Sooooo0_l0000Tooooo`?o00003oooool3o`0000oooooo1?l00007ooooo`;o0000
3?ooool002Wooooo00?o0000ooooooooool02_ooool2o`00023ooooo0_l0000Eooooo`;o00008ooo
ool2o`0002Cooooo0_l00008ooooo`;o00004Oooool2o`0002Cooooo0_l0000Qooooo`;o00002_oo
ool2o`0000oooooo0_l0000@ooooo`;o00005oooool002Wooooo00?o0000ooooooooool08oooool2
o`0000Oooooo0_l00015ooooo`;o00005_ooool2o`0000_ooooo0_l0000=ooooo`;o0000:?ooool2
o`00027ooooo0_l00016ooooo`00:Oooool00ol0003oooooooooo`0Sooooo`;o000000?oooooo`00
0?l00000:Oooool2o`0000Gooooo1?l0000Aooooo`;o00001?ooool2o`0000oooooo0_l00005oooo
o`Co00002oooool2o`000003ooooool0003o000000Sooooo0_l0002Cooooo`00:Oooool2o`0002Oo
oooo0_l0000;ooooo`;o00007?ooool2o`0000Gooooo1?l0000Aooooo`;o00004_ooool2o`000003
ooooool0003o000000Oooooo0_l0000;ooooo`;o000000?oooooo`000?l00000GOooool2o`0003ko
oooo000Yooooo`03o`000?oooooooooo00Kooooo0_l000000ooooooo0000o`000007ooooo`;o0000
7Oooool4o`0002Cooooo0_l0000;ooooo`?o00002Oooool2o`0000gooooo0_l00004ooooo`;o0000
9?ooool2o`0002Cooooo0_l0000Aooooo`?o00004?ooool2o`000003ooooool0003o000003kooooo
000Yooooo`03o`000?oooooooooo00Kooooo0_l000000ooooooo0000o`000007ooooo`;o00007Ooo
ool2o`0000_ooooo0_l0000Vooooo`?o00002Oooool2o`0001?ooooo0_l00006ooooo`;o00007?oo
ool2o`0002Cooooo0_l00009ooooo`;o00001_ooool3o`0000Kooooo0_l00008ooooo`;o00002Ooo
ool3o`0001Kooooo0_l0000Mooooo`00:Oooool00ol0003oooooooooo`0:ooooo`;o0000:Oooool2
o`0000Oooooo0_l0000=ooooo`;o00005Oooool2o`0002Wooooo0_l0000<ooooo`;o0000:oooool2
o`0000gooooo0_l00003ooooo`;o00003oooool2o`00017ooooo1Ol0000Fooooo`?o00007?ooool0
02Wooooo00?o0000ooooooooool02?ooool4o`0000Sooooo0_l0000Aooooo`;o00003?ooool2o`00
01Kooooo0_l0000Eooooo`;o0000=oooool2o`0001oooooo0_l0000:ooooo`;o00003Oooool2o`00
02Oooooo0ol0000;ooooo`;o00003?ooool2o`0000Wooooo0_l0000Aooooo`00:Oooool2o`0000Wo
oooo0_l00003ooooo`;o00001Oooool2o`0000Kooooo0_l00009ooooo`;o0000:oooool2o`0006So
oooo0_l0001@ooooo`;o00005?ooool5o`0000;ooooo0_l0000=ooooo`00:Oooool00ol0003ooooo
ooooo`0<ooooo`?o00002oooool4o`0001[ooooo0_l0000@ooooo`;o00002?ooool4o`0001[ooooo
0_l0000aooooo`;o00006oooool2o`0006;ooooo1?l00003ooooo`;o00003Oooool002Wooooo00?o
0000ooooooooool03?ooool2o`0000cooooo0_l0000Looooo`;o00004?ooool2o`0000[ooooo0_l0
000Jooooo`;o00009_ooool2o`0000Kooooo0_l000000ooooooo0000o`00000Cooooo`;o00001_oo
ool2o`0001gooooo0_l00006ooooo`;o0000DOooool002Wooooo00?o0000ooooooooool06_ooool2
o`00017ooooo0_l0001[ooooo`;o00001_ooool2o`0000Cooooo0_l0000<ooooo`;o00000_ooool4
o`0001;ooooo0_l0000?ooooo`;o00001_ooool2o`0001Wooooo0_l0000@ooooo`;o00002_ooool4
o`0001Kooooo000Yooooo`03o`000?oooooooooo01gooooo0_l0000>ooooo`;o0000;Oooool2o`00
00cooooo0_l0000Cooooo`;o00008_ooool2o`0000?ooooo0_l0000<ooooo`;o00000oooool3o`00
01;ooooo0_l00006ooooo`;o00005_ooool2o`0001;ooooo0_l00008ooooo`;o00001_ooool2o`00
00Cooooo0_l00004ooooo`Co00005_ooool002Wooooo0_l0000Nooooo`;o00008oooool2o`0001So
oooo0_l000000ooooooo0000o`000009ooooo`;o00004oooool2o`0002;ooooo0_l00004ooooo`;o
00008oooool2o`0000Oooooo0ol00009ooooo`;o00002oooool2o`0001cooooo0ol0000;ooooo`;o
00007_ooool002Wooooo00?o0000ooooooooool07_ooool2o`0002;ooooo0_l0000Kooooo`;o0000
@_ooool2o`0000Cooooo0_l0000Sooooo`;o00001oooool2o`0000[ooooo0_l0000Eooooo`;o0000
4oooool2o`0002_ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Booooo`;o
00002_ooool2o`0008Cooooo0_l0001Dooooo`;o00009_ooool2o`0001Sooooo0006ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool04_ooool2o`0004kooooo0_l0000Hoooo
o`;o00007Oooool2o`0000Oooooo0_l0000Wooooo`;o00004oooool2o`00027ooooo0_l0000Koooo
o`;o00006?ooool000Kooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^
00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Gooooo`;o0000;oooool2o`00
01Sooooo0_l0000Hooooo`;o00004_ooool2o`0000Wooooo0_l0000`ooooo`;o00004oooool2o`00
00Oooooo0_l0000Hooooo`;o0000=Oooool000Kooooo00Go0000ooooooooooooooooo`00000=oooo
o`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool5o`0001Gooooo0_l0000_oooo
o`;o00001?ooool3o`00023ooooo0_l00004ooooo`;o00005oooool2o`00013ooooo0_l0000:oooo
o`;o00003Oooool2o`0000Gooooo0_l00007ooooo`;o00007?ooool2o`0003?ooooo0_l00003oooo
o`;o00005Oooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00;o0000C?ooool3
o`00023ooooo0_l00004ooooo`;o00006Oooool2o`0000kooooo0_l0000:ooooo`;o00001oooool2
o`0000Cooooo0_l00005ooooo`;o00001oooool2o`00057ooooo0_l00003ooooo`;o00005Oooool0
00Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`04ooooo`;o0000@?ooool2o`0001Wooooo0_l0000<
ooooo`;o00008Oooool2o`0002?ooooo0_l0001dooooo`;o00003Oooool000Kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Cooooo0_l000000ooooooo0000o`00000hooooo`;o00000ooo
ool2o`0001Wooooo0_l0000<ooooo`?o0000ROooool2o`00033ooooo0_l0000=ooooo`001_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co0000
1_ooool00ol0003oooooooooo`02ooooo`;o00000oooool4o`0000Gooooo0_l0000_ooooo`;o0000
;Oooool2o`0000?ooooo0_l0000nooooo`;o000000?oooooo`000?l00000@Oooool2o`0003oooooo
000Yooooo`;o00000oooool2o`0000Gooooo1?l00003ooooo`;o0000Hoooool2o`0000?ooooo0_l0
000Hooooo`;o000000?oooooo`000?l000001_ooool2o`0001Cooooo0_l000000ooooooo0000o`00
001Cooooo`;o00002oooool2o`00023ooooo000Yooooo`03o`000?oooooooooo00_ooooo0_l00002
ooooo`;o0000B_ooool2o`0001gooooo0_l0000;ooooo`;o00000oooool2o`0000Kooooo0_l00000
0ooooooo0000o`000006ooooo`;o0000J?ooool2o`0000;ooooo0_l0000;ooooo`;o00008?ooool0
02Wooooo00?o0000ooooooooool03oooool2o`0001Kooooo0_l00005ooooo`;o00004?ooool2o`00
00Oooooo0_l0000@ooooo`;o0000:_ooool2o`0000?ooooo0_l00004ooooo`;o0000Aoooool2o`00
013ooooo0_l0000Jooooo`;o0000<Oooool002Wooooo00?o0000ooooooooool09Oooool4o`0000Go
oooo0_l0000@ooooo`;o00001oooool2o`0004Oooooo0_l0000Looooo`;o0000:Oooool2o`0000Co
oooo0_l0000:ooooo`;o0000:?ooool2o`0002?ooooo000Yooooo`03o`000?oooooooooo02Gooooo
0_l0000=ooooo`;o00001oooool2o`0000Kooooo0_l0000Mooooo`;o00002?ooool2o`00013ooooo
0_l00004ooooo`;o0000:?ooool2o`0002oooooo0_l0000>ooooo`;o00009?ooool2o`0000kooooo
0_l0000Cooooo`00:Oooool2o`0000gooooo0_l0000Vooooo`;o00001oooool2o`0000Kooooo0_l0
000Mooooo`;o00002?ooool2o`00013ooooo0_l00004ooooo`;o0000EOooool2o`0001;ooooo0_l0
000dooooo`;o00004oooool002Wooooo00?o0000ooooooooool03?ooool2o`0000Oooooo0_l0002R
ooooo`;o00008_ooool2o`0005gooooo000Yooooo`03o`000?oooooooooo01Gooooo0_l00008oooo
o`;o00009?ooool2o`0001Oooooo0_l0000Rooooo`;o0000=Oooool2o`00087ooooo000Yooooo`03
o`000?oooooooooo01oooooo0_l0000Tooooo`;o00005oooool2o`000003ooooool0003o000001oo
oooo0_l0001Sooooo`;o0000Doooool002Wooooo00?o0000ooooooooool0HOooool2o`0000kooooo
0_l0001dooooo`;o0000Doooool002Wooooo0_l0001Tooooo`;o00003?ooool2o`000<Wooooo000Y
ooooo`03o`000?oooooooooo05Kooooo0_l0000;ooooo`;o0000G?ooool2o`0000kooooo0_l00009
ooooo`;o0000:oooool2o`00037ooooo000Yooooo`03o`000?oooooooooo00Gooooo0_l0000Moooo
o`;o0000:?ooool2o`0000?ooooo0_l000000ooooooo0000o`00000Dooooo`;o00007?ooool2o`00
02Wooooo0_l00009ooooo`?o00003_ooool2o`0000Wooooo0_l000000ooooooo0000o`00000;oooo
o`;o00001?ooool2o`0001Gooooo0_l0000aooooo`00:Oooool00ol0003oooooooooo`05ooooo`;o
00002Oooool2o`0001;ooooo0_l0000:ooooo`;o00007?ooool2o`0000?ooooo0_l0000Dooooo`;o
000000?oooooo`000?l000002?ooool2o`0001;ooooo0_l0000Vooooo`;o000000?oooooo`000?l0
00002Oooool2o`0001[ooooo0_l000000ooooooo0000o`00000;ooooo`;o00001?ooool3o`0003[o
oooo0_l0000;ooooo`00:Oooool00ol0003oooooooooo`04ooooo`;o00002_ooool2o`0000?ooooo
0_l0000Iooooo`;o00002Oooool2o`0001Gooooo0_l0000Eooooo`;o00002Oooool4o`0003Cooooo
0_l00004ooooo`;o0000:?ooool2o`0001Gooooo0_l00002ooooo`;o00002?ooool2o`0002cooooo
0_l0000;ooooo`00:Oooool2o`0000;ooooo0_l000000ooooooo0000o`00000?ooooo`;o00002?oo
ool2o`0001[ooooo0_l0000Eooooo`;o00008?ooool2o`0000kooooo0_l0000Fooooo`;o00003_oo
ool2o`0001[ooooo0_l0000<ooooo`;o00000_ooool2o`0000?ooooo0_l0000Eooooo`?o00002?oo
ool2o`00013ooooo0_l00004ooooo`;o00008Oooool002Wooooo00Co0000oooooooooooooooo0_l0
000Looooo`;o0000Hoooool2o`0001Kooooo0_l0000Hooooo`;o00004?ooool2o`0000Gooooo0_l0
0005ooooo`;o00000_ooool2o`0000?ooooo0_l0000Eooooo`;o00006oooool2o`0000Cooooo0_l0
000Qooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2fooooo`;o00005oooool2o`0003[ooooo
0_l0000_ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0ooooool<ooooo`;o0000;oooool000kooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo
000>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo01gooooo0_l0000<ooooo`;o0000ooooool@ooooo`003_ooool01Ol0003ooooooooo
oooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo01go
oooo0_l0000<ooooo`;o00003?ooool2o`0001cooooo0_l0003Sooooo`003_ooool01Ol@413ooooo
oooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0iooooo`;o
00007?ooool2o`000>?ooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0
j?ooool2o`0005;ooooo000Yooooo`03o`000?oooooooooo04?ooooo0_l0002Sooooo`;o0000D_oo
ool002Wooooo00?o0000ooooooooool0@oooool2o`000>Gooooo0_l0000@ooooo`00:Oooool00ol0
003oooooooooo`3oooooo`Sooooo0_l0000Qooooo`;o00004?ooool002Wooooo0_l0003oooooo`Wo
oooo0_l0000cooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o
0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo
00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo
?Oooool000Kooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo
00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000Kooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<
ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgo
oooo0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`00
0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`00
0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Oooooo`Co000000?o410@ooooooooool00oooool00ol0003ooooooooo
o`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolm
ooooo`008Oooool00ol0003oooooooooo`05ooooo`?o0000oooooolmooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Ooooo
o`03oeEEEOmVIVKo00000?ooooooAoooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .36102 Mdot
.02762 .25239 Mdot
.02952 .31247 Mdot
.03143 .2641 Mdot
.03333 .32622 Mdot
.03524 .3851 Mdot
.03714 .2697 Mdot
.03905 .42164 Mdot
.04095 .31234 Mdot
.04286 .33507 Mdot
.04476 .26578 Mdot
.04667 .44083 Mdot
.04857 .3268 Mdot
.05048 .29625 Mdot
.05238 .44213 Mdot
.05429 .31043 Mdot
.05619 .32395 Mdot
.0581 .33455 Mdot
.06 .34834 Mdot
.0619 .40994 Mdot
.06381 .34072 Mdot
.06571 .24126 Mdot
.06762 .25978 Mdot
.06952 .34868 Mdot
.07143 .45142 Mdot
.07333 .30596 Mdot
.07524 .25542 Mdot
.07714 .34225 Mdot
.07905 .39804 Mdot
.08095 .2465 Mdot
.08286 .36399 Mdot
.08476 .3109 Mdot
.08667 .39982 Mdot
.08857 .25481 Mdot
.09048 .26168 Mdot
.09238 .41748 Mdot
.09429 .26369 Mdot
.09619 .31224 Mdot
.0981 .37887 Mdot
.1 .44696 Mdot
.1019 .45414 Mdot
.10381 .24369 Mdot
.10571 .33862 Mdot
.10762 .34883 Mdot
.10952 .38016 Mdot
.11143 .25414 Mdot
.11333 .30576 Mdot
.11524 .25437 Mdot
.11714 .37346 Mdot
.11905 .39852 Mdot
.12095 .25105 Mdot
.12286 .34924 Mdot
.12476 .39766 Mdot
.12667 .3033 Mdot
.12857 .31356 Mdot
.13048 .36016 Mdot
.13238 .42517 Mdot
.13429 .32731 Mdot
.13619 .229 Mdot
.1381 .38589 Mdot
.14 .24895 Mdot
.1419 .38322 Mdot
.14381 .37381 Mdot
.14571 .32404 Mdot
.14762 .3958 Mdot
.14952 .3373 Mdot
.15143 .33864 Mdot
.15333 .29422 Mdot
.15524 .31595 Mdot
.15714 .3658 Mdot
.15905 .30655 Mdot
.16095 .31999 Mdot
.16286 .33102 Mdot
.16476 .34696 Mdot
.16667 .37394 Mdot
.16857 .27663 Mdot
.17048 .39797 Mdot
.17238 .26082 Mdot
.17429 .36455 Mdot
.17619 .36344 Mdot
.1781 .40556 Mdot
.18 .25046 Mdot
.1819 .27941 Mdot
.18381 .24543 Mdot
.18571 .39635 Mdot
.18762 .31909 Mdot
.18952 .31961 Mdot
.19143 .28942 Mdot
.19333 .34501 Mdot
.19524 .29886 Mdot
.19714 .45053 Mdot
.19905 .23364 Mdot
.20095 .33789 Mdot
.20286 .27252 Mdot
.20476 .33735 Mdot
.20667 .22228 Mdot
.20857 .30177 Mdot
.21048 .25636 Mdot
.21238 .40794 Mdot
.21429 .34284 Mdot
.21619 .34465 Mdot
.2181 .36282 Mdot
.22 .43911 Mdot
.2219 .33181 Mdot
.22381 .39495 Mdot
.22571 .24759 Mdot
.22762 .28733 Mdot
.22952 .35745 Mdot
.23143 .33775 Mdot
.23333 .36819 Mdot
.23524 .31938 Mdot
.23714 .2681 Mdot
.23905 .30605 Mdot
.24095 .41904 Mdot
.24286 .48666 Mdot
.24476 .31026 Mdot
.24667 .25074 Mdot
.24857 .35603 Mdot
.25048 .33668 Mdot
.25238 .27086 Mdot
.25429 .32568 Mdot
.25619 .41101 Mdot
.2581 .31187 Mdot
.26 .3958 Mdot
.2619 .36861 Mdot
.26381 .25856 Mdot
.26571 .41485 Mdot
.26762 .22472 Mdot
.26952 .29292 Mdot
.27143 .32806 Mdot
.27333 .25763 Mdot
.27524 .32154 Mdot
.27714 .44779 Mdot
.27905 .38881 Mdot
.28095 .35924 Mdot
.28286 .37866 Mdot
.28476 .28229 Mdot
.28667 .40611 Mdot
.28857 .33313 Mdot
.29048 .41405 Mdot
.29238 .44445 Mdot
.29429 .32429 Mdot
.29619 .31161 Mdot
.2981 .33234 Mdot
.3 .32353 Mdot
.3019 .41566 Mdot
.30381 .38172 Mdot
.30571 .49625 Mdot
.30762 .35705 Mdot
.30952 .27559 Mdot
.31143 .42632 Mdot
.31333 .3677 Mdot
.31524 .27906 Mdot
.31714 .35214 Mdot
.31905 .31466 Mdot
.32095 .39304 Mdot
.32286 .30526 Mdot
.32476 .36622 Mdot
.32667 .35543 Mdot
.32857 .26296 Mdot
.33048 .29996 Mdot
.33238 .34665 Mdot
.33429 .36508 Mdot
.33619 .45773 Mdot
.3381 .41727 Mdot
.34 .33591 Mdot
.3419 .35008 Mdot
.34381 .37652 Mdot
.34571 .40372 Mdot
.34762 .30852 Mdot
.34952 .30694 Mdot
.35143 .40749 Mdot
.35333 .33327 Mdot
.35524 .28675 Mdot
.35714 .31794 Mdot
.35905 .35856 Mdot
.36095 .40182 Mdot
.36286 .22077 Mdot
.36476 .39247 Mdot
.36667 .30297 Mdot
.36857 .39191 Mdot
.37048 .33088 Mdot
.37238 .45202 Mdot
.37429 .34335 Mdot
.37619 .45383 Mdot
.3781 .29809 Mdot
.38 .30344 Mdot
.3819 .22611 Mdot
.38381 .30479 Mdot
.38571 .45705 Mdot
.38762 .35097 Mdot
.38952 .42643 Mdot
.39143 .41596 Mdot
.39333 .29877 Mdot
.39524 .39401 Mdot
.39714 .40895 Mdot
.39905 .45119 Mdot
.40095 .44339 Mdot
.40286 .28436 Mdot
.40476 .2707 Mdot
.40667 .25483 Mdot
.40857 .27275 Mdot
.41048 .27631 Mdot
.41238 .32266 Mdot
.41429 .33117 Mdot
.41619 .29397 Mdot
.4181 .33443 Mdot
.42 .26255 Mdot
.4219 .39014 Mdot
.42381 .27088 Mdot
.42571 .27217 Mdot
.42762 .26071 Mdot
.42952 .28231 Mdot
.43143 .25627 Mdot
.43333 .40431 Mdot
.43524 .33558 Mdot
.43714 .34524 Mdot
.43905 .25039 Mdot
.44095 .4573 Mdot
.44286 .29469 Mdot
.44476 .38881 Mdot
.44667 .44229 Mdot
.44857 .24927 Mdot
.45048 .23026 Mdot
.45238 .39895 Mdot
.45429 .41127 Mdot
.45619 .32168 Mdot
.4581 .34923 Mdot
.46 .26624 Mdot
.4619 .33524 Mdot
.46381 .44288 Mdot
.46571 .40551 Mdot
.46762 .28195 Mdot
.46952 .31601 Mdot
.47143 .2998 Mdot
.47333 .3739 Mdot
.47524 .25448 Mdot
.47714 .4183 Mdot
.47905 .29981 Mdot
.48095 .319 Mdot
.48286 .30837 Mdot
.48476 .32954 Mdot
.48667 .38246 Mdot
.48857 .37277 Mdot
.49048 .41502 Mdot
.49238 .30744 Mdot
.49429 .31485 Mdot
.49619 .33473 Mdot
.4981 .31313 Mdot
.5 .35756 Mdot
.5019 .31107 Mdot
.50381 .37251 Mdot
.50571 .45197 Mdot
.50762 .30765 Mdot
.50952 .29784 Mdot
.51143 .29549 Mdot
.51333 .31112 Mdot
.51524 .28051 Mdot
.51714 .33118 Mdot
.51905 .27365 Mdot
.52095 .41927 Mdot
.52286 .23675 Mdot
.52476 .37542 Mdot
.52667 .25433 Mdot
.52857 .41435 Mdot
.53048 .32748 Mdot
.53238 .36898 Mdot
.53429 .37206 Mdot
.53619 .29482 Mdot
.5381 .37309 Mdot
.54 .41406 Mdot
.5419 .33562 Mdot
.54381 .41744 Mdot
.54571 .32441 Mdot
.54762 .33647 Mdot
.54952 .37088 Mdot
.55143 .30966 Mdot
.55333 .34585 Mdot
.55524 .35918 Mdot
.55714 .26177 Mdot
.55905 .26498 Mdot
.56095 .3931 Mdot
.56286 .38362 Mdot
.56476 .32677 Mdot
.56667 .34488 Mdot
.56857 .26311 Mdot
.57048 .43467 Mdot
.57238 .3586 Mdot
.57429 .29256 Mdot
.57619 .34923 Mdot
.5781 .42225 Mdot
.58 .26428 Mdot
.5819 .39883 Mdot
.58381 .22626 Mdot
.58571 .23005 Mdot
.58762 .43604 Mdot
.58952 .22991 Mdot
.59143 .2885 Mdot
.59333 .23389 Mdot
.59524 .40489 Mdot
.59714 .42189 Mdot
.59905 .43991 Mdot
.60095 .49544 Mdot
.60286 .36774 Mdot
.60476 .35681 Mdot
.60667 .31537 Mdot
.60857 .31408 Mdot
.61048 .45289 Mdot
.61238 .29482 Mdot
.61429 .25906 Mdot
.61619 .32082 Mdot
.6181 .26754 Mdot
.62 .27838 Mdot
.6219 .31356 Mdot
.62381 .31633 Mdot
.62571 .43207 Mdot
.62762 .31751 Mdot
.62952 .38412 Mdot
.63143 .24499 Mdot
.63333 .40517 Mdot
.63524 .32907 Mdot
.63714 .45245 Mdot
.63905 .43326 Mdot
.64095 .2972 Mdot
.64286 .26705 Mdot
.64476 .39044 Mdot
.64667 .24674 Mdot
.64857 .35867 Mdot
.65048 .34796 Mdot
.65238 .26722 Mdot
.65429 .27611 Mdot
.65619 .29955 Mdot
.6581 .43541 Mdot
.66 .30072 Mdot
.6619 .33726 Mdot
.66381 .25921 Mdot
.66571 .32662 Mdot
.66762 .32285 Mdot
.66952 .26188 Mdot
.67143 .38202 Mdot
.67333 .33692 Mdot
.67524 .34663 Mdot
.67714 .33687 Mdot
.67905 .37696 Mdot
.68095 .31994 Mdot
.68286 .26345 Mdot
.68476 .32455 Mdot
.68667 .38329 Mdot
.68857 .2542 Mdot
.69048 .40874 Mdot
.69238 .23865 Mdot
.69429 .32884 Mdot
.69619 .25307 Mdot
.6981 .32722 Mdot
.7 .43988 Mdot
.7019 .235 Mdot
.70381 .41676 Mdot
.70571 .36331 Mdot
.70762 .25992 Mdot
.70952 .41018 Mdot
.71143 .37229 Mdot
.71333 .43942 Mdot
.71524 .28866 Mdot
.71714 .4165 Mdot
.71905 .44677 Mdot
.72095 .45314 Mdot
.72286 .45564 Mdot
.72476 .32117 Mdot
.72667 .37458 Mdot
.72857 .4446 Mdot
.73048 .42151 Mdot
.73238 .31876 Mdot
.73429 .38892 Mdot
.73619 .31923 Mdot
.7381 .39161 Mdot
.74 .35018 Mdot
.7419 .26873 Mdot
.74381 .32076 Mdot
.74571 .2462 Mdot
.74762 .32824 Mdot
.74952 .25355 Mdot
.75143 .24435 Mdot
.75333 .25217 Mdot
.75524 .45134 Mdot
.75714 .49263 Mdot
.75905 .25343 Mdot
.76095 .39405 Mdot
.76286 .30803 Mdot
.76476 .44365 Mdot
.76667 .35009 Mdot
.76857 .27965 Mdot
.77048 .45369 Mdot
.77238 .36849 Mdot
.77429 .26617 Mdot
.77619 .34547 Mdot
.7781 .27898 Mdot
.78 .25822 Mdot
.7819 .26377 Mdot
.78381 .40407 Mdot
.78571 .39688 Mdot
.78762 .4529 Mdot
.78952 .27963 Mdot
.79143 .36181 Mdot
.79333 .26688 Mdot
.79524 .35883 Mdot
.79714 .35826 Mdot
.79905 .30943 Mdot
.80095 .43183 Mdot
.80286 .43959 Mdot
.80476 .25469 Mdot
.80667 .32987 Mdot
.80857 .25482 Mdot
.81048 .33267 Mdot
.81238 .44189 Mdot
.81429 .28021 Mdot
.81619 .41792 Mdot
.8181 .30166 Mdot
.82 .28302 Mdot
.8219 .32949 Mdot
.82381 .29959 Mdot
.82571 .26373 Mdot
.82762 .26159 Mdot
.82952 .26457 Mdot
.83143 .41882 Mdot
.83333 .41273 Mdot
.83524 .27996 Mdot
.83714 .27131 Mdot
.83905 .2871 Mdot
.84095 .3911 Mdot
.84286 .3305 Mdot
.84476 .29506 Mdot
.84667 .44353 Mdot
.84857 .23085 Mdot
.85048 .30697 Mdot
.85238 .47182 Mdot
.85429 .33961 Mdot
.85619 .27301 Mdot
.8581 .32787 Mdot
.86 .44587 Mdot
.8619 .26094 Mdot
.86381 .23863 Mdot
.86571 .38278 Mdot
.86762 .32596 Mdot
.86952 .26781 Mdot
.87143 .3571 Mdot
.87333 .41425 Mdot
.87524 .35654 Mdot
.87714 .25193 Mdot
.87905 .28404 Mdot
.88095 .2781 Mdot
.88286 .24302 Mdot
.88476 .33414 Mdot
.88667 .31507 Mdot
.88857 .34772 Mdot
.89048 .42202 Mdot
.89238 .32506 Mdot
.89429 .37309 Mdot
.89619 .27056 Mdot
.8981 .38075 Mdot
.9 .41658 Mdot
.9019 .39014 Mdot
.90381 .2966 Mdot
.90571 .22528 Mdot
.90762 .34422 Mdot
.90952 .4371 Mdot
.91143 .45271 Mdot
.91333 .29352 Mdot
.91524 .23406 Mdot
.91714 .33319 Mdot
.91905 .33675 Mdot
.92095 .40992 Mdot
.92286 .34413 Mdot
.92476 .35228 Mdot
.92667 .25226 Mdot
.92857 .25596 Mdot
.93048 .38639 Mdot
.93238 .3563 Mdot
.93429 .27951 Mdot
.93619 .32774 Mdot
.9381 .36548 Mdot
.94 .32256 Mdot
.9419 .27402 Mdot
.94381 .29814 Mdot
.94571 .35569 Mdot
.94762 .29067 Mdot
.94952 .29645 Mdot
.95143 .33976 Mdot
.95333 .33091 Mdot
.95524 .37827 Mdot
.95714 .3244 Mdot
.95905 .34128 Mdot
.96095 .30466 Mdot
.96286 .48446 Mdot
.96476 .29877 Mdot
.96667 .25693 Mdot
.96857 .23142 Mdot
.97048 .41797 Mdot
.97238 .32362 Mdot
.97429 .40086 Mdot
.97619 .44879 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo06Wooooo0_l0003Aooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool0=oooool2o`0001;ooooo0_l0000Looooo`;o0000dOooool000Kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0gooooo`;o00004_ooool2o`0002;ooooo0_l0
000oooooo`;o0000I_ooool2o`0002;ooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Pooooo`;o0000COooool2o`0001Cooooo0_l0000Yooooo`Co0000DOooool2o`00017ooooo0_l0
000Rooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00omgMgOo<S8booooo`04ooooo`?o00008?ooool2o`0001?ooooo0_l0001>ooooo`;o0000:_oo
ool4o`00053ooooo0_l0000Dooooo`;o00003oooool2o`0000kooooo0006ooooo`05o`000?oooooo
ooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`0eooooo`;o0000I_ooool2o`0001Cooooo0_l0000Qooooo`;o0000
@oooool2o`0000oooooo0_l0000>ooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo09gooooo
0_l0000dooooo`;o000000?oooooo`000?l00000<_ooool2o`00033ooooo0006ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0:ooooo`;o0000aoooool2o`0003Gooooo0_l00004ooooo`;o
0000:_ooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool02_ooool2o`0000?ooooo0_l00005oooo
o`;o00006?ooool2o`0008kooooo0_l0000Rooooo`Co0000:?ooool2o`0002[ooooo000Yooooo`;o
00004?ooool2o`0000Gooooo0_l0000:ooooo`;o00003?ooool2o`0000_ooooo0_l00016ooooo`;o
0000>Oooool2o`0000?ooooo0_l0000Mooooo`Co0000E?ooool002Wooooo0_l0000Mooooo`;o0000
1?ooool2o`0000[ooooo0_l0000=ooooo`;o00001Oooool2o`0003cooooo0_l000000ooooooo0000
o`00000nooooo`;o00008?ooool2o`0002Kooooo0_l0000>ooooo`;o00006oooool002Wooooo0_l0
000>ooooo`;o00000_ooool2o`0000Gooooo1_l0000@ooooo`;o00005?ooool2o`00037ooooo0_l0
0009ooooo`;o00002Oooool2o`0000oooooo0_l0000booooo`Co00004?ooool5o`0000cooooo1?l0
000Dooooo`;o00003_ooool2o`0001_ooooo000Yooooo`03o`000?oooooooooo00gooooo0_l00002
ooooo`;o00001Oooool4o`0001cooooo0_l0000?ooooo`;o00000_ooool2o`0002Sooooo0_l00006
ooooo`;o00003?ooool2o`0000oooooo0_l0000Jooooo`;o00005_ooool4o`00013ooooo0_l00000
0ooooooo0000o`000004ooooo`;o00001_ooool4o`0002Cooooo0_l0000:ooooo`;o00003oooool0
02Wooooo00?o0000ooooooooool02_ooool2o`0000Kooooo0_l0000Hooooo`;o00002_ooool2o`00
00oooooo0_l00002ooooo`;o0000;oooool3o`0002Oooooo0_l0000@ooooo`;o00003_ooool4o`00
00[ooooo0_l0000Eooooo`;o00003_ooool2o`0000Wooooo0_l0000Cooooo`;o00002_ooool2o`00
00oooooo000Yooooo`Co00002Oooool2o`0000Kooooo0ol0000Gooooo`;o0000<?ooool2o`0001co
oooo1?l0000Xooooo`;o000000?oooooo`000?l000000_ooool2o`0001Wooooo1?l00002ooooo`;o
00001_ooool2o`0001Kooooo0_l0000<ooooo`?o00002Oooool2o`00033ooooo000Yooooo`04o`00
0?oooooo0000o`0000;ooooo0_l0000>ooooo`;o0000;?ooool2o`0001_ooooo0_l0000Looooo`;o
00002oooool2o`0001gooooo0_l000000ooooooo0000o`000002ooooo`;o00002_ooool2o`0000Ko
oooo0_l000000ooooooo0000o`000008ooooo`;o00007?ooool4o`0000;ooooo0_l00008ooooo`?o
00002oooool2o`0002kooooo000Yooooo`04o`000?ooooooooooooooo`Co0000:oooool4o`000008
oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000o`000?o^k^h0
0_ooool2o`0002Gooooo1Ol00003ooooo`05onk^k_lb<S;o0000o`000?o^k^h00oooool3o`000003
oc8b<_o^k^kooooo00Kooooo0_l0000Oooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^o`000?l0003o<S8bonk^kP04ooooo`;o000000?o
ooooo`000?l000006oooool2o`0000Cooooo0_l000000ol@413oooooooooo`02o`000004oc8b<_l0
003o<S8bonk^kP;o000000Koooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`;o00002?ooool2o`00
00Oooooo0_l0000>ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool01?l0003ooooooooo
ooooool2o`0002oooooo00Co0000oooooooooooooooo0_l000001?nHV9SooooooiRHV?mgMgL3oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool2o`0002Gooooo00GoV9RHob4Q8Oo^k^koooooodA4
A003ooooo`03ogMgMonHV9So000000;o00000oooool2o`000003oooooonHV9SoMgMg01[ooooo0_l0
000<ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Tooooo`;o00001Oooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo0_l0
0004ooooo`;o00002oooool2o`0000cooooo0_l00003ooooo`09ogMgMolb<S;ooooooooooomgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool00ol0
003oooooooooo`0[ooooo`;o00001Oooool01?l0003oooooooooooooool2o`0000?ooooo00Go410@
oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01;ooooo0_l0000Dooooo`03oiRHV?lQ
8B7ok^k^00Cooooo00?o410@ooooooooool00ol00002ooooo`;o00000_ooool00ol@413ooooooooo
o`0Hooooo`;o00004?ooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`03oa0@4?oooooooooo00Kooooo0_l0000Nooooo`Go00000oooool01Ol@413o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@400<ooooo`;o00006Oooool2
o`0000Cooooo00Co0000oooooooooooo410@0oooool01Ol@413ooooooooooooooooo410@00?ooooo
00?o410@ooooooooool00Oooool002Wooooo0_l0000/ooooo`;o00000_ooool2o`000003ooooool0
003ooooo00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00005?ooool4o`0001?ooooo00?oV9RHob4Q8Oo^k^h00oooool01?l0003oooooooooooooool2o`00
00;ooooo00Go0000ooooooooooooooooo`00000Hooooo`;o00004Oooool00onYZJWo410@ooooo`02
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooo`000002o`0000Sooooo0_l0
000Nooooo`05odA4A?oMgMgoooooo`000?ooool00_l000001?oooooo0000o`000?ooool2o`0000?o
oooo00?o0000ooooooooool00_l00005ooooo`;o00003Oooool2o`0000oooooo0_l00005ooooo`05
ogMgMolb<S;oooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool00Oooool002Wooooo00?o0000ooooooooool0;oooool2o`000003ooooool0003ooooo
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000003?oo
ool2o`0000Sooooo0_l0000Dooooo`03ogMgMomVIVKooooo00;ooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooo000000;o00002Oooool2o`0000gooooo0_l0000@ooooo`03oa0@
4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000;o
0000:?ooool01OoMgMgoEEEEooooool0003ooooo00;o000000Coooooo`000?l0003ooooo0_l00003
ooooo`03o`000?oooooooooo00Co00000oooool2o`0000gooooo0_l0000?ooooo`;o00000_ooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000oooool002Wooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@
00cooooo0_l0000Eooooo`;o00002?ooool01Ol0003ooooooooooooooooo410@00;o000000?ooooo
oa0@4?ooool00_ooool01Ol@413oooooo`000?l0003o410@00Wooooo0_l0000Pooooo`03okZj^_lQ
8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
4100:Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@00;o00004Oooool2o`0001Cooooo00?o0000ooooooooool01?ooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`00:Ooo
ool00ol0003oooooooooo`0booooo`;o00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo
0_l000001?nHV9SooooooiRHV?mgMgLSooooo`;o00001?ooool01Ol0003o^[ZjoooooonHV9So410@
00?ooooo00GoMgMgo`000?l0003oV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:?oo
ool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgo`000?l0003oV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL07?ooool2o`0000_ooooo00?ok^k^odA4A?l000001?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`;o00002ooo
ool2o`0001Cooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool00ol0003oooooooooo`0`ooooo`04oeEE
EOmVIVKo0000o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`;o000000Co<S8bo`00
0?lb<S;ok^k^1oooool2o`00023ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo00?oZJVYoa0@4?l0
00000_l00003ooooo`05onk^k_l0003o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01cooooo0_l0000<ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool2o`00027ooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Yooooo`;o
00001_ooool2o`0001oooooo0_l0000Sooooo`;o0000;Oooool2o`0000Oooooo0_l0000Dooooo`;o
00001_ooool2o`0000[ooooo0_l0000;ooooo`;o0000B?ooool2o`0001Cooooo0_l00009ooooo`;o
00005Oooool002Wooooo00?o0000ooooooooool01Oooool2o`0001oooooo0_l0000;ooooo`;o0000
>Oooool2o`0000?ooooo0_l00005ooooo`;o00001oooool2o`0001?ooooo0ol00006ooooo`;o0000
5oooool2o`0000Oooooo0_l0000oooooo`;o00004Oooool2o`000003ooooool0003o000000Sooooo
1?l00003ooooo`;o00003oooool002Wooooo00?o0000ooooooooool0<oooool2o`0000?ooooo0_l0
000Uooooo`;o00003Oooool2o`0000?ooooo0_l0000Gooooo`;o000000?oooooo`000?l000001ooo
ool2o`0002Wooooo0_l00003ooooo`?o0000<Oooool4o`0001Oooooo0_l0000;ooooo`Co00000ooo
ool2o`0000oooooo000Yooooo`03o`000?oooooooooo01gooooo0_l0000Iooooo`;o00008_ooool2
o`000003ooooool0003o000000[ooooo0_l00002ooooo`?o00006_ooool2o`000003ooooool0003o
000003Oooooo0ol0000aooooo`Co0000:_ooool2o`00013ooooo000Yooooo`03o`000?oooooooooo
00cooooo0_l0000;ooooo`;o00000_ooool2o`0000Wooooo0_l0000Gooooo`;o00006Oooool2o`00
00Kooooo0ol00004ooooo`;o00000_ooool3o`0001kooooo0_l000000ooooooo0000o`000003oooo
o`;o0000D?ooool2o`0001[ooooo0_l0000Rooooo`;o00004?ooool0027oooooool00014o`0000Co
oooo000Yooooo`?o00000_ooool2o`0000;ooooo0_l000000ooooooo0000ooooo`05ooooo`;o0000
0_ooool3o`0000Oooooo0_l00002ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`06ooooo`;o00000_ooool3o`0000Wooooo0ol00005ooooo`;o0000
0_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooooooo`Co00000_ooool3o`0000Wo
oooo0_l000000ooooooo0000ooooo`0:ooooo`03o`000?oooooooooo00;o00000oooool2o`0000;o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool01?l0003oooooooooooooool2o`0000Kooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`00:Oooool3o`0000;ooooo0_l0000@ooooo`;o
00002?ooool2o`0000Oooooo0_l0000Aooooo`03o`000?oooooooooo01kooooo0_l0000:ooooo`;o
00003oooool00ol0003oooooooooo`0Aooooo`;o00001_ooool3o`0001kooooo00?o0000oooooooo
ool00_l00003ooooo`?o0000<_ooool00ol0003oooooooooo`0Mooooo`;o00006oooool00ol0003o
ooooooooo`0:ooooo`00:Oooool00ol0003oooooooooo`0Wooooo`?o00001oooool3o`0000cooooo
0_l0000Uooooo`;o00008oooool2o`000003ooooool0003o000002Oooooo0_l000000ooooooo0000
o`000003o`00013ooooo0_l0000<ooooo`Go000000?oooooo`000?l00000;?ooool2o`0002Sooooo
000Yooooo`03o`000?oooooooooo00Oooooo0_l0000Jooooo`;o00000oooool2o`0000Oooooo0ol0
000<ooooo`;o00002oooool2o`0000Cooooo1?l0000Rooooo`;o00003?ooool2o`0000Kooooo0_l0
000Zooooo`;o00003_ooool2o`0000?ooooo0_l0000<ooooo`Go000000?oooooo`000?l00000?Ooo
ool2o`0000Sooooo0_l0000=ooooo`00:Oooool4o`0000?ooooo0_l000000ooooooo0000o`00000G
ooooo`;o000000?oooooo`000?l000008Oooool2o`0000Gooooo0_l00004ooooo`Co00008_ooool2
o`0000cooooo0_l0000Fooooo`;o00000oooool2o`0000Cooooo0_l0000Oooooo`;o00001?ooool2
o`0000;ooooo0_l0000eooooo`;o00001_ooool2o`0000gooooo0_l00003ooooo`;o00000oooool2
o`0000gooooo000Yooooo`04o`000?oooooo0000o`0000?ooooo0_l0000Jooooo`;o00009?ooool2
o`0000Cooooo0_l00012ooooo`;o00003Oooool2o`0000?ooooo0_l00004ooooo`;o00005Oooool2
o`0000Sooooo0_l00004ooooo`;o000000Coooooo`000?l0003o00003_ooool2o`00017ooooo0_l0
0003ooooo`;o00001Oooool2o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`;o00003?oo
ool2o`0000Cooooo0_l0000Booooo`00:Oooool00ol0003oooooooooo`0Yooooo`;o00004Oooool2
o`0000kooooo0_l00003ooooo`;o000000?oooooo`000?l000004?ooool2o`0000Cooooo0_l0000<
ooooo`;o00005?ooool2o`0000Wooooo0_l0000Tooooo`;o00004Oooool2o`0000oooooo0_l0000A
ooooo`?o00000_ooool2o`0000Gooooo0_l00003ooooo`;o00004Oooool2o`0000Cooooo0_l00003
ooooo`;o00004oooool002Wooooo00?o0000ooooooooool00_ooool2o`0000?ooooo0_l0000Poooo
o`;o00004Oooool2o`0000Oooooo0_l0000:ooooo`;o000000?oooooo`000?l000003?ooool2o`00
00;ooooo0_l00004ooooo`;o00003?ooool3o`0000Cooooo0_l00006ooooo`;o00002Oooool2o`00
00Gooooo0_l00006ooooo`Co0000D_ooool2o`0001Kooooo0_l00009ooooo`;o00002Oooool2o`00
01?ooooo000Yooooo`03o`000?oooooooooo00;ooooo0_l00003ooooo`;o00003_ooool2o`0000co
oooo0_l0000>ooooo`?o00001oooool2o`0000Cooooo0_l0000Kooooo`;o00005oooool2o`0000Co
oooo0_l00006ooooo`;o00002Oooool2o`0000gooooo1?l0000Rooooo`;o00000_ooool3o`0003Oo
oooo0_l00008ooooo`;o00002Oooool2o`0000Wooooo0_l0000Cooooo`00:Oooool2o`0000[ooooo
0_l00002ooooo`;o00002?ooool2o`0000cooooo0_l0000>ooooo`?o00000_ooool2o`0000?ooooo
0_l00028ooooo`;o00000_ooool3o`0003Oooooo0_l0000Nooooo`Co00004Oooool002Wooooo00?o
0000ooooooooool02Oooool2o`0000;ooooo0_l0000Tooooo`;o00001Oooool2o`00037ooooo0_l0
000Booooo`;o00009?ooool2o`0000;ooooo0_l00011ooooo`;o0000:?ooool2o`0000?ooooo0_l0
000:ooooo`;o00004Oooool002Wooooo00?o0000ooooooooool02?ooool2o`000003ooooool0003o
000000[ooooo0_l00003ooooo`;o00003?ooool2o`0000Oooooo0_l00005ooooo`;o00008oooool2
o`0000cooooo0_l0000Booooo`;o00001Oooool2o`0001gooooo0_l00002ooooo`;o000000?ooooo
o`000?l000005_ooool2o`0000Kooooo0_l0000Nooooo`;o00008_ooool2o`0000Cooooo0_l00003
ooooo`;o00007Oooool002Wooooo00?o0000ooooooooool02?ooool2o`000003ooooool0003o0000
00[ooooo0_l00003ooooo`;o00003?ooool2o`0002oooooo0_l00002ooooo`;o00000_ooool2o`00
00cooooo0_l0000Eooooo`;o00009?ooool2o`0001Kooooo0_l00006ooooo`;o00004oooool2o`00
00Kooooo0_l0000Uooooo`;o00002_ooool2o`0001cooooo000Yooooo`03o`000?oooooooooo05_o
oooo0_l000000ooooooo0000o`000003ooooo`;o00003?ooool2o`00073ooooo0_l00006ooooo`;o
0000<Oooool2o`0001cooooo000Yooooo`;o0000?oooool2o`0000Gooooo0_l0000Aooooo`;o0000
1?ooool2o`0000Sooooo0_l0000[ooooo`;o00008?ooool2o`0003cooooo0_l0000Fooooo`?o0000
4?ooool2o`0000?ooooo0_l0000Eooooo`00:Oooool2o`00023ooooo0_l0000Mooooo`;o00001Ooo
ool2o`0000Sooooo0_l00007ooooo`;o00003_ooool2o`0002_ooooo0_l0000@ooooo`;o00001?oo
ool2o`0000Sooooo0_l0000<ooooo`;o0000;Oooool3o`0001Kooooo0ol0000@ooooo`;o00000ooo
ool2o`0001Gooooo000Yooooo`;o00004?ooool2o`0000kooooo0_l0000<ooooo`;o00003?ooool2
o`0001;ooooo0_l0001Fooooo`;o00001?ooool2o`0001Kooooo0_l0000Aooooo`;o00006Oooool3
o`0004Kooooo000Yooooo`03o`000?oooooooooo00oooooo0_l0000Fooooo`;o00001?ooool2o`00
00cooooo0_l0000Looooo`;o00000_ooool2o`000003ooooool0003o000005Cooooo0_l0000Poooo
o`;o00006Oooool2o`0002gooooo0_l0000Hooooo`00:Oooool00ol0003oooooooooo`0Wooooo`;o
00005oooool2o`0000Oooooo0_l0000>ooooo`;o00000_ooool2o`000003ooooool0003o000003ko
oooo0_l00003ooooo`;o00003oooool2o`0003Gooooo0_l0000cooooo`;o00006?ooool002Wooooo
0_l0000Kooooo`;o00001oooool2o`0000Gooooo0_l0000Dooooo`;o00001oooool2o`0004;ooooo
0_l00003ooooo`;o00000oooool2o`0000Oooooo1?l000000ooooooo0000o`00000booooo`;o0000
4_ooool2o`0002Gooooo0_l0000Vooooo`00:Oooool00ol0003oooooooooo`0Jooooo`;o00001ooo
ool2o`0000Gooooo0_l0000gooooo`;o0000:?ooool2o`0000?ooooo0_l00003ooooo`;o00001?oo
ool2o`000003ooooool0003o000000;o0000:oooool2o`0000Sooooo0_l00003ooooo`;o0000=?oo
ool2o`0002Kooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0
0004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Dooooo`;o0000
0_ooool2o`0003Kooooo0_l0000Aooooo`;o0000>?ooool2o`00033ooooo0_l0000=ooooo`;o0000
B?ooool2o`0001;ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo
00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool05?ooool2o`0000;ooooo0_l00008ooooo`;o0000;?ooool2o`0000Cooooo0_l0000iooooo`;o
0000>_ooool2o`0000;ooooo0_l0000hooooo`;o00002?ooool2o`00017ooooo0_l0000Booooo`00
1_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;o00007oooool3o`0003;ooooo0_l0000iooooo`;o
00005oooool2o`0001?ooooo0_l0000<ooooo`;o00000_ooool2o`0003Sooooo0_l00008ooooo`;o
00002Oooool2o`0001[ooooo0006ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So
8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo1Ol0000Oooooo`;o0000:oooool2o`0003Co
oooo0_l0000Tooooo`;o00004oooool2o`00023ooooo0_l0000mooooo`;o00006_ooool000Kooooo
00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c005ooooo`03o`000?oooooooooo04kooooo0_l0000Jooooo`?o00003oooool2o`00
00Kooooo0_l0000nooooo`;o00006oooool3o`0001oooooo0_l0000Booooo`;o00008oooool000Ko
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Tooooo`;o00005oooool2o`0000Wooooo0_l0000Boooo
o`;o00003?ooool3o`0000Oooooo0_l00006ooooo`;o0000:oooool2o`0001Wooooo0_l0000Loooo
o`;o00001Oooool2o`0001Sooooo0_l0000Booooo`;o00008oooool000Kooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00kooooo0_l0000;ooooo`Co00001Oooool2o`0000Gooooo0_l00003
ooooo`;o00002oooool2o`0000Wooooo0_l0000Booooo`;o00005_ooool2o`00013ooooo0_l0000Q
ooooo`;o00001Oooool2o`0003Oooooo0_l00006ooooo`;o0000BOooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o
0000ooooooooool03_ooool4o`0000Wooooo1?l0000<ooooo`;o00000oooool2o`0003Oooooo0_l0
000Kooooo`;o0000:?ooool2o`0003oooooo0_l0000kooooo`;o00003?ooool002Wooooo0_l0000A
ooooo`;o0000D_ooool2o`0000?ooooo0_l0000Eooooo`;o0000<_ooool2o`0000[ooooo0_l0000_
ooooo`;o0000>oooool2o`0000cooooo000Yooooo`03o`000?oooooooooo02kooooo0_l00009oooo
o`;o00005_ooool2o`00017ooooo1?l0000Hooooo`;o00002?ooool2o`0002Sooooo0_l0000:oooo
o`;o0000;oooool2o`0004Wooooo000Yooooo`03o`000?oooooooooo00Wooooo0_l0000Sooooo`;o
00002Oooool2o`0000cooooo0_l00008ooooo`;o00004oooool2o`0000cooooo0_l0000Aooooo`;o
000000?oooooo`000?l00000Aoooool2o`0000Cooooo0_l00012ooooo`;o00007Oooool002Wooooo
00?o0000ooooooooool02Oooool2o`0003cooooo0_l00009ooooo`;o00008?ooool2o`00017ooooo
0_l0000Fooooo`;o000000?oooooo`000?l00000;oooool2o`0000Cooooo0_l0000Vooooo`;o0000
2_ooool2o`0000kooooo0_l0000Mooooo`00:Oooool00ol0003oooooooooo`0Booooo`;o0000=_oo
ool2o`0000Kooooo0_l00002ooooo`;o00002Oooool2o`0000oooooo0_l0000Nooooo`;o00002ooo
ool2o`000004ooooool0003o0000o`0003;ooooo0_l00002ooooo`;o00009?ooool2o`0000[ooooo
0_l00007ooooo`;o00009?ooool002Wooooo0_l0000Cooooo`;o0000;_ooool2o`0000Kooooo0_l0
000:ooooo`;o00002Oooool2o`0000oooooo0_l0000Jooooo`;o00000_ooool2o`0000Sooooo0_l0
0005ooooo`;o0000<_ooool2o`0000;ooooo0_l0000Nooooo`;o00000oooool2o`0001Cooooo0_l0
000Eooooo`;o00003Oooool002Wooooo00Co0000oooooooooooooooo0_l0000oooooo`;o0000B_oo
ool2o`0000cooooo0_l0000@ooooo`;o00001Oooool2o`0002Sooooo0_l0000Jooooo`;o00000ooo
ool2o`00017ooooo0_l0000Hooooo`;o00003Oooool002Wooooo00Co0000oooooooooooooooo0_l0
000Looooo`;o0000>?ooool2o`0001Oooooo0_l0000jooooo`;o00001Oooool2o`0002Sooooo0_l0
000booooo`;o00009oooool002Wooooo00?o0000ooooooooool07oooool2o`0003Sooooo0_l0000G
ooooo`;o0000b?ooool002Wooooo00?o0000ooooooooool0__ooool2o`0003Kooooo0_l00014oooo
o`00:Oooool2o`000:gooooo0_l00004ooooo`;o00002_ooool2o`0000;ooooo0_l00004ooooo`;o
0000;?ooool2o`0004Cooooo000Yooooo`03o`000?oooooooooo03_ooooo0_l0001_ooooo`;o0000
1?ooool2o`0000kooooo0_l00004ooooo`;o00004?ooool2o`0003gooooo0_l0000Qooooo`00:Ooo
ool00ol0003oooooooooo`04ooooo`?o0000=?ooool2o`0004Oooooo0_l0000_ooooo`;o00007ooo
ool2o`0000;ooooo0_l0000Kooooo`;o000000?oooooo`000?l000007Oooool2o`00027ooooo000Y
ooooo`03o`000?oooooooooo00Cooooo0ol0001<ooooo`;o00008Oooool2o`0000cooooo0_l00004
ooooo`;o0000:Oooool2o`0001oooooo0_l00007ooooo`;o00002_ooool2o`0000[ooooo0_l00000
0ooooooo0000o`000009ooooo`;o0000=Oooool002Wooooo00?o0000ooooooooool05Oooool2o`00
03Oooooo0_l00003ooooo`;o00008Oooool2o`0001;ooooo0_l0001@ooooo`;o000000?oooooo`00
0?l000002_ooool2o`0001Sooooo0_l00002ooooo`;o0000<Oooool002Wooooo0_l0000=ooooo`;o
00001oooool2o`0001gooooo0_l0000Hooooo`;o00009Oooool2o`0006Gooooo0_l00009ooooo`;o
00008?ooool2o`0002Cooooo0_l0000;ooooo`00:Oooool00ol0003oooooooooo`0<ooooo`;o0000
1oooool2o`0001gooooo0_l0000fooooo`Co00001Oooool2o`00023ooooo0_l0000Pooooo`;o0000
1_ooool2o`0001Wooooo0_l00009ooooo`;o00000oooool2o`0000Cooooo0_l0000Vooooo`;o0000
4oooool2o`0000_ooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01Gooooo0_l0001:ooooo`;o
00002Oooool4o`000003ooooool0003o000000oooooo0_l0000Cooooo`;o00008?ooool2o`0000Ko
oooo0_l0000Iooooo`?o00003Oooool2o`0000Cooooo0_l0000Vooooo`;o00008?ooool000kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo067ooooo0_l0000>ooooo`;o00003oooool2o`0005Wooooo0_l0001Mooooo`00
3_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oo
oooo?Oooool000kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000co
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000ko
oooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0ooooool8ooooo`;o0000<oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0ooooool8ooooo`;o0000<oooool000ko
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooob_ooooo
0_l0000@ooooo`00:Oooool00ol0003oooooooooo`13ooooo`;o0000iOooool2o`00013ooooo000Y
ooooo`03o`000?oooooooooo04?ooooo0_l0003gooooo`00:Oooool2o`000>Wooooo0_l0001Boooo
o`00:Oooool00ol0003oooooooooo`1Gooooo`;o0000GOooool2o`00033ooooo0_l0001Booooo`00
:Oooool00ol0003oooooooooo`1Gooooo`;o0000GOooool2o`0008Cooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`00
0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000
o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@
41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgo
oooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooo
oooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@
00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooo
oooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool0
00Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`007oooool4o`000003oa0@
4?oooooooooo00?ooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool3
o`000?oooooo?Oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`007oooool00omEEEGoIVIVo`00003oooooodOooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .39767 Mdot
.02762 .34357 Mdot
.02952 .28772 Mdot
.03143 .31846 Mdot
.03333 .36216 Mdot
.03524 .33318 Mdot
.03714 .3009 Mdot
.03905 .34292 Mdot
.04095 .22842 Mdot
.04286 .34741 Mdot
.04476 .32807 Mdot
.04667 .38442 Mdot
.04857 .23866 Mdot
.05048 .3455 Mdot
.05238 .39379 Mdot
.05429 .25826 Mdot
.05619 .37272 Mdot
.0581 .24242 Mdot
.06 .29263 Mdot
.0619 .42594 Mdot
.06381 .24741 Mdot
.06571 .28245 Mdot
.06762 .25615 Mdot
.06952 .25338 Mdot
.07143 .43543 Mdot
.07333 .24712 Mdot
.07524 .29158 Mdot
.07714 .28153 Mdot
.07905 .4268 Mdot
.08095 .33555 Mdot
.08286 .27324 Mdot
.08476 .22798 Mdot
.08667 .30698 Mdot
.08857 .33335 Mdot
.09048 .26151 Mdot
.09238 .40691 Mdot
.09429 .36542 Mdot
.09619 .25423 Mdot
.0981 .4219 Mdot
.1 .39718 Mdot
.1019 .43765 Mdot
.10381 .29715 Mdot
.10571 .25563 Mdot
.10762 .39664 Mdot
.10952 .3989 Mdot
.11143 .32375 Mdot
.11333 .34684 Mdot
.11524 .25099 Mdot
.11714 .33541 Mdot
.11905 .42435 Mdot
.12095 .25459 Mdot
.12286 .41342 Mdot
.12476 .28156 Mdot
.12667 .24236 Mdot
.12857 .24246 Mdot
.13048 .25297 Mdot
.13238 .35023 Mdot
.13429 .37429 Mdot
.13619 .3071 Mdot
.1381 .39669 Mdot
.14 .30936 Mdot
.1419 .44764 Mdot
.14381 .41993 Mdot
.14571 .27264 Mdot
.14762 .3027 Mdot
.14952 .23512 Mdot
.15143 .34469 Mdot
.15333 .25841 Mdot
.15524 .25504 Mdot
.15714 .27383 Mdot
.15905 .36838 Mdot
.16095 .28292 Mdot
.16286 .34769 Mdot
.16476 .32781 Mdot
.16667 .41994 Mdot
.16857 .30806 Mdot
.17048 .28202 Mdot
.17238 .27064 Mdot
.17429 .4194 Mdot
.17619 .31143 Mdot
.1781 .35038 Mdot
.18 .34041 Mdot
.1819 .33046 Mdot
.18381 .28853 Mdot
.18571 .29989 Mdot
.18762 .26148 Mdot
.18952 .361 Mdot
.19143 .34989 Mdot
.19333 .37845 Mdot
.19524 .25779 Mdot
.19714 .43698 Mdot
.19905 .26575 Mdot
.20095 .32164 Mdot
.20286 .34156 Mdot
.20476 .30713 Mdot
.20667 .2934 Mdot
.20857 .34711 Mdot
.21048 .2499 Mdot
.21238 .29645 Mdot
.21429 .37919 Mdot
.21619 .3937 Mdot
.2181 .37774 Mdot
.22 .38239 Mdot
.2219 .39062 Mdot
.22381 .32495 Mdot
.22571 .32208 Mdot
.22762 .35911 Mdot
.22952 .31847 Mdot
.23143 .32279 Mdot
.23333 .27768 Mdot
.23524 .35025 Mdot
.23714 .32342 Mdot
.23905 .22807 Mdot
.24095 .41457 Mdot
.24286 .43818 Mdot
.24476 .26662 Mdot
.24667 .28907 Mdot
.24857 .24769 Mdot
.25048 .23435 Mdot
.25238 .36992 Mdot
.25429 .23839 Mdot
.25619 .4576 Mdot
.2581 .23639 Mdot
.26 .42739 Mdot
.2619 .27806 Mdot
.26381 .30307 Mdot
.26571 .41908 Mdot
.26762 .33154 Mdot
.26952 .3712 Mdot
.27143 .31535 Mdot
.27333 .2578 Mdot
.27524 .38512 Mdot
.27714 .4038 Mdot
.27905 .34147 Mdot
.28095 .28091 Mdot
.28286 .42444 Mdot
.28476 .37948 Mdot
.28667 .42471 Mdot
.28857 .34681 Mdot
.29048 .33246 Mdot
.29238 .39879 Mdot
.29429 .41723 Mdot
.29619 .34008 Mdot
.2981 .26662 Mdot
.3 .37273 Mdot
.3019 .42176 Mdot
.30381 .27758 Mdot
.30571 .47519 Mdot
.30762 .32616 Mdot
.30952 .3428 Mdot
.31143 .46231 Mdot
.31333 .37585 Mdot
.31524 .25945 Mdot
.31714 .25655 Mdot
.31905 .27453 Mdot
.32095 .36868 Mdot
.32286 .39215 Mdot
.32476 .41856 Mdot
.32667 .24757 Mdot
.32857 .36454 Mdot
.33048 .38942 Mdot
.33238 .27418 Mdot
.33429 .4201 Mdot
.33619 .43713 Mdot
.3381 .39047 Mdot
.34 .25405 Mdot
.3419 .39428 Mdot
.34381 .27068 Mdot
.34571 .34277 Mdot
.34762 .25311 Mdot
.34952 .39386 Mdot
.35143 .42033 Mdot
.35333 .32885 Mdot
.35524 .25619 Mdot
.35714 .35975 Mdot
.35905 .33835 Mdot
.36095 .31149 Mdot
.36286 .30582 Mdot
.36476 .36483 Mdot
.36667 .26533 Mdot
.36857 .42533 Mdot
.37048 .40619 Mdot
.37238 .41346 Mdot
.37429 .3002 Mdot
.37619 .44149 Mdot
.3781 .33059 Mdot
.38 .22873 Mdot
.3819 .33456 Mdot
.38381 .22764 Mdot
.38571 .43277 Mdot
.38762 .26865 Mdot
.38952 .46008 Mdot
.39143 .42195 Mdot
.39333 .26127 Mdot
.39524 .45096 Mdot
.39714 .32096 Mdot
.39905 .45368 Mdot
.40095 .39213 Mdot
.40286 .34823 Mdot
.40476 .22991 Mdot
.40667 .33549 Mdot
.40857 .2801 Mdot
.41048 .2759 Mdot
.41238 .29193 Mdot
.41429 .36172 Mdot
.41619 .22117 Mdot
.4181 .38975 Mdot
.42 .29642 Mdot
.4219 .34864 Mdot
.42381 .32635 Mdot
.42571 .32114 Mdot
.42762 .32288 Mdot
.42952 .24 Mdot
.43143 .27721 Mdot
.43333 .34421 Mdot
.43524 .28219 Mdot
.43714 .39289 Mdot
.43905 .29202 Mdot
.44095 .43857 Mdot
.44286 .33075 Mdot
.44476 .39085 Mdot
.44667 .38497 Mdot
.44857 .29496 Mdot
.45048 .29664 Mdot
.45238 .33217 Mdot
.45429 .36651 Mdot
.45619 .26479 Mdot
.4581 .35947 Mdot
.46 .35659 Mdot
.4619 .32652 Mdot
.46381 .39555 Mdot
.46571 .45682 Mdot
.46762 .2626 Mdot
.46952 .30539 Mdot
.47143 .22046 Mdot
.47333 .36059 Mdot
.47524 .2943 Mdot
.47714 .45863 Mdot
.47905 .25306 Mdot
.48095 .38549 Mdot
.48286 .23571 Mdot
.48476 .38843 Mdot
.48667 .44699 Mdot
.48857 .3045 Mdot
.49048 .37001 Mdot
.49238 .36873 Mdot
.49429 .22795 Mdot
.49619 .29626 Mdot
.4981 .3954 Mdot
.5 .37511 Mdot
.5019 .37019 Mdot
.50381 .42007 Mdot
.50571 .45104 Mdot
.50762 .26571 Mdot
.50952 .26165 Mdot
.51143 .38564 Mdot
.51333 .24809 Mdot
.51524 .25924 Mdot
.51714 .24896 Mdot
.51905 .30242 Mdot
.52095 .3403 Mdot
.52286 .27498 Mdot
.52476 .34993 Mdot
.52667 .29508 Mdot
.52857 .37605 Mdot
.53048 .29176 Mdot
.53238 .37333 Mdot
.53429 .39744 Mdot
.53619 .34346 Mdot
.5381 .30818 Mdot
.54 .41397 Mdot
.5419 .26198 Mdot
.54381 .41299 Mdot
.54571 .24567 Mdot
.54762 .34761 Mdot
.54952 .3313 Mdot
.55143 .39473 Mdot
.55333 .30842 Mdot
.55524 .34974 Mdot
.55714 .24487 Mdot
.55905 .32803 Mdot
.56095 .3631 Mdot
.56286 .42456 Mdot
.56476 .32279 Mdot
.56667 .31061 Mdot
.56857 .36448 Mdot
.57048 .37187 Mdot
.57238 .32271 Mdot
.57429 .26931 Mdot
.57619 .3561 Mdot
.5781 .40558 Mdot
.58 .33476 Mdot
.5819 .33559 Mdot
.58381 .33466 Mdot
.58571 .31635 Mdot
.58762 .3778 Mdot
.58952 .31278 Mdot
.59143 .31881 Mdot
.59333 .3309 Mdot
.59524 .45344 Mdot
.59714 .39343 Mdot
.59905 .38786 Mdot
.60095 .4879 Mdot
.60286 .31969 Mdot
.60476 .2754 Mdot
.60667 .38282 Mdot
.60857 .22801 Mdot
.61048 .43296 Mdot
.61238 .34405 Mdot
.61429 .24725 Mdot
.61619 .25099 Mdot
.6181 .30718 Mdot
.62 .24203 Mdot
.6219 .36946 Mdot
.62381 .23599 Mdot
.62571 .46232 Mdot
.62762 .27195 Mdot
.62952 .39433 Mdot
.63143 .3153 Mdot
.63333 .31862 Mdot
.63524 .29715 Mdot
.63714 .41638 Mdot
.63905 .45652 Mdot
.64095 .40232 Mdot
.64286 .27609 Mdot
.64476 .34485 Mdot
.64667 .28425 Mdot
.64857 .4153 Mdot
.65048 .36128 Mdot
.65238 .28985 Mdot
.65429 .3132 Mdot
.65619 .36476 Mdot
.6581 .3698 Mdot
.66 .38815 Mdot
.6619 .30488 Mdot
.66381 .25549 Mdot
.66571 .3203 Mdot
.66762 .29354 Mdot
.66952 .35304 Mdot
.67143 .325 Mdot
.67333 .25485 Mdot
.67524 .27426 Mdot
.67714 .36152 Mdot
.67905 .25504 Mdot
.68095 .25097 Mdot
.68286 .35256 Mdot
.68476 .2737 Mdot
.68667 .28158 Mdot
.68857 .3009 Mdot
.69048 .42336 Mdot
.69238 .31751 Mdot
.69429 .33702 Mdot
.69619 .31949 Mdot
.6981 .41901 Mdot
.7 .38135 Mdot
.7019 .33384 Mdot
.70381 .4109 Mdot
.70571 .30704 Mdot
.70762 .34026 Mdot
.70952 .41951 Mdot
.71143 .36788 Mdot
.71333 .3806 Mdot
.71524 .39761 Mdot
.71714 .37452 Mdot
.71905 .40143 Mdot
.72095 .41964 Mdot
.72286 .44225 Mdot
.72476 .31254 Mdot
.72667 .35159 Mdot
.72857 .39997 Mdot
.73048 .34383 Mdot
.73238 .31685 Mdot
.73429 .31502 Mdot
.73619 .25113 Mdot
.7381 .35182 Mdot
.74 .39524 Mdot
.7419 .24046 Mdot
.74381 .38613 Mdot
.74571 .34918 Mdot
.74762 .40206 Mdot
.74952 .26289 Mdot
.75143 .34821 Mdot
.75333 .26417 Mdot
.75524 .4262 Mdot
.75714 .45463 Mdot
.75905 .35553 Mdot
.76095 .37513 Mdot
.76286 .27029 Mdot
.76476 .45352 Mdot
.76667 .3793 Mdot
.76857 .31556 Mdot
.77048 .41786 Mdot
.77238 .27771 Mdot
.77429 .29324 Mdot
.77619 .33505 Mdot
.7781 .25423 Mdot
.78 .28297 Mdot
.7819 .243 Mdot
.78381 .34116 Mdot
.78571 .45147 Mdot
.78762 .41659 Mdot
.78952 .35386 Mdot
.79143 .24076 Mdot
.79333 .34575 Mdot
.79524 .33538 Mdot
.79714 .3479 Mdot
.79905 .27505 Mdot
.80095 .3632 Mdot
.80286 .38174 Mdot
.80476 .29493 Mdot
.80667 .33501 Mdot
.80857 .28988 Mdot
.81048 .27566 Mdot
.81238 .45995 Mdot
.81429 .34654 Mdot
.81619 .3899 Mdot
.8181 .33839 Mdot
.82 .2574 Mdot
.8219 .30331 Mdot
.82381 .3551 Mdot
.82571 .34223 Mdot
.82762 .27628 Mdot
.82952 .28804 Mdot
.83143 .46015 Mdot
.83333 .32989 Mdot
.83524 .28626 Mdot
.83714 .2533 Mdot
.83905 .35895 Mdot
.84095 .38053 Mdot
.84286 .25794 Mdot
.84476 .25356 Mdot
.84667 .45518 Mdot
.84857 .26963 Mdot
.85048 .3796 Mdot
.85238 .40486 Mdot
.85429 .39405 Mdot
.85619 .27419 Mdot
.8581 .23194 Mdot
.86 .40446 Mdot
.8619 .32239 Mdot
.86381 .31667 Mdot
.86571 .26186 Mdot
.86762 .3371 Mdot
.86952 .30925 Mdot
.87143 .34586 Mdot
.87333 .37418 Mdot
.87524 .29444 Mdot
.87714 .24343 Mdot
.87905 .32735 Mdot
.88095 .24964 Mdot
.88286 .30239 Mdot
.88476 .29177 Mdot
.88667 .27011 Mdot
.88857 .32154 Mdot
.89048 .34383 Mdot
.89238 .2829 Mdot
.89429 .42242 Mdot
.89619 .35928 Mdot
.8981 .39735 Mdot
.9 .41621 Mdot
.9019 .31811 Mdot
.90381 .3627 Mdot
.90571 .33408 Mdot
.90762 .33847 Mdot
.90952 .37324 Mdot
.91143 .45123 Mdot
.91333 .34281 Mdot
.91524 .33156 Mdot
.91714 .25999 Mdot
.91905 .37503 Mdot
.92095 .42313 Mdot
.92286 .39382 Mdot
.92476 .30306 Mdot
.92667 .31788 Mdot
.92857 .33498 Mdot
.93048 .45006 Mdot
.93238 .27713 Mdot
.93429 .31106 Mdot
.93619 .24824 Mdot
.9381 .31611 Mdot
.94 .30983 Mdot
.9419 .26887 Mdot
.94381 .24275 Mdot
.94571 .27491 Mdot
.94762 .26651 Mdot
.94952 .24829 Mdot
.95143 .2365 Mdot
.95333 .36312 Mdot
.95524 .39621 Mdot
.95714 .25905 Mdot
.95905 .28091 Mdot
.96095 .32446 Mdot
.96286 .43127 Mdot
.96476 .32467 Mdot
.96667 .34842 Mdot
.96857 .29234 Mdot
.97048 .39354 Mdot
.97238 .25914 Mdot
.97429 .4255 Mdot
.97619 .40391 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo07[ooooo0_l0000@ooooo`;o0000[_ooool000Kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo07[ooooo0_l0000@ooooo`;o0000[_ooool000Kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1`ooooo`;o00008_ooool2o`000:Kooooo0004
o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`;o00003?ooool2o`0002oooooo0_l0
000/ooooo`?o00001Oooool2o`0001_ooooo0_l0000Rooooo`;o0000P_ooool000Kooooo00Go0000
ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?oo
ool3o`0000;ooooo0_l0000<ooooo`;o0000;oooool2o`0002cooooo0_l00006ooooo`;o0000?ooo
ool2o`0004oooooo0_l0000aooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
9Oooool2o`0001kooooo0_l000000ooooooo0000o`000016ooooo`;o0000:oooool2o`0004[ooooo
0_l0000Looooo`;o00004oooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`;o0000
7oooool2o`0001kooooo1Ol0000eooooo`;o00003oooool2o`0002_ooooo0_l0001Xooooo`;o0000
4oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@
41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo0_l000000ooooooo
0000o`00000Dooooo`?o00009_ooool2o`0003Oooooo0_l0000kooooo`;o00009Oooool2o`0000_o
oooo0_l000000ooooooo0000o`00000Jooooo`;o00004oooool2o`0001Kooooo0006ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006oooo
o`03o`000?oooooooooo00Oooooo0_l0000Dooooo`?o0000Q?ooool2o`0000;ooooo0_l0000Boooo
o`;o00009Oooool2o`0000_ooooo0_l000000ooooooo0000o`00000Jooooo`;o00004oooool2o`00
01Kooooo000Yooooo`;o00002_ooool2o`000003ooooool0003o000003Oooooo0_l0000Gooooo`;o
0000>_ooool3o`0000Oooooo0_l00002ooooo`;o00004?ooool2o`0005Cooooo0_l0000@ooooo`;o
00000_ooool2o`0001Cooooo000Yooooo`03o`000?oooooooooo00Wooooo0_l000000ooooooo0000
o`00000<ooooo`;o00007?ooool2o`0000_ooooo0_l0000Gooooo`;o0000>_ooool3o`0001gooooo
0ol0000Cooooo`;o00003oooool2o`0002gooooo0_l0000@ooooo`;o00000_ooool2o`0001Cooooo
000Yooooo`03o`000?oooooooooo00_ooooo0_l00007ooooo`;o000000Coooooo`000?l0003ooooo
1?l000000ooooooo0000o`000006ooooo`;o00003oooool2o`0002Sooooo1?l0000Yooooo`;o0000
:_ooool2o`0000gooooo0_l000000ooooooo0000o`000003o`0000oooooo0_l0000<ooooo`;o0000
4Oooool4o`0003Kooooo000Yooooo`03o`000?oooooooooo00Kooooo0_l00002ooooo`?o00001ooo
ool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000005ooooo`?o00002_oo
ool2o`0001Sooooo0_l0000<ooooo`;o00001Oooool4o`000003ooooool0003o000002Kooooo0_l0
000iooooo`;o000000?oooooo`000?l000000_l0000Nooooo`;o00002oooool2o`0000Cooooo1?l0
000Rooooo`;o00004_ooool002Wooooo00?o0000ooooooooool01_ooool2o`0000;ooooo0_l00006
ooooo`;o00004_ooool2o`0000Wooooo1?l0000Hooooo`;o00002oooool3o`0000[ooooo0_l0000:
ooooo`;o00008oooool4o`0000Oooooo0_l0001Gooooo`;o00001_ooool2o`0000Gooooo0_l0000?
ooooo`;o00002_ooool2o`0000?ooooo0_l0000=ooooo`00:Oooool2o`0001?ooooo0_l0000Moooo
o`;o00009oooool2o`0001Oooooo0_l0000Booooo`;o00000_ooool2o`0000_ooooo1?l00007oooo
o`;o0000@Oooool3o`0002;ooooo0_l0000?ooooo`;o00003oooool2o`0000gooooo000Yooooo`03
o`000?oooooooooo03Gooooo0_l0000<ooooo`;o00003oooool2o`0001Gooooo0_l0000Jooooo`;o
00000_ooool2o`0000_ooooo0_l0001<ooooo`?o0000??ooool2o`0001Gooooo000Yooooo`03o`00
0?oooooooooo02cooooo0_l00002ooooo`Co000000So410@o`000?l0003ok^k^oc8b<_l0003o<S8b
onk^kP?ooooo00Cok^k^oc8b<_l0003o<S8b0_l0000?ooooo`;o00003Oooool2o`0000Kooooo2?l0
0002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Ko
oooo0_l0000@ooooo`03oiRHV?l@413o000000;o00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Zooooo`?o00000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP09ooooo`;o00002oooool2o`0000oooooo
1Ol000002Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool002Wooooo00?o0000ooooooooool03oooool2o`0001;ooooo0_l00002
ooooo`;o00000oooool2o`0000Cooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Gooooo`;o00000_ooool2o`0000;ooooo
0_l00008ooooo`04oiRHV?lQ8B7ok^k^ooooo`;o00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Xooooo`03oa0@4?nj^[[ooooo00;o00000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00CoMgMgoiRHV?ooooooV9RH0_l0000>ooooo`;o0000
00?oooooo`000?l000005oooool2o`0000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02Oooool2o`000003ooooool0003o000000Sooooo0_l0000?oooo
o`;o00000oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool002Wooooo00?o0000ooooooooool03oooool2o`0001;ooooo
0_l00002ooooo`;o00002Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41000oooool01Ol@413o0000o`000?oooooo410@01;ooooo0_l00003ooooo`;o00000_ooool2o`00
00gooooo00?oV9RHob4Q8Oo^k^h01?ooool01?l@413oooooooooooooool2o`0000;ooooo00Go410@
ooooool0003o0000oa0@400Kooooo`;o00003oooool01Ol0003ooooooooooooooooo410@00?ooooo
00Go410@o`000?l0003ooooooa0@4003ooooo`;o00000oooool2o`0000Wooooo0_l000000ooooooo
0000o`00000Dooooo`Go000000Coooooo`000?l0003o410@0oooool00ol@413oooooooooo`02o`00
0004ooooool0003o0000oa0@40?ooooo0_l00007ooooo`;o00005_ooool2o`0000?ooooo0_l00002
ooooo`04o`000?oooooooooooa0@40?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@
4?oooooooooo007ooooo000Yooooo`;o0000<oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool3o`000003ooooool0003ooooo00Cooooo0_l0000;ooooo`;o0000
5oooool00onHV9So8B4Qonk^kP03ooooo`03o`000?oooooooooo00?o00000_ooool00ol0003ooooo
o`000002o`0001_ooooo0_l0000>ooooo`03ojVYZOl@413ooooo00;ooooo00Co0000oooooooooooo
oooo0ol000000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00;ooooo0_l0000Rooooo`04
odA4A?oMgMgoooooo`0000;ooooo0ol00003ooooo`03o`000?oooooooooo00;o000000Coooooo`00
0?l0003o00000oooool2o`0001oooooo0_l00003ooooo`;o000000?oooooogMgMolb<S800_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`00:Ooo
ool00ol0003oooooooooo`0:ooooo`;o000000?oooooo`000?l000003_ooool2o`0000Wooooo0_l0
00000ooooooo0000o`000005ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000001Oooool2o`0000Cooooo0_l0000Oooooo`03
ogMgMomVIVKooooo00;ooooo00?o0000ooooooooool00_l00003ooooo`04o`000?oooooooooooooo
o`;o0000:Oooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000001;ooooo0_l0000Dooooo`04omgMgOmEEEGoooooo`0000Cooooo
0_l00002ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Fooooo`;o
00003oooool01?l0003o8B4Qo`000?lb<S82o`000003ooooool0003ooooo00;ooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo007ooooo000Yooooo`03o`000?oooooooooo
00[ooooo0_l000000ooooooo0000o`00000>ooooo`;o00002Oooool2o`000003ooooool0003o0000
00Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@
oooooooooooooooooa0@400;ooooo`;o00008?ooool01Ol0003ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooooooooa0@4003ooooo`;o0000:_ooool00onj^[[o8B4Qooooo`02ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Kooooo0_l0000:
ooooo`;o00005Oooool00omgMgOoc<c<o`000004ooooo`;o00000_ooool01Ol@413ooooooooooooo
oooo410@00?ooooo00?o410@ooooooooool00oooool2o`00017ooooo0_l0000?ooooo`04o`000?oo
ooooooooooooo`;o000000?ooooooa0@4?ooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00?o410@ooooooooool00Oooool002Wooooo0ol0000`ooooo`?o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02o`0002Oooooo00Go0000okZj
^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg02Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo0ol0000Pooooo`03onk^k_m4A4Co
000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So0000o`000?mgMgL0
0oooool4o`0002;ooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool3o`0000Sooooo0_l00003ooooo`;o
00008Oooool3o`0000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00_l0000Wooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01?o^k^ko<S8bo`00
0?lb<S82o`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02o`0001_ooooo0_l00009ooooo`05
ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP07ooooo`;o00008Oooool00omgMgOo0000ooooo`02ooooo`;o000000Co
<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?l0003ok^k^00?ooooo0_l0000@ooooo`;o
00004_ooool4o`0000?ooooo0ol000000olb<S;ok^k^ooooo`02ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool002Wooooo0_l00009ooooo`;o00000oooool2o`0002Sooooo0_l00010ooooo`;o
00001oooool2o`000003ooooool0003o000000Kooooo0_l00005ooooo`;o00002?ooool3o`0002[o
oooo0_l0000Qooooo`;o00001oooool2o`0001Gooooo0_l000000ooooooo0000o`00000Iooooo`;o
00003_ooool002Wooooo00?o0000ooooooooool05_ooool2o`0001oooooo1?l00011ooooo`;o0000
1oooool2o`0000Kooooo0_l00005ooooo`;o00002?ooool2o`00027ooooo0_l00008ooooo`;o0000
:_ooool2o`0001Gooooo0_l0000/ooooo`00:Oooool01?l0003oooooooooooooool2o`0001?ooooo
0_l0000Hooooo`;o00001oooool2o`0003;ooooo0_l0000=ooooo`;o00001oooool2o`0001Gooooo
0_l0000Sooooo`;o00003oooool2o`0003cooooo0_l0000Zooooo`00:Oooool01?l0003ooooooooo
ooooool2o`00027ooooo0_l0000:ooooo`;o00005oooool2o`0002;ooooo0_l0000Mooooo`;o0000
1?ooool2o`0000Sooooo0_l0000[ooooo`;o00001oooool2o`0002Wooooo0_l0000Aooooo`;o0000
3?ooool2o`0001cooooo000Yooooo`03o`000?oooooooooo013ooooo0_l0000>ooooo`;o00000_oo
ool2o`0000Gooooo0_l00009ooooo`;o00004Oooool2o`0001kooooo0_l0000Qooooo`;o00001?oo
ool2o`0000kooooo0_l00003ooooo`;o00004_ooool2o`0000cooooo0_l0000=ooooo`;o00008ooo
ool2o`0001oooooo0_l0000Looooo`008Oooooooo`0004Co00001?ooool002Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0_l00009oooo
o`;o00002oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`07ooooo`?o00003?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:oooo
o`04o`000?oooooo0000o`0000Gooooo0_l000000ooooooo0000ooooo`0:ooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooooooo0_l0
00000ooooooo0000o`000003ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0:ooooo`?o00002Oooool00ol0003oooooooooo`07ooooo`Co00002_oo
ool00ol0003oooooooooo`0:ooooo`00:Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooo
oooo00oooooo0_l0000Zooooo`03o`000?oooooooooo03Kooooo0ol000000ooooooo0000ooooo`09
ooooo`;o00001Oooool2o`0000[ooooo0_l00009ooooo`Go00002Oooool2o`0000Cooooo00?o0000
ooooooooool05Oooool2o`0000_ooooo0_l00006ooooo`;o000000?oooooo`000?l000002oooool0
0ol0003oooooooooo`0:ooooo`00:Oooool01?l0003oooooo`000?l0000mooooo`;o00003?ooool2
o`0002Kooooo0_l00007ooooo`;o0000<_ooool4o`000003ooooool0003o000000Sooooo0_l00009
ooooo`;o00001_ooool3o`0000[ooooo0_l0000:ooooo`;o00007?ooool2o`0000_ooooo0_l00006
ooooo`;o000000?oooooo`000?l000006?ooool002Wooooo00Co0000ooooool0003o00005oooool2
o`0001_ooooo0_l00006ooooo`Ko0000<Oooool2o`0000Oooooo0ol0000Zooooo`;o000000?ooooo
o`000?l000001?ooool2o`000003ooooool0003o000000Sooooo0_l00009ooooo`;o00001oooool2
o`0003Cooooo0_l00006ooooo`;o0000:?ooool002Wooooo0_l0000Iooooo`;o00006oooool2o`00
00Kooooo1_l0000Eooooo`;o00008oooool3o`0000Wooooo0_l0000Oooooo`;o000000?oooooo`00
0?l000007_ooool2o`0003_ooooo0_l00003ooooo`;o000000?oooooo`000?l000005_ooool3o`00
00oooooo000Yooooo`03o`000?oooooooooo00?ooooo0_l0000Uooooo`;o00000oooool2o`0000co
oooo0_l0000Iooooo`;o00003?ooool2o`0000Kooooo0_l0000=ooooo`;o00002_ooool2o`0001go
oooo0_l0000Sooooo`;o0000<_ooool2o`0000cooooo0_l0000Iooooo`?o00003oooool002Wooooo
00?o0000ooooooooool00_l000000ooooooo0000o`00000<ooooo`;o00005oooool2o`0000?ooooo
0_l0000Jooooo`;o00001Oooool2o`0001;ooooo0_l00006ooooo`;o00004oooool2o`000003oooo
ool0003o000001gooooo0_l000000ooooooo0000o`000009ooooo`;o0000C?ooool2o`0001Sooooo
0_l0000Oooooo`00:Oooool00ol0003oooooooooo`02o`0000gooooo1?l00007ooooo`;o0000;ooo
ool2o`0000Gooooo0_l0000Kooooo`;o00001_ooool2o`0000[ooooo0_l000000ooooooo0000o`00
000Mooooo`;o00002?ooool3o`000003ooooool0003o0000027ooooo0_l0000Fooooo`;o00001?oo
ool2o`0000;ooooo0_l0000Nooooo`;o000000?oooooo`000?l000000_ooool2o`0001_ooooo000Y
ooooo`03o`000?oooooooooo00oooooo0_l00009ooooo`;o0000C?ooool2o`0000Gooooo0_l00006
ooooo`;o0000=_ooool3o`0002;ooooo1?l0000Fooooo`;o00001?ooool2o`0000;ooooo0_l00002
ooooo`;o00003_ooool2o`0000[ooooo0_l00005ooooo`;o00006oooool002Wooooo0_l00002oooo
o`;o0000:oooool2o`0000Kooooo0_l0000Fooooo`;o00001?ooool2o`0000;ooooo0_l0000:oooo
o`;o00000_ooool2o`0003;ooooo0_l0000fooooo`;o00000_ooool2o`0001Oooooo0_l00009oooo
o`Co00003?ooool2o`0000[ooooo1?l0000Pooooo`00:Oooool2o`0000;ooooo0_l00002ooooo`;o
00007_ooool2o`0000Oooooo0_l00006ooooo`;o00005_ooool2o`0000Cooooo0_l00002ooooo`;o
00002_ooool2o`0001[ooooo0_l0000Jooooo`;o00000oooool2o`0001Oooooo0_l00008ooooo`;o
00004_ooool2o`0000Gooooo0_l0000@ooooo`;o000000?oooooo`000?l000002?ooool2o`0000go
oooo0_l00004ooooo`;o00001Oooool2o`00023ooooo000Yooooo`;o00000oooool2o`000003oooo
ool0003o000001;ooooo0_l0000:ooooo`;o00000_ooool2o`0000gooooo0_l0000Gooooo`;o0000
8oooool2o`0000Cooooo0_l00002ooooo`;o00007oooool2o`0000;ooooo0_l0000Cooooo`;o0000
2?ooool2o`0001Wooooo0_l00003ooooo`Co00003?ooool3o`0000?ooooo0_l0000Aooooo`;o0000
1?ooool2o`0001Kooooo0_l0000?ooooo`00:Oooool00ol0003oooooooooo`02ooooo`;o00005Ooo
ool2o`0000Cooooo0_l00008ooooo`;o00000oooool2o`0000;ooooo0_l00004ooooo`;o00001_oo
ool2o`0000oooooo0_l0000Sooooo`;o00001?ooool2o`0001oooooo0_l00006ooooo`Co0000=Ooo
ool2o`0000;ooooo1_l0000=ooooo`;o00000oooool2o`0002oooooo0_l0000?ooooo`00:Oooool0
0ol0003oooooooooo`0Oooooo`;o00003Oooool2o`0000;ooooo0_l0000<ooooo`;o0000Foooool2
o`0000Sooooo0_l0000Sooooo`;o00000_ooool2o`0000cooooo0_l00002ooooo`;o00003_ooool2
o`0000[ooooo0_l0000looooo`00:Oooool2o`0008[ooooo0_l0000Sooooo`;o00007?ooool2o`00
00;ooooo0_l0000Gooooo`;o00001oooool2o`0000[ooooo0_l0000looooo`00:Oooool00ol0003o
ooooooooo`0booooo`;o00002_ooool2o`0002Oooooo0_l0000Oooooo`?o00000_ooool2o`0001oo
oooo0_l0000Fooooo`;o00001_ooool2o`0001Wooooo0_l0000Gooooo`;o00004Oooool2o`0002Go
oooo000Yooooo`04o`000?oooooo0000o`00037ooooo0_l0000:ooooo`;o00007_ooool2o`0000Oo
oooo0_l0000Aooooo`;o00003?ooool2o`0000?ooooo0_l0000Jooooo`Co00006Oooool4o`0000Co
oooo0_l0000Vooooo`;o00002_ooool2o`00017ooooo1?l0000>ooooo`;o00004oooool002Wooooo
00Co0000ooooool0003o00004_ooool2o`0004Wooooo0_l0000:ooooo`;o00003_ooool2o`0000_o
oooo0_l0000Pooooo`Co00006oooool2o`0000oooooo0_l0000Kooooo`;o00007oooool2o`0000ko
oooo0_l0000Cooooo`00:Oooool00ol0003oooooooooo`0Cooooo`;o00004oooool2o`0001cooooo
0_l0000Dooooo`;o00003?ooool2o`0001_ooooo0_l00009ooooo`?o000000?oooooo`000?l00000
9Oooool2o`0000Wooooo0_l0000?ooooo`;o0000HOooool002Wooooo0_l00008ooooo`;o00007ooo
ool2o`0001cooooo0_l00003ooooo`;o00002?ooool2o`0000Gooooo0_l0000dooooo`?o000000?o
ooooo`000?l000002?ooool2o`0000[ooooo0_l0000?ooooo`;o00002Oooool2o`0004oooooo0_l0
000Qooooo`00:Oooool00ol0003oooooooooo`07ooooo`;o00005oooool2o`0002Wooooo0_l00008
ooooo`;o00000_ooool2o`0003[ooooo0_l00008ooooo`?o00002_ooool2o`0002gooooo0_l0000<
ooooo`;o00008_ooool2o`0000[ooooo0_l000000ooooooo0000o`00000Nooooo`001_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool08?ooool2o`00017ooooo0_l00005ooooo`?o00004ooo
ool2o`0000Oooooo0_l0000jooooo`;o00002?ooool2o`00017ooooo0_l0000Wooooo`;o00003?oo
ool4o`0001Wooooo0_l00005ooooo`;o00003Oooool2o`0001kooooo0006ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0<oooool2o`0000Gooooo0ol0000Cooooo`;o0000
H?ooool2o`0000Cooooo0_l0000Looooo`;o00000_ooool2o`0000oooooo0_l0000:ooooo`;o0000
2_ooool2o`000003ooooool0003o000003Cooooo0006ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool2o`0003Gooooo0_l0000@ooooo`;o0000=Oooool2o`0000Wooooo0_l00008ooooo`;o0000
7Oooool2o`0001cooooo0_l00002ooooo`;o00002?ooool2o`00017ooooo0_l0000:ooooo`;o0000
=oooool000Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo
00?oMgMgoc8b<_ooool01?ooool3o`0000Cooooo0_l00017ooooo`;o00004?ooool2o`0002?ooooo
0_l00009ooooo`?o00001oooool2o`0001[ooooo0_l0000Booooo`;o00006Oooool2o`0005Kooooo
0006ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0looooo`;o00007_ooool2o`000003
ooooool0003o000000;o00004oooool2o`0000?ooooo0_l00007ooooo`;o00002_ooool2o`0002?o
oooo0_l0000Booooo`;o0000<?ooool2o`0003oooooo0006ooooo`05oa0@4?ooooooooooooooool@
41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01Oooool2o`0003?ooooo1?l0000Nooooo`;o00000oooool6o`0000oooooo0_l00003ooooo`;o
00001?ooool2o`000003ooooool0003o000000Cooooo0_l00009ooooo`;o00003oooool2o`0000go
oooo0_l00008ooooo`;o00008_ooool2o`0001Kooooo0_l0000:ooooo`;o00005?ooool2o`0000ko
oooo0_l0000=ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oo
ooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo0_l00006ooooo`;o00003_ooool5o`00
00Oooooo0_l0000Gooooo`;o00005oooool2o`0000kooooo1?l0000Jooooo`;o00001oooool2o`00
00Wooooo0_l00009ooooo`;o00001?ooool2o`0000gooooo0_l00008ooooo`;o00006_ooool2o`00
00Kooooo0_l0000Rooooo`;o00003?ooool2o`0000Kooooo0_l00009ooooo`;o00000oooool2o`00
00gooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7o
c<c<00Cooooo1?l00006ooooo`;o00005_ooool5o`0000Oooooo0_l0000`ooooo`;o0000Boooool2
o`0003Wooooo0ol000000ooooooo0000o`000004ooooo`;o0000;_ooool2o`00017ooooo0_l0000B
ooooo`00:Oooool2o`0004oooooo0_l0001cooooo`;o00005oooool2o`000003ooooool0003o0000
00Cooooo0_l0000Pooooo`Co00009?ooool2o`0000_ooooo000Yooooo`03o`000?oooooooooo01;o
oooo0_l0000jooooo`;o00007?ooool2o`00043ooooo0_l0000Cooooo`;o0000@_ooool4o`0002Co
oooo0_l0000;ooooo`00:Oooool00ol0003oooooooooo`0Booooo`;o0000F?ooool2o`00043ooooo
0_l0000Wooooo`;o0000Hoooool002Wooooo00?o0000ooooooooool07?ooool2o`0004kooooo0_l0
000dooooo`?o0000<_ooool2o`0006?ooooo000Yooooo`03o`000?oooooooooo01cooooo0_l0000T
ooooo`;o00003oooool2o`0001Oooooo0_l0000dooooo`?o00007?ooool2o`0000;ooooo0_l0000[
ooooo`;o00008_ooool2o`0002Cooooo000Yooooo`;o00009?ooool2o`0000Gooooo0_l000000ooo
oooo0000o`00000Cooooo`;o00001_ooool2o`0000Oooooo0_l00008ooooo`;o000000?oooooo`00
0?l000001?ooool2o`0002oooooo0_l0000Xooooo`;o00000_ooool2o`0000kooooo0_l00002oooo
o`;o000000?oooooo`000?l000003_ooool2o`0000Cooooo0_l0000Rooooo`;o00009?ooool002Wo
oooo00?o0000ooooooooool05?ooool2o`0000gooooo0_l00005ooooo`;o000000?oooooo`000?l0
00006oooool2o`0000[ooooo0_l00005ooooo`;o000000?oooooo`000?l000001?ooool2o`0000[o
oooo0_l0000Sooooo`;o0000>_ooool4o`0000;ooooo0_l000000ooooooo0000o`00000>ooooo`;o
00009_ooool2o`0000Oooooo0_l0000Mooooo`00:Oooool00ol0003oooooooooo`09ooooo`;o0000
0oooool2o`0000Cooooo0_l00005ooooo`;o0000<oooool3o`0000?ooooo0_l0000Cooooo`;o0000
1Oooool2o`0003Kooooo0_l0000Wooooo`;o00004_ooool2o`0002_ooooo0_l00007ooooo`;o0000
3oooool2o`0000cooooo000Yooooo`03o`000?oooooooooo00Wooooo0_l00003ooooo`;o00002ooo
ool2o`0002_ooooo0_l00006ooooo`?o00006?ooool2o`0003gooooo0_l0000kooooo`;o0000AOoo
ool2o`0000cooooo000Yooooo`03o`000?oooooooooo04Sooooo0_l0000Wooooo`;o0000A_ooool2
o`0006oooooo0_l0000@ooooo`00:Oooool2o`0000gooooo0_l0001Sooooo`;o0000A_ooool2o`00
06oooooo0_l0000@ooooo`00:Oooool00ol0003oooooooooo`0<ooooo`;o00001oooool2o`0001go
oooo0_l0000=ooooo`;o00007?ooool2o`0001oooooo0_l0002hooooo`00:Oooool00ol0003ooooo
ooooo`0Eooooo`;o00007Oooool2o`0000gooooo0_l0000Looooo`;o00002oooool2o`0001;ooooo
0_l0001Iooooo`;o0000GOooool002Wooooo00?o0000ooooooooool0K_ooool2o`0006gooooo0_l0
001Mooooo`00:Oooool00ol0003oooooooooo`0Rooooo`;o0000KOooool2o`000:Wooooo000Yoooo
o`;o00008oooool2o`00053ooooo0_l0000Kooooo`;o00001?ooool2o`0005Sooooo0_l0000Woooo
o`;o00001?ooool2o`0001[ooooo000Yooooo`03o`000?oooooooooo07Cooooo0ol0000Pooooo`;o
00006oooool2o`0003;ooooo0_l000000ooooooo0000o`000004ooooo`;o00009oooool2o`0000Co
oooo0_l0000Jooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`17ooooo`;o0000;?ooool2o`00
01?ooooo0_l0000Xooooo`;o00003?ooool2o`0002Cooooo0_l000000ooooooo0000o`00000Hoooo
o`;o0000=Oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo04Oooooo0_l0000Yooooo`;o00005_ooool2o`00
00;ooooo0_l0000booooo`;o0000=_ooool2o`0000Cooooo0_l00003ooooo`;o0000=Oooool000ko
oooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0001Ioooo
o`;o00005oooool2o`0001[ooooo0_l0000^ooooo`;o0000>_ooool2o`0000Cooooo0_l0000joooo
o`003_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`1Iooooo`;o0000Hoooool2o`0007cooooo000>ooooo`05o`000?oooooooooooooo
ool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Oooooo0_l0003Sooooo`003_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000F?ooool2o`000>?ooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`2fooooo`;o0000Q?ooool002Wooooo00?o0000ooooooooool0]_oo
ool2o`0008Cooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000ooooooln
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400=oooo
o`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000Ko
oooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b
<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Oooooo`Co000000?o410@oooooooo
ool00oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`?o0000oooo
oolmooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Oooooo`03oeEEEOmVIVKo00000?ooooooAoooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .38487 Mdot
.02762 .39719 Mdot
.02952 .27738 Mdot
.03143 .34075 Mdot
.03333 .34865 Mdot
.03524 .24953 Mdot
.03714 .31954 Mdot
.03905 .23582 Mdot
.04095 .30298 Mdot
.04286 .3103 Mdot
.04476 .35152 Mdot
.04667 .27951 Mdot
.04857 .28441 Mdot
.05048 .34555 Mdot
.05238 .29609 Mdot
.05429 .29198 Mdot
.05619 .37204 Mdot
.0581 .2757 Mdot
.06 .25279 Mdot
.0619 .3925 Mdot
.06381 .26842 Mdot
.06571 .36812 Mdot
.06762 .34776 Mdot
.06952 .25994 Mdot
.07143 .37001 Mdot
.07333 .30127 Mdot
.07524 .34391 Mdot
.07714 .25744 Mdot
.07905 .40611 Mdot
.08095 .39347 Mdot
.08286 .24463 Mdot
.08476 .30461 Mdot
.08667 .22653 Mdot
.08857 .37691 Mdot
.09048 .34314 Mdot
.09238 .3469 Mdot
.09429 .42186 Mdot
.09619 .29192 Mdot
.0981 .41549 Mdot
.1 .298 Mdot
.1019 .37172 Mdot
.10381 .3648 Mdot
.10571 .26719 Mdot
.10762 .395 Mdot
.10952 .36821 Mdot
.11143 .36442 Mdot
.11333 .33848 Mdot
.11524 .35693 Mdot
.11714 .25919 Mdot
.11905 .40074 Mdot
.12095 .3601 Mdot
.12286 .42816 Mdot
.12476 .2239 Mdot
.12667 .30599 Mdot
.12857 .29569 Mdot
.13048 .25143 Mdot
.13238 .24106 Mdot
.13429 .37182 Mdot
.13619 .39536 Mdot
.1381 .35805 Mdot
.14 .36012 Mdot
.1419 .46262 Mdot
.14381 .4166 Mdot
.14571 .27316 Mdot
.14762 .22758 Mdot
.14952 .27617 Mdot
.15143 .30137 Mdot
.15333 .30812 Mdot
.15524 .2879 Mdot
.15714 .2434 Mdot
.15905 .38077 Mdot
.16095 .27286 Mdot
.16286 .31492 Mdot
.16476 .26847 Mdot
.16667 .4165 Mdot
.16857 .30869 Mdot
.17048 .22373 Mdot
.17238 .34077 Mdot
.17429 .4248 Mdot
.17619 .24789 Mdot
.1781 .2548 Mdot
.18 .39485 Mdot
.1819 .33591 Mdot
.18381 .36088 Mdot
.18571 .22666 Mdot
.18762 .28211 Mdot
.18952 .35294 Mdot
.19143 .36158 Mdot
.19333 .36245 Mdot
.19524 .30375 Mdot
.19714 .37399 Mdot
.19905 .38277 Mdot
.20095 .26824 Mdot
.20286 .36555 Mdot
.20476 .2607 Mdot
.20667 .40223 Mdot
.20857 .34305 Mdot
.21048 .35473 Mdot
.21238 .2196 Mdot
.21429 .3661 Mdot
.21619 .39331 Mdot
.2181 .34322 Mdot
.22 .2774 Mdot
.2219 .39999 Mdot
.22381 .23739 Mdot
.22571 .3738 Mdot
.22762 .38213 Mdot
.22952 .25461 Mdot
.23143 .26935 Mdot
.23333 .24152 Mdot
.23524 .33167 Mdot
.23714 .3407 Mdot
.23905 .30943 Mdot
.24095 .36065 Mdot
.24286 .34026 Mdot
.24476 .28853 Mdot
.24667 .35189 Mdot
.24857 .25605 Mdot
.25048 .27704 Mdot
.25238 .42197 Mdot
.25429 .28559 Mdot
.25619 .45474 Mdot
.2581 .3 Mdot
.26 .40954 Mdot
.2619 .24123 Mdot
.26381 .33964 Mdot
.26571 .37388 Mdot
.26762 .42473 Mdot
.26952 .40026 Mdot
.27143 .26931 Mdot
.27333 .34994 Mdot
.27524 .39927 Mdot
.27714 .31037 Mdot
.27905 .25566 Mdot
.28095 .24676 Mdot
.28286 .42077 Mdot
.28476 .42802 Mdot
.28667 .39386 Mdot
.28857 .31105 Mdot
.29048 .23157 Mdot
.29238 .30368 Mdot
.29429 .46073 Mdot
.29619 .3191 Mdot
.2981 .26848 Mdot
.3 .37248 Mdot
.3019 .37842 Mdot
.30381 .23331 Mdot
.30571 .4047 Mdot
.30762 .26049 Mdot
.30952 .36395 Mdot
.31143 .44887 Mdot
.31333 .33455 Mdot
.31524 .32324 Mdot
.31714 .25635 Mdot
.31905 .2808 Mdot
.32095 .29504 Mdot
.32286 .42959 Mdot
.32476 .42146 Mdot
.32667 .25654 Mdot
.32857 .42108 Mdot
.33048 .42946 Mdot
.33238 .25586 Mdot
.33429 .42568 Mdot
.33619 .36709 Mdot
.3381 .31422 Mdot
.34 .27003 Mdot
.3419 .38903 Mdot
.34381 .23701 Mdot
.34571 .24715 Mdot
.34762 .29612 Mdot
.34952 .43133 Mdot
.35143 .38373 Mdot
.35333 .27919 Mdot
.35524 .31662 Mdot
.35714 .35211 Mdot
.35905 .27331 Mdot
.36095 .22694 Mdot
.36286 .40976 Mdot
.36476 .28829 Mdot
.36667 .29638 Mdot
.36857 .4093 Mdot
.37048 .43206 Mdot
.37238 .32545 Mdot
.37429 .25609 Mdot
.37619 .3797 Mdot
.3781 .3139 Mdot
.38 .31175 Mdot
.3819 .42605 Mdot
.38381 .31086 Mdot
.38571 .35905 Mdot
.38762 .25408 Mdot
.38952 .44429 Mdot
.39143 .37849 Mdot
.39333 .30233 Mdot
.39524 .45847 Mdot
.39714 .22722 Mdot
.39905 .40673 Mdot
.40095 .29163 Mdot
.40286 .36395 Mdot
.40476 .34579 Mdot
.40667 .38025 Mdot
.40857 .32132 Mdot
.41048 .31894 Mdot
.41238 .26857 Mdot
.41429 .34283 Mdot
.41619 .32461 Mdot
.4181 .39562 Mdot
.42 .33171 Mdot
.4219 .26381 Mdot
.42381 .34092 Mdot
.42571 .33078 Mdot
.42762 .35214 Mdot
.42952 .32844 Mdot
.43143 .34516 Mdot
.43333 .24832 Mdot
.43524 .26175 Mdot
.43714 .3911 Mdot
.43905 .35245 Mdot
.44095 .37039 Mdot
.44286 .31792 Mdot
.44476 .34345 Mdot
.44667 .27916 Mdot
.44857 .35459 Mdot
.45048 .38876 Mdot
.45238 .24025 Mdot
.45429 .27434 Mdot
.45619 .27832 Mdot
.4581 .32026 Mdot
.46 .40187 Mdot
.4619 .27488 Mdot
.46381 .29883 Mdot
.46571 .45868 Mdot
.46762 .31875 Mdot
.46952 .27205 Mdot
.47143 .31899 Mdot
.47333 .29794 Mdot
.47524 .34548 Mdot
.47714 .44952 Mdot
.47905 .30485 Mdot
.48095 .40253 Mdot
.48286 .30379 Mdot
.48476 .39788 Mdot
.48667 .46208 Mdot
.48857 .24064 Mdot
.49048 .27709 Mdot
.49238 .38057 Mdot
.49429 .30068 Mdot
.49619 .26078 Mdot
.4981 .42824 Mdot
.5 .34322 Mdot
.5019 .37988 Mdot
.50381 .4182 Mdot
.50571 .40067 Mdot
.50762 .29154 Mdot
.50952 .30311 Mdot
.51143 .42645 Mdot
.51333 .29569 Mdot
.51524 .32178 Mdot
.51714 .27611 Mdot
.51905 .3128 Mdot
.52095 .23487 Mdot
.52286 .3763 Mdot
.52476 .27739 Mdot
.52667 .34578 Mdot
.52857 .28871 Mdot
.53048 .26547 Mdot
.53238 .32823 Mdot
.53429 .37338 Mdot
.53619 .343 Mdot
.5381 .24149 Mdot
.54 .36444 Mdot
.5419 .26743 Mdot
.54381 .3591 Mdot
.54571 .28372 Mdot
.54762 .3093 Mdot
.54952 .25664 Mdot
.55143 .43035 Mdot
.55333 .25644 Mdot
.55524 .29136 Mdot
.55714 .3499 Mdot
.55905 .35271 Mdot
.56095 .28452 Mdot
.56286 .41605 Mdot
.56476 .27637 Mdot
.56667 .25772 Mdot
.56857 .42077 Mdot
.57048 .26335 Mdot
.57238 .25678 Mdot
.57429 .30506 Mdot
.57619 .31352 Mdot
.5781 .33945 Mdot
.58 .36478 Mdot
.5819 .24323 Mdot
.58381 .42592 Mdot
.58571 .39977 Mdot
.58762 .27205 Mdot
.58952 .39728 Mdot
.59143 .30251 Mdot
.59333 .40811 Mdot
.59524 .45254 Mdot
.59714 .31552 Mdot
.59905 .28677 Mdot
.60095 .43091 Mdot
.60286 .24954 Mdot
.60476 .24893 Mdot
.60667 .40082 Mdot
.60857 .30142 Mdot
.61048 .3636 Mdot
.61238 .34415 Mdot
.61429 .35232 Mdot
.61619 .28489 Mdot
.6181 .32487 Mdot
.62 .33177 Mdot
.6219 .37592 Mdot
.62381 .29573 Mdot
.62571 .44312 Mdot
.62762 .27921 Mdot
.62952 .35509 Mdot
.63143 .37174 Mdot
.63333 .22813 Mdot
.63524 .2641 Mdot
.63714 .33086 Mdot
.63905 .43034 Mdot
.64095 .45804 Mdot
.64286 .33027 Mdot
.64476 .2586 Mdot
.64667 .35888 Mdot
.64857 .42248 Mdot
.65048 .32515 Mdot
.65238 .32524 Mdot
.65429 .31371 Mdot
.65619 .38059 Mdot
.6581 .25951 Mdot
.66 .42616 Mdot
.6619 .26022 Mdot
.66381 .34877 Mdot
.66571 .27398 Mdot
.66762 .26819 Mdot
.66952 .40082 Mdot
.67143 .24483 Mdot
.67333 .26888 Mdot
.67524 .25586 Mdot
.67714 .33674 Mdot
.67905 .23917 Mdot
.68095 .28576 Mdot
.68286 .39787 Mdot
.68476 .27235 Mdot
.68667 .23228 Mdot
.68857 .34688 Mdot
.69048 .38853 Mdot
.69238 .38516 Mdot
.69429 .29608 Mdot
.69619 .36127 Mdot
.6981 .46136 Mdot
.7 .27485 Mdot
.7019 .41002 Mdot
.70381 .35559 Mdot
.70571 .24649 Mdot
.70762 .38055 Mdot
.70952 .3794 Mdot
.71143 .31403 Mdot
.71333 .27394 Mdot
.71524 .45738 Mdot
.71714 .28383 Mdot
.71905 .30665 Mdot
.72095 .33669 Mdot
.72286 .37942 Mdot
.72476 .27157 Mdot
.72667 .28084 Mdot
.72857 .3059 Mdot
.73048 .23678 Mdot
.73238 .27576 Mdot
.73429 .23541 Mdot
.73619 .28637 Mdot
.7381 .26721 Mdot
.74 .39085 Mdot
.7419 .34341 Mdot
.74381 .40206 Mdot
.74571 .4158 Mdot
.74762 .42643 Mdot
.74952 .35365 Mdot
.75143 .4169 Mdot
.75333 .35518 Mdot
.75524 .35163 Mdot
.75714 .36717 Mdot
.75905 .41669 Mdot
.76095 .30678 Mdot
.76286 .28918 Mdot
.76476 .41395 Mdot
.76667 .35906 Mdot
.76857 .31053 Mdot
.77048 .33257 Mdot
.77238 .24133 Mdot
.77429 .32608 Mdot
.77619 .27863 Mdot
.7781 .32567 Mdot
.78 .3407 Mdot
.7819 .34823 Mdot
.78381 .24525 Mdot
.78571 .45661 Mdot
.78762 .33084 Mdot
.78952 .38043 Mdot
.79143 .25375 Mdot
.79333 .38072 Mdot
.79524 .26916 Mdot
.79714 .28885 Mdot
.79905 .28571 Mdot
.80095 .25261 Mdot
.80286 .27581 Mdot
.80476 .34515 Mdot
.80667 .29151 Mdot
.80857 .34502 Mdot
.81048 .26538 Mdot
.81238 .42857 Mdot
.81429 .36549 Mdot
.81619 .31244 Mdot
.8181 .32575 Mdot
.82 .31994 Mdot
.8219 .26424 Mdot
.82381 .36125 Mdot
.82571 .3786 Mdot
.82762 .3377 Mdot
.82952 .32973 Mdot
.83143 .45204 Mdot
.83333 .2305 Mdot
.83524 .31034 Mdot
.83714 .33472 Mdot
.83905 .38208 Mdot
.84095 .32051 Mdot
.84286 .27318 Mdot
.84476 .30938 Mdot
.84667 .41739 Mdot
.84857 .38659 Mdot
.85048 .40279 Mdot
.85238 .28871 Mdot
.85429 .39906 Mdot
.85619 .32354 Mdot
.8581 .28623 Mdot
.86 .31361 Mdot
.8619 .35111 Mdot
.86381 .38444 Mdot
.86571 .23416 Mdot
.86762 .29896 Mdot
.86952 .32551 Mdot
.87143 .28629 Mdot
.87333 .28529 Mdot
.87524 .24812 Mdot
.87714 .36314 Mdot
.87905 .32408 Mdot
.88095 .32868 Mdot
.88286 .36755 Mdot
.88476 .26131 Mdot
.88667 .28229 Mdot
.88857 .26228 Mdot
.89048 .23645 Mdot
.89238 .26898 Mdot
.89429 .42232 Mdot
.89619 .40168 Mdot
.8981 .3645 Mdot
.9 .36639 Mdot
.9019 .23619 Mdot
.90381 .3795 Mdot
.90571 .42686 Mdot
.90762 .28493 Mdot
.90952 .26352 Mdot
.91143 .4003 Mdot
.91333 .34308 Mdot
.91524 .40866 Mdot
.91714 .27013 Mdot
.91905 .36387 Mdot
.92095 .3869 Mdot
.92286 .39407 Mdot
.92476 .25157 Mdot
.92667 .36102 Mdot
.92857 .37769 Mdot
.93048 .4643 Mdot
.93238 .24901 Mdot
.93429 .30551 Mdot
.93619 .27953 Mdot
.9381 .24884 Mdot
.94 .26962 Mdot
.9419 .3247 Mdot
.94381 .31098 Mdot
.94571 .24973 Mdot
.94762 .30817 Mdot
.94952 .31027 Mdot
.95143 .27342 Mdot
.95333 .34588 Mdot
.95524 .36471 Mdot
.95714 .27817 Mdot
.95905 .25818 Mdot
.96095 .29547 Mdot
.96286 .32863 Mdot
.96476 .30153 Mdot
.96667 .39909 Mdot
.96857 .38568 Mdot
.97048 .31967 Mdot
.97238 .27885 Mdot
.97429 .4007 Mdot
.97619 .30959 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo03Wooooo0_l0003oooooo`;ooooo0006ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`0Mooooo`;o00003?ooool2o`0000cooooo0_l0003oooooo`;ooooo0006oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4
A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool04?ooool2o`0000_ooooo0_l0
0005ooooo`;o00001Oooool2o`0000?ooooo0_l0000gooooo`;o00002Oooool2o`000<Kooooo0004
o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0@ooooo`;o00004_ooool2o`0000[ooooo0_l0
000gooooo`;o00002Oooool2o`0004[ooooo0_l0000oooooo`;o0000>Oooool000Kooooo00Go0000
ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?oo
ool3o`0005;ooooo0_l00002ooooo`;o0000J?ooool2o`0000oooooo0_l0000^ooooo`;o00002?oo
ool2o`0002oooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool01?l0003oooooooooooooool2o`0004oo
oooo0_l00002ooooo`;o00002oooool2o`0003Oooooo0_l0000cooooo`;o00003?ooool4o`0002So
oooo0_l00006ooooo`;o00000_ooool2o`0002?ooooo0006ooooo`05oa0@4?ooooooooooooooool@
41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooo
oooooooo0_l0000jooooo`;o00009?ooool2o`00027ooooo0_l0000Dooooo`;o0000<Oooool2o`00
00kooooo1?l0000`ooooo`;o00000_ooool2o`0002?ooooo0006ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Oooooo`;o00001_ooool2o`0001Cooooo0_l000000ooooooo0000o`000007
ooooo`;o0000>oooool2o`0000[ooooo0_l0000>ooooo`;o00003?ooool2o`0001gooooo0_l0000L
ooooo`;o0000COooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool03oooool2o`0000kooooo0_l0
0006ooooo`;o00005oooool2o`0000Oooooo0_l00017ooooo`;o00003_ooool2o`0000cooooo0_l0
000Kooooo`;o00002Oooool2o`0001?ooooo0_l00002ooooo`;o0000BOooool002Wooooo0_l00000
0ooooooo0000o`00000=ooooo`;o00007?ooool2o`00023ooooo0_l0000Cooooo`;o00006_ooool2
o`0003Cooooo0ol0000Dooooo`;o00002Oooool2o`0001Oooooo0_l0000Kooooo`;o00004?ooool4
o`000003ooooool0003o000001Gooooo000Yooooo`03o`000?oooooooooo00;o00001_ooool2o`00
01Gooooo0_l0000<ooooo`;o00008?ooool2o`0001?ooooo0_l0000Jooooo`;o0000=?ooool3o`00
03gooooo0_l0000Fooooo`;o00003_ooool6o`000003ooooool0003o000001Gooooo000Yooooo`03
o`000?oooooooooo00Sooooo0_l0000Eooooo`;o00003Oooool2o`0000kooooo0_l0000>ooooo`;o
00003oooool2o`00013ooooo0_l0001Kooooo`;o00008oooool2o`000003ooooool0003o000002Ko
oooo0_l0000Looooo`00:Oooool00ol0003oooooooooo`0=ooooo`;o00007oooool2o`0000kooooo
0_l00005ooooo`;o00001oooool2o`0000_ooooo0_l000001?oooooo0000o`000?l0000<ooooo`;o
00000_ooool2o`0003;ooooo1?l00002ooooo`Co00005Oooool2o`0000Sooooo0_l0000Sooooo`;o
0000=?ooool2o`00017ooooo000Yooooo`03o`000?oooooooooo00_ooooo1?l0000;ooooo`;o0000
6_ooool2o`0000gooooo0_l0000Aooooo`;o000000Coooooo`000?l0003ooooo0_l0000=ooooo`;o
00004_ooool2o`00017ooooo0_l0000?ooooo`Co00000_ooool4o`0001Gooooo0_l00002ooooo`?o
0000A_ooool2o`0001Kooooo0_l0000Aooooo`00:Oooool2o`0000cooooo0_l0000=ooooo`;o0000
6_ooool2o`00023ooooo0_l0000Rooooo`;o00000oooool2o`00017ooooo0_l0000Fooooo`;o0000
4oooool2o`0000Gooooo0ol0000booooo`;o00004_ooool3o`0000Gooooo0_l0000Qooooo`00:Ooo
ool00ol0003oooooooooo`0Gooooo`;o00007?ooool2o`0004Gooooo0_l0000Qooooo`;o00000_oo
ool2o`0000Oooooo0_l0000Cooooo`;o00002?ooool2o`0001Gooooo0_l0000Eooooo`;o00000_oo
ool2o`0001?ooooo0_l00005ooooo`;o00008Oooool002Wooooo00?o0000ooooooooool02Oooool2
o`0000cooooo0_l0000Aooooo`;o00001?ooool4o`000008oa0@4?l0003o0000onk^k_lb<S;o0000
oc8b<_o^k^h3ooooo`?o000000?o<S8bonk^k_ooool01oooool2o`0000Kooooo0_l0000<ooooo`;o
00002Oooool5o`0000?ooooo00Cok^k^oc8b<_l0003o<S8b0_l00002ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h07Oooool2o`0000;ooooo0_l00005ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co
00004oooool2o`0000Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^
kP02o`000003ooooooo^k^ko<S8b00;o000000?ok^k^ooooooooool05_ooool2o`0000Kooooo0_l0
0005ooooo`;o000000GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Yooooo`03o`000?oooooooooo00Wo
oooo0_l0000Hooooo`;o00000oooool4o`0000Kooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo0_l000000oooooooV9RHogMgM`08ooooo`;o00001_ooool2o`00
00cooooo0_l00004ooooo`;o00000oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00CoMgMg
oiRHV?ooooooV9RH0_l00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0000?ooooo
0_l0000Looooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool2o`000003oooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`Co00000_ooool2o`0000Oooooo0_l00002oooo
o`;o00002_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_l00000
1_ooooooMgMgoiRHV?ooooooV9RHogMgM`Sooooo0_l0000>ooooo`;o00001_ooool2o`0000Gooooo
0_l00002ooooo`;o000000So<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool3o`0000Oooooo0_l0000Jooooo`Co000000?ooooo
o`000?l000002?ooool00ol0003oooooooooo`02ooooo`04oa0@4?ooooooooooooooo`;o00000_oo
ool01_l@413ooooooooooooooooo410@ooooo`;o00008Oooool2o`0000Cooooo00?oV9RHob4Q8Oo^
k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4005
ooooo`Co000000?oooooo`000?l000001?ooool2o`0000Oooooo1?l0000;ooooo`;o00000_ooool0
1?l0003oooooooooooooool2o`0000;ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@
4?oooooooooo00[ooooo0_l00004ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`Co0000
1Oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@4003ooooo`;o00000_ooool00ol@413o
ooooooooo`06ooooo`;o00008Oooool3o`0000;ooooo00Go410@oooooooooooooooooa0@4003oooo
o`05oa0@4?ooooooooooooooool@41000oooool002Wooooo0ol00004ooooo`;o000000?oooooo`00
0?l000007?ooool2o`0000_ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooooooool2
o`0000;ooooo00Ko0000ooooooooooooooooo`000?ooool2o`0001Cooooo0_l00009ooooo`;o0000
1oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000;ooooo0_l000000ooooooo0000o`000002o`0000Oooooo0_l00007oooo
o`Co00002oooool2o`000003oooooonYZJWo410@00?ooooo00Go0000ooooooooooooooooo`000003
ooooo`04o`000?ooooooooooooooo`;o00005_ooool2o`0000Sooooo0_l00005ooooo`04odA4A?oM
gMgoooooo`0000?ooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000_ooool00ol0003o
ooooooooo`0Tooooo`;o00001?ooool2o`0000;ooooo0ol000000ooooooo0000ooooo`02ooooo`05
o`000?ooooooooooooooool000000oooool002Wooooo00?o0000ooooooooool01?ooool2o`0002_o
oooo0_l00004ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000001Oooooo0_l00009ooooo`;o00002?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo0_l000000ooooooo0000
o`00000Kooooo`;o00001_ooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool0
00000oooool01?l0003oooooooooooooool2o`0001_ooooo0_l000000ooooooo0000o`000007oooo
o`04omgMgOmEEEGoooooo`0000?ooooo0_l00003ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`0Dooooo`;o00003_ooool2o`000003ooooool0003o8B4Q00?o00000_oo
ool3o`000003ooooool0003ooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`00:Ooo
ool00ol0003oooooooooo`04ooooo`;o0000:oooool2o`0000Cooooo00Go410@oooooooooooooooo
oa0@4003ooooo`05oa0@4?ooooooooooooooool@41000_ooool2o`0002Wooooo00Go0000oooooooo
oooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`0P
ooooo`;o00000oooool2o`0000;ooooo00?o^[Zjob4Q8Oooool00_ooool00ol@413oooooooooo`02
o`0000?ooooo00Go410@o`000?l0003ooooooa0@400Aooooo`;o00002Oooool2o`000004ooooool0
003o0000ooooo`;o00001Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@
41000_ooool2o`0000?ooooo00?o410@ooooooooool02oooool2o`0000;ooooo0_l00003ooooo`;o
00001?ooool2o`0000_ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`00:Oooool00ol0003oooooooooo`04oooo
o`;o00008Oooool2o`0000Wooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00CoMgMgoiRHV?ooooooV9RH0_l000000ooooooo0000o`00000Rooooo`;o000000Ko
ooooo`000?nj^[[ooooooiRHV?l@4103ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01gooooo0_l00008ooooo`;o000000CoV9RHoooooonj^[[o00000ooo
ool00omgMgOoV9RHooooo`02o`0000?ooooo00GoMgMgo`000?l0003oV9RHogMgM`0Aooooo`;o0000
3oooool2o`0000Gooooo00Cok^k^odA4A?l0003o00000oooool01_mgMgOoV9RHoooooonHV9SoMgMg
ooooo`?o000000CoV9RHoooooonHV9SoMgMg2oooool4o`0000;ooooo0_l00009ooooo`;o00002ooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo000Yooooo`03o`000?oooooooooo00Kooooo0_l0000<ooooo`;o0000
4Oooool2o`0000Oooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo00Cok^k^oc8b<_l0003o<S8b0_l0000Uooooo`;o000000KooooooiRHV?l@413o0000ob4Q8Oo<
c<`3ooooo`05onk^k_l0003o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Ko
oooo0_l00005ooooo`;o00001_ooool2o`000006oooooonYZJWo410@o`000?l@413oZJVY0oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Zooooo`03ogMg
Mol0003o000000?ooooo00Kok^k^oc8b<_l0003o<S8bonk^k_ooool2o`000005onk^k_l0003o0000
oc8b<_o^k^h02oooool2o`0001cooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Yooooo`;o00001_ooool3o`0000cooooo0_l0
0008ooooo`;o0000??ooool2o`0000Kooooo0_l00005ooooo`;o00002Oooool2o`00023ooooo1?l0
000;ooooo`;o00005?ooool2o`0001Gooooo0_l0000Rooooo`;o0000<?ooool2o`00013ooooo000Y
ooooo`03o`000?oooooooooo00Gooooo0_l0000>ooooo`;o00001oooool2o`0003cooooo0_l00006
ooooo`;o00001Oooool2o`0001gooooo0_l000000ooooooo0000o`00000;ooooo`;o00008Oooool2
o`0001Gooooo0_l0000fooooo`;o00007?ooool2o`00013ooooo000Yooooo`03o`000?oooooooooo
00cooooo0_l00007ooooo`;o00003_ooool2o`00027ooooo0_l0000Yooooo`;o00005Oooool2o`00
0003ooooool0003o000000Gooooo0_l0000Mooooo`;o00000oooool2o`0005;ooooo0_l0000Moooo
o`;o00003oooool002Wooooo00?o0000ooooooooool00_ooool2o`0000Sooooo0_l00002ooooo`;o
00004oooool2o`0000cooooo0_l0000Cooooo`;o00002Oooool2o`0001kooooo0_l0000Jooooo`?o
00000_ooool2o`0000;ooooo0_l0000Cooooo`;o00001?ooool2o`0000?ooooo0_l0001Wooooo`;o
00002?ooool2o`0000oooooo000Yooooo`03o`000?oooooooooo00;ooooo0_l0000<ooooo`;o0000
2oooool2o`0000Oooooo0_l00003ooooo`;o00001_ooool2o`0001kooooo0_l0000jooooo`?o0000
1_ooool2o`0001?ooooo0_l0000]ooooo`;o000000?oooooo`000?l000002?ooool2o`0003Kooooo
0_l00002ooooo`;o00005Oooool0027oooooool00014o`0000Cooooo000Yooooo`03o`000?oooooo
oooo00;ooooo0_l00005ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`04ooooo`;o00000oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Cooooo0_l00004ooooo`03o`000?oooooooooo00Cooooo0_l000001?oooooo0000o`000?l0
000;ooooo`04o`000?oooooo0000o`0000Sooooo00?o0000ooooooooool01?l00006ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`;o0000
1oooool2o`0000;ooooo00?o0000ooooooooool00_ooool2o`0000Gooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`03ooooo`;o00001?ooool00ol0003oooooooooo`09ooooo`;o0000
2oooool00ol0003oooooooooo`03ooooo`;o00001?ooool00ol0003oooooooooo`06ooooo`;o0000
00Coooooo`000?oooooooooo0_l000000ooooooo0000o`000003ooooo`?o00002oooool00ol0003o
ooooooooo`09ooooo`Go00001oooool2o`0000_ooooo000Yooooo`03o`000?oooooooooo02Wooooo
0_l0000?ooooo`03o`000?oooooooooo02Cooooo0_l00004ooooo`;o00001Oooool2o`0000Sooooo
00?o0000ooooooooool02?ooool2o`0001Oooooo0_l0000@ooooo`;o00001Oooool2o`00013ooooo
0_l0000@ooooo`;o00005oooool00ol0003oooooooooo`06ooooo`;o00003?ooool2o`0002Cooooo
00?o0000ooooooooool02_ooool002Wooooo00Co0000oooooooooooooooo0_l0001Aooooo`;o0000
4Oooool2o`00013ooooo0_l00008ooooo`;o00000oooool2o`000004ooooool0003o0000o`0002Oo
oooo0_l00015ooooo`;o00001Oooool2o`0002Sooooo0_l0000=ooooo`00:Oooool01?l0003ooooo
ooooooooool2o`00057ooooo0_l00004ooooo`;o00007?ooool3o`0000gooooo0_l000001?oooooo
0000o`000?l0000<ooooo`;o0000H?ooool2o`0000Gooooo0_l00003ooooo`;o00001Oooool2o`00
01cooooo0_l0000=ooooo`00:Oooool2o`0005_ooooo0_l0000@ooooo`;o00002_ooool4o`0001ko
oooo0_l0000Oooooo`;o00002Oooool2o`0002Kooooo0ol0000;ooooo`;o00002_ooool2o`0000;o
oooo0_l000000ooooooo0000o`00000Booooo`;o00005oooool002Wooooo00?o0000ooooooooool0
K?ooool2o`0000cooooo0_l00003ooooo`;o00007oooool2o`0001Wooooo0_l00006ooooo`;o0000
00?oooooo`000?l000009_ooool3o`0000_ooooo0_l000000ooooooo0000o`00000;ooooo`;o0000
0_ooool2o`00017ooooo0_l00005ooooo`;o00004?ooool002Wooooo00?o0000ooooooooool0@?oo
ool2o`0003[ooooo1Ol0000Oooooo`;o00006_ooool2o`0000?ooooo1?l0000Wooooo`;o00001?oo
ool2o`0000_ooooo0_l0000?ooooo`;o00006?ooool2o`00013ooooo000Yooooo`03o`000?oooooo
oooo02oooooo0_l0000?ooooo`;o00005oooool2o`00027ooooo0ol0000mooooo`;o00000oooool2
o`0000_ooooo0_l0000<ooooo`;o00003_ooool2o`0000Cooooo0_l0000>ooooo`;o0000>?ooool0
02Wooooo00?o0000ooooooooool06Oooool2o`0001Cooooo0_l0000Hooooo`;o00003_ooool2o`00
05?ooooo0_l0000Nooooo`;o00003?ooool2o`00027ooooo0_l000000ooooooo0000o`00000hoooo
o`00:Oooool4o`0001Sooooo0_l0000Aooooo`;o00004oooool4o`0000Cooooo0_l0000_ooooo`;o
000000?oooooo`000?l000008_ooool2o`0000_ooooo0_l0000oooooo`;o00003_ooool2o`0003_o
oooo000Yooooo`04o`000?oooooo0000o`0000Cooooo0_l00006ooooo`;o00000oooool2o`0001So
oooo0_l0000:ooooo`;o000000?oooooo`000?l000001?ooool4o`0003;ooooo0_l000001?oooooo
0000o`000?ooool4o`0000?ooooo0_l00007ooooo`;o00001_ooool2o`0000Oooooo0_l000000ooo
oooo0000o`00000Gooooo`;o00009oooool2o`0000[ooooo0_l00006ooooo`Co00007oooool2o`00
00_ooooo0_l0000Cooooo`00:Oooool01?l0003oooooo`000?l00004ooooo`;o00000oooool2o`00
0003ooooool0003o000000?ooooo0_l0000Tooooo`;o000000?oooooo`000?l00000>_ooool2o`00
00Kooooo0_l00003ooooo`;o00001oooool2o`0000Kooooo0_l00007ooooo`;o00006_ooool2o`00
00kooooo0_l00006ooooo`;o00003oooool2o`0000_ooooo0_l00005ooooo`Co00007oooool2o`00
00_ooooo0_l0000Cooooo`00:Oooool01?l0003oooooo`000?l00002ooooo`;o00001Oooool2o`00
00Kooooo0_l0000`ooooo`;o00001oooool2o`0001Sooooo0_l0000Eooooo`;o0000:?ooool2o`00
013ooooo0_l0000>ooooo`;o00001_ooool2o`0001?ooooo0_l00007ooooo`;o00006?ooool2o`00
033ooooo000Yooooo`03o`000?oooooooooo00?ooooo0_l0000]ooooo`;o00001?ooool2o`0000[o
oooo0_l00007ooooo`;o00006?ooool2o`0001Gooooo0_l00002ooooo`;o000000?oooooo`000?l0
00008Oooool2o`00013ooooo0_l00003ooooo`;o00009Oooool3o`00027ooooo0_l0000`ooooo`00
:Oooool2o`0001_ooooo0_l00005ooooo`;o00003oooool2o`0000Cooooo0_l00018ooooo`;o0000
00?oooooo`000?l000008Oooool2o`0001Gooooo0_l0000Fooooo`;o00003Oooool3o`0005?ooooo
000Yooooo`03o`000?oooooooooo01[ooooo1?l00003ooooo`?o00003?ooool4o`0000kooooo0_l0
000]ooooo`;o0000<?ooool2o`00023ooooo0_l0000=ooooo`;o000000?oooooo`000?l000004_oo
ool2o`00017ooooo0_l0000Oooooo`;o00006oooool002Wooooo00?o0000ooooooooool05_ooool4
o`0000;ooooo0_l00004ooooo`;o00003?ooool5o`0000gooooo0_l0000Dooooo`;o00005oooool2
o`0000?ooooo0_l0000Zooooo`?o00002_ooool2o`0000Sooooo0_l0000:ooooo`;o00003Oooool2
o`0001Gooooo0_l0000Aooooo`;o00003oooool2o`0000Cooooo0_l00005ooooo`;o000000?ooooo
o`000?l000001oooool2o`0001;ooooo000Yooooo`03o`000?oooooooooo01Kooooo1?l0000Ioooo
o`;o000000?oooooo`000?l000000_ooool2o`0001cooooo0_l00007ooooo`;o00004oooool2o`00
02[ooooo0_l0000;ooooo`;o00002?ooool2o`0002gooooo0_l0000@ooooo`;o00004oooool3o`00
00?ooooo0ol00004ooooo`;o00002_ooool2o`0001;ooooo000Yooooo`03o`000?oooooooooo00[o
oooo1?l0000:ooooo`;o00007?ooool2o`0000;ooooo0_l0000Uooooo`;o00007oooool2o`0006Co
oooo0_l0000@ooooo`;o00005?ooool2o`0000Cooooo0_l0000Tooooo`00:Oooool2o`0000Sooooo
0_l000000ooooooo0000o`000002o`0000Oooooo0_l000000ooooooo0000o`000006ooooo`;o0000
4_ooool2o`0000Oooooo0_l0000;ooooo`;o00002Oooool2o`0002_ooooo0_l0000Looooo`;o0000
7_ooool2o`0007[ooooo000Yooooo`03o`000?oooooooooo00Oooooo0_l00008ooooo`;o00000_oo
ool2o`0000Wooooo0_l0000Booooo`;o00001oooool2o`0000_ooooo0_l00009ooooo`;o0000A_oo
ool2o`000003ooooool0003o000001_ooooo0_l000000ooooooo0000o`00001jooooo`001_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Gooooo00?o0000ooooooooool04Oooool2o`0004?ooooo0_l0000Fooooo`;o0000
0_ooool2o`0000?ooooo0_l0000Mooooo`;o00001Oooool2o`0001kooooo0_l0000Jooooo`;o0000
0_ooool2o`0001oooooo0_l0000Gooooo`;o00001_ooool2o`0001_ooooo0006ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0:?ooool2o`0000_ooooo0_l00007ooooo`;o
00005_ooool2o`0001Kooooo0_l00002ooooo`;o00000oooool2o`0001[ooooo0_l000000ooooooo
0000o`00000`ooooo`;o00003_ooool3o`0000;ooooo0_l0000Cooooo`Co00002?ooool2o`0000;o
oooo0_l0000Cooooo`;o00001_ooool2o`0001_ooooo0006ooooo`05oa0@4?ooooooooooooooool@
41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0_l0000Yooooo`;o
00002oooool2o`0000Oooooo0_l0000Vooooo`;o0000:oooool2o`0003?ooooo0_l00009ooooo`;o
00000oooool2o`0001Sooooo1?l0000<ooooo`;o00001_ooool2o`00023ooooo0_l0000>ooooo`00
1_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo
<S8booooo`04ooooo`?o0000Hoooool2o`000003ooooool0003o000001gooooo0_l0001<ooooo`;o
0000<?ooool2o`0000?ooooo0_l0000Aooooo`;o00003Oooool2o`0000kooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`09ooooo`;o0000F?ooool2o`0001cooooo0_l00002oooo
o`;o0000C?ooool2o`0000kooooo0_l0000Pooooo`;o00005_ooool2o`0001gooooo0006ooooo`05
oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02Oooool2o`0000Cooooo0_l00006ooooo`;o00001oooool2o`00
00cooooo0_l0000:ooooo`;o00005Oooool2o`0002Sooooo0_l00004ooooo`;o0000H?ooool2o`00
03Sooooo0_l0000Mooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo0_l0000@ooooo`;o00001_ooool2
o`0000Oooooo0_l0000<ooooo`;o00002_ooool2o`0001Gooooo0_l0000Xooooo`;o00004oooool2
o`00023ooooo0_l0000Looooo`;o0000Boooool2o`0001gooooo0006ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o00007?oo
ool2o`0001oooooo0_l0000=ooooo`Co0000>_ooool2o`0000Gooooo0_l00005ooooo`;o00006?oo
ool3o`0000Cooooo0_l0000Booooo`;o00000_ooool2o`0001;ooooo0_l0000Qooooo`;o00003?oo
ool2o`0000?ooooo0_l0000?ooooo`;o000000?oooooo`000?l000003?ooool002Wooooo0_l0000L
ooooo`;o00006_ooool2o`0000?ooooo0_l0000=ooooo`Co00002?ooool2o`00033ooooo0_l00004
ooooo`;o00001_ooool2o`0001Sooooo0_l00005ooooo`;o00004_ooool2o`0001Kooooo0_l0000P
ooooo`?o00003?ooool2o`0000?ooooo0_l0000?ooooo`;o000000?oooooo`000?l000003?ooool0
02Wooooo00?o0000ooooooooool03_ooool2o`0002Oooooo0_l0000Nooooo`;o00007?ooool2o`00
01Sooooo0_l0000Rooooo`;o0000DOooool2o`0003Cooooo000Yooooo`03o`000?oooooooooo00ko
oooo0_l0000hooooo`;o00007oooool4o`0000Sooooo0_l0000looooo`;o00008Oooool2o`0004?o
oooo0_l0000Oooooo`00:Oooool00ol0003oooooooooo`18ooooo`;o00007oooool4o`0006Wooooo
0_l0000Cooooo`;o0000;_ooool2o`0001oooooo000Yooooo`03o`000?oooooooooo01Cooooo0_l0
000=ooooo`;o00001Oooool2o`0007kooooo0_l0000hooooo`Co000000?oooooo`000?l000000_l0
000Hooooo`;o0000=Oooool002Wooooo0_l0000Eooooo`;o00003Oooool2o`0000Gooooo0_l0000T
ooooo`;o0000AOooool2o`00017ooooo0ol0000gooooo`Co000000?oooooo`000?l000006_ooool2
o`0003Gooooo000Yooooo`03o`000?oooooooooo01?ooooo0_l0000aooooo`;o00002?ooool2o`00
00_ooooo0ol0000gooooo`;o00004_ooool2o`0001Sooooo0_l0001=ooooo`;o00009_ooool002Wo
oooo00?o0000ooooooooool04oooool2o`0001Sooooo0_l0000Gooooo`;o00000oooool2o`00013o
oooo1Ol0000=ooooo`;o0000:?ooool2o`0001Gooooo0_l0000Cooooo`;o00000_ooool2o`0001[o
oooo0_l0000]ooooo`;o00000_ooool2o`0002;ooooo000Yooooo`03o`000?oooooooooo01cooooo
0_l0000?ooooo`;o00007?ooool2o`0000?ooooo0_l0000:ooooo`;o000000Coooooo`000?l0003o
00003Oooool2o`0002Cooooo0_l00002ooooo`;o00005Oooool2o`0001Oooooo0_l0000Jooooo`;o
00004oooool2o`0001cooooo0_l0000Rooooo`00:Oooool00ol0003oooooooooo`0Looooo`;o0000
<_ooool2o`0000[ooooo0_l000000ooooooo0000o`000004ooooo`;o00001Oooool2o`0002Oooooo
0_l0000?ooooo`;o00003_ooool2o`0000[ooooo0_l0000fooooo`;o0000@?ooool002Wooooo0_l0
001Vooooo`;o00001Oooool2o`0003Sooooo0_l0000>ooooo`;o00002_ooool2o`0007Sooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`1booooo`;o0000B_ooool2o`0007cooooo000Yooooo`03o`00
0?oooooooooo07;ooooo0_l0001:ooooo`;o0000O?ooool002Wooooo0_l0001Jooooo`;o0000<ooo
ool2o`000:cooooo000Yooooo`03o`000?oooooooooo04Oooooo0_l0000@ooooo`;o0000<oooool2
o`0002Cooooo0_l0001:ooooo`;o0000>_ooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0Aooo
ool2o`0006_ooooo0_l0000=ooooo`;o00005_ooool2o`0001Cooooo0_l0000=ooooo`;o0000>_oo
ool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo05?ooooo0_l0000Oooooo`;o00005?ooool2o`0003Oooooo0_l0
000Fooooo`;o00005?ooool2o`0004Wooooo000>ooooo`05oa0@4?ooooooooooooooool@41004?oo
ool00ol0003oooooooooo`03ooooo`?o00008_ooool2o`0002oooooo0_l0000Oooooo`;o00005?oo
ool2o`0000Gooooo0_l00012ooooo`;o0000BOooool2o`0001[ooooo000>ooooo`05o`000?oooooo
ooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02;ooooo0_l0
001]ooooo`;o0000@_ooool2o`0004Wooooo0_l0000Jooooo`003_ooool01Ol0003ooooooooooooo
oooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo
?Oooool000kooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0oooooolmooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46
ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_oo
ool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooo
oolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?oo
ool00ol0003oooooooooo`03ooooo`?o0000oooooolmooooo`001_ooool01Ol0003ooooooooooooo
oooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<
c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo
?Oooool000Kooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool5o`0000Cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o
0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o
0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool001oooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooo
oooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Qooooo`03o`000?oooooooooo00Gooooo0ol0003oooooocgooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001oo
oooo00?oEEEEofIVI_l00000oooooom7ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .32264 Mdot
.02762 .40136 Mdot
.02952 .30641 Mdot
.03143 .3136 Mdot
.03333 .28668 Mdot
.03524 .27411 Mdot
.03714 .29081 Mdot
.03905 .27092 Mdot
.04095 .39439 Mdot
.04286 .25622 Mdot
.04476 .32552 Mdot
.04667 .23164 Mdot
.04857 .37242 Mdot
.05048 .29638 Mdot
.05238 .22738 Mdot
.05429 .33913 Mdot
.05619 .32192 Mdot
.0581 .36702 Mdot
.06 .31215 Mdot
.0619 .30961 Mdot
.06381 .36088 Mdot
.06571 .40532 Mdot
.06762 .39903 Mdot
.06952 .35494 Mdot
.07143 .2598 Mdot
.07333 .35974 Mdot
.07524 .34738 Mdot
.07714 .32149 Mdot
.07905 .33598 Mdot
.08095 .40196 Mdot
.08286 .33635 Mdot
.08476 .39595 Mdot
.08667 .30916 Mdot
.08857 .37104 Mdot
.09048 .38332 Mdot
.09238 .24962 Mdot
.09429 .42886 Mdot
.09619 .3459 Mdot
.0981 .35964 Mdot
.1 .22583 Mdot
.1019 .26066 Mdot
.10381 .38312 Mdot
.10571 .34924 Mdot
.10762 .34392 Mdot
.10952 .28855 Mdot
.11143 .35565 Mdot
.11333 .28276 Mdot
.11524 .42257 Mdot
.11714 .26857 Mdot
.11905 .32768 Mdot
.12095 .42347 Mdot
.12286 .39346 Mdot
.12476 .33642 Mdot
.12667 .37034 Mdot
.12857 .3667 Mdot
.13048 .35864 Mdot
.13238 .26282 Mdot
.13429 .31992 Mdot
.13619 .43417 Mdot
.1381 .27274 Mdot
.14 .36144 Mdot
.1419 .42815 Mdot
.14381 .36383 Mdot
.14571 .32444 Mdot
.14762 .31299 Mdot
.14952 .37883 Mdot
.15143 .25549 Mdot
.15333 .34207 Mdot
.15524 .34485 Mdot
.15714 .33623 Mdot
.15905 .34372 Mdot
.16095 .3132 Mdot
.16286 .25809 Mdot
.16476 .27154 Mdot
.16667 .36361 Mdot
.16857 .27715 Mdot
.17048 .336 Mdot
.17238 .36657 Mdot
.17429 .38076 Mdot
.17619 .29547 Mdot
.1781 .25819 Mdot
.18 .39985 Mdot
.1819 .29257 Mdot
.18381 .38436 Mdot
.18571 .31621 Mdot
.18762 .33601 Mdot
.18952 .29565 Mdot
.19143 .32383 Mdot
.19333 .29712 Mdot
.19524 .34125 Mdot
.19714 .26484 Mdot
.19905 .453 Mdot
.20095 .27695 Mdot
.20286 .3401 Mdot
.20476 .29422 Mdot
.20667 .46173 Mdot
.20857 .29028 Mdot
.21048 .42013 Mdot
.21238 .32277 Mdot
.21429 .30358 Mdot
.21619 .34348 Mdot
.2181 .26566 Mdot
.22 .23291 Mdot
.2219 .35991 Mdot
.22381 .28671 Mdot
.22571 .37607 Mdot
.22762 .35571 Mdot
.22952 .28562 Mdot
.23143 .27549 Mdot
.23333 .33277 Mdot
.23524 .27064 Mdot
.23714 .30854 Mdot
.23905 .39843 Mdot
.24095 .26227 Mdot
.24286 .22337 Mdot
.24476 .32651 Mdot
.24667 .36593 Mdot
.24857 .36429 Mdot
.25048 .38004 Mdot
.25238 .42459 Mdot
.25429 .37289 Mdot
.25619 .40245 Mdot
.2581 .37873 Mdot
.26 .34225 Mdot
.2619 .33248 Mdot
.26381 .32679 Mdot
.26571 .28029 Mdot
.26762 .46848 Mdot
.26952 .37988 Mdot
.27143 .28236 Mdot
.27333 .40063 Mdot
.27524 .36397 Mdot
.27714 .22546 Mdot
.27905 .26488 Mdot
.28095 .32692 Mdot
.28286 .36767 Mdot
.28476 .42711 Mdot
.28667 .31356 Mdot
.28857 .25683 Mdot
.29048 .28206 Mdot
.29238 .22619 Mdot
.29429 .45478 Mdot
.29619 .26494 Mdot
.2981 .3339 Mdot
.3 .3228 Mdot
.3019 .28616 Mdot
.30381 .33655 Mdot
.30571 .28514 Mdot
.30762 .276 Mdot
.30952 .33566 Mdot
.31143 .38598 Mdot
.31333 .2567 Mdot
.31524 .35474 Mdot
.31714 .35195 Mdot
.31905 .31884 Mdot
.32095 .24128 Mdot
.32286 .4176 Mdot
.32476 .37492 Mdot
.32667 .36429 Mdot
.32857 .42819 Mdot
.33048 .42007 Mdot
.33238 .33028 Mdot
.33429 .38181 Mdot
.33619 .25409 Mdot
.3381 .23422 Mdot
.34 .35057 Mdot
.3419 .33435 Mdot
.34381 .34267 Mdot
.34571 .2668 Mdot
.34762 .34798 Mdot
.34952 .41936 Mdot
.35143 .29775 Mdot
.35333 .26722 Mdot
.35524 .35274 Mdot
.35714 .29526 Mdot
.35905 .26187 Mdot
.36095 .30447 Mdot
.36286 .46425 Mdot
.36476 .24312 Mdot
.36667 .32704 Mdot
.36857 .34382 Mdot
.37048 .40849 Mdot
.37238 .22722 Mdot
.37429 .30315 Mdot
.37619 .27053 Mdot
.3781 .26706 Mdot
.38 .39872 Mdot
.3819 .4681 Mdot
.38381 .40013 Mdot
.38571 .24635 Mdot
.38762 .33753 Mdot
.38952 .37905 Mdot
.39143 .28612 Mdot
.39333 .33458 Mdot
.39524 .41653 Mdot
.39714 .29494 Mdot
.39905 .31033 Mdot
.40095 .22772 Mdot
.40286 .33024 Mdot
.40476 .4354 Mdot
.40667 .37556 Mdot
.40857 .31875 Mdot
.41048 .3215 Mdot
.41238 .30602 Mdot
.41429 .27742 Mdot
.41619 .42336 Mdot
.4181 .35204 Mdot
.42 .31792 Mdot
.4219 .25692 Mdot
.42381 .30606 Mdot
.42571 .29187 Mdot
.42762 .33196 Mdot
.42952 .39455 Mdot
.43143 .36643 Mdot
.43333 .26519 Mdot
.43524 .31888 Mdot
.43714 .33987 Mdot
.43905 .36386 Mdot
.44095 .25787 Mdot
.44286 .26952 Mdot
.44476 .2566 Mdot
.44667 .23132 Mdot
.44857 .365 Mdot
.45048 .43151 Mdot
.45238 .27874 Mdot
.45429 .24289 Mdot
.45619 .3325 Mdot
.4581 .25458 Mdot
.46 .3977 Mdot
.4619 .27035 Mdot
.46381 .22688 Mdot
.46571 .4111 Mdot
.46762 .34372 Mdot
.46952 .29105 Mdot
.47143 .41941 Mdot
.47333 .24615 Mdot
.47524 .34756 Mdot
.47714 .39097 Mdot
.47905 .35028 Mdot
.48095 .37013 Mdot
.48286 .38144 Mdot
.48476 .35788 Mdot
.48667 .42773 Mdot
.48857 .30553 Mdot
.49048 .24044 Mdot
.49238 .34298 Mdot
.49429 .39429 Mdot
.49619 .30505 Mdot
.4981 .41163 Mdot
.5 .2676 Mdot
.5019 .34012 Mdot
.50381 .36688 Mdot
.50571 .30088 Mdot
.50762 .32714 Mdot
.50952 .33409 Mdot
.51143 .41783 Mdot
.51333 .35675 Mdot
.51524 .3532 Mdot
.51714 .35661 Mdot
.51905 .2824 Mdot
.52095 .27359 Mdot
.52286 .42977 Mdot
.52476 .25309 Mdot
.52667 .34733 Mdot
.52857 .23663 Mdot
.53048 .30753 Mdot
.53238 .25238 Mdot
.53429 .29992 Mdot
.53619 .29353 Mdot
.5381 .30148 Mdot
.54 .26862 Mdot
.5419 .3404 Mdot
.54381 .2612 Mdot
.54571 .3607 Mdot
.54762 .25576 Mdot
.54952 .27299 Mdot
.55143 .41652 Mdot
.55333 .29478 Mdot
.55524 .25197 Mdot
.55714 .41898 Mdot
.55905 .32794 Mdot
.56095 .24419 Mdot
.56286 .35811 Mdot
.56476 .27286 Mdot
.56667 .29203 Mdot
.56857 .42763 Mdot
.57048 .24102 Mdot
.57238 .28067 Mdot
.57429 .32086 Mdot
.57619 .25278 Mdot
.5781 .24261 Mdot
.58 .34537 Mdot
.5819 .27446 Mdot
.58381 .46773 Mdot
.58571 .43376 Mdot
.58762 .23608 Mdot
.58952 .43234 Mdot
.59143 .27018 Mdot
.59333 .43588 Mdot
.59524 .40219 Mdot
.59714 .23316 Mdot
.59905 .22976 Mdot
.60095 .32448 Mdot
.60286 .2866 Mdot
.60476 .33199 Mdot
.60667 .36937 Mdot
.60857 .39448 Mdot
.61048 .2523 Mdot
.61238 .29512 Mdot
.61429 .41967 Mdot
.61619 .35183 Mdot
.6181 .29395 Mdot
.62 .39544 Mdot
.6219 .33293 Mdot
.62381 .37825 Mdot
.62571 .37448 Mdot
.62762 .32268 Mdot
.62952 .26999 Mdot
.63143 .37873 Mdot
.63333 .29686 Mdot
.63524 .30273 Mdot
.63714 .22906 Mdot
.63905 .35472 Mdot
.64095 .46432 Mdot
.64286 .34007 Mdot
.64476 .26126 Mdot
.64667 .38507 Mdot
.64857 .38021 Mdot
.65048 .25708 Mdot
.65238 .31275 Mdot
.65429 .27672 Mdot
.65619 .34698 Mdot
.6581 .24312 Mdot
.66 .41473 Mdot
.6619 .29668 Mdot
.66381 .40174 Mdot
.66571 .27587 Mdot
.66762 .30458 Mdot
.66952 .39914 Mdot
.67143 .28352 Mdot
.67333 .34978 Mdot
.67524 .33019 Mdot
.67714 .26897 Mdot
.67905 .36079 Mdot
.68095 .35176 Mdot
.68286 .39373 Mdot
.68476 .32353 Mdot
.68667 .33266 Mdot
.68857 .34348 Mdot
.69048 .30428 Mdot
.69238 .40337 Mdot
.69429 .25944 Mdot
.69619 .35361 Mdot
.6981 .45426 Mdot
.7 .23367 Mdot
.7019 .43675 Mdot
.70381 .25781 Mdot
.70571 .30047 Mdot
.70762 .3714 Mdot
.70952 .29014 Mdot
.71143 .24653 Mdot
.71333 .23419 Mdot
.71524 .46772 Mdot
.71714 .23743 Mdot
.71905 .22555 Mdot
.72095 .23156 Mdot
.72286 .26938 Mdot
.72476 .28413 Mdot
.72667 .25154 Mdot
.72857 .22613 Mdot
.73048 .26976 Mdot
.73238 .27825 Mdot
.73429 .29729 Mdot
.73619 .35144 Mdot
.7381 .25381 Mdot
.74 .33702 Mdot
.7419 .41507 Mdot
.74381 .36855 Mdot
.74571 .43297 Mdot
.74762 .40137 Mdot
.74952 .40062 Mdot
.75143 .43615 Mdot
.75333 .40183 Mdot
.75524 .24194 Mdot
.75714 .24107 Mdot
.75905 .42841 Mdot
.76095 .23995 Mdot
.76286 .32097 Mdot
.76476 .32494 Mdot
.76667 .28987 Mdot
.76857 .27372 Mdot
.77048 .22943 Mdot
.77238 .33282 Mdot
.77429 .31036 Mdot
.77619 .26289 Mdot
.7781 .36676 Mdot
.78 .35088 Mdot
.7819 .41896 Mdot
.78381 .26885 Mdot
.78571 .41231 Mdot
.78762 .22893 Mdot
.78952 .35754 Mdot
.79143 .37501 Mdot
.79333 .36624 Mdot
.79524 .26526 Mdot
.79714 .25313 Mdot
.79905 .31609 Mdot
.80095 .24932 Mdot
.80286 .23338 Mdot
.80476 .34624 Mdot
.80667 .2608 Mdot
.80857 .35143 Mdot
.81048 .32437 Mdot
.81238 .34775 Mdot
.81429 .335 Mdot
.81619 .23382 Mdot
.8181 .2719 Mdot
.82 .35417 Mdot
.8219 .29651 Mdot
.82381 .31795 Mdot
.82571 .36553 Mdot
.82762 .35346 Mdot
.82952 .32359 Mdot
.83143 .39448 Mdot
.83333 .28492 Mdot
.83524 .29477 Mdot
.83714 .38142 Mdot
.83905 .35576 Mdot
.84095 .24283 Mdot
.84286 .34393 Mdot
.84476 .3517 Mdot
.84667 .33015 Mdot
.84857 .45607 Mdot
.85048 .37654 Mdot
.85238 .22024 Mdot
.85429 .35462 Mdot
.85619 .33132 Mdot
.8581 .38402 Mdot
.86 .22631 Mdot
.8619 .33039 Mdot
.86381 .40278 Mdot
.86571 .35438 Mdot
.86762 .25951 Mdot
.86952 .29323 Mdot
.87143 .25455 Mdot
.87333 .23763 Mdot
.87524 .31236 Mdot
.87714 .44414 Mdot
.87905 .27743 Mdot
.88095 .37853 Mdot
.88286 .38329 Mdot
.88476 .30932 Mdot
.88667 .32378 Mdot
.88857 .27948 Mdot
.89048 .26989 Mdot
.89238 .31494 Mdot
.89429 .37277 Mdot
.89619 .39464 Mdot
.8981 .28318 Mdot
.9 .26992 Mdot
.9019 .29389 Mdot
.90381 .34685 Mdot
.90571 .47019 Mdot
.90762 .25937 Mdot
.90952 .2401 Mdot
.91143 .29996 Mdot
.91333 .29429 Mdot
.91524 .43631 Mdot
.91714 .3421 Mdot
.91905 .30329 Mdot
.92095 .30125 Mdot
.92286 .34487 Mdot
.92476 .30224 Mdot
.92667 .35472 Mdot
.92857 .37096 Mdot
.93048 .42909 Mdot
.93238 .33003 Mdot
.93429 .27483 Mdot
.93619 .35708 Mdot
.9381 .29041 Mdot
.94 .28766 Mdot
.9419 .3414 Mdot
.94381 .37254 Mdot
.94571 .33218 Mdot
.94762 .32727 Mdot
.94952 .36191 Mdot
.95143 .37692 Mdot
.95333 .28113 Mdot
.95524 .2846 Mdot
.95714 .34076 Mdot
.95905 .32183 Mdot
.96095 .26696 Mdot
.96286 .2191 Mdot
.96476 .26677 Mdot
.96667 .40033 Mdot
.96857 .42977 Mdot
.97048 .23511 Mdot
.97238 .34043 Mdot
.97429 .32646 Mdot
.97619 .22513 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo2?ooool2o`00027ooooo0_l0000@ooooo`001_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool0@oooool2o`000<;ooooo0_l0000Qooooo`;o00004?ooool0
00Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`05ooooo`;o00003_oo
ool2o`0002cooooo0_l00009ooooo`;o00000oooool2o`0001Oooooo0_l00008ooooo`;o00004_oo
ool2o`00053ooooo0_l000000ooooooo0000o`00000Xooooo`;o00009?ooool2o`0000_ooooo0004
o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`;o00003_ooool2o`0003Oooooo0_l0
0003ooooo`;o00005oooool2o`0000Sooooo0_l0000Booooo`;o0000:Oooool2o`0000[ooooo0_l0
000Iooooo`;o000000?oooooo`000?l000002oooool2o`0000Cooooo0_l0000Eooooo`;o00009?oo
ool2o`0000_ooooo0006ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^
kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00004ooooo`;o0000=Oooool2o`0004Oooooo0_l0
000_ooooo`;o00002_ooool2o`0001?ooooo0_l00004ooooo`;o00003_ooool2o`0000Cooooo0_l0
0003ooooo`;o00000_ooool2o`0003oooooo0006ooooo`05o`000?ooooooooooooooool000003_oo
ool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`04ooooo`;o0000=Oooool2o`0002Cooooo0_l0000Qooooo`;o00006Oooool2o`00017ooooo
0_l000000ooooooo0000o`00000Oooooo`;o00000_ooool4o`0001Wooooo0_l00002ooooo`;o0000
<?ooool2o`0000gooooo0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0HOooool2o`0003cooooo
0_l0000Aooooo`;o00009_ooool3o`0000cooooo0_l0000Rooooo`;o00002_ooool2o`0001;ooooo
0_l0000=ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo
V9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0G?ooool2o`0000co
oooo0_l0000Kooooo`;o00002Oooool2o`0001Sooooo1?l0000Hooooo`;o00004Oooool2o`0000[o
oooo1?l0000Hooooo`;o00002?ooool2o`0000[ooooo0_l0000Qooooo`001_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0
003oooooooooo`1Looooo`;o00003?ooool2o`0000Gooooo0_l0000Dooooo`;o00001?ooool2o`00
00?ooooo0_l0000Eooooo`;o000000?oooooo`000?l000000_l0000Hooooo`;o00003oooool2o`00
00cooooo0ol0000Iooooo`;o0000=oooool002Wooooo0_l0000Cooooo`;o0000GOooool2o`0001[o
oooo0_l0000Jooooo`;o0000;_ooool2o`0001_ooooo0_l00014ooooo`00:Oooool00ol0003ooooo
ooooo`0Booooo`;o0000S?ooool2o`0000Gooooo0_l00005ooooo`;o00002Oooool2o`0002?ooooo
0_l0000Fooooo`;o0000A?ooool002Wooooo00?o0000ooooooooool09Oooool2o`0003[ooooo0_l0
000Uooooo`;o00004oooool2o`000003ooooool0003o000000?ooooo1?l00005ooooo`;o00002Ooo
ool2o`0002?ooooo0_l00002ooooo`;o00004Oooool2o`0001Kooooo0_l0000]ooooo`00:Oooool0
0ol0003oooooooooo`02ooooo`;o00008Oooool2o`0000;ooooo0_l00003ooooo`;o00008Oooool2
o`0000Kooooo0_l00006ooooo`;o00006Oooool2o`0000Cooooo1?l00002ooooo`;o00004oooool2
o`0000Kooooo0_l0000Oooooo`;o00003oooool2o`0000Wooooo0_l0000Aooooo`;o00005_ooool2
o`0002gooooo000Yooooo`03o`000?oooooooooo00;ooooo0_l00008ooooo`;o00001oooool2o`00
01;ooooo0_l00003ooooo`;o00008Oooool2o`0000Kooooo0_l0000=ooooo`;o00004_ooool2o`00
00Cooooo1?l0000Mooooo`;o00007oooool4o`0000cooooo0_l000000ooooooo0000o`00000Ooooo
o`;o00004_ooool2o`0000[ooooo0_l0000Rooooo`00:Oooool2o`0000gooooo0_l00007ooooo`;o
00002?ooool2o`0001?ooooo0_l0000<ooooo`;o00002_ooool2o`0000Cooooo0_l0000Booooo`;o
00005_ooool2o`00027ooooo0_l0000Oooooo`;o00003_ooool2o`0001Sooooo0_l00004ooooo`;o
00000_ooool2o`0001;ooooo0_l0000:ooooo`;o00008_ooool002Wooooo00?o0000ooooooooool0
7oooool2o`0001?ooooo0_l00005ooooo`;o00001Oooool2o`0000[ooooo0_l00004ooooo`;o0000
3_ooool4o`0000Kooooo0_l0000@ooooo`;o00004oooool2o`0005Oooooo0_l00004ooooo`;o0000
=?ooool3o`0000oooooo000Yooooo`04o`000?ooooooooooooooo`;o00005oooool2o`0001Cooooo
1?l000001ol@413oooooooooooo^k^ko<S8bo`000?lb<S800_l00002ooooo`05onk^k_l0003o0000
oc8b<_o^k^h08?ooool4o`0000Gooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01_o^k^ko<S8bo`000?lb<S;ok^k^ooooo`;o00001?ooool2o`0000[ooooo0_l0000;ooooo`;o
00001_ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^o`000?l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_l0000=ooooo`;o00003Oooool4o`0000Sooooo0_l0
00001_l@413oooooooooooooooook^k^oc8b<P;o000000Wok^k^ooooooooooooooooonk^k_lb<S;o
0000oc8b<_o^k^h05oooool2o`000003ooooool0003o000000gooooo00GoA4A4o`000?l0003o<S8b
omgMg@03o`000004oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`00:Oooool00ol0003oooooooooo`03o`0001Oooooo0_l00005ooooo`;o00001oooool2o`0000Ko
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgo`00
0?l0003oV9RHogMgM`0Yooooo`05oiRHV?l0003o0000oooooom4A4@00oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00KoMgMgoiRHV?ooooooV9RHogMgMoooool2o`0000Cooooo0_l0000Aoooo
o`;o00001?ooool2o`000003ooooool0003o000000?ooooo0_l000001?ooooooMgMgoc8b<_ooool2
o`000005ogMgMol0003o0000oiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00;o0000
3Oooool2o`0000gooooo1?l00009ooooo`07o`000?oooooo0000o`000?ooooooMgMgoiRHV002o`00
0009ogMgMooooooooooooooooomgMgOoV9RHoooooonHV9SoMgMg00;o00005Oooool2o`000003oooo
ool0003o0000013ooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000Yooooo`03o`000?oooooooooo00;o00007oooool2
o`0000Oooooo0ol00005ooooo`03o`000?oooooooooo00;o000000Go410@oooooooooooooooooa0@
4003ooooo`;o00000_ooool00ol@413oooooooooo`0Booooo`;o00005?ooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@41000_l000000ooooooo410@ooooo`02ooooo`03oa0@
4?oooooooooo01Sooooo0_l00007ooooo`;o00000oooool2o`0000;ooooo00Go0000ooooool0003o
0000oa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`06oooo
o`;o00000_ooool2o`0001[ooooo1ol000000ooooooo410@ooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41000oooool00ol@413o0000o`00000Aooooo`;o00004?ooool2o`0000Kooooo00Co0000
oooooooooooo410@0oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0
0Oooool002Wooooo0_l0000/ooooo`;o00001Oooool00ol0003oooooooooo`03o`0000?ooooo00Co
0000oooooooooooooooo0_l00002ooooo`03o`000?oooooooooo00Cooooo0_l0000<ooooo`;o0000
5Oooool00onHV9So8B4Qonk^kP03ooooo`04o`000?ooooooooooooooo`?o000000?oooooo`000?oo
ool00_ooool00ol0003oooooooooo`02ooooo`;o00009Oooool2o`0000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool2o`0000;ooooo0_l0000C
ooooo`;o00001Oooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000001?ooooo0_l000000ooooooo0000o`00000=ooooo`;o
00001Oooool01OmgMgOo<S8boooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo007ooooo000Yooooo`03o`000?oooooooooo01Wooooo0_l0000Goooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000001_ooool4o`0000Cooooo0_l0000Looooo`03ogMgMomVIVKooooo00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001?ooool2o`0001Co
oooo0_l0000>ooooo`03oa0@4?l0003o000000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000003_ooool2o`00017ooooo0_l00005ooooo`04omgMgOmEEEGo
ooooo`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00005_ooool2o`000003ooooool0003o000000kooooo00Go0000ob4Q8Ol0003o0000olc<c002oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo000Y
ooooo`04o`000?oooooo0000o`0001Sooooo0_l0000Gooooo`03o`000?oooooooooo00;ooooo00Ko
410@oooooooooooooooooa0@4?ooool3o`0000?ooooo00?o410@ooooooooool01_ooool2o`0000Co
oooo0_l00002ooooo`?o00006?ooool3o`000003ooooool@413ooooo00;ooooo00Go410@oooooooo
oooooooooa0@4003ooooo`03oa0@4?oooooooooo01Sooooo0_l0000?ooooo`03okZj^_lQ8B7ooooo
00;ooooo00Co410@oooooooooooooooo0_l00002ooooo`05oa0@4?ooooooooooooooool@41003_oo
ool2o`0000oooooo0_l00008ooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooo
oa0@4003ooooo`05oa0@4?ooooooooooooooool@41001Oooool2o`0001;ooooo0_l0000>ooooo`03
o`000?oooooo000000;o00000_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooo
oooooooooooooa0@4003ooooo`00:Oooool01?l0003oooooo`000?l0000Gooooo`;o00006?ooool0
0ol0003oooooooooo`02ooooo`06ogMgMonHV9SooooooiRHV?mgMgOooooo0ol000001?nHV9Sooooo
oiRHV?mgMgLBooooo`?o00005?ooool01Ol0003o^[ZjoooooonHV9So410@00;o000000KoooooogMg
MonHV9SooooooiRHV?mgMgL3ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:?ooool01Ol@413oV9RH
oooooonj^[[o000000?ooooo00CoMgMgoiRHV?ooooooV9RH0_l00002ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL06_ooool2o`0000?ooooo0_l00008ooooo`03onk^k_m4A4Co000000;o00000_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o0000
8?ooool3o`0000;ooooo0_l00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo000Yooooo`04o`000?ooooooooooooooo`;o00005Oooool2o`00
01Gooooo0_l000000omVIVKo0000ooooo`03ooooo`05onk^k_l0003o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^02Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool3o`000003oc8b<_o^k^kooooo00Wooooo0_l0000Looooo`05
ojVYZOl0003o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0Jooooo`;o00003_ooool01?mgMgOo0000o`000?l00002ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^013ooooo0_l0000Doooo
o`Oo00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`00:Oooool2o`0000;ooooo0_l00002ooooo`;o00009_ooool4o`000003ooooool0003o
000000;ooooo1?l0000]ooooo`;o00002oooool2o`0000Oooooo0_l0000=ooooo`;o00004oooool2
o`0000Cooooo0_l00002ooooo`;o00003Oooool3o`0004Cooooo0_l00009ooooo`;o00002Oooool2
o`000003ooooool0003o000000Kooooo0_l0000Hooooo`00:Oooool00ol0003oooooooooo`05oooo
o`;o00009_ooool2o`0000?ooooo0ol000000ooooooo0000o`00000^ooooo`?o00002oooool2o`00
02_ooooo0_l00004ooooo`;o00004Oooool3o`0000?ooooo0_l00007ooooo`;o00005_ooool2o`00
01[ooooo0_l00002ooooo`;o00005?ooool2o`000003ooooool0003o0000023ooooo000Yooooo`03
o`000?oooooooooo03?ooooo0_l0000aooooo`;o0000;oooool2o`0000Oooooo1?l0000Looooo`;o
00001oooool2o`0000gooooo0_l00007ooooo`;o00006_ooool2o`0001_ooooo0_l000001?oooooo
0000o`000?l0000Looooo`00:Oooool00ol0003oooooooooo`0jooooo`;o0000;Oooool2o`0000;o
oooo0_l0000Sooooo`Co000000?oooooo`000?l000001oooool4o`0001gooooo0_l00008ooooo`;o
00001_ooool2o`0000?ooooo0_l00010ooooo`Ko00007?ooool002Wooooo0ol0000jooooo`;o0000
1Oooool2o`0002Kooooo0_l00002ooooo`;o00002_ooool2o`0000;ooooo0_l0000Cooooo`Co0000
2Oooool2o`00023ooooo0_l00008ooooo`;o00001_ooool2o`0004Oooooo0_l0000Nooooo`008Ooo
ooooo`0004Co00001?ooool002Wooooo00Co0000ooooool0003o00001oooool3o`0000Gooooo0_l0
0004ooooo`03o`000?oooooooooo00Wooooo00Co0000ooooool0003o00000_ooool2o`0000Cooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo
0ol0000;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool2o`000003oooo
ool0003ooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00;ooooo0_l00005ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`05ooooo`;o00000_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool00_l000001?oooooo0000o`000?ooool2o`000003
ooooool0003ooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`00
:Oooool01?l0003oooooo`000?l00007ooooo`;o00006_ooool2o`0000;ooooo0_l00006ooooo`;o
00002?ooool00ol0003oooooooooo`0Dooooo`;o00009Oooool01?l0003oooooooooooooool2o`00
03Oooooo00?o0000ooooooooool03_ooool2o`0002[ooooo00Co0000oooooooooooooooo0_l00006
ooooo`;o00003_ooool2o`0000Cooooo0_l0000Iooooo`03o`000?oooooooooo00[ooooo000Yoooo
o`03o`000?oooooooooo023ooooo0_l0000>ooooo`;o0000:Oooool2o`0001_ooooo0_l00002oooo
o`;o00000oooool2o`0002[ooooo0_l0000kooooo`;o00002_ooool2o`0000Kooooo0_l0000loooo
o`00:Oooool2o`0000Sooooo0_l00004ooooo`;o00004Oooool2o`00013ooooo0_l00005ooooo`;o
00006_ooool2o`0000Cooooo0_l0000Kooooo`?o00001_ooool2o`0002[ooooo0_l0000?ooooo`;o
00004Oooool2o`0001Oooooo0_l0000=ooooo`;o00001?ooool2o`00017ooooo0_l0000Eooooo`;o
00004Oooool002Wooooo0_l00004ooooo`;o00000_ooool2o`0000Cooooo0_l0000Dooooo`;o0000
3Oooool2o`0000Gooooo0_l00008ooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`;o0000
5?ooool2o`0000cooooo0_l0000Mooooo`;o00007?ooool2o`0000Kooooo0_l0000Aooooo`;o0000
6?ooool2o`0000cooooo0_l00004ooooo`;o00004Oooool2o`00017ooooo0_l00002ooooo`;o0000
0oooool2o`0000cooooo000Yooooo`03o`000?oooooooooo00?ooooo0_l0000Fooooo`;o00001_oo
ool2o`0001kooooo0_l00004ooooo`;o00001?ooool2o`0000kooooo0_l0000:ooooo`;o00002Ooo
ool2o`00023ooooo0_l0000>ooooo`;o00003?ooool2o`0001Kooooo0_l0000Kooooo`;o00006?oo
ool2o`0000?ooooo0_l0000Dooooo`;o00000oooool2o`0000Oooooo0_l0000<ooooo`00:Oooool0
0ol0003oooooooooo`0Kooooo`;o00008oooool2o`0000Oooooo0_l0000Dooooo`;o00005Oooool2
o`0000Kooooo0_l00007ooooo`;o00007oooool2o`0000gooooo0_l00004ooooo`;o00003oooool2
o`000003ooooool0003o000001[ooooo0_l0000Fooooo`;o000000?oooooo`000?l000000_l0000D
ooooo`;o00000oooool2o`0001Gooooo000Yooooo`03o`000?oooooooooo00kooooo0ol0000<oooo
o`;o00002?ooool2o`0000;ooooo0_l00004ooooo`;o00003Oooool2o`0000Oooooo0_l00009oooo
o`Ko00002Oooool2o`0000kooooo0_l00009ooooo`;o00001oooool2o`0000oooooo0_l0000Moooo
o`;o00001?ooool2o`0001;ooooo0_l0000Jooooo`;o00002oooool2o`0000cooooo0_l0000Koooo
o`;o00005Oooool002Wooooo00?o0000ooooooooool01_ooool2o`0000Kooooo0ol0000<ooooo`;o
00002?ooool2o`0000;ooooo0_l00004ooooo`;o00008Oooool6o`0000Wooooo0_l0000<ooooo`Co
00003?ooool2o`0001Gooooo0_l00019ooooo`;o00005Oooool2o`00043ooooo000Yooooo`;o0000
1oooool2o`0001kooooo0_l0000;ooooo`;o000000?oooooo`000?l000004?ooool2o`0001Wooooo
0_l0000<ooooo`;o00003_ooool2o`00013ooooo0_l000000ooooooo0000o`00000;ooooo`;o0000
7_ooool2o`0001kooooo0_l0000gooooo`;o00001Oooool2o`0000?ooooo0_l00003ooooo`;o0000
3Oooool002Wooooo00?o0000ooooooooool05?ooool2o`000003ooooool0003o000000gooooo1?l0
0009ooooo`;o000000?oooooo`000?l000000_ooool2o`0000cooooo0_l0000Iooooo`;o00001_oo
ool2o`0001kooooo0_l00006ooooo`;o000000?oooooo`000?l000002oooool2o`0000[ooooo0_l0
000Booooo`;o00003Oooool2o`00033ooooo0_l0000Fooooo`?o00001?ooool2o`0000?ooooo0_l0
0003ooooo`;o00003Oooool002Wooooo00?o0000ooooooooool03Oooool2o`0000Gooooo0_l00000
0ooooooo0000o`00000>ooooo`?o00004?ooool2o`0002Sooooo0_l00005ooooo`;o00007_ooool4
o`0000oooooo0_l0000?ooooo`;o00005oooool2o`0000Sooooo0_l0000Sooooo`;o000000?ooooo
o`000?l000002?ooool2o`00017ooooo0_l00004ooooo`;o00007Oooool002Wooooo00?o0000oooo
ooooool03Oooool2o`0000Sooooo0_l00012ooooo`;o00001Oooool4o`0001Gooooo0_l0000@oooo
o`Co00003Oooool2o`0001_ooooo0_l0000;ooooo`;o00000oooool2o`000003ooooool0003o0000
00oooooo0_l0000<ooooo`;o00001_ooool5o`0000Sooooo0_l0000Aooooo`;o00008oooool002Wo
oooo00?o0000ooooooooool02oooool2o`0004gooooo0ol00005ooooo`;o00000oooool2o`0001;o
oooo0_l0000Booooo`;o00002Oooool2o`0001oooooo0_l00005ooooo`;o00002Oooool2o`000003
ooooool0003o000000;ooooo0_l0000;ooooo`;o00003?ooool2o`0000Sooooo0_l000001?oooooo
0000o`000?ooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o00004_ooool2o`00
01_ooooo000Yooooo`;o00003?ooool2o`0000_ooooo0_l0000Tooooo`;o00006_ooool2o`0000_o
oooo0_l0000Wooooo`;o00002?ooool3o`0000gooooo0_l0000Fooooo`;o00004?ooool2o`0001co
oooo0_l00008ooooo`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00000_ooool2o`00
01;ooooo0_l000000ooooooo0000o`00000Hooooo`00:Oooool00ol0003oooooooooo`09ooooo`;o
000000?oooooo`000?l000001_ooool2o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l0
00006?ooool4o`00053ooooo0_l00008ooooo`?o00001oooool2o`0000Cooooo0_l0000Sooooo`;o
00008Oooool2o`0000kooooo0_l0000Nooooo`;o00006?ooool002Wooooo00?o0000ooooooooool0
2Oooool2o`000003ooooool0003o000000Kooooo0_l00009ooooo`;o000000Coooooo`000?l0003o
00001Oooool2o`00013ooooo0_l00007ooooo`;o00001_ooool2o`0000oooooo0_l0000Rooooo`;o
00008?ooool2o`0002Wooooo0_l0001Eooooo`;o00005?ooool002Wooooo00?o0000ooooooooool0
1oooool2o`0001Gooooo0_l00003ooooo`;o00001Oooool4o`0001Kooooo0ol00006ooooo`;o0000
00?oooooo`000?l000003?ooool2o`0001oooooo0_l000001?oooooo0000o`000?ooool2o`00013o
oooo0_l0001Fooooo`;o00000oooool2o`0000Sooooo0_l0000Vooooo`;o00005?ooool002Wooooo
00?o0000ooooooooool01oooool2o`0001Cooooo0ol0000<ooooo`;o00005_ooool2o`0000[ooooo
0_l0000]ooooo`;o00001?ooool2o`0000Sooooo0_l00006ooooo`;o00007oooool2o`0002[ooooo
0_l00009ooooo`;o00000oooool2o`0000Sooooo0_l0000Oooooo`;o00006oooool002Wooooo0_l0
0005ooooo`;o00002oooool2o`0000[ooooo0_l0000Wooooo`;o0000Aoooool2o`0002Oooooo0_l0
000Nooooo`;o00002_ooool2o`0002kooooo0_l00009ooooo`;o00000oooool2o`0001Kooooo000Y
ooooo`03o`000?oooooooooo00Cooooo0_l0000;ooooo`;o0000:_ooool2o`0000Oooooo0_l0000E
ooooo`;o00006?ooool2o`0004Gooooo0_l0000Hooooo`;o00006Oooool2o`00017ooooo0_l0000<
ooooo`;o00003_ooool2o`000003ooooool0003o000001?ooooo0006ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`0Uooooo`;o00005_ooool2o`0000Kooooo0_l000001?oooooo0000o`00
0?ooool2o`00013ooooo0_l0000Cooooo`;o00000oooool2o`0004Cooooo1Ol00003ooooo`;o0000
;?ooool2o`00017ooooo0_l00008ooooo`;o00005Oooool2o`0001?ooooo0006ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool04_ooool2o`0000;ooooo0_l0000=ooooo`;o
00001_ooool2o`0001Kooooo0_l000001?oooooo0000o`000?ooool2o`0001?ooooo0_l0000@oooo
o`;o00007?ooool2o`0002_ooooo0_l000000ooooooo0000o`000003ooooo`;o0000>oooool2o`00
00cooooo0_l0000Zooooo`001_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q
8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01;ooooo0_l00002oooo
o`;o00005Oooool2o`000003ooooool0003o000002Oooooo0_l00005ooooo`;o0000;_ooool2o`00
03?ooooo0_l0000kooooo`;o00001Oooool2o`0000Gooooo0_l0000Zooooo`001_ooool01Ol0003o
oooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04oooo
o`?o0000<?ooool2o`0002Oooooo0_l0001Zooooo`;o0000@_ooool2o`00037ooooo0006ooooo`05
o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01Oooool00ol0003oooooooooo`2>ooooo`;o0000[?ooool000Kooooo00Go410@oooo
oooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`02ooooo`;o00006?ooool2o`00067ooooo0_l0000=ooooo`;o00001?ooool2
o`0002;ooooo0_l00002ooooo`;o00004_ooool2o`0002kooooo0_l0000Cooooo`;o00009Oooool0
00Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo0_l0000<ooooo`;o00002_oo
ool2o`0002?ooooo0_l0000/ooooo`;o00003_ooool2o`0000Sooooo0_l00009ooooo`;o00008_oo
ool2o`0000;ooooo0_l0000Booooo`;o0000;_ooool2o`0001?ooooo0_l0000Uooooo`001_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co0000
1_ooool2o`0000_ooooo0_l00003ooooo`?o00007?ooool2o`00017ooooo0_l0000:ooooo`;o0000
8?ooool3o`0001Oooooo0_l0000oooooo`Co00005oooool4o`0004;ooooo0_l0000?ooooo`00:Ooo
ool2o`0000_ooooo0_l00003ooooo`;o00007Oooool2o`0001Oooooo0_l00004ooooo`;o00008Ooo
ool2o`0004;ooooo0_l0000Dooooo`Co00001Oooool2o`00013ooooo1?l0000Qooooo`;o00007ooo
ool2o`0000oooooo000Yooooo`03o`000?oooooooooo00[ooooo0_l0000kooooo`;o0000Joooool2
o`0001gooooo0_l0000eooooo`;o0000<?ooool002Wooooo00?o0000ooooooooool02_ooool2o`00
063ooooo0_l0000Looooo`;o0000/?ooool002Wooooo00?o0000ooooooooool0K?ooool2o`0001co
oooo0_l00009ooooo`;o0000F_ooool2o`0004Wooooo000Yooooo`03o`000?oooooooooo05cooooo
0_l0000Fooooo`;o00007oooool2o`0000oooooo0_l0000Qooooo`;o00006?ooool2o`0000cooooo
0_l00019ooooo`00:Oooool2o`0003Wooooo0_l0000Rooooo`;o000000?oooooo`000?l000001?oo
ool2o`0000gooooo0_l0000Fooooo`;o00002oooool2o`0000_ooooo1?l0000@ooooo`;o00003Ooo
ool2o`0001Sooooo0_l0000;ooooo`;o0000B_ooool002Wooooo00?o0000ooooooooool06_ooool4
o`0001[ooooo0_l0000Uooooo`;o00001?ooool2o`0001?ooooo0_l0000@ooooo`;o00002oooool2
o`0000gooooo0_l0000@ooooo`;o0000=?ooool2o`0004[ooooo000Yooooo`03o`000?oooooooooo
01[ooooo1?l0000Xooooo`;o0000<_ooool2o`000<3ooooo000Yooooo`03o`000?oooooooooo01?o
oooo0_l0000=ooooo`;o00008_ooool2o`0000Sooooo0_l0000<ooooo`;o0000<Oooool2o`0000[o
oooo0_l0000<ooooo`;o0000??ooool2o`0003Gooooo0_l0000:ooooo`;o00003_ooool002Wooooo
00?o0000ooooooooool04oooool2o`0000gooooo0_l0000/ooooo`;o00003?ooool2o`0002Gooooo
0_l0000:ooooo`;o00002_ooool2o`0000cooooo0_l00005ooooo`;o0000<?ooool2o`0000?ooooo
0_l0000eooooo`;o00002_ooool2o`0000kooooo000Yooooo`;o00008Oooool2o`0005Gooooo0_l0
000<ooooo`;o0000:_ooool4o`0002oooooo1?l0000cooooo`;o00007oooool002Wooooo00?o0000
ooooooooool08?ooool2o`0005Gooooo0_l0000hooooo`Co00008Oooool2o`0000kooooo0_l0000c
ooooo`;o00007oooool002Wooooo00?o0000ooooooooool0e_ooool2o`0006Cooooo000Yooooo`03
o`000?oooooooooo0?oooooo4?ooool2o`0002_ooooo000Yooooo`03o`000?oooooooooo0?oooooo
4?ooool2o`0002_ooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`0e
ooooo`;o00007?ooool2o`00083ooooo0_l0001Uooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooooooo
o`0eooooo`;o00007?ooool2o`00083ooooo0_l0000^ooooo`;o0000=Oooool000kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0?oooooo1_ooool2o`0003Gooooo000>ooooo`05oa0@4?ooooooooooooooool@41004?oo
ool00ol0003oooooooooo`03ooooo`?o0000=oooool2o`00033ooooo0_l0001Hooooo`;o0000Mooo
ool000kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0=oooool2o`00033ooooo0_l0001Hooooo`;o0000Moooool000kooooo00Go0000
ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`1;ooooo`;o00008_ooool2o`0003oooooo0_l0000Yooooo`;o0000>oooool2o`0002;ooooo
000>ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo04_ooooo0_l0000Rooooo`;o0000?oooool2o`0002Wooooo0_l0000kooooo`;o0000
8_ooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
00Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocgooooo0006
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@
oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00ooo
ool3o`000?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooo
oooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006
ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?oo
ooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co
00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000O
ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3oooooocgooooo000Qoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003o
ooooooooo`05ooooo`?o0000oooooolmooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Oooooo`03oeEEEOmVIVKo00000?oo
ooooAoooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .24165 Mdot
.02762 .3561 Mdot
.02952 .30673 Mdot
.03143 .26127 Mdot
.03333 .25281 Mdot
.03524 .35619 Mdot
.03714 .27091 Mdot
.03905 .37839 Mdot
.04095 .43636 Mdot
.04286 .29299 Mdot
.04476 .26332 Mdot
.04667 .33518 Mdot
.04857 .41172 Mdot
.05048 .25452 Mdot
.05238 .31973 Mdot
.05429 .33747 Mdot
.05619 .24849 Mdot
.0581 .4107 Mdot
.06 .35499 Mdot
.0619 .23137 Mdot
.06381 .40735 Mdot
.06571 .39308 Mdot
.06762 .40085 Mdot
.06952 .40687 Mdot
.07143 .24293 Mdot
.07333 .3688 Mdot
.07524 .30145 Mdot
.07714 .35594 Mdot
.07905 .23912 Mdot
.08095 .36101 Mdot
.08286 .39769 Mdot
.08476 .43786 Mdot
.08667 .40108 Mdot
.08857 .31571 Mdot
.09048 .37405 Mdot
.09238 .26256 Mdot
.09429 .38642 Mdot
.09619 .35096 Mdot
.0981 .26004 Mdot
.1 .31847 Mdot
.1019 .2416 Mdot
.10381 .352 Mdot
.10571 .38679 Mdot
.10762 .25429 Mdot
.10952 .24115 Mdot
.11143 .29756 Mdot
.11333 .25971 Mdot
.11524 .43876 Mdot
.11714 .34378 Mdot
.11905 .23588 Mdot
.12095 .43741 Mdot
.12286 .30931 Mdot
.12476 .43219 Mdot
.12667 .38524 Mdot
.12857 .38841 Mdot
.13048 .42505 Mdot
.13238 .37195 Mdot
.13429 .24738 Mdot
.13619 .42355 Mdot
.1381 .24853 Mdot
.14 .31332 Mdot
.1419 .34424 Mdot
.14381 .2655 Mdot
.14571 .33433 Mdot
.14762 .40169 Mdot
.14952 .43344 Mdot
.15143 .30224 Mdot
.15333 .32658 Mdot
.15524 .3533 Mdot
.15714 .39949 Mdot
.15905 .26409 Mdot
.16095 .3195 Mdot
.16286 .28759 Mdot
.16476 .33028 Mdot
.16667 .26524 Mdot
.16857 .28554 Mdot
.17048 .43194 Mdot
.17238 .34292 Mdot
.17429 .28769 Mdot
.17619 .35707 Mdot
.1781 .35362 Mdot
.18 .35541 Mdot
.1819 .26018 Mdot
.18381 .35839 Mdot
.18571 .40584 Mdot
.18762 .34288 Mdot
.18952 .25025 Mdot
.19143 .25587 Mdot
.19333 .24501 Mdot
.19524 .32933 Mdot
.19714 .2394 Mdot
.19905 .47378 Mdot
.20095 .32836 Mdot
.20286 .27047 Mdot
.20476 .33491 Mdot
.20667 .47179 Mdot
.20857 .25598 Mdot
.21048 .43609 Mdot
.21238 .42438 Mdot
.21429 .24408 Mdot
.21619 .25493 Mdot
.2181 .26039 Mdot
.22 .33692 Mdot
.2219 .27299 Mdot
.22381 .37462 Mdot
.22571 .3289 Mdot
.22762 .28129 Mdot
.22952 .34586 Mdot
.23143 .32752 Mdot
.23333 .39766 Mdot
.23524 .26767 Mdot
.23714 .25929 Mdot
.23905 .438 Mdot
.24095 .2488 Mdot
.24286 .27824 Mdot
.24476 .31681 Mdot
.24667 .33052 Mdot
.24857 .42936 Mdot
.25048 .43485 Mdot
.25238 .37775 Mdot
.25429 .41136 Mdot
.25619 .30073 Mdot
.2581 .40806 Mdot
.26 .24284 Mdot
.2619 .39775 Mdot
.26381 .27222 Mdot
.26571 .2379 Mdot
.26762 .46278 Mdot
.26952 .31006 Mdot
.27143 .32482 Mdot
.27333 .40188 Mdot
.27524 .28051 Mdot
.27714 .30623 Mdot
.27905 .35 Mdot
.28095 .38106 Mdot
.28286 .26816 Mdot
.28476 .37676 Mdot
.28667 .2321 Mdot
.28857 .29198 Mdot
.29048 .38451 Mdot
.29238 .3126 Mdot
.29429 .3994 Mdot
.29619 .28064 Mdot
.2981 .35721 Mdot
.3 .24881 Mdot
.3019 .23517 Mdot
.30381 .41652 Mdot
.30571 .22003 Mdot
.30762 .33935 Mdot
.30952 .26591 Mdot
.31143 .27499 Mdot
.31333 .2702 Mdot
.31524 .3368 Mdot
.31714 .40623 Mdot
.31905 .31362 Mdot
.32095 .31473 Mdot
.32286 .35615 Mdot
.32476 .28 Mdot
.32667 .42871 Mdot
.32857 .38585 Mdot
.33048 .36123 Mdot
.33238 .3706 Mdot
.33429 .28885 Mdot
.33619 .24618 Mdot
.3381 .29859 Mdot
.34 .38568 Mdot
.3419 .24815 Mdot
.34381 .41936 Mdot
.34571 .36171 Mdot
.34762 .35062 Mdot
.34952 .35795 Mdot
.35143 .23323 Mdot
.35333 .31964 Mdot
.35524 .33942 Mdot
.35714 .2507 Mdot
.35905 .32862 Mdot
.36095 .39777 Mdot
.36286 .4693 Mdot
.36476 .32079 Mdot
.36667 .30872 Mdot
.36857 .24462 Mdot
.37048 .33547 Mdot
.37238 .29056 Mdot
.37429 .34413 Mdot
.37619 .23504 Mdot
.3781 .28473 Mdot
.38 .43626 Mdot
.3819 .4607 Mdot
.38381 .43995 Mdot
.38571 .25416 Mdot
.38762 .38467 Mdot
.38952 .267 Mdot
.39143 .23513 Mdot
.39333 .31744 Mdot
.39524 .32515 Mdot
.39714 .39376 Mdot
.39905 .22385 Mdot
.40095 .32414 Mdot
.40286 .25999 Mdot
.40476 .47556 Mdot
.40667 .32143 Mdot
.40857 .27584 Mdot
.41048 .28018 Mdot
.41238 .32252 Mdot
.41429 .2578 Mdot
.41619 .47267 Mdot
.4181 .26443 Mdot
.42 .26896 Mdot
.4219 .34228 Mdot
.42381 .25847 Mdot
.42571 .26338 Mdot
.42762 .26967 Mdot
.42952 .41122 Mdot
.43143 .33826 Mdot
.43333 .36043 Mdot
.43524 .34534 Mdot
.43714 .25235 Mdot
.43905 .32583 Mdot
.44095 .24305 Mdot
.44286 .27984 Mdot
.44476 .26298 Mdot
.44667 .3357 Mdot
.44857 .32597 Mdot
.45048 .42481 Mdot
.45238 .37012 Mdot
.45429 .33588 Mdot
.45619 .34113 Mdot
.4581 .28391 Mdot
.46 .34409 Mdot
.4619 .32305 Mdot
.46381 .31718 Mdot
.46571 .31408 Mdot
.46762 .31924 Mdot
.46952 .31784 Mdot
.47143 .47038 Mdot
.47333 .30971 Mdot
.47524 .30027 Mdot
.47714 .28354 Mdot
.47905 .34627 Mdot
.48095 .28873 Mdot
.48286 .40966 Mdot
.48476 .27148 Mdot
.48667 .34394 Mdot
.48857 .37325 Mdot
.49048 .3339 Mdot
.49238 .26327 Mdot
.49429 .43849 Mdot
.49619 .3363 Mdot
.4981 .34558 Mdot
.5 .25985 Mdot
.5019 .26021 Mdot
.50381 .26904 Mdot
.50571 .22449 Mdot
.50762 .31441 Mdot
.50952 .31567 Mdot
.51143 .35976 Mdot
.51333 .36856 Mdot
.51524 .33518 Mdot
.51714 .38989 Mdot
.51905 .27925 Mdot
.52095 .37954 Mdot
.52286 .4338 Mdot
.52476 .32792 Mdot
.52667 .29953 Mdot
.52857 .32321 Mdot
.53048 .32883 Mdot
.53238 .2774 Mdot
.53429 .23934 Mdot
.53619 .25593 Mdot
.5381 .37 Mdot
.54 .24503 Mdot
.5419 .37023 Mdot
.54381 .25012 Mdot
.54571 .38924 Mdot
.54762 .29418 Mdot
.54952 .34587 Mdot
.55143 .35326 Mdot
.55333 .34214 Mdot
.55524 .31378 Mdot
.55714 .43861 Mdot
.55905 .26488 Mdot
.56095 .32423 Mdot
.56286 .25742 Mdot
.56476 .32023 Mdot
.56667 .34003 Mdot
.56857 .38504 Mdot
.57048 .34959 Mdot
.57238 .34347 Mdot
.57429 .28936 Mdot
.57619 .29127 Mdot
.5781 .27131 Mdot
.58 .2789 Mdot
.5819 .36595 Mdot
.58381 .46009 Mdot
.58571 .4183 Mdot
.58762 .34151 Mdot
.58952 .41796 Mdot
.59143 .29474 Mdot
.59333 .4142 Mdot
.59524 .30242 Mdot
.59714 .29776 Mdot
.59905 .32827 Mdot
.60095 .21689 Mdot
.60286 .35404 Mdot
.60476 .38432 Mdot
.60667 .28893 Mdot
.60857 .43811 Mdot
.61048 .24912 Mdot
.61238 .25527 Mdot
.61429 .43757 Mdot
.61619 .37044 Mdot
.6181 .26685 Mdot
.62 .40967 Mdot
.6219 .25504 Mdot
.62381 .41144 Mdot
.62571 .26052 Mdot
.62762 .32237 Mdot
.62952 .25099 Mdot
.63143 .33628 Mdot
.63333 .39266 Mdot
.63524 .3296 Mdot
.63714 .28461 Mdot
.63905 .24271 Mdot
.64095 .42116 Mdot
.64286 .30052 Mdot
.64476 .34732 Mdot
.64667 .36181 Mdot
.64857 .28886 Mdot
.65048 .27828 Mdot
.65238 .26942 Mdot
.65429 .28079 Mdot
.65619 .26873 Mdot
.6581 .35347 Mdot
.66 .35385 Mdot
.6619 .3357 Mdot
.66381 .40526 Mdot
.66571 .32166 Mdot
.66762 .32273 Mdot
.66952 .34803 Mdot
.67143 .36212 Mdot
.67333 .38563 Mdot
.67524 .37047 Mdot
.67714 .26428 Mdot
.67905 .44596 Mdot
.68095 .36934 Mdot
.68286 .34015 Mdot
.68476 .33414 Mdot
.68667 .41309 Mdot
.68857 .29126 Mdot
.69048 .23195 Mdot
.69238 .37213 Mdot
.69429 .30582 Mdot
.69619 .29668 Mdot
.6981 .39772 Mdot
.7 .33942 Mdot
.7019 .41404 Mdot
.70381 .25346 Mdot
.70571 .36064 Mdot
.70762 .31281 Mdot
.70952 .2348 Mdot
.71143 .29346 Mdot
.71333 .34021 Mdot
.71524 .42861 Mdot
.71714 .32796 Mdot
.71905 .30991 Mdot
.72095 .27816 Mdot
.72286 .23534 Mdot
.72476 .32113 Mdot
.72667 .32486 Mdot
.72857 .31041 Mdot
.73048 .37705 Mdot
.73238 .31853 Mdot
.73429 .37967 Mdot
.73619 .368 Mdot
.7381 .33938 Mdot
.74 .24956 Mdot
.7419 .43729 Mdot
.74381 .28623 Mdot
.74571 .4007 Mdot
.74762 .32686 Mdot
.74952 .39814 Mdot
.75143 .40595 Mdot
.75333 .39903 Mdot
.75524 .26138 Mdot
.75714 .24959 Mdot
.75905 .39068 Mdot
.76095 .30355 Mdot
.76286 .30551 Mdot
.76476 .22664 Mdot
.76667 .2465 Mdot
.76857 .28519 Mdot
.77048 .28284 Mdot
.77238 .39804 Mdot
.77429 .2679 Mdot
.77619 .32218 Mdot
.7781 .3584 Mdot
.78 .31162 Mdot
.7819 .44024 Mdot
.78381 .36403 Mdot
.78571 .31857 Mdot
.78762 .28468 Mdot
.78952 .28606 Mdot
.79143 .45249 Mdot
.79333 .30235 Mdot
.79524 .33207 Mdot
.79714 .31581 Mdot
.79905 .30183 Mdot
.80095 .35994 Mdot
.80286 .33848 Mdot
.80476 .29803 Mdot
.80667 .3098 Mdot
.80857 .3084 Mdot
.81048 .34649 Mdot
.81238 .23618 Mdot
.81429 .26407 Mdot
.81619 .30054 Mdot
.8181 .27201 Mdot
.82 .33895 Mdot
.8219 .32886 Mdot
.82381 .25217 Mdot
.82571 .30303 Mdot
.82762 .31977 Mdot
.82952 .27529 Mdot
.83143 .2878 Mdot
.83333 .38643 Mdot
.83524 .27657 Mdot
.83714 .37867 Mdot
.83905 .28142 Mdot
.84095 .28868 Mdot
.84286 .36914 Mdot
.84476 .34457 Mdot
.84667 .22799 Mdot
.84857 .47609 Mdot
.85048 .30087 Mdot
.85238 .33047 Mdot
.85429 .26551 Mdot
.85619 .29069 Mdot
.8581 .43283 Mdot
.86 .30263 Mdot
.8619 .26854 Mdot
.86381 .37167 Mdot
.86571 .4424 Mdot
.86762 .30291 Mdot
.86952 .26654 Mdot
.87143 .31781 Mdot
.87333 .32633 Mdot
.87524 .36369 Mdot
.87714 .4757 Mdot
.87905 .27143 Mdot
.88095 .37893 Mdot
.88286 .34958 Mdot
.88476 .33746 Mdot
.88667 .31988 Mdot
.88857 .33565 Mdot
.89048 .37755 Mdot
.89238 .32819 Mdot
.89429 .27542 Mdot
.89619 .33816 Mdot
.8981 .24341 Mdot
.9 .24355 Mdot
.9019 .3775 Mdot
.90381 .26939 Mdot
.90571 .46409 Mdot
.90762 .31708 Mdot
.90952 .34979 Mdot
.91143 .22449 Mdot
.91333 .25588 Mdot
.91524 .41452 Mdot
.91714 .36969 Mdot
.91905 .24524 Mdot
.92095 .23214 Mdot
.92286 .25607 Mdot
.92476 .35201 Mdot
.92667 .29906 Mdot
.92857 .31478 Mdot
.93048 .34443 Mdot
.93238 .38142 Mdot
.93429 .28973 Mdot
.93619 .38683 Mdot
.9381 .35508 Mdot
.94 .32244 Mdot
.9419 .30867 Mdot
.94381 .38466 Mdot
.94571 .38331 Mdot
.94762 .29728 Mdot
.94952 .36411 Mdot
.95143 .43275 Mdot
.95333 .25514 Mdot
.95524 .24323 Mdot
.95714 .35684 Mdot
.95905 .35508 Mdot
.96095 .30318 Mdot
.96286 .29096 Mdot
.96476 .2972 Mdot
.96667 .35212 Mdot
.96857 .42441 Mdot
.97048 .29282 Mdot
.97238 .35536 Mdot
.97429 .23509 Mdot
.97619 .30716 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0002gooooo`;o0000Q?ooool0
02Wooooo00?o0000ooooooooool0Eoooool2o`0005gooooo0_l00024ooooo`001_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool0Eoooool2o`0001cooooo0_l0000Pooooo`;o0000POooool2
o`00023ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0MOoo
ool2o`00023ooooo0_l0001Booooo`;o0000;Oooool2o`00023ooooo0004o`0000;ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`3[ooooo`;o00006?ooool2o`0003Gooooo0006ooooo`05o`000?oooooo
ooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0
0009ooooo`;o0000A_ooool2o`0001?ooooo0_l0001[ooooo`;o0000<?ooool2o`0001Kooooo0_l0
000Mooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool02Oooool2o`00013ooooo
0_l0000dooooo`;o00000oooool2o`0000kooooo0_l00006ooooo`;o00000_ooool2o`0005oooooo
0_l00004ooooo`;o00000_ooool2o`0001_ooooo0_l0000Qooooo`;o00003oooool2o`0000cooooo
0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool03_ooool2o`0000_ooooo0_l0000Gooooo`;o0000
5?ooool2o`0000[ooooo0_l0000Fooooo`;o00000_ooool2o`0002cooooo0_l0000gooooo`;o0000
0_ooool2o`0001_ooooo0_l0000booooo`;o00003?ooool000Kooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`;o
00003Oooool4o`0000Gooooo0_l000000ooooooo0000o`00000Jooooo`;o00004_ooool4o`0003Ko
oooo0_l0000Looooo`;o00008?ooool2o`00057ooooo0_l0000Aooooo`;o00004_ooool000Kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`00
00Kooooo0_l0000=ooooo`;o00001oooool2o`000003ooooool0003o000001Wooooo0_l00005oooo
o`;o00003?ooool2o`0001Oooooo0_l00008ooooo`;o00005Oooool2o`0001kooooo0_l0000Noooo
o`;o00009oooool2o`0002Sooooo0ol00004ooooo`;o00002_ooool2o`0001;ooooo000Yooooo`;o
00002?ooool2o`0001Oooooo0ol0000@ooooo`;o00001Oooool2o`0000Kooooo0_l0000Aooooo`;o
00002_ooool4o`0000Kooooo0_l0000eooooo`;o00005Oooool2o`0002Sooooo0_l00003ooooo`;o
000000?oooooo`000?l00000:Oooool2o`0000Cooooo0_l0000Nooooo`00:Oooool01?l0003ooooo
o`000?l00006ooooo`;o00005oooool3o`0000oooooo0_l0000>ooooo`;o00004Oooool2o`0000co
oooo0_l00002ooooo`;o00006?ooool2o`00023ooooo0_l0000Dooooo`;o00001?ooool2o`0002;o
oooo0_l00003ooooo`;o00005?ooool2o`0003cooooo000Yooooo`04o`000?oooooo0000o`0000Co
oooo0_l0000@ooooo`;o00006Oooool2o`0000Kooooo0_l0000[ooooo`;o00002?ooool2o`0000ko
oooo0_l0000Nooooo`Co00005Oooool2o`000003ooooool0003o000000;o00005_ooool2o`0002Go
oooo0_l0000Jooooo`;o00002oooool2o`0001?ooooo000Yooooo`03o`000?oooooooooo00Gooooo
0_l0000@ooooo`;o00006Oooool2o`0000Cooooo1?l0000eooooo`;o00001oooool2o`000003oooo
ool0003o000002;ooooo0_l00007ooooo`;o00003_ooool2o`000003ooooool0003o000001Sooooo
0_l00011ooooo`;o000000?oooooo`000?l000002?ooool2o`0001?ooooo000Yooooo`04o`000?oo
oooo0000o`0001?ooooo0_l00003ooooo`;o00005?ooool2o`0000Oooooo0_l000000ooooooo0000
o`000004ooooo`;o0000<oooool2o`0000;ooooo0_l000000ooooooo0000o`00000Fooooo`?o0000
4_ooool2o`0001;ooooo0_l0000Wooooo`;o0000=?ooool2o`0001gooooo000Yooooo`Co00000_oo
ool2o`0000gooooo1?l00003ooooo`;o00003Oooool4o`0000?ooooo0_l0000:ooooo`;o00001?oo
ool2o`0003?ooooo0_l00003ooooo`Co00001Oooool2o`0000gooooo1Ol0000@ooooo`;o00005?oo
ool2o`0000kooooo0_l0000Gooooo`;o00004Oooool2o`00043ooooo000Yooooo`03o`000?oooooo
oooo00?ooooo0_l0000=ooooo`;o00003oooool2o`0000?ooooo1?l0000Dooooo`;o00003_ooool2
o`0000Kooooo0_l0000Hooooo`;o00001oooool4o`0000Gooooo0_l0000=ooooo`;o00004oooool2
o`00017ooooo0_l0000Aooooo`;o00007_ooool2o`0000[ooooo0_l0000;ooooo`;o00000oooool2
o`0002kooooo000Yooooo`04o`000?ooooooooooooooo`;o00008?ooool2o`0000_ooooo1?l00000
2?l@413oooooo`000?l0003o<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko0000o`000?lb<S;ok^k^
00cooooo0_l00006ooooo`?o00004_ooool7o`000006ooooooo^k^ko<S8bo`000?lb<S;ok^k^0_oo
ool4o`000003oc8b<_o^k^kooooo00gooooo0_l00005ooooo`;o00004Oooool01?nHV9So410@o`00
0?lb<S82o`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_l0003o0000oc8b
<_o^k^h01oooool4o`0001oooooo0_l000000ol@413oooooooooo`02o`000004oc8b<_l0003o<S8b
onk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`;o000000?oooooo`000?l000000_l0
00000ooooooo0000o`000006ooooo`;o00003?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool002Wo
oooo00Co0000oooooooooooooooo0_l0000_ooooo`04o`000?ooooooooooooooo`;o000000CoV9RH
oooooonHV9SoMgMg0_l000001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_l0000>ooooo`;o
00004_ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02
ooooo`Co000000?oV9RHogMgMoooool03Oooool2o`0000Gooooo0_l0000Aooooo`04oa0@4?nj^[[o
ooooogMgM`;o00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`07ooooo`Co00008?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00;o00003?ooool2o`0000?ooooo0_l00006
ooooo`;o00003oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000_l000000ooooooo410@ooooo`02oooo
o`03oa0@4?oooooooooo00?ooooo0_l0000>ooooo`;o00004oooool00onHV9So8B4Qonk^kP04oooo
o`03oa0@4?oooooooooo00;o00000oooool01Ol@413ooooooooooooooooo410@01kooooo0_l0000<
ooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo
00?o410@ooooooooool09_ooool5o`0000?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@41000_l000000ooooooo0000o`000002o`00017ooooo0_l0000Coooo
o`04o`000?oooooooooooa0@40?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oo
oooooooo007ooooo000Yooooo`;o0000<oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000000oooool01?l0003oooooooooooooool2o`0000Sooooo0_l00005ooooo`;o0000
0oooool2o`0000;ooooo0_l0000@ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00?o0000ooooooooool0
0ol00002ooooo`06o`000?ooooooooooooooool0003ooooo0_l0000Gooooo`;o00000_ooool2o`00
00_ooooo00KoZJVYoa0@4?l0003o0000ooooool00003ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`05ooooo`?o00004oooool2o`0000Wooooo00CoA4A4omgMgOoooooo
00001?ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`Co00004Oooool2o`0001;ooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`01ooooo`00:Oooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`;o0000
0oooool2o`0000Sooooo0_l00005ooooo`;o00001oooool2o`00017ooooo00?oMgMgofIVI_ooool0
0_ooool01?l0003oooooooooooooool2o`0000;ooooo00Ko0000ooooooooooooooooo`000?ooool2
o`0000?ooooo0_l00004ooooo`;o00003?ooool2o`0000kooooo00?o410@o`000?nj^[X00_l00000
0ooooooo0000ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`05ooooo`?o00004oooool2o`0000Wooooo00GogMgMoeEEEOoooooo0000ooooo`02o`000003oooo
ool0003ooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Co
oooo0_l0000Qooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`00:Oooool00ol0003oooooooooo`0[
ooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000_oo
ool2o`0000?ooooo00?o410@ooooooooool0:?ooool2o`000003ooooool0003ooooo00;ooooo00Go
410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001_ooool2o`0000Co
oooo0_l0000Mooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4003oooo
o`05oa0@4?ooooooooooooooool@41000_ooool2o`00027ooooo0_l00002ooooo`04ogMgMoo<c<co
0000ooooo`;o000000Cooooooa0@4?oooooooooo0_l00003ooooo`05oa0@4?ooooooooooooooool@
41001_ooool2o`00027ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`00:Oooool00ol0003oooooooooo`0Yoooo
o`Ko00000oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01cooooo0_l0000;ooooo`?o000000?oV9RHoa0@4?ooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0=ooooo`;o
00006Oooool00ol@413oV9RHooooo`02o`0000?ooooo00KoMgMgoiRHV?ooooooV9RHogMgMoooool2
o`000005ogMgMonHV9SooooooiRHV?mgMgL00_ooool2o`0000;ooooo0_l0000Mooooo`;o00000_oo
ool01?o^k^koA4A4o`000?ooool2o`000004oooooomgMgOoV9RHooooo`;o00000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Cooooo0_l000000ooooooo0000o`00000Looooo`;o00000_ooool00ol0
003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo000Yooooo`03o`000?oooooooooo00;ooooo0_l0000Uooooo`;o00000_ooool2
o`000004oooooomEEEGoIVIVo`0000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool2o`0000gooooo0_l0000:ooooo`;o000000Co410@o`000?lQ
8B7oc<c<0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0=ooooo`;o00006Oooool00onYZJWo410@o`000003o`0000;ooooo00Kok^k^oc8b<_l0003o<S8b
onk^k_ooool2o`000005onk^k_lb<S;o0000oc8b<_o^k^h01_ooool2o`0000_ooooo0_l0000Eoooo
o`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01?ooool2o`000003ooooool0003o000000?ooooo0_l0000Gooooo`;o00000_oo
ool4o`000004ooooool0003o0000onk^kP;o000000?o<S8bonk^k_ooool00_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo000Yooooo`;o00000oooool2o`0004gooooo0_l0000Iooooo`;o0000
=oooool2o`0000Oooooo0_l00003ooooo`;o00007Oooool2o`0000Gooooo0_l0000]ooooo`;o0000
8?ooool2o`000003ooooool0003o000000gooooo000Yooooo`03o`000?oooooooooo01Sooooo0_l0
0017ooooo`;o0000@_ooool2o`0000cooooo1?l0000Mooooo`;o00000oooool2o`0001cooooo0_l0
000Vooooo`;o00001?ooool2o`0000Cooooo0_l0000?ooooo`00:Oooool00ol0003oooooooooo`0=
ooooo`;o00002Oooool2o`0000_ooooo0_l0000Pooooo`;o00006?ooool2o`0002[ooooo0_l0000?
ooooo`;o00005?ooool3o`0000cooooo0_l0000?ooooo`;o00007_ooool5o`0000;ooooo0_l00009
ooooo`;o00005oooool2o`0000Cooooo0_l00004ooooo`;o00003oooool002Wooooo00?o0000oooo
ooooool03Oooool2o`0001Kooooo0_l0000Pooooo`;o0000A?ooool2o`0000oooooo0_l0000Doooo
o`;o00003Oooool2o`0002Cooooo0ol00008ooooo`Co00000oooool2o`000003ooooool0003o0000
00Kooooo0_l000001?oooooo0000o`000?ooool2o`0001cooooo0_l0000@ooooo`00:Oooool3o`00
04kooooo0_l0000Kooooo`;o0000Ioooool2o`0001?ooooo0ol0000=ooooo`;o00000oooool2o`00
00Wooooo0_l000000ooooooo0000o`00000Eooooo`;o00001Oooool2o`0000?ooooo0_l0000;oooo
o`008Oooooooo`0004Co00001?ooool002Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o00002_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooooooo0_l00006ooooo`;o
00001_ooool3o`000003ooooool0003ooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00?ooooo0_l000001Ooooooo0000o`000?oooooo0000
00Oooooo0_l00002ooooo`03o`000?oooooooooo00Sooooo0ol0000;ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`?o000000Coooooo`00
0?l0003ooooo0_l00005ooooo`03o`000?oooooooooo00Kooooo0_l000000ooooooo0000ooooo`04
ooooo`;o00001?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool01Oooool2o`0000;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:
ooooo`00:Oooool00ol0003oooooooooo`0Aooooo`;o00003oooool2o`0001Kooooo00?o0000oooo
ooooool01_ooool2o`0000kooooo0_l00006ooooo`?o00005Oooool2o`0000?ooooo00?o0000oooo
ooooool03oooool4o`0000[ooooo0_l0000=ooooo`;o00003?ooool00ol0003oooooooooo`0Poooo
o`;o00006?ooool00ol0003oooooooooo`02o`0001Kooooo0_l00009ooooo`;o00001Oooool2o`00
00kooooo00?o0000ooooooooool02_ooool002Wooooo00?o0000ooooooooool01Oooool2o`0000[o
oooo0_l00002ooooo`;o00004Oooool2o`0001Wooooo0_l0000Qooooo`;o00000_ooool2o`0000Oo
oooo0_l0000Eooooo`Co00002_ooool2o`00013ooooo0_l0000booooo`Co00003oooool2o`0000;o
oooo0_l00008ooooo`;o00003?ooool2o`0000?ooooo0_l00004ooooo`;o00008_ooool002Wooooo
00?o0000ooooooooool01Oooool2o`0000kooooo0_l0000Aooooo`;o0000??ooool2o`0000;ooooo
0_l0000:ooooo`Go00003_ooool4o`0001;ooooo0_l00008ooooo`?o00004_ooool2o`0000_ooooo
0_l0000Aooooo`Co00003?ooool2o`000003ooooool0003o000000cooooo0_l0000Aooooo`;o0000
3oooool2o`0001Oooooo000Yooooo`;o00009oooool2o`0002Cooooo0_l0000Vooooo`Oo00001ooo
ool2o`000003ooooool0003o000000;ooooo0_l0000Dooooo`;o00002?ooool2o`0001?ooooo0_l0
000;ooooo`;o00004Oooool2o`0000Gooooo0_l00007ooooo`;o00007Oooool2o`0001Cooooo0_l0
000Gooooo`00:Oooool00ol0003oooooooooo`0Vooooo`;o00000_ooool2o`0000Oooooo1?l00006
ooooo`Co00000oooool2o`0000Kooooo0_l0000Jooooo`;o00002_ooool2o`0000cooooo0_l00000
0ooooooo0000o`00000Fooooo`Co00005?ooool2o`0000[ooooo0_l0000Hooooo`;o000000?ooooo
o`000?l000001Oooool2o`0001Kooooo0_l00008ooooo`;o00001?ooool2o`0000Gooooo0_l0000V
ooooo`00:Oooool00ol0003oooooooooo`0Zooooo`;o00001oooool4o`0000Kooooo1?l00003oooo
o`;o00008_ooool2o`0003?ooooo1?l0000Dooooo`;o00002_ooool2o`0001Sooooo0_l0000Goooo
o`;o00001oooool2o`0000Sooooo0_l0000;ooooo`;o00009_ooool002Wooooo00?o0000oooooooo
ool01?ooool2o`0001gooooo0_l0000Aooooo`;o00008_ooool2o`00013ooooo0_l0000Fooooo`;o
000000?oooooo`000?l000002Oooool4o`0000Cooooo0_l0000Tooooo`;o00001oooool2o`0000Ko
oooo0_l0000Qooooo`;o00007?ooool2o`0002Sooooo000Yooooo`03o`000?oooooooooo00Cooooo
1?l0000Kooooo`;o00004Oooool2o`0000?ooooo0_l0000Kooooo`Co00002oooool2o`0000?ooooo
0_l0000Aooooo`;o00000oooool2o`000003ooooool0003o000000Wooooo1?l00004ooooo`;o0000
9?ooool2o`0000Oooooo0_l00006ooooo`;o00000oooool2o`0000[ooooo0_l0000Cooooo`;o0000
0oooool2o`0001?ooooo0ol000000ooooooo0000o`00000Uooooo`00:Oooool2o`0000Oooooo0_l0
000Tooooo`;o00000oooool2o`0000Sooooo0_l0000Kooooo`;o00003Oooool2o`0001?ooooo0_l0
00000ooooooo0000o`000006ooooo`;o00007_ooool2o`0000;ooooo0_l00005ooooo`;o00007?oo
ool2o`0000Cooooo0_l00002ooooo`;o00001_ooool2o`0001?ooooo0_l00003ooooo`;o00004ooo
ool2o`0000;ooooo0_l0000Uooooo`00:Oooool00ol0003oooooooooo`0Jooooo`;o00001_ooool2
o`0000Sooooo0_l00003ooooo`;o00002oooool2o`0002gooooo0_l0000=ooooo`;o00000oooool2
o`0000Cooooo1?l00006ooooo`;o00000_ooool2o`0000kooooo1?l00002ooooo`Co00000oooool2
o`0001cooooo0_l00008ooooo`;o0000:?ooool2o`0001[ooooo0_l0000Jooooo`00:Oooool00ol0
003oooooooooo`0Jooooo`;o00001_ooool2o`0001[ooooo0_l0000]ooooo`;o00004_ooool2o`00
00Kooooo0_l00004ooooo`Co00000_ooool2o`0000kooooo0_l00006ooooo`;o00005Oooool2o`00
00Kooooo0_l0000[ooooo`;o00002Oooool2o`0001[ooooo0_l0000Jooooo`00:Oooool00ol0003o
ooooooooo`0Dooooo`Co0000=_ooool2o`0001Cooooo0_l0000Yooooo`;o00006oooool2o`0001Ko
oooo0_l00006ooooo`;o0000:oooool2o`0001Gooooo0_l00007ooooo`;o00000oooool2o`0000_o
oooo0_l0000?ooooo`00:Oooool00ol0003oooooooooo`08ooooo`;o00002_ooool4o`0000oooooo
0_l00005ooooo`;o00007_ooool2o`0001Cooooo0_l00010ooooo`;o00001?ooool2o`0000Sooooo
0_l0000@ooooo`?o0000AOooool2o`0000Oooooo0_l00003ooooo`;o00000_ooool2o`0000Gooooo
1_l0000=ooooo`00:Oooool2o`000003ooooool0003o000000Kooooo0_l00003ooooo`;o00006?oo
ool2o`0000Cooooo1Ol0000Rooooo`;o00001_ooool2o`0000Oooooo0_l0000oooooo`;o00003_oo
ool2o`00013ooooo0ol0000Tooooo`;o0000<Oooool2o`0000Cooooo0ol00002ooooo`;o00003Ooo
ool002Wooooo0_l000000ooooooo0000o`00000;ooooo`Co00007?ooool2o`000003ooooool0003o
000002;ooooo0_l00006ooooo`;o000000?oooooo`000?l000001?ooool2o`0001Wooooo0_l0000G
ooooo`;o0000?Oooool2o`0001Gooooo0_l00005ooooo`;o0000<?ooool2o`0001;ooooo000Yoooo
o`03o`000?oooooooooo00oooooo0_l0001>ooooo`;o00000oooool2o`0001[ooooo0_l0000Goooo
o`;o0000:_ooool2o`0000Kooooo0_l00009ooooo`;o00005oooool2o`0000?ooooo0_l0000Foooo
o`;o00005_ooool2o`0001Cooooo000Yooooo`03o`000?oooooooooo06Cooooo0_l0001:ooooo`;o
00004oooool2o`0000Kooooo0_l0000Rooooo`;o00006oooool2o`0001Kooooo0_l0000Dooooo`00
:Oooool00ol0003oooooooooo`0<ooooo`;o0000DOooool2o`0002Gooooo0_l0000Booooo`;o0000
1_ooool3o`0000_ooooo0_l00009ooooo`;o00004Oooool4o`0000oooooo0_l0000Qooooo`;o0000
5_ooool2o`0001kooooo000Yooooo`;o00003Oooool2o`0000Cooooo0_l0000;ooooo`;o0000?_oo
ool2o`0002Gooooo0_l0000:ooooo`;o00001_ooool2o`0000Kooooo0ol0000Fooooo`;o00004Ooo
ool4o`000003ooooool0003o000000cooooo0_l0000Qooooo`;o00001?ooool2o`00013ooooo0_l0
000Nooooo`00:Oooool00ol0003oooooooooo`0Booooo`;o00002oooool2o`0001cooooo0_l0000A
ooooo`;o0000@?ooool2o`0003oooooo0_l0000:ooooo`;o0000:Oooool2o`00033ooooo0006oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01Oooool01?l0003oooooooooooooool2o`0003[ooooo0_l00007ooooo`;o0000
2?ooool2o`0004[ooooo0_l00011ooooo`Co00007oooool2o`0000cooooo0_l000000ooooooo0000
o`000002ooooo`;o00008oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool01?l0003o
ooooooooooooool2o`0004?ooooo0_l00007ooooo`;o0000Boooool2o`0004?ooooo0_l0000Ooooo
o`;o00003?ooool2o`000003ooooool0003o000000;ooooo0_l00007ooooo`;o00000oooool2o`00
01Gooooo0006ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool2o`0000Sooooo0_l0000`oooo
o`;o000000?oooooo`000?l000002_ooool2o`0000;ooooo0_l0000=ooooo`;o0000>?ooool2o`00
00[ooooo0_l0000Dooooo`;o0000<_ooool2o`0001gooooo0_l00002ooooo`?o00005Oooool000Ko
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b
<_ooool01?ooool3o`0001?ooooo0_l00002ooooo`;o00001?ooool3o`0003;ooooo0_l0000:oooo
o`;o00000_ooool2o`0000gooooo0_l0000aooooo`;o00001Oooool2o`0000[ooooo0_l0000Doooo
o`;o0000<_ooool2o`0001oooooo1?l0000Fooooo`001_ooool01Ol0003ooooooooooooooooo0000
00kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000
ooooooooool05oooool2o`0000Gooooo0_l0001kooooo`;o00001oooool2o`0001[ooooo0_l0000W
ooooo`;o0000=oooool2o`0001Sooooo0006ooooo`05oa0@4?ooooooooooooooool@41003oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool2
o`0006Sooooo0_l0000Uooooo`;o00008oooool2o`0002Oooooo0_l0001Aooooo`001_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02_ooool2o`0000?ooooo0_l0000_ooooo`;o00001ooo
ool2o`0001kooooo0_l00009ooooo`;o0000Goooool2o`0000oooooo0_l00005ooooo`;o0000COoo
ool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
1?ooool4o`0000Kooooo00?o0000ooooooooool02_ooool2o`0000?ooooo0ol0000Booooo`;o0000
00?oooooo`000?l000005oooool2o`0000Oooooo0_l00002ooooo`;o00001?ooool2o`0001Cooooo
0_l0001Zooooo`;o00003Oooool5o`0000Cooooo0_l0001=ooooo`00:Oooool2o`0000_ooooo0_l0
0004ooooo`;o00004_ooool2o`000003ooooool0003o000002Cooooo0_l00004ooooo`;o0000Sooo
ool2o`000003ooooool0003o000005?ooooo000Yooooo`03o`000?oooooooooo00Wooooo1?l0000S
ooooo`;o00005_ooool2o`00017ooooo0_l0001]ooooo`;o00006_ooool2o`0005Cooooo000Yoooo
o`03o`000?oooooooooo00Oooooo1_l0000Sooooo`;o00005?ooool4o`00017ooooo0_l0000Roooo
o`;o00003oooool2o`0002[ooooo0ol0000;ooooo`;o00006_ooool2o`0005Cooooo000Yooooo`03
o`000?oooooooooo00Cooooo0_l000000ooooooo0000o`00000mooooo`;o0000=oooool2o`0000oo
oooo0_l0000Qooooo`;o00001oooool3o`0001;ooooo0_l00003ooooo`;o0000@oooool2o`0001oo
oooo000Yooooo`03o`000?oooooooooo00Cooooo0_l0001@ooooo`;o0000Foooool2o`0001cooooo
0_l00003ooooo`;o0000@oooool2o`0001oooooo000Yooooo`;o0000Eoooool2o`0000_ooooo0_l0
001<ooooo`?o0000R?ooool002Wooooo00?o0000ooooooooool08?ooool2o`00047ooooo0_l0001<
ooooo`?o00003oooool2o`0007Oooooo000Yooooo`03o`000?oooooooooo01oooooo0ol0000Goooo
o`;o0000B_ooool2o`0003cooooo0_l0001Wooooo`;o00003_ooool002Wooooo00?o0000oooooooo
ool07oooool2o`0001Sooooo0_l0000:ooooo`;o00005oooool2o`0002Gooooo0_l0001Dooooo`;o
0000Coooool2o`0000kooooo000Yooooo`03o`000?oooooooooo01gooooo0_l0000<ooooo`;o0000
6?ooool2o`0001Oooooo0_l0001kooooo`;o0000;?ooool2o`0001cooooo0_l0000Cooooo`00:Ooo
ool2o`0001kooooo0_l00006ooooo`;o00001?ooool2o`0000_ooooo0_l0000;ooooo`;o0000:?oo
ool2o`0002cooooo0_l0001Zooooo`;o00007?ooool2o`0001?ooooo000Yooooo`03o`000?oooooo
oooo00;ooooo0_l0000<ooooo`;o00002?ooool4o`0000Oooooo0_l0000Aooooo`;o00001oooool2
o`0000;ooooo0_l0000Xooooo`;o00008oooool2o`0000Oooooo0_l00009ooooo`;o00003_ooool4
o`0002Oooooo0_l0001Gooooo`00:Oooool00ol0003oooooooooo`02ooooo`;o00003?ooool2o`00
00Sooooo1?l0000Sooooo`;o0000;Oooool2o`0002;ooooo0_l0000Booooo`;o00003_ooool4o`00
02Oooooo0_l0000;ooooo`;o00006Oooool2o`0002oooooo000Yooooo`03o`000?oooooooooo073o
oooo0_l0001nooooo`;o00006Oooool2o`0002oooooo000Yooooo`03o`000?oooooooooo0<oooooo
0_l0001[ooooo`00:Oooool2o`000=3ooooo0_l0001[ooooo`00:Oooool00ol0003oooooooooo`3c
ooooo`;o0000Aoooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0loooool2o`0004Oooooo000>
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`1_ooooo`;o0000?oooool2o`0008[ooooo000>ooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`?o0000Boooool2o`0002;ooooo0_l0
000oooooo`;o0000I_ooool2o`0002;ooooo000>ooooo`05o`000?ooooooooooooooool000003ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo04_ooooo0_l0003;ooooo`;o00008_oo
ool000kooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`1Yooooo`;o00008Oooool2o`000:kooooo000>ooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Oooooo
0_l0000`ooooo`;o00003oooool2o`00013ooooo0_l0002^ooooo`003_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0eooooo`Co0000
?_ooool2o`000003ooooool0003o000008Wooooo0_l00008ooooo`;o0000:oooool000kooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`0003Kooooo0_l00010ooooo`;o0000
S?ooool2o`0000Sooooo0_l0000[ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
00Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocgooooo0006
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@
oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00ooo
ool3o`000?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooo
oooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006
ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?oo
ooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co
00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000O
ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3oooooocgooooo000Qoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003o
ooooooooo`05ooooo`?o0000oooooolmooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Oooooo`03oeEEEOmVIVKo00000?oo
ooooAoooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .28712 Mdot
.02762 .26589 Mdot
.02952 .2776 Mdot
.03143 .28753 Mdot
.03333 .31817 Mdot
.03524 .39145 Mdot
.03714 .30612 Mdot
.03905 .43848 Mdot
.04095 .42889 Mdot
.04286 .3425 Mdot
.04476 .27545 Mdot
.04667 .41747 Mdot
.04857 .40157 Mdot
.05048 .30765 Mdot
.05238 .40753 Mdot
.05429 .28763 Mdot
.05619 .28491 Mdot
.0581 .40494 Mdot
.06 .3484 Mdot
.0619 .30443 Mdot
.06381 .40438 Mdot
.06571 .33139 Mdot
.06762 .35323 Mdot
.06952 .40937 Mdot
.07143 .35319 Mdot
.07333 .32842 Mdot
.07524 .25401 Mdot
.07714 .34095 Mdot
.07905 .27574 Mdot
.08095 .27312 Mdot
.08286 .40958 Mdot
.08476 .43031 Mdot
.08667 .44357 Mdot
.08857 .24557 Mdot
.09048 .31535 Mdot
.09238 .35937 Mdot
.09429 .29466 Mdot
.09619 .30657 Mdot
.0981 .25001 Mdot
.1 .40922 Mdot
.1019 .35266 Mdot
.10381 .27431 Mdot
.10571 .37491 Mdot
.10762 .26338 Mdot
.10952 .32138 Mdot
.11143 .24888 Mdot
.11333 .31919 Mdot
.11524 .40551 Mdot
.11714 .37485 Mdot
.11905 .28475 Mdot
.12095 .4019 Mdot
.12286 .23074 Mdot
.12476 .47852 Mdot
.12667 .3507 Mdot
.12857 .36068 Mdot
.13048 .44201 Mdot
.13238 .43546 Mdot
.13429 .28731 Mdot
.13619 .36348 Mdot
.1381 .33519 Mdot
.14 .24976 Mdot
.1419 .23299 Mdot
.14381 .24598 Mdot
.14571 .29521 Mdot
.14762 .44096 Mdot
.14952 .4386 Mdot
.15143 .34494 Mdot
.15333 .27037 Mdot
.15524 .31232 Mdot
.15714 .4133 Mdot
.15905 .26047 Mdot
.16095 .28179 Mdot
.16286 .33996 Mdot
.16476 .34655 Mdot
.16667 .24617 Mdot
.16857 .3137 Mdot
.17048 .47843 Mdot
.17238 .27371 Mdot
.17429 .23388 Mdot
.17619 .36943 Mdot
.1781 .40677 Mdot
.18 .26606 Mdot
.1819 .30901 Mdot
.18381 .28402 Mdot
.18571 .44602 Mdot
.18762 .3004 Mdot
.18952 .31022 Mdot
.19143 .28 Mdot
.19333 .31102 Mdot
.19524 .27407 Mdot
.19714 .3485 Mdot
.19905 .44513 Mdot
.20095 .33548 Mdot
.20286 .26135 Mdot
.20476 .32667 Mdot
.20667 .43241 Mdot
.20857 .31312 Mdot
.21048 .4026 Mdot
.21238 .47656 Mdot
.21429 .30497 Mdot
.21619 .26351 Mdot
.2181 .33849 Mdot
.22 .41769 Mdot
.2219 .24728 Mdot
.22381 .41362 Mdot
.22571 .25129 Mdot
.22762 .24891 Mdot
.22952 .35787 Mdot
.23143 .33607 Mdot
.23333 .41311 Mdot
.23524 .32924 Mdot
.23714 .29343 Mdot
.23905 .42812 Mdot
.24095 .34763 Mdot
.24286 .39848 Mdot
.24476 .27118 Mdot
.24667 .25902 Mdot
.24857 .44498 Mdot
.25048 .44022 Mdot
.25238 .28229 Mdot
.25429 .4004 Mdot
.25619 .22348 Mdot
.2581 .38795 Mdot
.26 .26882 Mdot
.2619 .41358 Mdot
.26381 .27104 Mdot
.26571 .33154 Mdot
.26762 .40765 Mdot
.26952 .23841 Mdot
.27143 .32166 Mdot
.27333 .35368 Mdot
.27524 .24389 Mdot
.27714 .40138 Mdot
.27905 .39123 Mdot
.28095 .38576 Mdot
.28286 .24299 Mdot
.28476 .27818 Mdot
.28667 .30017 Mdot
.28857 .34152 Mdot
.29048 .43824 Mdot
.29238 .40397 Mdot
.29429 .29466 Mdot
.29619 .33147 Mdot
.2981 .33109 Mdot
.3 .28393 Mdot
.3019 .32651 Mdot
.30381 .44705 Mdot
.30571 .33432 Mdot
.30762 .35692 Mdot
.30952 .26607 Mdot
.31143 .23086 Mdot
.31333 .3467 Mdot
.31524 .27403 Mdot
.31714 .41107 Mdot
.31905 .27347 Mdot
.32095 .37801 Mdot
.32286 .2536 Mdot
.32476 .23729 Mdot
.32667 .4437 Mdot
.32857 .2942 Mdot
.33048 .25881 Mdot
.33238 .36147 Mdot
.33429 .23333 Mdot
.33619 .35919 Mdot
.3381 .38219 Mdot
.34 .37135 Mdot
.3419 .27362 Mdot
.34381 .44661 Mdot
.34571 .41093 Mdot
.34762 .30384 Mdot
.34952 .25472 Mdot
.35143 .3155 Mdot
.35333 .33687 Mdot
.35524 .27941 Mdot
.35714 .31041 Mdot
.35905 .3585 Mdot
.36095 .44164 Mdot
.36286 .42491 Mdot
.36476 .38031 Mdot
.36667 .2668 Mdot
.36857 .26684 Mdot
.37048 .23725 Mdot
.37238 .39282 Mdot
.37429 .3357 Mdot
.37619 .3437 Mdot
.3781 .32707 Mdot
.38 .42435 Mdot
.3819 .40386 Mdot
.38381 .43033 Mdot
.38571 .36683 Mdot
.38762 .38237 Mdot
.38952 .23584 Mdot
.39143 .32657 Mdot
.39333 .26695 Mdot
.39524 .22531 Mdot
.39714 .44324 Mdot
.39905 .30697 Mdot
.40095 .4112 Mdot
.40286 .27263 Mdot
.40476 .46629 Mdot
.40667 .24618 Mdot
.40857 .2765 Mdot
.41048 .27257 Mdot
.41238 .2911 Mdot
.41429 .32579 Mdot
.41619 .47253 Mdot
.4181 .25432 Mdot
.42 .28007 Mdot
.4219 .38837 Mdot
.42381 .29626 Mdot
.42571 .30832 Mdot
.42762 .26776 Mdot
.42952 .37844 Mdot
.43143 .26739 Mdot
.43333 .41048 Mdot
.43524 .32235 Mdot
.43714 .26734 Mdot
.43905 .25609 Mdot
.44095 .35557 Mdot
.44286 .32554 Mdot
.44476 .34938 Mdot
.44667 .41869 Mdot
.44857 .25552 Mdot
.45048 .36868 Mdot
.45238 .41337 Mdot
.45429 .3998 Mdot
.45619 .30041 Mdot
.4581 .3462 Mdot
.46 .25264 Mdot
.4619 .33656 Mdot
.46381 .40622 Mdot
.46571 .22287 Mdot
.46762 .26293 Mdot
.46952 .29777 Mdot
.47143 .4719 Mdot
.47333 .36547 Mdot
.47524 .25374 Mdot
.47714 .22783 Mdot
.47905 .29323 Mdot
.48095 .24005 Mdot
.48286 .38843 Mdot
.48476 .24885 Mdot
.48667 .23297 Mdot
.48857 .39153 Mdot
.49048 .40101 Mdot
.49238 .26127 Mdot
.49429 .43323 Mdot
.49619 .31812 Mdot
.4981 .24496 Mdot
.5 .33631 Mdot
.5019 .26443 Mdot
.50381 .24337 Mdot
.50571 .31616 Mdot
.50762 .26927 Mdot
.50952 .2661 Mdot
.51143 .25841 Mdot
.51333 .33092 Mdot
.51524 .27298 Mdot
.51714 .37372 Mdot
.51905 .31094 Mdot
.52095 .43772 Mdot
.52286 .38838 Mdot
.52476 .37174 Mdot
.52667 .25378 Mdot
.52857 .39439 Mdot
.53048 .30081 Mdot
.53238 .35101 Mdot
.53429 .31068 Mdot
.53619 .30989 Mdot
.5381 .3891 Mdot
.54 .34153 Mdot
.5419 .35061 Mdot
.54381 .34841 Mdot
.54571 .36834 Mdot
.54762 .34328 Mdot
.54952 .37305 Mdot
.55143 .25062 Mdot
.55333 .34041 Mdot
.55524 .35778 Mdot
.55714 .4088 Mdot
.55905 .27275 Mdot
.56095 .3822 Mdot
.56286 .25175 Mdot
.56476 .32832 Mdot
.56667 .3392 Mdot
.56857 .29317 Mdot
.57048 .42418 Mdot
.57238 .359 Mdot
.57429 .27033 Mdot
.57619 .34837 Mdot
.5781 .36754 Mdot
.58 .25583 Mdot
.5819 .41004 Mdot
.58381 .40302 Mdot
.58571 .3534 Mdot
.58762 .41911 Mdot
.58952 .35413 Mdot
.59143 .3195 Mdot
.59333 .34309 Mdot
.59524 .22401 Mdot
.59714 .38386 Mdot
.59905 .41211 Mdot
.60095 .29594 Mdot
.60286 .3729 Mdot
.60476 .38721 Mdot
.60667 .24049 Mdot
.60857 .43231 Mdot
.61048 .36043 Mdot
.61238 .30858 Mdot
.61429 .40603 Mdot
.61619 .3396 Mdot
.6181 .30474 Mdot
.62 .37446 Mdot
.6219 .27219 Mdot
.62381 .39518 Mdot
.62571 .23979 Mdot
.62762 .27864 Mdot
.62952 .33729 Mdot
.63143 .25664 Mdot
.63333 .43908 Mdot
.63524 .30708 Mdot
.63714 .3889 Mdot
.63905 .25866 Mdot
.64095 .32856 Mdot
.64286 .25797 Mdot
.64476 .39115 Mdot
.64667 .28958 Mdot
.64857 .23425 Mdot
.65048 .34364 Mdot
.65238 .28484 Mdot
.65429 .31631 Mdot
.65619 .25685 Mdot
.6581 .42761 Mdot
.66 .25266 Mdot
.6619 .32557 Mdot
.66381 .35934 Mdot
.66571 .32573 Mdot
.66762 .29264 Mdot
.66952 .2564 Mdot
.67143 .39227 Mdot
.67333 .37204 Mdot
.67524 .36129 Mdot
.67714 .33273 Mdot
.67905 .48169 Mdot
.68095 .33747 Mdot
.68286 .25092 Mdot
.68476 .29569 Mdot
.68667 .44407 Mdot
.68857 .25568 Mdot
.69048 .30952 Mdot
.69238 .29173 Mdot
.69429 .33905 Mdot
.69619 .24995 Mdot
.6981 .29191 Mdot
.7 .41995 Mdot
.7019 .34189 Mdot
.70381 .35141 Mdot
.70571 .37142 Mdot
.70762 .24408 Mdot
.70952 .32255 Mdot
.71143 .35921 Mdot
.71333 .42024 Mdot
.71524 .34005 Mdot
.71714 .39839 Mdot
.71905 .40334 Mdot
.72095 .38461 Mdot
.72286 .3449 Mdot
.72476 .31261 Mdot
.72667 .37027 Mdot
.72857 .40259 Mdot
.73048 .43718 Mdot
.73238 .31711 Mdot
.73429 .41269 Mdot
.73619 .33512 Mdot
.7381 .38809 Mdot
.74 .27076 Mdot
.7419 .41006 Mdot
.74381 .24093 Mdot
.74571 .31899 Mdot
.74762 .23497 Mdot
.74952 .34622 Mdot
.75143 .32632 Mdot
.75333 .34679 Mdot
.75524 .37102 Mdot
.75714 .37588 Mdot
.75905 .30352 Mdot
.76095 .3736 Mdot
.76286 .26932 Mdot
.76476 .29131 Mdot
.76667 .31768 Mdot
.76857 .31794 Mdot
.77048 .38818 Mdot
.77238 .41382 Mdot
.77429 .28788 Mdot
.77619 .34754 Mdot
.7781 .30066 Mdot
.78 .25483 Mdot
.7819 .41208 Mdot
.78381 .41292 Mdot
.78571 .22417 Mdot
.78762 .38914 Mdot
.78952 .24746 Mdot
.79143 .48054 Mdot
.79333 .24374 Mdot
.79524 .35881 Mdot
.79714 .35745 Mdot
.79905 .27172 Mdot
.80095 .43028 Mdot
.80286 .41909 Mdot
.80476 .25424 Mdot
.80667 .33871 Mdot
.80857 .25338 Mdot
.81048 .31918 Mdot
.81238 .26664 Mdot
.81429 .26721 Mdot
.81619 .38359 Mdot
.8181 .32583 Mdot
.82 .27757 Mdot
.8219 .31217 Mdot
.82381 .28716 Mdot
.82571 .24427 Mdot
.82762 .25769 Mdot
.82952 .27258 Mdot
.83143 .22604 Mdot
.83333 .43903 Mdot
.83524 .29971 Mdot
.83714 .32648 Mdot
.83905 .24887 Mdot
.84095 .36533 Mdot
.84286 .3449 Mdot
.84476 .28884 Mdot
.84667 .28573 Mdot
.84857 .44668 Mdot
.85048 .23777 Mdot
.85238 .43129 Mdot
.85429 .25225 Mdot
.85619 .26317 Mdot
.8581 .4322 Mdot
.86 .39808 Mdot
.8619 .26939 Mdot
.86381 .29142 Mdot
.86571 .48098 Mdot
.86762 .33789 Mdot
.86952 .3056 Mdot
.87143 .35686 Mdot
.87333 .39611 Mdot
.87524 .36558 Mdot
.87714 .45781 Mdot
.87905 .31968 Mdot
.88095 .32988 Mdot
.88286 .27044 Mdot
.88476 .31615 Mdot
.88667 .27535 Mdot
.88857 .34551 Mdot
.89048 .43801 Mdot
.89238 .29286 Mdot
.89429 .23889 Mdot
.89619 .24828 Mdot
.8981 .32599 Mdot
.9 .34065 Mdot
.9019 .41184 Mdot
.90381 .25678 Mdot
.90571 .40853 Mdot
.90762 .34753 Mdot
.90952 .4259 Mdot
.91143 .31708 Mdot
.91333 .30915 Mdot
.91524 .34328 Mdot
.91714 .34784 Mdot
.91905 .30475 Mdot
.92095 .31246 Mdot
.92286 .26204 Mdot
.92476 .35236 Mdot
.92667 .24958 Mdot
.92857 .24518 Mdot
.93048 .23259 Mdot
.93238 .38336 Mdot
.93429 .31465 Mdot
.93619 .36714 Mdot
.9381 .37081 Mdot
.94 .3102 Mdot
.9419 .25894 Mdot
.94381 .34733 Mdot
.94571 .385 Mdot
.94762 .26517 Mdot
.94952 .31686 Mdot
.95143 .43913 Mdot
.95333 .32294 Mdot
.95524 .32457 Mdot
.95714 .32347 Mdot
.95905 .3389 Mdot
.96095 .32459 Mdot
.96286 .40735 Mdot
.96476 .3246 Mdot
.96667 .26095 Mdot
.96857 .36962 Mdot
.97048 .37923 Mdot
.97238 .32086 Mdot
.97429 .28625 Mdot
.97619 .40249 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo04Oooooo0_l00011ooooo`;o0000:?ooool2o`0003_ooooo0_l00019ooooo`001_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo04Oooooo0_l0000[ooooo`;o00005?oo
ool2o`0000;ooooo0_l0000Tooooo`;o0000>oooool2o`0000gooooo0_l0000jooooo`001?l00002
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool07?ooool2o`0003_ooooo0_l0000Iooooo`;o00006?oo
ool2o`00073ooooo0_l0000jooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o00007?ooool2o`0000Cooooo0_l0
0009ooooo`;o0000:_ooool2o`0000Gooooo0_l0000_ooooo`;o0000SOooool2o`0001[ooooo0006
ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Rooooo`;o00002Oooool2o`0002kooooo
0_l000000ooooooo0000o`00000:ooooo`;o00001?ooool2o`0001gooooo0_l0000booooo`;o0000
7_ooool2o`0003Wooooo0_l0000Jooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04_ooooo
0_l0000@ooooo`;o00003Oooool2o`0000Cooooo0_l0000Kooooo`;o0000;Oooool2o`0000Gooooo
0_l0000Nooooo`;o00007oooool2o`0000cooooo0_l0000Vooooo`001_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0Boooool2o`0000?ooooo0_l0000mooooo`;o00001_ooool2o`0001oo
oooo0_l00004ooooo`;o00009?ooool2o`00023ooooo0_l0000<ooooo`;o00009_ooool000Kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`00
00Kooooo00?o0000ooooooooool04Oooool2o`00013ooooo0_l00005ooooo`;o00008Oooool2o`00
0003ooooool0003o000002Gooooo0_l0000Looooo`Co00007oooool2o`0001kooooo0_l0000:oooo
o`;o00003_ooool2o`0000Sooooo0_l0000Oooooo`;o00006oooool002Wooooo0_l0000Booooo`;o
00001Oooool2o`0000Wooooo0_l00005ooooo`;o00004?ooool4o`0000gooooo0_l0000Xooooo`;o
00005oooool2o`0000?ooooo0_l00011ooooo`;o00006?ooool4o`0000Sooooo0_l00002ooooo`;o
00004Oooool2o`0000Sooooo0_l0000Kooooo`00:Oooool00ol0003oooooooooo`0Dooooo`;o0000
0_ooool2o`0000Sooooo0_l0000Hooooo`Co0000BOooool2o`0000Gooooo0_l0000Dooooo`;o0000
0_ooool2o`0001gooooo0_l00005ooooo`;o00000_ooool2o`0001cooooo0_l0000>ooooo`;o0000
0oooool2o`0000cooooo0_l00008ooooo`;o00006oooool002Wooooo00?o0000ooooooooool03Ooo
ool2o`0000Gooooo0_l0000<ooooo`;o00006Oooool2o`0001gooooo0_l00007ooooo`;o00005?oo
ool2o`0000Sooooo0_l00002ooooo`;o00000_ooool2o`0000oooooo0_l00006ooooo`;o00000_oo
ool2o`0000?ooooo0_l0000Hooooo`;o00001Oooool6o`0001Wooooo0_l00006ooooo`Co00003?oo
ool2o`0003?ooooo000Yooooo`03o`000?oooooooooo00gooooo0_l0000eooooo`;o00005_ooool2
o`000003ooooool0003o000000Cooooo0_l0000Dooooo`;o00001Oooool2o`000003ooooool0003o
000000Kooooo0_l0000:ooooo`;o00000oooool2o`0000oooooo0_l0000?ooooo`Go00000oooool2
o`0000;ooooo0_l00004ooooo`;o00006oooool2o`0000Kooooo1?l00004ooooo`;o00005_ooool2
o`0000[ooooo0_l0000Gooooo`00:Oooool00ol0003oooooooooo`0Xooooo`;o00003?ooool2o`00
00cooooo0_l0000Iooooo`;o00008Oooool2o`0000oooooo0_l00004ooooo`;o00009Oooool5o`00
00?ooooo0_l00002ooooo`;o0000<Oooool2o`0001Kooooo0_l00004ooooo`;o00001?ooool2o`00
00Kooooo0_l0000?ooooo`00:Oooool2o`0001Sooooo0_l0000?ooooo`;o00003?ooool2o`0000;o
oooo0_l0001?ooooo`;o00001_ooool2o`000003ooooool0003o0000073ooooo0_l0000Cooooo`;o
00001_ooool2o`0000Cooooo0_l0000?ooooo`00:Oooool2o`0001Sooooo0_l0000Eooooo`;o0000
2_ooool2o`0001cooooo0_l0000Aooooo`;o00001_ooool2o`0000Wooooo1Ol00008ooooo`;o0000
2Oooool4o`00063ooooo0_l0000<ooooo`;o00006oooool2o`0001Gooooo000Yooooo`;o00009ooo
ool2o`0000Kooooo1_l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01?o^
k^ko<S8bo`000?lb<S82o`0000?ooooo0ol0000=ooooo`;o00004Oooool7o`000008ooooool0003o
0000onk^k_lb<S;o0000oc8b<_o^k^h3ooooo`03onk^k_l0003o000000?o00005Oooool2o`00013o
oooo00?oV9RHoa0@4?l000000_l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Cooooo0_l00004ooooo`?o00000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00?ok^k^oc8b<_l000000_l0000>ooooo`;o00001?ooool2o`0001?ooooo00Go
A4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo000Yooooo`03o`000?oooooooooo00oooooo0_l00005ooooo`;o
00003_ooool2o`0000Cooooo0_l00004ooooo`?o00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00CoMgMgoiRHV?ooooooV9RH0_l00003ooooo`?o00003oooool3o`0000Kooooo0_l00008
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01?mgMgOo0000o`000?nHV9P2o`0000;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0Fooooo`Co00003?ooool2o`000003oa0@4?nj^[[ooooo00;o
00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?oMgMgoiRHV?ooool00_l0000Toooo
o`;o00001Oooool2o`0000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`;o000000CoV9RH
oooooonHV9SoMgMg0oooool2o`0000Wooooo0_l00004ooooo`;o00005_ooool02OmgMgOo<S8boooo
ooooooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0
02Wooooo0ol00003ooooo`;o00002Oooool3o`0000Gooooo0_l0000Dooooo`;o00001?ooool3o`00
00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41005_oo
ool3o`0000Kooooo0_l00009ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00?o410@o`000?l000000ol0
0002ooooo`05oa0@4?ooooooooooooooool@41006?ooool2o`0000cooooo0_l00004ooooo`05o`00
0?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00;ooooo0_l0000Xoooo
o`Go00000oooool01Ol@413ooooooooooooooooo410@00;ooooo0_l00003ooooo`04oa0@4?l0003o
0000ooooo`;o00004Oooool2o`0001Gooooo00Co0000oooooooooooo410@0oooool01Ol@413ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool00Oooool002Wooooo0ol00003ooooo`;o0000
2Oooool2o`0002;ooooo0_l00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000cooooo0_l0000Eooooo`;o00001_ooool00onHV9So8B4Qonk^kP03oooo
o`03o`000?oooooooooo00;o00000_ooool2o`0000?ooooo00?o0000ooooooooool0:Oooool00onY
ZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooooooooooo
ool2o`0002Oooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000000?o
oooo00Co0000oooooooooooooooo0ol0000Dooooo`;o00005?ooool01OmgMgOo<S8boooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo007ooooo000Y
ooooo`03o`000?oooooooooo02Sooooo0_l00008ooooo`;o00000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`;o00002?ooool2o`0000?ooooo
0_l0000@ooooo`;o00001oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool0
00000_ooool2o`0000?ooooo00?o0000ooooooooool0:?ooool00ol@413o0000okZj^P03ooooo`05
o`000?ooooooooooooooool000000oooool01?l0003oooooooooooooool2o`0002Oooooo00CogMgM
oeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`00000Yooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`00:Oooool00ol0003oooooooooo`07
ooooo`;o00004_ooool2o`0000_ooooo0_l00006ooooo`?o00001?ooool01Ol@413ooooooooooooo
oooo410@00?ooooo00Go410@oooooooooooooooooa0@4002ooooo`;o00003Oooool2o`0001[ooooo
00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@
413oooooooooo`0Yooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@41001oooool2o`00023ooooo00?oMgMgolc<c?l000001?oo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4009ooooo`;o
00007_ooool00ol0003oooooooooo`04ooooo`05oa0@4?oooooo0000o`000?l@41000oooool01Ol@
413ooooooooooooooooo410@00?ooooo000Yooooo`Co00001Oooool3o`0001;ooooo0_l00003oooo
o`;o00003_ooool3o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL0:Oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:?ooool01Ol@413oV9RHoooooonj^[[o
000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1_ooool3o`00023ooooo00?ok^k^odA4A?l000000oooool2o`000004oiRHV?ooooooV9RHogMgM`?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`;o00001?ooool3o`0001kooooo00?o0000oooo
ooooool01?ooool01OmgMgOoV9RHo`000?l0003oMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`00:Oooool4o`0000Gooooo0_l0000Hooooo`;o00003_ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Wooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`04onk^k_lb<S;o0000oc8b<P;o00000_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00gooooo0_l0000Iooooo`05ojVYZOl0003o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`;o
00001?ooool2o`0000Kooooo1?l0000Booooo`05ogMgMol0003o0000o`000?ooool00_l000001?lb
<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool2o`0000Cooooo0_l0
0004ooooo`;o00002?ooool2o`0000oooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Yooooo`;o00005?ooool2o`0000kooooo
0_l0000Looooo`;o00004?ooool2o`0000Wooooo0_l0000Iooooo`;o00000_ooool2o`00013ooooo
0_l0000Jooooo`;o00002Oooool2o`0001?ooooo0_l00004ooooo`Ko00005?ooool2o`0001gooooo
0_l00008ooooo`;o00009_ooool002Wooooo00?o0000ooooooooool04oooool2o`0000kooooo0_l0
000Looooo`;o00004?ooool2o`0000Wooooo0_l0000Mooooo`;o00003Oooool2o`0002Sooooo0_l0
000Iooooo`;o0000JOooool002Wooooo00?o0000ooooooooool0<Oooool2o`0001kooooo0_l0000d
ooooo`;o00000oooool2o`00017ooooo0_l0001>ooooo`;o00004?ooool2o`0003Wooooo000Yoooo
o`03o`000?oooooooooo00Wooooo0_l0000Vooooo`;o00001oooool2o`0001Gooooo0_l0000Aoooo
o`;o00008Oooool2o`0001Kooooo0_l0000Jooooo`;o0000;?ooool2o`0000Cooooo0_l0000@oooo
o`;o00002Oooool2o`0000kooooo0_l0000Nooooo`00:Oooool01?l0003oooooooooooooool2o`00
00;ooooo0_l00002ooooo`;o00002Oooool2o`0002Cooooo0_l0000Xooooo`;o00003oooool2o`00
00Kooooo0_l0000kooooo`?o00001?ooool2o`0002Kooooo0_l0000Qooooo`;o00003_ooool2o`00
01kooooo000Qoooooooo0000A?l00004ooooo`00:Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`;o0000
0_ooool2o`000005ooooool0003o0000o`000?ooool00ol00003ooooo`?o00003?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool2o`0000;o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool2o`0000;ooooo0ol00006ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?o
oooo0_l00005ooooo`04o`000?ooooooooooooooo`;o00001_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Sooooo0_l0000<ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool00_l000000ooooooo0000o`000002ooooo`Co00002_ooool00ol0003oooooooooo`0:oooo
o`00:Oooool00ol0003oooooooooo`0Booooo`;o00004oooool2o`0000;ooooo0_l0000;ooooo`?o
0000:oooool2o`00013ooooo00?o0000ooooooooool06Oooool2o`000003ooooool0003o000001co
oooo00?o0000ooooooooool03oooool2o`0001Gooooo1?l00009ooooo`?o00001?ooool00ol0003o
ooooooooo`08ooooo`;o00004_ooool2o`0000Oooooo0_l000000ooooooo0000o`000002ooooo`;o
00000oooool2o`0000Oooooo00?o0000ooooooooool02_ooool002Wooooo00Co0000ooooool0003o
00004Oooool2o`0000Gooooo0_l0001;ooooo`;o0000;?ooool2o`000003ooooool0003o000001[o
oooo0_l0000Booooo`;o00005oooool2o`0000;ooooo0_l00005ooooo`?o00002oooool2o`0001Co
oooo1?l00007ooooo`;o00002_ooool2o`0000Gooooo0_l0000=ooooo`00:Oooool01?l0003ooooo
o`000?l0000Gooooo`?o0000<Oooool2o`0003?ooooo0_l0000`ooooo`;o00009?ooool2o`0000Wo
oooo0_l0000Cooooo`;o00005?ooool2o`0001Kooooo0ol00003ooooo`;o00003Oooool002Wooooo
0_l0000Iooooo`;o00007?ooool2o`0001Cooooo0_l00008ooooo`;o00005_ooool2o`0000;ooooo
0_l00006ooooo`;o00001Oooool4o`0004Cooooo1?l0000<ooooo`;o00002oooool2o`0001Cooooo
0_l00004ooooo`;o00004Oooool2o`00013ooooo1_l0000?ooooo`00:Oooool00ol0003ooooooooo
o`0<ooooo`;o0000:?ooool2o`0000Sooooo0_l0000Dooooo`;o00005_ooool2o`0000;ooooo0_l0
0006ooooo`;o00001oooool2o`0002Gooooo0_l0000Gooooo`;o00001?ooool4o`0001Wooooo0_l0
000Dooooo`;o00001?ooool2o`0000cooooo0_l00003ooooo`;o00004Oooool5o`0000oooooo000Y
ooooo`03o`000?oooooooooo00[ooooo1?l0000booooo`;o00002?ooool2o`0000Sooooo0_l00014
ooooo`;o00003_ooool2o`0001Oooooo0_l00009ooooo`;o0000@?ooool2o`0002[ooooo000Yoooo
o`03o`000?oooooooooo00[ooooo0_l0000Eooooo`;o00004_ooool2o`0000Sooooo0_l00009oooo
o`;o00002?ooool2o`000003ooooool0003o000001Cooooo0_l0000Jooooo`;o00002_ooool2o`00
00?ooooo0_l0000booooo`;o00004Oooool2o`0005Wooooo000Yooooo`03o`000?oooooooooo027o
oooo0_l0000Booooo`;o00001?ooool2o`0000;ooooo0_l0000Fooooo`;o00003Oooool2o`0000Go
oooo0_l0000Jooooo`;o00002_ooool2o`0001Cooooo0_l0000>ooooo`;o00000_ooool2o`0000oo
oooo0_l00002ooooo`;o00002oooool2o`0001Gooooo0_l0000Booooo`;o00006oooool2o`00017o
oooo000Yooooo`;o00000oooool2o`0000Wooooo0_l0000Jooooo`;o00004?ooool2o`0001Cooooo
0_l0000Cooooo`;o0000>_ooool2o`0000?ooooo0_l00002ooooo`;o00003_ooool2o`0000;ooooo
0_l0000?ooooo`;o00000_ooool4o`0000?ooooo0_l0000Kooooo`;o00004_ooool2o`0000Sooooo
0_l0000Aooooo`;o00004Oooool002Wooooo00?o0000ooooooooool00_ooool2o`0000Wooooo0_l0
000Fooooo`;o00000_ooool2o`0002Kooooo0_l0000Kooooo`;o0000<_ooool2o`000003ooooool0
003o000000;o00002_ooool2o`00017ooooo0_l0000>ooooo`;o00000oooool4o`0002Gooooo0_l0
000<ooooo`;o00000_ooool2o`0000?ooooo0_l0000Oooooo`00:Oooool00ol0003oooooooooo`08
ooooo`;o00006oooool2o`0000?ooooo0_l00008ooooo`;o00003?ooool2o`0001Gooooo0_l0000C
ooooo`;o00006?ooool2o`0001Wooooo1?l00007ooooo`;o00000oooool2o`00017ooooo0_l0000E
ooooo`;o00001oooool3o`0000Gooooo0_l0000Dooooo`;o00003?ooool2o`0000Cooooo0_l00000
1?oooooo0000o`000?l00006ooooo`;o00005_ooool002Wooooo00?o0000ooooooooool02?ooool2
o`0001?ooooo0_l0000;ooooo`;o00002?ooool2o`0000cooooo0_l0000Eooooo`;o0000:Oooool2
o`0000;ooooo0_l0000Fooooo`;o000000?oooooo`000?l000002Oooool2o`0002Oooooo0_l0000=
ooooo`?o00001Oooool2o`0002Sooooo0_l00002ooooo`Co00001?ooool2o`0001Kooooo000Yoooo
o`03o`000?oooooooooo00[ooooo1?l00007ooooo`;o00001_ooool2o`0002kooooo0_l0000eoooo
o`;o00006_ooool2o`000003ooooool0003o000000cooooo0ol0000Sooooo`;o0000AOooool2o`00
01cooooo000Yooooo`;o00002oooool4o`0000Oooooo0_l0000Wooooo`;o00003Oooool2o`0000Wo
oooo0_l0000>ooooo`;o00006?ooool2o`0002?ooooo0_l00008ooooo`?o0000@Oooool2o`0001Ko
oooo0_l0000]ooooo`00:Oooool00ol0003oooooooooo`0Booooo`;o00002_ooool2o`0001kooooo
0_l0000Hooooo`;o00001Oooool4o`0000Gooooo0_l0000Hooooo`;o00008oooool2o`0000Cooooo
0_l0000:ooooo`;o00003oooool2o`0000;ooooo0_l00009ooooo`;o00006Oooool3o`0001Kooooo
0_l0000]ooooo`00:Oooool00ol0003oooooooooo`0Booooo`;o00002_ooool4o`0003gooooo1?l0
001:ooooo`;o00002_ooool2o`0000oooooo0_l00002ooooo`;o00002Oooool2o`0001Wooooo0_l0
0016ooooo`00:Oooool00ol0003oooooooooo`0Pooooo`;o0000Coooool2o`0001[ooooo0_l0000O
ooooo`;o0000Doooool2o`0000Wooooo0_l0000Booooo`;o00006?ooool002Wooooo00?o0000oooo
ooooool0;Oooool2o`0004;ooooo0_l0000Booooo`;o00001_ooool2o`0001Gooooo0_l00008oooo
o`;o0000;_ooool2o`0000Oooooo0_l0000Jooooo`;o00002Oooool2o`0001;ooooo0_l00008oooo
o`;o00003_ooool002Wooooo0_l0000^ooooo`;o0000<oooool2o`00027ooooo0_l0000Dooooo`Co
00001Oooool3o`0000oooooo0_l0000Eooooo`;o00002Oooool2o`0000Cooooo0_l00007ooooo`Co
0000=oooool2o`0000Sooooo0_l0000>ooooo`00:Oooool00ol0003oooooooooo`0Gooooo`;o0000
00?oooooo`000?l00000A_ooool2o`0003Oooooo1?l00006ooooo`;o00003oooool2o`0000Cooooo
0_l0000?ooooo`;o00002Oooool2o`0000kooooo0ol0001Aooooo`001_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Go
oooo00?o0000ooooooooool05oooool2o`000003ooooool0003o0000043ooooo0_l0000<ooooo`;o
00004oooool2o`0003_ooooo0_l0000Zooooo`;o0000@oooool2o`0000gooooo0006ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0G?ooool2o`0000?ooooo0_l00007oooo
o`;o00001Oooool2o`0000cooooo0_l0000Xooooo`;o0000MOooool2o`0000_ooooo0_l0000=oooo
o`001_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo04oooooo0_l0000@ooooo`;o00003_ooool2o`00
03Kooooo0_l0000:ooooo`;o00009Oooool2o`0001gooooo0_l0000Sooooo`;o00000oooool2o`00
01Gooooo0006ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07oooo
o`03ogMgMolb<S;ooooo00Cooooo0ol00018ooooo`;o00001Oooool2o`0002_ooooo0_l0000Boooo
o`;o00002oooool2o`0000?ooooo0_l0000Aooooo`Co00002?ooool2o`0001Wooooo0_l00004oooo
o`;o00002?ooool2o`0000Cooooo0_l00007ooooo`;o0000:?ooool2o`0001Gooooo0006ooooo`05
o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01Oooool00ol0003oooooooooo`02o`0004Kooooo0_l00004ooooo`;o0000;?ooool2
o`0001;ooooo1?l00009ooooo`;o00000oooool2o`0001?ooooo0_l00008ooooo`;o000000?ooooo
o`000?l000001oooool2o`0001?ooooo0_l00008ooooo`;o00001?ooool2o`0004Sooooo0006oooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool00_l0001<ooooo`;o00007?ooool2o`0002Cooooo0_l0000;
ooooo`;o00007?ooool2o`0000Gooooo0_l00007ooooo`;o0000KOooool000Kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo04?ooooo0_l0000Wooooo`;o0000<Oooool2o`0001cooooo0_l0
000Looooo`;o0000;?ooool2o`0000;ooooo0_l0000]ooooo`001_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003ooooo
ooooo`04ooooo`;o00005_ooool2o`0002Gooooo0_l000000ooooooo0000o`000006ooooo`;o0000
=oooool2o`0000Wooooo0_l00017ooooo`;o0000;?ooool2o`0000;ooooo0_l0000]ooooo`00:Ooo
ool2o`0000Gooooo0_l000000ooooooo0000o`000002o`00017ooooo0_l0000Jooooo`;o00003?oo
ool2o`0000Kooooo0_l00003ooooo`;o00006_ooool2o`0001Kooooo0_l00009ooooo`;o00007?oo
ool2o`0002[ooooo0_l000000ooooooo0000o`00001>ooooo`;o00002oooool002Wooooo00?o0000
ooooooooool01Oooool6o`0000oooooo0_l0000Booooo`;o00002?ooool2o`00017ooooo0_l00006
ooooo`;o00006_ooool2o`0001Wooooo0_l0000Tooooo`;o00002?ooool2o`00023ooooo0_l00000
0ooooooo0000o`000019ooooo`;o00000oooool2o`0000_ooooo000Yooooo`03o`000?oooooooooo
00Gooooo0_l00004ooooo`;o00000_ooool2o`0000Cooooo0_l00003ooooo`;o00004_ooool2o`00
01_ooooo0_l0000>ooooo`;o00001oooool2o`00013ooooo0_l00008ooooo`;o00002?ooool2o`00
01cooooo0_l00006ooooo`;o00002?ooool2o`0002Oooooo0_l0000cooooo`;o00004?ooool2o`00
013ooooo000Yooooo`03o`000?oooooooooo00_ooooo0_l00002ooooo`;o00001?ooool2o`00013o
oooo0_l0000Dooooo`;o000000?oooooo`000?l000001oooool2o`00013ooooo0_l00007ooooo`;o
00004?ooool2o`0000Sooooo0_l00004ooooo`;o00008?ooool2o`0000Kooooo0_l00003ooooo`;o
0000:_ooool4o`0000Sooooo0_l000001?oooooo0000o`000?l0000Tooooo`?o00008_ooool002Wo
oooo00?o0000ooooooooool01?ooool2o`00027ooooo0_l0000Dooooo`;o000000?oooooo`000?l0
00001oooool2o`0003_ooooo0_l0000]ooooo`;o0000:_ooool2o`0000[ooooo0_l000001?oooooo
0000o`000?l0000Tooooo`;o00008oooool002Wooooo0_l00005ooooo`;o0000=Oooool2o`0004Oo
oooo0_l0000/ooooo`;o00008_ooool2o`0000;ooooo0_l0000Kooooo`;o0000@oooool002Wooooo
00?o0000ooooooooool0>oooool2o`0004Oooooo0_l0000/ooooo`;o00008_ooool2o`0000;ooooo
0_l0000Kooooo`;o0000@oooool002Wooooo00?o0000ooooooooool0JOooool2o`0000Cooooo0_l0
000kooooo`;o0000Joooool2o`00027ooooo000Yooooo`03o`000?oooooooooo00;ooooo0_l0000m
ooooo`;o00009_ooool2o`0000Cooooo0_l0000kooooo`;o00006_ooool2o`0004oooooo0_l0000Q
ooooo`00:Oooool00ol0003oooooooooo`02ooooo`;o00003?ooool2o`0002Gooooo0_l00008oooo
o`;o0000;Oooool2o`0004Kooooo0_l0000>ooooo`;o0000;?ooool2o`0000oooooo1?l0000aoooo
o`00:Oooool2o`00017ooooo0_l0000=ooooo`;o00005_ooool2o`0003Oooooo0_l0000Rooooo`;o
00008_ooool2o`0003cooooo0_l0000?ooooo`Co0000<Oooool002Wooooo00Co0000oooooooooooo
oooo0_l0000Looooo`;o00001?ooool2o`0002_ooooo0_l00010ooooo`;o00001_ooool2o`0002;o
oooo0_l0000Mooooo`;o00008?ooool2o`00013ooooo0_l0000Booooo`;o00004oooool002Wooooo
00Co0000oooooooooooooooo0_l0000Looooo`;o00000oooool3o`0001kooooo0_l0000;ooooo`;o
00005Oooool2o`00037ooooo0_l0000Rooooo`;o00007Oooool2o`00023ooooo0_l0000@ooooo`;o
00004_ooool2o`0001?ooooo000Yooooo`03o`000?oooooooooo013ooooo0_l0000=ooooo`;o0000
0oooool2o`0000oooooo0_l0000>ooooo`;o00005oooool2o`0000Wooooo0_l00009ooooo`;o0000
Foooool2o`0006Wooooo000Yooooo`03o`000?oooooooooo013ooooo0_l0000Nooooo`;o00000ooo
ool2o`0000kooooo0_l0000?ooooo`;o00001_ooool2o`0000?ooooo0_l0000?ooooo`;o0000Fooo
ool2o`0003;ooooo0_l0000eooooo`00:Oooool2o`00037ooooo0_l0000Tooooo`;o00002oooool2
o`000:3ooooo0_l0000eooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo0?oooooo4?ooool2o`0002_ooooo000>ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3o
oooooa3ooooo0_l0000[ooooo`003_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000
ooooooooool00oooool3o`000?oooooo?Oooool000kooooo00Go0000ooooooooooooooooo`00000?
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0Moooool2o`000<?ooooo000>oooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool0Moooool2o`000<?ooooo000>ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07[ooooo0_l0000@ooooo`;o0000[_oo
ool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0>Oooool2o`0003oooooo0_l0000@ooooo`;o0000[_ooool000kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`0001kooooo0_l0000<ooooo`;o00003?oo
ool2o`000?oooooo0_ooool002Wooooo00?o0000ooooooooool07Oooool2o`0000cooooo0_l0002R
ooooo`;o00008_ooool2o`0001Kooooo0_l0000_ooooo`00:Oooool00ol0003oooooooooo`3?oooo
o`;o00008_ooool2o`0001Kooooo0_l0000_ooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo
00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo?Oooool0
00Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@
413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03
ooooo`?o0000oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Q
ooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool0
00Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@
oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo
1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
01oooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo?Oooool0027o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`00
0?oooooooooo00Gooooo0ol0003oooooocgooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001oooooo00?oEEEEofIVI_l00000
oooooom7ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .36732 Mdot
.02762 .25115 Mdot
.02952 .28731 Mdot
.03143 .33494 Mdot
.03333 .36035 Mdot
.03524 .37727 Mdot
.03714 .3183 Mdot
.03905 .44912 Mdot
.04095 .37198 Mdot
.04286 .34305 Mdot
.04476 .33557 Mdot
.04667 .45031 Mdot
.04857 .34198 Mdot
.05048 .34893 Mdot
.05238 .44589 Mdot
.05429 .25965 Mdot
.05619 .35594 Mdot
.0581 .34974 Mdot
.06 .29278 Mdot
.0619 .38967 Mdot
.06381 .35197 Mdot
.06571 .24314 Mdot
.06762 .26211 Mdot
.06952 .36242 Mdot
.07143 .42741 Mdot
.07333 .25529 Mdot
.07524 .3028 Mdot
.07714 .27919 Mdot
.07905 .37234 Mdot
.08095 .24656 Mdot
.08286 .37203 Mdot
.08476 .37333 Mdot
.08667 .43661 Mdot
.08857 .29221 Mdot
.09048 .24374 Mdot
.09238 .41176 Mdot
.09429 .23128 Mdot
.09619 .25311 Mdot
.0981 .34992 Mdot
.1 .45053 Mdot
.1019 .42845 Mdot
.10381 .25225 Mdot
.10571 .31358 Mdot
.10762 .35245 Mdot
.10952 .38442 Mdot
.11143 .3089 Mdot
.11333 .34926 Mdot
.11524 .32281 Mdot
.11714 .35648 Mdot
.11905 .37716 Mdot
.12095 .31695 Mdot
.12286 .305 Mdot
.12476 .47541 Mdot
.12667 .27057 Mdot
.12857 .28444 Mdot
.13048 .40953 Mdot
.13238 .44953 Mdot
.13429 .35762 Mdot
.13619 .25939 Mdot
.1381 .38969 Mdot
.14 .29277 Mdot
.1419 .27086 Mdot
.14381 .34485 Mdot
.14571 .26102 Mdot
.14762 .43078 Mdot
.14952 .39432 Mdot
.15143 .33823 Mdot
.15333 .27187 Mdot
.15524 .25379 Mdot
.15714 .37768 Mdot
.15905 .34044 Mdot
.16095 .27364 Mdot
.16286 .34404 Mdot
.16476 .31337 Mdot
.16667 .34508 Mdot
.16857 .29877 Mdot
.17048 .47549 Mdot
.17238 .25853 Mdot
.17429 .32549 Mdot
.17619 .33235 Mdot
.1781 .41047 Mdot
.18 .25158 Mdot
.1819 .33935 Mdot
.18381 .24705 Mdot
.18571 .43676 Mdot
.18762 .25637 Mdot
.18952 .35829 Mdot
.19143 .34503 Mdot
.19333 .36842 Mdot
.19524 .2684 Mdot
.19714 .42484 Mdot
.19905 .36703 Mdot
.20095 .29371 Mdot
.20286 .33218 Mdot
.20476 .27528 Mdot
.20667 .34359 Mdot
.20857 .34995 Mdot
.21048 .31968 Mdot
.21238 .47929 Mdot
.21429 .3667 Mdot
.21619 .3515 Mdot
.2181 .37683 Mdot
.22 .44902 Mdot
.2219 .33545 Mdot
.22381 .40318 Mdot
.22571 .27723 Mdot
.22762 .32555 Mdot
.22952 .32044 Mdot
.23143 .29555 Mdot
.23333 .37911 Mdot
.23524 .35051 Mdot
.23714 .33733 Mdot
.23905 .3688 Mdot
.24095 .40935 Mdot
.24286 .47011 Mdot
.24476 .28018 Mdot
.24667 .27276 Mdot
.24857 .41116 Mdot
.25048 .39615 Mdot
.25238 .23554 Mdot
.25429 .33999 Mdot
.25619 .31675 Mdot
.2581 .31839 Mdot
.26 .36774 Mdot
.2619 .37996 Mdot
.26381 .32587 Mdot
.26571 .40209 Mdot
.26762 .30307 Mdot
.26952 .30094 Mdot
.27143 .27645 Mdot
.27333 .26197 Mdot
.27524 .32863 Mdot
.27714 .44709 Mdot
.27905 .38302 Mdot
.28095 .34102 Mdot
.28286 .34297 Mdot
.28476 .23627 Mdot
.28667 .38657 Mdot
.28857 .3422 Mdot
.29048 .44254 Mdot
.29238 .44589 Mdot
.29429 .22405 Mdot
.29619 .33616 Mdot
.2981 .26524 Mdot
.3 .35551 Mdot
.3019 .40061 Mdot
.30381 .42813 Mdot
.30571 .43619 Mdot
.30762 .32504 Mdot
.30952 .3358 Mdot
.31143 .34051 Mdot
.31333 .37816 Mdot
.31524 .26281 Mdot
.31714 .36646 Mdot
.31905 .28226 Mdot
.32095 .39185 Mdot
.32286 .25421 Mdot
.32476 .33212 Mdot
.32667 .40924 Mdot
.32857 .23154 Mdot
.33048 .24919 Mdot
.33238 .30292 Mdot
.33429 .32452 Mdot
.33619 .43327 Mdot
.3381 .41641 Mdot
.34 .30757 Mdot
.3419 .35842 Mdot
.34381 .42442 Mdot
.34571 .41071 Mdot
.34762 .25264 Mdot
.34952 .25257 Mdot
.35143 .39329 Mdot
.35333 .30467 Mdot
.35524 .25971 Mdot
.35714 .3576 Mdot
.35905 .33893 Mdot
.36095 .43607 Mdot
.36286 .33107 Mdot
.36476 .39038 Mdot
.36667 .28999 Mdot
.36857 .36551 Mdot
.37048 .27696 Mdot
.37238 .44585 Mdot
.37429 .28064 Mdot
.37619 .42407 Mdot
.3781 .32265 Mdot
.38 .363 Mdot
.3819 .29762 Mdot
.38381 .37126 Mdot
.38571 .43656 Mdot
.38762 .33063 Mdot
.38952 .34747 Mdot
.39143 .40076 Mdot
.39333 .28136 Mdot
.39524 .29167 Mdot
.39714 .44327 Mdot
.39905 .40473 Mdot
.40095 .44882 Mdot
.40286 .34121 Mdot
.40476 .40757 Mdot
.40667 .28636 Mdot
.40857 .31921 Mdot
.41048 .31619 Mdot
.41238 .26881 Mdot
.41429 .36096 Mdot
.41619 .42296 Mdot
.4181 .34259 Mdot
.42 .32619 Mdot
.4219 .38502 Mdot
.42381 .33869 Mdot
.42571 .33308 Mdot
.42762 .33038 Mdot
.42952 .29633 Mdot
.43143 .2636 Mdot
.43333 .41108 Mdot
.43524 .26434 Mdot
.43714 .35389 Mdot
.43905 .27807 Mdot
.44095 .43133 Mdot
.44286 .32644 Mdot
.44476 .3926 Mdot
.44667 .45225 Mdot
.44857 .27817 Mdot
.45048 .26642 Mdot
.45238 .40718 Mdot
.45429 .41427 Mdot
.45619 .25736 Mdot
.4581 .36049 Mdot
.46 .26379 Mdot
.4619 .30071 Mdot
.46381 .44581 Mdot
.46571 .30365 Mdot
.46762 .28135 Mdot
.46952 .27085 Mdot
.47143 .42399 Mdot
.47333 .37179 Mdot
.47524 .30409 Mdot
.47714 .33255 Mdot
.47905 .25401 Mdot
.48095 .32168 Mdot
.48286 .31776 Mdot
.48476 .3365 Mdot
.48667 .27113 Mdot
.48857 .36036 Mdot
.49048 .41868 Mdot
.49238 .34116 Mdot
.49429 .37854 Mdot
.49619 .26643 Mdot
.4981 .26526 Mdot
.5 .37394 Mdot
.5019 .34393 Mdot
.50381 .34177 Mdot
.50571 .40974 Mdot
.50762 .28329 Mdot
.50952 .28342 Mdot
.51143 .25032 Mdot
.51333 .25774 Mdot
.51524 .26428 Mdot
.51714 .30811 Mdot
.51905 .30587 Mdot
.52095 .44646 Mdot
.52286 .29366 Mdot
.52476 .36611 Mdot
.52667 .30482 Mdot
.52857 .41612 Mdot
.53048 .26435 Mdot
.53238 .37749 Mdot
.53429 .37858 Mdot
.53619 .34769 Mdot
.5381 .35876 Mdot
.54 .40501 Mdot
.5419 .28296 Mdot
.54381 .40876 Mdot
.54571 .29807 Mdot
.54762 .34331 Mdot
.54952 .35079 Mdot
.55143 .25727 Mdot
.55333 .29005 Mdot
.55524 .35234 Mdot
.55714 .32955 Mdot
.55905 .33446 Mdot
.56095 .39074 Mdot
.56286 .35261 Mdot
.56476 .28857 Mdot
.56667 .28981 Mdot
.56857 .23188 Mdot
.57048 .44933 Mdot
.57238 .32509 Mdot
.57429 .30782 Mdot
.57619 .35656 Mdot
.5781 .41681 Mdot
.58 .32504 Mdot
.5819 .40469 Mdot
.58381 .29656 Mdot
.58571 .24953 Mdot
.58762 .44728 Mdot
.58952 .2507 Mdot
.59143 .29645 Mdot
.59333 .24069 Mdot
.59524 .31482 Mdot
.59714 .42057 Mdot
.59905 .44651 Mdot
.60095 .41268 Mdot
.60286 .34231 Mdot
.60476 .34066 Mdot
.60667 .32129 Mdot
.60857 .37705 Mdot
.61048 .43145 Mdot
.61238 .34807 Mdot
.61429 .32505 Mdot
.61619 .26623 Mdot
.6181 .32519 Mdot
.62 .29014 Mdot
.6219 .34846 Mdot
.62381 .32949 Mdot
.62571 .35361 Mdot
.62762 .2724 Mdot
.62952 .38906 Mdot
.63143 .26877 Mdot
.63333 .43605 Mdot
.63524 .26493 Mdot
.63714 .44426 Mdot
.63905 .37066 Mdot
.64095 .22478 Mdot
.64286 .30201 Mdot
.64476 .38555 Mdot
.64667 .2449 Mdot
.64857 .32411 Mdot
.65048 .36221 Mdot
.65238 .32373 Mdot
.65429 .30973 Mdot
.65619 .33623 Mdot
.6581 .45231 Mdot
.66 .2562 Mdot
.6619 .27349 Mdot
.66381 .26773 Mdot
.66571 .28359 Mdot
.66762 .2684 Mdot
.66952 .2595 Mdot
.67143 .37297 Mdot
.67333 .30901 Mdot
.67524 .3027 Mdot
.67714 .36137 Mdot
.67905 .46798 Mdot
.68095 .26434 Mdot
.68286 .26762 Mdot
.68476 .26113 Mdot
.68667 .42561 Mdot
.68857 .31227 Mdot
.69048 .39138 Mdot
.69238 .23905 Mdot
.69429 .32285 Mdot
.69619 .30933 Mdot
.6981 .22461 Mdot
.7 .45103 Mdot
.7019 .23962 Mdot
.70381 .40926 Mdot
.70571 .33275 Mdot
.70762 .29574 Mdot
.70952 .39695 Mdot
.71143 .37579 Mdot
.71333 .45083 Mdot
.71524 .22896 Mdot
.71714 .41938 Mdot
.71905 .44732 Mdot
.72095 .44267 Mdot
.72286 .42544 Mdot
.72476 .27163 Mdot
.72667 .36625 Mdot
.72857 .44533 Mdot
.73048 .44787 Mdot
.73238 .27612 Mdot
.73429 .39627 Mdot
.73619 .26251 Mdot
.7381 .38736 Mdot
.74 .357 Mdot
.7419 .33339 Mdot
.74381 .32389 Mdot
.74571 .23079 Mdot
.74762 .28591 Mdot
.74952 .25486 Mdot
.75143 .232 Mdot
.75333 .25494 Mdot
.75524 .43542 Mdot
.75714 .45943 Mdot
.75905 .23058 Mdot
.76095 .39422 Mdot
.76286 .29211 Mdot
.76476 .39399 Mdot
.76667 .37114 Mdot
.76857 .30556 Mdot
.77048 .44471 Mdot
.77238 .38016 Mdot
.77429 .32483 Mdot
.77619 .32345 Mdot
.7781 .24776 Mdot
.78 .29227 Mdot
.7819 .33447 Mdot
.78381 .41236 Mdot
.78571 .29862 Mdot
.78762 .44466 Mdot
.78952 .32118 Mdot
.79143 .45914 Mdot
.79333 .30635 Mdot
.79524 .3361 Mdot
.79714 .34965 Mdot
.79905 .29475 Mdot
.80095 .45117 Mdot
.80286 .45027 Mdot
.80476 .30612 Mdot
.80667 .31817 Mdot
.80857 .29612 Mdot
.81048 .26129 Mdot
.81238 .37859 Mdot
.81429 .33772 Mdot
.81619 .41722 Mdot
.8181 .33837 Mdot
.82 .26041 Mdot
.8219 .26715 Mdot
.82381 .34963 Mdot
.82571 .30543 Mdot
.82762 .28305 Mdot
.82952 .32159 Mdot
.83143 .32885 Mdot
.83333 .44217 Mdot
.83524 .3085 Mdot
.83714 .24783 Mdot
.83905 .32543 Mdot
.84095 .39303 Mdot
.84286 .27463 Mdot
.84476 .25515 Mdot
.84667 .39084 Mdot
.84857 .36782 Mdot
.85048 .3104 Mdot
.85238 .48267 Mdot
.85429 .34213 Mdot
.85619 .30959 Mdot
.8581 .38212 Mdot
.86 .4441 Mdot
.8619 .33109 Mdot
.86381 .23929 Mdot
.86571 .47012 Mdot
.86762 .32347 Mdot
.86952 .32605 Mdot
.87143 .34647 Mdot
.87333 .41644 Mdot
.87524 .31803 Mdot
.87714 .39048 Mdot
.87905 .32987 Mdot
.88095 .2504 Mdot
.88286 .25464 Mdot
.88476 .26449 Mdot
.88667 .2757 Mdot
.88857 .30593 Mdot
.89048 .44903 Mdot
.89238 .26489 Mdot
.89429 .33645 Mdot
.89619 .27027 Mdot
.8981 .38566 Mdot
.9 .40593 Mdot
.9019 .39673 Mdot
.90381 .33547 Mdot
.90571 .30355 Mdot
.90762 .32853 Mdot
.90952 .45256 Mdot
.91143 .41047 Mdot
.91333 .3473 Mdot
.91524 .24069 Mdot
.91714 .27879 Mdot
.91905 .36449 Mdot
.92095 .39298 Mdot
.92286 .35045 Mdot
.92476 .30329 Mdot
.92667 .3071 Mdot
.92857 .2933 Mdot
.93048 .27085 Mdot
.93238 .33586 Mdot
.93429 .29468 Mdot
.93619 .29809 Mdot
.9381 .3371 Mdot
.94 .26983 Mdot
.9419 .29344 Mdot
.94381 .26612 Mdot
.94571 .33725 Mdot
.94762 .30214 Mdot
.94952 .24998 Mdot
.95143 .39607 Mdot
.95333 .36169 Mdot
.95524 .38429 Mdot
.95714 .25839 Mdot
.95905 .27677 Mdot
.96095 .29706 Mdot
.96286 .47447 Mdot
.96476 .30304 Mdot
.96667 .25515 Mdot
.96857 .26828 Mdot
.97048 .4164 Mdot
.97238 .25733 Mdot
.97429 .37857 Mdot
.97619 .44837 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo05?ooooo0_l0001^ooooo`;o00004?ooool2o`0006Gooooo0006ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0Doooool2o`0006kooooo0_l0000@ooooo`;o0000IOoo
ool000Co00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0=_ooooo0_l00007ooooo`;o00000ooo
ool2o`00057ooooo0006ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^
kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Cooooo`;o0000BOooool2o`0004_ooooo0_l0
000^ooooo`;o00001oooool4o`000003ooooool0003o0000057ooooo0006ooooo`05o`000?oooooo
ooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`0Cooooo`;o0000<Oooool2o`0000Sooooo0_l0000<ooooo`;o0000
Boooool2o`0003Wooooo0_l0001Dooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Kooooo
0_l00008ooooo`;o0000POooool2o`000003ooooool0003o000003;ooooo0_l0000`ooooo`001_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool2o`000:Oooooo0_l0000Nooooo`;o
000000?oooooo`000?l00000<_ooool2o`0000oooooo0_l0000Oooooo`001_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0
003oooooooooo`0:ooooo`;o00000oooool2o`000003ooooool0003o000009oooooo0_l0000@oooo
o`;o0000E?ooool2o`0001oooooo000Yooooo`;o00004?ooool2o`000003ooooool0003o000001co
oooo0_l0000]ooooo`;o0000D?ooool2o`0001;ooooo0_l0000Xooooo`;o00004Oooool2o`0003So
oooo000Yooooo`;o00005oooool2o`0001Kooooo1?l0000]ooooo`;o00000oooool3o`0003;ooooo
0_l0000Fooooo`?o0000>oooool2o`00017ooooo0_l0000<ooooo`;o00005?ooool2o`0001Cooooo
000Yooooo`;o00003Oooool2o`0000Kooooo1?l0000?ooooo`;o00001Oooool2o`0002cooooo0_l0
0006ooooo`?o0000:?ooool2o`0000Sooooo0_l0000Gooooo`;o0000<_ooool3o`0001_ooooo0_l0
000:ooooo`;o00005?ooool2o`0000?ooooo0_l0000?ooooo`00:Oooool00ol0003oooooooooo`0<
ooooo`;o00001_ooool2o`00017ooooo0_l00003ooooo`;o00000oooool2o`0002Wooooo0_l0000Y
ooooo`;o00001_ooool2o`0000Wooooo0_l0000:ooooo`;o00008Oooool2o`0001_ooooo0ol0000K
ooooo`;o00002_ooool2o`0001Kooooo0_l000000ooooooo0000o`000002o`0000gooooo000Yoooo
o`03o`000?oooooooooo00Kooooo0_l00002ooooo`;o00005?ooool2o`000003ooooool0003o0000
00Oooooo0_l00003ooooo`;o00006_ooool2o`0001Sooooo0_l0000Nooooo`;o00004Oooool2o`00
00[ooooo0_l0000Qooooo`;o000000?oooooo`000?l000000oooool2o`0002Kooooo0_l000000ooo
oooo0000o`00000Zooooo`;o00000oooool2o`0000gooooo000Yooooo`;o00001oooool2o`0000;o
oooo0_l0000Dooooo`;o000000?oooooo`000?l00000:?ooool2o`0000Gooooo0_l00004ooooo`;o
00002oooool2o`0001Kooooo1?l00006ooooo`;o00002_ooool2o`0000?ooooo0_l00003ooooo`;o
00008?ooool2o`0000Wooooo0_l00002ooooo`?o00003_ooool2o`0001Kooooo0_l000000ooooooo
0000o`00000Cooooo`;o000000?oooooo`000?l000009_ooool002Wooooo00?o0000ooooooooool0
E?ooool2o`0000Cooooo0_l0000Sooooo`Co00000_ooool2o`0000;ooooo0_l00009ooooo`?o0000
0oooool2o`0000?ooooo0_l0000Jooooo`;o00001?ooool2o`0000Oooooo0_l00004ooooo`;o0000
3oooool2o`0001[ooooo0_l0000Booooo`;o000000?oooooo`000?l000003_ooool2o`0000Kooooo
0_l0000>ooooo`00:Oooool00ol0003oooooooooo`0Mooooo`;o00000oooool2o`0000cooooo1Ol0
0002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Wo
oooo1Ol00003ooooo`04onk^k_lb<S;o0000oc8b<P;o00000_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo0_l00005ooooo`;o00000oooool2o`000003ooooool0003o000001Cooooo00GoV9RH
oa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01_o^k^ko0000
o`000?lb<S;ok^k^ooooo`;o00002?ooool3o`0000?ooooo0_l0000Gooooo`;o000000Wo410@oooo
ooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h00oooool01_o^k^ko<S8bo`000?lb<S;ok^k^oooo
o`;o00005_ooool2o`0000Wooooo0_l000000ooooooo0000o`000003o`000004oc8b<_oMgMgooooo
ooooo`?o000000?o<S8bonk^k_ooool00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Y
ooooo`03o`000?oooooooooo01gooooo0_l00003ooooo`;o00000_ooool4o`0000Sooooo0ol00002
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00;o0000
9oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00CoMgMgoiRHV?ooooooV9RH0_l00002oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02_ooool2o`0000?ooooo0_l0000Gooooo`05oa0@4?nj^[[o
ooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00CoMgMgoiRHV?oooooo
V9RH1?l00007ooooo`Co00004Oooool2o`0000[ooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Iooooo`;o00002Oooool2
o`000003ooooool0003o000000?ooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000Yooooo`03o`000?oooooooooo02Ko
oooo1?l00008ooooo`04o`000?ooooooooooooooo`;o00000oooool01Ol@413oooooo`000?l0003o
410@00?ooooo00?o410@o`000?l000001_ooool2o`0001kooooo0_l000000onHV9So8B4Qonk^kP04
ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@02cooooo
00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool2o`00
00Wooooo0_l0000Cooooo`Co00001Oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@41002?ooool2o`0000cooooo0_l0000Eooooo`;o000000?o
oooooa0@4?ooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0
0Oooool002Wooooo0_l0000>ooooo`;o00008oooool01?l0003oooooooooooooool2o`0000?ooooo
00?o0000ooooool000000_l00003ooooo`;o00001oooool2o`0001kooooo0ol000000onHV9So8B4Q
onk^kP03ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooooooool3o`00
0003ooooool0003o000002Kooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`00000Qooooo`;o00001Oooool01?m4A4CogMgMoooo
ool00004ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00Sooooo0_l0000<ooooo`;o00002?ooool2o`0000[ooooo00GoMgMgo`000?l0003oooooo`000003
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`01ooooo`00:Oooool0
0ol0003oooooooooo`0=ooooo`;o00008oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000000oooool01?l0003oooooooooooooool2o`0001Kooooo0_l0000@ooooo`;o0000
00CoooooogMgMomVIVKooooo0ol00003ooooo`05o`000?ooooooooooooooool000000oooool3o`00
0003ooooool0003o000000Cooooo0_l0000;ooooo`;o00002Oooool2o`0000Oooooo00?o410@o`00
0?nj^[X00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
000<ooooo`;o00006_ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000?ooooo0_l0000Kooooo`;o00001oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool002Wooooo00?o0000ooooooooool07_ooool2o`0001;ooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@400Gooooo`;o00005?ooool01_l0003oooooo`000?l0003o410@ooooo`;o000000Go410@
oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Oooooo0_l0000;ooooo`;o00002Ooo
ool2o`0000Sooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooooooooa0@400<ooooo`;o00006?ooool2o`000004oooooomgMgOoc<c<o`00
00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool2o`0002Cooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooooooooa0@4003ooooo`00:Oooool3o`0001kooooo0_l0000Booooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL09oooool3o`000004okZj^_ooooooV9RHoa0@40?ooooo00GoMgMgoiRHV?l0003o0000ogMg
M`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL09Oooool2o`000006ooooool0003o0000o`000?nj
^[[o00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?l0003o0000ogMg
M`0Vooooo`;o000000Coooooonk^k_m4A4Co00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Yooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wooooo0ol00008
ooooo`;o00001oooool2o`0000oooooo0_l0000<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09oooool2o`000005oiRH
V?l@413o0000ob4Q8Oo<c<`00_ooool2o`000004oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Uooooo`;o000000Koooooo`000?l0003o0000oa0@4?nYZJT3ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?l0003ok^k^02[ooooo00?oMgMgo`00
0?l000000oooool3o`000003oc8b<_o^k^kooooo00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Y
ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`00:Oooool2o`0000Wooooo0_l00007ooooo`;o00003oooool2o`00017ooooo0_l0
0008ooooo`;o0000<oooool2o`0000Wooooo0_l0000Looooo`;o0000>Oooool2o`00013ooooo0_l0
0003ooooo`;o00001Oooool2o`000003ooooool0003o000002Cooooo1_l0000Gooooo`00:Oooool0
0ol0003oooooooooo`0[ooooo`;o00002?ooool2o`0000Sooooo0_l0000^ooooo`;o00003_ooool2
o`0001cooooo0_l00005ooooo`;o00002_ooool2o`000003ooooool0003o000002?ooooo0_l0000G
ooooo`;o00000oooool2o`000003ooooool0003o000002Cooooo1_l00005ooooo`;o00004?ooool0
02Wooooo00?o0000ooooooooool0:oooool2o`0001kooooo0_l0000Rooooo`;o00006?ooool2o`00
01Wooooo0_l0000:ooooo`;o000000?oooooo`000?l000003_ooool2o`0002cooooo0_l0000_oooo
o`;o000000?oooooo`000?l000000oooool2o`00013ooooo000Yooooo`03o`000?oooooooooo00go
oooo0_l0000=ooooo`;o0000;Oooool2o`0001;ooooo0_l00005ooooo`;o00008Oooool3o`000003
ooooool0003o000000oooooo0_l0000Sooooo`;o00002Oooool2o`0001cooooo0_l0000@ooooo`;o
00006?ooool2o`0000Cooooo0_l00005ooooo`;o00001?ooool2o`0000oooooo000Yooooo`03o`00
0?oooooooooo00gooooo0_l0000=ooooo`;o0000;Oooool2o`0001;ooooo0_l000000ooooooo0000
o`000002ooooo`;o00008_ooool2o`000003ooooool0003o000000cooooo1Ol0000=ooooo`;o0000
7oooool2o`0001cooooo0_l00006ooooo`;o000000?oooooo`000?l000001Oooool2o`000003oooo
ool0003o000000oooooo0_l00004ooooo`;o00001?ooool3o`0000[ooooo0_l0000?ooooo`008Ooo
ooooo`0004Co00001?ooool002Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:
ooooo`Co00002?ooool00ol0003oooooooooo`05ooooo`;o00000_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Sooooo0_l0000;ooooo`03o`000?oooooooooo00?ooooo0_l00004
ooooo`;o00000oooool4o`0000Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool4o`000003ooooool0003o
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo000Yooooo`03o`000?oooooooooo01Oooooo0_l00003ooooo`;o00003?ooool2o`00
00kooooo00?o0000ooooooooool02_ooool2o`0002oooooo0ol0000Eooooo`;o00008_ooool2o`00
01cooooo0_l0000Nooooo`03o`000?oooooooooo01Wooooo0_l0000Oooooo`03o`000?oooooooooo
00[ooooo000Yooooo`04o`000?ooooooooooooooo`;o00006Oooool2o`0001[ooooo0_l00004oooo
o`;o00001oooool3o`0002kooooo0ol0000Eooooo`;o0000H?ooool2o`0000Cooooo0_l0000Doooo
o`;o0000;?ooool002Wooooo00Co0000oooooooooooooooo0_l0000Gooooo`;o00007?ooool2o`00
00Cooooo0_l00008ooooo`;o00009?ooool2o`0000Sooooo0_l0000Eooooo`;o00009oooool2o`00
00_ooooo0ol0000<ooooo`;o00003_ooool2o`0000Sooooo0_l00002ooooo`;o00001?ooool2o`00
00Gooooo0_l0000;ooooo`;o0000;_ooool002Wooooo0_l0000Kooooo`;o00004Oooool2o`0000oo
oooo0_l00009ooooo`;o00003Oooool2o`0000Kooooo0_l0000<ooooo`;o00003?ooool2o`0000Go
oooo0_l0000:ooooo`;o00007?ooool4o`0000Oooooo1Ol00008ooooo`?o00003?ooool2o`0000ko
oooo0_l00008ooooo`;o00003oooool2o`000003ooooool0003o000000Sooooo0_l0000^ooooo`00
:Oooool00ol0003oooooooooo`0]ooooo`;o00003oooool2o`0000Wooooo0_l00002ooooo`;o0000
2Oooool2o`0000Kooooo0_l0000Jooooo`Co00000oooool2o`0002?ooooo0_l00003ooooo`Co0000
2Oooool5o`0002oooooo0_l0000@ooooo`Co00002?ooool2o`000003ooooool0003o000000Oooooo
0_l0000Rooooo`00:Oooool00ol0003oooooooooo`0]ooooo`;o00001oooool2o`0001Gooooo0_l0
000>ooooo`;o00002_ooool2o`0000Kooooo0_l0000:ooooo`?o00003_ooool2o`0001Sooooo0_l0
000Cooooo`;o00006Oooool2o`0000Wooooo0_l0000Kooooo`;o00002?ooool2o`0000?ooooo0_l0
0007ooooo`;o00008_ooool002Wooooo00Co0000ooooool0003o00000_ooool2o`0002Sooooo0_l0
0007ooooo`;o00001?ooool2o`0001Kooooo0_l00002ooooo`;o00000oooool2o`0000[ooooo0_l0
0006ooooo`;o00002_ooool2o`0000oooooo1?l0000Fooooo`;o00007_ooool2o`0000kooooo0_l0
0009ooooo`;o00002oooool2o`0000;ooooo0_l0000Dooooo`;o00002?ooool2o`000003ooooool0
003o000000Oooooo0_l0000Jooooo`00:Oooool01?l0003oooooo`000?l00002ooooo`;o00008?oo
ool2o`0000Sooooo0_l0000;ooooo`;o00000oooool2o`00017ooooo0_l00002ooooo`;o00003_oo
ool2o`0001?ooooo0_l0000Aooooo`;o00005_ooool2o`0001kooooo0_l0000Vooooo`;o00000_oo
ool2o`0000Cooooo1?l0000Fooooo`;o000000?oooooo`000?l000001oooool4o`000003ooooool0
003o000001Gooooo000Yooooo`;o00001Oooool2o`0001oooooo0_l000000ooooooo0000o`000005
ooooo`;o00004?ooool2o`0000?ooooo0_l00007ooooo`Co00001_ooool2o`0000gooooo0_l0000<
ooooo`;o00000oooool4o`0001Cooooo0_l00002ooooo`;o00007Oooool3o`00047ooooo1?l00009
ooooo`;o00006Oooool2o`000003ooooool0003o000001Gooooo000Yooooo`03o`000?oooooooooo
00;ooooo1?l0000Mooooo`;o00000oooool4o`0000Kooooo0_l00003ooooo`;o00003Oooool2o`00
00Oooooo1?l00006ooooo`;o00006oooool2o`0000?ooooo0_l0000Fooooo`;o000000Coooooo`00
0?l0003o00003?ooool2o`0000oooooo0ol0001>ooooo`;o0000<oooool002Wooooo00?o0000oooo
ooooool00_ooool2o`000003ooooool0003o000001cooooo0_l00004ooooo`?o00001_ooool2o`00
00?ooooo0_l0000iooooo`;o00008_ooool2o`0000Wooooo0_l00002ooooo`;o00004oooool2o`00
0003ooooool0003o000004kooooo0_l0000;ooooo`;o00008?ooool002Wooooo00?o0000oooooooo
ool01Oooool6o`0000Wooooo0_l00003ooooo`;o00007Oooool4o`0000Cooooo0_l0000`ooooo`;o
0000;Oooool2o`0000;ooooo1?l0000Aooooo`;o000000?oooooo`000?l00000=_ooool2o`0000Oo
oooo0_l0000=ooooo`;o00002oooool2o`000003ooooool0003o000001gooooo000Yooooo`03o`00
0?oooooooooo00Oooooo1?l00009ooooo`;o000000?oooooo`000?l000000_l0000Mooooo`Co0000
1?ooool2o`0003oooooo0_l0000Rooooo`Co000000?oooooo`000?l000004_ooool2o`0003Gooooo
0_l00007ooooo`;o00007Oooool2o`0001gooooo000Yooooo`;o00002?ooool2o`0000kooooo0_l0
00000ooooooo0000o`000004ooooo`;o00004?ooool2o`00027ooooo0_l0000<ooooo`;o00000_oo
ool2o`0001Sooooo0_l0000Wooooo`;o00000_ooool2o`0000kooooo0_l0000Sooooo`;o0000Eooo
ool002Wooooo00Co0000ooooool0003o00001_ooool2o`00017ooooo0_l00004ooooo`;o00004?oo
ool2o`00027ooooo0_l0000<ooooo`;o00000_ooool2o`00017ooooo0_l0000<ooooo`;o00002?oo
ool2o`0000kooooo0_l0000:ooooo`;o00007_ooool2o`0001?ooooo0_l00012ooooo`;o00004ooo
ool002Wooooo00Co0000ooooool0003o00002_ooool2o`0006;ooooo0_l00009ooooo`;o00003?oo
ool2o`0000Sooooo0_l0000>ooooo`;o00008_ooool2o`0000Kooooo0_l0001<ooooo`;o00002Ooo
ool2o`0001?ooooo000Yooooo`;o00003?ooool2o`0002Sooooo0_l00003ooooo`;o00003?ooool2
o`00017ooooo0_l0000>ooooo`;o00000_ooool2o`0002cooooo0_l0000Wooooo`;o00005_ooool2
o`0002Gooooo0_l0000Eooooo`;o00007_ooool002Wooooo0_l0000dooooo`Co00000oooool2o`00
00Gooooo0_l00005ooooo`;o00004Oooool2o`0000kooooo0_l0000`ooooo`;o00008oooool2o`00
01[ooooo0_l0000Uooooo`;o0000=Oooool002Wooooo0_l00003ooooo`;o00002_ooool4o`00027o
oooo0_l0000<ooooo`;o0000;Oooool2o`0001_ooooo0_l00006ooooo`;o0000:oooool2o`0000Wo
oooo0_l0000Looooo`;o0000Coooool002Wooooo00?o0000ooooooooool00_ooool2o`0000[ooooo
1?l00009ooooo`;o00007_ooool2o`0003?ooooo0_l0000Kooooo`;o00001_ooool2o`00027ooooo
0_l0000Cooooo`;o00002_ooool2o`00013ooooo0_l0001?ooooo`001_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Go
oooo00?o0000ooooooooool00_l0000Iooooo`;o00002_ooool2o`0001;ooooo0_l00003ooooo`;o
00001oooool2o`0000kooooo0_l0000iooooo`;o00002_ooool2o`0001Kooooo0_l0000Oooooo`;o
00004_ooool2o`0000_ooooo0_l0000booooo`;o00003?ooool000Kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`02o`0002Gooooo0_l0000Gooooo`;o00001oooool2o`00
00?ooooo0_l00009ooooo`;o0000>Oooool2o`0000[ooooo0_l0001;ooooo`;o00002oooool2o`00
00gooooo0_l0000Sooooo`;o00003?ooool000Kooooo00Go410@oooooooooooooooooa0@400<oooo
o`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Hoooo
o`;o0000=?ooool2o`000003ooooool0003o000002Wooooo0_l00016ooooo`;o0000@oooool2o`00
00[ooooo0_l0000Aooooo`;o00004_ooool000Kooooo00Go0000ooooooooooooooooo`00000=oooo
o`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0000Wooooo0_l0000=oooo
o`;o0000=oooool2o`0002Wooooo0_l00011ooooo`;o00000oooool2o`0001cooooo0_l0000aoooo
o`;o00004Oooool2o`0001;ooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omg
MgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`09
ooooo`;o00005_ooool2o`0003Wooooo0_l0000<ooooo`;o00006?ooool2o`0002?ooooo0_l0000D
ooooo`;o00004_ooool2o`0000gooooo0_l0000Qooooo`;o00002?ooool2o`0002_ooooo0006oooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool08Oooool2o`0000;ooooo0_l0000eooooo`;o00002?ooool2
o`0000;ooooo0_l0000Hooooo`;o00008oooool2o`0002Sooooo0_l0000Dooooo`Co00005_ooool4
o`0000Sooooo0_l0000<ooooo`;o00007Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo02Gooooo0_l0000Nooooo`;o00007oooool2o`00077ooooo0_l00006ooooo`;o00001_oo
ool4o`0001Kooooo0_l0000Booooo`;o00001?ooool2o`0000Sooooo0_l0000Cooooo`001_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co0000
1_ooool00ol0003oooooooooo`15ooooo`;o00000oooool2o`0000[ooooo0_l0000Jooooo`;o0000
IOooool2o`0000Kooooo0_l0000dooooo`;o00003_ooool2o`0001?ooooo000Yooooo`;o0000?_oo
ool2o`0000_ooooo0_l0000:ooooo`;o00006_ooool2o`000003ooooool0003o000002_ooooo0_l0
000<ooooo`;o0000R_ooool002Wooooo00?o0000ooooooooool0?Oooool2o`0003Kooooo1?l0000=
ooooo`;o00006_ooool2o`0000cooooo0_l0001Tooooo`;o00009?ooool002Wooooo00?o0000oooo
ooooool07oooool2o`0000gooooo0_l0000Booooo`;o000000?oooooo`000?l000005oooool2o`00
00Cooooo0_l0000Aooooo`;o00001oooool2o`0000Cooooo0_l0000?ooooo`;o00002_ooool2o`00
03;ooooo0_l0000mooooo`;o00000_ooool2o`00023ooooo000Yooooo`03o`000?oooooooooo01;o
oooo0_l0000;ooooo`;o00003Oooool2o`0001;ooooo0_l000000ooooooo0000o`00000Gooooo`;o
00001?ooool2o`0001[ooooo0_l00005ooooo`;o00003_ooool2o`0000[ooooo0_l0000Aooooo`;o
00007oooool2o`0001Sooooo0_l0000Wooooo`;o00008?ooool002Wooooo00?o0000ooooooooool0
4_ooool2o`0004gooooo0_l0000Tooooo`;o00005_ooool2o`0000gooooo0_l00006ooooo`;o0000
>Oooool2o`0000Sooooo0_l0000@ooooo`;o00007_ooool2o`0000gooooo000Yooooo`;o0000H_oo
ool2o`0002oooooo0_l0000;ooooo`;o00003Oooool2o`0000Gooooo0_l0000Tooooo`;o00007_oo
ool2o`00013ooooo0_l0000Nooooo`;o00003Oooool002Wooooo00?o0000ooooooooool0N_ooool2
o`0001Kooooo0_l0000Qooooo`;o00009?ooool2o`0005oooooo000Yooooo`03o`000?oooooooooo
03Cooooo0_l0000]ooooo`;o00002Oooool2o`0000[ooooo0_l0000@ooooo`;o0000@oooool2o`00
00[ooooo0_l0001Mooooo`00:Oooool00ol0003oooooooooo`0<ooooo`;o00001oooool2o`0001go
oooo0_l0000Pooooo`;o00002oooool2o`0000Wooooo0_l0000Looooo`;o0000@oooool2o`0000[o
oooo0_l0001Mooooo`00:Oooool00ol0003oooooooooo`0<ooooo`;o00001oooool2o`0000gooooo
0_l0000`ooooo`;o0000:_ooool2o`0003Gooooo0_l00021ooooo`00:Oooool2o`0002Gooooo0_l0
000aooooo`;o00002?ooool2o`0000Kooooo0_l0000Gooooo`;o0000=Oooool2o`0000Gooooo0_l0
000Uooooo`;o0000Doooool002Wooooo00?o0000ooooooooool04?ooool2o`0001kooooo0_l0000U
ooooo`;o00002?ooool2o`0000Kooooo0_l00006ooooo`;o0000COooool2o`0002Gooooo0_l0001C
ooooo`00:Oooool00ol0003oooooooooo`0@ooooo`;o00007_ooool2o`00023ooooo0_l0000Moooo
o`;o0000S_ooool2o`0003Wooooo000Yooooo`03o`000?oooooooooo05;ooooo0_l0000Pooooo`;o
0000Boooool2o`0001Wooooo0_l000000ooooooo0000o`00000;ooooo`;o00001?ooool2o`0000go
oooo0_l00006ooooo`;o0000<Oooool002Wooooo00?o0000ooooooooool01Oooool2o`0004Oooooo
0_l00003ooooo`;o00005oooool2o`0000Kooooo0_l0000Dooooo`;o00004?ooool2o`0001Cooooo
0_l000000ooooooo0000o`00000:ooooo`;o00006Oooool2o`000003ooooool0003o000000_ooooo
0_l00004ooooo`;o00005Oooool2o`0002Cooooo0_l0000;ooooo`00:Oooool2o`0000;ooooo0_l0
00001?oooooo0000o`000?l0000>ooooo`;o00002?ooool2o`0001[ooooo0_l0000Aooooo`;o0000
0oooool2o`0001Oooooo0_l00008ooooo`;o00004_ooool2o`00013ooooo0_l0000>ooooo`;o0000
1?ooool2o`000003ooooool0003o000001oooooo0_l00002ooooo`Co000000?oooooo`000?l00000
5Oooool3o`0001[ooooo0_l0000Jooooo`;o00002oooool002Wooooo00Co0000oooooooooooooooo
0_l000000ooooooo0000o`00000?ooooo`;o00002?ooool2o`0001[ooooo0_l0000iooooo`;o0000
3?ooool2o`0002Kooooo0_l0000Jooooo`;o00003?ooool2o`0000;ooooo0_l0000Jooooo`?o0000
6_ooool2o`0000Cooooo0_l0000Qooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`24ooooo`;o
0000@_ooool2o`0004oooooo0_l0000Qooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0j?ooool2o`0000Wo
oooo0_l00017ooooo`003_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooooooo
ool00oooool3o`000>Sooooo0_l00009ooooo`;o0000Aoooool000kooooo00Go0000oooooooooooo
ooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`00
3_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005oooo
o`03o`000?oooooooooo04?ooooo0_l0002:ooooo`;o0000>_ooool2o`0002oooooo000>ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
04?ooooo0_l0002:ooooo`;o0000>_ooool2o`0002oooooo000>ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01gooooo0_l0000<oooo
o`;o0000oOooool2o`00013ooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00
00Kooooo0_l0000Nooooo`;o00003?ooool2o`0000cooooo0_l0003_ooooo`;o00004?ooool002Wo
oooo00?o0000ooooooooool0>Oooool2o`000<cooooo0_l0000cooooo`00:Oooool00ol0003ooooo
ooooo`3oooooo`Sooooo0_l0000cooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`001_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooo
oooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o
0000oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qoooooooo
ool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo
00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooo
oooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@
413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3o
ooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006
ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool001oooooo
1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooo
oooo00Gooooo0ol0003oooooocgooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool001oooooo00?oEEEEofIVI_l00000oooooom7
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .39866 Mdot
.02762 .34214 Mdot
.02952 .3124 Mdot
.03143 .33431 Mdot
.03333 .35308 Mdot
.03524 .31364 Mdot
.03714 .28522 Mdot
.03905 .41032 Mdot
.04095 .26838 Mdot
.04286 .29452 Mdot
.04476 .35058 Mdot
.04667 .43371 Mdot
.04857 .24773 Mdot
.05048 .34077 Mdot
.05238 .43481 Mdot
.05429 .31421 Mdot
.05619 .37852 Mdot
.0581 .25443 Mdot
.06 .25276 Mdot
.0619 .42547 Mdot
.06381 .25774 Mdot
.06571 .27827 Mdot
.06762 .25405 Mdot
.06952 .26921 Mdot
.07143 .45219 Mdot
.07333 .27605 Mdot
.07524 .34778 Mdot
.07714 .25872 Mdot
.07905 .42111 Mdot
.08095 .33563 Mdot
.08286 .28567 Mdot
.08476 .26941 Mdot
.08667 .3802 Mdot
.08857 .36077 Mdot
.09048 .29336 Mdot
.09238 .41471 Mdot
.09429 .31948 Mdot
.09619 .29807 Mdot
.0981 .41153 Mdot
.1 .44239 Mdot
.1019 .45479 Mdot
.10381 .33175 Mdot
.10571 .24248 Mdot
.10762 .39774 Mdot
.10952 .39801 Mdot
.11143 .35997 Mdot
.11333 .32989 Mdot
.11524 .23015 Mdot
.11714 .28924 Mdot
.11905 .42076 Mdot
.12095 .22915 Mdot
.12286 .39109 Mdot
.12476 .42285 Mdot
.12667 .25385 Mdot
.12857 .24564 Mdot
.13048 .32761 Mdot
.13238 .41416 Mdot
.13429 .3792 Mdot
.13619 .24748 Mdot
.1381 .39474 Mdot
.14 .35356 Mdot
.1419 .38296 Mdot
.14381 .40891 Mdot
.14571 .306 Mdot
.14762 .37116 Mdot
.14952 .30061 Mdot
.15143 .28394 Mdot
.15333 .32776 Mdot
.15524 .29203 Mdot
.15714 .29282 Mdot
.15905 .38006 Mdot
.16095 .31403 Mdot
.16286 .2988 Mdot
.16476 .25796 Mdot
.16667 .40899 Mdot
.16857 .27333 Mdot
.17048 .4231 Mdot
.17238 .32964 Mdot
.17429 .40173 Mdot
.17619 .2586 Mdot
.1781 .36474 Mdot
.18 .34175 Mdot
.1819 .32024 Mdot
.18381 .32349 Mdot
.18571 .37805 Mdot
.18762 .30282 Mdot
.18952 .35692 Mdot
.19143 .36281 Mdot
.19333 .37638 Mdot
.19524 .32484 Mdot
.19714 .45175 Mdot
.19905 .2479 Mdot
.20095 .26038 Mdot
.20286 .36491 Mdot
.20476 .2701 Mdot
.20667 .22973 Mdot
.20857 .33733 Mdot
.21048 .23008 Mdot
.21238 .43257 Mdot
.21429 .379 Mdot
.21619 .39581 Mdot
.2181 .36573 Mdot
.22 .4309 Mdot
.2219 .39208 Mdot
.22381 .3433 Mdot
.22571 .35273 Mdot
.22762 .37565 Mdot
.22952 .25561 Mdot
.23143 .25999 Mdot
.23333 .29579 Mdot
.23524 .32233 Mdot
.23714 .33232 Mdot
.23905 .26387 Mdot
.24095 .42163 Mdot
.24286 .49229 Mdot
.24476 .32325 Mdot
.24667 .34254 Mdot
.24857 .3279 Mdot
.25048 .30265 Mdot
.25238 .33044 Mdot
.25429 .24643 Mdot
.25619 .41205 Mdot
.2581 .23755 Mdot
.26 .42013 Mdot
.2619 .29699 Mdot
.26381 .33991 Mdot
.26571 .42319 Mdot
.26762 .22118 Mdot
.26952 .3754 Mdot
.27143 .27377 Mdot
.27333 .25376 Mdot
.27524 .38815 Mdot
.27714 .44336 Mdot
.27905 .32537 Mdot
.28095 .25723 Mdot
.28286 .41044 Mdot
.28476 .33457 Mdot
.28667 .42356 Mdot
.28857 .29386 Mdot
.29048 .39739 Mdot
.29238 .43837 Mdot
.29429 .32264 Mdot
.29619 .29211 Mdot
.2981 .26998 Mdot
.3 .37876 Mdot
.3019 .42527 Mdot
.30381 .35978 Mdot
.30571 .48862 Mdot
.30762 .25961 Mdot
.30952 .36396 Mdot
.31143 .42611 Mdot
.31333 .36019 Mdot
.31524 .32737 Mdot
.31714 .27444 Mdot
.31905 .31951 Mdot
.32095 .35624 Mdot
.32286 .35675 Mdot
.32476 .40389 Mdot
.32667 .32534 Mdot
.32857 .31983 Mdot
.33048 .35185 Mdot
.33238 .24648 Mdot
.33429 .40163 Mdot
.33619 .4579 Mdot
.3381 .40118 Mdot
.34 .24226 Mdot
.3419 .39635 Mdot
.34381 .35278 Mdot
.34571 .36105 Mdot
.34762 .301 Mdot
.34952 .35586 Mdot
.35143 .42163 Mdot
.35333 .26039 Mdot
.35524 .32275 Mdot
.35714 .35534 Mdot
.35905 .27418 Mdot
.36095 .38105 Mdot
.36286 .22429 Mdot
.36476 .35101 Mdot
.36667 .32585 Mdot
.36857 .41819 Mdot
.37048 .37525 Mdot
.37238 .44945 Mdot
.37429 .26199 Mdot
.37619 .45499 Mdot
.3781 .27603 Mdot
.38 .25806 Mdot
.3819 .22207 Mdot
.38381 .26599 Mdot
.38571 .45685 Mdot
.38762 .24894 Mdot
.38952 .42865 Mdot
.39143 .4255 Mdot
.39333 .3284 Mdot
.39524 .39641 Mdot
.39714 .39386 Mdot
.39905 .45305 Mdot
.40095 .437 Mdot
.40286 .36476 Mdot
.40476 .29943 Mdot
.40667 .35967 Mdot
.40857 .32094 Mdot
.41048 .32335 Mdot
.41238 .30675 Mdot
.41429 .34669 Mdot
.41619 .32393 Mdot
.4181 .39269 Mdot
.42 .32727 Mdot
.4219 .33222 Mdot
.42381 .33197 Mdot
.42571 .3084 Mdot
.42762 .35227 Mdot
.42952 .23596 Mdot
.43143 .33497 Mdot
.43333 .36224 Mdot
.43524 .27788 Mdot
.43714 .39537 Mdot
.43905 .34519 Mdot
.44095 .45764 Mdot
.44286 .28166 Mdot
.44476 .38636 Mdot
.44667 .43635 Mdot
.44857 .34602 Mdot
.45048 .24261 Mdot
.45238 .35155 Mdot
.45429 .37931 Mdot
.45619 .30239 Mdot
.4581 .32534 Mdot
.46 .35463 Mdot
.4619 .25996 Mdot
.46381 .43596 Mdot
.46571 .40483 Mdot
.46762 .33411 Mdot
.46952 .29919 Mdot
.47143 .32663 Mdot
.47333 .32867 Mdot
.47524 .34873 Mdot
.47714 .42057 Mdot
.47905 .31102 Mdot
.48095 .3867 Mdot
.48286 .23696 Mdot
.48476 .39116 Mdot
.48667 .38296 Mdot
.48857 .28108 Mdot
.49048 .3869 Mdot
.49238 .38018 Mdot
.49429 .27583 Mdot
.49619 .28094 Mdot
.4981 .36542 Mdot
.5 .36213 Mdot
.5019 .3807 Mdot
.50381 .40796 Mdot
.50571 .45388 Mdot
.50762 .32453 Mdot
.50952 .32887 Mdot
.51143 .3519 Mdot
.51333 .2729 Mdot
.51524 .32794 Mdot
.51714 .24113 Mdot
.51905 .27495 Mdot
.52095 .40575 Mdot
.52286 .23006 Mdot
.52476 .31103 Mdot
.52667 .34894 Mdot
.52857 .3884 Mdot
.53048 .29896 Mdot
.53238 .35454 Mdot
.53429 .39705 Mdot
.53619 .33604 Mdot
.5381 .28044 Mdot
.54 .41904 Mdot
.5419 .25192 Mdot
.54381 .41967 Mdot
.54571 .24184 Mdot
.54762 .29426 Mdot
.54952 .28081 Mdot
.55143 .35974 Mdot
.55333 .2576 Mdot
.55524 .2976 Mdot
.55714 .23252 Mdot
.55905 .35222 Mdot
.56095 .34983 Mdot
.56286 .41378 Mdot
.56476 .26541 Mdot
.56667 .25836 Mdot
.56857 .32073 Mdot
.57048 .42503 Mdot
.57238 .2584 Mdot
.57429 .32009 Mdot
.57619 .31531 Mdot
.5781 .41664 Mdot
.58 .36323 Mdot
.5819 .3499 Mdot
.58381 .22234 Mdot
.58571 .2575 Mdot
.58762 .42599 Mdot
.58952 .25658 Mdot
.59143 .26995 Mdot
.59333 .26892 Mdot
.59524 .40957 Mdot
.59714 .40785 Mdot
.59905 .43146 Mdot
.60095 .48004 Mdot
.60286 .26801 Mdot
.60476 .25583 Mdot
.60667 .3855 Mdot
.60857 .27405 Mdot
.61048 .45302 Mdot
.61238 .33812 Mdot
.61429 .23117 Mdot
.61619 .26294 Mdot
.6181 .29668 Mdot
.62 .23762 Mdot
.6219 .37895 Mdot
.62381 .2404 Mdot
.62571 .43271 Mdot
.62762 .31793 Mdot
.62952 .39138 Mdot
.63143 .34727 Mdot
.63333 .38359 Mdot
.63524 .29244 Mdot
.63714 .45018 Mdot
.63905 .43809 Mdot
.64095 .28861 Mdot
.64286 .34042 Mdot
.64476 .3305 Mdot
.64667 .31868 Mdot
.64857 .39956 Mdot
.65048 .33134 Mdot
.65238 .31631 Mdot
.65429 .273 Mdot
.65619 .37834 Mdot
.6581 .42756 Mdot
.66 .35728 Mdot
.6619 .27159 Mdot
.66381 .24856 Mdot
.66571 .2683 Mdot
.66762 .30538 Mdot
.66952 .35095 Mdot
.67143 .30424 Mdot
.67333 .24233 Mdot
.67524 .24653 Mdot
.67714 .34056 Mdot
.67905 .40482 Mdot
.68095 .26517 Mdot
.68286 .35589 Mdot
.68476 .30548 Mdot
.68667 .35771 Mdot
.68857 .34982 Mdot
.69048 .42379 Mdot
.69238 .31906 Mdot
.69429 .2686 Mdot
.69619 .35828 Mdot
.6981 .32522 Mdot
.7 .43268 Mdot
.7019 .27035 Mdot
.70381 .41767 Mdot
.70571 .25773 Mdot
.70762 .36384 Mdot
.70952 .42191 Mdot
.71143 .34293 Mdot
.71333 .43198 Mdot
.71524 .27617 Mdot
.71714 .39092 Mdot
.71905 .44186 Mdot
.72095 .4513 Mdot
.72286 .45653 Mdot
.72476 .28404 Mdot
.72667 .31278 Mdot
.72857 .43862 Mdot
.73048 .40912 Mdot
.73238 .27786 Mdot
.73429 .33041 Mdot
.73619 .26764 Mdot
.7381 .33718 Mdot
.74 .39704 Mdot
.7419 .23463 Mdot
.74381 .38753 Mdot
.74571 .29535 Mdot
.74762 .37876 Mdot
.74952 .26138 Mdot
.75143 .28769 Mdot
.75333 .26091 Mdot
.75524 .45038 Mdot
.75714 .49353 Mdot
.75905 .31086 Mdot
.76095 .36539 Mdot
.76286 .32147 Mdot
.76476 .44742 Mdot
.76667 .37517 Mdot
.76857 .27101 Mdot
.77048 .4518 Mdot
.77238 .29713 Mdot
.77429 .31442 Mdot
.77619 .26394 Mdot
.7781 .3063 Mdot
.78 .34488 Mdot
.7819 .23428 Mdot
.78381 .36236 Mdot
.78571 .40039 Mdot
.78762 .45074 Mdot
.78952 .37302 Mdot
.79143 .3883 Mdot
.79333 .36799 Mdot
.79524 .2701 Mdot
.79714 .2928 Mdot
.79905 .31714 Mdot
.80095 .42262 Mdot
.80286 .432 Mdot
.80476 .34867 Mdot
.80667 .26508 Mdot
.80857 .34751 Mdot
.81048 .2821 Mdot
.81238 .44381 Mdot
.81429 .36572 Mdot
.81619 .40141 Mdot
.8181 .30152 Mdot
.82 .32445 Mdot
.8219 .2864 Mdot
.82381 .36356 Mdot
.82571 .36656 Mdot
.82762 .34149 Mdot
.82952 .33079 Mdot
.83143 .41928 Mdot
.83333 .39588 Mdot
.83524 .28205 Mdot
.83714 .28088 Mdot
.83905 .37557 Mdot
.84095 .37129 Mdot
.84286 .25696 Mdot
.84476 .31494 Mdot
.84667 .44694 Mdot
.84857 .24783 Mdot
.85048 .38128 Mdot
.85238 .4846 Mdot
.85429 .39498 Mdot
.85619 .33422 Mdot
.8581 .28328 Mdot
.86 .44068 Mdot
.8619 .35105 Mdot
.86381 .31927 Mdot
.86571 .40982 Mdot
.86762 .26991 Mdot
.86952 .29744 Mdot
.87143 .28758 Mdot
.87333 .38733 Mdot
.87524 .2498 Mdot
.87714 .27495 Mdot
.87905 .29159 Mdot
.88095 .2767 Mdot
.88286 .33516 Mdot
.88476 .28365 Mdot
.88667 .32013 Mdot
.88857 .25593 Mdot
.89048 .41061 Mdot
.89238 .30668 Mdot
.89429 .40716 Mdot
.89619 .35907 Mdot
.8981 .39589 Mdot
.9 .42178 Mdot
.9019 .33219 Mdot
.90381 .37721 Mdot
.90571 .22081 Mdot
.90762 .26888 Mdot
.90952 .42978 Mdot
.91143 .45443 Mdot
.91333 .33601 Mdot
.91524 .26875 Mdot
.91714 .25423 Mdot
.91905 .37479 Mdot
.92095 .42406 Mdot
.92286 .39581 Mdot
.92476 .25157 Mdot
.92667 .35769 Mdot
.92857 .36156 Mdot
.93048 .38362 Mdot
.93238 .2532 Mdot
.93429 .27343 Mdot
.93619 .24251 Mdot
.9381 .26289 Mdot
.94 .2872 Mdot
.9419 .3379 Mdot
.94381 .25726 Mdot
.94571 .25356 Mdot
.94762 .32758 Mdot
.94952 .28918 Mdot
.95143 .30358 Mdot
.95333 .351 Mdot
.95524 .39456 Mdot
.95714 .27929 Mdot
.95905 .26063 Mdot
.96095 .26677 Mdot
.96286 .49215 Mdot
.96476 .26695 Mdot
.96667 .34665 Mdot
.96857 .24171 Mdot
.97048 .40413 Mdot
.97238 .28218 Mdot
.97429 .42198 Mdot
.97619 .44482 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo04_ooooo0_l0003;ooooo`;o00008_ooool000Kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo04_ooooo0_l0000Looooo`;o00001?ooool2o`0003oooooo0_l0001V
ooooo`;o00008_ooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`1Yooooo`;o00001?ooool2o`0003oooooo0_l0002:ooooo`001?l00002ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool06_ooool4o`0001Wooooo0ol0001Sooooo`;o0000WOooool000Kooooo00Go0000
ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?oo
ool3o`0001[ooooo1?l0000Iooooo`?o0000Hoooool2o`0000Wooooo0_l0000@ooooo`;o0000P?oo
ool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo07oooooo0_l0000?ooooo`;o0000
5_ooool2o`00013ooooo0_l0000Wooooo`;o00002oooool2o`0004[ooooo0006ooooo`05oa0@4?oo
ooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0B?ooool2o`0003Gooooo0_l0000?ooooo`;o0000:_ooool3o`0002Cooooo
0_l0000;ooooo`;o0000B_ooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Oo
oooo0_l0000_ooooo`;o00006?ooool2o`00027ooooo0_l0000Dooooo`;o00001oooool2o`0001Ko
oooo0ol0000>ooooo`;o0000Doooool2o`0000Sooooo0_l0000>ooooo`001_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0
003oooooooooo`0Gooooo`;o00001Oooool2o`0002Kooooo0_l0000Gooooo`;o000000?oooooo`00
0?l000008Oooool2o`0001Cooooo0_l00007ooooo`;o00009oooool3o`0005;ooooo0_l00008oooo
o`;o00003_ooool002Wooooo0_l00005ooooo`;o00006?ooool4o`0001?ooooo0_l0000?ooooo`;o
00005oooool2o`00013ooooo0_l0001Gooooo`;o00000_ooool2o`0003Gooooo0_l0000eooooo`00
:Oooool00ol0003oooooooooo`04ooooo`;o00000_ooool2o`0001Kooooo0_l0000Cooooo`;o0000
>_ooool2o`00033ooooo0_l0000Uooooo`;o0000>Oooool2o`0000Oooooo0_l0000>ooooo`;o0000
7?ooool002Wooooo00?o0000ooooooooool01oooool5o`00017ooooo0_l0000Oooooo`;o00003Ooo
ool2o`0005Cooooo0_l0000Booooo`;o0000EOooool2o`0000;ooooo0_l00008ooooo`Ko00000ooo
ool2o`0001Gooooo000Yooooo`03o`000?oooooooooo00Oooooo1Ol000000ooooooo0000o`00000>
ooooo`;o00002oooool2o`000003ooooool0003o000000oooooo0_l0000=ooooo`Co00007_ooool2
o`0003Kooooo0_l00002ooooo`Co00000_ooool3o`0000?ooooo0_l0000Oooooo`;o0000:_ooool2
o`0000cooooo0_l00008ooooo`;o00000_ooool2o`0000;ooooo0ol0000Eooooo`00:Oooool00ol0
003oooooooooo`09ooooo`;o00000_ooool2o`0001_ooooo0_l000000ooooooo0000o`000006oooo
o`;o00002?ooool2o`0000kooooo0_l00007ooooo`;o00003?ooool2o`0000Gooooo1?l0000Hoooo
o`;o00007?ooool2o`0000;ooooo1?l00002ooooo`?o00009?ooool2o`0000cooooo0ol0000Koooo
o`;o00007_ooool2o`0000?ooooo0_l0000Aooooo`00:Oooool2o`0003Kooooo0_l00008ooooo`Co
00005Oooool2o`0000cooooo0_l00005ooooo`;o00006_ooool2o`00033ooooo0_l0000Cooooo`;o
00005?ooool3o`0000Gooooo0_l00008ooooo`;o0000:?ooool2o`0000Gooooo0_l0000Aooooo`00
:Oooool00ol0003oooooooooo`02ooooo`;o0000?Oooool2o`0002gooooo0_l0000hooooo`;o0000
2_ooool2o`0000?ooooo0_l0000>ooooo`;o00000oooool2o`0000oooooo0_l0000;ooooo`;o0000
2?ooool2o`0002Sooooo0_l00006ooooo`?o00003oooool002Wooooo00?o0000ooooooooool00_oo
ool2o`0000Oooooo0_l00003ooooo`;o00007_ooool4o`000008oa0@4?oooooo0000o`000?lb<S;o
0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04?ooool2o`0001Oooooo1Ol00003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo
0ol000000olb<S;oc<c<ooooo`02ooooo`04onk^k_l0003o0000oc8b<P;o00000_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00cooooo0_l00007ooooo`Co00002Oooool2o`0000Kooooo0_l000002Ol@
413o0000o`000?ooooook^k^oc8b<_l0003o<S8bonk^kP02o`000006ooooooo^k^ko<S8bo`000?lb
<S;ok^k^4?ooool2o`0000[ooooo0_l000000ooooooo0000o`000008ooooo`05odA4A?l0003o0000
oc8b<_oMgMd00ol000001?lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool002Wooooo00?o0000ooooooooool02oooool2o`0000?ooooo0_l0000Iooooo`;o00001Ooo
ool01?l0003oooooooooooooool2o`000004oiRHV?ooooooV9RHogMgM`?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`08ooooo`;o00001_ooool2o`0000Gooooo0_l0000;ooooo`;o00000oooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL06?ooool2o`0000kooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`06
ogMgMol0003o0000oiRHV?mgMgOooooo0_l000001OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo1?l0
0009ooooo`Co00004_ooool02_l0003oooooo`000?l0003oooooogMgMonHV9SooooooiRHV?mgMgL2
o`000006oooooomgMgOoV9RHoooooonHV9SoMgMg4?ooool2o`0000[ooooo0_l000000ooooooo0000
o`000004ooooo`;o00001Oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wooooo00?o0000ooooooooool03?ooool2
o`0001gooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41002?ooool2o`0000gooooo0_l0000;ooooo`;o0000
1?ooool2o`000003onk^k_oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@41004_ooool2o`0000Cooooo1?l0000@ooooo`05o`000?oooooooooo
ooooool@41000oooool01Ol@413oooooo`000?l0003o410@00?ooooo00?o410@ooooooooool01_oo
ool4o`00013ooooo0_l0000:ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooooooooa0@400Cooooo`?o00003oooool2o`0000Kooooo00Co0000oooooooo
oooo410@0oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool00Oooool0
02Wooooo0_l0000;ooooo`Co00009?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000002[ooooo0_l000000olQ8B7ok^k^oooo
o`02ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooooooool2o`00017o
oooo0_l00006ooooo`;o00001?ooool2o`000003ooooool0003o000000Kooooo00?oZJVYoa0@4?oo
ool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00000L
ooooo`;o00000oooool2o`0000Gooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`00000Cooooo`?o00005_ooool2o`0000;o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool0
02Wooooo00?o0000ooooooooool02_ooool2o`0001Wooooo0_l0000;ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000;?oo
ool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooo
ooooooooool4o`0000gooooo1?l0000<ooooo`;o000000?oooooo`000?l000001Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
0000027ooooo0_l00005ooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooo000000;o00001Oooool3o`0000Gooooo0_l00006ooooo`;o0000
4_ooool00ol0003o8B4Qo`000002o`0000;ooooo0ol000000ooooooo0000ooooo`02ooooo`05o`00
0?ooooooooooooooool000000oooool002Wooooo00Co0000oooooooooooooooo0_l0000<ooooo`;o
00005?ooool2o`0000_ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@400]ooooo`05o`000?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Co410@ooooool0003o00003Oooool4o`0001Oo
oooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooo
oooooooooooooa0@400Oooooo`;o00002?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooo
ooooooooool@41000oooool01_l@413oooooo`000?l0003o410@ooooo`;o00000_ooool3o`0000Go
oooo0_l00006ooooo`;o00004_ooool00ol0003oooooooooo`04ooooo`05oa0@4?l0003o0000oooo
ool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo000Yooooo`04o`000?oooooooooo
ooooo`;o00003?ooool2o`0000Wooooo0_l0000Fooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:Oooool01Ol0003o^[Zj
oooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0:?ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool2o`0001Wooooo0_l00006ooooo`;o
000000?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00KoMgMgoiRH
V?ooooooV9RHogMgMoooool2o`0000kooooo0_l0000Dooooo`Go00001?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool00ol0003ooooo
ooooo`0Jooooo`;o00002oooool2o`0000Oooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0@ooooo`;o00005oooool01OnH
V9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h0:?ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool4o`00027ooooo0_l00000
0oooooooMgMgo`000004ooooo`06onk^k_lb<S;o0000oc8b<_o^k^kooooo0_l000001Oo^k^ko<S8b
o`000?lb<S;ok^k^017ooooo1?l0000Booooo`Ko00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool2o`0000?ooooo0_l0000>oooo
o`;o00004oooool2o`0001Oooooo0_l0000?ooooo`;o000000?oooooo`000?l00000Coooool2o`00
01[ooooo0_l0000Qooooo`;o00003oooool2o`0001Sooooo0_l0000[ooooo`00:Oooool00ol0003o
ooooooooo`02ooooo`;o00003_ooool4o`0001?ooooo0_l0000Eooooo`;o00001oooool2o`0000Ko
oooo0_l0000Tooooo`;o00004oooool2o`00017ooooo0_l00004ooooo`Co00004_ooool2o`0002Oo
oooo0_l00007ooooo`;o00007Oooool2o`0002kooooo000Yooooo`03o`000?oooooooooo01Cooooo
0_l0000?ooooo`;o00000_ooool2o`0001kooooo0_l0000Iooooo`;o00004Oooool2o`0000kooooo
0_l00003ooooo`;o00004Oooool2o`0000Kooooo0_l0000Booooo`;o0000<?ooool2o`0000gooooo
0_l0000>ooooo`;o0000;_ooool002Wooooo00?o0000ooooooooool09Oooool2o`0000[ooooo0_l0
000Booooo`;o00007Oooool2o`00027ooooo0_l00012ooooo`Co00000_ooool2o`0002Wooooo0_l0
000Yooooo`;o00004oooool002Wooooo00?o0000ooooooooool08oooool2o`0000cooooo0_l0000B
ooooo`;o0000<_ooool2o`0000;ooooo0_l0001<ooooo`Co00000_ooool2o`0001cooooo0_l0000S
ooooo`;o00004Oooool2o`0001?ooooo000Qoooooooo0000A?l00004ooooo`00:Oooool5o`0000Co
oooo0_l000000ooooooo0000ooooo`0;ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool00oooool2o`0000Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`;o
00002oooool3o`0000[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool01?l0003oooooooooooooool2o`00
00Kooooo00?o0000ooooooooool00_l00003ooooo`;o00000_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00?ooooo0_l00005ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo000Yooooo`Go
00001?ooool2o`00023ooooo0_l0000@ooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool0<oooool2o`0000Gooooo00?o0000ooooooooool01_ooool2o`0000Kooooo0_l0000Fooooo`;o
00003_ooool2o`0000;ooooo00Co0000oooooooooooooooo0_l0000<ooooo`;o0000:Oooool00ol0
003oooooooooo`0:ooooo`00:Oooool00ol0003oooooooooo`0Cooooo`;o00006_ooool2o`0002[o
oooo0_l000000ooooooo0000o`00000Hooooo`;o0000<Oooool5o`0000kooooo0_l00005ooooo`?o
00002oooool2o`00027ooooo0_l0000Booooo`;o00001_ooool2o`0002Sooooo000Yooooo`03o`00
0?oooooooooo01?ooooo0_l0000Jooooo`?o00003_ooool2o`000003ooooool0003o000000kooooo
0_l00006ooooo`;o000000?oooooo`000?l000001oooool2o`0000oooooo1?l0000_ooooo`Co0000
5_ooool2o`0000cooooo0_l0000Eooooo`;o00007_ooool2o`0000Kooooo0_l0000Xooooo`00:Ooo
ool2o`00037ooooo0_l000000ooooooo0000o`00000;ooooo`;o000000?oooooo`000?l000002Ooo
ool2o`0000?ooooo0_l00005ooooo`;o00000_ooool2o`0000Oooooo0_l00002ooooo`;o00003?oo
ool5o`0000[ooooo0_l00002ooooo`;o00002_ooool2o`0003_ooooo0_l0000Cooooo`;o00004?oo
ool2o`0003kooooo000Yooooo`03o`000?oooooooooo01Wooooo0_l00004ooooo`;o00001Oooool2
o`0000Cooooo0_l00005ooooo`;o00004?ooool3o`0000Kooooo0_l0000:ooooo`;o00000_ooool2
o`0000_ooooo0_l00006ooooo`;o00001oooool2o`0000[ooooo0_l00002ooooo`?o00002Oooool4
o`0002Sooooo0_l0000?ooooo`;o00002_ooool2o`0001Wooooo0_l0000Wooooo`;o00005Oooool0
02Wooooo00?o0000ooooooooool05_ooool2o`000003ooooool0003o000000Cooooo0_l00005oooo
o`;o00001?ooool2o`0001?ooooo0_l00002ooooo`?o0000:oooool2o`0000Oooooo0ol0000>oooo
o`;o00002Oooool4o`0002Sooooo1?l0000Iooooo`;o00007?ooool2o`0001Kooooo0_l0000<oooo
o`;o00005Oooool002Wooooo00Co0000ooooool0003o00003_ooool2o`0000Gooooo0_l0000Yoooo
o`;o00003Oooool2o`0002[ooooo1Ol0000:ooooo`;o00005?ooool2o`0002?ooooo0_l0000goooo
o`;o00001oooool2o`0000Kooooo0_l00005ooooo`;o000000?oooooo`000?l000008?ooool002Wo
oooo00Co0000ooooool0003o00003_ooool2o`0002Oooooo0_l0000?ooooo`;o00001Oooool2o`00
02gooooo0_l0000:ooooo`;o00005?ooool2o`0001Oooooo0_l0000Vooooo`;o00009?ooool2o`00
00Kooooo0_l00008ooooo`;o00001oooool2o`0001Oooooo000Yooooo`;o00001_ooool2o`0002Oo
oooo0_l00008ooooo`;o00002_ooool2o`0000?ooooo0_l0001_ooooo`;o00001oooool2o`0000Wo
oooo0_l00009ooooo`;o00001oooool2o`0001_ooooo0_l0000Rooooo`;o00005oooool002Wooooo
0_l00006ooooo`;o00009oooool2o`0000gooooo0_l00005ooooo`;o0000??ooool2o`000003oooo
ool0003o000003cooooo0_l00009ooooo`;o00002Oooool2o`0001Cooooo0_l0000>ooooo`;o0000
>oooool002Wooooo00?o0000ooooooooool03Oooool2o`0002kooooo0_l0000kooooo`;o00001_oo
ool2o`000003ooooool0003o000000Kooooo0_l0000?ooooo`;o00008?ooool2o`0002gooooo0_l0
0006ooooo`Co0000<?ooool2o`0000oooooo000Yooooo`03o`000?oooooooooo00?ooooo0_l00008
ooooo`;o0000D?ooool2o`0000Wooooo0_l0000>ooooo`;o00000_ooool2o`0000Kooooo0_l00005
ooooo`;o00002_ooool2o`0000?ooooo0_l00008ooooo`?o00001Oooool2o`0000kooooo0_l0000:
ooooo`;o00001?ooool2o`0002?ooooo1?l0000?ooooo`;o00006oooool2o`0000;ooooo0_l0000?
ooooo`00:Oooool01?l0003oooooo`000?l00002ooooo`;o00007Oooool2o`0001Wooooo0_l0000P
ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000Booooo`;o00001_ooool2
o`000003ooooool0003o000000kooooo0_l00005ooooo`;o00001_ooool3o`0000Gooooo0_l0000J
ooooo`;o00001?ooool2o`0003Kooooo0_l0000Kooooo`;o00004oooool002Wooooo1?l0000Qoooo
o`;o00003_ooool2o`0000Wooooo0_l0000Mooooo`;o00001Oooool6o`00023ooooo0_l0000Eoooo
o`;o00009oooool2o`0000Gooooo0ol000000ooooooo0000o`000019ooooo`;o00006oooool002Wo
oooo00?o0000ooooooooool04Oooool2o`0000Gooooo0_l0000Hooooo`;o00008_ooool2o`000004
ooooool0003o0000ooooo`;o00001_ooool3o`00013ooooo0_l0000]ooooo`;o00008Oooool2o`00
00Gooooo0ol000000ooooooo0000o`00000oooooo`;o00002?ooool2o`0001_ooooo000Yooooo`03
o`000?oooooooooo017ooooo0_l00005ooooo`;o00005?ooool2o`0000;ooooo0_l0000Rooooo`Go
00002Oooool2o`00013ooooo0ol00007ooooo`;o00004oooool2o`0000oooooo0_l00007ooooo`;o
00009oooool2o`0001Oooooo0_l0000;ooooo`;o00005Oooool2o`0000Sooooo0_l0000Kooooo`00
:Oooool00ol0003oooooooooo`0^ooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o0000
6oooool2o`0001cooooo0_l00008ooooo`;o00004oooool2o`0001Sooooo0_l0000Wooooo`;o0000
3oooool2o`0000Kooooo0_l00007ooooo`;o00000_ooool2o`0003cooooo000Yooooo`03o`000?oo
oooooooo03Kooooo0_l00003ooooo`;o0000F?ooool2o`0005;ooooo0_l00009ooooo`;o00001?oo
ool2o`0000;ooooo0_l0000looooo`00:Oooool2o`0002Gooooo0_l0003<ooooo`Co00003Oooool2
o`0003Oooooo000Yooooo`03o`000?oooooooooo02Cooooo0_l0000=ooooo`;o00002Oooool2o`00
00_ooooo0_l0000Oooooo`;o0000OOooool2o`0000Gooooo0_l0000>ooooo`?o00004_ooool2o`00
00?ooooo0_l0000Nooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool01oooool2
o`0000Oooooo0_l0000>ooooo`;o00001_ooool2o`0000Kooooo0_l000000ooooooo0000o`000005
ooooo`;o00000_ooool2o`0000_ooooo0_l00008ooooo`;o00005Oooool2o`0001Wooooo0_l0000:
ooooo`;o0000:?ooool2o`0000Wooooo0_l0000Kooooo`;o00001?ooool2o`0001Gooooo0_l0000C
ooooo`;o00000oooool2o`0001kooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool01oooool2o`0000Oooooo0_l0000>ooooo`Co00001?ooool2o`0000Kooooo0_l0
0008ooooo`;o00006Oooool2o`0001;ooooo0_l0000Looooo`;o00002?ooool4o`000003ooooool0
003o000002Gooooo0_l00009ooooo`;o00006oooool2o`0001oooooo0_l0000dooooo`001_ooool0
1Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo02;ooooo0_l00015ooooo`;o00006Oooool2o`0000_ooooo0_l0
0003ooooo`;o00008?ooool2o`0000Kooooo0_l00014ooooo`;o00006?ooool2o`0001[ooooo0006
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol0001=ooooo`;o0000=Oooool2o`0000Wooooo0_l000000ooooooo0000o`00
000;ooooo`;o00005oooool2o`0000Kooooo0_l0000Rooooo`;o00003Oooool2o`0001Sooooo0_l0
000Aooooo`;o00006_ooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo01cooooo
0_l0000Nooooo`;o00003oooool2o`0002cooooo0_l0000Booooo`Go00002oooool2o`0001kooooo
0_l0000Jooooo`;o00001oooool2o`0000gooooo0_l0000Hooooo`;o0000;Oooool000Kooooo00Go
410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Looooo`;o00000oooool2o`0001Oooooo1?l0000fooooo`;o0000
1Oooool2o`0000Cooooo0_l0000=ooooo`;o0000;Oooool2o`0001[ooooo0_l0000Tooooo`;o0000
1?ooool2o`0000cooooo0_l00006ooooo`;o00002Oooool2o`0001;ooooo0006ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooooooo
ool01oooool2o`0001Sooooo0ol00007ooooo`;o00005oooool2o`0001Kooooo0_l0000?ooooo`;o
00003oooool2o`0000_ooooo0_l0000Mooooo`;o0000@Oooool2o`0001cooooo0_l00004ooooo`;o
00003?ooool2o`0000Kooooo0_l00009ooooo`;o00004_ooool000Kooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0000Hoooo
o`?o00004oooool2o`0002?ooooo0_l0000<ooooo`Go00003oooool2o`0002[ooooo0_l0000Soooo
o`;o00007?ooool2o`0000cooooo0_l00008ooooo`;o0000?oooool002Wooooo0_l0000^ooooo`;o
0000;_ooool2o`000004ooooool0003o0000o`0002Oooooo0_l0000iooooo`;o00002?ooool2o`00
023ooooo0_l00008ooooo`;o0000<?ooool2o`0000gooooo000Yooooo`03o`000?oooooooooo05go
oooo0_l0000[ooooo`;o00002oooool2o`0000?ooooo0_l0000Gooooo`;o00006?ooool2o`0004?o
oooo0_l0000Gooooo`;o00003Oooool002Wooooo00Co0000oooooooooooooooo0_l0000Pooooo`;o
00001Oooool2o`0002Cooooo0_l00015ooooo`;o00000oooool2o`0001Kooooo0ol0000Xooooo`;o
0000:_ooool2o`0000Kooooo0ol0000Vooooo`00:Oooool01?l0003oooooooooooooool2o`00017o
oooo0_l00009ooooo`;o00000_ooool2o`0000Gooooo0_l0000Kooooo`;o00001oooool2o`0005So
oooo0_l00008ooooo`;o0000:Oooool2o`0002[ooooo0_l00006ooooo`;o00009oooool002Wooooo
00?o0000ooooooooool04_ooool4o`0000Wooooo0_l0000Vooooo`;o0000HOooool2o`0000;ooooo
0_l0000Wooooo`;o0000Hoooool002Wooooo0_l0000Cooooo`;o00001oooool2o`0002_ooooo0_l0
000Qooooo`;o00008Oooool2o`0001;ooooo0ol00009ooooo`;o00009oooool2o`0002Oooooo0_l0
000jooooo`00:Oooool00ol0003oooooooooo`0>ooooo`;o00002oooool4o`0000cooooo0_l0000E
ooooo`;o00001?ooool4o`0000Gooooo0_l0000Cooooo`;o00000oooool2o`00027ooooo0_l0000B
ooooo`?o0000;_ooool2o`0000Cooooo0_l0000Kooooo`;o00002?ooool2o`0001Cooooo0_l0000F
ooooo`;o00003?ooool002Wooooo00?o0000ooooooooool02Oooool2o`0000?ooooo0_l0000=oooo
o`;o00003?ooool2o`0001Gooooo0_l00006ooooo`;o00001Oooool2o`0000?ooooo0_l000000ooo
oooo0000o`00000;ooooo`;o00002_ooool2o`0003Sooooo0_l00004ooooo`;o00007oooool2o`00
00Cooooo0_l0000Kooooo`;o00007_ooool2o`0000Gooooo0_l0000?ooooo`;o00003?ooool002Wo
oooo00?o0000ooooooooool02Oooool2o`0004_ooooo0_l000000ooooooo0000o`00000Gooooo`;o
0000>?ooool2o`0000Cooooo0_l0000Dooooo`;o0000Coooool2o`0000;ooooo0_l0000Mooooo`00
:Oooool00ol0003oooooooooo`0iooooo`Co0000=Oooool2o`00047ooooo0_l00007ooooo`;o0000
2?ooool2o`0000cooooo0_l00002ooooo`;o00006oooool2o`00023ooooo0_l0000Qooooo`00:Ooo
ool2o`0000Gooooo0ol0000booooo`Co0000COooool2o`0002Wooooo0_l00007ooooo`;o00005_oo
ool2o`0000;ooooo0_l0000Kooooo`;o0000@oooool002Wooooo00?o0000ooooooooool01?ooool3
o`0004cooooo0_l0000Qooooo`;o00003?ooool2o`0000Cooooo0_l0000fooooo`;o00006oooool2
o`0005_ooooo000Yooooo`03o`000?oooooooooo01Gooooo0_l0000looooo`;o00008Oooool2o`00
00cooooo0_l0000looooo`;o00006?ooool2o`000003ooooool0003o000002Sooooo0_l0000aoooo
o`00:Oooool00ol0003oooooooooo`0Eooooo`;o0000=oooool2o`0008cooooo0_l0000Looooo`;o
00003Oooool2o`0002Cooooo0_l0000;ooooo`00:Oooool00ol0003oooooooooo`1>ooooo`;o0000
Voooool2o`0000gooooo0_l00009ooooo`;o0000:?ooool2o`0000_ooooo000Yooooo`;o0000=Ooo
ool2o`0003Kooooo0_l0001Cooooo`;o00006Oooool2o`0000Wooooo0_l00002ooooo`?o00001?oo
ool2o`00017ooooo0_l0000eooooo`00:Oooool00ol0003oooooooooo`0<ooooo`;o00001oooool2
o`0001gooooo0_l0000fooooo`Co00001Oooool2o`00023ooooo0_l0000Pooooo`;o00001_ooool2
o`0001Wooooo0_l00009ooooo`;o00000oooool2o`0000Cooooo0_l0000Vooooo`;o00008?ooool0
00kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool03?ooool2o`0000Oooooo0_l0001:ooooo`;o00002ooo
ool2o`000003ooooool0003o000000;ooooo0_l0000;ooooo`;o00004oooool2o`00023ooooo0_l0
000Rooooo`;o0000>oooool2o`00023ooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1Qooooo`;o00003_oo
ool2o`0000oooooo0_l0001Iooooo`;o0000GOooool000kooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo000>ooooo`05o`000?oooooo
ooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Ooo
ool000kooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000
oooooolnooooo`00:Oooool00ol0003oooooooooo`2fooooo`;o0000Q?ooool002Wooooo00?o0000
ooooooooool0]_ooool2o`0004oooooo0_l0000cooooo`00:Oooool00ol0003oooooooooo`1Goooo
o`;o0000[_ooool2o`0003?ooooo000Yooooo`03o`000?oooooooooo04?ooooo0_l0000Booooo`;o
0000dOooool2o`00013ooooo000Yooooo`;o0000A?ooool2o`000:?ooooo0_l00010ooooo`;o0000
4?ooool002Wooooo00?o0000ooooooooool0j?ooool2o`0005;ooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000
oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool0
0ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?o
EEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Ooo
ool000Kooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o
0000ooooooooool00oooool3o`000?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<oooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo
0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oo
oooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oo
oooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Oooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3o
ooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolmoooo
o`008Oooool00ol0003oooooooooo`05ooooo`?o0000oooooolmooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Oooooo`03
oeEEEOmVIVKo00000?ooooooAoooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .38056 Mdot
.02762 .39666 Mdot
.02952 .29503 Mdot
.03143 .28596 Mdot
.03333 .29655 Mdot
.03524 .24122 Mdot
.03714 .27343 Mdot
.03905 .32208 Mdot
.04095 .24017 Mdot
.04286 .2559 Mdot
.04476 .31616 Mdot
.04667 .36767 Mdot
.04857 .26725 Mdot
.05048 .28474 Mdot
.05238 .37428 Mdot
.05429 .34423 Mdot
.05619 .35165 Mdot
.0581 .25879 Mdot
.06 .31201 Mdot
.0619 .41182 Mdot
.06381 .25614 Mdot
.06571 .36548 Mdot
.06762 .34562 Mdot
.06952 .24625 Mdot
.07143 .42753 Mdot
.07333 .34694 Mdot
.07524 .34335 Mdot
.07714 .32343 Mdot
.07905 .42044 Mdot
.08095 .39351 Mdot
.08286 .23889 Mdot
.08476 .23917 Mdot
.08667 .27575 Mdot
.08857 .38022 Mdot
.09048 .36409 Mdot
.09238 .36822 Mdot
.09429 .40026 Mdot
.09619 .34824 Mdot
.0981 .4237 Mdot
.1 .38482 Mdot
.1019 .4317 Mdot
.10381 .37859 Mdot
.10571 .29567 Mdot
.10762 .3936 Mdot
.10952 .36216 Mdot
.11143 .3616 Mdot
.11333 .26923 Mdot
.11524 .29188 Mdot
.11714 .24802 Mdot
.11905 .41492 Mdot
.12095 .29808 Mdot
.12286 .42773 Mdot
.12476 .32086 Mdot
.12667 .33535 Mdot
.12857 .32366 Mdot
.13048 .2308 Mdot
.13238 .32934 Mdot
.13429 .35133 Mdot
.13619 .3518 Mdot
.1381 .35036 Mdot
.14 .36527 Mdot
.1419 .44752 Mdot
.14381 .42352 Mdot
.14571 .33625 Mdot
.14762 .26544 Mdot
.14952 .22792 Mdot
.15143 .25968 Mdot
.15333 .34177 Mdot
.15524 .34664 Mdot
.15714 .23598 Mdot
.15905 .37024 Mdot
.16095 .31898 Mdot
.16286 .25556 Mdot
.16476 .28918 Mdot
.16667 .42346 Mdot
.16857 .29712 Mdot
.17048 .32127 Mdot
.17238 .36536 Mdot
.17429 .42853 Mdot
.17619 .27135 Mdot
.1781 .27206 Mdot
.18 .39535 Mdot
.1819 .26622 Mdot
.18381 .37636 Mdot
.18571 .27185 Mdot
.18762 .34351 Mdot
.18952 .30611 Mdot
.19143 .33115 Mdot
.19333 .33489 Mdot
.19524 .34239 Mdot
.19714 .42921 Mdot
.19905 .24779 Mdot
.20095 .30779 Mdot
.20286 .3482 Mdot
.20476 .32271 Mdot
.20667 .2727 Mdot
.20857 .27848 Mdot
.21048 .29498 Mdot
.21238 .33642 Mdot
.21429 .34185 Mdot
.21619 .39068 Mdot
.2181 .30519 Mdot
.22 .36335 Mdot
.2219 .39926 Mdot
.22381 .24807 Mdot
.22571 .38104 Mdot
.22762 .3763 Mdot
.22952 .2833 Mdot
.23143 .30611 Mdot
.23333 .23551 Mdot
.23524 .26125 Mdot
.23714 .28098 Mdot
.23905 .24297 Mdot
.24095 .38446 Mdot
.24286 .46504 Mdot
.24476 .32194 Mdot
.24667 .36708 Mdot
.24857 .23006 Mdot
.25048 .22737 Mdot
.25238 .40471 Mdot
.25429 .2694 Mdot
.25619 .45791 Mdot
.2581 .29302 Mdot
.26 .42307 Mdot
.2619 .23521 Mdot
.26381 .30451 Mdot
.26571 .39486 Mdot
.26762 .31539 Mdot
.26952 .40045 Mdot
.27143 .31974 Mdot
.27333 .34592 Mdot
.27524 .39823 Mdot
.27714 .39018 Mdot
.27905 .2445 Mdot
.28095 .2647 Mdot
.28286 .42847 Mdot
.28476 .40888 Mdot
.28667 .41111 Mdot
.28857 .2564 Mdot
.29048 .30281 Mdot
.29238 .38141 Mdot
.29429 .41627 Mdot
.29619 .26005 Mdot
.2981 .33508 Mdot
.3 .35258 Mdot
.3019 .40048 Mdot
.30381 .25068 Mdot
.30571 .49161 Mdot
.30762 .27736 Mdot
.30952 .34268 Mdot
.31143 .46227 Mdot
.31333 .29306 Mdot
.31524 .35511 Mdot
.31714 .24291 Mdot
.31905 .31252 Mdot
.32095 .27386 Mdot
.32286 .41785 Mdot
.32476 .42622 Mdot
.32667 .22953 Mdot
.32857 .40011 Mdot
.33048 .41606 Mdot
.33238 .30458 Mdot
.33429 .4293 Mdot
.33619 .43309 Mdot
.3381 .3365 Mdot
.34 .30176 Mdot
.3419 .38484 Mdot
.34381 .2445 Mdot
.34571 .26595 Mdot
.34762 .34971 Mdot
.34952 .41846 Mdot
.35143 .40053 Mdot
.35333 .29682 Mdot
.35524 .35366 Mdot
.35714 .30365 Mdot
.35905 .26123 Mdot
.36095 .27775 Mdot
.36286 .28642 Mdot
.36476 .26699 Mdot
.36667 .31375 Mdot
.36857 .42142 Mdot
.37048 .42549 Mdot
.37238 .4036 Mdot
.37429 .32041 Mdot
.37619 .43647 Mdot
.3781 .27309 Mdot
.38 .24812 Mdot
.3819 .3205 Mdot
.38381 .24099 Mdot
.38571 .4277 Mdot
.38762 .27662 Mdot
.38952 .46039 Mdot
.39143 .4008 Mdot
.39333 .32954 Mdot
.39524 .45189 Mdot
.39714 .29511 Mdot
.39905 .45192 Mdot
.40095 .37574 Mdot
.40286 .33886 Mdot
.40476 .22038 Mdot
.40667 .3843 Mdot
.40857 .27937 Mdot
.41048 .28442 Mdot
.41238 .32236 Mdot
.41429 .28434 Mdot
.41619 .22103 Mdot
.4181 .39336 Mdot
.42 .28231 Mdot
.4219 .24871 Mdot
.42381 .27942 Mdot
.42571 .2634 Mdot
.42762 .32471 Mdot
.42952 .31574 Mdot
.43143 .36613 Mdot
.43333 .26751 Mdot
.43524 .33327 Mdot
.43714 .3874 Mdot
.43905 .36545 Mdot
.44095 .43451 Mdot
.44286 .26831 Mdot
.44476 .33069 Mdot
.44667 .37102 Mdot
.44857 .36692 Mdot
.45048 .34521 Mdot
.45238 .25514 Mdot
.45429 .29503 Mdot
.45619 .34161 Mdot
.4581 .25771 Mdot
.46 .40128 Mdot
.4619 .30096 Mdot
.46381 .37666 Mdot
.46571 .45658 Mdot
.46762 .34021 Mdot
.46952 .31767 Mdot
.47143 .22199 Mdot
.47333 .25369 Mdot
.47524 .34393 Mdot
.47714 .45916 Mdot
.47905 .35196 Mdot
.48095 .40228 Mdot
.48286 .2939 Mdot
.48476 .39639 Mdot
.48667 .44721 Mdot
.48857 .24605 Mdot
.49048 .30568 Mdot
.49238 .36976 Mdot
.49429 .23532 Mdot
.49619 .32928 Mdot
.4981 .41993 Mdot
.5 .30092 Mdot
.5019 .36802 Mdot
.50381 .42471 Mdot
.50571 .44858 Mdot
.50762 .31987 Mdot
.50952 .32772 Mdot
.51143 .41453 Mdot
.51333 .34432 Mdot
.51524 .35364 Mdot
.51714 .30171 Mdot
.51905 .28932 Mdot
.52095 .3156 Mdot
.52286 .32102 Mdot
.52476 .24628 Mdot
.52667 .34364 Mdot
.52857 .31125 Mdot
.53048 .32867 Mdot
.53238 .28335 Mdot
.53429 .36607 Mdot
.53619 .27834 Mdot
.5381 .24709 Mdot
.54 .38363 Mdot
.5419 .32244 Mdot
.54381 .38113 Mdot
.54571 .31144 Mdot
.54762 .25575 Mdot
.54952 .25205 Mdot
.55143 .41928 Mdot
.55333 .31265 Mdot
.55524 .25075 Mdot
.55714 .28439 Mdot
.55905 .32054 Mdot
.56095 .26501 Mdot
.56286 .42551 Mdot
.56476 .31074 Mdot
.56667 .31256 Mdot
.56857 .40036 Mdot
.57048 .35129 Mdot
.57238 .27781 Mdot
.57429 .28623 Mdot
.57619 .25337 Mdot
.5781 .36703 Mdot
.58 .35198 Mdot
.5819 .25481 Mdot
.58381 .32146 Mdot
.58571 .36119 Mdot
.58762 .35527 Mdot
.58952 .35987 Mdot
.59143 .3009 Mdot
.59333 .37105 Mdot
.59524 .45489 Mdot
.59714 .34568 Mdot
.59905 .36698 Mdot
.60095 .49795 Mdot
.60286 .2604 Mdot
.60476 .26547 Mdot
.60667 .40027 Mdot
.60857 .23636 Mdot
.61048 .42515 Mdot
.61238 .28119 Mdot
.61429 .28927 Mdot
.61619 .33671 Mdot
.6181 .26643 Mdot
.62 .32131 Mdot
.6219 .36001 Mdot
.62381 .28116 Mdot
.62571 .46238 Mdot
.62762 .32586 Mdot
.62952 .34427 Mdot
.63143 .38107 Mdot
.63333 .2824 Mdot
.63524 .3282 Mdot
.63714 .40666 Mdot
.63905 .45608 Mdot
.64095 .39681 Mdot
.64286 .32943 Mdot
.64476 .24692 Mdot
.64667 .37499 Mdot
.64857 .42557 Mdot
.65048 .26223 Mdot
.65238 .27244 Mdot
.65429 .28631 Mdot
.65619 .371 Mdot
.6581 .35337 Mdot
.66 .41615 Mdot
.6619 .32412 Mdot
.66381 .34104 Mdot
.66571 .31453 Mdot
.66762 .3226 Mdot
.66952 .40014 Mdot
.67143 .24046 Mdot
.67333 .30029 Mdot
.67524 .30478 Mdot
.67714 .2743 Mdot
.67905 .29236 Mdot
.68095 .33819 Mdot
.68286 .39881 Mdot
.68476 .33583 Mdot
.68667 .24979 Mdot
.68857 .33792 Mdot
.69048 .40676 Mdot
.69238 .38587 Mdot
.69429 .27573 Mdot
.69619 .35779 Mdot
.6981 .41785 Mdot
.7 .36488 Mdot
.7019 .37244 Mdot
.70381 .37663 Mdot
.70571 .27133 Mdot
.70762 .38265 Mdot
.70952 .39742 Mdot
.71143 .2667 Mdot
.71333 .36368 Mdot
.71524 .38908 Mdot
.71714 .31302 Mdot
.71905 .38695 Mdot
.72095 .41047 Mdot
.72286 .43817 Mdot
.72476 .3211 Mdot
.72667 .24689 Mdot
.72857 .38247 Mdot
.73048 .32093 Mdot
.73238 .31829 Mdot
.73429 .24046 Mdot
.73619 .33961 Mdot
.7381 .25197 Mdot
.74 .38764 Mdot
.7419 .27993 Mdot
.74381 .40172 Mdot
.74571 .38747 Mdot
.74762 .4227 Mdot
.74952 .35236 Mdot
.75143 .38402 Mdot
.75333 .35243 Mdot
.75524 .41589 Mdot
.75714 .47818 Mdot
.75905 .39473 Mdot
.76095 .28769 Mdot
.76286 .30283 Mdot
.76476 .45141 Mdot
.76667 .32975 Mdot
.76857 .29133 Mdot
.77048 .40944 Mdot
.77238 .23512 Mdot
.77429 .27057 Mdot
.77619 .27705 Mdot
.7781 .36061 Mdot
.78 .34854 Mdot
.7819 .27908 Mdot
.78381 .26665 Mdot
.78571 .45276 Mdot
.78762 .40738 Mdot
.78952 .37542 Mdot
.79143 .26988 Mdot
.79333 .38019 Mdot
.79524 .26443 Mdot
.79714 .25203 Mdot
.79905 .29282 Mdot
.80095 .34463 Mdot
.80286 .36428 Mdot
.80476 .34178 Mdot
.80667 .28146 Mdot
.80857 .34968 Mdot
.81048 .33629 Mdot
.81238 .45959 Mdot
.81429 .34428 Mdot
.81619 .33616 Mdot
.8181 .25904 Mdot
.82 .35477 Mdot
.8219 .32639 Mdot
.82381 .32805 Mdot
.82571 .37826 Mdot
.82762 .35232 Mdot
.82952 .29149 Mdot
.83143 .46026 Mdot
.83333 .30017 Mdot
.83524 .28361 Mdot
.83714 .35751 Mdot
.83905 .37627 Mdot
.84095 .30016 Mdot
.84286 .32928 Mdot
.84476 .35302 Mdot
.84667 .45361 Mdot
.84857 .24723 Mdot
.85048 .40271 Mdot
.85238 .43709 Mdot
.85429 .39839 Mdot
.85619 .30941 Mdot
.8581 .23297 Mdot
.86 .38781 Mdot
.8619 .32156 Mdot
.86381 .38565 Mdot
.86571 .30009 Mdot
.86762 .27468 Mdot
.86952 .26589 Mdot
.87143 .25407 Mdot
.87333 .30878 Mdot
.87524 .28811 Mdot
.87714 .22816 Mdot
.87905 .26398 Mdot
.88095 .35424 Mdot
.88286 .38001 Mdot
.88476 .33112 Mdot
.88667 .3236 Mdot
.88857 .29749 Mdot
.89048 .32274 Mdot
.89238 .32949 Mdot
.89429 .42843 Mdot
.89619 .40163 Mdot
.8981 .35668 Mdot
.9 .38818 Mdot
.9019 .2416 Mdot
.90381 .3695 Mdot
.90571 .31507 Mdot
.90762 .27079 Mdot
.90952 .35756 Mdot
.91143 .44894 Mdot
.91333 .2786 Mdot
.91524 .37109 Mdot
.91714 .32587 Mdot
.91905 .33565 Mdot
.92095 .4057 Mdot
.92286 .39173 Mdot
.92476 .30201 Mdot
.92667 .35883 Mdot
.92857 .38064 Mdot
.93048 .44883 Mdot
.93238 .27038 Mdot
.93429 .30117 Mdot
.93619 .31113 Mdot
.9381 .26593 Mdot
.94 .32231 Mdot
.9419 .33344 Mdot
.94381 .33924 Mdot
.94571 .26908 Mdot
.94762 .3037 Mdot
.94952 .35315 Mdot
.95143 .22764 Mdot
.95333 .29136 Mdot
.95524 .3554 Mdot
.95714 .34141 Mdot
.95905 .32524 Mdot
.96095 .30166 Mdot
.96286 .46039 Mdot
.96476 .29561 Mdot
.96667 .39848 Mdot
.96857 .34339 Mdot
.97048 .34241 Mdot
.97238 .34226 Mdot
.97429 .41593 Mdot
.97619 .39182 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo07Oooooo0_l000000ooooooo0000o`000030ooooo`001_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool0Moooool2o`000003ooooool0003o0000013ooooo0_l0002^
ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02Gooooo0_l0
000Nooooo`;o0000AOooool2o`0009Wooooo0_l0000Cooooo`001?l00002ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool07oooool2o`0000Cooooo0_l0000Nooooo`;o00005oooool2o`000:oooooo0_l0
000Fooooo`;o00004oooool000Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ
8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0001oooooo0_l0000Tooooo`;o00005ooo
ool2o`000:Wooooo0_l00004ooooo`;o0000:oooool000Kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo02Oooooo0_l0000Gooooo`;o00001oooool2o`0004Wooooo0_l0000Rooooo`;o0000
<oooool2o`0001[ooooo0_l0000aooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo
0_l0000;ooooo`?o00005Oooool2o`0001Oooooo0_l00007ooooo`;o0000BOooool2o`0002;ooooo
0_l0000cooooo`;o0000COooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Co
00002oooool3o`0002oooooo0_l0000Hooooo`;o00004oooool2o`0005_ooooo0_l0000Booooo`;o
0000=?ooool2o`0002?ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So
410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo00;o00002Oooool2o`00
03Cooooo0_l0000;ooooo`;o00002oooool2o`0000Kooooo0_l0000;ooooo`;o00008?ooool2o`00
00Wooooo0_l0000^ooooo`;o00004_ooool2o`0003Cooooo0_l0000Sooooo`00:Oooool2o`0000co
oooo0_l0000=ooooo`;o00006Oooool2o`0000Kooooo0_l0000?ooooo`;o00004oooool2o`0000[o
oooo0_l0000;ooooo`;o00005?ooool2o`0000Wooooo0_l00003ooooo`;o00008?ooool2o`0001So
oooo0_l0000Uooooo`;o0000=Oooool002Wooooo00?o0000ooooooooool06_ooool2o`0001Wooooo
0_l00006ooooo`;o00005oooool2o`0001Oooooo0_l0000;ooooo`;o00009?ooool2o`000003oooo
ool0003o000000;o00006oooool2o`0000_ooooo0_l0000;ooooo`;o00000_ooool2o`00017ooooo
0_l0000>ooooo`;o0000=Oooool002Wooooo00?o0000ooooooooool00_ooool2o`0002Gooooo0_l0
000[ooooo`;o0000;_ooool2o`0000Gooooo0_l0000Fooooo`Co00001Oooool4o`0001oooooo0_l0
000?ooooo`;o00004Oooool2o`0001Kooooo0_l0000]ooooo`00:Oooool00ol0003oooooooooo`02
ooooo`;o00000oooool4o`0001kooooo0_l0000Vooooo`;o0000<oooool4o`0000?ooooo0_l0000F
ooooo`;o00001oooool4o`0004[ooooo0_l0000?ooooo`;o0000;Oooool002Wooooo00?o0000oooo
ooooool01oooool4o`0001[ooooo0_l0000Iooooo`;o00003oooool2o`000003ooooool0003o0000
01;ooooo0_l0000Nooooo`;o0000;?ooool2o`0004Cooooo0_l0000nooooo`00:Oooool2o`0002Ko
oooo0_l0000Iooooo`;o00003Oooool2o`0000?ooooo0_l0000Booooo`;o00004oooool2o`0002[o
oooo0_l0000;ooooo`;o00003_ooool2o`0002cooooo0_l0000Iooooo`;o0000:oooool002Wooooo
00?o0000ooooooooool01?ooool2o`0001kooooo0_l00009ooooo`;o00007_ooool2o`0001?ooooo
0_l00004ooooo`;o00004Oooool2o`000004ooooool0003o0000ooooo`;o00009?ooool2o`0000co
oooo0_l00002ooooo`;o00002Oooool2o`00017ooooo0_l0000Fooooo`;o000000?oooooo`000?l0
00005_ooool2o`000003ooooool0003o0000017ooooo0_l0000Hooooo`00:Oooool00ol0003ooooo
ooooo`04ooooo`;o00004oooool2o`0000Wooooo0_l00007ooooo`Oo000000So410@oooooooooooo
k^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`;o00007?oo
ool2o`0000Cooooo0_l000000ooooooo0000o`000003o`0000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`03onk^k_lb<S;o000000;o000000?oooooo`000?l000009Oooool01OnHV9So410@
o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02o`000006ooooooo^k^ko0000
o`000?lb<S;ok^k^6Oooool3o`0000kooooo0_l000000ol@413oooooooooo`02o`000003oc8b<_l0
003o000000;o00000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^013ooooo0_l0000:ooooo`;o0000
1_ooool4o`000006ooooool0003o0000o`000?lb<S;ogMgM0_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool01?l0003ooooooooooooo
ool2o`0001Kooooo0_l0000Booooo`Ko00001?ooool2o`000003oooooonHV9SoMgMg00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`02ooooo`;o00005?ooool2o`0000oooooo00GoV9RHo`000?l0003o
ooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg02Sooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo0_l00006ooooo`;o00002?ooool2o`00013o
oooo00Co0000oooooooooooooooo0_l000000onHV9SooooooiRHV002o`0000;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Looooo`;o00001_ooool2o`0000?ooooo0_l000000oooooooMgMgoc8b<P02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
000Yooooo`04o`000?ooooooooooooooo`;o00003Oooool2o`0001cooooo1Ol00004ooooo`;o0000
0_ooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool04_ooool2o`0000;o
oooo0_l0000@ooooo`;o000000?ok^k^o`000?l000000_ooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@400/ooooo`05o`000?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01Oooool2o`0000Kooooo
0_l00004ooooo`;o00004Oooool5o`0000;ooooo0_l00003ooooo`05oa0@4?ooooooooooooooool@
41000oooool00ol@413oooooooooo`0>ooooo`;o00006oooool01?l0003oooooooooool@4103oooo
o`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`01ooooo`00:Oooool2o`00
017ooooo0_l0000Pooooo`03o`000?oooooooooo00;ooooo0ol000000ooooooo0000ooooo`02oooo
o`05o`000?ooooooooooooooool000005?ooool2o`0000oooooo0_l00004ooooo`04oiRHV?lQ8B7o
0000o`0000;ooooo00?o0000ooooooooool00_l00003ooooo`;o00000_ooool00ol0003ooooooooo
o`0Mooooo`;o00002_ooool2o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000005Oooool2o`0000gooooo0_l00002ooooo`04odA4A?oMgMgoooooo`00
00?ooooo1?l000000ooooooo0000ooooo`02ooooo`05o`000?ooooooooooooooool000004?ooool2
o`0000cooooo0_l0000<ooooo`05ogMgMolb<S;oooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool00Oooool002Wooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`02ooooo`?o000000Coooooo`000?oooooooooo0_l000001?oooooo0000
o`000?l0000Uooooo`;o00001Oooool00omgMgOoIVIVooooo`02ooooo`03o`000?oooooooooo00;o
00000_ooool3o`0000;ooooo00?o0000ooooooooool07?ooool3o`0000Wooooo00?o410@o`000?l0
00000oooool01Ol0003ooooooooooooooooo000000?ooooo0_l000001?oooooo0000o`000?ooool2
o`00027ooooo0_l00002ooooo`04omgMgOmEEEGoooooo`0000Cooooo0ol000000ooooooo0000oooo
o`02ooooo`?o000000?oooooo`000?ooool01?ooool2o`0001Oooooo0_l00009ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`00:Oooool01?l0003oooooo`000?l00004ooooo`;o0000:oooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000_ooool2o`000004ooooool0003o
0000oa0@42Gooooo0_l00006ooooo`05o`000?ooooooooooooooool@41000oooool5o`0000?ooooo
00?o410@ooooooooool07?ooool2o`0000Kooooo0_l00003ooooo`;o00000oooool01Ol@413ooooo
oooooooooooo410@00?ooooo0_l000001?oooooo0000o`000?ooool2o`0000Gooooo0_l0000Ooooo
o`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?l0003o
0000ooooool@41001Oooool2o`0002;ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`00:Oooool01?l0003ooooo
o`000?l00004ooooo`;o00008oooool2o`0000Kooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Uooooo`;o00000_ooool0
1Ol0003o^[ZjoooooonHV9So410@00?ooooo00CoMgMgoiRHV?ooooooV9RH0ol000001_ooooooMgMg
oiRHV?ooooooV9RHogMgMa[ooooo0_l0000:ooooo`;o000000?o410@oiRHV?ooool00_l00003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool2o`000003oooooonHV9SoMgMg00Sooooo0_l0000O
ooooo`03onk^k_l0003o000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL04_ooool2o`0001Gooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool00ol0003o
ooooooooo`0Jooooo`;o00003_ooool2o`0000Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`;o00003oooool2
o`0001;ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo0_l0000<ooooo`05ojVYZOl@413o0000oa0@
4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo0ol000000olb<S;ok^k^ooooo`0?
ooooo`;o00006?ooool2o`000009ooooool0003o0000ooooooo^k^ko<S8bo`000?lb<S;ok^k^00;o
oooo0_l000001?lb<S;o0000oc8b<_o^k^h3ooooo`;o00003Oooool2o`0001Gooooo1?l00003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Y
ooooo`?o00005oooool2o`000003ooooool0003o000001cooooo0_l0000>ooooo`;o00003oooool2
o`0001Wooooo0_l0000Aooooo`;o00001oooool2o`0003gooooo0_l0000Kooooo`;o00002?ooool2
o`0000Oooooo0_l0000Vooooo`;o00000_ooool2o`0000oooooo000Yooooo`Co00005_ooool2o`00
00?ooooo0_l0000=ooooo`;o00002oooool2o`0002cooooo0_l0000<ooooo`;o00004Oooool2o`00
00Oooooo0_l00020ooooo`;o00005oooool2o`0000oooooo000Yooooo`04o`000?oooooo0000o`00
01_ooooo0_l0000=ooooo`;o0000=Oooool2o`0000;ooooo0_l0000Qooooo`;o00002_ooool2o`00
00Cooooo0_l0000Fooooo`;o00006?ooool2o`0003;ooooo1?l00006ooooo`;o00001Oooool2o`00
00[ooooo0_l000000ooooooo0000o`000007ooooo`;o00004?ooool002Wooooo00?o0000oooooooo
ool0>oooool2o`0000cooooo0_l00007ooooo`;o00002oooool2o`000003ooooool0003o000000?o
oooo0_l0000Pooooo`;o00001oooool2o`000003ooooool0003o000000Cooooo0_l0000Fooooo`;o
00006?ooool3o`0001[ooooo0_l0000Eooooo`Co00001_ooool2o`00017ooooo0_l000000ooooooo
0000o`000002ooooo`;o00000oooool2o`00013ooooo000Yooooo`03o`000?oooooooooo03;ooooo
0_l000000ooooooo0000o`000004ooooo`;o00000_ooool2o`0000Sooooo0_l00007ooooo`;o0000
2oooool2o`0000Kooooo0_l0000Yooooo`;o0000>_ooool2o`0001[ooooo0_l0000Qooooo`;o0000
5_ooool2o`0001Gooooo000Qoooooooo0000A?l00004ooooo`00:Oooool00ol0003oooooooooo`08
ooooo`;o00003?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool01Oooool2o`0000;ooooo00?o0000ooooooooool02Oooool2o`0000_ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool00_l00003ooooo`;o000000?oooooo`000?l000001?l00008ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool01oooool3o`0000cooooo0ol00009ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`;o000000?ooooo
o`000?ooool02_ooool00ol0003oooooooooo`08ooooo`;o00002oooool00ol0003oooooooooo`0:
ooooo`00:Oooool00ol0003oooooooooo`03ooooo`;o00000oooool2o`00033ooooo00?o0000oooo
ooooool03_ooool2o`0000kooooo0_l0000>ooooo`;o00002oooool00ol0003oooooooooo`04oooo
o`;o00002oooool2o`0000kooooo0_l00009ooooo`;o00000_ooool2o`0000Sooooo00?o0000oooo
ooooool04oooool2o`0000kooooo0_l0000Eooooo`03o`000?oooooooooo02?ooooo0_l0000Eoooo
o`03o`000?oooooooooo00[ooooo000Yooooo`03o`000?oooooooooo00?ooooo0_l0000Hooooo`;o
00002Oooool2o`00027ooooo0ol0000Oooooo`Co00003_ooool2o`0000_ooooo0_l0000:ooooo`;o
00000_ooool3o`0000Wooooo0_l0000dooooo`Co0000=_ooool2o`0002;ooooo000Yooooo`04o`00
0?ooooooooooooooo`;o00002_ooool2o`0000kooooo0ol00008ooooo`;o000000?oooooo`000?l0
00002Oooool2o`0000_ooooo0_l00007ooooo`;o00007oooool4o`0000Sooooo0_l0000Mooooo`;o
00000oooool2o`0000Cooooo0_l00003ooooo`;o00001_ooool2o`0000[ooooo0_l0000;ooooo`Co
00004Oooool4o`0002Sooooo0_l00006ooooo`?o00003_ooool2o`0001Oooooo000Yooooo`;o0000
0_ooool2o`0000[ooooo0_l0000?ooooo`;o00002oooool2o`0000Wooooo0_l0000;ooooo`;o0000
=?ooool2o`0000?ooooo0_l0000Sooooo`;o00002oooool2o`0000[ooooo1?l00009ooooo`Co0000
<?ooool2o`0000_ooooo0_l00006ooooo`?o00001oooool2o`0000Gooooo0_l00004ooooo`;o0000
4Oooool002Wooooo00?o0000ooooooooool07oooool2o`0005;ooooo0_l00009ooooo`;o00005?oo
ool2o`0000;ooooo0_l00005ooooo`;o00007Oooool2o`000003ooooool0003o000000;o00009_oo
ool2o`00013ooooo0ol00004ooooo`;o00003_ooool2o`0000Kooooo0_l0000;ooooo`;o00004Ooo
ool002Wooooo00?o0000ooooooooool07oooool2o`00017ooooo0_l0000oooooo`;o00003?ooool2
o`000003ooooool0003o000000kooooo0_l00002ooooo`;o00001Oooool2o`00023ooooo1?l0000V
ooooo`;o00004Oooool2o`0000Cooooo0_l0000;ooooo`;o000000?oooooo`000?l000003Oooool2
o`0001Oooooo000Yooooo`03o`000?oooooooooo01gooooo0_l00004ooooo`;o00003Oooool3o`00
00Cooooo0_l0000Iooooo`;o00002oooool2o`0001kooooo0_l000000ooooooo0000o`00000eoooo
o`;o00005?ooool2o`0002Kooooo1?l0000Dooooo`;o00002Oooool2o`0000Gooooo0_l0000Goooo
o`00:Oooool00ol0003oooooooooo`0Mooooo`;o00001?ooool2o`0000kooooo0_l00004ooooo`;o
00006Oooool2o`0000_ooooo0_l0000Cooooo`;o0000@oooool2o`0001?ooooo1?l0000=ooooo`;o
00005_ooool4o`0001oooooo0_l00006ooooo`;o00005_ooool002Wooooo0_l0000Wooooo`;o0000
2oooool2o`0000Gooooo0_l0000Looooo`;o00007?ooool2o`0000oooooo0_l00002ooooo`;o0000
?Oooool2o`0000Cooooo1?l0000=ooooo`;o00005?ooool2o`0002_ooooo0_l00002ooooo`;o0000
0oooool2o`0000gooooo000Yooooo`03o`000?oooooooooo00Kooooo0_l00002ooooo`;o000000?o
ooooo`000?l000005oooool2o`0000Wooooo1?l00005ooooo`;o00004Oooool2o`0000Wooooo0_l0
000[ooooo`Co00000_ooool4o`0000_ooooo0_l00002ooooo`;o00005Oooool2o`0000Sooooo0_l0
0009ooooo`;o0000:_ooool3o`000003ooooool0003o000002cooooo0_l00002ooooo`?o00003Ooo
ool002Wooooo00?o0000ooooooooool01_ooool2o`0000;ooooo1Ol00005ooooo`;o00004Oooool2
o`0000Sooooo0_l00003ooooo`;o00005Oooool2o`0003Kooooo0_l00006ooooo`;o00002oooool2
o`0000;ooooo0_l0000Eooooo`;o00002?ooool2o`0002kooooo0_l00005ooooo`;o00000_ooool2
o`00033ooooo0_l0000>ooooo`00:Oooool00ol0003oooooooooo`07ooooo`;o00000oooool2o`00
00Kooooo0_l0000:ooooo`?o00001?ooool2o`0000gooooo0_l0000/ooooo`;o0000:Oooool2o`00
01_ooooo0_l000000ooooooo0000o`00000eooooo`;o00001oooool2o`0000Sooooo0_l00004oooo
o`;o0000>oooool002Wooooo00?o0000ooooooooool01oooool2o`0001Oooooo0ol0000booooo`;o
00000oooool2o`0000Sooooo0_l000000ooooooo0000o`00000Vooooo`;o00002Oooool2o`00013o
oooo0_l000001?oooooo0000o`000?ooool2o`0001Cooooo0_l0000Looooo`?o00004?ooool2o`00
0004ooooool0003o0000ooooo`;o00000oooool2o`0000[ooooo0_l0000Dooooo`Co00004_ooool0
02Wooooo0_l0001Fooooo`;o00000oooool2o`0000_ooooo0_l0000aooooo`;o00005_ooool2o`00
01Cooooo0_l0000:ooooo`;o00004Oooool2o`0001?ooooo0_l00004ooooo`Co00002_ooool2o`00
00?ooooo0_l00002ooooo`;o00002oooool4o`0001;ooooo000Yooooo`03o`000?oooooooooo01So
oooo0_l0002Gooooo`?o00002Oooool2o`0001Gooooo0_l0000Iooooo`;o00004Oooool2o`00017o
oooo0_l00002ooooo`;o00001?ooool2o`0001_ooooo000Yooooo`03o`000?oooooooooo01;ooooo
0_l00004ooooo`;o00008Oooool2o`0007Cooooo0ol00009ooooo`;o00006oooool2o`0001?ooooo
0_l00006ooooo`;o00009_ooool2o`0001_ooooo000Yooooo`03o`000?oooooooooo00Cooooo0_l0
0004ooooo`;o00001_ooool2o`0000Cooooo0_l00008ooooo`;o00002?ooool2o`0000gooooo0_l0
0007ooooo`;o0000>Oooool2o`000004ooooool0003o0000ooooo`;o00006Oooool2o`0000cooooo
0_l00005ooooo`;o00007oooool2o`0000;ooooo0_l0000Kooooo`;o0000@oooool002Wooooo00?o
0000ooooooooool01?ooool2o`0000Cooooo0_l00006ooooo`;o00003_ooool2o`0000Cooooo0_l0
0002ooooo`;o00005_ooool2o`0003Wooooo0_l000000ooooooo0000o`000003o`0000cooooo0_l0
00000ooooooo0000o`000008ooooo`;o00003?ooool2o`0000Gooooo0_l0000Aooooo`;o00003?oo
ool2o`0003oooooo0_l0000Sooooo`00:Oooool2o`0001?ooooo0_l0000Dooooo`;o0000F_ooool2
o`0000gooooo0_l000000ooooooo0000o`00000Kooooo`;o00004oooool2o`0000cooooo0_l0000o
ooooo`;o00000_ooool2o`0001oooooo000Yooooo`03o`000?oooooooooo00Gooooo0_l0000Yoooo
o`;o00003?ooool2o`0003Kooooo0_l0000Booooo`;o00009oooool2o`00013ooooo0_l0000?oooo
o`?o00006Oooool2o`0000kooooo0_l0000Gooooo`;o00007oooool000Kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo00Gooooo0_l0000:ooooo`;o00000oooool2o`0001Sooooo0_l0000<
ooooo`;o0000=_ooool2o`0001;ooooo0_l0000iooooo`;o00004?ooool2o`0001Wooooo1?l00008
ooooo`;o00000_ooool2o`0000cooooo0_l0000Zooooo`001_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8boooo
o`04ooooo`;o00004_ooool2o`0000?ooooo0_l0000Uooooo`;o00005?ooool2o`0004kooooo0_l0
000Kooooo`;o00005_ooool2o`0000Gooooo0_l0000Cooooo`;o00002?ooool2o`00013ooooo0_l0
000=ooooo`;o00006oooool000Kooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool2o`0001Kooooo0_l0000Vooooo`;o00000ooo
ool2o`0000oooooo0_l0000>ooooo`;o00004_ooool2o`0002Wooooo0ol0000Kooooo`;o00004Ooo
ool2o`0000?ooooo0_l00005ooooo`;o00001Oooool2o`0002;ooooo0_l0000Cooooo`;o00006ooo
ool000Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o
MgMgoc8b<_ooool01?ooool3o`0001Gooooo0_l0000[ooooo`;o00007oooool2o`0001;ooooo0_l0
0008ooooo`;o00007oooool2o`0002oooooo0_l00006ooooo`?o00001Oooool5o`00027ooooo0ol0
000:ooooo`;o00009?ooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo03[ooooo
0_l0000Booooo`;o0000<Oooool2o`0005Sooooo0ol00005ooooo`?o00008oooool2o`0000_ooooo
0_l00005ooooo`;o00004?ooool2o`0000_ooooo0006ooooo`05oa0@4?ooooooooooooooool@4100
3oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
3oooool2o`0000Kooooo0_l0000Eooooo`;o00002_ooool2o`0000kooooo0_l00002ooooo`;o0000
:oooool2o`0006cooooo0_l0000booooo`;o00004?ooool2o`0000_ooooo0006ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooooooo
ool01oooool2o`00013ooooo0_l00006ooooo`;o00005Oooool2o`0001[ooooo0_l000000ooooooo
0000o`00000/ooooo`;o00004oooool2o`00037ooooo0_l0000;ooooo`;o00001oooool2o`0000ko
oooo0_l0000Looooo`;o00008_ooool2o`0000oooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o00005?ooool2o`00
02Oooooo0_l0000=ooooo`Co00001oooool2o`0000Kooooo0_l00006ooooo`;o00002_ooool2o`00
01Gooooo0_l00005ooooo`;o00006Oooool2o`0000_ooooo0_l00009ooooo`;o00001oooool2o`00
00;ooooo0_l00007ooooo`;o00002Oooool2o`00027ooooo0_l0000<ooooo`;o00005?ooool2o`00
00oooooo000Yooooo`;o00005?ooool2o`0002Oooooo0_l00008ooooo`;o00000oooool2o`0000Wo
oooo0_l00006ooooo`;o00001_ooool2o`0000Cooooo0_l00004ooooo`;o00005Oooool2o`0000Co
oooo0_l0000Jooooo`;o00002oooool2o`0001;ooooo0_l0000Fooooo`;o00008?ooool2o`0000go
oooo0_l0000Uooooo`00:Oooool00ol0003oooooooooo`16ooooo`;o00009?ooool2o`00027ooooo
0_l0000`ooooo`;o00004?ooool2o`0001gooooo0_l0000Booooo`;o00005Oooool2o`0001gooooo
000Yooooo`03o`000?oooooooooo053ooooo0ol0001^ooooo`;o00004?ooool2o`0000Oooooo0_l0
000>ooooo`;o00001?ooool2o`0002Wooooo0_l0000Mooooo`00:Oooool00ol0003oooooooooo`09
ooooo`;o0000AOooool3o`0004Kooooo0_l00011ooooo`;o00003_ooool2o`0004kooooo000Yoooo
o`03o`000?oooooooooo00Wooooo0_l0000@ooooo`;o0000=_ooool2o`0000[ooooo0_l0000hoooo
o`;o0000;_ooool2o`0001cooooo0_l00015ooooo`;o00003?ooool002Wooooo0_l0000?ooooo`;o
00002oooool2o`0003Kooooo0_l00007ooooo`;o000000?oooooo`000?l000001?ooool2o`0002ko
oooo0_l0000?ooooo`;o00008Oooool2o`0000[ooooo0_l0000@ooooo`;o0000AOooool2o`0000co
oooo000Yooooo`03o`000?oooooooooo00kooooo0_l00004ooooo`;o00003Oooool2o`0000Gooooo
0_l0000Looooo`;o00004_ooool2o`0000Oooooo0_l00004ooooo`;o0000:?ooool2o`0000oooooo
0_l0000]ooooo`;o00003_ooool2o`0005Gooooo000Yooooo`03o`000?oooooooooo01Cooooo0_l0
000=ooooo`;o00001Oooool2o`0001cooooo0_l0000Cooooo`;o00003?ooool3o`0002Wooooo0_l0
000Aooooo`;o00003Oooool2o`0000[ooooo0_l0000Nooooo`;o0000EOooool002Wooooo00?o0000
ooooooooool03?ooool2o`0000kooooo0_l0000?ooooo`;o00001Oooool2o`0001[ooooo0_l0000;
ooooo`;o000000?oooooo`000?l000002_ooool2o`0000?ooooo0_l0000Tooooo`;o00004Oooool2
o`0000gooooo0_l0000:ooooo`;o0000COooool2o`0002Kooooo000Yooooo`03o`000?oooooooooo
00cooooo0_l00007ooooo`;o00001Oooool2o`0000oooooo0_l00005ooooo`;o00006_ooool2o`00
00kooooo0ol0000>ooooo`;o0000XOooool2o`0002Kooooo000Yooooo`;o00005_ooool2o`0004[o
oooo0_l0000Oooooo`;o0000^?ooool002Wooooo00?o0000ooooooooool0K_ooool2o`0001;ooooo
0_l0001Iooooo`;o0000:?ooool2o`0003?ooooo000Yooooo`03o`000?oooooooooo06kooooo0_l0
001]ooooo`;o0000:?ooool2o`0003?ooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool08_ooool2o`0006gooooo0_l00004ooooo`;o0000Xoooool002Wo
oooo0_l0000Sooooo`;o0000KOooool2o`0000Cooooo0_l0001Booooo`;o0000;Oooool2o`0000Co
oooo0_l0000Jooooo`00:Oooool00ol0003oooooooooo`1dooooo`?o0000?Oooool2o`0003Gooooo
0_l00004ooooo`;o00004_ooool2o`0001?ooooo0_l00004ooooo`;o00006_ooool000kooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Go
oooo00?o0000ooooooooool0Aoooool2o`0002_ooooo0ol0000Cooooo`;o0000:?ooool2o`0000co
oooo0_l0000]ooooo`;o00004_ooool2o`0003Gooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`17ooooo`;o
0000:Oooool2o`0001Kooooo0_l00002ooooo`;o0000<_ooool2o`0003Kooooo0_l00004ooooo`;o
0000:?ooool2o`00013ooooo000>ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003o
ooooooooo`03ooooo`?o0000FOooool2o`0001Oooooo0_l0000Jooooo`;o0000;_ooool2o`0003[o
oooo0_l00004ooooo`;o0000:?ooool2o`00013ooooo000>ooooo`05o`000?ooooooooooooooool0
00003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo04?ooooo0_l0000Dooooo`;o
0000Hoooool2o`0007cooooo000>ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0@oooool2o`000?Oooooo000>ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
0?oooooo?Oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo1?l00006ooooo`;o0000jOooool2o`0005;ooooo000Yooooo`03o`000?oooooooooo0>So
oooo0_l0001Booooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0Eoooool2o`000>?ooooo000Yoooo
o`;o0000F?ooool2o`000>?ooooo000Yooooo`03o`000?oooooooooo0;Kooooo0_l00024ooooo`00
:Oooool00ol0003oooooooooo`2fooooo`;o0000Q?ooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400=ooooo`03
ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000Kooooo
00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05o`000?ooooooooooooooool0
00003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0
003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onY
ZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmoooo
o`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_ooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Oooooo`Co000000?o410@ooooooooool0
0oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`?o0000oooooolm
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Oooooo`03oeEEEOmVIVKo00000?ooooooAoooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .31302 Mdot
.02762 .40173 Mdot
.02952 .27494 Mdot
.03143 .26191 Mdot
.03333 .25024 Mdot
.03524 .29615 Mdot
.03714 .31062 Mdot
.03905 .22706 Mdot
.04095 .34395 Mdot
.04286 .30891 Mdot
.04476 .25714 Mdot
.04667 .25762 Mdot
.04857 .36072 Mdot
.05048 .25792 Mdot
.05238 .26715 Mdot
.05429 .32481 Mdot
.05619 .27759 Mdot
.0581 .3539 Mdot
.06 .35496 Mdot
.0619 .34874 Mdot
.06381 .35045 Mdot
.06571 .40475 Mdot
.06762 .39827 Mdot
.06952 .3403 Mdot
.07143 .35342 Mdot
.07333 .37128 Mdot
.07524 .2902 Mdot
.07714 .35624 Mdot
.07905 .37033 Mdot
.08095 .40195 Mdot
.08286 .32537 Mdot
.08476 .34317 Mdot
.08667 .23432 Mdot
.08857 .35023 Mdot
.09048 .38563 Mdot
.09238 .27426 Mdot
.09429 .4316 Mdot
.09619 .34912 Mdot
.0981 .38643 Mdot
.1 .27879 Mdot
.1019 .35916 Mdot
.10381 .37599 Mdot
.10571 .36666 Mdot
.10762 .34 Mdot
.10952 .27848 Mdot
.11143 .31378 Mdot
.11333 .26956 Mdot
.11524 .38786 Mdot
.11714 .31766 Mdot
.11905 .35964 Mdot
.12095 .3912 Mdot
.12286 .41493 Mdot
.12476 .21947 Mdot
.12667 .38155 Mdot
.12857 .37902 Mdot
.13048 .28696 Mdot
.13238 .2293 Mdot
.13429 .2765 Mdot
.13619 .41843 Mdot
.1381 .26272 Mdot
.14 .32753 Mdot
.1419 .46265 Mdot
.14381 .3887 Mdot
.14571 .31705 Mdot
.14762 .24115 Mdot
.14952 .31493 Mdot
.15143 .31797 Mdot
.15333 .30634 Mdot
.15524 .35231 Mdot
.15714 .31929 Mdot
.15905 .31098 Mdot
.16095 .28068 Mdot
.16286 .30478 Mdot
.16476 .33992 Mdot
.16667 .38848 Mdot
.16857 .31408 Mdot
.17048 .21954 Mdot
.17238 .35164 Mdot
.17429 .40589 Mdot
.17619 .34362 Mdot
.1781 .24431 Mdot
.18 .39951 Mdot
.1819 .27905 Mdot
.18381 .37979 Mdot
.18571 .23594 Mdot
.18762 .3348 Mdot
.18952 .24973 Mdot
.19143 .26164 Mdot
.19333 .25672 Mdot
.19524 .31049 Mdot
.19714 .35722 Mdot
.19905 .36692 Mdot
.20095 .33828 Mdot
.20286 .28347 Mdot
.20476 .33644 Mdot
.20667 .38806 Mdot
.20857 .26134 Mdot
.21048 .38864 Mdot
.21238 .22368 Mdot
.21429 .26296 Mdot
.21619 .3361 Mdot
.2181 .24467 Mdot
.22 .25351 Mdot
.2219 .357 Mdot
.22381 .26603 Mdot
.22571 .35989 Mdot
.22762 .32751 Mdot
.22952 .34469 Mdot
.23143 .33817 Mdot
.23333 .31649 Mdot
.23524 .27916 Mdot
.23714 .26426 Mdot
.23905 .34813 Mdot
.24095 .29792 Mdot
.24286 .38834 Mdot
.24476 .27778 Mdot
.24667 .34217 Mdot
.24857 .287 Mdot
.25048 .31312 Mdot
.25238 .42953 Mdot
.25429 .3621 Mdot
.25619 .45433 Mdot
.2581 .37495 Mdot
.26 .37657 Mdot
.2619 .31541 Mdot
.26381 .25868 Mdot
.26571 .31708 Mdot
.26762 .41517 Mdot
.26952 .37606 Mdot
.27143 .32612 Mdot
.27333 .3992 Mdot
.27524 .35886 Mdot
.27714 .2879 Mdot
.27905 .28331 Mdot
.28095 .34789 Mdot
.28286 .39706 Mdot
.28476 .43375 Mdot
.28667 .34921 Mdot
.28857 .30936 Mdot
.29048 .22673 Mdot
.29238 .27631 Mdot
.29429 .46046 Mdot
.29619 .30952 Mdot
.2981 .35716 Mdot
.3 .2789 Mdot
.3019 .32625 Mdot
.30381 .25235 Mdot
.30571 .44515 Mdot
.30762 .34019 Mdot
.30952 .2754 Mdot
.31143 .44899 Mdot
.31333 .24595 Mdot
.31524 .33341 Mdot
.31714 .33576 Mdot
.31905 .27248 Mdot
.32095 .24954 Mdot
.32286 .42951 Mdot
.32476 .3991 Mdot
.32667 .28968 Mdot
.32857 .43095 Mdot
.33048 .43084 Mdot
.33238 .36215 Mdot
.33429 .40752 Mdot
.33619 .35883 Mdot
.3381 .2426 Mdot
.34 .36871 Mdot
.3419 .32388 Mdot
.34381 .2596 Mdot
.34571 .24776 Mdot
.34762 .34903 Mdot
.34952 .43162 Mdot
.35143 .32999 Mdot
.35333 .33541 Mdot
.35524 .33513 Mdot
.35714 .25001 Mdot
.35905 .3279 Mdot
.36095 .2337 Mdot
.36286 .39737 Mdot
.36476 .25443 Mdot
.36667 .26961 Mdot
.36857 .37521 Mdot
.37048 .42629 Mdot
.37238 .3083 Mdot
.37429 .34679 Mdot
.37619 .3685 Mdot
.3781 .32051 Mdot
.38 .35325 Mdot
.3819 .41782 Mdot
.38381 .34642 Mdot
.38571 .3491 Mdot
.38762 .35652 Mdot
.38952 .44269 Mdot
.39143 .32666 Mdot
.39333 .28386 Mdot
.39524 .45793 Mdot
.39714 .22719 Mdot
.39905 .40136 Mdot
.40095 .2677 Mdot
.40286 .26939 Mdot
.40476 .3194 Mdot
.40667 .35949 Mdot
.40857 .27332 Mdot
.41048 .26982 Mdot
.41238 .29026 Mdot
.41429 .25422 Mdot
.41619 .2947 Mdot
.4181 .34457 Mdot
.42 .26753 Mdot
.4219 .27528 Mdot
.42381 .26489 Mdot
.42571 .29178 Mdot
.42762 .26215 Mdot
.42952 .38852 Mdot
.43143 .34785 Mdot
.43333 .24666 Mdot
.43524 .34313 Mdot
.43714 .32999 Mdot
.43905 .33627 Mdot
.44095 .36193 Mdot
.44286 .31652 Mdot
.44476 .24659 Mdot
.44667 .26063 Mdot
.44857 .33838 Mdot
.45048 .41461 Mdot
.45238 .2572 Mdot
.45429 .23531 Mdot
.45619 .33143 Mdot
.4581 .27786 Mdot
.46 .39848 Mdot
.4619 .3366 Mdot
.46381 .27017 Mdot
.46571 .45889 Mdot
.46762 .29711 Mdot
.46952 .28962 Mdot
.47143 .29166 Mdot
.47333 .27647 Mdot
.47524 .29039 Mdot
.47714 .4483 Mdot
.47905 .34344 Mdot
.48095 .36841 Mdot
.48286 .37613 Mdot
.48476 .35217 Mdot
.48667 .46203 Mdot
.48857 .32705 Mdot
.49048 .23322 Mdot
.49238 .30989 Mdot
.49429 .33758 Mdot
.49619 .33171 Mdot
.4981 .425 Mdot
.5 .24574 Mdot
.5019 .30591 Mdot
.50381 .39202 Mdot
.50571 .39383 Mdot
.50762 .27487 Mdot
.50952 .28093 Mdot
.51143 .42773 Mdot
.51333 .37023 Mdot
.51524 .32991 Mdot
.51714 .37075 Mdot
.51905 .31467 Mdot
.52095 .22643 Mdot
.52286 .40391 Mdot
.52476 .29656 Mdot
.52667 .28966 Mdot
.52857 .23418 Mdot
.53048 .30917 Mdot
.53238 .24945 Mdot
.53429 .28632 Mdot
.53619 .26227 Mdot
.5381 .32727 Mdot
.54 .29883 Mdot
.5419 .36665 Mdot
.54381 .29333 Mdot
.54571 .37451 Mdot
.54762 .30923 Mdot
.54952 .32467 Mdot
.55143 .42938 Mdot
.55333 .34662 Mdot
.55524 .30806 Mdot
.55714 .38291 Mdot
.55905 .25892 Mdot
.56095 .25575 Mdot
.56286 .3878 Mdot
.56476 .33091 Mdot
.56667 .34517 Mdot
.56857 .43055 Mdot
.57048 .24235 Mdot
.57238 .34183 Mdot
.57429 .27173 Mdot
.57619 .28925 Mdot
.5781 .2706 Mdot
.58 .29173 Mdot
.5819 .25856 Mdot
.58381 .41821 Mdot
.58571 .42168 Mdot
.58762 .24642 Mdot
.58952 .42043 Mdot
.59143 .3191 Mdot
.59333 .42645 Mdot
.59524 .45076 Mdot
.59714 .24759 Mdot
.59905 .25836 Mdot
.60095 .46643 Mdot
.60286 .33557 Mdot
.60476 .34956 Mdot
.60667 .3656 Mdot
.60857 .33912 Mdot
.61048 .34784 Mdot
.61238 .26023 Mdot
.61429 .38566 Mdot
.61619 .37006 Mdot
.6181 .30219 Mdot
.62 .39065 Mdot
.6219 .29196 Mdot
.62381 .36965 Mdot
.62571 .4426 Mdot
.62762 .28664 Mdot
.62952 .25721 Mdot
.63143 .36544 Mdot
.63333 .23211 Mdot
.63524 .31544 Mdot
.63714 .3137 Mdot
.63905 .42463 Mdot
.64095 .45585 Mdot
.64286 .27478 Mdot
.64476 .27755 Mdot
.64667 .38187 Mdot
.64857 .40214 Mdot
.65048 .27086 Mdot
.65238 .28012 Mdot
.65429 .3184 Mdot
.65619 .31422 Mdot
.6581 .24303 Mdot
.66 .42558 Mdot
.6619 .33625 Mdot
.66381 .39878 Mdot
.66571 .32898 Mdot
.66762 .29174 Mdot
.66952 .39988 Mdot
.67143 .30587 Mdot
.67333 .36809 Mdot
.67524 .36214 Mdot
.67714 .26004 Mdot
.67905 .22069 Mdot
.68095 .36942 Mdot
.68286 .39228 Mdot
.68476 .31675 Mdot
.68667 .25414 Mdot
.68857 .27947 Mdot
.69048 .34029 Mdot
.69238 .40325 Mdot
.69429 .32838 Mdot
.69619 .30786 Mdot
.6981 .46105 Mdot
.7 .25433 Mdot
.7019 .42749 Mdot
.70381 .28666 Mdot
.70571 .34485 Mdot
.70762 .35202 Mdot
.70952 .32349 Mdot
.71143 .26031 Mdot
.71333 .25317 Mdot
.71524 .45371 Mdot
.71714 .23349 Mdot
.71905 .28323 Mdot
.72095 .32021 Mdot
.72286 .37038 Mdot
.72476 .31268 Mdot
.72667 .29455 Mdot
.72857 .27799 Mdot
.73048 .22711 Mdot
.73238 .31738 Mdot
.73429 .28028 Mdot
.73619 .3685 Mdot
.7381 .26973 Mdot
.74 .3288 Mdot
.7419 .37938 Mdot
.74381 .36648 Mdot
.74571 .43025 Mdot
.74762 .4172 Mdot
.74952 .40021 Mdot
.75143 .4313 Mdot
.75333 .40095 Mdot
.75524 .33197 Mdot
.75714 .4134 Mdot
.75905 .42916 Mdot
.76095 .24279 Mdot
.76286 .26869 Mdot
.76476 .40595 Mdot
.76667 .25257 Mdot
.76857 .31923 Mdot
.77048 .31764 Mdot
.77238 .3153 Mdot
.77429 .28272 Mdot
.77619 .33413 Mdot
.7781 .36548 Mdot
.78 .30278 Mdot
.7819 .38 Mdot
.78381 .24675 Mdot
.78571 .45568 Mdot
.78762 .31457 Mdot
.78952 .32838 Mdot
.79143 .22978 Mdot
.79333 .34295 Mdot
.79524 .33129 Mdot
.79714 .31231 Mdot
.79905 .27212 Mdot
.80095 .23685 Mdot
.80286 .25401 Mdot
.80476 .28667 Mdot
.80667 .33099 Mdot
.80857 .30244 Mdot
.81048 .34344 Mdot
.81238 .42593 Mdot
.81429 .27642 Mdot
.81619 .24215 Mdot
.8181 .30055 Mdot
.82 .33564 Mdot
.8219 .31924 Mdot
.82381 .25817 Mdot
.82571 .34051 Mdot
.82762 .3137 Mdot
.82952 .26341 Mdot
.83143 .45181 Mdot
.83333 .22697 Mdot
.83524 .30939 Mdot
.83714 .38614 Mdot
.83905 .32752 Mdot
.84095 .24053 Mdot
.84286 .36734 Mdot
.84476 .34166 Mdot
.84667 .41083 Mdot
.84857 .36721 Mdot
.85048 .37469 Mdot
.85238 .34014 Mdot
.85429 .35236 Mdot
.85619 .26311 Mdot
.8581 .33053 Mdot
.86 .28596 Mdot
.8619 .26034 Mdot
.86381 .40258 Mdot
.86571 .21929 Mdot
.86762 .32715 Mdot
.86952 .30166 Mdot
.87143 .31669 Mdot
.87333 .23391 Mdot
.87524 .35352 Mdot
.87714 .34176 Mdot
.87905 .30835 Mdot
.88095 .38459 Mdot
.88286 .37542 Mdot
.88476 .33166 Mdot
.88667 .28189 Mdot
.88857 .3432 Mdot
.89048 .22726 Mdot
.89238 .30291 Mdot
.89429 .40026 Mdot
.89619 .39474 Mdot
.8981 .27121 Mdot
.9 .30514 Mdot
.9019 .27818 Mdot
.90381 .31235 Mdot
.90571 .41559 Mdot
.90762 .33008 Mdot
.90952 .24659 Mdot
.91143 .39401 Mdot
.91333 .26223 Mdot
.91524 .42673 Mdot
.91714 .36704 Mdot
.91905 .25856 Mdot
.92095 .3379 Mdot
.92286 .33821 Mdot
.92476 .35193 Mdot
.92667 .31053 Mdot
.92857 .35029 Mdot
.93048 .4646 Mdot
.93238 .3517 Mdot
.93429 .31321 Mdot
.93619 .37308 Mdot
.9381 .33978 Mdot
.94 .31057 Mdot
.9419 .28219 Mdot
.94381 .38271 Mdot
.94571 .35158 Mdot
.94762 .26536 Mdot
.94952 .36831 Mdot
.95143 .31208 Mdot
.95333 .25123 Mdot
.95524 .27028 Mdot
.95714 .35669 Mdot
.95905 .35551 Mdot
.96095 .32467 Mdot
.96286 .37918 Mdot
.96476 .32447 Mdot
.96667 .40086 Mdot
.96857 .4131 Mdot
.97048 .24651 Mdot
.97238 .35484 Mdot
.97429 .36045 Mdot
.97619 .28964 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo01gooooo0_l0000<ooooo`;o0000X_ooool2o`0003[ooooo0_l0000_oooo
o`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool07Oooool2o`0000cooooo0_l0000<
ooooo`;o0000U?ooool2o`0003[ooooo0_l0000_ooooo`001_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8boooo
o`04ooooo`04o`000?ooooooooooooooo`;o0000=_ooool2o`0001Oooooo0_l0000Pooooo`;o0000
9_ooool2o`00047ooooo0_l0000Pooooo`;o00004?ooool2o`0002Oooooo0004o`0000;ooooo00Go
410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool0
0oooool01?l0003oooooooooooooool2o`0001cooooo0_l0000aooooo`;o00008?ooool2o`0002Ko
oooo0_l00011ooooo`;o00004_ooool2o`0000cooooo0_l0000@ooooo`;o00009oooool000Kooooo
00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_oo
ool01?ooool3o`0001oooooo0_l00018ooooo`;o00009oooool2o`0000_ooooo0_l0000Oooooo`;o
00006Oooool2o`0001Kooooo0_l0000Hooooo`;o0000;Oooool000Kooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005oooo
o`03o`000?oooooooooo013ooooo0_l0000Nooooo`;o0000=oooool2o`0001cooooo0_l00009oooo
o`;o00002oooool2o`0001oooooo0_l0000Iooooo`;o00006Oooool2o`0001Gooooo0_l0000]oooo
o`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo013ooooo0_l0000Nooooo`;o0000EOooool2o`00
06gooooo0_l00014ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09?ooool2
o`0003_ooooo0_l00019ooooo`;o00006_ooool2o`0001oooooo0_l0000@ooooo`;o00001_ooool2
o`0003Oooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo02Cooooo0_l00008ooooo`;o00002ooo
ool2o`0001cooooo0_l00006ooooo`;o00008Oooool2o`0000oooooo0_l0000Eooooo`;o00001?oo
ool2o`0001Cooooo0_l0000Oooooo`;o00004?ooool2o`0000Kooooo0_l0000Dooooo`;o00004_oo
ool2o`0000gooooo000Yooooo`;o0000;oooool2o`0000;ooooo0_l00007ooooo`;o00007?ooool2
o`000003ooooool0003o000000Kooooo0_l0000Jooooo`;o00000_ooool2o`0000oooooo0_l00009
ooooo`;o00004?ooool2o`000003ooooool0003o000003[ooooo0_l0000Vooooo`;o00004_ooool2
o`0000gooooo000Yooooo`04o`000?oooooo0000o`00037ooooo0_l0000Rooooo`;o00001?ooool2
o`0000Kooooo0_l000000ooooooo0000o`00000Gooooo`;o00007_ooool2o`0001?ooooo0_l0000d
ooooo`;o00001?ooool2o`0003Cooooo0_l0000Cooooo`00:Oooool01?l0003oooooo`000?l0000j
ooooo`;o00006Oooool2o`0000oooooo0_l000000ooooooo0000o`00000>ooooo`;o0000;Oooool2
o`0002Kooooo0_l00003ooooo`;o00000_ooool2o`0000oooooo0_l0000:ooooo`;o0000;_ooool2
o`0001?ooooo000Yooooo`03o`000?oooooooooo00?ooooo1?l0000/ooooo`;o00001_ooool2o`00
00cooooo0_l0000Oooooo`;o00003_ooool2o`0000[ooooo0_l0000Pooooo`?o00001Oooool2o`00
00?ooooo0_l00008ooooo`;o00004?ooool2o`0000?ooooo0_l00002ooooo`;o00006oooool2o`00
00Gooooo0_l0000Looooo`;o00007_ooool002Wooooo00Co0000ooooool0003o00000_ooool4o`00
02_ooooo0ol00003ooooo`;o00003oooool2o`0001Sooooo0_l0000Iooooo`;o00001?ooool4o`00
023ooooo0_l00006ooooo`;o00000oooool2o`0000?ooooo0_l00003ooooo`;o00003Oooool2o`00
00Wooooo0_l0000Sooooo`;o00002_ooool2o`00013ooooo0_l0000Nooooo`00:Oooool4o`00023o
oooo0_l0000?ooooo`;o00001?ooool4o`0000Gooooo0_l0000Pooooo`;o00006?ooool3o`0000Co
oooo0_l0000Kooooo`;o00005oooool2o`0001;ooooo0_l00009ooooo`;o00009?ooool2o`0000Oo
oooo1?l0000>ooooo`;o00008?ooool002Wooooo00?o0000ooooooooool01Oooool2o`0001[ooooo
0_l0000Gooooo`;o000000?oooooo`000?l000000_ooool2o`0003?ooooo0_l00004ooooo`?o0000
8_ooool2o`0005cooooo0_l00007ooooo`;o00004?ooool2o`0000Wooooo0_l0000Eooooo`00:Ooo
ool00ol0003oooooooooo`05ooooo`;o00004_ooool2o`0001Gooooo1?l000002Ol@413ooooooooo
ooo^k^ko<S8bo`000?lb<S;ok^k^ooooo`02o`000005onk^k_lb<S;o0000oc8b<_o^k^h09oooool7
o`0000?ooooo00Cok^k^o`000?l0003o<S8b0_l000001ooooooo0000o`000?lb<S;o0000oc8b<_o^
k^h02?ooool2o`0001kooooo00CoV9RHoa0@4?l0003o<S8b0_l00002ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo0_l0000Jooooo`;o00001Ooo
ool3o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h06Oooool2o`0000kooooo1Ol00002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Yooooo`03o`000?oooooooooo01;ooooo0_l00005oooo
o`;o00005oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01Oooooo0_l0000>ooooo`;o000000GoV9RHob4Q8Oo^k^kooooo
odA4A003ooooo`03ogMgMol0003o000000?o00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00So
oooo0_l0000Nooooo`03oa0@4?nj^[[ooooo00?o00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`;o00006_ooool2o`0000Kooooo0_l00003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool2o`000004oiRHV?ooooooV9RHogMgMaWooooo
0_l0000Aooooo`;o00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`00:Oooool3o`0000Oooooo0_l00009ooooo`;o00003?ooool2o`00013o
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooo
oooooooooooooa0@400?ooooo`;o00000oooool2o`000003ooooool0003o0000017ooooo00?oV9RH
ob4Q8Oo^k^h01?ooool00ol@413oooooooooo`02o`0000;ooooo0_l00003ooooo`03oa0@4?oooooo
oooo00Wooooo0_l00009ooooo`;o00004oooool2o`0000?ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41001?ooool3o`00027ooooo1Ol00003ooooo`05oa0@
4?ooooooooooooooool@41000_ooool2o`0000;ooooo0_l0000]ooooo`04o`000?oooooooooooa0@
40?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo007ooooo000Yoooo
o`?o00001oooool2o`0000cooooo0_l000000ooooooo0000o`000006ooooo`;o00001_ooool2o`00
00Gooooo0_l000000ooooooo0000ooooo`03ooooo`05o`000?ooooooooooooooool000000oooool3
o`000003ooooool0003o000000kooooo1?l000000ooooooo0000o`00000Eooooo`03oiRHV?lQ8B7o
k^k^00?ooooo00Go0000ooooooooooooooooo`000002ooooo`;o00000oooool00ol0003ooooooooo
o`04ooooo`;o00000oooool2o`0000Wooooo0_l0000Cooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001?ooool5o`0000[o
oooo0_l0000;ooooo`Co00001?ooool01?m4A4CogMgMooooool00004ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`02o`0001_ooooo0_l0000?ooooo`05ogMgMolb<S;o
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
0Oooool002Wooooo00?o0000ooooooooool05Oooool2o`000003ooooool0003o000000kooooo0_l0
0005ooooo`;o000000?oooooo`000?ooool00_ooool2o`0000?ooooo00Co0000oooooooooooooooo
0ol000000ooooooo0000o`000009ooooo`;o00001Oooool2o`0001Wooooo00?oMgMgofIVI_ooool0
0ol00003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`04ooooo`;o
00003_ooool2o`0001;ooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000007ooooo`;o00002_ooool2o`0000Sooooo0_l00000
0ooooooo0000o`000002o`0000Cooooo00CogMgMoeEEEOoooooo00000oooool2o`0000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo01Cooooo0_l00003ooooo`;o0000
2_ooool3o`000004ob4Q8Ol0003o<S8bolc<c0;ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000000oooool002Wooooo00?o0000ooooooooool07oooool2o`00
017ooooo00Co0000oooooooooooooooo0_l00003ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool01?l@413oooooo`000?l00007ooooo`;o00008Oooool01Ol0003oooooo`000?l0003o410@00?o
oooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01Cooooo0_l00006oooo
o`;o00002oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool0
1?l@413oooooooooooooool2o`0001Oooooo0_l00003ooooo`;o00002_ooool00omgMgOoc<c<o`00
0003ooooo`;o00000oooool01?l@413oooooooooooooool2o`0000;ooooo00?o410@ooooooooool0
2oooool2o`0000Oooooo0_l0000?ooooo`?o00001_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@4003ooooo`00:Oooool00ol0003oooooooooo`0Oooooo`;o
00004Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01_mg
MgOoV9RHoooooonHV9SoMgMgooooo`;o00001oooool2o`0000kooooo0_l0000=ooooo`05o`000?nj
^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0:ooooo`;o00004?ooool4o`0000Sooooo00Co410@oiRHV?oooooo^[Zj0_l00002
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01?mgMgOoV9RHoooooonHV9P2o`0001Oooooo
0_l0000?ooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`;o
000000?ooooooiRHV?mgMgL03Oooool2o`0001[ooooo00?o0000ooooooooool01?ooool00omgMgOo
V9RHooooo`02o`0000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool00ol0003o
ooooooooo`0=ooooo`;o00008Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00[ooooo0_l0000>ooooo`;o00003Oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Cok^k^oc8b<_l0003o<S8b0_l00002ooooo`?o0000
00?o<S8bonk^k_ooool02Oooool3o`0000oooooo0_l0000:ooooo`04ojVYZOl@413o0000oa0@40?o
000000Koooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`03onk^k_lb<S;o000000;o00003?ooool2
o`0001cooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0Yooooo`Co00000oooool00oo^k^ko<S8bo`000002o`0000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool2o`000003ooooool0003o000000_ooooo
0_l0001Zooooo`?o000000?oooooo`000?l000003Oooool3o`0001Cooooo0_l0000:ooooo`;o0000
3?ooool2o`0000cooooo0_l0000Aooooo`;o0000G?ooool002Wooooo00?o0000ooooooooool00_l0
0010ooooo`;o0000=_ooool2o`0000oooooo0_l0000@ooooo`;o00000oooool3o`0003Wooooo0_l0
001Looooo`00:Oooool00ol0003oooooooooo`12ooooo`;o0000Aoooool2o`00013ooooo0_l00003
ooooo`;o00005oooool2o`0003cooooo0_l000000ooooooo0000o`00000>ooooo`;o0000;_ooool0
02Wooooo00?o0000ooooooooool0:Oooool2o`00093ooooo0_l0000booooo`;o00002?ooool2o`00
0003ooooool0003o000000kooooo0_l00006ooooo`Co00009?ooool002Wooooo00?o0000oooooooo
ool09_ooool2o`000003ooooool0003o0000047ooooo0_l0000Xooooo`;o00003oooool2o`0002Co
oooo0_l00005ooooo`;o00006Oooool2o`0001kooooo0_l00003ooooo`Co00009?ooool0027ooooo
ool00014o`0000Cooooo000Yooooo`;o00000_ooool3o`0000Gooooo00?o0000ooooooooool02_oo
ool01?l0003oooooo`000?l00008ooooo`03o`000?oooooooooo00;o000000Coooooo`000?l0003o
oooo0_l000000ooooooo0000ooooo`03ooooo`;o00001Oooool00ol0003oooooooooo`08ooooo`?o
00002Oooool5o`0000Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02o`0000Oo
oooo0_l000000ooooooo0000o`000004ooooo`;o00000_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo0_l00005ooooo`;o00000oooool00ol0003oooooooooo`0:ooooo`04
o`000?ooooooooooooooo`;o00001_ooool00ol0003oooooooooo`09ooooo`;o000000?oooooo`00
0?l000001oooool5o`0000Sooooo00?o0000ooooooooool02Oooool2o`0000Kooooo1_l00002oooo
o`;o00001_ooool00ol0003oooooooooo`0:ooooo`00:Oooool2o`0001Wooooo1?l00007ooooo`Co
00001?ooool2o`0000gooooo00?o0000ooooooooool00oooool2o`0000?ooooo0_l00002ooooo`?o
0000;?ooool00ol0003oooooooooo`08ooooo`;o00005oooool2o`0001Oooooo00?o0000oooooooo
ool02Oooool2o`0000Gooooo0_l00007ooooo`;o00002oooool4o`0000[ooooo0ol00003ooooo`;o
000000?oooooo`000?l000002?ooool2o`0000cooooo0_l00008ooooo`;o00002?ooool2o`0000Co
oooo0_l00006ooooo`03o`000?oooooooooo00[ooooo000Yooooo`03o`000?oooooooooo01[ooooo
0_l00007ooooo`Ko00005oooool2o`0000Oooooo0ol0000Rooooo`;o00001oooool2o`0000[ooooo
0_l0000^ooooo`;o00003?ooool2o`0000Cooooo0_l00008ooooo`;o00002Oooool2o`0000;ooooo
0_l0000:ooooo`?o00003_ooool2o`0000kooooo0_l0000]ooooo`00:Oooool00ol0003ooooooooo
o`0Wooooo`;o0000>_ooool2o`0000Wooooo0_l00007ooooo`;o0000>_ooool2o`0001;ooooo0_l0
000@ooooo`;o000000?oooooo`000?l000003_ooool2o`0000oooooo0_l0000mooooo`00:Oooool2
o`0000Oooooo0_l00007ooooo`;o0000>oooool2o`0000Sooooo0_l0000;ooooo`;o00003Oooool2
o`0001kooooo0_l0000>ooooo`;o000000?oooooo`000?l00000<_ooool2o`00037ooooo0_l0000L
ooooo`?o00003oooool002Wooooo00?o0000ooooooooool01_ooool2o`0000Oooooo0_l0000Aoooo
o`;o00006_ooool2o`0000cooooo0_l00008ooooo`;o00003_ooool4o`0000Sooooo0_l0000=oooo
o`;o00003oooool2o`0000Kooooo0_l00006ooooo`;o000000?oooooo`000?l000009?ooool2o`00
00Oooooo0_l0000=ooooo`;o00003Oooool2o`0000kooooo0_l00005ooooo`;o000000?oooooo`00
0?l000002_ooool2o`00013ooooo0ol0000?ooooo`00:Oooool00ol0003oooooooooo`0Rooooo`;o
00006_ooool2o`0001[ooooo0_l0000:ooooo`Co00005oooool2o`0000Cooooo0_l0000;ooooo`;o
00001?ooool2o`0000kooooo0_l0000Oooooo`;o00001oooool2o`0000gooooo0_l00002ooooo`;o
00002Oooool4o`0000;ooooo0_l00008ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o
00008_ooool002Wooooo00?o0000ooooooooool0<Oooool2o`0000?ooooo0_l00002ooooo`;o0000
7_ooool3o`0000Wooooo0ol0000Iooooo`;o00000oooool4o`0000Wooooo0_l0000Dooooo`;o0000
2_ooool2o`00017ooooo0_l0000Looooo`;o00001Oooool2o`0000Cooooo0_l00002ooooo`;o0000
0_ooool2o`0001?ooooo0_l0000Yooooo`00:Oooool00ol0003oooooooooo`0Zooooo`;o00001Ooo
ool2o`0000;ooooo0ol00002ooooo`;o00000oooool2o`0001[ooooo0_l00009ooooo`?o00006Ooo
ool2o`000003ooooool0003o000000;ooooo0_l00009ooooo`;o00008?ooool4o`0000oooooo0_l0
000Sooooo`;o00003?ooool2o`0001oooooo0_l00003ooooo`;o00006?ooool002Wooooo0_l0000<
ooooo`;o00002_ooool2o`00017ooooo0_l00009ooooo`;o00002?ooool2o`0000?ooooo0_l0000B
ooooo`;o0000:oooool2o`0000gooooo0_l0000Gooooo`;o00002Oooool2o`0001Wooooo0_l0000O
ooooo`;o00002?ooool2o`0000Cooooo0_l000000ooooooo0000o`000006ooooo`;o00003?ooool2
o`0000?ooooo0_l0000Hooooo`00:Oooool00ol0003oooooooooo`02ooooo`;o00001oooool2o`00
00?ooooo0_l00005ooooo`;o00005?ooool2o`0000oooooo0_l00004ooooo`;o00004_ooool2o`00
027ooooo0_l00004ooooo`;o00003?ooool2o`0001[ooooo1?l0000Tooooo`;o00000oooool2o`00
01[ooooo0_l00003ooooo`;o00000oooool2o`0000Cooooo0_l000000ooooooo0000o`000006oooo
o`;o000000?oooooo`000?l00000:?ooool002Wooooo00?o0000ooooooooool00_ooool2o`0000Go
oooo0_l00005ooooo`;o00000_ooool2o`0001Oooooo0_l0000?ooooo`;o000000?oooooo`000?l0
00003?ooool4o`00017ooooo0_l00007ooooo`;o000000Coooooo`000?l0003o00002?ooool2o`00
00;ooooo1?l0000<ooooo`;o00005_ooool2o`0000;ooooo0_l0000<ooooo`;o00007Oooool2o`00
01oooooo0_l0000Gooooo`;o0000:?ooool002Wooooo00?o0000ooooooooool02Oooool2o`0000Ko
oooo0_l000000ooooooo0000o`00000Aooooo`;o00000oooool2o`0001?ooooo0_l0000<ooooo`Co
00004Oooool2o`0000Oooooo0_l000001?oooooo0000o`000?l0000<ooooo`;o00003oooool2o`00
01Gooooo0_l0000>ooooo`Co00007Oooool2o`0002gooooo0_l0000Eooooo`Co00000oooool2o`00
01Gooooo000Yooooo`03o`000?oooooooooo00Oooooo1?l000000ooooooo0000o`000003ooooo`;o
00005?ooool2o`0000?ooooo0_l00011ooooo`;o00007oooool2o`0002Gooooo0_l0000Oooooo`;o
0000;Oooool2o`0000Gooooo0_l0000>ooooo`Co00000oooool2o`0000Kooooo0_l0000=ooooo`00
:Oooool2o`0000Sooooo0ol00002ooooo`?o00009Oooool2o`0000Kooooo0_l0000Fooooo`;o0000
6Oooool4o`0009_ooooo0_l0000Hooooo`?o00000_ooool2o`0000gooooo000Yooooo`03o`000?oo
oooooooo00Cooooo0_l00007ooooo`;o00001_ooool2o`0000Cooooo0_l0000Gooooo`;o00001_oo
ool3o`0000kooooo0_l00005ooooo`;o00002oooool2o`0000kooooo0_l00004ooooo`;o0000[ooo
ool3o`0000?ooooo0_l0000<ooooo`00:Oooool00ol0003oooooooooo`04ooooo`;o00003oooool2
o`0000Cooooo0_l0000Pooooo`;o00001oooool2o`0000Gooooo0_l0000@ooooo`Co00005?ooool2
o`0000Wooooo0_l0001:ooooo`;o0000G_ooool2o`0000cooooo000Yooooo`03o`000?oooooooooo
01Oooooo0_l0000Looooo`;o00003oooool2o`0001Oooooo0_l0000Qooooo`;o00007oooool2o`00
01?ooooo0_l00006ooooo`;o00003?ooool2o`0001Cooooo0_l00009ooooo`;o00004oooool3o`00
01Gooooo0_l0000Nooooo`00:Oooool00ol0003oooooooooo`0>ooooo`;o00001oooool2o`0001co
oooo0_l0000[ooooo`;o00002_ooool2o`0001oooooo0_l00009ooooo`?o00001_ooool2o`0001?o
oooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000_ooooo0_l000000ooooooo
0000o`00000;ooooo`;o00000_ooool2o`000003ooooool0003o000000Wooooo0_l0000Cooooo`?o
00005Oooool2o`0000Sooooo0_l0000Dooooo`00:Oooool2o`0000gooooo1?l0001Booooo`;o0000
2_ooool2o`0001oooooo0_l00009ooooo`?o00007_ooool4o`0000kooooo0_l000000ooooooo0000
o`00000;ooooo`;o00000_ooool2o`0003oooooo0_l00002ooooo`;o00005?ooool002Wooooo00?o
0000ooooooooool03?ooool2o`0000Sooooo0_l0000`ooooo`;o000000?oooooo`000?l000007_oo
ool2o`0002?ooooo0_l0000Booooo`;o0000H?ooool2o`0000Sooooo0_l0000@ooooo`;o00006?oo
ool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01Kooooo0_l00006ooooo`;o0000
4?ooool2o`0001Kooooo0_l000000ooooooo0000o`00000Nooooo`;o00008oooool2o`0001;ooooo
0_l0000mooooo`;o00002oooool2o`0001Cooooo0_l00008ooooo`;o00006?ooool2o`00013ooooo
0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool07Oooool3o`00013o
oooo0_l0001fooooo`;o00006oooool2o`0001cooooo0_l0000;ooooo`;o0000<_ooool2o`0000Co
oooo0_l0000@ooooo`001_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^
k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01;ooooo1?l00007ooooo`;o
0000ROooool2o`00013ooooo0_l00009ooooo`;o0000>oooool2o`0000cooooo0_l0000Booooo`;o
00005_ooool000Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo00?oMgMgoc8b<_ooool01?ooool3o`0001;ooooo1?l00004ooooo`;o00001oooool2o`0000Go
oooo0_l0000;ooooo`?o00002Oooool2o`0003[ooooo0_l0000Yooooo`;o00003_ooool2o`0004Ko
oooo0_l0000<ooooo`;o0000:_ooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo
01[ooooo1?l00005ooooo`;o00001Oooool2o`0000_ooooo0ol00009ooooo`;o0000>_ooool2o`00
01Kooooo0_l0000Aooooo`;o00004?ooool2o`0001;ooooo0_l0001Zooooo`001_ooool01Ol@413o
oooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo01cooooo0_l0001iooooo`;o00008oooool2o`0001;ooooo0_l00013oooo
o`;o00000oooool2o`00023ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:
ooooo`;o0000A?ooool2o`0001Oooooo0_l0000Nooooo`;o00003?ooool2o`00037ooooo0_l00019
ooooo`;o00000oooool2o`00023ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o00002oooool2o`0000?ooooo0_l0
000Mooooo`;o00007Oooool2o`000003ooooool0003o000000_ooooo0_l0000:ooooo`;o00002_oo
ool2o`0001;ooooo0_l0000oooooo`Co00006?ooool3o`0002_ooooo0_l0000Eooooo`;o00003ooo
ool002Wooooo0_l0000;ooooo`;o00000oooool2o`0001gooooo0_l0000Mooooo`;o00003_ooool2
o`0001Kooooo0_l0000Vooooo`;o00009_ooool2o`0000Gooooo0_l00005ooooo`;o00004Oooool3
o`00027ooooo0_l00008ooooo`;o00005Oooool2o`0000oooooo000Yooooo`03o`000?oooooooooo
00[ooooo0_l0000Qooooo`;o0000<Oooool2o`0003_ooooo0_l0000Vooooo`;o00003?ooool2o`00
01Kooooo0_l0000Mooooo`;o0000<?ooool002Wooooo00?o0000ooooooooool0;Oooool2o`00037o
oooo0_l00029ooooo`;o00006?ooool2o`0003Gooooo000Yooooo`03o`000?oooooooooo0>Sooooo
0_l0000Kooooo`;o00009Oooool2o`0000kooooo000Yooooo`03o`000?oooooooooo01cooooo0_l0
000]ooooo`;o0000>?ooool2o`0005kooooo0_l000000ooooooo0000o`00000^ooooo`;o00004_oo
ool2o`0000kooooo000Yooooo`;o00007Oooool2o`0000;ooooo0_l0000Yooooo`;o00008_ooool2
o`0001Cooooo0_l0000Yooooo`Co0000<Oooool2o`00037ooooo0_l0000Rooooo`00:Oooool00ol0
003oooooooooo`0Pooooo`;o0000COooool2o`0003oooooo1?l00028ooooo`00:Oooool00ol0003o
ooooooooo`1/ooooo`;o00009oooool2o`0001[ooooo1?l0000=ooooo`;o00001Oooool2o`0002oo
oooo0_l0000Oooooo`;o00007oooool002Wooooo00?o0000ooooooooool0A_ooool2o`0001Cooooo
0_l0000>ooooo`;o00009oooool2o`0000;ooooo0_l0000;ooooo`;o00002oooool2o`0000gooooo
0_l00005ooooo`;o00002oooool2o`00017ooooo0_l0000?ooooo`;o00007oooool2o`0001oooooo
000Yooooo`03o`000?oooooooooo01?ooooo0_l0000aooooo`;o00005?ooool5o`0000Cooooo0_l0
000booooo`;o00002oooool2o`0000?ooooo0_l0000Yooooo`;o00003?ooool4o`000003ooooool0
003o0000057ooooo000Yooooo`;o00005?ooool2o`0003_ooooo0_l0000<ooooo`?o00001?ooool2
o`0004Cooooo0_l0000gooooo`Co0000E?ooool002Wooooo00?o0000ooooooooool0D?ooool2o`00
0>[ooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
Eoooool2o`0001Wooooo0_l0001:ooooo`;o0000O?ooool002Wooooo00?o0000ooooooooool0Eooo
ool2o`0001Wooooo0_l0000Jooooo`;o0000;_ooool2o`0007cooooo000Yooooo`;o0000F_ooool2
o`0003?ooooo0_l0000Tooooo`;o0000B_ooool2o`0003[ooooo000Yooooo`03o`000?oooooooooo
04Oooooo0_l0000@ooooo`;o0000FOooool2o`0002Gooooo0_l0000Sooooo`;o0000>_ooool000ko
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool0Aoooool2o`0002_ooooo0_l0001=ooooo`;o00005_ooool2
o`0001Cooooo0_l00019ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0Doooool2o`0001oooooo0_l0000D
ooooo`;o0000=oooool2o`00013ooooo0_l0000Jooooo`;o0000BOooool000kooooo00Go410@oooo
oooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0000Rooooo`;o0000;oooool2
o`0003Gooooo0_l00005ooooo`;o0000@_ooool2o`0006Gooooo000>ooooo`05o`000?oooooooooo
ooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02;ooooo0_l0001]
ooooo`;o00008oooool2o`0006Sooooo0_l0000Jooooo`003_ooool01Ol0003ooooooooooooooooo
000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;Kooooo0_l0
001Xooooo`;o00006_ooool000kooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo000>
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0003oooooockooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVY
oeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolmooooo`001_ooool01Ol0
003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00000>
ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oo
oooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmg
MgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool001oooooo1?l000000ol@413oooooooooo`03oooo
o`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo0ol0003oooooocgooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool001oooooo00?oEEEEofIVI_l00000oooooom7ooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .23915 Mdot
.02762 .35736 Mdot
.02952 .30016 Mdot
.03143 .31491 Mdot
.03333 .30933 Mdot
.03524 .36901 Mdot
.03714 .31617 Mdot
.03905 .29392 Mdot
.04095 .41637 Mdot
.04286 .34712 Mdot
.04476 .28679 Mdot
.04667 .24497 Mdot
.04857 .40849 Mdot
.05048 .31792 Mdot
.05238 .23887 Mdot
.05429 .2672 Mdot
.05619 .25194 Mdot
.0581 .40649 Mdot
.06 .34846 Mdot
.0619 .2484 Mdot
.06381 .40383 Mdot
.06571 .39459 Mdot
.06762 .40147 Mdot
.06952 .40116 Mdot
.07143 .24312 Mdot
.07333 .34617 Mdot
.07524 .25581 Mdot
.07714 .3396 Mdot
.07905 .27287 Mdot
.08095 .36094 Mdot
.08286 .3928 Mdot
.08476 .41673 Mdot
.08667 .33812 Mdot
.08857 .2739 Mdot
.09048 .35772 Mdot
.09238 .24182 Mdot
.09429 .41349 Mdot
.09619 .30061 Mdot
.0981 .29974 Mdot
.1 .23142 Mdot
.1019 .24726 Mdot
.10381 .32395 Mdot
.10571 .38837 Mdot
.10762 .25085 Mdot
.10952 .24517 Mdot
.11143 .24987 Mdot
.11333 .33016 Mdot
.11524 .43459 Mdot
.11714 .36841 Mdot
.11905 .26049 Mdot
.12095 .43493 Mdot
.12286 .35269 Mdot
.12476 .29839 Mdot
.12667 .37831 Mdot
.12857 .38492 Mdot
.13048 .38606 Mdot
.13238 .28595 Mdot
.13429 .25231 Mdot
.13619 .43561 Mdot
.1381 .25596 Mdot
.14 .25667 Mdot
.1419 .42833 Mdot
.14381 .30443 Mdot
.14571 .26574 Mdot
.14762 .34702 Mdot
.14952 .40251 Mdot
.15143 .34794 Mdot
.15333 .25808 Mdot
.15524 .30853 Mdot
.15714 .3916 Mdot
.15905 .244 Mdot
.16095 .27447 Mdot
.16286 .34569 Mdot
.16476 .34216 Mdot
.16667 .30407 Mdot
.16857 .28712 Mdot
.17048 .29795 Mdot
.17238 .28913 Mdot
.17429 .3338 Mdot
.17619 .37091 Mdot
.1781 .33784 Mdot
.18 .35423 Mdot
.1819 .33026 Mdot
.18381 .33378 Mdot
.18571 .3418 Mdot
.18762 .27978 Mdot
.18952 .29999 Mdot
.19143 .27123 Mdot
.19333 .2699 Mdot
.19524 .25904 Mdot
.19714 .24658 Mdot
.19905 .44507 Mdot
.20095 .31933 Mdot
.20286 .25337 Mdot
.20476 .30082 Mdot
.20667 .45551 Mdot
.20857 .32304 Mdot
.21048 .43298 Mdot
.21238 .28165 Mdot
.21429 .26221 Mdot
.21619 .24878 Mdot
.2181 .3031 Mdot
.22 .24899 Mdot
.2219 .26896 Mdot
.22381 .36056 Mdot
.22571 .28979 Mdot
.22762 .25002 Mdot
.22952 .35825 Mdot
.23143 .32079 Mdot
.23333 .38995 Mdot
.23524 .33724 Mdot
.23714 .31905 Mdot
.23905 .41884 Mdot
.24095 .23285 Mdot
.24286 .26477 Mdot
.24476 .27306 Mdot
.24667 .27222 Mdot
.24857 .38735 Mdot
.25048 .40217 Mdot
.25238 .40491 Mdot
.25429 .40852 Mdot
.25619 .40131 Mdot
.2581 .40764 Mdot
.26 .28153 Mdot
.2619 .38961 Mdot
.26381 .29772 Mdot
.26571 .23309 Mdot
.26762 .4655 Mdot
.26952 .30224 Mdot
.27143 .28561 Mdot
.27333 .40304 Mdot
.27524 .27277 Mdot
.27714 .2285 Mdot
.27905 .36267 Mdot
.28095 .38756 Mdot
.28286 .3162 Mdot
.28476 .40918 Mdot
.28667 .24945 Mdot
.28857 .34649 Mdot
.29048 .31324 Mdot
.29238 .23355 Mdot
.29429 .45521 Mdot
.29619 .3399 Mdot
.2981 .3298 Mdot
.3 .25116 Mdot
.3019 .23508 Mdot
.30381 .36142 Mdot
.30571 .34925 Mdot
.30762 .35676 Mdot
.30952 .25832 Mdot
.31143 .38627 Mdot
.31333 .31469 Mdot
.31524 .26935 Mdot
.31714 .39959 Mdot
.31905 .28376 Mdot
.32095 .33346 Mdot
.32286 .39173 Mdot
.32476 .32254 Mdot
.32667 .38859 Mdot
.32857 .41234 Mdot
.33048 .39617 Mdot
.33238 .37027 Mdot
.33429 .3363 Mdot
.33619 .24585 Mdot
.3381 .2739 Mdot
.34 .38625 Mdot
.3419 .24246 Mdot
.34381 .36774 Mdot
.34571 .34353 Mdot
.34762 .29901 Mdot
.34952 .39534 Mdot
.35143 .23764 Mdot
.35333 .32484 Mdot
.35524 .27258 Mdot
.35714 .30233 Mdot
.35905 .35843 Mdot
.36095 .33618 Mdot
.36286 .45925 Mdot
.36476 .33939 Mdot
.36667 .28379 Mdot
.36857 .28057 Mdot
.37048 .37764 Mdot
.37238 .22488 Mdot
.37429 .32372 Mdot
.37619 .25669 Mdot
.3781 .32836 Mdot
.38 .42003 Mdot
.3819 .4657 Mdot
.38381 .41905 Mdot
.38571 .23816 Mdot
.38762 .38913 Mdot
.38952 .37554 Mdot
.39143 .23516 Mdot
.39333 .26554 Mdot
.39524 .41453 Mdot
.39714 .32081 Mdot
.39905 .30136 Mdot
.40095 .23786 Mdot
.40286 .26256 Mdot
.40476 .4199 Mdot
.40667 .28604 Mdot
.40857 .31673 Mdot
.41048 .31301 Mdot
.41238 .26908 Mdot
.41429 .31997 Mdot
.41619 .40484 Mdot
.4181 .25621 Mdot
.42 .31619 Mdot
.4219 .35717 Mdot
.42381 .32043 Mdot
.42571 .33076 Mdot
.42762 .27663 Mdot
.42952 .41185 Mdot
.43143 .28182 Mdot
.43333 .34213 Mdot
.43524 .30357 Mdot
.43714 .2454 Mdot
.43905 .2656 Mdot
.44095 .24887 Mdot
.44286 .33115 Mdot
.44476 .27751 Mdot
.44667 .24208 Mdot
.44857 .26719 Mdot
.45048 .43456 Mdot
.45238 .35353 Mdot
.45429 .31734 Mdot
.45619 .2765 Mdot
.4581 .34283 Mdot
.46 .34624 Mdot
.4619 .32289 Mdot
.46381 .23698 Mdot
.46571 .41175 Mdot
.46762 .25762 Mdot
.46952 .27256 Mdot
.47143 .40234 Mdot
.47333 .34925 Mdot
.47524 .25545 Mdot
.47714 .38799 Mdot
.47905 .28665 Mdot
.48095 .28578 Mdot
.48286 .40909 Mdot
.48476 .26402 Mdot
.48667 .4274 Mdot
.48857 .38244 Mdot
.49048 .30756 Mdot
.49238 .24388 Mdot
.49429 .41463 Mdot
.49619 .28649 Mdot
.4981 .38062 Mdot
.5 .30691 Mdot
.5019 .2436 Mdot
.50381 .30988 Mdot
.50571 .28988 Mdot
.50762 .2759 Mdot
.50952 .26757 Mdot
.51143 .39148 Mdot
.51333 .3467 Mdot
.51524 .26632 Mdot
.51714 .39036 Mdot
.51905 .29518 Mdot
.52095 .30059 Mdot
.52286 .43736 Mdot
.52476 .36008 Mdot
.52667 .25566 Mdot
.52857 .30158 Mdot
.53048 .26605 Mdot
.53238 .32312 Mdot
.53429 .24239 Mdot
.53619 .32277 Mdot
.5381 .38095 Mdot
.54 .23347 Mdot
.5419 .36142 Mdot
.54381 .23409 Mdot
.54571 .38814 Mdot
.54762 .34759 Mdot
.54952 .36916 Mdot
.55143 .39004 Mdot
.55333 .33114 Mdot
.55524 .35606 Mdot
.55714 .43258 Mdot
.55905 .28181 Mdot
.56095 .34126 Mdot
.56286 .30067 Mdot
.56476 .30171 Mdot
.56667 .32834 Mdot
.56857 .4113 Mdot
.57048 .26151 Mdot
.57238 .35933 Mdot
.57429 .31035 Mdot
.57619 .34747 Mdot
.5781 .24304 Mdot
.58 .25066 Mdot
.5819 .35347 Mdot
.58381 .46552 Mdot
.58571 .43274 Mdot
.58762 .25703 Mdot
.58952 .43155 Mdot
.59143 .29019 Mdot
.59333 .43241 Mdot
.59524 .39719 Mdot
.59714 .26425 Mdot
.59905 .24529 Mdot
.60095 .38546 Mdot
.60286 .37189 Mdot
.60476 .38964 Mdot
.60667 .2825 Mdot
.60857 .41513 Mdot
.61048 .23849 Mdot
.61238 .32061 Mdot
.61429 .43291 Mdot
.61619 .35398 Mdot
.6181 .32535 Mdot
.62 .41055 Mdot
.6219 .24601 Mdot
.62381 .40977 Mdot
.62571 .37338 Mdot
.62762 .26746 Mdot
.62952 .26215 Mdot
.63143 .3004 Mdot
.63333 .33185 Mdot
.63524 .26929 Mdot
.63714 .22514 Mdot
.63905 .34374 Mdot
.64095 .46545 Mdot
.64286 .2681 Mdot
.64476 .35953 Mdot
.64667 .3393 Mdot
.64857 .32926 Mdot
.65048 .33876 Mdot
.65238 .32169 Mdot
.65429 .30476 Mdot
.65619 .2449 Mdot
.6581 .25962 Mdot
.66 .38556 Mdot
.6619 .2991 Mdot
.66381 .40708 Mdot
.66571 .29458 Mdot
.66762 .26864 Mdot
.66952 .35018 Mdot
.67143 .37374 Mdot
.67333 .38648 Mdot
.67524 .37006 Mdot
.67714 .32828 Mdot
.67905 .32648 Mdot
.68095 .35122 Mdot
.68286 .3363 Mdot
.68476 .26578 Mdot
.68667 .362 Mdot
.68857 .26071 Mdot
.69048 .24267 Mdot
.69238 .37118 Mdot
.69429 .33724 Mdot
.69619 .24975 Mdot
.6981 .4548 Mdot
.7 .24769 Mdot
.7019 .43309 Mdot
.70381 .23622 Mdot
.70571 .37325 Mdot
.70762 .27473 Mdot
.70952 .23509 Mdot
.71143 .33722 Mdot
.71333 .24883 Mdot
.71524 .46889 Mdot
.71714 .30011 Mdot
.71905 .23015 Mdot
.72095 .22599 Mdot
.72286 .25817 Mdot
.72476 .27168 Mdot
.72667 .3587 Mdot
.72857 .23284 Mdot
.73048 .29503 Mdot
.73238 .27649 Mdot
.73429 .36963 Mdot
.73619 .34794 Mdot
.7381 .35372 Mdot
.74 .24432 Mdot
.7419 .43037 Mdot
.74381 .28277 Mdot
.74571 .42359 Mdot
.74762 .36225 Mdot
.74952 .39862 Mdot
.75143 .42914 Mdot
.75333 .40004 Mdot
.75524 .23013 Mdot
.75714 .2992 Mdot
.75905 .41415 Mdot
.76095 .32155 Mdot
.76286 .29507 Mdot
.76476 .31105 Mdot
.76667 .27595 Mdot
.76857 .29975 Mdot
.77048 .22532 Mdot
.77238 .38969 Mdot
.77429 .32301 Mdot
.77619 .34582 Mdot
.7781 .32091 Mdot
.78 .25359 Mdot
.7819 .43253 Mdot
.78381 .34313 Mdot
.78571 .40916 Mdot
.78762 .22511 Mdot
.78952 .25125 Mdot
.79143 .34679 Mdot
.79333 .26351 Mdot
.79524 .35877 Mdot
.79714 .35651 Mdot
.79905 .30359 Mdot
.80095 .26905 Mdot
.80286 .24819 Mdot
.80476 .25704 Mdot
.80667 .33421 Mdot
.80857 .2529 Mdot
.81048 .3012 Mdot
.81238 .34282 Mdot
.81429 .25702 Mdot
.81619 .27438 Mdot
.8181 .33816 Mdot
.82 .27244 Mdot
.8219 .27317 Mdot
.82381 .27524 Mdot
.82571 .26182 Mdot
.82762 .25494 Mdot
.82952 .30869 Mdot
.83143 .39391 Mdot
.83333 .31579 Mdot
.83524 .2978 Mdot
.83714 .36534 Mdot
.83905 .25005 Mdot
.84095 .30992 Mdot
.84286 .35596 Mdot
.84476 .28274 Mdot
.84667 .31861 Mdot
.84857 .44636 Mdot
.85048 .29733 Mdot
.85238 .22392 Mdot
.85429 .26275 Mdot
.85619 .2909 Mdot
.8581 .40923 Mdot
.86 .22974 Mdot
.8619 .28025 Mdot
.86381 .37007 Mdot
.86571 .31921 Mdot
.86762 .33661 Mdot
.86952 .32623 Mdot
.87143 .35661 Mdot
.87333 .30417 Mdot
.87524 .3702 Mdot
.87714 .43232 Mdot
.87905 .33199 Mdot
.88095 .36549 Mdot
.88286 .32138 Mdot
.88476 .28491 Mdot
.88667 .27037 Mdot
.88857 .33966 Mdot
.89048 .29319 Mdot
.89238 .26419 Mdot
.89429 .32264 Mdot
.89619 .33841 Mdot
.8981 .24969 Mdot
.9 .23237 Mdot
.9019 .36799 Mdot
.90381 .24494 Mdot
.90571 .46667 Mdot
.90762 .34729 Mdot
.90952 .25521 Mdot
.91143 .28988 Mdot
.91333 .32251 Mdot
.91524 .43292 Mdot
.91714 .35877 Mdot
.91905 .2686 Mdot
.92095 .24107 Mdot
.92286 .25019 Mdot
.92476 .35244 Mdot
.92667 .25007 Mdot
.92857 .27364 Mdot
.93048 .43093 Mdot
.93238 .38739 Mdot
.93429 .2835 Mdot
.93619 .38557 Mdot
.9381 .37118 Mdot
.94 .27004 Mdot
.9419 .26321 Mdot
.94381 .37673 Mdot
.94571 .38879 Mdot
.94762 .29564 Mdot
.94952 .33403 Mdot
.95143 .40093 Mdot
.95333 .31411 Mdot
.95524 .25072 Mdot
.95714 .32254 Mdot
.95905 .33634 Mdot
.96095 .29865 Mdot
.96286 .25379 Mdot
.96476 .30452 Mdot
.96667 .3538 Mdot
.96857 .43336 Mdot
.97048 .26734 Mdot
.97238 .31798 Mdot
.97429 .26089 Mdot
.97619 .2277 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo2?ooool2o`0003?ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0K?ooool2o`0005?ooooo0_l0000Iooooo`;o00003_ooool2o`0000Cooooo0_l0
000Cooooo`;o00009_ooool2o`0000_ooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1>ooooo`;o00007?ooool2o`0005?ooooo0_l0000Iooooo`;o00002Oooool2o`0000?ooooo0_l0
0004ooooo`;o00005Oooool2o`0002Cooooo0_l0000;ooooo`001_ooool01Ol0003ooooooooooooo
oooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o00005Ooo
ool2o`0002_ooooo0_l00006ooooo`;o00000_ooool2o`0000?ooooo0_l0001=ooooo`?o0000=ooo
ool2o`000003ooooool0003o000000Kooooo0_l0000Pooooo`;o00002oooool2o`0002Cooooo0006
ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Eooooo`;o0000:oooool2o`0000Kooooo
0_l00007ooooo`;o000000?oooooo`000?l000006_ooool2o`0001Kooooo0_l0000Fooooo`?o0000
<_ooool4o`0000Cooooo0_l0000eooooo`;o00009?ooool000Kooooo00Go410@oooooooooooooooo
oa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool2o`0000Kooooo
0_l0001?ooooo`;o00003_ooool2o`0000Wooooo0ol00002ooooo`;o00004_ooool2o`0002gooooo
0_l0000Looooo`Co0000HOooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`;o00001_ooool2o`0000Go
oooo0_l00004ooooo`;o0000Coooool2o`000003ooooool0003o000000Wooooo0_l00003ooooo`;o
00003?ooool2o`0001[ooooo0_l0000<ooooo`;o00002Oooool2o`0001Sooooo0_l00018ooooo`;o
00007Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool01?ooool2o`0000Kooooo0_l00004oooo
o`;o00001?ooool2o`0000kooooo0_l0000:ooooo`;o0000:oooool4o`0001cooooo0_l000000ooo
oooo0000o`00000=ooooo`;o000000?oooooo`000?l000002?ooool2o`0000cooooo0_l00005oooo
o`;o00001_ooool2o`0000Wooooo0_l00009ooooo`;o00003_ooool2o`0003;ooooo0_l00004oooo
o`;o00007Oooool002Wooooo0_l00005ooooo`;o00000oooool2o`0000[ooooo0_l000000ooooooo
0000o`00000>ooooo`;o00002_ooool2o`0000Cooooo0ol0000Dooooo`;o00003_ooool2o`0001ko
oooo0ol0000?ooooo`;o000000?oooooo`000?l000007Oooool2o`0000Kooooo0_l00009ooooo`;o
00003?ooool2o`0000;ooooo0_l00007ooooo`;o00004_ooool2o`0001cooooo1?l0000Sooooo`00
:Oooool00ol0003oooooooooo`07ooooo`Co00002_ooool5o`0000Kooooo0_l0000Hooooo`?o0000
00?oooooo`000?l000004Oooool2o`0000;ooooo0_l0000[ooooo`;o0000:oooool2o`0002?ooooo
1?l00002ooooo`;o00005_ooool2o`0000?ooooo0_l00009ooooo`;o00004Oooool2o`0000Kooooo
1?l00007ooooo`;o00004_ooool002Wooooo00?o0000ooooooooool01oooool2o`0000Cooooo0_l0
0008ooooo`?o00001_ooool2o`0001Cooooo0_l00006ooooo`;o00005Oooool2o`0003Kooooo0_l0
000?ooooo`;o00003oooool2o`0002?ooooo0_l0000Iooooo`;o000000?oooooo`000?l000001Ooo
ool2o`0000Cooooo0_l000000ooooooo0000o`00000Eooooo`;o00000_ooool4o`0000Oooooo1?l0
000@ooooo`00:Oooool00ol0003oooooooooo`0=ooooo`;o00004_ooool3o`0000;ooooo0_l0000;
ooooo`;o000000?oooooo`000?l000008?ooool2o`0001Cooooo0_l0000;ooooo`;o00003_ooool4
o`0000oooooo0_l0000Booooo`;o0000:Oooool2o`00013ooooo0_l00006ooooo`Go00000oooool2
o`0001Sooooo0_l0000?ooooo`;o00004?ooool002Wooooo00?o0000ooooooooool06oooool2o`00
00Cooooo0ol00002ooooo`;o00002oooool2o`0002?ooooo0_l0000Dooooo`;o00002oooool2o`00
00kooooo0_l0000Oooooo`;o00001?ooool2o`0000_ooooo0_l00007ooooo`;o00002?ooool2o`00
00Wooooo0_l0000Hooooo`;o000000?oooooo`000?l000000_ooool2o`0002kooooo0_l0000<oooo
o`00:Oooool2o`0001cooooo0_l0000Mooooo`;o00001oooool2o`00037ooooo0_l0000Hooooo`;o
00006_ooool2o`0000Oooooo0_l00008ooooo`;o00001oooool2o`0000Sooooo0_l0000Pooooo`;o
00002?ooool2o`0000Oooooo0_l0000;ooooo`;o00003Oooool2o`0000Wooooo0_l0000<ooooo`00
:Oooool00ol0003oooooooooo`06ooooo`;o00006oooool2o`0001Gooooo0_l00007ooooo`;o0000
;_ooool2o`000003ooooool0003o000000[ooooo0_l000000ooooooo0000o`000009ooooo`;o0000
1_ooool4o`0000?ooooo0_l0000Dooooo`;o00001oooool2o`0000?ooooo0_l0000<ooooo`;o0000
8Oooool2o`00017ooooo0_l0000;ooooo`;o00003Oooool2o`0000Sooooo0_l0000=ooooo`00:Ooo
ool00ol0003oooooooooo`06ooooo`;o00006oooool2o`0000_ooooo1Ol00002ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00_l000001_ooooook^k^oc8b<_l0003o<S8bonk^kQKooooo0_l0000Aoooo
o`Go000000Ooooooo`000?l0003ok^k^oc8b<_l0003o<S8b00;o00000_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00;o000000?oooooo`000?l000004Oooool4o`0000?ooooo0_l00009ooooo`05oiRH
V?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Cok^k^oc8b
<_l0003o<S8b0_l000000ooooooo0000o`000002o`0000Kooooo0_l00004ooooo`;o00005_ooool2
o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo0_l000001?lb<S;o
0000oc8b<_o^k^hFooooo`;o00002?ooool2o`0000Gooooo0_l000001Om4A4Co0000o`000?lb<S;o
gMgM00;ooooo00Gok^k^o`000?l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool002Wooooo00?o0000ooooooooool03_ooool2o`000003ooooool0003o000001Gooooo0_l0
0008ooooo`?o00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00;o000000GoooooogMgMonHV9So
oooooiRHV003o`0000Oooooo0_l0000;ooooo`;o00001Oooool2o`0000Cooooo0_l00004ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01?mgMgOoV9RHoooooonHV9P2o`0000;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0:ooooo`;o00007?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool2o`00
00Sooooo0_l0000Aooooo`;o00002_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00_ooool2o`000003oiRHV?ooooooV9RH00Co00004oooool2o`0000Sooooo0_l00000
0ooooooo0000o`000002ooooo`;o00000oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wooooo00?o0000oooooooo
ool03_ooool2o`000003ooooool0003o000001Gooooo0_l00008ooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@4003ooooo`04oa0@4?ooooooooooooooo`?o00001oooool2
o`0001;ooooo0_l00004ooooo`;o00001Oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?oooooo
ooooooooool@41000oooool01Ol@413o0000o`000?oooooo410@00;ooooo0_l000000ooooooo0000
o`000003ooooo`;o00002_ooool2o`0001Cooooo00Go0000oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Gooooo`;o00001?ooool4o`00
00Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41000oooool01?l@413ooooooooooooo
ool5o`0001oooooo0_l00008ooooo`04o`000?oooooooooooa0@40?ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`03oa0@4?oooooooooo007ooooo000Yooooo`;o0000<_ooool2o`0000Cooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000009oooool2o`00
00;ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000?ooooo0ol00000
1?oooooo0000ooooooooool2o`000003ooooool0003o000000oooooo0_l0000Cooooo`03ojVYZOl@
413ooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00006Oooool2o`0000Kooooo0_l00005ooooo`03odA4A?oMgMgooooo00?o00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`;o00002_ooool2
o`0001cooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`01ooooo`00:Oooool00ol0003oooooooooo`0aooooo`;o00001?oo
ool00ol0003oooooo`000002o`0000?ooooo00Go0000ooooooooooooooooo`000004ooooo`;o0000
4Oooool2o`0000kooooo0_l00003ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooo000000;o00009_ooool2o`0000;ooooo00?o410@o`000?nj
^[X00oooool01_l0003ooooooooooooooooo0000ooooo`?o00000oooool00ol0003oooooooooo`0S
ooooo`;o000000GoooooomgMgOmEEEGoooooo`000004ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000Sooooo0_l00004ooooo`;o00005Oooool2o`0000;o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo000Yooooo`03o`000?oooooooooo00?ooooo0_l0000J
ooooo`;o00004Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo0000o`000?l@41000ooo
ool01Ol@413ooooooooooooooooo410@00Cooooo0_l00002ooooo`;o00003Oooool2o`0000kooooo
0_l00004ooooo`06o`000?ooooooooooooooool@413ooooo0_l000001_l@413ooooooooooooooooo
410@ooooo`;o000000?o410@ooooooooool02oooool2o`0000?ooooo0_l0000Booooo`;o00000ooo
ool00onj^[[o8B4Qooooo`02ooooo`06oa0@4?ooooooooooooooool@413ooooo0_l000001Ol@413o
oooooooooooooooo410@02Gooooo0_l00002ooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooo
oooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?ooool2o`0000_ooooo0_l0
000>ooooo`;o00000_ooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100
0oooool01Ol@413ooooooooooooooooo410@00?ooooo000Yooooo`03o`000?oooooooooo00?ooooo
0_l0000Jooooo`;o00002_ooool3o`0000Cooooo00?o0000ooooooooool00_ooool01_mgMgOoV9RH
oooooonHV9SoMgMgooooo`;o000000GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`;o00007oooool0
1Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?l0003o0000ogMgM`03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03Oooool2o`0000?ooooo0_l000000ooooooo0000o`00000Aooooo`05
oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0Yooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05Oooool2o`0000Oooooo0_l00009ooooo`03
o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool002Wooooo00?o0000ooooooooool0:oooool3o`0000;ooooo00?oEEEEofIV
I_l000001?ooool01_o^k^ko<S8bo`000?lb<S;ok^k^ooooo`;o000000Gok^k^oc8b<_l0003o<S8b
onk^kP0Yooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Eooooo`;o00004Oooool01OnYZJWo410@o`000?l@
413oZJVY00?ooooo00Gok^k^o`000?l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h0:_ooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00cooooo0_l00009ooooo`;o00001Oooool2o`0000Wooooo1?l00003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
000Yooooo`;o00000_ooool2o`0009Wooooo0_l0000Eooooo`;o00005_ooool2o`0001;ooooo0_l0
0009ooooo`;o00007?ooool2o`0000Wooooo0_l0000@ooooo`;o00005Oooool002Wooooo00Co0000
oooooooooooooooo0_l0000Jooooo`;o00003?ooool2o`0001cooooo0_l0000Iooooo`;o0000=_oo
ool2o`0002_ooooo1?l0000Booooo`;o00001oooool4o`0001Gooooo0_l00003ooooo`;o00007Ooo
ool2o`0000?ooooo0_l0000@ooooo`00:Oooool3o`0001Cooooo0_l00007ooooo`;o00003?ooool2
o`0000Gooooo0_l00002ooooo`;o00004Oooool4o`0001Oooooo0_l000000ooooooo0000o`00000<
ooooo`;o00009Oooool2o`000003ooooool0003o000000Wooooo0_l0000Dooooo`;o00001oooool2
o`00013ooooo0_l0000;ooooo`;o00000_ooool2o`0000_ooooo0_l00006ooooo`;o00000oooool2
o`0002;ooooo0_l0000@ooooo`00:Oooool3o`0001Cooooo0_l0000=ooooo`;o00001Oooool2o`00
00Kooooo0_l00002ooooo`;o00000oooool2o`0000kooooo0_l0000Jooooo`;o00003?ooool2o`00
00[ooooo0_l0000Iooooo`;o000000?oooooo`000?l000002Oooool2o`0001Cooooo0_l00005oooo
o`;o00004_ooool2o`0000oooooo0_l00008ooooo`;o000000?oooooo`000?l000004_ooool2o`00
01cooooo0_l0000?ooooo`00:Oooool00ol0003oooooooooo`0Sooooo`;o00000_ooool2o`000003
ooooool0003o000000oooooo0_l00014ooooo`;o00003oooool2o`000003ooooool0003o0000033o
oooo0_l0000]ooooo`;o00001oooool2o`0000cooooo0_l0000Looooo`;o00003oooool0027ooooo
ool00014o`0000Cooooo000Yooooo`04o`000?oooooo0000o`0000Sooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo0_l00005ooooo`;o0000
1?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo0ol00009ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool01?ooool2o`0000?ooooo00?o0000ooooooooool0
2_ooool01?l0003oooooooooooooool2o`0000Kooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`02ooooo`;o00001Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;o
oooo0_l00006ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool01?l0003o
ooooooooooooool2o`0000Kooooo00?o0000ooooooooool02_ooool002Wooooo00?o0000ooooool0
00000ol00002ooooo`;o0000<oooool00ol0003oooooooooo`0Cooooo`Co00001Oooool2o`0001go
oooo0ol000000ooooooo0000o`000009ooooo`;o0000;?ooool00ol0003oooooooooo`0jooooo`03
o`000?oooooooooo00cooooo0_l0000Tooooo`;o00001?ooool3o`0000cooooo000Yooooo`04o`00
0?ooooooooooooooo`;o00000_ooool2o`0002kooooo0_l00008ooooo`Co00003Oooool2o`0002;o
oooo0_l00002ooooo`Oo00002?ooool2o`00037ooooo0_l0000cooooo`;o00004?ooool2o`0000;o
oooo0_l00004ooooo`;o00008?ooool2o`0000gooooo000Yooooo`03o`000?oooooooooo01Kooooo
0_l0000Mooooo`;o000000?oooooo`000?l000001Oooool4o`0001[ooooo0_l0000>ooooo`;o0000
1Oooool2o`0000Cooooo0_l000000ooooooo0000o`00000:ooooo`;o00005Oooool3o`0001Oooooo
0_l0000:ooooo`;o00008Oooool2o`0000?ooooo0ol0000Dooooo`;o00001?ooool2o`0000?ooooo
0_l00002ooooo`;o00001?ooool2o`0000cooooo0_l0000Booooo`00:Oooool2o`0001Oooooo0_l0
000Pooooo`;o00008oooool2o`0000Oooooo0_l00005ooooo`;o00006_ooool2o`0001Gooooo0ol0
000Hooooo`;o00002Oooool2o`0000Oooooo0_l0000Hooooo`;o00000oooool2o`0001cooooo0_l0
0002ooooo`;o00000_ooool2o`0000Cooooo0_l0000<ooooo`;o00004_ooool002Wooooo00?o0000
ooooooooool06Oooool2o`0001Cooooo0_l0000Sooooo`;o00004?ooool2o`0000Kooooo0_l0000k
ooooo`;o00003_ooool2o`0000Sooooo0_l00007ooooo`?o0000>oooool2o`0002kooooo000Yoooo
o`03o`000?oooooooooo01Wooooo0_l0000Dooooo`;o00008oooool2o`0000Kooooo0_l0000@oooo
o`;o00003Oooool2o`0000Cooooo0_l0000Rooooo`;o00000_ooool2o`0001?ooooo0_l00003oooo
o`;o00001oooool2o`0003oooooo0_l0000[ooooo`00:Oooool00ol0003oooooooooo`0]ooooo`;o
000000?oooooo`000?l00000:_ooool2o`0000;ooooo0_l00007ooooo`;o00004_ooool2o`0000Co
oooo0_l0000Rooooo`;o00005oooool2o`0000kooooo0_l0000Vooooo`;o00004_ooool2o`000003
ooooool0003o000001Gooooo0_l000000ooooooo0000o`00000Aooooo`00:Oooool00ol0003ooooo
ooooo`0=ooooo`;o000000?oooooo`000?l000006oooool5o`0000kooooo0_l0000Booooo`;o0000
2_ooool2o`0000Oooooo0ol0001Iooooo`?o00002?ooool2o`0000;ooooo0_l00003ooooo`;o0000
7Oooool2o`0000;ooooo0_l0000>ooooo`;o00001?ooool2o`000003ooooool0003o000000oooooo
0_l000000ooooooo0000o`00000Aooooo`00:Oooool2o`0000kooooo0_l000000ooooooo0000o`00
000Hooooo`;o00000_ooool4o`0000kooooo0_l0000Booooo`;o00005?ooool2o`0001Cooooo0_l0
0006ooooo`;o00007oooool2o`0001[ooooo0ol0000<ooooo`;o00000oooool2o`0001oooooo1?l0
000Dooooo`;o000000?oooooo`000?l000009Oooool002Wooooo00?o0000ooooooooool0:Oooool3
o`0000Cooooo0_l0000booooo`;o00006_ooool2o`0000Kooooo0_l0000Oooooo`;o00005oooool2
o`0002[ooooo0_l000000ooooooo0000o`000007ooooo`;o0000@?ooool002Wooooo00?o0000oooo
ooooool00_ooool2o`0000Cooooo0_l00002ooooo`;o00005_ooool3o`0000;ooooo0_l0000Voooo
o`;o00001?ooool2o`0000_ooooo0_l0000Sooooo`;o00000_ooool2o`0000_ooooo0_l00009oooo
o`;o00001oooool2o`0001;ooooo0_l0000Mooooo`;o00002oooool2o`000003ooooool0003o0000
00;o00008oooool2o`0002;ooooo000Yooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`;o
00000_ooool2o`0001Kooooo0ol0000Zooooo`;o00001?ooool2o`00033ooooo0_l00002ooooo`;o
00002oooool2o`0000Wooooo0_l00007ooooo`;o00007?ooool2o`0000;ooooo0_l0000?ooooo`;o
00004?ooool2o`0002?ooooo0_l0000Rooooo`00:Oooool00ol0003oooooooooo`0Looooo`;o0000
4?ooool2o`0005Kooooo0_l0000Xooooo`;o00002Oooool2o`0000oooooo0_l00002ooooo`;o0000
4?ooool2o`0003[ooooo0_l0000;ooooo`;o00003oooool002Wooooo0_l0000Cooooo`;o00002?oo
ool2o`00013ooooo0_l0000>ooooo`;o00006?ooool2o`0000kooooo0_l0000Booooo`;o00002?oo
ool2o`0001oooooo0_l00007ooooo`;o00002Oooool2o`0002Gooooo0_l0000Aooooo`;o00003Ooo
ool2o`0000Oooooo0_l0000?ooooo`;o00002oooool2o`0000oooooo000Yooooo`;o00004?ooool2
o`000003ooooool0003o000002Wooooo0ol0000Fooooo`Co00003_ooool2o`0001;ooooo0_l0000O
ooooo`;o00001?ooool2o`0000;ooooo0_l00004ooooo`;o00005Oooool2o`0001Sooooo0_l0000D
ooooo`?o00003Oooool2o`0000Oooooo0_l0000=ooooo`;o00007_ooool002Wooooo00?o0000oooo
ooooool03oooool2o`0002cooooo0_l0000?ooooo`;o00001_ooool2o`0004Gooooo0_l00004oooo
o`;o00002?ooool2o`0001Gooooo0_l0000;ooooo`;o00002oooool2o`0000Gooooo0_l0000=oooo
o`;o00009_ooool2o`0001kooooo000Yooooo`03o`000?oooooooooo04kooooo0_l0000Cooooo`;o
0000K?ooool2o`0001;ooooo0_l0000Kooooo`;o00003?ooool2o`0002[ooooo000Yooooo`03o`00
0?oooooooooo00;o00006?ooool2o`00017ooooo0_l0000`ooooo`;o00000_ooool2o`00043ooooo
0_l0000Wooooo`;o00004Oooool2o`0001oooooo0_l00006ooooo`;o00000_ooool4o`0000Gooooo
0_l0000Sooooo`00:Oooool2o`000003ooooool0003o000001Sooooo0_l0000Aooooo`;o0000<?oo
ool2o`0004Cooooo0_l0000?ooooo`;o00001_ooool2o`0000gooooo0ol00003ooooo`;o00000ooo
ool2o`0000Oooooo0_l0000Wooooo`;o00000_ooool2o`0000Oooooo0_l00009ooooo`;o00006?oo
ool002Wooooo00?o0000ooooooooool0L_ooool2o`0004;ooooo0_l00006ooooo`;o00003Oooool2
o`0000Cooooo0_l00003ooooo`;o0000B?ooool4o`0001Kooooo0006ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`0Mooooo`;o0000COooool2o`0000Cooooo0_l0002`ooooo`;o00005_oo
ool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^
k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Mooooo`;o0000
COooool2o`0002Cooooo0_l000000ooooooo0000o`00000;ooooo`;o0000V?ooool000Kooooo00Go
410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Nooooo`?o0000>?ooool2o`0000Oooooo0_l0000^ooooo`;o0000
00?oooooo`000?l000002oooool2o`0001;ooooo0_l0000Aooooo`;o00000_ooool2o`0005?ooooo
0_l0000Hooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o00005oooool2o`0000Gooooo0ol0000Tooooo`;o0000
0_ooool2o`0000Cooooo0_l00008ooooo`;o00000oooool2o`0000;ooooo0_l0000=ooooo`;o0000
6oooool2o`0001Cooooo0_l0000@ooooo`?o00004?ooool2o`0000;ooooo0_l0001Aooooo`Co0000
00?oooooo`000?l000005Oooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMg
MomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo01Oo
oooo0_l0000>ooooo`;o00005oooool2o`0000?ooooo0_l00002ooooo`;o00001?ooool2o`0000_o
oooo1?l0000Aooooo`;o00006oooool2o`0000Wooooo1?l00007ooooo`Co00003oooool2o`0003Co
oooo0_l0000aooooo`;o00000oooool2o`0001Gooooo0006ooooo`05oa0@4?ooooooooooooooool@
41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02_ooool2o`0000?ooooo0_l0000Fooooo`;o00005oooool2o`0001[ooooo0_l00007ooooo`;o
0000<_ooool4o`0000Wooooo0_l00015ooooo`;o00004Oooool2o`0003[ooooo0006ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0:ooooo`;o00000oooool2o`0004kooooo0_l00004oooo
o`;o0000COooool2o`00033ooooo0_l0000Hooooo`;o0000>_ooool000Kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000
ooooooooool02_ooool3o`0003[ooooo0_l0000Booooo`;o00000_ooool2o`0005?ooooo0_l0000`
ooooo`?o0000?_ooool2o`0001?ooooo000Yooooo`;o00002_ooool4o`0001Sooooo0_l0000Noooo
o`Co00001?ooool2o`0000cooooo0_l0000Mooooo`;o00004?ooool2o`0005Wooooo0_l0000noooo
o`;o00004oooool002Wooooo00?o0000ooooooooool01oooool4o`0001[ooooo0_l0000Nooooo`Go
00000oooool2o`0002_ooooo0_l0000@ooooo`;o0000??ooool2o`00073ooooo000Yooooo`03o`00
0?oooooooooo00Cooooo0_l000000ooooooo0000o`00000mooooo`Co00001_ooool2o`0003kooooo
0_l0000Iooooo`;o00003oooool3o`0000_ooooo0_l0000Uooooo`;o00005_ooool2o`00037ooooo
000Yooooo`03o`000?oooooooooo00Cooooo0_l0000=ooooo`;o0000<Oooool2o`0000Sooooo0_l0
000<ooooo`;o00005?ooool2o`0000Wooooo0_l00009ooooo`;o00001?ooool2o`0001Wooooo0_l0
000?ooooo`?o0000:_ooool2o`0000Kooooo0_l0000Fooooo`;o0000<Oooool002Wooooo00?o0000
ooooooooool00_ooool2o`0000cooooo0_l000000ooooooo0000o`000019ooooo`;o00005?ooool2
o`0000Wooooo0_l00009ooooo`;o00002?ooool2o`0002;ooooo0_l0000_ooooo`;o0000DOooool0
02Wooooo0_l00003ooooo`;o00003?ooool2o`0002oooooo0_l0000/ooooo`?o00001Oooool2o`00
01_ooooo0_l0000Rooooo`;o0000P_ooool002Wooooo00?o0000ooooooooool0@Oooool2o`0002co
oooo0ol00005ooooo`;o0000Joooool2o`0005Kooooo000Yooooo`03o`000?oooooooooo0>Cooooo
0_l0001Fooooo`00:Oooool00ol0003oooooooooo`0Rooooo`;o0000KOooool2o`0005?ooooo0_l0
001Dooooo`00:Oooool00ol0003oooooooooo`0Rooooo`;o00005?ooool2o`0005Oooooo0_l0000E
ooooo`;o00001oooool4o`0000Gooooo0_l0000Jooooo`;o00002oooool2o`000003ooooool0003o
000000Sooooo0_l0000Mooooo`;o00002_ooool2o`0000?ooooo0_l0000Jooooo`00:Oooool2o`00
01_ooooo1?l00002ooooo`;o00005_ooool2o`0004_ooooo0_l0000Qooooo`;o00001oooool4o`00
00Gooooo0_l0000Jooooo`;o00002oooool2o`0000_ooooo0_l0000Mooooo`;o00002_ooool2o`00
00?ooooo0_l0000:ooooo`;o00003_ooool002Wooooo00?o0000ooooooooool06_ooool4o`0000;o
oooo0_l0001Sooooo`;o00005_ooool2o`0008gooooo0_l0000>ooooo`00:Oooool00ol0003ooooo
ooooo`2Mooooo`;o0000WOooool002Wooooo00?o0000ooooooooool0=Oooool2o`000?oooooo1_oo
ool002Wooooo00?o0000ooooooooool0=Oooool2o`000<kooooo0_l0000eooooo`00:Oooool2o`00
0?oooooo1oooool2o`0003Gooooo000Yooooo`03o`000?oooooooooo0=Gooooo0_l0001Uooooo`00
3_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`0gooooo`;o00006_ooool2o`00083ooooo0_l0001Uoooo
o`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0=oooool2o`0001[ooooo0_l0000Dooooo`;o0000dOooool000ko
oooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0001Yoooo
o`;o0000dOooool000kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0Boooool2o`0002;ooooo0_l0000oooooo`;o00004Oooool2o`00
05?ooooo0_l0000Rooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo04_ooooo0_l0000Rooooo`;o0000?oooool2
o`00017ooooo0_l0000Fooooo`;o0000>oooool2o`0002;ooooo000>ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0=_ooooo0_l0001O
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
1_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413o
oooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03oooo
o`?o0000oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qoooo
ooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooo
oooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0
0006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool001oo
oooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oo
oooooooo00Gooooo0ol0003oooooocgooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001oooooo00?oEEEEofIVI_l00000oooo
oom7ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .29766 Mdot
.02762 .26751 Mdot
.02952 .31089 Mdot
.03143 .3408 Mdot
.03333 .35775 Mdot
.03524 .39256 Mdot
.03714 .28011 Mdot
.03905 .3938 Mdot
.04095 .43934 Mdot
.04286 .33588 Mdot
.04476 .34162 Mdot
.04667 .3551 Mdot
.04857 .40682 Mdot
.05048 .351 Mdot
.05238 .34597 Mdot
.05429 .27457 Mdot
.05619 .32822 Mdot
.0581 .40963 Mdot
.06 .29292 Mdot
.0619 .26151 Mdot
.06381 .40777 Mdot
.06571 .33498 Mdot
.06762 .35523 Mdot
.06952 .41257 Mdot
.07143 .25955 Mdot
.07333 .27485 Mdot
.07524 .31328 Mdot
.07714 .2769 Mdot
.07905 .24065 Mdot
.08095 .27303 Mdot
.08286 .41079 Mdot
.08476 .44084 Mdot
.08667 .41704 Mdot
.08857 .2535 Mdot
.09048 .2817 Mdot
.09238 .33644 Mdot
.09429 .34594 Mdot
.09619 .25292 Mdot
.0981 .2321 Mdot
.1 .33606 Mdot
.1019 .2538 Mdot
.10381 .24757 Mdot
.10571 .36063 Mdot
.10762 .26776 Mdot
.10952 .33026 Mdot
.11143 .29227 Mdot
.11333 .34922 Mdot
.11524 .43189 Mdot
.11714 .36971 Mdot
.11905 .24991 Mdot
.12095 .42922 Mdot
.12286 .25103 Mdot
.12476 .40885 Mdot
.12667 .32562 Mdot
.12857 .34139 Mdot
.13048 .43612 Mdot
.13238 .38858 Mdot
.13429 .32925 Mdot
.13619 .40335 Mdot
.1381 .34406 Mdot
.14 .2763 Mdot
.1419 .34457 Mdot
.14381 .2319 Mdot
.14571 .28224 Mdot
.14762 .41977 Mdot
.14952 .44064 Mdot
.15143 .32846 Mdot
.15333 .29614 Mdot
.15524 .25295 Mdot
.15714 .41447 Mdot
.15905 .2976 Mdot
.16095 .31482 Mdot
.16286 .33717 Mdot
.16476 .29527 Mdot
.16667 .23193 Mdot
.16857 .27622 Mdot
.17048 .40856 Mdot
.17238 .25089 Mdot
.17429 .23743 Mdot
.17619 .34876 Mdot
.1781 .40044 Mdot
.18 .26458 Mdot
.1819 .33603 Mdot
.18381 .25341 Mdot
.18571 .41976 Mdot
.18762 .2628 Mdot
.18952 .35468 Mdot
.19143 .33942 Mdot
.19333 .34678 Mdot
.19524 .29159 Mdot
.19714 .25548 Mdot
.19905 .47378 Mdot
.20095 .26616 Mdot
.20286 .32126 Mdot
.20476 .26004 Mdot
.20667 .47351 Mdot
.20857 .3513 Mdot
.21048 .42787 Mdot
.21238 .39805 Mdot
.21429 .34118 Mdot
.21619 .27185 Mdot
.2181 .36484 Mdot
.22 .35886 Mdot
.2219 .2499 Mdot
.22381 .40967 Mdot
.22571 .24602 Mdot
.22762 .27901 Mdot
.22952 .32236 Mdot
.23143 .26736 Mdot
.23333 .41397 Mdot
.23524 .34891 Mdot
.23714 .34119 Mdot
.23905 .4401 Mdot
.24095 .3155 Mdot
.24286 .23025 Mdot
.24476 .31858 Mdot
.24667 .25941 Mdot
.24857 .43867 Mdot
.25048 .44177 Mdot
.25238 .33085 Mdot
.25429 .40549 Mdot
.25619 .29888 Mdot
.2581 .39088 Mdot
.26 .23625 Mdot
.2619 .41438 Mdot
.26381 .33841 Mdot
.26571 .29625 Mdot
.26762 .4664 Mdot
.26952 .23831 Mdot
.27143 .26752 Mdot
.27333 .35744 Mdot
.27524 .248 Mdot
.27714 .32765 Mdot
.27905 .3936 Mdot
.28095 .37778 Mdot
.28286 .23147 Mdot
.28476 .33516 Mdot
.28667 .26079 Mdot
.28857 .33417 Mdot
.29048 .40342 Mdot
.29238 .33784 Mdot
.29429 .40051 Mdot
.29619 .32082 Mdot
.2981 .26391 Mdot
.3 .32713 Mdot
.3019 .28645 Mdot
.30381 .4289 Mdot
.30571 .22709 Mdot
.30762 .3239 Mdot
.30952 .32781 Mdot
.31143 .27539 Mdot
.31333 .36948 Mdot
.31524 .26673 Mdot
.31714 .41399 Mdot
.31905 .32011 Mdot
.32095 .3855 Mdot
.32286 .30451 Mdot
.32476 .23358 Mdot
.32667 .43833 Mdot
.32857 .3443 Mdot
.33048 .31206 Mdot
.33238 .32896 Mdot
.33429 .23854 Mdot
.33619 .25447 Mdot
.3381 .36704 Mdot
.34 .35434 Mdot
.3419 .28559 Mdot
.34381 .43137 Mdot
.34571 .40405 Mdot
.34762 .25277 Mdot
.34952 .30961 Mdot
.35143 .28184 Mdot
.35333 .27289 Mdot
.35524 .26443 Mdot
.35714 .35486 Mdot
.35905 .33951 Mdot
.36095 .41536 Mdot
.36286 .47169 Mdot
.36476 .38717 Mdot
.36667 .32387 Mdot
.36857 .23709 Mdot
.37048 .28052 Mdot
.37238 .30855 Mdot
.37429 .26463 Mdot
.37619 .2446 Mdot
.3781 .2884 Mdot
.38 .43736 Mdot
.3819 .46414 Mdot
.38381 .44223 Mdot
.38571 .26478 Mdot
.38762 .37229 Mdot
.38952 .26257 Mdot
.39143 .28603 Mdot
.39333 .31547 Mdot
.39524 .32168 Mdot
.39714 .40886 Mdot
.39905 .22422 Mdot
.40095 .34576 Mdot
.40286 .33296 Mdot
.40476 .47096 Mdot
.40667 .2463 Mdot
.40857 .32275 Mdot
.41048 .32477 Mdot
.41238 .30746 Mdot
.41429 .35977 Mdot
.41619 .46562 Mdot
.4181 .26223 Mdot
.42 .33214 Mdot
.4219 .39196 Mdot
.42381 .34185 Mdot
.42571 .3212 Mdot
.42762 .33679 Mdot
.42952 .38575 Mdot
.43143 .25379 Mdot
.43333 .40343 Mdot
.43524 .25672 Mdot
.43714 .27863 Mdot
.43905 .2657 Mdot
.44095 .25126 Mdot
.44286 .29669 Mdot
.44476 .36006 Mdot
.44667 .35251 Mdot
.44857 .26357 Mdot
.45048 .40508 Mdot
.45238 .40794 Mdot
.45429 .39106 Mdot
.45619 .26606 Mdot
.4581 .36118 Mdot
.46 .25465 Mdot
.4619 .27017 Mdot
.46381 .34327 Mdot
.46571 .31517 Mdot
.46762 .30558 Mdot
.46952 .3066 Mdot
.47143 .46374 Mdot
.47333 .3752 Mdot
.47524 .31325 Mdot
.47714 .27916 Mdot
.47905 .25601 Mdot
.48095 .24101 Mdot
.48286 .39262 Mdot
.48476 .25432 Mdot
.48667 .34332 Mdot
.48857 .38838 Mdot
.49048 .3879 Mdot
.49238 .29874 Mdot
.49429 .44223 Mdot
.49619 .26354 Mdot
.4981 .28725 Mdot
.5 .36462 Mdot
.5019 .30284 Mdot
.50381 .23172 Mdot
.50571 .22658 Mdot
.50762 .3206 Mdot
.50952 .31763 Mdot
.51143 .30579 Mdot
.51333 .27652 Mdot
.51524 .27057 Mdot
.51714 .36054 Mdot
.51905 .27331 Mdot
.52095 .39702 Mdot
.52286 .42136 Mdot
.52476 .37431 Mdot
.52667 .31389 Mdot
.52857 .38331 Mdot
.53048 .28987 Mdot
.53238 .37175 Mdot
.53429 .32315 Mdot
.53619 .34938 Mdot
.5381 .38518 Mdot
.54 .31431 Mdot
.5419 .30675 Mdot
.54381 .3196 Mdot
.54571 .35233 Mdot
.54762 .33651 Mdot
.54952 .36421 Mdot
.55143 .30128 Mdot
.55333 .27253 Mdot
.55524 .35462 Mdot
.55714 .43281 Mdot
.55905 .33992 Mdot
.56095 .38833 Mdot
.56286 .23152 Mdot
.56476 .26325 Mdot
.56667 .27023 Mdot
.56857 .34261 Mdot
.57048 .37037 Mdot
.57238 .32739 Mdot
.57429 .31907 Mdot
.57619 .35698 Mdot
.5781 .34009 Mdot
.58 .31398 Mdot
.5819 .40601 Mdot
.58381 .46338 Mdot
.58571 .39435 Mdot
.58762 .36578 Mdot
.58952 .39323 Mdot
.59143 .27137 Mdot
.59333 .38893 Mdot
.59524 .29428 Mdot
.59714 .3618 Mdot
.59905 .35402 Mdot
.60095 .25877 Mdot
.60286 .35876 Mdot
.60476 .38028 Mdot
.60667 .24278 Mdot
.60857 .4417 Mdot
.61048 .26572 Mdot
.61238 .35005 Mdot
.61429 .43072 Mdot
.61619 .28907 Mdot
.6181 .29938 Mdot
.62 .38101 Mdot
.6219 .31577 Mdot
.62381 .40044 Mdot
.62571 .25922 Mdot
.62762 .31179 Mdot
.62952 .34886 Mdot
.63143 .24382 Mdot
.63333 .41236 Mdot
.63524 .28229 Mdot
.63714 .30304 Mdot
.63905 .23472 Mdot
.64095 .4256 Mdot
.64286 .32416 Mdot
.64476 .39391 Mdot
.64667 .25789 Mdot
.64857 .23618 Mdot
.65048 .36259 Mdot
.65238 .31935 Mdot
.65429 .27063 Mdot
.65619 .29398 Mdot
.6581 .3699 Mdot
.66 .2962 Mdot
.6619 .26 Mdot
.66381 .36593 Mdot
.66571 .26426 Mdot
.66762 .30617 Mdot
.66952 .25866 Mdot
.67143 .39216 Mdot
.67333 .35544 Mdot
.67524 .32853 Mdot
.67714 .36089 Mdot
.67905 .42613 Mdot
.68095 .28472 Mdot
.68286 .24797 Mdot
.68476 .28252 Mdot
.68667 .42758 Mdot
.68857 .32224 Mdot
.69048 .27057 Mdot
.69238 .29004 Mdot
.69429 .29693 Mdot
.69619 .29823 Mdot
.6981 .3991 Mdot
.7 .35828 Mdot
.7019 .38926 Mdot
.70381 .32552 Mdot
.70571 .3522 Mdot
.70762 .25216 Mdot
.70952 .2891 Mdot
.71143 .37479 Mdot
.71333 .35938 Mdot
.71524 .43463 Mdot
.71714 .38403 Mdot
.71905 .33184 Mdot
.72095 .29622 Mdot
.72286 .243 Mdot
.72476 .28394 Mdot
.72667 .37364 Mdot
.72857 .3363 Mdot
.73048 .39398 Mdot
.73238 .27747 Mdot
.73429 .41069 Mdot
.73619 .27996 Mdot
.7381 .39204 Mdot
.74 .28017 Mdot
.7419 .43192 Mdot
.74381 .24224 Mdot
.74571 .36748 Mdot
.74762 .26258 Mdot
.74952 .34758 Mdot
.75143 .37754 Mdot
.75333 .34968 Mdot
.75524 .28312 Mdot
.75714 .21713 Mdot
.75905 .34969 Mdot
.76095 .3817 Mdot
.76286 .32176 Mdot
.76476 .22453 Mdot
.76667 .35108 Mdot
.76857 .26988 Mdot
.77048 .29904 Mdot
.77238 .41463 Mdot
.77429 .31791 Mdot
.77619 .30807 Mdot
.7781 .25157 Mdot
.78 .30165 Mdot
.7819 .43563 Mdot
.78381 .40492 Mdot
.78571 .3132 Mdot
.78762 .30219 Mdot
.78952 .27772 Mdot
.79143 .43712 Mdot
.79333 .26121 Mdot
.79524 .3368 Mdot
.79714 .35126 Mdot
.79905 .31552 Mdot
.80095 .37706 Mdot
.80286 .35851 Mdot
.80476 .31632 Mdot
.80667 .28915 Mdot
.80857 .30229 Mdot
.81048 .25617 Mdot
.81238 .23305 Mdot
.81429 .32724 Mdot
.81619 .36768 Mdot
.8181 .32643 Mdot
.82 .26409 Mdot
.8219 .27713 Mdot
.82381 .34294 Mdot
.82571 .2636 Mdot
.82762 .29016 Mdot
.82952 .33322 Mdot
.83143 .28693 Mdot
.83333 .40492 Mdot
.83524 .27639 Mdot
.83714 .29525 Mdot
.83905 .27899 Mdot
.84095 .37591 Mdot
.84286 .29534 Mdot
.84476 .25763 Mdot
.84667 .22501 Mdot
.84857 .47606 Mdot
.85048 .23819 Mdot
.85238 .27812 Mdot
.85429 .25451 Mdot
.85619 .33138 Mdot
.8581 .43849 Mdot
.86 .32914 Mdot
.8619 .33823 Mdot
.86381 .28858 Mdot
.86571 .42173 Mdot
.86762 .2969 Mdot
.86952 .30157 Mdot
.87143 .34708 Mdot
.87333 .3849 Mdot
.87524 .33744 Mdot
.87714 .47345 Mdot
.87905 .30621 Mdot
.88095 .29707 Mdot
.88286 .24623 Mdot
.88476 .26386 Mdot
.88667 .31537 Mdot
.88857 .28781 Mdot
.89048 .39327 Mdot
.89238 .29694 Mdot
.89429 .23299 Mdot
.89619 .24847 Mdot
.8981 .33644 Mdot
.9 .30848 Mdot
.9019 .40982 Mdot
.90381 .29583 Mdot
.90571 .46831 Mdot
.90762 .31505 Mdot
.90952 .36613 Mdot
.91143 .22648 Mdot
.91333 .34909 Mdot
.91524 .38967 Mdot
.91714 .30109 Mdot
.91905 .34464 Mdot
.92095 .27327 Mdot
.92286 .26951 Mdot
.92476 .30353 Mdot
.92667 .29542 Mdot
.92857 .25351 Mdot
.93048 .34781 Mdot
.93238 .37364 Mdot
.93429 .27842 Mdot
.93619 .34863 Mdot
.9381 .35313 Mdot
.94 .28674 Mdot
.9419 .31824 Mdot
.94381 .32131 Mdot
.94571 .37656 Mdot
.94762 .32706 Mdot
.94952 .26109 Mdot
.95143 .44035 Mdot
.95333 .3594 Mdot
.95524 .33707 Mdot
.95714 .25776 Mdot
.95905 .27283 Mdot
.96095 .26668 Mdot
.96286 .23792 Mdot
.96476 .26722 Mdot
.96667 .26292 Mdot
.96857 .40418 Mdot
.97048 .36253 Mdot
.97238 .25579 Mdot
.97429 .24924 Mdot
.97619 .3262 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003Yooooo`;o0000D_ooool0
02Wooooo00?o0000ooooooooool0j?ooool2o`0005;ooooo0006ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`1eooooo`;o0000M?ooool2o`0004oooooo0006ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0Eoooool2o`0001cooooo0_l0000Pooooo`;o0000D_oo
ool2o`0001Sooooo0_l0000Cooooo`;o00008?ooool000Co00000_ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo04?ooooo0_l0000Booooo`;o0000?_ooool2o`0006cooooo0_l0000Cooooo`;o00008?oo
ool000Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o
MgMgoc8b<_ooool01?ooool3o`0001Cooooo0_l0000=ooooo`;o00001Oooool2o`0001Oooooo0_l0
000;ooooo`;o00002oooool2o`0003Sooooo0_l0000Aooooo`;o0000C_ooool2o`0001Sooooo0_l0
000Vooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool05?ooool2o`0000gooooo
0_l00005ooooo`;o00007?ooool2o`0000Kooooo0_l0000;ooooo`;o00003?ooool2o`0002[ooooo
0_l0000Aooooo`;o00005_ooool2o`000003ooooool0003o000003?ooooo0_l0000Hooooo`;o0000
9_ooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0]ooooo`;o00006Oooool2o`000003oooo
ool0003o000001?ooooo0_l00009ooooo`;o0000EOooool2o`000003ooooool0003o000003oooooo
0_l0000Rooooo`;o00004?ooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00ko
oooo0_l0000Mooooo`;o00007?ooool2o`0001?ooooo0_l0000]ooooo`;o00009oooool2o`0002?o
oooo0_l00005ooooo`;o00008?ooool2o`0002;ooooo0_l0000@ooooo`001_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0
003oooooooooo`0>ooooo`;o0000;Oooool2o`0002oooooo0_l00007ooooo`;o00005_ooool2o`00
02Oooooo0_l00006ooooo`;o00006oooool2o`0000Gooooo0_l0000Zooooo`;o0000:_ooool002Wo
oooo0_l0000Gooooo`;o00009Oooool2o`0000kooooo0_l0000Oooooo`;o00001oooool2o`0004Oo
oooo0_l0000>ooooo`;o0000?_ooool2o`0000?ooooo0_l0000Gooooo`;o00003?ooool002Wooooo
00?o0000ooooooooool05_ooool2o`0000?ooooo0ol0000>ooooo`;o00003_ooool2o`0000oooooo
0_l0000Eooooo`;o00007?ooool2o`0004cooooo0_l00006ooooo`;o00005Oooool2o`0002Cooooo
0_l0000Gooooo`;o00003?ooool002Wooooo00?o0000ooooooooool04Oooool2o`000004ooooool0
003o0000o`0000Cooooo0ol00009ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`;o0000
1_ooool2o`0002?ooooo0_l000000ooooooo0000o`00000Iooooo`;o000000?oooooo`000?l00000
1Oooool2o`0000Gooooo0_l00016ooooo`;o00005Oooool2o`0001Kooooo0_l0000Fooooo`;o0000
3?ooool2o`0000gooooo000Yooooo`03o`000?oooooooooo017ooooo0_l000001?oooooo0000o`00
0?l0000@ooooo`;o00001oooool2o`0000;ooooo0_l0000[ooooo`;o00007?ooool4o`0000Kooooo
0_l00004ooooo`?o00009?ooool2o`0000gooooo0_l00005ooooo`;o0000:oooool2o`0000Wooooo
0_l000000ooooooo0000o`00000Fooooo`;o00001oooool2o`0000?ooooo0_l0000=ooooo`00:Ooo
ool00ol0003oooooooooo`09ooooo`;o000000?oooooo`000?l00000:?ooool2o`0000cooooo0_l0
000;ooooo`;o0000;_ooool2o`0000cooooo0_l0000Uooooo`;o00001_ooool2o`0000Gooooo0_l0
0002ooooo`;o000000?oooooo`000?l000009_ooool2o`0000?ooooo0_l00009ooooo`;o00008?oo
ool4o`0001;ooooo000Yooooo`;o00002_ooool2o`000003ooooool0003o0000023ooooo0_l00000
0ooooooo0000o`000003ooooo`;o00003?ooool2o`0000_ooooo0_l000000ooooooo0000o`00000A
ooooo`;o00001?ooool2o`0000;ooooo0ol00007ooooo`;o00002?ooool2o`0000gooooo0_l0000D
ooooo`;o00004_ooool2o`0000Wooooo1?l0000Hooooo`;o00003Oooool2o`0000Kooooo1?l0000A
ooooo`;o00004oooool2o`0000?ooooo0_l0000?ooooo`00:Oooool2o`0001Sooooo0_l0000Eoooo
o`;o000000?oooooo`000?l000000_ooool2o`0000Sooooo0_l0000;ooooo`;o00001_ooool2o`00
00Cooooo0_l0000;ooooo`;o00001?ooool2o`0000;ooooo0ol00007ooooo`;o00001Oooool2o`00
0003ooooool0003o000000;o00002oooool2o`0001Cooooo0_l0000=ooooo`;o00004?ooool2o`00
01Sooooo0_l0000Eooooo`Co00004Oooool2o`0001Oooooo0ol0000?ooooo`00:Oooool2o`0001So
oooo0_l0000Gooooo`Co000000So410@o`000?l0003ok^k^oc8b<_l0003o<S8bonk^kP?ooooo0ol0
00000olb<S;ok^k^ooooo`07ooooo`;o00003?ooool2o`00017ooooo1Ol00003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;o00000oooool4o`0000oo
oooo0_l0000>ooooo`05oiRHV?l0003o0000oc8b<_o<c<`00oooool01Oo^k^ko0000o`000?lb<S;o
k^k^00;ooooo0_l000001?lb<S;o0000oc8b<_o^k^h8ooooo`;o00002_ooool2o`0001Cooooo0_l0
00002Ol@413o0000o`000?ooooook^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h08Oooool2o`0000Kooooo00GoA4A4o`000?l0003o<S8bomgMg@03o`000004oc8b<_l0
003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool00ol0003ooooo
ooooo`06ooooo`;o00001oooool2o`00027ooooo00?o0000ooooooooool00_ooool00omgMgOoV9RH
ooooo`02o`0000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Rooooo`;o00001Oooool01OnHV9So
8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01oooool2o`0000oooooo1?l00009ooooo`;o000000Kooooooa0@4?l0003o0000
ogMgMolb<S83ooooo`05ogMgMol0003o0000oiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Sooooo0_l0000:ooooo`;o00005Oooool02_l0003oooooo`000?l0003oooooogMgMonHV9So
oooooiRHV?mgMgL3ooooo`05ogMgMonHV9SooooooiRHV?mgMgL08Oooool2o`0000Wooooo00WoMgMg
o`000?l0003oooooogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo000Yooooo`03o`000?oooooooooo00Kooooo0_l00004ooooo`Go00004Oooool2o`0000Oo
oooo0_l00005ooooo`03o`000?oooooooooo00;ooooo00?o410@ooooooooool00_l00003ooooo`05
oa0@4?ooooooooooooooool@41005Oooool2o`0000_ooooo0_l00006ooooo`03oiRHV?lQ8B7ok^k^
00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41006?oo
ool4o`0000Wooooo0_l00005ooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool07oooool2o`0000Gooooo1Ol00003ooooo`03
oa0@4?oooooooooo00;o00000oooool01_l@413ooooooooooooooooo410@ooooo`;o00000_ooool2
o`0001[ooooo0_l0000:ooooo`;o000000?ooooooa0@4?ooool00_ooool01Ol@413ooooooooooooo
oooo410@00?ooooo00?o410@ooooooooool00Oooool002Wooooo0_l00002ooooo`;o00002Oooool3
o`0001?ooooo0_l00007ooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000000_ooool2o`0000?ooooo00?o0000ooooooooool04oooool2o`00017ooooo0_l0
00001?ooooooV9RHob4Q8Oo^k^h3ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooooooool2o`0000_ooooo0_l0000:ooooo`;o00004Oooool00onYZJWo410@ooooo`02oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000027ooooo1Ol0
0002ooooo`04odA4A?oMgMgoooooo`0000Cooooo00?o0000ooooooooool00_l00003ooooo`06o`00
0?ooooooooooooooool0003ooooo0_l00002ooooo`?o00000oooool2o`0001Sooooo0_l00005oooo
o`05ogMgMolb<S;oooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool00Oooool002Wooooo00Co0000oooooooooooooooo0_l0000?ooooo`;o00003ooo
ool2o`0000gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo
0_l00003ooooo`03o`000?oooooooooo023ooooo0_l00004ooooo`;o00000_ooool00omgMgOoIVIV
ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooooooool2o`00
00_ooooo0_l0000Looooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000kooooo0_l0000;ooooo`;o000000?o
ooooo`000?l000000_l00002ooooo`;o000000?oooooo`000?ooool00oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000006ooooo`;o00000oooool2o`0001So
oooo0_l00002ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`00:Oooool00ol0003oooooooooo`0B
ooooo`;o00003oooool2o`0000gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@00?ooooo00Go410@oooooooooooooooooa0@400Booooo`;o00002oooool2o`000003oooo
ool0003o000000Wooooo0ol000000ooooooo410@ooooo`02ooooo`05oa0@4?ooooooooooooooool@
41000oooool00ol@413oooooooooo`0Yooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooo
oooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000_ooool2o`0000gooooo0ol0000;
ooooo`;o00001oooool2o`000003olc<c?l0003ooooo00?ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41001?ooool2o`00027ooooo0ol00006ooooo`05oa0@
4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo000Yooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Booooo`;o00002oooool2o`0000Sooooo0ol00000
2_nHV9So410@o`000?l0003oooooogMgMonHV9SooooooiRHV?mgMgL3ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL04oooool2o`0000Sooooo0_l00009ooooo`05oa0@4?nHV9SooooookZj^_l000000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgo`000?l0003oV9RHogMgM`0Aooooo`;o
000000?oooooo`000?l000001?ooool2o`0000gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgo`000?l0003oV9RHogMgM`03ooooo`?o00002?ooool2
o`0000Kooooo0_l0000?ooooo`?o00001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool00ol0003oooooooooo`08ooooo`;o00003_oo
ool2o`0001Kooooo00?oEEEEofIVI_l000000_l00002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Wooooo00GoV9RHo`000?l0003o8B4Qolc<c003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01?ooooo0_l0
0008ooooo`;o00002Oooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`05onk^k_l0003o0000oc8b<_o^k^h05?ooool2o`0000Cooooo0_l0000>oooo
o`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_l0003o
0000oc8b<_o^k^h00oooool2o`0000Wooooo0_l00006ooooo`;o00004Oooool4o`0000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool002Wooooo
0_l00009ooooo`;o00003_ooool2o`0000cooooo0_l00002ooooo`;o00001oooool2o`0001Gooooo
0_l0001Xooooo`;o00004_ooool3o`00017ooooo0_l0000Tooooo`Co00004Oooool2o`0000Kooooo
0_l0000Kooooo`00:Oooool2o`0002Oooooo1_l0000Kooooo`;o000000?oooooo`000?l00000=ooo
ool2o`0000kooooo0_l0000Oooooo`;o00001Oooool2o`0000_ooooo0ol00009ooooo`;o00001_oo
ool2o`0000kooooo0_l0000Dooooo`Co00001_ooool2o`0000;ooooo0_l00002ooooo`;o000000?o
ooooo`000?l000001_ooool2o`0001_ooooo000Yooooo`;o0000:Oooool2o`0001gooooo0_l0000j
ooooo`;o00003_ooool2o`00017ooooo0_l0000Cooooo`;o00005oooool2o`0001Kooooo0_l00000
1?oooooo0000o`000?ooool2o`0000Gooooo0_l0000Aooooo`;o00000_ooool2o`0000;ooooo0_l0
0006ooooo`;o00007_ooool002Wooooo00?o0000ooooooooool0G?ooool2o`0002gooooo0_l00009
ooooo`;o00003_ooool2o`0001Wooooo0_l0000/ooooo`;o000000?oooooo`000?l000001Oooool2
o`00017ooooo0_l0000>ooooo`Co00007?ooool002Wooooo00?o0000ooooooooool0G?ooool2o`00
00kooooo0_l0000;ooooo`;o00004?ooool3o`0000Sooooo0_l000000ooooooo0000o`000008oooo
o`;o00007?ooool2o`0000Sooooo0_l0000Qooooo`;o00007oooool2o`0000Gooooo0_l00006oooo
o`;o00007?ooool0027oooooool00014o`0000Cooooo000Yooooo`?o00002Oooool01?l0003ooooo
ooooooooool2o`0000Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`;o
00001?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`;o00001?ooool2o`0000Cooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo0_l000000ooooooo
0000ooooo`0:ooooo`04o`000?oooooo0000o`0000;ooooo0_l00005ooooo`03o`000?oooooooooo
00?ooooo0_l00004ooooo`03o`000?oooooooooo00Kooooo0_l000000ooooooo0000ooooo`0:oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08oooo
o`;o00002oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo000Yooooo`03
o`000?oooooooooo00gooooo0_l0000Iooooo`;o00004?ooool00ol0003oooooooooo`05ooooo`;o
00006oooool2o`0001;ooooo0_l00003ooooo`03o`000?oooooooooo00oooooo0_l000000ooooooo
0000o`000009ooooo`;o00001?ooool2o`0000;ooooo0_l0000;ooooo`;o00001?ooool00ol0003o
ooooooooo`05ooooo`;o0000;oooool2o`000003ooooool0003o000000?ooooo0ol0000Iooooo`;o
00001?ooool2o`0001Gooooo00?o0000ooooooooool02_ooool002Wooooo00?o0000ooooooooool0
=_ooool2o`0000[ooooo0ol0000?ooooo`;o00001Oooool2o`0001Kooooo0_l00008ooooo`;o0000
2oooool2o`0000cooooo0_l00009ooooo`;o00002?ooool2o`0000kooooo0_l00007ooooo`;o0000
9_ooool2o`0000Kooooo0ol0000Iooooo`;o00001?ooool2o`0000Wooooo0_l0000Gooooo`00:Ooo
ool00ol0003oooooooooo`0fooooo`;o00001_ooool2o`0000?ooooo0_l0000?ooooo`;o00000_oo
ool2o`000003ooooool0003o000000kooooo0_l00007ooooo`;o00000_ooool2o`0000?ooooo0_l0
000Iooooo`;o00001_ooool2o`000003ooooool0003o000000Sooooo0_l0000Dooooo`;o000000?o
ooooo`000?l000002_ooool2o`0001Kooooo0_l0000gooooo`?o00005_ooool002Wooooo0_l0000N
ooooo`;o00007oooool2o`0001Gooooo0_l000000ooooooo0000o`00000Aooooo`;o00001oooool2
o`0000;ooooo0ol0000Uooooo`;o00002oooool2o`0001Cooooo0_l0000=ooooo`;o00000oooool2
o`00017ooooo0_l0000>ooooo`Co00009_ooool3o`0000Sooooo0_l0000;ooooo`00:Oooool00ol0
003oooooooooo`07ooooo`;o00003oooool2o`0000?ooooo0_l000000ooooooo0000o`000003oooo
o`;o00009oooool2o`0000Gooooo0_l000000ooooooo0000o`000005ooooo`;o00006?ooool2o`00
03;ooooo0_l0000Oooooo`;o00001oooool2o`00027ooooo1?l0000;ooooo`;o00006_ooool2o`00
00Sooooo0_l0000;ooooo`00:Oooool00ol0003oooooooooo`07ooooo`;o00003oooool2o`0000Ko
oooo0_l00003ooooo`;o00007oooool2o`0000Kooooo0_l00008ooooo`;o00001Oooool2o`0001Go
oooo0_l00004ooooo`;o0000D?ooool2o`0000cooooo0_l0000Qooooo`;o00001oooool3o`00037o
oooo000Yooooo`03o`000?oooooooooo00;ooooo0_l00006ooooo`;o00001_ooool2o`000003oooo
ool0003o000001Sooooo0_l0000Eooooo`;o00002?ooool3o`0002?ooooo0_l00004ooooo`Co0000
9Oooool2o`0003Gooooo0_l000000ooooooo0000o`00000Cooooo`;o00002Oooool2o`0000Oooooo
0_l0000;ooooo`;o00009Oooool002Wooooo00?o0000ooooooooool00_ooool2o`0000Kooooo0_l0
0006ooooo`;o000000?oooooo`000?l000004_ooool2o`0000Cooooo0_l000000ooooooo0000o`00
000Eooooo`;o00001Oooool5o`0001?ooooo0_l0000Dooooo`;o00009Oooool2o`000003ooooool0
003o000003Gooooo0_l0000Cooooo`;o00005?ooool2o`0000;ooooo0_l00005ooooo`;o00004Ooo
ool2o`0001;ooooo000Yooooo`Co00000_ooool2o`0001Wooooo0_l00009ooooo`;o00001oooool2
o`0000Kooooo0_l00005ooooo`;o00001_ooool2o`0000Sooooo0_l0000Cooooo`;o00004oooool2
o`0002Wooooo0_l000001?oooooo0000o`000?ooool2o`0004kooooo0_l0000:ooooo`;o00000_oo
ool2o`0001Sooooo0_l0000Booooo`00:Oooool01?l0003oooooo`000?l00002ooooo`Co00003?oo
ool2o`0000Wooooo0_l000001?oooooo0000o`000?l0000Fooooo`;o00001Oooool2o`0001_ooooo
0_l0000Fooooo`;o00001Oooool2o`0000_ooooo0_l00005ooooo`;o00006?ooool2o`000003oooo
ool0003o000004kooooo0_l0000Looooo`;o00007_ooool002Wooooo00?o0000ooooooooool01Ooo
ool2o`0000cooooo0_l00004ooooo`;o00001_ooool3o`0000Wooooo0_l00004ooooo`;o00002ooo
ool2o`0001cooooo0_l0000Fooooo`;o00004_ooool2o`0000Gooooo0_l0000/ooooo`;o00009Ooo
ool2o`0002Gooooo0_l0000;ooooo`Co00000_ooool4o`0001Sooooo000Yooooo`03o`000?oooooo
oooo00Gooooo0_l0000Booooo`;o00004_ooool2o`0000Cooooo0_l00003ooooo`;o00001_ooool2
o`0005oooooo0_l000000ooooooo0000o`00000Dooooo`;o00000oooool2o`0001Oooooo0_l0000<
ooooo`Oo00002?ooool2o`0001Kooooo0_l0000;ooooo`;o00001?ooool4o`0001Sooooo000Yoooo
o`03o`000?oooooooooo00Cooooo0ol00003ooooo`;o00009_ooool2o`0000Cooooo0_l0000Xoooo
o`;o00000oooool2o`0001_ooooo0_l0000Kooooo`;o000000Coooooo`000?l0003ooooo0_l0000<
ooooo`;o00000oooool2o`00017ooooo0_l00009ooooo`;o00003Oooool6o`0000Sooooo0_l0000[
ooooo`;o00006?ooool002Wooooo1?l00003ooooo`;o00001?ooool2o`0002Kooooo0_l0000Ioooo
o`;o00004oooool2o`0000?ooooo0_l0000Kooooo`;o00008Oooool2o`0000Gooooo0_l00005oooo
o`;o00005_ooool2o`0000Oooooo0_l0000Oooooo`;o0000:Oooool2o`0001Sooooo000Yooooo`04
o`000?oooooo0000o`0001Kooooo0_l0000Rooooo`;o00004?ooool2o`0002_ooooo0_l00008oooo
o`;o00000_ooool2o`00017ooooo0_l0000Aooooo`;o00001_ooool2o`0001Kooooo0_l00006oooo
o`;o00000_ooool2o`0001_ooooo0_l0000^ooooo`;o00004oooool002Wooooo00?o0000oooooooo
ool05oooool2o`0002;ooooo0_l0000mooooo`;o00002?ooool2o`0000;ooooo0_l0000;ooooo`;o
00001?ooool2o`0000Sooooo0_l0000>ooooo`?o00003_ooool2o`0000Kooooo0_l0000:ooooo`;o
0000Boooool2o`0000Cooooo0_l0000=ooooo`00:Oooool00ol0003oooooooooo`0kooooo`;o0000
9?ooool2o`0003;ooooo0_l0000>ooooo`;o00002oooool2o`000003ooooool0003o000000oooooo
0_l00002ooooo`;o00006?ooool2o`0001Gooooo0_l0000Looooo`;o00004_ooool2o`0000gooooo
000Yooooo`03o`000?oooooooooo01[ooooo0_l0000Oooooo`;o00007?ooool2o`0000Kooooo0_l0
0019ooooo`;o00001?ooool2o`0001Cooooo1?l0000Hooooo`;o00005Oooool2o`0001cooooo0_l0
000Qooooo`00:Oooool2o`0001_ooooo0_l0000mooooo`;o00005_ooool2o`0002gooooo0_l0000:
ooooo`;o00006_ooool2o`0001Cooooo0_l00010ooooo`;o00006_ooool002Wooooo00?o0000oooo
ooooool0LOooool2o`0001[ooooo0_l0000>ooooo`;o000000?oooooo`000?l00000=oooool2o`00
00?ooooo0_l0000Fooooo`;o00002oooool2o`0001_ooooo0_l00003ooooo`;o00005Oooool000Ko
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo04oooooo0_l0000looooo`;o00003_ooool2
o`0001Sooooo0_l0000Pooooo`;o00002oooool2o`0000kooooo0_l0000;ooooo`;o00008?ooool2
o`0001Gooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0Cooo
ool2o`0004kooooo0_l0000Fooooo`;o00000oooool2o`0002Sooooo0_l000000ooooooo0000o`00
001Aooooo`001_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05cooooo0_l0000Qooooo`;o00007_oo
ool2o`000003ooooool0003o000001Sooooo0_l0000Mooooo`;o00003?ooool2o`0002;ooooo0_l0
000]ooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00omgMgOo<S8booooo`04ooooo`?o00007oooool2o`0003_ooooo0_l0000<ooooo`;o00004ooo
ool2o`00017ooooo0_l0000>ooooo`;o00001Oooool2o`0000Sooooo0_l0000Qooooo`;o00000ooo
ool2o`00033ooooo0_l0000<ooooo`;o00007oooool000Kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo00;o00007Oooool2o`0002Oooooo0_l0000Pooooo`;o00004?ooool2o`0000Wooooo
0_l00007ooooo`Co00005Oooool2o`0000Sooooo0_l0000Hooooo`;o00001oooool2o`0000[ooooo
0_l0000gooooo`;o00007oooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03o`0004Gooooo
0_l00004ooooo`;o0000;?ooool2o`0000Wooooo0_l00007ooooo`;o00007oooool3o`00013ooooo
0_l00007ooooo`;o00004?ooool2o`000003ooooool0003o000002oooooo0_l0000Wooooo`001_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03
o`000?oooooooooo00Oooooo00Co0000oooooooooooooooo0_l0000fooooo`;o00004oooool2o`00
04cooooo0_l0000Cooooo`?o00004?ooool2o`0001Wooooo0_l0000booooo`;o00009oooool000Ko
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4
o`0000Kooooo00?o0000ooooooooool0;_ooool2o`0000Wooooo0_l0000Hooooo`;o0000Aoooool2
o`0001oooooo0_l0000Fooooo`;o0000IOooool002Wooooo0_l0000Qooooo`;o00003?ooool2o`00
02;ooooo0ol0000?ooooo`;o00006_ooool2o`0000?ooooo0_l0000fooooo`;o00005_ooool2o`00
01[ooooo0_l0000>ooooo`;o0000:Oooool2o`0000kooooo000Yooooo`03o`000?oooooooooo00Co
oooo0_l00003ooooo`;o00005Oooool2o`0002Cooooo0_l0000:ooooo`;o00004?ooool2o`0001[o
oooo0_l00003ooooo`?o0000:?ooool2o`0003oooooo0_l0000>ooooo`;o0000:Oooool2o`0000ko
oooo000Yooooo`03o`000?oooooooooo00Cooooo0_l000000ooooooo0000o`000002o`0000Cooooo
0_l0000<ooooo`;o00003?ooool2o`00013ooooo0_l00007ooooo`;o0000;?ooool2o`00013ooooo
0_l0000Xooooo`;o0000;oooool2o`0003Cooooo0_l0000Sooooo`00:Oooool00ol0003ooooooooo
o`07ooooo`;o00000_ooool2o`0000;ooooo0_l0000<ooooo`;o00002?ooool2o`0000;ooooo0_l0
000@ooooo`;o000000?oooooo`000?l000001oooool2o`00013ooooo0_l0000Gooooo`;o0000B_oo
ool2o`0001oooooo0_l0000dooooo`;o00008oooool002Wooooo00?o0000ooooooooool02oooool2
o`0000?ooooo0_l0000Eooooo`;o00005oooool2o`0000Oooooo0_l0000@ooooo`;o00003?ooool2
o`0005Gooooo0_l0000[ooooo`;o0000COooool002Wooooo0_l0000Aooooo`;o00004_ooool2o`00
00[ooooo0_l0000gooooo`;o0000P_ooool2o`0004gooooo000Yooooo`03o`000?oooooooooo02Co
oooo0_l0000:ooooo`;o0000Joooool2o`0006cooooo0_l0000_ooooo`00:Oooool00ol0003ooooo
ooooo`2Mooooo`;o00009?ooool2o`0000[ooooo0_l0000jooooo`;o0000;oooool002Wooooo00?o
0000ooooooooool07?ooool2o`0001[ooooo0_l0000Looooo`;o0000Joooool2o`0000[ooooo1?l0
001Yooooo`00:Oooool00ol0003oooooooooo`0Jooooo`Co00006_ooool2o`0001cooooo0_l0000;
ooooo`;o0000@oooool2o`00013ooooo0_l0000Eooooo`;o00004?ooool2o`0005Oooooo000Yoooo
o`;o00006oooool2o`0000?ooooo0_l00012ooooo`;o0000@oooool2o`00013ooooo0_l0000Ooooo
o`;o00001_ooool2o`0000_ooooo0_l0001:ooooo`00:Oooool00ol0003oooooooooo`02ooooo`;o
00006oooool2o`0002Cooooo0_l0000Gooooo`;o00003oooool2o`0006[ooooo0_l0000Cooooo`;o
000000?oooooo`000?l000005?ooool2o`00037ooooo000Yooooo`03o`000?oooooooooo00;ooooo
0_l0000<ooooo`;o00004oooool2o`0001[ooooo0_l00002ooooo`;o00005oooool2o`0000oooooo
0ol0000Rooooo`;o00008_ooool2o`0003Wooooo0_l0000Dooooo`;o00007?ooool2o`0001?ooooo
000Yooooo`03o`000?oooooooooo013ooooo0_l0000Cooooo`;o00006_ooool2o`0000;ooooo0_l0
000Yooooo`;o00008_ooool2o`0002;ooooo0_l0001]ooooo`;o00004oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`3oooooocgooooo000>ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`03ooooo`?o0000Koooool2o`0001_ooooo0_l0000Rooooo`;o0000R_ooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0Boooool2o`0002;ooooo0_l00009ooooo`;o00004?ooool2o`0002;ooooo0_l0002:oooo
o`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005
ooooo`03o`000?oooooooooo04_ooooo0_l0000]ooooo`;o0000W?ooool2o`0002;ooooo000>oooo
o`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo03Oooooo0_l0000`ooooo`;o00003?ooool2o`0009Kooooo0_l00007ooooo`;o00008_ooool0
00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0=Oooool4o`00033ooooo0_l0000<ooooo`;o0000S?ooool2o`0000Sooooo0_l0000[
ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000=_ooool2
o`000<kooooo0_l0000eooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooo
oooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`00
0?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo
00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05
o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?oooooooooo
ooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@
oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooo
oolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_oo
ool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Oooooo`Co
000000?o410@ooooooooool00oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003ooooooooo
o`05ooooo`?o0000oooooolmooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Oooooo`03oeEEEOmVIVKo00000?ooooooAooo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .37306 Mdot
.02762 .24994 Mdot
.02952 .28264 Mdot
.03143 .31725 Mdot
.03333 .35672 Mdot
.03524 .36667 Mdot
.03714 .27711 Mdot
.03905 .44437 Mdot
.04095 .41288 Mdot
.04286 .27856 Mdot
.04476 .34821 Mdot
.04667 .42775 Mdot
.04857 .35571 Mdot
.05048 .33463 Mdot
.05238 .42158 Mdot
.05429 .33068 Mdot
.05619 .37405 Mdot
.0581 .36333 Mdot
.06 .25273 Mdot
.0619 .36147 Mdot
.06381 .36226 Mdot
.06571 .24529 Mdot
.06762 .26452 Mdot
.06952 .37454 Mdot
.07143 .36979 Mdot
.07333 .25605 Mdot
.07524 .35039 Mdot
.07714 .26011 Mdot
.07905 .33853 Mdot
.08095 .24661 Mdot
.08286 .37933 Mdot
.08476 .4155 Mdot
.08667 .44653 Mdot
.08857 .33165 Mdot
.09048 .24763 Mdot
.09238 .40235 Mdot
.09429 .24413 Mdot
.09619 .30411 Mdot
.0981 .31399 Mdot
.1 .41902 Mdot
.1019 .36566 Mdot
.10381 .28336 Mdot
.10571 .28438 Mdot
.10762 .35594 Mdot
.10952 .38814 Mdot
.11143 .35334 Mdot
.11333 .31884 Mdot
.11524 .37974 Mdot
.11714 .32157 Mdot
.11905 .3494 Mdot
.12095 .37407 Mdot
.12286 .25757 Mdot
.12476 .46989 Mdot
.12667 .24741 Mdot
.12857 .25823 Mdot
.13048 .43675 Mdot
.13238 .44222 Mdot
.13429 .37488 Mdot
.13619 .32164 Mdot
.1381 .39281 Mdot
.14 .34482 Mdot
.1419 .23319 Mdot
.14381 .30939 Mdot
.14571 .32978 Mdot
.14762 .44308 Mdot
.14952 .42934 Mdot
.15143 .26853 Mdot
.15333 .33936 Mdot
.15524 .29617 Mdot
.15714 .3879 Mdot
.15905 .36435 Mdot
.16095 .31842 Mdot
.16286 .28164 Mdot
.16476 .25643 Mdot
.16667 .30974 Mdot
.16857 .30752 Mdot
.17048 .46977 Mdot
.17238 .31651 Mdot
.17429 .2784 Mdot
.17619 .27926 Mdot
.1781 .41359 Mdot
.18 .25274 Mdot
.1819 .29297 Mdot
.18381 .27208 Mdot
.18571 .44829 Mdot
.18762 .32098 Mdot
.18952 .36 Mdot
.19143 .36329 Mdot
.19333 .3787 Mdot
.19524 .33788 Mdot
.19714 .36606 Mdot
.19905 .45305 Mdot
.20095 .27992 Mdot
.20286 .36272 Mdot
.20476 .30082 Mdot
.20667 .44208 Mdot
.20857 .33012 Mdot
.21048 .37331 Mdot
.21238 .46561 Mdot
.21429 .37886 Mdot
.21619 .3579 Mdot
.2181 .37715 Mdot
.22 .42879 Mdot
.2219 .33899 Mdot
.22381 .40934 Mdot
.22571 .31797 Mdot
.22762 .35434 Mdot
.22952 .25672 Mdot
.23143 .27807 Mdot
.23333 .38855 Mdot
.23524 .31113 Mdot
.23714 .31389 Mdot
.23905 .41192 Mdot
.24095 .39397 Mdot
.24286 .35257 Mdot
.24476 .32564 Mdot
.24667 .33097 Mdot
.24857 .44053 Mdot
.25048 .43193 Mdot
.25238 .23572 Mdot
.25429 .35303 Mdot
.25619 .22372 Mdot
.2581 .32469 Mdot
.26 .33094 Mdot
.2619 .38971 Mdot
.26381 .32988 Mdot
.26571 .38357 Mdot
.26762 .41785 Mdot
.26952 .3088 Mdot
.27143 .31281 Mdot
.27333 .26658 Mdot
.27524 .33539 Mdot
.27714 .41362 Mdot
.27905 .37508 Mdot
.28095 .31856 Mdot
.28286 .29781 Mdot
.28476 .23657 Mdot
.28667 .36019 Mdot
.28857 .2766 Mdot
.29048 .44416 Mdot
.29238 .41791 Mdot
.29429 .29644 Mdot
.29619 .26636 Mdot
.2981 .27153 Mdot
.3 .37388 Mdot
.3019 .3786 Mdot
.30381 .44694 Mdot
.30571 .26878 Mdot
.30762 .25877 Mdot
.30952 .36298 Mdot
.31143 .23067 Mdot
.31333 .37483 Mdot
.31524 .33122 Mdot
.31714 .37894 Mdot
.31905 .31135 Mdot
.32095 .38809 Mdot
.32286 .23026 Mdot
.32476 .29067 Mdot
.32667 .43863 Mdot
.32857 .24313 Mdot
.33048 .23024 Mdot
.33238 .25486 Mdot
.33429 .27569 Mdot
.33619 .36744 Mdot
.3381 .41283 Mdot
.34 .27547 Mdot
.3419 .36596 Mdot
.34381 .44555 Mdot
.34571 .41512 Mdot
.34762 .30578 Mdot
.34952 .22982 Mdot
.35143 .37422 Mdot
.35333 .27241 Mdot
.35524 .32834 Mdot
.35714 .35798 Mdot
.35905 .27506 Mdot
.36095 .44509 Mdot
.36286 .43468 Mdot
.36476 .38551 Mdot
.36667 .31798 Mdot
.36857 .3316 Mdot
.37048 .23564 Mdot
.37238 .40374 Mdot
.37429 .27653 Mdot
.37619 .35645 Mdot
.3781 .26541 Mdot
.38 .40526 Mdot
.3819 .41314 Mdot
.38381 .41597 Mdot
.38571 .3759 Mdot
.38762 .30601 Mdot
.38952 .23875 Mdot
.39143 .37844 Mdot
.39333 .33488 Mdot
.39524 .2245 Mdot
.39714 .44748 Mdot
.39905 .31579 Mdot
.40095 .42281 Mdot
.40286 .36433 Mdot
.40476 .47258 Mdot
.40667 .32171 Mdot
.40857 .28323 Mdot
.41048 .28891 Mdot
.41238 .32219 Mdot
.41429 .35012 Mdot
.41619 .47697 Mdot
.4181 .3502 Mdot
.42 .29884 Mdot
.4219 .37731 Mdot
.42381 .31383 Mdot
.42571 .27223 Mdot
.42762 .3513 Mdot
.42952 .31019 Mdot
.43143 .32281 Mdot
.43333 .4153 Mdot
.43524 .2995 Mdot
.43714 .36178 Mdot
.43905 .33635 Mdot
.44095 .36432 Mdot
.44286 .26288 Mdot
.44476 .395 Mdot
.44667 .42749 Mdot
.44857 .33523 Mdot
.45048 .32615 Mdot
.45238 .4129 Mdot
.45429 .41533 Mdot
.45619 .32311 Mdot
.4581 .33008 Mdot
.46 .26143 Mdot
.4619 .27508 Mdot
.46381 .42034 Mdot
.46571 .22296 Mdot
.46762 .34227 Mdot
.46952 .31548 Mdot
.47143 .4757 Mdot
.47333 .35171 Mdot
.47524 .35102 Mdot
.47714 .22953 Mdot
.47905 .3168 Mdot
.48095 .32432 Mdot
.48286 .32669 Mdot
.48476 .3431 Mdot
.48667 .2326 Mdot
.48857 .34488 Mdot
.49048 .4188 Mdot
.49238 .36486 Mdot
.49429 .4204 Mdot
.49619 .31366 Mdot
.4981 .23394 Mdot
.5 .37289 Mdot
.5019 .36668 Mdot
.50381 .30401 Mdot
.50571 .32644 Mdot
.50762 .324 Mdot
.50952 .33374 Mdot
.51143 .23074 Mdot
.51333 .25537 Mdot
.51524 .33344 Mdot
.51714 .28243 Mdot
.51905 .30072 Mdot
.52095 .44402 Mdot
.52286 .35592 Mdot
.52476 .33909 Mdot
.52667 .35116 Mdot
.52857 .41562 Mdot
.53048 .32701 Mdot
.53238 .37093 Mdot
.53429 .38414 Mdot
.53619 .32654 Mdot
.5381 .33996 Mdot
.54 .39191 Mdot
.5419 .24744 Mdot
.54381 .39531 Mdot
.54571 .27073 Mdot
.54762 .27911 Mdot
.54952 .30981 Mdot
.55143 .23042 Mdot
.55333 .26748 Mdot
.55524 .30375 Mdot
.55714 .38359 Mdot
.55905 .35076 Mdot
.56095 .38596 Mdot
.56286 .31332 Mdot
.56476 .29854 Mdot
.56667 .27047 Mdot
.56857 .24207 Mdot
.57048 .43401 Mdot
.57238 .26019 Mdot
.57429 .28322 Mdot
.57619 .31705 Mdot
.5781 .40586 Mdot
.58 .36033 Mdot
.5819 .40911 Mdot
.58381 .41181 Mdot
.58571 .30652 Mdot
.58762 .43089 Mdot
.58952 .30547 Mdot
.59143 .30655 Mdot
.59333 .29609 Mdot
.59524 .22522 Mdot
.59714 .41425 Mdot
.59905 .42542 Mdot
.60095 .23288 Mdot
.60286 .29635 Mdot
.60476 .32148 Mdot
.60667 .32699 Mdot
.60857 .41882 Mdot
.61048 .37518 Mdot
.61238 .33005 Mdot
.61429 .37908 Mdot
.61619 .2495 Mdot
.6181 .26629 Mdot
.62 .30204 Mdot
.6219 .3703 Mdot
.62381 .34167 Mdot
.62571 .24077 Mdot
.62762 .32797 Mdot
.62952 .39274 Mdot
.63143 .30826 Mdot
.63333 .44343 Mdot
.63524 .32488 Mdot
.63714 .4004 Mdot
.63905 .27063 Mdot
.64095 .33632 Mdot
.64286 .34182 Mdot
.64476 .37884 Mdot
.64667 .26586 Mdot
.64857 .28313 Mdot
.65048 .33697 Mdot
.65238 .27616 Mdot
.65429 .2923 Mdot
.65619 .36212 Mdot
.6581 .43545 Mdot
.66 .23197 Mdot
.6619 .30255 Mdot
.66381 .27701 Mdot
.66571 .30523 Mdot
.66762 .32244 Mdot
.66952 .2572 Mdot
.67143 .36115 Mdot
.67333 .27707 Mdot
.67524 .25462 Mdot
.67714 .34406 Mdot
.67905 .47635 Mdot
.68095 .25138 Mdot
.68286 .27199 Mdot
.68476 .32963 Mdot
.68667 .44372 Mdot
.68857 .35129 Mdot
.69048 .36761 Mdot
.69238 .23949 Mdot
.69429 .25933 Mdot
.69619 .35424 Mdot
.6981 .29408 Mdot
.7 .42954 Mdot
.7019 .29607 Mdot
.70381 .39764 Mdot
.70571 .28304 Mdot
.70762 .33131 Mdot
.70952 .37877 Mdot
.71143 .36292 Mdot
.71333 .42993 Mdot
.71524 .35093 Mdot
.71714 .41855 Mdot
.71905 .4157 Mdot
.72095 .39633 Mdot
.72286 .35522 Mdot
.72476 .32106 Mdot
.72667 .33913 Mdot
.72857 .41696 Mdot
.73048 .44359 Mdot
.73238 .31804 Mdot
.73429 .40231 Mdot
.73619 .25398 Mdot
.7381 .38092 Mdot
.74 .3633 Mdot
.7419 .38403 Mdot
.74381 .32695 Mdot
.74571 .26552 Mdot
.74762 .24763 Mdot
.74952 .25621 Mdot
.75143 .27773 Mdot
.75333 .25788 Mdot
.75524 .38698 Mdot
.75714 .32106 Mdot
.75905 .24792 Mdot
.76095 .3924 Mdot
.76286 .30002 Mdot
.76476 .30595 Mdot
.76667 .37937 Mdot
.76857 .29763 Mdot
.77048 .39846 Mdot
.77238 .39013 Mdot
.77429 .27409 Mdot
.77619 .25634 Mdot
.7781 .28456 Mdot
.78 .34819 Mdot
.7819 .38928 Mdot
.78381 .41727 Mdot
.78571 .22358 Mdot
.78762 .40008 Mdot
.78952 .35269 Mdot
.79143 .47801 Mdot
.79333 .34087 Mdot
.79524 .27105 Mdot
.79714 .29676 Mdot
.79905 .28394 Mdot
.80095 .43803 Mdot
.80286 .42926 Mdot
.80476 .3509 Mdot
.80667 .26153 Mdot
.80857 .34963 Mdot
.81048 .30211 Mdot
.81238 .27208 Mdot
.81429 .36429 Mdot
.81619 .41352 Mdot
.8181 .2728 Mdot
.82 .32865 Mdot
.8219 .32208 Mdot
.82381 .36465 Mdot
.82571 .34212 Mdot
.82762 .34479 Mdot
.82952 .30831 Mdot
.83143 .2263 Mdot
.83333 .44461 Mdot
.83524 .29676 Mdot
.83714 .24319 Mdot
.83905 .35429 Mdot
.84095 .39244 Mdot
.84286 .24851 Mdot
.84476 .32013 Mdot
.84667 .29822 Mdot
.84857 .45633 Mdot
.85048 .31377 Mdot
.85238 .39754 Mdot
.85429 .34462 Mdot
.85619 .32342 Mdot
.8581 .4183 Mdot
.86 .41314 Mdot
.8619 .34943 Mdot
.86381 .24008 Mdot
.86571 .4748 Mdot
.86762 .25969 Mdot
.86952 .26588 Mdot
.87143 .28888 Mdot
.87333 .4162 Mdot
.87524 .26372 Mdot
.87714 .46513 Mdot
.87905 .2634 Mdot
.88095 .2433 Mdot
.88286 .28638 Mdot
.88476 .31512 Mdot
.88667 .32622 Mdot
.88857 .25825 Mdot
.89048 .44406 Mdot
.89238 .32893 Mdot
.89429 .29082 Mdot
.89619 .26998 Mdot
.8981 .38975 Mdot
.9 .38997 Mdot
.9019 .4022 Mdot
.90381 .36234 Mdot
.90571 .4205 Mdot
.90762 .25838 Mdot
.90952 .43387 Mdot
.91143 .32649 Mdot
.91333 .32623 Mdot
.91524 .29705 Mdot
.91714 .24763 Mdot
.91905 .37639 Mdot
.92095 .36959 Mdot
.92286 .3564 Mdot
.92476 .25158 Mdot
.92667 .35323 Mdot
.92857 .33194 Mdot
.93048 .23473 Mdot
.93238 .31044 Mdot
.93429 .31019 Mdot
.93619 .26726 Mdot
.9381 .28653 Mdot
.94 .32218 Mdot
.9419 .34205 Mdot
.94381 .24544 Mdot
.94571 .31488 Mdot
.94762 .30956 Mdot
.94952 .26903 Mdot
.95143 .43032 Mdot
.95333 .35526 Mdot
.95524 .38912 Mdot
.95714 .28042 Mdot
.95905 .26347 Mdot
.96095 .30012 Mdot
.96286 .36291 Mdot
.96476 .29402 Mdot
.96667 .25344 Mdot
.96857 .32556 Mdot
.97048 .41185 Mdot
.97238 .28559 Mdot
.97429 .34917 Mdot
.97619 .41341 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo04Oooooo0_l0000[ooooo`;o00005?ooool2o`0006Gooooo0_l00019ooooo`001_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo04Oooooo0_l0000[ooooo`;o00005?oo
ool2o`0002Sooooo0_l0000kooooo`;o00003Oooool2o`0003[ooooo0004o`0000;ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1Iooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o0000
9oooool2o`0000Wooooo0_l0000;ooooo`;o00003?ooool2o`0004[ooooo0_l0000jooooo`001_oo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8b
ooooo`04ooooo`?o00008_ooool2o`0003Gooooo0_l000001?oooooo0000o`000?ooool2o`0000Co
oooo0_l0000Wooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l0000;ooooo`;o
00003_ooool2o`00017ooooo0_l0001aooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool08_ooool2o`0002;ooooo0_l00008ooooo`;o00006_ooool2o`0002?ooooo0_l00002oooo
o`;o00007oooool2o`00017ooooo0_l0001Eooooo`;o00006_ooool000Kooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`16ooooo`;o00002?ooool2o`0001[ooooo0_l00004ooooo`;o0000Goooool2o`00
03Gooooo0_l0000Dooooo`;o00006_ooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo05kooooo0_l0000Booooo`;o0000=oooool2o`00017ooooo0_l0000Cooooo`;o0000;Oooool2
o`0000Kooooo0_l00004ooooo`;o0000:_ooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool02_oo
ool2o`0000?ooooo0_l00002ooooo`;o0000BOooool2o`0004_ooooo0_l0000Aooooo`;o0000@_oo
ool2o`0000cooooo0_l0000Booooo`;o00005_ooool002Wooooo0_l0000;ooooo`;o00000oooool2
o`000004ooooool0003o0000o`0000Sooooo0_l00024ooooo`;o00005_ooool2o`0002Sooooo0_l0
0002ooooo`;o00006Oooool2o`0001Kooooo0_l00006ooooo`;o00005_ooool002Wooooo0_l00009
ooooo`;o00002?ooool2o`0000Wooooo0_l0000?ooooo`;o0000Loooool2o`0001Kooooo0_l0000C
ooooo`;o00004oooool2o`0000;ooooo0_l0000Iooooo`;o00005_ooool4o`0001cooooo000Yoooo
o`;o00002Oooool2o`0002Cooooo0_l0000_ooooo`;o0000>Oooool2o`0003;ooooo1?l0000?oooo
o`;o0000>oooool2o`0000_ooooo0_l0000?ooooo`00:Oooool00ol0003oooooooooo`0<ooooo`;o
00003_ooool4o`0000[ooooo0_l0000Booooo`;o00006?ooool2o`0000Gooooo0_l0000iooooo`;o
0000<?ooool4o`00017ooooo0_l00003ooooo`?o00001Oooool2o`0002;ooooo0_l00004ooooo`;o
00004Oooool2o`0000oooooo000Yooooo`03o`000?oooooooooo00cooooo0ol0000=ooooo`Co0000
2_ooool2o`0001;ooooo0_l0000Hooooo`;o0000;oooool2o`0002;ooooo0_l0000Mooooo`;o0000
1_ooool2o`00013ooooo0ol00005ooooo`;o00002?ooool2o`0001;ooooo0_l00004ooooo`;o0000
1?ooool2o`0002;ooooo000Yooooo`;o00002oooool2o`000003ooooool0003o000007Cooooo0_l0
0004ooooo`;o00008_ooool2o`0002Gooooo0_l0000Rooooo`;o00004_ooool5o`0001Sooooo0_l0
000Aooooo`00:Oooool00ol0003oooooooooo`0:ooooo`;o0000@Oooool2o`0000Gooooo0_l0000H
ooooo`;o00004oooool2o`0002;ooooo0_l0000Booooo`;o00002?ooool2o`0001gooooo0_l0000V
ooooo`Go00004Oooool2o`0000Gooooo0_l0000Aooooo`00:Oooool00ol0003oooooooooo`0Uoooo
o`;o00002Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02Oooool2o`0000Gooooo0_l000000ooooooo0000o`00000Dooooo`Go
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0R
ooooo`;o000000Goooooo`000?l0003ooooooiRHV002o`000003oc8b<_o<c<cooooo00;ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_l0003o0000oc8b<_o^k^h00oooool2o`000003
ooooool0003o000001gooooo0_l00003ooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o
0000oc8b<_o^k^h00_l000001_ooooook^k^oc8b<_l0003o<S8bonk^kQ3ooooo0_l00007ooooo`;o
00002oooool2o`000006oooooom4A4Co0000o`000?lb<S;ogMgM0_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool00ol0003ooooooooo
o`0Uooooo`;o00002Oooool3o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL04?ooool2o`000003ooooool0003o000000gooooo0_l00005ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0_l00000
0oooooooV9RHogMgM`0Rooooo`;o00001?ooool01Ol@413o0000o`000?mgMgOo<S8b00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool2o`0000co
oooo0_l0000Hooooo`04o`000?ooooooooooooooo`;o000000CoV9RHoooooonHV9SoMgMg0_l00000
1?ooooooMgMgoiRHV?ooool4o`0001Oooooo0_l0000?ooooo`;o000000WoMgMgoc8b<_oooooooooo
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000Yoooo
o`04o`000?ooooooooooooooo`;o0000;Oooool3o`0000Cooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41003Oooool2o`000003ooooool0003o000000[ooooo
1?l00002ooooo`Co00000oooool2o`000003ob4Q8Oo^k^kooooo00?ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`;o00000_ooool00ol@413oooooooooo`05ooooo`;o00008oooool01Ol0003o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooo
oooo00Gooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Eooooo`Go00000_oo
ool2o`0000?ooooo00Go410@oooooooooooooooooa0@4002ooooo`Co0000:oooool01?l0003ooooo
ooooool@4103ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`01oooo
o`00:Oooool2o`0000;ooooo0ol0000Yooooo`;o00000oooool00ol0003oooooooooo`03o`0000?o
oooo00Co0000oooooooooooooooo0_l00002ooooo`03o`000?oooooooooo00_ooooo0_l0000=oooo
o`Co00001?ooool2o`0000?ooooo0_l000000onHV9So8B4Qonk^kP03ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000Oooooo0_l0000Jooooo`;o00001_oo
ool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000Oooooo0_l00002ooooo`;o000000?oooooo`000?l000005oooool2o`000003
omgMgOoooooo000000Cooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool00000;?ooool2o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool002Wooooo0ol00002ooooo`;o00004_ooool2o`00017ooooo0_l0
0002ooooo`;o00000oooool00ol0003oooooooooo`03o`0000?ooooo00Co0000oooooooooooooooo
0_l00002ooooo`03o`000?oooooooooo02[ooooo00?oMgMgofIVI_ooool00_ooool00ol0003ooooo
ooooo`02o`0000?ooooo00Go0000ooooooooooooooooo`00000Iooooo`;o00002?ooool2o`0000Go
oooo00?o410@o`000?l000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000006ooooo`;o00004Oooool2o`0000cooooo0_l000000omEEEGoooooo`000004
ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000?ooooo00?o0000ooooooooool09ooo
ool00ol0003o8B4Qo`000002o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000oooool002Wooooo0ol0000Fooooo`?o00004?ooool2o`0000Oooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooooooooa0@400]ooooo`05o`000?ooooooooooooooool@41000_ooool2o`0000?ooooo00Go410@
oooooooooooooooooa0@400Iooooo`;o00004?ooool2o`0000?ooooo00Go410@oooooooooooooooo
oa0@4003ooooo`05oa0@4?ooooooooooooooool@41001_ooool2o`00017ooooo0_l0000>ooooo`03
ogMgMoo<c<co000000Cooooo0_l00002ooooo`03oa0@4?oooooooooo00;o00000oooool00ol@413o
ooooooooo`0Booooo`;o00004?ooool2o`000003ooooool0003ooooo00Gooooo00Go410@o`000?l0
003ooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool002Wooooo00?o0000oooo
ooooool05oooool2o`0001Wooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Yooooo`05o`000?nj^[[ooooooiRHV?l@4100
0oooool01?mgMgOoV9RHoooooonHV9P2o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Xoooo
o`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0Yooooo`03onk^k_m4A4Co000000Cooooo0_l000000oooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04Oooool2o`000003ooooool0003o0000013o
oooo0_l000000ooooooo0000ooooo`05ooooo`05ogMgMol0003o0000oiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo000Yooooo`03o`000?oooooooooo02oooooo0_l000000omV
IVKo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^01Wooooo0_l0000>ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01?o^k^ko<S8b
o`000?lb<S82o`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Xooooo`05ojVYZOl@413o0000
oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP08ooooo`;o00008?ooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^017ooooo0_l00005ooooo`;o00003oooool4o`00
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool002Wooooo0_l0000Xooooo`;o00001_ooool2o`0002cooooo0_l0001Dooooo`;o000000?ooooo
o`000?l000003oooool2o`0000cooooo0ol0000looooo`;o00005Oooool2o`0000oooooo000Yoooo
o`03o`000?oooooooooo02Oooooo0_l0000Wooooo`;o000000?oooooo`000?l000009oooool2o`00
02cooooo0_l00007ooooo`;o000000?oooooo`000?l000007Oooool3o`0001Cooooo0_l00007oooo
o`;o00002_ooool2o`0000;ooooo0_l0000Dooooo`;o00003_ooool2o`0000oooooo000Yooooo`03
o`000?oooooooooo03Kooooo0_l0000Hooooo`;o000000?oooooo`000?l000009oooool2o`0000?o
oooo0_l0000Iooooo`;o00003?ooool2o`00013ooooo0_l0000;ooooo`;o00007oooool4o`0000Oo
oooo0_l00002ooooo`;o00001_ooool2o`0000;ooooo0_l0000Dooooo`;o00003Oooool2o`00013o
oooo000Yooooo`03o`000?oooooooooo01Cooooo0_l0000Pooooo`;o0000BOooool2o`0001Cooooo
0_l00003ooooo`;o00002Oooool2o`0000Wooooo0_l00008ooooo`;o00002oooool4o`0001gooooo
0_l0000=ooooo`;o0000;oooool2o`00013ooooo000Yooooo`03o`000?oooooooooo01Cooooo0_l0
000Eooooo`;o00007_ooool2o`0001Oooooo0_l0000;ooooo`;o00009?ooool2o`0000kooooo0_l0
0008ooooo`Co00002oooool2o`0000Wooooo0_l0000Nooooo`;o00004_ooool2o`0003_ooooo000Q
oooooooo0000A?l00004ooooo`00:Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Sooooo0ol0000;ooooo`?o00001Oooool2o`0000;ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`03ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`;o00001Oooool00ol0
003oooooooooo`05ooooo`;o00000_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool00_ooool4o`0000?ooooo00?o0000ooooooooool02Oooool01?l0
003oooooooooooooool2o`0000Kooooo00?o0000ooooooooool01_ooool2o`0000;ooooo0ol00009
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Gooooo0_l00003ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool01_ooool4o`000003ooooool0003o000000Sooooo00?o0000ooooooooool02_ooool0
02Wooooo00Co0000ooooool0003o00004oooool2o`0001Kooooo0_l0000<ooooo`03o`000?oooooo
oooo00;o00000_ooool2o`0000Wooooo0_l0000Mooooo`;o00002?ooool2o`000003ooooool0003o
oooo00?ooooo0_l0000=ooooo`;o000000?oooooo`000?l000000oooool2o`0001Cooooo0_l00002
ooooo`;o00001Oooool00ol0003oooooooooo`0Xooooo`;o00004?ooool00ol0003oooooooooo`0A
ooooo`;o00002Oooool2o`0001;ooooo0_l00008ooooo`03o`000?oooooooooo00[ooooo000Yoooo
o`04o`000?oooooo0000o`0001Sooooo0_l0000=ooooo`;o00000_ooool2o`0000?ooooo0_l0000:
ooooo`;o00004?ooool2o`0001[ooooo0_l00008ooooo`;o00005Oooool2o`000003ooooool0003o
000001gooooo0_l0000^ooooo`Co00001_ooool2o`0001[ooooo0_l0000;ooooo`;o0000:Oooool0
02Wooooo00?o0000ooooooooool06Oooool3o`0000Cooooo0_l00006ooooo`;o00001oooool2o`00
01cooooo0_l0000Vooooo`Co00001?ooool2o`0000Kooooo0_l00006ooooo`;o00001oooool2o`00
01gooooo0_l0000Booooo`;o00004Oooool2o`0000Sooooo0_l0000Cooooo`;o00001Oooool2o`00
00;ooooo0_l0000Iooooo`;o00005oooool002Wooooo0_l0000Kooooo`;o00001?ooool2o`00027o
oooo0_l00003ooooo`;o0000;Oooool4o`0000Cooooo0_l00004ooooo`Co00001_ooool3o`0000Go
oooo0ol00005ooooo`Co00005?ooool3o`0000Oooooo0_l00008ooooo`;o00005oooool2o`0001Oo
oooo0_l00009ooooo`;o00002?ooool2o`0000Kooooo0_l00007ooooo`;o00001oooool2o`0000ko
oooo000Yooooo`03o`000?oooooooooo02?ooooo0_l0000Cooooo`;o00002Oooool2o`0000?ooooo
0ol0000Looooo`;o00007?ooool2o`000003ooooool0003o000000Kooooo0_l00005ooooo`;o0000
1_ooool4o`0001Gooooo1?l00002ooooo`;o000000?oooooo`000?l000003_ooool2o`00017ooooo
0_l0000Fooooo`;o00005?ooool4o`0000Cooooo0_l0000@ooooo`;o00003_ooool002Wooooo00?o
0000ooooooooool01_ooool2o`0000Wooooo0_l0000@ooooo`;o00004oooool2o`0000[ooooo0_l0
0002ooooo`?o00003oooool2o`0000_ooooo0_l00002ooooo`;o00006oooool2o`00013ooooo0_l0
000Nooooo`;o00000_ooool2o`00017ooooo0_l00005ooooo`;o00008_ooool2o`0001Kooooo0_l0
0009ooooo`;o00006oooool002Wooooo00?o0000ooooooooool01Oooool3o`0000Wooooo0_l0000a
ooooo`;o00000_ooool2o`0000?ooooo0_l0000;ooooo`;o00003oooool2o`0000Kooooo0_l0000=
ooooo`;o000000?oooooo`000?l000004Oooool4o`0002Oooooo0_l0000Cooooo`;o0000AOooool2
o`0001_ooooo000Yooooo`03o`000?oooooooooo00Gooooo0_l00007ooooo`;o00005_ooool2o`00
00_ooooo0_l00007ooooo`;o00003oooool2o`0002Cooooo0_l0000=ooooo`;o000000?oooooo`00
0?l000004Oooool2o`0000?ooooo0_l0000Tooooo`;o000000?oooooo`000?l000005_ooool2o`00
05cooooo000Yooooo`;o00003oooool2o`0001Kooooo0_l0000;ooooo`;o00001oooool2o`0004go
oooo0_l0000@ooooo`;o00000oooool2o`0001Wooooo0_l00004ooooo`;o000000?oooooo`000?l0
00005_ooool2o`0001Cooooo0_l00008ooooo`;o00008oooool2o`0001Oooooo000Yooooo`03o`00
0?oooooooooo02;ooooo0_l0001Wooooo`;o00000oooool4o`0000kooooo0_l0000Iooooo`;o0000
1?ooool2o`0000Wooooo0_l0000Tooooo`;o00002?ooool3o`0000Kooooo0_l0000Jooooo`;o0000
5oooool002Wooooo00?o0000ooooooooool00oooool2o`0001gooooo0_l0001/ooooo`Co0000>_oo
ool2o`0001oooooo0_l0000>ooooo`;o00001_ooool2o`0002Gooooo0_l0000<ooooo`00:Oooool0
0ol0003oooooooooo`03ooooo`;o00002?ooool2o`0000cooooo0_l0001Mooooo`?o000000?ooooo
o`000?l000003Oooool2o`0000oooooo0_l00008ooooo`;o0000:?ooool2o`0000Oooooo0_l0000B
ooooo`;o00001_ooool4o`0000oooooo0_l0000Rooooo`;o00003?ooool002Wooooo00?o0000oooo
ooooool03Oooool2o`0000Wooooo0_l000000ooooooo0000o`00000Qooooo`;o00000oooool2o`00
0003ooooool0003o000003;ooooo0ol000000ooooooo0000o`00000=ooooo`;o00003oooool2o`00
00Sooooo0_l0000Xooooo`Co00001Oooool4o`0001?ooooo0_l00003ooooo`Co00001oooool2o`00
00Kooooo0_l0000Cooooo`;o00001_ooool2o`0001?ooooo000Yooooo`Co00000oooool2o`00017o
oooo0ol0000Pooooo`;o00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`00000Oooooo`;o
00001Oooool2o`0002gooooo0_l0000eooooo`;o00001oooool2o`0001?ooooo0_l0000>ooooo`;o
00006Oooool4o`0000Kooooo0_l0000Cooooo`00:Oooool01?l0003oooooo`000?l00003ooooo`;o
00000oooool2o`0000cooooo0_l0000Iooooo`;o00001_ooool2o`0001Gooooo0_l0000Dooooo`;o
00001Oooool2o`0002gooooo0_l0000@ooooo`;o00007?ooool2o`0004kooooo0_l0000Mooooo`00
:Oooool00ol0003oooooooooo`07ooooo`Co00007Oooool2o`0000Sooooo0_l00002ooooo`;o0000
6Oooool2o`0000Gooooo0_l0000Looooo`;o00002Oooool3o`0002_ooooo0_l0000Gooooo`;o0000
0oooool2o`0000[ooooo0_l00008ooooo`;o00005Oooool2o`0000;ooooo0_l0000Gooooo`;o0000
4Oooool2o`00013ooooo000Yooooo`03o`000?oooooooooo00;o00001Oooool4o`0000[ooooo0_l0
000Aooooo`;o00002?ooool6o`00023ooooo0_l00007ooooo`Co00004Oooool2o`0000Wooooo0ol0
000?ooooo`;o000000?oooooo`000?l00000<?ooool2o`0000Wooooo0_l00004ooooo`;o00002?oo
ool2o`0001Gooooo0_l00002ooooo`;o00005oooool2o`00017ooooo0_l0000@ooooo`00:Oooool0
0ol0003oooooooooo`02o`0000[ooooo0_l00007ooooo`;o00007Oooool2o`0002_ooooo1?l0000^
ooooo`;o000000?oooooo`000?l000002?ooool2o`0001_ooooo0_l0000Dooooo`;o0000B?ooool2
o`0001gooooo000Yooooo`;o00002?ooool2o`0000?ooooo0_l0000>ooooo`;o00006_ooool2o`00
01_ooooo0_l0000nooooo`;o00002Oooool2o`0001_ooooo0_l0001Nooooo`;o00007Oooool002Wo
oooo0_l00008ooooo`;o00000_ooool2o`0000oooooo0_l00002ooooo`;o00005_ooool2o`000003
ooooool0003o0000017ooooo0_l00005ooooo`;o00000_ooool2o`0000_ooooo0_l00009ooooo`;o
00008_ooool2o`0002;ooooo0_l0001Qooooo`;o00007_ooool000Kooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo00_ooooo0_l00002ooooo`;o00002Oooool2o`0000Cooooo0_l0000Aoooo
o`;o00001Oooool3o`00017ooooo0_l00006ooooo`;o000000?oooooo`000?l000000_l00009oooo
o`;o00002Oooool3o`0000Sooooo0_l0000kooooo`?o00002?ooool2o`0001?ooooo0_l0000@oooo
o`;o0000;oooool2o`0001kooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool03oooool2o`0000Wooooo0_l0000Gooooo`;o00001Oooool2o`0001[ooooo0_l00003
ooooo`;o00005Oooool2o`0000Sooooo0_l0000looooo`;o00002?ooool2o`0001?ooooo0_l00007
ooooo`;o00001oooool2o`0004oooooo0006ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0B_ooool2
o`0001kooooo0_l0000dooooo`;o00001_ooool3o`0003Oooooo0ol0001Gooooo`001_ooool01Ol0
003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04
ooooo`?o00006?ooool2o`0000gooooo0_l0000Gooooo`;o00002?ooool2o`00013ooooo0_l0000<
ooooo`;o0000=?ooool2o`0000Kooooo0ol0000hooooo`;o00000_ooool2o`0000Oooooo0_l0000f
ooooo`;o00004_ooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKo
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo01Sooooo0_l0
000=ooooo`;o00005oooool2o`0000Oooooo0_l0000Aooooo`;o0000A?ooool2o`0001_ooooo0_l0
000Vooooo`Co00000_ooool2o`000003ooooool0003o0000017ooooo0_l0000@ooooo`?o00004?oo
ool2o`0001;ooooo0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08Oooool2o`0001oooooo0_l0
0005ooooo`;o0000>Oooool2o`0001cooooo0ol0000Jooooo`;o0000:?ooool2o`0000;ooooo0_l0
000Dooooo`;o00004?ooool3o`0002Cooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Qooooo`;o00007oooool2o`00043ooooo0_l0000Mooooo`;o0000<_ooool2o`0000?ooooo
0_l0000>ooooo`;o00006Oooool2o`0003?ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo0<7o
oooo0_l0000Dooooo`;o00000oooool2o`0000kooooo0_l00004ooooo`;o00004oooool2o`0003?o
oooo000Yooooo`;o00004oooool2o`0005Sooooo0_l0001Cooooo`;o00007_ooool2o`0000oooooo
0_l0000Sooooo`;o00008oooool002Wooooo00?o0000ooooooooool04_ooool2o`0005Sooooo0_l0
00000ooooooo0000o`00000mooooo`;o0000<Oooool2o`0003Cooooo0_l0000Sooooo`00:Oooool0
0ol0003oooooooooo`0mooooo`;o0000<?ooool2o`0003gooooo1?l0002:ooooo`00:Oooool00ol0
003oooooooooo`02ooooo`;o0000:_ooool2o`0000gooooo0_l00002ooooo`;o00002oooool2o`00
017ooooo0_l0000<ooooo`;o00005Oooool2o`0002Sooooo0_l00003ooooo`;o0000A?ooool2o`00
00cooooo0_l0000Rooooo`Co00002oooool002Wooooo00?o0000ooooooooool00_ooool2o`0000co
oooo0_l0000Looooo`;o00004Oooool2o`0000_ooooo0_l0000Aooooo`;o000000?oooooo`000?l0
00002Oooool3o`0000kooooo0_l00004ooooo`?o00005_ooool2o`0000oooooo0_l00003ooooo`;o
00009Oooool2o`000003ooooool0003o0000013ooooo0_l00008ooooo`;o00003?ooool2o`0000;o
oooo0_l0000Nooooo`Co00002oooool002Wooooo0_l0000Aooooo`;o00000oooool2o`0003Cooooo
0_l00006ooooo`;o00003oooool2o`0000[ooooo0_l0000>ooooo`;o00001Oooool2o`000003oooo
ool0003o000000Kooooo1?l00009ooooo`;o00005oooool2o`00027ooooo0ol000000ooooooo0000
o`00000@ooooo`;o00005_ooool2o`0000;ooooo0_l00009ooooo`;o00008_ooool002Wooooo00?o
0000ooooooooool01Oooool2o`0000kooooo0_l0000dooooo`;o00001_ooool2o`00027ooooo0_l0
000Booooo`;o00001_ooool4o`0002;ooooo0_l0000Qooooo`;o0000;?ooool2o`0000gooooo0_l0
000Rooooo`00:Oooool00ol0003oooooooooo`05ooooo`;o0000Koooool2o`0003gooooo0_l00025
ooooo`00:Oooool00ol0003oooooooooo`04ooooo`;o00007oooool2o`0001Cooooo0_l00017oooo
o`;o0000;oooool2o`0001oooooo0_l00002ooooo`;o00006oooool2o`0004?ooooo000Yooooo`03
o`000?oooooooooo00Cooooo0_l0000Oooooo`;o00005?ooool2o`0000Sooooo0_l0000mooooo`;o
0000;?ooool2o`0002;ooooo0_l00002ooooo`;o00006oooool2o`0002kooooo0_l0000Cooooo`00
:Oooool2o`0004Kooooo0_l0000Rooooo`;o0000@Oooool2o`0000Cooooo0_l0000Dooooo`;o0000
Coooool2o`0000cooooo0_l0000Cooooo`00:Oooool00ol0003oooooooooo`0Oooooo`;o0000?Ooo
ool2o`0000Wooooo0_l00011ooooo`;o00006_ooool2o`0002cooooo0_l0000Qooooo`;o00008Ooo
ool002Wooooo00?o0000ooooooooool07oooool2o`0001Kooooo0_l0000<ooooo`;o00005oooool2
o`0009Kooooo0_l00014ooooo`00:Oooool01?l0003oooooooooooooool2o`0001cooooo0_l00003
ooooo`;o00004Oooool2o`0000cooooo0_l0000;ooooo`;o00003oooool2o`0000Cooooo0_l0000a
ooooo`;o00008_ooool2o`0000oooooo0_l0000<ooooo`;o00008?ooool2o`00013ooooo0_l0000W
ooooo`00:Oooool01?l0003oooooooooooooool2o`0000gooooo0_l0000Booooo`;o00002_ooool2
o`00023ooooo0_l00002ooooo`;o00002oooool2o`0000Cooooo0_l00009ooooo`;o00009_ooool2
o`0002;ooooo0_l0000?ooooo`;o00003?ooool2o`00023ooooo0_l0000@ooooo`;o00009oooool0
02Wooooo0_l0000Aooooo`;o00007_ooool2o`0002Cooooo0_l0000Looooo`;o0000a_ooool002Wo
oooo00?o0000ooooooooool0=Oooool2o`000?oooooo1_ooool000kooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0=Oooool2o`000<kooooo0_l0000eooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0ooooool6oooo
o`;o0000=Oooool000kooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo
00?ooooo0ol0003oooooocgooooo000>ooooo`05o`000?ooooooooooooooool000003oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo03Wooooo0_l0003Dooooo`;o0000:oooool000ko
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`0Mooooo`;o00003?ooool2o`0000cooooo0_l0003Dooooo`;o0000:oooool0
00kooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool07Oooool2o`0000cooooo0_l0001:ooooo`;o0000`oooool000kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Moooool2
o`0001?ooooo0_l00011ooooo`;o0000>_ooool2o`0002oooooo000>ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0001kooooo`;o00004?ooool2o`00047ooooo0_l0000R
ooooo`;o00005_ooool2o`0002oooooo000Yooooo`03o`000?oooooooooo07[ooooo0_l0001goooo
o`;o0000Aoooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03
o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omE
EEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmoooo
o`001_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0
003oooooooooo`03ooooo`?o0000oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo0000
00kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
0?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool0
00Kooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool5o`0000Cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooo
oolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooo
oolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool001oooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oo
oooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo
000Qooooo`03o`000?oooooooooo00Gooooo0ol0003oooooocgooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001oooooo00?o
EEEEofIVI_l00000oooooom7ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .39909 Mdot
.02762 .3407 Mdot
.02952 .28098 Mdot
.03143 .26327 Mdot
.03333 .30626 Mdot
.03524 .29165 Mdot
.03714 .31425 Mdot
.03905 .44549 Mdot
.04095 .33697 Mdot
.04286 .26232 Mdot
.04476 .30536 Mdot
.04667 .45095 Mdot
.04857 .26107 Mdot
.05048 .27387 Mdot
.05238 .44775 Mdot
.05429 .34294 Mdot
.05619 .37045 Mdot
.0581 .27046 Mdot
.06 .31188 Mdot
.0619 .41707 Mdot
.06381 .27028 Mdot
.06571 .27419 Mdot
.06762 .25206 Mdot
.06952 .28755 Mdot
.07143 .43534 Mdot
.07333 .32943 Mdot
.07524 .33806 Mdot
.07714 .32532 Mdot
.07905 .40732 Mdot
.08095 .33571 Mdot
.08286 .29849 Mdot
.08476 .34073 Mdot
.08667 .42656 Mdot
.08857 .37643 Mdot
.09048 .32569 Mdot
.09238 .41882 Mdot
.09429 .26525 Mdot
.09619 .35023 Mdot
.0981 .39418 Mdot
.1 .45253 Mdot
.1019 .43484 Mdot
.10381 .3576 Mdot
.10571 .24568 Mdot
.10762 .39873 Mdot
.10952 .39658 Mdot
.11143 .36536 Mdot
.11333 .2595 Mdot
.11524 .2792 Mdot
.11714 .24959 Mdot
.11905 .41078 Mdot
.12095 .2716 Mdot
.12286 .35905 Mdot
.12476 .4815 Mdot
.12667 .28185 Mdot
.12857 .26408 Mdot
.13048 .38792 Mdot
.13238 .44642 Mdot
.13429 .37106 Mdot
.13619 .23071 Mdot
.1381 .39212 Mdot
.14 .36691 Mdot
.1419 .2705 Mdot
.14381 .39138 Mdot
.14571 .33094 Mdot
.14762 .41694 Mdot
.14952 .36859 Mdot
.15143 .27097 Mdot
.15333 .33343 Mdot
.15524 .34828 Mdot
.15714 .31189 Mdot
.15905 .38177 Mdot
.16095 .2796 Mdot
.16286 .26078 Mdot
.16476 .30793 Mdot
.16667 .39155 Mdot
.16857 .30919 Mdot
.17048 .48153 Mdot
.17238 .36215 Mdot
.17429 .3748 Mdot
.17619 .25356 Mdot
.1781 .3773 Mdot
.18 .34308 Mdot
.1819 .26008 Mdot
.18381 .35089 Mdot
.18571 .42737 Mdot
.18762 .3461 Mdot
.18952 .31587 Mdot
.19143 .33772 Mdot
.19333 .36117 Mdot
.19524 .33545 Mdot
.19714 .43341 Mdot
.19905 .38287 Mdot
.20095 .33003 Mdot
.20286 .35475 Mdot
.20476 .33644 Mdot
.20667 .3612 Mdot
.20857 .26812 Mdot
.21048 .2715 Mdot
.21238 .48374 Mdot
.21429 .3671 Mdot
.21619 .39746 Mdot
.2181 .34002 Mdot
.22 .44928 Mdot
.2219 .39344 Mdot
.22381 .35957 Mdot
.22571 .3723 Mdot
.22762 .38207 Mdot
.22952 .28102 Mdot
.23143 .32908 Mdot
.23333 .31369 Mdot
.23524 .25572 Mdot
.23714 .26117 Mdot
.23905 .3343 Mdot
.24095 .423 Mdot
.24286 .44542 Mdot
.24476 .28582 Mdot
.24667 .366 Mdot
.24857 .39296 Mdot
.25048 .37264 Mdot
.25238 .28184 Mdot
.25429 .25834 Mdot
.25619 .31851 Mdot
.2581 .23954 Mdot
.26 .40412 Mdot
.2619 .31559 Mdot
.26381 .27679 Mdot
.26571 .42155 Mdot
.26762 .31986 Mdot
.26952 .37928 Mdot
.27143 .32874 Mdot
.27333 .25008 Mdot
.27524 .39085 Mdot
.27714 .45014 Mdot
.27905 .30713 Mdot
.28095 .24328 Mdot
.28286 .38692 Mdot
.28476 .27751 Mdot
.28667 .41557 Mdot
.28857 .26403 Mdot
.29048 .43546 Mdot
.29238 .44853 Mdot
.29429 .22371 Mdot
.29619 .27845 Mdot
.2981 .33624 Mdot
.3 .37119 Mdot
.3019 .42181 Mdot
.30381 .41553 Mdot
.30571 .39283 Mdot
.30762 .27874 Mdot
.30952 .3487 Mdot
.31143 .34015 Mdot
.31333 .33073 Mdot
.31524 .3552 Mdot
.31714 .29459 Mdot
.31905 .27158 Mdot
.32095 .34125 Mdot
.32286 .31002 Mdot
.32476 .38159 Mdot
.32667 .38948 Mdot
.32857 .26699 Mdot
.33048 .30247 Mdot
.33238 .27574 Mdot
.33429 .37329 Mdot
.33619 .4373 Mdot
.3381 .40917 Mdot
.34 .25052 Mdot
.3419 .39763 Mdot
.34381 .41029 Mdot
.34571 .37675 Mdot
.34762 .35121 Mdot
.34952 .3051 Mdot
.35143 .41806 Mdot
.35333 .32447 Mdot
.35524 .35404 Mdot
.35714 .31165 Mdot
.35905 .2606 Mdot
.36095 .42538 Mdot
.36286 .34823 Mdot
.36476 .33441 Mdot
.36667 .27363 Mdot
.36857 .40354 Mdot
.37048 .3323 Mdot
.37238 .44949 Mdot
.37429 .33337 Mdot
.37619 .43063 Mdot
.3781 .31091 Mdot
.38 .32371 Mdot
.3819 .3127 Mdot
.38381 .34026 Mdot
.38571 .44076 Mdot
.38762 .24129 Mdot
.38952 .35153 Mdot
.39143 .42193 Mdot
.39333 .30486 Mdot
.39524 .29541 Mdot
.39714 .43665 Mdot
.39905 .40994 Mdot
.40095 .45042 Mdot
.40286 .34625 Mdot
.40476 .42475 Mdot
.40667 .37566 Mdot
.40857 .27062 Mdot
.41048 .26772 Mdot
.41238 .28943 Mdot
.41429 .29151 Mdot
.41619 .43887 Mdot
.4181 .39509 Mdot
.42 .26234 Mdot
.4219 .31322 Mdot
.42381 .26077 Mdot
.42571 .27576 Mdot
.42762 .31636 Mdot
.42952 .23525 Mdot
.43143 .36386 Mdot
.43333 .37772 Mdot
.43524 .3421 Mdot
.43714 .39708 Mdot
.43905 .36546 Mdot
.44095 .43567 Mdot
.44286 .30372 Mdot
.44476 .38049 Mdot
.44667 .45303 Mdot
.44857 .36662 Mdot
.45048 .23239 Mdot
.45238 .36842 Mdot
.45429 .39017 Mdot
.45619 .34356 Mdot
.4581 .26161 Mdot
.46 .35263 Mdot
.4619 .32666 Mdot
.46381 .44796 Mdot
.46571 .30252 Mdot
.46762 .32952 Mdot
.46952 .28197 Mdot
.47143 .43821 Mdot
.47333 .28051 Mdot
.47524 .33935 Mdot
.47714 .33651 Mdot
.47905 .35323 Mdot
.48095 .38787 Mdot
.48286 .23988 Mdot
.48476 .39354 Mdot
.48667 .27181 Mdot
.48857 .2601 Mdot
.49048 .40025 Mdot
.49238 .38161 Mdot
.49429 .34911 Mdot
.49619 .3367 Mdot
.4981 .32592 Mdot
.5 .33172 Mdot
.5019 .38109 Mdot
.50381 .38883 Mdot
.50571 .41564 Mdot
.50762 .28206 Mdot
.50952 .30052 Mdot
.51143 .30852 Mdot
.51333 .32786 Mdot
.51524 .35343 Mdot
.51714 .24584 Mdot
.51905 .31346 Mdot
.52095 .44158 Mdot
.52286 .25054 Mdot
.52476 .26285 Mdot
.52667 .33899 Mdot
.52857 .39849 Mdot
.53048 .31614 Mdot
.53238 .32067 Mdot
.53429 .39569 Mdot
.53619 .26562 Mdot
.5381 .25641 Mdot
.54 .42008 Mdot
.5419 .30034 Mdot
.54381 .42157 Mdot
.54571 .25271 Mdot
.54762 .26176 Mdot
.54952 .24688 Mdot
.55143 .31318 Mdot
.55333 .32705 Mdot
.55524 .25043 Mdot
.55714 .28545 Mdot
.55905 .31216 Mdot
.56095 .33415 Mdot
.56286 .39472 Mdot
.56476 .33055 Mdot
.56667 .32853 Mdot
.56857 .2688 Mdot
.57048 .44821 Mdot
.57238 .27503 Mdot
.57429 .27349 Mdot
.57619 .25406 Mdot
.5781 .4222 Mdot
.58 .35725 Mdot
.5819 .36276 Mdot
.58381 .31079 Mdot
.58571 .22938 Mdot
.58762 .44656 Mdot
.58952 .2297 Mdot
.59143 .31763 Mdot
.59333 .23008 Mdot
.59524 .32252 Mdot
.59714 .41726 Mdot
.59905 .44738 Mdot
.60095 .35871 Mdot
.60286 .24701 Mdot
.60476 .24354 Mdot
.60667 .38797 Mdot
.60857 .34651 Mdot
.61048 .43825 Mdot
.61238 .26887 Mdot
.61429 .27908 Mdot
.61619 .31718 Mdot
.6181 .29955 Mdot
.62 .23555 Mdot
.6219 .37539 Mdot
.62381 .24814 Mdot
.62571 .35482 Mdot
.62762 .29526 Mdot
.62952 .38718 Mdot
.63143 .36887 Mdot
.63333 .42506 Mdot
.63524 .32187 Mdot
.63714 .44832 Mdot
.63905 .3802 Mdot
.64095 .22771 Mdot
.64286 .31003 Mdot
.64476 .31433 Mdot
.64667 .34655 Mdot
.64857 .37665 Mdot
.65048 .26849 Mdot
.65238 .27586 Mdot
.65429 .31948 Mdot
.65619 .38105 Mdot
.6581 .45156 Mdot
.66 .31762 Mdot
.6619 .33691 Mdot
.66381 .24297 Mdot
.66571 .33004 Mdot
.66762 .29085 Mdot
.66952 .34881 Mdot
.67143 .28189 Mdot
.67333 .24957 Mdot
.67524 .27622 Mdot
.67714 .28004 Mdot
.67905 .47711 Mdot
.68095 .32084 Mdot
.68286 .3591 Mdot
.68476 .3303 Mdot
.68667 .41042 Mdot
.68857 .3309 Mdot
.69048 .41782 Mdot
.69238 .32059 Mdot
.69429 .30502 Mdot
.69619 .36093 Mdot
.6981 .22412 Mdot
.7 .45136 Mdot
.7019 .2299 Mdot
.70381 .42032 Mdot
.70571 .25092 Mdot
.70762 .37808 Mdot
.70952 .41936 Mdot
.71143 .30164 Mdot
.71333 .45105 Mdot
.71524 .23556 Mdot
.71714 .40362 Mdot
.71905 .45012 Mdot
.72095 .44707 Mdot
.72286 .43079 Mdot
.72476 .31275 Mdot
.72667 .26336 Mdot
.72857 .44818 Mdot
.73048 .44377 Mdot
.73238 .31763 Mdot
.73429 .34449 Mdot
.73619 .32471 Mdot
.7381 .32036 Mdot
.74 .39834 Mdot
.7419 .28711 Mdot
.74381 .38886 Mdot
.74571 .24355 Mdot
.74762 .34772 Mdot
.74952 .2599 Mdot
.75143 .23582 Mdot
.75333 .2578 Mdot
.75524 .44204 Mdot
.75714 .42727 Mdot
.75905 .26091 Mdot
.76095 .35366 Mdot
.76286 .26839 Mdot
.76476 .40294 Mdot
.76667 .35822 Mdot
.76857 .31942 Mdot
.77048 .44847 Mdot
.77238 .31618 Mdot
.77429 .27797 Mdot
.77619 .29517 Mdot
.7781 .35092 Mdot
.78 .34533 Mdot
.7819 .29363 Mdot
.78381 .38019 Mdot
.78571 .30421 Mdot
.78762 .44855 Mdot
.78952 .38037 Mdot
.79143 .46945 Mdot
.79333 .37975 Mdot
.79524 .26362 Mdot
.79714 .25129 Mdot
.79905 .27618 Mdot
.80095 .44955 Mdot
.80286 .45057 Mdot
.80476 .33605 Mdot
.80667 .31185 Mdot
.80857 .34756 Mdot
.81048 .34368 Mdot
.81238 .3827 Mdot
.81429 .3519 Mdot
.81619 .40991 Mdot
.8181 .27113 Mdot
.82 .35505 Mdot
.8219 .32446 Mdot
.82381 .33692 Mdot
.82571 .37858 Mdot
.82762 .35068 Mdot
.82952 .2633 Mdot
.83143 .32964 Mdot
.83333 .43486 Mdot
.83524 .30978 Mdot
.83714 .31368 Mdot
.83905 .38201 Mdot
.84095 .35954 Mdot
.84286 .31128 Mdot
.84476 .35398 Mdot
.84667 .39874 Mdot
.84857 .38715 Mdot
.85048 .38289 Mdot
.85238 .46836 Mdot
.85429 .39587 Mdot
.85619 .27403 Mdot
.8581 .34867 Mdot
.86 .44771 Mdot
.8619 .31118 Mdot
.86381 .32183 Mdot
.86571 .47843 Mdot
.86762 .30489 Mdot
.86952 .29755 Mdot
.87143 .25363 Mdot
.87333 .39805 Mdot
.87524 .26539 Mdot
.87714 .40737 Mdot
.87905 .29398 Mdot
.88095 .31182 Mdot
.88286 .35958 Mdot
.88476 .33752 Mdot
.88667 .28925 Mdot
.88857 .31463 Mdot
.89048 .4454 Mdot
.89238 .31185 Mdot
.89429 .38265 Mdot
.89619 .35886 Mdot
.8981 .39362 Mdot
.9 .42203 Mdot
.9019 .34513 Mdot
.90381 .37957 Mdot
.90571 .32325 Mdot
.90762 .28734 Mdot
.90952 .45218 Mdot
.91143 .41588 Mdot
.91333 .2655 Mdot
.91524 .22982 Mdot
.91714 .30592 Mdot
.91905 .3587 Mdot
.92095 .41854 Mdot
.92286 .39743 Mdot
.92476 .30177 Mdot
.92667 .36182 Mdot
.92857 .37685 Mdot
.93048 .26713 Mdot
.93238 .24195 Mdot
.93429 .30674 Mdot
.93619 .25604 Mdot
.9381 .25009 Mdot
.94 .31093 Mdot
.9419 .31641 Mdot
.94381 .28678 Mdot
.94571 .24215 Mdot
.94762 .26707 Mdot
.94952 .34099 Mdot
.95143 .37085 Mdot
.95333 .3017 Mdot
.95524 .39173 Mdot
.95714 .34204 Mdot
.95905 .32847 Mdot
.96095 .3247 Mdot
.96286 .45146 Mdot
.96476 .32428 Mdot
.96667 .34485 Mdot
.96857 .23253 Mdot
.97048 .41173 Mdot
.97238 .34398 Mdot
.97429 .41133 Mdot
.97619 .45118 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo05?ooooo0_l00020ooooo`;o0000IOooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`1Cooooo`;o0000K_ooool2o`00013ooooo0_l0001Uooooo`001?l00002
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool08?ooool2o`0008oooooo1?l0000>ooooo`;o00004Ooo
ool2o`0004?ooooo0_l0000Oooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o00008?ooool2o`0006?ooooo0_l0
000Zooooo`Co00008Oooool2o`0004?ooooo0_l0000?ooooo`;o00003_ooool000Kooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`03o`000?oooooooooo07oooooo0_l00004ooooo`;o0000=Oooool2o`0001gooooo
0_l00009ooooo`;o0000A?ooool2o`0000kooooo0006ooooo`05oa0@4?ooooooooooooooool@4100
3oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
B?ooool2o`0003Gooooo0_l0000?ooooo`;o0000:_ooool2o`0001gooooo0_l00009ooooo`;o0000
E?ooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@
41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Sooooo0_l00005ooooo`;o
00008?ooool2o`0001gooooo0_l0000hooooo`;o0000E?ooool2o`0000?ooooo0_l0000Eooooo`00
1_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co00001_ooool00ol0003oooooooooo`0Gooooo`;o0000=_ooool2o`00023ooooo0_l0000Xoooo
o`;o00006_ooool2o`00017ooooo0_l0000Hooooo`;o0000>_ooool2o`0000?ooooo0_l0000Eoooo
o`00:Oooool2o`0001Sooooo0_l000000ooooooo0000o`00001oooooo`;o00002?ooool2o`0000oo
oooo0ol00004ooooo`;o00003_ooool2o`0001Gooooo0_l0001Fooooo`00:Oooool00ol0003ooooo
ooooo`0:ooooo`;o00003_ooool2o`00037ooooo0_l0000Cooooo`;o0000>Oooool2o`0000Gooooo
1Ol0000=ooooo`;o00001Oooool2o`0000kooooo0_l00009ooooo`;o00006oooool2o`0002_ooooo
0_l0000Hooooo`00:Oooool00ol0003oooooooooo`0:ooooo`;o00008Oooool2o`00017ooooo0_l0
000;ooooo`;o00004oooool2o`0003Wooooo0_l00005ooooo`;o000000?oooooo`000?l000001Ooo
ool2o`0002Sooooo0_l0000Kooooo`;o00005_ooool2o`0001?ooooo0_l0000Hooooo`00:Oooool0
0ol0003oooooooooo`0]ooooo`;o00004Oooool2o`0000Cooooo0_l0001Jooooo`;o00002_ooool2
o`0003Oooooo0_l0000Tooooo`;o00004oooool2o`0001Sooooo000Yooooo`03o`000?oooooooooo
00Cooooo0_l0000Cooooo`;o00003_ooool2o`0000Cooooo0_l0000@ooooo`;o00000oooool2o`00
023ooooo0_l0000Cooooo`;o00002Oooool2o`0000Sooooo0_l0000>ooooo`;o000000?oooooo`00
0?l00000?oooool5o`0003Oooooo0_l0000Hooooo`00:Oooool4o`000003ooooool0003o000000;o
00003Oooool2o`0000Cooooo0_l00003ooooo`;o00002Oooool2o`0000Cooooo0_l0000@ooooo`;o
00003_ooool2o`0001Gooooo0_l0000Booooo`?o00002Oooool2o`0000Sooooo0_l00009ooooo`;o
00001_ooool2o`0003Oooooo0_l00006ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Wo
oooo0_l0000kooooo`00:Oooool01Ol0003oooooo`000?l0003ooooo00;o00003oooool2o`0000Wo
oooo0_l0000Hooooo`;o00005oooool2o`0000_ooooo0_l0000Iooooo`;o000000?oooooo`000?l0
00007oooool2o`0000;ooooo0_l0000kooooo`;o00002_ooool2o`0000Sooooo0_l00009ooooo`;o
00003Oooool2o`0000[ooooo0_l00004ooooo`;o00000oooool2o`0001Gooooo000Yooooo`03o`00
0?oooooooooo00Oooooo1?l0000Gooooo`;o000000?oooooo`000?l000002Oooool4o`000004oa0@
4?ooooooooooonk^kP;o000000?o<S8bonk^k_ooool00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01[ooooo0_l0000=ooooo`Go00000oooool00oo^k^ko<S8bo`000003o`0000;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Oooooo`;o00001oooool01OnHV9So0000o`000?lb<S;oc<c<00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`?o000000?o<S8bonk^k_ooool01_ooool2o`00027ooooo
0ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00;o00004?ooool2o`0000[ooooo0_l00004ooooo`;o00000oooool3o`000009oc8b<_oMgMgooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00
:Oooool00ol0003oooooooooo`05ooooo`Oo00004?ooool2o`0000Cooooo0_l000000ooooooo0000
o`00000;ooooo`03o`000?oooooooooo00;ooooo00GoMgMgo`000?l0003oV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL05oooool2o`0000kooooo0_l000001OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00?oMgMgoiRHV?ooool00_l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03ooo
ool2o`0001Oooooo00?o410@o`000?l000000_l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool2o`000003oooooonHV9SoMgMg00Oooooo0_l0000Rooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_l0000:oooo
o`;o00007_ooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool002Wooooo00?o0000ooooooooool01Oooool2o`0000?ooooo
0_l0000@ooooo`;o00005?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@00Gooooo0_l00005ooooo`;o00002Oooool2o`00
00;ooooo0_l0000:ooooo`;o000000CooooooiRHV?lQ8B7ok^k^1?ooool01Ol@413ooooooooooooo
oooo410@00?ooooo0_l00002ooooo`03oa0@4?oooooooooo00gooooo0_l0000Jooooo`;o00000ooo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4007ooooo`;o
00001_ooool2o`0001Oooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41000_ooool2o`00
00?ooooo00?o410@ooooooooool02_ooool2o`0001oooooo00Co0000oooooooooooo410@0oooool0
1Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool00Oooool002Wooooo0_l0000K
ooooo`;o00003?ooool2o`0000Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000005ooooo`;o00001Oooool2o`0000;ooooo
0_l00002ooooo`;o00001Oooool2o`0000kooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooo
oooooooooooo000000?ooooo0_l00002ooooo`03o`000?oooooooooo00Wooooo0_l0000Nooooo`;o
00000oooool01Ol0003ooooooooooooooooo000000?ooooo0_l00002ooooo`03o`000?oooooooooo
00Gooooo0_l00006ooooo`;o00005oooool01?m4A4CogMgMooooool00003ooooo`;o00000oooool0
0ol0003oooooooooo`02o`0000?ooooo00?o0000ooooooooool0:_ooool01OmgMgOo<S8boooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo007ooooo
000Yooooo`?o00006_ooool2o`000003ooooool0003o000000Wooooo0_l00008ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`;o00000oooool00ol0003ooooo
ooooo`02o`0000cooooo0_l00002ooooo`;o00005_ooool00omgMgOoIVIVooooo`02ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000[ooooo0ol00009oooo
o`;o00004_ooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000000oooool2
o`0000;ooooo00?o0000ooooooooool03?ooool3o`0001Oooooo00CogMgMoeEEEOoooooo00000ooo
ool2o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo02Oooooo
00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo000Yooooo`?o00007Oooool2o`0001?ooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00;ooooo0_l00003ooooo`;o000000?ooooo
o`000?l00000:Oooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooo
oa0@4003ooooo`03oa0@4?oooooooooo00Sooooo0_l0000:ooooo`;o00003_ooool2o`0000?ooooo
00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooooooooa0@400>ooooo`;o00006Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41000oooool01Ol@413ooooooooooooooooo410@02Sooooo0_l00006ooooo`05oa0@4?oo
ooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo000Yooooo`03o`00
0?oooooooooo00_ooooo0_l0000Uooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`04ogMgMonHV9SooooooiRHV0;o0000:?ooool01Ol0003o^[ZjoooooonHV9So
410@00?ooooo00CoMgMgoiRHV?ooooooV9RH0_l00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
9_ooool2o`000005oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Tooooo`;o00000oooool00oo^k^koA4A4o`000004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01Kooooo
0_l00004ooooo`;o00002_ooool2o`0000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wooooo00?o0000ooooooooool00_l00009ooooo`;o
00008oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`04onk^k_lb
<S;o0000oc8b<P?o000000Koooooonk^k_lb<S;o0000oc8b<_o^k^hXooooo`05ojVYZOl@413o0000
oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`;o00005_ooool2o`0000Cooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Fooooo`;o00001?ooool2o`00
00_ooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo000Yooooo`;o000000?oooooo`000?l00000FOooool2o`0001Oooooo0_l00004
ooooo`;o0000@_ooool2o`0000_ooooo0_l0000Qooooo`Co00007Oooool2o`0002_ooooo000Yoooo
o`03o`000?oooooooooo00oooooo0_l0001:ooooo`;o00005oooool2o`0004Sooooo0_l0000^oooo
o`Co00006_ooool2o`000003ooooool0003o000002_ooooo000Yooooo`03o`000?oooooooooo00oo
oooo0_l0001>ooooo`;o0000:Oooool2o`0000cooooo0_l00009ooooo`;o00005_ooool2o`0001co
oooo0_l0000aooooo`;o00004?ooool2o`0000Oooooo0_l0000Cooooo`00:Oooool00ol0003ooooo
ooooo`03ooooo`;o0000F_ooool2o`0000Cooooo0_l0000<ooooo`;o00003_ooool2o`0000Gooooo
0_l0000<ooooo`;o00002Oooool2o`0001Kooooo0_l0000Gooooo`;o00000oooool2o`0001Kooooo
0_l0000Iooooo`;o00004?ooool2o`0000Oooooo0_l0000Cooooo`00:Oooool01?l0003oooooo`00
0?l00002ooooo`;o00009Oooool2o`0002;ooooo0_l0000Eooooo`;o00003?ooool2o`0000kooooo
0_l0000Dooooo`;o0000>Oooool2o`0001_ooooo0_l0000Iooooo`;o00003_ooool2o`0000?ooooo
0_l0000Iooooo`008Oooooooo`0004Co00001?ooool002Wooooo00Co0000oooooooooooooooo0_l0
0005ooooo`;o00003?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo0_l0
0002ooooo`;o000000?oooooo`000?ooool02_ooool00ol0003oooooooooo`03ooooo`;o00001Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo0_l000000ooooooo0000oooo
o`06ooooo`;o00000_ooool00ol0003oooooooooo`03o`0000Oooooo00Co0000oooooooooooooooo
0_l00006ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool2o`0000Sooooo
1?l00006ooooo`;o00000oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo000000;o0000
1oooool00ol0003oooooooooo`0:ooooo`04o`000?ooooooooooooooo`;o00001_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03o`000?oooooooooo00Go
00001?ooool2o`0000Cooooo1_l000000ooooooo0000ooooo`0:ooooo`;o00002_ooool00ol0003o
ooooooooo`0:ooooo`00:Oooool01?l0003oooooooooooooool2o`0002oooooo0_l00006ooooo`03
o`000?oooooooooo00?ooooo0_l00007ooooo`;o00009?ooool2o`0000Oooooo00Co0000oooooooo
oooooooo1?l0000Looooo`;o000000?oooooo`000?l000001Oooool4o`0000Wooooo0ol00005oooo
o`;o00001oooool2o`0000?ooooo0_l0000Cooooo`Co00002oooool2o`0000?ooooo00?o0000oooo
ooooool03Oooool2o`0000kooooo0_l0000?ooooo`;o00002_ooool00ol0003oooooooooo`0:oooo
o`00:Oooool00ol0003oooooooooo`0booooo`;o00004oooool6o`00037ooooo0_l0000Oooooo`?o
00004Oooool2o`0000Kooooo0_l0000:ooooo`Co00001Oooool2o`000003ooooool0003o000000_o
oooo1?l00008ooooo`?o0000=?ooool2o`0001Oooooo000Yooooo`03o`000?oooooooooo04Oooooo
0_l00002ooooo`;o00008_ooool2o`0002oooooo0_l0000Booooo`;o00002oooool2o`0000Cooooo
0_l00007ooooo`;o000000?oooooo`000?l000003Oooool2o`0000Sooooo0_l0000Looooo`;o0000
3?ooool2o`00017ooooo0_l0000?ooooo`00:Oooool2o`0000kooooo0_l00003ooooo`;o0000D_oo
ool2o`0000Oooooo0_l0000Hooooo`;o00002_ooool2o`00013ooooo0_l0000;ooooo`;o00002ooo
ool2o`0001kooooo0_l0000Jooooo`;o00002oooool2o`0000cooooo0_l0000@ooooo`?o00003ooo
ool002Wooooo00?o0000ooooooooool03?ooool3o`0000?ooooo0_l0000Qooooo`;o00002?ooool2
o`0000_ooooo0_l0000Hooooo`;o00008Oooool4o`0000Sooooo0_l00003ooooo`;o00002oooool2
o`000004ooooool0003o0000o`0001kooooo0_l00004ooooo`;o00003_ooool2o`0001[ooooo0_l0
00000ooooooo0000o`00000Wooooo`?o00004?ooool002Wooooo00?o0000ooooooooool03?ooool2
o`0001Gooooo0_l000000ooooooo0000o`00000=ooooo`;o00002?ooool2o`0000_ooooo0_l0000;
ooooo`;o00004Oooool3o`0001cooooo0_l00008ooooo`;o00000oooool2o`0000kooooo0ol0000N
ooooo`;o00001?ooool3o`0002cooooo0_l0000Wooooo`;o00004Oooool002Wooooo00?o0000oooo
ooooool03oooool2o`0001;ooooo0_l000000ooooooo0000o`00000;ooooo`;o000000?oooooo`00
0?l000002Oooool2o`00017ooooo0_l00003ooooo`;o00003oooool5o`0001oooooo0_l00004oooo
o`?o00004_ooool2o`0002Oooooo0_l0000Sooooo`;o0000@oooool002Wooooo00?o0000oooooooo
ool00_ooool2o`0000Wooooo1?l0000Qooooo`?o000000?oooooo`000?l000002Oooool2o`00017o
oooo0_l0000Dooooo`;o00008Oooool3o`0000Cooooo0_l00008ooooo`;o00002Oooool2o`0001ko
oooo0_l0000/ooooo`;o00001Oooool2o`00017ooooo0_l0000Yooooo`00:Oooool2o`0000?ooooo
0_l00002ooooo`;o00001Oooool2o`000003ooooool0003o0000023ooooo0_l00007ooooo`;o0000
7?ooool2o`000003ooooool0003o000001;ooooo0_l0000?ooooo`;o00002_ooool2o`0000oooooo
0_l0000Yooooo`;o0000<oooool2o`00017ooooo0_l0000Cooooo`Co00004_ooool002Wooooo0_l0
0007ooooo`;o00002?ooool2o`0001cooooo0_l000000ooooooo0000o`000008ooooo`;o00007?oo
ool2o`000003ooooool0003o000001;ooooo0_l0000?ooooo`;o00001?ooool2o`0005Sooooo0_l0
000<ooooo`;o00002?ooool2o`0001cooooo0_l0000=ooooo`Co000000?oooooo`000?l000000_l0
000=ooooo`00:Oooool00ol0003oooooooooo`0Wooooo`;o00001Oooool2o`000003ooooool0003o
000002Gooooo0_l0000?ooooo`;o00002oooool2o`0000oooooo0_l0000;ooooo`;o00008_ooool2
o`0000_ooooo0_l00005ooooo`;o00004oooool2o`0000;ooooo0_l00008ooooo`;o00002?ooool2
o`0000kooooo0_l0000<ooooo`;o00004_ooool4o`0000gooooo000Yooooo`03o`000?oooooooooo
01Cooooo0_l0000Aooooo`;o00001oooool2o`0002Kooooo0_l0000:ooooo`;o00000oooool2o`00
00Oooooo0_l00002ooooo`;o00007?ooool2o`0002;ooooo0_l0000;ooooo`;o00001Oooool2o`00
01Oooooo0_l00008ooooo`;o00002?ooool3o`0000?ooooo0_l00008ooooo`;o0000<Oooool002Wo
oooo00?o0000ooooooooool05?ooool2o`0001[ooooo0_l00004ooooo`;o00008_ooool2o`0000So
oooo0_l000000ooooooo0000o`000009ooooo`;o00005Oooool2o`0000Cooooo0_l00009ooooo`;o
00008_ooool2o`0002Wooooo0_l00004ooooo`;o00002Oooool4o`000003ooooool0003o000000?o
oooo0_l0000fooooo`00:Oooool2o`0001Oooooo0_l0000Nooooo`;o00008_ooool2o`0000_ooooo
0_l0000Pooooo`;o00001?ooool2o`0000Wooooo0_l0000Cooooo`;o00003Oooool2o`0002Wooooo
1?l0000?ooooo`;o00001_ooool2o`0003Kooooo000Yooooo`03o`000?oooooooooo01Kooooo0_l0
0004ooooo`;o00005Oooool2o`0000;ooooo0_l00004ooooo`;o0000L?ooool2o`0000Gooooo0_l0
000Hooooo`;o00000_ooool2o`0001Gooooo0_l0000Fooooo`;o00002oooool2o`0000?ooooo0_l0
0005ooooo`;o00007_ooool002Wooooo00?o0000ooooooooool07?ooool2o`0000kooooo0_l00005
ooooo`;o00000_ooool2o`0000Cooooo0_l00010ooooo`;o0000;oooool2o`0000Cooooo0_l0000H
ooooo`;o00000_ooool2o`0002gooooo0_l0000;ooooo`;o00000oooool2o`0000Gooooo0_l00000
0ooooooo0000o`00000Kooooo`00:Oooool00ol0003oooooooooo`0Hooooo`;o00002?ooool2o`00
00Sooooo0_l0000<ooooo`;o00002?ooool2o`0003Wooooo0_l000001?oooooo0000o`000?ooool2
o`0002Wooooo0_l0001]ooooo`;o00006oooool002Wooooo00?o0000ooooooooool01oooool2o`00
00oooooo0_l00008ooooo`;o000000?oooooo`000?l000004oooool2o`0000Sooooo0_l0000loooo
o`;o000000Coooooo`000?l0003o0000>?ooool2o`0006Gooooo0_l0000Cooooo`00:Oooool2o`00
00Sooooo0_l0000Gooooo`;o00000oooool2o`0001Kooooo0_l00006ooooo`;o00003_ooool2o`00
00Wooooo0_l0000Tooooo`;o0000>?ooool2o`0006Gooooo0_l0000Cooooo`00:Oooool00ol0003o
ooooooooo`0Aooooo`;o00003Oooool2o`0000_ooooo0_l0000>ooooo`;o00001_ooool2o`0000ko
oooo0_l00009ooooo`;o00000_ooool2o`00017ooooo0_l00014ooooo`;o00001_ooool2o`0005So
oooo0_l0000Kooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go
00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool04Oooool2o`00
01[ooooo0ol0000Kooooo`;o00005oooool2o`00017ooooo0_l00007ooooo`;o0000>oooool2o`00
00?ooooo0_l000000ooooooo0000o`00000Aooooo`;o00005oooool2o`000003ooooool0003o0000
00Sooooo0_l0000Gooooo`;o00001_ooool2o`0001_ooooo0006ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0:?ooool2o`0000Cooooo0_l00005ooooo`;o00001oooool2
o`0000_ooooo0_l0000@ooooo`;o00008Oooool2o`0000;ooooo0_l0000=ooooo`;o000000?ooooo
o`000?l00000:_ooool2o`0000Cooooo0_l0000>ooooo`;o00005oooool5o`0000Cooooo0_l00002
ooooo`;o00000_ooool2o`0000;ooooo0_l0000<ooooo`;o000000?oooooo`000?l000008oooool0
00Kooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Xooooo`;o00002oooool2o`0000Oooooo0_l0000M
ooooo`;o00009Oooool2o`0000gooooo0_l000000ooooooo0000o`00000`ooooo`;o0000:?ooool2
o`0000Kooooo0_l00006ooooo`;o00000_ooool2o`0000cooooo0_l0000Vooooo`001_ooool01Ol0
003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04
ooooo`?o00007oooool2o`0002oooooo0_l0000<ooooo`;o0000;oooool2o`0000Kooooo0_l0000O
ooooo`;o00001Oooool2o`0002?ooooo0_l0000Oooooo`;o0000=Oooool000Kooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo01oooooo1_l00005ooooo`;o00008Oooool2o`000003ooooool0
003o000000cooooo0_l0000Wooooo`;o00001_ooool2o`0000Kooooo0_l0000Oooooo`;o00001Ooo
ool2o`0002?ooooo0_l0000Oooooo`;o00008Oooool2o`0001;ooooo0006ooooo`05oa0@4?oooooo
ooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool05?ooool2o`0000_ooooo1?l00005ooooo`;o00004?ooool2o`0000Oooooo0_l0
0006ooooo`;o00002?ooool2o`0002;ooooo0_l0000:ooooo`;o00001oooool2o`0000kooooo0_l0
0008ooooo`;o0000Foooool2o`0000cooooo0_l0000Aooooo`;o00004_ooool000Kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo01Cooooo0_l000001?oooooo0000o`000?l0000Pooooo`Co
00001oooool2o`00013ooooo0_l0000:ooooo`;o00005_ooool2o`0000Cooooo0_l0000=ooooo`;o
00003Oooool3o`0000Sooooo0_l0000gooooo`;o00008?ooool4o`0000Cooooo0_l00006ooooo`;o
00001_ooool2o`0001gooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So
410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o00006?ooool3o`00023ooooo0_l0000Woooo
o`;o00007?ooool2o`0000oooooo0_l0000;ooooo`;o0000@_ooool2o`00023ooooo0_l00006oooo
o`;o00003_ooool2o`0001gooooo000Yooooo`;o0000BOooool2o`00027ooooo0_l0000Uooooo`;o
0000Aoooool2o`0000kooooo0_l0001?ooooo`00:Oooool00ol0003oooooooooo`0>ooooo`;o0000
>?ooool2o`00027ooooo0_l0001^ooooo`;o00003_ooool2o`0002;ooooo0_l0000[ooooo`00:Ooo
ool00ol0003oooooooooo`0>ooooo`;o00002oooool2o`0004Cooooo1?l0000@ooooo`;o0000F_oo
ool2o`0002Sooooo0_l0000Booooo`;o00007Oooool2o`0000cooooo000Yooooo`03o`000?oooooo
oooo01_ooooo0_l00014ooooo`Co00004?ooool2o`0005[ooooo0_l0000Xooooo`;o0000<?ooool3
o`0000cooooo000Yooooo`03o`000?oooooooooo00Wooooo0_l0000Iooooo`;o0000:oooool2o`00
00?ooooo0_l0000oooooo`;o00007?ooool2o`0006?ooooo0_l0000Aooooo`;o00003Oooool002Wo
oooo0_l0000:ooooo`;o00001oooool2o`00013ooooo0_l0000[ooooo`;o00000oooool2o`0000ko
oooo0_l0000_ooooo`;o00002Oooool2o`00017ooooo0_l0000Looooo`;o00000_ooool4o`0003oo
oooo0_l000000ooooooo0000o`00000Mooooo`00:Oooool00ol0003oooooooooo`0Booooo`;o0000
;_ooool2o`0000Kooooo0_l0000:ooooo`;o00003_ooool2o`0000[ooooo0_l0000^ooooo`?o0000
2Oooool2o`0002?ooooo0_l00002ooooo`Co0000>oooool2o`0000Gooooo0_l0000Mooooo`00:Ooo
ool00ol0003oooooooooo`0@ooooo`;o0000<?ooool2o`0000Kooooo0_l0000:ooooo`;o00004Ooo
ool2o`0000Oooooo0_l00003ooooo`;o0000:_ooool2o`0000Wooooo0_l0000@ooooo`;o0000E?oo
ool2o`0002Cooooo000Yooooo`03o`000?oooooooooo013ooooo0_l0000Nooooo`;o0000=oooool2
o`0000cooooo0_l00017ooooo`;o00009_ooool2o`0005;ooooo000Yooooo`03o`000?oooooooooo
033ooooo0_l0000looooo`;o0000KOooool2o`0000Wooooo0_l0001Booooo`00:Oooool2o`0000go
oooo0_l00007ooooo`;o00007Oooool2o`0001cooooo0_l0000Jooooo`;o00004_ooool2o`0005Wo
oooo0_l0000Rooooo`;o0000>Oooool002Wooooo00?o0000ooooooooool03?ooool2o`0000Oooooo
0_l0000Mooooo`;o00007?ooool2o`0000gooooo0_l0000Aooooo`;o00001?ooool2o`0000Kooooo
0_l00008ooooo`;o0000:oooool2o`0004Kooooo0_l0000iooooo`00:Oooool00ol0003ooooooooo
o`1Qooooo`;o00003_ooool2o`000003ooooool0003o000000Cooooo0_l0000@ooooo`;o00003_oo
ool2o`0001_ooooo0_l0000/ooooo`;o0000Doooool002Wooooo00Co0000oooooooooooooooo0_l0
0010ooooo`;o0000;?ooool2o`0002Wooooo0_l00011ooooo`;o00001_ooool2o`0002[ooooo0_l0
000Wooooo`00:Oooool01?l0003oooooooooooooool2o`0000;ooooo0_l0000Hooooo`;o00008_oo
ool2o`0000kooooo0_l0000eooooo`;o00008?ooool2o`0000Cooooo0_l000000ooooooo0000o`00
000:ooooo`;o00006Oooool2o`000003ooooool0003o000000_ooooo0_l00004ooooo`;o00005Ooo
ool2o`0000Sooooo0_l0000Wooooo`00:Oooool2o`0000Gooooo0ol0000Hooooo`;o00006_ooool2
o`00017ooooo0_l00003ooooo`;o00005oooool2o`0000Sooooo0_l0000Booooo`;o00008?ooool2
o`0000Cooooo0_l000000ooooooo0000o`00000:ooooo`;o00001Oooool2o`0000cooooo0_l00002
ooooo`Co000000?oooooo`000?l000002oooool2o`0000Cooooo0_l00002ooooo`?o00004?ooool2
o`0001oooooo0_l00003ooooo`;o00002oooool002Wooooo00?o0000ooooooooool01?ooool2o`00
00oooooo0_l0000Tooooo`;o00004Oooool2o`0001cooooo0_l00008ooooo`;o00003?ooool2o`00
04;ooooo0_l0000<ooooo`;o00000_ooool4o`0001Sooooo0ol0000Pooooo`;o00003oooool2o`00
00?ooooo0_l0000;ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Eooooo`;o0000KOooool2
o`0009?ooooo0_l0000Qooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Ol@
413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool0
00kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0??ooooo0_l0000Booooo`;o0000<ooo
ool000kooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0loooool2o`0001;ooooo0_l0000cooooo`003_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo000>
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0003@ooooo`;o0000>_oo
ool2o`0002oooooo000Yooooo`03o`000?oooooooooo01gooooo0_l0000<ooooo`;o0000X_ooool2
o`0003[ooooo0_l0000_ooooo`00:Oooool00ol0003oooooooooo`0Mooooo`;o00003?ooool2o`00
00cooooo0_l0003oooooo`;ooooo000Yooooo`03o`000?oooooooooo03Wooooo0_l0003oooooo`;o
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo
00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo?Oooool0
00Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@
413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03
ooooo`?o0000oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Q
ooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool0
00Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@
oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo
1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
01oooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo?Oooool0027o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`00
0?oooooooooo00Gooooo0ol0003oooooocgooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001oooooo00?oEEEEofIVI_l00000
oooooom7ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .37568 Mdot
.02762 .39611 Mdot
.02952 .30994 Mdot
.03143 .28311 Mdot
.03333 .24987 Mdot
.03524 .24216 Mdot
.03714 .31315 Mdot
.03905 .39718 Mdot
.04095 .23586 Mdot
.04286 .32251 Mdot
.04476 .25431 Mdot
.04667 .42472 Mdot
.04857 .25254 Mdot
.05048 .26444 Mdot
.05238 .42448 Mdot
.05429 .30576 Mdot
.05619 .3174 Mdot
.0581 .24545 Mdot
.06 .35492 Mdot
.0619 .42322 Mdot
.06381 .24618 Mdot
.06571 .36275 Mdot
.06762 .34344 Mdot
.06952 .23746 Mdot
.07143 .45144 Mdot
.07333 .36904 Mdot
.07524 .27923 Mdot
.07714 .35648 Mdot
.07905 .42667 Mdot
.08095 .39354 Mdot
.08286 .23579 Mdot
.08476 .2376 Mdot
.08667 .35716 Mdot
.08857 .37177 Mdot
.09048 .37802 Mdot
.09238 .38584 Mdot
.09429 .36667 Mdot
.09619 .34692 Mdot
.0981 .42493 Mdot
.1 .4366 Mdot
.1019 .45457 Mdot
.10381 .38352 Mdot
.10571 .32371 Mdot
.10762 .39207 Mdot
.10952 .35558 Mdot
.11143 .32794 Mdot
.11333 .28318 Mdot
.11524 .23443 Mdot
.11714 .28477 Mdot
.11905 .42271 Mdot
.12095 .23845 Mdot
.12286 .4176 Mdot
.12476 .44366 Mdot
.12667 .35805 Mdot
.12857 .34674 Mdot
.13048 .28993 Mdot
.13238 .40117 Mdot
.13429 .3178 Mdot
.13619 .29278 Mdot
.1381 .34199 Mdot
.14 .33956 Mdot
.1419 .38269 Mdot
.14381 .42394 Mdot
.14571 .28488 Mdot
.14762 .34137 Mdot
.14952 .26255 Mdot
.15143 .33045 Mdot
.15333 .28102 Mdot
.15524 .35115 Mdot
.15714 .23469 Mdot
.15905 .34974 Mdot
.16095 .27534 Mdot
.16286 .31989 Mdot
.16476 .34558 Mdot
.16667 .42393 Mdot
.16857 .27761 Mdot
.17048 .44385 Mdot
.17238 .35835 Mdot
.17429 .423 Mdot
.17619 .32566 Mdot
.1781 .29181 Mdot
.18 .39584 Mdot
.1819 .30865 Mdot
.18381 .38371 Mdot
.18571 .35701 Mdot
.18762 .32179 Mdot
.18952 .25175 Mdot
.19143 .26896 Mdot
.19333 .29442 Mdot
.19524 .28534 Mdot
.19714 .45133 Mdot
.19905 .26589 Mdot
.20095 .33445 Mdot
.20286 .29746 Mdot
.20476 .3227 Mdot
.20667 .24242 Mdot
.20857 .26976 Mdot
.21048 .23893 Mdot
.21238 .45241 Mdot
.21429 .3059 Mdot
.21619 .38759 Mdot
.2181 .26199 Mdot
.22 .42032 Mdot
.2219 .39844 Mdot
.22381 .26478 Mdot
.22571 .37719 Mdot
.22762 .36035 Mdot
.22952 .34347 Mdot
.23143 .33522 Mdot
.23333 .23505 Mdot
.23524 .29238 Mdot
.23714 .28728 Mdot
.23905 .23424 Mdot
.24095 .40259 Mdot
.24286 .48883 Mdot
.24476 .26781 Mdot
.24667 .35159 Mdot
.24857 .29603 Mdot
.25048 .2669 Mdot
.25238 .37746 Mdot
.25429 .25519 Mdot
.25619 .41309 Mdot
.2581 .28606 Mdot
.26 .42786 Mdot
.2619 .23524 Mdot
.26381 .26714 Mdot
.26571 .41008 Mdot
.26762 .22174 Mdot
.26952 .40031 Mdot
.27143 .2957 Mdot
.27333 .34176 Mdot
.27524 .39686 Mdot
.27714 .43721 Mdot
.27905 .24008 Mdot
.28095 .29039 Mdot
.28286 .42665 Mdot
.28476 .37631 Mdot
.28667 .42152 Mdot
.28857 .32391 Mdot
.29048 .37731 Mdot
.29238 .42971 Mdot
.29429 .32098 Mdot
.29619 .33029 Mdot
.2981 .35708 Mdot
.3 .31905 Mdot
.3019 .41558 Mdot
.30381 .33468 Mdot
.30571 .4693 Mdot
.30762 .341 Mdot
.30952 .28604 Mdot
.31143 .42592 Mdot
.31333 .25365 Mdot
.31524 .32974 Mdot
.31714 .23546 Mdot
.31905 .2853 Mdot
.32095 .2559 Mdot
.32286 .39478 Mdot
.32476 .42334 Mdot
.32667 .29111 Mdot
.32857 .36774 Mdot
.33048 .39085 Mdot
.33238 .34767 Mdot
.33429 .42305 Mdot
.33619 .45771 Mdot
.3381 .35607 Mdot
.34 .33121 Mdot
.3419 .37984 Mdot
.34381 .32559 Mdot
.34571 .28929 Mdot
.34762 .34721 Mdot
.34952 .39283 Mdot
.35143 .41246 Mdot
.35333 .33555 Mdot
.35524 .3303 Mdot
.35714 .25096 Mdot
.35905 .32717 Mdot
.36095 .35623 Mdot
.36286 .23274 Mdot
.36476 .25041 Mdot
.36667 .27808 Mdot
.36857 .42604 Mdot
.37048 .40691 Mdot
.37238 .4458 Mdot
.37429 .34511 Mdot
.37619 .45538 Mdot
.3781 .33103 Mdot
.38 .2308 Mdot
.3819 .22121 Mdot
.38381 .23688 Mdot
.38571 .45617 Mdot
.38762 .30374 Mdot
.38952 .4308 Mdot
.39143 .41599 Mdot
.39333 .26152 Mdot
.39524 .39878 Mdot
.39714 .37638 Mdot
.39905 .45464 Mdot
.40095 .42859 Mdot
.40286 .28071 Mdot
.40476 .32748 Mdot
.40667 .38017 Mdot
.40857 .31388 Mdot
.41048 .30941 Mdot
.41238 .26938 Mdot
.41429 .25175 Mdot
.41619 .35133 Mdot
.4181 .39055 Mdot
.42 .3018 Mdot
.4219 .24101 Mdot
.42381 .28751 Mdot
.42571 .32381 Mdot
.42762 .25685 Mdot
.42952 .30217 Mdot
.43143 .35546 Mdot
.43333 .29097 Mdot
.43524 .33536 Mdot
.43714 .38293 Mdot
.43905 .34512 Mdot
.44095 .45758 Mdot
.44286 .33205 Mdot
.44476 .31654 Mdot
.44667 .42912 Mdot
.44857 .34856 Mdot
.45048 .28769 Mdot
.45238 .27619 Mdot
.45429 .31556 Mdot
.45619 .31457 Mdot
.4581 .27215 Mdot
.46 .40065 Mdot
.4619 .33517 Mdot
.46381 .42614 Mdot
.46571 .40415 Mdot
.46762 .27359 Mdot
.46952 .27699 Mdot
.47143 .35129 Mdot
.47333 .2515 Mdot
.47524 .28069 Mdot
.47714 .42278 Mdot
.47905 .34021 Mdot
.48095 .40199 Mdot
.48286 .284 Mdot
.48476 .39454 Mdot
.48667 .38346 Mdot
.48857 .26077 Mdot
.49048 .33226 Mdot
.49238 .34891 Mdot
.49429 .24302 Mdot
.49619 .3103 Mdot
.4981 .40211 Mdot
.5 .25578 Mdot
.5019 .34606 Mdot
.50381 .4242 Mdot
.50571 .4554 Mdot
.50762 .27002 Mdot
.50952 .26154 Mdot
.51143 .39298 Mdot
.51333 .36788 Mdot
.51524 .32397 Mdot
.51714 .3257 Mdot
.51905 .28399 Mdot
.52095 .38969 Mdot
.52286 .25527 Mdot
.52476 .26438 Mdot
.52667 .28003 Mdot
.52857 .33192 Mdot
.53048 .27042 Mdot
.53238 .24833 Mdot
.53429 .35779 Mdot
.53619 .27367 Mdot
.5381 .26583 Mdot
.54 .39879 Mdot
.5419 .35889 Mdot
.54381 .39839 Mdot
.54571 .33567 Mdot
.54762 .32216 Mdot
.54952 .29752 Mdot
.55143 .39665 Mdot
.55333 .34728 Mdot
.55524 .30205 Mdot
.55714 .23216 Mdot
.55905 .25512 Mdot
.56095 .24988 Mdot
.56286 .42668 Mdot
.56476 .31335 Mdot
.56667 .34513 Mdot
.56857 .36893 Mdot
.57048 .41297 Mdot
.57238 .3401 Mdot
.57429 .31262 Mdot
.57619 .28724 Mdot
.5781 .38908 Mdot
.58 .30473 Mdot
.5819 .26998 Mdot
.58381 .22124 Mdot
.58571 .30839 Mdot
.58762 .41279 Mdot
.58952 .3093 Mdot
.59143 .28416 Mdot
.59333 .31855 Mdot
.59524 .41404 Mdot
.59714 .37083 Mdot
.59905 .41989 Mdot
.60095 .45153 Mdot
.60286 .31093 Mdot
.60476 .28744 Mdot
.60667 .39951 Mdot
.60857 .24123 Mdot
.61048 .45188 Mdot
.61238 .26955 Mdot
.61429 .23483 Mdot
.61619 .36529 Mdot
.6181 .32535 Mdot
.62 .3102 Mdot
.6219 .33104 Mdot
.62381 .26736 Mdot
.62571 .43335 Mdot
.62762 .26483 Mdot
.62952 .33219 Mdot
.63143 .38005 Mdot
.63333 .35724 Mdot
.63524 .27663 Mdot
.63714 .44679 Mdot
.63905 .44236 Mdot
.64095 .28008 Mdot
.64286 .25918 Mdot
.64476 .24065 Mdot
.64667 .38356 Mdot
.64857 .42149 Mdot
.65048 .26426 Mdot
.65238 .31914 Mdot
.65429 .29906 Mdot
.65619 .35054 Mdot
.6581 .41822 Mdot
.66 .39734 Mdot
.6619 .32186 Mdot
.66381 .33286 Mdot
.66571 .30544 Mdot
.66762 .26891 Mdot
.66952 .39941 Mdot
.67143 .24551 Mdot
.67333 .32984 Mdot
.67524 .3479 Mdot
.67714 .2565 Mdot
.67905 .42844 Mdot
.68095 .36574 Mdot
.68286 .39963 Mdot
.68476 .28403 Mdot
.68667 .32768 Mdot
.68857 .269 Mdot
.69048 .41858 Mdot
.69238 .38658 Mdot
.69429 .33893 Mdot
.69619 .31817 Mdot
.6981 .3232 Mdot
.7 .42373 Mdot
.7019 .31865 Mdot
.70381 .39355 Mdot
.70571 .32279 Mdot
.70762 .37542 Mdot
.70952 .41051 Mdot
.71143 .24543 Mdot
.71333 .42271 Mdot
.71524 .26421 Mdot
.71714 .33925 Mdot
.71905 .43509 Mdot
.72095 .44837 Mdot
.72286 .45692 Mdot
.72476 .27174 Mdot
.72667 .26419 Mdot
.72857 .42996 Mdot
.73048 .39449 Mdot
.73238 .27686 Mdot
.73429 .24997 Mdot
.73619 .36592 Mdot
.7381 .24252 Mdot
.74 .38393 Mdot
.7419 .23197 Mdot
.74381 .40133 Mdot
.74571 .34588 Mdot
.74762 .41122 Mdot
.74952 .35106 Mdot
.75143 .33526 Mdot
.75333 .3496 Mdot
.75524 .44764 Mdot
.75714 .48403 Mdot
.75905 .36235 Mdot
.76095 .26935 Mdot
.76286 .298 Mdot
.76476 .45049 Mdot
.76667 .28825 Mdot
.76857 .2935 Mdot
.77048 .44904 Mdot
.77238 .23528 Mdot
.77429 .32062 Mdot
.77619 .34231 Mdot
.7781 .36902 Mdot
.78 .29344 Mdot
.7819 .22955 Mdot
.78381 .29382 Mdot
.78571 .4038 Mdot
.78762 .44757 Mdot
.78952 .35861 Mdot
.79143 .41146 Mdot
.79333 .36919 Mdot
.79524 .3305 Mdot
.79714 .30867 Mdot
.79905 .31072 Mdot
.80095 .41164 Mdot
.80286 .42243 Mdot
.80476 .27588 Mdot
.80667 .33883 Mdot
.80857 .29626 Mdot
.81048 .33584 Mdot
.81238 .44563 Mdot
.81429 .2906 Mdot
.81619 .35686 Mdot
.8181 .32514 Mdot
.82 .33201 Mdot
.8219 .28159 Mdot
.82381 .26696 Mdot
.82571 .3656 Mdot
.82762 .30713 Mdot
.82952 .29191 Mdot
.83143 .41973 Mdot
.83333 .37567 Mdot
.83524 .2845 Mdot
.83714 .3737 Mdot
.83905 .36029 Mdot
.84095 .27885 Mdot
.84286 .3622 Mdot
.84476 .33839 Mdot
.84667 .44986 Mdot
.84857 .27036 Mdot
.85048 .40256 Mdot
.85238 .48974 Mdot
.85429 .39768 Mdot
.85619 .27317 Mdot
.8581 .24393 Mdot
.86 .43283 Mdot
.8619 .25545 Mdot
.86381 .38681 Mdot
.86571 .43261 Mdot
.86762 .33822 Mdot
.86952 .32606 Mdot
.87143 .31557 Mdot
.87333 .33046 Mdot
.87524 .33891 Mdot
.87714 .30018 Mdot
.87905 .33045 Mdot
.88095 .37211 Mdot
.88286 .38411 Mdot
.88476 .31047 Mdot
.88667 .26668 Mdot
.88857 .34713 Mdot
.89048 .3973 Mdot
.89238 .26696 Mdot
.89429 .4253 Mdot
.89619 .40157 Mdot
.8981 .34804 Mdot
.9 .40464 Mdot
.9019 .25078 Mdot
.90381 .34735 Mdot
.90571 .22202 Mdot
.90762 .33954 Mdot
.90952 .42104 Mdot
.91143 .45583 Mdot
.91333 .27398 Mdot
.91524 .31769 Mdot
.91714 .36066 Mdot
.91905 .29194 Mdot
.92095 .41804 Mdot
.92286 .38902 Mdot
.92476 .35185 Mdot
.92667 .32096 Mdot
.92857 .37231 Mdot
.93048 .3808 Mdot
.93238 .29903 Mdot
.93429 .27551 Mdot
.93619 .33836 Mdot
.9381 .31952 Mdot
.94 .27027 Mdot
.9419 .26206 Mdot
.94381 .36089 Mdot
.94571 .29451 Mdot
.94762 .28903 Mdot
.94952 .36912 Mdot
.95143 .26533 Mdot
.95333 .24968 Mdot
.95524 .34489 Mdot
.95714 .35654 Mdot
.95905 .35576 Mdot
.96095 .30021 Mdot
.96286 .49056 Mdot
.96476 .30595 Mdot
.96667 .39783 Mdot
.96857 .28819 Mdot
.97048 .36216 Mdot
.97238 .35421 Mdot
.97429 .42405 Mdot
.97619 .43951 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo04_ooooo0_l0000Rooooo`;o0000?oooool2o`0008[ooooo0006ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool00ol0003oooooooooo`1;ooooo`;o00008_ooool2o`0003oooooo0_l0001V
ooooo`;o00008_ooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3ooooooaWooooo0_l0000Rooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Kooo
ool2o`0007oooooo0_l0001:ooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000JOooool2o`0000Cooooo0_l0
000gooooo`;o0000>Oooool2o`0000_ooooo0_l0001:ooooo`001_ooool01Ol0003ooooooooooooo
oooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool00_ooool2o`0000_ooooo0_l00009ooooo`;o00002oooool2o`0001Oooooo
0ol00006ooooo`;o00004?ooool2o`0000cooooo0_l00005ooooo`;o0000=_ooool2o`00013ooooo
0_l0000Wooooo`;o00002?ooool2o`0004gooooo0006ooooo`05oa0@4?ooooooooooooooool@4100
3oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
0_ooool2o`0000Oooooo0_l00002ooooo`?o00002?ooool4o`0000Wooooo0_l0000?ooooo`;o0000
1_ooool3o`0000Kooooo0_l00003ooooo`;o00002oooool2o`0001?ooooo0_l00018ooooo`;o0000
<Oooool2o`0004gooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zj
oooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02o`0000Wo
oooo0_l00003ooooo`;o00002_ooool2o`0001Wooooo0ol0000Dooooo`;o0000;?ooool2o`0001Ko
oooo0_l0000Rooooo`;o00002_ooool2o`0001cooooo0_l0001Hooooo`001_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0
003oooooooooo`02o`0000Gooooo1?l0000/ooooo`;o0000@oooool2o`0001Kooooo0_l0000Roooo
o`;o00002_ooool2o`0000Oooooo0_l0000:ooooo`;o00001oooool2o`0002Gooooo0_l0000aoooo
o`00:Oooool2o`0000Sooooo1?l0002Eooooo`;o0000:oooool2o`0000[ooooo0_l0000^ooooo`;o
00007?ooool2o`0001?ooooo000Yooooo`04o`000?oooooo0000o`0000?ooooo0_l0000/ooooo`;o
0000<oooool2o`000003ooooool0003o000000kooooo0_l0000Aooooo`;o00004Oooool2o`0000Oo
oooo0_l0000fooooo`;o0000=?ooool2o`0000kooooo0_l0000Cooooo`00:Oooool01?l0003ooooo
o`000?l00002ooooo`?o0000;?ooool2o`0001;ooooo0_l0000Aooooo`;o000000?oooooo`000?l0
00002Oooool2o`000003ooooool0003o000000kooooo0_l0000Aooooo`;o00001_ooool2o`0000Ko
oooo0_l00009ooooo`?o0000=_ooool2o`0002Oooooo0_l0000;ooooo`;o00008oooool002Wooooo
00?o0000ooooooooool00oooool2o`00047ooooo0_l0000Aooooo`;o000000?oooooo`000?l00000
8?ooool2o`0001Gooooo0_l00006ooooo`;o00002Oooool2o`0002Cooooo0_l0000jooooo`;o0000
<?ooool002Wooooo00?o0000ooooooooool0>oooool2o`0003Kooooo0_l00009ooooo`;o00004_oo
ool2o`0000Cooooo0_l0000Yooooo`;o00002Oooool2o`0005?ooooo0_l0000Gooooo`00:Oooool2
o`0000Kooooo0_l0000Nooooo`;o00005?ooool4o`0003Cooooo0_l0000Mooooo`;o00001?ooool2
o`0000?ooooo0_l0000Oooooo`;o00000oooool2o`000003ooooool0003o000001?ooooo0_l00000
0ooooooo0000o`000013ooooo`;o00005oooool002Wooooo00?o0000ooooooooool01Oooool2o`00
01kooooo0_l0000>ooooo`;o00001_ooool2o`0000Cooooo1?l00002ooooo`;o0000D_ooool2o`00
00?ooooo0_l0000Iooooo`?o00001_ooool2o`0001?ooooo0_l000000ooooooo0000o`00000Noooo
o`;o00004_ooool4o`00017ooooo0_l0000Cooooo`00:Oooool00ol0003oooooooooo`0`ooooo`Co
000000Co410@o`000?l0003ok^k^0_l000000olb<S;ok^k^ooooo`02ooooo`04onk^k_lb<S;o0000
oc8b<PCo00000_ooool2o`0002;ooooo1Ol00003ooooo`04onk^k_lb<S;o0000oc8b<P;o00000_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Kooooo0_l00005ooooo`;o000000?oooooo`000?l00000
1_ooool01_nHV9So410@o`000?lb<S;oc<c<ooooo`;o000000Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`Go00003?ooool2o`0000Gooooo0_l0000Eooooo`;o000000Wo410@ooooooooooooooooonk^
k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo0_l00005oooo
o`;o00002oooool4o`0000gooooo0_l000001Om4A4Co0000o`000?l0003ogMgM00;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool002Wooooo00?o
0000ooooooooool0<_ooool2o`0000?ooooo00GoMgMgo`000?l0003oV9RHogMgM`03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0:Oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00CoMgMgoiRH
V?ooooooV9RH0_l00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool2o`000003ooooool0
003o000000_ooooo0_l00005ooooo`Co00001oooool01_l@413o^[ZjoooooomgMgOo<S8booooo`;o
000000GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`;o000000?ooooooiRHV?mgMgL03?ooool2o`00
00Gooooo0_l0000:ooooo`;o00002Oooool2o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02Oooool2o`000003ooooool0003o0000013ooooo0_l0
0007ooooo`;o00000oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wooooo00?o0000ooooooooool0:?ooool2o`00
0003ooooool0003o000000Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@00?ooooo00Go410@oooooooooooooooooa0@400Zooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go
410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001?ooool4o`000004
ooooool0003o0000o`0001?ooooo0_l0000;ooooo`05o`000?ooooooooooooooool@41000oooool0
1Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool00_l0000Kooooo`Co00001Ooo
ool5o`0000?ooooo00Go410@oooooooooooooooooa0@4003ooooo`;o00000_ooool00ol@413ooooo
ooooo`0:ooooo`;o00004?ooool2o`0000Gooooo0_l00006ooooo`04o`000?oooooooooooa0@40?o
oooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo007ooooo000Yooooo`;o
00003_ooool2o`0001Wooooo0_l000000ooooooo0000o`000005ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000009oooool2
o`0000;ooooo00?oV9RHob4Q8Oo^k^h00oooool3o`000003ooooool0003ooooo00;ooooo00Go0000
ooooooooooooooooo`000004ooooo`;o00001?ooool3o`0000oooooo0_l0000=ooooo`03ojVYZOl@
413ooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000_ooool4o`0001_ooooo0_l00005ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000oooo
ooooooooooooo`000003ooooo`;o00000_ooool00ol0003oooooooooo`05ooooo`;o00007?ooool2
o`0000Gooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`01ooooo`00:Oooool01?l0003oooooo`000?l0000<ooooo`;o0000
2_ooool2o`0000_ooooo0_l0000:ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000009oooool2o`0000?ooooo00?oMgMgofIV
I_ooool00_ooool3o`000003ooooool0003ooooo00;ooooo00Go0000ooooooooooooooooo`00000;
ooooo`;o00003oooool2o`0000cooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000004ooooo`;o00008_ooool01?oMgMgoEEEE
ooooool00004ooooo`05o`000?ooooooooooooooool000000oooool01_l0003ooooooooooooooooo
0000ooooo`;o00001?ooool2o`00023ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo000Yooooo`04
o`000?oooooo0000o`0001Sooooo0ol00007ooooo`;o000000?oooooo`000?l000002_ooool3o`00
00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001?oo
ool2o`0000kooooo0_l000000ooooooo0000o`00000Dooooo`05o`000?ooooooooooooooool@4100
0oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool03?ooool2o`0000[o
oooo0_l0000?ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@o`000?l0003ooooooa0@4003oooo
o`05oa0@4?ooooooooooooooool@41004_ooool2o`0001Gooooo00?oMgMgolc<c?l000001?ooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Ko410@oooooooooooooooooa0@4?ooool2o`0000;o
oooo0_l0000Rooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@4003oooo
o`05oa0@4?ooooooooooooooool@41000oooool002Wooooo00?o0000ooooooooool06_ooool2o`00
00?ooooo0_l00002ooooo`;o00003Oooool3o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`05ogMgMonHV9So0000o`000?mgMgL01?ooool2o`0000kooooo0_l000000ooooooo0000o`00
0007ooooo`;o00001oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`;o000000?ooooooiRHV?mgMgL00oooool2o`0000Wooooo0_l0000:ooooo`;o
00003?ooool01?l@413oV9RHoooooonj^[X2o`0000;ooooo00GoMgMgo`000?l0003oV9RHogMgM`02
o`000006oooooomgMgOoV9RHoooooonHV9SoMgMg4_ooool2o`0001Gooooo00?ok^k^odA4A?l00000
0_l00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_l0000Rooooo`;o00001Oooool2o`000003oooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`00:Oooool00ol0003oooooooooo`0Oooooo`?o00003?ooool2o`00
0003oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_l0003o
0000o`000?o^k^h02oooool2o`0000gooooo0_l00004ooooo`;o00001oooool01OnHV9So410@o`00
0?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`Go00000oooool2o`0002?o
oooo00CoZJVYoa0@4?l0003o410@0_l00002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_l00000
1_ooooook^k^oc8b<_l0003o<S8bonk^kR[ooooo00CoMgMgo`000?l0003o00000_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo00?ok^k^oc8b<_l000000_l00003ooooo`;o00006oooool2o`00
00Oooooo1?l00003ooooo`?o000000?o<S8bonk^k_ooool00_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo000Yooooo`;o00008Oooool2o`0000cooooo0_l00003ooooo`;o00002oooool2o`00
00?ooooo0_l00005ooooo`;o000000?oooooo`000?l000003Oooool2o`00023ooooo0_l0001Zoooo
o`;o000000?oooooo`000?l000000_l00006ooooo`?o00000oooool2o`0001_ooooo0_l00007oooo
o`;o00005Oooool002Wooooo00?o0000ooooooooool0<oooool2o`000003ooooool0003o000000go
oooo0_l00005ooooo`;o0000Eoooool2o`00023ooooo0_l0000Qooooo`Co000000?oooooo`000?l0
00000_l00006ooooo`;o00009Oooool2o`0000?ooooo0_l0000Eooooo`00:Oooool00ol0003ooooo
ooooo`0fooooo`;o0000A?ooool2o`000003ooooool0003o000002Cooooo1?l0000Nooooo`;o0000
8Oooool2o`0002?ooooo0_l0000?ooooo`;o00002?ooool2o`00013ooooo000Yooooo`03o`000?oo
oooooooo077ooooo0_l00009ooooo`;o000000?oooooo`000?l000009_ooool2o`0000Kooooo0_l0
000Jooooo`;o0000@_ooool2o`0001Wooooo0_l0000@ooooo`00:Oooool00ol0003oooooooooo`06
ooooo`;o00009oooool2o`0000Wooooo0_l0000eooooo`;o0000??ooool4o`0001Sooooo0_l0000X
ooooo`;o00002?ooool2o`0002[ooooo0_l0000?ooooo`008Oooooooo`0004Co00001?ooool002Wo
oooo0ol000000ooooooo0000o`000006ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0:ooooo`?o00002Oooool00ol0003oooooooooo`02o`0000Oo
oooo00Co0000oooooooooooooooo0_l00006ooooo`03o`000?oooooooooo00[ooooo0ol000000ooo
oooo0000o`000003ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`0000?ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool01?l0003oooooooooooooool2o`0000Kooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`03ooooo`;o00001?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02_ooool002Wooooo00Co0000oooooooooooooooo0_l0
0004ooooo`;o00005oooool2o`0001Sooooo00?o0000ooooooooool0>oooool2o`0000[ooooo0_l0
00000ooooooo0000o`00000Qooooo`;o000000?oooooo`000?l000001_ooool00ol0003ooooooooo
o`0jooooo`03o`000?oooooooooo01Sooooo0_l0000<ooooo`;o00004_ooool00ol0003ooooooooo
o`0:ooooo`00:Oooool00ol0003oooooooooo`07ooooo`;o00005oooool2o`0000Oooooo0_l0000X
ooooo`Co0000;Oooool2o`000003ooooool0003o000002[ooooo0_l0000Aooooo`;o00003?ooool4
o`0001Kooooo0_l0000Mooooo`;o00003?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000H
ooooo`00:Oooool00ol0003oooooooooo`02ooooo`;o00004oooool2o`00013ooooo0_l00006oooo
o`;o00000oooool2o`0001Wooooo1_l0000Vooooo`;o00006oooool2o`0000Wooooo0_l0000<oooo
o`;o00004Oooool2o`000003ooooool0003o000000Wooooo1_l0000Dooooo`;o0000;oooool2o`00
0003ooooool0003o000001Sooooo000Yooooo`;o00000oooool2o`0001?ooooo0_l0000Dooooo`;o
00000_ooool2o`0000?ooooo0_l0000Iooooo`;o00004?ooool2o`0000?ooooo0_l0000=ooooo`;o
00001?ooool2o`0001_ooooo0ol00008ooooo`;o00005?ooool2o`0000cooooo0_l0000:ooooo`;o
000000?oooooo`000?l000008_ooool2o`0000kooooo0_l0000^ooooo`00:Oooool00ol0003ooooo
ooooo`0Hooooo`;o00002oooool2o`0000Kooooo0_l0000Uooooo`;o00001?ooool2o`0000Oooooo
0_l00002ooooo`?o00003Oooool2o`0002;ooooo0_l0000Nooooo`;o00004?ooool2o`0000;ooooo
0_l0000Qooooo`;o00001_ooool2o`0000kooooo1Ol0000[ooooo`00:Oooool00ol0003ooooooooo
o`0Hooooo`;o00002oooool2o`0002gooooo0_l00004ooooo`;o00001_ooool2o`0000?ooooo0_l0
0005ooooo`;o00004oooool2o`0000gooooo0_l0000;ooooo`;o00007?ooool4o`0000Wooooo0_l0
00000ooooooo0000o`000002ooooo`;o00008Oooool2o`0000Kooooo0_l0000?ooooo`Co0000:ooo
ool002Wooooo00?o0000ooooooooool0=Oooool2o`0000Sooooo0_l0000Eooooo`;o00002_ooool2
o`0000;ooooo0_l00006ooooo`;o00004Oooool4o`0000Cooooo0_l00007ooooo`;o00002oooool2
o`0000?ooooo0_l0000Gooooo`Co00002Oooool2o`0001[ooooo0_l0000Aooooo`;o000000?ooooo
o`000?l00000?_ooool002Wooooo00?o0000ooooooooool08_ooool2o`00017ooooo0_l00008oooo
o`;o00005Oooool2o`0000kooooo0_l0000Iooooo`;o00001_ooool2o`0001Wooooo0_l0000^oooo
o`;o00001Oooool2o`0000Wooooo0_l0000@ooooo`?o00002Oooool2o`0000Kooooo1?l00008oooo
o`;o00002?ooool2o`0001Sooooo000Yooooo`;o00008_ooool5o`0002Oooooo0_l00009ooooo`;o
0000=Oooool2o`0001cooooo0_l0000Uooooo`;o00001Oooool2o`00017ooooo0_l00008ooooo`;o
00002_ooool2o`0000Kooooo1?l00008ooooo`;o00002?ooool2o`0001Sooooo000Yooooo`03o`00
0?oooooooooo00[ooooo0_l0000Eooooo`;o000000?oooooo`000?l000001?ooool2o`0001;ooooo
0_l0000=ooooo`;o00002Oooool2o`0001?ooooo0_l0000Cooooo`;o00002oooool2o`0000Gooooo
0_l0000Cooooo`Co0000=Oooool2o`0000Sooooo0_l0000hooooo`;o00004_ooool002Wooooo00?o
0000ooooooooool02_ooool2o`0000Sooooo0_l00008ooooo`;o00002_ooool2o`0001;ooooo0_l0
000Oooooo`;o00000oooool2o`0000Oooooo0_l0000Cooooo`;o000000?oooooo`000?l000003?oo
ool2o`000003ooooool0003o000000oooooo0_l00002ooooo`;o00008Oooool2o`0001Cooooo0_l0
000/ooooo`;o000000?oooooo`000?l000000_l0000?ooooo`;o00004_ooool002Wooooo00?o0000
ooooooooool05?ooool2o`0000Sooooo0_l00007ooooo`?o00006_ooool2o`0001Wooooo0_l00003
ooooo`;o00005?ooool2o`0000Wooooo0_l00005ooooo`;o00001Oooool2o`0001;ooooo0_l0000O
ooooo`;o00001?ooool2o`0001Kooooo0ol0000Yooooo`;o000000?oooooo`000?l000000_l00005
ooooo`;o00007?ooool002Wooooo00?o0000ooooooooool02?ooool2o`0001gooooo0ol0000Joooo
o`;o0000=?ooool2o`0000?ooooo0_l0000;ooooo`;o0000>_ooool2o`0001cooooo0ol0000eoooo
o`;o00003Oooool2o`0000gooooo000Yooooo`;o00002Oooool2o`0000?ooooo0_l000000ooooooo
0000o`000006ooooo`;o00000oooool2o`0000gooooo0_l00002ooooo`;o00008_ooool2o`0000_o
oooo0_l00006ooooo`;o00005?ooool2o`0001oooooo0_l0000Nooooo`;o0000>Oooool2o`0002_o
oooo0ol00002ooooo`;o00003Oooool002Wooooo00?o0000ooooooooool03Oooool2o`000003oooo
ool0003o000000Kooooo0_l00003ooooo`;o00003Oooool2o`0000;ooooo0_l0000<ooooo`;o0000
5?ooool2o`0000_ooooo0_l00006ooooo`;o0000=Oooool2o`000003ooooool0003o000001_ooooo
0_l0000`ooooo`;o00001oooool2o`0000Gooooo0_l0000Hooooo`;o00001_ooool2o`0000;ooooo
0ol0000Aooooo`00:Oooool00ol0003oooooooooo`0:ooooo`;o0000<_ooool2o`0006?ooooo0_l0
0014ooooo`;o00001oooool2o`0000kooooo1?l0000Fooooo`;o00001_ooool2o`0000Oooooo0_l0
000=ooooo`00:Oooool00ol0003oooooooooo`0:ooooo`;o00001oooool2o`0004Wooooo0_l0000j
ooooo`;o00007oooool2o`0001?ooooo0_l0000?ooooo`;o00001_ooool2o`0001?ooooo0_l00004
ooooo`;o00009oooool2o`0000gooooo000Yooooo`03o`000?oooooooooo00cooooo0_l00005oooo
o`;o0000BOooool2o`0003[ooooo0_l0000?ooooo`;o00002?ooool2o`0000Cooooo0_l0000Coooo
o`;o00003oooool2o`0000cooooo0_l00003ooooo`;o00002?ooool2o`0002Kooooo0_l0000Doooo
o`00:Oooool2o`0000gooooo0_l00003ooooo`;o0000V?ooool2o`0000Sooooo0_l0000hooooo`;o
00000oooool2o`0000cooooo0_l0000<ooooo`;o00003Oooool2o`0000Gooooo0_l0000Dooooo`00
:Oooool2o`0001;ooooo0_l0000Zooooo`;o00004Oooool2o`0002;ooooo0_l0001Rooooo`;o0000
9oooool3o`0000cooooo0_l0000=ooooo`;o00006oooool000Kooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`;o
00004oooool2o`0002Wooooo0_l00007ooooo`;o00002?ooool4o`0000oooooo0_l0000?ooooo`;o
000000?oooooo`000?l00000Aoooool2o`0001Kooooo0_l0000Wooooo`;o0000>Oooool000Kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A4
00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Booooo`;o00003_ooool2o`00
02;ooooo0_l0000:ooooo`;o00003oooool2o`0001;ooooo0_l00008ooooo`;o00003_ooool2o`00
02gooooo0_l0001Nooooo`;o00006_ooool000Kooooo00Go410@oooooooooooooooooa0@400<oooo
o`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Boooo
o`;o00000_ooool2o`0000[ooooo0_l0000<ooooo`;o0000Coooool2o`0000kooooo0_l0000boooo
o`;o00007?ooool2o`0002_ooooo0_l0000>ooooo`;o00006_ooool000Kooooo00Go0000oooooooo
ooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`00
01;ooooo0_l00002ooooo`;o00006?ooool2o`0000Sooooo0_l0001booooo`;o00005Oooool2o`00
00cooooo0_l0000>ooooo`;o00009Oooool2o`0000Cooooo0_l0000;ooooo`;o00007Oooool000Ko
oooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo01Oooooo0_l0000Qooooo`;o00008oooool2
o`0001[ooooo0_l0000Oooooo`;o00004?ooool2o`0002?ooooo0_l0000eooooo`;o00004Oooool2
o`0001gooooo0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03oooool2o`0000Kooooo0_l0000E
ooooo`;o0000;?ooool2o`000003ooooool0003o000000Cooooo0_l0000Dooooo`;o00004oooool2
o`0000Oooooo0_l000000ooooooo0000o`00000iooooo`;o00001_ooool2o`0005_ooooo0006oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o
0000ooooooooool01oooool2o`0000;ooooo0_l0000<ooooo`;o00007Oooool2o`0000cooooo0_l0
000?ooooo`;o00003Oooool2o`0000Oooooo0_l0000=ooooo`;o00006_ooool2o`0000Oooooo0_l0
0007ooooo`?o000000?oooooo`000?l000008Oooool2o`0000cooooo0_l00006ooooo`;o00009_oo
ool2o`0000[ooooo0_l0000Fooooo`;o00003oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l00002ooooo`;o0000
7?ooool2o`0001_ooooo0_l0000=ooooo`Co00009Oooool2o`0001?ooooo0_l00004ooooo`;o0000
1?ooool2o`0000_ooooo0ol000000ooooooo0000o`00000@ooooo`;o00003oooool2o`000003oooo
ool0003o000000;ooooo0_l0000Booooo`;o00008Oooool2o`0000[ooooo1?l0000Dooooo`;o0000
3oooool002Wooooo0_l0000Pooooo`;o00008Oooool2o`0000Oooooo0_l0000looooo`?o00000ooo
ool2o`0000Cooooo0_l0000Qooooo`;o00004_ooool2o`0000;ooooo0_l0000Booooo`;o00002ooo
ool2o`0001?ooooo0_l0000=ooooo`?o00009?ooool002Wooooo00?o0000ooooooooool0@_ooool2
o`0002Sooooo0_l0000Looooo`;o0000IOooool2o`0001?ooooo0_l0000>ooooo`;o00009?ooool0
02Wooooo00?o0000ooooooooool0B_ooool2o`00023ooooo0_l0001[ooooo`;o00002_ooool2o`00
05Gooooo000Yooooo`03o`000?oooooooooo04Oooooo0_l000000ooooooo0000o`00000Jooooo`;o
0000A?ooool2o`0000Cooooo1?l0000Sooooo`;o00002_ooool2o`0000cooooo0_l000000ooooooo
0000o`000014ooooo`00:Oooool00ol0003oooooooooo`0Looooo`;o0000:Oooool2o`0000gooooo
0_l0000>ooooo`;o00002_ooool2o`0003Sooooo0_l00004ooooo`Co0000?Oooool2o`000003oooo
ool0003o000004Cooooo000Yooooo`;o00007Oooool2o`0001gooooo0_l0000Iooooo`;o00006_oo
ool2o`00047ooooo0_l0000Aooooo`;o00002Oooool2o`0002_ooooo0_l0000Kooooo`;o00007Ooo
ool002Wooooo00?o0000ooooooooool02Oooool2o`00013ooooo0_l0000@ooooo`;o00003?ooool2
o`0001Cooooo0_l0000:ooooo`;o000000?oooooo`000?l00000;?ooool2o`0002Gooooo0_l0000>
ooooo`;o000000?oooooo`000?l000002Oooool2o`000003ooooool0003o000000;ooooo0_l0000K
ooooo`;o00001oooool2o`0001Oooooo0_l00002ooooo`;o00007Oooool002Wooooo00?o0000oooo
ooooool01?ooool3o`0000;ooooo0_l00003ooooo`;o00001?ooool2o`0000Gooooo0_l00006oooo
o`;o00001Oooool2o`000003ooooool0003o0000027ooooo0ol00006ooooo`;o00000_ooool2o`00
0003ooooool0003o000000Wooooo0_l0000Mooooo`;o00000_ooool2o`0000Oooooo0_l0000Aoooo
o`;o00006Oooool2o`0000oooooo0_l00002ooooo`;o00006oooool2o`0001_ooooo0_l00003oooo
o`;o00004oooool2o`0000cooooo000Yooooo`03o`000?oooooooooo00Cooooo0ol00007ooooo`;o
00001?ooool2o`0000gooooo0_l00005ooooo`;o00007?ooool2o`0000Kooooo0_l000000ooooooo
0000o`000004ooooo`;o00004?ooool2o`0000Wooooo0_l0000<ooooo`;o00001?ooool2o`0000_o
oooo0_l0000Aooooo`;o00008oooool2o`0000kooooo0_l0000cooooo`;o00006?ooool2o`0000co
oooo000Yooooo`03o`000?oooooooooo04Sooooo0_l00009ooooo`;o00007Oooool2o`0000;ooooo
0_l0000<ooooo`;o0000BOooool2o`0000kooooo0_l0000Xooooo`Co0000;oooool002Wooooo0_l0
001cooooo`;o0000B_ooool2o`0001cooooo0_l0000[ooooo`Co0000;oooool002Wooooo00?o0000
ooooooooool05Oooool2o`0003Oooooo0_l0001^ooooo`;o00007?ooool2o`0005kooooo000Yoooo
o`03o`000?oooooooooo01Gooooo0_l0000gooooo`;o0000L_ooool2o`0006_ooooo0_l0000;oooo
o`00:Oooool00ol0003oooooooooo`0Mooooo`;o00003?ooool2o`0009Gooooo0_l0000fooooo`;o
0000<oooool2o`0000_ooooo000Yooooo`03o`000?oooooooooo01gooooo0_l0000<ooooo`;o0000
?oooool2o`0005?ooooo0_l0000Iooooo`;o00002Oooool2o`0000Wooooo0_l00006ooooo`;o0000
@?ooool002Wooooo0_l0000=ooooo`;o00009_ooool2o`0003Kooooo0_l00018ooooo`;o000000?o
ooooo`000?l000001_ooool2o`0001Wooooo0_l00009ooooo`;o00000_ooool3o`0000Cooooo0_l0
000Aooooo`;o0000=Oooool002Wooooo00?o0000ooooooooool03?ooool2o`0000Oooooo0_l0000M
ooooo`;o00000oooool2o`0003[ooooo0_l0000oooooo`;o000000?oooooo`000?l00000<?ooool3
o`0001Oooooo0_l0000eooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Eooooo`;o00008_oo
ool2o`0002Kooooo0_l0000;ooooo`;o000000?oooooo`000?l000000_ooool2o`0000_ooooo0_l0
000Cooooo`;o0000A?ooool2o`0003_ooooo0_l0000Pooooo`003_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0HOoo
ool2o`0000_ooooo0_l000000ooooooo0000o`00000?ooooo`;o00004oooool2o`0004Cooooo0_l0
000kooooo`;o00008?ooool000kooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oo
oooooooo00?ooooo0ol0003oooooocgooooo000>ooooo`05o`000?ooooooooooooooool000003ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go0000
ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`1Gooooo`;o0000hoooool000kooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0Eoooool2o`000>?ooooo000>ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo
?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`000?oooooo
?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3X
ooooo`;o0000D_ooool002Wooooo00?o0000ooooooooool0@oooool2o`000:?ooooo0_l0001Boooo
o`00:Oooool00ol0003oooooooooo`13ooooo`;o0000`_ooool2o`00027ooooo0_l0000@ooooo`00
:Oooool2o`000?oooooo2Oooool2o`00027ooooo0_l0000@ooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000
oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@
400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo?Ooo
ool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05o`000?oooooo
ooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@4100
3_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooo
oooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`00
1_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000?oo
oooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oo
oooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Oooooo`Co000000?o410@
ooooooooool00oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`?o
0000oooooolmooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Oooooo`03oeEEEOmVIVKo00000?ooooooAoooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .30284 Mdot
.02762 .40208 Mdot
.02952 .30211 Mdot
.03143 .33306 Mdot
.03333 .29978 Mdot
.03524 .31777 Mdot
.03714 .27577 Mdot
.03905 .29945 Mdot
.04095 .27617 Mdot
.04286 .34893 Mdot
.04476 .29876 Mdot
.04667 .34904 Mdot
.04857 .34757 Mdot
.05048 .32683 Mdot
.05238 .35176 Mdot
.05429 .25729 Mdot
.05619 .24675 Mdot
.0581 .33918 Mdot
.06 .34852 Mdot
.0619 .37994 Mdot
.06381 .33907 Mdot
.06571 .4041 Mdot
.06762 .39747 Mdot
.06952 .32405 Mdot
.07143 .4181 Mdot
.07333 .3592 Mdot
.07524 .26067 Mdot
.07714 .3382 Mdot
.07905 .39657 Mdot
.08095 .40193 Mdot
.08286 .31365 Mdot
.08476 .27214 Mdot
.08667 .24839 Mdot
.08857 .31767 Mdot
.09048 .38091 Mdot
.09238 .30343 Mdot
.09429 .42235 Mdot
.09619 .29449 Mdot
.0981 .40623 Mdot
.1 .37122 Mdot
.1019 .42486 Mdot
.10381 .36 Mdot
.10571 .37901 Mdot
.10762 .33596 Mdot
.10952 .26893 Mdot
.11143 .25697 Mdot
.11333 .33869 Mdot
.11524 .33427 Mdot
.11714 .35414 Mdot
.11905 .3852 Mdot
.12095 .34097 Mdot
.12286 .4267 Mdot
.12476 .35638 Mdot
.12667 .3861 Mdot
.12857 .38628 Mdot
.13048 .22993 Mdot
.13238 .30649 Mdot
.13429 .24662 Mdot
.13619 .38704 Mdot
.1381 .25402 Mdot
.14 .26874 Mdot
.1419 .4474 Mdot
.14381 .40705 Mdot
.14571 .26435 Mdot
.14762 .2373 Mdot
.14952 .24335 Mdot
.15143 .34765 Mdot
.15333 .26347 Mdot
.15524 .3046 Mdot
.15714 .30072 Mdot
.15905 .27189 Mdot
.16095 .31558 Mdot
.16286 .34821 Mdot
.16476 .33379 Mdot
.16667 .40686 Mdot
.16857 .28485 Mdot
.17048 .35673 Mdot
.17238 .30512 Mdot
.17429 .42175 Mdot
.17619 .36788 Mdot
.1781 .23611 Mdot
.18 .39915 Mdot
.1819 .33931 Mdot
.18381 .3671 Mdot
.18571 .24762 Mdot
.18762 .26343 Mdot
.18952 .28939 Mdot
.19143 .26355 Mdot
.19333 .24548 Mdot
.19524 .26127 Mdot
.19714 .4198 Mdot
.19905 .23356 Mdot
.20095 .29039 Mdot
.20286 .24938 Mdot
.20476 .27009 Mdot
.20667 .25371 Mdot
.20857 .33147 Mdot
.21048 .34087 Mdot
.21238 .37165 Mdot
.21429 .2441 Mdot
.21619 .32826 Mdot
.2181 .26392 Mdot
.22 .34193 Mdot
.2219 .354 Mdot
.22381 .249 Mdot
.22571 .33263 Mdot
.22762 .28969 Mdot
.22952 .35857 Mdot
.23143 .29258 Mdot
.23333 .29877 Mdot
.23524 .34337 Mdot
.23714 .33515 Mdot
.23905 .27925 Mdot
.24095 .33274 Mdot
.24286 .48279 Mdot
.24476 .31248 Mdot
.24667 .28846 Mdot
.24857 .22783 Mdot
.25048 .23996 Mdot
.25238 .42449 Mdot
.25429 .35003 Mdot
.25619 .45822 Mdot
.2581 .37093 Mdot
.26 .40215 Mdot
.2619 .2968 Mdot
.26381 .32231 Mdot
.26571 .34917 Mdot
.26762 .2984 Mdot
.26952 .3719 Mdot
.27143 .26434 Mdot
.27333 .39764 Mdot
.27524 .35343 Mdot
.27714 .37485 Mdot
.27905 .30315 Mdot
.28095 .36462 Mdot
.28286 .41693 Mdot
.28476 .42695 Mdot
.28667 .37802 Mdot
.28857 .34804 Mdot
.29048 .27171 Mdot
.29238 .36145 Mdot
.29429 .41531 Mdot
.29619 .3369 Mdot
.2981 .32849 Mdot
.3 .24723 Mdot
.3019 .3599 Mdot
.30381 .23239 Mdot
.30571 .49633 Mdot
.30762 .35659 Mdot
.30952 .25282 Mdot
.31143 .46224 Mdot
.31333 .27465 Mdot
.31524 .26512 Mdot
.31714 .31772 Mdot
.31905 .32065 Mdot
.32095 .26497 Mdot
.32286 .4301 Mdot
.32476 .41565 Mdot
.32667 .22916 Mdot
.32857 .42231 Mdot
.33048 .42979 Mdot
.33238 .37306 Mdot
.33429 .42336 Mdot
.33619 .42868 Mdot
.3381 .25979 Mdot
.34 .38061 Mdot
.3419 .31262 Mdot
.34381 .22909 Mdot
.34571 .23626 Mdot
.34762 .2941 Mdot
.34952 .43111 Mdot
.35143 .35742 Mdot
.35333 .29743 Mdot
.35524 .26648 Mdot
.35714 .29392 Mdot
.35905 .35835 Mdot
.36095 .24805 Mdot
.36286 .26752 Mdot
.36476 .27268 Mdot
.36667 .32111 Mdot
.36857 .39909 Mdot
.37048 .43207 Mdot
.37238 .39266 Mdot
.37429 .30741 Mdot
.37619 .43068 Mdot
.3781 .30177 Mdot
.38 .29072 Mdot
.3819 .30575 Mdot
.38381 .27283 Mdot
.38571 .42215 Mdot
.38762 .37124 Mdot
.38952 .46062 Mdot
.39143 .3606 Mdot
.39333 .29614 Mdot
.39524 .45279 Mdot
.39714 .26909 Mdot
.39905 .4499 Mdot
.40095 .35731 Mdot
.40286 .25497 Mdot
.40476 .22207 Mdot
.40667 .33524 Mdot
.40857 .32418 Mdot
.41048 .32576 Mdot
.41238 .30816 Mdot
.41429 .31372 Mdot
.41619 .23321 Mdot
.4181 .33656 Mdot
.42 .33254 Mdot
.4219 .29666 Mdot
.42381 .33572 Mdot
.42571 .32937 Mdot
.42762 .28671 Mdot
.42952 .38159 Mdot
.43143 .29774 Mdot
.43333 .23581 Mdot
.43524 .28175 Mdot
.43714 .31935 Mdot
.43905 .27795 Mdot
.44095 .43005 Mdot
.44286 .31096 Mdot
.44476 .24075 Mdot
.44667 .35577 Mdot
.44857 .28261 Mdot
.45048 .38334 Mdot
.45238 .2415 Mdot
.45429 .23497 Mdot
.45619 .2602 Mdot
.4581 .33913 Mdot
.46 .39923 Mdot
.4619 .2947 Mdot
.46381 .35488 Mdot
.46571 .45634 Mdot
.46762 .2684 Mdot
.46952 .31237 Mdot
.47143 .23359 Mdot
.47333 .32523 Mdot
.47524 .25951 Mdot
.47714 .45962 Mdot
.47905 .28025 Mdot
.48095 .36665 Mdot
.48286 .37036 Mdot
.48476 .34611 Mdot
.48667 .44744 Mdot
.48857 .3455 Mdot
.49048 .23956 Mdot
.49238 .27077 Mdot
.49429 .26305 Mdot
.49619 .26207 Mdot
.4981 .42886 Mdot
.5 .27296 Mdot
.5019 .26704 Mdot
.50381 .41014 Mdot
.50571 .44572 Mdot
.50762 .31535 Mdot
.50952 .30047 Mdot
.51143 .428 Mdot
.51333 .35845 Mdot
.51524 .26082 Mdot
.51714 .38111 Mdot
.51905 .27799 Mdot
.52095 .28868 Mdot
.52286 .36055 Mdot
.52476 .34045 Mdot
.52667 .25987 Mdot
.52857 .24033 Mdot
.53048 .28114 Mdot
.53238 .28617 Mdot
.53429 .27316 Mdot
.53619 .33312 Mdot
.5381 .34862 Mdot
.54 .32807 Mdot
.5419 .36804 Mdot
.54381 .32577 Mdot
.54571 .38383 Mdot
.54762 .34941 Mdot
.54952 .3592 Mdot
.55143 .43067 Mdot
.55333 .31806 Mdot
.55524 .35402 Mdot
.55714 .3286 Mdot
.55905 .29161 Mdot
.56095 .27312 Mdot
.56286 .4092 Mdot
.56476 .26679 Mdot
.56667 .31229 Mdot
.56857 .42246 Mdot
.57048 .32828 Mdot
.57238 .35958 Mdot
.57429 .3178 Mdot
.57619 .34654 Mdot
.5781 .30653 Mdot
.58 .2492 Mdot
.5819 .2459 Mdot
.58381 .30764 Mdot
.58571 .39539 Mdot
.58762 .32958 Mdot
.58952 .39537 Mdot
.59143 .27434 Mdot
.59333 .40158 Mdot
.59524 .45613 Mdot
.59714 .27653 Mdot
.59905 .34297 Mdot
.60095 .49491 Mdot
.60286 .36471 Mdot
.60476 .3641 Mdot
.60667 .36161 Mdot
.60857 .26583 Mdot
.61048 .41606 Mdot
.61238 .33061 Mdot
.61429 .33423 Mdot
.61619 .36395 Mdot
.6181 .30203 Mdot
.62 .38521 Mdot
.6219 .25358 Mdot
.62381 .36008 Mdot
.62571 .46243 Mdot
.62762 .30431 Mdot
.62952 .24736 Mdot
.63143 .34178 Mdot
.63333 .24958 Mdot
.63524 .27353 Mdot
.63714 .39582 Mdot
.63905 .45508 Mdot
.64095 .39109 Mdot
.64286 .29198 Mdot
.64476 .29571 Mdot
.64667 .37112 Mdot
.64857 .41689 Mdot
.65048 .33333 Mdot
.65238 .32186 Mdot
.65429 .26976 Mdot
.65619 .27371 Mdot
.6581 .33545 Mdot
.66 .42763 Mdot
.6619 .26904 Mdot
.66381 .39537 Mdot
.66571 .2643 Mdot
.66762 .30695 Mdot
.66952 .40058 Mdot
.67143 .32643 Mdot
.67333 .38023 Mdot
.67524 .37291 Mdot
.67714 .32351 Mdot
.67905 .33032 Mdot
.68095 .36119 Mdot
.68286 .39071 Mdot
.68476 .26497 Mdot
.68667 .23033 Mdot
.68857 .26883 Mdot
.69048 .36991 Mdot
.69238 .40312 Mdot
.69429 .32341 Mdot
.69619 .25248 Mdot
.6981 .41669 Mdot
.7 .34666 Mdot
.7019 .40202 Mdot
.70381 .31734 Mdot
.70571 .3688 Mdot
.70762 .32331 Mdot
.70952 .35221 Mdot
.71143 .30632 Mdot
.71333 .34494 Mdot
.71524 .38008 Mdot
.71714 .24365 Mdot
.71905 .37062 Mdot
.72095 .40023 Mdot
.72286 .4336 Mdot
.72476 .28385 Mdot
.72667 .33986 Mdot
.72857 .36229 Mdot
.73048 .29586 Mdot
.73238 .27709 Mdot
.73429 .26439 Mdot
.73619 .35769 Mdot
.7381 .28896 Mdot
.74 .32008 Mdot
.7419 .32693 Mdot
.74381 .36435 Mdot
.74571 .41426 Mdot
.74762 .42528 Mdot
.74952 .39979 Mdot
.75143 .41057 Mdot
.75333 .40001 Mdot
.75524 .40381 Mdot
.75714 .49135 Mdot
.75905 .41949 Mdot
.76095 .25208 Mdot
.76286 .32183 Mdot
.76476 .44859 Mdot
.76667 .247 Mdot
.76857 .27043 Mdot
.77048 .40017 Mdot
.77238 .29619 Mdot
.77429 .32082 Mdot
.77619 .34033 Mdot
.7781 .33767 Mdot
.78 .25456 Mdot
.7819 .32128 Mdot
.78381 .23467 Mdot
.78571 .45395 Mdot
.78762 .39715 Mdot
.78952 .28804 Mdot
.79143 .30402 Mdot
.79333 .30918 Mdot
.79524 .35872 Mdot
.79714 .35543 Mdot
.79905 .31123 Mdot
.80095 .32427 Mdot
.80286 .34485 Mdot
.80476 .26286 Mdot
.80667 .31637 Mdot
.80857 .25336 Mdot
.81048 .28122 Mdot
.81238 .45912 Mdot
.81429 .25071 Mdot
.81619 .26035 Mdot
.8181 .33858 Mdot
.82 .26773 Mdot
.8219 .26981 Mdot
.82381 .26476 Mdot
.82571 .3032 Mdot
.82762 .25341 Mdot
.82952 .3309 Mdot
.83143 .46037 Mdot
.83333 .26943 Mdot
.83524 .28128 Mdot
.83714 .38428 Mdot
.83905 .28961 Mdot
.84095 .24677 Mdot
.84286 .36367 Mdot
.84476 .27688 Mdot
.84667 .45153 Mdot
.84857 .23045 Mdot
.85048 .37279 Mdot
.85238 .46167 Mdot
.85429 .35004 Mdot
.85619 .32279 Mdot
.8581 .26309 Mdot
.86 .36851 Mdot
.8619 .29244 Mdot
.86381 .40234 Mdot
.86571 .33736 Mdot
.86762 .32211 Mdot
.86952 .3055 Mdot
.87143 .35634 Mdot
.87333 .23945 Mdot
.87524 .37039 Mdot
.87714 .22066 Mdot
.87905 .31812 Mdot
.88095 .38296 Mdot
.88286 .35919 Mdot
.88476 .26169 Mdot
.88667 .30952 Mdot
.88857 .33018 Mdot
.89048 .29979 Mdot
.89238 .2868 Mdot
.89429 .41851 Mdot
.89619 .39484 Mdot
.8981 .26041 Mdot
.9 .33781 Mdot
.9019 .26359 Mdot
.90381 .27006 Mdot
.90571 .29494 Mdot
.90762 .3435 Mdot
.90952 .34046 Mdot
.91143 .44633 Mdot
.91333 .33315 Mdot
.91524 .40131 Mdot
.91714 .36596 Mdot
.91905 .24676 Mdot
.92095 .3681 Mdot
.92286 .33116 Mdot
.92476 .35252 Mdot
.92667 .2537 Mdot
.92857 .31833 Mdot
.93048 .44755 Mdot
.93238 .36839 Mdot
.93429 .2882 Mdot
.93619 .38305 Mdot
.9381 .36658 Mdot
.94 .28629 Mdot
.9419 .28443 Mdot
.94381 .38626 Mdot
.94571 .36706 Mdot
.94762 .3257 Mdot
.94952 .34781 Mdot
.95143 .24136 Mdot
.95333 .30442 Mdot
.95524 .25774 Mdot
.95714 .32159 Mdot
.95905 .3336 Mdot
.96095 .26668 Mdot
.96286 .48022 Mdot
.96476 .26758 Mdot
.96667 .40137 Mdot
.96857 .38315 Mdot
.97048 .26686 Mdot
.97238 .315 Mdot
.97429 .38732 Mdot
.97619 .37839 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo4?ooool2o`0002_ooooo0006ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`1gooooo`;o0000U_ooool2o`0002_ooooo0006ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0AOooool2o`00033ooooo0_l00033ooooo`001?l00002
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool07oooool2o`0002Cooooo0_l0000Gooooo`;o00000ooo
ool2o`0006cooooo0_l0000booooo`;o0000=Oooool000Kooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0001oooooo0_l0
000Dooooo`;o00007oooool2o`0000Kooooo0_l00003ooooo`;o00005Oooool2o`00013ooooo0_l0
0013ooooo`;o0000<_ooool2o`0003Gooooo0006ooooo`05o`000?ooooooooooooooool000003_oo
ool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`0^ooooo`;o00001Oooool2o`0001oooooo0_l0000<ooooo`;o00005?ooool2o`0000Cooooo
0_l00005ooooo`;o00000oooool2o`0006?ooooo0_l00019ooooo`001_ooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo02Cooooo0_l00008ooooo`;o00005Oooool2o`0001gooooo0_l0000Jooooo`;o0000
1Oooool2o`0000Wooooo0_l0000;ooooo`;o0000D?ooool2o`0001[ooooo0_l0000]ooooo`001_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool09?ooool3o`0001kooooo0_l0000mooooo`Co
00002_ooool2o`0000_ooooo0_l0001/ooooo`;o00006?ooool2o`0001?ooooo0006ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006oooo
o`03o`000?oooooooooo023ooooo0_l00003ooooo`;o00003?ooool2o`0000Gooooo0_l00018oooo
o`Co0000:?ooool2o`0002Wooooo0_l0001:ooooo`;o00004oooool002Wooooo0_l00008ooooo`;o
00001oooool2o`0000kooooo0_l0000>ooooo`;o000000Coooooo`000?l0003ooooo0_l00002oooo
o`;o000000?oooooo`000?l000005_ooool2o`0001;ooooo0_l00014ooooo`?o00003Oooool3o`00
01Wooooo0_l0000>ooooo`;o00005_ooool2o`0001Oooooo0_l0000Nooooo`00:Oooool00ol0003o
ooooooooo`07ooooo`;o00001oooool2o`0001kooooo0_l00004ooooo`;o00001Oooool2o`0001Ko
oooo0_l000000ooooooo0000o`00000?ooooo`;o0000A?ooool2o`0000kooooo0ol0000Booooo`;o
00004oooool4o`0000gooooo0_l00007ooooo`;o00005oooool2o`0001kooooo000Yooooo`03o`00
0?oooooooooo027ooooo0_l0000Dooooo`;o00007oooool2o`0001cooooo0_l00015ooooo`;o0000
5Oooool2o`0001?ooooo0_l00004ooooo`;o00002?ooool3o`0000?ooooo0_l0000Nooooo`;o0000
6oooool002Wooooo00?o0000ooooooooool01_ooool2o`00013ooooo0_l00007ooooo`;o00005?oo
ool2o`0003gooooo0_l00015ooooo`;o0000<?ooool2o`0000Sooooo0_l00004ooooo`;o00007_oo
ool2o`0000Oooooo0_l0000Booooo`00:Oooool00ol0003oooooooooo`06ooooo`;o00001Oooool2
o`0000Wooooo0_l0000Iooooo`;o0000;?ooool2o`0002Cooooo0_l00004ooooo`;o00001Oooool2
o`0000Cooooo0_l00002ooooo`;o0000Foooool2o`0001Cooooo0_l00002ooooo`;o00004Oooool2
o`0001;ooooo000Yooooo`;o00003_ooool2o`0001Cooooo0_l000000ooooooo0000o`000009oooo
o`Co00001_ooool2o`0000oooooo0_l0000<ooooo`Co00000oooool2o`0002Cooooo0_l00004oooo
o`;o00001Oooool2o`0000Cooooo0_l00002ooooo`;o0000:oooool2o`0000Cooooo0_l0000>oooo
o`;o00005?ooool2o`0000;ooooo0_l000000ooooooo0000o`000009ooooo`;o00001_ooool2o`00
00;ooooo1?l0000Sooooo`00:Oooool00ol0003oooooooooo`0Sooooo`;o000000?oooooo`000?l0
00002Oooool3o`0000Oooooo0_l0000?ooooo`;o00003?ooool4o`0000Wooooo1?l0000Yooooo`Co
00004_ooool2o`0000cooooo0_l0000Aooooo`;o00001?ooool2o`0000kooooo0_l0000Dooooo`;o
00000oooool4o`0000Wooooo0_l0000<ooooo`;o00004Oooool5o`0000gooooo000Yooooo`03o`00
0?oooooooooo01Sooooo0_l00008ooooo`;o00003?ooool4o`000008oa0@4?oooooo0000o`000?lb
<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08oooool4o`0000;ooooo1Ol0
0002ooooo`;o000000Co<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Wo
oooo0_l00006ooooo`;o000000?oooooo`000?l000004_ooool3o`000003oc8b<_o<c<cooooo00;o
oooo00Kok^k^oc8b<_l0003o<S8bonk^k_ooool2o`000005onk^k_lb<S;o0000oc8b<_o^k^h02?oo
ool4o`0000Oooooo0_l0000Eooooo`;o000000Wo410@o`000?l0003oooooonk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o00000_ooool2o`0001Cooooo0_l0000<
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ol000000olb<S;ok^k^ooooo`02ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool002Wooooo00?o0000ooooooooool04?ooool2o`0000Kooooo0_l0
0008ooooo`;o00001?ooool2o`0000Sooooo00Co0000oooooooooooooooo0_l000001?nHV9Sooooo
oiRHV?mgMgL3ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool2o`0001Kooooo0_l000001?oo
ooooV9RHob4Q8Oo^k^h2o`0000;ooooo0_l000001?nHV9SooooooiRHV?mgMgL3ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02Oooool2o`0000Kooooo1?l00009ooooo`;o00001oooool2o`000004okZj
^_ooooooMgMgoc8b<P?ooooo00GoMgMgo`000?l0003oV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00_ooool2o`0000Cooooo1?l00007ooooo`;o00005_ooool02_l0003oooooo`000?l0
003oooooogMgMonHV9SooooooiRHV?mgMgL3ooooo`06ogMgMonHV9SooooooiRHV?mgMgOooooo0_l0
0002ooooo`;o00005?ooool2o`0000oooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000Yooooo`04o`000?oooooooooo
ooooo`?o00003?ooool2o`0001Kooooo0_l00008ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41003_ooool2o`0000Gooooo
0_l0000?ooooo`;o00000_ooool01?nHV9So8B4Qo`000?l00003ooooo`05oa0@4?oooooooooooooo
ool@41000oooool01Ol@413ooooooooooooooooo410@01?ooooo0_l00009ooooo`;o00001oooool2
o`0000?ooooo00Go0000oooooooooooooooooa0@4004o`0000?ooooo00Go410@oooooooooooooooo
oa0@4002ooooo`;o00001Oooool2o`0001Kooooo0_l00005ooooo`Go00000oooool01Ol@413ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`;o00008oooool01?l0
003oooooooooool@4103ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413ooooooooo
o`01ooooo`00:Oooool2o`0000;ooooo0ol0000^ooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooo000000;o00005Oooool2o`0001Cooooo00?o
V9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo
oooo0ol0000;ooooo`;o00002oooool2o`0000oooooo00?oZJVYoa0@4?ooool00_ooool00ol0003o
ooooooooo`02o`0000?ooooo00Go0000ooooooooooooooooo`00000Qooooo`;o00001Oooool01?m4
A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000Sooooo0_l0000Rooooo`05ogMgMolb<S;oooooooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool00Oooool002Wooooo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooo`000002o`0002cooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Co0000oooooooooooooooo0ol000000ooooooo0000o`000008ooooo`;o00002ooo
ool2o`000003ooooool0003o000000_ooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`00000Oooooo`;o00001oooool01?oMgMgo
EEEEooooool00004ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooo`000002
o`0000Gooooo0_l0000Rooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`00:Oooool00ol0003ooooo
ooooo`0[ooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@02gooooo00Go0000oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@41000_l000000ooooooo0000o`000002ooooo`;o00006?oo
ool3o`0000_ooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooooooooa0@400Oooooo`;o00002?ooool00omgMgOoc<c<o`000004ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413oooooo`000?l0003o410@00Gooooo0_l0000A
ooooo`;o00003Oooool3o`0000Kooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oo
ooooooooooooool@41000oooool002Wooooo00?o0000ooooooooool0:oooool2o`0000Gooooo0_l0
0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool2o`000004oiRHV?ooooooV9RHogMgM`;o
00009oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`05ogMgMol0003o0000oiRHV?mgMgL06_ooool2o`0000;ooooo0_l00008ooooo`05oa0@4?nH
V9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0Sooooo`;o00001?ooool00oo^k^koA4A4o`000004ooooo`03ogMgMonHV9Sooooo
00;o00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo0_l0000@ooooo`;o00002oooool5
o`0000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool002Wooooo00?o0000ooooooooool0<?ooool01OmEEEGoIVIVo`000?l0003ooooo00;o0000
00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`Co000000Co<S8bonk^k_l0003o00009oooool01OnH
V9So410@o`000?l0003oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h06_ooool2o`0000[ooooo0_l000001OnYZJWo410@o`000?l@413oZJVY00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool2
o`0001gooooo0_l00005ooooo`03ogMgMol0003ooooo00?ooooo00?ok^k^oc8b<_l000000_l00003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool2o`0000Kooooo0_l0000Eooooo`;o00000_oo
ool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool002Wooooo0_l0000Eooooo`;o00007oooool2o`0000Sooooo0_l0000Sooooo`;o0000
00?oooooo`000?l000001_ooool2o`0000;ooooo0_l0000Dooooo`;o00007Oooool2o`0001Wooooo
0ol0000Iooooo`;o00003?ooool2o`0001_ooooo0_l0000<ooooo`;o00008_ooool002Wooooo00Co
0000oooooooooooooooo1?l0000?ooooo`;o0000:_ooool2o`0000Oooooo1?l0000Gooooo`Go0000
2_ooool2o`0000Oooooo0_l000000ooooooo0000o`000008ooooo`;o0000>Oooool2o`0001Wooooo
0_l0000<ooooo`;o0000:Oooool2o`0002;ooooo000Yooooo`So00008_ooool2o`0001Oooooo0_l0
0007ooooo`Co00006Oooool2o`0000Kooooo0_l0000<ooooo`;o000000?oooooo`000?l000005ooo
ool2o`00027ooooo0_l0001Fooooo`;o00009oooool002Wooooo1?l0000Aooooo`;o00004oooool2
o`0000?ooooo0_l0000Pooooo`;o00007_ooool2o`0002Sooooo0_l0000Qooooo`;o000000?ooooo
o`000?l00000<oooool2o`0000Wooooo0_l0000<ooooo`;o00001Oooool2o`0001;ooooo0_l0000C
ooooo`00:Oooool2o`0001?ooooo0_l0000;ooooo`;o00001_ooool2o`0000?ooooo0_l0000Poooo
o`;o00007Oooool4o`0000Sooooo0_l0000cooooo`Co00003?ooool2o`0000_ooooo0_l0000<oooo
o`;o00006?ooool2o`0000Wooooo0_l0000<ooooo`;o00006Oooool2o`0001?ooooo000Qoooooooo
0000A?l00004ooooo`00:Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo
0_l00005ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Kooooo0_l00002ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02Oooool01?l0003oooooooooooooool2o`0000Kooooo00?o0000oooooooo
ool02_ooool01?l0003oooooo`000?l00007ooooo`;o00001oooool2o`0000;ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`04o`000?oooooo0000o`0000Sooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo000000?o00001_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo0_l00003ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool01oooool3o`0000cooooo000Yooooo`03o`000?oooooooooo
00;o00003Oooool4o`0001Gooooo0_l0000@ooooo`03o`000?oooooooooo00Kooooo0_l0000Foooo
o`;o00001_ooool2o`0001?ooooo00Co0000ooooool0003o00004?ooool2o`0000[ooooo0_l0000=
ooooo`;o00000_ooool4o`0000Kooooo00?o0000ooooooooool07oooool2o`0001Wooooo00?o0000
ooooooooool00oooool2o`0001Gooooo0_l0000Looooo`?o00003?ooool002Wooooo00?o0000oooo
ooooool00_l0000?ooooo`;o00005Oooool2o`00037ooooo0_l0000>ooooo`;o00005?ooool2o`00
01Gooooo0_l0000=ooooo`;o00001?ooool2o`0002Sooooo0_l0000:ooooo`;o00002Oooool2o`00
00Sooooo0_l0000Eooooo`;o00003_ooool2o`0001_ooooo000Yooooo`03o`000?oooooooooo00_o
oooo0_l0000looooo`;o00004?ooool2o`0000kooooo0_l0000;ooooo`;o00001oooool2o`0004?o
oooo0_l00006ooooo`;o00001?ooool2o`0000;ooooo0_l00009ooooo`;o00001Oooool2o`0000;o
oooo1?l00004ooooo`;o00004?ooool2o`0000;ooooo0_l0000Aooooo`;o00001oooool2o`0001;o
oooo000Yooooo`;o00001_ooool2o`0000Cooooo0_l0000looooo`;o0000;Oooool3o`0001;ooooo
0_l0000Dooooo`;o00008Oooool2o`0000Gooooo0ol00004ooooo`;o00000_ooool2o`0000Wooooo
0_l00005ooooo`;o00001?ooool2o`0000Cooooo0_l0000@ooooo`;o00000_ooool2o`0001Oooooo
0_l000000ooooooo0000o`00000Booooo`00:Oooool00ol0003oooooooooo`05ooooo`;o0000<ooo
ool2o`0001Sooooo0_l0000Sooooo`;o00000_ooool2o`0000kooooo0_l0000Cooooo`?o00000ooo
ool2o`0000;ooooo0_l00004ooooo`;o00006Oooool4o`0001;ooooo0_l0000]ooooo`;o00004Ooo
ool2o`0001Gooooo000Yooooo`04o`000?oooooo0000o`0003Oooooo1?l000000ooooooo0000o`00
0003ooooo`;o00004?ooool2o`0002Kooooo0ol0000Rooooo`?o00001?ooool2o`0000;ooooo0_l0
0004ooooo`;o00001_ooool2o`0000[ooooo0_l00007ooooo`;o0000;_ooool2o`00017ooooo0_l0
0006ooooo`;o000000?oooooo`000?l000002_ooool2o`00017ooooo000Yooooo`04o`000?oooooo
0000o`0001Kooooo0_l000000ooooooo0000o`00000>ooooo`;o00003?ooool2o`0000?ooooo0_l0
0002ooooo`?o0000<oooool2o`0000;ooooo1?l0000Rooooo`;o00005oooool2o`0000[ooooo1?l0
000eooooo`;o00006Oooool2o`000003ooooool0003o000000[ooooo0_l0000Aooooo`00:Oooool0
0ol0003oooooooooo`07ooooo`Co00000_ooool2o`0000Sooooo1Ol0000>ooooo`;o00000oooool2
o`00013ooooo0_l0000Aooooo`;o00008Oooool2o`0000;ooooo1?l00009ooooo`;o0000<?ooool2
o`0000cooooo0_l0000Dooooo`;o00003oooool2o`0000_ooooo0_l0000=ooooo`;o00002Oooool2
o`0002Cooooo000Yooooo`;o00002?ooool4o`0000;ooooo0_l0000:ooooo`;o000000?oooooo`00
0?l000004Oooool2o`0000Oooooo0_l000000ooooooo0000o`00000Gooooo`;o0000<_ooool2o`00
01?ooooo0_l0000Fooooo`;o00002Oooool2o`0001cooooo0_l0000>ooooo`?o00002oooool2o`00
00gooooo0_l00009ooooo`;o000000?oooooo`000?l000008Oooool002Wooooo00?o0000oooooooo
ool07?ooool2o`0001[ooooo0_l000000ooooooo0000o`000003ooooo`;o0000C_ooool4o`0000Wo
oooo0_l0000Fooooo`;o00002Oooool2o`0001Sooooo0_l0000Booooo`;o00001oooool2o`0001oo
oooo0ol0000Qooooo`00:Oooool00ol0003oooooooooo`02ooooo`Co00000_ooool2o`0001_ooooo
0_l00002ooooo`;o00005Oooool2o`0000Sooooo0_l00005ooooo`;o0000?Oooool4o`0000kooooo
0_l0000:ooooo`;o00009_ooool2o`0000;ooooo0_l0000Kooooo`;o00007oooool2o`0000cooooo
0_l0000Dooooo`00:Oooool00ol0003oooooooooo`02ooooo`Go000000?oooooo`000?l000006ooo
ool2o`0000;ooooo0_l0000Kooooo`;o00000_ooool2o`0000Gooooo0_l0001?ooooo`;o000000?o
ooooo`000?l000001oooool2o`0002Kooooo0_l000000ooooooo0000o`00000/ooooo`;o00007Ooo
ool2o`0001Cooooo000Yooooo`03o`000?oooooooooo00Gooooo0_l0000Cooooo`;o00008?ooool2
o`0000Sooooo0_l00005ooooo`;o0000>oooool2o`0001Wooooo1?l0000`ooooo`;o00006_ooool2
o`00013ooooo0_l0000Eooooo`;o00007?ooool002Wooooo0_l0000Kooooo`;o000000?oooooo`00
0?l000003?ooool2o`0000oooooo1?l0000=ooooo`;o00002Oooool2o`0000cooooo1?l0000<oooo
o`;o00003?ooool2o`0000Cooooo0_l0000>ooooo`;o00002oooool2o`0003Sooooo0_l0000Boooo
o`;o00005_ooool2o`0000oooooo0_l0000Looooo`00:Oooool00ol0003oooooooooo`0<ooooo`;o
00002?ooool2o`0000Gooooo0_l0000<ooooo`;o00004Oooool2o`0001?ooooo0_l000000ooooooo
0000o`000002o`0000cooooo1?l00008ooooo`;o00000_ooool2o`0000cooooo0_l0000Dooooo`;o
000000?oooooo`000?l000001_ooool2o`0000Kooooo0_l00009ooooo`;o00000oooool2o`00017o
oooo0_l0000?ooooo`;o00004Oooool2o`0001Oooooo0_l000000ooooooo0000o`00000Zooooo`00
:Oooool00ol0003oooooooooo`0<ooooo`;o00002?ooool2o`0003Oooooo0_l00002ooooo`;o0000
00?oooooo`000?l000006_ooool2o`0002Wooooo0_l00006ooooo`;o00001_ooool2o`0000Oooooo
1?l000000ooooooo0000o`000002o`00017ooooo0_l0000=ooooo`;o00000oooool2o`0000kooooo
0_l0000>ooooo`;o00002_ooool2o`0002[ooooo000Yooooo`03o`000?oooooooooo02gooooo0_l0
00000ooooooo0000o`00000Mooooo`;o0000?_ooool2o`0002Gooooo0ol00002ooooo`;o00008_oo
ool2o`0000?ooooo0_l0000Nooooo`;o00005_ooool2o`0000Cooooo0_l000000ooooooo0000o`00
000Eooooo`00:Oooool00ol0003oooooooooo`0]ooooo`;o000000?oooooo`000?l000005_ooool2
o`0004Gooooo0ol0000Aooooo`;o0000;_ooool2o`0000?ooooo0_l00002ooooo`;o0000:oooool2
o`0000?ooooo0_l0000<ooooo`?o000000?oooooo`000?l000000_l000000ooooooo0000o`00000E
ooooo`00:Oooool2o`0001Kooooo0_l0000Rooooo`;o00003Oooool2o`000003ooooool0003o0000
01;ooooo0_l0000@ooooo`;o00007Oooool2o`00017ooooo0_l0000Pooooo`;o00001oooool2o`00
00?ooooo0_l00003ooooo`;o00000_ooool2o`0002Sooooo0_l000000ooooooo0000o`000003oooo
o`;o00003Oooool2o`000003ooooool0003o000001[ooooo000Yooooo`03o`000?oooooooooo01Go
oooo0_l0000Rooooo`;o00004?ooool2o`000003ooooool0003o000000oooooo0_l0000@ooooo`;o
0000D_ooool2o`0000Oooooo0_l0000fooooo`;o0000=?ooool000Kooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo00Wooooo0_l0000<ooooo`;o0000=Oooool2o`000003ooooool0003o0000
07[ooooo0_l0000<ooooo`;o0000D_ooool2o`0000_ooooo0006ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool02Oooool2o`0000Oooooo0_l00003ooooo`;o0000>?ooool2
o`0000oooooo0_l0000Kooooo`;o00001?ooool2o`0001Cooooo0_l0000`ooooo`;o00003?ooool2
o`0003?ooooo0_l0000@ooooo`;o00002?ooool2o`000003ooooool0003o000000_ooooo0006oooo
o`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool04_ooool2o`0000Oooooo1Ol00012ooooo`;o00006oooool2
o`0000Cooooo0_l0000Dooooo`;o00001oooool2o`0001Kooooo0_l00014ooooo`;o00003?ooool2
o`00013ooooo1?l00006ooooo`;o00003_ooool000Kooooo00Go0000ooooooooooooooooo`00000=
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0001_ooooo1ol00022
ooooo`;o00005_ooool2o`0004Cooooo0_l0000Pooooo`;o00002?ooool2o`0000cooooo0006oooo
o`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Pooooo`;o0000B_ooool2o`0005Gooooo0_l0
000;ooooo`;o0000G?ooool2o`0000cooooo0006ooooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0K?oo
ool2o`0004?ooooo0ol0000=ooooo`Co00001Oooool2o`0000Cooooo0_l00013ooooo`;o00009Ooo
ool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo0_l00002ooooo`;o0000
?Oooool2o`0006;ooooo0ol0000=ooooo`;o00001oooool2o`0002Kooooo0_l0000Qooooo`;o0000
9Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`01?ooool4o`0000Kooooo0_l0000;ooooo`;o00000_ooool3o`0001gooooo0_l0000Mooooo`;o
00007?ooool2o`0001cooooo0_l0000Xooooo`;o00005oooool2o`0000Sooooo0_l00004ooooo`;o
00002?ooool3o`0000?ooooo0_l00004ooooo`;o00009oooool2o`0000kooooo0_l0000?ooooo`00
:Oooool2o`0000_ooooo0_l00003ooooo`;o00007Oooool2o`0001Sooooo0_l0000Qooooo`;o0000
7?ooool2o`0002Sooooo0_l0000Gooooo`;o00001Oooool2o`000003ooooool0003o000000Cooooo
0_l00008ooooo`?o00000oooool2o`0001cooooo0_l0000?ooooo`;o00003_ooool2o`0000oooooo
000Yooooo`03o`000?oooooooooo00[ooooo0_l00008ooooo`;o00003Oooool2o`0000Gooooo0_l0
000Looooo`;o0000ROooool2o`0001;ooooo0_l0000Qooooo`;o0000<?ooool002Wooooo00?o0000
ooooooooool05?ooool2o`0000gooooo0_l00005ooooo`;o0000Joooool2o`00017ooooo0_l0000j
ooooo`;o0000E?ooool002Wooooo00?o0000ooooooooool0Uoooool2o`00017ooooo0_l0000hoooo
o`Co0000E?ooool002Wooooo00?o0000ooooooooool0D?ooool2o`000003ooooool0003o000000So
oooo0_l0001Jooooo`;o00002_ooool2o`0000kooooo0_l0000=ooooo`;o0000E_ooool002Wooooo
0_l0000=ooooo`;o00009_ooool2o`0001[ooooo0_l000000ooooooo0000o`000008ooooo`;o0000
F_ooool2o`0000[ooooo0_l0000>ooooo`;o00004_ooool2o`0002Wooooo0_l0000Vooooo`00:Ooo
ool00ol0003oooooooooo`0<ooooo`;o00001Oooool2o`0001Sooooo0_l00005ooooo`;o0000:?oo
ool4o`0000oooooo0_l0000hooooo`;o0000??ooool2o`0002Wooooo0_l0000Vooooo`00:Oooool0
0ol0003oooooooooo`0Cooooo`Co00001Oooool2o`0000oooooo0_l0000Gooooo`;o00002?ooool2
o`0000cooooo1?l0000?ooooo`;o0000>?ooool2o`0003Sooooo0_l0001Eooooo`00:Oooool00ol0
003oooooooooo`0Eooooo`;o00001Oooool2o`0002Sooooo0_l00008ooooo`;o00002_ooool2o`00
0003ooooool0003o000000;o00007oooool2o`00017ooooo0_l00002ooooo`;o0000;_ooool2o`00
01[ooooo0_l0001Eooooo`00:Oooool00ol0003oooooooooo`1Looooo`;o000000?oooooo`000?l0
00000_l00002ooooo`;o00001Oooool4o`0001;ooooo0_l0000Aooooo`;o00000_ooool2o`0000_o
oooo0_l0000Qooooo`;o0000LOooool002Wooooo0_l0001Vooooo`;o00001Oooool4o`0003Kooooo
0_l0000eooooo`;o0000GOooool002Wooooo00?o0000ooooooooool0gOooool2o`0005gooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`0Rooooo`;o0000KOooool2o`0000Cooooo0_l0001Booooo`;o
0000;Oooool2o`0000Cooooo0_l0000Jooooo`00:Oooool2o`0002?ooooo0_l0001Aooooo`;o0000
6_ooool2o`0000Cooooo0_l0001Booooo`;o00006?ooool2o`0001?ooooo0_l00004ooooo`;o0000
6_ooool002Wooooo00?o0000ooooooooool0M?ooool3o`0007[ooooo0_l0000Booooo`;o0000=Ooo
ool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Gooooo00?o0000ooooooooool0M?ooool2o`0001Cooooo0_l0000Xooooo`;o0000
3?ooool2o`0002gooooo0_l00019ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0Aoooool2o`0002Wooooo
0_l0000Fooooo`;o00000_ooool2o`0002Cooooo0_l0000<ooooo`;o0000=_ooool2o`0000Cooooo
0_l0000jooooo`003_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool0
0oooool3o`0004Oooooo0_l0000@ooooo`;o00005oooool2o`0001[ooooo0_l0000^ooooo`;o0000
>_ooool2o`0000Cooooo0_l00005ooooo`;o0000<oooool000kooooo00Go0000oooooooooooooooo
o`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0FOooool2o`0006?ooooo
0_l00017ooooo`;o0000<oooool000kooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo?Oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`13ooooo`;o0000
iOooool2o`00013ooooo000Yooooo`03o`000?oooooooooo04?ooooo0_l0003Uooooo`;o00004?oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3Xoooo
o`;o0000D_ooool002Wooooo0_l0002gooooo`;o0000<?ooool2o`0005;ooooo000Yooooo`03o`00
0?oooooooooo05Oooooo0_l0001Mooooo`;o0000Q?ooool002Wooooo00?o0000ooooooooool0Eooo
ool2o`000>?ooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oo
oooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o
0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0
oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEE
EOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo
0006ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`00
0?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`000?ooooooooooooooool00000
3_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool0
0oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolmooooo`00
1_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003ooooo
ockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003ooooo
ockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`007oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooo
oolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo?Oooool0
027ooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`007oooool00omE
EEGoIVIVo`00003oooooodOooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .23865 Mdot
.02762 .3586 Mdot
.02952 .27536 Mdot
.03143 .33603 Mdot
.03333 .35437 Mdot
.03524 .37906 Mdot
.03714 .28173 Mdot
.03905 .22611 Mdot
.04095 .37762 Mdot
.04286 .32591 Mdot
.04476 .34624 Mdot
.04667 .24006 Mdot
.04857 .40382 Mdot
.05048 .3517 Mdot
.05238 .24327 Mdot
.05429 .29707 Mdot
.05619 .29004 Mdot
.0581 .40067 Mdot
.06 .29307 Mdot
.0619 .28763 Mdot
.06381 .39935 Mdot
.06571 .39601 Mdot
.06762 .40205 Mdot
.06952 .39383 Mdot
.07143 .33532 Mdot
.07333 .29998 Mdot
.07524 .32252 Mdot
.07714 .27467 Mdot
.07905 .31703 Mdot
.08095 .36088 Mdot
.08286 .38717 Mdot
.08476 .37534 Mdot
.08667 .25497 Mdot
.08857 .24615 Mdot
.09048 .33436 Mdot
.09238 .23321 Mdot
.09429 .42858 Mdot
.09619 .25365 Mdot
.0981 .33809 Mdot
.1 .26074 Mdot
.1019 .34571 Mdot
.10381 .28768 Mdot
.10571 .38486 Mdot
.10762 .24777 Mdot
.10952 .25087 Mdot
.11143 .27581 Mdot
.11333 .34674 Mdot
.11524 .41156 Mdot
.11714 .37512 Mdot
.11905 .2983 Mdot
.12095 .41449 Mdot
.12286 .38637 Mdot
.12476 .23555 Mdot
.12667 .36471 Mdot
.12857 .37638 Mdot
.13048 .32491 Mdot
.13238 .22565 Mdot
.13429 .28971 Mdot
.13619 .43203 Mdot
.1381 .26502 Mdot
.14 .26223 Mdot
.1419 .46267 Mdot
.14381 .34072 Mdot
.14571 .31494 Mdot
.14762 .2717 Mdot
.14952 .34959 Mdot
.15143 .3154 Mdot
.15333 .31935 Mdot
.15524 .25252 Mdot
.15714 .38206 Mdot
.15905 .25422 Mdot
.16095 .31783 Mdot
.16286 .3271 Mdot
.16476 .27675 Mdot
.16667 .34034 Mdot
.16857 .31349 Mdot
.17048 .23582 Mdot
.17238 .24869 Mdot
.17429 .37107 Mdot
.17619 .36066 Mdot
.1781 .32026 Mdot
.18 .35303 Mdot
.1819 .32052 Mdot
.18381 .30107 Mdot
.18571 .25532 Mdot
.18762 .27877 Mdot
.18952 .35017 Mdot
.19143 .33306 Mdot
.19333 .31352 Mdot
.19524 .31583 Mdot
.19714 .33882 Mdot
.19905 .34979 Mdot
.20095 .26124 Mdot
.20286 .30879 Mdot
.20476 .27528 Mdot
.20667 .37261 Mdot
.20857 .35118 Mdot
.21048 .41358 Mdot
.21238 .24887 Mdot
.21429 .30263 Mdot
.21619 .24394 Mdot
.2181 .34175 Mdot
.22 .23571 Mdot
.2219 .26508 Mdot
.22381 .34442 Mdot
.22571 .25395 Mdot
.22762 .24575 Mdot
.22952 .32423 Mdot
.23143 .26059 Mdot
.23333 .38076 Mdot
.23524 .34544 Mdot
.23714 .335 Mdot
.23905 .38006 Mdot
.24095 .23854 Mdot
.24286 .42731 Mdot
.24476 .32792 Mdot
.24667 .25093 Mdot
.24857 .3196 Mdot
.25048 .34579 Mdot
.25238 .42209 Mdot
.25429 .40439 Mdot
.25619 .45391 Mdot
.2581 .40698 Mdot
.26 .327 Mdot
.2619 .37986 Mdot
.26381 .34065 Mdot
.26571 .25011 Mdot
.26762 .40473 Mdot
.26952 .29423 Mdot
.27143 .30407 Mdot
.27333 .40407 Mdot
.27524 .26548 Mdot
.27714 .26605 Mdot
.27905 .3732 Mdot
.28095 .38981 Mdot
.28286 .35777 Mdot
.28476 .42816 Mdot
.28667 .28564 Mdot
.28857 .32272 Mdot
.29048 .23641 Mdot
.29238 .25178 Mdot
.29429 .46018 Mdot
.29619 .2945 Mdot
.2981 .26264 Mdot
.3 .28821 Mdot
.3019 .26036 Mdot
.30381 .27966 Mdot
.30571 .47391 Mdot
.30762 .32274 Mdot
.30952 .31882 Mdot
.31143 .44912 Mdot
.31333 .3498 Mdot
.31524 .27115 Mdot
.31714 .39111 Mdot
.31905 .31011 Mdot
.32095 .34964 Mdot
.32286 .41598 Mdot
.32476 .35851 Mdot
.32667 .32404 Mdot
.32857 .42745 Mdot
.33048 .41929 Mdot
.33238 .349 Mdot
.33429 .37423 Mdot
.33619 .35021 Mdot
.3381 .2526 Mdot
.34 .38057 Mdot
.3419 .23938 Mdot
.34381 .28963 Mdot
.34571 .32277 Mdot
.34762 .25348 Mdot
.34952 .41996 Mdot
.35143 .25919 Mdot
.35333 .26032 Mdot
.35524 .27018 Mdot
.35714 .35154 Mdot
.35905 .34008 Mdot
.36095 .25578 Mdot
.36286 .38389 Mdot
.36476 .3552 Mdot
.36667 .32144 Mdot
.36857 .32271 Mdot
.37048 .40779 Mdot
.37238 .29032 Mdot
.37429 .25654 Mdot
.37619 .35653 Mdot
.3781 .26319 Mdot
.38 .3865 Mdot
.3819 .40891 Mdot
.38381 .37639 Mdot
.38571 .33868 Mdot
.38762 .38931 Mdot
.38952 .44101 Mdot
.39143 .26107 Mdot
.39333 .33346 Mdot
.39524 .45735 Mdot
.39714 .23728 Mdot
.39905 .39572 Mdot
.40095 .24713 Mdot
.40286 .32347 Mdot
.40476 .2908 Mdot
.40667 .25462 Mdot
.40857 .28735 Mdot
.41048 .29353 Mdot
.41238 .32201 Mdot
.41429 .35814 Mdot
.41619 .26472 Mdot
.4181 .2493 Mdot
.42 .31392 Mdot
.4219 .36948 Mdot
.42381 .33585 Mdot
.42571 .28729 Mdot
.42762 .34209 Mdot
.42952 .41159 Mdot
.43143 .24901 Mdot
.43333 .32125 Mdot
.43524 .26199 Mdot
.43714 .24084 Mdot
.43905 .25616 Mdot
.44095 .35308 Mdot
.44286 .26487 Mdot
.44476 .29347 Mdot
.44667 .24484 Mdot
.44857 .25324 Mdot
.45048 .42995 Mdot
.45238 .33442 Mdot
.45429 .29694 Mdot
.45619 .28703 Mdot
.4581 .36153 Mdot
.46 .34836 Mdot
.4619 .26053 Mdot
.46381 .24583 Mdot
.46571 .45908 Mdot
.46762 .3254 Mdot
.46952 .31127 Mdot
.47143 .26462 Mdot
.47333 .37081 Mdot
.47524 .32146 Mdot
.47714 .44701 Mdot
.47905 .25901 Mdot
.48095 .28284 Mdot
.48286 .40807 Mdot
.48476 .25725 Mdot
.48667 .46197 Mdot
.48857 .38855 Mdot
.49048 .27895 Mdot
.49238 .25504 Mdot
.49429 .36894 Mdot
.49619 .29046 Mdot
.4981 .40616 Mdot
.5 .34714 Mdot
.5019 .25794 Mdot
.50381 .34663 Mdot
.50571 .3866 Mdot
.50762 .32682 Mdot
.50952 .33373 Mdot
.51143 .41357 Mdot
.51333 .29964 Mdot
.51524 .27784 Mdot
.51714 .38707 Mdot
.51905 .30988 Mdot
.52095 .22883 Mdot
.52286 .42341 Mdot
.52476 .37454 Mdot
.52667 .32201 Mdot
.52857 .27894 Mdot
.53048 .32384 Mdot
.53238 .35608 Mdot
.53429 .24863 Mdot
.53619 .34854 Mdot
.5381 .38742 Mdot
.54 .23727 Mdot
.5419 .32776 Mdot
.54381 .23596 Mdot
.54571 .38255 Mdot
.54762 .32721 Mdot
.54952 .37157 Mdot
.55143 .41525 Mdot
.55333 .26011 Mdot
.55524 .35657 Mdot
.55714 .4083 Mdot
.55905 .34441 Mdot
.56095 .35589 Mdot
.56286 .34228 Mdot
.56476 .2854 Mdot
.56667 .25826 Mdot
.56857 .42655 Mdot
.57048 .22927 Mdot
.57238 .32961 Mdot
.57429 .28038 Mdot
.57619 .35737 Mdot
.5781 .23226 Mdot
.58 .3016 Mdot
.5819 .33955 Mdot
.58381 .40989 Mdot
.58571 .43296 Mdot
.58762 .23024 Mdot
.58952 .43199 Mdot
.59143 .3113 Mdot
.59333 .43518 Mdot
.59524 .44877 Mdot
.59714 .23998 Mdot
.59905 .23696 Mdot
.60095 .48884 Mdot
.60286 .36905 Mdot
.60476 .39193 Mdot
.60667 .27623 Mdot
.60857 .37094 Mdot
.61048 .33081 Mdot
.61238 .34999 Mdot
.61429 .41082 Mdot
.61619 .31317 Mdot
.6181 .26642 Mdot
.62 .41078 Mdot
.6219 .27441 Mdot
.62381 .40712 Mdot
.62571 .44207 Mdot
.62762 .32871 Mdot
.62952 .27585 Mdot
.63143 .26213 Mdot
.63333 .25456 Mdot
.63524 .31964 Mdot
.63714 .2955 Mdot
.63905 .41836 Mdot
.64095 .45344 Mdot
.64286 .33761 Mdot
.64476 .36993 Mdot
.64667 .30925 Mdot
.64857 .36285 Mdot
.65048 .3624 Mdot
.65238 .28046 Mdot
.65429 .29838 Mdot
.65619 .25333 Mdot
.6581 .2314 Mdot
.66 .40848 Mdot
.6619 .27643 Mdot
.66381 .40843 Mdot
.66571 .29435 Mdot
.66762 .32227 Mdot
.66952 .35229 Mdot
.67143 .38258 Mdot
.67333 .38117 Mdot
.67524 .34848 Mdot
.67714 .3601 Mdot
.67905 .22177 Mdot
.68095 .30721 Mdot
.68286 .33234 Mdot
.68476 .31554 Mdot
.68667 .2871 Mdot
.68857 .33075 Mdot
.69048 .27377 Mdot
.69238 .37022 Mdot
.69429 .2692 Mdot
.69619 .28683 Mdot
.6981 .46072 Mdot
.7 .23819 Mdot
.7019 .43593 Mdot
.70381 .23393 Mdot
.70571 .36537 Mdot
.70762 .24747 Mdot
.70952 .25359 Mdot
.71143 .36488 Mdot
.71333 .2371 Mdot
.71524 .44955 Mdot
.71714 .27109 Mdot
.71905 .26103 Mdot
.72095 .30265 Mdot
.72286 .36084 Mdot
.72476 .32103 Mdot
.72667 .37375 Mdot
.72857 .25275 Mdot
.73048 .22695 Mdot
.73238 .31779 Mdot
.73429 .35827 Mdot
.73619 .30008 Mdot
.7381 .36587 Mdot
.74 .24068 Mdot
.7419 .4067 Mdot
.74381 .27934 Mdot
.74571 .43321 Mdot
.74762 .3899 Mdot
.74952 .39908 Mdot
.75143 .43644 Mdot
.75333 .40098 Mdot
.75524 .31053 Mdot
.75714 .44923 Mdot
.75905 .42719 Mdot
.76095 .33757 Mdot
.76286 .29712 Mdot
.76476 .39725 Mdot
.76667 .31912 Mdot
.76857 .30364 Mdot
.77048 .30187 Mdot
.77238 .37963 Mdot
.77429 .27832 Mdot
.77619 .28976 Mdot
.7781 .26482 Mdot
.78 .31057 Mdot
.7819 .40507 Mdot
.78381 .31885 Mdot
.78571 .45465 Mdot
.78762 .29735 Mdot
.78952 .24677 Mdot
.79143 .21934 Mdot
.79333 .24395 Mdot
.79524 .3375 Mdot
.79714 .35275 Mdot
.79905 .2767 Mdot
.80095 .22755 Mdot
.80286 .23719 Mdot
.80476 .32524 Mdot
.80667 .26385 Mdot
.80857 .30826 Mdot
.81048 .26177 Mdot
.81238 .42317 Mdot
.81429 .3151 Mdot
.81619 .2519 Mdot
.8181 .30262 Mdot
.82 .26836 Mdot
.8219 .31594 Mdot
.82381 .33502 Mdot
.82571 .24427 Mdot
.82762 .29737 Mdot
.82952 .32133 Mdot
.83143 .45158 Mdot
.83333 .23769 Mdot
.83524 .30795 Mdot
.83714 .34541 Mdot
.83905 .24579 Mdot
.84095 .32915 Mdot
.84286 .3157 Mdot
.84476 .26096 Mdot
.84667 .40377 Mdot
.84857 .34594 Mdot
.85048 .29376 Mdot
.85238 .38417 Mdot
.85429 .26009 Mdot
.85619 .33169 Mdot
.8581 .36757 Mdot
.86 .2596 Mdot
.8619 .34382 Mdot
.86381 .36843 Mdot
.86571 .22437 Mdot
.86762 .26846 Mdot
.86952 .26651 Mdot
.87143 .34766 Mdot
.87333 .28065 Mdot
.87524 .35243 Mdot
.87714 .31853 Mdot
.87905 .26984 Mdot
.88095 .34437 Mdot
.88286 .28566 Mdot
.88476 .29046 Mdot
.88667 .32774 Mdot
.88857 .27102 Mdot
.89048 .22611 Mdot
.89238 .32653 Mdot
.89429 .36227 Mdot
.89619 .33867 Mdot
.8981 .2583 Mdot
.9 .24165 Mdot
.9019 .35736 Mdot
.90381 .25627 Mdot
.90571 .40312 Mdot
.90762 .29818 Mdot
.90952 .23393 Mdot
.91143 .38739 Mdot
.91333 .34817 Mdot
.91524 .43549 Mdot
.91714 .32182 Mdot
.91905 .31547 Mdot
.92095 .27119 Mdot
.92286 .24538 Mdot
.92476 .30376 Mdot
.92667 .28361 Mdot
.92857 .24621 Mdot
.93048 .46485 Mdot
.93238 .38838 Mdot
.93429 .31446 Mdot
.93619 .3783 Mdot
.9381 .3642 Mdot
.94 .32204 Mdot
.9419 .33448 Mdot
.94381 .36219 Mdot
.94571 .39035 Mdot
.94762 .31463 Mdot
.94952 .27922 Mdot
.95143 .34705 Mdot
.95333 .35625 Mdot
.95524 .26149 Mdot
.95714 .25716 Mdot
.95905 .26913 Mdot
.96095 .29855 Mdot
.96286 .42044 Mdot
.96476 .29242 Mdot
.96667 .35546 Mdot
.96857 .42903 Mdot
.97048 .24684 Mdot
.97238 .25452 Mdot
.97429 .30118 Mdot
.97619 .27003 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0??ooooo0_l00017ooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool0coooool2o`0002;ooooo0_l0000Fooooo`;o0000;oooool000Kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool01?l0003oooooooooooooool2o`0001cooooo0_l0002^ooooo`;o0000
3_ooool2o`0001Gooooo0_l0000Cooooo`;o00001_ooool2o`0002Oooooo0004o`0000;ooooo00Go
410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool0
0oooool01?l0003oooooooooooooool2o`0001cooooo0_l0001kooooo`;o00003_ooool2o`0000Co
oooo0_l0000[ooooo`;o00005Oooool2o`0001_ooooo0_l0000Wooooo`001_ooool01Ol0003ooooo
oooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o
00004_ooool2o`0008Sooooo0_l0000>ooooo`Co00000_ooool2o`0001Cooooo0_l0000=ooooo`;o
0000@?ooool2o`00027ooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOo
IVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Boooo
o`;o00002Oooool2o`0000cooooo0_l0000>ooooo`;o00005Oooool2o`00023ooooo0_l0000/oooo
o`?o00002Oooool2o`0000Gooooo0_l0000Aooooo`;o00003Oooool2o`000003ooooool0003o0000
01_ooooo0_l0000Pooooo`;o00008Oooool000Kooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool2o`0000Gooooo0_l0000Goooo
o`;o00003?ooool2o`0000kooooo0_l00005ooooo`;o00003_ooool2o`0000oooooo0_l0000?oooo
o`;o0000;?ooool3o`00013ooooo0_l0000Oooooo`;o00000_ooool2o`0001_ooooo0_l00008oooo
o`;o0000>Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`;o00001Oooool3o`0003_ooooo0_l0000O
ooooo`;o00007?ooool2o`0003;ooooo0_l0000Oooooo`;o00002oooool2o`0001cooooo0_l0000C
ooooo`;o00009?ooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool01Oooool2o`0000[ooooo0_l0
000Wooooo`;o00000_ooool2o`00047ooooo0_l000000ooooooo0000o`000004ooooo`;o0000Eooo
ool2o`0000oooooo0_l00008ooooo`;o00000_ooool2o`0001;ooooo0_l00005ooooo`Co00006ooo
ool002Wooooo0_l0000Booooo`;o00001?ooool2o`0001?ooooo0_l0000;ooooo`?o00000_ooool2
o`0003Kooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00004ooooo`;o00005?ooool2
o`0003Kooooo0_l0000Hooooo`Co00002?ooool2o`0000;ooooo0_l0000Iooooo`Co00003?ooool2
o`0000gooooo000Yooooo`03o`000?oooooooooo01Oooooo0ol0000=ooooo`;o00000oooool2o`00
00_ooooo0_l00009ooooo`;o00001?ooool2o`0000Oooooo0_l0000<ooooo`;o00004oooool2o`00
00?ooooo0_l00002ooooo`;o00007oooool2o`0003Kooooo0_l00005ooooo`;o00004Oooool2o`00
00Oooooo0_l0000`ooooo`;o00003Oooool002Wooooo00?o0000ooooooooool04?ooool2o`0000;o
oooo0_l00002ooooo`;o00003Oooool3o`0000Kooooo0_l0000;ooooo`;o00001Oooool2o`0000Co
oooo0_l00007ooooo`;o00003?ooool2o`000003ooooool0003o000000?ooooo0_l0000<ooooo`;o
00003?ooool2o`0000cooooo0_l0000[ooooo`;o00001_ooool2o`0000oooooo0_l00004ooooo`;o
00006_ooool2o`00033ooooo0_l0000=ooooo`00:Oooool00ol0003oooooooooo`0@ooooo`;o0000
0_ooool2o`0001;ooooo0_l00006ooooo`;o00002oooool2o`0002Gooooo0_l00003ooooo`;o0000
0_ooool2o`0000Sooooo0_l00009ooooo`;o000000?oooooo`000?l000002?ooool3o`000004oooo
ool0003o0000ooooo`;o00004oooool2o`0001?ooooo0_l00006ooooo`;o00003oooool2o`0003[o
oooo1?l0000?ooooo`;o00000oooool2o`0000gooooo000Yooooo`03o`000?oooooooooo01Gooooo
0_l0000Nooooo`;o00002?ooool2o`0001Gooooo0_l0000>ooooo`;o00001Oooool2o`0000?ooooo
0_l0000=ooooo`?o00001Oooool2o`0000Cooooo0ol00004ooooo`;o00003oooool2o`0000;ooooo
0_l0000Cooooo`;o00006_ooool2o`0001_ooooo0_l00009ooooo`;o000000?oooooo`000?l00000
0_l0000:ooooo`Co00003oooool2o`0001;ooooo000Yooooo`;o00005_ooool2o`0000[ooooo0ol0
000Aooooo`;o00001Oooool2o`000003ooooool0003o000001?ooooo1?l0000>ooooo`;o00001_oo
ool2o`0000;ooooo0_l00006ooooo`;o00001Oooool4o`0000Cooooo0_l000000ooooooo0000o`00
000Iooooo`;o00005oooool2o`0001[ooooo0_l0000Aooooo`;o00001oooool3o`0000Wooooo0_l0
00000ooooooo0000o`000002o`0001gooooo0_l0000Booooo`00:Oooool00ol0003oooooooooo`0Q
ooooo`?o00006?ooool2o`0000oooooo0ol00004ooooo`;o00006?ooool2o`0000[ooooo0_l00007
ooooo`;o00001oooool2o`0002gooooo0_l0000booooo`;o00001oooool2o`0000;ooooo0_l0000>
ooooo`;o0000;_ooool002Wooooo00?o0000ooooooooool0<?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02Oooool3o`0000[o
oooo0_l0000;ooooo`;o00001?ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h0:?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_l0003o0000oc8b<_o^k^h05Oooool2o`0000Go
oooo0_l0000<ooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;o00003_ooool2o`000004ooooool0003o0000ooooo`;o
00002Oooool2o`0000Kooooo00CoA4A4o`000?l0003o<S8b0_l000000oooooook^k^oc8b<P03o`00
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool00ol0003oooooooooo`0Toooo
o`;o00003?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01Kooooo0_l0000;ooooo`;o00001?ooool01OnHV9So8B4Qonk^
k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL0:?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`03ogMgMonHV9Sooooo00;o00005?ooool3o`0000Gooooo0_l0000=ooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL04?ooool2o`000004ooooool0003o0000ooooo`;o00002Oooool2o`0000Wooooo00OoMgMgo`00
0?l0003oooooogMgMonHV9Sooooo00;o00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
000Yooooo`?o00003Oooool2o`0000Wooooo0_l0000:ooooo`;o00001?ooool2o`0000Kooooo00Co
0000oooooooooooooooo0_l00003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`0Xooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4003oooo
o`05oa0@4?ooooooooooooooool@4100;?ooool01Ol0003ooooooooooooooooo410@00?ooooo00Go
410@ooooool0003o0000oa0@4002ooooo`Co00002?ooool2o`0000Sooooo0_l0000Booooo`Go0000
0oooool01Ol@413ooooooooooooooooo410@00;ooooo0_l00003ooooo`03oa0@4?oooooooooo02_o
oooo00Co0000oooooooooooo410@0oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@
ooooooooool00Oooool002Wooooo0ol0000=ooooo`;o00002Oooool2o`00013ooooo0_l00005oooo
o`;o00000oooool2o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
oooo013ooooo0_l0000Gooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000004?ooool2o`0000Kooooo0_l00003ooooo`;o0000
3?ooool2o`0000?ooooo00Ko0000ooooooooooooooooo`000?ooool3o`0000?ooooo0ol00005oooo
o`;o000000?oooooo`000?l000006Oooool2o`000005oooooom4A4CogMgMooooool000000oooool2
o`0000?ooooo00?o0000ooooooooool00_l00003ooooo`03o`000?oooooooooo00oooooo0_l0000G
ooooo`;o000000GoMgMgoc8b<_ooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`01ooooo`00:Oooool01?l0003oooooooooooooool2o`0002kooooo
0_l00004ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
01;ooooo0_l0000Hooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000003Oooool2o`000003ooooool0003o000000Kooooo0_l0
0003ooooo`;o00002oooool00ol@413o0000o`000003ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000Oooooo0_l0000Looooo`;o000000GoooooomgMgOmE
EEGoooooo`000003ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool03oooool2o`00013ooooo0_l00004ooooo`?o000000Go<S8bolc<c?ooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`01ooooo`00:Ooo
ool01?l0003oooooooooooooool2o`0002oooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@400=ooooo`;o00007_ooool01Ol0
003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oo
oooooooo00?ooooo0_l00006ooooo`;o00006Oooool2o`000003oooooonj^[[o8B4Q00?ooooo00Go
410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41005Oooool2o`0001;o
oooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooo
oooooooooooooa0@400Dooooo`;o00003Oooool2o`0000Cooooo00?o0000ooooooooool01?ooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`00:Ooo
ool00ol0003oooooooooo`07ooooo`Co00002oooool2o`0000Sooooo0_l0000@ooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03Oooool2o`0000;ooooo0_l0000<ooooo`;o00002?ooool01Ol0003o^[ZjoooooonHV9So410@
00?ooooo00?oMgMgoiRHV?ooool00_l00003ooooo`;o000000?ooooooiRHV?mgMgL01Oooool2o`00
027ooooo0_l000000ooooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo0_l000000ooooooo0000o`00000Booooo`03onk^k_m4
A4Co000000?ooooo0_l000001?nHV9SooooooiRHV?mgMgL3ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL05?ooool2o`0001?ooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool00ol0003oooooooooo`07oooo
o`Co00002oooool2o`0000Sooooo0_l0000>ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04Oooool2o`0000cooooo0_l0
0007ooooo`;o000000Co410@o`000?lQ8B7oc<c<0oooool00oo^k^ko<S8bo`000002o`0000?ooooo
0ol000000olb<S;ok^k^ooooo`0Aooooo`;o00005?ooool01OnYZJWo410@o`000?l@413oZJVY00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool2
o`0001Kooooo00?oMgMgo`000?ooool00_ooool2o`000004oc8b<_l0003o<S8bonk^kP?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0Eooooo`;o00004_ooool4o`0000;ooooo0_l000001?lb<S;o0000
oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool002Wooooo0_l00009ooooo`;o
0000@Oooool2o`0000Oooooo0_l0000Fooooo`;o00002Oooool4o`0000Wooooo0_l0000>ooooo`;o
0000:oooool2o`0000Sooooo0_l0000iooooo`;o00002Oooool2o`0001Sooooo0_l0000?ooooo`00
:Oooool00ol0003oooooooooo`06ooooo`;o00004oooool2o`0002kooooo0_l00007ooooo`;o0000
8oooool2o`0000Wooooo0_l000000ooooooo0000o`00000hooooo`;o00001?ooool2o`0000;ooooo
0_l0000Mooooo`;o00001_ooool2o`0000_ooooo0_l00005ooooo`;o00004?ooool2o`00013ooooo
0_l0000@ooooo`00:Oooool00ol0003oooooooooo`06ooooo`;o00001?ooool2o`0000gooooo0_l0
000Cooooo`;o0000EOooool2o`00017ooooo0_l0000Cooooo`;o00005_ooool2o`0001Sooooo0_l0
0007ooooo`Co00001?ooool2o`0000_ooooo0_l0000Gooooo`;o00004?ooool2o`0000;ooooo0_l0
000<ooooo`00:Oooool00ol0003oooooooooo`0<ooooo`;o00008_ooool2o`0000Sooooo0_l0000@
ooooo`;o0000C?ooool2o`0001?ooooo0_l0000[ooooo`;o00000oooool2o`0000Wooooo0_l0000>
ooooo`;o00008?ooool2o`0000kooooo0_l0000<ooooo`00:Oooool00ol0003oooooooooo`0foooo
o`;o00000_ooool2o`00013ooooo0_l00022ooooo`;o00002_ooool2o`0000kooooo0_l0000;oooo
o`;o000000?oooooo`000?l000000oooool2o`0001_ooooo0_l0000Looooo`008Oooooooo`0004Co
00001?ooool002Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Wooooo0ol00006ooooo`;o000000?oooooo`000?ooool00oooool2o`0000Gooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo
0_l00002ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool01?l0003ooooo
ooooooooool2o`0000Kooooo00?o0000ooooooooool01Oooool2o`0000;ooooo00?o0000oooooooo
ool02Oooool2o`0000_ooooo00?o0000ooooooooool01oooool3o`0000Gooooo0_l00004ooooo`04
o`000?ooooooooooooooo`;o00001_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Wooooo0ol00006ooooo`;o000000?oooooo`000?ooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool3o`000003ooooool0003o0000
00Sooooo00?o0000ooooooooool02_ooool002Wooooo00?o0000ooooooooool03_ooool2o`0001?o
oooo1?l000001?oooooo0000o`000?ooool2o`0000Kooooo0_l00005ooooo`03o`000?oooooooooo
03_ooooo00Co0000oooooooooooooooo0_l0000gooooo`03o`000?oooooooooo00?ooooo0_l0000D
ooooo`;o00003Oooool2o`00013ooooo00?o0000ooooooooool01Oooool2o`000003ooooool0003o
000000Gooooo0_l0000Fooooo`;o00000oooool2o`0000;ooooo0_l00008ooooo`03o`000?oooooo
oooo00[ooooo000Yooooo`03o`000?oooooooooo00kooooo0_l0000Eooooo`Go00001?ooool3o`00
00;ooooo0_l0000@ooooo`;o00004Oooool2o`0002Kooooo0_l0000oooooo`;o00003_ooool2o`00
00_ooooo1?l00009ooooo`;o00001?ooool2o`0000Oooooo0_l000000ooooooo0000o`000005oooo
o`;o00002Oooool2o`0000_ooooo0_l0000Nooooo`00:Oooool00ol0003oooooooooo`0=ooooo`;o
00005oooool2o`0000Kooooo0ol0000=ooooo`;o00001Oooool2o`0000[ooooo0_l00005ooooo`;o
00001?ooool2o`0000Cooooo0_l00005ooooo`;o00002Oooool2o`000003ooooool0003o000000Go
oooo0_l0000;ooooo`;o00003oooool3o`00023ooooo0_l00008ooooo`;o00004Oooool2o`0000_o
oooo0_l00004ooooo`;o00003?ooool2o`0000kooooo0_l0000;ooooo`;o00001Oooool2o`0001Oo
oooo000Yooooo`;o00000oooool2o`0000Wooooo0_l0000@ooooo`;o00002?ooool2o`0001?ooooo
0_l00008ooooo`;o00001oooool2o`0000Gooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo
0_l00009ooooo`;o000000?oooooo`000?l000004?ooool4o`0000Wooooo0_l00004ooooo`?o0000
1?ooool2o`0002Cooooo0_l0000Zooooo`;o00001_ooool2o`0001?ooooo0_l00006ooooo`;o0000
1Oooool2o`0001Oooooo000Yooooo`03o`000?oooooooooo00;ooooo0_l0000Kooooo`;o00002?oo
ool2o`0001Sooooo0_l00003ooooo`;o0000@Oooool2o`0000_ooooo0_l00009ooooo`Co00001_oo
ool2o`0000oooooo0_l0000gooooo`;o00002_ooool2o`0000gooooo1?l0000Vooooo`00:Oooool0
0ol0003oooooooooo`0booooo`;o00003oooool2o`0002kooooo0_l0000^ooooo`;o00002?ooool2
o`0000[ooooo0_l00003ooooo`;o00004?ooool4o`0002oooooo0_l00003ooooo`;o00002?ooool2
o`0002Sooooo000Yooooo`04o`000?oooooo0000o`0000_ooooo0_l00004ooooo`;o00007_ooool2
o`0000gooooo0_l0000`ooooo`;o00002?ooool2o`0000Oooooo0_l0000@ooooo`;o00007oooool2
o`0001Gooooo1?l0000Zooooo`;o00002?ooool2o`0001Wooooo0_l0000Gooooo`00:Oooool01?l0
003oooooo`000?l0000;ooooo`;o00001?ooool4o`0001kooooo0_l0000;ooooo`;o0000;_ooool2
o`0000[ooooo0_l00007ooooo`;o00004?ooool2o`0001Kooooo0_l0000Aooooo`;o00009?ooool2
o`0000Wooooo0_l00008ooooo`;o00005Oooool2o`0000cooooo0_l0000Gooooo`00:Oooool2o`00
01Gooooo0_l0000=ooooo`;o00001Oooool2o`0000Sooooo0_l00005ooooo`;o00003?ooool2o`00
01gooooo0_l00007ooooo`;o00002oooool2o`0002[ooooo0_l00004ooooo`;o00004Oooool2o`00
02Cooooo0_l00009ooooo`;o00007oooool2o`0002Gooooo000Yooooo`03o`000?oooooooooo01Go
oooo0_l0000<ooooo`;o00001Oooool2o`0000oooooo1?l000000ooooooo0000o`000003ooooo`;o
00000_ooool2o`0001gooooo0_l0000Dooooo`;o0000:?ooool4o`0005Kooooo0_l000000ooooooo
0000o`000003ooooo`;o00001?ooool2o`0002[ooooo000Yooooo`03o`000?oooooooooo00?ooooo
0_l0000@ooooo`;o00000_ooool2o`0002;ooooo0_l000000ooooooo0000o`000003ooooo`;o0000
6?ooool2o`0002Sooooo0_l0000:ooooo`Co00002?ooool2o`0000Gooooo0_l0000Tooooo`;o0000
<_ooool2o`000003ooooool0003o000000?ooooo0_l000001?oooooo0000o`000?ooool2o`0000So
oooo0_l0000;ooooo`;o00004oooool002Wooooo00?o0000ooooooooool00oooool4o`0001;ooooo
0_l0000:ooooo`;o00002oooool2o`000004ooooool0003o0000ooooo`;o00007oooool2o`000004
ooooool0003o0000ooooo`Co00001?ooool2o`00023ooooo0_l0000:ooooo`Co00002?ooool2o`00
01Oooooo0_l0000@ooooo`Co0000?Oooool2o`0000_ooooo0_l0000;ooooo`;o00004oooool002Wo
oooo00Co0000ooooool0003o00001?ooool2o`0001kooooo0_l00007ooooo`;o00000_ooool2o`00
0004ooooool0003o0000ooooo`;o00007oooool2o`000003ooooool0003o000000?ooooo0_l00004
ooooo`;o000000?oooooo`000?l000005_ooool2o`0003Kooooo0_l0000@ooooo`;o00009oooool2
o`0001Oooooo0_l0000Kooooo`;o00003oooool002Wooooo1?l0000]ooooo`;o00008?ooool2o`00
00_ooooo0_l0000;ooooo`;o00000_ooool2o`0000[ooooo0_l00006ooooo`;o00007?ooool2o`00
00Gooooo1?l00003ooooo`;o0000<Oooool2o`0001;ooooo0_l0000Gooooo`;o00001oooool2o`00
00kooooo0_l00002ooooo`;o00003oooool002Wooooo0_l0000@ooooo`;o00007?ooool2o`00027o
oooo0_l0000;ooooo`;o00003oooool2o`0000[ooooo0_l0000<ooooo`;o00005_ooool2o`0000Go
oooo1?l00003ooooo`;o00007_ooool2o`0000gooooo0_l00002ooooo`;o0000=?ooool2o`0000ko
oooo0_l0000Cooooo`00:Oooool2o`00013ooooo0_l0000<ooooo`;o00003_ooool2o`0005Wooooo
0_l0000kooooo`?o00001_ooool2o`0000gooooo0_l0000eooooo`;o00003?ooool4o`0001Kooooo
000Yooooo`03o`000?oooooooooo01gooooo0_l0002Vooooo`?o00004?ooool3o`0000Oooooo0_l0
000Uooooo`;o00002Oooool2o`0000cooooo1?l0000Fooooo`00:Oooool00ol0003oooooooooo`1l
ooooo`;o00003oooool2o`0000Gooooo0_l0000Pooooo`Co00002_ooool2o`0000gooooo0_l00003
ooooo`?o00001oooool2o`0002Gooooo0ol0000`ooooo`00:Oooool2o`0002kooooo0_l00008oooo
o`;o00005Oooool2o`0002cooooo0_l0000?ooooo`;o00001Oooool2o`0000oooooo0_l0000?oooo
o`Co00002_ooool2o`0000gooooo0_l00009ooooo`;o0000:_ooool2o`00033ooooo000Yooooo`03
o`000?oooooooooo013ooooo0_l00008ooooo`;o00000_ooool2o`0000gooooo0_l00008ooooo`;o
00005Oooool2o`00013ooooo0_l0000>ooooo`;o0000:oooool2o`0000Kooooo0_l0000gooooo`;o
0000G?ooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00Co00003?ooool2o`00
00Sooooo0_l00002ooooo`;o00008Oooool2o`0000Kooooo0_l0000Eooooo`;o00003_ooool2o`00
02_ooooo0_l0001>ooooo`;o0000<oooool2o`0001Sooooo0006ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool01?l0000Sooooo`;o00005oooool3o`0000Kooooo0_l0000G
ooooo`;o0000@?ooool2o`0002Oooooo0_l0000Nooooo`;o0000<oooool2o`0001Sooooo0006oooo
o`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool05oooool2o`0000?ooooo0_l00009ooooo`;o00005oooool2
o`00023ooooo0_l00005ooooo`;o00001?ooool2o`0003?ooooo0_l0000Wooooo`;o0000>?ooool2
o`0003?ooooo0006ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07
ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000?ooooo`;o00001_ooool2o`0000?ooooo0_l0001;
ooooo`;o00001?ooool4o`0001oooooo0_l00003ooooo`;o00000_ooool2o`0000Gooooo0_l0001S
ooooo`;o00004Oooool2o`0000Cooooo0_l0000Jooooo`001_ooool01Ol0003ooooooooooooooooo
000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool03oooool2o`0003kooooo0_l0000:ooooo`;o00005?ooool2o`0001oooooo0_l0
0003ooooo`;o00000_ooool2o`0000Gooooo0_l0000Cooooo`;o0000;?ooool2o`0003?ooooo0_l0
0004ooooo`;o00000oooool2o`0001Gooooo0006ooooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02ooo
ool2o`0004;ooooo0_l0000:ooooo`;o00006?ooool2o`00043ooooo0_l0000/ooooo`;o0000?_oo
ool2o`0001Gooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooo
oonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`?o0000
J?ooool2o`0007Cooooo0_l0001?ooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`07ooooo`Go
0000f_ooool3o`0000;ooooo0_l0001?ooooo`00:Oooool2o`0000Gooooo0_l000000ooooooo0000
o`000003o`0003[ooooo0_l00003ooooo`Co0000Uoooool3o`0000Oooooo0_l0000Cooooo`;o0000
4Oooool2o`0002;ooooo000Yooooo`03o`000?oooooooooo00Cooooo0_l00010ooooo`Co000000?o
ooooo`000?l000000_l0000Mooooo`;o00008_ooool2o`0000?ooooo0_l0000Aooooo`;o00004ooo
ool2o`0002Cooooo0_l0000;ooooo`;o00004oooool2o`00017ooooo0_l0000Rooooo`00:Oooool0
0ol0003oooooooooo`18ooooo`;o00008_ooool2o`000003ooooool0003o000001oooooo0_l00003
ooooo`;o00004Oooool2o`0000Kooooo0_l00008ooooo`Go00002_ooool3o`0001Oooooo0_l0001G
ooooo`00:Oooool00ol0003oooooooooo`0Jooooo`Co00006_ooool2o`0003Gooooo0_l0000>oooo
o`;o00006?ooool2o`0001Gooooo0_l00008ooooo`Co00002oooool3o`00073ooooo000Yooooo`03
o`000?oooooooooo01[ooooo1?l0000Jooooo`;o00008_ooool2o`00027ooooo0_l0000Hooooo`;o
00002oooool2o`0009Cooooo000Yooooo`;o0000GOooool2o`000003ooooool0003o000000Cooooo
0_l0000oooooo`;o00006_ooool2o`0006Kooooo0_l0000@ooooo`00:Oooool00ol0003ooooooooo
o`16ooooo`;o00005oooool2o`0000Cooooo0_l0000fooooo`;o00008oooool2o`0003Kooooo0_l0
000^ooooo`;o00004?ooool002Wooooo00?o0000ooooooooool0A_ooool2o`0005Gooooo0_l0000<
ooooo`;o0000COooool2o`00043ooooo000Yooooo`03o`000?oooooooooo01?ooooo0_l0000^oooo
o`;o00002oooool2o`0000cooooo0_l0000Uooooo`;o00009?ooool2o`0003cooooo0_l00011oooo
o`;o00003_ooool002Wooooo00?o0000ooooooooool04oooool2o`0000_ooooo0_l0000Qooooo`;o
00002oooool2o`0000cooooo0_l0000Uooooo`;o0000:_ooool3o`00033ooooo0_l00003ooooo`;o
0000@Oooool2o`0000kooooo000Yooooo`;o00008Oooool2o`0008oooooo1?l0000Qooooo`;o0000
3?ooool2o`0003Gooooo0_l0000Oooooo`00:Oooool00ol0003oooooooooo`2cooooo`;o00008Ooo
ool2o`0000kooooo0_l0000cooooo`;o00007oooool002Wooooo00?o0000ooooooooool0L_ooool2
o`0004[ooooo0_l0000Vooooo`;o0000E?ooool002Wooooo00?o0000ooooooooool0L_ooool2o`00
04[ooooo0_l0001looooo`00:Oooool00ol0003oooooooooo`2>ooooo`;o00009?ooool2o`0008Ko
oooo000Yooooo`;o0000F_ooool2o`0003?ooooo0_l0000Tooooo`;o00009Oooool2o`0000_ooooo
0_l0000Fooooo`;o0000>_ooool002Wooooo00?o0000ooooooooool0Aoooool2o`00013ooooo0_l0
001Xooooo`;o00005_ooool2o`0000_ooooo0_l00007ooooo`;o00003Oooool2o`0003[ooooo000>
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8b
omgMg@05ooooo`03o`000?oooooooooo04Oooooo0_l0000[ooooo`;o0000COooool2o`0002cooooo
0_l00019ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0Doooool2o`0001oooooo0_l0000Dooooo`;o0000
BOooool2o`0006Gooooo000>ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooo
ooooo`03ooooo`?o00008_ooool2o`0002oooooo0_l0000eooooo`;o00001Oooool2o`0004;ooooo
0_l0001Uooooo`003_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`0Rooooo`;o0000KOooool2o`0008gooooo0_l0000Jooooo`003_oo
ool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0?oooooo8Oooool2o`0001[ooooo000>ooooo`05oa0@4?ooooooooooooooool@
41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0Eoooool2o`000>?ooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Ko
oooo0_l0001Hooooo`;o0000hoooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0;Kooooo0_l00024
ooooo`00:Oooool00ol0003oooooooooo`2fooooo`;o0000Q?ooool002Wooooo0_l0003oooooocko
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooocko
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^
k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo
?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVY
ooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_oo
ool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003ooooo
ooooo`03ooooo`?o0000oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo
00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo
?Oooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo
00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`00
00Cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool001oooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo?Ooo
ool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qoooo
o`03o`000?oooooooooo00Gooooo0ol0003oooooocgooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001oooooo00?oEEEEofIV
I_l00000oooooom7ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .30805 Mdot
.02762 .26917 Mdot
.02952 .29291 Mdot
.03143 .29045 Mdot
.03333 .35958 Mdot
.03524 .3909 Mdot
.03714 .31697 Mdot
.03905 .31689 Mdot
.04095 .43104 Mdot
.04286 .26529 Mdot
.04476 .3444 Mdot
.04667 .26415 Mdot
.04857 .41062 Mdot
.05048 .32713 Mdot
.05238 .26082 Mdot
.05429 .34078 Mdot
.05619 .35865 Mdot
.0581 .41271 Mdot
.06 .25269 Mdot
.0619 .23435 Mdot
.06381 .41019 Mdot
.06571 .33848 Mdot
.06762 .35719 Mdot
.06952 .41417 Mdot
.07143 .23137 Mdot
.07333 .24721 Mdot
.07524 .35174 Mdot
.07714 .26163 Mdot
.07905 .23212 Mdot
.08095 .27294 Mdot
.08286 .41124 Mdot
.08476 .4311 Mdot
.08667 .36366 Mdot
.08857 .29003 Mdot
.09048 .25327 Mdot
.09238 .30981 Mdot
.09429 .38537 Mdot
.09619 .30991 Mdot
.0981 .24092 Mdot
.1 .24192 Mdot
.1019 .2365 Mdot
.10381 .24596 Mdot
.10571 .34127 Mdot
.10762 .27235 Mdot
.10952 .33861 Mdot
.11143 .34452 Mdot
.11333 .30535 Mdot
.11524 .4394 Mdot
.11714 .34665 Mdot
.11905 .23251 Mdot
.12095 .43858 Mdot
.12286 .29667 Mdot
.12476 .25974 Mdot
.12667 .29409 Mdot
.12857 .31704 Mdot
.13048 .40808 Mdot
.13238 .31003 Mdot
.13429 .35887 Mdot
.13619 .42758 Mdot
.1381 .35226 Mdot
.14 .3339 Mdot
.1419 .4285 Mdot
.14381 .24291 Mdot
.14571 .33645 Mdot
.14762 .37589 Mdot
.14952 .4207 Mdot
.15143 .25837 Mdot
.15333 .34292 Mdot
.15524 .3003 Mdot
.15714 .41398 Mdot
.15905 .33364 Mdot
.16095 .27856 Mdot
.16286 .26692 Mdot
.16476 .26427 Mdot
.16667 .24266 Mdot
.16857 .2995 Mdot
.17048 .25936 Mdot
.17238 .30143 Mdot
.17429 .27298 Mdot
.17619 .304 Mdot
.1781 .3923 Mdot
.18 .26312 Mdot
.1819 .26647 Mdot
.18381 .24302 Mdot
.18571 .36463 Mdot
.18762 .33424 Mdot
.18952 .36217 Mdot
.19143 .36302 Mdot
.19333 .3694 Mdot
.19524 .34285 Mdot
.19714 .23325 Mdot
.19905 .43587 Mdot
.20095 .31073 Mdot
.20286 .35899 Mdot
.20476 .32667 Mdot
.20667 .448 Mdot
.20857 .32143 Mdot
.21048 .43684 Mdot
.21238 .24422 Mdot
.21429 .36569 Mdot
.21619 .28083 Mdot
.2181 .37748 Mdot
.22 .27183 Mdot
.2219 .25278 Mdot
.22381 .40364 Mdot
.22571 .27287 Mdot
.22762 .3182 Mdot
.22952 .25796 Mdot
.23143 .30882 Mdot
.23333 .41335 Mdot
.23524 .29821 Mdot
.23714 .28691 Mdot
.23905 .43247 Mdot
.24095 .27892 Mdot
.24286 .32239 Mdot
.24476 .29456 Mdot
.24667 .31717 Mdot
.24857 .40659 Mdot
.25048 .41962 Mdot
.25238 .37023 Mdot
.25429 .40931 Mdot
.25619 .40016 Mdot
.2581 .39359 Mdot
.26 .23461 Mdot
.2619 .41357 Mdot
.26381 .30955 Mdot
.26571 .2606 Mdot
.26762 .46165 Mdot
.26952 .23938 Mdot
.27143 .32951 Mdot
.27333 .36106 Mdot
.27524 .25309 Mdot
.27714 .23866 Mdot
.27905 .39382 Mdot
.28095 .36556 Mdot
.28286 .25629 Mdot
.28476 .37992 Mdot
.28667 .23539 Mdot
.28857 .26303 Mdot
.29048 .34174 Mdot
.29238 .25081 Mdot
.29429 .45562 Mdot
.29619 .25951 Mdot
.2981 .27313 Mdot
.3 .35782 Mdot
.3019 .24975 Mdot
.30381 .38314 Mdot
.30571 .40205 Mdot
.30762 .25797 Mdot
.30952 .361 Mdot
.31143 .38655 Mdot
.31333 .37847 Mdot
.31524 .33478 Mdot
.31714 .41506 Mdot
.31905 .27077 Mdot
.32095 .39043 Mdot
.32286 .35241 Mdot
.32476 .2583 Mdot
.32667 .40853 Mdot
.32857 .38313 Mdot
.33048 .35935 Mdot
.33238 .27785 Mdot
.33429 .27706 Mdot
.33619 .23871 Mdot
.3381 .34919 Mdot
.34 .33109 Mdot
.3419 .29796 Mdot
.34381 .38936 Mdot
.34571 .39458 Mdot
.34762 .31038 Mdot
.34952 .35936 Mdot
.35143 .25179 Mdot
.35333 .30408 Mdot
.35524 .33338 Mdot
.35714 .36003 Mdot
.35905 .27595 Mdot
.36095 .36386 Mdot
.36286 .45315 Mdot
.36476 .39125 Mdot
.36667 .27866 Mdot
.36857 .23368 Mdot
.37048 .33407 Mdot
.37238 .22729 Mdot
.37429 .29575 Mdot
.37619 .24468 Mdot
.3781 .2985 Mdot
.38 .43308 Mdot
.3819 .46263 Mdot
.38381 .43237 Mdot
.38571 .2317 Mdot
.38762 .35793 Mdot
.38952 .37195 Mdot
.39143 .2491 Mdot
.39333 .3217 Mdot
.39524 .41247 Mdot
.39714 .34439 Mdot
.39905 .29226 Mdot
.40095 .25524 Mdot
.40286 .36266 Mdot
.40476 .40201 Mdot
.40667 .27038 Mdot
.40857 .26847 Mdot
.41048 .26634 Mdot
.41238 .28861 Mdot
.41429 .35311 Mdot
.41619 .38365 Mdot
.4181 .27126 Mdot
.42 .26598 Mdot
.4219 .39297 Mdot
.42381 .28782 Mdot
.42571 .26494 Mdot
.42762 .34922 Mdot
.42952 .39215 Mdot
.43143 .30867 Mdot
.43333 .39382 Mdot
.43524 .31924 Mdot
.43714 .29067 Mdot
.43905 .32593 Mdot
.44095 .24099 Mdot
.44286 .28859 Mdot
.44476 .36935 Mdot
.44667 .25714 Mdot
.44857 .32222 Mdot
.45048 .42711 Mdot
.45238 .39998 Mdot
.45429 .38038 Mdot
.45619 .33672 Mdot
.4581 .33449 Mdot
.46 .25676 Mdot
.4619 .30672 Mdot
.46381 .25752 Mdot
.46571 .41239 Mdot
.46762 .34324 Mdot
.46952 .27581 Mdot
.47143 .38307 Mdot
.47333 .36696 Mdot
.47524 .35235 Mdot
.47714 .38496 Mdot
.47905 .32216 Mdot
.48095 .24213 Mdot
.48286 .39634 Mdot
.48476 .26071 Mdot
.48667 .42706 Mdot
.48857 .38216 Mdot
.49048 .37125 Mdot
.49238 .3346 Mdot
.49429 .4294 Mdot
.49619 .33311 Mdot
.4981 .33403 Mdot
.5 .37549 Mdot
.5019 .33782 Mdot
.50381 .24712 Mdot
.50571 .27898 Mdot
.50762 .29022 Mdot
.50952 .31767 Mdot
.51143 .34971 Mdot
.51333 .24758 Mdot
.51524 .33827 Mdot
.51714 .34359 Mdot
.51905 .30729 Mdot
.52095 .32669 Mdot
.52286 .43683 Mdot
.52476 .35918 Mdot
.52667 .35243 Mdot
.52857 .36998 Mdot
.53048 .3216 Mdot
.53238 .37741 Mdot
.53429 .33466 Mdot
.53619 .31452 Mdot
.5381 .37677 Mdot
.54 .28379 Mdot
.5419 .25518 Mdot
.54381 .28653 Mdot
.54571 .33182 Mdot
.54762 .26627 Mdot
.54952 .33448 Mdot
.55143 .35039 Mdot
.55333 .28367 Mdot
.55524 .30969 Mdot
.55714 .43856 Mdot
.55905 .34833 Mdot
.56095 .39206 Mdot
.56286 .24309 Mdot
.56476 .32724 Mdot
.56667 .29012 Mdot
.56857 .3812 Mdot
.57048 .28697 Mdot
.57238 .26216 Mdot
.57429 .27558 Mdot
.57619 .31876 Mdot
.5781 .30712 Mdot
.58 .35609 Mdot
.5819 .40054 Mdot
.58381 .4627 Mdot
.58571 .42108 Mdot
.58762 .28532 Mdot
.58952 .41917 Mdot
.59143 .31507 Mdot
.59333 .41933 Mdot
.59524 .39196 Mdot
.59714 .33473 Mdot
.59905 .27044 Mdot
.60095 .43333 Mdot
.60286 .32394 Mdot
.60476 .37032 Mdot
.60667 .24576 Mdot
.60857 .42989 Mdot
.61048 .22921 Mdot
.61238 .31993 Mdot
.61429 .43798 Mdot
.61619 .24832 Mdot
.6181 .29685 Mdot
.62 .38691 Mdot
.6219 .34997 Mdot
.62381 .40472 Mdot
.62571 .37227 Mdot
.62762 .30372 Mdot
.62952 .35916 Mdot
.63143 .26252 Mdot
.63333 .36214 Mdot
.63524 .32637 Mdot
.63714 .22616 Mdot
.63905 .3322 Mdot
.64095 .46635 Mdot
.64286 .33447 Mdot
.64476 .39485 Mdot
.64667 .24291 Mdot
.64857 .26373 Mdot
.65048 .34203 Mdot
.65238 .27219 Mdot
.65429 .31953 Mdot
.65619 .33195 Mdot
.6581 .27936 Mdot
.66 .33988 Mdot
.6619 .32754 Mdot
.66381 .37205 Mdot
.66571 .32893 Mdot
.66762 .28996 Mdot
.66952 .26101 Mdot
.67143 .38928 Mdot
.67333 .33267 Mdot
.67524 .27714 Mdot
.67714 .34724 Mdot
.67905 .2882 Mdot
.68095 .24769 Mdot
.68286 .24535 Mdot
.68476 .33596 Mdot
.68667 .38688 Mdot
.68857 .3513 Mdot
.69048 .24082 Mdot
.69238 .28834 Mdot
.69429 .27501 Mdot
.69619 .34917 Mdot
.6981 .45532 Mdot
.7 .26681 Mdot
.7019 .42041 Mdot
.70381 .29563 Mdot
.70571 .31249 Mdot
.70762 .284 Mdot
.70952 .25717 Mdot
.71143 .374 Mdot
.71333 .26868 Mdot
.71524 .46958 Mdot
.71714 .36598 Mdot
.71905 .24227 Mdot
.72095 .22514 Mdot
.72286 .24808 Mdot
.72476 .31282 Mdot
.72667 .3582 Mdot
.72857 .24994 Mdot
.73048 .32015 Mdot
.73238 .31789 Mdot
.73429 .40738 Mdot
.73619 .24806 Mdot
.7381 .3938 Mdot
.74 .29002 Mdot
.7419 .43703 Mdot
.74381 .24374 Mdot
.74571 .40271 Mdot
.74762 .30508 Mdot
.74952 .34892 Mdot
.75143 .41286 Mdot
.75333 .3525 Mdot
.75524 .22551 Mdot
.75714 .35766 Mdot
.75905 .38544 Mdot
.76095 .38781 Mdot
.76286 .26844 Mdot
.76476 .29654 Mdot
.76667 .37167 Mdot
.76857 .31851 Mdot
.77048 .22499 Mdot
.77238 .41374 Mdot
.77429 .27378 Mdot
.77619 .25767 Mdot
.7781 .26485 Mdot
.78 .35064 Mdot
.7819 .43942 Mdot
.78381 .39355 Mdot
.78571 .40591 Mdot
.78762 .22573 Mdot
.78952 .31943 Mdot
.79143 .31524 Mdot
.79333 .29942 Mdot
.79524 .27201 Mdot
.79714 .30068 Mdot
.79905 .28321 Mdot
.80095 .29157 Mdot
.80286 .26873 Mdot
.80476 .35185 Mdot
.80667 .28371 Mdot
.80857 .35139 Mdot
.81048 .3199 Mdot
.81238 .33778 Mdot
.81429 .3612 Mdot
.81619 .34876 Mdot
.8181 .25908 Mdot
.82 .33254 Mdot
.8219 .32785 Mdot
.82381 .36451 Mdot
.82571 .30527 Mdot
.82762 .3476 Mdot
.82952 .27226 Mdot
.83143 .39334 Mdot
.83333 .34382 Mdot
.83524 .3007 Mdot
.83714 .26377 Mdot
.83905 .31826 Mdot
.84095 .38396 Mdot
.84286 .24964 Mdot
.84476 .32497 Mdot
.84667 .30656 Mdot
.84857 .43476 Mdot
.85048 .23884 Mdot
.85238 .26067 Mdot
.85429 .2569 Mdot
.85619 .29199 Mdot
.8581 .42671 Mdot
.86 .24398 Mdot
.8619 .34625 Mdot
.86381 .28575 Mdot
.86571 .2805 Mdot
.86762 .27644 Mdot
.86952 .29334 Mdot
.87143 .29018 Mdot
.87333 .37126 Mdot
.87524 .28598 Mdot
.87714 .41866 Mdot
.87905 .27952 Mdot
.88095 .26335 Mdot
.88286 .24649 Mdot
.88476 .33372 Mdot
.88667 .29691 Mdot
.88857 .26872 Mdot
.89048 .31655 Mdot
.89238 .31901 Mdot
.89429 .26157 Mdot
.89619 .24866 Mdot
.8981 .34607 Mdot
.9 .27312 Mdot
.9019 .40666 Mdot
.90381 .33489 Mdot
.90571 .46194 Mdot
.90762 .25581 Mdot
.90952 .27382 Mdot
.91143 .27988 Mdot
.91333 .31375 Mdot
.91524 .42023 Mdot
.91714 .25189 Mdot
.91905 .36868 Mdot
.92095 .24227 Mdot
.92286 .27757 Mdot
.92476 .25159 Mdot
.92667 .34766 Mdot
.92857 .28936 Mdot
.93048 .43272 Mdot
.93238 .35893 Mdot
.93429 .29624 Mdot
.93619 .3241 Mdot
.9381 .31238 Mdot
.94 .31129 Mdot
.9419 .33712 Mdot
.94381 .28917 Mdot
.94571 .36419 Mdot
.94762 .27021 Mdot
.94952 .25418 Mdot
.95143 .4195 Mdot
.95333 .35864 Mdot
.95524 .34838 Mdot
.95714 .28156 Mdot
.95905 .26665 Mdot
.96095 .32467 Mdot
.96286 .31121 Mdot
.96476 .32404 Mdot
.96667 .26494 Mdot
.96857 .42547 Mdot
.97048 .34284 Mdot
.97238 .28906 Mdot
.97429 .23189 Mdot
.97619 .23591 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`1/ooooo`;o0000Doooool2o`0001Wooooo0_l00009ooooo`;o00000oooool2o`0000Cooooo0_l0
0018ooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^
kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0K?ooool2o`0004_ooooo0_l0
0006ooooo`;o00006Oooool2o`0000Wooooo0_l00003ooooo`;o00001?ooool2o`0004Sooooo0006
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol0000<ooooo`Co00002oooool2o`0001Oooooo0_l0000eooooo`;o00001?oo
ool2o`0004Kooooo0_l0001cooooo`;o00003?ooool000Kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo00Wooooo0_l000000ooooooo0000o`000002o`0000Gooooo0_l00004ooooo`;o0000
5oooool2o`0001;ooooo0_l00007ooooo`;o00006?ooool2o`0000Cooooo0_l0002kooooo`?o0000
2oooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`;o00002_ooool2o`00037ooooo
0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000kooooo0_l0002Sooooo`;o
00009oooool2o`0000_ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o
^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Doooo
o`?o00003?ooool2o`0000Gooooo0_l00004ooooo`;o00006Oooool2o`000003ooooool0003o0000
017ooooo0_l0000Oooooo`;o00002oooool2o`0001Wooooo0_l0000Iooooo`;o00003?ooool2o`00
00Oooooo0_l0000Xooooo`;o00005Oooool2o`0001gooooo0006ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooo
oooo01Cooooo1?l0000;ooooo`;o00001Oooool2o`0000Cooooo0_l00007ooooo`;o0000<oooool2
o`0001;ooooo0_l0000;ooooo`;o00006Oooool2o`0000cooooo0_l0000;ooooo`;o00002Oooool2
o`000003ooooool0003o000000Oooooo0_l00006ooooo`;o00008oooool2o`0000Gooooo0_l0000;
ooooo`;o00007Oooool002Wooooo0_l0000=ooooo`;o00002?ooool2o`00027ooooo0_l0000coooo
o`;o00000_ooool2o`0002?ooooo0_l000000ooooooo0000o`00000Looooo`;o000000?oooooo`00
0?l000004oooool2o`0000_ooooo0_l00002ooooo`;o000000?oooooo`000?l000007_ooool2o`00
00?ooooo0_l00005ooooo`;o00000oooool2o`0002Gooooo000Yooooo`03o`000?oooooooooo00So
oooo0_l00002ooooo`;o0000;_ooool2o`0001Gooooo0_l000000ooooooo0000o`00000>ooooo`;o
00002_ooool2o`0002?ooooo0_l000000ooooooo0000o`00000Oooooo`;o00004oooool2o`0000_o
oooo1_l0000Qooooo`;o00003oooool2o`0000Gooooo1?l0000Looooo`00:Oooool00ol0003ooooo
ooooo`08ooooo`;o00002?ooool2o`0002Sooooo0_l0000?ooooo`;o00001?ooool2o`000003oooo
ool0003o000000kooooo0_l0000>ooooo`;o0000:oooool2o`0003[ooooo0_l0000gooooo`;o0000
0_ooool4o`0000Kooooo0_l0000Dooooo`00:Oooool00ol0003oooooooooo`0Booooo`;o00004Ooo
ool2o`0001Oooooo0_l0000=ooooo`;o000000?oooooo`000?l000001_ooool2o`0000?ooooo0_l0
000Gooooo`;o00003?ooool2o`0000?ooooo0ol0000Gooooo`;o0000=?ooool2o`0001?ooooo0_l0
000Gooooo`;o00003oooool2o`0000cooooo0_l0000Dooooo`00:Oooool00ol0003oooooooooo`05
ooooo`;o00001_ooool2o`0000kooooo0_l00006ooooo`;o00001?ooool2o`00017ooooo0_l0000:
ooooo`;o00001?ooool2o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0002Gooooo0_l00003
ooooo`?o00001?ooool2o`0001_ooooo0_l0000Mooooo`;o00002oooool2o`0001?ooooo0_l0000<
ooooo`;o00002Oooool2o`0000_ooooo0_l0000Vooooo`00:Oooool2o`0000Gooooo0ol00006oooo
o`;o00003_ooool2o`0000_ooooo0ol000000ooooooo0000o`00000Jooooo`;o00001Oooool2o`00
0003ooooool0003o000002Oooooo0_l0000Aooooo`;o00006oooool2o`00017ooooo0_l00003oooo
o`;o00001Oooool2o`00027ooooo0_l0000;ooooo`;o00001?ooool2o`0000?ooooo0_l00007oooo
o`;o00000_ooool2o`0001Gooooo0_l0000?ooooo`00:Oooool00ol0003oooooooooo`02ooooo`Co
00008oooool3o`0000;ooooo0ol0000Pooooo`;o00009_ooool2o`000004ooooool0003o0000o`00
02Kooooo0_l0000Iooooo`;o00000oooool2o`0000oooooo0_l0000Gooooo`;o00004Oooool2o`00
00cooooo0_l0000Gooooo`Co00003oooool002Wooooo0_l00003ooooo`;o00009Oooool2o`0000Co
oooo1Ol000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^01Oooooo0_l0000@ooooo`Go00000oooool00oo^k^ko<S8bo`000006o`000004oc8b
<_l0003o<S8bonk^kR?ooooo0_l00003ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool00oo^
k^ko<S8bo`000002o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Gooooo`;o00000_ooool2
o`0000gooooo0ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool3o`000003oc8b<_o^
k^kooooo01Gooooo0_l0000Aooooo`?o000000Wo<S8bo`000?l0003oooooonk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Yooooo`;o00004?ooool2o`00
00Kooooo0_l0000Dooooo`;o00000oooool00ol0003oooooooooo`02ooooo`04ogMgMonHV9Sooooo
oiRHV0Co000000GoMgMgoiRHV?ooooooV9RHogMgM`0@ooooo`;o00001Oooool2o`00013ooooo00Go
V9RHob4Q8Oo^k^koooooodA4A003ooooo`03ogMgMonHV9So000000;o000000Soooooo`000?l0003o
MgMgoiRHV?ooooooV9RHogMgMbSooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`03ogMgMonH
V9Sooooo00;o00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo0_l0000Booooo`;o0000
3_ooool2o`0000;ooooo0_l000001?nHV9SooooooiRHV?mgMgL2o`000006ooooool0003o0000oooo
oonHV9SoMgMg0oooool2o`00017ooooo0_l00002ooooo`;o000000?oooooo`000?l000002_ooool2
o`000003oooooomgMgOo<S8b00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool002Wooooo00?o0000ooooooooool03oooool2o`0000Kooooo0_l0
000Dooooo`;o00000oooool00ol0003oooooooooo`02ooooo`04oa0@4?ooooooooooooooo`Co0000
00Go410@oooooooooooooooooa0@400@ooooo`;o00002_ooool2o`0000Kooooo0_l00004ooooo`03
oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooo
ooooool@41002_ooool2o`0001oooooo0_l00003ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@00Oooooo0_l00006ooooo`;o00001?ooool2o`00017ooooo
1Ol00002ooooo`;o00000oooool01Ol@413o0000o`000?oooooo410@00?ooooo00Co410@oooooooo
oooooooo0_l0000;ooooo`;o00002?ooool2o`000003ooooool0003o000000;ooooo0_l0000:oooo
o`04o`000?oooooooooooa0@40?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oo
oooooooo007ooooo000Yooooo`;o0000:Oooool2o`0000Sooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02o`0000?ooooo00?o0000ooooooooool00_l0000Kooooo`?o00001_ooool2
o`000003ooooool0003o000000;ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`00000:ooooo`;o00002Oooool2o`0001Cooooo
0_l00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00Wooooo0_l00004ooooo`;o00001?ooool2o`00017ooooo00CoA4A4omgMgOoooooo00001?ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00000?ooooo`?o0000
00?oooooo`000?l000002Oooool2o`000003ooooool0003o000000Wooooo00GoMgMgoc8b<_oooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`01oooo
o`00:Oooool00ol0003oooooooooo`0Xooooo`;o00002?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;o00000oooool00ol0003oooooooooo`02o`0001_ooooo0_l0000:ooooo`;o
00000oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000001Gooooo0_l00009ooooo`;o00000oooool2o`0000?ooooo00?o410@
o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000009ooooo`;o00007Oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?oooooooooooooo
ool000000_ooool4o`000003ooooool0003ooooo00kooooo0_l00002ooooo`;o00002Oooool2o`00
00Wooooo00?o0000ob4Q8Ol000000_l00002ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo000Yooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@ooooool0003o0000
oa0@400]ooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool07_ooool3o`0000;ooooo0_l00003ooooo`;o000000Co8B4Qoooo
oooooooooooo0_l00002ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413ooooooooo
o`0Gooooo`;o00003_ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@4100
0_ooool4o`000003ooooool@413ooooo00gooooo0_l00002ooooo`;o00005Oooool00ol0003ooooo
ooooo`02o`0000;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41000oooool002Wooooo00?o0000ooooooooool04Oooool2o`0001oooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?l0003o0000ogMgM`0Y
ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01?mgMgOoV9RHoooooonHV9P2o`0000;ooooo
0_l000001?ooooooV9RHogMgMoooool2o`0001kooooo0_l00005ooooo`03oa0@4?l0003o000000;o
00000oooool2o`000003oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o00002Oooool2o`0000?ooooo00?ok^k^odA4
A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0>ooooo`;o00000_ooool2o`0000oooooo0_l00003ooooo`;o00001_ooool01OmgMgOo0000o`00
0?nHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool4o`00013ooooo
0_l0000Mooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h0:Oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo0ol00000
0olb<S;o0000o`000002ooooo`?o000000?o<S8bo`000?l000000_l0000Cooooo`;o00004?ooool0
1OnYZJWo0000o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03?ooool2o`0000;ooooo0_l00002ooooo`;o00003_ooool2o`0000Co
oooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo0_l000001?lb
<S;o0000oc8b<_o^k^h<ooooo`;o00000oooool2o`00013ooooo0_l00003ooooo`Go00000oooool0
1Oo^k^ko0000o`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Ooo
ool4o`0001cooooo0_l0000Tooooo`;o0000:?ooool2o`0000Kooooo0_l0000:ooooo`;o00005Ooo
ool2o`0003gooooo0_l0000Mooooo`;o00004?ooool2o`0000;ooooo0ol0000Booooo`;o00006Ooo
ool002Wooooo00?o0000ooooooooool07?ooool3o`00027ooooo0_l000000ooooooo0000o`00000N
ooooo`;o00002?ooool3o`0004_ooooo0_l0000Jooooo`;o00004_ooool2o`0000Oooooo0_l0000F
ooooo`;o00001?ooool2o`0000gooooo0_l0000Iooooo`00:Oooool00ol0003oooooooooo`0Loooo
o`;o00002Oooool2o`0000;ooooo0ol0000Booooo`;o00008Oooool2o`0000Wooooo0_l0001;oooo
o`;o0000;_ooool2o`0000Oooooo0ol0000:ooooo`;o00003oooool2o`0002Sooooo000Yooooo`03
o`000?oooooooooo01Wooooo0_l0000<ooooo`;o00000_ooool4o`0003Oooooo0_l0001Fooooo`;o
00009Oooool2o`0000kooooo0_l00007ooooo`;o000000?oooooo`000?l00000>Oooool002Wooooo
0_l0000Jooooo`;o00004_ooool2o`00013ooooo0_l0000Uooooo`;o00005oooool2o`0000Sooooo
0_l0000Aooooo`;o00004?ooool2o`0000kooooo0_l0000Uooooo`;o00005oooool2o`0000Gooooo
0_l0000eooooo`008Oooooooo`0004Co00001?ooool002Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`06ooooo`Go00002?ooool2o`000003ooooool0003ooooo00[ooooo00?o0000
ooooooooool01?ooool2o`0000?ooooo00?o0000ooooooooool02_ooool01?l0003oooooo`000?l0
0008ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool2o`0000Gooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`;o00001?ooool3o`0000_ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo0ol0
0003ooooo`;o00001_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;o00001_oo
ool3o`0000Gooooo0_l00003ooooo`03o`000?oooooooooo00[ooooo000Yooooo`04o`000?oooooo
ooooooooo`;o00006oooool2o`0001[ooooo00?o0000ooooooooool01oooool2o`0003;ooooo00?o
0000ooooooooool07Oooool2o`0000Oooooo0_l0000@ooooo`?o00008_ooool2o`0000Cooooo1?l0
000@ooooo`?o00007_ooool2o`0000Gooooo0_l00006ooooo`;o00002oooool00ol0003ooooooooo
o`0:ooooo`00:Oooool01?l0003oooooooooooooool2o`0001_ooooo0_l0000Nooooo`;o00001?oo
ool2o`0003_ooooo0_l0000Eooooo`;o00005?ooool2o`0000?ooooo0_l00005ooooo`;o00002ooo
ool2o`0001Kooooo0ol0000:ooooo`;o00001?ooool3o`0000Cooooo0_l00007ooooo`;o00003ooo
ool3o`0002Kooooo000Yooooo`03o`000?oooooooooo03Sooooo0_l00004ooooo`;o00000oooool2
o`0002kooooo0_l0000<ooooo`;o00000_ooool2o`0000Sooooo0_l0000>ooooo`;o00003Oooool2
o`0000Kooooo0_l00002ooooo`;o00002oooool2o`0001Kooooo0_l0000;ooooo`;o00001?ooool2
o`0000Gooooo0_l00007ooooo`;o00004?ooool2o`0000cooooo0_l00007ooooo`;o00003oooool0
02Wooooo0_l00006ooooo`;o0000;oooool4o`0000Wooooo0_l0000^ooooo`;o00003Oooool2o`00
0003ooooool0003o000000Sooooo0_l0000;ooooo`;o000000?oooooo`000?l000002Oooool2o`00
00[ooooo0_l00009ooooo`;o0000@Oooool2o`0001cooooo0_l00006ooooo`?o00003oooool002Wo
oooo00?o0000ooooooooool01Oooool2o`0002oooooo0_l0000Dooooo`;o0000=?ooool2o`0001So
oooo0_l0000<ooooo`;o00005Oooool2o`0000Kooooo1?l0000`ooooo`;o00001Oooool2o`0002Co
oooo0_l0000@ooooo`00:Oooool00ol0003oooooooooo`0Xooooo`;o00008_ooool2o`0001Cooooo
0_l00003ooooo`;o0000:oooool2o`0000kooooo0_l0000Looooo`;o00001?ooool7o`0002gooooo
0ol0000mooooo`00:Oooool00ol0003oooooooooo`0Rooooo`?o00000oooool2o`0000Oooooo0_l0
000Wooooo`;o00001_ooool2o`0000?ooooo0_l00003ooooo`;o00006Oooool3o`0000Wooooo1?l0
0009ooooo`;o00000_ooool3o`0000kooooo0_l0000;ooooo`?o00000oooool2o`0000?ooooo0_l0
0002ooooo`;o0000:Oooool2o`0001?ooooo0_l00004ooooo`;o00008oooool002Wooooo00?o0000
ooooooooool02_ooool2o`0000cooooo0_l00008ooooo`?o00003?ooool2o`0002Oooooo0_l0000@
ooooo`;o00006Oooool3o`0000Wooooo1Ol00002ooooo`;o00001?ooool2o`0000?ooooo0_l0000>
ooooo`;o00003?ooool2o`0000Cooooo0_l00006ooooo`;o00009oooool2o`0001Gooooo0_l00004
ooooo`;o00002_ooool2o`0001Oooooo000Yooooo`;o00001oooool2o`0000;ooooo0_l0000;oooo
o`?o00003?ooool2o`0000_ooooo0_l0000Mooooo`;o0000@_ooool2o`0000;ooooo0_l0000Zoooo
o`;o000000?oooooo`000?l00000;oooool2o`0002Oooooo0_l00008ooooo`;o00003Oooool002Wo
oooo00?o0000ooooooooool00oooool2o`000003ooooool0003o000000oooooo0ol0000<ooooo`;o
00002oooool2o`0001gooooo0_l0000Pooooo`;o00005Oooool2o`0000kooooo0_l0000Yooooo`;o
0000>Oooool2o`0001;ooooo0_l0000Fooooo`;o00003Oooool002Wooooo00?o0000ooooooooool0
0oooool2o`0001?ooooo1?l00015ooooo`;o00004Oooool2o`0000Sooooo0_l0000;ooooo`;o0000
3_ooool2o`0000_ooooo0_l0000Tooooo`;o00001?ooool2o`00013ooooo0_l0000Cooooo`;o0000
0_ooool4o`0000Oooooo0_l00009ooooo`;o00002?ooool2o`0000Oooooo0_l0000Booooo`00:Ooo
ool00ol0003oooooooooo`0=ooooo`;o00002oooool2o`0000Gooooo0_l0000nooooo`;o00006ooo
ool2o`0000gooooo0_l0000:ooooo`;o00002oooool4o`0001?ooooo0_l0000?ooooo`;o00000_oo
ool4o`00013ooooo0_l00007ooooo`;o00001_ooool6o`0000;ooooo0_l00009ooooo`;o00004ooo
ool2o`0000Oooooo0_l0000Booooo`00:Oooool00ol0003oooooooooo`0=ooooo`;o00004_ooool2
o`0003Wooooo0_l0000Looooo`;o00004Oooool2o`0000[ooooo0_l00003ooooo`;o00001_ooool2
o`0001Gooooo0_l0000Cooooo`;o00004oooool2o`0000Kooooo0_l00006ooooo`Co0000@Oooool0
02Wooooo0_l0000;ooooo`;o0000BOooool2o`0000Gooooo0_l0000Cooooo`;o00001oooool2o`00
02;ooooo0_l0000?ooooo`;o0000;Oooool2o`0000Oooooo0ol0001Booooo`00:Oooool01?l0003o
ooooo`000?l00006ooooo`;o000000?oooooo`000?l000005?ooool2o`0001Cooooo0_l0000Eoooo
o`;o00001_ooool2o`000003ooooool0003o000000Gooooo0_l00004ooooo`Co00002?ooool2o`00
02[ooooo0_l0000@ooooo`;o00003_ooool2o`0001gooooo0_l00008ooooo`;o00004?ooool2o`00
02Cooooo0_l00005ooooo`;o00004oooool002Wooooo00Co0000ooooool0003o00001_ooool2o`00
00Oooooo0_l0000>ooooo`;o00003_ooool4o`0000;ooooo0_l0000Eooooo`;o00002Oooool2o`00
00Gooooo0_l00004ooooo`Ko00002oooool2o`0002Gooooo0_l0000Pooooo`?o0000>?ooool2o`00
00;ooooo0_l0000Pooooo`;o00000oooool4o`0001?ooooo000Yooooo`03o`000?oooooooooo013o
oooo0_l0000Nooooo`Co00001_ooool2o`0001?ooooo0_l0000Hooooo`;o00002oooool2o`0001Go
oooo0_l0000aooooo`;o00006Oooool2o`00027ooooo0_l0000Uooooo`;o00005Oooool002Wooooo
00?o0000ooooooooool0<oooool2o`0000Gooooo0_l0000:ooooo`;o00001oooool2o`0003?ooooo
0_l00007ooooo`;o00004?ooool2o`0001Kooooo0_l0000Rooooo`;o0000?oooool2o`0001kooooo
000Yooooo`;o0000=?ooool2o`00017ooooo0_l0000Zooooo`;o00004?ooool2o`0000cooooo0_l0
000;ooooo`;o00005_ooool2o`0000Gooooo0_l0000:ooooo`;o00003Oooool2o`00013ooooo0_l0
000Pooooo`;o00003Oooool2o`0001kooooo000Yooooo`03o`000?oooooooooo02Cooooo0_l0001<
ooooo`;o00007_ooool2o`000003ooooool0003o000000_ooooo0_l0000Jooooo`;o00002_ooool2
o`0000gooooo0_l0000@ooooo`;o00008?ooool2o`0002gooooo0006ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`0Tooooo`;o00005Oooool2o`0001?ooooo0_l00007ooooo`;o0000>_oo
ool2o`0000Wooooo1?l0002Hooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo03_ooooo0_l0000Cooooo`;o00001?ooool2o`000003ooooool0003o000000?ooooo
0_l0000Wooooo`;o00000oooool2o`0000Cooooo0_l0000<ooooo`;o00002Oooool2o`0008oooooo
0006ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool04oooool2o`00047ooooo0_l000000ooooooo0000
o`000003ooooo`;o00006_ooool2o`0000_ooooo0_l00003ooooo`Co00000_ooool2o`0001Oooooo
0_l0000looooo`;o00006?ooool2o`0003Oooooo0006ooooo`05o`000?ooooooooooooooool00000
3Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Cooooo`;o0000
A?ooool2o`0000Sooooo0_l0000Eooooo`;o00004_ooool2o`0002cooooo0_l0000?ooooo`;o0000
0_ooool2o`0001Kooooo0_l0000Hooooo`;o0000=oooool000Kooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo00;o0000;?ooool2o`0002cooooo0_l00005ooooo`;o00001Oooool2o`0001?o
oooo0_l0000Xooooo`;o00002Oooool2o`0000Kooooo0_l0000?ooooo`;o00000_ooool2o`0001Ko
oooo0_l0001Aooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;o0000;?ooool2o`0001So
oooo0_l00004ooooo`;o00003?ooool2o`0000Kooooo0_l00004ooooo`;o00004?ooool2o`000004
ooooool0003o0000o`0002Oooooo0_l00009ooooo`;o00003_ooool2o`0001cooooo0_l0000=oooo
o`;o00003Oooool2o`0003[ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`18
ooooo`;o00001?ooool2o`0001Cooooo0_l0000Fooooo`;o00000_ooool2o`0000kooooo0_l0000b
ooooo`;o00007?ooool2o`0000gooooo0_l0000=ooooo`;o0000>_ooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o
0000ooooooooool0Aoooool2o`0000kooooo0_l0000Nooooo`;o00003Oooool2o`0000Sooooo0_l0
000Nooooo`;o0000R_ooool002Wooooo0_l0000nooooo`;o00002?ooool2o`0000kooooo0_l0000N
ooooo`;o00003Oooool2o`0002Sooooo0_l0000;ooooo`;o00009Oooool2o`0005Kooooo000Yoooo
o`03o`000?oooooooooo01oooooo0_l0000Looooo`;o00001_ooool2o`0007Kooooo0_l0000Roooo
o`;o000000?oooooo`000?l000002oooool2o`0002Cooooo0_l0000Sooooo`00:Oooool00ol0003o
ooooooooo`04ooooo`;o00000oooool2o`0000Cooooo0_l0000>ooooo`;o00009?ooool3o`0001Ko
oooo0_l00021ooooo`;o00003_ooool2o`0002Cooooo0_l0000Sooooo`00:Oooool00ol0003ooooo
ooooo`04ooooo`;o000000?oooooo`000?l000001?l00002ooooo`;o00005_ooool2o`0001Oooooo
0_l00004ooooo`;o000000?oooooo`000?l000004oooool2o`0001Cooooo0_l0000Dooooo`;o0000
F_ooool2o`0000Gooooo0_l0001=ooooo`00:Oooool00ol0003oooooooooo`07ooooo`;o00000_oo
ool2o`0001[ooooo0_l0000Gooooo`;o00001oooool2o`00013ooooo0_l0000Gooooo`;o00005?oo
ool2o`0005[ooooo0_l00005ooooo`;o0000COooool002Wooooo0_l0000Vooooo`;o00007_ooool2
o`0001Cooooo0_l0001Eooooo`?o00008Oooool2o`0003Oooooo0_l0000:ooooo`;o00002_ooool2
o`0001?ooooo000Yooooo`03o`000?oooooooooo02Gooooo0_l0000Nooooo`;o0000J_ooool4o`00
027ooooo0_l0000gooooo`;o00002_ooool2o`0000[ooooo0_l0000Cooooo`00:Oooool00ol0003o
ooooooooo`2aooooo`;o0000E_ooool2o`00027ooooo0_l0000>ooooo`00:Oooool00ol0003ooooo
ooooo`0Pooooo`Co0000HOooool2o`0000[ooooo0_l000000ooooooo0000o`00000Rooooo`;o0000
Coooool2o`00027ooooo0_l0000>ooooo`00:Oooool00ol0003oooooooooo`02ooooo`;o00003?oo
ool2o`0000kooooo1?l0000Mooooo`;o0000;?ooool3o`0001?ooooo0_l0000:ooooo`;o000000?o
ooooo`000?l000008_ooool2o`0006Kooooo0_l0000Jooooo`00:Oooool2o`0000?ooooo0_l0000<
ooooo`;o00008oooool2o`0000[ooooo0_l0000/ooooo`?o0000A?ooool2o`0004gooooo0_l0000I
ooooo`;o00006_ooool002Wooooo00?o0000ooooooooool06_ooool4o`0001Oooooo0_l000000ooo
oooo0000o`00001Sooooo`;o00002Oooool2o`0000cooooo0_l00002ooooo`;o00009oooool2o`00
00_ooooo0_l0000Cooooo`;o0000=Oooool002Wooooo00?o0000ooooooooool06_ooool4o`0001[o
oooo0_l0001Sooooo`;o00002Oooool2o`00013ooooo0_l0000Wooooo`;o00002oooool2o`0004[o
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0=ooo
ool2o`000?oooooo1?ooool002Wooooo0_l0000hooooo`;o0000ooooool4ooooo`00:Oooool00ol0
003oooooooooo`1Yooooo`;o0000dOooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0Doooool2
o`0001Cooooo0_l0001Zooooo`;o0000IOooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo05?ooooo0_l00020
ooooo`;o0000IOooool000kooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00?ooooo0ol0001;ooooo`;o00008_ooool2o`0003oooooo0_l0001Vooooo`;o00008_ooool0
00kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool0Boooool2o`0002;ooooo0_l0000oooooo`;o00004Oooool2o`0005?ooooo0_l0000R
ooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo0<?ooooo0_l0000Fooooo`;o0000Goooool000kooooo00Go410@
oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0fooo
ool2o`0005oooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^
k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolm
ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWo
oooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006oooo
o`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooo
oooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool0
0olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolm
ooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool0
1Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go0000
1?ooool4o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`007oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooolmoooo
o`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo
00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`007oooool00omEEEGoIVIV
o`00003oooooodOooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .37822 Mdot
.02762 .24879 Mdot
.02952 .31267 Mdot
.03143 .26026 Mdot
.03333 .31535 Mdot
.03524 .35329 Mdot
.03714 .30923 Mdot
.03905 .40738 Mdot
.04095 .43502 Mdot
.04286 .27434 Mdot
.04476 .29353 Mdot
.04667 .37314 Mdot
.04857 .36798 Mdot
.05048 .26472 Mdot
.05238 .3692 Mdot
.05429 .33527 Mdot
.05619 .3783 Mdot
.0581 .37531 Mdot
.06 .31175 Mdot
.0619 .32534 Mdot
.06381 .37158 Mdot
.06571 .24772 Mdot
.06762 .267 Mdot
.06952 .38506 Mdot
.07143 .27949 Mdot
.07333 .30721 Mdot
.07524 .33151 Mdot
.07714 .32716 Mdot
.07905 .29671 Mdot
.08095 .24667 Mdot
.08286 .38587 Mdot
.08476 .43741 Mdot
.08667 .42959 Mdot
.08857 .35967 Mdot
.09048 .27164 Mdot
.09238 .38924 Mdot
.09429 .29289 Mdot
.09619 .35187 Mdot
.0981 .27316 Mdot
.1 .35243 Mdot
.1019 .26826 Mdot
.10381 .32016 Mdot
.10571 .25814 Mdot
.10762 .35931 Mdot
.10952 .39133 Mdot
.11143 .36694 Mdot
.11333 .25511 Mdot
.11524 .41779 Mdot
.11714 .27252 Mdot
.11905 .31526 Mdot
.12095 .41322 Mdot
.12286 .2316 Mdot
.12476 .38113 Mdot
.12667 .24344 Mdot
.12857 .24327 Mdot
.13048 .4418 Mdot
.13238 .40324 Mdot
.13429 .37909 Mdot
.13619 .37368 Mdot
.1381 .39527 Mdot
.14 .36637 Mdot
.1419 .34488 Mdot
.14381 .27011 Mdot
.14571 .30852 Mdot
.14762 .43269 Mdot
.14952 .44237 Mdot
.15143 .287 Mdot
.15333 .31705 Mdot
.15524 .34976 Mdot
.15714 .39647 Mdot
.15905 .37829 Mdot
.16095 .27625 Mdot
.16286 .2727 Mdot
.16476 .32364 Mdot
.16667 .27052 Mdot
.16857 .27338 Mdot
.17048 .38081 Mdot
.17238 .35696 Mdot
.17429 .24018 Mdot
.17619 .24716 Mdot
.1781 .41489 Mdot
.18 .25394 Mdot
.1819 .27869 Mdot
.18381 .30793 Mdot
.18571 .43094 Mdot
.18762 .34377 Mdot
.18952 .32472 Mdot
.19143 .34354 Mdot
.19333 .37584 Mdot
.19524 .32044 Mdot
.19714 .27555 Mdot
.19905 .4725 Mdot
.20095 .33852 Mdot
.20286 .35975 Mdot
.20476 .33491 Mdot
.20667 .47395 Mdot
.20857 .26017 Mdot
.21048 .41067 Mdot
.21238 .36693 Mdot
.21429 .37932 Mdot
.21619 .36384 Mdot
.2181 .36377 Mdot
.22 .37842 Mdot
.2219 .34244 Mdot
.22381 .41343 Mdot
.22571 .34986 Mdot
.22762 .373 Mdot
.22952 .27877 Mdot
.23143 .33847 Mdot
.23333 .3965 Mdot
.23524 .25471 Mdot
.23714 .26132 Mdot
.23905 .43543 Mdot
.24095 .37292 Mdot
.24286 .21778 Mdot
.24476 .26491 Mdot
.24667 .3627 Mdot
.24857 .44415 Mdot
.25048 .44401 Mdot
.25238 .27129 Mdot
.25429 .36479 Mdot
.25619 .29702 Mdot
.2581 .33075 Mdot
.26 .28593 Mdot
.2619 .39783 Mdot
.26381 .25965 Mdot
.26571 .3593 Mdot
.26762 .46913 Mdot
.26952 .31637 Mdot
.27143 .30555 Mdot
.27333 .27144 Mdot
.27524 .34182 Mdot
.27714 .34737 Mdot
.27905 .365 Mdot
.28095 .29216 Mdot
.28286 .25229 Mdot
.28476 .28297 Mdot
.28667 .32696 Mdot
.28857 .27808 Mdot
.29048 .41893 Mdot
.29238 .36049 Mdot
.29429 .40161 Mdot
.29619 .30736 Mdot
.2981 .33736 Mdot
.3 .37863 Mdot
.3019 .34962 Mdot
.30381 .43813 Mdot
.30571 .28134 Mdot
.30762 .28014 Mdot
.30952 .35373 Mdot
.31143 .27579 Mdot
.31333 .3577 Mdot
.31524 .355 Mdot
.31714 .38957 Mdot
.31905 .28688 Mdot
.32095 .38179 Mdot
.32286 .24994 Mdot
.32476 .25123 Mdot
.32667 .44358 Mdot
.32857 .28968 Mdot
.33048 .25671 Mdot
.33238 .25362 Mdot
.33429 .23786 Mdot
.33619 .26367 Mdot
.3381 .40654 Mdot
.34 .25044 Mdot
.3419 .37272 Mdot
.34381 .43992 Mdot
.34571 .41695 Mdot
.34762 .35249 Mdot
.34952 .25622 Mdot
.35143 .35029 Mdot
.35333 .33678 Mdot
.35524 .35387 Mdot
.35714 .31908 Mdot
.35905 .26 Mdot
.36095 .4289 Mdot
.36286 .47297 Mdot
.36476 .37786 Mdot
.36667 .27315 Mdot
.36857 .29046 Mdot
.37048 .23651 Mdot
.37238 .32568 Mdot
.37429 .342 Mdot
.37619 .2566 Mdot
.3781 .33065 Mdot
.38 .43022 Mdot
.3819 .4669 Mdot
.38381 .43891 Mdot
.38571 .2763 Mdot
.38762 .27883 Mdot
.38952 .25829 Mdot
.39143 .349 Mdot
.39333 .27102 Mdot
.39524 .31815 Mdot
.39714 .42159 Mdot
.39905 .22577 Mdot
.40095 .36535 Mdot
.40286 .3524 Mdot
.40476 .46396 Mdot
.40667 .34963 Mdot
.40857 .31065 Mdot
.41048 .30539 Mdot
.41238 .2697 Mdot
.41429 .29874 Mdot
.41619 .45592 Mdot
.4181 .35726 Mdot
.42 .28519 Mdot
.4219 .36702 Mdot
.42381 .26065 Mdot
.42571 .31223 Mdot
.42762 .30691 Mdot
.42952 .32326 Mdot
.43143 .3596 Mdot
.43333 .41694 Mdot
.43524 .34535 Mdot
.43714 .36889 Mdot
.43905 .36388 Mdot
.44095 .26054 Mdot
.44286 .32913 Mdot
.44476 .39601 Mdot
.44667 .36802 Mdot
.44857 .36409 Mdot
.45048 .37483 Mdot
.45238 .4161 Mdot
.45429 .41445 Mdot
.45619 .33836 Mdot
.4581 .26619 Mdot
.46 .25914 Mdot
.4619 .33746 Mdot
.46381 .36646 Mdot
.46571 .31625 Mdot
.46762 .31163 Mdot
.46952 .28355 Mdot
.47143 .4549 Mdot
.47333 .31366 Mdot
.47524 .3338 Mdot
.47714 .27484 Mdot
.47905 .35409 Mdot
.48095 .32692 Mdot
.48286 .33517 Mdot
.48476 .34934 Mdot
.48667 .34271 Mdot
.48857 .32632 Mdot
.49048 .41537 Mdot
.49238 .37852 Mdot
.49429 .44042 Mdot
.49619 .32732 Mdot
.4981 .23745 Mdot
.5 .3544 Mdot
.5019 .37932 Mdot
.50381 .26364 Mdot
.50571 .23036 Mdot
.50762 .26612 Mdot
.50952 .2676 Mdot
.51143 .24833 Mdot
.51333 .30739 Mdot
.51524 .35255 Mdot
.51714 .25941 Mdot
.51905 .27579 Mdot
.52095 .41196 Mdot
.52286 .40081 Mdot
.52476 .2946 Mdot
.52667 .3334 Mdot
.52857 .41287 Mdot
.53048 .27703 Mdot
.53238 .34929 Mdot
.53429 .38873 Mdot
.53619 .25742 Mdot
.5381 .31669 Mdot
.54 .37479 Mdot
.5419 .27669 Mdot
.54381 .37708 Mdot
.54571 .24987 Mdot
.54762 .27285 Mdot
.54952 .25943 Mdot
.55143 .24799 Mdot
.55333 .33764 Mdot
.55524 .251 Mdot
.55714 .41938 Mdot
.55905 .30284 Mdot
.56095 .37878 Mdot
.56286 .2687 Mdot
.56476 .32211 Mdot
.56667 .33932 Mdot
.56857 .28686 Mdot
.57048 .38871 Mdot
.57238 .27234 Mdot
.57429 .31464 Mdot
.57619 .25483 Mdot
.5781 .3894 Mdot
.58 .36117 Mdot
.5819 .41208 Mdot
.58381 .46606 Mdot
.58571 .35976 Mdot
.58762 .38689 Mdot
.58952 .3569 Mdot
.59143 .27878 Mdot
.59333 .35404 Mdot
.59524 .28613 Mdot
.59714 .40292 Mdot
.59905 .37664 Mdot
.60095 .32837 Mdot
.60286 .25159 Mdot
.60476 .29931 Mdot
.60667 .33248 Mdot
.60857 .43939 Mdot
.61048 .2846 Mdot
.61238 .25979 Mdot
.61429 .41569 Mdot
.61619 .29355 Mdot
.6181 .3252 Mdot
.62 .31359 Mdot
.6219 .37909 Mdot
.62381 .35288 Mdot
.62571 .25793 Mdot
.62762 .26474 Mdot
.62952 .39517 Mdot
.63143 .34214 Mdot
.63333 .4273 Mdot
.63524 .28606 Mdot
.63714 .32086 Mdot
.63905 .22886 Mdot
.64095 .42982 Mdot
.64286 .28401 Mdot
.64476 .37032 Mdot
.64667 .2998 Mdot
.64857 .24698 Mdot
.65048 .27567 Mdot
.65238 .31606 Mdot
.65429 .29299 Mdot
.65619 .37715 Mdot
.6581 .38483 Mdot
.66 .24119 Mdot
.6619 .33476 Mdot
.66381 .28679 Mdot
.66571 .31469 Mdot
.66762 .26921 Mdot
.66952 .25501 Mdot
.67143 .34654 Mdot
.67333 .25149 Mdot
.67524 .25408 Mdot
.67714 .28605 Mdot
.67905 .40206 Mdot
.68095 .29977 Mdot
.68286 .27651 Mdot
.68476 .30695 Mdot
.68667 .43762 Mdot
.68857 .32241 Mdot
.69048 .33744 Mdot
.69238 .23998 Mdot
.69429 .32792 Mdot
.69619 .36302 Mdot
.6981 .40047 Mdot
.7 .3754 Mdot
.7019 .35544 Mdot
.70381 .3819 Mdot
.70571 .24726 Mdot
.70762 .3577 Mdot
.70952 .35565 Mdot
.71143 .33368 Mdot
.71333 .37674 Mdot
.71524 .44017 Mdot
.71714 .41402 Mdot
.71905 .35192 Mdot
.72095 .31409 Mdot
.72286 .25229 Mdot
.72476 .2718 Mdot
.72667 .29349 Mdot
.72857 .35951 Mdot
.73048 .40868 Mdot
.73238 .27724 Mdot
.73429 .40704 Mdot
.73619 .30675 Mdot
.7381 .3723 Mdot
.74 .36911 Mdot
.7419 .41791 Mdot
.74381 .32996 Mdot
.74571 .32277 Mdot
.74762 .23141 Mdot
.74952 .25759 Mdot
.75143 .33984 Mdot
.75333 .26099 Mdot
.75524 .30604 Mdot
.75714 .23325 Mdot
.75905 .29439 Mdot
.76095 .3886 Mdot
.76286 .30088 Mdot
.76476 .22553 Mdot
.76667 .37478 Mdot
.76857 .28726 Mdot
.77048 .31495 Mdot
.77238 .3984 Mdot
.77429 .31765 Mdot
.77619 .31292 Mdot
.7781 .33771 Mdot
.78 .34126 Mdot
.7819 .42432 Mdot
.78381 .41882 Mdot
.78571 .30773 Mdot
.78762 .31918 Mdot
.78952 .37239 Mdot
.79143 .41841 Mdot
.79333 .36491 Mdot
.79524 .26284 Mdot
.79714 .2509 Mdot
.79905 .31525 Mdot
.80095 .39241 Mdot
.80286 .37658 Mdot
.80476 .32902 Mdot
.80667 .33204 Mdot
.80857 .34508 Mdot
.81048 .34652 Mdot
.81238 .23033 Mdot
.81429 .35786 Mdot
.81619 .4068 Mdot
.8181 .29943 Mdot
.82 .35503 Mdot
.8219 .29142 Mdot
.82381 .34456 Mdot
.82571 .3665 Mdot
.82762 .34856 Mdot
.82952 .27564 Mdot
.83143 .28606 Mdot
.83333 .42005 Mdot
.83524 .27676 Mdot
.83714 .2593 Mdot
.83905 .37299 Mdot
.84095 .38933 Mdot
.84286 .29046 Mdot
.84476 .35458 Mdot
.84667 .22425 Mdot
.84857 .47414 Mdot
.85048 .31708 Mdot
.85238 .23343 Mdot
.85429 .34705 Mdot
.85619 .2628 Mdot
.8581 .43642 Mdot
.86 .353 Mdot
.8619 .29935 Mdot
.86381 .24101 Mdot
.86571 .3968 Mdot
.86762 .32829 Mdot
.86952 .32553 Mdot
.87143 .25322 Mdot
.87333 .41352 Mdot
.87524 .25055 Mdot
.87714 .46935 Mdot
.87905 .32525 Mdot
.88095 .26019 Mdot
.88286 .32201 Mdot
.88476 .32852 Mdot
.88667 .2649 Mdot
.88857 .32833 Mdot
.89048 .4071 Mdot
.89238 .27288 Mdot
.89429 .24783 Mdot
.89619 .26969 Mdot
.8981 .39302 Mdot
.9 .3687 Mdot
.9019 .40652 Mdot
.90381 .37706 Mdot
.90571 .47132 Mdot
.90762 .30529 Mdot
.90952 .38105 Mdot
.91143 .22988 Mdot
.91333 .25725 Mdot
.91524 .35552 Mdot
.91714 .28355 Mdot
.91905 .37245 Mdot
.92095 .33974 Mdot
.92286 .36197 Mdot
.92476 .30154 Mdot
.92667 .36369 Mdot
.92857 .35956 Mdot
.93048 .35114 Mdot
.93238 .28136 Mdot
.93429 .27324 Mdot
.93619 .24635 Mdot
.9381 .24785 Mdot
.94 .27049 Mdot
.9419 .2911 Mdot
.94381 .24467 Mdot
.94571 .28908 Mdot
.94762 .28267 Mdot
.94952 .32543 Mdot
.95143 .4425 Mdot
.95333 .3116 Mdot
.95524 .39276 Mdot
.95714 .34266 Mdot
.95905 .33152 Mdot
.96095 .30175 Mdot
.96286 .21667 Mdot
.96476 .30734 Mdot
.96667 .25179 Mdot
.96857 .37247 Mdot
.97048 .40431 Mdot
.97238 .34558 Mdot
.97429 .31264 Mdot
.97619 .34391 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l00014ooooo`;o0000iOooool2
o`00013ooooo000Yooooo`03o`000?oooooooooo04?ooooo0_l0003Uooooo`;o00004?ooool000Ko
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo1_ooool2o`0003Gooooo0006oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4
A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0MOooool2o`0007Cooooo0_l0
000Hooooo`;o0000=Oooool000Co00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07Gooooo0_l0
000Pooooo`;o0000:Oooool2o`0002Oooooo0_l0000=ooooo`;o00007_ooool2o`00023ooooo0006
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol0000Looooo`;o0000NOooool2o`0002Wooooo0_l0000Qooooo`;o000000?o
ooooo`000?l000004?ooool2o`0000_ooooo0_l0000Aooooo`;o00008?ooool000Kooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`03o`000?oooooooooo01cooooo0_l0001>ooooo`;o0000Moooool2o`000003oooo
ool0003o000001gooooo0_l0000cooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02gooooo
0_l0000aooooo`;o00002_ooool2o`0002Oooooo0_l0000looooo`;o0000Ioooool000Kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo01gooooo0ol0000=ooooo`;o0000<Oooool2o`0003?o
oooo0_l0000booooo`;o00002?ooool2o`0003Gooooo0_l0000`ooooo`001_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0
003oooooooooo`0Mooooo`?o0000ZOooool2o`0003oooooo0_l0000Fooooo`Co00005_ooool002Wo
oooo0_l0000;ooooo`;o00000oooool2o`0001cooooo0_l0001Zooooo`;o00002oooool2o`0001go
oooo0_l0000Aooooo`;o0000>_ooool2o`0000cooooo1?l0000Fooooo`00:Oooool2o`0000_ooooo
0_l00003ooooo`;o00007?ooool2o`00027ooooo0_l0000:ooooo`?o00000oooool2o`0003Gooooo
0_l00009ooooo`Go00003Oooool2o`0000gooooo0_l00006ooooo`;o00002Oooool2o`0000?ooooo
0_l0000Fooooo`;o00005oooool2o`0000Cooooo0_l0000<ooooo`;o00001oooool2o`0000oooooo
000Yooooo`03o`000?oooooooooo01Wooooo0_l0000Cooooo`;o00004?ooool2o`0000kooooo0_l0
000:ooooo`Go000000?oooooo`000?l00000@?ooool2o`000003ooooool0003o000000Gooooo0_l0
0006ooooo`;o00005?ooool4o`0000gooooo0_l0000Fooooo`;o00005_ooool3o`0001_ooooo0_l0
000?ooooo`00:Oooool00ol0003oooooooooo`0Gooooo`Co00004oooool2o`00013ooooo0_l0000M
ooooo`;o00001?ooool2o`0000Oooooo0_l00002ooooo`;o0000;Oooool2o`0000_ooooo0_l0000>
ooooo`;o00003?ooool4o`0001Kooooo0_l0000Uooooo`;o00002oooool2o`00023ooooo000Yoooo
o`04o`000?oooooo0000o`0001Kooooo0_l0000Oooooo`;o00001oooool2o`0000Kooooo0_l0000D
ooooo`;o00001?ooool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o00002Oooool2
o`0000?ooooo0_l00005ooooo`;o00004?ooool2o`0000Cooooo0_l00002ooooo`;o00004oooool2
o`0000;ooooo0_l0000Vooooo`?o00006Oooool2o`0000cooooo0_l00008ooooo`;o00008?ooool0
02Wooooo1?l00004ooooo`;o0000<Oooool2o`0000Oooooo1?l00004ooooo`;o00005_ooool2o`00
00Gooooo0_l0000Cooooo`;o00000oooool2o`0000Gooooo0_l0000<ooooo`;o00000_ooool2o`00
00Sooooo0_l0000Cooooo`;o00000_ooool2o`0002Oooooo0_l0000;ooooo`;o00003?ooool2o`00
00Cooooo0_l00006ooooo`Co0000:?ooool002Wooooo00?o0000ooooooooool01Oooool2o`0000?o
oooo0_l00009ooooo`;o0000;?ooool2o`0001cooooo0_l0000Uooooo`;o00003Oooool3o`0002Co
oooo0_l0000dooooo`;o00004_ooool2o`0000Sooooo0_l0000Xooooo`00:Oooool00ol0003ooooo
ooooo`0:ooooo`;o00002Oooool2o`0000cooooo0_l00005ooooo`;o00001?ooool4o`000008oa0@
4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_oo
ool2o`0000Gooooo0_l0000Nooooo`Go000000Ooooooo`000?l0003ok^k^oc8b<_l0003o<S8b00;o
00000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo0_l0000>ooooo`;o00004?ooool3o`00
0003oc8b<_o<c<cooooo00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool2o`0001cooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0
003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06Oooool2o`0000cooooo0_l00000
1Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool002Wooooo00?o0000ooooooooool00_ooool2o`0000kooooo
1?l00004ooooo`;o00001oooool2o`0000Cooooo1?l00005ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool2o`00
00Gooooo0_l0000Looooo`;o000000KoV9RHob4Q8Oo^k^koooooodA4A?ooool2o`000004ogMgMonH
V9SooooooiRHV0;o00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo0_l00003ooooo`;o
000000?oooooo`000?l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`;o00004Oooool2o`0000[ooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Hooooo`?o0000
2_ooool4o`0000?ooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000Yooooo`03o`000?oooooooooo00;ooooo0_l0000>
ooooo`Co00001?ooool2o`0000cooooo1Ol00005ooooo`06o`000?oooooo0000o`000?oooooo410@
0oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool04oooool2o`00013o
oooo0_l000001?ooooooV9RHob4Q8Oo^k^h2o`0000;ooooo00Go410@oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@41003?ooool2o`0000cooooo0_l000000ooooooo0000o`00
0002ooooo`Co00001_ooool2o`0000?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@
4?ooooooooooooooool@41001oooool2o`0000Sooooo0_l0000<ooooo`Co00001Oooool5o`0000?o
oooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool4
o`00017ooooo0_l0000;ooooo`;o00001_ooool01?l0003oooooooooool@4103ooooo`05oa0@4?oo
ooooooooooooool@41000oooool00ol@413oooooooooo`01ooooo`00:Oooool2o`0000gooooo0_l0
000Jooooo`;o00001Oooool2o`000003ooooool0003ooooo00;o000000?oooooo`000?ooool00_oo
ool00ol0003oooooooooo`02o`0000?ooooo00?o0000ooooooooool02oooool2o`0000Gooooo0ol0
000Dooooo`04oiRHV?lQ8B7o0000o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000003?ooool2o`0000cooooo0_l000000ooooooo0000o`000002oooo
o`;o00002?ooool00onYZJWo410@ooooo`02ooooo`?o000000?oooooo`000?ooool00_ooool01Ol0
003ooooooooooooooooo000000Oooooo0_l00008ooooo`;o00003_ooool2o`0000Gooooo00CoA4A4
omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`Co00009Oooool01OmgMgOo<S8boooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo007ooooo000Yooooo`03o`000?oooooooooo
00cooooo0_l0000Qooooo`;o000000?oooooo`000?ooool00oooool01Ol0003ooooooooooooooooo
000000;ooooo0_l00003ooooo`03o`000?oooooooooo00[ooooo0ol00004ooooo`?o00005_ooool0
0omgMgOo0000o`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000[ooooo0_l0000Nooooo`03oa0@4?l0003o^[Zj00?ooooo0ol000000ooooooo0000
ooooo`02ooooo`05o`000?ooooooooooooooool00000:?ooool01?oMgMgoEEEEooooool00004oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000023ooooo0_l0
0002ooooo`;o00000oooool3o`000005oc8b<_o<c<coooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool00Oooool002Wooooo00?o0000ooooooooool0
9Oooool2o`0000_ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@4004ooooo`;o00001_ooool2o`0000Gooooo0_l00002oooo
o`;o00005?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool00_l00003
ooooo`03oa0@4?oooooooooo00Sooooo0_l0000Mooooo`;o000000?o^[Zjob4Q8Oooool00_ooool0
1Ol@413oooooo`000?l0003o410@00;ooooo0_l00003ooooo`03oa0@4?oooooooooo00Co00001Ooo
ool2o`0000;ooooo0_l0000Hooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooo
oa0@4003ooooo`05oa0@4?ooooooooooooooool@41001?ooool2o`0001[ooooo0_l00002ooooo`;o
00000oooool2o`0000Gooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooo
ooooool@41000oooool002Wooooo00?o0000ooooooooool09Oooool2o`0000_ooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`04ooooo`;o00004Oooool2o`000003ooooool0003o000000gooooo00Go0000okZj^_ooooooV9RH
oa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool2o`000004oiRHV?ooooooV9RHogMg
MbSooooo00Go410@o`000?l0003o^[Zjo`000003ooooo`05ogMgMonHV9So0000o`000?mgMgL00_oo
ool2o`000004oiRHV?ooooooV9RHogMgM`;ooooo1?l00005ooooo`;o00000_ooool2o`0001Sooooo
00Cok^k^odA4A?l0003ooooo0_l000001_ooooooMgMgoiRHV?ooooooV9RHogMgM`?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`04ooooo`;o00008oooool2o`0000Gooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wooooo00?o0000ooooooooool0
4oooool2o`0001_ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`;o00003Oooool2o`0000_ooooo0_l000001OnH
V9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h0:?ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool2o`00023ooooo00?oMgMg
o`000?ooool00_l000001_ooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Kok^k^oc8b<_l0003o
<S8bonk^k_ooool2o`0000Gooooo0_l0000Mooooo`Ko00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool2o`0000Cooooo0_l0000>
ooooo`;o0000>_ooool2o`0001[ooooo0_l0000`ooooo`;o00007?ooool2o`0000[ooooo0_l0000E
ooooo`;o00002Oooool2o`0001;ooooo0_l00005ooooo`;o00007Oooool2o`0001Oooooo000Yoooo
o`03o`000?oooooooooo00?ooooo0_l00009ooooo`;o0000=oooool2o`00037ooooo0_l0000Qoooo
o`;o00006?ooool2o`0000;ooooo0_l0000Qooooo`;o00002Oooool2o`00017ooooo0_l0000<oooo
o`;o0000<?ooool002Wooooo00?o0000ooooooooool03_ooool2o`0003Oooooo0_l0000aooooo`;o
0000>oooool2o`0000cooooo0_l00009ooooo`;o00006?ooool2o`00013ooooo0_l0000<ooooo`;o
00004_ooool2o`0000[ooooo0_l0000@ooooo`00:Oooool00ol0003oooooooooo`1<ooooo`;o0000
:oooool2o`0002gooooo0_l0000Kooooo`;o00002Oooool2o`0001Sooooo0_l0000/ooooo`;o0000
1?ooool2o`0000[ooooo0_l0000@ooooo`00:Oooool00ol0003oooooooooo`0<ooooo`;o00005Ooo
ool2o`0000_ooooo0_l0000Jooooo`;o00001_ooool2o`0002?ooooo0_l00003ooooo`;o00006_oo
ool2o`0000cooooo0_l0000Wooooo`;o00003_ooool2o`0000Cooooo0_l00008ooooo`;o00009Ooo
ool2o`00017ooooo0_l0000?ooooo`008Oooooooo`0004Co00001?ooool002Wooooo0ol000000ooo
oooo0000o`000005ooooo`;o00003?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00[ooooo0_l00003ooooo`;o00001Oooool00ol0003oooooooooo`04ooooo`Co000000?oooooo`00
0?ooool02_ooool00ol0003oooooooooo`0:ooooo`04o`000?ooooooooooooooo`;o00001_ooool0
0ol0003oooooooooo`04ooooo`;o00000oooool00ol0003oooooooooo`07ooooo`?o00003?ooool0
1?l0003oooooo`000?l00008ooooo`03o`000?oooooooooo00?ooooo1?l00002ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00Co0000oooooooooooooooo0_l00005ooooo`;o00003?ooool002Wooooo1?l0
000Jooooo`;o00002Oooool2o`0001;ooooo00?o0000ooooooooool03_ooool2o`0002Oooooo0_l0
0002ooooo`03o`000?oooooooooo00;ooooo0_l0000;ooooo`;o000000?oooooo`000?l000004ooo
ool2o`0000Wooooo0_l00006ooooo`03o`000?oooooooooo00Cooooo0_l00008ooooo`;o00000ooo
ool2o`0000oooooo0_l0000>ooooo`Co00000_ooool01?l0003oooooooooooooool2o`0000kooooo
0_l0000Vooooo`;o00003?ooool002Wooooo00Co0000ooooool0003o00005Oooool2o`0000?ooooo
0_l00009ooooo`;o00002oooool2o`0001Kooooo0_l0000Jooooo`;o00002oooool2o`0001Cooooo
0_l0000Fooooo`;o00007Oooool2o`0000?ooooo0_l0000Vooooo`;o00000_ooool2o`0000;ooooo
0_l0000>ooooo`;o0000=?ooool002Wooooo00?o0000ooooooooool05_ooool2o`0001;ooooo0_l0
0007ooooo`;o0000<_ooool2o`0001Kooooo0_l0000Yooooo`;o00005Oooool2o`0000oooooo0_l0
000@ooooo`;o00003?ooool2o`0001cooooo0_l0000Zooooo`00:Oooool2o`0000[ooooo0_l00002
ooooo`;o00006oooool2o`0000Kooooo0_l0000Mooooo`;o00006Oooool2o`00017ooooo0_l0000>
ooooo`;o000000?oooooo`000?l000000_l0000Dooooo`;o00003oooool2o`0001Gooooo0_l0000@
ooooo`;o00009_ooool2o`000004ooooool0003o0000o`0001Cooooo0_l0000Dooooo`00:Oooool0
0ol0003oooooooooo`09ooooo`;o00000_ooool2o`0002?ooooo0_l0000Mooooo`;o00006Oooool2
o`0001Gooooo0_l0000:ooooo`;o000000?oooooo`000?l000000_l0000Pooooo`;o00000oooool2
o`0001Oooooo0_l0000>ooooo`;o00004Oooool2o`0001?ooooo0_l000000ooooooo0000o`000003
o`0001;ooooo0_l0000Dooooo`00:Oooool00ol0003oooooooooo`0=ooooo`;o0000>Oooool2o`00
02Cooooo0_l0000Cooooo`;o00006Oooool2o`0001Kooooo1?l0000Jooooo`;o00000oooool2o`00
00Wooooo0_l0000Aooooo`?o00004_ooool2o`0000?ooooo0ol0000Eooooo`;o00004Oooool002Wo
oooo00?o0000ooooooooool01_ooool2o`0000Gooooo0_l0000Wooooo`;o00004?ooool2o`0001co
oooo0_l00006ooooo`;o00007Oooool2o`000003ooooool0003o000000cooooo0_l0000Hooooo`;o
00003oooool2o`0000kooooo0_l0000Mooooo`;o0000;oooool2o`00017ooooo000Yooooo`03o`00
0?oooooooooo00Kooooo0_l0000]ooooo`?o00001oooool2o`0001?ooooo0_l0000@ooooo`;o0000
7oooool4o`0000;ooooo0_l000000ooooooo0000o`00000Eooooo`;o00000_ooool2o`0001cooooo
0_l00008ooooo`;o00004Oooool2o`0000Oooooo0_l0000/ooooo`;o00007Oooool002Wooooo0_l0
000fooooo`;o00001Oooool2o`000003ooooool0003o000000cooooo0_l00005ooooo`;o00005ooo
ool2o`0001Sooooo1?l00006ooooo`;o00005?ooool2o`0000;ooooo0_l0000Cooooo`;o00004Ooo
ool2o`00017ooooo0_l00007ooooo`;o0000;?ooool2o`0000Wooooo0_l0000Booooo`00:Oooool0
0ol0003oooooooooo`0Rooooo`;o00003Oooool3o`0000Sooooo0_l0000?ooooo`;o00007_ooool2
o`0001;ooooo0_l0000>ooooo`;o0000;Oooool2o`0002gooooo0_l00008ooooo`;o00000oooool2
o`0002Sooooo0_l00003ooooo`Co00002oooool002Wooooo00?o0000ooooooooool08_ooool2o`00
00gooooo0ol0000Jooooo`;o00008_ooool2o`0000gooooo0_l0001:ooooo`;o0000:_ooool2o`00
00?ooooo0ol00006ooooo`;o00009?ooool4o`0000_ooooo000Yooooo`03o`000?oooooooooo01Co
oooo0_l0000Aooooo`;o00005?ooool2o`0000oooooo0_l00006ooooo`;o00003_ooool2o`0000[o
oooo0_l00003ooooo`;o00005oooool2o`0000kooooo0_l0000[ooooo`;o00003Oooool2o`0001_o
oooo0_l00004ooooo`;o00001_ooool2o`0001Oooooo0_l0000Jooooo`00:Oooool00ol0003ooooo
ooooo`02o`0001;ooooo0ol0000@ooooo`;o00005?ooool2o`0001Oooooo1_l00008ooooo`Go0000
3Oooool3o`0001Kooooo0ol00003ooooo`;o00000oooool2o`0000Cooooo0_l0000Aooooo`;o0000
2?ooool2o`0001Oooooo0_l00004ooooo`;o00007_ooool2o`0000Kooooo0_l00003ooooo`;o0000
5Oooool2o`0001[ooooo000Yooooo`;o000000?oooooo`000?l000004oooool2o`0001Gooooo0_l0
000Zooooo`Co00002?ooool2o`000003ooooool0003o000000gooooo0_l00003ooooo`;o00004_oo
ool2o`0000Cooooo0_l00003ooooo`;o00005_ooool3o`0000Sooooo0_l0000Gooooo`Go00007ooo
ool4o`0000Kooooo0_l00003ooooo`;o00004?ooool2o`0001oooooo000Yooooo`03o`000?oooooo
oooo017ooooo0_l00004ooooo`;o00004oooool2o`0000Sooooo0_l0000Booooo`;o00001oooool2
o`0000Cooooo0_l0000Pooooo`;o00000_ooool2o`0002kooooo1Ol0000Tooooo`?o00001?ooool2
o`0001Wooooo0_l0000Oooooo`;o00000_ooool2o`0001_ooooo000Yooooo`03o`000?oooooooooo
017ooooo0_l00004ooooo`;o00007Oooool2o`0000;ooooo0ol00007ooooo`Co00000_ooool2o`00
00Oooooo0_l0000Zooooo`;o000000Coooooo`000?l0003ooooo0_l0000Xooooo`Co00008Oooool2
o`0000Wooooo0_l0000looooo`Co00006oooool002Wooooo00?o0000ooooooooool06?ooool2o`00
00Sooooo0_l0000Eooooo`Co00001oooool4o`0000Kooooo0_l0000Vooooo`;o00001?ooool2o`00
00Cooooo0_l000000ooooooo0000o`000003ooooo`;o0000B?ooool2o`0001kooooo0_l00008oooo
o`;o00007Oooool4o`0001_ooooo000Yooooo`03o`000?oooooooooo00Cooooo0ol0000Aooooo`;o
00002?ooool2o`0001Gooooo0_l0000Cooooo`;o00009_ooool2o`0000Cooooo0_l00003ooooo`;o
000000?oooooo`000?l000001?ooool2o`0003Sooooo0_l0000Mooooo`;o00003oooool2o`0000So
oooo0_l0000Fooooo`;o00009?ooool002Wooooo0_l00005ooooo`?o00000_ooool2o`0001Gooooo
0_l0000Looooo`;o00000_ooool2o`0001oooooo0_l0000Looooo`;o000000?oooooo`000?l00000
?_ooool2o`0001cooooo0ol0000=ooooo`;o00003_ooool2o`0001;ooooo0_l00004ooooo`;o0000
3_ooool2o`0000kooooo000Yooooo`03o`000?oooooooooo00Cooooo0_l000000ooooooo0000o`00
0002o`0001Gooooo0_l0000Aooooo`;o00002Oooool2o`0000;ooooo0_l0000Oooooo`;o00008?oo
ool2o`0001_ooooo0ol0000@ooooo`;o00004Oooool2o`0000cooooo0_l00002ooooo`;o00001_oo
ool2o`0000Oooooo0_l00005ooooo`;o00000oooool2o`0000Wooooo0_l0000Cooooo`;o00000ooo
ool2o`0000kooooo0_l0000>ooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo0_l00008ooooo`;o0000
5oooool2o`0000Kooooo0_l00009ooooo`;o00001Oooool3o`0001Sooooo0_l0000Cooooo`;o0000
6Oooool2o`0000cooooo0_l000000ooooooo0000o`00000:ooooo`?o00001?ooool2o`0000[ooooo
0_l00006ooooo`;o00002Oooool2o`0000cooooo0_l00002ooooo`;o00003oooool2o`0000[ooooo
0_l0000Nooooo`;o00008oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool2o`0000So
oooo0_l0000Dooooo`;o000000?oooooo`000?l000001_ooool2o`000003ooooool0003o000000go
oooo0ol0000Hooooo`;o00001Oooool2o`0000cooooo0_l0000Wooooo`;o000000?oooooo`000?l0
00004Oooool2o`0001;ooooo0_l0000Hooooo`;o0000@?ooool2o`00027ooooo0006ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02oooool2o`0000;ooooo0_l0000<ooooo`;o00003?ooool2o`0002oo
oooo0_l0001Zooooo`;o00003Oooool2o`00043ooooo0_l0000Qooooo`001_ooool01Ol0003ooooo
oooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o
00002oooool2o`0000;ooooo0_l000000ooooooo0000o`000017ooooo`;o0000@oooool2o`0000[o
oooo1?l00002ooooo`;o00005?ooool2o`0001oooooo0_l0000Hooooo`;o0000=oooool000Kooooo
00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c005ooooo`03o`000?oooooooooo01;ooooo0_l00004ooooo`;o0000@Oooool2o`00
04?ooooo0_l0000:ooooo`Co00000_ooool2o`0003Gooooo0_l0000;ooooo`;o00002oooool2o`00
02?ooooo0_l0000Booooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Sooooo0_l00007oooo
o`;o0000W?ooool2o`0003Gooooo0_l0000Mooooo`;o00004Oooool2o`0001;ooooo0006ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Qooooo`;o00001?ooool2o`0001Oooooo0_l00007
ooooo`;o0000>Oooool2o`0003Wooooo0_l0000/ooooo`;o00007?ooool2o`0000Sooooo0_l0000U
ooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c004ooooo`Co00001_ooool00ol0003oooooooooo`0Wooooo`;o00005oooool2o`0000Oooooo0_l0
0008ooooo`;o0000;oooool2o`0001Oooooo0_l0000`ooooo`;o00001?ooool2o`0001Kooooo0_l0
000Looooo`;o0000;oooool002Wooooo0_l0000Pooooo`;o0000<_ooool2o`0004Sooooo0_l0000F
ooooo`;o00006?ooool2o`0000Cooooo0_l0001Fooooo`;o00003Oooool002Wooooo00Co0000oooo
oooooooooooo0_l0000Looooo`;o0000@?ooool2o`0005;ooooo0_l0000Zooooo`;o00006?ooool2
o`0001Kooooo0_l00002ooooo`;o00005?ooool2o`0000gooooo000Yooooo`04o`000?oooooooooo
ooooo`;o0000=Oooool2o`0002Oooooo0_l0001looooo`Co00006?ooool2o`0001Kooooo0_l00002
ooooo`;o00008oooool002Wooooo00?o0000ooooooooool07?ooool2o`0001[ooooo0_l00003oooo
o`;o0000B?ooool2o`0001?ooooo0_l000000ooooooo0000o`00000?ooooo`;o0000:Oooool2o`00
00;ooooo0_l0000/ooooo`;o0000;Oooool002Wooooo00?o0000ooooooooool07?ooool2o`00013o
oooo0_l0000=ooooo`;o00009Oooool2o`0001[ooooo0_l00004ooooo`?o00002Oooool2o`0000So
oooo0_l000000ooooooo0000o`00000?ooooo`;o00002?ooool2o`0001oooooo0_l0000`ooooo`;o
0000;Oooool002Wooooo0_l0000Kooooo`;o00004_ooool2o`0002;ooooo0_l0000@ooooo`;o0000
6_ooool2o`0000Cooooo0_l0000:ooooo`;o00005?ooool2o`00013ooooo0_l0000Wooooo`;o0000
3?ooool4o`0000cooooo0_l0000iooooo`00:Oooool00ol0003oooooooooo`0Jooooo`;o0000=_oo
ool2o`00023ooooo0_l0000booooo`;o0000>Oooool2o`0000cooooo1?l0000<ooooo`;o0000>Ooo
ool002Wooooo00?o0000ooooooooool0M?ooool2o`0007[ooooo0_l0001:ooooo`00:Oooool00ol0
003oooooooooo`0@ooooo`;o0000Eoooool2o`0005Gooooo0_l000000ooooooo0000o`00000[oooo
o`;o0000B_ooool002Wooooo00?o0000ooooooooool04?ooool2o`0001;ooooo0_l0000:ooooo`;o
0000=oooool2o`0000Cooooo0_l0001?ooooo`;o000000?oooooo`000?l00000Moooool002Wooooo
0_l00003ooooo`;o00008?ooool2o`0000[ooooo0_l0000?ooooo`;o0000;?ooool2o`000<_ooooo
000Yooooo`03o`000?oooooooooo00;ooooo0_l0000<ooooo`;o0000;oooool2o`0001?ooooo0_l0
000Hooooo`;o0000A_ooool2o`0001Oooooo0_l0000fooooo`;o0000<Oooool002Wooooo00?o0000
ooooooooool04?ooool2o`0000gooooo0_l00004ooooo`;o0000;oooool2o`0000_ooooo0_l0000;
ooooo`;o00008_ooool2o`0002;ooooo0_l0000Gooooo`;o00002?ooool2o`0002cooooo0_l0000L
ooooo`;o00004oooool002Wooooo00?o0000ooooooooool07oooool2o`0000Cooooo0_l0000Noooo
o`;o00005oooool2o`0000?ooooo0_l0000_ooooo`;o0000AOooool2o`0004[ooooo0_l0000Coooo
o`00:Oooool00ol0003oooooooooo`15ooooo`;o00005oooool2o`000=cooooo000Yooooo`;o0000
oooooolnooooo`00:Oooool00ol0003oooooooooo`2<ooooo`;o0000[_ooool000kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo
00?o0000ooooooooool0N_ooool2o`00013ooooo0_l0002^ooooo`003_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
N_ooool2o`000<3ooooo000>ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooo
ooooo`03ooooo`?o0000Moooool2o`000<?ooooo000>ooooo`05o`000?ooooooooooooooool00000
3oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo06oooooo0_l00006ooooo`;o0000
=oooool2o`0008[ooooo000>ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0Boooool2o`0002;ooooo0_l0000oooooo`;o
0000GOooool2o`0002_ooooo000>ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo03Gooooo0_l0000Dooooo`;o00007?ooool2o`000:Co
oooo0_l00007ooooo`;o00008_ooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0=Oooool4o`00033ooooo0_l0002Jooooo`;o
00004Oooool2o`0002;ooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Ko
oooo0_l0000hooooo`;o0000c?ooool2o`0003Gooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooocko
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooocko
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^
k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo
?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVY
ooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_oo
ool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003ooooo
ooooo`03ooooo`?o0000oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo
00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo
?Oooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo
00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`00
00Cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool001oooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo?Ooo
ool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qoooo
o`03o`000?oooooooooo00Gooooo0ol0003oooooocgooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001oooooo00?oEEEEofIV
I_l00000oooooom7ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .39894 Mdot
.02762 .33924 Mdot
.02952 .28934 Mdot
.03143 .31109 Mdot
.03333 .25172 Mdot
.03524 .27 Mdot
.03714 .27246 Mdot
.03905 .44843 Mdot
.04095 .38956 Mdot
.04286 .33329 Mdot
.04476 .2551 Mdot
.04667 .43615 Mdot
.04857 .27744 Mdot
.05048 .2735 Mdot
.05238 .43262 Mdot
.05429 .28267 Mdot
.05619 .34851 Mdot
.0581 .28887 Mdot
.06 .35489 Mdot
.0619 .40074 Mdot
.06381 .28428 Mdot
.06571 .27021 Mdot
.06762 .25016 Mdot
.06952 .30651 Mdot
.07143 .38487 Mdot
.07333 .36208 Mdot
.07524 .26941 Mdot
.07714 .35667 Mdot
.07905 .38543 Mdot
.08095 .33579 Mdot
.08286 .31106 Mdot
.08476 .39429 Mdot
.08667 .44607 Mdot
.08857 .38034 Mdot
.09048 .35123 Mdot
.09238 .41922 Mdot
.09429 .23166 Mdot
.09619 .34438 Mdot
.0981 .36985 Mdot
.1 .42759 Mdot
.1019 .37778 Mdot
.10381 .3746 Mdot
.10571 .2642 Mdot
.10762 .39958 Mdot
.10952 .39462 Mdot
.11143 .33992 Mdot
.11333 .29842 Mdot
.11524 .34675 Mdot
.11714 .25621 Mdot
.11905 .39441 Mdot
.12095 .33842 Mdot
.12286 .3173 Mdot
.12476 .45689 Mdot
.12667 .31474 Mdot
.12857 .29189 Mdot
.13048 .42608 Mdot
.13238 .44701 Mdot
.13429 .34987 Mdot
.13619 .27238 Mdot
.1381 .38883 Mdot
.14 .34941 Mdot
.1419 .23338 Mdot
.14381 .36735 Mdot
.14571 .2616 Mdot
.14762 .44005 Mdot
.14952 .4146 Mdot
.15143 .33962 Mdot
.15333 .26195 Mdot
.15524 .34984 Mdot
.15714 .32951 Mdot
.15905 .3735 Mdot
.16095 .31629 Mdot
.16286 .3318 Mdot
.16476 .34726 Mdot
.16667 .36763 Mdot
.16857 .29636 Mdot
.17048 .45673 Mdot
.17238 .36308 Mdot
.17429 .33862 Mdot
.17619 .30321 Mdot
.1781 .38804 Mdot
.18 .34439 Mdot
.1819 .33006 Mdot
.18381 .37016 Mdot
.18571 .44781 Mdot
.18762 .30387 Mdot
.18952 .25621 Mdot
.19143 .27746 Mdot
.19333 .33283 Mdot
.19524 .2643 Mdot
.19714 .38198 Mdot
.19905 .4597 Mdot
.20095 .31687 Mdot
.20286 .31107 Mdot
.20476 .29421 Mdot
.20667 .45046 Mdot
.20857 .28044 Mdot
.21048 .33505 Mdot
.21238 .44988 Mdot
.21429 .3435 Mdot
.21619 .39866 Mdot
.2181 .30066 Mdot
.22 .43751 Mdot
.2219 .3947 Mdot
.22381 .37377 Mdot
.22571 .38078 Mdot
.22762 .37837 Mdot
.22952 .3422 Mdot
.23143 .31867 Mdot
.23333 .33021 Mdot
.23524 .30574 Mdot
.23714 .3142 Mdot
.23905 .38896 Mdot
.24095 .4187 Mdot
.24286 .29761 Mdot
.24476 .30497 Mdot
.24667 .35879 Mdot
.24857 .43226 Mdot
.25048 .41895 Mdot
.25238 .2409 Mdot
.25429 .27313 Mdot
.25619 .22401 Mdot
.2581 .24232 Mdot
.26 .37937 Mdot
.2619 .33265 Mdot
.26381 .29226 Mdot
.26571 .41415 Mdot
.26762 .42717 Mdot
.26952 .38283 Mdot
.27143 .26462 Mdot
.27333 .24678 Mdot
.27524 .39321 Mdot
.27714 .42414 Mdot
.27905 .28733 Mdot
.28095 .24282 Mdot
.28286 .35388 Mdot
.28476 .23426 Mdot
.28667 .40074 Mdot
.28857 .33505 Mdot
.29048 .44666 Mdot
.29238 .42926 Mdot
.29429 .29821 Mdot
.29619 .33964 Mdot
.2981 .35697 Mdot
.3 .34999 Mdot
.3019 .41139 Mdot
.30381 .44367 Mdot
.30571 .22135 Mdot
.30762 .3418 Mdot
.30952 .29717 Mdot
.31143 .23048 Mdot
.31333 .28813 Mdot
.31524 .32578 Mdot
.31714 .31463 Mdot
.31905 .32113 Mdot
.32095 .3237 Mdot
.32286 .25813 Mdot
.32476 .35167 Mdot
.32667 .42919 Mdot
.32857 .23263 Mdot
.33048 .25103 Mdot
.33238 .32717 Mdot
.33429 .33509 Mdot
.33619 .37533 Mdot
.3381 .41446 Mdot
.34 .2756 Mdot
.3419 .39811 Mdot
.34381 .44104 Mdot
.34571 .38987 Mdot
.34762 .34516 Mdot
.34952 .25116 Mdot
.35143 .40964 Mdot
.35333 .32006 Mdot
.35524 .32492 Mdot
.35714 .25352 Mdot
.35905 .32644 Mdot
.36095 .4445 Mdot
.36286 .44334 Mdot
.36476 .31503 Mdot
.36667 .31757 Mdot
.36857 .38139 Mdot
.37048 .27853 Mdot
.37238 .41359 Mdot
.37429 .3391 Mdot
.37619 .36842 Mdot
.3781 .31358 Mdot
.38 .37792 Mdot
.3819 .42174 Mdot
.38381 .39601 Mdot
.38571 .38449 Mdot
.38762 .24778 Mdot
.38952 .24191 Mdot
.39143 .41125 Mdot
.39333 .2758 Mdot
.39524 .22389 Mdot
.39714 .44934 Mdot
.39905 .32434 Mdot
.40095 .43239 Mdot
.40286 .29306 Mdot
.40476 .47647 Mdot
.40667 .38346 Mdot
.40857 .32525 Mdot
.41048 .32633 Mdot
.41238 .30885 Mdot
.41429 .25044 Mdot
.41619 .47874 Mdot
.4181 .39694 Mdot
.42 .32847 Mdot
.4219 .29193 Mdot
.42381 .31357 Mdot
.42571 .33292 Mdot
.42762 .25415 Mdot
.42952 .23792 Mdot
.43143 .36109 Mdot
.43333 .39062 Mdot
.43524 .32201 Mdot
.43714 .39801 Mdot
.43905 .35239 Mdot
.44095 .37267 Mdot
.44286 .32177 Mdot
.44476 .37323 Mdot
.44667 .43498 Mdot
.44857 .35652 Mdot
.45048 .27477 Mdot
.45238 .38277 Mdot
.45429 .39908 Mdot
.45619 .29129 Mdot
.4581 .2669 Mdot
.46 .3506 Mdot
.4619 .31876 Mdot
.46381 .43156 Mdot
.46571 .22307 Mdot
.46762 .25902 Mdot
.46952 .31613 Mdot
.47143 .47729 Mdot
.47333 .24688 Mdot
.47524 .2718 Mdot
.47714 .23149 Mdot
.47905 .33657 Mdot
.48095 .389 Mdot
.48286 .24438 Mdot
.48476 .39556 Mdot
.48667 .23224 Mdot
.48857 .24568 Mdot
.49048 .41005 Mdot
.49238 .373 Mdot
.49429 .40199 Mdot
.49619 .27733 Mdot
.4981 .27819 Mdot
.5 .2849 Mdot
.5019 .37137 Mdot
.50381 .36267 Mdot
.50571 .33633 Mdot
.50762 .30879 Mdot
.50952 .28087 Mdot
.51143 .26076 Mdot
.51333 .3615 Mdot
.51524 .31738 Mdot
.51714 .26198 Mdot
.51905 .28753 Mdot
.52095 .44779 Mdot
.52286 .31535 Mdot
.52476 .24663 Mdot
.52667 .27123 Mdot
.52857 .40632 Mdot
.53048 .27361 Mdot
.53238 .27472 Mdot
.53429 .39336 Mdot
.53619 .28828 Mdot
.5381 .24288 Mdot
.54 .41707 Mdot
.5419 .34693 Mdot
.54381 .41871 Mdot
.54571 .27518 Mdot
.54762 .33259 Mdot
.54952 .26925 Mdot
.55143 .26034 Mdot
.55333 .34412 Mdot
.55524 .29586 Mdot
.55714 .35076 Mdot
.55905 .25371 Mdot
.56095 .31606 Mdot
.56286 .36738 Mdot
.56476 .27535 Mdot
.56667 .33991 Mdot
.56857 .23359 Mdot
.57048 .44141 Mdot
.57238 .3383 Mdot
.57429 .31627 Mdot
.57619 .28524 Mdot
.5781 .42224 Mdot
.58 .3168 Mdot
.5819 .37418 Mdot
.58381 .41998 Mdot
.58571 .25593 Mdot
.58762 .43952 Mdot
.58952 .25344 Mdot
.59143 .27864 Mdot
.59333 .2496 Mdot
.59524 .22737 Mdot
.59714 .42167 Mdot
.59905 .4356 Mdot
.60095 .21777 Mdot
.60286 .28168 Mdot
.60476 .24093 Mdot
.60667 .39024 Mdot
.60857 .39945 Mdot
.61048 .38865 Mdot
.61238 .28202 Mdot
.61429 .34396 Mdot
.61619 .35611 Mdot
.6181 .30458 Mdot
.62 .23591 Mdot
.6219 .35878 Mdot
.62381 .25871 Mdot
.62571 .24177 Mdot
.62762 .29588 Mdot
.62952 .38173 Mdot
.63143 .38013 Mdot
.63333 .44302 Mdot
.63524 .26723 Mdot
.63714 .41078 Mdot
.63905 .28343 Mdot
.64095 .34385 Mdot
.64286 .26214 Mdot
.64476 .29647 Mdot
.64667 .36689 Mdot
.64857 .34657 Mdot
.65048 .25871 Mdot
.65238 .32386 Mdot
.65429 .27045 Mdot
.65619 .37291 Mdot
.6581 .44179 Mdot
.66 .27149 Mdot
.6619 .29315 Mdot
.66381 .23889 Mdot
.66571 .26842 Mdot
.66762 .30771 Mdot
.66952 .34663 Mdot
.67143 .2616 Mdot
.67333 .27379 Mdot
.67524 .32776 Mdot
.67714 .25372 Mdot
.67905 .46676 Mdot
.68095 .35827 Mdot
.68286 .3622 Mdot
.68476 .26141 Mdot
.68667 .43892 Mdot
.68857 .26084 Mdot
.69048 .40545 Mdot
.69238 .32211 Mdot
.69429 .33746 Mdot
.69619 .32743 Mdot
.6981 .29625 Mdot
.7 .43739 Mdot
.7019 .25061 Mdot
.70381 .41885 Mdot
.70571 .29469 Mdot
.70762 .383 Mdot
.70952 .41187 Mdot
.71143 .257 Mdot
.71333 .43781 Mdot
.71524 .36132 Mdot
.71714 .41261 Mdot
.71905 .42622 Mdot
.72095 .40696 Mdot
.72286 .36504 Mdot
.72476 .28376 Mdot
.72667 .24711 Mdot
.72857 .42865 Mdot
.73048 .44777 Mdot
.73238 .27672 Mdot
.73429 .35726 Mdot
.73619 .36028 Mdot
.7381 .30138 Mdot
.74 .39913 Mdot
.7419 .34935 Mdot
.74381 .39013 Mdot
.74571 .23169 Mdot
.74762 .30894 Mdot
.74952 .25846 Mdot
.75143 .23842 Mdot
.75333 .25486 Mdot
.75524 .40119 Mdot
.75714 .2595 Mdot
.75905 .23179 Mdot
.76095 .33994 Mdot
.76286 .32169 Mdot
.76476 .32008 Mdot
.76667 .32844 Mdot
.76857 .27262 Mdot
.77048 .40788 Mdot
.77238 .33362 Mdot
.77429 .32317 Mdot
.77619 .34671 Mdot
.7781 .36902 Mdot
.78 .2841 Mdot
.7819 .35978 Mdot
.78381 .39464 Mdot
.78571 .22344 Mdot
.78762 .41003 Mdot
.78952 .37592 Mdot
.79143 .47214 Mdot
.79333 .38103 Mdot
.79524 .3297 Mdot
.79714 .30491 Mdot
.79905 .3043 Mdot
.80095 .44401 Mdot
.80286 .43746 Mdot
.80476 .26655 Mdot
.80667 .33334 Mdot
.80857 .29003 Mdot
.81048 .32371 Mdot
.81238 .27767 Mdot
.81429 .30508 Mdot
.81619 .4154 Mdot
.8181 .33792 Mdot
.82 .32808 Mdot
.8219 .26528 Mdot
.82381 .27784 Mdot
.82571 .37829 Mdot
.82762 .30015 Mdot
.82952 .32382 Mdot
.83143 .22658 Mdot
.83333 .44684 Mdot
.83524 .2937 Mdot
.83714 .34134 Mdot
.83905 .37829 Mdot
.84095 .34526 Mdot
.84286 .35372 Mdot
.84476 .33476 Mdot
.84667 .31057 Mdot
.84857 .46408 Mdot
.85048 .38443 Mdot
.85238 .35614 Mdot
.85429 .3967 Mdot
.85619 .30845 Mdot
.8581 .39668 Mdot
.86 .42555 Mdot
.8619 .25436 Mdot
.86381 .32435 Mdot
.86571 .46437 Mdot
.86762 .33606 Mdot
.86952 .30916 Mdot
.87143 .31442 Mdot
.87333 .40634 Mdot
.87524 .31989 Mdot
.87714 .47059 Mdot
.87905 .32637 Mdot
.88095 .3415 Mdot
.88286 .37565 Mdot
.88476 .27843 Mdot
.88667 .30262 Mdot
.88857 .34742 Mdot
.89048 .44821 Mdot
.89238 .27746 Mdot
.89429 .3489 Mdot
.89619 .35865 Mdot
.8981 .39052 Mdot
.9 .41696 Mdot
.9019 .35694 Mdot
.90381 .36978 Mdot
.90571 .43125 Mdot
.90762 .34545 Mdot
.90952 .44044 Mdot
.91143 .33557 Mdot
.91333 .28911 Mdot
.91524 .25085 Mdot
.91714 .35055 Mdot
.91905 .32678 Mdot
.92095 .40655 Mdot
.92286 .39867 Mdot
.92476 .35176 Mdot
.92667 .33027 Mdot
.92857 .38085 Mdot
.93048 .23705 Mdot
.93238 .24691 Mdot
.93429 .29969 Mdot
.93619 .28373 Mdot
.9381 .29454 Mdot
.94 .28583 Mdot
.9419 .25953 Mdot
.94381 .3192 Mdot
.94571 .2435 Mdot
.94762 .32351 Mdot
.94952 .36653 Mdot
.95143 .41606 Mdot
.95333 .25058 Mdot
.95524 .3877 Mdot
.95714 .35637 Mdot
.95905 .35582 Mdot
.96095 .26678 Mdot
.96286 .30919 Mdot
.96476 .26804 Mdot
.96667 .34303 Mdot
.96857 .27214 Mdot
.97048 .41634 Mdot
.97238 .35346 Mdot
.97429 .39356 Mdot
.97619 .423 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0002gooooo`;o0000Q?ooool0
02Wooooo00?o0000ooooooooool0Eoooool2o`0005gooooo0_l00024ooooo`001_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool0Aoooool2o`0000kooooo0_l0000Kooooo`;o00005?ooool2
o`0006Gooooo0_l00019ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo04Oooooo0_l0000[ooooo`;o00005?ooool2o`0002Sooooo0_l0000kooooo`;o00003Ooo
ool2o`0003[ooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Iooooo`;o0000FOoo
ool2o`0004[ooooo0_l0000jooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o00004oooool2o`0000gooooo0_l0
000eooooo`;o00000oooool2o`0002kooooo0_l000000ooooooo0000o`00000Hooooo`;o0000=ooo
ool2o`0000?ooooo0_l0001Aooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
4oooool2o`0000gooooo0_l0000/ooooo`;o00003?ooool2o`0002kooooo0_l000000ooooooo0000
o`00000Hooooo`;o00003oooool2o`0002Kooooo0_l00003ooooo`;o0000=Oooool2o`0001[ooooo
0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0D?ooool2o`0002gooooo0_l0000kooooo`;o0000
3?ooool2o`0001[ooooo0_l0000hooooo`;o00006_ooool000Kooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo04Kooooo1?l00005ooooo`;o00008Oooool2o`0000_ooooo0_l0000Qooooo`;o
00004oooool2o`0000Gooooo0_l0000:ooooo`;o00006_ooool2o`0003gooooo0_l0000Eooooo`00
1_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co00001_ooool00ol0003oooooooooo`16ooooo`Co00001Oooool2o`00027ooooo0_l0000Loooo
o`Co00003_ooool2o`0001?ooooo0_l00005ooooo`;o0000IOooool2o`0001Gooooo000Yooooo`;o
0000C_ooool2o`0002;ooooo0_l0000Jooooo`;o000000?oooooo`000?l000000_l00009ooooo`;o
00005?ooool2o`0002Wooooo0_l00010ooooo`;o00006_ooool002Wooooo00Co0000ooooool0003o
00002Oooool2o`00047ooooo0_l0000@ooooo`;o00001?ooool2o`0000[ooooo0_l00007ooooo`;o
00004Oooool2o`0000kooooo0_l0000Dooooo`;o00008Oooool2o`0000Kooooo0_l0000kooooo`;o
00000oooool2o`0000Gooooo0_l0000Cooooo`00:Oooool01?l0003oooooo`000?l00002ooooo`;o
00001Oooool2o`0005?ooooo0_l00004ooooo`Co00004Oooool2o`0000;ooooo0_l0000Xooooo`;o
00001oooool3o`0001[ooooo0_l00006ooooo`;o00003oooool2o`00027ooooo0_l0000?ooooo`;o
00002_ooool2o`0001?ooooo000Yooooo`03o`000?oooooooooo00?ooooo0_l0000Eooooo`;o0000
5_ooool2o`0002Sooooo0_l00009ooooo`;o00005Oooool2o`0000_ooooo0_l0000Kooooo`;o0000
1oooool3o`0000Wooooo0_l00007ooooo`;o00001_ooool2o`0000Wooooo0_l0000;ooooo`?o0000
8Oooool2o`00033ooooo000Yooooo`03o`000?oooooooooo01[ooooo0_l00007ooooo`;o000000?o
ooooo`000?l000002_ooool2o`0002Sooooo0_l0000]ooooo`;o00003?ooool4o`0000Wooooo0_l0
000Eooooo`;o00001?ooool2o`000003ooooool0003o000000Gooooo0_l00002ooooo`?o00001Ooo
ool2o`0000_ooooo1?l0000iooooo`;o00005oooool002Wooooo0_l0000Hooooo`;o00002_ooool2
o`000003ooooool0003o000000_ooooo0_l0000Gooooo`;o0000Boooool4o`0000Wooooo0_l0000K
ooooo`;o00002?ooool2o`0000;ooooo0ol0000Dooooo`;o00004oooool2o`0002Cooooo0_l0000G
ooooo`00:Oooool00ol0003oooooooooo`0Gooooo`;o00006_ooool2o`0001Oooooo0_l0000joooo
o`;o0000=oooool2o`0003Cooooo0_l00004ooooo`;o0000:oooool3o`0000oooooo000Yooooo`03
o`000?oooooooooo00;o00002?ooool2o`000003ooooool0003o0000027ooooo1?l000002?l@413o
ooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Wooooo
1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Kooooo0_l0000Dooooo`;o00001Oooool2o`0000?ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo
0_l00004ooooo`Ko00007?ooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo0ol000000olb<S;ok^k^ooooo`0Xooooo`05odA4A?l0003o0000oc8b<_oMgMd00ol0
00001?lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool002Wooooo
00?o0000ooooooooool00ol00002ooooo`;o00000oooool2o`000003ooooool0003o0000017ooooo
0_l0000@ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00_ooool2o`0002Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
0_l0000?ooooo`?o00001?ooool2o`0000?ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo2?l0000K
ooooo`0:o`000?oooooo0000o`000?ooooooMgMgoiRHV?ooooooV9RHogMgM`?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0/ooooo`04ogMgMolb<S;oooooooooo`;o000000?ooooooiRHV?mgMgL00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000Yooooo`04o`000?ooooooooooooooo`;o0000
00Coooooo`000?l0003o00006Oooool2o`00013ooooo0_l00003ooooo`05oa0@4?oooooooooooooo
ool@41000oooool01Ol@413ooooooooooooooooo410@00;ooooo0_l0000Jooooo`;o00002_ooool0
0onHV9So8B4Qonk^kP02ooooo`;o000000Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oo
ooooooooooooool@41000oooool2o`0000Kooooo0_l00005ooooo`;o00002Oooool3o`0000;ooooo
0_l00004ooooo`;o00000_ooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooooooooa0@4003ooooo`03oa0@4?oooooooooo00cooooo0_l0000Aooooo`;o00001Oooool7o`00
0003ooooool@413ooooo00;ooooo00Go410@oooooooooooooooooa0@4002ooooo`;o00006?ooool2
o`0001?ooooo00?o0000ooooooooool00_l00002ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool00ol@413oooooooooo`01ooooo`00:Oooool2o`0000Gooooo0_l0000/ooooo`;o00000oooool3
o`000003ooooool0003ooooo00;ooooo00Go0000ooooooooooooooooo`00000Nooooo`;o00002?oo
ool2o`000005oooooonHV9So8B4Qonk^k_ooool00ol00003ooooo`05o`000?ooooooooooooooool0
00000oooool01?l0003oooooooooooooool2o`0000gooooo0ol00009ooooo`;o00000_ooool2o`00
00Cooooo0_l000000oooooooZJVYoa0@4003ooooo`?o000000?oooooo`000?ooool00_ooool01Ol0
003ooooooooooooooooo0000027ooooo0_l00005ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;o00000_ooool2o`00017ooooo
0_l000000ooooooo0000o`00000Booooo`05ogMgMolb<S;oooooooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool00Oooool002Wooooo00?o0000oooooooo
ool01_ooool2o`0002[ooooo00?o0000ooooooooool00_ooool3o`000003ooooool0003ooooo00;o
oooo00Go0000ooooooooooooooooo`00000Xooooo`;o00000_ooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000001?ooooo0_l0
00000ooooooo0000o`00000Booooo`03oa0@4?l0003o^[Zj00?ooooo0ol000000ooooooo0000o`00
0002ooooo`;o00000_ooool01?l0003oooooooooooooool2o`0001[ooooo0_l00007ooooo`04omgM
gOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000_ooool2o`00017ooooo0_l0000?ooooo`;o000000Koooooo`000?lQ8B7o0000oc8b
<_o<c<`2ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo000Yooooo`03o`000?oooooooooo00Kooooo0_l000000ooooooo0000o`00000Wooooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooo
ooooool@4100;Oooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooo
oa0@4003ooooo`03oa0@4?oooooooooo017ooooo0_l000000ooooooo0000o`00000Cooooo`03okZj
^_l0003o000000;ooooo00Co410@oooooooooooooooo0_l00002ooooo`;o00000_ooool01?l@413o
ooooooooooooool2o`0001[ooooo0_l00008ooooo`03ogMgMoo<c<co000000Cooooo0_l00002oooo
o`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Tooooo`Co00001_ooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`00:Ooo
ool3o`0000Oooooo1?l0000Wooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02_ooool2o`0000Wooooo0_l0000Booooo`05
o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0Cooooo`;o00001Oooool2o`0000?ooooo0_l00007ooooo`04oa0@4?nH
V9SooooookZj^P;o00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0Yooooo`03onk^k_m4A4Co000000Cooooo0_l000000oooooooV9RHogMgM`03oooo
o`05ogMgMonHV9So0000o`000?mgMgL07_ooool2o`0000Oooooo0ol00006ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000Yooooo`?o00001ooo
ool2o`0001Gooooo0_l0000@ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2o`0000?ooooo0_l00009ooooo`;o
00004_ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^o`000?l0003o<S8bonk^kP02
ooooo`;o000000Co<S8bo`000?lb<S;ok^k^1Oooool2o`0001?ooooo0_l00003ooooo`;o00001ooo
ool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02_ooool2o`0001kooooo00?oMgMgo`000?ooool00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o0000onk^kP0Nooooo`;o00002Ooo
ool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool002Wooooo0_l0000Oooooo`;o00002oooool2o`0000Wooooo0_l0000Aooooo`;o0000
:oooool2o`0000Cooooo0_l00009ooooo`;o00007_ooool2o`0001Gooooo0_l00009ooooo`;o0000
2_ooool2o`000003ooooool0003o000002Oooooo0_l0000Oooooo`;o00006?ooool002Wooooo00?o
0000ooooooooool06Oooool2o`00013ooooo0_l00009ooooo`;o00002oooool2o`0000kooooo0_l0
0003ooooo`;o0000COooool2o`0001Gooooo0_l00004ooooo`;o00003oooool2o`000003ooooool0
003o000002Oooooo0_l0000Oooooo`;o00006?ooool002Wooooo00?o0000ooooooooool06Oooool2
o`00023ooooo0_l00006ooooo`;o00003_ooool2o`0000?ooooo0_l0001Zooooo`;o00007?ooool2
o`0001_ooooo0_l0000Pooooo`;o00006Oooool002Wooooo00?o0000ooooooooool0;Oooool2o`00
00;ooooo0_l00008ooooo`;o00001_ooool2o`0007Kooooo0_l0000Uooooo`;o00004Oooool3o`00
00;ooooo0_l00003ooooo`;o00004Oooool2o`0000gooooo0_l0000Iooooo`00:Oooool00ol0003o
ooooooooo`0;ooooo`;o00008?ooool2o`0000;ooooo0_l0000=ooooo`;o000000?oooooo`000?l0
0000Doooool2o`00027ooooo0_l0000>ooooo`;o0000:?ooool3o`0000;ooooo0_l0000<ooooo`;o
00002?ooool2o`0002Sooooo000Qoooooooo0000A?l00004ooooo`00:Oooool01?l0003oooooo`00
0?l00008ooooo`03o`000?oooooooooo00?ooooo0_l00005ooooo`03o`000?oooooooooo00Cooooo
0_l00003ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool2o`0000;ooooo
00?o0000ooooooooool01?ooool2o`0000Cooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`05ooooo`;o00000_ooool00ol0003oooooooooo`08ooooo`;o00000_ooool2o`0000Sooooo
0ol00002ooooo`;o00001Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo
0_l0000;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool2o`0000Cooooo
1?l00008ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool2o`0000?ooooo
00?o0000ooooooooool02_ooool002Wooooo00?o0000ooooooooool07?ooool3o`0000Wooooo0_l0
000;ooooo`;o00000oooool00ol0003oooooooooo`04ooooo`;o00006?ooool2o`0000gooooo0ol0
00000ooooooo0000o`000008ooooo`03o`000?oooooooooo00;ooooo0_l0000=ooooo`;o00003?oo
ool2o`000003ooooool0003o000000[ooooo0_l00002ooooo`Co00001?ooool00ol0003ooooooooo
o`0jooooo`03o`000?oooooooooo01Sooooo0_l0000Pooooo`03o`000?oooooooooo00[ooooo000Y
ooooo`03o`000?oooooooooo01cooooo0_l0000:ooooo`;o00002oooool2o`0000Sooooo0_l0000J
ooooo`;o00002Oooool2o`0000?ooooo0_l0000Looooo`;o000000?oooooo`000?l000003?ooool2
o`000003ooooool0003o000000[ooooo0_l00002ooooo`Co0000>_ooool2o`00027ooooo0_l0000D
ooooo`;o00005_ooool002Wooooo00?o0000ooooooooool0?oooool2o`0001[ooooo0ol00008oooo
o`;o00003Oooool2o`0000[ooooo1?l00004ooooo`;o0000>oooool2o`0000_ooooo0_l0000Eoooo
o`?o000000?oooooo`000?l000002Oooool2o`0000Cooooo0_l00009ooooo`;o00000_ooool2o`00
01Cooooo0ol0000Eooooo`00:Oooool2o`0005_ooooo1?l000000ooooooo0000o`000006ooooo`?o
00002oooool2o`000004ooooool0003o0000o`0000Kooooo1?l00011ooooo`;o00002oooool3o`00
01Cooooo0_l00002ooooo`;o00002Oooool2o`0000Cooooo0_l00009ooooo`;o00000oooool2o`00
00_ooooo0_l00007ooooo`;o00005Oooool002Wooooo00?o0000ooooooooool09oooool2o`0000Ko
oooo0_l0000?ooooo`;o00006?ooool2o`0000?ooooo0_l00006ooooo`?o00003_ooool3o`000003
ooooool0003o0000053ooooo0_l00004ooooo`;o00005Oooool2o`0000Oooooo0_l00006ooooo`;o
00004Oooool2o`0000_ooooo0_l000000ooooooo0000o`00000Kooooo`00:Oooool00ol0003ooooo
ooooo`02ooooo`;o00008oooool4o`0000Cooooo0_l00002ooooo`;o00002oooool2o`0000Oooooo
0_l0000aooooo`?o00009_ooool2o`0002Oooooo0_l0000Kooooo`Co00001Oooool2o`0000;ooooo
0_l00002ooooo`;o00008Oooool2o`0001_ooooo000Yooooo`03o`000?oooooooooo00;ooooo0_l0
000;ooooo`;o00006?ooool2o`0000Sooooo0_l00003ooooo`;o00003oooool2o`0000Kooooo0_l0
000=ooooo`;o00006oooool2o`00013ooooo0_l00006ooooo`;o00003?ooool2o`0004Kooooo0_l0
0009ooooo`;o00002_ooool2o`0000Kooooo0_l0000<ooooo`;o00008?ooool002Wooooo0_l0000@
ooooo`;o00001oooool2o`0000;ooooo0_l00007ooooo`;o00001_ooool2o`0000Wooooo0_l0000G
ooooo`;o000000?oooooo`000?l000002_ooool2o`0000_ooooo0_l0000Pooooo`;o00001_ooool2
o`0001;ooooo1?l0000Uooooo`;o00009_ooool2o`0000Kooooo0_l00006ooooo`;o00003?ooool2
o`00023ooooo000Yooooo`;o00006Oooool2o`0000;ooooo0_l00007ooooo`;o00001_ooool2o`00
00oooooo0_l0000Dooooo`;o00000_ooool2o`0001?ooooo0_l0000looooo`Co00009Oooool2o`00
01?ooooo0_l0000Aooooo`;o00001?ooool2o`0000cooooo0_l0000Iooooo`;o00003oooool002Wo
oooo00?o0000ooooooooool05?ooool2o`0001Sooooo0_l0000:ooooo`;o00000_ooool2o`0001So
oooo0_l0000:ooooo`;o0000@Oooool2o`00017ooooo0_l00007ooooo`;o00009?ooool2o`0001Oo
oooo0ol0000;ooooo`;o00001_ooool2o`00017ooooo0_l0000?ooooo`00:Oooool00ol0003ooooo
ooooo`07ooooo`;o00002oooool2o`0000Cooooo0_l0000>ooooo`;o00000_ooool2o`0000[ooooo
0_l0000Xooooo`;o0000?Oooool2o`0000;ooooo0_l0000Aooooo`;o00001oooool4o`0000Gooooo
0_l0000Pooooo`;o00004oooool2o`0000gooooo1?l00002ooooo`;o00008_ooool002Wooooo00?o
0000ooooooooool01oooool2o`0000Wooooo0_l00006ooooo`;o00001?ooool4o`0000?ooooo0_l0
00000ooooooo0000o`00000Yooooo`;o00001_ooool2o`0002[ooooo0_l0000Hooooo`;o00000ooo
ool2o`0001_ooooo0_l00005ooooo`;o00005Oooool2o`0000Wooooo0_l0000Rooooo`Co00001_oo
ool4o`0001cooooo000Yooooo`03o`000?oooooooooo00Sooooo0_l00008ooooo`;o00003?ooool4
o`0000?ooooo0_l0000Wooooo`;o00000oooool2o`0000Kooooo0_l0000Sooooo`;o00001Oooool2
o`0001gooooo0_l0000iooooo`;o00007oooool2o`0001Kooooo1?l0000=ooooo`;o00003Oooool0
02Wooooo0_l00009ooooo`;o00000oooool2o`00047ooooo0_l00002ooooo`;o0000;?ooool2o`00
0003ooooool0003o000003Cooooo0_l0000Cooooo`;o00003oooool2o`00027ooooo0_l000000ooo
oooo0000o`00000>ooooo`;o00003oooool3o`0000;ooooo0_l0000=ooooo`00:Oooool00ol0003o
ooooooooo`0=ooooo`;o0000=Oooool2o`0000kooooo0_l0000Yooooo`;o00001?ooool2o`0001?o
oooo0_l0000Oooooo`Co00004Oooool2o`0000Wooooo0_l00004ooooo`;o00003Oooool2o`0001Go
oooo0_l0000<ooooo`Co00003oooool3o`00017ooooo000Yooooo`03o`000?oooooooooo00cooooo
0_l0000Nooooo`;o00005_ooool2o`0003Wooooo0_l0000Fooooo`;o000000?oooooo`000?l00000
8Oooool2o`00017ooooo0_l00009ooooo`;o00001?ooool2o`0000gooooo0_l0000Sooooo`;o0000
9Oooool002Wooooo00?o0000ooooooooool03?ooool2o`0001Gooooo0_l00005ooooo`Co0000JOoo
ool2o`00017ooooo0_l0000Iooooo`;o00002Oooool2o`0000_ooooo0_l00017ooooo`;o00005?oo
ool002Wooooo00?o0000ooooooooool05?ooool2o`0000gooooo0_l00005ooooo`;o00001?ooool2
o`0003cooooo0_l0000jooooo`;o00006Oooool2o`0001Kooooo0_l0000@ooooo`;o00009_ooool2
o`0000gooooo0_l0000Dooooo`00:Oooool2o`0001Gooooo0_l0000Booooo`;o00001_ooool2o`00
00_ooooo0_l0000_ooooo`;o00004_ooool4o`0000gooooo0_l000000ooooooo0000o`00000`oooo
o`;o00009Oooool2o`0002Kooooo0_l0000Sooooo`00:Oooool00ol0003oooooooooo`0Fooooo`;o
00004?ooool2o`0001?ooooo0_l0000Rooooo`;o00007oooool4o`0000gooooo0_l000000ooooooo
0000o`00000Hooooo`;o00005_ooool2o`0002Sooooo0_l0000Looooo`;o0000:_ooool000Kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo017ooooo0_l00002ooooo`?o00009_ooool2o`00
00Sooooo0_l0000Gooooo`;o00003?ooool2o`0003oooooo0_l0000>ooooo`;o0000<?ooool2o`00
00[ooooo0_l00002ooooo`;o00003?ooool2o`0002[ooooo0006ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool04Oooool2o`0000;ooooo0_l0000Mooooo`;o00001oooool3
o`0000Sooooo0_l000000ooooooo0000o`00000Nooooo`;o00000_ooool2o`0000Kooooo0_l0000=
ooooo`;o0000=oooool3o`0001Kooooo0_l0000Jooooo`;o00002?ooool2o`0000;ooooo0_l0000K
ooooo`;o00006oooool000Kooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7o
k^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`Co00009?ooool2
o`0000Oooooo0_l0000<ooooo`;o00007_ooool2o`0000Cooooo0_l00004ooooo`;o00003Oooool2
o`0003Oooooo0_l0000Gooooo`;o00006_ooool2o`00013ooooo0_l0000Gooooo`;o00006oooool0
00Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMg
oc8b<_ooool01?ooool3o`0000;ooooo0_l00008ooooo`Co00004Oooool2o`0000_ooooo0_l0000A
ooooo`;o0000;_ooool2o`0001cooooo0_l0000Xooooo`;o0000Boooool2o`00023ooooo0_l0000B
ooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool00_ooool2o`0001gooooo0_l0
000;ooooo`;o00004Oooool2o`00027ooooo0_l0000Jooooo`;o00003Oooool2o`0002Oooooo0ol0
000Yooooo`;o0000;oooool2o`00017ooooo0_l0000Booooo`001_ooool01Ol@413ooooooooooooo
oooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo013ooooo0_l00006ooooo`;o000000?oooooo`000?l000007oooool2o`0000oooooo0_l0
000Eooooo`;o00006_ooool2o`0000kooooo0_l0000>ooooo`;o00005_ooool2o`0002[ooooo0_l0
000;ooooo`;o00008_ooool2o`0001Oooooo0_l0000<ooooo`001_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo
0_l0000Aooooo`;o00001_ooool2o`000003ooooool0003o000001gooooo1?l0000?ooooo`;o0000
5?ooool2o`0000_ooooo0_l00009ooooo`;o00001?ooool2o`0000gooooo0_l0000>ooooo`;o0000
Coooool2o`0001Cooooo1?l0000Booooo`;o00003oooool2o`0000cooooo0006ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o
00002_ooool2o`0000cooooo0_l0000Qooooo`;o00005Oooool2o`00013ooooo0_l0000;ooooo`;o
00002Oooool2o`0000Cooooo0_l00004ooooo`;o00002oooool2o`0002;ooooo0_l0000Yooooo`;o
00000_ooool2o`0001kooooo1?l0000Booooo`;o00007Oooool002Wooooo0_l0000:ooooo`;o0000
3?ooool2o`0003Sooooo0_l0000dooooo`;o00002oooool2o`0002;ooooo0_l0000Yooooo`;o0000
0_ooool2o`0005?ooooo000Yooooo`03o`000?oooooooooo09oooooo0_l0000booooo`;o00001ooo
ool2o`0000kooooo0_l0000Oooooo`;o00003_ooool2o`0001gooooo000Yooooo`03o`000?oooooo
oooo05Kooooo0_l0000>ooooo`;o00002_ooool2o`0001kooooo0_l0000;ooooo`;o00008?ooool2
o`00013ooooo0_l00007ooooo`;o00003_ooool2o`0000Cooooo0_l0000Iooooo`;o00003_ooool2
o`0001gooooo000Yooooo`03o`000?oooooooooo04[ooooo0_l0000:ooooo`;o00002Oooool2o`00
00?ooooo0_l00004ooooo`;o00001?ooool2o`0001kooooo0_l0000]ooooo`;o00005_ooool4o`00
01Gooooo0_l00018ooooo`00:Oooool00ol0003oooooooooo`0Uooooo`;o00008oooool2o`0001Go
oooo0_l00009ooooo`;o0000=?ooool2o`0003Gooooo1?l0000Nooooo`;o00006Oooool2o`0000oo
oooo0_l00004ooooo`;o00003Oooool002Wooooo0_l0000Cooooo`;o00004Oooool2o`0001_ooooo
0_l000000ooooooo0000o`00001Kooooo`?o00002oooool2o`0002Gooooo0_l0000Rooooo`;o0000
6Oooool2o`0000oooooo0_l00004ooooo`;o00003Oooool002Wooooo00?o0000ooooooooool04_oo
ool2o`0002kooooo0_l000000ooooooo0000o`00000Xooooo`;o0000<_ooool2o`0000Wooooo1?l0
0003ooooo`;o00008?ooool2o`0005Kooooo0_l0000;ooooo`00:Oooool00ol0003oooooooooo`0O
ooooo`;o0000;Oooool2o`0001oooooo0_l0000mooooo`;o00001Oooool2o`0002Gooooo0_l0000[
ooooo`;o00009?ooool2o`0000_ooooo000Yooooo`03o`000?oooooooooo01Gooooo0_l00008oooo
o`;o0000:_ooool2o`000003ooooool0003o000000?ooooo0_l00009ooooo`;o0000O?ooool2o`00
0003ooooool0003o000002Sooooo0_l0000aooooo`00:Oooool00ol0003oooooooooo`05ooooo`;o
00003_ooool2o`0002kooooo0_l00004ooooo`;o00001_ooool2o`0000Wooooo0_l0000Fooooo`;o
00004_ooool2o`0005?ooooo0_l0000gooooo`;o00008_ooool002Wooooo0_l00005ooooo`?o0000
?_ooool2o`0002oooooo0_l0000<ooooo`;o00001?ooool2o`0002Wooooo0_l0001Qooooo`;o0000
8_ooool002Wooooo00?o0000ooooooooool01?ooool2o`0003Gooooo0_l00017ooooo`;o0000;ooo
ool2o`0001[ooooo0_l00003ooooo`;o00000_ooool2o`0001_ooooo0_l00013ooooo`00:Oooool0
0ol0003oooooooooo`0Tooooo`;o00005Oooool2o`0002Kooooo0_l00017ooooo`;o00001?ooool2
o`0001Cooooo0_l00007ooooo`;o00000oooool2o`0000;ooooo0_l0000Kooooo`;o00008?ooool2
o`00027ooooo000Yooooo`03o`000?oooooooooo02Cooooo0_l0000`ooooo`;o00002oooool2o`00
00Cooooo0_l00011ooooo`;o00001?ooool2o`0000cooooo0_l00006ooooo`;o0000;?ooool2o`00
027ooooo0_l0000Qooooo`00:Oooool01?l0003oooooooooooooool2o`0000gooooo0_l0000=oooo
o`;o00003oooool2o`00023ooooo0_l00002ooooo`;o00004Oooool2o`00037ooooo0_l0000Roooo
o`;o00007Oooool2o`0001Gooooo0_l00009ooooo`;o00004?ooool2o`0002Oooooo000Yooooo`;o
00000_ooool2o`0000gooooo0_l0000=ooooo`;o00003oooool2o`0000Gooooo1?l0000Gooooo`;o
00008?ooool2o`0002Kooooo0_l00011ooooo`;o00008?ooool2o`00013ooooo0_l0000Wooooo`00
:Oooool00ol0003oooooooooo`0gooooo`Co0000>Oooool2o`000<Kooooo000>ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo01gooooo0_l0000<ooooo`;o0000ooooool@ooooo`003_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool07Oooool2o`0000cooooo0_l00008ooooo`;o0000ooooool6ooooo`003_ooool01Ol@413ooooo
oooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`0003Gooooo0_l0003>ooooo`;o
0000=Oooool000kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0coooool2o`0003Cooooo0_l00004ooooo`;o0000;oooool000kooooo
00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0
003oooooooooo`3?ooooo`;o0000>_ooool2o`0002oooooo000>ooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0??ooooo0_l0000Joooo
o`;o0000:oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0Moooool2o`0007[ooooo0_l0000Jooooo`;o0000:oooool000ko
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`0007Sooooo0_l000000ooo
oooo0000o`00000@ooooo`;o0000[_ooool002Wooooo00?o0000ooooooooool0N_ooool2o`00013o
oooo0_l0002^ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`00
0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`00
0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo
00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooooooo
ool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03
oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgo
oooo0006ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03
o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`000?ooooooooooooooool0
00003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?oo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolmoooo
o`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`007oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0
oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo?Ooo
ool0027ooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`007oooool0
0omEEEGoIVIVo`00003oooooodOooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .37023 Mdot
.02762 .39554 Mdot
.02952 .27659 Mdot
.03143 .34058 Mdot
.03333 .28991 Mdot
.03524 .2522 Mdot
.03714 .28704 Mdot
.03905 .44003 Mdot
.04095 .29477 Mdot
.04286 .34793 Mdot
.04476 .31024 Mdot
.04667 .44972 Mdot
.04857 .24167 Mdot
.05048 .33439 Mdot
.05238 .4466 Mdot
.05429 .26187 Mdot
.05619 .2728 Mdot
.0581 .23706 Mdot
.06 .34858 Mdot
.0619 .42669 Mdot
.06381 .23916 Mdot
.06571 .35993 Mdot
.06762 .34122 Mdot
.06952 .23446 Mdot
.07143 .44174 Mdot
.07333 .36752 Mdot
.07524 .2682 Mdot
.07714 .33674 Mdot
.07905 .42479 Mdot
.08095 .39358 Mdot
.08286 .2355 Mdot
.08476 .30173 Mdot
.08667 .41311 Mdot
.08857 .35156 Mdot
.09048 .38492 Mdot
.09238 .39977 Mdot
.09429 .32111 Mdot
.09619 .28835 Mdot
.0981 .41917 Mdot
.1 .4533 Mdot
.1019 .44034 Mdot
.10381 .37961 Mdot
.10571 .34682 Mdot
.10762 .39041 Mdot
.10952 .34846 Mdot
.11143 .26919 Mdot
.11333 .34476 Mdot
.11524 .24216 Mdot
.11714 .33203 Mdot
.11905 .42411 Mdot
.12095 .23691 Mdot
.12286 .39775 Mdot
.12476 .48321 Mdot
.12667 .37409 Mdot
.12857 .36476 Mdot
.13048 .36092 Mdot
.13238 .44134 Mdot
.13429 .27426 Mdot
.13619 .23861 Mdot
.1381 .33295 Mdot
.14 .28426 Mdot
.1419 .27015 Mdot
.14381 .41784 Mdot
.14571 .29245 Mdot
.14762 .39796 Mdot
.14952 .33738 Mdot
.15143 .34406 Mdot
.15333 .28386 Mdot
.15524 .30055 Mdot
.15714 .23967 Mdot
.15905 .31927 Mdot
.16095 .3172 Mdot
.16286 .34753 Mdot
.16476 .32143 Mdot
.16667 .41791 Mdot
.16857 .31421 Mdot
.17048 .4832 Mdot
.17238 .31976 Mdot
.17429 .40821 Mdot
.17619 .36034 Mdot
.1781 .31175 Mdot
.18 .39631 Mdot
.1819 .33615 Mdot
.18381 .38293 Mdot
.18571 .41523 Mdot
.18762 .25643 Mdot
.18952 .27903 Mdot
.19143 .25731 Mdot
.19333 .25499 Mdot
.19524 .27966 Mdot
.19714 .44035 Mdot
.19905 .39745 Mdot
.20095 .26433 Mdot
.20286 .24977 Mdot
.20476 .2607 Mdot
.20667 .37753 Mdot
.20857 .33843 Mdot
.21048 .23559 Mdot
.21238 .48339 Mdot
.21429 .26488 Mdot
.21619 .38404 Mdot
.2181 .24478 Mdot
.22 .44716 Mdot
.2219 .39752 Mdot
.22381 .2853 Mdot
.22571 .36225 Mdot
.22762 .33429 Mdot
.22952 .35885 Mdot
.23143 .26557 Mdot
.23333 .24018 Mdot
.23524 .34764 Mdot
.23714 .34121 Mdot
.23905 .29319 Mdot
.24095 .41505 Mdot
.24286 .41163 Mdot
.24476 .32878 Mdot
.24667 .30543 Mdot
.24857 .37093 Mdot
.25048 .34445 Mdot
.25238 .34024 Mdot
.25429 .24413 Mdot
.25619 .32026 Mdot
.2581 .2792 Mdot
.26 .4239 Mdot
.2619 .24132 Mdot
.26381 .33682 Mdot
.26571 .41955 Mdot
.26762 .33577 Mdot
.26952 .39985 Mdot
.27143 .29411 Mdot
.27333 .33746 Mdot
.27524 .39515 Mdot
.27714 .45147 Mdot
.27905 .24302 Mdot
.28095 .31696 Mdot
.28286 .4153 Mdot
.28476 .33029 Mdot
.28667 .42508 Mdot
.28857 .34617 Mdot
.29048 .42496 Mdot
.29238 .44859 Mdot
.29429 .22342 Mdot
.29619 .32247 Mdot
.2981 .32714 Mdot
.3 .27482 Mdot
.3019 .42371 Mdot
.30381 .39977 Mdot
.30571 .33779 Mdot
.30762 .3564 Mdot
.30952 .24993 Mdot
.31143 .33979 Mdot
.31333 .24731 Mdot
.31524 .26141 Mdot
.31714 .23489 Mdot
.31905 .30882 Mdot
.32095 .24408 Mdot
.32286 .36039 Mdot
.32476 .41284 Mdot
.32667 .36535 Mdot
.32857 .32397 Mdot
.33048 .35382 Mdot
.33238 .36982 Mdot
.33429 .40693 Mdot
.33619 .44097 Mdot
.3381 .37293 Mdot
.34 .35443 Mdot
.3419 .37405 Mdot
.34381 .39271 Mdot
.34571 .31335 Mdot
.34762 .28918 Mdot
.34952 .35442 Mdot
.35143 .41954 Mdot
.35333 .2676 Mdot
.35524 .26135 Mdot
.35714 .28549 Mdot
.35905 .35826 Mdot
.36095 .41066 Mdot
.36286 .36427 Mdot
.36476 .2415 Mdot
.36667 .32412 Mdot
.36857 .42315 Mdot
.37048 .37632 Mdot
.37238 .45205 Mdot
.37429 .2879 Mdot
.37619 .43643 Mdot
.3781 .26685 Mdot
.38 .27743 Mdot
.3819 .32713 Mdot
.38381 .30367 Mdot
.38571 .44448 Mdot
.38762 .32871 Mdot
.38952 .35551 Mdot
.39143 .42406 Mdot
.39333 .32529 Mdot
.39524 .29915 Mdot
.39714 .42765 Mdot
.39905 .41488 Mdot
.40095 .44999 Mdot
.40286 .25044 Mdot
.40476 .43953 Mdot
.40667 .36785 Mdot
.40857 .29161 Mdot
.41048 .29814 Mdot
.41238 .3218 Mdot
.41429 .30705 Mdot
.41619 .45212 Mdot
.4181 .38719 Mdot
.42 .32471 Mdot
.4219 .24197 Mdot
.42381 .34184 Mdot
.42571 .30418 Mdot
.42762 .29727 Mdot
.42952 .28812 Mdot
.43143 .31314 Mdot
.43333 .31486 Mdot
.43524 .26406 Mdot
.43714 .37769 Mdot
.43905 .29189 Mdot
.44095 .43963 Mdot
.44286 .2738 Mdot
.44476 .30104 Mdot
.44667 .45251 Mdot
.44857 .29958 Mdot
.45048 .23767 Mdot
.45238 .30004 Mdot
.45429 .33427 Mdot
.45619 .25877 Mdot
.4581 .3351 Mdot
.46 .39999 Mdot
.4619 .26622 Mdot
.46381 .44721 Mdot
.46571 .30139 Mdot
.46762 .29045 Mdot
.46952 .30509 Mdot
.47143 .45023 Mdot
.47333 .29368 Mdot
.47524 .26566 Mdot
.47714 .3404 Mdot
.47905 .27421 Mdot
.48095 .40165 Mdot
.48286 .27438 Mdot
.48476 .39234 Mdot
.48667 .27249 Mdot
.48857 .28192 Mdot
.49048 .35529 Mdot
.49238 .31803 Mdot
.49429 .31413 Mdot
.49619 .26893 Mdot
.4981 .3748 Mdot
.5 .24942 Mdot
.5019 .31398 Mdot
.50381 .41668 Mdot
.50571 .42116 Mdot
.50762 .32832 Mdot
.50952 .32769 Mdot
.51143 .3618 Mdot
.51333 .36618 Mdot
.51524 .25672 Mdot
.51714 .34595 Mdot
.51905 .31441 Mdot
.52095 .43417 Mdot
.52286 .22903 Mdot
.52476 .31285 Mdot
.52667 .26614 Mdot
.52857 .35032 Mdot
.53048 .31916 Mdot
.53238 .25397 Mdot
.53429 .34855 Mdot
.53619 .34094 Mdot
.5381 .29241 Mdot
.54 .40992 Mdot
.5419 .37048 Mdot
.54381 .41088 Mdot
.54571 .3554 Mdot
.54762 .34873 Mdot
.54952 .34319 Mdot
.55143 .36244 Mdot
.55333 .30122 Mdot
.55524 .35165 Mdot
.55714 .24558 Mdot
.55905 .30153 Mdot
.56095 .24147 Mdot
.56286 .41958 Mdot
.56476 .27379 Mdot
.56667 .29171 Mdot
.56857 .32648 Mdot
.57048 .44467 Mdot
.57238 .35975 Mdot
.57429 .27776 Mdot
.57619 .34557 Mdot
.5781 .40563 Mdot
.58 .25159 Mdot
.5819 .28733 Mdot
.58381 .32446 Mdot
.58571 .25094 Mdot
.58762 .4427 Mdot
.58952 .2537 Mdot
.59143 .31498 Mdot
.59333 .25699 Mdot
.59524 .33001 Mdot
.59714 .39097 Mdot
.59905 .44512 Mdot
.60095 .29177 Mdot
.60286 .35136 Mdot
.60476 .31059 Mdot
.60667 .39855 Mdot
.60857 .31007 Mdot
.61048 .44377 Mdot
.61238 .33855 Mdot
.61429 .24062 Mdot
.61619 .36952 Mdot
.6181 .26682 Mdot
.62 .29849 Mdot
.6219 .28954 Mdot
.62381 .2552 Mdot
.62571 .35604 Mdot
.62762 .32807 Mdot
.62952 .31885 Mdot
.63143 .36867 Mdot
.63333 .40929 Mdot
.63524 .31248 Mdot
.63714 .45125 Mdot
.63905 .38918 Mdot
.64095 .23158 Mdot
.64286 .31681 Mdot
.64476 .24052 Mdot
.64667 .38459 Mdot
.64857 .41024 Mdot
.65048 .32733 Mdot
.65238 .28521 Mdot
.65429 .30414 Mdot
.65619 .31923 Mdot
.6581 .44932 Mdot
.66 .36974 Mdot
.6619 .26084 Mdot
.66381 .32421 Mdot
.66571 .28337 Mdot
.66762 .32208 Mdot
.66952 .39865 Mdot
.67143 .25907 Mdot
.67333 .35328 Mdot
.67524 .36986 Mdot
.67714 .31842 Mdot
.67905 .48201 Mdot
.68095 .36739 Mdot
.68286 .40033 Mdot
.68476 .2941 Mdot
.68667 .39078 Mdot
.68857 .27926 Mdot
.69048 .424 Mdot
.69238 .38726 Mdot
.69429 .29777 Mdot
.69619 .25796 Mdot
.6981 .2237 Mdot
.7 .44994 Mdot
.7019 .25561 Mdot
.70381 .40635 Mdot
.70571 .35808 Mdot
.70762 .35886 Mdot
.70952 .41865 Mdot
.71143 .27082 Mdot
.71333 .44944 Mdot
.71524 .24394 Mdot
.71714 .36177 Mdot
.71905 .45107 Mdot
.72095 .45038 Mdot
.72286 .43564 Mdot
.72476 .32099 Mdot
.72667 .31375 Mdot
.72857 .44835 Mdot
.73048 .43742 Mdot
.73238 .31754 Mdot
.73429 .26315 Mdot
.73619 .36437 Mdot
.7381 .2402 Mdot
.74 .37971 Mdot
.7419 .24496 Mdot
.74381 .40087 Mdot
.74571 .29125 Mdot
.74762 .39201 Mdot
.74952 .34974 Mdot
.75143 .2726 Mdot
.75333 .34671 Mdot
.75524 .44689 Mdot
.75714 .38473 Mdot
.75905 .31952 Mdot
.76095 .25409 Mdot
.76286 .29418 Mdot
.76476 .41119 Mdot
.76667 .25169 Mdot
.76857 .30894 Mdot
.77048 .45138 Mdot
.77238 .24178 Mdot
.77429 .28311 Mdot
.77619 .33106 Mdot
.7781 .3509 Mdot
.78 .25769 Mdot
.7819 .25352 Mdot
.78381 .32102 Mdot
.78571 .30974 Mdot
.78762 .45143 Mdot
.78952 .32999 Mdot
.79143 .47643 Mdot
.79333 .34769 Mdot
.79524 .35866 Mdot
.79714 .35422 Mdot
.79905 .27234 Mdot
.80095 .44616 Mdot
.80286 .4489 Mdot
.80476 .27122 Mdot
.80667 .28681 Mdot
.80857 .25477 Mdot
.81048 .26478 Mdot
.81238 .3867 Mdot
.81429 .24895 Mdot
.81619 .37455 Mdot
.8181 .32709 Mdot
.82 .26354 Mdot
.8219 .30796 Mdot
.82381 .25655 Mdot
.82571 .34063 Mdot
.82762 .25317 Mdot
.82952 .32958 Mdot
.83143 .33043 Mdot
.83333 .42418 Mdot
.83524 .31056 Mdot
.83714 .38329 Mdot
.83905 .33414 Mdot
.84095 .2599 Mdot
.84286 .36805 Mdot
.84476 .27142 Mdot
.84667 .40614 Mdot
.84857 .40457 Mdot
.85048 .40235 Mdot
.85238 .4464 Mdot
.85429 .39691 Mdot
.85619 .33421 Mdot
.8581 .30749 Mdot
.86 .44866 Mdot
.8619 .30474 Mdot
.86381 .38793 Mdot
.86571 .48249 Mdot
.86762 .29482 Mdot
.86952 .26777 Mdot
.87143 .35605 Mdot
.87333 .34971 Mdot
.87524 .36616 Mdot
.87714 .4224 Mdot
.87905 .28179 Mdot
.88095 .38229 Mdot
.88286 .37984 Mdot
.88476 .26768 Mdot
.88667 .32816 Mdot
.88857 .31707 Mdot
.89048 .43988 Mdot
.89238 .32229 Mdot
.89429 .41293 Mdot
.89619 .40151 Mdot
.8981 .33858 Mdot
.9 .41579 Mdot
.9019 .26309 Mdot
.90381 .31306 Mdot
.90571 .34174 Mdot
.90762 .33617 Mdot
.90952 .45039 Mdot
.91143 .42096 Mdot
.91333 .3411 Mdot
.91524 .25548 Mdot
.91714 .36943 Mdot
.91905 .25173 Mdot
.92095 .42392 Mdot
.92286 .38592 Mdot
.92476 .35259 Mdot
.92667 .26019 Mdot
.92857 .35268 Mdot
.93048 .26349 Mdot
.93238 .32637 Mdot
.93429 .3137 Mdot
.93619 .35957 Mdot
.9381 .35703 Mdot
.94 .3219 Mdot
.9419 .31076 Mdot
.94381 .37591 Mdot
.94571 .3198 Mdot
.94762 .31886 Mdot
.94952 .35818 Mdot
.95143 .34018 Mdot
.95333 .29414 Mdot
.95524 .3332 Mdot
.95714 .32063 Mdot
.95905 .33068 Mdot
.96095 .29697 Mdot
.96286 .41916 Mdot
.96476 .29084 Mdot
.96667 .39716 Mdot
.96857 .23939 Mdot
.97048 .37893 Mdot
.97238 .3119 Mdot
.97429 .42504 Mdot
.97619 .45266 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo05?ooooo0_l00020ooooo`;o0000IOooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`1Cooooo`;o0000P?ooool2o`0006Gooooo0004o`0000;ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`2Mooooo`;o0000WOooool000Kooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0009gooooo0_l0
000Tooooo`;o0000Moooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00Oooooo
0_l00002ooooo`;o00000_ooool2o`0000_ooooo0_l0000Jooooo`;o00008Oooool2o`0006Kooooo
0_l0001gooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo1_l00002ooooo`;o0000
2oooool2o`0000;ooooo0_l00005ooooo`;o00003oooool2o`0000Kooooo0_l0000Iooooo`;o0000
:?ooool2o`0005_ooooo0_l00018ooooo`;o00003_ooool000Kooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Cooooo0_l00003ooooo`;o00003oooool2o`0000Cooooo0_l00005ooooo`;o
00005oooool2o`0000Oooooo0_l00003ooooo`;o00006_ooool2o`00013ooooo0_l00007ooooo`;o
00008_ooool2o`0000oooooo0_l00008ooooo`;o00007?ooool2o`0000Wooooo0_l0000mooooo`;o
00003_ooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool01?ooool2o`0001Cooooo0_l0000Ooooo
o`;o00002Oooool2o`000003ooooool0003o000000?ooooo0_l0000<ooooo`;o00003?ooool2o`00
013ooooo0_l0000Zooooo`?o00003oooool2o`0000Sooooo0_l0000Eooooo`;o00001_ooool2o`00
00Sooooo0_l0001=ooooo`00:Oooool2o`0003cooooo0_l00009ooooo`;o00004Oooool2o`000003
ooooool0003o000003Oooooo0_l0000Aooooo`;o0000<Oooool2o`0000Kooooo0_l0000Eooooo`;o
0000@?ooool002Wooooo00?o0000ooooooooool00_l0000dooooo`;o00008?ooool3o`0001_ooooo
0_l0000Mooooo`;o00006?ooool4o`0003Sooooo0_l0000=ooooo`;o00008?ooool2o`0001kooooo
000Yooooo`03o`000?oooooooooo00;o0000<Oooool2o`000003ooooool0003o0000023ooooo0_l0
000Looooo`;o0000:?ooool2o`0000gooooo1Ol00009ooooo`;o00005oooool2o`00017ooooo1?l0
0003ooooo`;o00001oooool2o`0000Cooooo0_l0000Jooooo`?o00007_ooool002Wooooo00?o0000
ooooooooool0<Oooool4o`0005;ooooo0_l0000Aooooo`;o00001?ooool2o`00013ooooo0ol00008
ooooo`;o00005Oooool4o`00017ooooo0_l00004ooooo`?o00001oooool2o`0000?ooooo0ol0000J
ooooo`;o00007oooool002Wooooo00?o0000ooooooooool01_ooool2o`0002Wooooo0ol00002oooo
o`;o00008_ooool2o`0000_ooooo0_l0000Nooooo`;o00004Oooool2o`0001Oooooo0_l0000Doooo
o`;o00000_ooool2o`0000Gooooo0_l0000Iooooo`;o00003Oooool2o`0000?ooooo0_l0000Joooo
o`;o00006oooool002Wooooo0_l00007ooooo`;o0000;Oooool3o`0000;ooooo0_l0000Nooooo`;o
00002oooool2o`0001Sooooo0_l00016ooooo`;o00000_ooool2o`0001;ooooo0_l0000Fooooo`;o
000000?oooooo`000?l000001Oooool2o`0001;ooooo0_l00006ooooo`?o00006_ooool002Wooooo
00?o0000ooooooooool03Oooool2o`0002Kooooo0_l00003ooooo`;o00000oooool2o`0002Gooooo
0_l00006ooooo`;o00004Oooool2o`0000Kooooo0_l00002ooooo`;o00003oooool2o`0001_ooooo
0_l0000Tooooo`;o00005_ooool2o`000003ooooool0003o000000kooooo0_l00003ooooo`;o0000
1?ooool2o`0000Oooooo0_l0000Jooooo`00:Oooool00ol0003oooooooooo`0=ooooo`;o00002Ooo
ool2o`0000Sooooo0_l0000<ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^
kP?ooooo0ol000000olb<S;ok^k^ooooo`0Qooooo`;o00001Oooool5o`0000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01oooool2o`0000;ooooo0_l0
0005ooooo`;o00002?ooool2o`0000[ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko0000o`000?lb<S;ok^k^01[ooooo0_l0000>oooo
o`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h00oooool3o`000003oc8b
<_o^k^kooooo00Oooooo0_l00006ooooo`;o00000oooool2o`0001;ooooo00GoA4A4o`000?l0003o
<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo000Yooooo`03o`000?oooooooooo00Oooooo0_l0000?ooooo`;o00001_ooool4o`00
00kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0Yooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00KoMgMgoiRHV?ooooooV9RHogMgMoooool2o`0000[ooooo1?l00000
0ooooooo0000o`00000Dooooo`;o000000?oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`;o00002oooool2o`0000;ooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo0ol000000ooooooo
V9RHogMgM`08ooooo`;o00008_ooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wooooo0ol00007ooooo`;o00005ooo
ool2o`00013ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooooooooa0@400Aooooo`;o00005oooool00onHV9So0000o`000004ooooo`05
oa0@4?ooooooooooooooool@41000oooool01_l@413ooooooooooooooooo410@ooooo`;o00002_oo
ool4o`0001Oooooo0_l00002ooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool09Oooool6o`0000?ooooo00Go410@oooooooo
oooooooooa0@4002ooooo`;o00000oooool00ol@413oooooooooo`0[ooooo`04o`000?oooooooooo
oa0@40?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo007ooooo000Y
ooooo`?o0000<_ooool3o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001?ooool2o`0000_ooooo0_l0000Hooooo`;o000000Gok^k^oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Yoooo
o`;o00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
000Cooooo`;o00004oooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000002cooooo00GoMgMgoc8b<_ooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`01ooooo`00:Oooool0
0ol0003oooooooooo`0Vooooo`;o00002_ooool3o`0000;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000001?ooool2o`0002Kooooo00?oMgMgofIVI_ooool0
0_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00000@oooo
o`;o00006?ooool00ol@413o0000o`000003ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000cooooo0_l00005ooooo`;o00004oooool01?oMgMgoEEEEoooo
ool00003ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool04Oooool2o`0001Cooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo000Yooooo`04o`000?oooooo
ooooooooo`;o00007oooool2o`0000;ooooo0_l0000:ooooo`03o`000?oooooooooo00;ooooo00Ko
410@oooooooooooooooooa0@4?ooool2o`000005oa0@4?ooooooooooooooool@41008oooool2o`00
00Sooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool00ol@413oooooooooo`0>ooooo`;o00006Oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Oooooo0_l00003ooooo`;o
00006oooool00omgMgOoc<c<o`000003ooooo`;o00000oooool01Ol@413ooooooooooooooooo410@
00;o000000?ooooooa0@4?ooool04_ooool2o`0001Cooooo00?o0000ooooooooool01?ooool01Ol@
413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`00:Oooool0
0ol0003oooooo`000003o`00017ooooo0_l0000<ooooo`;o00003_ooool00ol0003oooooooooo`02
ooooo`06ogMgMonHV9SooooooiRHV?mgMgOooooo0_l000001OmgMgOoV9RHoooooonHV9SoMgMg023o
oooo0_l000000ooooooo0000o`000004ooooo`;o000000?ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?l0003o0000ogMgM`0Xooooo`06oa0@4?nHV9So
oooookZj^_l0003ooooo0_l000001OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?oMgMgoiRHV?oo
ool00_l00007ooooo`;o00008?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOo0000o`000?nHV9SoMgMg02Wooooo00?o0000ooooooooool01?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Ooo
ool01?l0003oooooo`000?l0000Cooooo`;o00003Oooool2o`0000_ooooo00?oEEEEofIVI_l00000
1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o0000onk^kP0Poooo
o`;o00001oooool3o`000003ob4Q8Oo<c<cooooo00;ooooo00?ok^k^oc8b<_l000000_l00003oooo
o`05onk^k_lb<S;o0000o`000?o^k^h00_l00007ooooo`;o00005Oooool2o`0000Kooooo00KoZJVY
o`000?l0003o410@ojVYZOooool2o`000004onk^k_lb<S;o0000oc8b<P;o00000_ooool00oo^k^ko
<S8bo`000002o`0002Gooooo0_l00003ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:Oooool4o`0000;ooooo0_l00000
1?lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool002Wooooo0_l0
0003ooooo`;o00007oooool2o`0001cooooo0_l00009ooooo`;o0000:_ooool2o`0000Sooooo0_l0
0007ooooo`Co00004oooool2o`0000Oooooo0_l00009ooooo`;o00006Oooool2o`00017ooooo0_l0
0004ooooo`;o00008?ooool2o`0001Wooooo0_l00002ooooo`;o00003oooool002Wooooo00?o0000
ooooooooool00_ooool2o`0004Sooooo0_l0000Vooooo`;o00000oooool2o`0000?ooooo0_l0000=
ooooo`;o0000;Oooool2o`0001?ooooo0_l000000ooooooo0000o`00000Dooooo`;o00008?ooool2
o`0001Wooooo0_l000000ooooooo0000o`00000@ooooo`00:Oooool00ol0003oooooooooo`0@oooo
o`;o00005Oooool2o`0004_ooooo0_l00003ooooo`;o00000oooool2o`0000Cooooo1?l00002oooo
o`;o00006oooool3o`0001;ooooo0_l0000Fooooo`;o0000E?ooool2o`00013ooooo000Yooooo`03
o`000?oooooooooo013ooooo0_l0000Eooooo`;o00006oooool2o`0002[ooooo0_l0000;ooooo`;o
00001Oooool4o`0000;ooooo1?l0000Iooooo`?o00007Oooool2o`00047ooooo0_l0000`ooooo`00
:Oooool00ol0003oooooooooo`14ooooo`;o00005Oooool2o`0001?ooooo0_l00008ooooo`;o0000
00?oooooo`000?l000003Oooool2o`0003Wooooo0_l0000dooooo`;o00002_ooool3o`00033ooooo
000Qoooooooo0000A?l00004ooooo`00:Oooool00ol0003oooooooooo`03ooooo`;o00001?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool2
o`000003ooooool0003o000000[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool2o`0000Gooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`04ooooo`?o00000_ooool00ol0003oooooooooo`09
ooooo`04o`000?ooooooooooooooo`Co00001?ooool3o`0000[ooooo00?o0000ooooooooool01ooo
ool3o`000004ooooool0003o0000o`0000Oooooo0_l0000:ooooo`03o`000?oooooooooo00[ooooo
00Co0000oooooooooooooooo0_l00006ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`;o
00002oooool00ol0003oooooooooo`02o`0000Sooooo00?o0000ooooooooool02Oooool2o`0000So
oooo1?l00008ooooo`?o00003?ooool002Wooooo00?o0000ooooooooool0:?ooool2o`000003oooo
ool0003o000000gooooo00?o0000ooooooooool04_ooool2o`0001?ooooo0_l0000Booooo`03o`00
0?oooooooooo00Cooooo0ol0000Aooooo`Go00001?ooool3o`0001Cooooo0ol0000;ooooo`Co0000
6Oooool4o`00013ooooo00?o0000ooooooooool07Oooool2o`0000?ooooo0_l00008ooooo`;o0000
3?ooool00ol0003oooooooooo`0:ooooo`00:Oooool00ol0003oooooooooo`0Cooooo`;o00004ooo
ool2o`0000;ooooo0_l0000Iooooo`;o00001_ooool2o`0004;ooooo0_l0000:ooooo`;o00007_oo
ool2o`0000;ooooo0_l00003ooooo`;o00001?ooool2o`0000kooooo1?l00007ooooo`;o00001_oo
ool2o`0001oooooo0_l0000Aooooo`;o000000?oooooo`000?l000004_ooool002Wooooo00?o0000
ooooooooool04oooool2o`0001?ooooo1_l0000Iooooo`;o00002oooool2o`0000Sooooo0_l0000;
ooooo`;o00003?ooool2o`0002Cooooo0_l0000Nooooo`;o00001oooool5o`000003ooooool0003o
000000kooooo0_l00009ooooo`;o00001_ooool2o`00027ooooo0_l0000=ooooo`Co000000?ooooo
o`000?l000004_ooool002Wooooo0_l0000[ooooo`;o0000:?ooool2o`0000Sooooo0_l0000;oooo
o`;o00000_ooool2o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l00000;Oooool2o`00
00?ooooo0_l0000Dooooo`;o00000_ooool3o`0002oooooo0_l0000Fooooo`;o00002_ooool2o`00
0003ooooool0003o000001Oooooo000Yooooo`03o`000?oooooooooo04?ooooo0_l0000;ooooo`;o
00000_ooool2o`0001Wooooo1_l00007ooooo`;o00006_ooool2o`00017ooooo0_l00003ooooo`;o
00000_ooool2o`0000Sooooo0_l00006ooooo`;o0000:_ooool2o`0000Sooooo0_l000001?oooooo
0000o`000?l0000@ooooo`;o00003?ooool2o`0001[ooooo000Yooooo`03o`000?oooooooooo01[o
oooo0_l00005ooooo`;o00008?ooool2o`0000_ooooo0_l0000Oooooo`;o00009Oooool2o`0001[o
oooo0_l00008ooooo`;o0000;_ooool2o`0000;ooooo0_l0000;ooooo`?o00004?ooool2o`0001Co
oooo0ol0000Aooooo`00:Oooool00ol0003oooooooooo`05ooooo`;o00001_ooool2o`0000_ooooo
0_l00005ooooo`;o00003?ooool2o`0000gooooo0_l0000;ooooo`;o0000>_ooool3o`0006Cooooo
0_l0000Booooo`;o00001?ooool2o`0000kooooo0_l0000>ooooo`?o00004Oooool002Wooooo00?o
0000ooooooooool01Oooool2o`0000Kooooo0_l0000Fooooo`;o00002?ooool2o`0000Oooooo0_l0
0004ooooo`;o00002Oooool6o`0000Sooooo1?l0000/ooooo`?o0000<?ooool2o`0004Kooooo0_l0
0004ooooo`;o00002oooool2o`000003ooooool0003o000002;ooooo000Yooooo`Co00002Oooool2
o`0001Wooooo0_l0000Aooooo`;o00001oooool2o`0000?ooooo0_l000000ooooooo0000o`000002
ooooo`;o00002?ooool4o`0002;ooooo0_l0000?ooooo`;o00004Oooool2o`0001Oooooo0_l00012
ooooo`;o00005Oooool2o`000003ooooool0003o000000;o00002oooool2o`0001?ooooo000Yoooo
o`04o`000?oooooo0000o`0000Wooooo0_l0000=ooooo`;o00002_ooool2o`0001[ooooo0_l00002
ooooo`?o0000=Oooool2o`0000oooooo0_l0000;ooooo`;o00001?ooool2o`0000;ooooo0_l00007
ooooo`;o0000C_ooool2o`0001Sooooo1?l0000;ooooo`;o00004oooool002Wooooo00?o0000oooo
ooooool00_ooool2o`0000Cooooo0_l0000=ooooo`Co00002_ooool2o`0000;ooooo0_l0000Eoooo
o`;o00000oooool2o`0000[ooooo0_l00018ooooo`;o00000oooool2o`0000?ooooo0_l00007oooo
o`;o0000=oooool2o`0000_ooooo0_l00016ooooo`00:Oooool00ol0003oooooooooo`02ooooo`;o
00001?ooool2o`0000Oooooo0_l00004ooooo`?o00003oooool2o`0001Gooooo0_l0000?ooooo`;o
0000C?ooool3o`0000?ooooo1?l0000=ooooo`;o0000;_ooool3o`0000Kooooo0_l00003ooooo`;o
00005oooool2o`0002gooooo000Yooooo`03o`000?oooooooooo017ooooo0_l0001<ooooo`;o0000
00Coooooo`000?l0003ooooo0_l0000[ooooo`;o00002oooool2o`0000?ooooo0_l000000ooooooo
0000o`00000=ooooo`;o00005Oooool2o`0001Oooooo0_l00007ooooo`;o00001?ooool2o`0001Ko
oooo0_l0000?ooooo`?o00006oooool002Wooooo0_l0001Iooooo`;o00001Oooool2o`000004oooo
ool0003o0000ooooo`;o000000?oooooo`000?l000002?ooool2o`0001kooooo0_l0000@ooooo`;o
00006?ooool2o`0000gooooo0_l00009ooooo`;o00006oooool2o`0001Kooooo0_l0000?ooooo`?o
000000?oooooo`000?l000000_ooool2o`0001Cooooo000Yooooo`03o`000?oooooooooo00[ooooo
0_l0000Cooooo`;o00003?ooool2o`0000oooooo0_l0000Hooooo`;o00000_ooool2o`0000[ooooo
0_l00008ooooo`;o0000>Oooool2o`0000oooooo0_l0000Hooooo`;o00006_ooool2o`0001Oooooo
0_l0000Cooooo`;o00000_ooool2o`0001Cooooo000Yooooo`03o`000?oooooooooo00[ooooo0_l0
000Booooo`?o00003?ooool2o`0000kooooo0ol0000Looooo`;o00002oooool2o`0002kooooo0_l0
000;ooooo`;o00001Oooool2o`0002Wooooo0_l000000ooooooo0000o`000004ooooo`;o00004Ooo
ool2o`0002cooooo0_l0000Hooooo`00:Oooool00ol0003oooooooooo`0<ooooo`;o00004?ooool2
o`0001gooooo0_l0000Oooooo`;o00002Oooool2o`0000cooooo0_l0000Pooooo`?o00002_ooool2
o`0002Sooooo0_l00009ooooo`;o00001?ooool2o`0002_ooooo0_l0000/ooooo`00:Oooool2o`00
00gooooo0_l0000gooooo`;o00005oooool3o`0001Kooooo0_l0000Qooooo`;o00001oooool2o`00
01Kooooo0_l00003ooooo`;o00001oooool2o`0000?ooooo1?l0000booooo`;o00002?ooool2o`00
00cooooo0_l0000Nooooo`00:Oooool2o`0001kooooo0_l0000Vooooo`;o00006?ooool6o`0003ko
oooo0_l0000Fooooo`;o00000oooool2o`0000Oooooo0_l00003ooooo`;o0000=?ooool2o`0001Ko
oooo0_l0000Nooooo`00:Oooool00ol0003oooooooooo`0Mooooo`;o0000@_ooool4o`0000Oooooo
0_l0000Wooooo`;o0000I?ooool2o`0002Oooooo0_l0000Fooooo`001_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Go
oooo00?o0000ooooooooool05_ooool2o`0001oooooo0_l0000cooooo`;o00004oooool2o`0001;o
oooo0_l0001<ooooo`;o00005_ooool2o`0001?ooooo0_l0000Booooo`;o00001oooool2o`0000go
oooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool05_ooool2o`00
01Sooooo0_l00005ooooo`;o0000B?ooool2o`00063ooooo0_l0000Mooooo`;o00003?ooool2o`00
01_ooooo0_l0000=ooooo`001_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q
8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01;ooooo0_l0000Loooo
o`;o00002?ooool2o`0008Wooooo0_l0000Qooooo`;o00006?ooool2o`0000cooooo0_l0000;oooo
o`;o00007Oooool000Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^
00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0001;ooooo0_l0000Vooooo`;o0000?oooool2o`00
04Gooooo0_l000000ooooooo0000o`00000<ooooo`;o00004oooool2o`00013ooooo0_l0000>oooo
o`;o00004Oooool2o`0001gooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omg
MgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0G
ooooo`;o0000B_ooool2o`0001Kooooo0_l0000Cooooo`;o00008oooool2o`0000_ooooo0_l0000=
ooooo`Co00004?ooool2o`0001?ooooo0_l0000>ooooo`;o0000<?ooool000Kooooo00Go410@oooo
oooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool2
o`00013ooooo0_l00006ooooo`;o0000=?ooool2o`0001Cooooo0_l0000[ooooo`;o00008oooool2
o`0001[ooooo0_l0000Booooo`;o0000EOooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`;o00004?oo
ool2o`0000_ooooo0_l00006ooooo`;o00002?ooool2o`0000Gooooo0_l00005ooooo`;o00003ooo
ool2o`0006Wooooo0_l0000Booooo`;o0000>Oooool2o`0002;ooooo0_l0000?ooooo`001_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co0000
1_ooool00ol0003oooooooooo`0Booooo`;o00002?ooool2o`0000Kooooo0_l00008ooooo`;o0000
1Oooool2o`0000Gooooo0_l0000=ooooo`;o00002Oooool2o`00037ooooo0_l00004ooooo`;o0000
9oooool2o`0001;ooooo0_l00002ooooo`;o00004_ooool2o`00027ooooo0_l0000<ooooo`;o0000
5?ooool2o`0000oooooo000Yooooo`;o00004oooool2o`0003Oooooo0_l00009ooooo`;o0000<Ooo
ool2o`0000Cooooo0_l0000oooooo`;o00004_ooool2o`0001oooooo0ol0000=ooooo`;o00009Ooo
ool002Wooooo00?o0000ooooooooool0;Oooool2o`00037ooooo0_l0001<ooooo`;o00009oooool2
o`0002cooooo0ol0000dooooo`00:Oooool00ol0003oooooooooo`0]ooooo`;o0000<Oooool2o`00
00Oooooo0_l0000gooooo`?o00002Oooool2o`00013ooooo0_l00003ooooo`;o00004?ooool2o`00
01;ooooo0_l0000Hooooo`;o0000=Oooool002Wooooo00?o0000ooooooooool04?ooool2o`00037o
oooo0_l0000Hooooo`;o00002_ooool2o`0003Oooooo0ol0000Kooooo`;o00000oooool2o`0002Co
oooo0_l0000Wooooo`;o00009_ooool002Wooooo00?o0000ooooooooool04?ooool2o`0001kooooo
0_l0000@ooooo`?o00002oooool2o`0000_ooooo0_l0000Fooooo`;o00008?ooool2o`0007_ooooo
1?l0000Tooooo`00:Oooool2o`0001Gooooo0_l0000=ooooo`;o00001Oooool2o`0000Cooooo0_l0
000@ooooo`;o00001_ooool2o`0000Cooooo0_l0000Dooooo`;o00003Oooool2o`00023ooooo0_l0
000Aooooo`;o0000;Oooool2o`0003_ooooo0_l0000Booooo`;o00004?ooool002Wooooo00?o0000
ooooooooool05?ooool2o`0000gooooo0_l00005ooooo`;o00007_ooool2o`0000[ooooo0_l0000>
ooooo`;o00000oooool2o`0002[ooooo0_l0000Aooooo`;o0000;Oooool2o`0003Cooooo0_l00009
ooooo`;o00003_ooool2o`00013ooooo000Yooooo`03o`000?oooooooooo00Wooooo0_l00003oooo
o`;o00002oooool2o`0002_ooooo0_l00007ooooo`?o00000_ooool2o`0001?ooooo0_l00005oooo
o`;o00008oooool2o`0003[ooooo0_l0000/ooooo`;o00003?ooool2o`0000Wooooo0_l000000ooo
oooo0000o`00000?ooooo`;o00003?ooool002Wooooo00?o0000ooooooooool02Oooool2o`0000?o
oooo0_l0000;ooooo`;o0000:oooool2o`0000Oooooo0ol0000Nooooo`Co0000GOooool2o`0002co
oooo0_l0000Jooooo`;o00003oooool2o`0000cooooo000Yooooo`03o`000?oooooooooo07Cooooo
0_l00036ooooo`00:Oooool2o`0009gooooo0_l0000oooooo`;o0000GOooool002Wooooo00?o0000
ooooooooool0K_ooool2o`0002cooooo0_l0000oooooo`Co0000Foooool002Wooooo00Co0000oooo
oooooooooooo0_l00009ooooo`;o00001oooool2o`0000Sooooo0_l0000Cooooo`;o0000:oooool2
o`0000_ooooo0_l00007ooooo`;o00002Oooool2o`0005_ooooo0_l0000booooo`;o00009oooool0
02Wooooo00Co0000oooooooooooooooo0_l00009ooooo`;o00001oooool2o`0000Sooooo0_l0000C
ooooo`;o0000:oooool2o`0000kooooo0_l00004ooooo`;o00002Oooool2o`0002Sooooo0_l00004
ooooo`;o000000?oooooo`000?l000000_ooool2o`0005Sooooo0_l0000Wooooo`00:Oooool00ol0
003oooooooooo`05ooooo`;o0000=?ooool2o`0001Kooooo0_l0000Looooo`;o00005oooool2o`00
023ooooo0_l00004ooooo`;o000000?oooooo`000?l000000_ooool2o`0002Cooooo0_l00006oooo
o`;o00003Oooool2o`0000oooooo1?l0000aooooo`00:Oooool2o`0000Gooooo0ol0000dooooo`;o
00004Oooool2o`0000?ooooo0_l0000Qooooo`;o00004_ooool4o`0003?ooooo0_l00005ooooo`;o
00003?ooool2o`0000;ooooo1?l000000ooooooo0000o`000006ooooo`;o00000oooool2o`0000Co
oooo0_l00002ooooo`?o00003_ooool4o`0000kooooo0_l0000Qooooo`00:Oooool00ol0003ooooo
ooooo`04ooooo`;o00003oooool2o`0003Oooooo0_l0000Looooo`;o00002?ooool2o`0000;ooooo
0_l00008ooooo`;o00001_ooool2o`0003?ooooo0_l00005ooooo`;o00003?ooool2o`0000;ooooo
1?l0000>ooooo`;o00001?ooool2o`0000?ooooo0_l0000Pooooo`;o00005?ooool2o`0000_ooooo
000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo01Gooooo0_l0001Eooooo`;o00003?ooool2o`0000So
oooo0_l0002Yooooo`;o00002oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo
00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgo
oooo000>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo0?oooooo?Oooool000kooooo00Go0000ooooooooooooooooo`00000<ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
0?oooooo?Oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0loooool2o`0004Oooooo000>ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0000Kooooo0_l0003dooooo`;o0000Aoooool002Wooooo00?o0000oooooooo
ool0coooool2o`0003[ooooo0_l0000_ooooo`00:Oooool00ol0003oooooooooo`0Mooooo`;o0000
3?ooool2o`0000cooooo0_l0002Dooooo`;o0000>_ooool2o`0002oooooo000Yooooo`03o`000?oo
oooooooo01gooooo0_l0000<ooooo`;o00003?ooool2o`000?oooooo0_ooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`00
0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000
o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@
41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgo
oooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooo
oooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@
00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooo
oooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool0
00Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`007oooool4o`000003oa0@
4?oooooooooo00?ooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool3
o`000?oooooo?Oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`007oooool00omEEEGoIVIVo`00003oooooodOooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .29233 Mdot
.02762 .40241 Mdot
.02952 .30513 Mdot
.03143 .32063 Mdot
.03333 .35019 Mdot
.03524 .33676 Mdot
.03714 .31881 Mdot
.03905 .38219 Mdot
.04095 .22954 Mdot
.04286 .31312 Mdot
.04476 .34942 Mdot
.04667 .41385 Mdot
.04857 .33297 Mdot
.05048 .35105 Mdot
.05238 .41114 Mdot
.05429 .31832 Mdot
.05619 .25488 Mdot
.0581 .32286 Mdot
.06 .29322 Mdot
.0619 .4032 Mdot
.06381 .32672 Mdot
.06571 .40336 Mdot
.06762 .39663 Mdot
.06952 .30619 Mdot
.07143 .44917 Mdot
.07333 .32351 Mdot
.07524 .33051 Mdot
.07714 .27251 Mdot
.07905 .41471 Mdot
.08095 .40192 Mdot
.08286 .30119 Mdot
.08476 .22818 Mdot
.08667 .3307 Mdot
.08857 .27591 Mdot
.09048 .36916 Mdot
.09238 .33087 Mdot
.09429 .40112 Mdot
.09619 .2553 Mdot
.0981 .41905 Mdot
.1 .42957 Mdot
.1019 .45346 Mdot
.10381 .33516 Mdot
.10571 .38627 Mdot
.10762 .3318 Mdot
.10952 .26023 Mdot
.11143 .26184 Mdot
.11333 .3418 Mdot
.11524 .2653 Mdot
.11714 .37269 Mdot
.11905 .40438 Mdot
.12095 .27444 Mdot
.12286 .42877 Mdot
.12476 .46009 Mdot
.12667 .38399 Mdot
.12857 .38849 Mdot
.13048 .25377 Mdot
.13238 .38622 Mdot
.13429 .25367 Mdot
.13619 .34001 Mdot
.1381 .24702 Mdot
.14 .25254 Mdot
.1419 .38243 Mdot
.14381 .41889 Mdot
.14571 .33358 Mdot
.14762 .30643 Mdot
.14952 .23517 Mdot
.15143 .29916 Mdot
.15333 .33481 Mdot
.15524 .2525 Mdot
.15714 .28144 Mdot
.15905 .24606 Mdot
.16095 .27755 Mdot
.16286 .31382 Mdot
.16476 .26247 Mdot
.16667 .41875 Mdot
.16857 .28785 Mdot
.17048 .46023 Mdot
.17238 .25221 Mdot
.17429 .42836 Mdot
.17619 .36805 Mdot
.1781 .23457 Mdot
.18 .39878 Mdot
.1819 .29337 Mdot
.18381 .34627 Mdot
.18571 .33321 Mdot
.18762 .29933 Mdot
.18952 .34475 Mdot
.19143 .32596 Mdot
.19333 .2723 Mdot
.19524 .3327 Mdot
.19714 .44927 Mdot
.19905 .28613 Mdot
.20095 .28302 Mdot
.20286 .29501 Mdot
.20476 .30714 Mdot
.20667 .25931 Mdot
.20857 .34957 Mdot
.21048 .27802 Mdot
.21238 .46746 Mdot
.21429 .2604 Mdot
.21619 .31997 Mdot
.2181 .30758 Mdot
.22 .40736 Mdot
.2219 .3509 Mdot
.22381 .23787 Mdot
.22571 .29449 Mdot
.22762 .25482 Mdot
.22952 .32605 Mdot
.23143 .28078 Mdot
.23333 .28058 Mdot
.23524 .34011 Mdot
.23714 .31877 Mdot
.23905 .22968 Mdot
.24095 .36195 Mdot
.24286 .47626 Mdot
.24476 .30321 Mdot
.24667 .24853 Mdot
.24857 .26385 Mdot
.25048 .23902 Mdot
.25238 .40948 Mdot
.25429 .33669 Mdot
.25619 .41411 Mdot
.2581 .36669 Mdot
.26 .41898 Mdot
.2619 .27787 Mdot
.26381 .33259 Mdot
.26571 .37551 Mdot
.26762 .22636 Mdot
.26952 .36743 Mdot
.27143 .32845 Mdot
.27333 .39593 Mdot
.27524 .34766 Mdot
.27714 .42936 Mdot
.27905 .32182 Mdot
.28095 .37712 Mdot
.28286 .42728 Mdot
.28476 .40672 Mdot
.28667 .39998 Mdot
.28857 .30786 Mdot
.29048 .35381 Mdot
.29238 .41848 Mdot
.29429 .31932 Mdot
.29619 .2679 Mdot
.2981 .26143 Mdot
.3 .25349 Mdot
.3019 .38659 Mdot
.30381 .30642 Mdot
.30571 .4383 Mdot
.30762 .32156 Mdot
.30952 .30884 Mdot
.31143 .42572 Mdot
.31333 .31911 Mdot
.31524 .27598 Mdot
.31714 .2979 Mdot
.31905 .27006 Mdot
.32095 .28507 Mdot
.32286 .41937 Mdot
.32476 .42457 Mdot
.32667 .25774 Mdot
.32857 .40228 Mdot
.33048 .41693 Mdot
.33238 .36302 Mdot
.33429 .42933 Mdot
.33619 .45716 Mdot
.3381 .28281 Mdot
.34 .38626 Mdot
.3419 .30059 Mdot
.34381 .29505 Mdot
.34571 .23419 Mdot
.34762 .25477 Mdot
.34952 .41784 Mdot
.35143 .38 Mdot
.35333 .27864 Mdot
.35524 .27677 Mdot
.35714 .34764 Mdot
.35905 .34063 Mdot
.36095 .32737 Mdot
.36286 .24549 Mdot
.36476 .29465 Mdot
.36667 .28443 Mdot
.36857 .41547 Mdot
.37048 .42585 Mdot
.37238 .44107 Mdot
.37429 .25859 Mdot
.37619 .45499 Mdot
.3781 .28514 Mdot
.38 .23561 Mdot
.3819 .22356 Mdot
.38381 .2277 Mdot
.38571 .45502 Mdot
.38762 .38168 Mdot
.38952 .43287 Mdot
.39143 .38742 Mdot
.39333 .33181 Mdot
.39524 .4011 Mdot
.39714 .35652 Mdot
.39905 .45597 Mdot
.40095 .41815 Mdot
.40286 .31274 Mdot
.40476 .35315 Mdot
.40667 .30281 Mdot
.40857 .26692 Mdot
.41048 .26571 Mdot
.41238 .28779 Mdot
.41429 .35608 Mdot
.41619 .37606 Mdot
.4181 .32799 Mdot
.42 .2774 Mdot
.4219 .31757 Mdot
.42381 .32067 Mdot
.42571 .26248 Mdot
.42762 .34629 Mdot
.42952 .37377 Mdot
.43143 .24987 Mdot
.43333 .23441 Mdot
.43524 .27831 Mdot
.43714 .30793 Mdot
.43905 .25042 Mdot
.44095 .45714 Mdot
.44286 .27466 Mdot
.44476 .23962 Mdot
.44667 .42059 Mdot
.44857 .24864 Mdot
.45048 .33772 Mdot
.45238 .23417 Mdot
.45429 .24192 Mdot
.45619 .3109 Mdot
.4581 .36156 Mdot
.46 .39993 Mdot
.4619 .28042 Mdot
.46381 .41342 Mdot
.46571 .40345 Mdot
.46762 .33804 Mdot
.46952 .27194 Mdot
.47143 .37374 Mdot
.47333 .35863 Mdot
.47524 .32872 Mdot
.47714 .42493 Mdot
.47905 .26292 Mdot
.48095 .36485 Mdot
.48286 .36414 Mdot
.48476 .33968 Mdot
.48667 .38396 Mdot
.48857 .36087 Mdot
.49048 .25803 Mdot
.49238 .24566 Mdot
.49429 .22787 Mdot
.49619 .32092 Mdot
.4981 .42322 Mdot
.5 .32151 Mdot
.5019 .2446 Mdot
.50381 .42124 Mdot
.50571 .45654 Mdot
.50762 .29866 Mdot
.50952 .32889 Mdot
.51143 .41864 Mdot
.51333 .32141 Mdot
.51524 .28578 Mdot
.51714 .3877 Mdot
.51905 .29701 Mdot
.52095 .37111 Mdot
.52286 .29972 Mdot
.52476 .36679 Mdot
.52667 .32918 Mdot
.52857 .25418 Mdot
.53048 .32555 Mdot
.53238 .33051 Mdot
.53429 .26127 Mdot
.53619 .34517 Mdot
.5381 .36549 Mdot
.54 .35332 Mdot
.5419 .34458 Mdot
.54381 .35362 Mdot
.54571 .38865 Mdot
.54762 .31542 Mdot
.54952 .37286 Mdot
.55143 .42038 Mdot
.55333 .25579 Mdot
.55524 .35821 Mdot
.55714 .26084 Mdot
.55905 .34794 Mdot
.56095 .29363 Mdot
.56286 .42233 Mdot
.56476 .32098 Mdot
.56667 .25781 Mdot
.56857 .40335 Mdot
.57048 .39848 Mdot
.57238 .33176 Mdot
.57429 .27797 Mdot
.57619 .35772 Mdot
.5781 .33959 Mdot
.58 .28854 Mdot
.5819 .23766 Mdot
.58381 .22298 Mdot
.58571 .35489 Mdot
.58762 .39644 Mdot
.58952 .35715 Mdot
.59143 .31142 Mdot
.59333 .36127 Mdot
.59524 .4183 Mdot
.59714 .31084 Mdot
.59905 .40519 Mdot
.60095 .40991 Mdot
.60286 .37316 Mdot
.60476 .37561 Mdot
.60667 .35742 Mdot
.60857 .22773 Mdot
.61048 .44946 Mdot
.61238 .34788 Mdot
.61429 .2682 Mdot
.61619 .33349 Mdot
.6181 .29412 Mdot
.62 .37912 Mdot
.6219 .24667 Mdot
.62381 .34954 Mdot
.62571 .43398 Mdot
.62762 .31129 Mdot
.62952 .24124 Mdot
.63143 .30778 Mdot
.63333 .32612 Mdot
.63524 .32896 Mdot
.63714 .44227 Mdot
.63905 .44607 Mdot
.64095 .27175 Mdot
.64286 .34231 Mdot
.64476 .31362 Mdot
.64667 .35284 Mdot
.64857 .42447 Mdot
.65048 .36166 Mdot
.65238 .26923 Mdot
.65429 .31857 Mdot
.65619 .24637 Mdot
.6581 .4074 Mdot
.66 .42088 Mdot
.6619 .30814 Mdot
.66381 .39149 Mdot
.66571 .32564 Mdot
.66762 .28907 Mdot
.66952 .40123 Mdot
.67143 .34421 Mdot
.67333 .38621 Mdot
.67524 .36251 Mdot
.67714 .35898 Mdot
.67905 .44782 Mdot
.68095 .32707 Mdot
.68286 .38902 Mdot
.68476 .33373 Mdot
.68667 .29333 Mdot
.68857 .3378 Mdot
.69048 .39312 Mdot
.69238 .40297 Mdot
.69429 .25923 Mdot
.69619 .27588 Mdot
.6981 .32118 Mdot
.7 .41305 Mdot
.7019 .36033 Mdot
.70381 .34441 Mdot
.70571 .37226 Mdot
.70762 .28608 Mdot
.70952 .37598 Mdot
.71143 .34606 Mdot
.71333 .41163 Mdot
.71524 .25315 Mdot
.71714 .26552 Mdot
.71905 .42647 Mdot
.72095 .44436 Mdot
.72286 .45681 Mdot
.72476 .31289 Mdot
.72667 .3666 Mdot
.72857 .4186 Mdot
.73048 .37763 Mdot
.73238 .31813 Mdot
.73429 .25096 Mdot
.73619 .31902 Mdot
.7381 .30884 Mdot
.74 .31085 Mdot
.7419 .26218 Mdot
.74381 .36216 Mdot
.74571 .38502 Mdot
.74762 .42563 Mdot
.74952 .39935 Mdot
.75143 .37394 Mdot
.75333 .399 Mdot
.75524 .44315 Mdot
.75714 .46415 Mdot
.75905 .39938 Mdot
.76095 .26665 Mdot
.76286 .26884 Mdot
.76476 .45285 Mdot
.76667 .27749 Mdot
.76857 .3165 Mdot
.77048 .44543 Mdot
.77238 .2768 Mdot
.77429 .27033 Mdot
.77619 .27236 Mdot
.7781 .28452 Mdot
.78 .31869 Mdot
.7819 .25156 Mdot
.78381 .23522 Mdot
.78571 .40711 Mdot
.78762 .4434 Mdot
.78952 .25232 Mdot
.79143 .43127 Mdot
.79333 .26942 Mdot
.79524 .33818 Mdot
.79714 .3541 Mdot
.79905 .29201 Mdot
.80095 .39887 Mdot
.80286 .41089 Mdot
.80476 .33287 Mdot
.80667 .26241 Mdot
.80857 .3139 Mdot
.81048 .27649 Mdot
.81238 .44735 Mdot
.81429 .30135 Mdot
.81619 .28492 Mdot
.8181 .27372 Mdot
.82 .27314 Mdot
.8219 .3294 Mdot
.82381 .32587 Mdot
.82571 .26194 Mdot
.82762 .30446 Mdot
.82952 .28762 Mdot
.83143 .42018 Mdot
.83333 .35208 Mdot
.83524 .28724 Mdot
.83714 .37581 Mdot
.83905 .25472 Mdot
.84095 .26054 Mdot
.84286 .33293 Mdot
.84476 .26505 Mdot
.84667 .45227 Mdot
.84857 .2957 Mdot
.85048 .37081 Mdot
.85238 .48723 Mdot
.85429 .34767 Mdot
.85619 .31052 Mdot
.8581 .2284 Mdot
.86 .42233 Mdot
.8619 .34785 Mdot
.86381 .40206 Mdot
.86571 .45116 Mdot
.86762 .26 Mdot
.86952 .28913 Mdot
.87143 .34823 Mdot
.87333 .2534 Mdot
.87524 .36299 Mdot
.87714 .32476 Mdot
.87905 .26832 Mdot
.88095 .37365 Mdot
.88286 .3346 Mdot
.88476 .32026 Mdot
.88667 .30434 Mdot
.88857 .25943 Mdot
.89048 .3821 Mdot
.89238 .32431 Mdot
.89429 .42751 Mdot
.89619 .39494 Mdot
.8981 .25136 Mdot
.9 .36517 Mdot
.9019 .25119 Mdot
.90381 .24507 Mdot
.90571 .2288 Mdot
.90762 .2803 Mdot
.90952 .41089 Mdot
.91143 .4569 Mdot
.91333 .34455 Mdot
.91524 .36005 Mdot
.91714 .33887 Mdot
.91905 .27899 Mdot
.92095 .39185 Mdot
.92286 .32374 Mdot
.92476 .30399 Mdot
.92667 .27252 Mdot
.92857 .27731 Mdot
.93048 .37793 Mdot
.93238 .3801 Mdot
.93429 .28489 Mdot
.93619 .38701 Mdot
.9381 .37031 Mdot
.94 .31164 Mdot
.9419 .34167 Mdot
.94381 .38318 Mdot
.94571 .37861 Mdot
.94762 .2746 Mdot
.94952 .30044 Mdot
.95143 .23674 Mdot
.95333 .35223 Mdot
.95524 .24793 Mdot
.95714 .2566 Mdot
.95905 .26571 Mdot
.96095 .32458 Mdot
.96286 .47969 Mdot
.96476 .32375 Mdot
.96667 .40185 Mdot
.96857 .33993 Mdot
.97048 .29229 Mdot
.97238 .25353 Mdot
.97429 .40707 Mdot
.97619 .43287 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo06oooooo0_l0000oooooo`;o0000R_ooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`1;ooooo`;o00008_ooool3o`0002;ooooo0_l0000Jooooo`;o00001_oo
ool2o`0008;ooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`;o00003?oo
ool2o`0002oooooo0_l00008ooooo`;o00008oooool2o`0002;ooooo0_l0000Rooooo`;o0000Cooo
ool2o`0000gooooo0_l0000Rooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o00000_ooool2o`0000cooooo0_l0
000_ooooo`;o0000@oooool2o`00087ooooo0_l0000=ooooo`;o00008_ooool000Kooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`03o`000?oooooooooo02Gooooo0_l00007ooooo`;o0000=?ooool2o`0000Wooooo
0_l0000?ooooo`;o00001?ooool2o`0006Wooooo0_l0000dooooo`;o00004oooool000Kooooo00Go
410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Uooooo`;o00001oooool2o`0000gooooo0_l00006ooooo`;o0000
7Oooool2o`0000Wooooo0_l0000?ooooo`;o00000_ooool2o`0002[ooooo0_l0000oooooo`;o0000
=?ooool2o`0001?ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zj
oooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0mooooo`;o
00001_ooool2o`0003gooooo0_l000000ooooooo0000o`00000Wooooo`;o00003Oooool2o`0007_o
oooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
00Cooooo1?l00006ooooo`03o`000?oooooooooo02Sooooo0_l0000oooooo`;o00007?ooool2o`00
00[ooooo0_l000000ooooooo0000o`00000Wooooo`;o00001oooool2o`0004gooooo0_l0000Soooo
o`00:Oooool2o`0002;ooooo0_l00005ooooo`;o00006_ooool2o`0002?ooooo0_l0000Jooooo`;o
00003?ooool2o`000003ooooool0003o000002Gooooo0_l00009ooooo`;o0000COooool2o`0000oo
oooo0_l0000Booooo`00:Oooool00ol0003oooooooooo`0Qooooo`?o00000oooool2o`0000?ooooo
0_l0000Fooooo`;o0000>Oooool2o`000004ooooool0003o0000ooooo`;o0000=_ooool2o`0002;o
oooo0_l0000=ooooo`Co00008Oooool4o`0000oooooo0_l0000Booooo`00:Oooool00ol0003ooooo
ooooo`07ooooo`;o00002oooool2o`0000Wooooo1Ol00003ooooo`;o00000oooool2o`00013ooooo
0_l0000Eooooo`;o00003Oooool2o`0001Wooooo0_l000000ooooooo0000o`00000Kooooo`;o0000
1_ooool2o`0003;ooooo0_l00004ooooo`;o00003Oooool4o`0000kooooo0_l00009ooooo`;o0000
1_ooool4o`0001Cooooo0_l0000=ooooo`00:Oooool00ol0003oooooooooo`07ooooo`;o00002ooo
ool2o`0000Wooooo0ol0000Looooo`;o00005Oooool2o`0000Oooooo0_l00004ooooo`;o00001ooo
ool2o`0002?ooooo0_l0000;ooooo`;o00001_ooool2o`0000;ooooo0_l0000^ooooo`;o00009Ooo
ool2o`0000Wooooo0_l0000Iooooo`;o00000oooool2o`0000gooooo000Yooooo`03o`000?oooooo
oooo01Sooooo0_l0000Mooooo`;o000000?oooooo`000?l000006?ooool2o`0000Sooooo0_l0000=
ooooo`;o00008oooool2o`0000cooooo0_l00006ooooo`;o000000?oooooo`000?l000009oooool2
o`0002Sooooo0_l00003ooooo`;o00001oooool2o`0000Cooooo0_l0000Dooooo`;o00004_ooool0
02Wooooo0_l0000Iooooo`;o00004?ooool2o`0000_ooooo0_l000000ooooooo0000o`000009oooo
o`;o00003Oooool2o`0002Oooooo0_l0000@ooooo`;o00003oooool2o`0000Kooooo0_l0000Zoooo
o`;o00003Oooool2o`0001?ooooo0_l00004ooooo`;o00000oooool3o`0000Kooooo0_l00004oooo
o`;o0000:?ooool002Wooooo00?o0000ooooooooool06_ooool2o`0000kooooo0_l0000Iooooo`;o
00003Oooool2o`0002;ooooo0ol00002ooooo`;o00004?ooool2o`0002Wooooo0_l0000Oooooo`;o
00001_ooool2o`0000Cooooo0_l0000=ooooo`;o00002_ooool2o`0000Wooooo0_l0000Hooooo`;o
00004Oooool002Wooooo00?o0000ooooooooool06_ooool2o`0001Cooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^013ooooo0_l0
0005ooooo`;o00004?ooool5o`0000?ooooo00?ok^k^oc8b<_l000000ol00002ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h0:?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`?o000000?o<S8bonk^k_ooool01_ooool2o`0001?ooooo0_l0000<oooo
o`?o00000_ooool2o`000004oc8b<_l0003o<S8bonk^kP;o000000Koooooonk^k_lb<S;o0000oc8b
<_o^k^hCooooo`;o00005?ooool01?m4A4Co0000o`000?lb<S82o`000006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Yooooo`03o`000?oooooo
oooo00gooooo0_l0000=ooooo`;o00005?ooool3o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05oooool2o`00013ooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00[ooooo0_l0000Looooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`;o000000?oooooo`000?l0
00008_ooool2o`0000;ooooo0_l000001?nHV9SooooooiRHV?mgMgL2o`000006oooooomgMgOoV9RH
oooooonHV9SoMgMg0_l0000Qooooo`;o00001?ooool2o`000003oooooomgMgOo<S8b00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wooooo
00?o0000ooooooooool03Oooool2o`0000;ooooo0_l00009ooooo`;o00002_ooool2o`0000Sooooo
0ol00002ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@
01Kooooo0_l0000;ooooo`;o00001Oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?oooooooooo
ooooool@41000_ooool2o`0000?ooooo00Co410@ooooool0003o00001oooool2o`00023ooooo00Go
0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`02ooooo`;o00003oooool2o`00017ooooo2Ol00003ooooo`06oa0@4?oooooooooooooo
ool@413ooooo0_l000000ol@413o0000o`00000Qooooo`;o00001?ooool2o`0000;ooooo00Co0000
oooooooooooo410@0oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0
0Oooool002Wooooo0_l0000Booooo`;o00005Oooool2o`0000Sooooo00?o0000ooooooooool00_oo
ool3o`000003ooooool0003ooooo00;ooooo0ol000000ooooooo0000ooooo`04ooooo`;o00003ooo
ool2o`0000[ooooo0ol00006ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooooooooooo
o`000002ooooo`;o00000oooool4o`0000Cooooo0_l0000Rooooo`;o00000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00000Eooooo`;o00004Oooool00om4
A4CogMgMooooo`06o`0000?ooooo00Ko0000ooooooooooooooooo`000?ooool3o`0001cooooo0_l0
0002ooooo`;o000000?oooooo`000?l000001oooool01OmgMgOo<S8boooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo007ooooo000Yooooo`03o`00
0?oooooooooo02Oooooo0_l00009ooooo`03o`000?oooooooooo00Go000000?oooooo`000?ooool0
0_ooool3o`000003ooooool0003ooooo00Cooooo0_l0000Fooooo`;o00000oooool2o`0000Sooooo
00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooo
oooooooo0_l00006ooooo`;o00008Oooool00ol@413o0000o`000003ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000002Sooooo00CogMgMoeEEEOoooooo0000
1?ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00000Loooo
o`;o00000_ooool2o`0000Oooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo000Yooooo`03o`000?oo
oooooooo02Oooooo0_l00009ooooo`03o`000?oooooooooo00;o000000Go410@oooooooooooooooo
oa0@4003ooooo`05oa0@4?ooooooooooooooool@41006?ooool2o`0000?ooooo0_l00008ooooo`;o
000000Goooooo`000?l0003oooooo`000003ooooo`05oa0@4?ooooooooooooooool@41000oooool0
1Ol@413ooooooooooooooooo410@01Sooooo0_l0000Aooooo`03okZj^_lQ8B7ooooo00;ooooo00Go
410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41006Oooool2o`0000ko
oooo00?oMgMgolc<c?l000001?ooool2o`0000;ooooo00Go410@oooooooooooooooooa0@4003oooo
o`;o00009?ooool2o`0000;ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo
410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`00:Oooool00ol0003oooooooooo`0[
ooooo`;o00001Oooool00ol0003oooooooooo`02o`000005ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01Sooooo0_l0000=ooooo`Go000000?oV9RHoa0@4?ooool0
0_ooool01?mgMgOoV9RHoooooonHV9P2o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Hoooo
o`;o00003_ooool01?l@413oV9RHoooooonj^[X3o`000006oooooomgMgOoV9RHoooooonHV9SoMgMg
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo0_l0000;ooooo`;o00003_ooool00oo^k^ko
A4A4o`000004ooooo`;o000000?ooooooiRHV?mgMgL00oooool01?mgMgOoV9RHoooooonHV9P2o`00
00;ooooo1?l00009ooooo`;o00004oooool2o`0000;ooooo00?o0000ooooooooool01?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool2
o`0000Wooooo0_l0000Qooooo`;o00000oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Wooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c003ooooo`04onk^k_lb<S;o0000oc8b<P;o00000_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^02Sooooo00GoZJVYoa0@4?l0003o410@ojVYZ@02o`000006ooooooo^k^ko<S8bo`000?lb<S;o
k^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo0_l0000Looooo`03ogMgMol0003ooooo
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`;o000000Co<S8bo`000?lb<S;ok^k^0ooo
ool4o`0000Wooooo0_l0000Gooooo`Co00000oooool01Oo^k^ko0000o`000?lb<S;ok^k^00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool2o`0000Wooooo0_l0000Uooooo`;o0000
1Oooool2o`0000Gooooo0_l0000Tooooo`;o00001Oooool2o`0003gooooo0_l0000@ooooo`;o0000
5?ooool2o`0002?ooooo0_l0000=ooooo`;o00009_ooool2o`0000gooooo000Yooooo`03o`000?oo
oooooooo02Gooooo0_l00008ooooo`Co00000oooool2o`0000Gooooo0_l0000Looooo`;o00001_oo
ool2o`0000Gooooo0_l0000/ooooo`;o00000_ooool2o`0000_ooooo0_l0000@ooooo`;o00005?oo
ool2o`0003;ooooo0_l0000eooooo`00:Oooool00ol0003oooooooooo`0?ooooo`;o00005?ooool2
o`0000[ooooo0_l0000Xooooo`;o00001_ooool2o`0003?ooooo0_l00002ooooo`?o0000Foooool2
o`0002[ooooo0_l0000Dooooo`00:Oooool3o`0000oooooo0_l0000booooo`;o00007_ooool2o`00
01;ooooo0_l0000Tooooo`;o0000Foooool2o`0000?ooooo0_l0000Aooooo`;o00002_ooool2o`00
00Kooooo0_l0000Dooooo`00:Oooool3o`0000_ooooo0_l0000Gooooo`;o00004?ooool2o`0000?o
oooo0_l00006ooooo`;o00003?ooool2o`0000?ooooo0_l0000Oooooo`;o00002?ooool2o`0003go
oooo0_l00007ooooo`;o0000=?ooool2o`00017ooooo0_l0000:ooooo`;o00007?ooool0027ooooo
ool00014o`0000Cooooo000Yooooo`03o`000?oooooooooo00;ooooo0_l00005ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`;o00000ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`02ooooo`;o00001Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Sooooo0ol0000;ooooo`03o`000?oooooooooo00;o00001oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool4o`0000Oooooo0_l0
00001?oooooo0000ooooooooool2o`0000Oooooo00?o0000ooooooooool02_ooool01?l0003ooooo
ooooooooool2o`0000;ooooo0ol000000ooooooo0000ooooo`0:ooooo`03o`000?oooooooooo00Co
oooo0_l00003ooooo`03o`000?oooooooooo00Oooooo0_l000000ooooooo0000ooooo`0:ooooo`03
o`000?oooooooooo00Wooooo0_l0000:ooooo`03o`000?oooooooooo00[ooooo000Yooooo`03o`00
0?oooooooooo00;ooooo0_l0000Uooooo`;o00003oooool00ol0003oooooooooo`0iooooo`?o0000
0oooool2o`0002Oooooo0_l0000>ooooo`03o`000?oooooooooo00cooooo0_l0000Hooooo`Co0000
2_ooool2o`0000Cooooo00?o0000ooooooooool01?ooool2o`0003Cooooo00?o0000ooooooooool0
2_ooool002Wooooo00?o0000ooooool000000ol00003ooooo`;o0000<_ooool2o`0000Gooooo0_l0
000@ooooo`;o00001?ooool2o`00027ooooo0ol0000Eooooo`;o00003oooool2o`0000?ooooo0_l0
000Kooooo`;o00003?ooool2o`0000Wooooo0ol00009ooooo`;o000000?oooooo`000?l000008?oo
ool2o`0002Wooooo000Yooooo`03o`000?oooooo000000?o00000oooool3o`0000?ooooo0_l0000/
ooooo`;o00001Oooool2o`0000_ooooo0_l00003ooooo`;o00000oooool3o`0002;ooooo0_l0000E
ooooo`?o00000oooool2o`0000kooooo0_l0000Kooooo`;o00003?ooool2o`0000[ooooo0_l0000<
ooooo`;o00008?ooool2o`000003ooooool0003o000000Oooooo0_l0000<ooooo`;o00003oooool0
02Wooooo0_l00008ooooo`Co000000?oooooo`000?l000009?ooool2o`0000[ooooo0_l0000>oooo
o`;o00002?ooool2o`0000oooooo0_l0000Zooooo`;o00000oooool2o`0000?ooooo0_l0000Ooooo
o`;o00002Oooool2o`0000?ooooo0_l0000/ooooo`;o00003oooool2o`0000?ooooo0_l00007oooo
o`;o00002oooool3o`0000oooooo000Yooooo`03o`000?oooooooooo00Wooooo0_l00002ooooo`;o
00008oooool2o`0000[ooooo0_l0000<ooooo`;o00006oooool2o`00013ooooo0_l0000@ooooo`;o
00002Oooool2o`0000Cooooo1?l0000Nooooo`?o00002?ooool2o`0000?ooooo0_l0000[ooooo`?o
00003oooool2o`0001Wooooo0_l0000@ooooo`00:Oooool00ol0003oooooooooo`04ooooo`;o0000
1oooool2o`000003ooooool0003o000000;o00000oooool2o`0000[ooooo0_l0000;ooooo`;o0000
00?oooooo`000?l000005?ooool2o`000003ooooool0003o000002Gooooo0_l00006ooooo`;o0000
4?ooool2o`0000Wooooo0_l00004ooooo`Co00002oooool2o`0000cooooo0_l00004ooooo`;o0000
=?ooool2o`0000Cooooo0_l00005ooooo`;o0000=_ooool002Wooooo00?o0000ooooooooool00_l0
0002ooooo`;o00002_ooool4o`0000;ooooo0ol0000:ooooo`;o000000?oooooo`000?l000002?oo
ool2o`000003ooooool0003o0000017ooooo0_l000000ooooooo0000o`00000Xooooo`;o0000>?oo
ool2o`0000cooooo0_l0000Dooooo`;o00009?ooool2o`0000_ooooo0_l0000:ooooo`;o0000:_oo
ool002Wooooo00?o0000ooooooooool00_l0000Dooooo`;o00003_ooool2o`0001kooooo0_l0000m
ooooo`;o00001?ooool2o`0000?ooooo0_l0000Looooo`;o00008Oooool3o`00023ooooo0_l0000J
ooooo`;o00002_ooool2o`0001kooooo000Yooooo`;o00006_ooool2o`0000Gooooo0_l0000Noooo
o`;o00009_ooool2o`0001_ooooo0_l00004ooooo`;o00000oooool2o`0001cooooo0_l0000Coooo
o`;o00003Oooool2o`00023ooooo0_l0000Vooooo`;o00001Oooool2o`0000Oooooo0_l0000>oooo
o`00:Oooool00ol0003oooooooooo`0Iooooo`;o00001Oooool2o`00013ooooo0_l0000<ooooo`;o
00009_ooool2o`0003Oooooo1?l0000Nooooo`;o00002?ooool2o`0000Sooooo1?l0000oooooo`;o
00001oooool2o`0000Oooooo0_l0000>ooooo`00:Oooool00ol0003oooooooooo`0`ooooo`Co0000
6Oooool2o`0001Sooooo0_l0000Eooooo`;o00008Oooool4o`0000?ooooo0_l0000@ooooo`;o0000
4Oooool2o`0000Sooooo1?l0000/ooooo`;o000000Coooooo`000?l0003ooooo0_l0000;ooooo`;o
00008?ooool002Wooooo00Co0000ooooool0003o00000_ooool4o`0002Wooooo0_l00006ooooo`;o
00000_ooool2o`0000oooooo0_l0000Hooooo`;o00005Oooool2o`0002Sooooo0_l0000@ooooo`;o
000000?oooooo`000?l00000@_ooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`00
01Sooooo0_l0000Cooooo`00:Oooool01?l0003oooooo`000?l00002ooooo`Co0000<Oooool2o`00
00;ooooo0_l0000Dooooo`;o00008oooool2o`0002Wooooo0ol0000<ooooo`;o00002_ooool2o`00
00Kooooo0_l0000^ooooo`;o00002_ooool2o`0002Cooooo0_l0000Cooooo`00:Oooool2o`0005?o
oooo0_l0000Pooooo`;o000000Coooooo`000?l0003ooooo0_l0000Vooooo`?o00000_ooool2o`00
00Gooooo0_l000001?oooooo0000o`000?l00004ooooo`;o00002oooool2o`0002kooooo0_l00015
ooooo`00:Oooool00ol0003oooooooooo`1dooooo`;o00001?ooool2o`0000cooooo0_l00003oooo
o`;o00000oooool2o`0001?ooooo0_l00005ooooo`;o00000_ooool3o`0000?ooooo0_l0000<oooo
o`;o00001_ooool2o`0000Kooooo0_l00013ooooo`;o00007oooool002Wooooo00?o0000oooooooo
ool0@_ooool2o`0001_ooooo0_l0000Wooooo`;o00000oooool2o`000003ooooool0003o000000;o
00007oooool2o`00017ooooo0_l00006ooooo`;o00001_ooool2o`0000cooooo0_l0000Xooooo`;o
00002oooool2o`0001oooooo000Yooooo`03o`000?oooooooooo04;ooooo0_l00004ooooo`;o0000
00?oooooo`000?l000004_ooool2o`0002kooooo0ol0000;ooooo`;o00000oooool2o`0002[ooooo
0_l0000>ooooo`;o00001?ooool2o`0002Sooooo0_l00006ooooo`;o00009?ooool002Wooooo00?o
0000ooooooooool04_ooool2o`0001Wooooo0_l0000Iooooo`;o000000?oooooo`000?l00000@_oo
ool2o`0000cooooo0_l00003ooooo`;o0000>_ooool2o`0002Kooooo0_l0000>ooooo`;o00002_oo
ool2o`0001Sooooo000Yooooo`;o00004oooool2o`0000Kooooo0_l0000Aooooo`;o0000D?ooool2
o`0000_ooooo0_l0000>ooooo`;o00001oooool2o`0000oooooo0_l0000Pooooo`;o00003?ooool2
o`0001kooooo0_l00008ooooo`;o00004?ooool2o`0001Sooooo000Yooooo`03o`000?oooooooooo
01[ooooo0_l0000^ooooo`;o00000oooool2o`0002Wooooo0_l00003ooooo`;o00002oooool2o`00
00kooooo0_l00007ooooo`;o00003oooool3o`0001oooooo0ol0000;ooooo`;o00006_ooool2o`00
00cooooo0_l0000Zooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0B_ooool2
o`0000?ooooo0_l0000Eooooo`;o00004_ooool2o`0003_ooooo0_l00003ooooo`;o00006oooool2
o`0000Cooooo0_l0000Qooooo`;o00007?ooool2o`0000?ooooo0_l0000Eooooo`001_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01ooo
ool00omgMgOo<S8booooo`04ooooo`04o`000?ooooooooooooooo`;o00007oooool2o`0004;ooooo
0_l00009ooooo`;o0000BOooool2o`00027ooooo0_l0000booooo`;o00002oooool2o`0000;ooooo
0ol0000Eooooo`001_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0
2Oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00005?ooool2o`0000Co
oooo1?l000000ooooooo0000o`00000nooooo`;o00003Oooool2o`0001kooooo0_l0000jooooo`;o
00005Oooool2o`0002gooooo0_l0000?ooooo`;o00005_ooool000Kooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0001Oo
oooo0_l00004ooooo`Co0000=Oooool2o`0000[ooooo0_l0000>ooooo`;o00007Oooool2o`0000So
oooo0_l00007ooooo`;o00009oooool2o`000003ooooool0003o000001;ooooo0_l0000looooo`;o
00006?ooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo01kooooo0_l0000foooo
o`;o00006_ooool2o`0002Oooooo0_l00007ooooo`;o00009?ooool2o`0000Cooooo0_l0001;oooo
o`;o00000oooool2o`0001Sooooo0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0b_ooool2o`00
00Oooooo0_l00010ooooo`;o00001_ooool2o`0001gooooo0006ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0:ooooo`;o00008_ooool2o`0001gooooo0_l0001Mooooo`;o00001?ooool2
o`0001oooooo0_l0000Booooo`;o00003Oooool2o`0001gooooo0_l0000Uooooo`001_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_oo
ool00ol0003oooooooooo`0:ooooo`;o00000oooool2o`0000;ooooo0_l0000Iooooo`;o00007Ooo
ool2o`0000;ooooo0_l0000Qooooo`;o00004oooool2o`00027ooooo0_l00004ooooo`;o00006?oo
ool2o`0001Sooooo1Ol0000;ooooo`;o00004_ooool2o`0001oooooo0_l0000?ooooo`00:Oooool2
o`0000[ooooo0ol00003ooooo`;o00000_ooool2o`0000Kooooo0_l0000dooooo`;o00002oooool2
o`0001Cooooo0_l0000Cooooo`?o00007oooool2o`0000Sooooo0_l0000Eooooo`;o00001Oooool2
o`00017ooooo0_l000000ooooooo0000o`00000Oooooo`;o00007oooool2o`0000oooooo000Yoooo
o`;o00002_ooool3o`0000oooooo0_l0000Nooooo`;o00004oooool2o`0000cooooo0_l0000Zoooo
o`;o00007oooool2o`0000Sooooo0_l0000Aooooo`;o00002Oooool2o`0001cooooo0_l0000koooo
o`;o00003?ooool002Wooooo00?o0000ooooooooool01Oooool2o`0003Cooooo0_l00009ooooo`;o
00002?ooool2o`0006Cooooo0_l0000@ooooo`;o00009oooool2o`0000Cooooo0_l0000Pooooo`;o
00004oooool2o`0000cooooo000Yooooo`03o`000?oooooooooo00Cooooo0ol0000oooooo`?o0000
@Oooool2o`0002[ooooo0_l0000Nooooo`;o00000_ooool2o`0001_ooooo0_l0000Pooooo`;o0000
8Oooool002Wooooo00?o0000ooooooooool01?ooool2o`0000Sooooo0_l0000gooooo`;o00005_oo
ool2o`0000[ooooo0_l0000Mooooo`;o0000B_ooool2o`0000;ooooo0_l0001Pooooo`00:Oooool2
o`0000oooooo0_l00004ooooo`;o00003Oooool2o`0000Gooooo0_l0000Looooo`;o00002Oooool2
o`0000Oooooo0_l000000ooooooo0000o`000004ooooo`;o00001?ooool2o`0000Wooooo0_l0000<
ooooo`;o00004oooool2o`0000_ooooo0_l0000<ooooo`;o0000:Oooool2o`0001oooooo0_l0000j
ooooo`00:Oooool00ol0003oooooooooo`0Dooooo`;o00003Oooool2o`0000Gooooo0_l0000Loooo
o`;o00002Oooool2o`0000Oooooo0_l00007ooooo`;o00003oooool2o`0000cooooo0_l0000?oooo
o`Ko00002oooool2o`0000;ooooo0_l00008ooooo`;o00004oooool2o`0001Cooooo0_l0000Ooooo
o`;o00001oooool2o`00037ooooo000Yooooo`03o`000?oooooooooo05Wooooo0_l00002ooooo`;o
00003Oooool2o`00023ooooo0_l00005ooooo`Co00004Oooool2o`0001Wooooo0_l00002ooooo`;o
00004Oooool2o`0000Oooooo0_l0000Rooooo`;o0000<Oooool002Wooooo00?o0000ooooooooool0
5Oooool2o`0000Gooooo0_l0000?ooooo`;o00007oooool4o`0000Oooooo0_l00002ooooo`;o0000
00?oooooo`000?l000002_ooool2o`00023ooooo0_l0000eooooo`;o00005Oooool2o`0000Oooooo
0_l0000]ooooo`;o00009_ooool002Wooooo00?o0000ooooooooool05Oooool2o`0000Gooooo0_l0
000?ooooo`;o00007oooool4o`0000kooooo0_l0000@ooooo`;o0000Ooooool2o`0001oooooo0_l0
000Iooooo`;o00002oooool002Wooooo0_l0001cooooo`;o0000B_ooool2o`0003?ooooo0_l0000j
ooooo`;o00002oooool002Wooooo00?o0000ooooooooool0Eoooool2o`0006Gooooo0_l0001loooo
o`00:Oooool00ol0003oooooooooo`1Gooooo`;o00004oooool2o`0005?ooooo0_l0001iooooo`00
:Oooool00ol0003oooooooooo`1/ooooo`;o0000Doooool2o`0001Wooooo0_l00009ooooo`;o0000
0oooool2o`0000Cooooo0_l00018ooooo`00:Oooool00ol0003oooooooooo`32ooooo`;o00002ooo
ool2o`0000_ooooo0_l00009ooooo`;o00000oooool2o`0000Cooooo0_l00006ooooo`;o0000@?oo
ool002Wooooo0_l0000=ooooo`;o00009_ooool2o`0008?ooooo0_l00007ooooo`;o00002oooool2
o`0002Wooooo0_l0000?ooooo`;o0000;oooool002Wooooo00?o0000ooooooooool03?ooool2o`00
00Oooooo0_l0000Mooooo`;o0000>?ooool2o`0004Wooooo0_l0000`ooooo`;o00006?ooool2o`00
00Cooooo0_l0000_ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Eooooo`;o0000B_ooool2
o`0000_ooooo0_l000000ooooooo0000o`000002ooooo`;o00002oooool2o`0001?ooooo0_l00014
ooooo`;o00003?ooool2o`0001Sooooo0_l0000Cooooo`;o00008?ooool000kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo01gooooo0_l0000<ooooo`;o0000=?ooool2o`0000kooooo0_l00002ooooo`;o00002oooool2
o`0001?ooooo0_l00014ooooo`;o0000>oooool2o`00023ooooo000>ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`03ooooo`?o00007Oooool2o`0000cooooo0_l0002k
ooooo`;o0000D_ooool000kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0j?ooool2o`0005;ooooo000>ooooo`05o`000?oooooooooo
ooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0>Ooo
ool2o`000?oooooo0_ooool000kooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0>Oooool2o`000?oooooo0_ooool000kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0@ooo
ool2o`000?Oooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0
0014ooooo`;o0000iOooool2o`00013ooooo000Yooooo`03o`000?oooooooooo0?oooooo:oooool2
o`00013ooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0ooooool8ooooo`;o0000<oooool002Wooooo00?o0000ooooooooool0ooooool8ooooo`;o0000
<oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVY
oeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolmooooo`001_ooool01Ol0
003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00000>
ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oo
oooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmg
MgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool001oooooo1?l000000ol@413oooooooooo`03oooo
o`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo0ol0003oooooocgooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool001oooooo00?oEEEEofIVI_l00000oooooom7ooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .24017 Mdot
.02762 .35984 Mdot
.02952 .30788 Mdot
.03143 .26579 Mdot
.03333 .36165 Mdot
.03524 .38633 Mdot
.03714 .30446 Mdot
.03905 .27621 Mdot
.04095 .32013 Mdot
.04286 .25709 Mdot
.04476 .33915 Mdot
.04667 .32853 Mdot
.04857 .39769 Mdot
.05048 .31826 Mdot
.05238 .32624 Mdot
.05429 .34449 Mdot
.05619 .33231 Mdot
.0581 .39325 Mdot
.06 .25266 Mdot
.0619 .33027 Mdot
.06381 .3939 Mdot
.06571 .39734 Mdot
.06762 .40259 Mdot
.06952 .3849 Mdot
.07143 .40715 Mdot
.07333 .25216 Mdot
.07524 .35183 Mdot
.07714 .26326 Mdot
.07905 .35519 Mdot
.08095 .36082 Mdot
.08286 .38078 Mdot
.08476 .31369 Mdot
.08667 .23084 Mdot
.08857 .25226 Mdot
.09048 .30397 Mdot
.09238 .23875 Mdot
.09429 .43169 Mdot
.09619 .31537 Mdot
.0981 .36949 Mdot
.1 .3564 Mdot
.1019 .41714 Mdot
.10381 .25491 Mdot
.10571 .37627 Mdot
.10762 .24507 Mdot
.10952 .25804 Mdot
.11143 .33351 Mdot
.11333 .29016 Mdot
.11524 .36965 Mdot
.11714 .3639 Mdot
.11905 .3352 Mdot
.12095 .3761 Mdot
.12286 .41034 Mdot
.12476 .38752 Mdot
.12667 .34446 Mdot
.12857 .36279 Mdot
.13048 .25067 Mdot
.13238 .28235 Mdot
.13429 .33117 Mdot
.13619 .41281 Mdot
.1381 .2753 Mdot
.14 .32079 Mdot
.1419 .44728 Mdot
.14381 .3705 Mdot
.14571 .326 Mdot
.14762 .22739 Mdot
.14952 .27608 Mdot
.15143 .25558 Mdot
.15333 .33843 Mdot
.15524 .30435 Mdot
.15714 .37085 Mdot
.15905 .28851 Mdot
.16095 .27721 Mdot
.16286 .25763 Mdot
.16476 .27949 Mdot
.16667 .37014 Mdot
.16857 .27584 Mdot
.17048 .38782 Mdot
.17238 .2854 Mdot
.17429 .39907 Mdot
.17619 .32631 Mdot
.1781 .30091 Mdot
.18 .35182 Mdot
.1819 .25999 Mdot
.18381 .26594 Mdot
.18571 .23144 Mdot
.18762 .34258 Mdot
.18952 .36344 Mdot
.19143 .362 Mdot
.19333 .3485 Mdot
.19524 .33975 Mdot
.19714 .40875 Mdot
.19905 .22423 Mdot
.20095 .33155 Mdot
.20286 .35372 Mdot
.20476 .33735 Mdot
.20667 .23799 Mdot
.20857 .31126 Mdot
.21048 .3779 Mdot
.21238 .40209 Mdot
.21429 .33947 Mdot
.21619 .24056 Mdot
.2181 .36673 Mdot
.22 .31812 Mdot
.2219 .26138 Mdot
.22381 .32621 Mdot
.22571 .24487 Mdot
.22762 .27112 Mdot
.22952 .2593 Mdot
.23143 .33053 Mdot
.23333 .37007 Mdot
.23524 .28473 Mdot
.23714 .26405 Mdot
.23905 .32167 Mdot
.24095 .26384 Mdot
.24286 .49144 Mdot
.24476 .26462 Mdot
.24667 .30119 Mdot
.24857 .24156 Mdot
.25048 .26838 Mdot
.25238 .42928 Mdot
.25429 .399 Mdot
.25619 .45851 Mdot
.2581 .4061 Mdot
.26 .36462 Mdot
.2619 .36849 Mdot
.26381 .28177 Mdot
.26571 .28283 Mdot
.26762 .28114 Mdot
.26952 .28621 Mdot
.27143 .31402 Mdot
.27333 .40496 Mdot
.27524 .25879 Mdot
.27714 .35781 Mdot
.27905 .38157 Mdot
.28095 .38783 Mdot
.28286 .38981 Mdot
.28476 .4337 Mdot
.28667 .32543 Mdot
.28857 .25609 Mdot
.29048 .24536 Mdot
.29238 .33892 Mdot
.29429 .41433 Mdot
.29619 .27634 Mdot
.2981 .27477 Mdot
.3 .33061 Mdot
.3019 .30006 Mdot
.30381 .2264 Mdot
.30571 .48936 Mdot
.30762 .25722 Mdot
.30952 .35803 Mdot
.31143 .4622 Mdot
.31333 .3711 Mdot
.31524 .33805 Mdot
.31714 .38078 Mdot
.31905 .28849 Mdot
.32095 .36325 Mdot
.32286 .4289 Mdot
.32476 .38685 Mdot
.32667 .24655 Mdot
.32857 .43115 Mdot
.33048 .4306 Mdot
.33238 .30678 Mdot
.33429 .40229 Mdot
.33619 .42392 Mdot
.3381 .23839 Mdot
.34 .36865 Mdot
.3419 .23909 Mdot
.34381 .22782 Mdot
.34571 .29948 Mdot
.34762 .31476 Mdot
.34952 .4318 Mdot
.35143 .29128 Mdot
.35333 .32854 Mdot
.35524 .33787 Mdot
.35714 .36151 Mdot
.35905 .27685 Mdot
.36095 .23 Mdot
.36286 .25048 Mdot
.36476 .36823 Mdot
.36667 .26925 Mdot
.36857 .35835 Mdot
.37048 .42594 Mdot
.37238 .38065 Mdot
.37429 .31439 Mdot
.37619 .42411 Mdot
.3781 .32723 Mdot
.38 .33568 Mdot
.3819 .29051 Mdot
.38381 .31196 Mdot
.38571 .41612 Mdot
.38762 .38521 Mdot
.38952 .46079 Mdot
.39143 .30136 Mdot
.39333 .29001 Mdot
.39524 .45363 Mdot
.39714 .2468 Mdot
.39905 .44762 Mdot
.40095 .33686 Mdot
.40286 .35975 Mdot
.40476 .23472 Mdot
.40667 .24295 Mdot
.40857 .30705 Mdot
.41048 .30104 Mdot
.41238 .27005 Mdot
.41429 .35568 Mdot
.41619 .25565 Mdot
.4181 .24397 Mdot
.42 .27094 Mdot
.4219 .37921 Mdot
.42381 .26508 Mdot
.42571 .2964 Mdot
.42762 .34605 Mdot
.42952 .41043 Mdot
.43143 .2929 Mdot
.43333 .29788 Mdot
.43524 .33352 Mdot
.43714 .2389 Mdot
.43905 .31393 Mdot
.44095 .42521 Mdot
.44286 .3224 Mdot
.44476 .30944 Mdot
.44667 .33922 Mdot
.44857 .30699 Mdot
.45048 .41097 Mdot
.45238 .3128 Mdot
.45429 .27616 Mdot
.45619 .34317 Mdot
.4581 .33857 Mdot
.46 .35044 Mdot
.4619 .32976 Mdot
.46381 .33019 Mdot
.46571 .45609 Mdot
.46762 .33702 Mdot
.46952 .2914 Mdot
.47143 .25363 Mdot
.47333 .37441 Mdot
.47524 .35273 Mdot
.47714 .46001 Mdot
.47905 .32711 Mdot
.48095 .27994 Mdot
.48286 .4066 Mdot
.48476 .25133 Mdot
.48667 .44766 Mdot
.48857 .39158 Mdot
.49048 .25362 Mdot
.49238 .28989 Mdot
.49429 .30144 Mdot
.49619 .33574 Mdot
.4981 .4222 Mdot
.5 .36994 Mdot
.5019 .29435 Mdot
.50381 .37636 Mdot
.50571 .44249 Mdot
.50762 .26454 Mdot
.50952 .28347 Mdot
.51143 .42604 Mdot
.51333 .2515 Mdot
.51524 .34245 Mdot
.51714 .38 Mdot
.51905 .27313 Mdot
.52095 .26255 Mdot
.52286 .39197 Mdot
.52476 .37129 Mdot
.52667 .35274 Mdot
.52857 .25842 Mdot
.53048 .28524 Mdot
.53238 .37397 Mdot
.53429 .25768 Mdot
.53619 .30005 Mdot
.5381 .38941 Mdot
.54 .25546 Mdot
.5419 .27309 Mdot
.54381 .25515 Mdot
.54571 .37245 Mdot
.54762 .25777 Mdot
.54952 .35309 Mdot
.55143 .42889 Mdot
.55333 .30226 Mdot
.55524 .31532 Mdot
.55714 .36578 Mdot
.55905 .34494 Mdot
.56095 .36812 Mdot
.56286 .37564 Mdot
.56476 .32792 Mdot
.56667 .3109 Mdot
.56857 .43078 Mdot
.57048 .30286 Mdot
.57238 .26429 Mdot
.57429 .3164 Mdot
.57619 .32044 Mdot
.5781 .2427 Mdot
.58 .35049 Mdot
.5819 .32419 Mdot
.58381 .29334 Mdot
.58571 .41896 Mdot
.58762 .30076 Mdot
.58952 .41927 Mdot
.59143 .27444 Mdot
.59333 .42249 Mdot
.59524 .45715 Mdot
.59714 .23263 Mdot
.59905 .31582 Mdot
.60095 .47874 Mdot
.60286 .34552 Mdot
.60476 .39118 Mdot
.60667 .27019 Mdot
.60857 .30555 Mdot
.61048 .4057 Mdot
.61238 .30777 Mdot
.61429 .37132 Mdot
.61619 .25972 Mdot
.6181 .3249 Mdot
.62 .41035 Mdot
.6219 .31795 Mdot
.62381 .40351 Mdot
.62571 .46248 Mdot
.62762 .26719 Mdot
.62952 .29099 Mdot
.63143 .24378 Mdot
.63333 .22998 Mdot
.63524 .29641 Mdot
.63714 .38386 Mdot
.63905 .45352 Mdot
.64095 .38514 Mdot
.64286 .31838 Mdot
.64476 .37852 Mdot
.64667 .27444 Mdot
.64857 .38926 Mdot
.65048 .34654 Mdot
.65238 .31247 Mdot
.65429 .28697 Mdot
.65619 .28841 Mdot
.6581 .31604 Mdot
.66 .42258 Mdot
.6619 .33762 Mdot
.66381 .40933 Mdot
.66571 .32178 Mdot
.66762 .26954 Mdot
.66952 .35436 Mdot
.67143 .38864 Mdot
.67333 .36969 Mdot
.67524 .30573 Mdot
.67714 .35011 Mdot
.67905 .36418 Mdot
.68095 .25499 Mdot
.68286 .32827 Mdot
.68476 .32447 Mdot
.68667 .22868 Mdot
.68857 .34985 Mdot
.69048 .31279 Mdot
.69238 .36924 Mdot
.69429 .30422 Mdot
.69619 .34306 Mdot
.6981 .4155 Mdot
.7 .32671 Mdot
.7019 .42256 Mdot
.70381 .24719 Mdot
.70571 .33699 Mdot
.70762 .24667 Mdot
.70952 .28454 Mdot
.71143 .37617 Mdot
.71333 .32438 Mdot
.71524 .3706 Mdot
.71714 .24736 Mdot
.71905 .35244 Mdot
.72095 .38889 Mdot
.72286 .42853 Mdot
.72476 .27185 Mdot
.72667 .37001 Mdot
.72857 .33942 Mdot
.73048 .27054 Mdot
.73238 .27762 Mdot
.73429 .34561 Mdot
.73619 .25104 Mdot
.7381 .37584 Mdot
.74 .23878 Mdot
.7419 .36629 Mdot
.74381 .27598 Mdot
.74571 .42957 Mdot
.74762 .40981 Mdot
.74952 .39952 Mdot
.75143 .42784 Mdot
.75333 .40184 Mdot
.75524 .38996 Mdot
.75714 .49413 Mdot
.75905 .42979 Mdot
.76095 .3516 Mdot
.76286 .30365 Mdot
.76476 .44507 Mdot
.76667 .35206 Mdot
.76857 .28146 Mdot
.77048 .39003 Mdot
.77238 .36788 Mdot
.77429 .31412 Mdot
.77619 .2676 Mdot
.7781 .25159 Mdot
.78 .35223 Mdot
.7819 .35786 Mdot
.78381 .29145 Mdot
.78571 .45504 Mdot
.78762 .38592 Mdot
.78952 .27583 Mdot
.79143 .33667 Mdot
.79333 .25619 Mdot
.79524 .273 Mdot
.79714 .30455 Mdot
.79905 .31711 Mdot
.80095 .30215 Mdot
.80286 .32344 Mdot
.80476 .35151 Mdot
.80667 .31383 Mdot
.80857 .35279 Mdot
.81048 .33319 Mdot
.81238 .45855 Mdot
.81429 .35646 Mdot
.81619 .23741 Mdot
.8181 .27028 Mdot
.82 .33612 Mdot
.8219 .3015 Mdot
.82381 .36315 Mdot
.82571 .26347 Mdot
.82762 .34992 Mdot
.82952 .26474 Mdot
.83143 .46048 Mdot
.83333 .24385 Mdot
.83524 .27934 Mdot
.83714 .31888 Mdot
.83905 .27128 Mdot
.84095 .34585 Mdot
.84286 .26009 Mdot
.84476 .32944 Mdot
.84667 .44896 Mdot
.84857 .22133 Mdot
.85048 .2902 Mdot
.85238 .47861 Mdot
.85429 .25755 Mdot
.85619 .26352 Mdot
.8581 .30783 Mdot
.86 .34655 Mdot
.8619 .34153 Mdot
.86381 .36675 Mdot
.86571 .3704 Mdot
.86762 .30683 Mdot
.86952 .32464 Mdot
.87143 .29149 Mdot
.87333 .25913 Mdot
.87524 .31037 Mdot
.87714 .2218 Mdot
.87905 .31638 Mdot
.88095 .31556 Mdot
.88286 .25418 Mdot
.88476 .33691 Mdot
.88667 .26514 Mdot
.88857 .28492 Mdot
.89048 .27618 Mdot
.89238 .28125 Mdot
.89429 .39265 Mdot
.89619 .33892 Mdot
.8981 .26876 Mdot
.9 .26829 Mdot
.9019 .34559 Mdot
.90381 .29506 Mdot
.90571 .27471 Mdot
.90762 .26174 Mdot
.90952 .32195 Mdot
.91143 .4434 Mdot
.91333 .29869 Mdot
.91524 .42222 Mdot
.91714 .26602 Mdot
.91905 .35167 Mdot
.92095 .31034 Mdot
.92286 .24175 Mdot
.92476 .25159 Mdot
.92667 .34096 Mdot
.92857 .25131 Mdot
.93048 .44622 Mdot
.93238 .38438 Mdot
.93429 .27741 Mdot
.93619 .365 Mdot
.9381 .33414 Mdot
.94 .27073 Mdot
.9419 .32314 Mdot
.94381 .34101 Mdot
.94571 .38798 Mdot
.94762 .2769 Mdot
.94952 .24785 Mdot
.95143 .27296 Mdot
.95333 .36117 Mdot
.95524 .27472 Mdot
.95714 .28271 Mdot
.95905 .27015 Mdot
.96095 .30326 Mdot
.96286 .49077 Mdot
.96476 .30869 Mdot
.96667 .35709 Mdot
.96857 .41143 Mdot
.97048 .23523 Mdot
.97238 .29256 Mdot
.97429 .33967 Mdot
.97619 .36364 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo1_ooool2o`0003Gooooo0006ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`0eooooo`;o0000c_ooool2o`0000Sooooo0_l0000[ooooo`001_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02Cooooo0_l0000?ooooo`;o00007ooo
ool2o`0000_ooooo0_l0002Zooooo`;o0000:oooool000Co00000_ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo013ooooo0_l0000Booooo`;o0000<?ooool2o`0000_ooooo0_l00004ooooo`;o0000EOoo
ool2o`0000oooooo0_l0001Yooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o00004?ooool2o`0001kooooo0_l0
000gooooo`;o0000B_ooool2o`0000Wooooo0_l0000?ooooo`;o0000JOooool000Kooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`03o`000?oooooooooo033ooooo0_l00015ooooo`;o0000??ooool2o`0007Kooooo
0_l0000=ooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`07ooooo`;o00004oooool2o`0002?ooooo0_l0000Xooooo`Co0000
4_ooool2o`0000Sooooo0_l0001Pooooo`;o00005_ooool2o`00033ooooo0_l0000=ooooo`001_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03
o`000?oooooooooo00Oooooo0_l0000Cooooo`;o00008oooool2o`000003ooooool0003o000000Wo
oooo0_l0000Jooooo`Co00004_ooool2o`0000Sooooo0_l0000[ooooo`;o0000<oooool2o`0001Ko
oooo0_l0000Pooooo`;o00007Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool05oooool2o`00
027ooooo0_l000000ooooooo0000o`000006ooooo`;o00002oooool2o`0000[ooooo0_l0000Goooo
o`;o00000_ooool2o`00037ooooo0_l0000@ooooo`;o0000?oooool2o`0001[ooooo0_l0000Moooo
o`00:Oooool2o`0001Sooooo0_l0000Tooooo`;o00004oooool2o`0000[ooooo0_l0000Dooooo`;o
00001Oooool2o`0004?ooooo0_l0000Eooooo`?o000000?oooooo`000?l000009?ooool2o`0002?o
oooo0_l0000Dooooo`00:Oooool00ol0003oooooooooo`08ooooo`;o00000_ooool2o`0000?ooooo
0_l0000<ooooo`;o0000B?ooool2o`0000Wooooo0_l0000Jooooo`;o00002?ooool2o`0003_ooooo
0ol000000ooooooo0000o`000004ooooo`;o00003?ooool2o`0002gooooo0ol00005ooooo`;o0000
5?ooool002Wooooo00?o0000ooooooooool02?ooool2o`0000;ooooo0_l00003ooooo`;o00000ooo
ool2o`0000Oooooo0_l00004ooooo`;o0000@_ooool2o`0000oooooo0_l0000@ooooo`;o00000_oo
ool4o`0000Kooooo0_l00006ooooo`?o0000:oooool2o`0000oooooo0_l0000<ooooo`;o00007ooo
ool2o`0000cooooo0ol0000Kooooo`00:Oooool00ol0003oooooooooo`02ooooo`;o00004_ooool4
o`0000_ooooo0_l00002ooooo`;o00008_ooool2o`0000;ooooo0_l00005ooooo`;o00008?ooool2
o`00013ooooo0_l00004ooooo`;o00002oooool8o`0002Wooooo0_l0000Rooooo`;o00004Oooool2
o`0000Oooooo0_l0000Zooooo`00:Oooool00ol0003oooooooooo`02ooooo`;o00005?ooool2o`00
00oooooo0_l00004ooooo`;o00002oooool4o`0000gooooo0_l00002ooooo`;o00001Oooool2o`00
04Gooooo0ol00003ooooo`;o00005?ooool2o`0003Oooooo0_l0000>ooooo`;o000000?oooooo`00
0?l000001?ooool2o`0000Wooooo0_l0000Rooooo`00:Oooool2o`0000kooooo0_l0000Pooooo`;o
00002oooool4o`000003ooooool0003o000000;o0000>?ooool2o`0001Wooooo0_l00002ooooo`;o
00003oooool2o`0000cooooo0_l00011ooooo`?o00000oooool2o`0000;ooooo0_l00003ooooo`;o
00000oooool2o`0000Cooooo0_l0000Rooooo`00:Oooool01?l0003oooooo`000?l0000<ooooo`;o
00008Oooool2o`0000oooooo1_l0000fooooo`;o00006Oooool2o`0000;ooooo0_l0000?ooooo`;o
00003oooool2o`0002kooooo0_l0000>ooooo`?o00001oooool2o`0000Sooooo0_l00002ooooo`;o
00001?ooool2o`0001kooooo000Yooooo`04o`000?oooooo0000o`0002oooooo1?l000002?l@413o
ooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0_ooool2o`000005oc8b<_l0003o<S8bonk^k_ooool0
0_l0000Tooooo`Oo00000oooool01?o^k^ko<S8bo`000?lb<S82o`000007ooooool0003o0000oc8b
<_l0003o<S8bonk^kP0Xooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01_o^k^ko<S8bo`00
0?lb<S;ok^k^ooooo`;o000000Cok^k^oc8b<_l0003o<S8b0_l0000;ooooo`;o00004_ooool2o`00
00Sooooo0_l000000ol@413oooooooooo`02o`000004oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP02o`0000Cooooo0_l0000Aooooo`?o00001?ooool2o`0000Gooooo0_l0
00001?m4A4Co0000o`000?lb<S82o`000006ooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Yooooo`03o`000?oooooooooo03;ooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo0_l000001?nHV9SooooooiRHV?mg
MgLWooooo`;o000000GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`04ogMgMonHV9SooooooiRHV0;o
000000Ooooooo`000?l0003oV9RHoooooonHV9SoMgMg01[ooooo0_l00005ooooo`;o00001Oooool0
1Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00KoMgMgo`000?l0003oV9RHogMgMoooool2o`000005
ogMgMonHV9SooooooiRHV?mgMgL01_ooool2o`0000Cooooo0_l0000Aooooo`?o00002Oooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_l000001_ooooooMgMgoiRHV?oo
ooooV9RHogMgM`;o00001?ooool2o`00017ooooo0_l0000<ooooo`;o00000_ooool4o`000006oooo
oomgMgOoV9RHoooooonHV9SoMgMg0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000Yoooo
o`04o`000?ooooooooooooooo`;o00007_ooool2o`0000;ooooo0_l000001?oooooo0000o`000?oo
ool2o`0000Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooooooooa0@400@ooooo`;o00004_ooool2o`0000Cooooo00?oV9RHob4Q8Oo^
k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4005
ooooo`;o00004oooool2o`0000Gooooo0_l00009ooooo`05o`000?ooooooooooooooool@41000_l0
00000ooooooo410@ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool2o`0001Oooooo
1?l00002ooooo`;o000000?oooooo`000?l000000ol00003ooooo`03oa0@4?oooooooooo00Co0000
00?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0Eooooo`;o00000oooool2o`0000Oooooo
0_l00002ooooo`Go00000_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooooooooa0@4003ooooo`00:Oooool2o`0000;ooooo0_l0000Nooooo`;o00000_ooool2o`000003
ooooool0003o000000?o00001Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo0000013ooooo0_l0000Booooo`;o00001Oooool0
0onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000Gooooo0_l00006ooooo`;o00007?ooool00onYZJWo410@ooooo`02ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000027ooooo0_l00002oooo
o`;o000000GoooooodA4A?oMgMgoooooo`000004ooooo`03o`000?oooooooooo00;o00000oooool0
1Ol0003ooooooooooooooooo000000Gooooo0_l0000@ooooo`;o00000oooool2o`0000Oooooo0_l0
0002ooooo`;o000000?oooooo`000?l000000_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`00:Oooool00ol0003oooooooooo`0Oooooo`;o0000
2Oooool2o`0000Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000005ooooo`Co00008oooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000gooooo0_l0
0007ooooo`;o00004_ooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000002Sooooo00GogMgMoeEEEOoooooo0000ooooo`02o`00
0003ooooool0003ooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
oooo00?ooooo0_l0000Aooooo`;o00003oooool00ol0003o8B4Qo`000002o`0000;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool002Wooooo00?o
0000ooooooooool07oooool2o`0000_ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@4003ooooo`05oa0@4?l0003o0000ooooool@41001Oooool4o`0002Co
oooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool0
0ol@413oooooooooo`0Dooooo`;o00001Oooool2o`0000cooooo00?o^[Zjob4Q8Oooool00_ooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`;o0000
4?ooool2o`0000gooooo00CoMgMgolc<c?l0003ooooo0_l000000ooooooo410@ooooo`02ooooo`05
oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Dooooo`Co00003oooool00ol0
003oooooooooo`02o`0000;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo
ooooooooool@41000oooool002Wooooo00?o0000ooooooooool06Oooool2o`0000gooooo0_l00002
ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool01OmgMgOo0000o`000?nHV9SoMgMg00Oooooo0_l0000>ooooo`;o00004?ooool01_l0003o^[Zj
oooooonHV9So410@ooooo`;o000000GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL04Oooool2o`0000[ooooo0_l00009ooooo`05oa0@4?nHV9SooooookZj^_l00000
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08oooo
o`?o00003oooool2o`0000gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Fooooo`;o00004Oooool00ol0003ooooooooo
o`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo000Yooooo`03o`000?oooooooooo01Wooooo0_l0000=ooooo`;o00001_ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01Oooooo0_l00009ooooo`;o00001Oooool01_nHV9So410@o`000?l0003oc<c<ooooo`;o000000Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000o`000?o^k^h02_ooool2o`0000Go
oooo0_l0000Eooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02o`0000Oooooo0_l0000Oooooo`03ogMgMol0
003ooooo00?ooooo00Gok^k^oc8b<_l0003o0000onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02_ooool2o`0000Gooooo0_l0000Fooooo`Co00000oooool01Oo^k^ko0000o`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool2o`0006Oooooo0_l00007oooo
o`;o00003_ooool2o`0000_ooooo0_l00008ooooo`;o00006?ooool2o`0000gooooo0_l0000`oooo
o`;o00004oooool2o`0000Gooooo0_l00008ooooo`;o00005?ooool2o`0000gooooo000Yooooo`03
o`000?oooooooooo06Cooooo0_l0000Gooooo`;o000000?oooooo`000?l000005?ooool2o`0001So
oooo0_l0000?ooooo`;o0000E?ooool2o`000003ooooool0003o0000023ooooo000Yooooo`03o`00
0?oooooooooo02kooooo0_l0000Dooooo`;o00004?ooool2o`0000cooooo0_l0000<ooooo`;o0000
1Oooool2o`0000;ooooo0_l000000ooooooo0000o`00000Booooo`;o00002oooool2o`0000Cooooo
0_l00009ooooo`;o00003Oooool2o`0003?ooooo0_l00005ooooo`;o00006oooool2o`00023ooooo
000Yooooo`04o`000?ooooooooooooooo`;o00003oooool2o`0001?ooooo0_l00005ooooo`;o0000
5?ooool2o`00013ooooo0_l0000Jooooo`;o00001Oooool2o`0001Wooooo0_l0000;ooooo`;o0000
1?ooool2o`0000?ooooo0_l00004ooooo`;o00001?ooool2o`0001[ooooo0_l0000Dooooo`;o0000
2Oooool3o`0000Gooooo0_l0000[ooooo`;o00004?ooool002Wooooo0ol000000ooooooo0000o`00
000?ooooo`;o00004oooool2o`0003Kooooo0_l0000Gooooo`;o00002oooool2o`0002Gooooo0_l0
000:ooooo`Co00004_ooool2o`0000Cooooo0_l0000Dooooo`;o00002Oooool2o`0001;ooooo0_l0
00000ooooooo0000o`00000Looooo`?o00003oooool0027oooooool00014o`0000Cooooo000Yoooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool2o`0000Cooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo0ol0000<oooo
o`03o`000?oooooooooo00;ooooo0_l00005ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool00_ooool2o`0000Gooooo00Go0000ooooool0003o0000ooooo`02o`0000Kooooo00?o0000
ooooooooool01oooool6o`0000Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:
ooooo`04o`000?oooooo0000o`0000Sooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`02ooooo`;o00001Oooool00ol0003oooooooooo`03ooooo`;o00001Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Gooooo0_l00002ooooo`03o`000?oooooooooo00?ooooo0_l0
0004ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_l00007ooooo`03o`000?oo
oooooooo00?ooooo0_l00004ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_oo
ool002Wooooo00?o0000ooooooooool04?ooool2o`0000;ooooo0_l0000Tooooo`?o00003oooool2
o`0001Kooooo0_l00007ooooo`;o000000?oooooo`000?l000001_ooool00ol0003oooooooooo`07
ooooo`;o00000_ooool2o`0001oooooo0_l00004ooooo`;o00001_ooool2o`0000Kooooo0_l00007
ooooo`Co00002Oooool2o`0001Wooooo0_l00002ooooo`04o`000?ooooooooooooooo`Co00005Ooo
ool3o`0001gooooo00?o0000ooooooooool02_ooool002Wooooo00?o0000ooooooooool00_ooool2
o`000003ooooool0003o000000gooooo0_l0000<ooooo`;o00005oooool2o`0006[ooooo0_l00004
ooooo`?o00001Oooool2o`0000Kooooo0_l00004ooooo`;o00000oooool2o`0002cooooo0_l0000:
ooooo`;o00002oooool3o`0002[ooooo000Yooooo`03o`000?oooooooooo00;ooooo0_l000000ooo
oooo0000o`00000Kooooo`;o00007Oooool2o`00043ooooo0_l0000Yooooo`Co00004Oooool2o`00
00Kooooo0_l0000Zooooo`;o00002Oooool2o`0001Gooooo0_l00008ooooo`;o00005oooool002Wo
oooo0_l00006ooooo`;o00007?ooool2o`0000Sooooo0_l0000>ooooo`;o00000_ooool2o`0000ko
oooo0_l0000Kooooo`;o00004oooool2o`0000[ooooo0_l0000Oooooo`;o00002Oooool2o`0000ko
oooo0_l00004ooooo`;o00000oooool2o`0000;ooooo0_l0000Kooooo`;o00004oooool2o`0000_o
oooo0_l00008ooooo`;o00005oooool002Wooooo00?o0000ooooooooool01?ooool3o`0000;ooooo
0_l0000Hooooo`;o00002?ooool2o`0000kooooo1?l0000@ooooo`;o00004oooool2o`0000Kooooo
0_l0000Iooooo`?o00000oooool2o`0001Wooooo0_l0000?ooooo`;o00004oooool3o`0000?ooooo
0_l00002ooooo`;o0000:?ooool2o`0000Kooooo0_l0000^ooooo`00:Oooool00ol0003ooooooooo
o`04ooooo`;o000000?oooooo`000?l000000_l0000=ooooo`;o00001_ooool2o`0001?ooooo0_l0
0008ooooo`;o00005?ooool2o`0000oooooo0_l0000Iooooo`;o00001_ooool3o`0001kooooo0_l0
000Tooooo`;o00009oooool2o`0000Wooooo0_l0000fooooo`00:Oooool00ol0003oooooooooo`07
ooooo`;o00003oooool2o`000003ooooool0003o000000?ooooo0_l0000Cooooo`;o00007_ooool2
o`0001Sooooo0_l0000@ooooo`;o00004Oooool2o`0005gooooo0_l00004ooooo`;o000000?ooooo
o`000?l000009?ooool2o`0001Sooooo000Yooooo`03o`000?oooooooooo00?ooooo0_l0000Foooo
o`;o00002Oooool2o`0000_ooooo0_l000000ooooooo0000o`000002ooooo`;o00005oooool2o`00
00Gooooo0_l0000;ooooo`;o00001_ooool2o`0000Gooooo0_l0000<ooooo`;o00000_ooool2o`00
0003ooooool0003o000000Oooooo0_l0000cooooo`;o00003Oooool2o`0000Gooooo0_l0000Boooo
o`;o00001oooool2o`0001?ooooo0_l00002ooooo`;o00002oooool2o`0000[ooooo0_l0000<oooo
o`00:Oooool2o`0000Cooooo0_l0000Qooooo`;o00002Oooool4o`000003ooooool0003o000000;o
oooo0_l0000Gooooo`;o00001Oooool2o`0000_ooooo0_l0000=ooooo`;o00003?ooool2o`0000;o
oooo0_l000000ooooooo0000o`00000=ooooo`;o0000;Oooool2o`0000gooooo0_l00005ooooo`;o
0000:Oooool2o`0000Gooooo0_l00002ooooo`;o00002?ooool2o`0000?ooooo0_l00008ooooo`;o
00003?ooool002Wooooo00?o0000ooooooooool01_ooool2o`0001Gooooo0_l0000Booooo`;o0000
Boooool2o`0000Oooooo0_l0000Aooooo`;o00003?ooool2o`0000cooooo0_l0000Looooo`;o0000
2oooool2o`00023ooooo0_l00005ooooo`;o00002oooool2o`0000Kooooo0_l00003ooooo`;o0000
5_ooool002Wooooo00?o0000ooooooooool01_ooool2o`0001Gooooo0_l0000Dooooo`;o0000BOoo
ool2o`0000Oooooo0_l0000Oooooo`;o00003?ooool2o`0000kooooo0_l0000<ooooo`;o00002ooo
ool2o`00023ooooo0_l00004ooooo`;o00003?ooool2o`0002?ooooo000Yooooo`03o`000?oooooo
oooo00gooooo0_l0000Oooooo`;o00000oooool2o`0005Cooooo0_l0000Tooooo`;o00005Oooool2
o`0000Kooooo0_l00002ooooo`;o00005Oooool4o`0000;ooooo0_l00006ooooo`;o00001_ooool2
o`0000Sooooo0_l0000Aooooo`;o00007_ooool002Wooooo00?o0000ooooooooool03Oooool3o`00
01kooooo0_l00006ooooo`;o0000DOooool2o`0000;ooooo0_l0000?ooooo`;o00001Oooool2o`00
00Sooooo0_l0000Kooooo`Co00000_ooool2o`0000Sooooo0_l0000;ooooo`Co00000_ooool2o`00
00Kooooo1?l00004ooooo`;o00006oooool2o`0001kooooo000Yooooo`;o00003oooool2o`0000Go
oooo0_l0000Oooooo`;o00005_ooool2o`0000Sooooo0_l0000Aooooo`;o00003Oooool2o`00017o
oooo0_l0000?ooooo`;o00001Oooool2o`0002Gooooo0_l0000>ooooo`;o00004_ooool2o`0000Oo
oooo0ol0000_ooooo`;o00003oooool002Wooooo1?l0000>ooooo`;o00001?ooool2o`0003Oooooo
0_l00008ooooo`;o00003Oooool2o`0000;ooooo0_l00009ooooo`;o00000_ooool2o`0007Cooooo
0_l00008ooooo`;o0000:oooool2o`0000;ooooo0_l0000?ooooo`00:Oooool4o`0000kooooo0_l0
0009ooooo`;o00000_ooool2o`0001;ooooo0_l0000Dooooo`;o00004_ooool2o`0000Wooooo0_l0
000=ooooo`;o0000Eoooool2o`0002gooooo0_l0000Wooooo`;o00001_ooool2o`0000_ooooo000Y
ooooo`03o`000?oooooooooo01[ooooo0_l00002ooooo`;o00004_ooool2o`0000Oooooo0_l0000;
ooooo`;o00004_ooool2o`0004[ooooo0_l0000Uooooo`;o00004_ooool2o`0000Sooooo0_l0000?
ooooo`;o00002_ooool2o`0001Kooooo0_l0000;ooooo`;o00002oooool002Wooooo00?o0000oooo
ooooool05?ooool2o`0000Cooooo0_l00007ooooo`;o00000_ooool2o`000003ooooool0003o0000
00oooooo0_l00003ooooo`;o00001oooool2o`0001Oooooo0_l00006ooooo`;o0000:Oooool2o`00
017ooooo0ol0000Rooooo`;o00001?ooool2o`0000Kooooo0_l000000ooooooo0000o`000003oooo
o`;o00002?ooool2o`0001_ooooo0ol0000Eooooo`;o00006?ooool002Wooooo0_l0000Eooooo`;o
00001?ooool2o`0000Oooooo0_l00002ooooo`;o000000?oooooo`000?l000005?ooool2o`0000Oo
oooo0_l0000>ooooo`;o00001oooool2o`0000Kooooo0_l0000Yooooo`;o00001_ooool2o`000003
ooooool0003o000000;ooooo0_l00003ooooo`;o00003oooool2o`00017ooooo0_l00004ooooo`;o
00001_ooool2o`000003ooooool0003o000002_ooooo0_l0000_ooooo`00:Oooool00ol0003ooooo
ooooo`0Gooooo`;o00000oooool2o`0003_ooooo0_l0000booooo`;o00002?ooool2o`0000Cooooo
0_l000000ooooooo0000o`000002ooooo`;o00001?ooool2o`0000kooooo0_l0000Mooooo`;o0000
1oooool2o`0005Sooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Gooooo`;o
00000oooool2o`0001[ooooo0_l00012ooooo`;o00003oooool2o`0000Sooooo0_l00002ooooo`;o
00003Oooool2o`0001Sooooo0_l0000Cooooo`;o00001oooool2o`0005Sooooo0006ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool03oooool2o`0002Oooooo0_l0000Doooo
o`;o00002oooool2o`0000oooooo0_l0000>ooooo`;o00007Oooool2o`0002Oooooo0_l0001foooo
o`001_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;o00002Oooool2o`0000;ooooo0_l0000moooo
o`;o00002oooool2o`0000oooooo0_l00003ooooo`;o0000C_ooool4o`0002gooooo0_l0000/oooo
o`;o00006_ooool000Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^
00Oooooo00?oMgMgoc8b<_ooool01?ooool5o`0000Wooooo0_l0000@ooooo`;o00003?ooool2o`00
02;ooooo0_l0000<ooooo`;o00004_ooool2o`0002oooooo0_l0000Mooooo`Ko00001_ooool2o`00
00gooooo0_l0000Dooooo`;o0000;?ooool2o`0000?ooooo0_l0000Eooooo`001_ooool01Ol0003o
oooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool07Oooool2o`0000cooooo0_l0000Rooooo`?o00002oooool2
o`0003?ooooo0_l00009ooooo`;o00000oooool2o`0001?ooooo0_l0000<ooooo`;o00001_ooool2
o`0000gooooo0_l00009ooooo`;o00000oooool2o`0002Kooooo0_l0000?ooooo`;o00005Oooool0
00Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`Co0000AOooool2o`00043ooooo0_l00009
ooooo`;o00006?ooool2o`0002kooooo0_l00003ooooo`;o00009_ooool2o`0002Kooooo0006oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`;o000000?oooooo`000?l000000ol0
000jooooo`;o0000m?ooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool01?ooool2o`0000Cooooo
0_l0000Qooooo`;o00002_ooool2o`0000_ooooo0_l0002Nooooo`?o0000Doooool002Wooooo0_l0
000;ooooo`;o00008Oooool2o`0000[ooooo0_l0000Booooo`;o00004Oooool2o`0005_ooooo0_l0
000Wooooo`?o0000Doooool002Wooooo00?o0000ooooooooool02_ooool4o`0003[ooooo0_l00003
ooooo`;o00004Oooool2o`0002kooooo0_l0000Wooooo`;o00000_ooool2o`0007gooooo000Yoooo
o`03o`000?oooooooooo00cooooo0_l0000>ooooo`;o00005_ooool2o`0001;ooooo0_l0000eoooo
o`;o00001?ooool2o`0000Wooooo0_l0000Wooooo`;o000000?oooooo`000?l000003?ooool2o`00
01Wooooo0_l00015ooooo`;o00003_ooool002Wooooo00?o0000ooooooooool07?ooool2o`0000;o
oooo0_l0000Booooo`;o00007Oooool2o`0002[ooooo0_l00004ooooo`;o0000=Oooool2o`0000co
oooo0_l0000Iooooo`;o0000AOooool2o`0000kooooo000Yooooo`03o`000?oooooooooo01Gooooo
0_l00009ooooo`;o0000<Oooool2o`0001cooooo0_l0001Rooooo`;o0000IOooool002Wooooo0_l0
000Fooooo`;o0000F_ooool2o`0003kooooo0ol0000Qooooo`;o0000IOooool002Wooooo00?o0000
ooooooooool0UOooool2o`0001[ooooo1?l0000Dooooo`;o00002oooool2o`0004?ooooo0_l0000O
ooooo`00:Oooool00ol0003oooooooooo`1Qooooo`;o00002Oooool4o`0001;ooooo0_l0000Aoooo
o`;o00000_ooool2o`0001Sooooo0_l0000Dooooo`;o00002oooool2o`0004?ooooo0_l0000Ooooo
o`00:Oooool00ol0003oooooooooo`16ooooo`;o00005?ooool2o`0000?ooooo0_l00009ooooo`Co
00004_ooool2o`0001Gooooo0_l0000;ooooo`;o0000=Oooool2o`0000Gooooo1?l000000ooooooo
0000o`00001Aooooo`00:Oooool00ol0003oooooooooo`0Cooooo`;o0000<Oooool2o`0001Cooooo
1Ol00004ooooo`;o0000?oooool2o`0000?ooooo0_l0000`ooooo`;o00001Oooool4o`000003oooo
ool0003o0000057ooooo000Yooooo`;o00005?ooool2o`0003_ooooo0_l0000<ooooo`?o00001?oo
ool2o`0004Cooooo0_l0002?ooooo`00:Oooool00ol0003oooooooooo`1@ooooo`;o0000j_ooool0
02Wooooo00?o0000ooooooooool0Uoooool2o`000:?ooooo000Yooooo`03o`000?oooooooooo09Oo
oooo0_l0001Booooo`;o0000;Oooool2o`00023ooooo000Yooooo`03o`000?oooooooooo02;ooooo
0_l0001Aooooo`;o00006_ooool2o`0005Sooooo0_l0000]ooooo`;o00001?ooool2o`0001[ooooo
000Yooooo`;o00008oooool2o`00057ooooo0_l0000Jooooo`;o0000L_ooool2o`0001Wooooo0_l0
000Jooooo`00:Oooool00ol0003oooooooooo`1dooooo`;o0000C?ooool2o`00047ooooo0_l0000e
ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`1dooooo`;o00005?ooool2o`0002Sooooo0_l0
000<ooooo`;o0000;Oooool2o`0004Wooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`17ooooo`;o0000:Ooo
ool2o`0001Kooooo0_l00002ooooo`;o00009?ooool2o`0003_ooooo0_l00007ooooo`;o00001?oo
ool2o`0003[ooooo000>ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`03ooooo`?o0000Aoooool2o`00013ooooo0_l0000Gooooo`;o00006_ooool2o`0002kooooo0_l0
000jooooo`;o00001?ooool2o`0003[ooooo000>ooooo`05o`000?ooooooooooooooool000003ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo05Wooooo0_l0001Sooooo`;o0000O?oo
ool000kooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000
]oooool2o`0004oooooo0_l0000cooooo`00:Oooool00ol0003oooooooooo`2fooooo`;o0000Cooo
ool2o`0003?ooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`13ooooo`;o00004_ooool2o`000=7o
oooo0_l0000@ooooo`00:Oooool2o`0004Cooooo0_l0000Booooo`;o0000Soooool2o`00043ooooo
0_l0000@ooooo`00:Oooool00ol0003oooooooooo`3Xooooo`;o0000D_ooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46
ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_oo
ool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooo
oolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?oo
ool00ol0003oooooooooo`03ooooo`?o0000oooooolmooooo`001_ooool01Ol0003ooooooooooooo
oooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<
c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo
?Oooool000Kooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool5o`0000Cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o
0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o
0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool001oooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooo
oooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Qooooo`03o`000?oooooooooo00Gooooo0ol0003oooooocgooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001oo
oooo00?oEEEEofIVI_l00000oooooom7ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .31795 Mdot
.02762 .27084 Mdot
.02952 .27856 Mdot
.03143 .27887 Mdot
.03333 .32366 Mdot
.03524 .38646 Mdot
.03714 .27036 Mdot
.03905 .23309 Mdot
.04095 .40399 Mdot
.04286 .2898 Mdot
.04476 .2817 Mdot
.04667 .22894 Mdot
.04857 .41296 Mdot
.05048 .2581 Mdot
.05238 .22901 Mdot
.05429 .32121 Mdot
.05619 .37522 Mdot
.0581 .41419 Mdot
.06 .31162 Mdot
.0619 .23629 Mdot
.06381 .41164 Mdot
.06571 .34189 Mdot
.06762 .35911 Mdot
.06952 .41415 Mdot
.07143 .31569 Mdot
.07333 .28185 Mdot
.07524 .32371 Mdot
.07714 .32894 Mdot
.07905 .25443 Mdot
.08095 .27286 Mdot
.08286 .41095 Mdot
.08476 .4011 Mdot
.08667 .28401 Mdot
.08857 .32993 Mdot
.09048 .24249 Mdot
.09238 .28056 Mdot
.09429 .41282 Mdot
.09619 .35315 Mdot
.0981 .27265 Mdot
.1 .24529 Mdot
.1019 .33137 Mdot
.10381 .27034 Mdot
.10571 .31683 Mdot
.10762 .27712 Mdot
.10952 .34642 Mdot
.11143 .36633 Mdot
.11333 .25675 Mdot
.11524 .42803 Mdot
.11714 .30567 Mdot
.11905 .2395 Mdot
.12095 .42998 Mdot
.12286 .34246 Mdot
.12476 .26769 Mdot
.12667 .26271 Mdot
.12857 .2882 Mdot
.13048 .35787 Mdot
.13238 .23057 Mdot
.13429 .37543 Mdot
.13619 .43616 Mdot
.1381 .3598 Mdot
.14 .36365 Mdot
.1419 .4627 Mdot
.14381 .27452 Mdot
.14571 .27541 Mdot
.14762 .30934 Mdot
.14952 .37877 Mdot
.15143 .3044 Mdot
.15333 .29316 Mdot
.15524 .35108 Mdot
.15714 .41183 Mdot
.15905 .35981 Mdot
.16095 .31697 Mdot
.16286 .28888 Mdot
.16476 .33536 Mdot
.16667 .27403 Mdot
.16857 .30695 Mdot
.17048 .26807 Mdot
.17238 .34977 Mdot
.17429 .32033 Mdot
.17619 .25398 Mdot
.1781 .38236 Mdot
.18 .2617 Mdot
.1819 .30829 Mdot
.18381 .25807 Mdot
.18571 .28141 Mdot
.18762 .33651 Mdot
.18952 .33268 Mdot
.19143 .34861 Mdot
.19333 .3789 Mdot
.19524 .29756 Mdot
.19714 .31879 Mdot
.19905 .3314 Mdot
.20095 .33326 Mdot
.20286 .36322 Mdot
.20476 .31812 Mdot
.20667 .35588 Mdot
.20857 .25541 Mdot
.21048 .42954 Mdot
.21238 .28757 Mdot
.21429 .37849 Mdot
.21619 .29018 Mdot
.2181 .37643 Mdot
.22 .22669 Mdot
.2219 .25592 Mdot
.22381 .39555 Mdot
.22571 .31372 Mdot
.22762 .34912 Mdot
.22952 .27657 Mdot
.23143 .33425 Mdot
.23333 .41124 Mdot
.23524 .25835 Mdot
.23714 .28133 Mdot
.23905 .40522 Mdot
.24095 .24757 Mdot
.24286 .45717 Mdot
.24476 .29644 Mdot
.24667 .35717 Mdot
.24857 .34877 Mdot
.25048 .37378 Mdot
.25238 .39964 Mdot
.25429 .41186 Mdot
.25619 .45348 Mdot
.2581 .39606 Mdot
.26 .26479 Mdot
.2619 .41113 Mdot
.26381 .26389 Mdot
.26571 .23686 Mdot
.26762 .39341 Mdot
.26952 .24159 Mdot
.27143 .26831 Mdot
.27333 .36455 Mdot
.27524 .25906 Mdot
.27714 .24721 Mdot
.27905 .39189 Mdot
.28095 .3491 Mdot
.28286 .30291 Mdot
.28476 .41124 Mdot
.28667 .23484 Mdot
.28857 .29549 Mdot
.29048 .2585 Mdot
.29238 .23413 Mdot
.29429 .4599 Mdot
.29619 .32905 Mdot
.2981 .33845 Mdot
.3 .37491 Mdot
.3019 .23207 Mdot
.30381 .30977 Mdot
.30571 .49099 Mdot
.30762 .28156 Mdot
.30952 .35777 Mdot
.31143 .44924 Mdot
.31333 .37365 Mdot
.31524 .35451 Mdot
.31714 .41428 Mdot
.31905 .32154 Mdot
.32095 .39281 Mdot
.32286 .389 Mdot
.32476 .29973 Mdot
.32667 .3543 Mdot
.32857 .41058 Mdot
.33048 .39483 Mdot
.33238 .24658 Mdot
.33429 .32581 Mdot
.33619 .34123 Mdot
.3381 .32862 Mdot
.34 .30162 Mdot
.3419 .31011 Mdot
.34381 .3206 Mdot
.34571 .38254 Mdot
.34762 .35355 Mdot
.34952 .39633 Mdot
.35143 .23453 Mdot
.35333 .33347 Mdot
.35524 .35315 Mdot
.35714 .32593 Mdot
.35905 .25941 Mdot
.36095 .28753 Mdot
.36286 .3693 Mdot
.36476 .39255 Mdot
.36667 .31324 Mdot
.36857 .25821 Mdot
.37048 .37659 Mdot
.37238 .27255 Mdot
.37429 .34629 Mdot
.37619 .34379 Mdot
.3781 .32242 Mdot
.38 .4115 Mdot
.3819 .3993 Mdot
.38381 .40075 Mdot
.38571 .32777 Mdot
.38762 .33929 Mdot
.38952 .43926 Mdot
.39143 .23188 Mdot
.39333 .26294 Mdot
.39524 .45673 Mdot
.39714 .25595 Mdot
.39905 .38983 Mdot
.40095 .23259 Mdot
.40286 .35732 Mdot
.40476 .26266 Mdot
.40667 .30622 Mdot
.40857 .32594 Mdot
.41048 .32646 Mdot
.41238 .30952 Mdot
.41429 .30583 Mdot
.41619 .23966 Mdot
.4181 .28107 Mdot
.42 .31994 Mdot
.4219 .3914 Mdot
.42381 .27912 Mdot
.42571 .33184 Mdot
.42762 .29657 Mdot
.42952 .39765 Mdot
.43143 .35337 Mdot
.43333 .38164 Mdot
.43524 .34303 Mdot
.43714 .30285 Mdot
.43905 .36072 Mdot
.44095 .34383 Mdot
.44286 .32877 Mdot
.44476 .37726 Mdot
.44667 .23311 Mdot
.44857 .35935 Mdot
.45048 .43478 Mdot
.45238 .38951 Mdot
.45429 .36775 Mdot
.45619 .326 Mdot
.4581 .27137 Mdot
.46 .25896 Mdot
.4619 .33329 Mdot
.46381 .2303 Mdot
.46571 .45928 Mdot
.46762 .2878 Mdot
.46952 .31788 Mdot
.47143 .24166 Mdot
.47333 .34074 Mdot
.47524 .3273 Mdot
.47714 .44566 Mdot
.47905 .35454 Mdot
.48095 .24339 Mdot
.48286 .39962 Mdot
.48476 .26786 Mdot
.48667 .46191 Mdot
.48857 .37285 Mdot
.49048 .35106 Mdot
.49238 .3605 Mdot
.49429 .39474 Mdot
.49619 .3012 Mdot
.4981 .37174 Mdot
.5 .36893 Mdot
.5019 .36271 Mdot
.50381 .28283 Mdot
.50571 .37899 Mdot
.50762 .30103 Mdot
.50952 .26607 Mdot
.51143 .38399 Mdot
.51333 .28412 Mdot
.51524 .35101 Mdot
.51714 .32286 Mdot
.51905 .29896 Mdot
.52095 .24166 Mdot
.52286 .43481 Mdot
.52476 .32634 Mdot
.52667 .32686 Mdot
.52857 .35438 Mdot
.53048 .26801 Mdot
.53238 .36799 Mdot
.53429 .3452 Mdot
.53619 .25505 Mdot
.5381 .36389 Mdot
.54 .25578 Mdot
.5419 .25751 Mdot
.54381 .25565 Mdot
.54571 .30682 Mdot
.54762 .28724 Mdot
.54952 .28494 Mdot
.55143 .38795 Mdot
.55333 .3444 Mdot
.55524 .25247 Mdot
.55714 .42607 Mdot
.55905 .29295 Mdot
.56095 .39338 Mdot
.56286 .28051 Mdot
.56476 .28734 Mdot
.56667 .34492 Mdot
.56857 .40877 Mdot
.57048 .22615 Mdot
.57238 .26977 Mdot
.57429 .31448 Mdot
.57619 .25569 Mdot
.5781 .27116 Mdot
.58 .36374 Mdot
.5819 .39362 Mdot
.58381 .40096 Mdot
.58571 .4336 Mdot
.58762 .22679 Mdot
.58952 .43195 Mdot
.59143 .28399 Mdot
.59333 .43428 Mdot
.59524 .44656 Mdot
.59714 .30266 Mdot
.59905 .22684 Mdot
.60095 .49813 Mdot
.60286 .27237 Mdot
.60476 .35731 Mdot
.60667 .24939 Mdot
.60857 .39687 Mdot
.61048 .3125 Mdot
.61238 .25513 Mdot
.61429 .42782 Mdot
.61619 .26997 Mdot
.6181 .30703 Mdot
.62 .39215 Mdot
.6219 .37111 Mdot
.62381 .40804 Mdot
.62571 .44154 Mdot
.62762 .28725 Mdot
.62952 .36822 Mdot
.63143 .3009 Mdot
.63333 .28874 Mdot
.63524 .26418 Mdot
.63714 .27717 Mdot
.63905 .41153 Mdot
.64095 .45081 Mdot
.64286 .26315 Mdot
.64476 .39398 Mdot
.64667 .25167 Mdot
.64857 .3046 Mdot
.65048 .28348 Mdot
.65238 .32533 Mdot
.65429 .27266 Mdot
.65619 .35929 Mdot
.6581 .22572 Mdot
.66 .37484 Mdot
.6619 .31766 Mdot
.66381 .37772 Mdot
.66571 .27605 Mdot
.66762 .30846 Mdot
.66952 .26345 Mdot
.67143 .38362 Mdot
.67333 .30375 Mdot
.67524 .24657 Mdot
.67714 .29222 Mdot
.67905 .24212 Mdot
.68095 .27739 Mdot
.68286 .2431 Mdot
.68476 .27359 Mdot
.68667 .32197 Mdot
.68857 .31246 Mdot
.69048 .23219 Mdot
.69238 .28666 Mdot
.69429 .3388 Mdot
.69619 .36408 Mdot
.6981 .46039 Mdot
.7 .22822 Mdot
.7019 .43535 Mdot
.70381 .26543 Mdot
.70571 .26177 Mdot
.70762 .3215 Mdot
.70952 .23657 Mdot
.71143 .35684 Mdot
.71333 .22762 Mdot
.71524 .44493 Mdot
.71714 .34422 Mdot
.71905 .24269 Mdot
.72095 .28451 Mdot
.72286 .35081 Mdot
.72476 .28367 Mdot
.72667 .32397 Mdot
.72857 .23449 Mdot
.73048 .23633 Mdot
.73238 .27635 Mdot
.73429 .40276 Mdot
.73619 .28662 Mdot
.7381 .39339 Mdot
.74 .29999 Mdot
.7419 .42539 Mdot
.74381 .24544 Mdot
.74571 .42468 Mdot
.74762 .34455 Mdot
.74952 .35025 Mdot
.75143 .43229 Mdot
.75333 .35525 Mdot
.75524 .28769 Mdot
.75714 .47467 Mdot
.75905 .41076 Mdot
.76095 .39193 Mdot
.76286 .32134 Mdot
.76476 .38785 Mdot
.76667 .37943 Mdot
.76857 .27629 Mdot
.77048 .28565 Mdot
.77238 .41115 Mdot
.77429 .32495 Mdot
.77619 .3272 Mdot
.7781 .32095 Mdot
.78 .33634 Mdot
.7819 .42346 Mdot
.78381 .37882 Mdot
.78571 .45353 Mdot
.78762 .27989 Mdot
.78952 .35149 Mdot
.79143 .22464 Mdot
.79333 .33569 Mdot
.79524 .26207 Mdot
.79714 .25089 Mdot
.79905 .29555 Mdot
.80095 .22576 Mdot
.80286 .22749 Mdot
.80476 .32071 Mdot
.80667 .33888 Mdot
.80857 .34223 Mdot
.81048 .34483 Mdot
.81238 .42032 Mdot
.81429 .36217 Mdot
.81619 .32682 Mdot
.8181 .32443 Mdot
.82 .3547 Mdot
.8219 .26408 Mdot
.82381 .35098 Mdot
.82571 .342 Mdot
.82762 .34594 Mdot
.82952 .31199 Mdot
.83143 .45134 Mdot
.83333 .26037 Mdot
.83524 .30604 Mdot
.83714 .24456 Mdot
.83905 .34921 Mdot
.84095 .3895 Mdot
.84286 .27031 Mdot
.84476 .35482 Mdot
.84667 .3962 Mdot
.84857 .32278 Mdot
.85048 .23971 Mdot
.85238 .42055 Mdot
.85429 .25942 Mdot
.85619 .28961 Mdot
.8581 .39687 Mdot
.86 .23899 Mdot
.8619 .28694 Mdot
.86381 .28294 Mdot
.86571 .24804 Mdot
.86762 .33848 Mdot
.86952 .31248 Mdot
.87143 .25286 Mdot
.87333 .3552 Mdot
.87524 .24774 Mdot
.87714 .29356 Mdot
.87905 .33097 Mdot
.88095 .24406 Mdot
.88286 .27109 Mdot
.88476 .30414 Mdot
.88667 .29509 Mdot
.88857 .33839 Mdot
.89048 .23315 Mdot
.89238 .27002 Mdot
.89429 .30835 Mdot
.89619 .24885 Mdot
.8981 .35489 Mdot
.9 .2446 Mdot
.9019 .40237 Mdot
.90381 .36197 Mdot
.90571 .38942 Mdot
.90762 .32089 Mdot
.90952 .22667 Mdot
.91143 .38045 Mdot
.91333 .25526 Mdot
.91524 .43494 Mdot
.91714 .26356 Mdot
.91905 .37689 Mdot
.92095 .23197 Mdot
.92286 .28603 Mdot
.92476 .3013 Mdot
.92667 .36443 Mdot
.92857 .3288 Mdot
.93048 .46506 Mdot
.93238 .33923 Mdot
.93429 .30923 Mdot
.93619 .29378 Mdot
.9381 .2599 Mdot
.94 .28539 Mdot
.9419 .26725 Mdot
.94381 .25899 Mdot
.94571 .34791 Mdot
.94762 .32048 Mdot
.94952 .30647 Mdot
.95143 .37659 Mdot
.95333 .32066 Mdot
.95524 .35851 Mdot
.95714 .34327 Mdot
.95905 .33439 Mdot
.96095 .26698 Mdot
.96286 .45241 Mdot
.96476 .26858 Mdot
.96667 .26702 Mdot
.96857 .43349 Mdot
.97048 .32016 Mdot
.97238 .34708 Mdot
.97429 .24187 Mdot
.97619 .25243 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0??ooooo0_l00017ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo03_ooooo0_l0001_ooooo`;o00001?ooool2o`000003ooooool0003o0000017ooooo0_l0
000@ooooo`;o00005oooool2o`000004ooooool0003o0000o`00023ooooo0_l0000Qooooo`001?l0
0002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool3o`0001Sooooo0_l0000Jooooo`;o0000
COooool2o`00023ooooo0_l00004ooooo`;o000000?oooooo`000?l000004Oooool2o`0000cooooo
0_l00002ooooo`;o00006_ooool3o`00023ooooo0_l0000Qooooo`001_ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000
00Coooooo`000?l0003ooooo0ol0000Hooooo`;o0000<_ooool2o`000003ooooool0003o000001[o
oooo0_l00002ooooo`;o00003?ooool2o`0000Cooooo0_l00017ooooo`;o000000?oooooo`000?l0
0000>oooool2o`0000Sooooo0_l0000Mooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00Co0000oooo
oooooooooooo0_l00006ooooo`;o0000?oooool2o`0000Gooooo1?l000000ooooooo0000o`00000>
ooooo`;o00002_ooool2o`0000;ooooo0_l0000<ooooo`;o0000COooool2o`0000Cooooo0_l00004
ooooo`;o0000<_ooool2o`0000Sooooo0_l0000Mooooo`001_ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Wooooo0_l0000@ooooo`;o0000;Oooool2o`0000Gooooo0_l0000Cooooo`;o00004_ooool2
o`0005gooooo0_l00004ooooo`;o00009Oooool2o`000003ooooool0003o0000037ooooo0006oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`;o00001oooool2o`0002kooooo0_l0
000]ooooo`;o00004?ooool2o`000003ooooool0003o000000_ooooo0_l0000aooooo`?o00002_oo
ool2o`0002Sooooo0_l000000ooooooo0000o`00000Sooooo`;o00003?ooool000Kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo
00?o0000ooooooooool04_ooool2o`000003ooooool0003o000003Cooooo0_l0000Booooo`;o0000
:oooool2o`000003ooooool0003o000000_ooooo0_l0000`ooooo`Co00002_ooool2o`0000Kooooo
0_l0000Looooo`;o00003?ooool2o`0000Cooooo0_l0000Fooooo`;o00003?ooool002Wooooo0_l0
000Fooooo`;o0000:oooool2o`0000[ooooo0_l0000?ooooo`;o0000Eoooool2o`0001Cooooo0_l0
000Dooooo`;o00007?ooool2o`0000Oooooo0_l000000ooooooo0000o`000002o`0000?ooooo0ol0
000Tooooo`00:Oooool00ol0003oooooooooo`12ooooo`;o00002_ooool2o`0005Oooooo0_l0000?
ooooo`;o00002oooool2o`0002kooooo0_l0000Dooooo`;o000000?oooooo`000?l000001Oooool2
o`0001Sooooo0_l0000;ooooo`00:Oooool00ol0003oooooooooo`0>ooooo`;o00007Oooool2o`00
00Wooooo0_l00002ooooo`;o0000=_ooool2o`0002_ooooo1?l00002ooooo`;o00001Oooool2o`00
00[ooooo0_l00009ooooo`;o0000;_ooool2o`0001Kooooo0_l0000;ooooo`;o00004oooool2o`00
00_ooooo000Yooooo`03o`000?oooooooooo00Gooooo0_l00007ooooo`;o00002Oooool2o`0001;o
oooo0_l000000ooooooo0000o`000006ooooo`;o00000_ooool2o`0000;ooooo0_l0000;ooooo`;o
00000oooool2o`0001Oooooo0_l00007ooooo`;o00004oooool2o`0001Kooooo1?l00009ooooo`;o
00002_ooool2o`00057ooooo0_l0000;ooooo`;o00002?ooool2o`0001Kooooo000Yooooo`03o`00
0?oooooooooo00Gooooo0_l0000Booooo`;o00004oooool4o`0000kooooo0_l0000;ooooo`;o0000
0oooool2o`0001Cooooo0_l000000ooooooo0000o`00000Looooo`;o00006?ooool2o`0003?ooooo
0_l0000Jooooo`;o00002oooool2o`0000Cooooo0_l0000Iooooo`Co00005_ooool002Wooooo0_l0
000Nooooo`;o00003oooool2o`0001Sooooo0ol0000Mooooo`;o00002Oooool2o`0000;ooooo0_l0
0018ooooo`Co00001oooool2o`0000[ooooo0_l0000Jooooo`;o00001oooool2o`0000;ooooo0_l0
0004ooooo`;o00004oooool2o`0000Cooooo0_l0000Hooooo`00:Oooool00ol0003oooooooooo`0M
ooooo`;o00003?ooool2o`0001_ooooo0ol000000ooooooo0000o`00000Uooooo`;o00000_ooool2
o`0001Oooooo0_l00006ooooo`;o00001Oooool2o`00023ooooo1?l00007ooooo`;o00002Oooool2
o`0002Cooooo0_l0000Mooooo`;o00001Oooool2o`0000Gooooo0ol0000?ooooo`00:Oooool2o`00
00;ooooo0_l0000Cooooo`;o00001Oooool2o`0000cooooo0_l00003ooooo`Co000000So410@oooo
ooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`;o
00007oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01_ooool2o`0000Kooooo0_l00006ooooo`;o00001Oooool2o`0000Wooooo00?oV9RH
oa0@4?l000000ol00002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko0000o`00
0?lb<S;ok^k^01Sooooo0_l0000@ooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo0_l0000:ooooo`;o00000_oo
ool2o`0000gooooo0_l000001Om4A4Co0000o`000?lb<S;ogMgM00?o000000Co<S8bo`000?lb<S;o
k^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Yooooo`;o00000_ooool2o`0000co
oooo0_l00003ooooo`Co00002oooool2o`0000Gooooo0_l00006ooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:?ooool2
o`000004ob4Q8Oo^k^koooooodA4A0?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool2o`00023ooooo00?o410@okZj^_ooool00ol00002ooooo`04
ogMgMonHV9SooooooiRHV0;o00000_ooool01OmgMgOo0000o`000?nHV9SoMgMg00Sooooo0_l00008
ooooo`;o00005oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo0_l0000:ooooo`;o00000_ooool2o`0001;ooooo
00?oMgMgoc8b<_ooool00_l000001?nHV9SooooooiRHV?mgMgL3ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool002Wooooo00?o0000ooooooooool03oooool2o`0000?ooooo0_l000000ooooooo
0000o`00000:ooooo`;o00001Oooool2o`0000Kooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@00;ooooo0_l00003ooooo`03oa0@4?oooooooooo02Kooooo0_l000000onH
V9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@02cooooo00Go0000oooooooooooooooooa0@4003ooooo`;o00000_ooool01Ol@413ooooo
oooooooooooo410@00;ooooo0_l00004ooooo`;o00000_ooool2o`0000?ooooo0ol0000=ooooo`;o
00001Oooool7o`000003ooooool@413ooooo00;ooooo00Go410@oooooooooooooooooa0@4003oooo
o`03oa0@4?oooooooooo02_ooooo00Co0000oooooooooooo410@0oooool01Ol@413ooooooooooooo
oooo410@00?ooooo00?o410@ooooooooool00Oooool002Wooooo1?l0000Aooooo`;o00000oooool2
o`0000[ooooo0_l0000=ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0002ooooo`;o00000oooool00ol0003oooooooooo`0Yooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go
0000ooooooooooooooooo`000003ooooo`;o00000_ooool00ol0003oooooooooo`0Vooooo`;o0000
00?oooooojVYZOl@41000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000002ooooo`;o00002?ooool2o`0000?ooooo0_l0000>ooooo`;o00001Oooool01Om4
A4CogMgMooooool0003ooooo00;o000000Coooooo`000?oooooooooo0_l00003ooooo`05o`000?oo
ooooooooooooool00000;?ooool01OmgMgOo<S8boooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo007ooooo000Yooooo`Co00000_ooool2o`0000Oo
oooo0_l00004ooooo`;o00007?ooool3o`0000Cooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooo000000;o00005?ooool2o`0001Kooooo00?oMgMgofIVI_ooool00_ooool01_l0
003ooooooooooooooooo0000ooooo`Co00000_ooool00ol0003oooooooooo`0Cooooo`;o00004Ooo
ool2o`000003oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000001oooool2o`0001Kooooo0_l00007ooooo`04omgMgOmEEEGoooooo`00
00Cooooo00?o0000ooooooooool00_l00003ooooo`05o`000?ooooooooooooooool000003_ooool2
o`0001Wooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000?ooooo000Yooooo`03o`000?oooooooooo00?ooooo
0_l00007ooooo`;o00000_ooool2o`0001kooooo0ol00004ooooo`05oa0@4?ooooooooooooooool@
41000oooool01Ol@413oooooo`000?l0003o410@01Cooooo0_l0000Gooooo`05o`000?oooooooooo
ooooool@41000oooool01Ol@413oooooo`000?l0003o410@00?ooooo00?o410@ooooooooool04ooo
ool2o`000003ooooool0003o000000Wooooo0_l00006ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go
410@o`000?l0003ooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001oooool2o`0000_o
oooo0_l00007ooooo`Co000000?oooooo`000?l000001Oooool01?mgMgOoc<c<o`000?ooool2o`00
0003ooooool@413ooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooo
oooo00cooooo0_l0000Aooooo`;o00001?ooool3o`0000Kooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool002Wooooo00?o0000ooooooooool00_oo
ool2o`0000cooooo0_l0000<ooooo`;o00002Oooool2o`0000Oooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHo`000?l0003oMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Uooooo`;o
00000_ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02Oooool2o`0000gooooo0_l00009ooooo`;o00000ooo
ool2o`000003oooooonj^[[o000000?ooooo00GoMgMgo`000?l0003oV9RHogMgM`03ooooo`04ogMg
MonHV9SooooooiRHV0Co00004Oooool2o`0000Oooooo0_l00003ooooo`;o00001?ooool2o`000003
odA4A?l0003ooooo00;o000000KoooooogMgMonHV9SooooooiRHV?mgMgL3ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool4o`00017ooooo0_l00004ooooo`?o00001_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool00ol0003ooooo
ooooo`02ooooo`;o00006_ooool2o`0000Kooooo0_l000000ooooooo0000o`000005ooooo`03oeEE
EOmVIVKo000000Cooooo00?ok^k^oc8b<_l000000_l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h09Oooool2o`0000;ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Wooooo0_l0000Hooooo`;o000000?o
ooooo`000?l000000ol000000ol@413oZJVYooooo`02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool01?o^k^ko<S8bo`000?lb<S84o`0000cooooo0_l0000Gooooo`;o000000?oMgMgo`000?oo
ool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`;o00006oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool002Wooooo0_l0000Wooooo`;o00004_ooool2o`0001Gooooo0_l0
001Eooooo`;o00009?ooool2o`0002Kooooo0_l0000Gooooo`;o000000?oooooo`000?l000003_oo
ool2o`0001Sooooo000Yooooo`03o`000?oooooooooo03?ooooo0_l0000>ooooo`;o00003?ooool2
o`0002_ooooo0_l0000Looooo`;o0000F?ooool2o`0001Oooooo0_l000000ooooooo0000o`00000>
ooooo`;o00006?ooool002Wooooo00?o0000ooooooooool0<oooool2o`0000kooooo0_l0000Hoooo
o`;o00000oooool2o`0001[ooooo0_l0000Dooooo`;o00000_ooool2o`0000;ooooo0_l0000Roooo
o`;o00008Oooool2o`0003Wooooo0_l0000Looooo`00:Oooool00ol0003oooooooooo`0Jooooo`;o
00002Oooool2o`0002Wooooo0_l0000;ooooo`;o00000oooool2o`0001gooooo0_l0000Aooooo`;o
00000_ooool2o`0001_ooooo0_l00009ooooo`;o00000oooool2o`0000Kooooo0_l0000Dooooo`;o
0000;?ooool2o`0000_ooooo0_l0000Looooo`00:Oooool00ol0003oooooooooo`0Jooooo`;o0000
2Oooool2o`0000Cooooo0_l00002ooooo`;o00007oooool2o`0002Gooooo0_l000000ooooooo0000
o`000005ooooo`;o00008Oooool2o`0000oooooo0_l00004ooooo`;o00002?ooool2o`0000Cooooo
1?l0000booooo`;o00003_ooool2o`000003ooooool0003o0000013ooooo0_l0000Dooooo`008Ooo
ooooo`0004Co00001?ooool002Wooooo00?o0000ooooooooool02?ooool2o`0000cooooo00?o0000
ooooooooool02Oooool01?l0003oooooo`000?l00008ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool00_l00008ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_l0
0007ooooo`04o`000?ooooooooooooooo`;o00001_ooool2o`0000_ooooo0ol00009ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`04o`00
0?ooooooooooooooo`;o00001_ooool01?l0003oooooooooooooool2o`0000Kooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`02ooooo`;o00001_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool3o`0000[ooooo0ol00009oooo
o`03o`000?oooooooooo00Oooooo0ol0000;ooooo`03o`000?oooooooooo00[ooooo000Yooooo`;o
00003Oooool2o`0000Wooooo0_l0000?ooooo`;o00003?ooool2o`0000;ooooo00?o0000oooooooo
ool00_l0000/ooooo`;o00002oooool00ol0003oooooooooo`0Aooooo`;o00007oooool2o`0000Ko
oooo00Co0000oooooooooooooooo0_l0000>ooooo`;o00001oooool2o`0001kooooo00?o0000oooo
ooooool02_ooool2o`0000_ooooo0_l0000Qooooo`03o`000?oooooooooo00[ooooo000Yooooo`;o
00001oooool2o`0000Cooooo0_l00009ooooo`;o00003oooool2o`0000?ooooo0_l00005ooooo`Co
0000:oooool2o`0001Oooooo0_l0000>ooooo`;o0000>oooool2o`0002Cooooo0_l00006ooooo`;o
00007oooool2o`0000_ooooo1?l00004ooooo`;o00003Oooool002Wooooo00Co0000ooooool0003o
00001Oooool2o`0000Gooooo0_l0000Nooooo`;o00001Oooool2o`0002Gooooo0_l00006ooooo`;o
00002Oooool2o`0000cooooo0_l0000Mooooo`;o0000=?ooool2o`0000Gooooo0_l00004ooooo`;o
00002_ooool2o`0000?ooooo0_l00006ooooo`;o00003?ooool2o`00017ooooo0_l0000;ooooo`Co
00001?ooool2o`0000gooooo000Yooooo`Co00003?ooool2o`0004cooooo0_l00003ooooo`;o0000
1Oooool2o`0000Gooooo0_l00008ooooo`?o00003?ooool2o`0000Cooooo0_l0000<ooooo`Go0000
9_ooool2o`0000Wooooo0_l00005ooooo`;o00001?ooool2o`0000[ooooo0_l00002ooooo`;o0000
2oooool3o`0000Oooooo0_l0000eooooo`00:Oooool00ol0003oooooooooo`0=ooooo`;o00000_oo
ool2o`00047ooooo0_l0000:ooooo`?o00001?ooool2o`0000Sooooo0_l00005ooooo`?o00002?oo
ool2o`0000;ooooo0_l00004ooooo`;o00003_ooool3o`0002Kooooo0_l0000Vooooo`;o00002ooo
ool3o`00027ooooo0_l0000Kooooo`00:Oooool00ol0003oooooooooo`0=ooooo`;o00000_ooool2
o`0000;ooooo0_l0000Kooooo`;o000000?oooooo`000?l000007Oooool2o`0000_ooooo0_l00003
ooooo`;o00002Oooool2o`0000[ooooo0_l00004ooooo`;o00001?ooool2o`0008Cooooo0_l0000>
ooooo`;o00006oooool002Wooooo00?o0000ooooooooool05Oooool2o`0001?ooooo0_l00005oooo
o`?o000000?oooooo`000?l000002?ooool2o`0002Gooooo0_l0000Eooooo`;o00002_ooool2o`00
06Cooooo0_l00003ooooo`;o00006Oooool2o`0001Sooooo0_l0000Aooooo`00:Oooool00ol0003o
ooooooooo`0Zooooo`;o00001Oooool2o`0000cooooo0_l0000Cooooo`;o00006oooool2o`00067o
oooo0_l0000Iooooo`;o00000oooool2o`0000;ooooo0_l0000Booooo`;o00001?ooool2o`0000co
oooo0_l00007ooooo`;o00004Oooool002Wooooo0_l0000;ooooo`;o00004?ooool2o`0003Kooooo
0_l0000;ooooo`;o00003_ooool2o`0000kooooo0_l0000:ooooo`;o0000AOooool2o`0002;ooooo
0ol00003ooooo`;o00003?ooool2o`0000Cooooo0_l0000<ooooo`;o00006_ooool002Wooooo00?o
0000ooooooooool02_ooool2o`00013ooooo0_l00013ooooo`;o00002oooool2o`00017ooooo0ol0
0009ooooo`;o00004Oooool2o`0000Gooooo0_l00002ooooo`;o0000;_ooool2o`0000Sooooo0_l0
000Booooo`;o00000oooool3o`0002Oooooo0_l0000Booooo`00:Oooool00ol0003oooooooooo`0H
ooooo`;o00006?ooool2o`0000[ooooo0_l00005ooooo`;o00002?ooool2o`0001cooooo0ol0000B
ooooo`;o00007?ooool2o`0000Gooooo0_l00002ooooo`;o0000;_ooool2o`0000Sooooo0_l0000B
ooooo`;o00001?ooool2o`000003ooooool0003o0000027ooooo0_l000000ooooooo0000o`000003
ooooo`;o00003Oooool002Wooooo00?o0000ooooooooool06?ooool2o`0000gooooo0_l00003oooo
o`;o00001?ooool2o`0000[ooooo0_l00005ooooo`;o00002?ooool2o`0001cooooo0_l0000Soooo
o`;o00001_ooool2o`00047ooooo0_l00007ooooo`;o00002_ooool2o`0000[ooooo0_l00002oooo
o`;o00008Oooool2o`0000Kooooo0_l0000=ooooo`00:Oooool00ol0003oooooooooo`0Dooooo`;o
00004Oooool2o`0000?ooooo0_l0000/ooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo
0000o`00000Fooooo`;o00003_ooool2o`000003ooooool0003o000000Kooooo0_l00003ooooo`;o
0000??ooool2o`0000Oooooo0ol00009ooooo`;o00002?ooool4o`0000Cooooo0_l00007ooooo`;o
00001_ooool2o`0002Gooooo000Yooooo`;o00005Oooool2o`0000Wooooo0_l0000Fooooo`;o0000
2oooool2o`0001;ooooo1?l00002ooooo`;o00001?ooool2o`000003ooooool0003o000000gooooo
0_l00007ooooo`;o00003_ooool2o`0000kooooo0_l0000Fooooo`;o00008?ooool2o`0000cooooo
0_l0000Cooooo`;o00001_ooool2o`0000Oooooo0_l00006ooooo`;o00004Oooool2o`0001;ooooo
000Yooooo`03o`000?oooooooooo00[ooooo0_l0000Cooooo`Co00001Oooool2o`0000gooooo0_l0
000;ooooo`;o00004_ooool2o`0001cooooo0_l0000:ooooo`;o000000?oooooo`000?l000003?oo
ool2o`0002;ooooo0_l0000?ooooo`;o00003oooool2o`0004gooooo0_l0000Booooo`00:Oooool0
0ol0003oooooooooo`0:ooooo`;o00005Oooool3o`0000Cooooo0_l0000<ooooo`;o00005Oooool2
o`0003?ooooo0_l000000ooooooo0000o`00000<ooooo`;o000000?oooooo`000?l000002_ooool2
o`0000_ooooo0_l0000Gooooo`;o00002_ooool2o`0002Cooooo0_l0000Kooooo`;o00001_ooool2
o`0001_ooooo000Yooooo`03o`000?oooooooooo01Sooooo0_l00008ooooo`;o00004_ooool2o`00
01Gooooo0_l0000hooooo`;o00003Oooool2o`0000[ooooo0_l0000;ooooo`;o00008oooool2o`00
02Cooooo0_l0000Kooooo`;o00001_ooool2o`0001_ooooo000Yooooo`03o`000?oooooooooo01So
oooo0_l0001?ooooo`;o00007?ooool2o`0000cooooo0_l00009ooooo`;o00007Oooool2o`0007_o
oooo000Yooooo`;o0000A_ooool2o`0001;ooooo0_l0000>ooooo`;o00009oooool2o`000003oooo
ool0003o000000Wooooo0_l0000Kooooo`Co0000Noooool002Wooooo00?o0000ooooooooool01ooo
ool2o`0001Oooooo0_l0000Iooooo`;o00002?ooool2o`0000kooooo0_l00002ooooo`;o00004Ooo
ool2o`0002Cooooo0_l000000ooooooo0000o`00000Vooooo`;o00002_ooool2o`00057ooooo0_l0
0009ooooo`;o00004oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00Oooooo
0_l0000Gooooo`;o00000oooool2o`0000cooooo0_l00005ooooo`?o00006?ooool2o`0001Gooooo
0_l0000Fooooo`;o00004Oooool2o`00033ooooo0ol0000Oooooo`;o00001?ooool2o`0002Wooooo
0_l00009ooooo`;o00004oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`0Uooooo`;o00001oooool2o`0000?ooooo0_l00005ooooo`;o0000:?ooool2o`0001[o
oooo0_l00002ooooo`;o00004Oooool2o`00037ooooo0_l0000Oooooo`;o00001?ooool2o`0002Oo
oooo0_l0000Pooooo`001_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^
k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o0000;?ooool2o`0003Co
oooo0_l0000Jooooo`;o00005oooool2o`0003;ooooo0_l0001;ooooo`;o00008?ooool000Kooooo
00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_oo
ool01?ooool5o`0005[ooooo0_l0000Xooooo`;o00004Oooool2o`0000_ooooo0_l0000Uooooo`;o
00007?ooool2o`0001Kooooo0_l0000Cooooo`;o00008_ooool000Kooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005oooo
o`03o`000?oooooooooo04kooooo0_l0000<ooooo`;o00003?ooool2o`0000Wooooo0_l00005oooo
o`;o00002?ooool2o`0001kooooo0_l0000Dooooo`;o0000:oooool4o`0001Kooooo0_l0000Coooo
o`;o00008_ooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0mooooo`;o00003?ooool2o`00
0003ooooool0003o000000cooooo0_l000000ooooooo0000o`000009ooooo`;o00002Oooool2o`00
00Gooooo0_l0000Fooooo`;o00004oooool2o`0000Gooooo0_l0000:ooooo`;o00001_ooool2o`00
01cooooo0_l00005ooooo`;o0000DOooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo03gooooo0_l00009ooooo`;o000000?oooooo`000?l000003oooool2o`000003ooooool0003o
000000Cooooo0_l0000Hooooo`;o00004oooool2o`0001?ooooo0_l00005ooooo`;o00001_ooool2
o`0000[ooooo0_l0000Looooo`;o00008Oooool2o`0000;ooooo0_l0000aooooo`001_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_oo
ool00ol0003oooooooooo`0@ooooo`;o0000=?ooool4o`0001_ooooo0_l00008ooooo`?o00003Ooo
ool2o`0000oooooo0_l0000Nooooo`;o00001_ooool2o`0004_ooooo0_l00002ooooo`;o0000<Ooo
ool002Wooooo0_l00003ooooo`;o00003?ooool2o`0002oooooo0_l00003ooooo`;o00009oooool3
o`0001kooooo0_l0000Nooooo`;o0000;oooool2o`0003Cooooo0_l0000Sooooo`00:Oooool00ol0
003oooooooooo`02ooooo`;o0000?Oooool2o`0007[ooooo0_l0000Rooooo`;o0000=?ooool2o`00
02?ooooo000Yooooo`03o`000?oooooooooo00oooooo0_l0000_ooooo`;o00001oooool2o`0000Go
oooo0_l0000<ooooo`;o0000Boooool2o`00013ooooo0_l0000Zooooo`;o00000_ooool2o`0004go
oooo000Yooooo`03o`000?oooooooooo00Cooooo0_l000000ooooooo0000o`000004o`0000;ooooo
0_l00002ooooo`;o00004_ooool2o`0001Oooooo0_l00004ooooo`;o000000?oooooo`000?l00000
1Oooool2o`0000Wooooo0_l000000ooooooo0000o`00000?ooooo`;o0000>_ooool2o`0001Gooooo
0_l0000Uooooo`;o00000_ooool2o`0004gooooo000Yooooo`03o`000?oooooooooo00Cooooo0_l0
00000ooooooo0000o`000004o`0000Kooooo0_l0000Booooo`;o00007Oooool2o`0001?ooooo0_l0
000Booooo`;o0000DOooool2o`0007Sooooo000Yooooo`;o0000noooool2o`0000_ooooo0_l0000c
ooooo`00:Oooool00ol0003oooooooooo`3`ooooo`;o00002?ooool2o`0000_ooooo0_l0000coooo
o`00:Oooool00ol0003oooooooooo`2Xooooo`;o0000>Oooool3o`0000[ooooo0_l0001:ooooo`00
:Oooool00ol0003oooooooooo`0Jooooo`Co00006_ooool2o`0006kooooo0_l0000@ooooo`;o0000
9oooool3o`0005Kooooo000Yooooo`03o`000?oooooooooo01[ooooo1?l0000Jooooo`;o0000N?oo
ool2o`0000Kooooo0_l0000Zooooo`;o0000E?ooool002Wooooo0_l0000Qooooo`;o0000Hoooool2
o`0001Kooooo0_l0000Booooo`Co00008Oooool2o`0000kooooo0_l0000cooooo`;o00003oooool2
o`0000kooooo000Yooooo`03o`000?oooooooooo023ooooo0_l0001@ooooo`;o00004Oooool2o`00
01Kooooo0_l0000Booooo`Co00008Oooool2o`0004?ooooo0_l0000?ooooo`;o00003_ooool002Wo
oooo00?o0000ooooooooool0L_ooool2o`0004[ooooo0_l0001looooo`00:Oooool00ol0003ooooo
ooooo`2>ooooo`;o0000;_ooool2o`0001_ooooo0_l0001Oooooo`00:Oooool00ol0003ooooooooo
o`2>ooooo`;o00009?ooool2o`0002Gooooo0_l0001Oooooo`00:Oooool2o`0005[ooooo0_l0001I
ooooo`;o00003Oooool2o`0003_ooooo0_l0000jooooo`00:Oooool00ol0003oooooooooo`17oooo
o`;o00004?ooool2o`0006Sooooo0_l0000/ooooo`;o00003Oooool2o`0002Sooooo0_l0000@oooo
o`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool00ol0003oooooooooo`13ooooo`;o00000_ooool2o`0002_ooooo0_l0001k
ooooo`;o0000=oooool2o`00013ooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`13ooooo`;o00003_ooool2
o`0001oooooo0_l0000Dooooo`;o0000BOooool2o`0006Gooooo000>ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`03ooooo`?o00008_ooool2o`0002oooooo0_l0000e
ooooo`;o00001Oooool2o`0004;ooooo0_l0001Uooooo`003_ooool01Ol0003ooooooooooooooooo
000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Rooooo`;o0000KOooool2
o`0008gooooo0_l0000Jooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo8Oooool2o`0001[ooooo000>
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0?oooooo?Oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0j?ooool2o`0005;ooooo000>ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0003Yooooo`;o0000D_ooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0Eoooool2o`000>?ooooo
000Yooooo`;o0000F?ooool2o`000>?ooooo000Yooooo`03o`000?oooooooooo0;Kooooo0_l00024
ooooo`00:Oooool00ol0003oooooooooo`2fooooo`;o0000Q?ooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooo
oolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400=
ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool0
00Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05o`000?oooooooooo
ooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003_oo
ool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooo
oolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooo
oc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo
?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo
?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Oooooo`Co000000?o410@oooo
ooooool00oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`?o0000
oooooolmooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Oooooo`03oeEEEOmVIVKo00000?ooooooAoooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .38281 Mdot
.02762 .24767 Mdot
.02952 .28575 Mdot
.03143 .33091 Mdot
.03333 .2557 Mdot
.03524 .33714 Mdot
.03714 .29272 Mdot
.03905 .33816 Mdot
.04095 .43842 Mdot
.04286 .34127 Mdot
.04476 .25945 Mdot
.04667 .28687 Mdot
.04857 .3788 Mdot
.05048 .28433 Mdot
.05238 .28904 Mdot
.05429 .26394 Mdot
.05619 .36868 Mdot
.0581 .3857 Mdot
.06 .35485 Mdot
.0619 .28214 Mdot
.06381 .37994 Mdot
.06571 .25041 Mdot
.06762 .26954 Mdot
.06952 .39397 Mdot
.07143 .22571 Mdot
.07333 .35041 Mdot
.07524 .26156 Mdot
.07714 .3568 Mdot
.07905 .25469 Mdot
.08095 .24671 Mdot
.08286 .39167 Mdot
.08476 .43907 Mdot
.08667 .38579 Mdot
.08857 .37593 Mdot
.09048 .30526 Mdot
.09238 .37244 Mdot
.09429 .3445 Mdot
.09619 .34147 Mdot
.0981 .24121 Mdot
.1 .25651 Mdot
.1019 .22898 Mdot
.10381 .34923 Mdot
.10571 .24323 Mdot
.10762 .36254 Mdot
.10952 .39398 Mdot
.11143 .3497 Mdot
.11333 .31291 Mdot
.11524 .43698 Mdot
.11714 .24579 Mdot
.11905 .2763 Mdot
.12095 .43442 Mdot
.12286 .24255 Mdot
.12476 .23045 Mdot
.12667 .26031 Mdot
.12857 .24431 Mdot
.13048 .42469 Mdot
.13238 .3326 Mdot
.13429 .37026 Mdot
.13619 .41008 Mdot
.1381 .39706 Mdot
.14 .35707 Mdot
.1419 .42867 Mdot
.14381 .24037 Mdot
.14571 .27058 Mdot
.14762 .39962 Mdot
.14952 .43341 Mdot
.15143 .3455 Mdot
.15333 .25863 Mdot
.15524 .34837 Mdot
.15714 .40337 Mdot
.15905 .38226 Mdot
.16095 .31653 Mdot
.16286 .3405 Mdot
.16476 .34495 Mdot
.16667 .24065 Mdot
.16857 .30966 Mdot
.17048 .23024 Mdot
.17238 .36582 Mdot
.17429 .23239 Mdot
.17619 .27849 Mdot
.1781 .4144 Mdot
.18 .25517 Mdot
.1819 .33927 Mdot
.18381 .33912 Mdot
.18571 .38472 Mdot
.18762 .28315 Mdot
.18952 .26285 Mdot
.19143 .28675 Mdot
.19333 .35985 Mdot
.19524 .25791 Mdot
.19714 .22624 Mdot
.19905 .4254 Mdot
.20095 .2871 Mdot
.20286 .32328 Mdot
.20476 .26583 Mdot
.20667 .43922 Mdot
.20857 .29238 Mdot
.21048 .43173 Mdot
.21238 .2217 Mdot
.21429 .36807 Mdot
.21619 .36933 Mdot
.2181 .33668 Mdot
.22 .29797 Mdot
.2219 .34578 Mdot
.22381 .41545 Mdot
.22571 .37066 Mdot
.22762 .38155 Mdot
.22952 .34088 Mdot
.23143 .28961 Mdot
.23333 .40297 Mdot
.23524 .31774 Mdot
.23714 .3325 Mdot
.23905 .43933 Mdot
.24095 .34619 Mdot
.24286 .37347 Mdot
.24476 .32822 Mdot
.24667 .36375 Mdot
.24857 .42201 Mdot
.25048 .43239 Mdot
.25238 .32056 Mdot
.25429 .37527 Mdot
.25619 .399 Mdot
.2581 .33659 Mdot
.26 .24558 Mdot
.2619 .40433 Mdot
.26381 .31837 Mdot
.26571 .32928 Mdot
.26762 .45692 Mdot
.26952 .32361 Mdot
.27143 .28408 Mdot
.27333 .27649 Mdot
.27524 .3479 Mdot
.27714 .25484 Mdot
.27905 .35276 Mdot
.28095 .2662 Mdot
.28286 .23091 Mdot
.28476 .33934 Mdot
.28667 .28734 Mdot
.28857 .34276 Mdot
.29048 .36683 Mdot
.29238 .27511 Mdot
.29429 .45603 Mdot
.29619 .33756 Mdot
.2981 .35683 Mdot
.3 .36976 Mdot
.3019 .31369 Mdot
.30381 .40171 Mdot
.30571 .44317 Mdot
.30762 .34257 Mdot
.30952 .30807 Mdot
.31143 .38684 Mdot
.31333 .32676 Mdot
.31524 .32153 Mdot
.31714 .39835 Mdot
.31905 .30746 Mdot
.32095 .37292 Mdot
.32286 .29968 Mdot
.32476 .23186 Mdot
.32667 .4241 Mdot
.32857 .34056 Mdot
.33048 .30961 Mdot
.33238 .30069 Mdot
.33429 .23376 Mdot
.33619 .23285 Mdot
.3381 .39755 Mdot
.34 .24227 Mdot
.3419 .37867 Mdot
.34381 .40753 Mdot
.34571 .4162 Mdot
.34762 .3429 Mdot
.34952 .31141 Mdot
.35143 .3215 Mdot
.35333 .29001 Mdot
.35524 .31899 Mdot
.35714 .25759 Mdot
.35905 .32569 Mdot
.36095 .3875 Mdot
.36286 .44595 Mdot
.36476 .36742 Mdot
.36667 .32601 Mdot
.36857 .25137 Mdot
.37048 .27894 Mdot
.37238 .23427 Mdot
.37429 .32876 Mdot
.37619 .2351 Mdot
.3781 .27569 Mdot
.38 .43788 Mdot
.3819 .45886 Mdot
.38381 .44009 Mdot
.38571 .22715 Mdot
.38762 .25563 Mdot
.38952 .36829 Mdot
.39143 .31246 Mdot
.39333 .31037 Mdot
.39524 .41038 Mdot
.39714 .36559 Mdot
.39905 .28319 Mdot
.40095 .27759 Mdot
.40286 .30545 Mdot
.40476 .38172 Mdot
.40667 .36937 Mdot
.40857 .29592 Mdot
.41048 .30263 Mdot
.41238 .32158 Mdot
.41429 .25033 Mdot
.41619 .3598 Mdot
.4181 .36377 Mdot
.42 .33104 Mdot
.4219 .35416 Mdot
.42381 .3318 Mdot
.42571 .3182 Mdot
.42762 .25425 Mdot
.42952 .33542 Mdot
.43143 .36475 Mdot
.43333 .41602 Mdot
.43524 .30312 Mdot
.43714 .37523 Mdot
.43905 .35808 Mdot
.44095 .23445 Mdot
.44286 .2875 Mdot
.44476 .39565 Mdot
.44667 .27524 Mdot
.44857 .36226 Mdot
.45048 .40915 Mdot
.45238 .41678 Mdot
.45429 .41163 Mdot
.45619 .26904 Mdot
.4581 .26223 Mdot
.46 .25693 Mdot
.4619 .28866 Mdot
.46381 .28472 Mdot
.46571 .41303 Mdot
.46762 .25991 Mdot
.46952 .29743 Mdot
.47143 .3616 Mdot
.47333 .26483 Mdot
.47524 .26424 Mdot
.47714 .38186 Mdot
.47905 .33252 Mdot
.48095 .32947 Mdot
.48286 .34319 Mdot
.48476 .35521 Mdot
.48667 .42672 Mdot
.48857 .30468 Mdot
.49048 .40841 Mdot
.49238 .38215 Mdot
.49429 .43861 Mdot
.49619 .26048 Mdot
.4981 .27375 Mdot
.5 .31847 Mdot
.5019 .38185 Mdot
.50381 .23636 Mdot
.50571 .26845 Mdot
.50762 .32851 Mdot
.50952 .31563 Mdot
.51143 .29268 Mdot
.51333 .35111 Mdot
.51524 .31012 Mdot
.51714 .24456 Mdot
.51905 .31398 Mdot
.52095 .3503 Mdot
.52286 .4282 Mdot
.52476 .25208 Mdot
.52667 .2638 Mdot
.52857 .40785 Mdot
.53048 .31297 Mdot
.53238 .31257 Mdot
.53429 .39235 Mdot
.53619 .30375 Mdot
.5381 .2894 Mdot
.54 .35363 Mdot
.5419 .3308 Mdot
.54381 .3541 Mdot
.54571 .24143 Mdot
.54762 .34052 Mdot
.54952 .25021 Mdot
.55143 .29763 Mdot
.55333 .33714 Mdot
.55524 .28962 Mdot
.55714 .43693 Mdot
.55905 .25479 Mdot
.56095 .3692 Mdot
.56286 .23684 Mdot
.56476 .2659 Mdot
.56667 .32951 Mdot
.56857 .33731 Mdot
.57048 .31345 Mdot
.57238 .33642 Mdot
.57429 .2754 Mdot
.57619 .28327 Mdot
.5781 .36744 Mdot
.58 .32754 Mdot
.5819 .41361 Mdot
.58381 .45927 Mdot
.58571 .39879 Mdot
.58762 .31528 Mdot
.58952 .39519 Mdot
.59143 .31757 Mdot
.59333 .39662 Mdot
.59524 .38653 Mdot
.59714 .38658 Mdot
.59905 .30019 Mdot
.60095 .46808 Mdot
.60286 .25703 Mdot
.60476 .27618 Mdot
.60667 .33777 Mdot
.60857 .43876 Mdot
.61048 .2252 Mdot
.61238 .296 Mdot
.61429 .43489 Mdot
.61619 .34253 Mdot
.6181 .26749 Mdot
.62 .3245 Mdot
.6219 .37483 Mdot
.62381 .36312 Mdot
.62571 .37115 Mdot
.62762 .32606 Mdot
.62952 .39634 Mdot
.63143 .36566 Mdot
.63333 .38767 Mdot
.63524 .30343 Mdot
.63714 .23204 Mdot
.63905 .3201 Mdot
.64095 .46703 Mdot
.64286 .28207 Mdot
.64476 .35999 Mdot
.64667 .33186 Mdot
.64857 .23164 Mdot
.65048 .25441 Mdot
.65238 .29023 Mdot
.65429 .30921 Mdot
.65619 .38132 Mdot
.6581 .30047 Mdot
.66 .27885 Mdot
.6619 .26536 Mdot
.66381 .29677 Mdot
.66571 .27381 Mdot
.66762 .32187 Mdot
.66952 .25291 Mdot
.67143 .32916 Mdot
.67333 .24215 Mdot
.67524 .30174 Mdot
.67714 .25176 Mdot
.67905 .25153 Mdot
.68095 .34703 Mdot
.68286 .28117 Mdot
.68476 .27246 Mdot
.68667 .40731 Mdot
.68857 .25574 Mdot
.69048 .3009 Mdot
.69238 .24053 Mdot
.69429 .32396 Mdot
.69619 .33566 Mdot
.6981 .45583 Mdot
.7 .28892 Mdot
.7019 .39869 Mdot
.70381 .36205 Mdot
.70571 .26639 Mdot
.70762 .37476 Mdot
.70952 .3276 Mdot
.71143 .28867 Mdot
.71333 .29143 Mdot
.71524 .46981 Mdot
.71714 .40579 Mdot
.71905 .26048 Mdot
.72095 .22906 Mdot
.72286 .23946 Mdot
.72476 .32096 Mdot
.72667 .25105 Mdot
.72857 .27452 Mdot
.73048 .34313 Mdot
.73238 .31728 Mdot
.73429 .41046 Mdot
.73619 .35156 Mdot
.7381 .3615 Mdot
.74 .3744 Mdot
.7419 .43505 Mdot
.74381 .3329 Mdot
.74571 .37035 Mdot
.74762 .24505 Mdot
.74952 .25901 Mdot
.75143 .38731 Mdot
.75333 .26425 Mdot
.75524 .22861 Mdot
.75714 .40577 Mdot
.75905 .34229 Mdot
.76095 .3828 Mdot
.76286 .29122 Mdot
.76476 .28189 Mdot
.76667 .35736 Mdot
.76857 .3132 Mdot
.77048 .22845 Mdot
.77238 .40497 Mdot
.77429 .28828 Mdot
.77619 .34732 Mdot
.7781 .36549 Mdot
.78 .27528 Mdot
.7819 .43961 Mdot
.78381 .41699 Mdot
.78571 .40257 Mdot
.78762 .23075 Mdot
.78952 .38029 Mdot
.79143 .28102 Mdot
.79333 .37848 Mdot
.79524 .32889 Mdot
.79714 .30105 Mdot
.79905 .27161 Mdot
.80095 .31432 Mdot
.80286 .2924 Mdot
.80476 .25946 Mdot
.80667 .3145 Mdot
.80857 .28388 Mdot
.81048 .30703 Mdot
.81238 .33264 Mdot
.81429 .31843 Mdot
.81619 .39707 Mdot
.8181 .33878 Mdot
.82 .32383 Mdot
.8219 .29839 Mdot
.82381 .28996 Mdot
.82571 .37856 Mdot
.82762 .29295 Mdot
.82952 .33309 Mdot
.83143 .39276 Mdot
.83333 .36848 Mdot
.83524 .30336 Mdot
.83714 .28953 Mdot
.83905 .38152 Mdot
.84095 .3837 Mdot
.84286 .3419 Mdot
.84476 .33076 Mdot
.84667 .29412 Mdot
.84857 .42127 Mdot
.85048 .32033 Mdot
.85238 .31305 Mdot
.85429 .34943 Mdot
.85619 .33098 Mdot
.8581 .43646 Mdot
.86 .26661 Mdot
.8619 .25718 Mdot
.86381 .24207 Mdot
.86571 .24532 Mdot
.86762 .32069 Mdot
.86952 .26962 Mdot
.87143 .31327 Mdot
.87333 .40842 Mdot
.87524 .29659 Mdot
.87714 .40314 Mdot
.87905 .29648 Mdot
.88095 .29301 Mdot
.88286 .35005 Mdot
.88476 .26026 Mdot
.88667 .32748 Mdot
.88857 .34408 Mdot
.89048 .33817 Mdot
.89238 .3162 Mdot
.89429 .23087 Mdot
.89619 .26941 Mdot
.8981 .39547 Mdot
.9 .34211 Mdot
.9019 .40972 Mdot
.90381 .37963 Mdot
.90571 .45599 Mdot
.90762 .34781 Mdot
.90952 .29421 Mdot
.91143 .27016 Mdot
.91333 .30502 Mdot
.91524 .39822 Mdot
.91714 .33671 Mdot
.91905 .35267 Mdot
.92095 .30345 Mdot
.92286 .36716 Mdot
.92476 .35168 Mdot
.92667 .33846 Mdot
.92857 .3759 Mdot
.93048 .43446 Mdot
.93238 .25611 Mdot
.93429 .3079 Mdot
.93619 .24325 Mdot
.9381 .26937 Mdot
.94 .32175 Mdot
.9419 .27601 Mdot
.94381 .26412 Mdot
.94571 .26441 Mdot
.94762 .32226 Mdot
.94952 .36053 Mdot
.95143 .43262 Mdot
.95333 .25387 Mdot
.95524 .39522 Mdot
.95714 .35618 Mdot
.95905 .3557 Mdot
.96095 .29537 Mdot
.96286 .36461 Mdot
.96476 .28926 Mdot
.96667 .25022 Mdot
.96857 .40611 Mdot
.97048 .39378 Mdot
.97238 .35261 Mdot
.97429 .27141 Mdot
.97619 .24905 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo03Wooooo0_l0003oooooo`;ooooo0006ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`0iooooo`;o0000ooooool2ooooo`001_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo00cooooo0_l0000Vooooo`;o0000>oooool2o`0004Kooooo0_l0
0021ooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^
kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool2o`0000Oooooo0_l0
0006ooooo`;o00003?ooool2o`0000Oooooo0_l0000Jooooo`;o00007oooool2o`0004Kooooo0_l0
000Qooooo`;o00002Oooool2o`0000?ooooo0_l00004ooooo`;o00008?ooool2o`0002Kooooo0006
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol0000Eooooo`;o00001_ooool2o`0000cooooo1?l0000Qooooo`;o00002ooo
ool2o`000004ooooool0003o0000o`0005kooooo0_l00002ooooo`;o00005Oooool2o`0000Wooooo
0_l00003ooooo`;o00001?ooool2o`00023ooooo0_l0000Vooooo`001_ooool01Ol0003ooooooooo
oooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool0;Oooool2o`0002kooooo0_l000001?oooooo0000o`000?l00009oooo
o`Co00004_ooool2o`0001?ooooo0_l0000Aooooo`;o00005Oooool2o`0000;ooooo0_l0001eoooo
o`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo02?ooooo0_l00017ooooo`Co00004_ooool2o`00
01?ooooo0_l0000Aooooo`;o0000<Oooool2o`0005gooooo0006ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Dooooo`;o000000?oooooo`000?l000000oooool2o`0000Gooooo0_l00005
ooooo`;o0000=_ooool2o`00043ooooo0_l0000Wooooo`;o00001?ooool2o`0000Sooooo0_l0000[
ooooo`;o00005_ooool2o`0001Sooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo01Cooooo0_l0
00001?oooooo0000o`000?ooool6o`0000[ooooo0_l0000Looooo`;o00006?ooool2o`0003Oooooo
0_l00007ooooo`;o00009oooool2o`0000Cooooo0_l0000@ooooo`;o00008oooool3o`0001Gooooo
0_l0000Hooooo`00:Oooool2o`00013ooooo0_l00009ooooo`;o00000_ooool2o`0002Sooooo0_l0
001Aooooo`;o0000B?ooool2o`0002Cooooo0_l0000Rooooo`;o00002oooool002Wooooo0_l0000;
ooooo`;o00000oooool2o`0005[ooooo0_l0000=ooooo`;o00008Oooool2o`0000Kooooo0_l0000W
ooooo`?o00003Oooool2o`0004_ooooo0_l00002ooooo`;o00002oooool002Wooooo00Co0000oooo
ool0003o00002Oooool2o`0000;ooooo0_l0000Nooooo`;o00007_ooool2o`0001_ooooo0_l00004
ooooo`;o00001oooool2o`0000;ooooo0_l0000Mooooo`;o00001_ooool2o`000003ooooool0003o
000001cooooo0_l00004ooooo`Go000000?oooooo`000?l000002_ooool2o`0004Oooooo0_l00002
ooooo`;o00003oooool002Wooooo00Co0000ooooool0003o00003Oooool2o`0000Gooooo0_l0000?
ooooo`;o00001_ooool2o`0000?ooooo0_l0000Iooooo`;o00005oooool2o`0000Sooooo0_l0000;
ooooo`;o00002Oooool2o`0001gooooo0_l0000<ooooo`;o00003_ooool2o`0000Cooooo0_l00004
ooooo`;o00004_ooool2o`0002;ooooo0_l0000Dooooo`;o00001Oooool2o`0001?ooooo000Yoooo
o`03o`000?oooooooooo00?ooooo0_l00008ooooo`;o00001_ooool2o`0000Kooooo0_l00007oooo
o`;o00002oooool2o`0003;ooooo0_l0000Pooooo`Co00001oooool2o`00023ooooo0_l0000Toooo
o`;o00002?ooool2o`0000oooooo0_l0000Aooooo`;o00001Oooool2o`0000gooooo0_l0000Joooo
o`00:Oooool2o`0000Cooooo0_l000000ooooooo0000o`000005ooooo`;o00003_ooool2o`0001?o
oooo0_l0001Dooooo`;o000000?oooooo`000?l000000_l00005ooooo`;o00002?ooool2o`0003co
oooo0_l00009ooooo`;o00003_ooool2o`0001Sooooo0_l0000Aooooo`?o00005Oooool002Wooooo
00?o0000ooooooooool01_ooool2o`0002[ooooo0_l00002ooooo`;o00005oooool2o`0003Oooooo
0_l00003ooooo`;o00003oooool2o`0000[ooooo0_l0000?ooooo`;o00003?ooool2o`0000gooooo
0_l0000=ooooo`;o00008?ooool2o`0001Wooooo0ol0000Eooooo`00:Oooool00ol0003ooooooooo
o`0:ooooo`;o00005oooool2o`0000_ooooo1?l000002?l@413oooooo`000?l0003o<S8bo`000?lb
<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo0_l0000Looooo`Go00000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o0000
3_ooool2o`00017ooooo0ol000000olb<S;oc<c<ooooo`02ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko0000o`000?lb<S;ok^k^00[ooooo0_l0000=ooooo`;o00003oooool2o`00
0009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0=ooooo`;o000000?oooooo`000?l000001oooool2o`0000?ooooo0_l00006ooooo`;o
000000KoooooodA4A?l0003o0000oc8b<_oMgMd2ooooo`05onk^k_lb<S;o0000o`000?o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Yooooo`03o`000?oooooooooo00[ooooo0_l0
000Gooooo`;o00003Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg02Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l0
000<ooooo`Co00004Oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool2o`0000Cooooo0_l0000<oooo
o`;o00002Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool2
o`000004oiRHV?ooooooV9RHogMgMa3ooooo0_l00007ooooo`;o00000oooool2o`0000Kooooo0_l0
0004ooooo`06ogMgMolb<S;ooooooooooomgMgOoV9RH0_l000002OmgMgOoooooooooooooooooMgMg
oiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool00ol0003oooooooooo`0Kooooo`;o00005Oooool0
0ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooo
oooooooo410@00Wooooo0_l00004ooooo`;o00006Oooool2o`000003onk^k_oooooooooo00;ooooo
00Go410@o`000?l0003ooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000_ooool2o`00
00oooooo0_l0000Fooooo`;o00000oooool01Ol@413ooooooooooooooooo410@00;o000000?ooooo
oa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`;o00001?ooool2o`0000cooooo0_l00006
ooooo`Go00000oooool2o`0000;ooooo00?o410@ooooooooool00_l00003ooooo`03oa0@4?oooooo
oooo02Gooooo0_l00004ooooo`04o`000?oooooooooooa0@40?ooooo00Go410@oooooooooooooooo
oa0@4003ooooo`03oa0@4?oooooooooo007ooooo000Yooooo`;o00007?ooool2o`00013ooooo0_l0
0003ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000002Oooool2o`0000Cooooo0_l0000Gooooo`Co000000?o8B4Qonk^k_oo
ool00_ooool3o`000003ooooool0003ooooo00;ooooo00Go0000ooooooooooooooooo`000002oooo
o`;o00009oooool2o`0000?ooooo00Co0000oooooooooooooooo0ol000000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo00Sooooo0_l0000Looooo`04odA4A?oMgMgoooooo`0000Cooooo0_l0
0002ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Uooooo`;o0000
0oooool01OmgMgOo<S8boooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo007ooooo000Yooooo`03o`000?oooooooooo00Wooooo0_l0000Rooooo`;o
00000_ooool2o`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool00000:?ooool2o`0000;ooooo00?oMgMgofIVI_ooool00_ooool2o`0000;ooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo02Sooooo00Co410@o`000?l0003o0000
0_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000004oooo
o`;o00001?ooool2o`0000Gooooo0_l0000Eooooo`03omgMgOmEEEGooooo00?o00000_ooool01?l0
003oooooooooooooool2o`0000;ooooo00?o0000ooooool000000_l0000Yooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`00:Oooool3o`0000Cooooo0ol00002ooooo`;o00009_ooool3o`0000?ooooo
00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?ooool2o`00
02?ooooo00Co0000oooooooooooooooo0_l00002ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool00ol@413oooooooooo`06ooooo`;o00008Oooool00onj^[[o0000o`000002ooooo`05oa0@4?oo
ooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Cooooo0_l0000;ooooo`;o
00005_ooool00omgMgOoc<c<o`000002o`0000;ooooo00Co410@oooooooooooooooo0_l00002oooo
o`05oa0@4?oooooo0000o`000?l@4100:Oooool00ol0003oooooooooo`04ooooo`05oa0@4?oooooo
ooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo000Yooooo`?o00001?oo
ool3o`0002_ooooo0_l000002?oooooo0000o`000?mgMgOoV9RHoooooonHV9SoMgMg0oooool2o`00
0003oooooonHV9SoMgMg00Sooooo0_l00003ooooo`;o00004oooool2o`0000Gooooo00Go0000okZj
^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01_mgMgOoV9RHoooo
oonHV9SoMgMgooooo`;o00001?ooool3o`0001Kooooo0_l00003ooooo`;o000000Kooooooa0@4?nH
V9SooooookZj^_l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg01Oooooo0_l000000ooooooo0000o`00000=ooooo`03onk^k_m4A4Co000000?ooooo
0_l000001?nHV9SooooooiRHV?mgMgL3ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool2o`00
00;ooooo0_l0000Qooooo`03o`000?oooooooooo00?ooooo0_l000001?nHV9SooooooiRHV?mgMgL3
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wooooo00Co0000oooooooooooooooo0_l0
0002ooooo`;o0000:Oooool00omEEEGoIVIVo`000002ooooo`;o000000Gok^k^o`000?l0003o<S8b
onk^kP03ooooo`?o000000?o<S8bonk^k_ooool03?ooool2o`0001?ooooo0_l00005ooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Kok^k^oc8b
<_l0003o<S8bonk^k_ooool2o`0000Cooooo0_l0000>ooooo`;o00001oooool2o`0000?ooooo0_l0
00001_ooooooZJVYoa0@4?l0003o410@ojVYZ@?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01oooool2o`0000kooooo0_l000001?oooooo0000o`000?l0
000=ooooo`03ogMgMol0003o000000;ooooo0_l000001?lb<S;o0000oc8b<_o^k^h3ooooo`?o0000
00Co<S8bonk^k_oooooooooo0ol000000ooooooo0000o`00000<ooooo`;o00004oooool4o`0000;o
oooo0_l000001?lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
02Wooooo0_l00002ooooo`;o0000=Oooool2o`0003kooooo0_l0000Oooooo`;o00007oooool2o`00
00[ooooo0_l0000Booooo`;o00003_ooool2o`0000_ooooo0_l00006ooooo`;o00001?ooool2o`00
00Wooooo0_l00007ooooo`;o00003oooool2o`00013ooooo000Yooooo`03o`000?oooooooooo03_o
oooo0_l0000kooooo`;o00004_ooool2o`0001Sooooo0_l0000Booooo`;o00003_ooool2o`00037o
oooo0_l00006ooooo`;o00001oooool3o`0000Sooooo0_l0000?ooooo`;o00004?ooool002Wooooo
00?o0000ooooooooool0>oooool2o`0001oooooo0_l000000ooooooo0000o`00000[ooooo`;o0000
6?ooool2o`0000gooooo0_l0000Aooooo`Co00000_ooool2o`0000?ooooo0_l0000Pooooo`;o0000
1_ooool2o`0000oooooo0ol0000[ooooo`00:Oooool00ol0003oooooooooo`0Booooo`;o0000B?oo
ool2o`000003ooooool0003o000001Gooooo0_l000000ooooooo0000o`000006ooooo`;o00003ooo
ool2o`0000gooooo0_l0000Booooo`;o00002_ooool2o`0000Gooooo0_l00004ooooo`;o00000ooo
ool2o`00023ooooo0_l0000:ooooo`;o00005oooool2o`000003ooooool0003o000001gooooo000Y
ooooo`03o`000?oooooooooo01;ooooo0_l00014ooooo`;o000000?oooooo`000?l000006Oooool2
o`000003ooooool0003o000000Kooooo0_l0000?ooooo`;o00003Oooool2o`0001kooooo0_l0000f
ooooo`;o00001_ooool2o`0001Oooooo0_l000000ooooooo0000o`000002ooooo`;o00006Oooool0
027oooooool00014o`0000Cooooo000Yooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`02o`0000Oooooo00?o0000ooooooooool01_ooool2o`000003
ooooool0003ooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00;o00001oooool2o`0000Cooooo0_l00004ooooo`03o`000?oooooooooo00Co
oooo0ol00003ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`07ooooo`Co000000Coooooo`000?l0003o00001oooool00ol0003oooooooooo`02o`00
00Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`;o00001?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool2o`00
00Cooooo00Co0000oooooooooooooooo1?l00004ooooo`03o`000?oooooooooo00Kooooo0_l00002
ooooo`04o`000?oooooo0000o`0000Sooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00[ooooo000Yooooo`03o`000?oooooooooo01Wooooo0_l0000=
ooooo`;o00004?ooool00ol0003oooooooooo`03ooooo`;o00005?ooool2o`0001[ooooo0_l00004
ooooo`03o`000?oooooooooo01gooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00002_oo
ool2o`0000Cooooo1?l0000Zooooo`;o00002_ooool2o`0000Cooooo00Co0000oooooooooooooooo
1?l0000=ooooo`;o00001?ooool2o`0000Gooooo0_l0000Iooooo`03o`000?oooooooooo00[ooooo
000Yooooo`03o`000?oooooooooo02Sooooo0_l0000Fooooo`;o00001?ooool2o`000003ooooool0
003o000001cooooo0_l0000Dooooo`;o00005_ooool2o`000003ooooool0003o000001Sooooo0ol0
000=ooooo`;o00006_ooool4o`0001Sooooo0_l0000:ooooo`;o00001?ooool2o`0000Kooooo0_l0
000Vooooo`00:Oooool00ol0003oooooooooo`0fooooo`;o00003_ooool2o`000003ooooool0003o
000000;o00003Oooool2o`0000[ooooo0ol0000@ooooo`;o00000_ooool2o`0001Kooooo0_l0000[
ooooo`;o00001oooool2o`0000Oooooo0_l00008ooooo`;o00006_ooool4o`0000Sooooo0_l00004
ooooo`;o00005Oooool4o`0001Gooooo000Yooooo`;o0000=oooool2o`0001?ooooo0_l0000<oooo
o`?o00002_ooool4o`000003ooooool0003o000000cooooo0_l00011ooooo`Co00002oooool2o`00
00Oooooo0_l0000Vooooo`;o00005?ooool2o`0000oooooo1?l0000Eooooo`00:Oooool00ol0003o
ooooooooo`13ooooo`;o00001Oooool2o`0000gooooo0_l0000=ooooo`;o000000?oooooo`000?l0
00000_l0000Pooooo`;o00001oooool2o`00017ooooo0_l00002ooooo`;o00002oooool4o`0000go
oooo0_l0000:ooooo`;o00006Oooool2o`0001cooooo0_l0000Xooooo`00:Oooool01?l0003ooooo
o`000?l0000Nooooo`;o00008?ooool4o`0000Gooooo0_l0000Qooooo`;o00003Oooool3o`00013o
oooo0_l00007ooooo`;o00002Oooool2o`0000Kooooo0_l00002ooooo`;o00005?ooool2o`0000Ko
oooo0_l0000:ooooo`;o00002Oooool2o`0000kooooo0_l00004ooooo`;o00000oooool2o`0000?o
oooo0_l00002ooooo`;o0000<_ooool002Wooooo00Co0000ooooool0003o00007_ooool2o`0001[o
oooo0_l00004ooooo`;o00001Oooool2o`0003;ooooo1Ol0000>ooooo`;o00004_ooool2o`0000So
oooo0_l0000Fooooo`;o00003Oooool2o`0000kooooo0_l0000Dooooo`;o00000oooool2o`0000?o
oooo0_l00002ooooo`;o00004_ooool2o`0001kooooo000Yooooo`03o`000?oooooooooo00?o0000
;?ooool3o`0000Wooooo0_l0000;ooooo`;o00001_ooool2o`0000;ooooo0_l0000Yooooo`;o0000
9_ooool2o`0000;ooooo1?l00009ooooo`;o00006_ooool2o`0002Kooooo0_l0000Eooooo`;o0000
1oooool2o`000003ooooool0003o000001_ooooo000Yooooo`;o000000?oooooo`000?l000000_l0
000@ooooo`;o00004oooool2o`0000Cooooo0ol0000<ooooo`;o00004?ooool3o`000003ooooool0
003o000000;ooooo0_l00004ooooo`;o00001?ooool2o`0003oooooo1?l00002ooooo`;o00002ooo
ool2o`000003ooooool0003o000002cooooo0_l0000Aooooo`;o00001_ooool2o`0000gooooo0_l0
00000ooooooo0000o`000007ooooo`;o00006oooool002Wooooo00?o0000ooooooooool00_ooool2
o`0000oooooo0ol0000?ooooo`;o00000_ooool3o`00013ooooo1?l0000Aooooo`;o00001Oooool2
o`0000Cooooo0_l00004ooooo`;o0000:_ooool2o`0001?ooooo0_l0000Dooooo`;o00008_ooool2
o`0000Sooooo0_l0000Iooooo`;o00003?ooool2o`0000;ooooo0_l0000Tooooo`00:Oooool00ol0
003oooooooooo`0Cooooo`;o000000?oooooo`000?l000003Oooool4o`000003ooooool0003o0000
013ooooo0_l00004ooooo`;o00002Oooool2o`00047ooooo0_l0000nooooo`;o00003Oooool2o`00
00gooooo0_l0000Rooooo`;o00001?ooool2o`0002;ooooo000Yooooo`03o`000?oooooooooo00co
oooo0_l00008ooooo`Co00003Oooool2o`0001Wooooo0_l00009ooooo`;o0000Boooool4o`0003;o
oooo0_l0000?ooooo`;o00002oooool2o`0001Oooooo0_l00007ooooo`;o00001_ooool2o`0000Co
oooo0_l0000Looooo`00:Oooool00ol0003oooooooooo`08ooooo`;o00000_ooool2o`0000[ooooo
0_l0000dooooo`;o0000;?ooool2o`0001;ooooo0_l00008ooooo`Co00001?ooool3o`0003cooooo
0_l0000Tooooo`;o00001oooool2o`0000[ooooo1?l0000=ooooo`;o00003Oooool002Wooooo0_l0
0009ooooo`;o00000oooool2o`0001?ooooo0_l0000Zooooo`;o00001?ooool2o`0002Kooooo0_l0
0004ooooo`;o00003?ooool2o`00013ooooo0ol00016ooooo`;o0000;oooool2o`0000[ooooo0ol0
0002ooooo`;o00003Oooool002Wooooo00?o0000ooooooooool03Oooool2o`0001?ooooo0_l0000?
ooooo`;o00007oooool2o`0002Cooooo0_l00006ooooo`;o00002?ooool2o`0003Kooooo0_l0000L
ooooo`;o00001oooool2o`0003Wooooo1Ol0000Aooooo`00:Oooool00ol0003oooooooooo`0Goooo
o`;o00006_ooool2o`0000oooooo0_l0000dooooo`?o00000_ooool2o`0000Cooooo0_l00005oooo
o`;o0000;oooool2o`0000Gooooo0_l0000Aooooo`;o00002Oooool2o`0004;ooooo0_l00002oooo
o`;o00004?ooool002Wooooo00?o0000ooooooooool05oooool2o`0001?ooooo0_l0000Fooooo`;o
00003?ooool2o`0001Kooooo0_l00008ooooo`;o00001Oooool2o`0000;ooooo0_l00004ooooo`;o
00009oooool2o`0000gooooo0_l000000ooooooo0000o`00000Eooooo`;o00005_ooool2o`0002co
oooo0_l0000;ooooo`;o00004?ooool002Wooooo00?o0000ooooooooool01oooool2o`0001Oooooo
0_l0000:ooooo`;o00003?ooool2o`000003ooooool0003o000001?ooooo0_l000000ooooooo0000
o`00000Cooooo`;o00001_ooool4o`000003ooooool0003o0000033ooooo0_l00003ooooo`;o0000
4?ooool2o`0002;ooooo0_l00009ooooo`;o00004?ooool2o`0001[ooooo0_l0000Mooooo`00:Ooo
ool2o`0000Sooooo0_l00009ooooo`;o00003?ooool2o`0001Sooooo0_l000000ooooooo0000o`00
0004ooooo`;o00004?ooool2o`0000Gooooo0_l0000Dooooo`;o00000oooool2o`00033ooooo0_l0
000Cooooo`;o00009?ooool2o`0001_ooooo0_l0000iooooo`00:Oooool00ol0003oooooooooo`0A
ooooo`?o0000;oooool2o`000003ooooool0003o000001Cooooo0_l0000Sooooo`;o0000>_ooool3
o`0001Sooooo0_l00009ooooo`;o0000>_ooool2o`0001_ooooo0006ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`04ooooo`;o00000oooool2o`0000Kooooo0_l0000cooooo`;o00006ooo
ool2o`0001cooooo0_l0000jooooo`;o00006Oooool2o`0000Wooooo0_l0000=ooooo`Co00002?oo
ool2o`0001Oooooo0_l00006ooooo`;o00006oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool2o`0000Gooooo0_l00003ooooo`;o00007Oooool2o`0001Cooooo0_l0000Sooooo`;o0000
4_ooool2o`0001Gooooo0_l00003ooooo`;o000000?oooooo`000?l00000<?ooool2o`0001oooooo
0_l00007ooooo`Co00002?ooool2o`0000;ooooo0_l0000Cooooo`;o00008oooool000Kooooo00Go
410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool0
0oooool2o`0000Sooooo0_l00007ooooo`;o00005_ooool2o`0000Kooooo0_l0000<ooooo`;o0000
=oooool2o`0001Gooooo0_l00003ooooo`;o000000?oooooo`000?l000007?ooool2o`0001;ooooo
0_l0000Oooooo`;o00005oooool3o`0003Oooooo0006ooooo`05o`000?ooooooooooooooool00000
3Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00007ooooo`;o0000
1oooool2o`0001kooooo0_l0000Wooooo`;o00003_ooool2o`0004Wooooo0ol00009ooooo`;o0000
9?ooool2o`0001_ooooo0_l0000gooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo
00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool03oooool2o`0004Sooooo0_l0000>ooooo`;o0000=Oooool2o`0001?ooooo0_l00009ooooo`;o
00009?ooool2o`0001Sooooo0_l0000jooooo`001_ooool01Ol@413ooooooooooooooooo410@00oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00_o
oooo0_l00002ooooo`;o00001oooool2o`0006[ooooo0_l0000Jooooo`;o00004?ooool2o`0004co
oooo0_l0000Cooooo`;o00004Oooool2o`0000?ooooo0_l0000=ooooo`001_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02oooool2o`0000_ooooo0_l00007ooooo`;o00009?ooool2o`00
01;ooooo0_l00004ooooo`;o00008Oooool2o`0002_ooooo1?l0000:ooooo`;o00005Oooool2o`00
02?ooooo0_l0000Hooooo`;o00001?ooool2o`0000_ooooo0_l00003ooooo`;o00003Oooool000Ko
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4
o`0000Kooooo00?o0000ooooooooool08Oooool2o`000003ooooool0003o0000027ooooo0_l0000=
ooooo`;o00000oooool2o`0000Cooooo0_l0001>ooooo`Co00002_ooool2o`0001Gooooo0_l0000S
ooooo`;o00007_ooool2o`0001oooooo000Yooooo`;o00009Oooool2o`000003ooooool0003o0000
01Oooooo0_l00007ooooo`;o00002oooool2o`0009Gooooo0_l00002ooooo`;o00007?ooool2o`00
02_ooooo000Yooooo`03o`000?oooooooooo02Oooooo0_l0000Gooooo`;o00001oooool2o`0001So
oooo0_l0000jooooo`;o0000<?ooool2o`0000Sooooo0_l0000;ooooo`;o00000oooool2o`0000;o
oooo0_l0000Looooo`;o00006oooool2o`0000kooooo000Yooooo`03o`000?oooooooooo023ooooo
0_l00011ooooo`;o00003oooool2o`0000oooooo0_l0000;ooooo`;o00002oooool2o`00033ooooo
0_l00008ooooo`;o00001?ooool2o`0000Gooooo0_l0000Sooooo`;o00002?ooool2o`0001?ooooo
0_l0000>ooooo`00:Oooool00ol0003oooooooooo`0Pooooo`;o00003?ooool2o`0004Cooooo0_l0
000?ooooo`Co000000?oooooo`000?l000001_ooool2o`0001cooooo0_l0000_ooooo`;o0000:_oo
ool2o`0000Sooooo0_l0000Sooooo`00:Oooool00ol0003oooooooooo`0^ooooo`;o00003Oooool2
o`0002Gooooo0_l0000Jooooo`;o00001?ooool3o`000003ooooool0003o000002Cooooo0_l0000o
ooooo`;o0000BOooool002Wooooo0_l0000nooooo`;o00009Oooool2o`0001[ooooo0_l00004oooo
o`;o0000JOooool2o`0004Wooooo000Yooooo`03o`000?oooooooooo04Gooooo0_l0002nooooo`;o
0000=Oooool002Wooooo00?o0000ooooooooool07oooool2o`0001Cooooo0_l0000>ooooo`;o0000
5oooool2o`00037ooooo0_l0001booooo`;o0000=Oooool002Wooooo00?o0000ooooooooool07ooo
ool2o`000003ooooool0003o0000017ooooo0_l0000Wooooo`;o0000<Oooool2o`0000[ooooo0_l0
002Mooooo`00:Oooool00ol0003oooooooooo`0Rooooo`;o00005?ooool2o`0000_ooooo0_l0001F
ooooo`;o0000R?ooool2o`0001?ooooo000Yooooo`;o00007Oooool2o`0000Oooooo0_l0000Aoooo
o`;o00002oooool2o`0007?ooooo0_l0000Wooooo`;o0000>oooool2o`0000Gooooo0_l0000Coooo
o`00:Oooool00ol0003oooooooooo`02ooooo`;o00003?ooool2o`0000Sooooo1?l00007ooooo`;o
00004?ooool2o`0000Sooooo0_l0000/ooooo`;o00008oooool2o`0001;ooooo0_l0000>ooooo`Co
00009oooool2o`0002Cooooo0_l0000Eooooo`;o00006_ooool002Wooooo00?o0000ooooooooool0
0_ooool2o`0000cooooo0_l00008ooooo`;o00006oooool2o`0000Sooooo0_l0000/ooooo`?o0000
8_ooool2o`0001;ooooo0_l0000>ooooo`;o0000=_ooool2o`0001Oooooo0_l0000aooooo`00:Ooo
ool00ol0003oooooooooo`1Gooooo`;o00005oooool2o`0007kooooo0_l0001:ooooo`00:Oooool0
0ol0003oooooooooo`1Gooooo`;o00004?ooool2o`000=7ooooo000Yooooo`;o0000J_ooool2o`00
0=7ooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0Boooool2o`0000Kooooo0_l00020ooooo`;o0000@Oooool2o`0002;ooooo000>ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`1;ooooo`;o00001_ooool2o`0001[ooooo0_l0000oooooo`;o00008oooool2o`00
047ooooo0_l0000Rooooo`003_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooo
ooooool00oooool3o`0006oooooo0_l0000oooooo`;o0000R_ooool000kooooo00Go0000oooooooo
ooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0`oooool2o`00
07Oooooo000>ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool0]_ooool2o`0000_ooooo0_l0000Fooooo`;o0000Goooool0
00kooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0]_ooool2o`0002?ooooo0_l0001Oooooo`003_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo000>oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEE
EOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolmooooo`001_ooool01Ol0003o
oooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00000>oooo
o`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOo
oooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool001oooooo1?l000000ol@413oooooooooo`03ooooo`03
o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo0ol0003oooooocgooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool001oooooo00?oEEEEofIVI_l00000oooooom7ooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .39823 Mdot
.02762 .33775 Mdot
.02952 .31205 Mdot
.03143 .33748 Mdot
.03333 .28023 Mdot
.03524 .25251 Mdot
.03714 .31975 Mdot
.03905 .41913 Mdot
.04095 .4234 Mdot
.04286 .34412 Mdot
.04476 .32042 Mdot
.04667 .3893 Mdot
.04857 .29531 Mdot
.05048 .34057 Mdot
.05238 .38943 Mdot
.05429 .27909 Mdot
.05619 .31271 Mdot
.0581 .30775 Mdot
.06 .34864 Mdot
.0619 .37649 Mdot
.06381 .29884 Mdot
.06571 .26636 Mdot
.06762 .24838 Mdot
.06952 .32434 Mdot
.07143 .30082 Mdot
.07333 .37112 Mdot
.07524 .27778 Mdot
.07714 .33522 Mdot
.07905 .35544 Mdot
.08095 .33586 Mdot
.08286 .32295 Mdot
.08476 .42759 Mdot
.08667 .43871 Mdot
.08857 .37248 Mdot
.09048 .36974 Mdot
.09238 .41594 Mdot
.09429 .24304 Mdot
.09619 .28233 Mdot
.0981 .33854 Mdot
.1 .36756 Mdot
.1019 .28416 Mdot
.10381 .38275 Mdot
.10571 .29212 Mdot
.10762 .40031 Mdot
.10952 .39211 Mdot
.11143 .28482 Mdot
.11333 .34838 Mdot
.11524 .39648 Mdot
.11714 .30213 Mdot
.11905 .37165 Mdot
.12095 .38942 Mdot
.12286 .26875 Mdot
.12476 .34903 Mdot
.12667 .34227 Mdot
.12857 .32035 Mdot
.13048 .44208 Mdot
.13238 .41593 Mdot
.13429 .31564 Mdot
.13619 .33455 Mdot
.1381 .38488 Mdot
.14 .30109 Mdot
.1419 .3452 Mdot
.14381 .3368 Mdot
.14571 .32234 Mdot
.14762 .44047 Mdot
.14952 .43861 Mdot
.15143 .33717 Mdot
.15333 .30909 Mdot
.15524 .29643 Mdot
.15714 .34547 Mdot
.15905 .35526 Mdot
.16095 .27657 Mdot
.16286 .34363 Mdot
.16476 .3051 Mdot
.16667 .33723 Mdot
.16857 .27809 Mdot
.17048 .34868 Mdot
.17238 .33242 Mdot
.17429 .29334 Mdot
.17619 .34829 Mdot
.1781 .39699 Mdot
.18 .34568 Mdot
.1819 .3208 Mdot
.18381 .3813 Mdot
.18571 .43937 Mdot
.18762 .26094 Mdot
.18952 .26952 Mdot
.19143 .25283 Mdot
.19333 .29173 Mdot
.19524 .305 Mdot
.19714 .29751 Mdot
.19905 .46996 Mdot
.20095 .26241 Mdot
.20286 .2545 Mdot
.20476 .28119 Mdot
.20667 .47312 Mdot
.20857 .34389 Mdot
.21048 .38449 Mdot
.21238 .33101 Mdot
.21429 .3082 Mdot
.21619 .3994 Mdot
.2181 .25861 Mdot
.22 .39561 Mdot
.2219 .39587 Mdot
.22381 .3859 Mdot
.22571 .37817 Mdot
.22762 .36455 Mdot
.22952 .35908 Mdot
.23143 .26145 Mdot
.23333 .34525 Mdot
.23524 .35005 Mdot
.23714 .33721 Mdot
.23905 .42399 Mdot
.24095 .40873 Mdot
.24286 .24781 Mdot
.24476 .31099 Mdot
.24667 .32089 Mdot
.24857 .44582 Mdot
.25048 .44156 Mdot
.25238 .23219 Mdot
.25429 .2896 Mdot
.25619 .29517 Mdot
.2581 .24586 Mdot
.26 .34588 Mdot
.2619 .3481 Mdot
.26381 .34102 Mdot
.26571 .40099 Mdot
.26762 .47099 Mdot
.26952 .38606 Mdot
.27143 .32554 Mdot
.27333 .24389 Mdot
.27524 .39523 Mdot
.27714 .36538 Mdot
.27905 .26839 Mdot
.28095 .25597 Mdot
.28286 .31133 Mdot
.28476 .23896 Mdot
.28667 .37907 Mdot
.28857 .34089 Mdot
.29048 .43101 Mdot
.29238 .38056 Mdot
.29429 .40271 Mdot
.29619 .29689 Mdot
.2981 .32576 Mdot
.3 .31518 Mdot
.3019 .39401 Mdot
.30381 .4442 Mdot
.30571 .34591 Mdot
.30762 .35619 Mdot
.30952 .24982 Mdot
.31143 .27619 Mdot
.31333 .251 Mdot
.31524 .2583 Mdot
.31714 .33297 Mdot
.31905 .26944 Mdot
.32095 .3036 Mdot
.32286 .23066 Mdot
.32476 .31411 Mdot
.32667 .44446 Mdot
.32857 .24052 Mdot
.33048 .2301 Mdot
.33238 .36055 Mdot
.33429 .28743 Mdot
.33619 .27356 Mdot
.3381 .41704 Mdot
.34 .30771 Mdot
.3419 .39779 Mdot
.34381 .44502 Mdot
.34571 .40041 Mdot
.34762 .28433 Mdot
.34952 .22991 Mdot
.35143 .39635 Mdot
.35333 .2619 Mdot
.35524 .25736 Mdot
.35714 .27737 Mdot
.35905 .35816 Mdot
.36095 .43841 Mdot
.36286 .47315 Mdot
.36476 .2931 Mdot
.36667 .29067 Mdot
.36857 .35173 Mdot
.37048 .23633 Mdot
.37238 .34174 Mdot
.37429 .26994 Mdot
.37619 .27044 Mdot
.3781 .27341 Mdot
.38 .41482 Mdot
.3819 .46897 Mdot
.38381 .42999 Mdot
.38571 .28836 Mdot
.38762 .26664 Mdot
.38952 .25419 Mdot
.39143 .39346 Mdot
.39333 .33516 Mdot
.39524 .31458 Mdot
.39714 .43192 Mdot
.39905 .22848 Mdot
.40095 .38292 Mdot
.40286 .24934 Mdot
.40476 .45456 Mdot
.40667 .38308 Mdot
.40857 .26602 Mdot
.41048 .26585 Mdot
.41238 .28697 Mdot
.41429 .30001 Mdot
.41619 .44355 Mdot
.4181 .39825 Mdot
.42 .29339 Mdot
.4219 .27092 Mdot
.42381 .33878 Mdot
.42571 .26909 Mdot
.42762 .30757 Mdot
.42952 .24381 Mdot
.43143 .32668 Mdot
.43333 .40096 Mdot
.43524 .2567 Mdot
.43714 .39818 Mdot
.43905 .30599 Mdot
.44095 .27065 Mdot
.44286 .2653 Mdot
.44476 .36459 Mdot
.44667 .38223 Mdot
.44857 .31573 Mdot
.45048 .33408 Mdot
.45238 .3946 Mdot
.45429 .40606 Mdot
.45619 .27284 Mdot
.4581 .33074 Mdot
.46 .34852 Mdot
.4619 .26217 Mdot
.46381 .38676 Mdot
.46571 .31733 Mdot
.46762 .31391 Mdot
.46952 .27086 Mdot
.47143 .44386 Mdot
.47333 .26249 Mdot
.47524 .27354 Mdot
.47714 .27059 Mdot
.47905 .26868 Mdot
.48095 .39009 Mdot
.48286 .25033 Mdot
.48476 .39721 Mdot
.48667 .34209 Mdot
.48857 .24064 Mdot
.49048 .41632 Mdot
.49238 .35436 Mdot
.49429 .43304 Mdot
.49619 .30025 Mdot
.4981 .23968 Mdot
.5 .24817 Mdot
.5019 .35154 Mdot
.50381 .3295 Mdot
.50571 .23571 Mdot
.50762 .30667 Mdot
.50952 .33409 Mdot
.51143 .23241 Mdot
.51333 .36988 Mdot
.51524 .25419 Mdot
.51714 .28567 Mdot
.51905 .28566 Mdot
.52095 .42439 Mdot
.52286 .37215 Mdot
.52476 .27925 Mdot
.52667 .27409 Mdot
.52857 .41187 Mdot
.53048 .328 Mdot
.53238 .24585 Mdot
.53429 .39006 Mdot
.53619 .34622 Mdot
.5381 .24368 Mdot
.54 .41004 Mdot
.5419 .36873 Mdot
.54381 .41107 Mdot
.54571 .30288 Mdot
.54762 .34555 Mdot
.54952 .32112 Mdot
.55143 .23087 Mdot
.55333 .28264 Mdot
.55524 .34896 Mdot
.55714 .39834 Mdot
.55905 .31096 Mdot
.56095 .29571 Mdot
.56286 .33177 Mdot
.56476 .31177 Mdot
.56667 .27174 Mdot
.56857 .23866 Mdot
.57048 .40464 Mdot
.57238 .35984 Mdot
.57429 .28061 Mdot
.57619 .34457 Mdot
.5781 .41678 Mdot
.58 .25762 Mdot
.5819 .38416 Mdot
.58381 .46813 Mdot
.58571 .31453 Mdot
.58762 .40486 Mdot
.58952 .30898 Mdot
.59143 .3067 Mdot
.59333 .30952 Mdot
.59524 .27808 Mdot
.59714 .42106 Mdot
.59905 .39613 Mdot
.60095 .38859 Mdot
.60286 .33185 Mdot
.60476 .2485 Mdot
.60667 .39229 Mdot
.60857 .4312 Mdot
.61048 .30422 Mdot
.61238 .34446 Mdot
.61429 .3925 Mdot
.61619 .3707 Mdot
.6181 .29139 Mdot
.62 .2387 Mdot
.6219 .32911 Mdot
.62381 .27146 Mdot
.62571 .25665 Mdot
.62762 .31753 Mdot
.62952 .37502 Mdot
.63143 .38102 Mdot
.63333 .43747 Mdot
.63524 .32962 Mdot
.63714 .33757 Mdot
.63905 .22535 Mdot
.64095 .43381 Mdot
.64286 .33356 Mdot
.64476 .27828 Mdot
.64667 .37969 Mdot
.64857 .30932 Mdot
.65048 .32078 Mdot
.65238 .2671 Mdot
.65429 .31659 Mdot
.65619 .35391 Mdot
.6581 .39827 Mdot
.66 .23739 Mdot
.6619 .28182 Mdot
.66381 .23642 Mdot
.66571 .32017 Mdot
.66762 .28819 Mdot
.66952 .34441 Mdot
.67143 .24698 Mdot
.67333 .30563 Mdot
.67524 .3609 Mdot
.67714 .31301 Mdot
.67905 .37375 Mdot
.68095 .36981 Mdot
.68286 .36518 Mdot
.68476 .32361 Mdot
.68667 .4432 Mdot
.68857 .29104 Mdot
.69048 .38667 Mdot
.69238 .32362 Mdot
.69429 .2698 Mdot
.69619 .26582 Mdot
.6981 .40182 Mdot
.7 .39079 Mdot
.7019 .3126 Mdot
.70381 .41326 Mdot
.70571 .34109 Mdot
.70762 .37858 Mdot
.70952 .39945 Mdot
.71143 .24781 Mdot
.71333 .39228 Mdot
.71524 .44525 Mdot
.71714 .41791 Mdot
.71905 .37015 Mdot
.72095 .33097 Mdot
.72286 .26291 Mdot
.72476 .31296 Mdot
.72667 .28188 Mdot
.72857 .38004 Mdot
.73048 .42114 Mdot
.73238 .31837 Mdot
.73429 .36872 Mdot
.73619 .36797 Mdot
.7381 .28141 Mdot
.74 .39941 Mdot
.7419 .39527 Mdot
.74381 .39134 Mdot
.74571 .26926 Mdot
.74762 .26608 Mdot
.74952 .25705 Mdot
.75143 .29304 Mdot
.75333 .2521 Mdot
.75524 .32783 Mdot
.75714 .28769 Mdot
.75905 .2421 Mdot
.76095 .32424 Mdot
.76286 .26958 Mdot
.76476 .22961 Mdot
.76667 .28662 Mdot
.76857 .31339 Mdot
.77048 .33003 Mdot
.77238 .34936 Mdot
.77429 .26773 Mdot
.77619 .318 Mdot
.7781 .36059 Mdot
.78 .26281 Mdot
.7819 .40633 Mdot
.78381 .40572 Mdot
.78571 .30218 Mdot
.78762 .33517 Mdot
.78952 .35965 Mdot
.79143 .39637 Mdot
.79333 .37182 Mdot
.79524 .35859 Mdot
.79714 .35288 Mdot
.79905 .30108 Mdot
.80095 .40599 Mdot
.80286 .39268 Mdot
.80476 .28142 Mdot
.80667 .26276 Mdot
.80857 .2571 Mdot
.81048 .25659 Mdot
.81238 .22804 Mdot
.81429 .25193 Mdot
.81619 .41787 Mdot
.8181 .30371 Mdot
.82 .25995 Mdot
.8219 .32911 Mdot
.82381 .25126 Mdot
.82571 .36568 Mdot
.82762 .2542 Mdot
.82952 .30475 Mdot
.83143 .2852 Mdot
.83333 .43181 Mdot
.83524 .27767 Mdot
.83714 .3624 Mdot
.83905 .36439 Mdot
.84095 .32846 Mdot
.84286 .36908 Mdot
.84476 .26647 Mdot
.84667 .22575 Mdot
.84857 .47033 Mdot
.85048 .38592 Mdot
.85238 .21729 Mdot
.85429 .39748 Mdot
.85619 .32415 Mdot
.8581 .42661 Mdot
.86 .37421 Mdot
.8619 .31598 Mdot
.86381 .32684 Mdot
.86571 .36763 Mdot
.86762 .26709 Mdot
.86952 .28503 Mdot
.87143 .35575 Mdot
.87333 .4122 Mdot
.87524 .3575 Mdot
.87714 .4634 Mdot
.87905 .26299 Mdot
.88095 .36349 Mdot
.88286 .38336 Mdot
.88476 .2974 Mdot
.88667 .31101 Mdot
.88857 .30041 Mdot
.89048 .41904 Mdot
.89238 .32778 Mdot
.89429 .30591 Mdot
.89619 .35844 Mdot
.8981 .38661 Mdot
.9 .40659 Mdot
.9019 .36762 Mdot
.90381 .34785 Mdot
.90571 .47311 Mdot
.90762 .32528 Mdot
.90952 .39457 Mdot
.91143 .23461 Mdot
.91333 .34634 Mdot
.91524 .31205 Mdot
.91714 .36917 Mdot
.91905 .28067 Mdot
.92095 .38812 Mdot
.92286 .39953 Mdot
.92476 .35267 Mdot
.92667 .2691 Mdot
.92857 .37356 Mdot
.93048 .35442 Mdot
.93238 .26653 Mdot
.93429 .27629 Mdot
.93619 .31514 Mdot
.9381 .34251 Mdot
.94 .31198 Mdot
.9419 .33004 Mdot
.94381 .34569 Mdot
.94571 .25729 Mdot
.94762 .28001 Mdot
.94952 .36515 Mdot
.95143 .4392 Mdot
.95333 .28382 Mdot
.95524 .38249 Mdot
.95714 .31965 Mdot
.95905 .32757 Mdot
.96095 .32445 Mdot
.96286 .23936 Mdot
.96476 .3234 Mdot
.96667 .34118 Mdot
.96857 .32928 Mdot
.97048 .41797 Mdot
.97238 .30869 Mdot
.97429 .36868 Mdot
.97619 .36028 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooo`Wooooo0_l0000c
ooooo`00:Oooool00ol0003oooooooooo`3oooooo`Sooooo0_l0000cooooo`001_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo0<;ooooo0_l00011ooooo`;o0000=Oooool000Co00000_ooool0
1Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo05cooooo0_l000000ooooooo0000o`000004ooooo`;o00003_oo
ool2o`0002oooooo0_l0000Jooooo`;o00009oooool2o`0000gooooo0_l00009ooooo`;o0000=Ooo
ool000Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o
MgMgoc8b<_ooool01?ooool3o`0004Kooooo0_l0000Dooooo`;o000000?oooooo`000?l000001?oo
ool2o`0000kooooo0_l0000Rooooo`;o00002oooool2o`0004?ooooo0_l0000=ooooo`;o0000@?oo
ool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo04Kooooo0_l0000Tooooo`;o0000
:Oooool4o`0002oooooo0_l0001>ooooo`;o00008?ooool000Kooooo00Go410@oooooooooooooooo
oa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`1@ooooo`;o00006_ooool2o`0002Oooooo1?l0000Booooo`;o00003oooool2o`0000_ooooo
0ol0001>ooooo`;o00003_ooool2o`00013ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Cooooo`;o0000>oooool2o`0000cooooo0_l0000booooo`;o000000?oooooo`000?l0
00005?ooool2o`0000oooooo0_l0000;ooooo`;o00007_ooool2o`0003oooooo0_l0000@ooooo`00
1_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co00001_ooool00ol0003oooooooooo`0Cooooo`;o0000<oooool2o`0000?ooooo0_l0000?oooo
o`;o00007oooool2o`00017ooooo0_l0000<ooooo`Co0000AOooool2o`00057ooooo000Yooooo`;o
00002oooool2o`0003Oooooo0_l00003ooooo`;o00000oooool2o`0002Oooooo0_l00007ooooo`;o
00005?ooool2o`0000Wooooo1?l0000Cooooo`;o00005?ooool2o`0000[ooooo0_l0001Qooooo`00
:Oooool00ol0003oooooooooo`02o`0000Sooooo0_l0000Vooooo`;o00003oooool2o`0001?ooooo
0ol0000Kooooo`;o00006?ooool2o`0000?ooooo0_l0000Pooooo`;o00005?ooool2o`0000[ooooo
0_l0000<ooooo`;o00004Oooool2o`0000;ooooo0_l0000looooo`00:Oooool00ol0003ooooooooo
o`02o`00033ooooo0_l00002ooooo`;o00008?ooool3o`0001Oooooo0_l0000Looooo`;o00002?oo
ool2o`0004_ooooo0_l0000Aooooo`;o00000_ooool3o`0003_ooooo000Yooooo`03o`000?oooooo
oooo03Kooooo0_l00003ooooo`;o00004_ooool2o`0000Wooooo0_l0000;ooooo`;o00002Oooool2
o`0000gooooo0_l0000Gooooo`;o00004oooool2o`0000gooooo0_l0000Vooooo`;o00004Oooool2
o`0000Cooooo0_l0000Tooooo`;o00005Oooool002Wooooo00?o0000ooooooooool0<Oooool2o`00
00Sooooo0_l00002ooooo`;o00003_ooool2o`0000Wooooo0_l0000:ooooo`?o00006?ooool2o`00
00Kooooo0_l0000Tooooo`;o00003Oooool2o`0002Kooooo0_l0000Aooooo`;o000000?oooooo`00
0?l000009oooool2o`0001Gooooo000Yooooo`;o0000<_ooool2o`0000;ooooo0_l00008ooooo`;o
00009Oooool2o`00027ooooo0_l00002ooooo`;o0000C_ooool2o`00013ooooo0_l00007ooooo`;o
00000_ooool2o`00017ooooo0_l0000[ooooo`00:Oooool00ol0003oooooooooo`0:ooooo`;o0000
:Oooool2o`0001Oooooo0_l0000Qooooo`;o00001Oooool3o`0000Sooooo0_l00008ooooo`;o0000
=oooool2o`0000cooooo0_l00007ooooo`;o00001_ooool2o`0000Oooooo0ol00007ooooo`;o0000
2_ooool2o`0000Kooooo0_l000000ooooooo0000o`00000?ooooo`;o00006_ooool002Wooooo00?o
0000ooooooooool02_ooool2o`00013ooooo0_l0000Booooo`Co000000So410@ooooooooooook^k^
oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0:ooooo`;o00002oooool2
o`00013ooooo1_l00002ooooo`03onk^k_lb<S;o000000?o000000?oooooo`000?l000000_l00000
0olb<S;ok^k^o`000002o`0000Oooooo1Ol0000Iooooo`05oiRHV?l@413o0000oc8b<_o<c<`00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?ok^k^oc8b<_l000000_l00007ooooo`;o0000
3?ooool2o`0000kooooo0ol00002ooooo`?o00000_ooool2o`000004oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`;o00001_ooool2o`00017ooooo0ol00003oooo
o`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool00ol0003oooooooooo`0Looooo`;o00005?oo
ool2o`0000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL05oooool2o`0000Cooooo0_l0000:ooooo`?o000000?oooooodA4A?ooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00;ooooo0ol000000oooooooV9RHogMgM`02o`0000?ooooo0_l00003oooo
o`Go00003Oooool2o`0000[ooooo00Go410@o`000?l0003oMgMgoc8b<P03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool00omgMgOoV9RHooooo`02o`0001Gooooo0_l0000>ooooo`;o00001?oo
ool2o`0000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL08oooool2o`0000Oooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000Yooooo`03o`000?oooooooooo02Sooooo0_l0
0008ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@
4?ooooooooooooooool@41005Oooool2o`0000Kooooo0_l00004ooooo`;o00001Oooool2o`000003
onk^k_oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooo
ooooool@41001Oooool2o`0000Cooooo0_l0000?ooooo`;o00002oooool2o`000003ooooool0003o
oooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100
:?ooool5o`0000?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41001Oooool2o`0001kooooo0_l00006ooooo`04o`000?oooooooooooa0@40?ooooo00Go410@
oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo007ooooo000Yooooo`Co00001Oooool2
o`0000Gooooo0_l0000Iooooo`;o000000?oooooo`000?l000001Oooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000001Gooooo
0_l0000<ooooo`;o00001_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000001_ooooo0_l0000>ooooo`;o00000oooool00ol0
003oooooo`000002o`0000?ooooo00Go0000ooooooooooooooooo`000005ooooo`;o00008Oooool0
1?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000Gooooo0_l0000Iooooo`;o00000oooool2o`0000;ooooo0_l000000ooooooo
MgMgoc8b<P02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000?ooooo000Yooooo`04o`000?oooooo0000o`0000Gooooo0_l00005ooooo`;o00001Oooool2
o`0001Gooooo0_l00005ooooo`04o`000?ooooooooooooooo`;o00000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool0:_ooool00omgMgOoIVIVooooo`02ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000001_ooooo0_l00008oooo
o`;o00000oooool00ol@413o0000o`000003ooooo`03o`000?oooooo000000;o00000oooool01Ol0
003ooooooooooooooooo000000Gooooo0_l00003ooooo`;o00004oooool2o`0000;ooooo0_l00003
ooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`;o0000
0_ooool00ol0003oooooooooo`0Nooooo`;o00001oooool4o`000004olc<c?ooooooooooo`0000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo007ooooo000Yooooo`03
o`000?oooooooooo01Cooooo0ol000000ooooooo0000o`00000Hooooo`04o`000?oooooooooooooo
o`;o00000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool07_ooool2
o`0000_ooooo00Go0000oooooooooooooooooa0@4003ooooo`;o00000_ooool01Ol@413ooooooooo
oooooooo410@01Wooooo0ol00009ooooo`;o00001?ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@
4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00[ooooo0_l0000Coooo
o`;o00000_ooool2o`0000Cooooo00?oMgMgolc<c?l000000_l00002ooooo`05oa0@4?oooooooooo
ooooool@41000oooool2o`0000;ooooo00?o410@ooooooooool00_ooool2o`0000[ooooo0_l0000G
ooooo`04o`000?oooooo0000o`0000?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@
4?ooooooooooooooool@41000oooool002Wooooo00?o0000ooooooooool05Oooool2o`000003oooo
ool0003o000001Sooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`;o00006?ooool2o`0000;ooooo0_l00007oooo
o`04o`000?nj^[[ooooooiRHV0;o00000_ooool01?mgMgOoV9RHoooooonHV9P2o`0000;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0Iooooo`?o00003?ooool01Ol@413oV9RHoooooonj^[[o000000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool2
o`0001_ooooo1Ol00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Cooooo0_l0000:ooooo`;o00005oooool00ol0003oooooooooo`04ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000Yooooo`03
o`000?oooooooooo01Oooooo0_l0000Gooooo`03oeEEEOmVIVKo000000;o00000_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`;o00006?ooool2
o`0000Sooooo0ol000001?nHV9So410@o`000?lQ8B42o`0000;ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:?ooool01OnYZJWo410@o`000?l@413oZJVY
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_l0003o0000oc8b<_o^k^h03?oo
ool2o`0000Gooooo0_l0000Booooo`Go00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Yooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool2o`0000Gooooo0_l0000Aoooo
o`;o00005?ooool2o`0000Cooooo0_l0000Booooo`;o00008Oooool3o`0000oooooo0_l0000[oooo
o`;o00004?ooool2o`0001Gooooo0_l0000Booooo`;o0000E?ooool002Wooooo00?o0000oooooooo
ool01?ooool2o`0000?ooooo0_l0000Looooo`;o00001?ooool2o`0000Gooooo0_l0000Aooooo`;o
00002oooool2o`0002Kooooo0_l0000[ooooo`;o0000I_ooool2o`0002Wooooo000Yooooo`03o`00
0?oooooooooo00Wooooo0_l000000ooooooo0000o`00000<ooooo`;o00001_ooool2o`0000?ooooo
0_l0000;ooooo`;o00007_ooool2o`0002Cooooo0_l0000Hooooo`;o0000Foooool2o`0000?ooooo
0_l0000Iooooo`?o0000:?ooool002Wooooo00?o0000ooooooooool03?ooool2o`0000cooooo0_l0
0006ooooo`;o00001_ooool2o`0000Oooooo0_l0000Wooooo`;o00007?ooool2o`0001Sooooo0_l0
000>ooooo`;o00004oooool2o`0001;ooooo0_l0000Rooooo`;o00000oooool2o`0000Cooooo0_l0
00000ooooooo0000o`00000Aooooo`;o0000:?ooool002Wooooo00?o0000ooooooooool01oooool2
o`00027ooooo0_l00007ooooo`;o00001Oooool2o`00023ooooo0_l00004ooooo`;o00006_ooool2
o`0000;ooooo0_l0000Dooooo`;o00002_ooool2o`0000gooooo0_l00004ooooo`;o00004_ooool2
o`0002gooooo0_l000000ooooooo0000o`00000Cooooo`;o00005oooool2o`0000gooooo000Qoooo
oooo0000A?l00004ooooo`00:Oooool3o`0000Oooooo0ol0000<ooooo`03o`000?oooooooooo00Wo
oooo00Co0000oooooooooooooooo0_l00006ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool01_ooool2o`0000;ooooo00?o0000ooooooooool01_ooool2o`000003ooooool0003ooooo
00Sooooo0ol0000;ooooo`03o`000?oooooooooo00Kooooo0_l00002ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01?ooool2o`0000?ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`Co00001Oooool5o`0000_ooooo00Co0000oooooooooooooooo0_l00006
ooooo`?o00001_ooool2o`0000;ooooo00Co0000oooooooooooooooo0_l00006ooooo`03o`000?oo
oooooooo00?ooooo0_l00004ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`04ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000Kooooo
0_l0000:ooooo`03o`000?oooooooooo00[ooooo000Yooooo`?o00001oooool2o`0001Oooooo0_l0
000Hooooo`03o`000?oooooooooo01Sooooo0_l00006ooooo`;o00005Oooool2o`0000;ooooo00?o
0000ooooooooool02_ooool2o`0000?ooooo0ol0000Tooooo`;o00000_ooool00ol0003ooooooooo
o`06ooooo`;o00001oooool2o`0000Gooooo0_l00006ooooo`;o00001_ooool2o`0000cooooo1?l0
0002ooooo`03o`000?oooooooooo01Gooooo0_l0000?ooooo`;o00001Oooool3o`0000[ooooo00?o
0000ooooooooool02_ooool002Wooooo00Co0000oooooooooooooooo1?l0000Iooooo`Co00003Ooo
ool2o`0001?ooooo0_l0000?ooooo`;o0000;_ooool2o`0000?ooooo0_l0000Iooooo`;o00005ooo
ool2o`0000Kooooo0ol00002ooooo`;o00004oooool2o`0000cooooo0_l0000Jooooo`;o00005_oo
ool2o`0000Cooooo0_l0000Booooo`00:Oooool01?l0003oooooooooooooool4o`0000Kooooo0_l0
0002ooooo`;o00003Oooool2o`0000?ooooo0_l0000:ooooo`;o00004oooool2o`0005oooooo0_l0
000Oooooo`;o00000oooool2o`0000Cooooo1?l0000;ooooo`;o00001oooool2o`0001gooooo0_l0
000Nooooo`;o000000?oooooo`000?l000003oooool002Wooooo0_l0000<ooooo`;o00000_ooool2
o`0001;ooooo0_l0000Wooooo`;o00001_ooool2o`0002Wooooo0_l0001@ooooo`Co00005?ooool2
o`0001gooooo1?l0000<ooooo`;o00004?ooool3o`0000oooooo000Yooooo`03o`000?oooooooooo
04cooooo0_l00006ooooo`;o0000:Oooool2o`0001Kooooo0_l00006ooooo`;o00007?ooool2o`00
00;ooooo0_l0000Tooooo`;o00000oooool2o`0000oooooo0_l00004ooooo`;o00001Oooool2o`00
00Sooooo0_l00002ooooo`;o00002Oooool2o`0000Cooooo1Ol0000>ooooo`00:Oooool00ol0003o
ooooooooo`0/ooooo`;o00002oooool2o`00023ooooo0_l0000[ooooo`;o00003Oooool2o`0000Ko
oooo0_l00009ooooo`;o00002_ooool2o`0000Gooooo0_l00002ooooo`Co00005oooool2o`0000Wo
oooo0_l00003ooooo`;o00003oooool2o`0000Cooooo0_l0000?ooooo`;o00003Oooool2o`0000Co
oooo0_l000000ooooooo0000o`00000>ooooo`00:Oooool00ol0003oooooooooo`0=ooooo`Co0000
3oooool2o`000003ooooool0003o000000Oooooo0_l0000;ooooo`;o00008?ooool2o`0001Kooooo
0_l0000@ooooo`;o000000?oooooo`000?l000003_ooool2o`00013ooooo0_l0000:ooooo`;o0000
2oooool2o`0001Oooooo0_l0000Dooooo`;o0000B?ooool002Wooooo1?l0000<ooooo`Co00000ooo
ool2o`0000[ooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l0000Eooooo`;o0000<?oo
ool2o`0000Sooooo0_l00006ooooo`;o00004Oooool2o`0002Oooooo0_l0000_ooooo`;o0000B?oo
ool002Wooooo1?l00004ooooo`;o00003Oooool2o`0000Oooooo0_l00006ooooo`;o00000oooool2
o`0001Gooooo0_l00006ooooo`;o00001_ooool2o`0001Wooooo0_l0000?ooooo`;o00004_ooool2
o`0002kooooo0_l0000Eooooo`;o0000B?ooool2o`0000Oooooo0_l0000?ooooo`00:Oooool00ol0
003oooooooooo`02ooooo`;o000000?oooooo`000?l000005_ooool2o`0000?ooooo0_l00003oooo
o`Co00000oooool2o`0000Sooooo0_l00006ooooo`;o00001_ooool3o`0000Kooooo0_l00004oooo
o`;o00004oooool2o`0002?ooooo0_l0000Booooo`;o00001oooool2o`0000[ooooo0_l0000@oooo
o`;o00002_ooool2o`0004Sooooo1?l00005ooooo`;o00003oooool002Wooooo00?o0000oooooooo
ool00_ooool2o`0000Cooooo0_l0000?ooooo`;o00000_ooool2o`0000?ooooo0_l00003ooooo`Wo
00002?ooool2o`0000Kooooo0_l00006ooooo`?o00003?ooool2o`00033ooooo0_l0000Fooooo`;o
00000_ooool4o`0000Gooooo0_l0000:ooooo`;o00004?ooool2o`0004Wooooo0_l000000ooooooo
0000o`000008ooooo`;o00005_ooool002Wooooo00?o0000ooooooooool02?ooool2o`0000oooooo
0_l00002ooooo`;o00003?ooool4o`00017ooooo0_l00007ooooo`;o00008?ooool2o`0001cooooo
0_l0000;ooooo`;o00002Oooool2o`0000Cooooo0_l00014ooooo`;o0000:?ooool2o`000003oooo
ool0003o0000023ooooo000Yooooo`03o`000?oooooooooo00kooooo0_l0000Hooooo`;o00005_oo
ool2o`0002Wooooo0_l0000Vooooo`;o000000?oooooo`000?l00000<?ooool2o`0002?ooooo0_l0
0006ooooo`;o00009oooool4o`0001[ooooo000Yooooo`;o00003oooool2o`0001Sooooo0_l0000^
ooooo`;o00003_ooool2o`0002Wooooo0_l0000cooooo`;o0000:oooool2o`0001Kooooo0ol00005
ooooo`;o00001oooool4o`0001[ooooo000Yooooo`03o`000?oooooooooo03kooooo0_l0000Hoooo
o`;o00001Oooool2o`0000Oooooo0_l00013ooooo`;o00007oooool2o`0001oooooo0_l000000ooo
oooo0000o`000002o`0001Oooooo0ol00005ooooo`;o00006?ooool2o`0000_ooooo000Yooooo`03
o`000?oooooooooo03kooooo0_l0000Oooooo`;o00008oooool2o`0002Oooooo0_l0000Oooooo`;o
00007oooool2o`000003ooooool0003o000000;o00003?ooool2o`0000cooooo0_l0000Mooooo`;o
00002oooool002Wooooo00?o0000ooooooooool05Oooool2o`0002Oooooo0_l0000>ooooo`;o0000
=?ooool2o`0004[ooooo0_l0000/ooooo`;o00000_ooool2o`0000Oooooo0_l00003ooooo`;o0000
1Oooool2o`0000gooooo0_l0000Dooooo`00:Oooool00ol0003oooooooooo`0Booooo`;o000000?o
ooooo`000?l00000=oooool2o`0004[ooooo0_l00007ooooo`;o00005_ooool2o`0001?ooooo0_l0
000:ooooo`;o00000oooool2o`0001_ooooo0_l00004ooooo`;o00001Oooool2o`0000[ooooo0_l0
0003ooooo`;o00002?ooool2o`0000Kooooo0_l0000<ooooo`00:Oooool2o`0000gooooo0_l00003
ooooo`?o00001oooool2o`0007gooooo0_l000000ooooooo0000o`000004ooooo`;o00005_ooool2
o`0001;ooooo0ol0000:ooooo`;o00000oooool2o`00017ooooo0_l0000>ooooo`;o00005_ooool2
o`000003ooooool0003o000000gooooo0_l0000<ooooo`00:Oooool00ol0003oooooooooo`09oooo
o`;o000000?oooooo`000?l000000oooool2o`0000Sooooo0_l00020ooooo`;o00008?ooool2o`00
00kooooo0_l0000Sooooo`;o00004oooool2o`0001Cooooo0_l0000Kooooo`001_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool02Oooool2o`0003;ooooo0_l0000Booooo`;o0000K?ooool2
o`0000Cooooo0_l0000Aooooo`;o00001Oooool2o`0002Sooooo0_l0000aooooo`001_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01Kooooo0_l0000Hooooo`;o00002ooo
ool2o`0001;ooooo1?l0000Qooooo`?o00002oooool2o`0003[ooooo0_l00003ooooo`;o00004Ooo
ool2o`0000Gooooo0_l0000_ooooo`;o00005_ooool2o`0001;ooooo0006ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool05_ooool2o`0000Wooooo0_l0000=ooooo`;o00001_ooool2o`0000?ooooo0_l0
000<ooooo`;o00001_ooool2o`00027ooooo0ol0000;ooooo`;o0000:_ooool2o`0000kooooo0_l0
0014ooooo`;o00002?ooool2o`0001Kooooo0_l0000Booooo`001_ooool01Ol0003ooooooooooooo
oooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o00001?oo
ool3o`0001Gooooo0_l00003ooooo`;o00005Oooool2o`0000?ooooo0_l0000<ooooo`;o0000?Ooo
ool2o`0002Cooooo0_l00004ooooo`;o00006oooool2o`00037ooooo0_l0000=ooooo`;o00001_oo
ool2o`0001gooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`04ooooo`?o0000
4Oooool2o`0000;ooooo0_l0001/ooooo`;o00000oooool2o`0000oooooo0_l0000Dooooo`Ko0000
5oooool2o`000003ooooool0003o000000;ooooo0_l00008ooooo`;o00004Oooool2o`0001cooooo
0_l00006ooooo`;o00007Oooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Hooooo`;o0000
8Oooool3o`0000oooooo0_l00007ooooo`;o00006_ooool2o`0001;ooooo0_l00007ooooo`;o0000
3oooool2o`0001Kooooo1?l0000Jooooo`;o00000_ooool2o`0000Oooooo0ol0000Aooooo`;o0000
8?ooool2o`00027ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zj
oooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool2o`0001_ooooo0_l0000Booooo`;o
00002oooool3o`0000oooooo0_l00007ooooo`;o00002oooool2o`000003ooooool0003o000000[o
oooo0_l00007ooooo`;o00001?ooool2o`0000?ooooo0_l00008ooooo`;o00005_ooool2o`0000_o
oooo0_l0000Aooooo`;o00006Oooool2o`0000kooooo0_l0000Booooo`;o00004?ooool2o`00027o
oooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
00Cooooo1?l00006ooooo`;o00006?ooool2o`000003ooooool0003o000001;ooooo0_l0000:oooo
o`;o00003_ooool2o`0001Oooooo1Ol0000Cooooo`;o00000oooool3o`0000gooooo0_l0000Foooo
o`;o00002oooool2o`00017ooooo0_l0000;ooooo`;o00000_ooool2o`0000Sooooo0_l0000>oooo
o`;o00004_ooool2o`0001Cooooo0_l0000Mooooo`00:Oooool2o`0001Sooooo0_l0000Qooooo`;o
00003_ooool2o`0000Oooooo0_l0000?ooooo`;o00006_ooool2o`0002[ooooo0_l00004ooooo`;o
00008Oooool2o`0000;ooooo0_l00008ooooo`;o0000>?ooool2o`0001gooooo000Yooooo`03o`00
0?oooooooooo05?ooooo0_l0000booooo`;o00008oooool2o`0000Cooooo0_l0000looooo`?o0000
0oooool2o`0001kooooo0_l0000Tooooo`00:Oooool00ol0003oooooooooo`12ooooo`;o0000@ooo
ool2o`0001Wooooo0ol0001;ooooo`?o00000oooool2o`0001kooooo0_l0000Tooooo`00:Oooool0
0ol0003oooooooooo`12ooooo`;o0000Foooool2o`000004ooooool0003o0000o`0003;ooooo0_l0
000dooooo`;o0000;Oooool002Wooooo00?o0000ooooooooool04_ooool2o`0000_ooooo0_l00010
ooooo`;o00003?ooool2o`00027ooooo0_l0000;ooooo`;o00003Oooool2o`0002Oooooo0_l0000d
ooooo`;o0000;Oooool002Wooooo0_l00002ooooo`;o00003oooool2o`0000_ooooo0_l00010oooo
o`;o00003?ooool2o`00027ooooo0_l0000Jooooo`;o0000:oooool2o`0001kooooo0_l0000Foooo
o`;o00006?ooool2o`0000gooooo000Yooooo`04o`000?ooooooooooooooo`?o0000/Oooool2o`00
02Cooooo0_l00002ooooo`;o00006_ooool2o`0001Kooooo0_l0000Hooooo`;o00003Oooool002Wo
oooo00?o0000ooooooooool00_ooool2o`0003gooooo0_l0001Iooooo`;o00005oooool2o`0002So
oooo0_l0000Xooooo`;o0000<Oooool002Wooooo00?o0000ooooooooool04?ooool2o`0002oooooo
0_l0000]ooooo`;o0000:_ooool2o`0006_ooooo0_l0000aooooo`00:Oooool00ol0003ooooooooo
o`0@ooooo`;o0000@?ooool2o`0001cooooo0_l00002ooooo`;o00007_ooool2o`0002;ooooo0_l0
0017ooooo`;o0000>Oooool002Wooooo0_l0001Cooooo`;o00008?ooool2o`0001kooooo0_l0000R
ooooo`;o00002Oooool2o`0003cooooo0_l0000iooooo`00:Oooool00ol0003oooooooooo`0@oooo
o`;o00004oooool2o`0000Wooooo0_l0000gooooo`;o0000EOooool2o`000003ooooool0003o0000
06;ooooo0_l0000Cooooo`00:Oooool00ol0003oooooooooo`0@ooooo`;o00003Oooool2o`0000?o
oooo0ol00009ooooo`;o00004oooool2o`0002;ooooo0_l0001Eooooo`;o0000IOooool2o`0001?o
oooo000Yooooo`03o`000?oooooooooo01oooooo0_l00003ooooo`;o00007oooool2o`0000oooooo
0_l00006ooooo`;o00000oooool2o`0001Gooooo0_l0000@ooooo`;o0000@oooool2o`0000Sooooo
0_l0001Oooooo`00:Oooool00ol0003oooooooooo`15ooooo`;o00003oooool2o`0000Kooooo0_l0
0003ooooo`;o00005Oooool2o`00013ooooo0_l00013ooooo`;o00002?ooool2o`0005oooooo000Y
ooooo`;o0000A_ooool2o`000?Gooooo000Yooooo`03o`000?oooooooooo07Oooooo0_l00033oooo
o`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool00ol0003oooooooooo`1gooooo`;o0000`oooool000kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000kooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00?ooooo0ol0003ooooooa3ooooo0_l0000[ooooo`003_ooool01Ol0003ooooooooooooooooo
000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooooa3ooooo0_l0000[
ooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo03Gooooo0_l0000hooooo`;o0000?oooool2o`0005?ooooo0_l0
000eooooo`003_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0eooooo`Co00004_ooool2o`0001cooooo0_l00004ooooo`;o0000?ooo
ool2o`0005?ooooo0_l0000Aooooo`;o00008_ooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0=oooool2o`0001;ooooo0_l0
000Looooo`;o0000[Oooool2o`0002;ooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?oo
ool4o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo
00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo?Oooool0
00Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@
413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03
ooooo`?o0000oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Q
ooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool0
00Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@
oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo
1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
01oooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo?Oooool0027o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`00
0?oooooooooo00Gooooo0ol0003oooooocgooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001oooooo00?oEEEEofIVI_l00000
oooooom7ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .36421 Mdot
.02762 .39496 Mdot
.02952 .29669 Mdot
.03143 .29499 Mdot
.03333 .34523 Mdot
.03524 .26955 Mdot
.03714 .29905 Mdot
.03905 .45065 Mdot
.04095 .35894 Mdot
.04286 .2977 Mdot
.04476 .35117 Mdot
.04667 .44267 Mdot
.04857 .23563 Mdot
.05048 .34903 Mdot
.05238 .44066 Mdot
.05429 .33342 Mdot
.05619 .24553 Mdot
.0581 .23448 Mdot
.06 .29336 Mdot
.0619 .42224 Mdot
.06381 .23552 Mdot
.06571 .35702 Mdot
.06762 .33897 Mdot
.06952 .23756 Mdot
.07143 .39843 Mdot
.07333 .34238 Mdot
.07524 .33723 Mdot
.07714 .27042 Mdot
.07905 .41481 Mdot
.08095 .3936 Mdot
.08286 .238 Mdot
.08476 .36667 Mdot
.08667 .44219 Mdot
.08857 .31959 Mdot
.09048 .38478 Mdot
.09238 .41 Mdot
.09429 .26685 Mdot
.09619 .25782 Mdot
.0981 .40644 Mdot
.1 .43492 Mdot
.1019 .38901 Mdot
.10381 .36684 Mdot
.10571 .36485 Mdot
.10762 .38863 Mdot
.10952 .34079 Mdot
.11143 .2523 Mdot
.11333 .3344 Mdot
.11524 .30654 Mdot
.11714 .36243 Mdot
.11905 .41913 Mdot
.12095 .29508 Mdot
.12286 .36821 Mdot
.12476 .43951 Mdot
.12667 .38347 Mdot
.12857 .37772 Mdot
.13048 .41001 Mdot
.13238 .44983 Mdot
.13429 .24597 Mdot
.13619 .23554 Mdot
.1381 .32325 Mdot
.14 .24857 Mdot
.1419 .23358 Mdot
.14381 .40523 Mdot
.14571 .33511 Mdot
.14762 .43187 Mdot
.14952 .39437 Mdot
.15143 .28179 Mdot
.15333 .34222 Mdot
.15524 .25291 Mdot
.15714 .25037 Mdot
.15905 .28041 Mdot
.16095 .27821 Mdot
.16286 .29751 Mdot
.16476 .25604 Mdot
.16667 .40541 Mdot
.16857 .28417 Mdot
.17048 .43931 Mdot
.17238 .26101 Mdot
.17429 .38416 Mdot
.17619 .37093 Mdot
.1781 .33014 Mdot
.18 .39676 Mdot
.1819 .26671 Mdot
.18381 .37403 Mdot
.18571 .44458 Mdot
.18762 .31823 Mdot
.18952 .33843 Mdot
.19143 .3181 Mdot
.19333 .24609 Mdot
.19524 .3415 Mdot
.19714 .39627 Mdot
.19905 .46507 Mdot
.20095 .31353 Mdot
.20286 .28109 Mdot
.20476 .33003 Mdot
.20667 .45757 Mdot
.20857 .34647 Mdot
.21048 .28816 Mdot
.21238 .42936 Mdot
.21429 .24424 Mdot
.21619 .38004 Mdot
.2181 .26773 Mdot
.22 .44386 Mdot
.2219 .3965 Mdot
.22381 .30691 Mdot
.22571 .33623 Mdot
.22762 .29819 Mdot
.22952 .32783 Mdot
.23143 .31142 Mdot
.23333 .2504 Mdot
.23524 .33291 Mdot
.23714 .29305 Mdot
.23905 .35922 Mdot
.24095 .42182 Mdot
.24286 .24319 Mdot
.24476 .26698 Mdot
.24667 .25255 Mdot
.24857 .42018 Mdot
.25048 .40129 Mdot
.25238 .2932 Mdot
.25429 .23712 Mdot
.25619 .22434 Mdot
.2581 .27255 Mdot
.26 .4112 Mdot
.2619 .25282 Mdot
.26381 .31422 Mdot
.26571 .42326 Mdot
.26762 .43562 Mdot
.26952 .39906 Mdot
.27143 .32065 Mdot
.27333 .33303 Mdot
.27524 .39312 Mdot
.27714 .43296 Mdot
.27905 .2529 Mdot
.28095 .33969 Mdot
.28286 .39444 Mdot
.28476 .27283 Mdot
.28667 .4218 Mdot
.28857 .29034 Mdot
.29048 .44575 Mdot
.29238 .43804 Mdot
.29429 .29998 Mdot
.29619 .25914 Mdot
.2981 .26028 Mdot
.3 .24602 Mdot
.3019 .42488 Mdot
.30381 .43724 Mdot
.30571 .22519 Mdot
.30762 .32036 Mdot
.30952 .29799 Mdot
.31143 .23029 Mdot
.31333 .2793 Mdot
.31524 .28113 Mdot
.31714 .24127 Mdot
.31905 .29012 Mdot
.32095 .24034 Mdot
.32286 .31467 Mdot
.32476 .3947 Mdot
.32667 .41538 Mdot
.32857 .27116 Mdot
.33048 .30498 Mdot
.33238 .37101 Mdot
.33429 .38094 Mdot
.33619 .38285 Mdot
.3381 .38708 Mdot
.34 .37141 Mdot
.3419 .36747 Mdot
.34381 .43307 Mdot
.34571 .33518 Mdot
.34762 .25662 Mdot
.34952 .30326 Mdot
.35143 .42176 Mdot
.35333 .31083 Mdot
.35524 .28395 Mdot
.35714 .34315 Mdot
.35905 .34118 Mdot
.36095 .43987 Mdot
.36286 .4509 Mdot
.36476 .24182 Mdot
.36667 .26658 Mdot
.36857 .41276 Mdot
.37048 .33371 Mdot
.37238 .42236 Mdot
.37429 .27023 Mdot
.37619 .37962 Mdot
.3781 .32077 Mdot
.38 .34232 Mdot
.3819 .42964 Mdot
.38381 .37044 Mdot
.38571 .3926 Mdot
.38762 .34942 Mdot
.38952 .24531 Mdot
.39143 .42502 Mdot
.39333 .3105 Mdot
.39524 .22347 Mdot
.39714 .44881 Mdot
.39905 .33263 Mdot
.40095 .43995 Mdot
.40286 .30082 Mdot
.40476 .47796 Mdot
.40667 .34734 Mdot
.40857 .30313 Mdot
.41048 .29649 Mdot
.41238 .27042 Mdot
.41429 .35359 Mdot
.41619 .47785 Mdot
.4181 .38328 Mdot
.42 .26308 Mdot
.4219 .25143 Mdot
.42381 .29658 Mdot
.42571 .27975 Mdot
.42762 .34939 Mdot
.42952 .27438 Mdot
.43143 .25626 Mdot
.43333 .33646 Mdot
.43524 .29996 Mdot
.43714 .37168 Mdot
.43905 .24906 Mdot
.44095 .38063 Mdot
.44286 .31187 Mdot
.44476 .28489 Mdot
.44667 .44118 Mdot
.44857 .25043 Mdot
.45048 .23571 Mdot
.45238 .32299 Mdot
.45429 .35105 Mdot
.45619 .32901 Mdot
.4581 .36125 Mdot
.46 .39928 Mdot
.4619 .31206 Mdot
.46381 .43988 Mdot
.46571 .2232 Mdot
.46762 .34348 Mdot
.46952 .29953 Mdot
.47143 .47668 Mdot
.47333 .33866 Mdot
.47524 .33502 Mdot
.47714 .2337 Mdot
.47905 .26764 Mdot
.48095 .40127 Mdot
.48286 .26532 Mdot
.48476 .38977 Mdot
.48667 .23189 Mdot
.48857 .30535 Mdot
.49048 .37479 Mdot
.49238 .27898 Mdot
.49429 .37803 Mdot
.49619 .33557 Mdot
.4981 .33798 Mdot
.5 .28838 Mdot
.5019 .27463 Mdot
.50381 .40214 Mdot
.50571 .34583 Mdot
.50762 .26542 Mdot
.50952 .30315 Mdot
.51143 .32099 Mdot
.51333 .33922 Mdot
.51524 .29405 Mdot
.51714 .36242 Mdot
.51905 .27686 Mdot
.52095 .44904 Mdot
.52286 .26926 Mdot
.52476 .35107 Mdot
.52667 .33541 Mdot
.52857 .36646 Mdot
.53048 .29425 Mdot
.53238 .29521 Mdot
.53429 .33833 Mdot
.53619 .33927 Mdot
.5381 .3194 Mdot
.54 .41701 Mdot
.5419 .35722 Mdot
.54381 .41861 Mdot
.54571 .37064 Mdot
.54762 .30118 Mdot
.54952 .3681 Mdot
.55143 .31665 Mdot
.55333 .26062 Mdot
.55524 .35951 Mdot
.55714 .31031 Mdot
.55905 .35049 Mdot
.56095 .24106 Mdot
.56286 .4042 Mdot
.56476 .33079 Mdot
.56667 .26902 Mdot
.56857 .27474 Mdot
.57048 .44639 Mdot
.57238 .33382 Mdot
.57429 .31791 Mdot
.57619 .35804 Mdot
.5781 .41668 Mdot
.58 .27592 Mdot
.5819 .30526 Mdot
.58381 .42755 Mdot
.58571 .2298 Mdot
.58762 .44499 Mdot
.58952 .22969 Mdot
.59143 .27143 Mdot
.59333 .22909 Mdot
.59524 .23042 Mdot
.59714 .40611 Mdot
.59905 .44265 Mdot
.60095 .26255 Mdot
.60286 .37111 Mdot
.60476 .33132 Mdot
.60667 .39737 Mdot
.60857 .3742 Mdot
.61048 .40084 Mdot
.61238 .34373 Mdot
.61429 .3007 Mdot
.61619 .34942 Mdot
.6181 .32443 Mdot
.62 .28659 Mdot
.6219 .25222 Mdot
.62381 .24543 Mdot
.62571 .24279 Mdot
.62762 .27197 Mdot
.62952 .30426 Mdot
.63143 .34693 Mdot
.63333 .43784 Mdot
.63524 .30641 Mdot
.63714 .42004 Mdot
.63905 .2966 Mdot
.64095 .35115 Mdot
.64286 .33827 Mdot
.64476 .24654 Mdot
.64667 .37807 Mdot
.64857 .39182 Mdot
.65048 .36036 Mdot
.65238 .30836 Mdot
.65429 .28137 Mdot
.65619 .27893 Mdot
.6581 .44665 Mdot
.66 .33333 Mdot
.6619 .33047 Mdot
.66381 .3151 Mdot
.66571 .32669 Mdot
.66762 .2699 Mdot
.66952 .39785 Mdot
.67143 .27875 Mdot
.67333 .37055 Mdot
.67524 .37065 Mdot
.67714 .35755 Mdot
.67905 .45293 Mdot
.68095 .34315 Mdot
.68286 .40092 Mdot
.68476 .3341 Mdot
.68667 .42966 Mdot
.68857 .34339 Mdot
.69048 .42302 Mdot
.69238 .38794 Mdot
.69429 .2743 Mdot
.69619 .26611 Mdot
.6981 .29842 Mdot
.7 .44351 Mdot
.7019 .22907 Mdot
.70381 .41503 Mdot
.70571 .37288 Mdot
.70762 .33296 Mdot
.70952 .42185 Mdot
.71143 .31833 Mdot
.71333 .44387 Mdot
.71524 .37124 Mdot
.71714 .38059 Mdot
.71905 .43488 Mdot
.72095 .41651 Mdot
.72286 .37436 Mdot
.72476 .27191 Mdot
.72667 .35218 Mdot
.72857 .43766 Mdot
.73048 .44971 Mdot
.73238 .278 Mdot
.73429 .27888 Mdot
.73619 .33495 Mdot
.7381 .24533 Mdot
.74 .37498 Mdot
.7419 .30604 Mdot
.74381 .40034 Mdot
.74571 .2411 Mdot
.74762 .36506 Mdot
.74952 .3484 Mdot
.75143 .23059 Mdot
.75333 .34375 Mdot
.75524 .41362 Mdot
.75714 .21963 Mdot
.75905 .26907 Mdot
.76095 .24386 Mdot
.76286 .30629 Mdot
.76476 .33351 Mdot
.76667 .24755 Mdot
.76857 .27651 Mdot
.77048 .41645 Mdot
.77238 .25392 Mdot
.77429 .31003 Mdot
.77619 .26005 Mdot
.7781 .30624 Mdot
.78 .32594 Mdot
.7819 .3236 Mdot
.78381 .34501 Mdot
.78571 .22374 Mdot
.78762 .41896 Mdot
.78952 .29005 Mdot
.79143 .46294 Mdot
.79333 .31572 Mdot
.79524 .33886 Mdot
.79714 .35532 Mdot
.79905 .31628 Mdot
.80095 .44821 Mdot
.80286 .44369 Mdot
.80476 .33922 Mdot
.80667 .286 Mdot
.80857 .31918 Mdot
.81048 .2961 Mdot
.81238 .28336 Mdot
.81429 .2868 Mdot
.81619 .38923 Mdot
.8181 .25915 Mdot
.82 .27832 Mdot
.8219 .31065 Mdot
.82381 .3155 Mdot
.82571 .30336 Mdot
.82762 .31121 Mdot
.82952 .26249 Mdot
.83143 .22686 Mdot
.83333 .44569 Mdot
.83524 .29065 Mdot
.83714 .38629 Mdot
.83905 .29791 Mdot
.84095 .24638 Mdot
.84286 .34682 Mdot
.84476 .26981 Mdot
.84667 .32245 Mdot
.84857 .46994 Mdot
.85048 .40207 Mdot
.85238 .30709 Mdot
.85429 .39609 Mdot
.85619 .27507 Mdot
.8581 .36731 Mdot
.86 .43531 Mdot
.8619 .35034 Mdot
.86381 .38901 Mdot
.86571 .44969 Mdot
.86762 .27828 Mdot
.86952 .32339 Mdot
.87143 .34879 Mdot
.87333 .36653 Mdot
.87524 .36912 Mdot
.87714 .47421 Mdot
.87905 .30388 Mdot
.88095 .38479 Mdot
.88286 .36723 Mdot
.88476 .33565 Mdot
.88667 .26739 Mdot
.88857 .25571 Mdot
.89048 .45047 Mdot
.89238 .29107 Mdot
.89429 .39131 Mdot
.89619 .40145 Mdot
.8981 .3283 Mdot
.9 .42162 Mdot
.9019 .27761 Mdot
.90381 .27074 Mdot
.90571 .44079 Mdot
.90762 .26541 Mdot
.90952 .4456 Mdot
.91143 .34433 Mdot
.91333 .33822 Mdot
.91524 .22912 Mdot
.91714 .35219 Mdot
.91905 .25088 Mdot
.92095 .42335 Mdot
.92286 .38245 Mdot
.92476 .30422 Mdot
.92667 .26295 Mdot
.92857 .32177 Mdot
.93048 .23954 Mdot
.93238 .34879 Mdot
.93429 .28671 Mdot
.93619 .37476 Mdot
.9381 .37145 Mdot
.94 .27097 Mdot
.9419 .33979 Mdot
.94381 .38431 Mdot
.94571 .34136 Mdot
.94762 .27202 Mdot
.94952 .32033 Mdot
.95143 .39635 Mdot
.95333 .34734 Mdot
.95524 .32031 Mdot
.95714 .25606 Mdot
.95905 .26262 Mdot
.96095 .30474 Mdot
.96286 .25204 Mdot
.96476 .30998 Mdot
.96667 .39646 Mdot
.96857 .23389 Mdot
.97048 .39271 Mdot
.97238 .25283 Mdot
.97429 .41892 Mdot
.97619 .43126 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0>Sooooo0_l0001Booooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool0Aoooool2o`0002_ooooo0_l0000Dooooo`;o0000G?ooool2o`0000Oooooo0_l00019
ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo04Oooooo0_l0
000>ooooo`;o00006oooool2o`0001Cooooo0_l0001Uooooo`;o00003Oooool2o`0003[ooooo0004
o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`1Gooooo`Co0000E_ooool5o`00023ooooo0_l0
000>ooooo`;o00006?ooool2o`0001Wooooo0_l0000Oooooo`001_ooool01Ol0003ooooooooooooo
oooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o00008_oo
ool2o`0003Gooooo0_l0000cooooo`;o000000?oooooo`000?l000007_ooool5o`00023ooooo0_l0
000>ooooo`;o0000<oooool2o`0000oooooo0_l0000>ooooo`001_ooool01Ol0003ooooooooooooo
oooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool01?ooool2o`000003ooooool0003o000000;o00005Oooool4o`0002;ooooo
0_l0000mooooo`;o00001oooool2o`000003ooooool0003o000009Wooooo0_l0000>ooooo`001_oo
ool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Cooooo0_l000000ooooooo0000o`000004o`0000;ooooo
0_l0000?ooooo`;o00009?ooool2o`0001Cooooo0_l0000Wooooo`;o0000VOooool2o`0001[ooooo
0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0;ooooo`;o00000_ooool2o`0003;o
oooo0_l0000Fooooo`?o00003?ooool2o`0003gooooo0_l0000Cooooo`;o00009?ooool2o`0003[o
oooo0_l0000Jooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`07ooooo`;o00005oooool2o`00
017ooooo0_l00005ooooo`;o00001oooool2o`00013ooooo0_l00004ooooo`;o00003Oooool2o`00
00Kooooo0_l0000eooooo`;o00004_ooool3o`0000Cooooo0_l0000Looooo`Co00000oooool2o`00
01Sooooo0_l0000gooooo`00:Oooool2o`0000Sooooo0_l0000Gooooo`Co00003oooool2o`0000Go
oooo0_l0000Iooooo`;o00006oooool2o`0000kooooo0_l0000iooooo`;o00001Oooool2o`0001co
oooo0_l00005ooooo`Co00005_ooool2o`0003Oooooo000Yooooo`03o`000?oooooooooo01Sooooo
0_l00008ooooo`;o00000oooool2o`0001Oooooo0_l00002ooooo`;o00000oooool2o`00037ooooo
0_l00004ooooo`;o000000?oooooo`000?l00000=_ooool2o`0002cooooo0_l0000_ooooo`;o0000
3?ooool2o`000003ooooool0003o000000gooooo000Yooooo`03o`000?oooooooooo01Sooooo0_l0
000=ooooo`;o00005oooool2o`0000;ooooo0_l00003ooooo`;o00000oooool2o`0002cooooo0_l0
0007ooooo`;o0000=_ooool2o`0002kooooo0_l0000Sooooo`;o00002?ooool2o`0000cooooo0_l0
00000ooooooo0000o`00000=ooooo`00:Oooool00ol0003oooooooooo`0Dooooo`;o00004Oooool2
o`000003ooooool0003o000002;ooooo0_l0000Dooooo`;o00006Oooool2o`0006cooooo0_l0000S
ooooo`;o00005?ooool2o`0001;ooooo000Yooooo`03o`000?oooooooooo01Cooooo0_l0000Doooo
o`Co00009_ooool2o`0000kooooo0_l0000Iooooo`;o00009_ooool2o`0004Gooooo0_l0000<oooo
o`;o0000:_ooool2o`0001;ooooo000Yooooo`;o0000;Oooool2o`0002Kooooo0_l0000Vooooo`;o
0000:Oooool2o`0000gooooo0_l0000fooooo`;o00003?ooool2o`000003ooooool0003o000001ko
oooo0_l00008ooooo`;o00004Oooool002Wooooo00?o0000ooooooooool04oooool2o`0001[ooooo
0_l0000:ooooo`;o00001_ooool2o`0002Kooooo0_l0000?ooooo`;o00004Oooool3o`0000Kooooo
0_l0000Looooo`;o00007?ooool2o`0002Wooooo0_l0000Aooooo`;o00001?ooool2o`0000Gooooo
0_l00008ooooo`;o00004Oooool002Wooooo00?o0000ooooooooool00_l0000;ooooo`;o00001?oo
ool2o`0001[ooooo1Ol000001ol@413oooooooooooo^k^ko<S8bo`000?lb<S800_l00002ooooo`04
onk^k_lb<S;o0000oc8b<P;o00006Oooool2o`0000_ooooo1ol00003ooooo`04onk^k_lb<S;o0000
oc8b<P;o00000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo0ol00006ooooo`;o00000ooo
ool2o`0000_ooooo00GoV9RHo`000?l0003o<S8bolc<c003ooooo`05onk^k_l0003o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo0_l00007ooooo`;o00004oooool2o`00
0009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP08ooooo`;o00003?ooool2o`0000?ooooo0ol00009ooooo`;o000000GoA4A4o`000?l0
003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo000Yooooo`03o`000?oooooooooo00;o00002oooool2o`0002?ooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`04ooooo`;o00001_ooool2o`0000cooooo0_l0000=ooooo`;o000000?ok^k^oooooom4A4@0
0oooool01?mgMgOoV9RHoooooonHV9P2o`0000;ooooo00GoMgMgoiRHV?l0003o0000ogMgM`0Koooo
o`;o00002oooool01Ol@413o0000o`000?mgMgOo<S8b00?ooooo00GoMgMgo`000?l0003oV9RHogMg
M`03ooooo`04ogMgMonHV9SooooooiRHV0;o00002oooool2o`0000Oooooo0_l00008ooooo`;o0000
2Oooool2o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02?ooool2o`00017ooooo0_l0000:ooooo`Co000000?oooooogMgMolb<S800_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41001?ooool2o`0000Kooooo0_l0000Looooo`03oiRH
V?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo0000o`00
0?l@41005?ooool2o`0000Cooooo0_l0000=ooooo`;o000000Koooooo`000?l0003o0000ooooool@
4103ooooo`05oa0@4?ooooooooooooooool@41000oooool2o`0001Cooooo0_l00008ooooo`;o0000
1oooool7o`000003ooooool@413ooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo00[ooooo0_l0000=ooooo`;o00003?ooool2o`0000;ooooo00Co0000oooooooo
oooo410@0oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool00Oooool0
02Wooooo0_l0000Yooooo`;o00002?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000001Gooooo0_l0000Dooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003ooooo`;o00000_ooool00ol0003ooooo
ooooo`0?ooooo`;o000000?oooooo`000?l000001?ooool2o`0000gooooo0_l000001_nYZJWo410@
o`000?l0003oooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
oooo00Oooooo0_l00003ooooo`;o00004Oooool3o`0000Cooooo00GoA4A4omgMgOoooooo0000oooo
o`02o`000003ooooool0003ooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`?o0000
2_ooool2o`0000;ooooo0_l00009ooooo`;o00003oooool01OmgMgOo<S8boooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo007ooooo000Yooooo`03
o`000?oooooooooo02Gooooo0_l000000ooooooo0000o`000008ooooo`04o`000?oooooooooooooo
o`;o00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool04oooool3
o`0001Cooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo0_l0
0002ooooo`03o`000?oooooooooo00oooooo0_l0000Gooooo`03oa0@4?l0003o^[Zj00?ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool3o`0000?o
oooo0_l0000Aooooo`?o00001?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`04o`0000kooooo0_l0000Gooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`00:Oooool00ol0003oooooooooo`0Uooooo`;o00001?ooool2o`0000Gooooo
00Co0000oooooooooooooooo0_l00003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@
413oooooooooo`0Dooooo`;o00002oooool2o`0000Sooooo00Go0000oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`02o`0002Oooooo00?o
^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@ooooool0003o
0000oa0@4008ooooo`;o00007oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooooooo
ool@41000oooool00ol@413o0000o`000002o`0002Gooooo0_l00002ooooo`03o`000?oooooooooo
00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool002Wooooo00?o0000ooooooooool0:oooool2o`0000Gooooo00?o0000ooooooooool00_ooool0
1OmgMgOo0000o`000?nHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Gooooo`;o0000
2_ooool2o`0000Cooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo0_l0000?ooooo`;o00004oooool0
1Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMg
MonHV9So0000o`000?mgMgL0:Oooool00oo^k^koA4A4o`000004ooooo`03ogMgMonHV9Sooooo00;o
00000oooool00omgMgOo0000o`000002o`0002Gooooo0_l00002ooooo`03o`000?oooooooooo00Co
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0
02Wooooo00?o0000ooooooooool0<?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_l0003o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?l0003ok^k^00;ooooo0_l00009ooooo`;o00002?oo
ool2o`00013ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01?ooooo0_l0000Cooooo`05ojVYZOl@413o0000
oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0Zooooo`03ogMgMol0003ooooo00?ooooo00?ok^k^oc8b<_l000000_l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2o`00017ooooo0_l0000?ooooo`Co00000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool4o`00
00Oooooo0_l0000Booooo`;o00008oooool2o`0000?ooooo0_l00009ooooo`;o0000Aoooool2o`00
00?ooooo0ol0001Gooooo`;o00001_ooool2o`00017ooooo0_l0000Vooooo`00:Oooool7o`0000Co
oooo0_l0000Booooo`;o00002oooool2o`0001?ooooo0_l0000Hooooo`;o00007oooool2o`0000;o
oooo0_l0000Kooooo`;o00000oooool3o`00023ooooo0_l0000Aooooo`;o00008_ooool2o`0000Oo
oooo0_l0000hooooo`00:Oooool3o`000004ooooool0003o0000o`0002Gooooo0_l0000Cooooo`;o
00004oooool2o`0000?ooooo0_l0000Looooo`;o000000?oooooo`000?l000000_ooool2o`0000;o
oooo0_l00009ooooo`;o00005oooool2o`0001?ooooo0_l00006ooooo`;o00004Oooool2o`0002_o
oooo0_l0000hooooo`00:Oooool00ol0003oooooooooo`1Cooooo`;o00002_ooool2o`0000Cooooo
0_l0000?ooooo`Co00001oooool2o`0000Wooooo0_l00004ooooo`;o00001?ooool2o`0000_ooooo
0_l00009ooooo`;o00002?ooool2o`0000?ooooo0_l0000mooooo`;o00003oooool2o`0000gooooo
0_l0000:ooooo`;o00004?ooool002Wooooo00?o0000ooooooooool06_ooool2o`00027ooooo0_l0
000Pooooo`;o00001?ooool2o`00017ooooo0_l0000Hooooo`;o00001?ooool2o`0001Kooooo0_l0
000=ooooo`Co00000oooool2o`0001_ooooo0_l00005ooooo`;o00000oooool2o`0000gooooo0_l0
0007ooooo`;o00001_ooool2o`0000gooooo0_l0000:ooooo`;o00004?ooool0027oooooool00014
o`0000Cooooo000Yooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool2o`00
00?ooooo00?o0000ooooooooool00_ooool2o`0000Kooooo00Co0000ooooool0003o00002?ooool0
0ol0003oooooooooo`06ooooo`;o000000?oooooo`000?ooool01Oooool2o`0000?ooooo00?o0000
ooooooooool01Oooool2o`0000?ooooo00?o0000ooooooooool02?ooool2o`0000Cooooo0_l00005
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool2o`0000_ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`05ooooo`;o00000_ooool00ol0003oooooooooo`08
ooooo`Co00002_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool01Oooool2o`0000;ooooo00?o0000ooooooooool02_ooool002Wooooo00?o0000oooo
ooooool0<_ooool2o`000003ooooool0003o000000?ooooo00?o0000ooooooooool03?ooool2o`00
017ooooo0_l0000Jooooo`03o`000?oooooooooo00kooooo0_l0000Kooooo`;o00001Oooool2o`00
00Kooooo00?o0000ooooooooool04_ooool2o`0002Kooooo00?o0000ooooool000000ol00006oooo
o`;o0000;oooool00ol0003oooooooooo`0:ooooo`00:Oooool00ol0003oooooooooo`0Aooooo`;o
00007_ooool3o`0001Sooooo0_l0000:ooooo`;o00005?ooool2o`0002Wooooo0_l00007ooooo`;o
00000_ooool2o`0000Gooooo0_l0000Kooooo`;o00003Oooool2o`0001Wooooo1?l000000ooooooo
0000o`000003ooooo`;o00009_ooool4o`0001;ooooo000Yooooo`03o`000?oooooooooo017ooooo
0_l0000>ooooo`;o00003_ooool2o`0001Wooooo0_l0000:ooooo`;o00005?ooool2o`0001Kooooo
0_l0000Aooooo`;o00001oooool2o`0003Gooooo0_l0000Eooooo`;o00001oooool2o`0000[ooooo
0_l00005ooooo`;o00004Oooool2o`0000Gooooo1?l0000Booooo`00:Oooool2o`0002;ooooo0_l0
001Sooooo`;o0000<oooool2o`0000kooooo0_l0000Rooooo`?o00004oooool2o`0000Gooooo0_l0
000Aooooo`;o00006oooool002Wooooo00?o0000ooooooooool0;_ooool2o`0000Kooooo0_l00006
ooooo`;o0000Aoooool2o`0003;ooooo0_l0000<ooooo`Co00008_ooool2o`0002Cooooo0_l0000U
ooooo`00:Oooool00ol0003oooooooooo`06ooooo`;o00009_ooool2o`0000Kooooo0_l00006oooo
o`Co00002oooool2o`0002Kooooo0_l0000@ooooo`;o00008Oooool2o`0000_ooooo0_l0000@oooo
o`;o00003Oooool2o`00017ooooo0_l0000Xooooo`;o00009Oooool002Wooooo00?o0000oooooooo
ool01_ooool2o`00017ooooo0_l00008ooooo`;o00006?ooool2o`000003ooooool0003o000000_o
oooo0_l0000Eooooo`;o00001_ooool2o`0000Oooooo0_l00009ooooo`;o00002oooool2o`0000Go
oooo0_l00008ooooo`;o00002_ooool2o`000003ooooool0003o000000Sooooo0_l0000@ooooo`;o
00001_ooool2o`0000Gooooo0_l00007ooooo`;o00002?ooool2o`0002Cooooo0_l0000Yooooo`00
:Oooool00ol0003oooooooooo`0:ooooo`;o000000?oooooo`000?l000002_ooool2o`0000Sooooo
0_l0000=ooooo`;o00002Oooool2o`00013ooooo0_l0000Cooooo`;o00001_ooool2o`0001;ooooo
0_l0000;ooooo`;o00001Oooool3o`0000?ooooo0_l00002ooooo`Go00002_ooool2o`0001Cooooo
0_l0000<ooooo`;o00003_ooool2o`00017ooooo0_l000000ooooooo0000o`00000Hooooo`;o0000
1oooool2o`0000Oooooo0_l0000Gooooo`00:Oooool2o`0000_ooooo1Ol00009ooooo`;o00003?oo
ool2o`0000[ooooo0ol0000Jooooo`;o00005oooool2o`0000Gooooo0_l0000Looooo`;o00001_oo
ool2o`0000?ooooo0_l00004ooooo`?o00008?ooool2o`0002oooooo0_l000000ooooooo0000o`00
000Qooooo`;o00001oooool4o`0001Gooooo000Yooooo`04o`000?oooooo0000o`0000_ooooo0_l0
000:ooooo`;o00003?ooool2o`0000_ooooo0_l0000booooo`?o00001Oooool2o`0001[ooooo0_l0
000:ooooo`;o00008Oooool2o`0001Cooooo1?l0000Cooooo`;o00002?ooool2o`0002Oooooo0_l0
0009ooooo`;o00005Oooool002Wooooo00Co0000ooooool0003o00001?ooool2o`00037ooooo0_l0
000]ooooo`;o00003_ooool2o`0001;ooooo0_l0000:ooooo`;o00008Oooool2o`0000Cooooo0_l0
000>ooooo`Co00004_ooool3o`0000Sooooo0_l0000Aooooo`;o00001oooool2o`0000_ooooo0_l0
0004ooooo`;o00001Oooool2o`0001?ooooo000Yooooo`03o`000?oooooooooo00?ooooo1?l0000a
ooooo`;o0000=oooool2o`0000Cooooo0_l00005ooooo`;o00001oooool2o`0001Cooooo0_l00009
ooooo`;o00004Oooool2o`0000?ooooo0_l000000ooooooo0000o`00000Iooooo`;o00001_ooool2
o`0001cooooo0_l00004ooooo`;o000000?oooooo`000?l000003Oooool2o`0000;ooooo0_l00005
ooooo`;o00004oooool002Wooooo00?o0000ooooooooool00oooool2o`0006cooooo0_l00007oooo
o`;o00000_ooool2o`0000Oooooo0_l0000Dooooo`;o00002Oooool2o`00017ooooo0_l00006oooo
o`;o00006Oooool2o`0001Gooooo0_l0000Cooooo`;o00004?ooool2o`0001kooooo000Yooooo`;o
00002oooool2o`0006kooooo0_l0000Wooooo`;o00002Oooool2o`0001kooooo0_l0000Uooooo`;o
0000AOooool002Wooooo00?o0000ooooooooool00_ooool2o`0000Kooooo0_l0000eooooo`;o0000
AOooool2o`0001Wooooo0_l00002ooooo`;o00001Oooool2o`0001Kooooo0_l00006ooooo`;o0000
K?ooool002Wooooo0_l00003ooooo`;o00005_ooool2o`0002Gooooo0_l00015ooooo`;o00004Ooo
ool2o`0000[ooooo0_l0000Mooooo`;o0000M?ooool002Wooooo0_l0000Aooooo`;o00001?ooool3
o`000003ooooool0003o000004Oooooo0_l0000fooooo`;o00000_ooool2o`0004Cooooo0_l0000R
ooooo`;o00000_ooool2o`000003ooooool0003o000002[ooooo000Yooooo`03o`000?oooooooooo
013ooooo0_l00004ooooo`?o00000oooool2o`0000oooooo0_l0000`ooooo`;o00000_ooool2o`00
00_ooooo0_l0000]ooooo`;o00000oooool3o`0002Kooooo0ol0000Eooooo`;o00008_ooool2o`00
00;ooooo1Ol0000Zooooo`00:Oooool2o`0001gooooo0_l0000?ooooo`;o000000?oooooo`000?l0
0000;Oooool2o`000003ooooool0003o000000cooooo0_l0000?ooooo`;o00008Oooool3o`0000oo
oooo0_l0000Eooooo`?o00002?ooool2o`000003ooooool0003o0000037ooooo0_l0000Booooo`;o
00006?ooool002Wooooo00?o0000ooooooooool0<?ooool2o`00033ooooo0_l0000Mooooo`;o0000
3oooool2o`0002;ooooo1?l0000Nooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o0000
?Oooool2o`0001Sooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Nooooo`;o
00006_ooool2o`0003;ooooo0_l0000Rooooo`Co00008_ooool2o`0000_ooooo0_l0000Fooooo`;o
00001?ooool2o`0003gooooo0_l0000Hooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo01kooooo0_l0000Jooooo`;o00009?ooool3o`0000_ooooo0_l0000;oooo
o`;o00001Oooool2o`00013ooooo0_l0000_ooooo`;o00005?ooool2o`00043ooooo0_l0000Moooo
o`001_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo01;ooooo0_l00009ooooo`;o00003_ooool2o`00
037ooooo0ol0000Hooooo`;o00001Oooool2o`0005Oooooo0_l0000Uooooo`;o00003?ooool2o`00
00_ooooo0_l00005ooooo`;o00005_ooool000Kooooo00Go0000ooooooooooooooooo`00000=oooo
o`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0001;ooooo0_l000000ooo
oooo0000o`000002o`0000Cooooo0_l0000>ooooo`;o0000<_ooool2o`00073ooooo0_l0000Voooo
o`;o00001Oooool2o`0000Kooooo0_l00004ooooo`;o00004_ooool2o`0001Kooooo0006ooooo`05
o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Eooooo`Co0000B?ooool2o`0000kooooo0_l0000M
ooooo`;o0000<oooool2o`0000cooooo0_l0000Vooooo`;o00003Oooool2o`0000Sooooo0_l0000G
ooooo`;o00003Oooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01oooool2o`00013ooooo0_l0000Dooooo`;o00009_ooool2
o`000003ooooool0003o000000_ooooo0_l0000Booooo`;o00007Oooool2o`0003?ooooo0_l0001=
ooooo`;o00005oooool2o`0000gooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool2o`0000gooooo0_l0
00000ooooooo0000o`00000Dooooo`;o00001oooool2o`0000Cooooo0_l00006ooooo`;o00003ooo
ool2o`000003ooooool0003o000000_ooooo0_l0001Iooooo`;o00004_ooool2o`0003Wooooo0_l0
000Nooooo`;o00000_ooool2o`0000oooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo00cooooo
0_l0000Pooooo`;o00001?ooool2o`0000Kooooo0_l00007ooooo`;o00001?ooool2o`0003cooooo
0_l00004ooooo`;o00009oooool3o`00017ooooo0_l00002ooooo`;o00004_ooool2o`00023ooooo
0ol0000<ooooo`;o00004?ooool2o`0000;ooooo0_l0000?ooooo`00:Oooool2o`0002Cooooo0_l0
000Pooooo`;o00001?ooool2o`0003cooooo0_l00004ooooo`;o00001_ooool2o`00017ooooo0_l0
000=ooooo`;o00005Oooool2o`0001;ooooo0_l0000Pooooo`;o00003Oooool2o`0002Gooooo000Y
ooooo`03o`000?oooooooooo01Cooooo0_l0000=ooooo`;o00001Oooool2o`0006_ooooo0_l0000A
ooooo`;o00002Oooool2o`0008Gooooo000Yooooo`03o`000?oooooooooo01;ooooo1?l00009oooo
o`;o00002Oooool2o`0001cooooo0_l0001[ooooo`;o0000QOooool002Wooooo00?o0000oooooooo
ool04_ooool2o`0000_ooooo0_l0000Wooooo`;o00008Oooool2o`0007[ooooo0_l0001Cooooo`00
:Oooool00ol0003oooooooooo`0>ooooo`;o0000C_ooool2o`0000_ooooo0_l0000eooooo`;o0000
2_ooool2o`0002Oooooo0_l00003ooooo`;o00002Oooool2o`0000?ooooo0_l0001>ooooo`00:Ooo
ool2o`0000oooooo0_l0000;ooooo`;o0000:?ooool2o`0001Oooooo0_l00012ooooo`?o00002Ooo
ool2o`00017ooooo0_l0000Dooooo`;o00000oooool2o`0000kooooo0_l00004ooooo`;o0000>_oo
ool2o`0000cooooo000Yooooo`03o`000?oooooooooo00Wooooo0_l0000@ooooo`;o00009Oooool2
o`000003ooooool0003o000000?ooooo0_l00005ooooo`;o00004oooool2o`0000Cooooo0_l0000e
ooooo`;o00007?ooool2o`00013ooooo0_l00004ooooo`;o00005oooool2o`0002;ooooo0_l00005
ooooo`;o00003oooool2o`0000cooooo000Yooooo`03o`000?oooooooooo00Wooooo0_l0000goooo
o`;o00001_ooool2o`0000Gooooo0_l00003ooooo`;o00003_ooool2o`0000Cooooo0_l00004oooo
o`;o0000Goooool2o`0000Cooooo0_l0000kooooo`;o00001Oooool2o`0001gooooo000Yooooo`03
o`000?oooooooooo03Wooooo0_l0000Kooooo`;o00005oooool2o`000003ooooool0003o000003co
oooo0_l0000Oooooo`;o0000JOooool002Wooooo00?o0000ooooooooool09?ooool2o`0001?ooooo
0_l0000Cooooo`;o00004oooool2o`0000[ooooo0_l0000oooooo`;o00007oooool2o`0005cooooo
0_l0000;ooooo`00:Oooool2o`0001Kooooo0_l0000=ooooo`;o00009Oooool2o`000003ooooool0
003o000001?ooooo0_l0001gooooo`;o0000:oooool2o`0002Cooooo0_l0000;ooooo`00:Oooool0
0ol0003oooooooooo`0Eooooo`;o00005?ooool2o`0001kooooo0_l00006ooooo`;o000000?ooooo
o`000?l00000J?ooool2o`0001[ooooo0_l000000ooooooo0000o`00000Xooooo`;o0000<Oooool0
02Wooooo00?o0000ooooooooool01Oooool2o`0000Wooooo0_l0000;ooooo`;o00003?ooool2o`00
02Kooooo0_l000000ooooooo0000o`00000Aooooo`;o00002oooool2o`0000cooooo0_l00004oooo
o`;o0000=?ooool2o`0001gooooo0_l0000gooooo`;o00008_ooool002Wooooo00?o0000oooooooo
ool01?ooool3o`0000Wooooo0_l0000;ooooo`;o00004Oooool2o`0000Wooooo0_l0000/ooooo`;o
00002oooool2o`0000cooooo0_l00004ooooo`;o00009_ooool2o`000003ooooool0003o000001oo
oooo0_l00002ooooo`;o00006oooool2o`0001oooooo0ol0000Qooooo`00:Oooool00ol0003ooooo
ooooo`04ooooo`;o0000:_ooool2o`0000Wooooo0_l0000Eooooo`;o0000F?ooool2o`0000Cooooo
0_l000000ooooooo0000o`00000Aooooo`;o00003?ooool2o`0000;ooooo0_l0000Jooooo`?o0000
2?ooool2o`0001Kooooo0_l0000Qooooo`00:Oooool2o`0000;ooooo0_l0000Looooo`;o0000<Ooo
ool2o`0001Gooooo0_l00009ooooo`;o00009_ooool2o`0000kooooo0_l0000Jooooo`;o00005Ooo
ool2o`0001Gooooo0_l00009ooooo`;o00002?ooool2o`0000Kooooo0_l0000Wooooo`00:Oooool0
1?l0003oooooooooooooool2o`0001cooooo0_l00018ooooo`;o00002Oooool2o`0002Kooooo0_l0
000aooooo`;o00003_ooool2o`0002[ooooo0_l00006ooooo`;o00009oooool000kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo
00?o0000ooooooooool0=oooool2o`0009Kooooo0_l0001[ooooo`003_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
=oooool2o`000?oooooo1?ooool000kooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`00
0?oooooooooo00?ooooo0ol0003cooooo`;o0000Aoooool000kooooo00Go0000oooooooooooooooo
o`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0=Oooool2o`000;cooooo
0_l00017ooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo03Gooooo0_l0003>ooooo`;o0000=Oooool000kooooo
00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0ooooool6ooooo`;o0000=Oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0S?ooool2o`00087ooooo0_l0000[ooooo`00
3_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000N?ooool2o`000003
ooooool0003o0000013ooooo0_l00021ooooo`;o0000:oooool002Wooooo00?o0000ooooooooool0
Moooool2o`000003ooooool0003o00000<3ooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVY
ZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000Kooooo00Go
0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05o`000?ooooooooooooooool00000
3_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003o
ooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWo
MgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`00
1_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Oooooo`Co000000?o410@ooooooooool00ooo
ool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`?o0000oooooolmoooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Oooooo`03oeEEEOmVIVKo00000?ooooooAoooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .28186 Mdot
.02762 .40273 Mdot
.02952 .27478 Mdot
.03143 .25917 Mdot
.03333 .36293 Mdot
.03524 .35297 Mdot
.03714 .2696 Mdot
.03905 .43274 Mdot
.04095 .25306 Mdot
.04286 .25542 Mdot
.04476 .33247 Mdot
.04667 .4466 Mdot
.04857 .31691 Mdot
.05048 .30804 Mdot
.05238 .44245 Mdot
.05429 .34181 Mdot
.05619 .29521 Mdot
.0581 .30494 Mdot
.06 .25263 Mdot
.0619 .41854 Mdot
.06381 .31341 Mdot
.06571 .40253 Mdot
.06762 .39575 Mdot
.06952 .28722 Mdot
.07143 .44662 Mdot
.07333 .26944 Mdot
.07524 .35065 Mdot
.07714 .265 Mdot
.07905 .42475 Mdot
.08095 .40191 Mdot
.08286 .28838 Mdot
.08476 .26099 Mdot
.08667 .39623 Mdot
.08857 .24682 Mdot
.09048 .35038 Mdot
.09238 .35461 Mdot
.09429 .36792 Mdot
.09619 .32048 Mdot
.0981 .4249 Mdot
.1 .45284 Mdot
.1019 .44496 Mdot
.10381 .3015 Mdot
.10571 .38845 Mdot
.10762 .32751 Mdot
.10952 .25269 Mdot
.11143 .32032 Mdot
.11333 .2755 Mdot
.11524 .22823 Mdot
.11714 .37332 Mdot
.11905 .41716 Mdot
.12095 .22966 Mdot
.12286 .42113 Mdot
.12476 .48055 Mdot
.12667 .37522 Mdot
.12857 .38565 Mdot
.13048 .32851 Mdot
.13238 .43428 Mdot
.13429 .29211 Mdot
.13619 .27849 Mdot
.1381 .24203 Mdot
.14 .30551 Mdot
.1419 .2698 Mdot
.14381 .42422 Mdot
.14571 .29862 Mdot
.14762 .37382 Mdot
.14952 .3007 Mdot
.15143 .26076 Mdot
.15333 .3259 Mdot
.15524 .30829 Mdot
.15714 .26346 Mdot
.15905 .24928 Mdot
.16095 .31762 Mdot
.16286 .25568 Mdot
.16476 .29827 Mdot
.16667 .42416 Mdot
.16857 .31327 Mdot
.17048 .48049 Mdot
.17238 .2704 Mdot
.17429 .42571 Mdot
.17619 .34413 Mdot
.1781 .23984 Mdot
.18 .3984 Mdot
.1819 .27833 Mdot
.18381 .31731 Mdot
.18571 .40035 Mdot
.18762 .34601 Mdot
.18952 .3638 Mdot
.19143 .36023 Mdot
.19333 .31598 Mdot
.19524 .32857 Mdot
.19714 .44565 Mdot
.19905 .41075 Mdot
.20095 .33861 Mdot
.20286 .3469 Mdot
.20476 .33277 Mdot
.20667 .39258 Mdot
.20857 .2997 Mdot
.21048 .23176 Mdot
.21238 .47826 Mdot
.21429 .30027 Mdot
.21619 .31123 Mdot
.2181 .34488 Mdot
.22 .44267 Mdot
.2219 .3477 Mdot
.22381 .23411 Mdot
.22571 .25696 Mdot
.22762 .24397 Mdot
.22952 .26075 Mdot
.23143 .33865 Mdot
.23333 .26363 Mdot
.23524 .27231 Mdot
.23714 .25937 Mdot
.23905 .25299 Mdot
.24095 .38548 Mdot
.24286 .36874 Mdot
.24476 .28765 Mdot
.24667 .28417 Mdot
.24857 .34509 Mdot
.25048 .31158 Mdot
.25238 .38449 Mdot
.25429 .32208 Mdot
.25619 .322 Mdot
.2581 .36222 Mdot
.26 .42707 Mdot
.2619 .26057 Mdot
.26381 .26143 Mdot
.26571 .39609 Mdot
.26762 .35081 Mdot
.26952 .36262 Mdot
.27143 .27498 Mdot
.27333 .39409 Mdot
.27524 .34156 Mdot
.27714 .4511 Mdot
.27905 .33836 Mdot
.28095 .38537 Mdot
.28286 .42811 Mdot
.28476 .37304 Mdot
.28667 .41509 Mdot
.28857 .25729 Mdot
.29048 .41105 Mdot
.29238 .44607 Mdot
.29429 .22317 Mdot
.29619 .30514 Mdot
.2981 .27644 Mdot
.3 .29255 Mdot
.3019 .40631 Mdot
.30381 .38085 Mdot
.30571 .27244 Mdot
.30762 .25652 Mdot
.30952 .35406 Mdot
.31143 .33943 Mdot
.31333 .35274 Mdot
.31524 .34104 Mdot
.31714 .2776 Mdot
.31905 .32189 Mdot
.32095 .30656 Mdot
.32286 .39731 Mdot
.32476 .42585 Mdot
.32667 .33686 Mdot
.32857 .37086 Mdot
.33048 .39226 Mdot
.33238 .33202 Mdot
.33429 .42543 Mdot
.33619 .44427 Mdot
.3381 .30768 Mdot
.34 .38566 Mdot
.3419 .28821 Mdot
.34381 .37168 Mdot
.34571 .2419 Mdot
.34762 .31892 Mdot
.34952 .39179 Mdot
.35143 .39772 Mdot
.35333 .3374 Mdot
.35524 .34181 Mdot
.35714 .3624 Mdot
.35905 .27776 Mdot
.36095 .39189 Mdot
.36286 .37922 Mdot
.36476 .31645 Mdot
.36667 .30814 Mdot
.36857 .42434 Mdot
.37048 .40761 Mdot
.37238 .45354 Mdot
.37429 .32899 Mdot
.37619 .44145 Mdot
.3781 .32823 Mdot
.38 .23954 Mdot
.3819 .34087 Mdot
.38381 .26495 Mdot
.38571 .44771 Mdot
.38762 .38785 Mdot
.38952 .35941 Mdot
.39143 .40714 Mdot
.39333 .26299 Mdot
.39524 .30289 Mdot
.39714 .41626 Mdot
.39905 .41955 Mdot
.40095 .44753 Mdot
.40286 .3556 Mdot
.40476 .45191 Mdot
.40667 .26733 Mdot
.40857 .32626 Mdot
.41048 .32617 Mdot
.41238 .31018 Mdot
.41429 .35781 Mdot
.41619 .4627 Mdot
.4181 .31887 Mdot
.42 .30693 Mdot
.4219 .33601 Mdot
.42381 .25843 Mdot
.42571 .32614 Mdot
.42762 .34177 Mdot
.42952 .36505 Mdot
.43143 .27722 Mdot
.43333 .2427 Mdot
.43524 .34222 Mdot
.43714 .29587 Mdot
.43905 .3004 Mdot
.44095 .44319 Mdot
.44286 .33196 Mdot
.44476 .24329 Mdot
.44667 .45069 Mdot
.44857 .29009 Mdot
.45048 .27885 Mdot
.45238 .23637 Mdot
.45429 .2553 Mdot
.45619 .34247 Mdot
.4581 .34232 Mdot
.46 .4006 Mdot
.4619 .33782 Mdot
.46381 .44357 Mdot
.46571 .30026 Mdot
.46762 .32361 Mdot
.46952 .31761 Mdot
.47143 .46006 Mdot
.47333 .37406 Mdot
.47524 .35216 Mdot
.47714 .34423 Mdot
.47905 .33166 Mdot
.48095 .36301 Mdot
.48286 .35746 Mdot
.48476 .33289 Mdot
.48667 .27318 Mdot
.48857 .37316 Mdot
.49048 .2845 Mdot
.49238 .25001 Mdot
.49429 .2751 Mdot
.49619 .32156 Mdot
.4981 .40808 Mdot
.5 .35624 Mdot
.5019 .25249 Mdot
.50381 .42533 Mdot
.50571 .42628 Mdot
.50762 .29264 Mdot
.50952 .26166 Mdot
.51143 .39965 Mdot
.51333 .26613 Mdot
.51524 .34597 Mdot
.51714 .39051 Mdot
.51905 .3087 Mdot
.52095 .42424 Mdot
.52286 .23994 Mdot
.52476 .37542 Mdot
.52667 .3521 Mdot
.52857 .27374 Mdot
.53048 .26488 Mdot
.53238 .36062 Mdot
.53429 .2514 Mdot
.53619 .28455 Mdot
.5381 .37789 Mdot
.54 .37453 Mdot
.5419 .29643 Mdot
.54381 .3767 Mdot
.54571 .38897 Mdot
.54762 .25499 Mdot
.54952 .36564 Mdot
.55143 .39852 Mdot
.55333 .31891 Mdot
.55524 .32063 Mdot
.55714 .22842 Mdot
.55905 .34058 Mdot
.56095 .31415 Mdot
.56286 .42718 Mdot
.56476 .30049 Mdot
.56667 .32733 Mdot
.56857 .37323 Mdot
.57048 .43871 Mdot
.57238 .26656 Mdot
.57429 .31244 Mdot
.57619 .32207 Mdot
.5781 .36713 Mdot
.58 .34355 Mdot
.5819 .2346 Mdot
.58381 .33752 Mdot
.58571 .3002 Mdot
.58762 .43568 Mdot
.58952 .30579 Mdot
.59143 .29001 Mdot
.59333 .30551 Mdot
.59524 .33729 Mdot
.59714 .34171 Mdot
.59905 .43972 Mdot
.60095 .23035 Mdot
.60286 .36093 Mdot
.60476 .38408 Mdot
.60667 .35301 Mdot
.60857 .27011 Mdot
.61048 .44802 Mdot
.61238 .29395 Mdot
.61429 .22894 Mdot
.61619 .28054 Mdot
.6181 .30934 Mdot
.62 .37237 Mdot
.6219 .27667 Mdot
.62381 .33803 Mdot
.62571 .35724 Mdot
.62762 .27918 Mdot
.62952 .23935 Mdot
.63143 .26833 Mdot
.63333 .38876 Mdot
.63524 .26475 Mdot
.63714 .45306 Mdot
.63905 .3976 Mdot
.64095 .23634 Mdot
.64286 .294 Mdot
.64476 .32986 Mdot
.64667 .32702 Mdot
.64857 .42488 Mdot
.65048 .3505 Mdot
.65238 .32629 Mdot
.65429 .27624 Mdot
.65619 .25031 Mdot
.6581 .44558 Mdot
.66 .40534 Mdot
.6619 .33277 Mdot
.66381 .38715 Mdot
.66571 .28611 Mdot
.66762 .30919 Mdot
.66952 .40184 Mdot
.67143 .35921 Mdot
.67333 .38602 Mdot
.67524 .33095 Mdot
.67714 .35265 Mdot
.67905 .48266 Mdot
.68095 .27153 Mdot
.68286 .38722 Mdot
.68476 .29555 Mdot
.68667 .36667 Mdot
.68857 .34694 Mdot
.69048 .40993 Mdot
.69238 .40281 Mdot
.69429 .32744 Mdot
.69619 .33591 Mdot
.6981 .22334 Mdot
.7 .44679 Mdot
.7019 .30245 Mdot
.70381 .36736 Mdot
.70571 .35522 Mdot
.70762 .25338 Mdot
.70952 .39481 Mdot
.71143 .36943 Mdot
.71333 .44603 Mdot
.71524 .25385 Mdot
.71714 .29398 Mdot
.71905 .45016 Mdot
.72095 .4526 Mdot
.72286 .44 Mdot
.72476 .28357 Mdot
.72667 .37455 Mdot
.72857 .44584 Mdot
.73048 .42884 Mdot
.73238 .27599 Mdot
.73429 .2411 Mdot
.73619 .26233 Mdot
.7381 .32702 Mdot
.74 .30113 Mdot
.7419 .22875 Mdot
.74381 .3599 Mdot
.74571 .34251 Mdot
.74762 .41824 Mdot
.74952 .3989 Mdot
.75143 .32143 Mdot
.75333 .39792 Mdot
.75524 .44997 Mdot
.75714 .3318 Mdot
.75905 .36884 Mdot
.76095 .28465 Mdot
.76286 .32077 Mdot
.76476 .41874 Mdot
.76667 .32055 Mdot
.76857 .28117 Mdot
.77048 .45342 Mdot
.77238 .25924 Mdot
.77429 .32615 Mdot
.77619 .28375 Mdot
.7781 .24776 Mdot
.78 .35297 Mdot
.7819 .23014 Mdot
.78381 .24827 Mdot
.78571 .31517 Mdot
.78762 .45331 Mdot
.78952 .24616 Mdot
.79143 .48006 Mdot
.79333 .24514 Mdot
.79524 .27399 Mdot
.79714 .30832 Mdot
.79905 .28647 Mdot
.80095 .441 Mdot
.80286 .44526 Mdot
.80476 .34989 Mdot
.80667 .33301 Mdot
.80857 .35382 Mdot
.81048 .34193 Mdot
.81238 .39059 Mdot
.81429 .35007 Mdot
.81619 .31114 Mdot
.8181 .29831 Mdot
.82 .3394 Mdot
.8219 .26635 Mdot
.82381 .36056 Mdot
.82571 .24426 Mdot
.82762 .35174 Mdot
.82952 .29583 Mdot
.83143 .33122 Mdot
.83333 .41014 Mdot
.83524 .31084 Mdot
.83714 .36074 Mdot
.83905 .24402 Mdot
.84095 .27963 Mdot
.84286 .27766 Mdot
.84476 .33355 Mdot
.84667 .41304 Mdot
.84857 .4201 Mdot
.85048 .36878 Mdot
.85238 .4168 Mdot
.85429 .34525 Mdot
.85619 .27219 Mdot
.8581 .26278 Mdot
.86 .44696 Mdot
.8619 .33525 Mdot
.86381 .40174 Mdot
.86571 .4823 Mdot
.86762 .32937 Mdot
.86952 .31544 Mdot
.87143 .29279 Mdot
.87333 .27358 Mdot
.87524 .3313 Mdot
.87714 .43558 Mdot
.87905 .33189 Mdot
.88095 .35665 Mdot
.88286 .30168 Mdot
.88476 .32471 Mdot
.88667 .28745 Mdot
.88857 .3031 Mdot
.89048 .43246 Mdot
.89238 .26537 Mdot
.89429 .42727 Mdot
.89619 .39503 Mdot
.8981 .24454 Mdot
.9 .38721 Mdot
.9019 .24187 Mdot
.90381 .25578 Mdot
.90571 .35902 Mdot
.90762 .27484 Mdot
.90952 .44718 Mdot
.91143 .42571 Mdot
.91333 .28277 Mdot
.91524 .30296 Mdot
.91714 .28665 Mdot
.91905 .32534 Mdot
.92095 .40914 Mdot
.92286 .31593 Mdot
.92476 .2516 Mdot
.92667 .33315 Mdot
.92857 .24753 Mdot
.93048 .25995 Mdot
.93238 .38682 Mdot
.93429 .31418 Mdot
.93619 .38494 Mdot
.9381 .35095 Mdot
.94 .28494 Mdot
.9419 .30018 Mdot
.94381 .37348 Mdot
.94571 .38625 Mdot
.94762 .31662 Mdot
.94952 .25139 Mdot
.95143 .30406 Mdot
.95333 .36282 Mdot
.95524 .24162 Mdot
.95714 .28386 Mdot
.95905 .27392 Mdot
.96095 .26727 Mdot
.96286 .37758 Mdot
.96476 .26922 Mdot
.96667 .4023 Mdot
.96857 .28407 Mdot
.97048 .318 Mdot
.97238 .29607 Mdot
.97429 .41971 Mdot
.97619 .4528 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo05?ooooo0_l00020ooooo`;o0000IOooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`1Cooooo`;o0000P?ooool2o`0006Gooooo0004o`0000;ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Jooooo`Co0000R_ooool2o`0000cooooo0_l00002ooooo`;o00009ooo
ool2o`0000_ooooo0_l0001:ooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o00006_ooool4o`0001[ooooo0_l0
0003ooooo`;o0000JOooool2o`0000cooooo0_l00002ooooo`;o00009oooool2o`0000_ooooo0_l0
001:ooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0>?ooool2o`0000?ooooo
0_l00017ooooo`;o0000:?ooool2o`00017ooooo0_l0001gooooo`001_ooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo02kooooo0_l0000oooooo`;o00005Oooool2o`0001Gooooo0_l0000Aooooo`;o0000
3Oooool2o`0000;ooooo0_l0001gooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool08Oooool2o`0000_ooooo0_l0000dooooo`;o00002Oooool2o`0000oooooo0_l00002ooooo`;o
00005oooool2o`00023ooooo0_l0000Pooooo`;o0000=?ooool2o`0000oooooo0_l0000Booooo`00
1_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co00001_ooool00ol0003oooooooooo`0Qooooo`;o00006oooool2o`0002Cooooo0_l0000Joooo
o`;o00000_ooool2o`0005_ooooo0_l0000?ooooo`Co00002?ooool2o`0000;ooooo0_l0000Aoooo
o`Co00003oooool2o`0001;ooooo000Yooooo`;o00004_ooool2o`0001Gooooo0_l0000Dooooo`;o
0000[oooool7o`0000Sooooo0_l00002ooooo`;o00004Oooool2o`0000Sooooo0_l0000Kooooo`00
:Oooool00ol0003oooooooooo`08ooooo`;o00001oooool2o`0000Gooooo0_l0000>ooooo`;o0000
JOooool2o`000003ooooool0003o000000Sooooo0_l0000Vooooo`;o00009Oooool4o`0002_ooooo
0ol00005ooooo`;o00005?ooool002Wooooo00?o0000ooooooooool00_ooool2o`0000Cooooo0_l0
000>ooooo`;o00003oooool2o`0001Kooooo0_l00014ooooo`;o00002_ooool2o`000003ooooool0
003o000000Sooooo0_l00003ooooo`;o00008Oooool2o`0000kooooo0_l000000ooooooo0000o`00
000jooooo`;o00001Oooool2o`0000Kooooo0_l0000Dooooo`00:Oooool00ol0003oooooooooo`02
ooooo`;o00009Oooool2o`0001;ooooo0_l00002ooooo`;o00003_ooool2o`0000Gooooo0_l0000S
ooooo`;o00002?ooool2o`0001cooooo0_l0000aooooo`;o000000?oooooo`000?l00000>_ooool2
o`0002?ooooo000Yooooo`04o`000?oooooo0000o`0000oooooo0_l0000Cooooo`;o00005_ooool3
o`000003ooooool0003o000000Kooooo0_l00006ooooo`;o00001Oooool2o`0002?ooooo0_l0000I
ooooo`;o0000Doooool2o`00037ooooo0_l0000Jooooo`00:Oooool4o`0000cooooo0_l000000ooo
oooo0000o`00000Cooooo`Co00005Oooool5o`0000Kooooo0_l0000Uooooo`;o000000?oooooo`00
0?l000008oooool2o`0000Gooooo0_l0000Pooooo`;o00007_ooool2o`0000[ooooo0_l0000Joooo
o`;o00005Oooool2o`0001[ooooo000Yooooo`03o`000?oooooooooo00gooooo0_l0000Hooooo`;o
00005oooool2o`0002kooooo0_l000000ooooooo0000o`000002ooooo`;o00008Oooool2o`0000?o
oooo0_l0000<ooooo`;o00004Oooool3o`0001kooooo0_l0000Jooooo`;o00002_ooool2o`0000Wo
oooo0_l0000Dooooo`;o00004?ooool002Wooooo00Co0000oooooooooooooooo0_l00009ooooo`;o
00005?ooool2o`0000Sooooo0_l00002ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o
<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Yooooo`Go00000oooool01Oo^k^ko<S8b
o`000?l0003ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Hooooo`;o00003_ooool00onH
V9So410@o`000002o`0000?ooooo00Kok^k^oc8b<_l0003o<S8bonk^k_ooool2o`000006onk^k_lb
<S;o0000oc8b<_o^k^kooooo0_l0000Wooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o
0000oc8b<_o^k^h00oooool01_o^k^ko<S8bo`000?lb<S;ok^k^ooooo`;o00005Oooool2o`0000oo
oooo00GoA4A4o`000?l0003o<S8bomgMg@03o`000004oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool01?l0003oooooooooooooool2o`0000Wooooo0_l0
000Dooooo`;o00002?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgo`000?l0003oV9RHogMgM`0Cooooo`;o00005?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03oooool2o`0000cooooo0_l00009ooooo`05oa0@4?nj^[[oooooogMgMolb<S80
0oooool01_mgMgOoV9RHoooooonHV9SoMgMgooooo`;o000000GoMgMgoiRHV?ooooooV9RHogMgM`0A
ooooo`;o00006?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_l0
00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo0_l00003ooooo`;o00006Oooool00omgMgOo
0000o`000002o`000004oiRHV?ooooooV9RHogMgM`?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`00:Oooool3o`0001Wooooo0_l0000Gooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@4003ooooo`05oa0@4?l0003o0000ooooool@41002?ooool2o`0000Kooooo0_l0
00000ooooooo0000o`000002ooooo`;o00004Oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?oo
ooooooooooooool@41000oooool01Ol@413oooooo`000?l0003o410@00oooooo0_l000000ooooooo
0000o`000009ooooo`;o00003Oooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooo
oooooooooooooa0@4002ooooo`;o00002?ooool2o`0000Oooooo0_l0000>ooooo`;o00001Oooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@4002o`000003ooooool@413ooooo00;ooooo00?o
410@ooooooooool01_ooool2o`0000;ooooo0_l00003ooooo`;o00002Oooool2o`0000oooooo0_l0
00000ooooooo410@ooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413ooooo
ooooo`01ooooo`00:Oooool3o`0001Wooooo0_l00005ooooo`;o00003Oooool2o`000003ooooool0
003ooooo00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00002?ooool2o`0000Kooooo0_l00005ooooo`;o00002oooool2o`0000Gooooo00?oV9RHob4Q8Oo^
k^h00oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000000_l00003oooo
o`;o00003Oooool2o`0001Oooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo
000000?ooooo1_l00007ooooo`;o00005oooool2o`0000Gooooo00CoA4A4omgMgOoooooo00001?oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000007ooooo`?o
00004_ooool2o`0000kooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`01ooooo`00:Oooool2o`00027ooooo0_l0000=oooo
o`;o000000?oooooo`000?ooool00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`00000Tooooo`;o00001_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo0_l0000Uooooo`03
oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`000003ooooo`?o000000?oooooo`00
0?l000007_ooool2o`0000Oooooo00GogMgMoeEEEOoooooo0000ooooo`04o`0000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo0_l0000Eooooo`;o00002Ooo
ool00ol0003o8B4Qo`000002o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000oooool002Wooooo0_l0000cooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000_l0000[oooo
o`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o
410@ooooooooool03_ooool2o`0000gooooo0_l0000:ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go
410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41003?ooool2o`00017o
oooo0_l00008ooooo`04ogMgMol0003o0000ooooo`Co00000oooool00ol@413oooooooooo`02o`00
00?ooooo00?o410@ooooooooool07?ooool4o`0000Gooooo0ol00002ooooo`;o00000_ooool2o`00
00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo007ooooo000Yoooo
o`03o`000?oooooooooo00_ooooo0_l00002ooooo`;o00008Oooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01?mgMgOoV9RHoooooonHV9P3o`0001gooooo0_l0
0008ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`;o00002oooool2o`0000gooooo0_l00007oooo
o`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOo0000o`000?nHV9SoMgMg00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`;o00006oooool00oo^k^ko0000o`000004ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00_ooool2o`000004oiRHV?ooooooV9RHogMgMaKooooo0_l00008oooo
o`;o00001Oooool3o`0000Kooooo0_l000000oooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool002Wooooo00?o0000ooooooooool02oooool2o`0000;ooooo0_l0000?oooo
o`;o00003_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1?o^k^ko<S8bo`000?lb<S82o`00013ooooo0_l0000<ooooo`;o00002?ooool01OnHV9So410@o`00
0?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool2o`00017ooooo0_l0000@ooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool0
1Oo^k^ko0000o`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Zooooo`03ogMg
Mol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h04Oooool2o`0000?ooooo0_l0000Aooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool2o`0000Sooooo0_l0000G
ooooo`;o0000<oooool2o`0002[ooooo0_l0000Eooooo`;o00008?ooool2o`0000Oooooo0_l0000<
ooooo`;o00002?ooool2o`0002;ooooo0_l0000<ooooo`;o00007_ooool2o`0000gooooo000Yoooo
o`03o`000?oooooooooo00Oooooo0_l0000Jooooo`;o00001Oooool2o`0005Gooooo0_l0000Poooo
o`;o00005Oooool2o`0000Oooooo0_l0000<ooooo`;o00002?ooool2o`0001oooooo0_l000000ooo
oooo0000o`00000/ooooo`;o00003Oooool002Wooooo00?o0000ooooooooool05_ooool2o`0000_o
oooo1?l00003ooooo`;o00003?ooool4o`0004Kooooo0_l00006ooooo`;o00005oooool2o`0000Go
oooo0_l00005ooooo`;o00008oooool2o`0000_ooooo0_l0000Gooooo`;o00004_ooool2o`00017o
oooo0_l0000Gooooo`00:Oooool00ol0003oooooooooo`07ooooo`;o00003Oooool2o`0000[ooooo
0_l000000ooooooo0000o`00000Aooooo`Co00006?ooool2o`0001kooooo0_l0000<ooooo`;o0000
1_ooool2o`0001kooooo0_l00005ooooo`Co00008Oooool2o`0000_ooooo0_l0000[ooooo`Co0000
1oooool2o`0000Kooooo0_l00002ooooo`;o00004oooool002Wooooo00?o0000ooooooooool01Ooo
ool4o`0001Wooooo0_l00003ooooo`;o0000:oooool2o`0000Kooooo0_l00003ooooo`;o00002?oo
ool2o`0000Oooooo0_l00006ooooo`;o00007_ooool2o`0001Cooooo0ol00010ooooo`;o00006ooo
ool2o`0000Oooooo0_l0000:ooooo`;o00004oooool0027oooooool00014o`0000Cooooo000Yoooo
o`03o`000?oooooooooo00Wooooo0_l0000;ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool01_ooool2o`000003ooooool0003ooooo00[ooooo0_l00009ooooo`?o00002oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool3o`00
00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00[ooooo0_l00002ooooo`;o00001_ooool00ol0003oooooooooo`03ooooo`;o00001?ooool00ol0
003oooooooooo`07ooooo`?o00003?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01_ooool2o`000004ooooool0003oooooooooo`;o00002?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo0ol0000;ooooo`03o`000?oooooo
oooo00[ooooo000Yooooo`03o`000?oooooooooo00Cooooo0_l00003ooooo`;o00007Oooool2o`00
0003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000005ooooo`03o`000?oooooooooo
02gooooo0_l0000<ooooo`03o`000?oooooooooo017ooooo0_l0000Kooooo`;o00000_ooool2o`00
00Kooooo00?o0000ooooooooool0>Oooool2o`0001Wooooo0_l0000?ooooo`;o00000_ooool2o`00
00;ooooo0_l00006ooooo`?o00003?ooool002Wooooo00?o0000ooooooooool01?ooool2o`0000ko
oooo0_l00002ooooo`;o00003_ooool2o`0000Kooooo0_l000000ooooooo0000o`00000_ooooo`;o
00001?ooool2o`0000oooooo0_l0000?ooooo`;o00006Oooool2o`00047ooooo0ol00004ooooo`;o
00006Oooool2o`0000oooooo0_l00006ooooo`;o00001_ooool2o`0000gooooo000Yooooo`03o`00
0?oooooooooo01Cooooo0_l00002ooooo`;o0000;?ooool3o`0001;ooooo0_l00007ooooo`;o0000
5Oooool2o`0000kooooo0_l00007ooooo`;o00004Oooool2o`0000Gooooo0_l0000fooooo`;o0000
0_ooool3o`0004oooooo000Yooooo`;o00009oooool2o`0001kooooo0ol0000Booooo`;o00006ooo
ool3o`0000;ooooo0_l0000<ooooo`;o00001oooool2o`0001Gooooo0_l000000ooooooo0000o`00
000Eooooo`?o00003?ooool2o`0000cooooo0_l00002ooooo`;o00001_ooool2o`00027ooooo0_l0
0009ooooo`;o00007_ooool002Wooooo00?o0000ooooooooool05oooool2o`0000Kooooo0_l00005
ooooo`;o00002oooool2o`0003Sooooo0ol00008ooooo`?o00000_ooool2o`0002cooooo0_l0000G
ooooo`Co00003?ooool2o`0000cooooo0_l0000:ooooo`;o00007?ooool2o`0000?ooooo0_l00009
ooooo`;o00007_ooool002Wooooo00?o0000ooooooooool00oooool2o`0001;ooooo0_l00006oooo
o`;o00004_ooool2o`000003ooooool0003o000002Oooooo0_l0000<ooooo`?o00004oooool2o`00
00[ooooo0ol0000booooo`;o00000oooool2o`0000?ooooo0_l0000Hooooo`;o00003_ooool2o`00
00Kooooo0_l00002ooooo`;o00001_ooool5o`0000kooooo0_l0000Kooooo`00:Oooool00ol0003o
ooooooooo`03ooooo`;o0000<Oooool2o`0002Oooooo0_l0000Kooooo`;o00001Oooool2o`0000[o
oooo0ol0000gooooo`;o00000oooool2o`0000Cooooo0_l0000Booooo`;o00003_ooool2o`0000Ko
oooo0_l00002ooooo`;o00001?ooool2o`0000;ooooo0ol0000>ooooo`;o00006oooool002Wooooo
00?o0000ooooooooool0=Oooool2o`0000Sooooo0_l0000=ooooo`;o00002Oooool2o`0000?ooooo
0_l00006ooooo`;o00005?ooool2o`0000_ooooo0_l0000Uooooo`;o00000_ooool2o`0000Oooooo
0_l0000Eooooo`;o00009_ooool2o`0000cooooo0_l0000`ooooo`00:Oooool2o`0000Oooooo0_l0
000]ooooo`;o00002?ooool2o`0000cooooo0ol00009ooooo`?o00000_ooool2o`0000Kooooo0ol0
0006ooooo`;o00003Oooool2o`000003ooooool0003o000000Cooooo1?l0000Mooooo`;o00001_oo
ool2o`0000;ooooo0ol00006ooooo`;o00009Oooool2o`0001?ooooo0_l000000ooooooo0000o`00
000nooooo`00:Oooool00ol0003oooooooooo`06ooooo`;o00009Oooool2o`0000;ooooo0_l00008
ooooo`;o00002?ooool2o`0000Kooooo0_l0000;ooooo`;o00002oooool2o`0000Kooooo0_l0000=
ooooo`;o000000?oooooo`000?l000001?ooool3o`0000Cooooo0_l0000:ooooo`;o00003?ooool2
o`0000Gooooo0_l00004ooooo`;o0000;Oooool2o`0001?ooooo0_l0000<ooooo`;o0000<oooool0
02Wooooo00?o0000ooooooooool0;Oooool2o`0000;ooooo0_l00003ooooo`;o00000oooool3o`00
00Oooooo0_l00017ooooo`;o00002_ooool2o`0001?ooooo0_l0000Qooooo`;o0000<oooool2o`00
03?ooooo000Yooooo`03o`000?oooooooooo00gooooo0_l00003ooooo`;o00008_ooool2o`0000Co
oooo0_l0000=ooooo`;o0000@?ooool2o`0000oooooo0_l0000Vooooo`;o00002_ooool2o`0002?o
oooo0_l000000ooooooo0000o`000003ooooo`;o00008Oooool2o`0001Sooooo000Yooooo`03o`00
0?oooooooooo00;o00002oooool2o`0000?ooooo0_l0000gooooo`;o00002oooool3o`0003;ooooo
0_l0000?ooooo`;o00006?ooool2o`0000cooooo0_l00006ooooo`;o00002?ooool2o`0001Gooooo
0_l00006ooooo`Go00000oooool2o`00027ooooo0_l0000Hooooo`00:Oooool2o`000003ooooool0
003o0000013ooooo0_l00014ooooo`?o00006oooool2o`0000;ooooo0_l0000Dooooo`;o00000ooo
ool2o`00027ooooo0_l00004ooooo`;o00003_ooool2o`0000Sooooo0_l0000Eooooo`;o00002?oo
ool2o`0001Gooooo0_l0000Zooooo`00:Oooool00ol0003oooooooooo`0booooo`;o0000?_ooool2
o`0000;ooooo0_l00002ooooo`;o00005?ooool2o`0000?ooooo0_l00009ooooo`;o00005?ooool2
o`0000Kooooo0_l0000=ooooo`;o00005Oooool2o`0001Sooooo0_l00002ooooo`;o00003?ooool2
o`0000Kooooo0_l0000Rooooo`00:Oooool01?l0003oooooo`000?l0000aooooo`;o00005?ooool2
o`000003ooooool0003o000001[ooooo0_l00009ooooo`;o00006oooool2o`0000oooooo0_l0000D
ooooo`;o00005Oooool2o`0001Gooooo0_l0000Hooooo`;o00000_ooool2o`0001Cooooo0_l0000=
ooooo`;o00004oooool002Wooooo00Co0000ooooool0003o0000<Oooool2o`0001Cooooo0_l00000
0ooooooo0000o`00000Jooooo`;o00005_ooool2o`0000kooooo0_l0000Dooooo`;o00001oooool2
o`00027ooooo0_l00004ooooo`;o0000C_ooool2o`0001?ooooo000Yooooo`03o`000?oooooooooo
01?ooooo0_l0000^ooooo`;o00006Oooool2o`0001oooooo0_l0000Tooooo`;o00001oooool2o`00
027ooooo0_l00004ooooo`Co00003_ooool2o`0001_ooooo0_l0000dooooo`00:Oooool2o`0001Co
oooo0_l00005ooooo`;o00002?ooool2o`0001gooooo0_l0000;ooooo`;o00003?ooool2o`0000?o
oooo0_l0000Xooooo`;o00000oooool2o`0001Oooooo0_l0000?ooooo`;o00006oooool2o`0000ko
oooo0_l0000Kooooo`;o00007?ooool2o`0001Kooooo000Yooooo`03o`000?oooooooooo01[ooooo
0_l000000ooooooo0000o`000005ooooo`;o0000:_ooool2o`00017ooooo0_l0000Xooooo`;o0000
0oooool2o`0000Wooooo0_l00003ooooo`?o00001_ooool2o`0000oooooo0_l0000Pooooo`;o0000
A?ooool2o`0001Kooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Mooooo`;o
0000B_ooool2o`0003;ooooo0_l00003ooooo`?o0000>Oooool2o`0004[ooooo0_l0000@ooooo`00
1_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo05Kooooo0_l0000Aoooo
o`;o0000=oooool2o`0008Kooooo0_l0000@ooooo`001_ooool01Ol@413ooooooooooooooooo410@
00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01kooooo0_l0000Rooooo`;o00000_ooool2o`0000Oooooo0_l00005ooooo`;o00002_ooool2o`00
05?ooooo0_l0000Dooooo`;o0000Doooool2o`000003ooooool0003o000001Gooooo0006ooooo`05
o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo
00Cooooo0ol0000Gooooo`;o00001Oooool2o`0002;ooooo0_l00002ooooo`;o00001oooool2o`00
017ooooo0_l0000=ooooo`;o0000<Oooool2o`00017ooooo0_l00007ooooo`;o00002?ooool2o`00
0004ooooool0003o0000ooooo`;o0000A?ooool2o`0000Sooooo1?l000000ooooooo0000o`00000E
ooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool05oooool2o`0001kooooo0_l0
000Vooooo`;o00001?ooool2o`0000;ooooo0_l00006ooooo`;o0000:?ooool2o`0000Oooooo0_l0
000Jooooo`;o00002?ooool2o`0000Cooooo0_l0000Xooooo`;o00006_ooool2o`0000Sooooo0_l0
000Jooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo0_l0000[ooooo`;o00005?oo
ool2o`00013ooooo0_l00004ooooo`;o00000_ooool2o`00033ooooo0_l0000looooo`;o00007ooo
ool2o`0001Wooooo0_l0000Uooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2_ooool2o`0000Cooooo0_l0000Looooo`;o00006_ooool2o`000003ooooool0003o000000gooooo
0_l00008ooooo`;o0000?_ooool2o`0001[ooooo0_l0000Eooooo`;o00002oooool3o`0002cooooo
0_l0000Uooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`0?ooooo`?o00007?ooool4o`0001So
oooo0_l0000@ooooo`;o00002?ooool2o`00027ooooo0_l0000>ooooo`;o00002oooool2o`0001[o
oooo0_l00008ooooo`;o00006?ooool3o`00027ooooo0_l0000`ooooo`00:Oooool2o`0000_ooooo
0_l00003ooooo`;o00007oooool2o`0005Oooooo0_l0000>ooooo`;o0000<Oooool2o`0000Gooooo
0_l0000eooooo`;o00007oooool2o`0000oooooo000Yooooo`;o00002oooool2o`0004[ooooo0_l0
000Dooooo`;o00001?ooool2o`00027ooooo0_l0000booooo`;o00002?ooool2o`0005Kooooo0_l0
000?ooooo`00:Oooool00ol0003oooooooooo`0eooooo`;o00006oooool2o`0000;ooooo0_l0000D
ooooo`;o00001?ooool2o`00027ooooo0_l0000booooo`;o00002?ooool2o`0002cooooo0_l0000J
ooooo`;o00007Oooool002Wooooo00?o0000ooooooooool0=Oooool2o`0001_ooooo0_l0001ooooo
o`;o0000;?ooool2o`0000;ooooo0_l0000Fooooo`;o00007Oooool002Wooooo00?o0000oooooooo
ool06oooool2o`0003Cooooo0_l0000Qooooo`;o0000Soooool4o`0003?ooooo000Yooooo`;o0000
2_ooool2o`00013ooooo0_l0000dooooo`;o00008Oooool3o`0006kooooo0_l00004ooooo`;o0000
6?ooool4o`0002Gooooo0_l0000<ooooo`00:Oooool00ol0003oooooooooo`09ooooo`;o00004Ooo
ool2o`0005Oooooo0_l0001^ooooo`;o00001?ooool2o`0001Sooooo0_l0000Wooooo`;o00003?oo
ool002Wooooo00?o0000ooooooooool03_ooool2o`0000Cooooo0_l00006ooooo`;o00001Oooool2
o`0000Gooooo0_l000000ooooooo0000o`00000^ooooo`;o000000?oooooo`000?l000002Oooool2
o`0002[ooooo0_l00003ooooo`;o00009oooool2o`0005?ooooo0_l0000Pooooo`00:Oooool00ol0
003oooooooooo`0>ooooo`;o00001?ooool2o`0000gooooo0_l00005ooooo`;o000000?oooooo`00
0?l000006Oooool2o`0000Kooooo0_l0000;ooooo`;o000000?oooooo`000?l000002Oooool2o`00
02[ooooo0_l00003ooooo`;o00003?ooool2o`0001Wooooo0_l0000Hooooo`;o0000<oooool2o`00
00Cooooo0_l0000Pooooo`00:Oooool01?l0003oooooooooooooool2o`0004Gooooo0_l00006oooo
o`;o0000F?ooool2o`0003?ooooo0_l0000booooo`?o00009_ooool002Wooooo0_l00002ooooo`;o
00007?ooool2o`00097ooooo0_l0001Kooooo`;o00000_ooool2o`0002Oooooo000Yooooo`03o`00
0?oooooooooo01oooooo0_l0002;ooooo`;o00001?ooool2o`0005_ooooo0_l0000[ooooo`00:Ooo
ool00ol0003oooooooooo`05ooooo`;o0000Ioooool2o`0003cooooo0_l00007ooooo`;o00009_oo
ool2o`0001Oooooo0_l00014ooooo`00:Oooool00ol0003oooooooooo`05ooooo`;o00003_ooool2
o`0001gooooo0_l00005ooooo`;o00009?ooool2o`0000_ooooo0_l0000Booooo`;o00001_ooool2
o`0002Wooooo0_l0000Aooooo`;o00004oooool2o`0001Oooooo0ol00013ooooo`00:Oooool00ol0
003oooooooooo`04ooooo`;o00001_ooool2o`0000Oooooo0_l0000Mooooo`;o00001Oooool2o`00
01Kooooo0_l0000<ooooo`;o00003_ooool2o`0000?ooooo0_l0000:ooooo`;o00001_ooool2o`00
02gooooo0_l0000=ooooo`;o00003?ooool2o`0000;ooooo0_l00003ooooo`;o00005_ooool2o`00
013ooooo0_l0000>ooooo`;o00008Oooool002Wooooo0_l00005ooooo`;o00001_ooool2o`00043o
oooo0_l00003ooooo`;o00007?ooool2o`0000?ooooo0_l0000<ooooo`;o0000<oooool2o`0001_o
oooo0_l00002ooooo`Co000000?oooooo`000?l000001_ooool2o`00023ooooo0_l0000>ooooo`;o
00008Oooool002Wooooo00?o0000ooooooooool05Oooool2o`0003Oooooo0_l0000Looooo`;o0000
2Oooool2o`0000_ooooo0_l0000kooooo`;o00006Oooool2o`0000Wooooo0_l00003ooooo`;o0000
1?ooool2o`0003_ooooo0_l0000;ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Eooooo`;o
0000EOooool2o`0000Wooooo0_l00018ooooo`;o00006Oooool2o`0000kooooo0_l00004ooooo`;o
0000>oooool2o`0000_ooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2<ooooo`;o0000[_ooool000kooooo
00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0001jooooo`;o
00004?ooool2o`000:kooooo000>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo07[ooooo0_l00030ooooo`003_ooool01Ol0003ooooo
oooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo
0?oooooo?Oooool000kooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0000jooooo`;o0000ooooool2oooo
o`00:Oooool00ol0003oooooooooo`0Mooooo`;o00003?ooool2o`0000cooooo0_l0002Dooooo`;o
00008_ooool2o`0001Kooooo0_l0000_ooooo`00:Oooool00ol0003oooooooooo`0Mooooo`;o0000
3?ooool2o`000:;ooooo0_l0000Rooooo`;o00005_ooool2o`0002oooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`00
0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`00
0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo
00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooooooo
ool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03
oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgo
oooo0006ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03
o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`000?ooooooooooooooool0
00003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?oo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolmoooo
o`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`007oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0
oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo?Ooo
ool0027ooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`007oooool0
0omEEEGoIVIVo`00003oooooodOooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .24365 Mdot
.02762 .36105 Mdot
.02952 .29857 Mdot
.03143 .30702 Mdot
.03333 .33118 Mdot
.03524 .39083 Mdot
.03714 .29845 Mdot
.03905 .36538 Mdot
.04095 .2523 Mdot
.04286 .30594 Mdot
.04476 .27097 Mdot
.04667 .40109 Mdot
.04857 .39011 Mdot
.05048 .25458 Mdot
.05238 .3948 Mdot
.05429 .30084 Mdot
.05619 .36119 Mdot
.0581 .38423 Mdot
.06 .31149 Mdot
.0619 .36541 Mdot
.06381 .38749 Mdot
.06571 .39859 Mdot
.06762 .4031 Mdot
.06952 .37435 Mdot
.07143 .44537 Mdot
.07333 .25997 Mdot
.07524 .31463 Mdot
.07714 .33066 Mdot
.07905 .38524 Mdot
.08095 .36077 Mdot
.08286 .37364 Mdot
.08476 .24495 Mdot
.08667 .30084 Mdot
.08857 .28787 Mdot
.09048 .27046 Mdot
.09238 .25714 Mdot
.09429 .42282 Mdot
.09619 .35407 Mdot
.0981 .39391 Mdot
.1 .42131 Mdot
.1019 .45147 Mdot
.10381 .24324 Mdot
.10571 .36259 Mdot
.10762 .24277 Mdot
.10952 .26645 Mdot
.11143 .36353 Mdot
.11333 .26415 Mdot
.11524 .30887 Mdot
.11714 .33476 Mdot
.11905 .36576 Mdot
.12095 .31975 Mdot
.12286 .4246 Mdot
.12476 .47214 Mdot
.12667 .31754 Mdot
.12857 .34414 Mdot
.13048 .23112 Mdot
.13238 .36929 Mdot
.13429 .36008 Mdot
.13619 .37794 Mdot
.1381 .28638 Mdot
.14 .35875 Mdot
.1419 .38217 Mdot
.14381 .39377 Mdot
.14571 .26062 Mdot
.14762 .26891 Mdot
.14952 .22792 Mdot
.15143 .31974 Mdot
.15333 .26957 Mdot
.15524 .35224 Mdot
.15714 .35799 Mdot
.15905 .32633 Mdot
.16095 .31582 Mdot
.16286 .30601 Mdot
.16476 .34311 Mdot
.16667 .39345 Mdot
.16857 .30022 Mdot
.17048 .47223 Mdot
.17238 .3406 Mdot
.17429 .41781 Mdot
.17619 .27207 Mdot
.1781 .28078 Mdot
.18 .35059 Mdot
.1819 .32986 Mdot
.18381 .24472 Mdot
.18571 .30667 Mdot
.18762 .32434 Mdot
.18952 .33973 Mdot
.19143 .35293 Mdot
.19333 .37034 Mdot
.19524 .27298 Mdot
.19714 .44558 Mdot
.19905 .30698 Mdot
.20095 .31425 Mdot
.20286 .36514 Mdot
.20476 .28758 Mdot
.20667 .279 Mdot
.20857 .25428 Mdot
.21048 .32593 Mdot
.21238 .47772 Mdot
.21429 .36463 Mdot
.21619 .23874 Mdot
.2181 .37799 Mdot
.22 .39203 Mdot
.2219 .25787 Mdot
.22381 .30594 Mdot
.22571 .26869 Mdot
.22762 .3104 Mdot
.22952 .27443 Mdot
.23143 .31644 Mdot
.23333 .3579 Mdot
.23524 .26618 Mdot
.23714 .30888 Mdot
.23905 .25212 Mdot
.24095 .29972 Mdot
.24286 .45458 Mdot
.24476 .32625 Mdot
.24667 .34941 Mdot
.24857 .23888 Mdot
.25048 .22726 Mdot
.25238 .4265 Mdot
.25429 .39232 Mdot
.25619 .41512 Mdot
.2581 .40498 Mdot
.26 .39351 Mdot
.2619 .3555 Mdot
.26381 .28684 Mdot
.26571 .31947 Mdot
.26762 .23478 Mdot
.26952 .27835 Mdot
.27143 .27518 Mdot
.27333 .40572 Mdot
.27524 .25286 Mdot
.27714 .4198 Mdot
.27905 .3878 Mdot
.28095 .38161 Mdot
.28286 .41234 Mdot
.28476 .4258 Mdot
.28667 .35894 Mdot
.28857 .31249 Mdot
.29048 .3269 Mdot
.29238 .40465 Mdot
.29429 .31763 Mdot
.29619 .33931 Mdot
.2981 .33951 Mdot
.3 .36002 Mdot
.3019 .3383 Mdot
.30381 .27632 Mdot
.30571 .3956 Mdot
.30762 .28299 Mdot
.30952 .36081 Mdot
.31143 .42551 Mdot
.31333 .37861 Mdot
.31524 .35374 Mdot
.31714 .3686 Mdot
.31905 .30604 Mdot
.32095 .37432 Mdot
.32286 .43051 Mdot
.32476 .40756 Mdot
.32667 .23425 Mdot
.32857 .42346 Mdot
.33048 .4301 Mdot
.33238 .25726 Mdot
.33429 .42048 Mdot
.33619 .45626 Mdot
.3381 .2337 Mdot
.34 .35048 Mdot
.3419 .24158 Mdot
.34381 .26437 Mdot
.34571 .27535 Mdot
.34762 .35438 Mdot
.34952 .43088 Mdot
.35143 .32424 Mdot
.35333 .31452 Mdot
.35524 .35188 Mdot
.35714 .3322 Mdot
.35905 .25884 Mdot
.36095 .29458 Mdot
.36286 .26166 Mdot
.36476 .37848 Mdot
.36667 .32712 Mdot
.36857 .38649 Mdot
.37048 .43208 Mdot
.37238 .43527 Mdot
.37429 .34625 Mdot
.37619 .45383 Mdot
.3781 .28798 Mdot
.38 .27001 Mdot
.3819 .22902 Mdot
.38381 .24169 Mdot
.38571 .45338 Mdot
.38762 .37684 Mdot
.38952 .43487 Mdot
.39143 .33981 Mdot
.39333 .28986 Mdot
.39524 .40338 Mdot
.39714 .33426 Mdot
.39905 .45703 Mdot
.40095 .40568 Mdot
.40286 .36099 Mdot
.40476 .37642 Mdot
.40667 .25695 Mdot
.40857 .30018 Mdot
.41048 .30687 Mdot
.41238 .32134 Mdot
.41429 .31258 Mdot
.41619 .39812 Mdot
.4181 .24039 Mdot
.42 .3329 Mdot
.4219 .38635 Mdot
.42381 .30575 Mdot
.42571 .32762 Mdot
.42762 .28602 Mdot
.42952 .40837 Mdot
.43143 .34516 Mdot
.43333 .2739 Mdot
.43524 .33513 Mdot
.43714 .23969 Mdot
.43905 .35598 Mdot
.44095 .4563 Mdot
.44286 .30267 Mdot
.44476 .32424 Mdot
.44667 .41076 Mdot
.44857 .35237 Mdot
.45048 .37763 Mdot
.45238 .28904 Mdot
.45429 .25754 Mdot
.45619 .30648 Mdot
.4581 .27702 Mdot
.46 .35247 Mdot
.4619 .31413 Mdot
.46381 .39781 Mdot
.46571 .40276 Mdot
.46762 .26655 Mdot
.46952 .28927 Mdot
.47143 .39399 Mdot
.47333 .36002 Mdot
.47524 .31985 Mdot
.47714 .42701 Mdot
.47905 .35458 Mdot
.48095 .27707 Mdot
.48286 .40467 Mdot
.48476 .24639 Mdot
.48667 .38446 Mdot
.48857 .39154 Mdot
.49048 .23727 Mdot
.49238 .32756 Mdot
.49429 .23568 Mdot
.49619 .26959 Mdot
.4981 .42873 Mdot
.5 .3753 Mdot
.5019 .33127 Mdot
.50381 .39907 Mdot
.50571 .45729 Mdot
.50762 .32738 Mdot
.50952 .29779 Mdot
.51143 .42887 Mdot
.51333 .26326 Mdot
.51524 .34881 Mdot
.51714 .36916 Mdot
.51905 .3086 Mdot
.52095 .35 Mdot
.52286 .34302 Mdot
.52476 .35033 Mdot
.52667 .31936 Mdot
.52857 .24299 Mdot
.53048 .30529 Mdot
.53238 .37678 Mdot
.53429 .26896 Mdot
.53619 .25891 Mdot
.5381 .38693 Mdot
.54 .28338 Mdot
.5419 .24789 Mdot
.54381 .2859 Mdot
.54571 .35786 Mdot
.54762 .30264 Mdot
.54952 .31374 Mdot
.55143 .43095 Mdot
.55333 .34734 Mdot
.55524 .25479 Mdot
.55714 .30501 Mdot
.55905 .2831 Mdot
.56095 .37794 Mdot
.56286 .40072 Mdot
.56476 .26321 Mdot
.56667 .34535 Mdot
.56857 .424 Mdot
.57048 .38157 Mdot
.57238 .26732 Mdot
.57429 .27333 Mdot
.57619 .25664 Mdot
.5781 .27074 Mdot
.58 .36496 Mdot
.5819 .30738 Mdot
.58381 .22751 Mdot
.58571 .39075 Mdot
.58762 .37693 Mdot
.58952 .39341 Mdot
.59143 .31908 Mdot
.59333 .39437 Mdot
.59524 .42235 Mdot
.59714 .2445 Mdot
.59905 .38736 Mdot
.60095 .35518 Mdot
.60286 .30134 Mdot
.60476 .3874 Mdot
.60667 .26447 Mdot
.60857 .23854 Mdot
.61048 .44576 Mdot
.61238 .2555 Mdot
.61429 .3144 Mdot
.61619 .25296 Mdot
.6181 .26842 Mdot
.62 .40928 Mdot
.6219 .35144 Mdot
.62381 .39893 Mdot
.62571 .4346 Mdot
.62762 .32267 Mdot
.62952 .30633 Mdot
.63143 .25699 Mdot
.63333 .29048 Mdot
.63524 .29319 Mdot
.63714 .43664 Mdot
.63905 .44922 Mdot
.64095 .26374 Mdot
.64286 .25871 Mdot
.64476 .3853 Mdot
.64667 .24859 Mdot
.64857 .4085 Mdot
.65048 .29166 Mdot
.65238 .29537 Mdot
.65429 .31331 Mdot
.65619 .32747 Mdot
.6581 .39508 Mdot
.66 .4279 Mdot
.6619 .2872 Mdot
.66381 .40976 Mdot
.66571 .267 Mdot
.66762 .32164 Mdot
.66952 .3564 Mdot
.67143 .39192 Mdot
.67333 .35206 Mdot
.67524 .25646 Mdot
.67714 .29841 Mdot
.67905 .46295 Mdot
.68095 .25888 Mdot
.68286 .32408 Mdot
.68476 .26115 Mdot
.68667 .25934 Mdot
.68857 .30111 Mdot
.69048 .3474 Mdot
.69238 .36825 Mdot
.69429 .33766 Mdot
.69619 .3641 Mdot
.6981 .31914 Mdot
.7 .40062 Mdot
.7019 .39298 Mdot
.70381 .27253 Mdot
.70571 .28876 Mdot
.70762 .2728 Mdot
.70952 .31833 Mdot
.71143 .37108 Mdot
.71333 .39874 Mdot
.71524 .24334 Mdot
.71714 .23447 Mdot
.71905 .416 Mdot
.72095 .43926 Mdot
.72286 .4562 Mdot
.72476 .32092 Mdot
.72667 .34747 Mdot
.72857 .40457 Mdot
.73048 .35852 Mdot
.73238 .31702 Mdot
.73429 .33164 Mdot
.73619 .26785 Mdot
.7381 .38363 Mdot
.74 .23868 Mdot
.7419 .30914 Mdot
.74381 .27268 Mdot
.74571 .41267 Mdot
.74762 .42198 Mdot
.74952 .39995 Mdot
.75143 .40336 Mdot
.75333 .40264 Mdot
.75524 .43688 Mdot
.75714 .43388 Mdot
.75905 .42196 Mdot
.76095 .36365 Mdot
.76286 .2883 Mdot
.76476 .45452 Mdot
.76667 .37218 Mdot
.76857 .31637 Mdot
.77048 .44095 Mdot
.77238 .35443 Mdot
.77429 .29365 Mdot
.77619 .33771 Mdot
.7781 .30071 Mdot
.78 .33055 Mdot
.7819 .29112 Mdot
.78381 .26455 Mdot
.78571 .41032 Mdot
.78762 .43822 Mdot
.78952 .31765 Mdot
.79143 .44775 Mdot
.79333 .29239 Mdot
.79524 .26133 Mdot
.79714 .25123 Mdot
.79905 .27463 Mdot
.80095 .38434 Mdot
.80286 .39738 Mdot
.80476 .31112 Mdot
.80667 .33239 Mdot
.80857 .33903 Mdot
.81048 .3386 Mdot
.81238 .44896 Mdot
.81429 .36482 Mdot
.81619 .23369 Mdot
.8181 .33765 Mdot
.82 .35406 Mdot
.8219 .28826 Mdot
.82381 .35617 Mdot
.82571 .3051 Mdot
.82762 .34283 Mdot
.82952 .33183 Mdot
.83143 .42063 Mdot
.83333 .32514 Mdot
.83524 .29019 Mdot
.83714 .28649 Mdot
.83905 .31066 Mdot
.84095 .36003 Mdot
.84286 .25509 Mdot
.84476 .3547 Mdot
.84667 .45418 Mdot
.84857 .32083 Mdot
.85048 .28665 Mdot
.85238 .47707 Mdot
.85429 .25512 Mdot
.85619 .32201 Mdot
.8581 .24416 Mdot
.86 .40917 Mdot
.8619 .27519 Mdot
.86381 .36502 Mdot
.86571 .46546 Mdot
.86762 .33545 Mdot
.86952 .27203 Mdot
.87143 .25253 Mdot
.87333 .24296 Mdot
.87524 .25775 Mdot
.87714 .3475 Mdot
.87905 .31049 Mdot
.88095 .28058 Mdot
.88286 .24306 Mdot
.88476 .27259 Mdot
.88667 .3257 Mdot
.88857 .34481 Mdot
.89048 .365 Mdot
.89238 .30826 Mdot
.89429 .41379 Mdot
.89619 .33916 Mdot
.8981 .28054 Mdot
.9 .30337 Mdot
.9019 .33269 Mdot
.90381 .33431 Mdot
.90571 .24063 Mdot
.90762 .33295 Mdot
.90952 .39933 Mdot
.91143 .45764 Mdot
.91333 .25988 Mdot
.91524 .3931 Mdot
.91714 .25066 Mdot
.91905 .37202 Mdot
.92095 .34549 Mdot
.92286 .23939 Mdot
.92476 .30107 Mdot
.92667 .36406 Mdot
.92857 .28546 Mdot
.93048 .37501 Mdot
.93238 .3754 Mdot
.93429 .29779 Mdot
.93619 .34568 Mdot
.9381 .28247 Mdot
.94 .3216 Mdot
.9419 .25809 Mdot
.94381 .31322 Mdot
.94571 .3817 Mdot
.94762 .32482 Mdot
.94952 .2852 Mdot
.95143 .22762 Mdot
.95333 .32886 Mdot
.95524 .28939 Mdot
.95714 .34387 Mdot
.95905 .33708 Mdot
.96095 .29377 Mdot
.96286 .45953 Mdot
.96476 .28769 Mdot
.96667 .3587 Mdot
.96857 .38055 Mdot
.97048 .23472 Mdot
.97238 .34846 Mdot
.97429 .37106 Mdot
.97619 .42489 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`0Uooooo`;o00007_ooool2o`0006Wooooo0_l0001eooooo`;o00004oooool000Co00000_ooool0
1Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo02Gooooo0_l0000Nooooo`;o0000:?ooool2o`0003oooooo0_l0
001eooooo`;o00004oooool000Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ
8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0001oooooo0_l00010ooooo`;o00003?oo
ool2o`0008[ooooo0_l0000oooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
7oooool2o`0002[ooooo0_l0000Aooooo`;o000000?oooooo`000?l00000;oooool4o`0004Gooooo
0_l0000Nooooo`;o0000<?ooool2o`0000gooooo0006ooooo`05oa0@4?ooooooooooooooool@4100
3oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
>_ooool2o`0000Wooooo0_l00004ooooo`;o00004Oooool2o`0001_ooooo0_l00004ooooo`;o0000
3oooool4o`0002;ooooo0_l0000Qooooo`;o00001_ooool2o`0003Sooooo0_l0000>ooooo`;o0000
3Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@
41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo0ol0000Qooooo`;o
00002Oooool2o`0001cooooo0_l0000;ooooo`;o00002Oooool2o`0000Cooooo0_l0000Looooo`;o
00005oooool2o`00027ooooo0_l00006ooooo`;o0000:?ooool2o`000003ooooool0003o000000Ko
oooo0_l00003ooooo`;o00007Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0000Aooooo`;o00001?ooool3o`00
01Oooooo0_l0000aooooo`;o00002oooool2o`0001kooooo0_l0000=ooooo`;o00005?ooool2o`00
02Cooooo0_l0000/ooooo`;o00000_ooool2o`000003ooooool0003o000000Kooooo0_l0000Roooo
o`00:Oooool2o`00017ooooo0_l0000Nooooo`;o0000G_ooool2o`00017ooooo0_l0000@ooooo`;o
00003_ooool2o`0004;ooooo0_l0000aooooo`00:Oooool00ol0003oooooooooo`02ooooo`;o0000
?Oooool2o`00063ooooo0_l0000Pooooo`;o0000;_ooool2o`0001Kooooo0_l0000=ooooo`;o0000
7_ooool002Wooooo00?o0000ooooooooool00_ooool2o`000003ooooool0003o0000037ooooo0_l0
0007ooooo`;o00002_ooool2o`0005Sooooo0_l0000Aooooo`?o0000>?ooool2o`0000gooooo0_l0
00000ooooooo0000o`000004ooooo`;o00003Oooool2o`0001kooooo000Yooooo`03o`000?oooooo
oooo00Gooooo0_l0000;ooooo`;o00009?ooool2o`0000;ooooo0_l0000?ooooo`;o00004?ooool2
o`0000Oooooo0_l0000=ooooo`;o00003_ooool2o`0001Sooooo0_l00004ooooo`;o00001Oooool2
o`0000[ooooo0ol00003ooooo`;o000000?oooooo`000?l000002Oooool4o`0003;ooooo0_l00000
0ooooooo0000o`000005ooooo`;o00004oooool2o`0001Oooooo000Yooooo`03o`000?oooooooooo
00cooooo0_l00004ooooo`;o00003oooool2o`0001Oooooo0_l0000Qooooo`;o00001oooool3o`00
00cooooo0_l0000>ooooo`;o00006?ooool2o`0000_ooooo0_l0000@ooooo`;o000000?oooooo`00
0?l000002Oooool5o`00027ooooo0_l0000Hooooo`;o00002_ooool2o`0000Oooooo0_l0000Goooo
o`00:Oooool2o`0000gooooo0_l0000;ooooo`;o00002?ooool2o`0003kooooo0_l00004ooooo`;o
0000;oooool2o`0000kooooo0_l0000<ooooo`;o00002Oooool2o`0000cooooo0_l0000Nooooo`;o
000000?oooooo`000?l000009?ooool2o`00023ooooo000Yooooo`03o`000?oooooooooo01Sooooo
0ol0000Uooooo`;o00008Oooool2o`0002Kooooo0_l0000=ooooo`;o00003_ooool2o`000003oooo
ool0003o000000Wooooo0_l00009ooooo`;o00001_ooool2o`0001Cooooo0_l0000>ooooo`;o0000
BOooool002Wooooo00?o0000ooooooooool00oooool2o`0000gooooo0_l00004ooooo`;o00002_oo
ool4o`0000Sooooo1?l000002Ol@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^ooooo`02o`00
0005onk^k_l0003o0000oc8b<_o^k^h0:Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02Oooool2o`0000Oooooo0_l0000:ooooo`;o0000
2?ooool00onHV9So410@o`000003o`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05
onk^k_l0003o0000oc8b<_o^k^h03?ooool2o`0001Cooooo0_l00006ooooo`;o000000Wo410@oooo
ooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Wo
oooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Yooooo`03o`000?oooooooooo00?ooooo0_l0000=
ooooo`;o00004?ooool4o`0000Gooooo0_l00003ooooo`?o00000_ooool01_mgMgOoV9RHoooooonH
V9SoMgMgooooo`?o000000CoV9RHoooooonHV9SoMgMg:Oooool01OnHV9So8B4Qo`000?l0003oA4A4
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03ogMgMonHV9Sooooo00;o00004_ooool2
o`0000[ooooo0_l00008ooooo`03oa0@4?nj^[[ooooo00?o00000_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00GoMgMgo`000?l0003oV9RHogMgM`0Hooooo`?o00002_ooool2o`0000Cooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0@ooooo`;o00000oooool2o`0001Gooooo00WoMgMgoc8b<_ooooooooooogMgMonH
V9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000Yooooo`03o`00
0?oooooooooo02gooooo0_l00003ooooo`?o00000_ooool01Ol@413ooooooooooooooooo410@00;o
oooo0_l00003ooooo`03oa0@4?oooooooooo00Kooooo0_l00008ooooo`;o00003?ooool2o`0000So
oooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooo
ooooool00_l00006ooooo`;o00001Oooool2o`0001cooooo0_l00003ooooo`05oa0@4?oooooooooo
ooooool@41000oooool01Ol@413ooooooooooooooooo410@01Sooooo0ol0000:ooooo`;o000000?o
ooooo`000?l000000ol00003ooooo`05oa0@4?ooooooooooooooool@41000_ooool2o`0000?ooooo
00?o410@ooooooooool03?ooool4o`0000?ooooo0_l0000Fooooo`04o`000?oooooooooooa0@40?o
oooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo007ooooo000Yooooo`;o
0000;oooool2o`0000;ooooo00?o0000ooooooooool00_ooool2o`0000;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo0ol00008ooooo`;o00003?ooool2o`00
00Wooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000006ooooo`;o00001Oooool2o`0001cooooo00?oZJVYoa0@4?ooool00_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00000Xooooo`04
odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`000002ooooo`;o00000oooool0
0ol0003oooooooooo`0<ooooo`;o00001?ooool2o`0000?ooooo0_l0000Aooooo`05ogMgMolb<S;o
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
0Oooool002Wooooo00?o0000ooooooooool0;_ooool2o`0000;ooooo00?o0000ooooooooool00_oo
ool2o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo
0_l0000;ooooo`;o00005_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo0000023ooooo0_l00004ooooo`;o00000_ooool00ol@
413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000002Sooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`00000Dooooo`;o00000oooool2o`0000_ooooo0_l000001_oo
oooo0000ob4Q8Ol0003o<S8bolc<c0;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000oooool002Wooooo00?o0000ooooooooool08Oooool2o`0000oooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooooooooa0@4005ooooo`;o00003Oooool2o`0001Oooooo00Go0000oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@41000_l000000ooooooo410@ooooo`0Oooooo`?o00000ooo
ool2o`0000?ooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooooooooa0@400Yooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooo
oooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001_ooool2o`0000;ooooo0_l0000G
ooooo`;o000000Coooooo`000?l0003ooooo0ol00004ooooo`05oa0@4?ooooooooooooooool@4100
0oooool01Ol@413ooooooooooooooooo410@00?ooooo000Yooooo`03o`000?oooooooooo017ooooo
0_l0000>ooooo`;o00003oooool01?l0003oooooooooooooool2o`000004oiRHV?ooooooV9RHogMg
M`?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o00008_ooool3o`000003oiRHV?l@413o
oooo00;o000000GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMol0003o0000oiRHV?mgMgL0
1?ooool2o`0000Cooooo0_l0000Eooooo`;o00001Oooool01Ol@413oV9RHoooooonj^[[o000000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02_ooool2
o`0000gooooo0_l0000>ooooo`04onk^k_m4A4Co0000o`0000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`06ogMgMonHV9SooooooiRHV?mgMgOooooo0_l00003ooooo`;o00000_ooool2o`00
01Oooooo0_l00004ooooo`Go000000Ooooooo`000?l0003oV9RHoooooonHV9SoMgMg00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool00ol0003oooooooooo`0Aooooo`;o00007Ooo
ool00omEEEGoIVIVo`000003ooooo`;o000000Co<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^02Wooooo00KoV9RHo`000?l0003o8B4Qolc<c?ooool2o`000005onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo0_l00004ooooo`;o0000
7?ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`06onk^k_lb<S;o0000oc8b<_o^k^kooooo0ol00003ooooo`;o000000?oooooo`000?l000003Ooo
ool2o`0000oooooo00?oMgMgo`000?l000000oooool01Oo^k^ko0000o`000?lb<S;ok^k^00;o0000
00Ooooooonk^k_lb<S;o0000oc8b<_o^k^kooooo00;o00000_ooool2o`0002;ooooo1Ol000001ooo
oooo0000o`000?lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
000Yooooo`;o0000J_ooool2o`0005Gooooo0ol00003ooooo`;o00009_ooool4o`0000;ooooo0_l0
000;ooooo`;o00009oooool2o`00013ooooo000Yooooo`?o000000?oooooo`000?l00000I_ooool2
o`0002gooooo0_l0000/ooooo`;o00001_ooool2o`0001kooooo0_l0000aooooo`;o00001oooool2
o`00013ooooo000Yooooo`?o000000?oooooo`000?l000000oooool2o`0000Sooooo0_l0000Ioooo
o`;o00005Oooool2o`0003Cooooo0_l0000Nooooo`;o00007?ooool2o`0001Kooooo0_l00002oooo
o`;o00006oooool2o`0002gooooo0_l000000ooooooo0000o`00000Iooooo`00:Oooool00ol0003o
ooooooooo`06ooooo`;o00002?ooool2o`0001Wooooo0_l0000Eooooo`;o0000=?ooool2o`0000Wo
oooo0_l0000Jooooo`;o00001?ooool2o`000003ooooool0003o000000cooooo0_l0000Jooooo`;o
00006oooool2o`0000gooooo0_l0000Fooooo`;o00001_ooool2o`0001cooooo000Yooooo`05o`00
0?oooooo0000o`000?ooool00_l0000Uooooo`;o00001Oooool2o`0000?ooooo0_l00006ooooo`;o
00007?ooool2o`0001cooooo0_l00002ooooo`;o00001?ooool2o`0000;ooooo0_l0000Cooooo`;o
000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000Kooooo0_l0000=ooooo`;o
0000?Oooool2o`0001Cooooo1?l0000Tooooo`008Oooooooo`0004Co00001?ooool002Wooooo00?o
0000ooooooooool02?ooool2o`0000?ooooo0_l00007ooooo`04o`000?ooooooooooooooo`;o0000
1_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo0_l00003ooooo`04o`00
0?ooooooooooooooo`;o000000?oooooo`000?l000001?ooool00ol0003oooooooooo`07ooooo`?o
00002oooool00ol0003oooooooooo`04ooooo`;o00000oooool00ol0003oooooooooo`0:ooooo`04
o`000?oooooo0000o`0000Sooooo00?o0000ooooooooool00_ooool2o`0000Gooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`06ooooo`;o00000_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00;ooooo0_l00005ooooo`03o`000?oooooooooo00?ooooo0_l00004oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool2o`000003ooooool0003ooooo
00[ooooo00?o0000ooooooooool00_ooool2o`0000Gooooo00Co0000oooooooooooooooo0_l00007
ooooo`04o`000?ooooooooooooooo`;o00001_ooool00ol0003oooooooooo`09ooooo`?o00002Ooo
ool00ol0003oooooooooo`0:ooooo`00:Oooool00ol0003oooooooooo`0=ooooo`;o00003_ooool2
o`0000Wooooo0_l0000;ooooo`;o00000oooool00ol0003oooooooooo`02ooooo`;o00004?ooool4
o`00017ooooo0_l0000@ooooo`04o`000?oooooo0000o`0000gooooo0_l0000Jooooo`;o00003_oo
ool00ol0003oooooooooo`02ooooo`;o00002oooool2o`0001Oooooo0_l0000:ooooo`;o00001?oo
ool2o`00033ooooo0_l00009ooooo`03o`000?oooooooooo00[ooooo000Yooooo`03o`000?oooooo
oooo01cooooo0ol00006ooooo`;o000000?oooooo`000?l000005Oooool2o`0000Wooooo0_l00007
ooooo`;o0000>?ooool2o`0000oooooo0_l0000Cooooo`;o00008?ooool2o`0000;ooooo0_l00003
ooooo`Co00002_ooool2o`0000Cooooo0_l0000Aooooo`;o0000=Oooool002Wooooo00?o0000oooo
ooooool07?ooool2o`0000Oooooo0_l0000:ooooo`;o00005oooool2o`0001[ooooo0_l0000Aoooo
o`;o00002Oooool2o`0000Oooooo0_l0000?ooooo`;o00004oooool2o`0000Wooooo0_l0000;oooo
o`;o00000oooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0002Gooooo0_l000000ooo
oooo0000o`00000Iooooo`;o00005oooool002Wooooo0_l0000Yooooo`;o00001oooool2o`0000Go
oooo0_l00009ooooo`;o00003Oooool2o`0001;ooooo0_l00003ooooo`;o00003?ooool2o`0000Wo
oooo0_l0000Booooo`;o00009?ooool2o`0000Sooooo0_l000000ooooooo0000o`000003ooooo`;o
0000;oooool2o`0000Gooooo0_l00008ooooo`;o00003oooool4o`0001Gooooo000Yooooo`03o`00
0?oooooooooo02Sooooo0_l00005ooooo`;o00001oooool2o`0000Wooooo0_l0000=ooooo`;o0000
5oooool2o`00013ooooo0_l0000Dooooo`;o00000oooool2o`0002kooooo0_l0000Uooooo`;o0000
4?ooool2o`0000oooooo0_l0000Aooooo`Co00004oooool002Wooooo00Co0000ooooool0003o0000
3?ooool2o`00023ooooo0_l0000fooooo`;o00004oooool3o`0001Cooooo0_l000000ooooooo0000
o`000019ooooo`;o00003?ooool2o`0000Oooooo0_l00005ooooo`;o00005_ooool3o`0000gooooo
0_l0000Cooooo`00:Oooool01?l0003oooooo`000?l0000<ooooo`;o00002oooool2o`0004_ooooo
0_l0000;ooooo`;o00001_ooool2o`0000?ooooo0_l0000Cooooo`;o0000BOooool2o`0001Gooooo
0_l00005ooooo`;o00002oooool2o`0000Wooooo0ol0000Rooooo`00:Oooool00ol0003ooooooooo
o`0Jooooo`;o00005_ooool2o`00023ooooo1?l0000Jooooo`Co00002oooool2o`00057ooooo0_l0
000Hooooo`;o00002Oooool2o`000003ooooool0003o000000kooooo0_l00007ooooo`Co00004?oo
ool2o`00017ooooo000Yooooo`;o0000;Oooool2o`0000Cooooo0_l0000Pooooo`Co00006_ooool2
o`0002Wooooo0_l0000eooooo`;o00006?ooool2o`0000Wooooo0_l000001?oooooo0000o`000?oo
ool2o`0001Cooooo0_l0000Booooo`;o00004Oooool002Wooooo00?o0000ooooooooool07_ooool2
o`0000[ooooo1?l0001Aooooo`;o00007?ooool2o`0000cooooo0_l0001Booooo`;o00004Oooool2
o`0000Wooooo0_l00003ooooo`;o00001?ooool2o`0001;ooooo000Yooooo`03o`000?oooooooooo
01kooooo0_l0000:ooooo`;o0000@Oooool2o`00013ooooo0_l0000Iooooo`;o00002oooool2o`00
00;ooooo0_l0000Vooooo`;o00002Oooool2o`0002oooooo0_l000000ooooooo0000o`000009oooo
o`;o00000oooool2o`0000Cooooo0_l00003ooooo`;o00003Oooool002Wooooo00?o0000oooooooo
ool09oooool2o`0000Gooooo0_l0000Dooooo`;o00007?ooool2o`0000?ooooo0_l00004ooooo`;o
0000:oooool5o`0000Sooooo0_l0000Dooooo`;o00003_ooool2o`0000Cooooo0_l00009ooooo`;o
0000;oooool2o`0001cooooo0_l0000=ooooo`00:Oooool00ol0003oooooooooo`0Dooooo`;o0000
4Oooool2o`0000Gooooo0_l00002ooooo`;o00004?ooool2o`0001Cooooo0_l00006ooooo`Co0000
00?oooooo`000?l000007?ooool2o`0000;ooooo0_l00004ooooo`;o00002oooool3o`0001Oooooo
0_l00005ooooo`;o00003_ooool2o`0001kooooo0_l0000=ooooo`;o00001_ooool2o`0003Kooooo
000Yooooo`;o00005Oooool2o`00017ooooo0_l00009ooooo`;o00003?ooool2o`0000Oooooo0_l0
000?ooooo`;o00002?ooool2o`0001cooooo0_l000000ooooooo0000o`000002ooooo`;o00001?oo
ool2o`0001?ooooo0_l0000@ooooo`;o00005?ooool2o`00017ooooo0_l0000<ooooo`;o00003Ooo
ool4o`0000Cooooo0_l0000fooooo`00:Oooool2o`0000Sooooo0_l00006ooooo`;o00003oooool4
o`0000?ooooo0_l0000Gooooo`;o00001oooool2o`0000Kooooo0_l00002ooooo`;o000000?ooooo
o`000?l000007?ooool2o`0000[ooooo0_l00009ooooo`;o00005Oooool2o`0002Kooooo0_l0000A
ooooo`;o00007Oooool2o`0000?ooooo0_l0000Vooooo`;o00003oooool002Wooooo0_l00008oooo
o`;o00001_ooool2o`0000Kooooo0ol00006ooooo`Co00005_ooool2o`0001Gooooo0_l00002oooo
o`;o000000?oooooo`000?l000007?ooool2o`0001Gooooo0_l00015ooooo`;o00004oooool2o`00
01Sooooo0_l0000Jooooo`;o00002_ooool2o`0000oooooo000Yooooo`04o`000?oooooooooooooo
o`;o00001_ooool2o`0000cooooo0ol000000ooooooo0000o`00000Iooooo`;o00000_ooool2o`00
07?ooooo0_l0000Sooooo`;o00004oooool2o`0000oooooo0_l0000>ooooo`;o00001oooool2o`00
00[ooooo0_l0000Kooooo`00:Oooool01?l0003oooooooooooooool2o`0000Kooooo0_l0000@oooo
o`;o00000_ooool2o`0001;ooooo0_l000000ooooooo0000o`00000Sooooo`;o0000?_ooool2o`00
01;ooooo0_l0000Rooooo`;o00009Oooool2o`0000kooooo0_l00007ooooo`;o00009oooool002Wo
oooo0_l0000@ooooo`;o00003_ooool2o`0001;ooooo0_l0000Vooooo`;o0000?_ooool2o`0003Ko
oooo0_l00004ooooo`;o00004?ooool2o`0002oooooo0_l0000@ooooo`;o00003?ooool002Wooooo
00?o0000ooooooooool02oooool2o`0000;ooooo0_l0001;ooooo`;o00004oooool2o`0000Cooooo
0_l0000Looooo`;o00002Oooool2o`00013ooooo0_l0000Uooooo`;o00004?ooool2o`0002oooooo
0_l00002ooooo`;o00003?ooool2o`0000cooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`0;ooooo`;o00004oooool2o`0001Wooooo0_l0000Looooo`;o000000?oooooo`000?l0
00003?ooool2o`0000Gooooo0_l00004ooooo`;o00003?ooool2o`0000kooooo0_l00009ooooo`;o
00001oooool2o`0000Oooooo0_l0001/ooooo`;o00006_ooool000Kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`0Pooooo`Co00005oooool2o`0001;ooooo0_l00008oooo
o`;o00003oooool2o`0001Wooooo0_l0000Rooooo`;o000000?oooooo`000?l00000Moooool2o`00
00Gooooo0_l0000>ooooo`001_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q
8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo0_l00005oooo
o`;o00004_ooool2o`0002_ooooo0_l0000Jooooo`;o00003oooool2o`0001?ooooo0_l0000Ioooo
o`;o00005_ooool2o`0001cooooo0_l0000Booooo`;o0000;Oooool2o`0000Gooooo0_l0000>oooo
o`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omg
MgOo<S8booooo`04ooooo`?o00001oooool4o`0000?ooooo0_l0000nooooo`;o00006oooool2o`00
00oooooo0_l0000Cooooo`;o00003oooool2o`00017ooooo1?l0000;ooooo`;o00007?ooool2o`00
01;ooooo0_l00014ooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool00_l00002
ooooo`;o00000oooool2o`00033ooooo0_l00009ooooo`;o00001_ooool2o`0004;ooooo0_l0000>
ooooo`;o00003Oooool2o`0000;ooooo1?l0000Dooooo`;o0000KOooool000Kooooo00Go410@oooo
oooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`02o`0000;ooooo0ol0000=ooooo`;o00003Oooool2o`0000Gooooo0_l0000?
ooooo`;o00002Oooool4o`0000gooooo0_l0000cooooo`;o00001?ooool2o`0001gooooo1?l0000C
ooooo`;o00000oooool2o`0000Oooooo0_l00013ooooo`;o00007oooool000Kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Gooooo0_l00003ooooo`;o00002?ooool2o`0000gooooo0_l0
0005ooooo`;o00007?ooool2o`0000gooooo0_l0000Qooooo`;o00003_ooool4o`0002Cooooo0ol0
0008ooooo`;o00002Oooool2o`0000cooooo0_l00002ooooo`;o00006oooool2o`0002;ooooo0_l0
000Oooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c004ooooo`Co00001_ooool00ol0003oooooooooo`04ooooo`;o00001?ooool2o`0006kooooo
0_l0000>ooooo`;o00002oooool2o`00017ooooo0_l0000Aooooo`;o00005oooool2o`0000;ooooo
0_l0000:ooooo`;o00003oooool2o`00023ooooo0_l0000Qooooo`00:Oooool2o`0000Gooooo0_l0
0004ooooo`;o0000??ooool2o`0000Wooooo0_l0000Oooooo`;o00005?ooool2o`0000Cooooo0_l0
0005ooooo`;o00004Oooool2o`0002[ooooo0_l00007ooooo`;o00001Oooool3o`00033ooooo0_l0
000Qooooo`00:Oooool00ol0003oooooooooo`0:ooooo`;o0000??ooool2o`0000?ooooo0_l00004
ooooo`;o00002?ooool2o`0001Gooooo1?l0000Booooo`;o00001?ooool2o`0004gooooo0_l00005
ooooo`?o0000Doooool002Wooooo00?o0000ooooooooool0COooool2o`0000kooooo0_l0000Goooo
o`;o00001oooool2o`0000?ooooo0_l0000fooooo`;o00001oooool2o`0000?ooooo0_l0000Uoooo
o`;o00005_ooool2o`00037ooooo000Yooooo`03o`000?oooooooooo053ooooo0_l0000]ooooo`;o
00000oooool2o`0003Kooooo0_l00007ooooo`;o00000oooool2o`0001Sooooo0_l0000;ooooo`;o
00005_ooool2o`0000Wooooo0_l0000Vooooo`00:Oooool00ol0003oooooooooo`17ooooo`;o0000
1oooool2o`0008[ooooo0_l00006ooooo`;o0000;_ooool2o`0002Kooooo000Yooooo`;o0000;_oo
ool2o`0001Sooooo0_l00005ooooo`;o00004?ooool2o`0007[ooooo0_l0000Rooooo`;o0000>_oo
ool002Wooooo00?o0000ooooooooool04oooool4o`0001Kooooo0_l0000Oooooo`;o00003_ooool4
o`0005;ooooo0_l0000_ooooo`;o00000_ooool2o`0001Gooooo0_l0000jooooo`00:Oooool00ol0
003oooooooooo`0Cooooo`Co00001Oooool2o`0002Sooooo0_l00008ooooo`;o00001oooool2o`00
00?ooooo0_l0001;ooooo`;o00001oooool2o`0002oooooo0_l00002ooooo`;o0000A?ooool2o`00
00_ooooo000Yooooo`03o`000?oooooooooo01cooooo0_l0000Xooooo`;o00002?ooool2o`0000Oo
oooo0_l00004ooooo`;o0000;Oooool2o`0000Gooooo0_l00002ooooo`;o00004?ooool2o`0001co
oooo0_l0001Tooooo`;o00002oooool002Wooooo00?o0000ooooooooool0G?ooool2o`000003oooo
ool0003o000000Cooooo0_l00005ooooo`;o00008?ooool2o`0000Gooooo0_l00002ooooo`;o0000
2oooool2o`00027ooooo0_l0001aooooo`00:Oooool2o`0005gooooo0_l00007ooooo`;o00001Ooo
ool2o`0000Cooooo0_l0000booooo`;o00005_ooool2o`0002Sooooo0_l0001Booooo`00:Oooool0
0ol0003oooooooooo`1/ooooo`;o00001?ooool2o`0004[ooooo0_l000000ooooooo0000o`00000I
ooooo`;o00002Oooool3o`0000Sooooo0_l00018ooooo`00:Oooool00ol0003oooooooooo`31oooo
o`;o00006Oooool2o`0000Wooooo0_l00003ooooo`;o00001?ooool2o`0004Sooooo000Yooooo`03
o`000?oooooooooo00cooooo0_l0000Vooooo`;o0000]_ooool2o`0004kooooo000Yooooo`03o`00
0?oooooooooo00cooooo0_l0000Vooooo`;o0000Poooool2o`0003Sooooo0_l00017ooooo`00:Ooo
ool2o`0001Kooooo0_l0002Rooooo`;o00001oooool2o`0002oooooo0_l00005ooooo`;o0000@?oo
ool002Wooooo00?o0000ooooooooool05Oooool2o`0002cooooo0_l0000Yooooo`;o000000?ooooo
o`000?l00000Coooool2o`0002Oooooo0_l0000=ooooo`;o00002Oooool2o`0003Gooooo000>oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@05ooooo`03o`000?oooooooooo04?ooooo0_l0000Looooo`;o00002oooool2o`000003ooooool0
003o000000;ooooo0_l0000;ooooo`;o00004oooool2o`0004Cooooo0_l0000<ooooo`;o00006?oo
ool2o`0001?ooooo0_l0000Pooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0HOooool2o`0001;ooooo0_l0
000;ooooo`;o00004oooool2o`0004Cooooo0_l0000kooooo`;o00003_ooool2o`00013ooooo000>
ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`?o0000cooo
ool2o`0005Wooooo0_l0000@ooooo`003_ooool01Ol0003ooooooooooooooooo000000oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3?ooooo`;o0000>_ooool2o`0002oooooo000>
ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool0ooooool<ooooo`;o0000;oooool000kooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07Oooool2o`0000cooooo
0_l0003ooooooa3ooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo01gooooo0_l0000<ooooo`;o0000ooooool@ooooo`003_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000>_ooool2o`000<cooooo
0_l0000cooooo`00:Oooool00ol0003oooooooooo`0iooooo`;o0000c?ooool2o`0003?ooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
00Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocgooooo0006
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@
oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00ooo
ool3o`000?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooo
oooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006
ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?oo
ooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co
00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000O
ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3oooooocgooooo000Qoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003o
ooooooooo`05ooooo`?o0000oooooolmooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Oooooo`03oeEEEOmVIVKo00000?oo
ooooAoooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .32729 Mdot
.02762 .27255 Mdot
.02952 .3115 Mdot
.03143 .3401 Mdot
.03333 .2616 Mdot
.03524 .37924 Mdot
.03714 .3198 Mdot
.03905 .25501 Mdot
.04095 .3582 Mdot
.04286 .34644 Mdot
.04476 .26694 Mdot
.04667 .30614 Mdot
.04857 .41386 Mdot
.05048 .29596 Mdot
.05238 .29776 Mdot
.05429 .25703 Mdot
.05619 .37792 Mdot
.0581 .41407 Mdot
.06 .35481 Mdot
.0619 .26639 Mdot
.06381 .41213 Mdot
.06571 .34521 Mdot
.06762 .361 Mdot
.06952 .41253 Mdot
.07143 .39467 Mdot
.07333 .33403 Mdot
.07524 .2563 Mdot
.07714 .35688 Mdot
.07905 .29637 Mdot
.08095 .27278 Mdot
.08286 .4099 Mdot
.08476 .35085 Mdot
.08667 .22692 Mdot
.08857 .35854 Mdot
.09048 .25409 Mdot
.09238 .25436 Mdot
.09429 .42828 Mdot
.09619 .33822 Mdot
.0981 .31348 Mdot
.1 .34035 Mdot
.1019 .40853 Mdot
.10381 .3074 Mdot
.10571 .28789 Mdot
.10762 .28202 Mdot
.10952 .35369 Mdot
.11143 .35731 Mdot
.11333 .32509 Mdot
.11524 .3978 Mdot
.11714 .25858 Mdot
.11905 .26809 Mdot
.12095 .40343 Mdot
.12286 .37863 Mdot
.12476 .41429 Mdot
.12667 .24417 Mdot
.12857 .26111 Mdot
.13048 .28597 Mdot
.13238 .25962 Mdot
.13429 .37895 Mdot
.13619 .42911 Mdot
.1381 .36668 Mdot
.14 .36256 Mdot
.1419 .44717 Mdot
.14381 .31388 Mdot
.14571 .30276 Mdot
.14762 .23893 Mdot
.14952 .31484 Mdot
.15143 .34808 Mdot
.15333 .27273 Mdot
.15524 .34674 Mdot
.15714 .40803 Mdot
.15905 .37601 Mdot
.16095 .27564 Mdot
.16286 .34599 Mdot
.16476 .33866 Mdot
.16667 .31331 Mdot
.16857 .27346 Mdot
.17048 .41453 Mdot
.17238 .36656 Mdot
.17429 .36047 Mdot
.17619 .25807 Mdot
.1781 .37062 Mdot
.18 .2603 Mdot
.1819 .33627 Mdot
.18381 .291 Mdot
.18571 .22615 Mdot
.18762 .26566 Mdot
.18952 .27127 Mdot
.19143 .29636 Mdot
.19333 .37525 Mdot
.19524 .26935 Mdot
.19714 .39607 Mdot
.19905 .22057 Mdot
.20095 .26278 Mdot
.20286 .33393 Mdot
.20476 .26266 Mdot
.20667 .22683 Mdot
.20857 .30443 Mdot
.21048 .40595 Mdot
.21238 .42774 Mdot
.21429 .3796 Mdot
.21619 .29962 Mdot
.2181 .36166 Mdot
.22 .29212 Mdot
.2219 .2593 Mdot
.22381 .38539 Mdot
.22571 .34685 Mdot
.22762 .36992 Mdot
.22952 .33951 Mdot
.23143 .26399 Mdot
.23333 .40765 Mdot
.23524 .32788 Mdot
.23714 .34074 Mdot
.23905 .35836 Mdot
.24095 .23261 Mdot
.24286 .49098 Mdot
.24476 .31739 Mdot
.24667 .36649 Mdot
.24857 .26789 Mdot
.25048 .30424 Mdot
.25238 .41907 Mdot
.25429 .41312 Mdot
.25619 .4588 Mdot
.2581 .39831 Mdot
.26 .3105 Mdot
.2619 .40708 Mdot
.26381 .33484 Mdot
.26571 .23359 Mdot
.26762 .26459 Mdot
.26952 .2449 Mdot
.27143 .32079 Mdot
.27333 .3679 Mdot
.27524 .26577 Mdot
.27714 .33906 Mdot
.27905 .38781 Mdot
.28095 .3284 Mdot
.28286 .34712 Mdot
.28476 .42912 Mdot
.28667 .25935 Mdot
.28857 .34706 Mdot
.29048 .22948 Mdot
.29238 .31379 Mdot
.29429 .41334 Mdot
.29619 .32405 Mdot
.2981 .35665 Mdot
.3 .37837 Mdot
.3019 .24107 Mdot
.30381 .23389 Mdot
.30571 .47071 Mdot
.30762 .34333 Mdot
.30952 .31812 Mdot
.31143 .46216 Mdot
.31333 .35504 Mdot
.31524 .317 Mdot
.31714 .41166 Mdot
.31905 .26892 Mdot
.32095 .39263 Mdot
.32286 .41426 Mdot
.32476 .33983 Mdot
.32667 .27692 Mdot
.32857 .42662 Mdot
.33048 .41849 Mdot
.33238 .27213 Mdot
.33429 .36609 Mdot
.33619 .41879 Mdot
.3381 .30535 Mdot
.34 .2699 Mdot
.3419 .32154 Mdot
.34381 .24098 Mdot
.34571 .36791 Mdot
.34762 .3404 Mdot
.34952 .42054 Mdot
.35143 .23537 Mdot
.35333 .2636 Mdot
.35524 .31251 Mdot
.35714 .26302 Mdot
.35905 .32494 Mdot
.36095 .22822 Mdot
.36286 .23649 Mdot
.36476 .39106 Mdot
.36667 .29705 Mdot
.36857 .29923 Mdot
.37048 .4071 Mdot
.37238 .36756 Mdot
.37429 .31408 Mdot
.37619 .41677 Mdot
.3781 .26558 Mdot
.38 .37263 Mdot
.3819 .27541 Mdot
.38381 .34737 Mdot
.38571 .4096 Mdot
.38762 .31638 Mdot
.38952 .46087 Mdot
.39143 .24197 Mdot
.39333 .33176 Mdot
.39524 .45444 Mdot
.39714 .23164 Mdot
.39905 .44507 Mdot
.40095 .31438 Mdot
.40286 .31694 Mdot
.40476 .25639 Mdot
.40667 .33789 Mdot
.40857 .26578 Mdot
.41048 .26675 Mdot
.41238 .28616 Mdot
.41429 .25143 Mdot
.41619 .28454 Mdot
.4181 .29133 Mdot
.42 .30943 Mdot
.4219 .38725 Mdot
.42381 .34087 Mdot
.42571 .28284 Mdot
.42762 .25712 Mdot
.42952 .40225 Mdot
.43143 .36643 Mdot
.43333 .3669 Mdot
.43524 .28131 Mdot
.43714 .31459 Mdot
.43905 .36218 Mdot
.44095 .41997 Mdot
.44286 .26277 Mdot
.44476 .38378 Mdot
.44667 .32138 Mdot
.44857 .36577 Mdot
.45048 .42809 Mdot
.45238 .37653 Mdot
.45429 .35318 Mdot
.45619 .25773 Mdot
.4581 .25822 Mdot
.46 .26124 Mdot
.4619 .26316 Mdot
.46381 .30262 Mdot
.46571 .45584 Mdot
.46762 .27587 Mdot
.46952 .2727 Mdot
.47143 .27929 Mdot
.47333 .29668 Mdot
.47524 .25849 Mdot
.47714 .46035 Mdot
.47905 .32806 Mdot
.48095 .24479 Mdot
.48286 .40243 Mdot
.48476 .27561 Mdot
.48667 .44788 Mdot
.48857 .36047 Mdot
.49048 .32733 Mdot
.49238 .37638 Mdot
.49429 .33824 Mdot
.49619 .27649 Mdot
.4981 .39995 Mdot
.5 .34492 Mdot
.5019 .37749 Mdot
.50381 .32338 Mdot
.50571 .43886 Mdot
.50762 .3136 Mdot
.50952 .33326 Mdot
.51143 .40864 Mdot
.51333 .33669 Mdot
.51524 .30224 Mdot
.51714 .29844 Mdot
.51905 .27677 Mdot
.52095 .24144 Mdot
.52286 .41527 Mdot
.52476 .27803 Mdot
.52667 .25819 Mdot
.52857 .33651 Mdot
.53048 .32894 Mdot
.53238 .3435 Mdot
.53429 .35478 Mdot
.53619 .31768 Mdot
.5381 .34654 Mdot
.54 .23743 Mdot
.5419 .31047 Mdot
.54381 .23617 Mdot
.54571 .279 Mdot
.54762 .34596 Mdot
.54952 .24764 Mdot
.55143 .41393 Mdot
.55333 .32633 Mdot
.55524 .28347 Mdot
.55714 .39534 Mdot
.55905 .25828 Mdot
.56095 .3923 Mdot
.56286 .32482 Mdot
.56476 .29977 Mdot
.56667 .31392 Mdot
.56857 .42532 Mdot
.57048 .2763 Mdot
.57238 .33446 Mdot
.57429 .28347 Mdot
.57619 .28132 Mdot
.5781 .24295 Mdot
.58 .33693 Mdot
.5819 .38526 Mdot
.58381 .27906 Mdot
.58571 .4319 Mdot
.58762 .27086 Mdot
.58952 .43159 Mdot
.59143 .30107 Mdot
.59333 .43379 Mdot
.59524 .45797 Mdot
.59714 .26867 Mdot
.59905 .286 Mdot
.60095 .44947 Mdot
.60286 .24648 Mdot
.60476 .34127 Mdot
.60667 .25363 Mdot
.60857 .34265 Mdot
.61048 .39405 Mdot
.61238 .30966 Mdot
.61429 .40025 Mdot
.61619 .32455 Mdot
.6181 .28867 Mdot
.62 .39675 Mdot
.6219 .3792 Mdot
.62381 .41038 Mdot
.62571 .46252 Mdot
.62762 .32238 Mdot
.62952 .37601 Mdot
.63143 .33666 Mdot
.63333 .22951 Mdot
.63524 .32836 Mdot
.63714 .37078 Mdot
.63905 .4514 Mdot
.64095 .37897 Mdot
.64286 .30821 Mdot
.64476 .3913 Mdot
.64667 .28006 Mdot
.64857 .34267 Mdot
.65048 .25153 Mdot
.65238 .26585 Mdot
.65429 .31359 Mdot
.65619 .37577 Mdot
.6581 .29523 Mdot
.66 .40101 Mdot
.6619 .26272 Mdot
.66381 .38293 Mdot
.66571 .31253 Mdot
.66762 .28731 Mdot
.66952 .26596 Mdot
.67143 .37518 Mdot
.67333 .27202 Mdot
.67524 .27336 Mdot
.67714 .25066 Mdot
.67905 .3938 Mdot
.68095 .33202 Mdot
.68286 .24123 Mdot
.68476 .30561 Mdot
.68667 .24529 Mdot
.68857 .2542 Mdot
.69048 .24813 Mdot
.69238 .28498 Mdot
.69429 .2986 Mdot
.69619 .34284 Mdot
.6981 .41431 Mdot
.7 .30502 Mdot
.7019 .43408 Mdot
.70381 .24257 Mdot
.70571 .24876 Mdot
.70762 .35071 Mdot
.70952 .23372 Mdot
.71143 .3233 Mdot
.71333 .30202 Mdot
.71524 .36065 Mdot
.71714 .31877 Mdot
.71905 .3324 Mdot
.72095 .37647 Mdot
.72286 .42296 Mdot
.72476 .31302 Mdot
.72667 .27421 Mdot
.72857 .31386 Mdot
.73048 .24851 Mdot
.73238 .31861 Mdot
.73429 .39683 Mdot
.73619 .33977 Mdot
.7381 .39079 Mdot
.74 .30975 Mdot
.7419 .39701 Mdot
.74381 .24733 Mdot
.74571 .43338 Mdot
.74762 .37628 Mdot
.74952 .35156 Mdot
.75143 .43584 Mdot
.75333 .35792 Mdot
.75524 .37434 Mdot
.75714 .48653 Mdot
.75905 .42564 Mdot
.76095 .39406 Mdot
.76286 .27065 Mdot
.76476 .44085 Mdot
.76667 .37437 Mdot
.76857 .30919 Mdot
.77048 .37904 Mdot
.77238 .40686 Mdot
.77429 .26608 Mdot
.77619 .34416 Mdot
.7781 .35842 Mdot
.78 .26748 Mdot
.7819 .38774 Mdot
.78381 .3607 Mdot
.78571 .45603 Mdot
.78762 .37368 Mdot
.78952 .37174 Mdot
.79143 .36599 Mdot
.79333 .36153 Mdot
.79524 .32807 Mdot
.79714 .29713 Mdot
.79905 .30886 Mdot
.80095 .2792 Mdot
.80286 .30009 Mdot
.80476 .25518 Mdot
.80667 .2845 Mdot
.80857 .27795 Mdot
.81048 .2871 Mdot
.81238 .45788 Mdot
.81429 .33013 Mdot
.81619 .3019 Mdot
.8181 .32773 Mdot
.82 .31928 Mdot
.8219 .32699 Mdot
.82381 .30237 Mdot
.82571 .36643 Mdot
.82762 .28578 Mdot
.82952 .31882 Mdot
.83143 .46059 Mdot
.83333 .2289 Mdot
.83524 .27785 Mdot
.83714 .24554 Mdot
.83905 .36999 Mdot
.84095 .39251 Mdot
.84286 .32673 Mdot
.84476 .32641 Mdot
.84667 .44587 Mdot
.84857 .22097 Mdot
.85048 .2408 Mdot
.85238 .4879 Mdot
.85429 .26205 Mdot
.85619 .33204 Mdot
.8581 .34896 Mdot
.86 .32194 Mdot
.8619 .26362 Mdot
.86381 .28016 Mdot
.86571 .39919 Mdot
.86762 .29274 Mdot
.86952 .28112 Mdot
.87143 .3121 Mdot
.87333 .3367 Mdot
.87524 .27257 Mdot
.87714 .23145 Mdot
.87905 .26477 Mdot
.88095 .2484 Mdot
.88286 .30731 Mdot
.88476 .27262 Mdot
.88667 .3166 Mdot
.88857 .3371 Mdot
.89048 .25468 Mdot
.89238 .32939 Mdot
.89429 .35087 Mdot
.89619 .24905 Mdot
.8981 .36289 Mdot
.9 .23245 Mdot
.9019 .39695 Mdot
.90381 .3769 Mdot
.90571 .25595 Mdot
.90762 .34662 Mdot
.90952 .30204 Mdot
.91143 .44014 Mdot
.91333 .31911 Mdot
.91524 .43381 Mdot
.91714 .31915 Mdot
.91905 .36925 Mdot
.92095 .24652 Mdot
.92286 .29466 Mdot
.92476 .3516 Mdot
.92667 .34554 Mdot
.92857 .35748 Mdot
.93048 .44483 Mdot
.93238 .31454 Mdot
.93429 .27316 Mdot
.93619 .26364 Mdot
.9381 .25176 Mdot
.94 .31232 Mdot
.9419 .3023 Mdot
.94381 .24311 Mdot
.94571 .3277 Mdot
.94762 .28615 Mdot
.94952 .35114 Mdot
.95143 .31161 Mdot
.95333 .25938 Mdot
.95524 .36744 Mdot
.95714 .35599 Mdot
.95905 .35541 Mdot
.96095 .32425 Mdot
.96286 .49204 Mdot
.96476 .323 Mdot
.96667 .26913 Mdot
.96857 .42823 Mdot
.97048 .29463 Mdot
.97238 .35164 Mdot
.97429 .27476 Mdot
.97619 .34755 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo03Gooooo0_l0003>ooooo`;o0000=Oooool000Kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo03Gooooo0_l0003>ooooo`;o0000=Oooool000Kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0@ooooo`;o00007_ooool2o`0000Gooooo0_l0
003oooooo`Cooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0@ooooo`;o00007_oo
ool2o`0000Gooooo0_l0000Iooooo`;o00005Oooool2o`0005Gooooo0_l0000oooooo`;o0000>Ooo
ool000Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o
MgMgoc8b<_ooool01?ooool3o`0004;ooooo0_l00006ooooo`;o00001_ooool2o`0000;ooooo0_l0
000Aooooo`;o00002Oooool2o`0004[ooooo0_l0000Gooooo`;o00009_ooool2o`0000cooooo0_l0
0005ooooo`;o00009?ooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo04;ooooo
0_l00006ooooo`;o00002_ooool2o`0000kooooo0_l000000ooooooo0000o`000009ooooo`;o0000
;Oooool2o`0003Cooooo0_l0000dooooo`;o00001Oooool2o`0002Cooooo0006ooooo`05oa0@4?oo
ooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool09?ooool2o`00043ooooo0_l000000ooooooo0000o`00000gooooo`?o0000
Uoooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@
41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Cooooo0_l0000`ooooo`;o
00002oooool2o`0000gooooo0_l0000Xooooo`;o00001?ooool2o`0000[ooooo0_l0000Pooooo`;o
00001Oooool2o`0002gooooo0_l0000Looooo`;o00005_ooool000Kooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000oooo
ooooool07Oooool2o`0002cooooo0_l00009ooooo`;o00002oooool2o`0000gooooo0_l0000Koooo
o`;o00002oooool2o`00013ooooo0_l00006ooooo`;o00006?ooool3o`0000Cooooo0_l0000Yoooo
o`;o00000_ooool2o`0001Gooooo0_l00005ooooo`;o00005_ooool002Wooooo0_l0000Nooooo`;o
0000;?ooool2o`0004;ooooo0_l0000Dooooo`;o00003oooool2o`0001Wooooo1?l00003ooooo`;o
00001Oooool2o`0000?ooooo0_l0000Looooo`;o00003?ooool2o`0000?ooooo0_l00006ooooo`;o
00007Oooool002Wooooo00?o0000ooooooooool0N_ooool2o`0002Wooooo0_l0000Oooooo`;o0000
1_ooool2o`0000?ooooo0_l00003ooooo`;o00001Oooool2o`0000?ooooo0_l0000Zooooo`;o0000
0oooool2o`0000_ooooo0_l0000Hooooo`00:Oooool01?l0003oooooooooooooool2o`0000oooooo
0_l0001Vooooo`;o0000??ooool2o`0000cooooo0_l00006ooooo`;o00000_ooool2o`0002?ooooo
0_l0000Jooooo`;o00000oooool2o`0000Sooooo0_l0000Hooooo`00:Oooool01?l0003ooooooooo
ooooool2o`0000?ooooo0_l00005ooooo`;o00000oooool2o`0000Kooooo0_l0000Aooooo`;o0000
B?ooool2o`0000Gooooo0_l00007ooooo`?o00000oooool2o`0000oooooo0_l00008ooooo`;o0000
3_ooool2o`0001Sooooo0_l0000Sooooo`;o00006_ooool2o`0000?ooooo0_l0000Rooooo`00:Ooo
ool01?l0003oooooo`000?l00005ooooo`;o00001Oooool2o`0000_ooooo0_l00002ooooo`?o0000
3?ooool3o`0000cooooo0_l0000Cooooo`;o00009?ooool2o`0000Gooooo0_l00007ooooo`Co0000
0_ooool2o`0000oooooo0_l00008ooooo`;o0000GOooool2o`0001kooooo0_l0000Cooooo`00:Ooo
ool4o`0001gooooo0ol0000=ooooo`;o00001Oooool3o`0000Cooooo0_l000000ooooooo0000o`00
000:ooooo`;o00001?ooool2o`0001?ooooo0ol0000Jooooo`;o00001?ooool2o`0003kooooo0_l0
000looooo`;o000000?oooooo`000?l000000oooool2o`00017ooooo0_l00003ooooo`;o00004ooo
ool002Wooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l0000@ooooo`;o00005?ooool2
o`0000;ooooo0ol00007ooooo`;o00001?ooool2o`0000Cooooo1?l0000Gooooo`?o00001Oooool2
o`0000Sooooo0ol00008ooooo`;o00001?ooool2o`0003_ooooo0_l000001?oooooo0000o`000?oo
ool2o`00023ooooo0ol0000Iooooo`;o00000oooool2o`00017ooooo0_l0000Hooooo`00:Oooool0
0ol0003oooooooooo`03ooooo`;o00001?ooool2o`00013ooooo0_l0000Cooooo`Go00000_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Kok^k^oc8b<_l0003o<S8bonk^k_ooool2o`0000Ko
oooo0_l0000<ooooo`;o00001Oooool2o`0000Wooooo1Ol00003ooooo`03onk^k_lb<S;o000000?o
00000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Sooooo00GoV9RHoa0@4?l0003o<S8bolc<c003
ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo0_l00004ooooo`;o00006ooo
ool3o`0000;ooooo1?l000000olb<S;ok^k^ooooo`02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
:Oooool01_m4A4Co0000o`000?lb<S;ogMgMooooo`;o000000Co<S8bo`000?lb<S;ok^k^0oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Yooooo`;o00004?ooool2o`0001Gooooo0_l00003
ooooo`;o00001Oooool3o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL05oooool2o`0000;ooooo0_l000000ooooooo0000o`000009ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0:ooooo`;o00007?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo0_l0
00000ooooooo0000o`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool3o`0000kooooo
0_l0000:ooooo`;o00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0Booooo`;o000000?oooooo`000?l000003_ooool2o`0000Gooooo00?oMgMgoc8b
<_ooool00_l000001?nHV9SooooooiRHV?mgMgL3ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool002Wooooo0_l0000@ooooo`;o00005Oooool4o`000003ooooool0003o000000Gooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooo
oa0@400Jooooo`?o00003Oooool00onHV9So0000o`000004ooooo`05oa0@4?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@00Wooooo0ol00002ooooo`;o00000_ooool2o`00
00Kooooo0_l0000>ooooo`?o00000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@
oooooooooooooooooa0@400>ooooo`?o00003_ooool2o`0000Oooooo1Ol00003ooooo`05oa0@4?oo
ooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@01;ooooo0_l000000ooooooo
0000o`00000>ooooo`;o00001_ooool01Ol0003oooooooooool@413ooooo00;o000000Go410@oooo
oooooooooooooa0@4003ooooo`03oa0@4?oooooooooo007ooooo000Yooooo`;o0000:Oooool2o`00
00Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`00000Jooooo`;o00003oooool2o`000005onk^k_ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01oooool3o`0000;o
oooo0_l00002ooooo`;o00001_ooool3o`0000Gooooo0_l00006ooooo`;o000000?o410@ooooool0
00000_l00003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`04oooo
o`;o00008?ooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000000_oo
ool2o`000004ooooool0003o0000o`0000Gooooo0_l00007ooooo`;o00007?ooool01_mgMgOo<S8b
oooooooooooo0000ooooo`?o00000oooool01Ol0003ooooooooooooooooo000000?ooooo000Yoooo
o`03o`000?oooooooooo01Oooooo0_l0000Iooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000;?ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool000000oooool2o`0000;ooooo0_l00009ooooo`;o0000
3oooool2o`0000Gooooo0_l000000ooooooo0000o`000003ooooo`03oa0@4?l0003o000000Co0000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01?ooool2o`00023o
oooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000;ooooo0_l00000
1?oooooo0000o`000?l00005ooooo`;o00001oooool4o`0001Oooooo00Go0000ob4Q8Ol0003o<S8b
olc<c002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo000Yooooo`03o`000?oooooooooo01Oooooo0_l00006ooooo`;o00004Oooool00ol0003o
ooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo
410@02gooooo00Go0000oooooooooooooooooa0@4003ooooo`?o000000?oooooo`000?l000000_oo
ool2o`0002Cooooo0_l00004ooooo`?o00000_ooool00ol@413oooooooooo`02o`0000?ooooo00Go
410@oooooooooooooooooa0@400Dooooo`;o00004oooool00omgMgOoc<c<o`000004ooooo`05oa0@
4?ooooooooooooooool@41000oooool01Ol@413o0000o`000?oooooo410@00?ooooo0_l0000;oooo
o`;o00005oooool2o`0000Gooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo
ooooooooool@41000oooool002Wooooo00?o0000ooooooooool05oooool2o`0000Kooooo0_l0000A
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0:Oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00CoMgMgoiRHV?oo
ooooV9RH0ol000001_ooooooMgMgoiRHV?ooooooV9RHogMgMbSooooo00Go410@oiRHV?oooooo^[Zj
o`000003ooooo`03ogMgMonHV9Sooooo00;o00000oooool01OmgMgOo0000o`000?nHV9SoMgMg00co
oooo0_l00006ooooo`;o00004oooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOo0000o`000?l0003oMgMg00?ooooo0_l0000Tooooo`;o00001Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Ooo
ool00ol0003oooooooooo`0Gooooo`;o00005oooool3o`0000Cooooo00Cok^k^oc8b<_l0003o<S8b
0_l00002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:Oooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Kok^k^oc8b<_l0003o<S8bonk^k_ooool2o`000005onk^k_lb<S;o0000oc8b<_o^k^h0
:?ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`05onk^k_l0003o0000oc8b<_o^k^h03?ooool2o`0001cooooo00?oMgMgo`000?ooool00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o0000onk^kP0@ooooo`;o0000
5oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool002Wooooo0_l00006ooooo`;o00001oooool2o`00023ooooo1?l00007ooooo`;o
0000?_ooool2o`0004_ooooo0_l00012ooooo`;o00003oooool2o`0000kooooo0_l0000=ooooo`00
:Oooool00ol0003oooooooooo`05ooooo`;o00001oooool2o`0002;ooooo0_l0000gooooo`;o0000
8?ooool2o`0000cooooo0_l0000[ooooo`;o00002_ooool2o`0001oooooo0_l0000Vooooo`;o0000
3_ooool2o`0000gooooo000Yooooo`03o`000?oooooooooo00Gooooo0_l0000cooooo`;o0000;ooo
ool2o`00023ooooo0_l0000;ooooo`?o00003Oooool2o`0000Oooooo0_l0000Oooooo`;o00001?oo
ool2o`0001Wooooo1?l00002ooooo`;o000000?oooooo`000?l000006Oooool2o`0000Sooooo0_l0
000Gooooo`00:Oooool00ol0003oooooooooo`0Sooooo`;o00004oooool4o`0000Wooooo0_l0000J
ooooo`;o00009oooool2o`0000kooooo0_l0000>ooooo`;o00001oooool2o`0001cooooo0_l00003
ooooo`;o00000_ooool2o`0001_ooooo0_l00002ooooo`;o000000?oooooo`000?l000006Oooool2
o`0000Sooooo0_l0000Gooooo`00:Oooool00ol0003oooooooooo`04ooooo`;o00004?ooool2o`00
00_ooooo0_l0000Cooooo`;o00002oooool2o`0001[ooooo0_l0000Wooooo`;o0000=oooool2o`00
00cooooo0_l00003ooooo`;o0000>?ooool2o`0002[ooooo000Qoooooooo0000A?l00004ooooo`00
:Oooool3o`0000Wooooo00?o0000ooooooooool02?ooool3o`0000_ooooo1Ol00003ooooo`;o0000
0_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo0ol00009ooooo`;o0000
2_ooool00ol0003oooooooooo`05ooooo`;o00000_ooool01?l0003oooooo`000?l00007ooooo`?o
00000oooool2o`0000?ooooo0_l000000ooooooo0000ooooo`0:ooooo`03o`000?oooooooooo00Go
oooo0_l00002ooooo`03o`000?oooooooooo00Cooooo0_l00004ooooo`04o`000?oooooo0000o`00
00Sooooo00?o0000ooooooooool00_ooool2o`0000Gooooo00?o0000ooooooooool00oooool2o`00
00;ooooo0ol0000<ooooo`04o`000?ooooooooooooooo`?o00000_ooool2o`000003ooooool0003o
oooo00Cooooo0_l00004ooooo`04o`000?ooooooooooooooo`;o00001_ooool00ol0003ooooooooo
o`0:ooooo`04o`000?oooooo0000o`0000Sooooo00?o0000ooooooooool01_ooool2o`000003oooo
ool0003o000000;ooooo0_l00006ooooo`03o`000?oooooooooo00[ooooo000Yooooo`03o`000?oo
oooooooo01Cooooo0_l0000=ooooo`Co00000oooool2o`0000kooooo00?o0000ooooooooool01_oo
ool2o`0000kooooo0_l00003ooooo`Co00002oooool2o`0000Cooooo0_l00002ooooo`;o00000ooo
ool3o`0000Sooooo0_l0000Eooooo`;o00001oooool2o`0000Sooooo0_l00008ooooo`03o`000?oo
oooooooo00oooooo0_l00002ooooo`;o00004Oooool3o`00017ooooo00?o0000ooooooooool06?oo
ool2o`0000?ooooo0_l0000<ooooo`;o000000?oooooo`000?l000002_ooool00ol0003ooooooooo
o`0:ooooo`00:Oooool01?l0003oooooooooooooool2o`00043ooooo0_l00007ooooo`;o00002_oo
ool4o`0001Gooooo0_l00003ooooo`;o0000:Oooool2o`0003Sooooo0_l00003ooooo`;o00006_oo
ool2o`000003ooooool0003o0000017ooooo0_l00006ooooo`Co00007_ooool002Wooooo00Co0000
oooooooooooooooo0_l00019ooooo`;o00001_ooool2o`0000gooooo0_l0000Oooooo`;o00004Ooo
ool2o`0002Gooooo0_l0000Iooooo`Co00000oooool2o`0001[ooooo0_l000000ooooooo0000o`00
0008ooooo`;o00003oooool4o`0000cooooo0ol0000?ooooo`00:Oooool2o`0001[ooooo0_l0000i
ooooo`;o00003Oooool2o`0000?ooooo0_l0000Jooooo`;o00003?ooool2o`0000?ooooo0_l0000>
ooooo`;o000000?oooooo`000?l000003oooool2o`000003ooooool0003o000001Wooooo0_l0000R
ooooo`;o00001Oooool2o`0000?ooooo0_l0000Oooooo`?o00003oooool002Wooooo0_l0000Joooo
o`;o00009Oooool2o`0000gooooo0_l0000Gooooo`;o00009Oooool2o`000003ooooool0003o0000
00_ooooo0_l00006ooooo`;o000000?oooooo`000?l000003oooool2o`0000Cooooo0_l0000aoooo
o`;o00001?ooool5o`0000Gooooo0_l0000>ooooo`;o00003oooool2o`0001Gooooo000Yooooo`03
o`000?oooooooooo043ooooo0_l0000=ooooo`;o00008_ooool2o`0001[ooooo0_l00007ooooo`;o
00001Oooool2o`00023ooooo0_l0000=ooooo`;o00002_ooool2o`0001Kooooo0_l00004ooooo`Co
00002_ooool2o`0000[ooooo0_l0000?ooooo`;o00005Oooool002Wooooo00?o0000ooooooooool0
3?ooool2o`00027ooooo0_l00005ooooo`;o00004Oooool2o`0002Sooooo0_l0000Sooooo`Co0000
0oooool2o`0000cooooo0_l0000Aooooo`;o00003_ooool2o`0000[ooooo0_l0000Zooooo`;o0000
0oooool2o`0002gooooo000Yooooo`03o`000?oooooooooo00cooooo0_l00006ooooo`;o00005?oo
ool2o`0000?ooooo0_l00005ooooo`;o00001_ooool2o`0000Wooooo0_l00003ooooo`;o00003Ooo
ool2o`0001Sooooo0_l0000Kooooo`;o00001?ooool2o`0000?ooooo0_l0000<ooooo`Co00003ooo
ool2o`0001oooooo0_l0000Zooooo`;o00000oooool2o`0002Sooooo000Yooooo`Co00004oooool3
o`0001?ooooo0_l0000Booooo`;o000000?oooooo`000?l000002oooool2o`0000gooooo0_l00005
ooooo`;o00004Oooool2o`0000Cooooo0_l0000Eooooo`;o00006Oooool2o`0000Kooooo0ol0000;
ooooo`;o00003Oooool2o`0000_ooooo0_l0000_ooooo`;o0000:?ooool002Wooooo00Co0000oooo
ool0003o00002Oooool2o`0000Wooooo0_l0000Booooo`;o00005_ooool2o`0001Gooooo0_l0000:
ooooo`;o00005oooool2o`0001Kooooo0_l00009ooooo`;o00000oooool2o`00013ooooo0ol0000;
ooooo`;o00003Oooool2o`0001Sooooo0_l0000_ooooo`;o00006oooool002Wooooo00?o0000oooo
ooooool00_ooool2o`0000Kooooo0_l0000Iooooo`Ko00004_ooool2o`00017ooooo0ol00005oooo
o`;o00005_ooool2o`0002?ooooo0_l00009ooooo`Co000000?oooooo`000?l00000Aoooool2o`00
01Wooooo0_l0000=ooooo`;o00001Oooool2o`0000kooooo0_l0000;ooooo`00:Oooool00ol0003o
ooooooooo`02ooooo`;o00003?ooool2o`0001?ooooo1?l0000Dooooo`;o00004Oooool3o`0001go
oooo0_l0000`ooooo`;o0000=?ooool2o`0000cooooo0_l0000Qooooo`;o00002Oooool2o`0000;o
oooo0_l00004ooooo`;o00001_ooool2o`0000Gooooo1?l0000;ooooo`00:Oooool00ol0003ooooo
ooooo`08ooooo`;o00001_ooool2o`0000Kooooo0_l0000oooooo`;o0000;?ooool2o`0001Oooooo
0_l0000fooooo`;o00003?ooool2o`0002cooooo0_l00008ooooo`;o00001_ooool2o`000003oooo
ool0003o000000;ooooo0_l0000=ooooo`00:Oooool2o`0000?ooooo0_l00004ooooo`;o00000ooo
ool2o`0000;ooooo0_l00005ooooo`;o00009oooool2o`00017ooooo0_l00003ooooo`;o0000;?oo
ool2o`0001Oooooo0_l00015ooooo`;o00001_ooool2o`0002kooooo0_l00007ooooo`?o00004Ooo
ool002Wooooo00?o0000ooooooooool00_ooool2o`0000Kooooo0_l000000ooooooo0000o`000002
ooooo`;o00001Oooool2o`0001?ooooo0_l0000<ooooo`;o00001?ooool2o`00017ooooo0_l0000l
ooooo`;o0000Aoooool2o`0000[ooooo0_l00006ooooo`Co000000?oooooo`000?l00000:Oooool2
o`0000Oooooo0_l0000Booooo`00:Oooool00ol0003oooooooooo`0:ooooo`;o00005_ooool2o`00
00Wooooo0_l0000<ooooo`;o0000AOooool2o`0000kooooo0_l00017ooooo`;o00005?ooool2o`00
0003ooooool0003o000001oooooo0_l0000Uooooo`00:Oooool00ol0003oooooooooo`0Qooooo`?o
00002?ooool2o`0001Kooooo0_l00007ooooo`;o00004Oooool2o`0000;ooooo0_l00006ooooo`;o
00004Oooool5o`000003ooooool0003o000006cooooo0_l00009ooooo`;o00005Oooool2o`00017o
oooo0_l0000Booooo`00:Oooool00ol0003oooooooooo`0Qooooo`;o00002Oooool4o`0000kooooo
0_l00004ooooo`;o00001oooool2o`00017ooooo0_l00002ooooo`;o00001_ooool2o`00017ooooo
0ol00003ooooo`;o0000>_ooool2o`00033ooooo0_l00009ooooo`;o00000_ooool2o`0001Sooooo
0_l0000:ooooo`;o00004_ooool002Wooooo0_l0000_ooooo`;o00003_ooool2o`0002oooooo0_l0
001@ooooo`;o0000;oooool2o`0000kooooo0_l0000Hooooo`;o00007_ooool002Wooooo00?o0000
ooooooooool0:?ooool2o`0000Wooooo0_l0000jooooo`;o00005Oooool2o`0000_ooooo0_l0000Z
ooooo`;o00001oooool2o`0000?ooooo0_l0000=ooooo`;o00001oooool4o`0000;ooooo0_l00005
ooooo`;o00008oooool2o`0002?ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooooooo
o`02o`0000Gooooo0_l0000Cooooo`;o00000_ooool2o`0000Kooooo0_l00009ooooo`;o00001Ooo
ool2o`0001Wooooo0_l0000_ooooo`;o00002oooool2o`000003ooooool0003o000002Gooooo1?l0
0002ooooo`;o00000oooool2o`0000?ooooo0_l0000=ooooo`;o00001oooool4o`0000;ooooo0ol0
000Yooooo`;o00008oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`02o`0000Gooooo0_l0000Cooooo`;o00000_ooool2o`0001Sooooo0_l0000Iooooo`;o0000
?oooool2o`0002Gooooo0_l00004ooooo`;o00001Oooool2o`00023ooooo0_l0001>ooooo`001_oo
ool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo03gooooo0_l00015ooooo`;o0000:_ooool2o`0001Sooooo
0_l0001`ooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000?Oooool2o`0000oooooo0_l0000/ooooo`;o0000
1_ooool2o`0002[ooooo0_l0000nooooo`;o0000B_ooool000Kooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo04kooooo0_l0000<ooooo`;o00003?ooool2o`00013ooooo0_l0000[ooooo`;o
00006Oooool2o`0001cooooo0_l0000<ooooo`;o00004Oooool2o`0003Oooooo0006ooooo`05oa0@
4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool03?ooool2o`0004kooooo0_l0000<ooooo`;o0000??ooool3o`0000ko
oooo0_l00009ooooo`;o00002Oooool2o`00017ooooo0_l00005ooooo`;o00006?ooool2o`0003Oo
oooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<ooooo`;o00003?ooool2o`00
01Sooooo0_l0000Booooo`;o0000G_ooool2o`0000oooooo0_l000000ooooooo0000o`00000Aoooo
o`;o00004?ooool4o`0000Cooooo0_l0000/ooooo`;o00008oooool000Kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000
ooooooooool06_ooool2o`0001Sooooo0_l0000Booooo`;o0000Boooool2o`0002?ooooo1?l0000;
ooooo`;o00005_ooool4o`0002Kooooo0_l0000:ooooo`;o00008oooool002Wooooo0_l0000Moooo
o`;o0000HOooool2o`0000oooooo0_l00003ooooo`;o00008oooool2o`0000gooooo0_l00010oooo
o`;o0000;oooool002Wooooo00?o0000ooooooooool07?ooool2o`0000Wooooo0_l0000?ooooo`;o
00001_ooool2o`0000Oooooo0_l0000Qooooo`;o00004Oooool2o`0000oooooo0_l0001Kooooo`;o
0000COooool002Wooooo00?o0000ooooooooool03oooool2o`0000Cooooo0_l0000@ooooo`;o0000
3oooool2o`0000Kooooo0_l00007ooooo`;o00008Oooool2o`0000?ooooo0_l0000Vooooo`;o0000
8_ooool2o`0002kooooo0_l0001=ooooo`00:Oooool00ol0003oooooooooo`04ooooo`;o000000?o
ooooo`000?l000001?l00002ooooo`;o00001?ooool2o`0000Kooooo0_l0000<ooooo`;o00006Ooo
ool2o`0000_ooooo0_l00006ooooo`?o00004oooool2o`0002Kooooo0_l0000;ooooo`;o00005Ooo
ool2o`0001Kooooo0_l0001Uooooo`00:Oooool00ol0003oooooooooo`04ooooo`;o000000?ooooo
o`000?l000001?l0000@ooooo`;o00003?ooool2o`0001Wooooo0_l0000;ooooo`;o00001_ooool3
o`00013ooooo0_l0000]ooooo`;o00001oooool2o`0002gooooo0_l0001Uooooo`00:Oooool2o`00
04Oooooo0_l0000Gooooo`Co00000_ooool2o`0000Oooooo0_l0000Booooo`;o00006Oooool2o`00
09gooooo000Yooooo`03o`000?oooooooooo04Kooooo0_l0000Gooooo`Co00000_ooool2o`0001_o
oooo0_l0001Iooooo`;o0000GOooool002Wooooo00?o0000ooooooooool0G_ooool2o`0004_ooooo
0_l0000`ooooo`;o00002_ooool2o`00057ooooo000Yooooo`03o`000?oooooooooo01?ooooo0_l0
000;ooooo`;o00005oooool2o`0001Gooooo0_l0000<ooooo`;o00009Oooool2o`0002Cooooo0_l0
000looooo`;o0000@Oooool2o`0000kooooo000Yooooo`03o`000?oooooooooo01?ooooo0_l0000;
ooooo`;o00005oooool2o`0001Gooooo0_l0000cooooo`;o0000:_ooool3o`0007Sooooo0_l0000>
ooooo`00:Oooool2o`000;;ooooo1?l0000Qooooo`;o00003?ooool4o`0003?ooooo0_l0000Ooooo
o`00:Oooool00ol0003oooooooooo`2Gooooo`;o00006_ooool2o`00027ooooo0_l0000<ooooo`Co
0000<oooool2o`0001oooooo000Yooooo`03o`000?oooooooooo09Oooooo0_l0001Booooo`;o0000
;Oooool2o`00023ooooo000Yooooo`03o`000?oooooooooo07Gooooo0_l0001dooooo`;o0000;Ooo
ool2o`0000Cooooo0_l0000Jooooo`00:Oooool00ol0003oooooooooo`0Rooooo`;o0000DOooool2
o`0001[ooooo0_l0001booooo`;o00006Oooool2o`0001[ooooo000Yooooo`;o00008oooool2o`00
06gooooo0_l0000Sooooo`;o00002_ooool2o`00047ooooo0_l0000eooooo`00:Oooool00ol0003o
ooooooooo`1dooooo`;o0000@?ooool2o`0000[ooooo0_l0001hooooo`003_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`1dooooo`;o00005?ooool2o`0002Sooooo0_l0000kooooo`;o00001oooool2o`00
043ooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`17ooooo`;o0000:Oooool2o`0001Kooooo0_l00002oooo
o`;o00009?ooool2o`0003_ooooo0_l00007ooooo`;o00001?ooool2o`0003[ooooo000>ooooo`05
oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`?o0000Aoooool2o`00
013ooooo0_l0000Gooooo`;o00006_ooool2o`0002kooooo0_l00010ooooo`;o0000>_ooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0FOooool2o`0006?ooooo0_l0001looooo`003_ooool01Ol0003ooooooooooooooooo0000
00cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool0
00kooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0Eoooool2o`000>?ooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Oooooo0_l0003Sooooo`003_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0j?ooool2o`0001gooooo0_l0000cooooo`00:Oooool00ol0003ooooooooo
o`13ooooo`;o0000Xoooool2o`0001gooooo0_l0000Qooooo`;o00004?ooool002Wooooo0_l00014
ooooo`;o0000iOooool2o`00013ooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEE
EOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolmooooo`001_ooool01Ol0003o
oooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00000>oooo
o`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOo
oooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool001oooooo1?l000000ol@413oooooooooo`03ooooo`03
o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo0ol0003oooooocgooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool001oooooo00?oEEEEofIVI_l00000oooooom7ooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .38684 Mdot
.02762 .24661 Mdot
.02952 .28405 Mdot
.03143 .32374 Mdot
.03333 .27122 Mdot
.03524 .31822 Mdot
.03714 .29334 Mdot
.03905 .24717 Mdot
.04095 .42307 Mdot
.04286 .3375 Mdot
.04476 .32915 Mdot
.04667 .22559 Mdot
.04857 .38816 Mdot
.05048 .3454 Mdot
.05238 .2271 Mdot
.05429 .3021 Mdot
.05619 .3452 Mdot
.0581 .39447 Mdot
.06 .3487 Mdot
.0619 .24477 Mdot
.06381 .38733 Mdot
.06571 .25334 Mdot
.06762 .27215 Mdot
.06952 .40127 Mdot
.07143 .29464 Mdot
.07333 .37 Mdot
.07524 .28865 Mdot
.07714 .33366 Mdot
.07905 .23218 Mdot
.08095 .24676 Mdot
.08286 .39671 Mdot
.08476 .42046 Mdot
.08667 .31514 Mdot
.08857 .38042 Mdot
.09048 .33538 Mdot
.09238 .35194 Mdot
.09429 .38431 Mdot
.09619 .27656 Mdot
.0981 .23203 Mdot
.1 .23365 Mdot
.1019 .31616 Mdot
.10381 .36945 Mdot
.10571 .24443 Mdot
.10762 .36565 Mdot
.10952 .3961 Mdot
.11143 .30167 Mdot
.11333 .34955 Mdot
.11524 .43729 Mdot
.11714 .26933 Mdot
.11905 .24425 Mdot
.12095 .43767 Mdot
.12286 .28389 Mdot
.12476 .30699 Mdot
.12667 .29101 Mdot
.12857 .26103 Mdot
.13048 .38543 Mdot
.13238 .24345 Mdot
.13429 .34837 Mdot
.13619 .43083 Mdot
.1381 .39818 Mdot
.14 .31691 Mdot
.1419 .46273 Mdot
.14381 .23227 Mdot
.14571 .33584 Mdot
.14762 .34388 Mdot
.14952 .40246 Mdot
.15143 .32698 Mdot
.15333 .3284 Mdot
.15524 .29228 Mdot
.15714 .40862 Mdot
.15905 .37625 Mdot
.16095 .27924 Mdot
.16286 .33653 Mdot
.16476 .2862 Mdot
.16667 .23221 Mdot
.16857 .29561 Mdot
.17048 .30738 Mdot
.17238 .34309 Mdot
.17429 .25946 Mdot
.17619 .33174 Mdot
.1781 .4121 Mdot
.18 .25644 Mdot
.1819 .29376 Mdot
.18381 .36218 Mdot
.18571 .30963 Mdot
.18762 .27557 Mdot
.18952 .26141 Mdot
.19143 .25031 Mdot
.19333 .33073 Mdot
.19524 .3257 Mdot
.19714 .29718 Mdot
.19905 .31174 Mdot
.20095 .28623 Mdot
.20286 .2631 Mdot
.20476 .31294 Mdot
.20667 .33788 Mdot
.20857 .34788 Mdot
.21048 .43652 Mdot
.21238 .32831 Mdot
.21429 .34512 Mdot
.21619 .37435 Mdot
.2181 .29605 Mdot
.22 .22783 Mdot
.2219 .34904 Mdot
.22381 .4154 Mdot
.22571 .38038 Mdot
.22762 .37999 Mdot
.22952 .35925 Mdot
.23143 .28358 Mdot
.23333 .40795 Mdot
.23524 .35059 Mdot
.23714 .32316 Mdot
.23905 .42361 Mdot
.24095 .31379 Mdot
.24286 .47793 Mdot
.24476 .27176 Mdot
.24667 .33412 Mdot
.24857 .3741 Mdot
.25048 .39708 Mdot
.25238 .3622 Mdot
.25429 .38448 Mdot
.25619 .45303 Mdot
.2581 .34219 Mdot
.26 .23112 Mdot
.2619 .40923 Mdot
.26381 .33492 Mdot
.26571 .29367 Mdot
.26762 .38121 Mdot
.26952 .33053 Mdot
.27143 .32544 Mdot
.27333 .28169 Mdot
.27524 .35366 Mdot
.27714 .23345 Mdot
.27905 .33837 Mdot
.28095 .24757 Mdot
.28286 .24619 Mdot
.28476 .383 Mdot
.28667 .25067 Mdot
.28857 .33219 Mdot
.29048 .28821 Mdot
.29238 .22628 Mdot
.29429 .4596 Mdot
.29619 .26957 Mdot
.2981 .32435 Mdot
.3 .34728 Mdot
.3019 .27292 Mdot
.30381 .33767 Mdot
.30571 .49637 Mdot
.30762 .35596 Mdot
.30952 .25251 Mdot
.31143 .44936 Mdot
.31333 .28324 Mdot
.31524 .25584 Mdot
.31714 .40528 Mdot
.31905 .29176 Mdot
.32095 .3615 Mdot
.32286 .34857 Mdot
.32476 .24172 Mdot
.32667 .3802 Mdot
.32857 .38034 Mdot
.33048 .35745 Mdot
.33238 .34525 Mdot
.33429 .26587 Mdot
.33619 .33189 Mdot
.3381 .38585 Mdot
.34 .25415 Mdot
.3419 .38384 Mdot
.34381 .34838 Mdot
.34571 .41286 Mdot
.34762 .27961 Mdot
.34952 .36074 Mdot
.35143 .28825 Mdot
.35333 .28561 Mdot
.35524 .25465 Mdot
.35714 .26985 Mdot
.35905 .35806 Mdot
.36095 .3209 Mdot
.36286 .35362 Mdot
.36476 .3542 Mdot
.36667 .26526 Mdot
.36857 .23196 Mdot
.37048 .33268 Mdot
.37238 .25623 Mdot
.37429 .25846 Mdot
.37619 .33027 Mdot
.3781 .31126 Mdot
.38 .42826 Mdot
.3819 .38901 Mdot
.38381 .41951 Mdot
.38571 .31639 Mdot
.38762 .24269 Mdot
.38952 .43744 Mdot
.39143 .27125 Mdot
.39333 .32537 Mdot
.39524 .45606 Mdot
.39714 .28036 Mdot
.39905 .38367 Mdot
.40095 .22596 Mdot
.40286 .25176 Mdot
.40476 .23926 Mdot
.40667 .38091 Mdot
.40857 .29898 Mdot
.41048 .29186 Mdot
.41238 .27081 Mdot
.41429 .29279 Mdot
.41619 .22376 Mdot
.4181 .36973 Mdot
.42 .26384 Mdot
.4219 .33871 Mdot
.42381 .32655 Mdot
.42571 .26713 Mdot
.42762 .31695 Mdot
.42952 .34669 Mdot
.43143 .33825 Mdot
.43333 .41254 Mdot
.43524 .26223 Mdot
.43714 .3808 Mdot
.43905 .31894 Mdot
.44095 .33419 Mdot
.44286 .29779 Mdot
.44476 .39389 Mdot
.44667 .22644 Mdot
.44857 .32973 Mdot
.45048 .42911 Mdot
.45238 .41495 Mdot
.45429 .40686 Mdot
.45619 .29616 Mdot
.4581 .32604 Mdot
.46 .25482 Mdot
.4619 .28619 Mdot
.46381 .22646 Mdot
.46571 .45947 Mdot
.46762 .33102 Mdot
.46952 .30689 Mdot
.47143 .226 Mdot
.47333 .24633 Mdot
.47524 .28265 Mdot
.47714 .44424 Mdot
.47905 .2638 Mdot
.48095 .33198 Mdot
.48286 .35076 Mdot
.48476 .36073 Mdot
.48667 .46185 Mdot
.48857 .28125 Mdot
.49048 .39791 Mdot
.49238 .37575 Mdot
.49429 .41496 Mdot
.49619 .32681 Mdot
.4981 .32172 Mdot
.5 .26984 Mdot
.5019 .37427 Mdot
.50381 .23409 Mdot
.50571 .37099 Mdot
.50762 .26868 Mdot
.50952 .31955 Mdot
.51143 .33897 Mdot
.51333 .36957 Mdot
.51524 .25334 Mdot
.51714 .24144 Mdot
.51905 .2858 Mdot
.52095 .26288 Mdot
.52286 .43809 Mdot
.52476 .25273 Mdot
.52667 .28324 Mdot
.52857 .40056 Mdot
.53048 .3032 Mdot
.53238 .26674 Mdot
.53429 .39501 Mdot
.53619 .34898 Mdot
.5381 .26332 Mdot
.54 .32843 Mdot
.5419 .36279 Mdot
.54381 .32634 Mdot
.54571 .2478 Mdot
.54762 .33987 Mdot
.54952 .29328 Mdot
.55143 .34747 Mdot
.55333 .26671 Mdot
.55524 .34594 Mdot
.55714 .43623 Mdot
.55905 .31947 Mdot
.56095 .35721 Mdot
.56286 .23403 Mdot
.56476 .33071 Mdot
.56667 .25889 Mdot
.56857 .3772 Mdot
.57048 .23346 Mdot
.57238 .35985 Mdot
.57429 .31916 Mdot
.57619 .34353 Mdot
.5781 .33996 Mdot
.58 .26676 Mdot
.5819 .4137 Mdot
.58381 .39143 Mdot
.58571 .4236 Mdot
.58762 .23674 Mdot
.58952 .42032 Mdot
.59143 .26997 Mdot
.59333 .42376 Mdot
.59524 .44415 Mdot
.59714 .36523 Mdot
.59905 .23001 Mdot
.60095 .49432 Mdot
.60286 .30617 Mdot
.60476 .2564 Mdot
.60667 .34284 Mdot
.60857 .41691 Mdot
.61048 .29305 Mdot
.61238 .34831 Mdot
.61429 .43666 Mdot
.61619 .36747 Mdot
.6181 .32382 Mdot
.62 .33477 Mdot
.6219 .35751 Mdot
.62381 .37239 Mdot
.62571 .441 Mdot
.62762 .27866 Mdot
.62952 .39625 Mdot
.63143 .37883 Mdot
.63333 .32453 Mdot
.63524 .3149 Mdot
.63714 .26002 Mdot
.63905 .40414 Mdot
.64095 .44795 Mdot
.64286 .34157 Mdot
.64476 .34785 Mdot
.64667 .35642 Mdot
.64857 .24394 Mdot
.65048 .31367 Mdot
.65238 .30376 Mdot
.65429 .27658 Mdot
.65619 .37463 Mdot
.6581 .22653 Mdot
.66 .32469 Mdot
.6619 .31329 Mdot
.66381 .30665 Mdot
.66571 .32942 Mdot
.66762 .27028 Mdot
.66952 .25092 Mdot
.67143 .309 Mdot
.67333 .25263 Mdot
.67524 .34603 Mdot
.67714 .30728 Mdot
.67905 .27627 Mdot
.68095 .36846 Mdot
.68286 .28592 Mdot
.68476 .33584 Mdot
.68667 .35278 Mdot
.68857 .30306 Mdot
.69048 .26267 Mdot
.69238 .24112 Mdot
.69429 .25916 Mdot
.69619 .27554 Mdot
.6981 .46003 Mdot
.7 .22553 Mdot
.7019 .42573 Mdot
.70381 .33807 Mdot
.70571 .31782 Mdot
.70762 .3825 Mdot
.70952 .29473 Mdot
.71143 .24995 Mdot
.71333 .22581 Mdot
.71524 .43982 Mdot
.71714 .39386 Mdot
.71905 .23038 Mdot
.72095 .267 Mdot
.72286 .34027 Mdot
.72476 .27196 Mdot
.72667 .2553 Mdot
.72857 .22635 Mdot
.73048 .25391 Mdot
.73238 .27839 Mdot
.73429 .41257 Mdot
.73619 .36851 Mdot
.7381 .34852 Mdot
.74 .37919 Mdot
.7419 .43544 Mdot
.74381 .33578 Mdot
.74571 .40466 Mdot
.74762 .282 Mdot
.74952 .26047 Mdot
.75143 .41888 Mdot
.75333 .26765 Mdot
.75524 .2655 Mdot
.75714 .48972 Mdot
.75905 .37988 Mdot
.76095 .37502 Mdot
.76286 .30875 Mdot
.76476 .37775 Mdot
.76667 .32711 Mdot
.76857 .27278 Mdot
.77048 .26987 Mdot
.77238 .40985 Mdot
.77429 .30537 Mdot
.77619 .30123 Mdot
.7781 .36674 Mdot
.78 .26963 Mdot
.7819 .43515 Mdot
.78381 .41179 Mdot
.78571 .4523 Mdot
.78762 .26331 Mdot
.78952 .37638 Mdot
.79143 .24454 Mdot
.79333 .38155 Mdot
.79524 .35851 Mdot
.79714 .35141 Mdot
.79905 .31278 Mdot
.80095 .2317 Mdot
.80286 .22613 Mdot
.80476 .29263 Mdot
.80667 .26345 Mdot
.80857 .26028 Mdot
.81048 .259 Mdot
.81238 .41735 Mdot
.81429 .25934 Mdot
.81619 .38433 Mdot
.8181 .27465 Mdot
.82 .25703 Mdot
.8219 .31805 Mdot
.82381 .24929 Mdot
.82571 .37831 Mdot
.82762 .25649 Mdot
.82952 .26956 Mdot
.83143 .45111 Mdot
.83333 .29015 Mdot
.83524 .30375 Mdot
.83714 .32158 Mdot
.83905 .37988 Mdot
.84095 .37555 Mdot
.84286 .36677 Mdot
.84476 .26216 Mdot
.84667 .38813 Mdot
.84857 .29777 Mdot
.85048 .32351 Mdot
.85238 .44928 Mdot
.85429 .35176 Mdot
.85619 .29329 Mdot
.8581 .41844 Mdot
.86 .22762 Mdot
.8619 .32568 Mdot
.86381 .24327 Mdot
.86571 .28394 Mdot
.86762 .26044 Mdot
.86952 .32178 Mdot
.87143 .35543 Mdot
.87333 .40088 Mdot
.87524 .34441 Mdot
.87714 .26863 Mdot
.87905 .2891 Mdot
.88095 .32654 Mdot
.88286 .36973 Mdot
.88476 .32473 Mdot
.88667 .2715 Mdot
.88857 .28225 Mdot
.89048 .24751 Mdot
.89238 .30118 Mdot
.89429 .24958 Mdot
.89619 .26913 Mdot
.8981 .3971 Mdot
.9 .31021 Mdot
.9019 .41178 Mdot
.90381 .37006 Mdot
.90571 .37453 Mdot
.90762 .31085 Mdot
.90952 .22549 Mdot
.91143 .37319 Mdot
.91333 .34887 Mdot
.91524 .42507 Mdot
.91714 .36518 Mdot
.91905 .31705 Mdot
.92095 .26478 Mdot
.92286 .37197 Mdot
.92476 .35274 Mdot
.92667 .27977 Mdot
.92857 .38095 Mdot
.93048 .46522 Mdot
.93238 .24263 Mdot
.93429 .29817 Mdot
.93619 .25913 Mdot
.9381 .32303 Mdot
.94 .27122 Mdot
.9419 .34027 Mdot
.94381 .29575 Mdot
.94571 .24698 Mdot
.94762 .2683 Mdot
.94952 .36872 Mdot
.95143 .40067 Mdot
.95333 .27405 Mdot
.95524 .39648 Mdot
.95714 .31866 Mdot
.95905 .32429 Mdot
.96095 .30617 Mdot
.96286 .4751 Mdot
.96476 .31121 Mdot
.96667 .24873 Mdot
.96857 .42647 Mdot
.97048 .38027 Mdot
.97238 .30537 Mdot
.97429 .24 Mdot
.97619 .23836 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo07[ooooo0_l00030ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo00Cooooo0ol0000dooooo`;o00005_ooool2o`00027ooooo0_l00002ooooo`;o00002?oo
ool2o`0000Cooooo1?l0000jooooo`;o00003?ooool2o`0000;ooooo0_l00003ooooo`;o00005_oo
ool2o`00013ooooo0_l0000>ooooo`;o00008Oooool000Co00000_ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo0ol0000dooooo`;o00005_ooool2o`00027ooooo0_l0000<ooooo`;o00001?oo
ool4o`0002Oooooo0_l0000Aooooo`;o00003?ooool2o`0000;ooooo1?l000000ooooooo0000o`00
000Fooooo`;o00004?ooool2o`0000kooooo0_l0000Qooooo`001_ooool01Ol0003ooooooooooooo
oooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o00003_oo
ool2o`0000Cooooo0ol0000<ooooo`;o00001Oooool2o`0001cooooo0_l00004ooooo`;o00006ooo
ool2o`0002[ooooo0_l0000Aooooo`Co00001oooool2o`0002Gooooo0_l0000Hooooo`;o0000A?oo
ool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00kooooo0_l00004ooooo`?o0000
3?ooool2o`0000Gooooo0_l0000Looooo`;o00001?ooool2o`0001_ooooo0_l0000Zooooo`;o0000
4Oooool4o`0000Cooooo0_l00012ooooo`;o0000A?ooool000Kooooo00Go410@oooooooooooooooo
oa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`1gooooo`;o0000>Oooool2o`0007[ooooo0ol0000;ooooo`001_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool07oooool2o`0003cooooo0_l0000Booooo`;o00001?ooool2o`0002;o
oooo0_l0000fooooo`;o0000=Oooool2o`0001Cooooo0_l0000<ooooo`?o00002oooool000Kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`00
00Kooooo0_l0000:ooooo`;o00003?ooool2o`0000;ooooo0_l00002ooooo`;o0000;oooool2o`00
00_ooooo0_l0000Booooo`;o00006_ooool2o`0000cooooo0_l0000Xooooo`;o00003?ooool2o`00
01kooooo0_l0000Eooooo`;o00005?ooool2o`0001[ooooo000Yooooo`;o00000_ooool2o`0000Ko
oooo0_l00004ooooo`;o00001_ooool2o`0000;ooooo0_l0000booooo`?o0000>oooool2o`0001Go
oooo0_l0000Oooooo`;o0000;?ooool2o`0000Wooooo0_l0000Cooooo`?o00003oooool2o`0000Co
oooo0_l0000?ooooo`00:Oooool01?l0003oooooooooooooool2o`0000cooooo0_l0000Qooooo`;o
00006oooool4o`0000Gooooo0_l0000Looooo`;o00009Oooool2o`0000Gooooo0_l0000Vooooo`?o
00002_ooool2o`0002?ooooo0_l0000Cooooo`?o00003oooool2o`0000Cooooo0_l0000?ooooo`00
:Oooool00ol0003oooooooooo`0:ooooo`;o00009_ooool2o`0001gooooo0_l00005ooooo`Co0000
1_ooool2o`0000?ooooo0_l0000=ooooo`;o00004Oooool2o`0000oooooo0_l000000ooooooo0000
o`00000]ooooo`?o00002_ooool2o`0000?ooooo0ol0001Kooooo`00:Oooool00ol0003ooooooooo
o`0:ooooo`;o00008_ooool2o`0002[ooooo0_l00006ooooo`;o00000oooool2o`0000?ooooo0ol0
000Jooooo`;o00003oooool2o`0000oooooo0_l0000:ooooo`;o00009Oooool3o`0001Sooooo0_l0
00001?oooooo0000o`000?ooool2o`0003_ooooo000Yooooo`03o`000?oooooooooo01kooooo0_l0
000=ooooo`?o00000_ooool2o`0003Sooooo0ol0000looooo`;o00002_ooool2o`0000Sooooo0_l0
000Aooooo`;o00004?ooool2o`00017ooooo1Ol000000ooooooo0000o`000003ooooo`;o00001_oo
ool2o`0001Cooooo0_l0000Hooooo`00:Oooool2o`0001oooooo0_l0000=ooooo`;o00000oooool2
o`0000;ooooo0_l0000cooooo`;o00003oooool2o`0000?ooooo0_l0000<ooooo`;o00002oooool2
o`0000Cooooo0_l0000Mooooo`;o00004?ooool3o`00013ooooo0_l0000:ooooo`;o00001?ooool4
o`0000Sooooo0_l00006ooooo`;o00003oooool2o`0000?ooooo0_l0000Hooooo`00:Oooool00ol0
003oooooooooo`0fooooo`;o0000:?ooool2o`0000Wooooo0_l0000?ooooo`?o00000_ooool2o`00
00cooooo0_l0000;ooooo`;o00000_ooool4o`0000?ooooo0_l00006ooooo`;o00008_ooool2o`00
00Oooooo0_l00009ooooo`;o00002Oooool2o`0000Cooooo0_l0000Sooooo`;o00001_ooool2o`00
01Gooooo000Yooooo`04o`000?oooooo0000o`0001Wooooo0_l0000Dooooo`Co000000So410@oooo
ooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0@ooooo`;o
00002_ooool2o`0000Gooooo0_l00004ooooo`Oo000000Goooooonk^k_lb<S;o0000oc8b<P02o`00
00;ooooo0ol000000olb<S;ok^k^ooooo`0Booooo`;o000000?oooooo`000?l000001_ooool2o`00
00Gooooo0_l000001_ooooooV9RHoa0@4?l0003o<S8bolc<c0;o000000Koooooonk^k_l0003o0000
oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool2o`0000oooooo0_l00009oooo
o`Co000000Co410@o`000?l0003ooooo0ol000000olb<S;ok^k^ooooo`02ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool2o`0000kooooo0_l000001?oooooo0000o`000?ooool2o`0000cooooo
1Ol000002Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool002Wooooo00Co0000ooooool0003o00002Oooool2o`0000kooooo0_l0
000Fooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`04ogMg
MonHV9SooooooiRHV0;o00003oooool4o`0000oooooo0_l00004ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@00_l000001OooooooMgMgoiRHV?ooooooV9RH00;o00000_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg01?ooooo0_l000000ooooooo0000o`00000@ooooo`05oa0@4?nj^[[oooooogMgMolb<S80
0oooool01OmgMgOo0000o`000?nHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`;o00004Oooool2o`0000[ooooo00Go0000ooooool0003o0000ooooo`02o`000003oooooonHV9So
MgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`;o00003_ooool2o`000004ooooool0
003o0000ooooo`;o00003?ooool2o`0000;ooooo0_l000002?lb<S;ooooooooooomgMgOoV9RHoooo
oonHV9SoMgMg0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000Yooooo`03o`000?oooooo
oooo00[ooooo0_l00008ooooo`;o00006oooool2o`0000Cooooo00Go410@oooooooooooooooooa0@
4003ooooo`04oa0@4?ooooooooooooooo`;o00004Oooool2o`0001Kooooo00?oV9RHob4Q8Oo^k^h0
1?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@400/oooo
o`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o
410@ooooooooool01_ooool2o`0000Kooooo0_l00003ooooo`;o00002?ooool2o`0000Oooooo1ol0
00000ooooooo410@ooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413o0000
o`00000Yooooo`?o00000_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooooooooa0@4003ooooo`00:Oooool2o`0001Gooooo0_l0000Booooo`;o00001oooool2o`0000Co
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000008?ooool2
o`0000Wooooo00?oV9RHob4Q8Oo^k^h00_ooool2o`0000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo02Wooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Co0000oooooooooooooooo0_l00007ooooo`;o00001_ooool2o`0000?o
oooo0_l0000:ooooo`;o00001Oooool01?m4A4CogMgMooooool00004ooooo`05o`000?oooooooooo
ooooool000000oooool01?l0003oooooooooooooool3o`00027ooooo0_l00007ooooo`05ogMgMolb
<S;oooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool00Oooool002Wooooo00?o0000ooooooooool07?ooool2o`0000[ooooo0_l00008ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`;o00000_ooool00ol0003o
ooooooooo`07ooooo`;o00002_ooool2o`0000Wooooo0_l0000:ooooo`04ogMgMomVIVKooooooooo
o`;o00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool02Oooool2
o`0000?ooooo0_l0000:ooooo`;o00003?ooool00ol@413o0000okZj^P03ooooo`05o`000?oooooo
ooooooooool000000oooool01?l0003oooooooooooooool2o`00023ooooo0_l00003ooooo`;o0000
00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`00000?ooooo`;o00001Oooool2o`0000_ooooo0_l00004ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`00:Oooool3o`0001cooooo0_l0000<ooooo`;o00001_ooool00ol0003ooooo
ooooo`02o`000005oa0@4?ooooooooooooooool@41000oooool2o`0000;ooooo00?o410@oooooooo
ool01oooool2o`0000[ooooo0_l0000;ooooo`;o00002Oooool01Ol0003ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Gooooo0_l00002
ooooo`;o00000oooool2o`0000Sooooo1?l0000=ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@
oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41004Oooool2o`0001?ooooo
0_l000001?ooooooMgMgolc<c?l00004ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@00oooooo0_l00005ooooo`;o00004Oooool00ol0003oooooooooo`04
ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo
000Yooooo`?o00003Oooool2o`0001_ooooo0_l00006ooooo`03o`000?oooooooooo00;o000000Go
MgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool2o`0001;o
oooo0_l00005ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`;o00004Oooool2o`0000cooooo00Go
410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg017ooooo0_l0000Fooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0000cooooo0_l0
000Dooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool002Wooooo00?o0000ooooooooool03Oooool2o`0000kooooo
0_l00008ooooo`;o00001oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo0_l00007ooooo`;o00002Oooool2o`00
00Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`04onk^k_lb<S;o0000oc8b<P?o000000Ko
ooooonk^k_lb<S;o0000oc8b<_o^k^hXooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00;ooooo0_l000001?lb<S;o0000oc8b<_o^k^hZooooo`03ogMgMol0
003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`?o000000?o<S8bonk^k_ooool0
1?ooool2o`0000cooooo0_l0000Dooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool2o`0000;ooooo0_l00009ooooo`;o
00003oooool2o`0000Sooooo0_l00002ooooo`;o00000_ooool2o`0000[ooooo0_l0000=ooooo`;o
00003oooool2o`0001cooooo0ol0000;ooooo`;o00007?ooool2o`0001;ooooo0_l0000Nooooo`;o
00007?ooool2o`0000oooooo0_l0000Jooooo`;o00005_ooool002Wooooo00Co0000oooooooooooo
oooo0_l00009ooooo`;o00007Oooool2o`0000;ooooo0_l00003ooooo`;o00001Oooool2o`0000go
oooo0_l0000/ooooo`;o00002Oooool2o`0000;ooooo0_l0000Looooo`;o0000<_ooool2o`0002[o
oooo0_l000000ooooooo0000o`00000Gooooo`;o000000?oooooo`000?l000005_ooool002Wooooo
00?o0000ooooooooool01_ooool2o`00013ooooo0_l0000Jooooo`;o0000@_ooool2o`0000Wooooo
0_l0001Yooooo`;o00005Oooool2o`0000gooooo0_l0000;ooooo`;o00006Oooool002Wooooo00?o
0000ooooooooool01_ooool2o`00013ooooo0_l00025ooooo`;o00009Oooool2o`0000[ooooo0_l0
000Jooooo`;o00004Oooool2o`00017ooooo0_l0000Gooooo`;o00003Oooool002Wooooo00?o0000
ooooooooool07Oooool2o`0000cooooo0_l0001Oooooo`;o00004Oooool2o`0001Gooooo0_l0000>
ooooo`;o00000_ooool2o`0000;ooooo0_l00002ooooo`;o00005_ooool2o`0000;ooooo0_l0000A
ooooo`;o00009oooool2o`000003ooooool0003o000000gooooo000Qoooooooo0000A?l00004oooo
o`00:Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`04o`000?oooooo0000o`0000?ooooo0ol00002oooo
o`03o`000?oooooooooo00Gooooo0_l00003ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;o00002?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool2o`00
00?ooooo0_l000000ooooooo0000o`000002ooooo`;o00002oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00Co0000oooooooooooooooo0_l00006ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02?ooool4o`0000Wooooo00?o0000ooooooooool01Oooool2
o`0000;ooooo00?o0000ooooooooool02_ooool002Wooooo00?o0000ooooooooool04?ooool2o`00
00?ooooo0_l0000;ooooo`;o00004_ooool2o`0000;ooooo00?o0000ooooooooool01Oooool2o`00
02gooooo0_l00005ooooo`03o`000?oooooooooo00?ooooo0_l0000eooooo`03o`000?oooooooooo
00Wooooo0_l00003ooooo`;o000000?oooooo`000?l000003Oooool2o`0001Sooooo00Co0000oooo
oooooooooooo0_l00005ooooo`;o00007Oooool2o`00017ooooo00?o0000ooooooooool02_ooool0
02Wooooo00?o0000ooooooooool00_l0000>ooooo`;o00000oooool2o`0000_ooooo0_l00015oooo
o`;o00001_ooool2o`0000_ooooo0_l00002ooooo`;o00005?ooool2o`0000kooooo0_l00003oooo
o`;o0000:Oooool2o`0002?ooooo0_l0000Mooooo`;o00002_ooool2o`0001;ooooo000Yooooo`03
o`000?oooooo000000;o0000?oooool2o`00017ooooo0_l0000Cooooo`;o00005oooool2o`00017o
oooo0_l000000ooooooo0000o`00000>ooooo`;o00000oooool2o`0000cooooo0_l00015ooooo`;o
00000_ooool2o`0000Cooooo0_l0000Dooooo`;o00001?ooool3o`00017ooooo000Yooooo`Co0000
9?ooool2o`0000cooooo0_l0000<ooooo`;o00002Oooool2o`0000Kooooo0_l0000Mooooo`;o0000
2?ooool2o`0000Wooooo0_l0000:ooooo`?o00003?ooool2o`0001Kooooo0_l00003ooooo`;o0000
1oooool2o`00023ooooo0_l0000Eooooo`;o00000_ooool2o`0000;ooooo1?l00002ooooo`?o0000
3oooool2o`0000Gooooo0_l0000Aooooo`00:Oooool00ol0003oooooooooo`03ooooo`;o00008?oo
ool3o`0000_ooooo0_l00004ooooo`;o00004?ooool3o`00023ooooo0_l00003ooooo`;o00002?oo
ool2o`0000Kooooo0_l000000ooooooo0000o`00000:ooooo`;o00003?ooool3o`0001_ooooo0_l0
0007ooooo`Co00007_ooool2o`0001gooooo0_l00004ooooo`?o0000:Oooool002Wooooo00?o0000
ooooooooool00oooool2o`0000Sooooo0_l0000Gooooo`;o00001Oooool2o`0000Cooooo0_l00004
ooooo`;o00004?ooool2o`0000Cooooo0_l0000>ooooo`;o00002Oooool4o`0001Gooooo0_l00004
ooooo`;o00000_ooool2o`00017ooooo0_l00006ooooo`;o00007oooool2o`0006oooooo000Yoooo
o`03o`000?oooooooooo00gooooo0_l00003ooooo`;o00003oooool2o`0000Cooooo0_l00002oooo
o`;o00001?ooool2o`0000oooooo0_l00003ooooo`;o00001_ooool2o`0000kooooo0_l00009oooo
o`;o00005?ooool2o`0000Oooooo0_l00002ooooo`;o00006Oooool2o`00013ooooo0_l0000Coooo
o`;o00004Oooool2o`0005Kooooo000Yooooo`03o`000?oooooooooo00;ooooo0_l0000>ooooo`;o
00003oooool2o`0000Cooooo0_l0000<ooooo`;o00002oooool2o`0000?ooooo0_l00003ooooo`;o
00001_ooool2o`0002Cooooo0_l000001?oooooo0000o`000?ooool2o`0001Gooooo0_l0000:oooo
o`;o00005Oooool2o`0001?ooooo0_l00004ooooo`;o00002oooool2o`0005Kooooo000Yooooo`;o
00000oooool2o`0003?ooooo0_l0000?ooooo`;o00001?ooool2o`0000Kooooo0_l0000Tooooo`;o
000000?oooooo`000?l000006?ooool2o`0000[ooooo0_l00007ooooo`;o00002?ooool2o`0000Wo
oooo0_l0000Booooo`;o00001?ooool2o`0004Cooooo0_l0000Gooooo`00:Oooool00ol0003ooooo
ooooo`05ooooo`Co00006oooool2o`0000Kooooo0_l0000<ooooo`;o00003?ooool2o`0001Gooooo
0_l00016ooooo`;o00001Oooool2o`0000Sooooo0_l00009ooooo`;o00002Oooool2o`0000gooooo
0_l0000_ooooo`;o00004oooool2o`0001Oooooo000Yooooo`03o`000?oooooooooo00Gooooo1Ol0
000Fooooo`;o00000_ooool2o`0000Kooooo0_l0000:ooooo`Ko00005oooool2o`0000Gooooo0_l0
00000ooooooo0000o`000002ooooo`;o00006_ooool2o`00023ooooo0_l00003ooooo`?o00001Ooo
ool2o`0000[ooooo0_l00008ooooo`;o00002?ooool2o`0001;ooooo0_l0000Zooooo`;o00002_oo
ool2o`00023ooooo000Yooooo`03o`000?oooooooooo00Sooooo0_l00008ooooo`;o00001Oooool2
o`0000Gooooo0_l0000Fooooo`;o00000_ooool2o`0000;ooooo0_l0000Cooooo`;o00001Oooool2
o`0000Gooooo0_l0000Jooooo`;o00003oooool2o`0000oooooo0_l00003ooooo`;o00004_ooool2
o`0000Sooooo0_l0000Looooo`;o00004Oooool2o`00013ooooo0_l0000Aooooo`;o00008?ooool0
02Wooooo00?o0000ooooooooool04_ooool2o`0000Gooooo0_l0000Uooooo`;o00002oooool2o`00
01[ooooo0ol0000Tooooo`;o0000?oooool2o`0002;ooooo0_l0000@ooooo`;o00001?ooool2o`00
00oooooo0_l0000Looooo`00:Oooool2o`0004kooooo0_l00009ooooo`;o00001Oooool2o`0000Oo
oooo1?l0000mooooo`;o00004_ooool2o`0000Kooooo0_l0000:ooooo`;o00008Oooool2o`0001Oo
oooo0_l0000?ooooo`;o00007?ooool002Wooooo00?o0000ooooooooool0?_ooool2o`0001Sooooo
0_l00002ooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000002Kooooo
0_l0000Gooooo`;o00000_ooool2o`0000kooooo0_l00006ooooo`;o0000;Oooool2o`0004Kooooo
000Yooooo`03o`000?oooooooooo033ooooo0_l0000<ooooo`;o00001_ooool2o`0001Cooooo0_l0
0007ooooo`;o0000:Oooool2o`00017ooooo0_l00008ooooo`;o0000SOooool002Wooooo00?o0000
ooooooooool05oooool2o`0001Oooooo0_l0000Dooooo`;o0000Foooool2o`00013ooooo0_l00004
ooooo`;o0000<_ooool2o`0001?ooooo0_l0000Fooooo`;o00007_ooool002Wooooo00?o0000oooo
ooooool03?ooool2o`0000Sooooo0ol0001Rooooo`;o00006_ooool2o`000003ooooool0003o0000
01Wooooo0_l00004ooooo`;o00004oooool2o`0000oooooo0_l0000<ooooo`;o00004oooool2o`00
00[ooooo0_l00005ooooo`;o00000oooool2o`0000Sooooo0_l0000Dooooo`00:Oooool2o`0000go
oooo0_l00008ooooo`;o0000;Oooool2o`0003Cooooo0_l0000Jooooo`;o000000?oooooo`000?l0
00008Oooool2o`00017ooooo0_l0000?ooooo`;o0000;Oooool2o`0000Gooooo0_l000001?oooooo
0000o`000?ooool2o`0000Oooooo0_l0000Dooooo`00:Oooool00ol0003oooooooooo`0Xooooo`;o
00004?ooool2o`0000Wooooo0_l0001<ooooo`;o000000?oooooo`000?l000004oooool2o`00013o
oooo0_l00009ooooo`;o00007oooool2o`0000Oooooo0_l0000?ooooo`;o00004oooool4o`000003
ooooool0003o000001gooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Xoooo
o`;o00004?ooool2o`0000;ooooo0_l0000Nooooo`;o0000<oooool2o`000003ooooool0003o0000
01?ooooo0_l0000Cooooo`;o00001_ooool2o`0001Wooooo0_l00004ooooo`Co00001Oooool2o`00
00[ooooo0_l00002ooooo`?o00004oooool2o`0001?ooooo0_l0000=ooooo`001_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo017ooooo0_l0000Zooooo`?o00002oooool2
o`0000?ooooo0_l0000<ooooo`;o00005oooool2o`0000Sooooo0_l0000mooooo`;o00005_ooool2
o`0000Wooooo0_l00004ooooo`Co00001oooool2o`0000Sooooo0_l00002ooooo`;o00006oooool2
o`0000cooooo0_l0000=ooooo`001_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RH
ob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo1?l0000:
ooooo`;o00007?ooool2o`0000Oooooo0_l00003ooooo`;o00000oooool2o`0000oooooo1?l0000@
ooooo`Co00002?ooool2o`0005Gooooo0_l0000Jooooo`;o00001Oooool2o`0002;ooooo0_l0000K
ooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool0
0omgMgOo<S8booooo`04ooooo`?o00001?ooool2o`0000?ooooo0_l00008ooooo`;o00002_ooool2
o`0002Gooooo0_l0000Iooooo`Co00002_ooool2o`0000Cooooo0_l00024ooooo`;o00002?ooool2
o`0003Gooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool2o`0000Gooooo0_l00003ooooo`;o0000I?oo
ool2o`0003oooooo0_l0001Cooooo`;o0000=Oooool000Kooooo00Go410@oooooooooooooooooa0@
400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`;o0000Noooool2o`0001[ooooo0_l0000>ooooo`;o0000:Oooool2o`0005oooooo0006
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`;o00001_ooool2o`0000Oooooo
0_l00007ooooo`;o00008_ooool2o`0003gooooo0_l0000<ooooo`;o00003?ooool2o`0001gooooo
0_l0000Jooooo`;o0000>?ooool2o`00017ooooo0_l0000Booooo`001_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003o
ooooooooo`0;ooooo`;o00000_ooool2o`0000Oooooo0_l00007ooooo`;o00008_ooool2o`0004_o
oooo0_l0000;ooooo`;o00007_ooool2o`0004cooooo0_l00006ooooo`;o00004?ooool3o`0001;o
oooo000Yooooo`;o00003?ooool2o`0001Sooooo0_l0001hooooo`;o00008Oooool2o`00023ooooo
0_l0000Wooooo`;o00006?ooool2o`0001?ooooo000Yooooo`03o`000?oooooooooo02Gooooo0_l0
000Iooooo`;o00006Oooool2o`0002[ooooo0_l0000iooooo`;o00008?ooool2o`0005Kooooo000Y
ooooo`03o`000?oooooooooo02Oooooo0_l0000Gooooo`;o00001oooool2o`00013ooooo0_l0000Z
ooooo`;o0000I?ooool2o`0004gooooo000Yooooo`03o`000?oooooooooo02Oooooo0_l00005oooo
o`;o00006Oooool2o`0001Wooooo0_l0000Jooooo`;o0000;_ooool2o`0002oooooo0_l0000:oooo
o`;o00000_ooool2o`0002Cooooo0_l0000Sooooo`00:Oooool00ol0003oooooooooo`0^ooooo`;o
00003Oooool2o`0002Gooooo0_l0000Jooooo`;o00001?ooool2o`0000cooooo0_l0000Jooooo`;o
00001_ooool2o`0002Oooooo0_l0000>ooooo`;o00001oooool2o`0001_ooooo0_l0000Sooooo`00
:Oooool2o`00017ooooo0_l0000[ooooo`;o0000<Oooool2o`0001Cooooo0_l0000<ooooo`;o0000
7?ooool2o`0000Cooooo0_l0000/ooooo`;o00004_ooool2o`0000gooooo0_l0000aooooo`00:Ooo
ool00ol0003oooooooooo`02ooooo`;o00003?ooool2o`0002oooooo0_l0000]ooooo`;o0000?ooo
ool4o`00037ooooo0_l0000Qooooo`;o0000<Oooool002Wooooo00?o0000ooooooooool00_ooool2
o`0003gooooo0_l0001^ooooo`Co00008Oooool2o`0004?ooooo0_l0000?ooooo`;o00003_ooool0
02Wooooo00?o0000ooooooooool0Koooool2o`0001Cooooo0_l0001?ooooo`;o0000@oooool2o`00
00oooooo0_l0000>ooooo`00:Oooool00ol0003oooooooooo`0Pooooo`;o0000COooool2o`0001Co
oooo0_l0002eooooo`00:Oooool2o`00027ooooo0_l00026ooooo`;o0000>Oooool2o`0000_ooooo
0_l0001:ooooo`00:Oooool00ol0003oooooooooo`0Jooooo`Co00006_ooool2o`0003Sooooo0_l0
000Yooooo`;o00002Oooool2o`00013ooooo0_l0000Wooooo`;o00002oooool2o`0004[ooooo000Y
ooooo`03o`000?oooooooooo01[ooooo1?l0000Jooooo`;o0000>?ooool2o`0002Wooooo0_l0000K
ooooo`;o00000_ooool2o`0001_ooooo0_l0001Oooooo`00:Oooool00ol0003oooooooooo`2>oooo
o`;o00009?ooool2o`0000Sooooo0_l0000Kooooo`;o0000Goooool002Wooooo00?o0000oooooooo
ool0S_ooool2o`0002Cooooo0_l0000=ooooo`;o0000Moooool002Wooooo0_l0001Jooooo`;o0000
J?ooool2o`0003_ooooo0_l00005ooooo`;o0000<oooool002Wooooo00?o0000ooooooooool0Aooo
ool2o`00013ooooo0_l0002Fooooo`;o00003Oooool2o`0000Gooooo0_l0000cooooo`003_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1Oooool00ol0003oooooooooo`17ooooo`;o0000:oooool2o`0007_ooooo0_l00019ooooo`003_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0Doooool2o`0001oooooo0_l0000Dooooo`;o0000BOooool2o`0006Gooooo
000>ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`?o0000
8_ooool2o`0002oooooo0_l0000eooooo`;o00001Oooool2o`0004;ooooo0_l0001Uooooo`003_oo
ool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`0Rooooo`;o0000KOooool2o`0008gooooo0_l0000Jooooo`003_ooool01Ol0003ooooooooo
oooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oo
oooo8Oooool2o`0001[ooooo000>ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0ooooool[ooooo`;o
00004?ooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`0004Co
oooo0_l0003Uooooo`;o00004?ooool002Wooooo00?o0000ooooooooool0@oooool2o`000?Oooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3Xooooo`;o0000D_ooool002Wooooo0_l0002gooooo`;o
0000<?ooool2o`0005;ooooo000Yooooo`03o`000?oooooooooo05Oooooo0_l0001Mooooo`;o0000
Q?ooool002Wooooo00?o0000ooooooooool0Eoooool2o`000>?ooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oo
oooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@4100
3Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo
0006ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooo
oooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00ko
oooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooo
oolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003ooooo
ockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003ooooo
ockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`007oooool4o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool3o`00
0?oooooo?Oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`007oooool00omEEEGoIVIVo`00003oooooodOooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .39695 Mdot
.02762 .33626 Mdot
.02952 .27979 Mdot
.03143 .26878 Mdot
.03333 .33948 Mdot
.03524 .24229 Mdot
.03714 .27021 Mdot
.03905 .3576 Mdot
.04095 .4385 Mdot
.04286 .28155 Mdot
.04476 .35147 Mdot
.04667 .31041 Mdot
.04857 .31303 Mdot
.05048 .34564 Mdot
.05238 .31817 Mdot
.05429 .34212 Mdot
.05619 .26823 Mdot
.0581 .32543 Mdot
.06 .29351 Mdot
.0619 .3443 Mdot
.06381 .31309 Mdot
.06571 .26266 Mdot
.06762 .24671 Mdot
.06952 .34056 Mdot
.07143 .22667 Mdot
.07333 .35653 Mdot
.07524 .34269 Mdot
.07714 .26842 Mdot
.07905 .31735 Mdot
.08095 .33593 Mdot
.08286 .33408 Mdot
.08476 .44063 Mdot
.08667 .4045 Mdot
.08857 .35286 Mdot
.09048 .38122 Mdot
.09238 .40896 Mdot
.09429 .29112 Mdot
.09619 .26116 Mdot
.0981 .30028 Mdot
.1 .27403 Mdot
.1019 .22515 Mdot
.10381 .38205 Mdot
.10571 .32062 Mdot
.10762 .4009 Mdot
.10952 .38907 Mdot
.11143 .24854 Mdot
.11333 .32456 Mdot
.11524 .42734 Mdot
.11714 .34435 Mdot
.11905 .3425 Mdot
.12095 .42246 Mdot
.12286 .23502 Mdot
.12476 .21864 Mdot
.12667 .36313 Mdot
.12857 .34407 Mdot
.13048 .43591 Mdot
.13238 .35319 Mdot
.13429 .27207 Mdot
.13619 .38311 Mdot
.1381 .38025 Mdot
.14 .25088 Mdot
.1419 .42884 Mdot
.14381 .29978 Mdot
.14571 .31952 Mdot
.14762 .41821 Mdot
.14952 .44063 Mdot
.15143 .26688 Mdot
.15333 .34159 Mdot
.15524 .25373 Mdot
.15714 .35977 Mdot
.15905 .32704 Mdot
.16095 .31823 Mdot
.16286 .28041 Mdot
.16476 .25907 Mdot
.16667 .30037 Mdot
.16857 .31432 Mdot
.17048 .21862 Mdot
.17238 .27395 Mdot
.17429 .24956 Mdot
.17619 .36931 Mdot
.1781 .40414 Mdot
.18 .34696 Mdot
.1819 .25991 Mdot
.18381 .38431 Mdot
.18571 .40207 Mdot
.18762 .33233 Mdot
.18952 .33121 Mdot
.19143 .30949 Mdot
.19333 .25338 Mdot
.19524 .34223 Mdot
.19714 .2263 Mdot
.19905 .41367 Mdot
.20095 .33292 Mdot
.20286 .2684 Mdot
.20476 .33766 Mdot
.20667 .42917 Mdot
.20857 .34189 Mdot
.21048 .41765 Mdot
.21238 .22089 Mdot
.21429 .26686 Mdot
.21619 .39969 Mdot
.2181 .24534 Mdot
.22 .32358 Mdot
.2219 .39694 Mdot
.22381 .39597 Mdot
.22571 .36447 Mdot
.22762 .34062 Mdot
.22952 .32955 Mdot
.23143 .33187 Mdot
.23333 .3588 Mdot
.23524 .32385 Mdot
.23714 .26784 Mdot
.23905 .43942 Mdot
.24095 .39308 Mdot
.24286 .41544 Mdot
.24476 .2794 Mdot
.24667 .2624 Mdot
.24857 .43359 Mdot
.25048 .44048 Mdot
.25238 .26102 Mdot
.25429 .3064 Mdot
.25619 .39782 Mdot
.2581 .2501 Mdot
.26 .30365 Mdot
.2619 .36193 Mdot
.26381 .28703 Mdot
.26571 .38208 Mdot
.26762 .45131 Mdot
.26952 .38896 Mdot
.27143 .28384 Mdot
.27333 .24143 Mdot
.27524 .39692 Mdot
.27714 .27526 Mdot
.27905 .25291 Mdot
.28095 .27921 Mdot
.28286 .26357 Mdot
.28476 .28782 Mdot
.28667 .35055 Mdot
.28857 .27353 Mdot
.29048 .38849 Mdot
.29238 .30245 Mdot
.29429 .45642 Mdot
.29619 .27431 Mdot
.2981 .2592 Mdot
.3 .27089 Mdot
.3019 .36967 Mdot
.30381 .41711 Mdot
.30571 .47259 Mdot
.30762 .31914 Mdot
.30952 .28686 Mdot
.31143 .38712 Mdot
.31333 .24915 Mdot
.31524 .28652 Mdot
.31714 .34946 Mdot
.31905 .32218 Mdot
.32095 .2821 Mdot
.32286 .24654 Mdot
.32476 .27133 Mdot
.32667 .43532 Mdot
.32857 .28518 Mdot
.33048 .25467 Mdot
.33238 .37297 Mdot
.33429 .24441 Mdot
.33619 .22839 Mdot
.3381 .41691 Mdot
.34 .33602 Mdot
.3419 .39669 Mdot
.34381 .42225 Mdot
.34571 .40837 Mdot
.34762 .259 Mdot
.34952 .25775 Mdot
.35143 .3782 Mdot
.35333 .33185 Mdot
.35524 .29147 Mdot
.35714 .33807 Mdot
.35905 .34173 Mdot
.36095 .40711 Mdot
.36286 .43764 Mdot
.36476 .27126 Mdot
.36667 .30233 Mdot
.36857 .31457 Mdot
.37048 .23582 Mdot
.37238 .24536 Mdot
.37429 .28826 Mdot
.37619 .22843 Mdot
.3781 .33099 Mdot
.38 .43443 Mdot
.3819 .4544 Mdot
.38381 .44221 Mdot
.38571 .22466 Mdot
.38762 .29279 Mdot
.38952 .36456 Mdot
.39143 .36856 Mdot
.39333 .27592 Mdot
.39524 .40824 Mdot
.39714 .3844 Mdot
.39905 .27429 Mdot
.40095 .30201 Mdot
.40286 .28833 Mdot
.40476 .35903 Mdot
.40667 .3745 Mdot
.40857 .32621 Mdot
.41048 .32545 Mdot
.41238 .31082 Mdot
.41429 .35067 Mdot
.41619 .3333 Mdot
.4181 .399 Mdot
.42 .29056 Mdot
.4219 .25364 Mdot
.42381 .27113 Mdot
.42571 .31581 Mdot
.42762 .35139 Mdot
.42952 .25257 Mdot
.43143 .26738 Mdot
.43333 .40874 Mdot
.43524 .3196 Mdot
.43714 .39757 Mdot
.43905 .25222 Mdot
.44095 .2294 Mdot
.44286 .33134 Mdot
.44476 .35455 Mdot
.44667 .29487 Mdot
.44857 .25836 Mdot
.45048 .38068 Mdot
.45238 .40392 Mdot
.45429 .41109 Mdot
.45619 .33996 Mdot
.4581 .36061 Mdot
.46 .34642 Mdot
.4619 .33236 Mdot
.46381 .31355 Mdot
.46571 .41366 Mdot
.46762 .34173 Mdot
.46952 .31533 Mdot
.47143 .33793 Mdot
.47333 .31089 Mdot
.47524 .34037 Mdot
.47714 .3787 Mdot
.47905 .27306 Mdot
.48095 .39113 Mdot
.48286 .25755 Mdot
.48476 .39851 Mdot
.48667 .42638 Mdot
.48857 .24597 Mdot
.49048 .41905 Mdot
.49238 .32569 Mdot
.49429 .44225 Mdot
.49619 .33341 Mdot
.4981 .23265 Mdot
.5 .25804 Mdot
.5019 .3216 Mdot
.50381 .28964 Mdot
.50571 .25854 Mdot
.50762 .28433 Mdot
.50952 .26928 Mdot
.51143 .24024 Mdot
.51333 .353 Mdot
.51524 .3023 Mdot
.51714 .31125 Mdot
.51905 .31402 Mdot
.52095 .37137 Mdot
.52286 .41146 Mdot
.52476 .32737 Mdot
.52667 .34068 Mdot
.52857 .41517 Mdot
.53048 .26453 Mdot
.53238 .25988 Mdot
.53429 .3858 Mdot
.53619 .33083 Mdot
.5381 .25859 Mdot
.54 .39897 Mdot
.5419 .36567 Mdot
.54381 .39867 Mdot
.54571 .32851 Mdot
.54762 .28577 Mdot
.54952 .35727 Mdot
.55143 .24551 Mdot
.55333 .27343 Mdot
.55524 .3605 Mdot
.55714 .42768 Mdot
.55905 .35208 Mdot
.56095 .27506 Mdot
.56286 .28827 Mdot
.56476 .31236 Mdot
.56667 .28824 Mdot
.56857 .28061 Mdot
.57048 .33789 Mdot
.57238 .3358 Mdot
.57429 .31015 Mdot
.57619 .35832 Mdot
.5781 .4058 Mdot
.58 .26482 Mdot
.5819 .39269 Mdot
.58381 .45523 Mdot
.58571 .36586 Mdot
.58762 .34258 Mdot
.58952 .35962 Mdot
.59143 .29628 Mdot
.59333 .36429 Mdot
.59524 .38089 Mdot
.59714 .41545 Mdot
.59905 .32897 Mdot
.60095 .48973 Mdot
.60286 .36289 Mdot
.60476 .26478 Mdot
.60667 .39413 Mdot
.60857 .44174 Mdot
.61048 .2268 Mdot
.61238 .33753 Mdot
.61429 .42362 Mdot
.61619 .36094 Mdot
.6181 .31149 Mdot
.62 .24378 Mdot
.6219 .28712 Mdot
.62381 .2856 Mdot
.62571 .37003 Mdot
.62762 .27238 Mdot
.62952 .36705 Mdot
.63143 .37155 Mdot
.63333 .40843 Mdot
.63524 .26886 Mdot
.63714 .24236 Mdot
.63905 .30744 Mdot
.64095 .46749 Mdot
.64286 .32548 Mdot
.64476 .26186 Mdot
.64667 .38494 Mdot
.64857 .26806 Mdot
.65048 .35851 Mdot
.65238 .32672 Mdot
.65429 .28096 Mdot
.65619 .32404 Mdot
.6581 .32098 Mdot
.66 .23378 Mdot
.6619 .33785 Mdot
.66381 .23566 Mdot
.66571 .29721 Mdot
.66762 .3099 Mdot
.66952 .34215 Mdot
.67143 .24061 Mdot
.67333 .3342 Mdot
.67524 .37287 Mdot
.67714 .3558 Mdot
.67905 .22614 Mdot
.68095 .35547 Mdot
.68286 .36805 Mdot
.68476 .31664 Mdot
.68667 .42328 Mdot
.68857 .34752 Mdot
.69048 .36149 Mdot
.69238 .32511 Mdot
.69429 .30342 Mdot
.69619 .25818 Mdot
.6981 .45632 Mdot
.7 .31155 Mdot
.7019 .36795 Mdot
.70381 .40355 Mdot
.70571 .36722 Mdot
.70762 .36483 Mdot
.70952 .38208 Mdot
.71143 .28297 Mdot
.71333 .31444 Mdot
.71524 .46955 Mdot
.71714 .41951 Mdot
.71905 .28261 Mdot
.72095 .23749 Mdot
.72286 .23258 Mdot
.72476 .28348 Mdot
.72667 .33049 Mdot
.72857 .30236 Mdot
.73048 .36387 Mdot
.73238 .27564 Mdot
.73429 .37887 Mdot
.73619 .3478 Mdot
.7381 .26314 Mdot
.74 .39919 Mdot
.7419 .42443 Mdot
.74381 .39249 Mdot
.74571 .32649 Mdot
.74762 .23642 Mdot
.74952 .25569 Mdot
.75143 .35248 Mdot
.75333 .24953 Mdot
.75524 .23907 Mdot
.75714 .44348 Mdot
.75905 .28525 Mdot
.76095 .30654 Mdot
.76286 .32 Mdot
.76476 .26777 Mdot
.76667 .25086 Mdot
.76857 .28694 Mdot
.77048 .23552 Mdot
.77238 .36339 Mdot
.77429 .32679 Mdot
.77619 .25577 Mdot
.7781 .32562 Mdot
.78 .33233 Mdot
.7819 .43312 Mdot
.78381 .41343 Mdot
.78571 .39912 Mdot
.78762 .23984 Mdot
.78952 .33158 Mdot
.79143 .24947 Mdot
.79333 .35213 Mdot
.79524 .33952 Mdot
.79714 .35641 Mdot
.79905 .27859 Mdot
.80095 .33549 Mdot
.80286 .31624 Mdot
.80476 .34428 Mdot
.80667 .31573 Mdot
.80857 .32409 Mdot
.81048 .31503 Mdot
.81238 .32739 Mdot
.81429 .27297 Mdot
.81619 .41733 Mdot
.8181 .26946 Mdot
.82 .28381 Mdot
.8219 .27183 Mdot
.82381 .30392 Mdot
.82571 .34076 Mdot
.82762 .31748 Mdot
.82952 .27899 Mdot
.83143 .39219 Mdot
.83333 .38977 Mdot
.83524 .30572 Mdot
.83714 .37686 Mdot
.83905 .34032 Mdot
.84095 .30914 Mdot
.84286 .35736 Mdot
.84476 .27512 Mdot
.84667 .28166 Mdot
.84857 .40589 Mdot
.85048 .38734 Mdot
.85238 .36122 Mdot
.85429 .39821 Mdot
.85619 .26248 Mdot
.8581 .43847 Mdot
.86 .29381 Mdot
.8619 .35127 Mdot
.86381 .32928 Mdot
.86571 .22311 Mdot
.86762 .30873 Mdot
.86952 .31804 Mdot
.87143 .34933 Mdot
.87333 .41563 Mdot
.87524 .37083 Mdot
.87714 .38578 Mdot
.87905 .32916 Mdot
.88095 .37779 Mdot
.88286 .38271 Mdot
.88476 .33564 Mdot
.88667 .28024 Mdot
.88857 .26071 Mdot
.89048 .35789 Mdot
.89238 .26406 Mdot
.89429 .25944 Mdot
.89619 .35823 Mdot
.8981 .38187 Mdot
.9 .39089 Mdot
.9019 .37717 Mdot
.90381 .31377 Mdot
.90571 .44883 Mdot
.90762 .25686 Mdot
.90952 .31455 Mdot
.91143 .26094 Mdot
.91333 .32919 Mdot
.91524 .3669 Mdot
.91714 .36178 Mdot
.91905 .24722 Mdot
.92095 .36323 Mdot
.92286 .40001 Mdot
.92476 .30445 Mdot
.92667 .25558 Mdot
.92857 .35498 Mdot
.93048 .43616 Mdot
.93238 .29464 Mdot
.93429 .31409 Mdot
.93619 .34157 Mdot
.9381 .36763 Mdot
.94 .2845 Mdot
.9419 .32884 Mdot
.94381 .36556 Mdot
.94571 .28009 Mdot
.94762 .31192 Mdot
.94952 .33687 Mdot
.95143 .44028 Mdot
.95333 .34159 Mdot
.95524 .37608 Mdot
.95714 .25555 Mdot
.95905 .25989 Mdot
.96095 .26765 Mdot
.96286 .40872 Mdot
.96476 .26993 Mdot
.96667 .3393 Mdot
.96857 .37526 Mdot
.97048 .4166 Mdot
.97238 .25243 Mdot
.97429 .33669 Mdot
.97619 .26601 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0000/ooooo`;o0000ooooool@
ooooo`00:Oooool00ol0003oooooooooo`0Mooooo`;o00003?ooool2o`0000cooooo0_l0003ooooo
o`;ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Mooooo`;o00006_ooool2
o`0003Kooooo0_l0002Hooooo`;o0000;oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`0<ooooo`;o00001oooool2o`0001gooooo0_l0000kooooo`;o0000A_oo
ool2o`0001Cooooo0_l0000jooooo`;o0000;oooool000Co00000_ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00cooooo0_l00007ooooo`;o00007Oooool2o`0002_ooooo0_l0000;ooooo`;o00004_oo
ool2o`0003Gooooo0_l0000Dooooo`;o0000Joooool000Kooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`00067ooooo0_l0
000;ooooo`;o00004_ooool2o`00017ooooo0_l0000booooo`;o00004_ooool2o`0005gooooo0006
ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Looooo`;o0000C_ooool2o`0002Oooooo
0_l0000booooo`?o00004Oooool2o`0000Kooooo0_l00005ooooo`;o0000C_ooool000Kooooo00Go
410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Looooo`;o0000C_ooool2o`0002_ooooo0_l0000_ooooo`;o0000
4?ooool2o`0000Oooooo1?l00003ooooo`;o00001?ooool2o`0004Sooooo0006ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`02o`0004_ooooo0_l0001:ooooo`;o00009_ooool2o`0000[o
oooo0_l0000=ooooo`;o00002Oooool2o`0000Wooooo0_l00018ooooo`001_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0
003oooooooooo`02o`0003Wooooo0_l0000@ooooo`;o00003Oooool2o`0000;ooooo0_l0000:oooo
o`;o00009?ooool2o`0001;ooooo0_l0000Dooooo`;o00000oooool2o`0000[ooooo0_l0001]oooo
o`00:Oooool2o`0000_ooooo0_l0000<ooooo`;o00004oooool2o`0000cooooo0_l0000Looooo`;o
000000?oooooo`000?l000000_ooool2o`0000[ooooo0_l0000Tooooo`;o00004_ooool2o`0001Co
oooo0_l0000Yooooo`;o00002_ooool2o`0002Oooooo0_l0000Nooooo`00:Oooool00ol0003ooooo
ooooo`0:ooooo`;o00003?ooool2o`0000Sooooo0_l00009ooooo`;o00006Oooool2o`0000oooooo
0_l0000Tooooo`;o000000?oooooo`000?l00000Hoooool2o`0000;ooooo0_l00006ooooo`;o0000
9oooool2o`0000oooooo0_l0000=ooooo`00:Oooool00ol0003oooooooooo`0Rooooo`;o00000ooo
ool2o`0000[ooooo0_l0000Cooooo`;o00001?ooool2o`0000oooooo0_l0000Kooooo`;o000000Co
ooooo`000?l0003ooooo0_l0001Rooooo`;o00000oooool2o`000003ooooool0003o000002oooooo
0_l00007ooooo`;o00000oooool2o`0000gooooo000Yooooo`03o`000?oooooooooo02Oooooo0_l0
000:ooooo`;o00006Oooool2o`0000oooooo0_l00003ooooo`?o00005Oooool2o`0000Oooooo0_l0
0009ooooo`;o00000oooool4o`0000Wooooo0_l0000`ooooo`;o00004?ooool2o`0000Kooooo0_l0
000Xooooo`;o00001Oooool2o`0000Oooooo0_l0000Booooo`00:Oooool00ol0003oooooooooo`0D
ooooo`;o00005?ooool2o`0000?ooooo0_l0000Eooooo`;o00003?ooool2o`0000kooooo0ol0000N
ooooo`;o00002Oooool2o`0000?ooooo1?l00007ooooo`Co00008?ooool2o`0000kooooo0_l0000l
ooooo`Co00000_ooool4o`0000gooooo0_l0000Aooooo`00:Oooool2o`0000_ooooo0_l00008oooo
o`;o00005?ooool2o`0000?ooooo0_l0000Cooooo`Co00002?ooool2o`0000;ooooo0_l00019oooo
o`?o00003Oooool2o`0000Kooooo0_l0000;ooooo`;o00007?ooool2o`0002Cooooo0_l00008oooo
o`Co00001?ooool2o`0000gooooo0_l0000Aooooo`00:Oooool00ol0003oooooooooo`07ooooo`;o
000000?oooooo`000?l000006Oooool2o`0001?ooooo0_l00005ooooo`;o000000?oooooo`000?l0
00002_ooool2o`0002gooooo0_l0000Nooooo`;o00003_ooool2o`0000Kooooo0_l0000<ooooo`;o
00006oooool2o`0000Oooooo0_l0000Kooooo`;o00002_ooool2o`0001Cooooo0_l00003ooooo`;o
00002oooool002Wooooo00?o0000ooooool000000ol00004ooooo`;o00001?ooool2o`0001Kooooo
0_l00009ooooo`Co000000Go410@ooooool0003o0000oc8b<P03o`0000?ooooo00Gok^k^oc8b<_l0
003o0000onk^kP0Aooooo`;o00001_ooool2o`0000_ooooo0_l000000ooooooo0000o`000003o`00
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`Co000000?ok^k^ooooooooool05?ooool2
o`00013ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo0_l00002ooooo`;o00008_ooool4o`0000;o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_l0000W
ooooo`05odA4A?l0003o0000oc8b<_oMgMd00ol000001?lb<S;o0000o`000?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool002Wooooo00?o0000ooooool000000ol0000:ooooo`;o0000
1_ooool2o`0000Wooooo0_l0000:ooooo`;o00001?ooool01?l0003oooooooooooooool2o`000004
oiRHV?ooooooV9RHogMgM`?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0=ooooo`;o000000Cooooo
o`000?l0003o00001_ooool2o`0000_ooooo0_l000001_ooooooV9RHob4Q8Oo^k^koooooodA4A0?o
oooo0_l000000oooooooV9RHogMgM`03ooooo`;o000000?ooooooiRHV?mgMgL03Oooool2o`0000Oo
oooo0_l0000=ooooo`;o000000Kooooooa0@4?nj^[[oooooogMgMolb<S83ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool01?mgMgOoV9RHoooooonHV9P2o`000003ooooool0003o000002Oooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?oMgMgoiRHV?oo
ool01Ol0000Yooooo`03ogMgMolb<S;ooooo00;o000000CoV9RHoooooonHV9SoMgMg0oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo000Yooooo`03o`000?oooooooooo01Gooooo0_l00009oooo
o`;o00002_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@00?ooooo00Go410@oooooooooooooooooa0@400:ooooo`;o000000Coooooo`000?l0003ooooo
0_l0000Hooooo`03oiRHV?lQ8B7ok^k^00;ooooo1?l00002ooooo`05oa0@4?ooooooooooooooool@
41000oooool00ol@413oooooooooo`0;ooooo`;o00005_ooool4o`0000?ooooo00Go0000oooooooo
oooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool2o`00023ooooo0_l00005
ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool00_l0
00000ooooooo0000o`000005ooooo`;o00008oooool01?l0003oooooooooool@4103ooooo`05oa0@
4?ooooooooooooooool@41000oooool00ol@413oooooooooo`01ooooo`00:Oooool3o`0002Wooooo
0_l00007ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`04
o`000?ooooooooooooooo`;o00002Oooool3o`0001kooooo00CoV9RHob4Q8Oo^k^kooooo0ol00003
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Uooooo`Co000000?o
ZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`00000Qooooo`;o00001Oooool01?m4A4CogMgMooooool00004ooooo`05o`000?oooooooooo
ooooool000000_ooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`;o00003?oo
ool2o`00017ooooo0_l000000oooooooMgMgoc8b<P02ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000?ooooo000Yooooo`?o00000_ooool2o`0002Gooooo
0_l00007ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`04
o`000?ooooooooooooooo`;o00001oooool2o`000003ooooool0003o000000_ooooo0_l0000Boooo
o`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool00000:Oooool3o`000005okZj^_ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool01_ooool2o`00013ooooo0_l000000ooooooo
0000o`000002o`0000Oooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo
000000;ooooo0_l00003ooooo`?o000000?oooooo`000?l000001?ooool2o`0000_ooooo0_l0000A
ooooo`?o000000Go<S8bolc<c?ooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`01ooooo`00:Oooool00ol0003oooooooooo`02ooooo`;o0000;_oo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooo
oooooooooooo410@00Gooooo0_l000000ooooooo0000o`00000:ooooo`So00004Oooool01Ol0003o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooo
oooo01Cooooo0_l0000;ooooo`;o00001_ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41000oooool00ol@413oooooooooo`02o`0000Sooooo0_l0000@ooooo`;o000000?o
ooooo`000?l000000_l00008ooooo`04ogMgMol0003o0000ooooo`;o000000?ooooooa0@4?ooool0
0_ooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@o`000?l000001oooool2o`0001co
oooo0ol00006ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo
410@00?ooooo000Yooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o00001Ooo
ool2o`0000Kooooo1?l00002ooooo`;o00003Oooool2o`000003oooooonHV9So410@00?ooooo00Go
MgMgo`000?l0003oV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05Oooool3o`0000_o
oooo0_l00003ooooo`?o000000?o^[Zjo`000?ooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00?oMgMgoiRHV?ooool00_l0000Yooooo`04onk^k_l0003o0000ooooo`;o000000Kooooo
ogMgMonHV9SooooooiRHV?mgMgL3ooooo`05ogMgMonHV9SooooooiRHV?mgMgL09oooool3o`0000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0
02Wooooo00?o0000ooooooooool04oooool2o`0001_ooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`;o00005Ooo
ool2o`0000Cooooo0ol000000olQ8B7o0000o`000002ooooo`05onk^k_l0003o0000oc8b<_o^k^h0
0_ooool2o`000004oc8b<_l0003o<S8bonk^kQGooooo0_l0000Aooooo`?o000000?o410@ojVYZOoo
ool00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?ok^k^oc8b<_l000000_l0000Zoooo
o`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h0:Oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool002Wooooo0_l00009ooooo`;o00002Oooool2o`0005;ooooo
0_l00008ooooo`;o00002Oooool2o`0000Kooooo0_l0000]ooooo`;o0000E?ooool2o`0001Gooooo
0_l0000Jooooo`00:Oooool00ol0003oooooooooo`08ooooo`;o0000N_ooool2o`0002gooooo0_l0
000Fooooo`;o0000??ooool2o`0001Gooooo0_l0000Jooooo`00:Oooool00ol0003oooooooooo`0D
ooooo`;o00003Oooool2o`0000Gooooo0_l0000Wooooo`;o00005_ooool2o`0000Wooooo0_l0000R
ooooo`;o0000;oooool2o`0001;ooooo0_l0001Kooooo`00:Oooool00ol0003oooooooooo`0Doooo
o`;o00003Oooool2o`0000Gooooo0_l0000Looooo`;o00002Oooool2o`0001Kooooo0_l00009oooo
o`;o00008_ooool2o`0003Sooooo0_l00009ooooo`;o00007Oooool2o`0001kooooo0_l0000Loooo
o`00:Oooool00ol0003oooooooooo`16ooooo`Co0000N?ooool2o`00013ooooo0_l0000Cooooo`;o
00004oooool2o`000003ooooool0003o000000Wooooo0_l0000@ooooo`;o00007?ooool0027ooooo
ool00014o`0000Cooooo000Yooooo`03o`000?oooooooooo00Cooooo0_l00003ooooo`;o00002ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo0_l000000ooooooo0000oooo
o`02ooooo`;o00001_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`;o00002oooool3o`0000Wooooo00?o
0000ooooooooool00oooool2o`000005ooooool0003o0000ooooool000002_ooool3o`0000_ooooo
0ol000000ooooooo0000o`000006ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03o`00
0?oooooooooo00Oooooo0ol00008ooooo`;o00000_ooool2o`0000[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`04ooooo`;o00000oooool00ol0003oooooooooo`02ooooo`;o0000
1_ooool00ol0003oooooooooo`09ooooo`Co00001_ooool3o`000003ooooool0003o000000Sooooo
00?o0000ooooooooool02_ooool002Wooooo00?o0000ooooooooool01?ooool2o`0000?ooooo0_l0
0003ooooo`;o00006oooool2o`0000gooooo00?o0000ooooooooool0;_ooool2o`0000_ooooo00?o
0000ooooooooool00_ooool2o`0000_ooooo1?l0000>ooooo`;o00003?ooool2o`0000Wooooo00?o
0000ooooooooool06Oooool2o`0000Oooooo0_l0000Fooooo`03o`000?oooooooooo00;ooooo1?l0
0004ooooo`;o00002oooool2o`0000Wooooo1?l00006ooooo`;o00003?ooool00ol0003ooooooooo
o`0:ooooo`00:Oooool00ol0003oooooooooo`05ooooo`;o00001oooool2o`0000Oooooo0_l0000:
ooooo`;o00000oooool2o`0002kooooo0_l0000Sooooo`;o00000_ooool2o`0000Wooooo0_l0000j
ooooo`;o00001oooool2o`0001Oooooo0_l0000;ooooo`?o00001Oooool2o`0000_ooooo0_l0000^
ooooo`00:Oooool00ol0003oooooooooo`05ooooo`;o00004?ooool2o`0000[ooooo0_l00003oooo
o`;o00004Oooool2o`0000?ooooo0_l0000Fooooo`;o000000?oooooo`000?l000009?ooool2o`00
01?ooooo0_l0000`ooooo`;o00008?ooool2o`0000gooooo0_l00011ooooo`00:Oooool2o`0000So
oooo0_l0000@ooooo`;o00003Oooool2o`00017ooooo0_l00003ooooo`;o00006Oooool2o`0001_o
oooo0ol0000Hooooo`;o000000?oooooo`000?l000001Oooool2o`0002Cooooo0_l000000ooooooo
0000o`000002o`0000Wooooo0_l0000?ooooo`;o00002?ooool3o`0000Sooooo0ol00010ooooo`00
:Oooool00ol0003oooooooooo`07ooooo`;o00004?ooool2o`0000gooooo0_l0000Dooooo`;o0000
>?ooool3o`0001Sooooo0_l00008ooooo`;o00001Oooool2o`0000oooooo0_l0000<ooooo`;o0000
00?oooooo`000?l000002oooool2o`0000Wooooo0_l00004ooooo`;o00002?ooool3o`0000Wooooo
0_l0000>ooooo`;o00000oooool2o`0000Wooooo0_l00007ooooo`;o00005oooool002Wooooo00?o
0000ooooooooool0<Oooool3o`000003ooooool0003o000000Oooooo0ol0000Uooooo`;o00001_oo
ool2o`0000[ooooo0_l00007ooooo`;o00001?ooool2o`0000Wooooo0_l0000;ooooo`;o000000?o
ooooo`000?l000003oooool2o`0002Oooooo0_l0000?ooooo`;o000000?oooooo`000?l000005_oo
ool2o`0000?ooooo0_l00009ooooo`;o00001oooool2o`0001Oooooo000Yooooo`;o00004?ooool2
o`00023ooooo0ol000000ooooooo0000o`000008ooooo`;o00008Oooool2o`0000;ooooo0_l00006
ooooo`;o00002_ooool2o`0000Oooooo0_l00004ooooo`;o00002Oooool2o`0000_ooooo0_l0000:
ooooo`;o00007_ooool2o`00023ooooo0_l000000ooooooo0000o`000002ooooo`;o00006Oooool2
o`0001_ooooo0_l0000<ooooo`00:Oooool4o`0000kooooo0_l0000Uooooo`;o0000:_ooool2o`00
00?ooooo0_l0000Sooooo`;o00007_ooool3o`0000_ooooo0_l0000=ooooo`;o00000_ooool2o`00
02Gooooo1?l0000Iooooo`;o00004oooool2o`0000?ooooo0_l000000ooooooo0000o`00000<oooo
o`00:Oooool4o`0000Gooooo0_l00003ooooo`Co00003?ooool2o`0000Wooooo0_l0000;ooooo`;o
000000?oooooo`000?l000000_l00004ooooo`;o00009oooool3o`0001gooooo0_l00002ooooo`Co
00003oooool2o`0000cooooo0_l00004ooooo`;o00001_ooool2o`0000gooooo0_l000000ooooooo
0000o`00000Vooooo`;o00002?ooool2o`0000;ooooo0_l0000Nooooo`;o00000_ooool3o`0000;o
oooo0_l0000?ooooo`00:Oooool00ol0003oooooooooo`05ooooo`?o000000?oooooo`000?l00000
1?l0000;ooooo`?o000000?oooooo`000?l000001_ooool2o`0000_ooooo0_l00003ooooo`;o0000
1?ooool2o`0002Sooooo0_l0000Mooooo`;o00000_ooool4o`0000oooooo0_l0000Booooo`;o0000
6?ooool2o`0002Wooooo0_l00005ooooo`;o00000_ooool2o`0001kooooo0_l00003ooooo`;o0000
4oooool002Wooooo00?o0000ooooooooool01Oooool2o`0000;ooooo0_l0000?ooooo`;o00000_oo
ool2o`0000kooooo0_l0001Iooooo`;o0000Aoooool2o`0000gooooo0_l0000Dooooo`;o0000@ooo
ool002Wooooo00?o0000ooooooooool00oooool2o`0002Wooooo0_l0000Qooooo`;o00002?ooool2
o`0001gooooo0_l00002ooooo`;o00002Oooool2o`0001gooooo0_l0000Xooooo`;o00003Oooool2
o`00017ooooo0_l0000Dooooo`;o000000?oooooo`000?l00000;Oooool002Wooooo00?o0000oooo
ooooool00oooool2o`0000cooooo0_l0000<ooooo`;o0000<?ooool2o`0000Sooooo0_l0000Moooo
o`;o00000_ooool2o`0000Cooooo0_l0000Dooooo`;o00003?ooool2o`0002Kooooo0_l0000Doooo
o`;o00003?ooool2o`0001Cooooo0_l000000ooooooo0000o`00000@ooooo`;o00006oooool002Wo
oooo0_l00002ooooo`;o00002Oooool2o`0000?ooooo0_l0000<ooooo`;o0000Hoooool2o`0001Co
oooo0_l00009ooooo`;o00001oooool2o`0001Kooooo0_l00006ooooo`Co00005?ooool2o`0000go
oooo0_l0000=ooooo`;o00003Oooool4o`0000Sooooo0_l0000Kooooo`00:Oooool01?l0003ooooo
ooooooooool2o`0000Wooooo0_l0000Iooooo`;o00005oooool2o`0003Gooooo0_l0000?ooooo`;o
00006oooool4o`0000Gooooo0_l00002ooooo`;o00001oooool2o`0000Wooooo0_l00006ooooo`;o
00000oooool2o`00023ooooo0_l0000=ooooo`;o000000?oooooo`000?l000002_ooool4o`0002Go
oooo000Yooooo`03o`000?oooooooooo01gooooo0_l00008ooooo`;o00005?ooool2o`000003oooo
ool0003o000000Oooooo0_l0000Wooooo`;o00000oooool2o`0000oooooo0_l0000Mooooo`;o0000
2Oooool3o`000003ooooool0003o000000?ooooo0_l0000Fooooo`;o00002_ooool2o`0000cooooo
0_l0000Hooooo`;o00004oooool3o`0001gooooo000Yooooo`03o`000?oooooooooo01gooooo0_l0
000Nooooo`;o00002_ooool2o`0002Oooooo0_l0000_ooooo`;o00003?ooool4o`000003ooooool0
003o000000Oooooo0_l0000Gooooo`;o00001Oooool2o`0000cooooo0_l0000/ooooo`Co00000ooo
ool4o`0001Kooooo000Yooooo`03o`000?oooooooooo02gooooo0_l0000Wooooo`;o00006_ooool2
o`0002oooooo0_l0000<ooooo`;o00002oooool3o`0000oooooo0_l00004ooooo`Co0000=?ooool2
o`0000_ooooo0_l00005ooooo`Co00005_ooool002Wooooo0_l0000^ooooo`;o00009oooool2o`00
00Oooooo0_l0000Aooooo`;o0000:?ooool2o`00023ooooo1?l0000<ooooo`Co00001?ooool2o`00
03Kooooo0_l0000/ooooo`00:Oooool00ol0003oooooooooo`1Oooooo`;o00005_ooool2o`0002?o
oooo0_l0000Rooooo`;o00003?ooool2o`0003;ooooo0_l0000Cooooo`;o00003oooool2o`0000;o
oooo0_l0000>ooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go
00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool08Oooool2o`00
04?ooooo0_l0000?ooooo`;o00005Oooool2o`00057ooooo0_l0000Oooooo`;o00003?ooool2o`00
00Gooooo0_l0000?ooooo`;o00000_ooool2o`0000kooooo0006ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool04_ooool2o`0000;ooooo0_l00008ooooo`?o00009oooool2
o`0001[ooooo0_l0000Mooooo`;o00001oooool2o`0002Cooooo0_l0000Sooooo`;o00001_ooool2
o`0002gooooo0_l00003ooooo`;o00009Oooool000Kooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0B
ooooo`;o00000_ooool2o`0000Sooooo0_l0000>ooooo`;o00006?ooool2o`0002Sooooo0_l0000?
ooooo`;o00006Oooool2o`0001;ooooo0_l0000?ooooo`;o00004_ooool2o`0003Cooooo0ol00003
ooooo`;o00009Oooool000Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0001Sooooo0_l0000Fooooo`;o00006Oooool2
o`0000Gooooo0_l00005ooooo`;o00006Oooool2o`0002[ooooo0_l0000Sooooo`;o0000?oooool2
o`0000Oooooo0_l0000[ooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMg
ofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool06?oo
ool2o`00037ooooo0_l00005ooooo`;o00001Oooool2o`0003Cooooo0_l0000Oooooo`;o0000<_oo
ool2o`0001[ooooo0ol00003ooooo`;o00003_ooool2o`0002Cooooo0006ooooo`05oa0@4?oooooo
ooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0@_ooool2o`0004_ooooo0_l0000Oooooo`;o00001_ooool2o`0002[ooooo0_l0
000Jooooo`?o00004oooool2o`0002Cooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool2o`0003gooooo
0ol00003ooooo`;o00000oooool2o`0000Cooooo0_l0000Dooooo`;o00005_ooool2o`0000Cooooo
0_l0000=ooooo`;o00004?ooool3o`0001?ooooo0_l0001=ooooo`;o0000<oooool000Kooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Ko
oooo0_l0000Hooooo`;o00005oooool2o`0000Sooooo1Ol00008ooooo`;o00001?ooool2o`0001Co
oooo0_l0000Fooooo`;o00001?ooool2o`0000gooooo0_l0000@ooooo`?o0000?_ooool2o`0000co
oooo0_l0000Dooooo`;o00005?ooool2o`0001gooooo000Yooooo`;o00004Oooool2o`0000Gooooo
0_l0000Eooooo`Co00002?ooool2o`0004[ooooo0_l0001?ooooo`;o00002_ooool2o`0000cooooo
0_l0000Zooooo`;o00007Oooool002Wooooo00?o0000ooooooooool04?ooool2o`0001cooooo0_l0
000iooooo`;o00002Oooool2o`00013ooooo0_l0000Vooooo`;o00009oooool2o`0002cooooo0_l0
000eooooo`00:Oooool00ol0003oooooooooo`0Booooo`;o0000D?ooool2o`0000?ooooo0_l00009
ooooo`;o00002_ooool2o`0000Gooooo0_l0000Uooooo`;o00004?ooool2o`0004?ooooo0_l0000S
ooooo`;o00004?ooool002Wooooo00?o0000ooooooooool04_ooool2o`00027ooooo0_l0000]oooo
o`;o00006_ooool2o`0000Gooooo0_l000000ooooooo0000o`00000Aooooo`;o00008Oooool2o`00
02oooooo0_l0000gooooo`;o00004?ooool002Wooooo00?o0000ooooooooool0=Oooool2o`000003
ooooool0003o000000Wooooo0_l0000Aooooo`;o00002Oooool2o`0002Oooooo0_l0000Aooooo`Co
00005?ooool2o`0003[ooooo0_l00008ooooo`;o00004?ooool2o`0001kooooo0_l0000=ooooo`00
:Oooool2o`0002Gooooo0_l0000Booooo`;o00002Oooool2o`00017ooooo0_l00009ooooo`;o0000
;oooool2o`0000_ooooo0_l0000Dooooo`;o00009?ooool2o`0001kooooo0_l0000@ooooo`;o0000
7_ooool2o`0000gooooo000Yooooo`03o`000?oooooooooo01cooooo0_l00006ooooo`;o0000?Ooo
ool2o`0002gooooo0_l0000Vooooo`;o00005Oooool2o`0000Sooooo0_l0001Oooooo`00:Oooool0
0ol0003oooooooooo`0Looooo`;o0000AOooool2o`0002cooooo0_l0000Wooooo`;o00005Oooool2
o`00013ooooo0_l0001Gooooo`00:Oooool00ol0003oooooooooo`0Jooooo`;o00001_ooool2o`00
01?ooooo0_l0001Hooooo`;o00005Oooool2o`0003Wooooo0_l0001Gooooo`00:Oooool00ol0003o
ooooooooo`0Jooooo`;o00001_ooool2o`0001?ooooo0_l0001_ooooo`;o0000A_ooool2o`0004[o
oooo000Yooooo`;o00008?ooool2o`0002Cooooo0_l0000Gooooo`;o00003oooool2o`0007oooooo
0_l0000^ooooo`;o00006_ooool002Wooooo00?o0000ooooooooool00_ooool2o`0001_ooooo0_l0
000Pooooo`;o00000_ooool2o`0001Oooooo0_l00009ooooo`;o00001?ooool2o`0009Sooooo0_l0
000Eooooo`;o00006_ooool002Wooooo00?o0000ooooooooool00_ooool2o`0000cooooo0_l0000C
ooooo`;o00006_ooool2o`0000;ooooo0_l0000Rooooo`;o00001Oooool2o`0002;ooooo0_l0000R
ooooo`;o0000Coooool2o`0001cooooo0_l0000Cooooo`00:Oooool00ol0003oooooooooo`0@oooo
o`;o00004oooool2o`0001kooooo0_l0000Yooooo`;o00008_ooool2o`0002;ooooo0_l0000^oooo
o`;o0000?Oooool2o`0001?ooooo000Yooooo`03o`000?oooooooooo0>Sooooo0_l0001Booooo`00
:Oooool2o`0004cooooo0_l0003;ooooo`;o00008_ooool002Wooooo00?o0000ooooooooool0Booo
ool2o`0002;ooooo0_l0002Wooooo`;o00008_ooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0
Doooool2o`0001[ooooo0_l0000oooooo`;o00008oooool2o`0006Gooooo000>ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`1Cooooo`;o0000Foooool2o`0002?ooooo0_l0001Uooooo`003_ooool01Ol@413ooooooooo
oooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000kooooo00Go
0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo0<?ooooo0_l0000Fooooo`;o0000Goooool000kooooo
00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0Eoooool2o`0006[ooooo0_l0000Fooooo`;o0000Goooool000kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Eoooool2o`000>?o
oooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0003oooooocko
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0;Kooooo0_l00024ooooo`00:Oooool2o`000;Oooooo0_l00024ooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o
0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooo
oa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo
?Oooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05o`000?oo
ooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@
41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooo
oooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmoooo
o`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`00
0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`00
0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Oooooo`Co000000?o
410@ooooooooool00oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05oooo
o`?o0000oooooolmooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Oooooo`03oeEEEOmVIVKo00000?ooooooAoooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .35761 Mdot
.02762 .39436 Mdot
.02952 .30904 Mdot
.03143 .27488 Mdot
.03333 .36342 Mdot
.03524 .29115 Mdot
.03714 .3039 Mdot
.03905 .42904 Mdot
.04095 .40449 Mdot
.04286 .26058 Mdot
.04476 .32435 Mdot
.04667 .40358 Mdot
.04857 .235 Mdot
.05048 .29665 Mdot
.05238 .40665 Mdot
.05429 .33275 Mdot
.05619 .25825 Mdot
.0581 .23797 Mdot
.06 .25259 Mdot
.0619 .40985 Mdot
.06381 .23548 Mdot
.06571 .35403 Mdot
.06762 .33667 Mdot
.06952 .24645 Mdot
.07143 .32151 Mdot
.07333 .29389 Mdot
.07524 .34822 Mdot
.07714 .26683 Mdot
.07905 .39674 Mdot
.08095 .39363 Mdot
.08286 .2432 Mdot
.08476 .41136 Mdot
.08667 .44442 Mdot
.08857 .27796 Mdot
.09048 .37762 Mdot
.09238 .41653 Mdot
.09429 .23208 Mdot
.09619 .32524 Mdot
.0981 .38672 Mdot
.1 .38147 Mdot
.1019 .30059 Mdot
.10381 .34521 Mdot
.10571 .3778 Mdot
.10762 .38671 Mdot
.10952 .33259 Mdot
.11143 .30494 Mdot
.11333 .26367 Mdot
.11524 .36794 Mdot
.11714 .37491 Mdot
.11905 .40775 Mdot
.12095 .35781 Mdot
.12286 .32897 Mdot
.12476 .31256 Mdot
.12667 .38619 Mdot
.12857 .38563 Mdot
.13048 .43695 Mdot
.13238 .42665 Mdot
.13429 .25512 Mdot
.13619 .28642 Mdot
.1381 .31287 Mdot
.14 .28874 Mdot
.1419 .34551 Mdot
.14381 .38612 Mdot
.14571 .26773 Mdot
.14762 .44309 Mdot
.14952 .42936 Mdot
.15143 .27281 Mdot
.15333 .30534 Mdot
.15524 .31209 Mdot
.15714 .26567 Mdot
.15905 .24969 Mdot
.16095 .31508 Mdot
.16286 .26147 Mdot
.16476 .31591 Mdot
.16667 .38643 Mdot
.16857 .28857 Mdot
.17048 .31218 Mdot
.17238 .25836 Mdot
.17429 .35086 Mdot
.17619 .35743 Mdot
.1781 .34673 Mdot
.18 .3972 Mdot
.1819 .30794 Mdot
.18381 .35699 Mdot
.18571 .44506 Mdot
.18762 .34451 Mdot
.18952 .36326 Mdot
.19143 .35771 Mdot
.19333 .27476 Mdot
.19524 .30931 Mdot
.19714 .3191 Mdot
.19905 .46615 Mdot
.20095 .33193 Mdot
.20286 .33853 Mdot
.20476 .31293 Mdot
.20667 .471 Mdot
.20857 .28755 Mdot
.21048 .34933 Mdot
.21238 .2905 Mdot
.21429 .25866 Mdot
.21619 .37558 Mdot
.2181 .31195 Mdot
.22 .41042 Mdot
.2219 .39539 Mdot
.22381 .32709 Mdot
.22571 .29919 Mdot
.22762 .26073 Mdot
.22952 .26231 Mdot
.23143 .33317 Mdot
.23333 .26474 Mdot
.23524 .26243 Mdot
.23714 .27575 Mdot
.23905 .40578 Mdot
.24095 .42292 Mdot
.24286 .30351 Mdot
.24476 .32285 Mdot
.24667 .26849 Mdot
.24857 .44365 Mdot
.25048 .43443 Mdot
.25238 .248 Mdot
.25429 .23474 Mdot
.25619 .2933 Mdot
.2581 .26622 Mdot
.26 .38976 Mdot
.2619 .26854 Mdot
.26381 .26135 Mdot
.26571 .42122 Mdot
.26762 .47197 Mdot
.26952 .39795 Mdot
.27143 .26844 Mdot
.27333 .32846 Mdot
.27524 .39074 Mdot
.27714 .38168 Mdot
.27905 .26838 Mdot
.28095 .35819 Mdot
.28286 .36407 Mdot
.28476 .2326 Mdot
.28667 .41168 Mdot
.28857 .26637 Mdot
.29048 .43968 Mdot
.29238 .39806 Mdot
.29429 .4038 Mdot
.29619 .32773 Mdot
.2981 .27815 Mdot
.3 .25614 Mdot
.3019 .41909 Mdot
.30381 .4471 Mdot
.30571 .39937 Mdot
.30762 .25586 Mdot
.30952 .34911 Mdot
.31143 .27659 Mdot
.31333 .32337 Mdot
.31524 .34374 Mdot
.31714 .25383 Mdot
.31905 .30457 Mdot
.32095 .24528 Mdot
.32286 .26227 Mdot
.32476 .36894 Mdot
.32667 .44099 Mdot
.32857 .23403 Mdot
.33048 .25295 Mdot
.33238 .35125 Mdot
.33429 .34508 Mdot
.33619 .28392 Mdot
.3381 .39852 Mdot
.34 .38214 Mdot
.3419 .36009 Mdot
.34381 .44667 Mdot
.34571 .35444 Mdot
.34762 .32286 Mdot
.34952 .24978 Mdot
.35143 .41911 Mdot
.35333 .33062 Mdot
.35524 .3452 Mdot
.35714 .3627 Mdot
.35905 .27868 Mdot
.36095 .44387 Mdot
.36286 .47222 Mdot
.36476 .25134 Mdot
.36667 .32745 Mdot
.36857 .39486 Mdot
.37048 .2801 Mdot
.37238 .35673 Mdot
.37429 .33925 Mdot
.37619 .28543 Mdot
.3781 .30136 Mdot
.38 .39117 Mdot
.3819 .47035 Mdot
.38381 .41547 Mdot
.38571 .30058 Mdot
.38762 .36586 Mdot
.38952 .25027 Mdot
.39143 .41887 Mdot
.39333 .27091 Mdot
.39524 .31097 Mdot
.39714 .43987 Mdot
.39905 .2323 Mdot
.40095 .39846 Mdot
.40286 .35022 Mdot
.40476 .44276 Mdot
.40667 .31864 Mdot
.40857 .30427 Mdot
.41048 .31075 Mdot
.41238 .32109 Mdot
.41429 .35951 Mdot
.41619 .42851 Mdot
.4181 .37882 Mdot
.42 .33029 Mdot
.4219 .26783 Mdot
.42381 .27162 Mdot
.42571 .33242 Mdot
.42762 .3364 Mdot
.42952 .26175 Mdot
.43143 .26362 Mdot
.43333 .35549 Mdot
.43524 .34535 Mdot
.43714 .36489 Mdot
.43905 .28618 Mdot
.44095 .28134 Mdot
.44286 .31572 Mdot
.44476 .26952 Mdot
.44667 .39515 Mdot
.44857 .27369 Mdot
.45048 .2835 Mdot
.45238 .34346 Mdot
.45429 .36587 Mdot
.45619 .3346 Mdot
.4581 .34573 Mdot
.46 .39854 Mdot
.4619 .33089 Mdot
.46381 .40415 Mdot
.46571 .31841 Mdot
.46762 .30303 Mdot
.46952 .28166 Mdot
.47143 .43062 Mdot
.47333 .36592 Mdot
.47524 .35062 Mdot
.47714 .26644 Mdot
.47905 .33579 Mdot
.48095 .40085 Mdot
.48286 .25709 Mdot
.48476 .38684 Mdot
.48667 .34147 Mdot
.48857 .3269 Mdot
.49048 .39075 Mdot
.49238 .24895 Mdot
.49429 .42009 Mdot
.49619 .29142 Mdot
.4981 .29187 Mdot
.5 .33438 Mdot
.5019 .24702 Mdot
.50381 .38058 Mdot
.50571 .24251 Mdot
.50762 .32494 Mdot
.50952 .27843 Mdot
.51143 .27265 Mdot
.51333 .28776 Mdot
.51524 .34883 Mdot
.51714 .37512 Mdot
.51905 .29882 Mdot
.52095 .43428 Mdot
.52286 .33538 Mdot
.52476 .37158 Mdot
.52667 .35051 Mdot
.52857 .38033 Mdot
.53048 .2965 Mdot
.53238 .33736 Mdot
.53429 .32715 Mdot
.53619 .27052 Mdot
.5381 .3422 Mdot
.54 .42006 Mdot
.5419 .3191 Mdot
.54381 .42156 Mdot
.54571 .38137 Mdot
.54762 .25836 Mdot
.54952 .37212 Mdot
.55143 .26352 Mdot
.55333 .33178 Mdot
.55524 .32561 Mdot
.55714 .36969 Mdot
.55905 .33525 Mdot
.56095 .24872 Mdot
.56286 .38054 Mdot
.56476 .26622 Mdot
.56667 .33857 Mdot
.56857 .2359 Mdot
.57048 .41815 Mdot
.57238 .26897 Mdot
.57429 .2716 Mdot
.57619 .32368 Mdot
.5781 .42221 Mdot
.58 .33525 Mdot
.5819 .32224 Mdot
.58381 .46958 Mdot
.58571 .26296 Mdot
.58762 .41966 Mdot
.58952 .2563 Mdot
.59143 .3195 Mdot
.59333 .26044 Mdot
.59524 .27024 Mdot
.59714 .41623 Mdot
.59905 .41249 Mdot
.60095 .43569 Mdot
.60286 .37017 Mdot
.60476 .349 Mdot
.60667 .39598 Mdot
.60857 .41712 Mdot
.61048 .32308 Mdot
.61238 .28008 Mdot
.61429 .36114 Mdot
.61619 .30497 Mdot
.6181 .26961 Mdot
.62 .27497 Mdot
.6219 .24744 Mdot
.62381 .23868 Mdot
.62571 .25539 Mdot
.62762 .31791 Mdot
.62952 .28887 Mdot
.63143 .31484 Mdot
.63333 .44288 Mdot
.63524 .28299 Mdot
.63714 .35315 Mdot
.63905 .22431 Mdot
.64095 .43759 Mdot
.64286 .26955 Mdot
.64476 .25803 Mdot
.64667 .36402 Mdot
.64857 .36623 Mdot
.65048 .3539 Mdot
.65238 .30044 Mdot
.65429 .31639 Mdot
.65619 .24842 Mdot
.6581 .41022 Mdot
.66 .2885 Mdot
.6619 .31297 Mdot
.66381 .30554 Mdot
.66571 .2639 Mdot
.66762 .3214 Mdot
.66952 .39701 Mdot
.67143 .30105 Mdot
.67333 .38166 Mdot
.67524 .35027 Mdot
.67714 .35487 Mdot
.67905 .34119 Mdot
.68095 .29334 Mdot
.68286 .4014 Mdot
.68476 .26571 Mdot
.68667 .44433 Mdot
.68857 .34257 Mdot
.69048 .41563 Mdot
.69238 .3886 Mdot
.69429 .33866 Mdot
.69619 .32772 Mdot
.6981 .40316 Mdot
.7 .40444 Mdot
.7019 .26449 Mdot
.70381 .41959 Mdot
.70571 .36718 Mdot
.70762 .29783 Mdot
.70952 .42011 Mdot
.71143 .35377 Mdot
.71333 .406 Mdot
.71524 .44984 Mdot
.71714 .39571 Mdot
.71905 .38654 Mdot
.72095 .34675 Mdot
.72286 .27452 Mdot
.72476 .32089 Mdot
.72667 .37181 Mdot
.72857 .39789 Mdot
.73048 .43136 Mdot
.73238 .31675 Mdot
.73429 .29584 Mdot
.73619 .27973 Mdot
.7381 .25719 Mdot
.74 .36974 Mdot
.7419 .36398 Mdot
.74381 .39976 Mdot
.74571 .23285 Mdot
.74762 .33037 Mdot
.74952 .34705 Mdot
.75143 .24798 Mdot
.75333 .34071 Mdot
.75524 .34785 Mdot
.75714 .34779 Mdot
.75905 .2343 Mdot
.76095 .23995 Mdot
.76286 .28544 Mdot
.76476 .23658 Mdot
.76667 .27904 Mdot
.76857 .31843 Mdot
.77048 .34426 Mdot
.77238 .27038 Mdot
.77429 .29902 Mdot
.77619 .30226 Mdot
.7781 .2542 Mdot
.78 .35284 Mdot
.7819 .38164 Mdot
.78381 .36564 Mdot
.78571 .29656 Mdot
.78762 .35016 Mdot
.78952 .25347 Mdot
.79143 .37099 Mdot
.79333 .27581 Mdot
.79524 .275 Mdot
.79714 .31197 Mdot
.79905 .28089 Mdot
.80095 .41779 Mdot
.80286 .40682 Mdot
.80476 .34698 Mdot
.80667 .33886 Mdot
.80857 .35449 Mdot
.81048 .34614 Mdot
.81238 .2262 Mdot
.81429 .34201 Mdot
.81619 .40089 Mdot
.8181 .3237 Mdot
.82 .34236 Mdot
.8219 .27876 Mdot
.82381 .35675 Mdot
.82571 .26208 Mdot
.82762 .35307 Mdot
.82952 .32583 Mdot
.83143 .28433 Mdot
.83333 .4402 Mdot
.83524 .27908 Mdot
.83714 .38269 Mdot
.83905 .26045 Mdot
.84095 .24046 Mdot
.84286 .29861 Mdot
.84476 .33729 Mdot
.84667 .22945 Mdot
.84857 .46462 Mdot
.85048 .40174 Mdot
.85238 .23738 Mdot
.85429 .39521 Mdot
.85619 .30729 Mdot
.8581 .40907 Mdot
.86 .39277 Mdot
.8619 .32741 Mdot
.86381 .39005 Mdot
.86571 .33422 Mdot
.86762 .33869 Mdot
.86952 .27493 Mdot
.87143 .2941 Mdot
.87333 .38092 Mdot
.87524 .3478 Mdot
.87714 .4556 Mdot
.87905 .32121 Mdot
.88095 .37959 Mdot
.88286 .34625 Mdot
.88476 .29736 Mdot
.88667 .32282 Mdot
.88857 .31928 Mdot
.89048 .42908 Mdot
.89238 .29872 Mdot
.89429 .36045 Mdot
.89619 .4014 Mdot
.8981 .3172 Mdot
.9 .42214 Mdot
.9019 .2933 Mdot
.90381 .24522 Mdot
.90571 .47369 Mdot
.90762 .29216 Mdot
.90952 .40667 Mdot
.91143 .24058 Mdot
.91333 .2687 Mdot
.91524 .26338 Mdot
.91714 .30893 Mdot
.91905 .29018 Mdot
.92095 .41633 Mdot
.92286 .3786 Mdot
.92476 .25161 Mdot
.92667 .32421 Mdot
.92857 .28108 Mdot
.93048 .35766 Mdot
.93238 .36622 Mdot
.93429 .28633 Mdot
.93619 .38393 Mdot
.9381 .36279 Mdot
.94 .32145 Mdot
.9419 .27416 Mdot
.94381 .38608 Mdot
.94571 .359 Mdot
.94762 .32655 Mdot
.94952 .26405 Mdot
.95143 .43046 Mdot
.95333 .36361 Mdot
.95524 .30624 Mdot
.95714 .28503 Mdot
.95905 .27793 Mdot
.96095 .29217 Mdot
.96286 .29302 Mdot
.96476 .28615 Mdot
.96667 .39573 Mdot
.96857 .2761 Mdot
.97048 .4035 Mdot
.97238 .29956 Mdot
.97429 .40568 Mdot
.97619 .37533 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0<;ooooo0_l0001hooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0<;ooooo0_l0000fooooo`;o0000@?ooool000Co00000_ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo0?[ooooo0_l00009ooooo`;o0000=Oooool000Kooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0001?ooooo0_l0
000kooooo`;o00003?ooool2o`0001Gooooo0_l0001]ooooo`;o00007oooool2o`0003Gooooo0006
ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`04ooooo`;o00000oooool2o`0000Sooooo
0_l0000aooooo`;o00002?ooool2o`0000cooooo0_l0000Eooooo`;o0000=?ooool2o`0003Oooooo
0_l00003ooooo`Co0000Coooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`;o0000
00?oooooo`000?l000000_l0000kooooo`;o0000Hoooool2o`00013ooooo0_l0000Zooooo`Co0000
6_ooool2o`0003?ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zj
oooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`;o
00001_ooool2o`0008Kooooo0_l0000Tooooo`;o0000:_ooool2o`0001Sooooo0_l00002ooooo`;o
00004Oooool2o`00023ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So
410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo00_ooooo0_l00002oooo
o`;o0000Boooool2o`0003Wooooo0_l0001Zooooo`;o00004_ooool2o`000003ooooool0003o0000
023ooooo000Yooooo`;o00003?ooool2o`0001_ooooo0_l0000Looooo`;o00005?ooool2o`0003Go
oooo0_l000000ooooooo0000o`00000Aooooo`;o00004_ooool2o`0000Wooooo0_l0000Looooo`;o
0000;oooool2o`0002?ooooo000Yooooo`03o`000?oooooooooo00Sooooo0_l0000Nooooo`;o0000
7?ooool2o`0001gooooo0_l00003ooooo`;o00001_ooool2o`0001oooooo0_l000000ooooooo0000
o`00000Aooooo`;o00004_ooool2o`0000Wooooo0_l0000Looooo`;o0000=_ooool2o`0001cooooo
000Yooooo`03o`000?oooooooooo00Sooooo0_l0000Fooooo`;o0000=_ooool2o`000003ooooool0
003o000000;ooooo0_l00004ooooo`;o00000oooool2o`0000Kooooo0_l0001:ooooo`;o0000;ooo
ool2o`000003ooooool0003o000002[ooooo0_l0000Looooo`00:Oooool00ol0003oooooooooo`07
ooooo`;o00005oooool2o`0000[ooooo0_l0000<ooooo`;o00006Oooool2o`000004ooooool0003o
0000ooooo`;o00000_ooool2o`0002oooooo0_l0000Cooooo`;o00002oooool2o`0000[ooooo0_l0
0004ooooo`;o00007?ooool2o`0000_ooooo0_l000000ooooooo0000o`000018ooooo`00:Oooool0
0ol0003oooooooooo`02ooooo`;o00000oooool2o`00023ooooo0_l000000ooooooo0000o`00000<
ooooo`;o00000_ooool2o`0000Wooooo0_l0000:ooooo`;o0000:?ooool2o`0000oooooo0_l0000C
ooooo`;o00002oooool3o`0000oooooo0_l0000Looooo`;o00006_ooool2o`0000;ooooo0_l0000h
ooooo`00:Oooool2o`0000?ooooo0_l0000Eooooo`;o00003_ooool2o`0001?ooooo1?l00007oooo
o`;o00004Oooool2o`00027ooooo0_l0000Uooooo`;o00002Oooool4o`0001Kooooo0_l00009oooo
o`;o00009_ooool2o`0000;ooooo0_l0000Gooooo`;o00002Oooool2o`0001Cooooo000Yooooo`03
o`000?oooooooooo00gooooo0_l0000:ooooo`;o00002?ooool2o`0000;ooooo0_l0000Eooooo`Co
00001_ooool2o`0000Cooooo0_l000000ooooooo0000o`000009ooooo`;o00007_ooool2o`000003
ooooool0003o000000gooooo0_l0000Fooooo`;o00000_ooool2o`0000Gooooo0_l0000Hooooo`;o
00001?ooool2o`0000?ooooo0_l00013ooooo`;o00002Oooool2o`0001Cooooo000Yooooo`03o`00
0?oooooooooo00gooooo0_l0000Dooooo`;o00000_ooool2o`0000Oooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;o00000_oo
ool3o`000003ooooool0003o000000;o000000?oooooo`000?l000006_ooool5o`000008ooooool0
003o0000onk^k_lb<S;o0000oc8b<_o^k^h2ooooo`;o000000Co<S8bo`000?lb<S;ok^k^0_ooool2
o`0000Sooooo0_l0000Aooooo`;o00001oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o0000onk^
kP03ooooo`05onk^k_l0003o0000oc8b<_o^k^h01?ooool2o`0000cooooo0_l0000Fooooo`;o0000
00Wo410@ooooool0003o0000onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^01kooooo0_l00009ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool00ol0003o
ooooooooo`0Uooooo`;o00002oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00;o00000oooool2o`000003ooooool0003o
000001oooooo00KoV9RHob4Q8Oo^k^koooooodA4A?ooool2o`000005ogMgMonHV9SooooooiRHV?mg
MgL00oooool2o`000003oooooonHV9SoMgMg00;ooooo0ol0000Booooo`;o00001_ooool2o`0000Oo
oooo00?o410@okZj^_ooool00_l00003ooooo`05ogMgMonHV9So0000o`000?mgMgL00oooool01Omg
MgOo0000o`000?nHV9SoMgMg00Cooooo0_l0000Hooooo`;o00002oooool00ol0003oooooooooo`02
o`000005ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo
0_l00007ooooo`;o00000oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wooooo00Co0000ooooool0003o00009?oo
ool2o`0000_ooooo0ol00002ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooo
o`000?l0003o410@01Gooooo0_l0000Cooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooo
oooooooooa0@4003ooooo`;o00000_ooool01?l@413oooooooooooooool2o`0001;ooooo0_l0000B
ooooo`;o00000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@ooooool0003o0000
oa0@400Nooooo`;o00002?ooool5o`0000?ooooo00Go410@oooooooooooooooooa0@4002o`000003
ooooool@413ooooo00;ooooo00?o410@ooooooooool03_ooool2o`0001Gooooo0_l00004ooooo`03
o`000?oooooooooo00;o00000_ooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooo
ooooool00Oooool002Wooooo1?l0000@ooooo`;o00007oooool3o`0000;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooo000000;o00004?ooool2o`0000?ooooo0_l0000=oooo
o`;o00000_ooool2o`000004oooooonHV9So8B4Qonk^kP?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000005_ooool2o`0001?ooooo00?oZJVYoa0@4?ooool0
0_ooool01Ol0003ooooooooooooooooo000000?ooooo1Ol0000Rooooo`;o00001?ooool00om4A4Co
gMgMooooo`03o`0000;ooooo00Co0000oooooooooooooooo0ol000000ooooooo0000ooooo`02oooo
o`04o`000?oooooo0000o`0000;ooooo0_l00009ooooo`;o00006_ooool01?mgMgOo0000o`000?oo
ool2o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo007ooooo
000Yooooo`03o`000?oooooooooo017ooooo0_l0000Oooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000004?ooool2o`0000_o
oooo0_l00005ooooo`;o00000_ooool2o`0000;ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Co0000oooooooooooooooo0ol000000ooooooo0000o`000005
ooooo`;o00002_ooool2o`0001;ooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooo
oooo000000?ooooo0_l00002ooooo`03o`000?oooooooooo00;o00007_ooool2o`0000Cooooo00?o
gMgMoeEEEOooool00ol00002ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000?ooooo
00Co0000ooooool0003o00000_ooool2o`0001cooooo0_l00004ooooo`04o`000?lQ8B7o0000oc8b
<P;o000000?oooooo`000?ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool00Oooool002Wooooo00?o0000ooooooooool08?ooool2o`00013ooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
400Mooooo`;o00002oooool2o`000003ooooool0003ooooo00;ooooo00Go410@oooooooooooooooo
oa0@4003ooooo`05oa0@4?ooooooooooooooool@41000_l000000ooooooo0000o`000005ooooo`;o
00007oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@00;ooooo0_l0000Uooooo`04ogMgMoo<c<co0000o`0000?ooooo00Go
410@oooooooooooooooooa0@4002ooooo`;o00000oooool00ol@413oooooooooo`02ooooo`;o0000
7Oooool4o`0000;ooooo00?o0000ooooooooool00_l000000ooooooo0000o`000003ooooo`05oa0@
4?ooooooooooooooool@41000oooool00ol@413oooooooooo`01ooooo`00:Oooool00ol0003ooooo
ooooo`0Pooooo`Co00001oooool2o`0000Gooooo00?o0000ooooooooool00_ooool01OmgMgOo0000
o`000?nHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Yooooo`?o000000?oV9RHoa0@
4?ooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`02o`0001Kooooo0_l0000>ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02o`0000Sooooo0_l0000Moooo
o`04onk^k_m4A4Co0000o`0000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01?ooool2o`0001oooooo0_l00002ooooo`03o`000?oooooooooo00;o0000
00Ooooooo`000?l0003oV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`00:Oooool00ol0003oooooooooo`02o`00023ooooo0_l00007ooooo`;o00000oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_l0003o0000o`000?o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^02Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo0ol00003ooooo`;o00003_ooool01OnY
ZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00_l00008ooooo`;o00007_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01cooooo0_l00002oooo
o`;o00001oooool4o`000008ooooool0003o0000onk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool002Wooooo0_l000000ooooooo0000o`00000:ooooo`;o0000
:oooool2o`0000cooooo0_l0001;ooooo`?o0000>Oooool2o`0000oooooo0_l0000Zooooo`;o0000
2?ooool3o`0000;ooooo0_l0000<ooooo`;o00004?ooool002Wooooo00?o0000ooooooooool01Ooo
ool2o`0000Gooooo0_l0000_ooooo`;o00002?ooool2o`0005?ooooo0_l000000ooooooo0000o`00
000_ooooo`;o00001_ooool2o`0000Oooooo0_l0000;ooooo`;o000000?oooooo`000?l000004Ooo
ool2o`0000Oooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Sooooo`00:Ooo
ool00ol0003oooooooooo`05ooooo`;o00003_ooool2o`0002Kooooo0_l0000_ooooo`;o000000?o
ooooo`000?l00000:Oooool2o`000003ooooool0003o000002Gooooo0_l00005ooooo`;o00002Ooo
ool2o`0001Cooooo0_l000000ooooooo0000o`00000Aooooo`;o00002oooool2o`000003ooooool0
003o000001Oooooo0_l0000=ooooo`00:Oooool01?l0003oooooooooooooool2o`0001;ooooo0_l0
00000ooooooo0000o`00000<ooooo`;o00006oooool2o`0001Kooooo0_l0000Aooooo`;o000000?o
ooooo`000?l000001Oooool2o`00017ooooo0_l0000^ooooo`;o00002Oooool2o`0000;ooooo0_l0
00000ooooooo0000o`00000Oooooo`;o0000?Oooool2o`0000gooooo000Yooooo`04o`000?oooooo
ooooooooo`;o00005Oooool2o`0000cooooo0_l00007ooooo`;o00004_ooool2o`0001Kooooo0_l0
000Kooooo`;o00004Oooool2o`0002kooooo0_l0000=ooooo`;o0000??ooool2o`0001kooooo0_l0
000Booooo`008Oooooooo`0004Co00001?ooool002Wooooo0ol00009ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool01?ooool2o`0000;ooooo0_l00004ooooo`;o00000_ooool2o`00
0003ooooool0003ooooo00?ooooo0_l000000ooooooo0000o`000002ooooo`?o00002_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`06ooooo`;o00000_ooool3o`0000Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`08ooooo`;o00001oooool2o`0000;ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_l00007oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02oooo
o`;o00001Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo000Yooooo`03
o`000?oooooooooo01gooooo0_l00002ooooo`;o00001?ooool6o`0000Wooooo0_l00002ooooo`?o
0000>oooool00ol0003oooooooooo`08ooooo`;o0000<?ooool00ol0003oooooooooo`06ooooo`Co
00001Oooool4o`0001Gooooo0_l0000@ooooo`03o`000?oooooooooo00;o00007_ooool2o`0001So
oooo00?o0000ooooooooool02_ooool002Wooooo00?o0000ooooooooool0:?ooool4o`0000Sooooo
0_l00011ooooo`Co00002?ooool2o`0000Gooooo0_l0000Gooooo`;o00003_ooool2o`0000Wooooo
0_l00007ooooo`;o00005Oooool4o`0000[ooooo0_l0000Qooooo`;o000000Coooooo`000?l0003o
oooo0_l0000Uooooo`00:Oooool00ol0003oooooooooo`03ooooo`;o00001oooool2o`0002Kooooo
0_l0000=ooooo`;o00005?ooool2o`0000Wooooo0_l0000Aooooo`Co00003oooool2o`0001Oooooo
0_l00009ooooo`Co000000?oooooo`000?l000001?ooool2o`00013ooooo0_l0000Aooooo`;o0000
3?ooool2o`0000kooooo0_l0000Aooooo`;o000000?oooooo`000?l000002oooool2o`0000;ooooo
0_l0000Gooooo`00:Oooool2o`0000Cooooo0_l00007ooooo`;o00001_ooool2o`0002Oooooo0_l0
0004ooooo`;o00005?ooool2o`0000Wooooo0_l00005ooooo`;o00009Oooool2o`0000Cooooo0_l0
0006ooooo`;o00001Oooool2o`0000Gooooo1?l00007ooooo`;o00004?ooool2o`0002oooooo0_l0
00000ooooooo0000o`000009ooooo`;o00001_ooool2o`0000_ooooo0_l00002ooooo`Co00005Ooo
ool002Wooooo00?o0000ooooooooool05?ooool2o`0000Kooooo0_l0000Oooooo`;o00003_ooool2
o`0000Gooooo0_l0000Eooooo`;o00003oooool2o`0001Cooooo0_l00004ooooo`;o00001_ooool2
o`0000Gooooo0_l0000[ooooo`;o00003oooool2o`0001Sooooo0_l00009ooooo`;o00006Oooool2
o`0001Gooooo000Yooooo`03o`000?oooooooooo00Kooooo0_l0000@ooooo`;o00000_ooool2o`00
01Oooooo0_l00008ooooo`;o00003?ooool2o`0000Gooooo0_l0000@ooooo`;o00005?ooool3o`00
00[ooooo0_l0000Looooo`;o0000:oooool2o`0000oooooo0_l0001Eooooo`00:Oooool00ol0003o
ooooooooo`06ooooo`;o00000_ooool2o`0000cooooo0_l0000Kooooo`;o00002?ooool2o`0002Go
oooo0_l0000Eooooo`?o00001oooool4o`0000Cooooo0_l00004ooooo`;o00001_ooool2o`0000So
oooo0ol00005ooooo`;o0000F_ooool2o`0002oooooo000Yooooo`03o`000?oooooooooo00[ooooo
0_l0000Zooooo`;o0000=Oooool2o`0000oooooo0_l00007ooooo`;o00001_ooool2o`0000Cooooo
0_l00006ooooo`;o000000?oooooo`000?l000001_ooool2o`000003ooooool0003o000000;ooooo
0_l0000Sooooo`;o00008_ooool2o`0000[ooooo0_l00005ooooo`?o0000;_ooool002Wooooo0_l0
000gooooo`;o0000=Oooool2o`0002;ooooo0_l0000=ooooo`Co00001oooool2o`0002;ooooo0_l0
00000ooooooo0000o`000002o`00017ooooo0_l0000?ooooo`Ko00001_ooool2o`0000Kooooo0_l0
000^ooooo`00:Oooool00ol0003oooooooooo`0Fooooo`;o00002_ooool2o`0000gooooo0_l0000W
ooooo`;o00001?ooool2o`0000Gooooo0_l0000Hooooo`;o00000oooool4o`0000Oooooo0_l0000?
ooooo`;o0000:oooool2o`000003ooooool0003o000001?ooooo0_l00003ooooo`;o00002oooool5
o`0003kooooo000Yooooo`03o`000?oooooooooo00gooooo0_l00007ooooo`;o00002_ooool2o`00
00[ooooo0_l000000ooooooo0000o`00000Uooooo`Co00001?ooool2o`0000Gooooo0_l0000Hoooo
o`;o00000oooool4o`00013ooooo0_l0000Kooooo`;o00008oooool2o`0000Sooooo1?l00002oooo
o`;o00002Oooool4o`0001?ooooo1?l0000Zooooo`00:Oooool00ol0003oooooooooo`0=ooooo`;o
00007_ooool3o`0000Sooooo0_l0000Nooooo`;o00001Oooool2o`0001Gooooo0_l0000Eooooo`;o
00002oooool2o`0000;ooooo0_l0000Gooooo`;o00005Oooool2o`0000cooooo0_l00008ooooo`Co
00002?ooool2o`0000?ooooo0_l0000Eooooo`Co0000:_ooool002Wooooo00?o0000ooooooooool0
2_ooool2o`00027ooooo0_l00009ooooo`;o00009Oooool2o`0000?ooooo0_l0000@ooooo`;o0000
5Oooool2o`0000oooooo0_l0000Qooooo`;o00000oooool2o`0000Kooooo0_l00009ooooo`;o0000
5?ooool2o`000003ooooool0003o000000Gooooo0_l00004ooooo`;o0000>oooool002Wooooo0_l0
000;ooooo`;o00004?ooool2o`0000oooooo0_l000000ooooooo0000o`000002o`0001_ooooo0_l0
000Cooooo`;o00001_ooool2o`0001;ooooo0_l0000oooooo`;o00000oooool2o`0000Kooooo0_l0
0009ooooo`;o00005?ooool2o`0000Sooooo0_l00003ooooo`?o00007oooool2o`0001[ooooo000Y
ooooo`;o00007Oooool2o`0000oooooo0_l000000ooooooo0000o`000002o`0001_ooooo0_l0000B
ooooo`;o00001oooool2o`0000cooooo0_l00004ooooo`;o0000>?ooool2o`0004;ooooo0_l0000D
ooooo`;o00002_ooool2o`0000?ooooo0_l0000Eooooo`00:Oooool01?l0003oooooo`000?l0000a
ooooo`;o00007?ooool2o`00017ooooo0_l00002ooooo`;o00004Oooool2o`0003kooooo0_l00009
ooooo`;o00007?ooool2o`0002oooooo0_l0000<ooooo`;o000000?oooooo`000?l000000_l0000C
ooooo`00:Oooool01?l0003oooooo`000?l0000aooooo`;o00007?ooool2o`0001Gooooo0_l00008
ooooo`;o00003_ooool2o`0000Cooooo0_l00004ooooo`;o0000=_ooool2o`00017ooooo0_l00009
ooooo`;o00003?ooool2o`0002gooooo1?l00003ooooo`;o00004oooool002Wooooo00?o0000oooo
ooooool06_ooool2o`00047ooooo0_l0000Booooo`;o00003_ooool2o`0000Cooooo0_l00004oooo
o`;o00006Oooool2o`0000cooooo0_l0000=ooooo`;o00004Oooool2o`0000Wooooo0_l0000<oooo
o`Co0000:oooool2o`0001[ooooo000Yooooo`;o00006oooool2o`00047ooooo0_l0000nooooo`;o
00001_ooool2o`000003ooooool0003o000000cooooo0_l0000Vooooo`;o00000oooool2o`0000ko
oooo0_l00017ooooo`00:Oooool00ol0003oooooooooo`0Jooooo`;o00007_ooool2o`0005oooooo
1?l00006ooooo`;o0000=oooool2o`0004oooooo0_l0000;ooooo`001_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Go
oooo00?o0000ooooooooool04_ooool2o`0000?ooooo0_l000000ooooooo0000o`00000Nooooo`;o
0000?oooool2o`0001kooooo0_l00002ooooo`;o0000Koooool2o`0000_ooooo0_l0000@ooooo`;o
00002oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Boooo
o`;o000000?oooooo`000?l000000_l0000eooooo`;o00004_ooool2o`0001Oooooo0_l0000Joooo
o`;o00001_ooool2o`0000?ooooo0_l00004ooooo`;o00008Oooool2o`00027ooooo0_l0000@oooo
o`;o00002Oooool2o`000003ooooool0003o000000_ooooo0_l0000Mooooo`001_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01Gooooo0_l00006ooooo`?o00000oooool2o`0000Gooooo0_l0000Roooo
o`;o00004_ooool2o`0003?ooooo0_l0000;ooooo`;o00001?ooool2o`00027ooooo0_l0000=oooo
o`;o00004_ooool2o`00013ooooo0_l00009ooooo`;o00004oooool4o`0001Kooooo0006ooooo`05
o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo
00Cooooo0ol0000Dooooo`;o000000?oooooo`000?l000001?ooool3o`0000?ooooo0_l00005oooo
o`;o0000I?ooool2o`00047ooooo0_l00007ooooo`;o0000A?ooool4o`0001Kooooo0006ooooo`05
o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Dooooo`;o000000?oooooo`000?l00000;oooool2
o`0000?ooooo0_l0000Pooooo`;o00007oooool4o`0003oooooo0_l0000dooooo`?o0000<?ooool0
00Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01oooool2o`00013ooooo0_l0000[ooooo`;o00002_ooool2o`0000?ooooo0_l0000L
ooooo`;o00000_ooool2o`0001?ooooo0_l0000<ooooo`;o0000Aoooool2o`0002[ooooo1Ol0000O
ooooo`;o00003oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`;o00003oooool3o`0001gooooo0_l0
000<ooooo`;o00003Oooool2o`0000Kooooo0_l0000<ooooo`;o00002?ooool2o`0000Wooooo0_l0
000<ooooo`;o00000oooool2o`0002gooooo0_l0000Booooo`;o00003Oooool2o`0000;ooooo0_l0
000Vooooo`;o00008_ooool2o`0000oooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo00kooooo
0_l0000Nooooo`;o00006oooool2o`0000Kooooo0_l00002ooooo`;o00002?ooool2o`0001?ooooo
0_l0000Aooooo`;o00001?ooool2o`0002Oooooo0_l0000Booooo`;o00000_ooool2o`0000gooooo
0_l00003ooooo`;o00005Oooool2o`0000Wooooo0_l0000=ooooo`;o00009Oooool002Wooooo0_l0
0003ooooo`Co0000COooool2o`0000;ooooo0_l0000aooooo`;o00000oooool2o`0003oooooo0_l0
0003ooooo`?o00003?ooool2o`0001Gooooo0_l00009ooooo`;o00003Oooool2o`0001Kooooo0_l0
000=ooooo`00:Oooool00ol0003oooooooooo`02ooooo`Go00005?ooool2o`0002Cooooo0_l0000@
ooooo`;o0000=Oooool2o`0004Wooooo0ol00002ooooo`;o00006oooool2o`00023ooooo0_l0000B
ooooo`?o00003?ooool002Wooooo00?o0000ooooooooool01Oooool2o`0000;ooooo0_l00005oooo
o`;o00002Oooool2o`0001kooooo0_l00004ooooo`;o0000QOooool2o`00013ooooo0_l0000Koooo
o`;o00004?ooool2o`0000kooooo0_l0000Cooooo`;o00003?ooool002Wooooo00?o0000oooooooo
ool02Oooool2o`0000Gooooo0_l0000Yooooo`;o00005?ooool2o`0006;ooooo0_l0000Aooooo`;o
0000?oooool2o`00037ooooo000Yooooo`03o`000?oooooooooo01;ooooo0_l0000mooooo`;o0000
7Oooool2o`0004?ooooo0_l000000ooooooo0000o`00000Iooooo`;o0000B?ooool2o`0001gooooo
000Yooooo`;o00004oooool2o`0004;ooooo0_l0000>ooooo`;o00002?ooool4o`00023ooooo0_l0
000<ooooo`;o00002?ooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0001Wooooo
0_l00002ooooo`Co00006oooool2o`0002Gooooo0_l0000Mooooo`00:Oooool00ol0003ooooooooo
o`12ooooo`;o00001_ooool2o`0000[ooooo0_l0000>ooooo`;o00002_ooool2o`00023ooooo0_l0
000<ooooo`?o00001oooool4o`0000;ooooo0_l0000Sooooo`Co00006oooool2o`0001kooooo0_l0
000Tooooo`00:Oooool00ol0003oooooooooo`0Oooooo`;o00008Oooool2o`0000Kooooo0_l0001G
ooooo`;o00002Oooool2o`0006Kooooo0_l0000Tooooo`00:Oooool01?l0003oooooooooooooool2
o`0001cooooo0_l00004ooooo`;o0000Doooool2o`0009Oooooo0_l0000Wooooo`00:Oooool01?l0
003oooooooooooooool2o`0002;ooooo0_l0001Cooooo`;o00004?ooool2o`00057ooooo0_l0000b
ooooo`;o00004_ooool2o`0001?ooooo000Yooooo`;o0000A_ooool2o`0004Gooooo0_l0000>oooo
o`;o00006?ooool2o`0002Oooooo0_l00016ooooo`;o00004oooool002Wooooo00?o0000oooooooo
ool07oooool2o`0002Cooooo0_l0001Eooooo`;o00006?ooool2o`0000_ooooo0_l0001gooooo`00
:Oooool00ol0003oooooooooo`0Oooooo`;o0000<Oooool2o`0000[ooooo0_l0000Dooooo`;o0000
COooool2o`0003cooooo0_l0000iooooo`00:Oooool00ol0003oooooooooo`0@ooooo`;o00004_oo
ool2o`0000[ooooo0_l0000Cooooo`;o00002oooool2o`0000[ooooo0_l00009ooooo`;o00002Ooo
ool2o`000003ooooool0003o000004Oooooo0_l0000?ooooo`;o0000;_ooool2o`0003Wooooo000Y
ooooo`03o`000?oooooooooo013ooooo0_l0000Booooo`;o00002_ooool2o`0001?ooooo0_l0000?
ooooo`;o00002oooool2o`0000Cooooo0_l0000<ooooo`;o0000Aoooool2o`0000oooooo0_l0001Y
ooooo`00:Oooool2o`0005Oooooo0_l0000;ooooo`;o0000M_ooool2o`0005oooooo000Yooooo`03
o`000?oooooooooo0=_ooooo0_l0001Oooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
oa3ooooo0_l0000[ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0ooooool@ooooo`;o0000:oooool000ko
oooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0003ooooo
ocgooooo000>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo03Gooooo0_l0003>ooooo`;o0000=Oooool000kooooo00Go0000oooooooo
ooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0e
ooooo`;o0000>?ooool2o`0003oooooo0_l0001Cooooo`;o0000=Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0=oooool2
o`0001;ooooo0_l0000Looooo`;o00001?ooool2o`0003oooooo0_l0002:ooooo`003_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0g
ooooo`;o00004_ooool2o`0001cooooo0_l0002]ooooo`;o00008_ooool000kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`000?oooooo6_ooool2o`0002;ooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEE
EOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolmooooo`001_ooool01Ol0003o
oooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00000>oooo
o`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOo
oooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool001oooooo1?l000000ol@413oooooooooo`03ooooo`03
o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo0ol0003oooooocgooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool001oooooo00?oEEEEofIVI_l00000oooooom7ooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .27182 Mdot
.02762 .40302 Mdot
.02952 .30356 Mdot
.03143 .32851 Mdot
.03333 .33792 Mdot
.03524 .36641 Mdot
.03714 .31895 Mdot
.03905 .45105 Mdot
.04095 .32103 Mdot
.04286 .32008 Mdot
.04476 .26232 Mdot
.04667 .44732 Mdot
.04857 .29945 Mdot
.05048 .25448 Mdot
.05238 .44569 Mdot
.05429 .27792 Mdot
.05619 .33623 Mdot
.0581 .286 Mdot
.06 .31135 Mdot
.0619 .42596 Mdot
.06381 .29918 Mdot
.06571 .40161 Mdot
.06762 .39484 Mdot
.06952 .26891 Mdot
.07143 .41046 Mdot
.07333 .24809 Mdot
.07524 .30431 Mdot
.07714 .33233 Mdot
.07905 .42668 Mdot
.08095 .40189 Mdot
.08286 .27581 Mdot
.08476 .33264 Mdot
.08667 .43489 Mdot
.08857 .2511 Mdot
.09048 .32457 Mdot
.09238 .37467 Mdot
.09429 .32273 Mdot
.09619 .35464 Mdot
.0981 .42376 Mdot
.1 .44103 Mdot
.1019 .39935 Mdot
.10381 .26515 Mdot
.10571 .38554 Mdot
.10762 .32308 Mdot
.10952 .24656 Mdot
.11143 .35855 Mdot
.11333 .27616 Mdot
.11524 .26316 Mdot
.11714 .35603 Mdot
.11905 .42356 Mdot
.12095 .25223 Mdot
.12286 .40379 Mdot
.12476 .41775 Mdot
.12667 .3598 Mdot
.12857 .37776 Mdot
.13048 .38855 Mdot
.13238 .45067 Mdot
.13429 .33304 Mdot
.13619 .23247 Mdot
.1381 .23926 Mdot
.14 .35167 Mdot
.1419 .23377 Mdot
.14381 .42305 Mdot
.14571 .27909 Mdot
.14762 .41853 Mdot
.14952 .36865 Mdot
.15143 .3318 Mdot
.15333 .25794 Mdot
.15524 .35325 Mdot
.15714 .24868 Mdot
.15905 .27959 Mdot
.16095 .27475 Mdot
.16286 .32089 Mdot
.16476 .34687 Mdot
.16667 .42308 Mdot
.16857 .27549 Mdot
.17048 .41751 Mdot
.17238 .32943 Mdot
.17429 .4138 Mdot
.17619 .29628 Mdot
.1781 .25132 Mdot
.18 .398 Mdot
.1819 .33922 Mdot
.18381 .28159 Mdot
.18571 .4386 Mdot
.18762 .30724 Mdot
.18952 .34587 Mdot
.19143 .35649 Mdot
.19333 .35017 Mdot
.19524 .2587 Mdot
.19714 .40893 Mdot
.19905 .46919 Mdot
.20095 .28387 Mdot
.20286 .36551 Mdot
.20476 .26266 Mdot
.20667 .4634 Mdot
.20857 .25689 Mdot
.21048 .24512 Mdot
.21238 .40405 Mdot
.21429 .33773 Mdot
.21619 .30205 Mdot
.2181 .36848 Mdot
.22 .44783 Mdot
.2219 .34441 Mdot
.22381 .23823 Mdot
.22571 .24416 Mdot
.22762 .26387 Mdot
.22952 .27234 Mdot
.23143 .28668 Mdot
.23333 .24953 Mdot
.23524 .2773 Mdot
.23714 .32936 Mdot
.23905 .3227 Mdot
.24095 .40333 Mdot
.24286 .21703 Mdot
.24476 .32237 Mdot
.24667 .33942 Mdot
.24857 .40426 Mdot
.25048 .37895 Mdot
.25238 .34952 Mdot
.25429 .30619 Mdot
.25619 .22473 Mdot
.2581 .35752 Mdot
.26 .42642 Mdot
.2619 .24669 Mdot
.26381 .31406 Mdot
.26571 .41092 Mdot
.26762 .44319 Mdot
.26952 .35749 Mdot
.27143 .3142 Mdot
.27333 .39212 Mdot
.27524 .33512 Mdot
.27714 .44008 Mdot
.27905 .35275 Mdot
.28095 .38939 Mdot
.28286 .41943 Mdot
.28476 .32592 Mdot
.28667 .42337 Mdot
.28857 .32637 Mdot
.29048 .44141 Mdot
.29238 .44423 Mdot
.29429 .30175 Mdot
.29619 .33815 Mdot
.2981 .34054 Mdot
.3 .33397 Mdot
.3019 .41908 Mdot
.30381 .42766 Mdot
.30571 .27757 Mdot
.30762 .28444 Mdot
.30952 .36286 Mdot
.31143 .23011 Mdot
.31333 .37257 Mdot
.31524 .35269 Mdot
.31714 .2592 Mdot
.31905 .2685 Mdot
.32095 .32631 Mdot
.32286 .36394 Mdot
.32476 .41951 Mdot
.32667 .39721 Mdot
.32857 .32804 Mdot
.33048 .35577 Mdot
.33238 .28166 Mdot
.33429 .41167 Mdot
.33619 .39002 Mdot
.3381 .33069 Mdot
.34 .37882 Mdot
.3419 .27611 Mdot
.34381 .42165 Mdot
.34571 .25812 Mdot
.34762 .35499 Mdot
.34952 .35298 Mdot
.35143 .41058 Mdot
.35333 .28276 Mdot
.35524 .35006 Mdot
.35714 .33788 Mdot
.35905 .25829 Mdot
.36095 .4312 Mdot
.36286 .45736 Mdot
.36476 .33565 Mdot
.36667 .30325 Mdot
.36857 .42571 Mdot
.37048 .37736 Mdot
.37238 .43006 Mdot
.37429 .34188 Mdot
.37619 .39006 Mdot
.3781 .26317 Mdot
.38 .29851 Mdot
.3819 .43685 Mdot
.38381 .33928 Mdot
.38571 .40023 Mdot
.38762 .38974 Mdot
.38952 .24895 Mdot
.39143 .41974 Mdot
.39333 .32161 Mdot
.39524 .22325 Mdot
.39714 .4459 Mdot
.39905 .34065 Mdot
.40095 .44548 Mdot
.40286 .36343 Mdot
.40476 .47704 Mdot
.40667 .24515 Mdot
.40857 .26621 Mdot
.41048 .2684 Mdot
.41238 .28536 Mdot
.41429 .3189 Mdot
.41619 .47429 Mdot
.4181 .30921 Mdot
.42 .32168 Mdot
.4219 .35187 Mdot
.42381 .32694 Mdot
.42571 .29973 Mdot
.42762 .276 Mdot
.42952 .35543 Mdot
.43143 .33498 Mdot
.43333 .25931 Mdot
.43524 .32167 Mdot
.43714 .28369 Mdot
.43905 .34966 Mdot
.44095 .3882 Mdot
.44286 .26768 Mdot
.44476 .25144 Mdot
.44667 .44608 Mdot
.44857 .34318 Mdot
.45048 .23381 Mdot
.45238 .24776 Mdot
.45429 .27343 Mdot
.45619 .28231 Mdot
.4581 .28302 Mdot
.46 .40123 Mdot
.4619 .28276 Mdot
.46381 .44531 Mdot
.46571 .22335 Mdot
.46762 .2574 Mdot
.46952 .27724 Mdot
.47143 .47387 Mdot
.47333 .37151 Mdot
.47524 .31143 Mdot
.47714 .23614 Mdot
.47905 .35421 Mdot
.48095 .36112 Mdot
.48286 .35032 Mdot
.48476 .32573 Mdot
.48667 .23154 Mdot
.48857 .38238 Mdot
.49048 .313 Mdot
.49238 .28114 Mdot
.49429 .3485 Mdot
.49619 .26179 Mdot
.4981 .38343 Mdot
.5 .37352 Mdot
.5019 .28583 Mdot
.50381 .42239 Mdot
.50571 .35494 Mdot
.50762 .31922 Mdot
.50952 .32641 Mdot
.51143 .37103 Mdot
.51333 .25011 Mdot
.51524 .34594 Mdot
.51714 .38956 Mdot
.51905 .27313 Mdot
.52095 .44775 Mdot
.52286 .23539 Mdot
.52476 .36635 Mdot
.52667 .31091 Mdot
.52857 .29616 Mdot
.53048 .32837 Mdot
.53238 .37566 Mdot
.53429 .24416 Mdot
.53619 .26837 Mdot
.5381 .38581 Mdot
.54 .39171 Mdot
.5419 .25036 Mdot
.54381 .395 Mdot
.54571 .38479 Mdot
.54762 .31666 Mdot
.54952 .33753 Mdot
.55143 .36509 Mdot
.55333 .34646 Mdot
.55524 .25793 Mdot
.55714 .26566 Mdot
.55905 .27389 Mdot
.56095 .33247 Mdot
.56286 .42375 Mdot
.56476 .28662 Mdot
.56667 .34058 Mdot
.56857 .33209 Mdot
.57048 .44895 Mdot
.57238 .265 Mdot
.57429 .28649 Mdot
.57619 .25767 Mdot
.5781 .38917 Mdot
.58 .36483 Mdot
.5819 .23701 Mdot
.58381 .4345 Mdot
.58571 .2451 Mdot
.58762 .44731 Mdot
.58952 .25095 Mdot
.59143 .29491 Mdot
.59333 .24668 Mdot
.59524 .23433 Mdot
.59714 .36757 Mdot
.59905 .44657 Mdot
.60095 .33221 Mdot
.60286 .32801 Mdot
.60476 .38951 Mdot
.60667 .34838 Mdot
.60857 .34305 Mdot
.61048 .41176 Mdot
.61238 .26085 Mdot
.61429 .25595 Mdot
.61619 .24724 Mdot
.6181 .28601 Mdot
.62 .36499 Mdot
.6219 .32008 Mdot
.62381 .32555 Mdot
.62571 .24383 Mdot
.62762 .32586 Mdot
.62952 .24184 Mdot
.63143 .24488 Mdot
.63333 .42789 Mdot
.63524 .32518 Mdot
.63714 .42817 Mdot
.63905 .30966 Mdot
.64095 .35824 Mdot
.64286 .2731 Mdot
.64476 .3443 Mdot
.64667 .29388 Mdot
.64857 .41812 Mdot
.65048 .29992 Mdot
.65238 .26553 Mdot
.65429 .30957 Mdot
.65619 .28291 Mdot
.6581 .45001 Mdot
.66 .38099 Mdot
.6619 .26257 Mdot
.66381 .38236 Mdot
.66571 .30276 Mdot
.66762 .28644 Mdot
.66952 .40242 Mdot
.67143 .37144 Mdot
.67333 .37968 Mdot
.67524 .28009 Mdot
.67714 .3045 Mdot
.67905 .43485 Mdot
.68095 .24868 Mdot
.68286 .3853 Mdot
.68476 .28266 Mdot
.68667 .41594 Mdot
.68857 .28905 Mdot
.69048 .42033 Mdot
.69238 .40264 Mdot
.69429 .32449 Mdot
.69619 .36307 Mdot
.6981 .30058 Mdot
.7 .44789 Mdot
.7019 .24342 Mdot
.70381 .38619 Mdot
.70571 .3177 Mdot
.70762 .24376 Mdot
.70952 .4087 Mdot
.71143 .37642 Mdot
.71333 .44812 Mdot
.71524 .38069 Mdot
.71714 .32247 Mdot
.71905 .44169 Mdot
.72095 .42497 Mdot
.72286 .38318 Mdot
.72476 .31309 Mdot
.72667 .36369 Mdot
.72857 .44398 Mdot
.73048 .44941 Mdot
.73238 .31884 Mdot
.73429 .23566 Mdot
.73619 .25411 Mdot
.7381 .34301 Mdot
.74 .29118 Mdot
.7419 .25944 Mdot
.74381 .35759 Mdot
.74571 .28717 Mdot
.74762 .40311 Mdot
.74952 .39843 Mdot
.75143 .2587 Mdot
.75333 .39676 Mdot
.75524 .42429 Mdot
.75714 .22674 Mdot
.75905 .32786 Mdot
.76095 .30379 Mdot
.76286 .27204 Mdot
.76476 .34625 Mdot
.76667 .35302 Mdot
.76857 .30394 Mdot
.77048 .42415 Mdot
.77238 .24542 Mdot
.77429 .26544 Mdot
.77619 .34444 Mdot
.7781 .27904 Mdot
.78 .32391 Mdot
.7819 .28153 Mdot
.78381 .27103 Mdot
.78571 .2245 Mdot
.78762 .42689 Mdot
.78952 .27397 Mdot
.79143 .4504 Mdot
.79333 .25191 Mdot
.79524 .26061 Mdot
.79714 .25195 Mdot
.79905 .31419 Mdot
.80095 .45064 Mdot
.80286 .44795 Mdot
.80476 .30031 Mdot
.80667 .31255 Mdot
.80857 .33545 Mdot
.81048 .32782 Mdot
.81238 .28913 Mdot
.81429 .36582 Mdot
.81619 .33501 Mdot
.8181 .33896 Mdot
.82 .35311 Mdot
.8219 .32303 Mdot
.82381 .36014 Mdot
.82571 .26333 Mdot
.82762 .33922 Mdot
.82952 .32814 Mdot
.83143 .22715 Mdot
.83333 .44118 Mdot
.83524 .28768 Mdot
.83714 .33908 Mdot
.83905 .26419 Mdot
.84095 .30097 Mdot
.84286 .24804 Mdot
.84476 .35421 Mdot
.84667 .33384 Mdot
.84857 .4739 Mdot
.85048 .36669 Mdot
.85238 .25528 Mdot
.85429 .34277 Mdot
.85619 .33417 Mdot
.8581 .33022 Mdot
.86 .44241 Mdot
.8619 .26528 Mdot
.86381 .40138 Mdot
.86571 .43076 Mdot
.86762 .3192 Mdot
.86952 .27751 Mdot
.87143 .25225 Mdot
.87333 .29687 Mdot
.87524 .27777 Mdot
.87714 .47597 Mdot
.87905 .27324 Mdot
.88095 .33196 Mdot
.88286 .26608 Mdot
.88476 .26027 Mdot
.88667 .32109 Mdot
.88857 .34761 Mdot
.89048 .45084 Mdot
.89238 .32916 Mdot
.89429 .41779 Mdot
.89619 .39512 Mdot
.8981 .24031 Mdot
.9 .40394 Mdot
.9019 .23632 Mdot
.90381 .29429 Mdot
.90571 .44911 Mdot
.90762 .34146 Mdot
.90952 .44934 Mdot
.91143 .35276 Mdot
.91333 .27031 Mdot
.91524 .24432 Mdot
.91714 .24791 Mdot
.91905 .35783 Mdot
.92095 .41998 Mdot
.92286 .30775 Mdot
.92476 .30084 Mdot
.92667 .36257 Mdot
.92857 .24938 Mdot
.93048 .24221 Mdot
.93238 .38855 Mdot
.93429 .27651 Mdot
.93619 .37686 Mdot
.9381 .30851 Mdot
.94 .31265 Mdot
.9419 .26875 Mdot
.94381 .35716 Mdot
.94571 .38997 Mdot
.94762 .29269 Mdot
.94952 .26573 Mdot
.95143 .37119 Mdot
.95333 .33619 Mdot
.95524 .23928 Mdot
.95714 .34445 Mdot
.95905 .33959 Mdot
.96095 .324 Mdot
.96286 .21861 Mdot
.96476 .32255 Mdot
.96667 .40273 Mdot
.96857 .2373 Mdot
.97048 .34095 Mdot
.97238 .34973 Mdot
.97429 .42523 Mdot
.97619 .43819 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l00014ooooo`;o0000iOooool2
o`00013ooooo000Yooooo`03o`000?oooooooooo04?ooooo0_l0003Uooooo`;o00004?ooool000Ko
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo04Oooooo0_l0000[ooooo`;o00005?ooool2
o`0006Gooooo0_l00019ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo04Oooooo0_l0000[ooooo`;o00005?ooool2o`0005cooooo0_l00007ooooo`;o00003Ooo
ool2o`0003[ooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Iooooo`;o0000SOoo
ool2o`0001Kooooo0_l0000jooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o00008?ooool4o`0003Gooooo0_l0
000Zooooo`;o00002_ooool2o`000:Wooooo0006ooooo`05o`000?ooooooooooooooool000003_oo
ool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`0Pooooo`Co0000HOooool2o`0000Oooooo0_l000000ooooooo0000o`00000:ooooo`;o0000
4Oooool2o`0000;ooooo0_l0000[ooooo`;o0000=?ooool2o`0002?ooooo0006ooooo`05oa0@4?oo
ooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool08Oooool2o`0001[ooooo0_l0001?ooooo`;o00003Oooool2o`00017ooooo
0_l00002ooooo`;o0000:oooool2o`0003;ooooo1?l0000?ooooo`;o00000_ooool2o`0000kooooo
0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Qooooo`;o00006_ooool2o`00083o
oooo0_l0000Eooooo`;o0000?Oooool2o`0000Wooooo0_l00006ooooo`;o00000_ooool2o`0000ko
oooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
00Cooooo1?l00006ooooo`03o`000?oooooooooo01Sooooo0_l0000Nooooo`;o00000oooool2o`00
03Sooooo0_l0000Wooooo`;o00003oooool2o`0000_ooooo1?l0000Dooooo`Co00004oooool2o`00
02cooooo0_l00003ooooo`;o00006_ooool002Wooooo0_l0000=ooooo`;o00002_ooool2o`0000go
oooo0_l0000?ooooo`;o00000oooool2o`000003ooooool0003o000000Oooooo0_l0000Wooooo`;o
00000oooool2o`0000gooooo0_l0000Hooooo`;o00003oooool4o`0000Kooooo0_l000000ooooooo
0000o`000002o`0000kooooo0_l00006ooooo`;o00004oooool2o`0001Gooooo0_l0000Eooooo`?o
000000?oooooo`000?l000006oooool002Wooooo00?o0000ooooooooool03?ooool2o`0000?ooooo
0_l00009ooooo`;o00002Oooool2o`0000Gooooo0_l0000@ooooo`;o00001oooool2o`0002Oooooo
0_l0000@ooooo`Co00004_ooool2o`0000Oooooo0_l0000=ooooo`?o00001_ooool2o`0001?ooooo
0_l0000Rooooo`?o00003Oooool2o`0000Oooooo0_l0000=ooooo`;o000000?oooooo`000?l00000
6oooool002Wooooo00?o0000ooooooooool01Oooool2o`0000[ooooo0_l00009ooooo`;o00004?oo
ool2o`0005Cooooo0_l0000Dooooo`;o00001oooool2o`0000gooooo0_l00006ooooo`;o00009Ooo
ool2o`00017ooooo0ol0000@ooooo`;o00001?ooool2o`0002gooooo000Yooooo`03o`000?oooooo
oooo00Gooooo0_l0000Oooooo`;o00002oooool2o`0000?ooooo0_l0000Zooooo`;o00000_ooool2
o`00027ooooo0_l0000Jooooo`;o00001Oooool2o`0000[ooooo0_l0000Uooooo`;o00000oooool2
o`0001oooooo0_l0000cooooo`00:Oooool00ol0003oooooooooo`0Vooooo`;o00002oooool2o`00
00?ooooo0_l0000Qooooo`;o00001oooool2o`0000;ooooo0_l0000Fooooo`;o00002Oooool2o`00
00Oooooo0_l0000Aooooo`;o00001Oooool2o`0000[ooooo0_l0000Wooooo`;o000000?oooooo`00
0?l000003?ooool2o`0001_ooooo0_l0000Yooooo`00:Oooool2o`0000Cooooo0_l0000Aooooo`;o
00000_ooool2o`0001[ooooo0_l00006ooooo`;o00006oooool2o`00017ooooo0_l0000@ooooo`;o
00004_ooool2o`0001Oooooo0_l0000;ooooo`;o00003Oooool2o`0001Sooooo0_l0000?ooooo`;o
00002?ooool2o`0000;ooooo0_l00006ooooo`;o00001Oooool2o`0002Wooooo000Yooooo`03o`00
0?oooooooooo00?ooooo0_l0000Aooooo`;o00000_ooool2o`0001[ooooo0_l00006ooooo`;o0000
;_ooool2o`0000Sooooo0_l00009ooooo`;o00007?ooool2o`0000Gooooo0_l00003ooooo`;o0000
5oooool2o`000003ooooool0003o000002?ooooo0_l0000>ooooo`;o00000_ooool2o`0000Kooooo
0_l00004ooooo`;o00005?ooool2o`0001Cooooo000Yooooo`03o`000?oooooooooo00_ooooo0_l0
000Sooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Gooooo`;o00004?ooool5o`0000?ooooo00?ok^k^oc8b<_l000000ol00002
ooooo`06onk^k_lb<S;o0000oc8b<_o^k^kooooo0_l0000Looooo`;o00001Oooool2o`000005oiRH
V?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP07ooooo`;o00008Oooool2o`000003oa0@4?oooooooooo00;o000000Co<S8b
o`000?l0003ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Cooooo0_l00008ooooo`;o0000
1oooool2o`000005odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool2o`0000cooooo0_l0000Uoooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`;o000000CoV9RH
oooooonHV9SoMgMg5oooool2o`00013ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`04ogMg
MonHV9SooooooiRHV0;o00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l0000Coooo
o`;o00002_ooool2o`000005oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`;o00009Oooool2o`0000?ooooo
00?oMgMgoiRHV?l000000_l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool2o`0000Wo
oooo0_l00007ooooo`;o00000oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wooooo0_l0000@ooooo`;o00002?oo
ool2o`0000gooooo0_l000000ooooooo0000o`000005ooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@4002ooooo`Co000000?ooooooa0@4?ooool04_ooool2o`0000[ooooo
0_l00009ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05
oa0@4?l0003o0000ooooool@41001Oooool2o`0000?ooooo0_l0000>ooooo`;o00002_ooool2o`00
00Cooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool00ol@413oooooooooo`02ooooo`;o00008_ooool5o`0000?ooooo00?o410@ooooooooool00_l0
0003ooooo`05oa0@4?ooooooooooooooool@41004?ooool2o`000003ooooool0003o0000013ooooo
0_l00006ooooo`04o`000?oooooooooooa0@40?ooooo00Go410@oooooooooooooooooa0@4003oooo
o`03oa0@4?oooooooooo007ooooo000Yooooo`;o00001oooool2o`0000Oooooo0_l00008ooooo`;o
00002?ooool2o`0000?ooooo0_l000000ooooooo0000o`000005ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`000003ooooo`?o000000?oooooo`000?ooool04_ooool2o`00
00[ooooo0_l0000:ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003
ooooo`?o000000?oooooo`000?ooool02Oooool2o`0001oooooo00?oZJVYoa0@4?ooool00_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00000?ooooo`;o0000
5oooool01?m4A4CogMgMooooool00004ooooo`;o00000_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool03_ooool4o`00017ooooo0_l00005ooooo`05ogMgMolb<S;ooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00Ooo
ool002Wooooo00?o0000ooooooooool01_ooool2o`0001_ooooo0_l00003ooooo`;o00001_ooool3
o`0000;ooooo0ol00003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`0Iooooo`;o00001Oooool2o`0000Sooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Co0000oooooooooooooooo0_l00004ooooo`Co00002?ooool2o`0001Oo
oooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000009ooooo`;o00001?ooool2o`000003ooooool0003o000001Cooooo00CogMgM
oeEEEOoooooo00001?ooool3o`000003ooooool0003ooooo00;ooooo00Go0000oooooooooooooooo
o`00000Booooo`;o00005Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool002Wooooo00?o0000oooo
ooooool01oooool2o`0002Oooooo0ol00002ooooo`;o000000Go410@oooooooooooooooooa0@4003
ooooo`;o00000_ooool00ol@413oooooooooo`0Booooo`;o00001Oooool2o`0000Gooooo0_l00009
ooooo`05o`000?ooooooooooooooool@41000oooool2o`0000;ooooo00Co410@oooooooooooooooo
0_l00004ooooo`Co00002?ooool2o`000003ooooool0003o000001;ooooo0_l000000ooooooo0000
o`000003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413o0000o`000?oooooo410@
00Wooooo0_l000000ooooooo0000o`000004ooooo`;o00005Oooool00omgMgOoc<c<o`000004oooo
o`05oa0@4?l0003o0000ooooool@41000oooool01Ol@413ooooooooooooooooo410@02Wooooo00?o
0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`00:Oooool00ol0003oooooooooo`07ooooo`;o0000:Oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool2o`000003oooooonHV9SoMgMg01Co
oooo0_l0000Cooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01?mgMgOoV9RHoooooonHV9P2
o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Dooooo`;o00004_ooool2o`000003ooooool0
003o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMol0003o0000oiRHV?mg
MgL03?ooool2o`0000Gooooo0_l0000@ooooo`;o00000_ooool00oo^k^koA4A4o`000004ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool00omgMgOoV9RHooooo`02o`0000Gooooo0_l0000Roooo
o`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool002Wooooo00?o0000ooooooooool0<?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Wooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Sooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01?ooooo0_l0000?ooooo`?o
00000oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00oo^
k^ko<S8bo`000002o`0000Gooooo0_l0000Rooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool2o`0002kooooo0_l0001`
ooooo`;o00004_ooool2o`00013ooooo0_l0000Looooo`;o0000<_ooool2o`0000cooooo0_l0000E
ooooo`00:Oooool00ol0003oooooooooo`04ooooo`;o00000oooool2o`0002;ooooo0_l00010oooo
o`;o0000;_ooool2o`0001;ooooo0_l0000@ooooo`;o0000A_ooool2o`0000Sooooo0_l0000Soooo
o`00:Oooool00ol0003oooooooooo`04ooooo`;o00000oooool2o`0002oooooo0_l0000Gooooo`;o
00006_ooool2o`0000cooooo0_l00017ooooo`;o00003Oooool2o`00023ooooo0_l0000:ooooo`;o
00002?ooool2o`0000oooooo0_l0000Looooo`00:Oooool3o`0000gooooo0_l0000[ooooo`;o0000
5oooool2o`0001Kooooo0_l0000@ooooo`;o0000Aoooool2o`0000?ooooo0_l000000ooooooo0000
o`000005ooooo`;o00004_ooool2o`000003ooooool0003o000000Wooooo0_l0000:ooooo`;o0000
6Oooool2o`0001cooooo000Yooooo`?o00003Oooool2o`0002;ooooo0_l0000Cooooo`;o00008ooo
ool2o`0005kooooo0_l000000ooooooo0000o`00000Iooooo`;o000000?oooooo`000?l00000;ooo
ool2o`0000?ooooo0_l0000Hooooo`008Oooooooo`0004Co00001?ooool002Wooooo00?o0000oooo
ooooool02?ooool2o`0000cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool01Ol0003oooooo`000?l0003o
oooo00;o00001Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`02o`0000Oooooo00?o0000ooooooooool01_ooool2
o`000003ooooool0003ooooo00;o00002?ooool01?l0003oooooo`000?l00009ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool3o`0000?ooooo0_l00004ooooo`03o`000?oo
oooooooo00[ooooo00Co0000oooooooooooooooo0_l00006ooooo`03o`000?oooooooooo00Wooooo
00Co0000oooooooooooooooo1?l00004ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`;o00002_ooool00ol0003oooooooooo`0:ooooo`00
:Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00cooooo0_l000000ooooooo0000
o`00000Zooooo`03o`000?oooooooooo01Oooooo0_l0000Aooooo`;o00003_ooool00ol0003ooooo
ooooo`0Pooooo`;o00001?ooool2o`0001;ooooo00Co0000oooooooooooooooo1?l0000Yooooo`;o
00002_ooool00ol0003oooooooooo`0:ooooo`00:Oooool01?l0003oooooooooooooool3o`0002Go
oooo0_l0001?ooooo`;o00007?ooool2o`0000_ooooo0_l0000Fooooo`;o00006Oooool2o`0000Ko
oooo0_l0000Zooooo`;o00001?ooool2o`0002Sooooo000Yooooo`04o`000?ooooooooooooooo`?o
00003oooool2o`0000;ooooo0_l0000@ooooo`;o00005_ooool4o`0002kooooo0_l00005ooooo`Co
00000oooool2o`0001Gooooo0_l0000Sooooo`;o00007?ooool2o`0000?ooooo0_l0000=ooooo`;o
00003?ooool2o`0000gooooo0_l00004ooooo`;o00005_ooool3o`0000oooooo000Yooooo`;o0000
4oooool3o`0000;ooooo0_l0000Xooooo`Co00002oooool3o`0000Wooooo0_l0000Eooooo`;o0000
1oooool3o`0000;ooooo0_l0000=ooooo`;o00001_ooool2o`0002?ooooo0ol000000ooooooo0000
o`00000Aooooo`;o00001Oooool2o`0001;ooooo0_l0000<ooooo`;o0000:oooool3o`0000oooooo
000Yooooo`04o`000?oooooo0000o`00017ooooo0_l0000Hooooo`;o00004oooool2o`0000gooooo
0ol00009ooooo`Co00007Oooool2o`00017ooooo0_l00006ooooo`;o00001Oooool2o`0001Gooooo
0_l00005ooooo`?o000000?oooooo`000?l000004Oooool2o`0001?ooooo0_l0000>ooooo`;o0000
1?ooool2o`0000Sooooo0_l00009ooooo`;o00009_ooool002Wooooo00Co0000ooooool0003o0000
3?ooool2o`000003ooooool0003o000000kooooo0_l00003ooooo`;o00001Oooool2o`0001?ooooo
0_l0000Kooooo`;o000000?oooooo`000?l00000??ooool2o`0000Sooooo1?l00009ooooo`;o0000
<Oooool2o`0000kooooo0_l00004ooooo`;o00002?ooool2o`0000Gooooo0_l00002ooooo`;o0000
9_ooool002Wooooo00?o0000ooooooooool01oooool2o`0000Cooooo0_l000000ooooooo0000o`00
000>ooooo`;o00000oooool2o`0002Kooooo0_l00006ooooo`;o00002_ooool2o`0000Oooooo0_l0
000Cooooo`;o0000:?ooool4o`0000Wooooo0_l00011ooooo`Co00002?ooool2o`000003ooooool0
003o000000Kooooo0_l0000Eooooo`;o00004oooool002Wooooo00Co0000ooooool0003o00001_oo
ool2o`0002Kooooo0_l00009ooooo`;o00002?ooool2o`0000Oooooo0_l00005ooooo`?o00004?oo
ool2o`000003ooooool0003o000000Cooooo0_l0000=ooooo`;o00009?ooool2o`0005;ooooo1Ol0
00001?oooooo0000o`000?ooool2o`000004ooooool0003o0000ooooo`;o00007Oooool4o`00017o
oooo000Yooooo`Co0000;_ooool2o`0000Wooooo0_l00008ooooo`;o00003_ooool2o`00017ooooo
0_l00004ooooo`;o000000?oooooo`000?l000000oooool2o`0002kooooo0_l00004ooooo`;o0000
=Oooool2o`0001Sooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l0000?ooooo`;o
00003oooool2o`0000;ooooo0_l0000=ooooo`00:Oooool00ol0003oooooooooo`0booooo`;o0000
2?ooool2o`0001Kooooo0_l0000Gooooo`;o00001_ooool2o`0000kooooo0_l0000Cooooo`;o0000
3oooool2o`0000_ooooo0_l0000:ooooo`;o00007?ooool2o`0000[ooooo0_l0000Gooooo`;o0000
3oooool2o`0000kooooo0_l00003ooooo`;o00003Oooool002Wooooo00?o0000ooooooooool0:_oo
ool2o`0000Kooooo0_l00008ooooo`;o0000Aoooool2o`0000gooooo0_l00004ooooo`;o00002ooo
ool2o`0000oooooo0_l0000:ooooo`;o00009Oooool2o`000003ooooool0003o000002;ooooo0_l0
000Dooooo`;o00004_ooool002Wooooo00?o0000ooooooooool08_ooool2o`0000Kooooo0_l00007
ooooo`;o00004Oooool2o`0001oooooo0_l0000Cooooo`;o00001?ooool2o`0000cooooo0_l00002
ooooo`;o00004Oooool2o`0000oooooo0_l0000aooooo`;o00009Oooool2o`0001Wooooo0_l0000=
ooooo`00:Oooool00ol0003oooooooooo`0Dooooo`;o00003?ooool2o`0000?ooooo0_l0000:oooo
o`;o00004Oooool2o`0000Kooooo0_l0000:ooooo`;o00002?ooool5o`0001?ooooo0_l000001?oo
oooo0000o`000?ooool2o`0000_ooooo0ol00005ooooo`;o0000D_ooool2o`0000oooooo0_l00006
ooooo`;o00005?ooool2o`00017ooooo0_l0000=ooooo`00:Oooool2o`0001Gooooo0_l00002oooo
o`Co00002oooool2o`0000Wooooo0_l0000Dooooo`;o000000Coooooo`000?l0003ooooo0_l0000:
ooooo`;o00000oooool2o`0000?ooooo0ol0000Hooooo`;o00003_ooool2o`0000Kooooo0_l0000Z
ooooo`;o00007oooool2o`0000Gooooo0_l0000?ooooo`;o00001_ooool2o`0001Cooooo1?l00006
ooooo`;o00005_ooool002Wooooo00?o0000ooooooooool06?ooool4o`000003ooooool0003o0000
01?ooooo0_l0000Dooooo`;o000000?oooooo`000?l000004_ooool2o`0002kooooo0_l0000boooo
o`;o00007oooool2o`0001Sooooo0_l0000Looooo`;o00001_ooool2o`0001Kooooo000Yooooo`03
o`000?oooooooooo01gooooo0_l0000iooooo`;o00000_ooool2o`0001Sooooo0_l0000Gooooo`;o
0000@oooool2o`0000Sooooo0_l0000Nooooo`;o00007oooool2o`0001_ooooo000Yooooo`03o`00
0?oooooooooo00;o0000=?ooool2o`00023ooooo0_l00002ooooo`;o00006?ooool2o`0002Gooooo
0_l00007ooooo`;o00001oooool2o`0000Cooooo0_l00005ooooo`;o00005_ooool2o`0000Sooooo
0_l0000Jooooo`;o00002_ooool2o`0001Oooooo0_l0000Kooooo`00:Oooool00ol0003ooooooooo
o`02o`0002?ooooo0_l0000?ooooo`;o00000oooool2o`00063ooooo0_l00007ooooo`;o00001ooo
ool2o`0000Cooooo0_l00005ooooo`;o0000??ooool2o`0000[ooooo0_l0000dooooo`00:Oooool2
o`0002Kooooo0_l0000Dooooo`;o00007?ooool2o`0003;ooooo0_l00006ooooo`;o00000_ooool2
o`0003;ooooo0_l0001Hooooo`;o00004oooool002Wooooo00?o0000ooooooooool04_ooool2o`00
04Gooooo0_l0000booooo`;o00001_ooool2o`0000;ooooo0_l00005ooooo`;o0000:oooool2o`00
00[ooooo0_l00017ooooo`;o00000oooool2o`0001?ooooo0006ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`0Booooo`;o00002_ooool2o`0002Gooooo0_l0000Kooooo`;o00002?ooool2
o`0003;ooooo0_l0000[ooooo`;o00002_ooool2o`0004Oooooo0_l0000Hooooo`001_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01kooooo0_l0000Uooooo`;o00006ooo
ool2o`0000Sooooo0_l0000Tooooo`;o000000?oooooo`000?l00000<_ooool3o`000003ooooool0
003o000000cooooo1?l0001Mooooo`001_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Oooooo0_l0
001iooooo`;o000000?oooooo`000?l000002oooool4o`0002?ooooo0ol00004ooooo`;o00001Ooo
ool2o`0000;ooooo1?l0001Mooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o00005oooool2o`0000Kooooo0_l0
000^ooooo`;o0000<Oooool2o`0001Oooooo0_l00005ooooo`Co00002?ooool2o`0000Oooooo0_l0
000Gooooo`;o00001Oooool2o`0004Oooooo0_l0000Jooooo`001_ooool01Ol0003ooooooooooooo
oooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool07oooool2o`0002cooooo1?l0000@ooooo`;o00002oooool2o`000003oooo
ool0003o000000oooooo0_l0000Gooooo`;o00001Oooool2o`0000[ooooo0_l00007ooooo`;o0000
Ioooool2o`0000?ooooo0_l0000Eooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo
0_l00011ooooo`;o00004_ooool2o`0000_ooooo0_l000000ooooooo0000o`00000_ooooo`?o0000
L?ooool2o`0000kooooo0_l0000Eooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02_ooool2o`0002;ooooo0_l0000^ooooo`;o0000@oooool2o`00047ooooo0ol0000/ooooo`;o
00009Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool02_ooool2o`0000?ooooo0_l00004oooo
o`;o00005oooool2o`0002kooooo0_l0000Aooooo`;o00005_ooool2o`0005_ooooo0ol0000Qoooo
o`;o0000<?ooool002Wooooo0_l0000;ooooo`;o00000oooool2o`0000Cooooo0_l00005ooooo`;o
00006oooool2o`0000Oooooo0_l000000ooooooo0000o`00000Zooooo`;o00005_ooool2o`00047o
oooo0_l00005ooooo`;o00004?ooool2o`0002?ooooo0_l0000:ooooo`;o00004oooool2o`0000oo
oooo000Yooooo`;o00007Oooool2o`0001_ooooo0_l00007ooooo`;o000000?oooooo`000?l00000
QOooool2o`0000Gooooo0_l0000@ooooo`;o0000;oooool2o`0001?ooooo0_l0000?ooooo`00:Ooo
ool00ol0003oooooooooo`0<ooooo`;o00009_ooool2o`0001Cooooo0_l0000Jooooo`;o0000LOoo
ool2o`00067ooooo000Yooooo`03o`000?oooooooooo00cooooo0_l0000Oooooo`;o00001Oooool2
o`0001Cooooo0_l0000Dooooo`;o00001?ooool2o`00057ooooo0_l0000Nooooo`;o0000HOooool0
02Wooooo00?o0000ooooooooool0:oooool4o`00037ooooo0_l0001Gooooo`;o00005_ooool2o`00
06Wooooo000Yooooo`;o00007_ooool2o`0000Gooooo0_l00005ooooo`;o00008oooool2o`0000Co
oooo0_l00005ooooo`;o00004oooool2o`00057ooooo0_l0000:ooooo`Co0000?oooool2o`0000Oo
oooo0_l0000Mooooo`00:Oooool00ol0003oooooooooo`0Dooooo`;o00001Oooool4o`0000Cooooo
0ol00004ooooo`;o00009?ooool3o`0000?ooooo0_l00005ooooo`;o00001?ooool2o`0000gooooo
0_l0000Sooooo`;o00004Oooool2o`0001Wooooo0_l0000<ooooo`;o0000?oooool2o`0000Oooooo
0_l0000Mooooo`00:Oooool00ol0003oooooooooo`09ooooo`;o00000oooool2o`0000Cooooo0_l0
0005ooooo`;o00001_ooool2o`0000Gooooo0_l0000Looooo`;o00001oooool2o`00013ooooo0_l0
0006ooooo`;o0000:_ooool2o`00017ooooo0_l0000`ooooo`;o00002Oooool2o`0000?ooooo0_l0
0004ooooo`;o0000>_ooool2o`0000cooooo000Yooooo`03o`000?oooooooooo00Wooooo0_l00003
ooooo`;o0000>?ooool2o`0000cooooo0_l0000Cooooo`?o0000D_ooool3o`0001Wooooo0_l00009
ooooo`;o00000oooool2o`0000Cooooo0_l0000jooooo`;o00003?ooool002Wooooo00?o0000oooo
ooooool0E_ooool2o`00017ooooo0_l000000ooooooo0000o`00001Booooo`?o0000B?ooool2o`00
02oooooo000Yooooo`;o00004Oooool2o`0005Oooooo0_l00015ooooo`;o00007Oooool2o`0003[o
oooo0_l0000_ooooo`00:Oooool00ol0003oooooooooo`0@ooooo`;o00007_ooool2o`0003gooooo
0_l0000oooooo`;o00007Oooool2o`0005kooooo0_l0000;ooooo`00:Oooool00ol0003ooooooooo
o`0Eooooo`;o00006Oooool2o`0001cooooo0_l00002ooooo`;o00006oooool2o`0006_ooooo0_l0
000Sooooo`;o00001_ooool2o`0002Cooooo0_l0000;ooooo`00:Oooool00ol0003oooooooooo`0E
ooooo`;o0000=?ooool2o`000003ooooool0003o000000;ooooo0ol0000Qooooo`;o00004_ooool2
o`00053ooooo0_l000000ooooooo0000o`00000Pooooo`;o00001_ooool2o`00037ooooo000Yoooo
o`03o`000?oooooooooo00Cooooo0ol0000dooooo`;o00003_ooool2o`0000Kooooo0_l0000Ooooo
o`Co00003?ooool2o`0000Cooooo0_l0000@ooooo`;o00005?ooool2o`000003ooooool0003o0000
01oooooo0_l00002ooooo`;o00000oooool2o`0001Kooooo0_l00013ooooo`00:Oooool2o`0000;o
oooo0_l000001?oooooo0000o`000?l0000Hooooo`;o00006_ooool2o`0003Oooooo0_l0000>oooo
o`;o00005_ooool2o`0000kooooo0_l00004ooooo`;o000000?oooooo`000?l000004Oooool2o`00
00cooooo0_l00002ooooo`;o00000oooool2o`0001;ooooo0_l000001?oooooo0000o`000?l0000J
ooooo`;o00000oooool3o`00027ooooo000Yooooo`04o`000?ooooooooooooooo`;o00007?ooool2
o`0008_ooooo0_l0000Jooooo`;o00005Oooool2o`0001;ooooo0_l000000ooooooo0000o`00000K
ooooo`;o00000oooool3o`00027ooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo06Wooooo0_l0
003Aooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0JOooool2o`000=7ooooo000>ooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`?o0000=oooool2o`000?oooooo1?oo
ool000kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0=oooool2o`000?oooooo1?ooool000kooooo00Go0000ooooooooooooooooo`00
000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0eooooo`;o0000
ooooool6ooooo`003_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0eooooo`;o0000ooooool6ooooo`003_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1jooooo`;o0000
4?ooool2o`0007Oooooo0_l00008ooooo`;o0000:oooool000kooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`Co00001_ooool2o`0007Sooooo0_l000000ooooooo0000o`00000@ooooo`;o0000
Moooool2o`0000Sooooo0_l0000[ooooo`00:Oooool00ol0003oooooooooo`1gooooo`;o0000`ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^ko
oooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo?Ooo
ool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYoooo
o`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool0
1Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003ooooooooo
o`03ooooo`?o0000oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o
8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Ooo
ool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go
410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Co
oooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool001oooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo?Oooool0
027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03
o`000?oooooooooo00Gooooo0ol0003oooooocgooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001oooooo00?oEEEEofIVI_l0
0000oooooom7ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .24897 Mdot
.02762 .36224 Mdot
.02952 .27585 Mdot
.03143 .33867 Mdot
.03333 .26912 Mdot
.03524 .39255 Mdot
.03714 .28763 Mdot
.03905 .42361 Mdot
.04095 .22974 Mdot
.04286 .3488 Mdot
.04476 .27689 Mdot
.04667 .44161 Mdot
.04857 .38107 Mdot
.05048 .30739 Mdot
.05238 .43529 Mdot
.05429 .26471 Mdot
.05619 .37621 Mdot
.0581 .3736 Mdot
.06 .35478 Mdot
.0619 .39262 Mdot
.06381 .38012 Mdot
.06571 .39975 Mdot
.06762 .40356 Mdot
.06952 .36219 Mdot
.07143 .44998 Mdot
.07333 .31292 Mdot
.07524 .25407 Mdot
.07714 .3569 Mdot
.07905 .40718 Mdot
.08095 .36071 Mdot
.08286 .36576 Mdot
.08476 .23329 Mdot
.08667 .37593 Mdot
.08857 .32818 Mdot
.09048 .24706 Mdot
.09238 .28407 Mdot
.09429 .40198 Mdot
.09619 .33461 Mdot
.0981 .41135 Mdot
.1 .45115 Mdot
.1019 .44869 Mdot
.10381 .25906 Mdot
.10571 .34384 Mdot
.10762 .24089 Mdot
.10952 .27581 Mdot
.11143 .36272 Mdot
.11333 .33482 Mdot
.11524 .24367 Mdot
.11714 .28835 Mdot
.11905 .38993 Mdot
.12095 .25336 Mdot
.12286 .42916 Mdot
.12476 .4735 Mdot
.12667 .28487 Mdot
.12857 .32044 Mdot
.13048 .29093 Mdot
.13238 .42525 Mdot
.13429 .37595 Mdot
.13619 .32744 Mdot
.1381 .29776 Mdot
.14 .36586 Mdot
.1419 .26946 Mdot
.14381 .41054 Mdot
.14571 .3282 Mdot
.14762 .34453 Mdot
.14952 .26262 Mdot
.15143 .34737 Mdot
.15333 .29721 Mdot
.15524 .34496 Mdot
.15714 .34348 Mdot
.15905 .35476 Mdot
.16095 .28031 Mdot
.16286 .34827 Mdot
.16476 .3284 Mdot
.16667 .41028 Mdot
.16857 .30638 Mdot
.17048 .4734 Mdot
.17238 .36532 Mdot
.17429 .4273 Mdot
.17619 .24775 Mdot
.1781 .26213 Mdot
.18 .34935 Mdot
.1819 .32107 Mdot
.18381 .24809 Mdot
.18571 .38271 Mdot
.18762 .25682 Mdot
.18952 .28099 Mdot
.19143 .30584 Mdot
.19333 .37904 Mdot
.19524 .29291 Mdot
.19714 .44931 Mdot
.19905 .42278 Mdot
.20095 .26389 Mdot
.20286 .34305 Mdot
.20476 .28759 Mdot
.20667 .40635 Mdot
.20857 .31549 Mdot
.21048 .26215 Mdot
.21238 .46834 Mdot
.21429 .37809 Mdot
.21619 .23853 Mdot
.2181 .37556 Mdot
.22 .43579 Mdot
.2219 .25459 Mdot
.22381 .28432 Mdot
.22571 .30933 Mdot
.22762 .34345 Mdot
.22952 .3381 Mdot
.23143 .26255 Mdot
.23333 .34424 Mdot
.23524 .33616 Mdot
.23714 .33894 Mdot
.23905 .22993 Mdot
.24095 .33429 Mdot
.24286 .31675 Mdot
.24476 .27853 Mdot
.24667 .36699 Mdot
.24857 .31542 Mdot
.25048 .27547 Mdot
.25238 .41375 Mdot
.25429 .38437 Mdot
.25619 .32373 Mdot
.2581 .40364 Mdot
.26 .41364 Mdot
.2619 .34089 Mdot
.26381 .34101 Mdot
.26571 .35117 Mdot
.26762 .36496 Mdot
.26952 .2708 Mdot
.27143 .3284 Mdot
.27333 .40634 Mdot
.27524 .24781 Mdot
.27714 .44903 Mdot
.27905 .39188 Mdot
.28095 .37114 Mdot
.28286 .42534 Mdot
.28476 .40446 Mdot
.28667 .38561 Mdot
.28857 .34794 Mdot
.29048 .39371 Mdot
.29238 .44096 Mdot
.29429 .22297 Mdot
.29619 .29925 Mdot
.2981 .35645 Mdot
.3 .37582 Mdot
.3019 .36962 Mdot
.30381 .35877 Mdot
.30571 .22285 Mdot
.30762 .34406 Mdot
.30952 .32718 Mdot
.31143 .33906 Mdot
.31333 .37232 Mdot
.31524 .31218 Mdot
.31714 .35458 Mdot
.31905 .29341 Mdot
.32095 .38282 Mdot
.32286 .42079 Mdot
.32476 .42065 Mdot
.32667 .304 Mdot
.32857 .40438 Mdot
.33048 .41778 Mdot
.33238 .25166 Mdot
.33429 .42881 Mdot
.33619 .44723 Mdot
.3381 .23936 Mdot
.34 .32606 Mdot
.3419 .24674 Mdot
.34381 .34719 Mdot
.34571 .25422 Mdot
.34762 .33769 Mdot
.34952 .4172 Mdot
.35143 .3526 Mdot
.35333 .26503 Mdot
.35524 .30548 Mdot
.35714 .2696 Mdot
.35905 .32418 Mdot
.36095 .36908 Mdot
.36286 .39306 Mdot
.36476 .38594 Mdot
.36667 .26537 Mdot
.36857 .40711 Mdot
.37048 .4262 Mdot
.37238 .45395 Mdot
.37429 .29538 Mdot
.37619 .4457 Mdot
.3781 .29892 Mdot
.38 .22924 Mdot
.3819 .35391 Mdot
.38381 .2363 Mdot
.38571 .45047 Mdot
.38762 .36419 Mdot
.38952 .36325 Mdot
.39143 .37116 Mdot
.39333 .33349 Mdot
.39524 .30659 Mdot
.39714 .40248 Mdot
.39905 .42396 Mdot
.40095 .44305 Mdot
.40286 .3272 Mdot
.40476 .46189 Mdot
.40667 .28951 Mdot
.40857 .29469 Mdot
.41048 .28728 Mdot
.41238 .27123 Mdot
.41429 .25371 Mdot
.41619 .47062 Mdot
.4181 .23869 Mdot
.42 .27298 Mdot
.4219 .39092 Mdot
.42381 .34076 Mdot
.42571 .26223 Mdot
.42762 .26258 Mdot
.42952 .40542 Mdot
.43143 .36613 Mdot
.43333 .25314 Mdot
.43524 .26378 Mdot
.43714 .24315 Mdot
.43905 .36471 Mdot
.44095 .44636 Mdot
.44286 .2827 Mdot
.44476 .33765 Mdot
.44667 .44757 Mdot
.44857 .36706 Mdot
.45048 .32993 Mdot
.45238 .26601 Mdot
.45429 .2434 Mdot
.45619 .26239 Mdot
.4581 .25498 Mdot
.46 .35447 Mdot
.4619 .26484 Mdot
.46381 .43702 Mdot
.46571 .29913 Mdot
.46762 .29975 Mdot
.46952 .31257 Mdot
.47143 .46768 Mdot
.47333 .32766 Mdot
.47524 .2549 Mdot
.47714 .348 Mdot
.47905 .32318 Mdot
.48095 .27425 Mdot
.48286 .40228 Mdot
.48476 .24255 Mdot
.48667 .27386 Mdot
.48857 .38841 Mdot
.49048 .23357 Mdot
.49238 .35566 Mdot
.49429 .24253 Mdot
.49619 .30946 Mdot
.4981 .42576 Mdot
.5 .36322 Mdot
.5019 .35829 Mdot
.50381 .41477 Mdot
.50571 .43102 Mdot
.50762 .27404 Mdot
.50952 .32995 Mdot
.51143 .42207 Mdot
.51333 .31825 Mdot
.51524 .29398 Mdot
.51714 .35455 Mdot
.51905 .29716 Mdot
.52095 .41178 Mdot
.52286 .27779 Mdot
.52476 .31167 Mdot
.52667 .25475 Mdot
.52857 .23488 Mdot
.53048 .31121 Mdot
.53238 .36452 Mdot
.53429 .28178 Mdot
.53619 .32909 Mdot
.5381 .37998 Mdot
.54 .31392 Mdot
.5419 .28683 Mdot
.54381 .31901 Mdot
.54571 .33877 Mdot
.54762 .3489 Mdot
.54952 .26249 Mdot
.55143 .42143 Mdot
.55333 .31171 Mdot
.55524 .27753 Mdot
.55714 .24207 Mdot
.55905 .26398 Mdot
.56095 .38536 Mdot
.56286 .41753 Mdot
.56476 .32768 Mdot
.56667 .29361 Mdot
.56857 .40619 Mdot
.57048 .43032 Mdot
.57238 .33242 Mdot
.57429 .32016 Mdot
.57619 .2794 Mdot
.5781 .30669 Mdot
.58 .34497 Mdot
.5819 .28949 Mdot
.58381 .34997 Mdot
.58571 .34833 Mdot
.58762 .42551 Mdot
.58952 .35439 Mdot
.59143 .27015 Mdot
.59333 .3508 Mdot
.59524 .34436 Mdot
.59714 .27185 Mdot
.59905 .4312 Mdot
.60095 .21887 Mdot
.60286 .25411 Mdot
.60476 .38057 Mdot
.60667 .25914 Mdot
.60857 .23881 Mdot
.61048 .45099 Mdot
.61238 .32152 Mdot
.61429 .24994 Mdot
.61619 .30221 Mdot
.6181 .32304 Mdot
.62 .40756 Mdot
.6219 .37188 Mdot
.62381 .39337 Mdot
.62571 .35844 Mdot
.62762 .28667 Mdot
.62952 .32075 Mdot
.63143 .29338 Mdot
.63333 .36345 Mdot
.63524 .32146 Mdot
.63714 .45375 Mdot
.63905 .40546 Mdot
.64095 .24192 Mdot
.64286 .32827 Mdot
.64476 .39027 Mdot
.64667 .24382 Mdot
.64857 .42057 Mdot
.65048 .25015 Mdot
.65238 .29882 Mdot
.65429 .2729 Mdot
.65619 .35626 Mdot
.6581 .44036 Mdot
.66 .42441 Mdot
.6619 .28759 Mdot
.66381 .40973 Mdot
.66571 .32997 Mdot
.66762 .2707 Mdot
.66952 .35839 Mdot
.67143 .39242 Mdot
.67333 .32825 Mdot
.67524 .25247 Mdot
.67714 .25046 Mdot
.67905 .47907 Mdot
.68095 .31323 Mdot
.68286 .31977 Mdot
.68476 .32969 Mdot
.68667 .33811 Mdot
.68857 .25635 Mdot
.69048 .37559 Mdot
.69238 .36724 Mdot
.69429 .27042 Mdot
.69619 .34899 Mdot
.6981 .22305 Mdot
.7 .4419 Mdot
.7019 .34718 Mdot
.70381 .30336 Mdot
.70571 .24872 Mdot
.70762 .31086 Mdot
.70952 .34785 Mdot
.71143 .34962 Mdot
.71333 .44079 Mdot
.71524 .26498 Mdot
.71714 .23545 Mdot
.71905 .44741 Mdot
.72095 .45375 Mdot
.72286 .44386 Mdot
.72476 .27202 Mdot
.72667 .30613 Mdot
.72857 .44064 Mdot
.73048 .41802 Mdot
.73238 .27879 Mdot
.73429 .31637 Mdot
.73619 .32491 Mdot
.7381 .38923 Mdot
.74 .24037 Mdot
.7419 .24712 Mdot
.74381 .26947 Mdot
.74571 .3825 Mdot
.74762 .42641 Mdot
.74952 .40037 Mdot
.75143 .36298 Mdot
.75333 .40337 Mdot
.75524 .45128 Mdot
.75714 .27018 Mdot
.75905 .40369 Mdot
.76095 .37371 Mdot
.76286 .31101 Mdot
.76476 .42559 Mdot
.76667 .37947 Mdot
.76857 .27051 Mdot
.77048 .45461 Mdot
.77238 .33929 Mdot
.77429 .30028 Mdot
.77619 .33722 Mdot
.7781 .34782 Mdot
.78 .26112 Mdot
.7819 .23326 Mdot
.78381 .24388 Mdot
.78571 .32051 Mdot
.78762 .45418 Mdot
.78952 .35026 Mdot
.79143 .48037 Mdot
.79333 .3302 Mdot
.79524 .32723 Mdot
.79714 .29317 Mdot
.79905 .3066 Mdot
.80095 .43405 Mdot
.80286 .43965 Mdot
.80476 .25407 Mdot
.80667 .26182 Mdot
.80857 .27239 Mdot
.81048 .26902 Mdot
.81238 .39438 Mdot
.81429 .34018 Mdot
.81619 .24146 Mdot
.8181 .30479 Mdot
.82 .31441 Mdot
.8219 .32362 Mdot
.82381 .3141 Mdot
.82571 .34188 Mdot
.82762 .27885 Mdot
.82952 .28382 Mdot
.83143 .33201 Mdot
.83333 .39272 Mdot
.83524 .31063 Mdot
.83714 .25709 Mdot
.83905 .3437 Mdot
.84095 .37169 Mdot
.84286 .30822 Mdot
.84476 .32168 Mdot
.84667 .41943 Mdot
.84857 .43374 Mdot
.85048 .28313 Mdot
.85238 .37955 Mdot
.85429 .25282 Mdot
.85619 .31161 Mdot
.8581 .23284 Mdot
.86 .44261 Mdot
.8619 .27305 Mdot
.86381 .36326 Mdot
.86571 .47786 Mdot
.86762 .26583 Mdot
.86952 .31982 Mdot
.87143 .31091 Mdot
.87333 .23465 Mdot
.87524 .25442 Mdot
.87714 .4469 Mdot
.87905 .27536 Mdot
.88095 .25181 Mdot
.88286 .25805 Mdot
.88476 .30418 Mdot
.88667 .27717 Mdot
.88857 .3265 Mdot
.89048 .42315 Mdot
.89238 .3104 Mdot
.89429 .42569 Mdot
.89619 .33941 Mdot
.8981 .29301 Mdot
.9 .3363 Mdot
.9019 .31865 Mdot
.90381 .3616 Mdot
.90571 .37509 Mdot
.90762 .34189 Mdot
.90952 .44256 Mdot
.91143 .43014 Mdot
.91333 .3305 Mdot
.91524 .34815 Mdot
.91714 .29796 Mdot
.91905 .37652 Mdot
.92095 .3742 Mdot
.92286 .23835 Mdot
.92476 .35152 Mdot
.92667 .35149 Mdot
.92857 .32557 Mdot
.93048 .25651 Mdot
.93238 .36143 Mdot
.93429 .30818 Mdot
.93619 .32034 Mdot
.9381 .24722 Mdot
.94 .27148 Mdot
.9419 .32458 Mdot
.94381 .28033 Mdot
.94571 .37149 Mdot
.94762 .26594 Mdot
.94952 .33834 Mdot
.95143 .26576 Mdot
.95333 .2668 Mdot
.95524 .30438 Mdot
.95714 .35578 Mdot
.95905 .35493 Mdot
.96095 .30756 Mdot
.96286 .32672 Mdot
.96476 .31239 Mdot
.96667 .36028 Mdot
.96857 .3364 Mdot
.97048 .24541 Mdot
.97238 .35055 Mdot
.97429 .39533 Mdot
.97619 .45161 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0;Kooooo0_l00024ooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool0Doooool2o`0000;ooooo0_l0001Mooooo`;o00007Oooool2o`0006Gooooo0006oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4
A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0Doooool2o`0000;ooooo0_l0
001looooo`;o0000IOooool000Co00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0_l0
000mooooo`;o0000;?ooool2o`000<_ooooo0006ooooo`05o`000?ooooooooooooooool000003Ooo
ool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00002ooooo`;o00003?oo
ool2o`0002oooooo0_l0000/ooooo`;o00008Oooool2o`0005cooooo0_l0000Gooooo`;o0000<Ooo
ool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo013ooooo0_l0001Nooooo`;o0000
8?ooool2o`0000_ooooo0_l0000jooooo`;o00004oooool2o`0001Oooooo0_l00002ooooo`;o0000
;Oooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0jooooo`;o00009Oooool2o`0000gooooo
0_l00009ooooo`;o00008_ooool2o`0001Oooooo0_l0000Qooooo`;o00001_ooool2o`0002Sooooo
0_l0000>ooooo`;o00007Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Oo
oooo0_l0000Qooooo`;o00009Oooool2o`0001Sooooo0_l00004ooooo`;o00001?ooool2o`0000Oo
oooo0_l00002ooooo`;o00004_ooool2o`0000kooooo0_l00009ooooo`;o00007_ooool2o`0001Ko
oooo0_l0000Pooooo`;o00007Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool05oooool2o`00
0003ooooool0003o000006Gooooo0_l00004ooooo`;o00001oooool2o`0000;ooooo0_l0000Boooo
o`;o00006Oooool4o`0002[ooooo0_l00008ooooo`;o0000<?ooool2o`0000gooooo000Yooooo`;o
00004oooool2o`0000Kooooo0_l0000Aooooo`;o000000?oooooo`000?l000006oooool2o`0001Co
oooo0_l0001Pooooo`;o00004Oooool2o`0000Wooooo0_l0000<ooooo`;o0000;oooool2o`0000Wo
oooo0_l0000=ooooo`00:Oooool2o`0001?ooooo0_l0000Iooooo`;o000000?oooooo`000?l00000
6oooool2o`00013ooooo0_l00002ooooo`;o0000EOooool2o`0000[ooooo0_l00006ooooo`;o0000
2?ooool2o`0000Wooooo0_l0000Rooooo`;o00001oooool2o`00013ooooo0_l0000Hooooo`00:Ooo
ool00ol0003oooooooooo`0=ooooo`;o00003Oooool2o`0001kooooo0_l0000Qooooo`;o00000ooo
ool2o`0001Cooooo0_l00004ooooo`;o00001_ooool2o`0000?ooooo0_l0000?ooooo`;o00005_oo
ool2o`0000;ooooo0_l0000:ooooo`;o00001_ooool2o`0002Oooooo0_l0000>ooooo`;o00001Ooo
ool4o`0002[ooooo000Yooooo`03o`000?oooooooooo00gooooo0_l00007ooooo`;o00001?ooool2
o`0001?ooooo0_l00009ooooo`;o00009_ooool2o`0001Cooooo0_l00004ooooo`;o00001_ooool2
o`0000?ooooo0_l0000?ooooo`;o00005_ooool2o`0001[ooooo0_l0000Sooooo`;o00002Oooool2
o`0000[ooooo1?l0000>ooooo`;o00006_ooool002Wooooo00?o0000ooooooooool05_ooool2o`00
01Kooooo0_l000000ooooooo0000o`000005ooooo`;o0000O_ooool2o`0001Sooooo0_l0000Koooo
o`;o00001oooool2o`0000Sooooo0_l0000<ooooo`;o00003_ooool2o`0001[ooooo000Yooooo`;o
00001oooool2o`0001gooooo0_l00007ooooo`;o00001Oooool2o`000003ooooool0003o000000Go
oooo0_l0000Uooooo`;o00005Oooool3o`000003ooooool0003o000000Cooooo1?l0000Jooooo`;o
000000?oooooo`000?l000003_ooool2o`00027ooooo0_l0000Booooo`;o00001oooool2o`0004;o
oooo000Yooooo`03o`000?oooooooooo00Kooooo0_l0000Mooooo`;o00003_ooool2o`0000Sooooo
0_l0000Uooooo`;o00000oooool2o`00013ooooo0ol000000ooooooo0000o`000003ooooo`Go0000
6_ooool2o`000003ooooool0003o0000037ooooo0_l0000_ooooo`;o00005oooool4o`0001?ooooo
000Yooooo`04o`000?oooooo0000o`00027ooooo0_l0000<ooooo`Co000000So410@oooooooooooo
k^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`;o00006_oo
ool2o`0000;ooooo1ol00003ooooo`04onk^k_lb<S;o0000oc8b<P;o00000_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Cooooo0_l0000Rooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^
k^ko0000o`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`;o00001ooo
ool2o`0000kooooo0_l00002ooooo`?o000000Wo410@o`000?l0003oooooonk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?l0003ok^k^013ooooo0_l0000Eooooo`Ko000000SogMgM
ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`00:Oooool01?l0003oooooo`000?l0000Qooooo`;o00003_ooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo0_l0
000Jooooo`;o00001?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00CoMgMgoiRHV?oooooo
V9RH0_l000001ooooooo0000o`000?nHV9SooooooiRHV?mgMgL03Oooool4o`0000Gooooo0_l0000@
ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool00omgMgOo0000o`000002o`0000?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`08ooooo`;o00000_ooool2o`0000Oooooo0_l00008ooooo`;o0000
1?ooool2o`0000;ooooo0ol000002Ooooooo0000o`000?ooooooMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`05ogMgMonHV9So0000o`000?mgMgL03_ooool2o`0001Oooooo0_l00003ooooo`09ogMgMolb
<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`00:Oooool3o`0000?ooooo0_l0000Cooooo`;o00006?ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41000oooool01_l@413ooooooooooooooooo410@ooooo`;o0000
9oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000_ooool2o`0000?o
oooo00?o410@ooooooooool02oooool4o`0000Gooooo0_l0000=ooooo`;o00001Oooool01Ol0003o
oooooooooooooooo410@00;ooooo0_l00003ooooo`05oa0@4?ooooooooooooooool@41002?ooool2
o`0001Gooooo0_l00007ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@ooooool0003o0000oa0@400>ooooo`;o00000oooool2o`000003ooooool0003o000001Gooooo
00Co0000oooooooooooo410@0oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooo
ooooool00Oooool002Wooooo0ol00003ooooo`;o00004oooool2o`0000kooooo0_l00008ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooooooo
ooooo`Co0000:?ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000001_ooooo0_l00008ooooo`;o00001?ooool00onYZJWo0000
o`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
027ooooo0_l00005ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool2o`0000kooooo0_l000000ooooooo0000
o`00000@ooooo`;o00000_ooool01OmgMgOo<S8boooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo007ooooo000Yooooo`03o`000?oooooooooo02So
oooo0_l00008ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooo
oooooooooooo0_l0000[ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`06o`000?ooooooooooooooool0003ooooo0_l0000Hooooo`;o000000?oooooo`000?l0
00002_ooool01?l@413o0000o`000?l00002ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo0000027ooooo0_l00005ooooo`04omgMgOmEEEGoooooo`0000Cooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool2o`00
00Gooooo0_l0000Looooo`;o000000Co8B4Qo`000?lb<S;oc<c<0_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`00:Oooool00ol0003ooooooooo
o`0Booooo`;o00002Oooool2o`0001?ooooo0_l00003ooooo`06oa0@4?ooooooooooooooool@413o
oooo0_l000001Ol@413ooooooooooooooooo410@02gooooo00Go0000oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@41000oooool01?l@413oooooo`000?l0000Kooooo`;o0000
00?oooooo`000?l000002?ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@
41000oooool01?l@413oooooooooooooool2o`0002Sooooo00?oMgMgolc<c?l000001?ooool01Ol@
413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`;o00001Ooo
ool2o`0001gooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooooooooa0@4003ooooo`00:Oooool01?l0003oooooooooooooool2o`0000oo
oooo0_l00006ooooo`;o000000?oooooo`000?l000004oooool01?l0003oooooooooooooool2o`00
0005oiRHV?ooooooV9RHogMgMoooool00_l000001OmgMgOoV9RHoooooonHV9SoMgMg02Wooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`03ogMgMonHV9So000000?o00000_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg027ooooo0_l00005ooooo`06oa0@4?nHV9SooooookZj^_l0003ooooo0_l00000
1OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00CoMgMgoiRHV?ooooooV9RH0_l00009ooooo`;o0000
7Oooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Wooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool01?l0003ooooooooooooo
ool2o`0001Oooooo0_l00003ooooo`;o00003oooool00omEEEGoIVIVo`000002o`000007ooooool0
003o0000oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:Oooool01OnH
V9So410@o`000?lQ8B7oc<c<00?ooooo00?ok^k^oc8b<_l000000ol00002ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h0:?ooool01_nYZJWo410@o`000?l@413oZJVYooooo`;o000000Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02_ooool2o`0001kooooo00?oMgMg
o`000?ooool00oooool01_o^k^ko<S8bo`000?lb<S;ok^k^ooooo`;o000000Gok^k^oc8b<_l0003o
<S8bonk^kP0Iooooo`;o00003_ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool002Wooooo0_l0000Pooooo`;o00004_ooool2o`00
02Kooooo0_l0000@ooooo`;o00002Oooool2o`00023ooooo0_l0000?ooooo`;o00004oooool2o`00
03?ooooo0_l0000Nooooo`;o00009Oooool002Wooooo00?o0000ooooooooool08Oooool2o`0000?o
oooo0_l0000/ooooo`;o00001Oooool2o`00013ooooo0ol00008ooooo`;o00004?ooool2o`0000ko
oooo1?l0000=ooooo`;o00004oooool2o`0000Cooooo0_l0001Dooooo`;o00007_ooool002Wooooo
00?o0000ooooooooool08Oooool2o`0000?ooooo0_l0000/ooooo`;o00006?ooool2o`0001[ooooo
0ol0000?ooooo`;o00007Oooool2o`0000Wooooo0_l0000Vooooo`;o0000;?ooool2o`0001kooooo
000Yooooo`03o`000?oooooooooo05kooooo0_l00007ooooo`;o00008_ooool2o`0002kooooo0_l0
000Jooooo`;o00005Oooool2o`0000cooooo0_l0000Cooooo`;o00005Oooool2o`0001;ooooo000Y
ooooo`03o`000?oooooooooo00Gooooo0_l0000Tooooo`;o00001Oooool2o`0002[ooooo0_l00007
ooooo`;o00002oooool2o`0003Sooooo0_l0000Wooooo`;o00001Oooool2o`0001Kooooo0_l00004
ooooo`;o00001_ooool2o`0000_ooooo0_l0000>ooooo`;o00001Oooool4o`00013ooooo000Qoooo
oooo0000A?l00004ooooo`00:Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;o
00002?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`02o`0000Sooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`04ooooo`;o00000oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`;o00000_ooool01?l0003o
ooooooooooooool2o`0000Kooooo1Ol000000ooooooo0000o`000003ooooo`?o00002oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_l00006oooo
o`?o00002oooool01?l0003oooooooooooooool2o`0000Kooooo00?o0000ooooooooool01oooool4
o`000003ooooool0003o000000Gooooo0_l000000ooooooo0000ooooo`02o`0000Gooooo0_l00000
0ooooooo0000ooooo`0:ooooo`03o`000?oooooooooo00Gooooo0_l00002ooooo`03o`000?oooooo
oooo00[ooooo000Yooooo`03o`000?oooooooooo00cooooo0_l0000Zooooo`?o00002?ooool4o`00
01?ooooo0_l0000Looooo`03o`000?oooooooooo017ooooo0_l0000Dooooo`;o00004Oooool00ol0
003oooooooooo`0Hooooo`;o00003oooool2o`0000oooooo00?o0000ooooooooool01oooool4o`00
02_ooooo0_l00002ooooo`03o`000?oooooooooo00[ooooo000Yooooo`03o`000?oooooooooo01ko
oooo0_l0000?ooooo`;o00001oooool2o`0000Wooooo1?l0001Cooooo`;o00001oooool2o`0000So
oooo0_l0000@ooooo`;o00003oooool2o`0000oooooo0_l0000>ooooo`;o00006Oooool2o`0000Wo
oooo0_l00009ooooo`;o00006?ooool002Wooooo00?o0000ooooooooool07_ooool2o`0000oooooo
0_l0000Fooooo`;o00007oooool2o`0002Gooooo0_l00009ooooo`;o00001oooool2o`0000Sooooo
0_l0000;ooooo`?o00000_ooool4o`0000gooooo0_l0000Oooooo`;o00002_ooool2o`0000Gooooo
0_l00006ooooo`;o00002Oooool2o`0000Wooooo0_l0000Hooooo`00:Oooool2o`00027ooooo0_l0
000Uooooo`;o00003oooool2o`0000Sooooo0_l00004ooooo`;o00003?ooool2o`0001Oooooo0_l0
000Yooooo`?o00001?ooool2o`0001kooooo0_l0000Aooooo`;o00001oooool2o`0000Gooooo0_l0
000<ooooo`;o00002oooool2o`0000;ooooo0_l00005ooooo`;o00004?ooool002Wooooo00?o0000
ooooooooool04Oooool2o`0000gooooo0_l000000ooooooo0000o`000005ooooo`;o00008?ooool2
o`0000[ooooo0_l00008ooooo`;o00004_ooool2o`0000gooooo0_l00006ooooo`;o00002Oooool2
o`0000Oooooo0_l00007ooooo`;o00005oooool2o`0000Kooooo1?l00002ooooo`;o00003_ooool2
o`00017ooooo0_l0000Looooo`;o00001_ooool2o`0000?ooooo0_l00002ooooo`;o00001Oooool2
o`00013ooooo000Yooooo`03o`000?oooooooooo017ooooo0_l0000@ooooo`;o00001Oooool2o`00
023ooooo0_l0000Uooooo`;o00004?ooool2o`0000Kooooo0_l00009ooooo`;o00001oooool2o`00
00Oooooo0_l000000ooooooo0000o`00000Dooooo`;o00001_ooool4o`0000;ooooo0_l0000Qoooo
o`;o00002_ooool2o`0001Sooooo0_l0000Pooooo`00:Oooool00ol0003oooooooooo`0Dooooo`;o
00000oooool2o`0002Gooooo1?l0000_ooooo`;o0000>?ooool2o`00057ooooo0_l0000Dooooo`;o
00005?ooool2o`0000kooooo000Yooooo`04o`000?oooooo0000o`0001?ooooo0_l00003ooooo`;o
00008oooool6o`0001Gooooo0_l00009ooooo`;o00007_ooool2o`0001kooooo0_l0000[ooooo`;o
00006_ooool3o`0002Gooooo0ol0000>ooooo`;o00001?ooool2o`0000kooooo000Yooooo`Co0000
?Oooool2o`000003ooooool0003o000000Kooooo0_l0000>ooooo`;o00002Oooool2o`0001Oooooo
0_l00005ooooo`;o00007_ooool2o`0002_ooooo0_l0000Jooooo`?o00002_ooool2o`0000;ooooo
0_l0000Eooooo`;o000000?oooooo`000?l000003?ooool2o`0001Cooooo000Yooooo`03o`000?oo
oooooooo01Oooooo0_l0000;ooooo`;o000000?oooooo`000?l000003Oooool2o`0000Kooooo1?l0
0007ooooo`;o00003Oooool2o`0002?ooooo0_l0000`ooooo`;o00000oooool2o`0004Cooooo0_l0
0002ooooo`;o00000_ooool2o`0001Cooooo0_l0000Rooooo`00:Oooool00ol0003oooooooooo`02
ooooo`;o00004oooool2o`0000_ooooo1ol0000;ooooo`;o00001_ooool4o`0000oooooo0_l00005
ooooo`;o00002Oooool2o`0002Wooooo0_l0000Eooooo`;o00002?ooool4o`000003ooooool0003o
000001kooooo1?l000000ooooooo0000o`00000Dooooo`;o00004Oooool2o`0001Oooooo0_l0000O
ooooo`00:Oooool00ol0003oooooooooo`02ooooo`;o00008Oooool2o`0000;ooooo0_l00003oooo
o`;o00006_ooool2o`0000Gooooo0_l0000@ooooo`;o0000:Oooool2o`0001Gooooo0_l00009oooo
o`Go00007oooool4o`000003ooooool0003o000001Cooooo0_l000000ooooooo0000o`00000Woooo
o`;o000000Coooooo`000?l0003o00003?ooool2o`0000gooooo000Yooooo`03o`000?oooooooooo
00Sooooo0_l0000Nooooo`;o00001?ooool2o`0001[ooooo0_l0000?ooooo`;o00002Oooool2o`00
00Oooooo0_l0000Hooooo`;o00004?ooool2o`0001?ooooo1Ol0000Tooooo`;o00005oooool2o`00
02[ooooo0ol00008ooooo`;o00000_ooool2o`0000gooooo000Yooooo`;o00002Oooool2o`0000?o
oooo0_l0000Iooooo`;o0000:_ooool2o`0000Gooooo0_l00009ooooo`;o00001oooool2o`0001So
oooo0_l00008ooooo`;o000000?oooooo`000?l000000oooool2o`0001Gooooo0_l0000:ooooo`;o
00002?ooool2o`0000;ooooo0_l0001Jooooo`?o00004Oooool002Wooooo00?o0000ooooooooool0
3Oooool4o`0004?ooooo1?l0000kooooo`;o000000?oooooo`000?l000009_ooool2o`0000Sooooo
0_l00002ooooo`;o0000BOooool2o`0000Oooooo0_l00006ooooo`;o000000?oooooo`000?l00000
3oooool002Wooooo0_l0000<ooooo`;o00000_ooool2o`0000Oooooo0_l0000looooo`;o00006Ooo
ool3o`0000kooooo0_l0000Aooooo`;o00002Oooool2o`0001kooooo0_l0000Tooooo`;o00008_oo
ool2o`0000_ooooo0_l00007ooooo`;o00002Oooool2o`0000oooooo000Yooooo`;o00003?ooool2
o`0000;ooooo0_l00007ooooo`;o00002?ooool2o`0000Sooooo0_l0000Fooooo`;o00001Oooool2
o`0002Cooooo0ol0000;ooooo`;o000000Coooooo`000?l0003ooooo0_l0000>ooooo`;o00002Ooo
ool2o`0001kooooo0_l0000Aooooo`;o00004Oooool2o`0002;ooooo0_l0000`ooooo`00:Oooool0
0ol0003oooooooooo`0?ooooo`;o00004Oooool2o`0000Sooooo0_l0000Fooooo`;o00001Oooool2
o`0000Wooooo0_l0000Aooooo`;o00005?ooool2o`0000Cooooo0_l0001<ooooo`;o0000Ioooool0
02Wooooo0_l00008ooooo`;o0000A_ooool2o`0000Gooooo0_l000000ooooooo0000o`00000>oooo
o`;o00001oooool2o`0004Wooooo0_l0000Zooooo`;o00006?ooool2o`00023ooooo0_l0000Eoooo
o`00:Oooool00ol0003oooooooooo`07ooooo`;o00001oooool2o`0000kooooo0_l0000Iooooo`;o
00004_ooool2o`0000Cooooo0_l00002ooooo`;o00005oooool2o`0004Wooooo0_l0000Dooooo`;o
00005?ooool2o`0001Sooooo0_l0000Cooooo`;o00000_ooool3o`0000Kooooo0_l0000Eooooo`00
1_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool01oooool4o`0000Gooooo0_l0000>oooo
o`;o00004Oooool2o`0000Gooooo0ol0000Hooooo`;o0000Boooool2o`0002oooooo0_l0000Foooo
o`;o00006_ooool2o`0000oooooo0_l00002ooooo`?o00007Oooool000Kooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`04ooooo`;o00000oooool2o`0002Gooooo0_l00000
0ooooooo0000o`000005ooooo`;o00008?ooool2o`0004Cooooo0_l0000Cooooo`;o0000:oooool2
o`0000Gooooo0_l0000Jooooo`;o0000<oooool000Kooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`;o0000:_ooool2o`0001Cooooo0_l00009ooooo`;o00002Oooool2o`0000cooooo0_l0000m
ooooo`;o00003?ooool2o`0002_ooooo0_l0001Fooooo`001_ooool01Ol0003ooooooooooooooooo
000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000A_ooool2
o`0000Wooooo0_l0000Gooooo`;o00009_ooool2o`0001Gooooo0_l0000gooooo`;o0000F?ooool0
00Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00;o00001oooool2o`00013ooooo0_l0
000aooooo`;o0000;?ooool2o`0001Cooooo0_l0000`ooooo`;o00001oooool2o`0001?ooooo0_l0
000Mooooo`;o0000>Oooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02o`0000Oooooo0_l0
000@ooooo`;o0000<Oooool2o`0000;ooooo0_l0000Eooooo`;o00004Oooool2o`0003oooooo0_l0
0005ooooo`;o00001oooool2o`0002_ooooo0_l00005ooooo`;o0000:oooool2o`0000cooooo0006
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`1Booooo`;o00005Oooool2o`0005;ooooo
0_l0000kooooo`;o0000<_ooool2o`0000cooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo00[o
oooo0_l00007ooooo`;o0000dOooool2o`0005Cooooo000Yooooo`;o00002oooool2o`0000Oooooo
0_l0000cooooo`;o00001_ooool2o`0000cooooo0_l0000Dooooo`;o00006_ooool2o`0005Cooooo
1Ol0001Aooooo`00:Oooool00ol0003oooooooooo`0:ooooo`;o00000_ooool2o`0002Oooooo0_l0
000?ooooo`;o00000oooool2o`000003ooooool0003o000000cooooo0_l0000;ooooo`;o00001ooo
ool2o`0000Wooooo0_l0000?ooooo`;o00006Oooool2o`0000oooooo0_l00004ooooo`;o00008ooo
ool4o`00057ooooo000Yooooo`03o`000?oooooooooo00kooooo0_l00004ooooo`;o00003Oooool2
o`0000Gooooo0_l0000;ooooo`;o00005?ooool2o`0001cooooo0_l0000Booooo`;o0000:_ooool2
o`0000oooooo0_l00004ooooo`;o00001_ooool2o`00073ooooo000Yooooo`03o`000?oooooooooo
01Cooooo0_l0000=ooooo`;o00001Oooool2o`0001[ooooo1?l0001Booooo`;o0000;?ooool2o`00
073ooooo000Yooooo`03o`000?oooooooooo04Kooooo1?l0000Kooooo`;o0000<?ooool2o`0000?o
oooo0_l0000<ooooo`;o0000T?ooool002Wooooo0_l0001Nooooo`Co00001?ooool2o`00033ooooo
0_l0000Aooooo`;o00006Oooool2o`0001Sooooo0_l0000Tooooo`;o0000=Oooool002Wooooo00Co
0000oooooooooooooooo0_l0000booooo`;o00009Oooool5o`0003Sooooo0_l0000;ooooo`;o0000
7Oooool2o`0001Sooooo0_l0000Tooooo`;o00003?ooool2o`0002Oooooo000Yooooo`04o`000?oo
ooooooooooooo`;o00007?ooool2o`0001Cooooo0_l0000Iooooo`;o00002_ooool2o`0000kooooo
0_l00007ooooo`;o00007_ooool2o`0000;ooooo0_l0000;ooooo`;o00002_ooool2o`0001Gooooo
0_l0000Jooooo`;o00001?ooool2o`0002Kooooo0ol0000Vooooo`00:Oooool00ol0003ooooooooo
o`0Looooo`;o000000?oooooo`000?l000003?ooool2o`00027ooooo0_l0000>ooooo`;o00002_oo
ool2o`0000Oooooo0_l0000Nooooo`;o00006oooool2o`0001Gooooo0_l0000Jooooo`;o00001?oo
ool2o`0002Oooooo0_l0000Vooooo`00:Oooool00ol0003oooooooooo`0Looooo`;o00003oooool2
o`00037ooooo0_l0000eooooo`;o00004oooool2o`0000Oooooo0_l0001Sooooo`;o00008?ooool0
02Wooooo0_l00006ooooo`;o0000=?ooool2o`0005[ooooo0_l0000Cooooo`;o00001oooool2o`00
03oooooo0_l0000=ooooo`;o00004oooool2o`00023ooooo000Yooooo`03o`000?oooooooooo00Go
oooo0_l0000dooooo`;o0000COooool2o`0006[ooooo0_l0000=ooooo`;o0000=Oooool002Wooooo
00?o0000ooooooooool01?ooool2o`0004gooooo0_l0000eooooo`;o0000??ooool2o`0000cooooo
0_l00002ooooo`;o00000oooool2o`0001Kooooo0_l00013ooooo`00:Oooool00ol0003ooooooooo
o`04ooooo`;o0000COooool2o`00027ooooo0_l0001@ooooo`;o00003?ooool2o`0000;ooooo0_l0
00000ooooooo0000o`000002o`0001Kooooo0_l0000@ooooo`;o00003_ooool2o`00027ooooo000Y
ooooo`03o`000?oooooooooo01Gooooo0_l0001:ooooo`;o00002oooool2o`0000Kooooo0_l0000:
ooooo`Co0000E_ooool3o`0002[ooooo0_l00004ooooo`;o00002?ooool2o`00027ooooo000Yoooo
o`;o00003Oooool2o`0000Oooooo0_l0000Mooooo`;o00006?ooool2o`00017ooooo0_l0000;oooo
o`;o000000?oooooo`000?l000003oooool4o`0003?ooooo0_l0000Qooooo`;o00002Oooool2o`00
02Kooooo0_l0000Nooooo`;o00002oooool002Wooooo00?o0000ooooooooool03?ooool2o`0000Oo
oooo0_l0000Mooooo`;o00006?ooool2o`0001cooooo0_l00003ooooo`;o0000A_ooool2o`0000Ko
oooo0_l0000Iooooo`;o00002Oooool2o`0000?ooooo0_l00004ooooo`;o0000>oooool2o`0000_o
oooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo06cooooo0_l0001Cooooo`;o00006Oooool2o`00
00kooooo0_l00004ooooo`;o0000B?ooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000ko
oooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0001goooo
o`;o0000`oooool000kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0Moooool2o`000<?ooooo000>ooooo`05o`000?oooooooooooooo
ool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0>Oooool2
o`00057ooooo0_l0002^ooooo`003_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Mooooo`;o00003?ooool2o`0000cooooo0_l0000o
ooooo`;o00004?ooool2o`000:kooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo01gooooo0_l0000<ooooo`;o0000COooool2
o`000<3ooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0003@
ooooo`;o0000>_ooool2o`0002oooooo000Yooooo`03o`000?oooooooooo0<oooooo0_l0000Roooo
o`;o00005_ooool2o`0002oooooo000Yooooo`03o`000?oooooooooo0??ooooo0_l00017ooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEE
EOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolmooooo`001_ooool01Ol0003o
oooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00000>oooo
o`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOo
oooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool001oooooo1?l000000ol@413oooooooooo`03ooooo`03
o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo0ol0003oooooocgooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool001oooooo00?oEEEEofIVI_l00000oooooom7ooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .33605 Mdot
.02762 .27427 Mdot
.02952 .29123 Mdot
.03143 .29951 Mdot
.03333 .26335 Mdot
.03524 .36926 Mdot
.03714 .27217 Mdot
.03905 .34673 Mdot
.04095 .2938 Mdot
.04286 .32807 Mdot
.04476 .33646 Mdot
.04667 .38646 Mdot
.04857 .4133 Mdot
.05048 .34886 Mdot
.05238 .37545 Mdot
.05429 .32215 Mdot
.05619 .36674 Mdot
.0581 .41235 Mdot
.06 .34876 Mdot
.0619 .30984 Mdot
.06381 .41166 Mdot
.06571 .34845 Mdot
.06762 .36284 Mdot
.06952 .4093 Mdot
.07143 .44005 Mdot
.07333 .36417 Mdot
.07524 .29991 Mdot
.07714 .33203 Mdot
.07905 .33824 Mdot
.08095 .27269 Mdot
.08286 .4081 Mdot
.08476 .28118 Mdot
.08667 .26984 Mdot
.08857 .37539 Mdot
.09048 .28299 Mdot
.09238 .23734 Mdot
.09429 .43177 Mdot
.09619 .27118 Mdot
.0981 .3495 Mdot
.1 .41183 Mdot
.1019 .44859 Mdot
.10381 .33969 Mdot
.10571 .26081 Mdot
.10762 .28702 Mdot
.10952 .36042 Mdot
.11143 .31745 Mdot
.11333 .34826 Mdot
.11524 .34869 Mdot
.11714 .2483 Mdot
.11905 .30685 Mdot
.12095 .35892 Mdot
.12286 .4051 Mdot
.12476 .47981 Mdot
.12667 .24616 Mdot
.12857 .24435 Mdot
.13048 .22967 Mdot
.13238 .35039 Mdot
.13429 .36942 Mdot
.13619 .40642 Mdot
.1381 .37288 Mdot
.14 .3306 Mdot
.1419 .38191 Mdot
.14381 .34858 Mdot
.14571 .33222 Mdot
.14762 .23937 Mdot
.14952 .24329 Mdot
.15143 .3135 Mdot
.15333 .33967 Mdot
.15524 .28815 Mdot
.15714 .40256 Mdot
.15905 .38223 Mdot
.16095 .3188 Mdot
.16286 .32621 Mdot
.16476 .26916 Mdot
.16667 .34804 Mdot
.16857 .31011 Mdot
.17048 .47985 Mdot
.17238 .35176 Mdot
.17429 .39135 Mdot
.17619 .31068 Mdot
.1781 .35707 Mdot
.18 .25893 Mdot
.1819 .26696 Mdot
.18381 .32559 Mdot
.18571 .27844 Mdot
.18762 .29579 Mdot
.18952 .25517 Mdot
.19143 .24989 Mdot
.19333 .35848 Mdot
.19524 .33833 Mdot
.19714 .44026 Mdot
.19905 .32693 Mdot
.20095 .31618 Mdot
.20286 .27472 Mdot
.20476 .33278 Mdot
.20667 .29988 Mdot
.20857 .35038 Mdot
.21048 .36607 Mdot
.21238 .48319 Mdot
.21429 .369 Mdot
.21619 .30889 Mdot
.2181 .3332 Mdot
.22 .37431 Mdot
.2219 .26289 Mdot
.22381 .37317 Mdot
.22571 .36889 Mdot
.22762 .3806 Mdot
.22952 .35939 Mdot
.23143 .3139 Mdot
.23333 .40256 Mdot
.23524 .34926 Mdot
.23714 .2992 Mdot
.23905 .29208 Mdot
.24095 .23937 Mdot
.24286 .4238 Mdot
.24476 .27244 Mdot
.24667 .34512 Mdot
.24857 .22718 Mdot
.25048 .2351 Mdot
.25238 .42853 Mdot
.25429 .41311 Mdot
.25619 .41612 Mdot
.2581 .40033 Mdot
.26 .35142 Mdot
.2619 .40142 Mdot
.26381 .31852 Mdot
.26571 .25197 Mdot
.26762 .24653 Mdot
.26952 .24923 Mdot
.27143 .29385 Mdot
.27333 .37111 Mdot
.27524 .27308 Mdot
.27714 .40854 Mdot
.27905 .38158 Mdot
.28095 .30346 Mdot
.28286 .38182 Mdot
.28476 .43356 Mdot
.28667 .29847 Mdot
.28857 .32006 Mdot
.29048 .29664 Mdot
.29238 .38824 Mdot
.29429 .31594 Mdot
.29619 .25893 Mdot
.2981 .32291 Mdot
.3 .36822 Mdot
.3019 .27285 Mdot
.30381 .24969 Mdot
.30571 .34123 Mdot
.30762 .35571 Mdot
.30952 .25783 Mdot
.31143 .42531 Mdot
.31333 .32263 Mdot
.31524 .25407 Mdot
.31714 .40719 Mdot
.31905 .3224 Mdot
.32095 .3899 Mdot
.32286 .4282 Mdot
.32476 .37234 Mdot
.32667 .22713 Mdot
.32857 .43128 Mdot
.33048 .43034 Mdot
.33238 .32394 Mdot
.33429 .3965 Mdot
.33619 .45499 Mdot
.3381 .28047 Mdot
.34 .24743 Mdot
.3419 .33218 Mdot
.34381 .2401 Mdot
.34571 .35071 Mdot
.34762 .27509 Mdot
.34952 .43197 Mdot
.35143 .25404 Mdot
.35333 .31683 Mdot
.35524 .25332 Mdot
.35714 .26324 Mdot
.35905 .35794 Mdot
.36095 .2618 Mdot
.36286 .28008 Mdot
.36476 .38678 Mdot
.36667 .29608 Mdot
.36857 .33908 Mdot
.37048 .42559 Mdot
.37238 .4284 Mdot
.37429 .2566 Mdot
.37619 .4519 Mdot
.3781 .3307 Mdot
.38 .31647 Mdot
.3819 .23735 Mdot
.38381 .27392 Mdot
.38571 .45126 Mdot
.38762 .28964 Mdot
.38952 .43679 Mdot
.39143 .27491 Mdot
.39333 .29629 Mdot
.39524 .40562 Mdot
.39714 .30962 Mdot
.39905 .45783 Mdot
.40095 .39118 Mdot
.40286 .2575 Mdot
.40476 .39729 Mdot
.40667 .36137 Mdot
.40857 .32578 Mdot
.41048 .32431 Mdot
.41238 .31144 Mdot
.41429 .28559 Mdot
.41619 .41751 Mdot
.4181 .30167 Mdot
.42 .27505 Mdot
.4219 .38053 Mdot
.42381 .30516 Mdot
.42571 .30097 Mdot
.42762 .32523 Mdot
.42952 .40596 Mdot
.43143 .34784 Mdot
.43333 .34959 Mdot
.43524 .27874 Mdot
.43714 .32556 Mdot
.43905 .33031 Mdot
.44095 .45507 Mdot
.44286 .32691 Mdot
.44476 .38892 Mdot
.44667 .39962 Mdot
.44857 .34151 Mdot
.45048 .40704 Mdot
.45238 .36103 Mdot
.45429 .33668 Mdot
.45619 .31847 Mdot
.4581 .32101 Mdot
.46 .2636 Mdot
.4619 .31691 Mdot
.46381 .3793 Mdot
.46571 .40206 Mdot
.46762 .34094 Mdot
.46952 .31104 Mdot
.47143 .41204 Mdot
.47333 .25301 Mdot
.47524 .29243 Mdot
.47714 .42904 Mdot
.47905 .25972 Mdot
.48095 .24633 Mdot
.48286 .4048 Mdot
.48476 .28379 Mdot
.48667 .38496 Mdot
.48857 .345 Mdot
.49048 .30009 Mdot
.49238 .38221 Mdot
.49429 .26372 Mdot
.49619 .33666 Mdot
.4981 .41866 Mdot
.5 .30349 Mdot
.5019 .38216 Mdot
.50381 .3577 Mdot
.50571 .45765 Mdot
.50762 .2768 Mdot
.50952 .28608 Mdot
.51143 .42366 Mdot
.51333 .36523 Mdot
.51524 .25421 Mdot
.51714 .27304 Mdot
.51905 .31438 Mdot
.52095 .32636 Mdot
.52286 .37824 Mdot
.52476 .24639 Mdot
.52667 .29302 Mdot
.52857 .31639 Mdot
.53048 .26699 Mdot
.53238 .30394 Mdot
.53429 .36338 Mdot
.53619 .3492 Mdot
.5381 .32471 Mdot
.54 .23342 Mdot
.5419 .35267 Mdot
.54381 .23395 Mdot
.54571 .25533 Mdot
.54762 .33169 Mdot
.54952 .26572 Mdot
.55143 .42834 Mdot
.55333 .25729 Mdot
.55524 .3426 Mdot
.55714 .34635 Mdot
.55905 .32701 Mdot
.56095 .38881 Mdot
.56286 .36186 Mdot
.56476 .3214 Mdot
.56667 .25735 Mdot
.56857 .43086 Mdot
.57048 .36224 Mdot
.57238 .35979 Mdot
.57429 .3076 Mdot
.57619 .34246 Mdot
.5781 .23226 Mdot
.58 .27822 Mdot
.5819 .37546 Mdot
.58381 .23463 Mdot
.58571 .41599 Mdot
.58762 .35427 Mdot
.58952 .41807 Mdot
.59143 .30235 Mdot
.59333 .41785 Mdot
.59524 .42619 Mdot
.59714 .24253 Mdot
.59905 .36639 Mdot
.60095 .28762 Mdot
.60286 .2769 Mdot
.60476 .32219 Mdot
.60667 .25841 Mdot
.60857 .26966 Mdot
.61048 .44078 Mdot
.61238 .35013 Mdot
.61429 .35526 Mdot
.61619 .35984 Mdot
.6181 .31349 Mdot
.62 .4007 Mdot
.6219 .37423 Mdot
.62381 .41175 Mdot
.62571 .43522 Mdot
.62762 .26745 Mdot
.62952 .38255 Mdot
.63143 .3621 Mdot
.63333 .25598 Mdot
.63524 .27602 Mdot
.63714 .42988 Mdot
.63905 .45181 Mdot
.64095 .25615 Mdot
.64286 .34082 Mdot
.64476 .38681 Mdot
.64667 .31479 Mdot
.64857 .37357 Mdot
.65048 .306 Mdot
.65238 .32664 Mdot
.65429 .2865 Mdot
.65619 .38139 Mdot
.6581 .38127 Mdot
.66 .41838 Mdot
.6619 .33291 Mdot
.66381 .38767 Mdot
.66571 .3078 Mdot
.66762 .31059 Mdot
.66952 .26855 Mdot
.67143 .36396 Mdot
.67333 .24861 Mdot
.67524 .32525 Mdot
.67714 .30128 Mdot
.67905 .47384 Mdot
.68095 .36333 Mdot
.68286 .23975 Mdot
.68476 .33024 Mdot
.68667 .23498 Mdot
.68857 .3142 Mdot
.69048 .28226 Mdot
.69238 .2833 Mdot
.69429 .27361 Mdot
.69619 .28646 Mdot
.6981 .31708 Mdot
.7 .38646 Mdot
.7019 .41659 Mdot
.70381 .233 Mdot
.70571 .2889 Mdot
.70762 .3706 Mdot
.70952 .2495 Mdot
.71143 .27606 Mdot
.71333 .38403 Mdot
.71524 .23506 Mdot
.71714 .28994 Mdot
.71905 .40368 Mdot
.72095 .43308 Mdot
.72286 .4551 Mdot
.72476 .28339 Mdot
.72667 .24603 Mdot
.72857 .38785 Mdot
.73048 .33718 Mdot
.73238 .27529 Mdot
.73429 .3896 Mdot
.73619 .36597 Mdot
.7381 .38601 Mdot
.74 .31904 Mdot
.7419 .35189 Mdot
.74381 .24941 Mdot
.74571 .42883 Mdot
.74762 .40027 Mdot
.74952 .35286 Mdot
.75143 .42349 Mdot
.75333 .36053 Mdot
.75524 .42884 Mdot
.75714 .39324 Mdot
.75905 .43009 Mdot
.76095 .3942 Mdot
.76286 .319 Mdot
.76476 .45548 Mdot
.76667 .35648 Mdot
.76857 .29317 Mdot
.77048 .43562 Mdot
.77238 .40088 Mdot
.77429 .32686 Mdot
.77619 .28274 Mdot
.7781 .36936 Mdot
.78 .27778 Mdot
.7819 .33227 Mdot
.78381 .33922 Mdot
.78571 .41344 Mdot
.78762 .43203 Mdot
.78952 .38018 Mdot
.79143 .46089 Mdot
.79333 .37689 Mdot
.79524 .35842 Mdot
.79714 .34981 Mdot
.79905 .27327 Mdot
.80095 .36802 Mdot
.80286 .3819 Mdot
.80476 .30391 Mdot
.80667 .28833 Mdot
.80857 .26425 Mdot
.81048 .27133 Mdot
.81238 .45046 Mdot
.81429 .27038 Mdot
.81619 .27568 Mdot
.8181 .25926 Mdot
.82 .25484 Mdot
.8219 .27986 Mdot
.82381 .25082 Mdot
.82571 .37854 Mdot
.82762 .25995 Mdot
.82952 .26652 Mdot
.83143 .42107 Mdot
.83333 .29493 Mdot
.83524 .29323 Mdot
.83714 .26631 Mdot
.83905 .3806 Mdot
.84095 .393 Mdot
.84286 .36111 Mdot
.84476 .25859 Mdot
.84667 .45558 Mdot
.84857 .34414 Mdot
.85048 .2421 Mdot
.85238 .45927 Mdot
.85429 .26479 Mdot
.85619 .26398 Mdot
.8581 .28363 Mdot
.86 .39336 Mdot
.8619 .33382 Mdot
.86381 .27741 Mdot
.86571 .47552 Mdot
.86762 .28017 Mdot
.86952 .32028 Mdot
.87143 .3551 Mdot
.87333 .31577 Mdot
.87524 .3269 Mdot
.87714 .36839 Mdot
.87905 .32276 Mdot
.88095 .27429 Mdot
.88286 .33896 Mdot
.88476 .33692 Mdot
.88667 .27398 Mdot
.88857 .2667 Mdot
.89048 .34601 Mdot
.89238 .26623 Mdot
.89429 .38414 Mdot
.89619 .24924 Mdot
.8981 .37007 Mdot
.9 .24072 Mdot
.9019 .3904 Mdot
.90381 .37969 Mdot
.90571 .25659 Mdot
.90762 .29333 Mdot
.90952 .38635 Mdot
.91143 .45807 Mdot
.91333 .34869 Mdot
.91524 .41684 Mdot
.91714 .35746 Mdot
.91905 .34577 Mdot
.92095 .28005 Mdot
.92286 .30327 Mdot
.92476 .35281 Mdot
.92667 .29143 Mdot
.92857 .37486 Mdot
.93048 .37205 Mdot
.93238 .28567 Mdot
.93429 .30897 Mdot
.93619 .24479 Mdot
.9381 .29868 Mdot
.94 .28406 Mdot
.9419 .34143 Mdot
.94381 .2481 Mdot
.94571 .30359 Mdot
.94762 .3064 Mdot
.94952 .3689 Mdot
.95143 .24107 Mdot
.95333 .26538 Mdot
.95524 .37519 Mdot
.95714 .31766 Mdot
.95905 .32082 Mdot
.96095 .26812 Mdot
.96286 .43009 Mdot
.96476 .27073 Mdot
.96667 .27129 Mdot
.96857 .4097 Mdot
.97048 .26897 Mdot
.97238 .30197 Mdot
.97429 .31599 Mdot
.97619 .41559 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`15ooooo`;o00005oooool2o`000=cooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Oooooo`;o00009?ooool2o`0001Oooooo0_l0003Looooo`001_ooool01Ol0003ooooooooooooo
oooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o00007ooo
ool2o`00087ooooo0ol00009ooooo`;o00009oooool2o`0006?ooooo0006ooooo`05o`000?oooooo
ooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`15ooooo`;o0000Foooool3o`0000Wooooo1?l0000Oooooo`;o0000
1?ooool2o`0000;ooooo0_l0001Oooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo
0_l0000@ooooo`;o00007?ooool2o`000003ooooool0003o000001cooooo0_l0000:ooooo`;o0000
?oooool2o`0001kooooo0ol00008ooooo`;o0000Goooool000Kooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo01;ooooo0_l0000@ooooo`?o00006oooool2o`0001oooooo0_l0000:ooooo`;o
0000A?ooool2o`0001Wooooo0_l0000dooooo`;o00003_ooool2o`0000oooooo0_l0000Cooooo`00
1_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co00001_ooool00ol0003oooooooooo`0Mooooo`?o00001Oooool2o`0002Cooooo0_l00012oooo
o`;o00003?ooool2o`0001Kooooo0_l0000Wooooo`;o00009_ooool2o`0000kooooo0_l0000:oooo
o`;o00000oooool2o`0001?ooooo000Yooooo`;o00006oooool2o`000004ooooool0003o0000o`00
02_ooooo0_l00009ooooo`;o00002_ooool2o`0002_ooooo0_l0000<ooooo`;o0000;_ooool2o`00
00[ooooo0_l00003ooooo`;o00001?ooool2o`0002oooooo0_l0000;ooooo`Co00005_ooool002Wo
oooo00?o0000ooooooooool06_ooool2o`0001Kooooo0_l0000Fooooo`?o00002Oooool2o`0000[o
oooo0_l0001Yooooo`;o00002_ooool2o`0000Wooooo0_l0000Hooooo`;o00005Oooool2o`0000go
oooo0_l0000Fooooo`00:Oooool00ol0003oooooooooo`0booooo`;o00005_ooool2o`0000kooooo
0_l0000:ooooo`?o00009?ooool2o`0000_ooooo0_l00008ooooo`;o0000E_ooool4o`0003cooooo
000Yooooo`03o`000?oooooooooo02kooooo0_l00002ooooo`;o00008?ooool2o`0000;ooooo1?l0
000:ooooo`?o00001?ooool2o`0000Oooooo0_l0000Eooooo`;o00002oooool2o`0000Sooooo0_l0
00000ooooooo0000o`000002ooooo`;o00002oooool2o`0000Kooooo0_l000000ooooooo0000o`00
000gooooo`;o00001_ooool2o`0001;ooooo0_l0000Rooooo`00:Oooool00ol0003oooooooooo`0G
ooooo`;o00005Oooool2o`0002Cooooo0_l00002ooooo`;o00003oooool2o`0000;ooooo0_l00007
ooooo`;o00005oooool2o`0001Kooooo0_l00002ooooo`;o00002oooool2o`0000Kooooo0_l00000
0ooooooo0000o`00000gooooo`;o000000?oooooo`000?l000000oooool2o`0001;ooooo0_l0000R
ooooo`00:Oooool4o`0001Kooooo0_l0000Sooooo`;o0000:Oooool4o`0001kooooo0_l00004oooo
o`;o00000oooool2o`0006?ooooo0_l000001?oooooo0000o`000?ooool2o`0000Kooooo0ol0000b
ooooo`00:Oooool01?l0003oooooo`000?l0000^ooooo`;o00002oooool2o`0002Wooooo0_l0000P
ooooo`;o00002Oooool2o`0000Wooooo0_l00004ooooo`;o00005oooool2o`0003Wooooo0_l00004
ooooo`;o000000?oooooo`000?l000000oooool3o`0000Sooooo1?l0000Aooooo`;o000000?ooooo
o`000?l000004?ooool002Wooooo00?o0000ooooooooool04?ooool2o`0000;ooooo0_l0000Doooo
o`;o00000oooool5o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0:Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h07Oooool2o`0000Cooooo0_l00003ooooo`05oiRHV?l@413o
0000oc8b<_o<c<`00oooool01_o^k^ko<S8bo`000?lb<S;ok^k^ooooo`;o000000Cok^k^oc8b<_l0
003o<S8b0_l0000<ooooo`;o00006oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00?ok^k^oc8b<_l000000_l00003ooooo`;o000000?oooooo`000?l00000
3_ooool4o`0000oooooo00GoA4A4o`000?l0003o0000omgMg@05o`000003oc8b<_o^k^kooooo00;o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool2o`0000;ooooo0_l0000<ooooo`?o
00000_ooool2o`0001Cooooo0_l00006ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`04ogMgMonHV9SooooooiRHV0;o00002?ooool2o`0000Oooooo0_l0000E
ooooo`03oiRHV?lQ8B7ok^k^00;o00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0Iooooo`;o00003Oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?o
oooo00KoMgMgoiRHV?ooooooV9RHogMgMoooool2o`000005ogMgMonHV9SooooooiRHV?mgMgL03Ooo
ool2o`0000Kooooo0_l0000Dooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`02ooooo`;o000000CoV9RHo`000?l0003o00005?ooool4o`0001Cooooo00?oMgMgoc8b<_oo
ool01?l000000onHV9SoMgMgooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wo
oooo0_l00002ooooo`;o00003?ooool2o`00027ooooo00Co0000oooooooooooooooo0_l00003oooo
o`05oa0@4?ooooooooooooooool@41000oooool2o`0000Sooooo0_l00007ooooo`;o00003?ooool2
o`0000Sooooo00?oV9RHob4Q8Ol000000ol000000ooooooo410@ooooo`02ooooo`03oa0@4?oooooo
oooo00;o00000oooool00ol@413oooooooooo`0Dooooo`;o000000?oooooo`000?l000004Oooool0
1Ol0003ooooooooooooooooo410@00?ooooo0_l00002ooooo`05oa0@4?ooooooooooooooool@4100
0_ooool2o`00017ooooo0_l00003ooooo`;o00001Oooool2o`0000Gooooo1Ol00003ooooo`05oa0@
4?ooooooooooooooool@41000_ooool2o`0000?ooooo0_l0000=ooooo`;o00001?ooool4o`0001Go
oooo00Co0000oooooooooooo410@0oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@
ooooooooool00Oooool002Wooooo0_l0000aooooo`?o00000oooool2o`0000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo01_ooooo0_l000000ooooooo0000o`000003
ooooo`;o00001?ooool00onHV9So8B4Qonk^kP02o`000003ooooool0003ooooo00;ooooo00?o0000
ooooooooool00_l00003ooooo`;o00005Oooool2o`0001?ooooo00KoZJVYoa0@4?l0003o0000oooo
ool00003ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000;ooooo0_l0000Fooooo`;o
00001Oooool2o`0000Gooooo00CoA4A4omgMgOoooooo00001?ooool2o`0000;ooooo00Go0000oooo
ooooooooooooo`000003ooooo`Co00002oooool4o`0000oooooo0_l00009ooooo`05ogMgMolb<S;o
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
0Oooool002Wooooo00?o0000ooooooooool04?ooool4o`0001cooooo0ol00004ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000001gooooo0_l00006ooooo`;o
00001Oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01?l0
003oooooooooooooool2o`0000gooooo0_l0000Jooooo`03oa0@4?l0003o^[Zj00;o000000?ooooo
o`000?ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool04_oo
ool2o`0000Wooooo0_l00007ooooo`04omgMgOmEEEGoooooo`0000?ooooo0ol00002ooooo`05o`00
0?ooooooooooooooool000000oooool01?l0003oooooo`000?l0000:ooooo`;o000000?oooooo`00
0?l000003oooool2o`0000Kooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo000Yooooo`03o`000?oo
oooooooo013ooooo1?l00003ooooo`;o00006Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@02gooooo00Go0000oooooooo
oooooooooa0@4003ooooo`05oa0@4?l0003o0000ooooool@41000oooool00ol@413oooooooooo`0<
ooooo`;o00001_ooool2o`0001?ooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooo
oooo410@00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`;o00002_ooool3o`0000Sooooo
0_l00008ooooo`03ogMgMoo<c<co000000?ooooo0_l00003ooooo`05oa0@4?ooooooooooooooool@
41000oooool00ol@413oooooooooo`0;ooooo`;o00005Oooool2o`000004ooooool0003o0000o`00
00Kooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool002Wooooo00?o0000ooooooooool05oooool2o`0000kooooo0_l00009ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
:Oooool01?l0003o^[ZjoooooonHV9P2o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02o`00
0006oooooomgMgOoV9RHoooooonHV9SoMgMg5_ooool2o`00013ooooo00Go410@oiRHV?oooooo^[Zj
o`000003ooooo`04ogMgMonHV9SooooooiRHV0;o00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Sooooo0_l0000;ooooo`;o00000_ooool2o`000003ooooool0003o000000_ooooo00?ok^k^odA4
A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgo`000?l0003oV9RHogMg
M`0Tooooo`;o000000Coooooo`000?l0003o00001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool3o`0002Oooooo0_l00007ooooo`03
oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000
o`000?o^k^h0:Oooool01?nHV9So410@o`000?lQ8B42o`0000;ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool2o`0000oooooo0_l0000:ooooo`05
ojVYZOl@413o0000oa0@4?nYZJT00oooool01?o^k^ko<S8bo`000?lb<S82o`0000;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0Iooooo`;o000000?oooooo`000?l000003?ooool00omgMgOo0000oooo
o`02o`000006ooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko0000o`000?lb<S;ok^k^
00Gooooo0_l0000Looooo`;o00001?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool002Wooooo0ol00002ooooo`;o0000;Oooool2
o`0000kooooo0_l00009ooooo`;o00007Oooool2o`0000Kooooo0_l0000Hooooo`;o00003oooool2
o`0004cooooo0_l0000Cooooo`;o00005Oooool2o`0000Gooooo0_l0000Kooooo`00:Oooool00ol0
003oooooooooo`02ooooo`;o0000;Oooool2o`0000kooooo0_l00009ooooo`;o00000oooool3o`00
01Oooooo0_l00006ooooo`;o0000S?ooool2o`0001Gooooo0_l00008ooooo`;o00006?ooool002Wo
oooo00Co0000ooooool0003o00003?ooool2o`0002Sooooo0_l00008ooooo`;o00003_ooool3o`00
02Oooooo1?l0000Cooooo`;o00007oooool2o`0001Wooooo0_l0001Booooo`;o00002Oooool2o`00
00gooooo000Yooooo`04o`000?oooooo0000o`0000cooooo0_l0000Xooooo`;o00005_ooool2o`00
02[ooooo1?l0000Cooooo`;o000000?oooooo`000?l000002Oooool2o`00017ooooo0_l0000Ioooo
o`;o00009oooool2o`0002Cooooo0_l00006ooooo`;o00001_ooool2o`0000gooooo000Yooooo`03
o`000?oooooooooo01_ooooo0_l0000booooo`;o0000;?ooool2o`0001Kooooo0_l00009ooooo`;o
00002oooool2o`0001Oooooo0_l00003ooooo`;o0000:_ooool2o`0002Cooooo0_l00006ooooo`;o
00005Oooool0027oooooool00014o`0000Cooooo000Yooooo`03o`000?oooooooooo00Wooooo0_l0
000;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_l00004ooooo`Co00002ooo
ool2o`0000?ooooo0_l00006ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo0_l00002ooooo`?o00002Ooo
ool00ol0003oooooooooo`05ooooo`;o00000_ooool00ol0003oooooooooo`09ooooo`;o00002ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`04o`000?oo
ooooooooooooo`;o00001?ooool3o`0000Cooooo0_l00006ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`?o00002oooool00ol0003ooooo
ooooo`0:ooooo`00:Oooool00ol0003oooooooooo`0Hooooo`;o00002oooool2o`0000kooooo0_l0
0003ooooo`03o`000?oooooooooo00;ooooo0_l0000Booooo`;o00004Oooool2o`0000Oooooo0_l0
0007ooooo`03o`000?oooooooooo00kooooo0_l0000Aooooo`;o000000?oooooo`000?l000005?oo
ool00ol0003oooooooooo`03ooooo`;o00002?ooool2o`0000_ooooo0_l000000ooooooo0000o`00
000Kooooo`03o`000?oooooooooo01Sooooo0_l0000Iooooo`;o00001?ooool2o`0000cooooo000Y
ooooo`03o`000?oooooooooo01Sooooo0_l0000>ooooo`;o00002oooool2o`0001;ooooo0_l00006
ooooo`Co00004Oooool2o`0000Oooooo0_l0000Fooooo`Co00005?ooool2o`0003Cooooo0_l0000<
ooooo`;o00001Oooool2o`00023ooooo0ol0000Iooooo`?o00000oooool2o`0000cooooo000Yoooo
o`03o`000?oooooooooo00Kooooo0_l0000Pooooo`;o00007oooool2o`0000Kooooo0_l000000ooo
oooo0000o`000003ooooo`Co00000_ooool2o`0001Sooooo0_l0000<ooooo`?o00008?ooool2o`00
00_ooooo0_l0000Zooooo`;o00001Oooool2o`00023ooooo0_l000000ooooooo0000o`00000Hoooo
o`;o00004Oooool002Wooooo0_l00007ooooo`;o00008Oooool2o`0000Gooooo0_l00003ooooo`;o
00007Oooool2o`0000?ooooo1?l00002ooooo`;o00005oooool3o`0000?ooooo0_l000000ooooooo
0000o`000002o`0001Oooooo0_l00004ooooo`;o00001?ooool4o`0000_ooooo0_l0000=ooooo`;o
00001_ooool2o`0001kooooo0_l0000Nooooo`?o0000:oooool002Wooooo00?o0000ooooooooool0
0_ooool2o`0002Gooooo0_l00005ooooo`;o00000oooool2o`00047ooooo0_l00004ooooo`;o0000
00?oooooo`000?l000000_l0000Gooooo`;o00001?ooool2o`0000Cooooo0_l0000Looooo`;o0000
1_ooool2o`000003ooooool0003o000001_ooooo0_l0000Nooooo`;o0000;?ooool002Wooooo00?o
0000ooooooooool00_ooool2o`0000Wooooo0_l0000Cooooo`?o00004Oooool2o`0000?ooooo0_l0
000Vooooo`;o00002Oooool2o`0001;ooooo0_l0000Qooooo`;o00008_ooool2o`0000Kooooo0_l0
000Mooooo`;o0000B_ooool002Wooooo0_l00004ooooo`;o00002?ooool2o`0001?ooooo0ol0000A
ooooo`;o00000oooool2o`0002Kooooo0_l00009ooooo`;o00005oooool2o`0000_ooooo0_l0000?
ooooo`;o00008_ooool2o`0002Gooooo0_l0000Hooooo`;o0000<?ooool002Wooooo0_l00004oooo
o`;o00002Oooool2o`0000Kooooo0_l0000>ooooo`;o00002oooool2o`0003Kooooo0_l0000Joooo
o`;o00002oooool2o`0004Wooooo0_l0000@ooooo`;o00005oooool2o`0000Cooooo0ol0000Yoooo
o`00:Oooool2o`0000oooooo0_l00006ooooo`;o00003_ooool2o`0000_ooooo0_l0000Rooooo`;o
00004_ooool2o`0001Sooooo0_l00004ooooo`;o00006_ooool2o`0000Gooooo0_l0000Cooooo`;o
00006_ooool2o`00013ooooo0_l0000Mooooo`?o00004?ooool2o`0001Oooooo000Yooooo`03o`00
0?oooooooooo04Cooooo0_l0000Aooooo`;o0000;?ooool2o`0000Cooooo0_l00005ooooo`;o0000
4oooool2o`0000Gooooo0_l0000Cooooo`;o0000@?ooool2o`0000cooooo0_l00007ooooo`;o0000
1Oooool2o`0001Oooooo000Yooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`000003oooo
ool0003o000000;o00003Oooool3o`0000Oooooo0_l00005ooooo`;o00006?ooool2o`0003Wooooo
0_l0000Aooooo`;o00003Oooool2o`0000Gooooo0_l0001Kooooo`;o00003?ooool2o`0000Gooooo
1?l0000Nooooo`00:Oooool01?l0003oooooooooooooool2o`0000;ooooo0_l000000ooooooo0000
o`000002o`0000Sooooo0_l00003ooooo`?o00000oooool2o`0000;ooooo0_l00005ooooo`Co0000
2_ooool2o`0000Kooooo0_l00006ooooo`;o00006_ooool2o`0001Wooooo0ol0000Oooooo`;o0000
1Oooool2o`00013ooooo0_l0000Wooooo`;o00004?ooool2o`0002?ooooo0_l0000Pooooo`00:Ooo
ool00ol0003oooooooooo`0Dooooo`;o00002Oooool2o`0000_ooooo0_l0000:ooooo`;o00001_oo
ool2o`0000Kooooo0_l0000Jooooo`;o00006_ooool2o`00027ooooo0_l0000=ooooo`;o00001_oo
ool2o`0002Oooooo0_l000000ooooooo0000o`00000=ooooo`;o00005_ooool2o`0000oooooo0_l0
000Looooo`00:Oooool2o`0002oooooo0_l00003ooooo`;o00008oooool2o`0000kooooo0_l0000]
ooooo`;o00002_ooool2o`0000gooooo0_l00006ooooo`;o0000:_ooool2o`0000?ooooo0_l00007
ooooo`;o00005oooool2o`0000gooooo1?l0000Looooo`00:Oooool00ol0003oooooooooo`0Hoooo
o`;o00000_ooool2o`00013ooooo0_l00003ooooo`;o00002Oooool2o`0001Sooooo0_l0000>oooo
o`;o00003Oooool2o`0000gooooo0_l0000?ooooo`;o00005?ooool2o`0000cooooo0_l0000Zoooo
o`;o00000_ooool2o`0000Oooooo0_l0000>ooooo`;o00005_ooool2o`0001kooooo000Yooooo`03
o`000?oooooooooo00[ooooo1?l0000:ooooo`;o00000_ooool2o`00023ooooo0_l0000gooooo`;o
00003Oooool2o`0001Sooooo0_l00008ooooo`Go00003?ooool2o`0000?ooooo0_l0000;ooooo`;o
000000?oooooo`000?l000005Oooool2o`0001_ooooo0_l0000fooooo`00:Oooool00ol0003ooooo
ooooo`07ooooo`;o000000?oooooo`000?l000000_l0000Zooooo`;o0000H?ooool2o`0000Cooooo
0_l00008ooooo`Co00001oooool2o`0000Wooooo0_l0000;ooooo`;o000000?oooooo`000?l00000
3oooool2o`0005Wooooo000Yooooo`03o`000?oooooooooo00;o00001Oooool2o`0001Oooooo0_l0
000Fooooo`Co000000?oooooo`000?l000005_ooool2o`0004?ooooo0_l0000Iooooo`;o00008Ooo
ool2o`0000Oooooo0_l0000<ooooo`;o00001Oooool2o`0001Oooooo0_l00004ooooo`;o00003ooo
ool2o`0001Cooooo000Yooooo`;o000000?oooooo`000?l000007_ooool3o`0001Oooooo0_l00000
0ooooooo0000o`00000>ooooo`;o00001_ooool2o`0000Kooooo0_l0001Vooooo`;o00004Oooool2
o`0001Gooooo0_l00005ooooo`;o00005oooool2o`0000Cooooo0_l00009ooooo`;o00001?ooool2
o`0001Cooooo000Yooooo`03o`000?oooooooooo00Gooooo0_l0000:ooooo`;o00003_ooool2o`00
01Sooooo1?l0000>ooooo`;o00003_ooool2o`00057ooooo0_l0000;ooooo`;o00001_ooool2o`00
02gooooo0_l0000Yooooo`?o00001_ooool2o`0001;ooooo0006ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`05ooooo`;o00002_ooool2o`0002Sooooo0_l0001=ooooo`;o00004Oooool2
o`00017ooooo0_l0000;ooooo`;o0000<oooool4o`0000Sooooo0_l0000Gooooo`;o00001_ooool2
o`0000Oooooo0_l0000Booooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo02;ooooo0_l00004ooooo`;o00005?ooool2o`0000kooooo1?l0000Zooooo`;o00003?oo
ool2o`0000Oooooo0_l000000ooooooo0000o`000005ooooo`;o00008?ooool2o`0000Oooooo0_l0
000Xooooo`;o00000oooool2o`0000Gooooo0_l00002ooooo`;o00004oooool2o`0002?ooooo0006
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool2o`0001cooooo0_l00004ooooo`;o00005?oo
ool2o`0000kooooo1?l0000Zooooo`;o00004oooool4o`000003ooooool0003o000002Oooooo0_l0
0007ooooo`;o00003?ooool2o`0000;ooooo0_l00006ooooo`;o00004oooool2o`0000Wooooo0_l0
000@ooooo`;o00000oooool2o`00027ooooo0006ooooo`05o`000?ooooooooooooooool000003Ooo
ool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00004ooooo`;o0000COoo
ool2o`0001Gooooo0_l0000Hooooo`;o00002oooool2o`0001Kooooo0_l0000Iooooo`;o00001?oo
ool2o`0000[ooooo0_l00002ooooo`;o00000oooool5o`00033ooooo0_l00003ooooo`;o00008Ooo
ool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo02gooooo0_l0000Tooooo`;o0000
1oooool2o`0000cooooo0_l0000:ooooo`;o00003?ooool2o`0002?ooooo0_l0000Iooooo`;o0000
1?ooool2o`0001?ooooo1?l0000dooooo`;o00008oooool000Kooooo00Go410@oooooooooooooooo
oa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0]ooooo`;o0000;Oooool2o`0001Sooooo0_l0001`ooooo`?o00006?ooool2o`0000Cooooo
0_l0000<ooooo`;o00008oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo063o
oooo0_l0000Eooooo`;o0000Koooool3o`0001Sooooo0_l00004ooooo`;o0000<Oooool000Kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`00
00Kooooo00?o0000ooooooooool0B?ooool3o`0001Gooooo0_l0000Eooooo`;o00002oooool2o`00
00Cooooo0_l0000`ooooo`;o00009oooool2o`0000Kooooo0_l0001=ooooo`00:Oooool2o`0001go
oooo0_l00009ooooo`;o00005oooool2o`0000Kooooo0ol0000iooooo`;o00001?ooool2o`0000Co
oooo0_l0000Zooooo`;o00007_ooool2o`0000Oooooo0_l00006ooooo`;o0000COooool002Wooooo
00?o0000ooooooooool03oooool2o`0000_ooooo0_l00002ooooo`;o00001Oooool2o`0001Oooooo
0_l0000Iooooo`;o00005oooool2o`0000Wooooo0_l00004ooooo`;o00002Oooool2o`0004[ooooo
0_l0001Nooooo`00:Oooool00ol0003oooooooooo`0;ooooo`;o00000_ooool2o`0000oooooo0_l0
000/ooooo`;o00002oooool2o`0001Oooooo0_l00009ooooo`;o00001?ooool2o`000:Gooooo0_l0
000>ooooo`00:Oooool00ol0003oooooooooo`04ooooo`;o000000?oooooo`000?l000001?l00008
ooooo`;o0000;oooool2o`0000Kooooo0_l0000looooo`;o0000;oooool2o`0003;ooooo0_l0000i
ooooo`;o00003_ooool002Wooooo00?o0000ooooooooool01?ooool2o`000003ooooool0003o0000
00;o00002_ooool2o`0002oooooo0ol0000aooooo`;o00004?ooool2o`0002?ooooo0_l0000:oooo
o`;o00005oooool2o`0001Wooooo0_l0000Xooooo`;o00004_ooool2o`0000_ooooo000Yooooo`;o
0000B?ooool2o`00037ooooo0_l0000Iooooo`;o00006_ooool4o`0001Cooooo0_l0000;ooooo`;o
0000@oooool2o`0001;ooooo0_l0000;ooooo`00:Oooool00ol0003oooooooooo`13ooooo`;o0000
D?ooool2o`0000;ooooo0_l0000Gooooo`?o00005?ooool2o`0001_ooooo0_l0000Hooooo`;o0000
>_ooool002Wooooo00?o0000ooooooooool0@oooool2o`0001Cooooo0_l0000Aooooo`;o0000:ooo
ool2o`0001Wooooo0_l0000`ooooo`;o00006?ooool2o`0003[ooooo000Yooooo`03o`000?oooooo
oooo04Kooooo0_l0000Aooooo`;o000000?oooooo`000?l000003_ooool2o`00023ooooo0_l0000F
ooooo`;o00003?ooool2o`0000_ooooo0_l0000Qooooo`;o000000?oooooo`000?l000000_l0000o
ooooo`;o00004?ooool002Wooooo00?o0000ooooooooool04oooool2o`00037ooooo0_l0000Doooo
o`Go00001?ooool2o`0000Gooooo0_l0000Pooooo`;o00005_ooool2o`0000?ooooo0_l0000Doooo
o`;o00006Oooool2o`0000Kooooo0_l000000ooooooo0000o`000002o`0000Oooooo0_l0000foooo
o`;o00004?ooool002Wooooo0_l0000Dooooo`;o0000>oooool2o`0000cooooo0ol00004ooooo`;o
0000A?ooool2o`00017ooooo0_l0000Looooo`;o00003_ooool2o`0000Cooooo0_l00018ooooo`00
:Oooool00ol0003oooooooooo`1@ooooo`;o00008?ooool2o`0004[ooooo0_l0000/ooooo`;o0000
C_ooool002Wooooo00?o0000ooooooooool03?ooool2o`0002Kooooo0_l0000looooo`;o0000AOoo
ool2o`00087ooooo000Yooooo`03o`000?oooooooooo00cooooo0_l0000Vooooo`;o0000Poooool2
o`00087ooooo000Yooooo`03o`000?oooooooooo01Gooooo0_l0003oooooobKooooo000Yooooo`;o
00005_ooool2o`0005[ooooo0_l0001?ooooo`;o0000=_ooool2o`00043ooooo000Yooooo`03o`00
0?oooooooooo067ooooo0_l0000;ooooo`;o000000?oooooo`000?l00000Coooool2o`0003Kooooo
0_l00010ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`1Qooooo`;o00002oooool2o`0000Go
oooo0_l0000;ooooo`;o00004oooool2o`0004Cooooo0_l0000<ooooo`;o00006?ooool2o`0001?o
oooo0_l0000Pooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0MOooool2o`0000_ooooo0_l0000Cooooo`;o
0000A?ooool2o`0000cooooo0_l00006ooooo`;o00004?ooool4o`00017ooooo0_l0000Pooooo`00
3_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000??o
oooo0_l0000Booooo`;o0000<oooool000kooooo00Go0000ooooooooooooooooo`00000?ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Ol0003ooooo
oooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo
0?oooooo?Oooool000kooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3?ooooo`;o0000>_ooool2o`00
02oooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0000Noooo
o`;o00003?ooool2o`000:;ooooo0_l0000jooooo`;o0000;oooool002Wooooo00?o0000oooooooo
ool07Oooool2o`0000cooooo0_l0003ooooooa3ooooo000Yooooo`03o`000?oooooooooo03Wooooo
0_l0003oooooo`;ooooo000Yooooo`03o`000?oooooooooo03Wooooo0_l0003oooooo`;ooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`001_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooo
oooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o
0000oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qoooooooo
ool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo
00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooo
oooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@
413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3o
ooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006
ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool001oooooo
1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooo
oooo00Gooooo0ol0003oooooocgooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool001oooooo00?oEEEEofIVI_l00000oooooom7
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .39029 Mdot
.02762 .2456 Mdot
.02952 .31274 Mdot
.03143 .25866 Mdot
.03333 .33295 Mdot
.03524 .29664 Mdot
.03714 .30876 Mdot
.03905 .23834 Mdot
.04095 .38897 Mdot
.04286 .26755 Mdot
.04476 .35035 Mdot
.04667 .28254 Mdot
.04857 .39608 Mdot
.05048 .34089 Mdot
.05238 .26869 Mdot
.05429 .34445 Mdot
.05619 .30784 Mdot
.0581 .40165 Mdot
.06 .29365 Mdot
.0619 .23138 Mdot
.06381 .39376 Mdot
.06571 .2565 Mdot
.06762 .27481 Mdot
.06952 .40696 Mdot
.07143 .38068 Mdot
.07333 .36597 Mdot
.07524 .34689 Mdot
.07714 .2665 Mdot
.07905 .24047 Mdot
.08095 .24681 Mdot
.08286 .40101 Mdot
.08476 .38159 Mdot
.08667 .23748 Mdot
.08857 .37316 Mdot
.09048 .35848 Mdot
.09238 .32774 Mdot
.09429 .41213 Mdot
.09619 .26524 Mdot
.0981 .24963 Mdot
.1 .32306 Mdot
.1019 .39904 Mdot
.10381 .38082 Mdot
.10571 .26135 Mdot
.10762 .36863 Mdot
.10952 .39767 Mdot
.11143 .25107 Mdot
.11333 .31226 Mdot
.11524 .41873 Mdot
.11714 .31844 Mdot
.11905 .2319 Mdot
.12095 .42295 Mdot
.12286 .33159 Mdot
.12476 .43667 Mdot
.12667 .32299 Mdot
.12857 .2881 Mdot
.13048 .324 Mdot
.13238 .24119 Mdot
.13429 .31344 Mdot
.13619 .43595 Mdot
.1381 .39864 Mdot
.14 .25914 Mdot
.1419 .44705 Mdot
.14381 .2491 Mdot
.14571 .28822 Mdot
.14762 .26818 Mdot
.14952 .34952 Mdot
.15143 .25757 Mdot
.15333 .33291 Mdot
.15524 .25495 Mdot
.15714 .41221 Mdot
.15905 .36026 Mdot
.16095 .3143 Mdot
.16286 .266 Mdot
.16476 .2708 Mdot
.16667 .24864 Mdot
.16857 .27858 Mdot
.17048 .43686 Mdot
.17238 .2894 Mdot
.17429 .30597 Mdot
.17619 .36317 Mdot
.1781 .408 Mdot
.18 .25775 Mdot
.1819 .27799 Mdot
.18381 .37711 Mdot
.18571 .23268 Mdot
.18762 .34151 Mdot
.18952 .32308 Mdot
.19143 .3002 Mdot
.19333 .28904 Mdot
.19524 .33488 Mdot
.19714 .38176 Mdot
.19905 .22285 Mdot
.20095 .33856 Mdot
.20286 .25821 Mdot
.20476 .33003 Mdot
.20667 .22115 Mdot
.20857 .33584 Mdot
.21048 .42502 Mdot
.21238 .44859 Mdot
.21429 .31047 Mdot
.21619 .37893 Mdot
.2181 .25553 Mdot
.22 .26637 Mdot
.2219 .3522 Mdot
.22381 .41329 Mdot
.22571 .37901 Mdot
.22762 .3683 Mdot
.22952 .33123 Mdot
.23143 .33871 Mdot
.23333 .41144 Mdot
.23524 .31293 Mdot
.23714 .25848 Mdot
.23905 .38828 Mdot
.24095 .27717 Mdot
.24286 .48142 Mdot
.24476 .31803 Mdot
.24667 .2767 Mdot
.24857 .30044 Mdot
.25048 .33808 Mdot
.25238 .39387 Mdot
.25429 .39242 Mdot
.25619 .45907 Mdot
.2581 .34757 Mdot
.26 .25036 Mdot
.2619 .4125 Mdot
.26381 .26399 Mdot
.26571 .25846 Mdot
.26762 .24968 Mdot
.26952 .33712 Mdot
.27143 .26467 Mdot
.27333 .28699 Mdot
.27524 .35908 Mdot
.27714 .3186 Mdot
.27905 .32183 Mdot
.28095 .24129 Mdot
.28286 .28918 Mdot
.28476 .41321 Mdot
.28667 .23231 Mdot
.28857 .26107 Mdot
.29048 .22751 Mdot
.29238 .28651 Mdot
.29429 .41234 Mdot
.29619 .30286 Mdot
.2981 .25819 Mdot
.3 .31118 Mdot
.3019 .24111 Mdot
.30381 .25338 Mdot
.30571 .44037 Mdot
.30762 .3179 Mdot
.30952 .27615 Mdot
.31143 .46212 Mdot
.31333 .24879 Mdot
.31524 .29204 Mdot
.31714 .41036 Mdot
.31905 .30305 Mdot
.32095 .34753 Mdot
.32286 .38617 Mdot
.32476 .27615 Mdot
.32667 .31188 Mdot
.32857 .40873 Mdot
.33048 .39346 Mdot
.33238 .36891 Mdot
.33429 .31476 Mdot
.33619 .41331 Mdot
.3381 .37144 Mdot
.34 .28144 Mdot
.3419 .3882 Mdot
.34381 .26568 Mdot
.34571 .40696 Mdot
.34762 .26189 Mdot
.34952 .3973 Mdot
.35143 .25674 Mdot
.35333 .33724 Mdot
.35524 .29906 Mdot
.35714 .33241 Mdot
.35905 .34226 Mdot
.36095 .24316 Mdot
.36286 .22655 Mdot
.36476 .33819 Mdot
.36667 .327 Mdot
.36857 .24129 Mdot
.37048 .37554 Mdot
.37238 .3534 Mdot
.37429 .30775 Mdot
.37619 .40866 Mdot
.3781 .31325 Mdot
.38 .40133 Mdot
.3819 .26112 Mdot
.38381 .37717 Mdot
.38571 .40261 Mdot
.38762 .24351 Mdot
.38952 .46089 Mdot
.39143 .23992 Mdot
.39333 .26151 Mdot
.39524 .4552 Mdot
.39714 .22592 Mdot
.39905 .44226 Mdot
.40095 .29011 Mdot
.40286 .27626 Mdot
.40476 .28375 Mdot
.40667 .38427 Mdot
.40857 .30811 Mdot
.41048 .3142 Mdot
.41238 .32082 Mdot
.41429 .34732 Mdot
.41619 .31496 Mdot
.4181 .37515 Mdot
.42 .32321 Mdot
.4219 .32069 Mdot
.42381 .25835 Mdot
.42571 .33259 Mdot
.42762 .35229 Mdot
.42952 .35706 Mdot
.43143 .2818 Mdot
.43333 .40649 Mdot
.43524 .33376 Mdot
.43714 .3856 Mdot
.43905 .25959 Mdot
.44095 .41434 Mdot
.44286 .32501 Mdot
.44476 .39075 Mdot
.44667 .30224 Mdot
.44857 .27129 Mdot
.45048 .4347 Mdot
.45238 .4106 Mdot
.45429 .40015 Mdot
.45619 .34375 Mdot
.4581 .35963 Mdot
.46 .2528 Mdot
.4619 .33767 Mdot
.46381 .27378 Mdot
.46571 .45558 Mdot
.46762 .33279 Mdot
.46952 .27559 Mdot
.47143 .30696 Mdot
.47333 .27766 Mdot
.47524 .34476 Mdot
.47714 .46063 Mdot
.47905 .27901 Mdot
.48095 .33444 Mdot
.48286 .35787 Mdot
.48476 .36589 Mdot
.48667 .4481 Mdot
.48857 .26023 Mdot
.49048 .38387 Mdot
.49238 .35932 Mdot
.49429 .36949 Mdot
.49619 .31443 Mdot
.4981 .3621 Mdot
.5 .24564 Mdot
.5019 .35658 Mdot
.50381 .25782 Mdot
.50571 .43485 Mdot
.50762 .32119 Mdot
.50952 .26478 Mdot
.51143 .37581 Mdot
.51333 .36277 Mdot
.51524 .31018 Mdot
.51714 .25078 Mdot
.51905 .28739 Mdot
.52095 .22872 Mdot
.52286 .43047 Mdot
.52476 .29587 Mdot
.52667 .345 Mdot
.52857 .39102 Mdot
.53048 .28742 Mdot
.53238 .24503 Mdot
.53429 .3967 Mdot
.53619 .31987 Mdot
.5381 .2458 Mdot
.54 .29925 Mdot
.5419 .36993 Mdot
.54381 .29397 Mdot
.54571 .26718 Mdot
.54762 .2716 Mdot
.54952 .34039 Mdot
.55143 .3858 Mdot
.55333 .29113 Mdot
.55524 .36116 Mdot
.55714 .41728 Mdot
.55905 .3527 Mdot
.56095 .34281 Mdot
.56286 .26173 Mdot
.56476 .27435 Mdot
.56667 .30919 Mdot
.56857 .40608 Mdot
.57048 .25241 Mdot
.57238 .33771 Mdot
.57429 .27023 Mdot
.57619 .35857 Mdot
.5781 .30697 Mdot
.58 .25622 Mdot
.5819 .41234 Mdot
.58381 .26535 Mdot
.58571 .4342 Mdot
.58762 .24553 Mdot
.58952 .43231 Mdot
.59143 .31884 Mdot
.59333 .43546 Mdot
.59524 .45858 Mdot
.59714 .33887 Mdot
.59905 .2577 Mdot
.60095 .4071 Mdot
.60286 .3485 Mdot
.60476 .24381 Mdot
.60667 .3477 Mdot
.60857 .37386 Mdot
.61048 .38114 Mdot
.61238 .32929 Mdot
.61429 .42101 Mdot
.61619 .36806 Mdot
.6181 .27104 Mdot
.62 .34439 Mdot
.6219 .32714 Mdot
.62381 .38069 Mdot
.62571 .46256 Mdot
.62762 .31177 Mdot
.62952 .39491 Mdot
.63143 .38163 Mdot
.63333 .2483 Mdot
.63524 .27409 Mdot
.63714 .35657 Mdot
.63905 .44872 Mdot
.64095 .37258 Mdot
.64286 .30395 Mdot
.64476 .3339 Mdot
.64667 .37344 Mdot
.64857 .2784 Mdot
.65048 .35609 Mdot
.65238 .30528 Mdot
.65429 .31845 Mdot
.65619 .35707 Mdot
.6581 .27427 Mdot
.66 .36291 Mdot
.6619 .33029 Mdot
.66381 .31616 Mdot
.66571 .26492 Mdot
.66762 .32113 Mdot
.66952 .24905 Mdot
.67143 .28672 Mdot
.67333 .27891 Mdot
.67524 .36918 Mdot
.67714 .35372 Mdot
.67905 .41917 Mdot
.68095 .364 Mdot
.68286 .29073 Mdot
.68476 .28389 Mdot
.68667 .27549 Mdot
.68857 .35019 Mdot
.69048 .23682 Mdot
.69238 .24176 Mdot
.69429 .32696 Mdot
.69619 .25261 Mdot
.6981 .4131 Mdot
.7 .28227 Mdot
.7019 .43656 Mdot
.70381 .30998 Mdot
.70571 .35529 Mdot
.70762 .3809 Mdot
.70952 .26185 Mdot
.71143 .25351 Mdot
.71333 .27882 Mdot
.71524 .35022 Mdot
.71714 .37823 Mdot
.71905 .31051 Mdot
.72095 .36297 Mdot
.72286 .41689 Mdot
.72476 .32085 Mdot
.72667 .30157 Mdot
.72857 .28606 Mdot
.73048 .23293 Mdot
.73238 .31647 Mdot
.73429 .41338 Mdot
.73619 .35759 Mdot
.7381 .33335 Mdot
.74 .38347 Mdot
.7419 .41909 Mdot
.74381 .33861 Mdot
.74571 .42571 Mdot
.74762 .32469 Mdot
.74952 .26196 Mdot
.75143 .43456 Mdot
.75333 .27116 Mdot
.75524 .35695 Mdot
.75714 .46854 Mdot
.75905 .40704 Mdot
.76095 .36525 Mdot
.76286 .2827 Mdot
.76476 .43593 Mdot
.76667 .28501 Mdot
.76857 .3194 Mdot
.77048 .36718 Mdot
.77238 .41303 Mdot
.77429 .30418 Mdot
.77619 .26055 Mdot
.7781 .34146 Mdot
.78 .33787 Mdot
.7819 .41093 Mdot
.78381 .40322 Mdot
.78571 .45693 Mdot
.78762 .36043 Mdot
.78952 .36067 Mdot
.79143 .39198 Mdot
.79333 .37414 Mdot
.79524 .34017 Mdot
.79714 .35737 Mdot
.79905 .28931 Mdot
.80095 .25788 Mdot
.80286 .27603 Mdot
.80476 .34806 Mdot
.80667 .33391 Mdot
.80857 .32864 Mdot
.81048 .32968 Mdot
.81238 .45709 Mdot
.81429 .26132 Mdot
.81619 .36857 Mdot
.8181 .29719 Mdot
.82 .2895 Mdot
.8219 .271 Mdot
.82381 .29155 Mdot
.82571 .36575 Mdot
.82762 .32326 Mdot
.82952 .31507 Mdot
.83143 .46069 Mdot
.83333 .2278 Mdot
.83524 .27687 Mdot
.83714 .3475 Mdot
.83905 .36806 Mdot
.84095 .36487 Mdot
.84286 .36456 Mdot
.84476 .28087 Mdot
.84667 .44229 Mdot
.84857 .22941 Mdot
.85048 .32663 Mdot
.85238 .48954 Mdot
.85429 .35404 Mdot
.85619 .28833 Mdot
.8581 .38235 Mdot
.86 .29478 Mdot
.8619 .35064 Mdot
.86381 .24459 Mdot
.86571 .42373 Mdot
.86762 .33039 Mdot
.86952 .27827 Mdot
.87143 .34985 Mdot
.87333 .39092 Mdot
.87524 .36811 Mdot
.87714 .24846 Mdot
.87905 .32827 Mdot
.88095 .35266 Mdot
.88286 .38105 Mdot
.88476 .32023 Mdot
.88667 .31884 Mdot
.88857 .2733 Mdot
.89048 .23791 Mdot
.89238 .28856 Mdot
.89429 .29332 Mdot
.89619 .26885 Mdot
.8981 .39791 Mdot
.9 .27482 Mdot
.9019 .41271 Mdot
.90381 .34834 Mdot
.90571 .24013 Mdot
.90762 .25658 Mdot
.90952 .28145 Mdot
.91143 .43656 Mdot
.91333 .31745 Mdot
.91524 .43609 Mdot
.91714 .36764 Mdot
.91905 .27012 Mdot
.92095 .23772 Mdot
.92286 .37641 Mdot
.92476 .30467 Mdot
.92667 .25095 Mdot
.92857 .37471 Mdot
.93048 .44341 Mdot
.93238 .24515 Mdot
.93429 .27717 Mdot
.93619 .28801 Mdot
.9381 .35885 Mdot
.94 .32129 Mdot
.9419 .30883 Mdot
.94381 .32695 Mdot
.94571 .24112 Mdot
.94762 .32745 Mdot
.94952 .35001 Mdot
.95143 .34666 Mdot
.95333 .33497 Mdot
.95524 .39656 Mdot
.95714 .25507 Mdot
.95905 .25756 Mdot
.96095 .29058 Mdot
.96286 .48402 Mdot
.96476 .28464 Mdot
.96667 .24731 Mdot
.96857 .43355 Mdot
.97048 .36376 Mdot
.97238 .25233 Mdot
.97429 .23233 Mdot
.97619 .33012 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo03Oooooo0_l0003oooooo`Cooooo0006ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`0eooooo`Co0000ooooool4ooooo`001_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo03Gooooo0_l0000Kooooo`;o00005Oooool2o`0000Wooooo0_l0
002;ooooo`;o0000>Oooool000Co00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05;ooooo0_l0
000Eooooo`;o00002Oooool2o`0002Kooooo0_l0001Sooooo`;o00000_ooool2o`0003Gooooo0006
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol00009ooooo`;o00004?ooool2o`0001?ooooo0_l0000Oooooo`;o0000BOoo
ool2o`00047ooooo0_l0000Tooooo`;o00009oooool2o`0000cooooo0006ooooo`05o`000?oooooo
ooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`09ooooo`;o00004?ooool2o`0001?ooooo0_l0000Oooooo`;o0000
P?ooool2o`0000[ooooo0_l0001=ooooo`;o00003?ooool000Kooooo00Go410@oooooooooooooooo
oa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool01?l0003ooooo
ooooooooool2o`0000gooooo0_l0001Pooooo`;o0000Goooool2o`0003kooooo0_l00003ooooo`;o
00000oooool2o`0001gooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o
^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool01?l0003oooooooooooooool2
o`0000_ooooo1?l0000=ooooo`;o0000;_ooool2o`0000Gooooo0_l0000Aooooo`Co00001?ooool3
o`0005oooooo0_l0000nooooo`;o00000oooool2o`0000?ooooo0_l00006ooooo`;o00005Oooool0
00Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?oo
ool4o`0000Kooooo0_l0000?ooooo`;o00003oooool2o`0002kooooo0_l00005ooooo`;o00004Ooo
ool4o`0000Cooooo0_l0000Rooooo`;o00002Oooool4o`0000kooooo0_l00003ooooo`;o00006_oo
ool2o`0003Gooooo0_l0000Dooooo`;o00000oooool2o`0001Gooooo000Yooooo`;o00004?ooool2
o`0000?ooooo0_l0000=ooooo`;o00001Oooool2o`0001oooooo0_l0000<ooooo`;o0000>_ooool2
o`0000Wooooo1?l0000>ooooo`;o00000oooool2o`0000Oooooo0_l0000:ooooo`;o0000??ooool2
o`0000?ooooo0_l0000?ooooo`;o00002Oooool2o`0000oooooo000Yooooo`03o`000?oooooooooo
00oooooo0_l00003ooooo`;o00000_ooool2o`0000Wooooo0_l00005ooooo`;o00007?ooool2o`00
0003ooooool0003o000000cooooo0_l0000^ooooo`;o00004?ooool2o`0000oooooo0_l0000Boooo
o`;o00002_ooool2o`0000Kooooo0_l0000iooooo`;o00003_ooool2o`0000[ooooo1?l0000=oooo
o`00:Oooool00ol0003oooooooooo`0Hooooo`;o00003Oooool2o`0001;ooooo0_l0000;ooooo`;o
00003?ooool2o`00037ooooo0_l0000@ooooo`;o00003oooool2o`0002Kooooo0_l00003ooooo`;o
0000A?ooool2o`0000Oooooo0_l00003ooooo`;o00003Oooool002Wooooo00Co0000ooooool0003o
00002Oooool2o`0001Wooooo1?l00005ooooo`;o00001_ooool2o`0000?ooooo0_l00004ooooo`;o
00001oooool2o`0000Sooooo1?l0000>ooooo`;o00005Oooool2o`0001Sooooo0_l0000Fooooo`;o
00001?ooool2o`0002;ooooo0_l0000Kooooo`;o00008?ooool2o`0000kooooo0ol0000Aooooo`00
:Oooool01?l0003oooooo`000?l00009ooooo`;o00002oooool2o`0000Wooooo0_l000000ooooooo
0000o`000007ooooo`;o00001_ooool2o`0000Wooooo0_l00007ooooo`;o00001Oooool2o`000003
ooooool0003o000000kooooo1?l00007ooooo`;o00000_ooool2o`0000Sooooo0_l00003ooooo`;o
00003_ooool2o`0000?ooooo0_l0000Aooooo`;o00000oooool2o`0000Cooooo0_l0000Rooooo`;o
00002oooool2o`0000Kooooo0_l00006ooooo`;o00000_ooool2o`0001cooooo0_l0000?ooooo`;o
00004Oooool002Wooooo0_l0000Eooooo`;o000000?oooooo`000?l000002Oooool2o`0002Gooooo
0_l000000ooooooo0000o`000003ooooo`;o00004Oooool2o`0000Wooooo0_l00002ooooo`;o0000
3Oooool2o`0000kooooo0_l00004ooooo`;o00004?ooool2o`0001oooooo0_l0000<ooooo`;o0000
2oooool2o`0000Kooooo0_l0000:ooooo`;o0000@?ooool002Wooooo00?o0000ooooooooool00_oo
ool2o`0000Wooooo0_l00005ooooo`;o00003_ooool2o`0000?ooooo0_l0000@ooooo`;o00003?oo
ool2o`000003ooooool0003o000001Gooooo0_l0000cooooo`;o00002_ooool2o`0000[ooooo0_l0
000Iooooo`;o0000Koooool002Wooooo00?o0000ooooooooool00_ooool2o`000003ooooool0003o
000000Kooooo0_l0000Eooooo`;o00000oooool3o`0000Cooooo1?l000001ol@413oooooooooooo^
k^ko<S8bo`000?lb<S800_l00002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07oooool2o`0000So
oooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo0_l0000Mooooo`;o00001?ooool00onHV9So410@o`000002o`000008ooooool0003o
0000onk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_l0003o0000oc8b<_o^k^h0:?ooool4o`00
0009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Kok^k^oc8b<_l0003o
<S8bonk^k_ooool2o`0001Kooooo0_l00005ooooo`;o00001oooool01Om4A4Co0000o`000?lb<S;o
gMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool002Wooooo00?o0000ooooooooool01Oooool2o`0002?ooooo0_l00006ooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0:Oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool2o`0000?ooooo0_l0000Iooooo`;o00000ooo
ool2o`000003ooooool0003o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMg
Mol0003o0000oiRHV?mgMgL00_ooool2o`0000Gooooo0_l0000Mooooo`;o000000?oooooo`000?oo
ool00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00KoMgMgoiRHV?ooooooV9RHogMgMooo
ool2o`0001?ooooo0_l000000ooooooo0000o`000005ooooo`;o00002_ooool02OmgMgOo<S8boooo
ooooooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0
02Wooooo00?o0000ooooooooool02_ooool2o`0002Kooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01?l0000Booooo`;o00000oooool2
o`0000oooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o0000o`000?oooooo410@00?ooooo00Go
410@oooooooooooooooooa0@4008ooooo`Go00005_ooool2o`0000?ooooo0_l00002ooooo`05o`00
0?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooo
ooooool00_l00005ooooo`;o00001oooool2o`0001Cooooo1Ol00003ooooo`05oa0@4?oooooooooo
ooooool@41000oooool2o`0000;ooooo00?o410@ooooooooool00oooool2o`0000oooooo0_l00002
ooooo`;o00002Oooool2o`0000Kooooo00Co0000oooooooooooo410@0oooool01Ol@413ooooooooo
oooooooo410@00?ooooo00?o410@ooooooooool00Oooool002Wooooo0_l0000;ooooo`;o00007ooo
ool2o`0000;ooooo0_l000000ooooooo0000ooooo`03ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`04o`0001;ooooo0_l00003ooooo`;o00004?ooool00onHV9So8B4Q
onk^kP03ooooo`?o000000?oooooo`000?ooool00_ooool01Ol0003ooooooooooooooooo000000[o
oooo1Ol0000Looooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001_ooool2o`0000Kooooo0_l00002ooooo`;o00001oooool2
o`0000_ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000000?ooooo
0_l00002ooooo`03o`000?oooooooooo00?ooooo0_l00009ooooo`;o00002?ooool2o`0000Wooooo
0_l00005ooooo`05ogMgMolb<S;oooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool00Oooool002Wooooo00?o0000ooooooooool01?ooool2o`0002Go
oooo0_l00002ooooo`;o000000?oooooo`000?ooool00oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`;o00003?ooool00omgMgOoIVIVooooo`02
ooooo`03o`000?oooooo000000;o00000oooool00ol0003oooooo`000002o`0000gooooo0_l0000K
ooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001_ooool2o`0000Kooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo
0_l0000;ooooo`03omgMgOmEEEGooooo00;o00000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000008ooooo`;o00001_ooool2o`0000_ooooo0_l0000:oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`00:Oooool00ol0003oooooooooo`04ooooo`;o0000;?oo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooo
oooooooooooo410@00Wooooo0_l00004ooooo`;o00003Oooool2o`0000gooooo00Ko0000oooooooo
oooooooooa0@4?ooool2o`000006oa0@4?ooooooooooooooool@413ooooo0_l000000ol@413ooooo
ooooo`0Yooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@41003_ooool2o`0000;ooooo0_l00003ooooo`;o00001oooool2o`00
00Oooooo00?oMgMgolc<c?l000000_l00002ooooo`05oa0@4?ooooooooooooooool@41000oooool0
1Ol@413ooooooooooooooooo410@00Sooooo0_l0000Cooooo`;o00002_ooool00ol0003ooooooooo
o`03ooooo`;o00000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0
0Oooool002Wooooo00?o0000ooooooooool07_ooool2o`0000?ooooo0_l00007ooooo`;o00001?oo
ool3o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02Oooool2o`000004ooooool0003o0000ooooo`;o00006?ooool01Ol0003o^[ZjoooooonHV9So
410@00?ooooo00GoMgMgo`000?l0003oV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
6_ooool2o`000003ooooool0003o000000Wooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo0_l0000@
ooooo`;o00001oooool00oo^k^koA4A4o`000002o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`02ooooo`;o000000CoV9RHoooooonHV9SoMgMg0_l0000:ooooo`;o00002_ooool2o`0000cooooo
0_l000000ooooooo0000ooooo`04ooooo`;o000000CoV9RHoooooonHV9SoMgMg0oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo000Yooooo`03o`000?oooooooooo01kooooo0_l00003ooooo`;o
00001oooool2o`0000;ooooo00?oEEEEofIVI_l000000_l00002ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo0_l00008ooooo`;o00004Oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^o`000?l0003o<S8bonk^kP03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h06_ooool2o`000003ooooool0003o000000Kooooo0_l000001_oooooo
ZJVYoa0@4?l0003o410@ojVYZ@?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h04Oooool2o`0001Oooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00;ooooo0_l000001?lb<S;o0000oc8b<_o^k^h4o`0000Sooooo0_l0000:oooo
o`;o00003?ooool2o`000003ooooool0003o000000;o000000Soooooo`000?l0003ok^k^oc8b<_l0
003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool2o`0000Wooooo
0_l0001@ooooo`;o0000@Oooool2o`0000Cooooo0_l00002ooooo`;o00009oooool2o`0002cooooo
0_l00009ooooo`;o00002Oooool2o`0001Cooooo0_l0000@ooooo`00:Oooool00ol0003ooooooooo
o`02o`0000Kooooo0_l0001Mooooo`;o0000=?ooool2o`0000?ooooo0ol0001Gooooo`;o00002ooo
ool2o`0000Wooooo0_l0000Vooooo`00:Oooool00ol0003oooooooooo`02o`00033ooooo0_l0000A
ooooo`;o00008?ooool2o`0001_ooooo0_l0000Looooo`;o0000>_ooool2o`0001cooooo0_l0000n
ooooo`00:Oooool00ol0003oooooooooo`0booooo`;o00004Oooool2o`0000gooooo0_l00005oooo
o`;o00009oooool2o`0003gooooo0_l000000ooooooo0000o`00000Fooooo`;o00003_ooool2o`00
02kooooo0_l0000Looooo`00:Oooool01?l0003oooooooooooooool2o`0000Cooooo0_l0000Toooo
o`;o00009Oooool2o`0000Gooooo0_l0000@ooooo`;o00002Oooool2o`0001;ooooo0_l0000Poooo
o`;o00004oooool2o`000003ooooool0003o000002Kooooo0_l0000^ooooo`;o00007?ooool0027o
ooooool00014o`0000Cooooo000Yooooo`?o00002Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00;o00001Oooool3o`0000Gooooo0_l00004ooooo`03o`000?oooooooooo00Wooooo
0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`09ooooo`04o`000?oooooo0000o`0000Oo
oooo1?l00009ooooo`03o`000?oooooooooo00;o00002?ooool4o`0000Sooooo00?o0000oooooooo
ool02Oooool01?l0003oooooooooooooool2o`0000Cooooo0ol0000<ooooo`04o`000?oooooo0000
o`0000Sooooo00?o0000ooooooooool01_ooool2o`000003ooooool0003ooooo00[ooooo00?o0000
ooooooooool01oooool2o`000003ooooool0003ooooo00;o00002?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Wooooo0_l0000:ooooo`03o`000?oooooooooo00[ooooo000Yoooo
o`?o00006Oooool2o`0000Gooooo0_l00006ooooo`;o00004?ooool00ol0003oooooooooo`03oooo
o`;o000000?oooooo`000?l000004oooool2o`0000Kooooo0_l0000<ooooo`;o00002?ooool4o`00
01Sooooo0_l0000Oooooo`03o`000?oooooooooo01;ooooo0_l0000Dooooo`;o00004?ooool00ol0
003oooooooooo`0:ooooo`;o00006Oooool2o`0001?ooooo00?o0000ooooooooool02_ooool002Wo
oooo00?o0000ooooooooool06_ooool2o`0002Oooooo0_l00009ooooo`;o00002?ooool2o`0001oo
oooo0_l000000ooooooo0000o`00000Jooooo`;o00001oooool2o`00013ooooo0_l0000Booooo`;o
000000Coooooo`000?l0003o00004Oooool4o`0000[ooooo0_l0000Aooooo`;o00004?ooool3o`00
00Kooooo0_l0000Pooooo`00:Oooool00ol0003oooooooooo`0Eooooo`;o00000oooool2o`000003
ooooool0003o000000;o00004Oooool2o`0001[ooooo0_l0000Yooooo`;o000000?oooooo`000?l0
00006_ooool2o`0000Oooooo0_l0000@ooooo`;o00004_ooool2o`0000;ooooo0_l0000Aooooo`;o
00003?ooool2o`00017ooooo0_l0000@ooooo`?o00003oooool2o`0001Oooooo000Yooooo`;o0000
5_ooool2o`0000Kooooo1?l0000Aooooo`;o00006_ooool2o`0001_ooooo0_l0000?ooooo`;o0000
1Oooool2o`0003Sooooo0_l0000Eooooo`;o00003oooool2o`0001Sooooo0_l00005ooooo`;o0000
6oooool4o`0001Gooooo000Yooooo`03o`000?oooooooooo01;ooooo0_l0000Rooooo`;o0000<ooo
ool2o`0001Kooooo0_l0000eooooo`;o000000?oooooo`000?l000002_ooool2o`0000Wooooo0_l0
000?ooooo`;o00004_ooool2o`0000_ooooo0_l00004ooooo`;o000000?oooooo`000?l000004ooo
ool3o`0000Sooooo0_l0000;ooooo`00:Oooool01?l0003oooooo`000?l0000Aooooo`;o00002?oo
ool2o`0000Sooooo0_l0000>ooooo`;o00001_ooool2o`0002Oooooo0_l0000Dooooo`;o00003?oo
ool2o`0002gooooo0_l0000=ooooo`;o00005oooool2o`0001Gooooo0_l0000Aooooo`;o000000?o
ooooo`000?l000007_ooool2o`0000_ooooo000Yooooo`04o`000?oooooo0000o`0001_ooooo0_l0
0008ooooo`;o00002oooool2o`0000?ooooo0_l00004ooooo`;o00009oooool2o`0001Cooooo0_l0
0002ooooo`;o00002?ooool2o`0000;ooooo0_l0000cooooo`;o00007?ooool2o`0001Cooooo0_l0
000]ooooo`;o00004oooool002Wooooo00?o0000ooooooooool0<oooool4o`000003ooooool0003o
000000Gooooo0_l00004ooooo`;o00001?ooool2o`0001Wooooo0_l00002ooooo`;o00005Oooool2
o`0000Kooooo0_l00004ooooo`;o00007?ooool2o`0000Kooooo0_l0000=ooooo`;o00007_ooool2
o`0000Wooooo0_l00007ooooo`;o0000;Oooool2o`0001?ooooo000Yooooo`;o00001_ooool2o`00
02[ooooo0_l00002ooooo`;o00002?ooool2o`0000Cooooo0_l00004ooooo`;o00006Oooool6o`00
01gooooo0_l0000Jooooo`;o00000_ooool2o`0000;ooooo0_l00006ooooo`;o0000;Oooool2o`00
00Wooooo0_l00003ooooo`;o0000A_ooool002Wooooo00?o0000ooooooooool01Oooool3o`0002Wo
oooo0_l0000eooooo`;o00007Oooool2o`0000Cooooo0_l0000?ooooo`;o00001Oooool2o`0000;o
oooo0_l0000Aooooo`;o0000<Oooool2o`0000?ooooo0_l00016ooooo`00:Oooool00ol0003ooooo
ooooo`06ooooo`;o00001Oooool2o`0003Wooooo0_l0000Booooo`;o00007?ooool2o`0000_ooooo
0_l00004ooooo`;o00003oooool2o`0001Kooooo1?l00002ooooo`;o0000>Oooool2o`0000Wooooo
0_l0000Cooooo`;o00003_ooool2o`0001?ooooo000Yooooo`03o`000?oooooooooo00?ooooo0_l0
0008ooooo`;o00005_ooool2o`0001Gooooo0_l0000:ooooo`;o00004_ooool2o`0001cooooo0_l0
0002ooooo`;o0000=_ooool4o`0001Sooooo0_l00007ooooo`;o00006_ooool2o`0000Wooooo0_l0
0006ooooo`;o000000?oooooo`000?l000002?ooool2o`0000gooooo0ol0000Cooooo`00:Oooool0
0ol0003oooooooooo`03ooooo`;o00008?ooool2o`0001Gooooo0_l0000^ooooo`;o00004?ooool2
o`0002Sooooo0_l0000Tooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`00000Z
ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00000Dooooo`;o00005?oo
ool002Wooooo0_l0000Cooooo`;o0000F?ooool2o`00017ooooo0_l0000?ooooo`;o00001?ooool2
o`00013ooooo0_l00004ooooo`;o00004Oooool2o`0000?ooooo1?l00004ooooo`;o00002?ooool2
o`0000Oooooo0_l00004ooooo`;o00003?ooool2o`00013ooooo0_l00007ooooo`;o0000:_ooool0
02Wooooo00?o0000ooooooooool04_ooool2o`0001Cooooo0_l0000Sooooo`;o0000<?ooool2o`00
00Oooooo0_l00006ooooo`;o000000Coooooo`000?l0003ooooo0_l0000?ooooo`;o00001Oooool2
o`00017ooooo0_l00003ooooo`Co00005oooool2o`0000Cooooo0_l00009ooooo`;o000000?ooooo
o`000?l00000:oooool2o`0001Sooooo000Yooooo`03o`000?oooooooooo02Sooooo0_l00003oooo
o`;o00007_ooool2o`0003Wooooo0_l00009ooooo`Co00000oooool2o`0000_ooooo0_l0000Poooo
o`;o00001Oooool2o`0000[ooooo0_l0000Dooooo`;o00004?ooool2o`0001cooooo0_l00009oooo
o`;o00003Oooool002Wooooo00?o0000ooooooooool03?ooool2o`0001oooooo0_l0001Qooooo`;o
00000oooool2o`0000?ooooo0_l0000]ooooo`;o00001Oooool2o`0000[ooooo0_l0000;ooooo`;o
000000?oooooo`000?l000004?ooool2o`0000?ooooo0ol0000Fooooo`;o00003oooool2o`0000go
oooo000Yooooo`03o`000?oooooooooo00cooooo0_l00009ooooo`;o00009Oooool2o`0001oooooo
0_l0000_ooooo`;o00000_ooool2o`0000gooooo0_l0000Fooooo`;o00004Oooool2o`0001Wooooo
0_l000000ooooooo0000o`00000=ooooo`;o000000?oooooo`000?l000000_ooool3o`0000Wooooo
0_l0000<ooooo`;o00007_ooool002Wooooo0_l0000Booooo`;o00001?ooool2o`0002Gooooo0_l0
000Oooooo`Co0000<Oooool2o`0000gooooo0_l0000Cooooo`;o000000?oooooo`000?l000001_oo
ool4o`0000Oooooo0_l0000[ooooo`;o00001Oooool2o`0000[ooooo0_l0000/ooooo`00:Oooool0
0ol0003oooooooooo`0Aooooo`;o00007Oooool2o`0002oooooo0_l00009ooooo`;o00000_ooool2
o`0000Wooooo0_l0000Looooo`;o00007Oooool2o`0000Wooooo1?l0000]ooooo`;o00009oooool4
o`0001_ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0`ooooo`;o00002?oo
ool2o`000003ooooool0003o000002gooooo0_l00002ooooo`;o00002Oooool2o`0001cooooo0_l0
0010ooooo`;o00005oooool2o`0002Oooooo1?l0000Kooooo`001_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo00cooooo0_l00002ooooo`;o00001?ooool2o`0001cooooo
0_l00004ooooo`;o000000?oooooo`000?l00000N_ooool2o`0000;ooooo0_l000000ooooooo0000
o`00000Fooooo`;o000000?oooooo`000?l00000;?ooool2o`0000Gooooo0_l0000Zooooo`001_oo
ool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00cooooo0_l00002ooooo`;o00001?ooool2o`0001cooooo
0_l0000Vooooo`;o00006Oooool2o`0000Sooooo0_l0000?ooooo`;o00004_ooool2o`00017ooooo
0_l00002ooooo`;o000000?oooooo`000?l000005_ooool2o`0000Wooooo0_l0000Tooooo`;o0000
1Oooool2o`0002[ooooo0006ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Q
onk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00002ooooo`;o0000?Oooool2o`0001Wooooo
0_l00005ooooo`;o00004_ooool2o`0000Sooooo0_l0000?ooooo`;o00004_ooool2o`0003_ooooo
0_l0001Gooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool0
0oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo0_l00003ooooo`;o0000?Oooool2o`0000?o
oooo0_l0000Kooooo`;o00007oooool2o`0001Wooooo0_l0001Booooo`;o00006?ooool2o`0002go
oooo0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Oooooo0_l0000:ooooo`;o0000>oooool2o`0001Oooooo0_l0000Sooooo`;o
00006Oooool2o`0001kooooo0_l0000booooo`;o00006?ooool2o`0002gooooo0006ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`04ooooo`;o00000oooool2o`0000gooooo0_l00007oooo
o`;o00008oooool2o`0001Oooooo0_l00004ooooo`;o0000>Oooool2o`0001gooooo0_l0001Doooo
o`;o00004Oooool2o`0001;ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnH
V9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo00Cooooo0_l00000
0ooooooo0000o`000006ooooo`;o00001?ooool2o`000003ooooool0003o000000Oooooo0_l00012
ooooo`;o00002?ooool2o`0001Kooooo0_l0000Gooooo`;o0000Loooool2o`00017ooooo0_l0000B
ooooo`00:Oooool2o`0000Sooooo0_l00006ooooo`;o00001?ooool2o`0005Sooooo1?l0000Doooo
o`;o0000J?ooool2o`0004Wooooo000Yooooo`03o`000?oooooooooo00_ooooo0_l0000Qooooo`;o
0000=?ooool2o`0000_ooooo0_l0000=ooooo`;o0000:Oooool2o`0000Wooooo0_l0000aooooo`;o
00001_ooool2o`0004Wooooo000Yooooo`03o`000?oooooooooo00_ooooo0_l0000Qooooo`;o0000
4?ooool2o`0001Wooooo0_l000000ooooooo0000o`000004ooooo`;o00002?ooool2o`00013ooooo
0_l00004ooooo`;o00008oooool2o`0000Wooooo0_l0000aooooo`;o00001Oooool2o`0004[ooooo
000Yooooo`03o`000?oooooooooo01?ooooo0_l0000Booooo`;o00005?ooool2o`000003ooooool0
003o000000Oooooo0_l00005ooooo`;o000000?oooooo`000?l000001_ooool2o`000004ooooool0
003o0000ooooo`;o00002oooool2o`0001;ooooo0_l00002ooooo`;o0000:?ooool2o`0002?ooooo
0_l0000:ooooo`;o00002_ooool2o`000003ooooool0003o000002Gooooo0_l0000Sooooo`00:Ooo
ool00ol0003oooooooooo`0Cooooo`;o00004_ooool2o`0001Cooooo0_l0000:ooooo`;o00001Ooo
ool2o`000003ooooool0003o000000cooooo0_l0000Oooooo`;o00009?ooool2o`0000Kooooo0_l0
000Sooooo`;o00001_ooool2o`0000;ooooo0_l0000:ooooo`;o0000:?ooool2o`0002?ooooo000Y
ooooo`;o00006oooool2o`0008cooooo0_l0000Uooooo`;o00003?ooool2o`0000Cooooo0_l0001G
ooooo`00:Oooool00ol0003oooooooooo`0Jooooo`Co0000W?ooool2o`0001?ooooo0_l0000Boooo
o`;o00009_ooool2o`0002oooooo000Yooooo`03o`000?oooooooooo01cooooo0_l0000Jooooo`;o
0000P?ooool2o`0002Sooooo0_l0000Uooooo`;o0000;oooool002Wooooo00?o0000ooooooooool0
>?ooool2o`000:[ooooo0_l0001Fooooo`00:Oooool00ol0003oooooooooo`2Mooooo`;o00004ooo
ool2o`0008Sooooo000Yooooo`;o00008Oooool2o`0006?ooooo0_l0000@ooooo`;o00001?ooool2
o`0001;ooooo1?l0000aooooo`;o00000oooool2o`0002kooooo0_l0000?ooooo`;o00003_ooool0
02Wooooo00?o0000ooooooooool07Oooool2o`000003ooooool0003o000000Wooooo0_l0001Hoooo
o`;o00004?ooool2o`0001Sooooo1?l0000Qooooo`;o00003_ooool2o`0000?ooooo0_l0000]oooo
o`?o00003oooool2o`0000kooooo000Yooooo`03o`000?oooooooooo01gooooo0_l0000<ooooo`;o
0000:_ooool2o`0001cooooo0_l0001Oooooo`;o0000;Oooool2o`0001?ooooo0_l0000Pooooo`00
:Oooool00ol0003oooooooooo`1Gooooo`;o00007?ooool2o`0008kooooo0_l0000Iooooo`;o0000
6_ooool002Wooooo00?o0000ooooooooool08_ooool2o`0001Gooooo0_l0001Fooooo`;o0000;ooo
ool2o`0005cooooo0_l0000Jooooo`00:Oooool2o`0002?ooooo0_l0000Eooooo`;o0000E_ooool2
o`0002oooooo0_l0001hooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo07Cooooo0_l0000Dooooo`;o0000IOooool2o`0000Oooooo0_l00010
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0Aoooool2o`0002Wooooo1?l0000Dooooo`;o00000_ooool2
o`0002Cooooo0_l0000kooooo`;o00001oooool2o`0000Cooooo0_l0000jooooo`003_ooool01Ol@
413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`0004Oooooo0_l0000@
ooooo`;o00005oooool2o`0001[ooooo0_l0000Tooooo`;o00002?ooool2o`00043ooooo0_l0000j
ooooo`003_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`1Iooooo`;o0000Hoooool2o`0007cooooo000>ooooo`05o`000?oooooooooo
ooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0j?oo
ool2o`0005;ooooo000>ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0>Sooooo0_l0001Booooo`003_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo000>
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0003oooooockooooo000Y
ooooo`03o`000?oooooooooo04?ooooo0_l0003gooooo`00:Oooool00ol0003oooooooooo`13oooo
o`;o0000iOooool2o`00013ooooo000Yooooo`03o`000?oooooooooo0?oooooo:oooool2o`00013o
oooo000Yooooo`03o`000?oooooooooo0?oooooo2?ooool2o`0003?ooooo000Yooooo`;o0000oooo
ool9ooooo`;o0000<oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46
ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3o
ooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08
ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`000?oooooooooo
ooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEE
olc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooo
oolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`007oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooo
ooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
oooo?Oooool0027ooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
7oooool00omEEEGoIVIVo`00003oooooodOooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .39509 Mdot
.02762 .33475 Mdot
.02952 .29099 Mdot
.03143 .30272 Mdot
.03333 .36313 Mdot
.03524 .24113 Mdot
.03714 .31721 Mdot
.03905 .26671 Mdot
.04095 .43485 Mdot
.04286 .27165 Mdot
.04476 .3148 Mdot
.04667 .23043 Mdot
.04857 .32942 Mdot
.05048 .285 Mdot
.05238 .23792 Mdot
.05429 .3173 Mdot
.05619 .24485 Mdot
.0581 .34151 Mdot
.06 .25256 Mdot
.0619 .3042 Mdot
.06381 .32642 Mdot
.06571 .25914 Mdot
.06762 .24515 Mdot
.06952 .35517 Mdot
.07143 .2735 Mdot
.07333 .31833 Mdot
.07524 .34452 Mdot
.07714 .26877 Mdot
.07905 .2732 Mdot
.08095 .336 Mdot
.08286 .34447 Mdot
.08476 .43341 Mdot
.08667 .34343 Mdot
.08857 .32148 Mdot
.09048 .38567 Mdot
.09238 .39828 Mdot
.09429 .34304 Mdot
.09619 .32964 Mdot
.0981 .2605 Mdot
.1 .22675 Mdot
.1019 .30008 Mdot
.10381 .3725 Mdot
.10571 .34434 Mdot
.10762 .40137 Mdot
.10952 .38548 Mdot
.11143 .28813 Mdot
.11333 .25653 Mdot
.11524 .43932 Mdot
.11714 .36867 Mdot
.11905 .30696 Mdot
.12095 .43754 Mdot
.12286 .23617 Mdot
.12476 .3441 Mdot
.12667 .37734 Mdot
.12857 .36273 Mdot
.13048 .40758 Mdot
.13238 .26265 Mdot
.13429 .24543 Mdot
.13619 .41604 Mdot
.1381 .37496 Mdot
.14 .27264 Mdot
.1419 .46275 Mdot
.14381 .2614 Mdot
.14571 .26292 Mdot
.14762 .37327 Mdot
.14952 .42067 Mdot
.15143 .28922 Mdot
.15333 .28002 Mdot
.15524 .31573 Mdot
.15714 .37241 Mdot
.15905 .28936 Mdot
.16095 .27391 Mdot
.16286 .2738 Mdot
.16476 .32972 Mdot
.16667 .26199 Mdot
.16857 .28351 Mdot
.17048 .34443 Mdot
.17238 .2508 Mdot
.17429 .23086 Mdot
.17619 .36623 Mdot
.1781 .40948 Mdot
.18 .34823 Mdot
.1819 .32966 Mdot
.18381 .37919 Mdot
.18571 .33588 Mdot
.18762 .33809 Mdot
.18952 .36182 Mdot
.19143 .35444 Mdot
.19333 .24684 Mdot
.19524 .28406 Mdot
.19714 .27523 Mdot
.19905 .29099 Mdot
.20095 .31149 Mdot
.20286 .32862 Mdot
.20476 .28118 Mdot
.20667 .31861 Mdot
.20857 .27598 Mdot
.21048 .43452 Mdot
.21238 .36455 Mdot
.21429 .24449 Mdot
.21619 .39952 Mdot
.2181 .27178 Mdot
.22 .23896 Mdot
.2219 .39791 Mdot
.22381 .40396 Mdot
.22571 .33969 Mdot
.22762 .30656 Mdot
.22952 .26396 Mdot
.23143 .31408 Mdot
.23333 .37087 Mdot
.23524 .25627 Mdot
.23714 .30311 Mdot
.23905 .43522 Mdot
.24095 .37175 Mdot
.24286 .48959 Mdot
.24476 .32593 Mdot
.24667 .25639 Mdot
.24857 .39561 Mdot
.25048 .4157 Mdot
.25238 .30976 Mdot
.25429 .32227 Mdot
.25619 .45258 Mdot
.2581 .25498 Mdot
.26 .25876 Mdot
.2619 .37414 Mdot
.26381 .28158 Mdot
.26571 .35742 Mdot
.26762 .36814 Mdot
.26952 .39153 Mdot
.27143 .30578 Mdot
.27333 .23944 Mdot
.27524 .39828 Mdot
.27714 .22627 Mdot
.27905 .24302 Mdot
.28095 .30629 Mdot
.28286 .23335 Mdot
.28476 .34343 Mdot
.28667 .31518 Mdot
.28857 .28136 Mdot
.29048 .31912 Mdot
.29238 .22952 Mdot
.29429 .4593 Mdot
.29619 .33891 Mdot
.2981 .27989 Mdot
.3 .24518 Mdot
.3019 .33836 Mdot
.30381 .36242 Mdot
.30571 .49007 Mdot
.30762 .25526 Mdot
.30952 .34316 Mdot
.31143 .44948 Mdot
.31333 .2841 Mdot
.31524 .34616 Mdot
.31714 .36409 Mdot
.31905 .26818 Mdot
.32095 .26247 Mdot
.32286 .29482 Mdot
.32476 .23909 Mdot
.32667 .40174 Mdot
.32857 .33674 Mdot
.33048 .30714 Mdot
.33238 .36445 Mdot
.33429 .23114 Mdot
.33619 .32219 Mdot
.3381 .41407 Mdot
.34 .35808 Mdot
.3419 .39478 Mdot
.34381 .37271 Mdot
.34571 .41376 Mdot
.34762 .32657 Mdot
.34952 .3132 Mdot
.35143 .35519 Mdot
.35333 .30822 Mdot
.35524 .34805 Mdot
.35714 .36242 Mdot
.35905 .27961 Mdot
.36095 .3506 Mdot
.36286 .33683 Mdot
.36476 .25339 Mdot
.36667 .30897 Mdot
.36857 .27215 Mdot
.37048 .27738 Mdot
.37238 .24249 Mdot
.37429 .34518 Mdot
.37619 .31598 Mdot
.3781 .26665 Mdot
.38 .43675 Mdot
.3819 .37804 Mdot
.38381 .43267 Mdot
.38571 .30452 Mdot
.38762 .31922 Mdot
.38952 .43554 Mdot
.39143 .33655 Mdot
.39333 .30472 Mdot
.39524 .45535 Mdot
.39714 .30678 Mdot
.39905 .37724 Mdot
.40095 .2281 Mdot
.40286 .3436 Mdot
.40476 .22419 Mdot
.40667 .35773 Mdot
.40857 .2673 Mdot
.41048 .27073 Mdot
.41238 .28457 Mdot
.41429 .36078 Mdot
.41619 .21972 Mdot
.4181 .3992 Mdot
.42 .32947 Mdot
.4219 .24294 Mdot
.42381 .29721 Mdot
.42571 .31486 Mdot
.42762 .32992 Mdot
.42952 .2637 Mdot
.43143 .2538 Mdot
.43333 .41395 Mdot
.43524 .34291 Mdot
.43714 .39619 Mdot
.43905 .27272 Mdot
.44095 .32417 Mdot
.44286 .27884 Mdot
.44476 .34314 Mdot
.44667 .22537 Mdot
.44857 .26012 Mdot
.45048 .41293 Mdot
.45238 .41073 Mdot
.45429 .41418 Mdot
.45619 .31957 Mdot
.4581 .34881 Mdot
.46 .34427 Mdot
.4619 .30899 Mdot
.46381 .235 Mdot
.46571 .45965 Mdot
.46762 .27888 Mdot
.46952 .28388 Mdot
.47143 .21985 Mdot
.47333 .34999 Mdot
.47524 .34813 Mdot
.47714 .44277 Mdot
.47905 .33952 Mdot
.48095 .39213 Mdot
.48286 .26583 Mdot
.48476 .39944 Mdot
.48667 .46179 Mdot
.48857 .26064 Mdot
.49048 .41824 Mdot
.49238 .28765 Mdot
.49429 .42963 Mdot
.49619 .26395 Mdot
.4981 .2612 Mdot
.5 .30438 Mdot
.5019 .28278 Mdot
.50381 .25194 Mdot
.50571 .36259 Mdot
.50762 .32353 Mdot
.50952 .31353 Mdot
.51143 .27961 Mdot
.51333 .31087 Mdot
.51524 .35102 Mdot
.51714 .33384 Mdot
.51905 .27586 Mdot
.52095 .28904 Mdot
.52286 .43326 Mdot
.52476 .35977 Mdot
.52667 .34797 Mdot
.52857 .4162 Mdot
.53048 .32629 Mdot
.53238 .30419 Mdot
.53429 .38057 Mdot
.53619 .2602 Mdot
.5381 .28339 Mdot
.54 .38386 Mdot
.5419 .33775 Mdot
.54381 .3815 Mdot
.54571 .34967 Mdot
.54762 .26734 Mdot
.54952 .37255 Mdot
.55143 .29397 Mdot
.55333 .34082 Mdot
.55524 .33027 Mdot
.55714 .43877 Mdot
.55905 .32895 Mdot
.56095 .25725 Mdot
.56286 .24808 Mdot
.56476 .27477 Mdot
.56667 .34464 Mdot
.56857 .33185 Mdot
.57048 .25007 Mdot
.57238 .27151 Mdot
.57429 .28963 Mdot
.57619 .32524 Mdot
.5781 .38932 Mdot
.58 .32561 Mdot
.5819 .39978 Mdot
.58381 .38129 Mdot
.58571 .40297 Mdot
.58762 .25809 Mdot
.58952 .3971 Mdot
.59143 .28866 Mdot
.59333 .40362 Mdot
.59524 .44152 Mdot
.59714 .40483 Mdot
.59905 .24584 Mdot
.60095 .47741 Mdot
.60286 .37325 Mdot
.60476 .28663 Mdot
.60667 .39576 Mdot
.60857 .43106 Mdot
.61048 .27366 Mdot
.61238 .26797 Mdot
.61429 .43732 Mdot
.61619 .32684 Mdot
.6181 .28343 Mdot
.62 .25095 Mdot
.6219 .25096 Mdot
.62381 .30022 Mdot
.62571 .44045 Mdot
.62762 .32797 Mdot
.62952 .35782 Mdot
.63143 .35173 Mdot
.63333 .35588 Mdot
.63524 .32008 Mdot
.63714 .24529 Mdot
.63905 .39618 Mdot
.64095 .44487 Mdot
.64286 .25807 Mdot
.64476 .24912 Mdot
.64667 .38265 Mdot
.64857 .23818 Mdot
.65048 .35674 Mdot
.65238 .26615 Mdot
.65429 .30457 Mdot
.65619 .28434 Mdot
.6581 .23376 Mdot
.66 .26264 Mdot
.6619 .28146 Mdot
.66381 .23662 Mdot
.66571 .29173 Mdot
.66762 .28558 Mdot
.66952 .33985 Mdot
.67143 .24363 Mdot
.67333 .3566 Mdot
.67524 .36367 Mdot
.67714 .35677 Mdot
.67905 .31506 Mdot
.68095 .31522 Mdot
.68286 .3708 Mdot
.68476 .26504 Mdot
.68667 .37914 Mdot
.68857 .33674 Mdot
.69048 .3299 Mdot
.69238 .32659 Mdot
.69429 .33785 Mdot
.69619 .31849 Mdot
.6981 .45967 Mdot
.7 .23043 Mdot
.7019 .40709 Mdot
.70381 .38973 Mdot
.70571 .37286 Mdot
.70762 .34175 Mdot
.70952 .35977 Mdot
.71143 .32921 Mdot
.71333 .23189 Mdot
.71524 .43424 Mdot
.71714 .4174 Mdot
.71905 .22557 Mdot
.72095 .25134 Mdot
.72286 .32924 Mdot
.72476 .31316 Mdot
.72667 .36182 Mdot
.72857 .22973 Mdot
.73048 .27716 Mdot
.73238 .31906 Mdot
.73429 .38772 Mdot
.73619 .29983 Mdot
.7381 .24911 Mdot
.74 .39846 Mdot
.7419 .43685 Mdot
.74381 .39359 Mdot
.74571 .37315 Mdot
.74762 .2342 Mdot
.74952 .25436 Mdot
.75143 .39619 Mdot
.75333 .24717 Mdot
.75524 .2465 Mdot
.75714 .4944 Mdot
.75905 .33455 Mdot
.76095 .28744 Mdot
.76286 .27372 Mdot
.76476 .36694 Mdot
.76667 .24815 Mdot
.76857 .29795 Mdot
.77048 .2554 Mdot
.77238 .37573 Mdot
.77429 .26584 Mdot
.77619 .31884 Mdot
.7781 .26949 Mdot
.78 .35186 Mdot
.7819 .44015 Mdot
.78381 .41778 Mdot
.78571 .45097 Mdot
.78762 .24869 Mdot
.78952 .29205 Mdot
.79143 .27484 Mdot
.79333 .32195 Mdot
.79524 .27603 Mdot
.79714 .31549 Mdot
.79905 .31684 Mdot
.80095 .24467 Mdot
.80286 .23327 Mdot
.80476 .34279 Mdot
.80667 .33136 Mdot
.80857 .3548 Mdot
.81048 .34581 Mdot
.81238 .41429 Mdot
.81429 .33231 Mdot
.81619 .41378 Mdot
.8181 .33737 Mdot
.82 .34501 Mdot
.8219 .31723 Mdot
.82381 .35171 Mdot
.82571 .30353 Mdot
.82762 .35391 Mdot
.82952 .33271 Mdot
.83143 .45087 Mdot
.83333 .32073 Mdot
.83524 .30112 Mdot
.83714 .38472 Mdot
.83905 .30609 Mdot
.84095 .28786 Mdot
.84286 .31857 Mdot
.84476 .34068 Mdot
.84667 .37955 Mdot
.84857 .27234 Mdot
.85048 .38871 Mdot
.85238 .47037 Mdot
.85429 .39889 Mdot
.85619 .33056 Mdot
.8581 .43227 Mdot
.86 .22742 Mdot
.8619 .31802 Mdot
.86381 .33169 Mdot
.86571 .3225 Mdot
.86762 .33479 Mdot
.86952 .27426 Mdot
.87143 .29541 Mdot
.87333 .41662 Mdot
.87524 .35987 Mdot
.87714 .24666 Mdot
.87905 .28644 Mdot
.88095 .38441 Mdot
.88286 .37371 Mdot
.88476 .26766 Mdot
.88667 .32449 Mdot
.88857 .33184 Mdot
.89048 .26747 Mdot
.89238 .32709 Mdot
.89429 .2324 Mdot
.89619 .35802 Mdot
.8981 .37631 Mdot
.9 .36989 Mdot
.9019 .38558 Mdot
.90381 .27142 Mdot
.90571 .35842 Mdot
.90762 .3098 Mdot
.90952 .23049 Mdot
.91143 .3656 Mdot
.91333 .25893 Mdot
.91524 .4059 Mdot
.91714 .32836 Mdot
.91905 .25737 Mdot
.92095 .33188 Mdot
.92286 .40011 Mdot
.92476 .25162 Mdot
.92667 .31415 Mdot
.92857 .32511 Mdot
.93048 .46533 Mdot
.93238 .3226 Mdot
.93429 .28526 Mdot
.93619 .36197 Mdot
.9381 .36968 Mdot
.94 .31298 Mdot
.9419 .25898 Mdot
.94381 .37881 Mdot
.94571 .30624 Mdot
.94762 .29927 Mdot
.94952 .28309 Mdot
.95143 .41931 Mdot
.95333 .36353 Mdot
.95524 .36848 Mdot
.95714 .28621 Mdot
.95905 .28211 Mdot
.96095 .3237 Mdot
.96286 .48851 Mdot
.96476 .32204 Mdot
.96667 .33739 Mdot
.96857 .40796 Mdot
.97048 .41225 Mdot
.97238 .30301 Mdot
.97429 .29765 Mdot
.97619 .22901 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo07[ooooo0_l0000@ooooo`;o0000[_ooool000Kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo07Oooooo0_l000000ooooooo0000o`00000@ooooo`;o0000[_ooool0
00Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Eooooo`;o0000=ooo
ool2o`0002Oooooo0_l0000;ooooo`;o0000E_ooool2o`0002_ooooo0_l0000aooooo`001?l00002
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool2o`0000oooooo0_l0000Fooooo`;o00007ooo
ool2o`0000?ooooo0_l0000Qooooo`;o00003?ooool2o`00053ooooo0_l00004ooooo`;o000000?o
ooooo`000?l00000:?ooool2o`0000kooooo0_l0000Dooooo`;o00002oooool000Kooooo00Go0000
ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?oo
ool3o`0000Cooooo0_l0000Wooooo`;o00008Oooool2o`000003ooooool0003o000000_ooooo0_l0
000Dooooo`;o0000D?ooool2o`0000cooooo0_l00002ooooo`;o00000oooool2o`0001Kooooo0_l0
000Kooooo`;o00000oooool2o`0001Cooooo0_l0000;ooooo`001_ooool01Ol0003ooooooooooooo
oooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool07?ooool2o`0003;ooooo0_l0000>ooooo`;o0000:?ooool2o`0003cooooo
1?l0000>ooooo`;o00002Oooool2o`00013ooooo0_l0000Kooooo`;o00009_ooool000Kooooo00Go
410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`05ooooo`;o00005Oooool2o`0001gooooo0_l0000@ooooo`;o0000
3_ooool2o`0002_ooooo0_l0000iooooo`;o00000oooool2o`0001Wooooo0_l0001Eooooo`001_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool00_l00003ooooo`;o0000=?ooool2o`00013o
oooo0ol0000=ooooo`;o00003Oooool2o`0000kooooo0_l00017ooooo`;o0000MOooool000Kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`00
00Kooooo00?o0000ooooooooool00_l00005ooooo`;o000000?oooooo`000?l000005?ooool2o`00
01Sooooo0_l0000Booooo`;o00001Oooool2o`0001Gooooo0_l0000>ooooo`;o0000=oooool2o`00
00[ooooo0_l0000:ooooo`;o00006?ooool2o`0000gooooo0_l00014ooooo`00:Oooool2o`0000So
oooo0_l000000ooooooo0000o`00000Dooooo`;o00004Oooool2o`0000Gooooo0_l0000Iooooo`;o
0000Doooool2o`0000Wooooo0_l0000:ooooo`;o000000?oooooo`000?l000001oooool2o`0001?o
oooo0_l00003ooooo`;o00000_ooool2o`0000Gooooo0_l00002ooooo`;o00005oooool2o`0002_o
oooo000Yooooo`03o`000?oooooooooo00Sooooo0_l0000Rooooo`;o00001Oooool2o`0006;ooooo
0_l0000Aooooo`Co00003_ooool3o`0000Gooooo0_l0000Fooooo`;o00001?ooool2o`0000?ooooo
0_l00002ooooo`;o00001Oooool2o`0001_ooooo0_l0000=ooooo`;o00007?ooool002Wooooo00?o
0000ooooooooool02?ooool2o`0002;ooooo0_l0000Jooooo`;o00003_ooool2o`00013ooooo0_l0
000Cooooo`;o00005_ooool2o`0001?ooooo0_l0000>ooooo`?o00007Oooool2o`0000Sooooo0_l0
0004ooooo`;o0000<?ooool2o`0001cooooo000Yooooo`03o`000?oooooooooo01Wooooo0_l0000U
ooooo`;o00000_ooool2o`0000;ooooo0_l0000>ooooo`;o00004?ooool2o`0001?ooooo0_l0000X
ooooo`;o00001oooool2o`0000oooooo0_l0000Qooooo`;o00001?ooool2o`0002cooooo1?l00005
ooooo`;o00005oooool002Wooooo00?o0000ooooooooool02_ooool2o`0000Sooooo0_l00003oooo
o`;o00002?ooool2o`0000Gooooo0_l0000Dooooo`;o00000_ooool2o`0000;ooooo0_l0000koooo
o`;o00002oooool2o`000003ooooool0003o000000[ooooo0_l00006ooooo`;o00001oooool2o`00
00oooooo0_l0001Eooooo`Co00001Oooool2o`0001Oooooo000Yooooo`;o00002oooool2o`0000So
oooo0_l00009ooooo`;o00000_ooool2o`0000Gooooo0_l0000Booooo`;o00007?ooool2o`00027o
oooo0_l00004ooooo`;o00002oooool5o`0000[ooooo0_l0000Vooooo`;o00001_ooool2o`0006Wo
oooo000Yooooo`04o`000?ooooooooooooooo`;o00007?ooool2o`0000;ooooo0_l0000Iooooo`;o
00006oooool3o`00013ooooo0_l00008ooooo`;o00001Oooool2o`0000oooooo0_l00002ooooo`;o
00003oooool2o`0001?ooooo0_l0000:ooooo`;o000000?oooooo`000?l000001_ooool2o`0001_o
oooo0_l0000Qooooo`Co00009oooool002Wooooo00Co0000oooooooooooooooo0_l0000:ooooo`;o
00008Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h05oooool2o`00013ooooo1Ol00003ooooo`03onk^k_lb<S;o000000?o0000
0_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo0_l0000Cooooo`;o00000oooool01OnHV9So
410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`?o000000?o<S8b
onk^k_ooool01_ooool2o`00027ooooo0_l000000ol@413oooooooooo`04o`000003oc8b<_o^k^ko
oooo00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Eooooo`Co00000_ooool2o`0000cooooo00Go
A4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo000Yooooo`03o`000?oooooooooo00;ooooo0_l00008ooooo`Co
00004_ooool2o`0000Cooooo0ol00007ooooo`03o`000?oooooooooo00;ooooo00CoMgMgoiRHV?oo
ooooV9RH0_l00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL09oooool2o`000005oiRHV?lQ8B7o
k^k^oooooom4A4@00oooool01?mgMgOoV9RHoooooonHV9P2o`0000;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`02o`0002Kooooo00?o410@okZj^_ooool00_l00003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00_ooool2o`000004oiRHV?ooooooV9RHogMgMb_ooooo0_l00003ooooo`;o000000?ooooo
oiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Wooooo0_l00005ooooo`;o00002Ooo
ool2o`0000oooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo000Yooooo`03o`000?oooooooooo00;ooooo0_l00008oooo
o`Co00004_ooool2o`0000Cooooo0ol00007ooooo`06o`000?oooooo0000o`000?oooooo410@0_l0
00000ooooooo0000o`000002ooooo`05oa0@4?ooooooooooooooool@41009oooool3o`000003oiRH
V?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41000_l0000Hooooo`;o00003?ooool2o`000003ooooool0003o000000?ooooo00Go410@oooo
oooooooooooooa0@4002ooooo`;o00000oooool00ol@413oooooooooo`0Nooooo`;o00001_ooool5
o`0000?ooooo00Co410@oooooooooooooooo0ol000000ooooooo410@ooooo`02ooooo`03oa0@4?oo
oooooooo00Oooooo0_l00005ooooo`;o00006oooool01?l0003oooooooooool@4103ooooo`05oa0@
4?ooooooooooooooool@41000oooool00ol@413oooooooooo`01ooooo`00:Oooool2o`0002Oooooo
0_l0000:ooooo`05o`000?oooooo0000o`000?ooool00ol000000ooooooo0000ooooo`02ooooo`05
o`000?ooooooooooooooool000004?ooool2o`0001;ooooo0_l00002ooooo`;o000000CooooooiRH
V?lQ8B7ok^k^0oooool01Ol0003ooooooooooooooooo000000?ooooo00Ko0000oooooooooooooooo
o`000?ooool2o`0000Kooooo0_l0000<ooooo`;o000000?oooooo`000?l000003?ooool2o`000003
oooooonYZJWo410@00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000008?ooool2o`0000Kooooo00CoA4A4omgMgOoooooo00001?ooool01?l0003ooooooooo
ooooool3o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool0:_ooool01OmgMgOo<S8b
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
007ooooo000Yooooo`03o`000?oooooooooo02Kooooo0_l00003ooooo`;o00001Oooool01?l0003o
ooooooooooooool2o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
oooo00?ooooo0_l00006ooooo`;o000000?oooooo`000?l000004_ooool2o`0000Kooooo00?oMgMg
ofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Ko0000oooooooooooooooo
o`000?ooool2o`0000Kooooo0ol00008ooooo`;o000000?oooooo`000?l000001oooool2o`0000So
oooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000000?ooooo0ol000000ooo
oooo0000ooooo`09ooooo`;o00007?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000002Wooooo0ol000001Olb<S;o0000
o`000?oooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
007ooooo000Yooooo`03o`000?oooooooooo00Gooooo0_l0000Tooooo`;o00001Oooool3o`000003
ooooool0003o000000?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo
00?ooooo0_l00006ooooo`;o00001_ooool2o`0001Kooooo00Go0000oooooooooooooooooa0@4003
ooooo`;o00000_ooool01Ol@413ooooooooooooooooo410@00[ooooo0_l00008ooooo`;o00002_oo
ool2o`0000Wooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00;o0000
00Kooooooa0@4?l0003o0000ooooool@4109ooooo`Go00006oooool00omgMgOoc<c<o`000004oooo
o`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@01?ooooo0_l0
000@ooooo`;o00000_ooool6o`000003ooooool@413ooooo00;ooooo00Go410@oooooooooooooooo
oa0@4003ooooo`03oa0@4?oooooooooo007ooooo000Yooooo`03o`000?oooooooooo00Gooooo0_l0
000Aooooo`;o00002oooool2o`000003ooooool0003o000000Sooooo0ol00002ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01Gooooo0_l0000Booooo`05
o`000?nj^[[ooooooiRHV?l@41000oooool01?mgMgOoV9RHoooooonHV9P2o`0000;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0Aooooo`;o00001oooool2o`0000cooooo00?o410@oiRHV?ooool00_l0
0003ooooo`05ogMgMol0003o0000oiRHV?mgMgL00_l000001_ooooooMgMgoiRHV?ooooooV9RHogMg
M`Wooooo0_l000000ooooooo0000o`00000Kooooo`03onk^k_l0003o000000Cooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01oooool2o`0000[ooooo0_l0
000@ooooo`;o00000_ooool00ol0003oooooooooo`02o`0000;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wooooo0ol0000Hooooo`;o0000
2oooool2o`000003ooooool0003o000000Kooooo00?oEEEEofIVI_l000000_ooool2o`000005onk^
k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Wooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^017ooooo0_l00007ooooo`;o00003?ooool00onYZJWo410@o`000002o`0000?ooooo
00Gok^k^o`000?l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool2o`00
01cooooo0_l00004ooooo`03onk^k_lb<S;o000000;o00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Oooooo0_l0000Pooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool3o`0003Gooooo0_l0000Uooooo`;o0000B?oo
ool2o`0002?ooooo0_l0000Uooooo`;o00006Oooool2o`0002gooooo000Yooooo`03o`000?oooooo
oooo05cooooo0_l0000Oooooo`;o00009oooool2o`0004Cooooo0_l0000Oooooo`;o00005_ooool2
o`0000Oooooo0_l0000<ooooo`00:Oooool00ol0003oooooooooo`0Eooooo`;o0000I_ooool2o`00
03kooooo0_l0000Rooooo`;o00002Oooool2o`0001?ooooo0_l0000Rooooo`;o00001oooool2o`00
00cooooo000Yooooo`04o`000?oooooo0000o`0000Sooooo0_l0000:ooooo`;o0000:_ooool2o`00
02kooooo1?l0000Pooooo`;o00002Oooool2o`0001_ooooo0_l00008ooooo`;o00006?ooool2o`00
01_ooooo0_l000000ooooooo0000o`00000Zooooo`;o00003Oooool002Wooooo00Co0000ooooool0
003o00002?ooool2o`00013ooooo0_l0000Qooooo`;o000000?oooooo`000?l000002Oooool2o`00
0003ooooool0003o000000kooooo0_l00005ooooo`;o00002Oooool5o`0001oooooo0_l00009oooo
o`;o00009Oooool2o`0003Gooooo0_l00002ooooo`;o00008Oooool2o`0000Kooooo0_l0000=oooo
o`008Oooooooo`0004Co00001?ooool002Wooooo00?o0000ooooooooool00oooool2o`0000Cooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool01?ooool2o`0000?ooooo00?o0000ooooooooool00_ooool2o`0000Gooooo
0_l0000;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool2o`0000Cooooo
0_l0000;ooooo`03o`000?oooooooooo00;ooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo
0_l00005ooooo`03o`000?oooooooooo00Gooooo1Ol0000<ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo
00Co0000oooooooooooooooo0_l00006ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0ol00005ooooo`;o
00000_ooool2o`0000[ooooo00?o0000ooooooooool02_ooool002Wooooo00Co0000oooooooooooo
oooo1?l000000ooooooo0000o`00000Oooooo`;o00004Oooool00ol0003oooooooooo`02ooooo`;o
00004?ooool2o`0001;ooooo0_l00007ooooo`;o00002?ooool00ol0003oooooooooo`02ooooo`;o
00006Oooool2o`0001_ooooo00?o0000ooooooooool05oooool3o`0000cooooo0_l0000Booooo`03
o`000?oooooooooo00?o00001Oooool2o`0000_ooooo0_l0000Cooooo`;o00000_ooool2o`0000[o
oooo00?o0000ooooooooool02_ooool002Wooooo00Co0000oooooooooooooooo0_l00003ooooo`;o
00001?ooool2o`0001Wooooo0_l0000>ooooo`;o00006?ooool3o`0001[ooooo0_l000000ooooooo
0000o`00000Dooooo`;o0000>?ooool2o`0000cooooo0ol00002ooooo`;o00002_ooool2o`0000co
oooo0_l00005ooooo`?o00001Oooool2o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`;o
0000<?ooool002Wooooo00?o0000ooooooooool03?ooool2o`0000?ooooo0_l0000Tooooo`;o0000
3Oooool2o`0000[ooooo0_l0000=ooooo`;o00003_ooool2o`0000oooooo0_l00003ooooo`;o0000
3oooool2o`0002Oooooo0_l0000Aooooo`;o00002_ooool2o`0000cooooo0_l00004ooooo`;o0000
2oooool2o`000003ooooool0003o000000Gooooo0_l0000Cooooo`;o00002?ooool3o`0000oooooo
000Yooooo`;o00002_ooool2o`0000Kooooo0_l0000`ooooo`;o000000?oooooo`000?l000006Ooo
ool2o`000003ooooool0003o000001cooooo0_l0000Dooooo`;o00001Oooool2o`0000gooooo0ol0
000:ooooo`;o00005_ooool2o`0001oooooo0_l0000Eooooo`;o00001Oooool4o`0000Wooooo0ol0
0008ooooo`?o00003oooool002Wooooo00?o0000ooooooooool01?ooool2o`0000?ooooo0_l00009
ooooo`;o00005?ooool2o`0000?ooooo0_l00005ooooo`;o00002oooool2o`0001oooooo0_l0000F
ooooo`Co00007oooool2o`0000Kooooo0ol00004ooooo`?o00002_ooool2o`000003ooooool0003o
000001?ooooo0_l00004ooooo`;o00000_ooool2o`0002Wooooo0_l00008ooooo`Co00001_ooool2
o`000003ooooool0003o000001_ooooo000Yooooo`03o`000?oooooooooo00Cooooo0_l0000>oooo
o`;o00005?ooool2o`0000?ooooo0_l00005ooooo`;o0000A?ooool4o`0002Oooooo0ol000000ooo
oooo0000o`00000Aooooo`;o00004oooool2o`0000Cooooo0_l00002ooooo`;o00006Oooool4o`00
00?ooooo0_l00007ooooo`Co00001_ooool2o`0000Sooooo0ol0000Mooooo`00:Oooool2o`00013o
oooo0_l0000Oooooo`;o0000;?ooool2o`0001;ooooo0_l0000Wooooo`;o00003_ooool2o`0002Go
oooo0_l0000Eooooo`;o00003Oooool4o`0000?ooooo0_l00009ooooo`Co00001?ooool2o`0000Wo
oooo0_l0000Mooooo`00:Oooool2o`00013ooooo0_l0000Oooooo`?o00002_ooool2o`0001Gooooo
1?l00006ooooo`;o00002Oooool2o`0000Oooooo0_l0000Kooooo`;o00002_ooool2o`0000Kooooo
0_l0000Wooooo`;o00001?ooool4o`0001?ooooo0_l0000Aooooo`;o00003_ooool2o`0001gooooo
0_l0000?ooooo`00:Oooool2o`0000Sooooo0_l0000Xooooo`;o00002_ooool2o`0001Gooooo1?l0
000Aooooo`;o00005_ooool2o`0000cooooo0_l0000Booooo`;o00000_ooool2o`0002?ooooo0_l0
0006ooooo`;o00000_ooool2o`0001gooooo0_l00003ooooo`;o00001_ooool2o`0002Gooooo0_l0
000?ooooo`00:Oooool00ol0003oooooooooo`07ooooo`;o00001?ooool5o`000003ooooool0003o
000000;ooooo0_l00004ooooo`;o00003?ooool2o`0002?ooooo0_l00006ooooo`;o00004oooool2
o`0000Oooooo0_l00009ooooo`;o000000?oooooo`000?l000000oooool2o`0001cooooo0_l00002
ooooo`;o0000:oooool2o`0001gooooo1?l000000ooooooo0000o`000006ooooo`;o0000=_ooool0
02Wooooo00?o0000ooooooooool03Oooool5o`000003ooooool0003o000000;ooooo0_l00004oooo
o`;o00003?ooool2o`000003ooooool0003o0000023ooooo0_l00006ooooo`Co00002oooool2o`00
00Cooooo0_l00007ooooo`;o00003?ooool2o`0000;ooooo0ol00002ooooo`;o00003oooool2o`00
00_ooooo0_l0001<ooooo`;o000000?oooooo`000?l00000?_ooool002Wooooo00?o0000oooooooo
ool0;_ooool2o`0002[ooooo0_l0000;ooooo`Co00007Oooool2o`0000?ooooo0_l0000;ooooo`;o
00000_ooool2o`0000Cooooo0_l0000Jooooo`;o0000;Oooool2o`0000gooooo0_l0000looooo`00
:Oooool00ol0003oooooooooo`0;ooooo`;o00009Oooool2o`0003;ooooo0_l000000ooooooo0000
o`00000Rooooo`;o00002oooool2o`0000Sooooo0_l0000Jooooo`;o0000;Oooool2o`0000Sooooo
0_l00003ooooo`?o0000>oooool002Wooooo0_l0000<ooooo`;o00009Oooool2o`0001Kooooo0_l0
000Fooooo`;o00000_ooool2o`0000oooooo0_l00016ooooo`?o00001?ooool2o`0000Gooooo0ol0
000Yooooo`;o00001?ooool2o`0001Cooooo0_l000000ooooooo0000o`00000Rooooo`00:Oooool0
0ol0003oooooooooo`1:ooooo`;o00005_ooool2o`0001?ooooo0_l000000ooooooo0000o`00000Q
ooooo`;o00008?ooool3o`0000Cooooo0_l00005ooooo`?o00002Oooool2o`0003?ooooo0_l00005
ooooo`;o000000?oooooo`000?l000008_ooool002Wooooo00Co0000ooooool0003o00007Oooool2
o`0001;ooooo0_l00005ooooo`;o00006oooool2o`0000?ooooo0_l00002ooooo`;o00001_ooool2
o`00017ooooo0_l0000Kooooo`;o00001?ooool2o`0002oooooo0_l00009ooooo`;o00000oooool2
o`0002kooooo0_l0000Booooo`;o00000oooool2o`0001?ooooo000Yooooo`04o`000?oooooo0000
o`0001gooooo0_l0000=ooooo`;o00000oooool2o`0000Gooooo0_l0000Kooooo`;o00000oooool2
o`0000;ooooo0_l00006ooooo`;o0000;_ooool2o`0003Gooooo0_l0000>ooooo`;o00002oooool2
o`0002gooooo0_l00006ooooo`;o00000oooool2o`0001?ooooo000Yooooo`03o`000?oooooooooo
01[ooooo0_l0000Aooooo`;o00004Oooool2o`0000Wooooo0_l00023ooooo`;o00006Oooool2o`00
02Wooooo0_l00002ooooo`;o00001_ooool2o`0000Cooooo0_l0000Booooo`00:Oooool2o`0001Oo
oooo0_l00002ooooo`;o00002?ooool2o`000003ooooool0003o000001Oooooo1?l00007ooooo`;o
00005_ooool2o`00043ooooo0_l0000?ooooo`;o00006?ooool2o`0000Kooooo0_l0000:ooooo`;o
0000:_ooool2o`0000Cooooo0_l0000:ooooo`;o00001?ooool2o`0001;ooooo000Yooooo`03o`00
0?oooooooooo01Kooooo0_l00009ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Iooooo`;o
00001Oooool2o`0001Sooooo0_l0000@ooooo`;o0000;_ooool2o`0000oooooo0_l0000Pooooo`;o
00002_ooool2o`0000Oooooo0_l0000Qooooo`;o00000oooool2o`0002Gooooo0006ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`0Mooooo`;o00000_ooool2o`0000gooooo0_l0000Goooo
o`;o00009?ooool2o`0000Cooooo0_l0001Jooooo`;o00006_ooool2o`0001Kooooo0_l0000>oooo
o`;o00003Oooool2o`0001Kooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool07Oooool2o`00017ooooo0_l0000mooooo`;o0000;oooool2o`000003ooooool0003o
000000_ooooo0_l0000Cooooo`;o00002_ooool2o`0003;ooooo0_l0000Mooooo`;o00005_ooool0
00Kooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Booooo`;o00001?ooool2o`0008Kooooo1Ol0000;
ooooo`;o00004oooool2o`0003_ooooo0_l0000<ooooo`;o00001Oooool2o`0002?ooooo0006oooo
o`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;o
oooo00Cooooo0ol0000Booooo`;o00001?ooool2o`0008Sooooo0_l0000:ooooo`;o0000<Oooool2
o`0001oooooo0_l00002ooooo`;o00002?ooool2o`0000Gooooo0_l0000Sooooo`001_ooool01Ol0
003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Gooooo00?o0000ooooooooool0Boooool2o`0004;ooooo0_l0000Mooooo`;o00009ooo
ool2o`0000Sooooo0_l0000Sooooo`;o0000=?ooool000Kooooo00Go410@oooooooooooooooooa0@
400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool2o`0004Kooooo0_l0
0004ooooo`;o00005_ooool2o`0002[ooooo0_l0000Wooooo`;o00007Oooool2o`0000_ooooo0_l0
001Fooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RH
oa0@4004ooooo`03o`000?oooooooooo00Oooooo0_l0000Cooooo`;o0000:?ooool2o`0000Oooooo
0_l00006ooooo`;o00005?ooool2o`0001cooooo0_l0000_ooooo`;o00001?ooool2o`0000Sooooo
0_l0000Oooooo`Go00007oooool2o`0003?ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo01;o
oooo0_l00003ooooo`;o00008Oooool4o`0000oooooo0_l0000?ooooo`;o00006oooool2o`0000Co
oooo0_l0000=ooooo`;o00007_ooool4o`0000kooooo0_l0000Oooooo`;o000000?oooooo`000?l0
00007oooool2o`0001Cooooo0_l0000Mooooo`00:Oooool2o`0001Sooooo0_l0000Qooooo`;o0000
00?oooooo`000?l000007oooool2o`0001_ooooo0_l0000Cooooo`;o00007_ooool7o`0006Kooooo
0_l0000Mooooo`00:Oooool00ol0003oooooooooo`0Oooooo`;o00007?ooool2o`0007;ooooo1_l0
000Oooooo`;o0000@oooool2o`0000oooooo0_l0000>ooooo`00:Oooool00ol0003oooooooooo`0O
ooooo`;o00003Oooool2o`0005Kooooo0_l0001>ooooo`;o0000@oooool2o`0000oooooo0_l0000>
ooooo`00:Oooool00ol0003oooooooooo`0^ooooo`;o0000<Oooool2o`000003ooooool0003o0000
01[ooooo0_l00003ooooo`Co0000LOooool3o`00033ooooo0_l0000=ooooo`00:Oooool00ol0003o
ooooooooo`0Pooooo`;o00008oooool2o`0001[ooooo0_l000000ooooooo0000o`00000Jooooo`;o
00000oooool4o`0001Kooooo0_l0000jooooo`;o00007Oooool3o`00013ooooo0_l0000Nooooo`;o
00003Oooool002Wooooo0_l0000Qooooo`;o00000oooool2o`0001kooooo0_l0001;ooooo`;o0000
2oooool2o`0003[ooooo0_l0000Dooooo`;o00006_ooool2o`0001Sooooo0_l0000Cooooo`00:Ooo
ool00ol0003oooooooooo`0Uooooo`;o0000Joooool2o`0005gooooo0_l0000dooooo`;o00004ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`2Doooo
o`;o0000Y_ooool002Wooooo00?o0000ooooooooool0L?ooool2o`0002;ooooo0_l0000Rooooo`;o
0000Coooool2o`00037ooooo000Yooooo`;o00000oooool2o`0000cooooo0_l0000Vooooo`;o0000
1oooool2o`0002gooooo1?l0000Yooooo`;o00006Oooool2o`00027ooooo0_l0000/ooooo`;o0000
<Oooool002Wooooo00?o0000ooooooooool00_ooool2o`0000cooooo0_l00008ooooo`Co00006_oo
ool2o`0000Oooooo0_l0000/ooooo`;o000000?oooooo`000?l00000:Oooool2o`0000Wooooo0_l0
000@ooooo`;o00007oooool2o`0000Kooooo0_l0001Gooooo`00:Oooool00ol0003oooooooooo`0J
ooooo`Co0000DOooool2o`0003Oooooo0_l0000:ooooo`;o00001?ooool2o`0000;ooooo0_l0000S
ooooo`;o00002oooool2o`0004[ooooo000Yooooo`03o`000?oooooooooo08kooooo0_l0000Toooo
o`;o00002?ooool2o`0000?ooooo0_l0000[ooooo`;o0000B_ooool002Wooooo00?o0000oooooooo
ool0S_ooool2o`0003?ooooo0_l0001gooooo`00:Oooool2o`0005[ooooo0_l0002Fooooo`;o0000
3Oooool2o`0003[ooooo000Yooooo`03o`000?oooooooooo04Oooooo0_l0000@ooooo`;o0000U_oo
ool2o`0000gooooo0_l0000jooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`17ooooo`;o0000
:oooool2o`000<Kooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1Cooooo`;o00007oooool2o`0001Cooooo
0_l00019ooooo`;o0000IOooool000kooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`00
0?oooooooooo00?ooooo0ol0000Rooooo`;o0000;oooool2o`0003Gooooo0_l00005ooooo`;o0000
@_ooool2o`0006Gooooo000>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo02;ooooo0_l0001]ooooo`;o0000SOooool2o`0001[ooooo
000>ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool0ooooool8ooooo`;o00005oooool2o`0001[ooooo000>ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo2?ooool2o`0003?ooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`Co00001_ooool2o`000;Oooooo0_l00024ooooo`00:Oooool00ol0003ooooo
ooooo`2fooooo`;o0000Q?ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooob_ooooo0_l0000@ooooo`00:Oooool00ol0003oooooooooo`13oooo
o`;o00004_ooool2o`000=7ooooo0_l0000@ooooo`00:Oooool2o`0004Cooooo0_l0000Booooo`;o
0000Soooool2o`0005;ooooo000Yooooo`03o`000?oooooooooo0>Sooooo0_l0001Booooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEE
ooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`000?oo
ooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo
00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMooo
ool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`007oooool4o`000003oa0@4?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`007oooool00omEEEGoIVIVo`00003oooooodOooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .35045 Mdot
.02762 .39375 Mdot
.02952 .27594 Mdot
.03143 .33936 Mdot
.03333 .34387 Mdot
.03524 .31318 Mdot
.03714 .28227 Mdot
.03905 .3752 Mdot
.04095 .43128 Mdot
.04286 .33141 Mdot
.04476 .25655 Mdot
.04667 .33245 Mdot
.04857 .23983 Mdot
.05048 .2578 Mdot
.05238 .34458 Mdot
.05429 .26124 Mdot
.05619 .30037 Mdot
.0581 .24718 Mdot
.06 .31122 Mdot
.0619 .38954 Mdot
.06381 .23904 Mdot
.06571 .35094 Mdot
.06762 .33434 Mdot
.06952 .26021 Mdot
.07143 .23418 Mdot
.07333 .24975 Mdot
.07524 .29314 Mdot
.07714 .33394 Mdot
.07905 .37056 Mdot
.08095 .39366 Mdot
.08286 .25083 Mdot
.08476 .43579 Mdot
.08667 .41979 Mdot
.08857 .24757 Mdot
.09048 .36342 Mdot
.09238 .41937 Mdot
.09429 .24198 Mdot
.09619 .35486 Mdot
.0981 .36003 Mdot
.1 .29309 Mdot
.1019 .22521 Mdot
.10381 .31474 Mdot
.10571 .38567 Mdot
.10762 .38467 Mdot
.10952 .32385 Mdot
.11143 .35138 Mdot
.11333 .2909 Mdot
.11524 .41047 Mdot
.11714 .36946 Mdot
.11905 .38999 Mdot
.12095 .40269 Mdot
.12286 .28096 Mdot
.12476 .22756 Mdot
.12667 .38224 Mdot
.12857 .38849 Mdot
.13048 .44172 Mdot
.13238 .37181 Mdot
.13429 .29452 Mdot
.13619 .34668 Mdot
.1381 .30185 Mdot
.14 .34241 Mdot
.1419 .42901 Mdot
.14381 .36049 Mdot
.14571 .31218 Mdot
.14762 .43164 Mdot
.14952 .44237 Mdot
.15143 .34055 Mdot
.15333 .26407 Mdot
.15524 .3541 Mdot
.15714 .28393 Mdot
.15905 .2458 Mdot
.16095 .28141 Mdot
.16286 .33256 Mdot
.16476 .34665 Mdot
.16667 .36097 Mdot
.16857 .31302 Mdot
.17048 .22774 Mdot
.17238 .31628 Mdot
.17429 .3083 Mdot
.17619 .31984 Mdot
.1781 .36151 Mdot
.18 .39763 Mdot
.1819 .33638 Mdot
.18381 .33182 Mdot
.18571 .41666 Mdot
.18762 .28661 Mdot
.18952 .35111 Mdot
.19143 .35931 Mdot
.19333 .31838 Mdot
.19524 .26187 Mdot
.19714 .23341 Mdot
.19905 .40066 Mdot
.20095 .26153 Mdot
.20286 .36434 Mdot
.20476 .26583 Mdot
.20667 .41783 Mdot
.20857 .26299 Mdot
.21048 .39458 Mdot
.21238 .24204 Mdot
.21429 .29789 Mdot
.21619 .37067 Mdot
.2181 .34788 Mdot
.22 .34685 Mdot
.2219 .39419 Mdot
.22381 .3452 Mdot
.22571 .2603 Mdot
.22762 .24363 Mdot
.22952 .27032 Mdot
.23143 .26264 Mdot
.23333 .28183 Mdot
.23524 .29035 Mdot
.23714 .3398 Mdot
.23905 .43273 Mdot
.24095 .41835 Mdot
.24286 .44831 Mdot
.24476 .28667 Mdot
.24667 .32721 Mdot
.24857 .44135 Mdot
.25048 .44388 Mdot
.25238 .23067 Mdot
.25429 .23718 Mdot
.25619 .39664 Mdot
.2581 .26029 Mdot
.26 .35957 Mdot
.2619 .28686 Mdot
.26381 .3325 Mdot
.26571 .41343 Mdot
.26762 .44483 Mdot
.26952 .3965 Mdot
.27143 .32951 Mdot
.27333 .32376 Mdot
.27524 .38803 Mdot
.27714 .29768 Mdot
.27905 .28732 Mdot
.28095 .37245 Mdot
.28286 .32417 Mdot
.28476 .24167 Mdot
.28667 .39471 Mdot
.28857 .33684 Mdot
.29048 .40674 Mdot
.29238 .32866 Mdot
.29429 .45681 Mdot
.29619 .32555 Mdot
.2981 .34154 Mdot
.3 .29689 Mdot
.3019 .40634 Mdot
.30381 .42936 Mdot
.30571 .49032 Mdot
.30762 .28589 Mdot
.30952 .36392 Mdot
.31143 .38741 Mdot
.31333 .35552 Mdot
.31524 .35134 Mdot
.31714 .27109 Mdot
.31905 .29507 Mdot
.32095 .2581 Mdot
.32286 .23144 Mdot
.32476 .33554 Mdot
.32667 .44216 Mdot
.32857 .23818 Mdot
.33048 .23005 Mdot
.33238 .31054 Mdot
.33429 .29939 Mdot
.33619 .22545 Mdot
.3381 .40725 Mdot
.34 .38662 Mdot
.3419 .35192 Mdot
.34381 .43351 Mdot
.34571 .37112 Mdot
.34762 .35538 Mdot
.34952 .23006 Mdot
.35143 .4116 Mdot
.35333 .26107 Mdot
.35524 .34769 Mdot
.35714 .34298 Mdot
.35905 .25776 Mdot
.36095 .42267 Mdot
.36286 .42824 Mdot
.36476 .26836 Mdot
.36667 .2669 Mdot
.36857 .36946 Mdot
.37048 .23705 Mdot
.37238 .25978 Mdot
.37429 .33317 Mdot
.37619 .225 Mdot
.3781 .28555 Mdot
.38 .42273 Mdot
.3819 .44926 Mdot
.38381 .43873 Mdot
.38571 .22431 Mdot
.38762 .37801 Mdot
.38952 .36075 Mdot
.39143 .40561 Mdot
.39333 .33486 Mdot
.39524 .40605 Mdot
.39714 .40083 Mdot
.39905 .26572 Mdot
.40095 .32553 Mdot
.40286 .36464 Mdot
.40476 .33394 Mdot
.40667 .28292 Mdot
.40857 .29038 Mdot
.41048 .28287 Mdot
.41238 .27168 Mdot
.41429 .32479 Mdot
.41619 .30413 Mdot
.4181 .37382 Mdot
.42 .28794 Mdot
.4219 .28846 Mdot
.42381 .33895 Mdot
.42571 .26647 Mdot
.42762 .26723 Mdot
.42952 .25096 Mdot
.43143 .32282 Mdot
.43333 .37196 Mdot
.43524 .30266 Mdot
.43714 .35733 Mdot
.43905 .34175 Mdot
.44095 .22597 Mdot
.44286 .27023 Mdot
.44476 .25629 Mdot
.44667 .3144 Mdot
.44857 .33176 Mdot
.45048 .34171 Mdot
.45238 .36141 Mdot
.45429 .37876 Mdot
.45619 .26315 Mdot
.4581 .28925 Mdot
.46 .39776 Mdot
.4619 .26108 Mdot
.46381 .34003 Mdot
.46571 .41429 Mdot
.46762 .26443 Mdot
.46952 .31625 Mdot
.47143 .31206 Mdot
.47333 .37521 Mdot
.47524 .3021 Mdot
.47714 .37548 Mdot
.47905 .35343 Mdot
.48095 .40038 Mdot
.48286 .24994 Mdot
.48476 .38355 Mdot
.48667 .42604 Mdot
.48857 .34538 Mdot
.49048 .40317 Mdot
.49238 .24636 Mdot
.49429 .44033 Mdot
.49619 .28555 Mdot
.4981 .24803 Mdot
.5 .36359 Mdot
.5019 .24824 Mdot
.50381 .352 Mdot
.50571 .24951 Mdot
.50762 .28104 Mdot
.50952 .33433 Mdot
.51143 .23677 Mdot
.51333 .24804 Mdot
.51524 .34242 Mdot
.51714 .38405 Mdot
.51905 .3074 Mdot
.52095 .38992 Mdot
.52286 .3866 Mdot
.52476 .37439 Mdot
.52667 .30156 Mdot
.52857 .39194 Mdot
.53048 .31777 Mdot
.53238 .36462 Mdot
.53429 .31499 Mdot
.53619 .2819 Mdot
.5381 .36052 Mdot
.54 .41908 Mdot
.5419 .26428 Mdot
.54381 .41974 Mdot
.54571 .38761 Mdot
.54762 .32822 Mdot
.54952 .35527 Mdot
.55143 .23154 Mdot
.55333 .34176 Mdot
.55524 .26181 Mdot
.55714 .41082 Mdot
.55905 .26592 Mdot
.56095 .26328 Mdot
.56286 .3486 Mdot
.56476 .3217 Mdot
.56667 .33064 Mdot
.56857 .23579 Mdot
.57048 .35992 Mdot
.57238 .26282 Mdot
.57429 .32091 Mdot
.57619 .25878 Mdot
.5781 .42223 Mdot
.58 .36335 Mdot
.5819 .33778 Mdot
.58381 .45058 Mdot
.58571 .32229 Mdot
.58762 .36672 Mdot
.58952 .31245 Mdot
.59143 .27196 Mdot
.59333 .32234 Mdot
.59524 .37503 Mdot
.59714 .42135 Mdot
.59905 .35465 Mdot
.60095 .49827 Mdot
.60286 .34855 Mdot
.60476 .36365 Mdot
.60667 .39438 Mdot
.60857 .43883 Mdot
.61048 .23389 Mdot
.61238 .27049 Mdot
.61429 .40419 Mdot
.61619 .2544 Mdot
.6181 .32211 Mdot
.62 .26413 Mdot
.6219 .27896 Mdot
.62381 .23535 Mdot
.62571 .3689 Mdot
.62762 .29528 Mdot
.62952 .27386 Mdot
.63143 .2751 Mdot
.63333 .42442 Mdot
.63524 .32611 Mdot
.63714 .25638 Mdot
.63905 .29432 Mdot
.64095 .46773 Mdot
.64286 .29854 Mdot
.64476 .27364 Mdot
.64667 .34242 Mdot
.64857 .33347 Mdot
.65048 .30794 Mdot
.65238 .29371 Mdot
.65429 .27058 Mdot
.65619 .24783 Mdot
.6581 .34002 Mdot
.66 .24716 Mdot
.6619 .26557 Mdot
.66381 .29563 Mdot
.66571 .32835 Mdot
.66762 .27114 Mdot
.66952 .39612 Mdot
.67143 .32218 Mdot
.67333 .3866 Mdot
.67524 .30872 Mdot
.67714 .31037 Mdot
.67905 .21885 Mdot
.68095 .24922 Mdot
.68286 .40176 Mdot
.68476 .31565 Mdot
.68667 .43479 Mdot
.68857 .27742 Mdot
.69048 .40184 Mdot
.69238 .38924 Mdot
.69429 .29943 Mdot
.69619 .36101 Mdot
.6981 .4568 Mdot
.7 .33274 Mdot
.7019 .32817 Mdot
.70381 .42004 Mdot
.70571 .34099 Mdot
.70762 .26149 Mdot
.70952 .41343 Mdot
.71143 .37285 Mdot
.71333 .33582 Mdot
.71524 .46882 Mdot
.71714 .40713 Mdot
.71905 .30604 Mdot
.72095 .24982 Mdot
.72286 .22766 Mdot
.72476 .27208 Mdot
.72667 .37265 Mdot
.72857 .32903 Mdot
.73048 .38237 Mdot
.73238 .27918 Mdot
.73429 .31262 Mdot
.73619 .24808 Mdot
.7381 .27412 Mdot
.74 .364 Mdot
.7419 .40517 Mdot
.74381 .39912 Mdot
.74571 .27309 Mdot
.74762 .28832 Mdot
.74952 .34569 Mdot
.75143 .30838 Mdot
.75333 .33761 Mdot
.75524 .25571 Mdot
.75714 .47081 Mdot
.75905 .23735 Mdot
.76095 .24287 Mdot
.76286 .31305 Mdot
.76476 .25481 Mdot
.76667 .32196 Mdot
.76857 .26987 Mdot
.77048 .24581 Mdot
.77238 .28936 Mdot
.77429 .29495 Mdot
.77619 .34739 Mdot
.7781 .26063 Mdot
.78 .3164 Mdot
.7819 .41993 Mdot
.78381 .38289 Mdot
.78571 .39558 Mdot
.78762 .25243 Mdot
.78952 .24563 Mdot
.79143 .22727 Mdot
.79333 .24731 Mdot
.79524 .25992 Mdot
.79714 .25302 Mdot
.79905 .29825 Mdot
.80095 .35489 Mdot
.80286 .33827 Mdot
.80476 .28895 Mdot
.80667 .28223 Mdot
.80857 .33151 Mdot
.81048 .3125 Mdot
.81238 .32204 Mdot
.81429 .36516 Mdot
.81619 .40954 Mdot
.8181 .32836 Mdot
.82 .35184 Mdot
.8219 .32735 Mdot
.82381 .36288 Mdot
.82571 .24426 Mdot
.82762 .33513 Mdot
.82952 .30101 Mdot
.83143 .39161 Mdot
.83333 .4077 Mdot
.83524 .30768 Mdot
.83714 .37249 Mdot
.83905 .24363 Mdot
.84095 .24309 Mdot
.84286 .25067 Mdot
.84476 .35336 Mdot
.84667 .26958 Mdot
.84857 .38862 Mdot
.85048 .40134 Mdot
.85238 .40175 Mdot
.85429 .39429 Mdot
.85619 .32486 Mdot
.8581 .43275 Mdot
.86 .32104 Mdot
.8619 .25818 Mdot
.86381 .39105 Mdot
.86571 .21982 Mdot
.86762 .29065 Mdot
.86952 .3175 Mdot
.87143 .252 Mdot
.87333 .39288 Mdot
.87524 .30222 Mdot
.87714 .36657 Mdot
.87905 .26585 Mdot
.88095 .36671 Mdot
.88286 .31692 Mdot
.88476 .27847 Mdot
.88667 .28399 Mdot
.88857 .34677 Mdot
.89048 .37572 Mdot
.89238 .31787 Mdot
.89429 .32035 Mdot
.89619 .40134 Mdot
.8981 .30527 Mdot
.9 .41734 Mdot
.9019 .309 Mdot
.90381 .25529 Mdot
.90571 .44046 Mdot
.90762 .34642 Mdot
.90952 .3336 Mdot
.91143 .25239 Mdot
.91333 .28476 Mdot
.91524 .32626 Mdot
.91714 .25596 Mdot
.91905 .33434 Mdot
.92095 .40284 Mdot
.92286 .37437 Mdot
.92476 .30061 Mdot
.92667 .35996 Mdot
.92857 .24914 Mdot
.93048 .43781 Mdot
.93238 .37867 Mdot
.93429 .3138 Mdot
.93619 .38708 Mdot
.9381 .33106 Mdot
.94 .27174 Mdot
.9419 .29327 Mdot
.94381 .38123 Mdot
.94571 .37272 Mdot
.94762 .26507 Mdot
.94952 .25228 Mdot
.95143 .4425 Mdot
.95333 .34266 Mdot
.95524 .29128 Mdot
.95714 .34502 Mdot
.95905 .34192 Mdot
.96095 .3089 Mdot
.96286 .44356 Mdot
.96476 .31351 Mdot
.96667 .39498 Mdot
.96857 .33293 Mdot
.97048 .4113 Mdot
.97238 .35089 Mdot
.97429 .38533 Mdot
.97619 .28533 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0<oooooo0_l0000jooooo`;o0000;oooool000Kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo077ooooo0_l0001Looooo`;o0000>_ooool2o`0002oooooo0006oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4
A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool05Oooool2o`0000Kooooo0_l0
000<ooooo`;o0000=?ooool2o`0000_ooooo0_l000000ooooooo0000o`00000?ooooo`;o0000FOoo
ool2o`0001Cooooo0_l00017ooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05Ooo
ool2o`0000Kooooo0_l0000<ooooo`;o00006Oooool2o`0001Oooooo1?l00002ooooo`;o00001ooo
ool2o`0001;ooooo0_l0001Iooooo`;o00005?ooool2o`0004Oooooo0006ooooo`05o`000?oooooo
ooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0
000<ooooo`;o00009_ooool2o`00013ooooo0_l0000Dooooo`;o000000?oooooo`000?l000001?oo
ool2o`0003oooooo0_l0000Aooooo`;o0000POooool000Kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo00cooooo0_l0000Vooooo`;o00004?ooool2o`0001Cooooo0_l0000>ooooo`;o0000
:oooool2o`0000_ooooo0_l00003ooooo`;o00003?ooool2o`0000;ooooo0_l0001mooooo`001_oo
ool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Cooooo0_l00003ooooo`;o0000>oooool2o`0001Kooooo
0_l0000<ooooo`;o0000:oooool2o`00013ooooo0_l0000@ooooo`;o0000:_ooool2o`00057ooooo
0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`;o00000oooool2o`0000So
oooo0_l0000Tooooo`;o00005Oooool2o`0000cooooo0_l00029ooooo`;o00006?ooool2o`0003Oo
oooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
00Cooooo1?l00006ooooo`03o`000?oooooooooo01?ooooo0_l0000Cooooo`;o00003oooool2o`00
00?ooooo0_l0000@ooooo`;o0000@Oooool2o`0005Cooooo0_l000000ooooooo0000o`000004oooo
o`;o00002_ooool2o`0000;ooooo0ol0000gooooo`00:Oooool2o`0000Sooooo0_l00008ooooo`;o
00005Oooool2o`0001Cooooo0_l0001Cooooo`Ko000000?oooooo`000?l00000;?ooool3o`0000Go
oooo0_l0000?ooooo`;o00002Oooool2o`0000Cooooo1?l00008ooooo`;o00000_ooool2o`0001_o
oooo0_l0000Kooooo`00:Oooool00ol0003oooooooooo`07ooooo`;o00000oooool2o`000003oooo
ool0003o000000;o0000K?ooool2o`0000oooooo0_l00003ooooo`Co000000?oooooo`000?l00000
;?ooool3o`0000Gooooo0_l0000:ooooo`;o00000oooool2o`0000oooooo1?l0000>ooooo`;o0000
1oooool2o`0000_ooooo0_l00003ooooo`;o00001Oooool2o`0001Cooooo000Yooooo`03o`000?oo
oooooooo00cooooo0_l000000ooooooo0000o`00001^ooooo`;o00003oooool2o`0002Wooooo0_l0
000Oooooo`;o00002Oooool2o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l000003Ooo
ool2o`0000Oooooo0_l00008ooooo`;o000000?oooooo`000?l000002_ooool2o`0001Cooooo000Y
ooooo`03o`000?oooooooooo00?ooooo1?l0001Eooooo`;o00002_ooool2o`0001[ooooo0_l0000X
ooooo`;o00002oooool2o`0000Cooooo0_l0000Tooooo`;o00000_ooool2o`0000Sooooo0_l0000C
ooooo`;o00002oooool2o`0000?ooooo0_l0000Nooooo`00:Oooool00ol0003oooooooooo`03oooo
o`Go00000oooool2o`0002Kooooo1?l00006ooooo`;o00002Oooool2o`0001;ooooo0_l00008oooo
o`Co00000_ooool2o`0001Kooooo0_l00003ooooo`;o00007?ooool2o`0000Gooooo0_l0000Aoooo
o`;o00005Oooool2o`0001Gooooo0_l00003ooooo`;o00005?ooool2o`00013ooooo0_l0000Noooo
o`00:Oooool2o`0000Oooooo0_l00003ooooo`;o00006Oooool2o`0000_ooooo1?l000000ooooooo
0000o`000003ooooo`Co00001oooool2o`0001cooooo0_l00004ooooo`;o00006Oooool6o`0001Ko
oooo0_l00002ooooo`Co00000_ooool2o`0000gooooo0_l0000Jooooo`;o00005Oooool2o`0000?o
oooo0_l0000_ooooo`;o00005Oooool002Wooooo00?o0000ooooooooool09_ooool2o`0000kooooo
1?l00005ooooo`;o0000:Oooool3o`0000Sooooo0_l00006ooooo`?o00001oooool2o`0000;ooooo
0_l0000Fooooo`;o00000oooool3o`0000;ooooo0_l0000=ooooo`;o00002oooool2o`0004Cooooo
0_l0000Dooooo`;o00005Oooool002Wooooo00?o0000ooooooooool0<?ooool4o`000008oa0@4?oo
oooo0000o`000?lb<S;o0000oc8b<_o^k^h2ooooo`;o000000Co<S8bo`000?lb<S;ok^k^5oooool2
o`0000gooooo2?l00003ooooo`?o000000?o<S8bonk^k_ooool00_ooool3o`000003oc8b<_o^k^ko
oooo00;o00008oooool2o`000005oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo0ol000000olb<S;ok^k^ooooo`07ooooo`Ko00007?ooool2o`000009oa0@
4?l0003o0000ooooooo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP09ooooo`;o00002?ooool2o`0001Cooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Yooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00;ooooo0_l000001?nHV9SooooooiRHV?mgMgLGooooo`;o00004?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400?ooooo00CoMgMgoiRHV?ooooooV9RH0_l00002ooooo`06ogMgMonHV9SooooooiRHV?mg
MgOooooo0_l0000Uooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOo0000o`000?nH
V9SoMgMg00?ooooo0_l000000oooooooV9RHogMgM`02o`0000?ooooo0_l000000ooooooo0000o`00
0002ooooo`;o00004Oooool2o`0000;ooooo1?l00004ooooo`0:o`000?oooooo0000o`000?oooooo
MgMgoiRHV?ooooooV9RHogMgM`?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`09ooooo`;o00007?oo
ool2o`0000?ooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo000Yooooo`?o0000<_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@02[ooooo00?o
V9RHob4Q8Oo^k^h01?ooool01?l@413oooooooooooooool2o`0000;ooooo00Go410@oooooooooooo
oooooa0@400/ooooo`05o`000?ooooooooooooooool@41000_l000000ooooooo410@ooooo`02oooo
o`05oa0@4?ooooooooooooooool@41000ol00002ooooo`;o00003?ooool2o`0000[ooooo0_l00002
ooooo`Co000000?oooooo`000?l000000ol00003ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@02Oooooo0_l00004ooooo`04o`000?oooooooooooa0@40?o
oooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo007ooooo000Yooooo`?o
0000<_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000002_ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`00000[ooooo`03ojVYZOl@413ooooo00;ooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;o000000?oooooo`000?l0
00004?ooool2o`0000cooooo0_l00005ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000005Oooool2o`0001Gooooo00Go
MgMgoc8b<_ooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`01ooooo`00:Oooool01?l0003oooooooooooooool2o`0001Wooooo0_l00009ooooo`?o
00002?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool3o`00
0003ooooool0003ooooo02_ooooo00?oMgMgofIVI_ooool00_ooool00ol0003oooooo`000003o`00
00;ooooo00Go0000ooooooooooooooooo`00000Fooooo`;o00001oooool2o`0000Wooooo00?o410@
o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_l0
000Qooooo`;o00001Oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00000oooool3o`000003ooooool0003ooooo01Cooooo0_l0000Booooo`05o`000?lQ8B7o0000oc8b
<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`00:Oooool01?l0003oooooooooooooool2o`0001Wooooo0_l00009ooooo`?o00001ooo
ool2o`0000Cooooo00Go410@oooooooooooooooooa0@4003ooooo`04oa0@4?l0003o0000ooooo`;o
00001?ooool2o`0000gooooo0_l0000Dooooo`;o000000?oooooo`000?ooool00_ooool00ol@413o
ooooo`000003o`0000;ooooo00Go410@oooooooooooooooooa0@400Booooo`;o00000_ooool2o`00
00Oooooo0_l0000:ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@4100:Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oo
ooooooooooooool@41000oooool01Ol@413o0000o`000?oooooo410@01Kooooo0_l00006ooooo`;o
00002Oooool00ol0003oooooooooo`04ooooo`03oa0@4?oooooooooo00;o00000oooool01Ol@413o
oooooooooooooooo410@00?ooooo000Yooooo`03o`000?oooooooooo037ooooo0_l00004ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01?mgMgOoV9RHoooooonHV9P2o`0000Cooooo0_l00003
ooooo`;o00002?ooool2o`0001?ooooo0ol000000onHV9So410@ooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00_ooool2o`000004oiRHV?ooooooV9RHogMgM`Kooooo0_l0000:ooooo`;o0000
5?ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL09_ooool2o`000004ooooooo^k^koA4A4o`0000;ooooo0_l0
00001OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0_l000000oooooooV9RHogMgM`0Fooooo`;o0000
1_ooool2o`0000Wooooo00?o0000ooooooooool01?ooool00omgMgOoV9RHooooo`02o`0000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool00ol0003oooooooooo`0=ooooo`;o0000
1_ooool2o`0000;ooooo0_l0000Eooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`05onk^k_l0003o0000oc8b<_o^k^h02_ooool2o`0001gooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c003ooooo`03onk^k_lb<S;o000000;o00000_ooool2o`000004oc8b<_l0003o
<S8bonk^kPKooooo0_l0000Pooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Vooooo`;o00000_ooool01?mg
MgOo0000ooooooooool2o`000005onk^k_lb<S;o0000oc8b<_o^k^h00oooool3o`000003oc8b<_o^
k^kooooo00oooooo0_l0000Eooooo`Oo00000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool2o`0000kooooo0_l00006ooooo`;o0000
0_ooool2o`0000Gooooo0_l0000Nooooo`;o00006Oooool2o`0001_ooooo0_l00014ooooo`;o0000
0_ooool2o`0000;ooooo0_l00002ooooo`;o00008_ooool2o`0001cooooo0_l0000Eooooo`;o0000
0oooool2o`0001;ooooo000Yooooo`03o`000?oooooooooo023ooooo0_l0000Hooooo`;o00004_oo
ool2o`0000Gooooo0_l00004ooooo`;o00000oooool2o`0005cooooo0_l00002ooooo`?o000000?o
ooooo`000?l000000_ooool2o`0000Sooooo0_l0000Hooooo`;o00001_ooool2o`0004Cooooo000Y
ooooo`03o`000?oooooooooo00Oooooo0_l0000Hooooo`;o00005oooool2o`0001;ooooo0_l00005
ooooo`;o00002Oooool2o`0002_ooooo0_l0000?ooooo`;o00008oooool2o`0000oooooo0_l0000P
ooooo`;o00001oooool2o`0000gooooo0_l0000>ooooo`;o00007?ooool002Wooooo00?o0000oooo
ooooool01oooool2o`0001Sooooo0_l0001Gooooo`;o00001Oooool2o`0000[ooooo0_l0000?oooo
o`;o0000Goooool2o`0000gooooo0_l00005ooooo`;o00001oooool2o`0001cooooo000Yooooo`03
o`000?oooooooooo02gooooo0_l0001;ooooo`;o00001Oooool2o`0001Wooooo0_l0000Xooooo`;o
00001_ooool2o`0000cooooo0_l00008ooooo`;o00006Oooool2o`0001;ooooo0_l0000Uooooo`00
8Oooooooo`0004Co00001?ooool002Wooooo00?o0000ooooooooool00_l00006ooooo`;o00003?oo
ool2o`0000[ooooo0ol00006ooooo`;o000000?oooooo`000?ooool02_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool2o`0000[ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`;o00001_ooool2o`0000;ooooo00?o
0000ooooooooool02Oooool01?l0003oooooooooooooool2o`0000Oooooo00?o0000ooooooooool0
1_ooool2o`000003ooooool0003ooooo00[ooooo00?o0000ooooooooool02Oooool3o`0000[ooooo
00?o0000ooooooooool01?ooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00006ooooo`03
o`000?oooooooooo00Cooooo0_l00003ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02Oooool2o`0000Sooooo0ol00006ooooo`?o00000_ooool00ol0003oooooooooo`0:ooooo`00
:Oooool00ol0003oooooooooo`02o`0001Cooooo0_l0000;ooooo`;o00001_ooool3o`0000cooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`09ooooo`;o00001_ooool2o`00017ooooo
0ol0000@ooooo`;o000000?oooooo`000?ooool06_ooool2o`0000kooooo0_l00007ooooo`;o0000
0oooool2o`000003ooooool0003ooooo00Gooooo0_l0000Aooooo`;o00000_ooool2o`0000;ooooo
0_l0000;ooooo`;o00002?ooool2o`0000;ooooo00?o0000ooooooooool02_ooool002Wooooo00?o
0000ooooooooool0;?ooool3o`0000Cooooo0_l0001Gooooo`;o00004Oooool2o`0000cooooo0_l0
000Rooooo`;o00007?ooool2o`0001Sooooo0_l000000ooooooo0000o`000002ooooo`;o00000_oo
ool2o`0002Kooooo000Yooooo`03o`000?oooooooooo01Sooooo0_l0000Cooooo`;o00001?ooool2
o`0001Sooooo0_l000000ooooooo0000o`00000]ooooo`;o0000:Oooool2o`000003ooooool0003o
000000;ooooo1?l00006ooooo`;o00004?ooool2o`0001cooooo0_l0000=ooooo`;o00003Oooool2
o`0000Wooooo0_l0000Vooooo`00:Oooool2o`0001Wooooo0_l0000Zooooo`;o00001oooool2o`00
0003ooooool0003o000000;ooooo0_l0000Pooooo`;o00000_ooool2o`0000?ooooo0_l0000Yoooo
o`;o00001Oooool4o`0000Kooooo0_l00004ooooo`;o00002_ooool2o`0001cooooo0_l0000=oooo
o`;o000000?oooooo`000?l000002Oooool2o`00017ooooo0_l0000Oooooo`00:Oooool00ol0003o
ooooooooo`14ooooo`;o00001_ooool2o`0000Gooooo0ol0000Pooooo`;o00000_ooool2o`0002Wo
oooo0_l0000Jooooo`;o00002?ooool2o`0000Wooooo0_l00007ooooo`;o00006oooool3o`0000Wo
oooo0_l0000Aooooo`;o00007oooool002Wooooo00?o0000ooooooooool00_ooool4o`0002?ooooo
0_l00005ooooo`;o00005oooool2o`000003ooooool0003o000000Gooooo0_l0000Hooooo`;o0000
5_ooool2o`0001kooooo0_l00004ooooo`;o00006?ooool2o`0000Cooooo0_l00009ooooo`;o0000
1oooool2o`0001Sooooo0_l000000ooooooo0000o`00000Kooooo`;o00001oooool2o`0000Sooooo
0_l0000>ooooo`00:Oooool00ol0003oooooooooo`02ooooo`Co00001?ooool2o`000003ooooool0
003o000001[ooooo0_l00004ooooo`?o00005oooool2o`0001;ooooo0_l0000>ooooo`;o00001?oo
ool2o`0000;ooooo0_l0000<ooooo`;o00004Oooool2o`00017ooooo0_l0000Hooooo`;o00003ooo
ool2o`0000;ooooo0_l0000Mooooo`;o00001?ooool2o`0001Sooooo0_l000000ooooooo0000o`00
0004ooooo`;o00002?ooool2o`0000kooooo000Yooooo`04o`000?oooooo0000o`0000Wooooo0_l0
00000ooooooo0000o`00000Pooooo`;o00004?ooool2o`0000kooooo0_l0000:ooooo`;o00005?oo
ool2o`0000;ooooo0_l00004ooooo`;o00006Oooool2o`0001Kooooo0_l0000Xooooo`;o00002ooo
ool2o`0000kooooo0_l00006ooooo`;o00006oooool2o`0001kooooo000Yooooo`Co00008Oooool2
o`000003ooooool0003o000001[ooooo0_l0000>ooooo`;o000000?oooooo`000?l000004Oooool2
o`0001Cooooo0_l00003ooooo`;o000000?oooooo`000?l000000oooool2o`0000kooooo0_l0000;
ooooo`;o00001oooool2o`0001?ooooo0_l000000ooooooo0000o`00000>ooooo`;o00003Oooool2
o`0000kooooo0_l0000^ooooo`Co00004Oooool002Wooooo00Co0000ooooool0003o00001?ooool2
o`0001_ooooo0_l000000ooooooo0000o`00000Fooooo`;o00005Oooool2o`00017ooooo0_l0000I
ooooo`;o000000?oooooo`000?l000000oooool2o`0000Kooooo0_l00006ooooo`;o00002oooool2
o`0001cooooo0_l000000ooooooo0000o`00000>ooooo`;o00003?ooool2o`0003oooooo1?l0000A
ooooo`00:Oooool01?l0003oooooo`000?l00004ooooo`;o00006Oooool2o`0000Sooooo0_l0000?
ooooo`Co0000:?ooool2o`0002Wooooo0_l0000Fooooo`;o00002_ooool2o`0002kooooo0_l00006
ooooo`;o00008_ooool2o`0000Cooooo0_l0000>ooooo`;o00004_ooool002Wooooo0_l0000;oooo
o`;o00003?ooool2o`0000Kooooo0_l00008ooooo`;o00001_ooool2o`0000Oooooo0_l0000Moooo
o`;o00001oooool2o`0000;ooooo0_l0000^ooooo`;o00004Oooool2o`0000[ooooo0_l0000foooo
o`;o00003?ooool2o`0001Cooooo0_l00004ooooo`;o00004oooool2o`0000gooooo000Yooooo`;o
00002oooool2o`0000Sooooo0_l00002ooooo`;o00003Oooool2o`0000Wooooo0_l0000Vooooo`;o
00001oooool3o`0002Wooooo0_l00006ooooo`;o00003?ooool2o`0000kooooo0_l0000oooooo`;o
00001?ooool2o`0000Kooooo0_l0000Wooooo`;o00003Oooool002Wooooo0_l0000Eooooo`;o0000
4Oooool2o`00033ooooo0_l00009ooooo`;o00006oooool2o`0000cooooo0_l0000Dooooo`;o0000
3_ooool2o`0003oooooo0_l0000<ooooo`;o0000=_ooool002Wooooo00?o0000ooooooooool05?oo
ool2o`0000gooooo0_l00005ooooo`;o00000_ooool2o`0000;ooooo0_l0000Dooooo`;o00003ooo
ool2o`0001Oooooo0_l0000=ooooo`;o00000oooool2o`0001[ooooo0_l00008ooooo`;o00009_oo
ool2o`0004Wooooo0_l0000Kooooo`00:Oooool00ol0003oooooooooo`0Booooo`Co00003Oooool2
o`0000Gooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo0_l0000@ooooo`;o00003_ooool2
o`0001Sooooo0_l00002ooooo`;o00003_ooool2o`0000gooooo0_l00009ooooo`Co00002?ooool2
o`000003ooooool0003o000000Kooooo0_l0000Kooooo`;o00003Oooool2o`0001Wooooo0_l0000O
ooooo`;o00006oooool002Wooooo00?o0000ooooooooool04_ooool2o`0002;ooooo0_l0000Poooo
o`;o00007?ooool2o`0001gooooo0_l00009ooooo`;o00003Oooool2o`000003ooooool0003o0000
00?ooooo0_l0000Zooooo`;o00005Oooool2o`0000;ooooo0_l0000?ooooo`?o0000:_ooool002Wo
oooo00?o0000ooooooooool03_ooool2o`0000[ooooo0_l0000Nooooo`;o0000;oooool2o`0004Go
oooo0_l0000:ooooo`;o0000>_ooool2o`0001?ooooo0ol0000Zooooo`00:Oooool2o`0000oooooo
0_l0000:ooooo`;o00000oooool2o`0001Wooooo0_l0000Cooooo`;o00004oooool2o`0000Gooooo
0_l0000>ooooo`;o00000oooool2o`0003cooooo0_l0000Iooooo`;o00000oooool2o`0002;ooooo
0_l0000Qooooo`;o00005Oooool002Wooooo00Co0000oooooooooooooooo0_l0000Looooo`;o0000
;_ooool2o`0001?ooooo0_l0000Eooooo`;o00000oooool2o`0000_ooooo0ol0000=ooooo`;o0000
5Oooool2o`0002?ooooo0_l00003ooooo`;o00008_ooool2o`0000oooooo0_l00008ooooo`;o0000
1_ooool2o`0001Gooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool01?l0003oooooooooooooool2o`00
06kooooo0_l0000Dooooo`;o00001?ooool3o`0000gooooo0_l0000Eooooo`;o0000GOooool2o`00
00Sooooo0_l000000ooooooo0000o`00000Jooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo01gooooo0_l0001Booooo`;o00005?ooool2o`0005Kooooo0_l0000@
ooooo`;o0000;Oooool2o`0000;ooooo0_l0000Fooooo`001_ooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo01Oooooo0_l00004ooooo`;o0000LOooool2o`0000Wooooo0_l00012ooooo`;o00004?ooool2
o`00037ooooo0_l00008ooooo`;o00003?ooool000Kooooo00Go0000ooooooooooooooooo`00000=
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0000Wooooo0_l0000<
ooooo`;o00001Oooool2o`0002gooooo0_l0000:ooooo`;o00001oooool2o`0002cooooo0_l00009
ooooo`Co00001Oooool2o`0002Oooooo0_l00004ooooo`;o0000<?ooool2o`0001_ooooo0_l0000:
ooooo`;o00003?ooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKo
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00Wooooo0_l0
000@ooooo`;o000000?oooooo`000?l00000;Oooool2o`0000[ooooo0_l00007ooooo`;o0000>?oo
ool5o`0000?ooooo0_l0000Wooooo`;o00001?ooool2o`0002_ooooo0_l00003ooooo`;o00000ooo
ool2o`0001Kooooo0_l0000Hooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`;o00004?ooool2o`0000[ooooo0_l0
000Kooooo`;o00000_ooool2o`0001?ooooo0_l00019ooooo`;o000000?oooooo`000?l000005ooo
ool2o`0003Oooooo0_l0000=ooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`;o0000
7?ooool2o`0000oooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zj
oooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool2o`00013ooooo0_l0000Mooooo`;o
00002?ooool2o`0000;ooooo0_l00009ooooo`;o00000_ooool2o`0000Cooooo0_l0000fooooo`;o
0000;Oooool2o`0001;ooooo0_l0000Sooooo`;o00005?ooool2o`0000Cooooo0_l0000Looooo`;o
00003oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool0;_ooool2o`0000Gooooo0_l0000@oooo
o`;o00000_ooool2o`0002Oooooo0_l0000Cooooo`;o00001?ooool2o`0003_ooooo0_l00002oooo
o`;o000000?oooooo`000?l000003oooool2o`00023ooooo0ol0000<ooooo`;o00009Oooool002Wo
oooo0_l0000Mooooo`;o00005oooool2o`0003gooooo0_l0000Iooooo`;o000000?oooooo`000?l0
00009_ooool2o`0001Cooooo0_l000000ooooooo0000o`00000>ooooo`?o00008?ooool3o`0000co
oooo0_l00006ooooo`;o00007Oooool002Wooooo00?o0000ooooooooool07?ooool2o`0003Cooooo
0_l00002ooooo`;o00002Oooool2o`0000oooooo1?l0000Looooo`;o00009_ooool2o`0001oooooo
0_l00006ooooo`;o00007?ooool2o`0001[ooooo0_l0000Mooooo`00:Oooool00ol0003ooooooooo
o`0Jooooo`;o0000=_ooool2o`0000;ooooo0_l00009ooooo`;o00003oooool4o`0003;ooooo0_l0
000aooooo`;o00007_ooool2o`0000Cooooo0_l0000Zooooo`;o00003Oooool002Wooooo00?o0000
ooooooooool06_ooool2o`0002kooooo0_l0000Jooooo`;o00008_ooool2o`0001cooooo0_l0000_
ooooo`;o00008?ooool2o`00033ooooo0_l0000=ooooo`00:Oooool00ol0003oooooooooo`0`oooo
o`;o00006?ooool2o`0001[ooooo0_l0000Rooooo`;o0000COooool2o`0003_ooooo0_l0000Toooo
o`00:Oooool2o`00017ooooo1?l0000Looooo`;o00001Oooool2o`0000Wooooo0_l0001Nooooo`?o
0000<_ooool2o`0001Oooooo0_l0000Tooooo`;o00009?ooool002Wooooo00?o0000ooooooooool0
4?ooool4o`0002?ooooo0_l00009ooooo`;o00009Oooool2o`0000Cooooo0_l0000aooooo`?o0000
2Oooool2o`0000Gooooo0_l0000Pooooo`;o00005oooool2o`0004[ooooo000Yooooo`03o`000?oo
oooooooo06Wooooo0_l00004ooooo`;o00008?ooool2o`0001_ooooo0_l00005ooooo`;o00002Ooo
ool2o`0007[ooooo000Yooooo`03o`000?oooooooooo02;ooooo0_l0000booooo`;o00004Oooool2
o`0002Kooooo0_l0000]ooooo`;o0000N_ooool002Wooooo00?o0000ooooooooool00_ooool2o`00
01kooooo1?l0000Kooooo`;o00004oooool2o`00017ooooo0_l0002Nooooo`;o0000<Oooool002Wo
oooo0_l00003ooooo`;o00003?ooool2o`0001;ooooo0_l0000Kooooo`;o00008?ooool2o`0006co
oooo0_l0000fooooo`;o0000<Oooool002Wooooo00?o0000ooooooooool04?ooool2o`00057ooooo
0_l0000;ooooo`;o0000A_ooool2o`0001Oooooo0_l0001=ooooo`;o00006_ooool002Wooooo00?o
0000ooooooooool07oooool2o`0000Cooooo0_l0000Nooooo`;o00005oooool2o`00013ooooo0_l0
000Rooooo`;o00008_ooool2o`0005kooooo0_l00006ooooo`;o00001Oooool2o`0001?ooooo000Y
ooooo`03o`000?oooooooooo01oooooo0_l00004ooooo`;o00007_ooool2o`0000Cooooo0_l0000A
ooooo`;o0000=?ooool2o`0008;ooooo0_l0000=ooooo`;o000000?oooooo`000?l000004?ooool0
02Wooooo00?o0000ooooooooool0@oooool4o`0000Cooooo0_l0003Mooooo`;o00004?ooool002Wo
oooo0_l00014ooooo`;o0000:_ooool2o`0003oooooo0_l0002:ooooo`00:Oooool00ol0003ooooo
ooooo`1_ooooo`;o0000?oooool2o`0008[ooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo05?o
oooo0_l00020ooooo`;o0000IOooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo05?ooooo0_l00020ooooo`;o
0000IOooool000kooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?o
oooo0ol0003oooooocgooooo000>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`33oooo
o`;o00005_ooool2o`0005oooooo000>ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0<?ooooo0_l0000Fooooo`;o00002oooool2o`00
05;ooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo0>Sooooo0_l0001Booooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`1Gooooo`;o0000hoooool002Wooooo0_l0001Hoooo
o`;o0000hoooool002Wooooo00?o0000ooooooooool0]_ooool2o`0008Cooooo000Yooooo`03o`00
0?oooooooooo0;Kooooo0_l00024ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOoo
ool02?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolmooooo`001_ooool01Ol0003ooooo
oooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03
oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo
0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo
00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool001oooooo1?l000000ol@413oooooooooo`03ooooo`03o`00
0?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo0ol0003oooooocgooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool001oooooo00?oEEEEofIVI_l00000oooooom7ooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .26258 Mdot
.02762 .40331 Mdot
.02952 .30377 Mdot
.03143 .3266 Mdot
.03333 .27789 Mdot
.03524 .37707 Mdot
.03714 .27537 Mdot
.03905 .43712 Mdot
.04095 .37827 Mdot
.04286 .34834 Mdot
.04476 .28838 Mdot
.04667 .41599 Mdot
.04857 .28146 Mdot
.05048 .3177 Mdot
.05238 .42087 Mdot
.05429 .28392 Mdot
.05619 .36356 Mdot
.0581 .26784 Mdot
.06 .35474 Mdot
.0619 .42544 Mdot
.06381 .28462 Mdot
.06571 .40061 Mdot
.06762 .39389 Mdot
.06952 .25314 Mdot
.07143 .3407 Mdot
.07333 .28784 Mdot
.07524 .25503 Mdot
.07714 .35687 Mdot
.07905 .42052 Mdot
.08095 .40188 Mdot
.08286 .26411 Mdot
.08476 .38872 Mdot
.08667 .4467 Mdot
.08857 .28572 Mdot
.09048 .29204 Mdot
.09238 .39102 Mdot
.09429 .26847 Mdot
.09619 .33064 Mdot
.0981 .41564 Mdot
.1 .39415 Mdot
.1019 .31664 Mdot
.10381 .24431 Mdot
.10571 .37756 Mdot
.10762 .31853 Mdot
.10952 .24207 Mdot
.11143 .36595 Mdot
.11333 .34209 Mdot
.11524 .33218 Mdot
.11714 .32081 Mdot
.11905 .42357 Mdot
.12095 .31839 Mdot
.12286 .37674 Mdot
.12476 .27311 Mdot
.12667 .3377 Mdot
.12857 .36481 Mdot
.13048 .42642 Mdot
.13238 .4354 Mdot
.13429 .36126 Mdot
.13619 .24325 Mdot
.1381 .23884 Mdot
.14 .36698 Mdot
.1419 .34582 Mdot
.14381 .41536 Mdot
.14571 .33655 Mdot
.14762 .44057 Mdot
.14952 .41463 Mdot
.15143 .34336 Mdot
.15333 .32015 Mdot
.15524 .34302 Mdot
.15714 .23868 Mdot
.15905 .31851 Mdot
.16095 .31933 Mdot
.16286 .34735 Mdot
.16476 .31414 Mdot
.16667 .41552 Mdot
.16857 .30092 Mdot
.17048 .27274 Mdot
.17238 .36208 Mdot
.17429 .39263 Mdot
.17619 .25048 Mdot
.1781 .26768 Mdot
.18 .39758 Mdot
.1819 .29414 Mdot
.18381 .25194 Mdot
.18571 .44799 Mdot
.18762 .25938 Mdot
.18952 .29144 Mdot
.19143 .31474 Mdot
.19333 .37122 Mdot
.19524 .31688 Mdot
.19714 .33911 Mdot
.19905 .46106 Mdot
.20095 .28951 Mdot
.20286 .35061 Mdot
.20476 .31813 Mdot
.20667 .46762 Mdot
.20857 .32507 Mdot
.21048 .3052 Mdot
.21238 .25127 Mdot
.21429 .36354 Mdot
.21619 .29262 Mdot
.2181 .37837 Mdot
.22 .42286 Mdot
.2219 .34102 Mdot
.22381 .24966 Mdot
.22571 .26474 Mdot
.22762 .30218 Mdot
.22952 .33664 Mdot
.23143 .28646 Mdot
.23333 .23964 Mdot
.23524 .34257 Mdot
.23714 .32708 Mdot
.23905 .38079 Mdot
.24095 .41551 Mdot
.24286 .3576 Mdot
.24476 .26741 Mdot
.24667 .36528 Mdot
.24857 .43765 Mdot
.25048 .42262 Mdot
.25238 .30458 Mdot
.25429 .28939 Mdot
.25619 .29144 Mdot
.2581 .35259 Mdot
.26 .41703 Mdot
.2619 .23767 Mdot
.26381 .33688 Mdot
.26571 .41999 Mdot
.26762 .47207 Mdot
.26952 .35203 Mdot
.27143 .30383 Mdot
.27333 .39001 Mdot
.27524 .32834 Mdot
.27714 .39628 Mdot
.27905 .36499 Mdot
.28095 .38916 Mdot
.28286 .40123 Mdot
.28476 .26826 Mdot
.28667 .42479 Mdot
.28857 .3454 Mdot
.29048 .44492 Mdot
.29238 .41297 Mdot
.29429 .40488 Mdot
.29619 .27135 Mdot
.2981 .35621 Mdot
.3 .3621 Mdot
.3019 .42488 Mdot
.30381 .44686 Mdot
.30571 .44114 Mdot
.30762 .34478 Mdot
.30952 .33524 Mdot
.31143 .277 Mdot
.31333 .3786 Mdot
.31524 .30708 Mdot
.31714 .24486 Mdot
.31905 .32256 Mdot
.32095 .3435 Mdot
.32286 .31925 Mdot
.32476 .40554 Mdot
.32667 .43314 Mdot
.32857 .27544 Mdot
.33048 .30747 Mdot
.33238 .24701 Mdot
.33429 .38803 Mdot
.33619 .2945 Mdot
.3381 .351 Mdot
.34 .36573 Mdot
.3419 .26489 Mdot
.34381 .44486 Mdot
.34571 .28017 Mdot
.34762 .33475 Mdot
.34952 .30142 Mdot
.35143 .41857 Mdot
.35333 .29297 Mdot
.35524 .29804 Mdot
.35714 .27709 Mdot
.35905 .32341 Mdot
.36095 .4453 Mdot
.36286 .4702 Mdot
.36476 .35206 Mdot
.36667 .2897 Mdot
.36857 .41957 Mdot
.37048 .3351 Mdot
.37238 .37065 Mdot
.37429 .2762 Mdot
.37619 .30083 Mdot
.3781 .32738 Mdot
.38 .35926 Mdot
.3819 .47104 Mdot
.38381 .39535 Mdot
.38571 .31258 Mdot
.38762 .38736 Mdot
.38952 .24655 Mdot
.39143 .42523 Mdot
.39333 .31557 Mdot
.39524 .30731 Mdot
.39714 .44543 Mdot
.39905 .23717 Mdot
.40095 .41197 Mdot
.40286 .33622 Mdot
.40476 .42856 Mdot
.40667 .24753 Mdot
.40857 .32498 Mdot
.41048 .32274 Mdot
.41238 .31205 Mdot
.41429 .25709 Mdot
.41619 .41082 Mdot
.4181 .29905 Mdot
.42 .26476 Mdot
.4219 .36515 Mdot
.42381 .33148 Mdot
.42571 .28404 Mdot
.42762 .27023 Mdot
.42952 .34492 Mdot
.43143 .36386 Mdot
.43333 .28152 Mdot
.43524 .25668 Mdot
.43714 .272 Mdot
.43905 .36564 Mdot
.44095 .29234 Mdot
.44286 .31867 Mdot
.44476 .26334 Mdot
.44667 .40676 Mdot
.44857 .36613 Mdot
.45048 .24015 Mdot
.45238 .2665 Mdot
.45429 .29406 Mdot
.45619 .28095 Mdot
.4581 .25257 Mdot
.46 .40182 Mdot
.4619 .2922 Mdot
.46381 .41865 Mdot
.46571 .31948 Mdot
.46762 .32122 Mdot
.46952 .30477 Mdot
.47143 .41519 Mdot
.47333 .35099 Mdot
.47524 .25369 Mdot
.47714 .26241 Mdot
.47905 .3179 Mdot
.48095 .35918 Mdot
.48286 .34273 Mdot
.48476 .31822 Mdot
.48667 .34085 Mdot
.48857 .38851 Mdot
.49048 .33865 Mdot
.49238 .32002 Mdot
.49429 .40158 Mdot
.49619 .33133 Mdot
.4981 .34928 Mdot
.5 .37337 Mdot
.5019 .32426 Mdot
.50381 .41244 Mdot
.50571 .25059 Mdot
.50762 .27069 Mdot
.50952 .3057 Mdot
.51143 .33278 Mdot
.51333 .29597 Mdot
.51524 .28571 Mdot
.51714 .38483 Mdot
.51905 .30979 Mdot
.52095 .44166 Mdot
.52286 .29075 Mdot
.52476 .33958 Mdot
.52667 .25369 Mdot
.52857 .31824 Mdot
.53048 .27202 Mdot
.53238 .37562 Mdot
.53429 .23999 Mdot
.53619 .33796 Mdot
.5381 .38926 Mdot
.54 .40485 Mdot
.5419 .26497 Mdot
.54381 .40854 Mdot
.54571 .37612 Mdot
.54762 .34934 Mdot
.54952 .28915 Mdot
.55143 .32007 Mdot
.55333 .29369 Mdot
.55524 .27192 Mdot
.55714 .33342 Mdot
.55905 .27151 Mdot
.56095 .34839 Mdot
.56286 .41205 Mdot
.56476 .32749 Mdot
.56667 .2733 Mdot
.56857 .28087 Mdot
.57048 .42923 Mdot
.57238 .33031 Mdot
.57429 .30482 Mdot
.57619 .27751 Mdot
.5781 .40569 Mdot
.58 .35165 Mdot
.5819 .24466 Mdot
.58381 .47043 Mdot
.58571 .23128 Mdot
.58762 .43131 Mdot
.58952 .22988 Mdot
.59143 .30782 Mdot
.59333 .23094 Mdot
.59524 .26272 Mdot
.59714 .38842 Mdot
.59905 .42572 Mdot
.60095 .46969 Mdot
.60286 .27697 Mdot
.60476 .3919 Mdot
.60667 .34355 Mdot
.60857 .39714 Mdot
.61048 .34066 Mdot
.61238 .33135 Mdot
.61429 .32161 Mdot
.61619 .27784 Mdot
.6181 .31533 Mdot
.62 .35694 Mdot
.6219 .35287 Mdot
.62381 .3121 Mdot
.62571 .25415 Mdot
.62762 .26483 Mdot
.62952 .2485 Mdot
.63143 .25229 Mdot
.63333 .44352 Mdot
.63524 .28533 Mdot
.63714 .36761 Mdot
.63905 .22578 Mdot
.64095 .44114 Mdot
.64286 .33957 Mdot
.64476 .35692 Mdot
.64667 .26108 Mdot
.64857 .40419 Mdot
.65048 .25035 Mdot
.65238 .32604 Mdot
.65429 .29251 Mdot
.65619 .3228 Mdot
.6581 .42067 Mdot
.66 .34785 Mdot
.6619 .31795 Mdot
.66381 .3771 Mdot
.66571 .31655 Mdot
.66762 .31126 Mdot
.66952 .40295 Mdot
.67143 .38088 Mdot
.67333 .36717 Mdot
.67524 .2468 Mdot
.67714 .25114 Mdot
.67905 .30441 Mdot
.68095 .29112 Mdot
.68286 .38327 Mdot
.68476 .33595 Mdot
.68667 .441 Mdot
.68857 .26199 Mdot
.69048 .42434 Mdot
.69238 .40245 Mdot
.69429 .25912 Mdot
.69619 .3541 Mdot
.6981 .40449 Mdot
.7 .41636 Mdot
.7019 .23257 Mdot
.70381 .40091 Mdot
.70571 .26628 Mdot
.70762 .26274 Mdot
.70952 .41765 Mdot
.71143 .36704 Mdot
.71333 .4179 Mdot
.71524 .45396 Mdot
.71714 .34741 Mdot
.71905 .40107 Mdot
.72095 .36146 Mdot
.72286 .28674 Mdot
.72476 .2833 Mdot
.72667 .33404 Mdot
.72857 .41305 Mdot
.73048 .43934 Mdot
.73238 .27495 Mdot
.73429 .23508 Mdot
.73619 .30698 Mdot
.7381 .35682 Mdot
.74 .28129 Mdot
.7419 .32404 Mdot
.74381 .35522 Mdot
.74571 .23887 Mdot
.74762 .38024 Mdot
.74952 .39795 Mdot
.75143 .22895 Mdot
.75333 .39554 Mdot
.75524 .3661 Mdot
.75714 .39778 Mdot
.75905 .27775 Mdot
.76095 .32177 Mdot
.76286 .3178 Mdot
.76476 .24612 Mdot
.76667 .37267 Mdot
.76857 .29943 Mdot
.77048 .35762 Mdot
.77238 .23684 Mdot
.77429 .32636 Mdot
.77619 .32649 Mdot
.7781 .33368 Mdot
.78 .25656 Mdot
.7819 .35026 Mdot
.78381 .29861 Mdot
.78571 .29094 Mdot
.78762 .36415 Mdot
.78952 .31585 Mdot
.79143 .34228 Mdot
.79333 .28538 Mdot
.79524 .32639 Mdot
.79714 .28922 Mdot
.79905 .27143 Mdot
.80095 .42782 Mdot
.80286 .41898 Mdot
.80476 .25622 Mdot
.80667 .26463 Mdot
.80857 .26733 Mdot
.81048 .25798 Mdot
.81238 .22483 Mdot
.81429 .34856 Mdot
.81619 .35586 Mdot
.8181 .2756 Mdot
.82 .30923 Mdot
.8219 .2895 Mdot
.82381 .32462 Mdot
.82571 .30493 Mdot
.82762 .27239 Mdot
.82952 .26216 Mdot
.83143 .28346 Mdot
.83333 .44522 Mdot
.83524 .28095 Mdot
.83714 .31083 Mdot
.83905 .30266 Mdot
.84095 .32124 Mdot
.84286 .28721 Mdot
.84476 .3166 Mdot
.84667 .23523 Mdot
.84857 .45702 Mdot
.85048 .36453 Mdot
.85238 .28414 Mdot
.85429 .34025 Mdot
.85619 .27614 Mdot
.8581 .38379 Mdot
.86 .40867 Mdot
.8619 .28453 Mdot
.86381 .40098 Mdot
.86571 .29662 Mdot
.86762 .26101 Mdot
.86952 .32216 Mdot
.87143 .30971 Mdot
.87333 .3197 Mdot
.87524 .24722 Mdot
.87714 .44595 Mdot
.87905 .3127 Mdot
.88095 .29963 Mdot
.88286 .24469 Mdot
.88476 .32854 Mdot
.88667 .2691 Mdot
.88857 .31226 Mdot
.89048 .43723 Mdot
.89238 .27163 Mdot
.89429 .39907 Mdot
.89619 .39522 Mdot
.8981 .2389 Mdot
.9 .41535 Mdot
.9019 .23494 Mdot
.90381 .33372 Mdot
.90571 .47306 Mdot
.90762 .3336 Mdot
.90952 .41735 Mdot
.91143 .24765 Mdot
.91333 .33919 Mdot
.91524 .232 Mdot
.91714 .27584 Mdot
.91905 .37449 Mdot
.92095 .42436 Mdot
.92286 .29924 Mdot
.92476 .35144 Mdot
.92667 .35632 Mdot
.92857 .2816 Mdot
.93048 .36085 Mdot
.93238 .38529 Mdot
.93429 .2993 Mdot
.93619 .36275 Mdot
.9381 .25717 Mdot
.94 .28362 Mdot
.9419 .33785 Mdot
.94381 .33421 Mdot
.94571 .38977 Mdot
.94762 .30019 Mdot
.94952 .32214 Mdot
.95143 .41626 Mdot
.95333 .27571 Mdot
.95524 .2411 Mdot
.95714 .35556 Mdot
.95905 .35427 Mdot
.96095 .26868 Mdot
.96286 .34916 Mdot
.96476 .27161 Mdot
.96667 .40313 Mdot
.96857 .23551 Mdot
.97048 .36091 Mdot
.97238 .34936 Mdot
.97429 .42363 Mdot
.97619 .38904 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?[ooooo0_l00010ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0<;ooooo0_l0000fooooo`;o0000@?ooool000Co00000_ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo0;;ooooo0ol0000=ooooo`;o00008_ooool2o`0005Cooooo0006ooooo`05o`000?oooooo
ooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0
002aooooo`Co00008Oooool2o`0000kooooo0_l0000cooooo`;o00007oooool000Kooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`03o`000?oooooooooo07Gooooo0_l0000jooooo`;o00008oooool2o`0000Wooooo
0_l0000:ooooo`;o00005_ooool2o`00013ooooo0_l00002ooooo`;o00003oooool2o`0000kooooo
0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool08Oooool2o`0000Cooooo0_l0000Gooooo`;o0000
1oooool2o`0002[ooooo0_l0000>ooooo`;o00006Oooool2o`0003oooooo0_l000000ooooooo0000
o`000007ooooo`;o00005_ooool2o`0000kooooo1?l0000Cooooo`;o00003_ooool000Kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo01Sooooo0_l00006ooooo`?o00001?ooool2o`0001Oo
oooo0_l00007ooooo`;o0000>_ooool2o`0001Wooooo0_l00012ooooo`;o0000;oooool2o`00017o
oooo0_l0000Booooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`0Fooooo`Co00001_ooool2o`00
03Wooooo0_l0000Eooooo`;o0000??ooool2o`0003Wooooo0_l0000Sooooo`;o00005_ooool2o`00
01;ooooo000Yooooo`;o00005oooool2o`0002Gooooo0_l0000Looooo`;o00000_ooool2o`00017o
oooo0_l00003ooooo`;o0000=oooool2o`0000gooooo0_l0000=ooooo`;o00006oooool2o`00027o
oooo1?l00008ooooo`;o00008?ooool002Wooooo00?o0000ooooooooool0;Oooool2o`000003oooo
ool0003o000000Oooooo0_l00002ooooo`;o00008?ooool2o`0001Kooooo0_l0000?ooooo`;o0000
3Oooool2o`0002Kooooo0ol00004ooooo`;o00001_ooool2o`0003kooooo0_l0000:ooooo`;o0000
8?ooool002Wooooo00?o0000ooooooooool02oooool4o`0001kooooo0_l000000ooooooo0000o`00
0007ooooo`;o0000COooool2o`0000?ooooo0_l00008ooooo`;o00001Oooool2o`0001kooooo1?l0
0004ooooo`;o00001_ooool2o`0006cooooo000Yooooo`03o`000?oooooooooo00_ooooo1?l0001[
ooooo`;o00001Oooool2o`0000[ooooo0_l0000?ooooo`;o00007_ooool2o`0002oooooo0_l00006
ooooo`Co00009oooool2o`0001Sooooo000Yooooo`03o`000?oooooooooo037ooooo0_l00017oooo
o`;o00001Oooool2o`0004;ooooo0_l0000;ooooo`Co00006Oooool2o`0000Kooooo1?l00004oooo
o`;o00002oooool2o`0001Cooooo0_l0000Hooooo`00:Oooool2o`00013ooooo0_l0000Pooooo`;o
00002_ooool2o`0002Cooooo0_l0000Gooooo`;o00001_ooool2o`0000Sooooo0_l0000Cooooo`;o
00003oooool2o`0000Sooooo0_l00005ooooo`;o00002oooool4o`0000;ooooo0_l0000Nooooo`;o
00001Oooool2o`0000_ooooo0_l0000^ooooo`00:Oooool2o`0000Sooooo0_l00006ooooo`;o0000
7Oooool2o`0000gooooo0_l00004ooooo`;o00002oooool2o`00017ooooo0_l0000Gooooo`;o0000
1_ooool4o`0000Kooooo0_l0000Cooooo`;o00003oooool2o`0000Sooooo0_l0000Hooooo`;o0000
7_ooool3o`00047ooooo000Yooooo`03o`000?oooooooooo00Oooooo0_l0000:ooooo`;o00006Ooo
ool6o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`04onk^k_lb<S;o0000
oc8b<P;o00002oooool2o`0000;ooooo0_l0000Gooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^o`000?l0003o<S8bonk^kP04ooooo`;o00004?ooool2o`00013ooooo
00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^01Wooooo0_l0000?ooooo`;o000000Wo410@ooooooooooooooooonk^
k_lb<S;o0000oc8b<_o^k^h00_ooool2o`000004oc8b<_l0003o0000onk^kQKooooo0_l0000Aoooo
o`05odA4A?l0003o0000oc8b<_oMgMd00_l000001Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool00ol0003oooooooooo`0Cooooo`;o00002?oo
ool2o`0000cooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04?ooool2o`0001Oooooo00GoV9RHob4Q8Oo^
k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01?mgMgOo0000o`000?nH
V9P2o`0001Gooooo0_l00005ooooo`;o00001_ooool3o`000005oa0@4?l0003o0000ogMgMolb<S80
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0[oooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`;o000000CoV9RH
oooooonHV9SoMgMg0oooool2o`00017ooooo1?l0000Booooo`03ogMgMolb<S;o000000;o000000Co
V9RHoooooonHV9SoMgMg0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000Yooooo`04o`00
0?ooooooooooooooo`;o00006_ooool2o`0000cooooo0_l00005ooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41005Oooool2
o`0000?ooooo0_l00007ooooo`;o00001?ooool2o`000003ob4Q8Oo^k^kooooo00?ooooo00Go410@
oooooooooooooooooa0@4003ooooo`04oa0@4?ooooooooooooooo`;o00007?ooool2o`0000Kooooo
0ol000001?oooooo0000o`000?ooool2o`0000;ooooo00Co410@oooooooooooooooo0_l00002oooo
o`05oa0@4?ooooooooooooooool@41008Oooool2o`0000Gooooo1Ol00003ooooo`05oa0@4?oooooo
ooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00;o000000?oooooo`000?l00000
1oooool2o`0000[ooooo0_l00006ooooo`;o00002Oooool3o`000003ooooool0003o000000?ooooo
00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo007ooooo000Yooooo`Ko0000
;oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000001Gooooo0_l00003ooooo`;o00001?ooool2o`000003ooooool0003o0000
00Cooooo0_l000000onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000002_ooooo00?oZJVYo`000?l000000_ooool01?l0003ooooooooo
ooooool2o`0000;ooooo0ol000000ooooooo0000ooooo`0Pooooo`;o00001Oooool01?m4A4CogMgM
o`000?l00004ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooooooool3
o`0000[ooooo0_l0000Booooo`;o00002Oooool2o`000004oc8b<_ooooooooooo`0000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo007ooooo000Yooooo`04o`000?oo
oooo0000o`0000?ooooo1?l0000Zooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000008?ooool2o`0000[ooooo00?oMgMgofIV
I_ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_l00005
ooooo`;o00008_ooool3o`000005okZj^_ooooooooooooooool000000oooool01?l0003ooooooooo
ooooool3o`000003ooooool0003ooooo01kooooo0_l00003ooooo`;o00000_ooool01?oMgMgoEEEE
o`000?l00004ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000Cooooo0ol0000Looooo`;o00000_ooool3o`000004ob4Q8Ol0003o<S8bolc<c0;ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool002Wooooo
00?o0000ooooooooool01?ooool4o`000003ooooool0003o000000Kooooo0_l0000Oooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`;o00000_ooool00ol@413o
ooooooooo`0[ooooo`05o`000?ooooooooooooooool@41000oooool01?l@413oooooooooooooool2
o`000003ooooool0003o000000Gooooo0_l0000Aooooo`;o00003oooool2o`000003okZj^_lQ8B7o
oooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100
0_ooool2o`0001[ooooo0ol00003ooooo`;o00000oooool00omgMgOoc<c<o`000004ooooo`05oa0@
4?ooooooooooooooool@41000_l000000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00;o
oooo0ol00004ooooo`;o000000?oooooo`000?l000004oooool2o`0000;ooooo0ol00006ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo000Yoooo
o`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o000000?oooooo`000?l000000oooool2o`00
01oooooo00?o0000ooooooooool00_l000001OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0_l00000
0oooooooV9RHogMgM`02ooooo`;o00008oooool3o`000004okZj^_ooooooV9RHoa0@40?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`03ooooo`;o000000?ooooooiRHV?mgMgL06?ooool2o`0000Wooooo
0_l00003ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`;o00006_ooool2o`0000Wooooo00?ok^k^
odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o000000KoMgMgoiRHV?ooooooV9RH
ogMgMoooool2o`0000Gooooo0_l000001?oooooo0000o`000?ooool2o`0001Wooooo00?o0000oooo
ooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`00:Oooool00ol0003oooooooooo`03ooooo`;o00001oooool2o`0000Cooooo0_l0000L
ooooo`05oeEEEOmVIVKo0000o`000?ooool00_l000000oo^k^ko<S8bo`000002o`0000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP02ooooo`?o00007Oooool2o`0000?ooooo0_l000001OnHV9So410@
o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00_l00005ooooo`;o00004_ooool2o`0000Kooooo0_l00003ooooo`05ojVYZOl@413o
0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP08ooooo`;o00001oooool2o`0001Oooooo00?oMgMgo`000?ooool00oooool01_o^k^ko
<S8bo`000?l0003ok^k^ooooo`;o000000Kok^k^oc8b<_l0003o<S8bonk^k_ooool2o`0000Gooooo
0_l0000Oooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`00:Oooool2o`0001?ooooo0_l0000Kooooo`;o000000?oooooo`000?l0
00001_ooool2o`0000_ooooo0_l0000Hooooo`;o00000oooool2o`0001[ooooo0_l00003ooooo`Co
00003oooool2o`000003ooooool0003o000000Sooooo0_l0000Nooooo`;o00001oooool2o`0001oo
oooo0_l00019ooooo`00:Oooool00ol0003oooooooooo`0_ooooo`;o0000<?ooool2o`0000Cooooo
0_l0000Booooo`;o00002_ooool2o`00017ooooo0_l0000;ooooo`;o0000@oooool2o`0000?ooooo
0_l0000Hooooo`;o00004?ooool2o`0000;ooooo0_l0000Iooooo`00:Oooool00ol0003ooooooooo
o`0[ooooo`;o00004Oooool2o`0002Gooooo1?l00005ooooo`;o00002oooool2o`0006oooooo0_l0
0003ooooo`;o00006?ooool2o`0000?ooooo0_l0000;ooooo`;o00000_ooool2o`0000;ooooo0_l0
000Eooooo`00:Oooool3o`0002_ooooo0_l0000;ooooo`;o00001?ooool2o`0000Kooooo0_l00004
ooooo`;o00005oooool2o`0000Oooooo0_l0000Looooo`;o00002_ooool2o`0001?ooooo0_l0000P
ooooo`;o0000;Oooool2o`0000;ooooo0_l0000<ooooo`;o00004oooool2o`0001Gooooo000Yoooo
o`?o0000>?ooool2o`0000cooooo0_l00004ooooo`;o00003?ooool2o`0000?ooooo0_l0000Coooo
o`;o00005_ooool2o`0000[ooooo0_l0000Cooooo`;o00001?ooool2o`0001[ooooo0_l0000@oooo
o`;o00006oooool2o`0000;ooooo0_l0000hooooo`008Oooooooo`0004Co00001?ooool002Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool01Oooool2o`0000;ooooo00Co0000oooooooooooooooo0_l00006ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool2o`0000Gooooo0ol00009ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool2o`0000_ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`05ooooo`;o00000_ooool00ol0003oooooooooo`07ooooo`?o
00003?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool01oooool3o`0000?ooooo0_l00007ooooo`03o`000?oooooo000000?o000000?oooooo`000?l0
00000oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02_ooool002Wooooo00?o0000ooooooooool01Oooool2o`0000kooooo0_l0000Cooooo`;o0000
1_ooool3o`000003ooooool0003o000000;ooooo00?o0000ooooooooool0=?ooool4o`0000?ooooo
0ol0000Dooooo`;o00009?ooool00ol0003oooooooooo`03ooooo`Co00002_ooool4o`0001gooooo
0_l00006ooooo`;o00004?ooool2o`0000Wooooo0_l000000ooooooo0000o`00000Kooooo`03o`00
0?oooooooooo00[ooooo000Yooooo`03o`000?oooooooooo00Gooooo0_l0000>ooooo`Co000000?o
ooooo`000?l000000_l00008ooooo`Co00002Oooool2o`000003ooooool0003o000002Cooooo0_l0
000Eooooo`;o00003_ooool2o`0000Gooooo0ol00002ooooo`?o000000?oooooo`000?l000002_oo
ool2o`0000Gooooo0_l0000Cooooo`;o00003?ooool4o`0001gooooo0_l00006ooooo`;o00003ooo
ool3o`0000Oooooo0_l0000]ooooo`00:Oooool00ol0003oooooooooo`0Gooooo`;o000000?ooooo
o`000?l000000_l00008ooooo`Co0000<Oooool3o`0000[ooooo0_l0000?ooooo`;o00002?ooool2
o`0000Gooooo0ol00003ooooo`;o000000Coooooo`000?l0003ooooo0_l00007ooooo`;o00001Ooo
ool2o`0001;ooooo0_l0000<ooooo`;o00006Oooool2o`0000Cooooo0_l0000Hooooo`;o00001ooo
ool3o`0001Oooooo0_l0000Dooooo`00:Oooool4o`0003Oooooo0_l00007ooooo`;o00006?ooool2
o`0000_ooooo0_l00004ooooo`;o00002?ooool3o`0001_ooooo0_l0000Rooooo`;o00002_ooool4
o`0001Wooooo0_l00004ooooo`;o00000oooool2o`0000Cooooo0_l00008ooooo`;o00003?ooool2
o`0001Sooooo0_l0000Dooooo`00:Oooool01?l0003oooooo`000?l0000gooooo`;o00001oooool2
o`0000[ooooo0_l0000Oooooo`;o00002?ooool2o`00033ooooo0_l000000ooooooo0000o`00000G
ooooo`;o00009_ooool2o`0000Cooooo0_l00008ooooo`;o00004Oooool2o`0002Wooooo000Yoooo
o`03o`000?oooooooooo01Cooooo0_l00004ooooo`;o0000<Oooool2o`0002kooooo0_l0000Eoooo
o`;o00000oooool2o`0000gooooo1?l000000ooooooo0000o`00000;ooooo`;o0000<oooool2o`00
023ooooo0_l00005ooooo`;o00008_ooool002Wooooo00?o0000ooooooooool05?ooool2o`0000Co
oooo0_l00007ooooo`;o00006Oooool2o`0001Sooooo0_l0000:ooooo`;o00001_ooool2o`0000So
oooo0_l00005ooooo`;o00005Oooool2o`0000?ooooo0_l0000=ooooo`;o00004?ooool2o`0001Go
oooo0_l0000;ooooo`;o00003oooool2o`0002Kooooo0ol0000:ooooo`;o00005_ooool002Wooooo
00?o0000ooooooooool07Oooool2o`0000Cooooo0_l0000?ooooo`;o00002?ooool2o`0000Wooooo
0_l0000=ooooo`;o00002_ooool2o`0000Kooooo0_l00008ooooo`;o00006_ooool2o`0000Wooooo
0_l00002ooooo`;o00008?ooool2o`0000cooooo0_l0000;ooooo`;o0000=oooool2o`000003oooo
ool0003o000000Oooooo0ol0000Fooooo`00:Oooool2o`0000gooooo0_l0000;ooooo`;o00000_oo
ool2o`0000Sooooo0_l0000;ooooo`;o00001_ooool2o`0000;ooooo0_l00007ooooo`;o0000AOoo
ool4o`0000Wooooo0_l00002ooooo`;o00005_ooool2o`0000Sooooo0_l0000^ooooo`;o00004_oo
ool2o`00017ooooo0_l00007ooooo`;o00005oooool002Wooooo00?o0000ooooooooool03?ooool2
o`0000_ooooo0_l00007ooooo`;o000000?oooooo`000?l000000_l0000Cooooo`;o00000_ooool2
o`0000oooooo0_l00005ooooo`;o00000_ooool2o`00027ooooo0_l0000?ooooo`?o00009Oooool3
o`0003Sooooo0_l0000Booooo`;o0000<oooool002Wooooo00?o0000ooooooooool00_ooool2o`00
01kooooo0_l000000ooooooo0000o`000002ooooo`;o00009_ooool2o`0000Gooooo0_l00002oooo
o`;o00008Oooool2o`0002Sooooo0_l0000=ooooo`;o00003oooool2o`00013ooooo0_l0000Moooo
o`;o0000;_ooool2o`00013ooooo000Yooooo`03o`000?oooooooooo00;ooooo0_l0000Uooooo`;o
00002oooool2o`0001?ooooo0_l0000Dooooo`;o00001oooool2o`00027ooooo0_l00006ooooo`;o
00003_ooool2o`0000;ooooo0_l00004ooooo`;o00006?ooool2o`00013ooooo0_l0000Cooooo`;o
00002?ooool2o`0002;ooooo0_l0000:ooooo`;o000000?oooooo`000?l000003Oooool002Wooooo
00?o0000ooooooooool02?ooool2o`0002cooooo0_l0000@ooooo`;o000000?oooooo`000?l00000
5?ooool2o`0000Oooooo0_l0000Qooooo`;o00001_ooool2o`0000kooooo0_l00008ooooo`;o0000
3?ooool2o`0001Gooooo0_l0000>ooooo`;o00002_ooool2o`0002cooooo0_l00009ooooo`;o0000
0_ooool2o`0000gooooo000Yooooo`;o00002Oooool2o`0000?ooooo0_l0000dooooo`;o00000ooo
ool2o`0000[ooooo0_l0001Vooooo`?o00001Oooool2o`0000kooooo0_l0000<ooooo`Co00001_oo
ool2o`0000gooooo0_l0000Rooooo`;o00001oooool3o`00017ooooo000Yooooo`03o`000?oooooo
oooo00gooooo0_l0000Aooooo`;o00008Oooool2o`0000oooooo0_l0000Iooooo`;o00007_ooool2
o`0002_ooooo0_l00006ooooo`;o00005_ooool2o`0000Cooooo0_l00008ooooo`;o00003Oooool2
o`0002;ooooo0ol00006ooooo`;o00000oooool2o`0000gooooo000Yooooo`03o`000?oooooooooo
00Oooooo0_l0000Gooooo`;o00002_ooool2o`0000cooooo0_l0000Iooooo`;o00006?ooool2o`00
00kooooo0_l0000>ooooo`;o0000Boooool2o`0001Cooooo0_l0000Booooo`;o00006?ooool4o`00
00Wooooo0_l0000=ooooo`00:Oooool00ol0003oooooooooo`07ooooo`;o00003oooool2o`0000Co
oooo0_l00002ooooo`;o00002?ooool2o`0000cooooo0_l00008ooooo`;o00002?ooool2o`0000Go
oooo0_l0000;ooooo`;o00006?ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`00
0?l00000>_ooool2o`0000[ooooo0_l0000:ooooo`;o00003?ooool2o`0000Wooooo0_l0000Boooo
o`;o00006_ooool2o`0001Sooooo000Yooooo`03o`000?oooooooooo01Sooooo0_l00004ooooo`;o
00000_ooool2o`00023ooooo0_l00008ooooo`;o00004_ooool2o`0000Sooooo0_l0000>ooooo`;o
00001?ooool2o`000003ooooool0003o000003[ooooo0_l0000:ooooo`;o00002_ooool2o`0000co
oooo0_l0001Cooooo`00:Oooool2o`0003Cooooo0_l0000gooooo`;o00009oooool2o`0005Cooooo
0_l0001?ooooo`00:Oooool00ol0003oooooooooo`02o`0001[ooooo0_l0000Eooooo`;o0000H?oo
ool2o`0000Wooooo0_l00002ooooo`;o00009?ooool2o`0001oooooo0_l0000_ooooo`;o00007_oo
ool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00Co00004oooool2o`0000?ooooo
0_l0000Mooooo`;o00007?ooool2o`0004Gooooo0_l00002ooooo`;o00009?ooool2o`0001Wooooo
0_l0000eooooo`;o00007_ooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`02ooooo`;o00004oooool2o`0002;ooooo0_l00004ooooo`;o00005_ooool2o`0007;o
oooo0_l000000ooooooo0000o`00000Cooooo`;o0000EOooool000Kooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`11ooooo`;o0000F?ooool2o`00033ooooo0_l000000ooooooo0000o`00000gooooo`;o
00005Oooool2o`0001[ooooo0006ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So
8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000@ooooo`;o0000?Oooool2o`0000oo
oooo0_l0000?ooooo`;o00007oooool2o`0000Oooooo0_l00005ooooo`;o00004Oooool2o`0005;o
oooo0_l0000Eooooo`;o00003Oooool2o`0000_ooooo0006ooooo`05o`000?ooooooooooooooool0
00003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0
003oooooooooo`0@ooooo`Co00006Oooool2o`0001kooooo1?l0000?ooooo`;o00003oooool2o`00
01oooooo0_l0000>ooooo`;o00004Oooool4o`0006cooooo0_l00008ooooo`;o00002oooool000Ko
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0:ooooo`;o00001_ooool2o`000003ooooool0003o0000
01Kooooo0_l0000Nooooo`;o00008Oooool2o`0004Gooooo0_l0000^ooooo`;o0000;?ooool2o`00
00kooooo0_l0000Eooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool2
o`0000Wooooo0_l0000Gooooo`;o00007_ooool2o`00023ooooo0_l00016ooooo`;o0000;?ooool4
o`0002_ooooo0_l0000Uooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`0:ooooo`;o00000ooo
ool2o`0001gooooo0_l0000Nooooo`Co0000=oooool2o`0000Wooooo0_l0000Rooooo`;o00007Ooo
ool2o`0000?ooooo0_l00008ooooo`Co00008?ooool2o`0000Sooooo0_l0000Vooooo`00:Oooool2
o`0000_ooooo0_l00003ooooo`;o0000?oooool2o`000003ooooool0003o000003Cooooo0_l00009
ooooo`;o00003?ooool2o`00027ooooo0_l00005ooooo`;o00001Oooool6o`0000?ooooo0_l0000/
ooooo`;o00002?ooool2o`0001Gooooo0_l0000?ooooo`00:Oooool2o`0005Cooooo0_l00008oooo
o`;o00009Oooool2o`0001cooooo0_l0000:ooooo`;o00005Oooool2o`0000Gooooo0_l00005oooo
o`Co0000E?ooool2o`0000oooooo000Yooooo`03o`000?oooooooooo05gooooo0_l0000Kooooo`;o
00002?ooool2o`0001gooooo0_l00009ooooo`;o0000FOooool2o`00037ooooo000Yooooo`03o`00
0?oooooooooo05?ooooo0_l0000Qooooo`;o00000_ooool2o`0001_ooooo0_l0000:ooooo`;o0000
1Oooool2o`0003?ooooo0_l0000Xooooo`;o0000<Oooool002Wooooo00?o0000ooooooooool01?oo
ool2o`0000kooooo0_l0000=ooooo`Co00000oooool2o`0001Kooooo0_l00004ooooo`;o00002Ooo
ool2o`00027ooooo0_l0000Dooooo`;o00002Oooool2o`00017ooooo0_l0000Zooooo`;o000000?o
ooooo`000?l000001?ooool2o`0003Gooooo0_l000000ooooooo0000o`00000<ooooo`;o00004ooo
ool002Wooooo0_l00005ooooo`;o00002?ooool2o`0000Cooooo0_l0000=ooooo`Co00000oooool2
o`0001Kooooo0_l00004ooooo`Co00006_ooool2o`0000?ooooo0_l0000Mooooo`Co0000>_ooool2
o`0000cooooo0_l000001?oooooo0000o`000?l0000Kooooo`;o00007Oooool2o`000003ooooool0
003o000000cooooo0_l0000Cooooo`00:Oooool00ol0003oooooooooo`05ooooo`;o00001oooool2
o`0000_ooooo0_l0000Nooooo`;o00002?ooool2o`0000?ooooo0_l0000Jooooo`;o00000oooool2
o`0001gooooo0_l0000looooo`;o00004?ooool2o`0001_ooooo0_l0000eooooo`;o00003?ooool0
02Wooooo00?o0000ooooooooool01Oooool2o`0000;ooooo0_l0000@ooooo`;o00000_ooool2o`00
01[ooooo0_l00008ooooo`;o00002_ooool2o`0000?ooooo0_l0000Jooooo`;o0000@Oooool2o`00
01cooooo0_l00018ooooo`;o00003oooool2o`0000cooooo000Yooooo`03o`000?oooooooooo00Wo
oooo0_l0000Dooooo`;o0000<?ooool2o`0000?ooooo0_l0000Jooooo`;o00000oooool2o`0003?o
oooo0_l00007ooooo`;o00007?ooool2o`00027ooooo0_l0000Uooooo`;o00007Oooool002Wooooo
00?o0000ooooooooool0G_ooool2o`0001Oooooo0_l0000cooooo`;o00001?ooool2o`0004;ooooo
0_l00014ooooo`00:Oooool2o`00023ooooo0_l0000mooooo`;o0000D_ooool2o`0008Sooooo000Y
ooooo`04o`000?ooooooooooooooo`;o00007?ooool2o`0002Cooooo0_l0002Hooooo`;o0000<_oo
ool2o`0002Oooooo000Yooooo`04o`000?ooooooooooooooo`;o00008Oooool2o`0001oooooo0_l0
000@ooooo`;o0000@oooool2o`0002Gooooo0_l0000<ooooo`;o00003?ooool2o`0003;ooooo0_l0
000Wooooo`00:Oooool00ol0003oooooooooo`0Tooooo`;o0000;?ooool2o`0000?ooooo0_l0000:
ooooo`;o00001?ooool2o`0000Wooooo0_l0000Vooooo`;o00008_ooool2o`000003ooooool0003o
000000cooooo0_l0000^ooooo`;o0000>Oooool002Wooooo00?o0000ooooooooool04?ooool2o`00
01kooooo0_l0000Pooooo`;o00000_ooool2o`0000_ooooo0_l00004ooooo`;o00002Oooool2o`00
04[ooooo0_l0000oooooo`;o00003?ooool2o`0002_ooooo000Yooooo`;o00004Oooool2o`0001ko
oooo0_l0000Tooooo`;o0000]oooool2o`0002_ooooo000Yooooo`03o`000?oooooooooo0=_ooooo
0_l0001Oooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3Kooooo`;o0000:?ooool2o`0003Go
oooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`0eooooo`;o0000c_ooool2o`0003Gooooo000>ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`?o0000=Oooool2o`000?oo
oooo1_ooool000kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000co
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo03Oooooo0_l0000`oooo
o`;o0000AOooool2o`0000Cooooo0_l00024ooooo`003_ooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0gooooo`;o00004_ooool2o`00
01cooooo0_l00004ooooo`;o0000?oooool2o`0000Cooooo0_l0001Pooooo`;o00008_ooool000ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0Boooool2o`0002;ooooo0_l0002Wooooo`;o00008_ooool000kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`00
0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`00
0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo
00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooooooo
ool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03
oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgo
oooo0006ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03
o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`000?ooooooooooooooool0
00003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?oo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolmoooo
o`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`007oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0
oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo?Ooo
ool0027ooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`007oooool0
0omEEEGoIVIVo`00003oooooodOooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .25593 Mdot
.02762 .36342 Mdot
.02952 .3089 Mdot
.03143 .27218 Mdot
.03333 .25701 Mdot
.03524 .3915 Mdot
.03714 .31277 Mdot
.03905 .44961 Mdot
.04095 .27711 Mdot
.04286 .31583 Mdot
.04476 .34232 Mdot
.04667 .45008 Mdot
.04857 .37058 Mdot
.05048 .35096 Mdot
.05238 .44772 Mdot
.05429 .33585 Mdot
.05619 .37735 Mdot
.0581 .36138 Mdot
.06 .34882 Mdot
.0619 .4119 Mdot
.06381 .37179 Mdot
.06571 .40083 Mdot
.06762 .40399 Mdot
.06952 .34843 Mdot
.07143 .42098 Mdot
.07333 .35362 Mdot
.07524 .31066 Mdot
.07714 .33036 Mdot
.07905 .42103 Mdot
.08095 .36065 Mdot
.08286 .35712 Mdot
.08476 .29239 Mdot
.08667 .42418 Mdot
.08857 .35738 Mdot
.09048 .24405 Mdot
.09238 .31323 Mdot
.09429 .36915 Mdot
.09619 .26631 Mdot
.0981 .42181 Mdot
.1 .44591 Mdot
.1019 .40881 Mdot
.10381 .29372 Mdot
.10571 .32 Mdot
.10762 .23944 Mdot
.10952 .28578 Mdot
.11143 .33107 Mdot
.11333 .34452 Mdot
.11524 .23346 Mdot
.11714 .24925 Mdot
.11905 .40771 Mdot
.12095 .2294 Mdot
.12286 .42402 Mdot
.12476 .39161 Mdot
.12667 .25586 Mdot
.12857 .29199 Mdot
.13048 .36167 Mdot
.13238 .44955 Mdot
.13429 .37877 Mdot
.13619 .26496 Mdot
.1381 .30896 Mdot
.14 .3421 Mdot
.1419 .23397 Mdot
.14381 .42079 Mdot
.14571 .31148 Mdot
.14762 .40005 Mdot
.14952 .33745 Mdot
.15143 .29694 Mdot
.15333 .34289 Mdot
.15524 .28406 Mdot
.15714 .3273 Mdot
.15905 .37322 Mdot
.16095 .31348 Mdot
.16286 .31269 Mdot
.16476 .25827 Mdot
.16667 .42063 Mdot
.16857 .27356 Mdot
.17048 .39134 Mdot
.17238 .35845 Mdot
.17429 .42752 Mdot
.17619 .28606 Mdot
.1781 .24712 Mdot
.18 .34809 Mdot
.1819 .25983 Mdot
.18381 .27436 Mdot
.18571 .42988 Mdot
.18762 .31535 Mdot
.18952 .25117 Mdot
.19143 .25157 Mdot
.19333 .37462 Mdot
.19524 .34289 Mdot
.19714 .41995 Mdot
.19905 .47203 Mdot
.20095 .33414 Mdot
.20286 .28821 Mdot
.20476 .33735 Mdot
.20667 .46795 Mdot
.20857 .3514 Mdot
.21048 .22889 Mdot
.21238 .37395 Mdot
.21429 .37984 Mdot
.21619 .23994 Mdot
.2181 .35942 Mdot
.22 .44942 Mdot
.2219 .25156 Mdot
.22381 .26392 Mdot
.22571 .3437 Mdot
.22762 .36638 Mdot
.22952 .35947 Mdot
.23143 .33308 Mdot
.23333 .3291 Mdot
.23524 .34608 Mdot
.23714 .27242 Mdot
.23905 .28034 Mdot
.24095 .36322 Mdot
.24286 .23379 Mdot
.24476 .31179 Mdot
.24667 .3539 Mdot
.24857 .38451 Mdot
.25048 .35192 Mdot
.25238 .39101 Mdot
.25429 .37515 Mdot
.25619 .22516 Mdot
.2581 .40207 Mdot
.26 .42504 Mdot
.2619 .32467 Mdot
.26381 .29246 Mdot
.26571 .37711 Mdot
.26762 .44988 Mdot
.26952 .26373 Mdot
.27143 .26431 Mdot
.27333 .40682 Mdot
.27524 .24374 Mdot
.27714 .44548 Mdot
.27905 .39381 Mdot
.28095 .35643 Mdot
.28286 .42884 Mdot
.28476 .36968 Mdot
.28667 .40543 Mdot
.28857 .30453 Mdot
.29048 .43366 Mdot
.29238 .44784 Mdot
.29429 .30351 Mdot
.29619 .27237 Mdot
.2981 .32144 Mdot
.3 .37799 Mdot
.3019 .39398 Mdot
.30381 .41492 Mdot
.30571 .34251 Mdot
.30762 .35543 Mdot
.30952 .26543 Mdot
.31143 .22993 Mdot
.31333 .35223 Mdot
.31524 .25304 Mdot
.31714 .33871 Mdot
.31905 .30149 Mdot
.32095 .38877 Mdot
.32286 .39976 Mdot
.32476 .4261 Mdot
.32667 .37468 Mdot
.32857 .37391 Mdot
.33048 .39365 Mdot
.33238 .29674 Mdot
.33429 .42726 Mdot
.33619 .39683 Mdot
.3381 .25437 Mdot
.34 .29554 Mdot
.3419 .25429 Mdot
.34381 .40678 Mdot
.34571 .23957 Mdot
.34762 .27083 Mdot
.34952 .39074 Mdot
.35143 .3761 Mdot
.35333 .33439 Mdot
.35524 .25342 Mdot
.35714 .25776 Mdot
.35905 .35782 Mdot
.36095 .41848 Mdot
.36286 .46272 Mdot
.36476 .39061 Mdot
.36667 .32577 Mdot
.36857 .42024 Mdot
.37048 .4083 Mdot
.37238 .43669 Mdot
.37429 .26487 Mdot
.37619 .39972 Mdot
.3781 .32219 Mdot
.38 .254 Mdot
.3819 .44337 Mdot
.38381 .30254 Mdot
.38571 .40738 Mdot
.38762 .34727 Mdot
.38952 .2528 Mdot
.39143 .3954 Mdot
.39333 .26561 Mdot
.39524 .22323 Mdot
.39714 .44059 Mdot
.39905 .34841 Mdot
.40095 .44898 Mdot
.40286 .26612 Mdot
.40476 .47374 Mdot
.40667 .32444 Mdot
.40857 .31161 Mdot
.41048 .31722 Mdot
.41238 .32053 Mdot
.41429 .27861 Mdot
.41619 .46807 Mdot
.4181 .23894 Mdot
.42 .31166 Mdot
.4219 .3929 Mdot
.42381 .27855 Mdot
.42571 .32813 Mdot
.42762 .3324 Mdot
.42952 .40156 Mdot
.43143 .35545 Mdot
.43333 .239 Mdot
.43524 .30043 Mdot
.43714 .24912 Mdot
.43905 .34009 Mdot
.44095 .39538 Mdot
.44286 .3305 Mdot
.44476 .34968 Mdot
.44667 .44968 Mdot
.44857 .35105 Mdot
.45048 .27031 Mdot
.45238 .24741 Mdot
.45429 .2355 Mdot
.45619 .33392 Mdot
.4581 .31565 Mdot
.46 .35642 Mdot
.4619 .33445 Mdot
.46381 .44784 Mdot
.46571 .22352 Mdot
.46762 .34366 Mdot
.46952 .27183 Mdot
.47143 .46886 Mdot
.47333 .2793 Mdot
.47524 .30228 Mdot
.47714 .23881 Mdot
.47905 .25653 Mdot
.48095 .27148 Mdot
.48286 .39944 Mdot
.48476 .2399 Mdot
.48667 .2312 Mdot
.48857 .38221 Mdot
.49048 .24336 Mdot
.49238 .37374 Mdot
.49429 .3134 Mdot
.49619 .32971 Mdot
.4981 .41329 Mdot
.5 .3337 Mdot
.5019 .37521 Mdot
.50381 .42344 Mdot
.50571 .36368 Mdot
.50762 .31612 Mdot
.50952 .262 Mdot
.51143 .40564 Mdot
.51333 .35687 Mdot
.51524 .25675 Mdot
.51714 .33616 Mdot
.51905 .27789 Mdot
.52095 .44395 Mdot
.52286 .23075 Mdot
.52476 .26338 Mdot
.52667 .30283 Mdot
.52857 .23526 Mdot
.53048 .27894 Mdot
.53238 .33718 Mdot
.53429 .29533 Mdot
.53619 .34689 Mdot
.5381 .36855 Mdot
.54 .34119 Mdot
.5419 .33836 Mdot
.54381 .3479 Mdot
.54571 .31518 Mdot
.54762 .32102 Mdot
.54952 .24873 Mdot
.55143 .40034 Mdot
.55333 .25665 Mdot
.55524 .33894 Mdot
.55714 .2342 Mdot
.55905 .33358 Mdot
.56095 .39037 Mdot
.56286 .42605 Mdot
.56476 .2861 Mdot
.56667 .26763 Mdot
.56857 .37737 Mdot
.57048 .44909 Mdot
.57238 .35964 Mdot
.57429 .26924 Mdot
.57619 .34135 Mdot
.5781 .33971 Mdot
.58 .29101 Mdot
.5819 .27198 Mdot
.58381 .44083 Mdot
.58571 .2919 Mdot
.58762 .44647 Mdot
.58952 .30224 Mdot
.59143 .31709 Mdot
.59333 .29199 Mdot
.59524 .23906 Mdot
.59714 .30605 Mdot
.59905 .44736 Mdot
.60095 .39166 Mdot
.60286 .25406 Mdot
.60476 .37071 Mdot
.60667 .25428 Mdot
.60857 .30602 Mdot
.61048 .42139 Mdot
.61238 .34989 Mdot
.61429 .23022 Mdot
.61619 .34782 Mdot
.6181 .27269 Mdot
.62 .40519 Mdot
.6219 .37926 Mdot
.62381 .38685 Mdot
.62571 .24489 Mdot
.62762 .30429 Mdot
.62952 .33392 Mdot
.63143 .33083 Mdot
.63333 .41317 Mdot
.63524 .26759 Mdot
.63714 .43519 Mdot
.63905 .32223 Mdot
.64095 .3651 Mdot
.64286 .33133 Mdot
.64476 .39344 Mdot
.64667 .26236 Mdot
.64857 .42546 Mdot
.65048 .29789 Mdot
.65238 .30973 Mdot
.65429 .31949 Mdot
.65619 .3742 Mdot
.6581 .45188 Mdot
.66 .41212 Mdot
.6619 .33759 Mdot
.66381 .40925 Mdot
.66571 .26993 Mdot
.66762 .32085 Mdot
.66952 .36034 Mdot
.67143 .39014 Mdot
.67333 .29836 Mdot
.67524 .29865 Mdot
.67714 .29512 Mdot
.67905 .41254 Mdot
.68095 .35443 Mdot
.68286 .31534 Mdot
.68476 .30681 Mdot
.68667 .39777 Mdot
.68857 .32391 Mdot
.69048 .39739 Mdot
.69238 .36622 Mdot
.69429 .30261 Mdot
.69619 .29786 Mdot
.6981 .30274 Mdot
.7 .45053 Mdot
.7019 .28568 Mdot
.70381 .33233 Mdot
.70571 .26187 Mdot
.70762 .34289 Mdot
.70952 .37243 Mdot
.71143 .31179 Mdot
.71333 .45054 Mdot
.71524 .38966 Mdot
.71714 .25007 Mdot
.71905 .44666 Mdot
.72095 .43235 Mdot
.72286 .39151 Mdot
.72476 .32082 Mdot
.72667 .25825 Mdot
.72857 .44762 Mdot
.73048 .44687 Mdot
.73238 .3162 Mdot
.73429 .29982 Mdot
.73619 .36037 Mdot
.7381 .39266 Mdot
.74 .24381 Mdot
.7419 .23105 Mdot
.74381 .26635 Mdot
.74571 .33908 Mdot
.74762 .4231 Mdot
.74952 .40076 Mdot
.75143 .30671 Mdot
.75333 .40402 Mdot
.75524 .43318 Mdot
.75714 .2763 Mdot
.75905 .375 Mdot
.76095 .38179 Mdot
.76286 .28011 Mdot
.76476 .35828 Mdot
.76667 .37394 Mdot
.76857 .31927 Mdot
.77048 .431 Mdot
.77238 .32245 Mdot
.77429 .30895 Mdot
.77619 .26684 Mdot
.7781 .36844 Mdot
.78 .2868 Mdot
.7819 .24463 Mdot
.78381 .23384 Mdot
.78571 .2257 Mdot
.78762 .43382 Mdot
.78952 .37106 Mdot
.79143 .43453 Mdot
.79333 .35785 Mdot
.79524 .35832 Mdot
.79714 .34807 Mdot
.79905 .29846 Mdot
.80095 .4513 Mdot
.80286 .45025 Mdot
.80476 .31436 Mdot
.80667 .31755 Mdot
.80857 .2689 Mdot
.81048 .29003 Mdot
.81238 .29492 Mdot
.81429 .28388 Mdot
.81619 .25921 Mdot
.8181 .26866 Mdot
.82 .25343 Mdot
.8219 .26589 Mdot
.82381 .25571 Mdot
.82571 .36635 Mdot
.82762 .26449 Mdot
.82952 .29971 Mdot
.83143 .22746 Mdot
.83333 .4333 Mdot
.83524 .28491 Mdot
.83714 .24272 Mdot
.83905 .36656 Mdot
.84095 .38083 Mdot
.84286 .35212 Mdot
.84476 .25583 Mdot
.84667 .34472 Mdot
.84857 .47597 Mdot
.85048 .27965 Mdot
.85238 .22165 Mdot
.85429 .25066 Mdot
.85619 .27125 Mdot
.8581 .28587 Mdot
.86 .44686 Mdot
.8619 .34041 Mdot
.86381 .36145 Mdot
.86571 .40759 Mdot
.86762 .31057 Mdot
.86952 .28195 Mdot
.87143 .35476 Mdot
.87333 .23549 Mdot
.87524 .30497 Mdot
.87714 .47589 Mdot
.87905 .33167 Mdot
.88095 .24298 Mdot
.88286 .2914 Mdot
.88476 .3337 Mdot
.88667 .31376 Mdot
.88857 .25735 Mdot
.89048 .44931 Mdot
.89238 .279 Mdot
.89429 .42834 Mdot
.89619 .33965 Mdot
.8981 .30551 Mdot
.9 .36392 Mdot
.9019 .3035 Mdot
.90381 .37675 Mdot
.90571 .45622 Mdot
.90762 .27587 Mdot
.90952 .45166 Mdot
.91143 .36087 Mdot
.91333 .34581 Mdot
.91524 .28775 Mdot
.91714 .34602 Mdot
.91905 .36519 Mdot
.92095 .39644 Mdot
.92286 .23867 Mdot
.92476 .35289 Mdot
.92667 .30325 Mdot
.92857 .35529 Mdot
.93048 .24504 Mdot
.93238 .34248 Mdot
.93429 .27321 Mdot
.93619 .28945 Mdot
.9381 .273 Mdot
.94 .32112 Mdot
.9419 .33352 Mdot
.94381 .25292 Mdot
.94571 .35737 Mdot
.94762 .3275 Mdot
.94952 .36566 Mdot
.95143 .34057 Mdot
.95333 .25827 Mdot
.95524 .31861 Mdot
.95714 .31665 Mdot
.95905 .31718 Mdot
.96095 .289 Mdot
.96286 .22801 Mdot
.96476 .28316 Mdot
.96667 .36183 Mdot
.96857 .27999 Mdot
.97048 .26525 Mdot
.97238 .2985 Mdot
.97429 .41249 Mdot
.97619 .44379 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo2?ooool2o`0003?ooooo0006ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`1dooooo`;o00005?ooool2o`0007_ooooo0_l0000cooooo`001_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo04Oooooo0_l0000[ooooo`;o00005?oo
ool2o`0006Gooooo0_l0000=ooooo`;o0000>_ooool000Co00000_ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo01cooooo0_l0000Jooooo`;o00003Oooool2o`00013ooooo0_l00012ooooo`;o00006ooo
ool2o`0002Oooooo0_l0000<ooooo`;o00003Oooool2o`0002Sooooo0_l0000@ooooo`001_ooool0
1Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8boooo
o`04ooooo`?o00006_ooool4o`0000Cooooo0_l0000Dooooo`;o00002Oooool2o`0001Cooooo0_l0
000fooooo`;o00002_ooool2o`0001_ooooo0_l0000Wooooo`;o00003?ooool2o`0003Oooooo0_l0
000@ooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool06_ooool2o`0000Kooooo
0_l0000Oooooo`;o0000@_ooool2o`0000Sooooo0_l0000<ooooo`;o00001oooool2o`0004Oooooo
0_l0000Jooooo`;o0000;Oooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Gooooo`;o0000
8Oooool2o`0002Sooooo0_l0000Eooooo`;o00000oooool2o`0000Gooooo0_l00005ooooo`Co0000
3Oooool2o`0000Oooooo0_l0000:ooooo`;o0000Eoooool2o`0000kooooo0_l0000Mooooo`001_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool05oooool2o`00027ooooo0_l0000Xooooo`;o
00005Oooool2o`0000?ooooo0_l0000<ooooo`Ko00008?ooool2o`0004cooooo0_l0000<ooooo`;o
00002oooool2o`0001gooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So
410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo01;ooooo0_l0000ioooo
o`;o0000@oooool2o`0002[ooooo0_l0000Sooooo`;o00002oooool2o`00013ooooo0_l0000<oooo
o`;o00003_ooool2o`0001[ooooo000Yooooo`;o00004oooool2o`0000Kooooo0_l0000Booooo`;o
00007Oooool2o`0003;ooooo0_l00003ooooo`;o00007Oooool2o`0001Oooooo0_l0000Sooooo`;o
00002oooool2o`0002kooooo0_l0000Jooooo`00:Oooool00ol0003oooooooooo`0Jooooo`;o0000
4_ooool2o`0000;ooooo0_l00008ooooo`;o0000=?ooool2o`0000gooooo0_l00003ooooo`;o0000
7Oooool2o`0003Cooooo0_l0000Zooooo`;o0000<oooool002Wooooo0_l0000Nooooo`;o00004ooo
ool2o`0000Sooooo0_l0000Looooo`;o00001Oooool4o`0000;ooooo0_l00006ooooo`;o000000?o
ooooo`000?l00000@_ooool4o`00027ooooo0_l0000Oooooo`Co00001?ooool2o`000003ooooool0
003o000001_ooooo0_l0000Fooooo`00:Oooool4o`0001cooooo0_l0000;ooooo`;o0000;_ooool2
o`0000Gooooo1?l00002ooooo`;o00001_ooool2o`0001kooooo0_l00009ooooo`;o00002oooool2
o`0000gooooo1?l0000Tooooo`;o00007?ooool4o`0000Cooooo0_l0000<ooooo`;o00004?ooool2
o`000003ooooool0003o000001?ooooo000Yooooo`04o`000?oooooo0000o`0002Wooooo0_l00003
ooooo`;o0000=_ooool2o`0002Kooooo0_l00007ooooo`Co00002oooool2o`0002oooooo0_l00004
ooooo`;o00006oooool2o`0001Gooooo0_l0000Cooooo`;o00004oooool002Wooooo0_l0000Qoooo
o`;o00003Oooool2o`0000cooooo0_l0000<ooooo`?o00007oooool2o`0002Wooooo0_l00003oooo
o`;o00009_ooool2o`00017ooooo0_l0000Qooooo`;o00000_ooool2o`0002cooooo0_l0000=oooo
o`00:Oooool00ol0003oooooooooo`0Dooooo`;o00002_ooool2o`0001_ooooo0_l0000<ooooo`?o
00002_ooool2o`0001?ooooo0_l00004ooooo`;o000000?oooooo`000?l000009Oooool2o`0000co
oooo0_l0000Dooooo`;o00000_ooool2o`0001gooooo0_l00008ooooo`;o00003Oooool4o`0002co
oooo0_l0000=ooooo`00:Oooool00ol0003oooooooooo`0Dooooo`;o00006_ooool4o`000008oa0@
4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h05?oo
ool2o`0000[ooooo0_l00007ooooo`Go000000Coooooo`000?l0003ok^k^0_l000000olb<S;ok^k^
ooooo`02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool2o`0000Sooooo0_l0000Iooooo`03
oiRHV?l0003o000000;o00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP02ooooo`;o00002?ooool2o`0001Oooooo0_l00003ooooo`;o000000?o410@
ooooooooool00_l000001?lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000o`000?o^k^h0
0ol00009ooooo`;o00006oooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool002Wooooo00Co0000oooo
ool0003o0000:_ooool2o`0000?ooooo0ol00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool01OmgMgOoV9RHo`000?l0003oMgMg013ooooo0_l0000>ooooo`;o00001oooool01OnHV9So8B4Q
onk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool2o`0000Gooooo0_l000000ooooooo0000o`00000Iooooo`03oa0@4?nj^[[o
oooo00;o000000Soooooo`000?l0003oMgMgoiRHV?ooooooV9RHogMgM`?ooooo00GoMgMgo`000?l0
003oV9RHogMgM`0<ooooo`;o00007Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool01OmgMgOoV9RHo`000?l0003oMgMg00;o00002_ooool2o`0001Oooooo0ol0
0004ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`00:Oooool01Ol0003oooooo`000?l0003ooooo00;o00009oooool2
o`0000?ooooo0ol00004ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413oooooo`00
0?l0003o410@013ooooo0_l0000Hooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002_ooool2o`00023ooooo00Go0000oooo
ool0003o0000oa0@4003ooooo`05oa0@4?ooooooooooooooool@41000_l000000ooooooo410@oooo
o`0Wooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@400Looooo`;o00001oooool3o`0000Gooooo00Co0000oooooooooooo410@0oooool01Ol@
413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool00Oooool002Wooooo0_l00003oooo
o`;o0000;_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooo`000002o`0002_ooooo00?oV9RHob4Q8Oo^k^h00oooool01?l0003ooooooooooooo
ool3o`000003ooooool0003o000000;ooooo00?o0000ooooooooool02Oooool2o`0000gooooo0_l0
00000ooooooo0000o`00000<ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool00000:?ooool00om4A4Co0000o`000002o`0000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002_ooool2
o`0000cooooo0_l00002ooooo`;o00003_ooool01?mgMgOo<S8booooooooool2o`0000;ooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo007ooooo000Yooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooool000000_l0000/ooooo`03ogMgMomVIVKooooo00;ooooo00Co0000oooooooooooo
oooo0ol000000ooooooo0000o`000002ooooo`03o`000?oooooooooo00Wooooo0_l0000=ooooo`;o
000000?oooooo`000?l000002oooool00ol@413o0000okZj^P03ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000002Sooooo00?ogMgMoeEEEOooool00_l00003
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02o`0000[ooooo0_l0
0004ooooo`;o00001_ooool2o`0000oooooo00Ko0000ob4Q8Ol0003o<S8bolc<c?ooool3o`0000;o
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo007ooooo000Yooooo`03
o`000?oooooooooo01Sooooo0_l0000=ooooo`;o00001?ooool2o`0000?ooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@400]
ooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo
00?o410@ooooooooool09_ooool2o`000003oooooonj^[[o8B4Q00?ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41005oooool2o`00013ooooo00?oMgMgolc<
c?l000001?ooool2o`0000;ooooo00Go410@oooooooooooooooooa0@4002ooooo`;o00001Oooool2
o`0000Kooooo0_l000000ooooooo0000o`00000Gooooo`03o`000?oooooooooo00?ooooo0_l00003
ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`01ooooo`00:Oooool0
0ol0003oooooooooo`0Hooooo`;o00003Oooool2o`0000Cooooo0_l00003ooooo`04o`000?oooooo
ooooooooo`;o000000CoV9RHoooooonHV9SoMgMg0oooool01OmgMgOoV9RHoooooonHV9SoMgMg02Wo
oooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg02Sooooo0_l000000ooooooo^[Zjo`000003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01Oooooo0_l0000@ooooo`03
onk^k_m4A4Co000000Cooooo0_l000000oooooooV9RHogMgM`03ooooo`05ogMgMonHV9So0000o`00
0?mgMgL01Oooool2o`0000Kooooo0_l0000@ooooo`;o00001Oooool2o`000003ooooool0003ooooo
00?ooooo0_l000001OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`00:Oooool00ol0003oooooooooo`0@ooooo`;o00003?ooool2o`00013ooooo00?oEEEE
ofIVI_l000000oooool2o`000004oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o00008_ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:?ooool01OnYZJWo410@o`000?l@
413oZJVY00Ko000000?o<S8bonk^k_ooool00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02[ooooo
00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0
003o0000onk^kP0Dooooo`;o00002Oooool2o`0000Gooooo0_l000000ooooooo0000o`000002o`00
0008ooooool0003o0000onk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool002Wooooo0_l0000Aooooo`;o00001?ooool2o`0000Kooooo0_l0000Yooooo`;o0000
5oooool2o`0003cooooo0_l0000=ooooo`Ko00006Oooool2o`0002[ooooo0_l0000Dooooo`;o0000
:_ooool002Wooooo00?o0000ooooooooool05_ooool2o`0000gooooo0_l0000hooooo`;o000000?o
ooooo`000?l00000??ooool2o`0002Cooooo0_l00005ooooo`?o00001?ooool2o`00023ooooo0_l0
0002ooooo`;o0000<Oooool2o`0000gooooo000Yooooo`03o`000?oooooooooo02Gooooo0_l0000d
ooooo`;o00000_ooool2o`0000oooooo0_l0000?ooooo`;o00002_ooool2o`0002?ooooo0_l0000B
ooooo`;o00001Oooool3o`0000Cooooo0_l0000;ooooo`;o00004oooool2o`0000Oooooo0_l0000/
ooooo`;o00003Oooool002Wooooo00?o0000ooooooooool0DOooool4o`0000Kooooo0_l0000Coooo
o`;o00003oooool2o`0000[ooooo0_l0000?ooooo`;o00004_ooool2o`0000[ooooo0_l0000Doooo
o`?o00002_ooool2o`0001cooooo0_l0000=ooooo`;o00001Oooool4o`0000Kooooo0_l0000Koooo
o`00:Oooool00ol0003oooooooooo`1Aooooo`Co0000BOooool2o`0001Gooooo0_l000000ooooooo
0000o`000004ooooo`;o00004Oooool2o`000004ooooool0003o0000o`0000oooooo0_l0000Voooo
o`;o00001Oooool4o`0000Kooooo0_l0000Kooooo`008Oooooooo`0004Co00001?ooool002Wooooo
0ol000000ooooooo0000o`000006ooooo`04o`000?ooooooooooooooo`;o00000oooool2o`0000;o
oooo00?o0000ooooooooool02?ooool4o`0000?ooooo0ol00003ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01_ooool2o`0000;ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool2o`0000;o
oooo0_l00006ooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooooooo0_l00006oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00;ooooo0_l00005ooooo`03o`000?oooooooooo00Wooooo0_l0000;oooo
o`03o`000?oooooooooo00Gooooo0_l00002ooooo`03o`000?oooooooooo00;ooooo0_l00005oooo
o`03o`000?oooooooooo00[ooooo0ol00004ooooo`;o00000oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool002Wooooo00Co0000oooooooo
oooooooo0ol0000>ooooo`;o00005?ooool3o`0000Kooooo0_l00007ooooo`03o`000?oooooooooo
03_ooooo0ol0000=ooooo`;o00002_ooool2o`0000;ooooo0_l0000:ooooo`;o00003Oooool3o`00
01[ooooo0_l0000>ooooo`;o00004?ooool00ol0003oooooooooo`02ooooo`?o00006?ooool2o`00
01Cooooo0ol00004ooooo`03o`000?oooooooooo00[ooooo000Yooooo`03o`000?oooooooooo00;o
oooo0_l0000Cooooo`;o00006?ooool2o`0004Kooooo0_l0000=ooooo`;o00003_ooool2o`0000[o
oooo0ol0000<ooooo`;o00004_ooool2o`0000;ooooo0_l00003ooooo`;o00003?ooool4o`0000[o
oooo0_l0000:ooooo`;o0000:Oooool2o`0000?ooooo0ol0000Aooooo`00:Oooool00ol0003ooooo
ooooo`0Gooooo`;o0000>oooool2o`0001Sooooo0_l00009ooooo`;o0000:_ooool2o`0001_ooooo
0_l00003ooooo`;o00000_ooool2o`0000Gooooo0_l0000:ooooo`;o00003?ooool3o`0003Cooooo
0_l00003ooooo`;o00004_ooool002Wooooo0_l0000Xooooo`;o00008?ooool2o`0000Wooooo0_l0
000Eooooo`;o000000?oooooo`000?l000001oooool2o`0004Wooooo0_l0000>ooooo`;o00006Ooo
ool2o`0004gooooo000Yooooo`03o`000?oooooooooo00gooooo0_l0000Hooooo`;o00005oooool2
o`0000Oooooo0_l0000Pooooo`;o00002_ooool2o`0000Cooooo0_l00004ooooo`;o00003oooool2
o`0008oooooo0_l0000Eooooo`00:Oooool00ol0003oooooooooo`0=ooooo`;o00002Oooool2o`00
02Gooooo0ol0000kooooo`?o00000oooool2o`0000oooooo0ol0000Aooooo`;o00005_ooool2o`00
0003ooooool0003o000001;ooooo0_l0000fooooo`Co00004?ooool4o`0001Gooooo000Yooooo`03
o`000?oooooooooo00Kooooo0_l0000@ooooo`;o00006oooool2o`0000Sooooo0_l0000Uooooo`;o
00005_ooool2o`0000Oooooo1?l0000:ooooo`;o00001?ooool2o`0000_ooooo0_l0000Eooooo`?o
000000?oooooo`000?l000004_ooool2o`0003Kooooo1?l0000@ooooo`;o00005oooool002Wooooo
00?o0000ooooooooool01_ooool2o`0001gooooo0_l0000>ooooo`?o00008oooool2o`0000Wooooo
0_l0000Oooooo`Co00004?ooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o0000
1Oooool2o`0000oooooo0_l00008ooooo`;o00006Oooool2o`0002oooooo0_l0000Uooooo`00:Ooo
ool2o`0000Cooooo0_l0000Mooooo`;o000000Coooooo`000?l0003o00002oooool2o`000003oooo
ool0003o000001oooooo0_l00002ooooo`;o00009Oooool2o`0001cooooo1Ol00002ooooo`;o0000
1Oooool2o`0001Wooooo0_l0000=ooooo`;o00002_ooool2o`0002Cooooo0_l00009ooooo`;o0000
2Oooool2o`0000Gooooo0_l0000Cooooo`00:Oooool00ol0003oooooooooo`03ooooo`;o00005?oo
ool2o`0000Oooooo0_l00002ooooo`;o00002oooool2o`0000Sooooo0_l000000ooooooo0000o`00
000Eooooo`;o0000:Oooool2o`0000Oooooo0_l0000Eooooo`;o00002_ooool2o`0002Sooooo0_l0
000[ooooo`;o00000oooool2o`0000kooooo1?l00002ooooo`;o00001Oooool2o`0001?ooooo000Y
ooooo`03o`000?oooooooooo00Sooooo0_l000000ooooooo0000o`00000<ooooo`;o00004oooool2
o`0000gooooo0_l000000ooooooo0000o`00000_ooooo`;o00000_ooool2o`0001Cooooo0_l0000D
ooooo`Co00005_ooool2o`0003Sooooo0_l0000>ooooo`;o00004oooool4o`0001kooooo000Yoooo
o`03o`000?oooooooooo00Gooooo0_l000001?oooooo0000o`000?ooool2o`00027ooooo0_l00008
ooooo`;o00002oooool2o`0001;ooooo0_l0000Fooooo`;o00000_ooool2o`0000gooooo0ol0000J
ooooo`Co00005Oooool3o`0003Sooooo0_l0000=ooooo`;o0000=_ooool002Wooooo00?o0000oooo
ooooool01Oooool2o`0000Gooooo0_l0000Zooooo`;o00002_ooool3o`00017ooooo0ol0000Toooo
o`;o00000oooool3o`0003?ooooo0_l0000Dooooo`;o0000<_ooool2o`0000Oooooo0_l0000?oooo
o`?o00006oooool002Wooooo0_l0000=ooooo`;o000000?oooooo`000?l000000_l0000Iooooo`;o
00005_ooool2o`0000Wooooo0_l00007ooooo`;o00003_ooool2o`0001Gooooo0_l00008ooooo`;o
00003oooool2o`0003Cooooo0_l0000Iooooo`;o00001oooool2o`0001Oooooo0_l0000?ooooo`?o
00001?ooool2o`0001Gooooo000Yooooo`03o`000?oooooooooo00Oooooo0_l00006ooooo`Co0000
3?ooool2o`0000_ooooo0_l0000=ooooo`;o000000?oooooo`000?l000003oooool2o`0001Oooooo
0_l0000Oooooo`;o00003oooool2o`00017ooooo0_l0000Mooooo`;o00004oooool2o`0000Sooooo
0_l00007ooooo`;o00005?ooool2o`0000kooooo0_l00009ooooo`;o00005Oooool002Wooooo0_l0
0008ooooo`;o00001_ooool2o`0000kooooo0_l0000Jooooo`;o000000?oooooo`000?l000000_oo
ool2o`0005?ooooo0_l0000Dooooo`;o00007Oooool2o`0001?ooooo0_l0000Wooooo`;o00002_oo
ool2o`0000;ooooo0_l0000?ooooo`;o00003oooool002Wooooo0_l0000oooooo`;o00000_ooool2
o`0005?ooooo0_l0000Zooooo`;o00003_ooool2o`0002Wooooo0_l00002ooooo`;o00004_ooool2
o`0000Cooooo0_l00008ooooo`;o00000oooool2o`0000oooooo000Yooooo`03o`000?oooooooooo
00Cooooo0_l0000=ooooo`;o0000:Oooool2o`00013ooooo0_l0001@ooooo`;o00004oooool2o`00
00[ooooo0_l0000>ooooo`;o00006_ooool2o`0000gooooo0_l00002ooooo`;o00006?ooool2o`00
00Sooooo0_l0000Dooooo`00:Oooool2o`0000Gooooo0_l00003ooooo`;o00002?ooool2o`0001?o
oooo0_l0000?ooooo`;o00005Oooool2o`0000cooooo0_l0000cooooo`;o00003Oooool2o`0001?o
oooo0_l0000Pooooo`;o00004?ooool2o`0000;ooooo0_l000000ooooooo0000o`000018ooooo`00
:Oooool00ol0003oooooooooo`09ooooo`;o00007Oooool2o`0000Wooooo0_l00004ooooo`;o0000
2oooool2o`0000;ooooo0_l0000Booooo`;o00001_ooool2o`0002_ooooo0_l000000ooooooo0000
o`00000`ooooo`;o00003oooool2o`0000kooooo1?l00005ooooo`;o00008oooool2o`0002?ooooo
0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`07ooooo`;o00005oooool2o`00017o
oooo0_l00005ooooo`;o00002_ooool2o`0000;ooooo0_l00009ooooo`;o00001oooool2o`0000Ko
oooo0_l0000^ooooo`;o00004oooool2o`00013ooooo0_l00009ooooo`;o00007oooool2o`0002co
oooo0_l0000Sooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
00Oooooo0_l0000Gooooo`;o00006?ooool2o`0001Wooooo0_l0000kooooo`;o00005oooool2o`00
013ooooo0_l0000Zooooo`;o00006?ooool2o`0003Oooooo0006ooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0AOooool2o`0004_ooooo0_l0001Eooooo`;o00006?ooool2o`0003Oooooo0006ooooo`05
o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo
00Cooooo0ol00015ooooo`;o00005Oooool2o`0005oooooo0_l0000Looooo`;o0000Goooool000Ko
oooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00;o00006oooool2o`0000cooooo0_l0000I
ooooo`;o00005?ooool2o`0000Oooooo0_l00003ooooo`;o0000?Oooool2o`0000_ooooo0_l00005
ooooo`;o00003_ooool2o`0000cooooo1?l00003ooooo`;o0000F?ooool000Kooooo00Go410@oooo
oooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`02o`0001_ooooo0_l0000<ooooo`;o00006Oooool2o`0000Kooooo0_l00006
ooooo`;o00001oooool2o`0000Cooooo0_l00003ooooo`;o00001_ooool2o`0000Sooooo0_l00004
ooooo`;o00009Oooool2o`0000_ooooo0_l0000<ooooo`;o00001oooool2o`0000kooooo0_l00003
ooooo`;o0000F?ooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04kooooo0_l0
0006ooooo`;o00001oooool4o`0000oooooo0_l00008ooooo`;o00001?ooool2o`00043ooooo0_l0
000;ooooo`Co0000B?ooool2o`0001gooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo00[ooooo
0_l0000Hooooo`;o00008_ooool2o`0001;ooooo0_l00003ooooo`;o00002oooool2o`0000oooooo
0_l0000?ooooo`;o00005?ooool2o`0002Wooooo1?l0000Aooooo`;o0000=Oooool2o`0001gooooo
000Yooooo`;o00002oooool2o`0001Sooooo0_l0000Rooooo`;o00004_ooool2o`00013ooooo0_l0
000?ooooo`;o00003oooool2o`0001Cooooo0_l0000Dooooo`;o0000:?ooool3o`0005?ooooo000Y
ooooo`03o`000?oooooooooo00[ooooo0_l0000?ooooo`;o0000<?ooool2o`0000;ooooo0_l0000@
ooooo`;o00001oooool2o`0000?ooooo0_l0000Vooooo`;o00008Oooool2o`0002Wooooo0_l0000R
ooooo`;o0000;oooool002Wooooo00?o0000ooooooooool05Oooool2o`0000Cooooo0_l0000`oooo
o`;o00000_ooool2o`00013ooooo0_l00007ooooo`;o00000oooool2o`0002Kooooo0_l0000_oooo
o`;o0000?oooool2o`0002oooooo000Yooooo`03o`000?oooooooooo00Wooooo0_l0000:ooooo`;o
0000O_ooool2o`0002Wooooo0_l00007ooooo`?o00000oooool2o`0005gooooo0_l0000<ooooo`00
:Oooool00ol0003oooooooooo`09ooooo`;o0000Boooool2o`0003gooooo0_l0000Yooooo`;o0000
1oooool2o`0000Cooooo0_l0001Mooooo`;o00003?ooool002Wooooo0_l0000[ooooo`;o00002?oo
ool2o`00023ooooo0_l0000Aooooo`Co0000coooool002Wooooo00?o0000ooooooooool03?ooool4
o`0000Cooooo0_l0000=ooooo`;o00001Oooool2o`0000Sooooo0_l0000cooooo`Co0000:_ooool2
o`00023ooooo0_l0000Zooooo`;o0000EOooool002Wooooo00?o0000ooooooooool03?ooool6o`00
00;ooooo0_l00006ooooo`;o00001Oooool2o`0002?ooooo0_l0000Cooooo`;o0000>?ooool2o`00
017ooooo0_l0000=ooooo`;o00002_ooool2o`0001kooooo0_l0001Eooooo`00:Oooool00ol0003o
ooooooooo`0@ooooo`;o00002_ooool2o`0000oooooo0_l000000ooooooo0000o`00000Fooooo`;o
00001_ooool2o`0000_ooooo0_l000000ooooooo0000o`000018ooooo`;o00006Oooool2o`0004go
oooo0_l0000Vooooo`00:Oooool00ol0003oooooooooo`0]ooooo`;o000000?oooooo`000?l00000
7_ooool2o`0000kooooo0_l0001jooooo`;o00002Oooool2o`0000?ooooo0_l0000Vooooo`;o0000
9_ooool002Wooooo0_l0001Cooooo`;o0000KOooool2o`0001Wooooo0_l00009ooooo`;o00000ooo
ool2o`0000Cooooo0ol0000<ooooo`;o0000>Oooool002Wooooo00?o0000ooooooooool0D_ooool2
o`0001Sooooo0_l0001Cooooo`;o0000;oooool3o`0000cooooo0_l0000iooooo`00:Oooool00ol0
003oooooooooo`1/ooooo`;o00001_ooool2o`0003[ooooo0_l0002:ooooo`00:Oooool00ol0003o
ooooooooo`1>ooooo`;o00007oooool2o`0000?ooooo0_l0000Vooooo`;o00004_ooool2o`0007go
oooo0_l0000;ooooo`00:Oooool00ol0003oooooooooo`05ooooo`;o00003_ooool2o`0003Oooooo
0_l00003ooooo`;o00006_ooool2o`0001Wooooo0_l0000@ooooo`;o00005?ooool2o`000003oooo
ool0003o000002Gooooo0_l000000ooooooo0000o`00000Xooooo`;o00009?ooool2o`0000_ooooo
000Yooooo`;o00000_ooool2o`000004ooooool0003o0000o`0000kooooo0_l00008ooooo`;o0000
6_ooool2o`0000kooooo0_l00006ooooo`;o00008Oooool2o`0000cooooo0_l00004ooooo`;o0000
8?ooool2o`0000Cooooo0_l000000ooooooo0000o`00000Aooooo`;o00003?ooool2o`0000;ooooo
1?l000000ooooooo0000o`00000Eooooo`?o00004?ooool2o`0000Sooooo0_l00004ooooo`;o0000
8Oooool002Wooooo00Co0000oooooooooooooooo0_l000000ooooooo0000o`00000Iooooo`;o0000
6_ooool2o`0000kooooo0_l0000Yooooo`;o00003?ooool2o`0002Kooooo0_l0000Jooooo`;o0000
3?ooool2o`0000;ooooo0_l0000Jooooo`?o00006_ooool2o`0000Cooooo0_l0000Qooooo`003_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01Oooool00ol0003oooooooooo`3ooooooaWooooo0_l0000Rooooo`003_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolIooooo`;o00008_ooool000kooooo00Go410@oooooooooooooooooa0@400@ooooo`03
o`000?oooooooooo00?ooooo0ol0001Yooooo`;o0000dOooool000kooooo00Go0000oooooooooooo
ooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0JOooool2o`000=7o
oooo000>ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool0=oooool2o`00047ooooo0_l0000@ooooo`;o0000[_ooool000ko
oooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0=Oooool4o`00047ooooo0_l0000@ooooo`;o0000[_ooool000kooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0=Oooool2o`00
043ooooo0_l0002<ooooo`;o00002?ooool2o`0002_ooooo000>ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0000Kooooo0_l0001hooooo`;o0000S?ooool2o`0000Sooooo0_l0000[oooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400=ooooo`03
ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000Kooooo
00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05o`000?ooooooooooooooool0
00003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0
003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onY
ZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmoooo
o`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_ooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Oooooo`Co000000?o410@ooooooooool0
0oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`?o0000oooooolm
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Oooooo`03oeEEEOmVIVKo00000?ooooooAoooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .34424 Mdot
.02762 .27601 Mdot
.02952 .27963 Mdot
.03143 .27121 Mdot
.03333 .32562 Mdot
.03524 .3565 Mdot
.03714 .31458 Mdot
.03905 .41265 Mdot
.04095 .23541 Mdot
.04286 .25821 Mdot
.04476 .34778 Mdot
.04667 .43474 Mdot
.04857 .41128 Mdot
.05048 .33478 Mdot
.05238 .42512 Mdot
.05429 .34038 Mdot
.05619 .3417 Mdot
.0581 .40902 Mdot
.06 .2938 Mdot
.0619 .34892 Mdot
.06381 .41023 Mdot
.06571 .3516 Mdot
.06762 .36464 Mdot
.06952 .40445 Mdot
.07143 .45181 Mdot
.07333 .37069 Mdot
.07524 .34983 Mdot
.07714 .26468 Mdot
.07905 .3721 Mdot
.08095 .27261 Mdot
.08286 .40556 Mdot
.08476 .22972 Mdot
.08667 .35221 Mdot
.08857 .38047 Mdot
.09048 .31655 Mdot
.09238 .23351 Mdot
.09429 .42329 Mdot
.09619 .26997 Mdot
.0981 .37854 Mdot
.1 .44823 Mdot
.1019 .45154 Mdot
.10381 .36313 Mdot
.10571 .24421 Mdot
.10762 .29208 Mdot
.10952 .36662 Mdot
.11143 .25955 Mdot
.11333 .29768 Mdot
.11524 .28154 Mdot
.11714 .28565 Mdot
.11905 .34241 Mdot
.12095 .29654 Mdot
.12286 .42186 Mdot
.12476 .46208 Mdot
.12667 .26787 Mdot
.12857 .24325 Mdot
.13048 .25457 Mdot
.13238 .41425 Mdot
.13429 .34684 Mdot
.13619 .36808 Mdot
.1381 .37842 Mdot
.14 .2722 Mdot
.1419 .26911 Mdot
.14381 .37677 Mdot
.14571 .26262 Mdot
.14762 .3101 Mdot
.14952 .23521 Mdot
.15143 .25581 Mdot
.15333 .31619 Mdot
.15524 .25657 Mdot
.15714 .39544 Mdot
.15905 .37848 Mdot
.16095 .27311 Mdot
.16286 .25722 Mdot
.16476 .28828 Mdot
.16667 .37629 Mdot
.16857 .29486 Mdot
.17048 .46194 Mdot
.17238 .30537 Mdot
.17429 .41297 Mdot
.17619 .35253 Mdot
.1781 .34173 Mdot
.18 .2576 Mdot
.1819 .30759 Mdot
.18381 .35244 Mdot
.18571 .36232 Mdot
.18762 .34577 Mdot
.18952 .31405 Mdot
.19143 .29058 Mdot
.19333 .32857 Mdot
.19524 .31945 Mdot
.19714 .45134 Mdot
.19905 .43355 Mdot
.20095 .33044 Mdot
.20286 .25153 Mdot
.20476 .30714 Mdot
.20667 .41885 Mdot
.20857 .32829 Mdot
.21048 .30992 Mdot
.21238 .45363 Mdot
.21429 .3467 Mdot
.21619 .31776 Mdot
.2181 .29141 Mdot
.22 .42654 Mdot
.2219 .26667 Mdot
.22381 .35887 Mdot
.22571 .37984 Mdot
.22762 .38116 Mdot
.22952 .33286 Mdot
.23143 .33196 Mdot
.23333 .39599 Mdot
.23524 .30022 Mdot
.23714 .27074 Mdot
.23905 .23377 Mdot
.24095 .26543 Mdot
.24286 .25936 Mdot
.24476 .32807 Mdot
.24667 .2934 Mdot
.24857 .28262 Mdot
.25048 .24472 Mdot
.25238 .428 Mdot
.25429 .41183 Mdot
.25619 .32545 Mdot
.2581 .40212 Mdot
.26 .38361 Mdot
.2619 .39414 Mdot
.26381 .2596 Mdot
.26571 .28537 Mdot
.26762 .37824 Mdot
.26952 .2545 Mdot
.27143 .29596 Mdot
.27333 .37418 Mdot
.27524 .28084 Mdot
.27714 .44524 Mdot
.27905 .3732 Mdot
.28095 .27644 Mdot
.28286 .407 Mdot
.28476 .42456 Mdot
.28667 .33663 Mdot
.28857 .25566 Mdot
.29048 .37296 Mdot
.29238 .43327 Mdot
.29429 .22281 Mdot
.29619 .32635 Mdot
.2981 .25725 Mdot
.3 .34445 Mdot
.3019 .31363 Mdot
.30381 .33353 Mdot
.30571 .22345 Mdot
.30762 .31665 Mdot
.30952 .26656 Mdot
.31143 .3387 Mdot
.31333 .27847 Mdot
.31524 .29759 Mdot
.31714 .40088 Mdot
.31905 .26797 Mdot
.32095 .38461 Mdot
.32286 .43082 Mdot
.32476 .39721 Mdot
.32667 .26924 Mdot
.32857 .42453 Mdot
.33048 .43038 Mdot
.33238 .35883 Mdot
.33429 .41704 Mdot
.33619 .44982 Mdot
.3381 .25785 Mdot
.34 .243 Mdot
.3419 .34203 Mdot
.34381 .31925 Mdot
.34571 .33092 Mdot
.34762 .26523 Mdot
.34952 .43064 Mdot
.35143 .28482 Mdot
.35333 .32701 Mdot
.35524 .30646 Mdot
.35714 .32617 Mdot
.35905 .34278 Mdot
.36095 .34222 Mdot
.36286 .4058 Mdot
.36476 .37972 Mdot
.36667 .31395 Mdot
.36857 .37146 Mdot
.37048 .43207 Mdot
.37238 .45329 Mdot
.37429 .32399 Mdot
.37619 .44918 Mdot
.3781 .27534 Mdot
.38 .25181 Mdot
.3819 .36627 Mdot
.38381 .22779 Mdot
.38571 .45274 Mdot
.38762 .26399 Mdot
.38952 .36701 Mdot
.39143 .31614 Mdot
.39333 .28372 Mdot
.39524 .31026 Mdot
.39714 .38631 Mdot
.39905 .42811 Mdot
.40095 .43654 Mdot
.40286 .26557 Mdot
.40476 .46947 Mdot
.40667 .37666 Mdot
.40857 .26902 Mdot
.41048 .27369 Mdot
.41238 .28378 Mdot
.41429 .34354 Mdot
.41619 .47588 Mdot
.4181 .31172 Mdot
.42 .33278 Mdot
.4219 .37122 Mdot
.42381 .26546 Mdot
.42571 .32553 Mdot
.42762 .35209 Mdot
.42952 .40877 Mdot
.43143 .29772 Mdot
.43333 .32973 Mdot
.43524 .34234 Mdot
.43714 .33577 Mdot
.43905 .2704 Mdot
.44095 .44914 Mdot
.44286 .29356 Mdot
.44476 .39267 Mdot
.44667 .44316 Mdot
.44857 .28738 Mdot
.45048 .37162 Mdot
.45238 .34302 Mdot
.45429 .31824 Mdot
.45619 .34037 Mdot
.4581 .35833 Mdot
.46 .26603 Mdot
.4619 .328 Mdot
.46381 .42758 Mdot
.46571 .29801 Mdot
.46762 .31666 Mdot
.46952 .29176 Mdot
.47143 .4731 Mdot
.47333 .25212 Mdot
.47524 .34819 Mdot
.47714 .35171 Mdot
.47905 .28535 Mdot
.48095 .248 Mdot
.48286 .4067 Mdot
.48476 .29219 Mdot
.48667 .27455 Mdot
.48857 .32646 Mdot
.49048 .27172 Mdot
.49238 .37802 Mdot
.49429 .2278 Mdot
.49619 .28183 Mdot
.4981 .42786 Mdot
.5 .25744 Mdot
.5019 .37671 Mdot
.50381 .385 Mdot
.50571 .43538 Mdot
.50762 .32652 Mdot
.50952 .29509 Mdot
.51143 .42905 Mdot
.51333 .36851 Mdot
.51524 .31743 Mdot
.51714 .25256 Mdot
.51905 .28412 Mdot
.52095 .39679 Mdot
.52286 .32371 Mdot
.52476 .26383 Mdot
.52667 .34836 Mdot
.52857 .29416 Mdot
.53048 .32271 Mdot
.53238 .2597 Mdot
.53429 .37102 Mdot
.53619 .30638 Mdot
.5381 .29847 Mdot
.54 .24478 Mdot
.5419 .37001 Mdot
.54381 .24967 Mdot
.54571 .24252 Mdot
.54762 .26094 Mdot
.54952 .31744 Mdot
.55143 .43117 Mdot
.55333 .30941 Mdot
.55524 .36149 Mdot
.55714 .28008 Mdot
.55905 .35235 Mdot
.56095 .38291 Mdot
.56286 .39061 Mdot
.56476 .26645 Mdot
.56667 .32608 Mdot
.56857 .42538 Mdot
.57048 .4195 Mdot
.57238 .33953 Mdot
.57429 .29284 Mdot
.57619 .35878 Mdot
.5781 .24279 Mdot
.58 .25085 Mdot
.5819 .36421 Mdot
.58381 .36179 Mdot
.58571 .38586 Mdot
.58762 .41218 Mdot
.58952 .3914 Mdot
.59143 .28276 Mdot
.59333 .38647 Mdot
.59524 .35122 Mdot
.59714 .23249 Mdot
.59905 .41955 Mdot
.60095 .2664 Mdot
.60286 .32795 Mdot
.60476 .30012 Mdot
.60667 .26367 Mdot
.60857 .22771 Mdot
.61048 .45268 Mdot
.61238 .31899 Mdot
.61429 .29301 Mdot
.61619 .37078 Mdot
.6181 .28094 Mdot
.62 .40399 Mdot
.6219 .35621 Mdot
.62381 .41216 Mdot
.62571 .35962 Mdot
.62762 .3287 Mdot
.62952 .38783 Mdot
.63143 .37718 Mdot
.63333 .33338 Mdot
.63524 .31306 Mdot
.63714 .45332 Mdot
.63905 .41275 Mdot
.64095 .24824 Mdot
.64286 .27787 Mdot
.64476 .38051 Mdot
.64667 .34358 Mdot
.64857 .3973 Mdot
.65048 .35311 Mdot
.65238 .26769 Mdot
.65429 .29885 Mdot
.65619 .37615 Mdot
.6581 .43365 Mdot
.66 .42695 Mdot
.6619 .30779 Mdot
.66381 .39195 Mdot
.66571 .28095 Mdot
.66762 .28473 Mdot
.66952 .2712 Mdot
.67143 .34996 Mdot
.67333 .24254 Mdot
.67524 .35959 Mdot
.67714 .35133 Mdot
.67905 .47124 Mdot
.68095 .36876 Mdot
.68286 .23866 Mdot
.68476 .26138 Mdot
.68667 .3051 Mdot
.68857 .3514 Mdot
.69048 .321 Mdot
.69238 .28164 Mdot
.69429 .33851 Mdot
.69619 .24979 Mdot
.6981 .22283 Mdot
.7 .43526 Mdot
.7019 .38289 Mdot
.70381 .23922 Mdot
.70571 .33709 Mdot
.70762 .38115 Mdot
.70952 .279 Mdot
.71143 .24606 Mdot
.71333 .43374 Mdot
.71524 .27698 Mdot
.71714 .26201 Mdot
.71905 .4428 Mdot
.72095 .45381 Mdot
.72286 .44722 Mdot
.72476 .31323 Mdot
.72667 .27005 Mdot
.72857 .43275 Mdot
.73048 .40496 Mdot
.73238 .31928 Mdot
.73429 .38105 Mdot
.73619 .36431 Mdot
.7381 .37905 Mdot
.74 .32782 Mdot
.7419 .29029 Mdot
.74381 .25165 Mdot
.74571 .41101 Mdot
.74762 .41652 Mdot
.74952 .35414 Mdot
.75143 .39526 Mdot
.75333 .36306 Mdot
.75524 .45083 Mdot
.75714 .22379 Mdot
.75905 .4241 Mdot
.76095 .39236 Mdot
.76286 .27568 Mdot
.76476 .43174 Mdot
.76667 .32576 Mdot
.76857 .29166 Mdot
.77048 .45493 Mdot
.77238 .3932 Mdot
.77429 .26725 Mdot
.77619 .27325 Mdot
.7781 .35377 Mdot
.78 .34254 Mdot
.7819 .26156 Mdot
.78381 .31437 Mdot
.78571 .32573 Mdot
.78762 .45404 Mdot
.78952 .37682 Mdot
.79143 .47734 Mdot
.79333 .38177 Mdot
.79524 .34081 Mdot
.79714 .35819 Mdot
.79905 .3168 Mdot
.80095 .42534 Mdot
.80286 .43207 Mdot
.80476 .35056 Mdot
.80667 .33876 Mdot
.80857 .33282 Mdot
.81048 .33979 Mdot
.81238 .39806 Mdot
.81429 .2531 Mdot
.81619 .2529 Mdot
.8181 .32297 Mdot
.82 .29527 Mdot
.8219 .3096 Mdot
.82381 .27934 Mdot
.82571 .37834 Mdot
.82762 .32854 Mdot
.82952 .33253 Mdot
.83143 .33279 Mdot
.83333 .37194 Mdot
.83524 .30993 Mdot
.83714 .29831 Mdot
.83905 .38104 Mdot
.84095 .39098 Mdot
.84286 .36842 Mdot
.84476 .28692 Mdot
.84667 .42532 Mdot
.84857 .44548 Mdot
.85048 .24361 Mdot
.85238 .33466 Mdot
.85429 .26763 Mdot
.85619 .32121 Mdot
.8581 .23206 Mdot
.86 .4356 Mdot
.8619 .34847 Mdot
.86381 .2747 Mdot
.86571 .46918 Mdot
.86762 .33884 Mdot
.86952 .27146 Mdot
.87143 .35037 Mdot
.87333 .29262 Mdot
.87524 .36096 Mdot
.87714 .45638 Mdot
.87905 .30129 Mdot
.88095 .30939 Mdot
.88286 .36225 Mdot
.88476 .29041 Mdot
.88667 .32678 Mdot
.88857 .29055 Mdot
.89048 .41194 Mdot
.89238 .32317 Mdot
.89429 .40817 Mdot
.89619 .24943 Mdot
.8981 .37643 Mdot
.9 .26666 Mdot
.9019 .38272 Mdot
.90381 .37033 Mdot
.90571 .38994 Mdot
.90762 .26464 Mdot
.90952 .43653 Mdot
.91143 .43424 Mdot
.91333 .30303 Mdot
.91524 .38404 Mdot
.91714 .36977 Mdot
.91905 .30645 Mdot
.92095 .31908 Mdot
.92286 .31165 Mdot
.92476 .3049 Mdot
.92667 .24939 Mdot
.92857 .38095 Mdot
.93048 .25318 Mdot
.93238 .25929 Mdot
.93429 .29664 Mdot
.93619 .24435 Mdot
.9381 .34511 Mdot
.94 .31331 Mdot
.9419 .28235 Mdot
.94381 .2719 Mdot
.94571 .27748 Mdot
.94762 .30555 Mdot
.94952 .35975 Mdot
.95143 .23698 Mdot
.95333 .32748 Mdot
.95524 .38174 Mdot
.95714 .25463 Mdot
.95905 .25564 Mdot
.96095 .32334 Mdot
.96286 .26851 Mdot
.96476 .32147 Mdot
.96667 .27349 Mdot
.96857 .37789 Mdot
.97048 .24799 Mdot
.97238 .25252 Mdot
.97429 .35191 Mdot
.97619 .44909 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo05?ooooo0_l00002ooooo`;o0000O?ooool2o`00017ooooo0_l0001Booooo`001_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo05?ooooo0_l00002ooooo`;o00005ooo
ool2o`0002;ooooo0_l0000Rooooo`;o00006oooool2o`00017ooooo0_l0001Booooo`001?l00002
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool04?ooool2o`0005kooooo0_l0000Rooooo`;o00008_oo
ool2o`0008;ooooo0006ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^
kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000@ooooo`Co0000;Oooool2o`0007;ooooo0_l0
001Booooo`;o0000<Oooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00;ooooo
0_l0000>ooooo`;o00004Oooool2o`0001[ooooo0_l0001booooo`;o0000D_ooool2o`0001cooooo
0_l0000Cooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo0_l0000Qooooo`;o0000
ZOooool2o`0000Gooooo0_l0001>ooooo`;o00004oooool000Kooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo01kooooo0_l00012ooooo`;o0000@?ooool2o`0000Sooooo0_l0000Mooooo`;o
000000?oooooo`000?l000001Oooool2o`0006?ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo
01Oooooo0_l00005ooooo`;o00009Oooool2o`0001_ooooo0_l0000nooooo`Co00002?ooool2o`00
01gooooo0_l0000:ooooo`;o0000:oooool2o`0001[ooooo0_l0000Hooooo`00:Oooool2o`0001So
oooo0_l0000/ooooo`;o0000B?ooool2o`00017ooooo0ol0000Nooooo`;o00005?ooool2o`0002_o
oooo0_l0000=ooooo`;o00002?ooool2o`000003ooooool0003o000000Wooooo0_l0000=ooooo`00
:Oooool00ol0003oooooooooo`0fooooo`;o0000=oooool2o`0001cooooo1?l0000:ooooo`;o0000
1_ooool2o`0000[ooooo0_l0000Booooo`;o00003oooool2o`0000kooooo0_l0000_ooooo`;o0000
2?ooool2o`0000cooooo0_l0000=ooooo`00:Oooool00ol0003oooooooooo`0Oooooo`;o00001?oo
ool2o`0000oooooo0_l0000Cooooo`;o00001?ooool2o`0001cooooo0_l0000Looooo`;o00003?oo
ool2o`0001;ooooo0_l0000Sooooo`;o00003_ooool2o`0001Cooooo0ol0000Sooooo`;o00001_oo
ool3o`0000;ooooo0_l0000=ooooo`00:Oooool00ol0003oooooooooo`02ooooo`;o00006oooool2
o`0000Cooooo1_l00003ooooo`;o00006oooool2o`0000Cooooo0_l000000ooooooo0000o`00000;
ooooo`;o0000<_ooool2o`0006?ooooo0ol0000Sooooo`;o00001_ooool3o`00017ooooo000Yoooo
o`03o`000?oooooooooo00;ooooo0_l0000Dooooo`;o00003Oooool4o`0000?ooooo0_l0000Coooo
o`;o00001?ooool2o`0000Wooooo0_l0000;ooooo`;o0000<_ooool2o`0000Wooooo0_l00003oooo
o`;o0000:_ooool2o`0000Sooooo0_l0000Cooooo`;o0000;_ooool2o`0001[ooooo000Yooooo`;o
00003_ooool2o`0000Wooooo0_l00009ooooo`;o00007_ooool2o`0000Cooooo0_l0000Iooooo`;o
00002oooool2o`0002[ooooo0_l000000ooooooo0000o`000003ooooo`;o00004Oooool2o`0001Oo
oooo0_l00008ooooo`;o00004oooool2o`0002Kooooo0_l00006ooooo`;o00006_ooool002Wooooo
00?o0000ooooooooool03Oooool2o`0000kooooo0_l00004ooooo`;o00005oooool2o`0000Cooooo
0_l0000Dooooo`;o000000?oooooo`000?l000001oooool2o`0000_ooooo0_l00003ooooo`;o0000
1Oooool2o`0000[ooooo0_l0000Booooo`;o00002oooool2o`0000[ooooo1?l0000<ooooo`;o0000
9_ooool2o`0001Oooooo0_l0000=ooooo`Co00008_ooool002Wooooo00Co0000ooooool0003o0000
4oooool2o`0000Oooooo0_l00003ooooo`;o00003?ooool4o`000008oa0@4?ooooooooooonk^k_lb
<S;o0000oc8b<_o^k^h2o`000003ooooooo^k^ko<S8b00?o00005?ooool2o`000004ooooool0003o
0000ooooo`;o00003Oooool5o`0000?ooooo00?ok^k^o`000?l000000_l00003ooooo`?o000000Co
<S8bonk^k_l0003o00001Oooool2o`0001oooooo0ol000000olb<S;oc<c<ooooo`02ooooo`04onk^
k_lb<S;o0000oc8b<P;o00000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo0_l00004oooo
o`;o00004?ooool2o`0000Wooooo0_l000000ol@413oooooooooo`02o`000004oc8b<_l0003o<S8b
onk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`;o00000oooool2o`0000Sooooo0_l0
000=ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_l000001Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool01?l0003oooooo`000?l0000>oooo
o`;o00000oooool2o`0000cooooo0_l00004ooooo`;o00002?ooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHo`000?l0003oMgMg01[ooooo0_l0
000=ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool00omgMgOoV9RHooooo`03o`0000;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`02o`0000gooooo0ol0000Fooooo`05oa0@4?nj^[[oooooogMg
Molb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0=ooooo`;o00004?ooool2o`0000[ooooo00Co0000oooooooooooooooo0_l000001?nHV9Sooooo
oiRHV?mgMgL3ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04?ooool2o`0001Kooooo0_l00002oooo
o`03ogMgMolb<S;o000000;o000000CoV9RHoooooonHV9SoMgMg0oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo000Yooooo`;o00004?ooool2o`00017ooooo0_l00004ooooo`;o00002?ooool0
0ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooo
oooooooo410@00_ooooo0_l0000Mooooo`;o000000?ok^k^ooooooooool00_ooool01?l@413ooooo
ooooooooool2o`0000;ooooo00Go410@oooooooooooooooooa0@400?ooooo`?o00006_ooool01Ol0
003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oo
oooooooo01[ooooo0_l0000:ooooo`Go00000_ooool2o`0000?ooooo00Go410@oooooooooooooooo
oa0@4003ooooo`03oa0@4?oooooooooo00cooooo0_l0000Hooooo`?o00000_ooool01?l0003ooooo
o`000?l00003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`01oooo
o`00:Oooool3o`0003;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`00000;ooooo`;o00002?ooool2o`0001?ooooo0_l00000
0olQ8B7ok^k^ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000002Kooooo0_l00003ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000001?ooool2o`0001Cooooo1?l0000:oooo
o`03odA4A?oMgMgooooo00;o00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000002ooooo`;o00002_ooool2o`0001Wooooo0_l000000oooooooMgMgoc8b
<P02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?o
oooo000Yooooo`?o00006_ooool2o`0001Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00Ko0000ooooooooooooooooo`000?ooool2o`0000Kooooo0_l0000:
ooooo`;o00005Oooool00omgMgOoIVIVooooo`03o`0000?ooooo0_l00002ooooo`05o`000?oooooo
ooooooooool000004_ooool2o`0001;ooooo0_l00002ooooo`03oa0@4?l0003o^[Zj00?ooooo0ol0
00000ooooooo0000ooooo`02ooooo`?o000000?oooooo`000?ooool00oooool2o`0000Kooooo0_l0
0006ooooo`;o00001?ooool2o`0000cooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`;o00008oooool3o`00
0004ob4Q8Ol0003o<S8bolc<c0;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool002Wooooo00?o0000ooooooooool06_ooool2o`0001Kooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Ko410@oooooooooooo
oooooa0@4?ooool2o`0000?ooooo0_l000000ooooooo0000o`00000Gooooo`;o00002Oooool01Ol0
003oooooo`000?l0003o410@00?ooooo0_l00002ooooo`05oa0@4?ooooooooooooooool@41003Ooo
ool2o`0000?ooooo0_l00006ooooo`;o00003oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?l0
003o0000ooooool@41000oooool01Ol@413o0000o`000?oooooo410@00cooooo0_l00006ooooo`;o
00004oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@00Sooooo0_l0000Mooooo`?o00001_ooool01Ol@413ooooooooooooo
oooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`00:Oooool00ol0003ooooooooo
o`0Jooooo`;o00003_ooool2o`0000Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`;o00006_ooool2o`0000Go
oooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0_l00008ooooo`;o00002oooool2o`0000cooooo00Go
410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00cooooo0_l0000Kooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool2o`0001oooooo00?o
0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`00:Oooool00ol0003oooooooooo`0Gooooo`;o00004Oooool2o`0000Cooooo
00CoEEEEofIVI_l0003o00000oooool01?o^k^ko<S8bo`000?lb<S82o`0000;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Yooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`;o00001Oooool2o`0000;o
oooo0_l0000Hooooo`03ojVYZOl@413o000000;o00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo0ol000000olb<S;ok^k^ooooo`0Sooooo`;o00001?ooool00omgMgOo0000ooooo`02o`00
0006ooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^017ooooo
0_l00002ooooo`?o00004Oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool002Wooooo0_l00009ooooo`;o00003Oooool2o`0001;o
oooo0_l00005ooooo`;o00001oooool2o`0000Oooooo0_l00006ooooo`;o0000=Oooool2o`0000Oo
oooo0_l00002ooooo`;o00001_ooool2o`0000Gooooo0_l0000<ooooo`;o00002oooool2o`0002Oo
oooo0_l00007ooooo`;o00003_ooool2o`0000oooooo0_l00002ooooo`?o0000:?ooool002Wooooo
00?o0000ooooooooool02?ooool2o`0000oooooo0_l000000ooooooo0000o`00000=ooooo`;o0000
5oooool2o`0000Kooooo0_l0000<ooooo`;o00008oooool2o`0000;ooooo0_l00005ooooo`;o0000
3?ooool2o`0000Gooooo0_l000000ooooooo0000o`00000Sooooo`;o0000<oooool2o`0000Cooooo
0_l0000Mooooo`;o00006Oooool002Wooooo00?o0000ooooooooool06Oooool2o`000003ooooool0
003o000002;ooooo0_l0000Hooooo`;o00008oooool2o`0000Wooooo0_l0000Fooooo`;o00004ooo
ool2o`0000kooooo0_l0000iooooo`;o00002oooool2o`00013ooooo0_l0000Iooooo`00:Oooool0
0ol0003oooooooooo`0/ooooo`;o00004_ooool2o`0007Gooooo0_l0000Hooooo`;o0000??ooool2
o`0000Wooooo0_l00002ooooo`;o00001Oooool2o`0001Gooooo000Yooooo`03o`000?oooooooooo
02cooooo0_l000000ooooooo0000o`000005ooooo`;o0000;oooool2o`0003Sooooo0_l0000Voooo
o`;o00001_ooool2o`0004Oooooo1_l00005ooooo`;o00005Oooool0027oooooool00014o`0000Co
oooo000Yooooo`04o`000?ooooooooooooooo`;o00001_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Wooooo00Co0000ooooool0003o00002?ooool01?l0003oooooooooooooool2
o`0000Cooooo0ol0000<ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_l00007
ooooo`03o`000?oooooooooo00Wooooo0_l00007ooooo`;o00000_ooool00ol0003oooooooooo`02
o`0000Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Sooooo0ol0000;ooooo`03o`000?oooooooooo00Wooooo0_l0000:ooooo`03o`000?oooooo
oooo00[ooooo00Co0000oooooooooooooooo0_l00006ooooo`03o`000?oooooooooo00Sooooo0_l0
000:ooooo`;o00000_ooool2o`0000Sooooo00?o0000ooooooooool00_ooool2o`0000Gooooo00?o
0000ooooooooool00oooool2o`0000Cooooo0_l0000:ooooo`03o`000?oooooooooo00[ooooo000Y
ooooo`04o`000?ooooooooooooooo`;o00003oooool2o`0001;ooooo0_l0000:ooooo`;o00001_oo
ool2o`0001[ooooo1?l0000Aooooo`;o00001Oooool2o`0000Cooooo00?o0000ooooooooool04?oo
ool2o`0000gooooo0_l00009ooooo`;o00003_ooool00ol0003oooooooooo`09ooooo`;o00006ooo
ool2o`00017ooooo0_l00003ooooo`;o0000:oooool2o`0000[ooooo00?o0000ooooooooool02_oo
ool002Wooooo00?o0000ooooooooool04_ooool2o`0001;ooooo0_l0000;ooooo`;o00001Oooool2
o`0001cooooo0_l00009ooooo`;o00003Oooool2o`0001?ooooo0_l00002ooooo`;o00003Oooool2
o`0000Wooooo0_l0000Cooooo`;o00005oooool2o`0000_ooooo0_l0000Dooooo`;o00004?ooool2
o`0001?ooooo0_l0000Mooooo`00:Oooool00ol0003oooooooooo`0cooooo`;o0000;_ooool2o`00
00Sooooo0_l0000Hooooo`;o00005?ooool4o`0001Wooooo0_l0000Gooooo`;o00002oooool2o`00
01[ooooo0_l0000:ooooo`;o00002_ooool2o`0000Oooooo0_l0000;ooooo`?o00003oooool002Wo
oooo1?l00016ooooo`;o00002oooool2o`00013ooooo0ol00004ooooo`;o00003_ooool2o`0001?o
oooo0_l00004ooooo`;o00000oooool4o`0000[ooooo0_l0000nooooo`;o00001?ooool2o`0000Wo
oooo0_l0000Dooooo`Co00004Oooool2o`000004ooooool0003o0000o`0000oooooo000Yooooo`04
o`000?oooooo0000o`0003;ooooo1?l000000ooooooo0000o`000009ooooo`;o00000_ooool2o`00
00_ooooo0_l0000@ooooo`?o00005?ooool2o`000003ooooool0003o000000Oooooo0_l00007oooo
o`;o00001?ooool2o`00017ooooo0_l00009ooooo`;o00001_ooool2o`0002?ooooo0_l00006oooo
o`;o00001?ooool2o`0000cooooo0_l0000Aooooo`;o00004oooool2o`0001?ooooo000Yooooo`03
o`000?oooooooooo03?ooooo1?l000000ooooooo0000o`000004ooooo`?o00000_ooool2o`00017o
oooo0_l0000<ooooo`;o00005_ooool2o`0000;ooooo0_l00007ooooo`;o0000:oooool2o`0000Ko
oooo1?l0000Qooooo`;o00005?ooool2o`0000Cooooo0ol0000jooooo`00:Oooool00ol0003ooooo
ooooo`05ooooo`;o0000=oooool3o`00013ooooo0_l00003ooooo`;o00003?ooool2o`0001Kooooo
0_l00003ooooo`;o0000?Oooool2o`0003Oooooo0_l00004ooooo`?o00001Oooool2o`0003?ooooo
000Yooooo`03o`000?oooooooooo00Gooooo0_l0001:ooooo`;o00001_ooool2o`0002Kooooo0_l0
000Zooooo`;o00009Oooool2o`0000;ooooo0_l0000Nooooo`?o00003?ooool2o`0000?ooooo0_l0
000^ooooo`00:Oooool2o`0000Oooooo0ol0000Booooo`;o00004Oooool2o`0002Wooooo0_l00008
ooooo`;o00000oooool3o`0001Kooooo0_l00003ooooo`?o00009?ooool2o`0002Gooooo0_l00002
ooooo`;o00005Oooool2o`0000?ooooo0_l00002ooooo`?o00004Oooool2o`0002kooooo000Yoooo
o`;o00001oooool3o`0001;ooooo0_l0000Aooooo`;o000000?oooooo`000?l000008_ooool2o`00
00cooooo0_l00003ooooo`?o00003oooool2o`0000Gooooo0_l00003ooooo`?o0000??ooool2o`00
02Sooooo0_l00003ooooo`;o0000;?ooool2o`0001Sooooo000Yooooo`;o00001?ooool2o`0000Co
oooo0_l0000Eooooo`;o00003oooool2o`0000Oooooo0_l0000Iooooo`;o00008oooool2o`00017o
oooo0_l0000?ooooo`;o00009Oooool2o`0004?ooooo0_l0000Fooooo`;o00006?ooool002Wooooo
00?o0000ooooooooool00oooool2o`0000Cooooo0ol000001?oooooo0000o`000?ooool2o`0000ko
oooo0_l0000Hooooo`;o0000@_ooool2o`0000gooooo0ol0000>ooooo`;o00002?ooool2o`0000[o
oooo0_l0000Gooooo`?o00000_ooool2o`0002?ooooo0_l0000Aooooo`;o000000?oooooo`000?l0
00007oooool2o`0000cooooo000Yooooo`03o`000?oooooooooo00[ooooo0_l000001?oooooo0000
o`000?ooool2o`0001_ooooo0_l000000ooooooo0000o`00001<ooooo`;o00003_ooool2o`0001So
oooo0_l0000:ooooo`;o00004?ooool2o`0000Gooooo0ol00002ooooo`;o00004_ooool2o`0000Oo
oooo0_l00006ooooo`;o00005?ooool2o`0001oooooo0_l0000<ooooo`00:Oooool2o`000003oooo
ool0003o000002_ooooo0_l000000ooooooo0000o`00001Fooooo`;o0000<oooool2o`0000Oooooo
0_l0000Nooooo`;o00001oooool2o`0000Cooooo0_l00015ooooo`00:Oooool00ol0003ooooooooo
o`02o`0003_ooooo0_l0000Pooooo`;o00009oooool2o`0001gooooo0_l00005ooooo`;o00003Ooo
ool3o`0000kooooo0_l0000Uooooo`;o00005oooool2o`0001Kooooo0_l0000Dooooo`00:Oooool0
0ol0003oooooooooo`0:ooooo`;o00002_ooool2o`0001Sooooo0_l0000;ooooo`;o00008?ooool2
o`0004Kooooo0_l00005ooooo`Co00003?ooool2o`0000kooooo0_l0000Aooooo`;o00001?ooool2
o`0002Gooooo1?l0000Dooooo`;o00005?ooool002Wooooo00?o0000ooooooooool02_ooool2o`00
00[ooooo1?l0000Fooooo`;o0000?Oooool2o`000003ooooool0003o000003cooooo0_l0000_oooo
o`;o00001?ooool2o`0002Oooooo0_l0000Zooooo`00:Oooool00ol0003oooooooooo`0<ooooo`;o
00002_ooool2o`0000Kooooo0_l0001=ooooo`;o000000?oooooo`000?l000009_ooool2o`0000Co
oooo0_l000000ooooooo0000o`00000Fooooo`;o00004oooool2o`0003;ooooo0_l0000Aooooo`;o
00000oooool2o`0001kooooo000Yooooo`;o00003Oooool4o`00013ooooo0_l0000/ooooo`;o0000
0_ooool2o`0001Oooooo0_l0000?ooooo`;o00001oooool2o`0001?ooooo0_l00004ooooo`;o0000
00?oooooo`000?l000005_ooool2o`0001?ooooo0_l0000_ooooo`;o000000?oooooo`000?l00000
4Oooool2o`0000?ooooo0_l0000Nooooo`00:Oooool00ol0003oooooooooo`0>ooooo`;o00004ooo
ool2o`0000Gooooo0_l0000Qooooo`?o00000_ooool2o`0001Oooooo0_l0000:ooooo`;o00000ooo
ool2o`0000Oooooo0_l0000?ooooo`;o0000:?ooool2o`0000Kooooo0_l0000Xooooo`;o00003Ooo
ool2o`0001;ooooo0_l0000Uooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0
5?ooool2o`0000_ooooo1?l00003ooooo`Co00004Oooool2o`0000cooooo1?l0000Kooooo`;o0000
2oooool2o`0001[ooooo0_l000000ooooooo0000o`00000Xooooo`;o00001_ooool2o`0001Sooooo
0_l0000>ooooo`;o00002_ooool2o`0001Gooooo0_l0000Eooooo`;o00003_ooool000Kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oo
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Aooooo`;o000000?oooooo`000?l0
00002oooool2o`0000Gooooo0_l0000Cooooo`?o00002oooool2o`0001gooooo0_l0000Wooooo`;o
00005?ooool2o`0001Wooooo0_l0000@ooooo`Co00001oooool3o`00013ooooo0_l00008ooooo`;o
00000_ooool2o`0001?ooooo0_l00006ooooo`;o00001oooool2o`0000;ooooo0_l0000>ooooo`00
1_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo017ooooo0_l0000[ooooo`;o00002?ooool2o`0001;o
oooo0_l0000Fooooo`;o00008Oooool2o`00013ooooo0_l00006ooooo`Co00003oooool2o`00013o
oooo1?l00007ooooo`;o00004Oooool2o`0000cooooo0_l0000Cooooo`;o00000_ooool2o`0000;o
oooo0_l00007ooooo`;o00004_ooool000Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03
oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0004Sooooo0_l0000Booooo`;o
00005_ooool2o`00027ooooo0_l0000Hooooo`Co00002_ooool2o`0005[ooooo0_l0000Oooooo`00
1_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0Q?ooool2o`0002Cooooo0_l00006oooo
o`;o00002oooool2o`0000Wooooo0_l0000Mooooo`;o00006?ooool2o`0001?ooooo0_l0000Roooo
o`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo02Oooooo0_l0000Pooooo`;o0000>Oooool2o`00
02Cooooo0_l00006ooooo`;o00005_ooool2o`0001[ooooo0_l000000ooooooo0000o`000002oooo
o`;o00005?ooool2o`0001?ooooo0_l0000Rooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool09oooool2o`0001Oooooo0_l00007ooooo`;o00004_ooool2o`0003gooooo0_l0000W
ooooo`;o00007oooool2o`0000Gooooo0_l0000;ooooo`;o0000@?ooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o
0000ooooooooool0@?ooool2o`0000Kooooo0_l0000Aooooo`Co0000?Oooool2o`0002Oooooo0_l0
000cooooo`;o0000@?ooool002Wooooo0_l0000<ooooo`;o0000>oooool2o`00017ooooo0_l0001O
ooooo`;o00008Oooool2o`0005_ooooo000Yooooo`03o`000?oooooooooo00_ooooo0_l00002oooo
o`;o0000?oooool2o`0001Oooooo0_l0000Uooooo`;o0000:_ooool2o`00027ooooo0_l0000coooo
o`;o00009_ooool002Wooooo00?o0000ooooooooool01?ooool2o`000003ooooool0003o000000;o
00001?ooool2o`0003oooooo0_l0000Gooooo`;o00005?ooool2o`0000oooooo0_l0001Booooo`;o
0000;_ooool2o`0002Kooooo000Yooooo`04o`000?ooooooooooooooo`;o000000Coooooo`000?l0
003ooooo1?l0000Dooooo`;o00003?ooool2o`0001Oooooo0_l0000gooooo`;o0000<Oooool2o`00
00Wooooo0_l00003ooooo`;o00008?ooool2o`0002gooooo0_l0000Wooooo`00:Oooool01?l0003o
ooooooooooooool2o`0001cooooo0_l0000<ooooo`;o00005oooool2o`0001Sooooo0_l0001@oooo
o`;o00002Oooool2o`0000?ooooo0_l0000Qooooo`;o0000;?ooool2o`0002Oooooo000Yooooo`;o
0000>?ooool2o`0002Oooooo0_l0001:ooooo`;o00001oooool2o`0002kooooo0_l0001Eooooo`00
:Oooool00ol0003oooooooooo`0Cooooo`;o00001oooool2o`0001Wooooo0_l0001cooooo`;o0000
1oooool2o`0008Gooooo000Yooooo`03o`000?oooooooooo00Gooooo0_l0000<ooooo`;o00001ooo
ool2o`0001gooooo0_l0000Cooooo`;o00003?ooool2o`0004_ooooo0_l0000Looooo`;o00007_oo
ool2o`0000_ooooo0_l0000=ooooo`;o0000=Oooool002Wooooo00?o0000ooooooooool01Oooool2
o`0003Cooooo0_l00009ooooo`;o00002?ooool2o`0000cooooo0_l0000Eooooo`;o00004oooool2
o`0000Wooooo0_l00002ooooo`;o00004?ooool2o`0001cooooo0_l0000Nooooo`;o00002oooool2
o`0000gooooo0_l0000eooooo`00:Oooool00ol0003oooooooooo`16ooooo`;o00005?ooool2o`00
0003ooooool0003o000000Cooooo0_l00005ooooo`;o00001oooool2o`0001?ooooo0_l00009oooo
o`;o00000_ooool2o`0000_ooooo0_l0000gooooo`;o00002_ooool2o`0000[ooooo0_l00013oooo
o`00:Oooool2o`0000Gooooo0_l0000_ooooo`;o00007?ooool2o`0000Oooooo0_l000000ooooooo
0000o`000004ooooo`;o00001Oooool2o`0002Wooooo0_l0000=ooooo`;o00008?ooool2o`0000co
oooo0_l00002ooooo`;o00000oooool2o`0000[ooooo0_l0000:ooooo`;o00004?ooool2o`0000oo
oooo0_l0000Pooooo`00:Oooool00ol0003oooooooooo`04ooooo`;o0000;oooool2o`0001cooooo
0_l0000Qooooo`;o00007oooool2o`0002oooooo0_l0000<ooooo`;o00000_ooool2o`0002gooooo
0_l0000>ooooo`?o00008?ooool002Wooooo00?o0000ooooooooool0M_ooool2o`000:7ooooo0_l0
000Qooooo`00:Oooool00ol0003oooooooooo`1>ooooo`;o0000=?ooool2o`0005Kooooo0_l0000W
ooooo`;o0000=Oooool002Wooooo00?o0000ooooooooool05Oooool2o`0003Oooooo0_l0000doooo
o`;o0000E_ooool3o`0002Kooooo0_l0000eooooo`00:Oooool2o`0000gooooo0_l00007ooooo`;o
00007Oooool2o`0002_ooooo0_l0000;ooooo`;o00004_ooool2o`0005Wooooo0_l00008ooooo`;o
0000A_ooool2o`0000_ooooo000Yooooo`03o`000?oooooooooo00cooooo0_l00007ooooo`;o0000
7Oooool2o`0000?ooooo0_l0000Vooooo`;o00002Oooool4o`000003ooooool0003o000000oooooo
0_l0000eooooo`;o00001_ooool2o`0001Wooooo0_l00009ooooo`;o00000oooool2o`0000Cooooo
0_l0000kooooo`;o00002oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0>Oooool2o`00037o
oooo0_l00003ooooo`;o0000A_ooool2o`0000Kooooo0_l0000Iooooo`;o00003_ooool2o`0000Co
oooo0_l0000Kooooo`;o0000:oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo4?ooool2o`0002_o
oooo000>ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`?o
00007Oooool2o`0000cooooo0_l0003ooooooa3ooooo000>ooooo`05o`000?ooooooooooooooool0
00003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01gooooo0_l0000<ooooo`;o
0000ooooool@ooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0
003o<S8bolc<c005ooooo`03o`000?oooooooooo07Oooooo0_l0002Booooo`;o0000;oooool000ko
oooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0Moooool2o`0001?ooooo0_l00011ooooo`;o0000>_ooool2o`0002oooooo000>ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
07[ooooo0_l0000@ooooo`;o0000@Oooool2o`0006_ooooo000>ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0000Kooooo0_l0001kooooo`;o0000Moooool2o`0004Oooooo000Yooooo`03
o`000?oooooooooo0??ooooo0_l00017ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Go
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`007oooool4o`000003oa0@4?oooooooooo00?ooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`007oooool00omEEEGoIVIVo`00003oooooodOooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .39318 Mdot
.02762 .24464 Mdot
.02952 .28426 Mdot
.03143 .32584 Mdot
.03333 .36204 Mdot
.03524 .27457 Mdot
.03714 .27756 Mdot
.03905 .32624 Mdot
.04095 .33613 Mdot
.04286 .28665 Mdot
.04476 .30382 Mdot
.04667 .36995 Mdot
.04857 .40254 Mdot
.05048 .27409 Mdot
.05238 .35309 Mdot
.05429 .29577 Mdot
.05619 .26395 Mdot
.0581 .40723 Mdot
.06 .25253 Mdot
.0619 .24855 Mdot
.06381 .39923 Mdot
.06571 .25987 Mdot
.06762 .27751 Mdot
.06952 .41103 Mdot
.07143 .4332 Mdot
.07333 .33832 Mdot
.07524 .33956 Mdot
.07714 .27078 Mdot
.07905 .27541 Mdot
.08095 .24686 Mdot
.08286 .40455 Mdot
.08476 .32247 Mdot
.08667 .24399 Mdot
.08857 .35413 Mdot
.09048 .37454 Mdot
.09238 .29989 Mdot
.09429 .42798 Mdot
.09619 .33369 Mdot
.0981 .28633 Mdot
.1 .40111 Mdot
.1019 .44483 Mdot
.10381 .38333 Mdot
.10571 .28858 Mdot
.10762 .37149 Mdot
.10952 .39871 Mdot
.11143 .27208 Mdot
.11333 .25519 Mdot
.11524 .3813 Mdot
.11714 .35461 Mdot
.11905 .24418 Mdot
.12095 .39029 Mdot
.12286 .37025 Mdot
.12476 .4831 Mdot
.12667 .34868 Mdot
.12857 .31695 Mdot
.13048 .24992 Mdot
.13238 .32951 Mdot
.13429 .26993 Mdot
.13619 .42542 Mdot
.1381 .39843 Mdot
.14 .25946 Mdot
.1419 .38165 Mdot
.14381 .284 Mdot
.14571 .28905 Mdot
.14762 .22741 Mdot
.14952 .276 Mdot
.15143 .30653 Mdot
.15333 .26145 Mdot
.15524 .31921 Mdot
.15714 .41414 Mdot
.15905 .3343 Mdot
.16095 .28255 Mdot
.16286 .29018 Mdot
.16476 .33955 Mdot
.16667 .28327 Mdot
.16857 .31441 Mdot
.17048 .4831 Mdot
.17238 .2487 Mdot
.17429 .34898 Mdot
.17619 .37052 Mdot
.1781 .40209 Mdot
.18 .25909 Mdot
.1819 .33918 Mdot
.18381 .38391 Mdot
.18571 .25286 Mdot
.18762 .32675 Mdot
.18952 .35947 Mdot
.19143 .35043 Mdot
.19333 .25189 Mdot
.19524 .26356 Mdot
.19714 .4333 Mdot
.19905 .34562 Mdot
.20095 .28073 Mdot
.20286 .31716 Mdot
.20476 .2607 Mdot
.20667 .3203 Mdot
.20857 .26608 Mdot
.21048 .39724 Mdot
.21238 .48386 Mdot
.21429 .2689 Mdot
.21619 .38305 Mdot
.2181 .24633 Mdot
.22 .35422 Mdot
.2219 .35525 Mdot
.22381 .4091 Mdot
.22571 .36655 Mdot
.22762 .34649 Mdot
.22952 .2657 Mdot
.23143 .28379 Mdot
.23333 .41344 Mdot
.23524 .25456 Mdot
.23714 .32576 Mdot
.23905 .33333 Mdot
.24095 .2464 Mdot
.24286 .38392 Mdot
.24476 .29544 Mdot
.24667 .24958 Mdot
.24857 .23157 Mdot
.25048 .26021 Mdot
.25238 .41555 Mdot
.25429 .39907 Mdot
.25619 .41711 Mdot
.2581 .35272 Mdot
.26 .29292 Mdot
.2619 .41416 Mdot
.26381 .30937 Mdot
.26571 .23592 Mdot
.26762 .26093 Mdot
.26952 .34338 Mdot
.27143 .32878 Mdot
.27333 .29235 Mdot
.27524 .36417 Mdot
.27714 .39556 Mdot
.27905 .30315 Mdot
.28095 .24903 Mdot
.28286 .33573 Mdot
.28476 .42999 Mdot
.28667 .2401 Mdot
.28857 .299 Mdot
.29048 .26595 Mdot
.29238 .36925 Mdot
.29429 .31424 Mdot
.29619 .33866 Mdot
.2981 .28166 Mdot
.3 .26713 Mdot
.3019 .23206 Mdot
.30381 .23187 Mdot
.30571 .27617 Mdot
.30762 .2547 Mdot
.30952 .33622 Mdot
.31143 .42511 Mdot
.31333 .25144 Mdot
.31524 .34829 Mdot
.31714 .4136 Mdot
.31905 .29671 Mdot
.32095 .331 Mdot
.32286 .41245 Mdot
.32476 .31888 Mdot
.32667 .23834 Mdot
.32857 .42572 Mdot
.33048 .41767 Mdot
.33238 .37163 Mdot
.33429 .35739 Mdot
.33619 .45336 Mdot
.3381 .35433 Mdot
.34 .31347 Mdot
.3419 .39177 Mdot
.34381 .22756 Mdot
.34571 .39846 Mdot
.34762 .33006 Mdot
.34952 .4211 Mdot
.35143 .2365 Mdot
.35333 .27605 Mdot
.35524 .35034 Mdot
.35714 .36155 Mdot
.35905 .28054 Mdot
.36095 .23714 Mdot
.36286 .29946 Mdot
.36476 .31939 Mdot
.36667 .26977 Mdot
.36857 .275 Mdot
.37048 .40638 Mdot
.37238 .42045 Mdot
.37429 .34678 Mdot
.37619 .4492 Mdot
.3781 .27373 Mdot
.38 .35712 Mdot
.3819 .24817 Mdot
.38381 .31306 Mdot
.38571 .44866 Mdot
.38762 .25787 Mdot
.38952 .43864 Mdot
.39143 .23235 Mdot
.39333 .32947 Mdot
.39524 .40781 Mdot
.39714 .28322 Mdot
.39905 .45837 Mdot
.40095 .37465 Mdot
.40286 .33575 Mdot
.40476 .41576 Mdot
.40667 .37943 Mdot
.40857 .28615 Mdot
.41048 .27876 Mdot
.41238 .27214 Mdot
.41429 .36162 Mdot
.41619 .43424 Mdot
.4181 .38001 Mdot
.42 .30448 Mdot
.4219 .30014 Mdot
.42381 .32112 Mdot
.42571 .27862 Mdot
.42762 .32234 Mdot
.42952 .36653 Mdot
.43143 .24901 Mdot
.43333 .39788 Mdot
.43524 .3349 Mdot
.43714 .38962 Mdot
.43905 .26138 Mdot
.44095 .45345 Mdot
.44286 .26341 Mdot
.44476 .38622 Mdot
.44667 .38719 Mdot
.44857 .2513 Mdot
.45048 .42593 Mdot
.45238 .40374 Mdot
.45429 .3915 Mdot
.45619 .29759 Mdot
.4581 .35156 Mdot
.46 .25089 Mdot
.4619 .27722 Mdot
.46381 .35788 Mdot
.46571 .40136 Mdot
.46762 .2613 Mdot
.46952 .3179 Mdot
.47143 .42789 Mdot
.47333 .32626 Mdot
.47524 .34468 Mdot
.47714 .43099 Mdot
.47905 .34283 Mdot
.48095 .33687 Mdot
.48286 .36452 Mdot
.48476 .37069 Mdot
.48667 .38545 Mdot
.48857 .24575 Mdot
.49048 .36629 Mdot
.49238 .33286 Mdot
.49429 .30219 Mdot
.49619 .2659 Mdot
.4981 .39298 Mdot
.5 .27064 Mdot
.5019 .32877 Mdot
.50381 .29718 Mdot
.50571 .45764 Mdot
.50762 .28911 Mdot
.50952 .33269 Mdot
.51143 .40303 Mdot
.51333 .33071 Mdot
.51524 .35256 Mdot
.51714 .27037 Mdot
.51905 .3135 Mdot
.52095 .30022 Mdot
.52286 .40535 Mdot
.52476 .33998 Mdot
.52667 .34448 Mdot
.52857 .37921 Mdot
.53048 .32282 Mdot
.53238 .26695 Mdot
.53429 .39741 Mdot
.53619 .25528 Mdot
.5381 .24178 Mdot
.54 .269 Mdot
.5419 .35222 Mdot
.54381 .26175 Mdot
.54571 .29406 Mdot
.54762 .28051 Mdot
.54952 .36691 Mdot
.55143 .41256 Mdot
.55333 .34605 Mdot
.55524 .33461 Mdot
.55714 .38008 Mdot
.55905 .32168 Mdot
.56095 .32601 Mdot
.56286 .30573 Mdot
.56476 .31278 Mdot
.56667 .34552 Mdot
.56857 .42393 Mdot
.57048 .34048 Mdot
.57238 .27416 Mdot
.57429 .3214 Mdot
.57619 .32678 Mdot
.5781 .27102 Mdot
.58 .31462 Mdot
.5819 .40954 Mdot
.58381 .24408 Mdot
.58571 .43058 Mdot
.58762 .32845 Mdot
.58952 .43114 Mdot
.59143 .27529 Mdot
.59333 .43171 Mdot
.59524 .42982 Mdot
.59714 .30751 Mdot
.59905 .34229 Mdot
.60095 .22801 Mdot
.60286 .37016 Mdot
.60476 .24085 Mdot
.60667 .35235 Mdot
.60857 .3096 Mdot
.61048 .43453 Mdot
.61238 .25922 Mdot
.61429 .38795 Mdot
.61619 .34431 Mdot
.6181 .32103 Mdot
.62 .35336 Mdot
.6219 .28473 Mdot
.62381 .38802 Mdot
.62571 .43582 Mdot
.62762 .30374 Mdot
.62952 .39231 Mdot
.63143 .37408 Mdot
.63333 .23278 Mdot
.63524 .32883 Mdot
.63714 .42201 Mdot
.63905 .45383 Mdot
.64095 .2491 Mdot
.64286 .26576 Mdot
.64476 .31813 Mdot
.64667 .38293 Mdot
.64857 .31969 Mdot
.65048 .35902 Mdot
.65238 .2886 Mdot
.65429 .26976 Mdot
.65619 .32866 Mdot
.6581 .36597 Mdot
.66 .39234 Mdot
.6619 .26076 Mdot
.66381 .32521 Mdot
.66571 .32455 Mdot
.66762 .27161 Mdot
.66952 .24729 Mdot
.67143 .26565 Mdot
.67333 .31085 Mdot
.67524 .37117 Mdot
.67714 .35835 Mdot
.67905 .48049 Mdot
.68095 .33365 Mdot
.68286 .29556 Mdot
.68476 .29425 Mdot
.68667 .22711 Mdot
.68857 .32944 Mdot
.69048 .23368 Mdot
.69238 .24245 Mdot
.69429 .32501 Mdot
.69619 .30821 Mdot
.6981 .31501 Mdot
.7 .37055 Mdot
.7019 .43118 Mdot
.70381 .27902 Mdot
.70571 .37227 Mdot
.70762 .36996 Mdot
.70952 .23884 Mdot
.71143 .2959 Mdot
.71333 .36749 Mdot
.71524 .22859 Mdot
.71714 .35891 Mdot
.71905 .38951 Mdot
.72095 .42581 Mdot
.72286 .45349 Mdot
.72476 .27213 Mdot
.72667 .34455 Mdot
.72857 .36844 Mdot
.73048 .3136 Mdot
.73238 .27959 Mdot
.73429 .41288 Mdot
.73619 .3188 Mdot
.7381 .316 Mdot
.74 .38724 Mdot
.7419 .386 Mdot
.74381 .34137 Mdot
.74571 .4335 Mdot
.74762 .3605 Mdot
.74952 .26348 Mdot
.75143 .43436 Mdot
.75333 .27478 Mdot
.75524 .41903 Mdot
.75714 .34221 Mdot
.75905 .42377 Mdot
.76095 .35349 Mdot
.76286 .31488 Mdot
.76476 .45575 Mdot
.76667 .25007 Mdot
.76857 .27091 Mdot
.77048 .42942 Mdot
.77238 .41451 Mdot
.77429 .28957 Mdot
.77619 .33168 Mdot
.7781 .29018 Mdot
.78 .35001 Mdot
.7819 .36696 Mdot
.78381 .39128 Mdot
.78571 .41645 Mdot
.78762 .42483 Mdot
.78952 .33315 Mdot
.79143 .4707 Mdot
.79333 .35625 Mdot
.79524 .27707 Mdot
.79714 .31887 Mdot
.79905 .28909 Mdot
.80095 .34994 Mdot
.80286 .36445 Mdot
.80476 .33731 Mdot
.80667 .31052 Mdot
.80857 .35474 Mdot
.81048 .34094 Mdot
.81238 .45186 Mdot
.81429 .32094 Mdot
.81619 .34981 Mdot
.8181 .33913 Mdot
.82 .34735 Mdot
.8219 .32925 Mdot
.82381 .34544 Mdot
.82571 .34088 Mdot
.82762 .35426 Mdot
.82952 .31606 Mdot
.83143 .42151 Mdot
.83333 .2646 Mdot
.83524 .29629 Mdot
.83714 .36683 Mdot
.83905 .34608 Mdot
.84095 .35168 Mdot
.84286 .33528 Mdot
.84476 .3437 Mdot
.84667 .45648 Mdot
.84857 .36555 Mdot
.85048 .32969 Mdot
.85238 .43382 Mdot
.85429 .35627 Mdot
.85619 .33236 Mdot
.8581 .3282 Mdot
.86 .37491 Mdot
.8619 .30708 Mdot
.86381 .24605 Mdot
.86571 .48132 Mdot
.86762 .31766 Mdot
.86952 .31482 Mdot
.87143 .29671 Mdot
.87333 .37852 Mdot
.87524 .36752 Mdot
.87714 .38743 Mdot
.87905 .26278 Mdot
.88095 .37108 Mdot
.88286 .38402 Mdot
.88476 .26171 Mdot
.88667 .29149 Mdot
.88857 .34077 Mdot
.89048 .32513 Mdot
.89238 .32351 Mdot
.89429 .33856 Mdot
.89619 .26858 Mdot
.8981 .3979 Mdot
.9 .2457 Mdot
.9019 .41251 Mdot
.90381 .31448 Mdot
.90571 .27542 Mdot
.90762 .32446 Mdot
.90952 .37195 Mdot
.91143 .45816 Mdot
.91333 .25514 Mdot
.91524 .43127 Mdot
.91714 .34407 Mdot
.91905 .2453 Mdot
.92095 .23319 Mdot
.92286 .38046 Mdot
.92476 .25163 Mdot
.92667 .303 Mdot
.92857 .35718 Mdot
.93048 .36903 Mdot
.93238 .26288 Mdot
.93429 .31439 Mdot
.93619 .31905 Mdot
.9381 .3716 Mdot
.94 .27201 Mdot
.9419 .26312 Mdot
.94381 .35167 Mdot
.94571 .24829 Mdot
.94762 .26572 Mdot
.94952 .30439 Mdot
.95143 .27251 Mdot
.95333 .36259 Mdot
.95524 .39544 Mdot
.95714 .28739 Mdot
.95905 .28644 Mdot
.96095 .31019 Mdot
.96286 .39137 Mdot
.96476 .31458 Mdot
.96667 .24597 Mdot
.96857 .42737 Mdot
.97048 .34428 Mdot
.97238 .30639 Mdot
.97429 .25179 Mdot
.97619 .40495 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`0Tooooo`;o0000?Oooool2o`0006cooooo0_l0001Yooooo`001?l00002ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool09?ooool2o`0003gooooo0_l0001Aooooo`;o00006Oooool2o`0000Sooooo0_l0
001Oooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00omgMgOo<S8booooo`04ooooo`?o0000AOooool2o`0000oooooo0_l0000Jooooo`;o0000@_oo
ool2o`0000Sooooo0_l0000Aooooo`;o00001_ooool2o`00043ooooo0_l0000Mooooo`001_ooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0AOooool2o`0000?ooooo0_l0000:ooooo`;o0000
3_ooool2o`000003ooooool0003o000000Oooooo0_l0001<ooooo`;o00004Oooool2o`0004Sooooo
0_l0000Mooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04[ooooo0_l00005ooooo`;o0000
2oooool2o`0000Kooooo0_l000000ooooooo0000o`00001^ooooo`;o0000HOooool000Kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo057ooooo0_l0000;ooooo`;o0000@_ooool2o`0001?o
oooo0_l0000Jooooo`;o00001?ooool2o`00067ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o00004Oooool2o`00
00Wooooo0_l0000Nooooo`;o00001Oooool2o`0004kooooo0_l0000>ooooo`;o00003?ooool2o`00
00Gooooo0_l0000Jooooo`;o0000=Oooool2o`0000[ooooo0_l00004ooooo`;o00003Oooool2o`00
00oooooo000Yooooo`;o00002_ooool2o`0000Cooooo0ol00009ooooo`;o00003oooool2o`0000go
oooo0_l00005ooooo`Co00002Oooool2o`0001kooooo0_l0000>ooooo`;o00004Oooool2o`0001co
oooo0_l0000Aooooo`;o00001oooool2o`0003cooooo0_l0000:ooooo`;o00001?ooool2o`0000Oo
oooo0_l00004ooooo`;o00003oooool002Wooooo00?o0000ooooooooool02?ooool3o`0000Cooooo
0_l0000>ooooo`;o00002oooool2o`0000Gooooo0_l0000?ooooo`;o00002Oooool2o`0000Sooooo
0_l0000Dooooo`;o00003_ooool2o`0000Cooooo0_l00002ooooo`;o0000>?ooool2o`0000Oooooo
0_l0000Mooooo`;o0000<Oooool2o`0000Gooooo0_l00007ooooo`;o00003?ooool002Wooooo00?o
0000ooooooooool02?ooool2o`0000oooooo0_l00004ooooo`;o00003oooool2o`000003ooooool0
003o000000_ooooo0_l0000Fooooo`?o0000:_ooool2o`0000;ooooo0_l0000Fooooo`;o0000B?oo
ool2o`0002gooooo0_l00002ooooo`;o00003_ooool2o`0000cooooo000Yooooo`03o`000?oooooo
oooo01Wooooo0_l0000Eooooo`;o00003_ooool2o`0001Kooooo0_l0000Gooooo`;o0000;_ooool2
o`0007Oooooo0_l0000Pooooo`00:Oooool00ol0003oooooooooo`0:ooooo`;o00005_ooool2o`00
00;ooooo0_l00006ooooo`;o00001_ooool2o`0000gooooo0_l00004ooooo`;o00009?ooool2o`00
00oooooo0_l00007ooooo`;o00005_ooool2o`0001Gooooo0_l0000=ooooo`;o0000A_ooool2o`00
02Wooooo000Yooooo`;o00002?ooool2o`000003ooooool0003o000001Kooooo0_l00002ooooo`;o
00001_ooool2o`0000?ooooo0_l000000ooooooo0000o`00000=ooooo`;o00001?ooool2o`0003Go
oooo0ol00006ooooo`;o00005_ooool2o`0001Gooooo0_l0000=ooooo`;o00006oooool2o`0001Wo
oooo0_l0000<ooooo`Co00003Oooool2o`000003ooooool0003o000001Oooooo000Yooooo`03o`00
0?oooooooooo00Oooooo0_l0000Zooooo`;o00000oooool2o`0000Cooooo0_l0000Booooo`;o0000
00?oooooo`000?l00000;?ooool2o`0000oooooo0_l0000:ooooo`;o00008Oooool2o`0000Sooooo
0_l0000Gooooo`;o00006Oooool2o`0000cooooo0_l0000?ooooo`;o000000?oooooo`000?l00000
0_l0000Eooooo`00:Oooool00ol0003oooooooooo`0=ooooo`;o00004Oooool2o`0000kooooo1?l0
00001?l@413oooooooooooo^k^h4o`0000;ooooo0_l000001?lb<S;o0000oc8b<_o^k^h>ooooo`;o
000000?oooooo`000?l000005?ooool7o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool3o`0000Cooooo0_l00003ooooo`Co00001_ooool0
1?nHV9So410@o`000?lb<S82o`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01?ooool2o`0000;ooooo0_l00004ooooo`;o00006_ooool2o`000009
oa0@4?l0003o0000ooooooo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0Iooooo`;o00003_ooool3o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool00ol0003oooooooooo`02
o`0000?ooooo0_l00006ooooo`;o00002Oooool2o`0000Kooooo0_l0000@ooooo`03o`000?oooooo
oooo00;ooooo00?oMgMgoiRHV?ooool00_l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL09ooo
ool2o`000005oiRHV?l0003o0000oooooom4A4@00oooool01?mgMgOoV9RHoooooonHV9P2o`0000;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Cooooo`;o00001?ooool2o`0000Gooooo0_l00006oooo
o`03oa0@4?nj^[[ooooo00?o00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`08ooooo`;o00000_ooool2o`00017ooooo0_l0000:ooooo`0:o`000?oo
oooo0000o`000?ooooooMgMgoiRHV?ooooooV9RHogMgM`?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Iooooo`;o00003?ooool2o`0000;ooooo0_l000002?lb<S;ooooooooooomgMgOoV9RHoooooonH
V9SoMgMg0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000Yooooo`03o`000?oooooooooo
00?o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00002?ooool2o`0000_ooooo0_l0000;oooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo
ooooooooool@41004oooool2o`0000gooooo0_l00003ooooo`;o000000Coooooo`000?l0003ok^k^
1?ooool01?l@413oooooooooooooool2o`0000;ooooo00Go410@oooooooooooooooooa0@4007oooo
o`;o00008_ooool2o`0000?ooooo00Go410@o`000?l0003ooooooa0@4003ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool2o`00017ooooo0_l00007ooooo`Go00000oooool01Ol@413ooooooooo
oooooooo410@00;o000000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0Jooooo`;o0000
2Oooool2o`0000;ooooo0ol00002ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@00?ooooo000Yooooo`;o00000_ooool2o`0000Oooooo0_l00002ooooo`;o
00005Oooool2o`0000_ooooo00?o0000ooooooooool00ol00003ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`0Aooooo`;o00003Oooool4o`000003ooooool0003o0000
00;ooooo00?oV9RHob4Q8Oo^k^h00oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00002
ooooo`03o`000?oooooooooo00Gooooo0_l0000Jooooo`;o00001_ooool00onYZJWo410@ooooo`02
ooooo`?o000000?oooooo`000?ooool00_ooool01Ol0003ooooooooooooooooo000001Sooooo0_l0
0007ooooo`;o00001Oooool2o`000003ooooool0003ooooo00?ooooo00Co0000oooooooooooooooo
0ol000000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo01[ooooo0_l0000>ooooo`05ogMg
Molb<S;oooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool00Oooool002Wooooo00?o0000ooooooooool0:?ooool4o`0000Kooooo00?o0000oooooooo
ool00ol00003ooooo`04o`000?ooooooooooooooo`;o00000_ooool00ol0003oooooooooo`0>oooo
o`;o00004_ooool2o`0000Kooooo00CoMgMgofIVI_oooooooooo0_l00003ooooo`;o00000_ooool2
o`0000;ooooo00?o0000ooooooooool08Oooool2o`0000Gooooo00?o410@o`000?nj^[X00oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00000Hooooo`;o0000
1oooool2o`0000Gooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`00000Yooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`00
:Oooool3o`0000;ooooo0_l0000@ooooo`;o00003Oooool2o`0000?ooooo1?l00006ooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`;o00000_ooool00ol@413o
ooooooooo`0>ooooo`;o00006oooool00ol0003oooooooooo`02o`0000;ooooo0_l00003ooooo`05
oa0@4?ooooooooooooooool@4100:oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41000oooool00ol@413oooooooooo`02o`0002Wooooo00?oMgMgolc<c?l000001?ooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@400Yooooo`04o`00
0?ooooooooooooooo`;o000000?ooooooa0@4?ooool00_ooool01Ol@413ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool00Oooool002Wooooo0ol00002ooooo`;o00004?ooool2o`000003
ooooool0003o000000[ooooo0_l0000=ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:Oooool01Ol0003o^[ZjoooooonH
V9So410@00?ooooo00?oMgMgoiRHV?ooool00_l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
5_ooool2o`00013ooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool00omgMgOoV9RHooooo`02o`0000Oooooo0_l0000Pooooo`03onk^k_m4A4Co0000
00?ooooo0_l000001?nHV9SooooooiRHV?mgMgL2ooooo`;o000000CoV9RHoooooonHV9SoMgMg:Ooo
ool00ol0003oooooooooo`03o`000006oooooomgMgOoV9RHoooooonHV9SoMgMg0oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo000Yooooo`03o`000?oooooooooo01Oooooo0_l0000:ooooo`;o
00001?ooool2o`0000Gooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`;o00000oooool2o`0001kooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01Kooooo0_l0000@ooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`;o00008Ooo
ool00omgMgOo0000ooooo`02ooooo`Co000000Co<S8bonk^k_oooooooooo0_l000001?lb<S;o0000
oc8b<_o^k^hFooooo`;o00004Oooool5o`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool002Wooooo0_l00007ooooo`;o00008Oooool2o`00
01Sooooo0_l00003ooooo`;o00000oooool2o`0005Gooooo0_l0000Zooooo`?o00001_ooool2o`00
01Cooooo0_l0000@ooooo`;o00003oooool2o`0002Sooooo000Yooooo`03o`000?oooooooooo00Ko
oooo0_l0000kooooo`;o00003?ooool2o`0000Sooooo0_l0000<ooooo`;o00007?ooool2o`0000ko
oooo0_l0000;ooooo`;o0000:_ooool3o`0000Kooooo0_l0000Vooooo`;o00002_ooool2o`0002go
oooo000Yooooo`03o`000?oooooooooo01;ooooo0_l0000mooooo`;o00002?ooool2o`0000cooooo
0_l0000Aooooo`;o00002Oooool2o`0000_ooooo0_l000000ooooooo0000o`000003ooooo`;o0000
Koooool2o`0002gooooo000Yooooo`03o`000?oooooooooo00?ooooo0_l0000=ooooo`;o0000>_oo
ool2o`0002cooooo0_l0000Fooooo`;o00001_ooool2o`00023ooooo0_l0001Oooooo`;o00001Ooo
ool2o`0001Cooooo000Yooooo`03o`000?oooooooooo00?ooooo0_l0000Pooooo`;o00009oooool2
o`0002cooooo0_l0000/ooooo`;o00002Oooool2o`0000Oooooo0_l0000Dooooo`;o0000=?ooool2
o`0001?ooooo0_l00005ooooo`;o00001Oooool2o`0000gooooo000Qoooooooo0000A?l00004oooo
o`00:Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`06ooooo`;o000000?oooooo`000?ooool02_ooool00ol0003o
ooooooooo`0:ooooo`04o`000?oooooo0000o`0000Sooooo0_l0000:ooooo`03o`000?oooooooooo
00;o00001oooool00ol0003oooooooooo`02ooooo`;o00001_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool2o`0000_ooooo0ol00003oooo
o`;o00001?ooool00ol0003oooooooooo`02o`0000Oooooo00?o0000ooooooooool02Oooool2o`00
00Kooooo0_l00003ooooo`03o`000?oooooooooo00;ooooo0_l00005ooooo`04o`000?oooooooooo
ooooo`;o00001_ooool00ol0003oooooooooo`03ooooo`;o00001?ooool00ol0003oooooooooo`0:
ooooo`?o00002Oooool2o`0000Sooooo0ol00006ooooo`?o00000_ooool00ol0003oooooooooo`0:
ooooo`00:Oooool00ol0003oooooooooo`0Nooooo`;o00002oooool2o`0000Wooooo0_l00002oooo
o`03o`000?oooooooooo01Kooooo0_l0000=ooooo`;o00003?ooool2o`0000Kooooo00?o0000oooo
ooooool04Oooool2o`0000kooooo0_l0000<ooooo`;o00000oooool2o`0000Cooooo00?o0000oooo
ooooool03?ooool2o`0000oooooo0_l00008ooooo`;o000000?oooooo`000?l000001_ooool2o`00
00Kooooo00?o0000ooooooooool02_ooool2o`0000_ooooo0_l00009ooooo`;o00002?ooool2o`00
00Sooooo0_l00002ooooo`03o`000?oooooooooo00[ooooo000Yooooo`03o`000?oooooooooo01ko
oooo0_l00007ooooo`;o00003Oooool3o`0002Cooooo0_l0000;ooooo`;o00004Oooool2o`0000go
oooo0_l0000]ooooo`;o00001oooool3o`0001[ooooo0ol0000Aooooo`;o00000oooool2o`0000?o
oooo0_l0000;ooooo`;o00005?ooool2o`0001Sooooo000Yooooo`03o`000?oooooooooo013ooooo
0_l0000Eooooo`;o00003_ooool2o`0002Cooooo0_l0000;ooooo`;o00004Oooool3o`0001oooooo
0_l00007ooooo`;o00000oooool2o`0000cooooo0_l00008ooooo`;o00006_ooool2o`0001;ooooo
0_l00003ooooo`;o00006?ooool2o`0000cooooo0_l0000Hooooo`00:Oooool6o`0000gooooo0_l0
000Oooooo`;o00003_ooool2o`0003_ooooo0_l0000=ooooo`;o00004?ooool2o`0000Oooooo0ol0
0002ooooo`?o00006_ooool3o`0000Oooooo0_l0000mooooo`?o00000_ooool2o`0002;ooooo000Y
ooooo`03o`000?oooooo000000?o00007?ooool2o`00013ooooo0_l0000>ooooo`;o00002Oooool2
o`0001Kooooo0_l0000=ooooo`;o00006?ooool2o`0000Oooooo0_l0000Aooooo`;o00000oooool2
o`0000;ooooo0_l0000=ooooo`;o00001Oooool5o`0000Gooooo1?l0000Wooooo`;o00001oooool2
o`000003ooooool0003o000000Sooooo0_l00003ooooo`;o00008_ooool002Wooooo00?o0000oooo
ooooool05?ooool2o`0000Wooooo0_l0000Pooooo`;o00002Oooool2o`0000kooooo0_l00006oooo
o`;o00003Oooool2o`0001kooooo0_l000000ooooooo0000o`000004o`0001Kooooo0_l0000=oooo
o`;o00001Oooool2o`0000Kooooo1?l0000Jooooo`;o00000_ooool2o`0000Wooooo0_l00007oooo
o`Go0000<Oooool002Wooooo00?o0000ooooooooool00_ooool2o`00013ooooo0_l0000Booooo`;o
00005oooool2o`0000gooooo0_l00006ooooo`;o00000_ooool2o`0001Sooooo0_l00009ooooo`;o
00004?ooool2o`0000?ooooo1?l0000;ooooo`;o00009oooool2o`0001cooooo0_l00002ooooo`;o
00004?ooool2o`0000;ooooo0_l0000booooo`00:Oooool00ol0003oooooooooo`02ooooo`;o0000
2?ooool3o`0001Wooooo1?l00003ooooo`;o00007oooool2o`0000;ooooo0_l00002ooooo`;o0000
7?ooool2o`0000Wooooo0_l0000<ooooo`;o00005_ooool2o`0004kooooo0_l00003ooooo`;o0000
1_ooool2o`0000kooooo0_l0000Vooooo`00:Oooool2o`0000gooooo0ol0000Kooooo`;o00000ooo
ool2o`0002?ooooo0_l0000iooooo`;o00003?ooool2o`0000gooooo0_l00007ooooo`;o0000;Ooo
ool2o`0000;ooooo0_l0000=ooooo`Co000000?oooooo`000?l000000_l0000Booooo`Co00009_oo
ool002Wooooo00?o0000ooooooooool0=Oooool2o`0001Cooooo0_l00010ooooo`Co00003?ooool3
o`0000Oooooo0_l00002ooooo`?o00001oooool2o`0000Cooooo0_l0000Qooooo`;o00001?ooool2
o`0000;ooooo0_l0000?ooooo`;o00000oooool2o`0000;ooooo1?l0000<ooooo`;o00002?ooool2
o`0000oooooo0_l0000=ooooo`00:Oooool00ol0003oooooooooo`0Mooooo`;o00003_ooool2o`00
00Kooooo0_l00007ooooo`;o00002oooool2o`0000gooooo0_l0000Aooooo`;o00007_ooool2o`00
00oooooo0_l00007ooooo`;o00000_ooool2o`0000kooooo0_l0000Qooooo`;o00007?ooool4o`00
00;ooooo1?l0000Fooooo`;o00003oooool2o`0000gooooo000Yooooo`03o`000?oooooooooo01go
oooo0_l0000>ooooo`;o00000oooool2o`0000[ooooo0_l0000Jooooo`;o00002oooool2o`0000Co
oooo0_l0000Iooooo`;o00006Oooool2o`0001?ooooo0_l0000eooooo`;o00001Oooool2o`0000?o
oooo0ol00005ooooo`;o00007oooool2o`0001Kooooo000Yooooo`03o`000?oooooooooo00Gooooo
0_l0000:ooooo`;o00001oooool2o`0001Kooooo0_l00007ooooo`?o00002_ooool2o`0001Oooooo
0_l00004ooooo`;o00007oooool2o`00013ooooo0_l00007ooooo`;o00004oooool2o`0000;ooooo
0_l0000[ooooo`;o00001?ooool2o`0000Gooooo0_l000000ooooooo0000o`000002o`0000;ooooo
0_l00002ooooo`;o00007oooool2o`0001Kooooo000Yooooo`;o00001_ooool2o`0000[ooooo0_l0
0007ooooo`;o00007oooool3o`0000[ooooo0_l0000Fooooo`?o00003?ooool2o`0001Wooooo0_l0
000>ooooo`;o00008?ooool2o`00013ooooo0_l0000Iooooo`;o00002Oooool2o`0000?ooooo0_l0
0004ooooo`;o00001_ooool2o`0001Kooooo0_l0000Kooooo`00:Oooool00ol0003oooooooooo`0b
ooooo`;o0000;?ooool2o`0000Gooooo0_l00006ooooo`;o00002Oooool2o`0000kooooo0_l0000j
ooooo`;o00001_ooool2o`0000_ooooo0_l00008ooooo`;o00003Oooool2o`00017ooooo0_l0000F
ooooo`;o00006oooool002Wooooo00Co0000ooooool0003o0000<Oooool2o`0001Wooooo0_l0000H
ooooo`;o00004Oooool2o`0001Cooooo0_l0000dooooo`;o00004oooool2o`0000Sooooo0_l0000@
ooooo`;o0000;_ooool2o`0001?ooooo000Yooooo`04o`000?oooooo0000o`0003cooooo0_l0000>
ooooo`;o0000<?ooool2o`0000oooooo1?l0000Aooooo`;o00008Oooool2o`00013ooooo0_l0000D
ooooo`;o00001Oooool2o`0000Wooooo0_l000000ooooooo0000o`000007ooooo`;o00005oooool2
o`0001?ooooo000Yooooo`03o`000?oooooooooo00Cooooo0_l0000Fooooo`;o00003oooool2o`00
00kooooo0_l0000Dooooo`;o0000:_ooool2o`0000oooooo1?l0000Aooooo`;o00003oooool2o`00
013ooooo0_l0000<ooooo`Ko00000oooool2o`0000oooooo0_l0000@ooooo`;o000000?oooooo`00
0?l000001oooool2o`00013ooooo0_l0000Jooooo`00:Oooool2o`0000Gooooo0_l0000Aooooo`;o
00000oooool2o`0000oooooo0_l0000Tooooo`;o00002_ooool2o`0002oooooo0_l0000Tooooo`;o
00002?ooool2o`0000cooooo0_l00006ooooo`Co00001Oooool2o`0002oooooo0_l00007ooooo`;o
00001Oooool4o`0001Sooooo000Yooooo`03o`000?oooooooooo01;ooooo0_l00003ooooo`;o0000
A_ooool2o`0001Gooooo0_l00018ooooo`;o00003?ooool2o`0000Sooooo0_l0000_ooooo`;o0000
1Oooool2o`0000Oooooo0_l00007ooooo`;o00006?ooool000Kooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo01;ooooo0_l0001Rooooo`?o00000_ooool2o`0002;ooooo0_l00007ooooo`;o
0000Goooool2o`0000;ooooo0_l0000]ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo01Kooooo0_l00002ooooo`;o00001_ooool2o`0001Kooooo0_l0000koooo
o`;o00000_ooool2o`0002;ooooo0_l00007ooooo`;o00006oooool2o`0004Kooooo0_l0000>oooo
o`;o00007Oooool000Kooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^
00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Fooooo`;o00000_ooool2o`00
00Kooooo0_l0000<ooooo`;o00002?ooool2o`0000Oooooo0_l0000oooooo`;o00002oooool2o`00
03;ooooo0_l0000Looooo`;o0000:oooool2o`0000_ooooo0_l0000Mooooo`001_ooool01Ol0003o
oooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04oooo
o`?o0000<?ooool2o`00017ooooo0_l0000looooo`;o000000?oooooo`000?l000002oooool2o`00
02Oooooo0_l000000ooooooo0000o`00000Mooooo`;o00001Oooool2o`0002[ooooo0ol0000Zoooo
o`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool07?ooool2o`0004Gooooo0_l0000L
ooooo`;o000000Coooooo`000?l0003ooooo0_l0000aooooo`;o000000?oooooo`000?l000000_l0
0008ooooo`;o00004Oooool2o`0000Gooooo0_l0000<ooooo`;o00007?ooool2o`0001Wooooo0_l0
000@ooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`07ooooo`;o00007Oooool2o`00033ooooo0_l0000Cooooo`;o00008_oo
ool2o`0000cooooo0_l0000Xooooo`;o00002?ooool2o`0002Kooooo0_l0000eooooo`Co00004?oo
ool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
1?ooool00ol0003oooooooooo`07ooooo`;o00006Oooool2o`0000Oooooo0_l0000Eooooo`;o0000
5?ooool2o`0001Cooooo0_l0000Jooooo`;o00004oooool2o`0000Wooooo0_l0001cooooo`;o0000
4Oooool2o`0001;ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@
o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo00Wooooo0_l0000:ooooo`;o
000000?oooooo`000?l000001oooool2o`0000_ooooo0_l00008ooooo`;o00003?ooool2o`0001co
oooo0_l0000Jooooo`;o00002?ooool2o`0001Cooooo0_l0001cooooo`;o00009Oooool002Wooooo
0_l00005ooooo`;o00000oooool2o`0000Cooooo0_l00004ooooo`;o00005oooool2o`0001Kooooo
0_l0000nooooo`;o00000_ooool2o`0000gooooo0_l0002Dooooo`;o00002oooool002Wooooo00?o
0000ooooooooool01?ooool2o`000003ooooool0003o000000Kooooo0_l0001Kooooo`;o00001_oo
ool2o`00013ooooo0_l0000Aooooo`;o00000_ooool2o`00093ooooo0_l0000;ooooo`00:Oooool0
0ol0003oooooooooo`07ooooo`;o00000_ooool2o`00033ooooo0_l0000]ooooo`;o00001_ooool2
o`0002Oooooo0_l0000Aooooo`;o0000R_ooool002Wooooo00?o0000ooooooooool02oooool2o`00
01[ooooo0_l0000Dooooo`;o000000?oooooo`000?l000001oooool2o`00013ooooo0ol00018oooo
o`;o00002?ooool2o`0002oooooo0_l0000:ooooo`;o0000:?ooool2o`0002?ooooo000Yooooo`03
o`000?oooooooooo02Oooooo0_l0000Gooooo`;o00001?ooool5o`00013ooooo0ol000000ooooooo
0000o`00000Fooooo`;o0000;Oooool2o`0003Wooooo0_l0000:ooooo`;o00000_ooool2o`0002Co
oooo0_l0000Sooooo`00:Oooool2o`0004Oooooo0ol0000Fooooo`;o00002oooool2o`0000Wooooo
0_l0001^ooooo`;o00002?ooool2o`0004Wooooo000Yooooo`03o`000?oooooooooo06Gooooo0_l0
0005ooooo`;o0000Doooool2o`0002Cooooo1?l0000Eooooo`;o0000>_ooool002Wooooo00?o0000
ooooooooool08?ooool2o`0003Oooooo0_l00003ooooo`;o00001Oooool2o`0001kooooo0_l0000T
ooooo`;o00005?ooool2o`0001Wooooo0_l0000;ooooo`;o00001oooool2o`0000cooooo0_l0000j
ooooo`00:Oooool00ol0003oooooooooo`0Cooooo`;o00002oooool2o`0002kooooo0_l00007oooo
o`;o00000oooool2o`0002Gooooo0_l00005ooooo`;o00007Oooool2o`0000Oooooo0_l0000Voooo
o`;o00003_ooool2o`0000Cooooo0_l0000hooooo`;o00003_ooool002Wooooo00?o0000oooooooo
ool03?ooool2o`0000Gooooo0_l0000kooooo`;o0000>_ooool4o`00027ooooo1Ol0000Pooooo`;o
00005?ooool2o`0002gooooo0_l0000?ooooo`;o00003_ooool002Wooooo0_l0000=ooooo`;o0000
9_ooool2o`0004Cooooo0_l0000Booooo`;o00008Oooool4o`0000Cooooo0_l00003ooooo`;o0000
5_ooool2o`0000cooooo1?l0000Oooooo`;o00004_ooool2o`0001oooooo000Yooooo`03o`000?oo
oooooooo03Cooooo0_l0000looooo`;o00001_ooool2o`0003gooooo0_l00003ooooo`;o00009?oo
ool4o`0001oooooo0_l0000cooooo`00:Oooool00ol0003oooooooooo`1booooo`;o0000b?ooool0
02Wooooo00?o0000ooooooooool05Oooool2o`000?oooooo9_ooool002Wooooo00?o0000oooooooo
ool05Oooool2o`0005[ooooo0_l00039ooooo`00:Oooool2o`0006oooooo0_l000000ooooooo0000
o`000027ooooo`;o0000@?ooool002Wooooo00?o0000ooooooooool0HOooool2o`0000_ooooo0_l0
000Booooo`;o0000?_ooool2o`0001Wooooo0_l0000Kooooo`;o0000@?ooool000kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo
00?o0000ooooooooool0HOooool2o`0001oooooo0_l0000Cooooo`;o0000:Oooool2o`0001Wooooo
0_l0000<ooooo`;o00006?ooool2o`0003Gooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1eooooo`;o0000
8?ooool2o`0005;ooooo0_l0000Hooooo`;o00004oooool2o`00023ooooo000>ooooo`05oa0@4?oo
ooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`?o0000MOooool2o`000:?ooooo
0_l0000Pooooo`003_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolmooooo`00
3_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`3cooooo`;o0000Aoooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0loooool2o`0004Oooooo000>ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`00
0?oooooooooo0<oooooo0_l0000jooooo`;o0000;oooool002Wooooo00?o0000ooooooooool07Ooo
ool2o`0000cooooo0_l0000<ooooo`;o0000U?ooool2o`0003[ooooo0_l0000_ooooo`00:Oooool0
0ol0003oooooooooo`0Mooooo`;o00003?ooool2o`0000cooooo0_l0003oooooo`;ooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`001_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooo
oooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000
oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool0
1_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go
0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooo
oooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413o
oooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooo
ocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006oooo
o`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool001oooooo1?l0
00000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo
00Gooooo0ol0003oooooocgooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool001oooooo00?oEEEEofIVI_l00000oooooom7oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .39267 Mdot
.02762 .33322 Mdot
.02952 .31158 Mdot
.03143 .33959 Mdot
.03333 .34903 Mdot
.03524 .24925 Mdot
.03714 .27961 Mdot
.03905 .22816 Mdot
.04095 .41245 Mdot
.04286 .33994 Mdot
.04476 .2542 Mdot
.04667 .26027 Mdot
.04857 .34436 Mdot
.05048 .26426 Mdot
.05238 .24438 Mdot
.05429 .25748 Mdot
.05619 .26202 Mdot
.0581 .35599 Mdot
.06 .31109 Mdot
.0619 .26132 Mdot
.06381 .33879 Mdot
.06571 .25582 Mdot
.06762 .24372 Mdot
.06952 .36817 Mdot
.07143 .36515 Mdot
.07333 .26444 Mdot
.07524 .28201 Mdot
.07714 .3355 Mdot
.07905 .2393 Mdot
.08095 .33607 Mdot
.08286 .3541 Mdot
.08476 .40594 Mdot
.08667 .26022 Mdot
.08857 .28003 Mdot
.09048 .38308 Mdot
.09238 .38391 Mdot
.09429 .38322 Mdot
.09619 .35473 Mdot
.0981 .23511 Mdot
.1 .30454 Mdot
.1019 .38867 Mdot
.10381 .35409 Mdot
.10571 .36297 Mdot
.10762 .40172 Mdot
.10952 .38136 Mdot
.11143 .34203 Mdot
.11333 .30606 Mdot
.11524 .43244 Mdot
.11714 .37507 Mdot
.11905 .26819 Mdot
.12095 .43467 Mdot
.12286 .27151 Mdot
.12476 .45468 Mdot
.12667 .38488 Mdot
.12857 .37634 Mdot
.13048 .35709 Mdot
.13238 .22936 Mdot
.13429 .25667 Mdot
.13619 .43332 Mdot
.1381 .36899 Mdot
.14 .33097 Mdot
.1419 .44693 Mdot
.14381 .23611 Mdot
.14571 .33251 Mdot
.14762 .30566 Mdot
.14952 .37871 Mdot
.15143 .34601 Mdot
.15333 .2849 Mdot
.15524 .35479 Mdot
.15714 .38339 Mdot
.15905 .25476 Mdot
.16095 .31983 Mdot
.16286 .34102 Mdot
.16476 .34245 Mdot
.16667 .23639 Mdot
.16857 .28931 Mdot
.17048 .45482 Mdot
.17238 .30117 Mdot
.17429 .24789 Mdot
.17619 .33906 Mdot
.1781 .41301 Mdot
.18 .34949 Mdot
.1819 .32133 Mdot
.18381 .36594 Mdot
.18571 .24989 Mdot
.18762 .26813 Mdot
.18952 .35545 Mdot
.19143 .36138 Mdot
.19333 .27728 Mdot
.19524 .28089 Mdot
.19714 .36581 Mdot
.19905 .23092 Mdot
.20095 .26565 Mdot
.20286 .36162 Mdot
.20476 .29422 Mdot
.20667 .2214 Mdot
.20857 .272 Mdot
.21048 .43511 Mdot
.21238 .46466 Mdot
.21429 .25701 Mdot
.21619 .39889 Mdot
.2181 .31619 Mdot
.22 .24475 Mdot
.2219 .39879 Mdot
.22381 .40989 Mdot
.22571 .30383 Mdot
.22762 .2676 Mdot
.22952 .26838 Mdot
.23143 .26388 Mdot
.23333 .38144 Mdot
.23524 .30379 Mdot
.23714 .34018 Mdot
.23905 .41142 Mdot
.24095 .34475 Mdot
.24286 .46275 Mdot
.24476 .26476 Mdot
.24667 .31277 Mdot
.24857 .33186 Mdot
.25048 .36724 Mdot
.25238 .35366 Mdot
.25429 .33687 Mdot
.25619 .45933 Mdot
.2581 .26044 Mdot
.26 .23265 Mdot
.2619 .38474 Mdot
.26381 .34063 Mdot
.26571 .32701 Mdot
.26762 .23724 Mdot
.26952 .39378 Mdot
.27143 .31261 Mdot
.27333 .23792 Mdot
.27524 .3993 Mdot
.27714 .29651 Mdot
.27905 .24008 Mdot
.28095 .33079 Mdot
.28286 .23836 Mdot
.28476 .38598 Mdot
.28667 .27477 Mdot
.28857 .34388 Mdot
.29048 .23989 Mdot
.29238 .26038 Mdot
.29429 .41133 Mdot
.29619 .30159 Mdot
.2981 .34251 Mdot
.3 .25908 Mdot
.3019 .30012 Mdot
.30381 .28094 Mdot
.30571 .39835 Mdot
.30762 .28736 Mdot
.30952 .36398 Mdot
.31143 .46208 Mdot
.31333 .32747 Mdot
.31524 .34971 Mdot
.31714 .37688 Mdot
.31905 .32265 Mdot
.32095 .24791 Mdot
.32286 .34463 Mdot
.32476 .23267 Mdot
.32667 .34374 Mdot
.32857 .37746 Mdot
.33048 .35551 Mdot
.33238 .33498 Mdot
.33429 .25568 Mdot
.33619 .40746 Mdot
.3381 .40853 Mdot
.34 .37389 Mdot
.3419 .39208 Mdot
.34381 .29649 Mdot
.34571 .41656 Mdot
.34762 .35554 Mdot
.34952 .36211 Mdot
.35143 .32733 Mdot
.35333 .26957 Mdot
.35524 .34478 Mdot
.35714 .34749 Mdot
.35905 .25725 Mdot
.36095 .27101 Mdot
.36286 .22136 Mdot
.36476 .24265 Mdot
.36667 .28352 Mdot
.36857 .23973 Mdot
.37048 .33126 Mdot
.37238 .33816 Mdot
.37429 .32012 Mdot
.37619 .39978 Mdot
.3781 .32102 Mdot
.38 .42178 Mdot
.3819 .24827 Mdot
.38381 .40137 Mdot
.38571 .39514 Mdot
.38762 .34165 Mdot
.38952 .46083 Mdot
.39143 .2975 Mdot
.39333 .32846 Mdot
.39524 .45592 Mdot
.39714 .23053 Mdot
.39905 .43918 Mdot
.40095 .2663 Mdot
.40286 .3646 Mdot
.40476 .31261 Mdot
.40667 .33277 Mdot
.40857 .32381 Mdot
.41048 .32074 Mdot
.41238 .31264 Mdot
.41429 .33025 Mdot
.41619 .34316 Mdot
.4181 .39886 Mdot
.42 .26261 Mdot
.4219 .24057 Mdot
.42381 .3418 Mdot
.42571 .2699 Mdot
.42762 .26032 Mdot
.42952 .27656 Mdot
.43143 .30869 Mdot
.43333 .4166 Mdot
.43524 .28086 Mdot
.43714 .39403 Mdot
.43905 .33226 Mdot
.44095 .40832 Mdot
.44286 .30662 Mdot
.44476 .33033 Mdot
.44667 .28245 Mdot
.44857 .31811 Mdot
.45048 .43081 Mdot
.45238 .41501 Mdot
.45429 .41532 Mdot
.45619 .25755 Mdot
.4581 .29558 Mdot
.46 .34209 Mdot
.4619 .26844 Mdot
.46381 .24859 Mdot
.46571 .45532 Mdot
.46762 .28451 Mdot
.46952 .29706 Mdot
.47143 .33324 Mdot
.47333 .37112 Mdot
.47524 .29224 Mdot
.47714 .46084 Mdot
.47905 .35224 Mdot
.48095 .39309 Mdot
.48286 .27493 Mdot
.48476 .40002 Mdot
.48667 .44831 Mdot
.48857 .28176 Mdot
.49048 .41389 Mdot
.49238 .25364 Mdot
.49429 .39518 Mdot
.49619 .31741 Mdot
.4981 .30866 Mdot
.5 .3455 Mdot
.5019 .2508 Mdot
.50381 .23244 Mdot
.50571 .43046 Mdot
.50762 .26651 Mdot
.50952 .32131 Mdot
.51143 .32756 Mdot
.51333 .25757 Mdot
.51524 .33823 Mdot
.51714 .35265 Mdot
.51905 .30058 Mdot
.52095 .22648 Mdot
.52286 .43756 Mdot
.52476 .37446 Mdot
.52667 .29171 Mdot
.52857 .41497 Mdot
.53048 .27913 Mdot
.53238 .34367 Mdot
.53429 .37436 Mdot
.53619 .29732 Mdot
.5381 .31107 Mdot
.54 .36472 Mdot
.5419 .28595 Mdot
.54381 .35956 Mdot
.54571 .36632 Mdot
.54762 .33727 Mdot
.54952 .36695 Mdot
.55143 .3445 Mdot
.55333 .33324 Mdot
.55524 .26635 Mdot
.55714 .43161 Mdot
.55905 .25967 Mdot
.56095 .24502 Mdot
.56286 .2312 Mdot
.56476 .33064 Mdot
.56667 .3155 Mdot
.56857 .37305 Mdot
.57048 .23489 Mdot
.57238 .26081 Mdot
.57429 .30185 Mdot
.57619 .25998 Mdot
.5781 .36733 Mdot
.58 .36053 Mdot
.5819 .40543 Mdot
.58381 .25275 Mdot
.58571 .42586 Mdot
.58762 .22983 Mdot
.58952 .42143 Mdot
.59143 .31231 Mdot
.59333 .42751 Mdot
.59524 .45897 Mdot
.59714 .3892 Mdot
.59905 .23654 Mdot
.60095 .35162 Mdot
.60286 .36292 Mdot
.60476 .30982 Mdot
.60667 .39718 Mdot
.60857 .39919 Mdot
.61048 .36693 Mdot
.61238 .28315 Mdot
.61429 .43361 Mdot
.61619 .27245 Mdot
.6181 .31702 Mdot
.62 .25991 Mdot
.6219 .24833 Mdot
.62381 .31445 Mdot
.62571 .46258 Mdot
.62762 .26474 Mdot
.62952 .34734 Mdot
.63143 .32154 Mdot
.63333 .2807 Mdot
.63524 .29565 Mdot
.63714 .34125 Mdot
.63905 .44547 Mdot
.64095 .36596 Mdot
.64286 .32173 Mdot
.64476 .24154 Mdot
.64667 .37283 Mdot
.64857 .23303 Mdot
.65048 .31548 Mdot
.65238 .32492 Mdot
.65429 .29859 Mdot
.65619 .25104 Mdot
.6581 .25516 Mdot
.66 .30829 Mdot
.6619 .29354 Mdot
.66381 .23927 Mdot
.66571 .32312 Mdot
.66762 .31192 Mdot
.66952 .33751 Mdot
.67143 .25549 Mdot
.67333 .37284 Mdot
.67524 .33331 Mdot
.67714 .31592 Mdot
.67905 .4403 Mdot
.68095 .26038 Mdot
.68286 .37343 Mdot
.68476 .33377 Mdot
.68667 .31079 Mdot
.68857 .2673 Mdot
.69048 .29213 Mdot
.69238 .32806 Mdot
.69429 .27105 Mdot
.69619 .35791 Mdot
.6981 .41187 Mdot
.7 .26078 Mdot
.7019 .43001 Mdot
.70381 .37179 Mdot
.70571 .35801 Mdot
.70762 .30933 Mdot
.70952 .33253 Mdot
.71143 .36036 Mdot
.71333 .25734 Mdot
.71524 .33931 Mdot
.71714 .4116 Mdot
.71905 .28715 Mdot
.72095 .34838 Mdot
.72286 .41032 Mdot
.72476 .28321 Mdot
.72667 .37434 Mdot
.72857 .25955 Mdot
.73048 .22604 Mdot
.73238 .27461 Mdot
.73429 .39526 Mdot
.73619 .25095 Mdot
.7381 .24129 Mdot
.74 .39721 Mdot
.7419 .43253 Mdot
.74381 .39461 Mdot
.74571 .40654 Mdot
.74762 .2605 Mdot
.74952 .25307 Mdot
.75143 .42401 Mdot
.75333 .24502 Mdot
.75524 .33779 Mdot
.75714 .44017 Mdot
.75905 .37399 Mdot
.76095 .26912 Mdot
.76286 .31638 Mdot
.76476 .43031 Mdot
.76667 .28061 Mdot
.76857 .30528 Mdot
.77048 .35446 Mdot
.77238 .38637 Mdot
.77429 .32529 Mdot
.77619 .34655 Mdot
.7781 .24961 Mdot
.78 .30804 Mdot
.7819 .42743 Mdot
.78381 .41875 Mdot
.78571 .45772 Mdot
.78762 .34617 Mdot
.78952 .25467 Mdot
.79143 .41462 Mdot
.79333 .28255 Mdot
.79524 .25924 Mdot
.79714 .25443 Mdot
.79905 .27336 Mdot
.80095 .24063 Mdot
.80286 .25419 Mdot
.80476 .27797 Mdot
.80667 .26103 Mdot
.80857 .32721 Mdot
.81048 .29314 Mdot
.81238 .45621 Mdot
.81429 .36284 Mdot
.81619 .40722 Mdot
.8181 .30585 Mdot
.82 .35027 Mdot
.8219 .29963 Mdot
.82381 .3644 Mdot
.82571 .26221 Mdot
.82762 .33054 Mdot
.82952 .26722 Mdot
.83143 .46079 Mdot
.83333 .24077 Mdot
.83524 .27642 Mdot
.83714 .38599 Mdot
.83905 .2671 Mdot
.84095 .2675 Mdot
.84286 .26241 Mdot
.84476 .35215 Mdot
.84667 .4382 Mdot
.84857 .24562 Mdot
.85048 .39 Mdot
.85238 .48353 Mdot
.85429 .39951 Mdot
.85619 .29458 Mdot
.8581 .408 Mdot
.86 .26752 Mdot
.8619 .25461 Mdot
.86381 .33406 Mdot
.86571 .44403 Mdot
.86762 .26466 Mdot
.86952 .32369 Mdot
.87143 .25179 Mdot
.87333 .41519 Mdot
.87524 .32463 Mdot
.87714 .27082 Mdot
.87905 .29917 Mdot
.88095 .38333 Mdot
.88286 .35635 Mdot
.88476 .31051 Mdot
.88667 .26595 Mdot
.88857 .3423 Mdot
.89048 .22788 Mdot
.89238 .27963 Mdot
.89429 .24015 Mdot
.89619 .35781 Mdot
.8981 .36993 Mdot
.9 .34357 Mdot
.9019 .39286 Mdot
.90381 .24539 Mdot
.90571 .22847 Mdot
.90762 .34784 Mdot
.90952 .26195 Mdot
.91143 .43264 Mdot
.91333 .30073 Mdot
.91524 .42906 Mdot
.91714 .2729 Mdot
.91905 .30156 Mdot
.92095 .29423 Mdot
.92286 .39983 Mdot
.92476 .30038 Mdot
.92667 .35622 Mdot
.92857 .28492 Mdot
.93048 .44193 Mdot
.93238 .34576 Mdot
.93429 .28781 Mdot
.93619 .37635 Mdot
.9381 .34864 Mdot
.94 .28319 Mdot
.9419 .3181 Mdot
.94381 .38543 Mdot
.94571 .32997 Mdot
.94762 .29363 Mdot
.94952 .24775 Mdot
.95143 .37627 Mdot
.95333 .34826 Mdot
.95524 .35969 Mdot
.95714 .34558 Mdot
.95905 .34408 Mdot
.96095 .26933 Mdot
.96286 .46672 Mdot
.96476 .27257 Mdot
.96667 .33546 Mdot
.96857 .42739 Mdot
.97048 .40492 Mdot
.97238 .35194 Mdot
.97429 .25794 Mdot
.97619 .31137 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo03Oooooo0_l0000`ooooo`;o0000dOooool000Kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo03Oooooo0_l0000`ooooo`;o0000dOooool000Kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2Looooo`;o0000@Oooool2o`0003;ooooo0_l0
000Wooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^
kP09ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l0000Looooo`;o0000
5?ooool2o`0003gooooo0_l0000Vooooo`;o00005?ooool2o`0002_ooooo0_l0000booooo`;o0000
0oooool2o`0002;ooooo0006ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Q
onk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol000000ooooooo0000o`00000Looooo`;o0000
5?ooool2o`00017ooooo0_l0000Cooooo`;o00005Oooool2o`00027ooooo0_l0000Aooooo`;o0000
1_ooool2o`00017ooooo0_l0001Aooooo`;o00008_ooool000Kooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo01Cooooo0_l0000=ooooo`;o00001Oooool2o`0001cooooo0_l000000ooooooo
0000o`00000@ooooo`;o0000>?ooool2o`00017ooooo1?l00007ooooo`;o00003_ooool2o`0007Go
oooo0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool2o`0000Cooooo0_l0000=ooooo`;o
00001Oooool2o`0001oooooo2Ol0000Gooooo`;o0000?oooool2o`0000Oooooo0_l0000Cooooo`;o
0000B?ooool2o`0002Kooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o
^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0>oooo
o`;o0000?Oooool7o`0001Kooooo0ol0000?ooooo`;o0000A_ooool2o`0000Cooooo0_l0000Foooo
o`;o00004_ooool2o`0000Wooooo0_l0000Aooooo`;o00009_ooool000Kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000
ooooooooool01Oooool2o`0000?ooooo0_l0000_ooooo`;o0000;Oooool2o`00013ooooo0_l0000[
ooooo`;o00006Oooool2o`0001cooooo0_l00003ooooo`;o00003Oooool2o`0000Wooooo0_l00002
ooooo`;o00004?ooool2o`0002?ooooo000Yooooo`;o000000?oooooo`000?l000000oooool2o`00
00?ooooo0_l0000Qooooo`;o00003?ooool2o`0001oooooo0_l0000Aooooo`;o00006Oooool2o`00
01gooooo0_l0000Booooo`;o0000:?ooool2o`0000Kooooo0_l0000Dooooo`;o00004?ooool2o`00
00gooooo0_l0000Dooooo`00:Oooool00ol0003oooooooooo`02o`0002_ooooo0_l000000ooooooo
0000o`00000Zooooo`;o00004Oooool2o`0001Wooooo0_l0000:ooooo`;o00006?ooool2o`0000_o
oooo0_l00009ooooo`;o00005oooool2o`0000cooooo0_l0000Looooo`;o00005oooool2o`0001Co
oooo000Yooooo`03o`000?oooooooooo00?ooooo0_l00005ooooo`;o00007?ooool2o`0000Kooooo
0_l0000^ooooo`;o0000<Oooool2o`000003ooooool0003o000001Sooooo0_l0000Fooooo`;o0000
0oooool2o`0001;ooooo0_l00003ooooo`;o00002_ooool2o`000003ooooool0003o000000;o0000
4Oooool2o`000003ooooool0003o000002gooooo000Yooooo`03o`000?oooooooooo00?ooooo0_l0
00000ooooooo0000o`000002ooooo`;o00005?ooool2o`0000Kooooo0_l0000@ooooo`;o00009?oo
ool2o`0000Kooooo0_l0000Mooooo`;o00002_ooool2o`0000Gooooo0_l0000/ooooo`;o00000ooo
ool2o`0000_ooooo0_l0000:ooooo`;o00002_ooool2o`000003ooooool0003o000000;o00004Ooo
ool2o`0002;ooooo0_l0000<ooooo`00:Oooool00ol0003oooooooooo`04ooooo`Oo00001Oooool2
o`0000kooooo0_l0000Hooooo`;o00003?ooool2o`0000Wooooo1?l0000Aooooo`;o00005?ooool2
o`0000Oooooo0_l0000Aooooo`;o00003?ooool2o`0000?ooooo0ol0000<ooooo`;o00004_ooool2
o`0000Cooooo0_l00002ooooo`;o00000oooool2o`0000Cooooo0_l0000=ooooo`;o00000_ooool2
o`0001oooooo0_l0000Cooooo`;o00003?ooool002Wooooo0_l00005ooooo`Oo000000?oooooo`00
0?l000000_ooool2o`0002gooooo0_l00002ooooo`;o00000oooool2o`0000Wooooo1?l0000Uoooo
o`Co0000:?ooool2o`0000?ooooo0ol0000<ooooo`Co00004?ooool2o`0000Cooooo0_l00007oooo
o`;o00001?ooool2o`0000gooooo0_l00002ooooo`;o00001?ooool2o`0000Cooooo0_l00006oooo
o`;o00002oooool2o`00027ooooo000Yooooo`03o`000?oooooooooo00Gooooo0_l00005ooooo`;o
00003Oooool2o`0001Cooooo0_l00002ooooo`;o00001oooool3o`0000;ooooo0_l0000aooooo`;o
00001?ooool2o`0001[ooooo0_l0000=ooooo`;o00005Oooool2o`0001;ooooo0_l0000Zooooo`?o
000000?oooooo`000?l000000_l00003ooooo`;o000000?oooooo`000?l000001?ooool2o`0002So
oooo000Yooooo`03o`000?oooooooooo01_ooooo0_l0000Cooooo`Co000000So410@o`000?l0003o
k^k^oc8b<_l0003o<S8bonk^kP;ooooo0_l000001?lb<S;o0000oc8b<_o^k^hRooooo`;o000000?o
ooooo`000?l000000_ooool5o`0000?ooooo00Gok^k^o`000?l0003o<S8bonk^kP03ooooo`?o0000
00?o<S8bonk^k_ooool01_ooool2o`0000gooooo0_l0000=ooooo`;o000000KooooooiRHV?l@413o
0000oc8b<_o<c<`3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^01?ooooo1?l0000Cooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo0_l000001?oooooo0000o`000?l0
0004ooooo`;o00001?ooool2o`000003ooooool0003o0000017ooooo00GoA4A4o`000?l0003o<S8b
omgMg@02o`000005onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo000Yooooo`03o`000?oooooooooo01cooooo0_l0000Dooooo`03o`000?oooooooooo00;o
oooo00GoMgMgo`000?l0003oV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL08_ooool2
o`000003ooooool0003o000000;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool2o`000003oooooonHV9SoMgMg00Oooooo0_l0000Oooooo`05oa0@
4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgo`00
0?l0003oV9RHogMgM`0Eooooo`;o00002_ooool2o`0000Oooooo0_l00004ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00_ooool2o`000004oiRHV?ooooooV9RHogMgMa?ooooo0_l0000;ooooo`;o0000
2_ooool00omgMgOo<S8bo`000002o`000004oiRHV?ooooooV9RHogMgM`?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`00:Oooool00ol0003oooooooooo`0Looooo`;o00005?ooool3o`0000;o
oooo00Go410@o`000?l0003ooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41003Oooool2
o`0001_ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@ooooool0003o0000oa0@400>ooooo`;o00007?ooool01Ol0003ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@4002o`000003ooooool@413ooooo023ooooo0_l00005oooo
o`Go00000oooool01Ol@413ooooooooooooooooo410@00;ooooo0_l00003ooooo`03oa0@4?oooooo
oooo00?ooooo0_l0000Iooooo`;o00002oooool01?l0003oooooo`000?l00003ooooo`05oa0@4?oo
ooooooooooooool@41000oooool00ol@413oooooooooo`01ooooo`00:Oooool2o`0000;ooooo0_l0
000>ooooo`;o00007oooool3o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000003Oooool2o`0001cooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooool000000_l0000>ooooo`;o00003Oooool2o`00
00cooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Ko0000
ooooooooooooooooo`000?ooool2o`0002Gooooo00?oA4A4omgMgOooool00ol00002ooooo`05o`00
0?ooooooooooooooool000000oooool2o`0000;ooooo00?o0000ooooooooool00oooool2o`00017o
oooo0_l0000Booooo`05ogMgMolb<S;oooooooooool000000oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00Oooool002Wooooo00Co0000oooooooooooooooo0_l0000:
ooooo`;o00000_ooool2o`0001oooooo0ol00002ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000001;ooooo0_l0000Cooooo`;o00000oooool00omgMgOoIVIV
ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooooooool2o`00
0003ooooool0003o000000cooooo0_l0000;ooooo`;o00002oooool00ol@413o0000okZj^P03oooo
o`05o`000?ooooooooooooooool000000oooool2o`0000;ooooo00Co0000ooooool0003o00007?oo
ool2o`0000Oooooo00?ogMgMoeEEEOooool00ol00002ooooo`04o`000?ooooooooooooooo`?o0000
00?oooooo`000?l000000_ooool00ol0003oooooooooo`0Fooooo`;o00003Oooool3o`000004ob4Q
8Ol0003o<S8bolc<c0;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool002Wooooo00?o0000ooooooooool03Oooool2o`0001Oooooo0_l0000:oooo
o`?o00000_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
400Booooo`;o00004oooool2o`0000Cooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@
4?ooooooooooooooool@41000oooool2o`000003ooooool0003o000000Gooooo0_l00005ooooo`;o
00003oooool2o`0000Sooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@
00?ooooo0_l00002ooooo`03oa0@4?oooooooooo01gooooo0_l00008ooooo`03ogMgMoo<c<co0000
00Cooooo00Go410@oooooooooooooooooa0@4002o`000003ooooool@413ooooo00;ooooo00?o410@
ooooooooool08Oooool2o`0000;ooooo0ol00006ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@00?ooooo000Yooooo`03o`000?oooooooooo02Kooooo0_l0
0003ooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg01Cooooo0_l0000Cooooo`05o`000?nj^[[ooooooiRH
V?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`09ooooo`;o00005_ooool2o`0000Gooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo0_l0000:oooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL08oooool4o`0000;ooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool00ol0003ooooo
ooooo`0[ooooo`;o00000oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Cooooo0_l0000Cooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`;o00003oooool2o`0000[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Cooooo0_l00007
ooooo`;o00002oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?l0003ok^k^02Gooooo0_l00002ooooo`Co00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool2o`0003Oo
oooo0_l0001@ooooo`;o00000oooool2o`0000oooooo0_l0000Qooooo`;o00001_ooool2o`0000So
oooo0_l0000Tooooo`;o00003Oooool2o`0001?ooooo0_l00006ooooo`;o00005Oooool002Wooooo
00?o0000ooooooooool0=_ooool2o`0001Kooooo0_l0000Cooooo`;o00003Oooool2o`0001Cooooo
0_l00002ooooo`;o00004oooool2o`0001kooooo0_l00004ooooo`Co0000?Oooool2o`0000Gooooo
0_l0000<ooooo`;o00001_ooool2o`0001Gooooo000Yooooo`03o`000?oooooooooo02cooooo0_l0
000Pooooo`;o00001?ooool4o`0000_ooooo0_l0000=ooooo`;o00006?ooool2o`0000kooooo0_l0
0003ooooo`;o00002_ooool2o`0001Sooooo0_l0000dooooo`;o00004?ooool2o`0000Wooooo1_l0
000Looooo`00:Oooool00ol0003oooooooooo`0Eooooo`;o00003Oooool2o`0000Kooooo0_l0000?
ooooo`;o000000?oooooo`000?l000004_ooool4o`0004Cooooo0_l0000?ooooo`;o0000?Oooool2
o`0000oooooo0_l0000Kooooo`Ko00007?ooool002Wooooo00?o0000ooooooooool05Oooool2o`00
00;ooooo0_l00009ooooo`;o00005oooool2o`000003ooooool0003o000003gooooo0_l00002oooo
o`;o00004?ooool2o`0003;ooooo0_l0000Qooooo`;o000000?oooooo`000?l000002oooool2o`00
03kooooo000Qoooooooo0000A?l00004ooooo`00:Oooool3o`0000Sooooo0_l0000<ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Oooooo0_l000000ooooooo0000ooooo`03ooooo`;o00001Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool4o`0000Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo
0_l00005ooooo`03o`000?oooooooooo00Oooooo0ol000000ooooooo0000o`000004ooooo`;o0000
0_ooool00ol0003oooooooooo`07ooooo`?o00000oooool2o`0000Gooooo0ol0000;ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00?ooooo0_l00004ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool2o`0000_ooooo000Yooooo`03o`000?oooooooooo03[ooooo0ol00007ooooo`;o00001_oo
ool2o`0002Wooooo1?l0000:ooooo`;o00003Oooool2o`0001Gooooo0_l00006ooooo`?o00001Ooo
ool4o`0000Oooooo0_l00006ooooo`;o00006_ooool2o`0000Kooooo00?o0000ooooooooool0;_oo
ool2o`0000[ooooo00?o0000ooooooooool02_ooool002Wooooo00?o0000ooooooooool0:?ooool2
o`00017ooooo0_l0000`ooooo`?o00002Oooool2o`0000[ooooo0_l0000=ooooo`;o00005Oooool2
o`0000kooooo0_l00009ooooo`;o00001_ooool2o`0001[ooooo0_l0000gooooo`;o00005oooool0
02Wooooo00?o0000ooooooooool0:?ooool2o`0000Gooooo0_l0000Zooooo`;o00004?ooool3o`00
00Sooooo0ol0000Mooooo`;o00009_ooool2o`000003ooooool0003o000000Kooooo0_l0000ooooo
o`;o0000;_ooool002Wooooo0_l0000`ooooo`;o00006Oooool2o`0000gooooo1?l00009ooooo`;o
00004?ooool2o`0001kooooo0_l0000Vooooo`;o000000Coooooo`000?l0003ooooo0_l00003oooo
o`;o00008Oooool2o`0000Wooooo0_l0000Aooooo`Co0000;?ooool002Wooooo00?o0000oooooooo
ool0B_ooool2o`0000gooooo0_l0000;ooooo`;o00002oooool2o`0000Gooooo0_l00008ooooo`;o
00004oooool2o`0002_ooooo0_l0000;ooooo`;o00006Oooool2o`0000Wooooo0_l00004ooooo`;o
00003Oooool2o`0001Gooooo0_l0000Eooooo`00:Oooool2o`0002?ooooo0ol0000Pooooo`;o0000
2?ooool2o`0001_ooooo0_l00005ooooo`;o00000_ooool2o`000003ooooool0003o000000Kooooo
1?l00006ooooo`;o00002oooool2o`0000cooooo0_l000000ooooooo0000o`00000Rooooo`;o0000
0oooool2o`0000Cooooo0_l0000Tooooo`;o00009?ooool2o`0001Gooooo000Yooooo`;o00003_oo
ool4o`00017ooooo0ol0000Pooooo`;o00002?ooool2o`0000kooooo0_l0000;ooooo`;o00002Ooo
ool2o`0000Wooooo0_l00008ooooo`;o00006Oooool2o`000003ooooool0003o000002;ooooo0_l0
00000ooooooo0000o`000006ooooo`;o0000;oooool2o`0001oooooo0_l0000?ooooo`00:Oooool0
1?l0003oooooo`000?l00008ooooo`;o00000_ooool4o`0001cooooo0_l0000Gooooo`;o00005ooo
ool2o`0000_ooooo0_l0000/ooooo`;o00002Oooool2o`0002Gooooo0_l00003ooooo`;o00002?oo
ool2o`0000[ooooo0_l0000Qooooo`;o00007oooool2o`0000oooooo000Yooooo`Co000000?ooooo
o`000?l000001Oooool2o`0000gooooo0_l0000?ooooo`?o000000?oooooo`000?l000004_ooool2
o`0000?ooooo0_l000000ooooooo0000o`000009ooooo`;o00005_ooool2o`0000?ooooo0_l0000:
ooooo`;o00002_ooool2o`0000oooooo0_l00009ooooo`;o00006_ooool2o`0000Wooooo0_l0000=
ooooo`;o00002_ooool2o`0002Wooooo0_l0000Xooooo`00:Oooool00ol0003oooooooooo`02oooo
o`Co00004_ooool2o`0000_ooooo0_l00002ooooo`?o00005Oooool3o`0000Gooooo0_l00006oooo
o`;o000000?oooooo`000?l000001_ooool4o`0000Oooooo0_l00008ooooo`;o00001oooool2o`00
0003ooooool0003o000000[ooooo0_l0000:ooooo`;o00002Oooool2o`0000Cooooo0_l0000Ioooo
o`;o0000Coooool2o`0000;ooooo0_l00008ooooo`;o00001_ooool3o`00017ooooo000Yooooo`04
o`000?oooooo0000o`0000?ooooo0_l0000Oooooo`;o00006oooool2o`0000gooooo0_l00009oooo
o`Co00001oooool2o`00017ooooo0_l0000Iooooo`;o00002Oooool2o`0000Cooooo0_l0000Goooo
o`;o00006oooool2o`00013ooooo0_l00002ooooo`;o00008_ooool4o`0000Kooooo1?l00003oooo
o`Co00004Oooool002Wooooo00Co0000ooooool0003o0000;Oooool2o`0002[ooooo0_l0000;oooo
o`;o00009_ooool2o`0002Gooooo0_l00007ooooo`;o00006oooool2o`00013ooooo0_l00002oooo
o`;o00002?ooool2o`0000Kooooo0_l0000Booooo`;o00002?ooool2o`0000?ooooo0_l00004oooo
o`;o00003Oooool002Wooooo00?o0000ooooooooool03oooool2o`0000?ooooo1?l0000?ooooo`;o
00001Oooool2o`0000;ooooo0_l0000Booooo`;o00004_ooool2o`0003?ooooo0_l0000:ooooo`;o
00006Oooool2o`0003Cooooo0_l0000>ooooo`;o00001_ooool2o`0002Oooooo0_l0000=ooooo`00
:Oooool2o`0000Sooooo0_l00006ooooo`;o00000oooool4o`0000Oooooo0_l00006ooooo`;o0000
2Oooool2o`0001;ooooo0_l0000Gooooo`;o00000oooool2o`0003Gooooo0_l0000gooooo`;o0000
0_ooool2o`0001;ooooo0_l0000Rooooo`;o00000oooool2o`0000Sooooo0_l0000Kooooo`00:Ooo
ool00ol0003oooooooooo`07ooooo`;o00005_ooool2o`00017ooooo0_l00002ooooo`;o00009ooo
ool2o`0000?ooooo0_l0000mooooo`;o00002_ooool2o`0002?ooooo0_l00002ooooo`?o0000=Ooo
ool2o`0000?ooooo0_l00008ooooo`;o00001oooool2o`0001;ooooo000Yooooo`03o`000?oooooo
oooo01Oooooo0_l0000Iooooo`;o00000_ooool2o`00023ooooo0_l0000;ooooo`;o00003oooool2
o`0002[ooooo0ol0000:ooooo`;o00001Oooool2o`00027ooooo0_l0000Oooooo`;o00000_ooool2
o`0002Sooooo0_l0000Booooo`00:Oooool00ol0003oooooooooo`0<ooooo`;o00002Oooool2o`00
01Oooooo0_l00002ooooo`;o00003oooool2o`00017ooooo0_l0000;ooooo`;o00003oooool2o`00
02[ooooo1Ol00007ooooo`;o00001_ooool2o`000003ooooool0003o000000Sooooo0_l0000eoooo
o`;o00000_ooool2o`0003cooooo000Yooooo`03o`000?oooooooooo00_ooooo0ol0000Cooooo`;o
00003Oooool2o`0000;ooooo0_l0000?ooooo`;o0000GOooool3o`0000Oooooo0_l00009ooooo`;o
00002?ooool2o`00053ooooo0_l0000Uooooo`00:Oooool2o`0000cooooo0_l0000Dooooo`;o0000
?oooool2o`0002Wooooo0_l0000Looooo`;o00006?ooool2o`0000Kooooo0_l000000ooooooo0000
o`000005ooooo`;o00004?ooool2o`0002[ooooo0_l0000Uooooo`00:Oooool00ol0003ooooooooo
o`0Jooooo`;o00000_ooool2o`0003_ooooo0_l00005ooooo`;o0000:Oooool2o`0000kooooo0_l0
00000ooooooo0000o`000009ooooo`;o00006?ooool2o`0000Kooooo0_l000000ooooooo0000o`00
0005ooooo`;o00001Oooool2o`0000Wooooo0_l0000gooooo`;o00000oooool2o`0001?ooooo0006
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Jooooo`;o00000_ooool2o`0000Gooooo
0_l0000dooooo`;o000000?oooooo`000?l00000?Oooool2o`000003ooooool0003o000003cooooo
0_l00012ooooo`;o00000oooool2o`0001?ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool04_ooool3o`0000?ooooo0_l0000;ooooo`Co00005oooool2o`0001co
oooo0_l0002`ooooo`;o0000:_ooool000Kooooo00Go410@oooooooooooooooooa0@400<ooooo`03
oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Booooo`?o
00000oooool2o`0000?ooooo0_l00008ooooo`;o00005oooool2o`0000Oooooo0_l00005ooooo`;o
0000Voooool2o`0001?ooooo0_l0000<ooooo`;o00004_ooool2o`0001Kooooo0006ooooo`05o`00
0?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Co
oooo0ol0000Booooo`;o000000?oooooo`000?l000001_ooool2o`0002[ooooo0_l00005ooooo`;o
0000Hoooool2o`0003Kooooo0_l0000Cooooo`;o00008?ooool2o`0001Kooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool2o`0001Kooooo0_l0001<ooooo`;o0000D?ooool2o`0004oooooo0_l0000doooo
o`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`07ooooo`;o0000C?ooool2o`0001Kooooo0_l0000<ooooo`;o00003_ooool2o`00
00cooooo0_l00003ooooo`;o0000Boooool2o`000003ooooool0003o0000023ooooo0_l0000?oooo
o`;o00008oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03[ooooo1?l0000=
ooooo`;o00002_ooool2o`0001Sooooo0_l00008ooooo`;o00001?ooool2o`0000cooooo0_l00003
ooooo`;o00008_ooool2o`0002Oooooo1Ol0000aooooo`;o00008oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o
0000ooooooooool05oooool2o`00027ooooo1?l0000?ooooo`;o00002?ooool2o`0001Gooooo1?l0
0009ooooo`;o00004oooool2o`0002Kooooo0_l0000Yooooo`;o00008_ooool2o`0001Cooooo0_l0
000Mooooo`00:Oooool2o`0001Sooooo0_l0000dooooo`;o00007oooool4o`0001kooooo0_l0000V
ooooo`;o0000COooool2o`0001Cooooo0_l0000>ooooo`;o00003Oooool002Wooooo00?o0000oooo
ooooool04?ooool2o`0004oooooo0_l0000Oooooo`;o0000;?ooool2o`0003;ooooo0_l0000Eoooo
o`;o00003?ooool2o`0002;ooooo0_l0000=ooooo`00:Oooool00ol0003oooooooooo`0@ooooo`;o
0000:oooool2o`0000;ooooo0_l0000@ooooo`;o00003?ooool2o`0001oooooo0_l0000/ooooo`;o
0000:oooool2o`0000Gooooo0_l0000Eooooo`;o00003?ooool2o`00037ooooo000Yooooo`03o`00
0?oooooooooo00;ooooo0_l0000Zooooo`;o00003Oooool2o`0000;ooooo0_l0000@ooooo`;o0000
3?ooool2o`0002oooooo0_l00011ooooo`;o00001?ooool4o`0005gooooo000Yooooo`03o`000?oo
oooooooo00;ooooo0_l0000Zooooo`;o0000=?ooool2o`0001[ooooo0_l00004ooooo`?o00002Ooo
ool2o`0000_ooooo0_l0000dooooo`;o00001?ooool2o`0001Kooooo0_l0000Hooooo`;o0000;Ooo
ool002Wooooo0_l0001Uooooo`;o00006_ooool2o`0000Cooooo0ol0000Fooooo`;o0000D?ooool4
o`0001Sooooo0_l0000]ooooo`00:Oooool00ol0003oooooooooo`1_ooooo`;o0000@Oooool2o`00
03gooooo0_l00019ooooo`00:Oooool00ol0003oooooooooo`1_ooooo`;o0000@?ooool3o`0003;o
oooo0_l0001Dooooo`00:Oooool00ol0003oooooooooo`2aooooo`Co00008Oooool2o`0000kooooo
0_l00008ooooo`;o0000:Oooool2o`0000oooooo0_l0000>ooooo`00:Oooool00ol0003ooooooooo
o`0Jooooo`;o0000JOooool2o`00013ooooo0_l0000?ooooo`;o00002Oooool2o`00027ooooo0_l0
000;ooooo`;o00001_ooool2o`0000?ooooo0_l0000Xooooo`?o00003oooool2o`0000kooooo000Y
ooooo`;o00006oooool4o`0000;ooooo0_l0000Fooooo`;o0000Boooool2o`00013ooooo0_l0000?
ooooo`;o00004?ooool2o`0002Oooooo0_l00006ooooo`;o0000;Oooool2o`00023ooooo000Yoooo
o`03o`000?oooooooooo01cooooo0_l00002ooooo`;o00005_ooool2o`0003_ooooo0_l0000Voooo
o`;o00006oooool2o`0004Wooooo0_l0000eooooo`00:Oooool00ol0003oooooooooo`1eooooo`;o
00009_ooool2o`00033ooooo0_l0000Gooooo`;o00006oooool2o`0001Wooooo0_l0000Jooooo`00
:Oooool00ol0003oooooooooo`32ooooo`;o00002oooool2o`0001Oooooo0_l0000Qooooo`;o0000
4oooool2o`0001[ooooo000Yooooo`03o`000?oooooooooo02;ooooo0_l0001]ooooo`;o0000;ooo
ool2o`0004Oooooo0_l0000_ooooo`00:Oooool2o`0002?ooooo0_l0001]ooooo`;o0000ZOooool0
02Wooooo00?o0000ooooooooool07Oooool2o`0000cooooo0_l0003ooooooa3ooooo000>ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo01gooooo0_l0000<ooooo`;o0000Aoooool2o`0001Cooooo0_l0001U
ooooo`;o00001oooool2o`00043ooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`17ooooo`;o0000:Oooool4
o`0001Cooooo0_l00002ooooo`;o00009?ooool2o`0003_ooooo0_l00007ooooo`;o00001?ooool2
o`0003[ooooo000>ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03
ooooo`?o0000@oooool2o`0000;ooooo0_l0000@ooooo`;o00005oooool2o`0001[ooooo0_l0000T
ooooo`;o00002?ooool2o`00043ooooo0_l0000jooooo`003_ooool01Ol0003ooooooooooooooooo
000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0iooooo`;o00002?ooool2
o`0001Cooooo0_l0001Sooooo`;o0000J_ooool2o`00013ooooo000>ooooo`05o`000?oooooooooo
ooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0>Ooo
ool2o`000>oooooo0_l0000@ooooo`003_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Ooo
ool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
o`Sooooo0_l0000cooooo`00:Oooool00ol0003oooooooooo`3oooooo`Sooooo0_l0000cooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocgooooo0006oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooo
oooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3
o`000?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooo
oooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006oooo
o`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?oooooo
ooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co0000
1_ooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Ooooo
o`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003ooooo
ooooo`05ooooo`?o0000oooooolmooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Oooooo`03oeEEEOmVIVKo00000?oooooo
Aoooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .34271 Mdot
.02762 .39312 Mdot
.02952 .29833 Mdot
.03143 .30393 Mdot
.03333 .28745 Mdot
.03524 .33278 Mdot
.03714 .31589 Mdot
.03905 .2894 Mdot
.04095 .43933 Mdot
.04286 .34508 Mdot
.04476 .30034 Mdot
.04667 .24287 Mdot
.04857 .24967 Mdot
.05048 .32665 Mdot
.05238 .2594 Mdot
.05429 .30697 Mdot
.05619 .33997 Mdot
.0581 .26116 Mdot
.06 .35471 Mdot
.0619 .36131 Mdot
.06381 .24598 Mdot
.06571 .34777 Mdot
.06762 .33197 Mdot
.06952 .27741 Mdot
.07143 .25432 Mdot
.07333 .26447 Mdot
.07524 .25913 Mdot
.07714 .35679 Mdot
.07905 .33628 Mdot
.08095 .39369 Mdot
.08286 .26053 Mdot
.08476 .43996 Mdot
.08667 .3683 Mdot
.08857 .25003 Mdot
.09048 .34218 Mdot
.09238 .41852 Mdot
.09429 .28935 Mdot
.09619 .32633 Mdot
.0981 .32636 Mdot
.1 .22514 Mdot
.1019 .28365 Mdot
.10381 .27752 Mdot
.10571 .38845 Mdot
.10762 .3825 Mdot
.10952 .31457 Mdot
.11143 .36699 Mdot
.11333 .34691 Mdot
.11524 .43413 Mdot
.11714 .34609 Mdot
.11905 .36583 Mdot
.12095 .42961 Mdot
.12286 .24086 Mdot
.12476 .37682 Mdot
.12667 .37163 Mdot
.12857 .3863 Mdot
.13048 .42434 Mdot
.13238 .28576 Mdot
.13429 .33488 Mdot
.13619 .39177 Mdot
.1381 .29048 Mdot
.14 .36592 Mdot
.1419 .46278 Mdot
.14381 .32837 Mdot
.14571 .32778 Mdot
.14762 .39751 Mdot
.14952 .43339 Mdot
.15143 .33605 Mdot
.15333 .33527 Mdot
.15524 .34092 Mdot
.15714 .30321 Mdot
.15905 .27113 Mdot
.16095 .31262 Mdot
.16286 .34321 Mdot
.16476 .29617 Mdot
.16667 .32902 Mdot
.16857 .27516 Mdot
.17048 .3771 Mdot
.17238 .35686 Mdot
.17429 .26149 Mdot
.17619 .26548 Mdot
.1781 .37449 Mdot
.18 .39804 Mdot
.1819 .2672 Mdot
.18381 .2986 Mdot
.18571 .35939 Mdot
.18762 .27255 Mdot
.18952 .30201 Mdot
.19143 .3229 Mdot
.19333 .35179 Mdot
.19524 .33334 Mdot
.19714 .2552 Mdot
.19905 .27046 Mdot
.20095 .31869 Mdot
.20286 .35664 Mdot
.20476 .33491 Mdot
.20667 .2981 Mdot
.20857 .33317 Mdot
.21048 .42354 Mdot
.21238 .39601 Mdot
.21429 .33596 Mdot
.21619 .3653 Mdot
.2181 .37009 Mdot
.22 .25838 Mdot
.2219 .39288 Mdot
.22381 .36124 Mdot
.22571 .24389 Mdot
.22762 .25748 Mdot
.22952 .33513 Mdot
.23143 .31627 Mdot
.23333 .30004 Mdot
.23524 .34712 Mdot
.23714 .30517 Mdot
.23905 .44006 Mdot
.24095 .4081 Mdot
.24286 .49214 Mdot
.24476 .30416 Mdot
.24667 .36133 Mdot
.24857 .41329 Mdot
.25048 .42964 Mdot
.25238 .25182 Mdot
.25429 .24425 Mdot
.25619 .45211 Mdot
.2581 .25485 Mdot
.26 .32065 Mdot
.2619 .30587 Mdot
.26381 .32245 Mdot
.26571 .39988 Mdot
.26762 .35419 Mdot
.26952 .39474 Mdot
.27143 .2674 Mdot
.27333 .31892 Mdot
.27524 .38499 Mdot
.27714 .22647 Mdot
.27905 .30712 Mdot
.28095 .38246 Mdot
.28286 .27628 Mdot
.28476 .29271 Mdot
.28667 .37089 Mdot
.28857 .33944 Mdot
.29048 .34695 Mdot
.29238 .24332 Mdot
.29429 .45898 Mdot
.29619 .25889 Mdot
.2981 .35594 Mdot
.3 .33722 Mdot
.3019 .38662 Mdot
.30381 .384 Mdot
.30571 .47209 Mdot
.30762 .34548 Mdot
.30952 .34231 Mdot
.31143 .44961 Mdot
.31333 .37387 Mdot
.31524 .30173 Mdot
.31714 .291 Mdot
.31905 .2999 Mdot
.32095 .2767 Mdot
.32286 .24341 Mdot
.32476 .29465 Mdot
.32667 .41891 Mdot
.32857 .28072 Mdot
.33048 .25269 Mdot
.33238 .25993 Mdot
.33429 .25273 Mdot
.33619 .31212 Mdot
.3381 .41328 Mdot
.34 .38486 Mdot
.3419 .34295 Mdot
.34381 .39359 Mdot
.34571 .38521 Mdot
.34762 .33159 Mdot
.34952 .2593 Mdot
.35143 .39924 Mdot
.35333 .32206 Mdot
.35524 .29044 Mdot
.35714 .28519 Mdot
.35905 .32263 Mdot
.36095 .37625 Mdot
.36286 .31895 Mdot
.36476 .28985 Mdot
.36667 .32376 Mdot
.36857 .33655 Mdot
.37048 .23516 Mdot
.37238 .23229 Mdot
.37429 .26178 Mdot
.37619 .30093 Mdot
.3781 .32809 Mdot
.38 .43699 Mdot
.3819 .36637 Mdot
.38381 .44023 Mdot
.38571 .29233 Mdot
.38762 .38589 Mdot
.38952 .43357 Mdot
.39143 .38524 Mdot
.39333 .28149 Mdot
.39524 .45459 Mdot
.39714 .33169 Mdot
.39905 .37056 Mdot
.40095 .23875 Mdot
.40286 .34401 Mdot
.40476 .21974 Mdot
.40667 .25267 Mdot
.40857 .31473 Mdot
.41048 .31981 Mdot
.41238 .32023 Mdot
.41429 .2615 Mdot
.41619 .22822 Mdot
.4181 .36826 Mdot
.42 .29605 Mdot
.4219 .30993 Mdot
.42381 .31303 Mdot
.42571 .31906 Mdot
.42762 .27954 Mdot
.42952 .24264 Mdot
.43143 .35961 Mdot
.43333 .38587 Mdot
.43524 .26249 Mdot
.43714 .349 Mdot
.43905 .365 Mdot
.44095 .31375 Mdot
.44286 .33217 Mdot
.44476 .24637 Mdot
.44667 .23 Mdot
.44857 .36297 Mdot
.45048 .38624 Mdot
.45238 .37685 Mdot
.45429 .3897 Mdot
.45619 .30513 Mdot
.4581 .25103 Mdot
.46 .39695 Mdot
.4619 .32125 Mdot
.46381 .25437 Mdot
.46571 .45984 Mdot
.46762 .33561 Mdot
.46952 .27088 Mdot
.47143 .22408 Mdot
.47333 .36653 Mdot
.47524 .25495 Mdot
.47714 .44124 Mdot
.47905 .3122 Mdot
.48095 .39987 Mdot
.48286 .24408 Mdot
.48476 .3799 Mdot
.48667 .46173 Mdot
.48857 .36077 Mdot
.49048 .41204 Mdot
.49238 .27279 Mdot
.49429 .43873 Mdot
.49619 .33639 Mdot
.4981 .23079 Mdot
.5 .37536 Mdot
.5019 .27755 Mdot
.50381 .31642 Mdot
.50571 .35384 Mdot
.50762 .30973 Mdot
.50952 .27113 Mdot
.51143 .23448 Mdot
.51333 .27315 Mdot
.51524 .27777 Mdot
.51714 .38921 Mdot
.51905 .27329 Mdot
.52095 .31595 Mdot
.52286 .42032 Mdot
.52476 .3595 Mdot
.52667 .25507 Mdot
.52857 .40129 Mdot
.53048 .27187 Mdot
.53238 .37681 Mdot
.53429 .30189 Mdot
.53619 .34431 Mdot
.5381 .37437 Mdot
.54 .41406 Mdot
.5419 .25068 Mdot
.54381 .41316 Mdot
.54571 .38935 Mdot
.54762 .34728 Mdot
.54952 .31754 Mdot
.55143 .24321 Mdot
.55333 .27565 Mdot
.55524 .26676 Mdot
.55714 .43369 Mdot
.55905 .28043 Mdot
.56095 .28249 Mdot
.56286 .30838 Mdot
.56476 .29925 Mdot
.56667 .25961 Mdot
.56857 .27449 Mdot
.57048 .27342 Mdot
.57238 .32811 Mdot
.57429 .26866 Mdot
.57619 .27566 Mdot
.5781 .41674 Mdot
.58 .35699 Mdot
.5819 .35187 Mdot
.58381 .37054 Mdot
.58571 .37169 Mdot
.58762 .28657 Mdot
.58952 .36228 Mdot
.59143 .31426 Mdot
.59333 .37387 Mdot
.59524 .43869 Mdot
.59714 .42145 Mdot
.59905 .27118 Mdot
.60095 .44738 Mdot
.60286 .30625 Mdot
.60476 .37526 Mdot
.60667 .39256 Mdot
.60857 .43933 Mdot
.61048 .25589 Mdot
.61238 .33912 Mdot
.61429 .42982 Mdot
.61619 .25785 Mdot
.6181 .27455 Mdot
.62 .25453 Mdot
.6219 .32218 Mdot
.62381 .23566 Mdot
.62571 .4399 Mdot
.62762 .29586 Mdot
.62952 .26044 Mdot
.63143 .24709 Mdot
.63333 .38246 Mdot
.63524 .26429 Mdot
.63714 .23404 Mdot
.63905 .38767 Mdot
.64095 .44157 Mdot
.64286 .34213 Mdot
.64476 .29156 Mdot
.64667 .31328 Mdot
.64857 .2937 Mdot
.65048 .2521 Mdot
.65238 .31367 Mdot
.65429 .31951 Mdot
.65619 .27755 Mdot
.6581 .24672 Mdot
.66 .23102 Mdot
.6619 .33487 Mdot
.66381 .28567 Mdot
.66571 .27823 Mdot
.66762 .32054 Mdot
.66952 .3952 Mdot
.67143 .34057 Mdot
.67333 .38539 Mdot
.67524 .25846 Mdot
.67714 .25269 Mdot
.67905 .35067 Mdot
.68095 .2696 Mdot
.68286 .402 Mdot
.68476 .32438 Mdot
.68667 .40104 Mdot
.68857 .2706 Mdot
.69048 .38165 Mdot
.69238 .38988 Mdot
.69429 .27294 Mdot
.69619 .35816 Mdot
.6981 .45929 Mdot
.7 .24236 Mdot
.7019 .37941 Mdot
.70381 .41637 Mdot
.70571 .29454 Mdot
.70762 .24357 Mdot
.70952 .40182 Mdot
.71143 .37554 Mdot
.71333 .24516 Mdot
.71524 .42819 Mdot
.71714 .41485 Mdot
.71905 .22883 Mdot
.72095 .23863 Mdot
.72286 .31771 Mdot
.72476 .32078 Mdot
.72667 .35469 Mdot
.72857 .24404 Mdot
.73048 .30276 Mdot
.73238 .31591 Mdot
.73429 .3282 Mdot
.73619 .28687 Mdot
.7381 .29377 Mdot
.74 .35775 Mdot
.7419 .42962 Mdot
.74381 .39842 Mdot
.74571 .33014 Mdot
.74762 .2493 Mdot
.74952 .34431 Mdot
.75143 .36423 Mdot
.75333 .33443 Mdot
.75524 .23283 Mdot
.75714 .48868 Mdot
.75905 .27627 Mdot
.76095 .25224 Mdot
.76286 .27771 Mdot
.76476 .35544 Mdot
.76667 .35397 Mdot
.76857 .31803 Mdot
.77048 .24305 Mdot
.77238 .3088 Mdot
.77429 .31318 Mdot
.77619 .31199 Mdot
.7781 .316 Mdot
.78 .25405 Mdot
.7819 .43846 Mdot
.78381 .39677 Mdot
.78571 .44955 Mdot
.78762 .23698 Mdot
.78952 .27215 Mdot
.79143 .3091 Mdot
.79333 .24846 Mdot
.79524 .32553 Mdot
.79714 .28531 Mdot
.79905 .30678 Mdot
.80095 .26321 Mdot
.80286 .24803 Mdot
.80476 .26147 Mdot
.80667 .29069 Mdot
.80857 .26288 Mdot
.81048 .25715 Mdot
.81238 .41111 Mdot
.81429 .3553 Mdot
.81619 .41518 Mdot
.8181 .25941 Mdot
.82 .30376 Mdot
.8219 .26404 Mdot
.82381 .33392 Mdot
.82571 .2632 Mdot
.82762 .2666 Mdot
.82952 .28257 Mdot
.83143 .45063 Mdot
.83333 .34819 Mdot
.83524 .29826 Mdot
.83714 .3557 Mdot
.83905 .25791 Mdot
.84095 .25384 Mdot
.84286 .26755 Mdot
.84476 .31115 Mdot
.84667 .37047 Mdot
.84857 .24949 Mdot
.85048 .40087 Mdot
.85238 .48381 Mdot
.85429 .39331 Mdot
.85619 .26222 Mdot
.8581 .43837 Mdot
.86 .23842 Mdot
.8619 .2969 Mdot
.86381 .39202 Mdot
.86571 .35729 Mdot
.86762 .28212 Mdot
.86952 .28591 Mdot
.87143 .3085 Mdot
.87333 .40241 Mdot
.87524 .25299 Mdot
.87714 .23024 Mdot
.87905 .3314 Mdot
.88095 .34614 Mdot
.88286 .28074 Mdot
.88476 .33752 Mdot
.88667 .30759 Mdot
.88857 .29474 Mdot
.89048 .29059 Mdot
.89238 .27116 Mdot
.89429 .27305 Mdot
.89619 .40128 Mdot
.8981 .29277 Mdot
.9 .40723 Mdot
.9019 .32376 Mdot
.90381 .29352 Mdot
.90571 .3411 Mdot
.90762 .32177 Mdot
.90952 .24121 Mdot
.91143 .35768 Mdot
.91333 .34517 Mdot
.91524 .37741 Mdot
.91714 .25791 Mdot
.91905 .36314 Mdot
.92095 .38291 Mdot
.92286 .36976 Mdot
.92476 .35136 Mdot
.92667 .36003 Mdot
.92857 .24774 Mdot
.93048 .4654 Mdot
.93238 .38613 Mdot
.93429 .2757 Mdot
.93619 .3842 Mdot
.9381 .27849 Mdot
.94 .32095 Mdot
.9419 .34205 Mdot
.94381 .36976 Mdot
.94571 .38253 Mdot
.94762 .32673 Mdot
.94952 .30256 Mdot
.95143 .43249 Mdot
.95333 .28561 Mdot
.95524 .27651 Mdot
.95714 .35532 Mdot
.95905 .35343 Mdot
.96095 .28743 Mdot
.96286 .49263 Mdot
.96476 .28171 Mdot
.96667 .3942 Mdot
.96857 .37798 Mdot
.97048 .41612 Mdot
.97238 .34805 Mdot
.97429 .35787 Mdot
.97619 .22519 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo07Oooooo0_l00033ooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool0Moooool2o`0001?ooooo0_l0002^ooooo`001_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo01Gooooo0_l0000gooooo`;o0000??ooool2o`000:7ooooo0_l0
000;ooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^
kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05Oooool2o`0003Oooooo0_l0
000Zooooo`;o00002?ooool2o`0000oooooo0_l0000booooo`;o00004Oooool2o`00037ooooo0_l0
000Nooooo`;o00002oooool000Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ
8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0006cooooo0_l0000<ooooo`;o00002?oo
ool2o`0000oooooo0_l0000Zooooo`;o00001_ooool2o`00017ooooo0_l00009ooooo`;o00009_oo
ool2o`0002_ooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`1/ooooo`;o0000
:oooool2o`0002;ooooo0_l00002ooooo`;o00009?ooool2o`0000Wooooo0_l00018ooooo`001_oo
ool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo06cooooo0_l00008ooooo`;o00008Oooool2o`0002;ooooo
0_l0000Mooooo`;o00005?ooool2o`0001Gooooo0_l0000aooooo`001_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01?ooool2o`0001Kooooo0_l0000eooooo`;o00001oooool2o`0001So
oooo0_l00007ooooo`;o00009Oooool2o`0002kooooo0_l00004ooooo`;o00003_ooool2o`0001_o
oooo0_l0000>ooooo`;o00008Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool01?ooool2o`00
00?ooooo0_l0000Aooooo`;o00007oooool2o`0000Oooooo0_l0000;ooooo`;o00001oooool2o`00
027ooooo0_l00003ooooo`;o00002_ooool2o`0001Cooooo0_l0000^ooooo`Ko00000oooool2o`00
00_ooooo0_l0000[ooooo`;o00008Oooool002Wooooo0_l00005ooooo`;o00000oooool2o`0003;o
oooo0_l00007ooooo`;o0000??ooool2o`0000[ooooo0_l0000^ooooo`;o00001_ooool2o`0000ko
oooo1?l00003ooooo`;o00001?ooool2o`0000gooooo0_l000000ooooooo0000o`00000<ooooo`;o
00006?ooool2o`0001_ooooo000Yooooo`03o`000?oooooooooo00Cooooo0_l0000;ooooo`;o0000
<oooool2o`0001Oooooo0ol0000Eooooo`;o00003oooool2o`0001Wooooo0_l0000Kooooo`;o0000
1?ooool4o`0000Cooooo0_l0000Eooooo`;o00000_ooool2o`0000Wooooo0_l000000ooooooo0000
o`00000<ooooo`;o00006?ooool2o`0001_ooooo000Yooooo`03o`000?oooooooooo00cooooo0_l0
0003ooooo`;o00008Oooool2o`00013ooooo1?l0000Eooooo`?o00005Oooool2o`0000oooooo1?l0
00000ooooooo0000o`00000?ooooo`;o00000oooool2o`0001Cooooo0_l000000ooooooo0000o`00
0008ooooo`;o00001_ooool2o`0001Wooooo0_l00004ooooo`;o00004_ooool2o`0000Wooooo0_l0
000/ooooo`00:Oooool00ol0003oooooooooo`0<ooooo`;o00009_ooool2o`0000Gooooo0_l00000
0ooooooo0000o`000008ooooo`;o00002_ooool2o`0003Cooooo0_l000000ooooooo0000o`00000?
ooooo`;o00006Oooool5o`00013ooooo0_l0000Oooooo`;o00002?ooool2o`0000Oooooo0ol00009
ooooo`;o00003?ooool2o`0001kooooo000Yooooo`03o`000?oooooooooo00Gooooo1?l00004oooo
o`Co00007?ooool2o`0000cooooo0_l000000ooooooo0000o`00000Dooooo`;o00002Oooool2o`00
00Cooooo0_l00006ooooo`;o00002oooool2o`0002oooooo0_l0000>ooooo`;o00000_ooool2o`00
00gooooo0_l0000Wooooo`Co000000?oooooo`000?l000001?ooool2o`0001Sooooo0_l0000Noooo
o`00:Oooool2o`0000Kooooo1?l00003ooooo`Go00007?ooool2o`00033ooooo0_l00004ooooo`;o
00001_ooool2o`0000_ooooo0_l00005ooooo`;o0000:?ooool2o`0001;ooooo1?l0000cooooo`Go
000000?oooooo`000?l000000_l00008ooooo`;o0000<_ooool002Wooooo00?o0000ooooooooool0
3?ooool2o`0001oooooo1?l0000Kooooo`;o0000<oooool2o`0002Cooooo0_l0000Hooooo`;o0000
<oooool2o`000003ooooool0003o000000;ooooo1?l00003ooooo`;o00000_ooool2o`0003;ooooo
000Yooooo`03o`000?oooooooooo02Sooooo0_l00003ooooo`Oo000000So410@o`000?l0003ok^k^
oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`;o00007oooool5
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2_ooool2o`0000[ooooo0_l0000=ooooo`;o000000?ooooooiRHV?l@41000ol00003ooooo`03onk^
k_lb<S;o000000;o00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^017ooooo1?l0000Eooooo`;o
000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo0_l00003ooooo`;o00003_ooool2o`0000oooooo00GoA4A4o`000?l0003o
<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo000Yooooo`03o`000?oooooooooo02Sooooo0_l00007ooooo`;o00000_ooool2o`00
0005ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg02Wooooo00Go
V9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00[ooooo0_l00005ooooo`;o00000oooool6o`000003ooooool0003o0000
00Wooooo00?o410@o`000?l000000_l00003ooooo`03ogMgMonHV9Sooooo00;o00000oooool01Omg
MgOo0000o`000?nHV9SoMgMg017ooooo1_l0000Dooooo`03o`000?oooooooooo00;ooooo00?oMgMg
oiRHV?ooool00_l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06?ooool2o`0001;ooooo00Wo
MgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo000Yooooo`03o`000?oooooooooo00_ooooo0_l00009ooooo`;o00004oooool2o`00
00Cooooo0_l00004ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@00cooooo0_l0000:ooooo`;o00004?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?oo
ooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@017ooooo0_l000000ooooooo
0000o`000002ooooo`Co000000?oooooo`000?l000001_ooool2o`0000;ooooo1Ol00002ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413o0000o`000?oooooo410@00Wooooo0_l0000:
ooooo`;o00004Oooool5o`0000?ooooo00?o410@ooooooooool00_l00003ooooo`05oa0@4?oooooo
ooooooooool@41006?ooool2o`0000_ooooo0_l00005ooooo`;o00000_ooool01Ol@413ooooooooo
oooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`00:Oooool2o`0000cooooo
0_l00009ooooo`;o00004oooool2o`0000Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00000<ooooo`;o00002_ooool4o`00
00oooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000?ooooo0ol00000
0ooooooo0000ooooo`0Cooooo`;o00000_ooool2o`0000_ooooo0ol00003ooooo`03ojVYZOl0003o
000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
2Oooool2o`000003ooooool0003o000001[ooooo00?oA4A4omgMgOl000000_l00003ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000001Cooooo0_l0000?oooo
o`?o00001?ooool2o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool002Wooooo00?o0000ooooooooool05Oooool2o`0001_ooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`00000Jooooo`;o00004?ooool00omgMgOoIVIVooooo`03o`0000?ooooo00Co0000oooooooooooo
oooo0ol000000ooooooo0000ooooo`0Gooooo`;o00003?ooool3o`000004ooooool@413o0000okZj
^P?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000003?oo
ool2o`0001[ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`;o00002oooool2o`0000;ooooo0_l0000@oooo
o`;o000000Ooooooo`000?lQ8B7o0000oc8b<_o<c<cooooo00;o00000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool00Oooool002Wooooo00?o0000ooooooooool05Ooo
ool2o`0000Sooooo0_l0000Aooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@4003ooooo`05oa0@4?ooooooooooooooool@41008oooool2o`0000Sooooo00Go0000ooooool0
003o0000oa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`0U
ooooo`;o00000_ooool00onj^[[o8B4Qooooo`02ooooo`;o00000_ooool01Ol@413ooooooooooooo
oooo410@00?ooooo00?o410@ooooooooool02Oooool2o`0001Gooooo0_l00005ooooo`03ogMgMoo<
c<co000000Cooooo00Ko410@oooooooooooooooooa0@4?ooool2o`000005oa0@4?oooooooooooooo
ool@41000oooool2o`0000_ooooo0_l0000Gooooo`04o`000?oooooo0000o`0000;ooooo0_l00003
ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`01ooooo`00:Oooool0
0ol0003oooooo`000003o`00013ooooo0_l0000:ooooo`;o00004Oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
0_l000002Ooooooo0000o`000?oooooo0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg02Sooooo00Go410@oiRHV?oooooo
^[Zjo`000003ooooo`;o000000?ooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo0_l0000Eooooo`;o00001Oooool00oo^k^koA4A4o`000004ooooo`06ogMgMonHV9Sooooo
oiRHV?mgMgOooooo0_l000001OmgMgOoV9RHoooooonHV9SoMgMg013ooooo0_l0000Gooooo`05o`00
0?oooooo0000o`000?ooool00_l000001OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`00:Oooool00ol0003oooooo`000003o`00013ooooo0_l0000<oooo
o`;o00003Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo0_l00009ooooo`;o00002_ooool2o`000008ooooool0
003o0000oooooonHV9So410@o`000?lQ8B42o`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:?ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2o`00
02?ooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
o`000?l0003o<S8bonk^kP0Gooooo`Co00003_ooool4o`000008ooooool0003o0000onk^k_lb<S;o
0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool002Wooooo0_l0000Roooo
o`;o00001oooool2o`0002Cooooo0_l00009ooooo`Co00002?ooool2o`0000Sooooo0_l00009oooo
o`;o0000@?ooool2o`0000Cooooo0ol0000Aooooo`;o00002?ooool2o`0001Cooooo0_l0000Hoooo
o`Oo00008oooool002Wooooo0ol0000Zooooo`;o00001?ooool2o`0000Gooooo0_l0000Tooooo`;o
00007Oooool2o`0002cooooo0_l0000Booooo`;o00001Oooool2o`00017ooooo0_l00008ooooo`;o
00007Oooool2o`0000Oooooo0_l00006ooooo`;o00000oooool2o`0002?ooooo000Yooooo`?o0000
0oooool2o`0002_ooooo1?l00003ooooo`;o00001oooool2o`0001Sooooo0ol0000Aooooo`;o0000
<?ooool2o`0000Sooooo0_l0001Eooooo`;o00001oooool2o`0001[ooooo0_l0000Dooooo`00:Ooo
ool01?l0003oooooo`000?l00002ooooo`;o00008_ooool2o`0000Wooooo0_l0000<ooooo`Go0000
5Oooool3o`00017ooooo0_l0000Gooooo`;o00005oooool2o`0003gooooo0_l0000Kooooo`;o0000
:?ooool2o`0001Cooooo000Yooooo`04o`000?oooooo0000o`0000Gooooo0_l0000Oooooo`;o0000
6?ooool4o`0000Cooooo0_l00003ooooo`;o0000=oooool2o`00027ooooo0_l0000:ooooo`;o0000
9oooool2o`0000cooooo0_l00007ooooo`;o00001?ooool2o`0000oooooo0_l00003ooooo`;o0000
:?ooool0027oooooool00014o`0000Cooooo000Yooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02_ooool01?l0003oooooo`000?l00008ooooo`03o`000?oooooooooo00?ooooo0_l0
0004ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00Co0000ooooool0003o00002?ooool00ol0003ooooo
ooooo`0:ooooo`;o00000_ooool3o`0000?ooooo0ol0000:ooooo`;o00001oooool2o`0000;ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`?o00002oooool01?l0003ooooo
ooooooooool3o`0000Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Gooooo0_l00002ooooo`?o00002Oooool00ol0003oooooooooo`03ooooo`;o
00001Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0:ooooo`00:Oooool01?l0003oooooooooooooool2o`0001Go
oooo0_l0000>ooooo`;o00004?ooool00ol0003oooooooooo`02ooooo`;o00008?ooool2o`0001Go
oooo0_l00003ooooo`;o00000oooool2o`0000_ooooo0_l00006ooooo`;o00000oooool2o`0000Oo
oooo0_l0000<ooooo`?o00003oooool3o`0001Gooooo0_l000000ooooooo0000o`00000:ooooo`Go
000000?oooooo`000?ooool0>oooool00ol0003oooooooooo`0:ooooo`00:Oooool01?l0003ooooo
ooooooooool2o`0003;ooooo0_l00008ooooo`;o00001oooool2o`0000?ooooo0_l0000Jooooo`;o
00003_ooool2o`0000;ooooo0_l0000:ooooo`;o00003?ooool2o`0000?ooooo0_l00007ooooo`;o
00008?ooool2o`0000;ooooo0_l0000@ooooo`Go00002_ooool2o`000003ooooool0003o000003;o
oooo0_l0000Gooooo`00:Oooool00ol0003oooooooooo`0booooo`;o000000?oooooo`000?l00000
4Oooool3o`0000;ooooo0_l0000Gooooo`Oo00003?ooool2o`0000;ooooo0_l0000:ooooo`;o0000
<_ooool2o`0000Sooooo0_l00002ooooo`;o00004Oooool2o`0003Oooooo0ol00009ooooo`;o0000
5oooool002Wooooo0_l00006ooooo`;o00003Oooool2o`0001cooooo0_l0000Eooooo`;o00006ooo
ool4o`000003ooooool0003o0000053ooooo0_l0000Booooo`;o00008Oooool2o`00027ooooo0ol0
000;ooooo`;o00005Oooool002Wooooo00?o0000ooooooooool01Oooool2o`0000gooooo0_l0000=
ooooo`;o00001Oooool2o`0004;ooooo0_l0000mooooo`;o00008_ooool2o`0000kooooo0_l00000
0ooooooo0000o`00000>ooooo`;o0000;oooool2o`0001Gooooo000Yooooo`03o`000?oooooooooo
00;o00002?ooool2o`0001Oooooo0_l00005ooooo`;o00001oooool2o`0000?ooooo0_l0000Zoooo
o`;o00002?ooool2o`0000Cooooo0_l0000=ooooo`;o0000:?ooool2o`0003;ooooo0_l000000ooo
oooo0000o`00000Yooooo`;o0000:oooool002Wooooo00?o0000ooooooooool00_l00008ooooo`;o
00000_ooool2o`00013ooooo0_l00003ooooo`?o00002oooool2o`000003ooooool0003o000000Co
00000_ooool2o`0002Cooooo0_l00005ooooo`;o00001oooool2o`0000gooooo0_l00006ooooo`;o
00001oooool2o`0003?ooooo0_l0000Looooo`;o00005Oooool2o`0000oooooo0_l0000[ooooo`00
:Oooool00ol0003oooooooooo`0>ooooo`;o00004?ooool2o`0000?ooooo0ol0000>ooooo`;o0000
0_ooool2o`0000;ooooo0_l0000Aooooo`;o00000_ooool2o`0001Cooooo0_l0000Nooooo`;o0000
1oooool2o`0002Cooooo0_l0000=ooooo`;o00007?ooool2o`0001Gooooo0_l0000Aooooo`;o0000
:Oooool002Wooooo0_l00008ooooo`;o00002Oooool2o`0001?ooooo0_l0000Xooooo`;o00000_oo
ool2o`000003ooooool0003o000000Wooooo0_l0001Eooooo`;o00001oooool2o`0000Sooooo0_l0
0012ooooo`;o00001Oooool2o`0000Wooooo0_l0000Gooooo`00:Oooool2o`0000?ooooo0_l00003
ooooo`;o00002Oooool2o`0000Kooooo0_l0000;ooooo`Co0000;Oooool2o`0000Wooooo0_l0000A
ooooo`;o0000:Oooool2o`00023ooooo0_l00008ooooo`;o00005oooool2o`0002Sooooo0_l00006
ooooo`Co00001oooool2o`0001Oooooo000Yooooo`03o`000?oooooooooo00;ooooo0_l00006oooo
o`;o00003Oooool3o`0000gooooo0_l0000Eooooo`;o00004?ooool2o`0000Cooooo0_l0000Loooo
o`;o00002Oooool2o`0001kooooo0_l00002ooooo`;o0000?oooool2o`0001Wooooo0_l0000=oooo
o`;o00002?ooool2o`00017ooooo0_l0000=ooooo`00:Oooool00ol0003oooooooooo`0:ooooo`;o
00003Oooool2o`0001Sooooo0_l0000;ooooo`;o00004?ooool2o`0002gooooo0_l0000Rooooo`;o
00002Oooool2o`0001gooooo0_l0000`ooooo`;o00006oooool2o`0000gooooo0_l0000=ooooo`00
:Oooool00ol0003oooooooooo`08ooooo`;o0000:Oooool2o`0001Kooooo0_l0001:ooooo`;o0000
5oooool2o`0001gooooo0_l0000=ooooo`;o00002oooool2o`0000gooooo0_l0000Rooooo`;o0000
2?ooool3o`00017ooooo000Yooooo`;o00002Oooool2o`0000?ooooo0_l0000Mooooo`;o00002?oo
ool2o`0001?ooooo0_l00007ooooo`;o0000@Oooool2o`0001Kooooo0_l0000Sooooo`;o00002?oo
ool2o`0000?ooooo0_l00006ooooo`;o00003Oooool2o`0000Kooooo0_l00007ooooo`;o00003Ooo
ool2o`0000cooooo0ol00003ooooo`;o00003?ooool002Wooooo00?o0000ooooooooool02Oooool2
o`0000;ooooo0_l0000Mooooo`;o00000_ooool2o`0000Cooooo0_l00005ooooo`;o00001Oooool2
o`0000kooooo0_l0000Yooooo`;o00004Oooool2o`0000Wooooo0_l0000@ooooo`;o00008oooool2
o`0000gooooo0_l0000Mooooo`;o00001oooool2o`0000gooooo0_l00003ooooo`;o00003Oooool2
o`0000cooooo000Yooooo`03o`000?oooooooooo00Wooooo0_l0000Uooooo`;o00002oooool2o`00
00Gooooo0_l0000iooooo`;o00001?ooool2o`0000_ooooo0_l00009ooooo`;o00004oooool2o`00
03;ooooo0_l0000dooooo`;o000000?oooooo`000?l000006oooool002Wooooo00?o0000oooooooo
ool06?ooool2o`000003ooooool0003o000000Gooooo0_l0000Fooooo`;o0000<oooool2o`00017o
oooo0_l000000ooooooo0000o`000006ooooo`;o00008oooool2o`0003;ooooo0_l0000dooooo`;o
00007_ooool002Wooooo00?o0000ooooooooool04?ooool2o`0000Kooooo0_l000000ooooooo0000
o`000005ooooo`;o00005_ooool3o`0001Cooooo0_l0000Looooo`;o00001?ooool2o`0000Cooooo
0_l00005ooooo`;o00002Oooool2o`00027ooooo0_l0001Cooooo`;o00005_ooool2o`0000Gooooo
0_l0000Fooooo`00:Oooool2o`00017ooooo0_l0000;ooooo`;o00007?ooool2o`0001Cooooo0_l0
0006ooooo`;o00006_ooool2o`0000Cooooo0_l0000cooooo`Go0000D?ooool2o`0001Kooooo0_l0
0005ooooo`;o00005_ooool002Wooooo00?o0000ooooooooool07Oooool2o`0000cooooo0_l00000
0ooooooo0000o`00000Yooooo`;o00003_ooool2o`0001_ooooo0_l0000=ooooo`;o00002Oooool4
o`0000gooooo1?l00002ooooo`;o00008?ooool2o`00067ooooo0006ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`0Mooooo`;o00003?ooool2o`000003ooooool0003o000003Wooooo0_l0
000Kooooo`;o00002?ooool2o`0000?ooooo0_l00009ooooo`Co00004oooool2o`0001gooooo0_l0
00000ooooooo0000o`000010ooooo`;o00003oooool2o`0000kooooo0006ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool05oooool2o`0003Kooooo0_l0000oooooo`;o0000
;_ooool2o`00017ooooo0_l000000ooooooo0000o`000013ooooo`Co00001_ooool2o`0000Gooooo
0_l0000>ooooo`001_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0
2Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Oooooo0_l00005ooooo`;o0000
;Oooool4o`0000Gooooo0_l0000:ooooo`Co00002oooool3o`0000cooooo0_l00003ooooo`;o0000
>Oooool2o`0000_ooooo0_l00004ooooo`;o0000B?ooool2o`000003ooooool0003o000000;o0000
00?oooooo`000?l000005Oooool000Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0001Oooooo0_l00005ooooo`;o0000
;Oooool2o`0000Oooooo0_l0000:ooooo`Co00002oooool3o`0000cooooo0_l00003ooooo`;o0000
5?ooool2o`0000Oooooo0_l0000Looooo`;o00002Oooool2o`00057ooooo1?l0000Hooooo`001_oo
ool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool05oooool2o`0000Oooooo0_l0000dooooo`;o
0000;oooool2o`0001;ooooo0_l00007ooooo`;o00004_ooool2o`0000Sooooo0_l0000?ooooo`;o
0000=Oooool2o`00033ooooo0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo0_l0000@ooooo`;o00003oooool2o`0001[o
oooo0_l0000=ooooo`;o00005_ooool2o`0002;ooooo0_l0000_ooooo`;o00004_ooool2o`0000Go
oooo0_l0000booooo`;o000000?oooooo`000?l000007oooool2o`0000oooooo0006ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooo
ooooool01oooool2o`00013ooooo0_l0000Cooooo`;o00002?ooool2o`0000Wooooo0_l000000ooo
oooo0000o`00000=ooooo`;o00005_ooool2o`0002Cooooo0_l00011ooooo`;o00005_ooool2o`00
00_ooooo0_l0000Dooooo`;o00008_ooool2o`0000oooooo0006ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooo
oooo02Cooooo0_l00008ooooo`;o00002Oooool2o`0000oooooo0_l0000Jooooo`;o00008Oooool2
o`0000Cooooo0_l0000>ooooo`;o0000;oooool3o`0000Kooooo0_l00009ooooo`;o00002oooool2
o`0001?ooooo0_l0000=ooooo`;o00009Oooool002Wooooo0_l0001;ooooo`;o00006_ooool2o`00
02Oooooo0_l0000>ooooo`;o0000;oooool3o`0000Kooooo0_l0000[ooooo`;o00001Oooool2o`00
00Kooooo0_l0000Uooooo`00:Oooool00ol0003oooooooooo`12ooooo`;o0000bOooool2o`0000Oo
oooo0_l0000Tooooo`00:Oooool00ol0003oooooooooo`12ooooo`;o0000]_ooool2o`0001[ooooo
0_l0000Tooooo`00:Oooool00ol0003oooooooooo`15ooooo`;o00006_ooool2o`0002oooooo0_l0
000>ooooo`?o0000EOooool2o`00043ooooo000Yooooo`03o`000?oooooooooo04Gooooo0_l0000J
ooooo`;o0000;oooool2o`0000kooooo0ol00009ooooo`;o00009oooool2o`0000;ooooo0_l0000N
ooooo`;o0000<?ooool2o`0000gooooo000Yooooo`;o00004oooool2o`0004[ooooo0_l0000moooo
o`;o00003oooool2o`0002Oooooo0_l00002ooooo`;o00007_ooool2o`00033ooooo0_l0000=oooo
o`00:Oooool00ol0003oooooooooo`0Booooo`;o00009?ooool2o`0002Cooooo0_l0000mooooo`;o
00005_ooool2o`0008Gooooo000Yooooo`03o`000?oooooooooo01oooooo0_l0000Gooooo`;o0000
Noooool2o`0008Gooooo000Yooooo`03o`000?oooooooooo01cooooo0_l000000ooooooo0000o`00
000Tooooo`;o0000Loooool2o`0001oooooo0_l00006ooooo`;o0000Eoooool002Wooooo00?o0000
ooooooooool07?ooool2o`0002Oooooo0_l0001cooooo`;o00007oooool2o`0000Kooooo0_l00012
ooooo`;o00004oooool002Wooooo0_l0000Kooooo`;o00002Oooool2o`0004_ooooo0_l0000doooo
o`;o0000OOooool2o`0001?ooooo000Yooooo`03o`000?oooooooooo00;ooooo0_l0000Fooooo`;o
00002Oooool2o`0004Sooooo0_l000000ooooooo0000o`00000Pooooo`;o00004_ooool2o`0000[o
oooo0_l00002ooooo`;o0000=_ooool2o`0001Oooooo0_l0000aooooo`00:Oooool00ol0003ooooo
ooooo`02ooooo`;o00003?ooool2o`0002oooooo0_l0000/ooooo`?o00007?ooool2o`0000Cooooo
0_l0000Nooooo`;o00000_ooool2o`0000Cooooo0_l00003ooooo`;o0000:oooool2o`0001Oooooo
0_l0000aooooo`00:Oooool00ol0003oooooooooo`0@ooooo`;o0000;oooool2o`0002gooooo0_l0
000Looooo`;o0000;_ooool2o`0000?ooooo0_l0001gooooo`00:Oooool00ol0003oooooooooo`2f
ooooo`;o0000Q?ooool002Wooooo0_l0001Jooooo`;o0000Foooool2o`0003Wooooo0_l0000=oooo
o`;o0000>_ooool002Wooooo00?o0000ooooooooool0Aoooool2o`00013ooooo0_l0000Iooooo`;o
0000Noooool2o`0000gooooo0_l0000jooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`17oooo
o`;o0000:oooool2o`000<Kooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1Cooooo`;o0000=Oooool2o`00
04Wooooo0_l0001Uooooo`003_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooo
ooooool00oooool3o`0002;ooooo0_l0000_ooooo`;o0000=Oooool2o`0000Gooooo0_l00012oooo
o`;o0000IOooool000kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool08_ooool2o`0006gooooo0_l0002=ooooo`;o00006_ooool000ko
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`3oooooob7ooooo0_l0000Jooooo`003_ooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Gooooo`;o0000hoooool0
00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0Eoooool2o`000>?ooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0ooooool8ooooo`;o0000<oooool002Wooooo00?o0000ooooooooool0
j?ooool2o`0001gooooo0_l0000cooooo`00:Oooool00ol0003oooooooooo`13ooooo`;o0000Xooo
ool2o`0005;ooooo000Yooooo`;o0000A?ooool2o`000>Gooooo0_l0000@ooooo`00:Oooool00ol0
003oooooooooo`3oooooob_ooooo0_l0000@ooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_oo
ool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmoooo
o`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo
00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05
oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo
00?ooooo0ol0003oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00olQ
8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmoooo
o`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@
413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?oo
ool4o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`007oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooolmooooo`00
8Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o
0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`007oooool00omEEEGoIVIVo`00
003oooooodOooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .25448 Mdot
.02762 .40357 Mdot
.02952 .27478 Mdot
.03143 .25874 Mdot
.03333 .25253 Mdot
.03524 .38495 Mdot
.03714 .31105 Mdot
.03905 .39097 Mdot
.04095 .41676 Mdot
.04286 .30085 Mdot
.04476 .34675 Mdot
.04667 .35262 Mdot
.04857 .2646 Mdot
.05048 .3517 Mdot
.05238 .36799 Mdot
.05429 .34317 Mdot
.05619 .37702 Mdot
.0581 .25232 Mdot
.06 .34888 Mdot
.0619 .417 Mdot
.06381 .2706 Mdot
.06571 .39951 Mdot
.06762 .3929 Mdot
.06952 .24155 Mdot
.07143 .2475 Mdot
.07333 .33835 Mdot
.07524 .32024 Mdot
.07714 .32863 Mdot
.07905 .40625 Mdot
.08095 .40186 Mdot
.08286 .25383 Mdot
.08476 .42454 Mdot
.08667 .43166 Mdot
.08857 .3264 Mdot
.09048 .26048 Mdot
.09238 .40369 Mdot
.09429 .23256 Mdot
.09619 .26207 Mdot
.0981 .40055 Mdot
.1 .3122 Mdot
.1019 .22917 Mdot
.10381 .25038 Mdot
.10571 .36449 Mdot
.10762 .31384 Mdot
.10952 .23937 Mdot
.11143 .34251 Mdot
.11333 .33833 Mdot
.11524 .38639 Mdot
.11714 .27172 Mdot
.11905 .41719 Mdot
.12095 .37511 Mdot
.12286 .33999 Mdot
.12476 .25476 Mdot
.12667 .30895 Mdot
.12857 .3468 Mdot
.13048 .44213 Mdot
.13238 .38846 Mdot
.13429 .37643 Mdot
.13619 .30081 Mdot
.1381 .24077 Mdot
.14 .35143 Mdot
.1419 .42918 Mdot
.14381 .40117 Mdot
.14571 .27835 Mdot
.14762 .43993 Mdot
.14952 .43862 Mdot
.15143 .27968 Mdot
.15333 .33807 Mdot
.15524 .28008 Mdot
.15714 .2345 Mdot
.15905 .3492 Mdot
.16095 .27236 Mdot
.16286 .29621 Mdot
.16476 .25629 Mdot
.16667 .40147 Mdot
.16857 .30579 Mdot
.17048 .25507 Mdot
.17238 .36314 Mdot
.17429 .36221 Mdot
.17619 .26358 Mdot
.1781 .28703 Mdot
.18 .39715 Mdot
.1819 .27765 Mdot
.18381 .24325 Mdot
.18571 .4285 Mdot
.18762 .33029 Mdot
.18952 .24963 Mdot
.19143 .25529 Mdot
.19333 .37915 Mdot
.19524 .33937 Mdot
.19714 .24682 Mdot
.19905 .38638 Mdot
.20095 .33835 Mdot
.20286 .30223 Mdot
.20476 .32667 Mdot
.20667 .40523 Mdot
.20857 .35094 Mdot
.21048 .36253 Mdot
.21238 .27875 Mdot
.21429 .37765 Mdot
.21619 .28322 Mdot
.2181 .37455 Mdot
.22 .36775 Mdot
.2219 .33753 Mdot
.22381 .26691 Mdot
.22571 .3048 Mdot
.22762 .33733 Mdot
.22952 .35951 Mdot
.23143 .33866 Mdot
.23333 .2349 Mdot
.23524 .34102 Mdot
.23714 .25867 Mdot
.23905 .41927 Mdot
.24095 .42201 Mdot
.24286 .47208 Mdot
.24476 .32879 Mdot
.24667 .36045 Mdot
.24857 .44528 Mdot
.25048 .44261 Mdot
.25238 .2566 Mdot
.25429 .27293 Mdot
.25619 .39544 Mdot
.2581 .34743 Mdot
.26 .39889 Mdot
.2619 .23445 Mdot
.26381 .26727 Mdot
.26571 .4233 Mdot
.26762 .43746 Mdot
.26952 .34625 Mdot
.27143 .28586 Mdot
.27333 .38776 Mdot
.27524 .32123 Mdot
.27714 .3197 Mdot
.27905 .37508 Mdot
.28095 .38469 Mdot
.28286 .37351 Mdot
.28476 .23129 Mdot
.28667 .41937 Mdot
.28857 .28685 Mdot
.29048 .42157 Mdot
.29238 .35229 Mdot
.29429 .45718 Mdot
.29619 .30054 Mdot
.2981 .31994 Mdot
.3 .37661 Mdot
.3019 .42372 Mdot
.30381 .43845 Mdot
.30571 .49638 Mdot
.30762 .35514 Mdot
.30952 .27483 Mdot
.31143 .38769 Mdot
.31333 .37083 Mdot
.31524 .25276 Mdot
.31714 .23629 Mdot
.31905 .26787 Mdot
.32095 .35813 Mdot
.32286 .2666 Mdot
.32476 .38394 Mdot
.32667 .44464 Mdot
.32857 .23574 Mdot
.33048 .25495 Mdot
.33238 .26867 Mdot
.33429 .35452 Mdot
.33619 .22409 Mdot
.3381 .36859 Mdot
.34 .34638 Mdot
.3419 .25515 Mdot
.34381 .44132 Mdot
.34571 .30443 Mdot
.34762 .26691 Mdot
.34952 .24845 Mdot
.35143 .42171 Mdot
.35333 .33632 Mdot
.35524 .25494 Mdot
.35714 .25364 Mdot
.35905 .35769 Mdot
.36095 .43419 Mdot
.36286 .41773 Mdot
.36476 .36569 Mdot
.36667 .31815 Mdot
.36857 .40592 Mdot
.37048 .28168 Mdot
.37238 .27653 Mdot
.37429 .281 Mdot
.37619 .22499 Mdot
.3781 .28756 Mdot
.38 .40277 Mdot
.3819 .44343 Mdot
.38381 .42966 Mdot
.38571 .22611 Mdot
.38762 .3807 Mdot
.38952 .35687 Mdot
.39143 .42361 Mdot
.39333 .26688 Mdot
.39524 .40382 Mdot
.39714 .41487 Mdot
.39905 .25763 Mdot
.40095 .34703 Mdot
.40286 .27691 Mdot
.40476 .30646 Mdot
.40667 .27325 Mdot
.40857 .27133 Mdot
.41048 .2772 Mdot
.41238 .28301 Mdot
.41429 .27205 Mdot
.41619 .27368 Mdot
.4181 .28869 Mdot
.42 .33163 Mdot
.4219 .37584 Mdot
.42381 .26042 Mdot
.42571 .33157 Mdot
.42762 .33848 Mdot
.42952 .3335 Mdot
.43143 .36108 Mdot
.43333 .3057 Mdot
.43524 .31996 Mdot
.43714 .26139 Mdot
.43905 .3483 Mdot
.44095 .22426 Mdot
.44286 .30828 Mdot
.44476 .27793 Mdot
.44667 .33274 Mdot
.44857 .35838 Mdot
.45048 .29241 Mdot
.45238 .28959 Mdot
.45429 .31464 Mdot
.45619 .3422 Mdot
.4581 .30996 Mdot
.46 .40237 Mdot
.4619 .33702 Mdot
.46381 .3636 Mdot
.46571 .41491 Mdot
.46762 .3392 Mdot
.46952 .29988 Mdot
.47143 .28445 Mdot
.47333 .31249 Mdot
.47524 .3116 Mdot
.47714 .3722 Mdot
.47905 .25433 Mdot
.48095 .3572 Mdot
.48286 .33468 Mdot
.48476 .31034 Mdot
.48667 .4257 Mdot
.48857 .39157 Mdot
.49048 .36076 Mdot
.49238 .35034 Mdot
.49429 .43284 Mdot
.49619 .30593 Mdot
.4981 .30563 Mdot
.5 .35577 Mdot
.5019 .35343 Mdot
.50381 .39548 Mdot
.50571 .24159 Mdot
.50762 .3282 Mdot
.50952 .2761 Mdot
.51143 .28546 Mdot
.51333 .34449 Mdot
.51524 .26087 Mdot
.51714 .37632 Mdot
.51905 .29533 Mdot
.52095 .40595 Mdot
.52286 .35364 Mdot
.52476 .29529 Mdot
.52667 .31208 Mdot
.52857 .33817 Mdot
.53048 .31763 Mdot
.53238 .36051 Mdot
.53429 .23917 Mdot
.53619 .34205 Mdot
.5381 .38822 Mdot
.54 .41396 Mdot
.5419 .31986 Mdot
.54381 .41731 Mdot
.54571 .36294 Mdot
.54762 .30784 Mdot
.54952 .24876 Mdot
.55143 .26679 Mdot
.55333 .26496 Mdot
.55524 .33495 Mdot
.55714 .38633 Mdot
.55905 .33918 Mdot
.56095 .3619 Mdot
.56286 .39206 Mdot
.56476 .26322 Mdot
.56667 .28637 Mdot
.56857 .23879 Mdot
.57048 .37953 Mdot
.57238 .35942 Mdot
.57429 .29606 Mdot
.57619 .3402 Mdot
.5781 .41671 Mdot
.58 .30403 Mdot
.5819 .25683 Mdot
.58381 .44532 Mdot
.58571 .2705 Mdot
.58762 .3877 Mdot
.58952 .25928 Mdot
.59143 .2776 Mdot
.59333 .27275 Mdot
.59524 .36896 Mdot
.59714 .40426 Mdot
.59905 .37719 Mdot
.60095 .4937 Mdot
.60286 .24648 Mdot
.60476 .39126 Mdot
.60667 .3385 Mdot
.60857 .43003 Mdot
.61048 .24587 Mdot
.61238 .34761 Mdot
.61429 .37659 Mdot
.61619 .33139 Mdot
.6181 .27859 Mdot
.62 .34825 Mdot
.6219 .37261 Mdot
.62381 .29775 Mdot
.62571 .36777 Mdot
.62762 .32806 Mdot
.62952 .25882 Mdot
.63143 .28586 Mdot
.63333 .43564 Mdot
.63524 .30415 Mdot
.63714 .27307 Mdot
.63905 .28118 Mdot
.64095 .46774 Mdot
.64286 .31309 Mdot
.64476 .36774 Mdot
.64667 .2435 Mdot
.64857 .38309 Mdot
.65048 .28963 Mdot
.65238 .27009 Mdot
.65429 .29277 Mdot
.65619 .35305 Mdot
.6581 .35758 Mdot
.66 .30591 Mdot
.6619 .32733 Mdot
.66381 .37138 Mdot
.66571 .27193 Mdot
.66762 .28388 Mdot
.66952 .40344 Mdot
.67143 .38755 Mdot
.67333 .34849 Mdot
.67524 .27059 Mdot
.67714 .28893 Mdot
.67905 .2316 Mdot
.68095 .34175 Mdot
.68286 .38112 Mdot
.68476 .27347 Mdot
.68667 .44185 Mdot
.68857 .33216 Mdot
.69048 .42194 Mdot
.69238 .40225 Mdot
.69429 .32648 Mdot
.69619 .30897 Mdot
.6981 .45726 Mdot
.7 .35219 Mdot
.7019 .28032 Mdot
.70381 .4115 Mdot
.70571 .24728 Mdot
.70762 .29943 Mdot
.70952 .42166 Mdot
.71143 .34128 Mdot
.71333 .35539 Mdot
.71524 .46762 Mdot
.71714 .36866 Mdot
.71905 .32829 Mdot
.72095 .26521 Mdot
.72286 .22486 Mdot
.72476 .31329 Mdot
.72667 .28645 Mdot
.72857 .35304 Mdot
.73048 .39864 Mdot
.73238 .3195 Mdot
.73429 .23941 Mdot
.73619 .35169 Mdot
.7381 .36845 Mdot
.74 .27181 Mdot
.7419 .37727 Mdot
.74381 .35278 Mdot
.74571 .23425 Mdot
.74762 .34964 Mdot
.74952 .39745 Mdot
.75143 .26014 Mdot
.75333 .39424 Mdot
.75524 .27665 Mdot
.75714 .48776 Mdot
.75905 .23807 Mdot
.76095 .33777 Mdot
.76286 .27789 Mdot
.76476 .24359 Mdot
.76667 .37949 Mdot
.76857 .2855 Mdot
.77048 .25874 Mdot
.77238 .23444 Mdot
.77429 .26962 Mdot
.77619 .25735 Mdot
.7781 .36399 Mdot
.78 .29619 Mdot
.7819 .40004 Mdot
.78381 .32535 Mdot
.78571 .39194 Mdot
.78762 .26768 Mdot
.78952 .34901 Mdot
.79143 .21912 Mdot
.79333 .32441 Mdot
.79524 .35821 Mdot
.79714 .34619 Mdot
.79905 .31409 Mdot
.80095 .37251 Mdot
.80286 .35834 Mdot
.80476 .32354 Mdot
.80667 .33474 Mdot
.80857 .27414 Mdot
.81048 .30975 Mdot
.81238 .31658 Mdot
.81429 .29841 Mdot
.81619 .37371 Mdot
.8181 .29607 Mdot
.82 .25282 Mdot
.8219 .30028 Mdot
.82381 .26358 Mdot
.82571 .34176 Mdot
.82762 .26995 Mdot
.82952 .3276 Mdot
.83143 .39103 Mdot
.83333 .42225 Mdot
.83524 .30919 Mdot
.83714 .27793 Mdot
.83905 .33776 Mdot
.84095 .33902 Mdot
.84286 .33978 Mdot
.84476 .25396 Mdot
.84667 .25828 Mdot
.84857 .36946 Mdot
.85048 .3623 Mdot
.85238 .43464 Mdot
.85429 .33767 Mdot
.85619 .30611 Mdot
.8581 .41929 Mdot
.86 .34573 Mdot
.8619 .34544 Mdot
.86381 .40054 Mdot
.86571 .23634 Mdot
.86762 .33136 Mdot
.86952 .26917 Mdot
.87143 .3544 Mdot
.87333 .34019 Mdot
.87524 .28045 Mdot
.87714 .34551 Mdot
.87905 .31439 Mdot
.88095 .26546 Mdot
.88286 .24857 Mdot
.88476 .31508 Mdot
.88667 .32797 Mdot
.88857 .25634 Mdot
.89048 .39165 Mdot
.89238 .31741 Mdot
.89429 .3711 Mdot
.89619 .39531 Mdot
.8981 .24037 Mdot
.9 .42145 Mdot
.9019 .23783 Mdot
.90381 .36122 Mdot
.90571 .43088 Mdot
.90762 .26239 Mdot
.90952 .35124 Mdot
.91143 .24471 Mdot
.91333 .34023 Mdot
.91524 .27758 Mdot
.91714 .33084 Mdot
.91905 .3753 Mdot
.92095 .42229 Mdot
.92286 .29059 Mdot
.92476 .35296 Mdot
.92667 .31439 Mdot
.92857 .32224 Mdot
.93048 .43942 Mdot
.93238 .37705 Mdot
.93429 .30705 Mdot
.93619 .34262 Mdot
.9381 .25376 Mdot
.94 .31362 Mdot
.9419 .31655 Mdot
.94381 .30464 Mdot
.94571 .38565 Mdot
.94762 .31118 Mdot
.94952 .35903 Mdot
.95143 .43927 Mdot
.95333 .25313 Mdot
.95524 .24694 Mdot
.95714 .31562 Mdot
.95905 .31335 Mdot
.96095 .32293 Mdot
.96286 .4691 Mdot
.96476 .32086 Mdot
.96667 .4035 Mdot
.96857 .28012 Mdot
.97048 .37788 Mdot
.97238 .295 Mdot
.97429 .41492 Mdot
.97619 .30535 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0??ooooo0_l00017ooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool0HOooool2o`0001oooooo0_l0001_ooooo`;o0000Aoooool000Kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1Qooooo`;o00002oooool2o`000003ooooool0
003o000000oooooo0_l0001Iooooo`;o0000GOooool000Co00000_ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo01Gooooo0_l0001Gooooo`;o000000?oooooo`000?l00000J_ooool2o`0005gooooo0006
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol0000Cooooo`Co0000>Oooool2o`0007gooooo0_l0001[ooooo`001_ooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool04oooool2o`0001;ooooo0_l0000Gooooo`;o0000
1oooool2o`0000Gooooo0_l00009ooooo`;o000000?oooooo`000?l00000Koooool2o`0001?ooooo
0_l00007ooooo`;o00007?ooool2o`0002oooooo0006ooooo`05oa0@4?ooooooooooooooool@4100
3oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
6?ooool2o`0000gooooo0_l0000Gooooo`;o00001oooool2o`00013ooooo0_l000000ooooooo0000
o`000010ooooo`;o00002Oooool2o`0003Cooooo0_l000000ooooooo0000o`000003ooooo`;o0000
0_ooool2o`0001cooooo0_l00008ooooo`Co00008oooool000Kooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00_ooooo0_l0000;ooooo`;o00001oooool2o`0000gooooo0_l0001Uooooo`;o
00001oooool2o`0000Wooooo0_l0000Hooooo`;o00006_ooool2o`0000Kooooo0_l0000Zooooo`Co
00008oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool02oooool2o`0001Cooooo0_l0000=oooo
o`;o0000IOooool2o`0001gooooo0_l000000ooooooo0000o`00000:ooooo`;o00009?ooool2o`00
02gooooo0_l0000Pooooo`00:Oooool2o`0000gooooo0_l0000Tooooo`Co0000;oooool2o`0003ko
oooo0_l0000?ooooo`;o000000?oooooo`000?l000007Oooool2o`00017ooooo0_l0000Sooooo`;o
00002?ooool2o`0000cooooo0_l0000Booooo`00:Oooool01?l0003oooooo`000?l00006ooooo`;o
00000oooool2o`0000Sooooo0_l0000Jooooo`Co00009?ooool2o`0000Wooooo0_l0000nooooo`;o
0000<Oooool2o`0002;ooooo0_l0000Booooo`;o00005_ooool2o`0001;ooooo000Yooooo`Co0000
1_ooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000cooooo0_l00005ooooo`;o0000
9_ooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`0002Kooooo0_l0001[ooooo`;o0000
1_ooool2o`0001cooooo0_l00003ooooo`;o00004oooool002Wooooo1?l0000>ooooo`;o00003?oo
ool2o`0000_ooooo0ol00005ooooo`;o00003Oooool2o`0000?ooooo0_l0000Gooooo`;o00000_oo
ool2o`0000;ooooo0_l0000<ooooo`;o00006?ooool2o`0001oooooo0_l0000=ooooo`;o0000:ooo
ool4o`0001Cooooo0ol0000;ooooo`;o00003_ooool2o`0000?ooooo0_l0000Cooooo`00:Oooool0
1?l0003oooooo`000?l0000Aooooo`Co00005?ooool2o`0001Gooooo0_l00003ooooo`;o0000;Ooo
ool2o`0000Kooooo0_l00002ooooo`;o00005oooool2o`0001Cooooo1?l0000;ooooo`;o00009Ooo
ool2o`0000Cooooo1?l0000Eooooo`;o00002oooool2o`0002Sooooo000Yooooo`;o00001Oooool2
o`0000cooooo1?l0000Gooooo`;o0000C_ooool2o`0000;ooooo0_l0000Gooooo`;o00002oooool2
o`000003ooooool0003o000000Kooooo0_l0000Xooooo`;o00002?ooool2o`0001Kooooo0_l0000H
ooooo`;o00008_ooool002Wooooo00?o0000ooooooooool01?ooool2o`0002Oooooo0_l0000>oooo
o`;o00002_ooool2o`00013ooooo0ol00006ooooo`;o00003Oooool2o`00037ooooo0ol000000ooo
oooo0000o`00000`ooooo`;o00005?ooool2o`0000[ooooo0_l0000@ooooo`;o00001_ooool2o`00
02;ooooo000Yooooo`03o`000?oooooooooo00Wooooo0_l0000Uooooo`Co000000Wo410@oooooooo
ooook^k^oc8b<_l0003o<S8bonk^k_ooool00_l000001Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_l0000@ooooo`?o000000?oooooo`000?l000000oooool2o`0000Oooooo1Ol000001Ooooooo0000
o`000?o^k^ko<S8b00?o00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Cooooo0_l00002oooo
o`05oiRHV?l@413o0000oc8b<_o<c<`00_ooool2o`000004oc8b<_l0003o<S8bonk^kP?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP07ooooo`;o00001_ooool2o`0001Wooooo0_l000000ol@413ooooo
ooooo`02o`000004oc8b<_l0003o0000o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`;o00002oooool2o`0000;ooooo0_l0000Cooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Ooo
ool00ol0003oooooooooo`09ooooo`;o00003oooool2o`0000cooooo0_l00008ooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00_ooool2o`0001Oooooo0_l0000<ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool00omg
MgOoV9RHo`000004o`000006oooooomgMgOoV9RHoooooonHV9SoMgMg:?ooool01Ol@413o^[Zjoooo
oomgMgOo<S8b00;ooooo1?l000000onHV9SoMgMgooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00_ooool2o`0000?ooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l0000@oooo
o`;o00001Oooool01?l0003oooooooooooooool2o`000004oiRHV?ooooooV9RHogMgM`?ooooo00Go
MgMgoiRHV?l0003o0000ogMgM`03ooooo`;o00002oooool2o`0001[ooooo00WoMgMgoc8b<_oooooo
ooooogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000Y
ooooo`?o00006_ooool2o`0000cooooo0_l00005ooooo`;o000000?oooooo`000?ooool00oooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4002ooooo`;o0000
4?ooool2o`0001;ooooo0_l000000onHV9So8B4Qonk^kP04ooooo`03oa0@4?l0003o000000Co0000
00?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0Dooooo`;o00005?ooool01Ol0003ooooo
oooooooooooo410@00;o000000?ooooooa0@4?ooool00_ooool01Ol@413ooooooooooooooooo410@
00;ooooo0_l00008ooooo`;o00001?ooool2o`00013ooooo0_l00002ooooo`Go00000oooool01Ol@
413ooooooooooooooooo410@00?ooooo00Go410@ooooool0003o0000oa0@400Oooooo`;o00003?oo
ool01?l0003oooooooooool@4103ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`01ooooo`00:Oooool3o`0002?ooooo1_l00006ooooo`;o000000?oooooo`000?ooool0
0oooool00ol0003oooooo`000002o`0000?ooooo00Go0000ooooooooooooooooo`00000Dooooo`;o
00004_ooool2o`000004oooooonHV9So8B4Qonk^kP?ooooo0ol000000ooooooo0000o`000002oooo
o`05o`000?ooooooooooooooool000000_ooool2o`0001;ooooo0_l0000Cooooo`03ojVYZOl@413o
oooo00;ooooo0ol000000ooooooo0000ooooo`02ooooo`?o000000?oooooo`000?ooool05_ooool2
o`0000oooooo0_l000000ooooooo0000o`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000Kooooo0_l0000:ooooo`;o00002oooool2o`0000_ooooo
00CoMgMgoc8b<_oooooooooo0_l00002ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`01ooooo`00:Oooool00ol0003oooooooooo`0Sooooo`Ko00002Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooo000000;o00000oooool01Ol0003ooooooooooooooooo0000
02Sooooo0ol000000oooooooMgMgofIVIP03ooooo`04o`000?ooooooooooooooo`;o00000_ooool0
1Ol0003ooooooooooooooooo000000;ooooo0_l0000Vooooo`03oa0@4?l0003o^[Zj00?ooooo00Go
0000ooooooooooooooooo`000003ooooo`?o000000?oooooo`000?ooool00_ooool2o`0000Oooooo
0_l00009ooooo`;o00003oooool00ooMgMgoEEEEooooo`02o`0000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool2o`0000[ooooo0_l0000Eoooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool2o`0000;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo007ooooo000Yooooo`03o`000?oooooooooo02kooooo0_l00002
ooooo`03o`000?oooooooooo00;ooooo00?o410@ooooooooool00_l00003ooooo`05oa0@4?oooooo
ooooooooool@41002?ooool2o`0000?ooooo0_l0000Iooooo`?o00000_ooool01Ol0003ooooooooo
oooooooo410@00?ooooo0_l00002ooooo`05oa0@4?ooooooooooooooool@41002_ooool2o`0000_o
oooo0_l0000@ooooo`;o000000?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@
00?ooooo00Ko410@oooooooooooooooooa0@4?ooool4o`0000Oooooo0_l0000Aooooo`;o00002?oo
ool01?mgMgOoc<c<o`000?ooool2o`000003ooooool@413ooooo00;ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`03oa0@4?oooooooooo02Oooooo00?o0000ooooooooool01?ooool01Ol@413o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`00:Oooool00ol0
003oooooooooo`0^ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo0_l00003ooooo`;o00006_oo
ool3o`000003oiRHV?l@413ooooo00;ooooo00KoMgMgoiRHV?ooooooV9RHogMgMoooool2o`000005
ogMgMonHV9SooooooiRHV?mgMgL01?ooool2o`0000Cooooo0_l0000;ooooo`;o00003oooool01Ol@
413o0000o`000?nj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`06ogMgMonH
V9SooooooiRHV?mgMgOooooo0_l00004ooooo`;o00001_ooool2o`0000kooooo0_l00008ooooo`04
onk^k_m4A4Co0000ooooo`;o000000KoooooogMgMonHV9SooooooiRHV?mgMgL3ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0:Oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000Yooooo`03o`000?oooooooooo033o
oooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Yooooo`05oiRHV?l0003o0000ob4Q8Oo<c<`00oooool01_o^k^ko<S8bo`00
0?lb<S;ok^k^ooooo`;o000000Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`?o00008_ooool01OnY
ZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01oooool3o`0000Gooooo0_l0000Iooooo`03ogMgMol0003ooooo00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08Oooool2o`00
00Kooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo000Yooooo`;o0000:_ooool2o`0005[ooooo0_l0000Eooooo`?o00003_ooool2
o`0001Sooooo0_l0000Vooooo`;o00002oooool2o`0001oooooo0_l0000>ooooo`;o00003Oooool0
02Wooooo00?o0000ooooooooool0:Oooool2o`00077ooooo0ol0000>ooooo`;o00003_ooool2o`00
01Wooooo0_l0000Eooooo`;o00002Oooool4o`0002oooooo0_l0000=ooooo`00:Oooool00ol0003o
ooooooooo`02ooooo`;o00007?ooool2o`0001Cooooo0_l0000Looooo`;o0000=_ooool2o`0002oo
oooo0_l0000Iooooo`;o00008?ooool2o`000003ooooool0003o000003gooooo000Yooooo`03o`00
0?oooooooooo00;ooooo0_l0000Looooo`;o00005?ooool2o`0000Gooooo0_l0000Eooooo`;o0000
3_ooool2o`0001[ooooo0_l0000:ooooo`;o00001oooool2o`0001Sooooo0_l0000@ooooo`;o0000
>_ooool2o`0002Gooooo0_l00009ooooo`;o00002oooool002Wooooo00?o0000ooooooooool0:ooo
ool2o`00013ooooo0_l0000Uooooo`;o00004Oooool2o`0000Oooooo0_l000000ooooooo0000o`00
000?ooooo`?o00003_ooool2o`0000Sooooo0_l0000@ooooo`;o00001_ooool2o`0003gooooo0_l0
000Gooooo`;o000000?oooooo`000?l000002Oooool2o`0000_ooooo000Qoooooooo0000A?l00004
ooooo`00:Oooool01?l0003oooooooooooooool2o`0000Kooooo00?o0000ooooooooool02Oooool4
o`0000Cooooo0_l00003ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`03o`0000?ooooo0_l000000ooooooo0000o`00000:ooooo`04o`000?oooooo
0000o`0000Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`04o`000?oo
oooo0000o`0000Sooooo00?o0000ooooooooool01?ooool2o`0000Cooooo00Co0000oooooooooooo
oooo0_l00006ooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooooooo0_l000000ooo
oooo0000o`000003ooooo`03o`000?oooooooooo00;o00002?ooool01?l0003oooooooooooooool2
o`0000Kooooo00?o0000ooooooooool01Oooool2o`0000;ooooo1?l00002ooooo`;o00001?ooool0
0ol0003oooooooooo`0:ooooo`00:Oooool00ol0003oooooooooo`0Eooooo`Co00008Oooool00ol0
003oooooooooo`0^ooooo`;o00002oooool00ol0003oooooooooo`0<ooooo`;o00001?ooool2o`00
00oooooo0ol0000Dooooo`03o`000?oooooooooo00_ooooo0_l0000Iooooo`;o00004_ooool01?l0
003oooooooooooooool2o`0000;ooooo0_l0000Cooooo`Co000000?oooooo`000?l000002Oooool2
o`0000;ooooo0_l00003ooooo`?o00001?ooool00ol0003oooooooooo`0:ooooo`00:Oooool00ol0
003oooooooooo`0=ooooo`;o0000?_ooool3o`0000Cooooo0_l0000Eooooo`;o00005?ooool2o`00
01cooooo0_l00002ooooo`;o0000>oooool2o`0001Sooooo0_l0000Eooooo`;o000000?oooooo`00
0?l000003Oooool2o`0000?ooooo0_l000000ooooooo0000o`00000?ooooo`00:Oooool00ol0003o
ooooooooo`0=ooooo`;o0000?_ooool3o`0000Cooooo0_l0000[ooooo`;o00008?ooool2o`0003_o
oooo0_l0000Eooooo`;o00009_ooool2o`0000Wooooo0ol0000?ooooo`00:Oooool2o`0001;ooooo
0_l0000Sooooo`;o0000TOooool2o`0000Wooooo0_l0000Kooooo`;o000000Coooooo`000?l0003o
oooo0_l0000Vooooo`;o00002Oooool2o`00013ooooo000Yooooo`03o`000?oooooooooo00gooooo
0_l00002ooooo`;o00007_ooool2o`0000?ooooo0_l0000;ooooo`;o0000Doooool2o`0002Cooooo
0_l00009ooooo`;o00002Oooool2o`0000Kooooo0_l0000Cooooo`;o000000?oooooo`000?l00000
2Oooool2o`00017ooooo0_l0000Xooooo`00:Oooool00ol0003oooooooooo`0=ooooo`;o00008_oo
ool2o`00013ooooo0_l0000gooooo`Go00000oooool2o`0001;ooooo0_l0000Qooooo`;o000000?o
ooooo`000?l000004_ooool2o`0000Sooooo0_l0000Qooooo`;o00002oooool2o`0000Cooooo0_l0
0008ooooo`;o00007_ooool002Wooooo00?o0000ooooooooool0I_ooool2o`0001Cooooo1Ol00003
ooooo`;o00002_ooool2o`0001Gooooo0_l0000Booooo`;o00005Oooool2o`0002Cooooo0_l0000B
ooooo`;o00003_ooool2o`0001kooooo000Yooooo`03o`000?oooooooooo00cooooo0_l0000;oooo
o`;o00002oooool2o`0000_ooooo1?l00005ooooo`Go00009Oooool2o`0001Kooooo0_l00009oooo
o`Co00000oooool2o`0000gooooo0_l00006ooooo`?o00003_ooool2o`0002oooooo0_l0000=oooo
o`;o00002?ooool4o`000003ooooool0003o000003?ooooo000Yooooo`;o00003Oooool2o`0000[o
oooo0ol000000ooooooo0000o`000008ooooo`;o00002oooool4o`0000Gooooo1_l0000looooo`;o
00001oooool6o`0001;ooooo1?l00005ooooo`;o00001?ooool2o`0000Sooooo0_l0000Fooooo`;o
00001oooool2o`0000kooooo0_l0000Cooooo`;o00000_ooool4o`000003ooooool0003o000000Co
oooo0_l0000;ooooo`;o00001_ooool2o`0001Sooooo000Yooooo`03o`000?oooooooooo00Kooooo
0_l0000@ooooo`;o00000_ooool2o`0002;ooooo0_l00015ooooo`;o00004Oooool2o`0000Gooooo
0_l0000;ooooo`;o00008?ooool2o`0000Oooooo0_l0000Sooooo`;o00002Oooool3o`000003oooo
ool0003o000000;o00002Oooool2o`0000Kooooo0_l0000Hooooo`00:Oooool00ol0003ooooooooo
o`03ooooo`;o000000?oooooo`000?l000000_l0000Dooooo`;o00002?ooool2o`0001kooooo0_l0
00000ooooooo0000o`00000Eooooo`;o00004_ooool2o`0000[ooooo0_l0000Fooooo`;o00007_oo
ool4o`0000oooooo0_l0000Sooooo`;o000000?oooooo`000?l000004_ooool3o`0000?ooooo0_l0
000[ooooo`00:Oooool00ol0003oooooooooo`03ooooo`Co000000?oooooo`000?l000005?ooool2
o`0000;ooooo0_l00004ooooo`;o00003_ooool2o`0000kooooo0_l000000ooooooo0000o`000006
ooooo`;o00003Oooool2o`0001;ooooo0_l0000:ooooo`;o00003oooool2o`0002Gooooo1?l0000?
ooooo`;o00001oooool2o`0000Wooooo0_l00002ooooo`;o00002oooool2o`000003ooooool0003o
000002;ooooo0_l0000Qooooo`00:Oooool00ol0003oooooooooo`04ooooo`?o00006oooool2o`00
01Cooooo0_l0000Iooooo`;o00000oooool2o`0000Kooooo0_l0000aooooo`;o000000?oooooo`00
0?l000001Oooool2o`0002Wooooo0_l0000<ooooo`;o00000_ooool2o`0000?ooooo1?l000001?oo
oooo0000o`000?l0000Vooooo`;o00002_ooool2o`0000?ooooo0_l0000Looooo`00:Oooool2o`00
00Gooooo0_l0001Booooo`;o00000_ooool2o`0000;ooooo0_l00006ooooo`;o00002?ooool2o`00
017ooooo0_l00008ooooo`;o00001?ooool3o`0000Gooooo0_l0000Yooooo`;o00004?ooool2o`00
00?ooooo0_l00003ooooo`;o00003_ooool2o`000003ooooool0003o000001Cooooo0_l0000?oooo
o`;o00007?ooool002Wooooo00?o0000ooooooooool0?_ooool2o`0000Cooooo0_l0000Fooooo`;o
00002_ooool2o`0000Sooooo0_l0000;ooooo`;o00001?ooool2o`0000Sooooo0_l000001?oooooo
0000o`000?ooool2o`0000Wooooo0_l0000;ooooo`;o00006Oooool2o`0002[ooooo0_l000000ooo
oooo0000o`00000Nooooo`;o00003Oooool2o`0001Cooooo000Yooooo`03o`000?oooooooooo01Oo
oooo0_l0000Cooooo`?o00002Oooool2o`0000Cooooo0_l00004ooooo`;o0000>Oooool2o`0000Wo
oooo0_l00006ooooo`;o00003?ooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`00043o
oooo0_l0000Eooooo`;o00003oooool2o`0000gooooo0_l0000Dooooo`00:Oooool00ol0003ooooo
ooooo`0Gooooo`;o00004oooool3o`0000Wooooo0_l000000ooooooo0000o`00000]ooooo`;o0000
7_ooool2o`0001Sooooo0_l00003ooooo`;o00004oooool2o`0000Cooooo0_l0000Yooooo`;o0000
5Oooool2o`0003Cooooo000Yooooo`03o`000?oooooooooo00Gooooo0_l0000dooooo`;o00007?oo
ool2o`0000Kooooo0_l00007ooooo`;o0000B?ooool2o`0000Sooooo0_l00004ooooo`;o00005Ooo
ool2o`0000Gooooo0_l0000Qooooo`;o0000=Oooool002Wooooo0_l00006ooooo`;o0000BOooool2
o`0000Oooooo0_l00006ooooo`;o0000:oooool2o`0002Cooooo0_l00007ooooo`;o00002oooool2
o`0000oooooo0_l00005ooooo`;o00004_ooool2o`0000?ooooo0_l00008ooooo`;o00003Oooool2
o`0002Kooooo000Yooooo`03o`000?oooooooooo00Oooooo0_l0000Cooooo`;o00000_ooool2o`00
01Wooooo0_l0000Aooooo`Co00000oooool2o`0002Gooooo0_l0000@ooooo`;o00002oooool2o`00
01Sooooo0_l00003ooooo`;o000000?oooooo`000?l000002oooool2o`0002[ooooo0_l00003oooo
o`;o00005oooool2o`0000Kooooo0_l00002ooooo`;o00006_ooool000Kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo00Oooooo0_l0000Cooooo`;o00000_ooool2o`00017ooooo0_l00005
ooooo`?o00004Oooool2o`0000Gooooo0_l0000Uooooo`;o00007Oooool2o`0000oooooo0_l00007
ooooo`;o00000oooool2o`0002Oooooo0_l00006ooooo`;o0000;oooool2o`0000;ooooo0_l0000;
ooooo`;o00003Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`0cooooo`;o00001Oooool2o`0003Gooooo0_l0000iooooo`;o00005oooool2o`0000Wooooo0_l0
000Aooooo`;o00001_ooool2o`00043ooooo0_l0000=ooooo`001_ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;o00006?ooool2o`0001Wooooo0_l0000Hooooo`;o00003?ooool2o`0001;ooooo0_l0
000eooooo`;o00006oooool2o`0000Wooooo0_l0001Cooooo`;o00005Oooool000Kooooo00Go0000
ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?oo
ool5o`0001Sooooo0_l00003ooooo`;o00005?ooool2o`0001Kooooo1?l00008ooooo`;o00000_oo
ool2o`0004?ooooo0_l00004ooooo`;o00002?ooool2o`0001Wooooo0_l0001Fooooo`;o00005Ooo
ool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`04o`000?ooooooooooooooo`;o00007?ooool2o`0002co
oooo0_l0000:ooooo`;o0000=oooool2o`0000kooooo0_l00006ooooo`;o00001_ooool2o`0000?o
oooo0_l0000Dooooo`;o00008_ooool2o`0000gooooo0_l0000Aooooo`;o00009oooool000Kooooo
00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01oooool01?l0003oooooooooooooool2o`0000Oooooo0_l0000kooooo`;o0000BOooool2o`00
00?ooooo0_l0000Aooooo`;o00002oooool2o`0002kooooo0_l00008ooooo`;o00003Oooool2o`00
017ooooo1?l0000Uooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool2
o`0002;ooooo0_l0000Gooooo`?o0000COooool2o`0004Kooooo0_l00005ooooo`?o0000;?ooool2
o`0002Gooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo00[ooooo0_l00003ooooo`;o00000ooo
ool2o`0000gooooo0_l00005ooooo`;o00000_ooool2o`0001Sooooo0_l0002Eooooo`;o00001Ooo
ool2o`0000Sooooo0_l0000Hooooo`;o0000<?ooool002Wooooo0_l0000;ooooo`;o00000oooool2
o`000003ooooool0003o000000;o00003Oooool2o`0000Gooooo0_l0000;ooooo`;o0000=_ooool2
o`0000?ooooo0_l0000Cooooo`;o0000:_ooool2o`0001Gooooo0_l00005ooooo`;o00006oooool2
o`0001Sooooo0_l0000Oooooo`;o00003oooool002Wooooo0_l0000?ooooo`;o00000_ooool2o`00
02?ooooo0_l0000booooo`;o00000_ooool2o`0000?ooooo0_l0000Cooooo`;o00004Oooool2o`00
01Oooooo0_l0000Eooooo`;o00001Oooool2o`0005Kooooo0_l0000?ooooo`00:Oooool00ol0003o
ooooooooo`0>ooooo`;o0000Foooool2o`0002oooooo0_l0002Nooooo`00:Oooool00ol0003ooooo
ooooo`2Rooooo`;o0000<oooool2o`0006?ooooo000Yooooo`03o`000?oooooooooo00;ooooo0_l0
0005ooooo`;o00004?ooool2o`0005Oooooo0_l0000Dooooo`;o00005_ooool3o`0000Wooooo0_l0
000Wooooo`;o0000EOooool2o`0000cooooo000Yooooo`;o00000oooool2o`0000Gooooo0_l0000@
ooooo`;o00009?ooool2o`0000kooooo0_l0000Fooooo`;o00002Oooool2o`0001Cooooo0_l0000G
ooooo`;o00002Oooool2o`0005Wooooo0_l0000Sooooo`;o00003?ooool002Wooooo00?o0000oooo
ooooool0@Oooool3o`0000Kooooo0_l00005ooooo`?o00000_ooool2o`0000kooooo0_l000000ooo
oooo0000o`000007ooooo`;o0000Goooool2o`0000Cooooo0_l0000Vooooo`;o00001_ooool2o`00
00_ooooo0_l00005ooooo`;o00007Oooool002Wooooo00?o0000ooooooooool04?ooool2o`00033o
oooo0_l00006ooooo`;o00001_ooool2o`0000;ooooo0_l0000>ooooo`;o00002_ooool2o`0001go
oooo0_l00010ooooo`;o00001?ooool2o`0002Kooooo0_l0000Cooooo`;o00001Oooool2o`0001go
oooo000Yooooo`03o`000?oooooooooo013ooooo0_l0000@ooooo`;o00003?ooool2o`0003kooooo
0_l0000Oooooo`;o00009Oooool2o`0008;ooooo000Yooooo`03o`000?oooooooooo013ooooo0_l0
000@ooooo`;o00003?ooool2o`0003kooooo0_l0000Rooooo`;o00008_ooool2o`0005kooooo0_l0
000Rooooo`00:Oooool2o`00017ooooo0_l0001Gooooo`;o0000:Oooool2o`0002[ooooo0_l00015
ooooo`;o00003oooool2o`0002;ooooo000Yooooo`03o`000?oooooooooo02Gooooo0_l0000Toooo
o`;o00002Oooool2o`00017ooooo0_l0001Eooooo`;o0000AOooool2o`0001Oooooo0_l00005oooo
o`;o00004oooool002Wooooo00?o0000ooooooooool07oooool2o`0000?ooooo0ol0000Tooooo`;o
00002Oooool2o`0000_ooooo0_l0001/ooooo`;o0000COooool2o`0000Gooooo0_l0000Cooooo`00
:Oooool00ol0003oooooooooo`0Oooooo`;o00000oooool2o`0001oooooo0_l0000Gooooo`;o0000
0oooool2o`0000[ooooo0_l0000oooooo`;o00007oooool2o`0006Wooooo000Yooooo`03o`000?oo
oooooooo04Gooooo0_l0000Gooooo`;o00003oooool2o`0003oooooo0_l0002:ooooo`00:Oooool2
o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`1Cooooo`;o0000P?ooool2o`0006Gooooo000>ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1C
ooooo`;o0000P?ooool2o`0006Gooooo000>ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`03ooooo`?o0000oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo
000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo000>oooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool0`oooool2o`0001Kooooo0_l0001=ooooo`;o00004?ooool000kooooo00Go410@
oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0@ooo
ool2o`0007kooooo0_l0000Fooooo`;o0000COooool2o`00013ooooo000>ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04?ooooo0_l0
003gooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000oooo
oolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0j?ooool2o`0005;ooooo000Yooooo`03o`00
0?oooooooooo0>Sooooo0_l0001Booooo`00:Oooool2o`000;Oooooo0_l00024ooooo`00:Oooool0
0ol0003oooooooooo`1Gooooo`;o0000GOooool2o`0008Cooooo000Yooooo`03o`000?oooooooooo
05Oooooo0_l0003Sooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0
003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool0
0omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolm
ooooo`001_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool0
0ol0003oooooooooo`03ooooo`?o0000oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo
000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<co
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Ooo
ool000Kooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool5o`0000Cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000
oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000
oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool001oooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgo
oooo000Qooooo`03o`000?oooooooooo00Gooooo0ol0003oooooocgooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001oooooo
00?oEEEEofIVI_l00000oooooom7ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .26428 Mdot
.02762 .36458 Mdot
.02952 .29694 Mdot
.03143 .29827 Mdot
.03333 .31751 Mdot
.03524 .38768 Mdot
.03714 .27377 Mdot
.03905 .44337 Mdot
.04095 .34475 Mdot
.04286 .2552 Mdot
.04476 .34378 Mdot
.04667 .42652 Mdot
.04857 .35865 Mdot
.05048 .32731 Mdot
.05238 .43208 Mdot
.05429 .32993 Mdot
.05619 .36463 Mdot
.0581 .34755 Mdot
.06 .29394 Mdot
.0619 .42326 Mdot
.06381 .36249 Mdot
.06571 .40181 Mdot
.06762 .40437 Mdot
.06952 .33305 Mdot
.07143 .35837 Mdot
.07333 .37069 Mdot
.07524 .35151 Mdot
.07714 .26297 Mdot
.07905 .42678 Mdot
.08095 .36059 Mdot
.08286 .34773 Mdot
.08476 .35968 Mdot
.08667 .44557 Mdot
.08857 .37482 Mdot
.09048 .26273 Mdot
.09238 .33941 Mdot
.09429 .32435 Mdot
.09619 .27522 Mdot
.0981 .42529 Mdot
.1 .4056 Mdot
.1019 .33183 Mdot
.10381 .32899 Mdot
.10571 .29143 Mdot
.10762 .23843 Mdot
.10952 .29602 Mdot
.11143 .27277 Mdot
.11333 .28246 Mdot
.11524 .28949 Mdot
.11714 .25678 Mdot
.11905 .4191 Mdot
.12095 .27305 Mdot
.12286 .40918 Mdot
.12476 .23932 Mdot
.12667 .24253 Mdot
.12857 .26416 Mdot
.13048 .41049 Mdot
.13238 .44217 Mdot
.13429 .36854 Mdot
.13619 .22936 Mdot
.1381 .31958 Mdot
.14 .28824 Mdot
.1419 .34613 Mdot
.14381 .42453 Mdot
.14571 .26826 Mdot
.14762 .43289 Mdot
.14952 .39441 Mdot
.15143 .26195 Mdot
.15333 .29207 Mdot
.15524 .25857 Mdot
.15714 .30947 Mdot
.15905 .3817 Mdot
.16095 .2837 Mdot
.16286 .25586 Mdot
.16476 .30709 Mdot
.16667 .42449 Mdot
.16857 .31053 Mdot
.17048 .23907 Mdot
.17238 .31998 Mdot
.17429 .41849 Mdot
.17619 .33738 Mdot
.1781 .23747 Mdot
.18 .34682 Mdot
.1819 .32947 Mdot
.18381 .3103 Mdot
.18571 .44817 Mdot
.18762 .34511 Mdot
.18952 .30413 Mdot
.19143 .28111 Mdot
.19333 .35706 Mdot
.19524 .29624 Mdot
.19714 .35749 Mdot
.19905 .45471 Mdot
.20095 .30858 Mdot
.20286 .24901 Mdot
.20476 .27528 Mdot
.20667 .46295 Mdot
.20857 .31927 Mdot
.21048 .258 Mdot
.21238 .22482 Mdot
.21429 .3699 Mdot
.21619 .24293 Mdot
.2181 .32957 Mdot
.22 .43292 Mdot
.2219 .24878 Mdot
.22381 .24745 Mdot
.22571 .36698 Mdot
.22762 .37919 Mdot
.22952 .33444 Mdot
.23143 .3116 Mdot
.23333 .31248 Mdot
.23524 .28672 Mdot
.23714 .29706 Mdot
.23905 .34903 Mdot
.24095 .38647 Mdot
.24286 .40258 Mdot
.24476 .30403 Mdot
.24667 .31013 Mdot
.24857 .42784 Mdot
.25048 .40613 Mdot
.25238 .3583 Mdot
.25429 .36465 Mdot
.25619 .28958 Mdot
.2581 .40028 Mdot
.26 .42769 Mdot
.2619 .30684 Mdot
.26381 .27662 Mdot
.26571 .39729 Mdot
.26762 .4713 Mdot
.26952 .2573 Mdot
.27143 .3262 Mdot
.27333 .40717 Mdot
.27524 .24075 Mdot
.27714 .40916 Mdot
.27905 .39359 Mdot
.28095 .33748 Mdot
.28286 .42281 Mdot
.28476 .32146 Mdot
.28667 .41841 Mdot
.28857 .2585 Mdot
.29048 .44675 Mdot
.29238 .4253 Mdot
.29429 .40595 Mdot
.29619 .33844 Mdot
.2981 .25638 Mdot
.3 .36655 Mdot
.3019 .41138 Mdot
.30381 .44345 Mdot
.30571 .47123 Mdot
.30762 .31537 Mdot
.30952 .2587 Mdot
.31143 .2774 Mdot
.31333 .31834 Mdot
.31524 .30306 Mdot
.31714 .32101 Mdot
.31905 .29835 Mdot
.32095 .39217 Mdot
.32286 .3674 Mdot
.32476 .42392 Mdot
.32667 .42093 Mdot
.32857 .33204 Mdot
.33048 .3577 Mdot
.33238 .34272 Mdot
.33429 .41584 Mdot
.33619 .30507 Mdot
.3381 .27615 Mdot
.34 .26466 Mdot
.3419 .26387 Mdot
.34381 .43961 Mdot
.34571 .23381 Mdot
.34762 .26899 Mdot
.34952 .35152 Mdot
.35143 .39473 Mdot
.35333 .30122 Mdot
.35524 .31342 Mdot
.35714 .31934 Mdot
.35905 .3433 Mdot
.36095 .44267 Mdot
.36286 .46708 Mdot
.36476 .3925 Mdot
.36667 .27384 Mdot
.36857 .42585 Mdot
.37048 .3784 Mdot
.37238 .38349 Mdot
.37429 .33589 Mdot
.37619 .31589 Mdot
.3781 .26575 Mdot
.38 .3191 Mdot
.3819 .47104 Mdot
.38381 .36964 Mdot
.38571 .32412 Mdot
.38762 .32606 Mdot
.38952 .24306 Mdot
.39143 .41253 Mdot
.39333 .31734 Mdot
.39524 .30361 Mdot
.39714 .44861 Mdot
.39905 .24299 Mdot
.40095 .42346 Mdot
.40286 .2571 Mdot
.40476 .41197 Mdot
.40667 .35166 Mdot
.40857 .2821 Mdot
.41048 .27505 Mdot
.41238 .27263 Mdot
.41429 .33932 Mdot
.41619 .39047 Mdot
.4181 .24113 Mdot
.42 .31817 Mdot
.4219 .39231 Mdot
.42381 .28845 Mdot
.42571 .29513 Mdot
.42762 .35079 Mdot
.42952 .39681 Mdot
.43143 .31311 Mdot
.43333 .23379 Mdot
.43524 .34536 Mdot
.43714 .25731 Mdot
.43905 .28356 Mdot
.44095 .30338 Mdot
.44286 .26386 Mdot
.44476 .36033 Mdot
.44667 .41708 Mdot
.44857 .30436 Mdot
.45048 .23112 Mdot
.45238 .23622 Mdot
.45429 .23482 Mdot
.45619 .32984 Mdot
.4581 .35669 Mdot
.46 .35835 Mdot
.4619 .30337 Mdot
.46381 .43026 Mdot
.46571 .32054 Mdot
.46762 .2938 Mdot
.46952 .31755 Mdot
.47143 .39755 Mdot
.47333 .24662 Mdot
.47524 .35066 Mdot
.47714 .25849 Mdot
.47905 .29192 Mdot
.48095 .26878 Mdot
.48286 .39614 Mdot
.48476 .2385 Mdot
.48667 .34023 Mdot
.48857 .37292 Mdot
.49048 .26443 Mdot
.49238 .38179 Mdot
.49429 .37751 Mdot
.49619 .26092 Mdot
.4981 .39131 Mdot
.5 .28748 Mdot
.5019 .38201 Mdot
.50381 .4251 Mdot
.50571 .25973 Mdot
.50762 .29754 Mdot
.50952 .32502 Mdot
.51143 .37958 Mdot
.51333 .37023 Mdot
.51524 .32403 Mdot
.51714 .31399 Mdot
.51905 .31466 Mdot
.52095 .4465 Mdot
.52286 .2484 Mdot
.52476 .24649 Mdot
.52667 .35078 Mdot
.52857 .24408 Mdot
.53048 .32636 Mdot
.53238 .29496 Mdot
.53429 .30878 Mdot
.53619 .29102 Mdot
.5381 .35264 Mdot
.54 .36442 Mdot
.5419 .3659 Mdot
.54381 .37202 Mdot
.54571 .28768 Mdot
.54762 .25548 Mdot
.54952 .28904 Mdot
.55143 .36767 Mdot
.55333 .32456 Mdot
.55524 .36151 Mdot
.55714 .28981 Mdot
.55905 .35103 Mdot
.56095 .39297 Mdot
.56286 .4263 Mdot
.56476 .30101 Mdot
.56667 .33779 Mdot
.56857 .33754 Mdot
.57048 .43788 Mdot
.57238 .34128 Mdot
.57429 .32163 Mdot
.57619 .35896 Mdot
.5781 .36723 Mdot
.58 .24918 Mdot
.5819 .25647 Mdot
.58381 .47066 Mdot
.58571 .24008 Mdot
.58762 .43981 Mdot
.58952 .24834 Mdot
.59143 .27989 Mdot
.59333 .23845 Mdot
.59524 .25562 Mdot
.59714 .33762 Mdot
.59905 .43582 Mdot
.60095 .49057 Mdot
.60286 .30126 Mdot
.60476 .35781 Mdot
.60667 .24996 Mdot
.60857 .37128 Mdot
.61048 .35697 Mdot
.61238 .30666 Mdot
.61429 .27544 Mdot
.61619 .36911 Mdot
.6181 .31979 Mdot
.62 .40216 Mdot
.6219 .37359 Mdot
.62381 .37936 Mdot
.62571 .25293 Mdot
.62762 .31131 Mdot
.62952 .34583 Mdot
.63143 .35818 Mdot
.63333 .43938 Mdot
.63524 .32964 Mdot
.63714 .38095 Mdot
.63905 .22971 Mdot
.64095 .44446 Mdot
.64286 .26026 Mdot
.64476 .39479 Mdot
.64667 .29552 Mdot
.64857 .42319 Mdot
.65048 .34958 Mdot
.65238 .28365 Mdot
.65429 .27051 Mdot
.65619 .38127 Mdot
.6581 .42964 Mdot
.66 .39104 Mdot
.6619 .2761 Mdot
.66381 .4083 Mdot
.66571 .31858 Mdot
.66762 .27211 Mdot
.66952 .36225 Mdot
.67143 .38509 Mdot
.67333 .2672 Mdot
.67524 .34408 Mdot
.67714 .34862 Mdot
.67905 .26587 Mdot
.68095 .36974 Mdot
.68286 .3108 Mdot
.68476 .27258 Mdot
.68667 .43322 Mdot
.68857 .35115 Mdot
.69048 .41278 Mdot
.69238 .36518 Mdot
.69429 .33803 Mdot
.69619 .24989 Mdot
.6981 .4058 Mdot
.7 .42654 Mdot
.7019 .2346 Mdot
.70381 .35719 Mdot
.70571 .31262 Mdot
.70762 .36559 Mdot
.70952 .39207 Mdot
.71143 .26472 Mdot
.71333 .42799 Mdot
.71524 .45761 Mdot
.71714 .27489 Mdot
.71905 .41375 Mdot
.72095 .37508 Mdot
.72286 .29917 Mdot
.72476 .27219 Mdot
.72667 .24916 Mdot
.72857 .42552 Mdot
.73048 .44509 Mdot
.73238 .27999 Mdot
.73429 .28278 Mdot
.73619 .36795 Mdot
.7381 .3939 Mdot
.74 .24889 Mdot
.7419 .27682 Mdot
.74381 .26333 Mdot
.74571 .28311 Mdot
.74762 .41206 Mdot
.74952 .40115 Mdot
.75143 .24679 Mdot
.75333 .4046 Mdot
.75524 .38258 Mdot
.75714 .43739 Mdot
.75905 .33587 Mdot
.76095 .38787 Mdot
.76286 .3165 Mdot
.76476 .2578 Mdot
.76667 .35558 Mdot
.76857 .27355 Mdot
.77048 .37013 Mdot
.77238 .30392 Mdot
.77429 .28434 Mdot
.77619 .29082 Mdot
.7781 .36253 Mdot
.78 .34636 Mdot
.7819 .31219 Mdot
.78381 .23661 Mdot
.78571 .28533 Mdot
.78762 .37712 Mdot
.78952 .38005 Mdot
.79143 .31024 Mdot
.79333 .375 Mdot
.79524 .34144 Mdot
.79714 .35888 Mdot
.79905 .28071 Mdot
.80095 .43606 Mdot
.80286 .42918 Mdot
.80476 .35176 Mdot
.80667 .33026 Mdot
.80857 .33665 Mdot
.81048 .34536 Mdot
.81238 .22392 Mdot
.81429 .24918 Mdot
.81619 .28356 Mdot
.8181 .33708 Mdot
.82 .301 Mdot
.8219 .32931 Mdot
.82381 .26825 Mdot
.82571 .37851 Mdot
.82762 .33333 Mdot
.82952 .32645 Mdot
.83143 .2826 Mdot
.83333 .44688 Mdot
.83524 .28323 Mdot
.83714 .24929 Mdot
.83905 .37925 Mdot
.84095 .38744 Mdot
.84286 .36894 Mdot
.84476 .29312 Mdot
.84667 .24292 Mdot
.84857 .44753 Mdot
.85048 .27622 Mdot
.85238 .33602 Mdot
.85429 .24864 Mdot
.85619 .33411 Mdot
.8581 .35077 Mdot
.86 .42191 Mdot
.8619 .34474 Mdot
.86381 .35961 Mdot
.86571 .25874 Mdot
.86762 .33406 Mdot
.86952 .31179 Mdot
.87143 .35086 Mdot
.87333 .24534 Mdot
.87524 .34939 Mdot
.87714 .43445 Mdot
.87905 .26686 Mdot
.88095 .25829 Mdot
.88286 .3263 Mdot
.88476 .26384 Mdot
.88667 .29914 Mdot
.88857 .3085 Mdot
.89048 .44349 Mdot
.89238 .32729 Mdot
.89429 .42175 Mdot
.89619 .3399 Mdot
.8981 .31742 Mdot
.9 .38623 Mdot
.9019 .28767 Mdot
.90381 .37975 Mdot
.90571 .47122 Mdot
.90762 .27921 Mdot
.90952 .42663 Mdot
.91143 .2557 Mdot
.91333 .28707 Mdot
.91524 .2359 Mdot
.91714 .36817 Mdot
.91905 .33802 Mdot
.92095 .41223 Mdot
.92286 .24034 Mdot
.92476 .30512 Mdot
.92667 .25102 Mdot
.92857 .37372 Mdot
.93048 .36399 Mdot
.93238 .31853 Mdot
.93429 .30995 Mdot
.93619 .26022 Mdot
.9381 .32641 Mdot
.94 .27228 Mdot
.9419 .26214 Mdot
.94381 .24232 Mdot
.94571 .33933 Mdot
.94762 .26788 Mdot
.94952 .36608 Mdot
.95143 .39661 Mdot
.95333 .31914 Mdot
.95524 .33165 Mdot
.95714 .25422 Mdot
.95905 .25417 Mdot
.96095 .31143 Mdot
.96286 .39613 Mdot
.96476 .3156 Mdot
.96667 .36335 Mdot
.96857 .23545 Mdot
.97048 .29049 Mdot
.97238 .25302 Mdot
.97429 .42254 Mdot
.97619 .40142 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo03Wooooo0_l0002oooooo`;o0000@?ooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`0iooooo`;o0000_oooool2o`00043ooooo0004o`0000;ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Pooooo`;o0000X?ooool2o`0007Sooooo0006ooooo`05o`000?oooooo
ooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0
000Pooooo`;o0000@_ooool2o`0001[ooooo0_l00003ooooo`;o0000>oooool2o`0007Sooooo0006
ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`1Tooooo`;o00006_ooool2o`0000?ooooo
1?l0001=ooooo`;o00006Oooool2o`0002Sooooo0_l0000?ooooo`;o00003_ooool000Kooooo00Go
410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Gooooo`;o00001?ooool2o`0000cooooo0_l000000ooooooo0000
o`00001Fooooo`?o00001oooool2o`0001oooooo1?l0000Qooooo`;o00006Oooool2o`0002Sooooo
1?l0000=ooooo`;o00003_ooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Oo
oooo0_l00004ooooo`;o00003?ooool2o`000003ooooool0003o000000[ooooo0_l0000Aooooo`;o
00008oooool2o`000003ooooool0003o000000Cooooo0_l0000Cooooo`;o00007oooool4o`00053o
oooo0_l0000Fooooo`;o00001Oooool2o`0001Kooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo
01gooooo0_l0000Kooooo`;o00004Oooool2o`0002?ooooo0_l000000ooooooo0000o`000004oooo
o`;o00004?ooool2o`0000kooooo1?l0001Tooooo`;o00001_ooool2o`0001Gooooo0_l0000Foooo
o`00:Oooool2o`0003Oooooo0_l00004ooooo`?o0000C_ooool2o`0000kooooo1?l0000>ooooo`;o
000000?oooooo`000?l00000:_ooool2o`0000?ooooo0_l000000ooooooo0000o`00000Booooo`;o
00001_ooool2o`0000?ooooo0_l00004ooooo`;o0000;Oooool002Wooooo00?o0000ooooooooool0
=_ooool2o`0000Cooooo0ol0001Nooooo`;o00004?ooool2o`000003ooooool0003o000000Cooooo
0_l0000Jooooo`;o00002?ooool2o`0000?ooooo0_l000000ooooooo0000o`00000Booooo`;o0000
1_ooool2o`0000?ooooo0_l0000Fooooo`;o00006oooool002Wooooo00?o0000ooooooooool00_oo
ool2o`0002Gooooo0_l0001jooooo`;o00003Oooool2o`0000;ooooo0_l00004ooooo`;o00005?oo
ool2o`0004Cooooo0_l00003ooooo`;o00001oooool3o`0000;ooooo0_l0000=ooooo`00:Oooool0
0ol0003oooooooooo`02ooooo`;o00005_ooool2o`0000_ooooo1?l0000=ooooo`;o00004Oooool2
o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o00007?ooool2o`0000Wooooo0_l0000;
ooooo`;o00005Oooool2o`0000Wooooo0_l00002ooooo`;o00002?ooool2o`0002_ooooo0_l0000N
ooooo`;o00000oooool2o`0000Sooooo0_l0000<ooooo`?o00000_ooool2o`0000gooooo000Yoooo
o`03o`000?oooooooooo01[ooooo0_l00009ooooo`Co00003oooool2o`00017ooooo0_l00004oooo
o`;o000000?oooooo`000?l000000_ooool2o`0001cooooo0_l00009ooooo`;o00002oooool2o`00
00Cooooo0_l000000ooooooo0000o`00000Gooooo`;o00004Oooool2o`0002Kooooo0_l0000Noooo
o`;o00000oooool2o`00013ooooo0ol0000Gooooo`00:Oooool2o`0000kooooo0_l00003ooooo`;o
00002_ooool2o`0000Gooooo0_l0000kooooo`?o00007_ooool2o`0000gooooo1?l000000ooooooo
0000o`00000Zooooo`;o00005?ooool2o`0000Wooooo0_l0000[ooooo`;o00003oooool3o`0001Oo
oooo000Yooooo`;o00003_ooool2o`0000?ooooo0_l0000:ooooo`;o00000oooool2o`0003gooooo
0ol00009ooooo`;o00004oooool2o`0000gooooo0_l0000iooooo`Co00002?ooool2o`0000Wooooo
0_l0000Hooooo`;o00003oooool4o`0001;ooooo0_l0000Eooooo`00:Oooool00ol0003ooooooooo
o`0Sooooo`;o00002oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h08?ooool2o`0000Oooooo1Ol00003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo0_l0000Iooooo`05oiRH
V?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP08ooooo`;o00001?ooool4o`0001Sooooo0_l000002Ol@413ooooooooooooo
ooook^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool2o`00
00oooooo0_l0000Dooooo`?o000000Wo<S8bomgMgOooooooooooonk^k_lb<S;o0000oc8b<_o^k^h0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Yooooo`04o`000?ooooooooooooooo`;o
00005Oooool2o`0000;ooooo0_l0000Dooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL08?ooool2o`0000Gooooo0_l00000
1OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00CoMgMgoiRHV?ooooooV9RH0_l00002ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03Oooool2o`0001Wooooo00Go410@okZj^_ooooooMgMgoc8b<P03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo0_l0
0002ooooo`;o00001?ooool2o`0000_ooooo0_l0000:ooooo`0:o`000?oooooo0000o`000?oooooo
MgMgoiRHV?ooooooV9RHogMgM`?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Wooooo`;o00000ooo
ool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool002Wooooo00Co0000oooooooooooooooo0_l0000Aooooo`;o00000_ooool2
o`0000;ooooo0_l0000Dooooo`04o`000?ooooooooooooooo`;o00000oooool01Ol@413ooooooooo
oooooooo410@00?ooooo00?o410@ooooooooool00oooool2o`0000kooooo0_l00006ooooo`;o0000
2?ooool2o`000004oooooonHV9So8B4Qonk^kPCooooo00Co410@oooooooooooooooo0_l00002oooo
o`05oa0@4?ooooooooooooooool@4100;?ooool01Ol0003ooooooooooooooooo410@00?ooooo00Co
410@oooooooooooooooo0_l00002ooooo`03oa0@4?oooooooooo00Sooooo1?l00004ooooo`;o0000
2?ooool2o`000003ooooool0003o000000?ooooo0_l00002ooooo`Oo000000?ooooooa0@4?ooool0
0_ooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool02?ooool2o`0001_o
oooo0_l00004ooooo`04o`000?oooooooooooa0@40?ooooo00Go410@oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo007ooooo000Yooooo`;o00005Oooool2o`0001cooooo00Co0000oooo
oooooooooooo0_l00003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`03ooooo`;o00003_ooool2o`0000Kooooo0_l0000<ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Co
0000oooooooooooooooo0_l00002ooooo`05o`000?ooooooooooooooool00000:oooool00onYZJWo
410@ooooo`02ooooo`?o000000?oooooo`000?ooool00_ooool2o`0000;ooooo00?o0000oooooooo
ool02?ooool2o`00013ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool01?m4A4Co
gMgMooooool00004ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000?ooooo00?o0000
ooooooooool02?ooool2o`00013ooooo0_l0000>ooooo`05ogMgMolb<S;oooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00Oooool002Wooooo00?o
0000ooooooooool06Oooool2o`0000gooooo0_l00008ooooo`;o00000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`00000/ooooo`03ogMgMomVIVKooooo00;o
oooo00?o0000ooooooooool00_l00003ooooo`04o`000?ooooooooooooooo`?o0000:?ooool00ol@
413o0000okZj^P03ooooo`?o000000?oooooo`000?ooool00_ooool01Ol0003ooooooooooooooooo
000000Oooooo0_l0000Hooooo`?o000000Soooooo`000?l0003oooooomgMgOmEEEGoooooo`0000Co
oooo00Go0000ooooooooooooooooo`000002ooooo`;o00000oooool2o`0000?ooooo0ol0000Eoooo
o`;o00002oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool002Wooooo00?o0000ooooooooool06Ooo
ool2o`0000gooooo0_l00008ooooo`;o00000oooool01Ol@413ooooooooooooooooo410@00?ooooo
00Go410@o`000?l0003ooooooa0@400]ooooo`05o`000?ooooooooooooooool@41000_ooool2o`00
00?ooooo00Go410@oooooooooooooooooa0@4002o`0002Wooooo00?o^[Zjob4Q8Oooool00_ooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4007ooooo`;o0000
6Oooool2o`000003ooooool0003o000000;ooooo00?oMgMgolc<c?l000000oooool2o`000004oooo
ool0003o0000oa0@40?ooooo00Co410@oooooooooooooooo0_l00003ooooo`?o00008_ooool00ol0
003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@00?ooooo000Yooooo`03o`000?oooooooooo01[ooooo0_l00006ooooo`;o00003_ooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOo0000o`00
0?nHV9SoMgMg00?ooooo0_l0000Tooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo0_l000000oooooooV9RHogMgM`0Cooooo`;o00003Oooool3o`00
0008ooooool0003o0000oa0@4?nHV9SooooookZj^_l00003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg02Wooooo00?ok^k^odA4A?l000000oooool2o`00
0004oiRHV?l0003o0000ogMgM`?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`;o000000?o
ooooo`000?l000002Oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000Yooooo`03o`000?oooooooooo01Oooooo
0_l000000ooooooo0000o`000006ooooo`;o00000_ooool2o`0000Sooooo00?oEEEEofIVI_l00000
1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`;o00009?ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`?o000000?o<S8bonk^k_ooool03?ooool2o`0000Cooooo0_l0000:ooooo`;o000000Go
ooooo`000?l0003o0000ooooo`02o`000005ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Zooooo`03ogMgMol0003o
oooo00;ooooo0_l000001?lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2?ooool2o`00017ooooo0_l000000ooooooo0000o`000009ooooo`Co00000oooool01Oo^k^ko0000
o`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool2o`0000Wo
oooo0_l0000=ooooo`?o00003?ooool2o`0000_ooooo0_l00018ooooo`;o00003?ooool2o`0000;o
oooo0_l0000?ooooo`?o00008_ooool2o`0002Oooooo0_l0000Dooooo`;o00009oooool2o`0000go
oooo000Yooooo`Co00001oooool2o`0000kooooo0_l0000Iooooo`;o00003?ooool2o`0001Sooooo
0_l0000Pooooo`;o00003?ooool2o`0000_ooooo0_l00006ooooo`;o00008oooool2o`0001Kooooo
0_l0000cooooo`;o0000:?ooool002Wooooo1?l00010ooooo`;o00006?ooool2o`0000Wooooo0_l0
000`ooooo`;o00004?ooool2o`0000[ooooo0_l0000Uooooo`;o00007Oooool2o`0001Cooooo0_l0
000Xooooo`00:Oooool00ol0003oooooooooo`0booooo`;o00003oooool2o`0001Gooooo0_l00005
ooooo`;o00000oooool2o`0000cooooo0_l0000<ooooo`;o000000?oooooo`000?l000000_ooool2
o`0001oooooo0_l0000:ooooo`;o0000=Oooool2o`0000gooooo0_l0000Pooooo`;o00007?ooool0
02Wooooo00?o0000ooooooooool0:_ooool2o`0000Kooooo0_l000000ooooooo0000o`00000<oooo
o`;o00001?ooool2o`0000oooooo0_l00005ooooo`;o00004Oooool2o`0000cooooo0_l000000ooo
oooo0000o`000002ooooo`;o00005Oooool2o`0001Sooooo0_l0000aooooo`;o00008oooool2o`00
00[ooooo0_l0000Looooo`008Oooooooo`0004Co00001?ooool002Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
0_ooool2o`0000;ooooo0_l000000ooooooo0000ooooo`02o`0000Sooooo00?o0000ooooooooool0
0_ooool3o`0000;ooooo0_l000000ooooooo0000ooooo`0:ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool01Oooool2o`0000;ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`04ooooo`;o00000oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo
0ol0000;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool2o`000003oooo
ool0003ooooo00[ooooo00?o0000ooooooooool00_l00006ooooo`?o00002oooool00ol0003ooooo
ooooo`07ooooo`Go00002Oooool00ol0003oooooooooo`0:ooooo`?o00002Oooool00ol0003ooooo
ooooo`07ooooo`?o00001_ooool2o`0000?ooooo00?o0000ooooooooool02_ooool002Wooooo00Co
0000ooooool0003o0000>Oooool00ol0003oooooooooo`03ooooo`;o00005_ooool2o`0000gooooo
0_l00005ooooo`;o00000oooool2o`0000?ooooo00?o0000ooooooooool01?ooool2o`0000_ooooo
0_l0000=ooooo`?o00005oooool00ol0003oooooooooo`0Pooooo`;o00004?ooool2o`0000Cooooo
0ol0000Rooooo`;o00005?ooool2o`0000;ooooo00?o0000ooooooooool02_ooool002Wooooo00Co
0000ooooool0003o00008?ooool2o`0000Wooooo0_l0000:ooooo`;o00007_ooool5o`0000[ooooo
0_l00005ooooo`?o00000_ooool2o`0000Oooooo0_l0000<ooooo`Co0000;Oooool2o`0000kooooo
0_l0000Mooooo`;o0000:Oooool2o`0000Wooooo0_l00005ooooo`;o00000_ooool2o`0000oooooo
000Yooooo`03o`000?oooooooooo01?ooooo0_l0000<ooooo`;o00002Oooool2o`0000[ooooo0_l0
000Fooooo`;o00001oooool4o`0000[ooooo0_l00006ooooo`Co00002Oooool2o`0000cooooo0_l0
000>ooooo`;o00004Oooool2o`0000cooooo0_l0000>ooooo`;o0000Doooool2o`0000Gooooo0_l0
000Cooooo`00:Oooool2o`0000Kooooo0_l0000<ooooo`;o0000=oooool2o`0000;ooooo0_l0000O
ooooo`;o00009Oooool4o`0000?ooooo0_l00006ooooo`;o00001?ooool2o`00053ooooo0_l0000?
ooooo`;o00000_ooool2o`0000cooooo0_l0000Hooooo`00:Oooool00ol0003oooooooooo`05oooo
o`?o00003_ooool2o`0001Oooooo0_l0000:ooooo`;o00003oooool2o`0002?ooooo0_l0000Doooo
o`;o00003oooool2o`0000Gooooo0_l00006ooooo`;o00006?ooool2o`0003Gooooo0_l00003oooo
o`Co00003oooool2o`0000;ooooo0_l0000<ooooo`;o00006?ooool002Wooooo00?o0000oooooooo
ool01_ooool2o`0000?ooooo0_l00008ooooo`?o00005oooool2o`0000[ooooo0_l0000Qooooo`;o
00009oooool2o`0003Sooooo0_l0000eooooo`;o00000oooool4o`0002Oooooo0_l0000Booooo`00
:Oooool00ol0003oooooooooo`0;ooooo`;o00002?ooool2o`0002Oooooo0_l0000Nooooo`;o0000
3Oooool2o`0007[ooooo0_l0000>ooooo`;o00001?ooool2o`0000Kooooo0ol00002ooooo`;o0000
6_ooool2o`0001;ooooo000Yooooo`03o`000?oooooooooo01;ooooo0_l0000Iooooo`;o00003ooo
ool2o`0000oooooo0_l00003ooooo`;o00005oooool2o`0000_ooooo0_l0000_ooooo`;o00002?oo
ool2o`0001gooooo0_l0000Cooooo`;o00003_ooool2o`000003ooooool0003o000000Wooooo0ol0
0002ooooo`;o00001oooool2o`0000Gooooo0_l00007ooooo`;o00005Oooool002Wooooo0_l0000C
ooooo`;o00006Oooool2o`00023ooooo0_l00003ooooo`;o00002Oooool2o`0001Wooooo0_l0000E
ooooo`;o00006?ooool4o`0000Kooooo0_l0000Mooooo`;o00007_ooool2o`0000Kooooo0_l0000G
ooooo`;o00001Oooool2o`0000Oooooo0_l0000Eooooo`00:Oooool00ol0003oooooooooo`02oooo
o`?o00007Oooool2o`0000gooooo0_l0000/ooooo`;o00001oooool2o`0001Oooooo0_l0000>oooo
o`;o00006_ooool2o`00013ooooo0_l0000=ooooo`;o00009?ooool2o`0000?ooooo0_l0000?oooo
o`;o0000<?ooool002Wooooo00?o0000ooooooooool00_ooool3o`0000;ooooo0_l00006ooooo`;o
00004Oooool2o`0000[ooooo0_l000000ooooooo0000o`00000>ooooo`;o00009Oooool2o`0001Oo
oooo0_l0000looooo`;o00003Oooool2o`0001oooooo0_l00008ooooo`;o00003oooool2o`00033o
oooo000Yooooo`03o`000?oooooooooo00Oooooo0_l00004ooooo`Co00007Oooool2o`00017ooooo
0_l0000Rooooo`;o00004?ooool2o`0000Gooooo0_l0000=ooooo`;o00003oooool2o`0000Sooooo
0_l0000Looooo`;o00001_ooool2o`0000;ooooo0_l0000Kooooo`;o00001_ooool2o`00013ooooo
0_l00002ooooo`?o0000;?ooool002Wooooo00?o0000ooooooooool03Oooool2o`0005Kooooo0_l0
000@ooooo`;o00001Oooool2o`0000gooooo0_l0000?ooooo`;o00000_ooool2o`0000Cooooo0_l0
000Looooo`;o00002_ooool2o`0002?ooooo0_l0000@ooooo`;o00000_ooool3o`0002cooooo000Y
ooooo`;o00003Oooool2o`0002Gooooo0ol0000@ooooo`;o00005oooool2o`0002Oooooo0ol0000G
ooooo`;o00004oooool4o`0000Gooooo0_l0000Eooooo`;o00004_ooool2o`0004oooooo000Yoooo
o`03o`000?oooooooooo00Cooooo0_l00006ooooo`;o000000Coooooo`000?l0003o00008Oooool3
o`00013ooooo0_l0000Gooooo`;o00008oooool2o`0000;ooooo0ol0000Looooo`;o00001Oooool2
o`0000Oooooo1?l00005ooooo`;o00005Oooool2o`0001;ooooo0_l00008ooooo`;o00004oooool2
o`00033ooooo000Yooooo`;o00001Oooool2o`000003ooooool0003o000000;o00001?ooool3o`00
03Cooooo0_l0000looooo`;o00007?ooool2o`0000?ooooo0_l00005ooooo`;o00007?ooool2o`00
027ooooo0_l00004ooooo`;o00004oooool2o`0001Cooooo0_l00009ooooo`;o00003oooool002Wo
oooo0_l00008ooooo`Co0000<_ooool2o`0000Oooooo0_l0000=ooooo`;o00001Oooool2o`0004Co
oooo0ol000000ooooooo0000o`000006ooooo`;o00007?ooool2o`0000Gooooo0_l00003ooooo`;o
00005Oooool2o`0002oooooo0_l00004ooooo`;o00000oooool2o`0000oooooo000Yooooo`03o`00
0?oooooooooo00cooooo0_l0000Booooo`;o00006?ooool2o`000003ooooool0003o000001Kooooo
0_l00005ooooo`;o00004_ooool2o`0002Sooooo0_l00007ooooo`;o000000?oooooo`000?l00000
1_ooool2o`0000_ooooo0_l0000Cooooo`;o000000?oooooo`000?l000000oooool2o`0000Oooooo
0_l00009ooooo`;o00005_ooool2o`0001Kooooo0_l00008ooooo`;o00005?ooool002Wooooo0_l0
000=ooooo`;o00004_ooool2o`0001Sooooo0_l0000dooooo`;o00008?ooool2o`0000Kooooo0_l0
0007ooooo`;o00004oooool2o`000003ooooool0003o000000;o00004Oooool2o`0000oooooo0_l0
0009ooooo`;o00005_ooool2o`0001Kooooo0_l000000ooooooo0000o`00000Kooooo`00:Oooool0
0ol0003oooooooooo`0Aooooo`;o0000Ooooool2o`0000oooooo0_l0000Cooooo`;o00000oooool2
o`0001gooooo0_l0000Dooooo`Co0000:Oooool2o`0001_ooooo0006ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`0Aooooo`;o0000:oooool2o`0002cooooo0_l0000Vooooo`;o00000ooo
ool2o`0002;ooooo0_l0000Mooooo`;o00005?ooool4o`0000Sooooo0_l00002ooooo`;o00004ooo
ool2o`0002?ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
:?ooool2o`0001Cooooo0_l0000/ooooo`;o00009Oooool5o`000003ooooool0003o000002;ooooo
0_l00002ooooo`;o00001Oooool2o`0001gooooo0_l00009ooooo`;o00002_ooool2o`0000;ooooo
0_l0000Cooooo`;o00008oooool000Kooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRH
V?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Xooooo`;o0000
6?ooool2o`0002Sooooo0_l0000Uooooo`;o000000?oooooo`000?l00000:Oooool2o`0000Gooooo
0_l00003ooooo`;o00006?ooool2o`0002gooooo0_l0000Tooooo`001_ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`Go0000
@?ooool2o`0002Sooooo0_l0001Oooooo`;o00006_ooool2o`0001Sooooo0_l0000Aooooo`;o0000
9?ooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00;o0000F_ooool2o`0000co
oooo0_l0000>ooooo`Co00005oooool2o`0003;ooooo0_l0000>ooooo`;o00003_ooool2o`0001So
oooo0_l0000gooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Gooooo0_l0000Wooooo`;o
00003?ooool2o`0000Sooooo0_l00002ooooo`;o00003_ooool4o`0001Oooooo0_l0000Booooo`;o
00006Oooool2o`0000?ooooo0_l0000>ooooo`;o00001oooool2o`0005Sooooo0006ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Uooooo`;o00008oooool2o`0000;ooooo0_l0000Foooo
o`;o00005oooool2o`0000_ooooo0_l00002ooooo`;o00005oooool2o`0001Wooooo0_l0000Loooo
o`;o0000@oooool2o`000003ooooool0003o0000013ooooo0006ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooo
oooo00[ooooo0_l0000looooo`Co0000<oooool2o`0000_ooooo0_l00002ooooo`;o0000E?ooool2
o`0003oooooo0_l000000ooooooo0000o`000003ooooo`;o00002oooool002Wooooo0_l0000;oooo
o`;o0000=oooool2o`0000?ooooo0_l0001booooo`;o0000:?ooool3o`0004Kooooo0_l0000;oooo
o`00:Oooool00ol0003oooooooooo`0:ooooo`;o00002Oooool2o`0002cooooo1?l00006ooooo`;o
00001?ooool2o`0006Oooooo0_l0000<ooooo`;o00002Oooool2o`00013ooooo0_l0001Cooooo`00
:Oooool00ol0003oooooooooo`0Eooooo`;o00001Oooool2o`000003ooooool0003o000002Cooooo
0_l00006ooooo`?o00000oooool2o`000003ooooool0003o000007;ooooo0_l00009ooooo`;o0000
IOooool002Wooooo00?o0000ooooooooool07?ooool2o`000003ooooool0003o000002gooooo0_l0
0006ooooo`;o00006_ooool2o`0000?ooooo0_l0001Jooooo`;o00001oooool2o`0000Oooooo0_l0
000fooooo`;o00007Oooool002Wooooo00?o0000ooooooooool0H?ooool2o`00013ooooo0_l00003
ooooo`;o00002oooool2o`0004gooooo0_l00007ooooo`;o00001oooool2o`0003Kooooo0_l0000M
ooooo`00:Oooool2o`0001cooooo0_l0000@ooooo`;o00008_ooool2o`0000gooooo0_l0000Roooo
o`;o0000]_ooool002Wooooo00?o0000ooooooooool02Oooool2o`00013ooooo0_l0000@ooooo`;o
00008Oooool3o`0000_ooooo0_l0000Fooooo`;o0000COooool2o`0004;ooooo0_l00009ooooo`;o
00006?ooool2o`0000cooooo000Yooooo`03o`000?oooooooooo00Cooooo0_l00003ooooo`;o0000
0oooool2o`0000Cooooo0_l0000=ooooo`;o00001Oooool2o`0002Cooooo0_l000000ooooooo0000
o`000008ooooo`?o00002oooool2o`0000Wooooo0_l0000Oooooo`;o00004Oooool2o`0001Wooooo
0_l0000?ooooo`;o00001oooool2o`0002Sooooo0_l00009ooooo`;o00000oooool2o`0001?ooooo
0_l0000<ooooo`00:Oooool00ol0003oooooooooo`04ooooo`;o00002?ooool2o`0000Cooooo0_l0
000=ooooo`;o00001Oooool2o`0001Wooooo0_l000000ooooooo0000o`000009ooooo`;o00002?oo
ool2o`0000cooooo0_l0000Zooooo`;o00004Oooool2o`0001cooooo0_l0000<ooooo`;o00000_oo
ool2o`0000?ooooo0_l0000Fooooo`;o00008?ooool2o`00027ooooo000Yooooo`03o`000?oooooo
oooo00Gooooo0_l0000Mooooo`;o00005Oooool2o`0000Sooooo0_l000000ooooooo0000o`000010
ooooo`;o0000??ooool2o`0000Oooooo0_l00007ooooo`;o00006oooool2o`0004?ooooo000Yoooo
o`;o00001_ooool2o`0001gooooo0_l0000Eooooo`;o0000COooool2o`0002Wooooo0_l0000Joooo
o`;o00008oooool2o`0001Oooooo0_l0000[ooooo`00:Oooool00ol0003oooooooooo`2/ooooo`;o
00001oooool2o`0000Wooooo0_l0000Vooooo`;o00003?ooool2o`0001Oooooo0_l0000[ooooo`00
:Oooool00ol0003oooooooooo`0Oooooo`;o0000@_ooool2o`0004Oooooo0_l00004ooooo`;o0000
3?ooool2o`0002Kooooo0_l0001Booooo`00:Oooool01?l0003oooooooooooooool2o`0000gooooo
0_l0000=ooooo`;o0000=Oooool2o`0000_ooooo0_l00004ooooo`;o0000Aoooool2o`0000oooooo
0_l0000Jooooo`;o0000<_ooool2o`0002Oooooo000Yooooo`04o`000?ooooooooooooooo`;o0000
3Oooool2o`0001kooooo0_l0000Pooooo`;o00000_ooool2o`00017ooooo0_l00009ooooo`;o0000
9_ooool2o`0002Gooooo0_l0000Jooooo`;o00008?ooool2o`0000;ooooo0_l0000<ooooo`;o0000
9oooool002Wooooo0_l0000aooooo`;o00008?ooool2o`00023ooooo0_l0000Vooooo`;o0000Hooo
ool2o`0000;ooooo0_l0000eooooo`00:Oooool00ol0003oooooooooo`0eooooo`;o0000ooooool6
ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0eooooo`;o0000Y?ooool2o`0005oooooo000>
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`3Kooooo`;o0000Goooool000kooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo0ol0000gooooo`;o0000ooooool4ooooo`003_ooool0
1Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`0gooooo`;o0000<?ooool2o`000=7ooooo000>ooooo`05o`000?ooooooooooooooool000003?oo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0JOooool2o`000=7ooooo
000>ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo04_ooooo0_l0000:ooooo`;o00005_ooool2o`0003oooooo0_l0001Vooooo`;o0000
8_ooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0Boooool2o`0000[ooooo0_l0000Fooooo`;o0000?oooool2o`0006Kooooo
0_l0000Rooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000
oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`2fooooo`;o0000Q?ooool002Wooooo0_l0002gooooo`;o0000Q?ooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`007oooool4
o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`007oooool00omEEEGoIVIVo`00003oooooodOo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .35187 Mdot
.02762 .27777 Mdot
.02952 .31199 Mdot
.03143 .33836 Mdot
.03333 .36017 Mdot
.03524 .34097 Mdot
.03714 .28466 Mdot
.03905 .44633 Mdot
.04095 .24074 Mdot
.04286 .30289 Mdot
.04476 .29192 Mdot
.04667 .45097 Mdot
.04857 .40782 Mdot
.05048 .2649 Mdot
.05238 .44674 Mdot
.05429 .27346 Mdot
.05619 .30281 Mdot
.0581 .4041 Mdot
.06 .2525 Mdot
.0619 .38007 Mdot
.06381 .40783 Mdot
.06571 .35467 Mdot
.06762 .36641 Mdot
.06952 .398 Mdot
.07143 .42997 Mdot
.07333 .3536 Mdot
.07524 .33334 Mdot
.07714 .27288 Mdot
.07905 .39786 Mdot
.08095 .27253 Mdot
.08286 .40226 Mdot
.08476 .25321 Mdot
.08667 .41004 Mdot
.08857 .3738 Mdot
.09048 .34423 Mdot
.09238 .24376 Mdot
.09429 .40282 Mdot
.09619 .33738 Mdot
.0981 .40059 Mdot
.1 .44956 Mdot
.1019 .41739 Mdot
.10381 .37771 Mdot
.10571 .2434 Mdot
.10762 .29715 Mdot
.10952 .37228 Mdot
.11143 .25904 Mdot
.11333 .25986 Mdot
.11524 .23077 Mdot
.11714 .33272 Mdot
.11905 .37157 Mdot
.12095 .23765 Mdot
.12286 .42892 Mdot
.12476 .36109 Mdot
.12667 .30027 Mdot
.12857 .25816 Mdot
.13048 .3294 Mdot
.13238 .44645 Mdot
.13429 .31121 Mdot
.13619 .31411 Mdot
.1381 .38328 Mdot
.14 .25104 Mdot
.1419 .23417 Mdot
.14381 .39845 Mdot
.14571 .32009 Mdot
.14762 .37642 Mdot
.14952 .30078 Mdot
.15143 .32146 Mdot
.15333 .2589 Mdot
.15524 .32254 Mdot
.15714 .38666 Mdot
.15905 .36475 Mdot
.16095 .32029 Mdot
.16286 .30724 Mdot
.16476 .3454 Mdot
.16667 .39805 Mdot
.16857 .2791 Mdot
.17048 .36079 Mdot
.17238 .25232 Mdot
.17429 .42534 Mdot
.17619 .3703 Mdot
.1781 .32458 Mdot
.18 .25629 Mdot
.1819 .33649 Mdot
.18381 .37116 Mdot
.18571 .4184 Mdot
.18762 .31048 Mdot
.18952 .35622 Mdot
.19143 .34566 Mdot
.19333 .28635 Mdot
.19524 .25807 Mdot
.19714 .42934 Mdot
.19905 .47359 Mdot
.20095 .26058 Mdot
.20286 .30418 Mdot
.20476 .27009 Mdot
.20667 .47123 Mdot
.20857 .2588 Mdot
.21048 .24846 Mdot
.21238 .33906 Mdot
.21429 .3127 Mdot
.21619 .32617 Mdot
.2181 .25278 Mdot
.22 .44864 Mdot
.2219 .27062 Mdot
.22381 .34251 Mdot
.22571 .37971 Mdot
.22762 .3716 Mdot
.22952 .26753 Mdot
.23143 .26152 Mdot
.23333 .38794 Mdot
.23524 .25752 Mdot
.23714 .33838 Mdot
.23905 .24368 Mdot
.24095 .30151 Mdot
.24286 .28408 Mdot
.24476 .26474 Mdot
.24667 .24904 Mdot
.24857 .36094 Mdot
.25048 .3202 Mdot
.25238 .4175 Mdot
.25429 .40927 Mdot
.25619 .22564 Mdot
.2581 .40368 Mdot
.26 .40705 Mdot
.2619 .38524 Mdot
.26381 .32977 Mdot
.26571 .32183 Mdot
.26762 .45569 Mdot
.26952 .26059 Mdot
.27143 .31958 Mdot
.27333 .37713 Mdot
.27524 .28888 Mdot
.27714 .44917 Mdot
.27905 .36266 Mdot
.28095 .25401 Mdot
.28286 .42267 Mdot
.28476 .40211 Mdot
.28667 .36801 Mdot
.28857 .3155 Mdot
.29048 .42249 Mdot
.29238 .44887 Mdot
.29429 .30527 Mdot
.29619 .32698 Mdot
.2981 .28346 Mdot
.3 .30706 Mdot
.3019 .34959 Mdot
.30381 .39901 Mdot
.30571 .39663 Mdot
.30762 .25419 Mdot
.30952 .32828 Mdot
.31143 .22975 Mdot
.31333 .24704 Mdot
.31524 .35014 Mdot
.31714 .39272 Mdot
.31905 .32268 Mdot
.32095 .37676 Mdot
.32286 .42213 Mdot
.32476 .41445 Mdot
.32667 .34777 Mdot
.32857 .4064 Mdot
.33048 .4186 Mdot
.33238 .37278 Mdot
.33429 .42772 Mdot
.33619 .40328 Mdot
.3381 .2414 Mdot
.34 .25833 Mdot
.3419 .35107 Mdot
.34381 .38845 Mdot
.34571 .30856 Mdot
.34762 .33333 Mdot
.34952 .41654 Mdot
.35143 .31832 Mdot
.35333 .26015 Mdot
.35524 .35208 Mdot
.35714 .3601 Mdot
.35905 .28148 Mdot
.36095 .40172 Mdot
.36286 .46698 Mdot
.36476 .36988 Mdot
.36667 .27785 Mdot
.36857 .39634 Mdot
.37048 .42653 Mdot
.37238 .44224 Mdot
.37429 .34404 Mdot
.37619 .40861 Mdot
.3781 .31161 Mdot
.38 .2297 Mdot
.3819 .44921 Mdot
.38381 .26394 Mdot
.38571 .41405 Mdot
.38762 .24634 Mdot
.38952 .25685 Mdot
.39143 .35202 Mdot
.39333 .33459 Mdot
.39524 .22341 Mdot
.39714 .4329 Mdot
.39905 .35591 Mdot
.40095 .45045 Mdot
.40286 .32666 Mdot
.40476 .46803 Mdot
.40667 .38375 Mdot
.40857 .32227 Mdot
.41048 .31832 Mdot
.41238 .31322 Mdot
.41429 .36202 Mdot
.41619 .45919 Mdot
.4181 .32125 Mdot
.42 .26919 Mdot
.4219 .35934 Mdot
.42381 .33609 Mdot
.42571 .26267 Mdot
.42762 .31367 Mdot
.42952 .41068 Mdot
.43143 .24986 Mdot
.43333 .3073 Mdot
.43524 .32131 Mdot
.43714 .3452 Mdot
.43905 .2533 Mdot
.44095 .40217 Mdot
.44286 .29171 Mdot
.44476 .39504 Mdot
.44667 .45198 Mdot
.44857 .24849 Mdot
.45048 .32184 Mdot
.45238 .32249 Mdot
.45429 .29792 Mdot
.45619 .27404 Mdot
.4581 .35398 Mdot
.46 .26852 Mdot
.4619 .26007 Mdot
.46381 .44747 Mdot
.46571 .2237 Mdot
.46762 .25817 Mdot
.46952 .2889 Mdot
.47143 .46166 Mdot
.47333 .29495 Mdot
.47524 .34027 Mdot
.47714 .2417 Mdot
.47905 .34574 Mdot
.48095 .2498 Mdot
.48286 .40815 Mdot
.48476 .30062 Mdot
.48667 .23087 Mdot
.48857 .30484 Mdot
.49048 .24826 Mdot
.49238 .3638 Mdot
.49429 .27437 Mdot
.49619 .29532 Mdot
.4981 .42756 Mdot
.5 .24847 Mdot
.5019 .36116 Mdot
.50381 .40528 Mdot
.50571 .372 Mdot
.50762 .26462 Mdot
.50952 .3309 Mdot
.51143 .42481 Mdot
.51333 .34653 Mdot
.51524 .35343 Mdot
.51714 .24188 Mdot
.51905 .28917 Mdot
.52095 .43761 Mdot
.52286 .25767 Mdot
.52476 .31221 Mdot
.52667 .34004 Mdot
.52857 .27187 Mdot
.53048 .28764 Mdot
.53238 .2459 Mdot
.53429 .37769 Mdot
.53619 .25655 Mdot
.5381 .27114 Mdot
.54 .2686 Mdot
.5419 .36249 Mdot
.54381 .27858 Mdot
.54571 .24423 Mdot
.54762 .29577 Mdot
.54952 .35522 Mdot
.55143 .42243 Mdot
.55333 .34745 Mdot
.55524 .33862 Mdot
.55714 .23082 Mdot
.55905 .31344 Mdot
.56095 .37461 Mdot
.56286 .41109 Mdot
.56476 .33084 Mdot
.56667 .34121 Mdot
.56857 .40888 Mdot
.57048 .4468 Mdot
.57238 .27691 Mdot
.57429 .29875 Mdot
.57619 .32827 Mdot
.5781 .27088 Mdot
.58 .30231 Mdot
.5819 .35152 Mdot
.58381 .44656 Mdot
.58571 .34152 Mdot
.58762 .44247 Mdot
.58952 .35159 Mdot
.59143 .31572 Mdot
.59333 .33965 Mdot
.59524 .24453 Mdot
.59714 .24172 Mdot
.59905 .44501 Mdot
.60095 .43801 Mdot
.60286 .3609 Mdot
.60476 .27695 Mdot
.60667 .26935 Mdot
.60857 .26628 Mdot
.61048 .42976 Mdot
.61238 .25496 Mdot
.61429 .23654 Mdot
.61619 .35738 Mdot
.6181 .31855 Mdot
.62 .40664 Mdot
.6219 .32514 Mdot
.62381 .41159 Mdot
.62571 .24598 Mdot
.62762 .2672 Mdot
.62952 .39186 Mdot
.63143 .38189 Mdot
.63333 .39368 Mdot
.63524 .30572 Mdot
.63714 .44108 Mdot
.63905 .33424 Mdot
.64095 .37174 Mdot
.64286 .28846 Mdot
.64476 .3724 Mdot
.64667 .36483 Mdot
.64857 .41385 Mdot
.65048 .36074 Mdot
.65238 .32327 Mdot
.65429 .30434 Mdot
.65619 .36004 Mdot
.6581 .45226 Mdot
.66 .42672 Mdot
.6619 .26931 Mdot
.66381 .39577 Mdot
.66571 .32752 Mdot
.66762 .31255 Mdot
.66952 .27392 Mdot
.67143 .33319 Mdot
.67333 .25616 Mdot
.67524 .37276 Mdot
.67714 .35961 Mdot
.67905 .38599 Mdot
.68095 .34829 Mdot
.68286 .23799 Mdot
.68476 .3237 Mdot
.68667 .37514 Mdot
.68857 .32069 Mdot
.69048 .35419 Mdot
.69238 .27998 Mdot
.69429 .30025 Mdot
.69619 .29706 Mdot
.6981 .30489 Mdot
.7 .45144 Mdot
.7019 .33298 Mdot
.70381 .2596 Mdot
.70571 .36541 Mdot
.70762 .38236 Mdot
.70952 .31303 Mdot
.71143 .26211 Mdot
.71333 .45115 Mdot
.71524 .39816 Mdot
.71714 .24148 Mdot
.71905 .44977 Mdot
.72095 .43865 Mdot
.72286 .39933 Mdot
.72476 .28312 Mdot
.72667 .32002 Mdot
.72857 .44857 Mdot
.73048 .44209 Mdot
.73238 .27428 Mdot
.73429 .3712 Mdot
.73619 .33477 Mdot
.7381 .3699 Mdot
.74 .3361 Mdot
.7419 .23603 Mdot
.74381 .25406 Mdot
.74571 .37993 Mdot
.74762 .42504 Mdot
.74952 .3554 Mdot
.75143 .35113 Mdot
.75333 .36553 Mdot
.75524 .44032 Mdot
.75714 .33757 Mdot
.75905 .40769 Mdot
.76095 .38853 Mdot
.76286 .31474 Mdot
.76476 .36962 Mdot
.76667 .2834 Mdot
.76857 .3103 Mdot
.77048 .43698 Mdot
.77238 .38382 Mdot
.77429 .32365 Mdot
.77619 .34074 Mdot
.7781 .31164 Mdot
.78 .3473 Mdot
.7819 .22817 Mdot
.78381 .28666 Mdot
.78571 .22734 Mdot
.78762 .43973 Mdot
.78952 .36166 Mdot
.79143 .41533 Mdot
.79333 .37616 Mdot
.79524 .27811 Mdot
.79714 .32212 Mdot
.79905 .27875 Mdot
.80095 .45017 Mdot
.80286 .45057 Mdot
.80476 .33054 Mdot
.80667 .28002 Mdot
.80857 .35431 Mdot
.81048 .33152 Mdot
.81238 .3007 Mdot
.81429 .30793 Mdot
.81619 .23791 Mdot
.8181 .32896 Mdot
.82 .34939 Mdot
.8219 .30904 Mdot
.82381 .33796 Mdot
.82571 .36582 Mdot
.82762 .35411 Mdot
.82952 .28018 Mdot
.83143 .22777 Mdot
.83333 .42206 Mdot
.83524 .28241 Mdot
.83714 .32902 Mdot
.83905 .37131 Mdot
.84095 .38642 Mdot
.84286 .34865 Mdot
.84476 .34636 Mdot
.84667 .3551 Mdot
.84857 .47615 Mdot
.85048 .24532 Mdot
.85238 .22217 Mdot
.85429 .27056 Mdot
.85619 .31267 Mdot
.8581 .24566 Mdot
.86 .44865 Mdot
.8619 .2949 Mdot
.86381 .27205 Mdot
.86571 .38018 Mdot
.86762 .28858 Mdot
.86952 .32486 Mdot
.87143 .29801 Mdot
.87333 .26964 Mdot
.87524 .37074 Mdot
.87714 .47395 Mdot
.87905 .28434 Mdot
.88095 .33962 Mdot
.88286 .37718 Mdot
.88476 .28496 Mdot
.88667 .26476 Mdot
.88857 .34607 Mdot
.89048 .44588 Mdot
.89238 .28927 Mdot
.89429 .42296 Mdot
.89619 .24962 Mdot
.8981 .38197 Mdot
.9 .30158 Mdot
.9019 .37391 Mdot
.90381 .34883 Mdot
.90571 .46212 Mdot
.90762 .33557 Mdot
.90952 .45258 Mdot
.91143 .36866 Mdot
.91333 .25798 Mdot
.91524 .33539 Mdot
.91714 .35606 Mdot
.91905 .26088 Mdot
.92095 .35273 Mdot
.92286 .31966 Mdot
.92476 .25165 Mdot
.92667 .29117 Mdot
.92857 .37576 Mdot
.93048 .24801 Mdot
.93238 .24367 Mdot
.93429 .27815 Mdot
.93619 .26247 Mdot
.9381 .36856 Mdot
.94 .28276 Mdot
.9419 .28426 Mdot
.94381 .30466 Mdot
.94571 .25538 Mdot
.94762 .28707 Mdot
.94952 .32369 Mdot
.95143 .30452 Mdot
.95333 .36079 Mdot
.95524 .38711 Mdot
.95714 .28858 Mdot
.95905 .29084 Mdot
.96095 .27007 Mdot
.96286 .27485 Mdot
.96476 .2736 Mdot
.96667 .27573 Mdot
.96857 .33281 Mdot
.97048 .23569 Mdot
.97238 .30967 Mdot
.97429 .38071 Mdot
.97619 .44805 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo07Cooooo0_l0000Dooooo`;o0000Noooool2o`0003?ooooo0006ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0Aoooool2o`0002_ooooo0_l0000Dooooo`;o0000IOoo
ool2o`0000gooooo0_l00005ooooo`;o0000<oooool000Co00000_ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo01[ooooo0_l0000[ooooo`;o00004?ooool2o`0001Cooooo0_l0000Pooooo`;o00005Ooo
ool2o`0004Kooooo0ol0000=ooooo`;o0000>_ooool000Kooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0001[ooooo0_l0
0006ooooo`;o0000=Oooool2o`0001Cooooo0_l0000Pooooo`;o00005Oooool2o`0004Kooooo0_l0
001:ooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool08_ooool2o`0009Kooooo
0_l0000Wooooo`;o0000B?ooool2o`0000gooooo0006ooooo`05oa0@4?ooooooooooooooool@4100
3oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
7?ooool2o`0009cooooo0_l0000Dooooo`;o00004Oooool2o`0001Kooooo0_l0000`ooooo`;o0000
3Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@
41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo0_l0000Cooooo`;o
00000oooool2o`0004?ooooo0_l0000[ooooo`;o00002oooool2o`0001Sooooo0_l0000Iooooo`;o
00002Oooool2o`0001kooooo0_l0000oooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`02oooo
o`;o00003_ooool2o`0000?ooooo0_l0000Xooooo`;o00007_ooool2o`0000kooooo0_l0000Koooo
o`;o00002oooool2o`0000?ooooo0_l00002ooooo`;o00003_ooool3o`0000Oooooo0_l0000Koooo
o`;o0000:Oooool2o`000003ooooool0003o000001Gooooo0_l0000Jooooo`00:Oooool2o`0001?o
oooo0_l0000Tooooo`;o00001oooool2o`000003ooooool0003o000001?ooooo0_l0000Fooooo`;o
00004_ooool2o`0000_ooooo0_l000000ooooooo0000o`000009ooooo`;o00000_ooool2o`0000ko
oooo0_l00008ooooo`;o0000A_ooool2o`000003ooooool0003o000000[ooooo0_l00009ooooo`;o
00006_ooool002Wooooo00?o0000ooooooooool02?ooool2o`0001Sooooo0_l00008ooooo`;o0000
2_ooool2o`000003ooooool0003o000000Oooooo0_l0000Cooooo`;o00009?ooool2o`0000Cooooo
0_l00008ooooo`;o000000Coooooo`000?l0003ooooo0_l0001nooooo`;o00001oooool4o`0001[o
oooo000Yooooo`03o`000?oooooooooo00Sooooo0_l00006ooooo`;o00004?ooool2o`0000Sooooo
0_l0000=ooooo`;o00004_ooool2o`0000Oooooo0_l0000Uooooo`;o000000?oooooo`000?l00000
2oooool2o`0002Wooooo0_l0000Xooooo`;o0000>?ooool2o`0000Gooooo0_l0000Eooooo`00:Ooo
ool00ol0003oooooooooo`0@ooooo`;o00001_ooool2o`0000Cooooo0_l00006ooooo`;o00001_oo
ool2o`0000?ooooo0_l00003ooooo`;o00001_ooool2o`0000gooooo0_l00007ooooo`;o00002?oo
ool2o`0000kooooo0_l0000>ooooo`;o00001oooool2o`00013ooooo0_l00002ooooo`;o00005ooo
ool2o`00017ooooo0_l0000Eooooo`;o0000=?ooool2o`0000Wooooo0_l0000Eooooo`00:Oooool0
0ol0003oooooooooo`0Hooooo`?o00000oooool2o`0000Kooooo0_l00006ooooo`;o00000oooool4
o`000003ooooool0003o000000Gooooo0ol00009ooooo`;o00005Oooool2o`0000;ooooo0_l0000:
ooooo`;o00005Oooool4o`00013ooooo0_l00002ooooo`;o0000:_ooool2o`0000Sooooo1?l0000o
ooooo`Co00007_ooool002Wooooo0_l00006ooooo`;o00004_ooool2o`0001[ooooo0_l00008oooo
o`;o00000_ooool2o`0000Kooooo0_l0000Iooooo`;o00002?ooool2o`0000_ooooo0_l0000:oooo
o`;o00003Oooool2o`0003gooooo1?l0000gooooo`;o00002?ooool2o`0000Cooooo0_l0000Hoooo
o`00:Oooool00ol0003oooooooooo`05ooooo`;o0000=oooool2o`0000?ooooo0_l0000[ooooo`;o
00002oooool2o`0001Wooooo0_l0000Nooooo`;o00001?ooool2o`0005;ooooo0_l0000>ooooo`;o
00006?ooool002Wooooo00?o0000ooooooooool0<?ooool4o`000008oa0@4?oooooo0000o`000?lb
<S;o0000oc8b<_o^k^h4o`000004oc8b<_l0003o<S8bonk^kRWooooo1Ol00003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00_ooool2o`000004oc8b<_l0003o<S8bonk^kPOooooo0_l0000Gooooo`;o
00001_ooool01?nHV9So410@o`000?lb<S82o`0000;ooooo00Kok^k^oc8b<_l0003o<S8bonk^k_oo
ool2o`000004onk^k_lb<S;o0000oc8b<P;o00002Oooool2o`0001kooooo0_l000002Ol@413ooooo
ooooooooooook^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool2o`0000Cooooo0_l0000Fooooo`05odA4A?l0003o0000oc8b<_oMgMd00_l000001Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool00ol0003o
ooooooooo`06ooooo`;o00001Oooool4o`00027ooooo00Co0000oooooooooooooooo0_l000001?nH
V9SooooooiRHV?mgMgL2o`000006oooooomgMgOoV9RHoooooonHV9SoMgMg:Oooool01OnHV9So8B4Q
onk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`;o000000CoV9RHoooo
oonHV9SoMgMg1Oooool4o`0000Wooooo0_l00009ooooo`;o000000?oooooo`000?l000001_ooool0
1?l@413o^[ZjoooooomgMgL2o`0000;ooooo00KoMgMgoiRHV?ooooooV9RHogMgMoooool2o`000005
ogMgMonHV9SooooooiRHV?mgMgL02_ooool2o`000003ooooool0003o000001;ooooo0_l00008oooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool2o`000004ooooool0003o0000ooooo`;o00006Oooool00omgMgOo<S8b
o`000002o`000004oiRHV?ooooooV9RHogMgM`?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`00:Oooool00ol0003oooooooooo`06ooooo`;o00001Oooool4o`00027ooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@400Z
ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oo
ooooooooooooool@41001Oooool2o`0000_ooooo0_l00009ooooo`;o00003?ooool2o`0000?ooooo
00Go410@oooooooooooooooooa0@4002o`000003ooooool@413ooooo00;ooooo00?o410@oooooooo
ool02oooool2o`0001;ooooo0_l00005ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@400>ooooo`;o00007Oooool4o`0000?ooooo00Go410@
oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo007ooooo000Yooooo`;o0000;?ooool2
o`0000Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`00000Wooooo`;o00000_ooool00onHV9So8B4Qonk^kP03ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000027ooooo0_l00008oooo
o`;o00000oooool01?l0003oooooooooooooool3o`000003ooooool0003ooooo00;ooooo00?o0000
ooooooooool04_ooool2o`0001;ooooo00CoA4A4omgMgOoooooo00001?ooool01?l0003ooooooooo
ooooool7o`000003ooooool0003ooooo00;ooooo0_l0000Pooooo`;o00001Oooool00omgMgOo<S8b
o`000002o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo007o
oooo000Yooooo`;o0000;?ooool2o`0000Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00000@ooooo`;o00004_ooool2o`00
0003ooooool0003o000000?ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`00000Qooooo`;o00001oooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000001Co
oooo0_l00009ooooo`;o00001oooool00ooMgMgoEEEEooooo`03o`0000;ooooo00Co0000oooooooo
oooooooo1ol000000ooooooo0000ooooo`02ooooo`Co00007_ooool5o`000004ob4Q8Ol0003o<S8b
olc<c0;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool002Wooooo00Co0000oooooooooooooooo0_l0000_ooooo`?o00000_ooool01Ol@413ooooo
oooooooooooo410@00?ooooo00Co410@oooooooooooooooo0_l0000?ooooo`;o00004_ooool2o`00
00Oooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool00ol@413oooooooooo`0Yooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooo
oa0@4003ooooo`05oa0@4?ooooooooooooooool@41007oooool2o`0000Sooooo00?oMgMgolc<c?l0
00000_l00002ooooo`05oa0@4?oooooo0000o`000?l@41000oooool01Ol@413ooooooooooooooooo
410@00Gooooo0_l0000<ooooo`Co00004?ooool3o`0000Kooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool002Wooooo00Co0000oooooooooooooooo
0_l0000_ooooo`?o00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00CoMgMgoiRHV?oo
ooooV9RH0_l00008ooooo`;o00007_ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02_ooool2o`0000kooooo
0_l000000ooooooo0000o`000009ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`;o00008oooool0
0oo^k^koA4A4o`000004ooooo`05ogMgMonHV9So0000o`000?mgMgL00oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg013ooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000gooooo
1?l000000ooooooo0000o`000002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo000Yooooo`03o`000?oooooooooo00?ooooo0_l0000[ooooo`03
oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02Oooool2o`0001kooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool01_o^k^ko<S8bo`000?lb<S;ok^k^ooooo`;o00001oooool2o`00
00kooooo0_l000000ooooooo0000o`000009ooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`;o0000
9?ooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^013ooooo0_l00006ooooo`;o00002Oooool2o`0000Cooooo1_l000001_oo
ooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Ooo
ool2o`0000Cooooo0_l0001nooooo`;o00002?ooool2o`0000Gooooo0_l0000?ooooo`;o0000Hooo
ool2o`0001?ooooo0_l00008ooooo`;o00004Oooool002Wooooo00?o0000ooooooooool05oooool2
o`0006kooooo0_l00004ooooo`;o00001Oooool2o`0000oooooo0_l00006ooooo`;o00009Oooool2
o`0003Cooooo0_l000000ooooooo0000o`00000]ooooo`00:Oooool00ol0003oooooooooo`0Goooo
o`;o00001?ooool2o`0000Kooooo0_l0000Kooooo`;o0000@oooool2o`0000Oooooo0_l0000Koooo
o`Co00008oooool2o`0002Cooooo0_l0000Aooooo`;o00001oooool2o`0002Cooooo000Yooooo`03
o`000?oooooooooo00;ooooo0_l00003ooooo`;o00005?ooool2o`0000Kooooo0_l0000?ooooo`;o
00002_ooool2o`0000oooooo0_l0000kooooo`Co00006oooool2o`0001Kooooo0_l0000;ooooo`?o
00008oooool2o`0001[ooooo0_l0000<ooooo`;o000000?oooooo`000?l000004oooool002Wooooo
00?o0000ooooooooool00_ooool2o`0000?ooooo0_l0000Pooooo`;o00002oooool2o`0001_ooooo
1?l0000=ooooo`;o00006_ooool2o`00013ooooo0_l0000]ooooo`;o00001?ooool2o`0000cooooo
0_l0000Sooooo`;o0000:?ooool2o`000003ooooool0003o000001?ooooo000Qoooooooo0000A?l0
0004ooooo`00:Oooool3o`0000Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07
ooooo`?o00002oooool00ol0003oooooooooo`02o`0000Oooooo0_l0000;ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00;o00002?ooool3o`0000?ooooo0_l00004ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool3o`0000Wooooo0_l0000;ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool01oooool3o`0000_ooooo0_l0000;ooooo`04o`000?ooooooooooooooo`Co000000Go
ooooo`000?l0003oooooo`00000:ooooo`;o00002Oooool2o`000003ooooool0003ooooo00[ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`?o00003?ooool002Wooooo0ol0
000Pooooo`;o00006?ooool2o`0001Gooooo0_l0000Uooooo`?o00000oooool2o`0001gooooo0_l0
0009ooooo`;o00002Oooool3o`0001Gooooo0_l0000<ooooo`;o00003oooool2o`0000Kooooo00?o
0000ooooooooool04oooool2o`0002Gooooo00?o0000ooooooooool02_ooool002Wooooo00?o0000
ooooooooool08oooool2o`0000?ooooo0_l0000Kooooo`;o00001Oooool2o`0000?ooooo0_l0000C
ooooo`;o00004Oooool4o`0003Kooooo0_l00006ooooo`;o00005Oooool2o`0000[ooooo0_l0000m
ooooo`;o00007Oooool002Wooooo00?o0000ooooooooool08oooool7o`0001_ooooo0_l00003oooo
o`Co00003Oooool2o`0000Wooooo0_l0000@ooooo`Go00001?ooool2o`0000;ooooo0ol0000coooo
o`;o00002Oooool2o`0000Wooooo0ol0000:ooooo`;o00003_ooool2o`0000Gooooo0_l0000Voooo
o`;o00001oooool2o`0001Cooooo000Yooooo`;o00009_ooool4o`0000Gooooo0_l0000:ooooo`;o
00003_ooool2o`0000Sooooo0_l00005ooooo`;o00006Oooool4o`0000Oooooo0_l00002ooooo`?o
0000=Oooool2o`0000Oooooo0_l00009ooooo`;o00006oooool2o`0000Gooooo0_l0000Eooooo`;o
00006?ooool2o`0001Cooooo000Yooooo`03o`000?oooooooooo01oooooo0_l0000=ooooo`;o0000
2_ooool2o`0000gooooo0_l00009ooooo`;o00000_ooool2o`0001cooooo0_l0000fooooo`;o0000
3Oooool2o`0000cooooo0_l0000Zooooo`;o00000oooool2o`0000Cooooo0_l00008ooooo`;o0000
;_ooool002Wooooo00?o0000ooooooooool03Oooool2o`0000_ooooo0_l00003ooooo`;o0000:?oo
ool2o`0000gooooo0_l0000:ooooo`;o0000<_ooool2o`00013ooooo0_l00002ooooo`;o00006ooo
ool4o`0000Oooooo0_l0000Oooooo`Co000000?oooooo`000?l000001?ooool2o`0002Sooooo0_l0
000>ooooo`00:Oooool00ol0003oooooooooo`0=ooooo`;o00002oooool2o`0001?ooooo0_l0000c
ooooo`;o00003Oooool2o`0000Sooooo0_l0000Iooooo`;o00004?ooool2o`0001Kooooo0_l00009
ooooo`;o00001oooool2o`0000Wooooo1?l0000Dooooo`;o00007Oooool2o`000003ooooool0003o
000000oooooo0_l0000>ooooo`00:Oooool01?l0003oooooo`000?l0000Cooooo`;o00006Oooool2
o`0000Sooooo0_l00006ooooo`;o0000<?ooool2o`0000Sooooo0_l0000Xooooo`;o00002_ooool2
o`0000gooooo0_l0000Mooooo`Co00000oooool2o`0001Cooooo0_l0000@ooooo`;o00001_ooool2
o`000003ooooool0003o000001oooooo000Yooooo`Go00004_ooool2o`0002?ooooo0_l00002oooo
o`;o00000_ooool2o`0004[ooooo0_l0000?ooooo`;o00001oooool2o`0000;ooooo0_l00004oooo
o`Co0000<oooool2o`0000Cooooo0_l0000>ooooo`;o00004?ooool2o`0002[ooooo000Yooooo`03
o`000?oooooooooo00;o00004?ooool2o`0001Kooooo0_l00006ooooo`;o00002Oooool2o`0002ko
oooo0_l0000Booooo`;o00002_ooool4o`0000gooooo0_l0000;ooooo`;o00001?ooool2o`0003_o
oooo0_l0000Rooooo`;o0000:?ooool002Wooooo00?o0000ooooooooool04_ooool2o`0001Kooooo
0_l00006ooooo`;o0000:_ooool2o`0000gooooo0_l0000Booooo`;o00003?ooool2o`0000Wooooo
0_l0000;ooooo`;o00009oooool2o`0001gooooo0_l0000Cooooo`;o00003?ooool2o`0000?ooooo
0_l0000Sooooo`00:Oooool2o`0005Oooooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo0_l0
0002ooooo`;o00002Oooool2o`0002Kooooo0_l0000;ooooo`;o00001oooool4o`0001cooooo0_l0
000Dooooo`;o00001oooool2o`0000_ooooo0_l00006ooooo`;o00004Oooool2o`0002?ooooo000Y
ooooo`;o00002oooool4o`0004Sooooo0_l00002ooooo`;o00001oooool2o`0000;ooooo0_l00009
ooooo`;o00005?ooool2o`00013ooooo0_l00009ooooo`;o00002Oooool4o`0001oooooo0_l0000A
ooooo`;o00004Oooool2o`000004ooooool0003o0000ooooo`;o00001?ooool2o`0001Kooooo0_l0
000Mooooo`00:Oooool2o`0000_ooooo1?l0000Tooooo`;o0000@Oooool2o`00017ooooo0_l0000@
ooooo`;o00002Oooool2o`0001Cooooo0_l0000Fooooo`;o00004Oooool2o`00017ooooo0_l00004
ooooo`;o00001?ooool2o`0001Gooooo0ol0000Mooooo`00:Oooool01?l0003oooooo`000?l0000L
ooooo`;o00003?ooool2o`0000Gooooo0_l0000Aooooo`;o00008?ooool2o`0000cooooo0_l00005
ooooo`;o00006?ooool2o`0001kooooo0_l00003ooooo`;o00002Oooool4o`0000Cooooo0_l0000R
ooooo`;o0000:?ooool2o`0000Wooooo0_l0000Cooooo`00:Oooool01?l0003oooooo`000?l0000L
ooooo`;o00002Oooool2o`000003ooooool0003o000001Sooooo0_l00007ooooo`;o00005oooool2
o`00017ooooo1?l0000Eooooo`;o000000?oooooo`000?l000002oooool2o`00017ooooo0_l0000>
ooooo`Co00001?ooool2o`0002;ooooo0_l0000cooooo`;o00004oooool002Wooooo00?o0000oooo
ooooool02_ooool2o`0001cooooo0_l0000Tooooo`;o0000:_ooool2o`0001Oooooo0_l0000>oooo
o`;o00008?ooool2o`00017ooooo0_l0000=ooooo`;o00005Oooool2o`0003cooooo000Yooooo`03
o`000?oooooooooo00[ooooo0_l0000Qooooo`;o00008_ooool2o`0001Oooooo0_l0001Iooooo`;o
00004Oooool2o`0000Sooooo0_l00003ooooo`;o00000_ooool2o`00017ooooo0_l0000>ooooo`;o
00002_ooool2o`0000Kooooo0_l0000Hooooo`00:Oooool2o`0001;ooooo0_l00005ooooo`;o0000
00?oooooo`000?l000004?ooool2o`000003ooooool0003o000000cooooo0_l0000Aooooo`;o0000
3?ooool2o`0000Wooooo0_l0000[ooooo`;o0000:_ooool3o`0000Sooooo0_l0000Aooooo`?o0000
1oooool2o`0001Gooooo0_l0000:ooooo`;o00001oooool2o`000003ooooool0003o000000Kooooo
0_l0000Hooooo`00:Oooool00ol0003oooooooooo`0Aooooo`;o00001Oooool2o`000003ooooool0
003o000000Oooooo0_l0000:ooooo`;o00003?ooool2o`0000gooooo0_l0000=ooooo`;o000000?o
ooooo`000?l00000=_ooool2o`00013ooooo0_l0000Hooooo`?o00002?ooool2o`000003ooooool0
003o000000kooooo0_l0000Aooooo`;o00003?ooool2o`0000cooooo0_l00005ooooo`;o00001_oo
ool2o`0001_ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0
0004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`09ooooo`;o0000
2oooool2o`0000cooooo0_l0000Gooooo`;o00003_ooool2o`0000gooooo0_l00012ooooo`;o0000
1oooool2o`0002Kooooo0_l0000Aooooo`;o00003_ooool2o`0001Gooooo0_l00003ooooo`;o0000
3Oooool2o`0001_ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo
00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool02Oooool2o`0000_ooooo0_l00009ooooo`;o00006_ooool2o`00067ooooo0_l0000Nooooo`;o
00005_ooool2o`0000[ooooo0_l0000Uooooo`;o00002?ooool2o`0001Oooooo0_l0000<ooooo`00
1_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo027ooooo0_l0000Vooooo`;o0000;?ooool2o`0004Oo
oooo0_l0000=ooooo`;o00001oooool2o`0001?ooooo0_l0000Dooooo`;o00004?ooool2o`0001Oo
oooo0_l0000<ooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^
k^h01oooool00omgMgOo<S8booooo`04ooooo`?o00009oooool2o`0001Oooooo0_l00007ooooo`;o
00006?ooool2o`0001;ooooo0_l0001Fooooo`;o00006?ooool2o`0000;ooooo0_l0000Dooooo`;o
00008oooool2o`0001;ooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOo
IVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Woooo
o`;o00005oooool2o`0001Wooooo0_l00006ooooo`;o0000F_ooool2o`0002Sooooo0_l0000moooo
o`;o00004_ooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Kooooo`;o00009oooool2o`00
03Wooooo0ol00008ooooo`;o0000L?ooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00_ooooo0_l000000ooooooo0000o`00000Cooooo`;o00001Oooool2o`0002[ooooo0ol0000B
ooooo`;o00005oooool2o`0003[ooooo0_l00008ooooo`;o00003oooool2o`0005oooooo0006oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0
0006ooooo`03o`000?oooooooooo00_ooooo0_l000000ooooooo0000o`000004ooooo`;o00003Ooo
ool2o`0000Gooooo0_l0000Tooooo`;o00001?ooool3o`00013ooooo1?l0001^ooooo`Co0000GOoo
ool002Wooooo0_l00008ooooo`;o00001_ooool2o`0000;ooooo0ol0000booooo`;o00001_ooool2
o`0000oooooo0_l00006ooooo`;o00005oooool2o`0005Wooooo0_l0001Mooooo`00:Oooool00ol0
003oooooooooo`04ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o00000_ooool2o`00
03?ooooo0_l0000Dooooo`;o000000?oooooo`000?l000007oooool2o`0000cooooo0_l00005oooo
o`;o00008oooool2o`0002_ooooo0_l0001Aooooo`00:Oooool00ol0003oooooooooo`04ooooo`;o
00000oooool2o`0000Gooooo0_l0000dooooo`Co00005?ooool2o`0000kooooo0_l0000?ooooo`;o
00003oooool2o`0000Gooooo0_l0000Aooooo`?o00003oooool2o`0002_ooooo0_l0001Aooooo`00
:Oooool00ol0003oooooooooo`0@ooooo`;o0000=?ooool2o`0001Gooooo0_l0000?ooooo`;o0000
00?oooooo`000?l000003?ooool2o`0002Wooooo0ol0000@ooooo`;o00001_ooool2o`0007Gooooo
000Yooooo`03o`000?oooooooooo01Gooooo0_l0000_ooooo`;o00005Oooool2o`0000Kooooo0_l0
000:ooooo`;o0000B_ooool2o`0000Kooooo0_l0000/ooooo`;o0000Aoooool002Wooooo0_l0000F
ooooo`;o00006Oooool2o`0001Cooooo0_l0000Gooooo`;o00001?ooool2o`0008cooooo0_l00017
ooooo`00:Oooool00ol0003oooooooooo`0`ooooo`;o00007_ooool4o`0000Sooooo0_l000000ooo
oooo0000o`000015ooooo`;o0000FOooool2o`00017ooooo0_l0000Vooooo`00:Oooool00ol0003o
ooooooooo`0]ooooo`;o00008Oooool4o`0000Sooooo0_l0000>ooooo`;o0000:oooool2o`0000_o
oooo0_l0000Qooooo`;o00006_ooool2o`0001[ooooo0_l0000Aooooo`;o00009_ooool002Wooooo
00?o0000ooooooooool03?ooool2o`0000kooooo0_l0000?ooooo`;o00001Oooool2o`0002[ooooo
0_l0000:ooooo`;o00009oooool2o`0000;ooooo0_l0000Nooooo`;o00003_ooool2o`0001[ooooo
0_l0001Eooooo`00:Oooool00ol0003oooooooooo`0<ooooo`;o00003_ooool2o`0001Kooooo0_l0
000Zooooo`;o00004_ooool2o`0001oooooo0_l0000Rooooo`;o0000POooool002Wooooo0_l0001e
ooooo`;o0000a_ooool002Wooooo00?o0000ooooooooool0W?ooool2o`0001Sooooo0_l0000Toooo
o`;o00003_ooool2o`0004kooooo000Yooooo`03o`000?oooooooooo06cooooo0_l0000^ooooo`;o
00005?ooool2o`0000;ooooo0_l00009ooooo`;o00006Oooool2o`000003ooooool0003o000000Ko
oooo0_l00003ooooo`;o00001?ooool2o`0004Sooooo000Yooooo`03o`000?oooooooooo06cooooo
0_l00014ooooo`;o000000?oooooo`000?l000002_ooool2o`0001cooooo0_l00006ooooo`;o0000
2Oooool2o`0004Sooooo000Yooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0001Sooooo
0_l0000Jooooo`;o0000COooool2o`00023ooooo0_l00002ooooo`;o00000oooool2o`0002Sooooo
0_l0000Xooooo`;o00002?ooool2o`0001[ooooo0_l0000;ooooo`00:Oooool2o`0000;ooooo0_l0
00001?oooooo0000o`000?l0000>ooooo`;o00002?ooool2o`0001[ooooo0_l0000Aooooo`;o0000
0oooool2o`0001[ooooo0_l00005ooooo`;o00004_ooool2o`00023ooooo0_l00002ooooo`;o0000
9?ooool2o`0000;ooooo1?l000000ooooooo0000o`00000Eooooo`?o00004?ooool2o`0000Sooooo
0_l0000Jooooo`;o00002oooool002Wooooo00?o0000ooooooooool01?ooool2o`0000oooooo0_l0
000gooooo`;o00000oooool2o`0001[ooooo0_l00005ooooo`;o00003?ooool2o`0004;ooooo0_l0
000<ooooo`;o00000_ooool4o`0001Sooooo0ol0000Pooooo`;o00008Oooool000kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo
00?o0000ooooooooool0Boooool2o`0003Oooooo0_l00012ooooo`;o0000Coooool2o`00027ooooo
000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`1;ooooo`;o0000;Oooool2o`000<3ooooo000>ooooo`05oa0@4?oo
ooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`?o0000N_ooool2o`00013ooooo
0_l0002:ooooo`;o00008_ooool000kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0JOooool2o`00027ooooo0_l0002:ooooo`;o0000
8_ooool000kooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`1Yooooo`;o00003?ooool2o`000<?ooooo000>ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Go
oooo1?l0000nooooo`;o0000`oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0=Oooool4o`000<cooooo0_l00008ooooo`;o
0000:oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`000?oo
oooo1oooool2o`0000Sooooo0_l0000[ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^oooo
o`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocgooooo
0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool0
1oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go
410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool0
0oooool3o`000?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q
8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo
0006ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@
4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004oooo
o`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Oooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3oooooocgooooo000Q
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0
003oooooooooo`05ooooo`?o0000oooooolmooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Oooooo`03oeEEEOmVIVKo0000
0?ooooooAoooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .39549 Mdot
.02762 .24374 Mdot
.02952 .28552 Mdot
.03143 .32919 Mdot
.03333 .3534 Mdot
.03524 .25586 Mdot
.03714 .31812 Mdot
.03905 .39985 Mdot
.04095 .26749 Mdot
.04286 .34565 Mdot
.04476 .25549 Mdot
.04667 .42598 Mdot
.04857 .40755 Mdot
.05048 .27329 Mdot
.05238 .41195 Mdot
.05429 .26812 Mdot
.05619 .24472 Mdot
.0581 .4112 Mdot
.06 .31096 Mdot
.0619 .28785 Mdot
.06381 .40373 Mdot
.06571 .26343 Mdot
.06762 .28025 Mdot
.06952 .4135 Mdot
.07143 .45212 Mdot
.07333 .2878 Mdot
.07524 .27181 Mdot
.07714 .337 Mdot
.07905 .3195 Mdot
.08095 .24691 Mdot
.08286 .40734 Mdot
.08476 .25172 Mdot
.08667 .32507 Mdot
.08857 .32333 Mdot
.09048 .38357 Mdot
.09238 .2709 Mdot
.09429 .43185 Mdot
.09619 .35425 Mdot
.0981 .32645 Mdot
.1 .44408 Mdot
.1019 .45351 Mdot
.10381 .37699 Mdot
.10571 .31745 Mdot
.10762 .37422 Mdot
.10952 .39921 Mdot
.11143 .33049 Mdot
.11333 .31944 Mdot
.11524 .325 Mdot
.11714 .37285 Mdot
.11905 .27619 Mdot
.12095 .33967 Mdot
.12286 .39921 Mdot
.12476 .44627 Mdot
.12667 .36771 Mdot
.12857 .34132 Mdot
.13048 .23145 Mdot
.13238 .40128 Mdot
.13429 .24502 Mdot
.13619 .39926 Mdot
.1381 .39754 Mdot
.14 .31735 Mdot
.1419 .26877 Mdot
.14381 .32293 Mdot
.14571 .33571 Mdot
.14762 .27243 Mdot
.14952 .22791 Mdot
.15143 .34818 Mdot
.15333 .31006 Mdot
.15524 .35532 Mdot
.15714 .41441 Mdot
.15905 .29844 Mdot
.16095 .31173 Mdot
.16286 .34627 Mdot
.16476 .33427 Mdot
.16667 .32218 Mdot
.16857 .28287 Mdot
.17048 .4461 Mdot
.17238 .28514 Mdot
.17429 .38274 Mdot
.17619 .35377 Mdot
.1781 .39438 Mdot
.18 .26046 Mdot
.1819 .29452 Mdot
.18381 .38258 Mdot
.18571 .33919 Mdot
.18762 .25755 Mdot
.18952 .35888 Mdot
.19143 .3627 Mdot
.19333 .24774 Mdot
.19524 .30625 Mdot
.19714 .45174 Mdot
.19905 .44304 Mdot
.20095 .29283 Mdot
.20286 .35736 Mdot
.20476 .3227 Mdot
.20667 .43007 Mdot
.20857 .28307 Mdot
.21048 .35318 Mdot
.21238 .43413 Mdot
.21429 .24486 Mdot
.21619 .38671 Mdot
.2181 .27603 Mdot
.22 .41491 Mdot
.2219 .35822 Mdot
.22381 .40285 Mdot
.22571 .34301 Mdot
.22762 .31457 Mdot
.22952 .26651 Mdot
.23143 .2894 Mdot
.23333 .41396 Mdot
.23524 .31606 Mdot
.23714 .33051 Mdot
.23905 .26289 Mdot
.24095 .23243 Mdot
.24286 .22117 Mdot
.24476 .29557 Mdot
.24667 .29627 Mdot
.24857 .25248 Mdot
.25048 .2284 Mdot
.25238 .42726 Mdot
.25429 .40445 Mdot
.25619 .32717 Mdot
.2581 .35764 Mdot
.26 .33697 Mdot
.2619 .4142 Mdot
.26381 .33846 Mdot
.26571 .2342 Mdot
.26762 .39064 Mdot
.26952 .34932 Mdot
.27143 .27357 Mdot
.27333 .29772 Mdot
.27524 .36893 Mdot
.27714 .43975 Mdot
.27905 .2833 Mdot
.28095 .26872 Mdot
.28286 .37308 Mdot
.28476 .43333 Mdot
.28667 .27072 Mdot
.28857 .3475 Mdot
.29048 .34879 Mdot
.29238 .42299 Mdot
.29429 .22269 Mdot
.29619 .27323 Mdot
.2981 .34345 Mdot
.3 .24472 Mdot
.3019 .24972 Mdot
.30381 .30514 Mdot
.30571 .27382 Mdot
.30762 .28883 Mdot
.30952 .36306 Mdot
.31143 .33834 Mdot
.31333 .28899 Mdot
.31524 .3478 Mdot
.31714 .415 Mdot
.31905 .29828 Mdot
.32095 .31192 Mdot
.32286 .42741 Mdot
.32476 .35554 Mdot
.32667 .24119 Mdot
.32857 .43132 Mdot
.33048 .43005 Mdot
.33238 .35339 Mdot
.33429 .39015 Mdot
.33619 .45205 Mdot
.3381 .33451 Mdot
.34 .34061 Mdot
.3419 .39455 Mdot
.34381 .28819 Mdot
.34571 .38739 Mdot
.34762 .35548 Mdot
.34952 .43213 Mdot
.35143 .23376 Mdot
.35333 .30037 Mdot
.35524 .34131 Mdot
.35714 .35141 Mdot
.35905 .25676 Mdot
.36095 .31132 Mdot
.36286 .41743 Mdot
.36476 .29789 Mdot
.36667 .32097 Mdot
.36857 .31739 Mdot
.37048 .42522 Mdot
.37238 .45155 Mdot
.37429 .30277 Mdot
.37619 .45189 Mdot
.3781 .33094 Mdot
.38 .29571 Mdot
.3819 .37794 Mdot
.38381 .2424 Mdot
.38571 .45454 Mdot
.38762 .28188 Mdot
.38952 .37069 Mdot
.39143 .25189 Mdot
.39333 .30246 Mdot
.39524 .31388 Mdot
.39714 .36776 Mdot
.39905 .432 Mdot
.40095 .42799 Mdot
.40286 .36333 Mdot
.40476 .47466 Mdot
.40667 .36641 Mdot
.40857 .31748 Mdot
.41048 .32198 Mdot
.41238 .31991 Mdot
.41429 .33528 Mdot
.41619 .47847 Mdot
.4181 .38433 Mdot
.42 .27973 Mdot
.4219 .27861 Mdot
.42381 .33547 Mdot
.42571 .30537 Mdot
.42762 .25576 Mdot
.42952 .37511 Mdot
.43143 .29293 Mdot
.43333 .38671 Mdot
.43524 .2635 Mdot
.43714 .39288 Mdot
.43905 .32119 Mdot
.44095 .45153 Mdot
.44286 .33003 Mdot
.44476 .38031 Mdot
.44667 .43744 Mdot
.44857 .30228 Mdot
.45048 .4028 Mdot
.45238 .39436 Mdot
.45429 .38091 Mdot
.45619 .26801 Mdot
.4581 .30186 Mdot
.46 .24908 Mdot
.4619 .29826 Mdot
.46381 .41524 Mdot
.46571 .29688 Mdot
.46762 .30865 Mdot
.46952 .27286 Mdot
.47143 .47632 Mdot
.47333 .35923 Mdot
.47524 .28246 Mdot
.47714 .35535 Mdot
.47905 .35064 Mdot
.48095 .33925 Mdot
.48286 .37072 Mdot
.48476 .37513 Mdot
.48667 .27524 Mdot
.48857 .24064 Mdot
.49048 .34517 Mdot
.49238 .29651 Mdot
.49429 .23605 Mdot
.49619 .33449 Mdot
.4981 .41436 Mdot
.5 .31927 Mdot
.5019 .29124 Mdot
.50381 .33602 Mdot
.50571 .43934 Mdot
.50762 .30211 Mdot
.50952 .28873 Mdot
.51143 .42061 Mdot
.51333 .27626 Mdot
.51524 .33339 Mdot
.51714 .29551 Mdot
.51905 .27501 Mdot
.52095 .37927 Mdot
.52286 .36274 Mdot
.52476 .36655 Mdot
.52667 .28199 Mdot
.52857 .36514 Mdot
.53048 .2669 Mdot
.53238 .3128 Mdot
.53429 .39716 Mdot
.53619 .31214 Mdot
.5381 .25241 Mdot
.54 .24504 Mdot
.5419 .30965 Mdot
.54381 .23911 Mdot
.54571 .32092 Mdot
.54762 .34383 Mdot
.54952 .37256 Mdot
.55143 .42774 Mdot
.55333 .32089 Mdot
.55524 .27147 Mdot
.55714 .32464 Mdot
.55905 .25553 Mdot
.56095 .30681 Mdot
.56286 .34644 Mdot
.56476 .31133 Mdot
.56667 .2955 Mdot
.56857 .43078 Mdot
.57048 .40627 Mdot
.57238 .25896 Mdot
.57429 .26848 Mdot
.57619 .26125 Mdot
.5781 .24287 Mdot
.58 .35635 Mdot
.5819 .4053 Mdot
.58381 .37301 Mdot
.58571 .41275 Mdot
.58762 .39569 Mdot
.58952 .41682 Mdot
.59143 .31035 Mdot
.59333 .41252 Mdot
.59524 .35787 Mdot
.59714 .27326 Mdot
.59905 .40476 Mdot
.60095 .336 Mdot
.60286 .37113 Mdot
.60476 .24808 Mdot
.60667 .3568 Mdot
.60857 .24093 Mdot
.61048 .4531 Mdot
.61238 .29718 Mdot
.61429 .33747 Mdot
.61619 .29638 Mdot
.6181 .2766 Mdot
.62 .36167 Mdot
.6219 .24981 Mdot
.62381 .39438 Mdot
.62571 .36081 Mdot
.62762 .28724 Mdot
.62952 .38845 Mdot
.63143 .35617 Mdot
.63333 .29858 Mdot
.63524 .26459 Mdot
.63714 .45176 Mdot
.63905 .41949 Mdot
.64095 .25522 Mdot
.64286 .33634 Mdot
.64476 .30059 Mdot
.64667 .38486 Mdot
.64857 .35507 Mdot
.65048 .32246 Mdot
.65238 .3171 Mdot
.65429 .31852 Mdot
.65619 .28986 Mdot
.6581 .42544 Mdot
.66 .41297 Mdot
.6619 .32212 Mdot
.66381 .3338 Mdot
.66571 .28867 Mdot
.66762 .32022 Mdot
.66952 .24565 Mdot
.67143 .24953 Mdot
.67333 .33838 Mdot
.67524 .352 Mdot
.67714 .32115 Mdot
.67905 .45917 Mdot
.68095 .27949 Mdot
.68286 .30037 Mdot
.68476 .33406 Mdot
.68667 .26996 Mdot
.68857 .25965 Mdot
.69048 .25451 Mdot
.69238 .24318 Mdot
.69429 .25909 Mdot
.69619 .35377 Mdot
.6981 .22267 Mdot
.7 .4269 Mdot
.7019 .40958 Mdot
.70381 .25185 Mdot
.70571 .36876 Mdot
.70762 .34969 Mdot
.70952 .23286 Mdot
.71143 .33896 Mdot
.71333 .42487 Mdot
.71524 .2895 Mdot
.71714 .33588 Mdot
.71905 .43634 Mdot
.72095 .45278 Mdot
.72286 .45009 Mdot
.72476 .32075 Mdot
.72667 .36876 Mdot
.72857 .42218 Mdot
.73048 .38965 Mdot
.73238 .31563 Mdot
.73429 .41107 Mdot
.73619 .26215 Mdot
.7381 .29658 Mdot
.74 .3905 Mdot
.7419 .33617 Mdot
.74381 .34407 Mdot
.74571 .42802 Mdot
.74762 .38857 Mdot
.74952 .26503 Mdot
.75143 .41826 Mdot
.75333 .27849 Mdot
.75524 .44861 Mdot
.75714 .22172 Mdot
.75905 .43006 Mdot
.76095 .33975 Mdot
.76286 .27552 Mdot
.76476 .43719 Mdot
.76667 .24881 Mdot
.76857 .3157 Mdot
.77048 .45439 Mdot
.77238 .41429 Mdot
.77429 .31685 Mdot
.77619 .34194 Mdot
.7781 .24846 Mdot
.78 .29892 Mdot
.7819 .30324 Mdot
.78381 .37597 Mdot
.78571 .33086 Mdot
.78762 .4529 Mdot
.78952 .29405 Mdot
.79143 .47097 Mdot
.79333 .32787 Mdot
.79524 .2586 Mdot
.79714 .25619 Mdot
.79905 .31289 Mdot
.80095 .41484 Mdot
.80286 .42253 Mdot
.80476 .26828 Mdot
.80667 .26596 Mdot
.80857 .32254 Mdot
.81048 .2739 Mdot
.81238 .40164 Mdot
.81429 .35887 Mdot
.81619 .32803 Mdot
.8181 .27658 Mdot
.82 .34839 Mdot
.8219 .26566 Mdot
.82381 .3647 Mdot
.82571 .3037 Mdot
.82762 .32546 Mdot
.82952 .26872 Mdot
.83143 .33357 Mdot
.83333 .34779 Mdot
.83524 .30873 Mdot
.83714 .37956 Mdot
.83905 .31392 Mdot
.84095 .33596 Mdot
.84286 .28076 Mdot
.84476 .35057 Mdot
.84667 .43071 Mdot
.84857 .45533 Mdot
.85048 .33268 Mdot
.85238 .28264 Mdot
.85429 .35845 Mdot
.85619 .26449 Mdot
.8581 .26081 Mdot
.86 .42594 Mdot
.8619 .25493 Mdot
.86381 .24762 Mdot
.86571 .45625 Mdot
.86762 .26169 Mdot
.86952 .29004 Mdot
.87143 .25163 Mdot
.87333 .3637 Mdot
.87524 .34265 Mdot
.87714 .46401 Mdot
.87905 .32748 Mdot
.88095 .38182 Mdot
.88286 .37863 Mdot
.88476 .33168 Mdot
.88667 .30046 Mdot
.88857 .3342 Mdot
.89048 .39884 Mdot
.89238 .26597 Mdot
.89429 .37472 Mdot
.89619 .2683 Mdot
.8981 .39707 Mdot
.9 .23258 Mdot
.9019 .41118 Mdot
.90381 .27212 Mdot
.90571 .40357 Mdot
.90762 .3457 Mdot
.90952 .42908 Mdot
.91143 .43802 Mdot
.91333 .31551 Mdot
.91524 .41061 Mdot
.91714 .29473 Mdot
.91905 .26587 Mdot
.92095 .25301 Mdot
.92286 .38413 Mdot
.92476 .30014 Mdot
.92667 .35137 Mdot
.92857 .32835 Mdot
.93048 .24998 Mdot
.93238 .29025 Mdot
.93429 .28386 Mdot
.93619 .34467 Mdot
.9381 .36126 Mdot
.94 .32078 Mdot
.9419 .33441 Mdot
.94381 .36976 Mdot
.94571 .26671 Mdot
.94762 .32512 Mdot
.94952 .25313 Mdot
.95143 .22759 Mdot
.95333 .35299 Mdot
.95524 .39313 Mdot
.95714 .34613 Mdot
.95905 .34605 Mdot
.96095 .28588 Mdot
.96286 .22479 Mdot
.96476 .28031 Mdot
.96667 .24472 Mdot
.96857 .4079 Mdot
.97048 .3218 Mdot
.97238 .35288 Mdot
.97429 .28975 Mdot
.97619 .44524 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo04?ooooo0_l0002Sooooo`;o0000D_ooool000Kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo04?ooooo0_l0000>ooooo`;o0000P?ooool2o`00017ooooo0_l00010
ooooo`;o00004?ooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`0Uooooo`;o0000;?ooool2o`00083ooooo0_l0001@ooooo`;o000000?oooooo`000?l000004?oo
ool000Co00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Gooooo0_l0000Nooooo`;o0000h?oo
ool2o`0001?ooooo0006ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^
kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Oooooo`;o00008Oooool2o`000003ooooool0
003o000001oooooo0_l0001aooooo`;o0000>oooool2o`0002Cooooo0006ooooo`05o`000?oooooo
ooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`0Oooooo`;o00008Oooool2o`0000Kooooo0_l0000Jooooo`;o0000
;?ooool2o`0004?ooooo0_l0000kooooo`;o00009?ooool000Kooooo00Go410@oooooooooooooooo
oa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`1:ooooo`;o0000B?ooool2o`0000gooooo0_l0002Gooooo`001_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0G_ooool2o`00013ooooo0_l0000Pooooo`;o00003oooool2o`0000Wo
oooo0_l00008ooooo`;o00006Oooool2o`0006Oooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o00002?ooool2o`00
01Oooooo0_l0000Hooooo`;o00006Oooool2o`0000Oooooo0_l0000@ooooo`;o00008?ooool2o`00
00kooooo0_l0000:ooooo`;o00002?ooool2o`0001;ooooo0_l00005ooooo`;o0000E_ooool2o`00
00oooooo000Yooooo`;o00002?ooool2o`0000Kooooo0_l0000?ooooo`;o00004Oooool2o`0000Go
oooo0_l0000Iooooo`?o0000<Oooool2o`0001Oooooo0_l0000Cooooo`;o00004oooool3o`0001co
oooo0_l00002ooooo`;o00006Oooool2o`0001oooooo0_l0000?ooooo`00:Oooool00ol0003ooooo
ooooo`0?ooooo`?o00008Oooool2o`00013ooooo0_l0000?ooooo`;o00006_ooool2o`0001Gooooo
0_l0000Gooooo`;o00004oooool2o`0000Cooooo0_l0000>ooooo`;o00002?ooool2o`0001;ooooo
0_l00002ooooo`;o00006Oooool2o`000003ooooool0003o0000017ooooo0_l0000Jooooo`00:Ooo
ool00ol0003oooooooooo`02o`000003ooooool0003o000000_ooooo0_l0000cooooo`;o0000:ooo
ool2o`0000[ooooo0_l0000Rooooo`;o00001?ooool2o`0001?ooooo0_l00004ooooo`;o00003_oo
ool2o`0000;ooooo0_l0000aooooo`;o000000?oooooo`000?l000003_ooool2o`000003ooooool0
003o000000Cooooo0_l0000Dooooo`00:Oooool00ol0003oooooooooo`02o`000003ooooool0003o
000002cooooo0_l0000eooooo`;o00005?ooool2o`0002Sooooo0_l00003ooooo`;o00005?ooool2
o`0000kooooo0_l0000Oooooo`?o00004oooool2o`00017ooooo0_l00007ooooo`;o00005?ooool0
02Wooooo00?o0000ooooooooool0;_ooool2o`000003ooooool0003o000003Gooooo0_l00013oooo
o`?o00008_ooool4o`0000_ooooo0_l0000Aooooo`?o00004_ooool2o`000003ooooool0003o0000
02kooooo000Yooooo`;o00002oooool2o`0002;ooooo0_l0000Aooooo`;o0000?_ooool2o`0002_o
oooo0_l0000Aooooo`;o00003oooool4o`0000_ooooo0_l00003ooooo`;o00008?ooool3o`000003
ooooool0003o000002kooooo000Yooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o0000
0_ooool2o`0003;ooooo0_l000000ooooooo0000o`00000nooooo`;o00001?ooool2o`0001Kooooo
0_l0000Pooooo`;o00008oooool2o`0000oooooo0ol00003ooooo`;o00002Oooool2o`0000[ooooo
0ol00005ooooo`;o00001oooool2o`0001Gooooo000Yooooo`03o`000?oooooooooo00;ooooo0_l0
0002ooooo`;o00002_ooool2o`0000kooooo0_l0000<ooooo`Co000000So410@ooooooooooook^k^
oc8b<_l0003o<S8bonk^kP;ooooo0_l000001?lb<S;o0000oc8b<_o^k^h;ooooo`Co00006_ooool5
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2o`0001Kooooo0_l00006ooooo`;o000000?ooooooiRHV?l@41000ol00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo0_l0000Foooo
o`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h00oooool3o`000003oc8b
<_o^k^kooooo00Co00004oooool3o`0000Gooooo0_l00007ooooo`?o000000Wo<S8bomgMgOoooooo
ooooonk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Y
ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`;o00000oooool2o`0000kooooo1?l0000<
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02?ooool2o`000003ooooool0003o000000;o000000Coooooo`000?l0003o
oooo0_l0000Dooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0:ooooo`;o00006Oooool2o`000004ooooool@
413o^[Zjooooo`;o00000oooool00omgMgOoV9RHooooo`02o`0000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Booooo`;o00005oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHo`000?l0003oMgMg00?ooooo0_l0000Fooooo`;o00003oooool0
2OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool002Wooooo00?o0000ooooooooool01Oooool2o`0000Kooooo0_l0000<ooooo`;o
00001oooool2o`0000cooooo00?o0000ooooooooool00_ooool01?l@413oooooooooooooool2o`00
00;ooooo00Go410@oooooooooooooooooa0@4008ooooo`;o00001_ooool2o`000003ooooool0003o
000001Gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@400:ooooo`;o00000oooool2o`0000Oooooo1?l0000@ooooo`05o`00
0?ooooooooooooooool@41000_ooool2o`0000?ooooo00Go410@o`000?l0003ooooooa0@400Xoooo
o`Go00000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@ooooool0003o0000oa0@
4002o`0001Wooooo0_l0000@ooooo`04o`000?oooooooooooa0@40?ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`03oa0@4?oooooooooo007ooooo000Yooooo`;o00002oooool2o`0000oooooo
0_l0000Eooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0_l00002ooooo`05
o`000?ooooooooooooooool00000:oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooooooo
ooooool000000_ooool2o`0000?ooooo00?o0000ooooooooool03Oooool2o`0000Oooooo1?l0000?
ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`?o000000?o
ooooo`000?ooool04?ooool2o`0001Gooooo0_l000000ooooooo0000o`000003ooooo`05o`000?oo
ooooooooooooool000000oooool01?l0003oooooooooooooool3o`0000Kooooo0_l0000Rooooo`03
ogMgMolb<S;ooooo00;o00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool00Oooool002Wooooo00?o0000ooooooooool02_ooool2o`0001oooooo0_l00005ooooo`03
o`000?oooooooooo00;ooooo0ol000000ooooooo0000ooooo`02ooooo`05o`000?oooooooooooooo
ool000002_ooool2o`00023ooooo00?oMgMgo`000?l000000_ooool01Ol0003ooooooooooooooooo
000000;ooooo0_l00003ooooo`03o`000?oooooooooo00Wooooo0_l0000?ooooo`;o00003?ooool0
0ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo0000017ooooo0_l0000Eooooo`;o000000?oooooo`000?ooool00oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`;o000000?oooooo`00
0?l000006?ooool2o`0000;ooooo00Ko0000ob4Q8Ol0003o<S8bolc<c?ooool2o`0000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo007ooooo000Yooooo`?o0000:ooo
ool3o`0000Cooooo00?o0000ooooooooool00_ooool01Ol@413o0000o`000?oooooo410@00?ooooo
00Go410@oooooooooooooooooa0@400:ooooo`;o00008Oooool2o`0000;ooooo00Go410@oooooooo
oooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002oooool2o`0000oooooo0_l0000=
ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oo
ooooooooooooool@4100:Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@00_ooooo0_l0000Hooooo`;o00000_ooool00ol0
003oooooooooo`02ooooo`;o000000Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo
ooooooooool@41000oooool002Wooooo0ol00009ooooo`;o000000?oooooo`000?l000007_ooool2
o`0000Cooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0_l0
00000oooooooV9RHogMgM`0Dooooo`?o00002?ooool2o`0000Sooooo00Go0000okZj^_ooooooV9RH
oa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
01Kooooo0_l0000@ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00CoMgMgoiRHV?ooooooV9RH0_l00008ooooo`;o000000?oooooo`000?l00000
3_ooool2o`0000_ooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0@ooooo`;o00005oooool00ol0003oooooooooo`02oooo
o`;o000000GoMgMgoiRHV?l0003o0000ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool002Wooooo00?o0000ooooooooool02Oooool2o`000003ooooool0003o000002;ooooo00?oEEEE
ofIVI_l000000_ooool2o`000005onk^k_lb<S;o0000oc8b<_o^k^h00oooool3o`000003oc8b<_o^
k^kooooo01?ooooo0ol00008ooooo`;o00002?ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000o`000?o^k^h05?ooool4o`00
013ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01?o^k^ko<S8bo`000?lb<S82o`0000Sooooo0_l000000ooooooo0000o`00000>ooooo`;o0000
3?ooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^013ooooo0_l0000Booooo`;o00000oooool4o`0000?ooooo00Gok^k^oc8b
<_l0003o0000onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool002Wooooo0_l0000`
ooooo`;o00001?ooool2o`0000cooooo0ol0000Yooooo`;o00003_ooool2o`0001Gooooo0_l00003
ooooo`;o00003_ooool2o`0000kooooo0_l0000eooooo`;o0000:?ooool2o`0000;ooooo0_l0000J
ooooo`00:Oooool00ol0003oooooooooo`0Xooooo`;o00001Oooool2o`0001;ooooo0ol00007oooo
o`;o00003?ooool2o`0000gooooo0_l00003ooooo`;o00006?ooool3o`0000Oooooo0_l00006oooo
o`;o00003_ooool2o`0000gooooo0ol00003ooooo`;o00008?ooool2o`0000_ooooo0_l000000ooo
oooo0000o`00000Xooooo`;o00007_ooool002Wooooo00?o0000ooooooooool0:?ooool2o`0002?o
oooo0_l0000<ooooo`;o00002Oooool2o`0000;ooooo0_l00007ooooo`;o00004?ooool2o`000003
ooooool0003o000000;o00001oooool2o`0000?ooooo0_l0000Pooooo`;o00001?ooool2o`0000;o
oooo0_l0000:ooooo`;o00004?ooool2o`0000_ooooo0_l0000Qooooo`;o00002_ooool2o`0001co
oooo000Yooooo`03o`000?oooooooooo05Kooooo0_l0000>ooooo`;o00001Oooool2o`0000Cooooo
0_l00008ooooo`;o00001_ooool2o`000003ooooool0003o000000kooooo0_l0000Zooooo`;o0000
2_ooool2o`0001kooooo0_l0000<ooooo`;o00004_ooool2o`0000[ooooo0_l0000Looooo`00:Ooo
ool00ol0003oooooooooo`0cooooo`;o00008Oooool2o`0001Gooooo0_l0000>ooooo`;o00003?oo
ool2o`0001cooooo0_l00015ooooo`;o00003?ooool2o`000003ooooool0003o000003Wooooo000Q
oooooooo0000A?l00004ooooo`00:Oooool00ol0003oooooooooo`08ooooo`;o00003?ooool00ol0
003oooooooooo`09ooooo`04o`000?ooooooooooooooo`Co00001?ooool00ol0003oooooooooo`09
ooooo`04o`000?ooooooooooooooo`;o00001oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Kooooo0_l000000ooooooo0000ooooo`08ooooo`?o00002?ooool2o`0000;ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00Co
0000oooooooooooooooo1Ol00004ooooo`?o00001oooool3o`0000_ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool01?l0003oooooooooooooool2o`0000Kooooo00Co0000oooooooooooooooo0_l00007oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo000Yooooo`04o`000?ooooooooooooooo`;o00005?ooool2o`00
00Wooooo0_l0000Fooooo`04o`000?ooooooooooooooo`Co0000:Oooool2o`0000Oooooo0_l00002
ooooo`;o00009_ooool3o`0001;ooooo00?o0000ooooooooool03_ooool2o`0001Sooooo0_l0000:
ooooo`Co00000_ooool01?l0003oooooooooooooool2o`0000[ooooo0_l0000Fooooo`;o00004ooo
ool00ol0003oooooooooo`0:ooooo`00:Oooool01?l0003oooooooooooooool2o`0000_ooooo0_l0
0007ooooo`Co00001oooool2o`0001cooooo0_l0000Yooooo`;o00002oooool3o`0000Oooooo0_l0
000Aooooo`;o00003Oooool2o`000003ooooool0003o000001gooooo0ol00002ooooo`;o000000?o
ooooo`000?l000003_ooool4o`0000[ooooo1?l0000Zooooo`;o00001oooool2o`0001Oooooo000Y
ooooo`03o`000?oooooooooo00kooooo0_l000000ooooooo0000o`000006ooooo`;o00002?ooool2
o`0000Gooooo0_l0000:ooooo`;o0000<oooool2o`0000cooooo0_l00007ooooo`;o00004Oooool2
o`0000gooooo0_l000000ooooooo0000o`00000Mooooo`Oo000000?oooooo`000?l000003_ooool2
o`0001Wooooo0_l0000Xooooo`;o00002?ooool2o`0000gooooo000Yooooo`;o00004Oooool3o`00
0003ooooool0003o000000Cooooo0_l00007ooooo`;o00001Oooool2o`0000[ooooo0_l0000?oooo
o`;o0000<?ooool2o`0002gooooo0_l0000Looooo`;o000000?oooooo`000?l00000;_ooool2o`00
00Cooooo0_l0000>ooooo`;o00005?ooool2o`0000Kooooo0_l0000=ooooo`00:Oooool01?l0003o
ooooo`000?l0000?ooooo`;o00000_ooool2o`0000;ooooo1?l0000Uooooo`;o00001?ooool2o`00
03[ooooo0_l0000Sooooo`;o0000B_ooool2o`0000Gooooo0_l00002ooooo`;o00003_ooool2o`00
00kooooo0_l00004ooooo`;o00005Oooool002Wooooo00Co0000ooooool0003o00005oooool2o`00
02Oooooo0_l0000[ooooo`;o00004oooool2o`0001Gooooo0_l0001Eooooo`;o000000?oooooo`00
0?l000001Oooool2o`0000?ooooo0_l00004ooooo`;o00002Oooool2o`0000cooooo0_l0000Koooo
o`00:Oooool00ol0003oooooooooo`0Sooooo`;o00001Oooool2o`0003Gooooo0_l0000;ooooo`;o
00002_ooool2o`000003ooooool0003o000001Gooooo0_l000001?oooooo0000o`000?ooool2o`00
01[ooooo0_l0000;ooooo`;o00001Oooool2o`0000Gooooo0_l00008ooooo`;o00001_ooool2o`00
00cooooo0_l0000=ooooo`;o000000Coooooo`000?l0003ooooo0_l00009ooooo`?o00003oooool2
o`0001Oooooo000Yooooo`03o`000?oooooooooo00gooooo0_l0000=ooooo`;o00001Oooool2o`00
00Gooooo0_l00004ooooo`;o00005_ooool3o`0000kooooo0_l00006ooooo`;o00005oooool2o`00
0003ooooool0003o0000013ooooo0_l00003ooooo`;o000000?oooooo`000?l000007Oooool2o`00
00;ooooo0_l00007ooooo`;o00001Oooool2o`000003ooooool0003o000000;ooooo0_l00006oooo
o`Co00001_ooool2o`0000Cooooo0_l0000Hooooo`;o00003Oooool2o`0000oooooo0_l0000Goooo
o`00:Oooool2o`0000kooooo0_l0000=ooooo`Co00004?ooool2o`0000_ooooo0_l00009ooooo`?o
00003_ooool2o`0000Oooooo0_l00003ooooo`;o00009_ooool2o`0002Wooooo0_l0000Aooooo`;o
00002_ooool2o`0000kooooo0_l00003ooooo`;o00007_ooool2o`0002cooooo000Yooooo`03o`00
0?oooooooooo00;ooooo0_l0000Jooooo`;o00007Oooool2o`0001Gooooo0_l0000<ooooo`;o0000
0oooool2o`0002Wooooo0_l0000Aooooo`;o0000?Oooool2o`0000Sooooo0_l0000Nooooo`;o0000
2?ooool2o`0000Sooooo0_l00004ooooo`?o00004Oooool002Wooooo00?o0000ooooooooool00_oo
ool2o`00027ooooo0_l00002ooooo`;o00009_ooool5o`0000Cooooo0_l0000fooooo`;o00004Ooo
ool2o`0000?ooooo0_l0000hooooo`;o00005_ooool2o`0000?ooooo0_l0000Eooooo`;o00002?oo
ool2o`0000Cooooo0ol0000Aooooo`00:Oooool00ol0003oooooooooo`0Uooooo`;o00000_ooool2
o`00023ooooo0_l00004ooooo`?o00001_ooool2o`0000_ooooo0_l0000Vooooo`;o00006Oooool2
o`0002;ooooo0_l00008ooooo`;o00008_ooool2o`0000?ooooo0_l000000ooooooo0000o`00000I
ooooo`;o00006oooool002Wooooo00Co0000ooooool0003o00004oooool2o`00017ooooo0_l00004
ooooo`;o00002Oooool2o`00017ooooo0_l0000Booooo`;o00001_ooool2o`0002Gooooo0ol0000d
ooooo`;o00001oooool2o`0000Cooooo0_l00002ooooo`;o0000:_ooool2o`0001Wooooo0_l00006
ooooo`;o00001?ooool2o`0000gooooo000Yooooo`Co00004oooool2o`00017ooooo0_l00004oooo
o`;o00001oooool4o`0000;ooooo0_l0000:ooooo`;o00004oooool4o`0000?ooooo0_l0000Xoooo
o`;o00007oooool2o`0000?ooooo0_l00002ooooo`;o00001_ooool2o`0000?ooooo0_l0000=oooo
o`;o0000<Oooool2o`0001kooooo0_l00004ooooo`;o00003Oooool002Wooooo00?o0000oooooooo
ool0<_ooool2o`0000;ooooo0_l00004ooooo`;o00002_ooool2o`0001?ooooo0_l00005ooooo`;o
00009oooool2o`00023ooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo1_l0000hooooo`;o
00002oooool2o`0001Wooooo0_l0000Hooooo`00:Oooool00ol0003oooooooooo`0booooo`;o0000
9?ooool2o`0001cooooo0_l0000Eooooo`;o00003_ooool2o`0001gooooo1?l0000jooooo`;o0000
0_ooool2o`0000gooooo0_l0000Cooooo`;o00006?ooool002Wooooo00?o0000ooooooooool07Ooo
ool2o`0001?ooooo0_l0000Tooooo`;o00006_ooool5o`0002Cooooo1?l0001Mooooo`;o00003Ooo
ool2o`0002gooooo000Yooooo`03o`000?oooooooooo01gooooo0_l0000^ooooo`;o00008oooool4
o`000003ooooool0003o000001Oooooo0_l0000;ooooo`Co0000=oooool2o`0000Cooooo0_l00014
ooooo`;o00005_ooool002Wooooo0_l0000Kooooo`;o0000<Oooool2o`000003ooooool0003o0000
023ooooo0_l0000Looooo`;o00004oooool2o`0000Wooooo0_l00004ooooo`;o00008?ooool2o`00
00Cooooo0_l00014ooooo`;o00005_ooool002Wooooo00?o0000ooooooooool05_ooool3o`000003
ooooool0003o000003Cooooo0_l0000]ooooo`;o00003oooool2o`0001?ooooo0_l00009ooooo`;o
00001?ooool2o`0003Wooooo0_l0000Qooooo`;o00009_ooool000Kooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo01Kooooo0ol0001Fooooo`;o00003_ooool2o`0000?ooooo0_l0000:oooo
o`;o00002_ooool2o`0005?ooooo0_l0000?ooooo`;o00003?ooool2o`0000;ooooo0_l0000Voooo
o`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02gooooo0_l00000
0ooooooo0000o`00000mooooo`;o00004oooool2o`000003ooooool0003o000001?ooooo0_l0001T
ooooo`;o00003?ooool2o`0002[ooooo0006ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04_ooool2
o`0001Wooooo0_l000000ooooooo0000o`000019ooooo`;o00002_ooool2o`0003cooooo0_l00019
ooooo`;o00002oooool2o`0001gooooo0006ooooo`05o`000?ooooooooooooooool000003Oooool0
0onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Booooo`;o00009_ooool2
o`0002Sooooo0_l0000Eooooo`;o00000oooool2o`0003gooooo0_l00004ooooo`;o00006?ooool2
o`0000Cooooo0_l0000fooooo`;o00007Oooool000Kooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oo
oooooooo03[ooooo0_l0000?ooooo`;o00004oooool2o`0000;ooooo0_l0000Jooooo`;o0000?Ooo
ool2o`0001kooooo0_l00002ooooo`Co0000EOooool000Kooooo00Go410@oooooooooooooooooa0@
400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool2o`0002oooooo0_l0
000Kooooo`;o00004oooool2o`000003ooooool0003o000001cooooo0_l00003ooooo`;o0000:_oo
ool2o`0000Wooooo0_l0000Tooooo`;o0000@oooool2o`0001;ooooo0006ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool0
1oooool2o`0002;ooooo0_l0000;ooooo`;o0000<oooool2o`0001cooooo0_l00003ooooo`;o0000
6?ooool2o`00013ooooo0_l00009ooooo`;o0000E?ooool4o`00017ooooo0_l0000Booooo`001_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co
00001_ooool01?l0003oooooooooooooool2o`0001Gooooo0_l00002ooooo`;o000000?oooooo`00
0?l000000_l0001mooooo`;o0000F?ooool2o`0001Oooooo1?l0000Uooooo`00:Oooool2o`0000;o
oooo0_l00006ooooo`;o00003Oooool2o`0000;ooooo0_l000001?oooooo0000o`000?l0000Koooo
o`;o00001oooool2o`0003gooooo0_l0000^ooooo`;o0000@oooool2o`0001cooooo0_l0000Roooo
o`00:Oooool00ol0003oooooooooo`04ooooo`;o00000oooool2o`0000Cooooo0_l0000/ooooo`;o
00001oooool2o`0003gooooo0_l0000Uooooo`;o00000_ooool2o`0000?ooooo0_l0001Qooooo`;o
00004_ooool2o`0000kooooo000Yooooo`03o`000?oooooooooo00Cooooo0_l000000ooooooo0000
o`000006ooooo`;o0000Voooool2o`0000;ooooo0_l0000Tooooo`;o00002Oooool2o`0003Cooooo
0_l00002ooooo`;o00003oooool2o`0000kooooo000Yooooo`03o`000?oooooooooo00Gooooo1?l0
0002ooooo`;o00006_ooool2o`0001Oooooo0_l00007ooooo`;o0000B_ooool2o`0001[ooooo1?l0
000Dooooo`;o00002oooool2o`0000Wooooo0_l0000:ooooo`;o0000:?ooool2o`0000;ooooo0_l0
000Oooooo`00:Oooool00ol0003oooooooooo`05ooooo`;o00001?ooool2o`0001[ooooo0_l0000B
ooooo`;o00000oooool2o`0000Oooooo0_l0000@ooooo`;o00003?ooool2o`0001oooooo0_l00009
ooooo`;o00006_ooool4o`0001Cooooo0_l0000Rooooo`;o00001oooool2o`0004Cooooo000Yoooo
o`;o0000??ooool2o`0001kooooo0_l0000<ooooo`;o00007oooool2o`0000gooooo0_l0000Goooo
o`;o00003_ooool2o`0002;ooooo0_l0000>ooooo`;o0000A?ooool002Wooooo00?o0000oooooooo
ool0Doooool2o`0004Cooooo0_l0000Wooooo`;o00006oooool2o`0000Gooooo0_l0000?ooooo`;o
0000@oooool002Wooooo00?o0000ooooooooool01?ooool2o`0004gooooo0_l0000Gooooo`;o0000
F_ooool2o`0000cooooo0_l00002ooooo`;o00000oooool2o`0001Kooooo0_l0000@ooooo`;o0000
<Oooool002Wooooo00?o0000ooooooooool01?ooool2o`00037ooooo0_l0000=ooooo`;o00005?oo
ool2o`000003ooooool0003o000000_ooooo0_l00008ooooo`;o0000;_ooool2o`00023ooooo0_l0
000<ooooo`;o00000_ooool2o`0000Sooooo0_l00003ooooo`;o00007_ooool2o`0000kooooo0_l0
000Qooooo`00:Oooool00ol0003oooooooooo`0Cooooo`;o00008_ooool2o`0000gooooo0_l0000D
ooooo`Go00001?ooool2o`0000kooooo0ol0000^ooooo`;o00000oooool2o`0003Oooooo0_l00003
ooooo`;o00006_ooool2o`0001;ooooo0_l0000Qooooo`00:Oooool2o`0001Cooooo0_l0000Toooo
o`;o00005Oooool2o`0000cooooo0_l00005ooooo`;o00003_ooool2o`0003Cooooo0_l0001Hoooo
o`;o0000=Oooool002Wooooo00?o0000ooooooooool0>Oooool2o`0001Gooooo0_l0000booooo`;o
00004Oooool2o`0004?ooooo0_l0000=ooooo`;o0000;Oooool2o`00023ooooo000Yooooo`03o`00
0?oooooooooo04kooooo0_l0000dooooo`;o00004Oooool2o`0004?ooooo0_l0000=ooooo`;o0000
;Oooool2o`00023ooooo000Yooooo`03o`000?oooooooooo01Gooooo0_l0000Nooooo`;o00005ooo
ool2o`000=oooooo0_l0000;ooooo`00:Oooool00ol0003oooooooooo`0Eooooo`;o00001_ooool2
o`0000cooooo0_l00008ooooo`;o0000/?ooool2o`0004Kooooo0_l0000;ooooo`00:Oooool2o`00
01kooooo0_l0000<ooooo`;o00001oooool2o`0003Kooooo0_l0000Dooooo`;o0000?Oooool2o`00
01[ooooo0_l00008ooooo`;o0000Doooool002Wooooo00?o0000ooooooooool03?ooool2o`0000Oo
oooo0_l0000Mooooo`;o0000:oooool2o`0000Wooooo1?l000000ooooooo0000o`00000?ooooo`;o
0000=Oooool2o`0000Kooooo0_l0000Iooooo`?o00003Oooool2o`0000Cooooo0_l00018ooooo`00
3_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`0<ooooo`;o00001oooool2o`0004[ooooo0_l0000;oooo
o`;o000000?oooooo`000?l00000A_ooool2o`00027ooooo0_l0000>ooooo`;o00001?ooool2o`00
017ooooo0_l00004ooooo`;o0000;oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0<oooooo0_l0000doooo
o`;o00001?ooool2o`0002oooooo000>ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`03ooooo`?o0000coooool2o`0003kooooo0_l0000[ooooo`003_ooool01Ol0003o
oooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooo
oa3ooooo0_l0000[ooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0loooool2
o`0004Oooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo07Oooooo0_l0000Cooooo`;o0000IOooool2o`0004Oooooo000>oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0001hooooo`;o000000?ooooo
o`000?l000004?ooool2o`000:kooooo000Yooooo`03o`000?oooooooooo07[ooooo0_l00030oooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_oo
ool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmoooo
o`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo
00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05
oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo
00?ooooo0ol0003oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00olQ
8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmoooo
o`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@
413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?oo
ool4o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`007oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooolmooooo`00
8Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o
0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`007oooool00omEEEGoIVIVo`00
003oooooodOooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(100)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(200)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(300)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(400)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(500)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02571 .38967 Mdot
.02762 .33168 Mdot
.02952 .27871 Mdot
.03143 .27595 Mdot
.03333 .29732 Mdot
.03524 .26521 Mdot
.03714 .30663 Mdot
.03905 .30393 Mdot
.04095 .3713 Mdot
.04286 .33901 Mdot
.04476 .31169 Mdot
.04667 .35155 Mdot
.04857 .35784 Mdot
.05048 .33423 Mdot
.05238 .32772 Mdot
.05429 .32568 Mdot
.05619 .30546 Mdot
.0581 .36886 Mdot
.06 .35467 Mdot
.0619 .23428 Mdot
.06381 .35019 Mdot
.06571 .2527 Mdot
.06762 .24241 Mdot
.06952 .37956 Mdot
.07143 .42483 Mdot
.07333 .24976 Mdot
.07524 .26601 Mdot
.07714 .35664 Mdot
.07905 .23262 Mdot
.08095 .33615 Mdot
.08286 .36298 Mdot
.08476 .35821 Mdot
.08667 .22892 Mdot
.08857 .24842 Mdot
.09048 .37346 Mdot
.09238 .36583 Mdot
.09429 .41143 Mdot
.09619 .32167 Mdot
.0981 .23514 Mdot
.1 .38916 Mdot
.1019 .44018 Mdot
.10381 .32683 Mdot
.10571 .37653 Mdot
.10762 .40193 Mdot
.10952 .3767 Mdot
.11143 .36585 Mdot
.11333 .34928 Mdot
.11524 .40668 Mdot
.11714 .36355 Mdot
.11905 .23956 Mdot
.12095 .41385 Mdot
.12286 .32007 Mdot
.12476 .48201 Mdot
.12667 .38576 Mdot
.12857 .3849 Mdot
.13048 .28498 Mdot
.13238 .30666 Mdot
.13429 .29693 Mdot
.13619 .43496 Mdot
.1381 .36236 Mdot
.14 .36268 Mdot
.1419 .38139 Mdot
.14381 .23417 Mdot
.14571 .30196 Mdot
.14762 .2369 Mdot
.14952 .31477 Mdot
.15143 .32545 Mdot
.15333 .34235 Mdot
.15524 .33866 Mdot
.15714 .39272 Mdot
.15905 .24389 Mdot
.16095 .27166 Mdot
.16286 .33586 Mdot
.16476 .27756 Mdot
.16667 .23396 Mdot
.16857 .31275 Mdot
.17048 .48197 Mdot
.17238 .34964 Mdot
.17429 .29095 Mdot
.17619 .28848 Mdot
.1781 .41475 Mdot
.18 .35073 Mdot
.1819 .25976 Mdot
.18381 .34456 Mdot
.18571 .23442 Mdot
.18762 .29223 Mdot
.18952 .3121 Mdot
.19143 .3303 Mdot
.19333 .32075 Mdot
.19524 .34173 Mdot
.19714 .4247 Mdot
.19905 .36304 Mdot
.20095 .33522 Mdot
.20286 .36112 Mdot
.20476 .33644 Mdot
.20667 .33947 Mdot
.20857 .33979 Mdot
.21048 .41942 Mdot
.21238 .47975 Mdot
.21429 .2955 Mdot
.21619 .39781 Mdot
.2181 .35074 Mdot
.22 .33175 Mdot
.2219 .39957 Mdot
.22381 .41375 Mdot
.22571 .26393 Mdot
.22762 .24473 Mdot
.22952 .33357 Mdot
.23143 .33418 Mdot
.23333 .39053 Mdot
.23524 .3498 Mdot
.23714 .27765 Mdot
.23905 .368 Mdot
.24095 .31207 Mdot
.24286 .33494 Mdot
.24476 .32809 Mdot
.24667 .35515 Mdot
.24857 .25099 Mdot
.25048 .29518 Mdot
.25238 .38758 Mdot
.25429 .35019 Mdot
.25619 .4181 Mdot
.2581 .26638 Mdot
.26 .23941 Mdot
.2619 .39372 Mdot
.26381 .29791 Mdot
.26571 .2911 Mdot
.26762 .27718 Mdot
.26952 .39571 Mdot
.27143 .27667 Mdot
.27333 .2369 Mdot
.27524 .39999 Mdot
.27714 .38088 Mdot
.27905 .24451 Mdot
.28095 .35105 Mdot
.28286 .27567 Mdot
.28476 .4151 Mdot
.28667 .2424 Mdot
.28857 .33006 Mdot
.29048 .24126 Mdot
.29238 .34768 Mdot
.29429 .31253 Mdot
.29619 .27054 Mdot
.2981 .35565 Mdot
.3 .30121 Mdot
.3019 .2604 Mdot
.30381 .22644 Mdot
.30571 .22452 Mdot
.30762 .34615 Mdot
.30952 .34839 Mdot
.31143 .42491 Mdot
.31333 .35815 Mdot
.31524 .29623 Mdot
.31714 .38783 Mdot
.31905 .26787 Mdot
.32095 .24079 Mdot
.32286 .38325 Mdot
.32476 .2551 Mdot
.32667 .26479 Mdot
.32857 .4068 Mdot
.33048 .39207 Mdot
.33238 .28554 Mdot
.33429 .30315 Mdot
.33619 .45138 Mdot
.3381 .40028 Mdot
.34 .38345 Mdot
.3419 .38859 Mdot
.34381 .2295 Mdot
.34571 .41678 Mdot
.34762 .3282 Mdot
.34952 .39826 Mdot
.35143 .29473 Mdot
.35333 .33617 Mdot
.35524 .28295 Mdot
.35714 .29361 Mdot
.35905 .32185 Mdot
.36095 .22694 Mdot
.36286 .31845 Mdot
.36476 .24096 Mdot
.36667 .32157 Mdot
.36857 .23242 Mdot
.37048 .37446 Mdot
.37238 .41142 Mdot
.37429 .25608 Mdot
.37619 .44572 Mdot
.3781 .30094 Mdot
.38 .38951 Mdot
.3819 .261 Mdot
.38381 .34829 Mdot
.38571 .44558 Mdot
.38762 .35979 Mdot
.38952 .44041 Mdot
.39143 .25783 Mdot
.39333 .26128 Mdot
.39524 .40996 Mdot
.39714 .25839 Mdot
.39905 .45864 Mdot
.40095 .35609 Mdot
.40286 .35056 Mdot
.40476 .43183 Mdot
.40667 .29968 Mdot
.40857 .27418 Mdot
.41048 .28117 Mdot
.41238 .28224 Mdot
.41429 .26679 Mdot
.41619 .4483 Mdot
.4181 .39797 Mdot
.42 .32601 Mdot
.4219 .24692 Mdot
.42381 .28688 Mdot
.42571 .33299 Mdot
.42762 .28984 Mdot
.42952 .29041 Mdot
.43143 .35338 Mdot
.43333 .41668 Mdot
.43524 .27918 Mdot
.43714 .39111 Mdot
.43905 .36278 Mdot
.44095 .45144 Mdot
.44286 .31987 Mdot
.44476 .31614 Mdot
.44667 .37345 Mdot
.44857 .35759 Mdot
.45048 .43432 Mdot
.45238 .41679 Mdot
.45429 .41453 Mdot
.45619 .32506 Mdot
.4581 .25041 Mdot
.46 .33987 Mdot
.4619 .33605 Mdot
.46381 .33357 Mdot
.46571 .40066 Mdot
.46762 .34281 Mdot
.46952 .30719 Mdot
.47143 .44154 Mdot
.47333 .37427 Mdot
.47524 .25858 Mdot
.47714 .43289 Mdot
.47905 .3061 Mdot
.48095 .394 Mdot
.48286 .28458 Mdot
.48476 .40023 Mdot
.48667 .38595 Mdot
.48857 .30519 Mdot
.49048 .406 Mdot
.49238 .24418 Mdot
.49429 .33889 Mdot
.49619 .32463 Mdot
.4981 .35171 Mdot
.5 .3692 Mdot
.5019 .24532 Mdot
.50381 .23966 Mdot
.50571 .45723 Mdot
.50762 .32856 Mdot
.50952 .2637 Mdot
.51143 .36696 Mdot
.51333 .25553 Mdot
.51524 .27051 Mdot
.51714 .3677 Mdot
.51905 .30599 Mdot
.52095 .27322 Mdot
.52286 .42435 Mdot
.52476 .37145 Mdot
.52667 .25882 Mdot
.52857 .41148 Mdot
.53048 .31104 Mdot
.53238 .36808 Mdot
.53429 .36719 Mdot
.53619 .34813 Mdot
.5381 .33532 Mdot
.54 .34155 Mdot
.5419 .24776 Mdot
.54381 .33286 Mdot
.54571 .37848 Mdot
.54762 .34272 Mdot
.54952 .34046 Mdot
.55143 .38361 Mdot
.55333 .26195 Mdot
.55524 .26217 Mdot
.55714 .4062 Mdot
.55905 .29016 Mdot
.56095 .24025 Mdot
.56286 .24627 Mdot
.56476 .26569 Mdot
.56667 .25699 Mdot
.56857 .40323 Mdot
.57048 .31629 Mdot
.57238 .32584 Mdot
.57429 .29924 Mdot
.57619 .27385 Mdot
.5781 .33984 Mdot
.58 .36098 Mdot
.5819 .40963 Mdot
.58381 .25546 Mdot
.58571 .43454 Mdot
.58762 .2995 Mdot
.58952 .43261 Mdot
.59143 .27356 Mdot
.59333 .43595 Mdot
.59524 .43323 Mdot
.59714 .36857 Mdot
.59905 .31507 Mdot
.60095 .22018 Mdot
.60286 .33192 Mdot
.60476 .33065 Mdot
.60667 .39839 Mdot
.60857 .34611 Mdot
.61048 .427 Mdot
.61238 .34486 Mdot
.61429 .41247 Mdot
.61619 .24779 Mdot
.6181 .27638 Mdot
.62 .27028 Mdot
.6219 .2813 Mdot
.62381 .32773 Mdot
.62571 .43643 Mdot
.62762 .32605 Mdot
.62952 .33559 Mdot
.63143 .2823 Mdot
.63333 .22787 Mdot
.63524 .29396 Mdot
.63714 .41301 Mdot
.63905 .4553 Mdot
.64095 .24269 Mdot
.64286 .33594 Mdot
.64476 .24 Mdot
.64667 .35545 Mdot
.64857 .2549 Mdot
.65048 .25535 Mdot
.65238 .27328 Mdot
.65429 .28675 Mdot
.65619 .24593 Mdot
.6581 .34918 Mdot
.66 .34977 Mdot
.6619 .33684 Mdot
.66381 .24353 Mdot
.66571 .26592 Mdot
.66762 .28305 Mdot
.66952 .33513 Mdot
.67143 .2741 Mdot
.67333 .38292 Mdot
.67524 .28312 Mdot
.67714 .25509 Mdot
.67905 .4829 Mdot
.68095 .25383 Mdot
.68286 .37595 Mdot
.68476 .2954 Mdot
.68667 .23796 Mdot
.68857 .28136 Mdot
.69048 .25541 Mdot
.69238 .32951 Mdot
.69429 .3018 Mdot
.69619 .36119 Mdot
.6981 .31292 Mdot
.7 .35291 Mdot
.7019 .43673 Mdot
.70381 .34974 Mdot
.70571 .32267 Mdot
.70762 .27135 Mdot
.70952 .30037 Mdot
.71143 .37514 Mdot
.71333 .34914 Mdot
.71524 .2241 Mdot
.71714 .4021 Mdot
.71905 .37348 Mdot
.72095 .41746 Mdot
.72286 .45139 Mdot
.72476 .31336 Mdot
.72667 .36806 Mdot
.72857 .34634 Mdot
.73048 .28811 Mdot
.73238 .31971 Mdot
.73429 .40149 Mdot
.73619 .26806 Mdot
.7381 .24077 Mdot
.74 .39546 Mdot
.7419 .41147 Mdot
.74381 .39558 Mdot
.74571 .42667 Mdot
.74762 .30268 Mdot
.74952 .25182 Mdot
.75143 .43595 Mdot
.75333 .24309 Mdot
.75524 .40745 Mdot
.75714 .28139 Mdot
.75905 .403 Mdot
.76095 .25392 Mdot
.76286 .28031 Mdot
.76476 .45531 Mdot
.76667 .32336 Mdot
.76857 .2799 Mdot
.77048 .42236 Mdot
.77238 .39532 Mdot
.77429 .27287 Mdot
.77619 .2941 Mdot
.7781 .29501 Mdot
.78 .25373 Mdot
.7819 .39496 Mdot
.78381 .41634 Mdot
.78571 .41936 Mdot
.78762 .41662 Mdot
.78952 .24517 Mdot
.79143 .47718 Mdot
.79333 .25039 Mdot
.79524 .32466 Mdot
.79714 .28146 Mdot
.79905 .3087 Mdot
.80095 .33007 Mdot
.80286 .34504 Mdot
.80476 .26936 Mdot
.80667 .3193 Mdot
.80857 .25916 Mdot
.81048 .26676 Mdot
.81238 .45315 Mdot
.81429 .36037 Mdot
.81619 .39764 Mdot
.8181 .2679 Mdot
.82 .29808 Mdot
.8219 .29017 Mdot
.82381 .342 Mdot
.82571 .24426 Mdot
.82762 .26167 Mdot
.82952 .31791 Mdot
.83143 .42195 Mdot
.83333 .24047 Mdot
.83524 .29926 Mdot
.83714 .38065 Mdot
.83905 .2446 Mdot
.84095 .25134 Mdot
.84286 .25341 Mdot
.84476 .30535 Mdot
.84667 .45688 Mdot
.84857 .38507 Mdot
.85048 .39124 Mdot
.85238 .40072 Mdot
.85429 .40009 Mdot
.85619 .28706 Mdot
.8581 .36568 Mdot
.86 .35379 Mdot
.8619 .30895 Mdot
.86381 .33638 Mdot
.86571 .48289 Mdot
.86762 .31235 Mdot
.86952 .26745 Mdot
.87143 .30727 Mdot
.87333 .41133 Mdot
.87524 .2701 Mdot
.87714 .40462 Mdot
.87905 .32391 Mdot
.88095 .37457 Mdot
.88286 .33063 Mdot
.88476 .33109 Mdot
.88667 .32807 Mdot
.88857 .27695 Mdot
.89048 .30236 Mdot
.89238 .30981 Mdot
.89429 .27829 Mdot
.89619 .3576 Mdot
.8981 .36274 Mdot
.9 .31194 Mdot
.9019 .39901 Mdot
.90381 .2548 Mdot
.90571 .29566 Mdot
.90762 .30639 Mdot
.90952 .35615 Mdot
.91143 .45794 Mdot
.91333 .34844 Mdot
.91524 .43638 Mdot
.91714 .24841 Mdot
.91905 .34247 Mdot
.92095 .25694 Mdot
.92286 .39917 Mdot
.92476 .35127 Mdot
.92667 .36261 Mdot
.92857 .25103 Mdot
.93048 .36596 Mdot
.93238 .36394 Mdot
.93429 .31334 Mdot
.93619 .38471 Mdot
.9381 .30453 Mdot
.94 .31394 Mdot
.9419 .33718 Mdot
.94381 .38543 Mdot
.94571 .34976 Mdot
.94762 .31599 Mdot
.94952 .28127 Mdot
.95143 .31116 Mdot
.95333 .29595 Mdot
.95524 .34971 Mdot
.95714 .35507 Mdot
.95905 .35241 Mdot
.96095 .32246 Mdot
.96286 .34337 Mdot
.96476 .32019 Mdot
.96667 .33351 Mdot
.96857 .43355 Mdot
.97048 .3946 Mdot
.97238 .34664 Mdot
.97429 .23402 Mdot
.97619 .39298 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oo
oooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`00
00Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolmooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0;Kooooo0_l00024ooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool0Eoooool2o`0005gooooo0_l0000Sooooo`;o0000Goooool000Kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1Fooooo`?o00004?ooool2o`0005Gooooo0_l0
000Iooooo`;o0000Goooool000Co00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo013ooooo0_l0
0014ooooo`;o00002oooool2o`0000Cooooo0_l0001Eooooo`;o0000N_ooool000Kooooo00Go0000
ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?oo
ool3o`0000kooooo1?l0000Aooooo`;o00001Oooool2o`0003Oooooo0_l00006ooooo`;o0000`Ooo
ool2o`0000cooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`09ooooo`;o0000
0oooool2o`0000Cooooo0_l0000=ooooo`?o00001?ooool2o`0000Cooooo0_l0000Kooooo`;o0000
7?ooool2o`000<7ooooo0_l0000<ooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo
0_l00009ooooo`;o00001Oooool2o`0000Oooooo0_l0000:ooooo`;o00005_ooool2o`0000?ooooo
0_l00018ooooo`;o00004?ooool2o`0001Wooooo0_l0000;ooooo`;o0000JOooool000Kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00[ooooo0_l0000?ooooo`;o0000:oooool2o`0000Oo
oooo0ol00008ooooo`;o00003?ooool2o`0002_ooooo0_l0000@ooooo`;o00006?ooool3o`0000_o
oooo0_l0000?ooooo`;o00000oooool2o`0001Sooooo0_l0000iooooo`001_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0
003oooooooooo`0:ooooo`;o00007?ooool2o`0001Cooooo0_l0000>ooooo`;o000000Coooooo`00
0?l0003o00002?ooool2o`0000cooooo0_l0000Wooooo`;o000000?oooooo`000?l000004_ooool2
o`0001Oooooo0_l00003ooooo`Co00005_ooool2o`0000?ooooo0_l00009ooooo`;o00002_ooool2
o`000004ooooool0003o0000o`0003Sooooo000Yooooo`;o00004_ooool2o`0001Gooooo0_l0000D
ooooo`;o00003_ooool2o`0002cooooo0_l0000Eooooo`;o000000?oooooo`000?l000002oooool2
o`0000Gooooo0_l0000?ooooo`;o00002oooool4o`0002Kooooo0_l0000:ooooo`;o00000_ooool2
o`0001Sooooo0_l0000Nooooo`00:Oooool00ol0003oooooooooo`0:ooooo`Co00000oooool2o`00
03;ooooo0_l0000eooooo`;o00002_ooool2o`0001Wooooo0_l0000Fooooo`;o0000:Oooool2o`00
00cooooo0_l0000=ooooo`;o00005oooool2o`000003ooooool0003o000001_ooooo000Yooooo`03
o`000?oooooooooo00[ooooo1?l0000gooooo`;o00005_ooool2o`0002Wooooo0_l0000@ooooo`;o
00005?ooool2o`0001?ooooo0ol00006ooooo`Co000000?oooooo`000?l000004Oooool2o`000003
ooooool0003o000000Cooooo0_l00003ooooo`;o00003Oooool3o`00017ooooo0_l00006ooooo`;o
00006oooool002Wooooo00?o0000ooooooooool0GOooool2o`0000kooooo0_l00003ooooo`Co0000
5oooool2o`0000_ooooo0_l00002ooooo`;o00002oooool2o`0000?ooooo0_l0000Cooooo`?o0000
1_ooool4o`000003ooooool0003o000001Cooooo0_l00004ooooo`;o00004oooool2o`00017ooooo
0_l00004ooooo`;o00007Oooool002Wooooo00?o0000ooooooooool0;oooool2o`0002Gooooo0_l0
000Eooooo`Co000000?oooooo`000?l000000_l0000Gooooo`;o00003oooool2o`0000Oooooo0_l0
0002ooooo`;o0000C?ooool2o`0000Cooooo0_l0000Looooo`;o00007Oooool002Wooooo0_l00000
0ooooooo0000o`00000]ooooo`;o00003?ooool2o`0001Oooooo0_l00006ooooo`;o00003oooool2
o`0000;ooooo0_l0000Sooooo`;o00003Oooool2o`00053ooooo0_l00004ooooo`;o0000>oooool0
02Wooooo00?o0000ooooooooool00_l0000;ooooo`;o0000;_ooool2o`0000Wooooo0_l0000Aoooo
o`;o000000?oooooo`000?l000006_ooool2o`0001cooooo0_l0000@ooooo`;o00007oooool2o`00
01Cooooo0_l0000Fooooo`;o000000?oooooo`000?l000003_ooool2o`0002kooooo000Yooooo`03
o`000?oooooooooo00gooooo0_l0000Qooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o
<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`;o00002_ooool2o`0000Gooooo
0_l0000@ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;o000000Koooooonk^k_lb
<S;o0000oc8b<_o^k^hHooooo`;o00003_ooool3o`000003oc8b<_o<c<cooooo00;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000o`000?o^k^h03?ooool2o`0000_ooooo
0_l00007ooooo`;o00001_ooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo1?l000000oo^k^ko0000o`00000>ooooo`Co00005Oooool01Om4A4Co0000o`000?lb
<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool002Wooooo00?o0000ooooooooool0:?ooool2o`0000Sooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0@oooo
o`;o00005oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00?oMgMgoiRHV?ooool00_l00003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06?ooool4o`0000cooooo00Co410@okZj^_ooooooMgMg
0_l00002ooooo`05ogMgMol0003o0000oiRHV?mgMgL00oooool01OmgMgOoV9RHo`000?l0003oMgMg
00Oooooo0_l00005ooooo`;o00002Oooool2o`00013ooooo00Co0000oooooooooooooooo0_l00000
1?nHV9SooooooiRHV?mgMgL3ooooo`;o000000?ooooooiRHV?mgMgL04_ooool2o`0001Sooooo00Wo
MgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo000Yooooo`04o`000?oooooo0000o`0002Oooooo1?l00006ooooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo0000o`000?l@4100
1oooool3o`0000;ooooo0_l0000Looooo`03oiRHV?lQ8B7ok^k^00Cooooo00?o410@ooooooooool0
0_l00003ooooo`05oa0@4?ooooooooooooooool@41006_ooool2o`00013ooooo0_l00002ooooo`05
oa0@4?l0003o0000ooooool@41000oooool01Ol@413o0000o`000?oooooo410@00Oooooo0_l00005
ooooo`;o00006?ooool5o`0000;ooooo0_l00003ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool00ol@413oooooooooo`0Dooooo`;o00005Oooool01?l0003oooooooooool@4103ooooo`05oa0@
4?ooooooooooooooool@41000oooool00ol@413oooooooooo`01ooooo`00:Oooool4o`0002Wooooo
0_l00006ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooo000000;o00001oooool3o`0000;ooooo0_l0000Mooooo`03oiRHV?lQ8B7ok^k^00?o
oooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooooooo`;o0000:_ooool0
0onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool3o`000003ooooool0
003ooooo02Oooooo00?oA4A4omgMgOooool01?l000000ooooooo0000ooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`0Dooooo`Co00004_ooool01OmgMgOo<S8b
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
007ooooo000Yooooo`?o0000<_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000002?ooooo0_l00007ooooo`03ogMgMomVIVKo
oooo00;ooooo00Co0000oooooooooooooooo0_l00002ooooo`04o`000?ooooooooooooooo`;o0000
:Oooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`02o`000003ooooool0003o000000Wooooo0_l000000ooooooo0000o`000002ooooo`;o
00004oooool00ooMgMgo0000o`000004o`000003ooooool0003ooooo00;ooooo00?o0000ooooool0
00000_l00003ooooo`03o`000?oooooooooo01Kooooo0_l0000?ooooo`?o000000Go<S8bolc<c?oo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`01
ooooo`00:Oooool00ol0003oooooooooo`0Oooooo`;o00004Oooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@01_ooooo0_l0
0006ooooo`;o00002?ooool01Ol0003ooooooooooooooooo410@00?ooooo0_l00002ooooo`;o0000
0_ooool00ol@413oooooooooo`0<ooooo`;o00006oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@
4?ooooooooooooooool@41000oooool00ol@413oooooooooo`02o`000003ooooool0003o000000Go
oooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0001Cooooo0ol00004ooooo`06
oa0@4?ooooooooooooooool@413ooooo0_l000001Ol@413ooooooooooooooooo410@02Wooooo0ol0
0004ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?o
oooo000Yooooo`03o`000?oooooooooo01oooooo0_l0000<ooooo`;o00000oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
01_ooooo0_l0000<ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo0ol000000onHV9SoMgMgooooo`0=ooooo`;o00005_ooool2o`000005oa0@4?nH
V9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`08ooooo`;o00005_ooool2o`0000Oooooo00?ok^k^odA4A?l000001?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`;o00006ooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo000Yooooo`03o`000?oooooooooo02gooooo0_l000001?ooooooEEEE
o`000?l00004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo0_l0000Qooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00Gok^k^o`000?l0003o0000onk^kP0Vooooo`;o000000GoZJVYoa0@4?l0
003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^023ooooo0_l00008ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`06onk^k_lb<S;o0000oc8b<_o^k^kooooo0_l00009ooooo`;o00006oooool4o`00
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool002Wooooo0_l0000^ooooo`;o00000_ooool2o`0000Oooooo0_l00009ooooo`;o00000oooool2
o`0000kooooo0_l0000:ooooo`?o00005_ooool2o`00043ooooo0_l0000>ooooo`;o00006oooool3
o`0000cooooo0_l0000Iooooo`;o00003Oooool2o`0001?ooooo000Yooooo`04o`000?oooooo0000
o`0001oooooo0_l0000Hooooo`;o00002Oooool2o`0000;ooooo0_l0000?ooooo`;o00002_ooool3
o`0004Cooooo0_l0000Booooo`;o00003_ooool2o`0001_ooooo0ol0000;ooooo`;o00000oooool2
o`0001Gooooo0_l0000=ooooo`;o00004oooool002Wooooo00Co0000ooooool0003o00007oooool2
o`000003ooooool0003o000002Cooooo0_l0000:ooooo`;o00005oooool2o`0000Oooooo0_l0000d
ooooo`;o00000oooool2o`00023ooooo0_l00003ooooo`;o00008Oooool2o`0000?ooooo0_l0000@
ooooo`;o00009oooool002Wooooo00Co0000oooooooooooooooo0_l00004ooooo`;o00006_ooool2
o`00033ooooo0_l00009ooooo`;o00003?ooool2o`0000Oooooo0_l0000Iooooo`;o00007_ooool2
o`00023ooooo0_l00003ooooo`;o00002_ooool2o`0001gooooo0_l0000=ooooo`;o00003Oooool2
o`0001Sooooo000Yooooo`04o`000?ooooooooooooooo`;o00001?ooool2o`0001Kooooo0_l0000o
ooooo`;o0000:_ooool2o`000004ooooool0003o0000ooooo`;o00002?ooool2o`0004Oooooo0_l0
000?ooooo`;o00003?ooool2o`0000Oooooo0_l00009ooooo`;o00002?ooool2o`0001Sooooo000Q
oooooooo0000A?l00004ooooo`00:Oooool00ol0003oooooooooo`03ooooo`;o00001?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_l00004oooo
o`;o000000?oooooo`000?ooool00_ooool2o`0000Kooooo00?o0000ooooooooool01Oooool2o`00
00?ooooo00?o0000ooooooooool02Oooool2o`0000[ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00;o00002?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05oooo
o`;o00000oooool01?l0003oooooooooooooool2o`0000Kooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo1?l00006ooooo`Co00002Oooool4
o`0000;ooooo0_l00006ooooo`03o`000?oooooooooo00[ooooo000Yooooo`03o`000?oooooooooo
02Gooooo0_l00004ooooo`;o00001Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool2o`00
00oooooo0_l0000Sooooo`03o`000?oooooooooo00Wooooo0_l0000Vooooo`;o00001oooool2o`00
01kooooo0_l00007ooooo`;o00004_ooool00ol0003oooooooooo`0:ooooo`;o00002oooool2o`00
00Sooooo0_l00009ooooo`Ko00002?ooool00ol0003oooooooooo`0:ooooo`00:Oooool00ol0003o
ooooooooo`0Looooo`;o00005Oooool2o`0003Cooooo0_l0000Hooooo`?o00009_ooool2o`0000Oo
oooo0_l0000Yooooo`;o00005_ooool2o`0000Gooooo0_l0000Tooooo`;o00001?ooool2o`0000oo
oooo000Yooooo`03o`000?oooooooooo01Cooooo0_l00006ooooo`;o00005Oooool2o`0003?ooooo
1Ol0000Fooooo`;o0000Doooool2o`0000Kooooo0_l00009ooooo`;o00002oooool2o`0001Gooooo
0_l0000Iooooo`?o00003oooool002Wooooo0_l00007ooooo`;o00003?ooool4o`0000gooooo0_l0
0011ooooo`;o000000?oooooo`000?l000003oooool2o`0000Wooooo0_l0000;ooooo`;o00005ooo
ool2o`0000oooooo0_l0000Hooooo`;o00004Oooool2o`0000Oooooo0_l0000Iooooo`;o00006Ooo
ool2o`00013ooooo000Yooooo`03o`000?oooooooooo00Gooooo0ol0000>ooooo`;o00003Oooool2
o`0000_ooooo0_l0000?ooooo`;o00003?ooool2o`00017ooooo0_l0000Fooooo`;o00002Oooool2
o`0000_ooooo0_l00002ooooo`;o00004oooool2o`0000kooooo0ol0000Cooooo`;o00007oooool4
o`0001[ooooo0_l0000Xooooo`00:Oooool2o`0000Kooooo0_l0000[ooooo`;o00001oooool2o`00
0003ooooool0003o000000?ooooo0_l0000<ooooo`;o00004Oooool2o`0001Oooooo0_l0000;oooo
o`;o00003?ooool2o`0000Wooooo0_l0000Aooooo`?o00001?ooool2o`0001Cooooo0_l0000Qoooo
o`;o00006?ooool4o`0001Oooooo0_l0000?ooooo`00:Oooool2o`0000Kooooo0_l00008ooooo`;o
00006?ooool2o`0000[ooooo0ol00003ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`00
027ooooo0_l0000Eooooo`;o00002_ooool3o`0001Kooooo0ol0000Aooooo`?o00001_ooool2o`00
00;ooooo0_l00007ooooo`;o0000??ooool2o`0000Cooooo0ol0000Hooooo`;o00003oooool002Wo
oooo00?o0000ooooooooool00_ooool2o`000003ooooool0003o000000Sooooo0_l0000Fooooo`Co
00002_ooool5o`0000Gooooo0_l00002ooooo`;o00008Oooool2o`00027ooooo0_l00009ooooo`;o
00003?ooool2o`0000[ooooo0_l0000?ooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo
0000o`00000looooo`;o00005oooool2o`0001Oooooo000Yooooo`;o00000oooool2o`0002;ooooo
0ol0000:ooooo`;o00000_ooool3o`0004oooooo1?l00007ooooo`;o00003?ooool2o`000003oooo
ool0003o000000Oooooo0_l0000Iooooo`;o0000<oooool2o`0001cooooo0_l00005ooooo`;o0000
5oooool002Wooooo00?o0000ooooooooool09_ooool2o`0000Sooooo0_l000000ooooooo0000o`00
001Fooooo`;o00005Oooool2o`000003ooooool0003o0000017ooooo1?l0000kooooo`;o00001Ooo
ool2o`0001cooooo0_l0000<ooooo`;o00004?ooool002Wooooo00?o0000ooooooooool0<?ooool2
o`00027ooooo0_l00003ooooo`;o00005_ooool2o`0002oooooo0_l0000Eooooo`Co00003?ooool2
o`00013ooooo0_l00003ooooo`;o00005_ooool2o`00027ooooo0_l0000>ooooo`;o000000?ooooo
o`000?l000003Oooool002Wooooo00?o0000ooooooooool01?ooool2o`0000?ooooo0_l0000>oooo
o`;o00004Oooool4o`0000_ooooo0_l00003ooooo`;o00001?ooool2o`0000Oooooo0_l00002oooo
o`;o00000oooool2o`0001Kooooo0_l00004ooooo`;o00007Oooool2o`0000[ooooo0_l0000Uoooo
o`?o00003?ooool2o`000003ooooool0003o000000?ooooo0_l0000iooooo`;o00000_ooool2o`00
00Gooooo0_l000000ooooooo0000o`000003ooooo`;o00003Oooool002Wooooo00?o0000oooooooo
ool01?ooool2o`0000;ooooo0ol0000>ooooo`;o00004Oooool4o`0000_ooooo0_l00003ooooo`;o
00000_ooool4o`0000Oooooo0_l0000Uooooo`;o00001oooool2o`0001Cooooo0_l0000^ooooo`;o
00000_ooool2o`0000_ooooo0ol0000`ooooo`;o00004oooool2o`0000Gooooo0_l000001?oooooo
0000o`000?l0000Aooooo`00:Oooool2o`0000Gooooo0_l00002ooooo`;o00000oooool2o`000003
ooooool0003o000003;ooooo0_l0000>ooooo`;o00000oooool2o`0001_ooooo0_l00007ooooo`;o
00001?ooool2o`0003kooooo0_l0000?ooooo`;o0000<Oooool2o`0000[ooooo0_l00002ooooo`;o
00003Oooool3o`00017ooooo000Yooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`;o0000
00?oooooo`000?l000009?ooool2o`0001cooooo0_l00003ooooo`;o00005_ooool2o`0000?ooooo
0_l0000=ooooo`;o0000:?ooool2o`0002?ooooo0_l0000Tooooo`;o00006Oooool2o`0000;ooooo
0_l0000Qooooo`00:Oooool00ol0003oooooooooo`0?ooooo`;o00002Oooool2o`0000Gooooo0ol0
000Aooooo`?o0000>Oooool2o`0000oooooo0_l0000[ooooo`;o00008oooool2o`0002Cooooo0_l0
000Iooooo`;o00002?ooool3o`0001[ooooo000Yooooo`03o`000?oooooooooo00oooooo0_l00000
0ooooooo0000o`000004ooooo`Co00001Oooool3o`00017ooooo0_l0001;ooooo`;o00005Oooool4
o`0000?ooooo0_l0001Wooooo`;o00002_ooool2o`0000Sooooo0ol0000Jooooo`00:Oooool00ol0
003oooooooooo`07ooooo`;o00002Oooool2o`0000Cooooo0_l0000Wooooo`;o0000D_ooool2o`00
00;ooooo1?l00003ooooo`;o00004oooool2o`0002Oooooo0_l0000Yooooo`;o00005Oooool2o`00
01[ooooo000Yooooo`;o00000oooool2o`0000?ooooo0_l00009ooooo`;o0000;Oooool2o`00047o
oooo0_l0000?ooooo`;o00001_ooool2o`000003ooooool0003o000001?ooooo0_l0000Uooooo`Co
0000G?ooool002Wooooo00?o0000ooooooooool00_ooool2o`0000kooooo0_l00003ooooo`?o0000
D_ooool2o`0001Kooooo0_l00007ooooo`;o00003_ooool2o`00037ooooo0_l00007ooooo`;o0000
00?oooooo`000?l00000<_ooool2o`0002[ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`0;ooooo`;o00002_ooool3o`0005;ooooo0_l0000Oooooo`;o00005Oooool2o`0002[o
oooo0_l00007ooooo`;o0000=Oooool2o`0002[ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool02oooool2o`0001Gooooo0_l0000Zooooo`;o00003?ooool2o`00
00Cooooo0_l00010ooooo`;o00009oooool2o`0003?ooooo0_l0000hooooo`001_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01gooooo0ol00002ooooo`;o0000:_ooool2o`0000cooooo0_l00004oooo
o`;o0000;Oooool2o`0001?ooooo0_l0000Uooooo`;o0000<oooool2o`000003ooooool0003o0000
01_ooooo1?l0000Fooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q
8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o00005Oooool2o`0000Kooooo0ol0000Voooo
o`;o00004oooool2o`0000Kooooo0_l0000:ooooo`;o00008?ooool2o`0001?ooooo0_l0001Moooo
o`;o00006oooool4o`0001Kooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omg
MgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool2o`0001Kooooo0_l0000@
ooooo`;o00005oooool2o`0000Cooooo0_l0000Cooooo`;o00000_ooool2o`0000;ooooo0_l0000:
ooooo`;o00004?ooool2o`0008?ooooo0_l0000dooooo`001_ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo02Oooooo0_l0000Gooooo`;o00001oooool4o`0001;ooooo0_l0000Pooooo`;o00003?ooool2
o`0005;ooooo0ol00007ooooo`;o000000?oooooo`000?l000005?ooool2o`0002Gooooo1?l0000;
ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@
4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>_ooool2o`0000gooooo1?l0
000Hooooo`;o00005?ooool2o`0001;ooooo0_l0000Wooooo`;o0000:Oooool3o`0000Oooooo0_l0
00000ooooooo0000o`000009ooooo`;o00006_ooool2o`0001Cooooo1?l0000;ooooo`001_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co0000
1_ooool00ol0003oooooooooo`0Gooooo`;o00008Oooool4o`0000oooooo0_l0000Booooo`;o0000
0_ooool2o`0001Cooooo0_l0000=ooooo`;o00001?ooool2o`0002Kooooo0_l0000Qooooo`;o0000
1?ooool2o`0001Sooooo0_l0000:ooooo`;o00003_ooool2o`0000Cooooo0_l0000Mooooo`00:Ooo
ool2o`0001Sooooo0_l0000Sooooo`;o00003oooool2o`0001;ooooo0_l0000Wooooo`;o00001?oo
ool2o`0001Wooooo0_l0000^ooooo`;o00001?ooool2o`0000Kooooo0_l0000Looooo`;o00001_oo
ool2o`0000cooooo0_l0000Mooooo`00:Oooool00ol0003oooooooooo`0Jooooo`;o0000@_ooool2
o`0003;ooooo0_l0000Dooooo`;o000000?oooooo`000?l00000>_ooool4o`0002Cooooo0_l0000[
ooooo`00:Oooool00ol0003oooooooooo`0Cooooo`;o00001Oooool2o`0004;ooooo0_l0000<oooo
o`;o00001_ooool2o`0001cooooo0_l0000Dooooo`;o00001_ooool2o`0003Gooooo0_l0000Toooo
o`;o0000;Oooool002Wooooo00?o0000ooooooooool04oooool2o`0000Oooooo0_l0000Oooooo`;o
0000;Oooool2o`0000Kooooo0_l0000Aooooo`;o00005_ooool2o`0000oooooo0_l00008ooooo`;o
00001Oooool2o`00023ooooo0_l0000Xooooo`;o0000;Oooool002Wooooo00?o0000ooooooooool0
7?ooool2o`00013ooooo0_l0000=ooooo`;o00004Oooool2o`0001;ooooo0_l0000Jooooo`;o0000
1?ooool3o`0001Kooooo0_l0000Iooooo`;o00001Oooool2o`0001Wooooo0_l00005ooooo`;o0000
3?ooool3o`0004Sooooo000Yooooo`;o0000;oooool2o`0000Sooooo0_l0000=ooooo`;o00001ooo
ool2o`0001;ooooo0_l0000Jooooo`;o00001?ooool2o`0005Cooooo0_l0000Cooooo`?o0000B?oo
ool002Wooooo00?o0000ooooooooool0>?ooool2o`0000gooooo0_l0002Sooooo`;o00000oooool2
o`0000gooooo0_l0000jooooo`00:Oooool00ol0003oooooooooo`0<ooooo`;o00009_ooool2o`00
02?ooooo0_l00012ooooo`;o00006_ooool2o`0002Wooooo0_l00006ooooo`;o00004_ooool2o`00
03[ooooo000Yooooo`03o`000?oooooooooo00cooooo0_l0000Vooooo`;o00008oooool2o`0004;o
oooo0_l0000Jooooo`;o0000:Oooool2o`0005Kooooo000Yooooo`03o`000?oooooooooo07Oooooo
0_l0000Eooooo`;o00008_ooool2o`0008Sooooo000Yooooo`;o00008Oooool2o`0005Gooooo0_l0
000<ooooo`;o00001oooool2o`00027ooooo1Ol0000`ooooo`;o0000A?ooool2o`0000kooooo000Y
ooooo`03o`000?oooooooooo023ooooo0_l0001Sooooo`;o0000:_ooool5o`0000Sooooo0_l0000F
ooooo`;o00003_ooool2o`0003?ooooo0_l0000?ooooo`;o00003_ooool002Wooooo00?o0000oooo
ooooool05Oooool2o`0005_ooooo0_l0000Hooooo`;o0000<?ooool2o`0001Kooooo0_l00013oooo
o`;o00007oooool002Wooooo00?o0000ooooooooool05Oooool2o`0005[ooooo0ol0000Hooooo`;o
0000[_ooool002Wooooo00?o0000ooooooooool0K_ooool2o`000003ooooool0003o000000Oooooo
0_l00030ooooo`00:Oooool2o`0006;ooooo0_l0000;ooooo`;o00002_ooool2o`0000Kooooo0_l0
001Iooooo`;o0000GOooool002Wooooo00?o0000ooooooooool0HOooool2o`0001oooooo0_l0001I
ooooo`;o00006oooool2o`00043ooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo09Oooooo0_l0
000Yooooo`;o00009oooool2o`0000gooooo0_l00009ooooo`;o00004oooool2o`00023ooooo000>
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`1eooooo`;o00008?ooool2o`0002Wooooo0_l0000Wooooo`;o00006?oo
ool2o`0001?ooooo0_l0000Pooooo`003_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o
0000ooooooooool00oooool3o`0007Gooooo0_l00035ooooo`003_ooool01Ol0003ooooooooooooo
oooo000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo000>
ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool0oooooolmooooo`003_ooool01Ol@413ooooooooooooooooo410@00cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo
?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`0003[ooooo
0_l0002hooooo`;o0000Aoooool002Wooooo00?o0000ooooooooool07Oooool2o`0000cooooo0_l0
000<ooooo`;o0000U?ooool2o`0002;ooooo0_l0000Fooooo`;o0000;oooool002Wooooo00?o0000
ooooooooool07Oooool2o`0000cooooo0_l0002Rooooo`;o0000>_ooool2o`0002oooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEoooo
o`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`000?oooooo
ooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o
EEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool0
0oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`007oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`007oooool00omEEEGoIVIVo`00003oooooodOooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-67.7937, -1.114, 2.04097, \
0.0125804}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "\tThe phase mixing should be quite clear in this animation. After a few \
bounces, the gas  approaches  equilibrium. The evolution toward equilibrium \
can be seen more directly by evaluating the particle density ",
  Cell[BoxData[
      \(TraditionalForm\`n(x, t)\)]],
  ". It is the integral over the momenta of ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  ": "
}], "Text",
  CellTags->"i:12"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`n(x, 
          t)\  = \ \[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( f(x, p, 
              t)\) \[DifferentialD]p\)]],
  "."
}], "NumberedEquation",
  CellTags->"(7.1.28)"],

Cell[TextData[{
  "\tWe can use the data  generated above to approximately determine ",
  Cell[BoxData[
      \(TraditionalForm\`n(x, t)\)]],
  " for this evolution. The number of particles in the range ",
  Cell[BoxData[
      \(TraditionalForm\`x - \ x + \[DifferentialD]x\)]],
  " equals ",
  Cell[BoxData[
      \(TraditionalForm\`\(n(x, t)\)\ \[DifferentialD]x\)]],
  ". Therefore, we can determine ",
  Cell[BoxData[
      \(TraditionalForm\`n(x, t)\)]],
  " by counting particles that fall in small boxes of size ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]x\)]],
  ". If, at time ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ", the number of particles in the range ",
  Cell[BoxData[
      FormBox[
        RowBox[{"x", "-", " ", "x", "+", 
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]]}], TraditionalForm]]],
  " equals ",
  Cell[BoxData[
      \(TraditionalForm\`H(x, t)\)]],
  ", then "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`n(x, t) = \(H(x, t)\)/\[CapitalDelta]x\)]],
  ". "
}], "UNNEQ"],

Cell[TextData[{
  "This binning can be accomplished using the ",
  StyleBox["Histogram",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " plotting function, available in the graphics add-on  packages:"
}], "Text",
  CellTags->"i:13"],

Cell[BoxData[
    \(<< Graphics`\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.20"],

Cell[TextData[{
  StyleBox["Histogram",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " takes as its primary argument a list of data values that it bins into \
given categories. The ",
  StyleBox["HistogramCategories",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option is used to determined location and size of the bins. Here the bins \
are all of size 0.1, and run from -1 to 1.  We use the ",
  StyleBox["Show ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function in order to actually display the histograms, because this allows \
us more flexibility in choosing the plot range and the axis origin (see Cell \
",
  ButtonBox["7.21",
    ButtonData:>"Cell 7.21",
    ButtonStyle->"Hyperlink"],
  ")."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(H[
          t_] := \ \((plt\  = \ 
            Histogram[pos[t], 
              HistogramCategories \[Rule] Table[x, {x, \(-1\), 1,  .1}], 
              DisplayFunction \[Rule] Identity]; 
          Show[plt, PlotRange \[Rule] {{\(-1\), 1}, {0, 300}}, 
            DisplayFunction \[Rule] $DisplayFunction, 
            AxesLabel \[Rule] {"\<x\>", "\<H[x,t]\>"}, 
            AxesOrigin \[Rule] {0, 0}])\);\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(hist\  = \ Table[H[t], {t, 0, 50,  .4}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.21"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.55 -0.0125 -9 -9 ]
[.55 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.65 -0.0125 -9 -9 ]
[.65 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.55 0 m
.55 .00625 L
s
[(0.1)] .55 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.65 0 m
.65 .00625 L
s
[(0.3)] .65 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(0.5)] .75 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 0 m
.5 .22867 L
.55 .22867 L
.55 0 L
F
0 g
.5 Mabswid
.5 0 m
.5 .22867 L
.55 .22867 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .19571 L
.6 .19571 L
.6 0 L
F
0 g
.55 0 m
.55 .19571 L
.6 .19571 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .19983 L
.65 .19983 L
.65 0 L
F
0 g
.6 0 m
.6 .19983 L
.65 .19983 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .20807 L
.7 .20807 L
.7 0 L
F
0 g
.65 0 m
.65 .20807 L
.7 .20807 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .19777 L
.75 .19777 L
.75 0 L
F
0 g
.7 0 m
.7 .19777 L
.75 .19777 L
.75 0 L
.7 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00?oooooo3oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPGooooo
0_lQ8B44ooooo`Go00000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46
ooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Go
oooo00GoA4A4o`000?l0003o<S8bomgMg@2Kooooo`00ooooool?ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S800_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`2Jooooo`00ooooool?oooo
o`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP03ooooo`05oa0@4?ooooooooooooooool@4100
3oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00Wooooo1Ol00003ooooo`05
oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`2Iooooo`00ooooool?ooooo`05
o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000003Oooool00onHV9So8B4Qonk^kP02ooooo`05o`000?ooooooooooooooool000003_oo
ool01OnYZJWo410@oooooooooooo000000?ooooo00?o0000ooooooooool02Oooool01?m4A4CogMgM
ooooool00004ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`2Joooo
o`00ooooool?ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000003_ooool01OmgMgOoIVIVoooooooooooo000000?ooooo00?o
0000ooooooooool02oooool00ol@413o0000okZj^P02ooooo`05o`000?ooooooooooooooool00000
2oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<09_ooooo003oooooo`oooooo00Go410@oooooooooooooooooa0@400>
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400?ooooo`04o`000?oo
oooooooooa0@40?ooooo00?o410@ooooooooool03?ooool01Onj^[[o8B4Qoooooooooooo410@00?o
oooo00?o410@ooooooooool02_ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00ol0003oooooooooo`2Mooooo`00ooooool?ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol0003o^[ZjoooooonHV9So410@00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?nHV9SooooookZj^_l000000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4
A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool0WOooool0
0?oooooo3oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c002ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`Co0000W?ooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooo
oooo7oooool00?oooooooooooolOooooo`00ooooooolooooo`;o00000_ooool2o`0001cooooo003o
oooooocooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMdLooooo`00ooooooomooooo`04omgMgOl0
003o410@olc<c1gooooo000Goooooooo0000eol0000?ooooo`04onk^k_lQ8B7o410@onk^kQgooooo
003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo08;ooooo00Co8B4QogMgMomgMgOo<S8b7Oooool00?oooooo0oooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0POooool2o`0000;ooooo0_l0
000Looooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`2Sooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00ooooool3ooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00ooooool3ooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00oooo
ool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`2Sooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00ooooool3ooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00ooooool3ooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00oooo
ool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`2Sooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00ooooool3ooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00ooooool3ooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00oooo
ool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`2Sooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00ooooool3ooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00ooooool3ooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00oooo
ool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`2Sooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00ooooool3ooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00ooooool3ooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00oooo
ool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`2Sooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00ooooool3ooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00ooooool3ooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00oooo
ool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`2Sooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00ooooool3ooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00ooooool3ooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00oooo
ool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`2Sooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00ooooool3ooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00ooooool3ooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00oooo
ool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`2Sooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00ooooool3ooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00k_ooool01Om4A4Co0000
o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00lOooool02OmgMgOo
<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00l_ooool01?l0003oooooooooool@
4103ooooo`03oa0@4?oooooooooo00Kooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0:?ooooo003aooooo`05ogMgMolb<S;oooooooooool000000ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`2Sooooo`00k_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go
0000ooooooooooooooooo`000008ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00k_ooool00ol0003oooooooooo`04ooooo`05oa0@4?oo
ooooooooooooool@41002?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0Xoooool00>kooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Sooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0:?ooooo003^ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0:?ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003oooooo`?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003oooooo`?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0:?ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003oooooo`?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003oooooo`?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0:?ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003oooooo`?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003oooooo`?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0:?ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003oooooo`?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003oooooo`?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0:?ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003oooooo`?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003oooooo`?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0:?ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003oooooo`?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003oooooo`?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0:?ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003oooooo`?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003oooooo`?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0:?ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003oooooo`?ooooo00?o0000ool00?oo
00005?oo000Io`0001Koo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0:?ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo000Io`000:Gooooo
003Vooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP08ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05OoooolH
o`0001Koo`0000?o0000ooooooooool0^oooool00>Sooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0;?ooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0;_ooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo02cooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00j?oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000Sooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0/ooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00>Sooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008oooo
o`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0;?oooolHo`000;gooooo003Xooooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooo
ooooool@41002?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool0
0>Sooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0oooo
ool2ooooo`00i_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3o
ooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3ooooo
o`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;o
oooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo
003oooooo`?ooooo6?l0003oooooo`Cooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o
0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00i_oo
ool4o`000005oa0@4?oooooooooooooooom4A4@00_l000002Olb<S;ogMgMooooooooooook^k^oc8b
<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000oooo
ooooool01_ooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01oooool01?l0003ooooooooo
ool@4103ooooo`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?oo
ool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003ooooo
ooooo`06ooooo`Co0000oooooolHooooo`00j?ooool00ol0003oooooooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooooooo
ool0oooooolIooooo`00j?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oeEEEOmVIVKo000000Gooooo
1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOooool5o`0000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo
410@00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`Co0000oooooolHooooo`00ioooool0
0onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000So
oooo00?o0000ooooooooool0oooooolIooooo`00jOooool01Ol0003ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Kooooo00?o0000oooo
ooooool0oooooolIooooo`00iOooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003ooooooooo
o`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[o
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Gooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So
8B4Qonk^k_ooooooA4A400Oooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oiRHV?lQ8B7ok^k^00Wooooo00Co
0000oooooooooooo410@0oooool00ol@413oooooooooo`06ooooo`Co0000oooooolHooooo`00iooo
ool00onHV9So8B4Qonk^kP07ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?oMgMgofIVI_ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`000008ooooo`03
o`000?oooooooooo0?oooooo6Oooool00>Wooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWo
oooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`04ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o<S8bolc<c003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo
00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0
003oooooooooo`3ooooooaWooooo003Yooooo`05o`000?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3o
oooooaWooooo003Xooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000002?ooool4o`000?oooooo6?ooool00>Oooooo00?o410@
o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`00003oooooobCooooo003Xooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooo
oa0@4003ooooo`05oa0@4?ooooooooooooooool@4100oooooolTooooo`00iOooool01Ol@413oV9RH
oooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0oooooolTooooo`00iOooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0oooooolTooooo`00oooo
oooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoo
oooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooo
oooooooo7oooool00?oooooooooooolOooooo`00moooool2o`0000_ooooo00?o0000okZj^_ooool0
3?ooool2o`000?oooooo2Oooool00?Oooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o
0000ooooooooool0ooooool7ooooo`00joooool01?l@413o0000o`000?ooool2o`000003oa0@4?oo
oooooooo00?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000oooool00on7QhOo0000
okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X01?ooool00ol0003oooooooooo`3oooooo`Oo
oooo003/ooooo`05o`000?ooooooooooooooool000001_ooool02_l0003oooooooooooooooook^k^
ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^ko
MgMgoa0@4004ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo00;ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo1Ol00006oooo
o`03o`000?oooooooooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006
ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000Sooooo00?o410@o`000?l000000ol0
0005ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00ooo
ool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`000?oooooo2Oooool00?oooooooooooolO
ooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00001\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.45 0 m
.45 .03296 L
.5 .03296 L
.5 0 L
F
0 g
.5 Mabswid
.45 0 m
.45 .03296 L
.5 .03296 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .13391 L
.55 .13391 L
.55 0 L
F
0 g
.5 0 m
.5 .13391 L
.55 .13391 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .23073 L
.6 .23073 L
.6 0 L
F
0 g
.55 0 m
.55 .23073 L
.6 .23073 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .18747 L
.65 .18747 L
.65 0 L
F
0 g
.6 0 m
.6 .18747 L
.65 .18747 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .21219 L
.7 .21219 L
.7 0 L
F
0 g
.65 0 m
.65 .21219 L
.7 .21219 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .17717 L
.75 .17717 L
.75 0 L
F
0 g
.7 0 m
.7 .17717 L
.75 .17717 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .0515 L
.8 .0515 L
.8 0 L
F
0 g
.75 0 m
.75 .0515 L
.8 .0515 L
.8 0 L
.75 0 L
s
1 0 0 r
.8 0 m
.8 .00412 L
.85 .00412 L
.85 0 L
F
0 g
.8 0 m
.8 .00412 L
.85 .00412 L
.85 0 L
.8 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00?oooooo9oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00006Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46
ooooo`;o000000?o410@ooooooooool06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0QOooool00?oooooo9oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo01Wooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q08Gooooo003o
ooooobOooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^01[ooooo00Go
410@oooooooooooooooooa0@400;ooooo`Go00006_ooool01Ol@413ooooooooooooooooo410@00_o
oooo00Go0000ooooooooooooooooo`000025ooooo`00oooooolWooooo`05o`000?oooooooooooooo
ool000003Oooool00onHV9So8B4Qonk^kP0Iooooo`05o`000?ooooooooooooooool000002oooool0
1?m4A4CogMgMooooool0000Kooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RH
oooooonHV9So8B4Q08Gooooo003oooooobOooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
QOooool00?oooooo9oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
5oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000006oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0Qoooool00?oooooo9oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@400Iooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00000Kooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool00ooMgMgo410@oiRHV027ooooo`00oooooolWooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=oooo
o`03ogMgMol0003ooooo01[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co
0000oa0@48Gooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoo
oooo003ooooooooooooo7oooool00?ooooooo?ooool2o`0000;ooooo0_l0000Looooo`00oooooool
ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM7?ooool00?oooooooOooool01?oMgMgo0000oa0@
4?o<c<`Mooooo`005oooooooo`000=Oo00003oooool01?o^k^ko8B4Qoa0@4?o^k^hMooooo`00j_oo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Dooo
ool01?lQ8B7oMgMgogMgMolb<S8Mooooo`00j_ooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool001Wo0000E?oo
ool2o`0000;ooooo0_l0000Looooo`00j_ooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo08cooooo003Zooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0S?ooool00>[o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2<ooooo`00j_ooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo08cooooo003Zooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0S?ooool00>[ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2<
ooooo`00j_ooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo003Zooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0S?ooool00>[ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`2<ooooo`00j_ooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo08cooooo003Zooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0S?ooool0
0>[ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2<ooooo`00j_oooolIo`0001Ko
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08co
oooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0S?ooool00?oooooo0oooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`2<ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo003oooooo`?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0S?ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2<ooooo`00ooooool3ooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo08cooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0S?ooool00?oooooo0oooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`2<ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo000Ho`0008kooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0:?ooooo003oooooo`?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003oooooo`?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003o
ooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0:?ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0:?ooooo003oooooo`?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003oooooo`?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003o
ooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0:?ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0:?ooooo003oooooo`?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003oooooo`?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003o
ooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0:?ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0:?ooooo003oooooo`?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003oooooo`?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003o
ooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0:?ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0:?ooooo003^ooooo`05odA4A?l0003o0000oc8b<_oM
gMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003aooooo`09ogMgMolb<S;ooooooooo
oomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0:?ooooo003booooo`04o`000?oooooooooooa0@40?ooooo00?o
410@ooooooooool01_ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00?7ooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0:?ooooo003^ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooo
oooooooo000000Sooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0:?ooooo003^ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooo
oa0@4008ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00k_ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
Xoooool00>kooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00?oooooo0ooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xooo
ool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0Xoooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00?oooooo0oooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00?oooooo0ooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xooo
ool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0Xoooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00?oooooo0ooooolHo`0001Ooo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0Xoooool00?oooooo0oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00?oooooo0oooool00ol0003oooooooooo`0D
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00?oooooo0oooool00ol0
003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00?oo
oooo0oooool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0Xoooool00?oooooo0oooool2o`0001Gooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00ooooool3ooooo`03o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`2Sooooo`00ooooool3ooooo`03o`000?oooooooooo01Cooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00ooooool3ooooo`03o`000?oooooooooo
01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00ooooool3ooooo`03
o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00
ooooool3ooooo`03o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00ooooool3ooooo`03o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`2Sooooo`00ooooool3ooooo`03o`000?oooooooooo01Cooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00ooooool3ooooo`03o`000?oooooooooo
01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00ooooool3ooooo`;o
00005Oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003oooooo`?ooooo
00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
003oooooo`?ooooo00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0:?ooooo003oooooo`?ooooo00?o0000ooooooooool05?ooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo003oooooo`?ooooo00?o0000ooooooooool05?ooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003oooooo`?ooooo00?o0000oooooooo
ool05?ooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003oooooo`?ooooo
00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo000Io`000:Gooooo003oooooo`?ooooo00?o0000ooooooooool05?oo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2kooooo`00ooooool3ooooo`03o`000?oooooooooo01Cooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0^oooool00?oooooo0oooool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0;_ooooo003oooooo`?ooooo0_l0000Eooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003oooooo`?ooooo
00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool001So00005_oo00000ol0003ooooo
ooooo`2kooooo`00ooooool3ooooo`03o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^ooo
ool00?oooooo0oooool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000
ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003ooooo
o`?ooooo00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo
01Cooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00ooooool3ooooo`03
o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00?oooooo0oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo0;_ooooo003Vooooo`Co000000So410@ooooooooooook^k^
oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0^oooool00>Sooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0^oooool00>Sooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00>Sooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`Co
00004oooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2kooooo`00j?ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooo
ooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`2kooooo`00j?ooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000
ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo6?l0002m
ooooo`00j?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool05?ooool00ol0003oo`00ool0
000Eool00003o`000?oooooooooo0>Wooooo003Vooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00?oooooo0ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOoo
ool00?oooooo0oooool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0jOooool00?oooooo0oooool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0jOooool00?oooooo0oooool00ol0003oooooooooo`0Dooooo`03
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00?oooooo0oooool2o`0001Gooooo
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3
ooooo`03o`000?oooooooooo01Cooooo6Ol0003[ooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00i_ooool4o`000005oa0@4?oooooooooooooooom4A4@0
0_l000002Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool02OmgMgOo<S8boooooooooooo
MgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o
0000ooooooooool01oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00Kooooo
00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`06ooooo`05ogMgMolb
<S;oooooooooool000000oooool00ol0003oooooooooo`06ooooo`Co0000oooooolHooooo`00j?oo
ool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooo
oooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@4008ooooo`03
o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWo
oooo003Vooooo`03oeEEEOmVIVKo000000Gooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo
6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00iOooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q
8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
4008ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
oooooolIooooo`00j?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00
jOooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003oooo
o`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o
^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo1Ol00004ooooo`05odA4
A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00iOooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00WoMgMgoc8b
<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo
003Vooooo`03oiRHV?lQ8B7ok^k^00Wooooo00Co0000oooooooooooo410@0oooool00ol@413ooooo
ooooo`06ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP07ooooo`05ogMgMolb
<S;oooooooooool000000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Sooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo
00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@
41001?ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0
003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`00
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0>Gooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOoo
ool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`05
o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@
ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ojVYZOl@413ooooo
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?oo
ool4o`000?oooooo6?ooool00>Oooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`00003oooooobCooooo003Xooooo`03okZj^_lQ
8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
4100oooooolTooooo`00iOooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0oooooolTooooo`00iOooool01OnY
ZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h0oooooolTooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool0
0?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooo
oolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00
moooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`000?oooooo2Oooool00?Oooooo00?o
0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool0ooooool7ooooo`00joooool0
1?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo00Co0000oooooooooooooooo
0_l00002ooooo`;o00000oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj
^[X01?ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool0
00001_ooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<
c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo0?oo
oooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;o
oooo00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo0?oooooo1oooool00>cooooo1Ol00006ooooo`03o`000?oooooooooo00;ooooo00Co8B4QogMg
MomgMgOo<S8b2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool0
0>cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooooooo`;o00000_oo
ool2o`0000Sooooo00?o410@o`000?l000000ol00005ooooo`03o`000?oooooooooo0?oooooo1ooo
ool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o
0000ooooo`;o000000?o410@ooooooooool00oooool2o`0001;ooooo00?o0000ooooooooool01Ooo
ool2o`000?oooooo2Oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooo
oooo7oooool00001\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.4 0 m
.4 .10507 L
.45 .10507 L
.45 0 L
F
0 g
.5 Mabswid
.4 0 m
.4 .10507 L
.45 .10507 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .16275 L
.5 .16275 L
.5 0 L
F
0 g
.45 0 m
.45 .16275 L
.5 .16275 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .20807 L
.55 .20807 L
.55 0 L
F
0 g
.5 0 m
.5 .20807 L
.55 .20807 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .21425 L
.6 .21425 L
.6 0 L
F
0 g
.55 0 m
.55 .21425 L
.6 .21425 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .16893 L
.65 .16893 L
.65 0 L
F
0 g
.6 0 m
.6 .16893 L
.65 .16893 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .10301 L
.7 .10301 L
.7 0 L
F
0 g
.65 0 m
.65 .10301 L
.7 .10301 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .04738 L
.75 .04738 L
.75 0 L
F
0 g
.7 0 m
.7 .04738 L
.75 .04738 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .0206 L
.8 .0206 L
.8 0 L
F
0 g
.75 0 m
.75 .0206 L
.8 .0206 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo06_ooooo00Co8B4QogMgMomgMgOo<S8b7Oooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo06[ooooo
0_l00002ooooo`;o00007?ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`2<ooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0S?ooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2<ooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0S?oo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo08cooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`006?l0002>ooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xooo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`006Ol0002Uooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2koooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2k
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2koooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`006?l0002mooooo`00dooooolH
o`0001Ooo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0d_ooool00>[ooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3Booooo`00j_ooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;o
oooo003Zooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00>[ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00j_ooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0=;ooooo003Zooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0d_ooool00>[ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00
j_ooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Zooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0d_ooool00>[ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`3Booooo`00j_ooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0=;ooooo003Zooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00>[ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00j_ooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0=;ooooo003Zooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0d_ooool00>[ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Boooo
o`00j_ooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Zooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00>[ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3Booooo`00j_ooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0=;ooooo003Zooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00>[o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00j_ooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0=;ooooo003Zooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0d_ooool00>[ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3B
ooooo`00j_ooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003ZoooooaWo
00005_oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0d_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00ooooool3ooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0=;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool001So0000e?ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0jOooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00?oooooo0oooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00?oooooo0ooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOoo
ool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0jOooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0jOooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00?oooooo0oooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00?oooooo0ooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOoo
ool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0jOooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0jOooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00?oooooo0oooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00?oooooo0ooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOoo
ool00>Kooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0>Wooooo003Xooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00>Sooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
4008ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`3Yooooo`00j?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0>Wooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?oooolHo`0001Oo
o`0000?o0000ooooooooool0jOooool00>Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo
01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00j?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Sooooo00?o0000ooooooooool05?oooolIo`000>_ooooo003Vooooo`03oeEEEOmVIVKo0000
00Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?oo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`Co000000Go410@ooooooooooooooooodA4
A002o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`06ooooo`09ogMgMolb<S;ooooooooo
oomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool0
0ol0003oooooooooo`07ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool01_oo
ool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00Kooooo00GoMgMg
oc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo1?l0003ooooooaSooooo003X
ooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00Sooooo
00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Kooooo00?oEEEEofIVI_l000001Oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooo
oolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003Uooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go
V9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00onHV9So
8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo
410@00Sooooo1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooooooo
o`3ooooooaWooooo003Xooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo
003Yooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?o
oooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05o`00
0?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOooool5o`0000Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool02OmgMgOo
<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Kooooo00?oV9RHob4Q8Oo^k^h02Oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oo
oooooooo00Kooooo1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^00Oooooo00GoMgMg
oc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooo
oolIooooo`00j?ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_oo
ool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00jOoo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooo
oa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go0000okZj^_ooooooV9RH
oa0@4004ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03
o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00iOooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003U
ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo
00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@
413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?oZJVYoa0@4?oo
ool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008
ooooo`Co0000oooooolHooooo`00ioooool00ol@413o0000okZj^P03ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo00000?oooooo9?ooool00>Sooooo00?o^[Zj
ob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooo
oa0@403oooooobCooooo003Uooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`3oooooobCooooo003Uooooo`05
ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP3oooooobCooooo003ooooooooooooo7oooool00?oooooooooooolOoooo
o`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooo
oooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo
003gooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o0000ooooool9ooooo`00moooool0
0ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`3oooooo`Oooooo003[oooo
o`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool01?l0003ooooooooooooo
ool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4
okZj^P04ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000oooooooooooooooo
o`000006ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo00?o
c<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000ooooooooool0
ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
0_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0ooooool7ooooo`00k?ooool5o`0000Kooooo00?o0000ooooooooool00_ooool01?lQ8B7o
MgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7oooo
o`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooooooo0_l00002
ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool0ooooool7
ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>_ooooo00Co410@o`00
0?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`;o00004_ooool00ol0003oooooooooo`05
ooooo`;o0000ooooool9ooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooo
oooooolOooooo`00\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.35 -0.0125 -12 -9 ]
[.35 -0.0125 12 0 ]
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.45 -0.0125 -12 -9 ]
[.45 -0.0125 12 0 ]
[.5 -0.0125 -39.75 -12.5 ]
[.5 -0.0125 39.75 0 ]
[.55 -0.0125 -9 -9 ]
[.55 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.65 -0.0125 -9 -9 ]
[.65 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.35 0 m
.35 .00625 L
s
[(-0.3)] .35 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.45 0 m
.45 .00625 L
s
[(-0.1)] .45 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -39.75 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2.77556) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-17) show
grestore
.55 0 m
.55 .00625 L
s
[(0.1)] .55 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.65 0 m
.65 .00625 L
s
[(0.3)] .65 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .10713 L
.4 .10713 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .10713 L
.4 .10713 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .46971 L
.45 .46971 L
.45 0 L
F
0 g
.4 0 m
.4 .46971 L
.45 .46971 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .22249 L
.5 .22249 L
.5 0 L
F
0 g
.45 0 m
.45 .22249 L
.5 .22249 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .11949 L
.55 .11949 L
.55 0 L
F
0 g
.5 0 m
.5 .11949 L
.55 .11949 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .0618 L
.6 .0618 L
.6 0 L
F
0 g
.55 0 m
.55 .0618 L
.6 .0618 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .03708 L
.65 .03708 L
.65 0 L
F
0 g
.6 0 m
.6 .03708 L
.65 .03708 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .01236 L
.7 .01236 L
.7 0 L
F
0 g
.65 0 m
.65 .01236 L
.7 .01236 L
.7 0 L
.65 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00?oooooo4Oooool2onk^kP?ooooo0_o^k^koooooo`Oo
oooo003Iooooo`Go00001Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01Oooool00ol0003ok^k^
ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd00oooool01Om4A4Co0000o`000?lb<S;ogMgM
00;ooooo00Gok^k^oc8b<_l0003o410@olc<c002ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEE
onk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^k_Oooooo003Ioooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01Oooool0
0omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Gooooo00WoMgMgoc8b<_oooooooooooeEE
EOmgMgOooooooiRHV?lQ8B400oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg0?Oooooo003Aooooo`Ko00000oooool00onH
V9So8B4Qonk^kP0>ooooo`03ojVYZOmEEEGooooo00Gooooo00?oZJVYoeEEEOooool02?ooool00ol0
003oooooooooo`05ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool0
0ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
403gooooo`00]Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05oiRHV?l@
413o0000oc8b<_o<c<`00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B43ooooo`03
oiRHV?l0003o000000?o00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Co8B4Qoooo
oolQ8B7o8B4Q1?ooool00olQ8B7o0000o`000002o`000006oa0@4?oooooooooooooooomgMgOo<S8b
1_ooool04OmgMgOo<S8boooooooooooo0000oiRHV?ooooooV9RHob4Q8Oo^k^ko<S8bo`000?l_;boo
Cdm?omgMgOmEEEGok^k^00;ooooo0_lQ8B42ooooo`03o`000?oooooooooo00Co000000Oo410@oooo
ool0003o<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00000_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0/oooool00;Go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo
<S8b00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Om6ATKo3@d=onk^
k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`04oeEEEOo<c<co8B4Qob4Q
8@Cooooo00CoEEEEolc<c?oooooo00000_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c002ooooo`0?o`000?mEEEGo0000oa0@4?o<c<coMgMgoiRHV?o^k^ko
<S8bofm_Koooooook^k^oeEEEOo^k^kooooo00;o8B4Q0_ooool00ol0003oooooooooo`02ooooo`09
o`000?ooooooooooooooool0003oV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
oa0@4?nj^[[oooooogMgMolb<S800_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47
ooooo`03o`000?oooooooooo0;Cooooo002]ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo
410@00[ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41002oooool6o`0000;ooooo00Go
410@oooooooooooooooooa0@4003ooooo`03ojVYZOmgMgOooooo00Gooooo00CoZJVYogMgMooooooo
00000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?oEEEEohN7Qooo
ool00_ooool01Ol@413oooooonk^k_o^k^ko410@00;ooooo0_o^k^h5ooooo`03o`000?oooooooooo
00;ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RH
ob4Q8Oo^k^h00oooool01Ol@413ooooooooooooooooo410@00oooooo00Co0000oooooooooooo410@
0oooool00ol@413oooooooooo`09ooooo`Go0000]Oooool00;Gooooo00Go0000oooooooooooooooo
o`00000>ooooo`05ojVYZOl@413oooooooooool000000oooool00ol0003oooooooooo`06ooooo`08
o`000?nj^[[ooooooiRHV?l@413oV9RHob4Q8Oo^k^h3ooooo`06o`000?ooooooooooooooool0003o
410@0oooool01Olb<S;ooooooooooooooooo410@00?ooooo00?o<S8booooool000000_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?ogMgMoa0@4?nHV9P00_ooool01Ol0
003ooooooooooooooooo000000Wooooo00?o0000ooooooooool00_ooool01Ol0003oV9RHoooooonH
V9So000000?ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP02ooooo`05o`000?oo
ooooooooooooool000003_ooool01OnYZJWo410@oooooooooooo000000?ooooo00?o0000oooooooo
ool02Oooool01?m4A4CogMgMooooool0002fooooo`00]Oooool01Ol0003ooooooooooooooooo0000
00gooooo00?o410@o`000?nj^[X00_ooool01Ol0003ooooooooooooooooo000000Sooooo00SoV9RH
oa0@4?l0003o8B4Qolc<c?ooooooMgMgofIVIP?ooooo00Co0000oooooooooooooooo1_l00003oooo
o`Go000000Coooooo`000?oooooooooo1?l00004ooooo`Co00001?ooool01Oo<c<coA4A4o`000?l@
413o000000?ooooo00?o0000ooooooooool01Oooool00omEEEGoIVIVo`000004ooooo`05o`000?lb
<S;o0000oc8b<_l000000oooool00ol0003oooooooooo`02ooooo`?o00000_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMomVIVKoooooooooool000000oooool00ol0003oooooooooo`0;ooooo`03
oa0@4?l0003o^[Zj00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`000;Kooooo002eooooo`05oa0@4?ooooooooooooooool@41003_ooool01Onj^[[o8B4Qoooooooo
oooo410@00?ooooo00?o410@ooooooooool03Oooool01Ol0003ooooooooooooooooo410@00?ooooo
00?o410@ooooooooool03?ooool00ol0003oooooooooo`0Dooooo`05oa0@4?ooooooooooooooool@
41003_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool00oooool01Ol0
003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo410@0oooool00ol@413ooooooooo
o`0<ooooo`05okZj^_lQ8B7oooooooooool@41000oooool00ol@413oooooooooo`0:ooooo`03ogMg
Moo<c<co00000;Kooooo002eooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413oV9RH
oooooonj^[[o000000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool05?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00Oo0000ooooooooooooooooogMgMonHV9Sooooo
00Co00000oooool00ol0003oooooooooo`02ooooo`;o000000Co^[ZjoooooonHV9So410@0_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oiRHV?oooooo^[Zjo`000002ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00002fooooo`00]Oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@02ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`03oeEEEOmVIVKo000001Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03
oeEEEOmVIVKo000000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo
00;ooooo00Ko0000oiRHV?l@413o0000ob4Q8Oo<c<`2ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool01OnYZJWo410@o`000?l@413oZJVY00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=oooo
o`03ogMgMol0003ooooo0;Gooooo003ooooooc3ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`3Uooooo`00ooooool_ooooo`;o00000_ooool4o`000>Oooooo003ooooooooooooo
7oooool00?oooooooooooolOooooo`00oooooooiooooo`;o00000_ooool2o`0001oooooo003ooooo
ooWooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMdOooooo`00ooooooojooooo`04omgMgOl0003o
410@olc<c23ooooo000Koooooooo0000d?l0000?ooooo`04onk^k_lQ8B7o410@onk^kR3ooooo002l
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0V?ooool01?lQ8B7oMgMgogMgMolb
<S8Pooooo`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo09Oooooo0_l00002
ooooo`;o00007oooool00;cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2loooo
o`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;cooooo002looooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0_?ooool00;cooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`006?l0002nooooo`00_?ooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`3Cooooo`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Cooooo`00_?ooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`3Cooooo`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Cooooo`00_?ooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3Cooooo`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`3Cooooo`00_?ooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Coooo
o`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`3Cooooo`00_?ooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Cooooo`00_?oo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3Cooooo`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`006?l0003Eooooo`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0j_ooool00;cooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo0>[ooooo002looooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Zooooo`00_?ooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0j_ooool00;cooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0>[ooooo002loooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Zoooo
o`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0j_ooool00;cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0>[ooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3Zooooo`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0j_ooool00;cooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0>[ooooo002looooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`006?l0003/ooooo`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo
0_ooool00;cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo002l
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00_?ooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00;cooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`3oooooo`;ooooo002looooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0ooooool2ooooo`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0?oooooo0_ooool00;cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3o
ooooo`;ooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2oooo
o`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00;cooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo002looooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00_?ooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0?oooooo0_ooool00;cooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3oooooo`;ooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0ooooool2ooooo`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo
0_ooool00;cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo002l
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00_?ooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00;cooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`3oooooo`;ooooo002loooooaSo00005ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00dooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool0
0=?ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;o
oooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo000Ho`000?oooooo
1?ooool00=?ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool000;o0000oooooolJooooo`00doooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0oooooolIooooo`00doooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0oooooolIooooo`00doooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0oooooolIooooo`00dooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0oooo
oolIooooo`00doooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0oooooolIooooo`00doooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0oooooolIooooo`00doooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0oooooolIooooo`00doooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0oooooolIooooo`00dooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0oooo
oolIooooo`00doooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`000_l0003o
oooooa[ooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3ooooooaWooooo003C
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3o
oooooaWooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo0002o`000?oooooo6_ooool00=?ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo6Oooool0
0=?ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo6Oooool0
0=?ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool000;o0000oooooolJooooo`00doooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0oooooolIooooo`00doooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0oooooolIoooo
o`00doooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0oooooolIooooo`00doooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0oooooolIooooo`00doooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0oooooolIooooo`00doooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0oooooolIooooo`00doooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0oooooolIoooo
o`00doooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0oooooolIooooo`00doooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
1?l0003ooooooaSooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3ooooooaWooooo003Cooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3ooooooaWo
oooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`00
01Goo`006?l0003ooooooa_ooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool05?ooool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Goo`00
00?o0000ooooooooool05?ooool2o`000?oooooo6_ooool00=?ooooo00?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0?oooooo6Oooool0
0=?ooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0?oooooo6Oooool0
0=?ooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`0Dooooo`;o0000oooooolJooooo`00doooool00ol0003oo`00ool0000Eool00003o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0oooooolIooooo`00doooool00ol0003oo`00ool0000E
ool00003o`000?oooooooooo01Cooooo00?o0000ooooooooool0oooooolIooooo`00doooool00ol0
003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ooooooooool0oooooolIoooo
o`00doooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0oooooolIooooo`00doooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo
00?o0000ooooooooool0oooooolIooooo`00doooool00ol0003oo`00ool0000Eool00003o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0oooooolIooooo`00doooool00ol0003oo`00ool0000E
ool00003o`000?oooooooooo01Cooooo00?o0000ooooooooool0oooooolIooooo`00doooool00ol0
003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ooooooooool0oooooolIoooo
o`00doooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo0_l0003ooooooa[o
oooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?oo
ool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000
ooooooooool05?ooool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`00
01Goo`0000?o0000ooooooooool05?ooool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03
o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oooooooooo`3ooooooaWo
oooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?oo
ool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000
ooooooooool05?ooool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`00
01Goo`0000?o0000ooooooooool05?ooool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03
o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool2o`000?oooooo6_ooool00=?ooooo
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0?oooooo
6Oooool00=?ooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0?oooooo
6Oooool00=?ooooo00?o0000ool00?oo00005Ooo00001?l0003ooooooooooom4A4@2o`000009oc8b
<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolI
ooooo`00doooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo00?ooooo00WoMgMgoc8b
<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo
003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool01?ooool01?l0003ooooooooo
ool@4103ooooo`03oa0@4?oooooooooo00Kooooo1?l0003ooooooaSooooo003Cooooo`03o`000?oo
003oo`0001Goo`0000?o0000ooooooooool00oooool01OmgMgOo<S8boooooooooooo000000?ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo
003oo`0001Goo`0000So0000oooooooooooo0000ob4Q8Ol0003o<S8bolc<c0;ooooo00Go0000oooo
ooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool0
0?oo00005Ooo00001?l0003oooooooooool00006ooooo`05oa0@4?ooooooooooooooool@41002?oo
ool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Goo`0000Co0000
oooooooooooo00001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0
oooooolIooooo`00doooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo00Co00000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00dooo
ool00ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ooooooooool0oooo
oolIooooo`00doooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000
ooooooooool0oooooolIooooo`00doooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo
01Cooooo00?o0000ooooooooool0oooooolIooooo`00doooool00ol0003oo`00ool0000Eool00003
o`000?oooooooooo01Cooooo00?o0000ooooooooool0oooooolIooooo`00doooool00ol0003oo`00
ool0000Eool00003o`000?oooooooooo01Cooooo0_l0003ooooooa[ooooo003Cooooo`03o`000?oo
003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oooooooooo`3ooooooaWooooo003C
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oooooooooo`3o
oooooaWooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0
003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool05?ooool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Goo`00
00?o0000ooooooooool05?ooool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo
003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oooooooooo`3ooooooaWooooo003C
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oooooooooo`3o
oooooaWooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0
003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool05?ooool2o`000?oooooo6_ooool00=?ooooo00?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0?oooooo6Oooool0
0=?ooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0?oooooo6Oooool0
0=?ooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`;o
0000oooooolJooooo`00doooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo
00?o0000ooooooooool0oooooolIooooo`00doooool00ol0003oo`00ool0000Eool00003o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0oooooolIooooo`00doooool00ol0003oo`00ool0000E
ool00003o`000?oooooooooo01Cooooo00?o0000ooooooooool0oooooolIooooo`00doooool00ol0
003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ooooooooool0oooooolIoooo
o`00doooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0oooooolIooooo`00doooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo
00?o0000ooooooooool0oooooolIooooo`00doooool00ol0003oo`00ool0000Eool00003o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0oooooolIooooo`00doooool00ol0003oo`00ool0000E
ool00003o`000?oooooooooo01Cooooo00?o0000ooooooooool0oooooolIooooo`00doooool00ol0
003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo0_l0003ooooooa[ooooo003Cooooo`03
o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oooooooooo`3ooooooaWo
oooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?oo
ool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000
ooooooooool05?ooool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`00
01Goo`0000?o0000ooooooooool05?ooool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03
o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oooooooooo`3ooooooaWo
oooo003Cooooo`03o`000?oo003oo`0001Goo`0000Oo0000ooooooo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0=?ooooo00?o0000ool00?oo00005Ooo00001ol0003oooooogMgMonHV9SooooooiRHV?mgMgL00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00dooo
ool00ol0003oo`00ool0000Eool00003o`000?oooooo410@00?ooooo00Go410@oooooooooooooooo
oa0@4003ooooo`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00dooo
ool00ol0003oo`00ool0000Eool00003o`000?oooooo000000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo00Kooooo1?l0003ooooooaSooooo003Cooooo`03o`000?oo
003oo`0001Goo`0000?o0000ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo
003oo`0001Goo`0000?o0000ooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo
00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo
003oo`0001Goo`0000Oo0000oooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo
00005Ooo00001ol0003oooooonk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00doooool00ol0003oo`00ool0000E
ool00003o`000?oooooooooo01Cooooo00?o0000ooooooooool0oooooolIooooo`00doooool00ol0
003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ooooooooool0oooooolIoooo
o`00doooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0oooooolIooooo`00doooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo
00?o0000ooooooooool0oooooolIooooo`00doooool00ol0003oo`00ool0000Eool00003o`000?oo
oooooooo01Cooooo0_l0003ooooooa[ooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000
ooooooooool05?ooool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`00
01Goo`0000?o0000ooooooooool05?ooool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03
o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oooooooooo`3ooooooaWo
oooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?oo
ool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000
ooooooooool05?ooool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`00
01Goo`0000?o0000ooooooooool05?ooool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03
o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oooooooooo`3ooooooaWo
oooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?oo
ool2o`000?oooooo6_ooool00=?ooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0?oooooo
6Oooool00=?ooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo6Ol0000Fooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003U
ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A007ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000
ooooooooool0oooooolIooooo`00i_ooool00onHV9So8B4Qonk^kP09ooooo`04o`000?oooooooooo
oa0@40?ooooo00?o410@ooooooooool01_ooool4o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q
8Oo^k^h01oooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooooooo
o`3ooooooaWooooo003Yooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
1Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool0
1Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So410@o`00
0?lQ8B7oc<c<00Cooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o
0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0
003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol@413o^[Zjoooooomg
MgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`05o`000?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01_ooool00ol0
003oooooooooo`3ooooooaWooooo003Xooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool4o`000?oooooo6?ooool0
0>Oooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`00003oooooobCooooo003Xooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@
oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100oooooolTooooo`00iOoo
ool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0oooooolTooooo`00iOooool01OnYZJWo410@o`000?l@413oZJVY
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0oooo
oolTooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00
oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooo
oaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00moooool2o`0000_ooooo00?o
0000okZj^_ooool03?ooool2o`000?oooooo2Oooool00?Oooooo00?o0000ooooooooool02_ooool2
oc8b<Pkooooo00?o0000ooooooooool0ooooool7ooooo`00joooool01?l@413o0000o`000?ooool2
o`000003oa0@4?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000ooo
ool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X01?ooool00ol0003ooooo
ooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool02_l0003ooooo
ooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o410@00Cooooo00Go
410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00CogMgMo`000?l@413o
c<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@
413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>co
oooo1Ol00006ooooo`03o`000?oooooooooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000oooooooo
ooooooooo`000006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000Sooooo00?o410@
o`000?l000000ol00005ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@
ooooooooool00oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`000?oooooo2Oooool0
0?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00001\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.11695, -22.4749, \
0.0054076, 1.31245}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.35 -0.0125 -12 -9 ]
[.35 -0.0125 12 0 ]
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.45 -0.0125 -12 -9 ]
[.45 -0.0125 12 0 ]
[.5 -0.0125 -39.75 -12.5 ]
[.5 -0.0125 39.75 0 ]
[.55 -0.0125 -9 -9 ]
[.55 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.35 0 m
.35 .00625 L
s
[(-0.3)] .35 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.45 0 m
.45 .00625 L
s
[(-0.1)] .45 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -39.75 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2.77556) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-17) show
grestore
.55 0 m
.55 .00625 L
s
[(0.1)] .55 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .3461 L
.4 .3461 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .3461 L
.4 .3461 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .274 L
.45 .274 L
.45 0 L
F
0 g
.4 0 m
.4 .274 L
.45 .274 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .20807 L
.5 .20807 L
.5 0 L
F
0 g
.45 0 m
.45 .20807 L
.5 .20807 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .20189 L
.55 .20189 L
.55 0 L
F
0 g
.5 0 m
.5 .20189 L
.55 .20189 L
.55 0 L
.5 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00?oooooo4Oooool2onk^kP?ooooo0_o^k^koooooo`Oo
oooo003Iooooo`Go00001Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01Oooool00ol0003ok^k^
ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd00oooool01Om4A4Co0000o`000?lb<S;ogMgM
00;ooooo00Gok^k^oc8b<_l0003o410@olc<c002ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEE
onk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^k_Oooooo003Ioooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01Oooool0
0omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Gooooo00WoMgMgoc8b<_oooooooooooeEE
EOmgMgOooooooiRHV?lQ8B400oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg0?Oooooo003Aooooo`Ko00000oooool00onH
V9So8B4Qonk^kP0>ooooo`03ojVYZOmEEEGooooo00Gooooo00?oZJVYoeEEEOooool02?ooool00ol0
003oooooooooo`05ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool0
0ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
403gooooo`00]Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05oiRHV?l@
413o0000oc8b<_o<c<`00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B43ooooo`03
oiRHV?l0003o000000?o00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Co8B4Qoooo
oolQ8B7o8B4Q1?ooool00olQ8B7o0000o`000002o`000006oa0@4?oooooooooooooooomgMgOo<S8b
1_ooool04OmgMgOo<S8boooooooooooo0000oiRHV?ooooooV9RHob4Q8Oo^k^ko<S8bo`000?l_;boo
Cdm?omgMgOmEEEGok^k^00;ooooo0_lQ8B42ooooo`03o`000?oooooooooo00Co000000?o410@oooo
ool00000moooool00;Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@
413o^[ZjoooooomgMgOo<S8b00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01Om6ATKo3@d=onk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`04
oeEEEOo<c<co8B4Qob4Q8@Cooooo00CoEEEEolc<c?oooooo00000_ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`0?o`000?mEEEGo0000oa0@4?o<
c<coMgMgoiRHV?o^k^ko<S8bofm_Koooooook^k^oeEEEOo^k^kooooo00;o8B4Q0_ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool00000moooool00:gooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41002_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400;
ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00?ooooo00?oZJVYogMgMoooool01Ooo
ool01?nYZJWoMgMgooooool00002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1?ooool00omEEEGoQhN7ooooo`02ooooo`05oa0@4?ooooook^k^onk^k_l@41000_ooool2onk^kPGo
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo410@0?Oooooo002eooooo`05
o`000?ooooooooooooooool000003_ooool01OnYZJWo410@oooooooooooo000000?ooooo00?o0000
ooooooooool01_ooool02?l0003o^[ZjoooooonHV9So410@oiRHV?lQ8B7ok^k^0oooool01_l0003o
oooooooooooooooo0000oa0@40?ooooo00Go<S8boooooooooooooooooa0@4003ooooo`03oc8b<_oo
oooo000000;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03omgMgOl@
413oV9RH00;ooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo00;ooooo
00Go0000oiRHV?ooooooV9RHogMgM`3gooooo`00]Oooool01Ol0003ooooooooooooooooo000000go
oooo00?o410@o`000?nj^[X00_ooool01Ol0003ooooooooooooooooo000000Sooooo00SoV9RHoa0@
4?l0003o8B4Qolc<c?ooooooMgMgofIVIP?ooooo00Co0000oooooooooooooooo1_l00003ooooo`Go
000000Coooooo`000?oooooooooo1?l00004ooooo`Co00001?ooool01Oo<c<coA4A4o`000?l@413o
000000?ooooo00?o0000ooooooooool01Oooool00omEEEGoIVIVo`000004ooooo`05o`000?lb<S;o
0000oc8b<_o^k^h02?ooool3o`0000;ooooo00?o0000ooooooooool0ioooool00;Gooooo00Go410@
oooooooooooooooooa0@400>ooooo`05okZj^_lQ8B7oooooooooool@41000oooool00ol@413ooooo
ooooo`0=ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0<ooooo`03
o`000?oooooooooo01Cooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo
00_ooooo00Go0000ooooooooooooooooo`00003Yooooo`00]Oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go410@oiRHV?oooooo^[Zjo`000002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>oooo
o`03o`000?oooooooooo01Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooo
oooo00Cooooo1?l00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0i_ooool0
0;Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT00_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`00000Fooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool00omEEEGoIVIVo`00000=ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0i_ooool00?oooooo<?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo0>Gooooo003ooooooboooooo0_l00002ooooo`Co0000ioooool00?oooooooooooolOooooo`00
oooooooooooooaoooooo003oooooooWooooo0_l00002ooooo`;o00007oooool00?oooooonOooool0
1_o^k^ko8B4QohN7Qonj^[[o0000omgMgAoooooo003ooooooo[ooooo00CogMgMo`000?l@413oc<c<
8?ooool001_oooooool0003@o`0000oooooo00Cok^k^ob4Q8Ol@413ok^k^8?ooool00;cooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`3Mooooo`04ob4Q8OmgMgOoMgMgoc8b<R3ooooo
002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0g?ooool2o`0000;ooooo0_l0
000Oooooo`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool0
0;cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo002looooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00_?ooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00;cooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3oooooo`;ooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0ooooool2ooooo`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0?oooooo0_ooool00;cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;o
oooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00_?oo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00;cooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo002looooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0ooooool2ooooo`00_?ooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0?oooooo0_ooool00;cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3oooooo`;ooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0oooo
ool2ooooo`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool0
0;cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo002looooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00_?ooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00;cooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3oooooo`;ooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0ooooool2ooooo`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0?oooooo0_ooool00;cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;o
oooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00_?oo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00;cooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo002looooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0ooooool2ooooo`00_?ooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0?oooooo0_ooool00;cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3oooooo`;ooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0oooo
ool2ooooo`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool0
0;cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo002looooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00_?ooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00;cooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3oooooo`;ooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0ooooool2ooooo`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0?oooooo0_ooool00;cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;o
oooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00_?oo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00;cooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo002looooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0ooooool2ooooo`00_?ooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0?oooooo0_ooool00;cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3oooooo`;ooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0oooo
ool2ooooo`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool0
0;cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo002looooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00_?ooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00;cooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3oooooo`;ooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0ooooool2ooooo`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0?oooooo0_ooool00;cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;o
oooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00_?oo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00;cooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo002looooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0ooooool2ooooo`00_?ooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0?oooooo0_ooool00;cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3oooooo`;ooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0oooo
ool2ooooo`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool0
0;cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo002looooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00_?ooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00;cooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3oooooo`;ooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0ooooool2ooooo`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0?oooooo0_ooool00;cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;o
oooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00_?oo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00;cooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo002looooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0ooooool2ooooo`00_?ooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0?oooooo0_ooool00;cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3oooooo`;ooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0oooo
ool2ooooo`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool0
0;cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo002looooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00_?ooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00;cooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3oooooo`;ooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0ooooool2ooooo`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0?oooooo0_ooool00;cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;o
oooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00_?oo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00;cooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo002looooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0ooooool2ooooo`00_?ooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0?oooooo0_ooool00;cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3oooooo`;ooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0oooo
ool2ooooo`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool0
0;cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`006?l0003oooooo`Cooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool000Co0000oooooolHooooo`00_?ooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`006?l0003ooooooa_ooooo002looooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo
6Oooool00;cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Kooooo
00?o0000ooooooooool0oooooolIooooo`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000Oo0000oooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00;cooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00007o`000?ooooook^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo002l
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo0?oooooo6Oooool00;cooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ooooooooool0oooooolIoooo
o`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool05?ooool00ol0003oooooooooo`3ooooooaWooooo002looooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0?oooooo
6Oooool00;cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo01Cooooo0_l0003ooooooa[ooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0?oooooo6Oooool0
0;cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
01Cooooo00?o0000ooooooooool0oooooolIooooo`00_?ooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oooooooooo`3ooooooaWo
oooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo0?oooooo6Oooool00;cooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ooooooooool0oooo
oolIooooo`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool05?ooool00ol0003oooooooooo`3ooooooaWooooo002looooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
0?oooooo6Oooool00;cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo01Cooooo00?o0000ooooooooool0oooooolIooooo`00_?ooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`3ooooooaWooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`0Dooooo`;o0000oooooolJooooo`00_?ooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oooooooooo`3o
oooooaWooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo0?oooooo6Oooool00;cooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0oooooolIooooo`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool05?ooool00ol0003oooooooooo`3ooooooaWooooo002looooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo0?oooooo6Oooool00;cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo01Cooooo00?o0000ooooooooool0oooooolIooooo`00_?ooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0
003oooooooooo`3ooooooaWooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0?oooooo6Oooool00;cooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo
0_l0003ooooooa[ooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0?oooooo6Oooool00;cooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000
ooooooooool0oooooolIooooo`00_?ooool00ol0003oo`00ool0000Dool001Wo00005_ooool00ol0
003oooooooooo`3ooooooaWooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`3ooooooaWooooo002looooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0;?ooool00ol0003oooooooooo`3ooooooaWooooo002looooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0;?ooool00ol0003oooooooooo`3ooooooaWooooo002l
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0;?ooool00ol0003oooooooooo`3o
oooooaWooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0;?ooool00ol0
003oooooooooo`3ooooooaWooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`3ooooooaWooooo002looooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0;?ooool2o`000?oooooo6_ooool00;cooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`0/ooooo`03o`000?oooooooooo0?oooooo6Oooool00;cooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`0/ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0;cooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
0?oooooo6Oooool00;cooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo0?oooooo6Oooool00;cooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo0?oooooo6Oooool00;cooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`0/ooooo`03o`000?oooooooooo0?oooooo6Oooool00;cooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`0@ooooo`Co000000Go410@ooooooooooooooooodA4
A002o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01;o
oooo00?o0000ooooooooool01_ooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMg
M`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00;cooooo00?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo410@0ooo
ool00ol@413oooooooooo`06ooooo`Co0000oooooolHooooo`00_?ooool00ol0003oo`00ool0000D
ool00003o`000?oooooooooo01;ooooo00?o0000ooooooooool01_ooool01OmgMgOo<S8boooooooo
oooo000000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo002l
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool04_ooool00ol0003oooooooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000Sooooo
00?o0000ooooooooool0oooooolIooooo`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo01;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05oa0@4?oo
ooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo002looooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool04_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo
6Oooool00;cooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0@ooooo`03oeEEEOmV
IVKo000000Gooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003ooooo
ooooo`3ooooooaWooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`3ooooooaWooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0;?ooool00ol0003oooooooooo`3ooooooaWooooo002looooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0;?ooool00ol0003oooooooooo`3ooooooaWooooo002looooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0;?ooool00ol0003oooooooooo`3ooooooaWo
oooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0;?ooool2o`000?oooooo
6_ooool00;cooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00;cooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo0?oooooo6Oooool00;cooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo0?oooooo6Oooool00;cooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`0/ooooo`03o`000?oooooooooo0?oooooo6Oooool00;cooooo
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0/ooooo`03o`000?oooooooooo0?oooooo
6Oooool00;cooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00;cooooo6?l0000^ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[o
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[o
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Gooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So
8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oiRHV?lQ8B7o
k^k^00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Wooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool4o`000?oo
oooo6?ooool00>Sooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wo
oooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool0
0ol@413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go0000okZj
^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So410@o`00
0?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`Go00001?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`09ogMgMolb<S;o
oooooooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00
i_ooool00onHV9So8B4Qonk^kP09ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@oooooooo
ool01_ooool4o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h01oooool01OmgMgOo<S8b
oooooooooooo000000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWo
oooo003Xooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05
o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@
00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[ZjoooooonHV9So410@
00Cooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000
ooooooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00iOooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003ooooooooo
o`3ooooooaWooooo003Yooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooo
oooooooo410@00?ooooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo
003Xooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000002?ooool4o`000?oooooo6?ooool00>Oooooo00?o410@o`000?nj^[X0
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00003ooooo
obCooooo003Xooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4003oooo
o`05oa0@4?ooooooooooooooool@4100oooooolTooooo`00iOooool01Ol@413oV9RHoooooonj^[[o
000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
oooooolTooooo`00iOooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0oooooolTooooo`00oooooooooooooaoo
oooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooo
oooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7ooo
ool00?oooooooooooolOooooo`00moooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`00
0?oooooo2Oooool00?Oooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000oooooooo
ool0ooooool7ooooo`00joooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?o
oooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000oooool00on7QhOo0000okZj^P04oooo
o`05oiRHV?l0003o0000odA4A?nj^[X01?ooool00ol0003oooooooooo`3oooooo`Oooooo003/oooo
o`05o`000?ooooooooooooooool000001_ooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo
^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004
ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo00;ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo1Ol00006ooooo`03o`000?oo
oooooooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`00
0?ooooooooooooooo`;o00000_ooool2o`0000Sooooo00?o410@o`000?l000000ol00005ooooo`03
o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oo
oooo003[ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool2o`0001;o
oooo00?o0000ooooooooool01Oooool2o`000?oooooo2Oooool00?oooooooooooolOooooo`00oooo
oooooooooaoooooo003ooooooooooooo7oooool00001\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.11695, -22.4749, \
0.0054076, 1.31245}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.3 -0.0125 -12 -9 ]
[.3 -0.0125 12 0 ]
[.35 -0.0125 -12 -9 ]
[.35 -0.0125 12 0 ]
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.45 -0.0125 -12 -9 ]
[.45 -0.0125 12 0 ]
[.55 -0.0125 -9 -9 ]
[.55 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.65 -0.0125 -9 -9 ]
[.65 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.3 0 m
.3 .00625 L
s
[(-0.4)] .3 -0.0125 0 1 Mshowa
.35 0 m
.35 .00625 L
s
[(-0.3)] .35 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.45 0 m
.45 .00625 L
s
[(-0.1)] .45 -0.0125 0 1 Mshowa
.55 0 m
.55 .00625 L
s
[(0.1)] .55 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.65 0 m
.65 .00625 L
s
[(0.3)] .65 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.3 0 m
.3 .00412 L
.35 .00412 L
.35 0 L
F
0 g
.5 Mabswid
.3 0 m
.3 .00412 L
.35 .00412 L
.35 0 L
.3 0 L
s
1 0 0 r
.35 0 m
.35 .05768 L
.4 .05768 L
.4 0 L
F
0 g
.35 0 m
.35 .05768 L
.4 .05768 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .0618 L
.45 .0618 L
.45 0 L
F
0 g
.4 0 m
.4 .0618 L
.45 .0618 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .15451 L
.5 .15451 L
.5 0 L
F
0 g
.45 0 m
.45 .15451 L
.5 .15451 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .35228 L
.55 .35228 L
.55 0 L
F
0 g
.5 0 m
.5 .35228 L
.55 .35228 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .35434 L
.6 .35434 L
.6 0 L
F
0 g
.55 0 m
.55 .35434 L
.6 .35434 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .04532 L
.65 .04532 L
.65 0 L
F
0 g
.6 0 m
.6 .04532 L
.65 .04532 L
.65 0 L
.6 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool009gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1_ooool2o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q
1?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4
o`000003oa0@4?oooooooooo01?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Ooo
ool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`00
00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb
<S;oc<c<0<_ooooo002Mooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00Wo
0000ooooooooooooooooogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go410@okZj
^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oo
oooo00?o0000ooooooooool05Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b0<_ooooo002Eooooo`Ko00000_ooool01Ol@413ooooo
oooooooooooo410@00[ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41002oooool6o`00
00;ooooo00Go410@oooooooooooooooooa0@400:ooooo`Ko00000_ooool01Ol@413ooooooooooooo
oooo410@00kooooo00?o0000ooooooooool05Oooool01Ol@413ooooooooooooooooo410@00kooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^
k^h00oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0bOooool009go
oooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000?ooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oooooooooooooooo
o`00000=ooooo`03oiRHV?lQ8B7ok^k^00;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03
o`000?oooooooooo01Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00;ooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ojVYZOl@413ooooo0<[ooooo002Mooooo`05o`000?oooooo
ooooooooool000002oooool01?oMgMgoEEEEooooool00003ooooo`05o`000?ooooooooooooooool0
00003Oooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000003_ooool01Omg
MgOoIVIVoooooooooooo000000?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0E
ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000003_ooool01OmgMgOoIVIVoooooooooooo000000?ooooo00?o0000oooooooo
ool02oooool00ol@413o0000okZj^P3;ooooo`00WOooool01Ol@413ooooooooooooooooo410@00co
oooo00?oMgMgolc<c?l000000oooool01Ol@413ooooooooooooooooo410@00kooooo00?o^[Zjob4Q
8Oooool00_ooool01Ol@413ooooooooooooooooo410@00oooooo00Co0000oooooooooooo410@0ooo
ool00ol@413oooooooooo`0<ooooo`03o`000?oooooooooo01Gooooo00Go410@oooooooooooooooo
oa0@400>ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400?ooooo`04
o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool03?ooool00onj^[[o8B4Qooooo`3:oooo
o`00WOooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0>ooooo`03o`000?oooooooooo01Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj
^[[ooooooiRHV?l@41000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oiRHV?oo
oooo^[Zjo`00003;ooooo`00WOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`00
0?ooool00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVY
Z@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00;o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo000001Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@3;ooooo`00oooooooooooooaoooooo003ooooooooooooo
7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo0_l00002oooo
o`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAcooooo003ooooo
oogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo00Cok^k^ob4Q
8Ol@413ok^k^7Oooool00:Cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2aoooo
o`04ob4Q8OmgMgOoMgMgoc8b<Qgooooo002ToooooaSo00005ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0/?ooool2o`0000;ooooo0_l0000Loooo
o`00Y?ooool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0=;ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0=;ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0=;ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0=;ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0=;ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0=;ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0=;ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo0=;ooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0=;ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo000Ho`000=Cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool0
0;_ooooo6Ol0000Fool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0jOooool00=?ooooo6?l0000Gool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00j_ooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`3Yooooo`00j_ooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00j_ooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yoooo
o`00j_ooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`3Yooooo`00j_ooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00j_oo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`3Yooooo`00j_ooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00j_ooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`3Yooooo`00j_ooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00j_ooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`3Yooooo`00j_ooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00j_ooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Y
ooooo`00j_ooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00j_ooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00
j_ooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`3Yooooo`00j_ooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00j_ooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`3Yooooo`00j_ooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00j_ooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`3Yooooo`00j_ooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00j_ooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`3Yooooo`00j_ooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00j_ooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yoooo
o`00j_ooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`3Yooooo`00j_ooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00j_oo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`3Yooooo`00j_ooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00j_ooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`3Yooooo`00j_ooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00j_ooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`3Yooooo`00j_ooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00j_ooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Y
ooooo`00j_ooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00j_ooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00
j_ooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`3Yooooo`00j_ooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00j_ooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`3Yooooo`00j_ooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00j_ooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`3Yooooo`00j_ooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00j_ooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`3Yooooo`00j_ooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00j_oooolIo`0001Koo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00oooo
ool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00oooo
ool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00oooo
ool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00oooo
ool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00i_ooool4o`000008oa0@
4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?oo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOoo
ool00>Sooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`3Yooooo`00j?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Xooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000002?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0jOooool00>Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00j?ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003X
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0jOooool00>Kooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00oooo
ool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00oooo
ool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00oooo
ool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00oooo
ool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00oooo
ool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00oooo
ool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00oooo
ool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00oooo
ool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00i_ooool4o`000005oa0@
4?oooooooooooooooom4A4@00_l000002Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^
kP08ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`3Yooooo`00j?ooool00ol0003oooooooooo`06ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RH
oooooonHV9SoMgMg00Sooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0>Wooooo003Xooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo
410@0oooool00ol@413oooooooooo`06ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`3Yooooo`00j?ooool00ol0003oooooooooo`06ooooo`05ogMg
Molb<S;oooooooooool000000oooool00ol0003oooooooooo`06ooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00j?ooool00ol0003ooooo
ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo0000
00Sooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0>Wooooo003Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413o
oooooooooooooooo410@00Sooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0>Wooooo003Xooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Vooooo`03oeEEEOmVIVKo000000Go
oooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00?oooooo0oooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00?oooooo
0oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
jOooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0jOooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0jOooool00?oooooo0oooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00?oooooo0oooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00?oooooo
0oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
jOooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0jOooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0jOooool00?oooooo0oooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00?oooooo0oooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00?oooooo
0oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
jOooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0jOooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0jOooool00?oooooo0oooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00?oooooo0ooooolHo`0001Oo
o`0000?o0000ooooooooool0jOooool00?oooooo0oooool00ol0003oooooooooo`0DoooooaWo0000
joooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2
o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooo
oolIooooo`00i_ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@00Sooooo1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ogMgMomVIVKooooo00;ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0
003oooooooooo`3ooooooaWooooo003Yooooo`05o`000?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3o
oooooaWooooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00iOooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@01oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03
o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^k^h02Oooool01?l0003ooooo
ooooool@4103ooooo`03oa0@4?oooooooooo00Kooooo1?l0003ooooooaSooooo003Wooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00omgMgOoIVIVooooo`03ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooo
ooooool0oooooolIooooo`00jOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Go
oooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c004ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Uooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00>Wooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo
ooooooooool@41000oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Sooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000008ooooo`Co0000oooooolHooooo`00ioooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo00000?oo
oooo9?ooool00>Sooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@403oooooobCooooo003Uooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`3oooooobCooooo003Uooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP3oooooobCooooo003ooooooooooooo
7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oo
oooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolO
ooooo`00oooooooooooooaoooooo003gooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o
0000ooooool9ooooo`00moooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003ooooo
ooooo`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool0
0oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Co
oooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo0?oooooo1oooool00>co
oooo00Go0000ooooooooooooooooo`000006ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7
Qonj^[[o0000omgMg@?ooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@
00Cooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool5o`0000Kooooo00?o0000
ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co
0000oooooooooooooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Gooooo
00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo
1oooool00>_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`;o0000
4_ooool00ol0003oooooooooo`05ooooo`;o0000ooooool9ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.45 -0.0125 -12 -9 ]
[.45 -0.0125 12 0 ]
[.55 -0.0125 -9 -9 ]
[.55 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.65 -0.0125 -9 -9 ]
[.65 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.45 0 m
.45 .00625 L
s
[(-0.1)] .45 -0.0125 0 1 Mshowa
.55 0 m
.55 .00625 L
s
[(0.1)] .55 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.65 0 m
.65 .00625 L
s
[(0.3)] .65 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(0.5)] .75 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.4 0 m
.4 .05562 L
.45 .05562 L
.45 0 L
F
0 g
.5 Mabswid
.4 0 m
.4 .05562 L
.45 .05562 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .06386 L
.5 .06386 L
.5 0 L
F
0 g
.45 0 m
.45 .06386 L
.5 .06386 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .09271 L
.55 .09271 L
.55 0 L
F
0 g
.5 0 m
.5 .09271 L
.55 .09271 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .2843 L
.6 .2843 L
.6 0 L
F
0 g
.55 0 m
.55 .2843 L
.6 .2843 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .30902 L
.65 .30902 L
.65 0 L
F
0 g
.6 0 m
.6 .30902 L
.65 .30902 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .21631 L
.7 .21631 L
.7 0 L
F
0 g
.65 0 m
.65 .21631 L
.7 .21631 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .00824 L
.75 .00824 L
.75 0 L
F
0 g
.7 0 m
.7 .00824 L
.75 .00824 L
.75 0 L
.7 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4
o`000003oa0@4?oooooooooo01?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Ooo
ool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`00
00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb
<S;oc<c<00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000009oa0@
4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd0Voooool00<cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1oooool00ol0003oooooooooo`0Eooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S800_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`2Jooooo`00a?ooool6o`0000;ooooo00Go410@oooo
oooooooooooooa0@400:ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00kooooo00?o
0000ooooooooool05Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol@413o
oooooooooooooooo410@00oooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`09
ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool0VOoo
ool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00;ooooo00Go
0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo01Gooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000=oooo
o`03oiRHV?lQ8B7ok^k^00;ooooo00Go0000ooooooooooooooooo`00000>ooooo`05ojVYZOl@413o
ooooooooool000000oooool00ol0003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Cooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo09[ooooo003<ooooo`05o`00
0?ooooooooooooooool000003_ooool01OmgMgOoIVIVoooooooooooo000000?ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0Eooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003_ooool01OmgMgOoIVIVoooo
oooooooo000000?ooooo00?o0000ooooooooool02oooool00ol@413o0000okZj^P02ooooo`05o`00
0?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?oooooooooo
ooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<09_ooooo003<ooooo`05oa0@4?oooooo
ooooooooool@41003oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00cooooo
00?o0000ooooooooool05Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@00oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0<ooooo`05okZj^_lQ8B7oooooooooool@41000oooool00ol@413ooooooooo
o`0:ooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`00
0?oooooooooo09gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zj
oooooonHV9So410@00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo
01Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41000_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go410@oiRHV?oooooo^[Zjo`000002ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00ol0003oooooooooo`2Mooooo`00c?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00omEEEGo
IVIVo`00000Gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`000004oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00;ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT00_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo1?l0002Looooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooo
oooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo0_l00002ooooo`;o00007?ooool0
0?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAcooooo003ooooooogooooo00CogMgM
o`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo00Cok^k^ob4Q8Ol@413ok^k^7Ooo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`22ooooo`04ob4Q8OmgMgOo
MgMgoc8b<Qgooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0POooool2
o`0000;ooooo0_l0000Looooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool001Wo0000YOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^ooo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo6?l0
000Gool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00>[ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Zoooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2koooo
o`00j_ooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0^oooool00>[ooooo6Ol0000Fool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003oooooo`?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00ooooool3ooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0^oooool00?oooooo0oooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0;_ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`2kooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
^oooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003o
ooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00ooooool3oooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00?oooooo0oooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo0;_ooooo003oooooo`?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`2kooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0^oooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0;_ooooo003oooooo`?ooooo6?l0000Gool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`2kooooo`00ooooool3ooooo`03o`000?oooooooooo01Co
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0^oooool00?oooooo0oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0;_ooooo003^ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00
lOooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0^oooool00?;ooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`06ooooo`Co00004oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00lOooool01Omg
MgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0D
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0;_ooooo003^ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool0
1Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool05?ooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`2kooooo`00k_ooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41002?oo
ool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003^ooooo`03o`000?oooooo
oooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo01Cooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0^oooool00>kooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?oo
ool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003oooooo`?ooooo00?o0000
ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00ooooool3ooooo`03o`000?oooooooooo
01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0^oooool00?oooooo0oooool00ol0003oooooooooo`0Dooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0;_ooooo003oooooo`?ooooo00?o0000ooooooooool05?ooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`2kooooo`00ooooool3ooooo`;o00005Oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00ooooool3
ooooo`03o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00?oooooo0oooool00ol0
003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003oooooo`?ooooo00?o0000oooooooo
ool05?ooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2kooooo`00ooooool3ooooo`03o`000?oooooooooo01Cooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0^oooool00?oooooo0oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0;_ooooo003oooooo`?ooooo00?o0000ooooooooool05?ooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2k
ooooo`00ooooool3ooooo`03o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00?oo
oooo0oooool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003oooooo`?ooooo
00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00ooooool3ooooo`;o00005Ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2kooooo`00ooooool3ooooo`03o`000?oooooooooo01Cooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0^oooool00?oooooo0oooool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0;_ooooo003oooooo`?ooooo00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00
ooooool3ooooo`03o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00?oooooo0ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003oooooo`?ooooo00?o0000
ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00ooooool3ooooo`03o`000?oooooooooo
01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0^oooool00?oooooo0oooool00ol0003oooooooooo`0Dooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0;_ooooo003oooooo`?ooooo0_l0000Eooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo
003oooooo`?ooooo00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00ooooool3
ooooo`03o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00?oooooo0oooool00ol0
003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003oooooo`?ooooo00?o0000oooooooo
ool05?ooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2kooooo`00ooooool3ooooo`03o`000?oooooooooo01Cooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0^oooool00?oooooo0oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0;_ooooo003oooooo`?ooooo00?o0000ooooooooool05?ooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2k
ooooo`00ooooool3ooooo`03o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00?oo
oooo0oooool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003oooooo`?ooooo
0_l0000Eooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0;_ooooo003oooooo`?ooooo00?o0000ooooooooool05?oo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2kooooo`00ooooool3ooooo`03o`000?oooooooooo01Cooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0^oooool00?oooooo0oooool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0;_ooooo003oooooo`?ooooo00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00
ooooool3ooooo`03o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00?oooooo0ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Vooooo`Co000000So410@
ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08oooo
o`03o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00>Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08
ooooo`03o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00>Sooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
4008ooooo`03o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00>Sooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000008ooooo`Co00004oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00j?ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000So
oooo00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00j?ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@
00Sooooo00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00j?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Sooooo00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00i_ooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Sooooo00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`006?l0002mooooo`00ooooool3ooooo`03o`000?oooooooooo01Cooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003ooooo
o`?ooooo00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0d_ooool00?oooooo0oooool00ol0003oooooooooo`0Dooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00
ooooool3ooooo`03o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0=;ooooo003oooooo`?ooooo0_l0000Eooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00ooooool3
ooooo`03o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0=;ooooo003oooooo`?ooooo00?o0000ooooooooool05?ooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00?oo
oooo0oooool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`3Booooo`00ooooool3ooooo`03o`000?oooooooooo01Cooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo
003oooooo`?ooooo00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0d_ooool00?oooooo0oooool00ol0003oooooooooo`0D
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3B
ooooo`00ooooool3ooooo`03o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003oooooo`?ooooo00?o0000oooooooo
ool05?ooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0d_ooool00?oooooo0oooool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00ooooool3ooooo`;o00005Ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_oo
ool00?oooooo0oooool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00ooooool3ooooo`03o`000?oooooooooo
01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0=;ooooo003oooooo`?ooooo00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00?oooooo0oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3Booooo`00ooooool3ooooo`03o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003oooooo`?ooooo00?o0000
ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0d_ooool00?oooooo0oooool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00ooooool3ooooo`03
o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0=;ooooo003oooooo`?ooooo00?o0000ooooooooool05?ooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00?oooooo0ooo
ool2o`0001Gooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0=;ooooo003oooooo`?ooooo00?o0000ooooooooool05?ooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00?oooooo0oooool00ol0
003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3Booooo`00ooooool3ooooo`03o`000?oooooooooo01Cooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003oooooo`?ooooo
00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0d_ooool00?oooooo0oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00ooooool3
ooooo`03o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0=;ooooo003oooooo`?ooooo00?o0000ooooooooool05?oooolIo`00
01Koo`0000?o0000ooooooooool0d_ooool00?oooooo0oooool00ol0003oooooooooo`0/ooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00?oooooo0oooool2o`0002gooooo
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00ooooool3ooooo`03o`000?oo
oooooooo02cooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00ooooool3
ooooo`03o`000?oooooooooo02cooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3B
ooooo`00ooooool3ooooo`03o`000?oooooooooo02cooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3Booooo`00ooooool3ooooo`03o`000?oooooooooo02cooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`3Booooo`00ooooool3ooooo`03o`000?oooooooooo02cooooo
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00ooooool3ooooo`03o`000?oo
oooooooo02cooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00i_ooool4
o`000005oa0@4?oooooooooooooooom4A4@00_l000002Olb<S;ogMgMooooooooooook^k^oc8b<_l0
003o<S8bonk^kP08ooooo`03o`000?oooooooooo02cooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3Booooo`00j?ooool00ol0003oooooooooo`06ooooo`09ogMgMolb<S;ooooooooo
oomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0;?ooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo0=;ooooo003Xooooo`03o`000?oooooooooo00Oooooo00Co0000
oooooooooooo410@0oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo02cooooo00?o
0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00j?ooool00ol0003oooooooooo`06
ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`06ooooo`Co0000:ooo
oolHo`000=Cooooo003Xooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c002ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo
003Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Kooooo00?oEEEEofIVI_l000001Oooool4o`0000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oo
oooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00i_ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@00Sooooo1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?oo
ool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ogMgMomVIVKooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Yooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWo
oooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o
0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o
0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o
0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOoo
ool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^k^h02Oooool01?l0003oooooooooool@
4103ooooo`03oa0@4?oooooooooo00Kooooo1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7o
k^k^00Oooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0oooooolIooooo`00j?ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
oooooolIooooo`00jOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go
410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go
0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c004ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`00
0?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`00
0?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003ooooooooo
o`3ooooooaWooooo003Uooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Wooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>So
oooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000008ooooo`Co0000oooooolHooooo`00ioooool00ol@413o0000okZj^P03oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo00000?oooooo9?oo
ool00>Sooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@403oooooobCooooo003Uooooo`05oa0@4?nHV9SooooookZj^_l00000
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`3ooooo
obCooooo003Uooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP3oooooobCooooo003ooooooooooooo7oooool0
0?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooo
oolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00
oooooooooooooaoooooo003gooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o0000oooo
ool9ooooo`00moooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`3o
ooooo`Oooooo003[ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool0
1?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00Go
V9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go
0000ooooooooooooooooo`000006ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o
0000omgMg@?ooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo
00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool5o`0000Kooooo00?o0000oooooooo
ool00_ooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooo
oooooooooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Gooooo00?o0000
ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool0
0>_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`;o00004_ooool0
0ol0003oooooooooo`05ooooo`;o0000ooooool9ooooo`00oooooooooooooaoooooo003ooooooooo
oooo7oooool00?oooooooooooolOooooo`00\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.45 -0.0125 -12 -9 ]
[.45 -0.0125 12 0 ]
[.55 -0.0125 -9 -9 ]
[.55 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.65 -0.0125 -9 -9 ]
[.65 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.45 0 m
.45 .00625 L
s
[(-0.1)] .45 -0.0125 0 1 Mshowa
.55 0 m
.55 .00625 L
s
[(0.1)] .55 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.65 0 m
.65 .00625 L
s
[(0.3)] .65 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(0.5)] .75 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.4 0 m
.4 .10713 L
.45 .10713 L
.45 0 L
F
0 g
.5 Mabswid
.4 0 m
.4 .10713 L
.45 .10713 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .14215 L
.5 .14215 L
.5 0 L
F
0 g
.45 0 m
.45 .14215 L
.5 .14215 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .10507 L
.55 .10507 L
.55 0 L
F
0 g
.5 0 m
.5 .10507 L
.55 .10507 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .08446 L
.6 .08446 L
.6 0 L
F
0 g
.55 0 m
.55 .08446 L
.6 .08446 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .13391 L
.65 .13391 L
.65 0 L
F
0 g
.6 0 m
.6 .13391 L
.65 .13391 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .25545 L
.7 .25545 L
.7 0 L
F
0 g
.65 0 m
.65 .25545 L
.7 .25545 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .20189 L
.75 .20189 L
.75 0 L
F
0 g
.7 0 m
.7 .20189 L
.75 .20189 L
.75 0 L
.7 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4
o`000003oa0@4?oooooooooo01?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Ooo
ool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`00
00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb
<S;oc<c<00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000009oa0@
4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd0Voooool00<cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1oooool00ol0003oooooooooo`0Eooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S800_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`2Jooooo`00a?ooool6o`0000;ooooo00Go410@oooo
oooooooooooooa0@400:ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00kooooo00?o
0000ooooooooool05Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol@413o
oooooooooooooooo410@00oooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`09
ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool0VOoo
ool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00;ooooo00Go
0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo01Gooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000=oooo
o`03oiRHV?lQ8B7ok^k^00;ooooo00Go0000ooooooooooooooooo`00000>ooooo`05ojVYZOl@413o
ooooooooool000000oooool00ol0003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Cooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo09[ooooo003<ooooo`05o`00
0?ooooooooooooooool000003_ooool01OmgMgOoIVIVoooooooooooo000000?ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0Eooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003_ooool01OmgMgOoIVIVoooo
oooooooo000000?ooooo00?o0000ooooooooool02oooool00ol@413o0000okZj^P02ooooo`05o`00
0?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?oooooooooo
ooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<09_ooooo003<ooooo`05oa0@4?oooooo
ooooooooool@41003oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00cooooo
00?o0000ooooooooool05Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@00oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0<ooooo`05okZj^_lQ8B7oooooooooool@41000oooool00ol@413ooooooooo
o`0:ooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`00
0?oooooooooo09gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zj
oooooonHV9So410@00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo
01Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41000_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go410@oiRHV?oooooo^[Zjo`000002ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00ol0003oooooooooo`2Mooooo`00c?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00omEEEGo
IVIVo`00000Gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`000004oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00;ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT00_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo1?l0002Looooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooo
oooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo0_l00002ooooo`;o00007?ooool0
0?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAcooooo003ooooooogooooo00CogMgM
o`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo00Cok^k^ob4Q8Ol@413ok^k^7Ooo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`22ooooo`04ob4Q8OmgMgOo
MgMgoc8b<Qgooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0POooool2
o`0000;ooooo0_l0000Looooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Soooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2S
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xooo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool001Wo00005_oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Ooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2S
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo000Ho`0001Oooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0Xoooool00=?ooooo6?l0000Gool00003o`000?oooooooooo02cooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
Xoooool00>[ooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0/ooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0:?ooooo003Zooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0;?ooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`2Sooooo`00j_ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo
02cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0Xoooool00>[ooooo00?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`0/ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Zooooo`03o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0;?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00j_ooool00ol0003oo`00ool0
000Eool00003o`000?oooooooooo02cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00>[ooooo00?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`0/ooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Zoooo
o`03o`000?oo003oo`0001Goo`000_l0000]ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Zooooo`03
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0;?ooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00
j_ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo02cooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
Xoooool00>[ooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0/ooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0:?ooooo003Zooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0;?ooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`2Sooooo`00j_ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo
02cooooo6?l0000Fool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00>[o
oooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`13ooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00j_ooool00ol0003oo`00
ool0000Eool00003o`000?oooooooooo04?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0:?ooooo003Zooooo`03o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0@oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00>[ooooo6Ol00015ooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00ooooool3ooooo`;o0000A?ooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00?oo
oooo0oooool00ol0003oooooooooo`13ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00ooooool3ooooo`03o`000?oooooooooo04?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
003oooooo`?ooooo00?o0000ooooooooool0@oooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00?oooooo0oooool00ol0003oooooooooo`13
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2S
ooooo`00ooooool3ooooo`03o`000?oooooooooo04?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003oooooo`?ooooo00?o0000oooooooo
ool0@oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0Xoooool00?oooooo0oooool00ol0003oooooooooo`13ooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00ooooool3ooooo`03o`000?oo
oooooooo04?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0:?ooooo003oooooo`?ooooo0_l00014ooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00ooooool3ooooo`03o`000?oooooooooo
04?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0:?ooooo003oooooo`?ooooo00?o0000ooooooooool0@oooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00?oooooo0oooool00ol0003ooooo
ooooo`13ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00ooooool3ooooo`03o`000?oooooooooo04?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003oooooo`?ooooo00?o0000
ooooooooool0@oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00?oooooo0oooool00ol0003oooooooooo`13ooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00ooooool3ooooo`03
o`000?oooooooooo04?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0:?ooooo003oooooo`?ooooo00?o0000ooooooooool0@oooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00?oooooo0ooo
ool00ol0003oooooooooo`13ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`2Sooooo`00ooooool3ooooo`;o0000A?ooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00?oooooo0oooool00ol0
003oooooooooo`13ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`2Sooooo`00ooooool3ooooo`03o`000?oooooooooo04?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003oooooo`?ooooo
00?o0000ooooooooool0@oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0Xoooool00?oooooo0oooool00ol0003oooooooooo`13ooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00ooooool3
ooooo`03o`000?oooooooooo04?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo003oooooo`?ooooo00?o0000ooooooooool0@oooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00>Ko
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Sooooo00?o0000ooooooooool0@oooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00>Sooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03
o`000?oooooooooo04?ooooo00?o0000ool00?oo00005?oo000Io`000:Gooooo003Xooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41002?ooool00ol0003oooooooooo`13ooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0^oooool00>Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000008ooooo`Co0000@_ooool00ol0003oo`00ool0000D
ool00003o`000?oooooooooo0;_ooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooooooo
o`13ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00>Sooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooo
oa0@4008ooooo`03o`000?oooooooooo04?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`2kooooo`00j?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0@oooool00ol0003o
o`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Vooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0
003oooooooooo`13ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00?oo
oooo0oooool00ol0003oooooooooo`13ooooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0^oooool00?oooooo0oooool00ol0003oooooooooo`13ooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0^oooool00?oooooo0oooool00ol0003oooooooooo`13ooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0^oooool00?oooooo0oooool00ol0003oooooooooo`13
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00?oooooo0oooool2o`00
04Cooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00ooooool3ooooo`03
o`000?oooooooooo04?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00
ooooool3ooooo`03o`000?oooooooooo04?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`2kooooo`00ooooool3ooooo`03o`000?oooooooooo04?ooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2kooooo`00ooooool3ooooo`03o`000?oooooooooo04?ooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00ooooool3ooooo`03o`000?oooooooooo
04?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00ooooool3ooooo`03
o`000?oooooooooo04?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00
ooooool3ooooo`03o`000?oooooooooo04?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`2kooooo`00ooooool3ooooo`03o`000?oooooooooo04?ooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2kooooo`00ooooool3ooooo`03o`000?oooooooooo04?ooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00ooooool3ooooo`;o0000A?ooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003oooooo`?ooooo00?o0000oooooooo
ool0@oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003oooooo`?ooooo
00?o0000ooooooooool0@oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo
003oooooo`?ooooo00?o0000ooooooooool0@oooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0;_ooooo003oooooo`?ooooo00?o0000ooooooooool0@ooooolHo`000;gooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool4o`000005oa0@4?oooooooooooooo
oom4A4@00_l000002Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool02OmgMgOo<S8boooo
ooooooooMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>So
oooo00?o0000ooooooooool01oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo
00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`06ooooo`05
ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`06ooooo`Co0000oooooolHoooo
o`00j?ooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0
003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@4008
ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3o
oooooaWooooo003Vooooo`03oeEEEOmVIVKo000000Gooooo1?l00003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`00
0?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00iOooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uoooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?o
V9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@4008ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP03ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooo
ooooool0oooooolIooooo`00j?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolI
ooooo`00jOooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
4003ooooo`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00iOooool0
1Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_oo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_oo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_oo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo1Ol00004oooo
o`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o
0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00Wo
MgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Vooooo`03oiRHV?lQ8B7ok^k^00Wooooo00Co0000oooooooooooo410@0oooool00ol@
413oooooooooo`06ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP07ooooo`05
ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Sooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00;ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0>Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05oa0@4?oooooooooo
ooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05o`000?nj^[[ooooo
oiRHV?l@41001?ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?oo
ool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?oo
ool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Gooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00iOooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Y
ooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo
00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ojVYZOl@
413ooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00002?ooool4o`000?oooooo6?ooool00>Oooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00003oooooobCooooo003Xooooo`03
okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooo
ooooool@4100oooooolTooooo`00iOooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0oooooolTooooo`00iOoo
ool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h0oooooolTooooo`00oooooooooooooaoooooo003ooooooooooooo
7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oo
oooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolO
ooooo`00moooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`000?oooooo2Oooool00?Oo
oooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool0ooooool7ooooo`00
joooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo00Co0000oooooooo
oooooooo0_l00002ooooo`;o00000oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000
odA4A?nj^[X01?ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?oooooooooo
ooooool000001_ooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3oooo
o`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooo
oooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo00;ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo0?oooooo1oooool00>cooooo1Ol00006ooooo`03o`000?oooooooooo00;ooooo00Co
8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo
1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooooooo`;o
00000_ooool2o`0000Sooooo00?o410@o`000?l000000ol00005ooooo`03o`000?oooooooooo0?oo
oooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003[ooooo`04oa0@
4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool2o`0001;ooooo00?o0000oooooooo
ool01Oooool2o`000?oooooo2Oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00001\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .00206 L
.4 .00206 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .00206 L
.4 .00206 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .23279 L
.45 .23279 L
.45 0 L
F
0 g
.4 0 m
.4 .23279 L
.45 .23279 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .13185 L
.5 .13185 L
.5 0 L
F
0 g
.45 0 m
.45 .13185 L
.5 .13185 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .15039 L
.55 .15039 L
.55 0 L
F
0 g
.5 0 m
.5 .15039 L
.55 .15039 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .08652 L
.6 .08652 L
.6 0 L
F
0 g
.55 0 m
.55 .08652 L
.6 .08652 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .09064 L
.65 .09064 L
.65 0 L
F
0 g
.6 0 m
.6 .09064 L
.65 .09064 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .15245 L
.7 .15245 L
.7 0 L
F
0 g
.65 0 m
.65 .15245 L
.7 .15245 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .12773 L
.75 .12773 L
.75 0 L
F
0 g
.7 0 m
.7 .12773 L
.75 .12773 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .05562 L
.8 .05562 L
.8 0 L
F
0 g
.75 0 m
.75 .05562 L
.8 .05562 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo6Ol0000Fool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0Joooool01?lQ8B7oMgMgogMgMolb<S8Mooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0J_ooool2o`0000;ooooo
0_l0000Looooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0S?ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo08cooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`2<ooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0S?ooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2<ooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0S?ooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
08cooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`2<ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0S?ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`2<ooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0S?ooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2<ooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0S?oo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo08cooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`2<ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0S?ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo08cooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`2<ooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0S?ooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`006?l0002>ooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xooo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`006Ol0000Fool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`0EoooooaSo00005_oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo02cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo02cooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo02cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo02cooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo02cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo02cooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo02cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo02cooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo02co
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo02cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo02cooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo02cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo02cooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo02cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo02cooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo02cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo02cooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
02cooooo00?o0000ool00?oo00005?oo000Io`000:Gooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo02co
oooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00
ool0000Dool001Wo00005_oo00000ol0003oooooooooo`0/ooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0;?ooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo02cooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0/oooo
o`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0;?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo02cooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`0/ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^ooo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0;?ooool00ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05OoooolHo`00
02kooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ooooooooool0@ooooolHo`000;go
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool05Oooool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool05Oooool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oooooooooo`3ooooooaWo
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool2o`000?oooooo
6_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo
6Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`;o0000oooooolJooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ooooooooool0oooo
oolIooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000
ooooooooool0oooooolIooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo
01Gooooo00?o0000ooooooooool0oooooolIooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo01Gooooo00?o0000ooooooooool0oooooolIooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ooooooooool0oooooolIooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ooooooooool0oooo
oolIooooo`00doooool00ol0003oo`00ool0000Dool00008o`000?ooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Cooooo`03o`000?oo003oo`0001Coo`0000So0000ooooooooooooMgMgoiRHV?oooooo
V9RHogMgM`?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo
6Oooool00=?ooooo00?o0000ool00?oo00005?oo00001?l0003oooooooooool@4103ooooo`05oa0@
4?ooooooooooooooool@41000oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00=?ooooo00?o0000ool00?oo00005?oo00001?l0003oooooooooool00003ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`06ooooo`Co0000oooooolHoooo
o`00doooool00ol0003oo`00ool0000Dool00004o`000?ooooooooooo`0000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooolI
ooooo`00doooool00ol0003oo`00ool0000Dool00004o`000?oooooooooooa0@40?ooooo00Go410@
oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooo
oolIooooo`00doooool00ol0003oo`00ool0000Dool00008o`000?ooooooooooogMgMonHV9Sooooo
oiRHV?mgMgL3ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Cooooo`03o`000?oo003oo`0001Coo`0000So0000ooooooooooook^k^oc8b<_l0003o
<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo
6Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`;o0000oooooolJooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ooooooooool0oooo
oolIooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000
ooooooooool0oooooolIooooo`00dooooolHo`0001Oooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000
oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000
oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003Vooooo`Co000000Go410@ooooooooooooooooodA4A002o`000009oc8b
<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolI
ooooo`00j?ooool00ol0003oooooooooo`06ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooo
oonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003ooooooooo
o`07ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool01_ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00Kooooo00GoMgMgoc8b<_oooooooooo
o`000003ooooo`03o`000?oooooooooo00Kooooo1?l0003ooooooaSooooo003Xooooo`03o`000?oo
oooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool0
00002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000oooooooo
ool0oooooolIooooo`00j?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo
00?oEEEEofIVI_l000001Oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003Uooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo1?l0
003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo
003Xooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`05o`00
0?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooo
ooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05o`000?nj^[[ooooooiRH
V?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00So
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00iOooool5o`0000Cooooo00GoA4A4o`000?l0003o
<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool02OmgMgOo<S8boooooooooooo
MgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?o
V9RHob4Q8Oo^k^h02Oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00Kooooo
1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^00Oooooo00GoMgMgoc8b<_oooooooooo
o`000003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?oo
ool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooo
oooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00jOooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@4008ooooo`03
o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03
o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooo
oolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooo
oolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnH
V9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oa0@4?nj
^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00Go0000oooooooo
oooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`06
ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?oZJVYoa0@4?ooool00_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`Co0000oooo
oolHooooo`00ioooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo00000?oooooo9?ooool00>Sooooo00?o^[Zjob4Q8Oooool00_oo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@403oooooobCo
oooo003Uooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`3oooooobCooooo003Uooooo`05ojVYZOl@413o0000
oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP3oooooobCooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooo
oaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003gooooo`;o0000
2oooool00ol0003o^[Zjooooo`0<ooooo`;o0000ooooool9ooooo`00moooool00ol0003ooooooooo
o`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o
0000ooooo`;o000000?o410@ooooooooool00oooool01?l0003oooooooooooooool2o`0000;ooooo
0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03
o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`0:
o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo00?oc<c<o`000?l@4100
1?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000ooooooooool0ooooool7ooooo`00
k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool01?oMgMgo
0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7oooo
o`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool01?o^
k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7
ooooo`00k?ooool5o`0000Kooooo00?o0000ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb<S8;
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0
003ooooooooooooooooo000000Kooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00002?oo
ool00ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>_ooooo00Co410@o`000?l0003ooooo0_l0
00000ol@413oooooooooo`03ooooo`;o00004_ooool00ol0003oooooooooo`05ooooo`;o0000oooo
ool9ooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00
\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .08446 L
.4 .08446 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .08446 L
.4 .08446 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .21631 L
.45 .21631 L
.45 0 L
F
0 g
.4 0 m
.4 .21631 L
.45 .21631 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .18541 L
.5 .18541 L
.5 0 L
F
0 g
.45 0 m
.45 .18541 L
.5 .18541 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .22455 L
.55 .22455 L
.55 0 L
F
0 g
.5 0 m
.5 .22455 L
.55 .22455 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .11743 L
.6 .11743 L
.6 0 L
F
0 g
.55 0 m
.55 .11743 L
.6 .11743 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .08858 L
.65 .08858 L
.65 0 L
F
0 g
.6 0 m
.6 .08858 L
.65 .08858 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .04944 L
.7 .04944 L
.7 0 L
F
0 g
.65 0 m
.65 .04944 L
.7 .04944 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .03708 L
.75 .03708 L
.75 0 L
F
0 g
.7 0 m
.7 .03708 L
.75 .03708 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .02472 L
.8 .02472 L
.8 0 L
F
0 g
.75 0 m
.75 .02472 L
.8 .02472 L
.8 0 L
.75 0 L
s
1 0 0 r
.8 0 m
.8 .00206 L
.85 .00206 L
.85 0 L
F
0 g
.8 0 m
.8 .00206 L
.85 .00206 L
.85 0 L
.8 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`006Ol0001Eooooo`04ob4Q8OmgMgOoMgMgoc8b<Qgo
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo06[ooooo0_l00002ooooo`;o00007?ooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0S?ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0S?ooool00;_ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0S?ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0S?ooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
S?ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0S?ooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0S?ooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0S?ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0S?ooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool001So0000S_ooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2S
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`006Ol0002Uooooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`006?l0
002mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Boooo
o`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3B
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00
^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`3Booooo`00^ooooolIo`0001Koo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool001So0000e?ooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yoooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Y
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo000Io`000>_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2oooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo
0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3o
ooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2oooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo
0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3o
ooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo
00?o0000ool00?oo00005?oo000Io`0001Koo`0000?o0000ooooooooool0ooooool2ooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0oooo
ool2ooooo`00doooool00ol0003oo`00ool0000Dool00008o`000?ooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00002?l0003o
oooooooooomgMgOoV9RHoooooonHV9SoMgMg0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000Co0000oooooooooooo410@0oooool01Ol@413ooooooooooooooooo410@00?o
oooo00?o410@ooooooooool01_ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oo
oooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00001?l0003oooooooooool00003ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`06ooooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00004
o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000Co0000oooooooooooo410@0oooool01Ol@413ooooooooooooo
oooo410@00?ooooo00?o410@ooooooooool01_ooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00002?l0003ooooooooooomg
MgOoV9RHoooooonHV9SoMgMg0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003CoooooaSo00000_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0ooooool2ooooo`00ooooool3oooooaSo0000ooooool4ooooo`00ooooool3
ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003Vooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooooooo
ool0oooooolIooooo`00j?ooool00ol0003oooooooooo`06ooooo`09ogMgMolb<S;ooooooooooomg
MgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0
003oooooooooo`07ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool01_ooool0
0ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00Kooooo00GoMgMgoc8b
<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo1?l0003ooooooaSooooo003Xoooo
o`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?oooooo
ooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00Sooooo00?o
0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Kooooo00?oEEEEofIVI_l000001Oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJ
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003Uooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00onHV9So8B4Q
onk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@
00Sooooo1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3o
oooooaWooooo003Xooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Y
ooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo
00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05o`000?nj
^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOooool5o`0000Cooooo00GoA4A4
o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool02OmgMgOo<S8b
ooooooooooooMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0>Kooooo00?oV9RHob4Q8Oo^k^h02Oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooo
oooo00Kooooo1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^00Oooooo00GoMgMgoc8b
<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooolI
ooooo`00j?ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool0
1Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00jOooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@
4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go0000okZj^_ooooooV9RHoa0@
4004ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co0000
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
iOooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uoooo
o`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00Go
0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?oZJVYoa0@4?ooool0
0_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008oooo
o`Co0000oooooolHooooo`00ioooool00ol@413o0000okZj^P03ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo00000?oooooo9?ooool00>Sooooo00?o^[Zjob4Q
8Oooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
403oooooobCooooo003Uooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`3oooooobCooooo003Uooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP3oooooobCooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00
oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooo
oaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003g
ooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o0000ooooool9ooooo`00moooool00ol0
003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`3oooooo`Oooooo003[ooooo`04
oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool01?l0003oooooooooooooool2
o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj
^P04ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`00
0006ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo00?oc<c<
o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000ooooooooool0oooo
ool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_oo
ool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
0_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0ooooool7ooooo`00k?ooool5o`0000Kooooo00?o0000ooooooooool00_ooool01?lQ8B7oMgMg
ogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00
k?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooooooo0_l00002oooo
o`;o00002?ooool00ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool0ooooool7oooo
o`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>_ooooo00Co410@o`000?l0
003ooooo0_l000000ol@413oooooooooo`03ooooo`;o00004_ooool00ol0003oooooooooo`05oooo
o`;o0000ooooool9ooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooo
oolOooooo`00\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .18953 L
.4 .18953 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .18953 L
.4 .18953 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .23279 L
.45 .23279 L
.45 0 L
F
0 g
.4 0 m
.4 .23279 L
.45 .23279 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .17099 L
.5 .17099 L
.5 0 L
F
0 g
.45 0 m
.45 .17099 L
.5 .17099 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .16481 L
.55 .16481 L
.55 0 L
F
0 g
.5 0 m
.5 .16481 L
.55 .16481 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .21837 L
.6 .21837 L
.6 0 L
F
0 g
.55 0 m
.55 .21837 L
.6 .21837 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .02472 L
.65 .02472 L
.65 0 L
F
0 g
.6 0 m
.6 .02472 L
.65 .02472 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .01648 L
.7 .01648 L
.7 0 L
F
0 g
.65 0 m
.65 .01648 L
.7 .01648 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .01236 L
.75 .01236 L
.75 0 L
F
0 g
.7 0 m
.7 .01236 L
.75 .01236 L
.75 0 L
.7 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo0;;ooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Oooooo00?o0000ooooooooool0/oooool00<Cooooo1_l00002ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002oooool5o`000;Cooooo
003<ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP15ooooo`05o`00
0?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP0Iooooo`05o`000?oooooooooooooo
ool000002oooool01?m4A4CogMgMooooool0002eooooo`00c?ooool01Ol0003ooooooooooooooooo
000000kooooo00?oMgMgofIVI_ooool0A?ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool06?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo
0000]Oooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co00000;Gooooo003<ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?ok^k^odA4A?l00000]Oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`0AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c00Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo
0000ooooo`2dooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolO
ooooo`00oooooooooooooaoooooo003ooooooocooooo0_l00002ooooo`;o00007?ooool00?oooooo
o?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAcooooo003ooooooogooooo00CogMgMo`000?l@
413oc<c<7Oooool001Ooooooool0003Go`0000oooooo00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo08;o
oooo00Co8B4QogMgMomgMgOo<S8b7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo087ooooo0_l00002ooooo`;o00007?ooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo000Io`000:Gooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`006?l0002mooooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`006?l0003Dooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0jOooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0>Wooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOoo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0>Wooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`3Yooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0jOooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0>Wooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00;_ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00
^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
jOooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0>Wooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`3Yooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0jOooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0>Wooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00^oooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00;_ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yoooo
o`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0jOooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0>Wooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`3Yooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0jOooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Y
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0jOooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0>Wooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`3Yooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0jOooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`3Yooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0jOooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0>Wooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`3Yooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wo
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`3Yooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0jOooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0>Wooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0>Wooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`3Yooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0jOooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0>Wooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`006?l0000Gool00003
o`000?oooooooooo0>Wooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`3Yooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0jOooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool001Wo00005_ooool00ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0>Wooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`3Yooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool05Oooool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0jOooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ooooooooool05?ooool00ol0003oo`00
ool0000Eool00003o`000?oooooooooo0>Wooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Cooooo00?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oooooooooo`0D
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00;_ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000oooo
ooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`;o
00005Oooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00^ooo
oolIo`0001Koo`0000?o0000ooooooooool05Oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo
01Gooooo00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo
0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003o
ooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Cooooo
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0
000Dool00008o`000?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02?ooool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00002?l0003ooooooooooomgMgOo
V9RHoooooonHV9SoMgMg0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000oooooooo
ool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000Co0000oooooooooooo410@0oooool01Ol@413ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00001?l0003o
ooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`06
ooooo`Co00004oooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000Co0000oooooooooooo00000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo0000
1?l0003oooooooooool@4103ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413ooooo
ooooo`06ooooo`03o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00008o`000?ooooooooooogMgMonHV9So
oooooiRHV?mgMgL3ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`0D
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool0
0?oo00005?oo00002?l0003oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003
o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0DoooooaWo0000joooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`;o
0000oooooolJooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo
00?o0000ooooooooool0oooooolIooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0oooooolIooooo`00dooooolHo`0001Oooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`Co000000Go410@oooooooooooo
ooooodA4A002o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o
0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`06ooooo`09ogMgMolb<S;o
oooooooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00
j?ooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@oooooooo
ool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00Kooooo
00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo1?l0003ooooooaSo
oooo003Xooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05
o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@
00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Kooooo00?oEEEEofIVI_l000001Oooool4o`0000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o
0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003Uooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Go
oooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooo
oooooooo410@00Sooooo1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Xooooo`03ogMgMomVIVKooooo00;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Yooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo
410@00?ooooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Uoooo
o`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJ
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJ
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJ
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOooool5o`0000Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool0
0ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool0
2OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^k^h02Oooool01?l0003oooooooooool@4103ooooo`03
oa0@4?oooooooooo00Kooooo1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^00Oooooo
00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooolIooooo`00j?ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`00_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIoooo
o`00jOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooo
oooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go0000okZj^_oo
ooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08
ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004
ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_oo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_oo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00iOooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWo
oooo003Uooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0>Wooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?oZJVY
oa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000008ooooo`Co0000oooooolHooooo`00ioooool00ol@413o0000okZj^P03ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo00000?oooooo9?ooool00>Sooooo
00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooooooooa0@403oooooobCooooo003Uooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`3oooooobCooooo003U
ooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP3oooooobCooooo003ooooooooooooo7oooool00?oooooooooo
oolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00
oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooo
oaoooooo003gooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o0000ooooool9ooooo`00
moooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`3oooooo`Oooooo
003[ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool01?l0003ooooo
ooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0
003oA4A4okZj^P04ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000oooooooo
ooooooooo`000006ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?o
oooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000oooo
ooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool00_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0ooooool7ooooo`00k?ooool5o`0000Kooooo00?o0000ooooooooool00_ooool0
1?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooo
ool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooooooo
0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool0
ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>_ooooo00Co
410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`;o00004_ooool00ol0003ooooo
ooooo`05ooooo`;o0000ooooool9ooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool0
0?oooooooooooolOooooo`00\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.35 -0.0125 -12 -9 ]
[.35 -0.0125 12 0 ]
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.45 -0.0125 -12 -9 ]
[.45 -0.0125 12 0 ]
[.5 -0.0125 -39.75 -12.5 ]
[.5 -0.0125 39.75 0 ]
[.55 -0.0125 -9 -9 ]
[.55 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.65 -0.0125 -9 -9 ]
[.65 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.35 0 m
.35 .00625 L
s
[(-0.3)] .35 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.45 0 m
.45 .00625 L
s
[(-0.1)] .45 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -39.75 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2.77556) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-17) show
grestore
.55 0 m
.55 .00625 L
s
[(0.1)] .55 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.65 0 m
.65 .00625 L
s
[(0.3)] .65 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .16275 L
.4 .16275 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .16275 L
.4 .16275 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .20395 L
.45 .20395 L
.45 0 L
F
0 g
.4 0 m
.4 .20395 L
.45 .20395 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .12567 L
.5 .12567 L
.5 0 L
F
0 g
.45 0 m
.45 .12567 L
.5 .12567 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .17099 L
.55 .17099 L
.55 0 L
F
0 g
.5 0 m
.5 .17099 L
.55 .17099 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .29254 L
.6 .29254 L
.6 0 L
F
0 g
.55 0 m
.55 .29254 L
.6 .29254 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .07416 L
.65 .07416 L
.65 0 L
F
0 g
.6 0 m
.6 .07416 L
.65 .07416 L
.65 0 L
.6 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00?oooooo4Oooool2onk^kP?ooooo0_o^k^koooooo`Oo
oooo003Iooooo`Go00001Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01Oooool00ol0003ok^k^
ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd00oooool01Om4A4Co0000o`000?lb<S;ogMgM
00;ooooo00Gok^k^oc8b<_l0003o410@olc<c002ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEE
onk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^k_Oooooo003Ioooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01Oooool0
0omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Gooooo00WoMgMgoc8b<_oooooooooooeEE
EOmgMgOooooooiRHV?lQ8B400oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg0?Oooooo003Aooooo`Ko00000oooool00onH
V9So8B4Qonk^kP0>ooooo`03ojVYZOmEEEGooooo00Gooooo00?oZJVYoeEEEOooool02?ooool00ol0
003oooooooooo`05ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool0
0ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
403gooooo`00]Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05oiRHV?l@
413o0000oc8b<_o<c<`00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B43ooooo`03
oiRHV?l0003o000000?o00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Co8B4Qoooo
oolQ8B7o8B4Q1?ooool00olQ8B7o0000o`000002o`000006oa0@4?oooooooooooooooomgMgOo<S8b
1_ooool04OmgMgOo<S8boooooooooooo0000oiRHV?ooooooV9RHob4Q8Oo^k^ko<S8bo`000?l_;boo
Cdm?omgMgOmEEEGok^k^00;ooooo0_lQ8B42ooooo`03o`000?oooooooooo00Co000000Oo410@oooo
ool0003o<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00000_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05oiRHV?l@413o0000oc8b<_o<c<`0c?ooool00;Gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Om6ATKo3@d=onk^k_oo
ooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`04oeEEEOo<c<co8B4Qob4Q8@Co
oooo00CoEEEEolc<c?oooooo00000_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c002ooooo`0?o`000?mEEEGo0000oa0@4?o<c<coMgMgoiRHV?o^k^ko<S8b
ofm_Koooooook^k^oeEEEOo^k^kooooo00;o8B4Q0_ooool00ol0003oooooooooo`02ooooo`09o`00
0?ooooooooooooooool0003oV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oa0@
4?nj^[[oooooogMgMolb<S80c?ooool00:gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@
41002_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400;ooooo`Ko00000_ooool01Ol@
413ooooooooooooooooo410@00?ooooo00?oZJVYogMgMoooool01Oooool01?nYZJWoMgMgooooool0
0002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00omEEEGoQhN7oooo
o`02ooooo`05oa0@4?ooooook^k^onk^k_l@41000_ooool2onk^kPGooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool02_ooool00onHV9So
8B4Qonk^kP03ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`3:oooo
o`00]Oooool01Ol0003ooooooooooooooooo000000kooooo00GoZJVYoa0@4?ooooooooooo`000003
ooooo`03o`000?oooooooooo00Kooooo00So0000okZj^_ooooooV9RHoa0@4?nHV9So8B4Qonk^kP?o
oooo00Ko0000ooooooooooooooooo`000?l@4103ooooo`05oc8b<_ooooooooooooooool@41000ooo
ool00olb<S;oooooo`000002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?oo
ool00ooMgMgo410@oiRHV002ooooo`05o`000?ooooooooooooooool000002Oooool00ol0003ooooo
ooooo`02ooooo`05o`000?nHV9SooooooiRHV?l000000oooool00ol0003oooooooooo`0;ooooo`03
oiRHV?lQ8B7ok^k^00;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ojVYZOl@413ooooo
0<_ooooo002eooooo`05o`000?ooooooooooooooool000003Oooool00ol@413o0000okZj^P02oooo
o`05o`000?ooooooooooooooool000002?ooool02?nHV9So410@o`000?lQ8B7oc<c<oooooomgMgOo
IVIV0oooool01?l0003oooooooooooooool6o`0000?ooooo1Ol000001?oooooo0000ooooooooool4
o`0000Cooooo1?l00004ooooo`05olc<c?m4A4Co0000oa0@4?l000000oooool00ol0003ooooooooo
o`05ooooo`03oeEEEOmVIVKo000000Cooooo00Go0000oc8b<_l0003o<S8bo`000003ooooo`03o`00
0?oooooooooo00;ooooo0ol00002ooooo`03o`000?oooooooooo00;ooooo00GoMgMgofIVI_oooooo
ooooo`000003ooooo`03o`000?oooooooooo00_ooooo00?o410@o`000?nj^[X0c?ooool00;Gooooo
00Go410@oooooooooooooooooa0@400>ooooo`05okZj^_lQ8B7oooooooooool@41000oooool00ol@
413oooooooooo`0=ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0<
ooooo`03o`000?oooooooooo01Cooooo00Go410@oooooooooooooooooa0@400>ooooo`05o`000?oo
ooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`05o`000?ooooooooooooooool0
00001Oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00cooooo00?o^[Zjob4Q
8Oooool0boooool00;Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9Sooooo
okZj^_l000000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RH
oa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`0Dooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03_ooool01ol0003oooooooooooooooooMgMgoiRHV?ooool01?l0
0003ooooo`03o`000?oooooooooo00;ooooo0_l000001?nj^[[ooooooiRHV?l@4102ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol@413oV9RHoooooonj^[[o00000<cooooo002eooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000005_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo00?oEEEEofIVI_l000000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000
ooooooooool00_ooool01_l0003oV9RHoa0@4?l0003o8B4Qolc<c0;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0c?ooool00?oooooo<?ooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo0>Gooooo003ooooooboooooo0_l00002ooooo`Co
0000ioooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003oooooooWooooo0_l00002
ooooo`;o00007oooool00?oooooonOooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAoooooo003o
oooooo[ooooo00CogMgMo`000?l@413oc<c<8?ooool001_oooooool0003@o`0000oooooo00Cok^k^
ob4Q8Ol@413ok^k^8?ooool00;cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0[oooool01?lQ8B7oMgMgogMgMolb
<S8Pooooo`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`2^ooooo`;o00000_ooool2o`0001oooooo002loooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0=?ooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=?ooooo002looooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0=?ooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=?ooooo002looooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0=?ooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0=?ooooo002looooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=?o
oooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0=?ooooo002looooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=?ooooo002l
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0=?ooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=?ooooo002looooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0=?ooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=?ooooo002looooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0=?ooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0=?ooooo002looooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0=?ooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo0=?ooooo002looooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=?ooooo
002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0=?ooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=?ooooo002loooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0=?ooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=?ooooo002looooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0=?ooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=?ooooo002looooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0=?ooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0=?ooooo002looooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=?o
oooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0=?ooooo002looooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=?ooooo002l
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0=?ooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=?ooooo002looooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0=?ooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo000Ho`000=Gooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3Zooooo`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0j_ooool00;cooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0>[ooooo002looooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Zooooo`00_?ooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0j_ooool00;cooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0>[ooooo002l
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Z
ooooo`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0j_ooool00;cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0>[ooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`3Zooooo`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0j_ooool00;cooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0>[ooooo002looooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Zooooo`00_?ooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0j_ooool00;cooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0>[ooooo
002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3Zooooo`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0j_ooool00;cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0>[ooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`3Zooooo`00_?ooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0j_ooool00;cooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0>[ooooo002looooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Zooooo`00_?ooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`006?l0000Fool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0j_ooool00;cooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo0>[ooooo002looooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Zooooo`00_?ooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0j_ooool00;cooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0>[ooooo002loooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0Doooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Zoooo
o`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool05?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0j_ooool00;cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0>[ooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3Zooooo`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0j_ooool00;cooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0>[ooooo002looooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Zooooo`00_?ooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0j_ooool00;cooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0>[ooooo002l
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0D
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Z
ooooo`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0j_ooool00;cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0>[ooooo002loooooaSo00005ooo00000ol0003oooooooooo`0Dooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Zooooo`00dooo
ool00ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0>[ooooo003Cooooo`03o`000?oo003o
o`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0j_ooool00=?ooooo00?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3Zooooo`00doooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo01Co
oooo6?l0000Fool00003o`000?oooooooooo0>[ooooo003Cooooo`03o`000?oo003oo`0001Goo`00
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0j_ooool00=?ooooo00?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3Zooooo`00doooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000
ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0>[ooooo003Coooo
o`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0j_ooool00=?ooooo00?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Cooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`3Zooooo`00doooool00ol0003oo`00ool0000Eool00003o`00
0?oooooooooo01Cooooo00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0>[ooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?oo
ool2o`0001Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Zooooo`00doooool0
0ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ooooooooool05?ooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0>[ooooo003Cooooo`03o`000?oo003oo`00
01Goo`0000?o0000ooooooooool05?ooool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0j_ooool00=?ooooo00?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`3Zooooo`00doooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo
00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0>[ooooo
003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0j_ooool00=?ooooo00?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Cooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`3Zooooo`00doooool00ol0003oo`00ool0000Eool0
0007o`000?ooooook^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2?ooool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
j_ooool00=?ooooo00?o0000ool00?oo00005Ooo00001ol0003oooooogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool05?ooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo0>[ooooo003CoooooaWo000000?ooooooa0@4?oo
ool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01_ooool4o`00
01?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Zooooo`00j?ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000Sooooo00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0>[ooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0j_ooool00>Sooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Zooooo`00j?oo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Sooooo00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo0>[ooooo003Vooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0j_ooool00?oooooo0oooool00ol0003o
ooooooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0j_ooool00?oooooo
0oooool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
j_ooool00?oooooo0oooool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0j_ooool00?oooooo0oooool00ol0003oooooooooo`0Dooooo`03o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0j_ooool00?oooooo0oooool2o`0001Gooooo00?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3Zooooo`00ooooool3ooooo`03o`000?oooooooooo01Co
oooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Zooooo`00ooooool3ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Zooooo`00oooo
ool3ooooo`03o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3Zooooo`00ooooool3ooooo`03o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`3Zooooo`00ooooool3ooooo`03o`000?oooooooooo01Cooooo00?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3Zooooo`00ooooool3ooooo`03o`000?oooooooooo01Co
oooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Zooooo`00ooooool3ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Zooooo`00oooo
ool3ooooo`03o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3Zooooo`00ooooool3ooooo`03o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`3Zooooo`00ooooool3ooooo`;o00005Oooool00ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0>[ooooo003oooooo`?ooooo00?o0000ooooooooool05?ooool00ol0003o
o`00ool0000Dool00003o`000?oooooooooo0>[ooooo003oooooo`?ooooo00?o0000ooooooooool0
5?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0>[ooooo003oooooo`?ooooo00?o
0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0>[ooooo003o
ooooo`?ooooo00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0>[ooooo003oooooo`?ooooo00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0>[ooooo003oooooo`?ooooo00?o0000ooooooooool05?ooool00ol0003o
o`00ool0000Dool00003o`000?oooooooooo0>[ooooo003oooooo`?ooooo00?o0000ooooooooool0
5?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0>[ooooo003oooooo`?ooooo00?o
0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0>[ooooo003o
ooooo`?ooooo0_l0000Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0j_ooool0
0?oooooo0oooool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0j_ooool00?oooooo0oooool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0j_ooool00?oooooo0oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0j_ooool00?oooooo0oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0j_ooool00?oooooo0oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0j_ooool0
0?oooooo0oooool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0j_ooool00?oooooo0oooool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0j_ooool00?oooooo0oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0j_ooool00?oooooo0oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0j_ooool00?oooooo0oooool2
o`0001Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Zooooo`00ooooool3oooo
o`03o`000?oooooooooo01Cooooo6?l0003/ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`Co000000Go410@oooooooo
ooooooooodA4A002o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo
00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`06ooooo`09ogMgMolb
<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00j?ooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@oooo
ooooool01_ooool4o`000?oooooo6?ooool00>Sooooo00?o0000ooooooooool01_ooool01OmgMgOo
<S8boooooooooooo000000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooo
oaWooooo003Xooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002oooo
o`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xoooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo
410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00>Kooooo00?oEEEEofIVI_l000001Oooool4o`0000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_oo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_oo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00iOooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^
k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008
ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Oooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`Co0000oooo
oolHooooo`00j?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00jOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[Zj
oooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo1Ol00004ooooo`05odA4A?l0
003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooooooo
ool0oooooolIooooo`00iOooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00WoMgMgoc8b<_oo
ooooooooogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003V
ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00Co0000oooooooooooo410@0oooool00ol@413ooooooooo
o`06ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP07ooooo`05ogMgMolb<S;o
ooooooooool000000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Sooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go
0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@4100
1?ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2
o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2
o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Uooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Wooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooo
ooooool@41000oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0>Sooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000008ooooo`Co0000oooooolHooooo`00ioooool00ol@413o0000okZj^P03
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo00000?oooooo
9?ooool00>Sooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooooooooa0@403oooooobCooooo003Uooooo`05oa0@4?nHV9SooooookZj^_l0
00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`3o
ooooobCooooo003Uooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP3oooooobCooooo003ooooooooooooo7ooo
ool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooo
oooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOoooo
o`00oooooooooooooaoooooo003gooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o0000
ooooool9ooooo`00moooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003ooooooooo
o`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00ooo
ool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo
00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo
00Go0000ooooooooooooooooo`000006ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj
^[[o0000omgMg@?ooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Co
oooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool5o`0000Kooooo00?o0000oooo
ooooool00_ooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000
oooooooooooooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Gooooo00?o
0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1ooo
ool00>_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`;o00004_oo
ool00ol0003oooooooooo`05ooooo`;o0000ooooool9ooooo`00oooooooooooooaoooooo003ooooo
oooooooo7oooool00?oooooooooooolOooooo`00\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.11695, -22.4749, \
0.0054076, 1.31245}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.35 -0.0125 -12 -9 ]
[.35 -0.0125 12 0 ]
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.45 -0.0125 -12 -9 ]
[.45 -0.0125 12 0 ]
[.5 -0.0125 -39.75 -12.5 ]
[.5 -0.0125 39.75 0 ]
[.55 -0.0125 -9 -9 ]
[.55 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.65 -0.0125 -9 -9 ]
[.65 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.35 0 m
.35 .00625 L
s
[(-0.3)] .35 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.45 0 m
.45 .00625 L
s
[(-0.1)] .45 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -39.75 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2.77556) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-17) show
grestore
.55 0 m
.55 .00625 L
s
[(0.1)] .55 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.65 0 m
.65 .00625 L
s
[(0.3)] .65 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .05562 L
.4 .05562 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .05562 L
.4 .05562 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .12155 L
.45 .12155 L
.45 0 L
F
0 g
.4 0 m
.4 .12155 L
.45 .12155 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .13185 L
.5 .13185 L
.5 0 L
F
0 g
.45 0 m
.45 .13185 L
.5 .13185 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .18541 L
.55 .18541 L
.55 0 L
F
0 g
.5 0 m
.5 .18541 L
.55 .18541 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .20395 L
.6 .20395 L
.6 0 L
F
0 g
.55 0 m
.55 .20395 L
.6 .20395 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .27606 L
.65 .27606 L
.65 0 L
F
0 g
.6 0 m
.6 .27606 L
.65 .27606 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .05562 L
.7 .05562 L
.7 0 L
F
0 g
.65 0 m
.65 .05562 L
.7 .05562 L
.7 0 L
.65 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00?oooooo4Oooool2onk^kP?ooooo0_o^k^koooooo`Oo
oooo003Iooooo`Go00001Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01Oooool00ol0003ok^k^
ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd00oooool01Om4A4Co0000o`000?lb<S;ogMgM
00;ooooo00Gok^k^oc8b<_l0003o410@olc<c002ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEE
onk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^k_Oooooo003Ioooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01Oooool0
0omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Gooooo00WoMgMgoc8b<_oooooooooooeEE
EOmgMgOooooooiRHV?lQ8B400oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg0?Oooooo003Aooooo`Ko00000oooool00onH
V9So8B4Qonk^kP0>ooooo`03ojVYZOmEEEGooooo00Gooooo00?oZJVYoeEEEOooool02?ooool00ol0
003oooooooooo`05ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool0
0ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
403gooooo`00]Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05oiRHV?l@
413o0000oc8b<_o<c<`00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B43ooooo`03
oiRHV?l0003o000000?o00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Co8B4Qoooo
oolQ8B7o8B4Q1?ooool00olQ8B7o0000o`000002o`000006oa0@4?oooooooooooooooomgMgOo<S8b
1_ooool04OmgMgOo<S8boooooooooooo0000oiRHV?ooooooV9RHob4Q8Oo^k^ko<S8bo`000?l_;boo
Cdm?omgMgOmEEEGok^k^00;ooooo0_lQ8B42ooooo`03o`000?oooooooooo00Co000000Oo410@oooo
ool0003o<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00000_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0/oooool00;Go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo
<S8b00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Om6ATKo3@d=onk^
k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`04oeEEEOo<c<co8B4Qob4Q
8@Cooooo00CoEEEEolc<c?oooooo00000_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c002ooooo`0?o`000?mEEEGo0000oa0@4?o<c<coMgMgoiRHV?o^k^ko
<S8bofm_Koooooook^k^oeEEEOo^k^kooooo00;o8B4Q0_ooool00ol0003oooooooooo`02ooooo`09
o`000?ooooooooooooooool0003oV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
oa0@4?nj^[[oooooogMgMolb<S800_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47
ooooo`03o`000?oooooooooo0;Cooooo002]ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo
410@00[ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41002oooool6o`0000;ooooo00Go
410@oooooooooooooooooa0@4003ooooo`03ojVYZOmgMgOooooo00Gooooo00CoZJVYogMgMooooooo
00000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?oEEEEohN7Qooo
ool00_ooool01Ol@413oooooonk^k_o^k^ko410@00;ooooo0_o^k^h5ooooo`03o`000?oooooooooo
00;ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RH
ob4Q8Oo^k^h00oooool01Ol@413ooooooooooooooooo410@00oooooo00Co0000oooooooooooo410@
0oooool00ol@413oooooooooo`09ooooo`Go0000]Oooool00;Gooooo00Go0000oooooooooooooooo
o`00000>ooooo`05ojVYZOl@413oooooooooool000000oooool00ol0003oooooooooo`06ooooo`08
o`000?nj^[[ooooooiRHV?l@413oV9RHob4Q8Oo^k^h3ooooo`06o`000?ooooooooooooooool0003o
410@0oooool01Olb<S;ooooooooooooooooo410@00?ooooo00?o<S8booooool000000_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?ogMgMoa0@4?nHV9P00_ooool01Ol0
003ooooooooooooooooo000000Wooooo00?o0000ooooooooool00_ooool01Ol0003oV9RHoooooonH
V9So000000?ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP02ooooo`05o`000?oo
ooooooooooooool000003_ooool01OnYZJWo410@oooooooooooo000000?ooooo00?o0000oooooooo
ool02Oooool01?m4A4CogMgMooooool0002fooooo`00]Oooool01Ol0003ooooooooooooooooo0000
00gooooo00?o410@o`000?nj^[X00_ooool01Ol0003ooooooooooooooooo000000Sooooo00SoV9RH
oa0@4?l0003o8B4Qolc<c?ooooooMgMgofIVIP?ooooo00Co0000oooooooooooooooo1_l00003oooo
o`Go000000Coooooo`000?oooooooooo1?l00004ooooo`Co00001?ooool01Oo<c<coA4A4o`000?l@
413o000000?ooooo00?o0000ooooooooool01Oooool00omEEEGoIVIVo`000004ooooo`05o`000?lb
<S;o0000oc8b<_l000000oooool00ol0003oooooooooo`02ooooo`?o00000_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMomVIVKoooooooooool000000oooool00ol0003oooooooooo`0;ooooo`03
oa0@4?l0003o^[Zj00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`000;Kooooo002eooooo`05oa0@4?ooooooooooooooool@41003_ooool01Onj^[[o8B4Qoooooooo
oooo410@00?ooooo00?o410@ooooooooool03Oooool01Ol0003ooooooooooooooooo410@00?ooooo
00?o410@ooooooooool03?ooool00ol0003oooooooooo`0Dooooo`05oa0@4?ooooooooooooooool@
41003_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool00oooool01Ol0
003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo410@0oooool00ol@413ooooooooo
o`0<ooooo`05okZj^_lQ8B7oooooooooool@41000oooool00ol@413oooooooooo`0:ooooo`03ogMg
Moo<c<co00000;Kooooo002eooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413oV9RH
oooooonj^[[o000000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool05?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00Oo0000ooooooooooooooooogMgMonHV9Sooooo
00Co00000oooool00ol0003oooooooooo`02ooooo`;o000000Co^[ZjoooooonHV9So410@0_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oiRHV?oooooo^[Zjo`000002ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00002fooooo`00]Oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@02ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`03oeEEEOmVIVKo000001Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03
oeEEEOmVIVKo000000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo
00;ooooo00Ko0000oiRHV?l@413o0000ob4Q8Oo<c<`2ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool01OnYZJWo410@o`000?l@413oZJVY00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=oooo
o`03ogMgMol0003ooooo0;Gooooo003ooooooc3ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`3Uooooo`00ooooool_ooooo`;o00000_ooool4o`000>Oooooo003ooooooooooooo
7oooool00?oooooooooooolOooooo`00oooooooiooooo`;o00000_ooool2o`0001oooooo003ooooo
ooWooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMdOooooo`00ooooooojooooo`04omgMgOl0003o
410@olc<c23ooooo000Koooooooo0000d?l0000?ooooo`04onk^k_lQ8B7o410@onk^kR3ooooo002l
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0V?ooool01?lQ8B7oMgMgogMgMolb
<S8Pooooo`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo09Oooooo0_l00002
ooooo`;o00007oooool00;cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2loooo
o`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;cooooo002looooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0_?ooool00;cooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2looooo`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0;cooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0_?ooool00;co
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2looooo`00_?ooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0;cooooo002looooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0_?ooool00;cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2l
ooooo`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;cooooo002looooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0_?ooool00;cooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`2looooo`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0;cooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0_?ooool0
0;cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2looooo`00_?ooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo0;cooooo002looooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0_?ooool00;cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`2looooo`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;cooooo002loooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0_?ooool00;cooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2looooo`00_?ooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0;cooooo002loooooaSo00005ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool001So0000__oo
ool00=?ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0=?ooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3Cooooo`00doooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0doooool00=?ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0=?ooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`3Cooooo`00doooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0doooool00=?ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=?ooooo003Cooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Cooooo`00
doooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
doooool00=?ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0=?ooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`3Cooooo`00doooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0doooool00=?ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo0=?ooooo003Cooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Cooooo`00doooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0doooool00=?ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=?ooooo003Coooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Coooo
o`00doooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0doooool00=?ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0=?ooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3Cooooo`00doooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0doooool00=?ooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0=?ooooo003Cooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Cooooo`00doooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0doooool00=?ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=?ooooo003C
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3C
ooooo`00doooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0doooool00=?ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0=?ooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`3Cooooo`00dooooolIo`0001Koo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0dooo
ool00>_ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Cooooo`00joooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0=?ooooo003[ooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0doooool00>_ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3Cooooo`00jooooolHo`0001Koo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0=?ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0doooool0
0?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3Cooooo`00ooooool3ooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=?o
oooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0doooool00?oooooo0oooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3Cooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0=?ooooo003oooooo`?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0doooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Cooooo`00ooooool3ooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0=?ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0doooool00?oooooo0oooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`3Cooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=?ooooo003oooooo`?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0doooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Cooooo`00oooo
ool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0=?ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0doooool0
0?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3Cooooo`00ooooool3ooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=?o
oooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0doooool00?oooooo0oooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3Cooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0=?ooooo003oooooo`?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0doooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Cooooo`00ooooool3ooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0=?ooooo003oooooo`?ooooo6?l0000Fool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0doooool00?oooooo0oooool00ol0003oooooooooo`0Dooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Cooooo`00ooooool3oooo
o`03o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0=?ooooo003oooooo`?ooooo00?o0000ooooooooool05?ooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0doooool00?oooooo
0oooool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`3Cooooo`00ooooool3ooooo`03o`000?oooooooooo01Cooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=?ooooo003o
ooooo`?ooooo00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0doooool00>Kooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooooooo
ool05?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0doooool00>Sooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo01Cooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=?ooooo003Xooooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooo
ooooool@41002?ooool4o`0001?ooooo6?l0000Fool00003o`000?oooooooooo0=?ooooo003Xoooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000002?ooool00ol0003oooooooooo`0[ooooo`03o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0doooool00>Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo02_ooooo
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Cooooo`00j?ooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00So
oooo00?o0000ooooooooool0:oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0=?o
oooo003Xooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`0[ooooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0doooool00>Kooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooo
oooo02_ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Cooooo`00ooooool3oooo
o`03o`000?oooooooooo02_ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Coooo
o`00ooooool3ooooo`03o`000?oooooooooo02_ooooo00?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`3Cooooo`00ooooool3ooooo`03o`000?oooooooooo02_ooooo00?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`3Cooooo`00ooooool3ooooo`03o`000?oooooooooo02_ooooo00?o
0000ool00?oo00005?oo00000ol0003oooooooooo`3Cooooo`00ooooool3ooooo`;o0000;?ooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0=?ooooo003oooooo`?ooooo00?o0000oooo
ooooool0:oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0=?ooooo003oooooo`?o
oooo00?o0000ooooooooool0:oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0=?o
oooo003oooooo`?ooooo00?o0000ooooooooool0:oooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0=?ooooo003oooooo`?ooooo00?o0000ooooooooool0:oooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo0=?ooooo003oooooo`?ooooo00?o0000ooooooooool0:oooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0=?ooooo003oooooo`?ooooo00?o0000oooo
ooooool0:oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0=?ooooo003oooooo`?o
oooo00?o0000ooooooooool0:oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0=?o
oooo003oooooo`?ooooo00?o0000ooooooooool0:oooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0=?ooooo003oooooo`?ooooo00?o0000ooooooooool0:oooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo0=?ooooo003oooooo`?ooooo0_l0000/ooooo`03o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0doooool00?oooooo0oooool00ol0003oooooooooo`0[oooo
o`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0doooool00?oooooo0oooool00ol0003o
ooooooooo`0[ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0doooool00?oooooo
0oooool00ol0003oooooooooo`0[ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
doooool00?oooooo0oooool00ol0003oooooooooo`0[ooooo`03o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0doooool00?oooooo0oooool00ol0003oooooooooo`0[ooooo`03o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0doooool00?oooooo0oooool00ol0003oooooooooo`0[oooo
o`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0doooool00?oooooo0oooool00ol0003o
ooooooooo`0[ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0doooool00?oooooo
0oooool00ol0003oooooooooo`0[ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
doooool00?oooooo0oooool2o`0002cooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3Cooooo`00ooooool3ooooo`03o`000?oooooooooo02_ooooo00?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`3Cooooo`00ooooool3ooooo`03o`000?oooooooooo02_ooooo00?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3Cooooo`00ooooool3ooooo`03o`000?oooooooooo02_o
oooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Cooooo`00ooooool3ooooo`03o`00
0?oooooooooo02_ooooo6?l0003Eooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`Co000000Go410@oooo
ooooooooooooodA4A002o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00So
oooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`06ooooo`09ogMg
Molb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolI
ooooo`00j?ooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@
ooooooooool01_ooool4o`000?oooooo6?ooool00>Sooooo00?o0000ooooooooool01_ooool01Omg
MgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3o
oooooaWooooo003Xooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003X
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooo
oooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Kooooo00?oEEEEofIVI_l000001Oooool4o`0000?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo
6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo
6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00iOooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q
8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Oooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`Co0000
oooooolHooooo`00j?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00
jOooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003oooo
o`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o
^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo1Ol00004ooooo`05odA4
A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00iOooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00WoMgMgoc8b
<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo
003Vooooo`03oiRHV?lQ8B7ok^k^00Wooooo00Co0000oooooooooooo410@0oooool00ol@413ooooo
ooooo`06ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP07ooooo`05ogMgMolb
<S;oooooooooool000000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Sooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo
00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@
41001?ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0
003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`00
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Uooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00>Wooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo
ooooooooool@41000oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Sooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000008ooooo`Co0000oooooolHooooo`00ioooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo00000?oo
oooo9?ooool00>Sooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@403oooooobCooooo003Uooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`3oooooobCooooo003Uooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP3oooooobCooooo003ooooooooooooo
7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oo
oooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolO
ooooo`00oooooooooooooaoooooo003gooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o
0000ooooool9ooooo`00moooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003ooooo
ooooo`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool0
0oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Co
oooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo0?oooooo1oooool00>co
oooo00Go0000ooooooooooooooooo`000006ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7
Qonj^[[o0000omgMg@?ooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@
00Cooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool5o`0000Kooooo00?o0000
ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co
0000oooooooooooooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Gooooo
00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo
1oooool00>_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`;o0000
4_ooool00ol0003oooooooooo`05ooooo`;o0000ooooool9ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.11695, -22.4749, \
0.0054076, 1.31245}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.45 -0.0125 -12 -9 ]
[.45 -0.0125 12 0 ]
[.55 -0.0125 -9 -9 ]
[.55 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.65 -0.0125 -9 -9 ]
[.65 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.45 0 m
.45 .00625 L
s
[(-0.1)] .45 -0.0125 0 1 Mshowa
.55 0 m
.55 .00625 L
s
[(0.1)] .55 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.65 0 m
.65 .00625 L
s
[(0.3)] .65 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(0.5)] .75 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.4 0 m
.4 .18129 L
.45 .18129 L
.45 0 L
F
0 g
.5 Mabswid
.4 0 m
.4 .18129 L
.45 .18129 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .11331 L
.5 .11331 L
.5 0 L
F
0 g
.45 0 m
.45 .11331 L
.5 .11331 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .15451 L
.55 .15451 L
.55 0 L
F
0 g
.5 0 m
.5 .15451 L
.55 .15451 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .09683 L
.6 .09683 L
.6 0 L
F
0 g
.55 0 m
.55 .09683 L
.6 .09683 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .13803 L
.65 .13803 L
.65 0 L
F
0 g
.6 0 m
.6 .13803 L
.65 .13803 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .30902 L
.7 .30902 L
.7 0 L
F
0 g
.65 0 m
.65 .30902 L
.7 .30902 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .03708 L
.75 .03708 L
.75 0 L
F
0 g
.7 0 m
.7 .03708 L
.75 .03708 L
.75 0 L
.7 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4
o`000003oa0@4?oooooooooo01?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Ooo
ool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`00
00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb
<S;oc<c<00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000009oa0@
4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd0Voooool00<cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1oooool00ol0003oooooooooo`0Eooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S800_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`2Jooooo`00a?ooool6o`0000;ooooo00Go410@oooo
oooooooooooooa0@400:ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00kooooo00?o
0000ooooooooool05Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol@413o
oooooooooooooooo410@00oooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`09
ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool0VOoo
ool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00;ooooo00Go
0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo01Gooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000=oooo
o`03oiRHV?lQ8B7ok^k^00;ooooo00Go0000ooooooooooooooooo`00000>ooooo`05ojVYZOl@413o
ooooooooool000000oooool00ol0003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Cooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo09[ooooo003<ooooo`05o`00
0?ooooooooooooooool000003_ooool01OmgMgOoIVIVoooooooooooo000000?ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0Eooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003_ooool01OmgMgOoIVIVoooo
oooooooo000000?ooooo00?o0000ooooooooool02oooool00ol@413o0000okZj^P02ooooo`05o`00
0?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?oooooooooo
ooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<09_ooooo003<ooooo`05oa0@4?oooooo
ooooooooool@41003oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00cooooo
00?o0000ooooooooool05Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@00oooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0<ooooo`05okZj^_lQ8B7oooooooooool@41000oooool00ol@413ooooooooo
o`0:ooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`00
0?oooooooooo09gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zj
oooooonHV9So410@00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo
01Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41000_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go410@oiRHV?oooooo^[Zjo`000002ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00ol0003oooooooooo`2Mooooo`00c?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00omEEEGo
IVIVo`00000Gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`000004oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00;ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT00_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo1?l0002Looooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooo
oooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo0_l00002ooooo`;o00007?ooool0
0?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAcooooo003ooooooogooooo00CogMgM
o`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo00Cok^k^ob4Q8Ol@413ok^k^7Ooo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`22ooooo`04ob4Q8OmgMgOo
MgMgoc8b<Qgooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0POooool2
o`0000;ooooo0_l0000Looooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Soooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`006Ol0002Uooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2koooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2k
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2koooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo000Io`0001Koo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eoooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2koooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0
003oo`00ool0000Dool001Wo00005_oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eoooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2koooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooo
oooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Go
oooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`0EoooooaSo00005_oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`0/ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0;?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool0
0003o`000?oooooooooo02cooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2koooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`0/ooooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0;?ooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Ooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo02cooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooo
oooo01Gooooo6?l0000^ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
04?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ooooooooool0@oooool00ol0003o
o`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool05Oooool00ol0003oooooooooo`13ooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo04?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo0_l00014
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo01Gooooo00?o0000ooooooooool0@oooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
5Oooool00ol0003oooooooooo`13ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo04?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ooooooooool0@oooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool05Oooool00ol0003oooooooooo`13ooooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo04?ooooo00?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`2kooooo`00dooooolHo`0001Oooooo00?o0000ooooooooool0@oooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo0;_ooooo003oooooo`?ooooo00?o0000ooooooooool0@ooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003oooooo`?ooooo0_l00014
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00?oooooo0oooool00ol0
003oooooooooo`13ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00?oo
oooo0oooool00ol0003oooooooooo`13ooooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0^oooool00?oooooo0oooool00ol0003oooooooooo`13ooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0^oooool00?oooooo0oooool00ol0003oooooooooo`13ooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0^oooool00?oooooo0oooool00ol0003oooooooooo`13
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00?oooooo0oooool00ol0
003oooooooooo`13ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00>Ko
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Sooooo00?o0000ooooooooool0@oooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0;_ooooo003Xooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`13ooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00>Sooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008oooo
o`03o`000?oooooooooo04?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2koooo
o`00j?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000Sooooo1?l00012ooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0^oooool00>Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo04?ooooo00?o
0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00j?ooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo
00?o0000ooooooooool0@oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo
003Xooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`13ooooo`03o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0^oooool00>Kooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo
04?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00ooooool3ooooo`03
o`000?oooooooooo04?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00
ooooool3ooooo`03o`000?oooooooooo04?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`2kooooo`00ooooool3ooooo`03o`000?oooooooooo04?ooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2kooooo`00ooooool3ooooo`03o`000?oooooooooo04?ooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00ooooool3ooooo`;o0000A?ooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003oooooo`?ooooo00?o0000oooooooo
ool0@oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003oooooo`?ooooo
00?o0000ooooooooool0@oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo
003oooooo`?ooooo00?o0000ooooooooool0@oooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0;_ooooo003oooooo`?ooooo00?o0000ooooooooool0@oooool00ol0003oo`00ool0000D
ool00003o`000?oooooooooo0;_ooooo003oooooo`?ooooo00?o0000ooooooooool0@oooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003oooooo`?ooooo00?o0000oooooooo
ool0@oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003oooooo`?ooooo
00?o0000ooooooooool0@oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo
003oooooo`?ooooo00?o0000ooooooooool0@oooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0;_ooooo003oooooo`?ooooo00?o0000ooooooooool0@oooool00ol0003oo`00ool0000D
ool00003o`000?oooooooooo0;_ooooo003oooooo`?ooooo0_l00014ooooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0^oooool00?oooooo0oooool00ol0003oooooooooo`13ooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00?oooooo0oooool00ol0003ooooo
ooooo`13ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00?oooooo0ooo
ool00ol0003oooooooooo`13ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^ooo
ool00?oooooo0oooool00ol0003oooooooooo`13ooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0^oooool00?oooooo0oooool00ol0003oooooooooo`13ooooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0^oooool00?oooooo0oooool00ol0003oooooooooo`13ooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00?oooooo0oooool00ol0003ooooo
ooooo`13ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00?oooooo0ooo
ool00ol0003oooooooooo`13ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^ooo
ool00?oooooo0oooool00ol0003oooooooooo`13ooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0^oooool00?oooooo0oooool2o`0004Cooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`2kooooo`00ooooool3ooooo`03o`000?oooooooooo04?ooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2kooooo`00ooooool3ooooo`03o`000?oooooooooo04?ooooo
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00ooooool3ooooo`03o`000?oo
oooooooo04?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00ooooool3
ooooo`03o`000?oooooooooo04?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2k
ooooo`00ooooool3ooooo`03o`000?oooooooooo04?ooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`2kooooo`00ooooool3ooooo`03o`000?oooooooooo04?ooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2kooooo`00ooooool3ooooo`03o`000?oooooooooo04?ooooo
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00ooooool3ooooo`03o`000?oo
oooooooo04?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00ooooool3
ooooo`;o0000A?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003ooooo
o`?ooooo00?o0000ooooooooool0@oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo
0;_ooooo003oooooo`?ooooo00?o0000ooooooooool0@oooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo0;_ooooo003oooooo`?ooooo00?o0000ooooooooool0@oooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo0;_ooooo003oooooo`?ooooo00?o0000ooooooooool0@ooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003oooooo`?ooooo00?o0000
ooooooooool0@oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003ooooo
o`?ooooo00?o0000ooooooooool0@oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo
0;_ooooo003Vooooo`Co000000Go410@ooooooooooooooooodA4A002o`000009oc8b<_oMgMgooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0@oooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo0;_ooooo003Xooooo`03o`000?oooooooooo00Kooooo00Wo
MgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`13oooo
o`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00>Sooooo00?o0000oooooooo
ool01oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00Kooooo00?o0000oooo
ooooool0@oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Xooooo`03
o`000?oooooooooo00Kooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo
00Kooooo1?l00012oooooaSo0000_Oooool00>Sooooo00?o0000ooooooooool00oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`05oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xoooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00omEEEGoIVIVo`000005oooo
o`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000
ooooooooool0oooooolIooooo`00iOooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Vooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooo
oa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?ooool4o`000?oooooo6?ooool00>Oooooo
00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?oMgMgofIVI_oo
ool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008
ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00Go0000oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`06ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Gooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000oooooooo
ool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJ
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003Uooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A007ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg
00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00onHV9So8B4Qonk^kP09ooooo`04
o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool01_ooool4o`000?oooooo6?ooool00>Oo
oooo00?oV9RHob4Q8Oo^k^h01oooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ogMgMomVIVKooooo00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000002?ooool0
0ol0003oooooooooo`3ooooooaWooooo003Yooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolI
ooooo`00iOooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool0
1OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000oc8b<_o<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08oooo
o`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go410@okZj^_ooooooMgMgoc8b<P03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o
0000ooooooooool0oooooolIooooo`00jOooool01Ol0003ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0
oooooolIooooo`00j?ooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000Sooooo1?l0003ooooooaSooooo003Wooooo`03oa0@
4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool00000oooooolTooooo`00j?ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41000oooool01Ol@413ooooooooooooooooo410@0?oooooo9?ooool00>Gooooo00Go410@oiRH
V?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg0?oooooo9?ooool00>Gooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^0?oooooo9?ooool00?oo
oooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolO
ooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooo
oooooooooaoooooo003ooooooooooooo7oooool00?Oooooo0_l0000;ooooo`03o`000?nj^[[ooooo
00cooooo0_l0003oooooo`Wooooo003gooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03
o`000?oooooooooo0?oooooo1oooool00>_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413o
ooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`00
0?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool0ooooool7
ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00[o0000ooooooooooooooooonk^
k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^
ogMgMol@41001?ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`02ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`Go00001_oo
ool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool00000
1_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o000000?o
00001Oooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0ooooool7ooooo`00joooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?o
oooo0_l0000Booooo`03o`000?oooooooooo00Gooooo0_l0003oooooo`Wooooo003ooooooooooooo
7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo0000\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .0309 L
.4 .0309 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .0309 L
.4 .0309 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .16275 L
.45 .16275 L
.45 0 L
F
0 g
.4 0 m
.4 .16275 L
.45 .16275 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .14627 L
.5 .14627 L
.5 0 L
F
0 g
.45 0 m
.45 .14627 L
.5 .14627 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .16893 L
.55 .16893 L
.55 0 L
F
0 g
.5 0 m
.5 .16893 L
.55 .16893 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .07828 L
.6 .07828 L
.6 0 L
F
0 g
.55 0 m
.55 .07828 L
.6 .07828 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .0721 L
.65 .0721 L
.65 0 L
F
0 g
.6 0 m
.6 .0721 L
.65 .0721 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .15245 L
.7 .15245 L
.7 0 L
F
0 g
.65 0 m
.65 .15245 L
.7 .15245 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .21837 L
.75 .21837 L
.75 0 L
F
0 g
.7 0 m
.7 .21837 L
.75 .21837 L
.75 0 L
.7 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo0;;ooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Oooooo00?o0000ooooooooool0/oooool00<Cooooo1_l00002ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002oooool5o`000;Cooooo
003<ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP15ooooo`05o`00
0?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP0Iooooo`05o`000?oooooooooooooo
ool000002oooool01?m4A4CogMgMooooool0002eooooo`00c?ooool01Ol0003ooooooooooooooooo
000000kooooo00?oMgMgofIVI_ooool0A?ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool06?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo
0000]Oooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co00000;Gooooo003<ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?ok^k^odA4A?l00000]Oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`0AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c00Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo
0000ooooo`2dooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolO
ooooo`00oooooooooooooaoooooo003ooooooocooooo0_l00002ooooo`;o00007?ooool00?oooooo
o?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAcooooo003ooooooogooooo00CogMgMo`000?l@
413oc<c<7Oooool001Ooooooool0003Go`0000oooooo00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo08;o
oooo00Co8B4QogMgMomgMgOo<S8b7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo087ooooo0_l00002ooooo`;o00007?ooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00^ooooolIo`0001Koo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool001So00005_oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo000Io`0001Kooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo02cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo02cooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo02cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo02cooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo02co
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo02cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo02cooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo02cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo02cooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo02cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo02cooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo02cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo02cooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
02cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo02cooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo02cooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo02cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo02cooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo02cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo02cooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo02cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo02cooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo02cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo02cooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo02co
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo02cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo02cooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo02cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo02cooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo02cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo02cooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo
003oo`0001Coo`006Ol0000Fool00003o`000?oooooooooo02cooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooo
oooo02cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo02cooooo6?l0000Gool00003o`000?oooooooooo
0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003o
o`00ool0000Dool00003o`000?oooooooooo04?ooooo00?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`13ooooo`03o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0@oooool00ol0003oo`00ool0
000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo04?ooooo00?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00dooooolHo`0001Oooooo00?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`13ooooo`03o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0Xoooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo04?o
oooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00ooooool3ooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0@oooool00ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0:?ooooo003oooooo`?ooooo6?l00015ooooo`03o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00?oooooo0oooool00ol0003oooooooooo`1Jooooo`03o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0Xoooool00?oooooo0oooool00ol0003oooooooooo`1Joooo
o`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00?oooooo0oooool00ol0003o
ooooooooo`1Jooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00?oooooo
0oooool00ol0003oooooooooo`1Jooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
Xoooool00?oooooo0oooool00ol0003oooooooooo`1Jooooo`03o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00?oooooo0oooool00ol0003oooooooooo`1Jooooo`03o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0Xoooool00?oooooo0oooool00ol0003oooooooooo`1Joooo
o`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00?oooooo0oooool2o`0005_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00ooooool3ooooo`03o`00
0?oooooooooo05[ooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00oooo
ool3ooooo`03o`000?oooooooooo05[ooooo00?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00ooooool3ooooo`03o`000?oooooooooo05[ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`2Sooooo`00ooooool3ooooo`03o`000?oooooooooo05[ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00ooooool3ooooo`03o`000?oooooooooo05[o
oooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00ooooool3ooooo`03o`00
0?oooooooooo05[ooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00i_oo
ool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02?ooool00ol0003oooooooooo`1Jooooo`03o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00>Sooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo05[ooooo00?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00j?ooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo
00?o0000ooooooooool0F_ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
003Xooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000002?ooool4o`0005Wooooo00?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`2Sooooo`00j?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0F_ooool00ol0
003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Xooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?ooool0
0ol0003oooooooooo`1Jooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool0
0>Sooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo05[ooooo00?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`2Sooooo`00i_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0
F_ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003oooooo`?ooooo00?o
0000ooooooooool0F_oooolIo`000:Gooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oo
oooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo1?l0
00001Ol@413oooooooooooooooooA4A400;o000000Wo<S8bomgMgOooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo
00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo410@
0oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o
0000ooooooooool01_ooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool0
1_ooool4o`000?oooooo6?ooool00>Sooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05oa0@
4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00So
oooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00omEEEGoIVIVo`000005ooooo`Co0000
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo1Ol00003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooooooo
ool0oooooolIooooo`00iOooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3o
oooooaWooooo003Vooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@41002?ooool4o`000?oooooo6?ooool00>Oooooo00?oV9RH
ob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?oMgMgofIVI_ooool00_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03
o`000?oooooooooo0?oooooo6Oooool00>Wooooo00Go0000oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Gooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooo
oolIooooo`00iOooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003Uooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^
k^koooooodA4A007ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo
00?o0000ooooooooool0oooooolIooooo`00i_ooool00onHV9So8B4Qonk^kP09ooooo`04o`000?oo
oooooooooa0@40?ooooo00?o410@ooooooooool01_ooool4o`000?oooooo6?ooool00>Oooooo00?o
V9RHob4Q8Oo^k^h01oooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ogMgMomVIVKooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Yooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00
iOooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So
410@o`000?lQ8B7oc<c<00Cooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Gooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00jOooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooo
oooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolI
ooooo`00j?ooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000Sooooo1?l0003ooooooaSooooo003Wooooo`03oa0@4?l0003o
^[Zj00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
oooooolTooooo`00j?ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
0oooool01Ol@413ooooooooooooooooo410@0?oooooo9?ooool00>Gooooo00Go410@oiRHV?oooooo
^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg0?oooooo9?ooool00>Gooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^0?oooooo9?ooool00?oooooooooo
oolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00
oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooo
oaoooooo003ooooooooooooo7oooool00?Oooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo
0_l0003oooooo`Wooooo003gooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oo
oooooooo0?oooooo1oooool00>_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413ooooooooo
o`03ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X0
1?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool0ooooool7ooooo`00
k?ooool01Ol0003ooooooooooooooooo000000Kooooo00[o0000ooooooooooooooooonk^k_lQ8B7o
QhN7okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@
41001?ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`02ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`Go00001_ooool00ol0
003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool0
1?l0003oooooooooooooool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o000000?o00001Ooo
ool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooo
ool7ooooo`00joooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo0_l0
000Booooo`03o`000?oooooooooo00Gooooo0_l0003oooooo`Wooooo003ooooooooooooo7oooool0
0?oooooooooooolOooooo`00oooooooooooooaoooooo0000\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .0721 L
.4 .0721 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .0721 L
.4 .0721 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .15451 L
.45 .15451 L
.45 0 L
F
0 g
.4 0 m
.4 .15451 L
.45 .15451 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .14627 L
.5 .14627 L
.5 0 L
F
0 g
.45 0 m
.45 .14627 L
.5 .14627 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .13597 L
.55 .13597 L
.55 0 L
F
0 g
.5 0 m
.5 .13597 L
.55 .13597 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .21425 L
.6 .21425 L
.6 0 L
F
0 g
.55 0 m
.55 .21425 L
.6 .21425 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .0515 L
.65 .0515 L
.65 0 L
F
0 g
.6 0 m
.6 .0515 L
.65 .0515 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .10919 L
.7 .10919 L
.7 0 L
F
0 g
.65 0 m
.65 .10919 L
.7 .10919 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .09889 L
.75 .09889 L
.75 0 L
F
0 g
.7 0 m
.7 .09889 L
.75 .09889 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .04738 L
.8 .04738 L
.8 0 L
F
0 g
.75 0 m
.75 .04738 L
.8 .04738 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08co
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo000Ho`0008kooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`006?l0000Fool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo01Co
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00;_ooooo6Ol0000Fool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?oo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xooo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo000Io`000:Gooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?oo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool05?oooolHo`000;gooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOoo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo000Ho`0001Ooo`0000?o0000
ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yoooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool000;o00005Oooool00ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`006Ol0000Fooooo`03o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Go
oooo00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wo
oooo003CoooooaSo00005oooool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0jOooool00?oooooo0oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0jOooool00?oooooo0oooool00ol0003oooooooooo`0D
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00?oooooo0oooool00ol0
003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00?oo
oooo0oooool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0jOooool00?oooooo0oooool2o`0001Gooooo00?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`3Yooooo`00ooooool3ooooo`03o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oooooooooo01Cooooo00?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oooooooooo
01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03
o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00
ooooool3ooooo`03o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`3Yooooo`00ooooool3ooooo`03o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oooooooooo01Cooooo00?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oooooooooo
01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03
o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00
ooooool3ooooo`;o00005Oooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo
003oooooo`?ooooo00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0>Wooooo003oooooo`?ooooo00?o0000ooooooooool05?ooool00ol0003oo`00ool0000E
ool00003o`000?oooooooooo0>Wooooo003oooooo`?ooooo00?o0000ooooooooool05?ooool00ol0
003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003oooooo`?ooooo00?o0000oooooooo
ool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003oooooo`?ooooo
00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo
003oooooo`?ooooo00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0>Wooooo003Vooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo01Cooooo00?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00j?ooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000
ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Xoooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo
ooooooooool@41002?ooool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0jOooool00>Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`Co00004oooool00ol0003oo`00
ool0000Eool00003o`000?oooooooooo0>Wooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00>Sooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooooooooa0@4008ooooo`03o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`3Yooooo`00j?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool05?oooolI
o`000>_ooooo003Vooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003V
ooooo`Co000000Go410@ooooooooooooooooodA4A002o`000009oc8b<_oMgMgoooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003o
ooooooooo`06ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o
0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`07ooooo`04o`000?oooooo
oooooa0@40?ooooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003X
ooooo`03o`000?oooooooooo00Kooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oo
oooooooo00Kooooo1?l0003ooooooaSooooo003Xooooo`03o`000?oooooooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oEEEEofIVI_l000001Ooo
ool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`Go00000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00i_ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?oooooooooooooo
ool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo1?l0003ooooooaSooooo003Woooo
o`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`05o`000?ooooooooooooooool@4100
0oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01_ooool00ol0003o
ooooooooo`3ooooooaWooooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo
6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00iOooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMg
M`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^k^h02Oooool0
1?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00Kooooo1?l0003ooooooaSooooo003W
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00omgMgOoIVIVooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000Sooooo
00?o0000ooooooooool0oooooolIooooo`00jOooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Gooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lb<S;oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?oo
ool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oa0@4?nj^[[oooooogMgMolb<S800ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03
o`000?oooooooooo0?oooooo6Oooool00>Wooooo00Go0000oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Sooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000008ooooo`Co0000oooooolHooooo`00ioooool00ol@
413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo00000?oooooo9?ooool00>Sooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooo
oooo410@00?ooooo00Go410@oooooooooooooooooa0@403oooooobCooooo003Uooooo`05oa0@4?nH
V9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`3oooooobCooooo003Uooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP3oooooobCooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo
7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oo
oooooooooolOooooo`00oooooooooooooaoooooo003gooooo`;o00002oooool00ol0003o^[Zjoooo
o`0<ooooo`;o0000ooooool9ooooo`00moooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool0
0ol0003oooooooooo`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@
ooooooooool00oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0
003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo0?oooooo
1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`0:o`000?ooooooooooooooooo^
k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^
k_mgMgOo410@00Cooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool5o`0000Ko
oooo00?o0000ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo0000
00Kooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003
o`0000Gooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo0?oooooo1oooool00>_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03
ooooo`;o00004_ooool00ol0003oooooooooo`05ooooo`;o0000ooooool9ooooo`00oooooooooooo
oaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .09683 L
.4 .09683 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .09683 L
.4 .09683 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .17305 L
.45 .17305 L
.45 0 L
F
0 g
.4 0 m
.4 .17305 L
.45 .17305 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .14833 L
.5 .14833 L
.5 0 L
F
0 g
.45 0 m
.45 .14833 L
.5 .14833 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .20807 L
.55 .20807 L
.55 0 L
F
0 g
.5 0 m
.5 .20807 L
.55 .20807 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .24721 L
.6 .24721 L
.6 0 L
F
0 g
.55 0 m
.55 .24721 L
.6 .24721 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .05356 L
.65 .05356 L
.65 0 L
F
0 g
.6 0 m
.6 .05356 L
.65 .05356 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .0412 L
.7 .0412 L
.7 0 L
F
0 g
.65 0 m
.65 .0412 L
.7 .0412 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .02678 L
.75 .02678 L
.75 0 L
F
0 g
.7 0 m
.7 .02678 L
.75 .02678 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .0309 L
.8 .0309 L
.8 0 L
F
0 g
.75 0 m
.75 .0309 L
.8 .0309 L
.8 0 L
.75 0 L
s
1 0 0 r
.8 0 m
.8 .00412 L
.85 .00412 L
.85 0 L
F
0 g
.8 0 m
.8 .00412 L
.85 .00412 L
.85 0 L
.8 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`1Cooooo`04ob4Q8OmgMgOoMgMgoc8b<Qgooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool001Wo0000E?ooool2o`0000;ooooo
0_l0000Looooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`2<ooooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2<
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`2<ooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2<ooooo`00
^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`2<ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2<ooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`2<ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2<ooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`2<ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool001Wo00005_oo00000ol0003ooooo
ooooo`2<ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o
0000ool00?oo00005?oo00000ol0003oooooooooo`2<ooooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo01Gooooo6?l0002>ooooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool001So0000_Oooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00;_ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
01So0000e?ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0>Wooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`3Yooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0jOooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`3Yooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0jOooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0>Wooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`3Yooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wo
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`3Yooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0jOooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0>Wooooo002koooooaWo00005_oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yoooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Y
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOoo
ool00=?ooooo00?o0000ool00?oo00005?oo000Io`0001Koo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo
01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eoooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yoooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooo
oooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?o
oooo6?l0000Gooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3oooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yoooo
o`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3oooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yoooo
o`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00i_ooool4o`000008oa0@4?oooooo
ooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00>So
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`08ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`3Yooooo`00j?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Xooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
2?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
jOooool00>Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000008oooooaSo00005ooo00000ol0003oooooooooo`3Yooooo`00
j?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@00Sooooo00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0>Wooooo003Xooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`0D
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00>Kooooo00?oEEEEofIV
I_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP08ooooo`03o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`3Yooooo`00ooooool3ooooo`03o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oooooooooo01Cooooo00?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oooooooooo01Co
oooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00oooo
ool3ooooo`;o00005Oooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003o
ooooo`?ooooo00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0>Wooooo003oooooo`?ooooo00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0>Wooooo003oooooo`?ooooo00?o0000ooooooooool05?ooool00ol0003o
o`00ool0000Eool00003o`000?oooooooooo0>Wooooo003oooooo`?ooooo00?o0000ooooooooool0
5?ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003oooooo`?ooooo00?o
0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003o
ooooo`?ooooo00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0>Wooooo003oooooo`?ooooo00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0>Wooooo003oooooo`?ooooo00?o0000ooooooooool05?ooool00ol0003o
o`00ool0000Eool00003o`000?oooooooooo0>Wooooo003oooooo`?ooooo00?o0000ooooooooool0
5?ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003oooooo`?ooooo0_l0
000EoooooaWo0000joooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00i_ooool4o`000005oa0@4?oooooooooooooooom4A4@00_l0
00002Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool02OmgMgOo<S8booooooooooooMgMg
oiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000
ooooooooool01oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00Kooooo00?o
0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;o
ooooooooool000000oooool00ol0003oooooooooo`06ooooo`Co0000oooooolHooooo`00j?ooool0
0ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooo
oooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo
003Vooooo`03oeEEEOmVIVKo000000Gooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_oo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00iOooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^
k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008
ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooo
oolIooooo`00j?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00jOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[Zj
oooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo1Ol00004ooooo`05odA4A?l0
003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooooooo
ool0oooooolIooooo`00iOooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00WoMgMgoc8b<_oo
ooooooooogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003V
ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00Co0000oooooooooooo410@0oooool00ol@413ooooooooo
o`06ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP07ooooo`05ogMgMolb<S;o
ooooooooool000000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Sooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go
0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@4100
1?ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2
o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2
o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Go
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool0
1Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`05o`00
0?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooo
ooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ojVYZOl@413ooooo00;o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool4
o`000?oooooo6?ooool00>Oooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`00003oooooobCooooo003Xooooo`03okZj^_lQ8B7o
oooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100
oooooolTooooo`00iOooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0oooooolTooooo`00iOooool01OnYZJWo
410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h0oooooolTooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oo
oooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolO
ooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00mooo
ool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`000?oooooo2Oooool00?Oooooo00?o0000
ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool0ooooool7ooooo`00joooool01?l@
413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l0
0002ooooo`;o00000oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X0
1?ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool00000
1_ooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0
003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo0?oooooo
1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo
00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oo
oooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;o
oooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
0?oooooo1oooool00>cooooo1Ol00006ooooo`03o`000?oooooooooo00;ooooo00Co8B4QogMgMomg
MgOo<S8b2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>co
oooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2
o`0000Sooooo00?o410@o`000?l000000ol00005ooooo`03o`000?oooooooooo0?oooooo1oooool0
0>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o0000
ooooo`;o000000?o410@ooooooooool00oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2
o`000?oooooo2Oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo
7oooool00001\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .15657 L
.4 .15657 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .15657 L
.4 .15657 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .19777 L
.45 .19777 L
.45 0 L
F
0 g
.4 0 m
.4 .19777 L
.45 .19777 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .16481 L
.5 .16481 L
.5 0 L
F
0 g
.45 0 m
.45 .16481 L
.5 .16481 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .17717 L
.55 .17717 L
.55 0 L
F
0 g
.5 0 m
.5 .17717 L
.55 .17717 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .16275 L
.6 .16275 L
.6 0 L
F
0 g
.55 0 m
.55 .16275 L
.6 .16275 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .13391 L
.65 .13391 L
.65 0 L
F
0 g
.6 0 m
.6 .13391 L
.65 .13391 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .01236 L
.7 .01236 L
.7 0 L
F
0 g
.65 0 m
.65 .01236 L
.7 .01236 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .01236 L
.75 .01236 L
.75 0 L
F
0 g
.7 0 m
.7 .01236 L
.75 .01236 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .01236 L
.8 .01236 L
.8 0 L
F
0 g
.75 0 m
.75 .01236 L
.8 .01236 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool004Oo0000S_ooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
d_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00;_ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_oo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00;_ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
d_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00;_ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_oo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00;_ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
d_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00;_ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_oo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool001So0000e?ooool00;_ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yoooo
o`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0jOooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0>Wooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`3Yooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0jOooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00;_ooooo6Ol0
000Fool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yoooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo000Io`000>_ooooo003Cooooo`03o`000?oo003oo`0001Coo`006Ol0000Fool00003o`00
0?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05OoooolHo`000?oooooo1?oo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`0Eooooo`;o0000oooooolJooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo01Gooooo00?o0000ooooooooool0oooooolIooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ooooooooool0oooooolI
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0oooooolIooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Go
oooo00?o0000ooooooooool0oooooolIooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo01Gooooo00?o0000ooooooooool0oooooolIooooo`00dooooolHo`0001Oooooo00?o
0000ooooooooool0oooooolIooooo`00i_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xoooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo
ooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
2?ooool4o`000?oooooo6?ooool00>Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>So
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oEEEEofIV
I_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo1?l000001Ol@413ooooooooooooo
ooooA4A400;o000000Wo<S8bomgMgOooooooooooonk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0
003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_oo
ooooooooogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003X
ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo410@0oooool00ol@413ooooooooo
o`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool0
1OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool01_ooool4o`000?oooooo6?oo
ool00>Sooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go
0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0
oooooolIooooo`00i_ooool00omEEEGoIVIVo`000005ooooo`Co00000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Gooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOoo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03
oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooo
ooooool@41002?ooool4o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Sooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Wooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
41000oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo
00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnH
V9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[o
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[o
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[o
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`Go00001?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03
o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`09
ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooo
oolIooooo`00i_ooool00onHV9So8B4Qonk^kP09ooooo`04o`000?oooooooooooa0@40?ooooo00?o
410@ooooooooool01_ooool4o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h01oooool0
1OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`3ooooooaWooooo003Xooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c002ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo
003Yooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[Zjoooo
oonHV9So410@00Cooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00So
oooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lQ8B7oc<c<00Co
oooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003Uooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Gooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00
jOooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003oooo
o`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00onYZJWo
410@ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000Sooooo1?l0003ooooooaSooooo003Wooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000oooooolTooooo`00j?ooool0
0onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooo
oooooooo410@0?oooooo9?ooool00>Gooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?oooooo9?ooool00>Go
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^0?oooooo9?ooool00?oooooooooooolOooooo`00oooooooooooo
oaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo
7oooool00?Oooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo0_l0003oooooo`Wooooo003g
ooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo0?oooooo1oooool0
0>_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`04o`000?oooooo
ooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`00
0?m4A4Co^[Zj00Cooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooo
oooooooo000000Kooooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0ooo
ool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003ooooo
ooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`02ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`3oooooo`Oooooo003/ooooo`Go00001_ooool00ol0003oooooooooo`02ooooo`04
ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooo
o`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooooooool2
o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0003oooooooooo`3o
ooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00joooool01?l@
413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo0_l0000Booooo`03o`000?oooooo
oooo00Gooooo0_l0003oooooo`Wooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00
oooooooooooooaoooooo0000\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.35 -0.0125 -12 -9 ]
[.35 -0.0125 12 0 ]
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.45 -0.0125 -12 -9 ]
[.45 -0.0125 12 0 ]
[.5 -0.0125 -39.75 -12.5 ]
[.5 -0.0125 39.75 0 ]
[.55 -0.0125 -9 -9 ]
[.55 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.65 -0.0125 -9 -9 ]
[.65 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.35 0 m
.35 .00625 L
s
[(-0.3)] .35 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.45 0 m
.45 .00625 L
s
[(-0.1)] .45 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -39.75 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2.77556) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-17) show
grestore
.55 0 m
.55 .00625 L
s
[(0.1)] .55 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.65 0 m
.65 .00625 L
s
[(0.3)] .65 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .09477 L
.4 .09477 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .09477 L
.4 .09477 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .21219 L
.45 .21219 L
.45 0 L
F
0 g
.4 0 m
.4 .21219 L
.45 .21219 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .18541 L
.5 .18541 L
.5 0 L
F
0 g
.45 0 m
.45 .18541 L
.5 .18541 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .17923 L
.55 .17923 L
.55 0 L
F
0 g
.5 0 m
.5 .17923 L
.55 .17923 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .12567 L
.6 .12567 L
.6 0 L
F
0 g
.55 0 m
.55 .12567 L
.6 .12567 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .19777 L
.65 .19777 L
.65 0 L
F
0 g
.6 0 m
.6 .19777 L
.65 .19777 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .03502 L
.7 .03502 L
.7 0 L
F
0 g
.65 0 m
.65 .03502 L
.7 .03502 L
.7 0 L
.65 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00?oooooo4Oooool2onk^kP?ooooo0_o^k^koooooo`Oo
oooo003Iooooo`Go00001Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01Oooool00ol0003ok^k^
ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd00oooool01Om4A4Co0000o`000?lb<S;ogMgM
00;ooooo00Gok^k^oc8b<_l0003o410@olc<c002ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEE
onk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^k_Oooooo003Ioooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01Oooool0
0omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Gooooo00WoMgMgoc8b<_oooooooooooeEE
EOmgMgOooooooiRHV?lQ8B400oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg0?Oooooo003Aooooo`Ko00000oooool00onH
V9So8B4Qonk^kP0>ooooo`03ojVYZOmEEEGooooo00Gooooo00?oZJVYoeEEEOooool02?ooool00ol0
003oooooooooo`05ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool0
0ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
403gooooo`00]Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05oiRHV?l@
413o0000oc8b<_o<c<`00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B43ooooo`03
oiRHV?l0003o000000?o00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Co8B4Qoooo
oolQ8B7o8B4Q1?ooool00olQ8B7o0000o`000002o`000006oa0@4?oooooooooooooooomgMgOo<S8b
1_ooool04OmgMgOo<S8boooooooooooo0000oiRHV?ooooooV9RHob4Q8Oo^k^ko<S8bo`000?l_;boo
Cdm?omgMgOmEEEGok^k^00;ooooo0_lQ8B42ooooo`03o`000?oooooooooo00Co000000Oo410@oooo
ool0003o<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00000_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0/oooool00;Go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo
<S8b00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Om6ATKo3@d=onk^
k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`04oeEEEOo<c<co8B4Qob4Q
8@Cooooo00CoEEEEolc<c?oooooo00000_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c002ooooo`0?o`000?mEEEGo0000oa0@4?o<c<coMgMgoiRHV?o^k^ko
<S8bofm_Koooooook^k^oeEEEOo^k^kooooo00;o8B4Q0_ooool00ol0003oooooooooo`02ooooo`09
o`000?ooooooooooooooool0003oV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
oa0@4?nj^[[oooooogMgMolb<S800_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47
ooooo`03o`000?oooooooooo0;Cooooo002]ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo
410@00[ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41002oooool6o`0000;ooooo00Go
410@oooooooooooooooooa0@4003ooooo`03ojVYZOmgMgOooooo00Gooooo00CoZJVYogMgMooooooo
00000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?oEEEEohN7Qooo
ool00_ooool01Ol@413oooooonk^k_o^k^ko410@00;ooooo0_o^k^h5ooooo`03o`000?oooooooooo
00;ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RH
ob4Q8Oo^k^h00oooool01Ol@413ooooooooooooooooo410@00oooooo00Co0000oooooooooooo410@
0oooool00ol@413oooooooooo`09ooooo`Go0000]Oooool00;Gooooo00Go0000oooooooooooooooo
o`00000>ooooo`05ojVYZOl@413oooooooooool000000oooool00ol0003oooooooooo`06ooooo`08
o`000?nj^[[ooooooiRHV?l@413oV9RHob4Q8Oo^k^h3ooooo`06o`000?ooooooooooooooool0003o
410@0oooool01Olb<S;ooooooooooooooooo410@00?ooooo00?o<S8booooool000000_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?ogMgMoa0@4?nHV9P00_ooool01Ol0
003ooooooooooooooooo000000Wooooo00?o0000ooooooooool00_ooool01Ol0003oV9RHoooooonH
V9So000000?ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP02ooooo`05o`000?oo
ooooooooooooool000003_ooool01OnYZJWo410@oooooooooooo000000?ooooo00?o0000oooooooo
ool02Oooool01?m4A4CogMgMooooool0002fooooo`00]Oooool01Ol0003ooooooooooooooooo0000
00gooooo00?o410@o`000?nj^[X00_ooool01Ol0003ooooooooooooooooo000000Sooooo00SoV9RH
oa0@4?l0003o8B4Qolc<c?ooooooMgMgofIVIP?ooooo00Co0000oooooooooooooooo1_l00003oooo
o`Go000000Coooooo`000?oooooooooo1?l00004ooooo`Co00001?ooool01Oo<c<coA4A4o`000?l@
413o000000?ooooo00?o0000ooooooooool01Oooool00omEEEGoIVIVo`000004ooooo`05o`000?lb
<S;o0000oc8b<_l000000oooool00ol0003oooooooooo`02ooooo`?o00000_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMomVIVKoooooooooool000000oooool00ol0003oooooooooo`0;ooooo`03
oa0@4?l0003o^[Zj00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`000;Kooooo002eooooo`05oa0@4?ooooooooooooooool@41003_ooool01Onj^[[o8B4Qoooooooo
oooo410@00?ooooo00?o410@ooooooooool03Oooool01Ol0003ooooooooooooooooo410@00?ooooo
00?o410@ooooooooool03?ooool00ol0003oooooooooo`0Dooooo`05oa0@4?ooooooooooooooool@
41003_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool00oooool01Ol0
003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo410@0oooool00ol@413ooooooooo
o`0<ooooo`05okZj^_lQ8B7oooooooooool@41000oooool00ol@413oooooooooo`0:ooooo`03ogMg
Moo<c<co00000;Kooooo002eooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413oV9RH
oooooonj^[[o000000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool05?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00Oo0000ooooooooooooooooogMgMonHV9Sooooo
00Co00000oooool00ol0003oooooooooo`02ooooo`;o000000Co^[ZjoooooonHV9So410@0_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oiRHV?oooooo^[Zjo`000002ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00002fooooo`00]Oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@02ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`03oeEEEOmVIVKo000001Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03
oeEEEOmVIVKo000000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo
00;ooooo00Ko0000oiRHV?l@413o0000ob4Q8Oo<c<`2ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool01OnYZJWo410@o`000?l@413oZJVY00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=oooo
o`03ogMgMol0003ooooo0;Gooooo003ooooooc3ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`3Uooooo`00ooooool_ooooo`;o00000_ooool4o`000>Oooooo003ooooooooooooo
7oooool00?oooooooooooolOooooo`00oooooooiooooo`;o00000_ooool2o`0001oooooo003ooooo
ooWooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMdOooooo`00ooooooojooooo`04omgMgOl0003o
410@olc<c23ooooo000Koooooooo0000d?l0000?ooooo`04onk^k_lQ8B7o410@onk^kR3ooooo002l
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0V?ooool01?lQ8B7oMgMgogMgMolb
<S8Pooooo`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo09Oooooo0_l00002
ooooo`;o00007oooool00;cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2loooo
o`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;cooooo002looooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0_?ooool00;cooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2looooo`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0;cooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0_?ooool00;co
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2looooo`00_?ooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0;cooooo002looooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0_?ooool00;cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2l
ooooo`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;cooooo002looooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0_?ooool00;cooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`2looooo`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo000Ho`000;kooooo002looooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0=?ooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0=?ooooo002looooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=?o
oooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0=?ooooo002looooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=?ooooo002l
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0=?ooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=?ooooo002looooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0=?ooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=?ooooo002looooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0=?ooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0=?ooooo002looooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0=?ooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo0=?ooooo002looooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=?ooooo
002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0=?ooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=?ooooo002loooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0=?ooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=?ooooo002looooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0=?ooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=?ooooo002looooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0=?ooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0=?ooooo002looooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=?o
oooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0=?ooooo002looooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=?ooooo002l
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0=?ooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=?ooooo002loooooaSo
00005ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=?ooooo003Cooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Cooooo`00dooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0dooo
ool00=?ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0=?ooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3Cooooo`00doooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0doooool00=?ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0=?ooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`3Cooooo`00doooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0doooool00=?ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=?ooooo003Cooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Cooooo`00
doooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
doooool00=?ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0=?ooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`3Cooooo`00doooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo000Ho`0001Koo`0000?o0000ooooooooool0doooool00=?o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0=?o
oooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3Cooooo`00doooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0doooool00=?ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000D
ool00003o`000?oooooooooo0=?ooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo01Cooooo00?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3Cooooo`00doooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Dooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0doooool00=?ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
5?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0=?ooooo003Cooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Cooooo`00doooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0doooool0
0=?ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo
0=?ooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`3Cooooo`00doooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0doooool00=?ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo0=?ooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo01Cooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`3Cooooo`00doooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Doooo
o`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0doooool00=?ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool05?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0=?ooooo003Cooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Cooooo`00dooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0dooo
ool00=?ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0=?ooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3Cooooo`00doooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0doooool00=?ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05?ooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo0=?ooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo01Cooooo00?o
0000ool00?oo00005?oo00000ol0003oooooooooo`3Cooooo`00doooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`0D
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0doooool00=?ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool001So00005_ooool00ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0=?ooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`0[ooooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0doooool00=?ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo02_ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Cooooo`00dooo
ool00ol0003oo`00ool0000Eool001Wo0000;?ooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0=?ooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0[ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0doooool0
0=?ooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
02_ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Cooooo`00doooool00ol0003o
o`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ooooooooool0:oooool00ol0003o
o`00ool0000Dool00003o`000?oooooooooo0=?ooooo003Cooooo`03o`000?oo003oo`0001Goo`00
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0[ooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0doooool00=?ooooo00?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo02_ooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3Cooooo`00doooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000
ooooooooool0:ooooolHo`000=Gooooo003Cooooo`03o`000?oo003oo`0001Goo`0000Oo0000oooo
ooo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005Ooo00001ol0003oooooogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00doooool00ol0003oo`00ool0000Eool00003o`000?oooooo410@00?o
oooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Kooooo1?l0003ooooo
oaSooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooo
oaWooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooo
oaWooooo003CoooooaWo000000?ooooooa0@4?ooool00_ooool01Ol@413ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oeEEEOmVIVKo0000
00Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?oo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`Co000000Go410@ooooooooooooooooodA4
A002o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`06ooooo`09ogMgMolb<S;ooooooooo
oomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool0
0ol0003oooooooooo`07ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool01_oo
ool4o`000?oooooo6?ooool00>Sooooo00?o0000ooooooooool01_ooool01OmgMgOo<S8boooooooo
oooo000000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003X
ooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00Sooooo
00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Kooooo00?oEEEEofIVI_l000001Oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
iOooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^k^h01?ooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Oooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`Co0000oooooolHooooo`00
j?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00jOooool01Ol0003o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooo
oooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[ZjoooooonHV9So
410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b
<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolI
ooooo`00iOooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00WoMgMgoc8b<_ooooooooooogMg
MonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oiRH
V?lQ8B7ok^k^00Wooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`06ooooo`Co
0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP07ooooo`05ogMgMolb<S;oooooooooool0
00000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo
00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooooooo
ooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0
003oooooooooo`3ooooooaWooooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3o
oooooaWooooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo
6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo
6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00iOooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Uooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Wooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o
ZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000008ooooo`Co0000oooooolHooooo`00ioooool00ol@413o0000okZj^P03ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo00000?oooooo9?ooool00>So
oooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooo
oooooooooooooa0@403oooooobCooooo003Uooooo`05oa0@4?nHV9SooooookZj^_l000000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`3oooooobCooooo
003Uooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP3oooooobCooooo003ooooooooooooo7oooool00?oooooo
oooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOoooo
o`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooo
oooooaoooooo003gooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o0000ooooool9oooo
o`00moooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`3oooooo`Oo
oooo003[ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool01?l0003o
ooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`00
0?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000oooo
ooooooooooooo`000006ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgM
g@?ooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000
ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0ooooool7ooooo`00k?ooool5o`0000Kooooo00?o0000ooooooooool00_oo
ool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo
oooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Gooooo00?o0000oooooooo
ool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>_ooooo
00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`;o00004_ooool00ol0003o
ooooooooo`05ooooo`;o0000ooooool9ooooo`00oooooooooooooaoooooo003ooooooooooooo7ooo
ool00?oooooooooooolOooooo`00\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.11695, -22.4749, \
0.0054076, 1.31245}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.35 -0.0125 -12 -9 ]
[.35 -0.0125 12 0 ]
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.45 -0.0125 -12 -9 ]
[.45 -0.0125 12 0 ]
[.5 -0.0125 -39.75 -12.5 ]
[.5 -0.0125 39.75 0 ]
[.55 -0.0125 -9 -9 ]
[.55 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.65 -0.0125 -9 -9 ]
[.65 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.35 0 m
.35 .00625 L
s
[(-0.3)] .35 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.45 0 m
.45 .00625 L
s
[(-0.1)] .45 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -39.75 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2.77556) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-17) show
grestore
.55 0 m
.55 .00625 L
s
[(0.1)] .55 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.65 0 m
.65 .00625 L
s
[(0.3)] .65 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .04738 L
.4 .04738 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .04738 L
.4 .04738 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .17305 L
.45 .17305 L
.45 0 L
F
0 g
.4 0 m
.4 .17305 L
.45 .17305 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .14421 L
.5 .14421 L
.5 0 L
F
0 g
.45 0 m
.45 .14421 L
.5 .14421 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .17923 L
.55 .17923 L
.55 0 L
F
0 g
.5 0 m
.5 .17923 L
.55 .17923 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .13803 L
.6 .13803 L
.6 0 L
F
0 g
.55 0 m
.55 .13803 L
.6 .13803 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .18747 L
.65 .18747 L
.65 0 L
F
0 g
.6 0 m
.6 .18747 L
.65 .18747 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .16069 L
.7 .16069 L
.7 0 L
F
0 g
.65 0 m
.65 .16069 L
.7 .16069 L
.7 0 L
.65 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00?oooooo4Oooool2onk^kP?ooooo0_o^k^koooooo`Oo
oooo003Iooooo`Go00001Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01Oooool00ol0003ok^k^
ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd00oooool01Om4A4Co0000o`000?lb<S;ogMgM
00;ooooo00Gok^k^oc8b<_l0003o410@olc<c002ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEE
onk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^k_Oooooo003Ioooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01Oooool0
0omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Gooooo00WoMgMgoc8b<_oooooooooooeEE
EOmgMgOooooooiRHV?lQ8B400oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg0?Oooooo003Aooooo`Ko00000oooool00onH
V9So8B4Qonk^kP0>ooooo`03ojVYZOmEEEGooooo00Gooooo00?oZJVYoeEEEOooool02?ooool00ol0
003oooooooooo`05ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool0
0ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
403gooooo`00]Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05oiRHV?l@
413o0000oc8b<_o<c<`00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B43ooooo`03
oiRHV?l0003o000000?o00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Co8B4Qoooo
oolQ8B7o8B4Q1?ooool00olQ8B7o0000o`000002o`000006oa0@4?oooooooooooooooomgMgOo<S8b
1_ooool04OmgMgOo<S8boooooooooooo0000oiRHV?ooooooV9RHob4Q8Oo^k^ko<S8bo`000?l_;boo
Cdm?omgMgOmEEEGok^k^00;ooooo0_lQ8B42ooooo`03o`000?oooooooooo00Co000000Oo410@oooo
ool0003o<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00000_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0/oooool00;Go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo
<S8b00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Om6ATKo3@d=onk^
k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`04oeEEEOo<c<co8B4Qob4Q
8@Cooooo00CoEEEEolc<c?oooooo00000_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c002ooooo`0?o`000?mEEEGo0000oa0@4?o<c<coMgMgoiRHV?o^k^ko
<S8bofm_Koooooook^k^oeEEEOo^k^kooooo00;o8B4Q0_ooool00ol0003oooooooooo`02ooooo`09
o`000?ooooooooooooooool0003oV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
oa0@4?nj^[[oooooogMgMolb<S800_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47
ooooo`03o`000?oooooooooo0;Cooooo002]ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo
410@00[ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41002oooool6o`0000;ooooo00Go
410@oooooooooooooooooa0@4003ooooo`03ojVYZOmgMgOooooo00Gooooo00CoZJVYogMgMooooooo
00000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?oEEEEohN7Qooo
ool00_ooool01Ol@413oooooonk^k_o^k^ko410@00;ooooo0_o^k^h5ooooo`03o`000?oooooooooo
00;ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RH
ob4Q8Oo^k^h00oooool01Ol@413ooooooooooooooooo410@00oooooo00Co0000oooooooooooo410@
0oooool00ol@413oooooooooo`09ooooo`Go0000]Oooool00;Gooooo00Go0000oooooooooooooooo
o`00000>ooooo`05ojVYZOl@413oooooooooool000000oooool00ol0003oooooooooo`06ooooo`08
o`000?nj^[[ooooooiRHV?l@413oV9RHob4Q8Oo^k^h3ooooo`06o`000?ooooooooooooooool0003o
410@0oooool01Olb<S;ooooooooooooooooo410@00?ooooo00?o<S8booooool000000_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?ogMgMoa0@4?nHV9P00_ooool01Ol0
003ooooooooooooooooo000000Wooooo00?o0000ooooooooool00_ooool01Ol0003oV9RHoooooonH
V9So000000?ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP02ooooo`05o`000?oo
ooooooooooooool000003_ooool01OnYZJWo410@oooooooooooo000000?ooooo00?o0000oooooooo
ool02Oooool01?m4A4CogMgMooooool0002fooooo`00]Oooool01Ol0003ooooooooooooooooo0000
00gooooo00?o410@o`000?nj^[X00_ooool01Ol0003ooooooooooooooooo000000Sooooo00SoV9RH
oa0@4?l0003o8B4Qolc<c?ooooooMgMgofIVIP?ooooo00Co0000oooooooooooooooo1_l00003oooo
o`Go000000Coooooo`000?oooooooooo1?l00004ooooo`Co00001?ooool01Oo<c<coA4A4o`000?l@
413o000000?ooooo00?o0000ooooooooool01Oooool00omEEEGoIVIVo`000004ooooo`05o`000?lb
<S;o0000oc8b<_l000000oooool00ol0003oooooooooo`02ooooo`?o00000_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMomVIVKoooooooooool000000oooool00ol0003oooooooooo`0;ooooo`03
oa0@4?l0003o^[Zj00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`000;Kooooo002eooooo`05oa0@4?ooooooooooooooool@41003_ooool01Onj^[[o8B4Qoooooooo
oooo410@00?ooooo00?o410@ooooooooool03Oooool01Ol0003ooooooooooooooooo410@00?ooooo
00?o410@ooooooooool03?ooool00ol0003oooooooooo`0Dooooo`05oa0@4?ooooooooooooooool@
41003_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool00oooool01Ol0
003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo410@0oooool00ol@413ooooooooo
o`0<ooooo`05okZj^_lQ8B7oooooooooool@41000oooool00ol@413oooooooooo`0:ooooo`03ogMg
Moo<c<co00000;Kooooo002eooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413oV9RH
oooooonj^[[o000000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool05?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00Oo0000ooooooooooooooooogMgMonHV9Sooooo
00Co00000oooool00ol0003oooooooooo`02ooooo`;o000000Co^[ZjoooooonHV9So410@0_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oiRHV?oooooo^[Zjo`000002ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00002fooooo`00]Oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@02ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`03oeEEEOmVIVKo000001Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03
oeEEEOmVIVKo000000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo
00;ooooo00Ko0000oiRHV?l@413o0000ob4Q8Oo<c<`2ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool01OnYZJWo410@o`000?l@413oZJVY00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=oooo
o`03ogMgMol0003ooooo0;Gooooo003ooooooc3ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`3Uooooo`00ooooool_ooooo`;o00000_ooool4o`000>Oooooo003ooooooooooooo
7oooool00?oooooooooooolOooooo`00oooooooiooooo`;o00000_ooool2o`0001oooooo003ooooo
ooWooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMdOooooo`00ooooooojooooo`04omgMgOl0003o
410@olc<c23ooooo000Koooooooo0000d?l0000?ooooo`04onk^k_lQ8B7o410@onk^kR3ooooo002l
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0V?ooool01?lQ8B7oMgMgogMgMolb
<S8Pooooo`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo09Oooooo0_l00002
ooooo`;o00007oooool00;cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2loooo
o`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;cooooo002looooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0_?ooool00;cooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2looooo`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0;cooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0_?ooool00;co
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2looooo`00_?ooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0;cooooo002looooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0_?ooool00;cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2l
ooooo`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;cooooo002looooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0_?ooool00;cooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`2looooo`00_?ooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0;cooooo002looooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0_?ooool0
0;cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2looooo`00_?ooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo0;cooooo002looooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0_?ooool00;cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`2looooo`00_?oooolHo`0001Ooo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0;cooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;cooooo003Cooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0;cooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;cooooo003Cooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0;cooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0;cooooo003Cooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0;cooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo0;cooooo003Cooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;cooooo
003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0;cooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;cooooo003Coooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0;cooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;cooooo003Cooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0;cooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;cooooo003Cooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0;cooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0;cooooo003Cooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;co
oooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0;cooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;cooooo003C
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0;cooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;cooooo003Cooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0;cooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;cooooo003Cooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0;cooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0;cooooo003Cooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0;cooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo0;cooooo003Cooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;cooooo
003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0;cooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;cooooo003Coooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0;cooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;cooooo003Cooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0;cooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;cooooo003Cooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0;cooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0;cooooo003Cooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;co
oooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0;cooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;cooooo003C
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0;cooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;cooooo003Cooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool001So
00005_oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;cooooo003Cooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0;cooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;cooooo003Cooooo`03o`000?oo003o
o`0001Goo`006?l0000Fool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0;cooooo003Cooooo`03o`000?oo003oo`00
01Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo
01Cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0;cooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003o
o`00ool0000Dool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo0;cooooo003Cooooo`03o`000?oo003oo`0001Goo`00
00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Cooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;cooooo
003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0;cooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000
ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Cooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;cooooo003Coooo
o`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool0
0003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0;cooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool05?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;cooooo003Cooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo01Cooooo00?o0000ool00?oo00005?oo000Ho`000;kooooo003Cooooo`03o`000?oo
003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Cooooo`00doooool0
0ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0doooool0
0=?ooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo
0=?ooooo003Cooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003o
o`00ool0000Dool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`3Cooooo`00dooooolIo`0001Kooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0doooool00?oooooo0ooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3Cooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0=?ooooo003ooooo
o`?ooooo6?l0000Fooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0doooool00?oo
oooo0oooool00ol0003oooooooooo`0[ooooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0doooool00?oooooo0oooool00ol0003oooooooooo`0[ooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0doooool00?oooooo0oooool2o`0002cooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3Cooooo`00ooooool3ooooo`03o`000?oooooooooo02_ooooo6?l0003E
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003Vooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008
ooooo`Co0000oooooolHooooo`00j?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooo
oolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00j?oo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooo
oooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00omEEEGoIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2
o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2
o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00i_ooool4o`000005oa0@4?oooooooooooooooom4A4@00_l00000
2Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool02OmgMgOo<S8booooooooooooMgMgoiRH
V?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000oooo
ooooool01oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00Kooooo1?l0003o
oooooaSooooo003Xooooo`03o`000?oooooooooo00Kooooo00GoMgMgoc8b<_ooooooooooo`000003
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0
003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooo
oooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003V
ooooo`03oeEEEOmVIVKo000000Gooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?oo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oo
oooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo1Ol0
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00So
oooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So8B4Qonk^k_ooooooA4A400?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool0
0ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooo
oooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003ooooooooo
o`3ooooooaWooooo003Wooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000002?ooool4o`000?oooooo6?ooool00>Sooooo00?o
MgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00Go0000oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`06oooo
o`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go0000okZj^_ooooooV9RHoa0@4003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o
0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o
0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o
0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003Uooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Go
oooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooo
oonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00onHV9So8B4Qonk^
kP09ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool01_ooool4o`000?oooooo
6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h01oooool01OmgMgOo<S8boooooooooooo000000?ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ogMgMomV
IVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool0
00002?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000oooooooo
ool0oooooolIooooo`00iOooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooooooo
ool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00iOooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Gooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00
iOooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Yoooo
o`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o
410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ojVYZOl@413o
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
2?ooool4o`000?oooooo6?ooool00>Oooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`00003oooooobCooooo003Xooooo`03okZj
^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@4100oooooolTooooo`00iOooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0oooooolTooooo`00iOooool0
1OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0oooooolTooooo`00oooooooooooooaoooooo003ooooooooooooo7ooo
ool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooo
oooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOoooo
o`00moooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`000?oooooo2Oooool00?Oooooo
00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool0ooooool7ooooo`00jooo
ool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo00Co0000oooooooooooo
oooo0_l00002ooooo`;o00000oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4
A?nj^[X01?ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?oooooooooooooo
ool000001_ooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03
olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo
0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
00;ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?oooooo1oooool00>cooooo1Ol00006ooooo`03o`000?oooooooooo00;ooooo00Co8B4Q
ogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1ooo
ool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooooooo`;o0000
0_ooool2o`0000Sooooo00?o410@o`000?l000000ol00005ooooo`03o`000?oooooooooo0?oooooo
1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003[ooooo`04oa0@4?l0
003o0000ooooo`;o000000?o410@ooooooooool00oooool2o`0001;ooooo00?o0000ooooooooool0
1Oooool2o`000?oooooo2Oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooo
oooooooo7oooool00001\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.11695, -22.4749, \
0.0054076, 1.31245}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.3 -0.0125 -12 -9 ]
[.3 -0.0125 12 0 ]
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.3 0 m
.3 .00625 L
s
[(-0.4)] .3 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.3 0 m
.3 .00206 L
.35 .00206 L
.35 0 L
F
0 g
.5 Mabswid
.3 0 m
.3 .00206 L
.35 .00206 L
.35 0 L
.3 0 L
s
1 0 0 r
.35 0 m
.35 .0412 L
.4 .0412 L
.4 0 L
F
0 g
.35 0 m
.35 .0412 L
.4 .0412 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .15451 L
.45 .15451 L
.45 0 L
F
0 g
.4 0 m
.4 .15451 L
.45 .15451 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .11537 L
.5 .11537 L
.5 0 L
F
0 g
.45 0 m
.45 .11537 L
.5 .11537 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .16069 L
.55 .16069 L
.55 0 L
F
0 g
.5 0 m
.5 .16069 L
.55 .16069 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .16687 L
.6 .16687 L
.6 0 L
F
0 g
.55 0 m
.55 .16687 L
.6 .16687 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .0824 L
.65 .0824 L
.65 0 L
F
0 g
.6 0 m
.6 .0824 L
.65 .0824 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .21631 L
.7 .21631 L
.7 0 L
F
0 g
.65 0 m
.65 .21631 L
.7 .21631 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .09064 L
.75 .09064 L
.75 0 L
F
0 g
.7 0 m
.7 .09064 L
.75 .09064 L
.75 0 L
.7 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool009gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool5o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@
4?oooooooooo0;;ooooo002Mooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo
00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@0AOooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B47ooooo`03o`000?oooooooooo0;?ooooo002Eooooo`Ko00000_ooool01Ol@413ooooooooo
oooooooo410@00_ooooo1Ol0000Booooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00co
oooo00?oV9RHob4Q8Oo^k^h0A_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q
8Oo^k^h06_ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0002dooooo`00WOooool01Ol0
003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00006oooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0AOooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h06Oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgM
gOoooooo0000]Oooool009gooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo
00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo01Sooooo00Go0000oooooooo
ooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`000;Gooooo002Mooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00omgMgOoc<c<o`00000Kooooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`13ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Gooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00002eooooo`00
WOooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000006oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4015ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@01Wooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0<ooooo`03onk^k_m4A4Co00000;Gooooo002Mooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnH
V9So410@o`000?lQ8B7oc<c<04Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`06Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?oo
ool0]?ooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool0
0?oooooooooooolOooooo`00ooooooolooooo`;o00000_ooool2o`0001cooooo003ooooooocooooo
00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMdLooooo`00ooooooomooooo`04omgMgOl0003o410@olc<
c1gooooo000Goooooooo0000eol0000?ooooo`04onk^k_lQ8B7o410@onk^kQgooooo002ToooooaSo
00005ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo08;ooooo00Co8B4QogMgMomg
MgOo<S8b7Oooool00:Cooooo00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0POooool2o`0000;ooooo0_l0000Looooo`00
Y?ooool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00^ooooolIo`0001Koo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool001So00005_oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo000Io`000:Gooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?oo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000D
ool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
5?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo
003oo`0001Coo`006Ol0000Fool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?oo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000D
ool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
5Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
5?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo
0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003o
o`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0;_ooooo003CoooooaSo00005oooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo0;_ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`2kooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^ooo
ool00?oooooo0ooooolHo`0001Ooo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000D
ool00003o`000?oooooooooo0;_ooooo003oooooo`?ooooo00?o0000ooooooooool05?ooool00ol0
003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`2kooooo`00ooooool3ooooo`;o00005Oooool00ol0003oo`00ool0000Eool00003
o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00
ooooool3ooooo`03o`000?oooooooooo01Cooooo6Ol0000Fooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0^oooool00?oooooo0oooool00ol0003oooooooooo`13ooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0^oooool00?oooooo0oooool00ol0003oooooooooo`13
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00?oooooo0oooool00ol0
003oooooooooo`13ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00?oo
oooo0oooool00ol0003oooooooooo`13ooooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0^oooool00?oooooo0oooool00ol0003oooooooooo`13ooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0^oooool00?oooooo0oooool00ol0003oooooooooo`13ooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0^oooool00?oooooo0oooool00ol0003oooooooooo`13
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00?oooooo0oooool00ol0
003oooooooooo`13ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00?oo
oooo0oooool2o`0004Cooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00
ooooool3ooooo`03o`000?oooooooooo04?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`2kooooo`00ooooool3ooooo`03o`000?oooooooooo04?ooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2kooooo`00ooooool3ooooo`03o`000?oooooooooo04?ooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00ooooool3ooooo`03o`000?oooooooooo
04?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00ooooool3ooooo`03
o`000?oooooooooo04?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00
ooooool3ooooo`03o`000?oooooooooo04?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`2kooooo`00i_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`13ooooo`03o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0^oooool00>Sooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oo
oooooooo04?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00j?ooool0
0ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooo
oooooooo410@00Sooooo00?o0000ooooooooool0@oooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0;_ooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000002?ooool4o`0004;ooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2kooooo`00j?ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooo
ooooool0@oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Xooooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooo
ooooool@41002?ooool00ol0003oooooooooo`13ooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0^oooool00>Sooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo04?ooooo00?o
0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00i_ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo
00?o0000ooooooooool0@ooooolHo`000;gooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`Co000000Go410@oooooooooooooooo
odA4A002o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000
ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`06ooooo`09ogMgMolb<S;ooooo
oooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?oo
ool00ol0003oooooooooo`07ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool0
1_ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00Kooooo00Go
MgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo1?l0003ooooooaSooooo
003Xooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`00
0?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00So
oooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Kooooo00?oEEEEofIVI_l000001Oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000
oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003Uooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00onH
V9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@00Sooooo1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Xooooo`03ogMgMomVIVKooooo00;ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWo
oooo003Yooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05
o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOooool5o`0000Cooooo
00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0
003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool02Omg
MgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Kooooo00?oV9RHob4Q8Oo^k^h02Oooool01?l0003oooooooooool@4103ooooo`03oa0@
4?oooooooooo00Kooooo1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^00Oooooo00Go
MgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
oooooolIooooo`00j?ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
0_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00
jOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooo
oooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go0000okZj^_oooooo
V9RHoa0@4004ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08oooo
o`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00iOooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo
003Uooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wo
oooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool0
0ol@413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?oZJVYoa0@
4?ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0008ooooo`Co0000oooooolHooooo`00ioooool00ol@413o0000okZj^P03ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo00000?oooooo9?ooool00>Sooooo00?o
^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@403oooooobCooooo003Uooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`3oooooobCooooo003Uoooo
o`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP3oooooobCooooo003ooooooooooooo7oooool00?oooooooooooolO
ooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooo
oooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoo
oooo003gooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o0000ooooool9ooooo`00mooo
ool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`3oooooo`Oooooo003[
ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool01?l0003ooooooooo
ooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003o
A4A4okZj^P04ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000oooooooooooo
ooooo`000006ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo
00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000oooooooo
ool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool00_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0ooooool7ooooo`00k?ooool5o`0000Kooooo00?o0000ooooooooool00_ooool01?lQ
8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7
ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooooooo0_l0
0002ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool0oooo
ool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>_ooooo00Co410@
o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`;o00004_ooool00ol0003ooooooooo
o`05ooooo`;o0000ooooool9ooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oo
oooooooooolOooooo`00\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .05356 L
.4 .05356 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .05356 L
.4 .05356 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .13185 L
.45 .13185 L
.45 0 L
F
0 g
.4 0 m
.4 .13185 L
.45 .13185 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .14009 L
.5 .14009 L
.5 0 L
F
0 g
.45 0 m
.45 .14009 L
.5 .14009 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .16481 L
.55 .16481 L
.55 0 L
F
0 g
.5 0 m
.5 .16481 L
.55 .16481 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .18335 L
.6 .18335 L
.6 0 L
F
0 g
.55 0 m
.55 .18335 L
.6 .18335 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .07828 L
.65 .07828 L
.65 0 L
F
0 g
.6 0 m
.6 .07828 L
.65 .07828 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .09064 L
.7 .09064 L
.7 0 L
F
0 g
.65 0 m
.65 .09064 L
.7 .09064 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .18747 L
.75 .18747 L
.75 0 L
F
0 g
.7 0 m
.7 .18747 L
.75 .18747 L
.75 0 L
.7 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo0;;ooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Oooooo00?o0000ooooooooool0/oooool00<Cooooo1_l00002ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002oooool5o`000;Cooooo
003<ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP15ooooo`05o`00
0?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP0Iooooo`05o`000?oooooooooooooo
ool000002oooool01?m4A4CogMgMooooool0002eooooo`00c?ooool01Ol0003ooooooooooooooooo
000000kooooo00?oMgMgofIVI_ooool0A?ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool06?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo
0000]Oooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co00000;Gooooo003<ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?ok^k^odA4A?l00000]Oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`0AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c00Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo
0000ooooo`2dooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolO
ooooo`00oooooooooooooaoooooo003ooooooocooooo0_l00002ooooo`;o00007?ooool00?oooooo
o?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAcooooo003ooooooogooooo00CogMgMo`000?l@
413oc<c<7Oooool001Ooooooool0003Go`0000oooooo00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo08;o
oooo00Co8B4QogMgMomgMgOo<S8b7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo087ooooo0_l00002ooooo`;o00007?ooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0:?ooooo002koooooaWo00005_oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2S
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo000Ho`0001Koo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
01Cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?oooolHo`0001Oo
o`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`0[ooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`0[ooooo`03o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0[
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`0[ooooo`03o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0[ooooo`03
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`0[ooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0[ooooo`03o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`0[ooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0[ooooo`03o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`0[ooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0[ooooo`03o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`0[ooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`0[ooooo`03o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0[oooo
o`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`0[ooooo`03o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0[ooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`0[ooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xooo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0[ooooo`03o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`0[ooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?o
oooo6?l0000Gool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`0[ooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00>[ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0:oooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
003Zooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo02_ooooo00?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00j_ooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`0[ooooo`03o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00>[ooooo6Ol0000Fool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0:oooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003oooooo`?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo02_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00ooooool3ooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0[ooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00?oooooo0oooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0:oooool00ol0003oo`00ool0
000Eool00003o`000?oooooooooo0:?ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo02_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`2Sooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`0[ooooo`03o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0Xoooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0:oooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo02_ooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00oooo
ool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`0[ooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00?oooooo0oooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0:oooool0
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003oooooo`?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo02_ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00ooooool3oooooaSo00005ooo00000ol0003o
ooooooooo`0[ooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00?oooooo
0oooool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
:oooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003oooooo`?ooooo00?o
0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo02_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00ooooool3ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0[ooooo`03o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0Xoooool00?oooooo0oooool00ol0003oooooooooo`0Doooo
o`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0:oooool00ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo003oooooo`?ooooo00?o0000ooooooooool05?ooool00ol0003o
o`00ool0000Eool00003o`000?oooooooooo02_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`2Sooooo`00ooooool3ooooo`03o`000?oooooooooo01Cooooo00?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`0[ooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
Xoooool00?oooooo0oooool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0:oooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003o
ooooo`?ooooo00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooo
oooo02_ooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00ooooool3oooo
o`03o`000?oooooooooo01Cooooo6Ol0000]ooooo`03o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0Xoooool00?oooooo0oooool2o`0005_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`2Sooooo`00ooooool3ooooo`03o`000?oooooooooo05[ooooo6Ol0002Uooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003Vooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`Co0000oooooolHooooo`00
j?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003o
ooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo
410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o
0000ooooooooool0oooooolIooooo`00i_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo
6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo
6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo
6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00i_ooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000002Olb<S;ogMgM
ooooooooooook^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0>Sooooo00?o0000ooooooooool01_ooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RH
ogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01ooo
ool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0
oooooolIooooo`00j?ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool00000
0oooool00ol0003oooooooooo`06ooooo`Co0000oooooolHooooo`00j?ooool00ol0003ooooooooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000So
oooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oeEE
EOmVIVKo000000Gooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o
0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o
0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOoo
ool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08
ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@
413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`Co0000oooo
oolHooooo`00ioooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00j?oo
ool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00jOooool01Ol0003ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo
00Kooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[ZjoooooonHV9So410@
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?oo
ool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00>Gooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oM
gMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00iOooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00WoMgMgoc8b<_ooooooooooogMgMonH
V9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`06ooooo`Co0000
oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP07ooooo`05ogMgMolb<S;oooooooooool00000
0oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooooooooooo
ooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003o
ooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_oo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_oo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@
4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol@413o^[Zjoooo
oomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`05o`000?oooooooooooooo
ool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01_ooool0
0ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool4o`000?oooooo6?oo
ool00>Oooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`00003oooooobCooooo003Xooooo`03okZj^_lQ8B7ooooo00;ooooo00Go
410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100oooooolTooooo`00
iOooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL0oooooolTooooo`00iOooool01OnYZJWo410@o`000?l@413o
ZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
oooooolTooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOoooo
o`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooo
oooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00moooool2o`0000_ooooo
00?o0000okZj^_ooool03?ooool2o`000?oooooo2Oooool00?Oooooo00?o0000ooooooooool02_oo
ool2oc8b<Pkooooo00?o0000ooooooooool0ooooool7ooooo`00joooool01?l@413o0000o`000?oo
ool2o`000003oa0@4?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o0000
0oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X01?ooool00ol0003o
ooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool02_l0003o
ooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o410@00Cooooo
00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00CogMgMo`000?l@
413oc<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>co
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q
8Ol@413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool0
0>cooooo1Ol00006ooooo`03o`000?oooooooooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000oooo
ooooooooooooo`000006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000Sooooo00?o
410@o`000?l000000ol00005ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o0000ooooo`;o000000?o
410@ooooooooool00oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`000?oooooo2Ooo
ool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00001\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .0721 L
.4 .0721 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .0721 L
.4 .0721 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .16481 L
.45 .16481 L
.45 0 L
F
0 g
.4 0 m
.4 .16481 L
.45 .16481 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .16069 L
.5 .16069 L
.5 0 L
F
0 g
.45 0 m
.45 .16069 L
.5 .16069 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .16687 L
.55 .16687 L
.55 0 L
F
0 g
.5 0 m
.5 .16687 L
.55 .16687 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .16275 L
.6 .16275 L
.6 0 L
F
0 g
.55 0 m
.55 .16275 L
.6 .16275 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .10507 L
.65 .10507 L
.65 0 L
F
0 g
.6 0 m
.6 .10507 L
.65 .10507 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .07416 L
.7 .07416 L
.7 0 L
F
0 g
.65 0 m
.65 .07416 L
.7 .07416 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .09477 L
.75 .09477 L
.75 0 L
F
0 g
.7 0 m
.7 .09477 L
.75 .09477 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .02884 L
.8 .02884 L
.8 0 L
F
0 g
.75 0 m
.75 .02884 L
.8 .02884 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08co
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo000Ho`0008kooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xooo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00
^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo6Ol0000F
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo000Ho`0001Ooo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xooo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05?ooool00ol0
003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`0D
oooooaWo0000YOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`006?l0003Dooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yoooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Y
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Coooo
o`03o`000?oo003oo`0001Coo`006Ol0000Fool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03
o`000?oo003oo`0001Coo`006Ol0003[ooooo`00dooooolHo`0001Oooooo00?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`3oooooo`;ooooo003oooooo`?ooooo6?l0003oooooo`Cooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Kooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o
0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo1?l0003ooooooaSooooo
003Xooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool0
0ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooo
oolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooo
oolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooo
oolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003Vooooo`Co000000Go410@ooooooooooooooooodA4A002o`000009oc8b<_oM
gMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00j?ooool00ol0003oooooooooo`06ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonH
V9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`07
ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool01_ooool00ol0003ooooooooo
o`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00Kooooo00GoMgMgoc8b<_ooooooooooo`00
0003ooooo`03o`000?oooooooooo00Kooooo1?l0003ooooooaSooooo003Xooooo`03o`000?oooooo
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool00000
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0
oooooolIooooo`00j?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?o
EEEEofIVI_l000001Oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003U
ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo1?l0003o
oooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003X
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`05o`000?oo
ooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooooooo
ool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@
41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08
ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00iOooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8b
omgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWo
oooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool02OmgMgOo<S8booooooooooooMgMg
oiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oV9RH
ob4Q8Oo^k^h02Oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00Kooooo1?l0
003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^00Oooooo00GoMgMgoc8b<_ooooooooooo`00
0003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool0
0omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooo
oooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00jOooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Gooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`00
0?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJ
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJ
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So
410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oa0@4?nj^[[o
ooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00Go0000oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`06oooo
o`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`Co0000oooooolH
ooooo`00ioooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo00000?oooooo9?ooool00>Sooooo00?o^[Zjob4Q8Oooool00_ooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@403oooooobCooooo
003Uooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`3oooooobCooooo003Uooooo`05ojVYZOl@413o0000oa0@
4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooobCooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoo
oooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooo
oooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003gooooo`;o00002ooo
ool00ol0003o^[Zjooooo`0<ooooo`;o0000ooooool9ooooo`00moooool00ol0003oooooooooo`0:
ooooo`;o<S8b3_ooool00ol0003oooooooooo`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o0000
ooooo`;o000000?o410@ooooooooool00oooool01?l0003oooooooooooooool2o`0000;ooooo0_l0
0003ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`00
0?oooooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`0:o`00
0?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo00?oc<c<o`000?l@41001?oo
ool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000ooooooooool0ooooool7ooooo`00k?oo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool01?oMgMgo0000
oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00
k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool01?o^k^ko
8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7oooo
o`00k?ooool5o`0000Kooooo00?o0000ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb<S8;oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003o
oooooooooooooooo000000Kooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00002?ooool0
0ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo0?oooooo1oooool00>_ooooo00Co410@o`000?l0003ooooo0_l00000
0ol@413oooooooooo`03ooooo`;o00004_ooool00ol0003oooooooooo`05ooooo`;o0000ooooool9
ooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .09271 L
.4 .09271 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .09271 L
.4 .09271 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .21013 L
.45 .21013 L
.45 0 L
F
0 g
.4 0 m
.4 .21013 L
.45 .21013 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .16893 L
.5 .16893 L
.5 0 L
F
0 g
.45 0 m
.45 .16893 L
.5 .16893 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .18129 L
.55 .18129 L
.55 0 L
F
0 g
.5 0 m
.5 .18129 L
.55 .18129 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .13391 L
.6 .13391 L
.6 0 L
F
0 g
.55 0 m
.55 .13391 L
.6 .13391 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .15451 L
.65 .15451 L
.65 0 L
F
0 g
.6 0 m
.6 .15451 L
.65 .15451 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .02678 L
.7 .02678 L
.7 0 L
F
0 g
.65 0 m
.65 .02678 L
.7 .02678 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .0206 L
.75 .0206 L
.75 0 L
F
0 g
.7 0 m
.7 .0206 L
.75 .0206 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .0412 L
.8 .0412 L
.8 0 L
F
0 g
.75 0 m
.75 .0412 L
.8 .0412 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`006Ol0000Fool00003o`000?oooooooooo
08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003o
o`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool001So00005oooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo02cooooo00?o
0000ool00?oo00005?oo00000ol0003oooooooooo`2<ooooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`0/
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0S?ooool00;_ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0;?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo02cooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2<ooooo`00
^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`0/ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
S?ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0;?ooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo02cooooo6?l0002>ooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3B
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00
^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Boooo
o`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3Booooo`00^ooooolIo`0001Koo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`006Ol0000Fool00003o`000?oooooooooo0=;ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3B
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool05OoooolHo`000=Cooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_oo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3ooooo
o`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003o
o`0001Coo`006Ol0000Fool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Go
oooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool05OoooolHo`000?oooooo1?ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`0Eooooo`;o0000oooooolJooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo01Gooooo00?o0000ooooooooool0oooooolIooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ooooooooool0oooooolI
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0oooooolIooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Go
oooo00?o0000ooooooooool0oooooolIooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo01Gooooo00?o0000ooooooooool0oooooolIooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo01Gooooo00?o0000ooooooooool0oooooolIooooo`00doooool0
0ol0003oo`00ool0000Dool00008o`000?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000So0000ooooooooooooMgMgoiRHV?ooooooV9RHogMgM`?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o
0000ool00?oo00005?oo00001?l0003oooooooooool@4103ooooo`05oa0@4?ooooooooooooooool@
41000oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo
00?o0000ool00?oo00005?oo00001?l0003oooooooooool00003ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`06ooooo`Co0000oooooolHooooo`00dooooolHo`0000;o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool0
0ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003ooooooooo
o`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo
003Vooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooo
oa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`Co0000
00Go410@ooooooooooooooooodA4A002o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb
<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`06
ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000oooooooo
ool0oooooolIooooo`00j?ooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooooa0@40?o
oooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`00
0?oooooooooo00Kooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Ko
oooo1?l0003ooooooaSooooo003Xooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c002ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413o
oooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08oooo
o`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oEEEEofIVI_l000001Oooool4o`0000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2
o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooo
oolIooooo`00i_ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@00Sooooo1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ogMgMomVIVKooooo00;ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0
003oooooooooo`3ooooooaWooooo003Yooooo`05o`000?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3o
oooooaWooooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00iOooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@01oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03
o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^k^h02Oooool01?l0003ooooo
ooooool@4103ooooo`03oa0@4?oooooooooo00Kooooo1?l0003ooooooaSooooo003Wooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00omgMgOoIVIVooooo`03ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooo
ooooool0oooooolIooooo`00jOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Go
oooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c004ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Uooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00>Wooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo
ooooooooool@41000oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Sooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000008ooooo`Co0000oooooolHooooo`00ioooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo00000?oo
oooo9?ooool00>Sooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@403oooooobCooooo003Uooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`3oooooobCooooo003Uooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP3oooooobCooooo003ooooooooooooo
7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oo
oooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolO
ooooo`00oooooooooooooaoooooo003gooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o
0000ooooool9ooooo`00moooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003ooooo
ooooo`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool0
0oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Co
oooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo0?oooooo1oooool00>co
oooo00Go0000ooooooooooooooooo`000006ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7
Qonj^[[o0000omgMg@?ooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@
00Cooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool5o`0000Kooooo00?o0000
ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co
0000oooooooooooooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Gooooo
00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo
1oooool00>_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`;o0000
4_ooool00ol0003oooooooooo`05ooooo`;o0000ooooool9ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .12773 L
.4 .12773 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .12773 L
.4 .12773 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .18129 L
.45 .18129 L
.45 0 L
F
0 g
.4 0 m
.4 .18129 L
.45 .18129 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .16893 L
.5 .16893 L
.5 0 L
F
0 g
.45 0 m
.45 .16893 L
.5 .16893 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .19571 L
.55 .19571 L
.55 0 L
F
0 g
.5 0 m
.5 .19571 L
.55 .19571 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .13803 L
.6 .13803 L
.6 0 L
F
0 g
.55 0 m
.55 .13803 L
.6 .13803 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .15039 L
.65 .15039 L
.65 0 L
F
0 g
.6 0 m
.6 .15039 L
.65 .15039 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .03914 L
.7 .03914 L
.7 0 L
F
0 g
.65 0 m
.65 .03914 L
.7 .03914 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .01648 L
.75 .01648 L
.75 0 L
F
0 g
.7 0 m
.7 .01648 L
.75 .01648 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .0103 L
.8 .0103 L
.8 0 L
F
0 g
.75 0 m
.75 .0103 L
.8 .0103 L
.8 0 L
.75 0 L
s
1 0 0 r
.8 0 m
.8 .00206 L
.85 .00206 L
.85 0 L
F
0 g
.8 0 m
.8 .00206 L
.85 .00206 L
.85 0 L
.8 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`006Ol0001Eooooo`04ob4Q8OmgMgOoMgMgoc8b<Qgo
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo06[ooooo0_l00002ooooo`;o00007?ooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0S?ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0S?ooool00;_ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool001So0000S_ooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool001Wo0000YOooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2koooo
o`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`006?l0002mooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Boooo
o`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3B
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00
^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Boooo
o`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3B
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00
^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`3Booooo`00^ooooolIo`0001Koo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`006Ol0000Fool0
0003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Ooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`0EoooooaSo0000e?ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_oo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3ooooo
o`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003o
o`0001Coo`006Ol0000Fool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Go
oooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`3oooooo`;ooooo003CoooooaSo00005oooool00ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo
0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oo
oooo0_ooool00?oooooo0ooooolHo`000?oooooo1?ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003Vooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>So
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`Co0000
oooooolHooooo`00j?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00
j?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00omEEEGoIVIVo`000004oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00i_ooool4o`000005oa0@4?oooooooooooooooom4A4@00_l0
00002Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool02OmgMgOo<S8booooooooooooMgMg
oiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000
ooooooooool01oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00Kooooo00?o
0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;o
ooooooooool000000oooool00ol0003oooooooooo`06ooooo`Co0000oooooolHooooo`00j?ooool0
0ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooo
oooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo
003Vooooo`03oeEEEOmVIVKo000000Gooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_oo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00iOooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^
k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008
ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooo
oolIooooo`00j?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00jOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[Zj
oooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo1Ol00004ooooo`05odA4A?l0
003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooooooo
ool0oooooolIooooo`00iOooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00WoMgMgoc8b<_oo
ooooooooogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003V
ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00Co0000oooooooooooo410@0oooool00ol@413ooooooooo
o`06ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP07ooooo`05ogMgMolb<S;o
ooooooooool000000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Sooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go
0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@4100
1?ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2
o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2
o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Go
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool0
1Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`05o`00
0?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooo
ooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ojVYZOl@413ooooo00;o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool4
o`000?oooooo6?ooool00>Oooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`00003oooooobCooooo003Xooooo`03okZj^_lQ8B7o
oooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100
oooooolTooooo`00iOooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0oooooolTooooo`00iOooool01OnYZJWo
410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h0oooooolTooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oo
oooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolO
ooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00mooo
ool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`000?oooooo2Oooool00?Oooooo00?o0000
ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool0ooooool7ooooo`00joooool01?l@
413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l0
0002ooooo`;o00000oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X0
1?ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool00000
1_ooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0
003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo0?oooooo
1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo
00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oo
oooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;o
oooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
0?oooooo1oooool00>cooooo1Ol00006ooooo`03o`000?oooooooooo00;ooooo00Co8B4QogMgMomg
MgOo<S8b2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>co
oooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2
o`0000Sooooo00?o410@o`000?l000000ol00005ooooo`03o`000?oooooooooo0?oooooo1oooool0
0>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o0000
ooooo`;o000000?o410@ooooooooool00oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2
o`000?oooooo2Oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo
7oooool00001\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .09477 L
.4 .09477 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .09477 L
.4 .09477 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .16687 L
.45 .16687 L
.45 0 L
F
0 g
.4 0 m
.4 .16687 L
.45 .16687 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .14833 L
.5 .14833 L
.5 0 L
F
0 g
.45 0 m
.45 .14833 L
.5 .14833 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .20395 L
.55 .20395 L
.55 0 L
F
0 g
.5 0 m
.5 .20395 L
.55 .20395 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .15451 L
.6 .15451 L
.6 0 L
F
0 g
.55 0 m
.55 .15451 L
.6 .15451 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .14627 L
.65 .14627 L
.65 0 L
F
0 g
.6 0 m
.6 .14627 L
.65 .14627 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .10713 L
.7 .10713 L
.7 0 L
F
0 g
.65 0 m
.65 .10713 L
.7 .10713 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .00824 L
.75 .00824 L
.75 0 L
F
0 g
.7 0 m
.7 .00824 L
.75 .00824 L
.75 0 L
.7 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo0;;ooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Oooooo00?o0000ooooooooool0/oooool00<Cooooo1_l00002ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002oooool5o`000;Cooooo
003<ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP15ooooo`05o`00
0?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP0Iooooo`05o`000?oooooooooooooo
ool000002oooool01?m4A4CogMgMooooool0002eooooo`00c?ooool01Ol0003ooooooooooooooooo
000000kooooo00?oMgMgofIVI_ooool0A?ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool06?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo
0000]Oooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co00000;Gooooo003<ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?ok^k^odA4A?l00000]Oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`0AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c00Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo
0000ooooo`2dooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolO
ooooo`00oooooooooooooaoooooo003ooooooocooooo0_l00002ooooo`;o00007?ooool00?oooooo
o?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAcooooo003ooooooogooooo00CogMgMo`000?l@
413oc<c<7Oooool001Ooooooool0003Go`0000oooooo00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo08;o
oooo00Co8B4QogMgMomgMgOo<S8b7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo087ooooo0_l00002ooooo`;o00007?ooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`006Ol0002Uooooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00
^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2koooo
o`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2k
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^ooo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`2kooooo`00^ooooolIo`0001Koo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo000Ho`000;gooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo
003oo`0001Coo`006Ol0000Fool00003o`000?oo003oo`0001Goo`006?l0003Dooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`006Ol0003[ooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Ooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo
01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo0?oooooo0_ooool00=?ooooo6?l0000Gooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0oooo
ool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2
ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2oooo
o`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00
ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00oooo
ool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3oooo
o`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00i_ooool4o`000008oa0@4?oo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00>Sooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`08ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00j?ooool0
0ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooo
oooooooo410@00Sooooo6?l0003oooooo`Cooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool4o`000?oo
oooo6?ooool00>Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>So
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooo
oooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Kooooo1?l000001Ol@413oooooooooooooooooA4A400;o0000
00Wo<S8bomgMgOooooooooooonk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3o
oooooaWooooo003Xooooo`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonH
V9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oo
oooooooo00Oooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`06ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool01OmgMgOo<S8boooo
oooooooo000000?ooooo00?o0000ooooooooool01_ooool4o`000?oooooo6?ooool00>Sooooo00?o
0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooooooooooo
ooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00
i_ooool00omEEEGoIVIVo`000005ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00So
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Gooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So8B4Q
onk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oiRHV?lQ8B7ok^k^
00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?oo
ool4o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Sooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo
00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@
413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go0000okZj^_oo
ooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lQ
8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`Go00001?ooool01Om4A4Co0000
o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`09ogMgMolb<S;ooooo
oooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_oo
ool00onHV9So8B4Qonk^kP09ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool0
1_ooool4o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h01oooool01OmgMgOo<S8boooo
oooooooo000000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo
003Xooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`00
0?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00So
oooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[ZjoooooonHV9So410@00Co
oooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Uoooo
o`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go
410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00jOooool01Ol0003o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooo
oooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00onYZJWo410@ooooo`02oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo1?l0
003ooooooaSooooo003Wooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool00000oooooolTooooo`00j?ooool00onj^[[o8B4Qoooo
o`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@0?oo
oooo9?ooool00>Gooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?oooooo9?ooool00>Gooooo00GoZJVYoa0@
4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^0?oooooo9?ooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooo
oooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7ooo
ool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?Oooooo
0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo0_l0003oooooo`Wooooo003gooooo`03o`000?oo
oooooooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo0?oooooo1oooool00>_ooooo00Co410@
o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o0000
0_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Co
oooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Ko
oooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000
oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003oooooooooo`3oooooo`Oo
oooo003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`04
omgMgOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooo
o`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02oooo
o`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3o
ooooo`Oooooo003/ooooo`Go00001_ooool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMg
oc8b<P_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003/oooo
o`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l0
0008ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0003oooooooooo`3oooooo`Oooooo003/
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00joooool01?l@413o0000o`000?oo
ool2o`000003oa0@4?oooooooooo00?ooooo0_l0000Booooo`03o`000?oooooooooo00Gooooo0_l0
003oooooo`Wooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoo
oooo0000\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .06798 L
.4 .06798 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .06798 L
.4 .06798 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .14421 L
.45 .14421 L
.45 0 L
F
0 g
.4 0 m
.4 .14421 L
.45 .14421 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .11743 L
.5 .11743 L
.5 0 L
F
0 g
.45 0 m
.45 .11743 L
.5 .11743 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .20189 L
.55 .20189 L
.55 0 L
F
0 g
.5 0 m
.5 .20189 L
.55 .20189 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .18335 L
.6 .18335 L
.6 0 L
F
0 g
.55 0 m
.55 .18335 L
.6 .18335 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .11125 L
.65 .11125 L
.65 0 L
F
0 g
.6 0 m
.6 .11125 L
.65 .11125 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .20189 L
.7 .20189 L
.7 0 L
F
0 g
.65 0 m
.65 .20189 L
.7 .20189 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .00206 L
.75 .00206 L
.75 0 L
F
0 g
.7 0 m
.7 .00206 L
.75 .00206 L
.75 0 L
.7 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo0;;ooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Oooooo00?o0000ooooooooool0/oooool00<Cooooo1_l00002ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002oooool5o`000;Cooooo
003<ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP15ooooo`05o`00
0?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP0Iooooo`05o`000?oooooooooooooo
ool000002oooool01?m4A4CogMgMooooool0002eooooo`00c?ooool01Ol0003ooooooooooooooooo
000000kooooo00?oMgMgofIVI_ooool0A?ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool06?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo
0000]Oooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co00000;Gooooo003<ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?ok^k^odA4A?l00000]Oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`0AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c00Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo
0000ooooo`2dooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolO
ooooo`00oooooooooooooaoooooo003ooooooocooooo0_l00002ooooo`;o00007?ooool00?oooooo
o?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAcooooo003ooooooogooooo00CogMgMo`000?l@
413oc<c<7Oooool001Ooooooool0003Go`0000oooooo00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo000Io`0008Cooooo00Co8B4QogMgMomgMgOo<S8b7Oooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2Iooooo`;o00000_ooool2o`0001co
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00
^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2koooo
o`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2k
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^ooooolIo`0001Ko
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`006?l0000Fool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`006Ol0000F
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000D
ool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
5Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
5?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo
0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003o
o`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool05?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003CoooooaSo0000
5oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
5?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003oooooo`?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o
0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00ooooool3ooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0^oooool00?oooooo0oooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0;_ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`2kooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
^oooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003o
ooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00ooooool3oooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0Doooo
o`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00?oooooo0oooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003o
o`00ool0000Dool00003o`000?oooooooooo0;_ooooo003oooooo`?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`2kooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0^oooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0;_ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2koooo
o`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00?oooooo
0oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
5?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003oooooo`?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o
0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00ooooool3ooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0^oooool00?oooooo0oooool00ol0003oo`00ool0000Dool0
01Wo00005_ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003oooooo`?o
oooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0/ooooo`03o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0^oooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo02cooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00oooo
ool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0;?ooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo0;_ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`0/ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool0
0?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo02cooooo00?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`2kooooo`00ooooool3ooooo`03o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0;?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_o
oooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0/ooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00>Kooooo1?l000002?l@413ooooooooo
ooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`0/ooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0^oooool00>Sooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08oooooaSo0000;_oooolHo`000;gooooo003X
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oo
ooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00002?ooool4o`000?oooooo6?ooool00>Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0>Sooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oEEEE
ofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo1?l000001Ol@413ooooooooo
ooooooooA4A400;o000000Wo<S8bomgMgOooooooooooonk^k_lb<S;o0000oc8b<_o^k^h02?ooool0
0ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00Kooooo00WoMgMgoc8b
<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo
003Xooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo410@0oooool00ol@413ooooo
ooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_oo
ool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool01_ooool4o`000?oooooo
6?ooool00>Sooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo
00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000oooooooo
ool0oooooolIooooo`00i_ooool00omEEEGoIVIVo`000005ooooo`Co00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Gooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00
iOooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Voooo
o`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo
ooooooooool@41002?ooool4o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Sooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Wooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Go
oooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool0
1OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooo
oa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooo
oa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooo
oa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`Go0000
1?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08oooo
o`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A007oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0
oooooolIooooo`00i_ooool00onHV9So8B4Qonk^kP09ooooo`04o`000?oooooooooooa0@40?ooooo
00?o410@ooooooooool01_ooool4o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h01ooo
ool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Xooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c002ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWo
oooo003Yooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol@413ooooo
oooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[Zj
oooooonHV9So410@00Cooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lQ8B7oc<c<
00Cooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJ
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJ
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003Uooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Gooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00jOooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00onY
ZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000Sooooo1?l0003ooooooaSooooo003Wooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000oooooolTooooo`00j?oo
ool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooo
oooooooooooo410@0?oooooo9?ooool00>Gooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?oooooo9?ooool0
0>Gooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^0?oooooo9?ooool00?oooooooooooolOooooo`00oooooooo
oooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo
003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooo
oooo7oooool00?Oooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo0_l0003oooooo`Wooooo
003gooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo0?oooooo1ooo
ool00>_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`04o`000?oo
ooooooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000
o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooo
oooooooooooo000000Kooooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM
0oooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003o
ooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`02ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`3oooooo`Oooooo003/ooooo`Go00001_ooool00ol0003oooooooooo`02oooo
o`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3o
ooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003ooooooooooooo
ool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0003ooooooooo
o`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00joooool0
1?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo0_l0000Booooo`03o`000?oo
oooooooo00Gooooo0_l0003oooooo`Wooooo003ooooooooooooo7oooool00?oooooooooooolOoooo
o`00oooooooooooooaoooooo0000\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .08034 L
.4 .08034 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .08034 L
.4 .08034 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .14215 L
.45 .14215 L
.45 0 L
F
0 g
.4 0 m
.4 .14215 L
.45 .14215 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .15863 L
.5 .15863 L
.5 0 L
F
0 g
.45 0 m
.45 .15863 L
.5 .15863 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .16069 L
.55 .16069 L
.55 0 L
F
0 g
.5 0 m
.5 .16069 L
.55 .16069 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .14215 L
.6 .14215 L
.6 0 L
F
0 g
.55 0 m
.55 .14215 L
.6 .14215 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .08446 L
.65 .08446 L
.65 0 L
F
0 g
.6 0 m
.6 .08446 L
.65 .08446 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .14215 L
.7 .14215 L
.7 0 L
F
0 g
.65 0 m
.65 .14215 L
.7 .14215 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .11949 L
.75 .11949 L
.75 0 L
F
0 g
.7 0 m
.7 .11949 L
.75 .11949 L
.75 0 L
.7 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo0;;ooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Oooooo00?o0000ooooooooool0/oooool00<Cooooo1_l00002ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002oooool5o`000;Cooooo
003<ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP15ooooo`05o`00
0?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP0Iooooo`05o`000?oooooooooooooo
ool000002oooool01?m4A4CogMgMooooool0002eooooo`00c?ooool01Ol0003ooooooooooooooooo
000000kooooo00?oMgMgofIVI_ooool0A?ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool06?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo
0000]Oooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co00000;Gooooo003<ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?ok^k^odA4A?l00000]Oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`0AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c00Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo
0000ooooo`2dooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolO
ooooo`00oooooooooooooaoooooo003ooooooocooooo0_l00002ooooo`;o00007?ooool00?oooooo
o?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAcooooo003ooooooogooooo00CogMgMo`000?l@
413oc<c<7Oooool001Ooooooool0003Go`0000oooooo00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo08;o
oooo00Co8B4QogMgMomgMgOo<S8b7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo087ooooo0_l00002ooooo`;o00007?ooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xooo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00
^ooooolIo`0001Koo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool001So00005_oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool05?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo01Co
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool05?ooool00ol0003oo`00ool0000Dool001Wo0000YOooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^ooo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0D
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0^oooool00=?ooooo6?l0000Gool00003o`000?oo003oo`0001Coo`006Ol0000FoooooaSo
0000_Oooool00>[ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0?oooooo0_ooool00>[ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0?oooooo0_ooool00>[ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00>[ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00>[o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oo
oooo0_ooool00>[ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0?oooooo0_ooool00>[ooooo6Ol0000Fool00003o`000?oooooooooo0?oooooo0_oo
ool00?oooooo0ooooolHo`000?oooooo1?ooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003Vooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^
kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0>Sooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooo
oa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`Co
0000oooooolHooooo`00j?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIoooo
o`00j?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00i_ooool4o`000005oa0@4?oooooooooooooooom4A4@0
0_l000002Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool02OmgMgOo<S8boooooooooooo
MgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o
0000ooooooooool01oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00Kooooo
00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`06ooooo`05ogMgMolb
<S;oooooooooool000000oooool00ol0003oooooooooo`06ooooo`Co0000oooooolHooooo`00j?oo
ool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooo
oooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@4008ooooo`03
o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWo
oooo003Vooooo`03oeEEEOmVIVKo000000Gooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo
6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00iOooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q
8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
4008ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
oooooolIooooo`00j?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00
jOooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003oooo
o`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o
^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo1Ol00004ooooo`05odA4
A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00iOooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00WoMgMgoc8b
<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo
003Vooooo`03oiRHV?lQ8B7ok^k^00Wooooo00Co0000oooooooooooo410@0oooool00ol@413ooooo
ooooo`06ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP07ooooo`05ogMgMolb
<S;oooooooooool000000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Sooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo
00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@
41001?ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0
003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`00
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0>Gooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOoo
ool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`05
o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@
ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ojVYZOl@413ooooo
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?oo
ool4o`000?oooooo6?ooool00>Oooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`00003oooooobCooooo003Xooooo`03okZj^_lQ
8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
4100oooooolTooooo`00iOooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0oooooolTooooo`00iOooool01OnY
ZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h0oooooolTooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool0
0?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooo
oolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00
moooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`000?oooooo2Oooool00?Oooooo00?o
0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool0ooooool7ooooo`00joooool0
1?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo00Co0000oooooooooooooooo
0_l00002ooooo`;o00000oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj
^[X01?ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool0
00001_ooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<
c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo0?oo
oooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;o
oooo00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo0?oooooo1oooool00>cooooo1Ol00006ooooo`03o`000?oooooooooo00;ooooo00Co8B4QogMg
MomgMgOo<S8b2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool0
0>cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooooooo`;o00000_oo
ool2o`0000Sooooo00?o410@o`000?l000000ol00005ooooo`03o`000?oooooooooo0?oooooo1ooo
ool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o
0000ooooo`;o000000?o410@ooooooooool00oooool2o`0001;ooooo00?o0000ooooooooool01Ooo
ool2o`000?oooooo2Oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooo
oooo7oooool00001\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .05768 L
.4 .05768 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .05768 L
.4 .05768 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .16275 L
.45 .16275 L
.45 0 L
F
0 g
.4 0 m
.4 .16275 L
.45 .16275 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .14215 L
.5 .14215 L
.5 0 L
F
0 g
.45 0 m
.45 .14215 L
.5 .14215 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .18953 L
.55 .18953 L
.55 0 L
F
0 g
.5 0 m
.5 .18953 L
.55 .18953 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .13597 L
.6 .13597 L
.6 0 L
F
0 g
.55 0 m
.55 .13597 L
.6 .13597 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .11125 L
.65 .11125 L
.65 0 L
F
0 g
.6 0 m
.6 .11125 L
.65 .11125 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .07622 L
.7 .07622 L
.7 0 L
F
0 g
.65 0 m
.65 .07622 L
.7 .07622 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .15451 L
.75 .15451 L
.75 0 L
F
0 g
.7 0 m
.7 .15451 L
.75 .15451 L
.75 0 L
.7 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo0;;ooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Oooooo00?o0000ooooooooool0/oooool00<Cooooo1_l00002ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002oooool5o`000;Cooooo
003<ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP15ooooo`05o`00
0?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP0Iooooo`05o`000?oooooooooooooo
ool000002oooool01?m4A4CogMgMooooool0002eooooo`00c?ooool01Ol0003ooooooooooooooooo
000000kooooo00?oMgMgofIVI_ooool0A?ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool06?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo
0000]Oooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co00000;Gooooo003<ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?ok^k^odA4A?l00000]Oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`0AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c00Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo
0000ooooo`2dooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolO
ooooo`00oooooooooooooaoooooo003ooooooocooooo0_l00002ooooo`;o00007?ooool00?oooooo
o?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAcooooo003ooooooogooooo00CogMgMo`000?l@
413oc<c<7Oooool001Ooooooool0003Go`0000oooooo00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo08;o
oooo00Co8B4QogMgMomgMgOo<S8b7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo087ooooo0_l00002ooooo`;o00007?ooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo6Ol0000Fool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`006?l0000Gool00003o`000?oooooooooo0:?ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Dooooo`03
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05?ooool00ol0003o
o`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Doooo
o`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xooo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05?ooool00ol0
003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`006?l0000Fooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0[ooooo`03o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`0[ooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`0[ooooo`03o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0[oooo
o`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`0[ooooo`03o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0[ooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`0[ooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xooo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0[ooooo`03o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`0[ooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0[ooooo`03o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`0[ooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`006Ol0
000]ooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0@oooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo04?ooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Soooo
o`00doooool00ol0003oo`00ool0000Dool001Wo00005_oo00000ol0003oooooooooo`13ooooo`03
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
@oooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo04?ooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`13ooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0@oooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo
0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003o
o`00ool0000Dool00003o`000?oooooooooo04?ooooo6Ol0002Uooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Ooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0ooooool2ooooo`00dooooolHo`0001Oooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3o
ooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3ooooo
o`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;o
oooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo
003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003o
ooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003ooooo
o`?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003oooooo`?o
oooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003oooooo`?ooooo
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003oooooo`?ooooo6?l0
003oooooo`Cooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool4o`000008oa0@4?oo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool0
0ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003ooooooooo
o`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo
003Xooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000002?ooool4o`000?oooooo6?ooool00>Sooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008oooo
o`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Kooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oo
oooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo1?l0
00001Ol@413oooooooooooooooooA4A400;o000000Wo<S8bomgMgOooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo
00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo410@
0oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o
0000ooooooooool01_ooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool0
1_ooool4o`000?oooooo6?ooool00>Sooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05oa0@
4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00So
oooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00omEEEGoIVIVo`000005ooooo`Co0000
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo1Ol00003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooooooo
ool0oooooolIooooo`00iOooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3o
oooooaWooooo003Vooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@41002?ooool4o`000?oooooo6?ooool00>Oooooo00?oV9RH
ob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?oMgMgofIVI_ooool00_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03
o`000?oooooooooo0?oooooo6Oooool00>Wooooo00Go0000oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Gooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooo
oolIooooo`00iOooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003Uooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^
k^koooooodA4A007ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo
00?o0000ooooooooool0oooooolIooooo`00i_ooool00onHV9So8B4Qonk^kP09ooooo`04o`000?oo
oooooooooa0@40?ooooo00?o410@ooooooooool01_ooool4o`000?oooooo6?ooool00>Oooooo00?o
V9RHob4Q8Oo^k^h01oooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ogMgMomVIVKooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Yooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00
iOooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So
410@o`000?lQ8B7oc<c<00Cooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Gooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00jOooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooo
oooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolI
ooooo`00j?ooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000Sooooo1?l0003ooooooaSooooo003Wooooo`03oa0@4?l0003o
^[Zj00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
oooooolTooooo`00j?ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
0oooool01Ol@413ooooooooooooooooo410@0?oooooo9?ooool00>Gooooo00Go410@oiRHV?oooooo
^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg0?oooooo9?ooool00>Gooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^0?oooooo9?ooool00?oooooooooo
oolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00
oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooo
oaoooooo003ooooooooooooo7oooool00?Oooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo
0_l0003oooooo`Wooooo003gooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oo
oooooooo0?oooooo1oooool00>_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413ooooooooo
o`03ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X0
1?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool0ooooool7ooooo`00
k?ooool01Ol0003ooooooooooooooooo000000Kooooo00[o0000ooooooooooooooooonk^k_lQ8B7o
QhN7okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@
41001?ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`02ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`Go00001_ooool00ol0
003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool0
1?l0003oooooooooooooool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o000000?o00001Ooo
ool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooo
ool7ooooo`00joooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo0_l0
000Booooo`03o`000?oooooooooo00Gooooo0_l0003oooooo`Wooooo003ooooooooooooo7oooool0
0?oooooooooooolOooooo`00oooooooooooooaoooooo0000\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .07622 L
.4 .07622 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .07622 L
.4 .07622 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .16687 L
.45 .16687 L
.45 0 L
F
0 g
.4 0 m
.4 .16687 L
.45 .16687 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .12155 L
.5 .12155 L
.5 0 L
F
0 g
.45 0 m
.45 .12155 L
.5 .12155 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .18953 L
.55 .18953 L
.55 0 L
F
0 g
.5 0 m
.5 .18953 L
.55 .18953 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .16069 L
.6 .16069 L
.6 0 L
F
0 g
.55 0 m
.55 .16069 L
.6 .16069 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .14627 L
.65 .14627 L
.65 0 L
F
0 g
.6 0 m
.6 .14627 L
.65 .14627 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .0618 L
.7 .0618 L
.7 0 L
F
0 g
.65 0 m
.65 .0618 L
.7 .0618 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .09064 L
.75 .09064 L
.75 0 L
F
0 g
.7 0 m
.7 .09064 L
.75 .09064 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .01648 L
.8 .01648 L
.8 0 L
F
0 g
.75 0 m
.75 .01648 L
.8 .01648 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
000Ho`0008kooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Soooo
o`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2S
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`006?l0000Gool00003o`000?oooooo
oooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05?ooool00ol0003oo`00
ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo01Cooooo00?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`0D
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002koooooaWo
00005_oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xooo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05?ooool00ol0
003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo01Cooooo6Ol0002Uooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Boooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3B
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`006Ol0000Fool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_oo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Go
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`006?l0003Dooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`006Ol0003[oooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo
0_ooool00=?ooooo6?l0000Gooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0oooo
ool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2
ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2oooo
o`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00
ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00oooo
ool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3oooo
o`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3oooooaSo0000ooooool4
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo1?l000002?l@413oooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolI
ooooo`00j?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool0
1Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000Sooooo1?l0003ooooooaSooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Voooo
o`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`Co000000Go410@
ooooooooooooooooodA4A002o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`06ooooo`09
ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooo
oolIooooo`00j?ooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooooa0@40?ooooo00?o
410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooo
oooo00Kooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo1?l0
003ooooooaSooooo003Xooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c002ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo
003Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Kooooo00?oEEEEofIVI_l000001Oooool4o`0000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oo
oooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00i_ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@00Sooooo1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?oo
ool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ogMgMomVIVKooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Yooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWo
oooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o
0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o
0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o
0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOoo
ool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^k^h02Oooool01?l0003oooooooooool@
4103ooooo`03oa0@4?oooooooooo00Kooooo1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7o
k^k^00Oooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0oooooolIooooo`00j?ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
oooooolIooooo`00jOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go
410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go
0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c004ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`00
0?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`00
0?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003ooooooooo
o`3ooooooaWooooo003Uooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Wooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>So
oooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000008ooooo`Co0000oooooolHooooo`00ioooool00ol@413o0000okZj^P03oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo00000?oooooo9?oo
ool00>Sooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@403oooooobCooooo003Uooooo`05oa0@4?nHV9SooooookZj^_l00000
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`3ooooo
obCooooo003Uooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP3oooooobCooooo003ooooooooooooo7oooool0
0?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooo
oolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00
oooooooooooooaoooooo003gooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o0000oooo
ool9ooooo`00moooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`3o
ooooo`Oooooo003[ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool0
1?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00Go
V9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go
0000ooooooooooooooooo`000006ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o
0000omgMg@?ooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo
00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool5o`0000Kooooo00?o0000oooooooo
ool00_ooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooo
oooooooooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Gooooo00?o0000
ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool0
0>_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`;o00004_ooool0
0ol0003oooooooooo`05ooooo`;o0000ooooool9ooooo`00oooooooooooooaoooooo003ooooooooo
oooo7oooool00?oooooooooooolOooooo`00\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .08034 L
.4 .08034 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .08034 L
.4 .08034 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .17717 L
.45 .17717 L
.45 0 L
F
0 g
.4 0 m
.4 .17717 L
.45 .17717 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .16687 L
.5 .16687 L
.5 0 L
F
0 g
.45 0 m
.45 .16687 L
.5 .16687 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .19159 L
.55 .19159 L
.55 0 L
F
0 g
.5 0 m
.5 .19159 L
.55 .19159 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .17099 L
.6 .17099 L
.6 0 L
F
0 g
.55 0 m
.55 .17099 L
.6 .17099 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .14627 L
.65 .14627 L
.65 0 L
F
0 g
.6 0 m
.6 .14627 L
.65 .14627 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .03914 L
.7 .03914 L
.7 0 L
F
0 g
.65 0 m
.65 .03914 L
.7 .03914 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .01442 L
.75 .01442 L
.75 0 L
F
0 g
.7 0 m
.7 .01442 L
.75 .01442 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .04326 L
.8 .04326 L
.8 0 L
F
0 g
.75 0 m
.75 .04326 L
.8 .04326 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`006Ol0000Fool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo
08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003o
o`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool001So00005oooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo02cooooo00?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`2<ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`0/oooooaSo0000S_ooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00;_ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
d_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00;_ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00;_ooooo6Ol0000Fool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_oo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo000Ho`000=Cooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00dooo
ool00ol0003oo`00ool0000Dool001Wo00005_oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`00
01Coo`006Ol0003[ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Go
oooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0?oooooo0_ooool00=?ooooo6?l0000Gooooo`03o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0oooo
ool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2
ooooo`00ooooool3oooooaSo0000ooooool4ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00i_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xoooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo
ooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
2?ooool4o`000?oooooo6?ooool00>Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>So
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oEEEEofIV
I_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo1?l000001Ol@413ooooooooooooo
ooooA4A400;o000000Wo<S8bomgMgOooooooooooonk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0
003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_oo
ooooooooogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003X
ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo410@0oooool00ol@413ooooooooo
o`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool0
1OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool01_ooool4o`000?oooooo6?oo
ool00>Sooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go
0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0
oooooolIooooo`00i_ooool00omEEEGoIVIVo`000005ooooo`Co00000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Gooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOoo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03
oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooo
ooooool@41002?ooool4o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Sooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Wooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
41000oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo
00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnH
V9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[o
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[o
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[o
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`Go00001?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03
o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`09
ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooo
oolIooooo`00i_ooool00onHV9So8B4Qonk^kP09ooooo`04o`000?oooooooooooa0@40?ooooo00?o
410@ooooooooool01_ooool4o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h01oooool0
1OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`3ooooooaWooooo003Xooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c002ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo
003Yooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[Zjoooo
oonHV9So410@00Cooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00So
oooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lQ8B7oc<c<00Co
oooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003Uooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Gooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00
jOooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003oooo
o`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00onYZJWo
410@ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000Sooooo1?l0003ooooooaSooooo003Wooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000oooooolTooooo`00j?ooool0
0onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooo
oooooooo410@0?oooooo9?ooool00>Gooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?oooooo9?ooool00>Go
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^0?oooooo9?ooool00?oooooooooooolOooooo`00oooooooooooo
oaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo
7oooool00?Oooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo0_l0003oooooo`Wooooo003g
ooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo0?oooooo1oooool0
0>_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`04o`000?oooooo
ooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`00
0?m4A4Co^[Zj00Cooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooo
oooooooo000000Kooooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0ooo
ool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003ooooo
ooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`02ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`3oooooo`Oooooo003/ooooo`Go00001_ooool00ol0003oooooooooo`02ooooo`04
ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooo
o`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooooooool2
o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0003oooooooooo`3o
ooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00joooool01?l@
413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo0_l0000Booooo`03o`000?oooooo
oooo00Gooooo0_l0003oooooo`Wooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00
oooooooooooooaoooooo0000\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .12361 L
.4 .12361 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .12361 L
.4 .12361 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .19571 L
.45 .19571 L
.45 0 L
F
0 g
.4 0 m
.4 .19571 L
.45 .19571 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .14627 L
.5 .14627 L
.5 0 L
F
0 g
.45 0 m
.45 .14627 L
.5 .14627 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .16893 L
.55 .16893 L
.55 0 L
F
0 g
.5 0 m
.5 .16893 L
.55 .16893 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .15245 L
.6 .15245 L
.6 0 L
F
0 g
.55 0 m
.55 .15245 L
.6 .15245 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .12567 L
.65 .12567 L
.65 0 L
F
0 g
.6 0 m
.6 .12567 L
.65 .12567 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .0824 L
.7 .0824 L
.7 0 L
F
0 g
.65 0 m
.65 .0824 L
.7 .0824 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .0103 L
.75 .0103 L
.75 0 L
F
0 g
.7 0 m
.7 .0103 L
.75 .0103 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .0206 L
.8 .0206 L
.8 0 L
F
0 g
.75 0 m
.75 .0206 L
.8 .0206 L
.8 0 L
.75 0 L
s
1 0 0 r
.8 0 m
.8 .00412 L
.85 .00412 L
.85 0 L
F
0 g
.8 0 m
.8 .00412 L
.85 .00412 L
.85 0 L
.8 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`1Cooooo`04ob4Q8OmgMgOoMgMgoc8b<Qgooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool001Wo0000E?ooool2o`0000;ooooo
0_l0000Looooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`2<ooooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2<
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool001Wo00005_oo00000ol0003oooooooooo`2<oooo
o`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2<ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2<ooooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2<ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2<ooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo6?l0002>ooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^ooo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool001So0000_Oooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00;_ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_oo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00;_ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
d_ooool00;_ooooo6Ol0000Fool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_oo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo000Ho`000=Cooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003o
o`0001Coo`006Ol0000Fool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo000Io`000>_o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0oooo
ool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo
0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Ooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`0EoooooaSo0000ooooool4ooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ooooooooool0oooooolIoooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0oooooolIooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo
00?o0000ooooooooool0oooooolIooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0oooooolIooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oooooooooo01Gooooo00?o0000ooooooooool0oooooolIooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ooooooooool0oooooolIoooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0oooooolIooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo
0_l0003ooooooa[ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool05Oooool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool05Oooool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oooooooooo`3ooooooaWo
oooo003CoooooaSo00005oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00i_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xoooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo
ooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
2?ooool4o`000?oooooo6?ooool00>Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>So
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oEEEEofIV
I_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo1?l000001Ol@413ooooooooooooo
ooooA4A400;o000000Wo<S8bomgMgOooooooooooonk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0
003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_oo
ooooooooogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003X
ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo410@0oooool00ol@413ooooooooo
o`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool0
1OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool01_ooool4o`000?oooooo6?oo
ool00>Sooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go
0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0
oooooolIooooo`00i_ooool00omEEEGoIVIVo`000005ooooo`Co00000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Gooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOoo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03
oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooo
ooooool@41002?ooool4o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Sooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Wooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
41000oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo
00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnH
V9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[o
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[o
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[o
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`Go00001?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03
o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`09
ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooo
oolIooooo`00i_ooool00onHV9So8B4Qonk^kP09ooooo`04o`000?oooooooooooa0@40?ooooo00?o
410@ooooooooool01_ooool4o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h01oooool0
1OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`3ooooooaWooooo003Xooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c002ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo
003Yooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[Zjoooo
oonHV9So410@00Cooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00So
oooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lQ8B7oc<c<00Co
oooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003Uooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Gooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00
jOooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003oooo
o`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00onYZJWo
410@ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000Sooooo1?l0003ooooooaSooooo003Wooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000oooooolTooooo`00j?ooool0
0onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooo
oooooooo410@0?oooooo9?ooool00>Gooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?oooooo9?ooool00>Go
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^0?oooooo9?ooool00?oooooooooooolOooooo`00oooooooooooo
oaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo
7oooool00?Oooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo0_l0003oooooo`Wooooo003g
ooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo0?oooooo1oooool0
0>_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`04o`000?oooooo
ooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`00
0?m4A4Co^[Zj00Cooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooo
oooooooo000000Kooooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0ooo
ool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003ooooo
ooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`02ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`3oooooo`Oooooo003/ooooo`Go00001_ooool00ol0003oooooooooo`02ooooo`04
ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooo
o`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooooooool2
o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0003oooooooooo`3o
ooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00joooool01?l@
413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo0_l0000Booooo`03o`000?oooooo
oooo00Gooooo0_l0003oooooo`Wooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00
oooooooooooooaoooooo0000\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .09683 L
.4 .09683 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .09683 L
.4 .09683 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .17099 L
.45 .17099 L
.45 0 L
F
0 g
.4 0 m
.4 .17099 L
.45 .17099 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .15451 L
.5 .15451 L
.5 0 L
F
0 g
.45 0 m
.45 .15451 L
.5 .15451 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .19777 L
.55 .19777 L
.55 0 L
F
0 g
.5 0 m
.5 .19777 L
.55 .19777 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .16275 L
.6 .16275 L
.6 0 L
F
0 g
.55 0 m
.55 .16275 L
.6 .16275 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .08652 L
.65 .08652 L
.65 0 L
F
0 g
.6 0 m
.6 .08652 L
.65 .08652 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .14833 L
.7 .14833 L
.7 0 L
F
0 g
.65 0 m
.65 .14833 L
.7 .14833 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .00412 L
.75 .00412 L
.75 0 L
F
0 g
.7 0 m
.7 .00412 L
.75 .00412 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .00824 L
.8 .00824 L
.8 0 L
F
0 g
.75 0 m
.75 .00824 L
.8 .00824 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool001Wo00005_oo00000ol0003ooooo
ooooo`1Zooooo`;o00000_ooool2o`0001cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05OoooolHo`0008kooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^ooo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00
^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo000Ho`0001Ko
o`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0D
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo6Ol0000Fool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2koooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo01Co
oooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o
0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2k
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
01Cooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2koooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo01Cooooo6?l0002mooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo
00?o0000ool00?oo00005?oo000Io`0001Koo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo000Io`000>_ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`3oooooo`;ooooo003CoooooaSo00005oooool00ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo
0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oo
oooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo
0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_oo
ool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool0
0?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oo
oooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oooooo
0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oooooo0ooo
oolHo`000?oooooo1?ooool00>Kooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;o
k^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00j?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo
1?l0003ooooooaSooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWo
oooo003Xooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oeEEEOmVIVKo0000
00Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?oo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`Co000000Go410@ooooooooooooooooodA4
A002o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`06ooooo`09ogMgMolb<S;ooooooooo
oomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool0
0ol0003oooooooooo`07ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool01_oo
ool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00Kooooo00GoMgMg
oc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo1?l0003ooooooaSooooo003X
ooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00Sooooo
00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Kooooo00?oEEEEofIVI_l000001Oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooo
oolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003Uooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go
V9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00onHV9So
8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo
410@00Sooooo1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooooooo
o`3ooooooaWooooo003Xooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo
003Yooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?o
oooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05o`00
0?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOooool5o`0000Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool02OmgMgOo
<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Kooooo00?oV9RHob4Q8Oo^k^h02Oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oo
oooooooo00Kooooo1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^00Oooooo00GoMgMg
oc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooo
oolIooooo`00j?ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_oo
ool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00jOoo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooo
oa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go0000okZj^_ooooooV9RH
oa0@4004ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03
o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00iOooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003U
ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo
00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@
413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?oZJVYoa0@4?oo
ool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008
ooooo`Co0000oooooolHooooo`00ioooool00ol@413o0000okZj^P03ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo00000?oooooo9?ooool00>Sooooo00?o^[Zj
ob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooo
oa0@403oooooobCooooo003Uooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`3oooooobCooooo003Uooooo`05
ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP3oooooobCooooo003ooooooooooooo7oooool00?oooooooooooolOoooo
o`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooo
oooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo
003gooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o0000ooooool9ooooo`00moooool0
0ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`3oooooo`Oooooo003[oooo
o`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool01?l0003ooooooooooooo
ool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4
okZj^P04ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000oooooooooooooooo
o`000006ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo00?o
c<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000ooooooooool0
ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
0_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0ooooool7ooooo`00k?ooool5o`0000Kooooo00?o0000ooooooooool00_ooool01?lQ8B7o
MgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7oooo
o`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooooooo0_l00002
ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool0ooooool7
ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>_ooooo00Co410@o`00
0?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`;o00004_ooool00ol0003oooooooooo`05
ooooo`;o0000ooooool9ooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooo
oooooolOooooo`00\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .07416 L
.4 .07416 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .07416 L
.4 .07416 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .15039 L
.45 .15039 L
.45 0 L
F
0 g
.4 0 m
.4 .15039 L
.45 .15039 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .14627 L
.5 .14627 L
.5 0 L
F
0 g
.45 0 m
.45 .14627 L
.5 .14627 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .16275 L
.55 .16275 L
.55 0 L
F
0 g
.5 0 m
.5 .16275 L
.55 .16275 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .16069 L
.6 .16069 L
.6 0 L
F
0 g
.55 0 m
.55 .16069 L
.6 .16069 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .13803 L
.65 .13803 L
.65 0 L
F
0 g
.6 0 m
.6 .13803 L
.65 .13803 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .17923 L
.7 .17923 L
.7 0 L
F
0 g
.65 0 m
.65 .17923 L
.7 .17923 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .01854 L
.75 .01854 L
.75 0 L
F
0 g
.7 0 m
.7 .01854 L
.75 .01854 L
.75 0 L
.7 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo0;;ooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Oooooo00?o0000ooooooooool0/oooool00<Cooooo1_l00002ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002oooool5o`000;Cooooo
003<ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP15ooooo`05o`00
0?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP0Iooooo`05o`000?oooooooooooooo
ool000002oooool01?m4A4CogMgMooooool0002eooooo`00c?ooool01Ol0003ooooooooooooooooo
000000kooooo00?oMgMgofIVI_ooool0A?ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool06?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo
0000]Oooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co00000;Gooooo003<ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?ok^k^odA4A?l00000]Oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`0AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c00Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo
0000ooooo`2dooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolO
ooooo`00oooooooooooooaoooooo003ooooooocooooo0_l00002ooooo`;o00007?ooool00?oooooo
o?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAcooooo003ooooooogooooo00CogMgMo`000?l@
413oc<c<7Oooool001Ooooooool0003Go`0000oooooo00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo08;o
oooo00Co8B4QogMgMomgMgOo<S8b7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo087ooooo0_l00002ooooo`;o00007?ooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
000Io`000:Gooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^ooo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo6Ol0000F
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2k
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2koooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2k
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool001So00005_oo00000ol0003oooooooooo`2k
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool001Wo00005_oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2kooooo`00dooooolHo`0001Oooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`2kooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0^oooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_o
oooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00oooo
ool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`0Dooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00?oooooo0oooool0
0ol0003oo`00ool0000Dool001Wo00005_ooool00ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0;_ooooo003oooooo`?ooooo6?l0000^ooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0^oooool00?oooooo0oooool2o`0004Cooooo00?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`2kooooo`00ooooool3ooooo`03o`000?oooooooooo04?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`2kooooo`00ooooool3ooooo`03o`000?oooooooooo04?ooooo00?o
0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00ooooool3ooooo`03o`000?oooooo
oooo04?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00ooooool3oooo
o`03o`000?oooooooooo04?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2koooo
o`00ooooool3ooooo`03o`000?oooooooooo04?ooooo00?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`2kooooo`00ooooool3ooooo`03o`000?oooooooooo04?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`2kooooo`00ooooool3ooooo`03o`000?oooooooooo04?ooooo6?l0
002mooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`Co000000So410@ooooooooooook^k^
oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000008ooooo`Co0000oooooolHooooo`00j?ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooo
ooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolI
ooooo`00j?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool0
0omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000002Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^kP08
ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool02Omg
MgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Sooooo00?o0000ooooooooool01oooool01?l0003oooooooooool@4103ooooo`03oa0@
4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003ooooooooo
o`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`06ooooo`Co0000
oooooolHooooo`00j?ooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
0_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00
j?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooo
oooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Vooooo`03oeEEEOmVIVKo000000Gooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooo
oa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00iOooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWo
oooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0>Kooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@
oooooooooooooooooa0@4008ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP03
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo
00?o0000ooooooooool0oooooolIooooo`00j?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooooooo
ool0oooooolIooooo`00jOooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooooooooa0@4003ooooo`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIoooo
o`00iOooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003U
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`00
0?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`00
0?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`00
0?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo
1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So8B4Qonk^k_ooooooA4A4
00Oooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Vooooo`03oiRHV?lQ8B7ok^k^00Wooooo00Co0000oooooooooooo410@
0oooool00ol@413oooooooooo`06ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^
kP07ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Sooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05oa0@
4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003o
oooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003o
oooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0
oooooolIooooo`00iOooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Yooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo
410@00?ooooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Xoooo
o`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000002?ooool4o`000?oooooo6?ooool00>Oooooo00?o410@o`000?nj^[X00oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00003oooooobCooooo
003Xooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@
4?ooooooooooooooool@4100oooooolTooooo`00iOooool01Ol@413oV9RHoooooonj^[[o000000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0oooooolT
ooooo`00iOooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0oooooolTooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo
7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oo
oooooooooolOooooo`00moooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`000?oooooo
2Oooool00?Oooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool0oooo
ool7ooooo`00joooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo00Co
0000oooooooooooooooo0_l00002ooooo`;o00000oooool00on7QhOo0000okZj^P04ooooo`05oiRH
V?l0003o0000odA4A?nj^[X01?ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`00
0?ooooooooooooooool000001_ooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`00
0?oMgMd3ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03
o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00;ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo1Ol00006ooooo`03o`000?oooooooooo
00;ooooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooo
ooooooooo`;o00000_ooool2o`0000Sooooo00?o410@o`000?l000000ol00005ooooo`03o`000?oo
oooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003[
ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool2o`0001;ooooo00?o
0000ooooooooool01Oooool2o`000?oooooo2Oooool00?oooooooooooolOooooo`00oooooooooooo
oaoooooo003ooooooooooooo7oooool00001\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .05974 L
.4 .05974 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .05974 L
.4 .05974 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .16275 L
.45 .16275 L
.45 0 L
F
0 g
.4 0 m
.4 .16275 L
.45 .16275 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .13803 L
.5 .13803 L
.5 0 L
F
0 g
.45 0 m
.45 .13803 L
.5 .13803 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .17923 L
.55 .17923 L
.55 0 L
F
0 g
.5 0 m
.5 .17923 L
.55 .17923 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .14215 L
.6 .14215 L
.6 0 L
F
0 g
.55 0 m
.55 .14215 L
.6 .14215 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .12361 L
.65 .12361 L
.65 0 L
F
0 g
.6 0 m
.6 .12361 L
.65 .12361 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .09477 L
.7 .09477 L
.7 0 L
F
0 g
.65 0 m
.65 .09477 L
.7 .09477 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .12979 L
.75 .12979 L
.75 0 L
F
0 g
.7 0 m
.7 .12979 L
.75 .12979 L
.75 0 L
.7 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo0;;ooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Oooooo00?o0000ooooooooool0/oooool00<Cooooo1_l00002ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002oooool5o`000;Cooooo
003<ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP15ooooo`05o`00
0?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP0Iooooo`05o`000?oooooooooooooo
ool000002oooool01?m4A4CogMgMooooool0002eooooo`00c?ooool01Ol0003ooooooooooooooooo
000000kooooo00?oMgMgofIVI_ooool0A?ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool06?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo
0000]Oooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co00000;Gooooo003<ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?ok^k^odA4A?l00000]Oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`0AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c00Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo
0000ooooo`2dooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolO
ooooo`00oooooooooooooaoooooo003ooooooocooooo0_l00002ooooo`;o00007?ooool00?oooooo
o?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAcooooo003ooooooogooooo00CogMgMo`000?l@
413oc<c<7Oooool001Ooooooool0003Go`0000oooooo00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo08;o
oooo00Co8B4QogMgMomgMgOo<S8b7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo087ooooo0_l00002ooooo`;o00007?ooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002koooooaWo0000
5_oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xooo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`006?l0
000Gool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Soooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Dooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo01Co
oooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05?ooool00ol0003oo`00
ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2S
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Dooooo`03
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo000Ho`0001Kooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo02_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo02_ooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo02_ooooo6Ol0002Uooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`3Yooooo`00doooool00ol0003oo`00ool0000Dool001Wo00005_oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03
o`000?oo003oo`0001Coo`006Ol0003[ooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oo
oooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo6?l0000Goooo
o`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0ooooool2ooooo`00ooooool3oooooaSo0000ooooool4ooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003Vooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^
kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0>Sooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooo
oa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`Co
0000oooooolHooooo`00j?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIoooo
o`00j?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00i_ooool4o`000005oa0@4?oooooooooooooooom4A4@0
0_l000002Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool02OmgMgOo<S8boooooooooooo
MgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o
0000ooooooooool01oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00Kooooo
00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`06ooooo`05ogMgMolb
<S;oooooooooool000000oooool00ol0003oooooooooo`06ooooo`Co0000oooooolHooooo`00j?oo
ool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooo
oooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@4008ooooo`03
o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWo
oooo003Vooooo`03oeEEEOmVIVKo000000Gooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo
6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00iOooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q
8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
4008ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
oooooolIooooo`00j?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00
jOooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003oooo
o`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o
^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo1Ol00004ooooo`05odA4
A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00iOooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00WoMgMgoc8b
<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo
003Vooooo`03oiRHV?lQ8B7ok^k^00Wooooo00Co0000oooooooooooo410@0oooool00ol@413ooooo
ooooo`06ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP07ooooo`05ogMgMolb
<S;oooooooooool000000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Sooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo
00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@
41001?ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0
003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`00
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0>Gooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOoo
ool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`05
o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@
ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ojVYZOl@413ooooo
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?oo
ool4o`000?oooooo6?ooool00>Oooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`00003oooooobCooooo003Xooooo`03okZj^_lQ
8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
4100oooooolTooooo`00iOooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0oooooolTooooo`00iOooool01OnY
ZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h0oooooolTooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool0
0?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooo
oolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00
moooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`000?oooooo2Oooool00?Oooooo00?o
0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool0ooooool7ooooo`00joooool0
1?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo00Co0000oooooooooooooooo
0_l00002ooooo`;o00000oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj
^[X01?ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool0
00001_ooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<
c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo0?oo
oooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;o
oooo00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo0?oooooo1oooool00>cooooo1Ol00006ooooo`03o`000?oooooooooo00;ooooo00Co8B4QogMg
MomgMgOo<S8b2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool0
0>cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooooooo`;o00000_oo
ool2o`0000Sooooo00?o410@o`000?l000000ol00005ooooo`03o`000?oooooooooo0?oooooo1ooo
ool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o
0000ooooo`;o000000?o410@ooooooooool00oooool2o`0001;ooooo00?o0000ooooooooool01Ooo
ool2o`000?oooooo2Oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooo
oooo7oooool00001\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.3 -0.0125 -12 -9 ]
[.3 -0.0125 12 0 ]
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.3 0 m
.3 .00625 L
s
[(-0.4)] .3 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.3 0 m
.3 .00206 L
.35 .00206 L
.35 0 L
F
0 g
.5 Mabswid
.3 0 m
.3 .00206 L
.35 .00206 L
.35 0 L
.3 0 L
s
1 0 0 r
.35 0 m
.35 .05974 L
.4 .05974 L
.4 0 L
F
0 g
.35 0 m
.35 .05974 L
.4 .05974 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .17717 L
.45 .17717 L
.45 0 L
F
0 g
.4 0 m
.4 .17717 L
.45 .17717 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .13391 L
.5 .13391 L
.5 0 L
F
0 g
.45 0 m
.45 .13391 L
.5 .13391 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .17099 L
.55 .17099 L
.55 0 L
F
0 g
.5 0 m
.5 .17099 L
.55 .17099 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .16275 L
.6 .16275 L
.6 0 L
F
0 g
.55 0 m
.55 .16275 L
.6 .16275 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .12773 L
.65 .12773 L
.65 0 L
F
0 g
.6 0 m
.6 .12773 L
.65 .12773 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .05974 L
.7 .05974 L
.7 0 L
F
0 g
.65 0 m
.65 .05974 L
.7 .05974 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .13597 L
.75 .13597 L
.75 0 L
F
0 g
.7 0 m
.7 .13597 L
.75 .13597 L
.75 0 L
.7 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool009gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool5o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@
4?oooooooooo0;;ooooo002Mooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo
00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@0AOooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B47ooooo`03o`000?oooooooooo0;?ooooo002Eooooo`Ko00000_ooool01Ol@413ooooooooo
oooooooo410@00_ooooo1Ol0000Booooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00co
oooo00?oV9RHob4Q8Oo^k^h0A_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q
8Oo^k^h06_ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0002dooooo`00WOooool01Ol0
003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00006oooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0AOooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h06Oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgM
gOoooooo0000]Oooool009gooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo
00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo01Sooooo00Go0000oooooooo
ooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`000;Gooooo002Mooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00omgMgOoc<c<o`00000Kooooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`13ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Gooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00002eooooo`00
WOooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000006oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4015ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@01Wooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0<ooooo`03onk^k_m4A4Co00000;Gooooo002Mooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnH
V9So410@o`000?lQ8B7oc<c<04Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`06Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?oo
ool0]?ooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool0
0?oooooooooooolOooooo`00ooooooolooooo`;o00000_ooool2o`0001cooooo003ooooooocooooo
00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMdLooooo`00ooooooomooooo`04omgMgOl0003o410@olc<
c1gooooo000Goooooooo0000eol0000?ooooo`04onk^k_lQ8B7o410@onk^kQgooooo002ToooooaSo
00005ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo08;ooooo00Co8B4QogMgMomg
MgOo<S8b7Oooool00:Cooooo00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0POooool2o`0000;ooooo0_l0000Looooo`00
Y?ooool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`2Sooooo`00^ooooolIo`0001Koo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo000Ho`0001Ooo`00
00?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Doooo
o`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xooo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05?ooool00ol0
003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`0D
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo01Cooooo00?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003
o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05?ooool0
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo01Cooooo00?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05?oo
ool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Dooooo`03o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo01Cooooo00?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool001So00005_ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0:oooool00ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0:oooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`006Ol0000Fool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
:oooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0:ooooolIo`000:Gooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Go
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wo
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo
01Gooooo00?o0000ool00?oo00005?oo000Io`000>_ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oo
oooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05OoooolH
o`000?oooooo1?ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo6?l0000Gooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Kooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb
<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolI
ooooo`00j?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool0
0ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooo
oooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000So
oooo1?l0003ooooooaSooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003oooo
o`05oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xoooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oeEEEOmVIVKo
000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`Co000000Go410@oooooooooooooooo
odA4A002o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000
ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`06ooooo`09ogMgMolb<S;ooooo
oooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?oo
ool00ol0003oooooooooo`07ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool0
1_ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00Kooooo00Go
MgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo1?l0003ooooooaSooooo
003Xooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`00
0?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00So
oooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Kooooo00?oEEEEofIVI_l000001Oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000
oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003Uooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00onH
V9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@00Sooooo1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Xooooo`03ogMgMomVIVKooooo00;ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWo
oooo003Yooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05
o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOooool5o`0000Cooooo
00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0
003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool02Omg
MgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Kooooo00?oV9RHob4Q8Oo^k^h02Oooool01?l0003oooooooooool@4103ooooo`03oa0@
4?oooooooooo00Kooooo1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^00Oooooo00Go
MgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
oooooolIooooo`00j?ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
0_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00
jOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooo
oooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go0000okZj^_oooooo
V9RHoa0@4004ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08oooo
o`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00iOooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo
003Uooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wo
oooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool0
0ol@413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?oZJVYoa0@
4?ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0008ooooo`Co0000oooooolHooooo`00ioooool00ol@413o0000okZj^P03ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo00000?oooooo9?ooool00>Sooooo00?o
^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@403oooooobCooooo003Uooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`3oooooobCooooo003Uoooo
o`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP3oooooobCooooo003ooooooooooooo7oooool00?oooooooooooolO
ooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooo
oooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoo
oooo003gooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o0000ooooool9ooooo`00mooo
ool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`3oooooo`Oooooo003[
ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool01?l0003ooooooooo
ooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003o
A4A4okZj^P04ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000oooooooooooo
ooooo`000006ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo
00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000oooooooo
ool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool00_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0ooooool7ooooo`00k?ooool5o`0000Kooooo00?o0000ooooooooool00_ooool01?lQ
8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7
ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooooooo0_l0
0002ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool0oooo
ool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>_ooooo00Co410@
o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`;o00004_ooool00ol0003ooooooooo
o`05ooooo`;o0000ooooool9ooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oo
oooooooooolOooooo`00\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .06798 L
.4 .06798 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .06798 L
.4 .06798 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .18747 L
.45 .18747 L
.45 0 L
F
0 g
.4 0 m
.4 .18747 L
.45 .18747 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .12979 L
.5 .12979 L
.5 0 L
F
0 g
.45 0 m
.45 .12979 L
.5 .12979 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .19983 L
.55 .19983 L
.55 0 L
F
0 g
.5 0 m
.5 .19983 L
.55 .19983 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .15451 L
.6 .15451 L
.6 0 L
F
0 g
.55 0 m
.55 .15451 L
.6 .15451 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .13185 L
.65 .13185 L
.65 0 L
F
0 g
.6 0 m
.6 .13185 L
.65 .13185 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .0824 L
.7 .0824 L
.7 0 L
F
0 g
.65 0 m
.65 .0824 L
.7 .0824 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .06798 L
.75 .06798 L
.75 0 L
F
0 g
.7 0 m
.7 .06798 L
.75 .06798 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .00824 L
.8 .00824 L
.8 0 L
F
0 g
.75 0 m
.75 .00824 L
.8 .00824 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo000Ho`0008kooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xooo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00
^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0:?ooooo002koooooaWo00005_oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`006Ol0002Uooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2koooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`006?l0002mooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Boooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3B
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003o
o`00ool0000Dool001Wo00005_oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo000Ho`000=Cooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Go
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wo
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00
ool0000Dool001Wo0000joooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oo
oooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Go
oooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0?oooooo0_ooool00=?ooooo6?l0000Gooooo`03o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0oooo
ool2ooooo`00i_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02?oooolHo`000?oooooo1?ooool00>Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08
ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`Co0000oooooolHooooo`00j?oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@
00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000
ooooooooool0oooooolIooooo`00i_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_oo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_oo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_oo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00i_ooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000002Olb<S;ogMgMoooo
ooooooook^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>So
oooo00?o0000ooooooooool01_ooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMg
M`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01oooool0
1?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooo
oolIooooo`00j?ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000ooo
ool00ol0003oooooooooo`06ooooo`Co0000oooooolHooooo`00j?ooool00ol0003oooooooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000Sooooo
00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oeEEEOmV
IVKo000000Gooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000
oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000
oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOooool5
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08oooo
o`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`Co0000oooooolH
ooooo`00ioooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool0
0omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00jOooool01Ol0003ooooooooo
oooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Ko
oooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[ZjoooooonHV9So410@00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool0
0ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Gooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
0_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00
iOooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9So
oooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oiRHV?lQ8B7o
k^k^00Wooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`06ooooo`Co0000oooo
oolHooooo`00ioooool00onHV9So8B4Qonk^kP07ooooo`05ogMgMolb<S;oooooooooool000000ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?oMgMg
ofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooooooooooooooo
o`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooo
ooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWo
oooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0
003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol@413o^[Zjoooooomg
MgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`05o`000?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01_ooool00ol0
003oooooooooo`3ooooooaWooooo003Xooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool4o`000?oooooo6?ooool0
0>Oooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`00003oooooobCooooo003Xooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@
oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100oooooolTooooo`00iOoo
ool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0oooooolTooooo`00iOooool01OnYZJWo410@o`000?l@413oZJVY
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0oooo
oolTooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00
oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooo
oaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00moooool2o`0000_ooooo00?o
0000okZj^_ooool03?ooool2o`000?oooooo2Oooool00?Oooooo00?o0000ooooooooool02_ooool2
oc8b<Pkooooo00?o0000ooooooooool0ooooool7ooooo`00joooool01?l@413o0000o`000?ooool2
o`000003oa0@4?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000ooo
ool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X01?ooool00ol0003ooooo
ooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool02_l0003ooooo
ooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o410@00Cooooo00Go
410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00CogMgMo`000?l@413o
c<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@
413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>co
oooo1Ol00006ooooo`03o`000?oooooooooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000oooooooo
ooooooooo`000006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000Sooooo00?o410@
o`000?l000000ol00005ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@
ooooooooool00oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`000?oooooo2Oooool0
0?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00001\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .08858 L
.4 .08858 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .08858 L
.4 .08858 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .17923 L
.45 .17923 L
.45 0 L
F
0 g
.4 0 m
.4 .17923 L
.45 .17923 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .16275 L
.5 .16275 L
.5 0 L
F
0 g
.45 0 m
.45 .16275 L
.5 .16275 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .18129 L
.55 .18129 L
.55 0 L
F
0 g
.5 0 m
.5 .18129 L
.55 .18129 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .18541 L
.6 .18541 L
.6 0 L
F
0 g
.55 0 m
.55 .18541 L
.6 .18541 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .10301 L
.65 .10301 L
.65 0 L
F
0 g
.6 0 m
.6 .10301 L
.65 .10301 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .07622 L
.7 .07622 L
.7 0 L
F
0 g
.65 0 m
.65 .07622 L
.7 .07622 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .01648 L
.75 .01648 L
.75 0 L
F
0 g
.7 0 m
.7 .01648 L
.75 .01648 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .03708 L
.8 .03708 L
.8 0 L
F
0 g
.75 0 m
.75 .03708 L
.8 .03708 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`006Ol0000Fool00003o`000?oo
oooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo
08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003o
o`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool05OoooolHo`0008kooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2koooo
o`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2k
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool001So
0000_Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_oo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00;_o
oooo6Ol0000Fool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
000Ho`000=Cooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOoo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`006Ol0000Fool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`3Yooooo`00dooooolHo`0001Oooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0>Wooooo003oooooo`?ooooo6?l0000Gool00003o`000?oooooooooo
0>Wooooo003oooooo`?ooooo00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003
o`000?oooooooooo0>Wooooo003oooooo`?ooooo0_l0000EoooooaWo0000joooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo1?l000002?l@413oooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolI
ooooo`00j?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool0
1Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000Sooooo1?l0003ooooooaSooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Voooo
o`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`Co000000Go410@
ooooooooooooooooodA4A002o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`06ooooo`09
ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooo
oolIooooo`00j?ooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooooa0@40?ooooo00?o
410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooo
oooo00Kooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo1?l0
003ooooooaSooooo003Xooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c002ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo
003Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Kooooo00?oEEEEofIVI_l000001Oooool4o`0000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oo
oooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00i_ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@00Sooooo1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?oo
ool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ogMgMomVIVKooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Yooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWo
oooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o
0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o
0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o
0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOoo
ool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^k^h02Oooool01?l0003oooooooooool@
4103ooooo`03oa0@4?oooooooooo00Kooooo1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7o
k^k^00Oooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0oooooolIooooo`00j?ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
oooooolIooooo`00jOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go
410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go
0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c004ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`00
0?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`00
0?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003ooooooooo
o`3ooooooaWooooo003Uooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Wooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>So
oooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000008ooooo`Co0000oooooolHooooo`00ioooool00ol@413o0000okZj^P03oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo00000?oooooo9?oo
ool00>Sooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@403oooooobCooooo003Uooooo`05oa0@4?nHV9SooooookZj^_l00000
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`3ooooo
obCooooo003Uooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP3oooooobCooooo003ooooooooooooo7oooool0
0?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooo
oolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00
oooooooooooooaoooooo003gooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o0000oooo
ool9ooooo`00moooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`3o
ooooo`Oooooo003[ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool0
1?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00Go
V9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go
0000ooooooooooooooooo`000006ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o
0000omgMg@?ooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo
00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool5o`0000Kooooo00?o0000oooooooo
ool00_ooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooo
oooooooooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Gooooo00?o0000
ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool0
0>_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`;o00004_ooool0
0ol0003oooooooooo`05ooooo`;o0000ooooool9ooooo`00oooooooooooooaoooooo003ooooooooo
oooo7oooool00?oooooooooooolOooooo`00\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .11949 L
.4 .11949 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .11949 L
.4 .11949 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .18747 L
.45 .18747 L
.45 0 L
F
0 g
.4 0 m
.4 .18747 L
.45 .18747 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .14627 L
.5 .14627 L
.5 0 L
F
0 g
.45 0 m
.45 .14627 L
.5 .14627 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .17511 L
.55 .17511 L
.55 0 L
F
0 g
.5 0 m
.5 .17511 L
.55 .17511 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .15245 L
.6 .15245 L
.6 0 L
F
0 g
.55 0 m
.55 .15245 L
.6 .15245 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .09064 L
.65 .09064 L
.65 0 L
F
0 g
.6 0 m
.6 .09064 L
.65 .09064 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .11949 L
.7 .11949 L
.7 0 L
F
0 g
.65 0 m
.65 .11949 L
.7 .11949 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .01236 L
.75 .01236 L
.75 0 L
F
0 g
.7 0 m
.7 .01236 L
.75 .01236 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .02678 L
.8 .02678 L
.8 0 L
F
0 g
.75 0 m
.75 .02678 L
.8 .02678 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`006Ol0000Fool00003
o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
5Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo
08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003o
o`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool05OoooolHo`0008kooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2k
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^ooo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
6?l0000Fool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2k
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
01Cooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003o
o`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0Doooo
o`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo6Ol0000Fool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo01Cooooo6?l0002mooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOoo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool0
0ol0003oo`00ool0000Dool001Wo00005_oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Co
o`006Ol0003[ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0E
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000D
ool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2oooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool05OoooolHo`000?oooooo1?ooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`0Eooooo`;o0000oooooolJooooo`00dooooolHo`0001Oooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003Vooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>So
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`Co0000
oooooolHooooo`00j?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00
j?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00omEEEGoIVIVo`000004oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00i_ooool4o`000005oa0@4?oooooooooooooooom4A4@00_l0
00002Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool02OmgMgOo<S8booooooooooooMgMg
oiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000
ooooooooool01oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00Kooooo00?o
0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;o
ooooooooool000000oooool00ol0003oooooooooo`06ooooo`Co0000oooooolHooooo`00j?ooool0
0ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooo
oooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo
003Vooooo`03oeEEEOmVIVKo000000Gooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_oo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00iOooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^
k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008
ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooo
oolIooooo`00j?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00jOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[Zj
oooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo1Ol00004ooooo`05odA4A?l0
003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooooooo
ool0oooooolIooooo`00iOooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00WoMgMgoc8b<_oo
ooooooooogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003V
ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00Co0000oooooooooooo410@0oooool00ol@413ooooooooo
o`06ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP07ooooo`05ogMgMolb<S;o
ooooooooool000000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Sooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go
0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@4100
1?ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2
o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2
o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Go
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool0
1Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`05o`00
0?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooo
ooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ojVYZOl@413ooooo00;o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool4
o`000?oooooo6?ooool00>Oooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`00003oooooobCooooo003Xooooo`03okZj^_lQ8B7o
oooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100
oooooolTooooo`00iOooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0oooooolTooooo`00iOooool01OnYZJWo
410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h0oooooolTooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oo
oooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolO
ooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00mooo
ool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`000?oooooo2Oooool00?Oooooo00?o0000
ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool0ooooool7ooooo`00joooool01?l@
413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l0
0002ooooo`;o00000oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X0
1?ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool00000
1_ooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0
003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo0?oooooo
1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo
00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oo
oooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;o
oooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
0?oooooo1oooool00>cooooo1Ol00006ooooo`03o`000?oooooooooo00;ooooo00Co8B4QogMgMomg
MgOo<S8b2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>co
oooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2
o`0000Sooooo00?o410@o`000?l000000ol00005ooooo`03o`000?oooooooooo0?oooooo1oooool0
0>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o0000
ooooo`;o000000?o410@ooooooooool00oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2
o`000?oooooo2Oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo
7oooool00001\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .08652 L
.4 .08652 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .08652 L
.4 .08652 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .14833 L
.45 .14833 L
.45 0 L
F
0 g
.4 0 m
.4 .14833 L
.45 .14833 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .15657 L
.5 .15657 L
.5 0 L
F
0 g
.45 0 m
.45 .15657 L
.5 .15657 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .19365 L
.55 .19365 L
.55 0 L
F
0 g
.5 0 m
.5 .19365 L
.55 .19365 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .16069 L
.6 .16069 L
.6 0 L
F
0 g
.55 0 m
.55 .16069 L
.6 .16069 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .11949 L
.65 .11949 L
.65 0 L
F
0 g
.6 0 m
.6 .11949 L
.65 .11949 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .14627 L
.7 .14627 L
.7 0 L
F
0 g
.65 0 m
.65 .14627 L
.7 .14627 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .00618 L
.75 .00618 L
.75 0 L
F
0 g
.7 0 m
.7 .00618 L
.75 .00618 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .0103 L
.8 .0103 L
.8 0 L
F
0 g
.75 0 m
.75 .0103 L
.8 .0103 L
.8 0 L
.75 0 L
s
1 0 0 r
.8 0 m
.8 .00206 L
.85 .00206 L
.85 0 L
F
0 g
.8 0 m
.8 .00206 L
.85 .00206 L
.85 0 L
.8 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`006Ol0001Eooooo`04ob4Q8OmgMgOoMgMgoc8b<Qgo
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo06[ooooo0_l00002ooooo`;o00007?ooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo000Io`0001Koo`0000?o0000ooooooooool0S?ooool00;_ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0S?ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eoooo
oaSo0000S_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00
^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2koooo
o`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2k
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^ooo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002koooooaWo00005_oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^ooo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo000Ho`0001Koo`0000?o0000oooooooo
ool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^ooo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0D
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo6?l0000Gool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0DoooooaSo0000_Oooool0
0>[ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0jOooool00>[ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00>[ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0jOooool00>[ooooo6Ol0000Fool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0jOooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0jOooool00?oooooo0oooool00ol0003oo`00ool0000Dool0
01Wo0000joooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oo
oooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo
0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_oo
ool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool0
0?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oo
oooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oooooo
0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oooooo0ooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oooooo0oooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oooooo0oooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oooooo0oooool00ol0003o
o`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000D
ool00003o`000?oooooooooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0?oooooo0_ooool00?oooooo0ooooolHo`000?oooooo1?ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00i_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?oo
ool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool4o`000?oooooo
6?ooool00>Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08
ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Kooooo1?l000001Ol@413oooooooooooooooooA4A400;o000000Wo
<S8bomgMgOooooooooooonk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Xooooo`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9So
oooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooo
oooo00Oooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`06ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool01OmgMgOo<S8boooooooo
oooo000000?ooooo00?o0000ooooooooool01_ooool4o`000?oooooo6?ooool00>Sooooo00?o0000
ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooooooooooooooo
o`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_oo
ool00omEEEGoIVIVo`000005ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Gooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So8B4Qonk^
k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oiRHV?lQ8B7ok^k^00Co
oooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?ooool4
o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Sooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00Go
0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go0000okZj^_oooooo
V9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lQ8B7o
c<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`Go00001?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`09ogMgMolb<S;ooooooooo
oomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool0
0onHV9So8B4Qonk^kP09ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool01_oo
ool4o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h01oooool01OmgMgOo<S8boooooooo
oooo000000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003X
ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00Sooooo
00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo
00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000oooooooo
ool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003o
oooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003o
oooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05
oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go410@
okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00jOooool01Ol0003ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo
00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00onYZJWo410@ooooo`02ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo1?l0003o
oooooaSooooo003Wooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool00000oooooolTooooo`00j?ooool00onj^[[o8B4Qooooo`02
ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@0?oooooo
9?ooool00>Gooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?oooooo9?ooool00>Gooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^0?oooooo9?ooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooo
oooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool0
0?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?Oooooo0_l0
000;ooooo`03o`000?nj^[[ooooo00cooooo0_l0003oooooo`Wooooo003gooooo`03o`000?oooooo
oooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo0?oooooo1oooool00>_ooooo00Co410@o`00
0?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00000_oo
ool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo
00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo
00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@
4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003oooooooooo`3oooooo`Oooooo
003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`04omgM
gOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oo
oooo003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`04
onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooo
o`Oooooo003/ooooo`Go00001_ooool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b
<P_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05
o`000?ooooooooooooooool000001_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l00008
ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0003oooooooooo`3oooooo`Oooooo003/oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00joooool01?l@413o0000o`000?ooool2
o`000003oa0@4?oooooooooo00?ooooo0_l0000Booooo`03o`000?oooooooooo00Gooooo0_l0003o
ooooo`Wooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo
0000\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .05768 L
.4 .05768 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .05768 L
.4 .05768 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .16481 L
.45 .16481 L
.45 0 L
F
0 g
.4 0 m
.4 .16481 L
.45 .16481 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .13597 L
.5 .13597 L
.5 0 L
F
0 g
.45 0 m
.45 .13597 L
.5 .13597 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .17923 L
.55 .17923 L
.55 0 L
F
0 g
.5 0 m
.5 .17923 L
.55 .17923 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .16069 L
.6 .16069 L
.6 0 L
F
0 g
.55 0 m
.55 .16069 L
.6 .16069 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .14833 L
.65 .14833 L
.65 0 L
F
0 g
.6 0 m
.6 .14833 L
.65 .14833 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .11949 L
.7 .11949 L
.7 0 L
F
0 g
.65 0 m
.65 .11949 L
.7 .11949 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .06386 L
.75 .06386 L
.75 0 L
F
0 g
.7 0 m
.7 .06386 L
.75 .06386 L
.75 0 L
.7 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo0;;ooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Oooooo00?o0000ooooooooool0/oooool00<Cooooo1_l00002ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002oooool5o`000;Cooooo
003<ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP15ooooo`05o`00
0?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP0Iooooo`05o`000?oooooooooooooo
ool000002oooool01?m4A4CogMgMooooool0002eooooo`00c?ooool01Ol0003ooooooooooooooooo
000000kooooo00?oMgMgofIVI_ooool0A?ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool06?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo
0000]Oooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co00000;Gooooo003<ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?ok^k^odA4A?l00000]Oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`0AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c00Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo
0000ooooo`2dooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolO
ooooo`00oooooooooooooaoooooo003ooooooocooooo0_l00002ooooo`;o00007?ooool00?oooooo
o?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAcooooo003ooooooogooooo00CogMgMo`000?l@
413oc<c<7Oooool001Ooooooool0003Go`0000oooooo00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo08;o
oooo00Co8B4QogMgMomgMgOo<S8b7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo087ooooo0_l00002ooooo`;o00007?ooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo6Ol0000Fool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo000I
o`000:Gooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo000Ho`000;gooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool001Wo00005_oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Boooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Ooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`006?l0003Dooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`006Ol0003[
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003CoooooaSo00005oooool00ol0003o
o`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000D
ool00003o`000?oooooooooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0?oooooo0_ooool00?oooooo0ooooolHo`000?oooooo1?ooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00i_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xoooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool4o`000?oo
oooo6?ooool00>Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>So
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooo
oooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Kooooo1?l000001Ol@413oooooooooooooooooA4A400;o0000
00Wo<S8bomgMgOooooooooooonk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3o
oooooaWooooo003Xooooo`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonH
V9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oo
oooooooo00Oooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`06ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool01OmgMgOo<S8boooo
oooooooo000000?ooooo00?o0000ooooooooool01_ooool4o`000?oooooo6?ooool00>Sooooo00?o
0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooooooooooo
ooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00
i_ooool00omEEEGoIVIVo`000005ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00So
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Gooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So8B4Q
onk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oiRHV?lQ8B7ok^k^
00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?oo
ool4o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Sooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo
00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@
413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go0000okZj^_oo
ooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lQ
8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`Go00001?ooool01Om4A4Co0000
o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`09ogMgMolb<S;ooooo
oooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_oo
ool00onHV9So8B4Qonk^kP09ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool0
1_ooool4o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h01oooool01OmgMgOo<S8boooo
oooooooo000000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo
003Xooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`00
0?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00So
oooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[ZjoooooonHV9So410@00Co
oooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Uoooo
o`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go
410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00jOooool01Ol0003o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooo
oooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00onYZJWo410@ooooo`02oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo1?l0
003ooooooaSooooo003Wooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool00000oooooolTooooo`00j?ooool00onj^[[o8B4Qoooo
o`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@0?oo
oooo9?ooool00>Gooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?oooooo9?ooool00>Gooooo00GoZJVYoa0@
4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^0?oooooo9?ooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooo
oooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7ooo
ool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?Oooooo
0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo0_l0003oooooo`Wooooo003gooooo`03o`000?oo
oooooooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo0?oooooo1oooool00>_ooooo00Co410@
o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o0000
0_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Co
oooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Ko
oooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000
oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003oooooooooo`3oooooo`Oo
oooo003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`04
omgMgOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooo
o`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02oooo
o`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3o
ooooo`Oooooo003/ooooo`Go00001_ooool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMg
oc8b<P_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003/oooo
o`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l0
0008ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0003oooooooooo`3oooooo`Oooooo003/
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00joooool01?l@413o0000o`000?oo
ool2o`000003oa0@4?oooooooooo00?ooooo0_l0000Booooo`03o`000?oooooooooo00Gooooo0_l0
003oooooo`Wooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoo
oooo0000\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .0721 L
.4 .0721 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .0721 L
.4 .0721 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .14627 L
.45 .14627 L
.45 0 L
F
0 g
.4 0 m
.4 .14627 L
.45 .14627 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .16893 L
.5 .16893 L
.5 0 L
F
0 g
.45 0 m
.45 .16893 L
.5 .16893 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .17511 L
.55 .17511 L
.55 0 L
F
0 g
.5 0 m
.5 .17511 L
.55 .17511 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .14009 L
.6 .14009 L
.6 0 L
F
0 g
.55 0 m
.55 .14009 L
.6 .14009 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .13391 L
.65 .13391 L
.65 0 L
F
0 g
.6 0 m
.6 .13391 L
.65 .13391 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .05974 L
.7 .05974 L
.7 0 L
F
0 g
.65 0 m
.65 .05974 L
.7 .05974 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .13391 L
.75 .13391 L
.75 0 L
F
0 g
.7 0 m
.7 .13391 L
.75 .13391 L
.75 0 L
.7 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo0;;ooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Oooooo00?o0000ooooooooool0/oooool00<Cooooo1_l00002ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002oooool5o`000;Cooooo
003<ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP15ooooo`05o`00
0?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP0Iooooo`05o`000?oooooooooooooo
ool000002oooool01?m4A4CogMgMooooool0002eooooo`00c?ooool01Ol0003ooooooooooooooooo
000000kooooo00?oMgMgofIVI_ooool0A?ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool06?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo
0000]Oooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co00000;Gooooo003<ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?ok^k^odA4A?l00000]Oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`0AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c00Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo
0000ooooo`2dooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolO
ooooo`00oooooooooooooaoooooo003ooooooocooooo0_l00002ooooo`;o00007?ooool00?oooooo
o?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAcooooo003ooooooogooooo00CogMgMo`000?l@
413oc<c<7Oooool001Ooooooool0003Go`0000oooooo00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo08;o
oooo00Co8B4QogMgMomgMgOo<S8b7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo087ooooo0_l00002ooooo`;o00007?ooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool001So0000
5ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Dooooo`03o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05?ooool0
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002koooooaWo00005_oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo01Cooooo00?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
5?ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Dooooo`03o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo
0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo01Cooooo
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0
000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Soooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Dooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo01Co
oooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05?ooool00ol0003oo`00
ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2S
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Dooooo`03
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05?ooool00ol0003o
o`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
6?l0000FoooooaWo0000YOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
01Wo0000joooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3oooooo`;ooooo003CoooooaSo00005ooo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0?oooooo0_ooool00>[ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0?oooooo0_ooool00>[ooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00>[ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00>[ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo
0_ooool00>[ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0?oooooo0_ooool00>[ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0?oooooo0_ooool00>[ooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00>[ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00>[ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo
0_ooool00>[ooooo6Ol0000Fool00003o`000?oooooooooo0?oooooo0_ooool00?oooooo0oooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oooooo0oooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oooooo0ooooolHo`000?oo
oooo1?ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[o
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`Co000000So
410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08
ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000008ooooo`Co0000oooooolHooooo`00j?ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000
ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooo
oolIooooo`00i_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o
0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00i_oo
ool4o`000005oa0@4?oooooooooooooooom4A4@00_l000002Olb<S;ogMgMooooooooooook^k^oc8b
<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000oooo
ooooool01_ooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01oooool01?l0003ooooooooo
ool@4103ooooo`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?oo
ool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003ooooo
ooooo`06ooooo`Co0000oooooolHooooo`00j?ooool00ol0003oooooooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooooooo
ool0oooooolIooooo`00j?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oeEEEOmVIVKo000000Gooooo
1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOooool5o`0000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo
410@00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`Co0000oooooolHooooo`00ioooool0
0onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000So
oooo00?o0000ooooooooool0oooooolIooooo`00jOooool01Ol0003ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Kooooo00?o0000oooo
ooooool0oooooolIooooo`00iOooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003ooooooooo
o`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[o
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Gooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So
8B4Qonk^k_ooooooA4A400Oooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oiRHV?lQ8B7ok^k^00Wooooo00Co
0000oooooooooooo410@0oooool00ol@413oooooooooo`06ooooo`Co0000oooooolHooooo`00iooo
ool00onHV9So8B4Qonk^kP07ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?oMgMgofIVI_ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`000008ooooo`03
o`000?oooooooooo0?oooooo6Oooool00>Wooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWo
oooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`04ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o<S8bolc<c003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo
00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0
003oooooooooo`3ooooooaWooooo003Yooooo`05o`000?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3o
oooooaWooooo003Xooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000002?ooool4o`000?oooooo6?ooool00>Oooooo00?o410@
o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`00003oooooobCooooo003Xooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooo
oa0@4003ooooo`05oa0@4?ooooooooooooooool@4100oooooolTooooo`00iOooool01Ol@413oV9RH
oooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0oooooolTooooo`00iOooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0oooooolTooooo`00oooo
oooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoo
oooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooo
oooooooo7oooool00?oooooooooooolOooooo`00moooool2o`0000_ooooo00?o0000okZj^_ooool0
3?ooool2o`000?oooooo2Oooool00?Oooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o
0000ooooooooool0ooooool7ooooo`00joooool01?l@413o0000o`000?ooool2o`000003oa0@4?oo
oooooooo00?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000oooool00on7QhOo0000
okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X01?ooool00ol0003oooooooooo`3oooooo`Oo
oooo003/ooooo`05o`000?ooooooooooooooool000001_ooool02_l0003oooooooooooooooook^k^
ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^ko
MgMgoa0@4004ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo00;ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo1Ol00006oooo
o`03o`000?oooooooooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006
ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000Sooooo00?o410@o`000?l000000ol0
0005ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00ooo
ool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`000?oooooo2Oooool00?oooooooooooolO
ooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00001\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .09271 L
.4 .09271 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .09271 L
.4 .09271 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .17923 L
.45 .17923 L
.45 0 L
F
0 g
.4 0 m
.4 .17923 L
.45 .17923 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .14627 L
.5 .14627 L
.5 0 L
F
0 g
.45 0 m
.45 .14627 L
.5 .14627 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .15039 L
.55 .15039 L
.55 0 L
F
0 g
.5 0 m
.5 .15039 L
.55 .15039 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .16069 L
.6 .16069 L
.6 0 L
F
0 g
.55 0 m
.55 .16069 L
.6 .16069 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .12155 L
.65 .12155 L
.65 0 L
F
0 g
.6 0 m
.6 .12155 L
.65 .12155 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .06592 L
.7 .06592 L
.7 0 L
F
0 g
.65 0 m
.65 .06592 L
.7 .06592 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .11331 L
.75 .11331 L
.75 0 L
F
0 g
.7 0 m
.7 .11331 L
.75 .11331 L
.75 0 L
.7 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo0;;ooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Oooooo00?o0000ooooooooool0/oooool00<Cooooo1_l00002ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002oooool5o`000;Cooooo
003<ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP15ooooo`05o`00
0?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP0Iooooo`05o`000?oooooooooooooo
ool000002oooool01?m4A4CogMgMooooool0002eooooo`00c?ooool01Ol0003ooooooooooooooooo
000000kooooo00?oMgMgofIVI_ooool0A?ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool06?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo
0000]Oooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co00000;Gooooo003<ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?ok^k^odA4A?l00000]Oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`0AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c00Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo
0000ooooo`2dooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolO
ooooo`00oooooooooooooaoooooo003ooooooocooooo0_l00002ooooo`;o00007?ooool00?oooooo
o?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAcooooo003ooooooogooooo00CogMgMo`000?l@
413oc<c<7Oooool001Ooooooool0003Go`0000oooooo00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo08;o
oooo00Co8B4QogMgMomgMgOo<S8b7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo087ooooo0_l00002ooooo`;o00007?ooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xooo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool001So00005ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Dooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05?oo
ool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo002koooooaWo00005_oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo01Cooooo
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0
000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Soooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Dooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo01Co
oooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05?oooolIo`000:Gooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`006?l0003Dooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yoooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo
000Io`0001Koo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo6?l0000Gool00003o`000?oooooo
oooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0
003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Co
oooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ooooooooool05?ooool00ol0003oo`00
ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ooooooooool05Oooool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo01Cooooo6Ol0003[ooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oooooooooo01Gooooo00?o0000ooooooooool0oooooolIooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oooooooooo01Gooooo0_l0003ooooooa[ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oooooooooo`3ooooooaWooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003ooooooooo
o`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool0
0ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool05Oooool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ooooooooool05Oooool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oooooooooo`3ooooooaWooooo
003CoooooaSo00005oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Kooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo
00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo1?l0003ooooooaSo
oooo003Xooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooo
ooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?oo
ool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000
oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000
oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000
oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003Vooooo`Co000000Go410@ooooooooooooooooodA4A002o`000009oc8b
<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolI
ooooo`00j?ooool00ol0003oooooooooo`06ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooo
oonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003ooooooooo
o`07ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool01_ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00Kooooo00GoMgMgoc8b<_oooooooooo
o`000003ooooo`03o`000?oooooooooo00Kooooo1?l0003ooooooaSooooo003Xooooo`03o`000?oo
oooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool0
00002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000oooooooo
ool0oooooolIooooo`00j?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo
00?oEEEEofIVI_l000001Oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003Uooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo1?l0
003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo
003Xooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`05o`00
0?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooo
ooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05o`000?nj^[[ooooooiRH
V?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00So
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00iOooool5o`0000Cooooo00GoA4A4o`000?l0003o
<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool02OmgMgOo<S8boooooooooooo
MgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?o
V9RHob4Q8Oo^k^h02Oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00Kooooo
1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^00Oooooo00GoMgMgoc8b<_oooooooooo
o`000003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?oo
ool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooo
oooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00jOooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@4008ooooo`03
o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03
o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooo
oolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooo
oolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnH
V9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oa0@4?nj
^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00Go0000oooooooo
oooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`06
ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?oZJVYoa0@4?ooool00_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`Co0000oooo
oolHooooo`00ioooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo00000?oooooo9?ooool00>Sooooo00?o^[Zjob4Q8Oooool00_oo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@403oooooobCo
oooo003Uooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`3oooooobCooooo003Uooooo`05ojVYZOl@413o0000
oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP3oooooobCooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooo
oaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003gooooo`;o0000
2oooool00ol0003o^[Zjooooo`0<ooooo`;o0000ooooool9ooooo`00moooool00ol0003ooooooooo
o`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o
0000ooooo`;o000000?o410@ooooooooool00oooool01?l0003oooooooooooooool2o`0000;ooooo
0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03
o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`0:
o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo00?oc<c<o`000?l@4100
1?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000ooooooooool0ooooool7ooooo`00
k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool01?oMgMgo
0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7oooo
o`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool01?o^
k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7
ooooo`00k?ooool5o`0000Kooooo00?o0000ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb<S8;
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0
003ooooooooooooooooo000000Kooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00002?oo
ool00ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>_ooooo00Co410@o`000?l0003ooooo0_l0
00000ol@413oooooooooo`03ooooo`;o00004_ooool00ol0003oooooooooo`05ooooo`;o0000oooo
ool9ooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00
\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .06798 L
.4 .06798 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .06798 L
.4 .06798 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .17511 L
.45 .17511 L
.45 0 L
F
0 g
.4 0 m
.4 .17511 L
.45 .17511 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .16275 L
.5 .16275 L
.5 0 L
F
0 g
.45 0 m
.45 .16275 L
.5 .16275 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .17717 L
.55 .17717 L
.55 0 L
F
0 g
.5 0 m
.5 .17717 L
.55 .17717 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .16687 L
.6 .16687 L
.6 0 L
F
0 g
.55 0 m
.55 .16687 L
.6 .16687 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .12567 L
.65 .12567 L
.65 0 L
F
0 g
.6 0 m
.6 .12567 L
.65 .12567 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .08652 L
.7 .08652 L
.7 0 L
F
0 g
.65 0 m
.65 .08652 L
.7 .08652 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .0618 L
.75 .0618 L
.75 0 L
F
0 g
.7 0 m
.7 .0618 L
.75 .0618 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .00618 L
.8 .00618 L
.8 0 L
F
0 g
.75 0 m
.75 .00618 L
.8 .00618 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo000Ho`0008kooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2S
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool001Wo0000YOooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_o
oooo002koooooaWo00005_oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^ooo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool001So0000_Oooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool001So0000e?ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wo
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yoooo
o`00doooool00ol0003oo`00ool0000Dool001Wo00005_oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
5Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo
003oo`0001Coo`006Ol0003[ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooo
oooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00
dooooolHo`0001Oooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo
003oooooo`?ooooo6?l0003oooooo`Cooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`Co000000So410@ooooooooooook^k^oc8b
<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0>Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@
oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000008ooooo`Co0000oooooolHooooo`00j?ooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooooooo
ool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00j?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool4o`000005oa0@4?oooooo
oooooooooom4A4@00_l000002Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^kP08oooo
o`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool02OmgMgOo
<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Sooooo00?o0000ooooooooool01oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oo
oooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`06
ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`06ooooo`Co0000oooo
oolHooooo`00j?ooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_oo
ool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00j?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooo
oa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Vooooo`03oeEEEOmVIVKo000000Gooooo1?l00003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[o
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00iOooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo
003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Ko
oooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooo
oooooooooooooa0@4008ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP03oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o
0000ooooooooool0oooooolIooooo`00j?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
oooooolIooooo`00jOooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00
iOooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uoooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oo
oooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oo
oooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oo
oooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo1Ol0
0004ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00So
oooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So8B4Qonk^k_ooooooA4A400Oo
oooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003ooooooooo
o`3ooooooaWooooo003Vooooo`03oiRHV?lQ8B7ok^k^00Wooooo00Co0000oooooooooooo410@0ooo
ool00ol@413oooooooooo`06ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP07
ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Sooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05oa0@4?oo
ooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05o`000?nj
^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`01?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooo
oa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooo
oa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooo
oolIooooo`00iOooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWo
oooo003Yooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000002?ooool4o`000?oooooo6?ooool00>Oooooo00?o410@o`000?nj^[X00oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00003oooooobCooooo003X
ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oo
ooooooooooooool@4100oooooolTooooo`00iOooool01Ol@413oV9RHoooooonj^[[o000000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0oooooolToooo
o`00iOooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0oooooolTooooo`00oooooooooooooaoooooo003ooooo
oooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7ooo
ool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooo
oooooolOooooo`00moooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`000?oooooo2Ooo
ool00?Oooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool0ooooool7
ooooo`00joooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo00Co0000
oooooooooooooooo0_l00002ooooo`;o00000oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0
003o0000odA4A?nj^[X01?ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?oo
ooooooooooooool000001_ooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oM
gMd3ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`00
0?oooooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo00;ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo0?oooooo1oooool00>cooooo1Ol00006ooooo`03o`000?oooooooooo00;o
oooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooooooo
ooooo`;o00000_ooool2o`0000Sooooo00?o410@o`000?l000000ol00005ooooo`03o`000?oooooo
oooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003[oooo
o`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool2o`0001;ooooo00?o0000
ooooooooool01Oooool2o`000?oooooo2Oooool00?oooooooooooolOooooo`00oooooooooooooaoo
oooo003ooooooooooooo7oooool00001\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .07622 L
.4 .07622 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .07622 L
.4 .07622 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .18129 L
.45 .18129 L
.45 0 L
F
0 g
.4 0 m
.4 .18129 L
.45 .18129 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .16069 L
.5 .16069 L
.5 0 L
F
0 g
.45 0 m
.45 .16069 L
.5 .16069 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .18129 L
.55 .18129 L
.55 0 L
F
0 g
.5 0 m
.5 .18129 L
.55 .18129 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .16481 L
.6 .16481 L
.6 0 L
F
0 g
.55 0 m
.55 .16481 L
.6 .16481 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .11743 L
.65 .11743 L
.65 0 L
F
0 g
.6 0 m
.6 .11743 L
.65 .11743 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .10301 L
.7 .10301 L
.7 0 L
F
0 g
.65 0 m
.65 .10301 L
.7 .10301 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .01442 L
.75 .01442 L
.75 0 L
F
0 g
.7 0 m
.7 .01442 L
.75 .01442 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .0309 L
.8 .0309 L
.8 0 L
F
0 g
.75 0 m
.75 .0309 L
.8 .0309 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`006Ol0000Fool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo
08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003o
o`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool05OoooolHo`0008kooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00
^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2koooo
o`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2k
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002koooooaWo
00005_oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^ooo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool001So0000_Ooo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo000Ho`000=Cooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wo
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo000Io`0001Koo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
5Oooool00ol0003oo`00ool0000Dool001Wo0000joooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0oooo
ool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo
0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Ooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0ooooool2ooooo`00dooooolHo`0001Oooooo6?l0003oooooo`Cooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool4o`000008oa0@4?oooooo
ooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0
003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3o
oooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003X
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000002?ooool4o`000?oooooo6?ooool00>Sooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03
o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0>Kooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo
6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo1?l00000
1Ol@413oooooooooooooooooA4A400;o000000Wo<S8bomgMgOooooooooooonk^k_lb<S;o0000oc8b
<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00Ko
oooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003ooooooooo
o`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo410@0ooo
ool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000
ooooooooool01_ooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool01_oo
ool4o`000?oooooo6?ooool00>Sooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05oa0@4?oo
ooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo
00?o0000ooooooooool0oooooolIooooo`00i_ooool00omEEEGoIVIVo`000005ooooo`Co00000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o
0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo1Ol00003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0
oooooolIooooo`00iOooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Vooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4003oooo
o`05oa0@4?ooooooooooooooool@41002?ooool4o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?oMgMgofIVI_ooool00_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Wooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@
4?ooooooooooooooool@41000oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Gooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolI
ooooo`00iOooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003Uooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A007ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o
0000ooooooooool0oooooolIooooo`00i_ooool00onHV9So8B4Qonk^kP09ooooo`04o`000?oooooo
oooooa0@40?ooooo00?o410@ooooooooool01_ooool4o`000?oooooo6?ooool00>Oooooo00?oV9RH
ob4Q8Oo^k^h01oooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ogMgMomVIVKooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Yooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOoo
ool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So410@
o`000?lQ8B7oc<c<00Cooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Gooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000oooooooo
ool0oooooolIooooo`00jOooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooooooooa0@4003ooooo`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIoooo
o`00j?ooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000Sooooo1?l0003ooooooaSooooo003Wooooo`03oa0@4?l0003o^[Zj
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000oooo
oolTooooo`00j?ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@0?oooooo9?ooool00>Gooooo00Go410@oiRHV?oooooo^[Zj
o`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
0?oooooo9?ooool00>Gooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^0?oooooo9?ooool00?oooooooooooolO
ooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooo
oooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoo
oooo003ooooooooooooo7oooool00?Oooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo0_l0
003oooooo`Wooooo003gooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oooooo
oooo0?oooooo1oooool00>_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03
ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X01?oo
ool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool0ooooool7ooooo`00k?oo
ool01Ol0003ooooooooooooooooo000000Kooooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7
okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@4100
1?ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`02ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`Go00001_ooool00ol0003o
ooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool01?l0
003oooooooooooooool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o000000?o00001Oooool0
0ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7
ooooo`00joooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo0_l0000B
ooooo`03o`000?oooooooooo00Gooooo0_l0003oooooo`Wooooo003ooooooooooooo7oooool00?oo
oooooooooolOooooo`00oooooooooooooaoooooo0000\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .11949 L
.4 .11949 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .11949 L
.4 .11949 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .16893 L
.45 .16893 L
.45 0 L
F
0 g
.4 0 m
.4 .16893 L
.45 .16893 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .13597 L
.5 .13597 L
.5 0 L
F
0 g
.45 0 m
.45 .13597 L
.5 .13597 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .17511 L
.55 .17511 L
.55 0 L
F
0 g
.5 0 m
.5 .17511 L
.55 .17511 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .15245 L
.6 .15245 L
.6 0 L
F
0 g
.55 0 m
.55 .15245 L
.6 .15245 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .11949 L
.65 .11949 L
.65 0 L
F
0 g
.6 0 m
.6 .11949 L
.65 .11949 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .11331 L
.7 .11331 L
.7 0 L
F
0 g
.65 0 m
.65 .11331 L
.7 .11331 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .01854 L
.75 .01854 L
.75 0 L
F
0 g
.7 0 m
.7 .01854 L
.75 .01854 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .02678 L
.8 .02678 L
.8 0 L
F
0 g
.75 0 m
.75 .02678 L
.8 .02678 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`006Ol0000Fool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo
08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003o
o`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool05OoooolHo`0008kooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2k
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^ooo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`006?l0
002mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Boooo
o`00^ooooolIo`0001Koo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`006?l0003Dooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOoo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003C
ooooo`03o`000?oo003oo`0001Coo`006Ol0000Fool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eoooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yoooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooo
oooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Co
o`006Ol0003[ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0E
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003C
oooooaSo00005oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool0
0?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oo
oooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oooooo
0ooooolHo`000?oooooo1?ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003V
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08
ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`Co0000oooooolHooooo`00j?oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@
00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000
ooooooooool0oooooolIooooo`00i_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_oo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_oo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_oo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00i_ooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000002Olb<S;ogMgMoooo
ooooooook^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>So
oooo00?o0000ooooooooool01_ooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMg
M`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01oooool0
1?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooo
oolIooooo`00j?ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000ooo
ool00ol0003oooooooooo`06ooooo`Co0000oooooolHooooo`00j?ooool00ol0003oooooooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000Sooooo
00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oeEEEOmV
IVKo000000Gooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000
oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000
oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOooool5
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08oooo
o`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`Co0000oooooolH
ooooo`00ioooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool0
0omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00jOooool01Ol0003ooooooooo
oooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Ko
oooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[ZjoooooonHV9So410@00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool0
0ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Gooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
0_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00
iOooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9So
oooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oiRHV?lQ8B7o
k^k^00Wooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`06ooooo`Co0000oooo
oolHooooo`00ioooool00onHV9So8B4Qonk^kP07ooooo`05ogMgMolb<S;oooooooooool000000ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?oMgMg
ofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooooooooooooooo
o`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooo
ooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWo
oooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0
003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol@413o^[Zjoooooomg
MgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`05o`000?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01_ooool00ol0
003oooooooooo`3ooooooaWooooo003Xooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool4o`000?oooooo6?ooool0
0>Oooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`00003oooooobCooooo003Xooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@
oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100oooooolTooooo`00iOoo
ool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0oooooolTooooo`00iOooool01OnYZJWo410@o`000?l@413oZJVY
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0oooo
oolTooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00
oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooo
oaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00moooool2o`0000_ooooo00?o
0000okZj^_ooool03?ooool2o`000?oooooo2Oooool00?Oooooo00?o0000ooooooooool02_ooool2
oc8b<Pkooooo00?o0000ooooooooool0ooooool7ooooo`00joooool01?l@413o0000o`000?ooool2
o`000003oa0@4?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000ooo
ool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X01?ooool00ol0003ooooo
ooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool02_l0003ooooo
ooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o410@00Cooooo00Go
410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00CogMgMo`000?l@413o
c<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@
413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>co
oooo1Ol00006ooooo`03o`000?oooooooooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000oooooooo
ooooooooo`000006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000Sooooo00?o410@
o`000?l000000ol00005ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@
ooooooooool00oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`000?oooooo2Oooool0
0?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00001\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .06798 L
.4 .06798 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .06798 L
.4 .06798 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .16069 L
.45 .16069 L
.45 0 L
F
0 g
.4 0 m
.4 .16069 L
.45 .16069 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .14627 L
.5 .14627 L
.5 0 L
F
0 g
.45 0 m
.45 .14627 L
.5 .14627 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .21425 L
.55 .21425 L
.55 0 L
F
0 g
.5 0 m
.5 .21425 L
.55 .21425 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .15039 L
.6 .15039 L
.6 0 L
F
0 g
.55 0 m
.55 .15039 L
.6 .15039 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .13597 L
.65 .13597 L
.65 0 L
F
0 g
.6 0 m
.6 .13597 L
.65 .13597 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .11949 L
.7 .11949 L
.7 0 L
F
0 g
.65 0 m
.65 .11949 L
.7 .11949 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .02266 L
.75 .02266 L
.75 0 L
F
0 g
.7 0 m
.7 .02266 L
.75 .02266 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .00824 L
.8 .00824 L
.8 0 L
F
0 g
.75 0 m
.75 .00824 L
.8 .00824 L
.8 0 L
.75 0 L
s
1 0 0 r
.8 0 m
.8 .00412 L
.85 .00412 L
.85 0 L
F
0 g
.8 0 m
.8 .00412 L
.85 .00412 L
.85 0 L
.8 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`1Cooooo`04ob4Q8OmgMgOoMgMgoc8b<Qgooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool001Wo0000E?ooool2o`0000;ooooo
0_l0000Looooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`2<ooooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`006?l0002>ooooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xooo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool001Wo0000YOooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2koooo
o`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2k
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo0;_ooooo002koooooaWo00005_oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^ooo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool001So
0000_Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`006?l0003Dooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003o
o`0001Coo`006Ol0000Fool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`00
01Coo`006Ol0003[ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Go
oooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`3oooooo`;ooooo003CoooooaSo00005oooool00ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo
0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oo
oooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo
0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_oo
ool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool0
0?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oo
oooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oooooo
0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oooooo0ooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oooooo0oooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oooooo0oooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oooooo0oooool00ol0003o
o`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo0?oooooo0_ooool00>Kooooo1?l000002?l@413oooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Xooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00>Sooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
4008ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00j?ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000Sooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo
003Xooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000002?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oo
oooo0_ooool00>Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0ooooool2ooooo`00j?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo6?l0003oooooo`Cooooo003Voooo
o`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`Co000000Go410@
ooooooooooooooooodA4A002o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`06ooooo`09
ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooo
oolIooooo`00j?ooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooooa0@40?ooooo00?o
410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooo
oooo00Kooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo1?l0
003ooooooaSooooo003Xooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c002ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo
003Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Kooooo00?oEEEEofIVI_l000001Oooool4o`0000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oo
oooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00i_ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@00Sooooo1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?oo
ool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ogMgMomVIVKooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Yooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWo
oooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o
0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o
0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o
0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOoo
ool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^k^h02Oooool01?l0003oooooooooool@
4103ooooo`03oa0@4?oooooooooo00Kooooo1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7o
k^k^00Oooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0oooooolIooooo`00j?ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
oooooolIooooo`00jOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go
410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go
0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c004ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`00
0?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`00
0?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003ooooooooo
o`3ooooooaWooooo003Uooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Wooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>So
oooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000008ooooo`Co0000oooooolHooooo`00ioooool00ol@413o0000okZj^P03oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo00000?oooooo9?oo
ool00>Sooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@403oooooobCooooo003Uooooo`05oa0@4?nHV9SooooookZj^_l00000
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`3ooooo
obCooooo003Uooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP3oooooobCooooo003ooooooooooooo7oooool0
0?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooo
oolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00
oooooooooooooaoooooo003gooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o0000oooo
ool9ooooo`00moooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`3o
ooooo`Oooooo003[ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool0
1?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00Go
V9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go
0000ooooooooooooooooo`000006ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o
0000omgMg@?ooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo
00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool5o`0000Kooooo00?o0000oooooooo
ool00_ooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooo
oooooooooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Gooooo00?o0000
ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool0
0>_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`;o00004_ooool0
0ol0003oooooooooo`05ooooo`;o0000ooooool9ooooo`00oooooooooooooaoooooo003ooooooooo
oooo7oooool00?oooooooooooolOooooo`00\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .0618 L
.4 .0618 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .0618 L
.4 .0618 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .18129 L
.45 .18129 L
.45 0 L
F
0 g
.4 0 m
.4 .18129 L
.45 .18129 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .14215 L
.5 .14215 L
.5 0 L
F
0 g
.45 0 m
.45 .14215 L
.5 .14215 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .16275 L
.55 .16275 L
.55 0 L
F
0 g
.5 0 m
.5 .16275 L
.55 .16275 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .16481 L
.6 .16481 L
.6 0 L
F
0 g
.55 0 m
.55 .16481 L
.6 .16481 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .13597 L
.65 .13597 L
.65 0 L
F
0 g
.6 0 m
.6 .13597 L
.65 .13597 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .09477 L
.7 .09477 L
.7 0 L
F
0 g
.65 0 m
.65 .09477 L
.7 .09477 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .08034 L
.75 .08034 L
.75 0 L
F
0 g
.7 0 m
.7 .08034 L
.75 .08034 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .00618 L
.8 .00618 L
.8 0 L
F
0 g
.75 0 m
.75 .00618 L
.8 .00618 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo000Ho`0008kooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2S
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^ooooolI
o`0001Koo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool001Wo0000YOoo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool001So0000_Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`006?l0003D
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo0000
5?oo000Io`0001Koo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Go
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wo
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0EoooooaSo
00005ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo01Gooooo0_l0000EoooooaWo0000joooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool0
0=?ooooo6?l0000Gooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`Co000000So410@ooooooooooook^k^oc8b
<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0>Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@
oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000008ooooo`Co0000oooooolHooooo`00j?ooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooooooo
ool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00j?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool4o`000005oa0@4?oooooo
oooooooooom4A4@00_l000002Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^kP08oooo
o`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool02OmgMgOo
<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Sooooo00?o0000ooooooooool01oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oo
oooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`06
ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`06ooooo`Co0000oooo
oolHooooo`00j?ooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_oo
ool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00j?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooo
oa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Vooooo`03oeEEEOmVIVKo000000Gooooo1?l00003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[o
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00iOooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo
003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Ko
oooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooo
oooooooooooooa0@4008ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP03oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o
0000ooooooooool0oooooolIooooo`00j?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
oooooolIooooo`00jOooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00
iOooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uoooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oo
oooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oo
oooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oo
oooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo1Ol0
0004ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00So
oooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So8B4Qonk^k_ooooooA4A400Oo
oooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003ooooooooo
o`3ooooooaWooooo003Vooooo`03oiRHV?lQ8B7ok^k^00Wooooo00Co0000oooooooooooo410@0ooo
ool00ol@413oooooooooo`06ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP07
ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Sooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05oa0@4?oo
ooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05o`000?nj
^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`01?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooo
oa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooo
oa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooo
oolIooooo`00iOooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWo
oooo003Yooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000002?ooool4o`000?oooooo6?ooool00>Oooooo00?o410@o`000?nj^[X00oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00003oooooobCooooo003X
ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oo
ooooooooooooool@4100oooooolTooooo`00iOooool01Ol@413oV9RHoooooonj^[[o000000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0oooooolToooo
o`00iOooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0oooooolTooooo`00oooooooooooooaoooooo003ooooo
oooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7ooo
ool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooo
oooooolOooooo`00moooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`000?oooooo2Ooo
ool00?Oooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool0ooooool7
ooooo`00joooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo00Co0000
oooooooooooooooo0_l00002ooooo`;o00000oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0
003o0000odA4A?nj^[X01?ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?oo
ooooooooooooool000001_ooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oM
gMd3ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`00
0?oooooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo00;ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo0?oooooo1oooool00>cooooo1Ol00006ooooo`03o`000?oooooooooo00;o
oooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooooooo
ooooo`;o00000_ooool2o`0000Sooooo00?o410@o`000?l000000ol00005ooooo`03o`000?oooooo
oooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003[oooo
o`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool2o`0001;ooooo00?o0000
ooooooooool01Oooool2o`000?oooooo2Oooool00?oooooooooooolOooooo`00oooooooooooooaoo
oooo003ooooooooooooo7oooool00001\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .08858 L
.4 .08858 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .08858 L
.4 .08858 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .17511 L
.45 .17511 L
.45 0 L
F
0 g
.4 0 m
.4 .17511 L
.45 .17511 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .13803 L
.5 .13803 L
.5 0 L
F
0 g
.45 0 m
.45 .13803 L
.5 .13803 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .16893 L
.55 .16893 L
.55 0 L
F
0 g
.5 0 m
.5 .16893 L
.55 .16893 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .15451 L
.6 .15451 L
.6 0 L
F
0 g
.55 0 m
.55 .15451 L
.6 .15451 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .10713 L
.65 .10713 L
.65 0 L
F
0 g
.6 0 m
.6 .10713 L
.65 .10713 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .08034 L
.7 .08034 L
.7 0 L
F
0 g
.65 0 m
.65 .08034 L
.7 .08034 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .11743 L
.75 .11743 L
.75 0 L
F
0 g
.7 0 m
.7 .11743 L
.75 .11743 L
.75 0 L
.7 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo0;;ooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Oooooo00?o0000ooooooooool0/oooool00<Cooooo1_l00002ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002oooool5o`000;Cooooo
003<ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP15ooooo`05o`00
0?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP0Iooooo`05o`000?oooooooooooooo
ool000002oooool01?m4A4CogMgMooooool0002eooooo`00c?ooool01Ol0003ooooooooooooooooo
000000kooooo00?oMgMgofIVI_ooool0A?ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool06?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo
0000]Oooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co00000;Gooooo003<ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?ok^k^odA4A?l00000]Oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`0AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c00Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo
0000ooooo`2dooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolO
ooooo`00oooooooooooooaoooooo003ooooooocooooo0_l00002ooooo`;o00007?ooool00?oooooo
o?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAcooooo003ooooooogooooo00CogMgMo`000?l@
413oc<c<7Oooool001Ooooooool0003Go`0000oooooo00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo08;o
oooo00Co8B4QogMgMomgMgOo<S8b7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo087ooooo0_l00002ooooo`;o00007?ooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xooo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00
^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo000Ho`0001Ooo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05?oo
ool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^ooooolIo`00
01Koo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo01Cooooo00?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05?oo
ool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`006?l0000Fooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0[ooooo`03o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`0[ooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0[ooooo`03o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`0[ooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`0[oooooaWo0000YOooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000
ool00?oo00005?oo000Io`0001Koo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Y
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo000Io`000>_o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0oooo
ool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo
0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Ooo
oolHo`000?oooooo1?ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo6?l0000Gooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003Vooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`Co0000oooooolHooooo`00
j?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003o
ooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo
410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o
0000ooooooooool0oooooolIooooo`00i_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo
6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo
6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo
6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00i_ooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000002Olb<S;ogMgM
ooooooooooook^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0>Sooooo00?o0000ooooooooool01_ooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RH
ogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01ooo
ool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0
oooooolIooooo`00j?ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool00000
0oooool00ol0003oooooooooo`06ooooo`Co0000oooooolHooooo`00j?ooool00ol0003ooooooooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000So
oooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oeEE
EOmVIVKo000000Gooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o
0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o
0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOoo
ool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08
ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@
413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`Co0000oooo
oolHooooo`00ioooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00j?oo
ool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00jOooool01Ol0003ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo
00Kooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[ZjoooooonHV9So410@
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?oo
ool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00>Gooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oM
gMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00iOooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00WoMgMgoc8b<_ooooooooooogMgMonH
V9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`06ooooo`Co0000
oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP07ooooo`05ogMgMolb<S;oooooooooool00000
0oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooooooooooo
ooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003o
ooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_oo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_oo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@
4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol@413o^[Zjoooo
oomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`05o`000?oooooooooooooo
ool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01_ooool0
0ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool4o`000?oooooo6?oo
ool00>Oooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`00003oooooobCooooo003Xooooo`03okZj^_lQ8B7ooooo00;ooooo00Go
410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100oooooolTooooo`00
iOooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL0oooooolTooooo`00iOooool01OnYZJWo410@o`000?l@413o
ZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
oooooolTooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOoooo
o`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooo
oooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00moooool2o`0000_ooooo
00?o0000okZj^_ooool03?ooool2o`000?oooooo2Oooool00?Oooooo00?o0000ooooooooool02_oo
ool2oc8b<Pkooooo00?o0000ooooooooool0ooooool7ooooo`00joooool01?l@413o0000o`000?oo
ool2o`000003oa0@4?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o0000
0oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X01?ooool00ol0003o
ooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool02_l0003o
ooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o410@00Cooooo
00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00CogMgMo`000?l@
413oc<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>co
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q
8Ol@413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool0
0>cooooo1Ol00006ooooo`03o`000?oooooooooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000oooo
ooooooooooooo`000006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000Sooooo00?o
410@o`000?l000000ol00005ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o0000ooooo`;o000000?o
410@ooooooooool00oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`000?oooooo2Ooo
ool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00001\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .07622 L
.4 .07622 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .07622 L
.4 .07622 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .16275 L
.45 .16275 L
.45 0 L
F
0 g
.4 0 m
.4 .16275 L
.45 .16275 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .15657 L
.5 .15657 L
.5 0 L
F
0 g
.45 0 m
.45 .15657 L
.5 .15657 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .17099 L
.55 .17099 L
.55 0 L
F
0 g
.5 0 m
.5 .17099 L
.55 .17099 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .16275 L
.6 .16275 L
.6 0 L
F
0 g
.55 0 m
.55 .16275 L
.6 .16275 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .11743 L
.65 .11743 L
.65 0 L
F
0 g
.6 0 m
.6 .11743 L
.65 .11743 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .0824 L
.7 .0824 L
.7 0 L
F
0 g
.65 0 m
.65 .0824 L
.7 .0824 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .10095 L
.75 .10095 L
.75 0 L
F
0 g
.7 0 m
.7 .10095 L
.75 .10095 L
.75 0 L
.7 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo0;;ooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Oooooo00?o0000ooooooooool0/oooool00<Cooooo1_l00002ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002oooool5o`000;Cooooo
003<ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP15ooooo`05o`00
0?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP0Iooooo`05o`000?oooooooooooooo
ool000002oooool01?m4A4CogMgMooooool0002eooooo`00c?ooool01Ol0003ooooooooooooooooo
000000kooooo00?oMgMgofIVI_ooool0A?ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool06?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo
0000]Oooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co00000;Gooooo003<ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?ok^k^odA4A?l00000]Oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`0AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c00Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo
0000ooooo`2dooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolO
ooooo`00oooooooooooooaoooooo003ooooooocooooo0_l00002ooooo`;o00007?ooool00?oooooo
o?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAcooooo003ooooooogooooo00CogMgMo`000?l@
413oc<c<7Oooool001Ooooooool0003Go`0000oooooo00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo08;o
oooo00Co8B4QogMgMomgMgOo<S8b7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo087ooooo0_l00002ooooo`;o00007?ooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xooo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo6Ol0000Fool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`006?l0000Gool00003o`000?oo
oooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05?ooool00ol0003o
o`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Doooo
o`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo01Cooooo6Ol0002Uooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo000Ho`000=Cooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yoooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00
ool0000Dool001Wo00005_oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00dooooolHo`0001Oooooo00?o0000ool0
0?oo00005?oo000Io`000>_ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3oooooo`;ooooo003oooooo`?ooooo6?l0003oooooo`Cooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`Co000000So410@ooooooooooook^k^
oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000008ooooo`Co0000oooooolHooooo`00j?ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooo
ooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolI
ooooo`00j?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool0
0omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000002Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^kP08
ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool02Omg
MgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Sooooo00?o0000ooooooooool01oooool01?l0003oooooooooool@4103ooooo`03oa0@
4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003ooooooooo
o`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`06ooooo`Co0000
oooooolHooooo`00j?ooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
0_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00
j?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooo
oooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Vooooo`03oeEEEOmVIVKo000000Gooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooo
oa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00iOooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWo
oooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0>Kooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@
oooooooooooooooooa0@4008ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP03
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo
00?o0000ooooooooool0oooooolIooooo`00j?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooooooo
ool0oooooolIooooo`00jOooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooooooooa0@4003ooooo`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIoooo
o`00iOooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003U
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`00
0?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`00
0?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`00
0?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo
1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So8B4Qonk^k_ooooooA4A4
00Oooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Vooooo`03oiRHV?lQ8B7ok^k^00Wooooo00Co0000oooooooooooo410@
0oooool00ol@413oooooooooo`06ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^
kP07ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Sooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05oa0@
4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003o
oooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003o
oooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0
oooooolIooooo`00iOooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Yooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo
410@00?ooooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Xoooo
o`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000002?ooool4o`000?oooooo6?ooool00>Oooooo00?o410@o`000?nj^[X00oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00003oooooobCooooo
003Xooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@
4?ooooooooooooooool@4100oooooolTooooo`00iOooool01Ol@413oV9RHoooooonj^[[o000000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0oooooolT
ooooo`00iOooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0oooooolTooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo
7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oo
oooooooooolOooooo`00moooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`000?oooooo
2Oooool00?Oooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool0oooo
ool7ooooo`00joooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo00Co
0000oooooooooooooooo0_l00002ooooo`;o00000oooool00on7QhOo0000okZj^P04ooooo`05oiRH
V?l0003o0000odA4A?nj^[X01?ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`00
0?ooooooooooooooool000001_ooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`00
0?oMgMd3ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03
o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00;ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo1Ol00006ooooo`03o`000?oooooooooo
00;ooooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooo
ooooooooo`;o00000_ooool2o`0000Sooooo00?o410@o`000?l000000ol00005ooooo`03o`000?oo
oooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003[
ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool2o`0001;ooooo00?o
0000ooooooooool01Oooool2o`000?oooooo2Oooool00?oooooooooooolOooooo`00oooooooooooo
oaoooooo003ooooooooooooo7oooool00001\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.3 -0.0125 -12 -9 ]
[.3 -0.0125 12 0 ]
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.3 0 m
.3 .00625 L
s
[(-0.4)] .3 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.3 0 m
.3 .00206 L
.35 .00206 L
.35 0 L
F
0 g
.5 Mabswid
.3 0 m
.3 .00206 L
.35 .00206 L
.35 0 L
.3 0 L
s
1 0 0 r
.35 0 m
.35 .05356 L
.4 .05356 L
.4 0 L
F
0 g
.35 0 m
.35 .05356 L
.4 .05356 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .18129 L
.45 .18129 L
.45 0 L
F
0 g
.4 0 m
.4 .18129 L
.45 .18129 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .14627 L
.5 .14627 L
.5 0 L
F
0 g
.45 0 m
.45 .14627 L
.5 .14627 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .19365 L
.55 .19365 L
.55 0 L
F
0 g
.5 0 m
.5 .19365 L
.55 .19365 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .15245 L
.6 .15245 L
.6 0 L
F
0 g
.55 0 m
.55 .15245 L
.6 .15245 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .15657 L
.65 .15657 L
.65 0 L
F
0 g
.6 0 m
.6 .15657 L
.65 .15657 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .08446 L
.7 .08446 L
.7 0 L
F
0 g
.65 0 m
.65 .08446 L
.7 .08446 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .05562 L
.75 .05562 L
.75 0 L
F
0 g
.7 0 m
.7 .05562 L
.75 .05562 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .00412 L
.8 .00412 L
.8 0 L
F
0 g
.75 0 m
.75 .00412 L
.8 .00412 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool009gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool5o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@
4?oooooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko
<S8bo`000?l@413oc<c<08Gooooo002Mooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0AOooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo01Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q08Gooooo002Eooooo`Ko00000_ooool0
1Ol@413ooooooooooooooooo410@00_ooooo1Ol0000Booooo`Ko00000_ooool01Ol@413ooooooooo
oooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0A_ooool01Ol@413ooooooooooooooooo410@00co
oooo00?oV9RHob4Q8Oo^k^h06_ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0000Joooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000008Gooooo002M
ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool0000Kooooo`05o`00
0?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP15ooooo`05o`000?oooooooooooooo
ool000003Oooool00onHV9So8B4Qonk^kP0Iooooo`05o`000?ooooooooooooooool000002oooool0
1?m4A4CogMgMooooool0000Kooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RH
oooooonHV9So8B4Q08Gooooo002Mooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgo
EEEEooooool0000Kooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`14
ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`0Hooooo`05o`000?oo
ooooooooooooool000002oooool01?oMgMgoEEEEooooool0000Kooooo`05o`000?oooooooooooooo
ool000002oooool01Ol0003oEEEEo`000?l@413oc<c<08Gooooo002Mooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00omgMgOoc<c<o`00000Kooooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`13ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Gooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Kooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`27ooooo`00WOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol0003o^[ZjoooooonHV9So410@01Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03onk^k_m4A4Co000001_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413o
V9RH08Oooooo002Mooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0J
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<04Gooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`06Oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool06_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@QOooool00?oooooooooooolOooooo`00oooooooo
oooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00ooooooolooooo`;o0000
0_ooool2o`0001cooooo003ooooooocooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMdLooooo`00
ooooooomooooo`04omgMgOl0003o410@olc<c1gooooo000Goooooooo0000eol0000?ooooo`04onk^
k_lQ8B7o410@onk^kQgooooo002ToooooaSo00005ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMgogMgMolb<S8Mooooo`00
Y?ooool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo000Ho`0006cooooo0_l00002ooooo`;o00007?ooool00:Cooooo00?o0000ooooooooool05?oo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?oo
ool00ol0003oooooooooo`2<ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2S
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^ooooolIo`00
01Koo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`006Ol0002Uooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2k
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`006?l0002mooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_oo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000
ool00?oo00005?oo000Io`0001Koo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo000Io`0001Koo`0000?o0000oooooooo
ool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Ooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo6?l0003Dooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oo
oooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo6?l0000Goooo
o`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3oooooaSo0000ooooool4ooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003Vooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>So
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`Co0000
oooooolHooooo`00j?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00
j?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00omEEEGoIVIVo`000004oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00i_ooool4o`000005oa0@4?oooooooooooooooom4A4@00_l0
00002Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool02OmgMgOo<S8booooooooooooMgMg
oiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000
ooooooooool01oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00Kooooo00?o
0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;o
ooooooooool000000oooool00ol0003oooooooooo`06ooooo`Co0000oooooolHooooo`00j?ooool0
0ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooo
oooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo
003Vooooo`03oeEEEOmVIVKo000000Gooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_oo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00iOooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^
k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008
ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooo
oolIooooo`00j?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00jOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[Zj
oooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo1Ol00004ooooo`05odA4A?l0
003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooooooo
ool0oooooolIooooo`00iOooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00WoMgMgoc8b<_oo
ooooooooogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003V
ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00Co0000oooooooooooo410@0oooool00ol@413ooooooooo
o`06ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP07ooooo`05ogMgMolb<S;o
ooooooooool000000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Sooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go
0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@4100
1?ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2
o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2
o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Go
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool0
1Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`05o`00
0?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooo
ooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ojVYZOl@413ooooo00;o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool4
o`000?oooooo6?ooool00>Oooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`00003oooooobCooooo003Xooooo`03okZj^_lQ8B7o
oooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100
oooooolTooooo`00iOooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0oooooolTooooo`00iOooool01OnYZJWo
410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h0oooooolTooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oo
oooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolO
ooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00mooo
ool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`000?oooooo2Oooool00?Oooooo00?o0000
ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool0ooooool7ooooo`00joooool01?l@
413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l0
0002ooooo`;o00000oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X0
1?ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool00000
1_ooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0
003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo0?oooooo
1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo
00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oo
oooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;o
oooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
0?oooooo1oooool00>cooooo1Ol00006ooooo`03o`000?oooooooooo00;ooooo00Co8B4QogMgMomg
MgOo<S8b2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>co
oooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2
o`0000Sooooo00?o410@o`000?l000000ol00005ooooo`03o`000?oooooooooo0?oooooo1oooool0
0>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o0000
ooooo`;o000000?o410@ooooooooool00oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2
o`000?oooooo2Oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo
7oooool00001\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .09683 L
.4 .09683 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .09683 L
.4 .09683 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .18335 L
.45 .18335 L
.45 0 L
F
0 g
.4 0 m
.4 .18335 L
.45 .18335 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .15039 L
.5 .15039 L
.5 0 L
F
0 g
.45 0 m
.45 .15039 L
.5 .15039 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .16893 L
.55 .16893 L
.55 0 L
F
0 g
.5 0 m
.5 .16893 L
.55 .16893 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .16687 L
.6 .16687 L
.6 0 L
F
0 g
.55 0 m
.55 .16687 L
.6 .16687 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .09889 L
.65 .09889 L
.65 0 L
F
0 g
.6 0 m
.6 .09889 L
.65 .09889 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .11949 L
.7 .11949 L
.7 0 L
F
0 g
.65 0 m
.65 .11949 L
.7 .11949 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .0206 L
.75 .0206 L
.75 0 L
F
0 g
.7 0 m
.7 .0206 L
.75 .0206 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .02472 L
.8 .02472 L
.8 0 L
F
0 g
.75 0 m
.75 .02472 L
.8 .02472 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`006Ol0000Fool00003o`000?oooooooooo
08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003o
o`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool05OoooolHo`0008kooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2k
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^ooo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^ooooolIo`0001Koo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`006?l0000Fool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?oo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000D
ool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?oooolHo`000;gooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Y
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool0
0=?ooooo00?o0000ool00?oo00005?oo000Io`0001Koo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Go
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wo
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool001Wo0000jooo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0EoooooaSo0000ooooool4
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0oooooolIooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Go
oooo00?o0000ooooooooool0oooooolIooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo01Gooooo00?o0000ooooooooool0oooooolIooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo01Gooooo00?o0000ooooooooool0oooooolIooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ooooooooool0oooooolI
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0oooooolIooooo`00dooooolHo`0001Oooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00i_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?oo
ool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool4o`000?oooooo
6?ooool00>Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08
ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Kooooo1?l000001Ol@413oooooooooooooooooA4A400;o000000Wo
<S8bomgMgOooooooooooonk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Xooooo`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9So
oooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooo
oooo00Oooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`06ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool01OmgMgOo<S8boooooooo
oooo000000?ooooo00?o0000ooooooooool01_ooool4o`000?oooooo6?ooool00>Sooooo00?o0000
ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooooooooooooooo
o`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_oo
ool00omEEEGoIVIVo`000005ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Gooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So8B4Qonk^
k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oiRHV?lQ8B7ok^k^00Co
oooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?ooool4
o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Sooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00Go
0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go0000okZj^_oooooo
V9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lQ8B7o
c<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`Go00001?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`09ogMgMolb<S;ooooooooo
oomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool0
0onHV9So8B4Qonk^kP09ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool01_oo
ool4o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h01oooool01OmgMgOo<S8boooooooo
oooo000000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003X
ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00Sooooo
00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo
00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000oooooooo
ool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003o
oooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003o
oooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05
oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go410@
okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00jOooool01Ol0003ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo
00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00onYZJWo410@ooooo`02ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo1?l0003o
oooooaSooooo003Wooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool00000oooooolTooooo`00j?ooool00onj^[[o8B4Qooooo`02
ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@0?oooooo
9?ooool00>Gooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?oooooo9?ooool00>Gooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^0?oooooo9?ooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooo
oooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool0
0?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?Oooooo0_l0
000;ooooo`03o`000?nj^[[ooooo00cooooo0_l0003oooooo`Wooooo003gooooo`03o`000?oooooo
oooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo0?oooooo1oooool00>_ooooo00Co410@o`00
0?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00000_oo
ool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo
00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo
00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@
4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003oooooooooo`3oooooo`Oooooo
003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`04omgM
gOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oo
oooo003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`04
onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooo
o`Oooooo003/ooooo`Go00001_ooool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b
<P_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05
o`000?ooooooooooooooool000001_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l00008
ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0003oooooooooo`3oooooo`Oooooo003/oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00joooool01?l@413o0000o`000?ooool2
o`000003oa0@4?oooooooooo00?ooooo0_l0000Booooo`03o`000?oooooooooo00Gooooo0_l0003o
ooooo`Wooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo
0000\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .09477 L
.4 .09477 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .09477 L
.4 .09477 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .19159 L
.45 .19159 L
.45 0 L
F
0 g
.4 0 m
.4 .19159 L
.45 .19159 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .15657 L
.5 .15657 L
.5 0 L
F
0 g
.45 0 m
.45 .15657 L
.5 .15657 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .15863 L
.55 .15863 L
.55 0 L
F
0 g
.5 0 m
.5 .15863 L
.55 .15863 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .16069 L
.6 .16069 L
.6 0 L
F
0 g
.55 0 m
.55 .16069 L
.6 .16069 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .10713 L
.65 .10713 L
.65 0 L
F
0 g
.6 0 m
.6 .10713 L
.65 .10713 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .11537 L
.7 .11537 L
.7 0 L
F
0 g
.65 0 m
.65 .11537 L
.7 .11537 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .02266 L
.75 .02266 L
.75 0 L
F
0 g
.7 0 m
.7 .02266 L
.75 .02266 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .02266 L
.8 .02266 L
.8 0 L
F
0 g
.75 0 m
.75 .02266 L
.8 .02266 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`00<?l0002>ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00
^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2koooo
o`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0^oooool00;_ooooo6Ol0000Fool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2koooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool001So00005_oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo6?l0002m
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOoo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool001Wo00005_oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool05OoooolHo`0001Ooo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Cooooo6Ol0003[oooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0oooooolIooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo
0_l0003ooooooa[ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool05Oooool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool05Oooool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oooooooooo`3ooooooaWo
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool05Oooool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool05Oooool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oooooooooo`3ooooooaWo
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool2o`000?oooooo
6_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo6?l0000Gooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Kooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o
0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo1?l0003ooooooaSooooo
003Xooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool0
0ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooo
oolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooo
oolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooo
oolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003Vooooo`Co000000Go410@ooooooooooooooooodA4A002o`000009oc8b<_oM
gMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00j?ooool00ol0003oooooooooo`06ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonH
V9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`07
ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool01_ooool00ol0003ooooooooo
o`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00Kooooo00GoMgMgoc8b<_ooooooooooo`00
0003ooooo`03o`000?oooooooooo00Kooooo1?l0003ooooooaSooooo003Xooooo`03o`000?oooooo
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool00000
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0
oooooolIooooo`00j?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?o
EEEEofIVI_l000001Oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003U
ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo1?l0003o
oooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003X
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`05o`000?oo
ooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooooooo
ool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@
41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08
ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00iOooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8b
omgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWo
oooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool02OmgMgOo<S8booooooooooooMgMg
oiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oV9RH
ob4Q8Oo^k^h02Oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00Kooooo1?l0
003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^00Oooooo00GoMgMgoc8b<_ooooooooooo`00
0003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool0
0omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooo
oooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00jOooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Gooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`00
0?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJ
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJ
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So
410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oa0@4?nj^[[o
ooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00Go0000oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`06oooo
o`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`Co0000oooooolH
ooooo`00ioooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo00000?oooooo9?ooool00>Sooooo00?o^[Zjob4Q8Oooool00_ooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@403oooooobCooooo
003Uooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`3oooooobCooooo003Uooooo`05ojVYZOl@413o0000oa0@
4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooobCooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoo
oooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooo
oooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003gooooo`;o00002ooo
ool00ol0003o^[Zjooooo`0<ooooo`;o0000ooooool9ooooo`00moooool00ol0003oooooooooo`0:
ooooo`;o<S8b3_ooool00ol0003oooooooooo`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o0000
ooooo`;o000000?o410@ooooooooool00oooool01?l0003oooooooooooooool2o`0000;ooooo0_l0
0003ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`00
0?oooooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`0:o`00
0?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo00?oc<c<o`000?l@41001?oo
ool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000ooooooooool0ooooool7ooooo`00k?oo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool01?oMgMgo0000
oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00
k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool01?o^k^ko
8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7oooo
o`00k?ooool5o`0000Kooooo00?o0000ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb<S8;oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003o
oooooooooooooooo000000Kooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00002?ooool0
0ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo0?oooooo1oooool00>_ooooo00Co410@o`000?l0003ooooo0_l00000
0ol@413oooooooooo`03ooooo`;o00004_ooool00ol0003oooooooooo`05ooooo`;o0000ooooool9
ooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .07416 L
.4 .07416 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .07416 L
.4 .07416 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .15657 L
.45 .15657 L
.45 0 L
F
0 g
.4 0 m
.4 .15657 L
.45 .15657 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .16069 L
.5 .16069 L
.5 0 L
F
0 g
.45 0 m
.45 .16069 L
.5 .16069 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .17717 L
.55 .17717 L
.55 0 L
F
0 g
.5 0 m
.5 .17717 L
.55 .17717 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .18541 L
.6 .18541 L
.6 0 L
F
0 g
.55 0 m
.55 .18541 L
.6 .18541 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .13391 L
.65 .13391 L
.65 0 L
F
0 g
.6 0 m
.6 .13391 L
.65 .13391 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .08858 L
.7 .08858 L
.7 0 L
F
0 g
.65 0 m
.65 .08858 L
.7 .08858 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .03502 L
.75 .03502 L
.75 0 L
F
0 g
.7 0 m
.7 .03502 L
.75 .03502 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .01854 L
.8 .01854 L
.8 0 L
F
0 g
.75 0 m
.75 .01854 L
.8 .01854 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo000Ho`0008kooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`006Ol0002Uooooo`00
^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2koooo
o`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2k
ooooo`00^ooooolIo`0001Koo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo000Ho`000;gooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Boooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3B
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`006?l0003Dooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00dooooolHo`0001Ooo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Z
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0>Wooooo003ZoooooaWo00005_oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0>Wooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0>Wooooo003oooooo`?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003oooooo`?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003o
ooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0>Wooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0>Wooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0>Wooooo003oooooo`?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003oooooo`?ooooo6?l0
000Gool00003o`000?oooooooooo0>Wooooo003oooooo`?ooooo00?o0000ooooooooool05?ooool0
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003oooooo`?ooooo00?o0000oooo
ooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003oooooo`?o
oooo00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wo
oooo003oooooo`?ooooo0_l0000EoooooaWo0000joooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Kooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;o
k^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00j?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo
1?l0003ooooooaSooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWo
oooo003Xooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oeEEEOmVIVKo0000
00Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?oo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`Co000000Go410@ooooooooooooooooodA4
A002o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`06ooooo`09ogMgMolb<S;ooooooooo
oomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool0
0ol0003oooooooooo`07ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool01_oo
ool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00Kooooo00GoMgMg
oc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo1?l0003ooooooaSooooo003X
ooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00Sooooo
00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Kooooo00?oEEEEofIVI_l000001Oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooo
oolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003Uooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go
V9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00onHV9So
8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo
410@00Sooooo1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooooooo
o`3ooooooaWooooo003Xooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo
003Yooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?o
oooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05o`00
0?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOooool5o`0000Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool02OmgMgOo
<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Kooooo00?oV9RHob4Q8Oo^k^h02Oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oo
oooooooo00Kooooo1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^00Oooooo00GoMgMg
oc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooo
oolIooooo`00j?ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_oo
ool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00jOoo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooo
oa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go0000okZj^_ooooooV9RH
oa0@4004ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03
o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00iOooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003U
ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo
00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@
413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?oZJVYoa0@4?oo
ool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008
ooooo`Co0000oooooolHooooo`00ioooool00ol@413o0000okZj^P03ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo00000?oooooo9?ooool00>Sooooo00?o^[Zj
ob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooo
oa0@403oooooobCooooo003Uooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`3oooooobCooooo003Uooooo`05
ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP3oooooobCooooo003ooooooooooooo7oooool00?oooooooooooolOoooo
o`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooo
oooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo
003gooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o0000ooooool9ooooo`00moooool0
0ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`3oooooo`Oooooo003[oooo
o`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool01?l0003ooooooooooooo
ool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4
okZj^P04ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000oooooooooooooooo
o`000006ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo00?o
c<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000ooooooooool0
ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
0_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0ooooool7ooooo`00k?ooool5o`0000Kooooo00?o0000ooooooooool00_ooool01?lQ8B7o
MgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7oooo
o`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooooooo0_l00002
ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool0ooooool7
ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>_ooooo00Co410@o`00
0?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`;o00004_ooool00ol0003oooooooooo`05
ooooo`;o0000ooooool9ooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooo
oooooolOooooo`00\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .06592 L
.4 .06592 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .06592 L
.4 .06592 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .17511 L
.45 .17511 L
.45 0 L
F
0 g
.4 0 m
.4 .17511 L
.45 .17511 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .11949 L
.5 .11949 L
.5 0 L
F
0 g
.45 0 m
.45 .11949 L
.5 .11949 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .21013 L
.55 .21013 L
.55 0 L
F
0 g
.5 0 m
.5 .21013 L
.55 .21013 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .15245 L
.6 .15245 L
.6 0 L
F
0 g
.55 0 m
.55 .15245 L
.6 .15245 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .12155 L
.65 .12155 L
.65 0 L
F
0 g
.6 0 m
.6 .12155 L
.65 .12155 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .10301 L
.7 .10301 L
.7 0 L
F
0 g
.65 0 m
.65 .10301 L
.7 .10301 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .0721 L
.75 .0721 L
.75 0 L
F
0 g
.7 0 m
.7 .0721 L
.75 .0721 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .00824 L
.8 .00824 L
.8 0 L
F
0 g
.75 0 m
.75 .00824 L
.8 .00824 L
.8 0 L
.75 0 L
s
1 0 0 r
.8 0 m
.8 .00206 L
.85 .00206 L
.85 0 L
F
0 g
.8 0 m
.8 .00206 L
.85 .00206 L
.85 0 L
.8 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`006Ol0001Eooooo`04ob4Q8OmgMgOoMgMgoc8b<Qgo
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo06[ooooo0_l00002ooooo`;o00007?ooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0S?ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool001So0000S_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xooo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`2Sooooo`00^ooooolIo`0001Koo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool001Wo0000YOooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool001So0000_Oooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`006Ol0000Fool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool001So0000e?ooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooo
oooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0E
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Y
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo000Io`000>_o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0oooo
ool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo
0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Ooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo
01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo0?oooooo0_ooool00=?ooooo6?l0000Gooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0oooo
ool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2
ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2oooo
o`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00
ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00oooo
ool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00i_ooool4
o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00>So
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`08ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2
ooooo`00j?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool0
1Ol@413ooooooooooooooooo410@00Sooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3oooooo`;ooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0?oooooo0_ooool00>Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000008oooooaSo0000ooooool4ooooo`00
j?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00omEEEGoIVIVo`000004oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00i_ooool4o`000005oa0@4?oooooooooooooooom4A4@00_l0
00002Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool02OmgMgOo<S8booooooooooooMgMg
oiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000
ooooooooool01oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00Kooooo00?o
0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;o
ooooooooool000000oooool00ol0003oooooooooo`06ooooo`Co0000oooooolHooooo`00j?ooool0
0ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooo
oooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo
003Vooooo`03oeEEEOmVIVKo000000Gooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_oo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00iOooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^
k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008
ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooo
oolIooooo`00j?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00jOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[Zj
oooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo1Ol00004ooooo`05odA4A?l0
003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooooooo
ool0oooooolIooooo`00iOooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00WoMgMgoc8b<_oo
ooooooooogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003V
ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00Co0000oooooooooooo410@0oooool00ol@413ooooooooo
o`06ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP07ooooo`05ogMgMolb<S;o
ooooooooool000000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Sooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go
0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@4100
1?ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2
o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2
o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Go
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool0
1Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`05o`00
0?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooo
ooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ojVYZOl@413ooooo00;o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool4
o`000?oooooo6?ooool00>Oooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`00003oooooobCooooo003Xooooo`03okZj^_lQ8B7o
oooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100
oooooolTooooo`00iOooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0oooooolTooooo`00iOooool01OnYZJWo
410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h0oooooolTooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oo
oooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolO
ooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00mooo
ool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`000?oooooo2Oooool00?Oooooo00?o0000
ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool0ooooool7ooooo`00joooool01?l@
413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l0
0002ooooo`;o00000oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X0
1?ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool00000
1_ooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0
003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo0?oooooo
1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo
00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oo
oooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;o
oooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
0?oooooo1oooool00>cooooo1Ol00006ooooo`03o`000?oooooooooo00;ooooo00Co8B4QogMgMomg
MgOo<S8b2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>co
oooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2
o`0000Sooooo00?o410@o`000?l000000ol00005ooooo`03o`000?oooooooooo0?oooooo1oooool0
0>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o0000
ooooo`;o000000?o410@ooooooooool00oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2
o`000?oooooo2Oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo
7oooool00001\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .08034 L
.4 .08034 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .08034 L
.4 .08034 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .17099 L
.45 .17099 L
.45 0 L
F
0 g
.4 0 m
.4 .17099 L
.45 .17099 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .13803 L
.5 .13803 L
.5 0 L
F
0 g
.45 0 m
.45 .13803 L
.5 .13803 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .17717 L
.55 .17717 L
.55 0 L
F
0 g
.5 0 m
.5 .17717 L
.55 .17717 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .14627 L
.6 .14627 L
.6 0 L
F
0 g
.55 0 m
.55 .14627 L
.6 .14627 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .11331 L
.65 .11331 L
.65 0 L
F
0 g
.6 0 m
.6 .11331 L
.65 .11331 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .08652 L
.7 .08652 L
.7 0 L
F
0 g
.65 0 m
.65 .08652 L
.7 .08652 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .11743 L
.75 .11743 L
.75 0 L
F
0 g
.7 0 m
.7 .11743 L
.75 .11743 L
.75 0 L
.7 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo0;;ooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Oooooo00?o0000ooooooooool0/oooool00<Cooooo1_l00002ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002oooool5o`000;Cooooo
003<ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP15ooooo`05o`00
0?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP0Iooooo`05o`000?oooooooooooooo
ool000002oooool01?m4A4CogMgMooooool0002eooooo`00c?ooool01Ol0003ooooooooooooooooo
000000kooooo00?oMgMgofIVI_ooool0A?ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool06?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo
0000]Oooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co00000;Gooooo003<ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?ok^k^odA4A?l00000]Oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`0AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c00Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo
0000ooooo`2dooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolO
ooooo`00oooooooooooooaoooooo003ooooooocooooo0_l00002ooooo`;o00007?ooool00?oooooo
o?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAcooooo003ooooooogooooo00CogMgMo`000?l@
413oc<c<7Oooool001Ooooooool0003Go`0000oooooo00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo08;o
oooo00Co8B4QogMgMomgMgOo<S8b7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo087ooooo0_l00002ooooo`;o00007?ooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xooo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00
^ooooolIo`0001Koo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo000Ho`00
01Ooo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo01Cooooo00?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05?oo
ool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Dooooo`03o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`006?l0000Fooooo`03o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`0[ooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`0[oooooaWo0000YOooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000
ool00?oo00005?oo000Io`0001Koo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Y
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo01Gooooo00?o0000ool00?oo00005?oo000Io`000>_ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eoooo
o`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
5Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooo
oooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_oo
ool00=?ooooo6?l0000Gooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2
ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2oooo
o`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00
ooooool3oooooaSo0000ooooool4ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00i_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o
0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3o
oooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003X
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oo
ooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00002?ooool4o`000?oooooo6?ooool00>Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0>Sooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oEEEE
ofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo1?l000001Ol@413ooooooooo
ooooooooA4A400;o000000Wo<S8bomgMgOooooooooooonk^k_lb<S;o0000oc8b<_o^k^h02?ooool0
0ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00Kooooo00WoMgMgoc8b
<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo
003Xooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo410@0oooool00ol@413ooooo
ooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_oo
ool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool01_ooool4o`000?oooooo
6?ooool00>Sooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo
00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000oooooooo
ool0oooooolIooooo`00i_ooool00omEEEGoIVIVo`000005ooooo`Co00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Gooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00
iOooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Voooo
o`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo
ooooooooool@41002?ooool4o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Sooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Wooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Go
oooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool0
1OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooo
oa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooo
oa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooo
oa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`Go0000
1?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08oooo
o`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A007oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0
oooooolIooooo`00i_ooool00onHV9So8B4Qonk^kP09ooooo`04o`000?oooooooooooa0@40?ooooo
00?o410@ooooooooool01_ooool4o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h01ooo
ool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Xooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c002ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWo
oooo003Yooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol@413ooooo
oooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[Zj
oooooonHV9So410@00Cooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lQ8B7oc<c<
00Cooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJ
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJ
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003Uooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Gooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00jOooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00onY
ZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000Sooooo1?l0003ooooooaSooooo003Wooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000oooooolTooooo`00j?oo
ool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooo
oooooooooooo410@0?oooooo9?ooool00>Gooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?oooooo9?ooool0
0>Gooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^0?oooooo9?ooool00?oooooooooooolOooooo`00oooooooo
oooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo
003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooo
oooo7oooool00?Oooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo0_l0003oooooo`Wooooo
003gooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo0?oooooo1ooo
ool00>_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`04o`000?oo
ooooooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000
o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooo
oooooooooooo000000Kooooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM
0oooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003o
ooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`02ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`3oooooo`Oooooo003/ooooo`Go00001_ooool00ol0003oooooooooo`02oooo
o`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3o
ooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003ooooooooooooo
ool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0003ooooooooo
o`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00joooool0
1?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo0_l0000Booooo`03o`000?oo
oooooooo00Gooooo0_l0003oooooo`Wooooo003ooooooooooooo7oooool00?oooooooooooolOoooo
o`00oooooooooooooaoooooo0000\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .0721 L
.4 .0721 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .0721 L
.4 .0721 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .16069 L
.45 .16069 L
.45 0 L
F
0 g
.4 0 m
.4 .16069 L
.45 .16069 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .16069 L
.5 .16069 L
.5 0 L
F
0 g
.45 0 m
.45 .16069 L
.5 .16069 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .17305 L
.55 .17305 L
.55 0 L
F
0 g
.5 0 m
.5 .17305 L
.55 .17305 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .15657 L
.6 .15657 L
.6 0 L
F
0 g
.55 0 m
.55 .15657 L
.6 .15657 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .13391 L
.65 .13391 L
.65 0 L
F
0 g
.6 0 m
.6 .13391 L
.65 .13391 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .08652 L
.7 .08652 L
.7 0 L
F
0 g
.65 0 m
.65 .08652 L
.7 .08652 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .08652 L
.75 .08652 L
.75 0 L
F
0 g
.7 0 m
.7 .08652 L
.75 .08652 L
.75 0 L
.7 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo0;;ooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Oooooo00?o0000ooooooooool0/oooool00<Cooooo1_l00002ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002oooool5o`000;Cooooo
003<ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP15ooooo`05o`00
0?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP0Iooooo`05o`000?oooooooooooooo
ool000002oooool01?m4A4CogMgMooooool0002eooooo`00c?ooool01Ol0003ooooooooooooooooo
000000kooooo00?oMgMgofIVI_ooool0A?ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool06?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo
0000]Oooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co00000;Gooooo003<ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?ok^k^odA4A?l00000]Oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`0AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c00Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo
0000ooooo`2dooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolO
ooooo`00oooooooooooooaoooooo003ooooooocooooo0_l00002ooooo`;o00007?ooool00?oooooo
o?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAcooooo003ooooooogooooo00CogMgMo`000?l@
413oc<c<7Oooool001Ooooooool0003Go`0000oooooo00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo08;o
oooo00Co8B4QogMgMomgMgOo<S8b7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo087ooooo0_l00002ooooo`;o00007?ooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xooo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0:?ooooo002koooooaWo00005_oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xooo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00<?l0002Uooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool001So0000e?ooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
6Ol0003[ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Coooooc3o00005_oo0000
0ol0003oooooooooo`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3o
ooooo`;ooooo003oooooo`?ooooo6?l0003oooooo`Cooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oo
oooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o
0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0
oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000Sooooo1?l0003ooooooaSooooo003Xooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?ooool0
0ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003ooooooooo
o`3ooooooaWooooo003Vooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003Vooooo`Co000000Go410@ooooooooooooooooodA4A002o`000009oc8b<_oMgMgoooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0
003oooooooooo`06ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo
00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`07ooooo`04o`000?oo
oooooooooa0@40?ooooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo
003Xooooo`03o`000?oooooooooo00Kooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`00
0?oooooooooo00Kooooo1?l0003ooooooaSooooo003Xooooo`03o`000?oooooooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00
j?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oEEEEofIVI_l00000
1Oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[o
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[o
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`Go00000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03
o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000
ooooooooool0oooooolIooooo`00i_ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?oooooooooo
ooooool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo1?l0003ooooooaSooooo003W
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ogMgMomV
IVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00002?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`05o`000?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01_ooool00ol0
003oooooooooo`3ooooooaWooooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oo
oooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00iOooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RH
ogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^k^h02Ooo
ool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00Kooooo1?l0003ooooooaSooooo
003Wooooo`03oiRHV?lQ8B7ok^k^00Oooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00omgMgOoIVIVoooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000So
oooo00?o0000ooooooooool0oooooolIooooo`00jOooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Gooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Co
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Go
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lb<S;o
c<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oa0@4?nj^[[oooooogMgMolb<S80
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08oooo
o`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00Go0000oooooooooooooooooa0@4003oooo
o`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`06ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00>Sooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`Co0000oooooolHooooo`00ioooool0
0ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo00000?oooooo9?ooool00>Sooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooo
oooooooo410@00?ooooo00Go410@oooooooooooooooooa0@403oooooobCooooo003Uooooo`05oa0@
4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`3oooooobCooooo003Uooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP3oooooobCooooo
003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooo
oooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool0
0?oooooooooooolOooooo`00oooooooooooooaoooooo003gooooo`;o00002oooool00ol0003o^[Zj
ooooo`0<ooooo`;o0000ooooool9ooooo`00moooool00ol0003oooooooooo`0:ooooo`;o<S8b3_oo
ool00ol0003oooooooooo`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o0000ooooo`;o000000?o
410@ooooooooool00oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7
Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo0?oo
oooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`0:o`000?oooooooooooooo
ooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zj
onk^k_mgMgOo410@00Cooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`;oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool5o`00
00Kooooo00?o0000ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo
000000Kooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`00
0003o`0000Gooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?oooooo1oooool00>_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413ooooooooo
o`03ooooo`;o00004_ooool00ol0003oooooooooo`05ooooo`;o0000ooooool9ooooo`00oooooooo
oooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .08858 L
.4 .08858 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .08858 L
.4 .08858 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .16893 L
.45 .16893 L
.45 0 L
F
0 g
.4 0 m
.4 .16893 L
.45 .16893 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .14421 L
.5 .14421 L
.5 0 L
F
0 g
.45 0 m
.45 .14421 L
.5 .14421 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .17305 L
.55 .17305 L
.55 0 L
F
0 g
.5 0 m
.5 .17305 L
.55 .17305 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .16893 L
.6 .16893 L
.6 0 L
F
0 g
.55 0 m
.55 .16893 L
.6 .16893 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .12567 L
.65 .12567 L
.65 0 L
F
0 g
.6 0 m
.6 .12567 L
.65 .12567 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .10301 L
.7 .10301 L
.7 0 L
F
0 g
.65 0 m
.65 .10301 L
.7 .10301 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .05562 L
.75 .05562 L
.75 0 L
F
0 g
.7 0 m
.7 .05562 L
.75 .05562 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .00206 L
.8 .00206 L
.8 0 L
F
0 g
.75 0 m
.75 .00206 L
.8 .00206 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool001So0000KOooool01?lQ8B7oMgMgogMgMolb<S8Mooooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`1Zooooo`;o00000_ooool2o`0001cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oooooooooo08cooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2S
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool001Wo
0000YOooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00
^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0;_ooooo002koooooaWo00005_oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool001So0000_Ooo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`006?l0003Dooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
jOooool00=?ooooo00?o0000ool00?oo00005?oo000Io`0001Koo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooo
oooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0E
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Y
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0>Wooooo003CoooooaSo00005oooool00ol0003oo`00ool0000Dool001Wo0000joooool0
0?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oo
oooo0ooooolHo`000?oooooo1?ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool4o`000008oa0@4?oooooo
ooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0
003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3o
oooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003X
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000002?ooool4o`000?oooooo6?ooool00>Sooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03
o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0>Kooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo
6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo1?l00000
1Ol@413oooooooooooooooooA4A400;o000000Wo<S8bomgMgOooooooooooonk^k_lb<S;o0000oc8b
<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00Ko
oooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003ooooooooo
o`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo410@0ooo
ool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000
ooooooooool01_ooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool01_oo
ool4o`000?oooooo6?ooool00>Sooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05oa0@4?oo
ooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo
00?o0000ooooooooool0oooooolIooooo`00i_ooool00omEEEGoIVIVo`000005ooooo`Co00000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o
0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo1Ol00003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0
oooooolIooooo`00iOooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Vooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4003oooo
o`05oa0@4?ooooooooooooooool@41002?ooool4o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?oMgMgofIVI_ooool00_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Wooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@
4?ooooooooooooooool@41000oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Gooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolI
ooooo`00iOooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003Uooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A007ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o
0000ooooooooool0oooooolIooooo`00i_ooool00onHV9So8B4Qonk^kP09ooooo`04o`000?oooooo
oooooa0@40?ooooo00?o410@ooooooooool01_ooool4o`000?oooooo6?ooool00>Oooooo00?oV9RH
ob4Q8Oo^k^h01oooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ogMgMomVIVKooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Yooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOoo
ool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So410@
o`000?lQ8B7oc<c<00Cooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Gooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000oooooooo
ool0oooooolIooooo`00jOooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooooooooa0@4003ooooo`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIoooo
o`00j?ooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000Sooooo1?l0003ooooooaSooooo003Wooooo`03oa0@4?l0003o^[Zj
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000oooo
oolTooooo`00j?ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@0?oooooo9?ooool00>Gooooo00Go410@oiRHV?oooooo^[Zj
o`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
0?oooooo9?ooool00>Gooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^0?oooooo9?ooool00?oooooooooooolO
ooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooo
oooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoo
oooo003ooooooooooooo7oooool00?Oooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo0_l0
003oooooo`Wooooo003gooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oooooo
oooo0?oooooo1oooool00>_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03
ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X01?oo
ool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool0ooooool7ooooo`00k?oo
ool01Ol0003ooooooooooooooooo000000Kooooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7
okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@4100
1?ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`02ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`Go00001_ooool00ol0003o
ooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool01?l0
003oooooooooooooool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o000000?o00001Oooool0
0ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7
ooooo`00joooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo0_l0000B
ooooo`03o`000?oooooooooo00Gooooo0_l0003oooooo`Wooooo003ooooooooooooo7oooool00?oo
oooooooooolOooooo`00oooooooooooooaoooooo0000\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .07828 L
.4 .07828 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .07828 L
.4 .07828 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .19777 L
.45 .19777 L
.45 0 L
F
0 g
.4 0 m
.4 .19777 L
.45 .19777 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .14009 L
.5 .14009 L
.5 0 L
F
0 g
.45 0 m
.45 .14009 L
.5 .14009 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .20395 L
.55 .20395 L
.55 0 L
F
0 g
.5 0 m
.5 .20395 L
.55 .20395 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .14833 L
.6 .14833 L
.6 0 L
F
0 g
.55 0 m
.55 .14833 L
.6 .14833 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .10507 L
.65 .10507 L
.65 0 L
F
0 g
.6 0 m
.6 .10507 L
.65 .10507 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .11743 L
.7 .11743 L
.7 0 L
F
0 g
.65 0 m
.65 .11743 L
.7 .11743 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .01854 L
.75 .01854 L
.75 0 L
F
0 g
.7 0 m
.7 .01854 L
.75 .01854 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .0206 L
.8 .0206 L
.8 0 L
F
0 g
.75 0 m
.75 .0206 L
.8 .0206 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`006Ol0000Fool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool05OoooolHo`0008kooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00
^ooooolIo`0001Koo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`006?l0000Fool00003o`000?oooooo
oooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000D
ool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool05?oooolHo`000;gooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wo
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo000Io`0001Koo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Ooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOoo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003o
o`0001Coo`006Ol0003[ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo
01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0oooo
ool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo
0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Ooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo
01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo6?l0000Gooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00i_ooool4o`000008oa0@4?oooooo
ooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00>Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00j?ooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@00Sooooo6?l0003oooooo`Cooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool4o`000?oooooo
6?ooool00>Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08
ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Kooooo1?l000001Ol@413oooooooooooooooooA4A400;o000000Wo
<S8bomgMgOooooooooooonk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Xooooo`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9So
oooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooo
oooo00Oooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`06ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool01OmgMgOo<S8boooooooo
oooo000000?ooooo00?o0000ooooooooool01_ooool4o`000?oooooo6?ooool00>Sooooo00?o0000
ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooooooooooooooo
o`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_oo
ool00omEEEGoIVIVo`000005ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Gooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So8B4Qonk^
k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oiRHV?lQ8B7ok^k^00Co
oooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?ooool4
o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Sooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00Go
0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go0000okZj^_oooooo
V9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lQ8B7o
c<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`Go00001?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`09ogMgMolb<S;ooooooooo
oomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool0
0onHV9So8B4Qonk^kP09ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool01_oo
ool4o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h01oooool01OmgMgOo<S8boooooooo
oooo000000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003X
ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00Sooooo
00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo
00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000oooooooo
ool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003o
oooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003o
oooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05
oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go410@
okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00jOooool01Ol0003ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo
00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00onYZJWo410@ooooo`02ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo1?l0003o
oooooaSooooo003Wooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool00000oooooolTooooo`00j?ooool00onj^[[o8B4Qooooo`02
ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@0?oooooo
9?ooool00>Gooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?oooooo9?ooool00>Gooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^0?oooooo9?ooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooo
oooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool0
0?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?Oooooo0_l0
000;ooooo`03o`000?nj^[[ooooo00cooooo0_l0003oooooo`Wooooo003gooooo`03o`000?oooooo
oooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo0?oooooo1oooool00>_ooooo00Co410@o`00
0?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00000_oo
ool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo
00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo
00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@
4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003oooooooooo`3oooooo`Oooooo
003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`04omgM
gOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oo
oooo003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`04
onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooo
o`Oooooo003/ooooo`Go00001_ooool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b
<P_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05
o`000?ooooooooooooooool000001_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l00008
ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0003oooooooooo`3oooooo`Oooooo003/oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00joooool01?l@413o0000o`000?ooool2
o`000003oa0@4?oooooooooo00?ooooo0_l0000Booooo`03o`000?oooooooooo00Gooooo0_l0003o
ooooo`Wooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo
0000\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .09683 L
.4 .09683 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .09683 L
.4 .09683 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .16893 L
.45 .16893 L
.45 0 L
F
0 g
.4 0 m
.4 .16893 L
.45 .16893 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .13597 L
.5 .13597 L
.5 0 L
F
0 g
.45 0 m
.45 .13597 L
.5 .13597 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .19159 L
.55 .19159 L
.55 0 L
F
0 g
.5 0 m
.5 .19159 L
.55 .19159 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .16275 L
.6 .16275 L
.6 0 L
F
0 g
.55 0 m
.55 .16275 L
.6 .16275 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .13391 L
.65 .13391 L
.65 0 L
F
0 g
.6 0 m
.6 .13391 L
.65 .13391 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .09064 L
.7 .09064 L
.7 0 L
F
0 g
.65 0 m
.65 .09064 L
.7 .09064 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .02472 L
.75 .02472 L
.75 0 L
F
0 g
.7 0 m
.7 .02472 L
.75 .02472 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .02472 L
.8 .02472 L
.8 0 L
F
0 g
.75 0 m
.75 .02472 L
.8 .02472 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08co
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`00<?l0002>ooooo`00^oooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2koooo
o`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2k
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^ooo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`006?l0002mooooo`00^oooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^ooooolIo`0001Koo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_oo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`006?l0
003Dooooo`00doooool00ol0003oo`00ool0000Dool001Wo00005_oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo
01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eoooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yoooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo
00005?oo000Io`000>_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
5Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0ooooool2ooooo`00dooooolHo`0001Oooooo00?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3o
ooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3ooooo
o`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;o
oooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo
003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003o
ooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003ooooo
o`?ooooo6?l0003oooooo`Cooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003Vooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>So
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`Co0000
oooooolHooooo`00j?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00
j?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00omEEEGoIVIVo`000004oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00i_ooool4o`000005oa0@4?oooooooooooooooom4A4@00_l0
00002Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool02OmgMgOo<S8booooooooooooMgMg
oiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000
ooooooooool01oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00Kooooo00?o
0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;o
ooooooooool000000oooool00ol0003oooooooooo`06ooooo`Co0000oooooolHooooo`00j?ooool0
0ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooo
oooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo
003Vooooo`03oeEEEOmVIVKo000000Gooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_oo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00iOooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^
k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008
ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooo
oolIooooo`00j?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00jOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[Zj
oooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo1Ol00004ooooo`05odA4A?l0
003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooooooo
ool0oooooolIooooo`00iOooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00WoMgMgoc8b<_oo
ooooooooogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003V
ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00Co0000oooooooooooo410@0oooool00ol@413ooooooooo
o`06ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP07ooooo`05ogMgMolb<S;o
ooooooooool000000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Sooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go
0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@4100
1?ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2
o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2
o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Go
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool0
1Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`05o`00
0?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooo
ooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ojVYZOl@413ooooo00;o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool4
o`000?oooooo6?ooool00>Oooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`00003oooooobCooooo003Xooooo`03okZj^_lQ8B7o
oooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100
oooooolTooooo`00iOooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0oooooolTooooo`00iOooool01OnYZJWo
410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h0oooooolTooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oo
oooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolO
ooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00mooo
ool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`000?oooooo2Oooool00?Oooooo00?o0000
ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool0ooooool7ooooo`00joooool01?l@
413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l0
0002ooooo`;o00000oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X0
1?ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool00000
1_ooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0
003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo0?oooooo
1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo
00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oo
oooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;o
oooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
0?oooooo1oooool00>cooooo1Ol00006ooooo`03o`000?oooooooooo00;ooooo00Co8B4QogMgMomg
MgOo<S8b2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>co
oooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2
o`0000Sooooo00?o410@o`000?l000000ol00005ooooo`03o`000?oooooooooo0?oooooo1oooool0
0>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o0000
ooooo`;o000000?o410@ooooooooool00oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2
o`000?oooooo2Oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo
7oooool00001\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .07004 L
.4 .07004 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .07004 L
.4 .07004 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .17099 L
.45 .17099 L
.45 0 L
F
0 g
.4 0 m
.4 .17099 L
.45 .17099 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .15245 L
.5 .15245 L
.5 0 L
F
0 g
.45 0 m
.45 .15245 L
.5 .15245 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .17923 L
.55 .17923 L
.55 0 L
F
0 g
.5 0 m
.5 .17923 L
.55 .17923 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .17099 L
.6 .17099 L
.6 0 L
F
0 g
.55 0 m
.55 .17099 L
.6 .17099 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .12567 L
.65 .12567 L
.65 0 L
F
0 g
.6 0 m
.6 .12567 L
.65 .12567 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .08652 L
.7 .08652 L
.7 0 L
F
0 g
.65 0 m
.65 .08652 L
.7 .08652 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .0515 L
.75 .0515 L
.75 0 L
F
0 g
.7 0 m
.7 .0515 L
.75 .0515 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .02266 L
.8 .02266 L
.8 0 L
F
0 g
.75 0 m
.75 .02266 L
.8 .02266 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo000Ho`0008kooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Soooo
o`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`006Ol0002Uooooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo6Ol0
000Fool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2koooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`006?l0002mooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_oo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`006?l0003Dooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo000Io`0001Ko
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0E
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Y
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool0
0=?ooooo6?l0000Gooooo`03o`000?oo003oo`0001Coo`006Ol0003[ooooo`00ooooool3ooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3oooooaSo0000ooooool4
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`Co000000So410@ooooooooooook^k^oc8b
<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0>Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@
oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000008ooooo`Co0000oooooolHooooo`00j?ooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooooooo
ool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00j?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool4o`000005oa0@4?oooooo
oooooooooom4A4@00_l000002Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^kP08oooo
o`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool02OmgMgOo
<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Sooooo00?o0000ooooooooool01oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oo
oooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`06
ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`06ooooo`Co0000oooo
oolHooooo`00j?ooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_oo
ool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00j?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooo
oa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Vooooo`03oeEEEOmVIVKo000000Gooooo1?l00003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[o
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00iOooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo
003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Ko
oooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooo
oooooooooooooa0@4008ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP03oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o
0000ooooooooool0oooooolIooooo`00j?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
oooooolIooooo`00jOooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00
iOooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uoooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oo
oooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oo
oooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oo
oooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo1Ol0
0004ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00So
oooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So8B4Qonk^k_ooooooA4A400Oo
oooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003ooooooooo
o`3ooooooaWooooo003Vooooo`03oiRHV?lQ8B7ok^k^00Wooooo00Co0000oooooooooooo410@0ooo
ool00ol@413oooooooooo`06ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP07
ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Sooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05oa0@4?oo
ooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05o`000?nj
^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`01?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooo
oa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooo
oa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooo
oolIooooo`00iOooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWo
oooo003Yooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000002?ooool4o`000?oooooo6?ooool00>Oooooo00?o410@o`000?nj^[X00oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00003oooooobCooooo003X
ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oo
ooooooooooooool@4100oooooolTooooo`00iOooool01Ol@413oV9RHoooooonj^[[o000000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0oooooolToooo
o`00iOooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0oooooolTooooo`00oooooooooooooaoooooo003ooooo
oooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7ooo
ool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooo
oooooolOooooo`00moooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`000?oooooo2Ooo
ool00?Oooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool0ooooool7
ooooo`00joooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo00Co0000
oooooooooooooooo0_l00002ooooo`;o00000oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0
003o0000odA4A?nj^[X01?ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?oo
ooooooooooooool000001_ooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oM
gMd3ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`00
0?oooooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo00;ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo0?oooooo1oooool00>cooooo1Ol00006ooooo`03o`000?oooooooooo00;o
oooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooooooo
ooooo`;o00000_ooool2o`0000Sooooo00?o410@o`000?l000000ol00005ooooo`03o`000?oooooo
oooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003[oooo
o`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool2o`0001;ooooo00?o0000
ooooooooool01Oooool2o`000?oooooo2Oooool00?oooooooooooolOooooo`00oooooooooooooaoo
oooo003ooooooooooooo7oooool00001\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .06798 L
.4 .06798 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .06798 L
.4 .06798 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .19571 L
.45 .19571 L
.45 0 L
F
0 g
.4 0 m
.4 .19571 L
.45 .19571 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .13391 L
.5 .13391 L
.5 0 L
F
0 g
.45 0 m
.45 .13391 L
.5 .13391 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .16069 L
.55 .16069 L
.55 0 L
F
0 g
.5 0 m
.5 .16069 L
.55 .16069 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .15245 L
.6 .15245 L
.6 0 L
F
0 g
.55 0 m
.55 .15245 L
.6 .15245 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .12567 L
.65 .12567 L
.65 0 L
F
0 g
.6 0 m
.6 .12567 L
.65 .12567 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .10095 L
.7 .10095 L
.7 0 L
F
0 g
.65 0 m
.65 .10095 L
.7 .10095 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .08034 L
.75 .08034 L
.75 0 L
F
0 g
.7 0 m
.7 .08034 L
.75 .08034 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .00824 L
.8 .00824 L
.8 0 L
F
0 g
.75 0 m
.75 .00824 L
.8 .00824 L
.8 0 L
.75 0 L
s
1 0 0 r
.8 0 m
.8 .00412 L
.85 .00412 L
.85 0 L
F
0 g
.8 0 m
.8 .00412 L
.85 .00412 L
.85 0 L
.8 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`1Cooooo`04ob4Q8OmgMgOoMgMgoc8b<Qgooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool001Wo0000E?ooool2o`0000;ooooo
0_l0000Looooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`2<ooooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`006?l0002>ooooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xooo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00
^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Soooo
o`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^ooooolIo`0001Koo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool001Wo0000YOooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool001So0000
_Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Boooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool001So0000e?ooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo000Io`0001Koo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo
01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003o
o`00ool0000Dool001Wo0000joooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0EoooooaSo0000ooooool4oooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0oooooolIooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo
0_l0003ooooooa[ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool05Oooool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool05Oooool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oooooooooo`3ooooooaWo
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool05Oooool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool05Oooool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oooooooooo`3ooooooaWo
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool2o`000?oooooo
6_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo
6?l0000Gooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003Vooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>So
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`Co0000
oooooolHooooo`00j?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00
j?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00omEEEGoIVIVo`000004oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00i_ooool4o`000005oa0@4?oooooooooooooooom4A4@00_l0
00002Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool02OmgMgOo<S8booooooooooooMgMg
oiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000
ooooooooool01oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00Kooooo00?o
0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;o
ooooooooool000000oooool00ol0003oooooooooo`06ooooo`Co0000oooooolHooooo`00j?ooool0
0ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooo
oooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo
003Vooooo`03oeEEEOmVIVKo000000Gooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_oo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00iOooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^
k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008
ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooo
oolIooooo`00j?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00jOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[Zj
oooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo1Ol00004ooooo`05odA4A?l0
003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooooooo
ool0oooooolIooooo`00iOooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00WoMgMgoc8b<_oo
ooooooooogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003V
ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00Co0000oooooooooooo410@0oooool00ol@413ooooooooo
o`06ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP07ooooo`05ogMgMolb<S;o
ooooooooool000000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Sooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go
0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@4100
1?ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2
o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2
o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Go
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool0
1Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`05o`00
0?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooo
ooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ojVYZOl@413ooooo00;o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool4
o`000?oooooo6?ooool00>Oooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`00003oooooobCooooo003Xooooo`03okZj^_lQ8B7o
oooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100
oooooolTooooo`00iOooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0oooooolTooooo`00iOooool01OnYZJWo
410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h0oooooolTooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oo
oooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolO
ooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00mooo
ool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`000?oooooo2Oooool00?Oooooo00?o0000
ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool0ooooool7ooooo`00joooool01?l@
413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l0
0002ooooo`;o00000oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X0
1?ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool00000
1_ooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0
003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo0?oooooo
1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo
00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oo
oooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;o
oooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
0?oooooo1oooool00>cooooo1Ol00006ooooo`03o`000?oooooooooo00;ooooo00Co8B4QogMgMomg
MgOo<S8b2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>co
oooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2
o`0000Sooooo00?o410@o`000?l000000ol00005ooooo`03o`000?oooooooooo0?oooooo1oooool0
0>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o0000
ooooo`;o000000?o410@ooooooooool00oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2
o`000?oooooo2Oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo
7oooool00001\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .06592 L
.4 .06592 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .06592 L
.4 .06592 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .17923 L
.45 .17923 L
.45 0 L
F
0 g
.4 0 m
.4 .17923 L
.45 .17923 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .12979 L
.5 .12979 L
.5 0 L
F
0 g
.45 0 m
.45 .12979 L
.5 .12979 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .19159 L
.55 .19159 L
.55 0 L
F
0 g
.5 0 m
.5 .19159 L
.55 .19159 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .15657 L
.6 .15657 L
.6 0 L
F
0 g
.55 0 m
.55 .15657 L
.6 .15657 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .11125 L
.65 .11125 L
.65 0 L
F
0 g
.6 0 m
.6 .11125 L
.65 .11125 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .08034 L
.7 .08034 L
.7 0 L
F
0 g
.65 0 m
.65 .08034 L
.7 .08034 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .11125 L
.75 .11125 L
.75 0 L
F
0 g
.7 0 m
.7 .11125 L
.75 .11125 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .00412 L
.8 .00412 L
.8 0 L
F
0 g
.75 0 m
.75 .00412 L
.8 .00412 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
6?l0001/ooooo`;o00000_ooool2o`0001cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oooooooooo08cooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2S
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0:?ooooo002koooooaWo00005_oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2S
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`006?l0000Gool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Dooooo`03o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo01Cooooo00?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
5?ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Dooooo`03o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo
0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo000Ho`0001Kooooo6Ol0002Uooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yoooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?o
oooo00?o0000ool00?oo00005?oo000Io`0001Koo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Go
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wo
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`006Ol0
003[ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo
0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Ooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo
01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3oooooo`;ooooo003CoooooaSo00005oooool00ol0003oo`00ool0000D
ool00003o`000?oooooooooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0?oooooo0_ooool00?oooooo0ooooolHo`000?oooooo1?ooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo1?l000002?l@413oooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolI
ooooo`00j?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool0
1Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000Sooooo1?l0003ooooooaSooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Voooo
o`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`Co000000Go410@
ooooooooooooooooodA4A002o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`06ooooo`09
ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooo
oolIooooo`00j?ooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooooa0@40?ooooo00?o
410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooo
oooo00Kooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo1?l0
003ooooooaSooooo003Xooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c002ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo
003Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Kooooo00?oEEEEofIVI_l000001Oooool4o`0000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oo
oooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00i_ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@00Sooooo1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?oo
ool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ogMgMomVIVKooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Yooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWo
oooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o
0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o
0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o
0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOoo
ool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^k^h02Oooool01?l0003oooooooooool@
4103ooooo`03oa0@4?oooooooooo00Kooooo1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7o
k^k^00Oooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0oooooolIooooo`00j?ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
oooooolIooooo`00jOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go
410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go
0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c004ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`00
0?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`00
0?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003ooooooooo
o`3ooooooaWooooo003Uooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Wooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>So
oooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000008ooooo`Co0000oooooolHooooo`00ioooool00ol@413o0000okZj^P03oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo00000?oooooo9?oo
ool00>Sooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@403oooooobCooooo003Uooooo`05oa0@4?nHV9SooooookZj^_l00000
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`3ooooo
obCooooo003Uooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP3oooooobCooooo003ooooooooooooo7oooool0
0?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooo
oolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00
oooooooooooooaoooooo003gooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o0000oooo
ool9ooooo`00moooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`3o
ooooo`Oooooo003[ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool0
1?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00Go
V9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go
0000ooooooooooooooooo`000006ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o
0000omgMg@?ooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo
00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool5o`0000Kooooo00?o0000oooooooo
ool00_ooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooo
oooooooooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Gooooo00?o0000
ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool0
0>_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`;o00004_ooool0
0ol0003oooooooooo`05ooooo`;o0000ooooool9ooooo`00oooooooooooooaoooooo003ooooooooo
oooo7oooool00?oooooooooooolOooooo`00\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .08446 L
.4 .08446 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .08446 L
.4 .08446 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .14215 L
.45 .14215 L
.45 0 L
F
0 g
.4 0 m
.4 .14215 L
.45 .14215 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .15245 L
.5 .15245 L
.5 0 L
F
0 g
.45 0 m
.45 .15245 L
.5 .15245 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .18335 L
.55 .18335 L
.55 0 L
F
0 g
.5 0 m
.5 .18335 L
.55 .18335 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .16069 L
.6 .16069 L
.6 0 L
F
0 g
.55 0 m
.55 .16069 L
.6 .16069 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .12773 L
.65 .12773 L
.65 0 L
F
0 g
.6 0 m
.6 .12773 L
.65 .12773 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .11537 L
.7 .11537 L
.7 0 L
F
0 g
.65 0 m
.65 .11537 L
.7 .11537 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .06386 L
.75 .06386 L
.75 0 L
F
0 g
.7 0 m
.7 .06386 L
.75 .06386 L
.75 0 L
.7 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo0;;ooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Oooooo00?o0000ooooooooool0/oooool00<Cooooo1_l00002ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002oooool5o`000;Cooooo
003<ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP15ooooo`05o`00
0?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP0Iooooo`05o`000?oooooooooooooo
ool000002oooool01?m4A4CogMgMooooool0002eooooo`00c?ooool01Ol0003ooooooooooooooooo
000000kooooo00?oMgMgofIVI_ooool0A?ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool06?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo
0000]Oooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co00000;Gooooo003<ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?ok^k^odA4A?l00000]Oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`0AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c00Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo
0000ooooo`2dooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolO
ooooo`00oooooooooooooaoooooo003ooooooocooooo0_l00002ooooo`;o00007?ooool00?oooooo
o?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAcooooo003ooooooogooooo00CogMgMo`000?l@
413oc<c<7Oooool001Ooooooool0003Go`0000oooooo00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo08;o
oooo00Co8B4QogMgMomgMgOo<S8b7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo087ooooo0_l00002ooooo`;o00007?ooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xooo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo000Io`000:Gooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002koooooaWo00005_oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^ooo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool001So0000_Oooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Boooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool001So0000e?ooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo6?l0000Gool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00
j_ooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`3Yooooo`00j_ooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00j_ooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`3Yooooo`00j_oooolIo`0001Koo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3
ooooo`03o`000?oo003oo`0001Coo`006Ol0003[ooooo`00ooooool3ooooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0oooo
ool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2
ooooo`00ooooool3oooooaSo0000ooooool4ooooo`00ooooool3ooooo`;o0000oooooolJooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool4o`000008oa0@4?oo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool0
0ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003ooooooooo
o`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo
003Xooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000002?ooool4o`000?oooooo6?ooool00>Sooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008oooo
o`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Kooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oo
oooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo1?l0
00001Ol@413oooooooooooooooooA4A400;o000000Wo<S8bomgMgOooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo
00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo410@
0oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o
0000ooooooooool01_ooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool0
1_ooool4o`000?oooooo6?ooool00>Sooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05oa0@
4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00So
oooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00omEEEGoIVIVo`000005ooooo`Co0000
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo1Ol00003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooooooo
ool0oooooolIooooo`00iOooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3o
oooooaWooooo003Vooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@41002?ooool4o`000?oooooo6?ooool00>Oooooo00?oV9RH
ob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?oMgMgofIVI_ooool00_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03
o`000?oooooooooo0?oooooo6Oooool00>Wooooo00Go0000oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Gooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooo
oolIooooo`00iOooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003Uooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^
k^koooooodA4A007ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo
00?o0000ooooooooool0oooooolIooooo`00i_ooool00onHV9So8B4Qonk^kP09ooooo`04o`000?oo
oooooooooa0@40?ooooo00?o410@ooooooooool01_ooool4o`000?oooooo6?ooool00>Oooooo00?o
V9RHob4Q8Oo^k^h01oooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ogMgMomVIVKooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Yooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00
iOooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So
410@o`000?lQ8B7oc<c<00Cooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Gooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00jOooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooo
oooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolI
ooooo`00j?ooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000Sooooo1?l0003ooooooaSooooo003Wooooo`03oa0@4?l0003o
^[Zj00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
oooooolTooooo`00j?ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
0oooool01Ol@413ooooooooooooooooo410@0?oooooo9?ooool00>Gooooo00Go410@oiRHV?oooooo
^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg0?oooooo9?ooool00>Gooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^0?oooooo9?ooool00?oooooooooo
oolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00
oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooo
oaoooooo003ooooooooooooo7oooool00?Oooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo
0_l0003oooooo`Wooooo003gooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oo
oooooooo0?oooooo1oooool00>_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413ooooooooo
o`03ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X0
1?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool0ooooool7ooooo`00
k?ooool01Ol0003ooooooooooooooooo000000Kooooo00[o0000ooooooooooooooooonk^k_lQ8B7o
QhN7okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@
41001?ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`02ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`Go00001_ooool00ol0
003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool0
1?l0003oooooooooooooool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o000000?o00001Ooo
ool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooo
ool7ooooo`00joooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo0_l0
000Booooo`03o`000?oooooooooo00Gooooo0_l0003oooooo`Wooooo003ooooooooooooo7oooool0
0?oooooooooooolOooooo`00oooooooooooooaoooooo0000\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .07004 L
.4 .07004 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .07004 L
.4 .07004 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .18747 L
.45 .18747 L
.45 0 L
F
0 g
.4 0 m
.4 .18747 L
.45 .18747 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .14009 L
.5 .14009 L
.5 0 L
F
0 g
.45 0 m
.45 .14009 L
.5 .14009 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .18335 L
.55 .18335 L
.55 0 L
F
0 g
.5 0 m
.5 .18335 L
.55 .18335 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .18129 L
.6 .18129 L
.6 0 L
F
0 g
.55 0 m
.55 .18129 L
.6 .18129 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .11743 L
.65 .11743 L
.65 0 L
F
0 g
.6 0 m
.6 .11743 L
.65 .11743 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .10301 L
.7 .10301 L
.7 0 L
F
0 g
.65 0 m
.65 .10301 L
.7 .10301 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .04532 L
.75 .04532 L
.75 0 L
F
0 g
.7 0 m
.7 .04532 L
.75 .04532 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .00206 L
.8 .00206 L
.8 0 L
F
0 g
.75 0 m
.75 .00206 L
.8 .00206 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool001So0000KOooool01?lQ8B7oMgMgogMgMolb<S8Mooooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`1Zooooo`;o00000_ooool2o`0001cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oooooooooo08cooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2S
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo000Io`000:Gooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^ooo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`2kooooo`00^ooooolIo`0001Koo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo000Ho`000;gooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`006?l0003Doooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Y
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03
o`000?oo003oo`0001Coo`006Ol0000Fool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Go
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wo
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo
01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eoooo
o`03o`000?oo003oo`0001Coo`006Ol0003[ooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo01Gooooo6?l0003oooooo`Cooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool05Oooool2o`000?oooooo6_ooool00=?ooooo6?l0000Gooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00i_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xoooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo
ooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
2?ooool4o`000?oooooo6?ooool00>Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>So
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oEEEEofIV
I_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo1?l000001Ol@413ooooooooooooo
ooooA4A400;o000000Wo<S8bomgMgOooooooooooonk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0
003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_oo
ooooooooogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003X
ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo410@0oooool00ol@413ooooooooo
o`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool0
1OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool01_ooool4o`000?oooooo6?oo
ool00>Sooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go
0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0
oooooolIooooo`00i_ooool00omEEEGoIVIVo`000005ooooo`Co00000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Gooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOoo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03
oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooo
ooooool@41002?ooool4o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Sooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Wooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
41000oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo
00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnH
V9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[o
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[o
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[o
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`Go00001?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03
o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`09
ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooo
oolIooooo`00i_ooool00onHV9So8B4Qonk^kP09ooooo`04o`000?oooooooooooa0@40?ooooo00?o
410@ooooooooool01_ooool4o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h01oooool0
1OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`3ooooooaWooooo003Xooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c002ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo
003Yooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[Zjoooo
oonHV9So410@00Cooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00So
oooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lQ8B7oc<c<00Co
oooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003Uooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Gooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00
jOooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003oooo
o`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00onYZJWo
410@ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000Sooooo1?l0003ooooooaSooooo003Wooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000oooooolTooooo`00j?ooool0
0onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooo
oooooooo410@0?oooooo9?ooool00>Gooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?oooooo9?ooool00>Go
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^0?oooooo9?ooool00?oooooooooooolOooooo`00oooooooooooo
oaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo
7oooool00?Oooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo0_l0003oooooo`Wooooo003g
ooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo0?oooooo1oooool0
0>_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`04o`000?oooooo
ooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`00
0?m4A4Co^[Zj00Cooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooo
oooooooo000000Kooooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0ooo
ool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003ooooo
ooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`02ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`3oooooo`Oooooo003/ooooo`Go00001_ooool00ol0003oooooooooo`02ooooo`04
ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooo
o`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooooooool2
o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0003oooooooooo`3o
ooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00joooool01?l@
413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo0_l0000Booooo`03o`000?oooooo
oooo00Gooooo0_l0003oooooo`Wooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00
oooooooooooooaoooooo0000\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.3 -0.0125 -12 -9 ]
[.3 -0.0125 12 0 ]
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.3 0 m
.3 .00625 L
s
[(-0.4)] .3 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.3 0 m
.3 .00206 L
.35 .00206 L
.35 0 L
F
0 g
.5 Mabswid
.3 0 m
.3 .00206 L
.35 .00206 L
.35 0 L
.3 0 L
s
1 0 0 r
.35 0 m
.35 .10507 L
.4 .10507 L
.4 0 L
F
0 g
.35 0 m
.35 .10507 L
.4 .10507 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .17923 L
.45 .17923 L
.45 0 L
F
0 g
.4 0 m
.4 .17923 L
.45 .17923 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .15451 L
.5 .15451 L
.5 0 L
F
0 g
.45 0 m
.45 .15451 L
.5 .15451 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .17305 L
.55 .17305 L
.55 0 L
F
0 g
.5 0 m
.5 .17305 L
.55 .17305 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .14215 L
.6 .14215 L
.6 0 L
F
0 g
.55 0 m
.55 .14215 L
.6 .14215 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .12773 L
.65 .12773 L
.65 0 L
F
0 g
.6 0 m
.6 .12773 L
.65 .12773 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .11331 L
.7 .11331 L
.7 0 L
F
0 g
.65 0 m
.65 .11331 L
.7 .11331 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .01442 L
.75 .01442 L
.75 0 L
F
0 g
.7 0 m
.7 .01442 L
.75 .01442 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .01854 L
.8 .01854 L
.8 0 L
F
0 g
.75 0 m
.75 .01854 L
.8 .01854 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool009gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool5o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@
4?oooooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko
<S8bo`000?l@413oc<c<08Gooooo002Mooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0AOooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo01Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q08Gooooo002Eooooo`Ko00000_ooool0
1Ol@413ooooooooooooooooo410@00_ooooo1Ol0000Booooo`Ko00000_ooool01Ol@413ooooooooo
oooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0A_ooool01Ol@413ooooooooooooooooo410@00co
oooo00?oV9RHob4Q8Oo^k^h06_ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0000Joooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000008Gooooo002M
ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool0000Kooooo`05o`00
0?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP15ooooo`05o`000?oooooooooooooo
ool000003Oooool00onHV9So8B4Qonk^kP0Iooooo`05o`000?ooooooooooooooool000002oooool0
1?m4A4CogMgMooooool0000Kooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RH
oooooonHV9So8B4Q08Gooooo002Mooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgo
EEEEooooool0000Kooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`14
ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`0Hooooo`05o`000?oo
ooooooooooooool000002oooool01?oMgMgoEEEEooooool0000Kooooo`05o`000?oooooooooooooo
ool000002oooool01Ol0003oEEEEo`000?l@413oc<c<08Gooooo002Mooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00omgMgOoc<c<o`00000Kooooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`13ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Gooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Kooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`27ooooo`00WOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol0003o^[ZjoooooonHV9So410@01Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03onk^k_m4A4Co000001_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413o
V9RH08Oooooo002Mooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0J
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<04Gooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`06Oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool06_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@QOooool00?oooooooooooolOooooo`00oooooooo
oooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00ooooooolooooo`;o0000
0_ooool2o`0001cooooo003ooooooocooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMdLooooo`00
ooooooomooooo`04omgMgOl0003o410@olc<c1gooooo000Goooooooo0000eol0000?ooooo`04onk^
k_lQ8B7o410@onk^kQgooooo002ToooooaSo00005ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMgogMgMolb<S8Mooooo`00
Y?ooool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo06[ooooo0_l00002ooooo`;o0000
7?ooool00:Cooooo00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2<ooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`2<ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2<ooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`2<ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool001Wo00005_oo00000ol0003ooooo
ooooo`2<ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o
0000ool00?oo00005?oo00000ol0003oooooooooo`2<ooooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo01Gooooo6?l0002>ooooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00
^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2koooo
o`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2k
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`2kooooo`00^ooooolIo`0001Koo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo000Ho`000;gooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`006?l0003Doooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo000Io`000>_ooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oo
oooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo000Io`0001Koo`0000?o0000ooooooooool0
ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o
0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eoooo
o`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
5Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooo
oooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`0EoooooaSo0000ooooool4ooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo01Gooooo00?o0000ooooooooool0oooooolIooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo01Gooooo00?o0000ooooooooool0oooooolIooooo`00dooooolH
o`0001Oooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003V
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08
ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`Co0000oooooolHooooo`00j?oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@
00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000
ooooooooool0oooooolIooooo`00i_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_oo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_oo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_oo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00i_ooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000002Olb<S;ogMgMoooo
ooooooook^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>So
oooo00?o0000ooooooooool01_ooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMg
M`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01oooool0
1?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooo
oolIooooo`00j?ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000ooo
ool00ol0003oooooooooo`06ooooo`Co0000oooooolHooooo`00j?ooool00ol0003oooooooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000Sooooo
00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oeEEEOmV
IVKo000000Gooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000
oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000
oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOooool5
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08oooo
o`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`Co0000oooooolH
ooooo`00ioooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool0
0omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00jOooool01Ol0003ooooooooo
oooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Ko
oooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[ZjoooooonHV9So410@00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool0
0ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Gooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
0_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00
iOooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9So
oooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oiRHV?lQ8B7o
k^k^00Wooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`06ooooo`Co0000oooo
oolHooooo`00ioooool00onHV9So8B4Qonk^kP07ooooo`05ogMgMolb<S;oooooooooool000000ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?oMgMg
ofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooooooooooooooo
o`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooo
ooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWo
oooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0
003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol@413o^[Zjoooooomg
MgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`05o`000?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01_ooool00ol0
003oooooooooo`3ooooooaWooooo003Xooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool4o`000?oooooo6?ooool0
0>Oooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`00003oooooobCooooo003Xooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@
oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100oooooolTooooo`00iOoo
ool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0oooooolTooooo`00iOooool01OnYZJWo410@o`000?l@413oZJVY
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0oooo
oolTooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00
oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooo
oaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00moooool2o`0000_ooooo00?o
0000okZj^_ooool03?ooool2o`000?oooooo2Oooool00?Oooooo00?o0000ooooooooool02_ooool2
oc8b<Pkooooo00?o0000ooooooooool0ooooool7ooooo`00joooool01?l@413o0000o`000?ooool2
o`000003oa0@4?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000ooo
ool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X01?ooool00ol0003ooooo
ooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool02_l0003ooooo
ooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o410@00Cooooo00Go
410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00CogMgMo`000?l@413o
c<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@
413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>co
oooo1Ol00006ooooo`03o`000?oooooooooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000oooooooo
ooooooooo`000006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000Sooooo00?o410@
o`000?l000000ol00005ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@
ooooooooool00oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`000?oooooo2Oooool0
0?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00001\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .08034 L
.4 .08034 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .08034 L
.4 .08034 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .19365 L
.45 .19365 L
.45 0 L
F
0 g
.4 0 m
.4 .19365 L
.45 .19365 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .14421 L
.5 .14421 L
.5 0 L
F
0 g
.45 0 m
.45 .14421 L
.5 .14421 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .19159 L
.55 .19159 L
.55 0 L
F
0 g
.5 0 m
.5 .19159 L
.55 .19159 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .14215 L
.6 .14215 L
.6 0 L
F
0 g
.55 0 m
.55 .14215 L
.6 .14215 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .13597 L
.65 .13597 L
.65 0 L
F
0 g
.6 0 m
.6 .13597 L
.65 .13597 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .08446 L
.7 .08446 L
.7 0 L
F
0 g
.65 0 m
.65 .08446 L
.7 .08446 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .03296 L
.75 .03296 L
.75 0 L
F
0 g
.7 0 m
.7 .03296 L
.75 .03296 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .02472 L
.8 .02472 L
.8 0 L
F
0 g
.75 0 m
.75 .02472 L
.8 .02472 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08co
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo000Ho`0008kooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo000Io`000:Gooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^ooo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
^oooool00;_ooooo6Ol0000Fool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`006?l0002mooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`006?l0003D
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`006Ol0003[ooooo`00dooo
ool00ol0003oo`00ool0000Dool001Wo00005_oo00000ol0003oooooooooo`3oooooo`;ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000D
ool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2oooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo
0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3o
ooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0E
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000D
ool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2oooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo
0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3o
ooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05OoooolHo`00
0?oooooo1?ooool00=?ooooo6?l0000Gooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00i_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?oo
ool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool4o`000?oooooo
6?ooool00>Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08
ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Kooooo1?l000001Ol@413oooooooooooooooooA4A400;o000000Wo
<S8bomgMgOooooooooooonk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Xooooo`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9So
oooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooo
oooo00Oooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`06ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool01OmgMgOo<S8boooooooo
oooo000000?ooooo00?o0000ooooooooool01_ooool4o`000?oooooo6?ooool00>Sooooo00?o0000
ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooooooooooooooo
o`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_oo
ool00omEEEGoIVIVo`000005ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Gooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So8B4Qonk^
k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oiRHV?lQ8B7ok^k^00Co
oooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?ooool4
o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Sooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00Go
0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go0000okZj^_oooooo
V9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lQ8B7o
c<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`Go00001?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`09ogMgMolb<S;ooooooooo
oomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool0
0onHV9So8B4Qonk^kP09ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool01_oo
ool4o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h01oooool01OmgMgOo<S8boooooooo
oooo000000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003X
ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00Sooooo
00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo
00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000oooooooo
ool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003o
oooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003o
oooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05
oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go410@
okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00jOooool01Ol0003ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo
00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00onYZJWo410@ooooo`02ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo1?l0003o
oooooaSooooo003Wooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool00000oooooolTooooo`00j?ooool00onj^[[o8B4Qooooo`02
ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@0?oooooo
9?ooool00>Gooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?oooooo9?ooool00>Gooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^0?oooooo9?ooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooo
oooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool0
0?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?Oooooo0_l0
000;ooooo`03o`000?nj^[[ooooo00cooooo0_l0003oooooo`Wooooo003gooooo`03o`000?oooooo
oooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo0?oooooo1oooool00>_ooooo00Co410@o`00
0?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00000_oo
ool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo
00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo
00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@
4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003oooooooooo`3oooooo`Oooooo
003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`04omgM
gOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oo
oooo003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`04
onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooo
o`Oooooo003/ooooo`Go00001_ooool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b
<P_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05
o`000?ooooooooooooooool000001_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l00008
ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0003oooooooooo`3oooooo`Oooooo003/oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00joooool01?l@413o0000o`000?ooool2
o`000003oa0@4?oooooooooo00?ooooo0_l0000Booooo`03o`000?oooooooooo00Gooooo0_l0003o
ooooo`Wooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo
0000\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .08034 L
.4 .08034 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .08034 L
.4 .08034 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .15451 L
.45 .15451 L
.45 0 L
F
0 g
.4 0 m
.4 .15451 L
.45 .15451 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .14215 L
.5 .14215 L
.5 0 L
F
0 g
.45 0 m
.45 .14215 L
.5 .14215 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .18541 L
.55 .18541 L
.55 0 L
F
0 g
.5 0 m
.5 .18541 L
.55 .18541 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .15863 L
.6 .15863 L
.6 0 L
F
0 g
.55 0 m
.55 .15863 L
.6 .15863 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .14833 L
.65 .14833 L
.65 0 L
F
0 g
.6 0 m
.6 .14833 L
.65 .14833 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .08034 L
.7 .08034 L
.7 0 L
F
0 g
.65 0 m
.65 .08034 L
.7 .08034 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .06386 L
.75 .06386 L
.75 0 L
F
0 g
.7 0 m
.7 .06386 L
.75 .06386 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .01648 L
.8 .01648 L
.8 0 L
F
0 g
.75 0 m
.75 .01648 L
.8 .01648 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
000Ho`0008kooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Soooo
o`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2S
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`006Ol0002Uooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00
^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002koooooaWo00005_oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool001So0000_Oooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`006Ol0000Fool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo000H
o`000=Cooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00dooooolHo`0001Oooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo
003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0>Wooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo000Io`000>_ooooo003ooooo
o`?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003oooooo`?o
oooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003oooooo`?ooooo
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003oooooo`?ooooo00?o
0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003oooooo`?ooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`3oooooo`;ooooo003oooooo`?ooooo6?l0003oooooo`Cooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`Co000000So410@ooooooooooook^k^oc8b
<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0>Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@
oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000008ooooo`Co0000oooooolHooooo`00j?ooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooooooo
ool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00j?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool4o`000005oa0@4?oooooo
oooooooooom4A4@00_l000002Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^kP08oooo
o`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool02OmgMgOo
<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Sooooo00?o0000ooooooooool01oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oo
oooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`06
ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`06ooooo`Co0000oooo
oolHooooo`00j?ooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_oo
ool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00j?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooo
oa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Vooooo`03oeEEEOmVIVKo000000Gooooo1?l00003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[o
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00iOooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo
003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Ko
oooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooo
oooooooooooooa0@4008ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP03oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o
0000ooooooooool0oooooolIooooo`00j?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
oooooolIooooo`00jOooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00
iOooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uoooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oo
oooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oo
oooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oo
oooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo1Ol0
0004ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00So
oooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So8B4Qonk^k_ooooooA4A400Oo
oooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003ooooooooo
o`3ooooooaWooooo003Vooooo`03oiRHV?lQ8B7ok^k^00Wooooo00Co0000oooooooooooo410@0ooo
ool00ol@413oooooooooo`06ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP07
ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Sooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05oa0@4?oo
ooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05o`000?nj
^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`01?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooo
oa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooo
oa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooo
oolIooooo`00iOooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWo
oooo003Yooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000002?ooool4o`000?oooooo6?ooool00>Oooooo00?o410@o`000?nj^[X00oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00003oooooobCooooo003X
ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oo
ooooooooooooool@4100oooooolTooooo`00iOooool01Ol@413oV9RHoooooonj^[[o000000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0oooooolToooo
o`00iOooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0oooooolTooooo`00oooooooooooooaoooooo003ooooo
oooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7ooo
ool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooo
oooooolOooooo`00moooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`000?oooooo2Ooo
ool00?Oooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool0ooooool7
ooooo`00joooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo00Co0000
oooooooooooooooo0_l00002ooooo`;o00000oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0
003o0000odA4A?nj^[X01?ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?oo
ooooooooooooool000001_ooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oM
gMd3ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`00
0?oooooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo00;ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo0?oooooo1oooool00>cooooo1Ol00006ooooo`03o`000?oooooooooo00;o
oooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooooooo
ooooo`;o00000_ooool2o`0000Sooooo00?o410@o`000?l000000ol00005ooooo`03o`000?oooooo
oooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003[oooo
o`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool2o`0001;ooooo00?o0000
ooooooooool01Oooool2o`000?oooooo2Oooool00?oooooooooooolOooooo`00oooooooooooooaoo
oooo003ooooooooooooo7oooool00001\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .05768 L
.4 .05768 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .05768 L
.4 .05768 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .16893 L
.45 .16893 L
.45 0 L
F
0 g
.4 0 m
.4 .16893 L
.45 .16893 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .14833 L
.5 .14833 L
.5 0 L
F
0 g
.45 0 m
.45 .14833 L
.5 .14833 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .19777 L
.55 .19777 L
.55 0 L
F
0 g
.5 0 m
.5 .19777 L
.55 .19777 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .16069 L
.6 .16069 L
.6 0 L
F
0 g
.55 0 m
.55 .16069 L
.6 .16069 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .10095 L
.65 .10095 L
.65 0 L
F
0 g
.6 0 m
.6 .10095 L
.65 .10095 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .08446 L
.7 .08446 L
.7 0 L
F
0 g
.65 0 m
.65 .08446 L
.7 .08446 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .09889 L
.75 .09889 L
.75 0 L
F
0 g
.7 0 m
.7 .09889 L
.75 .09889 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .01236 L
.8 .01236 L
.8 0 L
F
0 g
.75 0 m
.75 .01236 L
.8 .01236 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo000Ho`0008kooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo6Ol0000Fool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xooo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo000Ho`0001Ooo`0000?o0000ooooooooool0Xoooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo01Co
oooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05?ooool00ol0003oo`00
ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2S
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`0DoooooaWo
0000YOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo000Ho`000=Cooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yoooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Y
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`006Ol0000Fool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Go
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wo
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool05Oooool00ol0003oo`00ool0000Dool001Wo0000joooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0?oooooo0_ooool00=?ooooo6?l0000Gooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0oooo
ool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2
ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2oooo
o`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00
ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00oooo
ool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3oooo
o`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3oooooaSo0000oooo
ool4ooooo`00i_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?oo
ool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool4o`000?oooooo
6?ooool00>Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08
ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Kooooo1?l000001Ol@413oooooooooooooooooA4A400;o000000Wo
<S8bomgMgOooooooooooonk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Xooooo`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9So
oooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooo
oooo00Oooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`06ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool01OmgMgOo<S8boooooooo
oooo000000?ooooo00?o0000ooooooooool01_ooool4o`000?oooooo6?ooool00>Sooooo00?o0000
ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooooooooooooooo
o`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_oo
ool00omEEEGoIVIVo`000005ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Gooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So8B4Qonk^
k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oiRHV?lQ8B7ok^k^00Co
oooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?ooool4
o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Sooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00Go
0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go0000okZj^_oooooo
V9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lQ8B7o
c<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`Go00001?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`09ogMgMolb<S;ooooooooo
oomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool0
0onHV9So8B4Qonk^kP09ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool01_oo
ool4o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h01oooool01OmgMgOo<S8boooooooo
oooo000000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003X
ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00Sooooo
00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo
00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000oooooooo
ool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003o
oooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003o
oooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05
oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go410@
okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00jOooool01Ol0003ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo
00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00onYZJWo410@ooooo`02ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo1?l0003o
oooooaSooooo003Wooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool00000oooooolTooooo`00j?ooool00onj^[[o8B4Qooooo`02
ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@0?oooooo
9?ooool00>Gooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?oooooo9?ooool00>Gooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^0?oooooo9?ooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooo
oooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool0
0?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?Oooooo0_l0
000;ooooo`03o`000?nj^[[ooooo00cooooo0_l0003oooooo`Wooooo003gooooo`03o`000?oooooo
oooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo0?oooooo1oooool00>_ooooo00Co410@o`00
0?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00000_oo
ool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo
00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo
00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@
4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003oooooooooo`3oooooo`Oooooo
003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`04omgM
gOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oo
oooo003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`04
onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooo
o`Oooooo003/ooooo`Go00001_ooool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b
<P_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05
o`000?ooooooooooooooool000001_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l00008
ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0003oooooooooo`3oooooo`Oooooo003/oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00joooool01?l@413o0000o`000?ooool2
o`000003oa0@4?oooooooooo00?ooooo0_l0000Booooo`03o`000?oooooooooo00Gooooo0_l0003o
ooooo`Wooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo
0000\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .07622 L
.4 .07622 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .07622 L
.4 .07622 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .18541 L
.45 .18541 L
.45 0 L
F
0 g
.4 0 m
.4 .18541 L
.45 .18541 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .12773 L
.5 .12773 L
.5 0 L
F
0 g
.45 0 m
.45 .12773 L
.5 .12773 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .15863 L
.55 .15863 L
.55 0 L
F
0 g
.5 0 m
.5 .15863 L
.55 .15863 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .16687 L
.6 .16687 L
.6 0 L
F
0 g
.55 0 m
.55 .16687 L
.6 .16687 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .11949 L
.65 .11949 L
.65 0 L
F
0 g
.6 0 m
.6 .11949 L
.65 .11949 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .09271 L
.7 .09271 L
.7 0 L
F
0 g
.65 0 m
.65 .09271 L
.7 .09271 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .09271 L
.75 .09271 L
.75 0 L
F
0 g
.7 0 m
.7 .09271 L
.75 .09271 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .00824 L
.8 .00824 L
.8 0 L
F
0 g
.75 0 m
.75 .00824 L
.8 .00824 L
.8 0 L
.75 0 L
s
1 0 0 r
.8 0 m
.8 .00206 L
.85 .00206 L
.85 0 L
F
0 g
.8 0 m
.8 .00206 L
.85 .00206 L
.85 0 L
.8 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`006Ol0001Eooooo`04ob4Q8OmgMgOoMgMgoc8b<Qgo
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo06[ooooo0_l00002ooooo`;o00007?ooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0S?ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool001So0000S_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xooo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002koooooaWo
00005_oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xooo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00<?l0
002Uooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool001So
0000e?ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo000Io`00
01Koo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Ooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOoo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05OoooolHo`0001Ooo`0000?o0000
ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yoooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000oooooooo
ool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool2o`0001Gooooo00?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo01Gooooo00?o0000ooooooooool05?oooolIo`000>_ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oooooooooo`3ooooooaWooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oooooooooo`3ooooo
oaWooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003o
ooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
5Oooool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ooooooooool05Oooool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oooooooooo`3ooooooaWooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oooooooooo`3ooooo
oaWooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003o
ooooooooo`3ooooooaWooooo003CoooooaSo00005oooool2o`000?oooooo6_ooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo1?l000002?l@413oooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolI
ooooo`00j?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool0
1Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000Sooooo1?l0003ooooooaSooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Voooo
o`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`Co000000Go410@
ooooooooooooooooodA4A002o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`06ooooo`09
ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooo
oolIooooo`00j?ooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooooa0@40?ooooo00?o
410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooo
oooo00Kooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo1?l0
003ooooooaSooooo003Xooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c002ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo
003Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Kooooo00?oEEEEofIVI_l000001Oooool4o`0000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oo
oooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00i_ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@00Sooooo1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?oo
ool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ogMgMomVIVKooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Yooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWo
oooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o
0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o
0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o
0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOoo
ool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^k^h02Oooool01?l0003oooooooooool@
4103ooooo`03oa0@4?oooooooooo00Kooooo1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7o
k^k^00Oooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0oooooolIooooo`00j?ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
oooooolIooooo`00jOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go
410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go
0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c004ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`00
0?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`00
0?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003ooooooooo
o`3ooooooaWooooo003Uooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Wooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>So
oooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000008ooooo`Co0000oooooolHooooo`00ioooool00ol@413o0000okZj^P03oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo00000?oooooo9?oo
ool00>Sooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@403oooooobCooooo003Uooooo`05oa0@4?nHV9SooooookZj^_l00000
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`3ooooo
obCooooo003Uooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP3oooooobCooooo003ooooooooooooo7oooool0
0?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooo
oolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00
oooooooooooooaoooooo003gooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o0000oooo
ool9ooooo`00moooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`3o
ooooo`Oooooo003[ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool0
1?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00Go
V9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go
0000ooooooooooooooooo`000006ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o
0000omgMg@?ooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo
00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool5o`0000Kooooo00?o0000oooooooo
ool00_ooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooo
oooooooooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Gooooo00?o0000
ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool0
0>_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`;o00004_ooool0
0ol0003oooooooooo`05ooooo`;o0000ooooool9ooooo`00oooooooooooooaoooooo003ooooooooo
oooo7oooool00?oooooooooooolOooooo`00\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .06798 L
.4 .06798 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .06798 L
.4 .06798 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .18953 L
.45 .18953 L
.45 0 L
F
0 g
.4 0 m
.4 .18953 L
.45 .18953 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .12773 L
.5 .12773 L
.5 0 L
F
0 g
.45 0 m
.45 .12773 L
.5 .12773 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .17511 L
.55 .17511 L
.55 0 L
F
0 g
.5 0 m
.5 .17511 L
.55 .17511 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .17717 L
.6 .17717 L
.6 0 L
F
0 g
.55 0 m
.55 .17717 L
.6 .17717 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .11537 L
.65 .11537 L
.65 0 L
F
0 g
.6 0 m
.6 .11537 L
.65 .11537 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .11125 L
.7 .11125 L
.7 0 L
F
0 g
.65 0 m
.65 .11125 L
.7 .11125 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .06386 L
.75 .06386 L
.75 0 L
F
0 g
.7 0 m
.7 .06386 L
.75 .06386 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .00206 L
.8 .00206 L
.8 0 L
F
0 g
.75 0 m
.75 .00206 L
.8 .00206 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool001So0000KOooool01?lQ8B7oMgMgogMgMolb<S8Mooooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`1Zooooo`;o00000_ooool2o`0001cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oooooooooo08cooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2S
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo000Io`000:Gooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0^oooool00;_ooooo6Ol0000Fool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2koooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2k
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
6?l0002mooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo000Ho`000=Cooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOoo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0
003oo`00ool0000Dool001Wo00005_oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eoooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yoooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooo
oooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0E
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Y
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool05OoooolHo`0001Ooo`0000?o0000ooooooooool0jOooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Cooooo6Ol0
003[ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000
ooooooooool0oooooolIooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo
01Gooooo00?o0000ooooooooool0oooooolIooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo01Gooooo00?o0000ooooooooool0oooooolIooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo01Gooooo0_l0003ooooooa[ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oooooooooo`3ooooooaWooooo003C
oooooaSo00005oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00i_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?oo
ool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool4o`000?oooooo
6?ooool00>Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08
ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Kooooo1?l000001Ol@413oooooooooooooooooA4A400;o000000Wo
<S8bomgMgOooooooooooonk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Xooooo`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9So
oooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooo
oooo00Oooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`06ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool01OmgMgOo<S8boooooooo
oooo000000?ooooo00?o0000ooooooooool01_ooool4o`000?oooooo6?ooool00>Sooooo00?o0000
ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooooooooooooooo
o`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_oo
ool00omEEEGoIVIVo`000005ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Gooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So8B4Qonk^
k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oiRHV?lQ8B7ok^k^00Co
oooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?ooool4
o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Sooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00Go
0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go0000okZj^_oooooo
V9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lQ8B7o
c<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`Go00001?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`09ogMgMolb<S;ooooooooo
oomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool0
0onHV9So8B4Qonk^kP09ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool01_oo
ool4o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h01oooool01OmgMgOo<S8boooooooo
oooo000000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003X
ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00Sooooo
00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo
00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000oooooooo
ool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003o
oooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003o
oooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05
oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go410@
okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00jOooool01Ol0003ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo
00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00onYZJWo410@ooooo`02ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo1?l0003o
oooooaSooooo003Wooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool00000oooooolTooooo`00j?ooool00onj^[[o8B4Qooooo`02
ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@0?oooooo
9?ooool00>Gooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?oooooo9?ooool00>Gooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^0?oooooo9?ooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooo
oooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool0
0?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?Oooooo0_l0
000;ooooo`03o`000?nj^[[ooooo00cooooo0_l0003oooooo`Wooooo003gooooo`03o`000?oooooo
oooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo0?oooooo1oooool00>_ooooo00Co410@o`00
0?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00000_oo
ool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo
00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo
00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@
4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003oooooooooo`3oooooo`Oooooo
003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`04omgM
gOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oo
oooo003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`04
onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooo
o`Oooooo003/ooooo`Go00001_ooool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b
<P_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05
o`000?ooooooooooooooool000001_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l00008
ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0003oooooooooo`3oooooo`Oooooo003/oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00joooool01?l@413o0000o`000?ooool2
o`000003oa0@4?oooooooooo00?ooooo0_l0000Booooo`03o`000?oooooooooo00Gooooo0_l0003o
ooooo`Wooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo
0000\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .06386 L
.4 .06386 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .06386 L
.4 .06386 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .16687 L
.45 .16687 L
.45 0 L
F
0 g
.4 0 m
.4 .16687 L
.45 .16687 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .17099 L
.5 .17099 L
.5 0 L
F
0 g
.45 0 m
.45 .17099 L
.5 .17099 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .19159 L
.55 .19159 L
.55 0 L
F
0 g
.5 0 m
.5 .19159 L
.55 .19159 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .16069 L
.6 .16069 L
.6 0 L
F
0 g
.55 0 m
.55 .16069 L
.6 .16069 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .13185 L
.65 .13185 L
.65 0 L
F
0 g
.6 0 m
.6 .13185 L
.65 .13185 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .09889 L
.7 .09889 L
.7 0 L
F
0 g
.65 0 m
.65 .09889 L
.7 .09889 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .04326 L
.75 .04326 L
.75 0 L
F
0 g
.7 0 m
.7 .04326 L
.75 .04326 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .00206 L
.8 .00206 L
.8 0 L
F
0 g
.75 0 m
.75 .00206 L
.8 .00206 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool001So0000KOooool01?lQ8B7oMgMgogMgMolb<S8Mooooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`1Zooooo`;o00000_ooool2o`0001cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oooooooooo08cooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2S
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool001Wo0000YOooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo6Ol0000Fool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2koooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2k
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`006?l0002mooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool001So0000e?ooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`006Ol0003[ooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo6?l0000Gool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00j_ooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00j_oooolIo`00
01Koo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0oooo
ool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2
ooooo`00ooooool3oooooaSo0000ooooool4ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00i_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xoooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo
ooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
2?ooool4o`000?oooooo6?ooool00>Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>So
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oEEEEofIV
I_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo1?l000001Ol@413ooooooooooooo
ooooA4A400;o000000Wo<S8bomgMgOooooooooooonk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0
003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_oo
ooooooooogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003X
ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo410@0oooool00ol@413ooooooooo
o`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool0
1OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool01_ooool4o`000?oooooo6?oo
ool00>Sooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go
0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0
oooooolIooooo`00i_ooool00omEEEGoIVIVo`000005ooooo`Co00000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Gooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOoo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03
oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooo
ooooool@41002?ooool4o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Sooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Wooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
41000oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo
00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnH
V9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[o
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[o
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[o
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`Go00001?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03
o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`09
ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooo
oolIooooo`00i_ooool00onHV9So8B4Qonk^kP09ooooo`04o`000?oooooooooooa0@40?ooooo00?o
410@ooooooooool01_ooool4o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h01oooool0
1OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`3ooooooaWooooo003Xooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c002ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo
003Yooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[Zjoooo
oonHV9So410@00Cooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00So
oooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lQ8B7oc<c<00Co
oooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003Uooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Gooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00
jOooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003oooo
o`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00onYZJWo
410@ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000Sooooo1?l0003ooooooaSooooo003Wooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000oooooolTooooo`00j?ooool0
0onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooo
oooooooo410@0?oooooo9?ooool00>Gooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?oooooo9?ooool00>Go
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^0?oooooo9?ooool00?oooooooooooolOooooo`00oooooooooooo
oaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo
7oooool00?Oooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo0_l0003oooooo`Wooooo003g
ooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo0?oooooo1oooool0
0>_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`04o`000?oooooo
ooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`00
0?m4A4Co^[Zj00Cooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooo
oooooooo000000Kooooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0ooo
ool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003ooooo
ooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`02ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`3oooooo`Oooooo003/ooooo`Go00001_ooool00ol0003oooooooooo`02ooooo`04
ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooo
o`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooooooool2
o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0003oooooooooo`3o
ooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00joooool01?l@
413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo0_l0000Booooo`03o`000?oooooo
oooo00Gooooo0_l0003oooooo`Wooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00
oooooooooooooaoooooo0000\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .10095 L
.4 .10095 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .10095 L
.4 .10095 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .19571 L
.45 .19571 L
.45 0 L
F
0 g
.4 0 m
.4 .19571 L
.45 .19571 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .12567 L
.5 .12567 L
.5 0 L
F
0 g
.45 0 m
.45 .12567 L
.5 .12567 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .16893 L
.55 .16893 L
.55 0 L
F
0 g
.5 0 m
.5 .16893 L
.55 .16893 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .16893 L
.6 .16893 L
.6 0 L
F
0 g
.55 0 m
.55 .16893 L
.6 .16893 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .13185 L
.65 .13185 L
.65 0 L
F
0 g
.6 0 m
.6 .13185 L
.65 .13185 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .10095 L
.7 .10095 L
.7 0 L
F
0 g
.65 0 m
.65 .10095 L
.7 .10095 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .0206 L
.75 .0206 L
.75 0 L
F
0 g
.7 0 m
.7 .0206 L
.75 .0206 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .01648 L
.8 .01648 L
.8 0 L
F
0 g
.75 0 m
.75 .01648 L
.8 .01648 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
000Ho`0008kooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool001Wo0000YOooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2k
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^ooo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0^oooool00;_ooooo6Ol0000Fool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`006?l0002mooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_oo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`006Ol0000Fool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`006?l0003Dooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eoooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yoooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooo
oooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0E
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Y
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool`
o`000>_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0
003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool05Oooool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool05Oooool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oooooooooo`3ooooooaWooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oooooooooo`3o
oooooaWooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0
003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool05Oooool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool05Oooool2o`000?oooooo6_ooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo0?oooooo6Oooool00=?ooooo6?l0000Gooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`Co000000So410@
ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08oooo
o`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000008ooooo`Co0000oooooolHooooo`00j?ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000So
oooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolI
ooooo`00i_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000
oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool4
o`000005oa0@4?oooooooooooooooom4A4@00_l000002Olb<S;ogMgMooooooooooook^k^oc8b<_l0
003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000oooooooo
ool01_ooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01oooool01?l0003oooooooooool@
4103ooooo`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool0
0ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003ooooooooo
o`06ooooo`Co0000oooooolHooooo`00j?ooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
oooooolIooooo`00j?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go
410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oeEEEOmVIVKo000000Gooooo1?l0
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOooool5o`0000?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`Co0000oooooolHooooo`00ioooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00omgMgOoIVIVooooo`02
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo
00?o0000ooooooooool0oooooolIooooo`00jOooool01Ol0003ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooolIooooo`00iOooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3o
oooooaWooooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Gooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So8B4Q
onk^k_ooooooA4A400Oooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL02?oo
ool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oiRHV?lQ8B7ok^k^00Wooooo00Co0000
oooooooooooo410@0oooool00ol@413oooooooooo`06ooooo`Co0000oooooolHooooo`00ioooool0
0onHV9So8B4Qonk^kP07ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?oMgMgofIVI_ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Wooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo
003Uooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`04ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o<S8bolc<c003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o
0000ooooooooool0oooooolIooooo`00iOooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Yooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@00?ooooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooo
oaWooooo003Xooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000002?ooool4o`000?oooooo6?ooool00>Oooooo00?o410@o`00
0?nj^[X00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
003oooooobCooooo003Xooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100oooooolTooooo`00iOooool01Ol@413oV9RHoooo
oonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL0oooooolTooooo`00iOooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0oooooolTooooo`00oooooooo
oooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo
003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooo
oooo7oooool00?oooooooooooolOooooo`00moooool2o`0000_ooooo00?o0000okZj^_ooool03?oo
ool2o`000?oooooo2Oooool00?Oooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000
ooooooooool0ooooool7ooooo`00joooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooo
oooo00?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000oooool00on7QhOo0000okZj
^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X01?ooool00ol0003oooooooooo`3oooooo`Oooooo
003/ooooo`05o`000?ooooooooooooooool000001_ooool02_l0003oooooooooooooooook^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMg
oa0@4004ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo00;ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo1Ol00006ooooo`03
o`000?oooooooooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006oooo
o`04o`000?ooooooooooooooo`;o00000_ooool2o`0000Sooooo00?o410@o`000?l000000ol00005
ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3o
ooooo`Oooooo003[ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool2
o`0001;ooooo00?o0000ooooooooool01Oooool2o`000?oooooo2Oooool00?oooooooooooolOoooo
o`00oooooooooooooaoooooo003ooooooooooooo7oooool00001\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .07416 L
.4 .07416 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .07416 L
.4 .07416 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .16275 L
.45 .16275 L
.45 0 L
F
0 g
.4 0 m
.4 .16275 L
.45 .16275 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .16893 L
.5 .16893 L
.5 0 L
F
0 g
.45 0 m
.45 .16893 L
.5 .16893 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .18541 L
.55 .18541 L
.55 0 L
F
0 g
.5 0 m
.5 .18541 L
.55 .18541 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .18747 L
.6 .18747 L
.6 0 L
F
0 g
.55 0 m
.55 .18747 L
.6 .18747 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .11537 L
.65 .11537 L
.65 0 L
F
0 g
.6 0 m
.6 .11537 L
.65 .11537 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .07622 L
.7 .07622 L
.7 0 L
F
0 g
.65 0 m
.65 .07622 L
.7 .07622 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .0412 L
.75 .0412 L
.75 0 L
F
0 g
.7 0 m
.7 .0412 L
.75 .0412 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .01854 L
.8 .01854 L
.8 0 L
F
0 g
.75 0 m
.75 .01854 L
.8 .01854 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo000Ho`0008kooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`006Ol0002Uooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2koooo
o`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2k
ooooo`00^ooooolIo`0001Koo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo000Ho`000;gooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo000Ho`000=Cooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOoo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0>Wooooo003CoooooaSo00005ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00>[ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
jOooool00>[ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0jOooool00>[ooooo6Ol0000Fool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0jOooool00?oooooo0oooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00?oooooo0oooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00?oooooo
0oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
jOooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0jOooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0jOooool00?oooooo0oooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00?oooooo0oooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00?oooooo
0ooooolHo`0001Ooo`0000?o0000ooooooooool0jOooool00?oooooo0oooool00ol0003ooooooooo
o`0DoooooaWo0000joooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00i_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xoooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo
ooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
2?ooool4o`000?oooooo6?ooool00>Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>So
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oEEEEofIV
I_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo1?l000001Ol@413ooooooooooooo
ooooA4A400;o000000Wo<S8bomgMgOooooooooooonk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0
003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_oo
ooooooooogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003X
ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo410@0oooool00ol@413ooooooooo
o`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool0
1OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool01_ooool4o`000?oooooo6?oo
ool00>Sooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go
0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0
oooooolIooooo`00i_ooool00omEEEGoIVIVo`000005ooooo`Co00000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Gooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOoo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03
oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooo
ooooool@41002?ooool4o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Sooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Wooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
41000oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo
00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnH
V9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[o
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[o
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[o
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`Go00001?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03
o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`09
ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooo
oolIooooo`00i_ooool00onHV9So8B4Qonk^kP09ooooo`04o`000?oooooooooooa0@40?ooooo00?o
410@ooooooooool01_ooool4o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h01oooool0
1OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`3ooooooaWooooo003Xooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c002ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo
003Yooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[Zjoooo
oonHV9So410@00Cooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00So
oooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lQ8B7oc<c<00Co
oooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003Uooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Gooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00
jOooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003oooo
o`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00onYZJWo
410@ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000Sooooo1?l0003ooooooaSooooo003Wooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000oooooolTooooo`00j?ooool0
0onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooo
oooooooo410@0?oooooo9?ooool00>Gooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?oooooo9?ooool00>Go
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^0?oooooo9?ooool00?oooooooooooolOooooo`00oooooooooooo
oaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo
7oooool00?Oooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo0_l0003oooooo`Wooooo003g
ooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo0?oooooo1oooool0
0>_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`04o`000?oooooo
ooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`00
0?m4A4Co^[Zj00Cooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooo
oooooooo000000Kooooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0ooo
ool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003ooooo
ooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`02ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`3oooooo`Oooooo003/ooooo`Go00001_ooool00ol0003oooooooooo`02ooooo`04
ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooo
o`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooooooool2
o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0003oooooooooo`3o
ooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00joooool01?l@
413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo0_l0000Booooo`03o`000?oooooo
oooo00Gooooo0_l0003oooooo`Wooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00
oooooooooooooaoooooo0000\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .08446 L
.4 .08446 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .08446 L
.4 .08446 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .17305 L
.45 .17305 L
.45 0 L
F
0 g
.4 0 m
.4 .17305 L
.45 .17305 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .14215 L
.5 .14215 L
.5 0 L
F
0 g
.45 0 m
.45 .14215 L
.5 .14215 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .16069 L
.55 .16069 L
.55 0 L
F
0 g
.5 0 m
.5 .16069 L
.55 .16069 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .16893 L
.6 .16893 L
.6 0 L
F
0 g
.55 0 m
.55 .16893 L
.6 .16893 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .12567 L
.65 .12567 L
.65 0 L
F
0 g
.6 0 m
.6 .12567 L
.65 .12567 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .09889 L
.7 .09889 L
.7 0 L
F
0 g
.65 0 m
.65 .09889 L
.7 .09889 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .05974 L
.75 .05974 L
.75 0 L
F
0 g
.7 0 m
.7 .05974 L
.75 .05974 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .01648 L
.8 .01648 L
.8 0 L
F
0 g
.75 0 m
.75 .01648 L
.8 .01648 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
000Ho`0008kooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Soooo
o`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2S
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool001Wo0000YOoo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002koooooaWo00005_oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool001So
0000_Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3B
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo000H
o`000=Cooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Y
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo0000
5?oo000Io`0001Koo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Go
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wo
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool05OoooolHo`0001Ooo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Cooooo00?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo01Gooooo0_l0000Eooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ooooooooool05?oooolI
o`000>_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0
003oooooooooo`3ooooooaWooooo003CoooooaSo00005oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Kooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;o
k^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00j?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo
1?l0003ooooooaSooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWo
oooo003Xooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oeEEEOmVIVKo0000
00Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?oo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`Co000000Go410@ooooooooooooooooodA4
A002o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`06ooooo`09ogMgMolb<S;ooooooooo
oomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool0
0ol0003oooooooooo`07ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool01_oo
ool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00Kooooo00GoMgMg
oc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo1?l0003ooooooaSooooo003X
ooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00Sooooo
00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Kooooo00?oEEEEofIVI_l000001Oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooo
oolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003Uooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go
V9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00onHV9So
8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo
410@00Sooooo1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooooooo
o`3ooooooaWooooo003Xooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo
003Yooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?o
oooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05o`00
0?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOooool5o`0000Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool02OmgMgOo
<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Kooooo00?oV9RHob4Q8Oo^k^h02Oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oo
oooooooo00Kooooo1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^00Oooooo00GoMgMg
oc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooo
oolIooooo`00j?ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_oo
ool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00jOoo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooo
oa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go0000okZj^_ooooooV9RH
oa0@4004ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03
o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00iOooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003U
ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo
00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@
413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?oZJVYoa0@4?oo
ool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008
ooooo`Co0000oooooolHooooo`00ioooool00ol@413o0000okZj^P03ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo00000?oooooo9?ooool00>Sooooo00?o^[Zj
ob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooo
oa0@403oooooobCooooo003Uooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`3oooooobCooooo003Uooooo`05
ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP3oooooobCooooo003ooooooooooooo7oooool00?oooooooooooolOoooo
o`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooo
oooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo
003gooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o0000ooooool9ooooo`00moooool0
0ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`3oooooo`Oooooo003[oooo
o`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool01?l0003ooooooooooooo
ool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4
okZj^P04ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000oooooooooooooooo
o`000006ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo00?o
c<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000ooooooooool0
ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
0_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0ooooool7ooooo`00k?ooool5o`0000Kooooo00?o0000ooooooooool00_ooool01?lQ8B7o
MgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7oooo
o`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooooooo0_l00002
ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool0ooooool7
ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>_ooooo00Co410@o`00
0?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`;o00004_ooool00ol0003oooooooooo`05
ooooo`;o0000ooooool9ooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooo
oooooolOooooo`00\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .07004 L
.4 .07004 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .07004 L
.4 .07004 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .17305 L
.45 .17305 L
.45 0 L
F
0 g
.4 0 m
.4 .17305 L
.45 .17305 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .14421 L
.5 .14421 L
.5 0 L
F
0 g
.45 0 m
.45 .14421 L
.5 .14421 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .17099 L
.55 .17099 L
.55 0 L
F
0 g
.5 0 m
.5 .17099 L
.55 .17099 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .16275 L
.6 .16275 L
.6 0 L
F
0 g
.55 0 m
.55 .16275 L
.6 .16275 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .10713 L
.65 .10713 L
.65 0 L
F
0 g
.6 0 m
.6 .10713 L
.65 .10713 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .08858 L
.7 .08858 L
.7 0 L
F
0 g
.65 0 m
.65 .08858 L
.7 .08858 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .09683 L
.75 .09683 L
.75 0 L
F
0 g
.7 0 m
.7 .09683 L
.75 .09683 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .01648 L
.8 .01648 L
.8 0 L
F
0 g
.75 0 m
.75 .01648 L
.8 .01648 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
000Ho`0008kooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Soooo
o`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2S
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002koooooaWo00005_oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo000Ho`0001Oo
o`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`0D
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo01Cooooo6Ol0002Uoooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo000Ho`00
0=Cooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yoooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Y
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool001Wo00005_oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Go
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wo
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03
o`000?oo003oo`0001Coo`006Ol0003[ooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo6?l0003ooooo
o`Cooooo003CoooooaSo00005oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Kooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o
0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo1?l0003ooooooaSooooo
003Xooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool0
0ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooo
oolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooo
oolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooo
oolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003Vooooo`Co000000Go410@ooooooooooooooooodA4A002o`000009oc8b<_oM
gMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00j?ooool00ol0003oooooooooo`06ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonH
V9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`07
ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool01_ooool00ol0003ooooooooo
o`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00Kooooo00GoMgMgoc8b<_ooooooooooo`00
0003ooooo`03o`000?oooooooooo00Kooooo1?l0003ooooooaSooooo003Xooooo`03o`000?oooooo
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool00000
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0
oooooolIooooo`00j?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?o
EEEEofIVI_l000001Oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003U
ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo1?l0003o
oooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003X
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`05o`000?oo
ooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooooooo
ool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@
41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08
ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00iOooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8b
omgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWo
oooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool02OmgMgOo<S8booooooooooooMgMg
oiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oV9RH
ob4Q8Oo^k^h02Oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00Kooooo1?l0
003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^00Oooooo00GoMgMgoc8b<_ooooooooooo`00
0003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool0
0omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooo
oooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00jOooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Gooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`00
0?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJ
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJ
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So
410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oa0@4?nj^[[o
ooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00Go0000oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`06oooo
o`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`Co0000oooooolH
ooooo`00ioooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo00000?oooooo9?ooool00>Sooooo00?o^[Zjob4Q8Oooool00_ooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@403oooooobCooooo
003Uooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`3oooooobCooooo003Uooooo`05ojVYZOl@413o0000oa0@
4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooobCooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoo
oooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooo
oooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003gooooo`;o00002ooo
ool00ol0003o^[Zjooooo`0<ooooo`;o0000ooooool9ooooo`00moooool00ol0003oooooooooo`0:
ooooo`;o<S8b3_ooool00ol0003oooooooooo`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o0000
ooooo`;o000000?o410@ooooooooool00oooool01?l0003oooooooooooooool2o`0000;ooooo0_l0
0003ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`00
0?oooooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`0:o`00
0?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo00?oc<c<o`000?l@41001?oo
ool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000ooooooooool0ooooool7ooooo`00k?oo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool01?oMgMgo0000
oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00
k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool01?o^k^ko
8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7oooo
o`00k?ooool5o`0000Kooooo00?o0000ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb<S8;oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003o
oooooooooooooooo000000Kooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00002?ooool0
0ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo0?oooooo1oooool00>_ooooo00Co410@o`000?l0003ooooo0_l00000
0ol@413oooooooooo`03ooooo`;o00004_ooool00ol0003oooooooooo`05ooooo`;o0000ooooool9
ooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .05768 L
.4 .05768 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .05768 L
.4 .05768 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .16481 L
.45 .16481 L
.45 0 L
F
0 g
.4 0 m
.4 .16481 L
.45 .16481 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .14009 L
.5 .14009 L
.5 0 L
F
0 g
.45 0 m
.45 .14009 L
.5 .14009 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .21219 L
.55 .21219 L
.55 0 L
F
0 g
.5 0 m
.5 .21219 L
.55 .21219 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .13391 L
.6 .13391 L
.6 0 L
F
0 g
.55 0 m
.55 .13391 L
.6 .13391 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .11949 L
.65 .11949 L
.65 0 L
F
0 g
.6 0 m
.6 .11949 L
.65 .11949 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .10095 L
.7 .10095 L
.7 0 L
F
0 g
.65 0 m
.65 .10095 L
.7 .10095 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .08858 L
.75 .08858 L
.75 0 L
F
0 g
.7 0 m
.7 .08858 L
.75 .08858 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .00824 L
.8 .00824 L
.8 0 L
F
0 g
.75 0 m
.75 .00824 L
.8 .00824 L
.8 0 L
.75 0 L
s
1 0 0 r
.8 0 m
.8 .00412 L
.85 .00412 L
.85 0 L
F
0 g
.8 0 m
.8 .00412 L
.85 .00412 L
.85 0 L
.8 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`1Cooooo`04ob4Q8OmgMgOoMgMgoc8b<Qgooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool001Wo0000E?ooool2o`0000;ooooo
0_l0000Looooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`2<ooooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`006?l0002>ooooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xooo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00
^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Soooo
o`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0Xoooool00;_ooooo6Ol0000Fool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Soooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`006Ol0002Uooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2koooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`006?l0002mooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`006?l0003Dooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo000Io`000>_ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2oooo
o`00doooool00ol0003oo`00ool0000Dool001Wo00005_oo00000ol0003oooooooooo`3oooooo`;o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0oooo
ool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo
0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Ooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo
01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo0?oooooo0_ooool00=?ooooo6?l0000Gooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0oooo
ool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2
ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2oooo
o`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00
ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00oooo
ool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3oooo
o`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00i_ooool4o`000008oa0@4?oooooo
ooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00>Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00j?ooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@00Sooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003X
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo
0_ooool00>Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000008ooooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0ooooool2ooooo`00j?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@00Sooooo6?l0003oooooo`Cooooo003Xooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oeEEEOmVIVKo0000
00Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?oo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`Co000000Go410@ooooooooooooooooodA4
A002o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`06ooooo`09ogMgMolb<S;ooooooooo
oomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool0
0ol0003oooooooooo`07ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool01_oo
ool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00Kooooo00GoMgMg
oc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo1?l0003ooooooaSooooo003X
ooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00Sooooo
00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Kooooo00?oEEEEofIVI_l000001Oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooo
oolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003Uooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go
V9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00onHV9So
8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo
410@00Sooooo1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooooooo
o`3ooooooaWooooo003Xooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo
003Yooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?o
oooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05o`00
0?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOooool5o`0000Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool02OmgMgOo
<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Kooooo00?oV9RHob4Q8Oo^k^h02Oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oo
oooooooo00Kooooo1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^00Oooooo00GoMgMg
oc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooo
oolIooooo`00j?ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_oo
ool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00jOoo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooo
oa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go0000okZj^_ooooooV9RH
oa0@4004ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03
o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00iOooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003U
ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo
00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@
413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?oZJVYoa0@4?oo
ool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008
ooooo`Co0000oooooolHooooo`00ioooool00ol@413o0000okZj^P03ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo00000?oooooo9?ooool00>Sooooo00?o^[Zj
ob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooo
oa0@403oooooobCooooo003Uooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`3oooooobCooooo003Uooooo`05
ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP3oooooobCooooo003ooooooooooooo7oooool00?oooooooooooolOoooo
o`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooo
oooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo
003gooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o0000ooooool9ooooo`00moooool0
0ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`3oooooo`Oooooo003[oooo
o`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool01?l0003ooooooooooooo
ool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4
okZj^P04ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000oooooooooooooooo
o`000006ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo00?o
c<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000ooooooooool0
ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
0_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0ooooool7ooooo`00k?ooool5o`0000Kooooo00?o0000ooooooooool00_ooool01?lQ8B7o
MgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7oooo
o`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooooooo0_l00002
ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool0ooooool7
ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>_ooooo00Co410@o`00
0?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`;o00004_ooool00ol0003oooooooooo`05
ooooo`;o0000ooooool9ooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooo
oooooolOooooo`00\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .06592 L
.4 .06592 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .06592 L
.4 .06592 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .18541 L
.45 .18541 L
.45 0 L
F
0 g
.4 0 m
.4 .18541 L
.45 .18541 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .12979 L
.5 .12979 L
.5 0 L
F
0 g
.45 0 m
.45 .12979 L
.5 .12979 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .16893 L
.55 .16893 L
.55 0 L
F
0 g
.5 0 m
.5 .16893 L
.55 .16893 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .16687 L
.6 .16687 L
.6 0 L
F
0 g
.55 0 m
.55 .16687 L
.6 .16687 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .14421 L
.65 .14421 L
.65 0 L
F
0 g
.6 0 m
.6 .14421 L
.65 .14421 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .10095 L
.7 .10095 L
.7 0 L
F
0 g
.65 0 m
.65 .10095 L
.7 .10095 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .06386 L
.75 .06386 L
.75 0 L
F
0 g
.7 0 m
.7 .06386 L
.75 .06386 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .00412 L
.8 .00412 L
.8 0 L
F
0 g
.75 0 m
.75 .00412 L
.8 .00412 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
6?l0001/ooooo`;o00000_ooool2o`0001cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oooooooooo08cooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2S
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo000Io`000:Gooooo002koooooaWo00005_oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^ooo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool001So0000_Oooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`006Ol0000Fool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3B
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
5Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool001So0000e?oo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
5Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo
003oo`0001Coo`006Ol0003[ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooo
oooo01Gooooo6?l0003oooooo`Cooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool05Oooool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ooooooooool05Oooool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oooooooooo`3ooooooaWooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003ooooooooo
o`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool0
0ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool05Oooool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ooooooooool05Oooool00ol0003oooooooooo`3ooooooaWooooo003CoooooaSo0000
5oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Kooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o
0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo1?l0003ooooooaSooooo
003Xooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool0
0ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooo
oolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooo
oolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooo
oolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003Vooooo`Co000000Go410@ooooooooooooooooodA4A002o`000009oc8b<_oM
gMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00j?ooool00ol0003oooooooooo`06ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonH
V9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`07
ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool01_ooool00ol0003ooooooooo
o`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00Kooooo00GoMgMgoc8b<_ooooooooooo`00
0003ooooo`03o`000?oooooooooo00Kooooo1?l0003ooooooaSooooo003Xooooo`03o`000?oooooo
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool00000
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0
oooooolIooooo`00j?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?o
EEEEofIVI_l000001Oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003U
ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo1?l0003o
oooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003X
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`05o`000?oo
ooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooooooo
ool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@
41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08
ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00iOooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8b
omgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWo
oooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool02OmgMgOo<S8booooooooooooMgMg
oiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oV9RH
ob4Q8Oo^k^h02Oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00Kooooo1?l0
003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^00Oooooo00GoMgMgoc8b<_ooooooooooo`00
0003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool0
0omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooo
oooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00jOooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Gooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`00
0?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJ
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJ
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So
410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oa0@4?nj^[[o
ooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00Go0000oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`06oooo
o`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`Co0000oooooolH
ooooo`00ioooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo00000?oooooo9?ooool00>Sooooo00?o^[Zjob4Q8Oooool00_ooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@403oooooobCooooo
003Uooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`3oooooobCooooo003Uooooo`05ojVYZOl@413o0000oa0@
4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooobCooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoo
oooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooo
oooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003gooooo`;o00002ooo
ool00ol0003o^[Zjooooo`0<ooooo`;o0000ooooool9ooooo`00moooool00ol0003oooooooooo`0:
ooooo`;o<S8b3_ooool00ol0003oooooooooo`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o0000
ooooo`;o000000?o410@ooooooooool00oooool01?l0003oooooooooooooool2o`0000;ooooo0_l0
0003ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`00
0?oooooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`0:o`00
0?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo00?oc<c<o`000?l@41001?oo
ool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000ooooooooool0ooooool7ooooo`00k?oo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool01?oMgMgo0000
oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00
k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool01?o^k^ko
8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7oooo
o`00k?ooool5o`0000Kooooo00?o0000ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb<S8;oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003o
oooooooooooooooo000000Kooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00002?ooool0
0ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo0?oooooo1oooool00>_ooooo00Co410@o`000?l0003ooooo0_l00000
0ol@413oooooooooo`03ooooo`;o00004_ooool00ol0003oooooooooo`05ooooo`;o0000ooooool9
ooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .07828 L
.4 .07828 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .07828 L
.4 .07828 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .18541 L
.45 .18541 L
.45 0 L
F
0 g
.4 0 m
.4 .18541 L
.45 .18541 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .15863 L
.5 .15863 L
.5 0 L
F
0 g
.45 0 m
.45 .15863 L
.5 .15863 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .14627 L
.55 .14627 L
.55 0 L
F
0 g
.5 0 m
.5 .14627 L
.55 .14627 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .17717 L
.6 .17717 L
.6 0 L
F
0 g
.55 0 m
.55 .17717 L
.6 .17717 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .14215 L
.65 .14215 L
.65 0 L
F
0 g
.6 0 m
.6 .14215 L
.65 .14215 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .10713 L
.7 .10713 L
.7 0 L
F
0 g
.65 0 m
.65 .10713 L
.7 .10713 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .03296 L
.75 .03296 L
.75 0 L
F
0 g
.7 0 m
.7 .03296 L
.75 .03296 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .00206 L
.8 .00206 L
.8 0 L
F
0 g
.75 0 m
.75 .00206 L
.8 .00206 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool001So0000KOooool01?lQ8B7oMgMgogMgMolb<S8Mooooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`1Zooooo`;o00000_ooool2o`0001cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oooooooooo08cooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2S
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo000Io`000:Gooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^ooo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0;_ooooo002koooooaWo00005_oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^ooo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool001So0000_Oooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`006?l0003Dooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo000H
o`0001Ooo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wo
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000D
ool001Wo00005_ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oooooooooo`0Doooo
o`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Cooooo00?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo01Gooooo0_l0000Eooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ooooooooool05?ooool0
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool05Oooool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo
00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003ooooooooo
o`0DoooooaWo0000joooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo
6?l0000Gooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00i_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?oo
ool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool4o`000?oooooo
6?ooool00>Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08
ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Kooooo1?l000001Ol@413oooooooooooooooooA4A400;o000000Wo
<S8bomgMgOooooooooooonk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Xooooo`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9So
oooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooo
oooo00Oooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`06ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool01OmgMgOo<S8boooooooo
oooo000000?ooooo00?o0000ooooooooool01_ooool4o`000?oooooo6?ooool00>Sooooo00?o0000
ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooooooooooooooo
o`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_oo
ool00omEEEGoIVIVo`000005ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Gooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So8B4Qonk^
k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oiRHV?lQ8B7ok^k^00Co
oooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?ooool4
o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Sooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00Go
0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go0000okZj^_oooooo
V9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lQ8B7o
c<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`Go00001?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`09ogMgMolb<S;ooooooooo
oomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool0
0onHV9So8B4Qonk^kP09ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool01_oo
ool4o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h01oooool01OmgMgOo<S8boooooooo
oooo000000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003X
ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00Sooooo
00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo
00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000oooooooo
ool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003o
oooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003o
oooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05
oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go410@
okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00jOooool01Ol0003ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo
00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00onYZJWo410@ooooo`02ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo1?l0003o
oooooaSooooo003Wooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool00000oooooolTooooo`00j?ooool00onj^[[o8B4Qooooo`02
ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@0?oooooo
9?ooool00>Gooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?oooooo9?ooool00>Gooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^0?oooooo9?ooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooo
oooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool0
0?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?Oooooo0_l0
000;ooooo`03o`000?nj^[[ooooo00cooooo0_l0003oooooo`Wooooo003gooooo`03o`000?oooooo
oooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo0?oooooo1oooool00>_ooooo00Co410@o`00
0?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00000_oo
ool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo
00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo
00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@
4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003oooooooooo`3oooooo`Oooooo
003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`04omgM
gOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oo
oooo003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`04
onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooo
o`Oooooo003/ooooo`Go00001_ooool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b
<P_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05
o`000?ooooooooooooooool000001_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l00008
ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0003oooooooooo`3oooooo`Oooooo003/oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00joooool01?l@413o0000o`000?ooool2
o`000003oa0@4?oooooooooo00?ooooo0_l0000Booooo`03o`000?oooooooooo00Gooooo0_l0003o
ooooo`Wooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo
0000\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .10095 L
.4 .10095 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .10095 L
.4 .10095 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .16893 L
.45 .16893 L
.45 0 L
F
0 g
.4 0 m
.4 .16893 L
.45 .16893 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .15245 L
.5 .15245 L
.5 0 L
F
0 g
.45 0 m
.45 .15245 L
.5 .15245 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .16893 L
.55 .16893 L
.55 0 L
F
0 g
.5 0 m
.5 .16893 L
.55 .16893 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .19365 L
.6 .19365 L
.6 0 L
F
0 g
.55 0 m
.55 .19365 L
.6 .19365 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .11743 L
.65 .11743 L
.65 0 L
F
0 g
.6 0 m
.6 .11743 L
.65 .11743 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .08446 L
.7 .08446 L
.7 0 L
F
0 g
.65 0 m
.65 .08446 L
.7 .08446 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .02884 L
.75 .02884 L
.75 0 L
F
0 g
.7 0 m
.7 .02884 L
.75 .02884 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .01442 L
.8 .01442 L
.8 0 L
F
0 g
.75 0 m
.75 .01442 L
.8 .01442 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo000Ho`0008kooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo000Io`000:Gooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00
^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo000Ho`000;gooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0=;ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0=;ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0=;ooooo002koooooaWo00005_oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3B
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool001So0000e?ooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOoo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo000Io`0001Ko
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0E
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Y
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0>Wooooo003CoooooaSo00005ooooolHo`0001Ooo`0000?o0000ooooooooool0jOooool0
0?oooooo0oooool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0jOooool00?oooooo0oooool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0jOooool00?oooooo0oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00?oooooo0oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00?oooooo0oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool0
0?oooooo0oooool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0jOooool00?oooooo0oooool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0jOooool00?oooooo0oooool2o`0001Gooooo00?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oooooooooo01Cooooo00?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3oooo
o`03o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yoooo
o`00ooooool3ooooo`03o`000?oooooooooo01Cooooo6Ol0003[ooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003V
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08
ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`Co0000oooooolHooooo`00j?oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@
00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000
ooooooooool0oooooolIooooo`00i_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_oo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_oo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_oo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00i_ooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000002Olb<S;ogMgMoooo
ooooooook^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>So
oooo00?o0000ooooooooool01_ooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMg
M`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01oooool0
1?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooo
oolIooooo`00j?ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000ooo
ool00ol0003oooooooooo`06ooooo`Co0000oooooolHooooo`00j?ooool00ol0003oooooooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000Sooooo
00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oeEEEOmV
IVKo000000Gooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000
oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000
oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOooool5
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08oooo
o`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`Co0000oooooolH
ooooo`00ioooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool0
0omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00jOooool01Ol0003ooooooooo
oooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Ko
oooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[ZjoooooonHV9So410@00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool0
0ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Gooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
0_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00
iOooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9So
oooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oiRHV?lQ8B7o
k^k^00Wooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`06ooooo`Co0000oooo
oolHooooo`00ioooool00onHV9So8B4Qonk^kP07ooooo`05ogMgMolb<S;oooooooooool000000ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?oMgMg
ofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooooooooooooooo
o`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooo
ooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWo
oooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0
003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol@413o^[Zjoooooomg
MgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`05o`000?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01_ooool00ol0
003oooooooooo`3ooooooaWooooo003Xooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool4o`000?oooooo6?ooool0
0>Oooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`00003oooooobCooooo003Xooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@
oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100oooooolTooooo`00iOoo
ool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0oooooolTooooo`00iOooool01OnYZJWo410@o`000?l@413oZJVY
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0oooo
oolTooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00
oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooo
oaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00moooool2o`0000_ooooo00?o
0000okZj^_ooool03?ooool2o`000?oooooo2Oooool00?Oooooo00?o0000ooooooooool02_ooool2
oc8b<Pkooooo00?o0000ooooooooool0ooooool7ooooo`00joooool01?l@413o0000o`000?ooool2
o`000003oa0@4?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000ooo
ool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X01?ooool00ol0003ooooo
ooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool02_l0003ooooo
ooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o410@00Cooooo00Go
410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00CogMgMo`000?l@413o
c<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@
413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>co
oooo1Ol00006ooooo`03o`000?oooooooooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000oooooooo
ooooooooo`000006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000Sooooo00?o410@
o`000?l000000ol00005ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@
ooooooooool00oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`000?oooooo2Oooool0
0?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00001\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .08446 L
.4 .08446 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .08446 L
.4 .08446 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .17511 L
.45 .17511 L
.45 0 L
F
0 g
.4 0 m
.4 .17511 L
.45 .17511 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .15657 L
.5 .15657 L
.5 0 L
F
0 g
.45 0 m
.45 .15657 L
.5 .15657 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .19983 L
.55 .19983 L
.55 0 L
F
0 g
.5 0 m
.5 .19983 L
.55 .19983 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .16481 L
.6 .16481 L
.6 0 L
F
0 g
.55 0 m
.55 .16481 L
.6 .16481 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .10919 L
.65 .10919 L
.65 0 L
F
0 g
.6 0 m
.6 .10919 L
.65 .10919 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .07004 L
.7 .07004 L
.7 0 L
F
0 g
.65 0 m
.65 .07004 L
.7 .07004 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .0515 L
.75 .0515 L
.75 0 L
F
0 g
.7 0 m
.7 .0515 L
.75 .0515 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .01854 L
.8 .01854 L
.8 0 L
F
0 g
.75 0 m
.75 .01854 L
.8 .01854 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo000Ho`0008kooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo000Io`000:Gooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^ooo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo000Ho`000;gooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0=;ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0=;ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0=;ooooo002koooooaWo00005_oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_oo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool001So0000e?ooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yoooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Y
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo000Io`0001Koo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo0000
5?oo000Io`000>_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Ooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo
01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo0?oooooo0_ooool00=?ooooo6?l0000Gooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0oooo
ool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2
ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2oooo
o`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00
ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00oooo
ool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00i_ooool4
o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02?oooolHo`000?oooooo1?ooool00>Sooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000008ooooo`Co0000oooooolHooooo`00j?ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000So
oooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolI
ooooo`00i_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000
oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool4
o`000005oa0@4?oooooooooooooooom4A4@00_l000002Olb<S;ogMgMooooooooooook^k^oc8b<_l0
003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000oooooooo
ool01_ooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01oooool01?l0003oooooooooool@
4103ooooo`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool0
0ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003ooooooooo
o`06ooooo`Co0000oooooolHooooo`00j?ooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
oooooolIooooo`00j?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go
410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oeEEEOmVIVKo000000Gooooo1?l0
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOooool5o`0000?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`Co0000oooooolHooooo`00ioooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00omgMgOoIVIVooooo`02
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo
00?o0000ooooooooool0oooooolIooooo`00jOooool01Ol0003ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooolIooooo`00iOooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3o
oooooaWooooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Gooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So8B4Q
onk^k_ooooooA4A400Oooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL02?oo
ool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oiRHV?lQ8B7ok^k^00Wooooo00Co0000
oooooooooooo410@0oooool00ol@413oooooooooo`06ooooo`Co0000oooooolHooooo`00ioooool0
0onHV9So8B4Qonk^kP07ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?oMgMgofIVI_ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Wooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo
003Uooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`04ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o<S8bolc<c003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o
0000ooooooooool0oooooolIooooo`00iOooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Yooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@00?ooooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooo
oaWooooo003Xooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000002?ooool4o`000?oooooo6?ooool00>Oooooo00?o410@o`00
0?nj^[X00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
003oooooobCooooo003Xooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100oooooolTooooo`00iOooool01Ol@413oV9RHoooo
oonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL0oooooolTooooo`00iOooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0oooooolTooooo`00oooooooo
oooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo
003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooo
oooo7oooool00?oooooooooooolOooooo`00moooool2o`0000_ooooo00?o0000okZj^_ooool03?oo
ool2o`000?oooooo2Oooool00?Oooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000
ooooooooool0ooooool7ooooo`00joooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooo
oooo00?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000oooool00on7QhOo0000okZj
^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X01?ooool00ol0003oooooooooo`3oooooo`Oooooo
003/ooooo`05o`000?ooooooooooooooool000001_ooool02_l0003oooooooooooooooook^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMg
oa0@4004ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo00;ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo1Ol00006ooooo`03
o`000?oooooooooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006oooo
o`04o`000?ooooooooooooooo`;o00000_ooool2o`0000Sooooo00?o410@o`000?l000000ol00005
ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3o
ooooo`Oooooo003[ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool2
o`0001;ooooo00?o0000ooooooooool01Oooool2o`000?oooooo2Oooool00?oooooooooooolOoooo
o`00oooooooooooooaoooooo003ooooooooooooo7oooool00001\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .07828 L
.4 .07828 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .07828 L
.4 .07828 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .19571 L
.45 .19571 L
.45 0 L
F
0 g
.4 0 m
.4 .19571 L
.45 .19571 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .12567 L
.5 .12567 L
.5 0 L
F
0 g
.45 0 m
.45 .12567 L
.5 .12567 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .17305 L
.55 .17305 L
.55 0 L
F
0 g
.5 0 m
.5 .17305 L
.55 .17305 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .15245 L
.6 .15245 L
.6 0 L
F
0 g
.55 0 m
.55 .15245 L
.6 .15245 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .10919 L
.65 .10919 L
.65 0 L
F
0 g
.6 0 m
.6 .10919 L
.65 .10919 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .12361 L
.7 .12361 L
.7 0 L
F
0 g
.65 0 m
.65 .12361 L
.7 .12361 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .05356 L
.75 .05356 L
.75 0 L
F
0 g
.7 0 m
.7 .05356 L
.75 .05356 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .01854 L
.8 .01854 L
.8 0 L
F
0 g
.75 0 m
.75 .01854 L
.8 .01854 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo000Ho`0008kooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`006Ol0002Uoooo
o`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2k
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo6Ol0000Fool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2k
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool001So00005_oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o
0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2k
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo01Cooooo6?l0002mooooo`00doooool00ol0003oo`00ool0000Dool001Wo00005_oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Go
oooo00?o0000ool00?oo00005?oo000Io`000>_ooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo
0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3o
ooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0E
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool05OoooolHo`000?oooooo1?ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`0Eooooo`;o0000oooooolJooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0oooooolIooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oooooooooo01Gooooo00?o0000ooooooooool0oooooolIooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ooooooooool0oooooolIoooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0oooooolIooooo`00dooooolHo`0001Oooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo1?l000002?l@413oooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolI
ooooo`00j?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool0
1Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000Sooooo1?l0003ooooooaSooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Voooo
o`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`Co000000Go410@
ooooooooooooooooodA4A002o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`06ooooo`09
ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooo
oolIooooo`00j?ooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooooa0@40?ooooo00?o
410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooo
oooo00Kooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo1?l0
003ooooooaSooooo003Xooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c002ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo
003Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Kooooo00?oEEEEofIVI_l000001Oooool4o`0000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oo
oooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00i_ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@00Sooooo1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?oo
ool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ogMgMomVIVKooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Yooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWo
oooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o
0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o
0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o
0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOoo
ool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^k^h02Oooool01?l0003oooooooooool@
4103ooooo`03oa0@4?oooooooooo00Kooooo1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7o
k^k^00Oooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0oooooolIooooo`00j?ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
oooooolIooooo`00jOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go
410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go
0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c004ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`00
0?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`00
0?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003ooooooooo
o`3ooooooaWooooo003Uooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Wooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>So
oooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000008ooooo`Co0000oooooolHooooo`00ioooool00ol@413o0000okZj^P03oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo00000?oooooo9?oo
ool00>Sooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@403oooooobCooooo003Uooooo`05oa0@4?nHV9SooooookZj^_l00000
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`3ooooo
obCooooo003Uooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP3oooooobCooooo003ooooooooooooo7oooool0
0?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooo
oolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00
oooooooooooooaoooooo003gooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o0000oooo
ool9ooooo`00moooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`3o
ooooo`Oooooo003[ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool0
1?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00Go
V9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go
0000ooooooooooooooooo`000006ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o
0000omgMg@?ooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo
00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool5o`0000Kooooo00?o0000oooooooo
ool00_ooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooo
oooooooooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Gooooo00?o0000
ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool0
0>_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`;o00004_ooool0
0ol0003oooooooooo`05ooooo`;o0000ooooool9ooooo`00oooooooooooooaoooooo003ooooooooo
oooo7oooool00?oooooooooooolOooooo`00\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .04532 L
.4 .04532 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .04532 L
.4 .04532 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .18129 L
.45 .18129 L
.45 0 L
F
0 g
.4 0 m
.4 .18129 L
.45 .18129 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .15451 L
.5 .15451 L
.5 0 L
F
0 g
.45 0 m
.45 .15451 L
.5 .15451 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .17305 L
.55 .17305 L
.55 0 L
F
0 g
.5 0 m
.5 .17305 L
.55 .17305 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .15863 L
.6 .15863 L
.6 0 L
F
0 g
.55 0 m
.55 .15863 L
.6 .15863 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .11537 L
.65 .11537 L
.65 0 L
F
0 g
.6 0 m
.6 .11537 L
.65 .11537 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .09271 L
.7 .09271 L
.7 0 L
F
0 g
.65 0 m
.65 .09271 L
.7 .09271 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .09271 L
.75 .09271 L
.75 0 L
F
0 g
.7 0 m
.7 .09271 L
.75 .09271 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .01648 L
.8 .01648 L
.8 0 L
F
0 g
.75 0 m
.75 .01648 L
.8 .01648 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
000Ho`0008kooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Soooo
o`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002koooooaWo00005_oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`00<?l0002Uooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo000Ho`000=Cooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yoooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00
ool0000Dool001Wo00005_oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`006Ol0003[
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oo
oooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Go
oooo6?l0003oooooo`Cooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
5Oooool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ooooooooool05Oooool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oooooooooo`3ooooooaWooooo003Coooo
oaSo00005oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00i_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xoooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo
ooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
2?ooool4o`000?oooooo6?ooool00>Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>So
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oEEEEofIV
I_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo1?l000001Ol@413ooooooooooooo
ooooA4A400;o000000Wo<S8bomgMgOooooooooooonk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0
003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_oo
ooooooooogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003X
ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo410@0oooool00ol@413ooooooooo
o`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool0
1OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool01_ooool4o`000?oooooo6?oo
ool00>Sooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go
0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0
oooooolIooooo`00i_ooool00omEEEGoIVIVo`000005ooooo`Co00000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Gooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOoo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03
oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooo
ooooool@41002?ooool4o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Sooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Wooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
41000oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo
00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnH
V9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[o
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[o
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[o
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`Go00001?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03
o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`09
ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooo
oolIooooo`00i_ooool00onHV9So8B4Qonk^kP09ooooo`04o`000?oooooooooooa0@40?ooooo00?o
410@ooooooooool01_ooool4o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h01oooool0
1OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`3ooooooaWooooo003Xooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c002ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo
003Yooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[Zjoooo
oonHV9So410@00Cooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00So
oooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lQ8B7oc<c<00Co
oooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003Uooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Gooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00
jOooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003oooo
o`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00onYZJWo
410@ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000Sooooo1?l0003ooooooaSooooo003Wooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000oooooolTooooo`00j?ooool0
0onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooo
oooooooo410@0?oooooo9?ooool00>Gooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?oooooo9?ooool00>Go
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^0?oooooo9?ooool00?oooooooooooolOooooo`00oooooooooooo
oaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo
7oooool00?Oooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo0_l0003oooooo`Wooooo003g
ooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo0?oooooo1oooool0
0>_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`04o`000?oooooo
ooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`00
0?m4A4Co^[Zj00Cooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooo
oooooooo000000Kooooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0ooo
ool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003ooooo
ooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`02ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`3oooooo`Oooooo003/ooooo`Go00001_ooool00ol0003oooooooooo`02ooooo`04
ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooo
o`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooooooool2
o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0003oooooooooo`3o
ooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00joooool01?l@
413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo0_l0000Booooo`03o`000?oooooo
oooo00Gooooo0_l0003oooooo`Wooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00
oooooooooooooaoooooo0000\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .06386 L
.4 .06386 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .06386 L
.4 .06386 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .18129 L
.45 .18129 L
.45 0 L
F
0 g
.4 0 m
.4 .18129 L
.45 .18129 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .12567 L
.5 .12567 L
.5 0 L
F
0 g
.45 0 m
.45 .12567 L
.5 .12567 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .16069 L
.55 .16069 L
.55 0 L
F
0 g
.5 0 m
.5 .16069 L
.55 .16069 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .15451 L
.6 .15451 L
.6 0 L
F
0 g
.55 0 m
.55 .15451 L
.6 .15451 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .13803 L
.65 .13803 L
.65 0 L
F
0 g
.6 0 m
.6 .13803 L
.65 .13803 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .11949 L
.7 .11949 L
.7 0 L
F
0 g
.65 0 m
.65 .11949 L
.7 .11949 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .07416 L
.75 .07416 L
.75 0 L
F
0 g
.7 0 m
.7 .07416 L
.75 .07416 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .01236 L
.8 .01236 L
.8 0 L
F
0 g
.75 0 m
.75 .01236 L
.8 .01236 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo000Ho`0008kooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool0
0;_ooooo6Ol0000Fool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`006Ol0002Uoooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2k
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2koooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`006?l0002mooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`006Ol0000Fool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0E
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`006?l0003Doooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooo
oooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo000Io`000>_ooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo6?l0003ooooo
o`Cooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003o
ooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
5Oooool2o`000?oooooo6_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oo
oooo6Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo6?l0000Goooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003Vooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>So
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`Co0000
oooooolHooooo`00j?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00
j?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00omEEEGoIVIVo`000004oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00i_ooool4o`000005oa0@4?oooooooooooooooom4A4@00_l0
00002Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool02OmgMgOo<S8booooooooooooMgMg
oiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000
ooooooooool01oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00Kooooo00?o
0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;o
ooooooooool000000oooool00ol0003oooooooooo`06ooooo`Co0000oooooolHooooo`00j?ooool0
0ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooo
oooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo
003Vooooo`03oeEEEOmVIVKo000000Gooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_oo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00iOooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^
k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008
ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooo
oolIooooo`00j?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00jOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[Zj
oooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo1Ol00004ooooo`05odA4A?l0
003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooooooo
ool0oooooolIooooo`00iOooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00WoMgMgoc8b<_oo
ooooooooogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003V
ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00Co0000oooooooooooo410@0oooool00ol@413ooooooooo
o`06ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP07ooooo`05ogMgMolb<S;o
ooooooooool000000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Sooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go
0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@4100
1?ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2
o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2
o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Go
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool0
1Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`05o`00
0?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooo
ooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ojVYZOl@413ooooo00;o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool4
o`000?oooooo6?ooool00>Oooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`00003oooooobCooooo003Xooooo`03okZj^_lQ8B7o
oooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100
oooooolTooooo`00iOooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0oooooolTooooo`00iOooool01OnYZJWo
410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h0oooooolTooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oo
oooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolO
ooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00mooo
ool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`000?oooooo2Oooool00?Oooooo00?o0000
ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool0ooooool7ooooo`00joooool01?l@
413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l0
0002ooooo`;o00000oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X0
1?ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool00000
1_ooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0
003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo0?oooooo
1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo
00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oo
oooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;o
oooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
0?oooooo1oooool00>cooooo1Ol00006ooooo`03o`000?oooooooooo00;ooooo00Co8B4QogMgMomg
MgOo<S8b2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>co
oooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2
o`0000Sooooo00?o410@o`000?l000000ol00005ooooo`03o`000?oooooooooo0?oooooo1oooool0
0>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o0000
ooooo`;o000000?o410@ooooooooool00oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2
o`000?oooooo2Oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo
7oooool00001\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .0721 L
.4 .0721 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .0721 L
.4 .0721 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .15245 L
.45 .15245 L
.45 0 L
F
0 g
.4 0 m
.4 .15245 L
.45 .15245 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .15245 L
.5 .15245 L
.5 0 L
F
0 g
.45 0 m
.45 .15245 L
.5 .15245 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .16893 L
.55 .16893 L
.55 0 L
F
0 g
.5 0 m
.5 .16893 L
.55 .16893 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .17511 L
.6 .17511 L
.6 0 L
F
0 g
.55 0 m
.55 .17511 L
.6 .17511 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .14833 L
.65 .14833 L
.65 0 L
F
0 g
.6 0 m
.6 .14833 L
.65 .14833 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .09889 L
.7 .09889 L
.7 0 L
F
0 g
.65 0 m
.65 .09889 L
.7 .09889 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .05356 L
.75 .05356 L
.75 0 L
F
0 g
.7 0 m
.7 .05356 L
.75 .05356 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .00618 L
.8 .00618 L
.8 0 L
F
0 g
.75 0 m
.75 .00618 L
.8 .00618 L
.8 0 L
.75 0 L
s
1 0 0 r
.8 0 m
.8 .00206 L
.85 .00206 L
.85 0 L
F
0 g
.8 0 m
.8 .00206 L
.85 .00206 L
.85 0 L
.8 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`006Ol0001Eooooo`04ob4Q8OmgMgOoMgMgoc8b<Qgo
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo06[ooooo0_l00002ooooo`;o00007?ooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool001So0000S_ooool00;_ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Soooo
o`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2S
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo000Io`000:Gooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`2kooooo`00^ooooolIo`0001Koo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo000Ho`000;gooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool001So0000e?ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`3Yooooo`00doooool`o`0001Koo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3oooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yoooo
o`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3oooooaSo00005ooo0000
0ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oooooooooo01Cooooo00?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oooooooooo01Co
oooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`00
0?oooooooooo01Cooooo6Ol0003[ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Kooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o
0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo1?l0003ooooooaSooooo
003Xooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool0
0ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooo
oolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooo
oolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooo
oolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003Vooooo`Co000000Go410@ooooooooooooooooodA4A002o`000009oc8b<_oM
gMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00j?ooool00ol0003oooooooooo`06ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonH
V9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`07
ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool01_ooool00ol0003ooooooooo
o`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00Kooooo00GoMgMgoc8b<_ooooooooooo`00
0003ooooo`03o`000?oooooooooo00Kooooo1?l0003ooooooaSooooo003Xooooo`03o`000?oooooo
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool00000
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0
oooooolIooooo`00j?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?o
EEEEofIVI_l000001Oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003U
ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo1?l0003o
oooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003X
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`05o`000?oo
ooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooooooo
ool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@
41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08
ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00iOooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8b
omgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWo
oooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool02OmgMgOo<S8booooooooooooMgMg
oiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oV9RH
ob4Q8Oo^k^h02Oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00Kooooo1?l0
003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^00Oooooo00GoMgMgoc8b<_ooooooooooo`00
0003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool0
0omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooo
oooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00jOooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Gooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`00
0?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJ
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJ
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So
410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oa0@4?nj^[[o
ooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00Go0000oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`06oooo
o`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`Co0000oooooolH
ooooo`00ioooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo00000?oooooo9?ooool00>Sooooo00?o^[Zjob4Q8Oooool00_ooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@403oooooobCooooo
003Uooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`3oooooobCooooo003Uooooo`05ojVYZOl@413o0000oa0@
4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooobCooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoo
oooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooo
oooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003gooooo`;o00002ooo
ool00ol0003o^[Zjooooo`0<ooooo`;o0000ooooool9ooooo`00moooool00ol0003oooooooooo`0:
ooooo`;o<S8b3_ooool00ol0003oooooooooo`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o0000
ooooo`;o000000?o410@ooooooooool00oooool01?l0003oooooooooooooool2o`0000;ooooo0_l0
0003ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`00
0?oooooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`0:o`00
0?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo00?oc<c<o`000?l@41001?oo
ool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000ooooooooool0ooooool7ooooo`00k?oo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool01?oMgMgo0000
oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00
k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool01?o^k^ko
8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7oooo
o`00k?ooool5o`0000Kooooo00?o0000ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb<S8;oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003o
oooooooooooooooo000000Kooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00002?ooool0
0ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo0?oooooo1oooool00>_ooooo00Co410@o`000?l0003ooooo0_l00000
0ol@413oooooooooo`03ooooo`;o00004_ooool00ol0003oooooooooo`05ooooo`;o0000ooooool9
ooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .08446 L
.4 .08446 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .08446 L
.4 .08446 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .17099 L
.45 .17099 L
.45 0 L
F
0 g
.4 0 m
.4 .17099 L
.45 .17099 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .12979 L
.5 .12979 L
.5 0 L
F
0 g
.45 0 m
.45 .12979 L
.5 .12979 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .20807 L
.55 .20807 L
.55 0 L
F
0 g
.5 0 m
.5 .20807 L
.55 .20807 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .19571 L
.6 .19571 L
.6 0 L
F
0 g
.55 0 m
.55 .19571 L
.6 .19571 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .11125 L
.65 .11125 L
.65 0 L
F
0 g
.6 0 m
.6 .11125 L
.65 .11125 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .08858 L
.7 .08858 L
.7 0 L
F
0 g
.65 0 m
.65 .08858 L
.7 .08858 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .03708 L
.75 .03708 L
.75 0 L
F
0 g
.7 0 m
.7 .03708 L
.75 .03708 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .00412 L
.8 .00412 L
.8 0 L
F
0 g
.75 0 m
.75 .00412 L
.8 .00412 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
6?l0001/ooooo`;o00000_ooool2o`0001cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oooooooooo08cooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2S
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool001Wo0000
YOooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00
^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`2kooooo`00^ooooolIo`0001Koo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo000Ho`000;gooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Boooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool001So0000e?ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOoo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Co
o`006Ol0000Fool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eoooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yoooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooo
oooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0E
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Y
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool0
0=?ooooo6?l0000Gooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Y
ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Y
ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`00
6Ol0003[ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0oooo
ool2ooooo`00i_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo
0?oooooo0_ooool00>Sooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0ooooool2ooooo`00j?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3oooooo`;ooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00>Sooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008oooooaSo
0000ooooool4ooooo`00j?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00j?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool4o`000005oa0@4?oooooo
oooooooooom4A4@00_l000002Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^kP08oooo
o`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool02OmgMgOo
<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Sooooo00?o0000ooooooooool01oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oo
oooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`06
ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`06ooooo`Co0000oooo
oolHooooo`00j?ooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_oo
ool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00j?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooo
oa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Vooooo`03oeEEEOmVIVKo000000Gooooo1?l00003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[o
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00iOooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo
003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Ko
oooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooo
oooooooooooooa0@4008ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP03oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o
0000ooooooooool0oooooolIooooo`00j?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
oooooolIooooo`00jOooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00
iOooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uoooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oo
oooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oo
oooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oo
oooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo1Ol0
0004ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00So
oooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So8B4Qonk^k_ooooooA4A400Oo
oooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003ooooooooo
o`3ooooooaWooooo003Vooooo`03oiRHV?lQ8B7ok^k^00Wooooo00Co0000oooooooooooo410@0ooo
ool00ol@413oooooooooo`06ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP07
ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Sooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05oa0@4?oo
ooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05o`000?nj
^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`01?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooo
oa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooo
oa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooo
oolIooooo`00iOooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWo
oooo003Yooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000002?ooool4o`000?oooooo6?ooool00>Oooooo00?o410@o`000?nj^[X00oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00003oooooobCooooo003X
ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oo
ooooooooooooool@4100oooooolTooooo`00iOooool01Ol@413oV9RHoooooonj^[[o000000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0oooooolToooo
o`00iOooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0oooooolTooooo`00oooooooooooooaoooooo003ooooo
oooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7ooo
ool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooo
oooooolOooooo`00moooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`000?oooooo2Ooo
ool00?Oooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool0ooooool7
ooooo`00joooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo00Co0000
oooooooooooooooo0_l00002ooooo`;o00000oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0
003o0000odA4A?nj^[X01?ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?oo
ooooooooooooool000001_ooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oM
gMd3ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`00
0?oooooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo00;ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo0?oooooo1oooool00>cooooo1Ol00006ooooo`03o`000?oooooooooo00;o
oooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooooooo
ooooo`;o00000_ooool2o`0000Sooooo00?o410@o`000?l000000ol00005ooooo`03o`000?oooooo
oooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003[oooo
o`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool2o`0001;ooooo00?o0000
ooooooooool01Oooool2o`000?oooooo2Oooool00?oooooooooooolOooooo`00oooooooooooooaoo
oooo003ooooooooooooo7oooool00001\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .10507 L
.4 .10507 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .10507 L
.4 .10507 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .21631 L
.45 .21631 L
.45 0 L
F
0 g
.4 0 m
.4 .21631 L
.45 .21631 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .14833 L
.5 .14833 L
.5 0 L
F
0 g
.45 0 m
.45 .14833 L
.5 .14833 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .16687 L
.55 .16687 L
.55 0 L
F
0 g
.5 0 m
.5 .16687 L
.55 .16687 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .14627 L
.6 .14627 L
.6 0 L
F
0 g
.55 0 m
.55 .14627 L
.6 .14627 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .10919 L
.65 .10919 L
.65 0 L
F
0 g
.6 0 m
.6 .10919 L
.65 .10919 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .09064 L
.7 .09064 L
.7 0 L
F
0 g
.65 0 m
.65 .09064 L
.7 .09064 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .03502 L
.75 .03502 L
.75 0 L
F
0 g
.7 0 m
.7 .03502 L
.75 .03502 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .01236 L
.8 .01236 L
.8 0 L
F
0 g
.75 0 m
.75 .01236 L
.8 .01236 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo000Ho`0008kooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`006Ol0002Uooooo`00
^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2koooo
o`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2k
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool001So0000_Oooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00;_ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0d_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
d_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0d_ooool00;_ooooo6Ol0000Fool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`006?l0003Dooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wo
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo000I
o`0001Koo`006Ol0003[ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo
01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`0EoooooaSo0000ooooool4ooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oooooooooo01Gooooo00?o0000ooooooooool0oooooolIooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ooooooooool0oooooolIoooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0oooooolIooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo
00?o0000ooooooooool0oooooolIooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0oooooolIooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oooooooooo01Gooooo00?o0000ooooooooool0oooooolIooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ooooooooool0oooooolIoooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0oooooolIooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo
0_l0003ooooooa[ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool05Oooool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool05Oooool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oooooooooo`3ooooooaWo
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Coo`0000So0000
ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08oooo
o`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005?oo00002?l0003o
oooooooooomgMgOoV9RHoooooonHV9SoMgMg0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo
00?o0000ooooooooool0oooooolIooooo`00doooool00ol0003oo`00ool0000Dool00004o`000?oo
oooooooooa0@40?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Ko
oooo00?o0000ooooooooool0oooooolIooooo`00doooool00ol0003oo`00ool0000Dool00004o`00
0?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
00Kooooo1?l0003ooooooaSooooo003Cooooo`03o`000?oo003oo`0001Coo`0000Co0000oooooooo
oooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Coo`0000Co0000oooo
oooooooo410@0oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01_oo
ool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Coo`0000So0000
ooooooooooooMgMgoiRHV?ooooooV9RHogMgM`?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08oooo
o`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo6?l00002ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00i_ooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000002Olb<S;ogMgMoooooooo
ooook^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo
00?o0000ooooooooool01_ooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`08
ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01oooool01?l0
003oooooooooool@4103ooooo`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolI
ooooo`00j?ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool0
0ol0003oooooooooo`06ooooo`Co0000oooooolHooooo`00j?ooool00ol0003oooooooooo`03oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o
0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oeEEEOmVIVKo
000000Gooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooo
oolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooo
oolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOooool5o`00
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?oo
ool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03
o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`Co0000oooooolHoooo
o`00ioooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00jOooool01Ol0003ooooooooooooo
oooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Kooooo
00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0
003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Gooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOoo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9Sooooo
oiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oiRHV?lQ8B7ok^k^
00Wooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`06ooooo`Co0000oooooolH
ooooo`00ioooool00onHV9So8B4Qonk^kP07ooooo`05ogMgMolb<S;oooooooooool000000oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?oMgMgofIV
I_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00
0008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003ooooooooo
o`3ooooooaWooooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooooooo
o`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo
003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o
<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol@413o^[ZjoooooomgMgOo
<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`05o`000?ooooooooooooooool@4100
0oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01_ooool00ol0003o
ooooooooo`3ooooooaWooooo003Xooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool4o`000?oooooo6?ooool00>Oo
oooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`00003oooooobCooooo003Xooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooo
oooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100oooooolTooooo`00iOooool0
1Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0oooooolTooooo`00iOooool01OnYZJWo410@o`000?l@413oZJVY00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0oooooolT
ooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooo
oooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoo
oooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00moooool2o`0000_ooooo00?o0000
okZj^_ooool03?ooool2o`000?oooooo2Oooool00?Oooooo00?o0000ooooooooool02_ooool2oc8b
<Pkooooo00?o0000ooooooooool0ooooool7ooooo`00joooool01?l@413o0000o`000?ooool2o`00
0003oa0@4?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000oooool0
0on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X01?ooool00ol0003ooooooooo
o`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool02_l0003ooooooooo
ooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o410@00Cooooo00Go410@
okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00CogMgMo`000?l@413oc<c<
2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@413o
k^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo
1Ol00006ooooo`03o`000?oooooooooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000oooooooooooo
ooooo`000006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000Sooooo00?o410@o`00
0?l000000ol00005ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@oooo
ooooool00oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`000?oooooo2Oooool00?oo
oooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00001\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .07416 L
.4 .07416 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .07416 L
.4 .07416 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .19983 L
.45 .19983 L
.45 0 L
F
0 g
.4 0 m
.4 .19983 L
.45 .19983 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .16275 L
.5 .16275 L
.5 0 L
F
0 g
.45 0 m
.45 .16275 L
.5 .16275 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .17511 L
.55 .17511 L
.55 0 L
F
0 g
.5 0 m
.5 .17511 L
.55 .17511 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .16481 L
.6 .16481 L
.6 0 L
F
0 g
.55 0 m
.55 .16481 L
.6 .16481 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .10095 L
.65 .10095 L
.65 0 L
F
0 g
.6 0 m
.6 .10095 L
.65 .10095 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .09064 L
.7 .09064 L
.7 0 L
F
0 g
.65 0 m
.65 .09064 L
.7 .09064 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .03914 L
.75 .03914 L
.75 0 L
F
0 g
.7 0 m
.7 .03914 L
.75 .03914 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .02266 L
.8 .02266 L
.8 0 L
F
0 g
.75 0 m
.75 .02266 L
.8 .02266 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo000Ho`0008kooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Soooo
o`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`006Ol0002Uooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0;_ooooo002koooooaWo00005_oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^ooo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool001So0000_Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`006?l0003Dooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOoo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`006Ol0000Fool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`006Ol0003[ooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05OoooolHo`000?oooooo
1?ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`;o0000oooooolJooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ooooooooool0oooo
oolIooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000
ooooooooool0oooooolIooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo
01Gooooo00?o0000ooooooooool0oooooolIooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo01Gooooo00?o0000ooooooooool0oooooolIooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ooooooooool0oooooolIooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ooooooooool0oooo
oolIooooo`00dooooolHo`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0
003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool4o`000?oooooo6?ooool0
0>Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooo
oa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03
o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooo
oa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooo
oa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooo
oa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Kooooo1?l000001Ol@413oooooooooooooooooA4A400;o000000Wo<S8bomgM
gOooooooooooonk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo
003Xooooo`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRH
V?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00Oo
oooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool01OmgMgOo<S8boooooooooooo0000
00?ooooo00?o0000ooooooooool01_ooool4o`000?oooooo6?ooool00>Sooooo00?o0000oooooooo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`000008
ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`3o
oooooaWooooo003Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00omE
EEGoIVIVo`000005ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2
o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2
o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Go
oooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go
410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?ooool4o`000?oo
oooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>So
oooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00Go0000oooo
oooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413ooooooooo
o`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00So
oooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lQ8B7oc<c<00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003Uooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;o
gMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`09ogMgMolb<S;ooooooooooomgMgOo
V9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00onHV9So
8B4Qonk^kP09ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool01_ooool4o`00
0?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h01oooool01OmgMgOo<S8boooooooooooo0000
00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03
ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?oooooooooo
ooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000
ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000
ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooo
oolIooooo`00iOooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[o
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[o
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@
413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go410@okZj^_oo
ooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00jOooool01Ol0003ooooooooooooo
oooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Kooooo
00?o0000ooooooooool0oooooolIooooo`00j?ooool00onYZJWo410@ooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo1?l0003ooooooaSo
oooo003Wooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool00000oooooolTooooo`00j?ooool00onj^[[o8B4Qooooo`02ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@0?oooooo9?ooool0
0>Gooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg0?oooooo9?ooool00>Gooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
0?oooooo9?ooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7ooo
ool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooo
oooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?Oooooo0_l0000;oooo
o`03o`000?nj^[[ooooo00cooooo0_l0003oooooo`Wooooo003gooooo`03o`000?oooooooooo00[o
oooo0_lb<S8>ooooo`03o`000?oooooooooo0?oooooo1oooool00>_ooooo00Co410@o`000?l0003o
oooo0_l000000ol@413oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`00
00?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000
ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00[o0000
ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@4004oooo
o`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003oooooooooo`3oooooo`Oooooo003/oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`04omgMgOl0003o
410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003/
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`04onk^k_lQ
8B7o410@onk^kP_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo
003/ooooo`Go00001_ooool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?oo
ooooooooooooool000001_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l00008ooooo`03
oa0@4?l0003o000000?o00001Oooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0ooooool7ooooo`00joooool01?l@413o0000o`000?ooool2o`000003
oa0@4?oooooooooo00?ooooo0_l0000Booooo`03o`000?oooooooooo00Gooooo0_l0003oooooo`Wo
oooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo0000\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .07004 L
.4 .07004 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .07004 L
.4 .07004 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .16069 L
.45 .16069 L
.45 0 L
F
0 g
.4 0 m
.4 .16069 L
.45 .16069 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .12979 L
.5 .12979 L
.5 0 L
F
0 g
.45 0 m
.45 .12979 L
.5 .12979 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .19365 L
.55 .19365 L
.55 0 L
F
0 g
.5 0 m
.5 .19365 L
.55 .19365 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .16481 L
.6 .16481 L
.6 0 L
F
0 g
.55 0 m
.55 .16481 L
.6 .16481 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .12361 L
.65 .12361 L
.65 0 L
F
0 g
.6 0 m
.6 .12361 L
.65 .12361 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .11125 L
.7 .11125 L
.7 0 L
F
0 g
.65 0 m
.65 .11125 L
.7 .11125 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .05562 L
.75 .05562 L
.75 0 L
F
0 g
.7 0 m
.7 .05562 L
.75 .05562 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .0206 L
.8 .0206 L
.8 0 L
F
0 g
.75 0 m
.75 .0206 L
.8 .0206 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo000Ho`00
08kooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xooo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`006Ol0002Uooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^ooo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`2kooooo`00^ooooolIo`0001Koo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo000Ho`000;gooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo000Ho`000=Cooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool001Wo00005_oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Ooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOoo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo6?l0000Goooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yoooo
o`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`006Ol0003[ooooo`00oooo
ool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3oooo
o`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0ooooool2ooooo`00ooooool3oooooaSo0000ooooool4ooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003V
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08
ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`Co0000oooooolHooooo`00j?oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@
00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000
ooooooooool0oooooolIooooo`00i_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_oo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_oo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_oo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00i_ooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000002Olb<S;ogMgMoooo
ooooooook^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>So
oooo00?o0000ooooooooool01_ooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMg
M`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01oooool0
1?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooo
oolIooooo`00j?ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000ooo
ool00ol0003oooooooooo`06ooooo`Co0000oooooolHooooo`00j?ooool00ol0003oooooooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000Sooooo
00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oeEEEOmV
IVKo000000Gooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000
oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000
oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOooool5
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08oooo
o`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`Co0000oooooolH
ooooo`00ioooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool0
0omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00jOooool01Ol0003ooooooooo
oooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Ko
oooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[ZjoooooonHV9So410@00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool0
0ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Gooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
0_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00
iOooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9So
oooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oiRHV?lQ8B7o
k^k^00Wooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`06ooooo`Co0000oooo
oolHooooo`00ioooool00onHV9So8B4Qonk^kP07ooooo`05ogMgMolb<S;oooooooooool000000ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?oMgMg
ofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooooooooooooooo
o`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooo
ooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWo
oooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0
003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol@413o^[Zjoooooomg
MgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`05o`000?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01_ooool00ol0
003oooooooooo`3ooooooaWooooo003Xooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool4o`000?oooooo6?ooool0
0>Oooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`00003oooooobCooooo003Xooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@
oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100oooooolTooooo`00iOoo
ool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0oooooolTooooo`00iOooool01OnYZJWo410@o`000?l@413oZJVY
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0oooo
oolTooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00
oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooo
oaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00moooool2o`0000_ooooo00?o
0000okZj^_ooool03?ooool2o`000?oooooo2Oooool00?Oooooo00?o0000ooooooooool02_ooool2
oc8b<Pkooooo00?o0000ooooooooool0ooooool7ooooo`00joooool01?l@413o0000o`000?ooool2
o`000003oa0@4?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000ooo
ool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X01?ooool00ol0003ooooo
ooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool02_l0003ooooo
ooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o410@00Cooooo00Go
410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00CogMgMo`000?l@413o
c<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@
413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>co
oooo1Ol00006ooooo`03o`000?oooooooooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000oooooooo
ooooooooo`000006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000Sooooo00?o410@
o`000?l000000ol00005ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@
ooooooooool00oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`000?oooooo2Oooool0
0?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00001\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .05768 L
.4 .05768 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .05768 L
.4 .05768 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .16069 L
.45 .16069 L
.45 0 L
F
0 g
.4 0 m
.4 .16069 L
.45 .16069 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .11125 L
.5 .11125 L
.5 0 L
F
0 g
.45 0 m
.45 .11125 L
.5 .11125 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .19777 L
.55 .19777 L
.55 0 L
F
0 g
.5 0 m
.5 .19777 L
.55 .19777 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .15451 L
.6 .15451 L
.6 0 L
F
0 g
.55 0 m
.55 .15451 L
.6 .15451 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .14833 L
.65 .14833 L
.65 0 L
F
0 g
.6 0 m
.6 .14833 L
.65 .14833 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .08858 L
.7 .08858 L
.7 0 L
F
0 g
.65 0 m
.65 .08858 L
.7 .08858 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .09683 L
.75 .09683 L
.75 0 L
F
0 g
.7 0 m
.7 .09683 L
.75 .09683 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .01442 L
.8 .01442 L
.8 0 L
F
0 g
.75 0 m
.75 .01442 L
.8 .01442 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo000Ho`0008kooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xooo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00
^ooooolIo`0001Koo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2S
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`006?l0000Gool00003o`000?oooooooooo0:?o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo01Cooooo00?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`0DoooooaWo0000YOooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_oo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo000Io`0001Koo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000Co0000oooooooooooooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3B
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
5Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eoooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool001So0000
e?ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool001Wo0000joooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo
003CoooooaSo00005oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_oo
ool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool0
0?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oo
oooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oooooo
0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oooooo0ooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oooooo0oooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oooooo0oooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oooooo0oooool00ol0003o
o`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000D
ool00003o`000?oooooooooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo
0?oooooo0_ooool00?oooooo0ooooolHo`000?oooooo1?ooool00>Kooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o
0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0
oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
0oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00
j?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000Sooooo1?l0003ooooooaSooooo003Xooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool0
0ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003ooooooooo
o`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo
003Vooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooo
oa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`Co0000
00Go410@ooooooooooooooooodA4A002o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb
<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`06
ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000oooooooo
ool0oooooolIooooo`00j?ooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooooa0@40?o
oooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`00
0?oooooooooo00Kooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Ko
oooo1?l0003ooooooaSooooo003Xooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c002ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413o
oooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08oooo
o`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oEEEEofIVI_l000001Oooool4o`0000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2
o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooo
oolIooooo`00i_ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@00Sooooo1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ogMgMomVIVKooooo00;ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0
003oooooooooo`3ooooooaWooooo003Yooooo`05o`000?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3o
oooooaWooooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00iOooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@01oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03
o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^k^h02Oooool01?l0003ooooo
ooooool@4103ooooo`03oa0@4?oooooooooo00Kooooo1?l0003ooooooaSooooo003Wooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00omgMgOoIVIVooooo`03ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooo
ooooool0oooooolIooooo`00jOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Go
oooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c004ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Uooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00>Wooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo
ooooooooool@41000oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Sooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000008ooooo`Co0000oooooolHooooo`00ioooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo00000?oo
oooo9?ooool00>Sooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@403oooooobCooooo003Uooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`3oooooobCooooo003Uooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP3oooooobCooooo003ooooooooooooo
7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oo
oooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolO
ooooo`00oooooooooooooaoooooo003gooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o
0000ooooool9ooooo`00moooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003ooooo
ooooo`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool0
0oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Co
oooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo0?oooooo1oooool00>co
oooo00Go0000ooooooooooooooooo`000006ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7
Qonj^[[o0000omgMg@?ooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@
00Cooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool5o`0000Kooooo00?o0000
ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co
0000oooooooooooooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Gooooo
00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo
1oooool00>_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`;o0000
4_ooool00ol0003oooooooooo`05ooooo`;o0000ooooool9ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .07622 L
.4 .07622 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .07622 L
.4 .07622 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .15039 L
.45 .15039 L
.45 0 L
F
0 g
.4 0 m
.4 .15039 L
.45 .15039 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .14009 L
.5 .14009 L
.5 0 L
F
0 g
.45 0 m
.45 .14009 L
.5 .14009 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .17511 L
.55 .17511 L
.55 0 L
F
0 g
.5 0 m
.5 .17511 L
.55 .17511 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .15451 L
.6 .15451 L
.6 0 L
F
0 g
.55 0 m
.55 .15451 L
.6 .15451 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .13185 L
.65 .13185 L
.65 0 L
F
0 g
.6 0 m
.6 .13185 L
.65 .13185 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .12567 L
.7 .12567 L
.7 0 L
F
0 g
.65 0 m
.65 .12567 L
.7 .12567 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .06592 L
.75 .06592 L
.75 0 L
F
0 g
.7 0 m
.7 .06592 L
.75 .06592 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .0103 L
.8 .0103 L
.8 0 L
F
0 g
.75 0 m
.75 .0103 L
.8 .0103 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo000Ho`0008kooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00
^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Soooo
o`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2S
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool001Wo0000YOooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`2kooooo`00^ooooolIo`0001Koo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo000Ho`000;gooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo000Ho`000=Cooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Y
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03
o`000?oo003oo`0001Coo`006Ol0000Fool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo6?l0000Gooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00
ooooool3ooooo`03o`000?oo003oo`0001Coo`006Ol0003[ooooo`00ooooool3ooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0ooooool2ooooo`00ooooool3oooooaSo0000ooooool4ooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Kooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;o
k^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00j?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo
1?l0003ooooooaSooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWo
oooo003Xooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oeEEEOmVIVKo0000
00Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?oo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`Co000000Go410@ooooooooooooooooodA4
A002o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`06ooooo`09ogMgMolb<S;ooooooooo
oomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool0
0ol0003oooooooooo`07ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool01_oo
ool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00Kooooo00GoMgMg
oc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo1?l0003ooooooaSooooo003X
ooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00Sooooo
00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Kooooo00?oEEEEofIVI_l000001Oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooo
oolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003Uooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go
V9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00onHV9So
8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo
410@00Sooooo1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooooooo
o`3ooooooaWooooo003Xooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo
003Yooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?o
oooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05o`00
0?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOooool5o`0000Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool02OmgMgOo
<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Kooooo00?oV9RHob4Q8Oo^k^h02Oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oo
oooooooo00Kooooo1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^00Oooooo00GoMgMg
oc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooo
oolIooooo`00j?ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_oo
ool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00jOoo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooo
oa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go0000okZj^_ooooooV9RH
oa0@4004ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03
o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00iOooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003U
ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo
00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@
413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?oZJVYoa0@4?oo
ool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008
ooooo`Co0000oooooolHooooo`00ioooool00ol@413o0000okZj^P03ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo00000?oooooo9?ooool00>Sooooo00?o^[Zj
ob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooo
oa0@403oooooobCooooo003Uooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`3oooooobCooooo003Uooooo`05
ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP3oooooobCooooo003ooooooooooooo7oooool00?oooooooooooolOoooo
o`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooo
oooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo
003gooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o0000ooooool9ooooo`00moooool0
0ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`3oooooo`Oooooo003[oooo
o`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool01?l0003ooooooooooooo
ool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4
okZj^P04ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000oooooooooooooooo
o`000006ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo00?o
c<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000ooooooooool0
ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
0_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0ooooool7ooooo`00k?ooool5o`0000Kooooo00?o0000ooooooooool00_ooool01?lQ8B7o
MgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7oooo
o`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooooooo0_l00002
ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool0ooooool7
ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>_ooooo00Co410@o`00
0?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`;o00004_ooool00ol0003oooooooooo`05
ooooo`;o0000ooooool9ooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooo
oooooolOooooo`00\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .0721 L
.4 .0721 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .0721 L
.4 .0721 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .18953 L
.45 .18953 L
.45 0 L
F
0 g
.4 0 m
.4 .18953 L
.45 .18953 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .14421 L
.5 .14421 L
.5 0 L
F
0 g
.45 0 m
.45 .14421 L
.5 .14421 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .18335 L
.55 .18335 L
.55 0 L
F
0 g
.5 0 m
.5 .18335 L
.55 .18335 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .17305 L
.6 .17305 L
.6 0 L
F
0 g
.55 0 m
.55 .17305 L
.6 .17305 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .11537 L
.65 .11537 L
.65 0 L
F
0 g
.6 0 m
.6 .11537 L
.65 .11537 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .09683 L
.7 .09683 L
.7 0 L
F
0 g
.65 0 m
.65 .09683 L
.7 .09683 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .04532 L
.75 .04532 L
.75 0 L
F
0 g
.7 0 m
.7 .04532 L
.75 .04532 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .00618 L
.8 .00618 L
.8 0 L
F
0 g
.75 0 m
.75 .00618 L
.8 .00618 L
.8 0 L
.75 0 L
s
1 0 0 r
.8 0 m
.8 .00412 L
.85 .00412 L
.85 0 L
F
0 g
.8 0 m
.8 .00412 L
.85 .00412 L
.85 0 L
.8 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`1Cooooo`04ob4Q8OmgMgOoMgMgoc8b<Qgooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool001Wo0000E?ooool2o`0000;ooooo
0_l0000Looooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`006?l0
002>ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`006Ol0002Uooooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2k
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`2kooooo`00^ooooolIo`0001Koo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo000Ho`000;gooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo000Ho`000=Cooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yoooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo
000Io`0001Koo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Go
oooo00?o0000ool00?oo00005?oo000Io`000>_ooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo
0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3o
ooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`0EoooooaSo0000ooooool4ooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo01Gooooo0_l0003ooooooa[ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oooooooooo`3ooooooaWooooo003C
oooooaSo00005oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00i_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?oo
ool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool4o`000?oooooo
6?ooool00>Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08
ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Kooooo1?l000001Ol@413oooooooooooooooooA4A400;o000000Wo
<S8bomgMgOooooooooooonk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Xooooo`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9So
oooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooo
oooo00Oooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`06ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool01OmgMgOo<S8boooooooo
oooo000000?ooooo00?o0000ooooooooool01_ooool4o`000?oooooo6?ooool00>Sooooo00?o0000
ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooooooooooooooo
o`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_oo
ool00omEEEGoIVIVo`000005ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Gooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So8B4Qonk^
k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oiRHV?lQ8B7ok^k^00Co
oooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?ooool4
o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Sooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00Go
0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go0000okZj^_oooooo
V9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lQ8B7o
c<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`Go00001?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`09ogMgMolb<S;ooooooooo
oomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool0
0onHV9So8B4Qonk^kP09ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool01_oo
ool4o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h01oooool01OmgMgOo<S8boooooooo
oooo000000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003X
ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00Sooooo
00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo
00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000oooooooo
ool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003o
oooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003o
oooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05
oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go410@
okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00jOooool01Ol0003ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo
00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00onYZJWo410@ooooo`02ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo1?l0003o
oooooaSooooo003Wooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool00000oooooolTooooo`00j?ooool00onj^[[o8B4Qooooo`02
ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@0?oooooo
9?ooool00>Gooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?oooooo9?ooool00>Gooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^0?oooooo9?ooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooo
oooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool0
0?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?Oooooo0_l0
000;ooooo`03o`000?nj^[[ooooo00cooooo0_l0003oooooo`Wooooo003gooooo`03o`000?oooooo
oooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo0?oooooo1oooool00>_ooooo00Co410@o`00
0?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00000_oo
ool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo
00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo
00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@
4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003oooooooooo`3oooooo`Oooooo
003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`04omgM
gOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oo
oooo003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`04
onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooo
o`Oooooo003/ooooo`Go00001_ooool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b
<P_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05
o`000?ooooooooooooooool000001_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l00008
ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0003oooooooooo`3oooooo`Oooooo003/oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00joooool01?l@413o0000o`000?ooool2
o`000003oa0@4?oooooooooo00?ooooo0_l0000Booooo`03o`000?oooooooooo00Gooooo0_l0003o
ooooo`Wooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo
0000\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .10301 L
.4 .10301 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .10301 L
.4 .10301 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .19159 L
.45 .19159 L
.45 0 L
F
0 g
.4 0 m
.4 .19159 L
.45 .19159 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .13803 L
.5 .13803 L
.5 0 L
F
0 g
.45 0 m
.45 .13803 L
.5 .13803 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .18541 L
.55 .18541 L
.55 0 L
F
0 g
.5 0 m
.5 .18541 L
.55 .18541 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .16275 L
.6 .16275 L
.6 0 L
F
0 g
.55 0 m
.55 .16275 L
.6 .16275 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .10301 L
.65 .10301 L
.65 0 L
F
0 g
.6 0 m
.6 .10301 L
.65 .10301 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .09271 L
.7 .09271 L
.7 0 L
F
0 g
.65 0 m
.65 .09271 L
.7 .09271 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .04738 L
.75 .04738 L
.75 0 L
F
0 g
.7 0 m
.7 .04738 L
.75 .04738 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .00618 L
.8 .00618 L
.8 0 L
F
0 g
.75 0 m
.75 .00618 L
.8 .00618 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo000Ho`0008kooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2S
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`006Ol0002Uooooo`00^oooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2koooo
o`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2k
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`006?l0002mooooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3B
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00
^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`3Booooo`00^ooooolIo`0001Koo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`006?l0003Dooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wo
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`006Ol0000Fool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Ooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOoo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo000Io`000>_ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oo
oooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0EoooooaSo0000
ooooool4ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o
0000ooooooooool0oooooolIooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0oooooolIooooo`00dooooolHo`0001Oooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00i_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?oo
ool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool4o`000?oooooo
6?ooool00>Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08
ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Kooooo1?l000001Ol@413oooooooooooooooooA4A400;o000000Wo
<S8bomgMgOooooooooooonk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Xooooo`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9So
oooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooo
oooo00Oooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`06ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool01OmgMgOo<S8boooooooo
oooo000000?ooooo00?o0000ooooooooool01_ooool4o`000?oooooo6?ooool00>Sooooo00?o0000
ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooooooooooooooo
o`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_oo
ool00omEEEGoIVIVo`000005ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Gooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So8B4Qonk^
k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oiRHV?lQ8B7ok^k^00Co
oooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?ooool4
o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Sooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00Go
0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go0000okZj^_oooooo
V9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lQ8B7o
c<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`Go00001?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`09ogMgMolb<S;ooooooooo
oomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool0
0onHV9So8B4Qonk^kP09ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool01_oo
ool4o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h01oooool01OmgMgOo<S8boooooooo
oooo000000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003X
ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00Sooooo
00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo
00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000oooooooo
ool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003o
oooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003o
oooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05
oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go410@
okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00jOooool01Ol0003ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo
00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00onYZJWo410@ooooo`02ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo1?l0003o
oooooaSooooo003Wooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool00000oooooolTooooo`00j?ooool00onj^[[o8B4Qooooo`02
ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@0?oooooo
9?ooool00>Gooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?oooooo9?ooool00>Gooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^0?oooooo9?ooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooo
oooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool0
0?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?Oooooo0_l0
000;ooooo`03o`000?nj^[[ooooo00cooooo0_l0003oooooo`Wooooo003gooooo`03o`000?oooooo
oooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo0?oooooo1oooool00>_ooooo00Co410@o`00
0?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00000_oo
ool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo
00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo
00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@
4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003oooooooooo`3oooooo`Oooooo
003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`04omgM
gOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oo
oooo003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`04
onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooo
o`Oooooo003/ooooo`Go00001_ooool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b
<P_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05
o`000?ooooooooooooooool000001_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l00008
ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0003oooooooooo`3oooooo`Oooooo003/oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00joooool01?l@413o0000o`000?ooool2
o`000003oa0@4?oooooooooo00?ooooo0_l0000Booooo`03o`000?oooooooooo00Gooooo0_l0003o
ooooo`Wooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo
0000\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .09271 L
.4 .09271 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .09271 L
.4 .09271 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .19777 L
.45 .19777 L
.45 0 L
F
0 g
.4 0 m
.4 .19777 L
.45 .19777 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .15039 L
.5 .15039 L
.5 0 L
F
0 g
.45 0 m
.45 .15039 L
.5 .15039 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .17923 L
.55 .17923 L
.55 0 L
F
0 g
.5 0 m
.5 .17923 L
.55 .17923 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .16275 L
.6 .16275 L
.6 0 L
F
0 g
.55 0 m
.55 .16275 L
.6 .16275 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .10507 L
.65 .10507 L
.65 0 L
F
0 g
.6 0 m
.6 .10507 L
.65 .10507 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .09477 L
.7 .09477 L
.7 0 L
F
0 g
.65 0 m
.65 .09477 L
.7 .09477 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .04326 L
.75 .04326 L
.75 0 L
F
0 g
.7 0 m
.7 .04326 L
.75 .04326 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .00412 L
.8 .00412 L
.8 0 L
F
0 g
.75 0 m
.75 .00412 L
.8 .00412 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
6?l0001/ooooo`;o00000_ooool2o`0001cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oooooooooo08cooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2S
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool001Wo0000YOooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00
^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^ooooolIo`0001Koo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo000Ho`000;gooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Boooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool001So0000e?ooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOoo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`00
01Coo`006Ol0000Fool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0E
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Y
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool001Wo
0000joooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Go
oooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo6?l0003oooooo`Cooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oooooooooo`3ooooo
oaWooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003o
ooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
5Oooool2o`000?oooooo6_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oo
oooo6Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo0?oooooo6Oooool00=?ooooo6?l0000Gooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Kooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o
0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo1?l0003ooooooaSooooo
003Xooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool0
0ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooo
oolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooo
oolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooo
oolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003Vooooo`Co000000Go410@ooooooooooooooooodA4A002o`000009oc8b<_oM
gMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00j?ooool00ol0003oooooooooo`06ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonH
V9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`07
ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool01_ooool00ol0003ooooooooo
o`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00Kooooo00GoMgMgoc8b<_ooooooooooo`00
0003ooooo`03o`000?oooooooooo00Kooooo1?l0003ooooooaSooooo003Xooooo`03o`000?oooooo
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool00000
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0
oooooolIooooo`00j?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?o
EEEEofIVI_l000001Oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003U
ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo1?l0003o
oooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003X
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`05o`000?oo
ooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooooooo
ool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@
41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08
ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00iOooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8b
omgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWo
oooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool02OmgMgOo<S8booooooooooooMgMg
oiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oV9RH
ob4Q8Oo^k^h02Oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00Kooooo1?l0
003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^00Oooooo00GoMgMgoc8b<_ooooooooooo`00
0003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool0
0omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooo
oooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00jOooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Gooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`00
0?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJ
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJ
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So
410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oa0@4?nj^[[o
ooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00Go0000oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`06oooo
o`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`Co0000oooooolH
ooooo`00ioooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo00000?oooooo9?ooool00>Sooooo00?o^[Zjob4Q8Oooool00_ooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@403oooooobCooooo
003Uooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`3oooooobCooooo003Uooooo`05ojVYZOl@413o0000oa0@
4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooobCooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoo
oooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooo
oooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003gooooo`;o00002ooo
ool00ol0003o^[Zjooooo`0<ooooo`;o0000ooooool9ooooo`00moooool00ol0003oooooooooo`0:
ooooo`;o<S8b3_ooool00ol0003oooooooooo`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o0000
ooooo`;o000000?o410@ooooooooool00oooool01?l0003oooooooooooooool2o`0000;ooooo0_l0
0003ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`00
0?oooooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`0:o`00
0?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo00?oc<c<o`000?l@41001?oo
ool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000ooooooooool0ooooool7ooooo`00k?oo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool01?oMgMgo0000
oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00
k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool01?o^k^ko
8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7oooo
o`00k?ooool5o`0000Kooooo00?o0000ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb<S8;oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003o
oooooooooooooooo000000Kooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00002?ooool0
0ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo0?oooooo1oooool00>_ooooo00Co410@o`000?l0003ooooo0_l00000
0ol@413oooooooooo`03ooooo`;o00004_ooool00ol0003oooooooooo`05ooooo`;o0000ooooool9
ooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .05562 L
.4 .05562 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .05562 L
.4 .05562 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .20395 L
.45 .20395 L
.45 0 L
F
0 g
.4 0 m
.4 .20395 L
.45 .20395 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .13391 L
.5 .13391 L
.5 0 L
F
0 g
.45 0 m
.45 .13391 L
.5 .13391 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .16893 L
.55 .16893 L
.55 0 L
F
0 g
.5 0 m
.5 .16893 L
.55 .16893 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .18541 L
.6 .18541 L
.6 0 L
F
0 g
.55 0 m
.55 .18541 L
.6 .18541 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .13597 L
.65 .13597 L
.65 0 L
F
0 g
.6 0 m
.6 .13597 L
.65 .13597 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .08446 L
.7 .08446 L
.7 0 L
F
0 g
.65 0 m
.65 .08446 L
.7 .08446 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .0412 L
.75 .0412 L
.75 0 L
F
0 g
.7 0 m
.7 .0412 L
.75 .0412 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .0206 L
.8 .0206 L
.8 0 L
F
0 g
.75 0 m
.75 .0206 L
.8 .0206 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo000Ho`00
08kooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xooo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo000Io`000:Gooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0;_ooooo002koooooaWo00005_oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^ooo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool001So0000_Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Boooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3B
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo
003Cooooo`03o`000?oo003oo`0001Coo`006Ol0000Fool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool001So0000e?ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eoooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yoooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooo
oooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0E
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Y
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05OoooolH
o`0001Ooo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Go
oooo00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wo
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Cooooo00?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oooooooooo01Gooooo00?o0000ooooooooool05?ooool00ol0003oo`00ool0000E
ool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo0_l0000EoooooaWo0000
joooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo
6Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005?oo00002?l0003oooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00doooool00ol0003oo`00ool0000Dool00008o`000?ooooooooooogMg
MonHV9SooooooiRHV?mgMgL3ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003CoooooaSo00000_ooool01Ol@413ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000008ooooo`Co0000oooooolHooooo`00j?ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000
ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooo
oolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_oo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool4o`000005oa0@
4?oooooooooooooooom4A4@00_l000002Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^
kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool0
2OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Sooooo00?o0000ooooooooool01oooool01?l0003oooooooooool@4103ooooo`03
oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003ooooo
ooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`06ooooo`Co
0000oooooolHooooo`00j?ooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`00_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIoooo
o`00j?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooo
oooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0
003oooooooooo`3ooooooaWooooo003Vooooo`03oeEEEOmVIVKo000000Gooooo1?l00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003o
oooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00iOooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Kooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@4008ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^
kP03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000So
oooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00omgMgOoIVIVooooo`02ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooo
ooooool0oooooolIooooo`00jOooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooo
oooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolI
ooooo`00iOooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo
003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2
o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2
o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2
o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Go
oooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So8B4Qonk^k_oooooo
A4A400Oooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Vooooo`03oiRHV?lQ8B7ok^k^00Wooooo00Co0000oooooooooooo
410@0oooool00ol@413oooooooooo`06ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Q
onk^kP07ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05
oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05
o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooooooo
ool0oooooolIooooo`00iOooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3o
oooooaWooooo003Yooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@00?ooooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003X
ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000002?ooool4o`000?oooooo6?ooool00>Oooooo00?o410@o`000?nj^[X00ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00003oooooobCo
oooo003Xooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@4100oooooolTooooo`00iOooool01Ol@413oV9RHoooooonj^[[o0000
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0oooo
oolTooooo`00iOooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0oooooolTooooo`00oooooooooooooaoooooo
003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooo
oooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool0
0?oooooooooooolOooooo`00moooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`000?oo
oooo2Oooool00?Oooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool0
ooooool7ooooo`00joooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo
00Co0000oooooooooooooooo0_l00002ooooo`;o00000oooool00on7QhOo0000okZj^P04ooooo`05
oiRHV?l0003o0000odA4A?nj^[X01?ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05
o`000?ooooooooooooooool000001_ooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zj
o`000?oMgMd3ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004oooo
o`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo00;ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo1Ol00006ooooo`03o`000?oooooo
oooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oo
ooooooooooooo`;o00000_ooool2o`0000Sooooo00?o410@o`000?l000000ol00005ooooo`03o`00
0?oooooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo
003[ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool2o`0001;ooooo
00?o0000ooooooooool01Oooool2o`000?oooooo2Oooool00?oooooooooooolOooooo`00oooooooo
oooooaoooooo003ooooooooooooo7oooool00001\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .07828 L
.4 .07828 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .07828 L
.4 .07828 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .15863 L
.45 .15863 L
.45 0 L
F
0 g
.4 0 m
.4 .15863 L
.45 .15863 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .12979 L
.5 .12979 L
.5 0 L
F
0 g
.45 0 m
.45 .12979 L
.5 .12979 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .18129 L
.55 .18129 L
.55 0 L
F
0 g
.5 0 m
.5 .18129 L
.55 .18129 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .15039 L
.6 .15039 L
.6 0 L
F
0 g
.55 0 m
.55 .15039 L
.6 .15039 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .14627 L
.65 .14627 L
.65 0 L
F
0 g
.6 0 m
.6 .14627 L
.65 .14627 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .09889 L
.7 .09889 L
.7 0 L
F
0 g
.65 0 m
.65 .09889 L
.7 .09889 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .07004 L
.75 .07004 L
.75 0 L
F
0 g
.7 0 m
.7 .07004 L
.75 .07004 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .01648 L
.8 .01648 L
.8 0 L
F
0 g
.75 0 m
.75 .01648 L
.8 .01648 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
000Ho`0008kooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Soooo
o`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2S
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`006Ol0002Uooooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00
^ooooolIo`0001Koo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo000Ho`000;gooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_oo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo000Io`0001Ko
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0E
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool001So0000e?ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`006Ol0003[ooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
5Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0ooooool2ooooo`00dooooolHo`0001Oooooo00?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3o
ooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3ooooo
o`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;o
oooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo
003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003o
ooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003ooooo
o`?ooooo6?l0003oooooo`Cooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00i_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?oo
ool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool4o`000?oooooo
6?ooool00>Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08
ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Kooooo1?l000001Ol@413oooooooooooooooooA4A400;o000000Wo
<S8bomgMgOooooooooooonk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Xooooo`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9So
oooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooo
oooo00Oooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`06ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool01OmgMgOo<S8boooooooo
oooo000000?ooooo00?o0000ooooooooool01_ooool4o`000?oooooo6?ooool00>Sooooo00?o0000
ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooooooooooooooo
o`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_oo
ool00omEEEGoIVIVo`000005ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Gooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So8B4Qonk^
k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oiRHV?lQ8B7ok^k^00Co
oooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?ooool4
o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Sooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00Go
0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go0000okZj^_oooooo
V9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lQ8B7o
c<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`Go00001?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`09ogMgMolb<S;ooooooooo
oomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool0
0onHV9So8B4Qonk^kP09ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool01_oo
ool4o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h01oooool01OmgMgOo<S8boooooooo
oooo000000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003X
ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00Sooooo
00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo
00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000oooooooo
ool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003o
oooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003o
oooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05
oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go410@
okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00jOooool01Ol0003ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo
00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00onYZJWo410@ooooo`02ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo1?l0003o
oooooaSooooo003Wooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool00000oooooolTooooo`00j?ooool00onj^[[o8B4Qooooo`02
ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@0?oooooo
9?ooool00>Gooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?oooooo9?ooool00>Gooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^0?oooooo9?ooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooo
oooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool0
0?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?Oooooo0_l0
000;ooooo`03o`000?nj^[[ooooo00cooooo0_l0003oooooo`Wooooo003gooooo`03o`000?oooooo
oooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo0?oooooo1oooool00>_ooooo00Co410@o`00
0?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00000_oo
ool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo
00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo
00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@
4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003oooooooooo`3oooooo`Oooooo
003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`04omgM
gOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oo
oooo003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`04
onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooo
o`Oooooo003/ooooo`Go00001_ooool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b
<P_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05
o`000?ooooooooooooooool000001_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l00008
ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0003oooooooooo`3oooooo`Oooooo003/oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00joooool01?l@413o0000o`000?ooool2
o`000003oa0@4?oooooooooo00?ooooo0_l0000Booooo`03o`000?oooooooooo00Gooooo0_l0003o
ooooo`Wooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo
0000\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .06798 L
.4 .06798 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .06798 L
.4 .06798 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .15245 L
.45 .15245 L
.45 0 L
F
0 g
.4 0 m
.4 .15245 L
.45 .15245 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .13185 L
.5 .13185 L
.5 0 L
F
0 g
.45 0 m
.45 .13185 L
.5 .13185 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .19159 L
.55 .19159 L
.55 0 L
F
0 g
.5 0 m
.5 .19159 L
.55 .19159 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .17099 L
.6 .17099 L
.6 0 L
F
0 g
.55 0 m
.55 .17099 L
.6 .17099 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .10919 L
.65 .10919 L
.65 0 L
F
0 g
.6 0 m
.6 .10919 L
.65 .10919 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .09889 L
.7 .09889 L
.7 0 L
F
0 g
.65 0 m
.65 .09889 L
.7 .09889 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .09477 L
.75 .09477 L
.75 0 L
F
0 g
.7 0 m
.7 .09477 L
.75 .09477 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .01236 L
.8 .01236 L
.8 0 L
F
0 g
.75 0 m
.75 .01236 L
.8 .01236 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo000Ho`0008kooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`2Sooooo`00^ooooolIo`0001Koo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool001Wo0000YOooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool001So
0000_Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`006?l0003Dooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wo
oooo003Cooooo`03o`000?oo003oo`0001Coo`006Ol0000Fool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Ooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOoo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003CoooooaSo00005oooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00?oooooo
0oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
jOooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0jOooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0jOooool00?oooooo0oooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00?oooooo0oooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00?oooooo
0oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
jOooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0jOooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0jOooool00?oooooo0oooool00ol0003oo`00ool0000Dool0
01Wo0000joooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oo
oooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo
0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_oo
ool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool0
0?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oo
oooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oooooo
0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oooooo0ooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oooooo0oooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oooooo0ooooolHo`00
0?oooooo1?ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Kooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o
0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo1?l0003ooooooaSooooo
003Xooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool0
0ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooo
oolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooo
oolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooo
oolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003Vooooo`Co000000Go410@ooooooooooooooooodA4A002o`000009oc8b<_oM
gMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00j?ooool00ol0003oooooooooo`06ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonH
V9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`07
ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool01_ooool00ol0003ooooooooo
o`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00Kooooo00GoMgMgoc8b<_ooooooooooo`00
0003ooooo`03o`000?oooooooooo00Kooooo1?l0003ooooooaSooooo003Xooooo`03o`000?oooooo
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool00000
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0
oooooolIooooo`00j?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?o
EEEEofIVI_l000001Oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003U
ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo1?l0003o
oooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003X
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`05o`000?oo
ooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooooooo
ool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@
41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08
ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00iOooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8b
omgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWo
oooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool02OmgMgOo<S8booooooooooooMgMg
oiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oV9RH
ob4Q8Oo^k^h02Oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00Kooooo1?l0
003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^00Oooooo00GoMgMgoc8b<_ooooooooooo`00
0003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool0
0omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooo
oooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00jOooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Gooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`00
0?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJ
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJ
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So
410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oa0@4?nj^[[o
ooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00Go0000oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`06oooo
o`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`Co0000oooooolH
ooooo`00ioooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo00000?oooooo9?ooool00>Sooooo00?o^[Zjob4Q8Oooool00_ooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@403oooooobCooooo
003Uooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`3oooooobCooooo003Uooooo`05ojVYZOl@413o0000oa0@
4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooobCooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoo
oooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooo
oooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003gooooo`;o00002ooo
ool00ol0003o^[Zjooooo`0<ooooo`;o0000ooooool9ooooo`00moooool00ol0003oooooooooo`0:
ooooo`;o<S8b3_ooool00ol0003oooooooooo`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o0000
ooooo`;o000000?o410@ooooooooool00oooool01?l0003oooooooooooooool2o`0000;ooooo0_l0
0003ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`00
0?oooooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`0:o`00
0?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo00?oc<c<o`000?l@41001?oo
ool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000ooooooooool0ooooool7ooooo`00k?oo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool01?oMgMgo0000
oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00
k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool01?o^k^ko
8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7oooo
o`00k?ooool5o`0000Kooooo00?o0000ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb<S8;oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003o
oooooooooooooooo000000Kooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00002?ooool0
0ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo0?oooooo1oooool00>_ooooo00Co410@o`000?l0003ooooo0_l00000
0ol@413oooooooooo`03ooooo`;o00004_ooool00ol0003oooooooooo`05ooooo`;o0000ooooool9
ooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .06798 L
.4 .06798 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .06798 L
.4 .06798 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .18129 L
.45 .18129 L
.45 0 L
F
0 g
.4 0 m
.4 .18129 L
.45 .18129 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .13597 L
.5 .13597 L
.5 0 L
F
0 g
.45 0 m
.45 .13597 L
.5 .13597 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .17923 L
.55 .17923 L
.55 0 L
F
0 g
.5 0 m
.5 .17923 L
.55 .17923 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .14215 L
.6 .14215 L
.6 0 L
F
0 g
.55 0 m
.55 .14215 L
.6 .14215 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .11949 L
.65 .11949 L
.65 0 L
F
0 g
.6 0 m
.6 .11949 L
.65 .11949 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .13185 L
.7 .13185 L
.7 0 L
F
0 g
.65 0 m
.65 .13185 L
.7 .13185 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .0618 L
.75 .0618 L
.75 0 L
F
0 g
.7 0 m
.7 .0618 L
.75 .0618 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .0103 L
.8 .0103 L
.8 0 L
F
0 g
.75 0 m
.75 .0103 L
.8 .0103 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo000Ho`0008kooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00
^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Soooo
o`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2S
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo000I
o`000:Gooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^ooooolIo`0001Koo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`006?l0000Fool00003
o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
5?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo
0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0003o
o`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool05?oooolHo`000;gooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo000Io`0001Koo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`00
0?oo003oo`0001Coo`006Ol0003[ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000D
ool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2oooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo
0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3o
ooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0E
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05OoooolHo`000?oooooo1?ooool0
0=?ooooo6?l0000Gooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`Co000000So410@ooooooooooook^k^oc8b
<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0>Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@
oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000008ooooo`Co0000oooooolHooooo`00j?ooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooooooo
ool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00j?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool4o`000005oa0@4?oooooo
oooooooooom4A4@00_l000002Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^kP08oooo
o`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool02OmgMgOo
<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Sooooo00?o0000ooooooooool01oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oo
oooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`06
ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`06ooooo`Co0000oooo
oolHooooo`00j?ooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_oo
ool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00j?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooo
oa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Vooooo`03oeEEEOmVIVKo000000Gooooo1?l00003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[o
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00iOooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo
003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Ko
oooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooo
oooooooooooooa0@4008ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP03oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o
0000ooooooooool0oooooolIooooo`00j?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
oooooolIooooo`00jOooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00
iOooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uoooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oo
oooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oo
oooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oo
oooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo1Ol0
0004ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00So
oooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So8B4Qonk^k_ooooooA4A400Oo
oooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003ooooooooo
o`3ooooooaWooooo003Vooooo`03oiRHV?lQ8B7ok^k^00Wooooo00Co0000oooooooooooo410@0ooo
ool00ol@413oooooooooo`06ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP07
ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Sooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05oa0@4?oo
ooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05o`000?nj
^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`01?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooo
oa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooo
oa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooo
oolIooooo`00iOooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWo
oooo003Yooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000002?ooool4o`000?oooooo6?ooool00>Oooooo00?o410@o`000?nj^[X00oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00003oooooobCooooo003X
ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oo
ooooooooooooool@4100oooooolTooooo`00iOooool01Ol@413oV9RHoooooonj^[[o000000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0oooooolToooo
o`00iOooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0oooooolTooooo`00oooooooooooooaoooooo003ooooo
oooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7ooo
ool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooo
oooooolOooooo`00moooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`000?oooooo2Ooo
ool00?Oooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool0ooooool7
ooooo`00joooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo00Co0000
oooooooooooooooo0_l00002ooooo`;o00000oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0
003o0000odA4A?nj^[X01?ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?oo
ooooooooooooool000001_ooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oM
gMd3ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`00
0?oooooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo00;ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo0?oooooo1oooool00>cooooo1Ol00006ooooo`03o`000?oooooooooo00;o
oooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooooooo
ooooo`;o00000_ooool2o`0000Sooooo00?o410@o`000?l000000ol00005ooooo`03o`000?oooooo
oooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003[oooo
o`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool2o`0001;ooooo00?o0000
ooooooooool01Oooool2o`000?oooooo2Oooool00?oooooooooooolOooooo`00oooooooooooooaoo
oooo003ooooooooooooo7oooool00001\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .07622 L
.4 .07622 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .07622 L
.4 .07622 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .19571 L
.45 .19571 L
.45 0 L
F
0 g
.4 0 m
.4 .19571 L
.45 .19571 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .14421 L
.5 .14421 L
.5 0 L
F
0 g
.45 0 m
.45 .14421 L
.5 .14421 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .18747 L
.55 .18747 L
.55 0 L
F
0 g
.5 0 m
.5 .18747 L
.55 .18747 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .16893 L
.6 .16893 L
.6 0 L
F
0 g
.55 0 m
.55 .16893 L
.6 .16893 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .10507 L
.65 .10507 L
.65 0 L
F
0 g
.6 0 m
.6 .10507 L
.65 .10507 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .09683 L
.7 .09683 L
.7 0 L
F
0 g
.65 0 m
.65 .09683 L
.7 .09683 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .04326 L
.75 .04326 L
.75 0 L
F
0 g
.7 0 m
.7 .04326 L
.75 .04326 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .01236 L
.8 .01236 L
.8 0 L
F
0 g
.75 0 m
.75 .01236 L
.8 .01236 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo000Ho`0008kooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool001Wo0000YOooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0^oooool00;_ooooo6Ol0000Fool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2k
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`006?l0002moooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool001So0000e?ooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOoo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
jOooool00=?ooooo00?o0000ool00?oo00005?oo000Io`0001Koo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooo
oooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0E
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Y
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool0
0ol0003oo`00ool0000Dool001Wo0000joooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2oooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo
0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3o
ooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool05OoooolHo`000?oooooo1?ooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo0?oooooo6Oooool00=?ooooo6?l0000Gooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`Co000000So410@
ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08oooo
o`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000008ooooo`Co0000oooooolHooooo`00j?ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000So
oooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolI
ooooo`00i_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000
oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool4
o`000005oa0@4?oooooooooooooooom4A4@00_l000002Olb<S;ogMgMooooooooooook^k^oc8b<_l0
003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000oooooooo
ool01_ooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01oooool01?l0003oooooooooool@
4103ooooo`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool0
0ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003ooooooooo
o`06ooooo`Co0000oooooolHooooo`00j?ooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
oooooolIooooo`00j?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go
410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oeEEEOmVIVKo000000Gooooo1?l0
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOooool5o`0000?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`Co0000oooooolHooooo`00ioooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00omgMgOoIVIVooooo`02
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo
00?o0000ooooooooool0oooooolIooooo`00jOooool01Ol0003ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooolIooooo`00iOooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3o
oooooaWooooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Gooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So8B4Q
onk^k_ooooooA4A400Oooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL02?oo
ool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oiRHV?lQ8B7ok^k^00Wooooo00Co0000
oooooooooooo410@0oooool00ol@413oooooooooo`06ooooo`Co0000oooooolHooooo`00ioooool0
0onHV9So8B4Qonk^kP07ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?oMgMgofIVI_ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Wooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo
003Uooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`04ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o<S8bolc<c003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o
0000ooooooooool0oooooolIooooo`00iOooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Yooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@00?ooooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooo
oaWooooo003Xooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000002?ooool4o`000?oooooo6?ooool00>Oooooo00?o410@o`00
0?nj^[X00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
003oooooobCooooo003Xooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100oooooolTooooo`00iOooool01Ol@413oV9RHoooo
oonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL0oooooolTooooo`00iOooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0oooooolTooooo`00oooooooo
oooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo
003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooo
oooo7oooool00?oooooooooooolOooooo`00moooool2o`0000_ooooo00?o0000okZj^_ooool03?oo
ool2o`000?oooooo2Oooool00?Oooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000
ooooooooool0ooooool7ooooo`00joooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooo
oooo00?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000oooool00on7QhOo0000okZj
^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X01?ooool00ol0003oooooooooo`3oooooo`Oooooo
003/ooooo`05o`000?ooooooooooooooool000001_ooool02_l0003oooooooooooooooook^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMg
oa0@4004ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo00;ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo1Ol00006ooooo`03
o`000?oooooooooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006oooo
o`04o`000?ooooooooooooooo`;o00000_ooool2o`0000Sooooo00?o410@o`000?l000000ol00005
ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3o
ooooo`Oooooo003[ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool2
o`0001;ooooo00?o0000ooooooooool01Oooool2o`000?oooooo2Oooool00?oooooooooooolOoooo
o`00oooooooooooooaoooooo003ooooooooooooo7oooool00001\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .10713 L
.4 .10713 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .10713 L
.4 .10713 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .17511 L
.45 .17511 L
.45 0 L
F
0 g
.4 0 m
.4 .17511 L
.45 .17511 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .15863 L
.5 .15863 L
.5 0 L
F
0 g
.45 0 m
.45 .15863 L
.5 .15863 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .16893 L
.55 .16893 L
.55 0 L
F
0 g
.5 0 m
.5 .16893 L
.55 .16893 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .16069 L
.6 .16069 L
.6 0 L
F
0 g
.55 0 m
.55 .16069 L
.6 .16069 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .12567 L
.65 .12567 L
.65 0 L
F
0 g
.6 0 m
.6 .12567 L
.65 .12567 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .0721 L
.7 .0721 L
.7 0 L
F
0 g
.65 0 m
.65 .0721 L
.7 .0721 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .05356 L
.75 .05356 L
.75 0 L
F
0 g
.7 0 m
.7 .05356 L
.75 .05356 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .00618 L
.8 .00618 L
.8 0 L
F
0 g
.75 0 m
.75 .00618 L
.8 .00618 L
.8 0 L
.75 0 L
s
1 0 0 r
.8 0 m
.8 .00206 L
.85 .00206 L
.85 0 L
F
0 g
.8 0 m
.8 .00206 L
.85 .00206 L
.85 0 L
.8 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`006Ol0001Eooooo`04ob4Q8OmgMgOoMgMgoc8b<Qgo
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo06[ooooo0_l00002ooooo`;o00007?ooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool001So0000S_ooool00;_ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Soooo
o`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2S
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo000Io`000:Gooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo000Ho`000;gooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0=;ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0=;ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0=;ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo0=;ooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0=;ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0=;ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0=;ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0=;ooooo002koooooaWo00005_oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_oo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo000Ho`000=Cooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wo
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000D
ool001Wo00005_oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool0
01Wo0000joooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Ooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`0EoooooaSo0000ooooool4ooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ooooooooool0oooooolIoooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0oooooolIooooo`00dooooolHo`0001Oooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo1?l000002?l@413oooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolI
ooooo`00j?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool0
1Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000Sooooo1?l0003ooooooaSooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Voooo
o`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`Co000000Go410@
ooooooooooooooooodA4A002o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`06ooooo`09
ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooo
oolIooooo`00j?ooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooooa0@40?ooooo00?o
410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooo
oooo00Kooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo1?l0
003ooooooaSooooo003Xooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c002ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo
003Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Kooooo00?oEEEEofIVI_l000001Oooool4o`0000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oo
oooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00i_ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@00Sooooo1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?oo
ool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ogMgMomVIVKooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Yooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWo
oooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o
0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o
0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o
0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOoo
ool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^k^h02Oooool01?l0003oooooooooool@
4103ooooo`03oa0@4?oooooooooo00Kooooo1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7o
k^k^00Oooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0oooooolIooooo`00j?ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
oooooolIooooo`00jOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go
410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go
0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c004ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`00
0?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`00
0?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003ooooooooo
o`3ooooooaWooooo003Uooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Wooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>So
oooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000008ooooo`Co0000oooooolHooooo`00ioooool00ol@413o0000okZj^P03oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo00000?oooooo9?oo
ool00>Sooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@403oooooobCooooo003Uooooo`05oa0@4?nHV9SooooookZj^_l00000
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`3ooooo
obCooooo003Uooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP3oooooobCooooo003ooooooooooooo7oooool0
0?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooo
oolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00
oooooooooooooaoooooo003gooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o0000oooo
ool9ooooo`00moooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`3o
ooooo`Oooooo003[ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool0
1?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00Go
V9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go
0000ooooooooooooooooo`000006ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o
0000omgMg@?ooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo
00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool5o`0000Kooooo00?o0000oooooooo
ool00_ooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooo
oooooooooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Gooooo00?o0000
ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool0
0>_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`;o00004_ooool0
0ol0003oooooooooo`05ooooo`;o0000ooooool9ooooo`00oooooooooooooaoooooo003ooooooooo
oooo7oooool00?oooooooooooolOooooo`00\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .09064 L
.4 .09064 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .09064 L
.4 .09064 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .16275 L
.45 .16275 L
.45 0 L
F
0 g
.4 0 m
.4 .16275 L
.45 .16275 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .15451 L
.5 .15451 L
.5 0 L
F
0 g
.45 0 m
.45 .15451 L
.5 .15451 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .18953 L
.55 .18953 L
.55 0 L
F
0 g
.5 0 m
.5 .18953 L
.55 .18953 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .17099 L
.6 .17099 L
.6 0 L
F
0 g
.55 0 m
.55 .17099 L
.6 .17099 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .12361 L
.65 .12361 L
.65 0 L
F
0 g
.6 0 m
.6 .12361 L
.65 .12361 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .08034 L
.7 .08034 L
.7 0 L
F
0 g
.65 0 m
.65 .08034 L
.7 .08034 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .0515 L
.75 .0515 L
.75 0 L
F
0 g
.7 0 m
.7 .0515 L
.75 .0515 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .00618 L
.8 .00618 L
.8 0 L
F
0 g
.75 0 m
.75 .00618 L
.8 .00618 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo000Ho`0008kooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2S
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo000Io`000:Gooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^ooo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`006?l0002mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^ooooolIo`0001Koo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Boooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3B
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool001So0000e?oo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool001Wo00005_oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0E
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Y
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003CoooooaSo
00005oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0jOooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0jOooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0jOooool00?oooooo0oooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00?oooooo0oooool00ol0
003oo`00ool0000Dool001Wo0000joooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo
0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oo
oooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo
0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_oo
ool00?oooooo0ooooolHo`000?oooooo1?ooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003V
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08
ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`Co0000oooooolHooooo`00j?oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@
00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000
ooooooooool0oooooolIooooo`00i_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_oo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_oo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_oo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00i_ooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000002Olb<S;ogMgMoooo
ooooooook^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>So
oooo00?o0000ooooooooool01_ooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMg
M`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01oooool0
1?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooo
oolIooooo`00j?ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000ooo
ool00ol0003oooooooooo`06ooooo`Co0000oooooolHooooo`00j?ooool00ol0003oooooooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000Sooooo
00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oeEEEOmV
IVKo000000Gooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000
oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000
oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOooool5
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08oooo
o`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`Co0000oooooolH
ooooo`00ioooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool0
0omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00jOooool01Ol0003ooooooooo
oooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Ko
oooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[ZjoooooonHV9So410@00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool0
0ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Gooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
0_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00
iOooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9So
oooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oiRHV?lQ8B7o
k^k^00Wooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`06ooooo`Co0000oooo
oolHooooo`00ioooool00onHV9So8B4Qonk^kP07ooooo`05ogMgMolb<S;oooooooooool000000ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?oMgMg
ofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooooooooooooooo
o`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooo
ooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWo
oooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0
003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol@413o^[Zjoooooomg
MgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`05o`000?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01_ooool00ol0
003oooooooooo`3ooooooaWooooo003Xooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool4o`000?oooooo6?ooool0
0>Oooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`00003oooooobCooooo003Xooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@
oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100oooooolTooooo`00iOoo
ool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0oooooolTooooo`00iOooool01OnYZJWo410@o`000?l@413oZJVY
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0oooo
oolTooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00
oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooo
oaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00moooool2o`0000_ooooo00?o
0000okZj^_ooool03?ooool2o`000?oooooo2Oooool00?Oooooo00?o0000ooooooooool02_ooool2
oc8b<Pkooooo00?o0000ooooooooool0ooooool7ooooo`00joooool01?l@413o0000o`000?ooool2
o`000003oa0@4?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000ooo
ool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X01?ooool00ol0003ooooo
ooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool02_l0003ooooo
ooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o410@00Cooooo00Go
410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00CogMgMo`000?l@413o
c<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@
413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>co
oooo1Ol00006ooooo`03o`000?oooooooooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000oooooooo
ooooooooo`000006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000Sooooo00?o410@
o`000?l000000ol00005ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@
ooooooooool00oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`000?oooooo2Oooool0
0?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00001\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .06592 L
.4 .06592 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .06592 L
.4 .06592 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .17099 L
.45 .17099 L
.45 0 L
F
0 g
.4 0 m
.4 .17099 L
.45 .17099 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .14833 L
.5 .14833 L
.5 0 L
F
0 g
.45 0 m
.45 .14833 L
.5 .14833 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .18335 L
.55 .18335 L
.55 0 L
F
0 g
.5 0 m
.5 .18335 L
.55 .18335 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .16687 L
.6 .16687 L
.6 0 L
F
0 g
.55 0 m
.55 .16687 L
.6 .16687 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .15657 L
.65 .15657 L
.65 0 L
F
0 g
.6 0 m
.6 .15657 L
.65 .15657 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .07828 L
.7 .07828 L
.7 0 L
F
0 g
.65 0 m
.65 .07828 L
.7 .07828 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .04326 L
.75 .04326 L
.75 0 L
F
0 g
.7 0 m
.7 .04326 L
.75 .04326 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .01648 L
.8 .01648 L
.8 0 L
F
0 g
.75 0 m
.75 .01648 L
.8 .01648 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
000Ho`0008kooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Soooo
o`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo000Io`00
0:Gooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2koooo
o`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_o
oooo6Ol0000Fool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2koooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`006?l0002mooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_oo
ool00=?ooooo00?o0000ool00?oo00005?oo000Io`0001Koo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`006?l0003Dooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool001Wo0000jooo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00dooooolHo`0001Oooooo00?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3oooooo`;ooooo003oooooo`?ooooo6?l0003oooooo`Cooooo003oooooo`?ooooo
0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003V
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08
ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`Co0000oooooolHooooo`00j?oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@
00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000
ooooooooool0oooooolIooooo`00i_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_oo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_oo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_oo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00i_ooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000002Olb<S;ogMgMoooo
ooooooook^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>So
oooo00?o0000ooooooooool01_ooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMg
M`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01oooool0
1?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooo
oolIooooo`00j?ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000ooo
ool00ol0003oooooooooo`06ooooo`Co0000oooooolHooooo`00j?ooool00ol0003oooooooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000Sooooo
00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oeEEEOmV
IVKo000000Gooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000
oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000
oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOooool5
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08oooo
o`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`Co0000oooooolH
ooooo`00ioooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool0
0omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00jOooool01Ol0003ooooooooo
oooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Ko
oooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[ZjoooooonHV9So410@00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool0
0ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Gooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
0_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00
iOooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9So
oooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oiRHV?lQ8B7o
k^k^00Wooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`06ooooo`Co0000oooo
oolHooooo`00ioooool00onHV9So8B4Qonk^kP07ooooo`05ogMgMolb<S;oooooooooool000000ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?oMgMg
ofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooooooooooooooo
o`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooo
ooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWo
oooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0
003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol@413o^[Zjoooooomg
MgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`05o`000?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01_ooool00ol0
003oooooooooo`3ooooooaWooooo003Xooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool4o`000?oooooo6?ooool0
0>Oooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`00003oooooobCooooo003Xooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@
oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100oooooolTooooo`00iOoo
ool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0oooooolTooooo`00iOooool01OnYZJWo410@o`000?l@413oZJVY
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0oooo
oolTooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00
oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooo
oaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00moooool2o`0000_ooooo00?o
0000okZj^_ooool03?ooool2o`000?oooooo2Oooool00?Oooooo00?o0000ooooooooool02_ooool2
oc8b<Pkooooo00?o0000ooooooooool0ooooool7ooooo`00joooool01?l@413o0000o`000?ooool2
o`000003oa0@4?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000ooo
ool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X01?ooool00ol0003ooooo
ooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool02_l0003ooooo
ooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o410@00Cooooo00Go
410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00CogMgMo`000?l@413o
c<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@
413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>co
oooo1Ol00006ooooo`03o`000?oooooooooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000oooooooo
ooooooooo`000006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000Sooooo00?o410@
o`000?l000000ol00005ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@
ooooooooool00oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`000?oooooo2Oooool0
0?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00001\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .09477 L
.4 .09477 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .09477 L
.4 .09477 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .15039 L
.45 .15039 L
.45 0 L
F
0 g
.4 0 m
.4 .15039 L
.45 .15039 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .15245 L
.5 .15245 L
.5 0 L
F
0 g
.45 0 m
.45 .15245 L
.5 .15245 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .16893 L
.55 .16893 L
.55 0 L
F
0 g
.5 0 m
.5 .16893 L
.55 .16893 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .13803 L
.6 .13803 L
.6 0 L
F
0 g
.55 0 m
.55 .13803 L
.6 .13803 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .13391 L
.65 .13391 L
.65 0 L
F
0 g
.6 0 m
.6 .13391 L
.65 .13391 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .08858 L
.7 .08858 L
.7 0 L
F
0 g
.65 0 m
.65 .08858 L
.7 .08858 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .09064 L
.75 .09064 L
.75 0 L
F
0 g
.7 0 m
.7 .09064 L
.75 .09064 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .01236 L
.8 .01236 L
.8 0 L
F
0 g
.75 0 m
.75 .01236 L
.8 .01236 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo000Ho`0008kooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xooo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo000Ho`0001Ooo`0000?o0000ooooooooool0Xoooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool05?oooolIo`000:Gooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo002k
oooooaWo00005_oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Boooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3B
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`006?l0003Dooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool001Wo0000joooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00dooooolHo`00
01Ooo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003ZoooooaWo
00005_oo00000ol0003oooooooooo`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3oooooo`;ooooo003oooooo`?ooooo6?l0003oooooo`Cooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00i_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?oo
ool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool4o`000?oooooo
6?ooool00>Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08
ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Kooooo1?l000001Ol@413oooooooooooooooooA4A400;o000000Wo
<S8bomgMgOooooooooooonk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Xooooo`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9So
oooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooo
oooo00Oooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`06ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool01OmgMgOo<S8boooooooo
oooo000000?ooooo00?o0000ooooooooool01_ooool4o`000?oooooo6?ooool00>Sooooo00?o0000
ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooooooooooooooo
o`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_oo
ool00omEEEGoIVIVo`000005ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Gooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So8B4Qonk^
k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oiRHV?lQ8B7ok^k^00Co
oooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?ooool4
o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Sooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00Go
0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go0000okZj^_oooooo
V9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lQ8B7o
c<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`Go00001?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`09ogMgMolb<S;ooooooooo
oomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool0
0onHV9So8B4Qonk^kP09ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool01_oo
ool4o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h01oooool01OmgMgOo<S8boooooooo
oooo000000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003X
ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00Sooooo
00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo
00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000oooooooo
ool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003o
oooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003o
oooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05
oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go410@
okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00jOooool01Ol0003ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo
00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00onYZJWo410@ooooo`02ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo1?l0003o
oooooaSooooo003Wooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool00000oooooolTooooo`00j?ooool00onj^[[o8B4Qooooo`02
ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@0?oooooo
9?ooool00>Gooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?oooooo9?ooool00>Gooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^0?oooooo9?ooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooo
oooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool0
0?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?Oooooo0_l0
000;ooooo`03o`000?nj^[[ooooo00cooooo0_l0003oooooo`Wooooo003gooooo`03o`000?oooooo
oooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo0?oooooo1oooool00>_ooooo00Co410@o`00
0?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00000_oo
ool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo
00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo
00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@
4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003oooooooooo`3oooooo`Oooooo
003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`04omgM
gOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oo
oooo003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`04
onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooo
o`Oooooo003/ooooo`Go00001_ooool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b
<P_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05
o`000?ooooooooooooooool000001_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l00008
ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0003oooooooooo`3oooooo`Oooooo003/oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00joooool01?l@413o0000o`000?ooool2
o`000003oa0@4?oooooooooo00?ooooo0_l0000Booooo`03o`000?oooooooooo00Gooooo0_l0003o
ooooo`Wooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo
0000\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .06592 L
.4 .06592 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .06592 L
.4 .06592 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .16275 L
.45 .16275 L
.45 0 L
F
0 g
.4 0 m
.4 .16275 L
.45 .16275 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .15039 L
.5 .15039 L
.5 0 L
F
0 g
.45 0 m
.45 .15039 L
.5 .15039 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .17717 L
.55 .17717 L
.55 0 L
F
0 g
.5 0 m
.5 .17717 L
.55 .17717 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .15451 L
.6 .15451 L
.6 0 L
F
0 g
.55 0 m
.55 .15451 L
.6 .15451 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .11949 L
.65 .11949 L
.65 0 L
F
0 g
.6 0 m
.6 .11949 L
.65 .11949 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .09889 L
.7 .09889 L
.7 0 L
F
0 g
.65 0 m
.65 .09889 L
.7 .09889 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .08858 L
.75 .08858 L
.75 0 L
F
0 g
.7 0 m
.7 .08858 L
.75 .08858 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .01236 L
.8 .01236 L
.8 0 L
F
0 g
.75 0 m
.75 .01236 L
.8 .01236 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo000Ho`0008kooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0:?ooooo002koooooaWo00005_oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2S
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo000Io`000:Go
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo000Ho`000;gooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_oo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`006?l0003Dooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOoo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`00
01Coo`006Ol0000Fool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo000Io`000>_ooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003CoooooaSo00005oooool00ol0003o
o`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000D
ool00003o`000?oooooooooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0?oooooo0_ooool00?oooooo0ooooolHo`000?oooooo1?ooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo
6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo1?l00000
2?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000
ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooo
oolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000Sooooo1?l0003ooooooaSooooo003Xooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0
003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3o
oooooaWooooo003Vooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003V
ooooo`Co000000Go410@ooooooooooooooooodA4A002o`000009oc8b<_oMgMgoooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003o
ooooooooo`06ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o
0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`07ooooo`04o`000?oooooo
oooooa0@40?ooooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003X
ooooo`03o`000?oooooooooo00Kooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oo
oooooooo00Kooooo1?l0003ooooooaSooooo003Xooooo`03o`000?oooooooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oEEEEofIVI_l000001Ooo
ool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`Go00000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00i_ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?oooooooooooooo
ool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo1?l0003ooooooaSooooo003Woooo
o`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`05o`000?ooooooooooooooool@4100
0oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01_ooool00ol0003o
ooooooooo`3ooooooaWooooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo
6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00iOooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMg
M`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^k^h02Oooool0
1?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00Kooooo1?l0003ooooooaSooooo003W
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00omgMgOoIVIVooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000Sooooo
00?o0000ooooooooool0oooooolIooooo`00jOooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Gooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lb<S;oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?oo
ool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oa0@4?nj^[[oooooogMgMolb<S800ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03
o`000?oooooooooo0?oooooo6Oooool00>Wooooo00Go0000oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Sooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000008ooooo`Co0000oooooolHooooo`00ioooool00ol@
413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo00000?oooooo9?ooool00>Sooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooo
oooo410@00?ooooo00Go410@oooooooooooooooooa0@403oooooobCooooo003Uooooo`05oa0@4?nH
V9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`3oooooobCooooo003Uooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP3oooooobCooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo
7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oo
oooooooooolOooooo`00oooooooooooooaoooooo003gooooo`;o00002oooool00ol0003o^[Zjoooo
o`0<ooooo`;o0000ooooool9ooooo`00moooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool0
0ol0003oooooooooo`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@
ooooooooool00oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0
003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo0?oooooo
1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`0:o`000?ooooooooooooooooo^
k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^
k_mgMgOo410@00Cooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool5o`0000Ko
oooo00?o0000ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo0000
00Kooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003
o`0000Gooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo0?oooooo1oooool00>_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03
ooooo`;o00004_ooool00ol0003oooooooooo`05ooooo`;o0000ooooool9ooooo`00oooooooooooo
oaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .07416 L
.4 .07416 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .07416 L
.4 .07416 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .15657 L
.45 .15657 L
.45 0 L
F
0 g
.4 0 m
.4 .15657 L
.45 .15657 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .15451 L
.5 .15451 L
.5 0 L
F
0 g
.45 0 m
.45 .15451 L
.5 .15451 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .17305 L
.55 .17305 L
.55 0 L
F
0 g
.5 0 m
.5 .17305 L
.55 .17305 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .15863 L
.6 .15863 L
.6 0 L
F
0 g
.55 0 m
.55 .15863 L
.6 .15863 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .14215 L
.65 .14215 L
.65 0 L
F
0 g
.6 0 m
.6 .14215 L
.65 .14215 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .10095 L
.7 .10095 L
.7 0 L
F
0 g
.65 0 m
.65 .10095 L
.7 .10095 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .05974 L
.75 .05974 L
.75 0 L
F
0 g
.7 0 m
.7 .05974 L
.75 .05974 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .0103 L
.8 .0103 L
.8 0 L
F
0 g
.75 0 m
.75 .0103 L
.8 .0103 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo000Ho`0008kooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00
^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Soooo
o`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2S
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool001Wo0000YOoo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo6Ol0000Fool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2koooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2k
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`006?l0002mooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_oo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Boooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo000Ho`000=Cooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo
00?o0000ool00?oo00005?oo000Io`0001Koo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`3Yooooo`00dooooolHo`0001Oooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0>Wooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo000I
o`000>_ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3ooooo
o`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;o
oooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo
003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003o
ooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003ooooo
o`?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003oooooo`?o
oooo6?l0003oooooo`Cooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo1?l000002?l@413oooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolI
ooooo`00j?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool0
1Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000Sooooo1?l0003ooooooaSooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Voooo
o`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`Co000000Go410@
ooooooooooooooooodA4A002o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`06ooooo`09
ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooo
oolIooooo`00j?ooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooooa0@40?ooooo00?o
410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooo
oooo00Kooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo1?l0
003ooooooaSooooo003Xooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c002ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo
003Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Kooooo00?oEEEEofIVI_l000001Oooool4o`0000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oo
oooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00i_ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@00Sooooo1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?oo
ool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ogMgMomVIVKooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Yooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWo
oooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o
0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o
0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o
0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOoo
ool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^k^h02Oooool01?l0003oooooooooool@
4103ooooo`03oa0@4?oooooooooo00Kooooo1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7o
k^k^00Oooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0oooooolIooooo`00j?ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
oooooolIooooo`00jOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go
410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go
0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c004ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`00
0?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`00
0?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003ooooooooo
o`3ooooooaWooooo003Uooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Wooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>So
oooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000008ooooo`Co0000oooooolHooooo`00ioooool00ol@413o0000okZj^P03oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo00000?oooooo9?oo
ool00>Sooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@403oooooobCooooo003Uooooo`05oa0@4?nHV9SooooookZj^_l00000
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`3ooooo
obCooooo003Uooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP3oooooobCooooo003ooooooooooooo7oooool0
0?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooo
oolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00
oooooooooooooaoooooo003gooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o0000oooo
ool9ooooo`00moooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`3o
ooooo`Oooooo003[ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool0
1?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00Go
V9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go
0000ooooooooooooooooo`000006ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o
0000omgMg@?ooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo
00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool5o`0000Kooooo00?o0000oooooooo
ool00_ooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooo
oooooooooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Gooooo00?o0000
ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool0
0>_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`;o00004_ooool0
0ol0003oooooooooo`05ooooo`;o0000ooooool9ooooo`00oooooooooooooaoooooo003ooooooooo
oooo7oooool00?oooooooooooolOooooo`00\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .07622 L
.4 .07622 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .07622 L
.4 .07622 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .19777 L
.45 .19777 L
.45 0 L
F
0 g
.4 0 m
.4 .19777 L
.45 .19777 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .13185 L
.5 .13185 L
.5 0 L
F
0 g
.45 0 m
.45 .13185 L
.5 .13185 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .19365 L
.55 .19365 L
.55 0 L
F
0 g
.5 0 m
.5 .19365 L
.55 .19365 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .16275 L
.6 .16275 L
.6 0 L
F
0 g
.55 0 m
.55 .16275 L
.6 .16275 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .11125 L
.65 .11125 L
.65 0 L
F
0 g
.6 0 m
.6 .11125 L
.65 .11125 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .09271 L
.7 .09271 L
.7 0 L
F
0 g
.65 0 m
.65 .09271 L
.7 .09271 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .05356 L
.75 .05356 L
.75 0 L
F
0 g
.7 0 m
.7 .05356 L
.75 .05356 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .0103 L
.8 .0103 L
.8 0 L
F
0 g
.75 0 m
.75 .0103 L
.8 .0103 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo000Ho`0008kooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00
^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Soooo
o`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2S
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool001Wo0000YOooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^ooo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`2kooooo`00^ooooolIo`0001Koo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo000Ho`000;gooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_oo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo000Ho`000=Cooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wo
oooo003Cooooo`03o`000?oo003oo`0001Coo`006Ol0000Fool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Ooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOoo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo000Io`000>_ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oo
oooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Go
oooo6?l0003oooooo`Cooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
5Oooool00ol0003oooooooooo`3ooooooaWooooo003CoooooaSo00005oooool00ol0003ooooooooo
o`3ooooooaWooooo003Vooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>So
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`Co0000
oooooolHooooo`00j?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00
j?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00omEEEGoIVIVo`000004oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00i_ooool4o`000005oa0@4?oooooooooooooooom4A4@00_l0
00002Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool02OmgMgOo<S8booooooooooooMgMg
oiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000
ooooooooool01oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00Kooooo00?o
0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;o
ooooooooool000000oooool00ol0003oooooooooo`06ooooo`Co0000oooooolHooooo`00j?ooool0
0ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooo
oooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo
003Vooooo`03oeEEEOmVIVKo000000Gooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_oo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00iOooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^
k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008
ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooo
oolIooooo`00j?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00jOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[Zj
oooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo1Ol00004ooooo`05odA4A?l0
003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooooooo
ool0oooooolIooooo`00iOooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00WoMgMgoc8b<_oo
ooooooooogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003V
ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00Co0000oooooooooooo410@0oooool00ol@413ooooooooo
o`06ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP07ooooo`05ogMgMolb<S;o
ooooooooool000000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Sooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go
0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@4100
1?ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2
o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2
o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Go
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool0
1Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`05o`00
0?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooo
ooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ojVYZOl@413ooooo00;o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool4
o`000?oooooo6?ooool00>Oooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`00003oooooobCooooo003Xooooo`03okZj^_lQ8B7o
oooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100
oooooolTooooo`00iOooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0oooooolTooooo`00iOooool01OnYZJWo
410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h0oooooolTooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oo
oooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolO
ooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00mooo
ool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`000?oooooo2Oooool00?Oooooo00?o0000
ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool0ooooool7ooooo`00joooool01?l@
413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l0
0002ooooo`;o00000oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X0
1?ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool00000
1_ooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0
003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo0?oooooo
1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo
00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oo
oooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;o
oooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
0?oooooo1oooool00>cooooo1Ol00006ooooo`03o`000?oooooooooo00;ooooo00Co8B4QogMgMomg
MgOo<S8b2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>co
oooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2
o`0000Sooooo00?o410@o`000?l000000ol00005ooooo`03o`000?oooooooooo0?oooooo1oooool0
0>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o0000
ooooo`;o000000?o410@ooooooooool00oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2
o`000?oooooo2Oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo
7oooool00001\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .10713 L
.4 .10713 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .10713 L
.4 .10713 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .18541 L
.45 .18541 L
.45 0 L
F
0 g
.4 0 m
.4 .18541 L
.45 .18541 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .14421 L
.5 .14421 L
.5 0 L
F
0 g
.45 0 m
.45 .14421 L
.5 .14421 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .17717 L
.55 .17717 L
.55 0 L
F
0 g
.5 0 m
.5 .17717 L
.55 .17717 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .14833 L
.6 .14833 L
.6 0 L
F
0 g
.55 0 m
.55 .14833 L
.6 .14833 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .12979 L
.65 .12979 L
.65 0 L
F
0 g
.6 0 m
.6 .12979 L
.65 .12979 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .07416 L
.7 .07416 L
.7 0 L
F
0 g
.65 0 m
.65 .07416 L
.7 .07416 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .0515 L
.75 .0515 L
.75 0 L
F
0 g
.7 0 m
.7 .0515 L
.75 .0515 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .0103 L
.8 .0103 L
.8 0 L
F
0 g
.75 0 m
.75 .0103 L
.8 .0103 L
.8 0 L
.75 0 L
s
1 0 0 r
.8 0 m
.8 .00206 L
.85 .00206 L
.85 0 L
F
0 g
.8 0 m
.8 .00206 L
.85 .00206 L
.85 0 L
.8 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`006Ol0001Eooooo`04ob4Q8OmgMgOoMgMgoc8b<Qgo
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo06[ooooo0_l00002ooooo`;o00007?ooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0S?ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0S?ooool00;_ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool001So0000S_ooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xooo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00
^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo000Io`000:Gooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00
^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`006?l0002mooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00
^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Boooo
o`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^ooooolIo`00
01Koo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo000Ho`000=Cooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`006Ol0000Fool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`006Ol0003[ooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000D
ool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2oooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo
0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3o
ooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool05OoooolHo`000?oooooo1?ooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo0?oooooo6Oooool00=?ooooo6?l0000Gooooo`;o0000oooooolJooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool4o`000008oa0@4?oooooo
ooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0
003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3o
oooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003X
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000002?ooool4o`000?oooooo6?ooool00>Sooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03
o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0>Kooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo
6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo1?l00000
1Ol@413oooooooooooooooooA4A400;o000000Wo<S8bomgMgOooooooooooonk^k_lb<S;o0000oc8b
<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00Ko
oooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003ooooooooo
o`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo410@0ooo
ool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000
ooooooooool01_ooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool01_oo
ool4o`000?oooooo6?ooool00>Sooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05oa0@4?oo
ooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo
00?o0000ooooooooool0oooooolIooooo`00i_ooool00omEEEGoIVIVo`000005ooooo`Co00000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o
0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo1Ol00003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0
oooooolIooooo`00iOooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Vooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4003oooo
o`05oa0@4?ooooooooooooooool@41002?ooool4o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?oMgMgofIVI_ooool00_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Wooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@
4?ooooooooooooooool@41000oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Gooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolI
ooooo`00iOooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003Uooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A007ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o
0000ooooooooool0oooooolIooooo`00i_ooool00onHV9So8B4Qonk^kP09ooooo`04o`000?oooooo
oooooa0@40?ooooo00?o410@ooooooooool01_ooool4o`000?oooooo6?ooool00>Oooooo00?oV9RH
ob4Q8Oo^k^h01oooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ogMgMomVIVKooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Yooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOoo
ool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So410@
o`000?lQ8B7oc<c<00Cooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Gooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000oooooooo
ool0oooooolIooooo`00jOooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooooooooa0@4003ooooo`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIoooo
o`00j?ooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000Sooooo1?l0003ooooooaSooooo003Wooooo`03oa0@4?l0003o^[Zj
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000oooo
oolTooooo`00j?ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@0?oooooo9?ooool00>Gooooo00Go410@oiRHV?oooooo^[Zj
o`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
0?oooooo9?ooool00>Gooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^0?oooooo9?ooool00?oooooooooooolO
ooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooo
oooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoo
oooo003ooooooooooooo7oooool00?Oooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo0_l0
003oooooo`Wooooo003gooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oooooo
oooo0?oooooo1oooool00>_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03
ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X01?oo
ool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool0ooooool7ooooo`00k?oo
ool01Ol0003ooooooooooooooooo000000Kooooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7
okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@4100
1?ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`02ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`Go00001_ooool00ol0003o
ooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool01?l0
003oooooooooooooool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o000000?o00001Oooool0
0ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7
ooooo`00joooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo0_l0000B
ooooo`03o`000?oooooooooo00Gooooo0_l0003oooooo`Wooooo003ooooooooooooo7oooool00?oo
oooooooooolOooooo`00oooooooooooooaoooooo0000\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .07622 L
.4 .07622 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .07622 L
.4 .07622 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .17923 L
.45 .17923 L
.45 0 L
F
0 g
.4 0 m
.4 .17923 L
.45 .17923 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .12773 L
.5 .12773 L
.5 0 L
F
0 g
.45 0 m
.45 .12773 L
.5 .12773 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .20395 L
.55 .20395 L
.55 0 L
F
0 g
.5 0 m
.5 .20395 L
.55 .20395 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .17923 L
.6 .17923 L
.6 0 L
F
0 g
.55 0 m
.55 .17923 L
.6 .17923 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .12155 L
.65 .12155 L
.65 0 L
F
0 g
.6 0 m
.6 .12155 L
.65 .12155 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .08446 L
.7 .08446 L
.7 0 L
F
0 g
.65 0 m
.65 .08446 L
.7 .08446 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .04944 L
.75 .04944 L
.75 0 L
F
0 g
.7 0 m
.7 .04944 L
.75 .04944 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .00824 L
.8 .00824 L
.8 0 L
F
0 g
.75 0 m
.75 .00824 L
.8 .00824 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo000Ho`0008kooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xooo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`006Ol0
002Uooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^ooo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`2kooooo`00^ooooolIo`0001Koo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo000Ho`00
0;gooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_oo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool001So0000e?ooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`006Ol0000Fool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Go
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wo
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo
01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0>Wooooo003CoooooaSo00005oooool00ol0003oo`00ool0000D
ool001Wo0000joooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo
0?oooooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oo
oooo0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo
0_ooool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_oo
ool00?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool0
0?oooooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oo
oooo0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oooooo
0oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oooooo0ooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00>Kooooo1?l00000
2?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Sooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Xooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool0
0>Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@
oooooooooooooooooa0@4008oooooaSo0000ooooool4ooooo`00j?ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo
1?l0003ooooooaSooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWo
oooo003Xooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oeEEEOmVIVKo0000
00Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?oo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`Co000000Go410@ooooooooooooooooodA4
A002o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`06ooooo`09ogMgMolb<S;ooooooooo
oomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool0
0ol0003oooooooooo`07ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool01_oo
ool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00Kooooo00GoMgMg
oc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo1?l0003ooooooaSooooo003X
ooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00Sooooo
00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Kooooo00?oEEEEofIVI_l000001Oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooo
oolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003Uooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go
V9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00onHV9So
8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo
410@00Sooooo1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooooooo
o`3ooooooaWooooo003Xooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo
003Yooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?o
oooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05o`00
0?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOooool5o`0000Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool02OmgMgOo
<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Kooooo00?oV9RHob4Q8Oo^k^h02Oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oo
oooooooo00Kooooo1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^00Oooooo00GoMgMg
oc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooo
oolIooooo`00j?ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_oo
ool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00jOoo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooo
oa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go0000okZj^_ooooooV9RH
oa0@4004ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03
o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00iOooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003U
ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo
00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@
413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?oZJVYoa0@4?oo
ool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008
ooooo`Co0000oooooolHooooo`00ioooool00ol@413o0000okZj^P03ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo00000?oooooo9?ooool00>Sooooo00?o^[Zj
ob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooo
oa0@403oooooobCooooo003Uooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`3oooooobCooooo003Uooooo`05
ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP3oooooobCooooo003ooooooooooooo7oooool00?oooooooooooolOoooo
o`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooo
oooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo
003gooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o0000ooooool9ooooo`00moooool0
0ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`3oooooo`Oooooo003[oooo
o`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool01?l0003ooooooooooooo
ool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4
okZj^P04ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000oooooooooooooooo
o`000006ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo00?o
c<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000ooooooooool0
ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
0_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0ooooool7ooooo`00k?ooool5o`0000Kooooo00?o0000ooooooooool00_ooool01?lQ8B7o
MgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7oooo
o`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooooooo0_l00002
ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool0ooooool7
ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>_ooooo00Co410@o`00
0?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`;o00004_ooool00ol0003oooooooooo`05
ooooo`;o0000ooooool9ooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooo
oooooolOooooo`00\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .05356 L
.4 .05356 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .05356 L
.4 .05356 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .18129 L
.45 .18129 L
.45 0 L
F
0 g
.4 0 m
.4 .18129 L
.45 .18129 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .15245 L
.5 .15245 L
.5 0 L
F
0 g
.45 0 m
.45 .15245 L
.5 .15245 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .17305 L
.55 .17305 L
.55 0 L
F
0 g
.5 0 m
.5 .17305 L
.55 .17305 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .17099 L
.6 .17099 L
.6 0 L
F
0 g
.55 0 m
.55 .17099 L
.6 .17099 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .13391 L
.65 .13391 L
.65 0 L
F
0 g
.6 0 m
.6 .13391 L
.65 .13391 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .10507 L
.7 .10507 L
.7 0 L
F
0 g
.65 0 m
.65 .10507 L
.7 .10507 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .04326 L
.75 .04326 L
.75 0 L
F
0 g
.7 0 m
.7 .04326 L
.75 .04326 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .01648 L
.8 .01648 L
.8 0 L
F
0 g
.75 0 m
.75 .01648 L
.8 .01648 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
000Ho`0008kooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Soooo
o`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo000Io`00
0:Gooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0^oooool00;_ooooo6Ol0000Fool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2koooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2k
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`006?l0002mooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo000Ho`000=Cooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo000Io`0001Ko
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0E
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Y
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`00
01Coo`006Ol0003[ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Go
oooo6?l0003oooooo`Cooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
5Oooool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ooooooooool05Oooool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oooooooooo`3ooooooaWooooo003Coooo
oaSo00005oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00i_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xoooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo
ooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
2?ooool4o`000?oooooo6?ooool00>Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>So
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oEEEEofIV
I_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo1?l000001Ol@413ooooooooooooo
ooooA4A400;o000000Wo<S8bomgMgOooooooooooonk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0
003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_oo
ooooooooogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003X
ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo410@0oooool00ol@413ooooooooo
o`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool0
1OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool01_ooool4o`000?oooooo6?oo
ool00>Sooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go
0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0
oooooolIooooo`00i_ooool00omEEEGoIVIVo`000005ooooo`Co00000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Gooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOoo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03
oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooo
ooooool@41002?ooool4o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Sooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Wooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
41000oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo
00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnH
V9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[o
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[o
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[o
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`Go00001?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03
o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`09
ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooo
oolIooooo`00i_ooool00onHV9So8B4Qonk^kP09ooooo`04o`000?oooooooooooa0@40?ooooo00?o
410@ooooooooool01_ooool4o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h01oooool0
1OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`3ooooooaWooooo003Xooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c002ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo
003Yooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[Zjoooo
oonHV9So410@00Cooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00So
oooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lQ8B7oc<c<00Co
oooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003Uooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Gooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00
jOooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003oooo
o`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00onYZJWo
410@ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000Sooooo1?l0003ooooooaSooooo003Wooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000oooooolTooooo`00j?ooool0
0onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooo
oooooooo410@0?oooooo9?ooool00>Gooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?oooooo9?ooool00>Go
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^0?oooooo9?ooool00?oooooooooooolOooooo`00oooooooooooo
oaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo
7oooool00?Oooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo0_l0003oooooo`Wooooo003g
ooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo0?oooooo1oooool0
0>_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`04o`000?oooooo
ooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`00
0?m4A4Co^[Zj00Cooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooo
oooooooo000000Kooooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0ooo
ool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003ooooo
ooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`02ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`3oooooo`Oooooo003/ooooo`Go00001_ooool00ol0003oooooooooo`02ooooo`04
ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooo
o`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooooooool2
o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0003oooooooooo`3o
ooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00joooool01?l@
413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo0_l0000Booooo`03o`000?oooooo
oooo00Gooooo0_l0003oooooo`Wooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00
oooooooooooooaoooooo0000\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .0824 L
.4 .0824 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .0824 L
.4 .0824 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .17923 L
.45 .17923 L
.45 0 L
F
0 g
.4 0 m
.4 .17923 L
.45 .17923 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .12155 L
.5 .12155 L
.5 0 L
F
0 g
.45 0 m
.45 .12155 L
.5 .12155 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .18541 L
.55 .18541 L
.55 0 L
F
0 g
.5 0 m
.5 .18541 L
.55 .18541 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .15039 L
.6 .15039 L
.6 0 L
F
0 g
.55 0 m
.55 .15039 L
.6 .15039 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .10507 L
.65 .10507 L
.65 0 L
F
0 g
.6 0 m
.6 .10507 L
.65 .10507 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .11125 L
.7 .11125 L
.7 0 L
F
0 g
.65 0 m
.65 .11125 L
.7 .11125 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .0824 L
.75 .0824 L
.75 0 L
F
0 g
.7 0 m
.7 .0824 L
.75 .0824 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .01236 L
.8 .01236 L
.8 0 L
F
0 g
.75 0 m
.75 .01236 L
.8 .01236 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo000Ho`0008kooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xooo
ool00;_ooooo6Ol0000Fool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo000I
o`000:Gooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`006?l0000Fool00003o`000?oooooo
oooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?ooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool05?ooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool05?oooolHo`000;gooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0jOooool00=?ooooo00?o0000ool00?oo00005?oo000Io`0001Koo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Ooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOoo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo000Io`00
0>_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003o
o`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o
0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eoooo
o`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
5Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooo
oooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_oo
ool00=?ooooo6?l0000Gooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2
ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2oooo
o`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00
ooooool3oooooaSo0000ooooool4ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00i_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?oo
ool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool4o`000?oooooo
6?ooool00>Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08
ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Kooooo1?l000001Ol@413oooooooooooooooooA4A400;o000000Wo
<S8bomgMgOooooooooooonk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Xooooo`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9So
oooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooo
oooo00Oooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`06ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool01OmgMgOo<S8boooooooo
oooo000000?ooooo00?o0000ooooooooool01_ooool4o`000?oooooo6?ooool00>Sooooo00?o0000
ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooooooooooooooo
o`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_oo
ool00omEEEGoIVIVo`000005ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Gooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So8B4Qonk^
k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oiRHV?lQ8B7ok^k^00Co
oooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?ooool4
o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Sooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00Go
0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go0000okZj^_oooooo
V9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lQ8B7o
c<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`Go00001?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`09ogMgMolb<S;ooooooooo
oomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool0
0onHV9So8B4Qonk^kP09ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool01_oo
ool4o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h01oooool01OmgMgOo<S8boooooooo
oooo000000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003X
ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00Sooooo
00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo
00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000oooooooo
ool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003o
oooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003o
oooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05
oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go410@
okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00jOooool01Ol0003ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo
00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00onYZJWo410@ooooo`02ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo1?l0003o
oooooaSooooo003Wooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool00000oooooolTooooo`00j?ooool00onj^[[o8B4Qooooo`02
ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@0?oooooo
9?ooool00>Gooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?oooooo9?ooool00>Gooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^0?oooooo9?ooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooo
oooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool0
0?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?Oooooo0_l0
000;ooooo`03o`000?nj^[[ooooo00cooooo0_l0003oooooo`Wooooo003gooooo`03o`000?oooooo
oooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo0?oooooo1oooool00>_ooooo00Co410@o`00
0?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00000_oo
ool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo
00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo
00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@
4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003oooooooooo`3oooooo`Oooooo
003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`04omgM
gOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oo
oooo003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`04
onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooo
o`Oooooo003/ooooo`Go00001_ooool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b
<P_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05
o`000?ooooooooooooooool000001_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l00008
ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0003oooooooooo`3oooooo`Oooooo003/oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00joooool01?l@413o0000o`000?ooool2
o`000003oa0@4?oooooooooo00?ooooo0_l0000Booooo`03o`000?oooooooooo00Gooooo0_l0003o
ooooo`Wooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo
0000\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .07416 L
.4 .07416 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .07416 L
.4 .07416 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .17511 L
.45 .17511 L
.45 0 L
F
0 g
.4 0 m
.4 .17511 L
.45 .17511 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .12361 L
.5 .12361 L
.5 0 L
F
0 g
.45 0 m
.45 .12361 L
.5 .12361 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .18129 L
.55 .18129 L
.55 0 L
F
0 g
.5 0 m
.5 .18129 L
.55 .18129 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .16893 L
.6 .16893 L
.6 0 L
F
0 g
.55 0 m
.55 .16893 L
.6 .16893 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .10095 L
.65 .10095 L
.65 0 L
F
0 g
.6 0 m
.6 .10095 L
.65 .10095 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .11331 L
.7 .11331 L
.7 0 L
F
0 g
.65 0 m
.65 .11331 L
.7 .11331 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .07622 L
.75 .07622 L
.75 0 L
F
0 g
.7 0 m
.7 .07622 L
.75 .07622 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .01648 L
.8 .01648 L
.8 0 L
F
0 g
.75 0 m
.75 .01648 L
.8 .01648 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
000Ho`0008kooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Soooo
o`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2S
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo6Ol0000Fool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool001Wo
0000YOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^ooo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo000Ho`0001Koo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^ooo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`0Dooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`0DoooooaSo0000_Oooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00dooo
ool00ol0003oo`00ool0000Dool001Wo00005_oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Ooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOoo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
5Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo000I
o`000>_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0ooooool2ooooo`00dooooolHo`0001Oooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3o
ooooo`;ooooo003oooooo`?ooooo6?l0003oooooo`Cooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00i_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xoooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo
ooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
2?ooool4o`000?oooooo6?ooool00>Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>So
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oEEEEofIV
I_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo1?l000001Ol@413ooooooooooooo
ooooA4A400;o000000Wo<S8bomgMgOooooooooooonk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0
003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_oo
ooooooooogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003X
ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo410@0oooool00ol@413ooooooooo
o`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool0
1OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool01_ooool4o`000?oooooo6?oo
ool00>Sooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go
0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0
oooooolIooooo`00i_ooool00omEEEGoIVIVo`000005ooooo`Co00000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0
003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Gooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOoo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03
oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooo
ooooool@41002?ooool4o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Sooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Wooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
41000oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo
00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnH
V9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[o
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[o
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[o
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`Go00001?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03
o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`09
ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooo
oolIooooo`00i_ooool00onHV9So8B4Qonk^kP09ooooo`04o`000?oooooooooooa0@40?ooooo00?o
410@ooooooooool01_ooool4o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q8Oo^k^h01oooool0
1OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`3ooooooaWooooo003Xooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c002ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo
003Yooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[Zjoooo
oonHV9So410@00Cooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00So
oooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lQ8B7oc<c<00Co
oooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003Uooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Gooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00
jOooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003oooo
o`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00onYZJWo
410@ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000Sooooo1?l0003ooooooaSooooo003Wooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000oooooolTooooo`00j?ooool0
0onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooo
oooooooo410@0?oooooo9?ooool00>Gooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?oooooo9?ooool00>Go
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^0?oooooo9?ooool00?oooooooooooolOooooo`00oooooooooooo
oaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo
7oooool00?Oooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo0_l0003oooooo`Wooooo003g
ooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo0?oooooo1oooool0
0>_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`04o`000?oooooo
ooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`00
0?m4A4Co^[Zj00Cooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooo
oooooooo000000Kooooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0ooo
ool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003ooooo
ooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`02ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`3oooooo`Oooooo003/ooooo`Go00001_ooool00ol0003oooooooooo`02ooooo`04
ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooo
o`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooooooool2
o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0003oooooooooo`3o
ooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00joooool01?l@
413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo0_l0000Booooo`03o`000?oooooo
oooo00Gooooo0_l0003oooooo`Wooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00
oooooooooooooaoooooo0000\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .05974 L
.4 .05974 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .05974 L
.4 .05974 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .18335 L
.45 .18335 L
.45 0 L
F
0 g
.4 0 m
.4 .18335 L
.45 .18335 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .14421 L
.5 .14421 L
.5 0 L
F
0 g
.45 0 m
.45 .14421 L
.5 .14421 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .17099 L
.55 .17099 L
.55 0 L
F
0 g
.5 0 m
.5 .17099 L
.55 .17099 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .16893 L
.6 .16893 L
.6 0 L
F
0 g
.55 0 m
.55 .16893 L
.6 .16893 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .12979 L
.65 .12979 L
.65 0 L
F
0 g
.6 0 m
.6 .12979 L
.65 .12979 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .11537 L
.7 .11537 L
.7 0 L
F
0 g
.65 0 m
.65 .11537 L
.7 .11537 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .04738 L
.75 .04738 L
.75 0 L
F
0 g
.7 0 m
.7 .04738 L
.75 .04738 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .0103 L
.8 .0103 L
.8 0 L
F
0 g
.75 0 m
.75 .0103 L
.8 .0103 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo000Ho`0008kooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00
^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Soooo
o`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool001Wo0000YOooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0;_ooooo002koooooaWo00005_oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^ooo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool001So0000_Oooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo000Ho`000=Co
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo
003oo`0001Coo`006Ol0000Fool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOoo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
5Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo000I
o`000>_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05OoooolHo`00
0?oooooo1?ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
0?oooooo6Oooool00=?ooooo6?l0000Gooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Kooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o
0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo1?l0003ooooooaSooooo
003Xooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool0
0ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooo
oolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooo
oolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooo
oolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003Vooooo`Co000000Go410@ooooooooooooooooodA4A002o`000009oc8b<_oM
gMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00j?ooool00ol0003oooooooooo`06ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonH
V9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`07
ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool01_ooool00ol0003ooooooooo
o`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00Kooooo00GoMgMgoc8b<_ooooooooooo`00
0003ooooo`03o`000?oooooooooo00Kooooo1?l0003ooooooaSooooo003Xooooo`03o`000?oooooo
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool00000
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0
oooooolIooooo`00j?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?o
EEEEofIVI_l000001Oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003U
ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo1?l0003o
oooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003X
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`05o`000?oo
ooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooooooo
ool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@
41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08
ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00iOooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8b
omgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWo
oooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool02OmgMgOo<S8booooooooooooMgMg
oiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oV9RH
ob4Q8Oo^k^h02Oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00Kooooo1?l0
003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^00Oooooo00GoMgMgoc8b<_ooooooooooo`00
0003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool0
0omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooo
oooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00jOooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Gooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`00
0?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJ
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJ
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So
410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oa0@4?nj^[[o
ooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00Go0000oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`06oooo
o`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`Co0000oooooolH
ooooo`00ioooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo00000?oooooo9?ooool00>Sooooo00?o^[Zjob4Q8Oooool00_ooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@403oooooobCooooo
003Uooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`3oooooobCooooo003Uooooo`05ojVYZOl@413o0000oa0@
4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooobCooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoo
oooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooo
oooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003gooooo`;o00002ooo
ool00ol0003o^[Zjooooo`0<ooooo`;o0000ooooool9ooooo`00moooool00ol0003oooooooooo`0:
ooooo`;o<S8b3_ooool00ol0003oooooooooo`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o0000
ooooo`;o000000?o410@ooooooooool00oooool01?l0003oooooooooooooool2o`0000;ooooo0_l0
0003ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`00
0?oooooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`0:o`00
0?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo00?oc<c<o`000?l@41001?oo
ool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000ooooooooool0ooooool7ooooo`00k?oo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool01?oMgMgo0000
oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00
k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool01?o^k^ko
8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7oooo
o`00k?ooool5o`0000Kooooo00?o0000ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb<S8;oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003o
oooooooooooooooo000000Kooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00002?ooool0
0ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo0?oooooo1oooool00>_ooooo00Co410@o`000?l0003ooooo0_l00000
0ol@413oooooooooo`03ooooo`;o00004_ooool00ol0003oooooooooo`05ooooo`;o0000ooooool9
ooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .08034 L
.4 .08034 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .08034 L
.4 .08034 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .19159 L
.45 .19159 L
.45 0 L
F
0 g
.4 0 m
.4 .19159 L
.45 .19159 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .13597 L
.5 .13597 L
.5 0 L
F
0 g
.45 0 m
.45 .13597 L
.5 .13597 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .18129 L
.55 .18129 L
.55 0 L
F
0 g
.5 0 m
.5 .18129 L
.55 .18129 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .16687 L
.6 .16687 L
.6 0 L
F
0 g
.55 0 m
.55 .16687 L
.6 .16687 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .11743 L
.65 .11743 L
.65 0 L
F
0 g
.6 0 m
.6 .11743 L
.65 .11743 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .0824 L
.7 .0824 L
.7 0 L
F
0 g
.65 0 m
.65 .0824 L
.7 .0824 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .06592 L
.75 .06592 L
.75 0 L
F
0 g
.7 0 m
.7 .06592 L
.75 .06592 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .00824 L
.8 .00824 L
.8 0 L
F
0 g
.75 0 m
.75 .00824 L
.8 .00824 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo000Ho`0008kooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xooo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00
^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo000Io`000:Go
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00
^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002koooooaWo00005_oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^ooo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool001So0000_Oooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_oo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo000Ho`000=Cooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wo
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000D
ool001Wo00005_oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Ooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOoo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
5Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo
003oo`0001Coo`006Ol0003[ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooo
oooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_oo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oooooooooo01Gooooo6?l0003oooooo`Cooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ooooooooool05Oooool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool2o`000?oooooo6_ooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo0?oooooo6Oooool00=?ooooo6?l0000Gooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo1?l00000
2?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000
ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooo
oolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000Sooooo1?l0003ooooooaSooooo003Xooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0
003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3o
oooooaWooooo003Vooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003V
ooooo`Co000000Go410@ooooooooooooooooodA4A002o`000009oc8b<_oMgMgoooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003o
ooooooooo`06ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o
0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`07ooooo`04o`000?oooooo
oooooa0@40?ooooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003X
ooooo`03o`000?oooooooooo00Kooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oo
oooooooo00Kooooo1?l0003ooooooaSooooo003Xooooo`03o`000?oooooooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oEEEEofIVI_l000001Ooo
ool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`Go00000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00i_ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?oooooooooooooo
ool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo1?l0003ooooooaSooooo003Woooo
o`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`05o`000?ooooooooooooooool@4100
0oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01_ooool00ol0003o
ooooooooo`3ooooooaWooooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo
6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00iOooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMg
M`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^k^h02Oooool0
1?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00Kooooo1?l0003ooooooaSooooo003W
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00omgMgOoIVIVooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000Sooooo
00?o0000ooooooooool0oooooolIooooo`00jOooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Gooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lb<S;oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?oo
ool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oa0@4?nj^[[oooooogMgMolb<S800ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03
o`000?oooooooooo0?oooooo6Oooool00>Wooooo00Go0000oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Sooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000008ooooo`Co0000oooooolHooooo`00ioooool00ol@
413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo00000?oooooo9?ooool00>Sooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooo
oooo410@00?ooooo00Go410@oooooooooooooooooa0@403oooooobCooooo003Uooooo`05oa0@4?nH
V9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`3oooooobCooooo003Uooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP3oooooobCooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo
7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oo
oooooooooolOooooo`00oooooooooooooaoooooo003gooooo`;o00002oooool00ol0003o^[Zjoooo
o`0<ooooo`;o0000ooooool9ooooo`00moooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool0
0ol0003oooooooooo`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@
ooooooooool00oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0
003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo0?oooooo
1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`0:o`000?ooooooooooooooooo^
k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^
k_mgMgOo410@00Cooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool5o`0000Ko
oooo00?o0000ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo0000
00Kooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003
o`0000Gooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo0?oooooo1oooool00>_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03
ooooo`;o00004_ooool00ol0003oooooooooo`05ooooo`;o0000ooooool9ooooo`00oooooooooooo
oaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .09889 L
.4 .09889 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .09889 L
.4 .09889 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .16893 L
.45 .16893 L
.45 0 L
F
0 g
.4 0 m
.4 .16893 L
.45 .16893 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .14833 L
.5 .14833 L
.5 0 L
F
0 g
.45 0 m
.45 .14833 L
.5 .14833 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .19983 L
.55 .19983 L
.55 0 L
F
0 g
.5 0 m
.5 .19983 L
.55 .19983 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .15657 L
.6 .15657 L
.6 0 L
F
0 g
.55 0 m
.55 .15657 L
.6 .15657 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .11949 L
.65 .11949 L
.65 0 L
F
0 g
.6 0 m
.6 .11949 L
.65 .11949 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .06386 L
.7 .06386 L
.7 0 L
F
0 g
.65 0 m
.65 .06386 L
.7 .06386 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .05974 L
.75 .05974 L
.75 0 L
F
0 g
.7 0 m
.7 .05974 L
.75 .05974 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .01442 L
.8 .01442 L
.8 0 L
F
0 g
.75 0 m
.75 .01442 L
.8 .01442 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo000Ho`0008kooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xooo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00
^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo000Io`000:Gooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`006?l0002mooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Boooo
o`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3B
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3Booooo`00^ooooolIo`0001Koo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool001So
0000e?ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wo
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo000I
o`0001Koo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o
0000ool00?oo00005?oo000Io`000>_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0oooo
ool2ooooo`00dooooolHo`0001Oooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3o
ooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3ooooo
o`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;o
oooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo
003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003o
ooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003ooooo
o`?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003oooooo`?o
oooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003oooooo`?ooooo
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003oooooo`?ooooo00?o
0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003oooooo`?ooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3oooooo`;ooooo003Vooooo`Co000000So410@ooooooooooook^k^oc8b
<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08oooooaSo0000ooooool4oooo
o`00j?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo
1?l0003ooooooaSooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWo
oooo003Xooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oeEEEOmVIVKo0000
00Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?oo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`Co000000Go410@ooooooooooooooooodA4
A002o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`06ooooo`09ogMgMolb<S;ooooooooo
oomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool0
0ol0003oooooooooo`07ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool01_oo
ool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00Kooooo00GoMgMg
oc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo1?l0003ooooooaSooooo003X
ooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00Sooooo
00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Kooooo00?oEEEEofIVI_l000001Oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooo
oolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003Uooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go
V9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00onHV9So
8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo
410@00Sooooo1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooooooo
o`3ooooooaWooooo003Xooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo
003Yooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?o
oooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05o`00
0?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOooool5o`0000Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool02OmgMgOo
<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Kooooo00?oV9RHob4Q8Oo^k^h02Oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oo
oooooooo00Kooooo1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^00Oooooo00GoMgMg
oc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooo
oolIooooo`00j?ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_oo
ool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00jOoo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooo
oa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go0000okZj^_ooooooV9RH
oa0@4004ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03
o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00iOooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003U
ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo
00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@
413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?oZJVYoa0@4?oo
ool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008
ooooo`Co0000oooooolHooooo`00ioooool00ol@413o0000okZj^P03ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo00000?oooooo9?ooool00>Sooooo00?o^[Zj
ob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooo
oa0@403oooooobCooooo003Uooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`3oooooobCooooo003Uooooo`05
ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP3oooooobCooooo003ooooooooooooo7oooool00?oooooooooooolOoooo
o`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooo
oooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo
003gooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o0000ooooool9ooooo`00moooool0
0ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`3oooooo`Oooooo003[oooo
o`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool01?l0003ooooooooooooo
ool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4
okZj^P04ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000oooooooooooooooo
o`000006ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo00?o
c<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000ooooooooool0
ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
0_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0ooooool7ooooo`00k?ooool5o`0000Kooooo00?o0000ooooooooool00_ooool01?lQ8B7o
MgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7oooo
o`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooooooo0_l00002
ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool0ooooool7
ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>_ooooo00Co410@o`00
0?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`;o00004_ooool00ol0003oooooooooo`05
ooooo`;o0000ooooool9ooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooo
oooooolOooooo`00\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .08652 L
.4 .08652 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .08652 L
.4 .08652 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .17511 L
.45 .17511 L
.45 0 L
F
0 g
.4 0 m
.4 .17511 L
.45 .17511 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .14421 L
.5 .14421 L
.5 0 L
F
0 g
.45 0 m
.45 .14421 L
.5 .14421 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .17717 L
.55 .17717 L
.55 0 L
F
0 g
.5 0 m
.5 .17717 L
.55 .17717 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .16481 L
.6 .16481 L
.6 0 L
F
0 g
.55 0 m
.55 .16481 L
.6 .16481 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .13391 L
.65 .13391 L
.65 0 L
F
0 g
.6 0 m
.6 .13391 L
.65 .13391 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .09064 L
.7 .09064 L
.7 0 L
F
0 g
.65 0 m
.65 .09064 L
.7 .09064 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .04738 L
.75 .04738 L
.75 0 L
F
0 g
.7 0 m
.7 .04738 L
.75 .04738 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .00824 L
.8 .00824 L
.8 0 L
F
0 g
.75 0 m
.75 .00824 L
.8 .00824 L
.8 0 L
.75 0 L
s
1 0 0 r
.8 0 m
.8 .00206 L
.85 .00206 L
.85 0 L
F
0 g
.8 0 m
.8 .00206 L
.85 .00206 L
.85 0 L
.8 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`006Ol0001Eooooo`04ob4Q8OmgMgOoMgMgoc8b<Qgo
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo06[ooooo0_l00002ooooo`;o00007?ooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0S?ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool001So0000S_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool001Wo0000YOooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00
^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2koooo
o`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_o
oooo6Ol0000Fool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
6?l0002mooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_oo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`006?l0
003Dooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`006Ol0000Fool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo
01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eoooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yoooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool001Wo0000
joooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3o
ooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0ooooool2ooooo`00dooooolHo`0001Oooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3oooooo`;ooooo003oooooo`?ooooo6?l0003oooooo`Cooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`Co000000So410@
ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08oooo
o`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000008ooooo`Co0000oooooolHooooo`00j?ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000So
oooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolI
ooooo`00i_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000
oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool4
o`000005oa0@4?oooooooooooooooom4A4@00_l000002Olb<S;ogMgMooooooooooook^k^oc8b<_l0
003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000oooooooo
ool01_ooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01oooool01?l0003oooooooooool@
4103ooooo`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool0
0ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003ooooooooo
o`06ooooo`Co0000oooooolHooooo`00j?ooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
oooooolIooooo`00j?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go
410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oeEEEOmVIVKo000000Gooooo1?l0
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOooool5o`0000?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`Co0000oooooolHooooo`00ioooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00omgMgOoIVIVooooo`02
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo
00?o0000ooooooooool0oooooolIooooo`00jOooool01Ol0003ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooolIooooo`00iOooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3o
oooooaWooooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Gooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So8B4Q
onk^k_ooooooA4A400Oooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL02?oo
ool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oiRHV?lQ8B7ok^k^00Wooooo00Co0000
oooooooooooo410@0oooool00ol@413oooooooooo`06ooooo`Co0000oooooolHooooo`00ioooool0
0onHV9So8B4Qonk^kP07ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?oMgMgofIVI_ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Wooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo
003Uooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`04ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o<S8bolc<c003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o
0000ooooooooool0oooooolIooooo`00iOooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Yooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@00?ooooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooo
oaWooooo003Xooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000002?ooool4o`000?oooooo6?ooool00>Oooooo00?o410@o`00
0?nj^[X00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
003oooooobCooooo003Xooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100oooooolTooooo`00iOooool01Ol@413oV9RHoooo
oonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL0oooooolTooooo`00iOooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0oooooolTooooo`00oooooooo
oooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo
003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooo
oooo7oooool00?oooooooooooolOooooo`00moooool2o`0000_ooooo00?o0000okZj^_ooool03?oo
ool2o`000?oooooo2Oooool00?Oooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000
ooooooooool0ooooool7ooooo`00joooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooo
oooo00?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000oooool00on7QhOo0000okZj
^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X01?ooool00ol0003oooooooooo`3oooooo`Oooooo
003/ooooo`05o`000?ooooooooooooooool000001_ooool02_l0003oooooooooooooooook^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMg
oa0@4004ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo00;ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo1Ol00006ooooo`03
o`000?oooooooooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006oooo
o`04o`000?ooooooooooooooo`;o00000_ooool2o`0000Sooooo00?o410@o`000?l000000ol00005
ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3o
ooooo`Oooooo003[ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool2
o`0001;ooooo00?o0000ooooooooool01Oooool2o`000?oooooo2Oooool00?oooooooooooolOoooo
o`00oooooooooooooaoooooo003ooooooooooooo7oooool00001\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .06798 L
.4 .06798 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .06798 L
.4 .06798 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .16687 L
.45 .16687 L
.45 0 L
F
0 g
.4 0 m
.4 .16687 L
.45 .16687 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .15451 L
.5 .15451 L
.5 0 L
F
0 g
.45 0 m
.45 .15451 L
.5 .15451 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .18953 L
.55 .18953 L
.55 0 L
F
0 g
.5 0 m
.5 .18953 L
.55 .18953 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .16275 L
.6 .16275 L
.6 0 L
F
0 g
.55 0 m
.55 .16275 L
.6 .16275 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .10301 L
.65 .10301 L
.65 0 L
F
0 g
.6 0 m
.6 .10301 L
.65 .10301 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .12155 L
.7 .12155 L
.7 0 L
F
0 g
.65 0 m
.65 .12155 L
.7 .12155 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .04944 L
.75 .04944 L
.75 0 L
F
0 g
.7 0 m
.7 .04944 L
.75 .04944 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .01442 L
.8 .01442 L
.8 0 L
F
0 g
.75 0 m
.75 .01442 L
.8 .01442 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo000Ho`0008kooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xooo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`006Ol0
002Uooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^ooo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0^oooool00;_ooooo6Ol0000Fool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2koooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2k
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool001So00005_oo
00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo01Co
oooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o
0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2k
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo6?l0002mooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wo
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo
00?o0000ool00?oo00005?oo000Io`0001Koo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo000Io`000>_ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0?oooooo0_ooool00=?ooooo6?l0000Gooooo`03o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0oooo
ool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2
ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2oooo
o`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00
ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00oooo
ool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3
oooooaSo0000ooooool4ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo1?l00000
2?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000
ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooo
oolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000Sooooo1?l0003ooooooaSooooo003Xooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0
003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3o
oooooaWooooo003Vooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003V
ooooo`Co000000Go410@ooooooooooooooooodA4A002o`000009oc8b<_oMgMgoooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003o
ooooooooo`06ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o
0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`07ooooo`04o`000?oooooo
oooooa0@40?ooooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003X
ooooo`03o`000?oooooooooo00Kooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oo
oooooooo00Kooooo1?l0003ooooooaSooooo003Xooooo`03o`000?oooooooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oEEEEofIVI_l000001Ooo
ool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`Go00000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00i_ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?oooooooooooooo
ool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo1?l0003ooooooaSooooo003Woooo
o`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`05o`000?ooooooooooooooool@4100
0oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01_ooool00ol0003o
ooooooooo`3ooooooaWooooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo
6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00iOooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMg
M`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^k^h02Oooool0
1?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00Kooooo1?l0003ooooooaSooooo003W
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00omgMgOoIVIVooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000Sooooo
00?o0000ooooooooool0oooooolIooooo`00jOooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Gooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lb<S;oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?oo
ool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oa0@4?nj^[[oooooogMgMolb<S800ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03
o`000?oooooooooo0?oooooo6Oooool00>Wooooo00Go0000oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Sooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000008ooooo`Co0000oooooolHooooo`00ioooool00ol@
413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo00000?oooooo9?ooool00>Sooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooo
oooo410@00?ooooo00Go410@oooooooooooooooooa0@403oooooobCooooo003Uooooo`05oa0@4?nH
V9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`3oooooobCooooo003Uooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP3oooooobCooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo
7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oo
oooooooooolOooooo`00oooooooooooooaoooooo003gooooo`;o00002oooool00ol0003o^[Zjoooo
o`0<ooooo`;o0000ooooool9ooooo`00moooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool0
0ol0003oooooooooo`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@
ooooooooool00oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0
003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo0?oooooo
1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`0:o`000?ooooooooooooooooo^
k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^
k_mgMgOo410@00Cooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool5o`0000Ko
oooo00?o0000ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo0000
00Kooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003
o`0000Gooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo0?oooooo1oooool00>_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03
ooooo`;o00004_ooool00ol0003oooooooooo`05ooooo`;o0000ooooool9ooooo`00oooooooooooo
oaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .08446 L
.4 .08446 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .08446 L
.4 .08446 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .15657 L
.45 .15657 L
.45 0 L
F
0 g
.4 0 m
.4 .15657 L
.45 .15657 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .14215 L
.5 .14215 L
.5 0 L
F
0 g
.45 0 m
.45 .14215 L
.5 .14215 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .16275 L
.55 .16275 L
.55 0 L
F
0 g
.5 0 m
.5 .16275 L
.55 .16275 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .17099 L
.6 .17099 L
.6 0 L
F
0 g
.55 0 m
.55 .17099 L
.6 .17099 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .12361 L
.65 .12361 L
.65 0 L
F
0 g
.6 0 m
.6 .12361 L
.65 .12361 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .09271 L
.7 .09271 L
.7 0 L
F
0 g
.65 0 m
.65 .09271 L
.7 .09271 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .0824 L
.75 .0824 L
.75 0 L
F
0 g
.7 0 m
.7 .0824 L
.75 .0824 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .01442 L
.8 .01442 L
.8 0 L
F
0 g
.75 0 m
.75 .01442 L
.8 .01442 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo000Ho`0008kooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xooo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00
^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Soooo
o`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool001Wo0000YOooool0
0;_ooooo6Ol0000Fool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`006?l0
002mooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`006?l0003Dooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Y
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo0000
5?oo000Io`0001Koo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Go
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wo
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo6?l0
000Gooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3oooooaSo00005ooo00000ol0003o
ooooooooo`3Yooooo`00ooooool3ooooo`;o00005Oooool00ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0>Wooooo003oooooo`?ooooo00?o0000ooooooooool05?ooool00ol0003oo`00ool0
000Eool00003o`000?oooooooooo0>Wooooo003oooooo`?ooooo00?o0000ooooooooool05?ooool0
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003oooooo`?ooooo00?o0000oooo
ooooool05?oooolIo`000>_ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003Vooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>So
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`Co0000
oooooolHooooo`00j?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00
j?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00omEEEGoIVIVo`000004oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00i_ooool4o`000005oa0@4?oooooooooooooooom4A4@00_l0
00002Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool02OmgMgOo<S8booooooooooooMgMg
oiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000
ooooooooool01oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00Kooooo00?o
0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;o
ooooooooool000000oooool00ol0003oooooooooo`06ooooo`Co0000oooooolHooooo`00j?ooool0
0ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooo
oooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo
003Vooooo`03oeEEEOmVIVKo000000Gooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_oo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00iOooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^
k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008
ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooo
oolIooooo`00j?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00jOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[Zj
oooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo1Ol00004ooooo`05odA4A?l0
003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooooooo
ool0oooooolIooooo`00iOooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00WoMgMgoc8b<_oo
ooooooooogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003V
ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00Co0000oooooooooooo410@0oooool00ol@413ooooooooo
o`06ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP07ooooo`05ogMgMolb<S;o
ooooooooool000000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Sooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go
0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@4100
1?ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2
o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2
o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Go
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool0
1Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`05o`00
0?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooo
ooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ojVYZOl@413ooooo00;o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool4
o`000?oooooo6?ooool00>Oooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`00003oooooobCooooo003Xooooo`03okZj^_lQ8B7o
oooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100
oooooolTooooo`00iOooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0oooooolTooooo`00iOooool01OnYZJWo
410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h0oooooolTooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oo
oooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolO
ooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00mooo
ool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`000?oooooo2Oooool00?Oooooo00?o0000
ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool0ooooool7ooooo`00joooool01?l@
413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l0
0002ooooo`;o00000oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X0
1?ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool00000
1_ooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0
003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo0?oooooo
1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo
00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oo
oooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;o
oooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
0?oooooo1oooool00>cooooo1Ol00006ooooo`03o`000?oooooooooo00;ooooo00Co8B4QogMgMomg
MgOo<S8b2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>co
oooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2
o`0000Sooooo00?o410@o`000?l000000ol00005ooooo`03o`000?oooooooooo0?oooooo1oooool0
0>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o0000
ooooo`;o000000?o410@ooooooooool00oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2
o`000?oooooo2Oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo
7oooool00001\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .05768 L
.4 .05768 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .05768 L
.4 .05768 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .18129 L
.45 .18129 L
.45 0 L
F
0 g
.4 0 m
.4 .18129 L
.45 .18129 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .14009 L
.5 .14009 L
.5 0 L
F
0 g
.45 0 m
.45 .14009 L
.5 .14009 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .17305 L
.55 .17305 L
.55 0 L
F
0 g
.5 0 m
.5 .17305 L
.55 .17305 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .15451 L
.6 .15451 L
.6 0 L
F
0 g
.55 0 m
.55 .15451 L
.6 .15451 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .13185 L
.65 .13185 L
.65 0 L
F
0 g
.6 0 m
.6 .13185 L
.65 .13185 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .10301 L
.7 .10301 L
.7 0 L
F
0 g
.65 0 m
.65 .10301 L
.7 .10301 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .07622 L
.75 .07622 L
.75 0 L
F
0 g
.7 0 m
.7 .07622 L
.75 .07622 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .01236 L
.8 .01236 L
.8 0 L
F
0 g
.75 0 m
.75 .01236 L
.8 .01236 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo000Ho`0008kooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo6Ol0000Fool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xooo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo000Io`000:Gooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo000Ho`000;gooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool001So0000e?ooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo000Io`0001Koo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Ooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOoo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`0Eooooo`03o`000?oo003oo`0001Coo`006Ol0003[ooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Go
oooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0EoooooaSo0000ooooool4ooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ooooooooool0
oooooolIooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o
0000ooooooooool0oooooolIooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0oooooolIooooo`00dooooolHo`0001Oooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Kooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o
0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo1?l0003ooooooaSooooo
003Xooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool0
0ol0003oooooooooo`3ooooooaWooooo003Vooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooo
oolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooo
oolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooo
oolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003Vooooo`Co000000Go410@ooooooooooooooooodA4A002o`000009oc8b<_oM
gMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00j?ooool00ol0003oooooooooo`06ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonH
V9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`07
ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool01_ooool00ol0003ooooooooo
o`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00Kooooo00GoMgMgoc8b<_ooooooooooo`00
0003ooooo`03o`000?oooooooooo00Kooooo1?l0003ooooooaSooooo003Xooooo`03o`000?oooooo
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool00000
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0
oooooolIooooo`00j?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?o
EEEEofIVI_l000001Oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003U
ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo1?l0003o
oooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003X
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`05o`000?oo
ooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooooooo
ool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@
41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08
ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00iOooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8b
omgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWo
oooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool02OmgMgOo<S8booooooooooooMgMg
oiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oV9RH
ob4Q8Oo^k^h02Oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00Kooooo1?l0
003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^00Oooooo00GoMgMgoc8b<_ooooooooooo`00
0003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool0
0omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooo
oooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00jOooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Gooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`00
0?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJ
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJ
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So
410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oa0@4?nj^[[o
ooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00Go0000oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`06oooo
o`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`Co0000oooooolH
ooooo`00ioooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo00000?oooooo9?ooool00>Sooooo00?o^[Zjob4Q8Oooool00_ooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@403oooooobCooooo
003Uooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`3oooooobCooooo003Uooooo`05ojVYZOl@413o0000oa0@
4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP3oooooobCooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoo
oooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooo
oooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003gooooo`;o00002ooo
ool00ol0003o^[Zjooooo`0<ooooo`;o0000ooooool9ooooo`00moooool00ol0003oooooooooo`0:
ooooo`;o<S8b3_ooool00ol0003oooooooooo`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o0000
ooooo`;o000000?o410@ooooooooool00oooool01?l0003oooooooooooooool2o`0000;ooooo0_l0
0003ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`00
0?oooooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`0:o`00
0?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo00?oc<c<o`000?l@41001?oo
ool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000ooooooooool0ooooool7ooooo`00k?oo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool01?oMgMgo0000
oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00
k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool01?o^k^ko
8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7oooo
o`00k?ooool5o`0000Kooooo00?o0000ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb<S8;oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003o
oooooooooooooooo000000Kooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00002?ooool0
0ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo0?oooooo1oooool00>_ooooo00Co410@o`000?l0003ooooo0_l00000
0ol@413oooooooooo`03ooooo`;o00004_ooool00ol0003oooooooooo`05ooooo`;o0000ooooool9
ooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .06798 L
.4 .06798 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .06798 L
.4 .06798 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .18129 L
.45 .18129 L
.45 0 L
F
0 g
.4 0 m
.4 .18129 L
.45 .18129 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .12361 L
.5 .12361 L
.5 0 L
F
0 g
.45 0 m
.45 .12361 L
.5 .12361 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .19365 L
.55 .19365 L
.55 0 L
F
0 g
.5 0 m
.5 .19365 L
.55 .19365 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .18129 L
.6 .18129 L
.6 0 L
F
0 g
.55 0 m
.55 .18129 L
.6 .18129 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .11743 L
.65 .11743 L
.65 0 L
F
0 g
.6 0 m
.6 .11743 L
.65 .11743 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .10713 L
.7 .10713 L
.7 0 L
F
0 g
.65 0 m
.65 .10713 L
.7 .10713 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .04532 L
.75 .04532 L
.75 0 L
F
0 g
.7 0 m
.7 .04532 L
.75 .04532 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .01236 L
.8 .01236 L
.8 0 L
F
0 g
.75 0 m
.75 .01236 L
.8 .01236 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo000Ho`0008kooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo000Io`000:Gooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^ooo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0^oooool00;_ooooo6Ol0000Fool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2koooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2k
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`006?l0002mooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo000Ho`000=Cooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00dooo
ool00ol0003oo`00ool0000Dool001Wo00005_oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Ooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOoo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
5Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00dooooolHo`0001Oooooo00?o0000ool0
0?oo00005?oo000Io`000>_ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3oooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3o
ooooo`;ooooo003oooooo`?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3ooooo
o`;ooooo003oooooo`?ooooo6?l0003oooooo`Cooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo1?l00000
2?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000
ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooo
oolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000Sooooo1?l0003ooooooaSooooo003Xooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0
003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3o
oooooaWooooo003Vooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3
ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003V
ooooo`Co000000Go410@ooooooooooooooooodA4A002o`000009oc8b<_oMgMgoooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003o
ooooooooo`06ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o
0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`07ooooo`04o`000?oooooo
oooooa0@40?ooooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003X
ooooo`03o`000?oooooooooo00Kooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oo
oooooooo00Kooooo1?l0003ooooooaSooooo003Xooooo`03o`000?oooooooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oEEEEofIVI_l000001Ooo
ool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`Go00000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00i_ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?oooooooooooooo
ool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo1?l0003ooooooaSooooo003Woooo
o`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`05o`000?ooooooooooooooool@4100
0oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01_ooool00ol0003o
ooooooooo`3ooooooaWooooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo
6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00iOooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMg
M`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^k^h02Oooool0
1?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00Kooooo1?l0003ooooooaSooooo003W
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00omgMgOoIVIVooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000Sooooo
00?o0000ooooooooool0oooooolIooooo`00jOooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Gooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lb<S;oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?oo
ool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oa0@4?nj^[[oooooogMgMolb<S800ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03
o`000?oooooooooo0?oooooo6Oooool00>Wooooo00Go0000oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Sooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000008ooooo`Co0000oooooolHooooo`00ioooool00ol@
413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo00000?oooooo9?ooool00>Sooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooo
oooo410@00?ooooo00Go410@oooooooooooooooooa0@403oooooobCooooo003Uooooo`05oa0@4?nH
V9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`3oooooobCooooo003Uooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP3oooooobCooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo
7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oo
oooooooooolOooooo`00oooooooooooooaoooooo003gooooo`;o00002oooool00ol0003o^[Zjoooo
o`0<ooooo`;o0000ooooool9ooooo`00moooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool0
0ol0003oooooooooo`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@
ooooooooool00oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0
003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo0?oooooo
1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`0:o`000?ooooooooooooooooo^
k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^
k_mgMgOo410@00Cooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool5o`0000Ko
oooo00?o0000ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo0000
00Kooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003
o`0000Gooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo0?oooooo1oooool00>_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03
ooooo`;o00004_ooool00ol0003oooooooooo`05ooooo`;o0000ooooool9ooooo`00oooooooooooo
oaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .08858 L
.4 .08858 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .08858 L
.4 .08858 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .19983 L
.45 .19983 L
.45 0 L
F
0 g
.4 0 m
.4 .19983 L
.45 .19983 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .13185 L
.5 .13185 L
.5 0 L
F
0 g
.45 0 m
.45 .13185 L
.5 .13185 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .16275 L
.55 .16275 L
.55 0 L
F
0 g
.5 0 m
.5 .16275 L
.55 .16275 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .17717 L
.6 .17717 L
.6 0 L
F
0 g
.55 0 m
.55 .17717 L
.6 .17717 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .11949 L
.65 .11949 L
.65 0 L
F
0 g
.6 0 m
.6 .11949 L
.65 .11949 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .08446 L
.7 .08446 L
.7 0 L
F
0 g
.65 0 m
.65 .08446 L
.7 .08446 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .05974 L
.75 .05974 L
.75 0 L
F
0 g
.7 0 m
.7 .05974 L
.75 .05974 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .00618 L
.8 .00618 L
.8 0 L
F
0 g
.75 0 m
.75 .00618 L
.8 .00618 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo000Ho`0008kooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2S
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`006Ol0002Uooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2k
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`006?l0002mooooo`00^ooooolIo`0001Koo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_oo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`006?l0003Dooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOoo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo000Io`0001Koo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eoooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yoooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooo
oooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0E
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Y
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool05OoooolHo`0001Ooo`0000?o0000oooooooo
ool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`;o0000
5Oooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo
01Gooooo00?o0000ooooooooool05?ooool00ol0003oo`00ool0000Eool00003o`000?oooooooooo
0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003o
ooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Cooooo
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo01Gooooo00?o0000ooooooooool05?oooolIo`000>_ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oooooooooo`3o
oooooaWooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0
003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool05Oooool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool05Oooool2o`000?oooooo6_ooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo6?l00002
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo
00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000oooooooo
ool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00j?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000Sooooo1?l0003ooooooaSooooo003Xooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?oo
ool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWo
oooo003Vooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003o
oooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`Co
000000Go410@ooooooooooooooooodA4A002o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003ooooooooo
o`06ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooooa0@
40?ooooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03
o`000?oooooooooo00Kooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo
00Kooooo1?l0003ooooooaSooooo003Xooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3o
oooooaWooooo003Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol@
413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08
ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oEEEEofIVI_l000001Oooool4o`00
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`Go00000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0
oooooolIooooo`00i_ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@4100
0oooool01Ol@413ooooooooooooooooo410@00Sooooo1?l0003ooooooaSooooo003Wooooo`03oiRH
V?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool0
0ol0003oooooooooo`3ooooooaWooooo003Yooooo`05o`000?ooooooooooooooool@41000oooool0
1Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01_ooool00ol0003ooooooooo
o`3ooooooaWooooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00iOooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`08oooo
o`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^k^h02Oooool01?l0003o
ooooooooool@4103ooooo`03oa0@4?oooooooooo00Kooooo1?l0003ooooooaSooooo003Wooooo`03
oiRHV?lQ8B7ok^k^00Oooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00omgMgOoIVIVooooo`03ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000
ooooooooool0oooooolIooooo`00jOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0>Gooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c004ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0
003oooooooooo`3ooooooaWooooo003Uooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Wooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?oo
ooooooooooooool@41000oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Sooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000008ooooo`Co0000oooooolHooooo`00ioooool00ol@413o0000
okZj^P03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
0?oooooo9?ooool00>Sooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@403oooooobCooooo003Uooooo`05oa0@4?nHV9Sooooo
okZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`3oooooobCooooo003Uooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP3oooooobCooooo003ooooooooo
oooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool0
0?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooo
oolOooooo`00oooooooooooooaoooooo003gooooo`;o00002oooool00ol0003o^[Zjooooo`0<oooo
o`;o0000ooooool9ooooo`00moooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003o
ooooooooo`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@oooooooo
ool00oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj
00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo0?oooooo1oooool0
0>cooooo00Go0000ooooooooooooooooo`000006ooooo`0:o`000?ooooooooooooooooo^k^ko8B4Q
ohN7Qonj^[[o0000omgMg@?ooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo
410@00Cooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool5o`0000Kooooo00?o
0000ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo
00Co0000oooooooooooooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Go
oooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oo
oooo1oooool00>_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`;o
00004_ooool00ol0003oooooooooo`05ooooo`;o0000ooooool9ooooo`00oooooooooooooaoooooo
003ooooooooooooo7oooool00?oooooooooooolOooooo`00\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .0824 L
.4 .0824 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .0824 L
.4 .0824 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .19777 L
.45 .19777 L
.45 0 L
F
0 g
.4 0 m
.4 .19777 L
.45 .19777 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .15039 L
.5 .15039 L
.5 0 L
F
0 g
.45 0 m
.45 .15039 L
.5 .15039 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .17099 L
.55 .17099 L
.55 0 L
F
0 g
.5 0 m
.5 .17099 L
.55 .17099 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .16069 L
.6 .16069 L
.6 0 L
F
0 g
.55 0 m
.55 .16069 L
.6 .16069 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .14009 L
.65 .14009 L
.65 0 L
F
0 g
.6 0 m
.6 .14009 L
.65 .14009 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .05768 L
.7 .05768 L
.7 0 L
F
0 g
.65 0 m
.65 .05768 L
.7 .05768 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .05768 L
.75 .05768 L
.75 0 L
F
0 g
.7 0 m
.7 .05768 L
.75 .05768 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .01236 L
.8 .01236 L
.8 0 L
F
0 g
.75 0 m
.75 .01236 L
.8 .01236 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo000Ho`0008kooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00<?l0002Uooooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3B
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00
^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`3Booooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00^ooooolI
o`0001Koo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_oo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`006?l0003Dooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOoo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0
003oo`00ool0000Dool001Wo00005_oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000
ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eoooo
o`03o`000?oo003oo`0001Coo`006Ol0003[ooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0oooo
ool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool05OoooolHo`000?oooooo1?ooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo
6Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Oooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`;o0000oooooolJooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ooooooooool0oooo
oolIooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000
ooooooooool0oooooolIooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo
01Gooooo00?o0000ooooooooool0oooooolIooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo01Gooooo00?o0000ooooooooool0oooooolIooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ooooooooool0oooooolIooooo`00dooo
oolHo`0001Oooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool4o`000008oa0@4?oooooo
ooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0
003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3o
oooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003X
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000002?ooool4o`000?oooooo6?ooool00>Sooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03
o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0>Kooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo
6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo1?l00000
1Ol@413oooooooooooooooooA4A400;o000000Wo<S8bomgMgOooooooooooonk^k_lb<S;o0000oc8b
<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00Ko
oooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003ooooooooo
o`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo410@0ooo
ool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000
ooooooooool01_ooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool01_oo
ool4o`000?oooooo6?ooool00>Sooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05oa0@4?oo
ooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo
00?o0000ooooooooool0oooooolIooooo`00i_ooool00omEEEGoIVIVo`000005ooooo`Co00000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o
0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo1Ol00003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0
oooooolIooooo`00iOooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Vooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4003oooo
o`05oa0@4?ooooooooooooooool@41002?ooool4o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?oMgMgofIVI_ooool00_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Wooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@
4?ooooooooooooooool@41000oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Gooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolI
ooooo`00iOooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003Uooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A007ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o
0000ooooooooool0oooooolIooooo`00i_ooool00onHV9So8B4Qonk^kP09ooooo`04o`000?oooooo
oooooa0@40?ooooo00?o410@ooooooooool01_ooool4o`000?oooooo6?ooool00>Oooooo00?oV9RH
ob4Q8Oo^k^h01oooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ogMgMomVIVKooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Yooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOoo
ool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So410@
o`000?lQ8B7oc<c<00Cooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Gooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000oooooooo
ool0oooooolIooooo`00jOooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooooooooa0@4003ooooo`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIoooo
o`00j?ooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000Sooooo1?l0003ooooooaSooooo003Wooooo`03oa0@4?l0003o^[Zj
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000oooo
oolTooooo`00j?ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@0?oooooo9?ooool00>Gooooo00Go410@oiRHV?oooooo^[Zj
o`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
0?oooooo9?ooool00>Gooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^0?oooooo9?ooool00?oooooooooooolO
ooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooo
oooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoo
oooo003ooooooooooooo7oooool00?Oooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo0_l0
003oooooo`Wooooo003gooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oooooo
oooo0?oooooo1oooool00>_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03
ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X01?oo
ool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool0ooooool7ooooo`00k?oo
ool01Ol0003ooooooooooooooooo000000Kooooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7
okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@4100
1?ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`02ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`Go00001_ooool00ol0003o
ooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool01?l0
003oooooooooooooool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o000000?o00001Oooool0
0ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7
ooooo`00joooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo0_l0000B
ooooo`03o`000?oooooooooo00Gooooo0_l0003oooooo`Wooooo003ooooooooooooo7oooool00?oo
oooooooooolOooooo`00oooooooooooooaoooooo0000\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .07416 L
.4 .07416 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .07416 L
.4 .07416 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .18953 L
.45 .18953 L
.45 0 L
F
0 g
.4 0 m
.4 .18953 L
.45 .18953 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .13391 L
.5 .13391 L
.5 0 L
F
0 g
.45 0 m
.45 .13391 L
.5 .13391 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .16893 L
.55 .16893 L
.55 0 L
F
0 g
.5 0 m
.5 .16893 L
.55 .16893 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .17923 L
.6 .17923 L
.6 0 L
F
0 g
.55 0 m
.55 .17923 L
.6 .17923 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .13185 L
.65 .13185 L
.65 0 L
F
0 g
.6 0 m
.6 .13185 L
.65 .13185 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .09683 L
.7 .09683 L
.7 0 L
F
0 g
.65 0 m
.65 .09683 L
.7 .09683 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .0412 L
.75 .0412 L
.75 0 L
F
0 g
.7 0 m
.7 .0412 L
.75 .0412 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .01236 L
.8 .01236 L
.8 0 L
F
0 g
.75 0 m
.75 .01236 L
.8 .01236 L
.8 0 L
.75 0 L
s
1 0 0 r
.8 0 m
.8 .00206 L
.85 .00206 L
.85 0 L
F
0 g
.8 0 m
.8 .00206 L
.85 .00206 L
.85 0 L
.8 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`006Ol0001Eooooo`04ob4Q8OmgMgOoMgMgoc8b<Qgo
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo06[ooooo0_l00002ooooo`;o00007?ooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0S?ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0S?ooool00;_ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0S?ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool001So
0000S_ooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2S
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo000I
o`000:Gooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2k
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002koooo
oaWo00005_oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
01So0000_Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;o
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`006?l0003Dooooo`00doooool00ol0003oo`00ool0
000Dool001Wo00005_oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
5Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo
003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ooooooooool05OoooolHo`0001Ooo`0000?o0000ooooooooool0jOooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
01Cooooo00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ooooooooool05?ooool00ol0003o
o`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo01Cooooo00?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000
ooooooooool05?oooolIo`000>_ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool05Oooool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ooooooooool05Oooool00ol0003oooooooooo`3ooooooaWooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool2o`000?oooooo6_ooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00=?ooooo6?l0000Gooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003Vooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>So
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`Co0000
oooooolHooooo`00j?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00
j?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00omEEEGoIVIVo`000004oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00i_ooool4o`000005oa0@4?oooooooooooooooom4A4@00_l0
00002Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool02OmgMgOo<S8booooooooooooMgMg
oiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000
ooooooooool01oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00Kooooo00?o
0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;o
ooooooooool000000oooool00ol0003oooooooooo`06ooooo`Co0000oooooolHooooo`00j?ooool0
0ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooo
oooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo
003Vooooo`03oeEEEOmVIVKo000000Gooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_oo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00iOooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^
k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008
ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooo
oolIooooo`00j?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00jOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01Ol0003o^[Zj
oooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWo
oooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo1Ol00004ooooo`05odA4A?l0
003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooooooo
ool0oooooolIooooo`00iOooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00WoMgMgoc8b<_oo
ooooooooogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003V
ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00Co0000oooooooooooo410@0oooool00ol@413ooooooooo
o`06ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP07ooooo`05ogMgMolb<S;o
ooooooooool000000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Sooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go
0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Wooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100
2?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@4100
1?ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2
o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2
o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Go
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool0
1Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Yooooo`05o`00
0?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooo
ooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ojVYZOl@413ooooo00;o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool4
o`000?oooooo6?ooool00>Oooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`00003oooooobCooooo003Xooooo`03okZj^_lQ8B7o
oooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100
oooooolTooooo`00iOooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0oooooolTooooo`00iOooool01OnYZJWo
410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h0oooooolTooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oo
oooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolO
ooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00mooo
ool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`000?oooooo2Oooool00?Oooooo00?o0000
ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool0ooooool7ooooo`00joooool01?l@
413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l0
0002ooooo`;o00000oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X0
1?ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool00000
1_ooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0
003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo0?oooooo
1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo
00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oo
oooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;o
oooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
0?oooooo1oooool00>cooooo1Ol00006ooooo`03o`000?oooooooooo00;ooooo00Co8B4QogMgMomg
MgOo<S8b2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool00>co
oooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2
o`0000Sooooo00?o410@o`000?l000000ol00005ooooo`03o`000?oooooooooo0?oooooo1oooool0
0>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003[ooooo`04oa0@4?l0003o0000
ooooo`;o000000?o410@ooooooooool00oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2
o`000?oooooo2Oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo
7oooool00001\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .07004 L
.4 .07004 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .07004 L
.4 .07004 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .17511 L
.45 .17511 L
.45 0 L
F
0 g
.4 0 m
.4 .17511 L
.45 .17511 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .14215 L
.5 .14215 L
.5 0 L
F
0 g
.45 0 m
.45 .14215 L
.5 .14215 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .17923 L
.55 .17923 L
.55 0 L
F
0 g
.5 0 m
.5 .17923 L
.55 .17923 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .17099 L
.6 .17099 L
.6 0 L
F
0 g
.55 0 m
.55 .17099 L
.6 .17099 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .10919 L
.65 .10919 L
.65 0 L
F
0 g
.6 0 m
.6 .10919 L
.65 .10919 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .11125 L
.7 .11125 L
.7 0 L
F
0 g
.65 0 m
.65 .11125 L
.7 .11125 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .05768 L
.75 .05768 L
.75 0 L
F
0 g
.7 0 m
.7 .05768 L
.75 .05768 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .01442 L
.8 .01442 L
.8 0 L
F
0 g
.75 0 m
.75 .01442 L
.8 .01442 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo000Ho`0008kooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xooo
ool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00
^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool001Wo0000YOooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooo
oooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oooooooooo0;_ooooo002koooooaWo00005_oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^ooo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0
^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo000Ho`0001Ko
o`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`0DoooooaSo0000_Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOoo
ool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`006Ol0000Fool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooo
oooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o
0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0E
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Y
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool0
0=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`00
01Coo`006Ol0003[ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Go
oooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003CoooooaSo0000
5oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oooooo0ooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo0_ooool00?oooooo0ooooolH
o`000?oooooo1?ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool4o`000008oa0@4?oooooo
ooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0
003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3o
oooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003X
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000002?ooool4o`000?oooooo6?ooool00>Sooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03
o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0>Kooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooo
ooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool0
0ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIoooo
o`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo
6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo1?l00000
1Ol@413oooooooooooooooooA4A400;o000000Wo<S8bomgMgOooooooooooonk^k_lb<S;o0000oc8b
<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00Ko
oooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003ooooooooo
o`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo410@0ooo
ool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000
ooooooooool01_ooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool01_oo
ool4o`000?oooooo6?ooool00>Sooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05oa0@4?oo
ooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo
00?o0000ooooooooool0oooooolIooooo`00i_ooool00omEEEGoIVIVo`000005ooooo`Co00000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o
0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo1Ol00003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0
oooooolIooooo`00iOooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Vooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4003oooo
o`05oa0@4?ooooooooooooooool@41002?ooool4o`000?oooooo6?ooool00>Oooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?oMgMgofIVI_ooool00_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Wooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@
4?ooooooooooooooool@41000oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Gooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolI
ooooo`00iOooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003Uooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A007ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o
0000ooooooooool0oooooolIooooo`00i_ooool00onHV9So8B4Qonk^kP09ooooo`04o`000?oooooo
oooooa0@40?ooooo00?o410@ooooooooool01_ooool4o`000?oooooo6?ooool00>Oooooo00?oV9RH
ob4Q8Oo^k^h01oooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ogMgMomVIVKooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Yooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOoo
ool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So410@
o`000?lQ8B7oc<c<00Cooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3oooo
o`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00
ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003ooooooooo
o`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0
003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Gooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000oooooooo
ool0oooooolIooooo`00jOooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooooooooa0@4003ooooo`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIoooo
o`00j?ooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000Sooooo1?l0003ooooooaSooooo003Wooooo`03oa0@4?l0003o^[Zj
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000oooo
oolTooooo`00j?ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@0?oooooo9?ooool00>Gooooo00Go410@oiRHV?oooooo^[Zj
o`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
0?oooooo9?ooool00>Gooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^0?oooooo9?ooool00?oooooooooooolO
ooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooo
oooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoo
oooo003ooooooooooooo7oooool00?Oooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo0_l0
003oooooo`Wooooo003gooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oooooo
oooo0?oooooo1oooool00>_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03
ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X01?oo
ool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool0ooooool7ooooo`00k?oo
ool01Ol0003ooooooooooooooooo000000Kooooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7
okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@4100
1?ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`02ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`Go00001_ooool00ol0003o
ooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool01?l0
003oooooooooooooool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o000000?o00001Oooool0
0ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool7
ooooo`00joooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo0_l0000B
ooooo`03o`000?oooooooooo00Gooooo0_l0003oooooo`Wooooo003ooooooooooooo7oooool00?oo
oooooooooolOooooo`00oooooooooooooaoooooo0000\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .07622 L
.4 .07622 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .07622 L
.4 .07622 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .17099 L
.45 .17099 L
.45 0 L
F
0 g
.4 0 m
.4 .17099 L
.45 .17099 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .13391 L
.5 .13391 L
.5 0 L
F
0 g
.45 0 m
.45 .13391 L
.5 .13391 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .17305 L
.55 .17305 L
.55 0 L
F
0 g
.5 0 m
.5 .17305 L
.55 .17305 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .16069 L
.6 .16069 L
.6 0 L
F
0 g
.55 0 m
.55 .16069 L
.6 .16069 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .11949 L
.65 .11949 L
.65 0 L
F
0 g
.6 0 m
.6 .11949 L
.65 .11949 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .09889 L
.7 .09889 L
.7 0 L
F
0 g
.65 0 m
.65 .09889 L
.7 .09889 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .08446 L
.75 .08446 L
.75 0 L
F
0 g
.7 0 m
.7 .08446 L
.75 .08446 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .01236 L
.8 .01236 L
.8 0 L
F
0 g
.75 0 m
.75 .01236 L
.8 .01236 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo000Ho`0008kooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool0
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool0
0;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo
0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
ooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo6Ol0000Fool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
Xoooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool001Wo0000YOooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o
0000ooooooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00=?ooooo00?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0^oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool001So
0000_Oooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3B
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo000Ho`000=Cooooo003Cooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooo
oooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?o
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`006Ol0
000Fool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Go
oooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wo
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool05Oooool00ol0003oo`00ool0000Dool001Wo0000joooool00=?ooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0E
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00dooooolHo`00
01Oooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003oooooo`?o
oooo6?l0003oooooo`Cooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo1?l000002?l@413oooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolI
ooooo`00j?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool0
1Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000Sooooo1?l0003ooooooaSooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Voooo
o`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`Co000000Go410@
ooooooooooooooooodA4A002o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`06ooooo`09
ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooo
oolIooooo`00j?ooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooooa0@40?ooooo00?o
410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooo
oooo00Kooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo1?l0
003ooooooaSooooo003Xooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c002ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo
003Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Kooooo00?oEEEEofIVI_l000001Oooool4o`0000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oo
oooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00i_ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@00Sooooo1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?oo
ool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ogMgMomVIVKooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Yooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWo
oooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o
0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o
0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o
0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOoo
ool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^k^h02Oooool01?l0003oooooooooool@
4103ooooo`03oa0@4?oooooooooo00Kooooo1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7o
k^k^00Oooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0oooooolIooooo`00j?ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
oooooolIooooo`00jOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go
410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go
0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c004ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`00
0?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`00
0?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003ooooooooo
o`3ooooooaWooooo003Uooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Wooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>So
oooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000008ooooo`Co0000oooooolHooooo`00ioooool00ol@413o0000okZj^P03oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo00000?oooooo9?oo
ool00>Sooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@403oooooobCooooo003Uooooo`05oa0@4?nHV9SooooookZj^_l00000
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`3ooooo
obCooooo003Uooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP3oooooobCooooo003ooooooooooooo7oooool0
0?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooo
oolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00
oooooooooooooaoooooo003gooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o0000oooo
ool9ooooo`00moooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`3o
ooooo`Oooooo003[ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool0
1?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00Go
V9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go
0000ooooooooooooooooo`000006ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o
0000omgMg@?ooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo
00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool5o`0000Kooooo00?o0000oooooooo
ool00_ooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooo
oooooooooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Gooooo00?o0000
ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool0
0>_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`;o00004_ooool0
0ol0003oooooooooo`05ooooo`;o0000ooooool9ooooo`00oooooooooooooaoooooo003ooooooooo
oooo7oooool00?oooooooooooolOooooo`00\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .06386 L
.4 .06386 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .06386 L
.4 .06386 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .16687 L
.45 .16687 L
.45 0 L
F
0 g
.4 0 m
.4 .16687 L
.45 .16687 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .15039 L
.5 .15039 L
.5 0 L
F
0 g
.45 0 m
.45 .15039 L
.5 .15039 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .19571 L
.55 .19571 L
.55 0 L
F
0 g
.5 0 m
.5 .19571 L
.55 .19571 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .15245 L
.6 .15245 L
.6 0 L
F
0 g
.55 0 m
.55 .15245 L
.6 .15245 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .10507 L
.65 .10507 L
.65 0 L
F
0 g
.6 0 m
.6 .10507 L
.65 .10507 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .12155 L
.7 .12155 L
.7 0 L
F
0 g
.65 0 m
.65 .12155 L
.7 .12155 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .06386 L
.75 .06386 L
.75 0 L
F
0 g
.7 0 m
.7 .06386 L
.75 .06386 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .0103 L
.8 .0103 L
.8 0 L
F
0 g
.75 0 m
.75 .0103 L
.8 .0103 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo000Ho`0008kooooo002kooooo`03
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00
^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0
Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
oooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Soooo
o`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooooooo
ool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002k
ooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2S
ooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002koooooaWo00005_oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`006Ol0002Uooooo`00doooool00ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003o
ooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooooooo
o`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2koooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2k
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool0
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool001So00005_oo00000ol0003oooooooooo`2kooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo01Co
oooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003ooooo
ooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o
0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2k
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo00?o0000ool0
0?oo00005?oo00000ol0003oooooooooo`2kooooo`00doooool00ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oooooooooo01Cooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo01Cooooo6?l0002mooooo`00dooo
ool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wo
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000Dool001Wo00005_oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool001Wo0000joooool00=?ooooo
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool0ooooool2ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
oooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000D
ool00003o`000?oooooooooo0?oooooo0_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oooooooooo`0Eooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2oooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo
00005?oo00000ol0003oooooooooo`3oooooo`;ooooo003Cooooo`03o`000?oo003oo`0001Coo`00
00?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oooooooooo0?oooooo
0_ooool00=?ooooo6?l0000Gooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0oooo
ool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2
ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2oooo
o`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00
ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00oooo
ool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3oooo
o`03o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`00
01Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Co
o`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3oooooaSo0000ooooool4ooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Kooooo1?l000002?l@413oooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolI
ooooo`00j?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool0
1Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000Sooooo1?l0003ooooooaSooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003o
ooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooo
oaWooooo003Xooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Voooo
o`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0
oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000
ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oo
oooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`Co000000Go410@
ooooooooooooooooodA4A002o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`06ooooo`09
ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooo
oolIooooo`00j?ooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooooa0@40?ooooo00?o
410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03o`000?oooooo
oooo00Kooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo1?l0
003ooooooaSooooo003Xooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c002ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooaWooooo
003Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@00Sooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00>Kooooo00?oEEEEofIVI_l000001Oooool4o`0000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oo
oooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00i_ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@00Sooooo1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?oo
ool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03ogMgMomVIVKooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Yooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWo
oooo003Uooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0>Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o
0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o
0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o
0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00iOoo
ool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Kooooo00?oV9RHob4Q8Oo^k^h02Oooool01?l0003oooooooooool@
4103ooooo`03oa0@4?oooooooooo00Kooooo1?l0003ooooooaSooooo003Wooooo`03oiRHV?lQ8B7o
k^k^00Oooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0oooooolIooooo`00j?ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
oooooolIooooo`00jOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go
410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00Go
0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c004ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`00
0?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`00
0?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo
0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooo
oolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooo
ooooool0oooooolIooooo`00iOooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003ooooooooo
o`3ooooooaWooooo003Uooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00>Wooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00>So
oooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000008ooooo`Co0000oooooolHooooo`00ioooool00ol@413o0000okZj^P03oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo00000?oooooo9?oo
ool00>Sooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@403oooooobCooooo003Uooooo`05oa0@4?nHV9SooooookZj^_l00000
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`3ooooo
obCooooo003Uooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP3oooooobCooooo003ooooooooooooo7oooool0
0?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooo
oolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooooooooolOooooo`00
oooooooooooooaoooooo003gooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o0000oooo
ool9ooooo`00moooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`3o
ooooo`Oooooo003[ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool0
1?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00Go
V9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo0?oooooo1oooool00>cooooo00Go
0000ooooooooooooooooo`000006ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o
0000omgMg@?ooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo
00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0ooooool7ooooo`00k?ooool5o`0000Kooooo00?o0000oooooooo
ool00_ooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooo
oooooooooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Gooooo00?o0000
ooooooooool0ooooool7ooooo`00k?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo1oooool0
0>_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`;o00004_ooool0
0ol0003oooooooooo`05ooooo`;o0000ooooool9ooooo`00oooooooooooooaoooooo003ooooooooo
oooo7oooool00?oooooooooooolOooooo`00\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .09271 L
.4 .09271 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .09271 L
.4 .09271 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .15451 L
.45 .15451 L
.45 0 L
F
0 g
.4 0 m
.4 .15451 L
.45 .15451 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .14833 L
.5 .14833 L
.5 0 L
F
0 g
.45 0 m
.45 .14833 L
.5 .14833 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .17923 L
.55 .17923 L
.55 0 L
F
0 g
.5 0 m
.5 .17923 L
.55 .17923 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .17099 L
.6 .17099 L
.6 0 L
F
0 g
.55 0 m
.55 .17099 L
.6 .17099 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .12773 L
.65 .12773 L
.65 0 L
F
0 g
.6 0 m
.6 .12773 L
.65 .12773 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .08858 L
.7 .08858 L
.7 0 L
F
0 g
.65 0 m
.65 .08858 L
.7 .08858 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .05562 L
.75 .05562 L
.75 0 L
F
0 g
.7 0 m
.7 .05562 L
.75 .05562 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .01236 L
.8 .01236 L
.8 0 L
F
0 g
.75 0 m
.75 .01236 L
.8 .01236 L
.8 0 L
.75 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.188, 267.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0001CR000`400?l00000o`00003ooooooooo
oooooaoooooo003ooooooooooooo7oooool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0004Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08Gooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40QOooool00<Cooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP16ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0001[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
0000QOooool00<cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^04Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40QOooool00<cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo04Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0QOooool00<cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo04?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo08Oooooo003<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qooo
ool00<cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooooooooooaoooooo003o
oooooooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooocooooo
0_l00002ooooo`;o00007?ooool00?ooooooo?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgAco
oooo003ooooooogooooo00CogMgMo`000?l@413oc<c<7Oooool001Ooooooool0003Go`0000oooooo
00Cok^k^ob4Q8Ol@413ok^k^7Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0Joooool01?lQ8B7oMgMg
ogMgMolb<S8Mooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0001cooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo08cooooo002koooo
o`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oooooooooo08cooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo000Ho`0008kooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo
00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo
002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0
000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooooooo
o`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000
ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool0
0003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0Xoooool00;_o
oooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0:?o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003ooooo
ooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ooooooooool0Xoooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0:?ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oooooooooo`2Sooooo`00^oooool00ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool001Wo
0000YOooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^ooo
ool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0
003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_o
oooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000E
ool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000D
ool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`2kooooo`00
^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0;_ooooo002kooooo`03o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0^oooool00;_ooooo00?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005?oo0000
0ol0003oooooooooo`2kooooo`00^oooool00ol0003oo`00ool0000Eool00003o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo
0;_ooooo002kooooo`03o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003o
o`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003o
o`00ool0000Dool001So0000_Oooool00;_ooooo00?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00;_ooooo6Ol0
000Fool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000
ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000
ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Coooo
o`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool0
0003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Boooo
o`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo
00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooooooo
ool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`00
0?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`00
0?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo
00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo
00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003o
o`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003o
o`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00
ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003C
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oooooooooo`3B
ooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool0
0?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000oooo
ooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003
o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo0000
5Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oooooooooo`3Booooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0d_ooool00=?ooooo00?o0000ool00?oo00005?oo0000
0ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo0000
0ol0003oo`00ool0000Dool00003o`000?oooooooooo0=;ooooo003Cooooo`03o`000?oo003oo`00
01Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`00
01Goo`006?l0003Dooooo`00doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wo
oooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00
ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o
0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003o`000?oo003oo`0001Coo`0000?o
0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0003oo`00ool0000D
ool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0000E
ool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Coo`0000?o0000ool0
0?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000oooo
ooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo00000ol0003oo`00ool0000Eool00003
o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00
doooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Goo`0000?o0000ool00?oo0000
5?oo00000ol0003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oo`00ool0000Dool00003o`000?oo
003oo`0001Goo`0000?o0000ooooooooool0jOooool00=?ooooo00?o0000ool00?oo00005?oo000I
o`0001Koo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00doooool00ol0
003oo`00ool0000Dool00003o`000?oooooooooo01Gooooo00?o0000ool00?oo00005?oo00000ol0
003oo`00ool0000Eool00003o`000?oooooooooo0>Wooooo003Cooooo`03o`000?oo003oo`0001Co
o`0000?o0000ooooooooool05Oooool00ol0003oo`00ool0000Dool00003o`000?oo003oo`0001Go
o`0000?o0000ooooooooool0jOooool00=?ooooo6?l0000Gooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Y
ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0
003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo
00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`00
00?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3ooooo`03o`000?oo
003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Yooooo`00ooooool3
ooooo`03o`000?oo003oo`0001Coo`0000?o0000ool00?oo00005Ooo00000ol0003oooooooooo`3Y
ooooo`00ooooool3ooooo`03o`000?oo003oo`0001Coo`006Ol0003[ooooo`00ooooool3ooooo`03
o`000?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`00
0?oo003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3ooooo`03o`000?oo
003oo`0001Coo`0000?o0000ooooooooool0ooooool2ooooo`00ooooool3oooooaSo0000ooooool4
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003Vooooo`Co000000So410@ooooooooooook^k^oc8b
<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0>Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@
oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000008ooooo`Co0000oooooolHooooo`00j?ooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooooooo
ool0oooooolIooooo`00j?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0oooooolIoooo
o`00j?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Sooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo
6Oooool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooo
oooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?o
oooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00oooo
ool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3o
oooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03
o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo
003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00i_ooool4o`000005oa0@4?oooooo
oooooooooom4A4@00_l000002Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^kP08oooo
o`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool01_ooool02OmgMgOo
<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00>Sooooo00?o0000ooooooooool01oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oo
oooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00j?ooool00ol0003oooooooooo`06
ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`06ooooo`Co0000oooo
oolHooooo`00j?ooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_oo
ool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooolIooooo`00j?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooo
oa0@4008ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Sooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003ooooo
ooooo`3ooooooaWooooo003Vooooo`03oeEEEOmVIVKo000000Gooooo1?l00003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`;o0000oooooolJooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[o
oooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003ooooo
o`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oo
oooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00iOooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooaWooooo
003Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Ko
oooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooo
oooooooooooooa0@4008ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP03oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o
0000ooooooooool0oooooolIooooo`00j?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
oooooolIooooo`00jOooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00
iOooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uoooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003o
ooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooooa[ooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oo
oooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oo
oooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0ooo
ool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolI
ooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00?oooooo0oooool2o`000?oo
oooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o
0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool0
0?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo00?o0000oooooooo
ool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Oooool00>Gooooo1Ol0
0004ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00So
oooo00?o0000ooooooooool0oooooolIooooo`00iOooool01OnHV9So8B4Qonk^k_ooooooA4A400Oo
oooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003ooooooooo
o`3ooooooaWooooo003Vooooo`03oiRHV?lQ8B7ok^k^00Wooooo00Co0000oooooooooooo410@0ooo
ool00ol@413oooooooooo`06ooooo`Co0000oooooolHooooo`00ioooool00onHV9So8B4Qonk^kP07
ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00>Sooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo
6Oooool00>Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05oa0@4?oo
ooooooooooooool@41002?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05o`000?nj
^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02?ooool00ol0003oooooooooo`3ooooooaWooooo003Uooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`01?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooo
oa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo0_l0003ooooo
oa[ooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003oooooo`?ooooo
00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo0?oooooo6Ooo
ool00?oooooo0oooool2o`000?oooooo6_ooool00?oooooo0oooool00ol0003oooooooooo`3ooooo
oaWooooo003oooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`00
0?oooooooooo0?oooooo6Oooool00?oooooo0oooool00ol0003oooooooooo`3ooooooaWooooo003o
ooooo`?ooooo00?o0000ooooooooool0oooooolIooooo`00ooooool3ooooo`03o`000?oooooooooo
0?oooooo6Oooool00>Gooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooo
oolIooooo`00iOooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooaWo
oooo003Yooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo003Xooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000002?ooool4o`000?oooooo6?ooool00>Oooooo00?o410@o`000?nj^[X00oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00003oooooobCooooo003X
ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oo
ooooooooooooool@4100oooooolTooooo`00iOooool01Ol@413oV9RHoooooonj^[[o000000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0oooooolToooo
o`00iOooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0oooooolTooooo`00oooooooooooooaoooooo003ooooo
oooooooo7oooool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7ooo
ool00?oooooooooooolOooooo`00oooooooooooooaoooooo003ooooooooooooo7oooool00?oooooo
oooooolOooooo`00moooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`000?oooooo2Ooo
ool00?Oooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool0ooooool7
ooooo`00joooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo00Co0000
oooooooooooooooo0_l00002ooooo`;o00000oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0
003o0000odA4A?nj^[X01?ooool00ol0003oooooooooo`3oooooo`Oooooo003/ooooo`05o`000?oo
ooooooooooooool000001_ooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oM
gMd3ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`00
0?oooooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo00;ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo0?oooooo1oooool00>cooooo1Ol00006ooooo`03o`000?oooooooooo00;o
oooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooooooo
ooooo`;o00000_ooool2o`0000Sooooo00?o410@o`000?l000000ol00005ooooo`03o`000?oooooo
oooo0?oooooo1oooool00>cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`Oooooo003[oooo
o`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool2o`0001;ooooo00?o0000
ooooooooool01Oooool2o`000?oooooo2Oooool00?oooooooooooolOooooo`00oooooooooooooaoo
oooo003ooooooooooooo7oooool00001\
\>"],
  ImageRangeCache->{{{0, 540.438}, {333.688, 0}} -> {-1.1007, -17.7132, \
0.00533065, 1.29378}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "This method of solving the Boltzmann equation, by following a large \
collection of particles, is called a",
  StyleBox[" particle simulation",
    FontSlant->"Italic"],
  ".  The fluctuations that we see in the density at late times  are due to \
the finite number of particles used in the simulation. We will discuss other \
particle simulation methods in Sec. ",
  ButtonBox["7.3",
    ButtonData:>"c:27",
    ButtonStyle->"Hyperlink"],
  " and in Chapter ",
  ButtonBox["8",
    ButtonData:>{"Chapter8.nb", None},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  "\tWe can also determine the expected equilibrium form of the density using \
Eq. ",
  ButtonBox["(7.1.26)",
    ButtonData:>{"Chapter7.nb", "(7.1.26)"},
    ButtonStyle->"Hyperlink"],
  "  and ",
  ButtonBox["(7.1.27)",
    ButtonData:>{"Chapter7.nb", "(7.1.27)"},
    ButtonStyle->"Hyperlink"],
  " :"
}], "Text"],

Cell[BoxData[
    \(neq[x_]\  := \ 
      NIntegrate[feq[x, p], {p, \(-2\), 2}, 
        MaxRecursion \[Rule] 25]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.22"],

Cell[TextData[{
  "In Fig. ",
  ButtonBox["7.3",
    ButtonData:>"Fig. 7.3",
    ButtonStyle->"Hyperlink"],
  " we plot the density multiplied by the bin size ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ", so that we can compare it with the histogram function ",
  Cell[BoxData[
      \(TraditionalForm\`H(x, t)\)]],
  " evaluated at the last time step. "
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.00206011 [
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.7 -0.0125 -9 -9 ]
[.7 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.4 0 m
.4 .00625 L
s
[(-0.2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.2)] .6 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(0.4)] .7 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.6)] .8 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(50)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(100)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(150)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(200)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(250)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(300)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(H) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.35 0 m
.35 .09271 L
.4 .09271 L
.4 0 L
F
0 g
.5 Mabswid
.35 0 m
.35 .09271 L
.4 .09271 L
.4 0 L
.35 0 L
s
1 0 0 r
.4 0 m
.4 .15451 L
.45 .15451 L
.45 0 L
F
0 g
.4 0 m
.4 .15451 L
.45 .15451 L
.45 0 L
.4 0 L
s
1 0 0 r
.45 0 m
.45 .14833 L
.5 .14833 L
.5 0 L
F
0 g
.45 0 m
.45 .14833 L
.5 .14833 L
.5 0 L
.45 0 L
s
1 0 0 r
.5 0 m
.5 .17923 L
.55 .17923 L
.55 0 L
F
0 g
.5 0 m
.5 .17923 L
.55 .17923 L
.55 0 L
.5 0 L
s
1 0 0 r
.55 0 m
.55 .17099 L
.6 .17099 L
.6 0 L
F
0 g
.55 0 m
.55 .17099 L
.6 .17099 L
.6 0 L
.55 0 L
s
1 0 0 r
.6 0 m
.6 .12773 L
.65 .12773 L
.65 0 L
F
0 g
.6 0 m
.6 .12773 L
.65 .12773 L
.65 0 L
.6 0 L
s
1 0 0 r
.65 0 m
.65 .08858 L
.7 .08858 L
.7 0 L
F
0 g
.65 0 m
.65 .08858 L
.7 .08858 L
.7 0 L
.65 0 L
s
1 0 0 r
.7 0 m
.7 .05562 L
.75 .05562 L
.75 0 L
F
0 g
.7 0 m
.7 .05562 L
.75 .05562 L
.75 0 L
.7 0 L
s
1 0 0 r
.75 0 m
.75 .01236 L
.8 .01236 L
.8 0 L
F
0 g
.75 0 m
.75 .01236 L
.8 .01236 L
.8 0 L
.75 0 L
s
0 0 m
.0125 0 L
.025 0 L
.0375 0 L
.05 0 L
.0625 0 L
.075 0 L
.0875 0 L
.1 0 L
.1125 0 L
.125 0 L
.1375 0 L
.15 0 L
.1625 0 L
.175 0 L
.1875 0 L
.2 0 L
.2125 0 L
.225 0 L
.2375 0 L
.25 0 L
.2625 0 L
.275 0 L
.2875 0 L
.3 0 L
.3125 0 L
.325 0 L
.3375 0 L
.35 .00218 L
.3625 .04932 L
.375 .08932 L
.3875 .11824 L
.4 .14361 L
.4125 .1671 L
.425 .17855 L
.4375 .17529 L
.45 .15397 L
.4625 .14066 L
.475 .13761 L
.4875 .14066 L
.5 .15397 L
.5125 .17366 L
.525 .17841 L
.5375 .17855 L
.55 .17555 L
.5625 .16941 L
.575 .16035 L
.5875 .15176 L
.6 .14361 L
.6125 .13562 L
Mistroke
.625 .12781 L
.6375 .12014 L
.65 .11256 L
.6625 .10493 L
.675 .09721 L
.6875 .08932 L
.7 .08116 L
.7125 .07252 L
.725 .06314 L
.7375 .0524 L
.75 .03838 L
.7625 .02185 L
.775 .01286 L
.7875 .00651 L
.8 .00218 L
.8125 1e-05 L
.825 0 L
.8375 0 L
.85 0 L
.8625 0 L
.875 0 L
.8875 0 L
.9 0 L
.9125 0 L
.925 0 L
.9375 0 L
.95 0 L
.9625 0 L
.975 0 L
.9875 0 L
1 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Q?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00008oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00002Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<
c<`0G?ooool008Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A402?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1oooool00ol0003oooooooooo`07ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoEEEEogMgMoooooooV9RHob4Q8@1Looooo`00O?ooool6o`0000;ooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02Cooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^00[ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00002?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00001Looooo`00
Q?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h08oooool01Ol0003o
oooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h02Oooool01Ol0003ooooooooooooooooo
000000_ooooo00CoA4A4omgMgOoooooo00002Oooool01Ol0003ooooooooooooooooo000000_ooooo
00Go0000oiRHV?ooooooV9RHob4Q8@1Looooo`00Q?ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oMgMgofIVI_ooool08_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool02?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00002Ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c01Looooo`00
Q?ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool08Oooool01Ol@413o
oooooooooooooooo410@00oooooo00?o0000ooooooooool01oooool01Ol@413ooooooooooooooooo
410@00cooooo00?oMgMgolc<c?l000002Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?o
EEEEohN7Qoooool0G_ooool008Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj
^[[ooooooiRHV?l@41008oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oo
ooooV9RHoa0@4009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000009
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV01Nooooo`00Q?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Sooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Wooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Sooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`04olc<c?m4A4Co0000oa0@45cooooo003oooooofWooooo003oooooofWooooo003ooooo
od[ooooo0_l00002ooooo`;o00006Oooool00?ooooooB_ooool01_o^k^ko8B4QohN7Qonj^[[o0000
omgMgAWooooo003ooooood_ooooo00CogMgMo`000?l@413oc<c<6_ooool001Coooooool0000/o`00
00_ooooo00Cok^k^ob4Q8Ol@413ok^k^6_ooool007cooooo00?o0000ool00?oo00003?oo00000ol0
003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0
003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0
003oo`00ool0000;ool00003o`000?oo003oo`0000_oo`000ol00016ooooo`04ob4Q8OmgMgOoMgMg
oc8b<Q[ooooo001looooo`03o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0
003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0
003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo00000ol0
003oo`00ool00008ool000?o000000?oo`00o`000?ooool0AOooool2o`0000;ooooo0_l0000Ioooo
o`00O?ooool00ol0003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo
00003?oo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo
00003?oo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ool00?oo
00001_oo0002o`0000Coo`0000?o0000ooooooooool0Hoooool007cooooo0_l0000=ool00003o`00
0?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool00003o`00
0?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool00003o`00
0?oo003oo`0000_oo`004?l0001Uooooo`00O?ooool2o`0000goo`0000?o0000ool00?oo00003?oo
00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo
00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00002ooo
00000ol0003oooooooooo`03ooooo`03o`000?oooooooooo06cooooo001looooo`;o00003Ooo0000
0ol0003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo0000
0ol0003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo0000
0ol0003oo`00ool0000;ool00003o`000?oooooooooo00;ooooo00?o0000ooooooooool0KOooool0
07cooooo00?o0000ool00?l000003?oo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`00
00coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`00
00coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000;ool00005o`000?oooooooooo
ooooool00000L?ooool007cooooo00?o0000ool00?l000003?oo00000ol0003oo`00ool0000<ool0
0003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool0
0003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000;ool0
0005o`000?ooooooooooooooool00000L?ooool007cooooo00?o0000ool00?l000003?oo00000ol0
003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0
003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0
003oo`00ool0000;ool00004o`000?ooooooooooo`00077ooooo001looooo`03o`000?oo003o0000
00coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`00
00coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`00
00coo`0000?o0000ool00?oo00002ooo00000ol0003oooooo`00001booooo`00O?ooool01?l0003o
o`00ool00?l0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0
003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0
003oo`00ool0000<ool00003o`000?oo003oo`0000_oo`000_l0001cooooo`00O?ooool01?l0003o
o`00ool00?l0000;ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0
003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0
003oo`00ool0000<ool00003o`000?oo003oo`0000_oo`0000?o0000ooooooooool0L_ooool007co
oooo00Co0000ool00?oo003o00002ooo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`00
00coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`00
00coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000;ool00003o`000?oooooooooo
07;ooooo001looooo`05o`000?oo003oo`00ool00?l000002_oo00000ol0003oo`00ool0000<ool0
0003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool0
0003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000:ool0
00;o0000M?ooool007cooooo00Go0000ool00?oo003oo`00o`00000:ool00003o`000?oo003oo`00
00coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`00
00coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`00
00Woo`0000?o0000ool00?l00000M?ooool007cooooo00Go0000ool00?oo003oo`00o`00000:ool0
0003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool0
0003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool0
0003o`000?oo003oo`0000Ooo`000_l00002ool00003o`000?oooooooooo07;ooooo001looooo`03
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00001ooo00000ol0003oo`00ool0000<ool00003
o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool00003
o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo000?o`0007Cooooo001looooo`03o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00001ooo00000ol0003oo`00ool0000<ool00003o`00
0?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool00003o`00
0?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo07Sooooo001looooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00001ooo
00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo
00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo
00000ol0003oooooooooo`03ooooo`;o0000Noooool007cooooo00?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00006ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo0000
0ol0003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo0000
0ol0003oo`00ool0000<ool00003o`000?oooooooooo00;ooooo00?o0000ooooooooool0Noooool0
07cooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00006ool00003o`000?oo003oo`00
00coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`00
00coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool00005o`000?oooooooooo
ooooool00000O_ooool007cooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00006ool0
0003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool0
0003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool0
0004o`000?oooooo0000o`0007oooooo001looooo`03o`000?oo003oo`0000Coo`0000?o0000ool0
0?oo00001Ooo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool0
0?oo00003?oo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool0
0?oo00003?oo0002o`00087ooooo001looooo`03o`000?oo003oo`0000Coo`0000?o0000ool00?oo
00001Ooo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo
00003?oo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo
00002ooo0002o`0008;ooooo001looooo`03o`000?oo003oo`0000Coo`0000?o0000ool00?oo0000
1Ooo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo0000
3?oo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo0000
2_oo00000ol0003oo`00o`000022ooooo`00O?ooool00ol0003oo`00ool00005ool00003o`000?oo
003oo`0000Coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool00003o`000?oo
003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool0013o0000P_oo
ool007cooooo00?o0000ool00?oo00001Ooo00000ol0003oo`00ool00004ool00003o`000?oo003o
o`0000coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool00003o`000?oo003o
o`0000coo`0000?o0000ool00?oo00003?oo00000ol0003oooooooooo`07ooooo`;o0000Q_ooool0
07cooooo4?l0000>ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0
003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ooooooooool01Oooool2o`00
08Sooooo0025ooooo`03o`000?oooooooooo00?ooooo00?o0000ool00?oo00003?oo00000ol0003o
o`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0003o
o`00ool0000<ool00003o`000?oooooooooo00?ooooo0_l0002:ooooo`00QOooool00ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00
ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00001?l0003ooooo
ooooooooool2o`0008cooooo0026ooooo`03o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
3?oo00000ol0003oo`00ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo0000
3?oo00000ol0003oo`00ool0000<ool00004o`000?ooooooooooo`0008kooooo0026ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool00003o`00
0?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool00003o`00
0?oooooo000008oooooo0027ooooo`05o`000?ooooooooooooooool000003_oo00000ol0003oo`00
ool0000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00
ool0000<ool000;o0000T?ooool008Oooooo00Go0000ooooooooooooooooo`00000>ool00003o`00
0?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool00003o`00
0?oo003oo`0000_oo`000_l0002Aooooo`00R?ooool01?l0003oooooooooool0000>ool00003o`00
0?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool00003o`00
0?oo003oo`0000Woo`000_l000000ooo003o0000ooooo`2@ooooo`00R?ooool01?l0003ooooooooo
ool0000>ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00
ool0000<ool00003o`000?oo003oo`0000Ooo`000_l00003ool00003o`000?oooooooooo08oooooo
0029ooooo`03o`000?oooooo000000koo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0
000<ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00001Ooo0002o`0000Goo`0000?o
0000ooooooooool0Soooool008Wooooo00?o0000ooooool000003_oo00000ol0003oo`00ool0000<
ool00003o`000?oo003oo`0000coo`0000?o0000ool00?oo00003?oo000@o`00097ooooo0029oooo
o`03o`000?oooooo000000koo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool0
0003o`000?oo003oo`0000coo`0000?o0000ooooooooool00_ooool00ol0003oooooooooo`2Ioooo
o`00R_ooool2o`0000koo`0000?o0000ool00?oo00003?oo00000ol0003oo`00ool0000<ool00003
o`000?oo003oo`0000coo`0000?o0000ooooooooool00_l0002Looooo`00R_ooool2o`0000koo`00
00?o0000ool00?oo00000ooo0005o`0000Coo`0000?o0000ool00?oo00003?oo00000ol0003oo`00
ool0000<ool00003o`000?oooooo000009kooooo002:ooooo`;o00003_oo00001?l0003oo`00ool0
0?oo0002o`0000Goo`0000Go0000ool00?oo003oo`00o`00000>ool00003o`000?oo003oo`0000co
o`000_l0002Oooooo`00Roooool00ol0003oo`00ool0000<ool00004o`000?oo003oo`00o`0000So
o`0000Co0000ool00?oo003o00003_oo00000ol0003oo`00ool0000;ool000;o0000X?ooool008_o
oooo00?o0000ool00?oo00003?oo000@o`0000koo`0000?o0000ool00?oo00002Ooo0002o`000003
ool00?l0003ooooo09oooooo002;ooooo`;o00003Ooo0002o`0000cooooo0_l0000>ool00003o`00
0?oo003oo`0000Ooo`000_l00003ool00003o`000?oooooooooo09kooooo002;oooooa3o00003_oo
ool00ol0003oo`00ool0000<ool00003o`000?oo003oo`0000Koo`0000?o0000ool00?oo00000ooo
00000ol0003oooooooooo`2Nooooo`00SOooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00cooooo00?o0000ool00?oo00003?oo00000ol0003oo`00ool00005ool00003o`000?oo003o
o`0000Coo`0000?o0000ooooooooool0W_ooool008kooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0=ooooo`;o00003Ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`00
00Goo`0000?o0000ooooooooool0W_ooool008kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oo003o000000coo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00006ool00003o`000?oooooooooo09kooooo002?ooooo`;o00001oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oo003o000000coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00007ool00003o`000?oooooooooo09kooooo002Aooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool03oooool01?l0003oo`00ool00?l0000;ool0013o0000X?ooool009;ooooo00?o
0000ooooooooool00_l0000Booooo`04o`000?oo003oo`00ool000?o00001_oo0004o`000:kooooo
002Cooooo`;o00005?ooool@o`000:oooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo00?o0000ooooooooool0_?ooool008oooooo1?l000002?l@413oooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0_?ooool0097ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0;cooooo002Aoooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo
ooooooooool@41001_ooool3o`000;cooooo002Aooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`2looooo`00TOooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0_?ooool0097ooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooooooooa0@4006ooooo`03o`000?oooooooooo0;cooooo002Aooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool0
0ol0003oooooooooo`2looooo`00Soooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0_?oo
ool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2loooo
o`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00Soooool4o`000005oa0@
4?oooooooooooooooom4A4@00_l000002Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^
kP06ooooo`03o`000?oooooooooo0;cooooo002Aooooo`03o`000?oooooooooo00Kooooo00WoMgMg
oc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`2looooo`00
TOooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@oooooooo
ool01?ooool3o`000;cooooo002Aooooo`03o`000?oooooooooo00Kooooo00GoMgMgoc8b<_oooooo
ooooo`000003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0_?ooool0097ooooo
00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo0;cooooo002Aooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000oooo
ooooool0_?ooool0097ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`2looooo`00Soooool00omEEEGo
IVIVo`000005ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yoooo
o`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`00
0?oooooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool0
0:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo
00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000
ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00
ZOooool00ol0003oooooooooo`2looooo`00S_ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`2looooo`00
S_ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`2looooo`00Soooool00onH
V9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@00Kooooo00?o0000ooooooooool0_?ooool0093ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000
_?ooool0097ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;cooooo002Booooo`05o`00
0?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooo
ooooool01?ooool00ol0003oooooooooo`2looooo`00S_ooool01Ol0003o^[ZjoooooonHV9So410@
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_oo
ool00ol0003oooooooooo`2looooo`00S_ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Y
ooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wo
oooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002moooo
o`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03o`000?oooooooooo0;cooooo
002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002>oooo
o`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP06ooooo`03o`000?oooooooooo0;cooooo002>ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01ooo
ool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo
0;cooooo002?ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00Co0000oooooooooooo410@0oooool00ol@
413oooooooooo`04ooooo`?o0000_?ooool0093ooooo00?oV9RHob4Q8Oo^k^h01oooool01OmgMgOo
<S8boooooooooooo000000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2loooo
o`00TOooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0_?ooool009;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41001_ooool0
0ol0003oooooooooo`2looooo`00S_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000
ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0_?oo
ool008kooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Kooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?oo
ool00:Wooooo0_l0002mooooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool2o`000;gooooo002Yooooo`03
o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oo
oooooooo0;cooooo002Yooooo`03o`000?oooooooooo0;cooooo002Yooooo`03o`000?oooooooooo
0;cooooo002Yooooo`;o0000_Oooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo0_l0002mooooo`00ZOoo
ool00ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0
003oooooooooo`2looooo`00S_ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003ooooooooo
o`2looooo`00S_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`2looooo`00
T_ooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003oooo
o`03oa0@4?oooooooooo00Cooooo0ol0002looooo`00TOooool00onYZJWo410@ooooo`02ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo00000<Gooooo002@oooo
o`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool00000aOooool0097ooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooo
oooo410@00?ooooo00Go410@oooooooooooooooooa0@4035ooooo`00S_ooool01Ol@413oV9RHoooo
oonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL0aOooool008kooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^0<Gooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo002Nooooo`;o00002oooool00ol0003o^[Zjoooo
o`0<ooooo`;o0000[?ooool009kooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000
ooooooooool0Z_ooool009?ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o00000_ooool00on7QhOo0000okZj^P05
ooooo`05oiRHV?l0003o0000odA4A?nj^[X00oooool00ol0003oooooooooo`2Zooooo`00U?ooool0
1Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool00_ooool01_o^k^ko8B4QohN7
Qonj^[[o0000omgMg@;ooooo00?oc<c<o`000?l@41001Oooool01Ol@413o^[Zjonk^k_mgMgOo410@
00?ooooo00?o0000ooooooooool0Z_ooool009Cooooo00Go0000ooooooooooooooooo`000005oooo
o`03o`000?oooooooooo00?ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0:[ooooo002Dooooo`05o`000?ooooooooooooooool000001Oooool0
0ol0003oooooooooo`03ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`2Zooooo`00U?ooool5o`0000Gooooo00?o0000ooooooooool00oooool0
1?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Z_oo
ool009Cooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00;ooooo0_l0
0002ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Cooooo00?o0000ooooooooool0Z_oo
ool009Cooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`2Zooooo`00Toooool01?l@413o0000o`000?oo
ool2o`000003oa0@4?oooooooooo00;ooooo0_l0000Cooooo`03o`000?oooooooooo00Cooooo0_l0
002/ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-1.13909, -24.4154, \
0.00839893, 2.03847}}],

Cell[TextData[{
  "Fig. 7.3 Equilibrium density of particles vs. height ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ": theory (line) and simulation (histogram)."
}], "Caption",
  CellTags->"Fig. 7.3"],

Cell["\<\
The theoretical equilibrium density matches the late-time density \
found in the particle simulation. Note that this density, with a dip near the \
origin,  is far from what one might expect intuitively in an equilibrium gas. \
This is because we are used to thinking of thermal equilibrium states. The \
equilibrium shown above is a partial equilibrium caused by collisionless \
phase mixing of the initial condition. It is what one would see before \
collisions between particles have a chance of acting. In many systems, the \
collisions act so rapidly that partial equilibrium is not observed. However, \
in other systems, collisions occur rarely so that partial equilibrium is \
easily seen.  For instance, a gas can enter this collisionless regime if the \
density is sufficiently low so that atom-atom collisions can be ignored over \
the time range of interest.\
\>", "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["7.1.3 Nonlinear Waves", "Subsubtitle",
  CellTags->{"i:14", "c:10"}],

Cell[CellGroupData[{

Cell["A First-Order Nonlinear Wave Equation", "Section",
  CellTags->"c:11"],

Cell["\<\
\tWe now consider a nonlinear PDE that describes the evolution of \
shallow-water waves with small but finite amplitude:\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]z\/\[PartialD]t + \(\(c\_o\)(
              1 + \(3\/2\) z\/h)\) \[PartialD]z\/\[PartialD]x = 0\)]],
  ","
}], "NumberedEquation",
  CellTags->"(7.1.29)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`z(x, t)\)]],
  " is the wave height,  ",
  Cell[BoxData[
      \(TraditionalForm\`c\_o = \@\(g\ h\)\)]],
  " is the linear wave speed, ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  " is the acceleration of gravity, and ",
  Cell[BoxData[
      \(TraditionalForm\`h\)]],
  " is the equilibrium depth of the water [see Eq. ",
  ButtonBox["(3.1.79)",
    ButtonData:>{"Chapter3.nb", "(3.1.79)"},
    ButtonStyle->"Hyperlink"],
  " ]. The term ",
  Cell[BoxData[
      \(TraditionalForm\`3  z\ c\_o/2\ h\)]],
  " is the lowest-order nonlinear correction to the wave speed  due to finite \
wave height [see ",
  ButtonBox["Whitham (1999)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  " for a derivation of this correction]. Simply put, a wave peak increases \
the water depth, resulting in a local increase in wave speed. Without this \
term, solutions merely propagate to the right with speed ",
  Cell[BoxData[
      \(TraditionalForm\`c\_o\)]],
  ", describing linear shallow water waves [see Eq. ",
  ButtonBox["(7.1.14)",
    ButtonData:>{"Chapter7.nb", "(7.1.14)"},
    ButtonStyle->"Hyperlink"],
  " ]. Equation ",
  ButtonBox["(7.1.29)",
    ButtonData:>{"Chapter7.nb", "(7.1.29)"},
    ButtonStyle->"Hyperlink"],
  " neglects dispersion and viscous effects, and allows propagation in only \
one direction. Nevertheless,  its solutions  have much to tell us concerning \
the behavior of real finite-amplitude water waves. "
}], "Text",
  CellTags->"i:17"],

Cell[TextData[{
  "\tWe will first put the equation in a standard format.  This is \
accomplished by making a Galilean transformation to a moving frame, moving at \
speed ",
  Cell[BoxData[
      \(TraditionalForm\`c\_o\)]],
  ", via the change of variables ",
  Cell[BoxData[
      \(TraditionalForm\`x\&_ = x - \ \(\(c\_o\) \(t\)\(\ \)\)\)]],
  ". In this frame  Eq. ",
  ButtonBox["(7.1.29)",
    ButtonData:>{"Chapter7.nb", "(7.1.29)"},
    ButtonStyle->"Hyperlink"],
  "  becomes"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]z\/\[PartialD]t + \(3\/2\) \(c\_o\) \
\(z\/h\) \[PartialD]z\/\[PartialD]x\&_ = 0\)]],
  ". "
}], "UNNEQ"],

Cell[TextData[{
  "Next, we scale the wave height ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  ", defining ",
  Cell[BoxData[
      \(TraditionalForm\`f(x\&_, t) = 3\ c\_o\ z/\((2\ h)\)\)]],
  ".  Using these scaled variables, and dropping the overbar on ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " for notational convenience, we arrive at "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]f\/\[PartialD]t + 
          f \[PartialD]f\/\[PartialD]x = 0\)]],
  ". "
}], "NumberedEquation",
  CellTags->{"i:85", "(7.1.30)"}],

Cell[TextData[{
  "The simple form of the nonlinearity in Eq. ",
  ButtonBox["(7.1.30)",
    ButtonData:>{"Chapter7.nb", "(7.1.30)"},
    ButtonStyle->"Hyperlink"],
  "  appears in many other physical contexts, making the equation a \
paradigmatic nonlinear PDE. It is sometimes referred to as Burgers' equation \
without diffusion. The version with diffusion is discussed in Sec. ",
  ButtonBox["7.2.4",
    ButtonData:>"c:23",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Solution", "Section",
  CellTags->"c:12"],

Cell[TextData[{
  "\tUsing the method of characteristics we can obtain a complete analytic \
solution to Eq. ",
  ButtonBox["(7.1.30)",
    ButtonData:>{"Chapter7.nb", "(7.1.30)"},
    ButtonStyle->"Hyperlink"],
  " . (This is one of a mere handful of nonlinear PDEs where such a complete \
analytic solution is possible.) \tThe characteristics for Eq. ",
  ButtonBox["(7.1.30)",
    ButtonData:>{"Chapter7.nb", "(7.1.30)"},
    ButtonStyle->"Hyperlink"],
  "  are solutions to the equation"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]x/\[DifferentialD]t\  = \ 
        f(x, t)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(7.1.31)"],

Cell[TextData[{
  "Thus, the velocity along the characteristic ",
  StyleBox["depends on the amplitude of the solution along the \
characteristic",
    FontSlant->"Italic"],
  ". However, this is not as complicated as it sounds, because Eq. ",
  ButtonBox["(7.1.30)",
    ButtonData:>{"Chapter7.nb", "(7.1.30)"},
    ButtonStyle->"Hyperlink"],
  "  implies that "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]f/\[DifferentialD]t\  = \ 0\)]],
  " along the characteristics."
}], "NumberedEquation",
  CellTags->"(7.1.32)"],

Cell[TextData[{
  "Thus, ",
  Cell[BoxData[
      \(TraditionalForm\`f = constant\)]],
  " along each characteristic, retaining its initial value:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`f(x(t, x\_o), t)\  = \ \(f\_o\)(x\_o)\)]],
  ","
}], "NumberedEquation",
  CellTags->"(7.1.33)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_o\)(x) = f(x, 0)\)]],
  ".  Therefore, we can integrate Eq. ",
  ButtonBox["(7.1.31)",
    ButtonData:>{"Chapter7.nb", "(7.1.31)"},
    ButtonStyle->"Hyperlink"],
  "  to obtain an equation for the characteristics:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`x = \ x\_o + \(\(f\_o\)(x\_o)\)\ t\)]],
  ". "
}], "NumberedEquation",
  CellTags->{"i:18", "(7.1.34)"}],

Cell[TextData[{
  "Five of these nonlinear characteristics are depicted in Fig. ",
  ButtonBox["7.4",
    ButtonData:>"Fig. 7.4",
    ButtonStyle->"Hyperlink"],
  " They are straight lines in the ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, t)\)\)]],
  " plane, with slope that depends on ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_o\)(x\_o)\)]],
  "."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9646 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.07848 -0.00533562 1.07848 [
[.21289 .03628 -9.3742 -12 ]
[.21289 .03628 .6258 0 ]
[.84871 .30553 0 -8.01227 ]
[.84871 .30553 10 3.98773 ]
[-0.06055 .34522 -40 -3.77786 ]
[-0.06055 .34522 0 8.22214 ]
[ 0 0 0 0 ]
[ 1 .9646 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02975 .1885 m
.51756 0 L
s
gsave
.21289 .03628 -70.3742 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.51756 0 m
.9781 .59953 L
s
gsave
.84871 .30553 -61 -12.0123 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02975 .1885 m
0 .45327 L
s
gsave
-0.06055 .34522 -101 -7.77786 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(H) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(L) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02975 .1885 m
0 .45327 L
s
0 .45327 m
.55672 .9646 L
s
.55672 .9646 m
.55593 .72459 L
s
.55593 .72459 m
.02975 .1885 L
s
.51756 0 m
.9781 .59953 L
s
.9781 .59953 m
1 .84627 L
s
1 .84627 m
.51621 .27089 L
s
.51621 .27089 m
.51756 0 L
s
.02975 .1885 m
0 .45327 L
s
0 .45327 m
.51621 .27089 L
s
.51621 .27089 m
.51756 0 L
s
.51756 0 m
.02975 .1885 L
s
.55593 .72459 m
.9781 .59953 L
s
.9781 .59953 m
1 .84627 L
s
1 .84627 m
.55672 .9646 L
s
.55672 .9646 m
.55593 .72459 L
s
0 0 m
1 0 L
1 .9646 L
0 .9646 L
closepath
clip
newpath
.015 w
.55009 .71869 m
.55593 .72462 L
s
.54423 .71274 m
.55009 .71869 L
s
.53833 .70677 m
.54423 .71274 L
s
.5324 .7008 m
.53833 .70677 L
s
.52645 .69483 m
.5324 .7008 L
s
.52046 .68887 m
.52645 .69483 L
s
.51444 .68295 m
.52046 .68887 L
s
.5084 .67709 m
.51444 .68295 L
s
.50232 .67132 m
.5084 .67709 L
s
.49621 .66569 m
.50232 .67132 L
s
.76172 .66366 m
.75626 .65743 L
s
.49006 .66024 m
.49621 .66569 L
s
.75076 .65118 m
.75626 .65743 L
s
.48388 .65505 m
.49006 .66024 L
s
.74524 .64491 m
.75076 .65118 L
s
.47766 .6502 m
.48388 .65505 L
s
.5 Mabswid
.48186 .64913 m
.49024 .64662 L
s
.49024 .64662 m
.49864 .6441 L
s
.015 w
.73969 .63862 m
.74524 .64491 L
s
.5 Mabswid
.49864 .6441 m
.50705 .64159 L
s
.015 w
.4714 .64578 m
.47766 .6502 L
s
.5 Mabswid
.50705 .64159 m
.51548 .63906 L
s
.51548 .63906 m
.52393 .63654 L
s
.015 w
.73411 .63234 m
.73969 .63862 L
s
.5 Mabswid
.52393 .63654 m
.5324 .634 L
s
.015 w
.46509 .6419 m
.4714 .64578 L
s
.5 Mabswid
.5324 .634 m
.54088 .63146 L
s
.015 w
.72851 .62608 m
.73411 .63234 L
s
.5 Mabswid
.54088 .63146 m
.54938 .62892 L
s
.54938 .62892 m
.55789 .62637 L
s
.015 w
.45873 .63869 m
.46509 .6419 L
s
.5 Mabswid
.55789 .62637 m
.56643 .62382 L
s
.015 w
.72288 .61985 m
.72851 .62608 L
s
.5 Mabswid
.56643 .62382 m
.57498 .62126 L
s
.57498 .62126 m
.58355 .6187 L
s
.015 w
.45232 .63627 m
.45873 .63869 L
s
.71722 .61368 m
.72288 .61985 L
s
.5 Mabswid
.58355 .6187 m
.59213 .61613 L
s
.59213 .61613 m
.60073 .61355 L
s
.60073 .61355 m
.60936 .61097 L
s
.015 w
.71154 .60761 m
.71722 .61368 L
s
.5 Mabswid
.60936 .61097 m
.61799 .60839 L
s
.015 w
.44585 .63479 m
.45232 .63627 L
s
.5 Mabswid
.61799 .60839 m
.62665 .6058 L
s
.62665 .6058 m
.63532 .6032 L
s
.015 w
.70584 .6017 m
.71154 .60761 L
s
.5 Mabswid
.63532 .6032 m
.64401 .6006 L
s
.015 w
.43931 .6344 m
.44585 .63479 L
s
.5 Mabswid
.64401 .6006 m
.65272 .598 L
s
.015 w
.70011 .59601 m
.70584 .6017 L
s
.5 Mabswid
.65272 .598 m
.66145 .59538 L
s
.66145 .59538 m
.67019 .59277 L
s
.67019 .59277 m
.67895 .59015 L
s
.015 w
.43269 .63521 m
.43931 .6344 L
s
.69436 .59064 m
.70011 .59601 L
s
.96565 .5834 m
.9719 .5915 L
s
.5 Mabswid
.67895 .59015 m
.68773 .58752 L
s
.68773 .58752 m
.69653 .58488 L
s
.69653 .58488 m
.70535 .58225 L
s
.015 w
.68859 .58573 m
.69436 .59064 L
s
.95937 .57529 m
.96565 .5834 L
s
.5 Mabswid
.70535 .58225 m
.71418 .5796 L
s
.015 w
.42599 .63734 m
.43269 .63521 L
s
.5 Mabswid
.71418 .5796 m
.72304 .57695 L
s
.72304 .57695 m
.73191 .5743 L
s
.015 w
.68281 .58147 m
.68859 .58573 L
s
.95309 .56721 m
.95937 .57529 L
s
.5 Mabswid
.73191 .5743 m
.7408 .57164 L
s
.7408 .57164 m
.7497 .56897 L
s
.015 w
.4192 .64088 m
.42599 .63734 L
s
.5 Mabswid
.7497 .56897 m
.75863 .5663 L
s
0 1 0 r
.40303 .56882 m
.403 .56999 L
s
0 g
.40303 .56882 m
.41275 .56732 L
s
.015 w
.67702 .57814 m
.68281 .58147 L
s
0 1 0 r
.5 Mabswid
.403 .56999 m
.40297 .57117 L
s
.40297 .57117 m
.40294 .57234 L
s
0 g
.41275 .56732 m
.42248 .56582 L
s
0 1 0 r
.40294 .57234 m
.4029 .57352 L
s
0 g
.015 w
.94681 .55919 m
.95309 .56721 L
s
0 1 0 r
.5 Mabswid
.4029 .57352 m
.40287 .5747 L
s
0 g
.75863 .5663 m
.76757 .56363 L
s
.42248 .56582 m
.43222 .56433 L
s
0 1 0 r
.40287 .5747 m
.40284 .57588 L
s
.40284 .57588 m
.40281 .57706 L
s
.40281 .57706 m
.40277 .57823 L
s
0 g
.43222 .56433 m
.44197 .56283 L
s
0 1 0 r
.40277 .57823 m
.40274 .57941 L
s
0 g
.76757 .56363 m
.77654 .56094 L
s
0 1 0 r
.40274 .57941 m
.40271 .58059 L
s
0 g
.44197 .56283 m
.45174 .56132 L
s
0 1 0 r
.40271 .58059 m
.40268 .58178 L
s
.40268 .58178 m
.40264 .58296 L
s
.40264 .58296 m
.40261 .58414 L
s
0 g
.45174 .56132 m
.46151 .55982 L
s
.77654 .56094 m
.78552 .55826 L
s
0 1 0 r
.40261 .58414 m
.40258 .58532 L
s
0 g
.015 w
.67123 .57617 m
.67702 .57814 L
s
0 1 0 r
.5 Mabswid
.40258 .58532 m
.40254 .58651 L
s
0 g
.46151 .55982 m
.4713 .55832 L
s
0 1 0 r
.40254 .58651 m
.40251 .58769 L
s
.40251 .58769 m
.40248 .58887 L
s
0 g
.015 w
.94055 .55131 m
.94681 .55919 L
s
.4123 .64587 m
.4192 .64088 L
s
.5 Mabswid
.4713 .55832 m
.48109 .55681 L
s
0 1 0 r
.40248 .58887 m
.40245 .59006 L
s
0 g
.78552 .55826 m
.79452 .55556 L
s
0 1 0 r
.40245 .59006 m
.40241 .59124 L
s
.40241 .59124 m
.40238 .59243 L
s
0 g
.48109 .55681 m
.4909 .5553 L
s
0 1 0 r
.40238 .59243 m
.40235 .59362 L
s
.40235 .59362 m
.40231 .5948 L
s
0 g
.79452 .55556 m
.80354 .55286 L
s
.4909 .5553 m
.50072 .55379 L
s
0 1 0 r
.40231 .5948 m
.40228 .59599 L
s
.40228 .59599 m
.40225 .59718 L
s
.40225 .59718 m
.40222 .59837 L
s
0 g
.50072 .55379 m
.51055 .55228 L
s
0 1 0 r
.40222 .59837 m
.40218 .59956 L
s
0 g
.80354 .55286 m
.81257 .55016 L
s
0 1 0 r
.40218 .59956 m
.40215 .60075 L
s
0 g
.51055 .55228 m
.52039 .55076 L
s
0 1 0 r
.40215 .60075 m
.40212 .60194 L
s
.40212 .60194 m
.40208 .60313 L
s
0 g
.015 w
.66545 .57627 m
.67123 .57617 L
s
0 1 0 r
.5 Mabswid
.40208 .60313 m
.40205 .60432 L
s
0 g
.52039 .55076 m
.53025 .54925 L
s
.015 w
.93435 .54365 m
.94055 .55131 L
s
.5 Mabswid
.81257 .55016 m
.82163 .54745 L
s
0 1 0 r
.40205 .60432 m
.40202 .60551 L
s
.40202 .60551 m
.40198 .60671 L
s
0 g
.53025 .54925 m
.54011 .54773 L
s
0 1 0 r
.40198 .60671 m
.40195 .6079 L
s
.40195 .6079 m
.40192 .6091 L
s
0 g
.54011 .54773 m
.54999 .54621 L
s
0 1 0 r
.40192 .6091 m
.40188 .61029 L
s
0 g
.82163 .54745 m
.83071 .54473 L
s
0 1 0 r
.40188 .61029 m
.40185 .61149 L
s
.40185 .61149 m
.40182 .61268 L
s
0 g
.54999 .54621 m
.55988 .54469 L
s
0 1 0 r
.40182 .61268 m
.40179 .61388 L
s
0 g
.015 w
.40531 .65229 m
.4123 .64587 L
s
0 1 0 r
.5 Mabswid
.40179 .61388 m
.40175 .61507 L
s
0 g
.83071 .54473 m
.8398 .54201 L
s
.55988 .54469 m
.56978 .54317 L
s
0 1 0 r
.40175 .61507 m
.40172 .61627 L
s
.40172 .61627 m
.40169 .61747 L
s
.40169 .61747 m
.40165 .61867 L
s
0 g
.56978 .54317 m
.57969 .54164 L
s
0 1 0 r
.40165 .61867 m
.40162 .61987 L
s
0 g
.8398 .54201 m
.84891 .53929 L
s
0 1 0 r
.40162 .61987 m
.40159 .62107 L
s
0 g
.015 w
.92826 .53633 m
.93435 .54365 L
s
.5 Mabswid
.57969 .54164 m
.58961 .54011 L
s
0 1 0 r
.40159 .62107 m
.40155 .62227 L
s
.40155 .62227 m
.40152 .62347 L
s
0 g
.015 w
.65971 .57978 m
.66545 .57627 L
s
.5 Mabswid
.58961 .54011 m
.59955 .53859 L
s
0 1 0 r
.40152 .62347 m
.40149 .62467 L
s
.40149 .62467 m
.40145 .62587 L
s
0 g
.84891 .53929 m
.85805 .53655 L
s
0 1 0 r
.40145 .62587 m
.40142 .62708 L
s
0 g
.59955 .53859 m
.6095 .53706 L
s
0 1 0 r
.40142 .62708 m
.40139 .62828 L
s
.40139 .62828 m
.40135 .62948 L
s
0 g
.6095 .53706 m
.61945 .53552 L
s
0 1 0 r
.40135 .62948 m
.40132 .63069 L
s
0 g
.85805 .53655 m
.8672 .53381 L
s
0 1 0 r
.40132 .63069 m
.40129 .63189 L
s
.40129 .63189 m
.40125 .6331 L
s
0 g
.61945 .53552 m
.62942 .53399 L
s
0 1 0 r
.40125 .6331 m
.40122 .63431 L
s
.40122 .63431 m
.40119 .63551 L
s
0 g
.62942 .53399 m
.63941 .53246 L
s
.8672 .53381 m
.87637 .53107 L
s
0 1 0 r
.40119 .63551 m
.40115 .63672 L
s
0 g
.015 w
.92234 .52954 m
.92826 .53633 L
s
0 1 0 r
.5 Mabswid
.40115 .63672 m
.40112 .63793 L
s
.40112 .63793 m
.40109 .63914 L
s
0 g
.63941 .53246 m
.6494 .53092 L
s
.015 w
.3982 .66008 m
.40531 .65229 L
s
0 1 0 r
.5 Mabswid
.40109 .63914 m
.40105 .64035 L
s
.64607 .53143 m
.64609 .53261 L
s
.40105 .64035 m
.40102 .64156 L
s
0 g
.87637 .53107 m
.88556 .52832 L
s
.6494 .53092 m
.6594 .52938 L
s
0 1 0 r
.64609 .53261 m
.64612 .5338 L
s
.40102 .64156 m
.40098 .64277 L
s
.64612 .5338 m
.64614 .53498 L
s
.40098 .64277 m
.40095 .64398 L
s
.64614 .53498 m
.64617 .53617 L
s
0 g
.6594 .52938 m
.66942 .52784 L
s
0 1 0 r
.40095 .64398 m
.40092 .64519 L
s
.64617 .53617 m
.6462 .53735 L
s
.40092 .64519 m
.40088 .6464 L
s
0 g
.88556 .52832 m
.89477 .52556 L
s
0 1 0 r
.6462 .53735 m
.64622 .53854 L
s
0 g
.015 w
.65406 .58951 m
.65971 .57978 L
s
0 1 0 r
.5 Mabswid
.40088 .6464 m
.40085 .64761 L
s
0 g
.66942 .52784 m
.67945 .5263 L
s
0 1 0 r
.64622 .53854 m
.64625 .53973 L
s
.40085 .64761 m
.40082 .64883 L
s
.64625 .53973 m
.64627 .54091 L
s
.40082 .64883 m
.40078 .65004 L
s
.64627 .54091 m
.6463 .5421 L
s
0 g
.67945 .5263 m
.68949 .52475 L
s
0 1 0 r
.40078 .65004 m
.40075 .65125 L
s
.6463 .5421 m
.64633 .54329 L
s
0 g
.89477 .52556 m
.90399 .5228 L
s
0 1 0 r
.40075 .65125 m
.40072 .65247 L
s
0 g
.015 w
.91667 .52348 m
.92234 .52954 L
s
0 1 0 r
.5 Mabswid
.64633 .54329 m
.64635 .54448 L
s
.40072 .65247 m
.40068 .65369 L
s
0 g
.68949 .52475 m
.69954 .52321 L
s
0 1 0 r
.64635 .54448 m
.64638 .54567 L
s
.40068 .65369 m
.40065 .6549 L
s
.64638 .54567 m
.6464 .54686 L
s
.40065 .6549 m
.40061 .65612 L
s
0 g
.69954 .52321 m
.7096 .52166 L
s
0 1 0 r
.6464 .54686 m
.64643 .54805 L
s
.40061 .65612 m
.40058 .65734 L
s
0 g
.90399 .5228 m
.91324 .52004 L
s
0 1 0 r
.64643 .54805 m
.64646 .54924 L
s
.64646 .54924 m
.64648 .55043 L
s
0 g
.7096 .52166 m
.71968 .52011 L
s
0 1 0 r
.64648 .55043 m
.64651 .55162 L
s
.64651 .55162 m
.64653 .55282 L
s
0 g
.71968 .52011 m
.72977 .51856 L
s
.91633 .51911 m
.91324 .52004 L
s
0 1 0 r
.64653 .55282 m
.64656 .55401 L
s
.64656 .55401 m
.64659 .55521 L
s
.64659 .55521 m
.64661 .5564 L
s
0 g
.72977 .51856 m
.73987 .517 L
s
0 1 0 r
.64661 .5564 m
.64664 .5576 L
s
.64664 .5576 m
.64667 .55879 L
s
0 g
.015 w
.39098 .66907 m
.3982 .66008 L
s
.5 Mabswid
.73987 .517 m
.74998 .51545 L
s
.015 w
.91135 .51845 m
.91667 .52348 L
s
0 1 0 r
.5 Mabswid
.64667 .55879 m
.64669 .55999 L
s
.64669 .55999 m
.64672 .56119 L
s
.9139 .51595 m
.91415 .51918 L
s
0 g
.9139 .51595 m
.90993 .51574 L
s
.89802 .51508 m
.90993 .51574 L
s
.74998 .51545 m
.7601 .51389 L
s
0 1 0 r
.64672 .56119 m
.64674 .56238 L
s
0 g
.88609 .51442 m
.89802 .51508 L
s
0 1 0 r
.64674 .56238 m
.64677 .56358 L
s
0 g
.87417 .51377 m
.88609 .51442 L
s
0 1 0 r
.91415 .51918 m
.9144 .52241 L
s
.64677 .56358 m
.6468 .56478 L
s
0 g
.7601 .51389 m
.77024 .51233 L
s
.86223 .51311 m
.87417 .51377 L
s
0 1 0 r
.6468 .56478 m
.64682 .56598 L
s
0 g
.85029 .51245 m
.86223 .51311 L
s
0 1 0 r
.64682 .56598 m
.64685 .56718 L
s
0 g
.83835 .51179 m
.85029 .51245 L
s
0 1 0 r
.9144 .52241 m
.91465 .52565 L
s
0 g
.77024 .51233 m
.78038 .51077 L
s
.015 w
.64867 .61461 m
.65406 .58951 L
s
0 1 0 r
.5 Mabswid
.64685 .56718 m
.64688 .56838 L
s
0 g
.8264 .51113 m
.83835 .51179 L
s
0 1 0 r
.64688 .56838 m
.6469 .56958 L
s
0 g
.81444 .51048 m
.8264 .51113 L
s
0 1 0 r
.6469 .56958 m
.64693 .57078 L
s
0 g
.78038 .51077 m
.79054 .50921 L
s
0 1 0 r
.91465 .52565 m
.9149 .52889 L
s
0 g
.80247 .50982 m
.81444 .51048 L
s
0 1 0 r
.64693 .57078 m
.64695 .57199 L
s
0 g
.7905 .50916 m
.80247 .50982 L
s
0 1 0 r
.64695 .57199 m
.64698 .57319 L
s
0 g
.79054 .50921 m
.80072 .50764 L
s
.77853 .5085 m
.7905 .50916 L
s
0 1 0 r
.64698 .57319 m
.64701 .57439 L
s
.9149 .52889 m
.91515 .53213 L
s
0 g
.76655 .50784 m
.77853 .5085 L
s
.015 w
.90651 .51479 m
.91135 .51845 L
s
0 1 0 r
.5 Mabswid
.64701 .57439 m
.64703 .5756 L
s
0 g
.75456 .50718 m
.76655 .50784 L
s
0 1 0 r
.64703 .5756 m
.64706 .5768 L
s
0 g
.80072 .50764 m
.8109 .50608 L
s
.74257 .50652 m
.75456 .50718 L
s
0 1 0 r
.91515 .53213 m
.9154 .53538 L
s
.64706 .5768 m
.64709 .57801 L
s
0 g
.73057 .50586 m
.74257 .50652 L
s
0 1 0 r
.64709 .57801 m
.64711 .57921 L
s
0 g
.8109 .50608 m
.82109 .50451 L
s
.71856 .50519 m
.73057 .50586 L
s
0 1 0 r
.64711 .57921 m
.64714 .58042 L
s
.9154 .53538 m
.91565 .53863 L
s
0 g
.70655 .50453 m
.71856 .50519 L
s
0 1 0 r
.64714 .58042 m
.64717 .58163 L
s
0 g
.69453 .50387 m
.70655 .50453 L
s
.82109 .50451 m
.8313 .50294 L
s
0 1 0 r
.64717 .58163 m
.64719 .58284 L
s
0 g
.68251 .50321 m
.69453 .50387 L
s
0 1 0 r
.64719 .58284 m
.64722 .58404 L
s
.91565 .53863 m
.9159 .54189 L
s
0 g
.67048 .50255 m
.68251 .50321 L
s
0 1 0 r
.64722 .58404 m
.64725 .58525 L
s
0 g
.8313 .50294 m
.84152 .50136 L
s
.65844 .50188 m
.67048 .50255 L
s
0 1 0 r
.64725 .58525 m
.64727 .58646 L
s
0 g
.015 w
.38365 .67903 m
.39098 .66907 L
s
.5 Mabswid
.6464 .50122 m
.65844 .50188 L
s
0 1 0 r
.9159 .54189 m
.91615 .54515 L
s
.64727 .58646 m
.6473 .58767 L
s
0 g
.84152 .50136 m
.85175 .49979 L
s
.63435 .50056 m
.6464 .50122 L
s
0 1 0 r
.6473 .58767 m
.64732 .58888 L
s
0 g
.6223 .49989 m
.63435 .50056 L
s
0 1 0 r
.64732 .58888 m
.64735 .59009 L
s
0 g
.015 w
.9023 .51289 m
.90651 .51479 L
s
0 1 0 r
.5 Mabswid
.91615 .54515 m
.9164 .54841 L
s
0 g
.61024 .49923 m
.6223 .49989 L
s
0 1 0 r
.64735 .59009 m
.64738 .59131 L
s
0 g
.85175 .49979 m
.862 .49822 L
s
0 1 0 r
.61828 .49967 m
.61833 .50291 L
s
.64738 .59131 m
.6474 .59252 L
s
0 g
.59818 .49856 m
.61024 .49923 L
s
0 1 0 r
.6474 .59252 m
.64743 .59373 L
s
0 g
.5861 .4979 m
.59818 .49856 L
s
0 1 0 r
.9164 .54841 m
.91666 .55168 L
s
0 g
.862 .49822 m
.87225 .49664 L
s
0 1 0 r
.64743 .59373 m
.64746 .59495 L
s
.61833 .50291 m
.61839 .50615 L
s
0 g
.57403 .49723 m
.5861 .4979 L
s
0 1 0 r
.64746 .59495 m
.64748 .59616 L
s
0 g
.56194 .49657 m
.57403 .49723 L
s
.87225 .49664 m
.88252 .49506 L
s
0 1 0 r
.64748 .59616 m
.64751 .59737 L
s
0 g
.54985 .4959 m
.56194 .49657 L
s
0 1 0 r
.91666 .55168 m
.91691 .55496 L
s
.61839 .50615 m
.61844 .50939 L
s
.64751 .59737 m
.64754 .59859 L
s
0 g
.53776 .49524 m
.54985 .4959 L
s
0 1 0 r
.64754 .59859 m
.64756 .59981 L
s
0 g
.52565 .49457 m
.53776 .49524 L
s
.88252 .49506 m
.8928 .49348 L
s
0 1 0 r
.91691 .55496 m
.91716 .55824 L
s
.64756 .59981 m
.64759 .60102 L
s
0 g
.51355 .4939 m
.52565 .49457 L
s
0 1 0 r
.61844 .50939 m
.61849 .51264 L
s
.64759 .60102 m
.64762 .60224 L
s
0 g
.50143 .49324 m
.51355 .4939 L
s
.89623 .49295 m
.8928 .49348 L
s
0 1 0 r
.64762 .60224 m
.64764 .60346 L
s
0 g
.48931 .49257 m
.50143 .49324 L
s
0 1 0 r
.91716 .55824 m
.91741 .56152 L
s
.89623 .49295 m
.89632 .49414 L
s
.64764 .60346 m
.64767 .60468 L
s
0 g
.47719 .4919 m
.48931 .49257 L
s
0 1 0 r
.61849 .51264 m
.61855 .51589 L
s
.89632 .49414 m
.89641 .49533 L
s
0 g
.015 w
.89888 .51319 m
.9023 .51289 L
s
0 1 0 r
.5 Mabswid
.64767 .60468 m
.6477 .6059 L
s
0 g
.46505 .49123 m
.47719 .4919 L
s
0 1 0 r
.89641 .49533 m
.89649 .49652 L
s
.6477 .6059 m
.64772 .60712 L
s
0 g
.45291 .49056 m
.46505 .49123 L
s
0 1 0 r
.91741 .56152 m
.91767 .56481 L
s
.89649 .49652 m
.89658 .49772 L
s
.61855 .51589 m
.6186 .51915 L
s
.64772 .60712 m
.64775 .60834 L
s
0 g
.44077 .48989 m
.45291 .49056 L
s
0 1 0 r
.89658 .49772 m
.89667 .49891 L
s
.64775 .60834 m
.64778 .60956 L
s
0 g
.42862 .48922 m
.44077 .48989 L
s
0 1 0 r
.89667 .49891 m
.89676 .5001 L
s
.91767 .56481 m
.91792 .5681 L
s
.64778 .60956 m
.6478 .61078 L
s
0 g
.41646 .48856 m
.42862 .48922 L
s
0 1 0 r
.89676 .5001 m
.89685 .5013 L
s
.6186 .51915 m
.61865 .52241 L
s
.6478 .61078 m
.64783 .612 L
s
0 g
.4043 .48789 m
.41646 .48856 L
s
0 1 0 r
.89685 .5013 m
.89694 .50249 L
s
0 g
.015 w
.64439 .6978 m
.64867 .61461 L
s
0 1 0 r
.5 Mabswid
.64783 .612 m
.64786 .61322 L
s
0 g
.39213 .48721 m
.4043 .48789 L
s
0 1 0 r
.89694 .50249 m
.89702 .50369 L
s
.91792 .5681 m
.91818 .57139 L
s
.64786 .61322 m
.64788 .61445 L
s
0 g
.37996 .48654 m
.39213 .48721 L
s
0 1 0 r
.61865 .52241 m
.61871 .52568 L
s
.89702 .50369 m
.89711 .50489 L
s
.64788 .61445 m
.64791 .61567 L
s
0 g
.36777 .48587 m
.37996 .48654 L
s
0 1 0 r
.89711 .50489 m
.8972 .50608 L
s
0 g
.015 w
.37621 .68965 m
.38365 .67903 L
s
0 1 0 r
.5 Mabswid
.64791 .61567 m
.64794 .61689 L
s
0 g
.35559 .4852 m
.36777 .48587 L
s
0 1 0 r
.91818 .57139 m
.91843 .57469 L
s
.8972 .50608 m
.89729 .50728 L
s
.64794 .61689 m
.64797 .61812 L
s
.61871 .52568 m
.61876 .52895 L
s
0 g
.34339 .48453 m
.35559 .4852 L
s
0 1 0 r
.89729 .50728 m
.89738 .50848 L
s
.64797 .61812 m
.64799 .61935 L
s
0 g
.33119 .48386 m
.34339 .48453 L
s
0 1 0 r
.89738 .50848 m
.89747 .50968 L
s
0 g
.015 w
.89641 .51614 m
.89888 .51319 L
s
0 1 0 r
.5 Mabswid
.64799 .61935 m
.64802 .62057 L
s
.91843 .57469 m
.91868 .578 L
s
0 g
.31899 .48319 m
.33119 .48386 L
s
0 1 0 r
.89747 .50968 m
.89755 .51088 L
s
.61876 .52895 m
.61881 .53222 L
s
.31899 .48319 m
.31884 .48643 L
s
.89755 .51088 m
.89764 .51208 L
s
.89764 .51208 m
.89773 .51328 L
s
.91868 .578 m
.91894 .58131 L
s
.61881 .53222 m
.61887 .5355 L
s
.89773 .51328 m
.89782 .51448 L
s
.31884 .48643 m
.31869 .48968 L
s
.89782 .51448 m
.89791 .51568 L
s
.91894 .58131 m
.9192 .58462 L
s
.89791 .51568 m
.898 .51688 L
s
.61887 .5355 m
.61892 .53879 L
s
.898 .51688 m
.89809 .51809 L
s
.31869 .48968 m
.31854 .49293 L
s
.89809 .51809 m
.89817 .51929 L
s
.9192 .58462 m
.91945 .58794 L
s
.89817 .51929 m
.89826 .52049 L
s
.61892 .53879 m
.61897 .54207 L
s
.89826 .52049 m
.89835 .5217 L
s
.31854 .49293 m
.31839 .49619 L
s
.89835 .5217 m
.89844 .5229 L
s
.91945 .58794 m
.91971 .59126 L
s
0 g
.015 w
.89506 .5222 m
.89641 .51614 L
s
0 1 0 r
.5 Mabswid
.89844 .5229 m
.89853 .52411 L
s
.61897 .54207 m
.61903 .54537 L
s
.31839 .49619 m
.31825 .49945 L
s
.89853 .52411 m
.89862 .52532 L
s
.89862 .52532 m
.89871 .52652 L
s
.91971 .59126 m
.91996 .59459 L
s
.61903 .54537 m
.61908 .54866 L
s
.89871 .52652 m
.8988 .52773 L
s
.31825 .49945 m
.3181 .50272 L
s
.8988 .52773 m
.89889 .52894 L
s
.91996 .59459 m
.92022 .59792 L
s
.89889 .52894 m
.89898 .53015 L
s
.61908 .54866 m
.61913 .55196 L
s
.89898 .53015 m
.89907 .53136 L
s
.3181 .50272 m
.31795 .50599 L
s
.89907 .53136 m
.89915 .53257 L
s
.92022 .59792 m
.92048 .60126 L
s
.89915 .53257 m
.89924 .53378 L
s
.61913 .55196 m
.61919 .55527 L
s
.31795 .50599 m
.3178 .50927 L
s
.89924 .53378 m
.89933 .53499 L
s
.89933 .53499 m
.89942 .5362 L
s
0 g
.015 w
.36868 .70053 m
.37621 .68965 L
s
0 1 0 r
.5 Mabswid
.92048 .60126 m
.92073 .6046 L
s
0 g
.015 w
.89498 .53173 m
.89506 .5222 L
s
0 1 0 r
.5 Mabswid
.61919 .55527 m
.61924 .55858 L
s
.89942 .5362 m
.89951 .53742 L
s
.3178 .50927 m
.31765 .51255 L
s
.89951 .53742 m
.8996 .53863 L
s
.92073 .6046 m
.92099 .60794 L
s
.8996 .53863 m
.89969 .53984 L
s
.61924 .55858 m
.6193 .5619 L
s
.89969 .53984 m
.89978 .54106 L
s
.31765 .51255 m
.3175 .51583 L
s
.89978 .54106 m
.89987 .54227 L
s
.92099 .60794 m
.92125 .61129 L
s
.89987 .54227 m
.89996 .54349 L
s
.6193 .5619 m
.61935 .56521 L
s
.89996 .54349 m
.90005 .5447 L
s
.3175 .51583 m
.31735 .51912 L
s
.90005 .5447 m
.90014 .54592 L
s
.92125 .61129 m
.92151 .61465 L
s
.90014 .54592 m
.90023 .54714 L
s
.61935 .56521 m
.6194 .56854 L
s
.31735 .51912 m
.3172 .52241 L
s
.90023 .54714 m
.90032 .54836 L
s
.90032 .54836 m
.90041 .54957 L
s
0 g
.015 w
.89624 .54498 m
.89498 .53173 L
s
0 1 0 r
.5 Mabswid
.92151 .61465 m
.92177 .61801 L
s
.6194 .56854 m
.61946 .57187 L
s
.90041 .54957 m
.9005 .55079 L
s
.3172 .52241 m
.31705 .52571 L
s
.9005 .55079 m
.90059 .55201 L
s
.92177 .61801 m
.92203 .62137 L
s
.90059 .55201 m
.90068 .55323 L
s
.61946 .57187 m
.61951 .5752 L
s
.90068 .55323 m
.90077 .55445 L
s
.31705 .52571 m
.3169 .52901 L
s
.90077 .55445 m
.90086 .55568 L
s
.92203 .62137 m
.92229 .62474 L
s
.90086 .55568 m
.90095 .5569 L
s
.61951 .5752 m
.61957 .57854 L
s
.3169 .52901 m
.31675 .53232 L
s
.90095 .5569 m
.90104 .55812 L
s
.90104 .55812 m
.90113 .55935 L
s
.92229 .62474 m
.92255 .62811 L
s
.61957 .57854 m
.61962 .58188 L
s
.90113 .55935 m
.90122 .56057 L
s
.31675 .53232 m
.3166 .53563 L
s
0 g
.015 w
.89889 .56203 m
.89624 .54498 L
s
0 1 0 r
.5 Mabswid
.90122 .56057 m
.90131 .56179 L
s
.92255 .62811 m
.92281 .63149 L
s
.90131 .56179 m
.9014 .56302 L
s
.61962 .58188 m
.61968 .58522 L
s
.9014 .56302 m
.90149 .56425 L
s
.3166 .53563 m
.31644 .53894 L
s
.90149 .56425 m
.90158 .56547 L
s
.92281 .63149 m
.92307 .63487 L
s
0 g
.015 w
.36106 .71118 m
.36868 .70053 L
s
0 1 0 r
.5 Mabswid
.90158 .56547 m
.90167 .5667 L
s
.61968 .58522 m
.61973 .58858 L
s
.90167 .5667 m
.90176 .56793 L
s
.31644 .53894 m
.31629 .54226 L
s
.90176 .56793 m
.90185 .56915 L
s
.92307 .63487 m
.92333 .63826 L
s
.90185 .56915 m
.90194 .57038 L
s
.61973 .58858 m
.61979 .59193 L
s
.31629 .54226 m
.31614 .54559 L
s
.90194 .57038 m
.90204 .57161 L
s
.90204 .57161 m
.90213 .57284 L
s
.92333 .63826 m
.92359 .64165 L
s
0 g
.015 w
.90285 .58271 m
.89889 .56203 L
s
0 1 0 r
.5 Mabswid
.61979 .59193 m
.61984 .59529 L
s
.90213 .57284 m
.90222 .57407 L
s
.31614 .54559 m
.31599 .54892 L
s
.90222 .57407 m
.90231 .57531 L
s
.92359 .64165 m
.92385 .64504 L
s
.90231 .57531 m
.9024 .57654 L
s
.61984 .59529 m
.6199 .59866 L
s
.9024 .57654 m
.90249 .57777 L
s
.31599 .54892 m
.31584 .55225 L
s
.90249 .57777 m
.90258 .579 L
s
.92385 .64504 m
.92411 .64844 L
s
.90258 .579 m
.90267 .58024 L
s
.6199 .59866 m
.61995 .60202 L
s
.31584 .55225 m
.31569 .55559 L
s
.90267 .58024 m
.90276 .58147 L
s
.90276 .58147 m
.90285 .58271 L
s
.92411 .64844 m
.92438 .65185 L
s
.61995 .60202 m
.62001 .6054 L
s
0 g
.015 w
.90797 .60655 m
.90285 .58271 L
s
0 1 0 r
.5 Mabswid
.31569 .55559 m
.31553 .55893 L
s
.92438 .65185 m
.92464 .65526 L
s
.62001 .6054 m
.62006 .60878 L
s
.31553 .55893 m
.31538 .56228 L
s
.92464 .65526 m
.9249 .65867 L
s
.62006 .60878 m
.62012 .61216 L
s
.31538 .56228 m
.31523 .56563 L
s
.9249 .65867 m
.92517 .66209 L
s
.62012 .61216 m
.62017 .61555 L
s
0 g
.015 w
.91396 .6328 m
.90797 .60655 L
s
0 1 0 r
.5 Mabswid
.31523 .56563 m
.31507 .56899 L
s
.92517 .66209 m
.92543 .66551 L
s
0 g
.015 w
.35339 .72109 m
.36106 .71118 L
s
0 1 0 r
.5 Mabswid
.62017 .61555 m
.62023 .61894 L
s
.31507 .56899 m
.31492 .57235 L
s
.92543 .66551 m
.92569 .66894 L
s
.62023 .61894 m
.62028 .62234 L
s
.31492 .57235 m
.31477 .57571 L
s
.92569 .66894 m
.92596 .67238 L
s
0 g
.015 w
.92042 .66037 m
.91396 .6328 L
s
0 1 0 r
.5 Mabswid
.62028 .62234 m
.62034 .62574 L
s
0 g
.015 w
.63916 .74574 m
.64439 .6978 L
s
0 1 0 r
.5 Mabswid
.31477 .57571 m
.31461 .57908 L
s
.92596 .67238 m
.92622 .67581 L
s
.62034 .62574 m
.62039 .62914 L
s
.31461 .57908 m
.31446 .58246 L
s
.92622 .67581 m
.92649 .67926 L
s
.62039 .62914 m
.62045 .63255 L
s
.31446 .58246 m
.31431 .58584 L
s
.92649 .67926 m
.92675 .6827 L
s
0 g
.015 w
.92687 .68794 m
.92042 .66037 L
s
0 1 0 r
.5 Mabswid
.62045 .63255 m
.62051 .63597 L
s
.31431 .58584 m
.31415 .58922 L
s
.92675 .6827 m
.92702 .68615 L
s
.62051 .63597 m
.62056 .63939 L
s
.31415 .58922 m
.314 .59261 L
s
.92702 .68615 m
.92729 .68961 L
s
.62056 .63939 m
.62062 .64282 L
s
.314 .59261 m
.31384 .596 L
s
0 g
.015 w
.93273 .71395 m
.92687 .68794 L
s
0 1 0 r
.5 Mabswid
.92729 .68961 m
.92755 .69307 L
s
.62062 .64282 m
.62067 .64625 L
s
.31384 .596 m
.31369 .5994 L
s
0 g
.015 w
.34567 .72971 m
.35339 .72109 L
s
0 1 0 r
.5 Mabswid
.92755 .69307 m
.92782 .69654 L
s
.62067 .64625 m
.62073 .64968 L
s
.31369 .5994 m
.31353 .60281 L
s
.92782 .69654 m
.92809 .70001 L
s
.62073 .64968 m
.62078 .65312 L
s
.31353 .60281 m
.31338 .60621 L
s
0 g
.015 w
.93739 .73676 m
.93273 .71395 L
s
0 1 0 r
.5 Mabswid
.92809 .70001 m
.92836 .70348 L
s
.62078 .65312 m
.62084 .65656 L
s
.31338 .60621 m
.31322 .60962 L
s
.92836 .70348 m
.92862 .70696 L
s
.62084 .65656 m
.6209 .66001 L
s
.31322 .60962 m
.31306 .61304 L
s
.92862 .70696 m
.92889 .71045 L
s
.6209 .66001 m
.62095 .66346 L
s
.31306 .61304 m
.31291 .61646 L
s
0 g
.015 w
.94026 .75477 m
.93739 .73676 L
s
0 1 0 r
.5 Mabswid
.92889 .71045 m
.92916 .71394 L
s
.62095 .66346 m
.62101 .66692 L
s
.31291 .61646 m
.31275 .61989 L
s
.92916 .71394 m
.92943 .71743 L
s
.62101 .66692 m
.62107 .67039 L
s
.31275 .61989 m
.3126 .62332 L
s
.92943 .71743 m
.9297 .72093 L
s
.62107 .67039 m
.62112 .67385 L
s
.3126 .62332 m
.31244 .62676 L
s
.9297 .72093 m
.92997 .72444 L
s
.62112 .67385 m
.62118 .67733 L
s
0 g
.015 w
.33794 .73647 m
.34567 .72971 L
s
.94079 .76651 m
.94026 .75477 L
s
0 1 0 r
.5 Mabswid
.31244 .62676 m
.31228 .6302 L
s
.92997 .72444 m
.93024 .72795 L
s
.62118 .67733 m
.62124 .6808 L
s
.31228 .6302 m
.31212 .63364 L
s
.93024 .72795 m
.93051 .73146 L
s
.62124 .6808 m
.62129 .68429 L
s
.31212 .63364 m
.31197 .63709 L
s
.93051 .73146 m
.93078 .73498 L
s
.62129 .68429 m
.62135 .68777 L
s
.31197 .63709 m
.31181 .64055 L
s
.93078 .73498 m
.93105 .7385 L
s
0 g
.015 w
.93855 .77081 m
.94079 .76651 L
s
0 1 0 r
.5 Mabswid
.62135 .68777 m
.62141 .69126 L
s
.31181 .64055 m
.31165 .64401 L
s
0 g
.015 w
.63307 .75596 m
.63916 .74574 L
s
0 1 0 r
.5 Mabswid
.93105 .7385 m
.93133 .74203 L
s
.62141 .69126 m
.62146 .69476 L
s
.31165 .64401 m
.31149 .64747 L
s
.93133 .74203 m
.9316 .74557 L
s
.62146 .69476 m
.62152 .69826 L
s
.31149 .64747 m
.31134 .65094 L
s
.22918 .39169 m
.2291 .3929 L
s
0 g
.22918 .39169 m
.23946 .38998 L
s
0 1 0 r
.9316 .74557 m
.93187 .74911 L
s
.2291 .3929 m
.22902 .39411 L
s
.62152 .69826 m
.62158 .70177 L
s
.31134 .65094 m
.31118 .65441 L
s
.22902 .39411 m
.22894 .39532 L
s
0 g
.23946 .38998 m
.24975 .38827 L
s
0 1 0 r
.22894 .39532 m
.22886 .39653 L
s
.93187 .74911 m
.93214 .75265 L
s
0 g
.015 w
.33023 .74085 m
.33794 .73647 L
s
0 1 0 r
.5 Mabswid
.62158 .70177 m
.62164 .70528 L
s
.22886 .39653 m
.22879 .39775 L
s
0 g
.015 w
.93324 .76687 m
.93855 .77081 L
s
0 1 0 r
.5 Mabswid
.31118 .65441 m
.31102 .65789 L
s
0 g
.24975 .38827 m
.26005 .38656 L
s
0 1 0 r
.22879 .39775 m
.22871 .39896 L
s
.93214 .75265 m
.93242 .7562 L
s
.22871 .39896 m
.22863 .40018 L
s
.62164 .70528 m
.62169 .7088 L
s
.22863 .40018 m
.22855 .40139 L
s
.31102 .65789 m
.31086 .66138 L
s
0 g
.26005 .38656 m
.27036 .38485 L
s
0 1 0 r
.22855 .40139 m
.22847 .40261 L
s
.93242 .7562 m
.93269 .75975 L
s
.22847 .40261 m
.22839 .40382 L
s
.62169 .7088 m
.62175 .71232 L
s
0 g
.27036 .38485 m
.28069 .38313 L
s
0 1 0 r
.31086 .66138 m
.3107 .66486 L
s
.22839 .40382 m
.22831 .40504 L
s
.22831 .40504 m
.22823 .40626 L
s
.93269 .75975 m
.93297 .76331 L
s
.22823 .40626 m
.22815 .40748 L
s
.62175 .71232 m
.62181 .71584 L
s
0 g
.28069 .38313 m
.29103 .38142 L
s
0 1 0 r
.3107 .66486 m
.31054 .66836 L
s
.22815 .40748 m
.22807 .40869 L
s
.22807 .40869 m
.22799 .40991 L
s
.93297 .76331 m
.93324 .76687 L
s
0 g
.29103 .38142 m
.30139 .3797 L
s
0 1 0 r
.62181 .71584 m
.62187 .71937 L
s
.22799 .40991 m
.22791 .41113 L
s
.31054 .66836 m
.31038 .67186 L
s
.22791 .41113 m
.22783 .41235 L
s
0 g
.015 w
.92473 .75435 m
.93324 .76687 L
s
.5 Mabswid
.30139 .3797 m
.31175 .37797 L
s
0 1 0 r
.22783 .41235 m
.22775 .41357 L
s
.62187 .71937 m
.62192 .72291 L
s
.22775 .41357 m
.22767 .4148 L
s
.31038 .67186 m
.31022 .67536 L
s
0 g
.015 w
.62671 .75508 m
.63307 .75596 L
s
0 1 0 r
.5 Mabswid
.22767 .4148 m
.22759 .41602 L
s
0 g
.31175 .37797 m
.32213 .37625 L
s
0 1 0 r
.22759 .41602 m
.22751 .41724 L
s
.62192 .72291 m
.62198 .72645 L
s
.31022 .67536 m
.31006 .67887 L
s
.22751 .41724 m
.22743 .41847 L
s
0 g
.32213 .37625 m
.33252 .37453 L
s
0 1 0 r
.22743 .41847 m
.22735 .41969 L
s
0 g
.015 w
.32256 .74239 m
.33023 .74085 L
s
0 1 0 r
.5 Mabswid
.62198 .72645 m
.62204 .73 L
s
.22735 .41969 m
.22727 .42092 L
s
.31006 .67887 m
.3099 .68238 L
s
.22727 .42092 m
.22719 .42214 L
s
0 g
.33252 .37453 m
.34293 .3728 L
s
0 1 0 r
.22719 .42214 m
.22711 .42337 L
s
.62204 .73 m
.6221 .73355 L
s
.22711 .42337 m
.22703 .42459 L
s
.3099 .68238 m
.30974 .6859 L
s
0 g
.34293 .3728 m
.35335 .37107 L
s
0 1 0 r
.22703 .42459 m
.22695 .42582 L
s
.22695 .42582 m
.22687 .42705 L
s
.6221 .73355 m
.62215 .7371 L
s
.30974 .6859 m
.30958 .68942 L
s
.22687 .42705 m
.22679 .42828 L
s
0 g
.35335 .37107 m
.36378 .36933 L
s
0 1 0 r
.22679 .42828 m
.22671 .42951 L
s
0 g
.015 w
.91306 .73341 m
.92473 .75435 L
s
0 1 0 r
.5 Mabswid
.22671 .42951 m
.22663 .43074 L
s
.62215 .7371 m
.62221 .74066 L
s
0 g
.36378 .36933 m
.37422 .3676 L
s
0 1 0 r
.30958 .68942 m
.30942 .69295 L
s
.22663 .43074 m
.22655 .43197 L
s
.22655 .43197 m
.22646 .4332 L
s
.62221 .74066 m
.62227 .74423 L
s
0 g
.37422 .3676 m
.38468 .36586 L
s
0 1 0 r
.22646 .4332 m
.22638 .43443 L
s
0 g
.015 w
.62022 .74899 m
.62671 .75508 L
s
0 1 0 r
.5 Mabswid
.30942 .69295 m
.30926 .69648 L
s
.22638 .43443 m
.2263 .43566 L
s
.2263 .43566 m
.22622 .4369 L
s
0 g
.38468 .36586 m
.39515 .36412 L
s
0 1 0 r
.62227 .74423 m
.62233 .7478 L
s
.22622 .4369 m
.22614 .43813 L
s
.30926 .69648 m
.3091 .70002 L
s
.22614 .43813 m
.22606 .43937 L
s
0 g
.39515 .36412 m
.40563 .36238 L
s
0 1 0 r
.22606 .43937 m
.22598 .4406 L
s
.62233 .7478 m
.62239 .75137 L
s
.3091 .70002 m
.30894 .70356 L
s
.22598 .4406 m
.2259 .44184 L
s
0 g
.015 w
.31497 .74074 m
.32256 .74239 L
s
0 1 0 r
.5 Mabswid
.2259 .44184 m
.22582 .44307 L
s
0 g
.40563 .36238 m
.41613 .36064 L
s
0 1 0 r
.22582 .44307 m
.22574 .44431 L
s
.30894 .70356 m
.30877 .70711 L
s
.22574 .44431 m
.22566 .44555 L
s
0 g
.41613 .36064 m
.42663 .35889 L
s
0 1 0 r
.22566 .44555 m
.22558 .44679 L
s
.22558 .44679 m
.22549 .44803 L
s
.30877 .70711 m
.30861 .71066 L
s
0 g
.015 w
.61365 .73981 m
.62022 .74899 L
s
.5 Mabswid
.42663 .35889 m
.43716 .35715 L
s
0 1 0 r
.22549 .44803 m
.22541 .44926 L
s
0 g
.015 w
.89848 .70465 m
.91306 .73341 L
s
0 1 0 r
.5 Mabswid
.22541 .44926 m
.22533 .45051 L
s
.22533 .45051 m
.22525 .45175 L
s
.30861 .71066 m
.30845 .71422 L
s
0 g
.43716 .35715 m
.44769 .3554 L
s
0 1 0 r
.22525 .45175 m
.22517 .45299 L
s
.22517 .45299 m
.22509 .45423 L
s
.30845 .71422 m
.30829 .71778 L
s
0 g
.44769 .3554 m
.45824 .35365 L
s
0 1 0 r
.22509 .45423 m
.22501 .45547 L
s
.22501 .45547 m
.22493 .45672 L
s
.22493 .45672 m
.22484 .45796 L
s
0 g
.45824 .35365 m
.4688 .35189 L
s
0 1 0 r
.30829 .71778 m
.30812 .72135 L
s
.22484 .45796 m
.22476 .4592 L
s
0 g
.015 w
.60702 .72863 m
.61365 .73981 L
s
.30747 .73567 m
.31497 .74074 L
s
0 1 0 r
.5 Mabswid
.22476 .4592 m
.22468 .46045 L
s
0 g
.4688 .35189 m
.47938 .35013 L
s
0 1 0 r
.22468 .46045 m
.2246 .4617 L
s
.30812 .72135 m
.30796 .72492 L
s
.2246 .4617 m
.22452 .46294 L
s
.22452 .46294 m
.22444 .46419 L
s
0 g
.47938 .35013 m
.48997 .34838 L
s
0 1 0 r
.30796 .72492 m
.3078 .7285 L
s
.22444 .46419 m
.22435 .46544 L
s
.48644 .34896 m
.48642 .35018 L
s
.22435 .46544 m
.22427 .46669 L
s
0 g
.48997 .34838 m
.50057 .34662 L
s
0 1 0 r
.48642 .35018 m
.48641 .3514 L
s
.22427 .46669 m
.22419 .46794 L
s
.3078 .7285 m
.30763 .73208 L
s
.48641 .3514 m
.48639 .35262 L
s
.22419 .46794 m
.22411 .46919 L
s
0 g
.015 w
.60034 .71593 m
.60702 .72863 L
s
0 1 0 r
.5 Mabswid
.48639 .35262 m
.48638 .35384 L
s
0 g
.015 w
.88134 .66913 m
.89848 .70465 L
s
.5 Mabswid
.50057 .34662 m
.51118 .34485 L
s
0 1 0 r
.22411 .46919 m
.22403 .47044 L
s
.48638 .35384 m
.48637 .35506 L
s
.22403 .47044 m
.22395 .47169 L
s
.30763 .73208 m
.30747 .73567 L
s
.48637 .35506 m
.48635 .35628 L
s
.22395 .47169 m
.22386 .47294 L
s
0 g
.51118 .34485 m
.52181 .34309 L
s
0 1 0 r
.48635 .35628 m
.48634 .3575 L
s
.22386 .47294 m
.22378 .47419 L
s
.48634 .3575 m
.48633 .35873 L
s
.22378 .47419 m
.2237 .47545 L
s
0 g
.015 w
.30009 .72707 m
.30747 .73567 L
s
0 1 0 r
.5 Mabswid
.48633 .35873 m
.48631 .35995 L
s
0 g
.52181 .34309 m
.53245 .34132 L
s
0 1 0 r
.2237 .47545 m
.22362 .4767 L
s
0 g
.015 w
.59364 .70217 m
.60034 .71593 L
s
0 1 0 r
.5 Mabswid
.48631 .35995 m
.4863 .36117 L
s
.22362 .4767 m
.22354 .47795 L
s
.4863 .36117 m
.48628 .3624 L
s
.22354 .47795 m
.22345 .47921 L
s
0 g
.53245 .34132 m
.54311 .33955 L
s
0 1 0 r
.48628 .3624 m
.48627 .36362 L
s
.22345 .47921 m
.22337 .48046 L
s
.48627 .36362 m
.48626 .36485 L
s
.22337 .48046 m
.22329 .48172 L
s
0 g
.54311 .33955 m
.55378 .33778 L
s
0 1 0 r
.48626 .36485 m
.48624 .36608 L
s
.22329 .48172 m
.22321 .48298 L
s
0 g
.015 w
.21872 .46816 m
.22544 .4906 L
s
.21191 .44706 m
.21872 .46816 L
s
.20501 .42738 m
.21191 .44706 L
s
0 1 0 r
.5 Mabswid
.48624 .36608 m
.48623 .3673 L
s
0 g
.015 w
.5869 .68757 m
.59364 .70217 L
s
.22544 .4906 m
.23209 .5142 L
s
0 1 0 r
.5 Mabswid
.48623 .3673 m
.48622 .36853 L
s
0 g
.015 w
.19799 .40914 m
.20501 .42738 L
s
.5 Mabswid
.55378 .33778 m
.56446 .336 L
s
0 1 0 r
.48622 .36853 m
.4862 .36976 L
s
0 g
.015 w
.23209 .5142 m
.23869 .53871 L
s
.29284 .71501 m
.30009 .72707 L
s
0 1 0 r
.5 Mabswid
.4862 .36976 m
.48619 .37099 L
s
0 g
.015 w
.19086 .39231 m
.19799 .40914 L
s
.5 Mabswid
.56446 .336 m
.57515 .33423 L
s
0 1 0 r
.48619 .37099 m
.48617 .37222 L
s
.48617 .37222 m
.48616 .37345 L
s
0 g
.015 w
.23869 .53871 m
.24527 .56381 L
s
.58014 .67232 m
.5869 .68757 L
s
0 1 0 r
.5 Mabswid
.48616 .37345 m
.48615 .37468 L
s
0 g
.57515 .33423 m
.58586 .33245 L
s
.015 w
.86217 .62819 m
.88134 .66913 L
s
0 1 0 r
.5 Mabswid
.48615 .37468 m
.48613 .37591 L
s
0 g
.015 w
.18362 .37682 m
.19086 .39231 L
s
0 1 0 r
.5 Mabswid
.48613 .37591 m
.48612 .37714 L
s
0 g
.015 w
.24527 .56381 m
.25185 .58907 L
s
.5 Mabswid
.58586 .33245 m
.59658 .33067 L
s
0 1 0 r
.48612 .37714 m
.4861 .37838 L
s
0 g
.015 w
.28573 .6997 m
.29284 .71501 L
s
0 1 0 r
.5 Mabswid
.4861 .37838 m
.48609 .37961 L
s
0 g
.015 w
.57336 .65657 m
.58014 .67232 L
s
.5 Mabswid
.59658 .33067 m
.60732 .32888 L
s
0 1 0 r
.48609 .37961 m
.48608 .38084 L
s
0 g
.015 w
.25185 .58907 m
.25846 .61401 L
s
.17626 .36254 m
.18362 .37682 L
s
0 1 0 r
.5 Mabswid
.48608 .38084 m
.48606 .38208 L
s
.48606 .38208 m
.48605 .38331 L
s
0 g
.60732 .32888 m
.61807 .3271 L
s
0 1 0 r
.48605 .38331 m
.48603 .38455 L
s
0 g
.015 w
.25846 .61401 m
.26513 .63809 L
s
.56657 .64042 m
.57336 .65657 L
s
.27874 .68147 m
.28573 .6997 L
s
0 1 0 r
.5 Mabswid
.48603 .38455 m
.48602 .38579 L
s
0 g
.61807 .3271 m
.62883 .32531 L
s
0 1 0 r
.48602 .38579 m
.48601 .38702 L
s
0 g
.015 w
.26513 .63809 m
.27188 .66077 L
s
.27188 .66077 m
.27874 .68147 L
s
0 1 0 r
.5 Mabswid
.48601 .38702 m
.48599 .38826 L
s
0 g
.015 w
.16878 .34936 m
.17626 .36254 L
s
0 1 0 r
.5 Mabswid
.48599 .38826 m
.48598 .3895 L
s
0 g
.62883 .32531 m
.63961 .32352 L
s
.015 w
.55976 .62396 m
.56657 .64042 L
s
0 1 0 r
.5 Mabswid
.48598 .3895 m
.48597 .39074 L
s
.48597 .39074 m
.48595 .39198 L
s
0 g
.63961 .32352 m
.6504 .32173 L
s
0 1 0 r
.48595 .39198 m
.48594 .39322 L
s
.48594 .39322 m
.48592 .39446 L
s
0 g
.015 w
.55293 .60725 m
.55976 .62396 L
s
0 1 0 r
.5 Mabswid
.48592 .39446 m
.48591 .39571 L
s
0 g
.6504 .32173 m
.6612 .31994 L
s
0 1 0 r
.48591 .39571 m
.4859 .39695 L
s
0 g
.015 w
.16121 .33713 m
.16878 .34936 L
s
0 1 0 r
.5 Mabswid
.4859 .39695 m
.48588 .39819 L
s
0 g
.015 w
.84153 .58342 m
.86217 .62819 L
s
.5 Mabswid
.6612 .31994 m
.67202 .31814 L
s
.015 w
.5461 .59036 m
.55293 .60725 L
s
0 1 0 r
.5 Mabswid
.48588 .39819 m
.48587 .39944 L
s
.48587 .39944 m
.48585 .40068 L
s
0 g
.67202 .31814 m
.68285 .31634 L
s
0 1 0 r
.48585 .40068 m
.48584 .40193 L
s
.48584 .40193 m
.48583 .40317 L
s
0 g
.015 w
.53925 .57335 m
.5461 .59036 L
s
0 1 0 r
.5 Mabswid
.48583 .40317 m
.48581 .40442 L
s
0 g
.68285 .31634 m
.6937 .31454 L
s
0 1 0 r
.48581 .40442 m
.4858 .40566 L
s
0 g
.015 w
.15353 .32571 m
.16121 .33713 L
s
0 1 0 r
.5 Mabswid
.4858 .40566 m
.48578 .40691 L
s
0 g
.015 w
.53239 .55625 m
.53925 .57335 L
s
.5 Mabswid
.6937 .31454 m
.70456 .31274 L
s
0 1 0 r
.48578 .40691 m
.48577 .40816 L
s
.48577 .40816 m
.48576 .40941 L
s
.48576 .40941 m
.48574 .41066 L
s
0 g
.70456 .31274 m
.71543 .31093 L
s
.015 w
.52551 .53911 m
.53239 .55625 L
s
0 1 0 r
.5 Mabswid
.48574 .41066 m
.48573 .41191 L
s
.48573 .41191 m
.48571 .41316 L
s
0 g
.71543 .31093 m
.72632 .30912 L
s
0 1 0 r
.48571 .41316 m
.4857 .41441 L
s
.4857 .41441 m
.48568 .41567 L
s
0 g
.015 w
.51863 .52197 m
.52551 .53911 L
s
.14575 .31497 m
.15353 .32571 L
s
.5 Mabswid
.72632 .30912 m
.73722 .30731 L
s
0 1 0 r
.48568 .41567 m
.48567 .41692 L
s
.48567 .41692 m
.48566 .41817 L
s
.48566 .41817 m
.48564 .41943 L
s
0 g
.73722 .30731 m
.74813 .3055 L
s
.015 w
.51173 .50487 m
.51863 .52197 L
s
0 1 0 r
.5 Mabswid
.48564 .41943 m
.48563 .42068 L
s
0 g
.015 w
.82004 .53645 m
.84153 .58342 L
s
0 1 0 r
.5 Mabswid
.48563 .42068 m
.48561 .42194 L
s
0 g
.75177 .30489 m
.74813 .3055 L
s
0 1 0 r
.48561 .42194 m
.4856 .42319 L
s
.75177 .30489 m
.75183 .30612 L
s
.4856 .42319 m
.48559 .42445 L
s
0 g
.015 w
.50482 .48783 m
.51173 .50487 L
s
0 1 0 r
.5 Mabswid
.75183 .30612 m
.75188 .30735 L
s
.48559 .42445 m
.48557 .42571 L
s
.75188 .30735 m
.75194 .30857 L
s
.48557 .42571 m
.48556 .42697 L
s
0 g
.015 w
.13789 .30477 m
.14575 .31497 L
s
0 1 0 r
.5 Mabswid
.75194 .30857 m
.752 .3098 L
s
.48556 .42697 m
.48554 .42823 L
s
0 g
.015 w
.49789 .47091 m
.50482 .48783 L
s
0 1 0 r
.5 Mabswid
.752 .3098 m
.75205 .31103 L
s
.48554 .42823 m
.48553 .42949 L
s
.75205 .31103 m
.75211 .31226 L
s
.48553 .42949 m
.48552 .43075 L
s
.75211 .31226 m
.75217 .31349 L
s
.48552 .43075 m
.4855 .43201 L
s
.75217 .31349 m
.75222 .31472 L
s
.4855 .43201 m
.48549 .43327 L
s
0 g
.015 w
.49095 .45412 m
.49789 .47091 L
s
0 1 0 r
.5 Mabswid
.75222 .31472 m
.75228 .31595 L
s
.48549 .43327 m
.48547 .43453 L
s
.75228 .31595 m
.75233 .31718 L
s
.48547 .43453 m
.48546 .4358 L
s
.75233 .31718 m
.75239 .31841 L
s
.48546 .4358 m
.48544 .43706 L
s
.75239 .31841 m
.75245 .31965 L
s
0 g
.015 w
.48399 .43751 m
.49095 .45412 L
s
0 1 0 r
.5 Mabswid
.48544 .43706 m
.48543 .43832 L
s
.75245 .31965 m
.7525 .32088 L
s
0 g
.015 w
.12995 .29501 m
.13789 .30477 L
s
0 1 0 r
.5 Mabswid
.48543 .43832 m
.48542 .43959 L
s
.7525 .32088 m
.75256 .32211 L
s
.48542 .43959 m
.4854 .44085 L
s
.75256 .32211 m
.75262 .32335 L
s
0 g
.133 .2937 m
.14218 .29043 L
s
0 1 0 r
.75262 .32335 m
.75267 .32458 L
s
0 g
.015 w
.47702 .4211 m
.48399 .43751 L
s
0 1 0 r
.5 Mabswid
.75267 .32458 m
.75273 .32582 L
s
.75273 .32582 m
.75279 .32706 L
s
0 g
.015 w
.79828 .48888 m
.82004 .53645 L
s
0 1 0 r
.5 Mabswid
.75279 .32706 m
.75284 .32829 L
s
.75284 .32829 m
.7529 .32953 L
s
0 g
.14218 .29043 m
.15137 .28715 L
s
.015 w
.47002 .40494 m
.47702 .4211 L
s
0 1 0 r
.5 Mabswid
.7529 .32953 m
.75296 .33077 L
s
.75296 .33077 m
.75301 .33201 L
s
0 g
.015 w
.12193 .28559 m
.12995 .29501 L
s
0 1 0 r
.5 Mabswid
.75301 .33201 m
.75307 .33325 L
s
.75307 .33325 m
.75313 .33449 L
s
0 g
.15137 .28715 m
.16058 .28386 L
s
.015 w
.46301 .38906 m
.47002 .40494 L
s
0 1 0 r
.5 Mabswid
.75313 .33449 m
.75318 .33573 L
s
.75318 .33573 m
.75324 .33698 L
s
.75324 .33698 m
.7533 .33822 L
s
.7533 .33822 m
.75335 .33946 L
s
0 g
.16058 .28386 m
.16982 .28057 L
s
0 1 0 r
.75335 .33946 m
.75341 .34071 L
s
0 g
.015 w
.45597 .37348 m
.46301 .38906 L
s
0 1 0 r
.5 Mabswid
.75341 .34071 m
.75347 .34195 L
s
.75347 .34195 m
.75352 .3432 L
s
.75352 .3432 m
.75358 .34444 L
s
0 g
.015 w
.11385 .27643 m
.12193 .28559 L
s
0 1 0 r
.5 Mabswid
.75358 .34444 m
.75364 .34569 L
s
0 g
.16982 .28057 m
.17908 .27727 L
s
0 1 0 r
.75364 .34569 m
.75369 .34694 L
s
0 g
.015 w
.44891 .35826 m
.45597 .37348 L
s
0 1 0 r
.5 Mabswid
.75369 .34694 m
.75375 .34818 L
s
.75375 .34818 m
.75381 .34943 L
s
.75381 .34943 m
.75387 .35068 L
s
0 g
.17908 .27727 m
.18835 .27396 L
s
.015 w
.77679 .44213 m
.79828 .48888 L
s
0 1 0 r
.5 Mabswid
.75387 .35068 m
.75392 .35193 L
s
.75392 .35193 m
.75398 .35318 L
s
0 g
.015 w
.44182 .34341 m
.44891 .35826 L
s
0 1 0 r
.5 Mabswid
.75398 .35318 m
.75404 .35443 L
s
.75404 .35443 m
.75409 .35569 L
s
0 g
.18835 .27396 m
.19765 .27065 L
s
0 1 0 r
.75409 .35569 m
.75415 .35694 L
s
0 g
.015 w
.10569 .26744 m
.11385 .27643 L
s
0 1 0 r
.5 Mabswid
.75415 .35694 m
.75421 .35819 L
s
.75421 .35819 m
.75427 .35945 L
s
0 g
.015 w
.43469 .32897 m
.44182 .34341 L
s
0 1 0 r
.5 Mabswid
.75427 .35945 m
.75432 .3607 L
s
.75432 .3607 m
.75438 .36196 L
s
0 g
.19765 .27065 m
.20697 .26732 L
s
0 1 0 r
.75438 .36196 m
.75444 .36321 L
s
.75444 .36321 m
.7545 .36447 L
s
.7545 .36447 m
.75455 .36573 L
s
.75455 .36573 m
.75461 .36699 L
s
0 g
.20697 .26732 m
.21632 .26399 L
s
.015 w
.42754 .31498 m
.43469 .32897 L
s
0 1 0 r
.5 Mabswid
.75461 .36699 m
.75467 .36824 L
s
.75467 .36824 m
.75473 .3695 L
s
.75473 .3695 m
.75478 .37076 L
s
0 g
.015 w
.09748 .25858 m
.10569 .26744 L
s
0 1 0 r
.5 Mabswid
.75478 .37076 m
.75484 .37202 L
s
0 g
.21632 .26399 m
.22568 .26065 L
s
0 1 0 r
.75484 .37202 m
.7549 .37329 L
s
.7549 .37329 m
.75496 .37455 L
s
0 g
.015 w
.756 .39738 m
.77679 .44213 L
s
.42034 .30144 m
.42754 .31498 L
s
0 1 0 r
.5 Mabswid
.75496 .37455 m
.75501 .37581 L
s
.75501 .37581 m
.75507 .37707 L
s
.75507 .37707 m
.75513 .37834 L
s
0 g
.22568 .26065 m
.23507 .25731 L
s
0 1 0 r
.75513 .37834 m
.75519 .3796 L
s
.75519 .3796 m
.75524 .38087 L
s
.75524 .38087 m
.7553 .38213 L
s
.7553 .38213 m
.75536 .3834 L
s
0 g
.23507 .25731 m
.24447 .25395 L
s
.015 w
.41311 .28839 m
.42034 .30144 L
s
.0892 .24981 m
.09748 .25858 L
s
0 1 0 r
.5 Mabswid
.75536 .3834 m
.75542 .38467 L
s
.75542 .38467 m
.75548 .38594 L
s
.75548 .38594 m
.75553 .38721 L
s
.75553 .38721 m
.75559 .38848 L
s
0 g
.24447 .25395 m
.2539 .25059 L
s
0 1 0 r
.75559 .38848 m
.75565 .38975 L
s
.75565 .38975 m
.75571 .39102 L
s
.75571 .39102 m
.75577 .39229 L
s
0 g
.015 w
.40583 .27583 m
.41311 .28839 L
s
0 1 0 r
.5 Mabswid
.75577 .39229 m
.75582 .39356 L
s
0 g
.2539 .25059 m
.26335 .24722 L
s
0 1 0 r
.75582 .39356 m
.75588 .39483 L
s
.75588 .39483 m
.75594 .39611 L
s
.75594 .39611 m
.756 .39738 L
s
0 g
.015 w
.08087 .24108 m
.0892 .24981 L
s
.73624 .35553 m
.756 .39738 L
s
.5 Mabswid
.26335 .24722 m
.27283 .24384 L
s
.015 w
.39851 .26375 m
.40583 .27583 L
s
.5 Mabswid
.27283 .24384 m
.28232 .24046 L
s
.28232 .24046 m
.29184 .23706 L
s
.015 w
.07248 .23236 m
.08087 .24108 L
s
.39114 .25214 m
.39851 .26375 L
s
.5 Mabswid
.29184 .23706 m
.30138 .23366 L
s
.015 w
.71774 .31715 m
.73624 .35553 L
s
.5 Mabswid
.30138 .23366 m
.31094 .23025 L
s
.015 w
.38372 .24098 m
.39114 .25214 L
s
.06404 .22365 m
.07248 .23236 L
s
.5 Mabswid
.31094 .23025 m
.32052 .22683 L
s
.32052 .22683 m
.33013 .22341 L
s
.015 w
.37625 .23023 m
.38372 .24098 L
s
.5 Mabswid
.33013 .22341 m
.33976 .21998 L
s
.015 w
.05555 .21492 m
.06404 .22365 L
s
.70058 .28251 m
.71774 .31715 L
s
.5 Mabswid
.33976 .21998 m
.34941 .21653 L
s
.015 w
.36872 .21985 m
.37625 .23023 L
s
.5 Mabswid
.34941 .21653 m
.35909 .21308 L
s
.015 w
.047 .20616 m
.05555 .21492 L
s
.5 Mabswid
.35909 .21308 m
.36878 .20963 L
s
.015 w
.36114 .20977 m
.36872 .21985 L
s
.5 Mabswid
.36878 .20963 m
.3785 .20616 L
s
.015 w
.68479 .25163 m
.70058 .28251 L
s
.5 Mabswid
.3785 .20616 m
.38825 .20269 L
s
.015 w
.0384 .19737 m
.047 .20616 L
s
.35351 .19995 m
.36114 .20977 L
s
.5 Mabswid
.38825 .20269 m
.39801 .1992 L
s
.39801 .1992 m
.4078 .19571 L
s
.015 w
.02975 .18853 m
.0384 .19737 L
s
.5 Mabswid
.4078 .19571 m
.41761 .19222 L
s
.015 w
.34582 .19033 m
.35351 .19995 L
s
.67029 .22432 m
.68479 .25163 L
s
.5 Mabswid
.41761 .19222 m
.42745 .18871 L
s
.42745 .18871 m
.43731 .18519 L
s
.02975 .1885 m
.03906 .1849 L
s
.015 w
.33808 .18087 m
.34582 .19033 L
s
.5 Mabswid
.43731 .18519 m
.44719 .18167 L
s
.03906 .1849 m
.04839 .1813 L
s
.44719 .18167 m
.45709 .17814 L
s
.04839 .1813 m
.05775 .17769 L
s
.015 w
.65695 .20024 m
.67029 .22432 L
s
.3303 .17151 m
.33808 .18087 L
s
.5 Mabswid
.45709 .17814 m
.46702 .1746 L
s
.05775 .17769 m
.06712 .17406 L
s
.46702 .1746 m
.47697 .17105 L
s
.06712 .17406 m
.07652 .17043 L
s
.47697 .17105 m
.48695 .16749 L
s
.07652 .17043 m
.08595 .16679 L
s
.015 w
.32245 .16223 m
.3303 .17151 L
s
.64463 .17898 m
.65695 .20024 L
s
.5 Mabswid
.48695 .16749 m
.49695 .16393 L
s
.08595 .16679 m
.09539 .16314 L
s
.49695 .16393 m
.50698 .16035 L
s
.09539 .16314 m
.10486 .15948 L
s
.015 w
.31456 .15298 m
.32245 .16223 L
s
.5 Mabswid
.50698 .16035 m
.51702 .15677 L
s
.10486 .15948 m
.11435 .15582 L
s
.51702 .15677 m
.5271 .15318 L
s
.11435 .15582 m
.12387 .15214 L
s
.015 w
.63315 .16006 m
.64463 .17898 L
s
.5 Mabswid
.5271 .15318 m
.53719 .14958 L
s
.015 w
.30662 .14374 m
.31456 .15298 L
s
.5 Mabswid
.12387 .15214 m
.13341 .14846 L
s
.53719 .14958 m
.54731 .14597 L
s
.13341 .14846 m
.14297 .14476 L
s
.54731 .14597 m
.55746 .14235 L
s
.14297 .14476 m
.15255 .14106 L
s
.015 w
.62234 .14305 m
.63315 .16006 L
s
.29863 .13449 m
.30662 .14374 L
s
.5 Mabswid
.55746 .14235 m
.56763 .13872 L
s
.15255 .14106 m
.16216 .13734 L
s
.56763 .13872 m
.57782 .13509 L
s
.16216 .13734 m
.1718 .13362 L
s
.57782 .13509 m
.58804 .13145 L
s
.015 w
.29058 .12523 m
.29863 .13449 L
s
.5 Mabswid
.1718 .13362 m
.18145 .12989 L
s
.015 w
.61205 .12753 m
.62234 .14305 L
s
.5 Mabswid
.58804 .13145 m
.59828 .12779 L
s
.18145 .12989 m
.19113 .12615 L
s
.59828 .12779 m
.60855 .12413 L
s
.19113 .12615 m
.20084 .1224 L
s
.015 w
.28249 .11593 m
.29058 .12523 L
s
.5 Mabswid
.61198 .12291 m
.60855 .12413 L
s
.20084 .1224 m
.21057 .11864 L
s
.015 w
.60215 .11313 m
.61205 .12753 L
s
.5 Mabswid
.21057 .11864 m
.22032 .11488 L
s
.015 w
.27435 .10659 m
.28249 .11593 L
s
.5 Mabswid
.22032 .11488 m
.2301 .1111 L
s
.2301 .1111 m
.2399 .10731 L
s
.015 w
.59251 .09954 m
.60215 .11313 L
s
.5 Mabswid
.2399 .10731 m
.24972 .10352 L
s
.015 w
.26615 .0972 m
.27435 .10659 L
s
.5 Mabswid
.24972 .10352 m
.25958 .09971 L
s
.25958 .09971 m
.26945 .0959 L
s
.015 w
.58305 .08651 m
.59251 .09954 L
s
.5 Mabswid
.26945 .0959 m
.27935 .09207 L
s
.27935 .09207 m
.28927 .08824 L
s
.28927 .08824 m
.29922 .08439 L
s
.29922 .08439 m
.3092 .08054 L
s
.015 w
.5737 .07387 m
.58305 .08651 L
s
.5 Mabswid
.3092 .08054 m
.3192 .07668 L
s
.3192 .07668 m
.32922 .0728 L
s
.32922 .0728 m
.33927 .06892 L
s
.015 w
.56439 .06145 m
.5737 .07387 L
s
.5 Mabswid
.33927 .06892 m
.34935 .06503 L
s
.34935 .06503 m
.35945 .06113 L
s
.35945 .06113 m
.36957 .05721 L
s
.015 w
.5551 .04916 m
.56439 .06145 L
s
.5 Mabswid
.36957 .05721 m
.37973 .05329 L
s
.37973 .05329 m
.3899 .04936 L
s
.3899 .04936 m
.40011 .04542 L
s
.015 w
.54579 .03692 m
.5551 .04916 L
s
.5 Mabswid
.40011 .04542 m
.41034 .04146 L
s
.41034 .04146 m
.42059 .0375 L
s
.42059 .0375 m
.43087 .03353 L
s
.015 w
.53644 .02468 m
.54579 .03692 L
s
.5 Mabswid
.43087 .03353 m
.44118 .02955 L
s
.44118 .02955 m
.45152 .02556 L
s
.45152 .02556 m
.46188 .02155 L
s
.015 w
.52704 .0124 m
.53644 .02468 L
s
.5 Mabswid
.46188 .02155 m
.47227 .01754 L
s
.47227 .01754 m
.48268 .01352 L
s
.48268 .01352 m
.49312 .00948 L
s
.015 w
.51759 6e-05 m
.52704 .0124 L
s
.5 Mabswid
.49312 .00948 m
.50359 .00544 L
s
.50359 .00544 m
.51408 .00138 L
s
.51759 3e-05 m
.51408 .00138 L
s
.25 Mabswid
.51756 0 m
.9781 .59953 L
s
.9781 .59953 m
1 .84627 L
s
1 .84627 m
.51621 .27089 L
s
.51621 .27089 m
.51756 0 L
s
.02975 .1885 m
0 .45327 L
s
0 .45327 m
.51621 .27089 L
s
.51621 .27089 m
.51756 0 L
s
.51756 0 m
.02975 .1885 L
s
.02975 .1885 m
.51756 0 L
s
gsave
.21289 .03628 -70.3742 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{364.75, 351.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000770001]b000`400?l00000o`00003oooooooo8
ooooo`00ooooooo8ooooo`00ooooooo8ooooo`00ooooooo8ooooo`00ooooooo8ooooo`00ooooooo8
ooooo`00ooooooo8ooooo`00ooooooo8ooooo`00ooooooo8ooooo`00ooooooo8ooooo`00ooooooo8
ooooo`00ooooooo8ooooo`00ooooooo8ooooo`00ooooooo8ooooo`00ooooooo8ooooo`00ooooooo8
ooooo`00ooooooo8ooooo`00ooooooo8ooooo`00ooooooo8ooooo`00ooooooo8ooooo`00ooooooo8
ooooo`00ooooooo8ooooo`00ooooooo8ooooo`00ooooooo8ooooo`00ooooooo8ooooo`00ooooooo8
ooooo`00ooooooo8ooooo`00ooooooo8ooooo`00ooooooo8ooooo`00ooooooo8ooooo`00ooooooo8
ooooo`00ooooooo8ooooo`00ooooooo8ooooo`00ooooooo8ooooo`00ooooool=ooooo`Go0000]_oo
ool00?oooooo3Oooool6o`000;Gooooo003oooooo`gooooo1ol0002dooooo`00ooooool;ooooo`[o
0000/oooool00?oooooo2?ooool3o`0000;ooooo2Ol0002booooo`00Toooool01OnHV9So0000o`00
0?m4A4Co^[Zj06cooooo1?l00005ooooo`So0000/_ooool009?ooooo00Go410@okZj^_o^k^koMgMg
oa0@401Zooooo`?o00002Oooool8o`000;7ooooo002Cooooo`03o`000?oooooooooo06Wooooo0ol0
000<ooooo`Wo0000/?ooool009?ooooo00?o0000ooooooooool0I_ooool4o`0000kooooo00?o0000
ooooool000001_l0002`ooooo`00Toooool00ol0003oooooooooo`1Tooooo`?o00004Oooool00ol0
003oooooo`000007o`000:oooooo002Aooooo`03oa0@4?l0003o000000?o0000H?ooool4o`0001?o
oooo00?o0000ooooooooool01ol0002_ooooo`00Toooool00ol0003oooooooooo`1Nooooo`Co0000
5_ooool01?l0003oooooooooooooool7o`000:kooooo002Cooooo`03o`000?oooooooooo05cooooo
0ol0000Iooooo`04o`000?ooooooooooooooo`So0000[Oooool00>oooooo1?l0000Kooooo`03o`00
0?oooooooooo00;ooooo2?l0002/ooooo`00k?ooool4o`0001kooooo00?o0000ooooooooool00_oo
ool9o`000:_ooooo003Zooooo`Co00008?ooool00ol0003oooooooooo`03ooooo`Wo0000Z_ooool0
0>Oooooo1?l0000Sooooo`03o`000?oooooooooo00Cooooo2Ol0002Yooooo`00i?ooool5o`0002Go
oooo00?o0000ooooooooool01Oooool9o`000:Sooooo003Rooooo`Co0000:?ooool00ol0003ooooo
ooooo`06ooooo`Wo0000Yoooool00=oooooo1?l0000[ooooo`03o`000?oooooooooo00Oooooo2?l0
002Wooooo`00g?ooool5o`0002gooooo00?o0000ooooooooool02?ooool8o`000:Kooooo003Koooo
o`?o0000<?ooool00ol0003oooooooooo`09ooooo`So0000YOooool00=Sooooo1?l0000booooo`03
o`000?oooooooooo00[ooooo1ol0002Uooooo`00eOooool4o`0003Gooooo00?o0000ooooooooool0
2_ooool8o`000:Cooooo003Cooooo`?o0000>?ooool00ol0003oooooooooo`0;ooooo`Oo0000Y?oo
ool00=3ooooo1?l0000jooooo`03o`000?oooooooooo00cooooo1ol0002Sooooo`00cOooool4o`00
03gooooo00?o0000ooooooooool03?ooool8o`000:;ooooo003;ooooo`Co0000?oooool00ol0003o
ooooooooo`0=ooooo`So0000XOooool00<Sooooo1?l00012ooooo`03o`000?oooooooooo00gooooo
2Ol0002Pooooo`00aOooool5o`0004Cooooo00?o0000ooooooooool03_ooool8o`000:3ooooo0033
ooooo`Co0000Aoooool00ol0003oooooooooo`0?ooooo`So0000Woooool00<7ooooo0ol0001:oooo
o`03o`000?oooooooooo013ooooo2?l0002Nooooo`00__ooool4o`0004cooooo00?o0000oooooooo
ool04Oooool7o`0009kooooo002looooo`?o0000Coooool00ol0003oooooooooo`0Aooooo`So0000
WOooool00;Wooooo1?l0001Aooooo`03o`000?oooooooooo01;ooooo1ol0002Mooooo`00]_ooool4
o`0005Cooooo00?o0000ooooooooool04oooool7o`0009cooooo002dooooo`?o0000Eoooool00ol0
003oooooooooo`0Cooooo`So0000Voooool00:cooooo1Ol000001?oooooo0000o`000?l0001Ioooo
o`03o`000?oooooooooo01Cooooo2?l0002Jooooo`00[?ooool6o`0005cooooo00?o0000oooooooo
ool05?ooool9o`0009Wooooo002/ooooo`Oo0000Foooool00ol0003oooooooooo`0Eooooo`So0000
VOooool00:[ooooo2_l0001Jooooo`03o`000?oooooooooo01Kooooo2?l0002Hooooo`00Yoooool4
o`000003ooooool0003o000000Ko0000F_ooool00ol0003oooooooooo`0Gooooo`So0000Uoooool0
0:Gooooo0ol00005ooooo`So0000FOooool00ol0003oooooooooo`0Hooooo`So0000U_ooool00:;o
oooo0ol00009ooooo`So0000F?ooool00ol0003oooooooooo`0Hooooo`Wo0000UOooool009oooooo
1?l0000<ooooo`Wo0000E_ooool00ol0003oooooooooo`0Iooooo`So0000UOooool009cooooo1?l0
000?ooooo`[o0000EOooool00ol0003oooooooooo`0Jooooo`So0000U?ooool009[ooooo1?l0000B
ooooo`[o0000E?ooool00ol0003oooooooooo`0Kooooo`So0000Toooool009Oooooo1?l0000Foooo
o`[o0000Doooool00ol0003oooooooooo`0Looooo`Oo0000Toooool009Cooooo1?l0000Jooooo`Wo
0000Doooool00ol0003oooooooooo`0Looooo`So0000T_ooool009?ooooo0ol0000Nooooo`So0000
D_ooool00ol0003oooooooooo`0Mooooo`Oo0000T_ooool0093ooooo0ol0000Rooooo`So0000DOoo
ool00ol0003oooooooooo`0Kooooo`[o0000TOooool008gooooo1?l0000Uooooo`So0000D?ooool0
0ol0003oooooooooo`0Iooooo`;o00000oooool8o`00093ooooo002;ooooo`?o0000:?ooool9o`00
04oooooo00?o0000ooooooooool05_ooool3o`0000Kooooo1ol0002@ooooo`00ROooool3o`0002_o
oooo2Ol0001>ooooo`03o`000?oooooooooo01?ooooo0ol00009ooooo`So0000Soooool008Gooooo
1?l0000_ooooo`Wo0000COooool00ol0003oooooooooo`0Aooooo`;o00003Oooool8o`0008kooooo
0022ooooo`Co0000<oooool8o`0004gooooo00?o0000ooooooooool03_ooool3o`00013ooooo1ol0
002>ooooo`00P?ooool4o`0003Kooooo2?l0001<ooooo`03o`000?oooooooooo00_ooooo0ol0000C
ooooo`So0000SOooool007kooooo0ol0000jooooo`So0000Boooool00ol0003oooooooooo`08oooo
o`?o00005oooool7o`0008gooooo001kooooo`Co0000?Oooool8o`0004[ooooo00?o0000oooooooo
ool01_ooool2o`0001_ooooo1ol0002<ooooo`00NOooool3o`00043ooooo2?l0001:ooooo`03o`00
0?oooooooooo00?ooooo0ol0000Mooooo`So0000Roooool007Kooooo0ol00014ooooo`So0000BOoo
ool00ol0003oooooo`000003o`00027ooooo1ol0002;ooooo`00Loooool4o`0004Oooooo2?l00017
ooooo`?o00009Oooool8o`0008[ooooo001`ooooo`Co0000Boooool8o`0004Cooooo0_l000000ooo
oooo0000ooooo`0Vooooo`Oo0000R_ooool006kooooo1?l0001=ooooo`Wo0000@?ooool3o`0000?o
oooo00?o0000ooooooooool09_ooool7o`0008Wooooo001[ooooo`Co0000DOooool9o`0003cooooo
0ol00006ooooo`03o`000?oooooooooo02Kooooo2?l00028ooooo`00J?ooool5o`0005Cooooo2Ol0
000jooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09oooool8o`0008Oooooo001W
ooooo`?o0000F?ooool8o`0003Oooooo0ol0000:ooooo`03o`000?oooooooooo02Oooooo2?l00027
ooooo`00I?ooool3o`0005cooooo2?l0000booooo`Co00003Oooool00ol0003oooooooooo`0Xoooo
o`So0000Q_ooool0067ooooo1?l0001Oooooo`So0000;_ooool3o`00017ooooo00?o0000oooooooo
ool0:Oooool8o`0008Gooooo001Nooooo`Co0000Hoooool8o`0002_ooooo0_l0000Dooooo`03o`00
0?oooooooooo02[ooooo1ol00025ooooo`00G?ooool4o`0006Gooooo2Ol0000Wooooo`?o00005_oo
ool00ol0003oooooooooo`0Zooooo`So0000Q?ooool005[ooooo0ol0001Yooooo`Wo00008oooool3
o`0001Wooooo00?o0000ooooooooool0:oooool8o`0008?ooooo001Booooo`So0000KOooool9o`00
01oooooo0ol0000Looooo`03o`000?oooooooooo02cooooo2?l00022ooooo`00D_ooool6o`00073o
oooo2?l0000Mooooo`;o00007oooool00ol0003oooooooooo`0/ooooo`So0000P_ooool005;ooooo
1ol0001`ooooo`So00006Oooool3o`00027ooooo00?o0000ooooooooool0;Oooool8o`00087ooooo
001Booooo`Wo0000Koooool8o`0001Cooooo1?l0000Tooooo`03o`000?oooooooooo02gooooo1ol0
00000ooooooo0000ooooo`1oooooo`00D_ooool:o`0006oooooo2?l0000@ooooo`?o0000:?ooool0
0ol0003oooooooooo`0^ooooo`Oo000000?oooooo`000?ooool0O_ooool005?ooooo2_l0001^oooo
o`So00003oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02kooooo1ol00002oooo
o`03o`000?oooooooooo07cooooo001Dooooo`[o0000K_ooool8o`0000_ooooo0ol0000/ooooo`03
o`000?oooooooooo02oooooo1ol000000ooooooo0000ooooo`1mooooo`00E?ooool:o`0006oooooo
2?l00006ooooo`Co0000;oooool00ol0003oooooooooo`0_ooooo`So000000?oooooo`000?ooool0
O?ooool005?ooooo00Co0000oooooooooooooooo2?l0001_ooooo`So00000_ooool3o`0003?ooooo
00?o0000ooooooooool0<?ooool7o`0000;ooooo00?o0000ooooooooool0N_ooool005?ooooo00?o
0000ooooooooool00_ooool8o`0006kooooo2_l0000fooooo`03o`000?oooooooooo033ooooo2?l0
0002ooooo`03o`000?oooooooooo07Wooooo001Cooooo`03o`000?oooooooooo00?ooooo2?l0001^
ooooo`So0000=oooool00ol0003oooooooooo`0aooooo`So000000?oooooo`000?ooool0N_ooool0
05?ooooo00?o0000ooooooooool00oooool9o`0006kooooo1ol0000gooooo`03o`000?oooooooooo
03;ooooo1ol00002ooooo`03o`000?oooooooooo07Sooooo001Cooooo`03o`000?oooooooooo00Co
oooo2Ol0001Zooooo`?o000000?oooooo`000?l000001Ol0000fooooo`03o`000?oooooooooo03;o
oooo2?l00002ooooo`03o`000?oooooooooo07Oooooo001Cooooo`03o`000?oooooooooo00Gooooo
2Ol0001Wooooo`;o00001?ooool8o`0003Gooooo00?o0000ooooooooool0<oooool8o`0000;ooooo
00?o0000ooooooooool0M_ooool005?ooooo00?o0000ooooooooool01_ooool9o`0006Cooooo0_l0
0007ooooo`So0000=?ooool00ol0003oooooooooo`0dooooo`Oo00000_ooool00ol0003ooooooooo
o`1fooooo`00Doooool00ol0003oooooooooo`07ooooo`Wo0000Goooool4o`0000Wooooo2Ol0000c
ooooo`03o`000?oooooooooo03Cooooo2?l00002ooooo`03o`000?oooooooooo07Gooooo001Coooo
o`03o`000?oooooooooo00Sooooo2Ol0001Jooooo`Co00003_ooool8o`0003?ooooo00?o0000oooo
ooooool0=Oooool7o`0000?ooooo00?o0000ooooooooool0M?ooool005;ooooo00?o0000oooooooo
ool02_ooool9o`0005Kooooo0ol0000Cooooo`So0000<_ooool00ol0003oooooooooo`0fooooo`Oo
00000oooool00ol0003oooooooooo`1cooooo`00D_ooool00ol0003oooooooooo`0;ooooo`Wo0000
E?ooool00ol0003oooooooooo`0Eooooo`So0000<Oooool00ol0003oooooooooo`0fooooo`Oo0000
1?ooool00ol0003oooooooooo`1booooo`00D_ooool00ol0003oooooooooo`0<ooooo`Wo0000D?oo
ool3o`0001Wooooo1ol0000aooooo`03o`000?oooooooooo03Oooooo1ol00003ooooo`03o`000?oo
oooooooo07;ooooo001Booooo`03o`000?oooooooooo00gooooo2Ol0001;ooooo`Co00007?ooool8
o`00033ooooo00?o0000ooooooooool0=oooool7o`0000Cooooo00?o0000ooooooooool0LOooool0
05;ooooo00?o0000ooooooooool03_ooool9o`0004Oooooo0ol0000Qooooo`Oo0000<?ooool00ol0
003oooooooooo`0hooooo`Ko00001Oooool00ol0003oooooooooo`1`ooooo`00D_ooool00ol0003o
ooooooooo`0?ooooo`Wo0000AOooool00ol0003oooooooooo`0Sooooo`Oo0000;oooool00ol0003o
ooooooooo`0hooooo`Oo00001Oooool00ol0003oooooooooo`1_ooooo`00D_ooool00ol0003ooooo
ooooo`0@ooooo`Wo0000@Oooool3o`0002Kooooo2?l0000^ooooo`03o`000?oooooooooo03Wooooo
1_l00005ooooo`03o`000?oooooooooo06oooooo001Booooo`03o`000?oooooooooo017ooooo2Ol0
000mooooo`?o0000:_ooool8o`0002gooooo00?o0000ooooooooool0>Oooool7o`0000Gooooo00?o
0000ooooooooool0K_ooool005;ooooo00?o0000ooooooooool04_ooool9o`0003Wooooo0ol0000]
ooooo`So0000;Oooool00ol0003oooooooooo`0iooooo`Oo00001_ooool00ol0003oooooooooo`1]
ooooo`00DOooool00ol0003oooooooooo`0Dooooo`Wo0000=_ooool2o`00037ooooo2?l0000/oooo
o`03o`000?oooooooooo03[ooooo1ol00006ooooo`03o`000?oooooooooo06cooooo001Aooooo`03
o`000?oooooooooo01Gooooo2?l0000cooooo`?o0000=?ooool8o`0002_ooooo00?o0000oooooooo
ool0>_ooool7o`0000Kooooo00?o0000ooooooooool0K?ooool0057ooooo00?o0000ooooooooool0
5_ooool8o`0002oooooo0ol0000hooooo`So0000:_ooool00ol0003oooooooooo`0kooooo`Oo0000
1_ooool00ol0003oooooooooo`1[ooooo`00DOooool00ol0003oooooooooo`0Gooooo`So0000:_oo
ool4o`0003_ooooo2?l0000Zooooo`03o`000?oooooooooo03_ooooo1ol00007ooooo`03o`000?oo
oooooooo06[ooooo001Aooooo`03o`000?oooooooooo01Sooooo2?l0000Vooooo`?o0000@?ooool8
o`0002Wooooo00?o0000ooooooooool0??ooool7o`0000Oooooo00?o0000ooooooooool0JOooool0
057ooooo00?o0000ooooooooool06?ooool9o`0002Cooooo00?o0000ooooooooool0@_ooool8o`00
02Sooooo00?o0000ooooooooool0??ooool8o`0000Oooooo00?o0000ooooooooool0J?ooool0057o
oooo00?o0000ooooooooool06Oooool9o`00023ooooo0ol00016ooooo`Oo0000:?ooool00ol0003o
ooooooooo`0mooooo`Oo00001oooool00ol0003oooooooooo`1Xooooo`00DOooool00ol0003ooooo
ooooo`0Jooooo`Wo00007?ooool3o`0004Wooooo2?l0000Vooooo`;o0000?oooool8o`0000Oooooo
00?o0000ooooooooool0Ioooool0057ooooo00?o0000ooooooooool06oooool8o`0001Sooooo1?l0
001=ooooo`Oo00008oooool3o`000003ooooool0003ooooo03oooooo1ol00008ooooo`03o`000?oo
oooooooo06Kooooo001@ooooo`03o`000?oooooooooo01gooooo2?l0000Dooooo`?o0000D_ooool7
o`0001oooooo0ol00005ooooo`03o`000?oooooooooo03kooooo1ol00008ooooo`03o`000?oooooo
oooo06Gooooo001@ooooo`03o`000?oooooooooo01kooooo2?l0000Aooooo`;o0000EOooool7o`00
01cooooo0ol00009ooooo`03o`000?oooooooooo03gooooo1ol00008ooooo`03o`000?oooooooooo
06Gooooo001@ooooo`03o`000?oooooooooo01oooooo2?l0000>ooooo`;o0000F?ooool6o`0001Wo
oooo0ol0000=ooooo`03o`000?oooooooooo03gooooo1ol00008ooooo`03o`000?oooooooooo06Co
oooo001@ooooo`03o`000?oooooooooo01oooooo2Ol00009ooooo`Co0000F_ooool7o`0001Kooooo
0_l0000Aooooo`03o`000?oooooooooo03cooooo1ol00009ooooo`03o`000?oooooooooo06?ooooo
001@ooooo`03o`000?oooooooooo023ooooo2Ol00005ooooo`?o0000Goooool6o`0001?ooooo0ol0
000Dooooo`03o`000?oooooooooo03cooooo1ol00009ooooo`03o`000?oooooooooo06;ooooo001@
ooooo`03o`000?oooooooooo027ooooo2Ol000001?oooooo0000o`000?l0001Rooooo`Oo00003ooo
ool3o`0001Oooooo00?o0000ooooooooool0??ooool7o`0000[ooooo00?o0000ooooooooool0HOoo
ool0053ooooo00?o0000ooooooooool08_ooool9o`0006Gooooo2?l0000;ooooo`?o00006oooool0
0ol0003oooooooooo`0looooo`Oo00002Oooool00ol0003oooooooooo`0Zooooo`;o00000_ooool2
o`00037ooooo001@ooooo`03o`000?oooooooooo02?ooooo2?l0001Vooooo`Oo00002?ooool3o`00
01oooooo00?o0000ooooooooool0>oooool7o`0000[ooooo00?o0000ooooooooool0:Oooool01_o^
k^ko8B4QohN7Qonj^[[o0000omgMgC7ooooo001@ooooo`03o`000?oooooooooo02Cooooo2?l0001U
ooooo`So00001?ooool3o`0002?ooooo00?o0000ooooooooool0>oooool7o`0000[ooooo00?o0000
ooooooooool0:Oooool01?oMgMgo0000oa0@4?o<c<`booooo`00Coooool00ol0003oooooooooo`0V
ooooo`So0000IOooool7o`0000;ooooo0_l0000Wooooo`03o`000?oooooooooo03[ooooo1ol0000;
ooooo`03o`000?oooooooooo02Sooooo00Cok^k^ob4Q8Ol@413ok^k^<_ooool004oooooo00?o0000
ooooooooool09_ooool8o`0006Kooooo2?l0000Zooooo`03o`000?oooooooooo03[ooooo1ol0000:
ooooo`03o`000?oooooooooo02Sooooo00Co8B4QogMgMomgMgOo<S8b<_ooool004oooooo00?o0000
ooooooooool09oooool8o`0006Gooooo2?l0000Zooooo`03o`000?oooooooooo03[ooooo1ol00008
ooooo`Co000000?o0?l0ooooooooool09Oooool2o`0000;ooooo0_l0000aooooo`00Coooool00ol0
003oooooooooo`0Xooooo`So0000Hoooool9o`0002_ooooo00?o0000ooooooooool0>_ooool7o`00
00?ooooo1?l00004ooooo`03o`000?oooooooooo05cooooo001?ooooo`03o`000?oooooooooo02Wo
oooo2?l0001Oooooo`?o00000_ooool8o`0002_ooooo00?o0000ooooooooool0>Oooool:o`0000So
oooo00?o0?l0o`000?ooool0G?ooool004oooooo00?o0000ooooooooool0:Oooool8o`0005gooooo
0_l00006ooooo`Oo0000;?ooool00ol0003oooooooooo`0fooooo`[o00002_ooool00ol0o`3o0000
ooooo`1Looooo`00Coooool00ol0003oooooooooo`0Zooooo`So0000FOooool3o`0000Wooooo1ol0
000/ooooo`03o`000?oooooooooo02cooooo2Ol00003ooooo`Oo00002_ooool00ol0o`3oooooo`00
001Looooo`00Coooool00ol0003oooooooooo`0[ooooo`So0000EOooool3o`0000cooooo2?l0000/
ooooo`03o`000?oooooooooo02Oooooo1?l0000=ooooo`Oo00002Oooool01?l0o`3oooooooooool0
001Kooooo`00Coooool00ol0003oooooooooo`0/ooooo`So0000DOooool3o`00013ooooo1ol0000/
ooooo`03o`000?oooooooooo01oooooo2?l0000Aooooo`Oo00002Oooool01Ol0o`3ooooooooooooo
oooo000005[ooooo001>ooooo`03o`000?oooooooooo02gooooo2Ol0001=ooooo`?o00004oooool8
o`0002cooooo00?o0000ooooooooool06_ooool4o`0001[ooooo1ol00008ooooo`03o`3o0?oooooo
oooo00;ooooo00?o0000ooooooooool0Eoooool004kooooo00?o0000ooooooooool0;_ooool9o`00
04Wooooo0ol0000Gooooo`Oo0000;Oooool00ol0003oooooooooo`0Aooooo`So00007_ooool7o`00
00Sooooo00?o0?l0ooooooooool00_ooool00ol0003oooooooooo`1Gooooo`00C_ooool00ol0003o
ooooooooo`0_ooooo`Wo0000A_ooool2o`0001_ooooo1ol0000]ooooo`03o`000?oooooooooo00co
oooo1?l0000Wooooo`Oo00001oooool00ol0o`3oooooooooo`03ooooo`03o`000?oooooooooo05Ko
oooo001>ooooo`03o`000?oooooooooo033ooooo2Ol00012ooooo`?o00007Oooool7o`0002kooooo
00?o0000ooooooooool01_ooool5o`0002_ooooo1ol00007ooooo`03o`3o0?oooooooooo00Cooooo
00?o0000ooooooooool0EOooool004kooooo00?o0000ooooooooool0<?ooool8o`000003ooooool0
003ooooo03gooooo0ol0000Qooooo`Ko0000;oooool8o`00037ooooo1ol00006ooooo`03o`3o0?oo
oooooooo00Gooooo00?o0000ooooooooool0E?ooool004kooooo00?o0000ooooooooool0<Oooool8
o`000003ooooool0003ooooo03Wooooo0ol0000Tooooo`Oo0000:_ooool5o`0003Sooooo1ol00006
ooooo`03o`3o0?oooooooooo00Gooooo00?o0000ooooooooool0E?ooool000oooooo00?oMgMgofIV
I_ooool02Oooool00ol0003o^[Zjooooo`0;ooooo`03ofIVI_mgMgOooooo02;ooooo00?o0000oooo
ooooool0<_ooool8o`000003ooooool0003ooooo03Gooooo0ol0000Xooooo`Ko00008_ooool8o`00
00Gooooo00?o0000ooooooooool0=_ooool7o`0000Gooooo00?o0?l0ooooooooool01_ooool00ol0
003oooooooooo`1Cooooo`003_ooool00ooMgMgo410@onk^kP0:ooooo`;o<S8b3?ooool00oo^k^ko
410@omgMg@0Rooooo`03o`000?oooooooooo03?ooooo1ol00002ooooo`03o`000?oooooooooo037o
oooo0_l0000[ooooo`Ko00007_ooool4o`0000kooooo00?o0000ooooooooool0=Oooool7o`0000Go
oooo00?o0?l0ooooooooool01oooool00ol0003oooooooooo`1Booooo`000oooool00ol@413o0000
o`000002o`000003oa0@4?oooooooooo00?ooooo00CoEEEEoiRHV?oooooooooo0_l00002ooooo`;o
00000oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X00oooool00on7
QhOoIVIVooooo`0Qooooo`03o`000?oooooooooo03?ooooo2?l00002ooooo`03o`000?oooooooooo
02gooooo0ol0000]ooooo`Oo00005Oooool8o`0001?ooooo00?o0000ooooooooool0=Oooool7o`00
00Cooooo00?o0?l0ooooooooool02?ooool00ol0003oooooooooo`1Aooooo`001Oooool00ol0003o
ooooooooo`06ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo
00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00?ooooo00?ok^k^o`000?oo
ool08Oooool00ol0003oooooooooo`0dooooo`Oo00000oooool00ol0003oooooooooo`0Yooooo`?o
0000<Oooool7o`00013ooooo1?l0000Looooo`03o`000?oooooooooo03Cooooo1ol00004ooooo`03
o`3o0?oooooooooo00Wooooo00?o0000ooooooooool0D?ooool000Gooooo00?o0000ooooooooool0
1_ooool00olb<S;oooooooooo`02ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03Kooooo1ol00003ooooo`03
o`000?oooooooooo02Gooooo0ol0000dooooo`Oo00002?ooool4o`000004o`3o0?l0003o0000o`00
027ooooo00?o0000ooooooooool0=?ooool7o`0000?ooooo00?o0?l0ooooooooool02Oooool00ol0
003oooooooooo`1@ooooo`001Oooool00ol0003oooooooooo`06ooooo`03oc8b<_oooooooooo00;o
oooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool0=_ooool8o`0000?ooooo00?o0000ooooooooool08Oooool3o`00
03Oooooo2?l00003ooooo`Co00001?ooool00ol0o`3oooooooooo`0Sooooo`03o`000?oooooooooo
03?ooooo1ol00003ooooo`;o0?l02oooool00ol0003oooooooooo`1?ooooo`001Oooool00ol0003o
ooooooooo`06ooooo`03o`000?o^k^kooooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0
003oooooooooo`05ooooo`03onk^k_l0003ooooo023ooooo00?o0000ooooooooool0=oooool7o`00
00Cooooo00?o0000ooooooooool07_ooool2o`0003_ooooo2_l00008ooooo`03o`3o0?oooooooooo
02?ooooo00?o0000ooooooooool0=?ooool7o`0000?ooooo00?o0?l0ooooooooool02_ooool00ol0
003oooooooooo`1>ooooo`000oooool00ol@413o0000o`000003o`0000Gooooo00CoEEEEogMgMooo
oooooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Cooooo00?oMgMgoeEE
EOooool08?ooool00ol0003oooooooooo`0gooooo`So00001?ooool00ol0003oooooooooo`0Joooo
o`?o0000>oooool:o`0000[ooooo00?o0?l0ooooooooool09?ooool00ol0003oooooooooo`0coooo
o`Oo00000oooool00ol0o`3oooooooooo`0;ooooo`03o`000?oooooooooo04gooooo0005ooooo`03
o`000?oooooooooo00Kooooo00?ogMgMoa0@4?o^k^h04Oooool00ol0003oooooooooo`04ooooo`03
onk^k_l@413ogMgM027ooooo00?o0000ooooooooool0>?ooool7o`0000Gooooo00?o0000oooooooo
ool05_ooool3o`0003Kooooo2?l00003ooooo`Oo00002_ooool00ol0o`3oooooooooo`0Uooooo`03
o`000?oooooooooo03?ooooo1ol00002ooooo`03o`3o0?oooooooooo00_ooooo00?o0000oooooooo
ool0COooool000Gooooo00?o410@okZj^_ooool01oooool00omgMgOoIVIVooooo`0@ooooo`03o`00
0?oooooooooo00Cooooo00?oIVIVogMgMoooool08Oooool00ol0003oooooooooo`0iooooo`Oo0000
1Oooool00ol0003oooooooooo`0Booooo`?o0000=?ooool5o`0000cooooo1ol00009ooooo`03o`3o
0?oooooooooo02Kooooo00?o0000ooooooooool0<_ooool7o`0000;ooooo00?o0?l0ooooooooool0
3?ooool00ol0003oooooooooo`1<ooooo`001Oooool01?nj^[[o410@o`000?l@4114ooooo`03o`00
0?oooooooooo03Wooooo2?l00005ooooo`03o`000?oooooooooo00kooooo0ol0000`ooooo`Oo0000
4Oooool7o`0000Wooooo00?o0?l0ooooooooool09oooool00ol0003oooooooooo`0booooo`Ko0000
0_ooool00ol0o`3oooooooooo`0=ooooo`03o`000?oooooooooo04_ooooo001=ooooo`03o`000?oo
oooooooo03[ooooo1ol00006ooooo`03o`000?oooooooooo00[ooooo0ol0000_ooooo`Co00006Ooo
ool7o`0000Sooooo00?o0?l0ooooooooool0:?ooool00ol0003oooooooooo`0aooooo`Oo000000?o
ooooo`3o0?ooool03oooool00ol0003oooooooooo`1:ooooo`00COooool00ol0003oooooooooo`0j
ooooo`So00001Oooool00ol0003oooooooooo`08ooooo`;o0000:_ooool8o`0001gooooo1ol00008
ooooo`03o`3o0?oooooooooo02Sooooo00?o0000ooooooooool0<_ooool6o`000003ooooool0o`3o
oooo00oooooo00?o0000ooooooooool0B_ooool004cooooo00?o0000ooooooooool0??ooool7o`00
00Kooooo00?o0000ooooooooool01?ooool3o`0002Sooooo1?l0000Vooooo`Oo00001oooool00ol0
o`3oooooooooo`0Yooooo`03o`000?oooooooooo037ooooo1ol000000ol0o`3oooooooooo`0?oooo
o`03o`000?oooooooooo04Wooooo001<ooooo`03o`000?oooooooooo03gooooo1ol00006ooooo`03
o`000?oooooooooo00?o00008oooool8o`0002[ooooo1ol00007ooooo`03o`3o0?oooooooooo02[o
oooo00?o0000ooooooooool0<?ooool7o`000003o`3o0?oooooooooo013ooooo00?o0000oooooooo
ool0B?ooool004cooooo00?o0000ooooooooool0?Oooool7o`0000Kooooo0ol0000Rooooo`Co0000
<oooool6o`0000Oooooo00?o0?l0ooooooooool0:oooool00ol0003oooooooooo`0`ooooo`Oo0000
4oooool00ol0003oooooooooo`17ooooo`00C?ooool00ol0003oooooooooo`0nooooo`Ko00000ooo
ool3o`0000;ooooo00?o0000ooooooooool06?ooool8o`0003Oooooo1ol00006ooooo`03o`3o0?oo
oooooooo02cooooo00?o0000ooooooooool0;oooool7o`0001Cooooo00?o0000ooooooooool0A_oo
ool004cooooo00?o0000ooooooooool0?_ooool9o`0000Kooooo00?o0000ooooooooool04oooool4
o`00043ooooo1_l00006ooooo`03o`3o0?oooooooooo02gooooo00?o0000ooooooooool0;oooool6
o`0001Cooooo00?o0000ooooooooool0A_ooool004cooooo00?o0000ooooooooool0?oooool6o`00
00Wooooo00?o0000ooooooooool02_ooool8o`0004Cooooo1_l00006ooooo`03o`3o0?oooooooooo
02gooooo00?o0000ooooooooool0;oooool7o`0001Cooooo00?o0000ooooooooool0AOooool004co
oooo00?o0000ooooooooool0?oooool6o`0000[ooooo00Co0000oooooooooooooooo2?l0001<oooo
o`Oo00001Oooool00ol0o`3oooooooooo`0^ooooo`03o`000?oooooooooo02oooooo1_l0000Eoooo
o`03o`000?oooooooooo04Cooooo001<ooooo`03o`000?oooooooooo03cooooo2_l0000:ooooo`?o
0000EOooool6o`0000Gooooo00?o0?l0ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`Oo
00005Oooool00ol0003oooooooooo`13ooooo`00C?ooool00ol0003oooooooooo`0iooooo`?o0000
1?ooool6o`0000_ooooo00?o0?l0ooooooooool0E?ooool7o`0000Cooooo00?o0?l0ooooooooool0
<?ooool00ol0003oooooooooo`0]ooooo`Oo00005Oooool00ol0003oooooooooo`13ooooo`00Booo
ool00ol0003oooooooooo`0hooooo`;o00001oooool7o`0000[ooooo00?o0?l0o`000?ooool0E?oo
ool7o`0000Cooooo00?o0?l0ooooooooool0<Oooool00ol0003oooooooooo`0]ooooo`Oo00005Ooo
ool00ol0003oooooooooo`12ooooo`00Boooool00ol0003oooooooooo`0eooooo`?o00002Oooool7
o`0000[ooooo00?o0?l0ooooool00000EOooool7o`0000?ooooo00?o0?l0ooooooooool0<_ooool0
0ol0003oooooooooo`0/ooooo`Oo00005_ooool00ol0003oooooooooo`11ooooo`00Boooool00ol0
003oooooooooo`0booooo`?o00003Oooool6o`0000[ooooo00Co0?l0oooooooooooo0000E?ooool7
o`0000?ooooo00?o0?l0ooooooooool0<_ooool00ol0003oooooooooo`0]ooooo`Oo00005_ooool0
0ol0003oooooooooo`10ooooo`00Boooool00ol0003oooooooooo`0_ooooo`?o00004?ooool7o`00
00Wooooo00Go0?l0ooooooooooooooooo`00001Dooooo`Oo00000_ooool00ol0o`3oooooooooo`0c
ooooo`03o`000?oooooooooo02cooooo1ol0000Fooooo`03o`000?oooooooooo043ooooo001;oooo
o`03o`000?oooooooooo02cooooo0ol0000Dooooo`Ko00002Oooool00ol0o`3oooooooooo`02oooo
o`03o`000?oooooooooo057ooooo1ol00002ooooo`03o`3o0?oooooooooo03Cooooo00?o0000oooo
ooooool0;?ooool7o`0001Kooooo00?o0000ooooooooool0?oooool004_ooooo00?o0000oooooooo
ool0:Oooool3o`0001Oooooo1ol00008ooooo`03o`3o0?oooooooooo00?ooooo00?o0000oooooooo
ool0DOooool7o`000003ooooool0o`3ooooo03Kooooo00?o0000ooooooooool0:oooool7o`0001Oo
oooo00?o0000ooooooooool0?_ooool004_ooooo00?o0000ooooooooool09oooool2o`0001[ooooo
1ol00008ooooo`03o`3o0?oooooooooo00Cooooo00?o0000ooooooooool0D?ooool7o`000003oooo
ool0o`3ooooo03Oooooo00?o0000ooooooooool0:oooool7o`0001Oooooo00?o0000ooooooooool0
?Oooool004_ooooo00?o0000ooooooooool09?ooool3o`0001gooooo1ol00007ooooo`03o`3o0?oo
oooooooo00Gooooo00?o0000ooooooooool0D?ooool7o`000003o`3o0?oooooooooo03Oooooo00?o
0000ooooooooool0:_ooool7o`0001Sooooo00?o0000ooooooooool0??ooool004_ooooo00?o0000
ooooooooool08Oooool3o`00023ooooo1ol00006ooooo`03o`3o0?oooooooooo00Oooooo00?o0000
ooooooooool0Coooool7o`000003o`3o0?oooooooooo03Oooooo00?o0000ooooooooool0:oooool6
o`0001Sooooo00?o0000ooooooooool0??ooool004[ooooo00?o0000ooooooooool07oooool3o`00
02Cooooo1_l00006ooooo`03o`3o0?oooooooooo00Sooooo00?o0000ooooooooool0Coooool6o`00
0003o`3o0?oooooooooo03Sooooo00?o0000ooooooooool0:_ooool7o`0001Sooooo00?o0000oooo
ooooool0>oooool004[ooooo00?o0000ooooooooool07?ooool3o`0002Oooooo1ol00005ooooo`03
o`3o0?oooooooooo00Wooooo00?o0000ooooooooool0C_ooool7o`0003_ooooo00?o0000oooooooo
ool0:_ooool6o`0001Wooooo00?o0000ooooooooool0>_ooool004[ooooo00?o0000ooooooooool0
6_ooool2o`0002_ooooo1_l00005ooooo`03o`3o0?oooooooooo00[ooooo00?o0000ooooooooool0
C_ooool6o`0003cooooo00?o0000ooooooooool0:Oooool7o`0001Wooooo00?o0000ooooooooool0
>Oooool004[ooooo00?o0000ooooooooool05oooool3o`0002gooooo1ol00004ooooo`03o`3o0?oo
oooooooo00_ooooo00?o0000ooooooooool0COooool6o`0003gooooo00?o0000ooooooooool0:?oo
ool7o`0001Wooooo00?o0000ooooooooool0>Oooool004[ooooo00?o0000ooooooooool05?ooool3
o`00033ooooo1ol00004ooooo`03o`3o0?oooooooooo00cooooo00?o0000ooooooooool0C?ooool7
o`0003gooooo00?o0000ooooooooool0:?ooool7o`0001Wooooo00?o0000ooooooooool0>?ooool0
04[ooooo00?o0000ooooooooool04Oooool3o`0003Cooooo1ol00003ooooo`03o`3o0?oooooooooo
00gooooo00?o0000ooooooooool0C?ooool6o`0003gooooo00?o0000ooooooooool0:?ooool7o`00
01[ooooo00?o0000ooooooooool0=oooool004[ooooo00?o0000ooooooooool03_ooool3o`0003Oo
oooo1ol00003ooooo`03o`3o0?oooooooooo00kooooo00?o0000ooooooooool0Boooool6o`0003ko
oooo00?o0000ooooooooool0:?ooool7o`0001[ooooo00?o0000ooooooooool0=_ooool004[ooooo
00?o0000ooooooooool02oooool3o`0003_ooooo1_l00003ooooo`03o`3o0?oooooooooo00oooooo
00?o0000ooooooooool0B_ooool7o`0003kooooo00?o0000ooooooooool09oooool7o`0001_ooooo
00?o0000ooooooooool0=Oooool004[ooooo00?o0000ooooooooool02Oooool2o`0003kooooo1ol0
0002ooooo`03o`3o0?oooooooooo013ooooo00?o0000ooooooooool0B_ooool6o`0003oooooo00?o
0000ooooooooool09oooool7o`0001[ooooo00?o0000ooooooooool0=Oooool004Wooooo00?o0000
ooooooooool01oooool3o`00047ooooo1_l00002ooooo`03o`3o0?oooooooooo017ooooo00?o0000
ooooooooool0BOooool7o`0003oooooo00?o0000ooooooooool09_ooool7o`0001_ooooo00?o0000
ooooooooool0=?ooool004Wooooo00?o0000ooooooooool01?ooool3o`0004Cooooo1_l00002oooo
o`03o`3o0?oooooooooo01;ooooo00?o0000ooooooooool0B?ooool7o`00043ooooo00?o0000oooo
ooooool09_ooool7o`0001_ooooo00?o0000ooooooooool0<oooool004Wooooo00Co0000oooooooo
oooooooo0ol00017ooooo`Oo000000?oooooo`3o0?ooool05?ooool00ol0003oooooooooo`18oooo
o`Oo0000?oooool00ol0003oooooooooo`0Vooooo`Oo00007?ooool00ol0003oooooooooo`0boooo
o`00BOooool4o`0004_ooooo1_l000000ooooooo0?l0ooooo`0Eooooo`03o`000?oooooooooo04Oo
oooo1ol00010ooooo`03o`000?oooooooooo02Kooooo1_l0000Looooo`03o`000?oooooooooo03;o
oooo0019ooooo`;o0000COooool6o`000003ooooool0o`3ooooo01Kooooo00?o0000ooooooooool0
Aoooool7o`00043ooooo00?o0000ooooooooool09Oooool7o`0001cooooo00?o0000ooooooooool0
<Oooool004_ooooo00?o0000ooooooooool0B_ooool6o`0000;o0?l06?ooool00ol0003ooooooooo
o`16ooooo`Oo0000@Oooool00ol0003oooooooooo`0Uooooo`Ko00007Oooool00ol0003ooooooooo
o`0`ooooo`00C?ooool00ol0003oooooooooo`1:ooooo`Ko00006_ooool00ol0003oooooooooo`16
ooooo`Oo0000@Oooool00ol0003oooooooooo`0Tooooo`Oo00007Oooool00ol0003oooooooooo`0_
ooooo`00COooool00ol0003oooooooooo`19ooooo`Ko00006oooool00ol0003oooooooooo`15oooo
o`Oo0000@_ooool00ol0003oooooooooo`0Sooooo`Oo00007Oooool00ol0003oooooooooo`0_oooo
o`00C_ooool00ol0003oooooooooo`18ooooo`Ko00007?ooool00ol0003oooooooooo`15ooooo`Oo
0000@Oooool00ol0003oooooooooo`0Tooooo`Oo00007Oooool00ol0003oooooooooo`0^ooooo`00
Coooool00ol0003oooooooooo`17ooooo`Oo00007?ooool00ol0003oooooooooo`14ooooo`Oo0000
@_ooool00ol0003oooooooooo`0Sooooo`Oo00007_ooool00ol0003oooooooooo`0]ooooo`00D?oo
ool00ol0003oooooooooo`17ooooo`Ko00007Oooool00ol0003oooooooooo`14ooooo`Ko0000@ooo
ool00ol0003oooooooooo`0Sooooo`Oo00007_ooool00ol0003oooooooooo`0/ooooo`00DOooool0
0ol0003oooooooooo`16ooooo`Ko00007_ooool00ol0003oooooooooo`13ooooo`Oo0000@oooool0
0ol0003oooooooooo`0Rooooo`Oo00007oooool00ol0003oooooooooo`0[ooooo`00D_ooool00ol0
003oooooooooo`15ooooo`Oo00007_ooool00ol0003oooooooooo`13ooooo`Ko0000A?ooool00ol0
003oooooooooo`0Rooooo`Ko00007oooool00ol0003oooooooooo`0[ooooo`00Doooool00ol0003o
ooooooooo`15ooooo`Ko00007oooool00ol0003oooooooooo`12ooooo`Ko0000AOooool00ol0003o
ooooooooo`0Qooooo`Oo00007oooool00ol0003oooooooooo`0Zooooo`00E?ooool00ol0003ooooo
ooooo`14ooooo`Ko00008?ooool00ol0003oooooooooo`11ooooo`Oo0000A?ooool00ol0003ooooo
ooooo`0Rooooo`Ko00008?ooool00ol0003oooooooooo`0Yooooo`00EOooool2o`0004Cooooo1ol0
000Pooooo`03o`3o0?l0003o000000Ko0000>oooool6o`0004Gooooo00?o0000ooooooooool08Ooo
ool7o`00023ooooo00?o0000ooooooooool0:?ooool005Oooooo00?o0000ooooooooool0@_ooool6
o`00023ooooo00?o0?l0o`000?ooool01_oooolBo`0002Wooooo1_l00016ooooo`03o`000?oooooo
oooo023ooooo1ol0000Pooooo`03o`000?oooooooooo02Sooooo001Hooooo`03o`000?oooooooooo
047ooooo1_l0000Pooooo`03o`3o0?oooooo000001Sooooo4ol0000Fooooo`Oo0000A_ooool00ol0
003oooooooooo`0Pooooo`Oo00008?ooool00ol0003oooooooooo`0Wooooo`00FOooool00ol0003o
ooooooooo`10ooooo`Ko00008?ooool01?l0o`3oooooooooool0000Zoooooa;o00001Oooool6o`00
04Oooooo00?o0000ooooooooool07oooool7o`00027ooooo00?o0000ooooooooool09_ooool005[o
oooo00?o0000ooooooooool0@?ooool6o`0001oooooo00Go0?l0ooooooooooooooooo`00000koooo
oa?o0000@?ooool00ol0003oooooooooo`0Oooooo`Oo00007_ooool4o`0002Oooooo001Kooooo`03
o`000?oooooooooo03oooooo1_l0000Oooooo`03o`3o0?oooooooooo00;ooooo00?o0000oooooooo
ool0?Oooool7o`0000Oooooo4_l0000_ooooo`03o`000?oooooooooo01kooooo1ol0000Fooooo`So
00000oooool00ol0o`3o0000ooooo`0Uooooo`00G?ooool00ol0003oooooooooo`0nooooo`Ko0000
7oooool00ol0o`3oooooooooo`03ooooo`03o`000?oooooooooo03gooooo1ol0000Hooooo`ko0000
00?o0?l0o`000?l000000_l0000Looooo`03o`000?oooooooooo01oooooo1ol0000=ooooo`So0000
2oooool00ol0o`3o0000ooooo`0Uooooo`00GOooool00ol0003oooooooooo`0mooooo`Ko00007ooo
ool00ol0o`3oooooooooo`04ooooo`03o`000?oooooooooo03cooooo1ol0000Vooooo`03o`3o0?oo
oooooooo00;ooooo4_l0000;ooooo`03o`000?oooooooooo01kooooo1ol00009ooooo`Co00004ooo
ool00ol0o`3oooooo`00000Uooooo`00G_ooool00ol0003oooooooooo`0mooooo`Go00007oooool0
0ol0o`3oooooooooo`05ooooo`03o`000?oooooooooo03cooooo1ol0000Uooooo`03o`3o0?oooooo
oooo01Cooooo4ol0000Jooooo`oo00005oooool01?l0o`3oooooooooool0000Tooooo`00Goooool0
0ol0003oooooooooo`0looooo`Ko00007_ooool00ol0o`3oooooooooo`06ooooo`03o`000?oooooo
oooo03_ooooo1ol0000Uooooo`03o`3o0?oooooooooo027ooooo00?o0000ooooooooool00ooooolB
o`0000Oooooo2?l0000Oooooo`03o`3o0?l0003o000000?o00008_ooool0063ooooo00?o0000oooo
ooooool0>oooool6o`0001kooooo00?o0?l0ooooooooool01oooool00ol0003oooooooooo`0koooo
o`Oo00009?ooool00ol0o`3oooooooooo`0Rooooo`03o`000?oooooooooo01Cooooo4_l0000Koooo
o`03o`000?l0o`3o000000Go00008Oooool0067ooooo00?o0000ooooooooool0>_ooool6o`0001ko
oooo00?o0?l0ooooooooool02?ooool00ol0003oooooooooo`0jooooo`Oo00009?ooool00ol0o`3o
ooooooooo`0Sooooo`03o`000?oooooooooo00oooooo2?l00005ooooo`Oo00000_oooolBo`0000So
oooo2_l0000Pooooo`00H_ooool2o`0003[ooooo1ol0000Mooooo`03o`3o0?oooooooooo00Wooooo
00?o0000ooooooooool0>_ooool6o`0002Cooooo00?o0?l0ooooooooool08oooool00ol0003ooooo
ooooo`07ooooo`So00003_ooool7o`0001?ooooo5?l0000Nooooo`00I?ooool00ol0003ooooooooo
o`0hooooo`Ko00007Oooool00ol0o`3oooooooooo`0:ooooo`03o`000?oooooooooo03Wooooo1ol0
000Sooooo`03o`3o0?oooooooooo02Cooooo00?o0000ooooooooool00_ooool4o`0001Kooooo1ol0
000Jooooo`ko00007Oooool006Gooooo00?o0000ooooooooool0=oooool6o`0001gooooo00?o0?l0
ooooooooool02oooool00ol0003oooooooooo`0iooooo`Ko00008oooool00ol0o`3oooooooooo`0R
ooooo`Oo00006oooool7o`0001Wooooo3_l0000Mooooo`00I_ooool00ol0003oooooooooo`0foooo
o`Oo00007?ooool00ol0o`3oooooooooo`0<ooooo`03o`000?oooooooooo03Sooooo1ol0000Roooo
o`03o`3o0?oooooooooo01[ooooo2?l00004ooooo`03o`000?oooooooooo01_ooooo1ol0000Ioooo
o`oo00007?ooool006Oooooo00?o0000ooooooooool0=_ooool6o`0001cooooo00?o0?l0oooooooo
ool03Oooool00ol0003oooooooooo`0gooooo`Oo00008_ooool00ol0o`3oooooooooo`0Fooooo`Co
00003Oooool00ol0003oooooooooo`0Kooooo`Oo00006?ooool6o`000003ooooool0003o000000Oo
00006oooool006Sooooo00?o0000ooooooooool0=Oooool6o`0001cooooo00?o0?l0ooooooooool0
3_ooool00ol0003oooooooooo`0gooooo`Ko00008_ooool00ol0o`3oooooooooo`0>ooooo`So0000
4_ooool00ol0003oooooooooo`0Jooooo`Oo00005Oooool8o`0000Cooooo00?o0000o`3o0?l00000
1Ol0000Jooooo`00JOooool00ol0003oooooooooo`0dooooo`Oo00006oooool00ol0o`3ooooooooo
o`0?ooooo`03o`000?oooooooooo03Kooooo1ol0000Qooooo`03o`3o0?oooooooooo00Oooooo00?o
0?l0o`000?l000001?l0000Jooooo`03o`000?oooooooooo01_ooooo1ol0000Aooooo`?o00000ooo
ool5o`0000Cooooo00?o0000o`3o0?l000001_l0000Iooooo`00J_ooool00ol0003oooooooooo`0d
ooooo`Ko00006oooool00ol0o`3oooooooooo`0@ooooo`03o`000?oooooooooo03Kooooo1_l0000Q
ooooo`03o`3o0?oooooo000000Oo000000?o0?l0ooooooooool07oooool00ol0003oooooooooo`0J
ooooo`Oo00003Oooool4o`0000Kooooo1Ol00005ooooo`03o`3o0?l0003o000000Go00006Oooool0
06_ooooo00?o0000ooooooooool0<oooool6o`0001_ooooo00?o0?l0ooooooooool04Oooool00ol0
003oooooooooo`0eooooo`Ko00007oooool2o`000003o`3o0?l0003ooooo00Oooooo00?o0?l0oooo
ooooool08?ooool00ol0003oooooooooo`0Jooooo`Oo00002Oooool3o`0000[ooooo1_l00004oooo
o`03o`3o0?l0003o000000Ko00006?ooool006cooooo00?o0000ooooooooool0<_ooool6o`0001[o
oooo00?o0?l0ooooooooool04oooool00ol0003oooooooooo`0dooooo`Oo00005oooool7o`0000;o
oooo00?o0?l0ooooooooool01oooool00ol0o`3oooooooooo`0Qooooo`03o`000?oooooooooo01Wo
oooo1ol00006ooooo`?o00003Oooool6o`0000Cooooo00?o0?l0ooooool000001ol0000Gooooo`00
KOooool00ol0003oooooooooo`0booooo`Ko00006Oooool00ol0o`3oooooooooo`0Dooooo`03o`00
0?oooooooooo03Cooooo1_l0000?ooooo`So00002Oooool00ol0o`3oooooooooo`07ooooo`03o`3o
0?oooooooooo02;ooooo00?o0000ooooooooool06Oooool7o`0000?ooooo0_l0000@ooooo`Ko0000
1?ooool00ol0o`3oooooooooo`08o`0001Kooooo001^ooooo`;o0000<_ooool6o`0001Wooooo00?o
0?l0ooooooooool05Oooool00ol0003oooooooooo`0cooooo`Oo00002_ooool4o`00017ooooo00?o
0?l0ooooooooool01oooool00ol0o`3oooooooooo`0Sooooo`03o`000?oooooooooo01Sooooo1ol0
00000ooooooo0000o`00000Booooo`Ko00001?ooool00ol0o`3oooooooooo`09o`0001Gooooo001`
ooooo`03o`000?oooooooooo02oooooo1_l0000Iooooo`03o`3o0?oooooooooo01Kooooo00?o0000
ooooooooool0<_ooool7o`0000?ooooo1ol0000Eooooo`03o`3o0?oooooooooo00Oooooo00?o0?l0
ooooooooool08oooool00ol0003oooooooooo`0Iooooo`Oo00005Oooool5o`0000Cooooo00Co0?l0
oooooooooooooooo2Ol0000Dooooo`00LOooool00ol0003oooooooooo`0^ooooo`Ko00006Oooool0
0ol0o`3oooooooooo`0Fooooo`03o`000?oooooooooo03?ooooo2Ol0000Looooo`03o`3o0?oooooo
oooo00Oooooo00?o0?l0ooooooooool09?ooool00ol0003oooooooooo`0Hooooo`Oo00005Oooool5
o`0000Gooooo00Co0?l0oooooooooooooooo2?l0000Dooooo`00L_ooool00ol0003oooooooooo`0^
ooooo`Go00006Oooool00ol0o`3oooooooooo`0Gooooo`03o`000?oooooooooo02cooooo3Ol0000N
ooooo`03o`3o0?oooooooooo00Oooooo00?o0?l0ooooooooool09Oooool00ol0003oooooooooo`0C
ooooo`Co000000?oooooo`000?l000001?l0000Eooooo`Ko00001?ooool00ol0o`3oooooooooo`02
ooooo`So00004oooool007?ooooo00?o0000ooooooooool0;Oooool6o`0001Sooooo00?o0?l0oooo
ooooool06?ooool00ol0003oooooooooo`0Wooooo`Co00001oooool6o`0001kooooo00?o0?l0oooo
ooooool01oooool00ol0o`3oooooooooo`0Vooooo`03o`000?oooooooooo00oooooo0ol00005oooo
o`Oo00005?ooool6o`0000Cooooo00?o0?l0ooooooooool00oooool8o`0001;ooooo001dooooo`03
o`000?oooooooooo02cooooo1_l0000Hooooo`03o`3o0?oooooooooo01Wooooo00?o0000oooooooo
ool07oooool7o`0000_ooooo1ol0000Mooooo`03o`3o0?oooooooooo00Sooooo00?o0?l0oooooooo
ool09_ooool00ol0003oooooooooo`0;ooooo`?o00002?ooool7o`0001Cooooo1_l00004ooooo`03
o`3o0?oooooooooo00Cooooo2?l0000Aooooo`00MOooool00ol0003oooooooooo`0[ooooo`Ko0000
6?ooool00ol0o`3oooooooooo`0Jooooo`03o`000?oooooooooo01Kooooo2?l0000Booooo`Oo0000
7Oooool00ol0o`3oooooooooo`08ooooo`03o`3o0?oooooooooo02Oooooo00?o0000ooooooooool0
1_ooool4o`0000cooooo1ol0000Cooooo`Ko00001?ooool00ol0o`3oooooooooo`04ooooo`Wo0000
4?ooool007Kooooo00?o0000ooooooooool0:_ooool6o`0001Sooooo00?o0?l0ooooooooool06ooo
ool00ol0003oooooooooo`0>ooooo`Oo00006oooool7o`0001cooooo00?o0?l0ooooooooool02?oo
ool00ol0o`3oooooooooo`0Wooooo`03o`000?oooooooooo00?ooooo0ol0000@ooooo`Oo00005?oo
ool5o`0000Cooooo00?o0?l0ooooooooool01Oooool9o`0000oooooo001gooooo`03o`000?oooooo
oooo02[ooooo1_l0000Gooooo`03o`3o0?oooooooooo01cooooo00?o0000ooooooooool02Oooool4
o`0002;ooooo1ol0000Looooo`03o`3o0?oooooooooo00Sooooo00?o0?l0ooooooooool0:?ooool5
o`0001Cooooo1ol0000Cooooo`Go00001?ooool00ol0o`3oooooooooo`06ooooo`So00003oooool0
07Sooooo00?o0000ooooooooool0:Oooool6o`0001Oooooo00?o0?l0ooooooooool07Oooool01?l0
003oooooooooooooool7o`0002Oooooo1ol0000Kooooo`03o`3o0?oooooooooo00Sooooo00?o0?l0
ooooooooool09_ooool4o`0001Oooooo1ol0000Cooooo`Go00001?ooool00ol0o`3oooooooooo`07
ooooo`So00003_ooool007Wooooo00?o0000ooooooooool0:?ooool6o`0001Oooooo00?o0?l0oooo
ooooool07_ooool00ol0o`3o0000o`00000^ooooo`Oo00006oooool00ol0o`3oooooooooo`08oooo
o`03o`3o0?oooooooooo02;ooooo1?l00004ooooo`03o`000?oooooooooo01Gooooo1_l0000Coooo
o`Ko00000oooool00ol0o`3oooooooooo`08ooooo`So00003Oooool007[ooooo00?o0000oooooooo
ool09oooool7o`0001Kooooo00?o0?l0ooooooooool07_ooool00ol0o`3o0000ooooo`0_ooooo`Ko
00006oooool00ol0o`3oooooooooo`08ooooo`04o`3o0?ooooooooooooooo`[o00005?ooool3o`00
00Wooooo00?o0000ooooooooool05?ooool7o`0001;ooooo0ol000000ol0o`3o0000o`000003oooo
o`03o`3o0?oooooooooo00Wooooo1ol0000=ooooo`00Noooool2o`0002Sooooo1_l0000Fooooo`03
o`3o0?oooooooooo01kooooo00?o0?l0ooooool00000;oooool7o`0001[ooooo00?o0?l0oooooooo
ool02?ooool00ol0o`3oooooooooo`0<o`00013ooooo0ol0000=ooooo`03o`000?oooooooooo01Co
oooo1_l0000Booooo`?o000000?o0?l0o`000?l000000oooool00ol0o`3oooooooooo`09ooooo`So
00003?ooool007gooooo00?o0000ooooooooool09Oooool6o`0001Kooooo00?o0?l0ooooooooool0
7_ooool01?l0o`3oooooooooool0000_ooooo`Ko00006_ooool00ol0o`3oooooooooo`08ooooo`03
o`3o0?oooooooooo00oo00002Oooool4o`00013ooooo00?o0000ooooooooool05?ooool7o`00017o
oooo1_l00003ooooo`03o`3o0?oooooooooo00[ooooo2?l0000;ooooo`00O_ooool00ol0003ooooo
ooooo`0Tooooo`Oo00005Oooool00ol0o`3oooooooooo`0Nooooo`05o`3o0?ooooooooooooooool0
0000;_ooool6o`0001[ooooo00?o0?l0ooooooooool02?ooool00ol0o`3oooooo`00000@o`0000Go
oooo0ol0000Eooooo`03o`000?oooooooooo01?ooooo1ol0000Booooo`Go00000oooool00ol0o`3o
ooooooooo`0;ooooo`So00002_ooool007oooooo00?o0000ooooooooool09?ooool6o`0001Gooooo
00?o0?l0ooooooooool07_ooool00ol0o`3oooooooooo`02ooooo`03o`000?oooooooooo02_ooooo
1ol0000Iooooo`03o`3o0?oooooooooo00Sooooo00?o0?l0o`000?l000004Ol000001?oooooo0000
o`000?l0000Iooooo`03o`000?oooooooooo01?ooooo1ol0000Aooooo`Go00000oooool00ol0o`3o
ooooooooo`0;ooooo`Wo00002Oooool0083ooooo00?o0000ooooooooool08oooool6o`0001Gooooo
00?o0?l0ooooooooool07_ooool00ol0o`3oooooooooo`03ooooo`03o`000?oooooooooo02_ooooo
1_l0000Iooooo`03o`3o0?oooooooooo00Sooooo00?o0?l0o`000?l000001Ol00002ooooo`_o0000
7Oooool00ol0003oooooooooo`0Booooo`Oo00004Oooool6o`0000?ooooo00?o0?l0ooooooooool0
2oooool9o`0000Sooooo0021ooooo`03o`000?oooooooooo02;ooooo1_l0000Eooooo`03o`3o0?oo
oooooooo01kooooo00?o0?l0ooooooooool01?ooool00ol0003oooooooooo`0Zooooo`Ko00006Ooo
ool00ol0o`3oooooooooo`08ooooo`03o`3o0?l0003o000000Go00000oooool;o`0001gooooo00?o
0000ooooooooool04_ooool7o`00013ooooo1_l00003ooooo`03o`3o0?oooooooooo00cooooo2?l0
0008ooooo`00P_ooool00ol0003oooooooooo`0Rooooo`Ko00005?ooool00ol0o`3oooooooooo`0N
ooooo`03o`3o0?oooooooooo00Gooooo00?o0000ooooooooool0:Oooool7o`0001Sooooo00?o0?l0
ooooooooool02?ooool00ol0o`3o0000o`000004o`0000Cooooo3?l0000Mooooo`03o`000?oooooo
oooo017ooooo1ol0000@ooooo`Ko00000oooool00ol0o`3oooooooooo`0=ooooo`Oo00002?ooool0
08?ooooo00?o0000ooooooooool08Oooool6o`0001Cooooo00?o0?l0ooooooooool07_ooool00ol0
o`3oooooooooo`06ooooo`03o`000?oooooooooo02Wooooo1_l0000Hooooo`03o`3o0?oooooooooo
00Oooooo00?o0000o`3o0?l000001?l000000ooooooo0000o`000002o`0000Cooooo2Ol0000Loooo
o`03o`000?oooooooooo01;ooooo1ol0000?ooooo`Ko00000oooool00ol0o`3oooooooooo`0>oooo
o`Ko00002?ooool008Cooooo00?o0000ooooooooool08?ooool6o`0001?ooooo00?o0?l0oooooooo
ool07oooool00ol0o`3oooooooooo`07ooooo`03o`000?oooooooooo02Sooooo1ol0000Gooooo`03
o`3o0?oooooooooo00Oooooo00?o0000o`3o0?l000001Ol00009ooooo`Wo00007?ooool00ol0003o
ooooooooo`0Aooooo`Oo00004?ooool5o`0000?ooooo00?o0?l0ooooooooool03oooool5o`0000So
oooo0025ooooo`03o`000?oooooooooo01oooooo1_l0000Cooooo`03o`3o0?oooooooooo01oooooo
00?o0?l0ooooooooool02?ooool00ol0003oooooooooo`0Wooooo`Oo00005oooool00ol0o`3ooooo
ooooo`07ooooo`03o`000?l0o`3o000000?o00003?ooool8o`0001gooooo00?o0000ooooooooool0
4Oooool7o`0000oooooo1_l00002ooooo`03o`3o0?oooooooooo017ooooo0ol00008ooooo`00Q_oo
ool00ol0003oooooooooo`0Oooooo`Go00004oooool00ol0o`3oooooooooo`0Oooooo`03o`3o0?oo
oooooooo00Wooooo00?o0000ooooooooool09oooool7o`0001Kooooo00?o0?l0ooooooooool01Ooo
ool3o`000003o`3o0?l0003o000000;o00003Oooool8o`0001gooooo00?o0000ooooooooool04?oo
ool7o`0000oooooo1_l00002ooooo`03o`3o0?oooooooooo00kooooo0ol00002ooooo`03o`000?oo
oooooooo00Kooooo0027ooooo`;o00007oooool6o`0001;ooooo00?o0?l0ooooooooool07oooool0
0ol0o`3oooooooooo`0:ooooo`03o`000?oooooooooo02Kooooo1ol0000Fooooo`03o`3o0?oooooo
oooo00;ooooo0ol00002ooooo`03o`000?l0o`3o000000;o00003oooool8o`0001gooooo00?o0000
ooooooooool04?ooool6o`0000oooooo1_l00002ooooo`03o`3o0?oooooooooo00_ooooo0ol00005
ooooo`03o`000?oooooooooo00Kooooo0029ooooo`03o`000?oooooooooo01cooooo1_l0000Boooo
o`03o`3o0?oooooooooo01oooooo00?o0?l0ooooooooool02oooool00ol0003oooooooooo`0Voooo
o`Ko00005_ooool00ol0o`3oooooo`000002o`0000Cooooo0_l000001?l0o`3o0000o`000?l0000@
ooooo`So00007Oooool00ol0003oooooooooo`0?ooooo`Oo00003_ooool6o`0000;ooooo00?o0?l0
ooooooooool01oooool4o`0000Sooooo00?o0000ooooooooool01_ooool008[ooooo00?o0000oooo
ooooool06oooool6o`0001;ooooo00?o0?l0ooooooooool07oooool00ol0o`3oooooooooo`0<oooo
o`03o`000?oooooooooo02Gooooo1ol0000Cooooo`;o000000?o0?l0o`000?ooool01_ooool6o`00
013ooooo2_l0000Kooooo`03o`000?oooooooooo013ooooo1_l0000?ooooo`Ko000000?oooooo`3o
0?ooool01Oooool3o`0000cooooo00?o0000ooooooooool01_ooool008_ooooo00?o0000oooooooo
ool06_ooool6o`0001;ooooo00?o0?l0ooooooooool07oooool00ol0o`3oooooooooo`0=ooooo`03
o`000?oooooooooo02Gooooo1_l0000@ooooo`?o00000_ooool00ol0o`3oooooooooo`06ooooo`;o
000000Co0?l0o`000?l0003o00004Oooool:o`0001_ooooo00?o0000ooooooooool03oooool7o`00
00kooooo1_l000000ooooooo0?l0ooooo`02ooooo`?o00003oooool00ol0003oooooooooo`06oooo
o`00S?ooool00ol0003oooooooooo`0Jooooo`Ko00004Oooool00ol0o`3oooooooooo`0Oooooo`03
o`3o0?oooooooooo00kooooo00?o0000ooooooooool09?ooool6o`0000gooooo0ol00005ooooo`03
o`3o0?oooooooooo00Kooooo0_l000001?l0o`3o0000o`000?l0000Booooo`[o00006oooool00ol0
003oooooooooo`0>ooooo`Oo00003_ooool6o`000003ooooool0o`3o000000;o00004_ooool00ol0
003oooooooooo`06ooooo`00SOooool00ol0003oooooooooo`0Iooooo`Ko00004Oooool00ol0o`3o
ooooooooo`0Oooooo`03o`3o0?oooooooooo00oooooo00?o0000ooooooooool08oooool7o`0000So
oooo1?l00008ooooo`03o`3o0?oooooooooo00Kooooo0_l000000ol0o`3o0000o`00000Dooooo`Wo
00007?ooool00ol0003oooooooooo`0>ooooo`Oo00003Oooool7o`000003o`3o0?oooooooooo01Co
oooo00?o0000ooooooooool01Oooool008kooooo00?o0000ooooooooool06?ooool6o`00017ooooo
00?o0?l0ooooooooool07oooool00ol0o`3oooooooooo`0@ooooo`03o`000?oooooooooo02?ooooo
1_l00005ooooo`?o00003?ooool00ol0o`3oooooooooo`06ooooo`;o000000?o0?l0o`000?l00000
5Oooool9o`0001cooooo00?o0000ooooooooool03Oooool7o`0000gooooo1ol000000ooooooo0?l0
ooooo`0Dooooo`03o`000?oooooooooo00Gooooo002?ooooo`03o`000?oooooooooo01Oooooo1ol0
000@ooooo`03o`3o0?oooooooooo01oooooo00?o0?l0ooooooooool04Oooool00ol0003ooooooooo
o`0Rooooo`Ko00000_ooool3o`0000oooooo00?o0?l0ooooooooool01_ooool2o`000003o`3o0?l0
003o000001Oooooo2?l0000Looooo`03o`000?oooooooooo00gooooo1ol00009ooooo`?o000000?o
ooooo`000?l000001?l000000ooooooo0?l0ooooo`0Dooooo`03o`000?oooooooooo00Gooooo002@
ooooo`03o`000?oooooooooo01Oooooo1_l0000@ooooo`03o`3o0?oooooooooo01oooooo00?o0?l0
ooooooooool04_ooool00ol0003oooooooooo`0Qooooo`So00004_ooool00ol0o`3oooooooooo`06
ooooo`Go00006?ooool8o`0001_ooooo00?o0000ooooooooool03Oooool7o`0000Kooooo0ol00004
ooooo`Oo000000?o0?l0ooooooooool04oooool00ol0003oooooooooo`05ooooo`00TOooool00ol0
003oooooooooo`0Fooooo`Ko00004?ooool00ol0o`3oooooooooo`0Oooooo`03o`3o0?oooooooooo
01?ooooo00?o0000ooooooooool08Oooool6o`0001?ooooo00?o0?l0ooooooooool01_ooool5o`00
01Sooooo2Ol0000Kooooo`03o`000?oooooooooo00gooooo1ol000000ooooooo0000o`000002o`00
00Sooooo1_l000000ol0o`3oooooooooo`0Cooooo`03o`000?oooooooooo00Gooooo002Booooo`03
o`000?oooooooooo01Gooooo1ol0000?ooooo`03o`3o0?oooooooooo01oooooo00?o0?l0oooooooo
ool01_ooool<o`0000;ooooo00?o0000ooooooooool07Oooool:o`0001;ooooo00?o0?l0oooooooo
ool01_ooool5o`0001Wooooo2Ol0000Kooooo`03o`000?oooooooooo00cooooo2?l0000<ooooo`Ko
000000?o0?l0ooooooooool04oooool00ol0003oooooooooo`05ooooo`00Toooool00ol0003ooooo
ooooo`0Eooooo`Ko00003oooool00ol0o`3oooooooooo`0Oooooo`03o`3o0?oooooooooo00?ooooo
4ol0000Kooooo`?o00000oooool7o`0001?ooooo00?o0?l0ooooooooool01Oooool5o`0001[ooooo
2Ol0000Kooooo`03o`000?oooooooooo00cooooo1ol0000<ooooo`Ko000000?o0?l0ooooooooool0
4oooool00ol0003oooooooooo`05ooooo`00U?ooool2o`0001Gooooo1_l0000?ooooo`03o`3o0?oo
oooooooo01oooooo00Co0?l0oooooooooooooooo5_l0000Gooooo`?o00001oooool7o`0001;ooooo
00?o0?l0ooooooooool01Oooool5o`0001_ooooo2?l0000Looooo`03o`000?oooooooooo00Sooooo
2_l0000=ooooo`Go000000?o0?l0ooooooooool04oooool00ol0003oooooooooo`05ooooo`00U_oo
ool00ol0003oooooooooo`0Booooo`Ko00003oooool00ol0o`3oooooooooo`0Oooooo`03o`3o0?oo
oooooooo01[o00004?ooool4o`0000[ooooo1ol0000Booooo`03o`3o0?oooooooooo00Gooooo1Ol0
000Looooo`So00007?ooool00ol0003oooooooooo`04ooooo`?o00001?ooool6o`0000gooooo1_l0
000Eooooo`03o`000?oooooooooo00Gooooo002Gooooo`03o`000?oooooooooo01;ooooo1_l0000>
ooooo`03o`3o0?oooooooooo01oooooo00?o0?l0ooooool000006ol0000<ooooo`?o00003oooool7
o`00017ooooo00?o0?l0ooooooooool01Oooool5o`0001gooooo2?l0000Looooo`03o`000?oooooo
oooo00?o00001oooool7o`0000cooooo1_l0000Eooooo`03o`000?oooooooooo00Gooooo002Hoooo
o`03o`000?oooooooooo017ooooo1_l0000>ooooo`03o`3o0?oooooooooo01oooooo00?o0?l0o`00
0?l000002_l00004ooooo`ko00002?ooool3o`0001;ooooo1ol0000Aooooo`03o`3o0?oooooooooo
00Gooooo1Ol0000Nooooo`So00006_ooool4o`0000_ooooo1_l0000<ooooo`Ko00005Oooool00ol0
003oooooooooo`05ooooo`00VOooool00ol0003oooooooooo`0@ooooo`Ko00003_ooool00ol0o`3o
ooooooooo`0Oooooo`03o`3o0?l0003o000000Oo00002oooool;o`000003ooooool0003o000000Co
00005_ooool7o`00013ooooo00?o0?l0ooooooooool01Oooool5o`0001kooooo2Ol0000Fooooo`?o
00000_ooool00ol0003oooooooooo`0:ooooo`Oo00002oooool6o`0001Gooooo00?o0000oooooooo
ool01Oooool009[ooooo00?o0000ooooooooool03oooool6o`0000kooooo00?o0?l0ooooooooool0
7_ooool00ol0003o0?l0o`000006o`0000kooooo2ol0000Looooo`Oo00004?ooool00ol0o`3ooooo
ooooo`05ooooo`Go00007oooool8o`0001?ooooo0ol00006ooooo`03o`000?oooooooooo00Wooooo
1ol0000<ooooo`Go00005_ooool00ol0003oooooooooo`04ooooo`00Voooool00ol0003ooooooooo
o`0?ooooo`Go00003Oooool00ol0o`3oooooooooo`0Oooooo`03o`000?l0o`3o000000Go00004_oo
ool:o`0001_ooooo1ol0000?ooooo`03o`3o0?oooooooooo00Gooooo1Ol0000Pooooo`So00003_oo
ool4o`0000[ooooo00?o0000ooooooooool02Oooool7o`0000_ooooo1_l0000Eooooo`03o`000?oo
oooooooo00Cooooo002Looooo`03o`000?oooooooooo00kooooo1_l0000<ooooo`03o`3o0?oooooo
oooo01kooooo0_l000000ol0o`3o0000o`000003o`0001Cooooo2_l0000Jooooo`Oo00003oooool0
0ol0o`3oooooooooo`04ooooo`Ko00008Oooool8o`0000[ooooo0ol0000?ooooo`03o`000?oooooo
oooo00Sooooo1ol0000;ooooo`Ko00005Oooool00ol0003oooooooooo`04ooooo`00WOooool00ol0
003oooooooooo`0=ooooo`Ko00003?ooool00ol0o`3oooooooooo`0Mooooo`So00005_ooool:o`00
01[ooooo1ol0000>ooooo`03o`3o0?oooooooooo00Cooooo1_l0000Rooooo`So00001_ooool3o`00
01?ooooo00?o0000ooooooooool02?ooool6o`0000_ooooo1_l0000Eooooo`03o`000?oooooooooo
00Cooooo002Nooooo`03o`000?oooooooooo00cooooo1_l0000<ooooo`03o`3o0?oooooooooo01co
oooo2?l0000Hooooo`[o00006Oooool7o`0000kooooo00?o0?l0ooooooooool01?ooool6o`0002;o
oooo2Ol000000ooooooo0000o`000002o`0001Kooooo00?o0000ooooooooool02?ooool7o`0000[o
oooo1_l0000Eooooo`03o`000?oooooooooo00Cooooo002Oooooo`03o`000?oooooooooo00_ooooo
1ol0000;ooooo`03o`3o0?oooooooooo01_ooooo2Ol0000Iooooo`[o00006Oooool6o`0000kooooo
00?o0?l0ooooooooool01?ooool6o`0002?ooooo2Ol0000Kooooo`03o`000?oooooooooo00Sooooo
1_l0000;ooooo`Go00005Oooool00ol0003oooooooooo`04ooooo`00X?ooool2o`0000cooooo1_l0
000;ooooo`03o`3o0?oooooooooo01[ooooo2Ol0000Looooo`Wo00006?ooool7o`0000gooooo00?o
0?l0ooooooooool01?ooool5o`0002Gooooo1ol0000Mooooo`03o`000?oooooooooo00Oooooo1ol0
000:ooooo`Ko00005?ooool00ol0003oooooooooo`04ooooo`00X_ooool00ol0003oooooooooo`09
ooooo`Ko00002oooool00ol0o`3oooooooooo`0Jooooo`So00007_ooool:o`0001Oooooo1_l0000=
ooooo`03o`3o0?oooooooooo00Cooooo1Ol0000Sooooo`Wo00007_ooool00ol0003oooooooooo`06
ooooo`Oo00002_ooool6o`0001Cooooo00?o0000ooooooooool01?ooool00:?ooooo00?o0000oooo
ooooool02?ooool7o`0000[ooooo00?o0?l0ooooooooool06Oooool8o`00023ooooo2_l0000Foooo
o`Ko00003Oooool00ol0o`3oooooooooo`04ooooo`Go00008?ooool3o`0000Cooooo1Ol0000Ooooo
o`03o`000?oooooooooo00Kooooo1ol00009ooooo`Ko00005?ooool00ol0003oooooooooo`04oooo
o`00Y?ooool00ol0003oooooooooo`08ooooo`Ko00002_ooool00ol0o`3oooooooooo`0Hooooo`So
00008_ooool:o`0001Gooooo1ol0000<ooooo`03o`3o0?oooooooooo00Cooooo1Ol0000Looooo`Co
0000;?ooool00ol0003oooooooooo`05ooooo`Oo00002Oooool7o`0001?ooooo00?o0000oooooooo
ool01?ooool00:Gooooo00?o0000ooooooooool01oooool6o`0000[ooooo00?o0?l0ooooooooool0
5oooool8o`0002Cooooo2_l0000Eooooo`Ko00003?ooool00ol0o`3oooooooooo`04ooooo`Go0000
6Oooool3o`00033ooooo00?o0000ooooooooool01_ooool7o`0000Wooooo1_l0000Cooooo`03o`00
0?oooooooooo00Cooooo002Vooooo`03o`000?oooooooooo00Kooooo1ol00009ooooo`03o`3o0?oo
oooooooo01Oooooo2?l0000Uooooo`[o00005?ooool7o`0000_ooooo00?o0?l0ooooooooool01?oo
ool5o`0001Kooooo0ol0000dooooo`03o`000?oooooooooo00Gooooo1ol00009ooooo`Ko00004ooo
ool00ol0003oooooooooo`04ooooo`00Yoooool00ol0003oooooooooo`06ooooo`Ko00002Oooool0
0ol0o`3oooooooooo`0Fooooo`So0000:?ooool8o`0001Cooooo1ol0000;ooooo`03o`3o0?oooooo
oooo00Cooooo1Ol0000Booooo`Co0000>?ooool00ol0003oooooooooo`05ooooo`Oo00002?ooool7
o`0001?ooooo00?o0000ooooooooool00oooool00:Sooooo00?o0000ooooooooool01Oooool7o`00
00Sooooo00?o0?l0ooooooooool05Oooool8o`0002[ooooo2?l0000Dooooo`Oo00002_ooool00ol0
o`3oooooooooo`04ooooo`Go00003oooool3o`0003gooooo00?o0000ooooooooool01?ooool7o`00
00Wooooo1_l0000Cooooo`03o`000?oooooooooo00?ooooo002Yooooo`03o`000?oooooooooo00Co
oooo1ol00008ooooo`03o`3o0?oooooooooo01Cooooo2?l0000/ooooo`Wo00004_ooool7o`0000[o
oooo00?o0?l0ooooooooool01?ooool5o`0000cooooo0ol00011ooooo`03o`000?oooooooooo00Co
oooo1ol00008ooooo`Ko00004oooool00ol0003oooooooooo`03ooooo`00Z_ooool00ol0003ooooo
ooooo`04ooooo`Oo00001oooool00ol0o`3oooooooooo`0Dooooo`So0000;Oooool9o`0001;ooooo
1ol00009ooooo`03o`3o0?oooooooooo00Cooooo1Ol00008ooooo`Co0000AOooool00ol0003ooooo
ooooo`03ooooo`Oo00002?ooool6o`0001?ooooo00?o0000ooooooooool00oooool00:_ooooo00?o
0000ooooooooool00oooool7o`0000Oooooo00?o0?l0ooooooooool04oooool8o`0002kooooo2_l0
000Aooooo`Oo00002Oooool00ol0o`3oooooooooo`04ooooo`Go00001Oooool3o`0004Wooooo00?o
0000ooooooooool01?ooool7o`0000Sooooo0_l000001?l0o`3o0000o`000?l0000Booooo`03o`00
0?oooooooooo00?ooooo002/ooooo`03o`000?oooooooooo00?ooooo1_l00007ooooo`03o`3o0?oo
oooooooo01;ooooo2?l0000`ooooo`[o00004Oooool6o`0000Wooooo00?o0?l0ooooooooool01?oo
ool5o`0000;ooooo0ol0001=ooooo`03o`000?oooooooooo00?ooooo1ol00008ooooo`;o000000Co
0?l0o`000?l0003o00004_ooool00ol0003oooooooooo`03ooooo`00[Oooool2o`0000?ooooo1ol0
0006ooooo`03o`3o0?oooooooooo017ooooo2?l0000booooo`[o00004?ooool7o`0000Sooooo00?o
0?l0ooooooooool01?ooool7o`00057ooooo00?o0000ooooooooool00oooool7o`0000Oooooo0_l0
00001?l0o`3o0000o`000?l0000Booooo`03o`000?oooooooooo00?ooooo002_ooooo`04o`000?oo
ooooooooooooo`Ko00001_ooool00ol0o`3oooooooooo`0Aooooo`So0000=?ooool9o`00013ooooo
1_l00008ooooo`03o`3o0?oooooooooo00Cooooo1Ol0001Dooooo`03o`000?oooooooooo00;ooooo
1ol00007ooooo`;o000000Co0?l0o`000?l0003o00004_ooool00ol0003oooooooooo`03ooooo`00
/?ooool00ol0003oooooooooo`07o`0000Gooooo00?o0?l0ooooooooool04?ooool8o`0003Kooooo
2Ol0000?ooooo`Ko00002?ooool01?l0o`3oooooooooooooool8o`0005Gooooo00?o0000oooooooo
ool00_ooool7o`0000Oooooo00?o0000o`3o0?l000000_l0000Booooo`03o`000?oooooooooo00?o
oooo002aooooo`03o`000?oooooo000000Ko00001Oooool00ol0o`3oooooooooo`0?ooooo`So0000
>?ooool8o`0000oooooo1ol00007ooooo`04o`3o0?l0003o0000o`0000?ooooo1Ol0001Fooooo`04
o`000?ooooooooooooooo`Oo00001oooool00ol0003o0?l0o`000003o`00017ooooo00?o0000oooo
ooooool00oooool00;;ooooo00?o0000ooooool000001Ol00005ooooo`03o`3o0?oooooooooo00ko
oooo2?l0000jooooo`So00003oooool7o`0000?ooooo0ol000000ol0o`3oooooooooo`03ooooo`Ko
0000E_ooool00ol0003oooooooooo`02ooooo`Oo00001_ooool00ol0003o0?l0o`000003o`00017o
oooo00?o0000ooooooooool00oooool00;?ooooo2?l00004ooooo`03o`3o0?oooooooooo00kooooo
2?l0000kooooo`Wo00003Oooool:o`0000?ooooo00?o0?l0ooooooooool00oooool6o`0005Oooooo
00Co0000oooooooooooooooo1ol00006ooooo`03o`000?l0o`3o000000?o00004Oooool00ol0003o
ooooooooo`03ooooo`00]?ooool7o`0000?ooooo00?o0?l0ooooooooool03_ooool8o`0003gooooo
2Ol0000<ooooo`So00001Oooool00ol0o`3oooooooooo`03ooooo`Ko0000F?ooool01?l0003ooooo
ooooooooool7o`0000Gooooo00?o0000o`3o0?l000000ol0000Booooo`03o`000?oooooooooo00;o
oooo002eooooo`Ko00000oooool00ol0o`3oooooooooo`0>ooooo`Oo0000?_ooool:o`0000_ooooo
2?l00005ooooo`03o`3o0?oooooooooo00?ooooo1_l0001Iooooo`03o`000?oooooooooo00Oo0000
1_ooool00ol0o`3o0000o`000002o`0001;ooooo00?o0000ooooooooool00_ooool00;Gooooo1ol0
0002ooooo`03o`3o0?oooooooooo00gooooo1ol00010ooooo`[o00001_ooool4o`0000;ooooo1ol0
0004ooooo`03o`3o0?oooooooooo00?ooooo1Ol0001Kooooo`03o`000?oooooooooo00Oo00001Ooo
ool00ol0o`3o0000o`000003o`00017ooooo00?o0000ooooooooool00_ooool00;Kooooo1ol00000
0ooooooo0?l0ooooo`0=ooooo`So0000@Oooool:o`0000;ooooo0ol00006ooooo`Oo00001?ooool0
0ol0o`3oooooooooo`03ooooo`Go0000G?ooool00ol0003oooooo`000006o`0000Gooooo00?o0?l0
o`000?l000000ol0000Aooooo`03o`000?oooooooooo00;ooooo002fooooo`So000000?o0?l0oooo
ooooool02oooool8o`0004Cooooo2_l0000:ooooo`Ko00001?ooool00ol0o`3oooooooooo`03oooo
o`Go0000G?ooool00ol0003oooooooooo`06o`0000Gooooo00?o0000o`3o0?l000000ol0000Aoooo
o`03o`000?oooooooooo00;ooooo002fooooo`Wo00003?ooool9o`0004Gooooo1ol0000<ooooo`Oo
00000oooool00ol0o`3oooooooooo`03ooooo`Go0000GOooool00ol0003oooooo`000006o`0000Co
oooo00?o0000o`3o0?l000000ol0000Aooooo`03o`000?oooooooooo00;ooooo002gooooo`Wo0000
2_ooool9o`0004Oooooo1_l0000=ooooo`Ko00000oooool00ol0o`3oooooooooo`03ooooo`Go0000
G_ooool00ol0003oooooo`000005o`0000Gooooo00?o0?l0o`000?l000000_l0000Aooooo`03o`00
0?oooooooooo00;ooooo002hooooo`[o00001oooool9o`0004Wooooo1Ol0000=ooooo`Oo00000_oo
ool00ol0o`3oooooooooo`02ooooo`Ko0000Goooool8o`0000Cooooo00?o0?l0o`000?l000000ol0
000@ooooo`03o`000?oooooooooo00;ooooo002iooooo`[o00001?ooool:o`0004cooooo00?o0000
ooooooooool03Oooool8o`000003ooooool0o`3ooooo00?ooooo1_l0001Pooooo`Oo00001?ooool0
0ol0o`3o0000o`000003o`00013ooooo00?o0000ooooooooool00_ooool00;[ooooo5_l0001=oooo
o`03o`000?oooooooooo00kooooo2?l000000ol0o`3oooooooooo`02ooooo`Ko0000HOooool7o`00
00?ooooo00?o0?l0o`000?l000000ol0000@ooooo`03o`000?oooooooooo00;ooooo002koooooaCo
0000C_ooool00ol0003oooooooooo`0>ooooo`So000000?o0?l0ooooooooool00_ooool6o`00067o
oooo2?l00002ooooo`03o`3o0?l0003o000000?o00004?ooool00ol0003oooooooooo`02ooooo`00
_?oooolBo`0004oooooo00?o0000ooooooooool03oooool8o`0000Cooooo1Ol0001Sooooo`Oo0000
0_ooool00ol0o`3o0000o`000003o`00017ooooo00?o0000ooooooooool00Oooool00;kooooo3ol0
001@ooooo`03o`000?oooooooooo013ooooo1ol00004ooooo`Go0000Hoooool8o`000003ooooool0
o`3o000000Go00004?ooool00ol0003oooooooooo`01ooooo`00_oooool<o`0005;ooooo00?o0000
ooooooooool04Oooool8o`000003ooooool0003o000000Co0000I?ooool7o`000003ooooool0o`3o
000000Go00004?ooool00ol0003oooooooooo`01ooooo`00`_ooool6o`0005Gooooo00?o0000oooo
ooooool04Oooool?o`0006Gooooo1ol000000ol0o`3o0000o`000004o`00013ooooo00?o0000oooo
ooooool00Oooool00<Cooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0Booooo`ko
0000IOooool>o`00013ooooo00?o0000ooooooooool00Oooool00<Gooooo00?o0000ooooooooool0
EOooool00ol0003oooooooooo`0Booooo`ko0000I_ooool7o`000003o`3o0?l0003o000000?o0000
4?ooool00ol0003oooooooooo`01ooooo`00a_ooool2o`0005Gooooo00?o0000ooooooooool04ooo
ool<o`0006Oooooo3Ol0000@ooooo`03o`000?oooooooooo007ooooo0038ooooo`03o`000?oooooo
oooo05;ooooo00?o0000ooooooooool05Oooool9o`0006Wooooo3?l0000@ooooo`03o`000?oooooo
oooo007ooooo0039ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool05_ooool7o`00
06_ooooo2ol0000@ooooo`03o`000?oooooooooo007ooooo003:ooooo`03o`000?oooooooooo053o
oooo00?o0000ooooooooool0R?ooool;o`00013ooooo00?o0000ooooooooool00Oooool00<_ooooo
00?o0000ooooooooool0Coooool00ol0003oooooooooo`29ooooo`[o00004?ooool00ol0003ooooo
ooooo`01ooooo`00c?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo08[ooooo2Ol0
000@ooooo`03o`000?oooooooooo007ooooo003=ooooo`03o`000?oooooooooo04gooooo00?o0000
ooooooooool0Roooool8o`00017ooooo0Ol00001ooooo`7ooooo003>ooooo`03o`000?oooooooooo
04cooooo00?o0000ooooooooool0S?ooool7o`00017ooooo0Ol00001ooooo`7ooooo003?ooooo`03
o`000?oooooooooo04_ooooo00?o0000ooooooooool0SOooool5o`0001;ooooo0Ol00001ooooo`7o
oooo003@ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0T?ooool00ol0003ooooo
ooooo`0Aooooo`7o00000Oooool1ooooo`00dOooool00ol0003oooooooooo`19ooooo`03o`000?oo
oooooooo097ooooo00?o0000ooooooooool04?ooool1o`00007ooooo0Oooool00=;ooooo0_l00019
ooooo`03o`000?oooooooooo09;ooooo00?o0000ooooooooool03oooool1o`00007ooooo0Oooool0
0=Cooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`2Booooo`03o`000?oooooooooo
00oooooo0Ol00001ooooo`7ooooo003Eooooo`03o`000?oooooooooo04Gooooo00?o0000oooooooo
ool0Toooool00ol0003oooooooooo`0>ooooo`7o00000Oooool1ooooo`00e_ooool00ol0003ooooo
ooooo`14ooooo`03o`000?oooooooooo09Cooooo00?o0000ooooooooool03Oooool1o`00007ooooo
0Oooool00=Oooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`2Eooooo`03o`000?oo
oooooooo00cooooo0Ol00001ooooo`7ooooo003Hooooo`03o`000?oooooooooo04;ooooo00?o0000
ooooooooool0U_ooool00ol0003oooooooooo`0;ooooo`7o00000Oooool1ooooo`00fOooool00ol0
003oooooooooo`11ooooo`03o`000?oooooooooo09Oooooo00?o0000ooooooooool02_ooool1o`00
007ooooo0Oooool00=[ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`2Gooooo`03
o`000?oooooooooo00_ooooo0Ol00001ooooo`00foooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo09Sooooo00?o0000ooooooooool02_ooool1o`00007ooooo003Looooo`03o`000?oo
oooooooo03kooooo00?o0000ooooooooool0VOooool00ol0003oooooooooo`09ooooo`7o00000Ooo
ool00=gooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`2Jooooo`03o`000?oooooo
oooo00Sooooo0Ol00001ooooo`00g_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo
09_ooooo00?o0000ooooooooool01oooool1o`00007ooooo003Oooooo`;o0000??ooool00ol0003o
ooooooooo`2Looooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`00hOooool00ol0003ooooo
ooooo`0iooooo`03o`000?oooooooooo09cooooo00?o0000ooooooooool01_ooool1o`00007ooooo
003Rooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0WOooool00ol0003ooooooooo
o`05ooooo`7o00000Oooool00>?ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`2N
ooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`00i?ooool00ol0003oooooooooo`0foooo
o`03o`000?oooooooooo09oooooo00?o0000ooooooooool00oooool1o`00007ooooo003Uooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool0X?ooool00ol0003oooooooooo`02ooooo`7o
00000Oooool00>Kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`2Qooooo`05o`00
0?ooooooooooooooool000000Oooool00>Oooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`2Qooooo`03o`000?oooooooooo00;ooooo0Ol000000>Sooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`2Rooooo`04o`000?ooooooooooooooo`7o0000003Yooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool0Xoooool00ol0003oooooooooo`01o`000000j_ooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo0:Cooooo0Ol00001ooooo`7o0000003[oooo
o`;o0000<?ooool00ol0003oooooooooo`2Uooooo`;o0000003]ooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool0Y?ooool3o`000000k_ooool00ol0003oooooooooo`0/ooooo`03o`00
0?oooooooooo0:3ooooo1?l00003ooooo`00koooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo09gooooo0ol00007ooooo`00l?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo09Wooooo1?l0000:ooooo`00lOooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
09Gooooo1?l0000>ooooo`00l_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo097o
oooo1?l0000Booooo`00loooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo08kooooo
0ol0000Fooooo`00m?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo08[ooooo1?l0
000Iooooo`00mOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo08Kooooo1?l0000M
ooooo`00m_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo08;ooooo1?l0000Qoooo
o`00moooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo07oooooo0ol0000Uooooo`00
n?ooool2o`0002?ooooo00?o0000ooooooooool0Noooool4o`0002Sooooo003jooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool0Moooool4o`0002cooooo003kooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool0Loooool4o`00033ooooo003looooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool0L?ooool3o`0003Cooooo003mooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool0K?ooool4o`0003Oooooo003nooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool0J?ooool4o`0003_ooooo003oooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool0I?ooool4o`0003oooooo003oooooo`7ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`1Qooooo`?o0000@oooool00?oooooo0_ooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo05gooooo1?l00016ooooo`00ooooool3ooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool0FOooool4o`0004[ooooo003oooooo`Cooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`1Eooooo`Co0000C_ooool00?oooooo1Oooool2o`0001Oooooo00?o
0000ooooooooool0DOooool4o`0005;ooooo003oooooo`Oooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`1>ooooo`?o0000E_ooool00?oooooo2?ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo04[ooooo1?l0001Iooooo`00ooooool9ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0A_ooool4o`0005gooooo003oooooo`[ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`12ooooo`Co0000HOooool00?oooooo2oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo03oooooo0ol0001Uooooo`00ooooool<ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0>oooool4o`0006Sooooo003oooooo`gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0gooooo`Co0000K?ooool00?oooooo3_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo03?ooooo1?l0001`ooooo`00ooooool?ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0<?ooool3o`0007Cooooo003ooooooa3ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0/ooooo`Co0000Moooool00?oooooo4Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Sooooo1?l0001kooooo`00oooooolBoooo
o`;o00002_ooool00ol0003oooooooooo`0Tooooo`Co0000Ooooool00?oooooo5?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo027ooooo0ol00023ooooo`00oooooolEooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool07Oooool4o`0008Kooooo003ooooooaKooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Iooooo`Co0000R_ooool00?oooooo5oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Gooooo1?l0002>ooooo`00oooooolHoooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04_ooool3o`0009;ooooo003ooooooaWo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`Co0000UOooool00?oooooo
6_ooool01Ol0003ooooooooooooooooo000000cooooo1?l0002Iooooo`00oooooolKooooo`04o`00
0?ooooooooooo`0000Sooooo1?l0002Mooooo`00oooooolLooooo`03o`000?oooooo000000Gooooo
0ol0002Qooooo`00oooooolMooooo`;o000000?oooooo`000?l000000_l0002Tooooo`00oooooolN
ooooo`;o0000Z?ooool00?oooooob?ooool00?oooooob?ooool00?oooooob?ooool00?oooooob?oo
ool00?oooooob?ooool00?oooooob?ooool00?oooooob?ooool00?oooooob?ooool00?oooooob?oo
ool00?oooooob?ooool00?oooooob?ooool00?oooooob?ooool00?oooooob?ooool00?oooooob?oo
ool00?oooooob?ooool00?oooooob?ooool00?oooooob?ooool00?oooooob?ooool00?oooooob?oo
ool00?oooooob?ooool00?oooooob?ooool00?oooooob?ooool00?oooooob?ooool00?oooooob?oo
ool00?oooooob?ooool00?oooooob?ooool00?oooooob?ooool00?oooooob?ooool00?oooooob?oo
ool00?oooooob?ooool00?oooooob?ooool00?oooooob?ooool00?oooooob?ooool00?oooooob?oo
ool00001\
\>"],
  ImageRangeCache->{{{0, 454.938}, {438.688, 0}} -> {-0.177573, -0.0819158, \
0.00303561, 0.00303561}}],

Cell[TextData[{
  "Fig. 7.4 Solution of Eq. ",
  ButtonBox["(7.1.30)",
    ButtonData:>{"Chapter7.nb", "(7.1.30)"},
    ButtonStyle->"Hyperlink"],
  "  at three times, along with five characteristics. "
}], "Caption",
  CellTags->"Fig. 7.4"],

Cell[TextData[{
  " \tIn principle, one could invert Eq. ",
  ButtonBox["(7.1.34)",
    ButtonData:>{"Chapter7.nb", "(7.1.34)"},
    ButtonStyle->"Hyperlink"],
  "  to obtain ",
  Cell[BoxData[
      \(TraditionalForm\`x\_o = \(x\_o\)(x, t)\)]],
  ". Then, using this solution in Eq. ",
  ButtonBox["(7.1.33)",
    ButtonData:>{"Chapter7.nb", "(7.1.33)"},
    ButtonStyle->"Hyperlink"],
  " , one would obtain the solution"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`f(x, t)\  = \ \(f\_o\)(\(x\_o\)(x, t))\)]],
  ". "
}], "UNNEQ"],

Cell[TextData[{
  "However, as the required inversion usually cannot be accomplished \
analytically, it is often easier to simply determine the solution for ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, t)\)]],
  " numerically using Eqs. ",
  ButtonBox["(7.1.33)",
    ButtonData:>{"Chapter7.nb", "(7.1.33)"},
    ButtonStyle->"Hyperlink"],
  "  and Eq. ",
  ButtonBox["(7.1.34)",
    ButtonData:>{"Chapter7.nb", "(7.1.34)"},
    ButtonStyle->"Hyperlink"],
  " . This can be done as follows. First, we choose  an initial condition:"
}], "Text"],

Cell[BoxData[
    \(\(f0[x_]\  = \ Exp[\(-x^2\)];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.23"],

Cell[TextData[{
  "Next, define a table of values taken from the initial condition, and call \
it ",
  StyleBox["fval[0]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(fval[0] = Table[{x0, f0[x0]}, {x0, \(-3\), 3,  .1}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.24"],

Cell[TextData[{
  "This table is a discrete representation of the continuous initial \
condition. It can be plotted using a ",
  StyleBox["ListPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", or an interpolation could be taken to reproduce ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_o\)(x)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tNext, we use Eqs. ",
  ButtonBox["(7.1.27)",
    ButtonData:>{"Chapter7.nb", "(7.1.27)"},
    ButtonStyle->"Hyperlink"],
  "  and ",
  ButtonBox["(7.1.28)",
    ButtonData:>{"Chapter7.nb", "(7.1.28)"},
    ButtonStyle->"Hyperlink"],
  "  to follow the evolution of each data point in the table. The positions \
of the points satisfy Eq. ",
  ButtonBox["(7.1.28)",
    ButtonData:>{"Chapter7.nb", "(7.1.28)"},
    ButtonStyle->"Hyperlink"],
  " , and the values of ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " remain fixed in time:"
}], "Text",
  CellTags->"i:87"],

Cell[BoxData[{
    \(\(x[t_, x0_] = \ x0\  + \ f0[x0]\ t;\)\), "\n", 
    \(\(\(f[t_, x0_]\  = \ f0[x0];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(fval[t_]\  := \ 
      Table[{x[t, x0], f[t, x0]}, {x0, \(-3\), 3,  .1}]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.25"],

Cell[TextData[{
  "The table ",
  StyleBox["fval[t]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " provides us with a discretized solution to the problem at all times ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ". In Cell ",
  ButtonBox["7.26",
    ButtonData:>"Cell 7.26",
    ButtonStyle->"Hyperlink"],
  " we plot this solution."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Table[
        ListPlot[fval[t], PlotJoined \[Rule] True, 
          PlotRange \[Rule] {{\(-3\), 4}, {0, 1}}, 
          PlotLabel -> "\<t=\>" <> ToString[t]], {t, 0, 
          2.4,  .2}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.26"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.428571 0.142857 0 0.618034 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.14286 -0.0125 -6 -9 ]
[.14286 -0.0125 6 0 ]
[.28571 -0.0125 -6 -9 ]
[.28571 -0.0125 6 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.41607 .12361 -18 -4.5 ]
[.41607 .12361 0 4.5 ]
[.41607 .24721 -18 -4.5 ]
[.41607 .24721 0 4.5 ]
[.41607 .37082 -18 -4.5 ]
[.41607 .37082 0 4.5 ]
[.41607 .49443 -18 -4.5 ]
[.41607 .49443 0 4.5 ]
[.41607 .61803 -6 -4.5 ]
[.41607 .61803 0 4.5 ]
[.5 .63053 -11 0 ]
[.5 .63053 11 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-3)] 0 -0.0125 0 1 Mshowa
.14286 0 m
.14286 .00625 L
s
[(-2)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(-1)] .28571 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(1)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(2)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(3)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.42857 .12361 m
.43482 .12361 L
s
[(0.2)] .41607 .12361 1 0 Mshowa
.42857 .24721 m
.43482 .24721 L
s
[(0.4)] .41607 .24721 1 0 Mshowa
.42857 .37082 m
.43482 .37082 L
s
[(0.6)] .41607 .37082 1 0 Mshowa
.42857 .49443 m
.43482 .49443 L
s
[(0.8)] .41607 .49443 1 0 Mshowa
.42857 .61803 m
.43482 .61803 L
s
[(1)] .41607 .61803 1 0 Mshowa
.125 Mabswid
.42857 .0309 m
.43232 .0309 L
s
.42857 .0618 m
.43232 .0618 L
s
.42857 .09271 m
.43232 .09271 L
s
.42857 .15451 m
.43232 .15451 L
s
.42857 .18541 m
.43232 .18541 L
s
.42857 .21631 m
.43232 .21631 L
s
.42857 .27812 m
.43232 .27812 L
s
.42857 .30902 m
.43232 .30902 L
s
.42857 .33992 m
.43232 .33992 L
s
.42857 .40172 m
.43232 .40172 L
s
.42857 .43262 m
.43232 .43262 L
s
.42857 .46353 m
.43232 .46353 L
s
.42857 .52533 m
.43232 .52533 L
s
.42857 .55623 m
.43232 .55623 L
s
.42857 .58713 m
.43232 .58713 L
s
.25 Mabswid
.42857 0 m
.42857 .61803 L
s
gsave
.5 .63053 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 8e-05 m
.01429 .00014 L
.02857 .00024 L
.04286 .00042 L
.05714 .00072 L
.07143 .00119 L
.08571 .00195 L
.1 .00312 L
.11429 .00489 L
.12857 .00751 L
.14286 .01132 L
.15714 .01672 L
.17143 .0242 L
.18571 .03435 L
.2 .04778 L
.21429 .06514 L
.22857 .08706 L
.24286 .11404 L
.25714 .14643 L
.27143 .1843 L
.28571 .22736 L
.3 .27494 L
.31429 .32588 L
.32857 .37862 L
.34286 .43119 L
.35714 .48133 L
.37143 .52665 L
.38571 .56484 L
.4 .5938 L
.41429 .61188 L
.42857 .61803 L
.44286 .61188 L
.45714 .5938 L
.47143 .56484 L
.48571 .52665 L
.5 .48133 L
.51429 .43119 L
.52857 .37862 L
.54286 .32588 L
.55714 .27494 L
.57143 .22736 L
.58571 .1843 L
.6 .14643 L
.61429 .11404 L
.62857 .08706 L
.64286 .06514 L
.65714 .04778 L
.67143 .03435 L
.68571 .0242 L
.7 .01672 L
Mistroke
.71429 .01132 L
.72857 .00751 L
.74286 .00489 L
.75714 .00312 L
.77143 .00195 L
.78571 .00119 L
.8 .00072 L
.81429 .00042 L
.82857 .00024 L
.84286 .00014 L
.85714 8e-05 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`007_ooool01OnHV9So410@o`000?lb<S;oc<c<02Oooooo1Ol0000Woooo
o`Co000000?o410@ooooooooool0C?ooool4o`000003oa0@4?oooooooooo02?ooooo1Ol0000Voooo
o`05oiRHV?l@413o0000oc8b<_o<c<`0:Oooool2o`000003oa0@4?oooooooooo01Oooooo000Noooo
o`05oa0@4?nj^[[oooooogMgMolb<S809oooool01OnHV9So8B4Qonk^k_ooooooA4A402Wooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
9_ooool01Ol@413o^[ZjoooooomgMgOo<S8b02[ooooo00?o0000ooooooooool06?ooool001Kooooo
1_l00006ooooo`03o`000?oooooooooo01gooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^01oooooo
1_l00005ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09_ooool00onHV9So8B4Q
onk^kP0[ooooo`03o`000?oooooooooo02Gooooo1Ol0000Iooooo`008Oooool00onYZJWo410@oooo
o`0Xooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Wooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?oZJVYoa0@4?ooool09_ooool01?m4A4CogMgMoooo
ool0000Jooooo`008?ooool00ol@413o0000okZj^P0Zooooo`03ogMgMomVIVKooooo02Sooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Xooooo`03ogMgMomVIVKooooo02Oooooo00?o
410@o`000?nj^[X09oooool01?oMgMgoEEEEooooool0000Jooooo`008Oooool00onj^[[o8B4Qoooo
o`0Zooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo02Oooooo00?o^[Zjob4Q8Oooool09oooool00omgMgOoc<c<o`00
000Jooooo`007_ooool01Ol@413oV9RHoooooonj^[[o000002Oooooo00Go0000okZj^_ooooooV9RH
oa0@400Yooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09Oooool01Ol0003o^[Zj
oooooonHV9So410@02Kooooo00Go410@oiRHV?oooooo^[Zjo`00000Xooooo`03onk^k_m4A4Co0000
01[ooooo000Nooooo`05ojVYZOl@413o0000oa0@4?nYZJT09oooool01OnHV9So410@o`000?lQ8B7o
c<c<02Oooooo00?oEEEEofIVI_l00000D?ooool00omEEEGoIVIVo`00000Wooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`09_ooool01OnYZJWo410@o`000?l@413oZJVY02Wooooo00?oMgMgo`000?ooool0
6Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool001goooooool0000bo`0001[ooooo000Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool01?l0003oooooooooooooool=o`000003ooooool0003ooooo00Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooool000003?l00002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06?oo
ool001gooooo00?o0000ooooooooool07oooool7o`0000?ooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`08o`00023ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0H
ooooo`00A_ooool3o`0005Kooooo00?o0000ooooooooool0EOooool2o`0006oooooo0019ooooo`?o
0000Doooool00ol0003oooooooooo`1Booooo`?o0000LOooool004cooooo0ol0001@ooooo`03o`00
0?oooooooooo04oooooo0ol0001dooooo`00Coooool00ol0003oooooooooo`1=ooooo`03o`000?oo
oooooooo04gooooo0_l0001gooooo`00D?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooo
oooo04cooooo00?o0000ooooooooool0Moooool0057ooooo0_l0001<ooooo`03o`000?oooooooooo
04[ooooo0_l0001jooooo`00Doooool2o`0004[ooooo00?o0000ooooooooool0BOooool00ol0003o
ooooooooo`1jooooo`00EOooool00ol0003oooooooooo`17ooooo`;o0000BOooool00ol0003ooooo
ooooo`1kooooo`00E_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo04Oooooo00?o
0000ooooooooool0O?ooool005Oooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`16
ooooo`03o`000?oooooooooo07gooooo001Hooooo`03o`000?oooooooooo04Cooooo00?o0000oooo
ooooool0AOooool00ol0003oooooooooo`1nooooo`00FOooool00ol0003oooooooooo`13ooooo`03
o`000?oooooooooo04Cooooo00?o0000ooooooooool0Ooooool005[ooooo00?o0000ooooooooool0
@_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo083ooooo001Jooooo`03o`000?oo
oooooooo04;ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`21ooooo`00Foooool0
0ol0003oooooooooo`11ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0P_ooool0
05cooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo
08?ooooo001Mooooo`03o`000?oooooooooo03oooooo0_l00010ooooo`03o`000?oooooooooo08Co
oooo001Nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`25ooooo`00G_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o
0000ooooooooool0QOooool005oooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0m
ooooo`03o`000?oooooooooo08Kooooo001Pooooo`03o`000?oooooooooo03cooooo00?o0000oooo
ooooool0?Oooool00ol0003oooooooooo`26ooooo`00HOooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo03cooooo00?o0000ooooooooool0Qoooool0067ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo08Sooooo001Rooooo`03o`000?oo
oooooooo03[ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`28ooooo`00Hoooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0ROooool0
06?ooooo00?o0000ooooooooool0>Oooool2o`0003_ooooo00?o0000ooooooooool0ROooool006Co
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo08[o
oooo001Tooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0>Oooool00ol0003ooooo
ooooo`2:ooooo`00IOooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo03Sooooo00?o
0000ooooooooool0Roooool006Gooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0h
ooooo`03o`000?oooooooooo08_ooooo001Vooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`2<ooooo`00I_ooool00ol0003oooooooooo`0fooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool0S?ooool006Oooooo00?o0000ooooooooool0
6_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo08gooooo001Wooooo`03o`000?oooooooooo01[ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A4
00Kooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`2=ooooo`00J?ooool00ol0003o
ooooooooo`0Iooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP07oooo
o`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0S_ooool006Sooooo00?o0000oooooooo
ool06Oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`00
03Gooooo00?o0000ooooooooool0S_ooool006Sooooo00?o0000ooooooooool06Oooool01Ol0003o
oooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo08oooooo001Yooooo`03o`000?oooooooooo01Sooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`2?ooooo`00JOooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`2@ooooo`00J_ooool00ol0003oooooooooo`0Gooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`2@ooooo`00J_ooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool0TOooool006[ooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo097ooooo001[ooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2Booooo`00Joooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0T_ooool006cooooo00?o
0000ooooooooool0<?ooool2o`00037ooooo00?o0000ooooooooool0Toooool006cooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo09?ooooo001]oooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`2Coooo
o`00KOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool0U?ooool006kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo09Cooooo001^ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`2Dooooo`00K_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool0UOooool006oooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo09Gooooo001_ooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`2Eooooo`00L?ooool00ol0003ooooo
ooooo`0/ooooo`;o0000;_ooool00ol0003oooooooooo`2Fooooo`00L?ooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0U_ooool0073ooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo09Kooooo001aoooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`2Goooo
o`00LOooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo02cooooo00?o0000oooooooo
ool0Uoooool0077ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0/ooooo`03o`00
0?oooooooooo09Oooooo001booooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0:ooo
ool00ol0003oooooooooo`2Hooooo`00L_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool0V?ooool007;ooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo09Sooooo001cooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`2Iooooo`00Loooool00ol0003ooooo
ooooo`0Yooooo`;o0000:oooool00ol0003oooooooooo`2Iooooo`00Loooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0VOooool007Cooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo09[ooooo001doooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`2Joooo
o`00M?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool0V_ooool007Cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo09_ooooo001eooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`2Kooooo`00MOooool00ol0003oooooooooo`0<ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool0Voooool007Gooooo00?o0000ooooooooool03?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`2Looooo`00MOooool00ol0003oooooooooo`0<
ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol0000Wooooo`03o`000?oo
oooooooo09cooooo001fooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00
000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`2Looooo`00M_ooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool00000
2oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool0WOooool007Kooooo00?o0000ooooooooool02oooool01Ol@413ooooooooooooooooo410@00co
oooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo09go
oooo001gooooo`03o`000?oooooooooo00[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
onk^k_m4A4Co000000Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`2Mooooo`00
Moooool00ol0003oooooooooo`0:ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo
0000ooooo`06ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0W_ooool007Oooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo09kooooo
001gooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`2Nooooo`00N?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool0Woooool007Sooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo09oooooo001hooooo`03o`000?oooooooooo02Cooooo0_l0000Uooooo`03
o`000?oooooooooo09oooooo001iooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`2Oooooo`00NOooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool0X?ooool007Wooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo0:3ooooo001jooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`2Pooooo`00N_ooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0X?ooool007[ooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo0:7ooooo
001kooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`2Qooooo`00Noooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool0XOooool007_ooooo00?o0000ooooooooool08Oooool2o`0002;ooooo00?o0000oooo
ooooool0X_ooool007cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo0:;ooooo001looooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`2Rooooo`00O?ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0X_ooool007gooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0:?ooooo001mooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`2Sooooo`00OOooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0Xoooool007gooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0:?ooooo
001nooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`2Tooooo`00O_ooool00ol0003oooooooooo`0Nooooo`;o00008?ooool00ol0003oooooooooo`2T
ooooo`00O_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool0Y?ooool007kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo0:Cooooo001oooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`2Uooooo`00Ooooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool0YOooool007oooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo0:Gooooo001oooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`2Uooooo`00P?ooool02Ol0003o
ooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`00
0?l@413oc<c<00Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`2Vooooo`00P?oo
ool02Ol0003oooooooooooooooooMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmE
EEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`2V
ooooo`00P?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool02Oooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`2Vooooo`00P?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0000Mooooo`03o`000?oooooooooo0:Kooooo
0021ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool02Oooool01Ol0003oEEEE
o`000?l@413oc<c<00Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`2Wooooo`00
POooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qooo
ool02?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo0:Oooooo0021ooooo`08o`00
0?ooooooooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`2Wooooo`00POooool02?l0003oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool0Yoooool008;ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo0:Sooooo0022ooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`2Xooooo`00P_ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0Z?ooool008;ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo0:Wooooo0023ooooo`03
o`000?oooooooooo01Wooooo0_l0000Kooooo`03o`000?oooooooooo0:Wooooo0023ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`2Yooooo`00Pooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Z_oo
ool008?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo0:[ooooo0024ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`2Zooooo`00Q?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool0Zoooool008Cooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo0:_ooooo0024ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`2[ooooo`00QOooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0[?ooool008Gooooo00?o0000oooo
ooooool05oooool2o`0001Sooooo00?o0000ooooooooool0[?ooool008Gooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0:cooooo0026ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`2/ooooo`00Q_oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0[Ooo
ool008Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo0:gooooo0027ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`2]ooooo`00Qoooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool0[Oooool008Oooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo0:kooooo0028ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`2^ooooo`00R?ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0[_ooool008Sooooo00?o0000oooo
ooooool05?ooool2o`0001Gooooo00?o0000ooooooooool0[oooool008Wooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0:oooooo0029ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2_ooooo`00ROoo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0[ooo
ool008[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo0;3ooooo002:ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`2`ooooo`00R_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool0/?ooool008Cooooo00Ook^k^oc8b<_l0003o<S8bonk^k_oooooo0000
00?ooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo0;3ooooo0024ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool0
0ol0003oooooooooo`02ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0/Oooool008Cooooo00Go410@oooooooooooooooooa0@
4002ooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000
4_ooool00ol0003oooooooooo`2aooooo`00Q?ooool01Ol0003ooooooooooooooooo000000;ooooo
00?o0000ooooooooool01_ooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`2aooooo`00Q?ooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool01Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`2booooo`00Q?ooool01Ol@413ooooooooooooooooo410@
00?ooooo00?o0000ooooooooool01Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`2booooo`00Q?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00?o0000ooooooooool01Oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`2booooo`00Q?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00?o0000ooooooooool01Oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`2booooo`00SOooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0/oooool008gooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0;?ooooo002=oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`2coooo
o`00S_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0]?ooool008kooooo00?o0000ooooooooool03_ooool2o`00013ooooo00?o0000ooooooooool0
]?ooool008kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo0;Cooooo002?ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`2eooooo`00Soooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0]Oooool008oooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo0;Gooooo002@ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`2fooooo`00T?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0]_ooool0093ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0;Oooooo002Aoooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`2goooo
o`00TOooool00ol0003oooooooooo`0;ooooo`;o00003?ooool00ol0003oooooooooo`2hooooo`00
TOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
^?ooool009;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo0;Sooooo002Booooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`2iooooo`00T_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0^Oooool009?ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo0;[ooooo002Dooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`2jooooo`00U?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0^oooool009Gooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0;_ooooo002Eoooo
o`03o`000?oooooooooo00Oooooo0_l00008ooooo`03o`000?oooooooooo0;cooooo002Fooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2looooo`00
Uoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
_Oooool009Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0;gooooo002Hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`2nooooo`00VOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0_oooool009Wooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo0;oooooo002Eooooo`Co000000?o410@o`000?ooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0<3ooooo002Gooooo`04o`000?oo
ooooooooooooo`;o00000_ooool01?l0003oooooooooooooool2o`000<?ooooo002Gooooo`03o`00
0?oooooooooo00?ooooo1_l00035ooooo`00Uoooool00ol0003oooooooooo`05ooooo`?o0000a_oo
ool009Oooooo00?o0000ooooooooool0c_ooool009Oooooo00?o0000ooooooooool0c_ooool009Oo
oooo00?o0000ooooooooool0c_ooool009Gooooo00?oEEEEofIVI_l00000d?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00:cooooo00GoV9RHo`000?l0003oA4A4okZj^P09oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h0ZOooool00:cooooo00Ko410@okZj^_o^k^koMgMgoa0@4?oo
ool6o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`2Yooooo`00[?ooool00ol0003ooooooooo
o`0;ooooo`05oa0@4?ooooooooooooooool@4100ZOooool00:cooooo00?o0000ooooooooool00ooo
ool6o`0000;ooooo00Go0000ooooooooooooooooo`00002Yooooo`00[?ooool00ol0003ooooooooo
o`0;ooooo`05o`000?ooooooooooooooool00000ZOooool00:[ooooo00?o410@o`000?l000000ol0
000:ooooo`05oa0@4?ooooooooooooooool@4100ZOooool00:cooooo00?o0000ooooooooool02ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg0:Wooooo002/ooooo`03o`000?oooooooooo00_ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP2Yooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.68406, -0.0802184, \
0.0288357, 0.00666531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.428571 0.142857 0 0.618034 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.14286 -0.0125 -6 -9 ]
[.14286 -0.0125 6 0 ]
[.28571 -0.0125 -6 -9 ]
[.28571 -0.0125 6 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.41607 .12361 -18 -4.5 ]
[.41607 .12361 0 4.5 ]
[.41607 .24721 -18 -4.5 ]
[.41607 .24721 0 4.5 ]
[.41607 .37082 -18 -4.5 ]
[.41607 .37082 0 4.5 ]
[.41607 .49443 -18 -4.5 ]
[.41607 .49443 0 4.5 ]
[.41607 .61803 -6 -4.5 ]
[.41607 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-3)] 0 -0.0125 0 1 Mshowa
.14286 0 m
.14286 .00625 L
s
[(-2)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(-1)] .28571 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(1)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(2)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(3)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.42857 .12361 m
.43482 .12361 L
s
[(0.2)] .41607 .12361 1 0 Mshowa
.42857 .24721 m
.43482 .24721 L
s
[(0.4)] .41607 .24721 1 0 Mshowa
.42857 .37082 m
.43482 .37082 L
s
[(0.6)] .41607 .37082 1 0 Mshowa
.42857 .49443 m
.43482 .49443 L
s
[(0.8)] .41607 .49443 1 0 Mshowa
.42857 .61803 m
.43482 .61803 L
s
[(1)] .41607 .61803 1 0 Mshowa
.125 Mabswid
.42857 .0309 m
.43232 .0309 L
s
.42857 .0618 m
.43232 .0618 L
s
.42857 .09271 m
.43232 .09271 L
s
.42857 .15451 m
.43232 .15451 L
s
.42857 .18541 m
.43232 .18541 L
s
.42857 .21631 m
.43232 .21631 L
s
.42857 .27812 m
.43232 .27812 L
s
.42857 .30902 m
.43232 .30902 L
s
.42857 .33992 m
.43232 .33992 L
s
.42857 .40172 m
.43232 .40172 L
s
.42857 .43262 m
.43232 .43262 L
s
.42857 .46353 m
.43232 .46353 L
s
.42857 .52533 m
.43232 .52533 L
s
.42857 .55623 m
.43232 .55623 L
s
.42857 .58713 m
.43232 .58713 L
s
.25 Mabswid
.42857 0 m
.42857 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 8e-05 m
.01429 .00014 L
.02858 .00024 L
.04288 .00042 L
.05718 .00072 L
.07148 .00119 L
.0858 .00195 L
.10014 .00312 L
.11451 .00489 L
.12892 .00751 L
.14338 .01132 L
.15792 .01672 L
.17255 .0242 L
.1873 .03435 L
.20221 .04778 L
.2173 .06514 L
.2326 .08706 L
.24813 .11404 L
.26391 .14643 L
.27995 .1843 L
.29623 .22736 L
.31271 .27494 L
.32935 .32588 L
.34608 .37862 L
.36279 .43119 L
.37939 .48133 L
.39578 .52665 L
.41183 .56484 L
.42745 .5938 L
.44257 .61188 L
.45714 .61803 L
.47114 .61188 L
.48459 .5938 L
.49754 .56484 L
.51006 .52665 L
.52225 .48133 L
.53422 .43119 L
.54608 .37862 L
.55792 .32588 L
.56985 .27494 L
.58194 .22736 L
.59423 .1843 L
.60677 .14643 L
.61956 .11404 L
.6326 .08706 L
.64587 .06514 L
.65935 .04778 L
.67302 .03435 L
.68683 .0242 L
.70077 .01672 L
Mistroke
.71481 .01132 L
.72892 .00751 L
.74308 .00489 L
.75729 .00312 L
.77152 .00195 L
.78577 .00119 L
.80003 .00072 L
.81431 .00042 L
.82858 .00024 L
.84286 .00014 L
.85715 8e-05 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`007_ooool01OnHV9So410@o`000?lb<S;oc<c<02Oooooo1Ol0000Woooo
o`Co000000?o410@ooooooooool0C?ooool4o`000003oa0@4?oooooooooo02?ooooo1Ol0000Voooo
o`05oiRHV?l@413o0000oc8b<_o<c<`0:Oooool2o`000003oa0@4?oooooooooo01Oooooo000Noooo
o`05oa0@4?nj^[[oooooogMgMolb<S809oooool01OnHV9So8B4Qonk^k_ooooooA4A402Wooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
9_ooool01Ol@413o^[ZjoooooomgMgOo<S8b02[ooooo00?o0000ooooooooool06?ooool001Kooooo
1_l00006ooooo`03o`000?oooooooooo01gooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^01oooooo
1_l00005ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09_ooool00onHV9So8B4Q
onk^kP0[ooooo`03o`000?oooooooooo02Gooooo1Ol0000Iooooo`008Oooool00onYZJWo410@oooo
o`0Xooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Wooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?oZJVYoa0@4?ooool09_ooool01?m4A4CogMgMoooo
ool0000Jooooo`008?ooool00ol@413o0000okZj^P0Zooooo`03ogMgMomVIVKooooo02Sooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Xooooo`03ogMgMomVIVKooooo02Oooooo00?o
410@o`000?nj^[X09oooool01?oMgMgoEEEEooooool0000Jooooo`008Oooool00onj^[[o8B4Qoooo
o`0Zooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo02Oooooo00?o^[Zjob4Q8Oooool09oooool00omgMgOoc<c<o`00
000Jooooo`007_ooool01Ol@413oV9RHoooooonj^[[o000002Oooooo00Go0000okZj^_ooooooV9RH
oa0@400Yooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09Oooool01Ol0003o^[Zj
oooooonHV9So410@02Kooooo00Go410@oiRHV?oooooo^[Zjo`00000Xooooo`03onk^k_m4A4Co0000
01[ooooo000Nooooo`05ojVYZOl@413o0000oa0@4?nYZJT09oooool01OnHV9So410@o`000?lQ8B7o
c<c<02Oooooo00?oEEEEofIVI_l00000D?ooool00omEEEGoIVIVo`00000Wooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`09_ooool01OnYZJWo410@o`000?l@413oZJVY02Wooooo00?oMgMgo`000?ooool0
6Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool001goooooool0000bo`0001[ooooo000Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool01?l0003oooooooooooooool=o`000003ooooool0003ooooo00Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooool000003?l00002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06?oo
ool001gooooo00?o0000ooooooooool07oooool7o`0000?ooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`08o`00023ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0H
ooooo`00A_ooool3o`0005Kooooo00?o0000ooooooooool0EOooool2o`0006oooooo0019ooooo`?o
0000Doooool00ol0003oooooooooo`1Booooo`?o0000LOooool004cooooo0ol0001@ooooo`03o`00
0?oooooooooo04oooooo0ol0001dooooo`00Coooool2o`0004kooooo00?o0000ooooooooool0C_oo
ool00ol0003oooooooooo`1eooooo`00DOooool00ol0003oooooooooo`1;ooooo`03o`000?oooooo
oooo04gooooo00?o0000ooooooooool0M_ooool005;ooooo0_l0001;ooooo`03o`000?oooooooooo
04_ooooo0_l0001iooooo`00E?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo04Wo
oooo0_l0001kooooo`00EOooool00ol0003oooooooooo`17ooooo`;o0000BOooool00ol0003ooooo
ooooo`1kooooo`00E_ooool2o`0004Oooooo00?o0000ooooooooool0Aoooool00ol0003ooooooooo
o`1looooo`00F?ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo04Kooooo00?o0000
ooooooooool0OOooool005Wooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`15oooo
o`03o`000?oooooooooo07kooooo001Jooooo`03o`000?oooooooooo04;ooooo00?o0000oooooooo
ool0A?ooool00ol0003oooooooooo`1oooooo`00Foooool00ol0003oooooooooo`11ooooo`03o`00
0?oooooooooo04?ooooo00?o0000ooooooooool0P?ooool005_ooooo00?o0000ooooooooool0@Ooo
ool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo083ooooo001Looooo`03o`000?oooooo
oooo043ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`21ooooo`00GOooool00ol0
003oooooooooo`0oooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0P_ooool005ko
oooo00?o0000ooooooooool0?_ooool2o`00047ooooo00?o0000ooooooooool0Poooool005oooooo
00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo08Cooooo
001Oooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?oooool00ol0003ooooooooo
o`24ooooo`00H?ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo03kooooo00?o0000
ooooooooool0QOooool0067ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo08Gooooo001Rooooo`03o`000?oooooooooo03[ooooo00?o0000oooooooo
ool0?Oooool00ol0003oooooooooo`26ooooo`00H_ooool00ol0003oooooooooo`0jooooo`03o`00
0?oooooooooo03cooooo00?o0000ooooooooool0Qoooool006?ooooo00?o0000ooooooooool0>Ooo
ool00ol0003oooooooooo`0looooo`03o`000?oooooooooo08Oooooo001Tooooo`03o`000?oooooo
oooo03Sooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`28ooooo`00I?ooool00ol0
003oooooooooo`0hooooo`;o0000??ooool00ol0003oooooooooo`28ooooo`00IOooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0ROooool006Gooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo08Wooooo
001Vooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0>Oooool00ol0003ooooooooo
o`2:ooooo`00I_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo03Wooooo00?o0000
ooooooooool0R_ooool006Oooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo08_ooooo001Wooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`2;ooooo`00J?ooool00ol0003oooooooooo`0Iooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool0S?ooool006Sooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0
003oooooooooo`0gooooo`03o`000?oooooooooo08cooooo001Yooooo`03o`000?oooooooooo01So
oooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`2=ooooo`00JOooool00ol0003oooooooooo`0Hooooo`05
o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`?o0000=_ooool00ol0
003oooooooooo`2=ooooo`00J_ooool00ol0003oooooooooo`0Gooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool0SOooool006[ooooo00?o0000ooooooooool05oooool01Ol@413ooooooooooooooooo410@
00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
08kooooo001[ooooo`03o`000?oooooooooo01Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo08kooooo001[ooooo`03o`000?oooooooooo01Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo08oooooo001/ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`2?ooooo`00K?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
03Cooooo00?o0000ooooooooool0Soooool006gooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo093ooooo001]ooooo`03o`000?oooooooooo02oooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`2@ooooo`00K_ooool00ol0003ooooooooo
o`0^ooooo`;o0000<oooool00ol0003oooooooooo`2Aooooo`00K_ooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0TOooool006oooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo097ooooo001_ooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2Booooo`00
L?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
T_ooool0073ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo09;ooooo001`ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`2Cooooo`00LOooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool0Toooool0077ooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo09?ooooo001booooo`03o`000?oooooooooo02[ooooo
0_l0000`ooooo`03o`000?oooooooooo09Cooooo001booooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`2Dooooo`00Loooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0U?ooool007?ooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo09Gooooo001cooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`2Eooooo`00
M?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
UOooool007Cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo09Gooooo001eooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`2Fooooo`00MOooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool0U_ooool007Gooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo09Kooooo001fooooo`03o`000?oooooooooo02Kooooo
0_l0000^ooooo`03o`000?oooooooooo09Kooooo001fooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`2Fooooo`00M_ooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0Uoooool007Oooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo09Oooooo001gooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`2Gooooo`00
N?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
Uoooool007Sooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo09Sooooo001hooooo`03o`000?oooooooooo00Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0:ooo
ool00ol0003oooooooooo`2Hooooo`00NOooool00ol0003oooooooooo`08ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0[ooooo`03o`000?oooooooooo09Sooooo001iooooo`03o`000?oooooooooo00Sooooo00Go410@
oooooooooooooooooa0@400;ooooo`Go00001_ooool3o`0002_ooooo00?o0000ooooooooool0V?oo
ool007Wooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00001oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo09Wooooo
001jooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgM
gOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`2Iooooo`00
N_ooool00ol0003oooooooooo`07ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOo
c<c<o`000007ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0VOooool007[ooooo
00?o0000ooooooooool01oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l0
00001oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo09[ooooo001kooooo`03o`00
0?oooooooooo00Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Ko
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`2Jooooo`00Noooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0V_ooool007_ooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo09[ooooo001l
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`2K
ooooo`00O?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool0Voooool007cooooo00?o0000ooooooooool08?ooool2o`0002Wooooo00?o0000oooooooo
ool0Voooool007gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo09_ooooo001mooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`2Looooo`00OOooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool0W?ooool007kooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo09cooooo001nooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`2Looooo`00O_ooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0WOooool007oooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo09gooooo001o
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`2M
ooooo`00Ooooool00ol0003oooooooooo`0Mooooo`;o00009_ooool00ol0003oooooooooo`2Noooo
o`00P?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0W_ooool0083ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo09kooooo0020ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`2Nooooo`00POooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0Woooool0087ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo09oooooo0021ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`2Oooooo`00POooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0Woooool008;ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo09oooooo0022
ooooo`03o`000?oooooooooo01[ooooo0_l0000Tooooo`03o`000?oooooooooo0:3ooooo0022oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`2Poooo
o`00Poooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool0X?ooool008?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo0:3ooooo0023ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`2Pooooo`00Q?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool0XOooool008Cooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo0:7ooooo0024ooooo`05o`000?lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool0XOooool008Cooooo00GoMgMgo`000?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool08_oo
ool00ol0003oooooooooo`2Qooooo`00Q?ooool01Ol@413o0000oooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
XOooool008Cooooo0_l00002ooooo`03o`000?oooooooooo00Wooooo00Go0000oiRHV?ooooooV9RH
ob4Q8@06ooooo`?o00008Oooool00ol0003oooooooooo`2Rooooo`00Q?ooool01Ol0003oooooo`00
0?oooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool0X_ooool008Cooooo00Go410@ooooool0003ooooooa0@400;ooooo`03
oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`2Rooooo`00
Q?ooool01OmgMgOoV9RHo`000?nHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo0:;ooooo0024ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool0X_ooool008Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo0:?ooooo0027ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`2Sooooo`00Qoooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool0Xoooool008Sooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0:?ooooo0028ooooo`03o`000?oooooooooo
01Cooooo0_l0000Pooooo`03o`000?oooooooooo0:Cooooo0028ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`2Tooooo`00ROooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0Y?ooool008Wooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo0:Cooooo0029
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`2U
ooooo`00R_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool0YOooool008[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo0:Gooooo002:ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`2Uooooo`00Roooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool0Y_ooool008_ooooo00?o0000ooooooooool04Oooool2
o`0001kooooo00?o0000ooooooooool0Y_ooool008_ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo0:Kooooo002<ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`2Vooooo`00S?ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0Yoooool008cooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo0:Oooooo002=
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`2W
ooooo`00SOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool0Yoooool008gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo0:Oooooo002>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`2Xooooo`00S_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool0Z?ooool008kooooo00?o0000ooooooooool03_ooool2
o`0001cooooo00?o0000ooooooooool0Z?ooool008oooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo0:Sooooo002?ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`2Xooooo`00Soooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0ZOooool0093ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo0:Wooooo002@
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`2Y
ooooo`00T?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool0ZOooool008Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q00Woooooo`00
0?ooooooooooolc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo0:Wooooo0024ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@09oooo
ool0003ooooooooooolQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`2Zooooo`00Q?ooool01Ol@413ooooooooooooooooo410@00Sooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`04ooooo`?o00006Oooool00ol0003ooooooooo
o`2Zooooo`00Q?ooool01Ol0003ooooooooooooooooo000000Wooooo00Oo0000oooooolb<S;oV9RH
oooooonHV9So<S8b00Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`2Zooooo`00
Q?ooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooo<c<`00ol000000oo<c<co
ooooooooo`04ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0Zoooool008Cooooo
00Go410@oooooooooooooooooa0@4009ooooo`07o`000?oooooo410@okZj^_oooooo^[Zjoa0@4006
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0Zoooool008Cooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0:ooooo`;o000000Co^[Zjoooooonj^[[o00001_ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo0:_ooooo0024ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02_oo
ool01_l0003oZJVYoa0@4?l0003o410@ojVYZ@Kooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`2[ooooo`00Toooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0[?ooool009Cooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo0:cooooo002Dooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`2/ooooo`00U?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0[Oooool009Gooooo00?o0000oooooooo
ool01oooool2o`0001Oooooo00?o0000ooooooooool0[Oooool009Gooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo0:gooooo002Fooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`2^ooooo`00U_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0[_ooool0
09Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
0:kooooo002Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`2_ooooo`00Uoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0[oooool009Sooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo0:oooooo002Hooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`2`ooooo`00VOooool00ol0003oooooooooo`03oooo
o`;o00005?ooool00ol0003oooooooooo`2`ooooo`00VOooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool0/?ooool009Wooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0;7ooooo002Jooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`2aooooo`00V_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0/Oooool0
09_ooooo00Go0000ooooooooooooooooo`00000Cooooo`03o`000?oooooooooo0;;ooooo002Loooo
o`04o`000?ooooooooooo`0001?ooooo00?o0000ooooooooool0/_ooool009cooooo00Co0000oooo
oooooooo00004_ooool00ol0003oooooooooo`2cooooo`00WOooool00ol0003oooooo`00000Boooo
o`03o`000?oooooooooo0;?ooooo002Mooooo`04o`000?oooooo0000o`00013ooooo00?o0000oooo
ooooool0]?ooool009kooooo0_l0000Aooooo`03o`000?oooooooooo0;Cooooo002Oooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0]Oooool009oooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`2eooooo`00Woooool2o`0000kooooo00?o0000ooooooooool0]_ooool0
09oooooo00?o0000ooooool000003?ooool00ol0003oooooooooo`2gooooo`00Woooool00ol0003o
ooooo`00000<ooooo`03o`000?oooooooooo0;Oooooo002Eooooo`Co000000?o410@ooooooooool0
0oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo0;Sooooo002Gooooo`03o`00
0?oooooooooo00Gooooo00Co0000oooooooooooooooo0_l00006ooooo`;o0000^oooool009Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`?o000000?oooooo`000?l00000
_Oooool009Oooooo00?o0000ooooooooool01Oooool3o`0000Kooooo00?o0000ooooooooool0_Ooo
ool009Oooooo00?o0000ooooooooool0c_ooool009Oooooo00?o0000ooooooooool0c_ooool009Oo
oooo00?o0000ooooooooool0c_ooool009Gooooo00?oEEEEofIVI_l00000d?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00:Cooooo00GoV9RHo`000?l0003oA4A4okZj^P09oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0002Qooooo`00Y?ooool01Ol@
413o^[Zjonk^k_mgMgOo410@00;ooooo1_l000001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0XOooool00:Cooooo00?o0000ooooooooool0
2oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0X_ooool00:Cooooo
00?o0000ooooooooool01?ooool6o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
2oooool00onHV9So8B4Qonk^kP2Qooooo`00Y?ooool00ol0003oooooooooo`0;ooooo`05o`000?oo
ooooooooooooool000003_ooool00omgMgOoIVIVooooo`2Pooooo`00X_ooool00ol@413o0000o`00
0003o`0000[ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo09oooooo
002Tooooo`03o`000?oooooooooo00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@4100XOooool00:Cooooo00?o0000ooooooooool02oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c02Qooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.68406, -0.0802184, \
0.0288357, 0.00666531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.428571 0.142857 0 0.618034 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.14286 -0.0125 -6 -9 ]
[.14286 -0.0125 6 0 ]
[.28571 -0.0125 -6 -9 ]
[.28571 -0.0125 6 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.41607 .12361 -18 -4.5 ]
[.41607 .12361 0 4.5 ]
[.41607 .24721 -18 -4.5 ]
[.41607 .24721 0 4.5 ]
[.41607 .37082 -18 -4.5 ]
[.41607 .37082 0 4.5 ]
[.41607 .49443 -18 -4.5 ]
[.41607 .49443 0 4.5 ]
[.41607 .61803 -6 -4.5 ]
[.41607 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-3)] 0 -0.0125 0 1 Mshowa
.14286 0 m
.14286 .00625 L
s
[(-2)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(-1)] .28571 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(1)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(2)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(3)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.42857 .12361 m
.43482 .12361 L
s
[(0.2)] .41607 .12361 1 0 Mshowa
.42857 .24721 m
.43482 .24721 L
s
[(0.4)] .41607 .24721 1 0 Mshowa
.42857 .37082 m
.43482 .37082 L
s
[(0.6)] .41607 .37082 1 0 Mshowa
.42857 .49443 m
.43482 .49443 L
s
[(0.8)] .41607 .49443 1 0 Mshowa
.42857 .61803 m
.43482 .61803 L
s
[(1)] .41607 .61803 1 0 Mshowa
.125 Mabswid
.42857 .0309 m
.43232 .0309 L
s
.42857 .0618 m
.43232 .0618 L
s
.42857 .09271 m
.43232 .09271 L
s
.42857 .15451 m
.43232 .15451 L
s
.42857 .18541 m
.43232 .18541 L
s
.42857 .21631 m
.43232 .21631 L
s
.42857 .27812 m
.43232 .27812 L
s
.42857 .30902 m
.43232 .30902 L
s
.42857 .33992 m
.43232 .33992 L
s
.42857 .40172 m
.43232 .40172 L
s
.42857 .43262 m
.43232 .43262 L
s
.42857 .46353 m
.43232 .46353 L
s
.42857 .52533 m
.43232 .52533 L
s
.42857 .55623 m
.43232 .55623 L
s
.42857 .58713 m
.43232 .58713 L
s
.25 Mabswid
.42857 0 m
.42857 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
1e-05 8e-05 m
.0143 .00014 L
.02859 .00024 L
.0429 .00042 L
.05721 .00072 L
.07154 .00119 L
.08589 .00195 L
.10029 .00312 L
.11474 .00489 L
.12927 .00751 L
.1439 .01132 L
.15869 .01672 L
.17367 .0242 L
.18889 .03435 L
.20442 .04778 L
.22031 .06514 L
.23662 .08706 L
.2534 .11404 L
.27068 .14643 L
.28847 .1843 L
.30674 .22736 L
.32542 .27494 L
.34442 .32588 L
.36358 .37862 L
.38272 .43119 L
.40165 .48133 L
.42012 .52665 L
.43794 .56484 L
.4549 .5938 L
.47086 .61188 L
.48571 .61803 L
.49943 .61188 L
.51205 .5938 L
.52365 .56484 L
.53441 .52665 L
.5445 .48133 L
.55415 .43119 L
.56358 .37862 L
.57299 .32588 L
.58256 .27494 L
.59245 .22736 L
.60275 .1843 L
.61354 .14643 L
.62483 .11404 L
.63662 .08706 L
.64888 .06514 L
.66156 .04778 L
.6746 .03435 L
.68795 .0242 L
.70155 .01672 L
Mistroke
.71533 .01132 L
.72927 .00751 L
.74331 .00489 L
.75743 .00312 L
.77161 .00195 L
.78582 .00119 L
.80007 .00072 L
.81432 .00042 L
.82859 .00024 L
.84287 .00014 L
.85715 8e-05 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`007_ooool01OnHV9So410@o`000?lb<S;oc<c<02Oooooo1Ol0000Woooo
o`Co000000?o410@ooooooooool0C?ooool4o`000003oa0@4?oooooooooo02?ooooo1Ol0000Voooo
o`05oiRHV?l@413o0000oc8b<_o<c<`0:Oooool2o`000003oa0@4?oooooooooo01Oooooo000Noooo
o`05oa0@4?nj^[[oooooogMgMolb<S809oooool01OnHV9So8B4Qonk^k_ooooooA4A402Wooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
9_ooool01Ol@413o^[ZjoooooomgMgOo<S8b02[ooooo00?o0000ooooooooool06?ooool001Kooooo
1_l00006ooooo`03o`000?oooooooooo01gooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^01oooooo
1_l00005ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09_ooool00onHV9So8B4Q
onk^kP0[ooooo`03o`000?oooooooooo02Gooooo1Ol0000Iooooo`008Oooool00onYZJWo410@oooo
o`0Xooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Wooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?oZJVYoa0@4?ooool09_ooool01?m4A4CogMgMoooo
ool0000Jooooo`008?ooool00ol@413o0000okZj^P0Zooooo`03ogMgMomVIVKooooo02Sooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Xooooo`03ogMgMomVIVKooooo02Oooooo00?o
410@o`000?nj^[X09oooool01?oMgMgoEEEEooooool0000Jooooo`008Oooool00onj^[[o8B4Qoooo
o`0Zooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo02Oooooo00?o^[Zjob4Q8Oooool09oooool00omgMgOoc<c<o`00
000Jooooo`007_ooool01Ol@413oV9RHoooooonj^[[o000002Oooooo00Go0000okZj^_ooooooV9RH
oa0@400Yooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09Oooool01Ol0003o^[Zj
oooooonHV9So410@02Kooooo00Go410@oiRHV?oooooo^[Zjo`00000Xooooo`03onk^k_m4A4Co0000
01[ooooo000Nooooo`05ojVYZOl@413o0000oa0@4?nYZJT09oooool01OnHV9So410@o`000?lQ8B7o
c<c<02Oooooo00?oEEEEofIVI_l00000D?ooool00omEEEGoIVIVo`00000Wooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`09_ooool01OnYZJWo410@o`000?l@413oZJVY02Wooooo00?oMgMgo`000?ooool0
6Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool001goooooool0000bo`0001[ooooo000Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool01?l0003oooooooooooooool=o`000003ooooool0003ooooo00Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooool000003?l00002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06?oo
ool001gooooo00?o0000ooooooooool07oooool7o`0000?ooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`08o`00023ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0H
ooooo`00A_ooool3o`0005Kooooo00?o0000ooooooooool0EOooool2o`0006oooooo0019ooooo`?o
0000Doooool00ol0003oooooooooo`1Booooo`?o0000LOooool004cooooo0ol0001@ooooo`03o`00
0?oooooooooo04oooooo0ol0001dooooo`00Coooool2o`0004kooooo00?o0000ooooooooool0C_oo
ool00ol0003oooooooooo`1eooooo`00DOooool00ol0003oooooooooo`1;ooooo`03o`000?oooooo
oooo04gooooo00?o0000ooooooooool0M_ooool005;ooooo0_l0001;ooooo`03o`000?oooooooooo
04_ooooo0_l0001iooooo`00E?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo04[o
oooo00?o0000ooooooooool0NOooool005Gooooo00?o0000ooooooooool0Aoooool2o`0004[ooooo
00?o0000ooooooooool0N_ooool005Kooooo0_l00017ooooo`03o`000?oooooooooo04Sooooo00?o
0000ooooooooool0Noooool005Sooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`17
ooooo`03o`000?oooooooooo07cooooo001Iooooo`03o`000?oooooooooo04?ooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`1mooooo`00F_ooool00ol0003oooooooooo`12ooooo`03
o`000?oooooooooo04Gooooo00?o0000ooooooooool0O_ooool005_ooooo00?o0000ooooooooool0
@Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo07oooooo001Looooo`03o`000?oo
oooooooo043ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`1oooooo`00GOooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0P?ooool0
05kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo
087ooooo001Oooooo`03o`000?oooooooooo03gooooo0_l00012ooooo`03o`000?oooooooooo08;o
oooo001Pooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0@?ooool00ol0003ooooo
ooooo`23ooooo`00H?ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo043ooooo00?o
0000ooooooooool0Poooool0067ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo08Cooooo001Rooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`24ooooo`00Hoooool00ol0003oooooooooo`0iooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool0QOooool006?ooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo08Kooooo001Tooooo`03o`000?oo
oooooooo03Sooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`26ooooo`00IOooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0Qoooool0
06Gooooo00?o0000ooooooooool0=oooool2o`0003gooooo00?o0000ooooooooool0Qoooool006Ko
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo08So
oooo001Wooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`28ooooo`00Ioooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0R?ooool006Sooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo08Wooooo001Xooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`29ooooo`00JOooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo03[ooooo00?o0000ooooooooool0ROooool006[ooooo00?o0000ooooooooool0
5oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo08[ooooo001Zooooo`03o`000?oooooooooo01Oooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A4
00Kooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`2:ooooo`00Joooool00ol0003o
ooooooooo`0Fooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP07oooo
o`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0Roooool006_ooooo00?o0000oooooooo
ool05_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`00
03Sooooo00?o0000ooooooooool0Roooool006cooooo00?o0000ooooooooool05Oooool01Ol0003o
oooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo08_ooooo001/ooooo`03o`000?oooooooooo01Gooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`2<ooooo`00KOooool00ol0003oooooooooo`0Dooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`2<ooooo`00KOooool00ol0003oooooooooo`0Dooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`2=ooooo`00K_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool0SOooool006kooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo08gooooo001_ooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`2>ooooo`00Koooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0S_ooool0073ooooo00?o
0000ooooooooool0;?ooool2o`0003Kooooo00?o0000ooooooooool0S_ooool0073ooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo08oooooo001aoooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`2?oooo
o`00LOooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0Soooool007;ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooooooo093ooooo001cooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`2@ooooo`00Loooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool0T?ooool007Cooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo093ooooo001dooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`2Aooooo`00MOooool00ol0003ooooo
ooooo`0Wooooo`;o0000<oooool00ol0003oooooooooo`2Aooooo`00MOooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0TOooool007Kooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo097ooooo001foooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2Boooo
o`00M_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool0T_ooool007Oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo09;ooooo001gooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`2Booooo`00N?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool0Toooool007Sooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo09?ooooo001hooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`2Cooooo`00NOooool00ol0003ooooo
ooooo`0Sooooo`;o0000<Oooool00ol0003oooooooooo`2Cooooo`00NOooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0Toooool007Wooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo09Cooooo001joooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`2Doooo
o`00N_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool0U?ooool007_ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo09Cooooo001kooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`2Eooooo`00Noooool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool0UOooool007cooooo00?o0000ooooooooool01Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`2Eooooo`00O?ooool00ol0003oooooooooo`05
ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol0000^ooooo`03o`000?oo
oooooooo09Gooooo001mooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`2Eooooo`00OOooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
2oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool0U_ooool007gooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00co
oooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo09Ko
oooo001nooooo`03o`000?oooooooooo00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`2Fooooo`00
O_ooool00ol0003oooooooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo
0000ooooo`06ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0U_ooool007oooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo09Kooooo
001oooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`2Gooooo`00Ooooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool0Uoooool0083ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo09Oooooo0020ooooo`03o`000?oooooooooo01cooooo0_l0000]ooooo`03
o`000?oooooooooo09Oooooo0021ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`2Gooooo`00POooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool0V?ooool0087ooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo09Sooooo0022ooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`2Hooooo`00P_ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0V?ooool008?ooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo09Sooooo
0023ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:_ooool00ol0003ooooooooo
o`2Iooooo`00Poooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool0VOooool008Cooooo00?o0000ooooooooool06?ooool2o`0002_ooooo00?o0000oooo
ooooool0VOooool008Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo09Wooooo0025ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
:_ooool00ol0003oooooooooo`2Iooooo`00QOooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool0V_ooool008Gooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo09[ooooo0026ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`2Jooooo`00Q_ooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0V_ooool008Kooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo09[ooooo
0027ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`2Jooooo`00Qoooool00ol0003oooooooooo`0Eooooo`;o0000:Oooool00ol0003oooooooooo`2K
ooooo`00Qoooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool0Voooool008Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo09_ooooo0028ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`2Kooooo`00R?ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool0Voooool008Wooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo09cooooo0029ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`2Looooo`00Q?ooool01_o^k^ko
<S8bo`000?lb<S;ok^k^o`0000Cooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_oo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo09cooooo0024ooooo`07ogMgMonHV9So
oooooiRHV?mgMgOoooooo`000003ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Ko
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`2Looooo`00Q?ooool01ol@413ooooo
oooooooooooo410@ooooool000002Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`2Looooo`00Q?ooool01ol0003ooooooooooooooooo
0000ooooool000002Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0000Vooooo`03o`00
0?oooooooooo09gooooo0024ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooo
ooooo`06ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo09gooooo0024ooooo`05oa0@4?ooooooooooooooool@41000_ooool00ol0003o
ooooooooo`06ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`2Mooooo`00Q?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo00?o0000oooooooo
ool01_ooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool0WOooool008Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`03o`000?oooooooooo00Ko
oooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
09gooooo002<ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`2Mooooo`00S?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0W_ooool008gooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo09kooooo002=ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`2Nooooo`00SOooool00ol0003oooooooooo`0?oooo
o`;o00009_ooool00ol0003oooooooooo`2Nooooo`00S_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0W_ooool008kooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo09oooooo002?ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`2Oooooo`00Soooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0Woooool0
08oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
09oooooo002@ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`2Oooooo`00T?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool0X?ooool0093ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo0:3ooooo002Aooooo`03o`000?oooooooooo00_ooooo0_l0000T
ooooo`03o`000?oooooooooo0:3ooooo002Aooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`2Pooooo`00T_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool0X?ooool009;ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo0:7ooooo002Booooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`2Qooooo`00Toooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0XOooool0
09?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
0:7ooooo002Dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`2Qooooo`00U?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool0X_ooool009Cooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo0:;ooooo002Eooooo`03o`000?oooooooooo00Oooooo0_l0000R
ooooo`03o`000?oooooooooo0:;ooooo002Eooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`2Rooooo`00U_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool0X_ooool009Kooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0:?ooooo002Fooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`2Sooooo`00Uoooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0Xoooool0
09Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
0:?ooooo0024ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q
8Ol0003o8B4Qo`000006ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0Xoooool0
08Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonH
V9So000000Kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`2Tooooo`00Q?ooool0
1Ol@413ooooooooooooooooo410@00_ooooo00Co0000oooooooooooooooo0_l00005ooooo`?o0000
7oooool00ol0003oooooooooo`2Tooooo`00Q?ooool01Ol0003ooooooooooooooooo000000_ooooo
00Ko<S8boiRHV?ooooooV9RHoc8b<_l00005ooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool0Y?ooool008Cooooo00Go0000ooooooooooooooooo`00000;ooooo`06olc<c?l0003o0000
o`000?o<c<co00001Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo0:Cooooo0024
ooooo`05oa0@4?ooooooooooooooool@41002oooool01ol@413o^[Zjoooooonj^[[o410@ooooool0
00001?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo0:Cooooo0024ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01ol0003o^[Zjoooooonj^[[o0000ooooool000001?ooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo0:Gooooo0024ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00;ooooo00Go0000oooooooooooooooo
o`00000Pooooo`03o`000?oooooooooo0:Gooooo002Kooooo`05o`000?ooooooooooooooool00000
8?ooool00ol0003oooooooooo`2Uooooo`00W?ooool01?l0003oooooooooool0000Pooooo`03o`00
0?oooooooooo0:Gooooo002Looooo`04o`000?ooooooooooo`00023ooooo00?o0000ooooooooool0
YOooool009cooooo00Co0000oooooooooooo00007oooool00ol0003oooooooooo`2Vooooo`00WOoo
ool01?l0003oooooo`000?l0000Nooooo`03o`000?oooooooooo0:Kooooo002Mooooo`03o`000?oo
oooo000001oooooo00?o0000ooooooooool0Y_ooool009kooooo0_l0000Oooooo`03o`000?oooooo
oooo0:Kooooo002Nooooo`;o00007_ooool00ol0003oooooooooo`2Wooooo`00W_ooool2o`0001ko
oooo00?o0000ooooooooool0Yoooool009oooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`2Wooooo`00Woooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo0:Oooooo002O
ooooo`;o00007?ooool00ol0003oooooooooo`2Xooooo`00Woooool2o`0001cooooo00?o0000oooo
ooooool0Z?ooool009oooooo0ol0000Kooooo`03o`000?oooooooooo0:Sooooo002Oooooo`03o`00
0?oooooo000001_ooooo00?o0000ooooooooool0Z?ooool009oooooo00?o0000ooooool000006_oo
ool00ol0003oooooooooo`2Yooooo`00Woooool01?l0003oooooooooool0000Iooooo`03o`000?oo
oooooooo0:Wooooo002Oooooo`04o`000?ooooooooooo`0001Wooooo00?o0000ooooooooool0ZOoo
ool009oooooo00Go0000ooooooooooooooooo`00000Gooooo`03o`000?oooooooooo0:[ooooo002O
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2Z
ooooo`00Woooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0Z_ooool009oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo0:_ooooo002Oooooo`;o00001?ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo0:_ooooo002Oooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`2[ooooo`00Woooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0[?ooool009oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo0:cooooo002Oooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`2]ooooo`00Woooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0[_ooool009oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0:kooooo002E
ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0[oooool009Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0:ooooo`;o00001_ooool2o`000;;ooooo002Gooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool03?ooool3o`000003ooooool0003o00000;Cooooo002Gooooo`03o`00
0?oooooooooo00Gooooo0ol0000?ooooo`03o`000?oooooooooo0;Cooooo002Gooooo`03o`000?oo
oooooooo0<kooooo002Gooooo`03o`000?oooooooooo0<kooooo002Gooooo`03o`000?oooooooooo
0<kooooo002Eooooo`03oeEEEOmVIVKo00000=3ooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo002Tooooo`05oiRHV?l0003o0000odA4A?nj^[X02Oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0Woooool00:Cooooo00Go410@
okZj^_o^k^koMgMgoa0@4002ooooo`Ko000000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o
8B4Q1oooool00ol0003oooooooooo`2Pooooo`00Y?ooool00ol0003oooooooooo`0;ooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`000:7ooooo002Tooooo`03o`000?oooooooooo00Cooooo
1_l000000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo
0000X_ooool00:Cooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000000_o
oooo00CogMgMoeEEEOoooooo0000X_ooool00:;ooooo00?o410@o`000?l000000ol0000:ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00002Rooooo`00Y?ooool00ol0003o
ooooooooo`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00002Roooo
o`00Y?ooool00ol0003oooooooooo`0;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omg
MgOo0000ooooo`2Qooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.68406, -0.0802184, \
0.0288357, 0.00666531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.428571 0.142857 0 0.618034 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.14286 -0.0125 -6 -9 ]
[.14286 -0.0125 6 0 ]
[.28571 -0.0125 -6 -9 ]
[.28571 -0.0125 6 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.41607 .12361 -18 -4.5 ]
[.41607 .12361 0 4.5 ]
[.41607 .24721 -18 -4.5 ]
[.41607 .24721 0 4.5 ]
[.41607 .37082 -18 -4.5 ]
[.41607 .37082 0 4.5 ]
[.41607 .49443 -18 -4.5 ]
[.41607 .49443 0 4.5 ]
[.41607 .61803 -6 -4.5 ]
[.41607 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-3)] 0 -0.0125 0 1 Mshowa
.14286 0 m
.14286 .00625 L
s
[(-2)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(-1)] .28571 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(1)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(2)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(3)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.42857 .12361 m
.43482 .12361 L
s
[(0.2)] .41607 .12361 1 0 Mshowa
.42857 .24721 m
.43482 .24721 L
s
[(0.4)] .41607 .24721 1 0 Mshowa
.42857 .37082 m
.43482 .37082 L
s
[(0.6)] .41607 .37082 1 0 Mshowa
.42857 .49443 m
.43482 .49443 L
s
[(0.8)] .41607 .49443 1 0 Mshowa
.42857 .61803 m
.43482 .61803 L
s
[(1)] .41607 .61803 1 0 Mshowa
.125 Mabswid
.42857 .0309 m
.43232 .0309 L
s
.42857 .0618 m
.43232 .0618 L
s
.42857 .09271 m
.43232 .09271 L
s
.42857 .15451 m
.43232 .15451 L
s
.42857 .18541 m
.43232 .18541 L
s
.42857 .21631 m
.43232 .21631 L
s
.42857 .27812 m
.43232 .27812 L
s
.42857 .30902 m
.43232 .30902 L
s
.42857 .33992 m
.43232 .33992 L
s
.42857 .40172 m
.43232 .40172 L
s
.42857 .43262 m
.43232 .43262 L
s
.42857 .46353 m
.43232 .46353 L
s
.42857 .52533 m
.43232 .52533 L
s
.42857 .55623 m
.43232 .55623 L
s
.42857 .58713 m
.43232 .58713 L
s
.25 Mabswid
.42857 0 m
.42857 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
1e-05 8e-05 m
.0143 .00014 L
.02861 .00024 L
.04292 .00042 L
.05724 .00072 L
.07159 .00119 L
.08598 .00195 L
.10043 .00312 L
.11496 .00489 L
.12961 .00751 L
.14443 .01132 L
.15946 .01672 L
.17479 .0242 L
.19048 .03435 L
.20663 .04778 L
.22332 .06514 L
.24065 .08706 L
.25867 .11404 L
.27745 .14643 L
.29699 .1843 L
.31725 .22736 L
.33813 .27494 L
.35948 .32588 L
.38108 .37862 L
.40266 .43119 L
.4239 .48133 L
.44447 .52665 L
.46405 .56484 L
.48235 .5938 L
.49915 .61188 L
.51429 .61803 L
.52772 .61188 L
.5395 .5938 L
.54977 .56484 L
.55876 .52665 L
.56675 .48133 L
.57409 .43119 L
.58108 .37862 L
.58805 .32588 L
.59527 .27494 L
.60296 .22736 L
.61127 .1843 L
.62031 .14643 L
.6301 .11404 L
.64065 .08706 L
.65189 .06514 L
.66377 .04778 L
.67619 .03435 L
.68907 .0242 L
.70232 .01672 L
Mistroke
.71586 .01132 L
.72961 .00751 L
.74353 .00489 L
.75758 .00312 L
.7717 .00195 L
.78588 .00119 L
.8001 .00072 L
.81434 .00042 L
.82861 .00024 L
.84288 .00014 L
.85715 8e-05 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`007_ooool01OnHV9So410@o`000?lb<S;oc<c<02Oooooo1Ol0000Woooo
o`Co000000?o410@ooooooooool0C?ooool4o`000003oa0@4?oooooooooo02?ooooo1Ol0000Voooo
o`05oiRHV?l@413o0000oc8b<_o<c<`0:Oooool2o`000003oa0@4?oooooooooo01Oooooo000Noooo
o`05oa0@4?nj^[[oooooogMgMolb<S809oooool01OnHV9So8B4Qonk^k_ooooooA4A402Wooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
9_ooool01Ol@413o^[ZjoooooomgMgOo<S8b02[ooooo00?o0000ooooooooool06?ooool001Kooooo
1_l00006ooooo`03o`000?oooooooooo01gooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^01oooooo
1_l00005ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09_ooool00onHV9So8B4Q
onk^kP0[ooooo`03o`000?oooooooooo02Gooooo1Ol0000Iooooo`008Oooool00onYZJWo410@oooo
o`0Xooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Wooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?oZJVYoa0@4?ooool09_ooool01?m4A4CogMgMoooo
ool0000Jooooo`008?ooool00ol@413o0000okZj^P0Zooooo`03ogMgMomVIVKooooo02Sooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Xooooo`03ogMgMomVIVKooooo02Oooooo00?o
410@o`000?nj^[X09oooool01?oMgMgoEEEEooooool0000Jooooo`008Oooool00onj^[[o8B4Qoooo
o`0Zooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo02Oooooo00?o^[Zjob4Q8Oooool09oooool00omgMgOoc<c<o`00
000Jooooo`007_ooool01Ol@413oV9RHoooooonj^[[o000002Oooooo00Go0000okZj^_ooooooV9RH
oa0@400Yooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09Oooool01Ol0003o^[Zj
oooooonHV9So410@02Kooooo00Go410@oiRHV?oooooo^[Zjo`00000Xooooo`03onk^k_m4A4Co0000
01[ooooo000Nooooo`05ojVYZOl@413o0000oa0@4?nYZJT09oooool01OnHV9So410@o`000?lQ8B7o
c<c<02Oooooo00?oEEEEofIVI_l00000D?ooool00omEEEGoIVIVo`00000Wooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`09_ooool01OnYZJWo410@o`000?l@413oZJVY02Wooooo00?oMgMgo`000?ooool0
6Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool001goooooool0000bo`0001[ooooo000Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool01?l0003oooooooooooooool=o`000003ooooool0003ooooo00Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooool000003?l00002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06?oo
ool001gooooo00?o0000ooooooooool07oooool7o`0000?ooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:?ooool0
1?l0003oooooooooooooool7o`00023ooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0Hooooo`00A_ooool3o`0005Kooooo00?o0000ooooooooool0EOooool3o`0006kooooo0019oooo
o`Co0000D_ooool00ol0003oooooooooo`1Booooo`?o0000LOooool004gooooo0ol0001?ooooo`03
o`000?oooooooooo04oooooo0ol0001dooooo`00D?ooool00ol0003oooooooooo`1<ooooo`03o`00
0?oooooooooo04kooooo00?o0000ooooooooool0MOooool0057ooooo00?o0000ooooooooool0Booo
ool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo07Kooooo001Booooo`;o0000Boooool0
0ol0003oooooooooo`1;ooooo`;o0000NOooool005Cooooo0_l00019ooooo`03o`000?oooooooooo
04[ooooo00?o0000ooooooooool0NOooool005Kooooo00?o0000ooooooooool0A_ooool2o`0004[o
oooo00?o0000ooooooooool0N_ooool005Oooooo0_l00016ooooo`03o`000?oooooooooo04Sooooo
00?o0000ooooooooool0Noooool005Wooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`18ooooo`03o`000?oooooooooo07_ooooo001Jooooo`03o`000?oooooooooo04;ooooo00?o0000
ooooooooool0Aoooool00ol0003oooooooooo`1looooo`00Foooool00ol0003oooooooooo`11oooo
o`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0OOooool005cooooo00?o0000oooooooo
ool0@?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo07kooooo001Mooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`1nooooo`00G_oo
ool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0Oooo
ool005oooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooo
oooo083ooooo001Pooooo`03o`000?oooooooooo03cooooo0_l00013ooooo`03o`000?oooooooooo
087ooooo001Qooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0@Oooool00ol0003o
ooooooooo`22ooooo`00HOooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo047ooooo
00?o0000ooooooooool0P_ooool006;ooooo00?o0000ooooooooool0>_ooool00ol0003ooooooooo
o`10ooooo`03o`000?oooooooooo08?ooooo001Sooooo`03o`000?oooooooooo03Wooooo00?o0000
ooooooooool0@?ooool00ol0003oooooooooo`23ooooo`00I?ooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool0Q?ooool006Cooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo08Cooooo001Uooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`24ooooo`00I_oo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0QOoo
ool006Kooooo00?o0000ooooooooool0=_ooool2o`0003oooooo00?o0000ooooooooool0QOooool0
06Oooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo
08Kooooo001Xooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0?Oooool00ol0003o
ooooooooo`26ooooo`00JOooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03cooooo
00?o0000ooooooooool0Qoooool006Wooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`0looooo`03o`000?oooooooooo08Oooooo001Zooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`28ooooo`00Joooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0R?ooool006cooooo00?o0000oooooooo
ool05Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0
003oooooooooo`0jooooo`03o`000?oooooooooo08Wooooo001/ooooo`03o`000?oooooooooo01Go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400Kooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`29ooooo`00KOooool00ol0
003oooooooooo`0Dooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP07
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0ROooool006gooooo00?o0000oooo
ooooool05?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01_ooool3
o`0003Wooooo00?o0000ooooooooool0R_ooool006kooooo00?o0000ooooooooool04oooool01Ol0
003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo08[ooooo001^ooooo`03o`000?oooooooooo01?ooooo00Go410@oooo
oooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`2:ooooo`00Koooool00ol0003oooooooooo`0Booooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0>?oo
ool00ol0003oooooooooo`2;ooooo`00Koooool00ol0003oooooooooo`0Booooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`2;ooooo`00L?ooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo03Sooooo00?o0000ooooooooool0Roooool0073ooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo08cooooo001aooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`2<ooooo`00LOooool00ol0003o
ooooooooo`0[ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0S?ooool007;ooooo
00?o0000ooooooooool0:_ooool2o`0003Sooooo00?o0000ooooooooool0S?ooool007;ooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo08cooooo001c
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`2=
ooooo`00Loooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool0SOooool007Cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0fooooo`03
o`000?oooooooooo08gooooo001eooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`2=ooooo`00MOooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool0SOooool007Kooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0eooooo`03o`000?oooooooooo08kooooo001fooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`2>ooooo`00Moooool00ol0003o
ooooooooo`0Uooooo`;o0000=_ooool00ol0003oooooooooo`2>ooooo`00Moooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0S_ooool007Sooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo08kooooo001h
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`2?
ooooo`00NOooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool0Soooool007Wooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo08oooooo001jooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`2?ooooo`00N_ooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool0T?ooool007[ooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo093ooooo001kooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`2@ooooo`00Noooool00ol0003o
ooooooooo`0Qooooo`;o0000=?ooool00ol0003oooooooooo`2@ooooo`00O?ooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0T?ooool007cooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo097ooooo001m
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`2A
ooooo`00OOooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03;ooooo00?o0000oooo
ooooool0TOooool007kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo097ooooo001nooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`2Aooooo`00Ooooool00ol0003oooooooooo`02ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`00
0?oooooooooo03;ooooo00?o0000ooooooooool0TOooool007oooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2Booooo`00P?ooool01Ol0003ooooooooo
oooooooo410@00?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0000aooooo`03o`00
0?oooooooooo09;ooooo0020ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`2Booooo`00POooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Wo
oooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo
09;ooooo0021ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool02_ooool00omg
MgOoc<c<o`000007ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0T_ooool0087o
oooo00So0000ooooooooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l000001ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo09;ooooo0022ooooo`07o`000?oooooo
k^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`2Booooo`00P_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool0Toooool008?ooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo09?ooooo0023ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`2Cooooo`00Q?ooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0Toooool008Cooooo
00?o0000ooooooooool06?ooool2o`00037ooooo00?o0000ooooooooool0Toooool008Gooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo09?ooooo0025
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`2C
ooooo`00QOooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool0Toooool008Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo09Cooooo0026ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`2Dooooo`00Qoooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool0U?ooool008Oooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo09Cooooo0027ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`2Dooooo`00R?ooool00ol0003o
ooooooooo`0Dooooo`;o0000<?ooool00ol0003oooooooooo`2Dooooo`00R?ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0U?ooool008Wooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo09Gooooo0029
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`2E
ooooo`00ROooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool0UOooool008[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo09Gooooo002:ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`2Eooooo`00Roooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool0UOooool008_ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo09Gooooo002<ooooo`03o`000?oooooooooo
013ooooo0_l0000^ooooo`03o`000?oooooooooo09Kooooo002<ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`2Fooooo`00S?ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0U_ooool008gooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo09Kooooo002=
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`2F
ooooo`00S_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool0Uoooool008kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo09Oooooo0024ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00olQ8B7o
0000ooooo`03ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo09Oooooo0024ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00olQ
8B7o0000ooooo`03ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo09Oooooo0024ooooo`05oa0@4?ooooooooooooooool@41001_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo09Oooooo0024ooooo`05o`000?ooooooooooooooool000001ooo
ool02Ol0003ooooooooooooooooo0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000:oooool00ol0
003oooooooooo`2Hooooo`00Q?ooool01Ol0003ooooooooooooooooo000000Oooooo00Wo0000oooo
ooooooooooooo`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo09Sooooo0024ooooo`05oa0@4?ooooooooooooooool@41002?ooool01Ol0003ooooo
oooooomEEEGoQhN700Wooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`2Hooooo`00
Q?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00Ko0000oooooooooooogMgMoa0@4?nHV9P8
ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0V?ooool008Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP09ooooo`07o`000?ooooooooooolc<c?m4A4Co0000oa0@4006ooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool0V?ooool009;ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo09Sooooo002Booooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`2Hooooo`00Toooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0VOooool009?o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo09Wo
oooo002Cooooo`03o`000?oooooooooo00Wooooo0_l0000[ooooo`03o`000?oooooooooo09Wooooo
002Dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0:_ooool00ol0003ooooooooo
o`2Iooooo`00U?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool0VOooool009Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Zoooo
o`03o`000?oooooooooo09Wooooo002Eooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`2Iooooo`00UOooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool0VOooool009Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo09[ooooo002Fooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`2Jooooo`00U_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0V_ooool009Oo
oooo00?o0000ooooooooool01Oooool2o`0002[ooooo00?o0000ooooooooool0V_ooool009Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo09[ooooo
002Hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`2Jooooo`00V?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool0V_ooool009Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo09[ooooo002Iooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`2Kooooo`00V_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool0Voooool009[ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo09_ooooo002Kooooo`05o`000?oooooo
ooooooooool00000:_ooool00ol0003oooooooooo`2Kooooo`00Voooool01Ol0003ooooooooooooo
oooo000002[ooooo00?o0000ooooooooool0Voooool009_ooooo00Co0000oooooooooooooooo0_l0
000Yooooo`03o`000?oooooooooo09_ooooo002Looooo`04o`000?ooooooooooo`0002[ooooo00?o
0000ooooooooool0Voooool009cooooo00Co0000oooooooooooo0000:Oooool00ol0003ooooooooo
o`2Looooo`00WOooool00ol0003oooooo`00000Yooooo`03o`000?oooooooooo09cooooo002Moooo
o`03o`000?oooooo000002Wooooo00?o0000ooooooooool0W?ooool009kooooo0_l0000Yooooo`03
o`000?oooooooooo09cooooo002Nooooo`;o0000:Oooool00ol0003oooooooooo`2Looooo`00Q?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<
c<`01_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo09cooooo0024ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06oooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0W?ooool008Cooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`0002Kooooo00?o0000
ooooooooool0WOooool008Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9So
oooooiRHV?lb<S801_ooool2o`0002Oooooo00?o0000ooooooooool0WOooool008Cooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool2o`0002Oooooo
00?o0000ooooooooool0WOooool008Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@
4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooo`00000Vooooo`03o`000?oooooooooo09go
oooo0024ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o0000
00Kooooo00?o0000ooooool000009_ooool00ol0003oooooooooo`2Mooooo`00Q?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`04o`000?oooooo
ooooo`0002Gooooo00?o0000ooooooooool0WOooool009oooooo00Co0000oooooooooooo00009Ooo
ool00ol0003oooooooooo`2Mooooo`00Woooool01Ol0003ooooooooooooooooo000002?ooooo00?o
0000ooooooooool0W_ooool009oooooo00Go0000ooooooooooooooooo`00000Sooooo`03o`000?oo
oooooooo09kooooo002Oooooo`05o`000?ooooooooooooooool000008oooool00ol0003ooooooooo
o`2Nooooo`00Woooool2o`0000?ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`2N
ooooo`00Woooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool0W_ooool009oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo09kooooo002Oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`2Oooooo`00Woooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool0Woooool009oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo09oooooo002Oooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`2Oooooo`00Woooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0X?ooool009oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo0:3ooooo
002Oooooo`;o00001oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo0:3ooooo002O
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`2P
ooooo`00Woooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool0XOooool009oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo0:7ooooo002Oooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`2Qooooo`00Woooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0X_ooool009oooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0:;ooooo002Oooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`2Rooooo`00Woooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Xoooool009oooooo
0_l0000=ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0Xoooool009oooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0:?ooooo002O
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2T
ooooo`00Woooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0Y?ooool009oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo0:Gooooo002Oooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`2Vooooo`00Woooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0Y_ooool009Gooooo1?l000000ol@413oooooooooo`03
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2W
ooooo`00Uoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo0_l00005oooo
o`;o0000Z_ooool009Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Eooooo`;o
000000?oooooo`000?l00000[?ooool009Oooooo00?o0000ooooooooool01Oooool3o`0001Oooooo
00?o0000ooooooooool0[?ooool009Oooooo00?o0000ooooooooool0c_ooool009Oooooo00?o0000
ooooooooool0c_ooool009Oooooo00?o0000ooooooooool0c_ooool009Gooooo00?oEEEEofIVI_l0
0000d?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Cooooo00GoV9RHo`00
0?l0003oA4A4okZj^P09ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Go
k^k^oc8b<_l0003o410@olc<c02Qooooo`00Y?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00;ooooo
1_l000001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B40XOooool00:Cooooo00?o0000ooooooooool02oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go0000ooooooooooooooooo`00002Qooooo`00Y?ooool00ol0003oooooooooo`04
ooooo`Ko000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9So
oooooiRHV?lQ8B40XOooool00:Cooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooo
oooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c02Qooooo`00X_ooool00ol@413o0000o`00
0003o`0000[ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo0:?ooooo
002Tooooo`03o`000?oooooooooo00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgM
gOl@413oV9RH0:?ooooo002Tooooo`03o`000?oooooooooo00_ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@4:7ooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.68406, -0.0802184, \
0.0288357, 0.00666531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.428571 0.142857 0 0.618034 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.14286 -0.0125 -6 -9 ]
[.14286 -0.0125 6 0 ]
[.28571 -0.0125 -6 -9 ]
[.28571 -0.0125 6 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.41607 .12361 -18 -4.5 ]
[.41607 .12361 0 4.5 ]
[.41607 .24721 -18 -4.5 ]
[.41607 .24721 0 4.5 ]
[.41607 .37082 -18 -4.5 ]
[.41607 .37082 0 4.5 ]
[.41607 .49443 -18 -4.5 ]
[.41607 .49443 0 4.5 ]
[.41607 .61803 -6 -4.5 ]
[.41607 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-3)] 0 -0.0125 0 1 Mshowa
.14286 0 m
.14286 .00625 L
s
[(-2)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(-1)] .28571 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(1)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(2)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(3)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.42857 .12361 m
.43482 .12361 L
s
[(0.2)] .41607 .12361 1 0 Mshowa
.42857 .24721 m
.43482 .24721 L
s
[(0.4)] .41607 .24721 1 0 Mshowa
.42857 .37082 m
.43482 .37082 L
s
[(0.6)] .41607 .37082 1 0 Mshowa
.42857 .49443 m
.43482 .49443 L
s
[(0.8)] .41607 .49443 1 0 Mshowa
.42857 .61803 m
.43482 .61803 L
s
[(1)] .41607 .61803 1 0 Mshowa
.125 Mabswid
.42857 .0309 m
.43232 .0309 L
s
.42857 .0618 m
.43232 .0618 L
s
.42857 .09271 m
.43232 .09271 L
s
.42857 .15451 m
.43232 .15451 L
s
.42857 .18541 m
.43232 .18541 L
s
.42857 .21631 m
.43232 .21631 L
s
.42857 .27812 m
.43232 .27812 L
s
.42857 .30902 m
.43232 .30902 L
s
.42857 .33992 m
.43232 .33992 L
s
.42857 .40172 m
.43232 .40172 L
s
.42857 .43262 m
.43232 .43262 L
s
.42857 .46353 m
.43232 .46353 L
s
.42857 .52533 m
.43232 .52533 L
s
.42857 .55623 m
.43232 .55623 L
s
.42857 .58713 m
.43232 .58713 L
s
.25 Mabswid
.42857 0 m
.42857 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
1e-05 8e-05 m
.01431 .00014 L
.02862 .00024 L
.04294 .00042 L
.05728 .00072 L
.07165 .00119 L
.08607 .00195 L
.10058 .00312 L
.11519 .00489 L
.12996 .00751 L
.14495 .01132 L
.16023 .01672 L
.1759 .0242 L
.19207 .03435 L
.20883 .04778 L
.22633 .06514 L
.24467 .08706 L
.26395 .11404 L
.28422 .14643 L
.30551 .1843 L
.32776 .22736 L
.35084 .27494 L
.37455 .32588 L
.39859 .37862 L
.42259 .43119 L
.44615 .48133 L
.46882 .52665 L
.49016 .56484 L
.5098 .5938 L
.52743 .61188 L
.54286 .61803 L
.55601 .61188 L
.56695 .5938 L
.57588 .56484 L
.5831 .52665 L
.58901 .48133 L
.59402 .43119 L
.59859 .37862 L
.60312 .32588 L
.60798 .27494 L
.61347 .22736 L
.61979 .1843 L
.62708 .14643 L
.63537 .11404 L
.64467 .08706 L
.6549 .06514 L
.66598 .04778 L
.67778 .03435 L
.69019 .0242 L
.70309 .01672 L
Mistroke
.71638 .01132 L
.72996 .00751 L
.74376 .00489 L
.75772 .00312 L
.77179 .00195 L
.78593 .00119 L
.80013 .00072 L
.81436 .00042 L
.82862 .00024 L
.84288 .00014 L
.85716 8e-05 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`007_ooool01OnHV9So410@o`000?lb<S;oc<c<02Oooooo1Ol0000Woooo
o`Co000000?o410@ooooooooool0C?ooool4o`000003oa0@4?oooooooooo02?ooooo1Ol0000Voooo
o`05oiRHV?l@413o0000oc8b<_o<c<`0:Oooool2o`000003oa0@4?oooooooooo01Oooooo000Noooo
o`05oa0@4?nj^[[oooooogMgMolb<S809oooool01OnHV9So8B4Qonk^k_ooooooA4A402Wooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
9_ooool01Ol@413o^[ZjoooooomgMgOo<S8b02[ooooo00?o0000ooooooooool06?ooool001Kooooo
1_l00006ooooo`03o`000?oooooooooo01gooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^01oooooo
1_l00005ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09_ooool00onHV9So8B4Q
onk^kP0[ooooo`03o`000?oooooooooo02Gooooo1Ol0000Iooooo`008Oooool00onYZJWo410@oooo
o`0Xooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Wooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?oZJVYoa0@4?ooool09_ooool01?m4A4CogMgMoooo
ool0000Jooooo`008?ooool00ol@413o0000okZj^P0Zooooo`03ogMgMomVIVKooooo02Sooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Xooooo`03ogMgMomVIVKooooo02Oooooo00?o
410@o`000?nj^[X09oooool01?oMgMgoEEEEooooool0000Jooooo`008Oooool00onj^[[o8B4Qoooo
o`0Zooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo02Oooooo00?o^[Zjob4Q8Oooool09oooool00omgMgOoc<c<o`00
000Jooooo`007_ooool01Ol@413oV9RHoooooonj^[[o000002Oooooo00Go0000okZj^_ooooooV9RH
oa0@400Yooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09Oooool01Ol0003o^[Zj
oooooonHV9So410@02Kooooo00Go410@oiRHV?oooooo^[Zjo`00000Xooooo`03onk^k_m4A4Co0000
01[ooooo000Nooooo`05ojVYZOl@413o0000oa0@4?nYZJT09oooool01OnHV9So410@o`000?lQ8B7o
c<c<02Oooooo00?oEEEEofIVI_l00000D?ooool00omEEEGoIVIVo`00000Wooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`09_ooool01OnYZJWo410@o`000?l@413oZJVY02Wooooo00?oMgMgo`000?ooool0
6Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool001goooooool0000bo`0001[ooooo000Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool01?l0003oooooooooooooool=o`000003ooooool0003ooooo00Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooool000003?l00002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06?oo
ool001gooooo00?o0000ooooooooool07oooool8o`0000;ooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:?ooool0
1?l0003oooooooooooooool7o`00023ooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0Hooooo`00Aoooool2o`0005Kooooo00?o0000ooooooooool0E_ooool2o`0006kooooo0019oooo
o`Co0000D_ooool00ol0003oooooooooo`1Cooooo`?o0000L?ooool004gooooo0ol0001?ooooo`03
o`000?oooooooooo053ooooo0ol0001cooooo`00D?ooool2o`0004gooooo00?o0000ooooooooool0
Coooool00ol0003oooooooooo`1dooooo`00D_ooool00ol0003oooooooooo`1:ooooo`03o`000?oo
oooooooo04kooooo00?o0000ooooooooool0MOooool005?ooooo0_l0001:ooooo`03o`000?oooooo
oooo04cooooo0_l0001hooooo`00EOooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo
04_ooooo00?o0000ooooooooool0N?ooool005Kooooo00?o0000ooooooooool0A_ooool2o`0004_o
oooo00?o0000ooooooooool0NOooool005Oooooo0_l00016ooooo`03o`000?oooooooooo04Wooooo
00?o0000ooooooooool0N_ooool005Wooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`18ooooo`03o`000?oooooooooo07_ooooo001Jooooo`;o0000@oooool00ol0003oooooooooo`17
ooooo`03o`000?oooooooooo07cooooo001Looooo`03o`000?oooooooooo043ooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`1mooooo`00GOooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo04Gooooo00?o0000ooooooooool0O_ooool005kooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo07kooooo001Oooooo`03o`000?oo
oooooooo03gooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`1oooooo`00H?ooool0
0ol0003oooooooooo`0looooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0P?ooool0
067ooooo00?o0000ooooooooool0>oooool2o`0004Cooooo00?o0000ooooooooool0P?ooool006;o
oooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo087o
oooo001Rooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0@_ooool00ol0003ooooo
ooooo`21ooooo`00Hoooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo047ooooo00?o
0000ooooooooool0P_ooool006Cooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`11
ooooo`03o`000?oooooooooo08;ooooo001Uooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool0@?ooool00ol0003oooooooooo`23ooooo`00IOooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo043ooooo00?o0000ooooooooool0Poooool006Kooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo08?ooooo001Wooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`24ooooo`00Ioooool0
0ol0003oooooooooo`0eooooo`;o0000@?ooool00ol0003oooooooooo`24ooooo`00J?ooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0QOooool006Wo
oooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo08Go
oooo001Zooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`25ooooo`00J_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo03gooooo00?o
0000ooooooooool0Q_ooool006_ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0m
ooooo`03o`000?oooooooooo08Kooooo001/ooooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool0?Oooool00ol0003oooooooooo`26ooooo`00KOooool00ol0003oooooooooo`0Dooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo
03cooooo00?o0000ooooooooool0Qoooool006gooooo00?o0000ooooooooool05?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool0
0ol0003oooooooooo`0looooo`03o`000?oooooooooo08Oooooo001^ooooo`03o`000?oooooooooo
01?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000
ooooooooool0??ooool00ol0003oooooooooo`27ooooo`00Koooool00ol0003oooooooooo`0Boooo
o`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`?o0000>oooool0
0ol0003oooooooooo`28ooooo`00Koooool00ol0003oooooooooo`0Booooo`05o`000?oooooooooo
ooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0R?ooool0073ooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo08Sooooo001`ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`0jooooo`03o`000?oo
oooooooo08Wooooo001aooooo`03o`000?oooooooooo013ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0jooooo`03o`00
0?oooooooooo08Wooooo001booooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0>_oo
ool00ol0003oooooooooo`29ooooo`00L_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo03Wooooo00?o0000ooooooooool0R_ooool007?ooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo08[ooooo001cooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`2:ooooo`00M?ooool00ol0003ooooo
ooooo`0Xooooo`;o0000>_ooool00ol0003oooooooooo`2:ooooo`00MOooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0R_ooool007Gooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo08_ooooo001foooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`2;oooo
o`00Moooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool0Roooool007Oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo08_ooooo001hooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>?oo
ool00ol0003oooooooooo`2;ooooo`00N?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo03Oooooo00?o0000ooooooooool0S?ooool007Wooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`0gooooo`03o`000?oooooooooo08cooooo001jooooo`03o`000?oooooooooo02;o
oooo0_l0000hooooo`03o`000?oooooooooo08cooooo001jooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`2<ooooo`00Noooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0S?ooool007_ooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo08cooooo001loooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`2=oooo
o`00O?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03Kooooo00?o0000oooooooo
ool0SOooool007gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo08gooooo001nooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`2=ooooo`00O_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool0SOooool007oooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo08gooooo001oooooo`03o`000?oooooooooo01go
oooo0_l0000gooooo`03o`000?oooooooooo08gooooo0020ooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`2>ooooo`00P?ooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0S_ooool0087ooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo08kooooo0021oooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`2>oooo
o`00P_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool0S_ooool008;ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo08kooooo0023ooooo`06o`000?o^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Ko
oooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool0S_ooool008?ooooo00Ko0000ogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0S_ooool008Co
oooo00Go0000oooooooooooooooooa0@400;ooooo`Go00001_ooool3o`0003Gooooo00?o0000oooo
ooooool0S_ooool008Cooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgooooo
o`0000Oooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`2>ooooo`00Q?ooool2o`00
00;ooooo00?o0000ooooooooool02Oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool0Soooool008Cooooo00Go410@o`000?oooooooooooa0@400<
ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`2?
ooooo`00Q?ooool01OmgMgOo0000oooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool0
0ol0003oooooooooo`0dooooo`03o`000?oooooooooo08oooooo0024ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo03Cooooo00?o0000
ooooooooool0Soooool008Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo08oooooo0027ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`2?ooooo`00Qoooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool0Soooool008Sooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo08oooooo0028ooooo`03o`000?oooooo
oooo01Cooooo0_l0000eooooo`03o`000?oooooooooo08oooooo0029ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`2?ooooo`00ROooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0Soooool008[ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo08oooooo
002:ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`2@ooooo`00Roooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03?ooooo00?o0000
ooooooooool0T?ooool008_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0coooo
o`03o`000?oooooooooo093ooooo002<ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0<oooool00ol0003oooooooooo`2@ooooo`00S?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo03?ooooo00?o0000ooooooooool0T?ooool008cooooo00?o0000ooooooooool04?oo
ool2o`0003Cooooo00?o0000ooooooooool0T?ooool008gooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo093ooooo002=ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`2Aooooo`00S_ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0TOooool008kooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo097ooooo
002?ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0<_ooool00ol0003ooooooooo
o`2Aooooo`00Soooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool0TOooool0093ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0boooo
o`03o`000?oooooooooo097ooooo002@ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`2Aooooo`00TOooool00ol0003oooooooooo`0;ooooo`;o0000
<oooool00ol0003oooooooooo`2Aooooo`00TOooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool0TOooool0097ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo097ooooo002Booooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`2Aooooo`00T_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0TOooool009?ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo09;ooooo
002Cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`2Booooo`00Q?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05o`000?lb
<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo09;ooooo
0024ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go0000ogMgMooooooo
V9RHob4Q8@06ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0T_ooool008Cooooo
00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo09;ooooo0024ooooo`05o`000?oooooooooooooo
ool000002oooool2o`000003oooooonHV9So8B4Q00Kooooo0ol0000aooooo`03o`000?oooooooooo
09;ooooo0024ooooo`05o`000?ooooooooooooooool000002oooool3o`000003oa0@4?o<c<cooooo
00Gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2Booooo`00Q?ooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qol000002?ooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo09;ooooo0024ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooM
gMgo410@o`000008ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0T_ooool008Co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`2Booooo`00Uoooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool0T_ooool009Sooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo09;ooooo002Hooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`2Cooooo`00V?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0Tooo
ool009Wooooo00?o0000ooooooooool00oooool2o`00037ooooo00?o0000ooooooooool0Toooool0
09Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
09?ooooo002Jooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`2Cooooo`00V_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool0Toooool009_ooooo00Go0000ooooooooooooooooo`00000booooo`03o`00
0?oooooooooo09?ooooo002Kooooo`05o`000?ooooooooooooooool00000<_ooool00ol0003ooooo
ooooo`2Cooooo`00Voooool01Ol0003ooooooooooooooooo0000037ooooo00?o0000ooooooooool0
U?ooool009cooooo00Co0000oooooooooooo0000<Oooool00ol0003oooooooooo`2Dooooo`00W?oo
ool01?l0003oooooooooool0000aooooo`03o`000?oooooooooo09Cooooo002Mooooo`04o`000?oo
oooo0000o`00033ooooo00?o0000ooooooooool0U?ooool009gooooo00?o0000ooooool00000<Ooo
ool00ol0003oooooooooo`2Dooooo`00W_ooool2o`00037ooooo00?o0000ooooooooool0U?ooool0
09kooooo0_l0000aooooo`03o`000?oooooooooo09Cooooo002Oooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool0U?ooool009oooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`2Dooooo`00Woooool2o`00033ooooo00?o0000ooooooooool0U?ooool009oooooo0_l0000`
ooooo`03o`000?oooooooooo09Cooooo002Oooooo`03o`000?oooooo000002kooooo00?o0000oooo
ooooool0UOooool009oooooo00Co0000oooooooooooo0000;Oooool00ol0003oooooooooo`2Eoooo
o`00Woooool2o`000003ooooool0003ooooo02cooooo00?o0000ooooooooool0UOooool009oooooo
00Go0000ooooooooooooooooo`00000/ooooo`03o`000?oooooooooo09Gooooo002Oooooo`05o`00
0?ooooooooooooooool00000;?ooool00ol0003oooooooooo`2Eooooo`00Woooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0UOooool009oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo09Gooooo002O
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`2E
ooooo`00Woooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool0UOooool008Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<
c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo09Gooooo0024ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`2Eooooo`00Q?ooool01Ol@413ooooooooooooo
oooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o00001Oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo09Kooooo0024ooooo`05o`000?ooooooooooooooool00000
2oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo09Kooooo0024ooooo`05o`000?ooooooooooooooool0
00002oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo09Kooooo0024ooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo09Kooooo0024ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo09Kooooo0024ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo09Kooooo002Oooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`2Fooooo`00Woooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0Uoooool0
09oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
09Oooooo002Oooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`2Gooooo`00Woooool2o`0000[ooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`2Gooooo`00Woooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool0Uoooool009oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo09Oooooo002Oooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`2Gooooo`00Woooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool0V?ooool009oooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo09Sooooo002Oooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`2Hooooo`00Woooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0V?ooool0
09oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
09Sooooo002Oooooo`;o00003oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo09So
oooo002Oooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`2Iooooo`00Woooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool0VOooool009oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo09Wooooo002Oooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`2Iooooo`00Woooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool0V_ooool009oooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo09[ooooo002Oooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`2Jooooo`00Woooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Voooool0
09oooooo0_l0000Eooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0Voooool009oo
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo09_o
oooo002Oooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`2Looooo`00Woooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool0W?ooool009oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo09gooooo002Oooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`2Mooooo`00Woooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0W_ooool009Gooooo1?l000000ol@413ooooo
ooooo`03ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`2Nooooo`00Uoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01_ooooo0_l0
0006ooooo`;o0000XOooool009Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0M
ooooo`?o000000?oooooo`000?l00000Xoooool009Oooooo00?o0000ooooooooool01Oooool3o`00
023ooooo00?o0000ooooooooool0Xoooool009Oooooo00?o0000ooooooooool0c_ooool009Oooooo
00?o0000ooooooooool0c_ooool009Oooooo00?o0000ooooooooool0c_ooool009Gooooo00?oEEEE
ofIVI_l00000d?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Cooooo00Go
V9RHo`000?l0003oA4A4okZj^P09ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c02Qooooo`00Y?ooool01Ol@413o^[Zjonk^k_mgMgOo410@
00;ooooo1_l000001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B40XOooool00:Cooooo00?o0000ooooooooool02oooool01Ol@413ooooooooo
oooooooo410@00_ooooo00Go0000ooooooooooooooooo`00002Qooooo`00Y?ooool00ol0003ooooo
ooooo`04ooooo`Ko000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05oc8b
<_nHV9SooooooiRHV?lb<S80XOooool00:Cooooo00?o0000ooooooooool02oooool01Ol0003ooooo
oooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c02Qooooo`00X_ooool00ol@413o
0000o`000003o`0000[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooo
okZj^_l@4100XOooool00:Cooooo00?o0000ooooooooool02oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00002Qooooo`00Y?ooool00ol0003oooooooooo`0;
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY0:7ooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.68406, -0.0802184, \
0.0288357, 0.00666531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.428571 0.142857 0 0.618034 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.14286 -0.0125 -6 -9 ]
[.14286 -0.0125 6 0 ]
[.28571 -0.0125 -6 -9 ]
[.28571 -0.0125 6 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.41607 .12361 -18 -4.5 ]
[.41607 .12361 0 4.5 ]
[.41607 .24721 -18 -4.5 ]
[.41607 .24721 0 4.5 ]
[.41607 .37082 -18 -4.5 ]
[.41607 .37082 0 4.5 ]
[.41607 .49443 -18 -4.5 ]
[.41607 .49443 0 4.5 ]
[.41607 .61803 -6 -4.5 ]
[.41607 .61803 0 4.5 ]
[.5 .63053 -14 0 ]
[.5 .63053 14 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-3)] 0 -0.0125 0 1 Mshowa
.14286 0 m
.14286 .00625 L
s
[(-2)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(-1)] .28571 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(1)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(2)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(3)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.42857 .12361 m
.43482 .12361 L
s
[(0.2)] .41607 .12361 1 0 Mshowa
.42857 .24721 m
.43482 .24721 L
s
[(0.4)] .41607 .24721 1 0 Mshowa
.42857 .37082 m
.43482 .37082 L
s
[(0.6)] .41607 .37082 1 0 Mshowa
.42857 .49443 m
.43482 .49443 L
s
[(0.8)] .41607 .49443 1 0 Mshowa
.42857 .61803 m
.43482 .61803 L
s
[(1)] .41607 .61803 1 0 Mshowa
.125 Mabswid
.42857 .0309 m
.43232 .0309 L
s
.42857 .0618 m
.43232 .0618 L
s
.42857 .09271 m
.43232 .09271 L
s
.42857 .15451 m
.43232 .15451 L
s
.42857 .18541 m
.43232 .18541 L
s
.42857 .21631 m
.43232 .21631 L
s
.42857 .27812 m
.43232 .27812 L
s
.42857 .30902 m
.43232 .30902 L
s
.42857 .33992 m
.43232 .33992 L
s
.42857 .40172 m
.43232 .40172 L
s
.42857 .43262 m
.43232 .43262 L
s
.42857 .46353 m
.43232 .46353 L
s
.42857 .52533 m
.43232 .52533 L
s
.42857 .55623 m
.43232 .55623 L
s
.42857 .58713 m
.43232 .58713 L
s
.25 Mabswid
.42857 0 m
.42857 .61803 L
s
gsave
.5 .63053 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
2e-05 8e-05 m
.01432 .00014 L
.02863 .00024 L
.04295 .00042 L
.05731 .00072 L
.0717 .00119 L
.08616 .00195 L
.10072 .00312 L
.11542 .00489 L
.13031 .00751 L
.14547 .01132 L
.16101 .01672 L
.17702 .0242 L
.19365 .03435 L
.21104 .04778 L
.22934 .06514 L
.24869 .08706 L
.26922 .11404 L
.29099 .14643 L
.31403 .1843 L
.33827 .22736 L
.36355 .27494 L
.38961 .32588 L
.41609 .37862 L
.44253 .43119 L
.4684 .48133 L
.49316 .52665 L
.51628 .56484 L
.53726 .5938 L
.55572 .61188 L
.57143 .61803 L
.58429 .61188 L
.5944 .5938 L
.60199 .56484 L
.60745 .52665 L
.61126 .48133 L
.61395 .43119 L
.61609 .37862 L
.61818 .32588 L
.62069 .27494 L
.62398 .22736 L
.62831 .1843 L
.63385 .14643 L
.64065 .11404 L
.64869 .08706 L
.65791 .06514 L
.66819 .04778 L
.67937 .03435 L
.69131 .0242 L
.70386 .01672 L
Mistroke
.7169 .01132 L
.73031 .00751 L
.74399 .00489 L
.75786 .00312 L
.77188 .00195 L
.78599 .00119 L
.80017 .00072 L
.81438 .00042 L
.82863 .00024 L
.84289 .00014 L
.85716 8e-05 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`007_ooool01OnHV9So410@o`000?lb<S;oc<c<02Oooooo1Ol0000Woooo
o`Co000000?o410@ooooooooool0C?ooool4o`000003oa0@4?oooooooooo02?ooooo1Ol0000Voooo
o`05oiRHV?l@413o0000oc8b<_o<c<`0:Oooool2o`000003oa0@4?oooooooooo01Oooooo000Noooo
o`05oa0@4?nj^[[oooooogMgMolb<S809oooool01OnHV9So8B4Qonk^k_ooooooA4A402Wooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
9_ooool01Ol@413o^[ZjoooooomgMgOo<S8b02[ooooo00?o0000ooooooooool06?ooool001Kooooo
1_l00006ooooo`03o`000?oooooooooo01gooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^01oooooo
1_l00005ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09_ooool00onHV9So8B4Q
onk^kP0[ooooo`03o`000?oooooooooo02Gooooo1Ol0000Iooooo`008Oooool00onYZJWo410@oooo
o`0Xooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Wooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?oZJVYoa0@4?ooool09_ooool01?m4A4CogMgMoooo
ool0000Jooooo`008?ooool00ol@413o0000okZj^P0Zooooo`03ogMgMomVIVKooooo02Sooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Xooooo`03ogMgMomVIVKooooo02Oooooo00?o
410@o`000?nj^[X09oooool01?oMgMgoEEEEooooool0000Jooooo`008Oooool00onj^[[o8B4Qoooo
o`0Zooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo02Oooooo00?o^[Zjob4Q8Oooool09oooool00omgMgOoc<c<o`00
000Jooooo`007_ooool01Ol@413oV9RHoooooonj^[[o000002Oooooo00Go0000okZj^_ooooooV9RH
oa0@400Yooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09Oooool01Ol0003o^[Zj
oooooonHV9So410@02Kooooo00Go410@oiRHV?oooooo^[Zjo`00000Xooooo`03onk^k_m4A4Co0000
01[ooooo000Nooooo`05ojVYZOl@413o0000oa0@4?nYZJT09oooool01OnHV9So410@o`000?lQ8B7o
c<c<02Oooooo00?oEEEEofIVI_l00000D?ooool00omEEEGoIVIVo`00000Wooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`09_ooool01OnYZJWo410@o`000?l@413oZJVY02Wooooo00?oMgMgo`000?ooool0
6Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool001goooooool0000bo`0001[ooooo000Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool01?l0003oooooooooooooool=o`000003ooooool0003ooooo00Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooool000003?l00002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06?oo
ool001gooooo00?o0000ooooooooool07oooool8o`0000;ooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:?ooool0
1?l0003oooooooooooooool7o`00023ooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0Hooooo`00Aoooool2o`0005Kooooo00?o0000ooooooooool0E_ooool2o`0006kooooo0019oooo
o`Co0000D_ooool00ol0003oooooooooo`1Cooooo`?o0000L?ooool004gooooo0ol0001?ooooo`03
o`000?oooooooooo053ooooo0ol0001cooooo`00D?ooool2o`0004gooooo00?o0000ooooooooool0
Coooool00ol0003oooooooooo`1dooooo`00D_ooool00ol0003oooooooooo`1:ooooo`03o`000?oo
oooooooo04kooooo00?o0000ooooooooool0MOooool005?ooooo0_l0001:ooooo`03o`000?oooooo
oooo04cooooo0_l0001hooooo`00EOooool2o`0004Sooooo00?o0000ooooooooool0Boooool00ol0
003oooooooooo`1hooooo`00Eoooool00ol0003oooooooooo`15ooooo`;o0000Boooool00ol0003o
ooooooooo`1iooooo`00F?ooool2o`0004Gooooo00?o0000ooooooooool0BOooool00ol0003ooooo
ooooo`1jooooo`00F_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo04Wooooo00?o
0000ooooooooool0N_ooool005_ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`18
ooooo`03o`000?oooooooooo07_ooooo001Looooo`03o`000?oooooooooo043ooooo00?o0000oooo
ooooool0Aoooool00ol0003oooooooooo`1looooo`00GOooool2o`00043ooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`1mooooo`00Goooool00ol0003oooooooooo`0mooooo`03o`00
0?oooooooooo04Kooooo00?o0000ooooooooool0OOooool0063ooooo00?o0000ooooooooool0??oo
ool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo07kooooo001Qooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`1oooooo`00H_ooool00ol0
003oooooooooo`0jooooo`;o0000AOooool00ol0003oooooooooo`1oooooo`00Hoooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0P?ooool006?ooooo
00?o0000ooooooooool0>Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo083ooooo
001Tooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0@_ooool00ol0003ooooooooo
o`21ooooo`00IOooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo04;ooooo00?o0000
ooooooooool0POooool006Kooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`11oooo
o`03o`000?oooooooooo08;ooooo001Wooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool0@Oooool00ol0003oooooooooo`22ooooo`00J?ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo047ooooo00?o0000ooooooooool0P_ooool006Wooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo08?ooooo001Yooooo`03o`000?oooooo
oooo03?ooooo0_l00011ooooo`03o`000?oooooooooo08?ooooo001Zooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`23ooooo`00Joooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0Q?ooool006cooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo08Cooooo
001/ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0?oooool00ol0003ooooooooo
o`24ooooo`00KOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo03oooooo00?o0000
ooooooooool0Q?ooool006kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo08Gooooo001_ooooo`03o`000?oooooooooo01;ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0?_ooool00ol0
003oooooooooo`25ooooo`00Koooool00ol0003oooooooooo`0Booooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool0QOooool0073ooooo00?o0000ooooooooool04Oooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo08Gooooo001aooooo`03o`000?oooooooooo013ooooo00Go0000oooo
ooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0000mooooo`03o`000?oooooo
oooo08Kooooo001aooooo`03o`000?oooooooooo013ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`26
ooooo`00L_ooool00ol0003oooooooooo`0?ooooo`05oa0@4?ooooooooooooooool@41003oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0Q_ooool0
07;ooooo00?o0000ooooooooool03oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000
okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0Qooo
ool007?ooooo00?o0000ooooooooool03_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0
Qoooool007Cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0looooo`03o`000?oo
oooooooo08Oooooo001dooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`28ooooo`00MOooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0R?ooool007Gooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo08Sooooo001fooooo`03o`000?oooooooooo02Kooooo
0_l0000looooo`03o`000?oooooooooo08Sooooo001gooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`28ooooo`00Moooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0R?ooool007Sooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo08Sooooo001iooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`29ooooo`00
NOooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0
ROooool007[ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0jooooo`03o`000?oo
oooooooo08Wooooo001jooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`29ooooo`00Noooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
03[ooooo00?o0000ooooooooool0ROooool007cooooo00?o0000ooooooooool08?ooool2o`0003_o
oooo00?o0000ooooooooool0ROooool007cooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo08Wooooo001mooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`29ooooo`00O_ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0ROooool007kooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo08[ooooo001oooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`2:ooooo`00
Ooooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0
R_ooool0083ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo08[ooooo0021ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`2:ooooo`00POooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool0R_ooool008;ooooo00?o0000ooooooooool06_ooool2o`0003[o
oooo00?o0000ooooooooool0R_ooool008;ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0hooooo`03o`000?oooooooooo08_ooooo0023ooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool0>?ooool00ol0003oooooooooo`2;ooooo`00Q?ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0Roooool008Cooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo08_ooooo0025ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`2;ooooo`00
QOooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0
Roooool008Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@
4?oooooooooo00Cooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`2;ooooo`00Q?oo
ool01OmgMgOoV9RHo`000?nHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0>?ooool00ol0003oooooooooo`2;ooooo`00Q?ooool01Ol@413ooooooooo
ool0003o410@00_ooooo1Ol00006ooooo`?o0000>?ooool00ol0003oooooooooo`2;ooooo`00Q?oo
ool00ol0003oooooooooo`02o`0000_ooooo00CoA4A4omgMgOoooooo00001oooool00ol0003ooooo
ooooo`0hooooo`03o`000?oooooooooo08_ooooo0024ooooo`05o`000?ooooooooooooooool00000
2oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo03Oooooo00?o0000oooooooo
ool0S?ooool008Cooooo00Go410@ooooooooooooooooo`00000<ooooo`03ogMgMoo<c<co000000Oo
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`2<ooooo`00Q?ooool01OmgMgOoV9RH
oooooonHV9So000000cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo08cooooo0024ooooo`06onk^k_lb<S;o0000oc8b<_o^k^ko00003?ooool00omg
MgOo0000ooooo`06ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0S?ooool008Wo
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo08co
oooo002:ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`2<ooooo`00R_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03Oooooo00?o
0000ooooooooool0S?ooool008_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo08cooooo002;ooooo`03o`000?oooooooooo017ooooo0_l0000hoooo
o`03o`000?oooooooooo08cooooo002<ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`2<ooooo`00S?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool0S?ooool008gooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo08cooooo002=ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`2<ooooo`00S_ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0S?ooool008ko
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo08co
oooo002?ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`2<ooooo`00T?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Oooooo00?o
0000ooooooooool0S?ooool0093ooooo00?o0000ooooooooool03?ooool2o`0003Sooooo00?o0000
ooooooooool0S?ooool0097ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo08cooooo002Aooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`2<ooooo`00T_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool0S?ooool009;ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo08cooooo002Cooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`2<ooooo`00Toooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0S?ooool009Co
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo08co
oooo002Dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`2<ooooo`00UOooool00ol0003oooooooooo`07ooooo`;o0000>?ooool00ol0003ooooooooo
o`2<ooooo`00UOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Oooooo00?o0000
ooooooooool0S?ooool009Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo08cooooo002Fooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`2<ooooo`00Uoooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool0S?ooool009Oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo08gooooo002Hooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`2=ooooo`00Q?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?l000001_oo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo08gooooo0024ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00KoEEEEogMgMoooooooV9RHob4Q8Ol00005ooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool0SOooool008Cooooo00Go410@oooooooooooo
oooooa0@400;ooooo`04o`000?ooooooooooooooo`;o00001Oooool00ol0003oooooooooo`0foooo
o`03o`000?oooooooooo08gooooo0024ooooo`05o`000?ooooooooooooooool000002oooool01ol0
003oV9RHoooooonHV9So8B4Qooooool000001?ooool3o`0003Kooooo00?o0000ooooooooool0SOoo
ool008Cooooo00Go0000ooooooooooooooooo`00000;ooooo`07o`000?mEEEGo0000oa0@4?o<c<co
ooooo`000004ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0SOooool008Cooooo
00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Cooooo00Go0000oooooooo
ooooooooo`00000hooooo`03o`000?oooooooooo08gooooo0024ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool00ooMgMgo410@oiRHV004ooooo`05o`000?ooooooooooooooool00000>?ooool0
0ol0003oooooooooo`2=ooooo`00Q?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<
odA4A?l0003o410@0oooool01?l0003oooooooooool0000hooooo`03o`000?oooooooooo08gooooo
002Looooo`04o`000?ooooooooooo`0003Sooooo00?o0000ooooooooool0SOooool009gooooo00?o
0000ooooool00000>?ooool00ol0003oooooooooo`2=ooooo`00WOooool00ol0003oooooo`00000h
ooooo`03o`000?oooooooooo08gooooo002Nooooo`;o0000>?ooool00ol0003oooooooooo`2=oooo
o`00W_ooool3o`0003Oooooo00?o0000ooooooooool0SOooool009oooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`2=ooooo`00Woooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo08kooooo002Oooooo`;o0000=_ooool00ol0003oooooooooo`2>ooooo`00Woooool2o`00
03Kooooo00?o0000ooooooooool0S_ooool009oooooo00?o0000ooooool00000=Oooool00ol0003o
ooooooooo`2>ooooo`00Woooool00ol0003oooooo`00000eooooo`03o`000?oooooooooo08kooooo
002Oooooo`04o`000?ooooooooooo`0003Cooooo00?o0000ooooooooool0S_ooool009oooooo00Co
0000oooooooooooo0000=?ooool00ol0003oooooooooo`2>ooooo`00Woooool2o`0000;ooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`2>ooooo`00Woooool01Ol0003ooooooooooooo
oooo000003?ooooo00?o0000ooooooooool0S_ooool009oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo08kooooo002Oooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`2>ooooo`00Woooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0S_ooool009oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo08kooooo
002Oooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`2>ooooo`00Woooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool0S_ooool009oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0]oooo
o`03o`000?oooooooooo08kooooo002Oooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`2>ooooo`00Woooool2o`0000Oooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`2>ooooo`00Woooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool0S_ooool009oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo08kooooo002Oooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`2>ooooo`00Woooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0S_ooool009oooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo08kooooo
002Oooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`2>ooooo`00Q?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ
8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool0S_ooool008Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo08kooooo0024ooooo`05oa0@4?ooooooooooooooool@
41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0000;ooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool0Soooool008Cooooo00Go0000ooooooooooooooooo`00000;oooo
o`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0Soooool008Cooooo00Go0000ooooooooooooooooo`00000;
ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0Soooool008Cooooo00Go410@oooooooooooooooooa0@
400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool0Soooool008Cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0Soooool008Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0Soooool009oooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo08oooooo002Oooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`2@ooooo`00Wooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0T?oo
ool009oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo093ooooo002Oooooo`;o00004_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
093ooooo002Oooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`2@ooooo`00Woooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool0T?ooool009oooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo093ooooo002Oooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`2@ooooo`00Woooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool0T?ooool009oooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo093ooooo002Oooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`2Aooooo`00Wooo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0TOoo
ool009oooooo0_l0000Gooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0TOooool0
09oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
097ooooo002Oooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`2Aooooo`00Woooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0TOooool009oooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo097ooooo002Oooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`2Aooooo`00Woooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0T_ooool009oooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo09;ooooo002Oooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`2Booooo`00Wooo
ool2o`0001gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`2Booooo`00Woooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Toooool0
09oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
09?ooooo002Oooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`2Cooooo`00Woooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0U?ooool009oooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo09Gooooo002Oooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`2Eooooo`00UOooool4o`000003oa0@4?oooooooooo
00?ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
09Kooooo002Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09?ooool2o`0000Go
oooo0_l0002Iooooo`00Uoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Kooooo
0ol000000ooooooo0000ooooo`2Jooooo`00Uoooool00ol0003oooooooooo`05ooooo`?o0000:Ooo
ool00ol0003oooooooooo`2Jooooo`00Uoooool00ol0003oooooooooo`3>ooooo`00Uoooool00ol0
003oooooooooo`3>ooooo`00Uoooool00ol0003oooooooooo`3>ooooo`00UOooool00omEEEGoIVIV
o`00003@ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Z?ooool01OnHV9So
0000o`000?m4A4Co^[Zj00[ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4QY_ooool00:So
oooo00Ko410@okZj^_o^k^koMgMgoa0@4?ooool6o`0000Gooooo00?o0000ooooooooool01?ooool2
ob4Q8JKooooo002Xooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0[?ooool00:So
oooo00?o0000ooooooooool00oooool6o`0000Gooooo00?o0000ooooooooool0[?ooool00:Sooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`2/ooooo`00Y_ooool00ol@413o0000o`00
0003o`0000gooooo00?o0000ooooooooool0[?ooool00:Sooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`2/ooooo`00Z?ooool00ol0003oooooooooo`0<ooooo`03oeEEEOmVIVKo0000
0:kooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.68406, -0.0802184, \
0.0288357, 0.00666531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.428571 0.142857 0 0.618034 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.14286 -0.0125 -6 -9 ]
[.14286 -0.0125 6 0 ]
[.28571 -0.0125 -6 -9 ]
[.28571 -0.0125 6 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.41607 .12361 -18 -4.5 ]
[.41607 .12361 0 4.5 ]
[.41607 .24721 -18 -4.5 ]
[.41607 .24721 0 4.5 ]
[.41607 .37082 -18 -4.5 ]
[.41607 .37082 0 4.5 ]
[.41607 .49443 -18 -4.5 ]
[.41607 .49443 0 4.5 ]
[.41607 .61803 -6 -4.5 ]
[.41607 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-3)] 0 -0.0125 0 1 Mshowa
.14286 0 m
.14286 .00625 L
s
[(-2)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(-1)] .28571 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(1)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(2)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(3)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.42857 .12361 m
.43482 .12361 L
s
[(0.2)] .41607 .12361 1 0 Mshowa
.42857 .24721 m
.43482 .24721 L
s
[(0.4)] .41607 .24721 1 0 Mshowa
.42857 .37082 m
.43482 .37082 L
s
[(0.6)] .41607 .37082 1 0 Mshowa
.42857 .49443 m
.43482 .49443 L
s
[(0.8)] .41607 .49443 1 0 Mshowa
.42857 .61803 m
.43482 .61803 L
s
[(1)] .41607 .61803 1 0 Mshowa
.125 Mabswid
.42857 .0309 m
.43232 .0309 L
s
.42857 .0618 m
.43232 .0618 L
s
.42857 .09271 m
.43232 .09271 L
s
.42857 .15451 m
.43232 .15451 L
s
.42857 .18541 m
.43232 .18541 L
s
.42857 .21631 m
.43232 .21631 L
s
.42857 .27812 m
.43232 .27812 L
s
.42857 .30902 m
.43232 .30902 L
s
.42857 .33992 m
.43232 .33992 L
s
.42857 .40172 m
.43232 .40172 L
s
.42857 .43262 m
.43232 .43262 L
s
.42857 .46353 m
.43232 .46353 L
s
.42857 .52533 m
.43232 .52533 L
s
.42857 .55623 m
.43232 .55623 L
s
.42857 .58713 m
.43232 .58713 L
s
.25 Mabswid
.42857 0 m
.42857 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
2e-05 8e-05 m
.01432 .00014 L
.02864 .00024 L
.04297 .00042 L
.05734 .00072 L
.07176 .00119 L
.08625 .00195 L
.10086 .00312 L
.11564 .00489 L
.13066 .00751 L
.146 .01132 L
.16178 .01672 L
.17814 .0242 L
.19524 .03435 L
.21325 .04778 L
.23235 .06514 L
.25272 .08706 L
.27449 .11404 L
.29776 .14643 L
.32255 .1843 L
.34878 .22736 L
.37626 .27494 L
.40468 .32588 L
.43359 .37862 L
.46246 .43119 L
.49065 .48133 L
.51751 .52665 L
.54239 .56484 L
.56471 .5938 L
.58401 .61188 L
.6 .61803 L
.61258 .61188 L
.62185 .5938 L
.6281 .56484 L
.6318 .52665 L
.63351 .48133 L
.63389 .43119 L
.63359 .37862 L
.63325 .32588 L
.6334 .27494 L
.63449 .22736 L
.63683 .1843 L
.64062 .14643 L
.64592 .11404 L
.65272 .08706 L
.66093 .06514 L
.6704 .04778 L
.68096 .03435 L
.69243 .0242 L
.70464 .01672 L
Mistroke
.71743 .01132 L
.73066 .00751 L
.74421 .00489 L
.75801 .00312 L
.77197 .00195 L
.78605 .00119 L
.8002 .00072 L
.8144 .00042 L
.82864 .00024 L
.8429 .00014 L
.85716 8e-05 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`007_ooool01OnHV9So410@o`000?lb<S;oc<c<02Oooooo1Ol0000Woooo
o`Co000000?o410@ooooooooool0C?ooool4o`000003oa0@4?oooooooooo02?ooooo1Ol0000Voooo
o`05oiRHV?l@413o0000oc8b<_o<c<`0:Oooool2o`000003oa0@4?oooooooooo01Oooooo000Noooo
o`05oa0@4?nj^[[oooooogMgMolb<S809oooool01OnHV9So8B4Qonk^k_ooooooA4A402Wooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
9_ooool01Ol@413o^[ZjoooooomgMgOo<S8b02[ooooo00?o0000ooooooooool06?ooool001Kooooo
1_l00006ooooo`03o`000?oooooooooo01gooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^01oooooo
1_l00005ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09_ooool00onHV9So8B4Q
onk^kP0[ooooo`03o`000?oooooooooo02Gooooo1Ol0000Iooooo`008Oooool00onYZJWo410@oooo
o`0Xooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Wooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?oZJVYoa0@4?ooool09_ooool01?m4A4CogMgMoooo
ool0000Jooooo`008?ooool00ol@413o0000okZj^P0Zooooo`03ogMgMomVIVKooooo02Sooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Xooooo`03ogMgMomVIVKooooo02Oooooo00?o
410@o`000?nj^[X09oooool01?oMgMgoEEEEooooool0000Jooooo`008Oooool00onj^[[o8B4Qoooo
o`0Zooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo02Oooooo00?o^[Zjob4Q8Oooool09oooool00omgMgOoc<c<o`00
000Jooooo`007_ooool01Ol@413oV9RHoooooonj^[[o000002Oooooo00Go0000okZj^_ooooooV9RH
oa0@400Yooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09Oooool01Ol0003o^[Zj
oooooonHV9So410@02Kooooo00Go410@oiRHV?oooooo^[Zjo`00000Xooooo`03onk^k_m4A4Co0000
01[ooooo000Nooooo`05ojVYZOl@413o0000oa0@4?nYZJT09oooool01OnHV9So410@o`000?lQ8B7o
c<c<02Oooooo00?oEEEEofIVI_l00000D?ooool00omEEEGoIVIVo`00000Wooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`09_ooool01OnYZJWo410@o`000?l@413oZJVY02Wooooo00?oMgMgo`000?ooool0
6Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool001goooooool0000bo`0001[ooooo000Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool01?l0003oooooooooooooool=o`000003ooooool0003ooooo00Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooool000003?l00002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06?oo
ool001gooooo00?o0000ooooooooool07oooool8o`0000;ooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:?ooool0
1?l0003oooooooooooooool7o`00023ooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0Hooooo`00Aoooool2o`0005Kooooo00?o0000ooooooooool0E_ooool2o`0006kooooo0019oooo
o`Co0000D_ooool00ol0003oooooooooo`1Cooooo`?o0000L?ooool004gooooo0ol0001?ooooo`03
o`000?oooooooooo053ooooo0ol0001cooooo`00D?ooool2o`0004gooooo00?o0000ooooooooool0
Coooool00ol0003oooooooooo`1dooooo`00D_ooool00ol0003oooooooooo`1:ooooo`03o`000?oo
oooooooo04kooooo00?o0000ooooooooool0MOooool005?ooooo0_l0001:ooooo`03o`000?oooooo
oooo04gooooo00?o0000ooooooooool0M_ooool005Gooooo0_l00018ooooo`03o`000?oooooooooo
04cooooo00?o0000ooooooooool0Moooool005Oooooo00?o0000ooooooooool0AOooool2o`0004co
oooo00?o0000ooooooooool0N?ooool005Sooooo0_l00015ooooo`03o`000?oooooooooo04[ooooo
00?o0000ooooooooool0NOooool005[ooooo00?o0000ooooooooool0@_ooool00ol0003ooooooooo
o`1:ooooo`03o`000?oooooooooo07Wooooo001Kooooo`;o0000@_ooool00ol0003oooooooooo`19
ooooo`03o`000?oooooooooo07[ooooo001Mooooo`03o`000?oooooooooo03oooooo00?o0000oooo
ooooool0B?ooool00ol0003oooooooooo`1kooooo`00G_ooool2o`0003oooooo00?o0000oooooooo
ool0Aoooool00ol0003oooooooooo`1looooo`00H?ooool00ol0003oooooooooo`0looooo`03o`00
0?oooooooooo04Oooooo00?o0000ooooooooool0O?ooool0067ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo07gooooo001Rooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`1nooooo`00Hoooool00ol0
003oooooooooo`0iooooo`;o0000A_ooool00ol0003oooooooooo`1nooooo`00I?ooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0Ooooool006Cooooo
00?o0000ooooooooool0>?ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo07oooooo
001Uooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`20ooooo`00I_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo04?ooooo00?o0000
ooooooooool0P?ooool006Oooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`12oooo
o`03o`000?oooooooooo087ooooo001Xooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0@_ooool00ol0003oooooooooo`21ooooo`00JOooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooooooo04;ooooo00?o0000ooooooooool0POooool006[ooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo08;ooooo001Zooooo`03o`000?oooooo
oooo03;ooooo0_l00012ooooo`03o`000?oooooooooo08;ooooo001[ooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`22ooooo`00K?ooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0Poooool006gooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo08?ooooo
001]ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0@?ooool00ol0003ooooooooo
o`23ooooo`00K_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo043ooooo00?o0000
ooooooooool0Poooool006oooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0ooooo
o`03o`000?oooooooooo08Cooooo001`ooooo`03o`000?oooooooooo017ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0?oooool00ol0
003oooooooooo`24ooooo`00L?ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooo
oooo03oooooo00?o0000ooooooooool0Q?ooool0077ooooo00?o0000ooooooooool04?ooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo08Cooooo001booooo`03o`000?oooooooooo00oooooo00Go0000oooo
ooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0000oooooo`03o`000?oooooo
oooo08Cooooo001cooooo`03o`000?oooooooooo00kooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`24
ooooo`00M?ooool00ol0003oooooooooo`0=ooooo`05oa0@4?ooooooooooooooool@41003oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0Q?ooool0
07Cooooo00?o0000ooooooooool03Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000
okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0QOoo
ool007Gooooo00?o0000ooooooooool03?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0
QOooool007Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo08Gooooo001gooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0?_ooool0
0ol0003oooooooooo`25ooooo`00N?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool0QOooool007Sooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`0nooooo`03o`000?oooooooooo08Gooooo001iooooo`03o`000?oooooooooo02?ooooo
0_l0000oooooo`03o`000?oooooooooo08Gooooo001jooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`25ooooo`00N_ooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0Q_ooool007_ooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo08Kooooo001looooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`26ooooo`00
O?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0
Q_ooool007gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0mooooo`03o`000?oo
oooooooo08Kooooo001mooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0??ooool0
0ol0003oooooooooo`27ooooo`00O_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
03cooooo00?o0000ooooooooool0Qoooool007oooooo00?o0000ooooooooool07Oooool2o`0003go
oooo00?o0000ooooooooool0Qoooool007oooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0looooo`03o`000?oooooooooo08Oooooo0020ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool0??ooool00ol0003oooooooooo`27ooooo`00POooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0Qoooool0087ooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo08Oooooo0022ooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`27ooooo`00
P_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0
Qoooool008?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0looooo`03o`000?oo
oooooooo08Oooooo0024ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0??ooool0
0ol0003oooooooooo`27ooooo`00Q?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
03cooooo00?o0000ooooooooool0Qoooool008Gooooo00?o0000ooooooooool05oooool2o`0003go
oooo00?o0000ooooooooool0Qoooool008Gooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0looooo`03o`000?oooooooooo08Oooooo0026ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool0??ooool00ol0003oooooooooo`27ooooo`00Qoooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0Qoooool008Oooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo08Oooooo0028ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`27ooooo`00
R?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0
Qoooool008Cooooo00Kok^k^oc8b<_l0003o<S8bonk^k_l00004ooooo`;o8B4Q1_ooool2o`000003
oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`27ooooo`00
Q?ooool01_mgMgOoV9RHoooooonHV9SoMgMgo`0000Cooooo0_lQ8B47ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`27ooooo`00Q?ooool01ol@413o
oooooooooooooooo410@ooooool000002Oooool5o`0000Kooooo0ol0000looooo`03o`000?oooooo
oooo08Oooooo0024ooooo`07o`000?ooooooooooooooool0003oooooo`000009ooooo`04odA4A?oM
gMgoooooo`0000Oooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`27ooooo`00Q?oo
ool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool01_ooool01?oMgMgoEEEE
ooooool00007ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0R?ooool008Cooooo
00Go410@oooooooooooooooooa0@4003ooooo`03o`000?oooooooooo00Kooooo00?oMgMgolc<c?l0
00001oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo08Sooooo0024ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool00ol0003oooooooooo`06ooooo`03onk^k_m4A4Co000000Oo
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`28ooooo`00Q?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Cooooo00?o0000ooooooooool01_ooool00omgMgOo0000ooooo`06ooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0R?ooool008gooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo08Sooooo002>ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`28ooooo`00S_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0R?ooool0
08oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
08Sooooo002?ooooo`03o`000?oooooooooo00gooooo0_l0000looooo`03o`000?oooooooooo08So
oooo002@ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`28ooooo`00TOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0R?ooool0097ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo08Sooooo002Booooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`28ooooo`00T_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0R?ooool009?ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo08Sooooo002Dooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`28ooooo`00U?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0R?ooool0
09Gooooo00?o0000ooooooooool01oooool2o`0003cooooo00?o0000ooooooooool0R?ooool009Go
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo08So
oooo002Fooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`28ooooo`00Uoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0R?ooool009Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo08Sooooo002Hooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`28ooooo`00V?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0R?ooool009Wooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo08Sooooo002Iooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`28ooooo`00V_ooool0
0ol0003oooooooooo`02ooooo`;o0000??ooool00ol0003oooooooooo`28ooooo`00Voooool01Ol0
003ooooooooooooooooo000003gooooo00?o0000ooooooooool0R?ooool009_ooooo00Go0000oooo
ooooooooooooo`00000mooooo`03o`000?oooooooooo08Sooooo002Looooo`04o`000?oooooooooo
o`0003gooooo00?o0000ooooooooool0R?ooool009cooooo00Co0000oooooooooooo0000?Oooool0
0ol0003oooooooooo`28ooooo`00WOooool00ol0003oooooo`00000mooooo`03o`000?oooooooooo
08Sooooo002Mooooo`03o`000?oooooo000003gooooo00?o0000ooooooooool0R?ooool008Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
00Gooooo0_l0000mooooo`03o`000?oooooooooo08Sooooo0024ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@05ooooo`;o0000?Oooool0
0ol0003oooooooooo`28ooooo`00Q?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0R?oo
ool008Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40
1_ooool3o`0003_ooooo00?o0000ooooooooool0R?ooool008Cooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool2o`0003cooooo00?o0000oooooooo
ool0R?ooool008Cooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00So
oooo00?o0000ooooool00000>oooool00ol0003oooooooooo`28ooooo`00Q?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooo`00000kooooo`03
o`000?oooooooooo08Sooooo0024ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<co
A4A4o`000?l@4106ooooo`04o`000?ooooooooooo`0003[ooooo00?o0000ooooooooool0R?ooool0
09oooooo00Co0000oooooooooooo0000>_ooool00ol0003oooooooooo`28ooooo`00Woooool01Ol0
003ooooooooooooooooo000003Wooooo00?o0000ooooooooool0R?ooool009oooooo00Go0000oooo
ooooooooooooo`00000iooooo`03o`000?oooooooooo08Sooooo002Oooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`28ooooo`00Woooool2o`0000?o
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`28ooooo`00Woooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0R?ooool009oooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo08Oooooo002O
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`27
ooooo`00Woooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Gooooo00?o0000oooo
ooooool0Qoooool009oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo08Oooooo002Oooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`27ooooo`00Woooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool0Qoooool009oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo08Oooooo002Oooooo`;o00002?ooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo08Oooooo002Oooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`27ooooo`00Woooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0Qoooool009oooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo08Oooooo002O
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`27
ooooo`00Woooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02oooooo00?o0000oooo
ooooool0Qoooool009oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo08Oooooo002Oooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`27ooooo`00Woooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo02cooooo00?o0000ooooooooool0R?ooool009oooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0/ooooo`03o`000?oooooooooo08Sooooo002Oooooo`;o00003_ooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo08Sooooo002Oooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`28ooooo`00Woooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0R?ooool009oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo08Sooooo002O
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`28
ooooo`00Woooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool0R?ooool009oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo08Sooooo0024ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`28ooooo`00Q?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0R?ooool008Cooooo00Go410@oooo
oooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`0001;ooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`28ooooo`00Q?ooool01Ol0003ooooooooooooo
oooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`28ooooo`00Q?ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`28ooooo`00Q?ooool01Ol@413ooooo
oooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`28ooooo`00Q?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`28ooooo`00Q?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`28ooooo`00Woooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0R?ooool0
09oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
08Sooooo002Oooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`28ooooo`00Woooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool0R?ooool009oooooo0_l0000Iooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool0R?ooool009oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo08Sooooo002Oooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`28ooooo`00Woooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool0R?ooool009oooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo08Sooooo002Oooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`28ooooo`00Woooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0R?ooool0
09oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
08Wooooo002Oooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`29ooooo`00Woooool2o`0001oooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`29ooooo`00Woooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool0ROooool009oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo08Wooooo002Oooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`29ooooo`00Woooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool0ROooool009oooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo08Wooooo002Oooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2:ooooo`00Woooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0R_ooool0
09oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
08[ooooo002Oooooo`;o00009_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo08[o
oooo002Oooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`2;ooooo`00Woooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool0Roooool009oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo08_ooooo002Oooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`2<ooooo`00Woooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0S?ooool009oooooo00?o0000ooooooooool0
:_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo08gooooo002Eooooo`Co000000?o
410@ooooooooool00oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0SOooool009Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0/
ooooo`;o00001_ooool2o`00093ooooo002Gooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0;_ooool3o`000003ooooool0003o000009;ooooo002Gooooo`03o`000?oooooooooo00Go
oooo0ol0000aooooo`03o`000?oooooooooo09;ooooo002Gooooo`03o`000?oooooooooo0<kooooo
002Gooooo`03o`000?oooooooooo0<kooooo002Gooooo`03o`000?oooooooooo0<kooooo002Eoooo
o`03oeEEEOmVIVKo00000=3ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002T
ooooo`05oiRHV?l0003o0000odA4A?nj^[X02_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ
8B44ooooo`Go0000XOooool00:Cooooo00Go410@okZj^_o^k^koMgMgoa0@4002ooooo`Ko00001?oo
ool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A40:7ooooo
002Tooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^
kP2Rooooo`00Y?ooool00ol0003oooooooooo`04ooooo`Ko00001?ooool00ol0003oooooooooo`0<
ooooo`03oiRHV?lQ8B7ok^k^0:7ooooo002Tooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00omgMgOoIVIVooooo`2Pooooo`00X_ooool00ol@413o0000o`000003o`0000go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2Oooooo`00Y?ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@402Qooooo`00
Y?ooool00ol0003oooooooooo`0<ooooo`03oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c02Qooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.68406, -0.0802184, \
0.0288357, 0.00666531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.428571 0.142857 0 0.618034 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.14286 -0.0125 -6 -9 ]
[.14286 -0.0125 6 0 ]
[.28571 -0.0125 -6 -9 ]
[.28571 -0.0125 6 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.41607 .12361 -18 -4.5 ]
[.41607 .12361 0 4.5 ]
[.41607 .24721 -18 -4.5 ]
[.41607 .24721 0 4.5 ]
[.41607 .37082 -18 -4.5 ]
[.41607 .37082 0 4.5 ]
[.41607 .49443 -18 -4.5 ]
[.41607 .49443 0 4.5 ]
[.41607 .61803 -6 -4.5 ]
[.41607 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-3)] 0 -0.0125 0 1 Mshowa
.14286 0 m
.14286 .00625 L
s
[(-2)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(-1)] .28571 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(1)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(2)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(3)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.42857 .12361 m
.43482 .12361 L
s
[(0.2)] .41607 .12361 1 0 Mshowa
.42857 .24721 m
.43482 .24721 L
s
[(0.4)] .41607 .24721 1 0 Mshowa
.42857 .37082 m
.43482 .37082 L
s
[(0.6)] .41607 .37082 1 0 Mshowa
.42857 .49443 m
.43482 .49443 L
s
[(0.8)] .41607 .49443 1 0 Mshowa
.42857 .61803 m
.43482 .61803 L
s
[(1)] .41607 .61803 1 0 Mshowa
.125 Mabswid
.42857 .0309 m
.43232 .0309 L
s
.42857 .0618 m
.43232 .0618 L
s
.42857 .09271 m
.43232 .09271 L
s
.42857 .15451 m
.43232 .15451 L
s
.42857 .18541 m
.43232 .18541 L
s
.42857 .21631 m
.43232 .21631 L
s
.42857 .27812 m
.43232 .27812 L
s
.42857 .30902 m
.43232 .30902 L
s
.42857 .33992 m
.43232 .33992 L
s
.42857 .40172 m
.43232 .40172 L
s
.42857 .43262 m
.43232 .43262 L
s
.42857 .46353 m
.43232 .46353 L
s
.42857 .52533 m
.43232 .52533 L
s
.42857 .55623 m
.43232 .55623 L
s
.42857 .58713 m
.43232 .58713 L
s
.25 Mabswid
.42857 0 m
.42857 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
2e-05 8e-05 m
.01433 .00014 L
.02865 .00024 L
.04299 .00042 L
.05737 .00072 L
.07181 .00119 L
.08634 .00195 L
.10101 .00312 L
.11587 .00489 L
.131 .00751 L
.14652 .01132 L
.16255 .01672 L
.17926 .0242 L
.19683 .03435 L
.21546 .04778 L
.23537 .06514 L
.25674 .08706 L
.27976 .11404 L
.30453 .14643 L
.33107 .1843 L
.35929 .22736 L
.38897 .27494 L
.41974 .32588 L
.4511 .37862 L
.48239 .43119 L
.5129 .48133 L
.54186 .52665 L
.5685 .56484 L
.59216 .5938 L
.6123 .61188 L
.62857 .61803 L
.64087 .61188 L
.6493 .5938 L
.65421 .56484 L
.65614 .52665 L
.65576 .48133 L
.65382 .43119 L
.6511 .37862 L
.64832 .32588 L
.64611 .27494 L
.645 .22736 L
.64535 .1843 L
.64739 .14643 L
.65119 .11404 L
.65674 .08706 L
.66394 .06514 L
.6726 .04778 L
.68254 .03435 L
.69355 .0242 L
.70541 .01672 L
Mistroke
.71795 .01132 L
.731 .00751 L
.74444 .00489 L
.75815 .00312 L
.77206 .00195 L
.7861 .00119 L
.80023 .00072 L
.81442 .00042 L
.82865 .00024 L
.8429 .00014 L
.85717 8e-05 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`007_ooool01OnHV9So410@o`000?lb<S;oc<c<02Oooooo1Ol0000Woooo
o`Co000000?o410@ooooooooool0C?ooool4o`000003oa0@4?oooooooooo02?ooooo1Ol0000Voooo
o`05oiRHV?l@413o0000oc8b<_o<c<`0:Oooool2o`000003oa0@4?oooooooooo01Oooooo000Noooo
o`05oa0@4?nj^[[oooooogMgMolb<S809oooool01OnHV9So8B4Qonk^k_ooooooA4A402Wooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
9_ooool01Ol@413o^[ZjoooooomgMgOo<S8b02[ooooo00?o0000ooooooooool06?ooool001Kooooo
1_l00006ooooo`03o`000?oooooooooo01gooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^01oooooo
1_l00005ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09_ooool00onHV9So8B4Q
onk^kP0[ooooo`03o`000?oooooooooo02Gooooo1Ol0000Iooooo`008Oooool00onYZJWo410@oooo
o`0Xooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Wooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?oZJVYoa0@4?ooool09_ooool01?m4A4CogMgMoooo
ool0000Jooooo`008?ooool00ol@413o0000okZj^P0Zooooo`03ogMgMomVIVKooooo02Sooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Xooooo`03ogMgMomVIVKooooo02Oooooo00?o
410@o`000?nj^[X09oooool01?oMgMgoEEEEooooool0000Jooooo`008Oooool00onj^[[o8B4Qoooo
o`0Zooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo02Oooooo00?o^[Zjob4Q8Oooool09oooool00omgMgOoc<c<o`00
000Jooooo`007_ooool01Ol@413oV9RHoooooonj^[[o000002Oooooo00Go0000okZj^_ooooooV9RH
oa0@400Yooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09Oooool01Ol0003o^[Zj
oooooonHV9So410@02Kooooo00Go410@oiRHV?oooooo^[Zjo`00000Xooooo`03onk^k_m4A4Co0000
01[ooooo000Nooooo`05ojVYZOl@413o0000oa0@4?nYZJT09oooool01OnHV9So410@o`000?lQ8B7o
c<c<02Oooooo00?oEEEEofIVI_l00000D?ooool00omEEEGoIVIVo`00000Wooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`09_ooool01OnYZJWo410@o`000?l@413oZJVY02Wooooo00?oMgMgo`000?ooool0
6Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool001goooooool0000bo`0001[ooooo000Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool01?l0003oooooooooooooool=o`000003ooooool0003ooooo00Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooool000003?l00002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06?oo
ool001gooooo00?o0000ooooooooool07oooool8o`0000;ooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:?ooool0
1?l0003oooooooooooooool7o`00023ooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0Hooooo`00Aoooool3o`0005Gooooo00?o0000ooooooooool0E_ooool2o`0006kooooo001:oooo
o`?o0000D_ooool00ol0003oooooooooo`1Cooooo`?o0000L?ooool004gooooo0ol0001?ooooo`03
o`000?oooooooooo057ooooo0_l0001cooooo`00D?ooool2o`0004gooooo00?o0000ooooooooool0
D?ooool00ol0003oooooooooo`1cooooo`00D_ooool2o`0004_ooooo00?o0000ooooooooool0Cooo
ool00ol0003oooooooooo`1dooooo`00E?ooool2o`0004Wooooo00?o0000ooooooooool0COooool2
o`0007Oooooo001Fooooo`;o0000Aoooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo
07Oooooo001Hooooo`03o`000?oooooooooo04Cooooo0_l0001<ooooo`03o`000?oooooooooo07So
oooo001Iooooo`;o0000A?ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo07Wooooo
001Kooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0B_ooool00ol0003ooooooooo
o`1iooooo`00G?ooool2o`00047ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`1j
ooooo`00G_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo04Sooooo00?o0000oooo
ooooool0Noooool005oooooo0_l0000nooooo`03o`000?oooooooooo04Oooooo00?o0000oooooooo
ool0O?ooool0067ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`17ooooo`03o`00
0?oooooooooo07cooooo001Rooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0A_oo
ool00ol0003oooooooooo`1mooooo`00Hoooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo04Kooooo00?o0000ooooooooool0OOooool006Cooooo00?o0000ooooooooool0>?ooool2o`00
04Oooooo00?o0000ooooooooool0OOooool006Gooooo00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`15ooooo`03o`000?oooooooooo07kooooo001Uooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`1nooooo`00I_ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0Ooooool006Oooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo07oooooo001Xoooo
o`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`20oooo
o`00JOooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo04?ooooo00?o0000oooooooo
ool0P?ooool006[ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`13ooooo`03o`00
0?oooooooooo083ooooo001[ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0@_oo
ool00ol0003oooooooooo`21ooooo`00Joooool00ol0003oooooooooo`0aooooo`;o0000@oooool0
0ol0003oooooooooo`21ooooo`00K?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
04;ooooo00?o0000ooooooooool0POooool006gooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`12ooooo`03o`000?oooooooooo087ooooo001^ooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool0@_ooool00ol0003oooooooooo`21ooooo`00Koooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0P_ooool0073ooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo08;ooooo001aoooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`22oooo
o`00L_ooool00ol0003oooooooooo`0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo1Ol00006ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0P_ooool007;o
oooo00?o0000ooooooooool03oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooo
oooo08;ooooo001cooooo`03o`000?oooooooooo00kooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`22
ooooo`00M?ooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool000003Oooool0
0onHV9So8B4Qonk^kP06ooooo`?o0000@Oooool00ol0003oooooooooo`22ooooo`00MOooool00ol0
003oooooooooo`0<ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05
ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0P_ooool007Kooooo00?o0000oooo
ooooool02oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`11ooooo`03o`000?oooooooooo08;ooooo001fooooo`03o`000?oooooooooo
00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_oo
ool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo08?ooooo001gooooo`03o`000?oooooo
oooo00[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
1_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo08?ooooo001hooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`23ooooo`00NOooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0Poooool0
07[ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo
08?ooooo001jooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0@?ooool00ol0003o
ooooooooo`23ooooo`00Noooool00ol0003oooooooooo`0Qooooo`;o0000@Oooool00ol0003ooooo
ooooo`23ooooo`00O?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo043ooooo00?o
0000ooooooooool0Poooool007gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`10
ooooo`03o`000?oooooooooo08?ooooo001mooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool0@?ooool00ol0003oooooooooo`23ooooo`00O_ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0Q?ooool007oooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo08Cooooo001oooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`24ooooo`00P?ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0Q?ooool0
087ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
08Cooooo0022ooooo`03o`000?oooooooooo01[ooooo0_l00010ooooo`03o`000?oooooooooo08Co
oooo0022ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`24ooooo`00Poooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool0Q?ooool008Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo08Cooooo0024ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`24ooooo`00QOooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0Q?ooool008Gooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo08Cooooo0026ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`24ooooo`00Qoooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0Q?ooool0
08Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
08Cooooo0028ooooo`03o`000?oooooooooo01Cooooo0_l00010ooooo`03o`000?oooooooooo08Co
oooo0028ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`24ooooo`00ROooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool0Q?ooool008[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo08Cooooo002:ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`24ooooo`00Roooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0Q?ooool008cooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo08Cooooo0024ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool01?l0003oooooob4Q8OlQ8B46ooooo`;o000000?o410@oooooooo
ool01?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo08Cooooo0024ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01?ooool00ol0003o8B4Qob4Q8@07ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`24ooooo`00Q?ooool01Ol@413ooooo
oooooooooooo410@00Cooooo00?o0000ooooooooool01?ooool5o`0000Kooooo0ol0000oooooo`03
o`000?oooooooooo08Cooooo0024ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003o
ooooooooo`03ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0?oooool00ol0
003oooooooooo`24ooooo`00Q?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool00_ooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo03oooooo00?o0000
ooooooooool0Q?ooool008Cooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooo
oooo00?ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0oooooo`03o`000?oooooo
oooo08Cooooo0024ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01oooool00ol0003oooooooooo`02
ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`24
ooooo`00Q?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00?o0000ooooooooool00oooool0
0omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0Q?ooool0
097ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
08Cooooo002Booooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0?oooool00ol0003o
ooooooooo`24ooooo`00T_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03oooooo
00?o0000ooooooooool0Q?ooool009?ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0oooooo`03o`000?oooooooooo08Cooooo002Cooooo`03o`000?oooooooooo00Wooooo0_l00010
ooooo`03o`000?oooooooooo08Cooooo002Dooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`24ooooo`00UOooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0Q?ooool009Gooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo08Cooooo002Fooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`24ooooo`00Uoooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0Q?ooool0
09Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
08Cooooo002Hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0@?ooool00ol0003o
ooooooooo`23ooooo`00VOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo043ooooo
00?o0000ooooooooool0Poooool009Wooooo00?o0000ooooooooool00oooool2o`00047ooooo00?o
0000ooooooooool0Poooool009[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`10
ooooo`03o`000?oooooooooo08?ooooo002Kooooo`05o`000?ooooooooooooooool00000@_ooool0
0ol0003oooooooooo`23ooooo`00Voooool01Ol0003ooooooooooooooooo000004;ooooo00?o0000
ooooooooool0Poooool009cooooo00Co0000oooooooooooo0000@_ooool00ol0003oooooooooo`23
ooooo`00WOooool00ol0003oooooo`000012ooooo`03o`000?oooooooooo08?ooooo002Mooooo`03
o`000?oooooo000004;ooooo00?o0000ooooooooool0Poooool009kooooo0_l00012ooooo`03o`00
0?oooooooooo08?ooooo002Nooooo`;o0000@_ooool00ol0003oooooooooo`23ooooo`00Woooool2
o`00047ooooo00?o0000ooooooooool0Poooool009oooooo0_l00011ooooo`03o`000?oooooooooo
08?ooooo002Oooooo`;o0000@Oooool00ol0003oooooooooo`23ooooo`00Woooool00ol0003ooooo
o`000010ooooo`03o`000?oooooooooo08?ooooo002Oooooo`03o`000?oooooo0000043ooooo00?o
0000ooooooooool0Poooool009oooooo00Co0000oooooooooooo0000@?ooool00ol0003ooooooooo
o`22ooooo`00Woooool01?l0003oooooooooool00010ooooo`03o`000?oooooooooo08;ooooo0024
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@
olc<c006ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`22ooooo`00
Q?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRH
V?lQ8B401_ooool01Ol0003ooooooooooooooooo000003oooooo00?o0000ooooooooool0P_ooool0
08Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0P_oo
ool008Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40
1_ooool3o`0000?ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`22ooooo`00Q?oo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`22ooooo`00
Q?ooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0P_ooool008Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo08;ooooo0024ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`22ooooo`00Woooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0P_ooool009oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo08;ooooo
002Oooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0=oooool00ol0003ooooooooo
o`22ooooo`00Woooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Oooooo00?o0000
ooooooooool0P_ooool009oooooo0_l00009ooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool0P_ooool009oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo08;ooooo002Oooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`21ooooo`00Woooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool0POooool009oooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0dooooo`03o`000?oooooooooo087ooooo002Oooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`21ooooo`00Woooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0POooool009oooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo087ooooo
002Oooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0<_ooool00ol0003ooooooooo
o`21ooooo`00Woooool2o`0000oooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`21
ooooo`00Woooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool0POooool009oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo087ooooo002Oooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`21ooooo`00Woooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool0POooool009oooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo087ooooo002Oooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`21ooooo`00Woooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0POooool009oooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo087ooooo
002Oooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`21ooooo`00Woooool2o`0001Gooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`21
ooooo`00Woooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool0POooool009oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo087ooooo002Oooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`21ooooo`00Woooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool0POooool009oooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo087ooooo002Oooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`21ooooo`00Q?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0POooool0
08Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonH
V9So8B4Q00Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo087ooooo0024ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000000Kooooo0ol0000Iooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
POooool008Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb
<S801_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0POooool008Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`00
0?o<c<`01_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool0POooool008Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooo
okZj^_l@41001_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool0POooool008Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooookZj^_l000001_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool0POooool008Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@
413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool0POooool009oooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo087ooooo002Oooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`21ooooo`00Woooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool0POooool009oooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo087ooooo002Oooooo`;o0000
8Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo087ooooo002Oooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`21ooooo`00Woooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0POooool0
09oooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
087ooooo002Oooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`21ooooo`00Woooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool0POooool009oooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo087ooooo002Oooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`21ooooo`00Woooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0POooool009oooooo0_l0000Wooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool0POooool009oooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo087ooooo002Oooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`21ooooo`00Woooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0POooool0
09oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
087ooooo002Oooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`21ooooo`00Woooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0P_ooool009oooooo00?o0000ooooooooool0:oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo08;ooooo002Oooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`22ooooo`00Woooool2o`0002kooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`22ooooo`00Woooool00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0Poooool009oooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo08?ooooo002Oooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`23ooooo`00Woooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Q?ooool0
09oooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
08Cooooo002Oooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`24ooooo`00UOooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo08Gooooo002Gooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0=Oooool2o`0000Kooooo0_l00027ooooo`00Uoooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Oooooo0ol000000ooooooo0000o`000029
ooooo`00Uoooool00ol0003oooooooooo`05ooooo`?o0000>_ooool00ol0003oooooooooo`29oooo
o`00Uoooool00ol0003oooooooooo`3>ooooo`00Uoooool00ol0003oooooooooo`3>ooooo`00Uooo
ool00ol0003oooooooooo`3>ooooo`00UOooool00omEEEGoIVIVo`00003@ooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00Y?ooool01OnHV9So0000o`000?m4A4Co^[Zj00[ooooo
1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo09oooooo
002Tooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool6o`0000Cooooo00?o0000ooooooooool0
1?ooool2ob4Q8@Oooooo00?o0000ooooooooool0X?ooool00:Cooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0:ooooo`Go0000XOooool00:Cooooo00?o0000ooooooooool01?ooool6
o`0000Cooooo00?o0000ooooooooool02_ooool01?m4A4CogMgMooooool0002Rooooo`00Y?ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00[ooooo00CogMgMoeEEEOoooooo0000X_oo
ool00:;ooooo00?o410@o`000?l000000ol0000=ooooo`03o`000?oooooooooo00_ooooo00?oMgMg
olc<c?l00000X_ooool00:Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0;oooo
o`03onk^k_m4A4Co00000:;ooooo002Tooooo`03o`000?oooooooooo00cooooo00?oEEEEofIVI_l0
00003_ooool00omgMgOo0000ooooo`2Qooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.68406, -0.0802184, \
0.0288357, 0.00666531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.428571 0.142857 0 0.618034 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.14286 -0.0125 -6 -9 ]
[.14286 -0.0125 6 0 ]
[.28571 -0.0125 -6 -9 ]
[.28571 -0.0125 6 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.41607 .12361 -18 -4.5 ]
[.41607 .12361 0 4.5 ]
[.41607 .24721 -18 -4.5 ]
[.41607 .24721 0 4.5 ]
[.41607 .37082 -18 -4.5 ]
[.41607 .37082 0 4.5 ]
[.41607 .49443 -18 -4.5 ]
[.41607 .49443 0 4.5 ]
[.41607 .61803 -6 -4.5 ]
[.41607 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-3)] 0 -0.0125 0 1 Mshowa
.14286 0 m
.14286 .00625 L
s
[(-2)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(-1)] .28571 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(1)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(2)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(3)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.42857 .12361 m
.43482 .12361 L
s
[(0.2)] .41607 .12361 1 0 Mshowa
.42857 .24721 m
.43482 .24721 L
s
[(0.4)] .41607 .24721 1 0 Mshowa
.42857 .37082 m
.43482 .37082 L
s
[(0.6)] .41607 .37082 1 0 Mshowa
.42857 .49443 m
.43482 .49443 L
s
[(0.8)] .41607 .49443 1 0 Mshowa
.42857 .61803 m
.43482 .61803 L
s
[(1)] .41607 .61803 1 0 Mshowa
.125 Mabswid
.42857 .0309 m
.43232 .0309 L
s
.42857 .0618 m
.43232 .0618 L
s
.42857 .09271 m
.43232 .09271 L
s
.42857 .15451 m
.43232 .15451 L
s
.42857 .18541 m
.43232 .18541 L
s
.42857 .21631 m
.43232 .21631 L
s
.42857 .27812 m
.43232 .27812 L
s
.42857 .30902 m
.43232 .30902 L
s
.42857 .33992 m
.43232 .33992 L
s
.42857 .40172 m
.43232 .40172 L
s
.42857 .43262 m
.43232 .43262 L
s
.42857 .46353 m
.43232 .46353 L
s
.42857 .52533 m
.43232 .52533 L
s
.42857 .55623 m
.43232 .55623 L
s
.42857 .58713 m
.43232 .58713 L
s
.25 Mabswid
.42857 0 m
.42857 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
3e-05 8e-05 m
.01434 .00014 L
.02866 .00024 L
.04301 .00042 L
.05741 .00072 L
.07187 .00119 L
.08643 .00195 L
.10115 .00312 L
.11609 .00489 L
.13135 .00751 L
.14704 .01132 L
.16333 .01672 L
.18038 .0242 L
.19842 .03435 L
.21767 .04778 L
.23838 .06514 L
.26077 .08706 L
.28503 .11404 L
.3113 .14643 L
.33959 .1843 L
.3698 .22736 L
.40168 .27494 L
.43481 .32588 L
.4686 .37862 L
.50233 .43119 L
.53515 .48133 L
.5662 .52665 L
.59461 .56484 L
.61961 .5938 L
.64058 .61188 L
.65714 .61803 L
.66915 .61188 L
.67675 .5938 L
.68033 .56484 L
.68049 .52665 L
.67801 .48133 L
.67375 .43119 L
.6686 .37862 L
.66338 .32588 L
.65882 .27494 L
.65552 .22736 L
.65387 .1843 L
.65415 .14643 L
.65646 .11404 L
.66077 .08706 L
.66695 .06514 L
.67481 .04778 L
.68413 .03435 L
.69467 .0242 L
.70618 .01672 L
Mistroke
.71847 .01132 L
.73135 .00751 L
.74466 .00489 L
.7583 .00312 L
.77215 .00195 L
.78616 .00119 L
.80026 .00072 L
.81444 .00042 L
.82866 .00024 L
.84291 .00014 L
.85717 8e-05 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`007_ooool01OnHV9So410@o`000?lb<S;oc<c<02Oooooo1Ol0000Woooo
o`Co000000?o410@ooooooooool0C?ooool4o`000003oa0@4?oooooooooo02?ooooo1Ol0000Voooo
o`05oiRHV?l@413o0000oc8b<_o<c<`0:Oooool2o`000003oa0@4?oooooooooo01Oooooo000Noooo
o`05oa0@4?nj^[[oooooogMgMolb<S809oooool01OnHV9So8B4Qonk^k_ooooooA4A402Wooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
9_ooool01Ol@413o^[ZjoooooomgMgOo<S8b02[ooooo00?o0000ooooooooool06?ooool001Kooooo
1_l00006ooooo`03o`000?oooooooooo01gooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^01oooooo
1_l00005ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09_ooool00onHV9So8B4Q
onk^kP0[ooooo`03o`000?oooooooooo02Gooooo1Ol0000Iooooo`008Oooool00onYZJWo410@oooo
o`0Xooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Wooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?oZJVYoa0@4?ooool09_ooool01?m4A4CogMgMoooo
ool0000Jooooo`008?ooool00ol@413o0000okZj^P0Zooooo`03ogMgMomVIVKooooo02Sooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Xooooo`03ogMgMomVIVKooooo02Oooooo00?o
410@o`000?nj^[X09oooool01?oMgMgoEEEEooooool0000Jooooo`008Oooool00onj^[[o8B4Qoooo
o`0Zooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo02Oooooo00?o^[Zjob4Q8Oooool09oooool00omgMgOoc<c<o`00
000Jooooo`007_ooool01Ol@413oV9RHoooooonj^[[o000002Oooooo00Go0000okZj^_ooooooV9RH
oa0@400Yooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09Oooool01Ol0003o^[Zj
oooooonHV9So410@02Kooooo00Go410@oiRHV?oooooo^[Zjo`00000Xooooo`03onk^k_m4A4Co0000
01[ooooo000Nooooo`05ojVYZOl@413o0000oa0@4?nYZJT09oooool01OnHV9So410@o`000?lQ8B7o
c<c<02Oooooo00?oEEEEofIVI_l00000D?ooool00omEEEGoIVIVo`00000Wooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`09_ooool01OnYZJWo410@o`000?l@413oZJVY02Wooooo00?oMgMgo`000?ooool0
6Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool001goooooool0000bo`0001[ooooo000Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool01?l0003oooooooooooooool=o`000003ooooool0003ooooo00Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooool000003?l00002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06?oo
ool001gooooo00?o0000ooooooooool07oooool8o`0000;ooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:?ooool0
1?l0003oooooooooooooool7o`00023ooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0Hooooo`00Aoooool3o`0005Gooooo00?o0000ooooooooool0E_ooool2o`0006kooooo001:oooo
o`Co0000DOooool00ol0003oooooooooo`1Cooooo`?o0000L?ooool004kooooo0ol0001>ooooo`03
o`000?oooooooooo057ooooo0_l0001cooooo`00DOooool2o`0004cooooo00?o0000ooooooooool0
D?ooool00ol0003oooooooooo`1cooooo`00Doooool00ol0003oooooooooo`19ooooo`03o`000?oo
oooooooo04oooooo00?o0000ooooooooool0M?ooool005Cooooo0_l00019ooooo`03o`000?oooooo
oooo04kooooo00?o0000ooooooooool0MOooool005Kooooo0_l00017ooooo`03o`000?oooooooooo
04gooooo00?o0000ooooooooool0M_ooool005Sooooo00?o0000ooooooooool0A?ooool2o`0004go
oooo00?o0000ooooooooool0Moooool005Wooooo0_l00014ooooo`03o`000?oooooooooo04_ooooo
00?o0000ooooooooool0N?ooool005_ooooo00?o0000ooooooooool0@Oooool00ol0003ooooooooo
o`1;ooooo`03o`000?oooooooooo07Sooooo001Looooo`;o0000@Oooool00ol0003oooooooooo`1:
ooooo`03o`000?oooooooooo07Wooooo001Nooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool0BOooool00ol0003oooooooooo`1jooooo`00Goooool2o`0003kooooo00?o0000oooooooo
ool0B?ooool00ol0003oooooooooo`1kooooo`00HOooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo04Sooooo00?o0000ooooooooool0Noooool006;ooooo00?o0000ooooooooool0>_oo
ool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo07cooooo001Sooooo`03o`000?oooooo
oooo03Wooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1looooo`00I?ooool00ol0
003oooooooooo`0hooooo`;o0000B?ooool00ol0003oooooooooo`1looooo`00IOooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0OOooool006Kooooo
00?o0000ooooooooool0=_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo07gooooo
001Wooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0A_ooool00ol0003ooooooooo
o`1mooooo`00J?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo04Gooooo00?o0000
ooooooooool0O_ooool006Wooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`15oooo
o`03o`000?oooooooooo07kooooo001Zooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool0AOooool00ol0003oooooooooo`1nooooo`00Joooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo04Cooooo00?o0000ooooooooool0Ooooool006cooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo07oooooo001]ooooo`03o`000?oooooo
oooo02oooooo0_l00015ooooo`03o`000?oooooooooo07oooooo001^ooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`1oooooo`00Koooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0P?ooool0073ooooo
00?o0000ooooooooool0;?ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo083ooooo
001aooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`20ooooo`00L_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo04?ooooo00?o0000
ooooooooool0P?ooool007?ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`12oooo
o`03o`000?oooooooooo087ooooo001dooooo`03o`000?oooooooooo00gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0@_ooool00ol0
003oooooooooo`21ooooo`00M?ooool00ol0003oooooooooo`0=ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooo
oooo04;ooooo00?o0000ooooooooool0POooool007Gooooo00?o0000ooooooooool03?ooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`12
ooooo`03o`000?oooooooooo087ooooo001fooooo`03o`000?oooooooooo00_ooooo00Go0000oooo
ooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol00012ooooo`03o`000?oooooo
oooo087ooooo001gooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`21
ooooo`00N?ooool00ol0003oooooooooo`09ooooo`05oa0@4?ooooooooooooooool@41003oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0POooool0
07Sooooo00?o0000ooooooooool02Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000
okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0POoo
ool007Wooooo00?o0000ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0
POooool007[ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`12ooooo`03o`000?oo
oooooooo087ooooo001kooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0@_ooool0
0ol0003oooooooooo`21ooooo`00O?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
04;ooooo00?o0000ooooooooool0POooool007cooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`12ooooo`03o`000?oooooooooo087ooooo001mooooo`03o`000?oooooooooo01oooooo
0_l00013ooooo`03o`000?oooooooooo087ooooo001nooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool0@_ooool00ol0003oooooooooo`21ooooo`00Ooooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0POooool007oooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo087ooooo0020ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`21ooooo`00
POooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0
POooool0087ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`12ooooo`03o`000?oo
oooooooo087ooooo0022ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0@_ooool0
0ol0003oooooooooo`21ooooo`00Poooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
04;ooooo00?o0000ooooooooool0POooool008Cooooo00?o0000ooooooooool06?ooool2o`0004?o
oooo00?o0000ooooooooool0POooool008Cooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`12ooooo`03o`000?oooooooooo087ooooo0025ooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool0@_ooool00ol0003oooooooooo`21ooooo`00Q_ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0POooool008Kooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo087ooooo0027ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`21ooooo`00
R?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0
POooool008Wooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`12ooooo`03o`000?oo
oooooooo087ooooo0029ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0@_ooool0
0ol0003oooooooooo`21ooooo`00R_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
04;ooooo00?o0000ooooooooool0POooool008_ooooo00?o0000ooooooooool04Oooool2o`0004?o
oooo00?o0000ooooooooool0POooool008_ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`12ooooo`03o`000?oooooooooo087ooooo002<ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0@_ooool00ol0003oooooooooo`21ooooo`00SOooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0POooool008gooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo087ooooo002>ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`21ooooo`00
Soooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0
POooool008Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03ob4Q8Ol0003ooooo00Gooooo
0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0
POooool008Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0
POooool008Cooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo00Go0000
1_ooool3o`0004;ooooo00?o0000ooooooooool0POooool008Cooooo00Go0000oooooooooooooooo
o`000008ooooo`07o`000?ooooooooooodA4A?oMgMgoooooo`000007ooooo`03o`000?oooooooooo
04;ooooo00?o0000ooooooooool0POooool008Cooooo00Go0000ooooooooooooooooo`000009oooo
o`06o`000?oooooogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`13ooooo`03o`000?oo
oooooooo083ooooo0024ooooo`05oa0@4?ooooooooooooooool@41002_ooool01Ol0003oooooogMg
Moo<c<co000000Oooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`20ooooo`00Q?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo00Go0000ooooooo^k^koA4A4o`000007ooooo`03
o`000?oooooooooo04?ooooo00?o0000ooooooooool0P?ooool008Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`04o`000?ooooooMgMgo`0000Oooooo00?o0000ooooooooool0@oooool00ol0
003oooooooooo`20ooooo`00UOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04?o
oooo00?o0000ooooooooool0P?ooool009Gooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`13ooooo`03o`000?oooooooooo083ooooo002Fooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0@oooool00ol0003oooooooooo`20ooooo`00Uoooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0P?ooool009Oooooo00?o0000oooo
ooooool01Oooool2o`0004Cooooo00?o0000ooooooooool0P?ooool009Sooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo083ooooo002Iooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`20ooooo`00VOoo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0P?oo
ool009[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooo
oooo083ooooo002Kooooo`05o`000?ooooooooooooooool00000AOooool00ol0003oooooooooo`20
ooooo`00Voooool01Ol0003ooooooooooooooooo000004Gooooo00?o0000ooooooooool0P?ooool0
09cooooo00Co0000oooooooooooo0000A_ooool00ol0003oooooooooo`1oooooo`00WOooool00ol0
003oooooo`000016ooooo`03o`000?oooooooooo07oooooo002Mooooo`04o`000?oooooo0000o`00
04Gooooo00?o0000ooooooooool0Ooooool009kooooo0_l00016ooooo`03o`000?oooooooooo07oo
oooo002Oooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0Ooooool009oooooo00?o
0000ooooooooool0A?ooool00ol0003oooooooooo`1oooooo`00Woooool2o`0004Gooooo00?o0000
ooooooooool0Ooooool009oooooo00?o0000ooooool00000A?ooool00ol0003oooooooooo`1ooooo
o`00Woooool00ol0003oooooo`000014ooooo`03o`000?oooooooooo07oooooo002Oooooo`04o`00
0?ooooooooooo`0004?ooooo00?o0000ooooooooool0Ooooool009oooooo00Go0000oooooooooooo
ooooo`000012ooooo`03o`000?oooooooooo07oooooo002Oooooo`;o00000_ooool00ol0003ooooo
ooooo`10ooooo`03o`000?oooooooooo07oooooo002Oooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0@?ooool00ol0003oooooooooo`1nooooo`00Woooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0O_ooool009oooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo07kooooo002Oooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`1nooooo`00
Woooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0
O_ooool009oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0mooooo`03o`000?oo
oooooooo07kooooo0024ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Go
k^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`1nooooo`00Q?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo03cooooo00?o0000ooooooooool0O_ooool008Cooooo00Go410@oooooooooooo
oooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo03cooooo00?o0000ooooooooool0OOooool008Cooooo00Go0000oooooooo
ooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0000Oooooo00?o0000
ooooooooool0??ooool00ol0003oooooooooo`1mooooo`00Q?ooool01Ol0003ooooooooooooooooo
000000_ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`1mooooo`00Q?ooool01Ol@413ooooooooooooo
oooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo03[ooooo00?o0000ooooooooool0OOooool008Cooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0jooooo`03o`000?oooooooooo07gooooo0024ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?oo
ool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`1mooooo`00Woooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo03Sooooo00?o0000ooooooooool0OOooool009oooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0hooooo`03o`000?oooooooooo07gooooo002Oooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1looooo`00Woooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0O?ooool009oooooo
0_l0000>ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0O?ooool009oooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo07cooooo002O
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1l
ooooo`00Woooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool0O?ooool009oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo07cooooo002Oooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
<oooool00ol0003oooooooooo`1looooo`00Woooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool0Noooool009oooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo07_ooooo002Oooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`1kooooo`00Woooool2o`0001Go
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`1kooooo`00Woooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0Noooool009oooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo07_ooooo002O
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1k
ooooo`00Woooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02oooooo00?o0000oooo
ooooool0Noooool009oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo07_ooooo002Oooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`1kooooo`00Woooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool0Noooool009oooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo07[ooooo002Oooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1jooooo`00Woooool2o`0001_o
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1jooooo`00Woooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0N_ooool009oooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo07[ooooo002O
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1j
ooooo`00Woooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool0N_ooool009oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo07[ooooo002Oooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`1jooooo`00Q?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0N_ooool008Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo07[ooooo0024ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0000P
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0N_ooool008Cooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0N_ooool008Cooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0N_ooool008Cooooo00Go
410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0N_ooool008Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0NOooool008Co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0NOooool0
09oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
07Wooooo002Oooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`1iooooo`00Woooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool0NOooool009oooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo07Wooooo002Oooooo`;o0000:?ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo07Wooooo002Oooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`1iooooo`00Woooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool0NOooool009oooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo07Wooooo002Oooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1iooooo`00Woooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0NOooool0
09oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
07Wooooo002Oooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`1iooooo`00Woooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool0NOooool009oooooo0_l0000^ooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool0NOooool009oooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo07Wooooo002Oooooo`03o`000?oooooooooo02oooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`1iooooo`00Woooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool0NOooool009oooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo07Wooooo002Oooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1iooooo`00Woooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0NOooool0
09oooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
07Wooooo002Oooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`1jooooo`00Woooool2o`0003Kooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`1jooooo`00Woooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0N_ooool009oooooo00?o0000ooooooooool0=oooool2o`00013ooooo00?o0000
ooooooooool0N_ooool009oooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo07[ooooo002Oooooo`03o`000?oooooooooo03[ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`1kooooo`00Woooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0Noooool009oooooo00?o0000ooooooooool0??oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo07cooooo002Eooooo`Co000000?o410@
ooooooooool00oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0O?ooool009Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0noooo
o`;o00001Oooool2o`0007oooooo002Gooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0@?ooool3o`000003ooooool0003ooooo083ooooo002Gooooo`03o`000?oooooooooo00Gooooo
0ol00013ooooo`03o`000?oooooooooo083ooooo002Gooooo`03o`000?oooooooooo0<kooooo002G
ooooo`03o`000?oooooooooo0<kooooo002Gooooo`03o`000?oooooooooo0<kooooo002Eooooo`03
oeEEEOmVIVKo00000=3ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Toooo
o`05oiRHV?l0003o0000odA4A?nj^[X02_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0XOooool00:Cooooo00Go410@okZj^_o^k^koMgMgoa0@
4002ooooo`Ko00001?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooo
oonHV9So8B4Q0:7ooooo002Tooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02_oo
ool01Ol0003ooooooooooooooooo00000:7ooooo002Tooooo`03o`000?oooooooooo00Cooooo1_l0
0004ooooo`03o`000?oooooooooo00[ooooo00Go0000oiRHV?ooooooV9RHob4Q8@2Qooooo`00Y?oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00[ooooo00Go0000oeEEEOl0003o410@
olc<c02Qooooo`00X_ooool00ol@413o0000o`000003o`0000gooooo00?o0000ooooooooool02_oo
ool00omEEEGoQhN7ooooo`2Sooooo`00Y?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00[ooooo00?ogMgMoa0@4?nHV9P0Xoooool00:Cooooo00?o0000ooooooooool03?ooool00omE
EEGoIVIVo`00000=ooooo`04olc<c?m4A4Co0000oa0@4:7ooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.68406, -0.0802184, \
0.0288357, 0.00666531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.428571 0.142857 0 0.618034 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.14286 -0.0125 -6 -9 ]
[.14286 -0.0125 6 0 ]
[.28571 -0.0125 -6 -9 ]
[.28571 -0.0125 6 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.41607 .12361 -18 -4.5 ]
[.41607 .12361 0 4.5 ]
[.41607 .24721 -18 -4.5 ]
[.41607 .24721 0 4.5 ]
[.41607 .37082 -18 -4.5 ]
[.41607 .37082 0 4.5 ]
[.41607 .49443 -18 -4.5 ]
[.41607 .49443 0 4.5 ]
[.41607 .61803 -6 -4.5 ]
[.41607 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-3)] 0 -0.0125 0 1 Mshowa
.14286 0 m
.14286 .00625 L
s
[(-2)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(-1)] .28571 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(1)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(2)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(3)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.42857 .12361 m
.43482 .12361 L
s
[(0.2)] .41607 .12361 1 0 Mshowa
.42857 .24721 m
.43482 .24721 L
s
[(0.4)] .41607 .24721 1 0 Mshowa
.42857 .37082 m
.43482 .37082 L
s
[(0.6)] .41607 .37082 1 0 Mshowa
.42857 .49443 m
.43482 .49443 L
s
[(0.8)] .41607 .49443 1 0 Mshowa
.42857 .61803 m
.43482 .61803 L
s
[(1)] .41607 .61803 1 0 Mshowa
.125 Mabswid
.42857 .0309 m
.43232 .0309 L
s
.42857 .0618 m
.43232 .0618 L
s
.42857 .09271 m
.43232 .09271 L
s
.42857 .15451 m
.43232 .15451 L
s
.42857 .18541 m
.43232 .18541 L
s
.42857 .21631 m
.43232 .21631 L
s
.42857 .27812 m
.43232 .27812 L
s
.42857 .30902 m
.43232 .30902 L
s
.42857 .33992 m
.43232 .33992 L
s
.42857 .40172 m
.43232 .40172 L
s
.42857 .43262 m
.43232 .43262 L
s
.42857 .46353 m
.43232 .46353 L
s
.42857 .52533 m
.43232 .52533 L
s
.42857 .55623 m
.43232 .55623 L
s
.42857 .58713 m
.43232 .58713 L
s
.25 Mabswid
.42857 0 m
.42857 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
3e-05 8e-05 m
.01434 .00014 L
.02867 .00024 L
.04303 .00042 L
.05744 .00072 L
.07192 .00119 L
.08652 .00195 L
.1013 .00312 L
.11632 .00489 L
.1317 .00751 L
.14757 .01132 L
.1641 .01672 L
.1815 .0242 L
.20001 .03435 L
.21988 .04778 L
.24139 .06514 L
.26479 .08706 L
.29031 .11404 L
.31807 .14643 L
.34811 .1843 L
.38031 .22736 L
.41439 .27494 L
.44988 .32588 L
.4861 .37862 L
.52226 .43119 L
.55741 .48133 L
.59055 .52665 L
.62073 .56484 L
.64706 .5938 L
.66887 .61188 L
.68571 .61803 L
.69744 .61188 L
.7042 .5938 L
.70644 .56484 L
.70484 .52665 L
.70026 .48133 L
.69369 .43119 L
.6861 .37862 L
.67845 .32588 L
.67153 .27494 L
.66603 .22736 L
.66239 .1843 L
.66092 .14643 L
.66173 .11404 L
.66479 .08706 L
.66996 .06514 L
.67702 .04778 L
.68572 .03435 L
.69579 .0242 L
.70696 .01672 L
Mistroke
.719 .01132 L
.7317 .00751 L
.74489 .00489 L
.75844 .00312 L
.77224 .00195 L
.78621 .00119 L
.8003 .00072 L
.81446 .00042 L
.82867 .00024 L
.84291 .00014 L
.85717 8e-05 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`007_ooool01OnHV9So410@o`000?lb<S;oc<c<02Oooooo1Ol0000Woooo
o`Co000000?o410@ooooooooool0C?ooool4o`000003oa0@4?oooooooooo02?ooooo1Ol0000Voooo
o`05oiRHV?l@413o0000oc8b<_o<c<`0:Oooool2o`000003oa0@4?oooooooooo01Oooooo000Noooo
o`05oa0@4?nj^[[oooooogMgMolb<S809oooool01OnHV9So8B4Qonk^k_ooooooA4A402Wooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
9_ooool01Ol@413o^[ZjoooooomgMgOo<S8b02[ooooo00?o0000ooooooooool06?ooool001Kooooo
1_l00006ooooo`03o`000?oooooooooo01gooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^01oooooo
1_l00005ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09_ooool00onHV9So8B4Q
onk^kP0[ooooo`03o`000?oooooooooo02Gooooo1Ol0000Iooooo`008Oooool00onYZJWo410@oooo
o`0Xooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Wooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?oZJVYoa0@4?ooool09_ooool01?m4A4CogMgMoooo
ool0000Jooooo`008?ooool00ol@413o0000okZj^P0Zooooo`03ogMgMomVIVKooooo02Sooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Xooooo`03ogMgMomVIVKooooo02Oooooo00?o
410@o`000?nj^[X09oooool01?oMgMgoEEEEooooool0000Jooooo`008Oooool00onj^[[o8B4Qoooo
o`0Zooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo02Oooooo00?o^[Zjob4Q8Oooool09oooool00omgMgOoc<c<o`00
000Jooooo`007_ooool01Ol@413oV9RHoooooonj^[[o000002Oooooo00Go0000okZj^_ooooooV9RH
oa0@400Yooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09Oooool01Ol0003o^[Zj
oooooonHV9So410@02Kooooo00Go410@oiRHV?oooooo^[Zjo`00000Xooooo`03onk^k_m4A4Co0000
01[ooooo000Nooooo`05ojVYZOl@413o0000oa0@4?nYZJT09oooool01OnHV9So410@o`000?lQ8B7o
c<c<02Oooooo00?oEEEEofIVI_l00000D?ooool00omEEEGoIVIVo`00000Wooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`09_ooool01OnYZJWo410@o`000?l@413oZJVY02Wooooo00?oMgMgo`000?ooool0
6Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool001goooooool0000bo`0001[ooooo000Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool01?l0003oooooooooooooool=o`000003ooooool0003ooooo00Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooool000003?l00002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06?oo
ool001gooooo00?o0000ooooooooool07oooool8o`0000;ooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:?ooool0
1?l0003oooooooooooooool7o`00023ooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0Hooooo`00Aoooool3o`0005Gooooo00?o0000ooooooooool0E_ooool2o`0006kooooo001:oooo
o`Co0000DOooool00ol0003oooooooooo`1Dooooo`;o0000L?ooool004kooooo0ol0001>ooooo`03
o`000?oooooooooo057ooooo0ol0001booooo`00DOooool2o`0004cooooo00?o0000ooooooooool0
D?ooool00ol0003oooooooooo`1cooooo`00Doooool00ol0003oooooooooo`19ooooo`03o`000?oo
oooooooo04oooooo00?o0000ooooooooool0M?ooool005Cooooo0_l00019ooooo`03o`000?oooooo
oooo04kooooo00?o0000ooooooooool0MOooool005Kooooo0_l00017ooooo`03o`000?oooooooooo
04gooooo00?o0000ooooooooool0M_ooool005Sooooo0_l00015ooooo`;o0000COooool00ol0003o
ooooooooo`1gooooo`00F_ooool2o`0004?ooooo00?o0000ooooooooool0Boooool00ol0003ooooo
ooooo`1hooooo`00G?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo04_ooooo00?o
0000ooooooooool0N?ooool005gooooo0_l00010ooooo`03o`000?oooooooooo04[ooooo00?o0000
ooooooooool0NOooool005oooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`1:oooo
o`03o`000?oooooooooo07Wooooo001Pooooo`;o0000?Oooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo07[ooooo001Rooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0
BOooool00ol0003oooooooooo`1jooooo`00Hoooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo04Sooooo00?o0000ooooooooool0Noooool006Cooooo00?o0000ooooooooool0>?ooool0
0ol0003oooooooooo`17ooooo`03o`000?oooooooooo07cooooo001Uooooo`03o`000?oooooooooo
03Oooooo0_l00018ooooo`03o`000?oooooooooo07cooooo001Vooooo`;o0000=oooool00ol0003o
ooooooooo`16ooooo`03o`000?oooooooooo07gooooo001Xooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`1mooooo`00JOooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0OOooool006[ooooo00?o0000
ooooooooool0<_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo07gooooo001[oooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`1noooo
o`00K?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo04Gooooo00?o0000oooooooo
ool0O_ooool006gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`15ooooo`03o`00
0?oooooooooo07kooooo001^ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0AOoo
ool00ol0003oooooooooo`1nooooo`00K_ooool00ol0003oooooooooo`0^ooooo`;o0000A_ooool0
0ol0003oooooooooo`1nooooo`00Koooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
04Gooooo00?o0000ooooooooool0O_ooool0073ooooo00?o0000ooooooooool0;?ooool00ol0003o
ooooooooo`15ooooo`03o`000?oooooooooo07kooooo001aooooo`03o`000?oooooooooo02_ooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`1nooooo`00L_ooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0Ooooool007?ooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo07oooooo001doooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`1ooooo
o`00MOooool00ol0003oooooooooo`0<ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo1Ol00006ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0Ooooool007Go
oooo00?o0000ooooooooool03?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooo
oooo07oooooo001fooooo`03o`000?oooooooooo00_ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`1o
ooooo`00Moooool00ol0003oooooooooo`0:ooooo`05o`000?ooooooooooooooool000003Oooool0
0onHV9So8B4Qonk^kP06ooooo`?o0000A?ooool00ol0003oooooooooo`1oooooo`00N?ooool00ol0
003oooooooooo`09ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05
ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0Ooooool007Wooooo00?o0000oooo
ooooool02?ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`14ooooo`03o`000?oooooooooo07oooooo001jooooo`03o`000?oooooooooo
00Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_oo
ool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo07oooooo001kooooo`03o`000?oooooo
oooo00Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
1_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo07oooooo001looooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`1oooooo`00OOooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0Ooooool0
07kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo
07oooooo001nooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0A?ooool00ol0003o
ooooooooo`1oooooo`00Ooooool00ol0003oooooooooo`0Mooooo`;o0000AOooool00ol0003ooooo
ooooo`1oooooo`00P?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04Cooooo00?o
0000ooooooooool0Ooooool0087ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`14
ooooo`03o`000?oooooooooo07oooooo0022ooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool0A?ooool00ol0003oooooooooo`1oooooo`00Poooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo04Cooooo00?o0000ooooooooool0Ooooool008?ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo07oooooo0024ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`1oooooo`00QOooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0Ooooool0
08Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo
07oooooo0027ooooo`03o`000?oooooooooo01Gooooo0_l00015ooooo`03o`000?oooooooooo07oo
oooo0027ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0A?ooool00ol0003ooooo
ooooo`1oooooo`00R?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04Cooooo00?o
0000ooooooooool0Ooooool008Wooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`14
ooooo`03o`000?oooooooooo07oooooo002:ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool0A?ooool00ol0003oooooooooo`1oooooo`00R_ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo04Cooooo00?o0000ooooooooool0Ooooool008_ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo07oooooo002<ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`1nooooo`00SOooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0O_ooool0
08kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo
07kooooo002>ooooo`03o`000?oooooooooo00kooooo0_l00016ooooo`03o`000?oooooooooo07ko
oooo002?ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`1nooooo`00T?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04Gooooo00?o
0000ooooooooool0O_ooool0097ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`15
ooooo`03o`000?oooooooooo07kooooo002Aooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0AOooool00ol0003oooooooooo`1nooooo`00T_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo04Gooooo00?o0000ooooooooool0O_ooool009?ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo07kooooo0024ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@?ooooo00?o0000ooooooooool00_l000000ol@413ooooo
ooooo`04ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0O_ooool008Cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01?l0003oooooooooool00007ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0OOooool008Cooooo00Go410@oooooooooooo
oooooa0@400;ooooo`Go00001_ooool3o`0004Kooooo00?o0000ooooooooool0OOooool008Cooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?l0003oooooo`0000Oooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`1mooooo`00Q?ooool01Ol0003ooooooooooooooooo0000
00_ooooo00CogMgMoeEEEOl0003o00001oooool00ol0003oooooooooo`16ooooo`03o`000?oooooo
oooo07gooooo0024ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007
ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0OOooool008Cooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0A_ooool0
0ol0003oooooooooo`1mooooo`00Q?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMg
o`000?l000001_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo07gooooo002Ioooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1loooo
o`00VOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04Oooooo00?o0000oooooooo
ool0O?ooool009[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`17ooooo`03o`00
0?oooooooooo07cooooo002Kooooo`05o`000?ooooooooooooooool00000BOooool00ol0003ooooo
ooooo`1looooo`00Voooool01?l0003oooooooooooooool2o`0004Sooooo00?o0000ooooooooool0
O?ooool009cooooo00Co0000oooooooooooo0000BOooool00ol0003oooooooooo`1looooo`00WOoo
ool00ol0003oooooo`000019ooooo`03o`000?oooooooooo07cooooo002Nooooo`;o0000BOooool0
0ol0003oooooooooo`1looooo`00W_ooool2o`0004[ooooo00?o0000ooooooooool0Noooool009oo
oooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`1kooooo`00Woooool2o`0004Wooooo
00?o0000ooooooooool0Noooool009oooooo00?o0000ooooool00000B?ooool00ol0003ooooooooo
o`1kooooo`00Woooool00ol0003oooooo`000018ooooo`03o`000?oooooooooo07_ooooo002Ooooo
o`;o000000?oooooo`000?ooool0A_ooool00ol0003oooooooooo`1kooooo`00Woooool01Ol0003o
oooooooooooooooo000004Kooooo00?o0000ooooooooool0Noooool009oooooo00Go0000oooooooo
ooooooooo`000017ooooo`03o`000?oooooooooo07[ooooo002Oooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`1jooooo`00Woooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0N_ooool009oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo07[ooooo002O
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`1j
ooooo`00Woooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo047ooooo00?o0000oooo
ooooool0N_ooool009oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`10ooooo`03
o`000?oooooooooo07[ooooo002Oooooo`;o00001oooool00ol0003oooooooooo`10ooooo`03o`00
0?oooooooooo07[ooooo002Oooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0@?oo
ool00ol0003oooooooooo`1iooooo`00Woooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo03oooooo00?o0000ooooooooool0NOooool009oooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0oooooo`03o`000?oooooooooo07Wooooo002Oooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`1iooooo`00Woooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0NOooool009oooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo07Wooooo0024
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@
olc<c006ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0??ooool00ol0003ooooo
ooooo`1iooooo`00Q?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEE
EOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0NOooool008Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0N?ooool008Cooooo00Go0000ooooooooooooooooo`00000;oooo
o`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0000gooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`1hooooo`00Q?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000
oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0>_oo
ool00ol0003oooooooooo`1hooooo`00Q?ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o
EEEEohN7Qoooool02?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool0N?ooool008Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@
413oV9RH00Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo07Sooooo0024ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`00
0?l@4106ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0>?ooool00ol0003ooooo
ooooo`1hooooo`00Woooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03Oooooo00?o
0000ooooooooool0N?ooool009oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0h
ooooo`03o`000?oooooooooo07Oooooo002Oooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`1gooooo`00Woooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool0Moooool009oooooo0_l0000Dooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool0Moooool009oooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo07Oooooo002Oooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1fooooo`00Woooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0M_ooool009oo
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo07Ko
oooo002Oooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`1fooooo`00Woooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool0M_ooool009oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0c
ooooo`03o`000?oooooooooo07Gooooo002Oooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool0<_ooool00ol0003oooooooooo`1eooooo`00Woooool2o`0001_ooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`1eooooo`00Woooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0MOooool009oooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo07Gooooo002Oooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1eooooo`00Woooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0MOooool009oo
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo07Co
oooo002Oooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`1dooooo`00Woooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool0M?ooool009oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo07Cooooo002Oooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`1dooooo`00Woooool2o`00027ooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`1dooooo`00Woooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool0M?ooool009oooooo00?o0000ooooooooool08_oo
ool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo07?ooooo002Oooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1cooooo`00Woooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0Loooool009oo
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo07?o
oooo002Oooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`1cooooo`00Q?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<
c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool0Loooool008Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo07?ooooo0024ooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0000Wooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool0Loooool008Cooooo00Go0000ooooooooooooooooo`00000;
ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool0Loooool008Cooooo00Go0000ooooooooooooooooo`00
000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0Loooool008Cooooo00Go410@oooooooooooooooo
oa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0Loooool008Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0L_ooool008Cooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0L_ooool009oooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo07;ooooo002Oooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1booooo`00
Woooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
L_ooool009oooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo07;ooooo002Oooooo`;o0000;oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo07;ooooo002Oooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`1booooo`00Woooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool0L_ooool009oooooo00?o0000ooooooooool0<?ooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo07;ooooo002Oooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`1booooo`00Woooool00ol0003oooooooooo`0b
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0L_ooool009oooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo07;ooooo002Oooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1aooooo`00
Woooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
LOooool009oooooo0_l0000fooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0LOoo
ool009oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo077ooooo002Oooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`1aooooo`00Woooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool0LOooool009oooooo00?o0000ooooooooool0>Oooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo077ooooo002Oooooo`03o`000?oooooooooo03[ooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`1aooooo`00Woooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0LOooool009oooooo00?o0000oooo
ooooool0??ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo077ooooo002Oooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1booooo`00
Woooool2o`0003oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1booooo`00Wooo
ool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0L_oo
ool009oooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo07;ooooo002Oooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`1booooo`00Woooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0Loooool009oooooo00?o0000ooooooooool0@oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo07?ooooo002Oooooo`03o`000?oooooooooo04Cooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`1cooooo`00UOooool4o`000003oa0@4?oooooo
oooo00?ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo07Cooooo002Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0A_ooool2o`00
00Kooooo0_l0001fooooo`00Uoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04So
oooo0ol000000ooooooo0000o`00001hooooo`00Uoooool00ol0003oooooooooo`05ooooo`?o0000
Boooool00ol0003oooooooooo`1hooooo`00Uoooool00ol0003oooooooooo`3>ooooo`00Uoooool0
0ol0003oooooooooo`3>ooooo`00Uoooool00ol0003oooooooooo`3>ooooo`00UOooool00omEEEGo
IVIVo`00003@ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Y?ooool01OnH
V9So0000o`000?m4A4Co^[Zj00[ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool0
1Oo<c<co8B4Qo`000?lQ8B7oc<c<0:7ooooo002Tooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_oo
ool6o`0000Cooooo00?o0000ooooooooool01?ooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RH
ob4Q8@2Qooooo`00Y?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00[ooooo00Go
0000ooooooooooooooooo`00002Qooooo`00Y?ooool00ol0003oooooooooo`04ooooo`Ko00001?oo
ool00ol0003oooooooooo`0:ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80XOooool00:Cooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0:ooooo`05olc<c?l0003o0000o`000?o<c<`0
XOooool00:;ooooo00?o410@o`000?l000000ol0000=ooooo`03o`000?oooooooooo00[ooooo00Go
410@okZj^_oooooo^[Zjoa0@402Qooooo`00Y?ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00[ooooo00Go0000okZj^_oooooo^[Zjo`00002Qooooo`00Y?ooool00ol0003ooooooooo
o`0<ooooo`03oeEEEOmVIVKo000000cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2Qooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.68406, -0.0802184, \
0.0288357, 0.00666531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.428571 0.142857 0 0.618034 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.14286 -0.0125 -6 -9 ]
[.14286 -0.0125 6 0 ]
[.28571 -0.0125 -6 -9 ]
[.28571 -0.0125 6 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.41607 .12361 -18 -4.5 ]
[.41607 .12361 0 4.5 ]
[.41607 .24721 -18 -4.5 ]
[.41607 .24721 0 4.5 ]
[.41607 .37082 -18 -4.5 ]
[.41607 .37082 0 4.5 ]
[.41607 .49443 -18 -4.5 ]
[.41607 .49443 0 4.5 ]
[.41607 .61803 -6 -4.5 ]
[.41607 .61803 0 4.5 ]
[.5 .63053 -14 0 ]
[.5 .63053 14 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-3)] 0 -0.0125 0 1 Mshowa
.14286 0 m
.14286 .00625 L
s
[(-2)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(-1)] .28571 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(1)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(2)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(3)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.42857 .12361 m
.43482 .12361 L
s
[(0.2)] .41607 .12361 1 0 Mshowa
.42857 .24721 m
.43482 .24721 L
s
[(0.4)] .41607 .24721 1 0 Mshowa
.42857 .37082 m
.43482 .37082 L
s
[(0.6)] .41607 .37082 1 0 Mshowa
.42857 .49443 m
.43482 .49443 L
s
[(0.8)] .41607 .49443 1 0 Mshowa
.42857 .61803 m
.43482 .61803 L
s
[(1)] .41607 .61803 1 0 Mshowa
.125 Mabswid
.42857 .0309 m
.43232 .0309 L
s
.42857 .0618 m
.43232 .0618 L
s
.42857 .09271 m
.43232 .09271 L
s
.42857 .15451 m
.43232 .15451 L
s
.42857 .18541 m
.43232 .18541 L
s
.42857 .21631 m
.43232 .21631 L
s
.42857 .27812 m
.43232 .27812 L
s
.42857 .30902 m
.43232 .30902 L
s
.42857 .33992 m
.43232 .33992 L
s
.42857 .40172 m
.43232 .40172 L
s
.42857 .43262 m
.43232 .43262 L
s
.42857 .46353 m
.43232 .46353 L
s
.42857 .52533 m
.43232 .52533 L
s
.42857 .55623 m
.43232 .55623 L
s
.42857 .58713 m
.43232 .58713 L
s
.25 Mabswid
.42857 0 m
.42857 .61803 L
s
gsave
.5 .63053 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
4e-05 8e-05 m
.01435 .00014 L
.02868 .00024 L
.04305 .00042 L
.05747 .00072 L
.07198 .00119 L
.08661 .00195 L
.10144 .00312 L
.11654 .00489 L
.13204 .00751 L
.14809 .01132 L
.16487 .01672 L
.18262 .0242 L
.20159 .03435 L
.22209 .04778 L
.2444 .06514 L
.26882 .08706 L
.29558 .11404 L
.32484 .14643 L
.35663 .1843 L
.39082 .22736 L
.4271 .27494 L
.46494 .32588 L
.50361 .37862 L
.54219 .43119 L
.57966 .48133 L
.6149 .52665 L
.64684 .56484 L
.67451 .5938 L
.69716 .61188 L
.71429 .61803 L
.72573 .61188 L
.73165 .5938 L
.73255 .56484 L
.72918 .52665 L
.72251 .48133 L
.71362 .43119 L
.70361 .37862 L
.69351 .32588 L
.68425 .27494 L
.67654 .22736 L
.67091 .1843 L
.66769 .14643 L
.66701 .11404 L
.66882 .08706 L
.67297 .06514 L
.67923 .04778 L
.68731 .03435 L
.6969 .0242 L
.70773 .01672 L
Mistroke
.71952 .01132 L
.73204 .00751 L
.74512 .00489 L
.75858 .00312 L
.77233 .00195 L
.78627 .00119 L
.80033 .00072 L
.81448 .00042 L
.82868 .00024 L
.84292 .00014 L
.85718 8e-05 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`007_ooool01OnHV9So410@o`000?lb<S;oc<c<02Oooooo1Ol0000Woooo
o`Co000000?o410@ooooooooool0C?ooool4o`000003oa0@4?oooooooooo02?ooooo1Ol0000Voooo
o`05oiRHV?l@413o0000oc8b<_o<c<`0:Oooool2o`000003oa0@4?oooooooooo01Oooooo000Noooo
o`05oa0@4?nj^[[oooooogMgMolb<S809oooool01OnHV9So8B4Qonk^k_ooooooA4A402Wooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
9_ooool01Ol@413o^[ZjoooooomgMgOo<S8b02[ooooo00?o0000ooooooooool06?ooool001Kooooo
1_l00006ooooo`03o`000?oooooooooo01gooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^01oooooo
1_l00005ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09_ooool00onHV9So8B4Q
onk^kP0[ooooo`03o`000?oooooooooo02Gooooo1Ol0000Iooooo`008Oooool00onYZJWo410@oooo
o`0Xooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Wooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?oZJVYoa0@4?ooool09_ooool01?m4A4CogMgMoooo
ool0000Jooooo`008?ooool00ol@413o0000okZj^P0Zooooo`03ogMgMomVIVKooooo02Sooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Xooooo`03ogMgMomVIVKooooo02Oooooo00?o
410@o`000?nj^[X09oooool01?oMgMgoEEEEooooool0000Jooooo`008Oooool00onj^[[o8B4Qoooo
o`0Zooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo02Oooooo00?o^[Zjob4Q8Oooool09oooool00omgMgOoc<c<o`00
000Jooooo`007_ooool01Ol@413oV9RHoooooonj^[[o000002Oooooo00Go0000okZj^_ooooooV9RH
oa0@400Yooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09Oooool01Ol0003o^[Zj
oooooonHV9So410@02Kooooo00Go410@oiRHV?oooooo^[Zjo`00000Xooooo`03onk^k_m4A4Co0000
01[ooooo000Nooooo`05ojVYZOl@413o0000oa0@4?nYZJT09oooool01OnHV9So410@o`000?lQ8B7o
c<c<02Oooooo00?oEEEEofIVI_l00000D?ooool00omEEEGoIVIVo`00000Wooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`09_ooool01OnYZJWo410@o`000?l@413oZJVY02Wooooo00?oMgMgo`000?ooool0
6Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool001goooooool0000bo`0001[ooooo000Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool01?l0003oooooooooooooool?o`0000Sooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool000003?l0
0002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06?ooool001gooooo00?o0000
ooooooooool08?ooool7o`0000;ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:?ooool01?l0003ooooooooooooo
ool7o`00023ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Hooooo`00Aoooool3
o`0005Gooooo00?o0000ooooooooool0E_ooool2o`0006kooooo001:ooooo`Co0000DOooool00ol0
003oooooooooo`1Dooooo`;o0000L?ooool004kooooo0ol0001>ooooo`03o`000?oooooooooo05;o
oooo0_l0001booooo`00DOooool2o`0004cooooo00?o0000ooooooooool0DOooool00ol0003ooooo
ooooo`1booooo`00Doooool2o`0004[ooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`1cooooo`00EOooool2o`0004Sooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`1d
ooooo`00Eoooool2o`0004Kooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`1eoooo
o`00FOooool00ol0003oooooooooo`13ooooo`;o0000C_ooool00ol0003oooooooooo`1fooooo`00
F_ooool2o`0004?ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1gooooo`00G?oo
ool2o`00047ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1gooooo`00G_ooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0N?ooool0
05oooooo0_l0000nooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0NOooool0067o
oooo0_l0000looooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0N_ooool006?ooooo
00?o0000ooooooooool0>Oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo07[ooooo
001Tooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0B?ooool00ol0003ooooooooo
o`1kooooo`00IOooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo04Sooooo00?o0000
ooooooooool0Noooool006Kooooo00?o0000ooooooooool0=_ooool2o`0004Wooooo00?o0000oooo
ooooool0Noooool006Oooooo0_l0000fooooo`03o`000?oooooooooo04Oooooo00?o0000oooooooo
ool0O?ooool006Wooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`17ooooo`03o`00
0?oooooooooo07cooooo001Zooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0Aooo
ool00ol0003oooooooooo`1looooo`00Joooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo04Oooooo00?o0000ooooooooool0O?ooool006cooooo00?o0000ooooooooool0<?ooool00ol0
003oooooooooo`16ooooo`03o`000?oooooooooo07gooooo001]ooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`1mooooo`00K_ooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0OOooool006oooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo07gooooo001`
ooooo`03o`000?oooooooooo02cooooo0_l00017ooooo`03o`000?oooooooooo07gooooo001aoooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`1moooo
o`00L_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo04Kooooo00?o0000oooooooo
ool0OOooool007?ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`16ooooo`03o`00
0?oooooooooo07gooooo001dooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0A_oo
ool00ol0003oooooooooo`1mooooo`00MOooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo04Kooooo00?o0000ooooooooool0OOooool007Kooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`16ooooo`03o`000?oooooooooo07gooooo001gooooo`03o`000?oooooooooo00[o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`1mooooo`00Moooool00ol0003oooooooooo`0:ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006
ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0OOooool007Sooooo00?o0000oooo
ooooool02Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool0
0ol0003oooooooooo`16ooooo`03o`000?oooooooooo07gooooo001iooooo`03o`000?oooooooooo
00Sooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol00016
ooooo`03o`000?oooooooooo07gooooo001jooooo`03o`000?oooooooooo00Oooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0A_ooool0
0ol0003oooooooooo`1mooooo`00Noooool00ol0003oooooooooo`06ooooo`05oa0@4?oooooooooo
ooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04Kooooo00?o0000
ooooooooool0OOooool007cooooo00?o0000ooooooooool01Oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo04Kooooo00?o
0000ooooooooool0OOooool007gooooo00?o0000ooooooooool01?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo04Kooooo
00?o0000ooooooooool0OOooool007kooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`16ooooo`03o`000?oooooooooo07gooooo001oooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool0A_ooool00ol0003oooooooooo`1mooooo`00P?ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0OOooool0083ooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo07gooooo0021ooooo`03o`00
0?oooooooooo01_ooooo0_l00017ooooo`03o`000?oooooooooo07gooooo0022ooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`1mooooo`00Poooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0OOooool0
08Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo
07gooooo0025ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Aoooool00ol0003o
ooooooooo`1looooo`00QOooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Oooooo
00?o0000ooooooooool0O?ooool008Kooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`17ooooo`03o`000?oooooooooo07cooooo0027ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0Aoooool00ol0003oooooooooo`1looooo`00R?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0O?ooool008Wooooo00?o0000oooooooo
ool04oooool2o`0004Sooooo00?o0000ooooooooool0O?ooool008Wooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo07cooooo002:ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1looooo`00Roooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0O?ooool0
08cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo
07cooooo002=ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Aoooool00ol0003o
ooooooooo`1looooo`00S_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04Oooooo
00?o0000ooooooooool0O?ooool008oooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`18ooooo`03o`000?oooooooooo07_ooooo002?ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0B?ooool00ol0003oooooooooo`1kooooo`00T?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0Noooool0097ooooo00?o0000oooooooo
ool02oooool2o`0004Wooooo00?o0000ooooooooool0Noooool009;ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo07_ooooo002Cooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`1kooooo`00U?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0Noooool0
09Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo
07_ooooo002Eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0B?ooool00ol0003o
ooooooooo`1kooooo`00U_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Wooooo
00?o0000ooooooooool0N_ooool008Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0BOooool00ol0003ooooo
ooooo`1jooooo`00Q?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`1jooooo`00Q?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`?o0000BOooool00ol0003ooooo
ooooo`1jooooo`00Q?ooool01Ol0003ooooooooooooooooo000000_ooooo00KoA4A4omgMgOoooooo
0000ooooool00005ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0N_ooool008Co
oooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo07Wooooo0024oooo
o`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000002ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`1iooooo`00Q?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000000oooool01Ol0003ooooooooooooo
oooo000004cooooo00?o0000ooooooooool0NOooool008Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0=ooooo`03ogMgMol0003ooooo00?ooooo00Co0000oooooooooooo0000C?ooool00ol0003ooooo
ooooo`1iooooo`00W?ooool01?l0003oooooooooool0001<ooooo`03o`000?oooooooooo07Wooooo
002Mooooo`03o`000?oooooo000004gooooo00?o0000ooooooooool0N?ooool009kooooo0_l0001=
ooooo`03o`000?oooooooooo07Sooooo002Oooooo`03o`000?oooooooooo04_ooooo00?o0000oooo
ooooool0N?ooool009oooooo0_l0001<ooooo`03o`000?oooooooooo07Sooooo002Oooooo`;o0000
C?ooool00ol0003oooooooooo`1hooooo`00Woooool00ol0003oooooo`00001<ooooo`03o`000?oo
oooooooo07Oooooo002Oooooo`04o`000?ooooooooooo`0004_ooooo00?o0000ooooooooool0Mooo
ool009oooooo00Co0000oooooooooooo0000Boooool00ol0003oooooooooo`1gooooo`00Woooool0
1Ol0003ooooooooooooooooo000004[ooooo00?o0000ooooooooool0Moooool009oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo07Oooooo002Ooooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1foooo
o`00Woooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04Oooooo00?o0000oooooooo
ool0M_ooool009oooooo0_l00005ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0
M_ooool009oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`15ooooo`03o`000?oo
oooooooo07Kooooo002Oooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0AOooool0
0ol0003oooooooooo`1fooooo`00Woooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
04Gooooo00?o0000ooooooooool0MOooool009oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`14ooooo`03o`000?oooooooooo07Gooooo002Oooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0@oooool00ol0003oooooooooo`1eooooo`00Woooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0MOooool009oooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo07Gooooo002Ooooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`1eoooo
o`00Woooool2o`0000cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`1dooooo`00
Woooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0
M?ooool009oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`10ooooo`03o`000?oo
oooooooo07Cooooo002Oooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0?oooool0
0ol0003oooooooooo`1dooooo`00Woooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool0M?ooool009oooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0oooooo`03o`000?oooooooooo07?ooooo002Oooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`1cooooo`00Q?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0Loooool008Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q
00Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo
07?ooooo0024ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0looooo`03o`000?oooooo
oooo07?ooooo0024ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonH
V9So8B4Q00Kooooo0ol0000Booooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0L_oo
ool008Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
1_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
L_ooool008Cooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo07;ooooo
0024ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`1booooo`00Q?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0L_ooool009oooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo07;ooooo
002Oooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0>?ooool00ol0003ooooooooo
o`1aooooo`00Woooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool0LOooool009oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo077ooooo002Oooooo`;o00006_ooool00ol0003oooooooooo`0fooooo`03
o`000?oooooooooo077ooooo002Oooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`1aooooo`00Woooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool0L?ooool009oooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0eooooo`03o`000?oooooooooo073ooooo002Oooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`1`ooooo`00Woooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0L?ooool009oooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo073ooooo
002Oooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`1_ooooo`00Woooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool0Koooool009oooooo0_l0000Qooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool0Koooool009oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo06oooooo002Oooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`1_ooooo`00Woooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool0Koooool009oooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo06oooooo002Oooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1^ooooo`00Woooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0K_ooool009oooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06kooooo
002Oooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`1^ooooo`00Woooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool0K_ooool009oooooo0_l0000Xooooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool0K_ooool009oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo06kooooo002Oooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
:oooool00ol0003oooooooooo`1]ooooo`00Woooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool0KOooool009oooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo06gooooo002Oooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1]ooooo`00Woooool00ol0003o
ooooooooo`0[ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0KOooool008Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<
00Kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
06gooooo0024ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRH
V?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`1]ooooo`00Q?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`000006ooooo`?o0000;_ooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo06cooooo0024ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooo
oonHV9So<S8b00Kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo06cooooo0024ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo06cooooo0024ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o
^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo06cooooo0024ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo06cooooo0024ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0<_ooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo06cooooo002Oooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`1/ooooo`00Woooool00ol0003oooooooooo`0coooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0Joooool009oooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo06_ooooo002Oooooo`03o`00
0?oooooooooo03Gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1[ooooo`00Wooo
ool2o`0003Oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1[ooooo`00Woooool0
0ol0003oooooooooo`0fooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0Joooool0
09oooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
06_ooooo002Oooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`1[ooooo`00Woooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool0Joooool009oooooo00?o0000ooooooooool0>Oooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo06_ooooo002Oooooo`03o`000?oooooooooo03[ooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`1[ooooo`00Woooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0J_ooool009oooooo00?o0000oooooooo
ool0??ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo06[ooooo002Oooooo`;o0000
?Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo06[ooooo002Oooooo`03o`000?oo
oooooooo03gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1Zooooo`00Woooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0J_ooool0
09oooooo00?o0000ooooooooool0?oooool2o`0001Sooooo00?o0000ooooooooool0J_ooool009oo
oooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo06[o
oooo002Oooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`1Zooooo`00Woooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool0J_ooool009oooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo06[ooooo002Oooooo`03o`000?oooooooooo04Gooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`1Zooooo`00Woooool2o`0004Oooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`1Zooooo`00Woooool00ol0003oooooooooo`17ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0J_ooool009oooooo00?o0000ooooooooool0B?oo
ool2o`0000oooooo00?o0000ooooooooool0J_ooool009oooooo00?o0000ooooooooool0B_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo06[ooooo002Oooooo`03o`000?oooooooooo
04_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1[ooooo`00Woooool00ol0003o
ooooooooo`1<ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Joooool009oooooo
00?o0000ooooooooool0COooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06_ooooo
002Eooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`1>ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0K?ooool009Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1?ooooo`;o00001Oooool2o`0006kooooo002Gooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0DOooool3o`000003ooooool0003ooooo06oooooo002Gooooo`03
o`000?oooooooooo00Gooooo0ol0001Dooooo`03o`000?oooooooooo06oooooo002Gooooo`03o`00
0?oooooooooo0<kooooo002Gooooo`03o`000?oooooooooo0<kooooo002Gooooo`03o`000?oooooo
oooo0<kooooo002Eooooo`03oeEEEOmVIVKo00000=3ooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo002Xooooo`05oiRHV?l0003o0000odA4A?nj^[X02Oooool5o`0000Gooooo0_lQ
8B6Vooooo`00Z?ooool01_l@413o^[Zjonk^k_mgMgOo410@ooooo`Ko00000_ooool01OnHV9So8B4Q
onk^k_ooooooA4A400Gooooo0_lQ8B6Vooooo`00Z?ooool00ol0003oooooooooo`0<ooooo`03oiRH
V?lQ8B7ok^k^0:kooooo002Xooooo`03o`000?oooooooooo00?ooooo1_l00004ooooo`03oiRHV?lQ
8B7ok^k^0:gooooo002Xooooo`03o`000?oooooooooo00kooooo00?oMgMgofIVI_ooool0[?ooool0
0:Kooooo00?o410@o`000?l000000ol0000>ooooo`03o`000?oooooooooo0:_ooooo002Xooooo`03
o`000?oooooooooo00_ooooo00Go0000okZj^_ooooooV9RHoa0@402]ooooo`00Z?ooool00ol0003o
ooooooooo`0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0[Oooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.68406, -0.0802184, \
0.0288357, 0.00666531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.428571 0.142857 0 0.618034 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.14286 -0.0125 -6 -9 ]
[.14286 -0.0125 6 0 ]
[.28571 -0.0125 -6 -9 ]
[.28571 -0.0125 6 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.41607 .12361 -18 -4.5 ]
[.41607 .12361 0 4.5 ]
[.41607 .24721 -18 -4.5 ]
[.41607 .24721 0 4.5 ]
[.41607 .37082 -18 -4.5 ]
[.41607 .37082 0 4.5 ]
[.41607 .49443 -18 -4.5 ]
[.41607 .49443 0 4.5 ]
[.41607 .61803 -6 -4.5 ]
[.41607 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-3)] 0 -0.0125 0 1 Mshowa
.14286 0 m
.14286 .00625 L
s
[(-2)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(-1)] .28571 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(1)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(2)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(3)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.42857 .12361 m
.43482 .12361 L
s
[(0.2)] .41607 .12361 1 0 Mshowa
.42857 .24721 m
.43482 .24721 L
s
[(0.4)] .41607 .24721 1 0 Mshowa
.42857 .37082 m
.43482 .37082 L
s
[(0.6)] .41607 .37082 1 0 Mshowa
.42857 .49443 m
.43482 .49443 L
s
[(0.8)] .41607 .49443 1 0 Mshowa
.42857 .61803 m
.43482 .61803 L
s
[(1)] .41607 .61803 1 0 Mshowa
.125 Mabswid
.42857 .0309 m
.43232 .0309 L
s
.42857 .0618 m
.43232 .0618 L
s
.42857 .09271 m
.43232 .09271 L
s
.42857 .15451 m
.43232 .15451 L
s
.42857 .18541 m
.43232 .18541 L
s
.42857 .21631 m
.43232 .21631 L
s
.42857 .27812 m
.43232 .27812 L
s
.42857 .30902 m
.43232 .30902 L
s
.42857 .33992 m
.43232 .33992 L
s
.42857 .40172 m
.43232 .40172 L
s
.42857 .43262 m
.43232 .43262 L
s
.42857 .46353 m
.43232 .46353 L
s
.42857 .52533 m
.43232 .52533 L
s
.42857 .55623 m
.43232 .55623 L
s
.42857 .58713 m
.43232 .58713 L
s
.25 Mabswid
.42857 0 m
.42857 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
4e-05 8e-05 m
.01436 .00014 L
.0287 .00024 L
.04307 .00042 L
.05751 .00072 L
.07204 .00119 L
.0867 .00195 L
.10158 .00312 L
.11677 .00489 L
.13239 .00751 L
.14861 .01132 L
.16564 .01672 L
.18374 .0242 L
.20318 .03435 L
.2243 .04778 L
.24741 .06514 L
.27284 .08706 L
.30085 .11404 L
.33161 .14643 L
.36515 .1843 L
.40133 .22736 L
.43981 .27494 L
.48001 .32588 L
.52111 .37862 L
.56213 .43119 L
.60191 .48133 L
.63925 .52665 L
.67295 .56484 L
.70196 .5938 L
.72544 .61188 L
.74286 .61803 L
.75402 .61188 L
.75911 .5938 L
.75866 .56484 L
.75353 .52665 L
.74477 .48133 L
.73356 .43119 L
.72111 .37862 L
.70858 .32588 L
.69696 .27494 L
.68705 .22736 L
.67943 .1843 L
.67446 .14643 L
.67228 .11404 L
.67284 .08706 L
.67598 .06514 L
.68144 .04778 L
.6889 .03435 L
.69802 .0242 L
.7085 .01672 L
Mistroke
.72004 .01132 L
.73239 .00751 L
.74534 .00489 L
.75873 .00312 L
.77242 .00195 L
.78632 .00119 L
.80036 .00072 L
.8145 .00042 L
.8287 .00024 L
.84293 .00014 L
.85718 8e-05 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`007_ooool01OnHV9So410@o`000?lb<S;oc<c<02Oooooo1Ol0000Woooo
o`Co000000?o410@ooooooooool0C?ooool4o`000003oa0@4?oooooooooo02?ooooo1Ol0000Voooo
o`05oiRHV?l@413o0000oc8b<_o<c<`0:Oooool2o`000003oa0@4?oooooooooo01Oooooo000Noooo
o`05oa0@4?nj^[[oooooogMgMolb<S809oooool01OnHV9So8B4Qonk^k_ooooooA4A402Wooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
9_ooool01Ol@413o^[ZjoooooomgMgOo<S8b02[ooooo00?o0000ooooooooool06?ooool001Kooooo
1_l00006ooooo`03o`000?oooooooooo01gooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^01oooooo
1_l00005ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09_ooool00onHV9So8B4Q
onk^kP0[ooooo`03o`000?oooooooooo02Gooooo1Ol0000Iooooo`008Oooool00onYZJWo410@oooo
o`0Xooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Wooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?oZJVYoa0@4?ooool09_ooool01?m4A4CogMgMoooo
ool0000Jooooo`008?ooool00ol@413o0000okZj^P0Zooooo`03ogMgMomVIVKooooo02Sooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Xooooo`03ogMgMomVIVKooooo02Oooooo00?o
410@o`000?nj^[X09oooool01?oMgMgoEEEEooooool0000Jooooo`008Oooool00onj^[[o8B4Qoooo
o`0Zooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo02Oooooo00?o^[Zjob4Q8Oooool09oooool00omgMgOoc<c<o`00
000Jooooo`007_ooool01Ol@413oV9RHoooooonj^[[o000002Oooooo00Go0000okZj^_ooooooV9RH
oa0@400Yooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09Oooool01Ol0003o^[Zj
oooooonHV9So410@02Kooooo00Go410@oiRHV?oooooo^[Zjo`00000Xooooo`03onk^k_m4A4Co0000
01[ooooo000Nooooo`05ojVYZOl@413o0000oa0@4?nYZJT09oooool01OnHV9So410@o`000?lQ8B7o
c<c<02Oooooo00?oEEEEofIVI_l00000D?ooool00omEEEGoIVIVo`00000Wooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`09_ooool01OnYZJWo410@o`000?l@413oZJVY02Wooooo00?oMgMgo`000?ooool0
6Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool001goooooool0000bo`0001[ooooo000Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool01?l0003oooooooooooooool?o`0000Sooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool000003?l0
0002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06?ooool001gooooo00?o0000
ooooooooool08?ooool7o`0000;ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:?ooool01?l0003ooooooooooooo
ool7o`00023ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Hooooo`00Aoooool3
o`0005Gooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`1/ooooo`00B_ooool4o`00
057ooooo00?o0000ooooooooool0E?ooool3o`0006oooooo001>ooooo`?o0000C_ooool00ol0003o
ooooooooo`1Booooo`;o0000L_ooool0057ooooo0_l0001<ooooo`03o`000?oooooooooo057ooooo
00?o0000ooooooooool0L_ooool005?ooooo0_l0001:ooooo`03o`000?oooooooooo053ooooo00?o
0000ooooooooool0Loooool005Gooooo0_l00018ooooo`03o`000?oooooooooo04oooooo00?o0000
ooooooooool0M?ooool005Oooooo0_l00016ooooo`03o`000?oooooooooo04kooooo00?o0000oooo
ooooool0MOooool005Wooooo0_l00014ooooo`;o0000C_ooool00ol0003oooooooooo`1fooooo`00
Foooool2o`0004;ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1gooooo`00GOoo
ool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0Mooo
ool005kooooo0_l0000oooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0N?ooool0
063ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo
07Sooooo001Qooooo`;o0000??ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo07Wo
oooo001Sooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0B_ooool00ol0003ooooo
ooooo`1iooooo`00I?ooool2o`0003Wooooo00?o0000ooooooooool0BOooool00ol0003ooooooooo
o`1jooooo`00I_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo04Wooooo00?o0000
ooooooooool0N_ooool006Oooooo00?o0000ooooooooool0=Oooool2o`0004[ooooo00?o0000oooo
ooooool0N_ooool006Sooooo0_l0000eooooo`03o`000?oooooooooo04Sooooo00?o0000oooooooo
ool0Noooool006[ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`18ooooo`03o`00
0?oooooooooo07_ooooo001[ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0B?oo
ool00ol0003oooooooooo`1kooooo`00K?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo04Sooooo00?o0000ooooooooool0Noooool006gooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`17ooooo`03o`000?oooooooooo07cooooo001^ooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1looooo`00Koooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0O?ooool0073ooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo07cooooo001a
ooooo`03o`000?oooooooooo02_ooooo0_l00018ooooo`03o`000?oooooooooo07cooooo001boooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1loooo
o`00Loooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo04Oooooo00?o0000oooooooo
ool0O?ooool007Cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`17ooooo`03o`00
0?oooooooooo07cooooo001eooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Aooo
ool00ol0003oooooooooo`1looooo`00M_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo04Oooooo00?o0000ooooooooool0O?ooool007Oooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`17ooooo`03o`000?oooooooooo07cooooo001hooooo`03o`000?oooooooooo00Wo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000oooo
ooooool0Aoooool00ol0003oooooooooo`1looooo`00NOooool00ol0003oooooooooo`08ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006
ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0O?ooool007[ooooo00?o0000oooo
ooooool01oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool0
0ol0003oooooooooo`17ooooo`03o`000?oooooooooo07cooooo001kooooo`03o`000?oooooooooo
00Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol00017
ooooo`03o`000?oooooooooo07cooooo001looooo`03o`000?oooooooooo00Gooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0Aoooool0
0ol0003oooooooooo`1looooo`00OOooool00ol0003oooooooooo`04ooooo`05oa0@4?oooooooooo
ooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04Oooooo00?o0000
ooooooooool0O?ooool007kooooo00?o0000ooooooooool00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo04Sooooo00?o
0000ooooooooool0Noooool007oooooo00?o0000ooooooooool00_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo04Sooooo
00?o0000ooooooooool0Noooool0083ooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`18ooooo`03o`000?oooooooooo07_ooooo0021ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool0B?ooool00ol0003oooooooooo`1kooooo`00P_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0Noooool008;ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo07_ooooo0023ooooo`03o`00
0?oooooooooo01Wooooo0_l00019ooooo`03o`000?oooooooooo07_ooooo0024ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`1kooooo`00QOooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0Noooool0
08Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo
07_ooooo0027ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0BOooool00ol0003o
ooooooooo`1jooooo`00R?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04Wooooo
00?o0000ooooooooool0N_ooool008Wooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`19ooooo`03o`000?oooooooooo07[ooooo002:ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0BOooool00ol0003oooooooooo`1jooooo`00Roooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0N_ooool008cooooo00?o0000oooooooo
ool04?ooool2o`0004[ooooo00?o0000ooooooooool0N_ooool008cooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo07[ooooo002=ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`1jooooo`00S_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0NOooool0
08oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo
07Wooooo002@ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0B_ooool00ol0003o
ooooooooo`1iooooo`00TOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04[ooooo
00?o0000ooooooooool0NOooool009;ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`1;ooooo`03o`000?oooooooooo07Sooooo002Booooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0Boooool00ol0003oooooooooo`1hooooo`00Toooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0N?ooool009Cooooo00?o0000oooooooo
ool02?ooool2o`0004cooooo00?o0000ooooooooool0N?ooool009Gooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo07Sooooo002Fooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1gooooo`00Uoooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0Moooool0
09Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo
07Oooooo002Hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0C?ooool00ol0003o
ooooooooo`1gooooo`00VOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04gooooo
00?o0000ooooooooool0M_ooool008Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1_ooool2o`000003oa0@4?oooooo000000Cooooo00?o0000ooooooooool0COooool00ol0003ooooo
ooooo`1fooooo`00Q?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo07Ko
oooo0024ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000;ooooo00Co0000oooooooo
oooooooo0ol0001=ooooo`03o`000?oooooooooo07Kooooo0024ooooo`05o`000?oooooooooooooo
ool000002oooool01?m4A4CogMgMooooool00004ooooo`04o`000?ooooooooooo`0004oooooo00?o
0000ooooooooool0M_ooool008Cooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0000Gooooo00?o0000ooooool00000D?ooool00ol0003oooooooooo`1eooooo`00Q?oo
ool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool2o`00053ooooo
00?o0000ooooooooool0MOooool008Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^
k_m4A4Co000000Oooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`1eooooo`00Q?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooo
ooooo`1>ooooo`03o`000?oooooooooo07Gooooo002Oooooo`;o0000Coooool00ol0003ooooooooo
o`1eooooo`00Woooool00ol0003oooooo`00001?ooooo`03o`000?oooooooooo07Cooooo002Ooooo
o`04o`000?ooooooooooo`0004kooooo00?o0000ooooooooool0M?ooool009oooooo00Go0000oooo
ooooooooooooo`00001=ooooo`03o`000?oooooooooo07Cooooo002Oooooo`;o00000_ooool00ol0
003oooooooooo`1;ooooo`03o`000?oooooooooo07Cooooo002Oooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`1dooooo`00Woooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0Loooool009oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo07?ooooo002O
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`1c
ooooo`00Woooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Sooooo00?o0000oooo
ooooool0Loooool009oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`17ooooo`03
o`000?oooooooooo07?ooooo002Oooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
Aoooool00ol0003oooooooooo`1booooo`00Woooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo04Kooooo00?o0000ooooooooool0L_ooool009oooooo0_l0000:ooooo`03o`000?oooooo
oooo04Gooooo00?o0000ooooooooool0L_ooool009oooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`15ooooo`03o`000?oooooooooo07;ooooo002Oooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`1booooo`00Woooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0LOooool009oooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo077ooooo002O
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`1a
ooooo`00Woooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04;ooooo00?o0000oooo
ooooool0LOooool009oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`11ooooo`03
o`000?oooooooooo077ooooo002Oooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
@Oooool00ol0003oooooooooo`1`ooooo`00Woooool2o`00017ooooo00?o0000ooooooooool0@?oo
ool00ol0003oooooooooo`1`ooooo`00Woooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo043ooooo00?o0000ooooooooool0L?ooool009oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0oooooo`03o`000?oooooooooo073ooooo002Oooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`1_ooooo`00Woooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0Koooool009oooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo06oooooo002O
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`1_
ooooo`00Q?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o
0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03gooooo00?o
0000ooooooooool0K_ooool008Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0looooo`03o`000?oooooooooo06kooooo0024ooooo`05oa0@4?ooooooooooooooool@4100
2oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`0looooo`03o`000?oooooooooo06kooooo0024ooooo`05o`000?ooooooooooooooool0
00002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0000Gooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0K_ooool008Cooooo00Go0000ooooooooooooooooo`00000;oooo
o`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0KOooool008Cooooo00Go410@oooooooooooooooooa0@400;
ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo06gooooo0024ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
0ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`1]ooooo`00Q?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<
odA4A?l0003o410@1_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool0KOooool009oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo06cooooo002Oooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`1/ooooo`00Woooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool0K?ooool009oooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo06cooooo002Oooooo`;o00007ooo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo06_ooooo002Oooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`1[ooooo`00Woooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0Joooool009oo
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo06_o
oooo002Oooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`1Zooooo`00Woooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03Cooooo00?o
0000ooooooooool0J_ooool009oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0c
ooooo`03o`000?oooooooooo06[ooooo002Oooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool0<_ooool00ol0003oooooooooo`1Zooooo`00Woooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool0JOooool009oooooo0_l0000Wooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0JOooool009oooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo06Wooooo002Oooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1Yooooo`00Woooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0J?ooool009oo
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo06So
oooo002Oooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`1Xooooo`00Woooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool0J?ooool009oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo06Sooooo002Oooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`1Wooooo`00Woooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool0Ioooool009oooooo0_l0000_ooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool0Ioooool009oooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo06Oooooo002Oooooo`03o`000?oooooo
oooo02oooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1Wooooo`00Woooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0I_ooool009oo
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo06Ko
oooo002Oooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`1Vooooo`00Woooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool0I_ooool008Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo06Kooooo0024ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1Uooooo`00Q?ooool01Ol@413ooooo
oooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000=Oooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo06Gooooo0024ooooo`05o`000?oooooooooooooo
ool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06Gooooo0024ooooo`05o`000?oooooooooo
ooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06Gooooo0024ooooo`05oa0@4?oooooo
ooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0
=oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo06Gooooo0024ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo06Cooooo0024ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000oooo
ooooool0>Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo06Cooooo002Oooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Tooooo`00
Woooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
I?ooool009oooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo06Cooooo002Oooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`1Sooooo`00Woooool2o`0003kooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`1Sooooo`00Woooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool0Hoooool009oooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo06?ooooo002Oooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`1Sooooo`00Woooool00ol0003oooooooooo`10
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0Hoooool009oooooo00?o0000oooo
ooooool0@Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo06?ooooo002Oooooo`03
o`000?oooooooooo04;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Sooooo`00
Woooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
H_ooool009oooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo06;ooooo002Oooooo`;o0000AOooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo06;ooooo002Oooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`1Rooooo`00Woooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool0H_ooool009oooooo00?o0000ooooooooool0Aoooool2o`0001Sooooo
00?o0000ooooooooool0H_ooool009oooooo00?o0000ooooooooool0BOooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo06;ooooo002Oooooo`03o`000?oooooooooo04[ooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`1Rooooo`00Woooool00ol0003oooooooooo`1;oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0H_ooool009oooooo00?o0000oooooooo
ool0C?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo06;ooooo002Oooooo`03o`00
0?oooooooooo04gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Qooooo`00Wooo
ool2o`0004oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Qooooo`00Woooool0
0ol0003oooooooooo`1?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0HOooool0
09oooooo00?o0000ooooooooool0D?ooool2o`00013ooooo00?o0000ooooooooool0HOooool009oo
oooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo067o
oooo002Oooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`1Rooooo`00Woooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0H_ooool009oooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo06;ooooo002Eooooo`Co000000?o410@ooooooooool00oooool00ol0
003oooooooooo`1Fooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Hoooool009Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Gooooo`?o00001Oooool2o`0006Go
oooo002Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0F_ooool3o`000003oooo
ool0003ooooo06Kooooo002Gooooo`03o`000?oooooooooo00Gooooo0ol0001Mooooo`03o`000?oo
oooooooo06Kooooo002Gooooo`03o`000?oooooooooo0<kooooo002Gooooo`03o`000?oooooooooo
0<kooooo002Gooooo`03o`000?oooooooooo0<kooooo002Eooooo`03oeEEEOmVIVKo00000=3ooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo002Tooooo`05oiRHV?l0003o0000odA4
A?nj^[X02Oooool5o`0000Gooooo0_lQ8B44ooooo`Go0000XOooool00:Cooooo00Go410@okZj^_o^
k^koMgMgoa0@4002ooooo`Ko000000KooooooiRHV?lQ8B7ok^k^oooooom4A4@5ooooo`;o8B4Q1?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A40:7ooooo002Tooooo`03o`000?oooooooooo00cooooo00?o
V9RHob4Q8Oo^k^h03Oooool00onHV9So8B4Qonk^kP2Rooooo`00Y?ooool00ol0003oooooooooo`04
ooooo`Ko00000oooool00onHV9So8B4Qonk^kP0=ooooo`03oiRHV?lQ8B7ok^k^0:7ooooo002Toooo
o`03o`000?oooooooooo00kooooo00?oMgMgofIVI_ooool03Oooool00omgMgOoIVIVooooo`2Poooo
o`00X_ooool00ol@413o0000o`000003o`0000kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`2Oooooo`00Y?ooool00ol0003oooooooooo`0;ooooo`05o`000?nj^[[ooooooiRHV?l@
41002oooool01Ol0003o^[ZjoooooonHV9So410@0:7ooooo002Tooooo`03o`000?oooooooooo00_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c00;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0XOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.68406, -0.0802184, \
0.0288357, 0.00666531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.428571 0.142857 0 0.618034 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.14286 -0.0125 -6 -9 ]
[.14286 -0.0125 6 0 ]
[.28571 -0.0125 -6 -9 ]
[.28571 -0.0125 6 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.41607 .12361 -18 -4.5 ]
[.41607 .12361 0 4.5 ]
[.41607 .24721 -18 -4.5 ]
[.41607 .24721 0 4.5 ]
[.41607 .37082 -18 -4.5 ]
[.41607 .37082 0 4.5 ]
[.41607 .49443 -18 -4.5 ]
[.41607 .49443 0 4.5 ]
[.41607 .61803 -6 -4.5 ]
[.41607 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-3)] 0 -0.0125 0 1 Mshowa
.14286 0 m
.14286 .00625 L
s
[(-2)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(-1)] .28571 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(1)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(2)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(3)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.42857 .12361 m
.43482 .12361 L
s
[(0.2)] .41607 .12361 1 0 Mshowa
.42857 .24721 m
.43482 .24721 L
s
[(0.4)] .41607 .24721 1 0 Mshowa
.42857 .37082 m
.43482 .37082 L
s
[(0.6)] .41607 .37082 1 0 Mshowa
.42857 .49443 m
.43482 .49443 L
s
[(0.8)] .41607 .49443 1 0 Mshowa
.42857 .61803 m
.43482 .61803 L
s
[(1)] .41607 .61803 1 0 Mshowa
.125 Mabswid
.42857 .0309 m
.43232 .0309 L
s
.42857 .0618 m
.43232 .0618 L
s
.42857 .09271 m
.43232 .09271 L
s
.42857 .15451 m
.43232 .15451 L
s
.42857 .18541 m
.43232 .18541 L
s
.42857 .21631 m
.43232 .21631 L
s
.42857 .27812 m
.43232 .27812 L
s
.42857 .30902 m
.43232 .30902 L
s
.42857 .33992 m
.43232 .33992 L
s
.42857 .40172 m
.43232 .40172 L
s
.42857 .43262 m
.43232 .43262 L
s
.42857 .46353 m
.43232 .46353 L
s
.42857 .52533 m
.43232 .52533 L
s
.42857 .55623 m
.43232 .55623 L
s
.42857 .58713 m
.43232 .58713 L
s
.25 Mabswid
.42857 0 m
.42857 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
4e-05 8e-05 m
.01436 .00014 L
.02871 .00024 L
.04309 .00042 L
.05754 .00072 L
.07209 .00119 L
.08679 .00195 L
.10173 .00312 L
.117 .00489 L
.13274 .00751 L
.14914 .01132 L
.16642 .01672 L
.18486 .0242 L
.20477 .03435 L
.2265 .04778 L
.25042 .06514 L
.27687 .08706 L
.30612 .11404 L
.33838 .14643 L
.37367 .1843 L
.41184 .22736 L
.45252 .27494 L
.49507 .32588 L
.53861 .37862 L
.58206 .43119 L
.62416 .48133 L
.66359 .52665 L
.69906 .56484 L
.72941 .5938 L
.75373 .61188 L
.77143 .61803 L
.7823 .61188 L
.78656 .5938 L
.78478 .56484 L
.77788 .52665 L
.76702 .48133 L
.75349 .43119 L
.73861 .37862 L
.72364 .32588 L
.70967 .27494 L
.69756 .22736 L
.68795 .1843 L
.68123 .14643 L
.67755 .11404 L
.67687 .08706 L
.67899 .06514 L
.68365 .04778 L
.69048 .03435 L
.69914 .0242 L
.70927 .01672 L
Mistroke
.72057 .01132 L
.73274 .00751 L
.74557 .00489 L
.75887 .00312 L
.77251 .00195 L
.78638 .00119 L
.8004 .00072 L
.81452 .00042 L
.82871 .00024 L
.84293 .00014 L
.85719 8e-05 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`007_ooool01OnHV9So410@o`000?lb<S;oc<c<02Oooooo1Ol0000Woooo
o`Co000000?o410@ooooooooool0C?ooool4o`000003oa0@4?oooooooooo02?ooooo1Ol0000Voooo
o`05oiRHV?l@413o0000oc8b<_o<c<`0:Oooool2o`000003oa0@4?oooooooooo01Oooooo000Noooo
o`05oa0@4?nj^[[oooooogMgMolb<S809oooool01OnHV9So8B4Qonk^k_ooooooA4A402Wooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
9_ooool01Ol@413o^[ZjoooooomgMgOo<S8b02[ooooo00?o0000ooooooooool06?ooool001Kooooo
1_l00006ooooo`03o`000?oooooooooo01gooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^01oooooo
1_l00005ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09_ooool00onHV9So8B4Q
onk^kP0[ooooo`03o`000?oooooooooo02Gooooo1Ol0000Iooooo`008Oooool00onYZJWo410@oooo
o`0Xooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Wooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?oZJVYoa0@4?ooool09_ooool01?m4A4CogMgMoooo
ool0000Jooooo`008?ooool00ol@413o0000okZj^P0Zooooo`03ogMgMomVIVKooooo02Sooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Xooooo`03ogMgMomVIVKooooo02Oooooo00?o
410@o`000?nj^[X09oooool01?oMgMgoEEEEooooool0000Jooooo`008Oooool00onj^[[o8B4Qoooo
o`0Zooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo02Oooooo00?o^[Zjob4Q8Oooool09oooool00omgMgOoc<c<o`00
000Jooooo`007_ooool01Ol@413oV9RHoooooonj^[[o000002Oooooo00Go0000okZj^_ooooooV9RH
oa0@400Yooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool09Oooool01Ol0003o^[Zj
oooooonHV9So410@02Kooooo00Go410@oiRHV?oooooo^[Zjo`00000Xooooo`03onk^k_m4A4Co0000
01[ooooo000Nooooo`05ojVYZOl@413o0000oa0@4?nYZJT09oooool01OnHV9So410@o`000?lQ8B7o
c<c<02Oooooo00?oEEEEofIVI_l00000D?ooool00omEEEGoIVIVo`00000Wooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`09_ooool01OnYZJWo410@o`000?l@413oZJVY02Wooooo00?oMgMgo`000?ooool0
6Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool001goooooool0000bo`0001[ooooo000Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool01?l0003oooooooooooooool?o`0000Sooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool000003?l0
0002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06?ooool001gooooo00?o0000
ooooooooool08?ooool7o`0000;ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`02
ooooo`Ko00008?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Sooooo0017oooo
o`?o0000EOooool00ol0003oooooooooo`1Gooooo`;o0000KOooool004[ooooo1?l0001Aooooo`03
o`000?oooooooooo05Cooooo0ol0001_ooooo`00C_ooool4o`0004gooooo00?o0000ooooooooool0
D_ooool2o`0007;ooooo001Booooo`;o0000Boooool00ol0003oooooooooo`1Aooooo`03o`000?oo
oooooooo07;ooooo001Dooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0D?ooool0
0ol0003oooooooooo`1cooooo`00EOooool2o`0004Sooooo00?o0000ooooooooool0Coooool00ol0
003oooooooooo`1dooooo`00Eoooool2o`0004Kooooo00?o0000ooooooooool0Coooool00ol0003o
ooooooooo`1dooooo`00FOooool2o`0004Cooooo0_l0001?ooooo`03o`000?oooooooooo07Gooooo
001Kooooo`;o0000@_ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo07Kooooo001M
ooooo`;o0000@?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo07Kooooo001Ooooo
o`03o`000?oooooooooo03gooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1goooo
o`00H?ooool2o`0003gooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1gooooo`00
H_ooool2o`0003_ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`1hooooo`00I?oo
ool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0N?oo
ool006Gooooo0_l0000hooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0NOooool0
06Oooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo
07Wooooo001Xooooo`03o`000?oooooooooo03Cooooo0_l0001;ooooo`03o`000?oooooooooo07Wo
oooo001Yooooo`;o0000=?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo07[ooooo
001[ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0BOooool00ol0003ooooooooo
o`1jooooo`00K?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo04Wooooo00?o0000
ooooooooool0N_ooool006gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`19oooo
o`03o`000?oooooooooo07[ooooo001^ooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool0BOooool00ol0003oooooooooo`1jooooo`00Koooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo04Wooooo00?o0000ooooooooool0N_ooool0073ooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo07[ooooo001aooooo`;o0000;?ooool0
0ol0003oooooooooo`19ooooo`03o`000?oooooooooo07[ooooo001cooooo`03o`000?oooooooooo
02Wooooo0_l0001:ooooo`03o`000?oooooooooo07[ooooo001dooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`1jooooo`00MOooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0N_ooool007Kooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo07[ooooo001g
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`1j
ooooo`00N?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04Wooooo00?o0000oooo
ooooool0N_ooool007Wooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo07[ooooo001jooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0BOooool00ol0003o
ooooooooo`1jooooo`00Noooool00ol0003oooooooooo`06ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool0N_ooool007cooooo00?o0000ooooooooool01Oooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`19oooo
o`03o`000?oooooooooo07[ooooo001mooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol00019ooooo`03o`000?oooooooooo
07[ooooo001nooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`1joooo
o`00Ooooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0N_ooool0083o
oooo00Wo0000ooooooooooooooooogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooo
oonHV9So410@00Kooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`1iooooo`00POoo
ool02?l0003oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`1iooooo`00P_ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0NOooool008?o
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo07Wo
oooo0024ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0B_ooool00ol0003ooooo
ooooo`1iooooo`00QOooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04[ooooo00?o
0000ooooooooool0NOooool008Kooooo00?o0000ooooooooool05_ooool2o`0004_ooooo00?o0000
ooooooooool0NOooool008Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1:oooo
o`03o`000?oooooooooo07Wooooo0028ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0Boooool00ol0003oooooooooo`1hooooo`00ROooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo04_ooooo00?o0000ooooooooool0N?ooool008[ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo07Sooooo002;ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`1hooooo`00S?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0N?ooool008go
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo07Oo
oooo002>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0C?ooool00ol0003ooooo
ooooo`1gooooo`00Soooool00ol0003oooooooooo`0=ooooo`;o0000COooool00ol0003ooooooooo
o`1gooooo`00Soooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04cooooo00?o0000
ooooooooool0Moooool0093ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1<oooo
o`03o`000?oooooooooo07Oooooo002Aooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0COooool00ol0003oooooooooo`1fooooo`00T_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo04gooooo00?o0000ooooooooool0M_ooool009?ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo07Kooooo002Dooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`1fooooo`00UOooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0MOooool009Go
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo07Go
oooo002Fooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0C_ooool00ol0003ooooo
ooooo`1eooooo`00Uoooool00ol0003oooooooooo`05ooooo`;o0000Coooool00ol0003ooooooooo
o`1eooooo`00V?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04kooooo00?o0000
ooooooooool0MOooool009Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1?oooo
o`03o`000?oooooooooo07Cooooo002Jooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0Coooool00ol0003oooooooooo`1dooooo`00V_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo04oooooo00?o0000ooooooooool0M?ooool009_ooooo00Go0000oooooooooooooooo
o`00001Aooooo`03o`000?oooooooooo07Cooooo002Looooo`04o`000?ooooooooooo`0005;ooooo
00?o0000ooooooooool0Loooool008Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1_ooool2o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooool00000D_ooool00ol0003ooooo
ooooo`1cooooo`00Q?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`00
0?oooooooooo00Cooooo0_l0001Booooo`03o`000?oooooooooo07?ooooo0024ooooo`05oa0@4?oo
ooooooooooooool@41002oooool5o`0000Gooooo1?l0001@ooooo`03o`000?oooooooooo07?ooooo
0024ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00007ooooo`03
o`000?oooooooooo053ooooo00?o0000ooooooooool0Loooool008Cooooo00Go0000oooooooooooo
ooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo0_l0001Booooo`03o`000?oooooooooo
07;ooooo0024ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007oooo
o`03o`000?oooooo0000057ooooo00?o0000ooooooooool0L_ooool008Cooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00Co0000oooooooooooo0000D?ooool0
0ol0003oooooooooo`1booooo`00Q?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMg
o`000?ooool01_ooool01?l0003oooooooooool0001@ooooo`03o`000?oooooooooo07;ooooo002O
ooooo`05o`000?ooooooooooooooool00000Coooool00ol0003oooooooooo`1booooo`00Woooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0LOooool0
09oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo
077ooooo002Oooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Boooool00ol0003o
ooooooooo`1aooooo`00Woooool2o`0000Gooooo00?o0000ooooooooool0Boooool00ol0003ooooo
ooooo`1aooooo`00Woooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o
0000ooooooooool0L?ooool009oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1:
ooooo`03o`000?oooooooooo073ooooo002Oooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0BOooool00ol0003oooooooooo`1`ooooo`00Woooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo04Wooooo00?o0000ooooooooool0Koooool009oooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo06oooooo002Oooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1_ooooo`00Woooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0K_ooool0
09oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo
06kooooo002Oooooo`;o00003Oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo06ko
oooo002Oooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0A_ooool00ol0003ooooo
ooooo`1]ooooo`00Woooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04Gooooo00?o
0000ooooooooool0KOooool009oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`14
ooooo`03o`000?oooooooooo06gooooo002Oooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0A?ooool00ol0003oooooooooo`1/ooooo`00Woooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo04?ooooo00?o0000ooooooooool0K?ooool009oooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo06cooooo002Oooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`1/ooooo`00Woooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0Joooool0
09oooooo0_l0000Eooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0Joooool009oo
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo06_o
oooo002Oooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`1[ooooo`00Woooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool0J_ooool009oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo06[ooooo002Oooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool0?_ooool00ol0003oooooooooo`1Zooooo`00Woooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool0J_ooool008Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo06Wooooo0024ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`1Y
ooooo`00Q?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`1Yooooo`00Q?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RH
ob4Q8@06ooooo`?o00007Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo06Wooooo
0024ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Ko
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo06So
oooo0024ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`1Xooooo`00
Q?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0J?ooool008Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo06Sooooo002Oooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Wooooo`00
Woooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
Ioooool009oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo06Oooooo002Oooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`1Vooooo`00Woooool2o`0002Gooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`1Vooooo`00Woooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool0I_ooool009oooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo06Gooooo002Oooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`1Uooooo`00Woooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0IOooool009oooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo06Cooooo002Oooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`1Tooooo`00
Woooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
I?ooool009oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo06?ooooo002Oooooo`;o0000;Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo06?ooooo002Oooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`1Sooooo`00Woooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool0Hoooool009oooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo06;ooooo002Oooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`1Rooooo`00Woooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0H_ooool009oooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06;ooooo002Oooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Qooooo`00
Woooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
HOooool009oooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo067ooooo002Oooooo`;o0000=Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo
oooo063ooooo002Oooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`1Pooooo`00Woooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool0H?ooool009oooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo063ooooo002Oooooo`03o`000?oooooooooo03Sooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`1Oooooo`00Woooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0Goooool009oooooo00?o0000oooo
ooooool0>Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo05oooooo0024ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1O
ooooo`00Q?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9So
oooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool0G_ooool008Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oo
ooooooooooooool000001_ooool3o`0003cooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`1Nooooo`00Q?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oooooo
V9RHoc8b<P06ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1Nooooo`00Q?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0
003o0000olc<c006ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`1Nooooo`00Q?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj
^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`1Nooooo`00Q?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000
okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`1Mooooo`00Q?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
ZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`1Mooooo`00Woooool00ol0003oooooooooo`11ooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool0GOooool009oooooo00?o0000ooooooooool0@_ooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo05gooooo002Oooooo`03o`000?oooooooooo
04?ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1Mooooo`00Woooool00ol0003o
ooooooooo`14ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0G?ooool009oooooo
0_l00016ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0G?ooool009oooooo00?o
0000ooooooooool0AOooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo05cooooo002O
ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1L
ooooo`00Woooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool0G?ooool009oooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo05_ooooo002Oooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`1Kooooo`00Woooool00ol0003oooooooooo`1:ooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool0Foooool009oooooo00?o0000ooooooooool0B_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05_ooooo002Oooooo`03o`000?oooooooooo
04_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Kooooo`00Woooool2o`0004go
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1Kooooo`00Woooool00ol0003ooooo
ooooo`1=ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0F_ooool009oooooo00?o
0000ooooooooool0C_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo05[ooooo002O
ooooo`03o`000?oooooooooo04oooooo0_l0000Hooooo`03o`000?oooooooooo05[ooooo002Ooooo
o`03o`000?oooooooooo057ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Joooo
o`00Woooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0F_ooool009oooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo05[ooooo002Oooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`1Jooooo`00Woooool00ol0003oooooooooo`1Eooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool0FOooool009oooooo0_l0001Gooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0FOooool009oooooo00?o0000ooooooooool0Eoooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo05Wooooo002Oooooo`03o`000?oooooooooo05Sooooo
0_l0000@ooooo`03o`000?oooooooooo05Wooooo002Oooooo`03o`000?oooooooooo05[ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`1Iooooo`00Woooool00ol0003oooooooooo`1K
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0FOooool009oooooo00?o0000oooo
ooooool0G?ooool2o`0000cooooo00?o0000ooooooooool0FOooool009oooooo00?o0000oooooooo
ool0G_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05[ooooo002Eooooo`Co0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0F_ooool009Oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1Pooooo`;o00001_ooool2o`0005cooooo002Gooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0H_ooool3o`000003ooooool0003o000005kooooo002Gooooo`03o`000?oooooooooo
00Gooooo0ol0001Uooooo`03o`000?oooooooooo05kooooo002Gooooo`03o`000?oooooooooo0<ko
oooo002Gooooo`03o`000?oooooooooo0<kooooo002Gooooo`03o`000?oooooooooo0<kooooo002E
ooooo`03oeEEEOmVIVKo00000=3ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
002Tooooo`05oiRHV?l0003o0000odA4A?nj^[X02Oooool5o`0000Gooooo0_lQ8B46ooooo`;o0000
00?o410@ooooooooool0Woooool00:Cooooo00Go410@okZj^_o^k^koMgMgoa0@4002ooooo`Ko0000
00KooooooiRHV?lQ8B7ok^k^oooooom4A4@5ooooo`;o8B4Q1oooool00ol0003oooooooooo`2Poooo
o`00Y?ooool00ol0003oooooooooo`0<ooooo`03oiRHV?lQ8B7ok^k^00cooooo1Ol0002Qooooo`00
Y?ooool00ol0003oooooooooo`04ooooo`Ko00000oooool00onHV9So8B4Qonk^kP0;ooooo`04odA4
A?oMgMgoooooo`000:;ooooo002Tooooo`03o`000?oooooooooo00kooooo00?oMgMgofIVI_ooool0
2_ooool01?oMgMgoEEEEooooool0002Rooooo`00X_ooool00ol@413o0000o`000003o`0000kooooo
00?o0000ooooooooool02_ooool00omgMgOoc<c<o`00002Rooooo`00Y?ooool00ol0003ooooooooo
o`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00oo^k^koA4A4o`00002Rooooo`00Y?oo
ool00ol0003oooooooooo`0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03Oooool00omgMgOo0000
ooooo`2Qooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.68406, -0.0802184, \
0.0288357, 0.00666531}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "The bottom of the pulse does not move, because the wave amplitude is zero \
there. (Recall that this pulse is a wave as seen in a frame that moves with \
the linear wave speed. Linear waves would not evolve at all in this moving \
frame.) The peak of the pulse moves the fastest because wave speed increases \
with increasing amplitude.  Eventually",
  ",",
  " the peak overtakes the rest of the pulse. This solution exhibits ",
  StyleBox["wavebreaking",
    FontSlant->"Italic"],
  ": the solution becomes double-valued at around ",
  Cell[BoxData[
      \(TraditionalForm\`t = 1\)]],
  ". This phenomenon is familiar to anyone who has enjoyed watching waves \
curl and collapse on the beach. Our nonlinear wave equation cannot describe \
the collapse of the wave, which occurs because the wave crest is no longer \
supported by the fluid below it. However, it has captured the essential \
behavior of a breaking wave up to the point where the solution becomes \
double-valued.  "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Wavebreaking Time", "Section",
  CellTags->{"i:16", "c:13"}],

Cell[TextData[{
  "\tThe wavebreaking can also be understood by examining the characteristics \
. One can see from Eq. ",
  ButtonBox["(7.1.34)",
    ButtonData:>{"Chapter7.nb", "(7.1.34)"},
    ButtonStyle->"Hyperlink"],
  "  or Fig. ",
  ButtonBox["7.4",
    ButtonData:>"Fig. 7.4",
    ButtonStyle->"Hyperlink"],
  " that there are places where the characteristics cross. At such points \
values of ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " that were initially separated in ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " come to the same position, implying that the solution has become \
double-valued in ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tAlthough different characteristics cross at different places and times, \
it is evident that there is a  time ",
  Cell[BoxData[
      \(TraditionalForm\`t\_o\)]],
  " when the crossing of characteristics first occurs. At this instant, the \
",
  StyleBox["wavebreaking time",
    FontSlant->"Italic"],
  ", the solution goes from being a single-valued function of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " to being double-valued. "
}], "Text"],

Cell[TextData[{
  "\t\tIn order to determine the wavebreaking time, let us consider two \
characteristics that arise from initial conditions ",
  Cell[BoxData[
      \(TraditionalForm\`x\_\(o\ 1\)\)]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(x\_\(o\ 2\)\), "=", 
          RowBox[{\(x\_\(o\ 1\)\), "+", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  " . These characteristics cross when ",
  Cell[BoxData[
      \(TraditionalForm\`x(t, x\_\(o\ 1\)) = x(t, x\_\(o\ 2\))\)]],
  ". Applying Eq. ",
  ButtonBox["(7.1.34)",
    ButtonData:>{"Chapter7.nb", "(7.1.34)"},
    ButtonStyle->"Hyperlink"],
  "  then yields a crossing time ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(t\)\(\ \)\)\)]],
  " given by"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`x\_\(o\ 1\)\  + \ \(\(f\_o\)(x\_\(o\ 1\))\)\ t\  = \ 
        x\_\(o\ 2\) + \ \(\(f\_o\)(x\_\(o\ 2\))\)\ t\)]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "Solving for  ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " yields"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{"t", "=", 
        RowBox[{\(-\(\(x\_\(o\ 1\) - x\_\(o\ 2\)\)\/\(f(x\_\(o\ 1\)) - 
                  f(x\_\(o\ 2\))\)\)\), "=", 
          RowBox[{
            FractionBox[
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]], 
              RowBox[{\(f(x\_\(o\ 1\))\), "-", 
                RowBox[{"f", "(", 
                  RowBox[{\(x\_\(\(o\)\(\ \)\(1\)\(\ \)\)\), "+", " ", 
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["x",
                          FontSlant->"Italic"]}]]}], ")"}]}]], "."}]}]}], 
      TraditionalForm]]]], "NumberedEquation",
  CellTags->"(7.1.35)"],

Cell[TextData[{
  "Assuming for the moment that ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " is small, we Taylor expand ",
  Cell[BoxData[
      FormBox[
        RowBox[{"f", "(", 
          RowBox[{\(x\_\(o\ 1\)\), "+", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]]}], ")"}], TraditionalForm]]],
  " to first",
  "-order",
  " in ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " and so obtain"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`t = \(-\(1\/\(\[DifferentialD]f\_o/\[DifferentialD]x\
\_\(o\ 1\)\)\)\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(7.1.36)"],

Cell[TextData[{
  "To find the wavebreaking time ",
  Cell[BoxData[
      \(TraditionalForm\`t\_o\)]],
  ", we find the minimum (positive) value for ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`t\_o = 
        min\ \((\(-\(1\/\(\[DifferentialD]f\_o/\[DifferentialD]x\_\(o\ \
1\)\)\)\)\ )\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(7.1.37)"],

Cell[TextData[{
  "That is, we look for the maximum value of ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[DifferentialD]f\_o\)/\[DifferentialD]x\_\(o\ \
1\)\)]],
  ". This maximum will occur at the inflection point in ",
  Cell[BoxData[
      \(TraditionalForm\`f\_o\)]],
  ", where"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[DifferentialD]\^2 f\_o/\[DifferentialD]x\_\(o\ \
1\)\^2 = 0\)]]], "NumberedEquation",
  CellTags->"(7.1.38)"],

Cell["and", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]\^3 f\_o/\[DifferentialD]x\_\(o\ 1\)\
\^3 > 0\)]],
  "."
}], "NumberedEquation",
  CellTags->"(7.1.39)"],

Cell[TextData[{
  "For our Gaussian initial condition, there is only one inflection point \
with ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[DifferentialD]f\_o\)/\[DifferentialD]x\_\(o\ \
1\) > 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]\^2 f\_o/\[DifferentialD]x\_\(o\ 1\)\
\^2 = 0\)]],
  ". It may be found easily using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " : "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Factor[D[f0[x0], {x0, 2}]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.27"],

Cell[BoxData[
    \(2\ \[ExponentialE]\^\(-x0\^2\)\ \((\(-1\) + 2\ x0\^2)\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Thus, the inflection point happens at ",
  Cell[BoxData[
      \(TraditionalForm\`x\_\(0\ 1\) = \ 1/\@2\)]],
  ". At this point -",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]f\_o/\[DifferentialD]x\_\(o\ \
1\)\)]],
  " is given by "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(-\(f0'\)[1/Sqrt[2]]\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.28"],

Cell[BoxData[
    \(\@\(2\/\[ExponentialE]\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Therefore, the wavebreaking time for our Gaussian initial condition is ",
  Cell[BoxData[
      \(TraditionalForm\`t\_o = \(\@\(\[ExponentialE]/2\) = 0.858 ... \)\)]],
  ". This agrees with the results of the previous  animation. "
}], "Text"],

Cell[TextData[{
  "\tWe found the wavebreaking time by assuming that nearby characteristics \
were the first to cross, so that a first-order Taylor expansion of Eq. ",
  ButtonBox["(7.1.35)",
    ButtonData:>{"Chapter7.nb", "(7.1.35)"},
    ButtonStyle->"Hyperlink"],
  "  was allowed. We must now show that the minimum wavebreaking time really \
does occur for nearby characteristics. To do so, we keep up to third-order \
terms in ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " in Eq. ",
  ButtonBox["(7.1.35)",
    ButtonData:>{"Chapter7.nb", "(7.1.35)"},
    ButtonStyle->"Hyperlink"],
  " , and vary with respect to ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ".  Equation(7.1.36) is then replaced by"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{"t", "=", 
        RowBox[{"-", 
          RowBox[{
            FractionBox["1", 
              
              RowBox[{\(\[DifferentialD]f\_o/\[DifferentialD]x\_\(o\ 1\)\), 
                "+", " ", 
                RowBox[{
                  FractionBox[
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["x",
                          FontSlant->"Italic"]}]], 
                    "2"], \(\[DifferentialD]\^2 f\_o/\[DifferentialD]x\_\(o\ \
1\)\%\(\(\ \)\(2\)\)\)}], "+", 
                RowBox[{
                  FractionBox[
                    SuperscriptBox[
                      StyleBox[
                        RowBox[{"\[CapitalDelta]", 
                          StyleBox["x",
                            FontSlant->"Italic"]}]], "2"], 
                    "6"], \(\[DifferentialD]\^3 f\_o/\[DifferentialD]x\_\(o\ \
1\)\%\(\(\ \)\(3\)\)\)}]}]], "."}]}]}], 
      TraditionalForm]]]], "NumberedEquation",
  CellTags->"(7.1.40)"],

Cell[TextData[{
  "However, at the inflection point",
  ",",
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]\^2 f\_o/\[DifferentialD]x\_\(o\ 1\)\
\%\(\(\ \)\(2\)\) = 0\)]],
  " and this expression becomes"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{"t", "=", 
        RowBox[{
          FractionBox["1", 
            
            RowBox[{\(\(-\[DifferentialD]f\_o\)/\[DifferentialD]x\_\(o\ 1\)\),
               "-", 
              RowBox[{
                FractionBox[
                  SuperscriptBox[
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["x",
                          FontSlant->"Italic"]}]], "2"], 
                  "6"], \(\[DifferentialD]\^3 f\_o/\[DifferentialD]x\_\(o\ \
1\)\%\(\(\ \)\(3\)\)\)}]}]], "."}]}], TraditionalForm]]]], "NumberedEquation",\

  CellTags->"(7.1.41)"],

Cell[TextData[{
  "Since both ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[DifferentialD]f\_o\)/\[DifferentialD]x\_\(o\ \
1\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]\^3 f\_o/\[DifferentialD]x\_\(o\ 1\)\
\%\(\(\ \)\(3\)\)\)]],
  " are greater than zero, the minimum value of ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " occurs at ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], "\[Rule]", "0"}], 
        TraditionalForm]]],
  ", proving that the minimum wavebreaking time happens for closely separated \
characteristics, and is given by Eq. ",
  ButtonBox["(7.1.37)",
    ButtonData:>{"Chapter7.nb", "(7.1.37)"},
    ButtonStyle->"Hyperlink"],
  " ."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises for Sec. 7.1", "Subsubtitle",
  CellTags->"c:14"],

Cell[TextData[{
  StyleBox["(1)",
    FontWeight->"Bold"],
  " For the following PDEs,"
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " find the characteristics, and plot them for ",
  Cell[BoxData[
      \(TraditionalForm\`x\_0\  = \(-1\), 0, \ and\ 1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 2\)]],
  "; "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " solve the PDEs  for ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, t)\)]],
  ":"
}], "Text"],

Cell[TextData[{
  "(i) ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]f\/\[PartialD]t + \[ExponentialE]\^\(-x\)\
\ \ \[PartialD]f\/\[PartialD]x = 0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, 0)\  = \ \[ExponentialE]\^\(-x\^2\)\)]],
  ". Animate the solution for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 2\)]],
  " on ",
  Cell[BoxData[
      \(TraditionalForm\`\(-3\) < x < 3\)]],
  "."
}], "Text"],

Cell[TextData[{
  "(ii) ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]f\/\[PartialD]t + 
          6 \[PartialD]f\/\[PartialD]x = \(-f\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, 0) = sin\ x\)]],
  ". Animate for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 2\)]],
  "  on ",
  Cell[BoxData[
      \(TraditionalForm\`\(-2\) \[Pi] < x < 2  \[Pi]\)]],
  "."
}], "Text"],

Cell[TextData[{
  "(iii) ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]f\/\[PartialD]t - 
          x\ \[PartialD]f\/\[PartialD]x = \ log(x\^2)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, 0)\  = 0\)]],
  ". Animate for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 2\)]],
  " on ",
  Cell[BoxData[
      \(TraditionalForm\`\(-5\) < x < 5\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(2)",
    FontWeight->"Bold"],
  " Prove Eq. ",
  ButtonBox["(7.1.24)",
    ButtonData:>{"Chapter7.nb", "(7.1.24)"},
    ButtonStyle->"Hyperlink"],
  " ."
}], "Text"],

Cell[TextData[{
  StyleBox["(3)",
    FontWeight->"Bold"],
  " A radio wave packet with central frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o\)]],
  " travels in the ",
  Cell[BoxData[
      \(TraditionalForm\`\(+x\)\)]],
  " direction through a nonuniform plasma. The dispersion relation for the \
waves is ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\^2\  = \ \[Alpha]\^2\ x\^2\  + \ 
          c\^2\ k\^2\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " is the speed of light and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " is a constant. "
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Using the equations of geometrical optics, Eqs. ",
  ButtonBox["(5.2.48)",
    ButtonData:>{"Chapter5.nb", "(5.2.48)"},
    ButtonStyle->"Hyperlink"],
  " , show that the local wavenumber satisfies ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\^\(\(2\)\(\ \)\)\) \(\(k\^2\)(
            x)\) = \[Omega]\_o\%2 - \ \[Alpha]\^2\ x\^2\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Find the characteristics for the energy equation ",
  ButtonBox["(5.2.59)",
    ButtonData:>{"Chapter5.nb", "(5.2.59)"},
    ButtonStyle->"Hyperlink"],
  " . In particular, show that ",
  Cell[BoxData[
      \(TraditionalForm\`x(
          t)\  = \ \(\[Omega]\_o\/\[Alpha]\) \(sin(\ \ \(\(c\ \[Alpha]\)\/\
\[Omega]\_o\) t + a)\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " is a constant of integration."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Use the method of characteristics to solve the energy equation. Show that \
for a given initial energy density ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Epsilon]\_o\)(x)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon](x, t)\)]],
  " is given by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon](x, 
          t)\  = \ \(\(\[Epsilon]\_o\)(
            x\_o)\)\ \(cos(
              a)\)/\(cos(\(\(c\ \[Alpha]\)\/\[Omega]\_o\) t + a)\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`a = \(sin\^\(-1\)\)(\[Alpha]\ x/\[Omega]\_o)\  - \ 
          c\ \[Alpha]\ t/\[Omega]\_o\)]],
  ", and where ",
  Cell[BoxData[
      \(TraditionalForm\`x\_o = \(\[Omega]\_\(\(o\)\(\ \)\)\) \(sin(
              a)\)/\[Alpha]\)]],
  " is the initial condition. Animate this result on ",
  Cell[BoxData[
      \(TraditionalForm\`\(-5\) < x < 10\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 1.5\)]],
  ", assuming that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Epsilon]\_o\)(
          x\_o) = \[ExponentialE]\^\(-x\_o\^2\)\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(c = \(\[Alpha] = 1\)\)\(,\)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o = 10\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(4)",
    FontWeight->"Bold"],
  "  The dispersion relation for the waves in a time-dependent inhomogeneous  \
2D system  is ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\  = \ x\ k\_x\  + \ t\ y\ k\_y\)]],
  ". A wave packet initially has wave action ",
  Cell[BoxData[
      \(TraditionalForm\`N(x, y, 
          t = 0) = \[ExponentialE]\^\(\(-2\) \((x\^2 + y\^2)\)\)\)]],
  ". Solve Eq. ",
  ButtonBox["(5.3.23)",
    ButtonData:>{"Chapter5.nb", "(5.3.23)"},
    ButtonStyle->"Hyperlink"],
  "  for the wave action ",
  Cell[BoxData[
      \(TraditionalForm\`N(x, y, t)\)]],
  " using the method of characteristics. Animate the result using a series of \
",
  StyleBox["Plot3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "commands in the time interval ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 2\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(5)",
    FontWeight->"Bold"],
  " In the Galerkin method, it is often rather difficult to find basis \
functions that satisfy von Neumann boundary conditions in two- or \
three-dimensional domains. The method of characteristics can be used to \
determine the basis functions in this case. Take, for example, a \
2-dimensional domain with a surface ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " determined by the equation ",
  Cell[BoxData[
      \(TraditionalForm\`z(x, y)\  = \ 0\)]],
  ". We wish to find basis functions ",
  Cell[BoxData[
      \(TraditionalForm\`v\_\(i\ j\)\)]],
  "that satisfy ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              StyleBox["n",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              "\[CenterDot]", \(\[Del]\(\(v\_\(i\ j\)\)(x, 
                  y)\)\)}], \( | \_S\)}], "=", "0"}], TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      FormBox[
        StyleBox["n",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " is any normal vector to the surface ; for example, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["n",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox[\(\[Del]\(z(x, y)\)\),
            FontWeight->"Plain"]}], TraditionalForm]]],
  ". \t"
}], "Text",
  CellTags->"i:21"],

Cell["\tConsider the following first-order PDE:", "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["n",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            "\[CenterDot]", \(\[Del]\(\(v\_\(i\ j\)\)(x, y)\)\)}], 
          "=", \(\(z(x, y)\)\ x\^i\ y\^j\)}], TraditionalForm]]]
}], "NumberedEquation",
  CellTags->"(7.1.42)"],

Cell[TextData[{
  "If we solve this PDE inside the domain, then by construction we will have \
found functions ",
  Cell[BoxData[
      \(TraditionalForm\`v\_\(i\ j\)\)]],
  " that satisfy ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              StyleBox["n",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              "\[CenterDot]", \(\[Del]\(\(v\_\(i\ j\)\)(x, 
                  y)\)\)}], \( | \_S\)}], "=", "0"}], TraditionalForm]]],
  "because ",
  Cell[BoxData[
      \(TraditionalForm\`z(x, y) = 0\)]],
  " on ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  ".  \n\tFor instance, consider the elliptical domain specified by ",
  Cell[BoxData[
      \(TraditionalForm\`z(x, y) = x\^2/a\^2 + y\^2/b\^2 - 1\)]],
  ". A normal vector to this domain is ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["n",
            FontWeight->"Bold",
            FontSlant->"Plain"], "=", \((1, y\ a\^2/x\ b\^2)\)}], 
        TraditionalForm]]],
  ". Using this normal vector in Eq. ",
  ButtonBox["(7.1.42)",
    ButtonData:>{"Chapter7.nb", "(7.1.42)"},
    ButtonStyle->"Hyperlink"],
  " , and applying the method of characteristics, show that"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          RowBox[{\(\(v\_\(i\ j\)\)(x, y)\), "=", 
            RowBox[{\(x\^\(\(\ \)\(i\)\)\), 
              RowBox[{\(y\^j\), "   ", 
                StyleBox["[",
                  FontSize->16], 
                " ", \(\((\(b\^2\) i\  + \ \(a\^2\) 
                          j)\) \((x\^2\/\(\(a\^2\)(2\ b\^2 + \(b\^2\) i\  + \ \
\(a\^2\) j)\) + 
                        y\^2\/\(\(\(b\^2\)(2\ a\^2 + \ \(b\^2\) i\  + \ \
\(a\^2\) j)\)\(\ \)\)\ )\) - 1\), 
                StyleBox["]",
                  FontSize->16]}]}]}],
          "TraditionalForm"], ",", 
        RowBox[{
          FormBox[\(i, j \[GreaterEqual] \ 0\),
            "TraditionalForm"], "."}]}], TraditionalForm]]]], "UNNEQ"],

Cell[TextData[{
  StyleBox["(6)(a)",
    FontWeight->"Bold"],
  " Particles in an ideal gas are confined in a harmonic well of the form ",
  Cell[BoxData[
      \(TraditionalForm\`V(x)\  = \ m\ \(\[Omega]\_o\^2\) x\^2/2\)]],
  ". Initially, the particles are distributed in phase space according to ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, p, t = 0) = \ 
        N\ \(\[Delta](p)\)/a, \ \(\(|\)\(x\)\(|\)\(\(<\)\(a\)\)\)\)]],
  "; ",
  Cell[BoxData[
      \(TraditionalForm\`f = 0\)]],
  " otherwise. Find the phase-mixed equilibrium solution ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_eq\)(x, p)\)]],
  " for this initial condition. "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Simulate this problem, for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 10\ \[Pi]/\[Omega]\_o\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(N\)\(=\)\(100\)\(\ \)\)\)]],
  "particles. Show from the movie of the particle phase space orbits that \
phase mixing ",
  StyleBox["does not",
    FontSlant->"Italic"],
  " occur, and explain why, in a few words. "
}], "Text"],

Cell[TextData[{
  StyleBox["(7)",
    FontWeight->"Bold"],
  " Find the wavebreaking time ",
  Cell[BoxData[
      \(TraditionalForm\`t\_o\)]],
  " for the following initial condition in Eq. ",
  ButtonBox["(7.1.30)",
    ButtonData:>{"Chapter7.nb", "(7.1.30)"},
    ButtonStyle->"Hyperlink"],
  " : ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, 0) = A\ sin\ k\ x\)]],
  ". Animate the solution for ",
  Cell[BoxData[
      \(TraditionalForm\`k = \(A = 1\)\)]],
  " on ",
  Cell[BoxData[
      \(TraditionalForm\`\(-2\) \[Pi] < x < 2  \[Pi]\)]],
  " for  ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 2\ t\_o\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(8)",
    FontWeight->"Bold"],
  " Find the solution to the following nonlinear first-order partial \
differential equation using the method of characteristics on ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Infinity]\) < x < \[Infinity]\)]],
  ":"
}], "Text"],

Cell[TextData[{
  "\t\t ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FractionBox[\(\[PartialD]\(f(x, t)\)\), \(\[PartialD]t\),
              MultilineFunction->None], "+", 
            RowBox[{\(\(f\^2\)(x, t)\), 
              FractionBox[\(\[PartialD]\(f(x, t)\)\), \(\[PartialD]x\),
                MultilineFunction->None]}]}], "=", "0"}], TraditionalForm]]],
  "  [initial condition ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, 0) = sin(2\ x)\)]],
  "]."
}], "Text"],

Cell[TextData[{
  "Find the time to the formation of a singularity in the solution (the \
wavebreaking time ",
  Cell[BoxData[
      \(TraditionalForm\`t\_o\)]],
  "). Make an animation of the evolution of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(f(x, t)\)\)\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < \[Pi]\)]],
  " and for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 2  t\_o\)]]
}], "Text"],

Cell[TextData[{
  StyleBox["(9)(a)",
    FontWeight->"Bold"],
  " Find the solution to the following nonlinear PDE using the method of \
characteristics on ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Infinity]\) < x < \[Infinity]\)]],
  ":"
}], "Text"],

Cell[TextData[{
  StyleBox[" ", "UNNEQ"],
  StyleBox[Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FractionBox[\(\[PartialD]\(u(x, t)\)\), \(\[PartialD]t\),
              MultilineFunction->None], "+", 
            RowBox[{\(u(x, t)\), 
              FractionBox[\(\[PartialD]\(u(x, t)\)\), \(\[PartialD]x\),
                MultilineFunction->None]}]}], "=", \(-\ u\)}], 
        TraditionalForm]], "UNNEQ"], "UNNEQ"],
  StyleBox["  [initial condition ", "UNNEQ"],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`u(x, 0) = a\ \(exp(\(-2\)\ x\^2)\)\)], "UNNEQ"], 
    "UNNEQ"],
  StyleBox["].", "UNNEQ"]
}], "UNNEQ",
  CellTags->"i:22"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " For this initial condition, with ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(a\  = \ 1\)\(,\)\)\)]],
  " find the time ",
  Cell[BoxData[
      \(TraditionalForm\`t\_o\)]],
  "to the formation of a singularity in the solution."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Make an animation of the evolution of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(u(x, t)\)\)\)]],
  "  for ",
  Cell[BoxData[
      \(TraditionalForm\`\(-5\) < x < 5\)]],
  " and for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 2  t\_o\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " Find the value of ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " below which no singularity forms, because the solution decays away before \
wave breaking can occur.  (Answer: ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(a\)\(=\)\(0.824631 ... \)\(\ \)\)\)]],
  ") "
}], "Text"],

Cell[TextData[{
  StyleBox["(10)",
    FontWeight->"Bold"],
  " Consider the following simple model for the flow of traffic in a freeway. \
 The cars are modelled as a fluid of density ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, t)\)]],
  ". Cars move to the right with a speed that depends on this density. At low \
densities, the cars move at the speed limit ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  ". But at higher traffic density, their speed is reduced. In our simple \
model, we assume that the speed depends on density as ",
  Cell[BoxData[
      \(TraditionalForm\`c - f\)]],
  ".  According to the Boltzmann equation, the density will then obey"
}], "Text",
  CellTags->"i:23"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[PartialD]f\/\[PartialD]t + \((c - 
              f)\) \[PartialD]f\/\[PartialD]x = \(\(s\)\(.\)\)\)]]], \
"NumberedEquation",
  CellTags->"(7.1.43)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  " is a source of cars (such as an on ramp). "
}], "Text"],

Cell[TextData[{
  "Show that for ",
  Cell[BoxData[
      \(TraditionalForm\`s = 0\)]],
  " and for any nonuniform initial condition with regions of positive slope \
(i.e., traffic density increasing in the direction of flow)  the slope \
increases until the solution becomes double-valued, after which it is no \
longer valid. These regions of increasing slope propagate along the freeway \
(the phenomenon of sudden traffic slowdowns for no apparent reason, familiar \
to any freeway driver). Illustrate this by means of an animation, taking ",
  Cell[BoxData[
      \(TraditionalForm\`c = 1, s = 0\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, 0)\  = \ 0.2\  + \ 0.5\ \(sin\^2\) x\)]],
  ".  See the exercises in Sec. ",
  ButtonBox["7.2",
    ButtonData:>"c:26",
    ButtonStyle->"Hyperlink"],
  ", and ",
  ButtonBox["Whitham (1999)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  "  for other freeway models."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["7.2 The KdV equation ", "Subtitle",
  CellTags->{"i:24", "c:15"}],

Cell["", "Text"],

Cell[CellGroupData[{

Cell["7.2.1 Shallow Water Waves with Dispersion", "Subsubtitle",
  CellTags->"c:16"],

Cell["", "Text"],

Cell["\<\
\tIn the previous discussion of nonlinear shallow water waves, \
dispersion was neglected: the wave speed was independent of wavenumber \
(although it depended on amplitude). In this section we will see that adding \
dispersion has an important effect : it suppresses the wavebreaking.  The \
basic reason is easy to understand: dispersion causes waves to spread, and \
this acts against the steepening effect of the nonlinearity.\
\>", "Text"],

Cell["\<\
\tFor linear water waves without surface tension, we have \
previously seen that the dispersion relation is \
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Omega](k) = \@\(g\ k\ \ tanh\ k\ h\)\)]],
  " "
}], "NE2",
  CellTags->"(7.2.1)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`h\)]],
  " is the depth [see Exercise (3), Sec. ",
  ButtonBox["5.1",
    ButtonData:>{"Chapter5.nb", "c:18"},
    ButtonStyle->"Hyperlink"],
  "]. For long wavelengths where ",
  Cell[BoxData[
      \(TraditionalForm\`k\ h << 1\)]],
  ", this returns to the shallow-water result, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega](k) = \(\(c\_o\) k\  = \@\(g\ h\)\ k\)\)]],
  ".  When small nonlinearity is added the resulting wave equation is Eq. ",
  ButtonBox["(7.1.29)",
    ButtonData:>{"Chapter7.nb", "(7.1.29)"},
    ButtonStyle->"Hyperlink"],
  " . However, if ",
  Cell[BoxData[
      \(TraditionalForm\`k\ h\)]],
  " is not infinitesimally small, then we need to keep dispersion in the \
equation. If we expand ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega](k)\)]],
  " in small ",
  Cell[BoxData[
      \(TraditionalForm\`k\ h\)]],
  ", we obtain a correction to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega](k)\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Series[Sqrt[\ g\ k\ Tanh[k\ h]], {k, 0, 3}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.29"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{\(\@\(g\ h\)\ k\), "-", \(1\/6\ \((h\^2\ \@\(g\ h\))\)\ k\^3\), 
        "+", 
        InterpretationBox[\(O[k]\^4\),
          SeriesData[ k, 0, {}, 1, 4, 1]]}],
      SeriesData[ k, 0, {
        Power[ 
          Times[ g, h], 
          Rational[ 1, 2]], 0, 
        Times[ 
          Rational[ -1, 6], 
          Power[ h, 2], 
          Power[ 
            Times[ g, h], 
            Rational[ 1, 2]]]}, 1, 4, 1]]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Thus, the lowest",
  "-order",
  " correction to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega](k)\)]],
  " is"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Omega](
          k) = \ \(\(c\_o\) \(k(\ 
            1\  - \(1\/6\) \(k\^2\) h\^2)\)\(\ \)\)\)]],
  "."
}], "NE2",
  CellTags->"(7.2.2)"],

Cell[TextData[{
  "This correction can be added to Eq. ",
  ButtonBox["(7.1.29)",
    ButtonData:>{"Chapter7.nb", "(7.1.29)"},
    ButtonStyle->"Hyperlink"],
  "  by appending a term:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]z\/\[PartialD]t + \(\(c\_o\)(
              1 + \(3\/2\) z\/h)\) \[PartialD]z\/\[PartialD]x\  + \(1\/6\) 
            c\_o\ \(h\^2\) \[PartialD]\^3 z\/\[PartialD]x\^3\  = 0\)]],
  "."
}], "NE2",
  CellTags->"(7.2.3)"],

Cell["\<\
If we neglect the nonlinear term (assuming small amplitude \
disturbances), and Fourier transform this equation in time and space, we \
obtain\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\((\(-\[ImaginaryI]\)\ \[Omega]\  + \ \
\[ImaginaryI]\ c\_o\ k\  + \ \[ImaginaryI]\ \(1\/6\) c\_o\ \(h\^2\) 
                k\^3)\) \(\(z\&~\)(k, \[Omega])\)\)\(=\)\(0\)\(\ \)\)\)]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "This yields the linear dispersion relation of Eq. ",
  ButtonBox["(7.2.2)",
    ButtonData:>{"Chapter7.nb", "(7.2.2)"},
    ButtonStyle->"Hyperlink"],
  " . "
}], "Text"],

Cell[TextData[{
  "\tWe can put Eq. ",
  ButtonBox["(7.2.3)",
    ButtonData:>{"Chapter7.nb", "(7.2.3)"},
    ButtonStyle->"Hyperlink"],
  "  into a standard format using the same transformations as we used for Eq. \
",
  ButtonBox["(7.1.30)",
    ButtonData:>{"Chapter7.nb", "(7.1.30)"},
    ButtonStyle->"Hyperlink"],
  " : ",
  Cell[BoxData[
      \(TraditionalForm\`x\&_ = x - \(c\_\(\(o\)\(\ \)\)\) t\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`f(x\&_, t) = 3\ c\_o\ z/\((2\ h)\)\)]],
  ". The result is the ",
  StyleBox[ButtonBox["Korteweg",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Korteweg.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  StyleBox["-de Vries",
    FontSlant->"Italic"],
  " (",
  StyleBox["KdV) equation",
    FontSlant->"Italic"],
  ":"
}], "Text",
  CellTags->"i:25"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]f\/\[PartialD]t + 
          f \[PartialD]f\/\[PartialD]x + \[Alpha]\ \[PartialD]\^3 f\/\
\[PartialD]x\^3 = 0\)]],
  ", "
}], "NE2",
  CellTags->"(7.2.4)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] = \ c\_o\ h\^2/6\)]],
  ", and where we have dropped the overbar on ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " for convenience.  "
}], "Text"],

Cell["\<\
\tBecause the KdV equation is not first-order, we can no longer \
apply the method of characteristics. However, analytic solutions of the \
equation can be found using advanced inverse-scattering methods that are \
beyond the scope of this book. Here, for general initial conditions, we will \
content ourselves with a purely numerical solution to the problem. \
\>", \
"Text"],

Cell[TextData[{
  "\tHowever, there is one type of analytic solution that can be derived with \
relative ease:  steady solutions, where ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " is time-independent when observed in a comoving frame. These solutions \
will be the subject of the next subsection."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["7.2.2 Steady Solutions: Cnoidal Waves and Solitons", "Subsubtitle",
  CellTags->{"i:26", "c:17"}],

Cell[TextData[{
  "\tThe ",
  "KdV",
  " equation admits steady solutions of the form ",
  Cell[BoxData[
      \(TraditionalForm\`f = f(x - v\ t)\)]],
  ". In a frame moving with speed ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  ", such solutions are time-independent. These solutions occur because \
nonlinear steepening of the waves is in balance with dispersive broadening, \
allowing an equilibrium as viewed in the moving frame."
}], "Text"],

Cell[TextData[{
  "\tIn order to find the form of these steady solutions, we define the \
variable ",
  Cell[BoxData[
      \(TraditionalForm\`s = x - \ v\ t\)]],
  ". Then we assume ",
  Cell[BoxData[
      \(TraditionalForm\`f = f(s)\)]],
  ",so that ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]f/\[PartialD]x = \[DifferentialD]f/\
\[DifferentialD]s\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]f/\[PartialD]t = \(-v\) \
\[DifferentialD]f/\[DifferentialD]s\)]],
  ". The ",
  "KdV",
  " equation then becomes the following ODE:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(-v\) \[DifferentialD]f\/\[DifferentialD]s + 
          f \[DifferentialD]f\/\[DifferentialD]s + \[Alpha]\ \[DifferentialD]\
\^3 f\/\[DifferentialD]s\^3 = 0\)]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "Writing ",
  Cell[BoxData[
      \(TraditionalForm\`f\ \[DifferentialD]f/\[DifferentialD]s = \(1\/2\) \(\
\[DifferentialD]\/\[DifferentialD]s\) f\^2\)]],
  " allows us to integrate this third-order ODE once, yielding the following \
second",
  "-order",
  " ODE:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(-v\)\ f + \(1\/2\) 
            f\^2 + \[Alpha]\ \[DifferentialD]\^2 f\/\[DifferentialD]s\^2 = 
        A\)]],
  ","
}], "UNNEQ"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " is a constant of integration. If we now rearrange terms, writing ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\ \[DifferentialD]\^2 \
f\/\[DifferentialD]s\^2 = A + v\ f\  - \ \(1\/2\) f\^2\)]],
  ", we can see that this equation is of the same form as Newton's second \
law, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(m\)\(\ \)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]\^2 x\/\[DifferentialD]t\^2 = 
        F(x)\)]],
  ", where the mass ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " replaces ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  ", the position ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " replaces ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  ", the time ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " replaces ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  ",  and the force ",
  Cell[BoxData[
      \(TraditionalForm\`F(x)\)]],
  " replaces the ",
  "right-hand",
  " side. Equations of this type have a constant of integration: the energy \
",
  Cell[BoxData[
      \(TraditionalForm\`E\  = \ \(1\/2\) 
            m\ \((\[DifferentialD]x\/\[DifferentialD]t)\)\^2 + \ V(x)\)]],
  ", where the potential ",
  Cell[BoxData[
      \(TraditionalForm\`V(x)\)]],
  " is given by ",
  Cell[BoxData[
      \(TraditionalForm\`F\  = \ \
\(-\[DifferentialD]V\)/\[DifferentialD]x\)]],
  ". If we now translate back to our variables, we find a constant \"energy\" \
given by"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`E\  = \(\(\(1\/2\) \[Alpha]\ \((\[DifferentialD]f\/\
\[DifferentialD]s)\)\^2\)\(+\)\(\ \)\(V(f)\)\(\ \)\)\)]]], "NE2",
  CellTags->"(7.2.5)"],

Cell[TextData[{
  "where the \"potential\" ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(V(f)\)\(\ \)\)\)]],
  "is"
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`V(
          f)\  = \ \(-A\)\ f\  - \ \(1\/2\) v\ f\^2 + \(1\/6\) f\^3\)]]
}], "NE2",
  CellTags->"(7.2.6)"],

Cell[TextData[{
  "This potential is a cubic function of \"position\" ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  ", and the behavior of ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " as a function of \"time\" ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  " can be determined by examining this potential function.The function ",
  Cell[BoxData[
      \(TraditionalForm\`V(f)\)]],
  " can have one of two basic forms, as shown in Cell ",
  ButtonBox["7.30",
    ButtonData:>"Cell 7.30",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(<< Graphics`;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(V[f_]\  = \ \(-A\)\ f\  - \ 1/2\ v\ f^2\  + \ 1/6\ f^3;\)\), "\n", 
    \(\(Plot[
        Evaluate[{\((V[f] /. {A \[Rule] 1, v \[Rule] 1})\), 
            V[f] /. {A \[Rule] \ \(-1\), v \[Rule] 1}}], {f, \(-6\), 6}, \ 
        PlotStyle \[Rule] {{Red, Dashing[{0.05, 0.03}]}, Blue}, 
        PlotLabel -> "\<V(f)\>", 
        AxesLabel \[Rule] {"\<f\>", "\<\>"}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.30"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0793651 0.356269 0.0394172 [
[.02381 .34377 -6 -9 ]
[.02381 .34377 6 0 ]
[.18254 .34377 -6 -9 ]
[.18254 .34377 6 0 ]
[.34127 .34377 -6 -9 ]
[.34127 .34377 6 0 ]
[.65873 .34377 -3 -9 ]
[.65873 .34377 3 0 ]
[.81746 .34377 -3 -9 ]
[.81746 .34377 3 0 ]
[.97619 .34377 -3 -9 ]
[.97619 .34377 3 0 ]
[1.025 .35627 0 -6 ]
[1.025 .35627 10 6 ]
[.4875 .04093 -12 -4.5 ]
[.4875 .04093 0 4.5 ]
[.4875 .11977 -12 -4.5 ]
[.4875 .11977 0 4.5 ]
[.4875 .1986 -12 -4.5 ]
[.4875 .1986 0 4.5 ]
[.4875 .27743 -12 -4.5 ]
[.4875 .27743 0 4.5 ]
[.4875 .4351 -6 -4.5 ]
[.4875 .4351 0 4.5 ]
[.4875 .51394 -6 -4.5 ]
[.4875 .51394 0 4.5 ]
[.4875 .59277 -6 -4.5 ]
[.4875 .59277 0 4.5 ]
[.5 .63053 -14 0 ]
[.5 .63053 14 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .35627 m
.02381 .36252 L
s
[(-6)] .02381 .34377 0 1 Mshowa
.18254 .35627 m
.18254 .36252 L
s
[(-4)] .18254 .34377 0 1 Mshowa
.34127 .35627 m
.34127 .36252 L
s
[(-2)] .34127 .34377 0 1 Mshowa
.65873 .35627 m
.65873 .36252 L
s
[(2)] .65873 .34377 0 1 Mshowa
.81746 .35627 m
.81746 .36252 L
s
[(4)] .81746 .34377 0 1 Mshowa
.97619 .35627 m
.97619 .36252 L
s
[(6)] .97619 .34377 0 1 Mshowa
.125 Mabswid
.06349 .35627 m
.06349 .36002 L
s
.10317 .35627 m
.10317 .36002 L
s
.14286 .35627 m
.14286 .36002 L
s
.22222 .35627 m
.22222 .36002 L
s
.2619 .35627 m
.2619 .36002 L
s
.30159 .35627 m
.30159 .36002 L
s
.38095 .35627 m
.38095 .36002 L
s
.42063 .35627 m
.42063 .36002 L
s
.46032 .35627 m
.46032 .36002 L
s
.53968 .35627 m
.53968 .36002 L
s
.57937 .35627 m
.57937 .36002 L
s
.61905 .35627 m
.61905 .36002 L
s
.69841 .35627 m
.69841 .36002 L
s
.7381 .35627 m
.7381 .36002 L
s
.77778 .35627 m
.77778 .36002 L
s
.85714 .35627 m
.85714 .36002 L
s
.89683 .35627 m
.89683 .36002 L
s
.93651 .35627 m
.93651 .36002 L
s
.25 Mabswid
0 .35627 m
1 .35627 L
s
gsave
1.025 .35627 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .04093 m
.50625 .04093 L
s
[(-8)] .4875 .04093 1 0 Mshowa
.5 .11977 m
.50625 .11977 L
s
[(-6)] .4875 .11977 1 0 Mshowa
.5 .1986 m
.50625 .1986 L
s
[(-4)] .4875 .1986 1 0 Mshowa
.5 .27743 m
.50625 .27743 L
s
[(-2)] .4875 .27743 1 0 Mshowa
.5 .4351 m
.50625 .4351 L
s
[(2)] .4875 .4351 1 0 Mshowa
.5 .51394 m
.50625 .51394 L
s
[(4)] .4875 .51394 1 0 Mshowa
.5 .59277 m
.50625 .59277 L
s
[(6)] .4875 .59277 1 0 Mshowa
.125 Mabswid
.5 .06064 m
.50375 .06064 L
s
.5 .08035 m
.50375 .08035 L
s
.5 .10006 m
.50375 .10006 L
s
.5 .13947 m
.50375 .13947 L
s
.5 .15918 m
.50375 .15918 L
s
.5 .17889 m
.50375 .17889 L
s
.5 .21831 m
.50375 .21831 L
s
.5 .23802 m
.50375 .23802 L
s
.5 .25773 m
.50375 .25773 L
s
.5 .29714 m
.50375 .29714 L
s
.5 .31685 m
.50375 .31685 L
s
.5 .33656 m
.50375 .33656 L
s
.5 .37598 m
.50375 .37598 L
s
.5 .39569 m
.50375 .39569 L
s
.5 .41539 m
.50375 .41539 L
s
.5 .45481 m
.50375 .45481 L
s
.5 .47452 m
.50375 .47452 L
s
.5 .49423 m
.50375 .49423 L
s
.5 .53365 m
.50375 .53365 L
s
.5 .55335 m
.50375 .55335 L
s
.5 .57306 m
.50375 .57306 L
s
.5 .02122 m
.50375 .02122 L
s
.5 .00151 m
.50375 .00151 L
s
.5 .61248 m
.50375 .61248 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(V) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(H) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.000 moveto
(L) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ .05 .03 ] 0 setdash
.22987 0 m
.26171 .11914 L
.28158 .17855 L
.30316 .23256 L
.32216 .27171 L
.34309 .30639 L
.36292 .33171 L
.3739 .3428 L
.38395 .35123 L
.39323 .35763 L
.40336 .36318 L
.40891 .36562 L
.41406 .3675 L
.41936 .36908 L
.42424 .37022 L
.42932 .3711 L
.43199 .37144 L
.43335 .37158 L
.43481 .37171 L
.43609 .3718 L
.43726 .37187 L
.43844 .37192 L
.43955 .37195 L
.44085 .37198 L
.44205 .37198 L
.44336 .37197 L
.44403 .37196 L
.44476 .37194 L
.44594 .3719 L
.44717 .37184 L
.44938 .37169 L
.45176 .37147 L
.45436 .37117 L
.45903 .37046 L
.46337 .36962 L
.47389 .36687 L
.48383 .36343 L
.50241 .35505 L
.54088 .33163 L
.5818 .3019 L
.6212 .27351 L
.65909 .25098 L
.67854 .24265 L
.68945 .23923 L
.69429 .23804 L
.69943 .23701 L
.7021 .23657 L
.70461 .23623 L
.70705 .23595 L
.7093 .23574 L
Mistroke
.71144 .2356 L
.71252 .23554 L
.7137 .23549 L
.71489 .23546 L
.71616 .23544 L
.71736 .23544 L
.71845 .23545 L
.71974 .23549 L
.72039 .23551 L
.72111 .23554 L
.72356 .23569 L
.72494 .2358 L
.72642 .23595 L
.72911 .23628 L
.73437 .23718 L
.73919 .2383 L
.74902 .24149 L
.75815 .24562 L
.76817 .25151 L
.77887 .25943 L
.80025 .28079 L
.82042 .3082 L
.85893 .38259 L
.87885 .4336 L
.89991 .49772 L
Mfstroke
.89991 .49772 m
.93153 .61803 L
s
0 0 1 r
[ ] 0 setdash
.29323 0 m
.30316 .03703 L
.34309 .15052 L
.3815 .23161 L
.40095 .2636 L
.42237 .2927 L
.46172 .33193 L
.48113 .34569 L
.502 .35725 L
.52314 .36625 L
.54323 .37295 L
.58142 .38306 L
.60274 .38852 L
.62207 .39417 L
.64245 .40151 L
.6612 .41007 L
.68044 .42122 L
.70126 .43662 L
.72168 .45577 L
.74075 .47786 L
.77872 .53617 L
s
.77872 .53617 m
.81696 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oD?ooool0
0ooo003oooooooooo`0Booooo`03o`00oooooooooooo047ooooo00?o0000ooooooooool0_?ooool0
053ooooo00?oo`00ooooooooool04_ooool00ol00?ooooooooooo`11ooooo`;o0000_Oooool0053o
oooo00?oo`00ooooooooool04_ooool00ol00?ooooooooooo`11ooooo`03o`000?oooooooooo0;co
oooo001Aooooo`03ool00?oooooooooo01;ooooo00?o003oooooooooool0@?ooool00ol0003ooooo
ooooo`2looooo`00DOooool00ooo003oooooooooo`0Booooo`03o`00oooooooooooo043ooooo00?o
0000ooooooooool0_?ooool006Kooooo00?o003oooooooooool0@?ooool00ol0003oooooooooo`2l
ooooo`00I_ooool00ol00?ooooooooooo`10ooooo`03o`000?oooooooooo0;cooooo001Wooooo`03
o`00oooooooooooo03oooooo0_l0002mooooo`00Ioooool00ol00?ooooooooooo`0oooooo`03o`00
0?oooooooooo0;cooooo001Wooooo`03o`00oooooooooooo03oooooo00?o0000ooooooooool0_?oo
ool006Oooooo00?o003oooooooooool0?oooool00ol0003oooooooooo`2looooo`00J?ooool00ol0
0?ooooooooooo`0cooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2l
ooooo`00J?ooool00ol00?ooooooooooo`0cooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool0
0ol0003oooooooooo`2looooo`00J?ooool00ol00?ooooooooooo`0[ooooo`Ko00000_ooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0_?ooool005Cooooo00?oo`00oooo
ooooool04_ooool00ol00?ooooooooooo`0booooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3
o`000;cooooo001Dooooo`03ool00?oooooooooo01;ooooo00?o003oooooooooool0<_ooool01Oo<
c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0_?ooool005Cooooo00?oo`00oooo
ooooool04_ooool00ol00?ooooooooooo`0booooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool0
0ol0003oooooooooo`2looooo`00EOooool00ooo003oooooooooo`0Booooo`03o`00oooooooooooo
037ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0;cooooo001Eoooo
o`03ool00?oooooooooo01;ooooo00?o003oooooooooool0<Oooool01OnYZJWo410@o`000?l@413o
ZJVY00Kooooo00?o0000ooooooooool0_?ooool005Gooooo00?oo`00ooooooooool04_ooool00ol0
0?ooooooooooo`0looooo`03o`000?oooooooooo0;cooooo001Eooooo`03ool00?oooooooooo01?o
oooo00?o003oooooooooool0>oooool2o`000;gooooo001Fooooo`03ool00?oooooooooo01;ooooo
00?o003oooooooooool0>oooool00ol0003oooooooooo`2looooo`00E_ooool00ooo003ooooooooo
o`0Booooo`03o`00oooooooooooo03_ooooo00?o0000ooooooooool0_?ooool005Kooooo00?oo`00
ooooooooool04oooool00ol00?ooooooooooo`0jooooo`03o`000?oooooooooo0;cooooo001Foooo
o`03ool00?oooooooooo01?ooooo00?o003oooooooooool0>_ooool00ol0003oooooooooo`2loooo
o`00Eoooool00ooo003oooooooooo`0Booooo`03o`00oooooooooooo03[ooooo00?o0000oooooooo
ool0_?ooool005Oooooo00?oo`00ooooooooool04oooool00ol00?ooooooooooo`0iooooo`;o0000
_Oooool005Oooooo00?oo`00ooooooooool04oooool00ol00?ooooooooooo`0iooooo`03o`000?oo
oooooooo0;cooooo001Gooooo`03ool00?oooooooooo01?ooooo00?o003oooooooooool0>Oooool0
0ol0003oooooooooo`2looooo`00F?ooool00ooo003oooooooooo`0Cooooo`03o`00oooooooooooo
03Sooooo00?o0000ooooooooool0_?ooool005Sooooo00?oo`00ooooooooool04oooool00ol00?oo
ooooooooo`0hooooo`03o`000?oooooooooo0;cooooo001_ooooo`03o`00oooooooooooo03Oooooo
00?o0000ooooooooool0_?ooool006oooooo00?o003oooooooooool0=oooool00ol0003ooooooooo
o`2looooo`00Koooool00ol00?ooooooooooo`0gooooo`;o0000_Oooool0073ooooo00?o003ooooo
ooooool0=_ooool00ol0003oooooooooo`2looooo`00L?ooool00ol00?ooooooooooo`0fooooo`03
o`000?oooooooooo0;cooooo001`ooooo`03o`00oooooooooooo03Kooooo00?o0000ooooooooool0
_?ooool0077ooooo00?o003oooooooooool0:_ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo
00?o0000ooooooooool0_?ooool0077ooooo00?o003oooooooooool0:_ooool01OmEEEGoMgMgoooo
oonHV9So8B4Q00Kooooo00?o0000ooooooooool0_?ooool005_ooooo00?oo`00ooooooooool04ooo
ool00ol00?ooooooooooo`0Rooooo`Ko00000_ooool01Ol0003ooooooooooooooooo000000Kooooo
0ol0002looooo`00Foooool00ooo003oooooooooo`0Dooooo`03o`00oooooooooooo02Wooooo00Go
0000oiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;cooooo001Kooooo`03ool00?oo
oooooooo01Cooooo00?o003oooooooooool0:Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo
00?o0000ooooooooool0_?ooool005cooooo00?oo`00ooooooooool04oooool00ol00?oooooooooo
o`0Yooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0_?ooool005cooooo00?oo`00
ooooooooool05?ooool00ol00?ooooooooooo`0Xooooo`03omgMgOl@413oV9RH00Sooooo00?o0000
ooooooooool0_?ooool005cooooo00?oo`00ooooooooool05?ooool00ol00?ooooooooooo`0Yoooo
o`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0_?ooool005gooooo00?oo`00oooo
ooooool04oooool00ol00?ooooooooooo`0cooooo`03o`000?oooooooooo0;cooooo001Mooooo`03
ool00?oooooooooo01Cooooo00?o003oooooooooool0<_ooool2o`000;gooooo001Mooooo`03ool0
0?oooooooooo01Cooooo00?o003oooooooooool0<_ooool00ol0003oooooooooo`2looooo`00G_oo
ool00ooo003oooooooooo`0Cooooo`03o`00oooooooooooo03;ooooo00?o0000ooooooooool0_?oo
ool005kooooo00?oo`00ooooooooool05?ooool00ol00?ooooooooooo`0aooooo`03o`000?oooooo
oooo0;cooooo001Nooooo`03ool00?oooooooooo01Cooooo00?o003oooooooooool0<Oooool00ol0
003oooooooooo`2looooo`00Goooool00ooo003oooooooooo`0Dooooo`03o`00oooooooooooo033o
oooo00?o0000ooooooooool0_?ooool005oooooo00?oo`00ooooooooool05?ooool00ol00?oooooo
ooooo`0`ooooo`;o0000_Oooool005oooooo00?oo`00ooooooooool05Oooool00ol00?oooooooooo
o`0_ooooo`03o`000?oooooooooo0;cooooo001Pooooo`03ool00?oooooooooo01Cooooo00?o003o
ooooooooool0;oooool00ol0003oooooooooo`2looooo`00H?ooool00ooo003oooooooooo`0Eoooo
o`03o`00oooooooooooo02kooooo00?o0000ooooooooool0_?ooool007Sooooo00?o003ooooooooo
ool0;_ooool00ol0003oooooooooo`2looooo`00NOooool00ol00?ooooooooooo`0]ooooo`03o`00
0?oooooooooo0;cooooo001iooooo`03o`00oooooooooooo02gooooo00?o0000ooooooooool0_?oo
ool007[ooooo00?o003oooooooooool0;?ooool2o`000;gooooo001jooooo`03o`00oooooooooooo
02cooooo00?o0000ooooooooool0_?ooool007_ooooo00?o003oooooooooool0:oooool00ol0003o
ooooooooo`2looooo`00Noooool00ol00?ooooooooooo`0[ooooo`03o`000?oooooooooo0;cooooo
001looooo`03o`00oooooooooooo027ooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oo
oooooooo0;cooooo001Sooooo`03ool00?oooooooooo01Kooooo00?o003oooooooooool08_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;cooooo001Sooooo`03ool00?oooooooooo
01Kooooo00?o003oooooooooool05oooool6o`0000;ooooo1Ol00006ooooo`?o0000_?ooool006Co
oooo00?oo`00ooooooooool05_ooool00ol00?ooooooooooo`0Nooooo`04odA4A?oMgMgoooooo`00
00Oooooo00?o0000ooooooooool0_?ooool006Cooooo00?oo`00ooooooooool05_ooool00ol00?oo
ooooooooo`0Nooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0_?ooool006Co
oooo00?oo`00ooooooooool05oooool00ol00?ooooooooooo`0Nooooo`03ogMgMoo<c<co000000Oo
oooo00?o0000ooooooooool0_?ooool006Gooooo00?oo`00ooooooooool05_ooool00ol00?oooooo
ooooo`0Nooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0_?ooool006Gooooo00?o
o`00ooooooooool05oooool00ol00?ooooooooooo`0Nooooo`03ogMgMol0003ooooo00Kooooo00?o
0000ooooooooool0_?ooool006Kooooo00?oo`00ooooooooool05_ooool00ol00?ooooooooooo`0W
ooooo`03o`000?oooooooooo0;cooooo001Vooooo`03ool00?oooooooooo01Oooooo00?o003ooooo
ooooool09_ooool2o`000;gooooo001Wooooo`03ool00?oooooooooo01Kooooo00?o003ooooooooo
ool09_ooool00ol0003oooooooooo`2looooo`00Ioooool00ooo003oooooooooo`0Gooooo`03o`00
oooooooooooo02Gooooo00?o0000ooooooooool0_?ooool006Oooooo00?oo`00ooooooooool05ooo
ool00ol00?ooooooooooo`0Uooooo`03o`000?oooooooooo0;cooooo001Xooooo`03ool00?oooooo
oooo01Oooooo00?o003oooooooooool09?ooool00ol0003oooooooooo`2looooo`00J?ooool00ooo
003oooooooooo`0Gooooo`03o`00oooooooooooo02Cooooo00?o0000ooooooooool0@Oooool6ool0
07Gooooo001Yooooo`03ool00?oooooooooo01Oooooo00?o003oooooooooool08oooool2o`000;go
oooo001Zooooo`03ool00?oooooooooo01Oooooo00?o003oooooooooool08_ooool00ol0003ooooo
ooooo`0iooooo`;oo`00POooool008Cooooo00?o003oooooooooool08_ooool00ol0003ooooooooo
o`0fooooo`?oo`005_ooool2ool006_ooooo0025ooooo`03o`00oooooooooooo027ooooo00?o0000
ooooooooool0<oooool3ool001_ooooo0ooo001Xooooo`00QOooool00ol00?ooooooooooo`0Qoooo
o`03o`000?oooooooooo033ooooo0ooo000Qooooo`;oo`00I_ooool008Kooooo00?o003ooooooooo
ool08?ooool00ol0003oooooooooo`0_ooooo`03ool00?oooooooooo02Cooooo00?oo`00oooooooo
ool0Hoooool008Oooooo00?o003oooooooooool07oooool2o`0002kooooo0_oo000Xooooo`03ool0
0?oooooooooo06;ooooo0027ooooo`03o`00oooooooooooo01oooooo00?o0000ooooooooool0;?oo
ool00ooo003oooooooooo`0Yooooo`03ool00?oooooooooo067ooooo0028ooooo`03o`00oooooooo
oooo01kooooo00?o0000ooooooooool0:oooool00ooo003oooooooooo`0[ooooo`03ool00?oooooo
oooo063ooooo0028ooooo`03o`00oooooooooooo01kooooo00?o0000ooooooooool0F_ooool00ooo
003oooooooooo`1Oooooo`00K_ooool00ooo003oooooooooo`0Hooooo`03o`00oooooooooooo01;o
oooo1Ol00006ooooo`03o`000?oooooooooo05_ooooo00?oo`00ooooooooool0G_ooool006kooooo
00?oo`00ooooooooool06Oooool00ol00?ooooooooooo`0Aooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01_ooool00ol0003oooooooooo`1Looooo`03ool00?oooooooooo05gooooo001^ooooo`03ool0
0?oooooooooo01Wooooo00?o003oooooooooool02Oooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h0
1oooool00ol0003oooooooooo`2looooo`00Koooool00ooo003oooooooooo`0Iooooo`03o`00oooo
oooooooo01;ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0002;ooooo0_oo002Hooooo`00L?ooool0
0ooo003oooooooooo`0Iooooo`03o`00oooooooooooo01;ooooo00?oMgMgofIVI_ooool01Oooool0
0ol0003oooooooooo`0Qooooo`03ool00?oooooooooo09Sooooo001`ooooo`03ool00?oooooooooo
01[ooooo00?o003oooooooooool04_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01oooooo0_oo002Kooooo`00LOooool00ooo003oooooooooo`0Iooooo`03o`00oooooooooooo00ko
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo01kooooo00?oo`00oooo
ooooool0Voooool007;ooooo00?oo`00ooooooooool06Oooool00ol00?ooooooooooo`0=ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0Looooo`;oo`00W_ooool007;o
oooo00?oo`00ooooooooool06_ooool00ol00?ooooooooooo`0Gooooo`03o`000?oooooooooo01_o
oooo00?oo`00ooooooooool0W_ooool007?ooooo00?oo`00ooooooooool06_ooool00ol00?oooooo
ooooo`0Fooooo`;o00006_ooool2ool004Oooooo00?oo`00ooooooooool0Eoooool007?ooooo00?o
o`00ooooooooool06oooool00ol00?ooooooooooo`0Eooooo`03o`000?oooooooooo01Sooooo00?o
o`00ooooooooool0B?ooool00ooo003oooooooooo`1Fooooo`00M?ooool00ooo003oooooooooo`0K
ooooo`03o`00oooooooooooo01Cooooo00?o0000ooooooooool05_ooool2ool004cooooo00?oo`00
ooooooooool0EOooool007Gooooo00?oo`00ooooooooool06oooool00ol00?ooooooooooo`0Coooo
o`03o`000?oooooooooo01Gooooo00?oo`00ooooooooool0COooool00ooo003oooooooooo`1Doooo
o`00MOooool00ooo003oooooooooo`0Looooo`03o`00oooooooooooo01;ooooo00?o0000oooooooo
ool0I_ooool00ooo003oooooooooo`1Cooooo`00M_ooool00ooo003oooooooooo`0Looooo`03o`00
oooooooooooo017ooooo00?o0000ooooooooool0I_ooool00ooo003oooooooooo`1Cooooo`00U_oo
ool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo06Oooooo00?oo`00ooooooooool0D_oo
ool000kooooo00Gok^k^oc8b<_l0003o410@olc<c00aooooo`;o000000?o410@ooooooooool0;Ooo
ool5o`0001cooooo00?o003oooooooooool03oooool2o`0002oooooo1Ol0000aooooo`;o000000?o
410@ool00?ooool0;Oooool01Oo^k^ko<S8bo`000?l@413oc<c<027ooooo000>ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40<_ooool00ol0003oooooooooo`0^ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@07Oooool00ol00?ooooooooooo`0>ooooo`03o`000?oooooooooo02kooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00booooo`04o`000?ooooooooooool002gooooo00GoEEEEogMgMoooooooV9RHob4Q
8@0Qooooo`001_ooool6o`0000;ooooo00Go0000ooooooooooooooooo`00000Wooooo`Ko00000_oo
ool5o`0002Oooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^01oooooo00?o003oooooooooool03Ooo
ool00ol0003oooooooooo`0=ooooo`;oo`008?ooool00onHV9So8B4Qonk^kP0`ooooo`Go000000?o
ooooool00?ooool0;?ooool01Ol0003ooooooooooooooooo0000027ooooo000>ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;oooool01?m4A4CogMgMooooool0000booooo`03oiRHV?lQ8B7ok^k^01oo
oooo00?o003oooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo027o
oooo00?oV9RHob4Q8Oo^k^h0;oooool01?m4A4CogMgMooooool00003ooooo`03ool00?oooooooooo
02[ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Qooooo`003_ooool01Ol0003oEEEEo`000?l@413o
c<c<02oooooo00CogMgMoeEEEOoooooo0000<oooool00omgMgOoIVIVooooo`0Oooooo`03o`00oooo
oooooooo00_ooooo00?o0000ooooooooool02oooool00ooo003oooooooooo`0Sooooo`03ogMgMomV
IVKooooo02kooooo00CogMgMoeEEEOoooooo00000oooool00ooo003oooooooooo`0Zooooo`05o`00
0?mEEEGo0000oa0@4?o<c<`08Oooool000kooooo00?oEEEEohN7Qoooool0<_ooool00omgMgOoc<c<
o`00000dooooo`03o`000?ooooooo`0001oooooo0_l00?l;ooooo`03o`000?oooooooooo00Wooooo
0_oo000Wooooo`03o`000?oooooooooo02kooooo00?oMgMgolc<c?l000001?ooool00ooo003ooooo
ooooo`0Yooooo`03oeEEEOn7QhOooooo02?ooooo000>ooooo`03omgMgOl@413oV9RH03;ooooo00?o
k^k^odA4A?l00000<?ooool01Ol0003o^[ZjoooooonHV9So410@00;ooooo00?oo`00ooooooooool0
7_ooool00ol00?ooooooooooo`08ooooo`;o00002?ooool2ool002Gooooo00Go0000okZj^_oooooo
V9RHoa0@400`ooooo`03onk^k_m4A4Co000000Cooooo00?oo`00ooooooooool0:Oooool00ooMgMgo
410@oiRHV00Sooooo`003oooool01?o<c<coA4A4o`000?l@410aooooo`03ogMgMol0003ooooo02oo
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`03ool00?oooooooooo01kooooo0_l00?l8oooo
o`03o`000?oooooooooo00Kooooo00?oo`00ooooooooool09Oooool01OnHV9So410@o`000?lQ8B7o
c<c<037ooooo00?oMgMgo`000?ooool01?ooool00ooo003oooooooooo`0Yooooo`04olc<c?m4A4Co
0000oa0@427ooooo001oooooo`;oo`008?ooool00ol00?ooooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo0_oo002fooooo`00POooool00ooo003oooooooooo`0Nooooo`;o003o1Oooool00ol0
003oooooooooo`02ooooo`;oo`00^?ooool008;ooooo00?oo`00ooooooooool07oooool2o`00o`?o
oooo00Go0000ooooooooooooooooool0002Zooooo`03oa0@4?l0003o000000;o000000?o410@oooo
ooooool02?ooool008?ooooo0_oo000Qooooo`04o`00ooooooooooooo`0000;ooooo00?oo`00oooo
ooooool0Zoooool00ol0003oooooooooo`0;ooooo`00QOooool00ooo003oooooooooo`0Oooooo`;o
003o00?o0000ooooooooool0[_ooool00ol0003oooooooooo`0;ooooo`001Ooooon1o`0000;oo`00
8Ol00002o`00oj;o00003Oooool00ol0003oooooooooo`0;ooooo`003Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`03ooooo`03ool00?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooo003o00;o003o2?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0;ooooo`003Oooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04Oooool2
ool001Oooooo0_oo0005ooooo`03o`000?oooooooooo00;ooooo0_l00?l]ooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0@ooooo`03oa0@4?l0003o
000000?o00002_ooool009oooooo0ooo0007ooooo`03o`000?oooooooooo00Cooooo0ol00?mXoooo
o`03ool00?oooooooooo03cooooo00?o0000ooooooooool02oooool009_ooooo1?oo000:ooooo`03
o`000?oooooooooo00Oooooo0ol00?mUooooo`03ool00?oooooooooo03cooooo00?o410@okZj^_oo
ool02oooool009?ooooo2?oo000>ooooo`03o`000?oooooooooo00[ooooo1?l00?mRooooo`03ool0
0?oooooooooo03_ooooo00Co^[Zjoa0@4?l0003o410@2_ooool00:Wooooo0_l0000?ooooo`Co003o
Goooool00ooo003oooooooooo`18ooooo`00ZOooool00ol0003oooooooooo`0Booooo`Co003oFooo
ool00ooo003oooooooooo`18ooooo`00ZOooool00ol0003oooooooooo`0Fooooo`Co003oF?ooool0
0ooo003oooooooooo`17ooooo`00ZOooool00ol0003oooooooooo`0Jooooo`?o003oEOooool00ooo
003oooooooooo`17ooooo`00ZOooool00ol0003oooooooooo`0Mooooo`Co003oD_ooool00ooo003o
ooooooooo`16ooooo`00ZOooool00ol0003oooooooooo`0Qooooo`?o003oCoooool00ooo003ooooo
ooooo`16ooooo`00ZOooool00ol0003oooooooooo`0Tooooo`?o003oC?ooool00ooo003ooooooooo
o`16ooooo`00ZOooool2o`0002Sooooo0_l00?m;ooooo`03ool00?oooooooooo04Gooooo002Yoooo
o`03o`000?oooooooooo02Wooooo0_l00?m9ooooo`03ool00?oooooooooo04Gooooo002Yooooo`03
o`000?oooooooooo02_ooooo0ol00?m7ooooo`03ool00?oooooooooo04Cooooo002Yooooo`03o`00
0?oooooooooo02kooooo0ol00?m4ooooo`03ool00?oooooooooo04Cooooo002Yooooo`03o`000?oo
oooooooo037ooooo0_l00?m2ooooo`03ool00?oooooooooo04Cooooo002Yooooo`03o`000?oooooo
oooo03?ooooo0_l00?m1ooooo`03ool00?oooooooooo04?ooooo002Yooooo`;o0000=_ooool00ol0
0?ooooooooooo`24ooooo`00ZOooool00ol0003oooooooooo`0fooooo`;o003oQ?ooool00:Wooooo
00?o0000ooooooooool0>?ooool2o`00oh;ooooo002Yooooo`03o`000?oooooooooo03[ooooo00?o
003oooooooooool0Ooooool009kooooo1Ol00006ooooo`03o`000?oooooooooo03_ooooo0_l00?mo
ooooo`00W_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0?Oooool0
0ol00?ooooooooooo`1looooo`00Woooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo
03kooooo00?o003oooooooooool0Noooool00:3ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0003oo
oooo00?o003oooooooooool0N_ooool00:7ooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooo
ooooo`10ooooo`03o`00oooooooooooo03Kooooo00?oo`00ooooooooool0@?ooool00:;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`11ooooo`03o`00oooooooooooo03Gooooo00?o
o`00ooooooooool0@?ooool009kooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oo
oooooooo04;ooooo00?o003oooooooooool0=Oooool00ooo003oooooooooo`0oooooo`00W_ooool0
1OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0@oooool00ol00?oooooooooo
o`0dooooo`03ool00?oooooooooo03oooooo002Yooooo`03o`000?oooooooooo04Cooooo00?o003o
ooooooooool0<oooool00ooo003oooooooooo`0oooooo`00ZOooool2o`0004Kooooo00?o003ooooo
ooooool0<oooool00ooo003oooooooooo`0nooooo`00ZOooool00ol0003oooooooooo`15ooooo`03
o`00oooooooooooo03?ooooo00?oo`00ooooooooool0?_ooool00:Wooooo00?o0000ooooooooool0
A_ooool00ol00?ooooooooooo`0booooo`03ool00?oooooooooo03kooooo002Yooooo`03o`000?oo
oooooooo04Oooooo00?o003oooooooooool0<_ooool00ooo003oooooooooo`0mooooo`00ZOooool0
0ol0003oooooooooo`18ooooo`03o`00oooooooooooo037ooooo00?oo`00ooooooooool0?Oooool0
0:Wooooo00?o0000ooooooooool0B?ooool00ol00?ooooooooooo`0aooooo`03ool00?oooooooooo
03gooooo002Yooooo`;o0000B_ooool00ol00?ooooooooooo`0aooooo`03ool00?oooooooooo03co
oooo002Yooooo`03o`000?oooooooooo04[ooooo00?o003oooooooooool0<?ooool00ooo003ooooo
ooooo`0looooo`00ZOooool00ol0003oooooooooo`1;ooooo`03o`00oooooooooooo02oooooo00?o
o`00ooooooooool0??ooool00:Wooooo00?o0000ooooooooool0Boooool00ol00?ooooooooooo`0`
ooooo`03ool00?oooooooooo03_ooooo002Yooooo`03o`000?oooooooooo04cooooo00?o003ooooo
ooooool0;oooool00ooo003oooooooooo`0kooooo`00ZOooool00ol0003oooooooooo`1=ooooo`03
o`00oooooooooooo06cooooo002Yooooo`03o`000?oooooooooo04gooooo00?o003oooooooooool0
K?ooool00:Wooooo0_l0001?ooooo`03o`00oooooooooooo06_ooooo002Yooooo`03o`000?oooooo
oooo04oooooo00?o003oooooooooool0;_ooool00ooo003oooooooooo`0iooooo`00ZOooool00ol0
003oooooooooo`1?ooooo`03o`00oooooooooooo02kooooo00?oo`00ooooooooool0>Oooool00:Wo
oooo00?o0000ooooooooool0D?ooool00ol00?ooooooooooo`0]ooooo`03ool00?oooooooooo03Wo
oooo002Pooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`1Aooooo`03o`00
oooooooooooo02gooooo00?oo`00ooooooooool0>?ooool00:7ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1Booooo`03o`00oooooooooooo02cooooo00?oo`00ooooooooool0>?oo
ool009kooooo1Ol00006ooooo`?o0000D_ooool00ol00?ooooooooooo`0/ooooo`03ool00?oooooo
oooo03Sooooo002Nooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0Doooool0
0ol00?ooooooooooo`0[ooooo`03ool00?oooooooooo03Sooooo002Nooooo`04omgMgOmEEEGooooo
o`0000Oooooo00?o0000ooooooooool0E?ooool00ol00?ooooooooooo`0[ooooo`03ool00?oooooo
oooo03Oooooo002Oooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0E?ooool00ol0
0?ooooooooooo`0[ooooo`03ool00?oooooooooo03Oooooo002Oooooo`03onk^k_m4A4Co000000Oo
oooo00?o0000ooooooooool0EOooool00ol00?ooooooooooo`0Zooooo`03ool00?oooooooooo03Oo
oooo002Pooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0E_ooool00ol00?oooooo
ooooo`0Yooooo`03ool00?oooooooooo03Oooooo002Yooooo`03o`000?oooooooooo05Kooooo00?o
003oooooooooool0:_ooool00ooo003oooooooooo`0fooooo`00ZOooool2o`0005Sooooo00?o003o
ooooooooool0:Oooool00ooo003oooooooooo`0fooooo`00ZOooool00ol0003oooooooooo`1Hoooo
o`03o`00oooooooooooo02Sooooo00?oo`00ooooooooool0=_ooool00:Wooooo00?o0000oooooooo
ool0F?ooool00ol00?ooooooooooo`0Xooooo`03ool00?oooooooooo03Kooooo002Yooooo`03o`00
0?oooooooooo05Wooooo00?o003oooooooooool0:?ooool00ooo003oooooooooo`0eooooo`00ZOoo
ool00ol0003oooooooooo`1Iooooo`03o`00oooooooooooo02Sooooo00?oo`00ooooooooool0=Ooo
ool00:Wooooo00?o0000ooooooooool0F_ooool00ol00?ooooooooooo`1Oooooo`00ZOooool2o`00
05_ooooo00?o003oooooooooool0Goooool00:Wooooo00?o0000ooooooooool0Foooool00ol00?oo
ooooooooo`1Nooooo`00ZOooool00ol0003oooooooooo`1Kooooo`03o`00oooooooooooo05kooooo
002Yooooo`03o`000?oooooooooo05_ooooo00?o003oooooooooool0G_ooool00:Wooooo00?o0000
ooooooooool0G?ooool00ol00?ooooooooooo`1Mooooo`00ZOooool00ol0003oooooooooo`1Loooo
o`03o`00oooooooooooo05gooooo002Yooooo`03o`000?oooooooooo05gooooo00?o003ooooooooo
ool0G?ooool00:Wooooo0_l0001Nooooo`03o`00oooooooooooo02Kooooo00?oo`00ooooooooool0
<oooool00:Wooooo00?o0000ooooooooool0G_ooool00ol00?ooooooooooo`0Uooooo`03ool00?oo
oooooooo03?ooooo002Yooooo`03o`000?oooooooooo05kooooo00?o003oooooooooool09Oooool0
0ooo003oooooooooo`0cooooo`00ZOooool00ol0003oooooooooo`1Oooooo`03o`00oooooooooooo
02Gooooo00?oo`00ooooooooool0<_ooool009kooooo00Gok^k^oc8b<_l0003o410@olc<c006oooo
o`03o`000?oooooooooo05oooooo00?o003oooooooooool09Oooool00ooo003oooooooooo`0boooo
o`00W_ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0H?ooool00ol0
0?ooooooooooo`0Tooooo`03ool00?oooooooooo03;ooooo002Nooooo`05o`000?oooooooooooooo
ool000001_ooool3o`00063ooooo00?o003oooooooooool09Oooool00ooo003oooooooooo`0aoooo
o`00W_ooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0HOooool00ol0
0?ooooooooooo`0Tooooo`03ool00?oooooooooo037ooooo002Nooooo`05o`000?mEEEGo0000oa0@
4?o<c<`01_ooool00ol0003oooooooooo`1Qooooo`03o`00oooooooooooo02Cooooo00?oo`00oooo
ooooool0<Oooool009kooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`1Qooooo`03
o`00oooooooooooo02Cooooo00?oo`00ooooooooool0<Oooool009kooooo00?ogMgMoa0@4?nHV9P0
2?ooool00ol0003oooooooooo`1Rooooo`03o`00oooooooooooo02Cooooo00?oo`00ooooooooool0
<?ooool009oooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`1Rooooo`03o`00
oooooooooooo02Cooooo00?oo`00ooooooooool0<?ooool00:Wooooo00?o0000ooooooooool0Hooo
ool00ol00?ooooooooooo`0Sooooo`03ool00?oooooooooo033ooooo002Yooooo`;o0000I?ooool0
0ol00?ooooooooooo`0Tooooo`03ool00?oooooooooo02oooooo002Yooooo`03o`000?oooooooooo
06Cooooo00?o003oooooooooool08oooool00ooo003oooooooooo`0_ooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
Y_ooool00omgMgOoIVIVooooo`08ooooo`03ofIVI_mgMgOooooo0;Cooooo002Uooooo`03omgMgOl@
413ok^k^00Wooooo00?ok^k^oa0@4?oMgMd0]?ooool009gooooo0_lb<S86ooooo`03oeEEEOnHV9So
oooo00;ooooo00?o410@o`000?l000000_l000001Ol@413ooooooooooon7QhOoIVIV0;Cooooo002L
ooooo`04omgMgOl@413o410@olc<c0Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03onk^k_l0003ooooo0;?ooooo002Looooo`;oIVIV00?oMgMgofIVI_ooool01?ooool0
0olb<S;oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0/_ooool0
09cooooo00Co0000omgMgOoMgMgo00001Oooool00olb<S;oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0/_ooool009_ooooo00KoV9RHoc8b<_oooooooooooc8b<_nH
V9P4ooooo`03o`000?o^k^kooooo00Cooooo00?o0000ooooooooool00oooool00oo^k^ko0000oooo
o`2cooooo`00Voooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Cooooo00?oEEEEogMgMoooool0
0_ooool00ol@413o0000o`000003o`0000;ooooo00?oMgMgoeEEEOooool0/oooool009[ooooo00?o
gMgMo`000?ooool00oooool00ol0003ogMgMooooo`02ooooo`03omgMgOl@413ok^k^00Cooooo00?o
0000ooooooooool00_ooool00oo^k^ko410@omgMg@2dooooo`00V_ooool3o`0000;ooooo0ol00004
ooooo`03ogMgMomVIVKooooo00?ooooo00?o410@okZj^_ooool00_ooool00omVIVKoMgMgooooo`2d
ooooo`00[?ooool01?nj^[[o410@o`000?l@412hooooo`00oooooomYooooo`00oooooomYooooo`00
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-6.51205, -9.0385, \
0.0481209, 0.0968896}}]
}, Open  ]],

Cell[TextData[{
  "Solutions with ",
  Cell[BoxData[
      \(TraditionalForm\`A < \(-v\^2\)/2\)]],
  " (the solid curve) proceed monotonically from ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Infinity]\)\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`\(+\[Infinity]\)\)]],
  ". This can be seen analytically by solving for local extrema:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[\(V'\)[f] \[Equal] 0, f]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.31"],

Cell[BoxData[
    \({{f \[Rule] v - \@\(2\ A + v\^2\)}, {f \[Rule] 
          v + \@\(2\ A + v\^2\)}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Thus, for ",
  Cell[BoxData[
      \(TraditionalForm\`A < \(-v\^2\)/2\)]],
  " \"particles\" will slide down the potential hill as \"time\" ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(s\)\)\)]],
  " increases, and this implies ",
  Cell[BoxData[
      \(TraditionalForm\`f \[Rule] \ \(-\[Infinity]\)\)]],
  " for large ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  ". Such unbounded solutions are not of physical interest. On the other \
hand, for ",
  Cell[BoxData[
      \(TraditionalForm\`A > \(-v\^2\)/2\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`V(f)\)]],
  " is ",
  "no longer",
  " monotonic (the red curve), because there are now two real local extrema, \
a maximum and a minimum. In this regime, \"particles\" can get trapped in the \
potential well, resulting in periodic oscillations of ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " as a function of \"time\" ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tThe form of these periodic nonlinear wavetrains depends on the value of \
",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " and of the \"energy\" ",
  Cell[BoxData[
      \(TraditionalForm\`E\)]],
  ", and may be found by solving Eq. ",
  ButtonBox["(7.2.5)",
    ButtonData:>{"Chapter7.nb", "(7.2.5)"},
    ButtonStyle->"Hyperlink"],
  "  for ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]f/\[DifferentialD]s\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]f\/\[DifferentialD]s = \@\(\(2\/\
\[Alpha]\) \((E - V(f))\)\)\)]],
  ". "
}], "NE2",
  CellTags->"(7.2.7)"],

Cell["This is an ODE that can be reduced to quadratures:", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              SuperscriptBox["\[Integral]", 
                StyleBox["f",
                  FontSize->10]],
              
              FontSize->
                9], \(\[DifferentialD]f\&_\/\@\(\(2\/\[Alpha]\) \((E - \
V(f\&_))\)\)\)}], "=", \(s + B\)}], TraditionalForm]]],
  ","
}], "NE2",
  CellTags->"(7.2.8)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`B\)]],
  " is another constant of integration, which we will set to zero in what \
follows, as it merely corresponds to a change in the origin of ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  ". The integral involves the square root of a cubic polynomial, which makes \
it rather unpleasant, but it can nevertheless be carried out analytically in \
terms of special functions called ",
  StyleBox["elliptic functions: ",
    FontSlant->"Italic"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sqrt[\[Alpha]/2]\ Integrate[1/Sqrt[e\  - \ V[f]], f\ ]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.32"],

Cell[BoxData[
    \(\((\@2\ \@\[Alpha]\ EllipticF[
            ArcSin[\[Sqrt]\((\((\(-f\) + 
                        Root[\(-6\)\ e - 6\ A\ #1 - 3\ v\ #1\^2 + #1\^3 &, 
                          3])\)/\((\(-Root[\(-6\)\ e - 6\ A\ #1 - 
                                3\ v\ #1\^2 + #1\^3 &, 2]\) + 
                        Root[\(-6\)\ e - 6\ A\ #1 - 3\ v\ #1\^2 + #1\^3 &, 
                          3])\))\)], \((Root[\(-6\)\ e - 6\ A\ #1 - 
                        3\ v\ #1\^2 + #1\^3 &, 2] - 
                  Root[\(-6\)\ e - 6\ A\ #1 - 3\ v\ #1\^2 + #1\^3 &, 
                    3])\)/\((Root[\(-6\)\ e - 6\ A\ #1 - 
                        3\ v\ #1\^2 + #1\^3 &, 1] - 
                  Root[\(-6\)\ e - 6\ A\ #1 - 3\ v\ #1\^2 + #1\^3 &, 
                    3])\)]\ \((f - 
              Root[\(-6\)\ e - 6\ A\ #1 - 3\ v\ #1\^2 + #1\^3 &, 
                3])\)\ \[Sqrt]\((\((f - 
                    Root[\(-6\)\ e - 6\ A\ #1 - 3\ v\ #1\^2 + #1\^3 &, 
                      1])\)/\((\(-Root[\(-6\)\ e - 6\ A\ #1 - 
                            3\ v\ #1\^2 + #1\^3 &, 1]\) + 
                    Root[\(-6\)\ e - 6\ A\ #1 - 3\ v\ #1\^2 + #1\^3 &, 
                      3])\))\)\ \[Sqrt]\((\((f - 
                    Root[\(-6\)\ e - 6\ A\ #1 - 3\ v\ #1\^2 + #1\^3 &, 
                      2])\)/\((\(-Root[\(-6\)\ e - 6\ A\ #1 - 
                            3\ v\ #1\^2 + #1\^3 &, 2]\) + 
                    Root[\(-6\)\ e - 6\ A\ #1 - 3\ v\ #1\^2 + #1\^3 &, 
                      3])\))\))\)/\((\@\(e + A\ f - f\^3\/6 + \(f\^2\ \
v\)\/2\)\ \[Sqrt]\((\((f - 
                    Root[\(-6\)\ e - 6\ A\ #1 - 3\ v\ #1\^2 + #1\^3 &, 
                      3])\)/\((Root[\(-6\)\ e - 6\ A\ #1 - 
                          3\ v\ #1\^2 + #1\^3 &, 2] - 
                    Root[\(-6\)\ e - 6\ A\ #1 - 3\ v\ #1\^2 + #1\^3 &, 
                      3])\))\))\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This mess can be simplified somewhat if one notices that the ",
  StyleBox["Root",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " functions in the above expression are simply placeholders for the roots \
of the cubic polynomial ",
  Cell[BoxData[
      \(TraditionalForm\`E\  - \ V(f)\)]],
  ". That is, if we write"
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`E\  - \ 
          V(f) = \(-\(1\/6\)\) \((f - a)\) \((f - b)\) \((f - c)\)\)]],
  " "
}], "NE2",
  CellTags->"(7.2.9)"],

Cell[TextData[{
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`a \[GreaterEqual] \ b \[GreaterEqual] \ c\)]],
  ", then we can substitute for these roots and obtain "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullSimplify[% /. {Root[\(-6\)\ e - 6\ A\ #1 - 3\ v\ #1\^2 + #1\^3 &, 
              1] \[Rule] c, 
          Root[\(-6\)\ e - 6\ A\ #1 - 3\ v\ #1\^2 + #1\^3 &, 2] \[Rule] b, 
          Root[\(-6\)\ e - 6\ A\ #1 - 3\ v\ #1\^2 + #1\^3 &, 3] \[Rule] a, \ 
          e \[Rule] V[f] - \(1\/6\) \((f - a)\) \((f - b)\) \((f - c)\)\ }, \ 
      c < b < a\ ]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.33"],

Cell[BoxData[
    \(\(-\(\((2\ \@3\ \@\(\((a - b)\)\ \((a - f)\)\)\ \@\(\(b - f\)\/\(\(-a\) \
+ b\)\)\ \@\(\(c - f\)\/\(\(-a\) + c\)\)\ \@\[Alpha]\ EllipticF[
              ArcSin[\@\(\(a - f\)\/\(a - b\)\)], \(a - b\)\/\(a - \
c\)])\)/\((\@\(\((a - f)\)\ \((\(-b\) + f)\)\ \((\(-c\) + f)\)\))\)\)\)\)], \
"Output"]
}, Open  ]],

Cell[TextData[{
  "The special function ",
  StyleBox["EllipticF[\[Theta],m]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an incomplete elliptic integral of the first kind, referred to as ",
  Cell[BoxData[
      \(TraditionalForm\`F(\[Theta] | m)\)]],
  " in most textbooks. The definition of this function is"
}], "Text",
  CellTags->"i:27"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`F(\[Theta] | 
            m)\  \[Congruent] \ \
\[Integral]\_0\%\[Theta]\[DifferentialD]\[Phi]\/\@\(1 - m\ \ \(sin\^2\) \
\[Phi]\)\)]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "\tThe next step is most easily done by hand: the square roots involving ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " all cancel, leaving us with"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(\(\(-2\)\(\ \)\(\@\(3  \[Alpha]\)\)\(\ \)\)\/\@\(a - c\)\), 
          
          RowBox[{"F", "(", 
            RowBox[{
              RowBox[{"arcsin", 
                StyleBox["[",
                  FontSize->16], \(\@\(\(a - f\)\/\(a - b\)\)\), 
                StyleBox["]",
                  FontSize->16]}], "|", "m"}], ")"}]}], "=", "s"}], 
      TraditionalForm]]]], "NE2",
  CellTags->"(7.2.10)"],

Cell["where", "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`m = \(a - b\)\/\(a - c\)\)]],
  "."
}], "NE2",
  CellTags->"(7.2.11)"],

Cell[TextData[{
  "Since ",
  Cell[BoxData[
      \(TraditionalForm\`c \[LessEqual] \ b \[LessEqual] \ a\)]],
  ",",
  " it is worthwhile to note for future reference that ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] \ m \[LessEqual] \ 1\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tEquation ",
  ButtonBox["(7.2.10)",
    ButtonData:>{"Chapter7.nb", "(7.2.10)"},
    ButtonStyle->"Hyperlink"],
  "  can be inverted to obtain ",
  Cell[BoxData[
      \(TraditionalForm\`f(s)\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(a - f(s)\)\/\(a - b\) = \
\(Sin\^2\)[\(F\^\(-1\)\)(\(\@\(\(a - c\)\/\(12\ \[Alpha]\)\)\) s | \ m)]\)]],
  ". "
}], "UNNEQ"],

Cell[TextData[{
  "The ",
  "right-hand",
  " side can, in turn, be expressed as another special function, a ",
  StyleBox["Jacobian elliptic function",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`sn(\[Theta] | m)\)]],
  ",  defined by ",
  Cell[BoxData[
      \(TraditionalForm\`sn(\[Theta] | m) \[Congruent] 
        sin\ \(\(F\^\(-1\)\)(\[Theta] | \ m)\)\)]],
  ".  In other words, if ",
  Cell[BoxData[
      \(TraditionalForm\`u = \ F(\[Theta] | m)\)]],
  " then ",
  Cell[BoxData[
      \(TraditionalForm\`sn\ \((u)\)\  \[Congruent] sin\ \[Theta]\)]],
  ". Thus, "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`f(s)\  = \ 
        a\  - \ \((a - 
                b)\)\ \(\(sn\^2\)(\(\@\(\(a - c\)\/\(12\ \[Alpha]\)\)\) s | \ 
                m)\)\)]],
  "."
}], "NE2",
  CellTags->"(7.2.12)"],

Cell[TextData[{
  "The function sn is a nonlinear version of  the sin function. In ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " it is referred to as ",
  StyleBox["JacobiSN[\[Theta]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ",",
  StyleBox["m]",
    FontWeight->"Bold"],
  ".  There is  second function, cn, which is analogous to the cosine \
function, and is defined by the identity ",
  Cell[BoxData[
      \(TraditionalForm\`sn\^2\  + cn\^2 = 1\)]],
  ". Our periodic solution for ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " is often called a ",
  StyleBox["cnoidal wave ",
    FontSlant->"Italic"],
  " (because it is often expressed in terms of cn rather than sn). The \
function sn is plotted in Cell ",
  ButtonBox["7.34",
    ButtonData:>"Cell 7.34",
    ButtonStyle->"Hyperlink"],
  "  for ",
  Cell[BoxData[
      \(TraditionalForm\`m = 1/2\)]],
  "."
}], "Text",
  CellTags->"i:28"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[JacobiSN[\[Theta], 1/2], {\[Theta], \(-10\), 10}, 
        PlotLabel \[Rule] \ "\<sn(\[Theta]|m), m=1/2\>", 
        AxesLabel \[Rule] {"\<\[Theta]\>", "\<\>"}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.34"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0476191 0.309017 0.294302 [
[.02381 .29652 -9 -9 ]
[.02381 .29652 9 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.4875 .01471 -12 -4.5 ]
[.4875 .01471 0 4.5 ]
[.4875 .16187 -24 -4.5 ]
[.4875 .16187 0 4.5 ]
[.4875 .45617 -18 -4.5 ]
[.4875 .45617 0 4.5 ]
[.4875 .60332 -6 -4.5 ]
[.4875 .60332 0 4.5 ]
[.5 .63053 -44.125 0 ]
[.5 .63053 44.125 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-10)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-5)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(10)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(q) show
69.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .01471 m
.50625 .01471 L
s
[(-1)] .4875 .01471 1 0 Mshowa
.5 .16187 m
.50625 .16187 L
s
[(-0.5)] .4875 .16187 1 0 Mshowa
.5 .45617 m
.50625 .45617 L
s
[(0.5)] .4875 .45617 1 0 Mshowa
.5 .60332 m
.50625 .60332 L
s
[(1)] .4875 .60332 1 0 Mshowa
.125 Mabswid
.5 .04415 m
.50375 .04415 L
s
.5 .07358 m
.50375 .07358 L
s
.5 .10301 m
.50375 .10301 L
s
.5 .13244 m
.50375 .13244 L
s
.5 .1913 m
.50375 .1913 L
s
.5 .22073 m
.50375 .22073 L
s
.5 .25016 m
.50375 .25016 L
s
.5 .27959 m
.50375 .27959 L
s
.5 .33845 m
.50375 .33845 L
s
.5 .36788 m
.50375 .36788 L
s
.5 .39731 m
.50375 .39731 L
s
.5 .42674 m
.50375 .42674 L
s
.5 .4856 m
.50375 .4856 L
s
.5 .51503 m
.50375 .51503 L
s
.5 .54446 m
.50375 .54446 L
s
.5 .57389 m
.50375 .57389 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -105.125 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sn) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(q) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.000 moveto
(\\310) show
93.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
99.125 13.000 moveto
(L) show
105.125 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.125 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
123.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
135.250 13.000 moveto
(\\220) show
141.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
147.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .05627 m
.02846 .04548 L
.03279 .03701 L
.03793 .02882 L
.04262 .02307 L
.04498 .02075 L
.04754 .01868 L
.04996 .01712 L
.0522 .01603 L
.05342 .01557 L
.05456 .01523 L
.05582 .01496 L
.05653 .01485 L
.05717 .01478 L
.05846 .01472 L
.0592 .01473 L
.05987 .01477 L
.06112 .01493 L
.06181 .01506 L
.06244 .01521 L
.0637 .01558 L
.06508 .0161 L
.06787 .01755 L
.07046 .01935 L
.07287 .02144 L
.07831 .02764 L
.08414 .03669 L
.09483 .06023 L
.10458 .09022 L
.11449 .12958 L
.12366 .17374 L
.14443 .29408 L
.16468 .41552 L
.1746 .46722 L
.18369 .50743 L
.19237 .5388 L
.20186 .56537 L
.2114 .5845 L
.2166 .59197 L
.22144 .59718 L
.22407 .59932 L
.22649 .60089 L
.22915 .60216 L
.23049 .60262 L
.23125 .60283 L
.23196 .60299 L
.23326 .6032 L
.23444 .6033 L
.23571 .60331 L
.23643 .60326 L
Mistroke
.2371 .60319 L
.23832 .60299 L
.23942 .60272 L
.2407 .60231 L
.2419 .60183 L
.24417 .60066 L
.24656 .59905 L
.25083 .59521 L
.25544 .58964 L
.26049 .58175 L
.27072 .55962 L
.28004 .5317 L
.29079 .4897 L
.30096 .44054 L
.33935 .21327 L
.35916 .11512 L
.36916 .07856 L
.37453 .06265 L
.38018 .04862 L
.38502 .0387 L
.3903 .02995 L
.3951 .0238 L
.39957 .01954 L
.40229 .01761 L
.40363 .01684 L
.40486 .01624 L
.40596 .01579 L
.40717 .01539 L
.40838 .01508 L
.40966 .01485 L
.41038 .01477 L
.41107 .01473 L
.41235 .01473 L
.41307 .01477 L
.41373 .01485 L
.41446 .01496 L
.41523 .01512 L
.41651 .01546 L
.4177 .01588 L
.42044 .01719 L
.42286 .01878 L
.42512 .02061 L
.43025 .02607 L
.43525 .03322 L
.44059 .04295 L
.45028 .06652 L
.45909 .09507 L
.47825 .18123 L
.49904 .30308 L
.5185 .41922 L
Mistroke
.52883 .47233 L
.53993 .51935 L
.55055 .55384 L
.56026 .57678 L
.56493 .5851 L
.57002 .5923 L
.57235 .59496 L
.57483 .59739 L
.57696 .59913 L
.5793 .60068 L
.58191 .60199 L
.58333 .60252 L
.58401 .60273 L
.58466 .60289 L
.58591 .60313 L
.58704 .60327 L
.58826 .60332 L
.58895 .6033 L
.58959 .60326 L
.59023 .6032 L
.59092 .60309 L
.59216 .60283 L
.59364 .60239 L
.59499 .60186 L
.59778 .60038 L
.60072 .59826 L
.60572 .5933 L
.61036 .5871 L
.61546 .57844 L
.6209 .56694 L
.63115 .53848 L
.64226 .49698 L
.66242 .39465 L
.68192 .27613 L
.70336 .15557 L
.71318 .1116 L
.72373 .07412 L
.72884 .05957 L
.73369 .04784 L
.74278 .03096 L
.74783 .02428 L
.7524 .0198 L
.75494 .01793 L
.75627 .01712 L
.75768 .0164 L
.75891 .01587 L
.76026 .0154 L
.76149 .01508 L
.76264 .01488 L
.76379 .01475 L
Mistroke
.76503 .01472 L
.76621 .01477 L
.76729 .01491 L
.76827 .01509 L
.76935 .01537 L
.77153 .01616 L
.7739 .01737 L
.77644 .01909 L
.78104 .02333 L
.78628 .02996 L
.79114 .03793 L
.80217 .06298 L
.81189 .09377 L
.82226 .13607 L
.86383 .37414 L
.87397 .43179 L
.88468 .48479 L
.89461 .52493 L
.90388 .55433 L
.91274 .57544 L
.91772 .5845 L
.92225 .59112 L
.92721 .59667 L
.93001 .59905 L
.9326 .60077 L
.93487 .60191 L
.93615 .60241 L
.93736 .60278 L
.93863 .60306 L
.9398 .60323 L
.94107 .60331 L
.94172 .60332 L
.94242 .60329 L
.94352 .60318 L
.94453 .60301 L
.94564 .60275 L
.94682 .60238 L
.94879 .60156 L
.95097 .60036 L
.95499 .59731 L
.95874 .59345 L
.96314 .58767 L
.96715 .58113 L
.97619 .56177 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00Z_ooool00ol0003oooooooooo`2kooooo`00Z_ooool00ol0003oooooooooo`2kooooo`00
X?ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0^oooool00:;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`2kooooo`00Uoooool6o`0000Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2kooooo`006?ooool6o`0006gooooo1_l0000Aoooo
o`03o`000?oooooooooo00Gooooo0ol0001Aooooo`Ko0000I?ooool001Oooooo0_l00005ooooo`03
o`000?oooooooooo06Wooooo0_l00004ooooo`;o00004?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo053ooooo0_l00005ooooo`;o0000H_ooool001Gooooo0_l00008ooooo`03o`00
0?oooooooooo06Oooooo00?o0000ooooooooool01_ooool2o`0000kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
H?ooool001Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Uooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo04kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Oooooo`005?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0C_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo05kooooo000Dooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
05gooooo000Cooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0H_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0COooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo05gooooo000Booooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo05cooooo
000Booooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0Goooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0C?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo05cooooo000Aooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0G_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo0ol0001;
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Foooool0017ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0Foooool0017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Looooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1:ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool0F_ooool0013ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
F_ooool000oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1Kooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`19ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0FOooool002Gooooo00?o0000ooooooooool0F_ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0B?ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Wooooo000Vooooo`03o`000?oooooooooo
05Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
04Sooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Hooooo`009_ooool00ol0003o
ooooooooo`1Iooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`17ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0F?ooool002Oooooo
00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo05Sooooo
000Wooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`1Gooooo`00:?ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool03?ooool3o`0004Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1G
ooooo`00:?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool0Eoooool002Sooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo05Kooooo000Yooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`1Fooooo`00:Oooool00ol0003oooooooooo`1Dooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`15ooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool0E_ooool002[ooooo00?o0000ooooooooool0D_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0AOooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05Kooooo000Zooooo`03o`000?oooooooooo
05;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
04Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Eooooo`00:_ooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`14ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0EOooool002_ooooo
00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo05Gooooo
000[ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`1Eooooo`00:oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool02Oooool3o`0004Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1D
ooooo`00:oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool0E?ooool002cooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo05Cooooo000/ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`1Dooooo`00;?ooool00ol0003oooooooooo`1>ooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`13ooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool0Doooool002cooooo00?o0000ooooooooool0C_ooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0@_ooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo05?ooooo000/ooooo`03o`000?oooooooooo
04gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
04;ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1Cooooo`00;Oooool00ol0003o
ooooooooo`1<ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`12ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0Doooool002gooooo
00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo05?ooooo
000]ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`08ooooo`?o0000@_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo05;ooooo000]
ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1B
ooooo`00;_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool0D_ooool002kooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo05;ooooo000^ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`1Booooo`00;_ooool00ol0003oooooooooo`1:ooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`11ooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool0DOooool002kooooo00?o0000ooooooooool0BOooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0@?ooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo057ooooo000_ooooo`03o`000?oooooooooo
04Sooooo00?o0000ooooooooool04_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`10ooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool0DOooool002oooooo00?o0000ooooooooool0B?ooool0
0ol0003oooooooooo`0Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00Co
0000oooooomgMgOo<S8b1Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0DOooool002oooooo00?o0000ooooooooool0B?ooool00ol0003ooooooooo
o`0:ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00gooooo00Co0000oooooooooooo
00001Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool0DOooool002oooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Booooo`05o`00
0?ooooooooooooooool000003_ooool00ol0003oMgMgoc8b<P05ooooo`?o0000@?ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo053ooooo000_ooooo`03o`000?oooooooooo04Oooooo
00?o0000ooooooooool04oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0
003o<S8bolc<c005ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1@ooooo`00<?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01?o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooo000000Oooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo053ooooo000`ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool04oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooool000001oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool0D?ooool0033ooooo00?o0000ooooooooool0A_ooool00ol0003o
ooooooooo`0Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo053ooooo000`ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1@ooooo`00
<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
Coooool0033ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo04oooooo000aooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`1?ooooo`00<Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool01?ooool3o`0003kooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`1?ooooo`00<Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool0Coooool0037ooooo00?o0000ooooooooool0@oooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo04kooooo000aooooo`03o`000?oooooooooo04?ooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03kooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`1>ooooo`00<_ooool00ol0003oooooooooo`12
ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0m
ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0C_ooool003;ooooo00?o0000oooo
ooooool0@_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0?Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo04kooooo000booooo`03
o`000?oooooooooo047ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1>ooooo`00
<_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
C_ooool003;ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo04gooooo000booooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`1=ooooo`00<oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool00_ooool3o`0003cooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`1=ooooo`00<oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo02co
oooo00?o0000ooooooooool0COooool003?ooooo00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`0^ooooo`05o`000?ooooooooooooooool00000?_ooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo04gooooo000cooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0
;_ooool01Ol0003ooooooooooooooooo000003kooooo00?o0000ooooooooool0;?ooool00ol0003o
ooooooooo`1=ooooo`00<oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo02kooooo
00Go0000ooooooooooooooooo`00000nooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool0C?ooool003Cooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0^ooooo`05o`00
0?ooooooooooooooool00000?Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04co
oooo000dooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0;_ooool01Ol0003ooooo
oooooooooooo000003gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1<ooooo`00
=?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo02oooooo00Go0000oooooooooooo
ooooo`00000mooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0C?ooool003Cooooo
00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0`ooooo`04o`000?ooooooooooo`0003go
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1<ooooo`00=?ooool00ol0003ooooo
ooooo`0mooooo`03o`000?oooooooooo033ooooo00Co0000oooooooooooo0000?Oooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo04_ooooo000dooooo`03o`000?oooooooooo03gooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`03o`0003_ooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`1;ooooo`00=Oooool00ol0003oooooooooo`0looooo`03o`000?oo
oooooooo033ooooo00Co0000oooooooooooo0000??ooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo04_ooooo000eooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0<?oo
ool01?l0003oooooooooool0000looooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
Boooool003Gooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0`ooooo`04o`000?oo
ooooooooo`0003cooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1;ooooo`00=Ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03;ooooo00?o0000ooooool00000??oo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo04_ooooo000eooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0<_ooool00ol0003oooooo`00000looooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool0B_ooool000gooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^7?ooool00ol0003oooooooooo`0Wooooo`05odA4A?l0003o0000oc8b<_oM
gMd03oooool00ol0003oooooooooo`0booooo`03o`000?oooooo000003_ooooo00?o0000oooooooo
ool03Oooool01Om4A4Co0000o`000?lb<S;ogMgM023ooooo00?o0000ooooooooool08_ooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hLooooo`003oooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07Oooool00ol0003oooooooooo`0Yooooo`03ogMg
Molb<S;ooooo00kooooo00?o0000ooooooooool0<_ooool00ol0003oooooo`00000kooooo`03o`00
0?oooooooooo013ooooo00?oMgMgoc8b<_ooool07oooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`001?ooool6o`0000Gooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01gooooo00?o0000oooooooo
ool07Oooool6o`0000Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0booooo`03
o`000?oooooo000003_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@
01cooooo000?ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Moooo
o`03o`000?oooooooooo02Wooooo00?oMgMgoc8b<_ooool03_ooool00ol0003oooooooooo`0coooo
o`Co0000>Oooool00ol0003oooooooooo`0@ooooo`03ogMgMolb<S;ooooo01oooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007?ooool0
00oooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001gooooo00?o0000
ooooooooool09_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00kooooo00?o0000ooooooooool0=?oo
ool2o`0003_ooooo00?o0000ooooooooool03Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<027ooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00007?ooool000oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01go
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03Co
oooo0_l0000kooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Loooo
o`003oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0=?ooool2o`00
03[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01cooooo000=oooo
o`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Nooooo`03o`000?oooooo
oooo02Gooooo1?l0000?ooooo`03o`000?oooooooooo03Cooooo0_l0000jooooo`03o`000?oooooo
oooo00kooooo1?l0000Rooooo`03o`000?oooooooooo027ooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^01cooooo000gooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool0=?ooool2o`0003[ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`19
ooooo`00=oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo03Gooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo04Wooooo000gooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0hooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool0>Oooool01_o^k^ko<S8bo`000?l0003oEEEE
onk^kPWooooo000gooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`0gooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0>Oooool01omE
EEGoMgMgooooooo^k^koQhN7ob4Q8Oo^k^h02?ooool003Sooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`0fooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo00;ooooo00?oQhN7ogMgMoooool01oooool0
00Ooooooool00018o`0000_ooooo00?o0000ooooooooool00oooool00olQ8B7oooooooooo`06oooo
o`003oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0@ooooo`03ob4Q8Ol0003o000000Co00002?ooool000oooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0=_ooool2o`0003Sooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04?ooool00onHV9SoQhN7
ooooo`03ooooo`03o`000?oooooooooo00Kooooo000hooooo`03o`000?oooooooooo03Gooooo00?o
0000ooooooooool0=oooool2o`0003Sooooo00?o0000ooooooooool0=oooool00ol0003ooooooooo
o`0iooooo`06oc8b<_n7QhOok^k^oooooon7QhOo<S8b2?ooool003Sooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`0gooooo`;o0000=oooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo03Wooooo00Kok^k^ogMgMol0003o0000oc8b<_o<c<`8ooooo`00>?ooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo03Oooooo0_l0000gooooo`03o`000?oooooooooo03So
oooo00?o0000ooooooooool0Aoooool003Wooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`0gooooo`;o0000=oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo04Oooooo
000iooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=oooool2o`0003Oooooo00?o
0000ooooooooool0>?ooool00ol0003oooooooooo`17ooooo`00>Oooool00ol0003oooooooooo`0d
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooool00000=_ooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo04Kooooo000iooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool0=oooool3o`0003Gooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`16oooo
o`00>Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03Sooooo00?o0000ooooool0
0000=Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo04Kooooo000iooooo`03o`00
0?oooooooooo03?ooooo00?o0000ooooooooool0>?ooool00ol0003oooooo`00000eooooo`03o`00
0?oooooooooo03[ooooo00?o0000ooooooooool0A_ooool003[ooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`0hooooo`03o`000?oooooo000003Gooooo00?o0000ooooooooool0>_oo
ool00ol0003oooooooooo`16ooooo`00>_ooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo03Sooooo00?o0000ooooool00000=Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooo
oooo04Kooooo000jooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0>?ooool00ol0
003oooooo`00000eooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0AOooool003[o
oooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0hooooo`04o`000?ooooooooooo`00
03?ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`15ooooo`00>_ooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo03Wooooo00Co0000oooooooooooo0000<oooool00ol0
003oooooooooo`0looooo`03o`000?oooooooooo04Gooooo000jooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool0>Oooool01?l0003oooooooooool0000cooooo`03o`000?oooooooooo
03cooooo00?o0000ooooooooool0AOooool003[ooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`0iooooo`04o`000?ooooooooooo`0003?ooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`15ooooo`00>oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo03Wo
oooo1?l0000cooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0A?ooool003_ooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0iooooo`04o`000?ooooooooooo`0003?o
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`14ooooo`00>oooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo03Wooooo00Go0000ooooooooooooooooo`00000aooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool0A?ooool003_ooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`0jooooo`05o`000?ooooooooooooooool00000<Oooool00ol0003o
ooooooooo`0nooooo`03o`000?oooooooooo04Cooooo000kooooo`03o`000?oooooooooo02oooooo
00?o0000ooooooooool0>_ooool01Ol0003ooooooooooooooooo0000037ooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`14ooooo`00>oooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo03[ooooo00Go0000ooooooooooooooooo`00000aooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0A?ooool003cooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0jooooo`05o`000?ooooooooooooooool00000<Oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo04?ooooo000looooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
>_ooool01Ol0003ooooooooooooooooo0000033ooooo00?o0000ooooooooool0@?ooool00ol0003o
ooooooooo`13ooooo`00??ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo03[ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo043ooooo
00?o0000ooooooooool0@oooool003cooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`0kooooo`?o00000_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo043ooooo00?o
0000ooooooooool0@oooool003cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`10
ooooo`03o`000?oooooooooo04?ooooo000looooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool0@?ooool00ol0003oooooooooo`13ooooo`00??ooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo047ooooo00?o0000ooooooooool0@_ooool003gooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo04;ooooo000mooooo`03o`000?oo
oooooooo02cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo02cooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`12ooooo`00?Oooool0
0ol0003oooooooooo`0/ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0@_ooool0
03gooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo
04;ooooo000mooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0??ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0@_ooool00ol0003o
ooooooooo`12ooooo`00?Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo04?ooooo
00?o0000ooooooooool0@_ooool003kooooo00?o0000ooooooooool0:_ooool00ol0003ooooooooo
o`0looooo`?o00000oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo04Cooooo00?o
0000ooooooooool0@Oooool003kooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0l
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`14
ooooo`03o`000?oooooooooo047ooooo000nooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool0??ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool0A?ooool00ol0003oooooooooo`11ooooo`00?_ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo04Cooooo00?o0000ooooooooool0@Oooool003kooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo047ooooo000oooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`10ooooo`00?oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0@?ooool0
03oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Rooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`16ooooo`03o`000?oo
oooooooo043ooooo000oooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool08oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo04Kooooo00?o
0000ooooooooool0@?ooool003oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0S
ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`17ooooo`03o`000?oo
oooooooo03oooooo000oooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool08oooool0
1Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool3o`0000Kooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo03oooooo0010
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool08oooool01Ol0003ooooooooooooo
oooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo03oooooo
0010ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool09?ooool01Ol@413ooooooooo
oooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0oooooo`00@?oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0?oooool0043ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0Tooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool4o`0000Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo04Wooooo00?o0000ooooooooool0?_ooool0043ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo03kooooo0011ooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0nooooo`00@Oooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0?_ooool0047o
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo03go
oooo0011ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0@?ooool3o`0000Sooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo03gooooo
0012ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0@Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0Boooool00ol0003ooooooooo
o`0mooooo`00@_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo047ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo04cooooo00?o0000
ooooooooool0?Oooool004;ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`11oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1=oooo
o`03o`000?oooooooooo03cooooo0012ooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool0@Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool0COooool00ol0003oooooooooo`0looooo`00@_ooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo04;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo04gooooo00?o0000ooooooooool0??ooool004?ooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo03cooooo0013ooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0kooooo`00@oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0>oooool004?o
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo03_o
oooo0014ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@oooool3o`0000[ooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo03_ooooo
0014ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0kooooo`00A?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04?ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo057ooooo00?o0000
ooooooooool0>_ooool004Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`13oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Boooo
o`03o`000?oooooooooo03[ooooo0015ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool0A?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool0D_ooool00ol0003oooooooooo`0jooooo`00AOooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo04Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo05;ooooo00?o0000ooooooooool0>_ooool004Gooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo03Wooooo0016ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0iooooo`00A_ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0>Oooool004Ko
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`15ooooo`?o00003Oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0>?ooool004Oooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo03Sooooo
0017ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0A_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0E_ooool00ol0003ooooooooo
o`0hooooo`00Aoooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Kooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo05Oooooo00?o0000
ooooooooool0=oooool004Sooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`17oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Hoooo
o`03o`000?oooooooooo03Oooooo0018ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0Aoooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0F?ooool00ol0003oooooooooo`0gooooo`00B?ooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo04Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo05Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Oooooo`00BOoo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0Oooooo`00BOooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo04Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo05_ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Pooooo`00B_ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0Pooooo`00B_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04Wo
oooo0ol0000@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0G?ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo027ooooo001;ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0GOooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo027ooooo
001;ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0B_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Goooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo02;ooooo001<ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0Boooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0HOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02;ooooo001<oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo02?ooooo001=ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0C?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0Hoooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Cooooo001>ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0I?ooool2o`0000[ooooo00?o0000ooooooooool0
9Oooool004oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`14ooooo`Co000000?o
410@ooooooooool00oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0Ioooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Gooooo001@
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01Kooooo0_l00006ooooo`03o`000?oooooooooo06Wooooo00?o0000
ooooooooool01?ooool2o`0002Sooooo001Aooooo`?o000000Coooooo`000?l0003o0000B_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Oooooo0ol000001?oooooo0000o`000?l0
001/ooooo`?o00000_ooool2o`0002[ooooo001Cooooo`?o0000C?ooool00ol0003oooooooooo`05
ooooo`?o00006Oooool3o`00073ooooo0ol0000/ooooo`00X_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0;_ooooo002Rooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0^oooool00:;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2kooooo`00X?oo
ool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo0;_ooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002:oooo
o`03ogMgMomVIVKooooo00_ooooo00?o0000ooooooooool02Oooool00omVIVKoMgMgooooo`05oooo
o`03o`000?nj^[[ooooo0;Wooooo0029ooooo`03omgMgOl@413ok^k^00cooooo00?o0000oooooooo
ool02Oooool00oo^k^ko410@omgMg@05ooooo`;o<S8b9?ooool00olQ8B7ogMgMooooo`2Cooooo`00
Moooool01_l@413o<S8bo`000?l0003o410@ojVYZ@;ooooo00Co410@o`000?l0003ooooo0_l00000
1_l@413oooooooooooooooooEEEEoiRHV0;ooooo00Kok^k^oc8b<_l0003o0000oeEEEOo^k^h5oooo
o`03o`000?oooooooooo00;o00000_ooool02?l0003oooooooooool0003o410@oooooon7QhOoIVIV
1Oooool00on7QhOo0000okZj^P0:ooooo`;o00000_ooool01Ol0003oooooooooool0003o410@00Wo
oooo1?l000001Ol@413ooooooooooonHV9SoEEEE00Gooooo1Ol0002:ooooo`00Moooool01_l0003o
ZJVYoooooooooooo^[Zjo`0000?ooooo00Go0000ooooooooooooooooo`000004ooooo`0;o`000?oo
oooooooooooooomEEEGoMgMgooooooo^k^koQhN7ob4Q8Oo^k^h01?ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000_ooool00oo^k^ko0000ooooo`04ooooo`03olc<
c?l0003o410@00_ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000005o`0000Go
oooo00?o0000ooooooooool00oooool00ol0003ogMgMooooo`03ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@0R_ooool007Sooooo00Go^[ZjohN7QomVIVKoIVIVoa0@4003ooooo`05o`000?oooooooooo
ooooool000001?ooool01Olb<S;ooooooooooooooooo000000Cooooo00?oQhN7ogMgMoooool00ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`0Aooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`03ooooo`;oMgMg1Oooool00onHV9So8B4Qonk^kP2;ooooo`00Moooool01_lb<S;o
8B4QogMgMomgMgOoQhN7onk^kP?ooooo00Go0000ooooooooooooooooo`000004ooooo`05oc8b<_oo
ooooooooooooool000001Oooool00olQ8B7oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo017ooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooo`000005o`0000Gooooo00?o0000ooooooooool00oooool0
0oo^k^ko410@onk^kP05ooooo`03oiRHV?lQ8B7ok^k^08[ooooo001gooooo`06o`000?nj^[[ooooo
onk^k_mgMgOo00000oooool01Ol0003oQhN7oooooonYZJWo000000Cooooo00Go0000onk^k_oooooo
ooooob4Q8@06o`0000Cooooo00Go0000ooooooooooooooooo`000002olc<c004o`000?nYZJWogMgM
ob4Q8@;ooooo00?ok^k^o`000?ooool04_ooool01ol0003oc<c<olc<c?l0003oZJVYomgMgOlQ8B40
3?ooool00ol0003oooooooooo`04ooooo`03oeEEEOnHV9Sooooo00Gooooo00?oMgMgofIVI_ooool0
ROooool007Oooooo00KoZJVYob4Q8Ol0003o0000oc8b<_l00002ooooo`03oa0@4?l0003oMgMg00;o
000000?oV9RHooooooooool00_ooool01_mEEEGoMgMgooooooooooooV9RHohN7Q`Cooooo00?o0000
ooooooooool00_ooool02ol0003oooooooooool@413o0000ob4Q8Ol0003oMgMgoa0@4?l0003oZJVY
00;ooooo00?oMgMgoeEEEOooool04Oooool02?l@413o0000ob4Q8Ol0003oMgMgoa0@4?l0003oZJVY
3?ooool00ol0003oooooooooo`04ooooo`03omgMgOl@413ooooo00Kooooo00?o0000ooooooooool0
R?ooool008Wooooo00?ogMgMoa0@4?o^k^h00_ooool01_lb<S;oQhN7onk^k_ooooooQhN7oc8b<PCo
oooo00?o0000ooooooooool02Oooool00oo^k^ko410@omgMg@0Vooooo`03o`000?oooooooooo00Go
oooo00WoEEEEoiRHV?ooooooooooo`000?nj^[[ooooooiRHV?l@4100R_ooool008[ooooo00KoMgMg
ofIVI_ooooooooooonk^k_mgMgL2o`000003oc8b<_o<c<cooooo00?ooooo00?o0000ooooooooool0
2Oooool00omVIVKoMgMgooooo`0Tooooo`03oeEEEOmVIVKo000000Oooooo00Wo^[ZjodA4A?oooooo
oooooiRHV?l@413o0000ob4Q8Oo<c<`0R_ooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-11.0106, -1.05866, \
0.0805251, 0.0130292}}]
}, Open  ]],

Cell[TextData[{
  "\tSince the sn function, like the sine function, is zero at the origin and \
runs from ",
  Cell[BoxData[
      \(TraditionalForm\`\(-1\)\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`1\)]],
  ", we see from Eq. ",
  ButtonBox["(7.2.12)",
    ButtonData:>{"Chapter7.nb", "(7.2.12)"},
    ButtonStyle->"Hyperlink"],
  "  that the maximum and minimum of the wave is ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " respectively. This makes sense, since these are the turning points in the \
motion of the \"particle\" in the \"potential well\" ",
  Cell[BoxData[
      \(TraditionalForm\`V(f)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tHowever, unlike the sine function, the period ",
  Cell[BoxData[
      \(TraditionalForm\`P(m)\)]],
  " of the sn function is not fixed, but rather varies, depending on ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  ". As ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " increases away from zero, the period ",
  Cell[BoxData[
      \(TraditionalForm\`P(m)\)]],
  " of the sn function increases. In fact, one can show that"
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`P(m)\  = 4\ \(K(m)\)\)]],
  ", "
}], "NE2",
  CellTags->"(7.2.13)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`K(m)\)]],
  " is another special function, the complete elliptic function of the  first \
kind (called ",
  StyleBox["EllipticK[m]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "). This function is related to ",
  Cell[BoxData[
      \(TraditionalForm\`F\)]],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`K(m)\  = \ F(\[Pi]/2 | m)\)]],
  ".   The period of sn is plotted in Cell ",
  ButtonBox["7.35",
    ButtonData:>"Cell 7.35",
    ButtonStyle->"Hyperlink"],
  " vs. ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < m < 1\)]],
  "."
}], "Text",
  CellTags->"i:29"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[4\ EllipticK[m], {m, 0, 1}, 
        PlotLabel -> "\<Period of sn(\[Theta]|m)\>", 
        AxesLabel \[Rule] {"\<m\>", "\<\>"}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.35"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.167589 0.0290146 [
[.21429 .08104 -9 -9 ]
[.21429 .08104 9 0 ]
[.40476 .08104 -9 -9 ]
[.40476 .08104 9 0 ]
[.59524 .08104 -9 -9 ]
[.59524 .08104 9 0 ]
[.78571 .08104 -9 -9 ]
[.78571 .08104 9 0 ]
[.97619 .08104 -3 -9 ]
[.97619 .08104 3 0 ]
[1.025 .09354 0 -6 ]
[1.025 .09354 10.125 6 ]
[.01131 .12256 -12 -4.5 ]
[.01131 .12256 0 4.5 ]
[.01131 .26763 -12 -4.5 ]
[.01131 .26763 0 4.5 ]
[.01131 .4127 -12 -4.5 ]
[.01131 .4127 0 4.5 ]
[.01131 .55778 -12 -4.5 ]
[.01131 .55778 0 4.5 ]
[.5 .63053 -53.0625 0 ]
[.5 .63053 53.0625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .09354 m
.21429 .09979 L
s
[(0.2)] .21429 .08104 0 1 Mshowa
.40476 .09354 m
.40476 .09979 L
s
[(0.4)] .40476 .08104 0 1 Mshowa
.59524 .09354 m
.59524 .09979 L
s
[(0.6)] .59524 .08104 0 1 Mshowa
.78571 .09354 m
.78571 .09979 L
s
[(0.8)] .78571 .08104 0 1 Mshowa
.97619 .09354 m
.97619 .09979 L
s
[(1)] .97619 .08104 0 1 Mshowa
.125 Mabswid
.07143 .09354 m
.07143 .09729 L
s
.11905 .09354 m
.11905 .09729 L
s
.16667 .09354 m
.16667 .09729 L
s
.2619 .09354 m
.2619 .09729 L
s
.30952 .09354 m
.30952 .09729 L
s
.35714 .09354 m
.35714 .09729 L
s
.45238 .09354 m
.45238 .09729 L
s
.5 .09354 m
.5 .09729 L
s
.54762 .09354 m
.54762 .09729 L
s
.64286 .09354 m
.64286 .09729 L
s
.69048 .09354 m
.69048 .09729 L
s
.7381 .09354 m
.7381 .09729 L
s
.83333 .09354 m
.83333 .09729 L
s
.88095 .09354 m
.88095 .09729 L
s
.92857 .09354 m
.92857 .09729 L
s
.25 Mabswid
0 .09354 m
1 .09354 L
s
gsave
1.025 .09354 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
69.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .12256 m
.03006 .12256 L
s
[(10)] .01131 .12256 1 0 Mshowa
.02381 .26763 m
.03006 .26763 L
s
[(15)] .01131 .26763 1 0 Mshowa
.02381 .4127 m
.03006 .4127 L
s
[(20)] .01131 .4127 1 0 Mshowa
.02381 .55778 m
.03006 .55778 L
s
[(25)] .01131 .55778 1 0 Mshowa
.125 Mabswid
.02381 .15157 m
.02756 .15157 L
s
.02381 .18059 m
.02756 .18059 L
s
.02381 .2096 m
.02756 .2096 L
s
.02381 .23862 m
.02756 .23862 L
s
.02381 .29664 m
.02756 .29664 L
s
.02381 .32566 m
.02756 .32566 L
s
.02381 .35467 m
.02756 .35467 L
s
.02381 .38369 m
.02756 .38369 L
s
.02381 .44172 m
.02756 .44172 L
s
.02381 .47073 m
.02756 .47073 L
s
.02381 .49975 m
.02756 .49975 L
s
.02381 .52876 m
.02756 .52876 L
s
.02381 .06453 m
.02756 .06453 L
s
.02381 .03551 m
.02756 .03551 L
s
.02381 .0065 m
.02756 .0065 L
s
.02381 .58679 m
.02756 .58679 L
s
.02381 .6158 m
.02756 .6158 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -114.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Period) show
105.000 13.000 moveto
(of) show
123.000 13.000 moveto
(sn) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
135.000 13.000 moveto
(H) show
141.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(q) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
147.000 13.000 moveto
(\\310) show
153.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
159.125 13.000 moveto
(L) show
165.125 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .01661 L
.10458 .01878 L
.14415 .02092 L
.18221 .0231 L
.22272 .02555 L
.26171 .02804 L
.30316 .03087 L
.34309 .03378 L
.3815 .03678 L
.42237 .04022 L
.46172 .0438 L
.49955 .04755 L
.53984 .0519 L
.57861 .05654 L
.61984 .06203 L
.65954 .06802 L
.69774 .0746 L
.73838 .08276 L
.77751 .09216 L
.81909 .1046 L
.83996 .11223 L
.85916 .12042 L
.8791 .13057 L
.89771 .14223 L
.91654 .15739 L
.92651 .16758 L
.9372 .18115 L
.94679 .19706 L
.95221 .20859 L
.95722 .22192 L
.96159 .23687 L
.96642 .25985 L
.96884 .27624 L
.97021 .28806 L
.97146 .30157 L
.97256 .31685 L
.97376 .34013 L
.97502 .38237 L
s
.97502 .38237 m
.97548 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003o4oooool0
0ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool001?o
oooo0_l0003ooooooeCooooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo00?o
0000ooooooooool0oooooomCooooo`004oooool7o`000?ooooooCoooool001?ooooo00?o0000oooo
ooooool01?oooolKo`000?oooooo=?ooool001?ooooo00?o0000ooooooooool07oooool<o`000?oo
oooo:?ooool001?ooooo00?o0000ooooooooool0:oooool=o`000?oooooo6oooool001?ooooo00?o
0000ooooooooool0>?oooolJo`000?oooooo0Oooool001?ooooo00?o0000ooooooooool0D_ooool>
o`000?;ooooo000Cooooo`03o`000?oooooooooo063ooooo3Ol0003Uooooo`004oooool2o`0006ko
oooo3Ol0003Hooooo`004oooool00ol0003oooooooooo`1jooooo`Wo0000coooool001?ooooo00?o
0000ooooooooool0Poooool7o`000<Sooooo000Cooooo`03o`000?oooooooooo08[ooooo2Ol0002o
ooooo`004oooool00ol0003oooooooooo`2Cooooo`go0000/_ooool001?ooooo00?o0000oooooooo
ool0X?ooool9o`000:Wooooo000Cooooo`03o`000?oooooooooo033ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo02Cooooo1ol000000oo^k^koooooooooo`03oooo
o`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<02[ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<03;ooooo1?l000000ol@413ooooo
ooooo`0Iooooo`004oooool00ol0003oooooooooo`0`ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Yooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool0:?ooool01?mgMgOoV9RHoooooonHV9P6
o`0000;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02[ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Cooooo00?o0000oooooooo
ool06oooool001?ooooo00?o0000ooooooooool0<?ooool01Ol@413ooooooooooooooooo410@00co
oooo00?oV9RHob4Q8Oo^k^h0:_ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0000Yoooo
o`05oa0@4?ooooooooooooooool@41001Oooool7o`0000?ooooo00?o0000ooooooooool0:?ooool0
1Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000dooooo`03o`00
0?oooooooooo01_ooooo000Cooooo`;o0000<Oooool01Ol0003ooooooooooooooooo000000gooooo
00?oV9RHob4Q8Oo^k^h0:Oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoo
oooo0000:_ooool01Ol0003ooooooooooooooooo000000_ooooo2ol0000Tooooo`05o`000?oooooo
ooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b03Cooooo00?o0000ooooooooool0
6oooool001?ooooo00?o0000ooooooooool0<?ooool01Ol0003ooooooooooooooooo000000kooooo
00?oMgMgofIVI_ooool0:?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoo
oooo0000:_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<
c006ooooo`So00007?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o
0000olc<c00dooooo`03o`000?oooooooooo01_ooooo000Cooooo`03o`000?oooooooooo033ooooo
00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo02Oooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03ogMgMoo<c<co000002[ooooo00Go410@oooooooooooooooooa0@400;
ooooo`03oeEEEOn7QhOooooo013ooooo1Ol0000Gooooo`05oa0@4?ooooooooooooooool@41002ooo
ool01Ol@413o^[Zjoooooonj^[[o410@03Cooooo00?o0000ooooooooool06oooool001?ooooo00?o
0000ooooooooool0<?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo
V9RHoa0@400Yooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00000Zoooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV00Eooooo`Co00004oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000dooooo`03o`00
0?oooooooooo01_ooooo000Cooooo`03o`000?oooooooooo033ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0:Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00gooooo00?oMgMgo`000?ooool0:Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<
odA4A?l0003o410@5oooool5o`0000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT0<_ooool00omEEEGoIVIVo`00000Mooooo`004oooool00ol0003ooooo
ooooo`3Mooooo`Oo0000K_ooool001?ooooo00?o0000ooooooooool0i?ooool5o`0006Wooooo000C
ooooo`03o`000?oooooooooo0>Wooooo1Ol0001Hooooo`;o00000_ooool01Ol0003oooooooooool0
003o410@00?ooooo000Cooooo`03o`000?oooooooooo0>kooooo1?l0001Eooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooooooool00_ooool001?ooooo00?o0000ooooooooool0l_ooool4
o`00057ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`002ooooooo
o`0004Wo00002_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo000C
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?l00008ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo013ooooo00Oo0000olc<c?o<c<co0000ojVYZOoMgMgo8B4Q00Cooooo000Cooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo03cooooo00?o0000ooooooooool01?ooool3o`0003Cooooo00?o0000ooooooooool03ooo
ool02?l@413o0000ob4Q8Ol0003oMgMgoa0@4?l0003oZJVY1?ooool001?ooooo00?o0000oooooooo
ool0ooooool1ooooo`?o0000Coooool001?ooooo00?o0000ooooooooool0ooooool4ooooo`;o0000
COooool001?ooooo00?o0000ooooooooool0ooooool6ooooo`;o0000Boooool001?ooooo00?o0000
ooooooooool0ooooool8ooooo`;o0000BOooool00003ooooool0003o000000;o000000So410@oooo
ooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000ooooooooool0ooooool:ooooo`?o0000
A_ooool000?ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool0ooooool=ooooo`;o0000A?ooool000?ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00Kooooo0ol0003oooooo`oooooo0_l00012ooooo`000ooo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`3ooooooa7ooooo0_l00010ooooo`000oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooa?ooooo0_l0000nooooo`000ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooo
ooooo`3ooooooaGooooo0_l0000looooo`000oooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooaOooooo00?o0000ooooooooool0
>Oooool00004oooooomEEEGoIVIVo`0000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo0?oooooo6?ooool2o`0003Wooooo000Cooooo`03o`000?oooooooooo0?oooooo
6_ooool00ol0003oooooooooo`0fooooo`004oooool00ol0003oooooooooo`3ooooooa_ooooo0_l0
000fooooo`004oooool00ol0003oooooooooo`3ooooooagooooo00?o0000ooooooooool0<oooool0
01?ooooo00?o0000ooooooooool0oooooolNooooo`03o`000?oooooooooo03;ooooo000Cooooo`;o
0000oooooolPooooo`03o`000?oooooooooo037ooooo000Cooooo`03o`000?oooooooooo0?oooooo
8?ooool00ol0003oooooooooo`0`ooooo`004oooool00ol0003oooooooooo`3oooooob7ooooo0_l0
000`ooooo`004oooool00ol0003oooooooooo`3oooooob?ooooo00?o0000ooooooooool0;Oooool0
01?ooooo00?o0000ooooooooool0oooooolTooooo`03o`000?oooooooooo02cooooo000Cooooo`03
o`000?oooooooooo0?oooooo9Oooool00ol0003oooooooooo`0[ooooo`004oooool00ol0003ooooo
ooooo`3oooooobGooooo00?o0000ooooooooool0:oooool001?ooooo00?o0000ooooooooool0oooo
oolVooooo`03o`000?oooooooooo02[ooooo000Cooooo`03o`000?oooooooooo0?oooooo9oooool0
0ol0003oooooooooo`0Yooooo`004oooool2o`000?oooooo:Oooool00ol0003oooooooooo`0Xoooo
o`004oooool00ol0003oooooooooo`3oooooobSooooo00?o0000ooooooooool0:?ooool001?ooooo
00?o0000ooooooooool0oooooolYooooo`03o`000?oooooooooo02Oooooo000Cooooo`03o`000?oo
oooooooo0?oooooo:Oooool00ol0003oooooooooo`0Wooooo`004oooool00ol0003oooooooooo`3o
ooooob[ooooo00?o0000ooooooooool09_ooool001?ooooo00?o0000ooooooooool0oooooolZoooo
o`03o`000?oooooooooo02Kooooo000Cooooo`03o`000?oooooooooo0?oooooo:oooool00ol0003o
ooooooooo`0Uooooo`004oooool00ol0003oooooooooo`3oooooob_ooooo00?o0000ooooooooool0
9Oooool001?ooooo00?o0000ooooooooool0ooooool/ooooo`03o`000?oooooooooo02Cooooo000C
ooooo`03o`000?oooooooooo0?oooooo;Oooool00ol0003oooooooooo`0Sooooo`004oooool2o`00
0?oooooo;_ooool00ol0003oooooooooo`0Sooooo`004oooool00ol0003oooooooooo`3oooooobko
oooo00?o0000ooooooooool08_ooool001?ooooo00?o0000ooooooooool0ooooool^ooooo`03o`00
0?oooooooooo02;ooooo000Cooooo`03o`000?oooooooooo0?oooooo;_ooool00ol0003ooooooooo
o`0Rooooo`004oooool00ol0003oooooooooo`3ooooooboooooo00?o0000ooooooooool08Oooool0
01?ooooo00?o0000ooooooooool0ooooool_ooooo`03o`000?oooooooooo027ooooo000Cooooo`03
o`000?oooooooooo0?oooooo;oooool00ol0003oooooooooo`0Qooooo`004oooool00ol0003ooooo
ooooo`3ooooooc3ooooo00?o0000ooooooooool08?ooool001?ooooo00?o0000ooooooooool0oooo
ool`ooooo`03o`000?oooooooooo023ooooo000Cooooo`;o0000oooooolaooooo`03o`000?oooooo
oooo023ooooo000Cooooo`03o`000?oooooooooo0?oooooo<?ooool00ol0003oooooooooo`0Poooo
o`004oooool00ol0003oooooooooo`3ooooooc3ooooo00?o0000ooooooooool08?ooool001?ooooo
00?o0000ooooooooool0oooooolaooooo`03o`000?oooooooooo01oooooo000Cooooo`03o`000?oo
oooooooo0?oooooo<Oooool00ol0003oooooooooo`0Oooooo`004oooool00ol0003oooooooooo`3o
oooooc7ooooo00?o0000ooooooooool07oooool001?ooooo00?o0000ooooooooool0oooooolboooo
o`03o`000?oooooooooo01kooooo00000ooooooo0000o`000002o`000005oa0@4?oooooooooooooo
oom4A4@00_l000000olb<S;ogMgMooooo`04ooooo`03o`000?oooooooooo0?oooooo<_ooool00ol0
003oooooooooo`0Nooooo`000oooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolbooooo`03o`000?oooooooooo01kooooo0003ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooooc;ooooo
00?o0000ooooooooool07_ooool000?ooooo00?o0000ooooooooool01_ooool00omgMgOo<S8boooo
o`04ooooo`?o0000oooooolbooooo`03o`000?oooooooooo01kooooo0003ooooo`03o`000?oooooo
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo<_oo
ool00ol0003oooooooooo`0Nooooo`000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0oooooolbooooo`03o`000?oooooooooo01kooooo0003oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooo
oc;ooooo00?o0000ooooooooool07_ooool00004oooooomEEEGoIVIVo`0000Gooooo1?l00006oooo
o`03o`000?oooooooooo0?oooooo<_ooool00ol0003oooooooooo`0Nooooo`004oooool00ol0003o
ooooooooo`3ooooooc?ooooo00?o0000ooooooooool07Oooool001?ooooo00?o0000ooooooooool0
oooooolcooooo`03o`000?oooooooooo01gooooo000Cooooo`03o`000?oooooooooo0?oooooo<ooo
ool00ol0003oooooooooo`0Mooooo`004oooool00ol0003oooooooooo`3ooooooc?ooooo00?o0000
ooooooooool07Oooool001?ooooo0_l0003oooooocCooooo00?o0000ooooooooool07Oooool001?o
oooo00?o0000ooooooooool0oooooolcooooo`03o`000?oooooooooo01gooooo000Cooooo`03o`00
0?oooooooooo0?oooooo<oooool00ol0003oooooooooo`0Mooooo`004oooool00ol0003ooooooooo
o`3ooooooc?ooooo00?o0000ooooooooool07Oooool001?ooooo00?o0000ooooooooool0oooooolc
ooooo`03o`000?oooooooooo01gooooo000Cooooo`03o`000?oooooooooo0?oooooo=?ooool00ol0
003oooooooooo`0Looooo`004oooool00ol0003oooooooooo`3oooooocCooooo00?o0000oooooooo
ool07?ooool001?ooooo00?o0000ooooooooool0ooooooldooooo`03o`000?oooooooooo01cooooo
000Cooooo`03o`000?oooooooooo0?oooooo=?ooool00ol0003oooooooooo`0Looooo`004oooool0
0ol0003oooooooooo`3oooooocCooooo00?o0000ooooooooool07?ooool001?ooooo0_l0003ooooo
ocGooooo00?o0000ooooooooool07?ooool001?ooooo00?o0000ooooooooool0ooooooldooooo`03
o`000?oooooooooo01cooooo000Cooooo`03o`000?oooooooooo0?oooooo=?ooool00ol0003ooooo
ooooo`0Looooo`004oooool00ol0003oooooooooo`3oooooocCooooo00?o0000ooooooooool07?oo
ool001?ooooo00?o0000ooooooooool0ooooooldooooo`03o`000?oooooooooo01cooooo000Coooo
o`03o`000?oooooooooo0?oooooo=?ooool00ol0003oooooooooo`0Looooo`004oooool00ol0003o
ooooooooo`3oooooocCooooo00?o0000ooooooooool07?ooool001?ooooo00?o0000ooooooooool0
ooooooldooooo`03o`000?oooooooooo01cooooo000Cooooo`03o`000?oooooooooo0?oooooo=?oo
ool00ol0003oooooooooo`0Looooo`004oooool2o`000?oooooo=Oooool00ol0003oooooooooo`0L
ooooo`004oooool00ol0003oooooooooo`3oooooocCooooo00?o0000ooooooooool07?ooool001?o
oooo00?o0000ooooooooool0ooooooldooooo`03o`000?oooooooooo01cooooo000Cooooo`03o`00
0?oooooooooo0?oooooo=Oooool00ol0003oooooooooo`0Kooooo`004oooool00ol0003ooooooooo
o`3oooooocGooooo00?o0000ooooooooool06oooool001?ooooo00?o0000ooooooooool0oooooole
ooooo`03o`000?oooooooooo01_ooooo000Cooooo`03o`000?oooooooooo0?oooooo=Oooool00ol0
003oooooooooo`0Kooooo`004oooool00ol0003oooooooooo`3oooooocGooooo00?o0000oooooooo
ool06oooool001?ooooo00?o0000ooooooooool0ooooooleooooo`03o`000?oooooooooo01_ooooo
000Cooooo`03o`000?oooooooooo0?oooooo=Oooool00ol0003oooooooooo`0Kooooo`004oooool2
o`000?oooooo=_ooool00ol0003oooooooooo`0Kooooo`004oooool00ol0003oooooooooo`3ooooo
ocGooooo00?o0000ooooooooool06oooool001?ooooo00?o0000ooooooooool0ooooooleooooo`03
o`000?oooooooooo01_ooooo000Cooooo`03o`000?oooooooooo0?oooooo=Oooool00ol0003ooooo
ooooo`0Kooooo`004oooool00ol0003oooooooooo`3oooooocGooooo00?o0000ooooooooool06ooo
ool001?ooooo00?o0000ooooooooool0ooooooleooooo`03o`000?oooooooooo01_ooooo000Coooo
o`03o`000?oooooooooo0?oooooo=Oooool00ol0003oooooooooo`0Kooooo`001Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3oooooocGooooo00?o0000oooo
ooooool06oooool00005oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Kooooo00?o0000ooooooooool0ooooooleooooo`03o`000?oooooooooo01_ooooo00001?oo
ooooV9RHob4Q8Oo^k^h4ooooo`05oa0@4?ooooooooooooooool@41001_ooool3o`000?oooooo=Ooo
ool00ol0003oooooooooo`0Kooooo`000_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3oooooocGooooo00?o0000ooooooooool06ooo
ool000?ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool0ooooooleooooo`03o`000?oooooooooo01_ooooo0004ooooo`05o`000?oooooo
ooooooooool@41000oooool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo=Ooo
ool00ol0003oooooooooo`0Kooooo`0000Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3oooooocGooooo00?o0000ooooooooool0
6oooool00005oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Ko
oooo00?o0000ooooooooool0ooooooleooooo`03o`000?oooooooooo01_ooooo000Cooooo`03o`00
0?oooooooooo0?oooooo=Oooool00ol0003oooooooooo`0Kooooo`004oooool00ol0003ooooooooo
o`3oooooocGooooo00?o0000ooooooooool06oooool001?ooooo00?o0000ooooooooool0oooooole
ooooo`03o`000?oooooooooo01_ooooo000Cooooo`03o`000?oooooooooo0?oooooo=Oooool00ol0
003oooooooooo`0Kooooo`004oooool2o`000?oooooo=_ooool00ol0003oooooooooo`0Kooooo`00
4oooool00ol0003oooooooooo`3oooooocGooooo00?o0000ooooooooool06oooool001?ooooo00?o
0000ooooooooool0ooooooleooooo`03o`000?oooooooooo01_ooooo000Cooooo`03o`000?oooooo
oooo0?oooooo=Oooool00ol0003oooooooooo`0Kooooo`004oooool00ol0003oooooooooo`3ooooo
ocGooooo00?o0000ooooooooool06oooool001?ooooo00?o0000ooooooooool0ooooooleooooo`03
o`000?oooooooooo01_ooooo000Cooooo`03o`000?oooooooooo0?oooooo=Oooool00ol0003ooooo
ooooo`0Kooooo`004oooool00ol0003oooooooooo`3oooooocGooooo00?o0000ooooooooool06ooo
ool001?ooooo00?o0000ooooooooool0ooooooleooooo`03o`000?oooooooooo01_ooooo000Coooo
o`;o0000oooooolfooooo`03o`000?oooooooooo01_ooooo000Cooooo`03o`000?oooooooooo0?oo
oooo=Oooool00ol0003oooooooooo`0Kooooo`004oooool00ol0003oooooooooo`3oooooocGooooo
00?o0000ooooooooool06oooool001?ooooo00?o0000ooooooooool0ooooooleooooo`03o`000?oo
oooooooo01_ooooo000Cooooo`03o`000?oooooooooo0?oooooo=Oooool00ol0003oooooooooo`0K
ooooo`004oooool00ol0003oooooooooo`3oooooocGooooo00?o0000ooooooooool06oooool001?o
oooo00?o0000ooooooooool0ooooooleooooo`03o`000?oooooooooo01_ooooo000Cooooo`03o`00
0?oooooooooo0?oooooo=Oooool00ol0003oooooooooo`0Kooooo`004oooool00ol0003ooooooooo
o`3oooooocGooooo00?o0000ooooooooool06oooool001?ooooo00?o0000ooooooooool0oooooole
ooooo`03o`000?oooooooooo01_ooooo000Cooooo`;o0000oooooolfooooo`03o`000?oooooooooo
01_ooooo000Cooooo`03o`000?oooooooooo0?oooooo=Oooool00ol0003oooooooooo`0Kooooo`00
4oooool00ol0003oooooooooo`3oooooocGooooo00?o0000ooooooooool06oooool001?ooooo00?o
0000ooooooooool0ooooooleooooo`03o`000?oooooooooo01_ooooo000Cooooo`03o`000?oooooo
oooo0?oooooo=Oooool00ol0003oooooooooo`0Kooooo`004oooool00ol0003oooooooooo`3ooooo
ocGooooo00?o0000ooooooooool06oooool001?ooooo00?o0000ooooooooool0ooooooleooooo`03
o`000?oooooooooo01_ooooo000Cooooo`03o`000?oooooooooo0?oooooo=Oooool00ol0003ooooo
ooooo`0Kooooo`004oooool00ol0003oooooooooo`3oooooocGooooo00?o0000ooooooooool06ooo
ool001?ooooo0_l0003oooooocKooooo00?o0000ooooooooool06oooool001?ooooo00?o0000oooo
ooooool0ooooooleooooo`03o`000?oooooooooo01_ooooo000Cooooo`03o`000?oooooooooo0?oo
oooo=Oooool00ol0003oooooooooo`0Kooooo`004oooool00ol0003oooooooooo`3oooooocGooooo
00?o0000ooooooooool06oooool001?ooooo00?o0000ooooooooool0ooooooleooooo`03o`000?oo
oooooooo01_ooooo000Cooooo`03o`000?oooooooooo0?oooooo=Oooool00ol0003oooooooooo`0K
ooooo`004oooool00ol0003oooooooooo`3oooooocGooooo00?o0000ooooooooool06oooool000Go
00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0ooooooleoooo
o`03o`000?oooooooooo01_ooooo00001OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocGooooo00?o0000ooooooooool06oooool00004
oooooonHV9So8B4Qonk^kPWooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooo
ocGooooo00?o0000ooooooooool06oooool000;ooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo
<S8booooo`04ooooo`?o0000ooooooleooooo`03o`000?oooooooooo01_ooooo0003ooooo`03ogMg
MomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oo
oooo=Oooool00ol0003oooooooooo`0Kooooo`001?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0ooooooleooooo`03o`000?oooooooooo01_ooooo
00001Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3oooooocGooooo00?o0000ooooooooool06oooool00005oiRHV?l@413o0000ob4Q8Oo<c<`0
1?ooool4o`0000Kooooo00?o0000ooooooooool0ooooooleooooo`03o`000?oooooooooo01_ooooo
000Cooooo`03o`000?oooooooooo0?oooooo=Oooool00ol0003oooooooooo`0Kooooo`004oooool0
0ol0003oooooooooo`3oooooocGooooo00?o0000ooooooooool06oooool001?ooooo00?o0000oooo
ooooool0ooooooleooooo`03o`000?oooooooooo01_ooooo000Cooooo`03o`000?oooooooooo0?oo
oooo=Oooool00ol0003oooooooooo`0Kooooo`004oooool2o`000?oooooo=_ooool00ol0003ooooo
ooooo`0Kooooo`004oooool00ol0003oooooooooo`3oooooocGooooo00?o0000ooooooooool06ooo
ool001?ooooo00?o0000ooooooooool0ooooooleooooo`03o`000?oooooooooo01_ooooo000Coooo
o`03o`000?oooooooooo0?oooooo=Oooool00ol0003oooooooooo`0Kooooo`004oooool00ol0003o
ooooooooo`3oooooocGooooo00?o0000ooooooooool06oooool001?ooooo00?o0000ooooooooool0
ooooooleooooo`03o`000?oooooooooo01_ooooo000Cooooo`03o`000?oooooooooo0?oooooo=Ooo
ool00ol0003oooooooooo`0Kooooo`004oooool00ol0003oooooooooo`3oooooocGooooo00?o0000
ooooooooool06oooool001?ooooo00?o0000ooooooooool0ooooooleooooo`03o`000?oooooooooo
01_ooooo000Cooooo`03o`000?oooooooooo0?oooooo=Oooool00ol0003oooooooooo`0Kooooo`00
4oooool2o`000?oooooo=_ooool00ol0003oooooooooo`0Kooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00cOooool0
0omgMgOoIVIVooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?oIVIVogMgMoooool0OOooool0
0<cooooo00?ogMgMoa0@4?o^k^h03?ooool00ol0003oooooooooo`0:ooooo`03onk^k_l@413ogMgM
07gooooo001_ooooo`?o000000?o410@ooooooooool00_ooool02?o^k^koEEEEo`000?l0003oA4A4
okZj^_oooooo410@1Ol00004ooooo`Go00000_ooool01_o^k^koEEEEo`000?l0003oEEEEonk^kP;o
oooo00Ook^k^oeEEEOl0003o0000oiRHV?l0003o410@00Kooooo00Kok^k^oeEEEOl0003o0000oeEE
EOo^k^h2ooooo`03oa0@4?l0003o000000;o000000?o410@ooooooooool01_ooool01_l@413o<S8b
o`000?l0003o410@ojVYZ@;ooooo00Co410@o`000?l0003ooooo0_l000001_l@413ooooooooooooo
ooooEEEEoiRHV0?ooooo00Kok^k^oc8b<_l0003o0000oeEEEOo^k^h4ooooo`04o`000?oooooooooo
ooooo`;o00000_ooool02?l0003oooooooooool0003o410@oooooon7QhOoIVIVOOooool0073ooooo
00?o0000ooooooooool01?ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40?ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`02ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE0_oo
ool01_mEEEGoMgMgooooooo^k^koEEEEo`0000Oooooo00KoEEEEogMgMoooooooooooogMgMomEEED4
ooooo`03o`000?oooooooooo00Wooooo00Ko0000ojVYZOoooooooooookZj^_l00003ooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`07oeEEEOmgMgOoooooonk^
k_n7QhOo8B4Qonk^kP03ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01Ol0003oooooooooooo^k^ko000007gooooo001`ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`03onk^k_l0003ooooo00Kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo
00Go^[ZjohN7QomVIVKoIVIVoa0@4003ooooo`05o`000?ooooooooooooooool000001?ooool00olb
<S;oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?oQhN7ogMgMoooool00_ooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`00
001mooooo`00L?ooool3o`000004ob4Q8Oo<c<coooooooooo`Ko00000oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00003ooooo`03onk^k_l0003ooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Ko<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^h3oooo
o`05o`000?ooooooooooooooool000001?ooool00olb<S;oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00Go8B4Qooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000;ooooo
00Go0000ooooooooooooooooo`00001mooooo`00L?ooool01Ol0003ooooooooooon7QhOo410@00;o
oooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S83ooooo`03o`000?lb<S;ogMgM00Oooooo00?o0000
ooooooooool00_ooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@;ooooo00KoIVIVogMgMooooooo
k^k^oeEEEOl00007ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE1?ooool00ol0003ooooooooo
o`09ooooo`06o`000?nj^[[oooooonk^k_mgMgOo00000oooool01Ol0003oQhN7oooooonYZJWo0000
00Cooooo00?o0000onk^k_ooool00_ooool00olQ8B7o0000o`000004o`0000?ooooo00?o0000oooo
ooooool00_ooool01ol0003oc<c<olc<c?l0003oZJVYomgMgOlQ8B400_ooool00oo^k^ko0000oooo
o`1looooo`00L?ooool01Ol0003ooooooooooooooooo000000;ooooo00Kok^k^oeEEEOl0003o0000
odA4A?o^k^h2ooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q0oooool00ol@413o0000o`000004oooo
o`06onk^k_mEEEGo0000o`000?mEEEGok^k^0_ooool01_o^k^koEEEEo`000?l@413oc<c<o`0000Oo
oooo00Kok^k^oeEEEOl0003o0000oeEEEOo^k^h2ooooo`03oa0@4?l0003o000000?o00002?ooool0
1_nYZJWo8B4Qo`000?l0003o<S8bo`0000;ooooo00?o410@o`000?mgMgL00_l000000onHV9Sooooo
ooooo`02ooooo`03oeEEEOmgMgOooooo00;ooooo00?oV9RHohN7Qoooool00oooool01Ol0003ooooo
oooooooooooo000000?ooooo00So410@o`000?lQ8B7o0000ogMgMol@413o0000ojVYZ@;ooooo00?o
MgMgoeEEEOooool0O?ooool0073ooooo00Go0000ooooooooooooQhN7oa0@400Wooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool06oooool00ooMgMgo410@onk^kP03ooooo`06oc8b<_n7
QhOok^k^oooooon7QhOo<S8b0oooool00ol0003oooooooooo`0:ooooo`03onk^k_l@413ogMgM07go
oooo001_ooooo`Co000000?o8B4Qolc<c?ooool05?ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00oooooo00?o410@okZj^_ooool07?ooool00omgMgOoIVIVooooo`02ooooo`06onk^
k_mgMgOo0000o`000?lb<S;oc<c<0oooool00ol0003oooooooooo`0:ooooo`03ofIVI_mgMgOooooo
07gooooo002:ooooo`03oa0@4?oooooooooo00kooooo0_l0000Aooooo`04okZj^_l@413o0000oa0@
4;Kooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.0613147, 5.76145, \
0.00401541, 0.131803}}]
}, Open  ]],

Cell[TextData[{
  " For ",
  Cell[BoxData[
      \(TraditionalForm\`m \[Rule] 0\)]],
  ", corresponding to ",
  Cell[BoxData[
      \(TraditionalForm\`b \[Rule] \ a\)]],
  ", the period of sn is ",
  Cell[BoxData[
      \(TraditionalForm\`2  \[Pi]\)]],
  ", and in fact, ",
  Cell[BoxData[
      \(TraditionalForm\`sn(\[Theta], 0) = sin\ \[Theta]\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(JacobiSN[\[Theta], 0]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.36"],

Cell[BoxData[
    \(Sin[\[Theta]]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This low-amplitude limit of the cnoidal waves  [",
  Cell[BoxData[
      \(TraditionalForm\`\(\(m\)\(\[Rule]\)\(0\)\(\ \)\)\)]],
  "implies that ",
  Cell[BoxData[
      \(TraditionalForm\`b \[Rule] a\)]],
  " in Eq. ",
  ButtonBox["(7.2.12)",
    ButtonData:>{"Chapter7.nb", "(7.2.12)"},
    ButtonStyle->"Hyperlink"],
  " ] corresponds to the limit of linear waves. "
}], "Text"],

Cell[TextData[{
  "\tSince ",
  Cell[BoxData[
      \(TraditionalForm\`sn\^2\)]],
  " has a period half that of sn, Eq. ",
  ButtonBox["(7.2.12)",
    ButtonData:>{"Chapter7.nb", "(7.2.12)"},
    ButtonStyle->"Hyperlink"],
  "  implies that the wavelength ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda](a, b, c)\)]],
  " of the ",
  "cnoidal",
  " waves is given by"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda](a, b, 
          c)\  = \(\(1\/2\) \(\@\(\(12\ \[Alpha]\)\/\(a - c\)\)\)\(\ \)\(P(
            m)\)\(\ \)\)\)]],
  "."
}], "NE2",
  CellTags->"(7.2.14)"],

Cell[TextData[{
  "In the linear limit ",
  Cell[BoxData[
      \(TraditionalForm\`b \[Rule] \ a\)]],
  " (",
  Cell[BoxData[
      \(TraditionalForm\`m \[Rule] \ 0\)]],
  ") this becomes"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda](a, a, 
          c)\  = \@\(\(12\ \[Alpha]\)\/\(a - c\)\)\ \ \[Pi]\)]],
  "."
}], "NE2",
  CellTags->"(7.2.15)"],

Cell[TextData[{
  "Some examples of cnoidal waves for increasing amplitude are shown in Cell \
",
  ButtonBox["7.37",
    ButtonData:>"Cell 7.37",
    ButtonStyle->"Hyperlink"],
  ", keeping the wave height constant and increasing the depth of the troughs \
(",
  Cell[BoxData[
      \(TraditionalForm\`a = 1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`c = 0\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " decreasing away from ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " toward ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  "):"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(f[s_, a_, b_, 
          c_] = \ \ a\  - \ \((a - b)\)\ JacobiSN[Sqrt[\((a - c)\)/12] s, 
                  m]^2 /. m \[Rule] \((a - b)\)/\((a - c)\);\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(Table[
        Plot[f[s, 1, b, 0], {s, \(-20\), 20}, 
          PlotLabel \[Rule] "\<m =\>" <> 
              ToString[\((a - b)\)/\((a - c)\) /. {a \[Rule] 1, 
                    c \[Rule] 0}], 
          AxesLabel \[Rule] \ {"\<s/\!\(\@\[Alpha]\)\>", "\<\>"}, 
          PlotRange \[Rule] {\(-1\), 1}\ ], {b,  .9, 
          0. , \(- .2\)\ }];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.37"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0238095 0.309017 0.309017 [
[.02381 .29652 -9 -9 ]
[.02381 .29652 9 0 ]
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.7381 .29652 -6 -9 ]
[.7381 .29652 6 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[1.025 .30902 0 -6.71875 ]
[1.025 .30902 32.5625 6.71875 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -20.0625 0 ]
[.5 .63053 20.0625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-20)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-10)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(10)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(20)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10.7188 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.4375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 14.438 moveto
(\\220) show
0.000 0.000 0.000 setrgbcolor
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 9.062 moveto
(\\217) show
83.188 9.062 moveto
(!!) show
88.000 9.062 moveto
(!) show
83.562 14.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
91.562 14.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -81.0625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
75.125 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
81.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
99.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60607 m
.04262 .59926 L
.06244 .59287 L
.07286 .59028 L
.07784 .58928 L
.08255 .58851 L
.08523 .58814 L
.08813 .58781 L
.09054 .58758 L
.0932 .58738 L
.09468 .5873 L
.09607 .58723 L
.09754 .58718 L
.09836 .58716 L
.09912 .58715 L
.09981 .58714 L
.10045 .58713 L
.10116 .58713 L
.10192 .58714 L
.10264 .58714 L
.10331 .58715 L
.10458 .58718 L
.10574 .58722 L
.10699 .58728 L
.10923 .58741 L
.11191 .58761 L
.11434 .58785 L
.11964 .58853 L
.12466 .58937 L
.13351 .59127 L
.14313 .59388 L
.16252 .60036 L
.18391 .60807 L
.19366 .61126 L
.20417 .61418 L
.209 .61528 L
.21408 .61627 L
.21843 .61694 L
.22318 .6175 L
.22571 .61772 L
.22705 .61781 L
.22846 .61789 L
.2297 .61795 L
.23036 .61797 L
.23106 .61799 L
.2323 .61802 L
.23345 .61803 L
.23465 .61803 L
.23596 .61802 L
.23719 .61799 L
Mistroke
.23833 .61795 L
.23947 .6179 L
.24049 .61784 L
.24279 .61769 L
.24549 .61744 L
.24798 .61716 L
.25358 .61633 L
.26374 .61421 L
.2735 .61152 L
.2826 .60859 L
.30328 .60117 L
.32195 .59478 L
.3318 .59196 L
.34224 .58958 L
.3475 .58866 L
.35029 .58826 L
.3533 .58789 L
.35605 .58762 L
.35858 .58742 L
.36099 .58728 L
.3622 .58723 L
.36352 .58718 L
.36417 .58717 L
.36488 .58715 L
.36617 .58714 L
.36742 .58713 L
.36857 .58714 L
.36982 .58716 L
.37053 .58718 L
.37119 .5872 L
.37252 .58726 L
.37396 .58733 L
.37656 .5875 L
.37903 .58772 L
.38365 .58825 L
.38823 .58894 L
.39329 .58988 L
.40354 .5923 L
.42195 .59804 L
.4429 .6056 L
.46212 .612 L
.47187 .61459 L
.48094 .61642 L
.48552 .61709 L
.48787 .61737 L
.49041 .61762 L
.49186 .61773 L
.4932 .61782 L
.49446 .61789 L
.49584 .61796 L
Mistroke
.49708 .618 L
.49824 .61802 L
.49946 .61803 L
.50078 .61803 L
.50146 .61802 L
.50211 .61801 L
.50332 .61798 L
.50462 .61794 L
.50602 .61787 L
.50856 .6177 L
.51089 .6175 L
.51626 .61685 L
.52193 .61591 L
.53151 .61376 L
.54202 .61074 L
.56318 .60339 L
.58247 .59654 L
.59205 .59354 L
.60246 .5908 L
.60723 .58977 L
.6123 .58885 L
.61673 .5882 L
.62139 .58768 L
.62373 .58748 L
.62497 .58739 L
.62629 .58732 L
.62751 .58726 L
.62861 .58721 L
.62972 .58718 L
.63077 .58715 L
.632 .58714 L
.6333 .58713 L
.63441 .58714 L
.63562 .58716 L
.63693 .5872 L
.63834 .58725 L
.63967 .58731 L
.64088 .58739 L
.64537 .58775 L
.64791 .58803 L
.65026 .58834 L
.65916 .58986 L
.66977 .59237 L
.67974 .59531 L
.69837 .60177 L
.7168 .60838 L
.72725 .61175 L
.73699 .61438 L
.74665 .61637 L
.74943 .61681 L
Mistroke
.75206 .61716 L
.7544 .61743 L
.75698 .61767 L
.75953 .61785 L
.76093 .61792 L
.76224 .61797 L
.76346 .618 L
.76457 .61802 L
.76586 .61803 L
.76709 .61803 L
.76841 .61801 L
.76914 .61799 L
.76981 .61797 L
.77111 .61791 L
.77234 .61785 L
.77509 .61766 L
.77806 .61738 L
.78298 .61674 L
.78756 .61597 L
.79799 .61363 L
.81906 .60703 L
.83768 .60029 L
.85795 .59356 L
.86898 .59068 L
.87383 .58965 L
.87918 .58871 L
.88421 .58802 L
.88894 .58754 L
.89154 .58736 L
.89392 .58724 L
.89517 .58719 L
.89589 .58717 L
.89654 .58716 L
.89723 .58714 L
.89797 .58714 L
.89865 .58713 L
.8993 .58713 L
.90045 .58714 L
.90169 .58716 L
.90286 .58719 L
.90393 .58723 L
.90654 .58737 L
.90902 .58754 L
.91394 .58804 L
.9193 .58879 L
.92888 .59066 L
.93775 .59292 L
.97619 .60607 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00Toooool4o`000003oa0@4?oooooooooo0<kooooo002Eooooo`03o`00
0?oooooooooo0=3ooooo002:ooooo`Ko00001Oooool00ol0003oooooooooo`05ooooo`?o0000b?oo
ool009Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`38ooooo`00UOooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0<Sooooo002Eooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0b?ooool009Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`38ooooo`00Toooool00omEEEGoIVIVo`000007ooooo`;o0000bOooool009gooooo00?o0000
ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000oooooooo
ool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo0_l00039ooooo`00WOooool0
0ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003o
ooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2o`000<Wooooo002M
ooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03
o`000?oooooooooo0<Sooooo002Mooooo`;o0000bOooool009gooooo00?o0000ooooooooool0b?oo
ool009gooooo00?o0000ooooooooool0b?ooool007[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`38ooooo`00N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`38ooooo`00L_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmE
EEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000<Sooooo001jooooo`05o`000?oooooo
ooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0b?ooool007[ooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<
c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0<Sooooo
001jooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0b?ooool007[ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0<Sooooo001jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Co
oooo1?l00006ooooo`;o0000bOooool009gooooo00?o0000ooooooooool0b?ooool009gooooo00?o
0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000oooo
ooooool0b?ooool009gooooo0_l00039ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOoo
ool00ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2o`00
0<Wooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo
002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Moooo
o`;o0000bOooool009gooooo00?o0000ooooooooool0b?ooool008;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0b?ooool008;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0<Sooooo001jooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`38oooo
o`00P_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool3o`00
0<Sooooo0022ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool0b?ooool008;ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0b?ooool008;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0b?ooool0
08;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`38
ooooo`00WOooool2o`000<Wooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`00
0?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`;o0000bOooool0
09gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo
00?o0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo0_l00039
ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00
WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2
o`000<Wooooo002Mooooo`03o`000?oooooooooo0<Sooooo001jooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`38ooooo`00N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0<Sooooo001booooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0<Sooooo001j
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol00038ooooo`00N_ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
b?ooool007[ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`38ooooo`00N_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0b?ooool007[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l00039ooooo`00WOooool00ol0003o
ooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003ooooooooo
o`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2o`000<Wooooo0008ooooo`Go
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03gooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^?oooool00ol0003oooooooooo`10ooooo`Co000000So410@oooooooooooo
k^k^oc8b<_l0003o<S8bonk^kScooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0<ooo
ool000Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
?oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003o
ooooooooo`12ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo0006
o`0000?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@03Cooooo1_l0
0005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400oooooo`03o`00
0?oooooooooo04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@03go
oooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@03?ooooo000:ooooo`03
oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000oooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`00000oooooo`03o`000?oooooooooo04;ooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000003kooooo00?oV9RHob4Q8Oo^k^h00ooo
ool01Ol0003ooooooooooooooooo000003?ooooo000;ooooo`03ogMgMomVIVKooooo00;ooooo00Go
0000ooooooooooooooooo`00000oooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`00000oooooo`;o0000@oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000?oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000<oooool0
00cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03gooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@03oooooo00?o0000ooooooooool0@_oo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100@?ooool01Ol0003ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool0<Oooool000Sooooo00Go0000okZj^_oooooo
V9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003oooooooooo`12ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0looooo`05o`000?nj^[[ooooooiRHV?l@4100
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo0008ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03gooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03oooooo00?o0000ooooooooool0@?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0??ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Oooooo`03oiRHV?oooooooooo017ooooo002Mooooo`;o0000
]?ooool00oo^k^ko0000olc<c00Booooo`00WOooool00ol0003oooooooooo`2Zooooo`03ob4Q8OoM
gMgooooo00Kooooo00?oMgMgo`000?mVIVH04_ooool009gooooo00?o0000ooooooooool0XOooool0
1_l@413o<S8bo`000?l0003o410@ojVYZ@?ooooo00?oV9RHoeEEEOooool01Oooool01?o^k^ko0000
oiRHV?lQ8B45ooooo`07oiRHV?l0003o0000oeEEEOo^k^koIVIVo`000006ooooo`00WOooool00ol0
003oooooooooo`2Qooooo`06o`000?nYZJWooooooooooonj^[[o00001?ooool00ol0003ogMgMoooo
o`04ooooo`05ogMgMomEEEGoooooo`000?oMgMd01?ooool01_l0003oZJVYoooooon7QhOo<S8bofIV
IPOooooo002Mooooo`03o`000?oooooooooo0:;ooooo00Go^[ZjohN7QomVIVKoIVIVoa0@4004oooo
o`;oMgMg1Oooool01Ol0003oc<c<oooooomEEEGoQhN700Cooooo00Ko0000ooooooooooooooooohN7
Qom4A4@7ooooo`000oooooooo`0003Go00002_ooool01_lb<S;o8B4QogMgMomgMgOoQhN7onk^kPCo
oooo00?ok^k^oa0@4?o^k^h00_ooool00olb<S;oEEEEoc8b<P02ooooo`03ojVYZOlQ8B7ooooo00?o
oooo00Ko8B4Qolc<c?oooooooooooiRHV?lb<S87ooooo`002oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03oooool01_l0003o^[Zjooooooo^k^ko
MgMgo`0000Gooooo00OoEEEEoiRHV?oooooooooookZj^_lb<S;o^[Zj00?ooooo00?o0000omgMgOoo
ool00_ooool01onYZJWo8B4QomgMgOo^k^ko<S8boeEEEOnj^[X01_ooool000_ooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo04Kooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`0?ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o00001Ooo
ool00ooMgMgo410@ooooo`07ooooo`03oeEEEOn7QhOooooo00?ooooo00KoV9RHo`000?l0003oV9RH
okZj^_lb<S86ooooo`00WOooool00ol0003oooooooooo`2]ooooo`03oeEEEOnHV9Sooooo00Kooooo
00?oZJVYoc8b<_ooool03oooool009gooooo00?o0000ooooooooool0[Oooool00onj^[[oA4A4oooo
o`06ooooo`03onk^k_l0003ok^k^00oooooo002Mooooo`;o0000^?ooool00om4A4CoV9RHooooo`0>
ooooo`00WOooool00ol0003oooooooooo`2gooooo`03oiRHV?m4A4Cooooo00kooooo002Mooooo`03
o`000?oooooooooo0;Oooooo00?ok^k^o`000?l000002_l00004ooooo`00WOooool00ol0003ooooo
ooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2o`000<Wooooo002Moooo
o`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`00
0?oooooooooo0<Sooooo002Mooooo`;o0000bOooool009gooooo00?o0000ooooooooool0b?ooool0
09gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo
00?o0000ooooooooool0b?ooool009gooooo0_l00039ooooo`00WOooool00ol0003oooooooooo`38
ooooo`00N_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0b?ooool007[ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`38ooooo`00N_ooool01Ol@413ooooooooo
oooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo0<Sooooo001jooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Q
onk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00038ooooo`00N_ooool01Ol0003ooooooooo
oooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool0b?ooool007[ooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`38ooooo`00
N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0b?ooool007[ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000
ooooooooool0b?ooool009gooooo0_l00039ooooo`00WOooool00ol0003oooooooooo`38ooooo`00
WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2
o`000<Wooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<So
oooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002M
ooooo`;o0000bOooool009gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000oooooooo
ool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?oo
ool009gooooo0_l00039ooooo`00WOooool00ol0003oooooooooo`38ooooo`00P_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`38ooooo`00P_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0b?ooool008;ooooo00Go410@oooo
oooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0b?ooool0
08;ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00038
ooooo`00P_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo0<Sooooo0022ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0<Sooooo0022ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0<Sooooo0022
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l00039ooooo`00WOooool0
0ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003o
ooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2o`000<Wooooo002M
ooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03
o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`;o0000bOoo
ool009gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009go
oooo00?o0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo0_l0
0039ooooo`00WOooool00ol0003oooooooooo`38ooooo`00N_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgM
g@05ooooo`03o`000?oooooooooo0<Sooooo001jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0<Sooooo001jooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEoooo
o`08ooooo`03o`000?oooooooooo00?ooooo0ol00038ooooo`00N_ooool01Ol0003ooooooooooooo
oooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0<Sooooo001jooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<oooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`38ooooo`00N_oo
ool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0<Sooooo001jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`38ooooo`00N_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co
00001_ooool2o`000<Wooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oo
oooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo
0<Sooooo002Mooooo`;o0000bOooool009gooooo00?o0000ooooooooool0b?ooool009gooooo00?o
0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool002;ooooo00?o0000oooo
ooooool0Coooool00ol0003oooooooooo`0Vooooo`;o00009oooool00ol0003oooooooooo`1>oooo
o`03o`000?oooooooooo04kooooo000Ioooooa?o0000?ooooolDo`0001kooooo00?o0000oooooooo
ool07OoooolDo`0003kooooo4Ol00018ooooo`005_ooool3o`0001?ooooo0ol0000iooooo`?o0000
5?ooool3o`0001_ooooo00?o0000ooooooooool06?ooool5o`0001Cooooo0ol0000fooooo`Go0000
4Oooool6o`0004;ooooo000Cooooo`?o00006Oooool3o`0003?ooooo0ol0000Jooooo`?o00006?oo
ool00ol0003oooooooooo`0Eooooo`?o00007?ooool3o`00033ooooo0ol0000Looooo`?o0000?ooo
ool0013ooooo0ol0000Oooooo`?o0000;Oooool3o`00023ooooo0ol0000Eooooo`03o`000?oooooo
oooo01;ooooo0ol0000Rooooo`?o0000:oooool2o`0002;ooooo0ol0000looooo`003Oooool3o`00
02Gooooo0ol0000Wooooo`?o00009_ooool3o`0001;ooooo0_l0000@ooooo`?o0000:?ooool2o`00
02Oooooo0_l0000Wooooo`?o0000>Oooool000_ooooo0_l0000[ooooo`?o00008Oooool3o`0002co
oooo0ol0000?ooooo`03o`000?oooooooooo00gooooo0_l0000]ooooo`?o00008Oooool3o`0002co
oooo00?o0000ooooooooool0=_ooool003_ooooo1?l0000Jooooo`?o0000<_ooool3o`0000;ooooo
1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo0_l0000booooo`?o0000
6oooool3o`0006Sooooo000oooooo`?o00005?ooool3o`0003Sooooo0ol000000ooooooo0000oooo
o`06ooooo`03o`000?oooooooooo00Sooooo0ol0000gooooo`?o00005Oooool3o`0006_ooooo0012
ooooo`Co00002oooool5o`0003kooooo1?l00005ooooo`03o`000?oooooooooo00?ooooo1Ol0000m
ooooo`Co00003?ooool5o`0006kooooo0016ooooo`_o0000A?ooool00ol0003oooooooooo`0;o`00
04Kooooo3?l0001cooooo`00UOooool00ol0003oooooooooo`3@ooooo`00UOooool00ol0003ooooo
ooooo`3@ooooo`00UOooool00ol0003oooooooooo`3@ooooo`00Toooool00omEEEGoIVIVo`00003B
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Q_ooool2
o`0000;ooooo00Go0000oooooooooooo0000oa0@400?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Gooooo1?l000000ol@413oooooooooo`2booooo`00Qoooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00Kooooo1_l00002ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool0]?ooool008Oooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0>ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0
003oooooooooo`2dooooo`00Qoooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00Kooooo1_l00002ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`2d
ooooo`00Qoooool01ol0003oc<c<olc<c?l0003oZJVYomgMgOlQ8B404?ooool01Ol0003ooooooooo
oooooooo000000kooooo00?o0000ooooooooool0]?ooool008Kooooo00So410@o`000?lQ8B7o0000
ogMgMol@413o0000ojVYZA3ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooo
oooo0;Cooooo002Nooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`2d
ooooo`00W_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l00000]_ooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-21.5409, -1.09829, \
0.171189, 0.01319}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0238095 0.309017 0.309017 [
[.02381 .29652 -9 -9 ]
[.02381 .29652 9 0 ]
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.7381 .29652 -6 -9 ]
[.7381 .29652 6 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[1.025 .30902 0 -6.71875 ]
[1.025 .30902 32.5625 6.71875 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -20.0625 0 ]
[.5 .63053 20.0625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-20)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-10)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(10)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(20)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10.7188 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.4375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 14.438 moveto
(\\220) show
0.000 0.000 0.000 setrgbcolor
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 9.062 moveto
(\\217) show
83.188 9.062 moveto
(!!) show
88.000 9.062 moveto
(!) show
83.562 14.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
91.562 14.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -81.0625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
75.125 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
81.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
99.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .54972 m
.03279 .54239 L
.04262 .53567 L
.04758 .53287 L
.05288 .53034 L
.05785 .52842 L
.06244 .52706 L
.06508 .52645 L
.06788 .52594 L
.06924 .52575 L
.07069 .52559 L
.07153 .52551 L
.07229 .52545 L
.07301 .52541 L
.07379 .52537 L
.0745 .52535 L
.07515 .52533 L
.07641 .52533 L
.07712 .52534 L
.07789 .52537 L
.07862 .5254 L
.07928 .52544 L
.08049 .52553 L
.08182 .52566 L
.08451 .52603 L
.08713 .52652 L
.08952 .52709 L
.09489 .52874 L
.09987 .53073 L
.10458 .53303 L
.12449 .5467 L
.14291 .56381 L
.16316 .58468 L
.17308 .59445 L
.18218 .60249 L
.19085 .60893 L
.19544 .61173 L
.20034 .61419 L
.20293 .61526 L
.20528 .61609 L
.20768 .61678 L
.20988 .61729 L
.21106 .61751 L
.21236 .6177 L
.21367 .61786 L
.21438 .61792 L
.21505 .61797 L
.21628 .61802 L
.2174 .61803 L
.2187 .61801 L
Mistroke
.21993 .61794 L
.22118 .61783 L
.22253 .61766 L
.22497 .61723 L
.22735 .61666 L
.22954 .61601 L
.23452 .61406 L
.23977 .61136 L
.24855 .6055 L
.25817 .5975 L
.27936 .57647 L
.29865 .55694 L
.30824 .54824 L
.31867 .54007 L
.32844 .53387 L
.33761 .52951 L
.34215 .52791 L
.34703 .52661 L
.34968 .52609 L
.35112 .52587 L
.35246 .52569 L
.3537 .52556 L
.35483 .52547 L
.35608 .52539 L
.35677 .52536 L
.35742 .52534 L
.35864 .52533 L
.35933 .52533 L
.35998 .52535 L
.36128 .5254 L
.36201 .52544 L
.36268 .52548 L
.36387 .52559 L
.36516 .52573 L
.36752 .52608 L
.37027 .52661 L
.37319 .52734 L
.37844 .52904 L
.3878 .5333 L
.39789 .53956 L
.41616 .55461 L
.43579 .57424 L
.45727 .59582 L
.46718 .60431 L
.47262 .60829 L
.47777 .61151 L
.48257 .61397 L
.48509 .61505 L
.48777 .61601 L
.49002 .61669 L
Mistroke
.4925 .61727 L
.49358 .61747 L
.49475 .61766 L
.49584 .6178 L
.49686 .6179 L
.4975 .61795 L
.49819 .61799 L
.4994 .61803 L
.50009 .61803 L
.50081 .61803 L
.50211 .61797 L
.50331 .61788 L
.50443 .61777 L
.50566 .6176 L
.50698 .61737 L
.50994 .6167 L
.51275 .61584 L
.51801 .6137 L
.52301 .61105 L
.52764 .60811 L
.53811 .59996 L
.57739 .5608 L
.5971 .54325 L
.60573 .53712 L
.61516 .53179 L
.61972 .52975 L
.6246 .52799 L
.62729 .52721 L
.62974 .52661 L
.63206 .52615 L
.63452 .52577 L
.6358 .52562 L
.6372 .52549 L
.63848 .52541 L
.63968 .52536 L
.6404 .52534 L
.64108 .52533 L
.64237 .52534 L
.64308 .52536 L
.64375 .52538 L
.64448 .52542 L
.64526 .52547 L
.64657 .52559 L
.648 .52575 L
.65057 .52614 L
.65308 .52664 L
.65539 .5272 L
.66011 .52866 L
.66516 .53067 L
.67426 .53543 L
Mistroke
.68509 .54284 L
.69494 .55102 L
.7157 .57133 L
.73486 .59094 L
.7535 .60701 L
.7629 .61281 L
.76825 .61522 L
.77085 .61613 L
.77326 .61682 L
.77566 .61736 L
.77701 .61759 L
.77822 .61776 L
.77956 .6179 L
.78032 .61796 L
.78101 .61799 L
.78229 .61803 L
.78293 .61803 L
.78364 .61802 L
.78492 .61797 L
.7861 .61788 L
.78675 .61781 L
.78745 .61773 L
.78874 .61754 L
.79121 .61706 L
.7935 .61646 L
.79777 .61499 L
.80248 .61284 L
.81202 .60695 L
.83136 .59017 L
.85221 .56877 L
.87185 .54982 L
.88224 .54142 L
.89334 .53417 L
.89887 .53131 L
.90409 .52911 L
.90878 .52755 L
.9112 .52691 L
.91386 .52632 L
.91635 .5259 L
.91868 .52561 L
.91997 .52549 L
.92115 .52541 L
.9218 .52538 L
.9225 .52535 L
.92379 .52533 L
.925 .52534 L
.92609 .52537 L
.92736 .52543 L
.92855 .52552 L
.92965 .52562 L
Mistroke
.93066 .52574 L
.93295 .52608 L
.93542 .52655 L
.93766 .52708 L
.94271 .52862 L
.94738 .53045 L
.95181 .53255 L
.96171 .53845 L
.97248 .54657 L
.97619 .54972 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00Toooool4o`000003oa0@4?oooooooooo0<kooooo002Eooooo`03o`00
0?oooooooooo0=3ooooo002:ooooo`Ko00001Oooool00ol0003oooooooooo`05ooooo`?o0000b?oo
ool009Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`38ooooo`00UOooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0<Sooooo002Eooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0b?ooool009Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`38ooooo`00Toooool00omEEEGoIVIVo`000007ooooo`;o0000bOooool009gooooo00?o0000
ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000oooooooo
ool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo0_l00039ooooo`00WOooool0
0ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003o
ooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2o`000<Wooooo002M
ooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03
o`000?oooooooooo0<Sooooo002Mooooo`;o0000bOooool009gooooo00?o0000ooooooooool0b?oo
ool009gooooo00?o0000ooooooooool0b?ooool007[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`38ooooo`00N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`38ooooo`00L_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmE
EEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000<Sooooo001jooooo`05o`000?oooooo
ooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0b?ooool007[ooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<
c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0<Sooooo
001jooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0b?ooool007[ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0<Sooooo001jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Co
oooo1?l00006ooooo`;o0000bOooool009gooooo00?o0000ooooooooool0b?ooool009gooooo00?o
0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000oooo
ooooool0b?ooool009gooooo0_l00039ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOoo
ool00ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2o`00
0<Wooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo
002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Moooo
o`;o0000bOooool009gooooo00?o0000ooooooooool0b?ooool008;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0b?ooool008;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0<Sooooo001jooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`38oooo
o`00P_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool3o`00
0<Sooooo0022ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool0b?ooool008;ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0b?ooool008;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0b?ooool0
08;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`38
ooooo`00WOooool2o`000<Wooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`00
0?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`;o0000bOooool0
09gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo
00?o0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo0_l00039
ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00
WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2
o`000<Wooooo002Mooooo`03o`000?oooooooooo0<Sooooo001jooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`38ooooo`00N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0<Sooooo001booooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0<Sooooo001j
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol00038ooooo`00N_ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
b?ooool007[ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`38ooooo`00N_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0b?ooool007[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l00039ooooo`00WOooool00ol0003o
ooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003ooooooooo
o`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2o`000<Wooooo0008ooooo`Go
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03gooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^?oooool00ol0003oooooooooo`10ooooo`Co000000So410@oooooooooooo
k^k^oc8b<_l0003o<S8bonk^kScooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0<ooo
ool000Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
?oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003o
ooooooooo`12ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo0006
o`0000?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@03Cooooo1_l0
0005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400oooooo`03o`00
0?oooooooooo04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@03go
oooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@03?ooooo000:ooooo`03
oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000oooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`00000oooooo`03o`000?oooooooooo04;ooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000003kooooo00?oV9RHob4Q8Oo^k^h00ooo
ool01Ol0003ooooooooooooooooo000003?ooooo000;ooooo`03ogMgMomVIVKooooo00;ooooo00Go
0000ooooooooooooooooo`00000oooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`00000oooooo`;o0000@oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000?oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000<oooool0
00cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03gooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@03oooooo00?o0000ooooooooool0@_oo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100@?ooool01Ol0003ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool0<Oooool000Sooooo00Go0000okZj^_oooooo
V9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003oooooooooo`12ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0looooo`05o`000?nj^[[ooooooiRHV?l@4100
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo0008ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03gooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03oooooo00?o0000ooooooooool0@?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0??ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Oooooo`03oiRHV?oooooooooo017ooooo002Mooooo`;o0000
]?ooool00oo^k^ko0000olc<c00Booooo`00WOooool00ol0003oooooooooo`2Zooooo`03ob4Q8OoM
gMgooooo00Kooooo00?oMgMgo`000?mVIVH04_ooool009gooooo00?o0000ooooooooool0XOooool0
1_l@413o<S8bo`000?l0003o410@ojVYZ@?ooooo00?oV9RHoeEEEOooool01Oooool01?o^k^ko0000
oiRHV?lQ8B45ooooo`07oiRHV?l0003o0000oeEEEOo^k^koIVIVo`000006ooooo`00WOooool00ol0
003oooooooooo`2Qooooo`06o`000?nYZJWooooooooooonj^[[o00001?ooool00ol0003ogMgMoooo
o`04ooooo`05ogMgMomEEEGoooooo`000?oMgMd01?ooool01_l0003oZJVYoooooon7QhOo<S8bofIV
IPOooooo002Mooooo`03o`000?oooooooooo0:;ooooo00Go^[ZjohN7QomVIVKoIVIVoa0@4004oooo
o`;oMgMg1Oooool01Ol0003oc<c<oooooomEEEGoQhN700Cooooo00Ko0000ooooooooooooooooohN7
Qom4A4@7ooooo`000oooooooo`0003Go00002_ooool01_lb<S;o8B4QogMgMomgMgOoQhN7onk^kPCo
oooo00?ok^k^oa0@4?o^k^h00_ooool00olb<S;oEEEEoc8b<P02ooooo`03ojVYZOlQ8B7ooooo00?o
oooo00Ko8B4Qolc<c?oooooooooooiRHV?lb<S87ooooo`002oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03oooool01_l0003o^[Zjooooooo^k^ko
MgMgo`0000Gooooo00OoEEEEoiRHV?oooooooooookZj^_lb<S;o^[Zj00?ooooo00?o0000omgMgOoo
ool00_ooool01onYZJWo8B4QomgMgOo^k^ko<S8boeEEEOnj^[X01_ooool000_ooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo04Kooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`0?ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o00001Ooo
ool00ooMgMgo410@ooooo`07ooooo`03oeEEEOn7QhOooooo00?ooooo00KoV9RHo`000?l0003oV9RH
okZj^_lb<S86ooooo`00WOooool00ol0003oooooooooo`2]ooooo`03oeEEEOnHV9Sooooo00Kooooo
00?oZJVYoc8b<_ooool03oooool009gooooo00?o0000ooooooooool0[Oooool00onj^[[oA4A4oooo
o`06ooooo`03onk^k_l0003ok^k^00oooooo002Mooooo`;o0000^?ooool00om4A4CoV9RHooooo`0>
ooooo`00WOooool00ol0003oooooooooo`2gooooo`03oiRHV?m4A4Cooooo00kooooo002Mooooo`03
o`000?oooooooooo0;Oooooo00?ok^k^o`000?l000002_l00004ooooo`00WOooool00ol0003ooooo
ooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2o`000<Wooooo002Moooo
o`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`00
0?oooooooooo0<Sooooo002Mooooo`;o0000bOooool009gooooo00?o0000ooooooooool0b?ooool0
09gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo
00?o0000ooooooooool0b?ooool009gooooo0_l00039ooooo`00WOooool00ol0003oooooooooo`38
ooooo`00N_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0b?ooool007[ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`38ooooo`00N_ooool01Ol@413ooooooooo
oooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo0<Sooooo001jooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Q
onk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00038ooooo`00N_ooool01Ol0003ooooooooo
oooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool0b?ooool007[ooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`38ooooo`00
N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0b?ooool007[ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000
ooooooooool0b?ooool009gooooo0_l00039ooooo`00WOooool00ol0003oooooooooo`38ooooo`00
WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2
o`000<Wooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<So
oooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002M
ooooo`;o0000bOooool009gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000oooooooo
ool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?oo
ool009gooooo0_l00039ooooo`00WOooool00ol0003oooooooooo`38ooooo`00P_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`38ooooo`00P_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0b?ooool008;ooooo00Go410@oooo
oooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0b?ooool0
08;ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00038
ooooo`00P_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo0<Sooooo0022ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0<Sooooo0022ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0<Sooooo0022
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l00039ooooo`00WOooool0
0ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003o
ooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2o`000<Wooooo002M
ooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03
o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`;o0000bOoo
ool009gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009go
oooo00?o0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool001Gooooo3?l0
001;ooooo`co00009Oooool2o`0002Cooooo2ol0001<ooooo`_o0000@oooool001?ooooo0_l0000<
ooooo`?o0000A_ooool2o`0000cooooo0_l0000Sooooo`03o`000?oooooooooo027ooooo0_l0000;
ooooo`?o0000AOooool4o`0000_ooooo0_l00011ooooo`004_ooool00ol0003oooooooooo`0?oooo
o`;o0000@Oooool3o`00013ooooo0ol000000olb<S;ok^k^ooooo`04ooooo`;o8B4Q1_ooool00ol0
003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0O
ooooo`;o00004?ooool00ol0003oooooooooo`10ooooo`;o00004Oooool2o`0003oooooo000@oooo
o`;o00005?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRH
V?l0003oV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool07Oooool2o`0001?ooooo0_l0000oooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool0??ooool000oooooo00?o0000ooooooooool05Oooool2o`00
03cooooo00?o0000ooooooooool04_ooool00ol@413oooooooooo`02o`0000gooooo00?oZJVYoeEE
EOooool02?ooool00ol0003oooooooooo`03ooooo`?o00007?ooool00ol0003oooooooooo`0Eoooo
o`;o0000??ooool00ol0003oooooooooo`0Eooooo`;o0000??ooool000gooooo0_l0000Jooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool04oooool01?l0003oooooooooooooool2o`00
00gooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
01[ooooo0_l0000Jooooo`;o0000>Oooool00ol0003oooooooooo`0Hooooo`;o0000>_ooool000co
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01Co
oooo00Oo0000ooooooooooooooooo`000?oooooo000000cooooo00?oEEEEolc<c?ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0gooooo`002oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo03?ooooo0_l0000G
ooooo`05oa0@4?ooooooooooooooool@41000_ooool00ol0003oooooooooo`09ooooo`03ojVYZOmg
MgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo03Kooooo000/ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool05oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?o0000ooooooooool01Oooool01Ol@413ooooooooo
oooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`1Gooooo`00;Ooo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Sooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP04ooooo`03o`000?oooooooooo00Cooooo1Ol00004ooooo`Co00001_ooool2o`0001Oooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo05Sooooo
000^ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo01Cooooo0_l0000Uooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool0FOooool002oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0F_ooool002oooooo00?o0000oooo
ooooool0:_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool0Foooool0033ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo02Oooooo0_l0001Nooooo`00<Oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool04_ooool2o`00017ooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05kooooo000booooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool0;Oooool2o`0001;ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0Gooo
ool003?ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool0H?ooool003Cooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0HOooool003Go
oooo0_l0000Pooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool03Oooool2o`0000go
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo06;o
oooo000gooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo06?ooooo000hooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0>?ooool2o`0001[ooooo00?o0000ooooooooool0I?ooool003Wooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool0IOooool003[ooooo00?o0000ooooooooool05Oooool2o`0003gooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03gooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`1Vooooo`00>oooool2o`0001Cooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`08ooooo`;o00002?ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool0Ioooool003gooooo00?o0000ooooooooool0
3oooool2o`0004;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo047ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Xooooo`00?_oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04;ooooo1?l000000ol@413ooooooooo
o`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0@oooool2o`0000kooooo0_l0
001[ooooo`00?oooool2o`0000_ooooo0_l00017ooooo`;o00001_ooool00ol0003oooooooooo`03
ooooo`;o0000B?ooool2o`0000[ooooo0_l0001]ooooo`00@Oooool2o`0000Oooooo0_l00019oooo
o`03o`000?oooooo000000;o00000oooool01?l0003oooooooooooooool2o`0004cooooo0_l00006
ooooo`;o0000Koooool004?ooooo1ol0001;ooooo`03o`000?oooooooooo00;ooooo1ol0001@oooo
o`Ko0000LOooool009Gooooo00?o0000ooooooooool0d?ooool009Gooooo00?o0000ooooooooool0
d?ooool009Gooooo00?o0000ooooooooool0d?ooool009?ooooo00?oEEEEofIVI_l00000d_ooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool008Kooooo0_l00002
ooooo`05o`000?ooooooooooo`000?l@41003oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05oiRHV?l@413o0000oc8b<_o<c<`0]Oooool008Oooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`06ooooo`Ko00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S80]Oooool008Oooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0>ooooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`2cooooo`00Qoooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00Kooooo1_l00002ooooo`05o`000?ooooooooooooooool000003_ooool00onYZJWo410@
ooooo`2dooooo`00Qoooool01ol0003oc<c<olc<c?l0003oZJVYomgMgOlQ8B404?ooool01Ol0003o
oooooooooooooooo000000gooooo00?o410@o`000?nj^[X0]Oooool008Kooooo00So410@o`000?lQ
8B7o0000ogMgMol@413o0000ojVYZA3ooooo00Go410@oooooooooooooooooa0@400>ooooo`03okZj
^_lQ8B7ooooo0;Cooooo002Nooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413oV9RH
oooooonj^[[o00000;Gooooo002Nooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo
410@o`000?l@413oZJVY0;Gooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-21.5409, -1.09829, \
0.171189, 0.01319}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0238095 0.309017 0.309017 [
[.02381 .29652 -9 -9 ]
[.02381 .29652 9 0 ]
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.7381 .29652 -6 -9 ]
[.7381 .29652 6 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[1.025 .30902 0 -6.71875 ]
[1.025 .30902 32.5625 6.71875 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -20.0625 0 ]
[.5 .63053 20.0625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-20)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-10)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(10)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(20)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10.7188 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.4375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 14.438 moveto
(\\220) show
0.000 0.000 0.000 setrgbcolor
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 9.062 moveto
(\\217) show
83.188 9.062 moveto
(!!) show
88.000 9.062 moveto
(!) show
83.562 14.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
91.562 14.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -81.0625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
75.125 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
81.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
99.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .46697 m
.02605 .46614 L
.02846 .46538 L
.03053 .46483 L
.03279 .46434 L
.03416 .46409 L
.03543 .46391 L
.03662 .46377 L
.03793 .46365 L
.03911 .46358 L
.04021 .46354 L
.04137 .46353 L
.04262 .46355 L
.04393 .46361 L
.04516 .4637 L
.0465 .46384 L
.04793 .46403 L
.05057 .46452 L
.05297 .46509 L
.05785 .46666 L
.06244 .46863 L
.07299 .47496 L
.08269 .48297 L
.10458 .50831 L
.14407 .5702 L
.15427 .58576 L
.16393 .5986 L
.1726 .60783 L
.1775 .61186 L
.17984 .61345 L
.18204 .61473 L
.18438 .61588 L
.18654 .61672 L
.18892 .61741 L
.19018 .61767 L
.1915 .61787 L
.1927 .61799 L
.19399 .61803 L
.1952 .61801 L
.1963 .61793 L
.19759 .61777 L
.19833 .61764 L
.199 .6175 L
.20155 .6168 L
.20405 .61583 L
.20639 .61467 L
.21171 .61119 L
.21689 .60673 L
.22246 .60086 L
.24364 .57116 L
Mistroke
.26374 .53843 L
.28381 .5082 L
.30199 .48651 L
.31214 .47736 L
.3217 .47084 L
.32695 .46812 L
.33178 .46618 L
.33453 .46531 L
.33709 .46466 L
.33976 .46413 L
.34117 .46392 L
.34268 .46374 L
.34391 .46364 L
.3446 .4636 L
.34525 .46356 L
.34657 .46353 L
.34731 .46353 L
.34798 .46353 L
.34913 .46357 L
.35037 .46365 L
.35167 .46377 L
.35288 .46391 L
.35569 .46437 L
.35824 .46494 L
.36396 .46676 L
.36894 .46895 L
.37433 .47195 L
.3841 .47906 L
.39359 .48796 L
.40401 .49992 L
.42507 .52991 L
.44619 .56421 L
.46546 .59316 L
.47501 .60448 L
.48005 .60926 L
.48541 .61328 L
.49008 .61582 L
.49136 .61635 L
.49274 .61684 L
.49393 .6172 L
.49524 .61752 L
.49643 .61775 L
.49755 .6179 L
.49872 .618 L
.49998 .61803 L
.50115 .618 L
.50226 .61792 L
.50326 .61779 L
.50434 .61761 L
.50556 .61733 L
Mistroke
.50669 .61702 L
.50922 .61612 L
.51156 .61503 L
.51378 .61378 L
.51876 .61024 L
.52419 .6053 L
.5351 .59242 L
.54522 .57781 L
.58437 .51564 L
.59467 .50159 L
.6058 .48861 L
.61542 .47946 L
.62051 .47544 L
.62597 .47177 L
.63137 .4688 L
.6363 .46666 L
.63867 .46583 L
.64124 .46507 L
.64366 .4645 L
.64593 .46408 L
.64724 .46389 L
.64845 .46375 L
.64979 .46364 L
.6505 .46359 L
.65124 .46356 L
.65191 .46354 L
.65263 .46353 L
.65393 .46354 L
.65472 .46356 L
.65547 .4636 L
.65615 .46364 L
.65687 .4637 L
.65809 .46383 L
.65943 .46401 L
.66214 .46449 L
.66465 .46509 L
.667 .46578 L
.67198 .46765 L
.67741 .47034 L
.6873 .47693 L
.69692 .48542 L
.70584 .49506 L
.74504 .55277 L
.76507 .58448 L
.7756 .59858 L
.78134 .60498 L
.7867 .60993 L
.79152 .61344 L
.79399 .61488 L
.79668 .61614 L
Mistroke
.79821 .61672 L
.79962 .61716 L
.80098 .6175 L
.80167 .61764 L
.80241 .61777 L
.80369 .61793 L
.80489 .61801 L
.80562 .61803 L
.80631 .61803 L
.80762 .61796 L
.80883 .61783 L
.80992 .61766 L
.81119 .61739 L
.81238 .61707 L
.81451 .61634 L
.81681 .61533 L
.82203 .6122 L
.82684 .60834 L
.83656 .59801 L
.84565 .58587 L
.86631 .55332 L
.88494 .52348 L
.90521 .49581 L
.91623 .484 L
.92644 .47538 L
.93619 .46931 L
.94112 .46706 L
.94371 .4661 L
.94656 .46522 L
.95018 .46436 L
.95215 .46402 L
.9531 .46389 L
.95399 .46378 L
.95482 .4637 L
.95572 .46363 L
.95654 .46358 L
.95729 .46355 L
.95811 .46353 L
.959 .46353 L
.95994 .46354 L
.96081 .46357 L
.96176 .46363 L
.9628 .46371 L
.96469 .46392 L
.96652 .46421 L
.96823 .46454 L
.97208 .46554 L
.97619 .46697 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00Toooool4o`000003oa0@4?oooooooooo0<kooooo002Eooooo`03o`00
0?oooooooooo0=3ooooo002:ooooo`Ko00001Oooool00ol0003oooooooooo`05ooooo`?o0000b?oo
ool009Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`38ooooo`00UOooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0<Sooooo002Eooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0b?ooool009Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`38ooooo`00Toooool00omEEEGoIVIVo`000007ooooo`;o0000bOooool009gooooo00?o0000
ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000oooooooo
ool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo0_l00039ooooo`00WOooool0
0ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003o
ooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2o`000<Wooooo002M
ooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03
o`000?oooooooooo0<Sooooo002Mooooo`;o0000bOooool009gooooo00?o0000ooooooooool0b?oo
ool009gooooo00?o0000ooooooooool0b?ooool007[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`38ooooo`00N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`38ooooo`00L_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmE
EEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000<Sooooo001jooooo`05o`000?oooooo
ooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0b?ooool007[ooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<
c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0<Sooooo
001jooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0b?ooool007[ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0<Sooooo001jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Co
oooo1?l00006ooooo`;o0000bOooool009gooooo00?o0000ooooooooool0b?ooool009gooooo00?o
0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000oooo
ooooool0b?ooool009gooooo0_l00039ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOoo
ool00ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2o`00
0<Wooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo
002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Moooo
o`;o0000bOooool009gooooo00?o0000ooooooooool0b?ooool008;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0b?ooool008;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0<Sooooo001jooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`38oooo
o`00P_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool3o`00
0<Sooooo0022ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool0b?ooool008;ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0b?ooool008;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0b?ooool0
08;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`38
ooooo`00WOooool2o`000<Wooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`00
0?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`;o0000bOooool0
09gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo
00?o0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo0_l00039
ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00
WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2
o`000<Wooooo002Mooooo`03o`000?oooooooooo0<Sooooo001jooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`38ooooo`00N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0<Sooooo001booooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0<Sooooo001j
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol00038ooooo`00N_ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
b?ooool007[ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`38ooooo`00N_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0b?ooool007[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l00039ooooo`00WOooool00ol0003o
ooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003ooooooooo
o`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2o`000<Wooooo0008ooooo`Go
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03gooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^?oooool00ol0003oooooooooo`10ooooo`Co000000So410@oooooooooooo
k^k^oc8b<_l0003o<S8bonk^kScooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0<ooo
ool000Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
?oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003o
ooooooooo`12ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo0006
o`0000?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@03Cooooo1_l0
0005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400oooooo`03o`00
0?oooooooooo04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@03go
oooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@03?ooooo000:ooooo`03
oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000oooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`00000oooooo`03o`000?oooooooooo04;ooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000003kooooo00?oV9RHob4Q8Oo^k^h00ooo
ool01Ol0003ooooooooooooooooo000003?ooooo000;ooooo`03ogMgMomVIVKooooo00;ooooo00Go
0000ooooooooooooooooo`00000oooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`00000oooooo`;o0000@oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000?oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000<oooool0
00cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03gooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@03oooooo00?o0000ooooooooool0@_oo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100@?ooool01Ol0003ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool0<Oooool000Sooooo00Go0000okZj^_oooooo
V9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003oooooooooo`12ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0looooo`05o`000?nj^[[ooooooiRHV?l@4100
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo0008ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03gooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03oooooo00?o0000ooooooooool0@?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0??ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Oooooo`03oiRHV?oooooooooo017ooooo002Mooooo`;o0000
]?ooool00oo^k^ko0000olc<c00Booooo`00WOooool00ol0003oooooooooo`2Zooooo`03ob4Q8OoM
gMgooooo00Kooooo00?oMgMgo`000?mVIVH04_ooool009gooooo00?o0000ooooooooool0XOooool0
1_l@413o<S8bo`000?l0003o410@ojVYZ@?ooooo00?oV9RHoeEEEOooool01Oooool01?o^k^ko0000
oiRHV?lQ8B45ooooo`07oiRHV?l0003o0000oeEEEOo^k^koIVIVo`000006ooooo`00WOooool00ol0
003oooooooooo`2Qooooo`06o`000?nYZJWooooooooooonj^[[o00001?ooool00ol0003ogMgMoooo
o`04ooooo`05ogMgMomEEEGoooooo`000?oMgMd01?ooool01_l0003oZJVYoooooon7QhOo<S8bofIV
IPOooooo002Mooooo`03o`000?oooooooooo0:;ooooo00Go^[ZjohN7QomVIVKoIVIVoa0@4004oooo
o`;oMgMg1Oooool01Ol0003oc<c<oooooomEEEGoQhN700Cooooo00Ko0000ooooooooooooooooohN7
Qom4A4@7ooooo`000oooooooo`0003Go00002_ooool01_lb<S;o8B4QogMgMomgMgOoQhN7onk^kPCo
oooo00?ok^k^oa0@4?o^k^h00_ooool00olb<S;oEEEEoc8b<P02ooooo`03ojVYZOlQ8B7ooooo00?o
oooo00Ko8B4Qolc<c?oooooooooooiRHV?lb<S87ooooo`002oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03oooool01_l0003o^[Zjooooooo^k^ko
MgMgo`0000Gooooo00OoEEEEoiRHV?oooooooooookZj^_lb<S;o^[Zj00?ooooo00?o0000omgMgOoo
ool00_ooool01onYZJWo8B4QomgMgOo^k^ko<S8boeEEEOnj^[X01_ooool000_ooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo04Kooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`0?ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o00001Ooo
ool00ooMgMgo410@ooooo`07ooooo`03oeEEEOn7QhOooooo00?ooooo00KoV9RHo`000?l0003oV9RH
okZj^_lb<S86ooooo`00WOooool00ol0003oooooooooo`2]ooooo`03oeEEEOnHV9Sooooo00Kooooo
00?oZJVYoc8b<_ooool03oooool009gooooo00?o0000ooooooooool0[Oooool00onj^[[oA4A4oooo
o`06ooooo`03onk^k_l0003ok^k^00oooooo002Mooooo`;o0000^?ooool00om4A4CoV9RHooooo`0>
ooooo`00WOooool00ol0003oooooooooo`2gooooo`03oiRHV?m4A4Cooooo00kooooo002Mooooo`03
o`000?oooooooooo0;Oooooo00?ok^k^o`000?l000002_l00004ooooo`00WOooool00ol0003ooooo
ooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2o`000<Wooooo002Moooo
o`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`00
0?oooooooooo0<Sooooo002Mooooo`;o0000bOooool009gooooo00?o0000ooooooooool0b?ooool0
09gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo
00?o0000ooooooooool0b?ooool009gooooo0_l00039ooooo`00WOooool00ol0003oooooooooo`38
ooooo`00N_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0b?ooool007[ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`38ooooo`00N_ooool01Ol@413ooooooooo
oooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo0<Sooooo001jooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Q
onk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00038ooooo`00N_ooool01Ol0003ooooooooo
oooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool0b?ooool007[ooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`38ooooo`00
N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0b?ooool007[ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000
ooooooooool0b?ooool009gooooo0_l00039ooooo`00WOooool00ol0003oooooooooo`38ooooo`00
WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2
o`000<Wooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<So
oooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002M
ooooo`;o0000bOooool009gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000oooooooo
ool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?oo
ool009gooooo0_l00039ooooo`00WOooool00ol0003oooooooooo`38ooooo`00P_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`38ooooo`00P_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0b?ooool008;ooooo00Go410@oooo
oooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0b?ooool0
00_ooooo2_l0001Dooooo`[o00003oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMg
oc8b<_ooool01?ooool3o`0002Oooooo2ol0001Cooooo`[o0000>Oooool000_ooooo00?o0000oooo
ooooool01oooool4o`0004kooooo0_l0000:ooooo`?o00003?ooool01Ol0003ooooooooooooooooo
000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo02Cooooo1?l0
000:ooooo`03o`000?oooooooooo04gooooo0ol0000:ooooo`03o`000?oooooooooo03Kooooo000I
ooooo`03o`000?oooooooooo04Wooooo0_l0000?ooooo`;o00002_ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo00gooooo0_l0001<ooooo`03o`000?oooooooooo04Cooooo000Jooooo`03o`000?oooooo
oooo04Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`07ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo027ooooo0_l0
000Booooo`03o`000?oooooooooo04Oooooo0_l00017ooooo`006oooool00ol0003oooooooooo`15
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l00006ooooo`;o00008Oooool00ol0003oooooooooo`0Cooooo`;o0000A_oo
ool00ol0003oooooooooo`17ooooo`007?ooool00ol0003oooooooooo`13ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`18ooooo`007Oooool00ol0
003oooooooooo`11ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0@?ooool00ol0
003oooooooooo`19ooooo`007_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`1:ooooo`007oooool00ol0003ooooo
ooooo`0mooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0??ooool00ol0003ooooo
ooooo`1;ooooo`008?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool07Oooool2o`0001gooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0jooooo`03o`000?oooooooooo04cooooo000Qooooo`03o`000?oooooooooo03Wooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo04cooooo000Roooo
o`03o`000?oooooooooo03Oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo04gooooo000Sooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo04kooooo000Tooooo`03o`00
0?oooooooooo03?ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo04kooooo000Tooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0Iooooo`;o00006Oooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool0Coooool002Gooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0D?ooool0
02Kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool0D?ooool002Kooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0DOooool002Oooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool0D_ooool002Oooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`0[ooooo`03o`000?oooooooooo01Gooooo0_l0000Fooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`1Booooo`00:?ooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1C
ooooo`00:Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q00?o0000ooooooooool00oooool00ol0003ok^k^ooooo`04
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1Dooooo`00:Oooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q00?oooooo`000?ooool00oooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool0E?ooool002[ooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`0Sooooo`05oa0@4?ooooooooooooooool@41002Oooool01_l0003ooooooooo
ooooooooZJVYoeEEE@Wooooo00?o0000ooooooooool00oooool3o`0001?ooooo00?o0000oooooooo
ool0;oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo05Gooooo000[ooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool08oooool01Ol0003ooooooooooooooooo000000Wo
oooo00?o0000ooooooooool00_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0E_ooool002_ooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0Tooooo`05o`000?ooooooooooooooool000002_ooool01_l0003oooooooooooooooooEEEE
olc<c0Cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05Kooooo000/
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool09Oooool01Ol@413ooooooooooooo
oooo410@00[ooooo00Ko0000ooooooooooooooooojVYZOmgMgL4ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool0Eoooool002gooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`0Uooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003ooooooooooooooooo<S8b
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
03Gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1Hooooo`00;Oooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo02Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`Go00001?ooool4o`0000Kooooo0_l0000Aooooo`03o`000?oooooooooo03Gooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`1Hooooo`00;_ooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1Iooooo`00
;_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`1Jooooo`00;oooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo03[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Jooooo`00<?ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`1Kooooo`00<?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
03gooooo00?o0000ooooooooool03?ooool2o`0000kooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo05_ooooo000aooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05co
oooo000booooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo05gooooo000booooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool0@Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0?oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo05gooooo000c
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0:
ooooo`;o00002oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool0G_ooool003?ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`13oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`12oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0G_ooool003Cooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0Goooool003Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`15ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`16ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0H?ooool003Kooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0HOoo
ool003Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`19ooooo`03o`000?oooooo
oooo00Kooooo0_l00006ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`1Rooooo`00=oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
04_ooooo0_l00006ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0C?ooool2o`00
00gooooo00?o0000ooooooooool0Hoooool003Sooooo0_l0000;ooooo`;o0000C?ooool5o`0000Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0I?ooool003[ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`1>ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool00_ooool2o`00057ooooo
00?o0000ooooooooool01oooool2o`0006Oooooo000kooooo`;o00001Oooool2o`00057ooooo00?o
0000ooooooooool00ol00002ooooo`03o`000?oooooooooo00;o0000E?ooool3o`0000Cooooo0_l0
001Yooooo`00?Oooool5o`0005?ooooo00?o0000ooooooooool00oooool5o`0005Sooooo1_l0001Z
ooooo`00UOooool00ol0003oooooooooo`3@ooooo`00UOooool00ol0003oooooooooo`3@ooooo`00
UOooool00ol0003oooooooooo`3@ooooo`00Toooool00omEEEGoIVIVo`00003Booooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Q_ooool2o`0000;ooooo00Go
0000oooooooooooo0000oa0@400?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Go
oooo00GoA4A4o`000?l0003o<S8bomgMg@2dooooo`00Qoooool01?l0003oooooooooool00002oooo
o`03o`000?oooooooooo00Kooooo1_l00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Sooooo00?oMgMgoc8b<_ooool0/oooool008Oooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0>ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`2booooo`00Qoooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Kooooo1_l0
0002ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`2cooooo`00Qooo
ool01ol0003oc<c<olc<c?l0003oZJVYomgMgOlQ8B404?ooool01Ol0003ooooooooooooooooo0000
00cooooo00Go0000ob4Q8Ol0003o<S8bolc<c02dooooo`00Q_ooool02?l@413o0000ob4Q8Ol0003o
MgMgoa0@4?l0003oZJVY4?ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooooooo
ool0]_ooool009kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo0;Ko
oooo002Nooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`000;Gooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-21.5409, -1.09829, \
0.171189, 0.01319}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0238095 0.309017 0.309017 [
[.02381 .29652 -9 -9 ]
[.02381 .29652 9 0 ]
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.7381 .29652 -6 -9 ]
[.7381 .29652 6 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[1.025 .30902 0 -6.71875 ]
[1.025 .30902 32.5625 6.71875 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -20.0625 0 ]
[.5 .63053 20.0625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-20)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-10)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(10)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(20)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10.7188 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.4375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 14.438 moveto
(\\220) show
0.000 0.000 0.000 setrgbcolor
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 9.062 moveto
(\\217) show
83.188 9.062 moveto
(!!) show
88.000 9.062 moveto
(!) show
83.562 14.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
91.562 14.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -81.0625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
75.125 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
81.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
99.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .41536 m
.03279 .42296 L
.04262 .4334 L
.06244 .4614 L
.10458 .546 L
.11548 .56893 L
.12579 .5883 L
.13504 .60245 L
.14027 .60866 L
.14259 .61095 L
.14509 .61308 L
.14752 .61479 L
.14974 .61605 L
.15081 .61655 L
.15197 .61701 L
.15307 .61737 L
.1541 .61763 L
.1554 .61787 L
.15659 .618 L
.15786 .61803 L
.15858 .61801 L
.15924 .61795 L
.16035 .6178 L
.16156 .61755 L
.16283 .61718 L
.16402 .61675 L
.16662 .6155 L
.16908 .61393 L
.1737 .61002 L
.17867 .60449 L
.18408 .59706 L
.20386 .56065 L
.22486 .51531 L
.24456 .47585 L
.26261 .44646 L
.28196 .4235 L
.29212 .4149 L
.29773 .41112 L
.30282 .40826 L
.3074 .40614 L
.31236 .40432 L
.31509 .40353 L
.31761 .40293 L
.32001 .40246 L
.32134 .40226 L
.32256 .4021 L
.3236 .40198 L
.32474 .40188 L
.32594 .4018 L
.32708 .40175 L
Mistroke
.32814 .40173 L
.32927 .40172 L
.33034 .40174 L
.33131 .40178 L
.33255 .40185 L
.33369 .40195 L
.33494 .40208 L
.33626 .40225 L
.33849 .40261 L
.34093 .40312 L
.34618 .40461 L
.35116 .40652 L
.36047 .41146 L
.37051 .41882 L
.3814 .42936 L
.40122 .45566 L
.42224 .49338 L
.46004 .57333 L
.46949 .59059 L
.47942 .60503 L
.48463 .61067 L
.48738 .61304 L
.49032 .61508 L
.49171 .61586 L
.49303 .6165 L
.49431 .61701 L
.49549 .61739 L
.49661 .61767 L
.4978 .61788 L
.49899 .618 L
.50029 .61803 L
.50159 .61795 L
.5028 .61779 L
.50412 .61749 L
.50552 .61707 L
.50788 .61607 L
.51048 .61457 L
.51528 .61075 L
.51978 .60599 L
.52984 .5917 L
.54069 .5719 L
.58179 .48545 L
.6023 .45032 L
.61229 .43671 L
.62139 .4264 L
.63021 .41822 L
.63979 .41129 L
.64505 .40832 L
.6499 .40607 L
.65455 .40437 L
Mistroke
.65946 .40303 L
.66199 .40253 L
.66438 .40216 L
.66654 .40193 L
.66775 .40183 L
.66888 .40177 L
.66952 .40175 L
.67021 .40173 L
.67146 .40172 L
.67267 .40174 L
.67379 .40179 L
.675 .40186 L
.67633 .40198 L
.67772 .40213 L
.67901 .40231 L
.68139 .40272 L
.68364 .40321 L
.68785 .40439 L
.69239 .40605 L
.69732 .40833 L
.70673 .41406 L
.71711 .42261 L
.72795 .43415 L
.73812 .4475 L
.77683 .51894 L
.79649 .56137 L
.80689 .5819 L
.8126 .59185 L
.81799 .60006 L
.82315 .60667 L
.82587 .6096 L
.82875 .61225 L
.83118 .61411 L
.83384 .61575 L
.83501 .61633 L
.83626 .61686 L
.83736 .61725 L
.83853 .61757 L
.8398 .61783 L
.84098 .61797 L
.8417 .61802 L
.84238 .61803 L
.84365 .61798 L
.84487 .61783 L
.84599 .61761 L
.84722 .61728 L
.84851 .61683 L
.85077 .61579 L
.85286 .61455 L
.85763 .61075 L
Mistroke
.86266 .60535 L
.86812 .59803 L
.87804 .58147 L
.89661 .54341 L
.91605 .50164 L
.93747 .46155 L
.9471 .44676 L
.95746 .43331 L
.97619 .41536 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00Toooool4o`000003oa0@4?oooooooooo0<kooooo002Eooooo`03o`00
0?oooooooooo0=3ooooo002:ooooo`Ko00001Oooool00ol0003oooooooooo`05ooooo`?o0000b?oo
ool009Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`38ooooo`00UOooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0<Sooooo002Eooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0b?ooool009Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`38ooooo`00Toooool00omEEEGoIVIVo`000007ooooo`;o0000bOooool009gooooo00?o0000
ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000oooooooo
ool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo0_l00039ooooo`00WOooool0
0ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003o
ooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2o`000<Wooooo002M
ooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03
o`000?oooooooooo0<Sooooo002Mooooo`;o0000bOooool009gooooo00?o0000ooooooooool0b?oo
ool009gooooo00?o0000ooooooooool0b?ooool007[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`38ooooo`00N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`38ooooo`00L_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmE
EEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000<Sooooo001jooooo`05o`000?oooooo
ooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0b?ooool007[ooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<
c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0<Sooooo
001jooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0b?ooool007[ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0<Sooooo001jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Co
oooo1?l00006ooooo`;o0000bOooool009gooooo00?o0000ooooooooool0b?ooool009gooooo00?o
0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000oooo
ooooool0b?ooool009gooooo0_l00039ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOoo
ool00ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2o`00
0<Wooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo
002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Moooo
o`;o0000bOooool009gooooo00?o0000ooooooooool0b?ooool008;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0b?ooool008;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0<Sooooo001jooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`38oooo
o`00P_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool3o`00
0<Sooooo0022ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool0b?ooool008;ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0b?ooool008;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0b?ooool0
08;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`38
ooooo`00WOooool2o`000<Wooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`00
0?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`;o0000bOooool0
09gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo
00?o0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo0_l00039
ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00
WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2
o`000<Wooooo002Mooooo`03o`000?oooooooooo0<Sooooo001jooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`38ooooo`00N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0<Sooooo001booooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0<Sooooo001j
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol00038ooooo`00N_ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
b?ooool007[ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`38ooooo`00N_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0b?ooool007[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l00039ooooo`00WOooool00ol0003o
ooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003ooooooooo
o`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2o`000<Wooooo0008ooooo`Go
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03gooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^?oooool00ol0003oooooooooo`10ooooo`Co000000So410@oooooooooooo
k^k^oc8b<_l0003o<S8bonk^kScooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0<ooo
ool000Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
?oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003o
ooooooooo`12ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo0006
o`0000?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@03Cooooo1_l0
0005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400oooooo`03o`00
0?oooooooooo04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@03go
oooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@03?ooooo000:ooooo`03
oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000oooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`00000oooooo`03o`000?oooooooooo04;ooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000003kooooo00?oV9RHob4Q8Oo^k^h00ooo
ool01Ol0003ooooooooooooooooo000003?ooooo000;ooooo`03ogMgMomVIVKooooo00;ooooo00Go
0000ooooooooooooooooo`00000oooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`00000oooooo`;o0000@oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000?oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000<oooool0
00cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03gooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@03oooooo00?o0000ooooooooool0@_oo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100@?ooool01Ol0003ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool0<Oooool000Sooooo00Go0000okZj^_oooooo
V9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003oooooooooo`12ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0looooo`05o`000?nj^[[ooooooiRHV?l@4100
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo0008ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03gooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03oooooo00?o0000ooooooooool0@?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0??ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Oooooo`03oiRHV?oooooooooo017ooooo002Mooooo`;o0000
]?ooool00oo^k^ko0000olc<c00Booooo`00WOooool00ol0003oooooooooo`2Zooooo`03ob4Q8OoM
gMgooooo00Kooooo00?oMgMgo`000?mVIVH04_ooool009gooooo00?o0000ooooooooool0XOooool0
1_l@413o<S8bo`000?l0003o410@ojVYZ@?ooooo00?oV9RHoeEEEOooool01Oooool01?o^k^ko0000
oiRHV?lQ8B45ooooo`07oiRHV?l0003o0000oeEEEOo^k^koIVIVo`000006ooooo`00WOooool00ol0
003oooooooooo`2Qooooo`06o`000?nYZJWooooooooooonj^[[o00001?ooool00ol0003ogMgMoooo
o`04ooooo`05ogMgMomEEEGoooooo`000?oMgMd01?ooool01_l0003oZJVYoooooon7QhOo<S8bofIV
IPOooooo002Mooooo`03o`000?oooooooooo0:;ooooo00Go^[ZjohN7QomVIVKoIVIVoa0@4004oooo
o`;oMgMg1Oooool01Ol0003oc<c<oooooomEEEGoQhN700Cooooo00Ko0000ooooooooooooooooohN7
Qom4A4@7ooooo`000oooooooo`0003Go00002_ooool01_lb<S;o8B4QogMgMomgMgOoQhN7onk^kPCo
oooo00?ok^k^oa0@4?o^k^h00_ooool00olb<S;oEEEEoc8b<P02ooooo`03ojVYZOlQ8B7ooooo00?o
oooo00Ko8B4Qolc<c?oooooooooooiRHV?lb<S87ooooo`002oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03oooool01_l0003o^[Zjooooooo^k^ko
MgMgo`0000Gooooo00OoEEEEoiRHV?oooooooooookZj^_lb<S;o^[Zj00?ooooo00?o0000omgMgOoo
ool00_ooool01onYZJWo8B4QomgMgOo^k^ko<S8boeEEEOnj^[X01_ooool000_ooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo04Kooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`0?ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o00001Ooo
ool00ooMgMgo410@ooooo`07ooooo`03oeEEEOn7QhOooooo00?ooooo00KoV9RHo`000?l0003oV9RH
okZj^_lb<S86ooooo`00WOooool00ol0003oooooooooo`2]ooooo`03oeEEEOnHV9Sooooo00Kooooo
00?oZJVYoc8b<_ooool03oooool009gooooo00?o0000ooooooooool0[Oooool00onj^[[oA4A4oooo
o`06ooooo`03onk^k_l0003ok^k^00oooooo002Mooooo`;o0000^?ooool00om4A4CoV9RHooooo`0>
ooooo`00WOooool00ol0003oooooooooo`2gooooo`03oiRHV?m4A4Cooooo00kooooo002Mooooo`03
o`000?oooooooooo0;Oooooo00?ok^k^o`000?l000002_l00004ooooo`00WOooool00ol0003ooooo
ooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2o`000<Wooooo002Moooo
o`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`00
0?oooooooooo0<Sooooo002Mooooo`;o0000bOooool009gooooo00?o0000ooooooooool0b?ooool0
09gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo
00?o0000ooooooooool0b?ooool009gooooo0_l00039ooooo`00WOooool00ol0003oooooooooo`38
ooooo`00N_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0b?ooool007[ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`38ooooo`00N_ooool01Ol@413ooooooooo
oooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo0<Sooooo001jooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Q
onk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00038ooooo`00N_ooool01Ol0003ooooooooo
oooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool0b?ooool007[ooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`38ooooo`00
N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0b?ooool007[ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000
ooooooooool0b?ooool006?ooooo2ol0000_ooooo`;o0000;Oooool<o`00093ooooo001Qooooo`;o
00002oooool3o`0002cooooo00?o0000ooooooooool0:_ooool2o`0000cooooo00?o0000oooooooo
ool0SOooool0063ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool03Oooool3o`0008cooooo001Nooooo`;o00004_oo
ool2o`0002Wooooo00?o0000ooooooooool09oooool2o`0001?ooooo00?o0000ooooooooool0ROoo
ool000_ooooo0_l0001?ooooo`;o00005_ooool00ol0003oooooooooo`0Vooooo`;o00009oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04kooooo0_l0000hooooo`003Oooool00ol0
003oooooooooo`1;ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0Tooooo`;o00006?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo
03Sooooo000>ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`1:ooooo`03o`000?oooooooooo03Wooooo000?ooooo`03o`000?oooooooooo04Sooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo03[ooooo
000@ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`16ooooo`03o`000?oooooooooo03_ooooo000Aooooo`03o`000?oooooooooo04Cooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0Rooooo`;o00008Oooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0??ooool0017ooooo00?o0000oooo
ooooool0@oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo04?ooooo00?o0000oooo
ooooool0??ooool001;ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo04;ooooo00?o0000ooooooooool0?Oooool001?ooooo00?o0000ooooooooool0
?oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0
?_ooool001?ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo03kooooo00?o0000ooooooooool0?oooool001Cooooo00?o0000ooooooooool0?Oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo0_l0000Nooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0oooooo`005Oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`10ooooo`005Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02Wo
oooo00Wo0000ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo047ooooo000Fooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool0:Oooool02Ol0003oooooooooooooooooMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo
047ooooo000Gooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0:oooool01?l0003o
ooooooooool@4103ooooo`03oa0@4?oooooooooo00kooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0>?ooool00ol0
003oooooooooo`12ooooo`005oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02co
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0=ooooo`03ogMgMolb<S;ooooo
00Cooooo0ol0000Jooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0>?ooool00ol0
003oooooooooo`12ooooo`006?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02go
oooo00?o0000ooooool000000oooool00ol0003oooooooooo`0:ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`13ooooo`006?ooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo02oooooo00?o0000oa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool0@oooool001Wooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`0`ooooo`06o`000?mgMgOoV9RHoooooonHV9SoMgMg3?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo04Cooooo000Iooooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool0<Oooool01Ol0003o<S8bo`000?lb<S;ok^k^00cooooo1?l00006oooo
o`;o00006?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo03;ooooo00?o0000oooo
ooooool0AOooool001[ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool0AOooool001[ooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
A_ooool001_ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool0A_ooool001_ooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`0eooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0eooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0Aoooool0
01cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo
01Gooooo0_l0000Fooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`18ooooo`007?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`18ooooo`007Oooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`19ooooo`007Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`19ooooo`007_ooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1:
ooooo`007_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool04oooool2o`0001?ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo04[ooooo000Oooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool0?Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool0??ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo04_ooooo000Oooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo04_ooooo000Pooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0?ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04cooooo000Pooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo04cooooo000Qooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0@Oooool00ol0
003oooooooooo`0@ooooo`;o00004Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool0C?ooool0027ooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`11ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`11ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0COooool002;ooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`0aooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Gooooo0_l000000oo^k^koooooooooo`03ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04;ooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`1=ooooo`008_ooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo03;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1Oooool00ol0
003oEEEEojVYZ@08ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`12ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0C_ooool002?o
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0booooo`05oa0@4?oooooooooooooo
ool@41003Oooool00ol0003oEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0000>oooo
o`03o`000?oooooooooo04Cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1>oooo
o`008oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03?ooooo00Go0000oooooooo
ooooooooo`00000=ooooo`03o`000?lQ8B7ooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`1?ooooo`009?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo03?o
oooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?o<c<cooooo00?ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0AOooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo04oooooo000Tooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool0=?ooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0A_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo053ooooo000Uoooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0=?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go410@ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool0D?ooool002Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0d
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`;o00003Ooo
ool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0D?oo
ool002Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`19ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool0DOooool002Kooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`1:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`1:ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0DOooool002Ko
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool0D_ooool002Oooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`1<ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`1<ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0D_ooool002Oooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00Wooooo0_l0
000:ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`1Cooooo`00:?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04kooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04kooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`1Cooooo`00:?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo053ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo04oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Coooo
o`00:Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo053ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo053ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`1Dooooo`00:Oooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo057ooooo00?o0000ooooooooool02?ooool2o`0000Sooooo00?o0000ooooooooool0
DOooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo05Cooooo000Zooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo05Gooooo000Zooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Doooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0E?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05Kooooo000[ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
05Kooooo000/ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0EOooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0E_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo05Oooooo000]ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0Eoooool00ol0003oooooooooo`05ooooo`;o00001Oooool00ol0003ooooo
ooooo`1Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0F?ooool002gooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0FOooool002kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1F
ooooo`Go00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`1Jooooo`00;oooool2o`0000Oooooo0_l0001Koooo
o`03o`000?oooooooooo00;o00000oooool01Ol0003ooooooooooooooooo0000063ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1Kooooo`00<Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo05_ooooo00?o0000ooooooooool00_ooool01Ol0003oooooooooool0003o
oooo00;o0000HOooool3o`0000?ooooo0_l0001Nooooo`00<_ooool5o`0005kooooo00?o0000oooo
ooooool00oooool5o`0006Cooooo1Ol0001Oooooo`00UOooool00ol0003oooooooooo`3@ooooo`00
UOooool00ol0003oooooooooo`3@ooooo`00UOooool00ol0003oooooooooo`3@ooooo`00Toooool0
0omEEEGoIVIVo`00003Booooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00Q_ooool2o`0000;ooooo00Go0000oooooooooooo0000oa0@400?ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool0]Oooool008Oooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`06ooooo`Ko00000_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo0;Gooooo0027ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool03_ooool01Ol@413ooooooooooooooooo410@
00gooooo00?oZJVYoeEEEOooool0]Oooool008Oooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`06ooooo`Ko00000_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Q
ooooooooool0]?ooool008Oooooo00Oo0000olc<c?o<c<co0000ojVYZOoMgMgo8B4Q013ooooo00Go
0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo0;Cooooo0026ooooo`08oa0@4?l0
003o8B4Qo`000?mgMgOo410@o`000?nYZJT@ooooo`05oa0@4?ooooooooooooooool@41003_ooool0
0onYZJWoMgMgooooo`2dooooo`00W_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@
oooooooooooooooooc8b<P2eooooo`00W_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol0
002eooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-21.5409, -1.09829, \
0.171189, 0.01319}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0238095 0.309017 0.309017 [
[.02381 .29652 -9 -9 ]
[.02381 .29652 9 0 ]
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.7381 .29652 -6 -9 ]
[.7381 .29652 6 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[1.025 .30902 0 -6.71875 ]
[1.025 .30902 32.5625 6.71875 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -20.0625 0 ]
[.5 .63053 20.0625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-20)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-10)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(10)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(20)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10.7188 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.4375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 14.438 moveto
(\\220) show
0.000 0.000 0.000 setrgbcolor
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 9.062 moveto
(\\217) show
83.188 9.062 moveto
(!!) show
88.000 9.062 moveto
(!) show
83.562 14.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
91.562 14.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -81.0625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
75.125 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
81.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
99.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .53323 m
.03279 .55645 L
.04262 .57963 L
.04758 .58986 L
.05288 .59936 L
.05785 .6067 L
.06244 .61195 L
.06508 .61427 L
.06788 .61613 L
.06933 .61685 L
.07069 .61737 L
.07147 .6176 L
.07218 .61777 L
.073 .61791 L
.07379 .618 L
.07507 .61803 L
.07579 .61799 L
.07644 .61791 L
.07771 .61767 L
.07891 .61732 L
.08031 .61676 L
.0816 .61611 L
.08451 .61416 L
.08691 .61204 L
.08916 .60968 L
.09427 .60296 L
.10458 .58442 L
.14349 .48624 L
.1633 .43979 L
.17375 .41928 L
.18485 .40076 L
.19469 .38705 L
.20555 .37461 L
.22469 .35849 L
.23479 .35246 L
.24404 .34816 L
.2542 .34461 L
.25931 .34324 L
.2649 .34202 L
.27018 .34114 L
.27278 .3408 L
.27517 .34053 L
.27731 .34033 L
.27965 .34016 L
.28201 .34004 L
.2833 .33999 L
.28451 .33995 L
.2858 .33993 L
.28654 .33992 L
.28722 .33992 L
Mistroke
.28846 .33992 L
.28916 .33993 L
.28979 .33994 L
.29098 .33997 L
.29227 .34002 L
.29349 .34007 L
.29461 .34013 L
.29713 .34031 L
.29989 .34056 L
.30546 .34127 L
.31072 .3422 L
.31569 .3433 L
.32501 .34604 L
.33504 .35005 L
.34594 .35586 L
.35536 .36231 L
.36575 .37121 L
.37672 .38297 L
.38677 .39617 L
.40615 .42907 L
.42702 .47566 L
.44759 .52927 L
.45761 .55532 L
.4667 .577 L
.47557 .59492 L
.48023 .60262 L
.48516 .60922 L
.48768 .61191 L
.49044 .61433 L
.49296 .61601 L
.49408 .61661 L
.4953 .61713 L
.49654 .61755 L
.49771 .61782 L
.49886 .61798 L
.49991 .61803 L
.50105 .61799 L
.50231 .61782 L
.50363 .6175 L
.50486 .61707 L
.50603 .61655 L
.50729 .61587 L
.50955 .61434 L
.51468 .6094 L
.52009 .60213 L
.52502 .59386 L
.54352 .55247 L
.56429 .49779 L
.58347 .45088 L
.60332 .41172 L
Mistroke
.6219 .38463 L
.63093 .37449 L
.64064 .3655 L
.65134 .35758 L
.66127 .35184 L
.67139 .34734 L
.67718 .34532 L
.68242 .34379 L
.6871 .34265 L
.69215 .34166 L
.69493 .34122 L
.69749 .34087 L
.70012 .34056 L
.70252 .34034 L
.70493 .34016 L
.70722 .34004 L
.70848 .33999 L
.70964 .33996 L
.71091 .33993 L
.71155 .33992 L
.71226 .33992 L
.71344 .33992 L
.71452 .33993 L
.71571 .33996 L
.71695 .33999 L
.71804 .34004 L
.71906 .34009 L
.72135 .34023 L
.72405 .34045 L
.72659 .34072 L
.73135 .34137 L
.73647 .34229 L
.74202 .34357 L
.7515 .34646 L
.76191 .3508 L
.77279 .35684 L
.78296 .36413 L
.79338 .37352 L
.80326 .3845 L
.82181 .41146 L
.84167 .45056 L
.86007 .49542 L
.87892 .54518 L
.88883 .5698 L
.89927 .59204 L
.90461 .60125 L
.91046 .60925 L
.91303 .61199 L
.91578 .61438 L
.91712 .61533 L
Mistroke
.91838 .6161 L
.9196 .61672 L
.92074 .61719 L
.9219 .61757 L
.92318 .61786 L
.92443 .618 L
.92513 .61803 L
.92577 .61802 L
.92691 .61792 L
.92815 .6177 L
.92933 .61736 L
.93042 .61695 L
.93309 .61555 L
.9355 .6138 L
.94093 .60824 L
.94522 .60236 L
.94975 .59485 L
.95786 .57857 L
.97619 .53323 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00Toooool4o`000003oa0@4?oooooooooo0<kooooo002Eooooo`03o`00
0?oooooooooo0=3ooooo002:ooooo`Ko00001Oooool00ol0003oooooooooo`05ooooo`?o0000b?oo
ool009Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`38ooooo`00UOooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0<Sooooo002Eooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0b?ooool009Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`38ooooo`00Toooool00omEEEGoIVIVo`000007ooooo`;o0000bOooool009gooooo00?o0000
ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000oooooooo
ool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo0_l00039ooooo`00WOooool0
0ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003o
ooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2o`000<Wooooo002M
ooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03
o`000?oooooooooo0<Sooooo002Mooooo`;o0000bOooool009gooooo00?o0000ooooooooool0b?oo
ool009gooooo00?o0000ooooooooool0b?ooool007[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`38ooooo`00N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`38ooooo`00L_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmE
EEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000<Sooooo001jooooo`05o`000?oooooo
ooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0b?ooool007[ooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<
c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0<Sooooo
001jooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0b?ooool007[ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0<Sooooo001jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Co
oooo1?l00006ooooo`;o0000bOooool009gooooo00?o0000ooooooooool0b?ooool009gooooo00?o
0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000oooo
ooooool0b?ooool009gooooo0_l00039ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOoo
ool00ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2o`00
0<Wooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo
002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Moooo
o`;o0000bOooool009gooooo00?o0000ooooooooool0b?ooool008;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0b?ooool008;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0<Sooooo001jooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`38oooo
o`00P_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool3o`00
0<Sooooo0022ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool0b?ooool008;ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0b?ooool008;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0b?ooool0
08;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`38
ooooo`00WOooool2o`000<Wooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`03o`00
0?oooooooooo0<Sooooo002Mooooo`03o`000?oooooooooo0<Sooooo002Mooooo`;o0000bOooool0
09gooooo00?o0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo
00?o0000ooooooooool0b?ooool009gooooo00?o0000ooooooooool0b?ooool009gooooo0_l00039
ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00
WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2
o`000<Wooooo002Mooooo`03o`000?oooooooooo0<Sooooo001jooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`38ooooo`00N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0<Sooooo001booooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0<Sooooo001j
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol00038ooooo`00N_ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
b?ooool007[ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`38ooooo`00N_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0b?ooool007[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l00039ooooo`00WOooool00ol0003o
ooooooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool00ol0003ooooooooo
o`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00WOooool2o`000<Wooooo0008ooooo`Go
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03gooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^?oooool00ol0003oooooooooo`10ooooo`Co000000So410@oooooooooooo
k^k^oc8b<_l0003o<S8bonk^kScooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0<ooo
ool000Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
?oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003o
ooooooooo`12ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0loooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo0006
o`0000?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@03Cooooo1_l0
0005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400oooooo`03o`00
0?oooooooooo04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@03go
oooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@03?ooooo000:ooooo`03
oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000oooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`00000oooooo`03o`000?oooooooooo04;ooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000003kooooo00?oV9RHob4Q8Oo^k^h00ooo
ool01Ol0003ooooooooooooooooo000003?ooooo000;ooooo`03ogMgMomVIVKooooo00;ooooo00Go
0000ooooooooooooooooo`00000oooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`00000oooooo`;o0000@oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000?oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000<oooool0
00cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03gooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@03oooooo00?o0000ooooooooool0@_oo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100@?ooool01Ol0003ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool0<Oooool000Sooooo00Go0000okZj^_oooooo
V9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL0?oooool00ol0003oooooooooo`12ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0looooo`05o`000?nj^[[ooooooiRHV?l@4100
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo0008ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03gooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03oooooo00?o0000ooooooooool0@?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0??ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Oooooo`03oiRHV?oooooooooo017ooooo002Mooooo`;o0000
]?ooool00oo^k^ko0000olc<c00Booooo`00WOooool00ol0003oooooooooo`2Zooooo`03ob4Q8OoM
gMgooooo00Kooooo00?oMgMgo`000?mVIVH04_ooool009gooooo00?o0000ooooooooool0XOooool0
1_l@413o<S8bo`000?l0003o410@ojVYZ@?ooooo00?oV9RHoeEEEOooool01Oooool01?o^k^ko0000
oiRHV?lQ8B45ooooo`07oiRHV?l0003o0000oeEEEOo^k^koIVIVo`000006ooooo`00WOooool00ol0
003oooooooooo`2Qooooo`06o`000?nYZJWooooooooooonj^[[o00001?ooool00ol0003ogMgMoooo
o`04ooooo`05ogMgMomEEEGoooooo`000?oMgMd01?ooool01_l0003oZJVYoooooon7QhOo<S8bofIV
IPOooooo002Mooooo`03o`000?oooooooooo0:;ooooo00Go^[ZjohN7QomVIVKoIVIVoa0@4004oooo
o`;oMgMg1Oooool01Ol0003oc<c<oooooomEEEGoQhN700Cooooo00Ko0000ooooooooooooooooohN7
Qom4A4@7ooooo`000oooooooo`0003Go00002_ooool01_lb<S;o8B4QogMgMomgMgOoQhN7onk^kPCo
oooo00?ok^k^oa0@4?o^k^h00_ooool00olb<S;oEEEEoc8b<P02ooooo`03ojVYZOlQ8B7ooooo00?o
oooo00Ko8B4Qolc<c?oooooooooooiRHV?lb<S87ooooo`002oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03oooool01_l0003o^[Zjooooooo^k^ko
MgMgo`0000Gooooo00OoEEEEoiRHV?oooooooooookZj^_lb<S;o^[Zj00?ooooo00?o0000omgMgOoo
ool00_ooool01onYZJWo8B4QomgMgOo^k^ko<S8boeEEEOnj^[X01_ooool000_ooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo04Kooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`0?ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o00001Ooo
ool00ooMgMgo410@ooooo`07ooooo`03oeEEEOn7QhOooooo00?ooooo00KoV9RHo`000?l0003oV9RH
okZj^_lb<S86ooooo`00WOooool00ol0003oooooooooo`2]ooooo`03oeEEEOnHV9Sooooo00Kooooo
00?oZJVYoc8b<_ooool03oooool009gooooo00?o0000ooooooooool0[Oooool00onj^[[oA4A4oooo
o`06ooooo`03onk^k_l0003ok^k^00oooooo002Mooooo`;o0000^?ooool00om4A4CoV9RHooooo`0>
ooooo`00WOooool00ol0003oooooooooo`2gooooo`03oiRHV?m4A4Cooooo00kooooo002Mooooo`03
o`000?oooooooooo0;Oooooo00?ok^k^o`000?l000002_l00004ooooo`00WOooool00ol0003ooooo
ooooo`38ooooo`00WOooool00ol0003oooooooooo`38ooooo`00E?ooool@o`0003Wooooo0_l0000h
oooooa3o0000POooool0053ooooo1?l0000@ooooo`?o0000=_ooool00ol0003oooooooooo`0boooo
o`Go00004?ooool3o`0007kooooo001=ooooo`?o00005oooool3o`0003?ooooo00?o0000oooooooo
ool0<?ooool2o`0001Sooooo0ol0001kooooo`00C?ooool00ol0003oooooooooo`0Kooooo`;o0000
<Oooool00ol0003oooooooooo`0]ooooo`?o00007Oooool2o`0007Wooooo001:ooooo`;o00008?oo
ool2o`0002oooooo0_l0000]ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0M_oo
ool004Oooooo0ol0000Tooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`0Rooooo`;o0000M_ooool004Kooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool09Oooool2o`00
07Cooooo0015ooooo`03o`000?oooooooooo02Sooooo0_l0000[ooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1aooooo`00A?ooool00ol0003ooooo
ooooo`0[ooooo`;o0000:Oooool00ol0003oooooooooo`0Wooooo`;o0000;?ooool00ol0003ooooo
ooooo`1`ooooo`00@oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02Kooooo0_l0
000Wooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0Koooool004;ooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`1^ooooo`00@_ooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`1]ooooo`00@Oooool00ol0003oooooooooo`0b
ooooo`09o`000?oooooooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`1/ooooo`00@?ooool00ol0003o
ooooooooo`0dooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool02_ooool00onH
V9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo06_ooooo000oooooo`03o`000?oooooooooo03Go
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^
00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0002;ooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`1[ooooo`00?oooool00ol0003oooooooooo`0fooooo`03o`000?oooooo000000?o
oooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool0J_ooool003kooooo00?o0000ooooooooool0>?ooool00ol0003o410@ooooo`02ooooo`03
oa0@4?oooooooooo00gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Zooooo`00
?Oooool00ol0003oooooooooo`0jooooo`05o`000?nHV9SooooooiRHV?mgMgL02oooool01Ol0003o
^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Poooo
o`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0JOooool003cooooo00?o0000oooooooo
ool0>oooool01Ol0003o<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004
ooooo`Co00001_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0J?ooool003cooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Ooooo
o`;o00007oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo06Sooooo000kooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool0Ioooool003_ooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`1Wooooo`00>_ooool00ol0003oooooooooo`10ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`10ooooo`03o`000?oo
oooooooo06Kooooo000jooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool07Oooool2
o`0001gooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`1Vooooo`00>Oooool00ol0
003oooooooooo`12ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`12ooooo`03o`000?oooooooooo06Gooooo000iooooo`03o`000?oooooooooo04?o
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04;o
oooo00?o0000ooooooooool0IOooool003Sooooo00?o0000ooooooooool0A?ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0A?ooool00ol0003ooooo
ooooo`1Tooooo`00>?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo06?ooooo000g
ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool06_ooool2o`0001[ooooo00?o0000
ooooooooool0A_ooool00ol0003oooooooooo`1Sooooo`00=oooool00ol0003oooooooooo`17oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`17oooo
o`03o`000?oooooooooo06;ooooo000fooooo`03o`000?oooooooooo04Sooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04Sooooo00?o0000oooooooo
ool0H_ooool003Kooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`1Qooooo`00=Ooo
ool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo063ooooo000eooooo`03o`000?oooooo
oooo04[ooooo00?o0000ooooooooool06?ooool2o`0001Sooooo00?o0000ooooooooool0Boooool0
0ol0003oooooooooo`1Pooooo`00=?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo
05oooooo000dooooo`03o`000?oooooooooo04_ooooo00Gok^k^o`000?l0003o<S8bonk^kP05oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`1=ooooo`03o`000?oooooooooo05oooooo000cooooo`03o`000?oooooooooo
04cooooo00GoMgMgoiRHV?l0003oV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`1N
ooooo`00<oooool00ol0003oooooooooo`1<ooooo`05oa0@4?oooooo0000ooooool@41004?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0Coooool0
0ol0003oooooooooo`1Nooooo`00<_ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo
00;o00003oooool00omgMgOo<S8booooo`04ooooo`?o00005Oooool00ol0003oooooooooo`1?oooo
o`03o`000?oooooooooo05kooooo000booooo`03o`000?oooooooooo04gooooo00?o0000oooooooo
ool00_l0000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo057ooooo00?o0000ooooooooool0GOooool003;ooooo00?o0000oooooooo
ool0COooool01Ol@413oooooooooool0003o410@00cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0GOooool0037o
oooo00?o0000ooooooooool0C_ooool01OmgMgOoV9RHoooooonHV9So000000cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05;ooooo00?o0000oooo
ooooool0G?ooool0037ooooo00?o0000ooooooooool0C_ooool01Oo^k^ko<S8bo`000?lb<S;o0000
00cooooo1?l00006ooooo`;o00005?ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo
05cooooo000`ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0G?ooool0033ooooo
00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0E?ooool00ol0003oooooooooo`1Kooooo`00;oooool00ol0003ooooooooo
o`1Eooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`1Eooooo`03o`000?oooooooooo05_ooooo000_ooooo`03o`000?oooooooooo05Kooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05Gooooo00?o0000
ooooooooool0Foooool002kooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0Boooo
o`;o00004oooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo05[ooooo000^ooooo`03
o`000?oooooooooo05Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo05Oooooo00?o0000ooooooooool0F_ooool002kooooo00?o0000ooooooooool0
F?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
F?ooool00ol0003oooooooooo`1Iooooo`00;Oooool00ol0003oooooooooo`1Jooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Iooooo`03o`000?oo
oooooooo05Wooooo000]ooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0FOooool0
02gooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0@ooooo`;o00004Oooool00ol0
003oooooooooo`1Jooooo`03o`000?oooooooooo05Sooooo000/ooooo`03o`000?oooooooooo05co
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05_o
oooo00?o0000ooooooooool0F?ooool002cooooo00?o0000ooooooooool0G?ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Foooool00ol0003ooooo
ooooo`1Hooooo`00;?ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo05Oooooo000[
ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0Eoooool002_ooooo00?o0000oooo
ooooool0G_ooool00ol0003oooooooooo`0>ooooo`;o00003_ooool00ol0003oooooooooo`1Ooooo
o`03o`000?oooooooooo05Kooooo000Zooooo`03o`000?oooooooooo063ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo05oooooo00?o0000oooooooo
ool0E_ooool000_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1=ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l00005ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo05oooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0fooooo`002oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo04gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omE
EEGoZJVYo`000007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`1Qooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0=_ooool000co
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1>ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEo`000008ooooo`03o`000?oooooooooo00?ooooo0ol0000<oooo
o`03o`000?oooooooooo067ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0goooo
o`003?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04kooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03ob4Q8Ol0003ooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0gooooo`003Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04ko
oooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<co000000?ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Hoooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo03Sooooo000=ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool0Coooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMol000000oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0Hoooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo03Sooooo000=oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0Coooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Ko410@oooooooooooooooooc8b<_l00003ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool0>?ooool000kooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`1@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`000004ooooool0003oooooooooo`Co
00001_ooool2o`0000_ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo03Wooooo000>ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
I_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
Ioooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo03Wooooo000?ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo03[ooooo000?ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0J?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0J?ooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03[ooooo000@ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
03_ooooo000@ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0JOooool00ol0003o
ooooooooo`08ooooo`;o00002?ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool0>oooool0013ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`1[ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`1[ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0>oooool0017ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0??ooool0017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1/
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0??ooool001;ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Kooooo0_l00007oooo
o`03o`000?oooooooooo06gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0moooo
o`004_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06kooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0mooooo`004_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo06oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo06oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0mooooo`004ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0nooooo`005?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo07;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo077ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0oooooo`005?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool00oooool2o`00
00Cooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
043ooooo000Eooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0M?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0MOooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo043ooooo000Fooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0LOooool4o`000003oa0@4?l0003ooooo00?ooooo00Go0000oooooooooooo
ooooo`00001iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0@Oooool001Oooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1dooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000007Wooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`12ooooo`005oooool2o`0000?ooooo0_l0001gooooo`03o`000?oooooooooo00;o
oooo0_l000000ooooooo0000ooooo`02o`0007_ooooo0_l00004ooooo`03o`000?oooooooooo04?o
oooo000Iooooo`Co0000N?ooool00ol0003oooooooooo`03ooooo`Go0000OOooool5o`0004Kooooo
002Eooooo`03o`000?oooooooooo0=3ooooo002Eooooo`03o`000?oooooooooo0=3ooooo002Eoooo
o`03o`000?oooooooooo0=3ooooo002Cooooo`03oeEEEOmVIVKo00000=;ooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo0026ooooo`;o00000_ooool01Ol0003o
ooooooooool0003o410@00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool0
1?l@413o0000odA4A?o<c<bfooooo`00Qoooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00Kooooo1_l00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo
00?oV9RHoa0@4?oMgMd0]Oooool008Oooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`0>ooooo`05oa0@4?ooooooooooooooool@41003_ooool00on7QhOoEEEEooooo`2dooooo`00
Qoooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Kooooo1_l00002ooooo`05
o`000?ooooooooooooooool000002oooool01Oo<c<co8B4Qo`000?mEEEGo00000;Gooooo0027oooo
o`07o`000?o<c<coc<c<o`000?nYZJWogMgMob4Q8@0@ooooo`05o`000?ooooooooooooooool00000
2oooool01OlQ8B7oQhN7oooooonHV9So00000;Gooooo0026ooooo`08oa0@4?l0003o8B4Qo`000?mg
MgOo410@o`000?nYZJT@ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo00000;Gooooo002Nooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01OlQ8B7oV9RH
oooooomgMgOoEEEE0;Gooooo002Nooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo<c<co
410@o`000?lb<S;ok^k^0;Gooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-21.5409, -1.09829, \
0.171189, 0.01319}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "Different values of ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`a \[GreaterEqual] 0 \[GreaterEqual] c\)]],
  ", lead to the same basic behavior, but with different values for the peak \
height and trough depth.  (The reader is encouraged to vary the parameters ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " to verify this.) Note how, for finite wave amplitude, the troughs of the \
wave broaden and the peaks narrow. This corresponds qualitatively to the \
peaking of real water waves, shown in Fig. ",
  ButtonBox["7.5",
    ButtonData:>"Fig. 7.5",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .49783 
%%ImageSize: 920 458 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0010352 0.011853 0.0010352 [
[ 0 0 0 0 ]
[ 1 .49783 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49783 L
0 .49783 L
closepath
clip
newpath
% Start of gray image
p
.02381 .01185 translate
.95238 .47412 scale
920 string
920 458 8 [920 0 0 458 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
6B6C6C6A676463636162726B696565616363605A57595957615F5D5D5D5D5C5B56565B5B
55565C5D5A59575C56525B5A585755545556585A5E595B5C55525454505351575259585C
5551555A585759595453525152545758565450525754505354525152514D4C4D59585554
4D564D4E515353515052525053544B5153584E4E4F4E4F4D524A57595B555050484E4851
4C4D4C4A4A4D4F4D4F4D4645484544494C484744494B49544D484A48494D4A4C4E514F4F
53504A4A4D52524B45474E534A4A474F4A4D494E4E4B484B4F4F4A454C47564A51414C43
484C4E4B46434549494A4D4B46494C474C4E44494A50484A4846424644454C4742484E4D
6C648E8AABB4BDC4C7C2B5A9978A7B645C51534F4B4F4547443F49464547404145484E49
48464443444544434449484646434247424B49554A554B5D545F4E58515D4E5857495645
5048504B514A4B53544A44454748464140464B4D4B4B513B41474345404343454B4C515C
525355494B45474244474444474540403F4947444846454F5051535556585B5E595F5B65
584F4D524C504B506764706767594A4A4C4348484B3E3F5F5E4E5A777879718C759D705D
4942424345413D4D3F424A4B423F41403D40474D495A687F8D6F5A574C4F4546423E3F3D
434D4B4A403740545D45454649426051665F6153606379738982938F9E9DA49AA09A999F
9CA89FAC92937B695E474A47424D515B787A928FAB968159634D42403B3E423B3C41403D
3E3B3B403D3F3D3E3F3A383E3D3C3A3B3D3F4040403C3C3E3C393E473D3C3B3C3D3D3B3A
3A3B3B3A3A3B3E4042403D3A38393A3B393A3B3B3A3A3C3E3F3E3B383B40403D3A3E393D
413A3C3E3D3D3D3F42423F3B3A3B3D4041403B383B3D3E3E3D3C3C3D393A3B3B3B3B3B3B
3C3B3F3A41563C393E3E3B37383B3B38383A3C3C3A383737383C3C393738383637393B3C
3A37353438393A3B3D3D3D3D3738393B3B3A3938383B3B3837383734373A3A38383B3B39
393A3B3C3C3C3C3C3D39383A3B39393A3C3A3D3D393A3D3C3C3C3C3C3B3A3A393C3B3A3A
393A3A3A3B3A39393A3A3836383A3A37373A3B393A3B3C3B39383A3D3939393939393939
39393938363637383937393835383B3636383A39383635353939393939383736393A3A3B
3B3A3A3939393A38373738393838393B3D3C3A3837393A3B3A3A3B3B3D39373939373637
3939393735343536383737373737373838383737383736343938373736373737373A3B38
383A3C3C37383838383736363833363B38383A3A
5153545454535354574F584F53565954545756545253514D5452504F50504F4E4F4D5155
54555550545250534C474F4E4C4D4E4F4F4F4E4D524D50524D4B4D4D4B4F4C524E555358
524C4C4E4B4B4F504A4B4D4E4F4F4F4E4C4B484B514F4C4F504C4A4A4A494B4F504F4C4B
444D44454D4F4F4C4C4E4E4B494E494E4D514B504A4B4D4D50464F4F514D4B4E484D454C
4749484545494A494E4E4A4A4D49444845454A4B4F4E464D48444745474D4A4D4C514F4A
4844444A484C4E4B494745414B47414B4B4F48484948474748494B4C48484A4C43464849
44444444444444444746484542474D4B3C444147454841474447464842414B4A4955558B
719E738B7B8098B0BBC0B69F826A584A4D43474852474841434B42464849424245474B46
4545454747464340464642414645414252474E43574C4A49544F47444D45444F544B4946
4049494B4945484F4D45474F4245454241454848474B614F4949443F4446434244434650
524D514C4E4347484848434144444144494542404144464743444444434345464247434E
4440434B474F609098AF9CB699A88E9771795D5457494C4F6E65736A929BA68BA188AE81
6F5C5348404240404341434542434643413E45425D80749F9AB4999082726B66575A5E52
46433E413D413C748F4A3B403D4040615D55514C445F566D58817F8E859C8C8E95859D8D
9B97AB97B39FB59DA083807A767E7D8086A6ABB39593664B3E4445403C3C3B3A363D3F3E
3F3A373B393D3F4345403C403D3C3A3B3D3F4040403C3C3E3C393E473F3E3D3D3C3B3937
373A3C3E3D3D3D3D42403D3A38393A3B393A3B3B3A3A3C3E363B3E3C393A3C3B3A3E393D
413A3C3E3B3A3A3D3F3F3C3938393B3E3F3D3936393B3C3C3B3A3A3B3C3C3D3D3E3E3D3D
3A393D3A42583E3C3C3C3935353939363A3C3E3E3C3A393935393B3938393A3937393B3C
3A373534363738393A3B3B3B3C3B3A3A3A3B3D3E36383937383A39373537383636383936
3738393A3A3A3A3A3B373638393736383A383A3B36373B3A3F3E3E3C3B39373639393939
3A3B3C3D3838373738373634363837353538393737393A393736383B3737373737373737
3B3C3B3A3838393A3937393835383B3636383A39383635353B3C3C3C3B3A393937373838
383837373737373635343637363637393A3A383535363839383838393834333637363638
3B3B3B39373737393B3936343436393B383738393B3B3A39393837373637373735383936
36383A3937383838383736363734393E3B383734
565757575655555655525658555657535157534F53544F4E5352515152514F4D4C4F514F
4C4B4C4E544F4D4C484A4F4E4A514F4B4F504C4D5150504F4E4D4B4A495651514F485055
4E504C4E4E4C5252494D50504F4E4E4F4B4846474A4D4E4E4B4F4F4B4A4C4E4D4C514A4B
4C4A4E464E4946494F504C464A47464A4D4E4A4749535B595453535353514E4A4A4B4B4B
49504E4A4B494545484F4E4D504B4447484245474E524845434D4B424448474741464B4C
49464546414C4A4C4D44403D4441414546423F414950514843444644474A4A47484C4C48
42464A48444040413F4142424346494A453F414244464A453C4046454845524A6A637261
4F525355544E4D799FA79A70594D494943434C54444E48484448434A3D49483C3A3F4346
493D423D46424A433F41454F4C46484246454B4E494B485144474D504C46484E4E474240
47413A516357423F42424947474848424146494A46474A4B47413F413D3C454C46444849
5D5C7865716B5F5752524144454A463F424141413F3F454C4C41413D3E43424B3F403E46
3F413E433F3F7E9EC0C4D4CDD4C2C7A2B19AAD989084706B5B58545C69969BBBA6AC95B6
969A847052504E4043403E4236446E6E5D59637A7C74727D9199A3AAA89790A09CA6958C
816657545B4A434D564A3B3C3B40484B574B44414048524C585E636C6A6B706A655C5667
5C676679638584978A8F93949C8F8C79767F7E715F4B40433C3D3D3E3E3E3D3D3D3C3B3A
393A3C3D3E3D3B3A393939393A3938393B3D3D3D363B3E383C3F393D3C3938393B3D3C3B
3E373B423E3B3B38383D403D3B3C3C3A3B38383A39373A3F373A3E3E3A3737383D3B3B3E
40403C383E3A383A3B383637393C3C393A3C3C39373B3B38383B3A36383636393A373535
363C3F3C393B3C3B37373A3C3A37383E3735373733343939383B3A373639393538383738
393937363A3534373A3B3B3C3D35373D3C3B3B37343536393C3D3C3A3C3B363C3C363A35
3339363A3D39333E3D38373D3F393738383B3C414042483E3D3E3F3E3B38373632333538
3939393937383F3F353235333536363738383939383B3A393C3B383B39383637393A3B3A
3D3D3D3C3C3B3A39373C3F3D3936383C393A3B3A3A393838383A3A373434373A3537393A
3B3B3A393838383737373736383535393936373A3536363738393A3A3837363636373839
36373838373738393A3A383736363637343434373A3B393834373836363939363939393A
3A393939393332383935363D3736353537393B3D
5050504E4C4B49484E4C4F504B4B4C484C504D494D4E4A494D4D4E4F515252524E4D4B4A
4A4B4D4E514D4D4D494A4D4B464B4A47494A49484647474848494A4C4B544F4E4D474E53
50514A4C4D494B47474746454546484A4946444749494C4F474A4B4746484A49474D4849
49474942454445474A4B4A4944474948484948454A51555451504D494844444749474646
444C4C48494845474348494A4A4744464B494E4B4949424349504C45454543443D414445
434140403F47434648434549454343444544454644494A46454A4A464647484747494846
44434142444443414341424443404145474342433F4347473D434E515650574A494A4C49
36464C4D4544445F76808977594F4D4E47444A4F444B4649464B403D3D4544404344403F
3F404449454B4D4A514E4A4B433F494A47424E494F4A4C514F4F5153524D4B4D4C4B4948
4C4C546D675A484242475761424E4C4140494B3F42444647433F434A423F4448423F4140
414856606784858D828774727A6F5A4E4F4A4645454344464B403F3F4348444944454249
42454248433D4E7C82ACB1B9B6AF99AA96AAA1A6A8A59EA29083757864698E7E9C7E928D
A5AAA598827A7467635E4440453B5889959995B6A19978797F78798D9891939FA9A6B09B
AF8A918B82807A736F6E6A685B514E4D594B44433F3D443345434D564C555B534B454246
433B3E41424F576064666A69706762544A4D473F3C3A3C4538393A3C3D3D3E3E3C3B3A39
3A3B3C3C393939393A3A3B3B403F3E3D3E3E3E3D3C3E3E35373C3A413C3B3A3B3C3C3D3C
3F3A3B3C3A3D3E38363B3D3C3B3C3C3A3B393A3C3D3B3C3F393A3B3A38383A3D3A383638
3C3E3D3C3E3A383A3B393839373A3B38383A3A3742413D39393C3E3F3E3B393C3E3D3C3C
363C3F3D3B3B3A3838383A3C3937393E3634393B38383A373537383737393A393C3A3838
393939383635373939383C414339383B3A3B3D3B353537393C3D3C3A3638353C3D383D3B
373534363D3D3F434132383E45413E4A4447494E4D4C4E413B3C3C3A3837373838383838
383838383D3E44443C393B3936373737383839393A3D39373A39373B39383737393A3A3A
3A3A393939393939363A3D3C3836383B393A3B3B3A3938373B3C3B393737393C36353434
34343435383837373737373638363637373637383334353738393A3A3736363636373838
36373837363637383837353434353535373737393A39383736383937383A3A383939393A
3A3A3A3A3737393D3E3B3A3A3736353536383A3B
5656555453504E4C565457564F4D4F4D4B4E4D4C505251504C4D4D4D4D4D4D4E4E4B4848
494A4B4B4D4A4C4D49494B484A4A4C4B494B4C484C4C4C4A4747484B5257504D4A464A4D
4F504A4E5251524A4A4846454648494A4A46454749484A4C484B4C4B494A4B4A444A4848
47444540474A4D4C4947484A474E524E49494846494C4E4C49484746494342484C4A4849
454D4C4746434143444448494645464443444B49484A474C444745414241404241424344
4443424146494446443C40444344424040434646424444424447453F4545464747454445
4B47444346484745423E3E44433D3F46414140473F4B505649484A484942483C3E3E4A42
464352464E54525C5E5E6B66665D5C5B524B4B4B4749454A48544A3D46453F3F45464140
404350454B4450484547484E49444C4B4C4E4D554A52464F554E4845423F3C3B3F3E393B
3B3A42484D4543424248576B6C7C705D575E60494F49433F3C3C404543404244413E3F3D
423F4A424D576B6A9C94A9A4C4B6C9AFAB98827369625D5C656165625E55494645454147
4145444A50393C464F6272738E7884768C7A92959594919A919296A79F968C8E8E999791
9F9CA7ACB0B0A89A99996B4E55494863969399A2ABA5A1A0A68C737C85878F8A8B8D8599
878F7C8A978F8898A49F94998F7B71707C706E6F5F5A49423E463D4A4E626E685C595C54
574737493847363F3E3C413D43413B3441403A3739393A3E3838393A3B3B3B3B3B3A393A
3C3D3C3B39393A3A3A3A3A3A3F3E3D3B393737383F404136353A3A413E3E3E3D3C3C3D3E
3F3D3B38383F4038373A3C3B3A3A3A393A39393C3D3C3C3C3A3A3A39393A3B3C3C3A3939
3B3B39373D3A383A3A3A3A3B4142413F3D3E3D3A3D3B3A3B3C3B3B3D463F383837353232
383B3D3C3B3B383639393A3A3837393E3B383B3D39393935353637393837383C3C3A3737
373838383C39393A3937383B413A393B3A3B3C3A3636383A3C3C3B3A373A393D3D363738
363641353C333D393C4A5451537C7C855C5B55544F4A473B383938373636383A3C3B3938
38393A3B37373B3B3735353338383838383838383C3D39363837363A383737383A3B3A39
3C3B39373534343434383A3A3736373A3A3A3B3B3A3937363C3B3A393938393B3A3A3938
373636353837373737373636373837353536373638383838373533323535363737373736
37373736353537393836343436373634393A3A3A39383737363838363739393738383939
393A3A3A37383836373A3B393736363535373839
4D4D4D4D4D4C4A4849494E4E49494E4D4D4D4C4B4E4F4E4D4B4C4C4B4847484A4C4C4B4A
494848484B484A4B48484A474744484945474A44494C4E4D4B4B4D504D4E4B4847454748
4E50494A4A4849424745454749494643434341414448453E4346474746454545454A4A48
4545454347494946403D3D3E3E44494A47464749464848444142474B49433F4145474645
444D4D4644414043444145464040444048454947484B45474342414142404143403F3F3F
4141403E4545414545424D55444645403F4446453B404243454949454543454847424144
474645423F3E3F41423F3F40403E41464E424B546E6D6954413B3B3B4344524B4B4F5163
555D4F4B40444146454147434C46484B454142404444434C5067685E4E473D3B41403F43
404D454D3A4E484C454648514E494E49474455474C3F42414E473F3B3A3C3F42403F3B40
3E3E47404E4345414047546C7C86746A676A73636E5A4339383A3C3E4442424342413E3C
453F493A43384F435A7C6A8F96BCB5CFD5C3AE9F97918F8FA09EB69DA7858D8473757379
6E685B5A59454C4548434E4749405047514A61726A6A6B77747F8FA8AEA6ACA3BEC2D1C9
CEBDC3C2CED1CEC9C2C19F8882817D6679857D8A8AA3A1A8948879878F908B66705A6F60
6E5A5E62867E6B839FA09094928581819193A1AB9B8983686F574B44475E7078757C8B82
73504644453C383B3F393E3A3F433D3D36373738393835343B3B3B3B3A3938373C3A393B
3E3F3E3B3E3E3E3D3B3937363F403F3D3A393A3B3C3F443D383A383C3E40413F3C3B3D40
3E3D3B393B3F3E383B3C3D3C3A3A38373A3837383A3A38373A3B3C3D3D3B39373C3D3E3F
3F3D38343A39383839393B3C3D3D3C3B3B3D3F4044414043413D3B3E463D363638383737
393A3A3A3B3A39373A3A3A3937373A3D433D3B3A363637333837383A3834363B37363536
37383837423A36383C3B37343836383A3B3A38363738393A3B3B3B3A3B3A373D44403936
3C3D323D373E3D4E7090B78E9A9B997966605049433D3C3338383837363638393A393838
393C404239393A3A3938373538383838383838383A3C383638373639373737393B3B3A38
3D3B383533333333353739393837383A3B3A3939393937363A373637383737393B3D3F41
403C38353737373736363636383A393534383936393939383533302E3435363737373635
363636363536383A39373536393A393638393A3937363738343434343435353537373737
3738393937373636363738393737363535363637
545352535353514E595758554C494B4A54504D4C4B4A4947474848484747494B4E4F4F4B
4745474A4A47494A46484A474944484B46474A4645494C4C494747494A494C4D4D4E4F4F
494F4A4744424844484646484B4B4742484D4C4A525C5544434445464543434446484945
434545464948484747464646454446494842414447454343434446474544403E43484641
3F484945454545493F3C41423D3E434043414645474B47494B4847474544444442413F40
4243414045443F43444758604245454243474947454A4D4A454444434543444745404145
46484845413F3F414647443D3B3F424249534D7E6E8354424B49515A696C7B747B5E5E49
4B3D3F434140393A3E3F4240443F424542414240414549565C79848353545254554B4448
474E534C53585F5C5C514444403D423D424C4F5540483C45484845403D3E44494A4B4A4B
444758555C5150494241414F515143484945514E493F393C41413D394142414142413D39
454B474E4341443B3F3F4E515F688783908C898781776F6B708572916B897A8D7A8590A3
9F97847E6C6E637C62705E5B54605B6B5574708C7D7D797C70737A8B98A6AEBBB5C3C3C5
D0C3CFCED3D2D7DCD6CCBBBAA18D9686748681828392847B6D6861707678754E5042464C
41493C4E59695D68778B82707476807D868EA5B0BAB7B0BBABAA8374444C566A7A8EA39F
815A4A40423C444E3F393B393A403A3E393B3E3E3C3C3F403C3C3C3C3B3A39383D3B3A3B
3F403F3C4040403E3C3A38363A3B3C3B3A3A3C3E3A3D453F393B383A3E4042403C3B3D40
3C3A3A3F413E39383C3C3B3C3C3B3B3B3D3B383637383836393A3C3D3E3D3B3938393B3E
3F3E3B383738383737393A3A383736373B40464A5048423F3B37383D453C353639393A3B
3A383838393A3B3D3B3B3A3837383A3B423C3A39343536313937383B3936373B35353639
3B3C3A393C3533383E3E3B393436383A3C3C39373838393A3A3A3A3A3936343A47463B3A
333B4C4A59476A9CAECFC8D5ACBB8E7C554F3E3A39363835393A3B3A3837373739383738
3A3E41443C3C3B3A3B3B39393838383838383737373A38363A383639373737393B3B3A38
383736353638393B37383A3A3A3A3A3A3D3A383738393837393636383937373936383B3D
3D3A36343737373736363636393B3A3636393A3735353636363535343435363737373635
353636363636393A39373536393A38363537383736353738353433333333343536353535
3536373736353A42423A36373736363535353535
53514E4E4E4E4C4A4C4B4E4E494A4E4D514C4B4D4B4B4D4C4A4949484748494A52514E48
4444484D4946494A47484A474C494B4D4B4A4B4A484B4D4C484442414E4B51504D4F4D4D
444D4B4845464F4E4B4947484B4B49463F4647454E5A5241464647484745454845454741
404645464A484442403F3D3B4D4C4C4C48434142484443474B49433F4242414145494742
424A4945454444483F3F43454345484842434B4844444147474545454346474445444344
4546454341424144424048443B3C3D3E424546443D424645414042454243444442404145
4A4A4949494846454347443B3A424744474D7071816B6E5D5F5A5B5C5F54584C4D3F3E46
3D47384842433E3C3E3D3E40433E3E3F3B3A3A364246454B4653575B63707D85816E5D5B
546454634C5E4A4F48423D4649494E485252604F50444748434A4E49413D3E4047454547
42444B484744474746433F424541384242383E41484441403E3D3F433A3E3D3C4143403F
3D4243454A4347403A4B3A3D44453C434E535D65655D555353574D4F444746454F586277
797B706E6A6A6D858B97968E979BA7A3AFC2C7D1CBD0CCC9B2A3908B968492777F6B7F6F
8F87939FA8AEB7BCCCD0C3BDA6898D908786866E89868E847868585953535B4C453B3F3E
383E374B46514E6362716F5962728C8E91919E9EA59CB5BEC7C1AD8C5C4F4754697D8885
715B4A53495A5B6B45413E403D403B3F393A3D3C3535393B393A3B3C3C3D3C3C3D3B3A3B
3D3E3E3C3D3D3D3D3D3C3C3B3636373838393B3D3C3C433D373B3B3C3C3E403E3B3A3D40
3A3A3B41443C36393B39393C3E3E3E3F3F3F3C39383A3B3939393A3A3B3D3F403A393837
373839393538393837393A393F3C39393B3E444944403C3A3837383B453D373739383839
3A38373838393D413A3B3A3837393A393936383A37373733373636393B3B3C3D36373A3D
3F3F3D3B3736373A3A38383B383C3A383C3D3C3D3839393938383839343A3E3A39353342
50607C79AFA3B3BFDBD3DAA8B990885841403435393537363A3B3C3C393736363A393939
3A3C3E3F38393634363533343737373737373737363938373B393739383737383A3B3A39
38383737383A3B3C3A3A3A3B3C3C3B3A3C393636383939373B37383C3C38383D37373737
373737373737363636363635383A3A383839393737363636363636363535363737373736
363738383737373836353435373735333435353535363739393635353534353736353433
3334353637333740403733373636363636363535
53504C4C4E4F4D4C4B494B4C494B4E4D4A43444947494D4C4E4D4B4A4A4B4C4C514D4947
4749494948464A4C49494A46474746484A46444846484A4C4C4B4A4A4A454D4A44464445
454D494643444A45464646474948444143484B4B4E514D45434242444340414545434742
434A47484343434446484A4B424B4D46404345444444474B4A464445473E3B3F413E4045
474D4A4443423F41424647474847474A3B3D4746454644493E3D3F3E3E4549423E3E3E3F
40403F3D393F4144414143353D39383C414241403E4041403D3C3C3E3F4243403D3F4244
44454545434141413D41403D3E4448484D59496A47634C524C4647494C41483F423B443C
423C393A3D43454445434045403C3E403E40413C4144404643494A5353626D726E5E504E
44514E544A4E464E48484C57564F4F4751514D4A414B4347404A514F4A47474645404448
4C4F4B4850514A45413E413E3E3E3D41424043453F414446423F434A4044403D41444244
42414738503B423C3B3845384A3949393E3F444B4D4A47484C4F4E4B4F474B4146444048
4345404248404F4C6A5F75657F859195A4BFBCC7CBD2D1D4CFD5CCC7B897946D785E6F5E
74665D69707B83838694948A8B8A8C9E8F8772646769748991877E78685C5950524F4E43
41413D506158425B55524E4C515D7B87908F96908F82899C8FAA9B7E584B3F3C48524F4F
473A4746565A626145453F4742434042424043423A393C3A38383A3B3C3D3D3D3B3A3939
393A3B3B3A3A3A3B3C3D3E3E3D3C3C3C3E3F40403C39403B363C3D3D3A3C3D3C3A3A3C3E
383D3D3E403C373A3C38383B3D3C3C3D3C3E3D3A393B3C3B3B3C3D3C3B3B3D403C3B3836
35363739353A3C3A393A3A39403B37373635383C3C3E3E3C3D3E3F3E403B393C3F404143
3B39393A39383C413A3C3B38383A3A373534383B38383A37373737383B3F3E3C38383A3C
3D3D3B3939383A3B39343437393F3D393C3D3B3C3839393837363739373D413D41464B63
75A4ACB6BCD1C2C5A5AD9294768958413A3C34373C3534353A3B3B3A3836363639393939
3A3A3A3A393B3734363432363535363637373738383B38373A38363939383737393A3A3A
3A3A3A3A3A3A3A3A3C3A3A3B3C3C3A38383736383A3B39363937393D3C37383E39393837
37383939373636363636353536363739393736373B3A3836353535363736363636373838
393B3C3B38363434363636363636343336363535363738383A3635363534353839373634
3434353638343436363334373636363637363636
534F4C4D505353524E4A4C4D4B4D504E554C4C4F4B4B4E4C4C4A494B4E5254554C484649
4E4F484146454B4E4B4B4A45484A47494D49454B4A494A4A4A4A49484A454F4D484E4E51
444C49494B4F534A47494D51514E4742494B4F4F4A444346474545474543454947444A45
48504A4A47484845413F41444D5D5E4A3C41433E3D444C4C433E475459473E43423B4151
454B4742434240414046444244403C404642464545463D3B4040423F3D46483E3E3F4041
41403F3E484A454340464D3F4A423E4346454241403F3E40434445453C41423C3A3E4243
43484B473E393C423F3F40404040434545413E433E43423E413C4145483D42393E44403E
3D4547473F43433F403E3A40454143444142413B4042383E3E424150545A5A56544F4C50
495B515F48554A5E4948484C454048464A42413A444F4F4E464D504D484746444A454B49
4A4C4A5349514C494441464043494A43444E5251505359606160626752544B4141413E40
3F443C3B4542373C3B4B3D44383F383F403B3A3D40403F403A40463F4B42524A42413D46
454B484D3F44404A45474C474952535F597764767580838F99B1B1ADB2B4A6A99E9B8D95
908D8595949A9C97A396937C6D676282A5999C7D8153657D88888B8681878C8B80857971
666B6279707A565E5B544546443E4C566365706F7458585A527781663F4242393D423B42
3F3E3E4A4455484450544C5A5555555559504B453B393A3639393A3B3B3B3A3A3A393837
3637383A393838393A3B3D3E3E3D3B3B3D3D3D3C39363F3C383E3D3B393A3B3A393A3C3D
38413F393B3C3A3C403B393B3B393738363A3C39383B3C3A3C3F42413D3938383738393A
3A3B3C3D363C3F3D3B3C3B393D3A383A3A393B3F3F3F3B3332373A393D3A383A3A38383A
3B3A3B3C3A373A40393C3B39393B3A363937393934363B3B3A3B39373B403E3838373738
39383735383535393B393737363E3E3B3D3B353438393938363536383E36333E627D8192
A8A09D7FACA8AD96916C624B4E423D45373A33373C3636393A3A3A383635363836373839
3A393938393C38333532303534343536363737383B3D39363837363A39383637393A3B3A
3637383A3B3C3C3C3C3A393A3B3B3937363536393D3D39353634373C3A34353D36373839
383735343736363636353535343234393A363436393837363637393B3837363636373839
3C3D3E3D393532313839393938373635393735353739393838343234333132363B393735
3435353636383939393937353536363737373737
4E4D4D4F52514C484A4A4B4C4E4D4A474C4B4A4B4D4F4F4F46474A4D50504D4B45474744
46494945504A4C504A464746464B49484B474244484A494745454647444650554D4A4F52
484847454444464847464A5458514640424A4F4B474748484240414142484C46403F3F42
4546433F454749443B3D45454E6059474A4C46473F42474949484848534A403D41464849
454544434241414142444644403E3E403D4C473F3E3F413C4143423F3F42413C393A4048
484240423B42433F424B4A423842484E4539404640403B3F403E474B3841464444474640
433B3E46454444413F41464A4A4846463F473F43473F3D3C3E473D45473A3E3B3A3F4645
3E3F4341404846403F3D3B3F3C41423E44363E383A443C53434F5A4F53525752554B4A45
48464E4A474B484E4D544C4C4F4D545959484545484947534D5F595B4E5545454A474644
4550554C4841424A474B5549495156534E4C4C4D515E586158636172615F5A535A565C52
423C3843393F3E3E3A3B453E4344423E3B4440403D3B433F383E3E3D48423F484644434F
5164655F6447475D6A7779826D6E5A634F5C4F544E4549565C5E61605F6B6E71677F6E82
697C7B878AA1A1ABB5C7CDC7A5A6856275738AB19A9582A1888A857D7C879193AAAFB4A0
A794A398A598999698846B4C43483F414B4D50504D4740443C505F493947464145423C40
39424F3F4C4A4F5B695A5E5F5F74746C6B69635149423F4C4F634C53484B3B3F3D3A3539
3B383B3C373B37363C3C3A3F424242403D3C3D3E3E3E3D3C3B3C40443E3D3D41413F3F42
3E4447454344423F3D3D383C3F3D3F383939393A3B3D4041373D3B393C3B3A41383C3C3D
403F3B3D3C3D3E3C38373839393B3936383B3C3C3B39383836363C43393A413C40393D3C
373A3A35333738373A393838373737383D39383A3936363A3B36363B3E3D3A3A3B3C3D3B
38383A3D3939393A3B3C3D3E333B3D3C3F3D3C423B37383D3E38383C393E444D5D707C80
887A68646C6D727E585141393E3C343438383737373738383A38363537393A3A3A3E3C3A
3C3A373C37343B373538333837363537393A3938353637393A3A393938393735373C3B38
38393B3C3C3C3B3A363A3A383739373234393B3835363838373737373738383936373839
3A3A3A3A393B3E40413F3C3A3838383736353535363738353132383D373434393B393738
3D3A37363635333137383A3B3B3A39383534333537383736353536363635343438393938
3636383A38393938373638393233343537393B3C
514F4E4F52514E4B4B4B4C4E4F4E4D4C4C4B4B4C4E50515049494A4D4F4F4E4C47474747
494B4B494D47474946494D4D484A4643484A4D544B4B4C4D4B49494B4843454844454B4D
4E4D4C4A494A4E514846484C4D4A4747474B4C4A494B4A4848464747464B4E4842414246
4B4D4C4A494B514F484748433E48464145474548454648494848484844413F414546423E
42474A484340434744464846413F3F403E464140403B3E403D3D3D3E42454542393D4143
434343423D3E40434647454239403E403E3D44453C3E3C43433F45463D4446414043433E
413D3E4041444543424142434747433D3A433F41413D41403B433B44473C3F3B3F414343
40444E4C444A47414243444943453E3F3B3B4342464E4D69626D675346464E4C534E514E
4F4B4C46454B4D554D544D4E504C4E4F4C4444404349464A455046473C463C413D404343
454B49403B3C3F46434654513C404341404344443A4541453E423F4A454747475457635E
5547493C4439454341414D3D534643413F484544413F474546473C4741473E4743493C53
80A29EA59D8B827E93A4BEC4B7A9AD8F977C8377726560615A5048413C404A4C4C4B4349
41474D4C585A636A697DBCC1E1C9BF8C6850577A90999BA6918C7D6B6264707B859F9BB1
A6BCB2ACA29FACB5BDAE987C6E674E424445443D4645575855465B5357667781827B7D86
82856C7A647A6B7F5A62607A6E858484775F6754675B61556B6E6D637E7274634A444842
3D3D38413E3B37383E3B39403D3D3C3A39393C3F3A3B3B3A3A3A3C3D3D3B3C3E3F3D3C3F
3C4042414041403D3B3E3A3C3A363A383A3A39393B3D4042393C3B3A3C3A393B383C3B3B
403F3C3F393A3A3A393A3C3E393B3A37373A3A3937383C3F3D393A3E36353A353B373C3C
373B3D3D3C3C3B3A3A393838373738383435383D3E3B39393C38383B3E3C3B3B3A3C3D3C
39383A3D393838383A3C3F403C403D393A39393E423B37393835373E3E3F3F3F454D5150
524A3F3D423F3D433A3A373537393B3F3736363637383737373737393A3A3836393D3B39
3B39383D38363A363538353A333435383C3E3F40373737373839393937393A393B3F3F3D
3A3C3D3B38383C4035393C3D3D3D3B3830363A39383A3A39333435363738393A37383839
39393838393A3B3B3C3C3B3B39383837363635353636363535363739333132373A3A393A
3A383535373939393637393A3A3938363737363637373736323334353637373736373837
3636373937383837363638393434343536373839
4D4B49494B4B4947474849494949494A484746464849494846454445474848484D4A4A4B
4C4B4A4B4F4946433F4244404B4C49444342424649484A4E4C4645484F46434646474A49
4848484746464849454546464543464B43434242454948464644464644494B4646444343
454644424847494845484A443E3F414344434345424243444443413F4643404043454441
43484C4A443F404244464745413E3E3F3F403B4142393D4546423F4042403E3C3B40423E
3E4344423F3B3E4748423E41474A423E3F42453E393C3C43433E43434246453F3C3F403E
48484440414444444341403D4447443C434847433B3A403D3F453C44483F3F3C3F403C3E
3D414D473B42423F3F3F3E3F493F493F4C445E5758575360555D5348444349464D484B49
4947494442423E3F3E444043463F3E3A3D3F413B3E4844403F453E443C42393E38404241
43433E39444441454541433C4343413E3E4243423E434342403D3B3E4243403E43424B48
4545404243484B534D624B765D87627A606B6E6F665A554D5A4B4543423E434747523F45
668898B9B7B8A0ACB3CBD1D0DADCD2D4C2C3B6B69C9291948B7D70675853494E47434747
444337443A403B4A455B6CA5AACBAB90604E3B54505F5E6869675A4A434044504F5A7F6C
9481997E706E7B8792918C7E84795A474749483C4F53577C6E79849E98A5BAC6C0BABFC7
CDB3B790AA76817174617161717A7C877C766F7B6A765A4D5559465E678C8F917B8D8E93
836A6D686C614D3E3A3A3A3B3D3C3A3736383B3E39393A3A3B3A39373C3A3A3C3C39393B
393B3C3B3C3E3D3B393C383C3D3C403E3B3A39393B3D40423E3C3D3E3C3C3C3840423E3B
3D3B383B3D3B3A3A3B3B3B3B3A3B3B3937393A363B3C3E403D38383B3A373B383F3C403D
3A3A3B3B393636373A39383838383838353739393A3D3D3C413E3C3C3B393838393B3D3C
3A393A3B3F3D3A3837383A3B3E3F3C393938373A413B37373634373D3D3D3A3737383836
3C3C38383B3A36383C3B3D3B37373B3B3B3A393A3D3E3C3A383838393A393735383B3A38
3939393D393739363538373C3A3A3B3A393839393A393837373738393A3D3D3B3A3B3B3A
3E40413C3533383D3A3A3B3B383332343A3C3B39373736343A3A39393736353438383839
383837363938373737383A3A393838373736363637363637393936343735353738373636
3A383635373A3C3E34363839393836343838393837373737363636363635343435363737
3636363635363736363638393635353434353536
51504E4E4F4F4D4B4D4E4F4D4C4C4D4F4F4D4B4A4B4B4A494B4A48484A4C4E4F534E4C4E
4D4946484C4A4A49494F50484B4D4D4C4B4A4B4D4845484E4C434044494443484946423F
45484A4A484645454445464644434446524F4B47464645434B494A49474D514C4E4B4846
4645434249454444454D514B4742444743434541444446484947423E4A47413C3E424544
4243444545433F3C41434443403E3E3F3F403A40433A3F4847413D4042403D3D3D40413F
3E414343413C3E46463E3C3F3E413B3C3F404138414340464642494A4244423D3B3E403F
3B3D3B3B404242444241433F4C505147464748443C41494347493F4448403F3D3E3F393D
3C3C453A3E4243403F403F3F49474D5D57676F6E51515353464C424647454842453E413E
3C3E444747453F3C3A3E3C4245403D36393E3F3B3D44413A3D3F3A443E3F373B3F47443E
41403D3E48483F424642423C4244433E3C3D3E3C3F3F413D403B3C3B42443E3C3A363D3B
39423A423B40353E48454E55585D5B6352595D5E5C5A5C5D696C5B745B6857664B4F4847
414C536073768594BDBBC8C8D3CFE3D0E3C9D4C9C5BCB9B9AFA7A7A895927C826D615E4C
4E43374A444741505C61746E7D72745648434B4A473F4547484A413B4446403E39474551
43544D484C4647494C5257545F615146484F544A4F465F6E95899DA3B5C0C8C9C9CFD8DD
D9E6B2CD9AA4757D737B596F5C6A606B9295B0828D6869534C41404851607276767A9087
7F85879E9E9073524347483E42403D3A39393B3D3C3B3A3B3C3B39363D3A393B3A373739
383837383A3C3B3A3E3B33393F3E3C333C3B3A393B3D4042433C3D403D3F403944443F3A
3B39373A3D3B3A3B3D3E3B383A3A3C3B383B3C373A3A3C3F3F3C3C403D3A3D39403A3933
39393B403E3836393A393938383839393B3D3B37373B3C3A3E3D3C3B3939393A393B3D3C
3B39393A3F3E3B393737373838393A3A3B3A38373A37373A3A38383B38383838383A3A3A
3A3B3A38393B3B3C3D37393A36393B363C3A393B3E3F3D3A3B3937363738383836393939
3939393B393839373638393C38393938363536373B3A3938373737373A3B3B3937373839
393C3E3C383637393D3B3A3A38363B4346423B35323234343838393A3A3B3A3A37373838
38383737373737373738383838383837373736363A3A3A3A3A3836343A39383837363535
3B3938373738393A34353738383634333637383836363739383837373634333235363738
3837363634353636353638393736363535353636
4B4A4A4A4A4947454A4B4A484645474947454444454645444444434344474A4D524D4B4D
4C47454641404243444C4E464443444444474D504C494B504E44414545464A4E4D46403F
3E404242414142434746454546464543454442413F404346464444403D4247443D3C3C3E
414445463F3B3C3E4046473F444043444043474145444546484744413F41413E3F41413E
3E3F40434646434140414343424242433F443D3F423F434647413D40423F3D3F403F4042
413F404441404041403E3D3E44454248484243413739363C3C383E3F3F41413E3D3F4142
3F3E3F43454240404441494E656662514A4444413E45484248473D3F433F3D3F3E3F3B3E
3D40463D4645423E3E4750537163776A73647162544F4D4B484D3E43423F433D423D403E
414140404140414040413E444643433B4242403F3E3C3B3846423E453F3F3C414147433E
414142484448414142414A4D383F44413C3B3B3B4641443E443F44403E413B3E3A383E3F
393D433844393C3D444242453A3E394440424749494B4D5162645F5C5E575B6D7B7E7978
675E504C4D4C4453566F7CA2A9B5B5C7BBC5B8BBB5B3BAC0BAB9C4CDCBC0C6A8BE9AB28D
946B56414A3A4C5661766E776571635045505E7A6E846A6A7472635F758576605544473D
46404941403C3D403C3F413E4351534F4E56635E4C4D3E59618889999CA5A0989DA4ADBA
D1CFD598B67F917F8476836265564B5C7094A1A68EACA2A76F4B373B3D404140484E4147
4C54747B887C6B544345443842403E3D3C3C3C3C3D3B39393A3A38373E3B3A3B3A37373A
393736383A3B3B3B403F3B444D4D4D443C3B3A3A3B3D3F41423A3A3D3B3F403A3D3F3B38
3C3C3B3F3737383C41423F3B3B393D3D393D403A3D3C3C3E3D3A3A3D3D393C39423D3E39
383A414847413D3E393938383839393A383D3E3C3B3C393336373838393C3E3F393A3C3C
3B393939373839393A3A3A3A3636383A3A3A39373737383C3C393838373738393939393A
3B3A3936333536363E37383A383B3D3837343334373937343A3837373839383835373A3B
3A3939393739393A3937393A39393937353435373A3A3A39383735343636363737393D41
36363637393A3A3A3C3A393A38373D45413D37343335393C37373839393A3A3A35363738
383838383436383A3B39373537373737373737373C3E403D3835353737383938383A3A3A
383939383736353535353636363534333234363636363839333435363737373737373839
3939373734353535353537393737363637373839
50515151504E4C4A51504F4E4C4C4D4E494847494B4E4E4E494A4A4A4A4C4F514C494849
4A4847474F4A4846444749444D4B4D4E4C4C4D4B4948494D4A444245494C4D4F4F484447
48484746474B51554A484542444848464C4A48464342454A4D4A4A453F4347444D4C4947
464544444B47454342474A4443414546424447424443403F404243443C41444142454642
43454846434142434142444546474747414942404241444245413F40403F3F40423F4044
433E3F444143423D3B3D3F3D43433F433F363A3D3A3E3E45453F42423F40413F3F404244
3F3D444D5155554F49424D5A7A75684F4B41403D3E423E3C413F38393F3D3C403D3B3E3D
3D454A48434345474B576263696264665B605A5650443D43555C46423D3B403C433E4341
4848413F3C393C3B413F3B40403E41393A3A383F424045464744454B454240403B3F403F
4243444842444246464449443D454B47403D3D3E423B3C373B383F3B3F423B403A363839
3F403F3A3F42474A4A4F4C4B4B4D435159575F656F7B828B84917A7E656754677385858E
93938998867773544F4246504D575669606C62665D5C667278869FB2B5C7B4CEBAD9C9C1
AAA17D9A718164709C9DA18AA598A7847C74B596C6A3B29BB1ACA09EB6CAB38B6746453B
473F433838383B433D403C38354347443C404F4E4443523F4F49524C50585452595A637A
88B39FB8A0C8B1BDB2C3ACBB9E9C868A7572947A97A7D1C4B4806A4C4E373F3E433A4242
4F5D4F4D4B3D3F443B3840413D3C3B3B3C3D3D3C3C3A3836363737373F3B3A3B3A38383B
3A38383A3B3A3A3C383C3A3E3F3B3D383B3A3A3A3B3C3E3F3D3837393A3C3C383B3D3A39
3C3B3A3E39393A3E41423E3A3B393D3D383D423B3F3A37393E454F585A524E43453C3A34
3E3E3E3E3B3737383939383839393A3B393B3B3A3A3B3937393A3938393C3C3B3A3A3B3B
3A3939393737393A3A3A39383A38383835363A393C3B3A3A393837383A39393A3937383A
3D3B3D3F3C3A3B39403D3E3D3A393A3838363434353736353536383A3C3B383536373B3C
39393A38373B393B393639373C3B3A38373637383A3A3A3A393735333A383738393A3D42
3F3A34333537383739393A3A383536393836363838383A3D3A3937363534343435363738
393939393336393C3C3A373536363636363636363C3F403D37343639393B3B39383A3B3A
343638383736353537363635353434343133343536373839343536373737373739383838
3939383734353636353537393737373738393A3A
4F4F4E4D4B4A49494C4B4A4A4B4B4B4B46454546494B4C4B454748474646474948494847
484A494748434446424345434845494D4C4C4A4346464748474646484748454649444145
4444434344474C504648474343474B4B45413F4143434649464647443E41454141414243
4547494A4C48453F3B4046434543484E4B45444646454443424345464449484240464948
48484845413F40424142434446464646444B43414340413E3B3D3E3D3F43474843424342
414041434143423D3A3C3E3E3E413F42413D43433B3E3E44443E4242444342413F3F4143
4240484C4C5C614E4C424E5974665B4840393B3C41423C443D3C393A3F3D3B41423F4B45
414B4A4C454750565A636864675B65545C52544F4D4841485A573F393E3D423D433E423F
40454346443F4441413E3B403F3F453E44443E413F383C3B3B3C4347403D3B373A3B3F41
404041403E3B3B454545483A414648443F3E3D3D47404240404248454447404943404041
3843496268888E9684977B9C7CA07384686266676A6B64675E605A4C4B45464A575A525A
62727B8E9A9487806D6B594F45444543464344424540444B494A525970739D8FBEB2BEAE
AB9AA495A193A9A9AFC6ACC4ACC0B0A683989ABC9DC2A9B2BCB8B8BFCFDBC190563F3A3F
3C47413D403E3E4641494744404443423B3E494544444144394C4C584245444446434551
47568179ABBDDCCED9D0D8C8CDD1C8CCBBA4959290BFD8DFD0C2AA98614D333F383E3C4C
5D6263545D4B545F4A37393B3F3C3A393B3C3D3C3B3A3938373738393E3B393A3937383B
3A39393C3B39393C3639373A3A383C3A39393A3B3B3C3C3D3B3B3A3A3E3C37363A3D3B3A
3C3A36393E3D3D3E3F3F3C393D383C3C353B41393A3A4150657C92A1B0A49981735B4E41
4646433C3837373739393838393A3A3B3C3938383838393C3D3D3C3A3C3E3C373B3A3A39
393939393A3A3A39383736353A383A3934353A393D3C3B39383839393A38393B3A383B3F
3732373E3C383836353635373D3D39383D3B3837373738393335373A3C3C39363A383B3B
37373B39393D383A3834393636353536383B3D3E3B3A3A39383635353D39383A3B39383A
433F393534343536373A3D3D3D3E3D3C3636383A3836373B3A3837353536383937373839
39393939353638393A3938373535353636363636393B3B3A383637383A3D3D3836383938
353638373635363739383635343435363434343537383938363637373736363539373636
3838383736363736353536383737363637383939
5352504E4C4C4D4E4C4B4B4C4F50504F4D4B4A4A4B4C4C4B47494B4A48464647494B4A46
474A49444743484F4C484847524B4A4B494C4D4647494A4A4A4C4F50494844454C484346
42444545454445463E45494644474B4D4E464042464644454345494945484B4742434445
4647484947474A47424346413F3C44505043414A3D404444423F3E3D464C4A423E414341
44403C3D414445453F3F404142434242464B4343443E3D3C3E42423E3C40434342464540
3E4244424242413F3C3B3D3F3A413F3E3E3C3E363F403D41413D4446494744413E3D3F42
43444D4B4C6771564B424E50604C4B44413D4040443F37453F3F3F3F423F3A414F4C5F56
4D52494C47484E5253595D585850534749463D3E41433B39423F3B473F3D433F453F4240
3A413E413E383E3B3B39373E3D3F48423E423D3F3E393F3B3F3E43433C3C403E413D4042
3D3C3E39433D3B3E3536433C43444340414546454D484A4C4B50565351544E5953514F50
4E546D7A8D96A198A192AC8EB295967A6F5D5347444540463E4242424045413B453C4450
3C444E4C49484A51525056495149483D443D43404940434D50515455535351555C7D788F
7884889F92A9B0BFC7CBC7C0C7ABAA8FA092A793BAA9BEA7ADA8B1BBC2C7AF816C57604C
4842463E3F3E404F5163676846423E4343474F4758424440403D3A3D41414142464B4941
3F3F4B5D71B4CDCDCAD3D1D4C8D4D0D5CCB0AC9EAFBAD1D9DDCFD7B8AE81624A3C3C3F3F
47565D6175697A86684B423B44413C3A3B3C3D3D3B3C3D3C3A393B3C3D3A38393937383B
3A393A3D3B37383C3F3D35373937393338393A3B3C3C3B3B3C413F3F433F36373539393A
3E3C383A3C3B3B3C3E3F3F3F3E383B3A33383F36464F64819EB6C8D4D4CBC1AA98796655
474F5453514F4A4339393839393A3B3B3A37393D3C373537383A3A3B3F44423D3C3B3938
3939393A393838373738383934343B3D37373A3838393A3B3B3B3B3A3836373939373A3F
3F3639403C3635343A393339494B3F393C3B38353435363836353537393B3B3A3D393B3A
34363C3A3B3E3739363239373A373534353637363C3B393736363636363334393B393737
3A3B3C3A3837393B3C3E3C3736383733363536383634393F44413D393736363739393939
3939383737373636363738393535353535353636363636383939383635393A3636393C3B
38393937353435373B3936343334363737363536383A39383132343638393A3A39373535
3637373637373736353536383737363636363737
5055535053514F535050504F4D4C4C4C4C4B4A4B4C4C4B4A474948494A45444C4C4D4D4B
49494A4C444D504A474A4A45594F46464849494A46464747484848484C46434548464443
42464745474C4D4A45464D454247454A3F4446433F4041413D4644404546444743444647
4746454443424141434444423D3E40424342414042403F41424041433F44443D383B4042
41454441403E414B4B3D47473C3E40434045434144423F423B3C4140393D434042424140
4346423C3D43433D3D434541453F3A3B3E41474D4A4846423E4348454D44493D463B4A4F
42484842434A4A443B4647413F3C3B413D3D3B3C4040434D46413B3D403B455E626F635A
4F4A3D444440424B4F4B494B47444741443E423F3D413D41403A403E3B4043403D3F4244
383841463E3B3E3D4041434342403E3C42404043423F3E3F353A3E3E3C3B3D403E3F3E3D
4045433E40373F3C393F3B3A3B3E413F3D3D414548404F54948B965D666475657C78816A
6A7E79928997998B7676738F869F98A1939B84816D6A58514D535255545E4A4942473E42
484545423B3E4C3D3B3C43453D3E4040414345464037435F8BAFB1B0BDA3967565668890
91A4BAA8BAB9C1CFD3D0CDD3C2B69BBAB6C2A7B2A4C0BCB89B989A949F9C978A8D819B89
A88287725E654E5855635C56503F45474354484D434748534C4B444A45403F4B4F4F5550
4B45404B7672A09AA29DADB9BFB0AFAC9D9491888DA2B8D2DAD8CFD2C6C59C704A503D43
433E524C717592847E6F5C5A495545483C403B41433E3D3A3D3A3937363940383C474344
3B3D413E3D3E3A3635393E3E3B39393B33363D3D383A3D393638393B3A393736353A3D3C
3735393D383C3E3D3E403F3C393A3B3B393A444E464D6C8B9194958C817D756A60585351
505B777E6F5843473F3E363B403F413B323E4240403D38373738343843423A3838383737
383A3B3C3B3C39353537383637383939393838373634363D413F3D3E38383C413F39383A
35383D413C35353A3538383F474138393633373A37393D393A363234393E3E3C38393736
393E3C373A3938393A39383630323435353536383436393631353B383F3B37383B3C3834
36373838363636383235373633353C4336393B3935353A3F373737373738383935343332
333536373537393B3B393735343333363735353734363835393B3B34353B4143403B3736
353535353637373733333839343438383334373838363432343835343837353834343536
393A38363733313536343435363637383839393A
494D4C4C4E4A474C4747464648494A4B4B4A49494A4A4947454847484A45434A4C4A4744
44464A4D4548474447535E62554D45454747474742434445454443434743424547444241
424244464746454644454C46444A474A4146474441424444404545414242414143444546
464544433F3F3F41444647463E3F404142424242423F3F41403E3D403E40414142423F3B
3D464540414344474A3F4243464B454443464341444340443B3C41403D43494743434241
4244413C3C414442424545413E3B3D444A4E5256494646454650585759586155584A5355
4F4B44404143423F39403F3B3D3E3F423B3D3C3E413F3F46414241424447505E4E58504B
44443D43443E3D424441434840414840413A4042444842423E3A3D3A3C4143403D3F4041
3A373A3E3E3D40423C3D3F43444342424240414343403F413D3E3F3F3E3E3F413C434845
403F3E3D3F373E3D3C4240403D3D3D3F3F3D3C3C4652649CA9A473484556526D577D6D71
7C7E927E8E6B8976776D85778B85918382867782858A7D75778775957CA188957A816D6F
544C383C383B443C443F3B3F4342403F3F4142423F3942527398ACBAC6C8B4C09BB4B5C4
C3C6D4C8CFD1D8DCD9DADCDACFCFBCD0C9C0C6A3B3929D7F7C757167696365616872708F
829B8E9D989D909E95988D896E6978847C7E604B4E3843495B515C554C49475052535B56
535F5B62585A6975666D8197ABA6927C787E8575727C97B8B5B4C3CADACEBFA48C816255
4A3F4946505E6F8E869A8998939484726A584F443839393F3C433A3D3D3C40383843413F
393C3D393638393A373B3E3E3B393838383A3F3E38383B363B3B3C3B3A38373734373A3A
39393B3D3D40403D3C3C3B373E3E3F3F3C3B3F4645414A5454555854484644424140403F
4F5261615342353B3A3A34393D3D413C363E3E39393836383E43403C41423C393A393838
393B3E3F3A3B3A37373A3B393637393A393938393635373C3F3D3B3C3A3A3B3D3C393839
3636383B3C3B3B3C383634373C3A383B3734383936373B393838383838393A3A3B3C3936
37393834373635373B3E3F3E353637363637393B3B393A3835393C36363738393B3B3B3C
3B3B3B393737383A3C3E3F3C38373A3E373A3B393635383B383838373736363638383737
3637383A3B3A3A39393A3A3B363333363737393D2E383C46424C4C5155534E453D383636
373738383737383936333638363739353536383939383635353835323534313532343739
3835353736343438393635363737373838393939
4F505153544E4C514D4A4848494B4B4A504E4D4D4D4D4C4A4D504F50534F4C50524F4B48
48494B4C4C4B49484A4F5458514A454647464444494B4D4E4E4C4A484746474B4B474546
4845484D4D47454749494C48464844434447484442454748454648464343454242434445
454443424241414344444343424241414142424347454445454241434745464848443F3D
3B474740424745434244453F3E4241454443403E404040433D3D3F3F3E44494740424341
4142413E3D3F4143454645443E3D3F44494A4B4D494442403F4549454F50574C50444842
4C433C3E424341404044423F434441404446444346434248414546403A3D413E3C413D3C
383D3C3E413D3C3F3E3B3D434645494040383D3D404643403E3F433F3C4043403E3E3F3D
47423C3C3E3D3C40403E3F43433F3D3F46434242413D3C3D413F3D3D3D3E3F413D434745
40404244443E41403E42403F413E3E4141404246706CA1AAC8916F3E45404C474A4D473F
46504C5748454E5151504A594460535452544A5257544E4B59556B5D7C6A8379867E7F6A
6B4F443F3C3D4344574B3E4547434141424241403C3B40434A565D668F899F879F8BA7A6
A6A0A9A8A3ABB4B4CACED5CAC9D3CDD1CED3C1CEADB096888373665B5B534C454745444E
4B616273757974867F8280889BA8BBCECACBAA88704637434249524F4E4A424449597175
80676C415846574F4E575D6A7A8A7D68657783685F647C928992ACC1D9D1CDC9CEC0A380
6A65625D5C546B729692AAB1BDC2C1ADAF96907B6F6261454A3E3F373B383F3D3B44443C
4144403A383737353A3B3D3D3C3A38363A3B403E37383B363F3F3F3D3A3838393B3B3C3B
3938393A3F403F3C3A3A3836403F4042413D3D3F46403D3E3C3A39383B3A3B3D41444544
403F46443E39353C373934383A393D3A3D423F3A3A39393C3B423F36363A38363637393B
3C3C3B3A383A3B393A3D3E3C35383B3B3A3939393637393C3B39383A3C3C3B3938393835
3B3936373B3E3C373E383739383A3E403836383834353838373A3D3B3734353837393937
3638393A3E3A37373A3D3D3C3838383736373A3C403B3939383B3B3431363B3B3A393C40
3E3D3B3936363839393A3B3A3736373838393A3936363638393939383735333238393A39
373638393A3A393838393A3A3835333637393D413E475F5F675961625852483D36333436
393A3B3B3938393A39343437373A39333435363737373737343735353839383B3837383A
3935363B37363738373434363737383838383838
4D4B4C4F4F49494E54504D4D4E4F4D4A4B4A484848484645464A494A4E4B464847464545
464645434343444747464444474343474B4B4B4C4547494B4B4845424040424544414143
44424447474341423F404345484A47464447474443464849444247494344484342424343
434242413E3D3F4345454648464542414040424243403F403F3D3E40423F3F3F3B373B41
3F474641444643413F444743444C4E4B433F3B3A3B3B3D41403F3D3B3C40423F3D404240
3F424342403E3D3F414446484542403F403F3E3E433E3F41414545404844433A44424237
3E3B3A3F444543423F4447474847423D4445413E41403F4445474B463D40423940424241
3F4343403D3D4144413C3C404943423C444145423B41413C3C4347443B3F413F3E3F3E3C
4E4D4440423D3A40433F3F43413B393B3F3C3D3F4140424541403F3E3D3E434949443E3C
40454747464242404041403F383A404543404650647C7CAD90AF857F5C4B50434644433F
3F3D3E3B453D4A4445383A433747414746484044463D3E413E453C51434A43404447494A
4B51454A4541464A5C4B3C464A454245484744423D3E424445433C393B4B4053475E596D
56535B635660696D7E808B7D838E908A9D8FB1A0C7ADC9B4BAAE9E918C806E5D5F4E5440
4C46484651564B514F575E75A1BFCAD6D5D6C3AA8E613E49445553504C4A41414A648894
A8917A4F434545474A5C66624E5A615E595E6756535261646A838DADB1BEB1B9C5C6BC9C
96A696818176616E7484929EA5B4BDB6B9ACAA9A9194817665634C3539323739353D4035
383D37373D3C39333B3B3B3B3C3B393638393D3B373A3D39383A3A38363536373E3F3F3C
38383B3E3C3C3C3A3A3A3A393D3C3D41423F3D3D3F3E3C3D403E39373B39383A3E403E3C
3F3E403F3C383536393B363838353937363B393738363437353B3D3C3C3C383436363737
38373737373A3C3A3A3C3D3C36393C3C3A38383936393B3B393636383D3E3B3737393732
373736353A403F3A3833373934373C39373738363434383A393B3D3B3633343634383B3A
38383A3D423E39383A3A383638383836353537393D3838393638393434383C3C3A383A3D
3B3B3A383534343537373636353534343838383838373636383939393835333134373938
3533343634363738383736343936353738393C41404E546553534952423E393432323435
393B3D3B3837383B39353639373839343232323334343535353636353635343439333033
34313337333435363536383B3838383737373737
524F4F514E4C4E514E4B4A4B4E4F4D4A514F4E4D4E4D4C4A484B49494E4D48474646484A
4D4E4D4B494746474848494B4C494A4C4C49484946474A4B4B494643474648494845464A
484B4B49494C4B494444454B4E4E4C4A4446454242454747434045484342454242424242
4241404046434344433F3E4149474441403F40414845434545444548474240403F3F464F
4547434144433F42443D3B3D44545745443D393B3B3B3D4041413D3A3B3E3D3A3E424340
3E3F41403F3D3C3D3F414447444341404041403F403B3D4244484B484944413A4445453C
3B3F414040414140373D4445434343404043403E41413E40414145443C3C3F3A3A3B3D3B
3B3C3B363A3D4245423E3E405048453C413D413E3D42423A3940413F3A3D3E3E3F41403C
44484644443F3D463F3D3F43444141444A464343413F3F42404042423F3E475253473B39
3F44444241413E3E40414242383D464B4945474D5B57825C8D6F977B8E7D7E655C4E5455
504D50445B576457685451473D44404A43443D4347404042453F42424E3C4136404D5049
404B444C453E45485447424E534A44464949484845433F3F40403F3D393F413941393B41
3C4141493E42424643424B41494C4F494B524B7061847A848084827D7B7F7A7274736672
6170575848554C4C56667291B1D9D9D8D2CEC4BDAC8A766B7C70675556564F4B4853686B
8787825D473C3C3E3B567575473E45474A434F5149435253506968797790878E94948F7C
8FB5AE98A69B7976707A8182868E868A858F908A7F7D7761796C7550483D3B3A33394136
37403839403C3B353A39393A3C3C3A3837373B3A363A3E3A38393A3A3A3A3B3D3A3D3F3C
393A42493A39393A3A3A3A3B3D39393D3F3E3C3C3E3D39383B3C39373C3A393B3E403E3C
393D3E3F3F3D3B36393C383938353A38373A38373A38363B3D3735383A39393A3C3A3734
33353739373B3C3A383A3B39393B3C3C3A383737373A3D3B373536373D3E3C38383A3732
383C3C38383B3A373734383935373B37363736353536383B3B3A393837373636383B3E3E
3A3737393A3836373A3B3937383939393737373838363A3B36363A3938393A3A3A3A3939
393A3B3A37353434403E3B39383737363736363738393837373738393837353334363837
343234363536373737373635393636383938393B3D3741373F303B3E3938363535353636
383A3C3A3736373A37363A3B353537363232323233343536353536373736363537363739
363234382E32373A3C3E40413837373737373737
4E4C4C4B47494D4D4E4C4A4A4C4C4B494B4A484849484746454845454B4B454347464444
444545454747464342434444504E4E4F4B454243414243444443414043424243423F4145
424646424347484442423F44443F3E3A434544414144454448474A4C4845454542424241
41404040423E3F42423F41464746444241404040413E3E41413F404247413B3C3F414242
4746424043403E434140434547607F80473E3C40403F404140433F3C3F413E3D4144443F
3C3D3E3D3B3E40403F4042423E4041414244423E443C3B3D3D4146454242433F413F413E
3F4444403D3F42433F4145423D4045443F44444347453F3D4B494A473F3A3B3C3E424541
4643423E3B3C3E3E3C3C3E424341443C3E3A43463E3F423B393E3C3D3B3D3D3D3F43413D
3B3F4243413C3D453E404143454748484B474445444345493B3C3E403B39414D4A433D3E
4141414142443D3D403E4040454342434445454344514C5D4C605F61666F677E65756A70
5C5D6B5779758D8596898B68645A4A4A484F464A453F3C3F49423D3E4B4042443F495042
4546484A4640443D443E42515C4F44434545464A545854534E4748463C3F4139423B3E42
454D434946463F3E403E423D4541423F403F42474A534F534E514C4B49545657545D5368
627A737865706C677077788FAACCC8C5C0C2C4CDC5C5BDB6BAAA9A9B9999938C807B8380
918FA583936F735A4748585E443B3F3D4341424741454B403A4648464E5F6B707473685E
6E8C968EABA098849486978A9082606560797E7C726C524F54575743484340423D3D4239
3D483B3A3F393A373A39393A3C3C3B393A393B3A373C403C3C3B3A3A3B3D3E3F3B3E403E
3A3A41483B39393B3B39393A3F3A373A3C3A39393E3D3C3B3B3C3A353C3A393A3C3D3C3B
3A403D3B39383932363A36393A383D3C3F3F3B3B3E3D3E4442353339393637393B3B3C3D
3C3A3837373B3C39363739383B3A3A3A39383736373B3D3B373738383D3D3C3A393A3836
383C3D3A373739393C3B3A39383C3E3C363735343738373A3C3A3737393A393739393B3D
3C39383A3535363739393938393B3C3C3B3A3A3A38373C3F39383C3D3A3836383B3D3C3A
393B3D3D3B3938383E3D3B3A3A3A3B3B3737363738393939373738393838373637393A39
373637393B3938363638393B3937383A3A3736373C3B31392F39343B3938373636363839
373839393636373837373B3B3433363535353535353637373633353635363937383E4442
3A353639383D424342413D3A3737373737373737
515153504B50544F504E4B4A4A4B4C4D4E4D4C4C4D4D4C4B4C4F4A4950524C494C4C4B4A
484747474A50524E4C4E4E4C4444474B4A47474A48484747474848494746464847434346
45474848484848464446434A4C464946434544424244444247494A4C4D47454843434241
4040404045403F42403B3D44424343434342414042424448484441414845424144474540
4246423E414140433D4749453B496D7C483E3E44434141413F44423E42423F3E4143423E
3C3E3E3D3C4245403D3F42413E3F3F3D3E413F3C443D3E413F40454541414241403D4044
4543434342414245484645423D4145413E43403D41413B393D42423D3936373C3A41433C
474241423C3C3C3A383A3E414243484040393F413C3B403C3B3F3C403E3E3D3C3F43413C
3F3C3E403D3B3E403E424340404444404B47434342404246403C3C3E3C383B43403E3E41
413F3F4145483E3D403C3E3D4243403D414746404539523E53455751595C6360634E523E
404F415146656071728885977D9157644E584C524F595D6571745B6858614C665162536D
596B5A6651514C384443485A564B4344444141453F4A4F56534B4E4A4144393F353F3941
414A41414143423E3E413E3C443E3C3F353C3E424A564D574A463E413A3B393F3B3B3D39
50485A4C5F5B5C5A5856505C62706E75737D8690879A97A69F9E95B0BBBBBBC0BBBBC7C9
C8D0D2D4CAC5AFA37D67574D453B3D3E48504349434A47424645495251586675767E716F
737981728488798F889F9FA9907453535B6B757068525B556B52524A44443E403D3B403C
3A43333A4B4949403B3A3A3A3B3B3A393A393B3B394045413F3A3533343739393E3F3F3E
3C3C3C3C3A393A3C3C39383A3F3A37393B39383838373D3F3B3E3F364442403E3E3E3E3D
323C39373638403A363835383A393E3C3B3B37383C39383E3A373F47433D3934373A3E41
413E3936383C3C3835373A3A3B383637393A3938373C3D3A38393A3A3E3C3B3B3A393A3D
35353638393A3E42393A3734373B3938383935353A3A36373A39393A3B3B393839353539
3B3A3A3B37373837363637383A3B3B3B3A3A3B3C3935393E3B3A3C3C3A383737393B3C3C
383A3C3C3B3A3A3B3637383838393A3A393938373738393A39393938383837373A3A3939
38393A3C3B3A383636383A3B3A38393B3B3736373A383B343A353833363737363535373A
36373737373738383936393934343532353636363636363638333435343A4141484B4840
3D3E3C384A4A47413D3B38333536363637373838
484B4F4A444B4E4649484645464B50544B4A494A4B4B4A4946484340484B46413F43484A
4A494949484E4E443F424440444547494641414444434141414345464543444746424041
434143484842404241423E45453E424043454543434544413C41414448433F4643434241
40404040423D3C403F3C40483E404244444442413E3F444948423C3A383C3E3C3E444645
3C45443C3F44434240474142413F4542463B3D444340403E3F45433F42403B3B3D3F3F3C
3D4142414047473D393E434443433E3A3B414342423E4246413C3B39423C393C3D3E4147
4B4443494A423D40433E3E3E3D42443C484A423C3F4240403E4948403E3D3D4339424339
474141443C3D3D3B393A3D3F41404642474144413F3B413E3D3F393F41403D3C3F42403B
443B3B3E3B3E4342393F3F3A3A40403A3F3C3A3C3E4044494C444144443F3D40433F3E40
403C3A3B42473B3D423E42423C495355575B564C4F4D4D56425C495146524E5249425047
464145364943525A8085988B9884606A535843525F808B938F9383857C7C6B8C7385839C
908C899896967D525449404E4942414748423E3F3E44414646434B494341433D403B3E3C
3D49433E3A3C46423C433C3A433F3C423E41473448423D423A3C404D3F3634443A40414D
665C60444D393F423B383840413D3D4A444C4B4A4B4B5054624E4E6071737885888A999D
A8AAC9BCCFC2C9C4B5AA977763413942537578805D48578A686462866A706E8B92977A79
83888D6C6B606467797E94A2A1867B7D9599ABA28A646A6A786C708A5C58453F3D3C494D
4E513D4C69695F4B3C3C3B3B3A39393838373A3B3C454B484D463C38393C3E3F3B39393C
40403C373837393D3E3B3A3C3D39373A3B3A393A3D393F403940483F3C3B393736363738
3844403B37363D36383A353839383C393839393D403A353836363B3A34353A393B3A3838
393B3D3E383C3D3835383B3C3A363334393C3B3A383C3D3A393B3C3B403C3A3B3A383C43
453E393837343538393F3B383F413A383A3B36353C3A3435383A3C3D3C3A38383E373335
383736373637383635363A3D393938373637393C3A32343A3A3939363B3B393837383A3D
3537383838383A3B38393B3A383635353B3B3A383636383A3A3A3938383838383A393737
38393B3C36373737373737363B39393B3B383839363936343137373636393B3A37343536
37373737383939383B3636373636352F3434343534343333353137404858696E6C625146
4B545145504C4137343738373535363637383838
4B4E514F4C4A4C4F50494D4B4A4C48514F4B494B4C4B4B4D4D4A4847484848474D4E4849
49464B494F4D4649474348494B4D4D48474846424545484C4A474A504B49444D484B4447
4243434345494B4B4245474848494A4C4247444147494644403F3E414446444140424444
424040413D3E4041414140403E3D42444143494941484544403E444244413C4142454B44
40424044423B42453E3C45423E3F3D48413F3E4241473C4942443F3D41413F443B3B3E42
433F3C3D3B3F4446423E3E3F43454241423F404A464349433C3B3A453B40464846454546
424345464645413D443B3B3B3E413E433E44403C41423E3E3B3F4445423F41453E3D4141
3B3E45483A3F4445423E3A3D3C4340393A3D3F423C3E3F3E3D3C3D3D45403E40403E3C3D
40383D3D40423D43413D3B3C41444340363C3F3C3B3E4140413D3D4244413D3B3942433F
3D38373F394D43464A404A54475D687C7B6862524C44484A504241414443454744404248
3F4443424240475869798789808786908275636572829598947D7F656C4E59535A535E58
72788A9CC3C8B6764E424B4A4A444042444240403E40393E42493C3F41443D333A3D4045
445B4E5D50535A66554B5254585440495045453E42413D3B35414546413D413B442F464A
5D565E524951413A383C3741433E3F3C344041404241393F4745497596969896909A8D8D
7F86817677767A837E81857C6756403C43618F93B7908695BE9798A6A67B8394AAA28986
979D9191765C4971504D647D78937487A0B3C5CEB78FA79BAF919B7E96626B56463A4142
463D44616F6D624340423D3838383C44333C413C36383F433D373A3E3C3C403F38393C40
3F3B3B3F383B3C39393C3E3E3D37373836393B373B403B3D3B3A45473B393A3E3F3C3939
3B3E3F3E3A393C3F3B3C35343F423C383838393939393A3A3B3938393B3B383536383B3C
3C3B3B3B3C3D3D3A36363A3E3D3834363C403F3D3C3D3A3534383A393A3B3D3F40403D3A
3E3B3A3C3B39393B363937373C3A3638383B3E3E3C3A3A3B38393B3A3937373732343636
3535363838383836343537383536373736373A3C3634343737363A3F41413A3539383639
383838393A3A3B3C3235383A3A39383734373B3A332F3640373838393A3B3C3C36383A3A
383737383838383939383838313435343538393635353535363637373737373737373737
39373433353637363533383338333837363D383439342D32333950606D9088896759504C
494B4A423C3A3734333334343536363637373838
4C4E504F4D4B4C4D524A4B4A4B4D484C56524E4E4D4946474D4B4847474848484D4D4646
46454C4B4A49434746424747454A4D4B4645474940414344424042464645424A46474143
43414347474341434745434040434A4E42443F3D43454343404243444443434348474643
413F3F3F414040403F3F40403B3C4245434549473F4748494743453F403E3C41403F443C
383E3F4440393B393F3D454341413F483E3F3D403E44394340423E3F45443D3D3C3C3E41
413E3D3F42484B473F3C3F42403F3B3E4545444A4841454649473C3B3B3F4242403E3F40
4643403D3B3C404443404644413F3C423940403C3C3C3B3C3B3F43423F3E4042403F4445
3F3F403D3F4243433F3D403E3E423F3B3C3D3E42434443403E3D3E3F43414040403E3C39
3B363B3B3D3E3A3F3D3B3B3D40403C373C3D3E3F41444441403C3C4143413D3C3E413F40
4646434646524C4F4B4553546B7C7C7F6F56514546404443473C3C3B444545433D38393D
3B3F3D3B3D4047545C5B6E6067636C6B61605B61686D77777C767C53593E504D63687273
7F7E828B8F8A7C594F47463F4A4745423E3B3D4240403D413B403C3C4043444743474645
4A5D52645D5F616653505A5E6A7178A08C9687986E7A525740434A5553566564715B695C
6553595249575355525142443E3842363E3E423E4544403E41475C8EA9A9ADB6BCCDC6C8
BCB6C3AAB098A396938884685D4E4845434154739DC6B8D1C7C7C5BFA3A19DB1ACA08088
ADABB0999F72563A614A3B52516268788990ADC1B0B2A6C8BCD3B4BB9AA474645F654F44
3D3B414E4F47433C3B3D39373B3A383B383B3C3A393B3E3F3C383C403C3B3D3D3E3E4045
45413F4034383A393A3E40403B37383A393D413F3B3E393B3B3A43443C39393D3E3C3A3B
3B3C3D3C3A393A3C383C38353A3B37373939393A3A3A3A3A3235383A393837373D3C3A38
36373B3E373A3D3D3A3837373C3836383D3F3D3A393A383536393B3A3B3B3C3D3E3D3B38
363536393A38383A363835353B3B393B383A3B3C3B3A393938393B3B3A38383934353636
36363737373738373636383A343638383838393B3634353839383C413C3D383538373539
323437393B3B3B3A35363738393939393A39393A37333539363737373738383837383939
393837373838373636373838333536353538393634353535363738383737373737373737
3332323437393938303037363B3536333139353238383843515A7F8392877F6A5046403E
3C3E3E3739383736353434333636363737383838
53535352504D4A4958504E4D50524C4D4E4A4849484644454D4B4847474849484A4F4D52
524E504B47474347474348484A4B4D4C4844444745484845424345464848474D4A4A4545
413D3F47494343494D4B48464545484B4C4B46454A48434442454746424142454B494542
404041414543403E3E3F40413F3F4548454445413F47474A4946463F44434144403E433C
39414246433F413C423F4444434341474448454441483E434746414248453D383E3D3E40
3F3C3E4240494B443E40474D403E3C3E45464447493E3C3E44463C3A404243413E3C3D3F
4643403F3C393D4446444A46423F3A3F3F4246433D3E4242404546424144454243404345
42413F3842443F403B3F4C423F413E3D403E3D424041403F3E3F42444442403D3D3D3B3A
39373B3B3B3C393E3D3C3C3D3E3C38343F3B3B4046474440413E3F424543403F43464545
4748484B4B5051554C4E5F56696959534A3F443F4341453F413A3C39444849443F3F4143
46463F39393C3F434F4A434636484143484C484B4E50595A75877A5B464D566473807E7E
71675B59655D555160564A3D443F3D3F4140404145434346393A3D3A4439443A3F384944
374439494649474747454542494A5788C6BCCDB1B78F7C6259544D5150505F666E6D6B77
656C5C65526468747B837B808177916980585E4F615B6051524552686669708491ABB4C3
C4DDD3DDD8DDC4CEC3C4BCBBABB29F9D8B7D63526D98CCD6DCCFE4BAA499CBB4A0928A8E
92AEA0A98B724D47487D6D876E7C688B747192A1A196B5AAC8C9DBCECEACBC827B738654
423F3D3A3A3A3A413D3D38373C3B35353D3836393C3D3C3B3A393D413D393B3B3E3C3D41
43403B393A3E3E3B393A3A383B383A3A36383C3A393A363838393F3F3E3A393B3C3B3B3D
3B3B3B3A39383838363C3C37353534363A3A3A3B3B3B3B3B3A3F434039343335403E3A36
34363B3F3A3A3A39383838383A39383B3E3F3B373839393737393A393B3A3A3A3B3A3837
363434373938393C39393635393A393C3939393A3B3B393738393B3B3A39393A37363636
37373736353739393838393A3436383939393939363637393A3A3E423739373537363538
3D3F4142413D39363837363637383A3A3D3835393B393534373737373636363639393839
393837363937363535363739353737363638393734353536363737383838383838383838
3937363536373737323338373B36353231383533393D43517079818776624F3D403A3939
383A3A3636373838383634333737373738383838
4E4E505356565452504C4A4A4B4B49494F4B494B4D4C4D4F4C4A4847484949494A4C484B
4B4A4F4D4849454A4A454948484343494D4C4A4B45494842404345444444454746464443
4440404345464C52514F4D4C49454445454644474C494345444545434141434647444141
424445444543403F3F41424244424649464645404247424343434742484744453F3D4541
3E45434344454C484541414243424347454C45433F463E404A47444346464240403E3E3F
3D3B3F443C45464040454B504445444342404043453F3B3B3B3C3D414747464340404144
49444244433F3F43494344403F413B3D48454847404248464247474141464741443E3E41
4244433C40423B3F3B4357463F3F3E41443F3B403A3B3B3B3C3D404346403C3C3B3A3C40
3E3D3E3D3C3C3E4142403D3C3B3B3A3A3D3939414644403F44434142413F3B384B4C4B4B
4B4C4D4F484C4F524A4E5B4F4F4C3E3D3D3A403B4546493F413D413D3E43443F3C404547
44433E3A3E4547444338413D3E41433D424841434D57676E88958B564D3D45474F5B4B4F
3F494E546F6D6766725D4C3F3E3B3B4045423D3A393C3E44404148463B3941463F3D3F3C
3E4337413D41403F46403C383B383751637575907A91767D61614C434337353D3F463F52
3D4C36443E4A4A52566260676E847F957E9177887D9078A976A37E978B9094998C89848E
A19DC6BDE0D1EAD7E3D7D8C0C9C4C5BCA8B6A2B67A738FBEC5DDD2E69CA7CEC3A9B3A599
8D74A5A29E6649394C7DB0B0B8969795A19AA8A893AC9D9EA0D1C5DACCD0C1C79CAD7F85
4F46443A3A403D3F43423B383A3936383F38353A3D3C393938393D3F3C383A3D3F3B393C
3F3F3935383C3E3D3C3D3E3C3B3A3E3D363537353C3B38393B3C3E3E413C393A3B3A3A3D
3D3B3A3A3A3A3836373D3D39353536373B3B3B3B3C3C3C3C3A3E403F3A3637393B3B3A39
38393B3E3B3A3838393A3B3A3A393A3B3D3D3A373B3B3A39383736353A39383839393837
3D39373838393C413C3B3938393938383B3938393C3C3A37363839393938393A39383637
3839373636383B3B3A393939363738393939393A37383939393A3C3F3538383736353638
37393C3F3F3C39373938373738393A3A3B3532363B3A373639393939383838383A393838
393937353938373636373839383838383839393936363737373636363838383838383838
403D3935343537383A38373536353635393D3A3A41454A536F6B5D6149463C3A3B3A3B3C
3C3B3B3935363738383735343838383838383838
5352525354524E4B4A4D4D4C4A494B4C4E494545454445484B4A4848494A4949494B4648
49484E4D494A464B4A4447464E4744494D4A464546494843424647464445454444444645
494A47403E44494A4F4A47474542424546484545484642444744403F4144454541404042
444646454342404042444443464244474648494441443E3E3F404743434442453F3D4440
3F44403E3F424A4746423E3F4040434649504544404642444041434443444647413E3D3E
3D3C3F444046433F434543444545464442424342444341413E3C41474645434140404244
4C454042444342434441444041443F4049403F403D4145423E42423C3C42423C433C3D41
4346453E3F413B403D4457453D3E3D4348413B3D3A3C3D3C3B3B3B3C443B3A4141393B44
4243403D3B3C4042413F3D3D3D3D3D3D3B3A3D42433F3E413E3F4245494C4D4C524B474B
5256544F44494A4945444640414340403E3D43454244473C3F3D423E4345433B393D4142
3D3D3C3D434C4D48483E463F3F414748475555596470818C8D9C85775F5A3F3E3A463A41
333E434550534F4B524341383B3C414544414042383F3B3D423C3F3D403D4640473F4643
40423B40393C3E3E4039393A3E423D3D3D414947474E4A4C49564E4D55514D4E4E444A3D
463D3D3E3A423E403D4541464847544A5B5354575A596A6B747B878D929CA0ABA09E9EA7
9AB4A9BEC5DAC8D9D9DBD3D4C1C4A8A2B0A2C2A9BDA6A19DC3CFCCC1E5C4CAA9A09CA398
78939EC1A47A5254596F89B2AAAD8FADADB4C5BDA894B68296A7D6C1D1C5DACBD1A1AA75
544041413C3F3E3F3F423F3B3B38373C3E3A3A3D3C39383B38393B3D3C393B4145413D3D
4143403B3B3F403E3D3F3F3D3B3C42433C3B3D3B3F3C3C3B3E403F3E443E3B3B3B39393B
3E3C3B3B3C3C39363B3C3D3A393B3C393B3B3B3B3C3C3C3C3B3A37363535343436373939
3A3B3E4038383A3D403F3B383B3A3A3A3B3A3A393B3B3A3B3A38373638373637383A3A3A
3E3A393B3B3B3E423C3A3A3B3A3A39363D3A383A3D3E3B38363738383737383A3A393738
393A3837393B3D3D3B38373739383838393A3A3B383A3A393838393A38393A3A37363737
37383A3B3B3B3A39393838393A3B3A38393532353736363838383838393939393A393737
3839383639393939393939393A3938383839393B38383838373634343838383838383838
39383735353638393A38353636383838404242464F5352545B47483C41373E3C373A3B3B
3A37353536373737373737363838383838383838
4E4D4E4F51504D4B4C5353524E4C5252554F4B4B4B494A4D4A49494A4B4B4A48474B484C
4D4A4E4B4747434848424544454445494B4B4B4C474847454547484847484A4447464A49
454B4A413E42433F4744454A4B474446484D49424446464A484440404346464541414345
4646454443414042454644434D474546444646403D423F3F3F4046424043454A45424741
42464141403F444046433C3F3F3D43454B5246484549474A3D3F4446403E3F3E413E3D3E
3F3E3F424145414148453D3E443F3E40444A4B4447443D3E3D3B42463E3D3C3C3C3D3E3F
444240424545413C3C424C4944454143483F3B3D3F41413F3E41413E3E42413D403C4045
4646433B41423D413E424D413D3E3D4147433B3A3A3C3E3E3E3D3E3F3E3A3D47473D3C43
44463F3C3A3A403E3C3C3D3F42413E3C3B3E4244413E3F4345474847494B4B494B454346
484B4A453C424241423D3B3D3F3F3D3D3D3E41423C3C3F363B3A403C4544403C3B3E4040
423F3F41434747404144424C42514D5C64787A7A80859099A69A9578815D50413F424045
3F444644494A433E433E4D4549444242413E3D3F343D373943393F3D393C3F3F3E403E39
3F4040433C3E403F443F403E3B41413A403D3F383C433E393C424042444950484B40483E
4640413D444841413C4444474A43494D5E5F55515349574854484B454F54515F606A7279
9489A290ACA1BDB0BDB8C4BBC7C3C7C7C0B8B1B5ABA79FB7B2CDB8AF99B286885E666064
6C689FA0A6727574B3A3837D8E8A97869EA9BFC6A2A19D8B7FABB1BEA3C4A1AB9BC2AEAB
744A3A3E3A383D41373E3F3D3E3B393E3D3E403F3B37383B383A3A3B3D3A3B4243423E3D
3F4343413F42433F3D3D3D3B3D3D42423C3A3D3B3D393B3A3B3E3A3B433F3C3D3C393839
3E3D3C3D3E3D3A373C3B3C3B3A3E3F393A3A3A3B3B3B3B3B423D37343536343237373737
383B40433C3B3B3C3E3E3C3A3B3B3A3939393A3B3938383B3C3A3A3C383736373A3B3C3B
3635383C3E3D3D403937393C3B3D3D393D3B393A3D3E3C3937383837363638393A393939
3A3A3A393A3C3D3D3A3836363B393838393A3B3B383B3B38363737363A393B3C38393A38
403F3D3B3A3939393A39383A3C3C39363B38363634323438363636363737373739383737
3838393839393A3A3A3A39393B38383939393A3C38393939383634333838383838383838
33353738373635353536373E3F423D3B5050505153504A4650403D3938363431363A3A38
3835323438373736363637383838383837373737
5251504F4E4C4A484A514E4E4C494F4B4D4947494A49494B48484A4C4D4C494747484244
45444A49464642474742464648494848494B494644424243434242434243484044424745
41474945424242404341464F514A44443F4B4A4243484B4D464646464746454442444647
4847474745434142454644424D4543444345443D3D444242414148454345454946444A45
48484346443F434144443E42413C434442493E4644444347444145453F3D3D39413D3C3F
42403F403D4140464E463D44433D3C3E414A4C4446443B3D3D3941433B3B3B3C3C3D3D3D
3B4144434344413B3C434E4944443F4145423F42454340423F414242434343423F3D4246
4444433D41413F403F40433F3E403C3C43443D3A3A3C3D3E3E3F42433D3E424645414041
4548403E3C3A3F393F3E3E414546433F3C4042403E3D3E3F3B3E3F3E3F424341413E4041
3D3D3F3B3A3C3E40413C3C454542414242403A353B393C363E3C42403F3B3A3C3E3E3D3D
3F3A3E444447494747495A5160504D52475C616D828B8F90917E7260624E494139333E42
4846453E464443474B475E566C625854534E4A4741494544473C4B4855676C866B775744
4944454641444644454645413B393B3A37423E47384E404544403C3E393E4B474A474752
415044444A4E4B504F60676E816E8A7BA28D9888A194A58797716A59474C424842444340
44534B525B6B69776972849A9EABAAB9BFD5CEC7CABBCAB8C2BBB6836F665C4C43414343
3A494A585F54577D99D1C1C0ADAA8C858999A99D9E6F9972857FACA8AA96B0917581A08B
926A49443F383C3D3C403F3E413F3C3F3D4143403B3A3A3A3A3B3A3C3F3C3A403B3D3C3A
3B3F4140393D3E3C3C3F41413F3D3F3E38393D3C413D423F3F423D3F403D3C3E3F3B3939
3B3B3C3D3D3C3A383A3A3C3B383B3E383939393A3A3A3A3A3D3A36373A3D3D3C3A3A3937
37393D41423F3B3838393A3B393A3B3A38383A3C3937383B3D3B3C3F3939383A3C3D3C3B
3836373A3C3C3D403A36393C3A3D3F3B3C3A39393B3C3B39393A3A393737393A39393A3A
3A3A3B3C3A3B3C3C3A3837373B3A38393A3B3B3A383B3C38363737363B37393B393B3D3A
3A3937353537393A3B39383A3C3D3A363B38373837343538383838373737373637373737
37383A3B39393938383939393A37373939393B3E36373839393736353737373737373737
36383A3A3A3A3B3C3B40414C4C4F454240444A4E4E4D4C4B47453642323B3939373B3A38
3A38353939383737363637373838383737363636
50505051515151514E534D4E4E4C4F474F4C4B4E4F4C4B4B47484A4D4E4D49464549484C
4D494B464747434849454A4A494743444B514D434A4646494945444743464C4449454B47
46484A494542424547414148494340424F5F5F514B4B464245494D4D4945444442444749
49494A4B4845424244454441423C3C4044494A444147444341424B4B46433E403D3E4946
49463F43433E434442443F45433D434240473D4A49464549474040413F434642413D3C40
43423F3E3D43444B51453D484340413F3C4246414046454B473D41403E3E3F404141403F
3D45463E3A4045454243484240433D3C3F43424448413C423C3D404242404041403D4043
404346443F3E3E3E40403E423F413B3840443F3B3F3F3E3D3B3C3E403F4546403E434441
474B4241403D3F3647434042474A48463B3F3F3B3A3C3C393D4142404145464440393A3F
4145443C423D4043413B3D484342423D3A3B3E443E3B3E3B4542484646403F4548454140
40393E4646484D4E474D48484B4B4050505F5F6F8A8D7C6A6D565C42573E50484F394137
433F4441423F454E483A4E434A47464644424245474E5052514A65628E7CA67A99708858
685C595653595B58585D5B5A5549454946484D4C535E575149484448453F4546433B4244
384447473F4441443F4B4C4F524D50625D72717A728B7CA581A586A37C82706956524F4A
47464A3B443D4643413C45444649586E799292B0A5C1C5D0BFD7B7A5734E3F403C423E42
433A413C373E4952859ABFABBBADA084858A95876F504F624C696B8F7A9495B08C675B62
7B735D534C4448464A48413D42423F413F4444403C3D3C393A3D3B3D423D383D363B3D3B
3A3E41413C3F3E3B393C3D3D3F3C3D3E3B4048494E4A504D4C4F494C3D3A3B3F403D3A3A
393A3C3D3D3B3A3937383D3B34363B373838393939393A3A3B3A3837383838383B3B3C3B
3938393B403F3E3C3937353337393B3B39383A3C3D3A393C3D3A3B3E3B3A3A3B3D3D3C3B
413C383838393E433E383A3B383B3E3A3B3938383A3A3A393C3C3B3A38383A3B383A3B3B
3A3A3C3E393A3B3B393838393A39393A3C3C3A38373B3C39373939373A35373A393C3F3B
43413D3A383738383C3A38393C3D3A373A37373A3B3938393C3C3B3A3938383736373837
37383A3D3A3937363637393A3A3736393A393B3F34353739393937373737373737373737
3839393A3C41494E4A4D4D5855584D493B414848423E3F413D3E3736362C4137363A3836
3A39383C38383838373636363838373736363635
4A4D4F4E4B494A4D494B47464D4B44444B4B4B4A4A48474742464A4A484442414D4C4A48
454443433F4246494A474441454344474846474A4744444645413F424344454543424243
47484848464546473D4143403F4143423E464747494542473E42454744424243424D4244
3E474B443C404245473F3B433C3E43474644464B484A4742414648464B4745403A414642
4545423E404648453C3C3A3E423C3D48494A433F42414045403E3F42444241423F404140
3D3C3E40384441444946464441363C41464740473D42484945403E3E3E44403D43444040
3C3B3D41413D3B3D3D3D413F393D413D3B41414143403C3D3F3D373E413D3F3D3D454A46
414142413C3A3E403B3C403D373A3D3F404040413C3D3D3B3A3B3E413C44494845464747
423D3A3C3E3F40433B3D3E3D3E41403C3D403D403B3A42393841423C3C464842433F3D3B
3E4B50473F3936383A3B3E43373A41423D3E42413A3E404145494742413E3D464743453D
41413F424B473B3B3D443F40404545494F5F72808A7B7A6C656D5150413E454B554D4A4F
504B4A4E4C474344484B4A48624F47444D464848424D4C4C4B4C5654555D606555504544
45424943463D44485847625B75596E678B85938CB0B1B2908D75676068767B888A757755
553F3B473C48373F42464A44413F4041483E48464645504E535766647370817C7E82946B
6D4A6046424A394D4045423C453C434840473E51656A958CBACDD1CCBD8D5C5C424C4A42
453B47473D3F4A57596D758B77887C7869686C715D5C4F504846494C6D7E90908F726465
525F6459554A5C67625B5C584246403D3A4545433E3D4341433C4548413E3B3F3B38423D
3D3B3A3E3E403D3B454135413A4B4A5555606E768E8B908C7B6E614D433A3C423D383D42
3838393B3A38393D3A35323E3C3038433A3B3937393D3D3A3D39383A3A38393D3C3D3837
3F3F3B3C3F3F3D3A38393C3F3536393A3B3A3A39383A3A3734353A3F39373B383E383934
3A39393939393A3A3D3B3740433E3E3B35373A3B3A3A3B3C3A3A37383B37343939373737
393B3B3A3B413F3C3C37353A383B3C39383A3C3B3636353738393837393939393A3B3D3E
3A3B3C3B39373636353536373534383F39383838393A3C3D3C3E3D393738373435373A3C
3B3B3C3D3B3B3A393737393B373734353938373E3C3634373937363838343C3B39383239
38394248414C715B6D595E54524A443D403E3C3A39393A3B353637383837363539353739
37383B383A363436363334383838373738383939
50525353514F50514E4E4C4C4F4F4C4C514F4D4B4A4B4C4D4F4F4F4C4A48494B4E4D4B4A
4A4A4A4A484849494948474645434447484646484A49494B4B49494A4B4B49474445484B
4C4C4C4A47444343494A4946464B4E4F41454748494745474347494642414243444C4248
444643413E45454445423F424041434644424449403F3E3F40404143424144423C404747
424444434445423D3E3F3D3F413C3A423A41413F4040434B44413F4243403D3D383B3F42
434241403C454041444243414C42423E4145424643454644413F404140423E3B3F444546
403D3C3E3E3D3E413D4046453E3D3D3741423F4044423C3E413E363A3C3A3F3F3C3E4040
3C38393C3A3A40433F3E3E3A3E3F40403E3D3D3D3D3E3F3F3F3F4040404447494A4B4A48
44403D3E3F3E3E403F41403B393B3D3C40413C3D3A3C443C3640423B393F3F3A3B393A39
3C464A4139383B404241424544414445404045463F3D3B3D424645413D3A39424240453F
353E45423E41474A3E3E44384748484D59717A8A8C7580725E5757527764796E88817D7C
79726E6F6F65574E494845434C42403E433B3E404540403F3F44484B3C47474D3B3F3A43
44494350434E4854554F627587858D8E889AA3ACA5BDBFB6969390909AA5ADBAC2BFBFB4
9F82605E4958494D454145464341414450516368818089838177736565606A5E5B5D7B6B
8F6A7E766B68504C3D3940433F3D394545404540454348465F8E91BFC4BFA29171797264
5F4F525046454F54555E5F685B6E6C70625859617D7F8B70826970536D839895918F908A
6671828889808D8B8A8D948C6C685A505E686D72695B5A586055624B54454B45433B4238
414A40423A3D3E3B444D53666B8899A39FB3C6CFDACAC8B37D5B534637343B413C383B3D
3B3A3B3C3A37373B38373C50513E3836393A3937393D3E3C3B3A3A3C3C3B3B3C37383536
3D3F3D3E3A3A39383737393A3737383839393939393A3B3938393D4036363C363832393A
3B3B3B3A393837363637343C413F423E35383A3B3A393A3B363736393E3A373B3A383738
393B3B3A353A3A393B3A393E3A3A39383B3F3F3C373636383B3D3D3D3C3C3B3B3C3D3E3F
3A39393A3C3C3A383534363838383C423C3B3B3A3938373733383B383536393A36383A3B
3B3B3B3B393B3B3A39373738383834353B3A3A403C3B3A393837363638353C3C3C3E3D45
454D51665359544B493C413C3F3B37353435363738373736363737373737373638333537
3331343436353537373535363637383939393838
4D4E4E4E4E4D4C4C4B484949484A4C4A4C4B4A494848494A4D4C4946434344464A474544
464848474646464544434342454344474745444547484746464748474145494845424142
4D4E4E4B4844424140403E3B3D404242444244444343423E444A4C4641424546474A3D45
43413B3F3E4646414447464444434445423F414545414145433E3D40494341403D3D4041
464543403F40403D3E414040413D3B3D4243404043423F3F423D3C4043423F3E403F3E3F
404142423E443E3D40404341454345414347413F45454442404141403F3C3C3C3E444947
403E3D3E3F3F40423D4147453F3D3D3846423C3E44403A3C3E3D373B3C393F3E43414347
453E3D413B3A3C3D3B3D42424141413F3D3B3B3C41424344454543423D3D3F4447474542
4A474546454241423F454946413F3E3D3C3C393A393C40393A3C3B3A404742374241403D
3C43464045403C3F434444433F3A3F46423E3E3C433E3B3F4445423F43403D423E393E39
4143453E3846555146494B3D44585E7B7A7F85756455585F75856B876D7662695A575452
504B484649443E3C3E403F3D403D3F3D3D373D43513F40403E413F424245454B4E55565B
585C646F79828D959D8FA6A4C1AFBFB7C3B5C396A69EC0ABA19F969CAEB9BAB5ABB1A5B7
A1A68E98899385897A6D6A6D726C6A7B9BAEC4C6D1CDD0C9CCC7C7BCBFB8BCAEA0837A5F
705D728C979C8B7A755141493E4A393C433D453A3C3D3A423F545C729AA1B6ACB9C2BCAC
A08C857E7C73756F727B838495A2A6AFA4908588A9B1A99D9C988B6C7B8F9A9089A5B3A4
7C86A4B5AA9FADA7B8C1C9BD9F9D8A7A909EAAAD946D5E5B5D5F635A5B5F58544439453D
5B6F676B464D5855545B616DA3B8D2DFD5DDD3C7BB947F704F3E413D3B3D45453C383938
3C3A3B3C3B37383B3F3B3C4D52423A34383A3A39393C3D3D383A3C3C3C3D3C3A3B3B3736
3A3A3737363737393939383638373737373838383636363738393B3C443D3B353C383B38
39393A3B3A383634393B36393B3B3D37343638393A3A3B3C3C3C3A3A3E3933353B3A3838
3A3B3A3A3B3D3B393A3937393E3C39383D413F39383736373A3C3D3E3939383838383939
3A3735373B3D3A363D3A3839383536393C3C3B3B393736353B41433E3836383B3838393B
3C3C3A39383A3C3C3A3735343A38333438363439393B3A3635373A3A3C3B414241414047
5053605057494336363236333B39373A333436383838373638373736363737383D38393B
3635373737373634343738373536383A3A393736
4F4E4E4E4F4F4D4C4B474B4D484A4D494B4D4F50504E4B494B4C4C4C4A4846464F4C4949
4B4C4A4747484A4B4A4845434644454747444244494B4A45444747434547484642404245
494A4B4A4845444445454545464644414F4949484446473E434A4D4743464A4A4C4D3E40
41443D45454745424244444244434444423E3F42403F4145464545475D4E424246454240
46433F3C3C3E40413F4242414141403F474440414646423E413C3A3E4343413F44413E3E
404242413D413C3D3F4146424844403D3C3D3B3B404141414243413D3B383C403F444843
3D3D3F424342403F3F42433F3C3D3F3F43403B3D413B363B383D3C42413C3E3A3E3E4146
45403C3B4542403C3737393A3D3E3F3E3D3C3C3D403F3F414342403E4141434849474645
42404042423E3C3D3C454C49434141423E4040434546443C3D3B383A424943393A3B3A37
384046464C433B3C4346423E40383D4746403E3C423F414647423E3D403F3E433E39403D
44403B3938424D443E494C60779787937080707A7664776B80746C4D5F424F403D3E3F3E
3E3F3D3B45434243464643404140403C3A3A4249493C3F413C3F3D3B544A64528370887E
8D8D8F8D95909B9A8E9187A097ACA6B2BDB68F95709D8E827B858A9AA8B0B09E9C8A9172
8B70888499A2A2BBC5C6C5C9C9C7C0C4CCCED7D4D9D4D2C7CBC9CDC8D4D0D3D1DACBBCA6
B5AEA4B2BEBDB29EB195727244453E4049473D3E423D3F3D45423D42506A7598B0C3CDCE
CFC7BFB9B1B1BCB9C1C5CDC7D2D7D7DAD5C0A99F9D967878717A6E61638EA99B798D9F9C
737693A89897B0ADB9C1C6BFB3C3B8A9ABB6B7A77D5146473E4340454556494B4547394A
496A52614E525E55484948486A759CC0C1C3A58E6F514042433F3D3A3A3F454138383B39
3A38393C3C3A3B3D423B333C40393938383A3B3A393A3B3D373B3C393A3D3D3938373636
393B3A3A37383A3C3E3D3A37373636363839383836363537393939383433383238353C3C
363738393A393838383C3737393A3E383B3B3B3A383736363A3B38393E3C38393C3B3939
3A3B3A393A3A3A3A3C3C3C3D413F3C393B3D3B363A383636373939393737373636353535
393735363738363339353336373636373939393939393939373A3C3A3635383A3838383A
3C3C3B39383A3C3C39363433393833353936333638393B3B3B3A393734363E4344414043
494F463D383F343236383633393633383A3938363535363637373737373737373B373635
363B3C343D3D383130373B3B3536383939383737
504E4D4E50504E4C4B484D504A4A4B454A4C4E4F4F4E4B4A4C4D4E4F4F4E4B4A49474647
494946424748494A494846454645454747434244484A4945444646424547484643424345
454748484645454644434244464645444D49494642464940444A4D4A46484A4A4D4F4343
434C45494D484544413D3C3E4141424543403F413C3F403E3F4242404C40373B43423C39
3E3E3E3F3F4041434544444241424341464545434040414246403C3F42413E3C3B3B3D43
4748443F3E413D3F414247413F3B393F3F3A3B3E3C3E3E3D3F43413C3D383B403E414440
3E3F40424344413E4042403B3B3E3F403F414141413A373D383F40454540403A393C3D3D
3E3F3D39383B3E3F3E3B39393A3B3D3D3D3C3D3D3C3A38383A3B3A39393D40413E3B3C3E
3C3C3E42423E3D3F3E43453F393A3F433F4143434749433E3B3E3F3C3A393A3A3D3F3E3B
3B3E3F403F3E3E414444403B483B3A40403E3F3F3E3F4346433C3B3E3E3D3E433E383F3C
4A4D46453D38403E495D8B8BB69D9C8E97938C7C685A4C4A474C363F3D4F3F373D3F4142
434444433F3C3B3C3F42424242413D3A393E41433D3F40413C3F47413F4B48595C6D6975
7079677A6B7A767A827C87778B7E9293A398B194AD9BAC896D84999E8F8E9D9497907375
5B67626C879098BBCFD8D7DED7DAD1CCBEAFA69CA3A2A299A5AEC0C7D4D8DDD8E3E1DDD8
CFDBD5D7DBCDBE9E8B937D99766A60484540393D3E3C3B3D3D3F3F3C42453F667994AEBE
C9CDC2BDBDC8D6D6DEDADED8DDE1E0DBDACEB9AD987B6A4C5F48523F5A81A3A88E8F8D85
76686C76666E8883939B9F9FA2C0C1BCBCC4B89D785B534E4E4143384746464242423E3E
423F3E4547434A443C4446434443586A6064544B423F41443F3C3E3F3A3E433F37393D38
3B39393C3D3B3B3E3B39343A3B353938393A3B3B3A38393A373A3936363A3B3939383838
393B3C3B38393A3D3F3E3B38353536383A3B39383D3B3A3B3D3D3B3936363C373C353937
3737373838393A3A40443C39373638313939383839393A393B3D39373B3B393B3C3B3939
3A3B3A393B393939393A3C3B3E403E3A373838363C393736373939393A3A3A3939383837
373839383636373939353336383736373938373637393B3C3A3938383837363537373739
3C3C3B39393A3B3A38363536363735383D3B373C3A3635393D3F42454C4C4D4E4A423F3E
3E3C343B363734343C413A3636333033393836353333323236373839393837363B393632
3846463540403A3231373B3B3737373737373838
4F4E4D4E4F4F4D4C4A4A4D4F4D4B48444A4948484848494A4A494747484949494D4D4D4E
51514F4D4746444242434546484545464643434544464746464746444144474948454341
46474746454444464946434447494D514244443F3D434845494B4C4B4946474843444244
404C444448414144403D40433F3E404444403F404145443E3B3D3B36424444484D494341
3F3D3D3E3E3F43474C46454541414240474342403C3D3F3E46403D40434241403F3E3E41
4445433F42433F424142453C3B393A46463C3B3D3D3F3C393B41423F423C3B3D3C3E4242
43423F3E4043423F3F43413E40403C3A3D444543413D3C413D4240434342443E4143413B
3B4244423C403F3D3D3A383A3C3D3E3D3C3B3C3D3F3D3B3A3A3B3D3D3E4548433F3F4142
3E3F4246464342444044453F3A3A3D3F3F3F403B40443E3E3F3F403F3D3B3D40363C3F41
454543443B4245423D3A3B3C483D3B403F3D3D3A3D3E3F3E3A373A3F3F3E3E433D363B38
424742494A4C6169648E91B898AD96A585855D574738473E3C43433C454748423B3C3F41
424344473C3C3D3F4141403E41433D3D3D45413D3F49433F3B3C48474544473A4E454D50
48524457556469696D76727A76817F887B908FA68EA6999B9EA5A794716060556F5C674B
5E4E6461758390AEBCC8CDDCDAE2DFE4DDD5CBC0C9C4B9A19F9BA4AAAFBBC8C6CED2D1D5
CED4D5CAC8C3CDB69B9664716660634D6260766B4D453544404D4632493546565F7FA2BD
CFDED3D0D2DDD8D3D7D1D4D8D8DDE3D9DDDCD6D3C5B7A79397857D635453627A7F878983
7A6B5C553F475A58535C666F76939AA1A5AEA59A939393878F807D7A736E5B4C40414741
483848463F3A42434248433D4544454539474847403B4040383F484238393D3C383B3D38
3F3C3B3D3D3B3A3B393C3A3E3E393D3C3939393B3A38373939393836363839383E3B3B3B
383839373838393A3B3A39383736373A3C3D3A373C3B3A3A3B3B393738353B3A4542433D
3A39393838383838393C37393A3A3F3B393837383A3B3C3B3F423D37383836383B3A3838
3A3B3A3A3D3A3A39343537353A3D3D3937383A393B3A39393B3D3E3E3839393938373736
35393C3B39393D423E3A383A3B3836373C3A37353537393B433E3A3B3C3936343737383A
3B3B3A3938393A3938373839373836363A36353A39404B5760666A6D69635751493D3A37
363038333C323C3140453C3B373736363436383A3A3836343637383A3A3837363D3B3834
3A4A4A393C3D3B38373838373737363636373838
53525253535351504E4F4E4F53514C4A4D4C4B494A4B4D4E4D4B484648494A4A4A494848
494A4A4A4D4B484545464749494644464544454849494B4D4D4B49494A494848494A4B4B
4748474644444648484441424244494F454D4C4443484D504D49484B4945454A40393F46
3C464142403D41433F4147483F3E3F4242403F413D3F41424242413F3C4446474B484140
43403E3E3D3D42484C4343474340403F423B3B3E3E43464244403E424444444647433E3C
3D40414143423F414041463B47463E413E363A393E41403A3B41423D44413D3D40404045
4443403D3F43413D3F43414046463E3A3B43423D3E40404141443F404243464044423F3C
3B3D40413E403C393C3D3F4541413F3D3B3C3F42444342403F3F41433D43443C3A3F413D
3D3D4043413D3D3F3E42454341413E3B444547404348414545403E4246454342383C3C3C
403D393A434747403A393A3A423E41464646423B3E3E3C3A393C3E3E3D3C3C43403E4643
4749465152596D657F728C7DA3959F8A7E6B4D49474D453D45484A4A4D463D3C3F3D3F44
4543454B393B3E424545444142453F3F3D48433D3E453F393A393D46484A413D4749484F
6168616A757A8982867F89677D5E64565E5C715A746480828F93958F887C66574F4A514E
43473E40515F69797E8B96ADBFCED1DAD6DADDDED8DAD9CCD1C9C9C7C6C1C0B2A69A8E92
8F9BB8B7C6C2D3CBD1D2AF997C513F3A4E567D85686763746C795C4A4756637A95AFC6D2
D5DCC6BFCAD7C5C4CBC2BBC5C5C6CEC6D1D4D7DFDCE5D5DCD0D4BCA76F4A47504A4B626B
757460533E3F44424143474F4E5A565F656E6A6E829DB0AC999BA4C0B1C09C836D756673
54695F5B463D3F3F4145403F3A403C433D423D37433C44515A635E4A4B433E3A383D403C
403C3B3D3E3B3A3B3E3F3A3B3C3B413F3735363A3B3938393B393839383636383936383A
373A3E3B39393837363738393C3A393A3D3D3A37373736363636363536373D373A333939
39393939393939383A3B373B3A373B3A44413D3A39373533373E3C3738393A3D3A383738
393B3B3A3735393A36383F3E3C3D3C39393B3B383B3A3A3B3D3E3E3D3636373737363535
3638393A393B3E413634353A3D3C3D3F3C3B383635363839373535383A39393B393A3B3B
3A3837373637393939393B3C3A3B383739383A444C6C8B96948E8173564F403F3C353733
343633372A3D3434393D343932373B353336393C3D3C3A39373738393938373738353432
323B3D3538373739393736373636363737373737
4D4E4E4E4E4D4C4C484B47474F4D474847474848494848484D4B4848494948464D4B4846
4445474849484746444342414A464445454446494846484C4B4541434242434649494542
474746454546494C49464545434043494754514543464A514E4643494A46474E4939404B
3D45454B414347433C414743413E3E40413F3F413C3B3F4546403D3F3C42403F484C4643
40404346443E3D40483D404845404140434246453D3E44444844424444424244413F3E3E
3F424343413F3C3F3E42483D373E3A3E3F3D433E3D4344403F42403942433F4147433F45
4142414042443F383F423E3E484A434038403C353A41403D40443E3F4244463E44414142
403A3A3E4145423F403E3C4044423F3C3B3E44484242413F3D3D3F414147443C3D474840
41414345423D3B3E3B3D3D3C3D403F3D4145494346483E4244414245443F3C3E3E403B39
3E3E3C404243434244443D353936383C3E43443E40403E3C4045423C4743414744414947
535B626E625D63444D4E5F747593898A6A6C54594E494A424E48444747403C48443F4044
423D3F46403E3C3B3C3F414241453C3A3644423F3C3F403E47463F514E60576763777389
8997809991A6A7A6A1989779886E6A594C51544D544E586677899A9FAEAC989B8385818F
6C846A75474E4B4B444C546B69767990A1BBCBD0CED0D1CBD9D7D7D5D9D2D4C4A47D5C5A
4F52685E7D809FB4BDBDB9A399683E423E393C5853658487ACA4A4706D71788E9CB3C5CB
CBD2BBB6B9C7B1B8C5BDB0BDC3BABFBBCBCDD0DCDCDBE1D3E2CECDB3AE66525F625F695A
58615354545D585147414351555C525948535459698298989DA1C3D7DEE8D2A8B3A8B79B
A4A6B195957B62493E3E404B42443944403F4146404C6384A2ADA59B88735E4E4342423D
3D3A393C3F3D3D3E3E3E3637393A3F3B353233383B3A393A3C39393C3B3735373C383A3A
35363A373C3C3A373536393C413E3A3A3C3C3A3738373737373838393B36373138353A38
3536393B3C3C3B3A3737343B3B363B3C3D3B39393B3C3C3B38413F393736353839373737
393B3B3A3D3B3E3E383A414142403C393B3E3B353B3A3A3A3B3A393739393A3B3B3A3939
383635353739393A363536393A39393B3A393837373738393B3B3C3F3D3A3C403A3C3D3C
393635353436383A3A3B3C3E3C3E3C3C41454E5C7199B4A992816A52464134383B363934
3D313C323737313A3639313A323B4139343435363737383838383837373838383B363737
31313638373333363634363A3435373838383635
4D4F5153545351504E4C4A494A4B4C4C4C4B4E4A4C514C4C494F514A45474C4D4B4B5C5A
4E4A474E564E494A4B48454546474C514F49464748464B56554B45464C4A494B4B48484B
44464746484B49444547494C4D4D4C4A4A484645434349504E4745494D4A464643454441
444B4E4D3E40464642454742403C434242423D463F4245444140414344454A4C453C414C
46474140464540414244414348444148424042423E4046454544433F3B3B3E423E424240
40413F3D3C3E3F3F3E3C3C3D414345474644413F41434646403A3C423C4040414747474B
50473C393C41413F3E43433F414747413D35373F3F4146453F434244434044433F404141
3F3E3E3F423C3A39373B3F3E423E3D404041464E3F3A3C3A3F48413C4241463E42434536
44494642403C3A404045433D3F46453D3E3E45444446434744453E404447483F3C3F4346
443C393C3B3A3F433F3F413C3C3C36393B3B413F3F434145423A3F403A433E3F403B3F41
699693615958606A5A757A77736B69615B4E4848413E4042434646413E3F403E393E403E
3F4244433E383C3B423B3E3D3E403F3B3A3E414041403E4341485A5B82867F797C81848A
8397929398A8A3A8AAB8B39C988C8F896C7863755D70667F80848C959CA5ADAFAD8E7985
92A8AA854E4B4A4A493F42443D44434D5B64726E7A757D809AA4B6B8C0C9CABDB28B8976
7A6F886B7B5D6661546A5954544F3E3D3A45433E473F577289AFA49183918992878CA8B3
C0BFC6B9BFB2CFC6DFCAD4CBD6D1D0CDCDC4BDCCC4C6D1DBCFDDC3CDB4AC96A898A8A2A5
968D79705446715A504A686A8C92AFACB6A7A89A9C958C88808EA3D4D4E1D2D1BBD5CABC
B7D2CCC4C2B19F8F7060614F4535433E404049627C99B5BACDC5CDC9BCBFBCB5926C5442
3C3D3F3C3C3943383F3A383B3D3C3B3E393534383A3A3B3E403E3B3A3B3C3D3C3B3A3B3D
3D3B3D423B3736393937383B373B38373C3C3A3F383A3C3B3A3A3B3D363B3C3836383835
363A3A3836383A393A3939393939383846463D383C3B393E3A363C393A3F3A3F38393B3C
3D3C3C3B383B3A393B393B443D373B383637343D36393C3D3C3A393A3B3A3A3939383737
32363837383B3C3A33363735363B3C3A373A3A363436383835373B3D3A35373D3A324136
373D323832393B3B373B3E415A627376807D86899A96987F615448443736343536373736
343937353837363C3637383837363739343435373838383835373C403D38373A34373938
3535383C343234393935333535363342382E5064
4B4B4A4A4A4B4C4D4E4C4A494948464446464B494B504A484A4D4D49444446484F49514E
46494E584F4A4648484644454A4746474543444748464546464444454442434645424042
414446464748433E4545444343444547414143454342464C494544484B49464447454342
43444749433C3E434240413F433D43423F403E4441424343414041423D3D404546454A53
42433F3F45443F403D3D3D4146454549403C3D3F3E41423E404244423F3D3D3E4242403C
3C3F3F3D3D3E3E3E3D3D3E3F3E4042444544424147484949433D3E423C41414247464548
423F3C3E42433F3A3D403F3C3F4646413B393E413D3D4142393F3E41413D413F3F3F4041
41434547403A3A3B393C403E373B3F41424343433A373B3B424C47453D3A3F393E3F453B
3F44424143403D413B3E3E3A3B40423F4540423E3E4342473C403B3E414141373F3F4042
403D3D413C404A4D4541413D3E423E3F3D3B43443C3F3D41403B4245403F403B3B3D3F4D
82AFB48E908D867F62695B50504E4A3F454345444142423B454543414244433E3C3D3B37
3940464838363F41484144433E4043454648474548454146474A524D655D5F485E535E59
585D655E7770787B82959E949184877F847E82809082796B585B5D5F626466696A544D49
58535F4C444E3E483F404846404846484341494B474D45564C605D67687178868582868C
889F9EC19DB9A1B98B855F5252544C4E443E3E424D49484D4D738F909E9698A3A6AEB2B8
B9C8D0D6CBDFD1DAD4D1B1C1BBB3B0AAA3988C93A49CB4B0CCB6C3BFD7BFC8B4C9BFC8BB
B7B5ABA693757350575559857BBAD3E0D9D3DAD1D1C6B8AF988AA7AED6C8DCD3D3CED7AD
C3BFD1B5B7BEC3C2B7B1AE9F7A685D5F5D7F90B6AFBCBBB2A3A8A8B1BCB5C2BFC29C937B
4D413E4336493F453736393C3E3F3F3C3D39383B3D3D3D3F44423F3D3C3C3B3A38353539
3B3A3A3B3836373938353537393C38373B3A393D3B3A3938383A3C3E3E3F3F3D3C3D3E3D
36393B3A3A3D3E3D39383838393B3C3D3C3C38373A3B3A3C3C373B38393D393C3A3A3A3A
3A3B3B3C3A3937393A3537433D373B3B3D3E363637383A3B3A3939383A39383737373738
38393836383C3D3B333739393A3B3A37373E423E3938393A3937383A3A38393C3F40393F
36363834393539395368848DABBED1CCCDC7C2B498897D62494139373836353536373736
373A3836373635393637383837373738343536373738373734363A3E3C37363835373837
3636383A34333438393636383634333C434E6366
5150504F4F505151504F4E4E4E4C494749484D4A4C524E4D504F4F4E4B4747494A434948
4345474B4C4B4B4C4C4A494A4D4A494A49474646494A4845464947434747494C4B474443
4B4D4D4D4C4C484443444443403F4042484644423D3C434B434444444648454249434143
423E40464D4341454444423D403940423E42454643434342414041414744434445454343
4243404146464242494444474747474646403F424244423A3D404343403D3C3D42413E3B
3C3F403B3F3E3D3D3E3F40414142424342403F3E42424345434040433D41414246454244
4B46413F4041403E3B3D3B3A3F45453F3E434A483F3E4344393E3D42413C3E3A42403E3C
3C3D3E3F3F3B3C3D3B3D3F3B4044433D3B3F403E403E403E444B454540393C373B3B4441
3B3D3D3E42413D3D3E3F403E3C3D41444A42403A3B414043383D3B3F403C3C343B3B3F44
43403F3F3A3B40403B393B3A3E3F3A3E42454A4642433F42403C4447484045393D4D5877
9FB1A5808073635752503F3A434C4D453F42433D3A43443842403D3E4245413C3B3B3A39
3B3F4140403B3E3C443F44423E3E3F434644413E42413F444442443C464746404644433F
434D4848515A5556646E756A61515850584E60566E58573F4246423F4341404850463946
4E4F4A464848544245454644494F49493D3B404644444245434644454344405045504C5C
61667E92A9B5BFC9C2B79B9EA3AAA7A8A07F675144433D403C565E8181908EAEB5C2C6B7
C5C3C8CAD8CEE0BDC67B6E5B594F514F4F514E4F5D555978759689A7A2BCA6CEAEBEBAB7
B0AB9F9EA99D8C728D6F826B8781B8B8D9D5DBD9DFD5BFAF8C8F87B6ADCCBECAC3C6ACBF
9BC7B3A5A0B5C0BDC8D3CFCCC4B2C9ABC5ABB0A7ACA1A7786E555E5966716D9C91ABA6AE
8D5B56393F423B363C3B3F3E37383A353F3C3B3D3F3E3E3F38373637383A3A393D3A393D
40403E3D3C3C3E3F3C38383A3B3C39373939393C3C3937383B3D3D3B3937353636363738
36393A3A3C3F3E3B3E3C3A39393A3B3C3E3A3A3A383837333D393936383B38393D3B3938
37393B3C3935353C403B3E4E3F393A3B404339343B3A3A3A3B3B3A3A3A38373535363839
3E3D3935373C3D3B383A3B3A3A3A3937363F433F38373B3E3D3936383A3A3A3B3F403F3F
38333C3A3B49557A93BECEDADCE4E9DFDACEBDA6826D5B483C3A38393938363636373635
393B393637353437383737373838373736363737373736363435383B3B38363737373737
37373839353435373938393A32445A544D555148
4A4C4E4F4F4E4C4A474647484A4A484647444641434A48484B474749474241434B464B50
4E4C49464446484948464546454444454645423F454543414244423F434344464644403E
494845434243444443474B4C484442424645444340414A54414444414145443F45424141
403F42473E3D3F3E3F484A41423C42443E4044414343434443434140454646464746423E
4342404043434241443D4043424548434A444343414140393E4042403D3C3D40403F4041
4144433A3F3E3D3D40414141404141424241404041404041434241413D41404145433F40
43424141434444433B3C3B3C4146433C3E464B47404145453F434145433D3E393A393839
3B3D3E3F413D3F403D3E3D384A4A443C393C40414543444044474043483E403C3E394343
3C3A393B3F403C3943434546434248504C43413C3D423D3E3D413F41403C3D383A393E42
4140403C413D3B3C3F41413F3C3C353A42474A4341423E42413D4446423C423E51707E97
8D81684D50413B3E3E403B3A414748434144443C3A44473C403F3D3E4143403D3E3D3D3D
3E3E3C3948403F3B4541433E433F3E41444341413C424448454043403D4545474550565E
6C776B6A60634B4248474A44403B4C474542464441434943414742414D515667688375A3
78947D9788A087987F7E7C72736D6E585C494B3D404044404340464843443C423C43444B
494447505C656F79838A8CA5B2C6D1D3D5C0A8845D473D413F3E3D475354596A81A0929A
97AA95A0A6A7907D635D4F444F4D5349404E5D68685A7B69A86E9C8298868C838F95A1A4
A1A1959096969895A1C1B8B57D696B99A9BBC9C8CABB916B665F8874A487A394A592A586
9884987D80999F99B5CFCBD0C9CFCCD1C1BD918485979EAE877E584643465F54675C8283
AB988E7958513F3C3F3A3E413A3A3E3B3E3C3B3C3D3D3C3C3D3C3B3B3B3B39383B3A3A3B
3C3C3A3A373A3C3B383536383B3A383738393A3C3A38383C41423C373A3636393A373739
383A3A393A3C39353E3D3C3B3A3B3B3C3B363A3D3B3D3F393D3A3938393B39393E3C3937
3738393A3E3C3A3D3F3A3B46423D39363B3F3C38403E3C3C3D3E3E3D3938373737383939
403E3935373B3B383F3D3A3737383A3A373B3C3733363C403B3A39393A3A3B3B3B32412E
343A4258818EAFBBDADCE9E4E3D4C9C5BC9E7A6157483D39383837393B39373637373635
3A3A38373636353639373637383837363737373737363535363637393A39373739373636
37383837373636373838393B48617F6141413837
4D4F51525351504E4C4B4B4D4F5151504C4B4E494A4F4B4A4E4A4A4D4D4A494B4A44454C
4D4E504C42454848454443434C4B49484A4C4C4B504A45454546484B4848474748484643
494846454545474A454A50514E49474647484B4C484243474446443F3F42423E3F42423F
4045494A444648423D43443C3F3E40444143464142434546464442404244454544454646
44413F3E3D3E403F433E40413E41443F444041403A3B3E3C3D3F41403E3D3E40403E4245
4448483E3E3D3D3F4142413F393B3D4144464748494745444443403C3D403F4044423D3D
4443413F3D3B39373D3D3E40444641393A40413D3C40424341444245443F403C3C3C3C3D
3E3E3E3E3F3C3F413F3F3F3A41404244433F3F424140403E454842484A404340413A4141
3E3B3A3C4042423F4141444746454C574D45423C3D413D3F43454042403C403F423C3C3A
373C413F39393A3D41403C393B413C3C3D3E443F393B394142404647414341465D71726D
574B4038443C3F47414142403D3D3B383D3E414242474841414141414140404143403D3C
3D3D3D3D3F4048464B44433D3E3C3C3F424445453A424145443F434247495D5468657B7A
818089838A6C5A484A4748474948564E4D41413A3B3C4844474A413F484A52658A85AA9D
C0A3AF9CB1ABB4A6A4A09B9E98A595A18BA1857C5D594C4B42474243484F4B4146404D41
494845463E3B4453475356687390A5AAA6A89A8264453F41403F3A3B41454343495F5D49
59595F6A6461768AB47F6D7A9BA4AC927987A5BBA59A8C968AA999AC8F9A7A8A5F59636C
7E858591989C9D93B9CFDCBCB06F6258698490949B967553455353575665615F5E695E6C
577171807D8B81718FAFADB5C0B1BF90AD827F647A8DB2BFC7998758657179685D525F57
5F809AB9B39D7A50503D35393C3D403F3A393838393A38363D3C3C3C3D3C3A383A3C3C3A
3837383936393A383535383A39383838383A3D3D3B393A3E43433D383C393B3F3E3A393B
393A3A393A3C39343637393C3D3F3F3F3C363A3D3A3E413C3B3B393B3C3C3C3A3D3C3A39
38383838393D3A37393735383F3E393737383B3B413E3C3B3C3D3D3C38393A3A3B3A3939
3E3C3835373A3935403D3A383737393B3A3A383333373A3A373B3D3C3938393B3F3D3540
4672739FB2C4CDE3DCE4D2CEB8947268605245433F3B383B3C3735373B39373637373635
39373737363738373938363738383735373738373736353437383839393A39383A373536
3738383639393836363738383440553F2D38363C
4C4C4B4C4C4D4F4F4A4948494A4B4A4945454B48494C4340464545464746474847424048
47464B4645494B4947474645434546464849484545424143424041454645434143464542
4242444746444446494B4D4C4A494A4B4142454847444649484744414143413F3E43443F
3F464C4C4A484A4842444846414541424342443F4042444645444241484744403D3E4349
4844444340414342464544413D3F403E403E40403B3D4343393E4244423F3E3E433F4243
40474A423D3E3F404141403F393B3E41444546464544414041423F3A3C3E3C3D43423D3D
3E3E3E3E3F3F3F3E3F3F40434645403A3C3F3D3C3F42434540423E41423F423F4041423F
3C3938383D3A3D414042433F3C3B3F45443D3B3F403E3C3B4649424A463C413F423B413F
3E3B3D4142474A4841404143413F43494C45423B3A3F3F4545453E403F3B4041423D3E3D
363B423D3D424342413D3C403C423D3D3F41453E3F413F4647434646414D44444948493E
3D3D413C454143424940413F3D403E3D423D3D3F3E4144423D3C3D3D3B393B3F3E3C3C3F
4040404138404C45443C40403D4243413F4041403F41393B403D3F3C3D3E4C4D59575B51
4C4E54595F574C42444545434C4D584F56475A465F475B5150524F515A5D677A7D9C9EC6
9CB698A88D9774856D737677827E9575918596879987A0789F7FA39AADB2A282785D6246
4B453F4F524C4541555A4D4E4B5A605B575850484D3F454140483C48384D42424F707580
7F99A2BBB7BBB3CFCBDCBCC5CCD5D3B0959BA5AB9A86906E9A78A190987A8C829A8A7865
585D6A8FACC3C3B1ABCABBD19EAB8C765652485F73705E58615F664A625862516265644D
514C60727E816F627D9AA0A7AFAB87745E645458627E7CAA9E9C846C666B7D71857E9280
72807C84A7A7BBA19B774F3D3C3D3B3938383837383938353636383A3C3D3B393A3D3F3D
3B3B3B3A393C3C3A383A3D3E3937393B393C3E3D3D3B3A3B3E403E3C36373A3C3A363435
393B3C3B3C3F3E3A36373A3C3D3D3D3C3D39393938393A383A3C393C3C3A3E3C3C3B3B3B
3A393838353B3935383B39393A3B393C3A34383A3C3B393838393939383A3B3C3C3B3938
3A3A3835373938343A393A3C3B3837373B3C3A3838393732353B3F3D3837393A3B354048
8890B6C0C9C7CEBEBCA18F795B504445403D37383B3F3C3E3F39393A3938363636373635
3835353736383A383938373737373635373737373736353537393A3838393A393A383636
37383736393938353537373638363F3B363B3938
50505051525355564F4F4F50504F4D4B4A4A4F4C4D504947494B4A49494B4D4D4A49474F
4C464B45424647454546454343494D4E4D4D494544484B4B494949484B4B49474A4E4D49
47474A4D4D49494C4C4B49474647494B4A46444443414347494543454745424044454542
404246494A4644413E4449474B524540433E3D3A3D4042424140424345403C3D3D3D424B
4643464743434542383E3D3A3B3E4043423E4042404246433A3E424442403F40413D4243
3D42473E3E3F40403F3F3F3F3E3F414342413F3D3B3C3C3B3E413F3A3B3C3A3B42423E3E
3E40424647443F3A3F3F40424444413E404342424543424944443D3E3F3E423F3E41423F
3B393B3E413C3E403E414440403F403F3E3C3D3F43403C3B47494049433B403E413D423C
3A3A3F43414449484341403F3E3D3D3E4541433C393D3F4743433D41413C3F3F3E3D4444
3B3E433B383E3D393835363E3A3F393A4046493F474844494840413F39463E403D354045
494B50454640433D463B3F3F3C3E3A3A453E3C3B383D42413D3937393B3A3C3F3B3A3C41
413F40423C404840423F4645495252463D3F424144463B3A3F3E404045433D413A45423D
3D423840394B43423B4341383F3E48413D36473E533D4D5042454B555B5C64718780A98C
B88C9790908D80716160544F4A5146523E5D5568647873896F8B8FABB1BBB5AAA8A9B2A8
A288958DBC9195745C62555A595F5A545A4E555062565642463B3F3E434146413547656A
7A7F959BAF8CB2A6C1BACABFCED9D4B29E967D696453454D41655A7555635A867CB2ABB6
AAAAB1BABDD0CDCDCBBDBEA9C5BED3A38E74484B575B5E6D7F82837984807C74878D7F6E
6159556060645D6173848D8DA3A3A07A7D5C584F55656C7A836B624B4E5B5678759AA2AB
ADC2A4998A98A9C2CDB27E5448433C3B393B3B3A3B3D3C383E3E3E3F403E3A37383A3C3D
40423E38383B3B3837393A383A373B3D3A3C3E3B3A3A3A3A3A3B3C3D383D403D39373737
393C3D3B3B3D3E3C3A3B3B3B3B393837353634353A3C3B3D3B3F393A38353D3D3C3C3B3B
3A3A39393D3F3B37393A383B3A3A37403F33373A3A3A393837363637393A3B3B3B393837
38393836363939373736383C3B383637383B3C3938383734373B3D393738393840443F70
7D9E9EA475766A665755453E3B3E3A3A3339393C343C35363A3739393836353536373736
3834353736393B373939393837363636363737373736363535393A373537393939383736
3737373636383734343737353936343934303735
46484B4E4F4F4E4D4B4C4D4F504F4C494C494B45474E4B4C474A4A4645494C4A4746444C
48444D4A464A4B49494C4B4845494A4644464846464E4E45434A4F4E45454342454A4844
42414143424042474D4B4947474748494744444748464546494443494C4843404B474645
413C3F464342403B41545D55424D3D3A454446493C3E3F3E3C3D4145443C3A3F403C3C41
3C3A3F423E3E403B3B44423C3E3F4046433D3C3F3F4140393E4041403E3F42453D3A4244
3C3F41363F40403E3D3D3F413C3E404242403D3B3F403F3D3F413F3A3A3B383941423F3F
3F3C3A3B3F4344443F3E3F40424242423F444445453F3D464C4B413F3E3C403D4A4C4B45
3E3A3C40464140403D3F413D3C40413E3E434544433F3A3A494B414B463F423E423F433B
37383F423D3E4341403F3E3F424444423C3D443F3B3D3D4442423E45453E403D413F4544
3A3F4740383F3F4044413C3E36403E3C3B3D433E41413D41403A3B3941423A45493F474F
5B55564B463B3E3B3D3745484240393B3A3A3C3D3D43453F453D393D42444546413D3B3B
3A3A40473D3F46465354564E4852503D323941423D433A3738353B40443C45373E38473F
41393B3A433D4342384A4B3E433C413A403F31434049455B5D6272838A8B939C849F88B1
879D6D998798868A7374604C493E483E443D424C454A4C5E687E87909AA19A9D93A7A8AE
949F94C7BCCDBCC2B0B09C9B938E8789866E7F768C8E9C8DA08264675251474A413D4544
41424B454E4A5661688F83959CB9C7B7AEA6856C5A47494747423B453F496D5F68879CAD
C2BEC0AE9CA79CABB1C09EA898AAACB09199725B5A728691B5BAC3C1CCC2C2C4C8CFCABE
B4A39089858174726D6A706B76939CA0947D5F575A6F6E81786B524A4E466253705B898C
AFC3CDC1C8B6A5AEA7AA895E4E453C3B3C3E3F3D3F42403C3636393B3D3C3A373F3F4146
4E524A3E3D40403D3D3E3D393B383D3F3B3C3D3934373B3C3A3939393940423C37363838
3A3D3D39373839383939393939393939383B38373D3B36393D41393834313B3D3C3C3B3A
3A3A3B3B3735313238393B443F3A34404034383B3A3B3B3A373637383A3A3A3938383737
3739393636393B3A383535383836373A323739353335393B3B3B3936373A3A3640284244
4B504D4C4044453C38363A3A3439383D373C3739364036353B3A3C383736343536373736
3934353836393B3638393A38363535363636373737373636333839353335383939393837
363637373336363434373735373A333F392D3A35
4E5154524E4E5257514B494B4C49494B47504A434A4A4446444645464B504E4943454849
4847484943444547484A4B4B424447474341434443455448454549484B41424643434544
4245454B4942484B4A4C48413E4245453F41403F43494843494942474B494B4344474949
4948423B45424545404550524A4B434045444043424646413E3E3E3D423D3E3D393C413E
403F40434542414544404044433D3E4643443F4442393F403C3C403C3F45403E393E4140
41454541373F423E3A3A3C3C40403F3C3A3A3C3F3D3E453F3F454144403E3E3F3D3B3D41
41423D42403940403B3C3E3F3F41424444494746494540434749433E403F3E4347474644
413F3F3F4B44443C3B3F3C4242403F3E3F3F3E3C374548434547423D3D3E4540443E4240
3D3741463C3F453F3D40413F414647453B40413E3D40403F393C3F403F404448403D4341
4041393B3D3F3F3C3A3B3D3F353F46473E3D4B4A48484C4541434044443A3C4B5171765F
5C483F3D484245453A3B3C3C3B3A3B3C383D42423F3D3E42433E423E4249413F3C414441
3F43464747525D636D7A7D785F5F473A3B3C41403A4A4844413A3C3D46423A37403C443D
423E3D3B42444A4A4B453F3E43443E373F424743454B5368697685928F8A8777866A8E70
845D72677F74888A9B91957D6F5E57474650635D50655D867B907480717D6E635B5E7068
7970827D9B94A6A1A7A18B846E635D5D5A5A5E6F618D84AA9BB8C0C8B2BC805851374240
4136484238413E434547565B6D838D878B9591836D54584F5A4F504A495763716A707886
9794857A716D767A91849279816E856E7A7A7B6D636975888DA8BBD0D3D3D6D6DCD9C6E0
E0DCD6DFD5D0CAC7AC9D8677727A979AB0B37F655672868E7D766B6D6162605B56545A63
5E878DB2BACFC1C3B4A4877469686858554839453C3942393E3B38403A43434361667476
919D8F61493E3C443B3F3B3F3E3B3A3B3B38383A37383A3D40403F3D36383A3B3A373533
3637393A3B3A3938383B3B3735373836323336383A3C3C3D383B3B3635393C3C383C3935
3635373E3436383838393A3C3536363737383837383A3C3C3B3B3C3D3D3B3A3B3C3D3C3B
383C3D39383A3A39393938383838393934383936373A3A36393939383736363635353637
37373738373738393A3B3B3C39393A3A3A393939353535383B3C3C3C363636363638393A
383634343638383832323B3735373339403A373A3C39363639393937363536373738393A
3938383736363535353637373336383633333537
515150504F4E4E4D524E4B4C4D4D4D4E485F604F4846474D434546464A4E4D4943454748
48474848464646464848484744464A4A47464749454A53464743464D4B44454745444642
4346434644414A4D494948454446474740424446494A464242444345444243413B404241
40444747413F403E3C3F454841403F454A4842423F41403D3E40403C3D3B3F403C3E413E
3F3E3F42444546493F3C3C3F3F3E42483B3F3D43423D42423D3D413D3E443F3F44423E3A
393C3D3D3C3F413F3F414241444443413F3E3F4038393F3A393E3A3C3D3D3E41403D3D40
3B3D3A41413C42433D3B393D434747444649464345413D4040423F3E42413E4141403F3E
3F403F3E403D423F3E423D403C3C3E42464846433D423D383D4447493E3E4440453F4340
423E42443C3A3B3436383A3B3D4142413B3F3F3C3B3D3E3D36383A3A393B3F43413E4341
40423C3E3B39383A3C3E3F413F4344443D3B423C3F3D45454241414A4460668C6F825947
3F3A3B353B384246393B3C3C3A3A3C3E37393C3E3E3E3E3F3D393D3A3E46403E383F4342
4040403F5860696E6E6A61595453433D3D3C434245483E3F494A48414245474344484847
404648524C4E4443443F3C3D40424140474445414343404A3C43484F4D4C5045453F454E
41464A4F5F6A87928D86887F67565A53554F594F5257546365655555494E464D4A44565C
5A5A505E56686D7E868F8A896D57494760526A505C5159637F89A1A3C3CABB9F66454442
4B41493C393E3C3D3D3B46474A4E4F4F5D7272615A4D5A52574A4A46384045627C939094
8C8B85806D574F465C61596656696D757C7D837D75726C6F64698586968EA4B2BFCFD3D2
DFDCE8E3DEDCD9DFD8D4C3B6ADB3B39C8A926E62475461726B6A6C7B71716C635D585048
3E506A69888FA4AEBAAA969399A4A89486605842403B3F3C3F3C3C4A50697B889CACBDD0
CAC8C4BC6D594746403D3A3A3937383C3D3C3B3C3838393B3C3C3B3A3B3A383838383837
353638393A3B3A3A3A3D3C38363839393537393B3C3B3A393B3C3C393838393834383B3B
3B393739373737393B3C3B393435383B3D3E3F4038393A3B3A3939393A3A393A3A3A3A39
363838353437383636363535353637373638393838393837313539383533343639393938
383838383C3C3B3A3938373738383939393838383A383737383939383737363636373838
393837373838393936353C39363734393C3836393A383737383939373635363738383737
3736373736363636353535353536363533333538
524F4D4E51514D484C4B4947484B4B4A5983845B49535349494A4A484849484645454647
48484847484646464849484745484847454242444B4C4A3D4C44404F49484A4A47484741
454A45454342494845444447484747483F3F41444543403F4741404044463F3B47484643
42434444494A474445454649443D3C42454544403F3E3D3D4044433F3F3E41423F3F4344
404145464646454242403E3D3D3E4246414644423F3B3C363F3E423D3D413E404C453E3A
3939393B41403E3C3E403E3A414141403F3E3F3F3E3E423E3D403C3D3B3C3F43423F3E40
40413E403E393C3C413E3B3D414342404647423F403F3D3F3C3E3D4045454141413E3C3C
3E3F3E3C3A3A404040413C3D49433C3A3B3D3E3D42433E3C40403F42494649434740403C
3E3D3E414545403A3C3B3D41424242433D3F3E3C3A3C3E3E40403F3D3B3C404349464741
3E3E3A3B443C383B3D3A393B45464242403F4036443E45474443485A80858768644A4235
3C3E44393A363F413B3D3E3C39393B3E3E3C3C3E3F3F3D3A413F3F3A3A3E39383B3D3C39
393F464A44424142403D3C3E43413D3F3B394143514F444C5C615E5370637E65795E6C6F
82808778745B5245443F3C3E3E3C3E42413E3F3D41413A4143454345444449433F465167
66778385978E9F91947E877975687D808B777F7789958BA794A2898D7E8184937F4F4040
48414A445247575F6472737964564E4E5254565A4D554D595C66627D829D888D553B3B3E
4E4A51493D3F3E3E3E3B423F4D49494749595F55473E4B41453F43403D433F5671848390
A5A4A3A18768574648404742585F7E97A5A7B0AB9D8A7166786468545853697E80AFC3DB
D1E8DBDADBDAD1D0CDCDC4C2C9D6D6BB998E694D56453B4A47474C606767605552565246
3D41544E595F6C7C8D8A8B959DB4CBC4BBB182855B4B46393D3B3B43486892B0C4CCD9D8
CFAA9C847B554750403B4F363E3B3A3D3E3A37363939393A3A3B3C3D3C3A38383A3B3A39
38383939393939393C3D3C3937393B3B3637383A3B3C3C3C3837393A3D3A3A393B393736
34373B3D3B38373A3E3F3B3638393A3B3C3C3C3B3E3D3D3C3C3A38363738383838373838
3B3B3A39393C3C3B3838383839393A3B3A39393A3A3837373A3E413E373335393D3C3A39
39393A3A3E3E3C3B3937363538373737373837373C393635363737373837363635363636
393A3A3A3939393938383D3A373835393836363838373638373838373635373839383635
3535363637363636353534343736353433343638
52504E505354514E4D50504D4E51514E485153504C4546504E4E4D4A4746474849484748
4A4B4A49494747494C4E4D4C4E514E4B4B49494D4C4E4D4C69594047474A4C4B494B4842
464D4948464547414440404547454445484545484845464A454146424348444844413F42
4A4D4841494B46434846424549414041434B4E444141414143454443474442403E3E4449
4242454644464642454542403F4244463D4343403F42423B413F433E3C3F3D414B444042
43403D3D42403E3C3D3D3D3B3F3F3F3E3F404142404042403E3E3C3C3D3D4043423E3E40
3B3C3C3D3D3C40423F40403E3B3B3D3F45433F3C3E3F41423F3E3E41464846444544413F
3E3D3D3D43403E3A3A3C3D40504B44403F3E3B3740413F404240414A4D4849434942413C
3A434441413D38393E3C3D41403C3A3C3D3E3E3C3B3D3F413C3C3B39393C42464B4A473F
3B3B3A3A48413F43433E3E44424540434445473E433C3D3B3C475971677050533648343E
3D3B3F3A403B3F3C3E40403D38373A3E4241404142413F3D3E3E3F3C3D41403F423F3A36
373F4A514242413F3C3A3A3B3F393E453E3A4246434A4D58605E5B5360746C9A789A8098
858370705A5C4B4A453F3C3F3F3C3D414240413E3F3E3A44383B393F414248444E685792
76A8989F9A9898ABA5B0AAA8A494A2959B83918EA39FB6ACC1B1BFB7BFC7CDD5B471493F
3D4032493D493D4D444941494445444345444841443E454750494E4B615153584F444743
46393E3E3D3B414147464F4C5452585547484F483F353E363C3E413C4046414A4A4B4D63
66686B6E6258584A4D4840474A595E84A1ADC4CBC5B69E959D968F8C7B7C6C68656E8B98
AECACBD6D5DED9CFC8C5C6D0C6D2DEDAD3CFB8948B66484F4846434D4C4D4D484447463D
3D44445946574C5A595F696E6A7FA1A5C1ADB6A4A3766448413D3C3B3540586987B2BDDB
C8BF844E5B3B3E35434433383A38383C3F3D3B3B3A3A3A3A3B3E41443A39393B3E3E3B37
3D3C3B39383736363A3C3C3A39393A3A3736353535373A3B3A35393A413A3B3A3937393A
373737343A39383B3E3D39353B3A3837363535353D3B3837383836353638393837363739
393938383A3B3A383A3A3A3A3A3B3C3D3D39393C3B3735383D3E3C38323134383E3C3A39
393A3B3B3C3B3B3A39393838393837373838383739373535363737373636363636363636
383A3C3C3A38373838393B39383737393637373736343537363737363536373939383636
3636363538373636353637373835343536353537
4D4D4C4B4B4C4C4D454A4C4A4A4C4A46504A4851564D4951504F4D4A47474A4D44434242
444544434443434446484847494C47434646464C494B4A4C6A593F46444A4C4A4B4C4946
474D494948484A434742414446434244423F3E424240424645414642444B4A504845454D
575A565046484341474540423C3E434348585A4A42444645424042454945403F3D3B3E45
423E3F413F454C4B3F404141434547464045453E3F45443E423F433F3D3F3C4247424146
484541403E3E404040414447464442414243454643434142423F3F3E41404042403C3D40
403F3F3C3A3C3D3F3D3F403E3C3D414446423E3C3D404242433F3D3E4145464544464541
3C3A3C3F3B3F4245443F3B3646423E3D404344443D43484A4840404B433E413D47434540
44575C51463D3C474644454847423F413B3A3B3B3B3C3F4248464441404144474346423C
3A3C4140403E424949464B553D44414243424744434348423C3D3C444240423F413F3F38
42393B3C453C3C3A3D3E3E3C3A3A3D403F414242414041423D3F3E3E404344414040403F
3E3E3F413D4447423E3F3C36443C434A433F444A4146474C4B4D5B617E84A684A7819372
74625A454F444941423C3A3E43434242423F413E42423E474A4B434445444A4B4E546270
8B909C8BAAA7B3ACAC9BA19E9683836D7C758C8993908D9C9AB0B5B6B5C0BEB3986C5148
4F584E6558604D5B51544C595C65645F615B6D5974617B747D7375676B4643444B464B4B
4A3F4243423A423E434148434D474F544E4F5046453E47424445443E3D4341463E403A3D
464A494641454D424D40484049423D5465769AB7CEDCDBDDDBE2D9DBC8CBB69CA4848471
6D7E768FA7BECDCCCAC3C0C6C8D2C7DFCEE9DCD2DAB8978C71604D46534B4A494443433C
444354505B45524E4A4B49463C465A5570757DB0B0B17D614F4440404346443B3F6183A0
CED9C1896F4C3F434646553F3B38383B3D3C3C3D3C3B3A3A3B3E41433B3A393B3E3E3B38
3D3C3B393837363637383A3B393837383838393A3C3E4042413A3E3B42383A393F3E3D3D
3C3D3D3C37393B3C3B3937363938363536393C3E403E3D3E42474A4B38393A3A3837393A
3A393A3C3E3D3A38383737373738393A3D3A3A3C3B3735383937363537393A3B3B393737
393B3B3B39393939393939393A3937373839393837363636373736353434353636373737
36383B3B3937363636373738373638393638393734333435363637363535373839383738
393937353937363536383A3C3734353838353436
57585855515051544A4E50504F4E4D4B444F4F474B5653455553504D484546494C4B4A4A
4B4C4C4B4E4E4E4E4D4D4D4D53564F494C49464C4845433C4D433D4C434949484A4A4849
494B444548494E4A4B48464646444445444345484A484748504945414346434344414043
45454545494947464A4946464447453D3E49473840434645403C3F4643403D3E403B393F
3F393F46424246433F3E3F414342403F3E40433E404A4845433E42403F403C4145424143
444340403C3D3F40403F424648464341414141414343404445404240444140403D3B3C40
3F3F433E3C3F3D3E4542403F4042434348423F3E3D3F413E433D3B3B3B3F43413F41413E
39383C4041423D3E3E3D4140423E3936393F45493D403F3D3F4250643D393B38413D403B
3A484A423E3C3C423D3C3D3F3F3D3C3C3837383939383B3F42413F3C3B3A3A3B4247413B
393B43413C3E4346413C40483C46423F3D3A41424140423A373A383B403A3C3F363A403F
42393C3E4437393B393A3B3C3D3F4244434444423E3B3B3C3E413D3E4040413A3A3B3E42
413D39383D44443C393F423E433B4044413E3D4444433F43444F69757B8E73805F6F5447
4C4737403B473D3B423E3B3E4345433E403B3B3E47494043464841464F5566718C9897B3
B2C2B0A49E97828E7A85787F786B6D63818896899C808F77917E8F726E8287817F797373
82899485896C69695D64606D707B7E7C767F85949DADB5BACBD6CCC68F684945493C3D41
4341423B463B473E423E463F423E454E52585B534F49504A44424244454B47464351483A
414A4745474B50495946795C79585C58585C718BADCDDBE5ECECE9E1E0E0EAD5D5C1B7AD
899061655D6B7B8396A3B1B7B5B0C1AFC9C2E0DBE1D8CECBB2AA9E958C796F6A60584E40
516956754B513A454F514B4743464B4044444D6A93808C6F7D74716C71716852494A405F
81B8C0C5A6955B43443A49473E3C3B3C3B39393C403D3937393B3C3C3E3B3837393B3C3B
38383939393939393637383A393636383C3D3D3D3C3B3A3A3E39403B453C413E3E4A5358
5A50413C36393B3C3A3837383D3B3A3A3B3E42453F3D3938383A3B3C3A3A3B3A3A393A3A
3F3D3E41413E3C3C3A393938383939393C3B3A3B3A3836373938383B3E3F3C393A373536
383A3A393A3A3939383737363C393636383A3A3838373737383735333334353637383838
35373939393736353537343637353938373A3A3734343434363737363535363738373739
3B3B38363837363536393C3D3634363A3A353336
4F4F4E4C4A48484949494B4B4A4747494443454A4A47454752504F4F4B46444544444443
4242434546474947454445474D524C474B463F444B474D444840414C454846464846444B
4B48414548474B494A4B4A474545454342424243454644404C4E4B47403A3D3E46424042
4342434646434445434444423C3F3C39404645413F40434542404248403D3A3F45413D44
4137404B443D3D39443F3F43433E3A3B4644474040463F3D433D414141413C4142434342
4242403E3F3C3C3E3F3D3C3D4241404142413F3E3D3E3940413C403D42403F3F3D3A3C40
43444A433F3F37364644413F3F3F4040463F3E3F3D3F403B3F3B3C3E3B3E413E3E3D3B3A
3A3B3D3F3D403B3E3F3D434043424241404143444245423F40404651413C3E383E393B37
3E44413B3B3F403E404141404041403F3A393A3C3B38393D3A3B3D3F41434444444B433D
393B44403E4043423C3735373C46403C3B3A41453E383B3B3E413E41423D3F4636373635
363238383F393D3E39393A3C3F414343474543413F3D3B3A393D393E4243443B39383A3F
403D3B3D3E4445413C3C3B393D383B3C3F3E373E3A3C414D4E4F5A5B59544B454342403B
3D393D3B453F3E373E403F3B3D43433E433E3C3D46483F44475258697C889CABABA9ADA8
A89E90858B776262605E53506263707797A0A4958C828C918F8D866B647B868A969C9DA5
A3B3A49D827A656E59615A6363717A7C888E919A9EAEAFB2C2CBE5D0C394967E6E5B554F
413F433B4236483E413D443D383B404244494E4E51464A47403E3F45434A4240404C443F
3F4741444B464648444879908AACA6B3A9A3A9B0C1D4D9DFDFD2DAE4E4DBDCD3D5CCD5CE
D4CFB6999B8B79616167736E80877D848AADB4BEBBBBC0C7B9C1C2BDB0ABB3BBB6B1A28A
747786697146473F40484241444547404D423A413F575B73636F868FA2ADAE9B6C554B33
46597591BFA0A26F3C43374336373A3D3D3B3E42433E39373A3B3B393E3C393737383A3B
353638393A3B3A3A383737393835373B403D3A38393C40434C4D59536059605B8BA5B4B9
B38E635339393A3A3B3B3A393E3D3C3B3B3B3D3D363638393B3E42443B3A3A3A3B3B3A3A
3C3A3A3B3A3636393D3C3C3B3A3A3A3A3A3B3B393939383637363636373736353A373536
393A393739393838373636353B3835353739393738373636373838373536373838383737
36373738393938363739343737343A37373A3A3735373735373737363434353638363436
393B3937363636363738393A3634363B39333339
504F4F5050504E4C4E4B4B4C4A46484D48494C4E4E4D4C4A4545494E4F4B494A494A4A48
4646484A474A4D4D4A494C4F434C4A4A524E474B52484F4645414548474845454742414B
4B4842484B444441454A4A4542434340494844404348474345484246464145404E464246
49474341454043443F40433F3D414349514D4647413F41454746484C433F393F4947464E
473639433C383F42443E3E4546413E41403E444042484040433C404143433D403E444745
4445423D413C3A404544413F3F3F41454848454340413B4446414543403E3E3F3D3B3D40
373B474544483F3E3B3E3F3D393A3F44413B3C3E3D40413B3D3B40433F40423E423D3838
3D403F3C3A3F3C41413C403B3C3C3B3A3A3E454B46484440413F3B3D423E403B413C3F3C
3841443C353B43464144423E3D3F3E3B403E3F403F3B3B3E3F404041403E3C3A4049423E
3B3D48453B3E4244454443403A443D3B3E3F474C4A3B393A3D3C373D3E363B3E3E3A3E3C
433F413C4441433E3D3B3B3D4041403E44403E40454745423F433D41444242363F3D3E42
413D3A3B3C3F4344413C3B3C3D3B3D3C45463A4046484C544C42443D4142413F3C494040
3E40414542423E3D353C3E38394248463A383A3B434A4B59616E747F847C7E8475786572
58746376636356665A686779838A99A2B9C0C5BFBBAFC1ADA0827D5B5D686B6B767C8191
A8B2BEA5B499978F878F8A969CB0BDC2BEC1BDC2BDD0CAD0D1D6D5E3DAE3DFC5C4B1A48B
5F4F56547D6E7D6C67595A4F41464643454748494B3D434948453E3E393F384349483B44
4A4D41464F423F4B746286776B93AEC1D6D9E6EAEAE8DCDABEA19FC7C0C8BBC9ADBFBBC6
BCD1D9D1CCC2C0B2B1ADA993A59388617E7D7D696360657577909D9D9EA9C1D1D3D9D4BF
9DAC8A976B7B4A5A4C5346424B4C49433A3F3B404136484E54647F8AA4B7BFAB99837048
4348424D658E9F985A3C453E383A3E403D393A3E443E39393D403F3C3A3A3A3A39383737
3637393A3B3A39383B3836373635383E3A38383F4E637885AEB2C1B9C6BEC5BECAD3C0A6
9169443F3D3A38393D3F3C3937373737373635353E3F403F3C3B3B3C3B3A39393B3B3A39
403D3C3B3936383D3B3A393837363636383B3C38383A39353939373534373D423B393738
3A3A383537373737373737373A3733333638383636343334373A3C3C3737383838373635
373737383A3B3937393C353737343A363739393736393936373838363433343637343233
373A393833343637373736353734363A3832333B
494E4F4C4B4E4F4E494B4C4C494847474646464747464748404A48464C4842494B424750
4C4543424144484A4946454441464A4A454142453F464A47444443414045434349484649
434545434548464140464A494847454144444443434241404446413D403E3C403C3D3D3E
4244413C4842434141403A3F413E44443C464D42393F3F474349484C3F3F3E3E43494740
3C3B3A3F433B3A46404443454C483E3D423F4244414243403F3B38404744454E3E3D3D3F
4142424048443E44454145463D433C444A4141413D423F42413E42403F433E3E47423A41
463E3A3E42403E3D4040403E3D3D3F403B40413E4148463D4340454A453B3B42443D4141
3E3C3B4745443F3A3B40413E3A3D4041414041414743423F3C434842453B3B403D3A3F43
3D3E3B43453E403C404D403A3B463F433E3A393E42413F3F474239413E433E403E3C433E
3F47474F423E4046453D3C42453C3F413A3F4641463C373D46484745383D4048423E453E
3F413C42454449443D42433F3F43454441413D3F3F444D46453E45473D3E41383C3D4040
3B37383E3D3B3E44433C3A3F4443403F3E3E3F3F44464744444545433C3C41403B3F4643
3943444142403E423C37373D3F3A3B4041463F4E566A7B848D8C9690897670645A625965
5C6E616F5B6E6671858EA0A6A5AAA79974817285757E7C74606A6F6F6766676B76879AA6
B1AFA9949496A09E949AA1A8B2BDC4C6C9D1CAD3D4DBD4DCDAD4E3D0E6D8EDE9DCE3D3CC
A4A49FAEAFC4BEC79FB191A68B8E6D78685F5C5F47494452474141413E544A4D45493B4A
4C87987A764B54496DB3B5CDA7BFA0B4BEC8DEE3EAE9EBDED2AEA98C8A8784859E8C8F81
A3AFC5C3D2D7D4E1DAE1D0DAC8D7BABBA0B8A2A676724F4A434D545F6A668598C2C2D1C7
C6A2886C7C76807A847A766C625D47443E3A45373E3A3D43414C5871818A9EA6B1ACA182
5A424E45434855616C4C393D3C3B3E3C3E3E3A4642403D3B3C3C3C3C3A393736373A3D3F
3B383A3B383A3C393734353B3C37383E46556A89AFC4CBD0D2D8D2D8D1C9B5B39B997057
4835393C3A3D3E3A38393A3834373A3C3B3A3A3A37383B3D3C38373A36383A3D3D3B3836
363A3D37383B363A3A3F393843423B403A3837383635394039393839393A3B3B3D3A3635
3738363435353636373737383636383C3D393738363435383938383B3633373F403A383C
3535383A3C3C39373535373839393938303133353738393A313335363536383B3A393737
3839393834363737363637383236393936353639
4E51514F4E51514F4A4B4B4B4A49484745474A4B4C4E4F4E454E4C4A504B464C564D4B4B
433F434641454A4C4B49474745494D4D4B4A4B4E43454544454746413C41414348474446
47494A47474845413C4246464545433F42424241414040404345413F42413E4040444440
3F454A4B4A4445434445424852524F463F413F35434744463D4142494644414043464440
41413F41443F3E4641413F3F44454344403D3F413F42464545423E404442414943403D3C
3D40414142433C3E3F4045423E423C43494242413E424042413C403D373D3D414A443A3F
3E3C3C3E3F4043463E3F403F3E3E3F40403F3C3A3F45443D3A3E424545413E4044404545
42403D463E3E3D3B3C403F3C3C3D3F4040404041383A40413E4245403E393A3D3A3C403F
3A3D414B4D46413C3841393A3D423B41433E3D3F4241414342413E4540413C3F3C3B413F
3E3F393B393B3E42424143463E383E423C3F443E3F3C3B3B3A3B40473F42444C4A474B42
3D403D42434145414142423F3D3E3F3E3B4243433C3E4C4C433D3F403A3A3C373836363A
3D3D3E40413C3B3F3E3B3D434A453F3D3E3F3D3B383B3C3B3C3E3E3B373B4140393C4241
3C44443F403F3D403A373A40424041444655597789A1B8C1BBB6BBB1AA9992868281837C
7D7F777E6E8174848E9598999B847F60534B5550575561726F879A9D8F8A868B99AAB7BE
BFBAB7AAAEADB7B8B8B7B2AFB2BBC2C4BBC4BBCAC2D5CED8CFCFC9D1CCD3D0D3CAC8C6BE
BEB3ACA7A6A8BCA7B2A2AAA7A8A7939B91989AAB9EA0929E88634C5A8CB3A5B39FA98CA1
A2C9D4C6CEB3AFA3AFC6DCE1E6DEDAD8D6DFE6DBE2E2E4D9C6C8B2C68FAA90AA8E9A797E
6879868CADB8C1D7D9E6DAE5E1E0DAC8D1CCC7BBB7AA9A716E474C40453F495A7692B1BC
B9AE708C5D8153586E6E8690A7A487664F40424346453E3F42423B42484C617082A7B8C2
9A794F3F3E3B434F573D333D3B3938393F403A383C3B3A3B3C3E3D3D3A39393838393A3A
3A36383A38393B383D3A3A39373C516691A2B2BCC0B9AFAFB3B2B198987C6E5E4C533E39
3B32383B3B3E3E39363737353B3B3A3939393B3C3838393C3A37373A3738393A3A3A3938
35393B32353B3637303A3E495B5A4E4C3B3837383735373C3938373738393938423F3A39
3939363336373737383838393A3635363635373B39363639393737393236425051453A37
373737383A3938363738393A3A3A3A39343435373738383833353636363638393A383636
3738373734353636353536373336383835343638
4C4D4C4B4B4D4C4A4C4A494A4B4B49464E504F4B4A4E4E4B454C4A484C4842474A494C4B
4646494A46494B4A4846484A48494A49474546474B4845454A4E4A45474A484748464344
474A4C4B4A48454240444644444647464141403F3F3F404042434140444340404146453E
3D454B4B544B4B46424341474D534D434549443E404240423E44464B4642404144454647
4343403F41403F414642403F3D4043424742413F3B3D41404042403E4243444A44423E3D
3D3E3F3F4247403E40444B4542433D414641403E4247444745404340393D3A3D44413C42
3E4346413B3B40453D3E40403F3F40414C443B393D3F3C373840414047463F3D3E3E4543
403F3B3F3C3D3B39393B3B393F3E3E3E3F404040393D43433E3D3E3A3F3D3E3D3B414643
423F41424546444643453D4144423B42413D3A3A3A3B3D403E404147413F3C3F42404647
47463E3E404445403C3B3B3B3D393E403B3D403A40403F3C3633383F3939394143414239
393D3B3E3D3B3E3C41403F3F3C393A3C404443433D3F4A4746413E3C3B3C3D3B3E3A383A
3B3A393B433D3A3D3E3C3E4447413B3B4042403D3E403F3B3A3A3734343A403E393A3E3D
3E44443F3E3E3D3E3B3A3A3B3B3B3C3D4B657196A2AAB3B0AC9B907D7A77807C7D85838A
6E82697F73887A928B8D777078627766886D80657261606A5F6269685F5A56565D636667
676265636E6D777B8380797273787B7B85829584978B9D93A99DA3969F88887F78746E64
6C6057515355524D4A4C51515F6F5A757A87AABCC7C7D7E1CEA9A19ED3D4E5C8C1ACBAAE
CDD3CDCBDBE0E0E3E4E5DDE9DAD7CAD1C8D7DCCED7D4CCBFAC9FAA9291747F7E7D849586
9A86988774818EA4AAB9B0BCB7B9A3A89BAA9B9D9099898A6F6652504A483F453F576570
7E68746182676D584D525E8096C0C0BB9F7D69524A47473F45443A3B413F454F4A628689
936E4D363D3A44556456463D3D393534363B3D3A3939393A3C3D3C3B3A3A3A3A3A383736
3B36383938393A3636383A3A373C516679858C887D6F66676266594B42433B34363F3437
3C34353436393938373839393E3C3A39393A3B3B3A3838393836383B383837373738393A
2F363C36393E36373C546D818973503F3B3836373736363739373535363736353D3A3838
3A3B393838383838383939393A363334333335393B39383A393636373533363C3D373536
383736363737363538383939393938383737373837373636353637373636373839373535
3636353534353635343334353537383734343537
51504E4E4F504E4C4E4B48494C4D4A474B4E4B44454E524E4A4E4C4B4D4A454843484C4C
4B4B48425151504B47474C504C4B4947464545454D4946474B4C4944504F4B4746454547
43474A4B4A4846454546454141464C4D4342403F3E3F4041414140414444413F43484741
444C4C45504648443F42444A474D4841454C484141414042434442414A464344433F3F42
4445423F41444441433F42443F40433F443F3F3E3B3E43424147453F3F3F3D3F40404040
403F3D3B3F423C3B3D3F474347443F4042403E3B41464447454043403F3F3C3C413E3C42
42494C443C3A3D3E3D3E3F3F3F3F4143453E3A3D414140414146413F47463E3D3D3E4440
3D3F3B3E4946423D3B3C3E3F413E3C3C3E3F3F3F3C3E40414043454645403E3D3B404848
433C3F3C3E43404447463E3E413F3A3F44413F3D3C3D3F4241404044413F3D3F433F4043
4544403F3E40413F3B3A3B3E433E3E3D38393C3942403E3D3D3C3A3A3B3A3A3C3E3E3E3A
3C3E3F3E3B393C3D3E3C3C3E3D393A3F474641413F41483F48433C383B3D3D3E3C3B3C3C
3A373B41413E3D4142403E3F403D3B3D4042413F393A3936373A3A37373A3C3B3A3C3D3A
3F43434040403E3D393A3A3A3D444A4E586B697D777070686558534A535A67648383A17B
6D524C5650685E837D9181868E77785C7A55594453494245433E3B3E3F4042413F3C3A3A
403C403D47454A484543403E434B4F4F515A6066575D5750534B4C4C524B4D4E404C4449
434A45534B50554A4E494D4F43474B5050646E8D97C2BDDBD2DBBACDC7E5D2D3B0AA7B79
908D91AAC3DCDCE6E8E6ECDDDEAE917D9DA8B3B2C4C8C9C2BFC2ACB0928C766D6456595D
6B9292A7A9B4BABDAEA38786726E675E5C585C5F4D4D4B474846494A3B4143463B434240
464440494A5151575455707A929FCAD8D9C6BFA08E7C715245483E3A424441413F3D4148
4D54413D393A44576F766447403A3E3B3536373B3E3C3B3B3B3A3937393A3A3A3A383736
3E39393A38393A353B3A3B3C3935363A3F41403F3D3B3B3C3B443C4037443C3B3B413739
3C3634323637383838393A3A3A3A393B3C3C3A383B3836373736383C3938383635363839
34373B353436364277889391816143373937353638383634393735353637363436343435
37393837383838383838383837353537373433343C39393A393636383733323434323337
363534353636353436363636363535353737373736353434353536363636363738363434
3435343334353535333233333737373634333537
514F4E4E4F4F4E4D4E4B49494C4D4B494A4D4A44464E504B4A4C4B4A4C49464747484643
474C49434A4B4A474444484B474544444547484848474647474543414746464545464747
42444748474444444244433F3F4448494645434140404142403F41434343413E3E444442
444B4C474F4346443F424447464644414147473E3E40444342404040403E3F4343414246
3E3F3E3B3D42433E3D3A404542454945433F40403C3E413F3D45443E3E3D3A393D3E4041
403F3E3D403F3A3E3F3C43454541403F3F413F3C3A3E3D403F3B3E3C3D3E3F42443F3C3F
3F4548444141403E3F3F3F3E3E3F4244403E4045444141464746403F43403C3F42424741
3F4341454946423F3C3B3C3E413E3B3B3D3E3F3F42403E3F4447484A453C3C403D3B3F43
433D3F393A403D413F413F3C414241404241403E3E3F404147403D3D413F4040423E3C41
43403D3B3B393B403F3A3D45433F3F3D3A3A3C3A403D3A3B4043423E4142413E3D3E3F43
434445413D3D3E433E3B3C3E3D3A3C41434542423E3F4741433F3835383B3B3C3F3D3D3E
3C3A3D434240414444413D3C3E4041413F3D3C3C3C3B3836383C3E3C3E3D39373C403D39
3D3F41414143423D3D3F3F3E3F43484B4851464E4543484745434F556975817B75797E75
506056757586778B6F73595C5C514A414B433F434141414245424141383B404345454546
3B3D423A4242443B41403D3D4450595C7D769378896978626E635C514F464B4E4B5E6779
809095A5A0B592A0688E698C6E7F6D74685B6A6F9D9DC4BCD3C7D8C5CAC2E4D7DDC0BE92
7865607D9BBFCDD7D7E4D8E9CFC891785F5961687C8CA4AAB6CAD1D3D5CAC7B5B7999A86
8A8C8B9CACB6BEC4C5CCC4CCBEC8B2CDAAC1ACB98C83776D61594C454241484143424840
43474551474A414546565D7D778DA8BCCED7D3E1C0C8AE987E7E694B434746453F3B393C
3C453B3F393B3E495C747A7447393E3E3E3E353C423F3C3A3A3A39383A39393939393939
413C3D3D393A3A35393534373B3B3A3A3A373637393A383539363E363E333933373A3537
3A3838363D3C3A3A39373636383737383B3B3A383C3836373736383B393A3A3836353637
3D39393638415374938F7E654E3D373B37353435393A38343A3836363737373636363535
3535343337373737373736363635373A3A3634343A38383A3A3737393836353736353536
333334353737363536363535353535353435353535343333333333343536363637353333
3434343334353535333233333838373634343537
4E4B4B4C4D4B4B4C4C4C4B4B4B4C4C4C4C4F4E4B4C4F4B44474746464848464547484340
474C49464143464747464545454544434445464649494A4B494544454544484A48484744
474646464441414242464846454747464746454343434343424144454140403D3D434745
444951565144484842444241423E3F40404445413D414843403B424743424242413E3D3D
3C3D3F3E3E434540403E3F4141454847474243423C3C3D39373F3F3B3E3F3C3B3E3E3E3E
3D3E3F4142413D43433D4448403D413E3D43413F393D3B3E3D3A3E3C3E3D3E40413F3F43
3F4143444444423F3F40403F3E3F414341434648433C3C41434141423E3B3D4241404543
4143424841414344423E3D3D3F3D3B3B3C3E3F3F4343404246464447443C4048443C3C3D
44413F393A3F3F403B3F433F444445423D3E3E3C3D40403E4A403C3A413F4141403F3F4A
4E464340423D3D424039393F3B3B3E403F3E3D3B42413E3A3A3D3F404141423C3A3C3C44
4341443F3B3C3B40403F3F3F3D3B3B3E41413D403F424941413D3A3A3B3E3F3E453F3B3E
41413F3F43424040403F3F3F3B3E42413E3C3C3D43413C383A3E3E3C413F38363E423D39
3B3B3E3F4044443D3C3E4143413F3F41494A3F413B434B527176878B928D87756C5F7C5C
66566063575E505942483D474044434E41483C413E3E45413E3C3E333E3B393B41454442
363C42394142453B40424241444B51526168677569726C6E6073649178A08A99908B9796
AEACB5AFBBAC9F6C5D5353647376817D7A7E758483A18EAF9ECCACBBA3B69DB9ABC9AEBA
AAABA79D7E6F8993B4A5BBA3B59FAA889C88827870646B6A7EA6A3CEC1E6DAE0CFD5C2DF
CAD1C9D5D2D7D9D5D4D8D0D6E4D6E4D2E7D5E4D8E2D5DDCAC8AB998276696451514B5652
595458565D504D454B4B44455D5E7D789FA2C2CAE0CDDBC9C6C7B88E706C68656058594A
59473F3B3B3E3D4244587595765D4536393C353D413E3B3A3B3C3D3C3A393838383A3B3C
403D3E3E3A3A3B383D3A383838393B3D3A373839383A3B383A36393938353A3A393B3B3C
3E3C3A393D3A393A3A3837383937353436393B3D3B3836383938383A393A3C3A37363638
3C383B3D434E6285686050413936383B36353435383B3935393838373737373836373738
3838383737373736363636363A38373939373739383637393A38383A3835333131323537
333334363838373538383737373838393333343434333332333232343536363636343333
3435353434353635343334353737373636363637
504E4F51514E4F524B4D4E4C4A494C4F4949494B4F504E4A4A49494B4D4E4D4C474C4A47
4946414248494A4C4D4C49474A4A4A49484849494A48484A494747494B484A4B47474844
4C48454545434346474B4C4948494846454545454545464645444848413F413E44464949
474A535D483B44494649474244423F41443F3D4346464B45463F41404142413F3F41403F
4342474946494C4844433F3E41424142423F40413E3F423F3E413D3B3D3C393A3D3E3F3E
3D3D3F413C3F3C3F3E3B40403F3C433F3B42403F3E423E403E3B413F423F3C3C3B3B3F45
43414143444240413E404142414040403C3D3F403E3D40433C414C4B3E3D42413D3B4447
46433F474445484B494341423C3C3C3C3C3D3F403C404143484649524540444945403F3D
3C403F3F40403F393B393E3C423F474B40414040434747444740403C423D41403B3D3E4C
5045433F413E3E41423E3C3D383A3C3F403F3D3C4044453F3B3B3D3E4140413C3F423D45
403E433E3B3C383C4042413E3B3B3B3B41403D3F3F41473E403C3F423F4245403F3A393E
444544433F3F3E3D3D3D3F403B3C3D3E3E3E3F403A393736393E3E3B3E413C383E403B3A
3C393A3B3B42433C48464748433B393D484540444559616F817E7F6E65595343423C4542
3E4340403D3F3C443B3F3B423C42393F373E4042403D4440423F403545413D3C3E3F3C39
3F42473F423E403A3C414341404143424140464956545C63787BA197BEA3A588806A6A5C
675F67565B4C5240454A5554515C5961686A73767F6A8270786D7A6870695D5F54687A8B
9498A0B3B69596645D5255645760625D5957636A76747D808C92ADA2CABCD6D2DBDCDFD8
E7CEE5DBD8D8D7D0D4DEDEE6E9E5E2E4E1E8E9E5E2E2DCECD6E5CCCCCCC0B2A693909092
A9A2ADA6B19B96896F744F514D4A4F4D596E6E998DABB8D2CFD3DFD2C3C8CAC6ADA99394
7C6C4E44393E3A403C40507394936C4C3F3132373D3C3A3B3C3D3E3D3B3A3939393A3C3C
3B3A3E3E39393D3C37393A3A393A3C3D38343637363A3F3E32373542323D363535363A3B
3B3B3A3A383535383B3A393B3B39373635373B3D3A37373A3C393838383A3C3B38383A3C
3B3C403D3F424452423E3938393B3C3B37383635373A3935363738373635373A3536383A
3B3C3C3C38383837373636363B3837383837383C383636393937373A3636363636373636
3635353637383837383737373738393A3434353534333232363534353737373535343334
3537373634353636353536373737373838383837
4C4B4C4F4E4B4C51494D504D49484C51514B4747494A4949484647494B4D4E4C41484A48
4946464E4B4844434343413F414244454546484A45403D4043434345494343423F434A48
4E4844454646484C4A4B494441444646424244454647474748474B4A413F423F3F3B3A3E
3F3E4249483A43494547413941423D4149413D4C443F4446534E4A3E4647433E3D403F3B
3C3B4145404143413F413D3D45443F41484343413C3C3F3C3C3D39383E3F3E423A3D4142
403E3D3C3D45424140404540413E4741393F3C3B3F423D3E3C393E3D403E3F403C393A3C
423F3F42424042463C3F434443403E3D3F3D3A38393B3D3E3A4658544041483E3D3B484F
4F494249414041423F39383B3A3B3C3C3C3C3F414147484645424858434041403C3E403C
3E413838393B433E41383D3E464456643E3E3C3C40474744423F4440443B3F404344424D
4D403F3B4141414041413D393B3C3B3B3C3C3C3D383F45454545433F3D3B3C3840443B41
4442494543443C403E41413C3A3C3D3B3D454744393642403B363E443D40453D42404142
413D3D3F383B3D3D3D3D3E3F43403C3B3C3D3C3B42423F3D3F413D383A413F3B3E3D393A
3D373636373F423B3D393A3F3E3A3F493C3C4246434E434948494E42403D43393F354739
4439433B47403F3F3E3C3A3D3C4A3C3A453A3F373E3D3D3948403C383A3D4041403E3C3C
3C3B413D41393D3C3D40403B383B404347504F717A9293AB8FA191AD8C955B4350434144
3B454C456A4E6B5A7F7393727E7B79747A8180877B6565826B6B5E725974637C4F5A3F5A
535D6A849C8DB68B9A79545E44473D484043443E49464C52596D6D908AA09DB5ACB8B1B6
A1B7B3C1BBC0C5C3CED8D7DDDBE0E3E7DBE0DFDBE7DBE9DEE3E1E5E2DFDFD4E0C5D0CBD7
D2D1D4D9DBD8D8D9D7D7A88E785465737A88847869688AA3CDC4D3D5D0DCE1DED0CDD3CC
AB7D674840443A41423E33416FA0927A5D3A3E3E3C3B3B3B3D3D3C3A3C3B3B3A3A3B3B3B
37373C3D38393E3F3F3E3D3B3B3B3A393C363638363838313B3A41343537423937363A39
363738393935343839373638393A3B3A3938393A3A37383C3D3B3837383A3B3A39393D40
3F44453D3F4137373B3B3D3D3A383837393A383536393834333638373434373A38393A3B
3A39383739393938383737373836373A3A38383A39363638383636383435353434353636
3A38363536373837353535353537383936363636353332313A3836373838373535343334
3638383834363737363637383636373839393838
4C51515256534E514E55534F4D4949514D4B4D4D484A4F4E4D4C504D484C524D4E4E5153
504B48494B4D47454C4D48474547494B4B4A4948434B4A4546494B504C4A49484748494A
41474A47464A5053524D45444845454B454847434347494648464B45464B42403F474943
3F4344413C3E434745403E413E41423E3E42454542444959635643414644403F40424140
3D42464A423E4541423D3F413C3C414341434043413C40403B3A3C41423E3E403C3B4544
3E4143473C4041463D3A47463F373A423E3A3C3F3B3D40403E3D3D3F39454B454143433F
47444345454242463D403E3E43423E3F393B3D3D3C3E4246414048433F3F393D433A404C
4A41414539453D383B3E42413C3D3E4042424140374043413C4B46473F3D3E3F3C3F403B
3E3C383D3D404B423C383C4D4A40494D3E3F42403D44453A3C3F40403F3F4143373B4245
4241413F3F453D3C3A394039434045494340464B433E474B495B4B493A36404141413B41
3E3E4043413C3B3D413F3E3E3F403F3D383D3E3B383A3D3D383E3D3D423F3E443E3A3A42
4847413D3939403A3A413C3D4041413E3B3B3F433C3D393C3E444B41373D3A3E3E34373E
3938393B3D3E3D3C3D3F3C42433F42404F47433E36383D3C353D3D3B3C3A3A4136363738
3A3B3C3C3B3F373D3F373B3D3F483D3C403E43423837403840403E38373A3A3D393B433A
3D393B4237453D3F3C423C3F404B51616C729190BFA6B4A39B928E848579716756515A5C
6260666271656E83819782997A7D6E7473726F746D6B5A685D5C4F4C494C54556355524C
4C574E5059666474698A6A8279587044423D3E434049404442465147736A7B7FA7A59D99
858878887E86838B8B9195A89FB1ABBEB2BBB2C2BFBAB7B3C3D6D6DEDCDBDBD6E1D5E1DA
DEDCDEE4DDDCE1E2DFE2DBE2C8978B88A4B5C39B9474878C9FBCBBC3CAD4CEE0DBDCD5D7
BBAD8A725353463E39413B373D6C9BA096805D5B42413E35393F433E3B3D3F3F3E3B3836
3837393E3E3C3D40383C433D40333A433D3D353E3E40373D3B3D41323B3B403635413B32
40383A3A34373A3A383838383B3C3C3B3938393A373839393838393A362F3B44415A8887
A38E895C3C383A3A393C3C39383A393637383A3C3D3D3D3D363838373534363837373736
353537393A3B3C3A38373838363738373636373936363737383838393835353737343436
363636343334373A36353536383836343135333235333238333334353637383834353635
3536383B37353536333235383535363738393939
4B4E4B4A4D4C4A4E454A48454645464D4D4B4D4C47484C4B4B4B4D4B46494D4943444649
48444446464943414D554F473E44494946464A4F404745404345464A4D4A484646494D50
3D444948474A4E50464643444846434645454341414446454A474B464648403F41474742
40434747403E3F44454342443F43444240413F3C3E3C3C4146423F43474340404244423F
3E4142453E3D47453F3A444B4340413A4745434D4E4442403A393A3D3F404143403C423E
373C4045414341433D3B443F41393B3F3D3B3E3F3C3A393A3D3F403F3D41423F3F42413D
434140414243464A3E403F3F4445434741413F3C3A3C4146403C403C3C403D413D3B4146
4443433F3F49423C3E4045443B3B3B3B3D3F42443E3D3C3B353F3B4440393B4141424444
3C3E3B403E3C43403F3C3C49494446413F4144403C4246403A3B3D3D3E3F41433E42413F
4144454543463F3E3C3A3F3A3B3B404240434642423C44454252464639363D3E3F413E45
413C393B3D3C3D3F45423F3E40403F3D3D403F3B38393A3A3B3E3E3C3C3D3D403E3C3D42
44423F3F333339373A4241443B3D3E3D3C3C3F413A3B3A4141414338343C37393D3B3E3E
3938383A3F4447484846434A483D3E403D393B3D3B3F4341393D3B3B3F3E3B3D3F3F3F3F
3F41434543453C3E40393C3F3E42403C3F3F3C3E40403E393E3A3E3B353A3D424141453A
3E364539444848504D61676F7589909AA5B5A4C3B4C6AFB29FA5A0AEA7B2A8A99790918B
9191948791748E6988626E68666A5E6568717C8A7889749279917B7A6F6B78606A54636C
7D8B83837E7C706F69505A547A6F8C7F5E6E4948423742453F3C393948495571799991AD
AFB8AFA39590807E7678707374757F737F7C878C94918E858C9693999D9F96ABB6CDD8DD
DCD2E3D6DCD2DDD2D4D7E0E2DED4C7C2A0BCCDCEC4BBB1AD9B9F9D96B8C4D3DCD6D2DFDF
D9C7B89E9B8685544C43413F3A40657696AF979373785D473B413B42403B37393B3B3B3C
39383A3D3E3D40443E403B3E42403A404140353A3D423D423A413E463B40393C363E3939
443E3C373938383939393B3D3C3D3E3D3A373636343535353536383A3643538D89C5CDD3
D4C1A8824B4C3A3B35393C3B3B3C3A36353536373738383836393B3D3D3D3E3F37383838
37363839393B3C3A3837373937373737363636373434343435353535333233373837383A
363636353536383A3C3A3837383736343439373436353336333435363737373734353637
3737383930323943443933373535343535363838
4E504E4C4E4E4C4E4C4E4C4B4D4F52574C4A4C4C47474A474B4B4C4A46484A474E4D4E4F
4D49484B484E494249504A3F464A4C4B47464B504B4F4C494D4E4D504C4B4948484A4C4E
505456514A464442434847474C4D4A4A46444343434344464F4B4D4B4A48424344454542
4144484B4A454141434241403E4041414142403D414143423D3E42434544434444434344
4A4C4A4B433F4745473B434A4040453C47403D4B4E413E3C3A3B3B3B3C404242413C423C
35383B3F3F403D3D3D404640433C3B3D3C3E403E3E3E3E40424445463D3B3A3D41423F3A
40403E3C3E4347494547434042403F434745413E3C3D3F41423D3D393A3D3A3C393A4042
3F42423B424C4641404045443C3D3E3D3D3E4145403B3A3D353D4154493C3B43423E3F40
46453E3D3B343B4247443C3D3D3E45403F3F3F3B383E423D3C3B3A3B3C3E3F3F3C403A37
404340414A4842413E383A393E3E403F3F46483F413A3F3E394640413F3C3F3D3C3D3B41
4A423B3C3F3F3D3D43403C3C3E3F3E3D3D3E3D3A393C3D3D3B3D3E3B383D403E3C3B3D40
403D3C3F3F3A3B39393A373B393A3B3C3C3C3C3C3F3C383E3D3A3E38384139363C3D3D38
3D3B3A3A3B3D3D3D403E3D4845383A40484442424041403C3D3D3B3C42423C3A3A3A3A38
37383C4040433C3E423E3F423B393F3B3D3E353B393F393C413C40433F3E3A3D3E424A44
5458606A6C8A7B9391A5ACB2B0BAB9BDBDACB58AAB7C8F7B817F877C8373756E675E584A
4F51503C433F3F403F413F4340463F4542434C564548504A5B5668607C72897B94828B95
B6CCCED7CECCC7BDA46B574F4968657C6D916A6B674C4841493F474343403F47595F7071
A6B5C6C7D1C9BDBFB9BAA8999C90969393989BA6A5ABB1ADAFB2AEB2A59C988E9F9CACA6
B7B9CFD7D3DDD4CCD4C7D0CDD4E1D4D4CDD2E1DCE5E0DBC7B2A0896E7D88A3B2BDBDBBDC
D1E5CFC2C8C2B89B6B87605C4444434B5B6E7D7C7F7E6F48483B3D3C3F3A363D3F403C3C
3B3739393C3939383D473845414A37403A3E3837373C393D43433D473A3B39463A3F3940
3A383839413B3A3E3F3A36353B3D3E3E3B38363636373737383A3D40555C9BB0DCDBDFC9
D0B6AC7659433E343B3D3D3B3938363236353534343434343235383B3B3C3C3C38393A3A
39383839383A3C3A3736373938373636363635343434343333333333323234373938393A
36363637383939393C3A373636363535343A3935383A3734343435363737373634343537
383837363735384A584B38373534333233343638
4A4C4D4E4F4C494847474646484A4C4E4A474A4B474749454C4C4C4B494A4A494A484747
45404043424B4D4745474642464443434344444444464341464643444A4B4C4D4C4A4746
4B4E4F4B453F3C3B4147454146494747484545494945444746424244433E3B3E43434444
444346494B484441403F3F4041403D3D3F4142413B3C42423B3E423C3B3D414444444B52
484C4A4A443D3F3C4A3E3F423C3F4643443F3841423A3B3A3D3F3E3A3A3F403D3E3B4441
3A3B393A3B3E3D3B3C424642433E3D3D3C40423C343B42423E3B3C3F3C383A4044413D3B
4042403B3B4043413E42413F41403F4445444342403E3B3A3C3C3D3C3B3A38373B383D43
403F3F3D41494644413E42403F424544413F3F4144434343363C42574C3F3C413F3C3B39
42403A3C413D404D3E413E403C383F3E43423E3A3B40403B413E3B3B3C3D3C3B3A3C3539
4743393E423F3D40403D3F423F3C3C39363B3F3A413B3F3B373E3C3E4140403D3B3A3A3C
3A3635393E3E3E3E3D3A37373A3D3E3E3E3F3D3A3A3D3F3D3A3A3F3E3A41463F3A393A3E
3F3D3B3C3F3A3A3C3D3A393C3A3A3A3A3A3A3939423C383E3C373D393E443C393B393B38
3F3F404242413D3A3A3C3D46453B4044443F3A383A3E403F3E3E3D3F42413D3A3A3B3B3A
37383C403C3F3D3E433F3C3D453E3F39383B363D383D393E3E3A343E4949454E5B697A7C
9A8DA38CADA6B2B5B8BAB3B2A29B8F8E7F7C675D564C46434043424945484242463D3C34
3D414435393F383F3140363B393F4047453F41433D413D46403A3A3B3E3C4C4F57616E91
AED1DCE0BBA39C8C9E6C634547425558607B7B848981665B6D648D777C6D6A4F5E574B5A
6E989BC2D2D0CFD6CDCEBBA6A3798C7690809CABC1CCD7D9DBDEE0E3DADDD5D5CBCFCBCB
C6BAC8BAC0C4CAD5E0D5D4CDD0DBD0C6C9D5E0E9D9E8E0DECCBFA1885F585E757A79939B
BFBECDC3CEC8E1A6ACAEAB816D524F3C415240464D534B51424C44463D3D383A383F3D3E
413C3D3A403E42413846414043433B453F4A4E4F56636E7870605B5057546A796B735F7C
535A40403E3430373C39383B383A3C3C3B3A39393A3A3A39393B3F4254768BC0AFC49E9D
6F655D4E383D37373A39383636393B3C3A39373534343434333536373736353538393B3B
3A393939373A3C3A3735373A383635353636343236363535353434343535373838373636
35353537393A3937353434333434353531383835383E3C35353535353535353635343435
3737353436342F3B4E4735353534333333343637
4D4E5052514F4D4A4F4E4E4F4F504F4E4845484947484A464A4A4A4A4B4A494A4B494A4B
4A48494D44464A4A4541424440404143464746444A4B47474B4A454747494B4C4B494644
4A4C4E4E4A47464743494843464744444645474C4B464344484645494843444740424446
46434343404345434040424546423F3E3E3E3E3D434143413F474C45403D3D3F403F4348
42484547443E413F403D3D404342404242453F3E3D3B403E3C3F3F3C3C3F3F3C3D3B4645
3F403C3B3D41423C3B3E3F42423E3E3F3E41413A3E444A48423D3D3F3E3B3C41423E3E41
3F42413D3C3F3F3C3D42414042403F43424241413F3D3B3934393C3D3B3A3C3E3D393E43
4140413F3F464648433F413C3F424544413F3F403C3F403E3642424B453E3D3F4043443D
44413F454D453A404144424948404448474A49454343424143403C3C3E3F3D3A44403A45
53493D4645403F403E3A383B403C40413A383D3F423C413E3A3B3C3C3C3E3E3E3D3C3E3E
3C3A3B3D3D3B3C3F3D3B3938393B3D3E4444413C3A3B3B383D3C41423F44463E3C383940
45443F3C3C3A3A40423F3E3F3A3939393A3B3C3C3D3B3C45433C3E383D423D3F3F373C41
42424242423F3B383C434244413C403D554F453F3F3E3D3D3C3E4142403E3E3D3D3F4140
3D3D40434344403D3F3E3838413E41403F3F3D3E403F404546554E636C706F7C89919A9B
928E82918CA2A2A69289797464615653484A3E3E413E3F3E3C3B37404149434140383C3A
4140464041414B3D3F403E3D3C3C3C434541474545433F4447454F5249515169546E638C
AAC9CDC08560594B544D564D514D5C50626C7984838F81757C7AA89CA99EA7A18AA17D9D
8AA4A0B5CDD3DAE1D6DAD3CAC699A6889E8EABB9CCD4DADCDBDDE1E0DBE1E2E4E1E5DFDC
D5D4C0CEA8BA9DC0CCDAD9D5D1D4CFAFAEABD3CAE2D7E5DAE2E0D9D09E7E6F7A81968F98
89A2AAC6BCD0BCBD9DC8BFA793865A4642394044413D4940463744484451504F41453C38
3A3E494650516269819C7F9B7AA18AA4A7AFB1AFB6BBBEC0C5BCBDB4BDB5BAB7BAA2AD9A
AF8992746552413C3936373D393A3B3B3A393A3C3A3A393736373A3D394653545A484A47
3F3E3D3E37413E3F403D3A37353536373B3A3837353535353A3A39383838373637393A3B
3938383936393A3936353739373635353636333136363535353434343738383736363533
3434343638393735333434353434333331363735363C3B33363534323233343536343232
34353433313933313A39343A3535353636363636
54525354515254524C4A4C4D4B4A4A474945474947494B47474746474B49464948464647
454243474B44454A4743424143474C4D4B494949484946464A4641434546474748494A4A
4748494945403E3F444B4C4B4D4A44444344464A4945414041434145454146463F424445
454543413E45494641404244413F404243403E3E4844403D3D43423B473D383B3F3C3A3A
474B4443433F43453B3D3C3F45413D423E4542403E3D433E3A3C3D3D3E414241403C4443
3E4240413B3D413E3E3F3D46423D3E413F3F3F3B42413E3C3A393736413E3D3D3B3A3F47
3C3E3F3F3F3F3E3C4246454345413E4040403F3D3C3C3C3D383D3C3D3B393F403C3D4243
4043443E3F44454A4641433C3C3D3E3D3C3C3F42373B3B3B3B4E4642423E3F4142474841
433C3E434B493F413D3C353E443E3F42424A4E4945404046403D3C3D4142403D49413C47
5249424B3F3B3E3D3D3D3A3D403E474D46404347423C4241403B3E3B3B403F403F3D3F3C
3E3D3E404142484F4343413E3B3A3C3D4042413E3C3D3D3B4140424443413F3B3F3B3B43
4A49433E42423F43443E3D38393A3B3B3C3E40423E3E3E46433F433D4045404442383C44
43403D3B3A3A38373C4542403E3C403A45443F3C3D3B38373A3D43433D3B3E3F3B3D3E3E
3D3D3F41474540393D413C3F4843413C3B454C4D716664655D7B758E8D8D82827F74706C
6E66736E81738574615D4F49424F4D464244403C483F4542433B40394B454A42463E4340
413A3E3A3C4046403B463D3F47423F41433D45403F415D59867E998B7F785D7766866B81
8C948D8A6C605E55616760674F6E5C626976798C7D7D84706C636E73786D6B83859D9598
8CA09D9FA4B3C1CEC8D1D4D8D5CFD7CEC6C0B6B4C6CDD3DBDCD8D5C7D1C7D4C2DAD2D6C8
AC99878072717294A6BBC2CECCCDD7BE947D7A859DC2D0DFE6DFE6DED6B6B0ADBFC5C89B
9C91B3C1CCCFD7C3C7ACC6AFB9A78B5B484C58857F8677776A7177979AAAA9A28274594D
4F6C9AACBEB8C1C0CDCBCDB5C7C0CEC8D3CDC4BCC7C7C6C3BDBEB3B6ADB4A7A17A6C6465
6B697064716252474039373A3C3D3C3B3938393A3D3D3B393837393B3D45353F373A3B43
3C363F333B323832373637393A39393B39383736353535343B393838393A3A3936373938
373637383737383837363738353536363636343234343433333333333537363535363635
34343536373736343738393937343333353738363337372F383635333233343537363433
33333434353C3731373A383A3636373737373636
4F4C4E4F4C4E504D4C4A4D4E4A4B4D4A4C47484947494B47484946484C4944484B494949
4642414447434549484A4C4944474A4B484443434A4A48494C46404345464648494A4C4C
47484B4F4E4946473F4446494B46424544464847464643404349464848464D4A41444441
42474845444A4C48434242403D3C3F43444141434F4F4A464745403D3E39394144424245
43483F3E3F3B3E413F3E3D3E3F3E40453E423D3F403E423E3C3B3B3D3F404346403B4240
3C4041423A383D3E43433D48443C3D413E3B3D3D46423F3D3D3D3C3A3F3D3B3A39393D41
3C3C3E41413F3E3E3D403F3F454543463D3F403E3C3C3D3F3E413B3F403D403C3F3D4144
424244413E3F3F464340433B3C3B3B3B3B3D3F41404443403D4C413C423D3F434241413D
493E3F3C3C413D3E3E45424A514A46423E44454445423F443D3C3C3F4142403D423E3C41
46444245403E423C3B3E383A3C3B414440404241413B4141423B3F3A3C4340413F3C403A
403C3B3D3E3E3F42454646423C393A3D383D403F3E414242413F3D41433C383A3F3C3D43
4745413F3F423D414341423A3C3E414140404142414240434040474041484344453E4042
3E3C3B3B3E4143443F434041413F43403B3F3E3E42413D3E3A3B41423B3B3F3F3C3D3D3D
3D3F4142413F3E373D443E41413D46434E7080899D8F847F6277676E706E5E5854484748
49585B71666C62615C5B534F4653534D4D4E443F423A3D3B40423A463F4B41433D393E3A
3E3C423B3C3F423D3F414340423E3F40423B4743405C77ACC7DCD1C1A69C888E8D968A90
8C8E8C9A9699938F9284846960594E585971718C84797B6A665B58585A4D4A5657576166
5D75666D636F75817F858792A2B4D0C9D0BEB1A099A0ABBFC9C8C1AA99949795A7B9B9B4
9C88808370645A5F697183939298A5A28C71615C657F93B9D4D3D6CDD9D2D4CDC3CECAB8
9FADBABCB6BDBDD6C2BEB8C5BBB39893989AB2C3CAC9BEA8AFADBED0E5ECE4E5CAC4B2B3
B5C1DCDEEBDFE0D6CAD6CAE0D2F3E3DFC5AF91746F646365494F4A514A5248453E403A3E
3A3C3F3B3E3E3F40403F3E3F3B3C3C3C3A3838393E3F3E3C3A3A3B3C3B3C333A363B383E
3A3F3640353F383D3937383B3A3736373738383837373636373635363838373635363635
343435373736363637383737343537373735343434343434353535353436353232363736
363738373635353538393938363434353836383732333531393838373636353438383837
3534343534333031363935323737363636363636
4C4A50545050514C4E4B4F504C4E53514F49484946484A474C4C494A4F4A45494A494A4C
4B47484B4B4C504C44464B46454545484B4C48444C4D4B4C4E47424545474A4C4D4C4A48
45464B504F484444434546494C484851474A4A47464847433E47434342424A454346433D
3F494D4A45494A484748464343414041403D40454648423F43413E4440434A4E473F414B
3D45404246434446413D3F423D3D414346423A4044414543413D3B3E3F3E41463D39403F
3C3F3E3E41393C3F47443943453C3C413D393C403B3D3F3E3B39393A39393A3A3B3B3937
403D3E42423D3C3E40413D3C41413F41393E4243403D3C3D3B3D38424946453A43393D48
463E40453B3939403F3D42393D3D3E3F403F3D3C3A4346433A4540443F363A42403B3A3B
3F363E3A363F3E3E384643414341423F44423C3F4B4C44423D3D3E40403F3C3A3B3C3E40
4043433E3A3A413B3C443F3F43403F3C3A41443E40393E3F433A403A38413D40403F4640
3E3A393F44423F3C414446423B373A3D383E42413F4042413E3B373C4139343C3B3A3C3F
3F3C3B3D3F443D3F4141443A41444746423F3E3F3C4244474343463B3C45404148494A45
3B3A3A3B3C3D3B3A3C3B363B3B363A3B353A39393D3C393D3B393E3F3A3C403E3A393838
393C3F403B3B3E383E4338383E476F7684A097947D7871775565504842433A3C42404850
5B6A777B7B7B7884726E6A6A575753524D4F413F3E3D3F42403F433F423B3C393C3A3F37
3D42483B394435423741403F3F3B3E3D3D394D4F848194AAD6D5E0D3D4CDCEBDCCB7B9B2
A5AFB8C4BDC0C1D0C5CAB0B6826E435352656578807A6A686A66775C605266536E57747A
98626E58595A4F52525758686E8A8A9C909B8B917E8087A0B4BDBCA59185967D9C9BAAA2
B193A69CA88A987F86859C978B938E8B85877D967584668C98B0B1B5B2BFB1ABAAA6AA81
686B887B9C8C97979B9394ABA8A2A6B6C3CDD8E2E2E1D7D1D4E5EAE7EBE9E1F0E1E1D9E5
E3D7D5C4D0C2BBA6BBBED8D5E7E3E5C8BEAE9878674C47494440453B41383E3C3F44383B
373D3D39373B3E3D3B38363536393B3C3C3B3A3B3A3B3B3A38373839363234373339343F
3C3B3B363B353C3C393635373837393D38393A3A3B3A3939373737383A39363434353533
323234363836353638393736323538383735353536363737383838393637353131343635
38393A393635363735353634333335373734373832323635393A3B3B3A383634383A3B3A
3836353635323439383637393837353434343637
4D4D4E4F4F4F4F4E474B4D4B4B4D4D4A464A4B48494C4D4B46484B4D4C4A4644484B4946
474443474345494D4C484648424342464A45434944464847444345474E4D494F494B474B
434444434243474B4A434A4C4753563E48434748414043413D414040454340433D424441
41464D5047464547494A4A4B47474645454543404C47423E3C3B3E42363C3B3D3A384244
423D484A443E3B4A443D3B3F3E3A3B42403C3F3D3F433E3F3C40413F3E3F3D3A3E403F3A
393C3E3D363A404649463F39383E3E3A3A383840383A3C3B39393E433E3F3B37393F413F
3A383B4245423D3B3C3E404140404142374B414D47504741383B3F41414040413D3F4040
3E3D3D3E3A4B4A3D3B41403E3F43433F3D4042403C3B3E3F3B4045433D3F41403E3D3D3D
3E3B3B3E3F3D3D3F393C3E3D3E3F3E3B3C3F3E4047453D3B3C3E3F3A393D3F3F363B3B3E
47453E3E45403B3A3D404242403D413C3F463F3F3B3D413E393B3E38373E4446423E3A38
373E44423E3D3B383838413B3638353D3A3F423F3E40413E353C3E3A3A40403938393D41
413C3B3D3D3A3A3E403E3D3F40414446423D3D41403D4047443C3C43403E484944434450
3B3B3D424646423D393B3A3C363A43323A3D423D35393C3538393D42413C3B3E3E383C41
3C3B4143403F3E3C3B3D404344699B938A7676625B5247474A413B42403C424851486D68
8084858483837F79636662575251493D3D3F403F3B393A3B413F4341423E333C3A3A433B
3A3B453E4141473B3D443A4243535C6174838A99A3A88E94A19F9495999090979AAAA6AF
B1B0B3BCBEB5AFAB847B827B64564A4B46534B4F504F52585D616964656B6D70616C6B79
7B7B575855554B4C5A5165596D6885647B6364665F4C5684A0B6C8C5A7ABA19D929B839D
88A198B4AABCA2AF9CABB1ADA5A7A999A586A392AC91AB8E8F887E7470868F6E6B687252
4E3F4A4D535C626665655A5E66738A9AB3BBC0D7E3DCDFC6D8D6E6F0E3D0CDC8E0CEDAE1
DCCFB2B8A7B8A4B6ADCDD4E1E0D7CECEB4A5A6A8A38F6A5A4843413D3F3D3C3B423D3738
3E3D3B3F3E3B3938383939393737383A3C3C3937393735363839393838373637393A3938
3A3535393B3937393C41423D383838373536353637393B383536353B443F383C31393635
36353538353A333C313B34383B37363A3C373232303337363434383C3439342F34363232
34353636363534343334353536363636343434343435363634383A38373737353A3A3936
3232363933373633383732373334343A2F402B3D
4D4E4F504F4E4C4A4E4F4E4A494C4C4A484B4C4C4C4D4D4B4748494A49484645494D4B48
494745494C4B4C4E4C474445464846474A484549494A4A494746484A4A4A474F494C484B
4B4D4B4643454645504643485D7D785144454746424245443D3D3D4247443F3F4B4A4542
454D54554246484846444341434141434546474743414346453E3B3D42433D4042424745
3F414A4641413E4647424142413D3E44423B3C3C41463F3E383C3F4041423F3A3B404342
40403E3B45423E3C3D3E3E3E3C3F3C3A3D3C3A3E3B3E403F3C3B3D3F3F3F3E3D3D3D3B38
3C393B4043413D3C404141403E3C3B3A3946353B35403B3A3B3D3F3F3D3D3E4043413D39
37373A3C3842444040403F413F3C3B3C3E3F3F3E3A3A40413E4144403B3C3D3D3D3E4042
403E3D3F3E3C3D413B3F41404041413F3B3F42484F4B42403B3F3F4041413F383D404142
45444243403D3A3B3F434545393D4341484B3F3D404347433A3A3C39393D41423F3D3C3D
3D41413C3A3D41423C3D46434246454D3A3D3E3D3C3C3D3C4042403C3D4243403D3D3F42
413C3B3D3836373B3E3D3E40383A4045454244493F3A393D3F3D3F43433E413A3A3E3C47
46423F3E4041403E3339414B494D5341363A3F3D394045403C3E4348463F3B3B3A363A3E
3C3D403F3B3C3D3D3D3F41444E5D725E58484A3C3F41434747413E443D38434C5D586C5E
6666645F5C5B57524848443E3D41403C40403F3C3A393C3E44464847463F383F3E393E3C
423F45423E413F4E4B666A8C8FA6B2B2BDC8C6C5B6A1A67F8A7C92799D98B1ACCFC1CCC7
C4A68F8174706D605B5E565F51655863677264756464656B66646B5A61507065766D766F
817C6B614C4C474A4D52585963867D997892678C4D4C446A6E93A4AEB29FA68DA5889E7F
9286987EAA8FA29A9BA0AAB3AAA2B3BEAAB4ADCDB7D2C4BB96908476686B78725A565B4A
4843444557659772957986767B827F7F83969CB8CDDBD7D5CAE3DDE6DDC7A4ACACB2C6D3
CCD2CFBCCABFC4A8B8C5D2CEDEBFBCB6BEB3B2AEAAA59B9E988B6E594544383F3B3B3F3C
3B3E3A3837373738383837373939393B3C3C3937363636373A3C3D3D3938383839393A39
393736393B3A3939373C3E3B393A3B3B3B3B383A3C3A393938465F7A8879594233383333
3133363F38373C363A343B3C3A38373634323538363637393B3C3936303838353636363C
3435353535353434333435363636363635353535353535343739383535383A3938393B3A
38373839363938383E3C36373434412F3C353C40
4A4B4C4C4B484543494A4947464747454645474A4A484646434242434344454544474543
454341444340404344434345444845424444424348474645444344454E4A42453E434248
4A4A47424245454250534E4243534F3840484842404141424540424A4D4A45415049403C
40464743444B4D4741403F3D433E3C40413F40444E484548453E3C403B3E3C414341433F
3C444B423D43414145444442403E4043433B3B3B4248403D3B3C3D3E41423F3B4242403C
3B3D414246433F3C3B3C3C3C40403C3B3F3E3C3C40434544413E3D3D4242444747423D3A
3E3A3A3E413F3D3C3D3C3C3D3E3D3C3B515742423A423E3F3D3F3F3D3A393C3F47433E3A
393B3D3F3A3B3D42443D3B414D443F42443F3B3B3E3C3E413E3F43443E3D3D3C3C3E4144
41403F3F3D3C3F433F4344413F3F3E3C3D3C3A3F45423E4239403A3C3B39413D44424343
40414545413F3E40434647464446474346463C3C45464A473D3A3E3C40403F3D3B3A3C40
414343403D3F42434040443F3C3D3D433F3E3E3E3D3B3B3E43403D3C3D3E3E3D41414142
3F3C3B3C3D3C3C3C3B3A3A3C3E4045494946474B47423D3C404446473F3B413E4C533E3C
49443E3B3B3C3C3B3D3C3D40404B574E3B3D3F3D3B40433E3D3F434746413D3D3B393B3E
3F43433D3C3D3D3D3D3F43464646493B4540433C414243443C3D3D3F45404E505C575C4A
4948444040403F3B413F3C3C3D4042433F3F3E3D3C3B3C3D41433F41423D3D3E413C3F3D
44383A3F686A8B84A69BBCCED9DBD7D5D8D4C6B9BAA8949C8FADA8C2BCC8B1C7AAAC8A8D
8B828487878D897B97829E888D84997E786D676A64596D6B7A756C75596C605E625E5261
5481717B6D736E6A7862857B7F6B8A7991736C58515452484F4C5852596A6280728D7591
7E8D72987292788D848D8F8E8F9DB0ADBEC9CCCCD6D0D9D2CFC6B7B4B2ACAFAB9B878167
6757514A435963826C8C789B97ADC6B7B9A69E9BC8D1DDCECCD6D8D2DEA79F71676E7D9D
9DAEA7D6C7E3CBCFBFD2C1D5CAD8C1C1C3C5CDCDCACACAD1D4C8BE9683614F4740353E3F
3D44413B3D3E3D3C3A3836353B3A3A3B3C3B39373B3B3A38373636373B3A3A393838393B
373839393A3D3C3A383B3D3B383838383E3932323A3A39436083B5D4CBA47049373C393F
3A3C3A494352536A565C4C545C5D574A3D36363736343335383937353839353636373235
353534343333343434343536363636353636373736353433373836333437383638393938
363534343D3B3635393A3C3D393E313C5673807E
51525252514E4C4B4B4C4D4E4F4F4D4A4D4A4A4E4E4B494B4E4D4C4B4A4A4B4B474B4948
4A4846494C47454749494A4C4B514C46484947474D4D4C4B4B4A4848504F4A50494A464A
4B47434345454544464C4D484343464944504D4342434041434244464445443E47454243
494F4C454A5251443C3E4343464040484B48494F54494243413B3C433D45464A453D3C38
3C4448403D41413E3F41423F3D3D3F3F433D3E3D41453F3E423F3C3C3E403E3B3F3F3E3C
3A3C3E403F3F3F40403F3E3D403F3E3D3D3D3C3D4445464543413F3E4340424849433F3F
3E3B3A3E403E3C3B403F3D3D3E3D3A3844473A3D3B423D403E3E3E3C39383B3E42403E3E
404141413F3C3C42423A373C423D3A3D403F3E3E3B353943423939404342403E3D3D3E40
3F40403E3C3C40453C40423F3C3C3D3B45413C3D423F3D44414A3F3F3B3F5C67453E3F3F
3C4045414240404042434240414246454042454647444747413E413F47443F3C38373A3F
45474644413F3F404242423F3C3C3D4046424142413D3E42413D3C3F3F3B373742424140
3D3B3B3D3F3E3E3E3D3D3E3F3D3E4143423E3D3F44433F3A3A3F4240413F494D66724F41
403E3C3C3C3B3A383C3A3A3A3A4249443E40403D3B3C3A35393A3C3E3F4041423A393838
3C4240383C3B3A3938393C3F393C4345584E443B44413F423B4748434B49584D4B46463E
3F3D3A393B3D3D3B42404043433F3D3E3B3D4041403E3C3B3C44414441393E3E48526063
695958607EA5AECABCD0C3CBC7C8C2BDB19E92896C555E52646E6874646B5E6566636369
7F98B4BFC7C9C0BDB9CBC6D2BECEBEC39F917E93809FABB3B9BCBCB2C29ABDA0B3979655
50414C4B464C5C6B708893AB9EAE8698758C648A6C8A78947E8C6762685E8A716F575556
62575D5B665F6766636B645D657D86707EA499C9B8C8B1C3BBBBBAC8D1D3D4CBD1BFC4B3
BFADA69A77625D535259495C6792A9BBB4C1B4B7B0B4AABEA6CBC2CDB8B47A864C4A4753
54579388BDD0D2D4D7CACDB5D6C2CDC0CBD2DEE3E1DEDCDFE0E1D1D2B4A786726343413E
343A40433B3B3A39383738393B3A393A3A39373534353635343436383A3A3A383636383A
363A3B393A3E3D3A383A3B3A383737373A3D3F39383B4D70A9C5E1D39D6A493339383338
364148627A85959C8D75635F5C605E5348413D3A333333323234383C3C39313736393435
363534333333343435353636363636353536373838363534343635343536332E3A383635
353535363034383D3B3738343C455C70BAB3B17A
4C4B4B4A494949484A4847484A4948474A454346474544474F4E4C494643414040444242
4544414344403F43484B4F54464B474142434141454646474644424048463E433F45474E
544A454A4C474649484645484842414A4A55524848494646434848403D4244403D3F4042
464946404A5150443D40464747414146463E3B3E443E3D42443F3E413C434347453F413D
3F4242413F3D3F3E3B3E3F3E3D3E3E3E403F433F3E3F3C40413E3C3D403F3D3B3D3D3E3F
3E3D3D3F41403E3D3D3F42453D3E403E3A393C3F4645434242424141413C3B3F403C3B3C
3D3A3A3E403E3B3A3B3B3B3D4041414041413B40434840453D3D3D3C3A3A3C3D3B3A3B3D
3F41403F403D3D3E3D3B3939393C3D3B3C4042413C3742575741374045444341403E3D3C
3B3E3F3D3C3D4144393D3E3D3D3F403F393937393D3834383B443B3F40486D7D453C3B3E
3E43443D3F3E3D3D3E3D3C3B3B3C474B3F3E48474B4241454341413F48433F3D3A383B40
494745423F3F4043474743413F3E3F3F48444244433F3F4245414044443E3B3C40413F3D
3A3A3C3D4141413F3F3F3E3E3B3B3D40403D3D3F3D43453E3B3D403F3B383C394D5C483F
3D3D3D3E3E3D3B393A393D3E3F4444403A3D3E3D3E3E3A37373738393C3F42423F3E3A38
3E43403A3C3E40413F3E3E3E3D3D3F414F463D3A40413F463F4E4C45424250423D3C3C3D
423E3B3B3C3B3937413F4043413A37393B3D4041403E3E3E4548403E3F4C6D7D98A1A8A1
A4969497B0B6B9919F94A79D969D969CACB3B1A48246516B5D69708F80958FAEA4ADA1A9
B0C1D0CCD3DFDEE6ECD4F2D7D7B9D5B8B09C9E9199B4D5DDE1DBB5BEA9C0A8B2A2A79081
5971617675808A8C9E85A8A4BC98AC80956C816C697777788B7C71696295909E8B8A6A6B
54514A514849444649423F494944494741545F5F6E5759606A7283979DA8C1C8CDCDC9D8
D4E5D6D9BEA97755406946424058787D9B9DA59899747D6B887FA0A8B69B997E76604448
433F4848589696C4CCBEA0C0B6C8B6CACBD1D8DCDBDAE1E9E6E0E2DBD9BCB992977C7C77
5E4F43363C3C3C3C3B3A39383B3938383837353335363636343436383839393735353638
363A3B39393C3D393335373939393A3C35363E4250698BB7D8D1BC8C53393B3E403A3636
344047636F777F7E6B554643393D3F3E3D3E3B353839393735363A3E3C3C373B30363337
383735343333343435363637363635353435373838383736343636353739373236363637
393A3B3B3939373831374E53719F9DC5ADA26A45
4F4E4D4C4B4C4D4E58524C4A4B4B4D4E4F4B47494B4B4C4C4D4D4D4C4A49474645484747
4C4A47484D49464748484A4D4B4E4B474948454748494B4B494846454546444C484A464A
4E4541474B48484C4D4C494A4B494849464C4B4545474645444D4A404044454646484745
4546444041484C4743434443444142484945424342404045474542414241393D41424642
41413D41403A3D3E3E3E3F4141403F3F3E3E45403C3D3B413B3A3C4144413D3B3E3E4143
43403F4142413F3C3C3D41443B3C414039393E4045423F3E4042424244403C3B3B3A3B3C
3C39393D403E3B3B424141403F3E3C3A46403B3C3F40383F3F3D3B3B3C3D3E3D41403D3C
3D3F41413D3C3D3D3B3D3F3B3C42433D3B3F413F423F47595A453C454141414242413E3C
393D3F3E3D3F41413F41413E3E403F3C3D403E3D41413F4241433B3D3A38464B453F3D40
4346443E4140404041424344413F44483D3B48474D403E45433F3F3E443F3C3E3E3C3E44
424142444441404145453F3F3E3B3D3A45424141413F3E3F47434142403D3E413E3F3E3B
393A3C3C3E3F3F3F4244434042404042424040433A4347433E3F42434445443B3B464847
4241403F3E3E3E3D433D3E3A3B4141433A3F3F3F413F3C3C393B3B3C3E403F3C3E3F3A39
3E403E3E393E44484743403D3F3B38373D3D424846494144374340413937413A3A3C393A
433E3A3C3E3C38363E3B3B3D3C393B3F3F3F3F3C3A3C4145404145556A869FA6BAB5B3A9
ADA19B948BA0839670916D76738E99B0C4BEB8B07C7CB1A2B7B2C1ADB5B8D0CFE2D1E0DD
DDD5D7CED3E3DFDCCED7BCC2A9A385847882808B87B5C6DCDBC1917D9F91AA9DAAA7BA9D
B3A0ABA4A3A3B2B6ADAFA3B0A8B8999B7881687E6A8161785D654350504D85809686936C
48504F51474948504D4646514D434A4D596A5D5F4E584A56544B4953545E7983A096AC9A
BDBBD1CEC2A8954E5150565351646E94AAC4BDB39A755D5A555B6379799175A1978F857F
68584F4644424A699378827C9C8C9A9EB7BFC6CFCAC0C8D2CFD1C7DDD4D9CCAF7F7E92A7
A39575453C3B3A3B3B3B38363A393737373735343C3B3B39373737383637373736363636
36393A3939393A393636373A3A39393B3C3C556F8EABB7C79F86634536373E3F3B373E39
3B3C3B4D404E49573F45363B37353434373936313A393838383837373638333A313D3836
39383736363535353636373737363535343536373838373736383736383D3F3E33353738
38373636393B3E4C526C9DACC7D3C8A57F54453C
4A4A494949494949544C47474847474849474544474A4A47444445454646464541444243
494844454240404142414347454744444743404443444544424142444646414741444044
41403F4044484A4A49464442454D4E4745434444424444413F453F3D48453E453E3E3C3C
3F43423E3C41474A494743404140404243403E3C47454341434644404E4A3F3F4140443F
41413B403F393D3C433E3E4344403C3D3C3C413E3C3E3C413C3B3C41423F3D3E383C434A
49423D3C3D3E3F3E3D3D3E403D3C3F403B3D4141433F3B3B3E4141404543403C3D3F403E
3D38373B3E3D3C3D3C3D3E3F3F3F404049403D3D43433B44443F3A393C3F3F3E4644423F
3E3F42443B393D403D3E413E393938383A3C3D3C3E3E3E42443C39413E3E3E3F41403E3C
3A3F424141413F3C42423F3C3D3F3D393B413D373A3E3F403A3C3C403F393A3B44444241
444341414443424243464A4C4140383E44444C4F493E3F46423D4044433D3C3F403E4147
3B3C404647413D3C3E403B40434146424141403F3F403E3B3F3F3E3D3A393B3F3E403F3B
383A3C3B3C3E4043494F4D4844403D3D3C3A3A3D3A3E403D3A3A3D3F3F43464337384441
41403F3E3D3D3D3E423D3F3B3B3D37393B403F3D3F3C3A3F3D3E3C3A3C3E3D3936383637
3C3A393E393C3F41403D3B393B3B3F413F3E41424547393D34403A413B3638383C3B3637
413B383B3F3E3B3A3938373737383D424041403B383A434A404D7094AEB7A68FA2969797
9C8E867B5D60555D516856646E98A1A3977F92B3B7D2D5D7CACABABBB6BCC5D9C8D4D0D7
D1C9CEC8CFD9C9C4CBCDD6CDCCB1A98B798275728598B4C7E0D8BCC2B8D0C2D5D4D3C9D2
C7C8BCB0A09EA5A4B09CABA9B9AACEB8DDB5B98A6E8480877F6F5A58554B4A7169926772
4F5846443B49454F44464141434C5952534D74587B6879707366514B49494E494251546B
6C948E958B9B92A183A49EC29E968F94ADB7CCCBCBAD9C7979666A70564D67617B7C8B99
9D9D8C6D4447434041413C4B48625C676E7786A1AAA3ABB2B6AEADABC3C9C2B09299A6C1
CECCB88848413834353839393B3A383838383736373737393B3D3E3E3636373839393736
3738393A383636383B39393B3B3837394B598A9F9E9B8A845A4C3B373D3E38353837483D
46403A42333941393B3738323D3A383A3D3C3A39393836343335393C373C384541564D42
3A3A3A39383736353737373737363535363636363636363637393937383C3F3F36383938
37383B3E475A79A3B1C3E3DED6C5A08C6C654B52
4F4F4F4F4E4D4C4C4E49484C4E4B4847484948464A4F4D484C4B4A484746454543464446
4B4B4647494848494845474B464645474A45424745464643404144484547454F4A4B4547
4347453F414A4B4547494C48424852534D4647494546474141433B43564C3E4A46444242
474B463E3D40454B4D49444140414243464848463B3D3C3A3E43423B3A3D393C3D3D4443
40433B3E3E3A3E39453D3C43443D38393C393D3C3D413E41433F3D3D3C3A3C413D3C3D40
3F3D3E423B3B3C3B3A3C3F42403B3D403E414440413D393A3D3F3F3D3D3F3E3B3C41413E
3E3836383C3D3D3F393B3E3F3E3F40414F4341404441353E484139383C40403E4040403E
3D3D3F413B373E44403D3F3F473F3A3C3E3A37363C44413B3E3E3D3F3E3D3C3D3E3E3C39
3C41444443433F39393937383C41413C3944443D3F413D383D3F44453F39383E41474541
423E3C4242413F3D3E4146494246373F504A4444423B3F48423C434C463F3C40413E4046
403E3E41413D3B3D40423B40413E413B4042413F4042403A383C403F3C3A3B3C3F42413B
393B3C3A52524E4C4D4D453B45403D3D3D3C3D4144423F3D3C3C3E3F383B3F463A39473B
383A3C3D3D3C3B3B3E3A3F3B3C3E3638373C3A383B393A423F3D3935363B3D3B3C3F4044
4844434C494846423F3F41433A383D3E37393F3E4244333D3C4534363E3936393B39373B
403935383C3B39383D3E3E3C3B3D41443D40413E393A424A647093A9B5BDAFA2AA8E8175
6953514C566B5E8A6CA27C966B836D6B8191B5D8CEBCC7AAAD87A594C1ADCCAFB69DB2AA
ACAFB3A7AFB7ABBAB0D4D2DCD5D1B9AC81977A8EA0A1A1A6ACB9CADDE1DDDADBCBB6AEA3
A18E977E7A6D6E6C72727782809894BBB9E3D6D9CBDAB8B58D825D5864504C414C415250
52645D4F4A4D4C56494640414451666972605F61546C697A657973676462615B51545E52
5E66665C68769A84AAAACBCED9D6CAD0CAC8D3D9CAD0BFBAACBFB3BE9F877E6A645B6567
9395B7B78788645E4B4044393C3E424844424666797781877B8E9D959AA8A0B4BCC3C4D3
D2CCD0B67A68513F38383A3A3C3B3939393A39383A383737393A3A39363637393B3B3836
3837383A383333373936373B3D3B3B3D545D837F615445413B3E3A393B3635404E526E5F
66513C35384139392D3B3331363335393A353334393A39332F34424E515C5B6151605447
3B3B3B3B3A3836353737373737363535373736363535353535393B39383838363B3B3A3A
3C444F58A0AEC7E8E7E3EDD6CFADA47D7A5F5158
514B494B4B4B4C4C504E4C4C4B4A47444948494B4B494B4F44464747474A505545444648
4644454944474844434648484544474A443B3F493D42454240434546434447484442464D
49414441404545504A4B46474F514D4E3E444A4A474443453F4B48434A473E4240404148
4F4A4243404043474947413C3D4245444343403B3E3D4147453D3A3E3C393D3F3B3E4544
3D3F404140414243383A3C3E3F3E3C3A363D413F3D3E3F3E3B3742493E3B4240373E413F
3E40403D474343423F424239373C3C3B3D3A373B3F413F3B3A3D3D3A3C3A3C41413C3A3B
403A3A3C3A3F43403A3C3E3F4143464844413C3938393B3D3A383D3C3D3F3B3D3940393A
3C4641433C3F403C3B3C3E3D3E3D3B3B3D3F4041383B3E3D3C3C40433E3D3D3E403F3D3A
3C414B48423F3A3E413D4044434547424443413E3B3C3F43374147433C3B3E4041464747
41434D47444141413E3A3C413C3A3B3E3F40454B4B424949403E3F45423E3B3B3E414241
3A373D414041413B3C39393B3B393C4139403F3D403E3D43373838393E44443F46494539
3C4553747C6657473C3F404340423A3C3B38403E4440443C373A373E3A393E44423C404B
3F3B3A3E424242433B4141404039373F3D3F33373C373F433B3830414239443E454C5A6A
90635C484B453E3B3C3E3F3F393D403F3D3C3E413E3C3E3B42453A3D423E42423B3C403E
34383B3A3634383D35373C443D433F3F3F433A383E5D76946D5B66697A9B88938288938A
837063545B4663515D56615C635D558FC3C6C9B99D8E82787774717F7997879165726277
676D807D848895A1BFC5D3D3DAB9975D5344485356525365686789BFC8DBDAC98F7E5F52
49534A4246443F474B4A50506A5F8688C4CDDCD7DED8C6AB917E6F666769715F76647979
81A39E8B929A9E958E8272667170979197897F6B5F60596F697A8466595E685751736466
5C6A6163595351616583859898A6B8D4E1DFE5E8E2DDDDD5D9D7DBDBDCD3D3C4B79F8F78
618EAAD8CFDACBA692817B523A4142493A48453B484A544B5B557B6590828AA6BCCFCBC7
C1B1BEC0C19E95734E3642343636393A402F393B363834383A393D393B4246413B383736
34373A3B39373535353536383B3C3C3B3D39444D453C3B3A3B38383D48495C9384998465
51403B373738393938363636333537363333373B363A3937383C495C6968645B50453F3C
38343B3F37353C4135363736343232333637373636353637303A3937343B433238394047
5C9EBABBE2DEEBEAE0E1DACFADA0876A58565A5C
4951524B494B4C4D484848484949484744434548484545484647484747484C504646494D
4C49484B46484744454A4D4D4B46454747474D553F454845434344434441404243434548
4441484745444046414342454E504D4F41444748474543423F4545434546434241434346
4B474040434345474846413D404344434243423F3B393D44453F3E413E3D424440424645
4041414040404143393A3B3C3D3E3E3E3D40413E3C3D3E3F3D415359483D3C383B3E4141
3F3E3C393F4044444042443E393E3F3F423E3A3C383B3B393A3D3D3B3E3E3F403E3B3B3D
3D38393A393D423F3B3A3A3C3E40403F45423F3C3B3D4042403C3F3B3B3F3C3F3A413B3E
3E4540444043433E3B3C3C3B41403F3E3E3F3F3F34383D3F3F4045493C3B39393C404446
3E3E433F3C3E3C41424043454244464341434443403E3D3D424544403F44484A3D404043
3F404A453E4144444444454841424343403E444C755647413D3F4047393B3E3F4043484C
3C383A3C3C3F4340403F4144423D3A3B3B3F3D3D42413F423B3C3B3B3E41403C3A403D4B
6C838B926D55493F383B414B41443F42434247444442423C393B3B403A3C3F43433F3D3E
3B38383B3D3D3E4137393B3E403C3A3D384039383D3D413E434B57726D5350474F6B6491
7C744D4B43403C3C3E40403F4E4F4E4A443F3D3D42403C393F4340453F3D3E3D3A393B39
3737383A3C3C3B3A3C3B3F433A3C3E41433C404069789F8A886D7D7080756C6C6D737770
6857483E4C3E4A59556868746D6A638BADA7A1917F71665F615D51544E584F54454E414A
49536D748391A4B4C9DBDDE3C9B7947270686D73767571787F749FADB89D9C7B705D533D
4942483E383F4149464045474A595E807FA29EAEA1A3A19C9A9EA3A5A4B5B9CAC4C5C2C7
BACBDDCEDFD6E6D5D8C8BBB1B5A9BFBABCC3BAA7A1999AA8989B9B8581838B82716E6453
544F574855434343414D4C474F6998B8CEE1E7EDE4ECE6EFD8DBD1DCE2DDE1DDDFDBDDD3
ACB0BCC9D3DBE5D8DDC6B1977E8878764D4D473C423B4345383C485150716D8E99AFB2A0
998BADBBCAC9CABA7C54423B3F394634353D37373537353638363432393D3F3C3A393632
38393A3937363637363636383A3B3A3933343D3F3D3F3C3A393F3F5892B5B5BCBD986243
3C3939393738393735343537353738373535383B343635373D424A57514E49423C393838
3736393934323639393938363535363633353838343435343B372C374A5252463B5783AB
BEDDE7E9E5E2EDE9DCD2B697736E625249494C4C
516565554F504F50494A4C4C4C4C4C4D4C4B4C50504D4B4C4C4B4A474544444443424448
4B4D515648484543454A4D4D4B46414144494C4D464A4D4B4847464549433F4348494848
4B4A4F4C48464449464745454846403F45444546474643403D3D414242474945474C4B49
4B494342434344454543403E3D3E3C3B3B3D3E3D3E3B3D42433F3D3F3D3D414240404240
41424241404041433B3B3A3A3B3D404146423F3D3C3B3E41453E414239383D3B3D3D3E41
413E3A393E4147453F3E3F3C383C3C3C3F3B3535393B3B393A3D3D3C3C3F413F3D3D3F40
403C3C3E3E4145433F3E3D3E41413E3B4846423F3E3F4142433F423E3D3F3B3E3C403D44
41443E44444645403C3B3A383C3C3C3C3B3B3B3B3A3E42423F3E42453B3C3D3E3F414344
4541423D3C3F3C3E3D3D3F3F3A3B3E3E41424444413E3C3B3F4142414144474743423F44
423F47443D4142403F414447404244423C383F487251403E40403D443F4143413F3E4043
423E3D3D3B3C3D3B423F3E3E3D3B3B3C3D3D3B3C4343403F4242413D3B3B3A3743525570
969F8B6C58423D3B37383E4B3E3F3C414342433F4646403E3B393D3D3D3F3F3E3F403B34
38383C41423C38363E38383C3B3A393736403C3837363C4054667B9082655C515C596F53
5E3440383E3C3C3D40413F3C42424342403F3D3C3B3E3A3A3C3A3B3C3C3D3B3A3C3B393A
3A3938393B3C3B3A35373E423B363B3D423E35524E857E7A7E8A9ABDA9B0857A51545564
7474625982627F688062706A65635A656E615347514B48454C4C3F3F3B3D454243484653
687998A2ABB3BFCDD9D9E9CDD6BCCEBBC5C1C1B9B5B1A199998E80946B71594E48444044
4546403E403F3739393A45493C40484C4F4C535460605D5856595D5F707C829C99A6B1BC
D2D4D3E7DDE9E5D9D1B5A2918D838F94B9D4DACEDCC6D0D1D3CDCAC5D0CCCDCBC5ACA190
97858263654C543E4D434D3E3F4D73839AC5D8E3F4ECEBE7E7D0C0B0C5CED9D4D4D7DDD6
DCCFC8BBBCBFC9D1D4BDC0B3C2C3C2B9A1958A6F614A403F503148324D47637586A3989B
86909BA7B2B5D6CBC3886E4F3941384336343B2D373A38363C3C383B393A39393A3B3733
3C3C3A38363637393837373839393837373D43383439373E3D7498B5DAE0C7B38A5E3E35
36383637363839363332353838383837373738393838373C4547494F3F3C373534363839
383C3A35333231323A383634353536373334393A353A3F3B303B3836393B485789ADCFE5
E3E8EAE8E4E2E3CCAC97795D494A484340404040
4C615F4D4A49464B47494A49474545464B48484B4D4A48484A4947464442403F4343474C
4C48464749464341434545454243414042464541474A4B4A47464646484342464A4A4948
46474946413F4044434343434443403F4646474747464442464546444243413B48504F49
4A4945444141414140403F3F41403E3D3E404242423E3E4143403D3E3E3E3F403F3F3F3E
3F414242424142433E3D3C3B3B3D3F4149423E3E3D3C3E43473D3A39383E44423D3A3A3F
413E3D3E3F4143423E3C3B39383B3B3C43423E3F42413E3C3B3C3D3D393D3E3D3F444541
413E3E3F404345443F404141413F3D3C4B4844403E3D3D3D3E3E44424040393A3D403F49
43433D444344433F3D3C3B3837393A3B3B3B3C3D424445423D3A3D403C3E404141404142
464143424548403E404143413C3B3E414241403E3D3D3E3F3B414645413F414348443F44
45404545423F3D3B393B42493D3E3F3E3A383D454D414142413F3C433C3C3C3E40403F3D
40404142413E3A35423F3C3A3A3A3A3B3D3D3C3D40403D3C41413F3C3A3A3C3D50646C78
8C8B6E4945393C3E3939383F3C3B393B3E3D3B3742443D3F3E3A3F3C3F3F3D3A3A3C3A37
3A383B4145423D3B4239393B35363A39353A3B3D3E3D4C6263727A7A685A594E464A4D4A
3A403F4A3D3C3C3F41413D3A42403E3D3D3E3D3C4046404240393C393C3F3B3B42413C3F
3C3C3B3836373A3D403E40433D373D3B414B64628E70A897BAABC9B6C9B5B7A296938283
8382737562524B5041483E444244403F43413D3E4142433E40413A3D45444F4A4A5A637D
98A6BEC3C4C6CAD5CCD1BECDB2CABEBFC0BAB5A79E9682757B606350523E483745453C47
3C41393F40423E43454246444E42624966465E52605F5D5D5F61605F61555C5662597676
9A9AAFC7D1D7DBCFD4B8A28876665C5D6C8A88A0A5AEAEB3B3AEB0B8D3D5D9DDD9D3D1D5
DCD8CAB790907B8D81917F8A6B6A685A5E8EC8E6E2EDE6EDD4C8AEA3A3B6BFB1ABB7C4C4
C3D0C9D1C3CDBDC6CAC8C3D2CAD6CDD4D3CDCBAE9D897A74775F4143344037565E829A9A
9F969F9BA4B2B8D8CBCB9E84653B403742323E3C3F3F3A353B3C363D3A3A3A3A3C3C3A38
3E3D3A3836363739393837383838363439373C393E40394587B6D2E6E6B87F5A4A3D3D39
373A383C36393A38343235393938373738383837353533363C3B383C3A3837383B3C3937
3B433D343637333138353332333434333835383732363A333D3536454C5589C9CAE8E9DD
DAE6ECDED2C5B48B614F433D3B3C3C3A38373838
4B57524A4E4D4B534F5051504D4B4B4C4E4B494C4D4B4A4B4B4B4B4C4C4C4B4A49464445
454445484F4D4B4B4C4B4A49444B4E4C4C4F4F4C45444443424243454141434747444344
44494C4C494646453F3F41424243454545484B4A46444445414545444747433F41494944
44444142414140404041424343403F3F414343433F3D3D41444342434343414041414142
3C3E42434443434441403F3E3D3E3E3F46403E3F3F3D3F43444243413C3D4141403B393D
3F3E3E403C3B3A3C3F3F3D3C3F403D3C40403D3F46433E3B393A3C3E3B3C3B3D4348453C
3C3B3A3A3D3E3E3F383C3F3F3C393A3C4644413E3C3A3A3A3A3B42403F3E383B3E3F404A
42423E423E40403D3D3E3C393B3D3F403F3F40424041403D3B3C3F423E3E3E3D3D404549
3E3A3F424A4F4845414343403E3D3E42403E3B3A3A3D3F413B3D3E3D3B393C4045423B40
433F4343433C393C3D3D444E423F3D3D3D3C3F433F4349403A3D3E4840404040403D3A37
3A3C3F4345433E3B40414241403E3B393B3C3F3F3C3A3A3A393939393A3D4348575E5B49
484E40323C38413F3B3D39373E3B3A3A3D3F3C3B393D393F403D423E3D3C3B3C3A383A3E
4F4339383C3E3D3D3C373C3F38373E403A39393D4245506561645F544541443C413F4340
373F36393B3A3A3D4143424047433F3C3C3D3D3C474841413C38403E3E413D3D43413C3F
3A3B3C3D3D3E3F404B45393B383B45405268789C92B8B5D2B1A399AC91A4838C706D5953
4B4B42464239453C4841453C3D414038393D3D444143453E3F403B41433F424B4D727A94
A1A0A5A7AAB2B1B6C5AEB499AD9AA491968A83786E64524B46413E48404F565C65626B64
6753534E545E636867636866777084818282878E8A8B919FAEB7B9B7BCA28F756D58665D
5E6269747D9CBBD3D5CFCEC3B4A3817562575C5A716C7B777D828B95B2B8BDBFC9CDD4CA
C5BCB7ADB9B5B7C8DBD5D0D3CFCFB6A69391B0B1C7D9D7E3D3C29C7B6B797F7D7D8B99A2
9AA89EB0AEC4C9DFDADAE4DDE3CDD6D6D9D6E0D1CECAC9CBACA678654F4B354C51787F95
8CA7ABB8B3BBD5C7D2C4C6A99563444439413B3E3F403B393D3D3B3E393A3B3B3A393A3C
3E3D3B3938383737393838383838363436363C3B35355288CDDEDED7B26F44343D3D3E36
363B363B363A3C3B3734363938373636383837353435333435312F35363535383C3B3733
3A433D33373A363335343333353534323935373A3738383231363E4A6FACD7E3E5F5EEE1
E2E2D6B79077624C3C38373D383939393837383A
4B4C47464C49474F48494A4A494949494946454747464648464646454342414141404349
4C4A4849474545474846454641474A4542434545484544454545474A4143464947424244
3E4341424241454245444545403F424242474B4A464243464448464548463F3B3F454543
454341434342414142444647433F3D3F41414141414040424242404042423F3D40403E40
3A3D41434343444544434241403F3E3E403F3F3F3F3E3F41413F3D39383B3C3B423F3D3E
3E3D3D3E3F3C383A3F3E3A3B40413C393C3C3A3D423E3A3838383C403F3D3B3E43463F37
3D3E3B3A3E3E3C3E383C40403C3B3D403E3D3C3B3B3A3A3B3B3A3F3B393B393E3E3E3E46
3E423F403B3D3E3D3E403E3A3E3F413F3D3C3E3F403E3C3B3C3E40414040404040404142
3F393B3C434A45453E403E3D3F3E3D403C3B3A3B3D3F3F3E3D3B3B3F43423F3D4C4B4141
423D3E3E403A393D3F3E3E42433E3A3B3C3B3B3E4046473A383F3E443C414645403D3E40
3B3E3D3E42413E3F383C3E3E3E3F41413A3B40403A383A393B39393A3A3B40464B4B4A39
374340413C3A413D3A413E393B3738373A3F3D3F3B3E3D3F3E3C3D3C3A3A3D403E3A3A3E
4F44393739393A3B383A41443E393A3D403C3A3942474247423B3B3F3E3D3F3D403D3C3C
3B443A3E46433F3E3E3D3A38413E3A38393B3C3C3F4040413C3A3F3D3F403F3E3F3D3939
39393B434C4E48413F42354243545E557876907FA88DAF94987678525E4B48463F3E3A3B
3C423E38434041393C3E3F393B403F3A3C3F3E424140413D41443F474851617982A7AAB7
B6ABA7ADB7C3B7B3A7A18B977581605D4F46474645433D423E3E3F424862849DBBB7B2A5
98867D7972808C9AA09C99909C89969598A1A3AAA7A7ADB9C5CCCFD1D1CBACB19AA69F9E
828B79856F8E88A2A3AEBDCFD6DFC7C1B497A18DA28F9B909C9B9686898380787C728873
80727C6B858386B1C6DAE0E6E4EADBE4E1CBC6B0A7A8AEB6D4C5B68B776E5F5F616D7D93
9596918B867988A0B3C6C7E1DDDAD3D5DCD5DBD1CFCBD8E0DCD5C89699636266919B9C85
86869AA3AFC9CDDBBFCCB19F89815555353F423B3A3D393E3E3A3D3739393A3A3835373B
3D3C3A393939383739383738393937353E383842485A96D8DDCCB495643A384435353635
39383233363A3D3C383636383736353638383735363938373733333A3634333538393735
373C3A333439373336353536373736353634363B3B37383D3C4975A2C4E0E9E8E8E3E0DA
CEAD91754B3834383B3B39403939393A3937383B
54514E4F504D4B4E4A4A4A4C4D4D4D4C4B494B4D4D4B4B4E4F504F4D494747484B464446
474645464E4C4D4E4E4B4B4E494C4D49464445464A4746484947484B4746474947434345
4548424244464D4842424647404044434043474846434242414042444447463E40444445
4844414544413F3F414444444A4441434545454641424342403D3B3B3E3F3C3A3F3E3A3C
3D3E40404142434545444342414040413C3F403E3C3D3F3F3E3D3C3C40423D363F41413F
3E3E3E3D40403D3E413C373B3A3E3D3D4244454B3F3B393A3B3A3D41403D3C3F413F3B39
41423E3D41403D3F3E3E3F3F404141413A3B3B3B3B3B3B3C3B3A3E3A373A393F3D3D3B41
3942413E3D3F3F3E3F403E393C3D3E3C39393B3E413F3D3D3F403E3C3F40434544413D3A
423C3D3A3D423D3E41423F3F464642433C3C3C3D3F403F3E444142494D4A433F4E514540
413D3D3C3C3C3A393C403D373F3B393A39393B3F4042423A3E433B3C42474A473F3A393C
3D3F3B3A3E3D3A3D373C3D3A393E43463B393E403C3C3D393D3C3C3D3C39393C3A3B3C3C
3E413F3D3F393E3D3C413E3B37343835373D3A3E403F413E3B3C3B3E3E3F3F3E3E3E3C39
3A383A3D3D3C3E433C3F4042413A373A3F3B3E40494C42454338373D3D3A373435373A37
403C373D3B39383A3E41424144423F3D3B3B3A393F3D45474343413D3C3C3F403C3B3C39
3A393B444E504A424152475A54696A5C636A808788916C684B5042453C4A353D3F40453D
383F4942393E3E4341423D3A3F433D3D41403D3C4541403E42464A5C7A90B1BEC7D4DCD8
D5CFCDD2D1D3BDB5A7908B7165514942403D42403F3F3D433D3C3F3C4A5B798C8F9DA0B2
AAB4A8A78A9CAEC3CABDA68B8E6C7C667B67746775787F89929EAFBECADBCFE3D7E6D7D5
C0B09D9697A19DA9969B9BB1BCD1C9D3C5CACBDBD1DED1D6DFD6C9ACA299988B9B858D79
8674716465686D819BAEC9D1E3E6E0DBDDD7CFD2CCC9ACA59A9FB6C1AFA69187786F6B78
8B93AAAFA4846B685C6E7C98BBBDD0CCD0D0D5CDC7BFCDCCBEC4B7C0A08D7B7A94ABB3AC
94877B8097AABEC1C9BAA38B948C9B66563C3A383E3F38423E3947393F3B383A3A38373A
3D3B383839393837383737383A3A39373F3436679BBCD8DBBE81564538383C3A39393A3C
3734383538393A3937363638363637383939383734363434363231373836343537383735
35373835323638343536363535353637343635383A364360799FCFDEE3EDEBEAEDDDD7B8
8B5D49403B34393B3935323C3A3735353434383E
4847494A4848484748474748494A48464242464948454548424547464444474A45424246
484644444A474646433F40443F4042444443424145424245454342454844414242403F41
3E45414648474A4042424849413F43413F4042454645413E473F43453E4346383E3F3F43
46403C41423F3B3B3E40403E4A423E3F424141433C3F41413F3D3C3C3F413E3E43413C3E
40403F3E3E40434646454341414143443B40423D3A3C3E3D3C41423E3C3C3A38393F4341
4041413E393E4042443D3B423D41403D3F3D3C41403D3C3F3F3D3E413D3B3C3F3E3A3B3F
3F413D3B3F3D393C3F3B383A3F413F3B3C3C3C3C3C3B3B3B3939403D3A3A373C3D3C3A3D
3642423D4041413F40413D383C3E3F3D3B3C40443F3D3C3E4344403C3E3E3E4042434241
403C3F3C3E413C3D3D3E393B4546403F413F3D3D3F40403F413D3C3D3B38383B41483E3A
3D3D403F3B403D363C4A4A3D3D3D3E3F3D3C42494845423E4445393C3C3E404141403F3E
363A37383E3E3B3D3F474A453F3E3F3F3C383C403F41413A38373A3F3F3C3A3C423F383C
3D393E3B42373D403F3F3A393A363C38383D383D3B3A403C3B414149454640383A424036
3C3F42413A363B433E3E393A403D3A403F39404447413848453B39393A41423E39453A40
383A31443E3C3A3A3C3D3C3A3F3F3E3D3C3A3938413A42403B3F3C3B39383E423D3E423E
3C3C3D41454746445469555F4858523F526182728158404441443E3B47393B463E394239
3A424A353D3D3E41433A3A3A4444393A413F3C383C3B3E3E44506484B8C6E3D6DFD5E5D6
DBD9D2C6AC9D827D6F655F614B4D3B3F3E4046403B3B373B3E3E3B3F444C4B4D505A6E74
8585877F838B8988817468585D4A554D533F4C414047535F6C82A4C0C7D8DED8E4DEE2DA
C2B297A593A891A097917D8A868E828E93A1C4B7D5C5D8D5DCD8DBCBBFAEA08785807C80
8B8F89A07C9A7E8E74908EA6C4C9D5C5C6C2A1A9ACB5C4C3C49AA8A3B5C2BAAF9C968F96
9D9EA9BEB8BF8A785E644E576267767794A5B3ACA8A2AD9D8B86A9A4B397A97D93A6C1BF
BD9B7D6A618391A8ACAD99A08EA5A2B3866A484641433D5051567466463E393B3E3D3A39
3D3A373638393938373737383A3B3A393347629CC7DBE1C27044404437373C3F38393A3E
3435413539393837353536373637383A3A3A3A393A3936373B373337353535353635322F
3735393832363B3633343332313134373238383E485072A6C3D9ECE3E4ECE8EDE5DEDC9F
5D393A3C3D3A3C3634373C4A423C38383A3E4852
4E50534E494D4E47484A4C4C4C4B4B4C4345494B4B4A474648484A4B494A525C5248484E
4A4545464544434446474644494A49474444454742494D4A47464543494C484547454245
43434B4F4A4A4B464A47494944474C4C4745434346484744484949454142464A3B414443
4446433D3F3E3E3F404141403F41444543403F403C3D3F41424241413C3F413B40453F42
42403E3E3F4245483C413E413F3C403F403E3B3C3F4242423A40433F3D3F4140453F403D
3F423F41373F3C3F403F443D3B3A3A3D4142403D37373E3E3E403E423B3F413F3F41403C
4548443E3E3C3E454342424243413F3D3A3B494E3F383C3A35383C3C3B3B3F42383B3E3D
3C3D404239383C3E3C3D3F3C413F3C3C3E3F3F3F3A3A3C3F403F3E3E3A3C3F4242413E3C
3B3A42403F413B4039393A3D404242413F41434342403F3F403F3E3D3C3D3E3E3E3E4041
3E39383B434243433F393A3F42454444453F3B414E3F383E403A3A413D3D3E3E3D3C3A39
34393C3A393E44463B3A3D42433F3C3E3A3A3D41403B3B3F363B3D3B3C3F3D383F3D3B3C
3F4141403D3D423D3E44414141393A3D3A3A3E3C3C3F3B3E403F4645413F3C393C403E39
3C3E3F3D3C3E42443D3C3D3F434648483F3D3B3A3A3B3C3D393A3A3B3E413E38373A3E40
3F3C3B3B393F413D3A3B3D3C3C37363A3E3D3B3C333A3B3E373741373C37423E3D453F3E
3C4242565849515148585853495554515058524542403B3A3E453E4243373739413E3B3A
3A3C3C3D373E453F42393E45413C3F3E3C3C3C4540403D4F6681AAC0CFDEE2D6E1DCD8D5
CBB598806C5B5352483F3F403A3B3E3C413B3E3B41393E403D494A46645B7254584D4C4C
4E424A544D5A4C5F635F6E8879837E9C7E9D7D92738B6F7C7B8E9199A7B8CFCCD7C2C1AC
9B9FA898949D8CA5A5B2ADAAA4ACA5A597A0928C7F7A84749296BCBFCAC6C9B9BCBABBB6
B5AAB38C7C7F869BA596A895A9A5B2A4B2C0BEC1A7BFADA19CAEA7AE9DA998A57A708182
B8ADBBB3B4B8C4A3A78D8E77917E977773685852585A565558656B8978A2899989A7B3C7
C6AE9B98838E9D8F8E6B7983A78394B3BA84757B8F88A9BCBAB9AAA074443C413736373A
3C3C393C3E3E3C38353C3B32383C353B408EB1BDD9D4AC6B4D5B3D3A3E3C373937393A3A
38373839353739393838393B363333383C3B383833373938393B3A373938373635343332
35333335353335393231373433342F373539364B82A39D93AEA0B7A2C4DDDDD9DCDEB37A
503A3B3A393637393735383B34393A3C3E3F4E61
54474145494C4B4444464747454444444445474847464442434345464443484E47404248
48474A494A474341424546473F40414345484B4E42484B48454444424346434144444448
4C494A4A45464A484643444542444948484342484C4A4949494A4947434142443E3E3D3E
3F3F3F413A3A3B3E41413F3D40424443413F3F3F3D3E4041424241413F42433C3F423B3D
383C4145484845413E423F41403E43424041403F3F3F41423B40413D3A3B3D3D423C3E3B
3C3F3B3D3C423E403F3E423C3A3B3C3D3E3F4143434145403C3D383C3B40433F3B3C3E3E
3D413F3C3E3E404740403F3F3E3D3C3B3B39454B3F3B3F3D32373C3E3E3E3E3F393B3D3D
3C3D3E403B383B3D3B3C3F3C393A3C3E3F3F3D3B3C3E4040403F3D3B44423E3B393A3C3E
393A423E3D3F3A3E3D3E3F41434442413F41434342403F3F403F3E3D3C3A3A3944413F40
3E3B3D4039393C404140434846443E3D413E3D4255473F42443F3C3E3F40403F3D3C3B3B
393C3D3A3B3F43433D3C3C3E3F3D3B3B37393C3E3E3C3C3E373C3F3D3B3B3C3D3F3E3D3D
3D3E3E3D3739414143464141403C3F3F38363C3E3D3F3B3F41414746393A39393C3F3E3A
3B3D41423D393F483C41494F514F4A47433E3A393B3D3B3938393A3B3F43423E383D413E
3A383B3D373C3F3E3C3F42423D39373C3F3F3E3F383B383C3B3B40393C383E3E3E45433E
3F46495E605155545258535042443E3F3C423E3A424845423A3F393C3F383C403F3D3A39
3A3C3C3C393C3C373E3D40433F3A3E3D3D3F3C404052637B93ABCBD9D5DBD8CACEBEAEA4
817463554B433F3E3E393A403F3D3D3D3A3B423E413F4E57627F81989392867B686C4F56
4F4E4B59606B60717D80848D8C8DB5BAD5CAD4CEC5C9BAB3AFAEAAA396A19CA3A0AAADAC
B0C4BFC2B8C6BBC9C7D2D3D8D8DDD8DDDBD5D6B2BBA4BBA3AFA7B9AAA59BA19BAACBC2DD
D6E8E1DDAFC192AC7F8C828EB9A9AEA4A3A8AEC0C2CDD0C3CAC2C8C0B7ADB6A9A797A7A4
9C8E8C8A95B6ACC6A8AD8DB29CC6C0C0BBA98768503E42575A606A64575A62759099A0A1
B39C9486959C98918D5E576F5E5E82A997928BB6BECCC8BFBEAE865F4C3136413C393739
383C3C39383A3D3C3F3A36363F39354C8DCCD4D6BA97613B414C3835383A323A37383838
3838393A3134363838383A3B393534383B39363532363837383A39363334343637383939
333436373533343736383531383A343932383E4F6A716762565956638CB9CABC9C937052
3F3539373636373B3D3A393C384039545F565B43
83644F4D4C4B4C4D4A4B4C4B494747474B4B4B4B4A4847464847484A494546494B46484B
4A4B4D4A504D48454547494A4B4A484848494A4A4A4E4F4C494849484447434142414249
48464645444850524B46474745484C4A484140484A444245474747474542403F423F4248
484341434643414243433F3B424342403E3E3E3F3F3F4041414141413C3F423D40423B3F
3F4243424446433D40433F41403E43423F4142403D3B3D3F3E41413D39393B3B3F3C3E3A
3A3D38393F423F40403F413D3D3E3F3D3B3C40454844453E3A3A36393B41433F39383B3F
3B3E3D3B3C3B3D4240403E3C3B3B3C3D453F42443A383C3B3E3E3D3C3B3C3D3D3B3B3C3D
3C3C3D3E3C393B3D3A3C3F3C3D3F41413E3B38373C4142403F413F3A3E3E3D3C3C3B3B3C
3B3F46424043404042424244454543413F41434341403F404343434241403F3E403C393B
3B3A3A3D414040413F3D3D3F42403C3F43403C3D4F453D3D3F3D3936404141403D3C3D3E
3E3E3D3B3D41413F3C3C3B3A3B3D3C393B3D3E3D3B3A39383D3F42413B35393F3D3E3E3D
3B3A393A3A373C3B3D413E433F3C3D3F3B393C3F3F403B3F424247443B3D3E3C3C3D3B38
3E3B3E44413A3E484D5053514C45403E47403A393C3D3A363C3E3F3D3D403F3D454B4B42
39373B3D3A3E3F3E3C3D3F40403C3A3B3D3D3C3C3D3D373B403C3C3A3D4042484A4C4F44
4A4E4E5D5D4D4F4D484742473D3B363B3E423E393D3F3A3640413A3A3A35393C3C3A3939
3A3B3C3B3E423E373A3D3D3F3E3C3F3D4149474974899DB3C4CBCCC2C9C5B9ABAA947E72
504C453F3E41424045403D404038363D3B40494B5863767F868C767D6667535846553D48
4D4F5464646C656C7F97A6B2AFB8C1DBD8E2E0DFDDD7E0D7E0DDDDD0CAC7BDB4B4AEB5B0
CBDBDADEE6D9DFDBDFE5E4E9E7E6E2EADAE5D6DDC9E3DCD6DAD1E4DCD4C2C5C4CACFB7A2
C7C3CFD0DAD0D8C8CDB3D4B9AF8B7C70616D8AB4A3BBAFCEBCD3C5D0D2D7C7D3D0CCD7CF
D9C7D4B5BC8D866A6A6B7C7CA49EC4B9BFBAACA49A888EADB5CCBFCE9480626B707F7D9B
999B745A6F666C669161594F4F4D9194967D7C98C1B6B8927A897D6E544342423D3B3B40
3B3D4038363436363C38383C3F354780CBDAD4AA904E41383D473E393639314039383736
3738383835363838373535353B3736393A36333232353736363838353737373737373737
333637363535373837353643473B35363B38383B393843534E68676D847A875A5B4C3B39
37353B3B383D3A36353033414A5C77746B604438
69544B4E4C494E534B4C4C4B494848494A4948474645454549474749494544454A484948
4546484348474543424141414745434345474747494B4B4846454546424443444745474F
4A49484645474B4E4D4644434145484645414145474544453F3D3D3F403D3B3B3F3F4247
474340404E4944424343413E4444413D3B3D3F3E3F3F3F3F3F3F40403C3F423E41433C41
3F403C393C45484641433F41403C403D3E3F3F3E3D3B3B3B414242403D3B3C3C3F3E413C
3B3F3A3A3D3F3F41424242404342413E3B3B3D40403C3F3B3A3C393C3B3E403E3A393B3D
3C3D3D3C3B3A3B3D42413F3C3B3B3D3F4C413E3C36353A3A43403D3C3D3E3E3E3D3B3C3D
3C3A3B3D3C393B3D3B3D3E3A3D3F403F3E3E4042393F403C3D43433D393B3D3F3F3D3A38
3A4146424144434143424242434342413F414242413F3F403C3C3C3C3C3D3E3E413D3D41
44413E3D4240403F3F3E3D3D3E3C3D41423F3C3C3A3837373A3D3D3C3D3F41403E3D3D3F
3F3E3C3A3D42403C383A3A383B40403B3B3F3F3C3A3C3B3737373C42403B3F483B3D3F3E
3A3737383E383937373A393F3E38373D41413F3D41413A3E4140433F3F42433F3D3D3C3A
423B3A4144403F41484948443E3C3E4148433D3B3B3B39363D40423F3D3D3C3A4A4E4B41
39393B3B3B3D3E3C3B3B3C3D3C3A38383A3B3A3A3E3E383B423E3C424B595C5F5249534C
4F4E484F4D4144453D3B363F3A3C383D3A41423D3A3939393B3D3B3A3A393C3E3A393838
3A3B3B3A39403E3D42453E3A4440413F4F6F889AA9B1BBC6CDC9BAAA8D8373686452413B
44443F3B3C43454342403B3C3F3D465A6C78848686827C7467614D53454F4C4E596B5881
6983778A8F9EADB8C5D5DEE5E0DCE6DDE4D5D5CDCFCDD8D8E1E1E2DBE0E4D6E3D5D7CCC9
C0C3B3D2C9D0C7D1CBD1D2D3D6D8D9E0DEC3D092B2A0C3B1B9ADBBBBBCB5BDC6C3CEA57C
6863779894B39CC2C4DDCACACFB2A18F614F4A58596273668C8595A0B5AAC0A4C0B5C7C8
D0D9C8D8AA8F664A53645E757787939A9D9FA1B2C2B8B4C7DADBE3C0BB7FA6B2BEADA991
A79FA8917E6A585D68655E4D455268A0809A7FA5ADA5957F545C9FB87671695E544B4443
483E3F3A3F3C3B3C3B3C3A373A3B5FA9CBD9B6A66C4E36463E443A3934383A493C3A3735
3637363639383837363535353B3837393935323233363736363838353A3B3A3835333232
363736343537383739426489764C3F3535343F4642465C6F607D5964474549373D33343C
39373C3D363E3934393C4B6679A2A48A68453839
504A4B4E4946494A4B4C4D4C4B4B4C4D49484646464648484B4847494947464845444748
45484B474646444341403F3F434140414447484849484847454444454547464749444249
4A4A47444446494E514946434043474541434443474E5150474240434442404244464542
41444544454240414343423F4545423C3B3E403E3F3F3E3D3D3E3F404243464141403940
42423F3B3C3F3F3C44474244423E3F3B413E3C3D40413F3B3F3F40403F3D3C3D3D3D423C
3B403C3C3E3D3F4143433F3E44413F3D3E3E3D3B3C393D3B3C3F3C3E3B3A3B3D3E3D3B3A
3A3A3C3D3C3D3E3F42403D3B3A3B3D3E433C3A3B39383A3A37393D434747433F3D3B3C3E
3D393A3D3C393B3E3D3E3E38434343403C3B3B3C3A3F3E393A41433E44413E3B39393A3A
373C3E3D3D3F413E413F3D3D3F40414040414241403F3F404342414040424446423E3D42
4543403F3D3D3E3E3F4040403F3D3D3E3C3C40444244443E393838393A3C3E3F3F3E3E3E
3D3C3A393D41403B383B3C3B3D41403B373B3C3B3D42433F3F3B3D44433B3A3F393C3E3D
393738393A383D3C3C3D37393B38373D44423E3D41413A3D3F3D3F393C40403D3C3E4040
3F3D3C3F4243403D3A3D41413E3D3E3F4544413D3A39393A373C403F3D3E3E3C3F403C38
383C3C393A3B3B3C3D3E404338383737393D3F3F3B3C393A42454B5A657470694F3D4C48
47433E41413B3E414040393C373E383733383E3D3B3C40413B3C3F3E3C3C3B3A39383839
3B3C3B393A3D3C3B4445403B3F506D7F92A7B1B9C5C3C3BCA98C7062504A434445413C40
3F41403C3D41413D3E413E3E4145556F76889799908B858387768F74977EAC97AB8FB6AE
C8AEBFACCDC9CDCED1D3D6D8D3D6C9D3C1D7BDCBB5BCB8C2C1C5C3C8CCC6D1BCC89E9F88
8271808C9F9E9FA5AAB4B7B2B7B9B8B5A396796D567C7A8467596061656163687D725A4B
4C4A4D4A5C5C6E738A93B39F9A969C9B7C715F5444584A615D907FA0839F6F815E6A7F87
A59CAD859C614C4D4F6195A0CFB9CBBEC7C4BBC0CFD1D2E0D6DFBDC49F98AAD1D3CEB2AF
96AFACB7C8B5BBA09C7E9484765E5D6682829796AEACAD8F756C77A5A3B4BBB3A0877266
7357524D574A3F3D47473F394D6484B6DFDED6A9A27B7F786F6543413A3A41453B383635
363838373736353537393B3D393636393935333335383836363838363536373635343536
36353434363735334072B1CB9E675140494B585C524F53523E413937392F3B3439343B3D
363538363639374564798699A7A88D6E5337333F
514F51524E4F504C4B4C4D4D4C4D4E504A494848494A4C4D4C49484A4A49494B4845494B
48494D4C4C4B4845444446484A484644444444444A484849484646484545434649433F45
4848444143464B52534C4A474345484641464540424C4F4C504946484844434645494945
45494844424345474744403D4446423D3D41423E403F3E3D3D3F41424141444041403B44
3D3D3C3C3D3E4143494A45464540423D45403D3F4447443F3C3B3C3D3D3B3A3C393B403A
39403E3E423D404041413A3B403D3B3D40413F3C433F423F3F413B3D3C39393D403E3B39
3D3B3D3E3B3C3E3D3F3D3A39393A3A393B3A3D413F3A3736383A3D424545423F3D3B3D40
3D3839403D393B3D3C3E3E38393A3C3D3D3D3C3C3E403E39393E3F3C43413E3B3A3B3D3F
3D3E3A3D3F3E403D3E3C3B3B3D3F3F3F404141413F3E3F4043403D3A393A3C3E423C393C
3F3F3E3F3E40403E3D3E3E3D3E3C3F423F3E42453E4244403B3A3E413B3B3C3E3F3F3F3E
3A3C3B3A3C3F3F3C3D3F403E3E3D3C3A3B3C3C3C3E4141403E3A3C43443E3B3F393C3E3C
3938393B3C3C413D3D433E3F3A3C3D3F403B3A3F40413B3D3E3A3C373C3F3F3A383A3C3B
3A3F42403F3F3F3E41434444433F3C3A4142423E3A393B3F383D403E3C3D3D3B403B3738
3B3D3C3A413F3E3F3F3F40433F3F3D3A3A3D3E3D39373938404D5A6C726F5C554840483B
403D3B3F3F3A393A3D413A3B38433F3A3B3A3B3C3A3B3C393E3D44403B3C38353A393A3B
3C3C3B393A3C3E333D4056677F8DA5AFB3B6B2B3AE9986725F4E3E3D3D3D3B403D3B363A
3C3F42424343403D4547464342444F5E6B6F6C685E606368748380ADA3C6CBCDB4A1A3CC
B5D2AFA28F8184929C9591829587856F7071666860655D6B686E6D767D7C71675D52524C
554C4B5A4E6C6472717D848089878076836E906B96809B8B8D868B898C887F7B757A767C
5D5C54565A7F627A638579947A756D5E4B4E4B3F453A483D64737D7E798A928876635F52
4A5E586863716C7E6C7A6F9E84B49EB4A4A49E9BA1AEBFD0D6D1DCCED9A6AFB3CEC5CAAA
A792A3B1C6D6D3D3B8B2A5987C927387546C778D869E9BABAF988A7190B2CDDAD6CDCCC8
D4B4B4ABB39C847A7679787895B7CADFDCE3C7C6BFD2BAAC9F824F4A413D3E3736363536
37393B3B3937363637393B3B363535383936343636383836363838363234363635353739
3433343637383C426FB5E1CB977160544F4C4B453C3C3C3435352D40333E2E383C373A36
333735353A363A5D92AEAFAD8B5F513D323A3F5C
4B4A4F534F4C48414647484747484A4C464545454547484A47454547474445484943464A
44414445464646444243454742424141414244454543434545434345423F3E444C48464C
4B4D4843444242484744464540404240464846403F42434149423F42413C3B3F3F414444
4442403D47494A4946423F3D4346443F3F44443E42413F3E3F4144463D3D403E3F3F3D49
46413E3E3B383D45494942424240433F44413E3F424443413F3C3A3B3B393B3E383B413A
3A444344453C3E3D3E3F393C3C3C3C3D3E3F3F3F4742423E3E403C3D3D3A3A3D3E3B3A3B
3F3B3D3D3A3B3E3B3F3C393A3C3C39363B3D4143403936383F3E3D3D3D3D3D3C3C3B3E41
3D373A42403A3A3B3A3D3E3A3D3D3C3C3B3B3A393E3F3F3D3D3E3E3D3B3D41434442403E
48433A40423D403E3C3C3C3D3F3F3E3D404141403F3E3F404644413F3D3E3F40443F3C3E
403F3F413A3E403E3C3F40403F3A3E45464645414140403F3C3A3C3F413E3C3C3E403F3E
3A3E3F3D3C3E3E3D3F3F403F3C393A3C433F3D3E3E3C3A3A414041434039383B3C3D3E3C
39383A3B3E4043393A43413F3B3E3D3C3C3839423E403C3E3E3A3D393F413F3B38393836
3A3C4143403C3C3E434241434646423F40403F3D3C3D3F413F41403D3B3D3D3B463E3A3C
3E3B3B3E44403E3E3D3B3B3E4343403B393B3C3B37343B3A3E4D53595C53404040424535
3D3B3C3F403D3838393D383A384542403D3A3C3D393B3D3B39363F3C383F3E3C3B3B3C3D
3E3D3B383538453F555A829EA1A5B2B3AB9B857E6452473D3D4139393C3E3D4541433C3C
3C3B3C3F3F3E3E3F444242414044484641413D444045434748507488B0ADBDBDBCAAC2B5
D1BEAD896457566167627065706A6A76688177746A5A5D5D605E5C5D64665D59637899A7
B7A38C715656717A7A838E91A2A19C949491999A8F826E61606877777B7B6B5F7F6E7463
7560665A7B7D9382998CABA3AEA5967F6D5D544749493F7599CDC8CCBEC9AAAD8C82785A
51606959605888707F61715D6B6A6F6F6565676766707F89859291AB9CA393B5BBC9D0D5
B49A8096BBD1D4D4D5C6A786686A6F6B69606357606D86A0BBC9BDAAB8CBD8DED8D4DAD5
E1CBD2C3CDC1B5B2CBCED2CDD3E1E2E5DEDEDED0E3D5B890795E3E433C3B393436373838
38393A3B3B3938373837363435343538383535363638373535373735353739383635373A
35333538383F5770B9D1C89469524340403E3B3633353632363137343731333939363834
373A343939323348636C645B4A39303D455E8995
545052534D4B50524B4C4C4B4A4B4D4F4949484848494B4C4B4A4B4D4C49494C4C44484D
4843464A4245494A49474646434445454446494B484545494A474749534C45484C453F44
42484746494642464343484944434440494847454341414147414044443F3F4447424143
43404044454544413E3D3F42424645404147453E44424140414346493F3E403C3D3B3945
443F3F433F393D4846453C3C3D3C424041403E3D3D3E4040453F3B3B3B3A3D413A3E433C
3D48484A44393A393C403A403C3E3F3E3B3B3E40443E3E3A3B403D403E3D3D3E3B37393D
3A36393B393E4240413D3B3D40403B363B3D3F403E3B3E45393A3C3E3E3C3A383B3B3F42
3D363A44433B3939383C3F3B413E3A383A3D40413C3C3E4142403F403E41444746433E3B
4C43363E41383B393C3D3F4142413E3B404141403E3E3F4041403E3D3D3D3E3E3C393A3D
3E3B39393C41423E3B3C3E3E483B394045494A43453F3C3F403F3F4147423C3B3D40403F
3B40423F3C3C3E3E3E3D3D3E3A373A41433E3B3D3E3A383A3B3E42423C393C423E3F3E3C
39393A3B383F453B3A433B343E3D37363C3C3C443D403C3F3F3B3F3C3C3F3F3D3D3E3D3A
3E393B43443D3A3D3F3D3E444949423B403E3B3B3E4141413E3F3E3B3B404342423A373B
3B373B443E3A383A3A393A3D3A3D3B38383D404038333F3E3E4640383B3F3E3E36353E38
3836393C40413E3F40413A3C373E3A393B3C4242393941433D383F38333C3C3C3C3C3D3E
3F3E3B38413F565C827D949E9F91887B6C5A45403B3A3F393B433D3C3D3E3B4340463E3B
433D393938383D43453E3C3B3B424032373C3E483F3F3C43434C52646C7F86B3A5C1B0C1
B2BE867467758D9F9E92A89FB997B997B8A1CEACC6A4BAB1C1BBBDB5A9BDAABDA8CBD0DF
E1DCBAB38A87B1C2BFBDBFBECAC0B8B2C9BBCDB5B27A6B4E3E464B40445454524F5E5C64
5E656681747D687F85A49DA79D9DA1A2A799989671695687CBE0DFD6DBCFD5C4C4A78C55
4D728C8D908F8A888A6B6B67566A515555484548474E575666646C76797D6C88ABB2C5C4
B8907E989CA694A09395828161606C7C6D70585A5B77707D9DA3B7D7D6D8D2D0C4B7B19D
A28F93757F8796A2CFCED9DBDBDFDBDBDFE2D4BFA6916D5943353341383835383A3B3C3A
3836363736363638393835333534353838353436353736333336363434373A3A38383A3D
383536383848739FA585674D423D353C3435373737363637343732373434353531333938
3A372E3A37383C3F3B383A3E3A374C5679B5CDD4
6B6D6B63564C4747444A45444E4C454A49464A454348464C434748444245474741424344
45454443414043484946464848433E3E414444434B484242433E404D513B3D464A4A4545
48414045484340403E41454644413F3F3D40413F3D3C3D413F4446444343403B42413F40
464B48403B4050403F40413E3C5356463E3E3F423B444A4640404345393A3C3E3D3B3F45
47473E3D3D3C44443D3E3D3D3E3E3D3E414243413F3F4042433B3C3F3A393D3D3B3B3B3E
414444444039383A3B3F403A3C3C3B3B3B3D3E3F45413C3A3A3D3F3F3E41423E3D3E3C38
3B3B3F3F383A403E393D41413F3D3E403F3B41433E3F3E3A3D3D3E3E3D3C3B3A393D464A
444347473641403B3F403A373D3E4244413C3C403B3F413E3D3F3F3D3A40404045423C3E
403941483F3E433F3D3A3B444946403D3E3E3D3E3E3F40403F40403F3D3D3E403C3D3F41
41413F3E3C3D3E3E3E3F41433F3F3E424844414640403F3F3F3F3E3D38393B3D3E3D3D3C
39403A363D3B373D35383B3C3D3E40423E3C3B3B3C3E3F3F3E3C3F3B3E3C34403E3F4040
3F3E40424444413E3D3F3F3B3B3C3D3E40414141363B3D3B3A3E403F3F4038363C383643
40423E414340433F3438383A3F3E3C403B3F403F414444424346453E393B3D3E3F3F3E3D
3C3B3A39393D3F3E3A373A3F3D3C3B3938383A3B31373C3C3C3D3D3B353339383A3D3A3C
3A3F403B383A3E403B37393C3B3E3F3A363E3D3B404240423A3B3C3936363B3F3B41433F
3B3C404249535C6D6C706D72585C514A433E41393E393B414037363C413A413F3A3F3F3F
3E3A37373B3D3D3C3E3F3F3E39363C45403A423C42414552586270689D7FA98599768178
835D5B788BAFB0A29F948F9485827C7E7E9592B2B6C9D2D6CEC2B7B8AFB5CCCBDADFE5E7
EBE7DACFD1D3D8CBCFC6B1B3C0BFC2C5B5B699AD7A85584C4C4F47524942434D4D494D4C
575258577964716B7C8090767D7F92A3919988967B9387A4B1D2D2DDD0C9C8BBAD9A7967
678DC8CAD2CAD5CBD4C4BB985C585D605F55585E5F636463787683786E7F7082788F888C
7F81788D9680716A635E6961636D69656A6A70867F9E9092A199AAC5C3BAA8AB8B846F66
515D503E4B50596D92B8CBD5CECDBDC5AA807E6664493E3E3E3E3F3C3A414033343E343C
3A3C383A3B3E3D3D37443639383638323A393C363934343038383B38353C393B37313736
3E2E3E313245476B4E473D363436393B3A393837363637373C3935333334343430313335
3737373736363C36363F393C3B658FA2C2D5D8CA
4E545B5D59534F4E52564F4A4F4B454A45414645484E4B4E494C4D4947494A4947474849
4A4A4949494646494A4747484647484746464849474A494949474D5C785A4C4A4B4B4443
414245494E4E49434143464747454444464849484646484A4042413E3F4345443A3D4042
474C4D4A49626B4840403D3C40484E494144443C4646433F3F4243403D3C3D3E3D3C3F44
44443D414343464243424141424445463E4041413F3E3F40413B3C3E3A393B3B3D3C3B3D
414343413C393C3F3D4146443F3F3E3D3C3C3B3B3E3C3A3A3C3F40413B4043424243423F
3F3C3E3D373941443A3C3E3E3D3D3F423F3B3D3F3D4143413D3D3D3C3C3B3A39383A4244
3D3C40403B43413A3C3E39373B3C3F413F3B3B3F3A3E3F3D3C3D3E3C3A3E3D3D413F3B3D
4540464B433E3D38413D3C4245413C393C3B3A3A3A3A3A3A3A3B3D3E3F4143443B3B3C3D
3E3E3E3E3B3C3D3D3D3E40424546424246433F423F3F40403F3E3F3F3C3D3E3F3F3F3E3D
353C38373F3F3B42404142413F3E3F403B3A39393B3C3C3C36333D414144414744423E3D
404649493F3F3E3B3B3D3B373B3B3C3C3C3C3C3C35383A3A3B3D3F3E43413D3B3D3C3C40
3A3C373C3E3E434033393C3E44474543383B3C3C3D40403E3F42423C383A3C3D3F3E3C3B
3A3A3A3B3A3D403F3C3B3C3F3B39383737383B3C373B3C3A393A3A39383437373C403A39
3B4044413E3E3F3E3C383A3E3D3D3E3A383E3C393E403D3E36383A3B3A3A3D3F383A3A38
393E40403E42424B4548444A393D393E3F3A3F3C3C3A3D42434043483E393E3E40464342
41403D39373738393C3B3B3D3D3D41473C3D34435B8A8D9BA4A68B847A718D7E889086A6
809A79998092867975675A544D48615B717785939BA7BBC4D2CAC8C3CCD0D9DEE5E9E7E5
C8C3B1B6B6B5ADA69696929EA9A59E94917A776B6661695C69574B625F565B6B60615E5C
4D6257634E5952575451506BA7BDCCCCB2AA868976747F7EAEABBDBBBDB7B7AEA0988775
6E8491A49EB8BBBFB7BCC2BD907A6052455566778B969597A39C9784737C6A67676A616E
656C7594968F98887B61726B847C8A6158586B9AB9D2DFD6D4CFC8D4C3C9BFBFA3886C53
4E5547433E434458739EC2C6BB99786C59414737463C3B42383B424139393E3D373F353C
3D3F3E403B3640373B3C3B373036403B3E393D3B3237323E3640383C383A35393A383D39
3A40373A3E383B383837383A3B3B38353A39383635353535343333333435353533343536
3737373630392F373C3242446DAECFDCD3D4B09E
4F515454514D4B4A4D504A454846434A4A45444244474343484A4B484747464540414141
414142424A464444454342424244464746454546414443414040454D5B46404145464141
4D423C40423D3C3F4343454748494746414142434142434341413F3D3E42464641454845
424141405575754E48443C3F423C44473F43473B43403B393A3E3E3B403E3D3F3E3C3D41
43433D4246454640413F3F3F3F4245463C3E3F403F3D3D3D3F3B3D3E3B393A38403D3C3D
4042403E393A40413C3F46473F3F3F3E3D3C3B3A3A39393B3D3F3F3F393E41403E3C3A38
39363A403C393B3E42413F3D3B3B3C3C3E3B3A3D3D3F423F3D3C3B3B3A3A3A3A38393E3E
38383C3B4348443C3C3E3B3939393B3D3B393A3F3B3D3D3B3A3B3D3C3A3C3B3A3C3C3B3D
434143484642403E433E3C3E403E3A373537383A3D3F414239393A3B3D3E3E3E3A3A3B3B
3C3C3D3D3738393939393B3D3F423E3B40413E3F3E4041403E3E40423C3C3C3C3B3B3B3A
3B3F3C3A3F3C373C3E414344413D3A383B3A3A3B3C3D3C3A403941423B3C3C3B3D3D3B3B
4146443D3B3D3C3B3B3C3A35393A3C3C3B3A3C3E3C3B3A3C3C3937373E3C3C3D3E42423E
3D3E383A3B3B403D3C3E3F3D3D403E37373A3B3A3B3E3E3C3B3D3E3A38393C3D3E3C3A39
39393B3C3B3D403F3E3E3F3F43413E3B3A3A3B3C3A3C3B38373839393B3537383E423937
353A3F4141424342413B3E423F3B3A373B3E3B383C3E3B3941403F3D3C3B3B3B423F3B3A
3E454541403F393E373B3940403E3B4141393B3C4342403D3A393A3C413E3E3D42443B3B
424445423D3A3B3D3D3A393B3C3B3C3F39516C73ADC8CCC0BCB4BEA8B082A18092809464
6D4E574D4E52454348474642535A6E8C8AB4B8C6B4B0A7B3AEBBB2B3B2B1C5B5C5A9ADA0
90949C9BB4A2A399A3967F736C6A6B605C5E56715C6957584C4C495345454A48473F4D3E
4A646068516852675C696092A5C1D2D3CCDECED1C2C1B8B7B0A89CA8B5B9BEBDAFAAA289
7E5E5B50777585737C7480667B61787449607292C3DEDBD5D8DAD5CEC0BEB09A8C725A61
546585AEA7ABAFBAA79787748380848D73896D898EA2D4D3D2E0CAC8A7B7BDC1C0A29986
8B72634D5249575B709AABBEA48C5B4B4948454745555065676768655954595E4D51484A
48423E3A413B493B3A353F3B4847483B3B363C3A3935403440333D3A3839353738373936
33363539362D343E39363536383936323938373534333332393A3A3A3837363636373737
3736363539393D323B405870ABC4D4BBAD76574E
5352504F4D4C4B4B474C494649494950514D4B49494C4C4D4B4C4C4C4B4A494849494A4A
49494A4A514D4A4A4B4A4744484645474B4D4A464F4D4845474947454C4344444548484F
66534749483F40494142434648484643413F414240414240434341403F4041413E414342
3F3D3D3D3F534F4148443C4340363C413A3D46423E424544403F4245433F3E3F3F3C3B3D
41423D40424044403E3C3E3F3C3E42423F3F3F3F3D3C3C3B3E3D3E3F3D3B3A38423F3C3D
40403E3B3A3A3F3F393A3F3F3B3B3C3D3D3C3B3B3D3D3C3C3D3D3D3D42454645413D3B3A
3E3B414A494240433F3E3C3D3E4040403C3D3B3E3E3B3B353C3C3B3A3A3B3C3C3B393C3D
38393D3C4344413B393B3A383938393B3A383B3F3C3D3D3B3A3B3D3E3C3B3938393A3C3E
413F3D4044444447413D3B3C3E3F3E3C3B3C3E3E3E3E3E3F3C3B3B3C3E3E3D3B3B3D3E3E
3D3C3C3C3F404040404042443A403D393E403D3C3F4142403D3D3F423B3B3B3B3B3B3B3B
383B393A3F3C393E353A4145454039353D3C3D3E403F3D3B3E3A3D3D3A3C40403B3D3D3B
3D3F3A323C3E3D3C3D3F3D3938393C3F3F3E4248413D3B3E3E383535373A3A393E42403A
41413B3D3E3C403D3E3A3938383B3C38393C3D3C3D40403D383A3B3A393A3C3D3B3B3A39
393A3B3C3C3D3E3C3D40403F3E3D3A39383736353939393737393A3A3B363A3A3D403837
3C3D3D3C3B3A3A3A39343B444240403F3D3D3A383B3E3B3746423D3B3C3F42443D3C3937
3C41413D3E3C373D383D3B40433F3B3C3C3A3C3E3C3E3D38353738374141403A3D3C3237
373B3E3E3C3A3A3B413D3A3939393E434C88ABBFD5E5D3CDB7B391A07972605150453F41
374A474B3F3F3A3D3E3E46456E609A93BFBCDFCAB69E9B8891898E88898A95959C9D9D9F
ACCCCDDBDADCCBC9C3B8A292858282716C6466576F5B656E63757A724C464A42463D574F
6E84878A8F9A92A498ACA9B69AA1A4A19FC1C6C5BCA7A99FBFBEC4C8CDD8D9D5CCC8C7B2
936A42494A5051524D5E59494C3F4F5C4D5A6C90BAD8E5E1DDE1DAE1DCDBE5D3D1AE9080
57515A6873728E9AB9A6A27E7D697282A8B1BCB1A790958693BFC1C29B9C89898E9DB5CD
D5C0A5A58F9C999A9DA3A79BA38A7E6A6C5F8A6A96779796A59E9895979FA7ABABB29AA5
8989716D4F434C40475B8A9C68594A373B393B34433F3B3736353433373A3A3A36333536
36373739323E657D433D3634353635343736353433323232363738373432323336363636
363635353B36383C477A8EA6939C82624F4B3A33
4D4D4E50504F4C4A484C4B4A4A49484C46484847454345464948494A4B4A494843454646
44434445484745454747433E49464345494B4946474442414345443F4441444140413E45
4D4846464644413F424345484A484541454245474243454046444241403F3F403F3E3E3F
4141403F3A3D3A3F45413B3E4039383F414143463C424847403D414842403F41403C3A3B
393F3E41403D424141404546414245424543403E3C3C3C3C3E404040403E3B3A423F3D3D
3F3F3C3A3D3A3C3D393A3B38393A3B3B3C3B3A3A41403E3D3C3C3D3E3B3C3C3C3A383839
3E38383E403B3A4047444140403F3C3A3F433D40413A3B353B3B3B3B3C3D3F403C383A3B
383B3F3E3B3B3B38363737353B39393B3B393C403D3D3D3D3C3B3D3F3E3C3A3A393B3E3E
433F3C3E41403F423F3D3C3C3F4141403B3D3E3E3C3A3A3B3D3C3C3E414242413D404343
413E3C3B3A3A3B3B3A3A3C3E4146444043423C393F4143413D3C3D403E3E3E3F3F404141
3A3A383A3D39373C363A3F444644403C3D3D3E3F403F3D3B3C413E3D3F3E3F424446433D
3A3C3C3A3D3E3D3B3C40403D393A3D40403F444A3E3A3A3E403D3B3D373E3A3740423A39
3C3E3A3F413F433F3E3A393C3C3A3A3C393C3D3C3D3F3F3D3738393B3B3B3C3E393A3B3B
3C3B3B3A3C3D3B383A3F403E3938393B3D3D3B39393838393A39383939383D3B3A3C373A
3D3C3B3B3A3938373E3B4046413D3C393D3C3A383A3E3E3949443E3A3A3C3D3D3B3E403F
404445433A3A373F393B36393C3B3A37393F403F383E3F3B3A3E3E3B393D40393A3A3640
3D3C3B3A3A3B3C3C403C3A3B3F4B5F718FC1D0CBBFB19A98816F534E493E3D364A3F3D43
3C4441413F403E42414453586B789DCAC9DBC5A985817E8B829081888A7A96779E96B0AE
C8D3CBB2B5A0A09BA5B0BAC4C4C2BAA09F968477878899B3D3D1C9C08F77787A7E858E9F
9EAFA4ACB0B5C5C3C3C4C8B8AFAEACA9A5BABEBEAF937C778FA6A4A5A3B4ADA39B908779
6B5E4F604C414B5F4F5F4A414243414641598DC5D3D7E4DDD9D6CAD7D9D2E1D7D6CAC1B2
8B7F776C6768678498AA9F8881655A576F8BB2BDCBC2B38E6C6B7D8EBAAAB77F9D86A9AF
D2D2E7DFE0D5DFD3D0CEAFB2A9AFA59F868B8EC0A7C2ABB2BAB5AAA6B5CCDADCDED6D8C5
CDB2BAABBBA2B595B1A5D9D5B09A836D706B6759524D4B4A4E484035373739383839393B
31402B36354B8D803B393737383937343434343434333333313334333233353733333434
343535363E2C3B3D7B7FA47C745A403F3937343C
4F4E4D4D4D4C4B4B494B4C4C4C4A49494A4F4E4F4C464744454343464746454545484A4A
484646474A4B4B4B4C4C4944444444424141434547464A4B4645474741414442484C4445
4143464A4A474443444547494A494644433F44474041443F474441403F3F41444B454142
4443403E434441494442413D413E3A43504B4144413F3F3E3C3A3B3F40404244433D3B3B
353D3E43433F43424341484A434346424744403D3C3C3C3C3D41413F41403D3C3F3E3D3D
3D3D3C3B3E393A3D3C3E3E383B3B3B3B3A3A3938403F3E3C3B3D404244424040403E3D3F
413E3B3F433F3C4041403F404142414042483E41423C42403B3B3B3C3D3E3F403A363739
383B3F3D3B3A3C3C393B3C393C3A393B3C3A3C3F3E3D3D3E3D3B3C3F3E3B3C3C3A3C3F3E
3D3B3D41403E3D3C3F3F3E3E3F42413F3B3E41413F3D3E3F3C3B3A3A3C3D3D3D3E414546
433F3C3B3D3E3F3E3D3D3F403E42414044423B393E4041413E3D3D3E3C3C3D3E3F3F4040
403C3A3B3A3534393B3B3B3C3E4040403C3B3C3D3E3D3B38353F3B3B3F3B3B3C44444441
3E3C3D3E3B3B3A383A3F3F3D3E3B3C3F3D3A3D43403D3D3F3F3E3E3F363F3A3945453F44
3B3D393D3F3C3F3A3A3D3D3D3F393336373A3B393A3C3C3A3737393C3D3B3B3C393A3C3D
3E3D3B3A3A3D3B37383E3F3C3F3E3E404343403D3C3A3A3C3C38363538383E3B383A373C
3A383A3F42403D3C3A3B4144403F3F3B3C3A3A38383D3F3A373636383B3E3F3F353A3D3A
373738373B3D3C453E3F393C3C3D403C3E46413D3E4243403D3C3A36393D433D393A3B46
4D48413B3A3B3D3F3B393A404C63839CAAB7B08D8561554B4D493D4341413C3D3E3D443F
403D414040474D5D68707E8098839D849C79805C554B54454F46454F546387819AA5BBC0
B0B08890819896A7BCC3C0BCB0A190778F7C866881688383ADAFADBAB5C0CAC9C8CDCFDA
D8D1C9C3BFBECCBCD3C3CBC0C2C8C8C8C7C6C4CDBCBB9CAF9ABDAAB7A0B1ACA09C91847E
7E71726C6946545053544E465D5650423E4C80C5D9D7E3D9CAC4C1D7EAE1E5DDDBDFDCCB
ADA09588908582799A9EB19E9B7E7C594E5B5B677072737E7D70695B6F85979D98B5ACB7
A7BECDE0DAE7E2E3E2DCD5CBDCCEDBCDC8ACC4C7DDC9D1BAC4C3B8B0BDD2DEE1D8E1C2DD
B8D2C3CCD0CDC6DEDAE7E2DADCCCBDACB5B9C1BCC4B6BEA7B38D7E61473B3431373E3A39
393B31362E38543B36353536363635343233343434343434353636353535363732323232
333536373B3D4172778A684841383C2E39394130
4D4D4D4C4D4E50524D4D4F505151504F4E4E454849474B464B4746494A48474944484C4C
494645464547484546474642494948464444464748454A4E474245464746443D444B4548
4948494A4742434742444647474747484340484B43454A4546424143424041454A444042
444445463D3F3A453F42464241423F46524C404246403E4042403E3E3F41464947403D3E
42443F4244424643413E46484041474244423E3D3D3D3D3D3B41403D40413D3D3D3D3E3D
3C3C3C3D3D393C3E3C3E3E3A3C3B3B3B3B3B3B3C3D3D3D3B3A3C4043433E3C3F403E3B3C
3D3D3A3C423F39394442403E3E3E3E3D3F493F42433C44443B3B3C3C3D3D3C3C3C37383A
393D403D3E3A3D3F3C3D403E3D3A3A3C3C3A3B3D3C3B3C3E3D3A3B3E3D3A3D3E3B3D3F3C
39343B423E3D403E3C3F3F3F4042413D43454745403C3B3C3C3B3A3837383A3C3B3F4344
413E3D3D3A3B3B3B3A3A3B3D393B3B3D423F3A3C3A3C3F40403F3E3D38393A3B3C3C3B3A
3C36363B3C3A3D433D3B39393B3D3F3F3D3C3C3D3E3D3B393E453E3C3A373C38413D3D41
403B383A383A39393B3F3F3D433D3B3E3C37383D4142413D3C3D3E3E3C3E3C3E45444349
3E3F3A3C3C393B37364641383D3C353936383938383A3A383736383C3D3A38393C3C3D3E
3E3D3C3C383E3E39393E3E3A403D3A3A3B3B38353D39393C3D39373739373B38373B383C
45403E41423E39373D4045433C3D3D353B393A38353A3E3939383838393A39393A3E3F3D
3C3D3E3C3D3E3C433B3E3B4139353A393D433D3D393D3F3E3C3B39383E3D4540393A3A3F
4543403B3635373A3B3A3E465161768775795A54454941434A444040383D3C3F3C3F403D
3E3B3E425766717E847F7B73645C4C4B4445404244423C3C43545274919CB48797728D76
878F8699959A8D888083776F695F574C4B4C3D4A384B49535B6762696E8181737C7A7F78
86777B6B7D747569777077726F767B858D8F96A4BBB3BCB5C2AAAEA4ADB3B2ABB1B9BBC4
B6C2ABC1A19B714E5149474F5767707D70645E83A0A7C1CFCCC0B7BAD2D2D3D8DBE6E6DC
CAB5A7AAACB0A29999A2ABA5B0B0A8A87F97626251484C585F625F5765618E71927D9892
91A1B1B6CDCBD0D5CACABDC9D4D9E5DEE9DAD9E3E1E3E3D9D9DBD3CED6DEE1E3E1D6D7C3
C7B5C8BFC2B2B6B4D8CFE3D6DAD1C9BECAD2E0E2E5E2E1E3E2D8C5B57A614B39383D3635
36293438363B353337363533313234363334353535353433343433333332302F33333333
34353637514B7C607C54452E3635314236393038
4D50555654514D4B4C4A4A4C4C4C4B48695F4A4749494E474B4644464744444543474C4D
49464445484B4A46454848454A46424245464340463D414A4844444440494F494B4C4447
4B53544A444647443F41424242434749403D474B43454C474342444847423F3F47434041
42414449474437443F3F413F3E4243464A443E433D3A3C4245413C3B3F42494D4A434041
554E3F3E41434945423E46483F424A46413F3D3D3E3E3E3C39403E3B3F403D3E3B3D3E3E
3C3B3D3F3B3A3D3E3A393B383A3A3A3B3C3E40413D3D3D3B3A3A3D40403C3C4247474545
48473E3A41434142413F3D3B3B3D3F4138473F4344393F3E3B3B3C3C3C3B39393F3A3A3C
3C3F423E3A36383A36393D3B3D3A393C3C3A393B3A393B3E3D39393C3C393D3F3B3D3F3B
3C343C41393B423F383C3E3E4043423D3B3E41413D3B3B3C3C3D3D3C3D404448383C4040
3E3C3D3E3F40403F3E3E404141403D3F433D393D37393C3F41413F3E3B3C3D3E3E3C3B3A
4039383C3C3A3D443E3D3D3F42434241403F3E3F3F3F3D3B3D3F3B3E3E4659554A3E383C
3E3A393D383A3B3B3E41413D463F3C3E3D37383D3D40403B3A3E424148434142403C3E41
3D3E383A3C3B403D485D50373A3D353737393A39393B3B383736373B3C3836373E3E3E3E
3E3D3D3D373E413C3B3E3D383F3B3737393B3A383B37373B3D3B3A3B3B363835383D393B
49413C3D3E3C3B3B373E43403B4142393A383A3733373C373E3C3A3838393B3C3436383A
3F46484745453E4037393942433839383A3C373C3B3D3F3F3E3B3A3B3D38413F383A3A39
373D43423C38393C3F3F43494D4D4E514D50473D413C453F4236443F42424A433D3F3C47
4E4A464E56635F5A544945423D3F423B4A383C403F435057798C94B89695855D75669174
909A7B855E6C554E42494040454242404140443643383F3D42453E4B474443483E4A4444
3B454441443D424737424A40453E3F4748495253646165757966666265636A686E7F8792
A3C5D6E2E5DECC99AD8594829C84928C9194797B816F7E9E9F9284758E9AA5BBCAD5D9DB
D6BEB7CCD6D5CEC1CDC7C3A9A6B4CFBECDB9B69DB19B9F988E91847A6C5855514E506E87
77929FB0BFB9B0C2BEB09D9FB8BFDBD4DDE2E5E7DEE0E3E0ECEAE3E1E6E1D7D6DCE0D2DC
C3CBCACCABB1A6C2C6D3D0D1CFCBCCC8D6DBE4E0E7DADDC9D6C2C5B8B393724E3E3C3335
3C392D343E3D3F3A33353636353436393536363636353332333335373939373435353434
343537383F5D5B4A4636363431363A323833373B
515380967A7A7279535E55515B47524B504E4B4A50454D4B4748494A4B4B47444E4E494C
4D4A4B444852554B434648484A4A45484641464949444F4C46424F474243484C4941434C
494D4D4642454848404144464442444943414144454343453F4544414342434A49484343
4744424641464B4A443F3F423F4648413D404240443A414648453D43404242423B464550
4B474545444141454344433F3C3D42463D3D433D3D443E3E424445423D3938393D3B3F40
3B3B3E3C383E3D3D403E3B403D3D3E3F41434342333D39343B3A363C3A3C3B4046423D43
42463F3B4340393E434141413E3A3A3D3F3A393F4645403D393B3D3B3837393C3C3B373A
3F3A39443A393E3E37383D3C3E3A3C3C393A3D3A3A393838393C3E403D3F4141403E3E3F
393C373E403B4140413E3C404548454246423D3D4146474743413E3B3A3B3D3D36393D40
41403F3E3E3D3F42413C3B3F3E3F414342403D3C393B3E3F3F3E3E3E3E433F3A3E3D393B
3D38393834383D3B3A3D4347443D3C3E383E3B403F393D394A5E5B4448544A473E3C3D41
413C3A3C3E3B3B3F414040423F3B393B3F403C37393C3A36373E42423A3C3E414241403F
3C3A3C3C36373B3A3C3E383C3C373D3B3B383D37383E3636353C3F3A35373C3F383F3F3E
413C383C37393E403C37393E3A3C3C39393C3C3A3738383939393A3B38393A3B3D3F4142
4746423C393A3C3D3E3C3A39383A3D3F3A373A35353B3B403D3A393A3A393C424D3F4343
454A413D3B3C3C3B3E41413D37393B3B3A393A3A3C3E3C3E423D383D3740363F38414B3D
373B40403F4040443D3B3B494449393D3C4547413F403F3D3E433C373D414244393C4049
48474D403E4245433D3A3D413E3D3E413F433D4E5171898EB08F7C8F798F7C93926E7666
6A5447423D4345393941443F3A3B3D3E40403E3D3F423F393B3F403D3D41423F3E3E3E3F
3F3E3C3B3C3E3E403F41403F3D4E636A737481738B7C928CA999A696ABA0A69FA9ACB2BB
C5D5DFE7E8EEE7E2E8E5CAD9CBC0B1B8BBB9BBB8A3ACABA9A0865C505A68A3727D88CBBC
B2A9ADBBB9C4ADBDB2CAA17967587A9CA7B5B2B9C0BFC3CBC1C0C2A1B08695616E4B6374
A09DACBECEC4D3CBC4C5BEB2AAB6BED3CBE3DCE4D8E4DBE3DEE5E9E2DCCFB8B5CCD2D2CA
C2B8CDD4D9C3BBADC9CFD1CFCDCDD5D7DADDDCE3CED9B3B08C907D97789680844F3A303B
323639393C3E3F473436393334393435343637363535363739382F3A2F372C3636383234
35343B3A393C3E3B363435373838383838383838
4C4E669289AEB9C4B5A28E7D706C655F534B4B4D524B4A4B4546494545494848424A494C
4C484C4C41444B47464642434C4845464544464449434B4847424A4545403F4243404144
4042423F3E40434540404243413E4045413F42494D4A44413A3F3E3C3E3C3B403F42403E
404046544144464542414448434948413E4143403E393F3E3D3D3D4746423E413F4B4549
42414347484545474744413D3939424C3E3C413B3B403C403C3F40403E3C3D3D3C3A3E3F
3B3C403E393D3B393D3C3A3E3C3D3E4142413F3C3F4E493C3E403B3B3D3E3C3E43424043
4348423F46433D41424141413E39393C3D3B3B3D3E3D3D40393C3E3E3C3B3C3F3E3C393C
3F3A373E3B3C40413D3C3D3C3D3A3C3D3A3B3E3C3B3B3C3E3F403F3E3B3D3F4042434445
3A3B383F403C42413C3D3D3E3E3E3E3E42403F40434544433F3E3F403F3D3C3D38383A3C
3D3F3F3E37383B3F404042453F3F40403F3E3D3D3B3D3F3F3E3D3D3D3B3F3D393B3E3D3B
3C393C3E3B3D403D3D3B3C3E3E3D42483B3E3B3E403F474747514F3F41463E3E3E3C3D3F
403E3D3E3E3C3C40423F3E3F3F3E3E3E3F3F3D3C37393A393A3D3F3E3C3B3B3C3C3C3B3A
3E3C40403B3A3C3A3C423D3D3C3C40393B383B36383F3A3A34383B3B3A3C3E3F393C3A39
3939393C3F3C3A3C3C3C3E413A3C3C39393B3B393F3D3B3A3B3C3D3D37373738393C3E3F
433C393B3D3C3D3F3B3B3A3A3C3F43453E393B3A3B3F3B3F3B3A3B3E3E3D41464B434642
424B453E3B3D3D3C3C3F3F3C3938393C3D3C3D413B3D3B3D423D393C303D3B4136393F36
3C3F3F423F393B3E3840403F4D404C4D4E4B4A494746443F3E403F393A3D3C3F3C3A3A3F
3E3D403C414141424241403F3C463E595A8773918599857C958698B4908F6A6A5D3F483C
403639403F44463B3A3E3F3C38393C3E3D3E3D3C3E413F3B3C3D3F3F3E3D41453D3C3D3E
41413F3D423D45404E4C595B5B6073777D7F86837E939AC8B6D3C9D7D5CDD4D2DCDBDADD
D8CED3CCD6CED6D2DBDAEACFE3B0A4796F68797D7C9FADBFA3BDA2A46F575B574D6E90A4
79798AA3917574688E7790756F6472726D706C7472778796979FA7998999888C694A4F76
8EABB0D4CAD8CDD1D0CCD3C6CABCBAC1C9BBD8C5E2C8D2C8D8D7DEDDD5C0A2989CB5AFB0
919EB6D2D8D0B7B5B2B7A9A6A8A7AEAEAEB6C1D4CDBDB96D584D3B4641646C6758403932
33333335373D4F65513830323433313A36373737373737382F33353E3239363935383437
39383F3F37383837353637393737373737373737
7E676C5C61638982A091BDB6BCAEA4919D897F7160594A504948504B494C454749514C50
564F4B49554F524C494441454C474948454B504E4F474C4A4F484A494B48484A4A484745
454444464646474A46454546434143484643454D54514944454746454644424542464646
4849515F4646454442414244474947413F434340443E3E3C3E43414347413E4648514240
403F41434442424344424142403D40453E3B3E3B3A3B3B413A3B3D3E3E3E3E3F3D3A3D3E
3C3E43423E3E3A383A3A383A3D3D3D3F403E3B3945534F3F3B3935353D3F3B393D404041
4146424046443E413E3E40413D393B3F413E3B3C3B3A3D413A3D3F3F3D3C3C3D3D3A383C
403C393C3D3D3A3738393A3E3D3A3C3D3B3D403E3938383A3C3C3A393C3B3A3A3B3C3C3B
3B3B393F413E42423F4244423D3B3D40474542403E3D3D3D3D3D3F42413D3E423C3A3738
3B3E3F3E3F41423F3D3C3C3B403F3E3D3D3D3E3E3E3F3F3E3D3B3C3C3F40403D3D454740
3D3A3C3F3E3F4241423F3F3F3D3938393A3F3F42413E403F403E413E3C3D393D3D3D3C3D
4042413E3E3D3D40413F3C3B3A3B3C3B3838393B3D3D3F4344434142413F3C3B3C3D3C3B
403F43443F3D3D393A43403C3B3F4239403B3A35383F3D3C3F3D3D3D3D3A37363B3A3A3A
37393C3C443D393C40414040393B3B38383A3A37413D3836373839393838373738393C3D
403531383C37363A3D3C3B3B3C3F4142423A3D3F41413B3E38393D3F3C3B3E424744443B
384240373B3E3F3C3C3D3D3A3A36363A3C3B3D403D3C3C3F433F3B3C3A424444393A3A35
42443F433E333937354946516E647770866952483E3D42423F3F4B453E403A3C48413D3C
3F3E3B453C3D3F41464F585E8489A483A0958F96718F7894B69D8D76625A41444035423A
413B3F423E41453F3D3C3B3B3A393C403B3C3C3B3C3E3E3D3D3C3D3F3B373A4346413E3A
3E3D3D3A43464051464D434A4D45514E4E4E4E534C4C696E89859B9BA6A0A7A8B1AFAAA8
A3968BA498A7A5AEBED6CBEBD4EED4C9B8B8A790604E606B9A95B9A3A86C7B606E575D55
484D626F6E5B60686795A2B78C917E967B9774885E575957555C5F608E99A8909C725052
5065899CBBB5BDB3C1C0B1C3ABAC8790829196B6A5BEC0C9C4C7DCE4D7C2AEACB5B9C29F
A0869F9FD2CED2B2C09392765949464A59738CA6A6B6A39D6E48403A333F464450464344
3D3835363A51748A734634393B37353D383837383838383735383D403437383334373235
3639444737373635353637383535353636373737
CBB7AC94827D8773897D94ADB1C9BEB7CFCDD6C39F9376795C4B494853636C7E7273666C
7870625652514F4848424948444148463E424644494045424B4442444645494842404243
4642414443403F4242403F403E3C3E43443F3D414544424243414040413E3E403A3C3B3E
42404047454545454543403E46464441414444403B3937363C423F3A413E3E46444B3E40
42403D3C3C3D3F41414141434545413C3F3C3D3E3C393A413C3C3C3C3D3D3C3C37343638
36393F3E42403D3B3C3B3939403E3C3C3D3E3C3B3841423E3C3839423B3D3A37393E3E3B
3B403E3E42403B3E3B3B3D3E3B393D4348403A3C3F3F3F3F3B3D3E3D3A39393A403B383C
3F3C393A3C3D3633393B3B413F3B3D3E3B3D403D403D3A393B3D3E3D45423F3E3D3D3C3A
3E3C3C40403E40423E40413F3A383A3D4947423C38383B3E3F3D3E413F3C4148423E3A39
3C3F3F3E3D41423E3D40413F403F3E3D3D3E3F3F3E3F3F3E3C3B3C3D4141423F3D474B40
403C3A3B3B3D4044413C393B3C3B3C3E4347494A46413F3D3F3740423E3F3C3D3A3C3D3C
4045443E3F3E3D3E3F3E3C3B4040403F3D3D3E403B393C42433F3D3E403E3C3C3E3F3E3D
403E42433E3D3D384346433C393B3B3543403B37393E3C393A393A3D3E3D3D3E3E3B4042
3D3D3F3A403C3C4144413C3A37393938383A3A3745413D3B3D3E3E3C3B3A3938383A3C3D
3C36343A3C39383B3B3A39393B3C3D3D413B3F41413E393E41424747403D4041403E3E37
333B3E393B3F413E3C3D3D3C3E3C39383A3D3E3D3B39393D3F3B3737413E3C3A393E3E3E
3E42383C38364640506A6E8C969C9186775647453B373D3D4140555145453C3D48403C3C
4645405559667276788498A7CAD3C7BAADBC9D9F8BAD898777524E423E39353E3C3A423C
423B3B3A373B413F403C3B3E3E3C3E423A3B3B3B3B3C3C3D3C3A3A3C3A38393E4641423E
4541423D3A3C3F504A463B3F413C3F3C3B3B3B3F4C42413F464349495557616A77808587
9A88A2ABC3BAD0CAD2CDE5D6D8B9C7BEC8B4B3997C79728276947C8F7491729385916F87
566689998184ADBACFC0DCC7CBC0D5B6D3A5A9B0C3BBAD805A4F4C5D6DAE98C1AFC99472
6C5C55627085969CC4B5B5A4A889736754564C4D5C75978E99A8CCDACCBCAFABB1C4BAD4
BCC7AFB7ADC4C0D8C8CCB5B586644E423F424145766B9397956A49303A3B32363640384C
4C403C414D79A19C5A3A373B3737373839383737383938363837343632333936383B3738
36333A3A393B3D3C383534343435353636373838
C2B6BEB7BEC6C8B0B29DA7A4C1C0D7CED4D2D2B8949484846B56586E889CAAC0BDBEB2B3
B7AEA69D88816A56564C57484946494B484A4C474B454E49504A46494C484B4B42404648
4C48464847434244484544464544464A4B4744434241454A45403E403F3E3F4142434244
47423E42424141434647444241414140424443403940413F3F4449473D3D40443C413D49
403F3D3B3C3F42434045453F3F44443F3F3E3E413F3A3C3F3D3C3C3B3B3B3B3B413D3F41
40444847403E3E404041403D3F3D3B3D40413E3C3C4243413D3839413C3D3D3A3A3E3E39
383C3C3C3E3D3A3C3E3C3B3B39383C43453F3B3D403F3D3D3C3C3C3A3A3A3C3E453F3B3B
3C3A3938393D3B3D45443E40403D3E3E3A3B3E3B403E3B3A3B3C3D3D3937353638393939
403D3E3F3F3E3D40403F3E3D3D3D3D3D403F3D3A383A40443E3D3F41403E424846423E3D
3F40403E393E403E3F4447463E3F3F3F3F3F3F3F3D3E3E3D3C3C3D3E3E3D3F3C3941443A
423E3C3E3F3D3E4344403E4143403F3F40424542403F4043443D46463F413D37393B3C3D
4145433C3F3E3C3B3C3E3E3C3B393737383939383C39393E403D3B3C3737383A3C3D3C3A
3F3B3D3E3A3B3D394542403D3C3D3D3F41403C393B3D3D393D3E3F3E3B3A3C3F413D4144
3E3E3E383C3C3F44423C373634373837383A3A383A383636393937343B3A393838393A3B
36393C3E3E404346363535383C3F403F3C3A403F3B3A3740414247463D3B3E3C3A38383A
383B44443A3F41403E3F3F3E3E413E383A42433E413E3F42413E3B3A3E3D3E3E403C3736
343F3E484D586D647A7A7F7B6469534F48363A46403B3F3E413D504C41433C40433D3B3E
4D4C465D63778C9399AAC3D5D9D1D3C2D3C2AB7F606B4544423E3F373E3A3D4039383E3D
3B37383A3A3C3D393E3A3A3E403D3D3F3D3C3B3B3A3A3A3C4041403F4144433F3B3B423F
463D3D36403345374E32413C3E4440403F3F413F3F473F5141504A58616C7A8C9BACBAC2
C3C4C5E3CFE4E0E4E6E5CFC4837660676165647F8D889386B28CA06E8681A69AB59CB191
A49CAC9F957686B3ABD0C2DEE1E8DBE7DEDFCCE5DEDCE3D2C5AD765B5D547C92C492C7C8
D0BEAEA1A2A1A3A6C8C7B0BCAABDA1A78C7B6E55454D45495A6C909E9DA09C97A0A2C2BA
D6B7C2C3B0A2BFB1D5B5CAD4CDA27E62514A413D4445538388A6754B373D3E3E353F3340
514B618392A9A9733F2F373C353839383937363637383635373A373D3A323837353B3B3F
3C363732373E45443C3533343535363737383839
CEC2CFB6B9B0B7A0ADACA5B5B9C0C8CEC4BAAFA29390785A5D4A475F73767C87ADB8BCBD
B5AFB9BDC8BCA38D928482645A524144474549454442534948444143463F47504A44433F
47464545434142444441404242414245454443423E3B3E4446404044403D404342454342
413C3D4647433F3F424445443F3F3E3E4143434140433D39383B42403D424B524647414E
44454442414242403B464B433D40434240413E41413D3F3D3A3A3B3B3B3C3D3E3B37393B
3A3D413E3B3A3E42424446433C3B3C4044443F3A3840413D3C3F4040403F40403E3F3E39
3A3C3D3D3D3C3B3D433F3B3A3836393E3A3B3D3F3D39393D3D3C3B3B3C3F4345423C3B3C
3B3D3F3D383A3A3D42423F3F403D3E3D393A3C39393A3B3B3B3A39393A3A3A3B3C3E3E3E
403B3E3E3E3E3A3F44413E3F414342413A3B3D3D3C3C3E403B3E42434241414245423F3E
3F40403F3F4142413F4040403C3D3F4040403E3E3C3D3E3E3D3C3D3E3E3E403E3B3D3D39
4141414548413E423F3F42494C48444335383F3D3A3A383C413C44433F433E383A3B3C3D
3F413F3B3F3E3C393A3D3E3C3F3D3B3B3D3E3C3B3F3B3A3B3E3D3C3C36383B3E3F3E3D3C
3D38393A383B3E3C464141403F413F453A3D3A3A3C3D403C3C40423D393B3E40403D3D3D
3B3B3B383B3C3E3F3C36353833373837383A3A373A3A3B3D3F3E3B383838373737373737
33393D3B393B40423837373A3E3F3E3D3839403B383A3A4039383E3D35373C383A37363B
37363F3F3A3E41403F403F3D373B3A35373F423D433F4144403D3D3D393B3B3A3D363E46
465665777C838B7A755962433B3E3B3B3F373D443D393D3D3E39413D373A3840403E3A40
4B4540504C627D90A0B3C4CCBAAA957B70615F463E473D3F3B40404137383C3D383A4044
4140404140403E3B3A39393B3C3A3A3A3F3C3B3B3B3A3A3C3D3F3D393B403E383B3A423A
423C47484745424C494D4D54505D575D5D5F6363758880A390AEA6BEB8C2C2C8C3C4C5C4
CBC0CBBBC2B9CBC4C6B7BE84876F847988828D898D93969EA0AC95A581A79AC3B3CBC9CA
BCBBCACACDB7BAC6D0C0D4CAE1DBE1D4ECE2E9E5E6E7F3E7E1E1D2D6B37464A4A19693B6
ADCFCFD3CECDABB6C2C1D2BDC9AFA295A483BB9D9D7E515E47505C5556708A9D97998CA9
AAC3B2C6B3A29AB5ADAEA4C9CDAFA1978C7E5E44453D45436D639D7C4E373B3A413D3B3E
3C3A5B94ABB3A36765443837383C39383838373737363635383B353B31313E3C42433B3B
3A373B38333C44443D3635373636363737383838
B1C0BDCAB0C5CBCCB08F897791A1BED2D8CBB7B2A99E9F848C755756544D585D6A758288
7A727A779392A2A4BDB7AD967070575A59444645494B65554A4746464B445161584D4B4A
4C4E4D4A47494B4C4A4747494946464848464647464242444F494D524C46484A44444140
413F40494945413F4142424242403D3D3E4143444B4B413F3E3C413D42434B554D4C424A
474846424041403D414345454240414341433D3E403E413B393A3B3B3A3B3E413D383A3C
3B3D3F3B3B393D403E4044423E3C3A3D41423F3B3E403F3C3B3E3D39433D3E413D3C3C39
3B3C3D3D3B3B3C3D413C393A3A38393B36383C3F3D393A3D3D3D3C3C3E404244403C3D3E
3C3E413E3A373839393B3D3C3E3B3C3C38393B383B3E40403E3C3D3E3839393937363636
3D383D3C3D3E3A3F3E3C3A3A3C3E3F3F3C3D3E3E3C3B3A3A3B4143414143423D403E3C3B
3C3E40413D3E3F41403D3D3F3A3B3D3E3E3E3D3C3D3E403F3D3C3B3C3E414141403B393D
3F4041474B433D434D474241403E3E40383B4745403E373A3D373C3C3D423F403D3B3A3B
3C3B3C3D3F403D3A3A3C3C3937383938373736373A383534363938353B3E4242403D3C3C
3C37383A3A3E423F4946483F3C3E3738363C393A3A3A413D4348463D393C3A343A3B3A3A
3D3C39383A393A3B3A36363935383A38383A38353536383A3B3937353737383838383737
363638383735383C3B39383A3D3D3A3738393E393B423F3E3C393E3E363C433E37393739
35343C353B3E3F3E3F3F3D3938373738383A3D403936393C3634383934363137484B6779
8582868775655B494C3943383E3B3A3436383C3C393839393B3939383938363D3A3C3A44
4E4949515D6B787D7D7A71655154504B3D3A40464D453C3632393839393E3E3D3C383738
3D3F3F3D3B3A3D40393B3A3838393A39413C393B3D3C3C3E383A3B3C3F444A4D504F574B
54526973828E81A18EAB9CA9A6AFACB5B5BABCC7CFCBD3C8DCCFDCE0DCE2D8DBD2CFC9C0
B6B7AFB7ABB3ABAD9BA999AA90AF939C8F968D8B8D859B97B9A1B0B1BEB0B9ACB5B3BEB2
CFCDCBC7BDBEA9B596C3C2D5D0D5CEE2D2E6DFE0E8DBE1E3E3E2D9DED7C0A0ACCDBFBE8F
7296B4A8D5BCA7A9A2AEBCC0BCB6A9B0A48790A792BF96B4ACA99B7A68748EACC8B3AA97
B9BAB7B3D9C3C8BCCCA5A3A4B2A5B1BEC4BE9A747D6A715B4B6895C0915A41433E383A3E
3E383651636D755E6D4B373337393335393939383736363635353041364F614A534D3D36
3331373535383B3B393636373636363636363636
6474718485A1C7CDC8988960597181A6CAD5D2CCA97E9289968D706A5E4C514952596D84
8481826F90879E929C8C7B73586E6675714A4748494D6D59464445424C434F5B4C414C56
474B4A44404245464A4847494845444545413F4243413F3F4641474C443B3C3D46423B3E
46454143414040424445444345423E3C3C3F43463C4442443E374041493F3A423F453C44
4344403B3B4043435141383D4241424842453B3B3D3E43393A3C3D3C3A3A3D403D393A3C
3A3C3D383E3B3E3E38393E3C443E37373B3F403F3F3939404343434442393A3E3A373836
3A3B3C3B39383A3B3C38373A3D3C3B3C3A38393E413F3D3D3E3E3C3C3C3C3D3C47434443
3B3A3A353A373D403C3C3D373C393A3B37393B393A3C3C3A37383C403A3B3D3C39373737
3A353B3B3C3F3A413F3F3E3D3D3E40423D3C3B3B3B3C3D3E3E44433D3D43433D3B393837
383B3F423E3D3E413F39383B393A3B3B3C3C3C3C3E3F41403E3B3A393A3E3E3F3F36333C
3D3D3D4247413D45423E3C3C3C3A3C3F3B3C45413D3E3A41413839393C3E3B423F3B393A
3937393E40413F3B3A3C3A35353A3D3C3835373A3C3C3936383D3B363B3F42403B373637
3B37393C3D424542393C433A3A423B38373E393A38373F3C3B42403A3D464337343A3A3C
434038383836373B3C393738373A3B3938393633393A3C3D3C3A393838393A3B3B3B3938
3B35343B3E3A3C42353334373B3C3A36393A3D393F4A443D3D393D3B343B443D313A393B
393D463A3C3E3E3D3D3E3A35433D3D43423B3E473B383D4039383F413B464D6480798A8D
896F645A44383838383D35443B3A3639393F3E383A3F42413A3D3B3F443D383B3D434558
676870757D7B6F5D504B443C3F393B3B443E383D39373F3F3C3E3B3C383E3A3B403C3838
3B4245413934353A3B3E3D38373A3C3B413B383B3E3E3E3F4549515B626B7B8BAAABB5A3
A599ABB2C6BFC9B5C3B0BAB1BAB7B3B4ADACA4B9A6B49BBBA0BCA5BAB0B4A6ADABB0ACA2
ABA9ABA9A89381757C6C7467705245494147494146424F4D53646A8F8E96919E829C8C9D
9BA7AEC5C2B5B6A3AC8AA39EB39BACADC5BCD2C3CFB4B0B1A9A0A1AEA2B094B4A3C2A8BD
9DA89699ADB18B9875799592A69DB2C6D2C9D0A68F8FBBC1C4C8C6B6AEADB3C9C9CDC0B2
B5C4B7BCC3CBC6C9CFC6B9A89F99A7B1B6BFB29CB2C8BBAE93A3C8C6D7A472723F40353A
334035373C3A3F343B3940403D3A37423A3B3B3A383637383941517A718B844445423737
38373B3639363332343535353535353535353535
77757B7A7F7A8790AAA79EA98C998AB1B8B596896F555C61626E71748A6E6B5256596066
706A7576A4C9C4D2C4B992A173766575837B7A6F5153474B474A454A4954494D4A4A5551
43484B444C4444484C4D4B444B45454845434541454B433D484B4C4C40424C3C40424343
414040404140444949443F3E3B3B41423D3B3B373943403C413E393F3C3E444847444447
4948433D3D403F3B3D44423E4344403F403F3E3E3F3E3C3A383A4043403B3A3E3F373B3C
43493F3D3D3937383C3F3F3E3E3D3B3A3B3D40423C3D3F373E44383942413F3C39393B3E
3E3F3F3E3B38373737373B40413D3B3C3A393B40403E3C3D3B3C3E3E3C3C3D3E35393C3D
3B3B3D3F3B393D3F39363A3C383A3D3E3C3A3939383C39363938383E35363738393A3A3B
3A3D3E3C3B3C3C3A3E3E3E3E3E3E3E3F3B3A383D433F3A3D404242403D3C3E413B3A3D38
3A413E3E373A3B3B3E4344403E3A3A3E3E3B3C40403B3F3E40433C3C3C3B3A3A3C3C3B3A
3B3E404448433E423E3F3D433F393E363D3E3D3B3D41413E3C3A393A3D3F40403E3E3D3A
38383B3E3F41423F3A37383A393A3D3F3D39393C383A3936383D40403D3C3D3A363A3D39
3D3C3B39393C41453D3B3E3F3A3A3C39373C3F3B393B3E3E3A383C393F393B39343C363F
474042443B3A3A393A3A3A3B353C37393B3B3F383340383A4039393C3F36363D3E3B3A39
403D453A3B37383B3843443E3B38383D3C3C3C3B3A393939403C3A3B3B38383A363B403F
3B393B3F3D403F3E413E3A3C3C3A3E3D404038413E3C4545383B4B4F5A7B679462745951
4C3F3B403E3D4246423A3E433D383A3C3F3B3D3E39383B3938422F423D3E53595E7E6D96
6689545F45464849423B3D433C3B41433C3D4240373B3D393A404242423C393A37333842
3939434A413A39353A43413A3C3937433B3D3E4050576470849FADABADAFABAAAAB7AFB3
98A595ACA2AA8DA27B8F6F74585D615C5A4D53504D4C4F4C546263636C6D70778187837C
8399929A8E7A6A585A514E4843614D5250555451594A494540404149414E46534645514B
4F618793A3B8D1D9D5CFC0A89F8D8792A0B7B2B6ADA8A39E80796E636960645D77619199
C9D5DCD4CDB490877A7B9176958B8CB2C8E1D9D8C0A596C1C7BBA39DA8ABB2C3C3C4C2CC
C6C4BCA9B1B2ADB2B4BAC4BAA99E878A93919698B1BAB9C2DEDCD6DFD8D6BCA48357423D
3A39393A49404D68637A6A8C606C493C3F303A3A353B393D7870AD966872423C38353836
3639363831343435363231383335393631363A36
6D6D777B8E98A8ABB0B0C7C3BF9B7C80646B505E50534F5A5E7977A482857168746D7078
8C8E95929AACC4C8D3B3A3A19E8979829EADABAE9BA0967F726D78847E8E84916250505E
5148494B53444346454E40473C4D42444844424043484748434142494946453D3D3F4244
444341413B3E4448443E3D413E3C3E403C3E44463B433E3B47494343413D3C3F41414245
45474643424444413E43413E41413F413C3D3F41413F3B37383A4046453F3B3B3A363A38
3A3E393B3D3A38393C3E3D3B3E3D3D3B3B3C3F413F3E3E393F443C4041403E3A37373736
36393B3D3C3C3C3C39393B3F403D3C3E3D3A3A3C3C3B3C3F38393B3B3B3A3A3A3E3D3C3C
3D3D3D3D38353A3F3B3A3E4038393B3B393837363B3D39383D3C383A3A3A3A3A3A393838
3A3E3F3E3E414342393A3C3E404141413C3F3D3D43433F3E404141403E3D3E403C3F443B
3538393F393A3B3B3D403F3C404141403F3D3B3939373C3B3D3F37373C3B3B3C3E40403F
42413E3D3F3B393F3939363A3C3A3D4142423F3B3B3E3E3B3D3B39393B3D3E3E3B3D3E3D
3B3838383C3E40403E3D3D3F3A3A3B3E3E3B3C3E3D41403A3A3F403C38383A3A383E433F
3A3A3B3C3C3F42453F3B3C3B36393E3E383F4443414242413B3739343B383E3C4B524F51
4B3C3B3B3838393A3B393735373B363839393D37333E36383F393A3D39393E3D3437444A
4C4E44483C3C373839413E36393E40433F3D3B393A3B3D3E423F3D3E3C39383A3B3A393B
3C3D3B393B3E3D3D403E3A3B3A3738373B3B353E393840403C4855535D6048563A434142
3F37383D3C3A3D3C3932353D3B3A3E423E38383B3E43433B3D31476180748F727D745F56
45483A463B3C3E3E3B383B3F3F4044443F3B3A383C36363B3D3C3E453735393E3E3A3A3D
38373B3D3936393B373A3F3D4441343F435651747EB1BAD1BEC0B5A59D978C81837D8567
69535355474B454F444B414142464841403745474042494649514F505B646B6F79899190
858C9C9AAA9898938C887F778384848C94A5ABA5A59285727761735E785D65606D5C5F62
676B8085989EBACDD7DFDAD7D6C1BAAAC4C8D2DBD2CBC9CDBDBFBDB8AC97897886789BA5
CAD1D7D6D4BA918366648A8FAFB0B1BDC9D7E3D4CEA498ACB8B2A59C9E9B9CAEC9CFC9DF
DBDEC8B3A2A9ACA99A929FA095988F928F83868C969C9A9DB2D3D0E3D9D7CDCBBDA08F84
5C577E6CA38DB5B5C6CACBC7C3B6AA8C7D57433C405B6552736182553F393D3B39383936
3536373A353534373D3A33353B36393533383A39
5A5D635D6B799096B0BFC9D9BD9F61618381735B64596675B1ADD6C3CDA0B28685777068
6E6F73747D76877A78545E62705E697BA1C1BFCECEC9CAA5B1A1AAA3B7B9BEBCBA9E987C
6E4F474D5444474E514B4A4043424740504D4A4A494648494644434145443E4041414142
434342423C3F4346433E3E423F3B3E413E414A5041423E4656544846443D383B40424141
3F444745413E3D3B3E40403F403D3D42414243464745423F3C3C3F4446423D3C3D3D413D
3A3B3A3F403E3C3D3F3F3D3B3E3F3F3D3B3B3D3E413E3E3C40423F464546423C3A3B3935
37393C3D3C3B3B3C3D3B3B3D3E3C3D3F3D3A393B3B3A3B3D3B3B3D3E3F3E3D3B433F3B3B
3E41403F403A3C3F3B393C3B3C3B3A3A393837353D3C393A403F39363D3D3C3B3B3A3939
3F4243403F4142413B3C3E40403F3E3D363C3A373D403C383F3F40403F3E3E3E3A3D4642
3F3F38383C3A3A3C3D3C3A394046474240413D363B383D3C3C3E393A3C3C3C3E41444545
42413C393A37363B3C3F3F3C3E3E3D4744423E3A3A3C3C3B3D3B39393A3B3B3B3E3F4040
3D3B3938393A3B3D3E3E3E3E3E3B3A3D3E3E3F413E42423D3C40403B3B393B3B393D413D
393B3D3E3F3F41423C3A3E3F3A393B38363B3F3F3E3F40403D3A3C363D3B3F3C53524D4B
40373B3A353536393B3C3A38373A363738393B363B4138363B3735383D3C413F3C4E6261
5F52383D393F3C3C343D41454E50463C3F3C3A3B3D3E3E3D3E3C3C3D3C3A393A3D3A3738
3B3C3A37393C3B3B403E39393F3B39373C3E39404442423D3A454A40473D3C3B3C363E3F
3C383A3E3C3D3E3B3F393A3E3B3736373D3B3B37353D433E49546BAC928E6F5651404439
4B3D40473F403F3B393A3B3C41423F3D3E3E3F43403C393E403E3D3E3C3B3D4041403F3E
4544403C3A36383F454143393E4441577373A285BF9DB59A9E8D766358544E433F423F41
3D453E453D3A413A41373D3A3D3F3F3C4039433F413C42485464708098AAB7B4B3BABDB9
9E999395899282957A9173887F8C7F90879BA6AAB0A7A396A7979F9EABA1A5ABB6A7AAAF
B4B7BEB6B2AAB3A9A8B8BBC6D1D2BBB4A9B2A9BFCFC5C5D0CACECECCD5C9C2BEBDAAA29C
B2ABA7A4AAA392969785979CA5AFC0C4C9CFCFD3CBCFC4DAD7D3D4D0D5D1C5CFD8DED5DE
E1E6E1DADCDBDBD3C0A8A094968F7E7977737C899F8E9C899FABAAB9CABBAFB6BDC3CFD2
ABB9BACCBED7D7DDCDD5CBD8CCDBD7D4D2A28D8E8A97946F49413F3A31393C353B3D3C3A
38373B3D393836393E3B37393C31383536383332
5354584E545B6F77768A7C88646E5981A2B7A6B0A1B8A4C1C7CBC1C8BCDDDECBBCB9B7AC
9F8F7F799C72625B68575B55525060677B969EAEA8A3838A86B0ADBE9FAA97B9AEC2A595
9E766665634C48454846465C505B595F61676C727371747372706A52484C484D4845413F
4041424245424145474441403E3A40454241484D473F415663534345423D3C414543403E
41484E4D46413E3E3D3D3F41403B3C42413F3E3E3F414141423D3A3E41413F3F41424542
3F3E3E414543414041413F3D3E3F403F3C3A3B3C413D3D3E3F3E3F454848443C3B3D3C36
3B3C3D3D3C3B3C3E403C3B3C3C3C3D413B3A3C3F3F3B393A3C3C3D4041413E3B3F3C3A3A
3D424546423A3A3D3B3C3F3E423F3C3B3B3B39383C3B393A3E3E3A373B3B3B3B3C3D3E3E
3E4243403F3F3F3D3D3E3F403F3E3D3C3A3E3B3A40413D3B3D3E3E3F403F3E3D383B4546
46463C3B3F3B3A3E3E3A383A3F42444241413E3A3F3B3E3B3A3E3B3F3D3C3C3E41444646
3C3E3C3C3E3B373A3D40473D393E38393F3D3B3A3C3E3E3E3B3B3B3B3C3C3B3B3F3F3D3C
3B3A3A3B3E3D3C3D3E3F3E3D423C393C3E3F3F403C3B3B3C3D3E3E3F3F3B3C3C393B3D38
3B3D3E3E3D3C3C3C3B3B40413B3938343839393737393C3F3738403E4743453F453D3A3B
383A3F3B3D3A383738393837373838393B3B3B383A3C36363C3B3A3D3E3A3F3F425A685A
4E3B483244333D3E48484B555D58483A3B3A3B3E40403B373F3E3E3D3A3634343C3B3A39
3839393A3A3C3B3C403E38383C3A36343A3B383B433E3D3A373D3F373E3540363D34393C
3F3C3E3E3B3E413D3C3A3D42423D3A393E3F3F3938475453836D7464613B403E3F393E42
484239414344413C3B3F3F3C40423C3A4143444B3C3F3A383B4041383C3B3A3B3E403E3A
3F413C3A3C37353E4646474553656F7F92A1829F738D6263504745433D3D3F3A42443F40
3B413C3D3E3D423E40393D3F3F3C3D475E626C657B7582939C9B99A4A1B3C0BFB9B6B2AD
9898A9A5ACA4969B7D896E5E51524B54535C636D74747D7F8F9894A692A29FB4B7BBC7C9
C8CFD0BFB7A8A08E8B999CA5B4B0A9A0A99D8F89958E98AEB9C1C6C7BAB7BCC3BCB2968D
9A928F8E918E88959894A6B7BBBBBDB4B3ABBAB2C2C3C7C9DBD3D8D2D5D4C2CBCCD4CECD
D6D5D8D8E3E0E6E6E6D3BFA29F8D705D565460718884909D9AB3A0AECAB19E97949DB2BC
CCC8D1BECDCBDDD4CAA8B3A5DBC3D5C0BB8776715E5C5A4E3E3F3D4142423C3438393637
38383C3C363836353634374247353A353A3C3A3B
504C504E554D504F4C545B54584D4E5F7B879D99BFC0C2CFD5C7BF89A2ACD6DCDFDFDBD6
CDC7C0BEB7B799C39DAA808C6E70685A53585D595D53514953575A67635F6A728C7D888B
8462524A4D464C494B5A739998A29FA0A9B1B6B0A08B756578736D544345434347444241
424342414743414446433F3E3F3D4145403E4244433D42555C4B3E433E3E414444403D3E
343B4245413B3A3C3C3C3F433F3A3C403F3D3B3B3C3F4040413B383B3F3F3E3E3C3E3E3F
3F3D3D3B454341403F3F3E3D3E3F403F3D3B3B3B3E3B3B3F3E3A3C3E44433E38383B3B38
3C3C3C3C3C3E4144413D3B3C3C3B3D403C3C3D41413D3B3C39393A3C3E3D3B383A3B3B3A
3B3E44484A403D3D39393B3A42403C3B3B3B3A3938383939393A3C3C39393A3B3C3E4041
383E4141414242403B3B3C3D3F4041423D3C393B413E3A3D3C3C3D3E3F3F3E3E393B4441
3D3E3E47423D3C3F3F3C3B3D3F3D3D40403D3D3F3C393D3A3A3C393C3F3D3C3D3F424343
3B3F3F3E413F3B3C423F463C3B4F4A373B3A3A3C3E3E3E3E383A3D3F3F3E3C3B3A3A3939
3A3A393944413E3E3F414140443E393B3E3E3D3D3E37373D3E3B3D453E393A3C3B3C3D39
3B3C3C3B3A393A3B3F3C3D3D37383C3A3D3C3B3A3A3A3D3F3B3F4741464040383B363A3E
3C3F3E36383736363839393838373A3D3F3F3C3B43413D393B3B37383D424A46404C5346
3A39453F2D474C76866D58514A3E342F3A393A3C3F3D3833383A3D3C3B3B3B3C3E3C3A39
393A3B3B3B3E3C3C403D38383C3D37363C3C3A393D38393B38363A3C3B3C43383439363D
3F3D3F3F3A3C3E3A3A3A3C4042403F4143403D3A3E4C534C4B403440403E303E3B3F3D40
3B433A453C3C3B383B40403C3C413F3F44413C3F393A363F433F423D39393B3E41423E38
3B3D39393D3A3942485354637A8582737F685843443B42423C383D3F39383E3E3A3E3B3B
373C3D3A3E4238483A4C4A5B626A7B93B0B1B0A0AAA7B0B3B3B2B0B9C4C7C9C8C2BCBABA
B2B9C3C1CED1D3D5D7C3A777515141494E53535B5C606C70859AA9A79C989FA4A7A4A9A9
9A96948C8A878FA3BAC6CCD4D1CCC9C5CABCAE9D9B9297A4ACACADADB3B1B5BAB5BCADB1
AA9F9C9CA2A4A4B2A4A5A1AFC3CAC9C9CAB7B7A5B1B9C7C6C6C0C4B9B7BBB5C4BECDB5CB
C1D6C7CBD7D6DFD7DCDCDDCFD2C8B18F6F58586B7C76826F7F8999969D9699988C868C92
9CA9A7C3C6DDD1D4C2C6BAD3B9BFA6B2735553423B4C4D55958CA46F7647473D44403A37
383A3C3D3A3C3A3839383D494E3C3F383D383936
605B605D5E4F4F505457515752564C524F5E566B6E989AC0C4D2B5AD809E9DCFBFD0D4DB
D2CFD5D7DAC6CBBDDDBDB9AACDC3A997929AA0938D75655C636D6D7F5C72769FA2C3B6B8
937E6B57585B696B7288B3BED1C5C1ABAFAFB5AB9A846558524C4D4A454544433E404346
4746444242414344423D3C3F434042413D3E42403B3D4145474441433C3D40413E3A3D42
3C3E4346443F3D3F3D3C3F423D3C3E3E3F3E3E3F414241403B393A3E3F3D3B3B3A3C3A3E
3F3D3D39403F3E3E3D3C3B3B3E3E3E3E3E3D3C3C3C3B3B403E3A3D3843403D3B3B3C3D3D
3F3F3E3D3C3D4043413D3C3D3C3A3B3E403D3C3E3E3D3D40393A3B3D3D3D3B3A3B3D3E3C
393A3F434039383C3C3E43433E3C3B3A3A3A3A3A3837393936383E3F3A3A39393A3C3D3E
3B4043424242423F3D3D3D3D3E3F40413C3834383E39353A3A3B3D3E3E3E3F3F3B383D3B
3B3C3A4044403D3E3E3E3D3E403B3A3D3D39393E3B3A403F40413A3B403E3B3B3D3F4040
4044413D3F3F3D3F463C3D3A426061433B3A3A3D3F3D3B3B373A3E41403E3C3B3A3B3E41
43413D3A3D3B39393B3D3D3D423C393B3D3C3A3A433A383E3F3A3D45403A3B3E3D3C3C38
3738393938393C3E3B393C3E3A3B3F3D3C3B3D3F3E3B3A3A3E42473C3D383B353B3B413E
393C39383334363738393A3A3B383D3F41413C3D3D3B3E3C3D403B3D3C444B463E3F403A
3F3C3E47477780A26E574745423F41443C3A383839393735363A3D3D3D3F4142413B3637
3C3E3C383B3F3D3C3E3C393B3E423B3B3F3E3E3C3E3A3D403A33363F323C403D37443C44
403F4446413E3D3A40403D393938393F403F403D3B4040373E383C44413631393740483E
40403A3C3A3A3A3A3D3F3D393A3D3D3C3D3B38393F3A3F5E5F3F3A3E3F3C3A3C3E3E3C3A
3E3C3A3C4143485058635D666E6A624A4C3C3B3B40383C3B403E40403C3B3E3E3E413E3D
3D4249424B5C59847592889B97989A9EABA7AFA8ADBDD0CAC1BBAEA7918B888C8E8E8E92
9BB0ABB7AEB2A39F97898E9177927F8B6B6F67635C67716E84A0BBBCC3BDC6BDA3847475
60555C6A7D92A8BECDD4DAE0E0E7DEE7D7DFDCDCE3DADADADFDADDDDCCCCD2D0CDD3CDD2
D5C3B9B4B9BCB7BBBFBFA79DAAAFB4C6C8CCCAD7D2E0DBD6DAD3D3CAC5C5BCC1B2B1B3A4
B7AEC2BDBBB8C5BAC3C8D5D2D1CEC6AE96878CA5A4AA99947A77685E6F778E9C9B9B9FAB
A1A7C5B7CAABB4AEC0BDCFC0D4C3C5BFB3A1916470ABB9C8CBD3B9C597B47D885B524F44
3E3F3A3E393937383C3A3A403F363B363E363E36
57595F5858515B60596F68845C6D57604A4B4E454A4D607CB6ADCCABA070666679969AAB
A5A9BFC6BBC1AFB3A3B7BBD0DBCECFC9C9D2CBC6CAB8C3AFBA9A7B695D60778292A9BCB3
AAAEB0A5AEB4C3C8B7CAD2D7D8D9C3B0AEA4B6B8AF99736F4C4D4746464242433D404346
474645453F3F4244433F3E40424142403E4448423C40413E3E4345443E3E40413E3C3E44
3E3C3D3F3E3A38393F3D3F3E3A3D413E3E3D3C3D3E3F3F3E39393C3F3E3B3A3C3C403C40
403C3F3C3B3D3F40403E3B3A3E3C3B3C3E403E3D3C3D3B403F3E4338423F3F42413C3D41
3F3F3F3E3C3B3D3E3F3D3C3E3D3A393B3E3C3B3D3E3C3E413B3C3D3E3D3D3D3D3E3E3E3D
3B3B3B3C403A3C403D3D3F3D3B3B3B3B3A3B3C3D3C373839373A3F3D3A39383838393B3C
3E42423F3E3E3E3D3F3F3F3F3E3E3D3D3E3E3A3A3F3E3A3C393B3D3D3C3D3F413F37393A
3F40393A45433F3B3B3E3F3D3D3B3A3A3A393A3B403D403F41443D3D403E3B3A3B3D3E3E
4145403A3D3E3D3F3D3937373C4F56413D3A393C3E3B3A3B393B3E3F3E3C3B3B3D3F4245
46443F3B36363637393939393D39383B3C3A37373F3C3B3C3C3B3D3F413A3C414040403C
36383939393A3C3E3A3A3F413D3C3E3A3837393D3D393738363C4237393841403D3D3E35
353A363A3D3D3C3A383A3E42413A3E3E3F403A3E3D3B423F3D3D3738373937373A3A3A3D
43455D56836F866D4E4644443E3B3A373A393837383837373D41413C383839383E393536
3B3D3C38373C3B3A3C3A3A3F3A41373639383B39383A3D3F3C383C43393B3836383E393F
423E4349433E3E3E3A3E3B3737373A423A3B41423D3D3F3B383B494E4A3B41453D414839
403E3A383D3B3C40423F3A373B3A3B3A37383C3E3E404664603F3B3D433C393C40414449
464040434549505454564D4E4A4245403F373E41453C3A323E42423E3D3D3D3F47405044
6863826F949E9CB5A1A38E948C9BB1C4D8D5DCD5CFCDCAB7ACADA6A49C9A9CA5B1BABEC0
A6A6A597A2949E9CA89FC6CDDCD8DAC89FA195938A97A29FA1B9BECCC6D0D2D1D7B8A19B
80777B87809DB3B1B3BDC2CAD6D8D8CEDDD3E0D9DEDCDFDDE5E3EAEBE7E7EFE5E7E5E6E4
EBE1DFDBD6CBB3A68EA0ADAEB7B1B0BBC7C8C9C6CFCADED8E4DFDFE1E5E6DED8D4E0CAD6
AFBAADB1A595A6ADC8CBCEC6C9C4C2BBBABDC3DAD9DCD9CBC2A59B8D9499A9B1B3ACA3AB
AEC4C2CD9A99858E8B9CA3A59CACAFC6CCCCC9A6B1DDDBDBD8C5CBADD4CBD1BBC4BAB897
765E41403B3B38383A37363C3D424D4E55434B38
4E50554E55565C585F5D5F61595D65625E64616B5B57505E5E607FB39CA86E595566545E
5A648186C2C8D4C5C9BEC1B7CAB8CDC0B2B5A3B1C0CDD9DFD3DAC1CC8F6050614A5D82A4
95A7B5B0BCC0CFDADDD7D6C0D9D0D1C2BF9FA5A4A39D8A9F8A947C63574B4B4E42434443
42434548433F3E44494743403E404342434C4E434242434242444644403F414444424144
3F3B3A3E413F3F40413F3E3B373E433E4744403E404245463B3B3D3E3B383B413B413D3F
3C373E3D3A3E424545423E3C3E3B393B3F41403E3D3F3C414042483A3D393C424038373E
37393C3D3E3E3F3F3E3C3C3E3E3A383A39393B3F403D3C3D37393A3A39383A3B403E3C3D
3F3E3B383D393D423F3D3D3B3A3C3E3E3D3D3F4140383739393E3F393737363637393B3D
393C3C39393C3F3F393B3D3F4040403F3A3D39353A3D3A37393B3D3C3B3C3F43423B3C3A
3B3E3E4646454039383D3E3C383B3B38383C3D3A423B3A36393F3C3E403E3B3A3B3D3E3E
3C413E3A3D3F3D3E3A4140403939433C3D39383B3D3B3B3E3B3C3E3D3A39393A3D3C3C3E
3F3E3B383A3B3D3E3E3D3B3A3836373B3C393736363A3A37383C3D393C35394245474947
393A3B3C3B3A3B3B4440403D37383C3C3A37373B3C39393C3C444A3B38353C3B3C3C3B34
3B403333393938383B465561453C3F3C3C3E383E3837413F3D3E37393C3A34353D3D404F
517D65785441473436393D3B353A3F3A3537393B3B39383733383A3634373B3C37383938
38383A3B33393A3839393A413D44393739383E3D383C3E3C3B3A3B3E3D383839473F3B3C
40393C413C373B3F363E3F3C3C39383F4039383A393A3A354541384346423E393A3C3836
3942383B36343840433F3A393C3B41423A3A3D3B333F3D45423A4643454146535B5C6067
6B605D594E48484449403C42413A3B41423C363B3440403F3B423E39465C758B8D8E8597
A1BBC3B7C5B9AAA7A3A7B4C3D5D8DDE1E9DFE0D5CCB9B1B3C0CFD3DBD3D1CBC8CBD2D2CD
C0C2BCC1BEBDBAC4C8C8CCD2CCC8C4A6959083847473736F69797685869BB1BEC5C8C7C3
ACB0ADA69DA5B4ADB2BBB4BFB4CBC6CED2D1CED1D3D5DCD6DCD7DBDADADCE7DCE8E1E7DF
E6E2E6E4E4E6DDD9BDB8BDAFB0B4C3CEC9D5C2CEC0C4CFD2D3D3D2D4D7DBE0E0E0E1E2E2
DAD5D9CDCEA29EA0C1C5C8C3CCC9D0D3D9D9D4E1CFE2E4E1E0E1D9D1B7BCCACFCBB0887F
8A98C9C8C8ABA98E988C997F95849098AFB5C2BAC2D6D6DEC2D6BCD1BEDBD4D2CACDE5D0
B4A182875254514C494448544A6C96B2C3A7A37E
4D4B4E51504C4C50494D4F4D4B4B4B4A4E48484A4E4E6869635E615C67819963544D474A
4548617199CCD4CCBCB4958F7A8A908D685D64689892B9B2CFBACACCCAA69571574A5F8F
99A5B8AFAA9E9FB1ACC197938A9BA1BEBCC7C7BEA99C7C6C8073AFA4B58664644D3F4346
4445403F42403B434330423A3E3B4248464445443D414341414343423B3D403F3D3C3C3D
44393B43413D3E3F3C3E3F3F3E3E3F403F3E3C3C3C3F41433B393D3B3B3E3B403B3D3E3D
3B3A3B3C403C3D404248473D383F39373F3E3B433F413B41383F42393A423E3E39433B34
373F4443403F41423E3B3B3D3D3B3B3E3F3D3B3A3A3C3E40393938383A3D3F40363B3D3C
3D403E3939393A3A3B3C3D3D3A3C3E3E3E3D3D3E3C403F39393E3D3736393B3A3837393B
3A3C3E4142413D39353D3E3B3E3E3B3B3E41383839393F38383A3E3C393E423D423F3F40
3E3C3E43443E3D3D383A3D3A453D383B3F3F40423A3B3D3E3E3D3B3B393B37383C3A3A42
36393C3B38383C404040393840403B3C3D3C3B3A393A3A3B393A3B3B3A3A3C3E3B3A3939
393B3C3C36393F4445413933343637373737393B363534373C3E3C3A37393A3C4044433E
363937363C3C393D373C3D39373A3F413736413A3D47475B625C43343A3A363E39393A3B
3C3B3937353C3B3A506A67504D4A3F3A3E3E3B3E383A423A363B3639343B35414745504B
574D423E3F403B363B3D363A3B393F3B393B34353D334037383838393D403E393937373A
3936393E393A36353A3C3B3E343F3A393E403F373336393938383A3D3837373A3F42403D
383C39373C3C3B413E3C393A424A49433B3A3F46413637403D3C3C3F4243413F373B3B39
3A3C3C393438373D3E3A3A3437383F423B3A3D3B3B45394142464A516869858C927D827C
6363595442403A3D403D3A3B3F42413F40403D3C3E3A393F3D3F36406FA7C7CCCED5C9CB
CED0C5ABB6AA9593818A84A29DC1D2DFE3CFC2BFA4A6A59098B6D8D9C9CCAFAFAEBBC6BD
AD9FAE92A1909B99A496977974695F7961686963636D777B6A70727F7F8986887D817774
80807B82787382758A83938B9D91969AACA3A5A2AAB1B9B2B1A9B1B2B1C1B7C1B9C7C3D8
C6CDD9DBE1E3E8E6E6E3E3D0D2CAD1CCD4D3D7CFD5C3CAC2CCC3C4BEBFC4BFC3C0CFC7CF
C7D0C4CBBEB7888D6E7D6F7D8DB2C8D3D6E2D8D1D0D1DDE0E9E2DFD5D0C1B2B1BCB2C1B1
AAB2BAD8D9E5CED9C0C6AFA993947F81778B8E98A4B1CAD7D7D7CBB0C0B1C3C3D2CEDFDE
D5C1C8C0BEC0BCB4ADA8ACB7B5CECFE6E0DCD1C1
4E4E4F51514F4E504A4E4F4E4F5152504C4949495053717B705C494B4E606C625F585154
515364699EA0A78D966C60584C4D4B565654534B545D6A7F8B9DB5CAD3CFCCC5A08C5B53
62668984A28B938273806F5A4A57588290A2C8CDCDDEBFB582585A788AB6BBBC87695949
404C4E43434244453F3E4342443F4145413F3F3C3C444340454645484444424140404040
423C3D413F4143414141413F3C3B3C3D3F3E3D3C3D3F4244413B3C383A3E393B3A3B3D3D
3C3C3C3E3E3B3C3D3D42413938403D3D45423C423F42383D373C3E3B3D44424541494340
3D4447433E3E3F3D3C3A3C3F414041443C3B3A393A3D40423A3A3B3B3C3D3F4137393B3B
3C3C3B393B3B3B3C3C3D3D3D3C3A3837383C4144393D3E3B3C41434136393D3E3D3D4042
3D3B3B3D3F3F3E3E3D43413C3D3B38393D423C3B3B3C433F3B3B3F3F3C3F43413C39393B
3B3A3D42413B3B3B393C403D423E3B3D404243443C3D3E3E3D3D3C3D363B3C3C3C373842
3B3D3E3C39383B3F3E44443F3C38383F3D3C3B3A3A3A3B3B3838393838393A3B3C3C3B3A
39393A3A4041434545423C373836353638393A3A3837383A3E3E3C39373A3B3B3E413F3B
35393A3C42403A3932373D3D3A3C3D3B3D3E4239496362685E56433A41423D3F3B3B3A3A
3A39383734393B3E4C5B584C5D594D43433E393A35343A373A423D3D39413A4245424941
3E3935373E42413F3C3D373B3C3A3F3B353A383C44394339393A393A3E43433F3D3C3B3B
3A38393B3B3C38363B3B393C3D443E404442413E3A3A3B3C3D3E3E3E3D3B3A3C3F41403F
3A3C3A393B3B3B3D3A3835363D4445413B404444403D3E4138393C3F41424242383A3A38
3A3E403F363B393E403D3F3B363B44463C383B3B3947485B636F777D88828B7D7B666455
4E4C433F353A3B413A3A3B3F4345434140403B3A3D3A3940383B45668C9D9C99A4A29D8E
8D857A675D5E5A5F698792AAA3C5D3D5CDBBB0A9C7C1B89F9EA7B0A27F77605D595D5A54
525463667378828789998785678D677A797F84868E9CA3A2AA9DAD9FC2B2BEAEB1B5AFAD
B3B0ABAEA4AFA0AE9EB7B1BEAEB4A7C0ACBDB1BEB5BFB7BCB29C9788918A8E7F837E9195
9EADC6C7D8D5E2E3E2E7E1E5DBE2E0E7E0EBE4EBE2E7E5E2E1DEE0D7D1CEC5C4ABAFB9AB
B2A4A7A1AB9AA66F654E546C95BCD6E5E2E4D9D6C7D3CAD5C0CEC1C6B3AE968A7F85A1A6
B5C1CEE0E8EDE2E7E8DFEBC6D9B5B8A18477714E5586A3CFC4CDACAE939CA5C8D5D5DEE0
D5DADCD7DAD8D8DAD8D4CDC6CAD2EEDAF0C6B295
4A4B4B4A4B4C4B49474A4B4B4D504F4D4A48484956525D606B4B5B5E6A6D867D5B544C4E
4C4C534D585C4F58505746494D4C474C534A4A4A4B4B6C64967A96859A91A4A1B8A87C50
4C4C4E49504E6961707568615F56525A607397A3B0D5D6CFCFA766584E758393A7A5A48B
70685C4F594A44473A453E4947403F423F3E3F3D3B45413D4547454C4945403E3F403F3D
414041403F4345404242413F3D3C3C3D3F3E3D3D3E404244473F3D3A3D413C3C3B3C3D3D
3C3C3D3E3C3A3A39373B3C36393D38353B3B3A413F42383E40403C363B3E3C423B3E393A
404747403D3F3E393E3C3C3E3E3B3B3D3D3C3A393A3C3F403B3C3E3E3D3D3F413938383A
3A38383A3E3E3D3D3D3C3C3C3C3B3A393A3A3B3B383A3B3C3D404345383B3E3E3C3B3C3D
3E3A393D3F3D3D3F3B403E3B3D3E3D40363B393937383F3F3E3B3F423F3F43433F3C3A3C
3E3F4144403B3A3A3A3D3F3D3F403F3E3F4142413D3F3F3E3D3D3E403A3C3C3D3C393940
4141403D3A3A3B3E3B41423F3E3B3C413C3C3B3B3A3A3B3B3A393838393A3A3A3D3E3E3C
3937383937373738393938373A373536393B3A383A3A3A3D3F3F3B38393B3C3B3B3D3C38
3C3C393A40403C3C38363838363D433F40444C485664534944433F3B393838393C3C3B3A
393838383A3938393E44494A555147403F3C38383C3738373C423C383B423C3F403D4136
383635373A3B39373B3B373A3B3A3D3A3035363A423841383F3F3C3A3C40403C3E3F3D3B
3B3D3C3B383A36363C3E3D4040433B3F423C3C3D3E3D3C3D3F3F3F3E3F3D3B3B3C3C3D3E
3C3A3C3C3A3B3B393F3D3A393D4243413D45463E393B3B373A3D40403E3C3C3D3B3B3A38
393E4142383C3A3E3F3D42403B3F46453D3E474D5661697C7A7D7B76695B56444841463C
42423D3D383C3B3E3B3B3D3E3E3D3C3B3F3A3438413F3A3C484B586E786D626863565449
4B564A4A606D9385B1B6CFC8BACFD6CEBFB1A5958E83765D59585B4D4D443F413E423E42
4850787BA79EBCB7C5B8C49EAD9B9496A2A8ACAFBACAD5D8DAD6D5DCE4E4DAD0D1D3D3D1
CCC6C2C0C8CFD4C7D3CED7DCD6CDDEC5DAC0D4CED5CFC8C1A79F8C9392B6A0C9A9CBACCA
B9C7C0C6BFCDCDDCE0DAE3D9E7DCE8E6E1E2F1D7F0DCF3E2E6E6E6DDDADCD9D8CFDAC4DA
B5CEB7BCA8B9A3BC919D737DA3BDCFE0DFE3DFE7DAD1D9AFBAA4C0C2CFCFD2C0C7B3BC9F
9AB4B4D8D4EDE1EAE6ECE1F4E4F1D0BFBCC18B6E5D65A6C0CAC9DBA9B888AFBACBC6D9BE
BFC1D1CDD8D1D5D8D4D6D5C9BBCFCFD6ABAB6D77
4D4F4E4B4D504F4A4E50504F50524F4A4D4C4A4651474749536558606C8889985E595051
4E4E51475052534B4A4B4B454A4D4A4C57444247474F444B47505055534F53616F7F6C63
464C454E4C455751675D8178848972836A75717E89A9D5CED1CCB0877966645E749CC2CA
C9C0ADAB9B8E757760614E474E4340413F3F413F3B423F3C404445494A443E3E4042403C
414243414042423F3D3E40403F3F40413D3D3C3C3D3F4142413C3E3C3E413C3E3F3E3E3D
3C3C3C3C3C3A3B3935393C3740413A363A3C3E453F46413E393A3F3B3D3E3C443C3C373C
3E44433D3C41403A3C3A393B3C3B3C3F413F3C3A393A3C3D3B3D403F3D3C3E403C383739
3937383B3F3E3E3D3C3B3A3A3B3B3C3C3B3936343B3836383B3D3D3E3B3D3E3E3C3A3A3B
3C393A3F413C3A3B3F43403C3D3A383C3A3E3F3E3C3C42453F3A3E423E3C40413E3B3838
3A3B3C3D403D3C3C3D3E3D3A393E403E3E4143413F40403F3D3D3F42423C393B3F3E3B3B
41403E3C3B3B3D3F3B3D3E3E3F3E3E3F3B3A3A3A3A3A3A3A3E3C3B3B3D3E3D3C3C3E3F3D
3937383A3636363637393A3B393838393A3A39383A3A3A3C3E3E3C3A393D3E3B3A3C3B39
413E39383C3E3D3C423D3F3D393E433B48464A494B4535363E3E44474140413D3C3C3C3B
3A39393944413D3B3C40464B3F3C393738393939413C3A393C3E3934393F393939393C33
363738393A3A3A393938363839393A383D3E3D3C433C46413E3E3C393A3D3C383B3D3C3A
3C41403C3E3F3A383C3B383A3F433B3B3D393A3A3C3C3D3C3B3B3C3D3B39393A3938393B
3C383C3F3B3B3D373E3C3A39393A3A393E44443B373A3A353A3F42403A37373A3E3D3A38
383B3E3F393C393C3C3B41403B41484D4F5661696C6A66685756514C43383A39433B3D3A
434240403F403E3D42413F3B3838393B3F4140403F3A3E4B5E5C5E5E5D5244474C444E51
597F819C90ACC4C9D0DBD8CECEC3AD9176675B484644463D403D413C3C3C43443F454F5A
718D9BC7CDE1E2E6E9E1CEC4ADBBAFCBD0D8DBD6D1D1D3D4D4D2E0D4DFC8C7BAC3C2C7C4
B8B1AFABBED6C8DBCCDDC4D0CBD0BCCEBBD1BFC3AABAA8BEA69594939294C9C8D9C6E2D2
D5D5D4C2D1C7CAC8D1D8C8DFCEE8D6DBD6E4D4E4D2E4DEE1DEDCD6CDCACBC7C2CDBECEB9
CEBDCEBACECED3C6D7BEC9C1C1C6C5CFCDCECAD5CFDABDC89BAA9BB5B6CDD4DED8E1DBC4
ABB2B0BECED3DFE4E7E0E3E2E2D9C3A2DCCFCFAC92897F9D91BCC2D8BECEBEC8BBBFC0B0
92A9ACBDB5B7C8CCBCB6AF9AA58EA37F7D594545
4F514F4C4D514F4B4F51515051514D48484C534D5857667879828C817E727E635A575050
4D4E554E5B5453564E4D535C5E5A515A7463534A484A5549584F4F4F4D4B4B5150544A4A
5049535E876B786A7270716F78798C98857B5E58525D8781979BBCC1C3BAAF87536D92B1
CDD6CCCEBFC8A0987F7F7A59544843423D3C3D3B403F413F3C4248454A46424347484541
3F3F414344413F413A3D4042424141413C3C3B3B3C3D3E3F3A3A403E3C3C383C3F3E3D3D
3D3D3E3E3C3B3D3C383C403C3D3F3D3B3E3E3D3F3C413F3A36373E353B3C3A443E3F3C43
3B403F3B3B403F3A4843403F3D3A3B3E41403D3B3A3B3C3E3B3D403E3B3A3B3D3E3A383A
3A37393E3D3D3C3C3B3A39393A3A3939393A3B3C3E3935373C3D3B383C3D3F4041414142
3E3B3B3E3F3B393A3D413F3C3D39363A363739383636383C3F393C403B383B3D3D3B3939
3B3D3D3C3E3D3D3F42413D3A464A4A443E3C3A364040403E3D3E4042413B3B4043413C37
3C3C3C3B3B3C3F403C3F43423C38393A393939393A3939393F3E3C3C3D3E3E3D3B3D3E3C
3938393C3D3C3C3A39393A3A36393C3D3C3A3939393938393B3C3C3C3A3E403D3B3C3D3C
3C3B3B3C3C3D3C3A3E4B5D60544A443B433E3E3F403A37443E383E494D504C3F3C3C3D3D
3C3B3A3A36383735373A39343B393939393A3B3A3C3B393B3C3B3C3B3C3E393737393C37
3738393A3A3B3D3E3A3939393B3C3A3A3E3D3C363B353D3B37393A3A3C3F3F3C3A3C3B39
3B403F3A383A37383D3E3C3F414A423D3E3E403C393D3F3C38363A3E3837383B3B38383B
3B373B3E3C3D3E373C3B3C3C3C3A38373D3E3E3D3D3F4041373B3E3D39373A3D3B3A3939
39393B3D3D3F3A3C3D3B4140484E545A5E5D5A58544F4A4A3A3F3E3F3C3A404249403F3D
413C39373B3E41414242403D3A3A3D403C3F404446434A5B444448434445404A57619C97
ACACB9CDCAD1DCCDCDB9B0997965594E4242413B393B423F443D3E3C4846443E3E517483
9BA5BCC5DFD5E6DDE4DDD69B928FA2ADC5C6C4BDBABEC6CBCAD8D0E2C8D2BFC4C2C0C6C6
BAB7BAB5AEB2B4A0B0989087897F8276887F8276888994A9A8B5AAB9ADC5AFD0AFCBAFC3
B1B7AAAFAAB3A4A6AEB3C4C1D7D6DED1D7CBD8BED6B4CCC3D2D2CFD0D5D7D0C5BBC6B0CE
A5C5ABAEB8B6B3B9B0D1BED6D4D4CDD4CDC7BBC2C5BCD1B6C6909896B3C0D7C8DBD8ECD8
C9CBB0D4CBDCD1DEDDDCE0E4DCD8CBB9D4DBD4D8CDAB96876976A19CC1B4CED0DBCCD0A6
94888F9BA3A7BFCBC0BDAF8E7A4D3C423C433A3D
4E4E4C4A4A4C4C4A494C4C4B4B4D4C494D52646775757E887C8D686758534C595A554F52
4F5059566453575160576D786B665659695D514B4E4B4A454F544D5846434B44585A635B
574B53608A8CABC3C1B5B7ADA8A1807D6B5C594E494C504B5A657A939AB4A89B635D6F7E
848B8E92A6B5938D7D6E764D4F4541403C3C3E3C454145443C434B454443424447474441
3C3E3F4345413F443E40424341403F3F3D3D3C3C3C3C3C3D3D3F4845403E3A3E3E3D3C3C
3E3F40413D3D3F3F3C40433F3E3E3B39393A3B3E3A3D3A383B353C3A3839363F393B373D
3D3F3F3D3C3D3C393E3B3A3D3E3F42473F3D3C3B3B3E40423D3E3E3D3A393A3B3E3B3939
39393C3E3C3C3B3B3B3A3A3A3A3C3D3D3B3A3A3B3F3D3B3B3F413E3A3E3E3E3E3E3E3F3F
413E3A39393B3C3D393C3B3C3E3B393E3F3B3E3C3C3D3A3F3D393C3E39383B3A3B3D3E3E
414444433B3D3C404747413F414547464444444341403E3D3D3E40403B3B4248453F3B38
383A3C3C3B3C3E413D3D41423E3B3B3838393A3A3B3A3A3A3E3D3B3B3B3C3C3B3C3D3D3B
39393B3E383939383737373836393D3E3D3B3A3A39383738393A3C3D3A3F413E3B3C3F3F
3D3B3D3C393C4346556D817D6750423D393B3A3A41413E42423F45505559574D403F3D3D
3D3D3B3A3D403D393C4340373D3B3D3E3B3C3D3A393B383C3B383C3D44413C3A3A3B3D3D
3C3C3C3A383738393D3B3E3D3E413C3D4342443E413A3E3C393C3E3D3D3F3E3B3B3C3C3A
3B3B3A373D3E3A393C3B37383E4A433C3D3E413C3B3E403E39373C413A37383E3F3B3A3D
3B383A3D3D3E3C383E3D3F4243403E3D3D3A393C3E3C3C3F393B3C3A3837393C36353638
3A3A3B3D41423C3F414043404044464A514F49463D3D3F433B433E42383F40383D3E3E3A
3B3839363C3B3E3C3D3E3F3D3B39393A3D3B3C48514B44484541464652687C9EAEC5D7EB
CBD7BDCEC1BC9B9F7B785747473F464943413F3F3D3D3F39423D3F3F3B3B47546A89B1B9
CCD7C5E2D0EADEE7DDE2CDBF9097899DA0A0A3ABB8C3C7C7C9BCCEB1CAACBDB0B7ADA494
7C6B6258534F4E3C4E42433C403F3D4343474446475552686C677D7FA37B9C748C658760
61575B435045544E5169739698B7B2B7AFB2A5BCB0B8B7C3C9C7C3CCD5D7D4CCC0BDCEB8
C3B2C2BBBDA9BA8DB29FB8B7D1DADBE2DCD9CFD5C4CCB6CDAEAE93AAC6CFD3DBDCEAE6D8
DBCBBCC9D4CFCCD3CECADCC9CDB2BEBAB3BCBBBABCB5A6998B858EA09E989BB5C3B8A9A8
8F988D9EB1ACB9C7CDD9CFAA9A755A614741433B
52504F4F4E4C4D4F4D4E4D4A4A4F52525D576769716A615A4B4B4C514E4A5857574E474C
4A464B474B4F3F50445B5768565B4F4D4B484A5144504D565256526853594B4C435A5E65
6559615F5B616D9284A4A0C8D3CEC2AF8E817F6E7276736E596266606867636A68545757
4D545E637D8890A2AE8E8454484140423F3F4242444245433E4349453F40424343424140
3F45434042424144424343423F3E3F3F403F3E3E3D3C3C3C4141494644433E41423F3D3C
3D3F3F3F3E3D40403E41433E47433F3B3A3D41443E413D4759413D4C3E3E3A403A3E393B
3E3E3F413F3C3A3B3E3C3C3E3E3D3D403F3E3C3C3D3F4244403F3E3C3A393A3A3B3B3A38
383B3D3D3B3B3B3B3C3C3C3C3C3F42413D39393B3D4345413E40403D3F3E3C3A39393A3A
3E3F3B36383E403E40413E3C3D38363C3F3639393B3E373B3B3B3E3E393C3F3C363B3E3E
3F4242403E3F3D40484944434343454746434243413E3C3C3E3F3F3E3E3C4246413E3F3D
393C3F3F3C3B3C3F3E3C4144403F3E393A3B3C3D3D3D3C3C3E3E3D3C3B3B3C3C3F3D3B39
383A3C3E3A3B3C3C3B3B3D3E3A39383B3E3F3D3A3A3A3939393A3B3B3A40423E3A3B3E3F
3E3D3F3D363E4F59707C7867564437393E433C353A41403C393C42464545464548433D3B
3C3D3C3A3E3F3B36383F3E3939373C3E3B3B3D393D3D373C3B353A39453D3B3C3D3C3C41
393A3A3A39393A3B3D3A3E3C3E413B3D3C3B40393D373A393E403F3C3A3B3A373B3A3B3D
3B393839383A38383D3C393B38423C393A383B3A3E3E3D3C3B3B3E403D38373D3F3B3A3D
3C3C393A3E3E39383F3C3D41423E3B3A3F3A383A3A3734343E3C3A383738393A37353538
3A393B3E40403B404443443E3D3E3B393C3B37393D3D3B3B363F38423D45443E42433D37
3A393F3C423C3D393E3E3E3D3B3A3A3A4647494E4E423F4A484D6C8AABC1C4D7DFD8DFC3
C49F968067594A4646444C44423E45423D3E393D3E4142383F3C44495E6187A3BCCDD9D7
DDD6CCCBC9D3D0D4CBB2C5A5AE7880807F79747780878886746B655B5B53504A4C484644
403F3D3941413A38383F3E3E3F40465054585F69818FAEACAD9998979B8C8D7F7F6F6B58
625A5F5757545A4E49424E4F655C635E716C78718978908EADADADBFCED3DCDED4E1D0DC
C0CDB6BAA6BEACB599A4A8B8BACBD0DADADED5D5DAD6DAC5D7C2D0DAE1DBE6D8DED7E3DD
D0C09EA697A494A59EA999B69AAD9EB7B5BEC1B3B3BBBABEB9ADBEC0BEA1969A9F959597
9D9C9DA3C9C9D1D2D0D3C4A19A9297978C707C63
4E4B4B4C4A46484D4C4C494443494F5155454D484A4A4A48495854534E605F62685B5258
554B4B4440434B434E41474C434C4349474A48494950444C51525C726862594F54555A53
644A6C59665E636F658A85B7CADCD6CFD2D8CDC2C4B3AD909C849D7B8B647C626E524A53
6C8D9DA292776B608587957A4B454546414042423F42423F3F4244444144464644424344
454E493E3E424040444342403E3E40424241403F3E3D3C3C3C393F3E40423D3E4744403D
3D3C3B3A3E3D3F403E41423B403F3F3E3D3D3D3C413C3963996F3F383B3D393F3C433F3F
3E3C3F44433D3C3F403F40444441404241403E3D3D3E414242403E3C3A3A3A3B383B3A36
373C3E3C3A3B3B3C3D3E3F3F3E40403C383941473A474D443B3B3D3D3F3E3C3B3C3E3F40
383D3C383A42433C3E3E3B3B3E3B3C4443383B3B40443B3E3A3C403E3B40443F3B414544
4344444143443F3F4848434444414244433E3C3F403D3A3B3E403E3C493E3B3E3C3F4342
3B4043413D393A3C3D434D4B3C373B3C3C3C3E3F3F3F3E3E4041413F3D3D3E40413E3B38
383A3C3D4041403E3B393B3C3F3834373F433F393B3B3C3C3B3A39393B41433E39393C3E
383C44443D4456615B5A44353C3E3A413F4841393C41434142424141403E3C3C4F473D39
3B3D3C3A3A3B3C3B3C3C39363A373C3F3B3B3C383E3C343A3C363B383F36363C3E3B3B42
3C3C3D3C3B3A39393B363C3A3B3F383A3D3A40383D393E403B3C3B383639393839383A3E
3D39393E3A3C39383C3B3738373D383A3B35383B3F3B38383B3E3D3C3F3734393C39383B
3D3F3A393F3D36374A45424545403C3B3F3D3B3B3C3B38353B383535383C3E3F3B383739
3938393D3C3C373E4443433C383E3D3C3E3B383C393E3F3F3E4438433E3D36363E3F3B3D
3C393D383F3B41404241403F4145494C4E4843464D51627AA3ABC8D5E2E5D4DCC9C19B8B
7163524144423F403B36423D3B3A403B3E453D3C363E413847587B94BCADCBCFD0CBC6C7
B6B19CA692AA959E756B5E5A4E4E424142403F424547464442403F3F41413F3B44413D3D
3F3F3B383A3F3C41373F3A393D393C4347464E597485A1A2B59EADA1B293BC94B591BEA3
BFAEC0B3C1B1B79984665151574C423F4046474C53576263757E8BAABEC5D5DCE1E7E5E2
E2D0B29F98889B7C9D92928A92A6B0C1CBD6C7BEB6CBCCD1D2D6D2DED8D7E1DDD5CFD5D9
CCBFACA6979781888171716A7F6A6F76819098A0AEBAC9D2CCCAD5CACEC8B9AAA5A79EA8
A0A1999D9AB0CCD5D4DEDFCEAFB1A7BDC2CBCDAE
4C4E4E4E505453504E4E4D4C4B4C4E504B4B4B4B4C4D4E4F4D6160695D67616B6A625E66
6B5B4D4F4D4F4841474A4A4C484F4E4C43434C46434C474B49525360575158585C62626C
7B615C565E658C85987D7A8F98B9CACACACACDE0DACEC5CDBAC5CBC3B5B9C2BBA3A16C69
9DB9C4C0B9BAB789887363707068624F4546414547434E484843483C40473A464049474A
3B3F4147433A434C453C4D3F414146454142413F43413C43393C413C3F3F413E44403B43
3F3C433C3A3D3F3E4042413E3F3D3A3E3D3D443E39403470D29E3647363E43403B393939
3C3E3B3C42413C3B3F3D4045433C3C433A38383D3F3F40443D3E3E3E3D3C3B393C3D3E3C
3B4343373C3C393A3F3D3C433C3C3F3E3B40433D3B41423F3E3B3C423F403A363B3B3C42
3D3A393C3F41414046443E3E413B373B3A3C38373D3F3E403A3D42443F39393E42414140
3F3F4040423F3F42413D434D5A504642403E3D3E3A3F403D3C3E3F3C41423C3F393D393C
3C3A3F3C3B3C373A343C413F3C3D40413A3635393D3B3B3E38393A3A39393A3B3E3F3D3A
3A3D3F3E3D3D3B39383838363736353536393C3E3837393E413C3637333A3F3C39393A39
3136373A454F483A3D3F3B3D3D3A3D393A413E39404239342F363D3E3A383B40513E3638
383A3B363936383632383C3837363637393C3F423939393B3E403F3E3B3A393838393B3C
3A3C403D36363732333B3B383936363F393A3636393636413E3A393C3E3B373635353637
383A3C3E3A3B3C3C3C3C3B3A37393B3936363739333B363A373C383F403D3B3A3A393735
37393B3B39393B3E40403A393F3F3F4535383836383D3F3E36383B414646413C3834383D
3C3E3E373B433E40413C3D3E38393B3B3A3A3B3C3D43443E393A3A383A3F3B3B3C3E433F
3F38353E3842403B3D413F464548575157676B8F8DC2B3D4D4E4E1DED9D7C6AA997B5D4F
463D3F483D3F383D413F443F3C3C3F38373D393E3C3E37446FAAC1C1B8B4AEA89E907F74
7D7D78655C554547474040403C3F413D393E3A40403B3F393841453F3B3A3C3E403E3D3B
3A393939373B3F3C3C3F3E3E393C403941404745434B54676453575D59685D6F637D6E90
7B9A8DA38EA49DA8897B6452544C524548445B6F808996909392A5C8DCDBDDE6E2E6E7F0
E5DFD5D7B39C909A9AA18D888A83A2B5CFD2D5D7D0DCD8DAD5C4BDB7B1A9AAB0988698A3
BFC2C5C8B7B6B8BCAA95907986737A72796B718797A4B8C9C5D2CCD7D7D8DADDD7D6D8D3
DCD5C6AFA3A6A4B3C4D0D2DFD3D4D5D8E0D8DBD0
4A4B4B494B4D4C49484A4C4C4A4847464B4B4B4B4B4B4C4C4D564C524B54484A504C4A52
5A585863555F4E5A4E5F4E5342494744444E594E4B5048494649444A4C45474952606775
755E5C58584E68616C56535655677B7A848D9AB5CBCBD1CCC9D1D7DAD0D0D3D5D6D5B4A9
ABA3ADB4C4D1D4C5B6B29DAFA09F9E8A766B5E5E5E6381769377776357544D4452494D45
444841404541404343493B4D394A343C38483D474B434D4148393F3B4141494647444048
463E42403B3D3D39393C3D3C3E3C393D3B3C423C383E3561C7B44734383F423E3A3A3B3C
3C3D3A3A403F3A3A3635383C3A35363C3B3A3B3E3F3D3E413A3A3A3B3C3C3B3A3635383A
3C44473E393B3B3D413C393F3D3B3E3F3C3E403B373C3C3A3936353A3B3D39373B3B3A3E
3E3C3A3A3A3A39393E3E3B3A3E3C3A3E3C3E3A393D3D3A3C373B4145413A383A40403F40
424446463C3A3C403F3B3D43463F3A3B3D3D3D3E3A3C3C3A393B3E3E373A373D383E3B3D
3B3D45423D3C373B393F433F3B3B3D3D3D3B3A3C3D3C3B3B3A3B3C3C3B3B3C3D3B3D3C3B
3C4143433C3B3B3C3C3A3A3A3C3A3837383A3B3C3936383C3D3C3D3E373B3D3936383B3B
38373D484C463D39383B373A3B393D3A363E3F3B3C40403E39393A393A3B3C3E413C3937
373B3C393A383A38353A3E393333343637393A3B3E3D3C3B3B3A39373C3B3B3A3A3A3A3A
35373D3C36383A363C3D3A383939393C393B39373A393A42403B393A3A3735363C3D3D3E
3F40414241403F3D3A39383740403F3B3736383A343A3A423F3F373A3536383A3B3C3D3E
3D3D3E4041413F3E393D3A383C3D3D41383A3A38393D3F3D3A3A3B3D3F3E3A373A3A4041
3B3A3D3B373F3B3D3F3A3B3B3B3C3E3D3C3B3C3D3A3F42413E3E40403B413E3F3F3F4440
40413A3D3D463D38383D45474C658696BDBAD1C4DDDAE2E8DCDACDB6B29F8F6F604F4240
403D3E44373D3B3F3C383D3B3A393D3C3A3C3C3E4E404E65939C9C896E655B5351515251
4C4B4A3F3E423E43413D3E3F3C3D3F3B3F423D403F3B3F3B35393C3D3C3D3B3B383A3C3E
3E3D3C3B393C40403D3C3C3E383A3F39403E433F3D3F3F48453D474F4B5756655B695B6F
59716575677C7B86898D8B8483777B718780879193A7C1CDD2D1D7E1E4E0DFE4E0DDD7DF
DDE3DCDCDBCFD7CDDECAD6D2CCB9B5B5ABC4C2C4C4D3D3D6CFCCCAC2A1928B8D78615F58
7574847F8E8FA09A9F9DA6B1BEBEBCB9B4A29DA5ABB4C9DBD4DFD5DCDBDFDFE2E0E2E6DD
E0DBDBD3C3C2B3BCB5C3BFC9BED3D0DCCDD6CCCC
545553515153524E4D4F504F4C4947474E4D4C4B494846455357494C4751474A4A4C4C4D
4F4E515A56585253565D5A5B595F5B5759656C5A535146444448464A4C4F5E6A706E625F
5C4B515556495A5753495150595E6B5B566060626B697C7391A5BBD2C9BCADB5D0CAC9D8
CFB7B9BBC1B6C3ABBCB2BBC4CCCDCEC1B4AEA6A6A6A98A83859999AE90A493A88C9A909E
848576666A6A5D5853514A45483F434F50677789949689685B3B44374138413C46454046
463D3E4241464A48464442403E3C383C3A3A403A3D3F3C54A9B45D3B3A3F403C393A3D3F
40413D3D42413D3E403D3C3D3F3E3C3B3B3B3E3F3E3B3B3E3B3937383A3A39383F3B3C3D
3C3C3B36393C3D3E3E3A393D454142443F3D3D3A3A3F3E3C3C383639383937373C3C3939
3E3F3E3C3B3B3C3C3D41403D404141433E3F3C3B3E3B383A393B3F42413B393A43403D3C
3D3D3D3B3C39393D3D393A3F423D3B3D3F3E3D3D3F3D3B3A3A3B3F4449473D3E363C3B40
3C3E45413B3A373D3D4144403B3A3A393B3B3B3B3A3C3B373C3D3E3D3C3C3E403A3C3D3C
3E4245443D3B3C41403B393B413E3A393A3A3A3A3A353B403B3C413F363A3D3C3A3B3C3C
413F485453453C3C373B383C3D3C413F3E40413C383D403B403B37383C3E3C393A42423C
3D403F3E3A3A3C3A383B3C383537393A3B3B3A39403F3E3C393635353A3A3A3A39383737
34363B3B36383B383C3634373B4143413C3F3D393A3C3C3F423D3A3A3A38393C38383939
3A3A393941403E3C3B3A3B3B36373839383534343736363E3B3B373936383A3B3B3B3B3C
3B3A3A3D41403B373B42413B3A3A39393C3D3D3B3B3D3E3D3C3B3A393938373637373B3B
36353837383F3A3B3C35353538393939373637383D3E4143403C3C3F3C413E3D3A373B37
374239393E473C3C4142576483B3C8D5DBDFDCDBD0CABBBBA9A688816B685648443E3A3C
3D3A3737393D3A3B39373D3E3E39383A363B47454E5357715A5A4B4D474542424343413E
403C3F3C393D3A383B3A3C3D3B3B3C3A43433E3E3C393D3B413D393C3B3D3B3B3B3B3B3A
3B3C3C3C393A393B3C3C3F41464448414542464150545761666873798A92A0AEAEB3ACB1
A8B7ADB3AAB6B7BDBBC7D1D2D3CED4D1D3D1CDD7C6D3DAE4DEE4E8E6E1DDDBD9CAC8BBB6
AAACA6A69AA6A0C5C1D4D7E2DFD7E2E1CEE0D9D2D3D4CBCCBCB3ACAAAA9A9192877A776C
545D5A635D7573716E757D99A1B0ADB1B7ACA9A69A99AFC5CDDED9DFD9DEDCE0E0E1E6DE
DED1CCC3CFD1DEDAD9CAC3B3B9B9C8AFC2AEB6B4
4C4C4B48484A49454E4E4C4946454648454647494A4B4B4B424B474A4447414842454644
43424346494646424B4C51504E53504E4E5558474A4843414246484C494E5D6C71695950
56484C4C4D424A4648424940535B71615F5C4F4C4C555C514F5E6B79716E6C86978894B3
B1937D6E665656555861656CA2A5AAAEB5BFC1C0C8C5CB9FBE9AA5A1AD9CAAA3BDACC8C0
BAAF967D84A1AEAF949575906B897495A0BEB4C8CAC1CC9D5F4E45473B473B404B4D4644
46413F4540454A4A474341403F3D393C3A3A403A3B39363A5F6840333A3D3E3A383B3E3E
3A3C38373B3A373941403E3B39383735393C3F3F3D3A3A3C403C3839393736363E3A3B3F
403C39383E3F3F3D3B393C40453E3F423E3B3C3C3F43413F403C383A383837383C3C3A38
4144433F3A3A3B3B383F3D38393B3A3B3D3E3B3B3E3B383D403D3C3E3D3C3C3F4E494340
3F3D3A37433D3A3A3A3A3D4246423F41413E3D3D413C3A3A39383D444C4A41423B434348
3E3B3E383539393F3E4042403D3B3A3A3B3D403F3D41423B3D3E3E3D3C3D3E403B3D3D3C
3D4042413F3B3E4441383539413E3B393A3B3A383B3740453D3D413A373B404242413E3C
3B40454847433C373337343737353A393D3939383A43463A3D3A383B3F3F3A343D45443F
413F3B3D3A3C3D3A3839393538393B3C3C3B39383D3D3C3C3A37373A3737373737363636
3A3A3D3B35363A394038383A393E413B3E413F39393C3C3B3B38373939393C403C3B3B3C
3C3B39383E3E3D3C3C3D3D3E403F4042403C38373B35363D3B3836363E3C39393A3A3836
3737383A3B3A37333D4749413B3C3A373F3F3F3D3D3D3D3C3B3B3A3A39393A3B3A383739
3C3D3C3A323934363B383B3C3A3B3B3B39393A3B3E3B3D423F38373C41464344403B3E3B
4249403F3B3F3940445E99AFC4D9C4BFC1B3BC91A26F7C65605A56454A3A48433E3E3D3C
3D3D3C3A3E3B3737393939373C3D3F444350655B7E646449514A5B484644434342413E3B
3E393E3F3C3D3C353A3A3C3C39393A3A40403D3A383739393833313B383C3A3C403F3C37
373B3E3F3E424046505C666377747A777A757770979EA7B4C0CAD2D5DBD9E5E4DED2CBC1
D0D6D3D1CCCECCCAD7DBDDDDDEDDDCD7BBB099A595AFB2BED2D9DDDCDCDEDEDCE1E2DADA
D0C9AD996B5A59627579877D9194C3C7D2CFDADBDDE2D8DBD5DAD7DFD8CFCBCAC2BFC1BE
9B9B99867D74736B75797A868280757490919B9D8B7A7A808FA0BBC0DAD3D7CDC9C6CDD2
E2DDD5C6C3CACEDFCCDBD3CCA9A68A947E978DB2
50514F4C4D4F4F4C4E4E4C4A4848494B4B4B4A4948474646445052564F4C454B4A494746
474B4D4A4B4E41504050464C4748464946464D46494C52514E4848464846454C514F4E4D
524B4C484D4C4B444E5C69636D67715E504B4B5B5C746D6B5758554F474A4B636C64758A
89765E525B4C4D483E40474A4856677D92A1A9A7AEC0B1BBA8BBB3C6BBB6A5B6818D9DB4
BAB0A89EA3BEC7B3986D7B62868BABBED3CDD8D6D0D2CBC8AA9985555043403C4045413A
3F413B3C404141403D3C4044403E3A3E3C3B423B40403C3B3C3A393C393C3C39393B3C3B
393B38373B3A373A404446403936383B373B3E3E3C3B3B3C423D3A3B3B3736383A383A41
443F3C3E4041423F3B3B3F413D36373C3A393E403B3F3D3B3C3935383B39393A3B3C3C3A
383D3F3B383A3D3D3E45433D3E3F3E403A3B393B3E3B3B42423E3C3D3E3D3E414B46413E
3F3F3D3B443F3B3A3A3B3E423F3B3A3C3D3C3D3F3F3A393938363A404749454A42453E3E
3E383835393F3C3F3C3D3E3F3F3D3C3C3A3B40403C3F40383C3D3C3B3A3B3D403A3C3C3A
3B3E3F3D3C393D43403734393E3C3A393A3A3A393B3741453C3E433B4744424140403F40
3E42403C3D423F37373B3839373438373A3638383A4444373838393B3D3C39363E3E3A3A
3E3934393D40403C3B3A373438383838383737373C3A3A3C3B383A3F373736363638393B
403D3E3D36363B3C3E393C3C37393C383B3C3C38383C3D3A353334363737383C403F3E3F
403F3C3A3F3F3F3E3D3C3B3A3D39393B3A3736393B3636393D3D4042403933353A3E3B37
393B3D3C3A393A3B384247413C3E3F3C403F3F3F3E3D3C3C3C3D3D3D3D3D3E3E3B3A3839
3D3E3C3A3D403737393537383B3B3B3A39393B3D3C383A414039393F393D3A3D3C373A38
484843473C3D42566A82AFABA7AC969776735F594C44464140453642343B3B433B3C3C3B
3C3E3F3D393737383A3C3836424E565B5C6C7A6568716B6B393E383C3E3C3A393A3B3C3C
3F38373936373C373D3E3D3A3838393B3C3C3E3B3938383A34333541363835363139434E
5C6C757874858B94A4B9CBC8D4CED4CECBC1C2BAC3C4C7C9D1DCE1E4E8E5EFEBE9DFE3D7
DEDFE3DFDFDEDDD9DFE0E1E1E1E0D5CCB4A588948AA7A8B3B5B3B5BBC5CED5DAD7DBD9E1
DFDEC6B3946E675D6168726564586963756E8DA8B4D3DAD5D5E1DDDFE0DEE3E5E2E4E7E9
E5E2DFD1CABBB7B4B3ACACA29D8A827B85899DB1B2A28D7B7A8C88A7A7C7B7BEB5B1B5B8
CDD5DDD7D9CBD3BEBBB4C6B9BAA7AD85937F9DB5
4E4F4D4A4B4E4F4C4D4F51514F4E4D4D4949484848494A4B474945494B4C494E46434346
484B4A444E4B444A3F494A514D4C4A4E4B4C595A54555E5A544C4E4B4B49444849454644
47474A454F55504C4A574F4B52586154503F434643555155504D565357594F545053676D
6F746F73614B513D463D555153667788949CA6A7AEA7AF888E778D8CB5ACCFCAC89BA68B
867F7F858596A0815F4C586C6D9BA1C6B4A296ABB3AAB4B8C2C8C290906A583A403E3E3B
434A423E4141424341404246413F3B3F3D3D433D383C3A3C39383F3C3A3C3B393A3C3B38
3D403E3D41403E413D3937383A393634363A3D3C3B3C3C3C3F3B3A3E3D393A3E3F3F3E41
423C383B3E4044433F3F403D423C3D3E3B3B3F3E393E3C393A38363B3E3B3C3C3A3B3D3C
393F413C3A3D403F393D3B383B3B3A3C3839383C403B3B433E3C3D41413F3E3F44403C3A
3B3C3C3B3E3D3C3B3A3A3C3E3E3A383A3B3A3C40403F3E3D3C3C3E424547444943474142
3D373A3B4247403E3C3A3B3F403F3E3E403E44453E3E3E363C3C3B3A393A3C3F373A3A39
3A3D3E3C37373A3F3D38383D3A3A3A39393A3B3B3A383D3E3A404642564C403A383A3E43
4845403D3D40403D3E423F403D393E3C393C3E3B3A3F3E3638393A3938383A3C3F393539
3D3A383C3F44423D3E3D39383A3A3939393A3A3B3E3A393C3B38393E39393838393B3D3F
3E3B3E3E39393E3F38383C3C37373A3B36353738383D403C3B38383B3C3A393B3C3A3939
3B3B39373A3B3C3D3D3D3C3B39373A3F3E39383A3D40413D433D3939403832343B3F3B36
3A3D3E3C39393C3F363C423E37393C393E3C3D3E3E3C3B3C3F3E3E3E3E3E3D3C383C3D3B
3A3735393C4037373B393C3D3B3B3A393737393B413C3C41413B3A3F44453F42403A3C39
3D3B3A4640424F6A858E9A88786C514A5152434A3D3F3F3B403A3B374336403A3D3D3C3B
3C3C3B39363539373A444B55737B7C746D767762704A4237443440393B3C3E3F40403F3E
403E3B3E3C383A373F403C393938383B3C3C413F3C3C3A3D3E3C39412F393D4251627B92
ABC1CDCEC7DBDAD6D0D1DCD5C8BBBCB3AEA8B3B1B0B0B8BECCDDE4EBF0EFEFECE6E1E5DC
E1DDE6E2E4E4E4E1E0E3E6E7E3E7DCD8D4D0C5D1CAD6D0D5DED8D6DBDFDEDEE0DBDAD1D3
CFD9D6D6CFBEB4BA9BB1A8AB8B73534A473F516A7FA8D0DAE0E0D5D3D9D2D3D2D3D8DAE0
E1E4DAE7E2E9DDE2E7DEDFD2D1BCB9B29EA2B3CAD5D5CCBFC7BACAA5C0ABC6CACED1D3C3
C2C3D0D3CDCCCCCCAEA4938398AAAABDA5B7A8B2
5252504D4E51514F494B4D4D4B4949484F4D4B48474849494947454D595B575848444950
5152524D59545C5A5B55616268665F5A504C524C534E524C4A464E4B4949444A4A444846
4A4B4C454A4E495043584E66758A897D6F4F574459565D4C5A4B564A4C4843464445574C
424C484A4844414945555A58535E5F605C5A63626D756A6C596460696B8AA0B2A0ABB9BF
C7B5947F6669887D948AA4908A808399976D5649505A59708EB0A4B1A3AA8A70614C4440
43473F3D3B3C3F44443F3D3D403E3A3F3D3D443E3C42413D3C403E343D3E3C3A3B3E3C39
383C3B3B3F3E3C3F473D394046443E3B383B3C3A3A3C3D3B3C3A3C403E393A403C3E3B3B
3E3C3B403E3F43433E41423C434142413C3D3E393A3F3E3B3C3A3B423E3C3F3F39393D3C
464A49403B3C3C383E3F3C3C403F3D4138393B40423A373F3B3B3C40403D3C3E45423E3C
3B3B3C3D3C3D3C3B39393C3F403D3B3C3B3A3B3E3E403F3C3C404445504E44433A3E3B3E
3B373C3E43473F3E3E3B3B3F413E3C3C47424A4E4441423C3C3C3B3938393C3F393B3C39
393B3B3935383B3C3B3A3C40383A3B3B39393B3D393A3A3A3B4144424F463D3A3A3A3B3D
3E3C3B3C3A36373A373C3A3C3A363C3B353B3B393E43413D393A3B3A38383A3D3D39393B
3B3C3F3E3B413E3A3D3D3A3A3C3B3B3C3D3E3F403F39363A3A36363B39383838393A3C3D
3A383D413C3A3D3E3F403D3A3835343738323539393B3E3C3E3A393C3E3D3B3C3D3A3839
3C3D3C3A3839393A3B3C3C3D3936373C3B383B423D4C4F4751463B383D3936373B3B3835
39393939393A3B3D3A3A3D3B333337353B393A3D3D3A3A3C3E3C39393A3B39383C424240
413C393D3E42393A3E3B3B3A4343413E3C3B3C3E433E3D3F3E3B3A3E44423A3D3C363633
3B3E3A46494D536D71736653494240423B3B3B433F41413A393C34403C3F3B393A38373A
3C3D3D3D39363A383D4C55626D6A65554E514B433D3C3947373733403C3C3B3A3A3A3B3B
353B384041393A3A3D3E3A383B3A383B3D3C433F3C3D393E3A3A39483F5B6971949FA9AF
B9C4C8C5C3CBC0BCB4ABB6B2B8B0BBBDBFC1D5D7E3DDE1DFE1E4DFE4E3EBE5EAE0E3E4E0
DBD7E4E3E3E4E0DEE3E3E4E2DBE2D7D8C5C4C4CCD2DAE2EAE9E8E8EAE8E2DCDAD7CEBFC4
C5CFCCCDD9D4E6D8E3D2DDD6C3B58E7C6F575A4F556295B4CED5DAD9B9AEADACAFB6BAC6
D8D8DED4E6DFE4E1DFDFDDE0D6C8B6AEB4B7C1CACDD2D8D7D1D4C6C5A9B1AAC6D2DFE7D2
C9C0C2BBAAA3B1A7A28883718596C1CFE1D2D1B4
575653505053535150504E4C4A4A4B4D4A494847484B4E51454B5667746D5E57544B4A4B
47484D4E49535B715C5E51524D514E4C47484B3D50484D484A464C454D4E484D4B434745
494A504F5760657B677B5E6D65756D67604E76628F768C697E6C7E695F4A474B4D506A5A
454B44414547524749404C444A50494845424A4543494D464C464645486C8B87989EB6B2
B7BCA896694C605765829BBCAEC0ADCCB3A5815F4F494B544F657A84B2B8CEAEB1877166
5E5950513F3C3D40413E3C3E3E3D3A3E3D3D443E3B3F423838403C3941403D3A3C3F3E3A
373C3D3D41403D40403D40444138383F3A3C3B38393C3C393D3B3E423E36373E3D3F3A36
3A3B3C42413F403E3A40443E34363B3B383C3D36393E3D3A3A3A3D453D3C414139383C3A
3A40413B3B40423F3F3D393B3F3B383D393B3D434439333A3C3A3A3C3B3A3C403C3B3836
36373A3C40403D39373940453B39393B3B393A3D36393834343B414142423A3C353B383B
3A383D3C3E423D3F413D3C3F413D3A3A3C363F463D383B363C3C3B39383A3D3F3E403F3B
39393834383B3D3B393A3D3F383B3D3C3A393C3F373C3C3B3F423F3B3C393A41433E3734
34393F3F3B37383B343A393C3A383E3F3E413A3742473F38393B3D3E3D3B3A3938383B39
33393E39353B3835393A38393738393A3B3C3D3E3E363338393535393636363737373737
38373E433E393A3A3D3F39353B3A383D3C34363C3A393B3938333135393938393C393738
3B3E3D3B3E3D3B39383838383E373439414D6276767C6846493C36393537393B3B3A3938
3B3937393C3E3D3B3835393A333439393836383C3D3A393C3A363333363838363B3E3B3C
42413A3A353B363B424041404443413D393838393B39383A3C3C3E41413D363D403C3F3D
3A453E4A5A626078464D403E403C4140423C383B333838343A3F3F3F3F373C383D373335
3737383A39353B3C424A4649423D3F3A3C40393C3A424438393A3D39393A3B3C3B3B3A3A
393F373B3E35383D3A3C39383D3C383A3D3B423C383A363C4148506A6A8D9A9D9A978B7A
72747471726E5E6C777B8F93A5A8C5D4D9D6E0DCE4DBDEDBDBDDD9E0D9E7DBE5D6DBD6D4
D2D1E3E9E7E8E1DEDEDEE0E1DDE8D9D8D5D3DBDFEBE7EAEBEFF1F0EBE4DFDDDDC2BEB6BE
BDC7CBD6D2DDD0D8D8D7CECEBEBDAE96A087A2809C7D8F94ABBACCC0CEC5C7C2BDBAB6C3
BBCAC8C6C6D1D1D6CACDC2D2BFC3ADADABAFBAC1C0C3C5C0CBB5B39AA498A4B3CFDEECE1
E2DBD1BBBAA79986786A6B6B6F88ACD8DBE1E4D6
4D4D515656514E4E4F4C4A4B4E504E4C4B4A4A4A4846484C4E5F535D58434D494E4E4743
4647484E474B4E4E4B484748474747464444454640454A4B4946464644554B4B4E494D44
464652537661745E564C484C4C494E595658556F71716866586562735B57637D5B767071
625E58434A4641453D4A4F515251484848454740424443444644464F42435353637B7E8C
868B8C8568504D4645567EA4C5DAD3D1D6C4C08A7D7E8178767891BABAC1BCBEA2A5ADC0
BFAA8CA07342453E48413C3D3D433E3A413D4344434B473D3C3E3E3E3A413E38393A3B40
403C3B3D3D3B3E433A3C3C39393B3C3A3A3D3D3B3C4142413A3F4545413D3C3C3D383C38
393F3C4139373A3E3C3E403C3E393F3C3B3C373F3F3C3F3835393C443E3F3F3F3D3B3938
443B3B3F3D3D403F3B3F3E3E423E37373D45423B3B3A393C3A4447423E41413D413A3A3B
393D413E3F413C3A3F3F3D423B363941413B383B373A3E3E3C3B3B3C363F3E3A3C3C393A
3C38393F403D3E433C3C4045443F3A39353C4549484441403F3935373A3C4045383A3B3B
3938393A3D3D3C3C3D3D3E3E3C433D413F41383C3D3C3B3C3D3E3D3C3E403B3C3A373A38
384045433D3A393839393838393B3D3E3737393D40424140363D3B373A3C38373A3C4339
404A3A3C37383B3E3C38383C38393A3D3F3F3E3C3C3B393A3A3A3A393A3934353C3A3840
3633383C393A41453E3C3C3C3B3737393C3F36353739413C37393A3B3B3B3C3E3C3E3B3B
41403B3B38384833343C3D41444C3C496A84A2AD947052343C353F3C3735363B3D3C3A3B
3C3E3F3C3937383B35363738383939393E37353A3C38383C37353737383E403B3F3A3739
3C3E4044393A3C3F41413E3C3E3D3B3B3D3E3F3E3D403940403F353B443F434346494344
42494B64685A5741423F3F403E3B3D423D3B3D41423F3B3B3F4142413F3C3A3A3537403A
393D36373D3B3B393E3E353B3B3C3A373B4348473C3D3E3D3D3D3F413E3C3C3E3E3B3B3D
3E3C3E423B4037433A363D3538423C393B3F3D3F3A3F54566F7A93888D87817B60685056
454849484C525B6D799F9CB3BCCDCEDBCEDAD9CDCBD0D1D2D5D2D1D9D8DDD7D8D7D6D8D2
DBDEE4E4E4DDD9D5D5D8D4E2D5DED6E0DEE5E6EBE4EAEBF2ECEAEBE3E2E6E1DFE1E8E5E1
E1E1DDDEE0DCE5DEDECDD0B6A89D928E9098A0A299B29AB5A3C8B3C9C5C7C2B8B4A8B7B9
C3D3CFD2D1CBC6BEBDB7A89DA78F998F909398A9A5A39EA39EAA9AA49BBCC0DBDADFE2E9
E4E6E5DED9D6CCBBB1A28C737871A5A2CECCE4D4
5051555C5D5B595A4F4D4B4C4F504E4C4C4A4A4B4947484C4951444D50454D4A474B4A4A
4F4F4E514A4D504F4D4A49494748484848484A4C45484A4A4847484B50625D61645D5E52
4B53555559444C404245494C4F57646E645E5A5D62524F45414C485B4B4A50605B757C92
97917C594C4944483E464747404542484A45454447463F434946464844464C4449524954
46555F747D78725C4A556B7D8DA7B6C9CAC5D3BEBDBDB1A08D8CA6BFC3BCB7AEAEA5C3D4
A690909FB98467513B3F3E483C45383F3B4241463C3C3C3B3C41413D3C3D3935393F4243
3F3D3C3D3E3D3E3F3F403E3A3A3C3D3C383B3B39393D3E3C3E4042413F3C3C3D3C383C39
393E3B3F37383D3E38383D3C3C383C3B3A3B384038383E3B393C3A3E414142424241403F
423C3C3D3A3A3D3B3B3D3B3A3F3D383A3D44433D3D3C3A3D393E3C3C43423B3A3F3A3B3C
393B3E3A3D3F3C3A3E3C3A3D3A38383D403A373B3A3C3F3F3C3A3B3C3F443F3838383739
3E3A3A3F3F3B3C413E3E4043413C393A3A3C3F434443403D3E3936383A3B3E433C3C3B3A
39393A3B3B3B3B3B3C3D3F3F353D3A403E413A3F3C3A39393A3A39373A3D393B3B383C39
3B4145413C3B3B3C3C3B3A39393B3C3D363636373A3E40423B3F3C383A3A38393A3B4238
3E473A3C3535393D3D3B3C3F3838393C3E3E3D3B36393C3A363436393838393D413E3A3C
3C373A3C38393E413D3A393A3A37373A3B3F383839393E38383A3C3C3B3B3C3D343A3834
3B403D3A3D383E3A3C453E4A5555645C7AA299A696776044493B3E373F3B3A3D3F3E3D3D
37393A3A39383A3B393A3A3B3B3C3D3F3D37373C3D39373A373537393A40423C3B38383B
3D3C3C3D3C3C3D3F41403E3C393B3D3D3D3E414448463D413E413C43403F4545494F4A4A
504F4A524D444A413B3B3F43423F3F413A393D4345423E3D393D4446423F3C393A3A403A
393E393A393C40393A3B373E3E3E3C3A3B3F403E3A3B3C3B3A393A3B3735363A3B39393B
3B3342364036393C3E3D3B3A383A3D463E464D5E6E849691A3969565624E4E423D463A42
3C5059638994A1B8C2D7C9D2C6C2CFC5D0B7B8A49D9B9DA7A8A1B1D2D3DCDEE3E7E8EEEA
DAE1E3EDE7E9E0DFDCDFD6DBCDD3CFDCDED7E0D2E8DCE3D4DEDDE0DCDCE0D9D7CADBD1E2
D3E3D2D8CBCDC8D1BCBEB9AEA7A49F9C9D9C9B9BA69EBCA8D6BCD4CBD3D4D3C8BEA9ABA2
B0CCCBE3D7DFD8DED2D9C2D1C8C7C2C3C0BAB6BDBDBDBBBFC4BCCFB8CEC3DFDBE7E0EDE2
E4E5E5E1DCDFD8DAD1D1BCAE8B9089AD9DCCCBD6
5051535656524F4E49484647494A48464644444644424346484B414549434544464A4A4A
4D4A454747494A4A49464443414344444546484A4B4B4A4846474B4E575E514E4F505955
3C48454D47424A494B52534D4D565E5E5D6056635E5F554F44473E4B444C4F587C796667
6F72705C5656565E59605F604D514A4C4D4343484D4E42464942444340474A4855625A6A
57666166717C8A84645A4F4F51697688A9AEC6CBCFD0BEB2ADAAA2B5ABC3CBD4C2B1C0B6
6D5A65679389837950543F343C3D353A3F3B3B3A3E393A3B3A3E3F3943413F3D3E413E38
3E3E3E3D3F403E3B40403D38373A3B3A383A3B3A3A3C3B3A42413F3D3C3B3C3D3B393C3A
3A3C393C3B393C3D38393C3B3C383B3A3939383E3A373936373C3C414040403F3F3F3F3F
3C3B3C3B383A3E3B3B3B38373B3C3A3C3C4243403F3E3C3D3A403F444E473A3C3D3B3D3D
39393A383B3E3C3B3C3A37393F3F3C3E443F3B403D3F41403D3A3B3C3E43413D3C393535
3E3A3A3E3F3C3D41403F3F3F3C38383B3F3D3B3C3F403D3A3C3A393A3A3A3C40413E3B38
383A3B3C3A393A3A3B3D3E3F393F3B3E393C373D3C3A3938383836353639363A3B3A3E3C
3A4144423E3D3C3B3D3D3B3A3A3A3B3C3F3E3C393838383941413B383A37363B393A4038
3B43393B39393B3D3D3A3A3C3838393B3D3D3C3A3D40423F3936363739373B40403E3C38
3E383A3C39393D3E3B3837393938383B3B3D393A3B3A3B363637383837363738393D3B37
3B3D3D404A504D5A5060475559716266829AACA0967D6A51524648423F3A373B3E3E3D3D
3B3C3D3D3B3A39383C3C3C3B3A3C3F423F3A373A3B38383C3836383A3B41433C3D3D3F45
46423E3D3F3E3E3F403F3E3C3C4042403C3A3D40403F3C443E423E3E494A4E4A4D565352
54473D3E3E40413B42424343403A373739383C4244403C3B3B3B42443D3D413E3C3A3C38
383D3B3B3C3C3C353A413B3B3E3E3D3B3C3D3B373C3D3D3C393838383C3A3B3F3F3C3C3E
443E3E3D383C3B4136413744454764839AA0A7B9BFBDB19F695D5842433F403B3A434453
6290A6B5D4D5CDD0CAC6AFAC958F7B8B7B87737E728796999CAAC4DEDEE3E3E0E2DCE0D8
E3DEE4DBE4DBE2DEDCE1D5D3C8C8C5D2CCD2B9CAB5D6CDDADAD7D9D3D1D3CBCAD1D1D8C5
D3C4CBC7CCBECDBECEB3C4AFC2C8C4C0C1BDBABFB4B6AACEBED9CAD3D6D6DFE0E0D6DCD1
D3D5DAD6E2D1D2CDD3C8C9ADC8A7C4BCC2BCBEC7D6D7D8D8CFEACFE4D0E8CEE3E0E9D9E7
DAE0E5DDE0D9DCD1DACBC9BEC1AEB5B1C9BFC9B2
50515456565452524E4C4C4C4E4E4C4B4B49494B4A47484A424848484A47454A5254504D
4D4A46484B4C4D4D4D4C4A4949494A4A4A4A4C4E4C4A484543454A4E53554A4646464C47
47484145484952514E514E4A4C53524A52515E576D585E4C48494046424D4E525558575B
686B767065686A797A84868B6C69585558545B665F696568634E4843464E484650564653
57656053535D73867A6F59504146454E606A8299A3B5B6C2C7C2C7BBC0BDD3CFCFD0CBBC
988B786A524F5661566358453D38505877575D51514D443E4045433B413F3E3E40454640
3E403F3E40433F383E3F3D39383B3B3A3B3C3E3E3F3F3E3D43403C3B3B3B3C3B3B3A3C3B
3B3B3939413A393B3B3F3F393C3B3D3E3C39373B3C373835383F3E42403F3D3B3B3B3C3C
3C3F403B383B3D3A3C3B38383A3B3B3C3A3E4141403E3C3C383F404143403D403D3D3D3C
39383A3B3C3E3D3C3C3A3A3B40423C3C44423D413E4143433F3B3A3A3B3E3F3E3E3C3938
3A38383C3E3E40443E3D3D3D3A37383C403E3B3A3B3C3B3A3B3C3C3C3B3A3C3E433F3B39
3A3B3C3B38393A3B3C3C3C3C40443F40373B393E3D3C3A3A3A393836353835383A393F3E
3D40413D3B3C3E3D3C3C3B3A3A3A3B3B3B3C3E3E3D3C3B3A403E39393B36343B39393E37
383E393B3A3A3B3B3A3938383939393B3D3D3C3B383939373737342F3C36383B383A3C38
3A35383D3B3A3C3B3B38383B3B39383A3A3B3A3B3C3B3B383E3E3D3B3A3A3C3E3A393738
393741557E7D8B5960424E536E807E717B877E7568594D3C3E373A363A36353B3F3F3E3E
3A3A3A3A393735333A3A3A3837393D41433C38373736393E3B383939393E403A393A3F45
46413C3B3F3E3D3D3E3E3D3C404242403B38393B403C3A413A434443595E66605E60544B
403A41403C3E3B39403F3E3D3B3939393B393B3F403C38373B393F41393A413F3A383736
383A39393D3B393239453E383C3C3C3C3D3D3B3940403F3D3B3A3B3C39383A3D3E3C3B3D
393B39453941383841474869A5A4C4C7DBD0C5C5A8805846403A39413F4545475F7D96AD
B1C7CECDC8B6937C6D625859514C474B4C50485A618AAAAFB7CEDDDEDEE7D9E5D8DED1CB
CBCEC4CDBFC7BBBECEDAD7DEE3E3E4EADCBBBDA4CFBDD1C2C7C5C9C9CDD4D2D5D3DFC4D6
B7CEBACABDBDABCEBDCCB7AFACBABDBFCBCED1DFDECDDCC9E0C9D9CED7CFD4D2D4D2DBD3
D2DECFEAD8E7D4E1CAD1A8B58F9A89987F7D848EA7ACB4B8CDC8DACAD0BFD5C7DBCEE4D2
DDE0E0DFE1DBCAD0C1C8BFC5C2CAB5DEC6DECCCA
4D4E4F4E4E4D4B49484848484948474547444446464443454C50504A49474146484A4643
4544424544444546474645454647464543424344494745424244484B474946464543433B
574E4C414D424B42434445484D4F4D4949514E5B58574C424247474A44494445565E6964
6452564F45474551515959615C57484D5C687B889F9E8C7E6C534947454E454951533F4A
46484840414343504C4942484446454940444B5C5E6A6E817E9295A69BA9AFAFA3A9A6BC
CED2BDB78A583D3F504B4936463A4F5B79678895828B7E6C6D6E67644B47403939404544
3E40403E41433F383D3F3F3D3C3E3E3B3C3C3E4041414141413E3C3B3C3C3B393A3C3B3C
3C3A39373F3837393A3E3F39393B3D41403B3B3C3A373C3D40433D3E3F3E3C3B3B3C3D3E
4146443E3B3B3A383E3B3B3B3B3C3C3A3B3B3E403E3C3C3B3E3D3D3937424B483E3F3D3B
3A3A3C3F3F3F3F3E3C3D3F413A3C38363D3F3B3C3D414444413C3A39413D3A39393C4042
3A38383B3D3D40433B3A3B3C3B38393C3D3E3E3D3A393A3B3B3D3F3E3C3C3D3E413E3C3B
3C3C3B3938393B3D3D3B3937363A3A3E353836393D3C3A3A3B3B3938393A35383939403F
41413C36363B40423A3A39393A3A3B3B3A3B3D3E3E3D3B3A3B3A38393C37343A3A393C38
373B39393436383838393A3B3C3B3B3C3E3E3D3C393C3D3C3E41403B3E38383935393D38
3733383E3C3A3A383D3A3A3D3E3B38383A3838393B3C3B3C413F3C3937393D403A393636
3A435C7B968C78565056677B829189776D6051494541413A3F3A3A343C393A404443403F
38393A3C3C3C3A393939383736383C3F403C39383736393D3A373837353C403C38393E44
45413E3E3D3B3A3A3C3D3D3C3E3D3C3C3C3B3B3B413D3C47485D6A6F807D7763554F3F35
3B384644404138353B3B3A39393A3B3A3F3B3B3D3E3B393A36373F423C3A3B3839383639
3A3A3A383A3B3E36363F3E3C3D3B3A3B3D3D3C3C41403F3C3B3B3E403534363B3D3C3D3F
413B454049414A3E5F8E8ECBCCD1C5C99D856963524B4451685C76658A81A79FBCC7C4CB
BDAD90665C564B44463E3C3F3F44454B567589ABB0C2D4DBDDE3E4E0DED1D1B4C3A4A990
8B868F899D9FB2B5C3CED1DAE6DEDBD3C3C5AECBA7B5A2B89C9EACB7C6D4D7DEDCD7DCC0
C8ABAFAAB4A5B1ABC7ABB39CA2B3BAC1CED0D2E0D9E6DEEBDFECDFE2E1D6D8D0D2D1D6D1
CAC5D1CCDECAC3BCCDC1C8A9C4A9C9CBCECCC8BBB9A2959094B5A2B0A8B2A7BAB7BEA7B4
A3A9ACA2ACA1A9A6BBB9CBCFD3CBD4CADDCCE1D5
535453504D4C49464D4E4E4F4E4D4B4A4C49494C4D4A494A494A4743494C4A4C464A4948
4C4A464848494A4B4A4A4A4A4C4C4B4946454546464544424345484A4E4A4849484B4D48
47424C3F4B3C453F4143484B4944444846444B4857484F4442464A48414340454648554B
585264644F4D43474344414B4747455264768B9192826B5C5C616977677D828F8675514F
4B434040494D484B46413D42453F424149484552504E4750647B9AA4B9ACBAA89A8D8FB8
C0B9AFACA0795F63877E816D5B50414D3F425C7C82ACC2C1BFAD98988B877563594D3F39
40403F3F4142403C393C3D3B3B3D3C393B3A3B3E403F40423D3C3C3D3E3D3B393A3D3A3D
3C393B383736393A36373C3B35393A42423D40403E3A3F3E40433E3F3B3A3939393A3C3D
3D41403D3E3E3D3E3E3B3B3D3B3C3C393D3A3C3E3C3B3C3C3D393B3C3D4C53443F403C39
3B3B3C40403F41403C3D42433B3B3A393D43423C3B3F4344403C3A3A413B3A3C3B3D4040
3E3C3B3A3B3B3D3F3B38393B3C3A3A3C3A3D3F3E3A38393B3B3E3E3D3C3E3E3D3D3D3C3C
3C3B3A38383A3C3D3D3A37353B40434B41423C3B3C3B3A3A3A3A39383B3D37393A39403E
3C3D3D3C3D3F3F3C39393A3A3A3B3B3B3F3C393838383837363837393C3935393B393A39
373A3A3835393B38363639393D3C3C3C3E3F3E3D363D403B373839383D3C3C3C3B3D3C37
37353B403D3A39373E3B3A3E3F3C39383B3638383B3D3B3F3D3A37333133383C393D3936
41597790998277667271879288837C5A4A432F3C383839373A3A3A373B3A3C41413E3A3A
3A3B3C3C3B3A39393A3939393A3C3D3D393A3B3C3A38373836363837343B413F3B3C4044
454242443B3A39393B3C3C3B3F3C3A3A3B3D3D3C39434E626A7C7D7D716557423B403D3C
413A423F3E443E3A37393A3A3B3D3B38403C3B3E3F3E3E40383A3C3C3C3A3939393A383E
3F3B3D3B3C393D38373F3D3A3F3C3A3B3C3B3B3C3D3D3B3A393A3D3F3B39393B3C3A3A3C
3C34353F526F9095B4BBC8B3C5908F7563625F717C979BAC97ADA3C7B1DFD9D9C9C6A78B
6450523E3F3B3F39433D465252648B92B1B6CBD1E2E6E8E2DCDBD2C2B0AE8188677C6B6D
7D8990AAAFC7CCD7D6D6CFC6C3ABA5909773715D82779BA5B9BBCAD5E0E6E2E6DEECDAEE
D2E1CBDAD1DAC9E7D3E5D5D8D6DFE0DFE3E2E1EADFE8EBE3E4E1DFDBE4DFE4DDE3E0DFDE
DDDFCDE0D1DCB8B7ABB395A98FACA6C2C2CDD3D2D3C2B3B0A19EB69FB291B09AA7959F87
8B8B8A867D8387A4AEC4C8D3BBC5AECCBBE2DAE3
474A4A47474A4A4848494A4B4A4846454845454849464444494D47434647464642464545
47454143454748474443434544454543414142434846454446484B4D433F424646484741
3E4047444440424440424648443F424744453A4A44464142424045413C3E3F4944485E55
6A626B62524F44494749485551575C615E626B61655851495261667889A7B3BE9C794F49
45433B3E404248403F3C3D3E463A4A4D4244444E504942495B72809FB4BEC6BBB5A39BAF
A5ACB3A8A8B2A5ABC3C6CABD98967E8A66665D6356799BB2BBA78E89878C80787C6B4D40
413F3E3F404040423C3F3F3D3C3E3D3A3D3A3B3E3F3D3F423B3B3C3E3F3E3C3A3A3E3A3D
3D393D3938383D3E37373B3B373A3940403B4040423E403C3D403D403E3D3B3938383939
393B393A403E3C403C38393B393C3E3A423B3B3E3A3A3D3D3533373C3F4544373F403C39
3C3B393C3F3D41403A3B4040403D3F40404A4C403A3D40403E3C3C3D3C383C42413F3F3C
3F3E3B3A393B3C3D3E39373A3C3B3A3A393A3B3B3A3A3A3A3A3C3C3A3B3E3E3B3A3B3C3C
3B3A3939393A3B3C3B3A393835363840363A3633403E3C3C3C3B3A383B3E3A3D3D3B403E
383C404144443F393C3C3C3C3C3B3B3B3B3734363A3D3D3B353A39383B3B37383D39393B
393A3B36383D3F3A353537393D3C3B3C3D3E3D3C404748403A3C3C3A3A3E3D3B3D3E3936
38363C423D3B3D3D3E39383B3D3C3A3A3C3539393B3D393E3E3D3B3837383C3F363E3F45
5B758893969291947D75787E516347454232403B3D3C3A36383B3D3B39393B3E3C383637
383A3A38353333343938383B3E3E3D3A37393A3A3938383836383D3B35393E3D38393B3F
3E3C3C3F3D3B3B3B3C3C3B393D3C3B3A3B3D4143404F5766676A5A544A413D37383D3736
3B3C433E373D4244353738383C41413E3F3B3A3D3E3D3C3D3B3E39363C3C393E393B3940
403A3E3D40373B393A403C373D39383A3B3A393A3A3A3B3A39393A3B3B38373838363739
41536595A2C2CAC2A5AD94936A746A7E919EA4B3B3C3BBCAC5BED7C5D8B8C4A08E704D42
424E5745423C4C465E6E91B4AEBBBED5D1E1DEDCD6D3CDC0B1ADA699938989728D88ABA9
BBBDC7C2C6BDC2C1B0A5957D70586450617482AEB1CBCBDCE0DDE4E6E7E3D9D9D6DAE5E2
EBDEE2E6E2E3E6E0E8DEE6DFE6E7E6E4E4E3E3E6DEE0D9E0CED4C7C4BFC2CBC6D7DADDE7
DFE1E8DCDED8D1D3D6CFCEB6B59B9B9C9DA9A8AAADA89DA18EAC97BAB9D1C8D2CBCFC4CF
CAD3D7CFD0CED5D2D9CBC5BBBFBAC0A7B9BED6D7
5052524E4D4F4F4C494B4C4C4B494746494646494A4845453F4D4C4A4742454644474544
4848464A494B4C494543434543444444434345474A484646484B4F514A44494D4C4E4B44
484B454B3F49434A434241403F40414249463F4B49434142413F48474545434D4E4A563F
504650454E4E475359626677878E938B6F615D473E3B494A586A6D8594A7A39F76676173
5C645457525366546B5B524E5D4B5248494E4D4F4D434451444847526E6E7D6C8A948E94
99BBC4A7A8CFC7D9DBD9CBC0B3A991958FA0A1989D816A748D938B898C92868390805A4A
423E3D40403E4045484A484544454543403D3D3F3F3E3F423A3B3D3E3E3E3D3C3B3E393D
3D393E3A403D3F403D3D3E393C3E393E3D363D3C3E3D43414041393A484744403D3A3938
3D3C38393E3833383A353739373B3F3B453C3C3E393A3F3F3F3C3B3C3C3B3B3C3F403B39
3D3A36373D3C404039383C3B3F3A3F413F4B4F3F3A3C3E3D3B3B3D403D36394040404240
3D3C3A39393C3E3F413B36383B3B39393A3736373A3C3A38393A39383A3E3D39383A3B3B
3938393A3A3A3A3A3A3A3B3B3836343C353F4242454341403F3E3C3A3A3E3B40403D403D
40403E3C3F4444413F3F3F3E3D3C3B3A3F3C393B3F3F3A35363D3C383B3C39383E39383C
3A3B3C35343C403B36373C3E3D3B3A3A3C3C3C3B3E41403B3C42413B393F3A353A3B3636
37363C413E3E43463E3835373B3B3C3D3C353A3A3C3D373C3C3C3B3938393B3D3D444F67
889CA1A3B39EA6837B565F463C3F42343A41343B393C3C3A3B3D3A34393A3C3F3D393A3D
3F4142413E3E40433736363A3E3E3B36393A383634363A3D393D434037363A383C3C3E41
403D3D403F3E3D3C3D3C3A3835383A3B3C404950464E444341443A3B3E373A3C42443936
3C3C403D393D3F3B44423D37383C3D3B3D3A393B3B383636373F39394440373C373A373E
3D363D3D3D37403E383A393B3935363A3C3A393B393B3D3D3B3A39393B38383C3F414449
969EB3BFC0AB9F7A6B54554C62748996A6AFB1B6A2A7A0BCAEA191A185745D4B53423E41
4552574A58689DAAC4C2CCE2E0CBC9B6C5AEBBA2A8867579747694B6BFCBC5CDC5D1D8DE
DCE0DDD3BAA4918A6C65655F6B75A8A5BDBFC8CBDADADDD6DDD7DADBDBDAD3D6C8D6D7E4
D5CEBABEAEBAB4C7C9DBDAD8D4D5D9DBD8D4CEC9D7C2D5C4CBA8AB928B8E948BA0A8B0C4
CCD8DDE1DAE6D6DDD4DBD3DCCFD5C9D6C8D2C9C9C5BEAAABA1A2A6A4C7BDD4C3D1CED7D7
DADBD8CEC6C7C4C4BBB09D908B987B967DBDA8B9
5050504E4C4A4B4C44494D4C4A4A4845474A494545464643464848474544454642444646
4544444542454849494949494142434547484949464545474644474B44474A4A48464545
4243454747464443414141403F404345454546484643444741424846484F4E504443474E
5459616960535A66646E6D8A97ADA59489745E4E544E6662776F6B76677C707E685B5C6A
595E565657585E57685A505657594C544542484B454C524A5948725A73594F494C66747A
778990949697A5C5D2D3CDD2BDAD889695ACC9D3CEB6A98D7B725D63758DBCA3B696A87A
7450364A537E8F989FA9969E7E957C8B698344554B3C3E413A4734373E433D3B3C3D435E
583D3D383B3C3C3B393A3B3D3A3E3F3935383B3C3E3C3D403E3B3B3E393C3F3F3D3B3A3A
343B3B3E3B3538363738393B3B3B3A3A3A3F3A3C363E3B3B3E393B3C3A3C403F4044403C
40403C3B3C433F3B37373E3B3C3D3E3E3D3E41444146443C3A3A3A3A3C3C3C3B3938393B
383A424137363B3C3A3B3C3A37383C40373835383E3C393E39383737393A3A3A393D3F3C
3A393836393938393F433F38353E3E40424D584A40423F3E3D36343D3A3C3D3D3D3D3D3B
38393B404344403C39454C453A36393C3E40393D3E3A3E39363A3D3B3A3C3F40373D3E3A
37393A3A3836333132373C3F36383A3A393838393E41403C3A3D3F3E3833393B353B3F34
373A37373E3C38393A3943433F3A323A37383C3B36393C383A413E3A3C3638496774848D
8D8B8E9098836956463A393F363939373A3E3D38363A3C3D3B3A3C3E37393D3F3F3D3B3A
363B3E3C3836383C363A38383C3B383B34383C3B37363A3E3E3C48453A3A38383C3C3D3C
3C3C3C3C434A403B3C3B3E3C404033353A353B433D48423E3B33373E3A3B3936373B3C39
3A423C3842433C3E343C3B393B3A383B373E3E3D3E3A3538393D3E3A393B3C3B35373F46
463F3C3E3D3C3C3C3C3A383537383A3A3A383635363B2C3D363B3B403A3C393E415365A6
B1B19569574B4D473C564663618F89A67E86706666636C6666614D49473B3C3B413B3D4A
4D6072928CAFC6DAC8CEB6BFA29F7A7F5E5F51564E5E616A8891ABBBC8CBDAC4D0C8D1C1
C6BBB7A7A0999D9498ADB6C8C0D3D4DED5E1D8E6D9EAD2DDD9DCE1E0E1E1D8D0DAD6DDD7
CCB9AE9DA49FB9ADC7BAE0CED5DAE1E6DDE0D9DFD4DDD9DFD3CFD0D3BEB4A0918E8C909B
A4C3D8D7D3D1CDCBCDC8C3B5BFC8D7D7DAD6D7DADCDBD9DBD0D3CED2CFD9C7D1BFB0ACA7
A9C4BAB7A19B8D8392728368815B6863596F7D72
4C4D4D4C4B4A4A4A4B4F51504F4F4D4A494B4B48484A4A474A4A4A494847474840424344
4342424341434546454444444343434446494C4D4443464A4B4A4B4E4446494947454545
444444444546464745464645424040404040434749494B4F484A525051554F4E494A4F57
5C60656B5B50555B565D5B73718C8F8983736760665F6F5F6658535E4A56475747424651
5A5D544D46424C4C45494646444B424F403D42423C4249424E4A56737E8E5D493E474851
5464656554555772778685918C80637B7C9EB7C7C8C2CAC5BDB19996785A7C64736F9EBA
92724C4C5E90B7C2C5DDD0B3B19377857F797B68867166473F45404A4C4240433C3E3E4A
483C4040393939393A3D4145383C3F3F3E3F3E3D3A39393A3A38393D393B3D3E3D3B3938
383E3C3E3C383D3C393939393A3A3B3B3E3F383A39454240413E403F3B3D413E4345403A
3D3F3C3D3C3F3C3E3B373D3E3C3C3B39393A3E423C3C3E3E3F434645393B3C3A3A3B3D3D
3E3C3F3F3B3B3E3B3B3D3D3B39383B3E3C3A36373D3B383C3737383A3C3D3D3D363B3D3C
3B3D3D3B383A3938393D3D3A363C3A3A3A40483B3F403C3D403A363A3939353842403938
3D3B393A3D4142433D3F41414242403D343734393C3A3D393A404039383E413F383C3D3A
38393A393B3B393737373A3C3B3C3C3B3B3A3B3B393C3D3A3B3E3F3E3935393B373D4239
363B3B3A3D3D3C4137393C33343D3B3B363B413D383B3D373A3F3A39454F5D7382757477
767B7D736152433C38363A423636373B3E3E3C3B3637393B3D3E3D3C3C3B3A3939393B3C
383B3E40403E3D3C363A39383C3C3C403838383839393A3A383743423A3B393A3C3F4141
3D3A3A3B39413B3B3E3A3C3B353839383D4244493C3E3B42443D42473A3D3E3E3F41403D
353C393A44453C393C43403A3B3B393A3B3F3E3D3F3C383B3A3E3F3C3B3C3B393A393A3F
42413F3E393A3D3F403F3D3C3738393A393837362B3C3D323B373E3A3A3D4E4B7F94828B
5E514A42414C3C48586A877A91666A59414C413E4140443F3A3D3D3C3E3B3B4239383E4D
5772859F8C96B49A9D75685A5453464A4752575D61707175807B7F847F8B8492808D788E
7781929AB2C0D0D3D4DDDBE1DBE5E3E6E9E3EBDFEAE1E0E1DAD7D1C6BDBAB8B8AFADAAAA
A1A19F9D93A29DB1AFC7D3DEDFE0E3E7E1E8DFE4DBE1DDE1DEDDE0DEDFD9D2CBBC9F8D90
AEC3CFCDCFD2D0CEB9ABA2959B9BAAB1B3B2BDCED9DBD9DCC8BCC1B3C7C9D3D7D8D2CDB7
9CA2989B9D9B948D9C7F8E77967A897E827A745C
4E4E4F5050504F4E494B4C4A4A4C4B4748494A48494B4B494A4948484848474644464747
47464647454748484745454545454444464A4E51524E4B4B484341424446474746444444
44444445454647474A4B4D4D4A4644434342454C5154575A46474D49494C46444A4B4C4E
4C4846474F494D4B454B49595D6F7073756C676474696D595C4E434245493E5146464645
53544E4B4541484C516160595660566051535D605857564C564F4A4E576652454C484047
485049474847464D4C4D4D51554E48575D7286987F777F9DBECCBFADB5848C6B464D4365
4D4B453E4042606F8CC5B6CABBBD96B490A88E9D70856450483B3D4647373C3D43474440
3E3D3D3A3E3E3E3D3B3A3B3D3E3C3B3D3D393634403E3C3B3937393D393A3B3C3C3B3937
393D3A3C3A383F3F3B3B3A39393A3B3C46453D3C3E48443C383A3F3E3B4147444346403B
3E3F3C3C3839383F3D353A3D40403F3E3E3F4143443C3E413B3B3D373D40403B393B3C3A
423B393B3D3F3D373B3D3E3D3A393A3C3E3A36383D3B393B3E3E3F3E3C3A38373A3E3F3D
3C3C3C393B3D3D3937393C3D3C3D3B3B3A3B3F373E3C3A3C413E38383A3E3B3D453D353E
3B3B3A3C3E404142413C3A404647423E3D3D383A3B393C393F4542373640433D393B3B39
38393938393B3C3B393736373F3D3B3A3A3B3B3B383A39393A3D3D3C403B3D3C373C4038
3A40403D3A3739403A393C39393F3C3937373836363E413A3C413C3A47525C6863534E53
585F5C4D4A3F363537373A3F3A37383F403B393B373433363C4142413E3B38363637393A
3B3A3A3B3D3C39363C3F3D393B3A3A403C3936373B3C3A373C3B45433D3C38383E414240
3B393A3D3D433E403F3737383B3C463F3B433F3E44413E454642443E363A3D3E3F41403E
403D37353A3D3A3739413F37393E3F3D3C3D3B3A3D3D3A3C3C3E3F3F3E3E3B373C3D3D3C
3D3E3D3B3A3C3F40403D3A3938383838393939393E443341333E3A43447A837D805D5146
423B3840445D688881956C8A525A3D4139413F3B3C3C3A353A3C423A3B3F3A4346484C54
5464626B5F5A56484B4943454E55506051615052474F454545424248464342424D525687
B6C6D2CFDEDEDFDDE8E5DFDCDCDDD9D4CDC7B2C1A0B199A4938F867A6E666A707D75836C
88779090A7B5BDCCD6DDE1DFE5E4E3E5E1E9DFE0E4E4DBD5D6D4D8CFCBC9C7C6BCA9A1A8
B7BFBBB4B8C0C1C1BBACA6A0A1959DA79A969BADBDC2C7CCBDB3ADAAA9BBC5D0DDD7DAD8
CAC49B827977747A9896B1A8B7BEC6C8BBB7AFB1
4747484A4C4D4B484C4C4B484A4C4C48424344444546474745444242434342403F414242
4141414340414342414040404645454445484C4F514B4544444242444545454544444444
42434546464544423F41444543413F3F4844434648474748474546404047444546464646
43403F3F434246413D42424B414843474F4D5154646477757D6F58474A4740504645433B
41424751544E49464D5A544E515B4A504D505A5E5C6064605D5E56544F5552514F4B3F3F
3A44454A68676A5E5948443D3E3A4745494954625951506B8A9CA0917C566B4F4A5C4847
42434C46544345454262626F676C6D7B70828884898B958F9575695C5B4C51444746463E
383D3E393A3D424443403D3C473F393B3C3B3A3C39393939393A3C3F3B3A3A3B3D3C3937
3539363838363D3C3B3B3A3A3A3A3B3B40413D3A3C413C333A3D423F393D413D4145413E
40403A39373A393F3E373B3B3A3B3D3E3E3D3C3B413940463C383B363E42413C393C3C3A
3E3937383C3D3933393B3C3C3A39393A3B37363A3F3E3C3C3B3C3D3D3C3C3C3D3D40403D
3C3D3C394040403D3B3C3D3F3E3D3C3E3E3D3E3B3B3B3A3C3F3E3B3A3537383D3F383742
3A3A3B3D3F404040403D3D4244403E3F3D3B37373A3E434440434038383F413D3A3A3939
39393938383B3E3E3C3939393E3B3837383A3B3B3D3B3938393B3B3A4541413E383B3B34
3A3E3F3D3936373A36373D3D3B3D3B363832353E4448473F41453E393E42404043434143
49453C373D36323539393A3C3E3C3C3E3D3936373D3B3A3A3B3B39373B3A3A3A3A393635
3C393635363839393C403E3A3A38393F3F3B38383B3D3B393D3D44413D3C3536403F3E3B
39393C3F383D3A40423A3C413F3E4641393C3C393F3F3A3838434D4151504E4945424140
3D3B3A3938393834333C3B34353E3F39393937383B3B3A393D3D3E3F403F3C383A424641
3A3939393A3B3D3D3A3735343838383838393A3B3D3C42382F3E64718C9E666A50393E3F
4240455084778B6C7D6C544A3F35423E3A3E3F3A3A3D3B3B393B403A424B43474543444A
474E4243454B555A62665D605E505A4B4E413F393C413638373D3C454646464B636F84B4
C2CED6CACBC2BDB4AFA8A49C9E958F85886D735C5C444741414241484C51626E71817991
91B0B3CAD5D3D5DFDDE3E0D7DFDEDDDDD6DED3D4CCD1D0CAD0CBCCBCB5BEC8D1D7D9DADC
D6D4C6B8B9BDBDBEBEB4B6B6BAAEB5BEC3C1BEC6CDCDCCC6A89CA896A099B2B2BCB1AAA3
928D6C574E4F5666868B9A9094A3BFB5C4AFC1C4
4D4D4D505252504E4C4C4A47484C4B494848494A4B4B4C4D4A4947474848474545474747
464647494547484847474748444646464545474A48434244464647494544444444444343
434444434342414143454647464546464B474547484746474541413C3E47464746474645
4446494C4041453E3E424346454A444342404B54454D63686B5E4D3F59534C5247484A46
453F3E4143444449414540424850414750545B5E5F656967665364507D6683767C786250
3F46494E5D71768B7B826E6E5856505949564A5E4C4D4B565755584A51404B494557565F
838F9B82846D5C4E465A57654F4C413C4148455E648F6B90A5969A88918A896F52484640
373D443F4349535B616466675A4F45413F3B3A3B3B3D3E3D3C3C3D3D3C3B3B3C3D3D3B39
3438353939363B393A3B3B3C3C3C3B3B3C3E3E3C3E40403D3D3F44423B3D403C4144403C
3F3F3B3A39403F403F3D3F3A3B3B3B3B3C3C3B3B3B38454E423D423F383C3D3B3B3F4140
3B3B3A3A3B3A363436383A3A3A3939393B37383D3F3E3C3A3B3A3A393A3B3D3F393C3D3C
3D40403E413F3E3F403F3D3C3A38393B3D3C3A3B393B3D3C3B3C3E3F43383B4648494E50
3F3D3A393B3E40413D3D3F423F3A3B3F3A373636393E3F413E3C3B3B3B3C3D3E3A393939
393838383C3E3F3F3E3C3C3D3B393737393B3C3C403C3837383A3B3C3A3A3C3C3B3F3F39
36373B3E3D3C3C3C343E433B343E463E3C394658584E443E42433B34383E3E3D3B43433F
3E373338383534373B3B3A3A3D3F3E3A3839383632373D3F3F3C3A3A3A3A3C3E3E3C3733
3939393737393D40343939383B3A3C423E3D3C3B3B3B3D3E38383E3C3C3D3739413E3A39
3A3A3A383E44434B4F47484B423E3E4138343C3B3A3C3B3F47607B796F675A4D423A3737
3636383A393A3D3E353C3D35353C3B323837383A3B3C3B383C3B3B3E403F3D3C39424640
3A393B3B39393939383737363938383738393A3B373C412F477C977B70593A4336453335
476C628266695C504B3E3C3F3C3A3D383F40423E3B3D3D3D3D42433F444944454D433F4A
505E5B647E9493A98B95758154463F46353F363F3C3E393E414E4F5863626C5771576E6B
7D80877A736B6A5E5550514A4E44443F43373742373E383E404241515F6B828DA1AEBFC4
D6D2D5D9E0CFD5BDC5B2BCB2B4B5B1ACA2AAA4A7AEBDCBD0DBD5D3C0B3BCC9D5DCDFDCD6
D5D7CFC8C7C5C2C5BEB9BFBFC8C7D3DADCE0DBDDDFDEDDD0CDC2C8B6B7A4AFA3A8A19586
6D6D686A676E7B8B9C9E9F988F928E99999D9490
4949494A4B4B49484A4B494646494A484443434546444546444343424242414141424241
41414244414243434242434443454747454444464846484B4B4845454444444445444341
464442403F40424442434342403F4041403D3B3E3F3E4042413F4340444B46464546443F
3E4044454444464043434542484A42413E3A41434944494A4B46433D4A48464843434443
3E3E44423F3E3D443C3C3C413F443C473E4144444445443F453F3D4C5D6E818E82847A75
6F7C7F818788A390A3858F8291768162826B7A7A8180808985807E6A5F5355545A474C4C
6A89A4A1A29998987874593F46434A54474D4F4259576897C7BAA46B5E52554E46403D3D
393B413C3E4041424141424347423E3D3D3B3B3B3B3E3F3D3B3B3B3A3D3C3C3D3D3C3B3A
373B393D3C393C38393A3B3D3D3D3D3C423E3F3C3F3B3F423D3D43454040434042443E38
3B3D3C3D373E3B3A393A3D353F3D3A393A3C3F40393A464A413C3F3C3A3A3B3C3C3C3E41
3B3F3F3D3C39373A363738393A3A39393E3A3C403E3B3A38403D3938383A3A3A3B3C3C3A
3C3F3F3C3D3B3B3E403E3B393B3A3C3A3D3E373A393B3F3D393C41413F3539403A3D4545
413D3A3A3C3E3E3C3B3A3C3D3D3C3C3E3B393D3C3E403A3A3A37383C3C393A3E3A39393A
3A38383A3D3C3B3A393938383A39393B3C3E3E3E3D3A3738393B3D403D3D3E3C3B3C3934
3A3A3F42403F3F3B363D413F343845414444505B50403B3C403F3A37393E414337393E3E
3A393A3A3E3C3C3C3C3B3938383C3C36353A3C393A3C3E3C39383B3E3A3A3A3D3F3E3A37
383A3C3B38373739343938373A393A3F3C3D3D3B39393D403F3E403D40413A3D3F3D3B3B
3C3A3632414A4A51554C48453F3E39403D37424447515F7277737570554C423C39383A3C
3A3937383B3C3D42373B3D3A394040363B393B3E3D3D3E3A3A393A3D3F3D3D3D3C3C3A39
3A3D3E3E3F3D3B3A3A3A39373A39383838393A3B3B3E3744679170474A42453D384D574E
725D5A43423D3D3B39383B44383D3A3B3A3D3F3F393739364649463E3E4349555553607A
8893878A998D97747D56504541323F3B41383F3A3B3C414A5564666E59694E5F3F4D423B
3F3D4742413F47403F3B3F3C423E46483E383B423D423E464755607E96A6BEC3CCD0B4B9
96A08A9475847185687D647C757B80868AA3AAB5BEC9CFD5DAD4CFC0C6BEBDC1C0C1C6CA
B7C1CAD1D8D6D4D8CCCCD3D1D9D8DFDFDCE4DDDEDCD7DACFD5D6CDDDD5DCD4CDCBC3B8B6
A8ADA6A299A5B7BFBBB4A7A4B8AAB3A4B5A9AFA4
4E4F4F4E4D4C4C4C4C4E4D49494B4D4C4F4C4C4E4D4B4A4D4C4C4C4B4A49494A45464645
44454648464748474545464742454847454445474645474A4A4747494443444546454340
4343434243444545464747464442424349464444413E3F42444348474A4F48443F42423F
3E414343464445404642443E40413A3C3F40443F403738424644433D3C3E3F4245464242
3E3F453F3C414047413E4144383E3B4443423E3C404648473C3E4A4447434D545055545A
555B575860655C665865636F5D574D5554584C55525158646975817797888E7FA585897A
7D887D8F989FA398969C717366826C827299657D466476AAAFBFC19987645155444C403F
433F413C3D3E3E3D3C3C3D3F3A3D3D3C3B3C3E3E393C3D3A393B3D3C3B3C3C3C3B3A3A3B
3C3F3C3F3E3A3C38393A3B3C3D3E3E3F4137393B41363739423D4146413B3B3A3D413D39
3D3E3B3B3639353737363B383836343537393A3A33373C3E3E3F3F3C3E3B3B3D3C37393E
3E413E3A3B38373C39393A3A3A3A3A39403B3D403B393C3B3D3A36373B3E3E3D3D3D3C39
3A3D3C3839393C40403C3B3D3F40423C4042383B3A3A3E3E3B3F433E403E424238384143
423E3A3B3E3F3C38393B3C3B3B3D3E3D38353C3C3F443F4137383A3B39383A3C3A3A3B3C
3A37383C3B393737393A393737393B3D3D3C3C3C3A38383A3A393B3F333637383C414240
3D3E44453D3A3C3A3734363E36374A4C484546443A363A3B3D3B3A3A38373A3D3D3E3F41
403F3C3A3738393838383939363838373637393A39383737393D42463837393C3F3F3C38
3A3A3A3A3A3937353A3D39363838373C3B3B3A3938393C3F4443423D4041393D3A3B3C3B
3A39393A353D3B404744413C363A3B40474A4F555E615E64604E454047403A3A3B393837
393B39414C45383539393C3C3C42443D3D3A3D3E3A3C3F3C37373A3F3E3B393B3B373537
393A3B3C423F3C3C3D3D3A363A3A39393939393937344C4A63483C39404C55656D808261
5B3F4135393E3D44393F3E40393A3D3B363B3C44403C47413A39413F495C6780817C7B85
878E7D796D5B5140463E38393A3B3642374A4F4B554F544F525047434042363C31363D3B
393439353A333938403C3E3D403D41443B3C3E3F3E45434E566B768B928F979087757855
5E45564C4F595C6C75878298979EA6AEB6CFD0D5D1D2CAD1D3D0C9BDB5ADA9A49B9AA5AC
A1ABB7C4CECDCBD1D3D3D9D6DCD3D3CDD0D6CED2C7B3B4AEB2BBBFCAD4D0D2CCD5D0CAD0
CAD3D3D1D1D4DCDFDAE0D8DECEC8C7BFBCC0B9BF
4D4E4E4C4948484A46494845434547474946454746434244444546454342424343444443
4242444645464544424141424245484745444649494644444241454A4443444647464340
3D4045494A48464340414342403F3F3F3F3E3F424243474C403E423F42473F3B3F444543
4142413E4541423F4741433C3F45413E3A3A423F413B3F49443C3E3D3B3B383742474448
3F3C40393B444041403B3D3F313C3B3E3D3D3B3B4044413D454343393A403F3E3F403E44
3A3A3A443F3C49414B39414045475E586F5357555E5353575B6C787076997FA87FA484AB
89A48EA5A4ABAE919B918B767369554C4C5248484864787F989A895E5747517F7A886755
584C48463C3E40403E3D3C3D3B424645464E55575959544A43413F3C3A3B3C3B3938393A
3E413C3E3D393B373A3A3A3A3C3E404142373D475344403F3A333842403A3A3B363D3E3E
424039363D3B363C3E3A40423535383B3E3D3A373A3C3B3A3F43403B3C37373D3C373940
3F413A353837363C3D3C3B3B3B3B3A393F393C3E38393F41433E3A3A3D3E3A3638393838
3A3E3E3B383A4043403C3E443D40423B3F43373A3B3A3D3F3E43433A3E3F3F3F40434545
4A413734383D3D3B373F413D393A3D3D3C363934363C383C353B3D3936393B3B3A3A3C3D
3A36383D3E3B3A3C4143434033373B3C3B39373739383A3D3B37373A3E3F3C383A3C3B39
383B434338363C3D413C383D3E4F6D6F46403B35343E423B3A363637343339403B403A37
403F3A423A3C3C39363637393735373A3834343937383A3E42423E3A3334383E42413B36
3B3835383F4445433B3C3734383A3B403A383635373A3B3C3B3A38343A3D363C373A3B38
3537404840453B3A3F3F3F393C4348444C554F533D42393C423D3A383935353D43413D3A
3B3A343E524D3B373F3B3C3C3A3E413B3C393C3C36383D3C36373B403F3936383736393B
393333373C39373B40423E3A3B3A3A3A39393938453E464646454B628D98A4A97D804C41
3934313E3B3D3E3B363E36373C384238383D383F3934433D4842565A6B7E7A91807C7571
6B6F594E3F3F373D343C303E3D413B3C384F6154594A48383B3B3A3B37303C3A402E383A
3C3A3B3943393A403735373D403D3C3D3E49434C475D586B617576786B58574A584A6554
776C90889E94A5AAC9CFD4D6D6DADBDBD8E0CFC6C1C1BCD0D9DED4C8CCCECEC1AEABB2B2
BCBEC0C6CBC7C3C8CFC9CCC9CFC7C8C6CAC8BCC2B8A5B2B9ADC8BBD1B7B9A6AE9EA9B3C1
B6B6B2B0BBB9C1CED5E7DBDEDCBAA0797D786B6C
555655524F4E4F504D4F50504E4E4E504748494847484A4C4C4942444A47434848464A4E
4B43434949484646474848474145434646454B4A44474A4B4A4A4A4B4549494643454645
3F47484B484448453F444644434545424340464C484443414847423D3E444745434B4949
49484942474541454B443D43424545414042413D3F3C3D3E4E45403D393F444441404246
42413E3C40464743433E3B3D4144423F413D4144403F44473B3F3F40444342453E3F3C47
4B474D4C4744423E413D3E404E687A957184554F5467686A666752475360584D64565652
585360717B867E635051546B7A8D75746A6A5F5042433F4D4E474A4946413F495D547998
B79A615E4A4E4F5647445C575B5D6F78808E9BB2B9C29EAF918C69534B3F4B393A3E3B3F
39423A3C3E393F3D393C3D3C3D3C373B373D43444444413E47403C4C413A3B3E393E4241
3C38393C38393A3B3C3E3F403634353A3C39373834363D3E37373D3F383D42423E3A3737
393F403A36383D3F3D3A3A3C3C3B3B3E3A39393A3B3C3C3B423F3B3A3D3F3D3A3A3B3C3A
393A3E42453C3C444541475340403F3C39383839383C3E3F4245423C394044413D3D3F3F
46433F3B39373737373B3D3A37373D443C3C3B3937383B3E363A3A37383D3E3B393F3B37
41363C3E38393A3C3D3E3D3C32393C3A383A3B39393B3D383A3A333B3F44413D3E3A373B
36484A3E3837373A3545483F4C65644F3A373A3D393B403D3A3C363438393B4238363A3C
37393E3C3D3C3937373A3F433B38373A3A37383B3538393736393B3A3A3E3A3A37343C3E
37363D46453B373B3B3A393838393A3B363333383A39383A3B38373E343B3A384041413F
3E3D3B393241404042474C3F42443E3B3F4040453A3E3C3A3B39393E3D3B3A3B3E40403F
363D3D3B3D39373C373B36373C4B5848393B3D3E3D3D3E403B3B3B3B3C3C3C3D36383A3A
3938393A39353A3E3D414239363B363D3F373C3E46484D5F5C8E97B0BBA9886B5D423F40
373C3D39383C3E3D383E3C393E403C3A3C3F3E3D3C363E545E6C7B8A8E81777D76685B4E
413E403C3936373C3A363B45383A3C3D3D3C3B3A393736383737393D353B383833393839
353941383B373E3C3839433E343D3C3D3F424A51596E776C5D646D6A73838EA59BA4A9AC
B9CDD9DAD7D4D5D7D3D3D8D3D0D4D0CDC3BFBFACBCC8DADCE7D9E3DBDEDADDDAD4CCC2C5
BEBC9F98868F7886807982998F9A9BB5D1D5DDDCD2D0D0C7C3C7D1D1D6CECFCBC3B9C0B3
C4B6BCB2AF9F92A3BDDBE6EAD6D69B8C64595443
4E4E4E4D4B4A4949474849484747484945464645434344453F43454B524D44434947494C
484141473E3F4043454543414145434747454947434446464545464844484A4745474745
45453F424340423E4646454344474A4B4943464A47454543484A4947474947433A404045
48494E4A4242444A4C454247404142403F3F3D3B3C3B3C3B453C393A3D3D3E4043444241
47453F3B3D4243403F3F3E3F40403F3E3A3A40423A3941484144414144433F41413F3E3B
3B404A55403A423848475B5B72767E6F4F4E3F433D4944434249413F425D4859565E4A56
5450483F404A4B40433B5552827B7D718985916E8062676C5F54514A4443414A46456284
9CB4B8C79AA4A39E8374868595A6BEC4CBD4CFCBCECBC7D1DEC3A777644E4F3F3A373C42
40493C41413B42374245403B3B3E403A383A3B3B3E41403D353B40554C463F383A3F4343
3E3A3A3C3F3E3C3A39393A3A38393C3F3E3A393C37373D3E383A3F4041403F3B38393D42
3A3D3E3A37373B3D3D3A393A3A3A3B3F3A383738393A3B3A3A3837373A3C3B3A3C3D3E3C
3A393A3C38363B45464040463D3D3D3C3A3A3C3D373A3E414344403B3C40434242423F3A
3A3A3B3B3B3A393834363838383B414737383A3B3B3B3B3B3535363838393A3C373C3C38
3E353B3838383939393A3B3C3C3C3937373839383335373437393339343A3B3C403F3E42
4C4F483F3F403B39383C3F45515851453A373836343B413F373936353A3A3A3E3C393D3D
393A3E3C393939393A3E42463A38383A39363537373A3C3938393837343A393D3C383C3A
3B393A3E3E3A3A3E3635353536383A3B3B38393F424242443637373F393D39383736383D
3E39373837413E3E4044483E393C39383C3A383B353A39383C3C3D43413D393A3E3F3D3A
393E3D3A3B38373D3F433E3D3F454A3D3B3A3A38373737383B3B3C3C3C3B3B3A393A3C3C
3A393A3B373742433A3A3B393B413E3F424E64697B7B8F99ADB7B19F6C68513E3A353D3F
3838383939393A3C3D403C3C414441423C3F3D3C4657677388827B7872665E6148474A47
3C373835343335393835383E373A3C3C3B3E444A3D3B3A393835383D363A413638323B3A
393A3E363A373B373D353F3641403F3A3D453F484351505C6066788DAECBD8E8DCDFDDD7
D5D3CDC5C0B4A89D9189857C706E6A6D65626E6E859EA9D0C3DBCDD9D1CED4D0C4B29B93
776D5C4C505049535255677D9391ACAFCCD0D4D2CECFD2D0D0D6CEDED3E0D4D8DBDFD0DC
CBDAD0D7C8BFC4BEC9C2D0D4D8D5C6A2A0819787
4F4F4F50504F4D4B4A4B4A4948494A4C4A4B4B4A48474647444747474B4A44414C49494A
474142484746464647464341484B494D4E4B4D49484848474646484A4447484746474746
48474044443E4347454342424447494C4D464445424243403E40414142423F3B41434044
454044424342494E4942424444434446454240404040413E423C3C3F4341404246484642
42413F3D4043424041434545424141433E3E44453D3C44484849444144413C3C413B4040
484F433F4E5052585468747568675C603D5345554146413F3D4341434046433855516A7F
9E9472493B40423E444449424B48464950585B5D6C747892A09C9C90847A6E6E6F615664
5D8FB4CDCED7D2D2C3AA9F8F8694A4A7B4CACDC9C4BEB4CBD2D1BB9469474141413B403B
46403C3E41424243515B57544B41443E3D3D3C3B3E42403C3E413D473E3F3D383A3F4241
3D3B3B3B3D3B3938393B3D3E393C40423E38393D3C3A3D3E3A3B3E3D3B3C3D3B3A3A3D40
3C3B3B3A3836383B3D3A383939393B3F39383637383939393F3E3C3C3C3B3B3C3F3F3F3D
3B3837363E3C3C3D3C393A3E393A3B3C3C3D3F413E3B3A3C3E3E3F413B3B3A3B3E3F3B34
3839393A393838373C3C3A3837383B3E3C3C3B3B3B3937353A37383A373232373A3C3E39
3B38453B3A3A3B3938383A3D423D3838393836343B3A3C3839393235363B3C3D3E3C3A3D
5952453E403E39373A3A3E484C48434148443F39363C4240383937373B3B38373C3A3C3D
39393B3A36393C3D3E3F41423938383938353435363A3C3B3A3A39373639353839383E3D
3D3B3A3A3B3C3D3D3A3939393A3C3E403C3A3A3E41414243393E3D4140423D3F3F393A40
3F39383D43453F3D3D3D3E38383B39383A3836383B3E3B383A3A3A3E413D39393D3F3C38
3B3E3C3939393B414448403D3E3B3A353F3D3A38373839383C3C3C3C3B3A38373B3C3D3D
3C3B3B3B40383D3B3B3E3A3D3F3849708594B1BFC6B5B98F9970734E3D4B433D393D3E39
3A36353A3B38383C444542464A49424343515A585F72786E7562524B45403E3C38393E3D
363436363637393C3D3C3B3C373A3C3936373F46423C3B393A3637383C3B3837383B3835
3837373439393B37403A413A433E3E3F4045433E504F62819EA6BBCFE1E7E4ECE0D6C5B3
A18F7D716B6159514A47443F4546403E3C43515271687F7B92888C8C9C8F877B736E6566
6B766D8A89A99BB298AA93BFB1C7D0D0D2D2CECBCED2D5D9DFD9E4CFD7BDC0B5C4C1C2B4
B7AFBBBDC3C3B5BFA8ADA7B7B0C29DB68CB5ACBF
4E4D4C4D4E4E4C4B4B4A494847484A4B49494A4A484746454B4C4641424647454E4B4A4A
4744464C4D4A454242424242474945494A47484345454443424243444445454545464747
3C3F3F4D52464343424042474A484645443D3C3F3F434643424141414344444340403D43
443E4243433F464C45414240403E3F43423D3B3D3D3D3E3E3F3D3D3E3D3D3D3D3E3E3F3F
4343434242403B373D3E3E3D3C3C3E40423D3D3E3C3D403E3F403C3D454644463C3E4C5D
7074594164627A686B5A654D483C423F3E3E3C3D3C3D3B39373A3B3D42413B3F485C7EA0
B2A57E54464E514D4D524C473F3F3B4543463D47415555708DA2C3D0D0C9BBB89C937C7F
607B8399AAAA99979E9FA7AABEC2C7C9CDD2D3D3D3C3B4A99F9EAB9D8661504F5151645A
5C57666163635A768B968A887851423A3D3F3F3C3C3D3C3940413A453F3F3E3D3B3E3F3C
3A3B3B3B42403C3A3A3A3B3B393A3E3F3C3636393F3B3D3E3B3B3B3632353A3C3B3A3A3A
3E3A383A393636393C39383939383A3D393838383A3A39383C3A39393735373B3F3E3D3C
3B39373646433E3835363B3E37383A3C3D3E4143423D3A3C3C3A3B3F3C393535383B3B38
3C3B3A3837383A3C3D3B3837383A3C3D423F3B39393938373736383B3937383C3E3B3C33
3033463A3C3E3F3D3A393B3E3E3A393D3D38343439373B3A3D403A3B393C3D3C3C3C3C3D
433E3A3A3C3B3C413A4146433E3D434849423C3836373A3C3C3C3A383B3B373338373939
38383837383B3E403F3C3B3A393838383837373734383B3A3A3C3D3B3939333638393F3D
3A3D3D3C3D403E393A3938373738393A3C3A393A3B3B3A3A3E433E3D40403E44403B393C
3E40454B47433D3D3D3C3B383C3C3A373636383B41433D39393735393B3B3A3C3E3E3C3A
3B3C3B38383A3F4541433A36383433383C3C3A383A3D3D3B3E3E3C3B393837373C3C3D3D
3C3C3B3B3F3A393742443A474F5686C1D4D8DED9D7BC8C6C534444343B4A44443B41413D
3E3A383B3D3C3C3D4A4944505963636D76848B7C6B6C654E47383336363737313F3C3937
37383A3933353637393A3835383A3D3B3736373A3C3433333D393935393C3B3D383A3839
3A3938373A3C3F3F3B3B434042435768637E68988AB4A5D0DBDEE8F2EEDAC5BEA4907865
574A423F3F3C3F3D3B3C3A3C3D3D3A3A424E544F5E52434D455450605E5D69778BA0A6AE
B7B3C4B8D2CCD9E3D9D1D5C7D7BBD7C5D6DAD9DCE5E5E3E8E0ECD4DBA6AB8E98A2AD95AA
87A292A28E829497B5A1A397A693AD83AF95B0A0
4F4D4B4B4D4E4D4C4C4B4948494A4B4C46474748484847464547474444494A464B494848
4746484C4947434244464747474843454643464245444443434342424544424243444647
4345465C6D5F4C41434244494C4B4641433E3E404044453F43413E3E3F40414143433F44
443D41413E383D44434445413E3C3D41403C3A3C3E3D3D41434644413F3E3C3C3D3E3E3E
3C3C3E4042424140403D3A393C3F4142413C3C3D3C40423D45443E3C41413E3F424F5968
716E635140464C51404B4B403E343F3E433C40403E3D3E3B3D40444343435B6E7684A0B3
AFA897817A879391918489697E5A5E4C64586B606559636263799BA8ABB0B2BCBEB79D93
7E846974757B6C5C565A728B91909094949399A0999D8889596C7683887E81827C778978
7D97A9B0B6ACA5BAC1B88A77715547423E43443F3B3C3E3F474740504A423B3D3E403F3A
3A3E403F413F3D3D3E3F3E3C3B39393C3C3937383B383A3E3C3D3B353637373637393C3E
3E39383A3A3635383A38383B3B39393B3A3A3A3C3D3C3A373635353838383C433D3C3B3B
3B3B3B3B3D3F3F3C3A3B3C3C37393B3C3D3E40413C3C3F44423B36363D3B3A3A3B3C3F41
3A3B3B3A3A3C40433D3A37373A3C3D3C3D3B393A3C3E3F3F3E41413D3A3A39373D3A3F3A
3B435B4F3A3D3F3E3B393A3C38383A3E3C37373B373338383B3F3B3C41403F3D3A3A3C3D
3D3A3C3F3B36373C3A42443C363A444B4139363B3D39383F3E3D3B393A3E3C3635363738
39393838373A3E3F3D393634393A3938393A3B3C363A3B39393C3D3C3639363B3D3A3B35
3A3E3F3D3F423F3939393938383939393F3E3B3A3A3A39383B3F3B373A38383E41413D37
373C40403F3A393C40413F403B3A3937343437393D3F3B383B3A383C393C3F403D3B3B3C
3E3E3D3B383A3F433C3D38353835333C37393837393E3D39403E3C39383838393B3B3B3C
3C3C3B3A373E3C353D3E45698CABDBEADCDACBA78E7454453D37423E42484044393A3C3D
40413F3D3F42423F444C526B7A888792979487694D4741323B34373D3B3B3A3437373738
3A3A3837363635353739383538383A3C3E3E3D3C3A353938423C3F3D363A383F383B3537
36383838363A3F4569678C839E7F9389AEB3C2C7E4E1E7E8EBE8E4DABE9C8C887D6A5448
403C3C403A373C393B403B3F3A35363F484845484C4D505A61688297B5B2BAC0CDDAD9DA
D8DFD9E5DAE9D7E0C5C8BED2B1BCA7B0B2BFCBD4D8D3D4E0D8D2D8BBBBA5B5B7D1C3D4B5
CFB1C5B9AEA48FADB0CABEC4B1B599B794C097A3
504E4D4C4D4E4E4E4E4C4B4B4B4C4D4C46464647494A4948484749484647484447464646
46464749474747484A494846494B45474744484448474646464645444743414243434446
41443D49564C423E44434242474A463F45424445444747404A474546464342413D3F3E44
46434847403C3D414243423E403F3F41403E3E3F43424046454D4A4549433E3E43464440
45413E3E3E3D3F4146423E3D4145494A3F3F42423E42484645443E3B3F3F3D4036404044
40393C36443C4938433F564D443D39443B403938393F4E5662696E667677849B858E8B93
868A929490949EA396908B7F8E7E807688859CA49CA1A39C95959685726E75867C97B3BE
CCC3A29E9EAAAAA2998F8E979E9D8F806E5F5A5557545F474C54899CACB4C1BCAE9D9A7D
789E9FBCD7D0D4C9D0BC794C454140403E42423D393C41444F4A3E4C473C353B4042403B
3D4346443D3C3C3E414343423E3A393C3E3D3C3C3633373C3D3F3F393B3A3938393B3E40
3D3B3A3B3A3838383937393C3C39383A3C3B3C3D3E3D3B383A38393D3D3B3E443B3B3B3B
3B3C3D3E3A3D3E3D3B393837383A3C3C3C3C3D3E3C3E4042403B373637393C3E3D3A3B3F
393C3F3F3E3D3E403D3B39393C3D3C3A393A3C3E403F3E3C393E403D3F43423D3A373B37
35354539373A3C3B3937373838383A3A38373B413D373C3B393E3B3C4643413D37383B3B
3E3A3D434340403F3A3A3A3B3A3B3E42413B383E423C393E3C3B3B393940413B36393839
3D3D3A3B34373B3C3A383635393B3B3A3B3D3E3D3A3D3D3937393A39393B373B3C393A35
3B3E3D3B3C3F3F3C38393B3C3D3E3E3E3B3B3938393C3C3A393C3F3A3C363739383E3E39
3A41423D3B373A3B3E423E40393A3E3E3A383A383A3C39383D3D3A3D3E4143413C39393B
4240423F39393C3C3B3B3D3B3C3C373B3A3D3D3A3B3F3E393F3D3B393839393A3A393A3B
3C3C3B3A3C40393D50648FC2D8D3D5BC988E7F655342413C414248494B463F46403B4142
4043423D3E43433F4A5B647D7F82706F5C554B3F383A3C383A383A3B39393B3A32383938
373434393C3937383A3A3A39393735363B3D3D3C3B3840383E323B3D3D344A3F5D49574C
3E4449555967748290B1BBC29E9DABC9DFE1E3E5EAEBE2D8D3CEBFA9856C707663584D46
403B393B413B3D363A413B44474D5A6570757680869D96BFABC3C2D6D9D9E1E2E5E6D8D0
C8BCC8ADC6BBC4B9BCADCCB7C8B2BCB9C4CBD0CCBDAFB5C8D4DEC8E1C5E3D4E4DBDCD6DE
D8DFD7D7D4CAD3C9DBCED9D4D9C0DEB3DBC2D4C9
4B4C4C4B4A494A4B4A484748494A494845444344464747474F494A4A4544464548484949
4A4948474545464748474442454844464541454246444141424343434744434647454444
454D4340433D424C4748454147504D433C3D4346474D4F4A45414042423F3D3E42474445
4541433E4446454445413C3B3D3E3D3B3B3D3D3C40413F423A44434046413B3B3E41403D
413E3D3F3F3F424641403E3C3C3F44483E3E403F3B4045414848413C3E3D3B3E3C3C3D3F
3E3B3B3B3D3E3F403D40403F453B443C483C44393C486270848D8F7F8372826A6F575F5C
5F6D829697857B8172775E695F6C676E5E666780678B8388857F7D6E5A4E4B57616F8D82
8D80A0B3C5CACFD4D7D4CCC9C9D1CBC1AF978169545146444A7BADD5D2D5DACFCAC5C8B6
7E7C717E95A3B1B3A2956E4A404341373F41413F3E3F3E3B3E403644443F383B3D403E3B
3E46474344413E3D3F403E3C3D3B3A3C3D3C3F433733363B3C40423D3A3B3C3D3E3D3C3B
3A3C3D3B3A3B3A393A38393B3C39393B3E3D3B3B3C3C3B3A3A37393F3E3735393B3D3F3E
3C3B3C3D41403E3D39363537383A3C3C3B3B3B3C3E403F3B393B3D3E37373A3C3B373739
393C3F3E3C3A3B3D3938383B3F403F3D393B3E3F3E3C3A393E3E3E3F41413F3B39373A38
383340373839393938383838393A3A38383A3D3D3B363C3C393F41423E3B3C3C383B4141
443F40444344433E3C38383D3E3B393A3D3E38363B3A36363A3B3D3A383E4139383B3939
3F3D393A3436383938373738373B3D3C3D3E3D3A3A3D3E3A383838363C3D373939373C39
3A3B3B3A3A3B3C3C3335383A3B3B393937383735373C3E3C3D3C433E3E383E3C4144443F
3E3E3C383C393D38393D383A3A3A40413B3A3D3B3A3C3A393E3D393A4644413E3C3B3C3D
403F44443C3A3C393D39403D3B403B3A3D41413C3B3F3F3B3C3C3C3C3B3B3B3B3939393B
3D3E3D3C413F466B8599BFD1C3957C6A51443E3F413C404C44654E53584C444747424B49
3D3E3E3C3B3C3D3D515D585F545644443C3D3B383A393736383A3837393A3B3E373C3A35
3533353D39353337373434373937353435363838383138323F3845475C6C5E7A55644A57
4E4F4D5759656C797A86928BBEBAD8E0E4E0E9D3D7BDBAAA9386706251474D4843434241
3E3C3C3E3E4353505765697F9FAAB8BBC2C7C2C8CDCDD9D0D4C1C4BDC0C1C6C2BEB7A498
8B8E908993B0BFC5CAD0CFDBD2DBDAD7D8D2D0CBB9ABAFBBBCBBBEBDC1BCBBB6C5BDC5B5
C3B3BBB3D2DAD3D4C4D0D3DED5D5CDD5BECFB6C0
4F515352504F4E4F4E4D4C4D4E4F4D4C4D4B494A4C4E4E4D4A44494E494648474C4D4E4E
4E4D4B48484848494D4F5050474C4A4D4B4649474A47444244464848484545494B474343
425048454841434A4E52504B525D594C4344484743464740494542454747484B3D454344
4544463F424A4B4849433D404143423D3D41434044464444363F42414443413E3C3D3F42
403F4144433F3D3F404243403C3D43494A4442404146463C41423E3C404143493F3A4142
403E373D413C3E353E373D3D3F444446373A41464248595B6567644D4D4D4648424C404F
59697F999D765252544D433C5048524A504E574B4D5A64624E495053504C4B576E63837B
84577B788495B0C0C6CACDD2CBD1CED4D7D2CCBD9698807F6A878DA5ACBBD0CED0CCD0C8
BA847D5E537084B8B4A08E7D74766B55505153545552473C3F44373E3F3F3A3C373B3B39
3D45453F423E3A3A3E40414039393B3C3A393F473D38383A3A3E413E3A3A3B3B3C3B3A39
393D3E3B3A3C3D3A3B39383B3B393A3D403D3A393A3B3B3C39383C45453D393B3B3F4241
3D3A393A3F3E3F413E39383A383A3C3C3B3A3A3B3A3E3F3C3A3E403E413C3A3B3C39383B
3537393837393F43403F3E3E3E3C383437393A3A393A3C3E3C37383F43413E3E3B373836
3833413D3C3B3939393A3A3B3A3B3B393B3E3B343D363C3832373839403C3E3D37383D3B
3B383C403F444A473C3D3E3F3D3A38383C433C333A42403C3B3D403C363B3D34373A3737
3D3B35363738393837373839363B3E3E3E3E3B36373B3D3B393A3937373B393E3E393B36
36383A3B3A383839383A3C3E3E3C3A383A3B3937393F403E3F39403A3835413F4543403F
3D3B3B3C3A383C35343B373938363A3A33353B3A373A393A3F3F3B3C4A433C3A3C404140
3B3B43463F3D3F3B3E373E3835403E3B383E3D37353B3D3B393A3C3E3E3D3B3A3939393B
3E3F3F3D3B40629EA58F835E60423E403F45464B594F8D59756266586B605D5B58464333
3A38383A3935363C3B463B3F333F363C3B4340373634353D373B38363A38323434373332
3839373B3D37373C3B36353A37393B3A38383A3C4033393B5A60706F6A657164684C4A41
443F373F3D46485071A6B0C9E3E4D8E7C6CFAEB17F84687657514746413E4439393D3E3C
393A3F433D506C6968727D9EC9C9D3D8DCD2BFC4B2B8A9AB84907A867176818283817066
728EC0BCD0CFD7CBCFD8D6D2D8C5D0B0B7A6A2A59783756C646E677868766B71676E6676
6C7E7A839DA7B2ABA6A0A09CA9989C8085767673
48494C50504C4A4C494A4A4948494C4E4549494542454748444648484644444543505147
454847484542404D4A4842484C4A48484848464442424345484949484141434548494847
47464442404040403E45494844434241494443464541434B464144443E3F423D41404142
42403E3F40443E434441443D3D3D3E403F3C3D403F4B4B43403D3A3A39414644413F3E3C
403F40424443413E413D42413F3E3A40424C3C3E433C423D3D3F4442424945363C3E4042
413F3C3A3E3F43393D39404040464741443C40423E4041404142403C40414C75535C3B55
5F7788B6AD865550685E5B5344444D4A535260615A514952424F4D475C5E666563747389
788267617A8E8EA0B5B9C0B8B4BBC8B9C5BACFC9CFC6D9BCC8B3B6ABA6A1A2898B7BA1BE
B1BB8E905D505A6D98B0B1BBC0BEBEA4AC9FB1AAB9959B654E3F4A4B4F373E4439423E40
403D4965413F3A3B443D49443A3B343A3843393A3239433740433E3E373B3C3C3E403D37
39403C393638403E35383B3B3A38383936393A39393B3A37373B3F3D39373A3E3F41413E
3A383B3F42413D3E423E393D3D3C3B3B3B3C3D3E383E43444547443F383C3D3A393A3B3A
3B38383C3C393B413C3D36354046413D35393D3D3B393B3E373C403F3A3636383140373A
3B343F41443F3C3632393D38373A3B393634373A383A3D3F3F3F3E3D3B3C3D3E3D3B3938
3C3B3C4246433E3D3A3C3D3C3A393B3D3F3E3B37383D3D3934373837383C3C39363B3D3B
3A3B3B3A3A3D3E3B3737383B3A3C39373A3A393D3B3B39393E43413C3A3B3B393636393B
343C3B3F393238393A393C3C37383A373C373D3A3C413B3E403B363A43463F393E3F403F
3C3A3A3B3B3C373C3E3A3C383A39383737393A3B3C3B3A3A3D404141423E3A393C3E3E3D
3E3C3C3E3C373537383539393540473C393A3A3A3A3A39393C393C3E3A3B3D38403E3A3F
3B3F38393B4C6078545741413E3B40414D5D739A8CB0A2A98FA297997E8A5D544B39383A
38393A3937363738353937373D3C383B38393A393736373837393A393635373A34373434
3A3A373A3A373B3D3B3A393338393C3D3A383D453A5A5663635D5A5B55584640403C383B
373F3A3E3B5387B2C6D6D6CDC5B6BC9E90747169676B61666A6A6354463F3A36373A3C3C
3A393B3E434356626468759291929BA19A8D7B69665953585A524C4B5046474A51514D5C
688595ADA0B196B1979C95A58D9576775D604D484440473C433F4440443D474D52646272
829FACA6A5B2C2BEAFACB4B5A69B938B887A7C6C
4E4C4C4E4D4A4B4D4B4C4C4C4B4C4D4F494A4A484B4F504D484A4B4A48464646434C4C46
4648484B4B49444E4A4C474B4A4948474847454343424344474848473E4044484C4C4947
48484745434243443F45484746484847413E3F44443F4046434346494644433F41424342
434443423E403C4244404441423E3E4244434243404D524A444241414146484541403E3C
4040414346474644464144414041404740504B4C4A444D48423D41424145433E3F3F3E3F
404140404346544E4C495048434C4351474E3F453E3C3B3F474C4D4C5B505A665959464E
466160737C8E878788797165524C4B42504C52524F4D4C574F5B5E5968605B56574C5D7B
8A6F5C575E787F8E9C9FA9A4A9AA9CA794B3A7B7B2C4BACBA0B499A98F8F886871547D82
949AB4ADB9878D615B84A2BFC8C7D2C9BCC3B1D6C0D0C3B979583F443742434B4B4C443F
493E4841443B4333404A40403E3C42363C3A4440505456463A42344139393735373B3D3D
353C3B3D3C393D393A3B3C3C3B3A3B3C343637373A3F42423E4142403B393A3C44444341
3E3D3E3F3D3D3A3B3F3D3B403D3C3B3939383939383C3D3C3C3E3D3A383C3E3C3C3E403F
3A3C3A363C45443B3F3F3A394245403E3A3735383E42403D3A3A3A3B3C3D3C3B3740363C
413B44443A393C3E3D40413B3C3E3F3E3B393A3C3A3A3C3E4041403F393B3D3D3C3A3939
433E3C3F42413F3F3A3B3C3B3A3939393B3C3A37383B3C39393B3C3A3B3D3D3A3A3F3D36
33373836393B3C3B39373839383B38363A3A393D393A3937393C3B3734353637383A3D3F
373A393A3A3A3E3D3F3D3F3F383739353B373B383A3F3A3D3936363A3E4243414040403D
3A393A3B393B383B3B3D45423A3B3D3E3E3C3B393A3937383C4044453C3B3A3A3B3F4347
3A37373A3C3B3B3E39363A3A363F453A37373738393B3C3D3A373A3B383C42413E393C33
413940383B3E4741393E3D3E4B556C7D93A9B6C8C4D0CDBBC5A69F7B545A3C3F3C373837
383939393939393A383A36353A393639323437393A3A3B3C3435363635353739393B3836
3A39373A3C37373735373A3737383B3D3A383D443D55525A58504745393E403B3A36343C
393945527085A7B6B4B4A38572656C59614F57595B5D4F4F4345443E3A3A3B3A37393B3A
393A3E41404C5B5B5656565B524B4948454545403E3C3D43444142463A3A3A383B3B3C47
44525F617A7C87888B82766F6055484744464242444548445658605E65687B88A4B1B7C5
BEAEA1968D96A4A9A7AFBFC7BBC0CCD1D3CBD5CE
514D4C4E4C4A4A4B484848494A4A4948484644454B504E494647474644434242494D4A46
4644434748484145414743454A4949494948464444434344464746454C49474646464645
4647474644434446484A4A47464848464241454A494443464243403E4041414441454542
4348494643423F44423C3F40413C3A3F4444413F465157504542413E4346454240403F3C
4040404144454544443F4342424442494857595B5757635B4E414646403C363B3D3C3B3C
3F4141405B6073716C6C75676A65776A7D5951424542404043454645503E4B3C4A4B5555
5F7D767A819A968C86736354454446404B43423F3D3D3D474648483F4C4745484E424356
6B6D645C4C5F6678868C9DA29887776E8885A9A8AF9EA2899C91A0A0A186734B53798DAD
95BEA3C29FB699AA687A879A9D93938D8265706CB4AAD3C1C79082524B3A4B3F41565779
624246483E3F3D3942383A3C3F3C443C4A5B7876948FB88B915B45333D3B3A3A38373739
363A393F3F393B38393A3A393838393A3B3C3B38393F42423E4041403E3E3F4046444241
41403E3C40413E3E3E3834383B3B3938373737373F403E3A393B3C3B363A3B39393B3D3C
3A3F3C363B4744363B3A373A3F3E3B3C3D3732363E43413C464039393C3D3A3647473A3F
41373A39403C3F433F3C39333C3C3D3D3C3B3A393A39393B3E403F3E37393B3C3A39393A
413B3B3F423F3A363B3A3B3B3B3A3735383A3B3938393A3A3B3D3D3C3B3C3B3A3C41423C
3B3D3D393738393938363535363937363A39373A383B3C3835363735383737383A3A3A39
393C3E38373E3F40413E40403A383A373C393A383A3E3B3D3B37393A363D494A4342403E
3C3B3D3F3A3E3C3C383E4C48413F3B3A393A3C3E3F3D3A3B3C3C3C3D383A3B3B3A3E454B
443F3B3A3937353439383C3B373D40373A3A39383839393A3C3D414039383C3D3941373D
3C4141383D40494F4F57647F9197A6AFBFD4D6D1C0C8AB977E5D55414242323B3A3E3D38
393838393A3B3B3B3A3A36343737353639383737383839393A3A3A3A3A3A3B3C3B3C3A38
39383739403C3C3C3837353036373A3D3B393D433F49444544423C3D41373D334038383C
3A535A81768F7C7F7671695C5F656758745A51453F423C403D3E3C383737383737383938
383A3F433C4748433D3C3D37433C3939383E43413B3D3F3E3B39393A393D3A3D3E3F4F62
6B84838F92939B8F8981717E6F6B626D75757A7B7A7E8793A9B6C5C2BFB9BEC1B8B9BDC4
C0ACA6A2A3AABAC8CCD0D5D7CDD2D8D8D5CFDBD9
4E4A4C4F4D4A4A48464546474949464448454142464A494649494948474746464C4A4645
47424046494B44443F4845444A4A4B4B4B4A484746454444464746464A47434244464849
43444544424243454B4B48444447474446464A4D4C474546444947474B48444741474641
42494A4645434245423C3E424844424649464342444B514C4341403A3F3F3D3B3D41423F
3F3F3E3E3E3E3E3E3C39414343433E42434B4D4E4C535F54473E4747433E363E3A39393B
3E3F3D3B4F515D5653535A4B61777DA289834D483F444440424A4D4B584D64586F718586
93A093928986776D61564F4942434642423D3C3D3E3E3F4348474A434A4039393E405A53
7C74765955595A6B75747E837C665D6A658878938A8A76877F9588938D927E6A7D658D7E
9C99B194835C6B63617290B3BDAEA0987A83697F678B9FBEC4BEB4BB7E9381827B7B5F53
675A8A7B564334404B3540423E403B474668776F75878CA984874B49403D3D3F3C38393D
3C3B363C3D383C3D393A3A393939393942423F3A393C3E3D3D3D3D3E3E3F4041423F3C3D
3F3F3B383C3F3F40413B383D393939393A3A3A3B3E3D3A3735363838383A3A3737383836
3D3E3E3C3C3C3A373836373C3E3B3A3E3A3A3939393A3B3C403B35373C403E3B403C343C
3D34383A3E37383D3B393B3A3A3A3B3C3E3D3B393B3836373A3C3C3A35383A3A39393A3B
3C35373D3E3B36303A3A3A3C3E3D3935373A3D3C3938393A393A3B3B3A3939393E3D3B3A
383737383735353737353435373A38373A383538393E403B373638393E3C3B3B3C3B3733
3940483B343A3A3E3D393D403C3A3D3C3F3C3B3A3C3E3E3F393742473E3F453F42414040
404142443F444541383D4B443C3A3A3B3A3837383A38393D3F3E3D3D3C3C3C3B3B3C4043
413D39393A3A38363A393D3C383B3D353B3B3B3A393837373936373A3D3E3B3638433839
3A3D4940486570A1758E84B4CBC1BCB8B7BEB5A17A7849563C4B3E3D3C3B3338363B3434
3A3838383A3B3A393B3A373637373636413C3734343637373A3938373636363538393939
393838393D3A3D403D3D3C3637373A3D3C3A3C413E3E3C3A3A3D393B36443942313B3C5A
697E908B8673716469676B676E74655648383735343835363A3937353536363636373736
36393D403B3C3335343038373733373A393A3A343A3C3C3A3B3C3A353F424151595B7C9F
B4BBC3BDC0A69D7E7F6E7778968DAEBCD8D7D3C8B4A8B2C3C8D1D6D0CBCDD5D8D1CFD2D1
DCDADDD5D1CED1D8D9D5D2D1C0BEB9BDC4C8D4D4
4E484A4E4A494B494949494B4C4B49464A49474646484B4F484847474848484846444043
4845444C474B4546414A4644474849494948474749474545464747474242434648484644
42444544434343444544413F4247484642424446454242444045434246433E4142474640
40464742403F4245454343484B49494A484341423C4144424245443D3C3C3B3A3D424341
3D3D3D3C3B3B3B3C3B373E4042423C403B4042423D434B424241474441403A3F3D3C3B3B
3C3D3C3C3C3F443B4241443B5B60887C926B61565A61605B667B827A6A5C616069707F86
7D7F6F6C635D5653423F3F3C37383D3D3F3E3C3F403F40414240413D463F404045423A4C
47504B554A4E525C5E5A595353493E494E4650564E57514F4D586B8494A2AFA98E8B7C94
8BAB9CB79B9A606D47557A9FB3B8BBC6C0AEB28E98809B8B99A4D7CDC1A6A1877E9887A3
9A7E9AAF8D5A473840413A3C3C403A443A4C503E4345404C43493F3F3F3A393A3A3B424A
3F3D373C3D383E403E3E3F40403E3D3B3D3F3D3A3A3D3E3D3F3E3C3B3B3B3B3A3D3A383A
3D3E3B384243403F403D3C443B3C3C3C3D3D3D3D3E3C3A3939393A3B3C3E3D3A3A3C3B38
403E3E41403B3A3C3E3C3E42413D3E41353A3E3C3836383B393837383A3D3E3E3633323A
39333A3F3F36363A393A3F403C3C3C3F4242403E3E3B38383A3B3A393637393A39393A3C
3E34333837383A363A393A3D41403C37393C3F3E3B37383A38393B3B3A39393B56493E3C
393539433C3836383837373B3A3D3A383A383436373E413D38383B3D3C3A3A3C3F3F3C38
383F493D353A36383A363A3F3B3A3D3E3E3C393A3B3C3E3D41393E40373B433D3B3B3D3F
4142434440494A463D3D453C3B38393B3B3737393C39393D3F3D3C3E3F3D3B3B3C3D3C3A
383737393D3F3D3A3A3B3E3D3A3A3A353637393B3C3C3B3B40403F3D3E3F42463C414C3A
5B517E768D7FA6849582BCD1CBB0927D6C625542463F383C393B36353B413B3C3A3E353F
3A3937383939383639383839393A39363A373434373A3B3C393836363535353537383B3D
3D3D3D3C47413E3C373839363938393D3D3B3C3F3B393E40424242403C473D3E565A7A92
94A27C8A6579676377757360514B3A373A33383C3B3C3733383736363637383937373736
3637393B3D3A333C3E363B3B3B37393B38393935363B3B393A3E3E39414A5166707290AF
BAACA3907E73605A62707F9DAEC8D2DBD4D3C5BDA895A3AFB6BEC5C9CDD6D9D9D7D8DCD4
DDDDDACFCFCCCED6DCDAD5D4CFCEC6CED6D9DAD5
4F484B4E47474D4D4848494A4B4A47464748494947474D54454444444647474745444143
4745444A45494446424B4745434445444444454649474545464748474645444444444342
45454646464645444242403E414545433F3F4041414143464A4B47454646464842454440
3F43423F404045444446434546454748443E3C3E3C44413C4145413F3F3F3E3D3F434340
3C3D3E3E3E3E3F40413B3D3D3F413E433D444B49403D3F3C4449443E3D3E3F3F4443403D
3C3D4042383C413C4440413E4354596A596F5B70696C666170898E81866B534D44494C53
444F4743414647404343413E393B414541423D3D3C3A4042424544424A4147403B35413D
46363E413F474D4D4C52544B4F394944474F4A66658673967997859998ACA6A394647B7E
A8A3C3B0C29B987C776D6F696A7B90AEB4C7BDD0999D766A719495B8898F5A4845514F5A
948EAD9EAF9C8254403A3E3A3C3D3E38424A69615A554641383A43423C3A3A3B3C3C3F43
3B3D3A3E3E3A3E3D3E3E3E3F403E3C39393C3C3A3A3D3E3D3C3B3939393A3B3C3B3A393A
3C3D3C3C4B483F3A3B3A3D463F3F3F3F3E3D3B3B3E3D3D3F3F3E3E40393A3A38393C3C39
403F3D3E4245433F413F41423E3B3D3D37393B3C3A39393A383B3C3B38373A3C3E393A3C
3733373A484140413C3A3A373A393A3C3F403E3D403D3B3A3C3C3C3B383838393A3B3B3B
3E35383D3A3B3E3939393A3E41413D393A3C3E3F3C38393C393A3D3E3C3A3B3E4C3F3738
3631353E413C3A3C3C393C423D3F3C393B393639343A3D3A37393C3D3B39393C40413E3B
3A3C3F3A3A3D39353C363A3F3B373A3B3B3C37393A393C393B363A3D383A3D373737383A
3D3F3F3E3D484746433F403A403B393B3B3A3D43443D393B3B393A3E3F3C393A3D3E3D3A
3B3B3B3A3B3C3A353A3C3E3E3B3A3A3837383A3C3D3D3C3B40424141474D545B60746B85
7E9AA2AA818380AA89ABA1B67E694F47424044403F3E4F474036383E333C36363437313C
3A393838383737363836383B3A3B3B37333436393B3C3B3A37373838393A3B3C3D3B3D41
4142423E3C37383937393C383D3A393C3D3C3C3E3F383B3B3A384442435A65779F909E93
958A7A6D797676615B5952433638313A4138363634393D3C3F3D3C3C3B3A3B3D3A393837
36363738393A383B3D3D3D393E3A3A3B383A3D3B3C42443F3B3C3F3F43525D6569676D77
6B614F52436D6D92A7B6D2C8D3D2C9B7A09D89887E7488909CA8B5C9D2D8CFC8C4C5CFCF
D4D6D6D9DEDCD6D5D7D4D0D0D1D7D0D9DDDFDDDB
4F4A51554A484D4B4748494948474646454547484745494F4B494848494B4B4A46484544
4643414547494449464E4B4C4344444342434648474543434546474747433F3E41464A4D
464544454747444243444341424444414545444241424547414145484644434042434341
4141403E4142484242473F3C4442434747434040404C44383D3D3A403E40403E3F42413E
3C3E4041403F3F40443C3D3C3D3F3C413C414646423C383D3C463C3C403F474643444543
403F404242424C47443A42435156705B676162675C605F5E667272696352464844454544
39413E3B393C433F393A3C3D3C3B3A3A3C413D3F3E404E535E6B6B6E705C5C444F525950
5A5D645D615A5856565D605B5F4D735D8A6A8E92BBB8B0899B7C806D5F5355554E666188
7CA596C2A5AE7C8E67697A71696C67738A80A585A56F6F4B4159545C656159504A473E48
55495A677B958971614248453B454E5B7B8FBABEB6AF9385615B47393E404141403F3B37
363D3B3D3C393D3A3C3B3A3B3C3B3937393C3B3A3A3D3E3D393939393A3C3F41393A3A3A
39393B3D423F39383D3E40493D3D3E3D3D3B3A393937373A3B39393B38393836383B3A36
3B3E3E3B3E4545403D3C3F3E393B3E3B3D3D3D3C3C3C3B3A36393B3B393A3E423E393A3C
393C3E3D413F41423F403F3838373738393939383B3A3A3A3A3B3B3B3B3938393C3D3C3B
3C353C433D3C3E3839393A3D3F3F3C3938383B3D3B383A3E3A3B3D3E3C38393D3D3A3A3D
3E3D3C3C3F3B3B3E3C383B433E403D3A3D3C3A3D35383A39383B3D3C3B3A3A3C3E3E3B39
3D3D38393B3C3D3A3E383B403B36383A3C3E383C3D3A3E393B3A3B3936373B3C3C3A3939
3A3B3A393D464041463F3C3C3C393B4244403F433D37363C3F3D3F443F3D3B3A3B3E4042
393B3B393A3C3C393A3C3E3E3C3B3B3B3B3B3B3B3C3C3C3C3A424F6D92A5A3A092879F83
A684988591777F757458504A4140373A3C363938433C353E354139393B3F393E383C3A3D
38393939383838393935373938393B373637393A393837373234363636373A3C443E3D3F
3F41413B3A37393B38383832403C3A3C3D3C3C3D443C3D4043496B6F96B7ADC399968680
7F7767675966494242423A38363D384138363A3F3E40423D3837383A39373A403D3B3937
3638393A383A3C37383F3D3A3836393B383A3D3B3A3D3F3C3A3C40433E474D4B4B483F40
40445B669BAEC3C9C5C2B3A68594787F747C808E98A1BAC9D3D2CED5D3D7D0CFCDC6C9CB
C8CAC7D2CCD3D4D4D6D1C9C7CFD8D0D9DBDEDDE0
4C4B585E514A4B464A4C4D4D4B49494A4947484B4A4746494A4845454647474642464544
4645434741413C4240474549464747454446494C45434141434546464A47444344454646
454241424545413D3E414343454949474A494743403F40414641454743464A4641414143
42403F3F3D3F473F414A403A3C38383F43423E3C3B4D443539383644393C3E3D3E403F3C
3D4042413F3D3C3C413A3D3D3E3E383B3E3C3B3D44413B423D483B41453C44413A404748
45403D3D373547463E384D544950554943534A564951595A534A4441413C4142443E443E
3C3A39423F363E45423F3A393C3E3E3D383F3C3D3A3A4A4F5862565965678376A18FA086
A5889585846A636D716F6B6A595B5678608B799F8EA4807855584140423A424040453548
58565D6C80686569705D584E5E7A76796E685A565550444A4E714E64698A95AF856C5D43
4A3B4B49485B778AAA916D746F878CB2C2CED1CAC5C4ADB2898E5C464445433F3F42403B
353D3B3937373D3A403D3B3B3C3C3B39373939383B4042423E3E3D3C3B3B3D3F383A3A38
3535383C3D3D3A3B403D393D38393A3B3B3B3A393B38383B3B393A3D3E3E3C3A3A3C3A36
363D3F3B383A3F413B3B3F3E3B4146414343423F3B39393B3E3F3E3C38383A3D3F373839
3B42423C3A3B3E3E3D4142393C3B3B3A3A393939343536363738393A3E3B38393D3F3D3A
40373B3F37383F3C3A3A3B3C3D3D3A383635373B3B393B3F3A393B3C3934343935393836
373C3A343A37393C3A34373F3E403D3B3E3E3D42373A3A393B3E3F3D3838383A3C3D3C3A
4041393937353F413E383B413C37393C3F423C40413D413C373F43433F39373944413D3A
3A3A38373F473C3D463E393D3E39393F413F42483C383A42443E3A3C40403E3B393C4247
3B3D3C38373A3B393A3C3D3E3D3B3C3E393938393B3E4144556C89A6BBB7A59B877B736D
6E685E564A47484642433C4138423C3D40393C3D3B3F3C4535393A393735313C353B3E38
37393A3A39393A3C3B35363735373A363A3A39373535383B383A3C3B39393C3F483E3B3B
393C3C353C373637363A3E3C433E3A3C3D3C3C3D3E404E677C93CAD5C0ACA1878078866C
775E5C3F3D443338343C383B3638343F3B39383936383E3A3A393A3A3734363C403D3937
37393C3E3E4047403F433C3A3A373A3C393C403E433F3C3C3F4141413E3A3C393E403941
426B8DA6C7AA94707B6D727F758A7B9B8EA3BDCCCCCCD6E3D3D2CED7D0CEC4C5AD9D9394
96A9ACBDC6D0D0CDD3D8DBE0E0E8DCE4E4E3DBDA
50525658544D4C504E4F4F4E4B494A4B4A45474A47474B4C4746474C4C49484A48494A49
474647484744464845474A474042444444474C504A49484747484A4B4B47464948454547
45464747454444444342424243444545454A4F5656473B3F394445414449484841434345
48413E463E42504544404245373F4141434140463F3D3D3F3E3C3F443B3B3A3B3D404345
3B414043403C414040443A3A3E3C3E3D3D423C40434348413D3D3B3A4046443D4046423D
3E3E3A3A3A424846494956474C575C5446404143414B4F484344423C3F3B41463D393B3B
393C3F3E3C3A3C3E3B38393C3B383A3D373B3A3E3D45403D3D47443E3C4F6392879E8495
7D95757D5D60676B69675E4F433D43474846594F4B4A41433E37444B463A44353E363C41
3A473F47404A3E443E577B8E968C737071425851534B4656526E6E766E7B7D958D85835E
57413E433D4855A1B7C6CDD2CECDCFD0D5CAD0C9C9C0BBAF9C906272627E91796D644745
3D373F463741464A4D5048493C363C38393D3B413E463F3C373E3D3F3F3C373B3C39373C
3F3B3A383A383E3E3E413F443C3937383B3D3D3C3D37373A3A3E403B36393C3D3B393A3C
3738393D40413F3D3F3E3A373A40413F3C3D3E3E3D3C3A383B393A3C3C39393B3A383B3D
3C43474138393A3B3B3D3F403939393A3B3B3A383634363B3D3B3C40383A3B3B3938393A
343B3C3B3E3B3A40383E3D3B3B393A403838393A3B3D3E3E3437383735363A3F3C38363A
3B3A393A3D3F403F3D3B3A3A3437393938393B3D453E38373A3C3A363937373A3E403D3A
3C3B37383A383939403D3C3F4244413B37413F3B41443F3C3E45463D373C41403E3E3C3A
39393A3A36373939393A3C3E353637393B3E40413A3B3D3E404141423B454445433F4444
3A3A413D444640403D3A3E423E3F403C3738393D3E3C43535B8DA0AC969E827558464449
4A454B505F677E6C71535141413B38393938383A373B383C3C383B373637393A3B3B3B3B
3D3C3C3D3C393B3F373636373839393835393C3A3735383B36363A3C3935363B3937353A
3135364036353D35373A2F3A323E433C3F3B3D445C7094CADEDDDEC7A1848F948A7F6961
3B373A3B373A3E3B383C3B3B3B3536423E3539363639373E3D33343937383D3C383C3D3A
37383D433B41434E41473C3C383A3B3B3C404548433F3A3D3D3F3B3C383F394244445F6A
6C7F79867D646A708C88A6A8A1A1A89C96A5BDCBCAD3C8D0AD9B976E7E626A5865506066
5E6E6F6F6D7C8A97B0C0D1DFE1DEE5DEE3D4D8C3
4B4B4C4E4B47474A4A4A4A49474646464742454845444646474545484846454844454646
45444547464244454244484642434443424244474545444443434343454343464847484B
414141403F4041423F4041424344444346494B51524842483C4646414446454440434141
44403D423F3F493F413E3D3D3C43444345413F42423E3D3D3D3C3E433F3F3E3E3E3E3E3F
3A3F3D3F3D393F3E3D423C3F4440403F40443F42444448423D3E3F40424545433D42403C
404240413B3C42444B4C5E594A4E4F4A433F3E3D393D403E3B39393737383D3F3937393B
393B3C3C3B3B3D3F3D3936383D403D393A363E36423B48484244453F3D3C374842523D49
3C503F4A413F41414044453E403E444448454F4A474841423F3A3F3E3E36443A453C3E3F
4246403D3B434449526B868E979D928F6B485161646F5A654E68646559625B6665646A53
56464C5151484B7192A0C4CED3D7D6D5D0BEBDBCB1B0A1B6BECBB2B7AEBBCECEC7B88C80
6C3E3C3D4B6E728B9197847F584945423F403C413D4039383C41423F3E3D42493D393537
38393E433A3638363B433E3D393A3B3B3B3B3B3B3E39393B3A3C3D3839393B3C3D3C3A39
3C3C3E404242403E34393C3D3E4142403A3B3C3D3D3B3A3939383A3E3E3B393B3634383A
3B454C4A3D3A38393B3D3D3C3637383A3B3C3C3C3937383B3C3B3B3E36373A3A3A3A3C3D
383E3E3D3F3D3B3F3A3F3E3C3E3C3D423A3A3939393A3B3C33353839393B3F433C38373A
3B3938393C3D3D3D3C3B3A3A383838383A3A3A3A3B3C3C3A3736383B3737383B3E3F3B38
3737393B39393F4245413C3C42433F3C3B52584A414345484145443D383A3D3D413F3C3B
3A3B3C3C3A3B3B3A3838393B353537393B3B3B3A3838393A3B3B3B3B363E393B41414442
474C4B786B7C514C32313639383D403D373A393B403E43525769775B57444945474B4C59
5F7B8484849D8A9D62683D403A36363B3E3E3E40383C393D3D393C3839393A3B3B3A3A39
3B3837383736383C3837363738393837353638383837363638343535383B393C3736373D
3939363938393A373B3D373D383F364440626F81C6CBD6EAE5D2C4A7A5A29C947E64554C
3D393B3B37373834373E3F3D3C38363A3C3538363637343B39353639393A3C3C3A3A3A3B
3C3D3C3B3A363A353C3A3D393B3938393C3F3F3F3B37393B3C3E3F47455764819399AAAB
A4A29492819090ADB9BDB4BBA3C2C5CBC3C4CBC5B19C7D7358564C423F3A49464A3B4E4C
4B4A4E4947545C7180A1BBD6D8DED8E0D1D5D2CB
514F4E4E4E4D4D504C4C4B4A4A4948474A45484C49484A494D4B4A4A4A48484A46474849
4848494B4B47474845474C4A484949484746454549494949484745454745444546454649
474543424344464748494A4A494643414444434648434249424A48434445424245484542
454644444442473F4344413E4145444344403C3C413E3D3E3F3D3D3E414140403F3D3C3B
3F434042403C424144484143463F3F3E41454141424345403B3D4143434143464447443F
403F3B3C423E41414238413E3C3C3D3D3C3C3E403F3D3D3E3D3A3A3C3F4546403D3A3A3D
393A3A3A3A3B3D3E3F3B36363C403E3B40433D4A3C403A43423C403B403B38373F483E41
3E433A42433E3D3A363A3E3B3C414B464E4744444A4C443F41464B45403C4D4754484945
51494A44525D70705D6470777D755B4D5A3F51485F514E4D4C6362676572696B6D6F766B
766E8289866E58566066848B96A4AEC9D6D2D1D6D2D2C1B1BBABB1A5BCC2CDD7D0D0B2B0
8B56443B52727F9AB2BDC0B89C736A55514C423F393C3C3F3D39403B453E41383E3C3D3C
3B3B3C41413C3C383D453D37393B3D3E3C3B3A3A3C38393B3A3C3D383B3A3A3C3F3E3A36
3B3B3B3C3D3C3A38363C413F3D3C3C3B38393A3B3C3B3A3A39383B3F3F3C3A3B3E3C3C38
363B403F403B37373B3D3B383738393A3A3B3C3D3B39393B3B39393B3A3B3C3B3A393939
3A3D3D3C3E3C393B3A3D3A383B39373B3D3C3A3837373839383839393A3B3C3C3B39393B
3B3937373A3A3A3A3B3A39383B373537393A3836383737393A3A39373737383B3E3D3935
39383B38363E3F3741423C393D3B373B414F5248414142444142403C39393A3B44403C3B
3C3D3D3D3B3C3C3A3837383A3A383738393A38373B3B3B3B3B3B3B3B3B3B363B3B3A526C
7B7AAFB0B2755E44393A3B3A383D403B3B413C3A413E3C47444B42453D4B506278727774
98AFB08C81787C57583A433A403C3B3E403E3A38383D3B3F3F3B3D383B3C3C3B3A393838
3D393536353436383938373738393836343435373939363337343935363A34373B393536
39393B3C393D3A393B3A3E414248506F7CAFCCDCEDE8E6E3D8D4D2C6B8B4897B7D706855
44403F3D39393C3A3A42413B3A3A37353936373636363237373B3A393A3A38393A373638
3A3A3939353D2F403341343A413D393838393C3E424D4A76618777928E9FABC5D7DBE0D5
CABEB7969A849392A3AAC3B4D5CAD6C0AE9B8A76695A504F525642573F46454044444552
495A5C666B728F96A29AACB4C7C5D7C4D8C3DBCF
4D4A48494A4A4A4A48474545464644434540424644444746484746454442424241424242
424343434541434340424543414243454544424146454545444343424A49484645444547
46444241424343434647484643403D3B46434142423F3F43464B49434545424140423F3B
3E42423F403E423D3F433F3E4A4947454543403F3C3C3D4042403D3B3F3F3F3F3F3F3E3E
41454245433F43424A4C4242433C3E404042403E3E3F3F3C3B3A3C40403C3D4140444240
42403C3D413E423D3E333735383A3C3C3B3B42493D3A3836373838383943413A3B3B3A3F
3C3A3938393A3C3C3B3D3D3E403B37393F4350545A514D46493F473B3E36413C3E40403C
433D3C40403E4243404245423F4347373F382F3538454A494E565345404257576659584F
5F515B5065626F5F655748434749444143434A4847464754606E6F7B828F898C91909088
938CA7AEC2B4989481898786797A7491A3A194959EBEC8D4C4B9A89C8691929DA0BCBACC
A1917052493F4F4F72697E6B866D96868889827465594C423A3D3342384C44453C3B3F3F
3F3F3B3C3C3A3E3B3D3F39383D3D3C3D3D3D3B393835383C3C3E3F3B3D3C3B3C3D3D3A38
3E3E3E3E3E3D3C3C3F41403C393A39373A3B3B3C3C3B3B3A3B3A3B3E3E3B3A3B37393A37
35383B3A3D3B39393A3A39373B3B3B3A39393A3B39383838383838393C3D3D3C3B393736
3839393A3B393737383936363B3B393B3E3C3937353637383A393838383836343A393A3B
3B39363538373637393A3938393636383937373734383B3C3B3938383737383A3B3B3835
38333938353C3C36353F4243463E3940413C3A3E403D3A3B3F3C3B3B3A3A3B3D46423C3B
3C3D3C3B3A3B3B3A39393A3B403D3938393A3B3A3D3D3C3C3C3C3C3C3F3C3F49434B789B
828C96AA6B5B39403C3F3E39383D3F3B3D4239354142404B4F5C516B627D7A91999B8E8F
7E8C7B6B4E4542363F3A3E393A39393C41413E3B393D3B3F3F3B3D393C3C3B3B3A393938
423D3939393635363B3A39393A3A39373636373839393837353239363A413839393F3C3C
413F4241413F3A3538445462969DBAC7D8DEEBE2E6E3E2D9D1D8DFDFD5C89981847E7263
4D47423D3C40474A41423E38363737353A3A39363837343839423F38393834353235383A
38343438363B383F423938403D3F43474C5566749A89B2A5C9B1C3C0CFDADDE6E8DED0BB
A28C806D669593B4B1C1A3C1A5C19B939D928C85867674706E5762596D5769515F616E6B
7E7E979EACADAEBFACB4B8C6B8C9BBD4C1D9D2D8
4E4D4C4D4E4F4E4B4F4E4C4D4E4E4C4B5149494B494A4D4C4B4C4C4C4A49474548484847
474747464846494B4748494646484A4C4D4B49474A4A484848494A4B4749494745464748
4B4B4B4A4A49484847484949474647494845464746434242434643404242404045454441
42484A46404145403E433F404743403F3F3F3F3D3B3C3C3E4042403E3F3E3D3D3D3E4041
3C413F42413D403D45463E40433D40444041423D3C3D3C3A3D39393D3E3B393B3A3F3F41
44413C3D3D3C3F363C3C43443D3C3A3837373B3E3E403D383B42433E484F4A403F3D3A3C
3F3D3B3939393A3A3F3D393C403C3F4B616771727D7B7463514F615B5F50594C4E48473B
42393F413F3C3F413D3D3E3C3F3F423442494F5A555E6056545A54494A49524C5B54605D
665E70606851533C3E444542434A4D46474D51494443485352524E585A5C575E6C6D777A
8C859EA0AEB1B6C1BECCC3BE978567717773676668607F7A907E827D8590898F8C9B909D
C2CBB5957E656C5F715E735A735D81718DA4B8BAB5A9937C6D60523D3C3B423D3F383A36
383C3636393841403C3B3C47443F3A3A3D3F3D3939373A3D3C3E403C3C3E3E3D3A3A3B3D
3D3D3D3D3D3D3D3E3E3C39373B403F3B3E3E3D3D3D3C3B3B3F3C3C3D3C39393B30363A39
3A3C3C3B373A3C3C3A3838393D3C3A3838393A3B363636353537383838393A3B3C3B3A39
3737383A3939393737393738404342443C3A3836353638393938373739393735383A3B3B
3A383735373635363839383738393B3E3B383B413A3A3B3D3E3C38353938383838383736
3E363F3C3233374256534A46453E3B413E37373C3D393A3D3D3B3A3A3B3A3B3C46413C3A
3B3B3A383B3B3C3A39393A3B3D3B39393A3B3B3A3B3A3939393A3B3B3F3D444942547371
735C654E49374038393C3B383A3F4140373C3B43575F636F7F889284887C879092797461
5C414644393E2E46364A36393B3A393A3C3E3C3A3A3E3B3E3E3B3E3A3B3A3A3A3A3A3A3A
403C3A3C3C3937373D3C3A3A3B3B3A3937393B3A38383B3F3A393D38353A3E464153504E
49403D39453B42486087A2BAE0E1EDE5ECE4ECE6ECE7E3DCD9DEDBD4C5AF957567645556
4A47403C3D41474C423C393937353637373B37373F43484E3B433F37383834363D3B3A38
3431373F3A434053635C6070797C82898E95A4B3C2BAB9D2CBDED4DBDBE2E3E5E3DACDBC
A7A2A38EA794B09C9C8A9482A094A89FABA69D96917B7C74766D627C5F79666B7D9197B0
B1C4C5D1D6CAD8D6DBCBD6D3D3CBD0B8CDB7C9BB
4A4B4B4B4C4D4A464A494848494948475349464643434544444648474646444144434242
42424140434144474343433F43454748474442404341403F3F414344484B4C4845444444
4243444442404141414242403E3F414443414346454545413D403D3B3F403E40413E3F3E
3D4145424547494641463F41423D3C3C3B3E3F3D3E3E3C3A3C41444441403E3C3C3C3E3F
3D403E42423E423F40433E43453B3D414242453F3C3F3B3B403C3A3C3E3D3C3B3A3D3E41
45403B3D4243493D44434445413D36343A3F3C35373C3B373A4446403D3F3C3839393839
403F3E3B3A39393A3B3B363C494E52606C756D77778D80756A6E81828A787863524E4C41
443C3D38474040413E3E41403D3E4C4E63788C908073624B47545C616E737D768071796F
84838C71684D504651524C4945484F4A433A483442363F37413C3A43423E3F4A55587282
988F9B96938FA69BA49E998B8172626C74787E818E614C494148495D5D6F809C9D9F9399
AEAFB4AAA0968F898C8597907F706556597598AABECACDC3B3B0A98074524B40433C413B
3F473F413D3D433E38383B47474039383C3F3E3C3F3C3E403C3D3F3B3B3E3F3E3A393C3F
3A3A3A3939393B3D3B39383A404440393F3F3E3E3D3C3B3B403C3B3B3B39393C373E3F3D
3E3D3937353A3D3D3937393C3C393636383A3C3C34353533343738383838393B3C3B3937
39383B3D3A3B3C393B3D39393E3E3C3E393837363637393A3E3C3A393A3A3836373A3B39
3838383637363535373838383A3C4044403C4049413B373A41413A313938373737373838
3E3D4134364646496C5946403E3B37373C3C3D3A373B3E3B3E3E3D3A3A3A3A38423F3C3A
3B3B39383E3E3D3B393838393436393B3B3A38373D3D3C3B3B3C3D3E413B3E4138414E39
3F363A38353F3F3A3C3D3A383B3B3B3E3C4658748A8D8A8E989A8E7D6F6B6A716A4E394C
4240353C3D37403541333D3937373737393D3F3D3B3E393C3C393E3B39393939393A3A3B
3837373B3C3A38393C3B3A3A3B3B3B39383B3C3A37373D423C3A38393C414E595163514C
4449525A74697B8CACD3DEE9E9EDE9EAE2E8E4E4E2DBD4D5D1BE9F8079615C4A41473D43
3F3F3C393B3B3A3E3C36373C3A37383933424449524C4644393C3B38393A3A3B37333339
3E424B5448655F8A959F95A59A999FAAB3B7BCC3C4B0B8B8D4D6EBE2E6E6E3E0DDD6CDC4
BBB19E947A84706F6C7E7CA788A4859773776B6D706C807D8C6F7C5461628B9DC5CADCD6
E1D8DAD6D2CABCC3B4B6ACAD979C78826879686C
515353515152504C4B4B4B4B4A4A4A4B554B494A47474946474A4B49494B4B4847464546
474746454745484A4646474346484B4B484543434646454444444545474C4D484342413F
414446454242454844464543403F4245403C3F42414345403E3F3C3B4142404347424446
41424645404041423F483D3C45414345434547433E403F3B3C414445403F3E3D3C3C3C3C
3F413D40414045433F423D4344393B404141453E3B3E393B3C3E3E3C3B3E4040383A3B40
45434045484750495149444944423C39414B463A3E41424043484845443E3D3E3D3C3B38
3F40403E3B393A3B3D4C4E4F595954576E6A6E61716E70605A5C605B5F4F4E3B3F414242
444742393F3C4450555A5D5C615E6D768294ADA187705E5055646A73767B81767D6E7B73
666A69534A3E44484A443D44423F423A433E43453B48434441444C5656565F6D6F6A848B
98878378857C95859393958F8C85878F908F9C98927973665B444D474D5E85AEB3B2A593
B9BBC7D5C9B9A8998E78776D4C57464638404F556672868E9DC1BBC8ABAC868B57505343
3D423A3F3D40443D3E453F3A44413C3A3B3D3F40434041413D3D403D3B3C3E3F3E3D3D3C
3E3F3E3D3B3C3F413C3D3D3D40423D363E3E3D3C3C3C3C3C3C3A393B3B393A3D363C3A38
3D3F3C3D3A3B3B3A38383A3C3D393434373B3B3B36373633343739383939393B3B3A3633
3A393D3F39393B393E3F3A3739373335373737373738393A3F3D3B3939383837363A3B38
3638393837373736363638393C3B3E43413D40483C3D3E3D3B3939393738383838383838
33373930486151484C3D3D44423E3A323C3C3D38353B3F393C403F3A393C3C383D3C3C3C
3C3C3C3B3D3E3D3B3938393A33373A3B3A38393A41403E3D3C3C3D3E3E3C3B403B3C433A
3B3C473E3B3A3B3C3B3B3B414848495264677D999F92847E7E7C575E43543E483C36403F
3F333C3F38383B3D3C37383B3D3F3E39373838363B3D383A3A383D3B3938383838393A3A
3837383B3A38383B393838383A3A3A393637383837383B3E3B3C3D586A6B7372596E545A
5A768A9AA19EB2C5DAEDECE8EDE7E4E6DCDFD8CAD9BB8C776C5F57473F3B3F3E3B3D3B39
383B3937393733363734383C3A3C3F3E4E574840423B3A3A3836383C3B3C3D3C3B3A3D44
4541444B4E809AB0D1CACFD2D0CBCCD3D7D4D3D6C4C4B4D2CAE2E0D4D1C8C0B9B0A08D81
746B5B4F4F455A4F615D6752575550625D726E80827C8271727465726397A4C6C9C6C3BD
AEB5A6A69282715A594C4C4A4A4B4438433B4643
4C4E4E4B4A4B4A4745474847454546474D4444474747484645484846464A4B4944434243
454646444743454642434542404447474441414246464646454443424046494743434341
3D4143423F40454B3D3F403F3D3D4144454041424044484342433F3F4546444747404346
403D41423F3E3C42445044403D3A3F423F40423D3B4042403F4142403C3C3D3D3D3D3D3C
3D3E383A3B3C43423D3F393F423B40493E3E433B383C3639373D3F3A373B414343434041
433E3B4148404741493F3C493B403D3539423E313C3B3C3E3E3C3B3C4136373E3E3E3F3B
3D4041403C3A3C3D5D716B564F4D4A4B3F43434A494D423C3A3F3E3A413C47403E423D3F
3F4C463E3F42546B75787670685A60646475958172574943494E454653575A4E58526967
5F6560544F463F403E424043454E5C5374687A5F4E424A4A515A686F6D6E798594849691
97847B70766E7A7572857F857F777C7C756E7B7068766A67514F6857686E96BCC0BFA76F
76909AC2AD8B83626A4D59524A5E504E524B4D474942505B52607184C5CEC2B2B8A89A70
524A3F464249504D596958424141403D3A3A3F43433F41413E3F43413A3A3C3F42413D39
3D3D3C3A38383B3E3C3E3F3D3D3F3D3A3C3B3B3B3B3C3C3D3837383C3D3B3B3D363A3431
383C3B3E3F3C393738393A3B413A343336393937383A383434383A38343536393C3C3A37
39383D3E363538353B3E3A383B3A383B37373738383939393636353537393B3C353A3A37
36383A39373838373536383A3B37383E3F3B3C423C3C3B3B3A3A3A3A3637393939393838
3B373C40575B3C3A42363D443A373D3A3B3A3E3E36384042383F403A393E3F3B393A3C3D
3E3E3E3F3A3B3B3B3A3A3C3D3A3B3C3936373C41403E3C39383838393A423D3A3C3B3A31
38353F38423E3C3C3C3F46586B727B8B95888E998A7160585B50473F453B3738393E3F3B
374241353D3A363C39393638363B3D3A393B3D3C3C3D373838373D3C3939383737383939
3E3C3C3C3A36373A373636363839383735343435373939383F597093957F868869897589
89A4A8AFB8BAC4CED0D4D8D4E4D2E2D9D9C3B9926C5F4141443D433B3F4132363B3B4336
3A3D39363A38363A37363938363F4744414C3F3A3F39393A3A33383F3D3B3C393F3C3A38
35384A6078C2D1E0DEDED9DFE3DCD7D4CBC0BFC4D5CFD6CCD6B7BE938D7B6C6561584942
433F3C453A49474B4C5A5A61698F779678856C70676368555449644F877C988A91807F67
5A584B4644463D3A3D3E3A3D39483C443C433F44
4A4B4B4B4B4A4A4A4645464949484B50474545474B4B4845454144474547484348454343
4344495047474746464545443F4347474645474A474647494846474B4443434342434344
44444546474747484D454143423E424A433F3E4144444446434544414144423C3F404244
444341403B403E42424043413C404343403E3F42414B4D443D3E41413C3B3C3D3B38393D
3E3E3C3E413D3B414142423E3A383A3C3E3E3F3E3D3C3A39363E3F413E393E3B3D414340
404344433D3B3C3E3E3C3D413C383A42433C393B393C3A3E3B3A42393A374042383A4340
3F3D3D3D3C41484B70696453443E3C453E43433C3D43433D3B42433E403E3D4640443F41
3C43403F45484F61645F615547473F414C516E665A493A39404548494F5D64575A5A666D
8266514C494746413E584C4B4D53617B8885958C674F4C535C7F6F76798D7785746F686A
69594C4F5754585D5F646154564C484E504B47494745463F4F414C484E4A696FA8B5BD95
4D5266789E968F829884998BAE909F91A39BA79179726D544A434A6289BBA4AAAEC2BEB2
879F6F6B6F7174759488A5858E736A53454340433D413E3D3D37443737324242403A3D3F
3B403B383D3B383C37403C3D3D3A3F3B38383E3D3E423E42393F3D3D39363F4233373B3D
3C3B3C3D373C3735353942413C323637383F3C3837393D3931353B39393938393B3E4143
383D403F3A37393D3C383739393736363534343537393C3E36383836383D403F373E3D35
3740413833383B3938393937393D403F3B3A3E433F39383C3C38393F383837393B3D3D3D
3F3F454842403E3938393A3C3C3C3C3B353A373539393A403E3A3D3D383A3F3E3C403D41
403C3E3B3C3B3939393A3C3D3838393A3A393A3C403C3A3B3B393A3E3C3F3F3E40413F39
35393C393C38354C45576D81898893AAB187776A5449474D3C4143403F40403E3C38353D
343C3A3737363F3C3C3F393D3B3C413F3633373739383F383638343A373838373636383A
373C37413B313C3739333A383338383536383B3D37413D48806F90857C6C71797D838B84
8284939BA9C2A58E8882A5D1D0CBC9BA926B564D43403C3A3B3D3E3E3D3D39373B3B383A
35343538383534353638373E3A37413B353A383F3639383A3A383839383A3D3D39384339
424E727DB8B1D0CCE2CDDDD2CAC5B9BDB6C9C5D1CBC4B3B28B77584F4B3D3F3C3C3E3742
3D44555773707A7BAC98A7759C6C775B534140463D3A3F3B39414A60605F55514244483C
3D383E3C3A3A40433E3D3E394143444A51566B76
4B4B4D4E4E4E4E4F4B49494B4B494A4D474544464A4D4C4A4945474A484A4C4845444547
474545484847454443444546434445444345494C4A4747484745474B44484A4847474643
4444444444454545403D404546413E3F44404042444342433E3F3F3E404343413F404244
444342403C403D414340433F40424443403F40413A3F3F3A3A3F3E393B3A3B3E3D3B3C40
3E3F3C3D413D3B403D3F413F3C3A3B3D3C3D3D3D3C3B3A393B3F3E42403A3E3D3B3E3F3C
3C3F3F3E3D3D4144423D3A3B3C38383C3D383637393D3B3D3C3F48403B363C3F383B413C
40413F3E4044494E504948413C3D3C43393D3E3B3D4346443E424040414044473F423E3B
39424A505B5F5E61616367597D71665D605D62524C464243474B51565C62615153515758
64524B51555655516071584A464D53626B6A7C795E4E4849536252585664505044444346
4A45434A47464A4B494C4D463E475051483F3E4239373E3E3736453638423D435E706265
607475A9B7ADAEAD9CADAEC9B6BFAFBCBBC1C4C1B4ABA98E865D4F495450534E5A666E81
A8C5C8AFB3A195B7C0C2C6D0C0C7A9BB8CA376834D444445364835393E3C3A413540383F
3A3C36383C3B3F4134393B3E3A3C48423A3D4037363F3A36363A373B3B393F3D3A3B3C3C
3A3939393D413C3D3D3E44423E383D3B363A38383E3D3E3B373A3E3A383838393A3B3C3C
383B3E3D3938393C393635383A39383A3837363637383A3B383B3C3A3A3C3C3A3A3E3D36
373D3C36373B3C3937393938383B3E3E3C3C3E423C38393D3D373639393838393B3C3C3B
3E3E4346413F403C3637393B3C3D3D3D3B3F3D3A3D3C3C413D3B3E3F3A3A3D3B353A383D
3F3D413F383838383A3B3D3E393B3B3A39393A3A3A38383B3C3C3D403A3B3B393B3F403E
3E3A3F373C403C576B777D7C7A777D8A896453493F3B383B3B3F403E3D3E3D3A3937363C
353A39373B393F3C3A3B363936363A3B35363B3B3C373B393A3D393D36383A3C3B3A3938
343333485150594A453C3E3C393C3B403E3736364E6B62676569595C4A52586D625F5F6C
58626E8171785C5464779BB0A88E75614C404041413E3B3A3B3C3D3D3A3C39383D3C393C
3A38383A3A38383A393B393A33323C383A3C363A37403E3D30363B3C3C3B3B3E3E424758
5D7192BBC1CACDDFD0D5CACEBBC2CAD8D7DDC1B49A805F5C47483E3F373F3B403E3C5056
67868FBAB0BC9A9A8C8D73634946383B423A3433363F423D3436364240423D3D37383F3B
3F393E3D3B3A3E3E393F4C514E595D768093A5B3
4D4D4E4E4F4F4F4E47454547484645464C494544444543414643444645474A4646444548
484543434746464545444444454443434446494B4C4947474543464A474A494341434545
46454444444546464B4845444443413F4442414444413F3F3E3C3C40424344453F414244
444342413A3C383D3F3D3F3A43434342414041413C3F3F3D4044423C3D3C3D3F3E3C3D40
3F403D3D403D3A3E3B3D40403D3C3C3D3D3D3D3D3D3C3B3B40403D43423B3E3E3D3D3D3B
3B3D3C3A43424242403C3B3E403E3C3C3C3B39393D403E3C3B434C44453E40433F42443D
484C4640434140483D3B3E3A3C4341443D3E3E3D3C3F444744443E43423D433C49445644
62576F697A7266635E5C615D7A6A675B5D5A554845464746423F424752534E4146464847
554A474D4F4B4742515F4B414046414346424F4E4545434244443E46444F46403D424341
403E3E434240403E3D40413B3E4448433C3A3A3B3A4741443E484841433C42423D414242
49559191B5978E81737D9E8DAB95B1BACCCED6CCC8D4CACCABAF849E88886C75667F8093
93B1BAB9C7C7D8D3DBD1D9E1E6E2E2C0CDADA7A59B80845A4C413D4446404438403E3E3C
3E3C3B3F38333B3B403F43453B3F4C4538383F3E3C3E38383C3E393E3F3B3C363D3C3A39
3A3A39393B3D393E3F3B3E3C3E3B423D36373639413E3E3D3B3E3F3938393B3B3B3A3837
38393A3A38383A3B393535383938393B3938373738393A3B373C3E3D3C3B3A393B3C3A37
383A3A363C3D3C38363839393F40403E3B3736363B38383C3B3634373938393A3C3C3A39
39383C3E39393C393B3B3B3B3A393838393C3B393A38373A3A3A3D3D39383936373A363A
3B393E3B3C3C3B3A3A393838393D3E39373A3A373B3A3A3C3C3A3A3C393B3C3A393A3A39
3A343D37414E4A655D69695D575655544D3D37373C3D393B3D3E3E3D3D3D3B383A3A3A3E
383C3B3B3C3B3E3B383936393936383733353A393F3637383A3B36383A3A3B3C3C3A3735
3F424B5E594F503F433C3D3D3C3835413E47605C6A6C4E4B3C45504E856A84798957554F
53414E404E5657697B817C6259483C3C3C3D3D3B3D3C3A3A3A3B3B3A41423E3B3C383334
3C39393B3B39393C353C3D3D38383F3A363B3A39373F3C3C38413F393B3C414D59688C93
BBB6CFD9E5DBE6CCE0C4D1CBDCDEDDD5C6B99176624F404C46473B383C454147484D6E7F
ACAAB19D9E7D7161474E3E3F323B343D3A3C3732383D3A363536353B3B3E393C3F3D403A
3E3940413E495C696D7581879DA3B6C0D5CEDDDC
504F4F4E4E4D4B4A4A49494B4E4E4C4B504D4B4B4C4C4C4B4C484A4B494B4F4C4D484545
464444454346494B4A47434043434345484847464C494847454345494646464643424447
484746464647494A4E4A423C3C41423F4342434545403E3E444040454643424440414243
4443424143443F444745464043413F3F414242413C4143414041403E413F3F403F3C3B3E
3E413E3C3F3C3A3D3C3E3F3F3D3C3C3D3E3E3E3F3E3E3E3E413E3B44443B3C3C41403E3D
3E3E3D3A44413F3F3D3B3D4241403E3D3D3E3C3A4143423C3841473F474141423D3D3E38
4A504740433E39423D42453A3A46423C42403F3F3D3D424A4144445658545C4F59645472
5F775A56564E494B4B4748484940453F44454A453C3D3E3E3C3A3B3D3F413C363D414243
47403D40413F3E3D39453F4345493E3C3F393F3E3F4948423F3B3D403C3E3F3C353C3F3D
3C3C3A3845403B3A3F4440383D3D3D3E404141413B405A58433F594A4A5641484D636A83
8D88789B806A535F6374576D608D8DB1B7CCB5B9B5B2BDBCBBB4BAA5AB9DB5A0BDB4C195
9993948585B3C1D8CCE7DCDBD3DAB8C8A8B493AA96978E7C5444464F4F4E51454D525355
44363B3E37383C3B39363839353B433C3D373F403C3B383B373B393F413D3E383C393839
3C3D3D3B3937333B3D3739383A393F3C383A383C3E3C3F403C3C3C373B3C3D3E3D3B3938
3838373738393A3A3B3837383836373936363738393B3D3E36393C3C3A3A3B3C39373637
393A3A3A3B3D3B383639393838393A3B3A3937363B38373A393636393939393B3C3B3937
3A373A3A35363A383D3C3B3A39383736363838373635343637383A3A373636353A3B3739
3A383B3840403E3D3A383635373E3E38373B3C373F3D3B3A393838393C3D3C3A38393A3C
433E423E4448414F41494A434143413C373B3C3B3F3D373B3E3D3D3D3F3F3C3939393A3C
3A3B3C3D3A3A3B393838393B3B373837343639373E35373B3A3837373A383737393A3A3A
59595E614B3C433B423B38373B3D45606D5F5D4749483F3E5B7D709E8EA3A2BA8A7B7A8D
595F60616C604B4544464A3A44404045443E38343A3939393A3A39383C3F3C3B3D3B3738
3A3736383836373A373C3C39373839333B3B3A383B3D36383C474545586B7E94A1BDBFD3
D0ECE3E7DBDCD0D5D9DFD8DDDAD0C2A58A735545463A394442403E3F3A37464A52647490
867C715B51403B363A383E3141333834373837373733313435373A3B3D3E3639363A403A
45526A748192ACC2CED6DCDEDCE2D7E7DBDFD9DC
4A49474748474543454545464849474447464545464645444642444542444745504A4646
4645454745474A4C4C49454244434345484947454A484848464344474343495352484447
4646454546484A4B44454340434847414241434645413F404441424647423F4040404142
434242413E3F3A3F413F3F393F3D3C3D404243424043454443444341423F3E40403D3C3E
3E413E3C3E3D3A3C3C3D3D3D3C3D3E403E3D3D3D3D3D3D3D3F3C3943443A3A3943403F3F
403F3D3C3A3B3E41413E3D403D3D3C3B3C3C3B384040413B373E4039424142413C3B3D3B
3F46403C43403D463B43463C465C5748413E3F424140464F50565B71726A6F62665C5A4C
564D4B3E3E424545484A423B413C3E3C3E384039433F3B3B4043413D3B403C3A3B3E3D41
3D3A393B3F40424640413E4641413940443F4342464E4439403E3E3D3D3938393C3F4241
4347443D403E39383F433E373E3B3A3C3B3F50616B8E7E947984758E8AA5778B66785555
50445B54826F88787D7F7D789499A2AAAFAB9D92909B93A197AC827D6A907DA49DB0A8AF
8AB5A0A19197AEA4C8A2B395A88C9D7F95676E6A73899EB2A59D9C987D8A899C93B6B2C2
8B645540323A3A3A3B3938373B403E3A3F3A4040414A463E393F3F43423E403D3B39383A
3E403E3B3C3A363D3F3A3E3D3A373A393C3F393A3A3B42443D3A3B393C3C3C3C3B3B3A3A
3937363638393A3A3C3937383735363A373738383A3B3C3D3939393837373A3D39363537
3939393A383A39373739393633343537393937363737393C3C3A393A3939393B3C3B3836
403D3F3E393A3D3B3737383A3B3B3B3C393A3C3C3A3A3B3B37393A393938383A393B3639
3C3A3E3A3D3D3D3D3C3B3A3A363D3E38373D3E393D3C393737393C3D3B3B3939393C4247
47464140403B3638413F3C3A393B3D3C343E3B383C3B3A3E3B3A3A3C3E3E3C3B38373737
3B3C3C3B3A3B3A3938373A3B39353739373A3D3A39363A403A383C3C363535373C3F4141
433D3F4338343A333C3B3C3C4249536E4741463B3A496769947A999BC6B2CBC3CCAFBEA8
9A8183574D483F3F3F3A3D3F3C3C3C3D3D3A3A3E383838393A3A3937393D3B3A3D3B383B
39373637373637393B3A3834373C3A383B3B3E383A3C3F524B657B92B3C4C9D2D3D2E7DA
E2CFDBD4DADDDED5D9C7B8AFA18F7F6B5A504649463C3D3D3B373E423D3F504D4C53505A
3C4035433442393F393A3A343A34373B3833363A3837393A38383A31363B3A454F63797C
91A9C8D1D9DCDFE3E6E7E7E8E5DFE1D6DBC3C7BC
514F4F505353524F4E4F4E4C4B4C4A474C4B4A49474645444A484A4A46474A484B484749
494645464949494848474747484542424447484847464748474445484441454F50484548
434242424344454645474645474A494441414447464140423F3E3F4243413E3D3F404041
4141414141433E424340413C3C3B3B3D4042434245424143484A47423E3B3B3E403F3F41
3C413E3B3D3D3B3C3B3B3B3B3D3F41433C3B3B3A3A3A3A3A3D3C3941423A3B383F3D3C3E
3E3C3C3D3A393B3E3E3D3F42413F3D3E3F3E3D3C3C393E3A373D3D3A3E3F41413E3E4041
393F3D3C414140463F42433E50695F4B424041434341454B4E565D6E6D636762585A5150
474E4A4B4341403C40433D3F4741464A504A4E444F48403D414440393A403C3C3A3B383E
3F403D3D3E3C3A3D413A3C453B3A35413D393B3A40473E363F3F3A3B43423D3E403D3C3A
3B404039393E3E3B3D3E3C3C3B3C4247433F4A5B604C605072638D82A49DA28C9990A780
7C61678A92AA97AE8FA086AB95B79CAE9093778383747661594555434A4556626B77737A
80878E6D5D5A54585A5869657250514F4A453E474B507D91B8C7CBC19391B9A7BDA4B0A2
B294836244413C3A3C3A3A373D433E3D38354A585A584635383D3B3E3C383E3C3F3D3B3C
3E3F3C383C3D383D3E3C413F3D3939383F4238383A3B43463F3A3D3D3A39393838383939
39383838383939393A3737383736383C39393939393939393E3A38383837373A3B393737
383737363839383637393835363737373736353333363B40403D3A373939393A3B3A3837
3F3D3F3F39393B393638393B3C3C3B3B3A393C3D3A3B3E3E3A3E3D3C3D3C3C3F3D3D383B
3D3B3D383E3E3D3C3B3A3939373B3D39393C3D3B3E3E3A36363A3D3D39393C40413F3E40
3D3E36393B383D3A3F38383B383535353B443F3E413C38353837383C3D3C3B3B3E3B3B3B
4745423E3C3E3A3B38353A393B37393B383A3D3A37373A3C34333C3738393B3E40403E3D
39353940403E3D3836383E3B3D403D423D3D4953566A83717E8091D1BBD1BBC5ACB0A794
4F4C443A3B3A373E433A363D3B3B393839373435383837383A3A39383A3E3C3A3B383639
3B39383A3A38393B363639373B3D363A383A45435666748FB4C4CDD4E2E5DFDDE4D8C2D2
BBD0D5E7DDE9D2D8ACA87E7A6A584B4740403A433D373E3E47474F4A4B5A544E443D4338
39333A3339333B363B3935343B3935373836383B3A3A39323B3D443A4C5F6E879BB4D0D2
DBDCE2DBE6E7E5E4E8E7E3E3DDDECFDBD1D9DAE0
494747494C4D4B494B4D4C4846474745424242434446484A474548484342444246454749
494544454A494745454546474745434344464748464445474645474B4845424144474847
43424242424242424644413E3E40414143434547454140433F403F3E3F413F3D3F3F3F40
404040403D403C3F3F3B3D383C3C3D3F41424342423F3D3E4142403D3C39393D403F3F41
3B403E3A3D3E3C3C3D3C3C3D3D3E3E3E3E3D3C3B3A3A3A3A3C3E393D3E3A3E3B3D3B3C3E
3E3C3C3F3F3C3A3B3A3A3E4449434042423F3E423D353C3C393D3C3E393838383A3A3A39
40424140403E3E40434042404951443740404143434243444A50535751464A5452566C5C
69515546463F40424C514F5B5B5057515047433E4444413D3D3F3F3B3B3E373A393E393F
3C3F3D3B3E3B37393D353C463C403B433C383B3A3F4640403C403C3D3E413B3B3D3A3C3C
3A3E413E3B43423E3F3F3E40424040403D3B414A464B3D454F657582859583857A94827D
9C91998F9C7B7A5A675E75617D5B685E5D4C484B49474A3D4952456057707387637B778B
6E727F786B4A594458678992B48A7D6E5C634E544346476173A0A7A6AEB9C4E2B7B78C7F
747A817C6B5F5545413E433B363C3B3C3B47738E836B524445453E3F3F3D423F44413E3D
3D3D3B39393E3A3B3B3A3F3B3D3B3B3A4143393B3C393D413C3A3D3E3B3A393838383838
393A3A3A3A3939393B3938383634373C39393939393939383D39393C3E3B38373A3A3836
373838363C3C393636393936363637383838393935373B3D3E3C3A37393938383A3A3938
39383B3C37373835393A3C3D3D3B39373836393935373C3B3B403F3E403D3B3E3E3F393C
3E3A3B343E3D3B3937373637393B3C3B3A3A3B3C3D3E3B37373B3E3D3A3A3D42423C3735
3B3A373739393D3C3A373B403C393A383843454B4C45433C3B3A3C3F3F3C3C3E413E3E40
534F463D3B3F3A3C3A363B393D393A3A36383D3B393937383238463C3A3B3D3E3D3A3838
3E3C39383836353A3E3B3D373E4D4639575C6B6E556495B5BCA8A3A7B08D85706352503E
3F3B463C433D36393F3D383A3C3E3A383A393638393837383A3B3A39353938373B3A3A3F
3C3A3A3C3C3A3A3C36363C3A3B3A384846536F7BA8C8D1DEE1E9EBE4E0DDD8D2CABEBFC5
D3D2D8D8DCCABC998C6F654F443F3A423D48424C6E68706875767F7269654E463F363D36
3D393C3C383739353D373835463A3631323637373734394440506D7394AFC2DED9DBE0D6
D4C9C8C3D4DCE1E5EAE6DFDFE1E0E2E2E9E0EAE8
4F4D4B4D4F504D4A4B4E4E4A484A4C4B4C4B494747494C4F4A494C4C4644464344444547
4542444747474646454544444444454647464645464343454545494E494C4841444D4D45
4645454443424140434241414142444644444648454140434445423E3E41413D3E3E3F3F
3F3F3F3F41454144433E413D3D3E3F414242424246474744403E3E413D3A393D3F3E3D3E
3A3F3D393D3F3C3D4140403F3E3C393742413F3E3D3D3D3D3D403A3B3B3B403E3C3B3D40
3F3D3E433F3E3E403E3B3B3E4B423D3F3F3A3B4041353C3D3A3D3B413F3C38383C3D3835
45444544403E3F3E3737424748453D40383A3E41444646464046494845414A6158605961
535A4C4A42485355626A5F615B4D5C4B433D3941394145403A393C3D4343393D3E443E42
3D403D3B3E3D3A3D40373A3F353E393D3C3B434445443B3B384243453C4242443D3C4142
3B383B384044403B41423E3E383C3D3B38393D403B31514772719D85A081935E62617B6A
6F55544942443E4643403E4B41423D44433B41545A5F877E837F6C6D6176A28F9A8A9D97
9F96A5A091494A5B6B9B94AEA58F8590779D71785059433F43456855817FAEC3CABEB7A0
919D9BA8ABA6A1837970746146434240466BABC3AF9C908B7F78665E58504D4546433F3C
3C3C3C3C39413E3D3B3A3F393B3C3E3C43453C403D35363A39393C3C3D3D3C3B3A393938
393B3C3C3A3939393F3C3A3835323438363738393A3A3A3B3836394044403B3837383735
373B3B38403F3A36363939363F3F3D3B383535353A3A393838393A3A39383738393A3A39
38373C3E3A393A3735383B3E3F3D3B393936383934363B3A383F3F3E403B3639383A363B
3F3D3E38383736353637393A3C3C3C3C3B39393B353838373A4044433F3935373838393C
3A373B3A3A3E3B3C3C393B3C373C444445505152493D423F40404245433F3F423B38393E
554F4234373C383C3C383F3D37343637353A41423A3936393A4A5D503435363636373A3C
3A3B37363D3A353C3F3E464C62817A616555678C8A8F9DB89DA777806B504846453D3942
3F3D3C4450463E3B3E413A34343B3C393B39373D3A3838383A3B3B3A393D3A373837363B
3A38393C3C39383A3B3A3F3E434E60838DB3DFD8E7EEE7ECE4E9E8D8C6BDB6AEBBBCB4C7
C7C9C1D0C2AD7E7A5766493B3A3E3D48496F809AB8B9C5B2AD9282626B4638383E3F3643
3936383C373C3F3D3539383D3D3A363E373B393A3C3B568590A6CAC9D8D8CFDBC7AC9483
8B95B2C5D8E1E3E4E7E5E4EAE4E6E2E9E7E4E7E9
494A4C4B4A49494B47474746454547484244464647484B4D434649484442434544444341
454B4A46404444414044474741444542434646433F414447484846454240424648444040
3E3E3F42403D3F443C3D44474342413D474342413F3C3E434A48473C3E48454143434340
3C3B3D41434544414245433E3E38424341453F3D3D43434144403B3F3B3A393A3D3E3D3C
363D44443E3A3B3D36393F43403A3A3F3A3B3B3C3C3B3C3C3935363B3C37373B3A3B3D3E
3F3F3F3F3D403D3C3E39363D3B3B3B3B3E423F3A363C383D414143393D3D3C3A38393B3E
4640403F3B3D403B3C403F3B3F494C47413F3C3D4042403C3F3F3E423E3E4743544C4B4D
4746494743474C4E4F4F5152464447453D3C3F3E363C3F42413A3F5144464D4B403F413B
473F393A3B3A3A3C3F3B37373A3D3D3D3A393B3D3B393C423D40403C3C403F3B3A3A3C3E
3E3E3D3D3B3B3B3B35433E41393C393F373939433E413F574F675E6D5251464B3F424645
3B3C413D40433D453E48413E4245536B534E6076849DB5B8B9BAABAFA49F949C9D959290
827D6C735C79868AA79CA18E967D7A666861514E4144444F5048474342526095A4B6C8CC
CCCEC9BCA19992A1ABA5A59B808272817FB1CECFCBD1C9BABEB7B5A3A4979283936C8A5E
52463D363E39443B3C343C3B393F3C3D413C3A3B3833373E32444F48403C3C3D3A3A3B36
3A393B3D3C393A3E373A3A37373A3A3737393A38393B3A36373B3933343B3B3435343C3B
373431393837393A3835383E34383A38393B3A3635393A3736383A3A3438393736383A39
38383738383A3A3B3B3B393736373B3E3837363536383B3D373B3D3B3A3D3F3F39414848
413B3A3C3A3A3A3B3B3B3A3A3C383C38393F3B3F3A39383A4042403F3C3E3E3C39373738
38393939383837373B3B3B3D3E4143453C3E3E3B38373B3F3E3B3B3D3C393A3F343E3847
685E413F343A40413D3A3B3E3C3C4039383D373438393633343E4A4A343A383C38354142
414A413F3C384A415171749782994C41386297B9B29C908085695F5444413E3C3D3D4445
47564956514A403B3A3D3E3E383B3E3E3C3B3D3F393938393A3B3B3B3538393B383A3A3D
37403C3F353B3D4254596F728492B5E1D8E4E4E7E9EBF0E5E3DACDCCC5BEBCACABB0AEB2
C4CDC4B89B736E594C464344474D6265899FBDC1AEA18C856E67484D3F3A37383938383A
3B3733393C393B3B343738363D353E3D3A39354D7A86B0DEDEE2D9D1DBB2917F617B8D93
B1C2DEE2E5E2E6E4E5E9E5E8D7E1E5E0DCDEDEDA
4C4C4C4B4A4A4A4B4C4D4C4B4A4A4B4D484848484746474847494B4A4746474845454544
474C4C494145454343464745454746454546464542434546464543424341434749474444
45444547464444484543454642444847474443454645494D464549434245414242444440
3D3D3F41404243444545413C3F3940403F4442413C3F3D3C404142493F3E3E3F40403D3B
3C3E3F3F3D3C3D3E3A3B3E41424040413C3C3C3C3B3B3B3C423C3B3F403C3B3F3A3C3D3E
3D3D3C3D40403E3D3D38363A3A3B3A3A3D403E39393C36383B3B3E3637373737383A3D3F
3F393A3A383B3E3B393D3D3B3E42413C4A44414444403E3F3D3E3E423F3D4540433C3D40
3E3F44443F3F3F40404040403E3C3F403D3F454541413F4246403F49454546423D3F423F
3F3B393A3D3F4041393C41464947423D3F39393F3D373942403F3A38393C3C3A3C3B3A38
38393D3F3D3B3E3F3F4C40403C3D39413B3E3A3F36393B4439423841373D3B473F43433D
3A3B3F3B3F4440494D53474E51687B9A7C7C8897A1A8AAA4ACADAA979B929B9E988D837B
7C867E7D91ADB5A8A7837E6E594B52474C4C464B3D3D3A444B49494345395C567A7E9699
9DA3B9C4A17F6D7F969AB5B8C1CCCADACDD0C4A5A39D9889737F798490AFB7C2AFB8B1B0
798E66503F393B3D383E44433E3C3A3F3E3F453F3A353E3D373D4B473B373839383B3D3A
3434383C3D3B3B3E3638373535393A393A3F403C38383A393B3D3D3A3B40403B38343938
383834393132363A3A393C42393C3D3B3A39393733393C3B3A3938353A3C3B38383A3C3B
34353637383B3D3F37383838393A3C3D3A3937363637393A393C3D3A3A3C3D3C373A3D3E
3C383635343538393B3C3D3D3F3B3D3B40453B353537393A3C42423C3738393A3B3C3E40
39393938383838383D3C3B3A3A3B3C3C3A3C3D3B3A393C3E3A393A3C3B393A3E3B423A3D
514A383A363B3F3F3C39393A3B3B403B393D3838383B37353939393D373A34393F3E4341
3636414662556C6982809567755152506B8298A29482796A6B56524C3E3C3C3E373C494E
5058454C3536383B3E3D3A373B3C3C3B39393B3D3435383B3D3C3B3938343A363D363A3B
3644394B51697D80A5B2CFCED1D5E1EDE3EAEAEAE6E6EADEDCD8D7DAD4CABFADB0B4BCCA
D3C4AB9D8F838F867B6F5D5B5E677A7581787769655B4E4C4342323B3A3635383B3B3C3D
353A3B3B39393E3F393934383E363C424457709BCED3DDE8DCD9B4927761709491B4CBDC
E4E7E8E5E1E0E7E5E3E3DBDCD5D2C9BEBAB8AEA2
504E4C4A4A4B4B4C48494948464647484B4A49484847464546464645454445454B4B4946
464746444445464647484643494645454544444644444445444443424341424648464443
4441404243414141403F43454142454347434141414142444644494743423F4641454540
3E404242414040434442403F4740413E3C403E3E3A3F404042414043444341403F3F3F3E
423F3C3A3B3D3E3F3B3A39393B3E3D3A3F3E3D3C3B3C3C3C413B383B3B38383A3B3D3E3D
3B3A3A3B3F3A3B3E3D3B3C3C3A3B3A393C3F3D3849483F3B3A393A353D3C3B3B3C3D3F3F
3F3A39393738393640403F3F3F3E3B39433C3B41413C3C423B3E3E42403D423E46403F40
3C3A3D3E3A39393A3D3F4040403C3D3D393D424244413F41443F3C3F3F423F3A3C3E3E3F
3F403E3D3D3E3E3C414750575750463F3F3C3C3F3E38383C443E3739383C3C413A3A3C38
3A3A3F40423A3C393C493A3D41403A413D403B3D4042473E3B3A373B3A413E473F44443C
3B3C3C383C403F484C554D645A7574898E8F88869097999DA7AEB6A5ACA4A399938C8678
8292938B879490807E605E52473F473D3C3C3D484348484F5555564F5858787281868E91
9B96ACC0A7866C6C8698B2CCCFE1C7DBDCDCC0B4ACBBA89D8B825E53505F688477857783
83B0A57E8A6F706C7F756F4B48403D433D3B41313D353D3B3C37403C3B363738373B3F3D
3A39393A393636393637363435383A3A373B3B3734353636383737383A3B3A393B353736
383B36393435393B3A38393C3737383938363739343A3D3C3B3A37333D3E3B37373B3B39
3A3A3A383636393B3738393A3B3B3A393B3A3938373737373B3D3C3A3A3C3C3838363536
3838353236383A3A3838393A36373A35343A3B3E4A46443E384043383C3B393A3B3C3D3D
3B3A3938383839393B3B3938373636363A3B3C3C3B3A3A393C3C3C3D3A363536393F3A37
3E3D383C3A3C3E3D3B38373737363A37383B383B3931363A36393D3C3B3C32394A4B4239
4449476470786F7965757469636B768B9195918B7D716D627667665D4A4039393B3E4443
4244333838393C3E403F3E3D3A3A393737383A3C3D3D3B3A393B3D3F363B33443B47444D
577F839E9DB6D2D9DFD7DCD4D7E2E8E0E5E2DAD7D5DBE4DEDED8DBDCDAD7CCC2CECFCDCC
C4AE9B96AFB6C1B7A490727057565A4A4C414237433E3D3F413E353C3A38383B3C393839
3A3C3D37363936313B423B3D3C455D72839FBBD1E1D8D4D0B6997965919BBFCEDDE5EFE2
EDDBE5DEE0DFE1D9D1CAC0C0968E7F716B665A4D
524F4C4B4C4C4C4B49494A4947464748494847484A4A49474B4948474849494946464646
46474848464647494A49454248444244444243474242434343444445424141424342403F
454240414343413F40404649454547444B474341403F3D3C484547424043424740454540
3F43454345403E3F403E40444944413E3C3E3E3D3D404343423F3D3D47443F3C3B3D3F41
42403D3B3B3C3E4041423F3A3A3D3D3A403E3C3C3C3D3E3E413C3A3C3D3B393A3C3D3F3E
3C3B3B3D40393B403E3E413D3C3D3C3A3C3E3D393B3A3636393D41413F3E3D3D3E3E3E3E
403D3B3A3A3A3A3848423E3E3D3B3B3D3937383B3C3A3D423D403F42403D423F3D3B3C3F
3E3D40423A3C3F414345484A45403E3C373A3E3C3B3C3E3F3E3C3B3E3640403C3E3D393C
4345433D3B3C3C383E43494D4C47413D393E413E3E41403B3F3C383F3837353D3D3D403B
424754587B7271635D5D464743443E433D423E41524F54404943444245494144393F3F36
383A39373A3D3E454A544F6D576E5B665A6B6F7793A5ACB9CED3CFCFC2BF9D8D7A7C7A64
615E5D53535146404B3F433E433F433C3A3D4452596C7A868A898B847A93A9BEBFBFCACD
D8CECDBCA5A49D919C9EBCB9CAB6A2AEBCC4CBB0C2C9D0C6D5B28F6F65423E4B454F5143
475C6B63A5968AA5A9BCAC8F8C7954423A394542423B3A403F3C38363F3A3B3C3A3C3E3B
3B38353637373B40383837363738393A3D3B38373B403E393C39383A3B38383B3B373A38
383A3638393A3B3B383535363B39393A37313237373B3C3A393A39363B3B3836373A3936
3638393836373B3F3B3A3A3A3B3A38353A3A3938373736363D3D3B3A3C3F3D383C393637
3A3B3A38393B3D3B383536373B3838383635373D503F3835313C474043403B3A3B3B3937
3C3B393838383A3A38383837373737373D3C3B3A3A3A37363C3D3F3E3B363433343A3C3A
3A3E3E3D3C3C3D3C3B3A383738353634393B363B3E3A3C39393D3D403D505B68776C554A
49435749715D605E5D85958F85838D928F8D8687817777738576716451473F3E3D3B3C37
383C343C3C3B393837383A3C3736363637393A3B403F3D3A37373B3E3842464C616B8F93
C3D4D0DDD5E4D4C7C3AEA3A7BBCECEC0BEC0C1CBDCE4E1DBDED5D7D3D4DAD5D6CFDBD5BE
A896867F8389887B65604D503B3A3C3137353B37393942454D3E35353A39393C3B373435
3B363A33363E393A3B3E3E58719BB0ABCCD0D4D4CEBAA18981A0ACC2D0E2E8EDEFECD4D8
CACEC8C7C6BCB0967D6B5B595355545152575A59
504F4D4D4D4D4B49494A4A4948464647474646484A4B4A484C494747494B4A494E4C4B49
464443444746474A4A484542484443454644464A44434343434344444241414142434240
43413E3F4143403D434143444042474644423F3E3F403F3E4745463E3F48444240434441
4043444345403E3F3F3D3F4541403D3E414142424141403F3D3D4041413F3D3B3B3C3E3F
3E40413F3C3B3C3F3F43423B373A3D3D3F3D3B3B3E4041403E3C3C3F403D3B3A3C3D3E3E
3D3E3F40473F40433E3D3E3A3E3F3E3C3C3E3E3B433F3D3A38383738363638393B3C3D3D
3A3A393A3D3F3F40443D3A3C3C38393C3B3F403C3B3F424240444041413D42423F404244
444141443D424646413F4144433E3D3C393C403F383A3D3F4043454337444742413D3A3F
4042403C3B3F403E37393C3F41424241454948424044454341413F483C3A3A47524E4C41
4F5C747C939195867B6A4D4C3F46474C454A474A4D4C584C635D595146483F443B404138
363B3A3B3F3F414648494358486256665F6F7380A6C1C7CECDBCA9A08982635D494E5245
41393E3A3F41413F453D42433F3C3F3F3E43485462727A7D78716E6664756D8F7F999CB7
D2D3C78F6E869F9DA1A19FA89E9A86A29CACA19385A8B2C7BFB2AE9E97715237454A8F6E
7E4F5B6B9C8D8B8795939E847F7B5040453B3D3E403D3642373D363B3E3A3C3E3B3C3C37
3C3937393A3A3B3F3A3A3A3B3B3938383E3C39383D41403B403C3A3B3A36373C3839403B
37383437373838373737393A3A38383B3A36383C373A3B3A3A3C3B3837393837393B3935
3638393836373B3F3D3B39393A3A383739383838383838383E3D3B3A3E413F3A3E3D3B3A
3B3C3E3F383B3D3C3938393B413B383C3A384A5F6D4F403F393A3F3B413D3A3A3C3D3B38
3C3B393838383A3A38383939393A3A3A3C3A3838393A3937373A3D3E3C3B3A39383A3E3D
3B3E3E373D3C3B3B3C3B3A3A3D3837373D3B31373C413E34404A4959608094948D735751
5358525A57604A5B7B9F8D9D768A7F8869686774726261657A6659493E3B363737383A36
3A3A3539333436373838383836363737383838383C3D3C3A37393F44577E7B9F9DC1D6DB
E1E2E8DFC7C18C7C6F7B88A3BEC5B29D96999BB0D3DED3D1C2BDBEBABDC2BDC1C5CAB389
6E6358504E4E4941333D3B3E393A3F3B3F3A3A353C3D444752403B393635383B3B383738
3833403B383D37464D6589B1B7D1E0D3CFD0D0C1A79B9CA2BACBE4DCF2DFE5D1CDBDAF99
93756F5C565252484344444B4A50545351545A5F
4E4D4D4D4D4C4A4948494A4947464546474748494A49484748464545474848474B484849
4A4A4A4C4746464949464444494746484848494C48474544434241414243424244474846
41403E3E4043403C3E3D41423E3F413F3F403F3D3E40403E4243463F424B433C41414142
4241424241414242413E3E403D413D4044424342424142423D3C3D3C393B3E3E3E3C3B3B
3D4043413D3B3C3E373B3D3A36373C3F3E3C3A3C3F4142413B3C3E40403D3B3A3D3C3C3D
3F404242443F3F423F3D3D3D4041403C3C3E3E3B443F413E3D3C383B373A3C3D3B3A3B3C
393A38393D3E3C3D3F3B3B3F413E3C3D3A41413B3A42464342474141413E42433B3F4246
4845454B3D4247453F3B3C3F403D3E3E3A3C403E3E3C3D404750504840494B443F3E4146
3F3F3D3B3C40414139393B3E40414241494544464647515C47443B443A464E6265605F50
5E65797A7F83867C786453543C474C534C504D4F5556626178705E52514C3E433A404442
3F4642434540414247454A4F4E5A53625C5F5C6688A3A39997756E575244444C4644403D
3D3A43443A3D403F3E383B3E4443424640403D42494A4240404147434D3B4746587684AA
BBB6A77765809DA09E9DA8A1B09CADBECDC4BF90817070796B81889293A28057584E6C85
838A659683968FA08B8D84788E8B5B4A4E3F3F3F403D3E42363A3E4039363A3D3B3C3D38
3D3B3C3F3F3B37373B3B3C3E3D393737393C3D3937393A3A413E3C3D3A36363A363A413C
363734373637373536393B3A363536383A39393B34383B3C3E3F3B36373A3B3A3B3C3A36
3A3B3B3A373637393A393737393A3C3C383837373738393A3D3D3B3A3D413F3B3C3C3C3B
393A3C3F3A3C3D3C3A39393A3C38343936395A7A5D42383F3D3737363E3B393A3D3D3B38
3B3A3938383839393A3B3B3B3A3A393838373536393B3B3A373B3E3D3C3C3B393A37393A
393C3D373B3B3A3A3A3B3B3B3A3736373E3C37476852605E546E878D9A9E937866594A4C
665867526950565F78797B787C66675E5D5C5A64604B494F4D413D37373B3637393A3A35
3A36343637383A3C3D3D3C3B38393A39383737373A383536415A798FAAC6D2D7D8DAE3D8
DFC7BA906B68576D739CB7CED9D7C3B2A2999097ADAC958F7675726D6F706C70887E6347
4042424241403E3C363C3B373D3B3A3536353838393634353F3235363837393C3B38393B
44343F373B4D4F69B3B5CCEAE5E4E2CCD8CABFBBBAC8CFDBE6E9E2E5D5C9BCB07D7D686C
505046433E3C403C3B3F3E444042434140404142
4C4C4C4B4A4A4A4B4C4D4E4E4C4A494945474949494847464A494A4A4C4C4B4B4D484648
494746474745454746434447464848464648484748484745444241404546444243464744
454544434548474342414648444343404447464341434341404146414246403E423F3F43
433F3E4241444542403F3E3D3E443D41454141403F3F44453F3D3C383B3D3F403E3D3C3D
4141403F3D3D3D3D3A3B3D3F3E3D3F433E3C3B3C4041403E40434545423F3E3F3D3B3A3B
3F4141413C3C3C3E403D3D414041403C3B3C3C3B3D373C3B3A3A353A3D4143423E3A3A3B
3D3F3B3A3E3C37393D3C3C4042424141383B3B37383E414041474141423D3F413D403F3E
3E39383F3D3E4040403F3F403E3D40403A3A3C3A3E3C3D3E424D4F44444545413C3F4343
413E3C3E3F3F3E3E3A39393A3D3D3B393A383D464A4B576845453D4C4755545F5B5A5F52
5F5C63595F635D565B4B484B444B494C454B47484B4D51596C6D5D5D62564245393B4143
434B4445463F40403F3E524451443E46444B5A6B8193896C5E41493F433D3F494544383B
3B3C413E4845423D3C3D3D3B3C3E3B423B3D3C414244434B4E4B4D496D567E5782778E9F
B59C8B71707681888EA6ADB6B3B3C3CAD2D3D2C4AFA685866D7D7A8493B2A5947E578361
9A68565C5180A1B4B5A7AFAAC2C1A8A4957566495144574951414C373B383B3E3D3F413C
3937393E403E3B3B3B3A3A3D3C393739393E413E3A3B3D3D42434343403D3C3D36383E38
363A363837393836363939363C3C3B3B3C3D3B37373A3C3C3D3F3B36383B3C3A39393836
353638393A3A3B3B38383838383A3C3E393837363638393A3D3D3C3A3B3E3D383A3A3939
39393A3A3A3A3B3B3A3938383A39353D403E494F473B3B44453E3C403C3B3A3B3D3C3936
3939393838383838393A3A3A393837363736373839393838393D3F3C3939383536343639
393A3D3D3A3A39383838393B36353637424E6186B18EA4A5828795928E7F6A4E47515054
4F4C4B515157545F5D64566E50544655515249494639373B3D393C393A3B34343C3C3B34
3D3A3E413C3A37373839383738393A3A39393B3D3B3F44506689B0CBCDD5D4D9C5DAC3CA
93705C5662748AA6AEC6CBD3CAC5B9ABB7977F706A6556534B4D45414240414545423B3A
3D3A3333383C3C3A3F3B39373937373638393C3E3C3A3237403638393C3B3B3D3D3B3D41
463A525774A3B2D2E7E6EEF1E3D6E2E3DBE0E5E9E6ECE3E9DCCCC7B7AF8777574E4E4A46
3D373E373A373C393A3D3B3F413F3E3D3D3E3E3E
4B4B4B4948484A4D47494A49474544444245484949484848454647484949484846413F43
46454445474444464441444943464643424544404646464645444342494945403F42413D
4042413F41444440464242413C3E43433E42433F3E404140424044413F403F46433D3D43
433D3C414447453F3C3E403F3A423B40474345443C3A3E403C3F45434141403E3C3C3F42
47423C3B3D3F3E3D3B37383D3F3C3B3C3F3D3B3D40413F3C3D40423F3B38393A3E3B383A
3E41403E3A3E3C3B3E3A373F3F413F3B393B3B3A443D413E3C3B343A373C41413C393A3D
3D403C3B403F3B3D3A3937373A3E4040413E3B3A3838393B3E464041433D3D3E393D3C3C
3F3C3E483E3B393A3E3F3E3C38393F413B3A3D3B373A3D3A3740453E413D3D3C393E413A
3F3A3A3F42403E3E3D3B3A3C404242403E4248494540434A4C5559736E6E534944444D42
534E5346464C444657484D4D504F423F37403E3E46443C43505D5565706352584B464646
3B433E414540454559546B4D654F515C64667173717C775A523E414E464D383D3F473D44
3E403E373A393935353A3A37383C39413C42485365788EA3A08673646D8C80996D816479
675354525D5D718E9CBAC3B8B2A7C1B4C0C5D5CDD6DCC8C2C5BCB6B5D1CBCCD19E836E55
63695D7B80ACB7CECBC7C2BEB9B6B4C6B6A3A1799980A287A6808B5A413E404240434541
403B383A3B39393B3B38383B3B38383B34373838393C3C383A3D40403E3B383737363934
363D393934373837383A3936373A3D414952524D3D3D3B383A3C3C38373A3B3734343433
38393A3A3A393736383A3A3A38383A3C3A3937363637393A3C3D3C39393B3A363B393738
3A3B3836333435383B3C3D3D343E3E42413B3C3439393C404039373D3738393C3E3D3B39
3839393938383737363637383837373638393A3A39373432353A3C39383A39373635393D
3C383A3E393938363535373938393A3B4D6894CFBDBAC3BDAB7E55664B4B524A47504C4A
4D4B534B5A5C665E534B4B4343373E41484C3F3A3C393B3B3A383A35353A3A403B3B3A32
3A313534383736373A3B383534373939393B40454C5C71828E98A4ACA898A0948085585E
47485984A59EB6C0CBC5B7BFAEA08C7475534B473E42413E3941393B3D363838383A3837
3836373F363C38313E34353B3B3B3D3E3D3B3938363935424B403D3A39383A3D3F41464C
717DAFBBCDE8DCEBE8E7E2DFE7E1EAE9F2F0E8E5E6EDD3CDB39C7C5B463D483F3B3E363F
3540413B3C383A36373C3B3F3939393838393C3F
4E4E4E4D4D4C4C4B4B4C4D4D4D4D4C4B494848494C4D4D4C484444494D4C494943454846
434244474A4D4C47444548484947464745424348454647454242444744454443464C4D4A
46454444444546464F4B4541414345464245474542424548414345454341404041403E3E
3F42454748413E3D3D44473F4041403F3E3F43463E40413F3D3E42453B3F413F3F403F3C
3938393D42433F3B383D3D3E423C3942403D3E4446433E3C3B3C40423F3A3A3D383D413E
3D3E3E3C40443A3E42393B3D44423E3A393C41453C3A3B3F3F3C3C403E3A3F3E41443D3D
413A3B3F404445403C3D3D3C3C3D404244443F40443F393D3E3E3E3E3F3F3F3F383D403E
3936373A3C3E3C393A4042413A3E3E3937393A3938373A3D3C38393D3B383A41413C3A3E
3D3C3A3A3D3F3D3A383D383A3B3B433F39444C454F4D4C4557616776776961553E494C48
48453F3D3E3D4044413A3A4044403C3A36353A403C3F464B46414854484D4F4C47434344
3D42435C5B6456554E4D595D4C41506255595A5655565450474442413D393B42453C3A3F
413D3C3E3B3C3D3D393C393D404447554B6C739696ACB3C1BCA59375716260574C4A4747
3E4F565D60626960645957504E5457646C8A91AFA6B7B0AFB1BBB1C5CAD2DDD9CB805438
47474B5C719CC6C0DDD4D9BBB29A92A681746F77728C707973777A9B7B845D3F45443F40
3736393C3733353A393A39383838373735373A3A3A3A37393A37393B3C3D3936323A3436
3C3A3A353A343C3F3B3A39403949577B917C5A473E3C37363F413B3D353A3939393B3E3B
393A3F3C35373A343938373433353A3E34353637383939393738393A3C3C3A3634373A3D
3D3B39383838393A3B3B3A3A383F44413B39393938403D35373B3D3F3A3B3B3C3C3C3B3B
363B3936383533373A38353435363636353C3E393434373839403B393D37354341423734
34353E3A374235383D3A3F3643333E627488A5AAA3B39C7F71524E3F3C3B4A5A44464C4B
4B5479696860735941403F3E3C3A3938393B3D3C3A383839363A38363939383C36353C39
3A3E383C3A3C3B3D403A353A39383946494D5B758A879C8D857F6A5C545A4A4B473E4742
5F7C98BAC3C5C9C9C2A3887B6E5F50433D3D3D3E3E3E3E3E3E3F3F3E3A383838343E333B
383837383B363F363635363B35373835393E3B37383D373C3C3E403B3A474E54607A93B2
BFCFDCE0D0E3E6EFE2E4E2E8E9EEEBEFE9EFE2E0CFAC93734847443F3B3A3A3C38383939
3A3A3A3B37383A3B3B3B3B3B31383C3A37393D3E
4C4B4B4A494948484444444545454544464646484B4D4D4D4946464A4C49474744464746
4443444645444342464C4D4A44424243413F424647464544444443424142413F42474846
45464645444445464241404141413F3D3E4041403E3E404242424343424446493F3E3F3F
41434647413C3B3C3E4547403D3E3E3E3E3E3F403D3F40403E3E4042393B3A37373A3C3B
3B3A3B3D40403F3E3D3D3C3D3E3C3C42403D3C4042403D3C3A3C3F413E3A3A3D383C3E3D
3D3E3E3C373D3940433A38383C3B3A38383A3F423D3E40403C39393C3A3A41404040393A
3E3B3E403E3F423F393A3B3A3A3B3D3F42413E3E433F3B3F3838393B3D3E3F40393D3F3E
3A38393B3A3C3B39393B3B393B3E3F3B393A3B3A3B3B3D3E3C3A3B3D433D3A3D3C38373C
42403E3D3C3C3E41474E4744464A514A464B4D424641484D4E4F4B53565254513F423F3A
3D3E3E41403B3B41413B383A3A393C42433F39373A393C423F39393F403F4144423D3C3F
3B3B3746454D474A443F3E3E38373F4842424345474645453E3E3F3E3B393C413B3A3C3D
36363C3F384142383932433E64587C6789788A8B9A95817763505348413D474842424144
3D444442424449463F3D423F404644484049404F48515052526C79A1BED3D6C49A77546B
6384728D728F97B8C3DBD8D9CFBBA58C5246445B7B655D4A434D4D5F5F96A1836D51383E
3C37373A36393B3C393D3E3C3D3F3F3E3836383B3B393A3F3834383B3B3F413F3B3E3E3E
3F37323C39353D3C373C3F45517C87917B76493C393C3A393D3B35373D3D393434383C3B
39393C3C373A3D3B3A3B3D3E3D3C3D3E3A3A3A3A3B3B3B3B3938383A3A393838383A3D3E
3E3C3A393937393F413F3D3D373D413F3C3C3D3C3D443F383A3E3C3B38393A3C3E404141
373C3A383A3735393B393636383A3B3C363B3D3834353737414036323938353A393D3B39
38393D3C39373D373A3E3843394869888B94A8A39A895D47483E4142383C4E5E4A4A4942
494D6659595059403B3B3B3B3B3B3B3C383A3C3C3B393939343938393E3D3B3E3A3A3D39
36373A433C393A3834394140444D549C8FAD9DAE95999489625C47434237473D42495E6C
8E9CBBC2D3C6BBA88D70574D45413E3B3D3D3C3C3C3D3D3D383939393A3B3D3F353E383C
3838363B3139383B2F413537363A403D36363E443B3B38454E4C5A5C687E7E9DA1B9C9D8
D1BDC6B2CED4EBE6E6E4EBE1EBE5EADEE2DABAA17B544B403A3A3A3A393B3D3F39393939
39393939353638393B3C3C3D393F43403C3B3B3A
504F4F4E4D4C4B4B4B4B4B4B4B4B4C4C4A494848484847464A48484B4A47454646464645
444444444747444244484744464545454545474B494644444646423F4646444344484948
4547484745444446414244464746423F4848474746474748414243444445484A46454443
41403F3E3E3C3D3E41474741414142434443413F3D3E3F3F3E3D3D3D3E3E3D3B3C3F4140
3C3E3F3F3E3D3F4047413F403F414546413C3A3C3E3C3B3B3A3A3D3F3D393A3D393A3B3C
3D3F3E3B3A403F44463F3D3C3C3C3C3C3B3D40423C4143403B393A3A3B3B413E3D3D383A
3A3C42423C3C403F3A3B3C3B3A39393A403E3C3D403E3C40414141403F3E3E3E3B3D3E3E
3C3B3C3D4242403D3B3C3B3A3B3E3F3D3C3C3B3A3E40403D3C3C3D3C403A373A3C39393D
3D3B3B3C3B3B424B4D534C45474F544A4D4B4940463D404548443F4448474A493E3D3837
3B3A393F443C383D413D37353A3A3D43433E3A393D38383D3E3A383A3B36383F403A393E
3F3C373B3A3F404441413F404444413F413B3A3E3F3B383A3A3E403D393A3E413B3F4449
4344423E3E31354239484B70646660715F7D6D81645B4E545250606182716552413C3A3F
3D3E413F40413E403C3D3F3B3D4442423F43424F4E4B535A778691B6CCD1C8B4B795AA8B
AC8B979296939D9DBBA9B3AB9E969082666F6E8B6D6B525A5D8B7AA56D7A9AA4A3A0723C
3F3A353A3D453F36393A3C3D3A3839393C38383D403E3C38423C3A3C3C3E3E3835373E3E
3D383E62503E3C3A35373A4160777E4F44413F3B3A3F3D3A3A393A3D353539363A3C3D3C
3F3B3C3D39383A3A36383A3A3A3838383F3E3D3B3B3B3C3C3D39383A3A37383D3D3E3E3F
3E3D3B3A3D38373C3F3D3937393D3F3D3C3D3E3C3E433E383D413C383A3B3B3C3D3D3E3E
373A39383937363A3E3C39393A3C3D3D36393A37353636363E3B3534393C3936363A3E39
373938393B384038383E4460657C9DB0A49789695D50393940403E494E4E5359474D504B
4C474B40423E41343B3A3A393938383837393B3B3B3A3939373A38373B39373A3833313A
3D3B3A373B3A3B3A3C495554745F90B9DAC2BD9E97837151493840353C4242575D906A9A
95AFC2D0B5B184765E4C403E3B3B3D3C3C3C3B3A3A3A3B3C3C3A383738393A3B393A3635
3336323A3B363F2F3A353A39383439413D3B3F403E526A82A3A2BAB1C0A0978998A8A5A3
939194B1C0E9ECF2E9E7D9E4D5E7D3C2AD97705D4733383B363739383838393B3A3A3A39
3838383737373738393A3B3B3A3D3F3C3A393837
4D4C4C4B4948484747464544434344444A494747474645434948494B4A46444647464545
464544434246474442444748434344454545454648464444454544424443424141434444
45484A49464344454342424244444342413F3E3E3F403F3E404346474543424144434342
424242413F4042424446453F3D3C3C3D3E3D3A373F3E3D3D3D3C3B3B3B3C3D3F40413F3D
3C4043413D3B3D40463C3B3C393E423F413C393C3E3C3A3B3A393B3D3C393A3E3A39393A
3D3F3D3A3D3F3D3D3C3A3B3D4141403E3D3D3F403B3F413F3F41403C413C3F3C3C403B3E
3A3C42423D3E413E3F3F403F3D3A38373E3C3B3D3E3C3C3F3B3C3D3D3C3C3D3E3C3D3D3E
3E3E3E3E44423E393738393A3A3C3E3E3E3D3B393E41403B393C3D3A3A36363C3E3C3B3B
403C3C3E3D393C43494B4640424849413E3C3F4358554E45494542474A4846444640393C
403B393F463F3B3E413E38363D3F43423C373A4046403D3F403E3D3F3C3B3D41403C3D41
403F3E3E3F3F4041383D3A393E3D3B413F3A393D414140403E44453F3A3C41423A3C373C
3A3E3C433F413D3C4C425D57726A8C6C7D6370718882747C888A8D8A6F5D514643464449
4440413C3E413B43494644424346434159587881A0808E87858F9BBBCCCAC3B6A0987D86
6D897F968392758B6D7758594B4243494149404E565261657C86A5A7BDA0A0AEBECEAD6F
6A5E42353A4138323E3B3E433F3B3D403B3B3A3D3D40453F3C3E393B3D3B3B39383A3D3C
3D40598889553B3A3D3F3B3D434E473A34413A3D383D3A39393A3F3E3D3A423C403B3632
3936363A3936383B4846423D3A3838383D3C3A3938393A3B3F39383C3A373B443F3E3D3D
3C3B3A383D3B37363B403E383D3F3E3B3A3C3C393A3E3A373F433D373B3B3A3939383838
3536363635353638403E3C3B3B3A3938373837363636363538383938393D3F3D3A393E37
363D3A3D393E35363F4D6F899C9B988E705A4F393C4040413B444A647770615540474A48
46403A363939383739393838373636353838393939393A3A3B3D3936383735393C3A3740
3F39403E3838353D526570786D6B76BCA4B48E7E58513F3F3C444543594E9A6689708993
BFBDCAA193685E4E433C3D413D3B3A383C3B39383738393A3F3C38373737363538343635
3A3E353C393A383C37383541433F444D484C64708DBBAFD7BEDCC7BA9F9361664E637579
B5BCD2D8DFEBEFECE9D9E0C2B897947666533A393D3A3E3C3A3B3C3B3937373739393938
383838373A39383736363737373736353537393B
4C4C4B4A4A4948484F4E4C4A4948484844434345474949484746484A4A47464748464545
474746444347494643454748444647484848464445464644434346484443434342414243
45484A4946434445464442414243444447454343444544433F414445433F3D3C44434241
414243433D4142414343413D454342424242403E403F3D3B3B3B3B3C3D3D3D4041413F3D
3B4044433E3A3B3E453D3C3D3B3F413B403C3B3E403E3B3B3A393A3C3C3A3C3F3C39373A
3D3E3C3A3E3C3D3A383B3E41403F3E3B3A3A3C3E3C3E3E3E4347433C433C3D3D41463F3E
3B3B3E3F3F44443C3D3E3E3F3E3C39373E3B3C3E3C3A3B3D3B3D3E3D3C3B3C3D3E3D3D3D
3F40403F42403E3D3B3A3B3B3A3A3C3E3E3C3A383D3F3D38383B3B383C39393C3D3B3A3A
3E3B3D4448474646484442424344403F3C3D40445F61564347403E3F414241434C43393C
413D3D4645424142413E3C3C3A3E44454039393E484645433F3A393B3B4245403B3C3E3F
393B3D3D3D3E3D3D3C3F4042443D3B453D3C3A3A3E43433F4045453F3B3E4344464C454D
4B4B4D68694A48656873637F6E8981A46D8E637A7676625A635F554F4D44434246484244
3F3D40404F5D6273867A717578757577636A74A6B4B5A49E969794959A9790805D52674C
624A554B3E4D484A4543413F403A3C453D44484C526260846F89878B89918387A2ADB4C2
BFAA7545403A38423F3D3F3D373C423F3B3E414840373D393E493E3C3F37383E383C383B
393645588B5A413C3839393A3F3C30393E3E3A3A3A3F3A3C3D3D41393C354039413F3D3C
3E3C3C3E3E39393E544F48403B3837373A39383738393B3C403A393C3C393E473E3C3A3A
3A393836373C3B37404D4B3F3C3D3C393A3C3C393A3F3C3941453E373939383838393A3B
37363737353538393C3B3A3B3B39363438373637373736363B39393836393E3F413E413A
3A403C3E36404457768D9BA09F8367584339474C52473E383346567A726F60554345403C
3839393D3E3B363934343536373839393A38373637393A3B393D3C393B39383D403C3841
42445353574F4852605D54534D485F636150514343403B4555727C8576A993A57BA482B6
A3986F6C4A4B3C403D383A3C373536353A3938373738393A38373637393A393838353937
3B39323B2F474C4C484F4D4F444B5057556593B0CAD6E3CCCEA09A7560495B668FB8CAD2
DADEE6E1DDE7E0D6CDB998905D58433E3D3B35383B3A3A3537393B3B3A39393937373738
383838393A393836363536363838373737373A3C
4E4E4E4D4D4D4C4C4B4A4947454443434444444548494948474546494A48474848474646
484948464949474546494742484A4B4C4D4D4A46434647464444474B4746474847444446
4547484745444446474544444546464545434141424241403F4041413F3E3F4047464441
403F3F403A3F403D3F3F3D3D403F3D3C3C3C3C3B41403E3C3A3B3C3E443F3C3E40404040
3A3E43423E3A3A3B464342424244433C3F3C3C4143403D3C3C39393C3D3C3E423D39383A
3D3D3B3A3B3B413E3B4143453E3E3E3C3B3C3F413F3E3D3F4446413A3F3A3E4045483E3A
3C3A3B3C3F46463B3738393B3D3D3B3A3C393C3F3C3A3B3C424343413D3A3A3C3E3E3D3E
3E3F40403E3E404444403E3E3A393A3E3F3C39393C3C3B393A3C3C3A3D3B3939393B3E41
4948494C4E4D4741453E404143413C3F4446453B4A4B46393C37393A3C3E3C41433E393E
44403D4443434342403E3E403B3A3D42433F3D3D41444747423C3A3A363F423A36393C39
373A383A373D3C3C3B3A3C43443C36393F403D383A40403B3D3F3F3C3B3E42444E534F62
61615E796153484F6B66796F846F8A5267404D424049423B42433E3E39373A393B3C3943
37485B6D869497A1979296AFBEBAB9B8B7A1AE94B27F866B65584D48504C49404040403D
3E40404036424047433E3C3F3C3F454A434A524C4D4E5A48605C5C65697E808FA19EAAC0
CBC5A97A714D3D3E3D41433D415E716A6B615B696353554A484C3C44565758554D463B40
42424B4546363B3D3B484B423C353834442E3D393B3E3436373B463C3E344138423B3635
3B3E3D3C3B37383E413F3C3A39383736393939393B3C3E3F3F3B393C3D3B3F453C3A3838
3A3A3835333B3C3A424D4738383A3A38393D3D3B3D44413D42443D383E3D3C3A3A3A3B3B
3C3A3B3B37393C3C373738393B3A383638363638383736373B3A393B3C38353735393F3D
3E43444547445F6F94AD8D825E47373D3C3F5868865D3F38393D3E514C504A4A42443A3A
3537393C3C38373B36363637373738383B38363536383A3A353C3C3A3936363C3D435671
818D948B755847484744424147464245383E3C3B34476F81A7A9A495AA9EA0778367836F
70584B3E4D3641363E3A3D3E39393B393938383738393A3B363637383A3B3B3A39373934
3B3D495C6080845D605F66534D4635456D98C2CBB4AD8F9D73654A52658593C6C9DDE3E3
E4D7E1D5E5D7BF978D65553E443440373438393A3A3B3B38343638393837373836363637
38383839363636363737383839393A3A38353538
4A4A4A4A4A4A4A4A49494948484645454847464748484746484545494B49464647474748
494A4A4944444444474B4A4644464645474A494545464848484747474242454846414042
454646454444454644424040424445454443424141414040404243434241414241414141
424242423D44423D3E3D3B3D43434241404040413F40403E3C3B3D3F423C393B3D3C3B3C
3B3D3F3F3D3B3A3A3E413F3C3F403B373E3B3C4043413E3E3D3A3A3C3E3E40443F3B393B
3D3B3A3B3937403B363D3E3F3E3F3F3F3E3E3F403D3C3E4143403D3B3C393E3D3F413A3B
3C3A3B3A3B4344393838393B3D3E3D3B39373C413D3B3D3C393B3D3C39383A3D3F3F3E3E
3E3E40413737393D3E3B3A3B3C3A3A3E403D3B3B3D3B3B3E403F3F3F3C3D3C3A393B4044
43474947484A48423F3A3E3C3D3F3A3E3B3F3F343C393C3B38353D3E3E3F393F3A3A3A40
46403A3D3F3F3F3E3E3F3F3F3F3B393C3F3F3F403C3F4242413F3D3D373A3A37383C3C39
3B3F383C353F3A3C423D3C3C3C3E42423C3B3A393B3F42433D3C3C3E3E3D3E40423F3D54
4E55525F6250536B6D6C5D6D565046423547373E3C3C3D3B3A3C3E3F3D3D403C3E3E3C48
5C737C828981756F7B8598BED2CABEAF8E906E714C4F3D3E45393B404C43414044424C3E
483A413A3F423F494F453E3B42434846444745454646495C567176767F86A2BFC8CDD5D2
BEAFA6838C6A655D4341474E6393BABFB9AC9B9C9288877079756C82989D9D8871574842
383C474143383F42485F5D45434440483F3E383B37403D454850645B7D6C766265544742
3D434039363638403938383A3C3E3E3D39393A3B3C3D3E3F3E3B3A3A3B3C3D3E3B3A393A
3D3D3B38393B3A393D413B3135383938383B3C3A3A42413C3E403B38403F3D3B3A3A3A3B
3F3C3E3D38393E3C393838393A3B3B3A38363739393637393739393E423A39463E494D4A
44444E5469575E555F66413D3A3A3A403E47667877513A363D39353A3D413A3D39393036
3935383636343A3C3A3A3938373636353A38363637383837343B3A363639414E64708C97
8F8D8475604C4243403D3E3C4A3E3637343B403F638FA5C3C2C8B3A6878F6F6550433E46
4540323E373F383C39373A3D3A3B3B3737373838393A3B3B393A3A3939393A3A3A38383D
50556A796B8165513C433C39415A658AB9C4B089725E48534E647192B2AFBAC4DAE6DCDB
D7CBB7C4A9A46B5046413641363E373C3A35333437373535373839383635353637373737
3737373735363637383838383837383937373C43
4C4C4C4D4D4E4E4E4A4B4C4C4C4C4B4A46454547494A4A49494544484B49464547474848
494A4B4B474B4B474342424146474644474C4D4A4746474A4C4B46424445494D4B454346
46454444444546464B474342454A4E504544434241414141414448494744414044444444
423F3D3B464C48403F3D3A3D3F4041413F3E3F403D4042413E3C3D3F45413F4345423E3D
3D3C3C3C3B3B3A3A3D433F3B403F39383E3A3A3F42413F3F3E3B3A3C3E3F4245403C3A3C
3D3A393B423E453D353D3E3F3A3C3D3D3A38373738393E42403B3A3E3C3A3E383437373E
3B3B3C39383F41373E3D3D3E3F3F3D3B37343C423E3C3F3E3F4142403B39393B3F3F3F3E
3D3D3F413D39383A3B3B3E423E3B3B3F413E3C3D3F3B3C41444341433F4243403B393A3C
3D45463E3A3E3F3B3C3B403939413D3F3A3C403A3F36383B3C39403E3C3C383F3E3E3B3B
3F3D393D3D3B3A3A3D3F3E3C3E3D3F403D3A3B3F403D3A37383939383C3735393F42413F
3C41383E33403737393B3F3E3A424A45403B393A3A383A40413D3E42423D3A3B4347536C
575D58574C4B4F57544240423F3B3F39394235343D333F4A4546463F3F3B3B3C49545969
586B635D625F616082858595998A78635454493E3E3E47413E3B423C413E42434A484F46
5452696C7D736F687F6D6A58524D524E57636B89749797AFC9BFD1C7CCD0DDDDDBDBD6DC
C3A29D87A4929D8C836A5B5658708D97A2B8BFC2B7B6B897AFA9A4AFA391886566515C5D
4A494C484E40433E405E706A948A968A896B53413F5563787F86988D85717A666F666163
686D624F443E3C42413E3B3A3B3D3D3C3738393A3B3C3C3C3D3C3A393A3B3A373C3A3A3C
40413E3B423C37393C3C3B3A363A3B3837393937323C3D383A3B393838383737393B3D3F
3F3B3D3C36383C3B3F3D3A393A3B3B3B3836373A3936373B383C38383C394769727D7462
483A454B413E3B3A3D39363E363B3735364357583F3536343A34383A383B333937362F39
3732393739353C3638383838393939393938373839393634363A383439465C71A69EA08B
70675440444745464942393A4034363835394B548DACB5BAC3AF9D79624D3F43413B3B38
3A343A33393B38383A353638373B3D39363738393A3B3C3C3A3A3A3938393C3E3F3C3A48
5F575A544845393B4738435373AFC3C1B39175586A707B8891AFACB5ACB5B0C5D1DBCECC
BF9E907463473E3B3C3B3B363B3939383E3534383935343A373839393838393A38383737
3636363537383838383736353A3837393A3F4D5A
52484E425348514B46484948464648494C4B47434346474543413F404345474747444447
4744444844444343474B4A46414546434345433F3F46494642434442424446484745423F
3F424544424244474A424146433A3D483F4547423D3D404241454746423F3F413F40403D
3E41413F414141403F3D3C3C3E4047463D3B42444043423E3D4042414442424546434141
3D3C40413A393C39393A3C3D3A383D444138353A3C393B423D383E3F3B47373D3B3B3A38
36373A3E3A413F3D38353D3D393B3D3B373537393938393B3834363C3B3D3C3A3A3C3A36
3738393A3A3A393839353A3F3E40423D393A3C3C3C3E4144454A3E393B393D3E3F444039
393A3F483C373A3F3C3A3C3B3C3A3E413E3E3E3A3F454A48424149514B464343423F3C3D
3940403C3F3E3938383E403D3D4245443E3A393A3936373A353C3F3D3E42403A38393E44
433E3C3E35393E3D3A3A3D423840433C393E424137343D3C383B3A3C3836373C3E3C3939
3C3E40413F3C37343A393B3E3F3C3B3E3D373E423E46515050484B435345494841485666
57544D43424141403C3A40473B3E3E4639453944413F474D4B47484D50515A574A505F5F
5B5B5F63635F5F62635A5B594C42434B43483D3E3E403F463C4849505366696E656E7D80
7D90ADBBC5B4ABB4D3CBCBA1978D999DACC7CCD2D1D5DCD6D6C9C9C3C4D1CFCED1CDCDCA
BCC2C0CFCFCED3D4D7B66E4E4347546D7686949CABBBBB8F7D848DA7A75A493C403B494B
517F8D9791806D55498888ABB6D2C8D0B28B51474A494E605E767882A389A880947F9A91
ACAA9E9D8E6A6741423C383A3A35353D3D3C3B39393A3B3C3E3D403E373941453B413B40
46404438353D413B363739383338383B3637433D3B3B3B3F353E3C38403834383D3D3937
383938393B3A37363B3C3C3D3D3D3D3D373A353C3B353B393D3137433F4E6A7F7E6D5542
3A38383835383E413E3B3B3E3A3B41423D3D403E363738393A3A3B3B35393C3E3D3B3A3A
3A3A3A3A3A3938373637383A3B3B3B3B3A3B3B3B3A393734363C3B3747557E987E87604A
4452424957493C393B3E3C36343E353952667E838A9B968A7E7263453B3A393837373838
3537383939393A3A39393A39373738393737373737383838353B393A323B3D403E36414A
42403B3D37485863736E8392CFD5C4A28B807D7F9BB1C2D1D8DDDBC3CCC8C9CACDBD947C
73604E3C3A423D3B333F3B353C3C36393838373637393B3D3B3B34373B393C393B37393A
3735373E383C3B383838393B3E3E44477A7D9FA8
54534E504D504C4B4E4E4E4D4C4C4E50494A4A48494B49454B494747484A4B4A4A484748
4947474746464443464A4A464848484A4B4A4B4C45484947464748474447494B4B484542
404245454444474A474242484740404642444340404242403F424444424143443B3D3E3D
3F4547473F3F3E3F3F4040403C3E45463F3C3F3E3E403F3B3B3F43443B3B3C3F3F3E4043
413E41413D3E413E3A3B3E403E3C414848403B3C3C3A3C41413F45433C44373E3A3A3A39
39393B3D3A423F3C3939403E363839393837393B373A3E403E3937393E3E3C3A3C3F3E3B
393E43433E3C3E413B373A3E3E40413C3C3C3B3B3B3C3F40454D42393A3B3D3A34393939
3B39393F3F3A3C3F3C3C41423635393D3B3D403D43403E3F41424241403C3A3C3D3C3D3F
363D3C3A3E403E3E3E3D3B3B3A3B3E413C3B3B3C3B38373A363D403D3E42403A38393D43
44414042363A3F403D3C3D3F3F4547413D3F42423E383D3C3A3F3D3C3D3A3B3F413F3D3D
3D3E3E3F3F3F3F3F393C3D3E4144423F3B39434A45464A434748504855484F5147494F58
4746423B3C3C3E42423F3E40393C414C5060504C4B4C505C6057535555555B584D525E5D
4E4A4745413D3F433D3E403D3E3F3D3B3D3E3C3C403E3D3C466176827E8F989C999B978C
858F9DA29D9694A8CAD0D6B79F98A3A4B4C8CECECBD0CAC5A99C969FB4C6CBCDCBC7CFD6
D2D5D2D9DBD8DBD8CA9C5F4A4C585F757B746C867E85847F5D686177897D4B46414C676C
6A93A8BAC7B9AF796B655563639188B3C9ABA28C795C5654494E525294A5B7C6AFCEC3C6
B3B0A4A399838F7759453D3D383B43443838393A3B3C3D3E3D3C414039393D3C41343C38
40413C3734383B3C3D3E3C3A3936343C3B39423D3841383F3A3B453638383B3D3C3A393B
3A3A3C3C393B3F4039393A3A3A3A3A3A33393436393B3D333C4842505D45554F4C443B36
373A3C3C35353A3F3E3A3B3F3B393D413E3E3E393738393A3A3A3A3A3C3D3E3D3B39393A
3A3A3A3A3A393837363638393B3B3C3C3A3B3A393B3B3A3C383539435359696254533C3F
3F4F44453A3A3C3F3D36363D3A4761717E97868A75746150454040353939383837363535
3536383837383A3C3B3C3D3D3B3939393A3939383837373637393B433A38374134393C47
343D35415883ADC0C7BCCBD5CFC5AF9FA1ADBBC8D5DBDBE0E3E6E4D0CBBAA69388745244
3D3A3E3C445153565351454553544B4D383E4547434142463839383B393B3F3237373836
36393B3C3F37343A383840404E6E7EA7C2D3D4DC
54534A4C464C4949484949484645444545474746464846414B4947464647464646454443
44464441484745434549484547424245454345494A474545464443434143464848454240
494A4B484442424344424448494643434544403F4246443F44444342414141413E40403E
40444646413F3D3E404242423F3D41433E3D3E3B4243413D3A3B3B3B3D3D3F403F3D3F45
423F3F403F4143413D3E4143413E404545413C3A393B3C3C3E3D44413A3F353D3B3A3A3A
3C3C3C3B3A423E3B393D433E3A3A3A39373636363D3F403C383737373D3C3A383C40403C
3B3B3B3B3B3B3C3D3E393A3C3E40403C3E3D3B3A3A3B3C3C3A463E36383D41393F3D3A3E
443F393C3E393A3B373941443D3A3D403D3F423F413F3C3C3D3D3C393F3C3A3A3835373A
3D413E3A3C3C393A443E3B3E3E3A393D3B3B3D3E3C39383A393E3F3D3D403F3B3938393C
3C3A3737373B3F41403E3C3B414446433F3E414341383A39373D3A37423F3E403F3B3839
3D3D3D3E3E3F40413D3D3D3E403F3B373E3E4A5351514F4651545A4C5346484741404247
3A41413F3E3C3E4345403B393F434B53627063545054516168544B4A4F4B4E4C4549504C
4A46413D3A383B404043433C3E40433D3C3F3E4842545B67899CAAAC989E9E999C998A7A
7B81838488857E8EA2AEB7A89D9AA5A4B4C1C8BEC8C5BCB89B8A7A817C868587898EA5B7
C1CCC9DED8DDCEC6A48F888F949A939F9A91A09CA5909C8F9E809C7A846F6C80929BABA8
959E959198AC9FB48B9C6D7F71906E9BAFBABCB5B88BA594AD95AB96AD9DA77B8291B7C0
CECAC2BAA88C8F776B4E4544373A413639393A3B3B3A3A393C3A3E3E39393B393E3B3D43
353638413D3D3E3E3935363A3D3C3A3D3D3D434040413B3D3F3C463C3A39363434363737
35363F4137363B393D3D3E3E3E3E3F3F383631383D3C3C36425A64684B493F3C3F3D3A39
3A3C3B3B3D38393E3D36353A3E39393C3B3D3D3739393A3A3A3A3A393B3C3C3C3A383737
3A3A3A3A3A393837353638393A3B3B3C393D3B3A3D3934383C393B41464245394B403747
3F48413F373C3D3E3A313E5C5F79A1A9AB8C7A5D5A5140383431383A3737383736353332
3537393836373A3E3B3D3F3E3C3938373A3A3A3939383838393D40453B35374439364731
3F385364A8CCE2DCCEC0CED8E2D8CCCCD4D7D9DEE8E5E2E7E6E0D5BFA88D6D524840373E
4D51606C7D8C88858F7C625D665F4E4A3D434948423B393A34373A3A323B4A3F33383734
34393B374336354343517885B0C4CBD6DBD6D1D3
72655D4A514B4F48494A4B4C4B4948474F4F4C49494C4C494746444342424242494A4846
494D4B4649494643444747444C4A4948474747484A4441454745424348484A4A4A494847
464748474544454645444445474744404544414043474540484542404040403F41434340
3F41424143413E3F4243413F443E3D3E3C3F413E3B3D40403F3E3E3E44424143413E3D3E
413E3C3D3F41413E40404344403B3B3E3E3F3D3A3B40403D3A393F3D3B3F393E3E3B393A
3D3D3C3A39413C393A3F443D3E3D3A393938363434383835353A3E3E3A3A38373A3E3D38
413C3736383C3E3E3E3A393B3E403F3C3E3D3B3C3D3D3B3A37403B393B3E433C3E3C393C
3E383A463E3B3C3B36394144413E40413E4043413F3F3F3F3E3E3D3C4241424443414347
3A3E3C3A3E3D3A3C3B38383D3E3A35323A3B3D3D3B39393B3B3D3D3A3A3D3E3B42403E3F
3F3D393737393C3F403E3C3A3C3E40403E3C3F4241393D3A373A38373836373B3C3B3B3E
3B3C3D3E3E3D3B39413D414A4B44434A46444B515152524B4446473C453E3D3743404143
38423F3E47434243423D3A3B3D4046424B4B463A3F4942545E474143423C3D3D3A3D403B
4242413F3E3D3F413E3A3C3734364C4E4D5C617962848BA29E9EA1A0878A8D8B8F877065
70777B8788897D84848B8D857F7E82797E7C7E6C7B6971576249504B5451484B4E505E67
616B6C8B97B7B8BDBEC5D9E1DBD8CEC7C1CBC2D0BACFC7C4C3C7C0C6A8AD709BBDCBDAE0
D2D2C1B4B4A5B9ABBFA8B8B1BCABA081898A929B9E8C8CA9A2BAB3B2A8ADB0B8A0BFBACA
D1CCCBC3B39791787C625954444142343B3B3A3A393938383C38383936393E3D393B3A52
3C452F3E5F544A443C34363D3E413C35353E40384037403C433F3B3837393A3A3A393631
47434C4D403D40393B3B3B3B3B3B3C3C4A3D383F3B313A4D616F7F4E413839383C3B3A39
38393A3B423A383D3D36343840393838373B3F3C3A3B3B3B3B3A39393436393A3A383635
3A3A3A3A39383737373838393A3A3A3A393C38363A35323A3D443F3D3E393E424B413D47
363735373738384451505E818299959A6E584A3A3F3B37393A393B3D3737373736343332
36393B3936373B40393A3C3C3A3837373939393A3A3A3B3B3B3E3A3A3B3D3A3B383E3948
4E7287B1D7E2DED1C4C0D1DADCD9D9DEE2E0DFE3E4DDDBDDD1BAA28C725C483B3E444B5F
7074838F9EA79D968B795E52544A3A333A39393939383635373736373236423A393F3C39
3738404045495C7F91A9D2DDDCE2CFD7C4C8BDCB
B5A39076746861524F4D4A484748494A4A49474344484846474746464544454542434240
44494742494A484444464643454A494342464640484342494D4B48484342424141424343
4445464544444545484642404245433F424444414245464444423F3F414343433D414341
4041414042403F414344413E453F3E3F3E4144403C3D3F4040404143413D3D4144413C3A
413F3D3E42423E3C41414345413C3B3D3E424240424746413E3A3E3D40434040413D3A39
3C3D3B39383F3B393A3E423A3C3B393A3C3D3C3A353A3C3938393834393A39393B3E3B35
3A3B3B3937383B3F3C3B393A3E3F3E3D3C3B3C3E403F3C3A3F403D41403C403D363C4143
403D4A62424143413B3D43433B383A3C3B3E43413F3D3C3E4143413E3A3B3D403F3B3B3D
3A3E3D3D3F3C37393F4143444748423B3A3B3B3A38393A3B3C3C3A37373A3C3C38383737
393938353738393B3C3D3C3A3B3C3E3E3C3A3C3F413E46423A3B3A3C3C3A3B3D3D3B3B3E
3D3D3E3E3D3C3A393D3D4348443C3E474642434544454540383C3C343C3B3B3844444849
414B413F48474746403B3C413D3F46454D454A463E493E494D37353B3E39383A3A3C3D39
3C3E3E3B393838383E363E42465177758992A1A58D8F888E929097A2929AA9B5A092766A
73768098A0A597927C715E534F4F524A4A474839434440433A4B3F424E4E526674767974
686C5C7D7EAEB0C2C5D6E3E3E0E3DDBF8686A7A9C4B9C5BBD3C1D6B7B3B0B6A3CBD5D8E2
DCDED2C3C2C2A1C3A0C5C1D5DED2CDBA93998F9BB4AAB08685728892BCC0E6D0D8CBD2CF
B99E886E5E52584D4E433F3E3A3D424138383738393B3D3E3C373839373A3E3C3C383D41
3947466D6C55413E403C3736363B3D3C434A453D3B4244424C484A3C363D44433F3F444A
594D4D4A3F40453E3B3A3A3A3A3B3C3C3E39393A393F546C617C4B3A3B40323B37383839
393A3B3D3E37353B3E3A3A3E3B393B3B37393F3F3B3B3B3B3B3A39383838383839393838
393A3A3A3938373739393939393838373939343337373B46424941413F3836363C3B393D
32353538383C435B7067606F7B6A744E40353A3D38373635363938373939373635353535
383B3D3B37373C4138393A393838393A3B3B3B3A3A3A3A3A353C3931363A3D424E476669
A0A3C7DDE0E0DCE1DCD7DAD9D6D6D8D8D4CECAC7ADA19D97846D5A504E454343494B4B5B
6468716E6C6B615D4B493F393C3F3C3A3A383636383938373937333C3E3939353A3B353C
46587C919BA2B3CFDDE1E0CFD3BBBF9CA6767974
C0BCA5A597A08C82665F554D4A4A4D4F4B4C4C4B4D50504D474748474646464747474747
494C4B484849494645464542444C4C44444C4C4447464649494744424847464545464849
47474645434241414945403E404242403F434542414346464543403F404142413E424542
3F3F403E403F3E4043444341423F42444243433E4341403F3E3E41453E3B3C4449484442
41413F3F44433E3D40404345444140433E4141404244423D3F3C3E3B3F3E3E3C413D3A39
3B3C3B39393E3B3C3C3B3E383E3C3B3C3D3E3D3B383A3B3A3A3C3D3C393C3D3D3E3F3C37
36383B3D3E3C39373A3C3A3A3D3D3A3C393A3C3E3F3E3C3A3B39373F3C373C3B3D3F3D3C
3A3436423F3F42403B3C403D3E3B3C3E3B3E413F3B3C3D3D3D3E3F4043434547453F3B3C
3E403E3E3F393335363939373B403D363B3C3A38383B3C3B3B3A3937373A3C3C3E3F3F3E
3E3F3E3B38383838393A3A3A3D40403E3C3B3A3A3D3C46423939393C3B3B3E4345444649
413F3D3B3C3E4042464E514A413F40413D3C3D3E3E3D3D3B3C43453E3F3B3E4344464C4C
4753434141434647423C3E43414042444A3F423C363F393F423639403E39393C3D3D3D3C
3D3E3D3937393B3C3D363A3D48516E5C675D715F675B5D5A5C595E6E656C727A71685750
5550546960696362575346433D3B3E3D3A42464640424257679B9BA68785848F9494978F
99819A7CA790ACA5ACC1CFD2D8D9D2AB9BA49DA6A1C6C5CBBCD0A6B08EAC9FB9B8C1BDCC
CCCEC6B6BDBDCBBBD1BCD8D5D8CED4CDCFB0BFA6B2BEB09887868096ABC1C4BB98AFA0A9
64504D41403F42383B3D3C3B3C3A393D3B3A3838383A3C3D3C393C3E3B3B3B373B3C3445
615882864F3F34373C3A363538393C3A393B42535D877F898A6F6D3D3B3C3E404145505B
49413F3E37393C363D3C3C3B3B3C3E3E393C3C36435A594E4A443F2F3F36393D393B3E3F
403F3E3E3D39383B3C3C3B3C37383E403A393C3B3A3B3B3B3A393938413E393637393C3D
3939393939383736393939393938373638373B403E3A3C41363A39423A39393236383738
383C3A3A3543515E62564F59514D4344353F37393A3A3B35363C38363938373635363637
393C3D3B38373A3D393A3A3A3A3A3C3E3D3D3C3B3A3938383B3C3631434E5C6863748EBE
CCE0D6E5E5DFD5DDD6D0CFCCC7BDB3A99A8C7E736F63645F52484345423E3E3D41403A43
3F3F45403F423B3A3C41403835373735383B3D3B383636383536333938303B4641526488
A0B0CDDBDED9DAD8CDBFA78E7C6761555647474E
68726B797389807E615A514A464647474A4B4947484B4B48464748474645454646444445
4644444546494947464645424146453E3E444541454848454241403E4343434343444545
434343444545464646434142434241403F4243414144464647454240403F3F3E3F434441
3E40424342403F3E3F414243414145474140403C3E3C3D4041404449403F434849474647
3F403D3D42423E403E3E4044434141443C3C3C3B3D3E3D3A3C3C403A3B353A3A3D3B3A3A
3C3D3C3A3C3F3C413F393A383E3D3C3C3C3C3B3A413D393837373A3D363B3D3C3C3E3D3B
3E3C3D4146463F383A3E3D3B3C393638393A3B3C3B3B3A3B3635353A38363D383A3A3739
40403B3B39393C3B373A3C36433F40403C3D3F3C3B3D3E3C39383B3F3C3B3D4243403E3E
3739393C403C393E3A3A393A3C3D3A373D3D3B3A3C3F3E3A38393A3B3B3C3C3C3B3F3F3D
3B3C3A373B3B3B3A393838393C41413D3A3C3B3739373F3C3537373941414345433F3F41
403E3C3A3B3E42443B44463E3B40423D383A3C3D3E3D3D3E363D41424341444D49494C47
424F3C3A3D3E4042403C3C3F393D3B3D423E41383A3C393A3B38393B3B39393C3D3A393B
383A3A37373B3F3F3D3A3735443947344D41463A454A44494E4F4A4C41443E3D4245413F
423E3B42454A44403E423E41433D3F433D545D709E8AA793C7C5CFC0A69F94928E8E9288
8B8A7F9B8AA494A9A8AEBBBFC7C3C0B1B7B7BDA0A5A7ACA5B19F847D74665F625970758F
959CA5A1A2BBBAD0C2D5D0D3B9ACA4B0BBB7C2BDC2C6C5B5C9B49893ABA4A86D64524F42
463946424344433A383D3F3F423E38383D3C3B3A3939393A3D3B3F413C3C3C38383E4381
9C8A804B3B38393D3E3B3C3F4540403C3E485D816E845E564C404C343D3B404B4E48474B
39393C3C3A393937393837363637393A36353736495D4C363C2E43422E3E313B3436383C
3E3E3D3C3C3D3C39393A38363A383C3D39383A3639393A3A3A3938383F3C3836373A3C3D
3939393939383736373738393939383838343F4840383735393E3D4538383B3838373738
37393B3D424B504A413A3A3F3B3F353640313C3137353A36373C35343736363636363737
393A3B393736373838393B3B3A393A3B3B3B3B3A3A3A3A3A35383A497E9CA4A07085B6C9
D9D4D2CCD4CBB8B5A5A3A39F897D7C8075614F424C434A49413F3B3F3C383734393B353B
3C393A36383D373436373838383838373134373838383A3C3638373B3942617496A9B6D2
DFDADDD2D1B9B39C796650414941474959687581
4D53585153565B5752514F505253525156534D4645494B4A494A4B4A484646474B474749
4844434645484A48474745414E4D4A454446474740474945434649494445474848484747
48484645454442424340414647434141404141404246474442414140404141423A3E403E
3F454B4F4744403D3C3D4042454346453D3B3E3D3E3E4145443F3D3F42444747413C3D41
3B3D39383E3F3D403E3D3E41403D3D403E3C3A3B3D3E3F3F3B40463E3D333E413838393C
3E3E3D3B3E403E454238383839393A3B3C3D3E3E3734353A3B39393C33383B39383B3C3C
3A3B3C3D3D3D3C3C3A403F3B3B363236393A3A393737383A3E403E3E393A4036333A3A38
3936353838393B3B383C3E373C393B3C393B3D3A453F39393C3D3A373F3D3D40413E3B3B
3B3B393B3E3A383E3D3A3C42423C37363D3E3D3C3F43403A37383B3E3F3E3D3C383E4140
3F41413F3E3E3E3C39373737363D3F39383D3C363D373C3A363B3A3B3C3C3F413E39383A
3C3B3B3B3C3C3D3E4142403C3D41413D3C3D3D3B3A39393C3A3D3F464D4B4A514240433E
3D4F3E40413C3A3B3C39393A37403B38383A41393B383A3B3D42413D3A3A3A3D3C38373B
363A3C3A393C3E3C3E3E3A3D5137403D39464765618467796771665640413C3E3E43403A
3B3D3B393C403D383C413E423A3540555C8AA1C5C6C0BBC1AEB79394898B8E9BA4ACAFA0
AB8FAE8CAF849A97B59F9C9191807679766A6D76747579958BA17F7A6C7C5E7562716B87
96A3AEA8BCC3D2CDCBCACDB4B591956A6C63658596BAB9DBC9D6AEC8A8B5A3B0818F4E43
4637423735393F3E403F3B3A3C3D3C3B38393A3B3C3C3C3C3E3B3E3E3B3D4140404983B1
7C88423B3B39393C3D3B3A3B433F42434B4D434C40473E3F3D413C414647505952413C43
373B3C3A38373B413B3A393838393B3C3D3338393C3E383E3440383146473C3B3E3C3A39
39393837363A3B37373B3A36413A3736343739343839393A39393838343434363A3B3B39
393939393838373635363738393A3A3A3A30394035323A392F3A343D3C3D393B3A373C3D
373946503D3B39383C423D2F36393C383A4039463C363B38383A32353334353737373635
38393938363434343537393A38363535353637393B3D3E3F48657A84ADBCB19B7D9AB7BF
A8AFA5A3898A808274756E5F5A47454F4A3E3C3F3F363F3F3C3E3A3C38383B3940423838
32353C3634383538393333393D3B38383C383434373939373C3940536688B2BBDBE2D7D9
D2BDAE917E54554C394347494F68719B90BEABB6
4A5A776C868DA293A9999091898C85947D5E534A4A48474C4B474F4B444949474849454A
454A464748484747464544433F43444243464644484A444741474549444548545D524444
4447434645464E44414042464845454744444B4049485B4D414B4039433F3A4849454342
403D3F444140403F3E3D3E3E4142413E3E403F3B3B3B3B3D4042403D3F3D413D3A3C393E
3F423B3F423B3C3F3C3F41403D3D40433B3E3E3A393B3D3D3D3E3D3A38393C403D3C3C3D
3F40403F3C3C3F413F3A383A3A3A3A3A3A3B3B3B383B3B3B3C3E3B373A3A3D3C3A3F423C
35383B3A3A3B3A36353B3E3B38383939383D3B3D3A383F403B3A32363A3A3D383A37373A
3B3937383C3B3D42433F3C3B39383B3E3E3B3C3F403E3E403E3A3A3E35353E3C3B3E393E
3A3D3D3B3B3E3F3C37363D403A383A393C3C3F3D373A3C383D3D4146453D3939343D403C
3D43413A3B3A393838383737373E3E3C3D39373D39363A3B36393F3E35373A39393A3E42
393B3C3C3E42413D3B3A3D3B373B403C35393B3D48524D403B3F42484C47454B3C3C3C41
3D3D443C3C3A3F3C3B3D383A353F393B3C35393B39393A3F4138353D383B3A37383C3C39
393B3C3B39393A3C3C3E34393E3639413A54696B7D7264584A4A453D393A3B39353B413F
3D3E403D3C403F3C37404B5546528181BFB8CDBDB78A8477867E9B9BA697A09A9FB0ABAE
957D6C6A645751555353494A4D464647464C42494B49494E5455636C8A9AB8B4C4BEC1C1
B4BDB7BBAABBADC199B498A47E8D8391747F6F768D95ADC3C4C4CACFD7CBC4B8AE7A6C6A
71563941363F3A403A393C403B383A39363E38393C383B413C3C433C3E3E33465A779666
4C3E3E42383B4035363B35413A3D4234413540414140394036393C394B4E6350463F3A3F
3B41483A39353B36323235383836383C33373B364137333B3A373C3A3A3E3A3D393D3D39
383A3B393835373C3D3C434D4B483F3736393833373737383737373634363634373C3B37
383B3C3A3533343634353637383A3B3B39363A3C393A3C37393E3A3537393A3D40393935
42544E483B38383A38353335353135333C353838383938373536393B3238373538393534
36373837353434353439333A3D443C3E353A304236476A9A8EAEA5A18F848C76909AA797
918F8E787C6D665B49454841383D3B3A3F3D3A3C38393A3A3A3A3A3A36313438383B3B35
3B3E3E35353A383E353D373838373E353338383B433E3F485A8985B9B9CDDCDAC5C0BBB1
7C645A464443404C4A586981B4B1CAC4D6CAC095
7E998DB49EC7ACB3B0AAA39B918D83836F574E4B4C514E5042504F434D51464D42464649
4446454849494847464544434548484646494A4843443E44414844454543434C56514645
3F42414746474E4743424449494746473D3E403C4640493F3C453F3C45433E473E3D3E40
403D3E4242403F3E3E3E3E3E43454442404142413C3A3A3B3F403F3C3D3A3D39383D3C41
3B3F383C40393B3E3E41434341404244353A3C3C3C4144453D3C3C3A3A3A3C3E3B3A3A3A
3C3C3C3B38393C3F3E3B3B3E3E3E3D3C3A3938383A3A39383B4042413A3A3D3C383B3E38
373A3A39393B3B383A3E3F3C39393937373B383B3A383F3F3438353A3E4049493636393C
3D3C3F453F3C3C3F403D3B3C3D3C3E403E3A393C3B3A3B3D3B3736393B3A413E3D3F3B3F
3C3E3D3A3A3D3F3D3A3A3F3F393A3D3C3B3C3F3D383B3E3A3C4045443E38393D3A3F403C
3B3D3D393B3C3C3A37373839383E3E3D3F3C3A3E3B393D3F3C3E42403A3B3C3B3837393B
383E413E3C3D3F403E3B3C3D3C41433D42413D3C424A48403E403E3D3F3C3B4137373941
403E443F38373D3C3E423E4138403A3B3C3638393A3C3B3E403B394037393A3A3A3B3B3A
373A3A3E393B3738363F464D494752535F5E584C544D4946393C3D3D3C3E3F3F403E4342
3A3C403B3E433E4851738087798D9AB0BABDA18F797C6CA482A38C9E958583776C665650
4E463F3F424443423E413D3E3F40474341473D463C433A4740544D786F9EA5B3B7B1ABA0
87816B61515556544B544D525A626D767F8FA7B9BABDBBD8CADAD3DCD9E3C7D2A2A28482
7969505043544C4242373E3F3E393A36363A3A3B3F3F3D3D40363F3E3F4444574D5B5745
435F675C5C3C38383640413B3735413A47474D463F383D4039453C3F413F483A3A3B3B3E
3337403838343D3B3736383B3A38393C363A3A323F3835363835393636393538393B3C3A
39393A393836383B3A3B4856564E4136333536353838393A3A3A3A3A3A3B3B393A3B3A38
37383A39373637393A3A39393939393934343A393232383832383A3B3C38353935394345
4D574F4A3B38383938353536403A3C393F393C3B373737373738393A383C38323336373B
3738393938383839343B37383236353A38333C304782C0BAC8BAA1797574808C8C8C8975
717173664D4342403639403B393D3B3A3D3B383A3838393A3B3B3A393833363938393832
32363633393C36363238373338393D3A3838495C9191A295ACB7ACCFD0C8B9A0916C4E51
403C464E576882A7B6C4C8D1D3DBCFD6A8A8816A
7474948DBC9CA192919CA099918173605B4E5351525051525B4D4E504E4D464446454444
4446474748484847474747464445444344474848494A464B464B454545423F424B4B4543
4948484B47434741414143464644424247474241484347424044434346433E4042424244
423F3F4243413E3E3F403F3D3F3E3E3E3D3D3E40423F3D3F424443423B373B393B3F3C3F
40443D40423C3D3E4041434240404244404445403C3D3E3E3B3B3A3B3C3D3D3C3B3A3939
3A3A393838373A3D3D3B3C3F3F3F3E3D3B3A39393C3C3A383A3F403F404043423C3D3F3C
393B3B38383B3C3A3B3E3E3C3B3C3B38383B373A3A373C3A45453E3F3F3E44433637393A
38363C44423D3B3C3D3B3B3C3E3E3E3F3C39383A3A3B3D3F3D3938393B3A3D3B393A373A
3F3F3C39393C3E3E3D3F403A34373B383B3C3F3E3A3D403C3C41433E39393C3F3D3E3D3B
39383A3C3C3D3D3B39383A3C3D40403E3F3C393B3E3C3F42424344413E3F3F3D3C3A3939
393F413D393A3D3E3F3C3C3C3F44433A413C3736393C3B394044413D3E3F3E4139393942
403B3E3B413D413D3B3C37383B3F3B3C3D383939343837363836353A39393A3B38353639
3E3E353B35403D4261687D8D7F767C716D57433B45433F39403F3E3C3B3A3D403D3A3739
363A3E424A5F607B7A9C8F8B878BA085997E86798373907B95626B5C574B484944424242
3D3F3D3B3F43413C3F40404239353C36493F463F4E50535C6E6B876D83607A6866605750
444E494A423D43394041434447424A577489A7B8C3C1CED2D5CED8DBDED1E0BED5B5C29B
8363465057757262553D4741423D4240403D3A3A3D44443C3D3B4946506E69554A5C5975
85B2BDA98260433A3F3D3A466D6D82818B969185856E654C364335413D3C3F393D3B3937
4940433E3E3639333B3A3B3C3B39393D373B3730423E3933373538353537333639393B3C
3B3838393D39383B3D3F47524840373435393E423A3A3A3A3A3A3A3A3838393A39373638
39393A3A3A3938383E3D3C3B3A393837383A40403A37373637393534383937393E434A44
40433E3C3A383739383636393B3A403E3B3133333837373737383837343B393536363638
393A3B3A383635353437373832373839363C48659BC6C9BEA29B738594998575786F5D46
423F3E393A34373934393F3C3A3C3A393B3835373838383A3C3C3A373734363939393832
313836363A3A3838373B403A403A44525A778DB9C0C4C0B2CCBFA4BC95895D4B4745435B
67728EACC0C6CEDEE2E4DBD7D3B8C081834F6147
5A5B4D5D6B7B7A8E92A4B1B1B2A29B858074A185A37491888F61514F46484D4D4D4D4E4A
484445464747474748494A4A46464545484B4D4E484B474B42454043444341404244423F
46434448454345424647494B4B494645434642424140433E43424242413F3D3A3F3F4040
4040434644413E3E40413F3D403D3B3E40414243433F3E41444545463C383C3C3F423B3A
40453F41443F40413F403F3D3C3D4042393D3D383436393A3A39393B3F3F3D3B3C3B3A3A
3C3C3B3A3C3A3A3C3B39383B3B3B3C3C3D3D3E3E393A3A383A3C3C38454446443C3D4141
393C3B39393C3D3B393B3B3A3C3F3E3B3B3D393C3C383934464135373B3B3D373A393A3A
3735383E423D3A3B3B39393A393A3B3A393738393B3C3D3E3C3A3A3B3A393A3837373738
413F3B38383A3D3E373D3E39384146433B3B3E3E3B3F423D3D3F3C393A3F403D3B393A3B
3937393E3E3C3B3B3C3D3E3E37393A3D404140413E3D3E41434443413E3E3F4041403F3F
3C3D3B393A3D3D3B3E3E3D3C3C3E3C363C38383C3D3B393A3941413E41413C3A3C3B3940
3F383A3A3C383C39393B36383B3D3B3C3D3B3B3A393F3E3B3D3C3A3D3C3A3A3B39373B43
4041394A4C666A7586787D8A74594F3D463F3D3D3D3A3C3B3E3F4244433F3E3F403E483D
5D4D596087889B8294818E8176786C7379898384746E5359484C3C4949484B534A3E4242
3A3F3E3C3E3E3B3B3F3D3B423D323B445453527180A099A1818A727D4F5542423D3D3A40
3D4A505B4540413E41443E3D4946425354636A7B808889978B92909C929C89A38DA8A0A3
8270666C595C58515D3E4C3E3E383F413D413E413F45534A4047697E93B9B48E97A2A8C5
C7D2D5BEA68E67525A606E91C2CCDED8D3DCCAC5C2AC916B44433C443C403E3C3F3B3938
4C3F403C3F393F3D3C3A3A3B3B39393C373834384E453E3639373B38383A36393A393B3E
3D38373A433C393E43423F3D3D3734363837383C3C3C3A38373635353635373B3A36373B
3738393C3D3D3A373C3C3B3A393837373938393B3C3B38343A3B33303B4545443E414038
333537393A3737383937373A3432373B3B393D3E3D3A373637373635313737363A3B3635
3A3B3C3C393736363E393738373B3C394652989DD8B9B48788999FAAB88870414A473C33
3838393E3B373A3B37383B383A393839393635373837373A3D3D3936333335393B3B3936
353B37383C3936343E3B3A4463729EC3C2C5D5E0E1D3CEB3B68F7D62493B3D414B83A6BA
C7CBD2DCEFEAE1DEDBD3C1B38E8466653E47383A
4B544E565B5A4E565B646B6E746B71696B827DB5829171856D5C4F4B5352484F4C4A484A
4B4D4A48494948484848494A49464546484A4B4C4C4D474B454A45474648494845454644
454144464548484545474949494846443F4749494444493F45424343414245443F404140
4040424243403D3E40413F3C3F3A383B414443403E39383D41424244433D3F3D3F423A39
383F3A3C403E40403D3E3F3F3E3D3D3D3F41413D3B3F44463A39393C40403D393A39393A
3C3D3C3B3E3C3B3C3B38363839393A3B3D3E3F40363837373A3E3F3D433F403E38393F41
393B3C3A3B3D3D3A393A39383A3E3E3A3A3D3A3E3F3B3B34444036383D3E423C3F3C3B3D
3E3C3D3F403C3A3B3B383738363738363535363638393937363638393C3B39393A3A3C3C
403D3A3938393B3E3B413F38383D3D3A3B3A3D3D3B3F423D3D3F3D393B3F3E3A3A37383C
3B36373C3E3A383B4143413D3D3D3D3E3C3B3A383C3C3B3C404140403B3C3D3F40414140
3E3E3D3B3D40413E3D42423D3A3937363636393F3E39383C3C44434042413A36393A363C
3D393D3E3F3A3C38383A34353A393B3C3C3E3D3D383E3E3C3D3A36383C383738383B444F
4E504959586B686E54443D4A483F403A353A3E3D383A3C3C3F3E3F424850575B565F4E60
61746F8683927A8E5A6748544E446358998590757B6C524244454F60727C858D76544A40
3D45423B3D3E3B3C3B45444F5B586374A09495909E87816C524B4C414334423A3C3E3C46
404043515C565E59605A524D554E434C424540494D4D434C444E49505555595C7D8AB1C1
D6CAC5C8B6AE9C8A8A72826E65534E4B4148445A68758E827B7299C5D4DEE0D8DACFD3CD
CBC7D0C0A195969597ACC3D6D0DFDABFA19D7E85767D6D63464049484C4E454547413735
3C3B403A3C3335343B3737393938383B3A3735455D493E3839373B39393D393C3B3A3C40
3E39383C443E3B3E423F38313A36363A3A3635363D3C3A38373636363B3A3D41403B3B3F
3435383D40403C3936363737373737373D3C39393B3D3D3D383C3B3C42413F41393C3A39
38383937383636393937373A4036333836393B383E3B373637383938383934333D413D3A
393B3D3D3C3C3C3D3736393A3837404969AFB1D2B4B589AEB9BBBAAD79664647383C3839
3C3A384239383A3B39393B383A36363938353638383736383B3C3935333436383B3B3938
3536353840403A3A385773A4CCCCDEDCE8D6DACCB6A490785F4C40432C484B5EA0CEDCD9
E5EAE6DEDFD1C0B0A48F7560665559464F3B4237
494E4F49524B4B4F4E4C4B4C4E474C4D524D4D5C53494B504E495E72746D6365706E615C
4C4E4B504E4D4A48474646464B464445474746464B494146434942414542444542414241
443F4343444B473F404343424243423F3D43413E43414742424141403E4044453B3F4241
3F3F3F3D42403E3D3F3F3E3D3A3A39393D42403B3E39383E434242444941403B3C403B3C
3E453E3D3F3C3C3B3B3E424443403C3A3E3F3C36343638383A393A3D40403C3838373738
3A3B3B3A3D3A3A3C3D3A38383A3A3A3B3B3C3C3C403F3A36383E4241433E3E3D38393F41
383B3C3A3B3D3C3A3D3D3B38393C3B37393C393E403D3E3943453F3E3C394040413D3A3C
3D3B3A3A3E3B393B3B3836363638383533343535393B3A3735383A3B3839353739383C3A
3D3A393939383A3C3A403E393B3E3D3C3B393C3C3A3F413B3D41423E3A393A3A3B38393C
3C3735373C38373B4345413C3A393C3D3A3A3B39393B393A3E3E3D3F3B3C3C3C3C3B3B3C
3C4144413E3F43443D44443F3B39393B37383C3E3A34353B3F43403E41423E3F3B3F3839
3B383C3C3E393B393B3F3A3C38363C3C3B3F3E3F4146464647423E414F4C48464549515A
5653464940463D3E444239393D3F46423C3F3B3C3D433D3B363A3D424B5456535B496143
664C6D64695D56444035414A4E645980708C717A5A584B403D3F485849525B62523E3E3A
4B595241434946434E6A7380989C9EA596927F7F6757493E44403E43434149443F413841
3D3D43525C5266576C585B525E4D433D433D3E3B4040423D454044474951516185A3C2D2
D8D7D6CBA891909B9F97A89D9682746C5B605C768FA4C6C7CDBCC6DCE0DFE1E1DAD0D7BC
BFC2D0C7C6C2BC9C8B8D8CA0B7CAB9A68B947F968A9E949C8C8CA4A29F9C939392825E50
3D413B2C3B3D42423B3736383937383A3C3A394E62453C3837353A38383C393C3B3B3D3E
3D3A3A3B3D3D3D3C3B383737373536393B3B3D3F3C3B3A3A3A3C3D3E3F3F4042403D3B3B
393A3B3E3F3D383534343536373838393E454844403A393E4F535350483C3B473D3D3839
39363731373536393937363833333B43373638373B3A3838393B3D3D393B36374246403B
393A3A39373636373A3A3A353839587EC0BDE0BEBD93C8CBC8A08B6952373C3932363539
3637374039393A3A393A3A393B35363A373537393736353639393836363938373A393637
3C3A3A32343B405388B1BFDCE3DDECDBCAB5A4966560413F3F313E384F658B98C4DBE1DE
E4D9D0C4A3907C6B685D544A423C3F3539313837
5150515255505053504B4A4C4B4E4B504E4E505C5E5B5F57625785B4B8BDC2BDC6CEBDAA
735F4C534E4C4A48464646474F4A484B4E4D4C4C464C4B524C5251555C4F4B4D4C4A4A47
4A484F4D525D55484548484545484846494A42435D4C494D404547474746474C45484742
40424342403F3E3D3D3D3D3D3D4548413F43433E423C3C4246434144443F403C3D413B3D
4249413E3F3B3A373D3E3F403F3E3C3B3C3D3B39393D3D3B3B3A3B3D3F3E3B383A393839
3B3B3B3A3C39393D3E3B39383A3A3A3A3A3A393946433D37373C3F3F433D3D3F3A3A3E3E
393B3B39393C3D3B3E3F3D39393B3B383D3F3A3C3C3A3E3A363A373835333C3D3F3C3A3A
3937383C3E3A38393A37363736393A3635383A393A3D3D39383B3D3D3537313537353A36
3937383B3B38383A4648433F403F3B3D3A393A3A393D3F393D3E40403D3A3A3C3A38383A
3B3A373539393B3E42423E3B3C3B3F3F39373936363B3B3B3F3D3B3E3F40403D3A38383A
3A4043403C3D3F4039403F3A3C3D3C403E4347453E393A3F3C3C37383D3D3D413B443C38
3A393A36453F3F3A3A3C363638343E3D393E3D3F3B3C3C3F413B383F4443403B3A3E4143
4340393B383E3C3D393F3B3A3A3D423B333C393E3D3F3C493E403E3C434F4F47494F525E
494D413A3E424349474B4C514D4E4841423F3F443D3E41393C3840443E3D3D403C3C4647
56635A4C5058575751696B6E79766E676055584A4A3A4641444239433A3E43443D44363D
3D3F3C3C3E35453B4A3F4444413D3A3A3C3F44484B5C576A60726B7A768687989FB0B9BC
C0B7AA9F8E79747E85899396A3A4A09DA0A39E9A9492A4B6D1CDC7CBD8E4E4DDDDE1E3CE
C4C5C2B9AEBDC5AAA49062706F83768682A5A1BBD1DCD3D5C7D0DEDDD8CDBEB9BAB59391
757E65393A38383C403B38393A39393A393C3B4C5D403C3939363A38383B383A393C3C3A
393A3A39383A3B3A3837393B393A3B39393B3B3A3A3A393A3B3D3F413E404140403F3C39
3E3D3C3B3B393736383838383939393A364043403C37373F7D7D6D544237363C39393234
36353A373635363A3A363435343A47523D3938383B3C3D3D3D3C3C3C353A39383F403B38
383837363434363839343543647195C3B4BC9EAFA0C2C7B2756341493B3439323E3C383C
3439393D38373635343434353F36373C373436383636353536373737373A383639383639
38343F3C4C697CA1C9E2DCE1BCA6A38D8E634F3B3C3B3B3A3D43475B6E8AA7B5C6C8C4B7
AF9B9484614F443B403A3C3B373C3D3C393A3C3E
5148464F4E4D4C50504C4D5255696A74727A7983899BADA8A8948D8B8D908B8D92A19EAC
8B805A504A4948474748494A4945444A4F4F4E4E5F717E877E858E9D947D717474726F6A
76737A747580715E4649484545494A4840433E4975523D434F5A61646766676E78746757
4B4949473F3F3E3D3C3C3C3D3A494F433A3D3F3B413B3A41443F3D3F3B39404042433B3A
39413A393C3A3C39413E393636393C3E3D3D3D3C3E413E3A3B3B3C3D3E3D3B393E3D3C3C
3D3D3D3B3D3A3B3E3F3B373639393939393939393E3E3B38393D3F3D3E38393C38363736
3B3C3A37373B3D3C3D3F3D3A3A3D3E3C44443B3A38353A383D3F393B3B393E3B3A3A3B3C
3A3A424A3E3937383836363835393A38393E4141363A3B3837393A38383A34393A383C37
3735373B3C3837393A3B36343836343A3A383939383C3E373E39383D41403E3F38363537
3B3E3C38373A3F41403D3B3A36363D3F3A3B3F3E343B3D3E413E3B3F434444403B393A3C
3A3C3B393A3B3935333936343B3F3E413A4249473F39393C45423D3F433F3C4236423C38
3B3D3D383D373936393E393A3935403E383C3C3E3837363B3E37364036393937393E3F3C
3D3D3E4142403D3A3D3D3A3D3D3E433D3B3F36404447465D4D5252515A6763566463745B
644B524339423D3F323C393E373D3B3D3E3E393E3F3E393C3B4343433F3C3E414144433C
42483E363C3C3A423A4038383F4347444237413F3F3F40413B3C434A4A424A473D48393E
444D4539403E3D443E4946534C564E6C68867C817C82828A9AA8AFB8ACA9ADB6BEB9B8A6
A1A99F8D8784868EA0A49DA1BACCD3D6CBC3BFB5AEA1929E9AA0A5B8D2DADEE7E1E7DFE4
DDE6D7D3CCBFD3CDD4D8B0AC929C88A199B9ADB8C3CBD7DEDBECE9E7E3C2957062695C72
608E906357443B40443F3B3C3C3A393B343C3A47563E3E3B3C393D3A393C383B373B3C37
36393A383738393A3B3C3A3834393C39393A393439393838383A3C3E404344434547443E
38383737393C3E403C3C3C3B3B3A3A3A363A363339404A58666B5736303C3E35363A3539
3A363C393534363A3A363334363034423941413D3E4143423F3B3838363A352F3134363A
353638393B3F4548413F507BB3ADA5B3B67A777FA8859958433B4034353A373E4840393D
323A39363A3937363637383A4137383D373336373635353434353638343836353939383D
5E505F6A8FB8C1DDDAC9A39B69564D3E433B3545363A37444C596C8CB2B2C2BAB5A48E76
75726C48493C3A3942393C3D3C3C40333B353C37
5A5D646867706F777388809ABBC4D3CECAD7BFDCCBDCD2DFCFD1AB8B7360625B565F6460
7F6452515152515662686E7775766A6D726F787D99BDD1D6CBCAC5CDC6CCD3CBD1D0D2C9
D0CECAB3A29081634B473F4A5A6B7A70755B6E5363566B5B798D92A0969AA0B0C1BCB398
7D7E857B5B48483E403E41403E3C3C3F424241403B3C453E46403C4241433E3B41443F3C
3E3D403B403B3E3D403B3E413C3C44493F423E3F3E3B3E3A3B4042403E40413F42404042
403C3C3F383D3E3B393C3D3C3739393837383D4137393B3B3A393939383A3B3A37373B3E
36383C3C3A393C403E3E3E3C3B3B3C3E403B383B3F3E3D3D3B3C3E3D3C3B3D3E3E3E3D3D
3D3D3D3D3838393734393C3748423B37383C40423732363834373B3737343234383A3937
3B39363535373A3C393C37363C3B383B3E3C3C3D3A383C433C3A3838393A3A3A33383B3A
393A3A393836384045423D3B3E3B3B3D3C393A3F3A3A3A3C3E3E3B394244423D3A3B3935
3A3A393E3B383D3736383A3C3C3D3D3D38424D4F4439383D373A3D3D3A383A3D3F3B3A3D
3D3935353637383939393736373B3F3D3835383C39413F393B3B393B3E3C393839393938
3B413E3A3E403D3D3C3B3B3B40494C4945403F4345434346415665717E7A757E716E6A5C
4B433F373F3D3E43433F40443E39373A3B3B3D41363F353F3D3E3E3B3B3B3D444A4B4641
3A3B37423E443645384039413E373F3B3A40333C3A3C453D3F364B414D423E423F3A423F
4941414E685D7D697F6D8783999896ADC8CDCAC6B4A8A6B2B3ACA1858A788472876D7667
6F75736B666469758D919EB1C2CCD2D7D9D8D8D0D5C6C3C5BDCBBDC1BCC8CBD5D0DFD8DE
E6DFE6DDDCDBD3D5DBDBE0E5DED4D9D2E3D1D5B5B3ADBBC9DFD9E6DED2D79E665043423C
3E4A73645A854D3B473F384140383B363F3A383D3F3C393A3A393A3C3A3535383633393B
3C323D3938373F343F333A3C37393B3A39383A3C3A3C3C3A3A3C3C3A393939393E433F38
3436393A3938393A383A403C3B3F3A393637373940494B47433C403D3A3A34393535383D
3D3A393B3335373939383634353438343B453D353C3B3A3939393A3B3B3635343736303A
37354C545A81857C62537BB4C7A79B997569616A584C3D3D3A3D3F403D3A37353635383C
3C3836373A35353A3A333237372F353637382F332D383A323336363B353F3A5861627385
9AA3B0C8D7C9C19EA2796549423F2C463C3B4F53555768677A90AABBABB1AEA48A775C55
4A4940413B3A3B3C3B383B4139403A3F37373D3D
98A2ACBAB7CACBD9D1D6D6D2CECABBA19E9EAAA1BAA0ADA5B9CAC6CCC6AC9B87877F8978
706273738B8D8D8FA5BACBD5D1CFC0BEC0BEC8D1BDC1B4A19493959EB3C4D7DCE0DED9D0
CBD8D8DCBCAC866F4B4948586C81918A8C707F5D6E5A6D6275717F6A767971798F94A0A2
9DA3A5976C5853433F3B3D3E3E40413F3D3D3E3F403D40353F3E3C3E41413B3B41424041
3C3E413B3732373B3D393A3B3C3D403E3D3D3C46453A39393B3F413E3C3D3D3B3F3E3F41
403C3D403D3E3D3A393B3E40393939393A3A3938383A3B3B3A39383834383B3B38363537
3B3E40403E3C3C3D3E3D3C3A393A3B3C433E3B3C3D3A3736393A3B3B3B3B3C3C3B3B3C3C
3B3A39393634383A36373C3D403D393636383A3B3332363837363634383636393C3D3B38
33363A3D3E3C3936373938383B3A38393736383A39383C433D3B38373739393933383B3A
3A3B3A383835353A3D3B39393939393A3A393B3F3B3C3E3E3C3A3939373A3C3A3A3B3935
3839393E3B383C353737393A3B3C3D3D3B3F464A443C383A393B3D3C3A39393B403B383A
3B3A3B3D3937363536383B3D3E403F3C38383C403F423E3B40413E3F3D40413E3936393D
3F413C373C3F40444C53554D4645423E3837383D414344464A53595A5B58555645454744
3E4145413B3E4243403A373839393B3E3D39393C3D403E47445D71727C7C7E83898B8782
6F73687E6B7C67775964494C3A3C413B3C45453E483F55506463736B746B747878707575
8787868DA2B3B7BFB3BDBEBDBDBCB4BDC9C8BFB0948A717D60665B53424A4A514D59677C
8D969891898488949EA5B3C5CFD1D1D1CED1D7D6DED1CECDCACEC8C3B4AEB0AAB5B8BEBB
D5CFDED9DFD5CAC3CCD3D2DFDCE4CFDFCADDDADCD6D5D0DCD3D0CBC2BABDC08F5B413B3E
3A3E42475D827A5C3C3A3E433D3A3E3A3E3C3C3D3D3F42423C3A3B3C3B37373A3B383C38
3C363D3937333D333B35393B37373838383A3D3F393B3B3A3A3D3D3B393A39393A3D3D3B
3637393B3B3A3A3A3D3A3D39393E3A3B3D3C3A393A3D3B383B373A393D403B3F3735373C
3E3B3939353638393A39373636373A34353C35313535343435383A3B3A3836333732314B
637592A29EC7B49B6A6491BCBE987F675C4F5A54563D3D3534373B3D3C3B3A3A3937393D
3D3937383D39383A39343437322E383833343338353833353D3E424758707CA8C0C9CECF
C4BFBAC1B0A06D66463A3D3635383F627B86A1A198929D989F9CA68E897E7F646154403D
393E393935383A3A393938373D3D333F3A413A3A
C8C5D7CDDBD5DCDDDDCDC9AD8F8B7A66676A636669676A6F677980919896A5ACBBBAC2B5
B6ADB7B5C4CCD1CAD8D9D6CCC1C1B3B0AEAFB6C0ABA8A2999D9FA6ACCAD4DADDDADDDBD8
D5D2D6C1BA937C6957524C50555B5F555A4B52444E454D5149515F4855584B525B596168
686B675856494D45423F3F3F4548463F3D3F403D3B3D44373F41424444433E3E42403C3E
393E413F3A383B3F3F444843403A39383A3B3B45453A3A39383B3C3B3B3C3D3C3C3C3E40
403D3D3F3F3D3D3E3D3C3D403E3A38383A3A38353A3A3A3A3A3938373B3E403F3C393939
3C3E4041403F3D3B3E3D3B3939393A3A403B393B3D3A3838393838393A3A3A3A37383A3A
3A3937353632373B3533393D3A3A393836353536383A3A3A3C3A38393A3838393C3D3C3A
38393A3B3C3C3B3B3736393A3838393837383A3C3B3B3E433E3B38363637383833383B3A
3A3B3A383C3A38393A3A3B3D383A393736383B3C36393C3C3A38393B35393C3D3E3F3D3A
3638383D3A383C34373738383A3B3C3C3A393C40403B37363B3C3C3C3B3A39393E3A3738
393A3B3E3838393A3A3A3A3A3B3B3A3837383B3E433F39393F3D383833383C3B37383F45
42413D3C3F4043495A594F423C3D3C38383A3B3C3F4242404545433F3C40413D4441413F
393C3F3B3B3A38383C3F3D3738393B3B38363A404046637A7593ADB7B5B3B2B3B6B5B1AC
A29799948E888386636E4D543B3F3F3B46675E6C5E6D77878694A9A5A9A4B7BACBC0BCB5
BBB29E948997727E617F777F727979776E65665F4E453E464447524E5E776F9283A59EBB
B9C2C4C0BAAFA9ACBEC3CCD5D6CFC8C5D4CEC9B9B1998D8777677A5E6D52745F6C6E6886
92BAB2C0C3CAA8A2A39EBECFD6CFCAB9CAC2D3D0E2DBDDBCB59196808D9FB1BEA6665736
423F41465B8B9CA46D5B5654545E584538393F403C40443F3E3C3B3C3C3A3A3B3B383A33
3C393A363E3C41393B3B3A3B3D3B383737383939383A3B393A3D3E3C3A39393837363A3F
38393A3B3C3C3B3A3E383A383A3D393B3B3A393A39373536393939363D3E373B413C3A3D
3F3D3836373839393939383737383C343237323238373636383B3E40383937353D3C4873
9D9CAF9B99A29675675E788376615A413C393B4039393839393A3C3B393735353938383A
393736373A3837363635363837353A3631353533353531496370838CBAC9C4D7DAD3BEA7
9C87886F715540403F3C383F4D628CB4D0CED2C2AFA2A1979886705F51554D3A423F3637
373C3631363A3B393A3D3B36383A3C3B33333745
C6C5C6D2D6E4DADBDCD2CEC2B2A4958B808F79957C947F8E888F8D929699A7ACB9BDC6BF
C3BBBAAEAAB6C5C6D5CBBEAD98A5AAB7BABEBDC4D0D1DADAE2D9D9D7D4D4CDD0CED9DBE0
D0C9B3A08D7C5B5457504E50505150474C48434A4B535267567056574A4A3E454C434245
4548473F463F4746423F3D3E42423F3B414A473E4A515B463F3B3C3D3F43413E403E3A39
3F404041403F3B3839414A464639393D3B403C3C3C3C3F3A383A3B3B3B3C3C3C3B3C3E40
3F3D3D3E3C3B3D42423C3A3B403C3836373A3B3C3C3A39393A3A38373D3D3C393737393B
383A3B3C3E3F3D393E3D3C3B3B3B39383E3A383B3C3B3B3C3B3A38393A3A39373637393A
3A3A39383935373935353836393B3C3B393736363D403A373B3B3A403C39363537393A3A
3E3C393737393D3F3835393B36373B373B3C3D3C3A393A3C3B3937373738383736393A38
383A3A3834343434333335373B3E3C373437393835363838373636373335373838383634
3638383B38373D35383838393A3A39383C393A3D3F3C39393D3C3C3C3E3E3C3A3B3A3A3A
393837373C3D3E3E3D3B3836353536393B3C3B3A3F3935393C393535373737373738393B
414041454642424748453D3A3D3D3D404D4D49423F403D37393A36333840413E3E3A3A3A
373B3F3C3B3C3A383E46443C404448474342474E73677A83696D707E716E6B6A6A686460
65525D4B50414B46444637423B3D4348617B8D788774919DB8C0D3D0D4CCC6B4AD967E67
63615650464948414A454343454B4D52545D7177827F7B6764678C94B6B4BAA3BDA5AAA7
A9AFB4BAC1BBADA79F9FA1A29D9590907E746D5D58494746453E424544434F42453C5143
52525864616A6C63666B7595A3BBA5CDB7DCC6D9DDDFBCA97A817D7C5E607C96B080615B
8783B6A2C7BAD0D3CFBDBAAA9A926D42403B3E3F38393B343F3C3A3A3B3B3B3B3C363935
3F3A37363A433D373B3A3939403D393839393734373A3A38393B3C39393636383736393F
3939393B3D3D3B393934393A3C3D36383937393D3C38383C373C3A363A38353D4F453E3D
3F3C3734383838383838383838373B34343A3637373534333436393A393939363C455A83
83766C6E5868595246404F4B423F483A373A363F2F3A373A37383A393838383937363535
343333333333323132353838383A3A383D3E37333D4B5B8AB2C2D5D4CDC8ABA291856F5A
4F4F414339363837383F436991ABCDD8D0B7A2928780796D6B563C4135403A3938393735
373B373036363536383938363A38443D464F6785
8B839B99BFC0CCC7C4D9CED5DCCCCED1CBD0D2D0D4D3D1D4D3D4D0D2D0C2A685A79BB4C4
C8D8E9D2DCDBDCDBE6E0DAD6CDD8D9DFD9DCD2D8DCD8DCD9DFDADEDBDCDFDDE3DCDEDBDF
DBC9A179605E4C5049444649494A4843434245464D4B48594C60465C5D5D484745414347
47464644423C42433C3E3C404549494B5561615856647B6E6454483D4048453D3F434140
403E3E3D403E3E3B3F393F3F4638393A3C413C39393B413C3D3C3B3C3C3B3B3B3C3E3F3E
3D3C3C3C3B3A3C41413C38393B3B3B39383A3F423C3A39393A3B39383C3B3A3837383B3D
383A39383A3E3C383C3D3E3F3E3C3A39423E3A3B3B3A3B3E3E3C3A3A3A3A38363838393A
3B3C3D3E3D3A393739413F323A3C3C3B393737383A3D37343838373C3B3A383839393939
3B3B3B3B3A3939383A36383A35383C393A3A3A373534343437373738393A3938393A3936
363A3B3936393C3C3B3B3C3C3C3F3E3836393A383A383737383836343E3D3D3D3D3D3D3D
373A373835373F373A39393A3B3B38353F3D3E40403E3F423D3C3B3D40413F3D3C3D3D3C
3B3A393843413E3B3A3A3B3C3A393A3D3F403D3A3835373D3E3B3A3B383A3E40403D3937
3D3D414645403F413C3E3F44474247575C5A5146403F3B36383F3A384446403F403B3A3A
36383B3938464D484343403A3D464F514C4746475A474D4F40443C4F454341414242413F
40383C4139424044473F3E343C3B45484F7474877E959FBFD7D7E3CAB39F88755B4F463D
3B433E3E3D40403C3D4D44536D85939CA4AFBAB3AFBDB4B1A1B5C4C8B2C39CAE82916370
71726F70736959504F4D4C4C4946474A4B454640423B4346423F40495759625B5C666C81
6C8C7B927F8C757B7B63635B5F62918CCDB7CBBFC1C1C5ABB4ABBDAA927D766D72536283
9BB5BBDAC4C7C3D3D2D1D3B28B785635473D3B3E3D3F43413D3C39393A3C3B3A3D363A3B
423737383D503E363E383B3B3B3938393C3D3A36383A3A3737393936393433373A393A3D
3939393A3C3C3A3837363C3B3B3C37393B3A3B3E3C37373B343938373939445451463C3A
3B3A3634383837363636363639353632353C3837363534333436383A3C393C36333D4C5F
6F4F4C3A3D2F39353637403939353D3A3737463E41373E363A3B3B3A3837373836363533
323333323232323233363738353935393D333548708496B9CBC4BEA88B7D61594946403C
3A3F3C423B38383D4C6682BADCDAD2B588705F5F5D58504A4C3B3C343C313B393B3C3A34
373B3C393A35363B3C36363B3D4244677DAEB6D5
4D5259666879757D8BB9ACA7A38E9EAEB6B0AC979893979CB6C1CBCECCC8BBA79A949BA3
B1C6DCDDDFDBD3D4DADCDBE0D2DAD8DCD6E1D8E1E1D9D6D1D2D2D5CFCED0D3D6CFCCCDD5
D8BEA56B5D504D4C4F484E4F4C4D4A494D45503F5241484F504B4444545644484244484A
47444342403D474E484B474A5054534E4A4A4843494B5B5455534F474147423A3A3D3D40
403F453D413B4243433A4542473A403C3E3F3B3E3E3A3E3C3B39393C3E3E3F413D3F403D
3C3D3D3D3E3C3B3C3C3B3A3A35393D3E3C3C3E413C3B3A3A3A3B3B3B3B3B3C3D3D3E3E3E
3D3F3D393A3E3C363A3C3F403E3C3B3B403C3A3B3C3B3E413E3D3C3B3A39383739393A3A
3C3D3F403E3C3B393F4C49373939393837373738383A3A3A3C3B393A3A3C3D3F3F3C3937
393A3C3C3C3A38373B383839393B3C393B3B3A3736373735373636383A3B3A393A3A3835
363A3B393135383736373837393B3C3A393B3C3D383737393C3E3E3D3C39373838383A3D
393B38373439413A3B3A393A3C3C3A373C3B3B3D3C3A3C413B3B3B3D4041403F4041403D
3C3E3F3F3E3D3D3C3C3C3D3D413D3A3A3B3C3A383836393D3C3B3C3A373F4A4E4B45403D
3A393D3F3C3B3F404345454B5048475756524A423E3E3D3C3B4440414B45393C3D383B3E
3C3E43443F494E484342403B3A414746413E3B3A4240454239413749403E3C3B3C3C3A39
3936393B363B3537393E433440475147616A7E7A9794B2C4C9C2C496685A565C433E3F3F
383D3A3E3A39474462919DAB98BAC4C0C6CECCBAC0CAC8C2BEB7A98C62675452484B3D42
40434242474542443F3D3E403F3D3E423E3B4542423A41423F3F58559185A6A4BDB5C6BB
C9C1BEB0B1A5A9A6AEB19B9E8F846D73718B8896849896B5B5D9D4C9AC87645C53457881
B3A1BC95B599BAC6D6D4C19572675743413D39393C3E3D3D3B3C3B393A3C3C3A39363A3D
3E3444434456423139353E3F3B3A393B3E3E3A363A3C3B3837393835383535383B3B3A3A
39393A3B3C3B3A383C3F443C373A393D39393A3B3937373A3838383F3D3B4F61463D3636
383837383838373635353535393334313439343337373738393B3D3E3D393F3A32363839
3C35313D353C38373D3B3B313738464D47474D49423C3E393F3F3E3B3734333337383835
353636353837383938363535363731393B365787A7A39795897669534C43393F3536373E
40324230433E3D609CB7CFE5DCB8956D514A464A423C373B36393E39373537353A3B3E3A
3C3839363A35373F3D353944586797A2DDDBF0F0
4F4D5751555354574B7077746B595C6662695F61526356636D77837E72747F849FADA08F
9497ABD2CCD2CCD2D2DBD4D7D7DFDEE2DAE4D3D8D0D0CDC6B8B7B2A9A7A0A0A4ABA9AFB4
A49C9BA197A38681696471777A818489857A705D56535158474B494343463E44393D3F3F
3F4245474A49535D54554A4A494B4B4845444444433B4640454749453D414244453F3E46
42414F4551434B464D4C635D594B4D383F413C3F3E3A3E3B3C38373B3E3F40423C3F3F3C
3B3E40403F3E3D3B3B3D3C3937393C3D3D3C3B3A3B3B3B3B3B3C3D3F37373738393A3A3A
3C40403B3B3E3C36383C3F3E3B3A3C3E3A39393C3D3C3E413B3C3C3B3A39393938393A3A
3B3B3B3B3D3A393A404B493A39383737383838383B3A3E403F3F3F3C3C3C3E3E3D3B3938
3B3B3A3A3A3B3C3D3A3A393A403F3A383F403E39393B3C3A3A383737383A3B3B393A3937
383B3A36393B3B38373A3C3B38383A3C3C3A3B3D33363A3B3A3C3F43413D3B3C3D3C3E42
393C3938363B433A3C3937383C3F3F3D3C3837393A393A3D3A3A3A3C3D3E3E3D3F42433F
3D3E3E3D383A3C3E3E3C3A383E3C39393A3A39373B37383B3D42443D44474B4B47413D3B
38393D3D393E45443E4645484F473B3F47423D3B3B3C3E403B3E3E42463D363A3734383C
39393E4142423F3C3E43413C3E41413E3C3D3D3B373A3F434658566842403E3D3C3B3937
3E3B3C363A3D3B413C554F575C7179696A6A677C7D8986937F70694E363A42453E393E46
3E4647516A679A80B5B7D0C1B5C1AD9FA8A590797875765D644C513F41463A463F4B3B39
3D403E3C3E3D3C403F3C3D40413F3E3F3E3B4643413A464A5F7789A8C0C6CCD5D3DCD7E1
D7DCD2C0ABA7A9AEB1B7C0C5C7B8C39B906C6F6E7F878E90A1B6D1CCAD79614D454B4A40
5C5B59746EA387A8B4CBD1CAC4B89C7D545B4F3C3A3E3C3D3A3D3E3B3B3D3D3B393F4344
404269648E8A7A4E433C43403D3C3B3C3E3D3A383B3D3C3A393B3B38383A3B39383A3A3A
3A3B3D3D3C3B3A3A424A5141363A3A3D3739393837393A3A3D373D4E463A464D3D383637
3938393B39383837373636353734373434373336343435363738393A3B373C3A37363134
3B33392F3A35433B383539353E46585C5C5A4E533B3F383B37383A393837373736383836
363838353A373A3E3D3632333535333E4758809C967C62564C45443E3F3A394236363439
3E3C46515C7872A8CDD7DCC79F7B5E463E413D3E3538373B2E3A353C2F3B333434343B38
3C3437383835363A393C4C5F8CB8CBE6E2E6D8DF
4D4D4B514B554B5056494B4B4F524D514A5257534F55494E554E51514D5055565661655F
5753627B6E807F9199B7B8C0CED2CBCEC9DFD5E1D7DEDACCADABA8A58178849ABBC0C3BF
C8ACB7C0D6DDCDC0BDB5BFBFBCBEBDC2A8B3A4BD9FBEA4B095A77B79504F4A474B4D4A44
424444434441464F464A414344403E3E40403F3F443A453D3E3D4344454954666B5F5C68
6D6E8889A69AA195AEADC5B9AE9887573F463F3A393D413A443F3B3D3C3938393B3E3E3A
3A3F42423D3F403E3F403D363D3A38383A3B38363A3B3C3B3B3C3E413E3B3937383B3E3F
363C3E3B3B3F3C36373B3D3C38373C413C3B3C3E3D39373938393A3A3938393B3738393A
3A3937363B36373B3D4241383A3938393B3C3B3A3C373B3D393C403C3E3C3A373636383A
3A3A3B3C3D3E3F40393C393C4543393740413D38363939373E3B373536393B3C38393939
3A3C39343B3B373231363A3939383A3E3D38373B363B3F3B3431353C413D3A3B3A38393D
383D3B3A373C443A3C3835363B404343433D3A3C40403F3F39393A3B3B3B3B3A3C414441
3D3B37333D3B3938373738383A3B3C3F41413E3B3B36373C4453574E47413A393D403F3D
373A41413D444B483947443B3C3A373E3E3936383A3A3C403C373B423E3534383835393C
3634393C3A3B3C3B3B3C3B3735393B3B3D3F3D3851423A464F5A4C4E3A39393939393838
3B4434484168617B69835D6E57656554534348545E524844463F4247444A4C3F43415068
708A9BB1A9B6B0B791B6BBD4A39669525A53494B47473F42413C3E3E433E3E363A3A3E36
3A3C3A3D44443F3E3F3C3C40434444464B474F4C4D516974A5C0CAE4E0DED8E2DEE1DCD6
DDD0D2ADA58D91807890A0BAAEB0AFAF868C869A9EB9C3CDBBC5CCCCB8A97B61554A4C42
3D47434546454B525C879DA7B3BBC0BAB9BE975D443F3A3A393E403E3C3E3E3D414F5251
4C5B948CAC979055403F46433A39393B3E3F403F3B3E3E3B3B3E3E3B383F403A3537393A
3B3D3F3F3D3B3B3C43525B493A3B393A3C3E3D38373A3B383B333F5A4F3838323B3A3B3D
3C3A3A3D393A39393837363635353B383637363C3A3A3B3B3B3A39393A35353436332E3B
3532343337363E3A3A353D383A3F4C43453D433E3D33393638393A393634333333363734
353737343633373F3E3531333335353D48606E53614335393B3937363733353E363F4146
7680949DA8A2A6B3BCB2A57C54473D374043373534423B333E393B333B3436333B363936
3E3D4C55464543404253718ABBCDD2C1CEBABEB4
4A4B4B4B4B4A4B4B47484A4B49484747454D514D494A4D4E494C4D4C4A4A4A4A47464549
4D504F4E52504C575265696B787A807F8EA3C9CDD1D5D5CECFC1C5B69876787A94B3B1C4
BCD1C3D7C6DFDDE1DEDBE6E0DAE3DED7C9CFD1C6CEE2DDDBD9C6BF9077454844443D4544
414D4B3E433F3E4346413D3F45483E444A3B4A44423F3E41413D3E444087ABA6B6BCB9BF
BAC9CAD9D1DFD7D9D3D9D8DDD9C9B1A96C5D4F414642474640423B44313C3A403C403740
393F453F393A3D3C3A3C3C3E35363B403F3D4045363A3F3F3C393A3C3C3A3E3F393A3F3E
403D403C3A3B3638393C3F3E3A37373934373837383C3E3B373637393B3B3A3936394040
393B3F3A3A3F413C38393B3A353637393A3A393937393A3A38383B3E3A39393837373737
3C41413C3C42423D3A373A4246423A36433F3B38393A3B3B393F3A34383B3B3E3737393B
3D3D3B393B3A383737383A3B3737393B3C3D3C3C38393C3E39333740393B3D3D3C3B3B3C
37383E3F37363B3B3A3641363937393E3D3B38383A3C3E3E38383A3D40403E3C40414242
403D3937343936353C3F3C3C3A3B3C3B39383839383C3B3D484C4642413B3C404144453D
3E3E3E3C3B3B3C3E3C4044413B393D433C3D3D3D3D3E41433C3F3E3A393B3A3733373B3C
3A3A3C3E3C3B3A3D424646443F3D383C404A3B3F3F3C3C40403D3C3C413D404642495343
3A414E435D6476727A7D83736850473E3F3F4144433E3D40474853806D9076817D849290
9EAFC1B9BAC3BFA1B3A3D8CCBB98937483685D4946443D3B3F3D3D46413F39443C433C38
3B3940423E4449434D4846575A65808B9890A89992898B94A2B9CBD6EBE4E1D8ABB7A2B8
A1AE889B60695B5D55587D7F838DA392A4B9D3C6D4D5DED6D4D7D3D1CED0CAC8BA8F856C
7B5E574C534D47474C4A5C688D95B8D3D8DBD8B5734D4B3E3E3E423E474A5A5E84A3ABA2
8E76726D647081797C625E4B3E453B3C434447424340463A454147414036353B4038433E
676F8869664C364F413F443C423F3E453E383D383A383E393F403B453F3F3A3B423B332F
3136393A3839393937373738343433333335373835343638373333363536373634333436
37363832343A393B383535393B393A3E3738393A3A3937363435373A3934343836363738
393938373233353534343535323A3F4040403F3B393B2E393B3A3737343737334F6A81A1
B8C3CDC7B49C7A5954504A443F3B3939383D39353836343A373739393D3033414C585968
6B5967534B3E47535C6880A8A8A99071604F5659
4B4B4B4B4B4B4B4B4A4A4B4A4848494A4A4C4C4A4A4D4E4F4D4E4F4F4D4A4A4B524F4C4C
4E5051514D56544B4E4F4F52514A4A505B62828DA1C1BABA887E69655E5056555A64606D
6C7C8E899FA3C2C0C1C2CCCED0D6D9E5C9D5C1D5CFDCDCEADEDEC0AA7B6C52524C494745
4A453E4C444646463F424649484F403F42484446473E4446433E3E4D7FA5ADB4BECAC1CC
CAD7D9E5D6D8C8C6C4BDB9AFB5A69F9B967F736B7475766659454240443A3D3A3C3E3841
36373F423C3C3C3C3E3F3F443D3D4042413D3E413B3B3B3B3A3939393F39393B3A3D3F3A
39373B37373A373B383B3D3E3C3A3837383A3B39393B3B383C3A3837373737363A3B403E
383A3C37373D3F3C3A3C3E3E38393A3A3A39393A3B3A3938393A3A3B3A3A3B3B3A393837
393A3B3A39393A3B35373C403D383639413E3B3838373736363B39373B3B3A3C35353538
3C3E3D3B3A3B3B3B393838393838393A3939393A3C3E3F3D3C3D3F3F36383A3B3B3B3B3C
3A36383834363937393640383B393A3D3C3A39393A3D3F40383737393B3C3B393C3D3D3D
3C393735323A3B3C42433E3D3C3D3D3C3B3C3F41363A38383F413B38423B3B3E40424037
3E3E3E3C3B3A39393A3B3B3938383A3C36383B3C3B39383833383B3C3E403F3C37383837
373B40453D3C3B3D3F3F3C393A3C393E41483F433B37384045443F3C394146536A868661
60836B7C5F84738D7D85777A525146574B464242424349507D65897C958590888C898B8E
A6ABA7978CA496B28EB5A4B89A988A977C7E57543B3B3B3D403E3F453E3D44403A3D4549
495B6263757D767E5C6E77A3A5BDC6D3CAC2CDC6B3AB999B96999FA7B7B0A483645D5756
5B5B57686E745C596A76888FA1BBC6D0C1D5D3D5D8C5D0BDBFC1CFD4D0DFD4E5DADDD6D4
D2BDB7ABAEA79F9D8A8181758484A4BFCFD3DFDFBC987C57585258627488A4BDCDDEDCD9
D5CDC8C0B6C2D3CFCCA28A6B777F756E6D6E7D87897D826D6E4952534C403E3D403F4348
85A09A927B57484847464343485A67805E423B363B363A3C4642383B3537353A3B393738
3B3B39373839393937363738363635353536363739383A3B393635383334363635353738
3634383B3934333A35343537383738393132343637373636343436393937373B34343536
37393A3A373839393837383934383A39393A393631363D35433136352E41435B92BFBAC9
C5BBAA89624A413B3A393634343536373B3B37333536393F3F50586F5752506D71947D97
5651464F61626A656264636B4A524745393E4557
4C4B4B4B4C4C4B4B4C4C4A4847474A4D494441434648494B4A484A4C4A454346504D4A48
494D5154697E685F4B5A4E5A524F4D505450554A57729B8C8E6061514F5252524E4C4F50
4A534A504D5C5D595C617088A5B5C3DFDEBA8D7DB0A8D7DCDFDED4B8BFB4B0A59C6F6260
4F464544434543453F5665697D8D6D6F574B50464F3B433F3E3F4661948F8A7F9B9EA5A4
A5A9A6B2A7A7979575715E5F50544D586A5D677389989C836E54404C43433E4543454148
3F42433E3A3A35363B37363C3D3C3D3F3D3A393A3F3C3837383939383E39383A3A3C3C39
35353B39383B383C404040403F3B36323A3C3C3B3A3B3A383E3D3C3C3E3E3E3D38383B3A
383B3D3A3E40403B393A3C3D3E3F403E3C3B3D3F3E3A37373A3C3A383B3C3D3D3D3B3938
3B3A3939383636373837383A3A373738413F3D3B3A3837363A3C3B3C3D3833353D3A3738
3B3D3C3B393C3E3F3C3938373D3F3F3D3B3A3B3C3A3C3A36393F3F393D3F40403F3E3E3F
423A3737373B3C3936353D393E3D3D3E3B3B3A3A3B3D40433B393636393B39373A3A3A3A
39383635343A39373A3D3D3E3E3E3C3B3B3D41443D403D3A3D3C37363D3A3B3D3D404341
3D3D3D3E3D3C3A393B38343437393937393939393A3D41444C4D4D4A4744413D393A3A3A
3B3D3F414241414243403B36393D373A3A3A37383936353A3E3D3B3B3840496584938E78
9C8AA47089688B747E6D735A644657585D554D4A4B4F575D605D4C70497256685552535B
79796F657A6795617450504D494F50554848393F3E3D4144413E3E3C41474954476C7184
8A9EB7B7ABA08F83506B96B5D7D5DFDDE2D0DBC4C1A4907F78777D766D6B7258625C5165
5C716F888C8F776E89A0AEBECDC7C297A4959E8BA0858B788C91A8B6D0D6D1CBD6D9D9D8
DBD8DBDADFDFD9D8D3CECDBEC5BDCDD9D4CFD6E0D6CCC8B4938E98A0A3ADB2C7D0DBD5D6
DADFDFDED7E0E8D7C4A0A09CCFD1C3B7AFAFC4D9D7CEB29B755147434737393E3C423D40
4A61586656565F70A097AC8CAEA1BABC8B563E363E3A414D4C453D3D383B393E3A373536
383A3938373839383736373838383838383737363A393A3B3A3636383838383736343535
3A383535323033343436363536373736393939393735333134333537373638393A393734
32323232373838373635353635363534353737363940343B383F313F425F93AFDBDCBD90
7A634C3E3434393A373635353537393B3C393A39373B40426B5E8B718B578089A79C9574
7D50695B6D695E453940403D403D3C3D4A5F82A1
4C4B4B4B4C4C4C4B4C4B4A474647494C4D48464A4D4C4E514D4A4C504F49474A4C4B4949
4C535A5E737A7557525159565A5950515E6869574D5B576E5C625A6E575D515658535748
504A524651424C4A53524F515C6C90BCD3DAA39B8290A9D0D8DFCCC9CDD7C4BFD9CBC3BA
A8866460554D4B5F72A6C6CDD1AC9B918A95938F7D656456514F57685F635A6C799D9791
6F6453564E4F4342443F483D45354247423C45485A6B796C625A526D5C6156624C4D474C
4F6057434F4F45464A403D4139393A3B3B3A39383E3C3A3838393A3A393A3C3B37373A3B
383941403E3E383A44423F3F403E39343B3B3B3B3B3C3C3C3D3D3E414242403E3A383838
393B3C3B42413E3936373A3C3C3E3F3E3B3A3D403D3B3838393B3B3A3B3C3D3D3C3B3A39
3E3D3B3A3A3A38363A3938393A3A3B3B3D3C3A39393939393837383D3F3B383A48433E3C
3C3D3B38393C3F403E3B3A393E3F403D3A383A3D38383634363B3B38393A3B3B3A393A3A
433D38383A3C3D3B3D3C3E3C3D3C3B3A3B3C3D3C3B3D40423E3C39383A3D3B363A3B3C3C
3C3A3938383B3A3635393C3D3F3D3B3938393B3D4245413D3E3C393B3839393736394248
3B3B3C3E3F403F3F3E3A37373A3C3C3B3C3C3A3A3C41484E4E4C48433F3E3D3C403F3E3D
3D3C3B3A3C3C3E40403D38343A3D363C3F3E43403B393837353740494548527389827F84
7F92677A6183606E585340524754414245403B393A3B3D3E4F414542404343453E40443F
48414241474251423D4139453D3D433940373E43463F4247484C504B574F625C6E8899A1
A196928D7F7D82757B9EA8D6D4EDDBE6DBDBD6CEA791665A627896917F7D968D796E6D7A
6C716B777E7D6F69788F9FA29B95726158594D464A54636D9099A6B8B7B1AC96A8A19B9B
AFBDC7D2D7DED8D8D5D1D3CCD5CECDC7CBC5C7D0C9CBDDDED8CABCA695A5A7BCC8D7D5D5
D0D5D9E2F2EAE2DBDED1DBDADEDED8D4D2CED6E3D6D4C8A3A4858C6C654C4042373E3937
3A384F5250717FADCEDCEAE6E5D8B49C7F534D525C4D4142403A3A39373732353C393634
36383A3A383939393736373838383A3A3A39383737353538373434373939393836353535
383F3F3831333A35373A393535393A37373838393837373634323435333437363C3C3B3A
3837383938393837353434353836353537393A3935373D343C3332487FB9CAD2C6A85E46
423936373637393638373635353536373A3940433F40433F49535B72586473918A92646C
3B4841573B3B3C3632373A36414356628599C4D1
4C4B4A4A4C4D4C4A49494948464647494443464A4A47484C4D4B4C50504D4B4D49484849
4C51565A536051533C504546535244434B555A535852544C524A596E7780788897989D88
856B60525A556D817B818483796F727CBBACB28FB9A8B7B1C2C3D5C3EAD3DED9D1DBE0D6
D1CEC6CDB7AAABC0CBE2E6DBBC986F5A5F629D9EA18D85716758585057515647585D6652
574D40423F444247545652614F4D3D423B3E433B434549413D3C4A5152484C4D4F545A6B
758670534A4C4042433836363B3C3D3D3E3E3D3B3A3C3E3D3A393B3E393C3C3A3837383B
3D3C42403E3F3A3D3D3A38393D3F3E3C3E3C3B3A3A3B3C3E403E3C3C3C3B3938413E3A38
393937363B3B3B3B3A393A3C37393A3937373A3E3A3A3A3938393C3F3C3C3B3B3A3A3939
3C39393D3E3A3838343A3E3C37373C413837363536383C3E423C3B3E3E3A383846423E3C
3C3D3C3A393B3E3F3E3D3D3D37393937343336393C3B3B3D3C3A3C40353637383738393B
3B3A38373737383A3B3C3A3C3D3E40403C3D3E3D3B3B3D3F3D3D3B393B3E3B363A3B3C3D
3D3B3A383B3F413F3C3C3C393D3C3B3A393939383D3F3C3A3C3A383C3A3936343537393B
3A3A3A3B3C3D3F403D3C3B3B3B3D3E3F393A3B3C3C3D4042474542413F3F404147433D39
38393B3D3A3B3D3F3F3D3A3738362F343A3A413B3F3D3B3B3B404D5A5963616A77726961
806D7C5E604B5D433E3D413A454141373C3D3D3F4142413E3F383D3D3C3E3D3E3C414A3F
3B39444235423E40373B3F3D45483A434A5F667381756F6C65625B4D4B535D6E61857E8D
67695C79A6B5BFC1BEC0CAC1D9D7E3E8DBD5D4B0A2909BA5B6C3CEC2B4A9B2A377726381
56674A5658564B4D525B62534A4C3C47403F4A6466868B98968F82837C7867625D67596F
5E757C8D93A29FA59DA0ADB6C4C3BEB1A5A9B8CFD5D8E3E0E0D2C4AC979E97A6BCCDD2D9
D4DCDCE9E4E0DDDCDED2D9D7E1DFDDDBDCD7D4DCDDEAD8DED9DED4BBAB96716049403E42
43599AA3AFBDC0D1DCD2EBC5E2B5AA8C907371706F57453C3C363B383838343A3D3C3B3A
3A3A3A3938393A393837383936383A3B3C3B3A39353333353635353734343536383A3B3B
3E34333736373935393B393433383A3835353535343433333532353735393D3942434443
403E3E3F3C3C3C3A373637383A383637393A393939383C323A415E8DC5BEB88C6E4A4532
37393F3E373739353434343434363738393940443E3D3E39353645454442515444423F36
39323A3A3D3C3E3F3C434F4E597A84BEBADBD0C3
4C4A494A4C4C4B494748494847464647484A4F52514E4E504A4A4A4B4C4D4C4B49484848
484A4A4A494B49414846494944544D4A45494944454A4C454946424B616D6F8295A1AEA7
AC89867A9189A3B6CACCC8CBCECDCDC9B3A98D89768E7D8E7A9086A794AFA9CAD5D6D9C1
B1C6DBE0DBD1D4DCE1E4E1D4CEC0BF8E826A646360514F4549444D3E4245434F424A413E
44454446404042476C5D64636B554F44484E555057514D433E3F41453C3D3D3C3E414F64
676B534341453C3F3E383E373A3D3E3C3B3B3A38383C403F3B3A3C3F3E3D39383C3C3939
3F3A3C38393F3E433A383636383A3C3C413E3C3C3B393A3C433F3A37383A3C3D403E3939
3C3A373A3A3A3D403E3A3635393A3C3C3B3B3D40393A3B3937383D423C3B3A3939393939
38373C433F35353C34393C3A38393C3F3B3A3A393A3D42463D38373B3D3F42413A393839
3B3D3D3E3A3B3C3E3F3F3F3E37383938363637393D3C3F423E383B423C3D3C3B3938393A
373B3B393938383D3A3E393F3C3F42433D3D3D3C3B3B3B3C383C3C39393D3C3739393A3A
3A3938373D3E403D393B3B363D3C3C3C3D3D3B39393B39393C3A383D3E3B363A43433A34
3A3A3A393737393B3A3B3C3C3B3B3D3F39393939393B3F433B3A3B3D3C3836363F3E3D3B
3A3B3D3F40404040403F3E3D433E3D3E4240453E423D3A3C40444B51495E5B545C645D49
46534A4942463B424145443B3B41433E46464542403E3B37373939433F4641433C3D463E
3C3C453B3E4847414B455B527176787B97969C99898A9095948C7A68636B867D6F66676E
697F92B3C2B9B7B0AEAE9BABA0BCB0BFB3C3C3D1C8D6CED7CEBEA389847978664F3D4940
463B3F3C3F463C3D403E444044454F57736C8E9A9D9D867B615D5248434445454B5A6889
81968E9C98A5A0A8A29EA1A3ADB9C7C9CFD1D6E1DDD6D4C9D0CAD0D0C5BCABB1B7C3C8D5
D5E2D7E0DAE1DDCDB49EA7AFD4D7DCD9D9D6D2DADBD3D5D7E9D8E3DBDADDBEAA9472636C
7CA9D1D5E0D9EDDCD7C29F88727268786F5D544A46393C363A343F383A3B3B443C3B3938
37373738393A3B3A393838393637393B3C3C3B3A393535373938383A35343436383A3A3A
3C2F404E4639323938383633333537373A393837353433323633383C3A40453E41434442
3D3A38393A3A3937353436373A3837383837363838393550638A9BB898905A453B3C313E
3E3937353337382F3838383838393A3A3A393B3B36353635363B2E41314738353D3F403C
354C5F6C93897869616F84829BA0CDC2DCB4B279
4C4948494B4C4A48474849484746474846484B4C4E4E4B484E504E4B4C51514D4E4C4B4B
4C4C4B494C494150414946514C5D5450484A49484D4D433F49574F5952595E62656D767C
706B5B725D7874959DAEAEB3BBBBC5D0D6C3AF846A494F4A4C4E4E545157647A8AB1C5C1
CBCDC3D0D7D6DBD2D5CBC4B3A4A99FA9B7A8896A59444A3E43404B44483F4544483D4345
404243413E3E3D3B4840435C5F676569797F93989B8D83735F645A6749503F3E423D434B
42483E403A3F393E393C4B3F383C3E3A383837353A3C3E3D3C3A3B3C3F3F3A383D3D393A
3E3839373A4140433E3E3D3A3837393A3F3C3C3E3D3A393B423E3B3A3B3E40413B3B383A
3F3D3B41413F3E403E3835363C3D3E3E3E3E3E3F3C3B3A38383A3D3F3B3B3B3B3A3A3939
3A4C574E3E36393D3D3D3B383A3E3E3C3E3E3E3D3D3E42453F393939393F433E3536383A
3A3A3B3C3C3B3B3E40403E3B3C3D3D3D3C3B3B3B393B3E3E3B38383A3C3C3B3937363738
383C3B393C3B3A3F42483F443B3A3B3A3B3B3A3A3B3B3B3B383D3D39383E3F3C3B3A3937
373738383E3B3B3935393C363F3E3D3D3E3D3A383A3B393A3E3B393E3F3E3B3E48463D38
393B3D3B3836393C38393A3B3C3C3C3B3C3B3937383D43483B3B3D4243403E4036393D3E
3D3D3D3E3F3D3C3A3A3C3E403B37434142404441413C393B3D3E3F424855504948494A3E
494348493E40433640423B3A353D3B3A35383A393A3E403F3A3C3A3D3A3C3A3B3C404A46
484247454A455A54707D96A2B7B3AC8D9E81887D818C93979892867E7E868C9B82857F8B
8793ABA88A80847E8B7B82879496928EA6AAACB4C5C6BAAE907E65504E44483D463E3B3E
3B443D403842424349484C5957706B9693B0A79B896D6149454B555459607A7C97A2C0D1
CFE1CFDBCED4C7CFCFC3BCB8B8C0CCD0D0D2D4DBD9D3CFC0A49896969B9EA9B6CFDBDEE3
D5DBCCD8DDDDD1C5B7ABABA5C3CDD9D8DADDD8E0D6D0C7D6D4D6D7E1E1EAE8E1D9BAA9AD
C1E1E9E7E5E2EADED2C0A9806D5445404141424443353C304644574F4C42373C3C3C3B3A
3A3A3A3A3A3B3C3B3939393A3738393A3B3A3A393D3937393A3838393837363637383735
324B7C724A3B3540373635373736363837373738393A3B3C38353B3E3A41453C34373939
3736383B37373633313133353836363839383A3E3A4C7187A8A2967256473A343D373D2E
3B37393B3736393737373636353535353A3B383433323235343B35393139343A3C3A4360
75B8CBCEC8B4947F7E9ABBB8C2BFB0B57B824F38
4C4947484B4C4A47494A4A494747484A4A4B4B4B50534E464B4E4C45474E4E4747454447
4A4C4B494F3F495A4641464749483B484743414B4B46444050514751595B635B4F49444A
48414649494D47504E686C788781899C92A499A7897A725B534D4A4B4747484A55668AAA
C7D8D0CBD1CFC9A7A28A7B616760546B6D826C6E6E546253514647464643434B4B49464A
534E4540454A473F3E374352595B6A7486869CA4A6A2ACA49F979181665047413A3B4345
3B453C3C3B403C4039415849393E413E3A3B3B3A3E3C3B3A3B3B39383C413F3B3C39383E
3E393C3C40453F3F3F4243413D3B3D403A383B3F403C3B3C3E3D3C3C3C3B38363C3D3A3C
413D3A41453F3B3A3A393C413939393A3A3A3837403C3837393C3C3C3B3C3D3D3D3B3938
406777593C3B403C4044433D393C40423A3A3B393737393B3936363638424740393C3E3E
3B3836373D3C3B3E41413D383D3D3D3D3C3B3A38383D3E3B3A3B3934393B3C3D3E414447
36393533393A383C3A433C463D3E40403A3838393B3C3B3A3A40403A3A404443403D3936
36373A3C3B3A3F403E403F3543403E3C3B3A36343A3937393D39353A3E423E3B3C383437
373C41403C3B3D413A38383B3E3F3C393C3C3D3C3B3B3C3D3C39393C3C39393C37393B3A
393A3E42413F3D3B3C404549403E524B453F40403E3C3C3C3A3A3F4649473C3A38373C38
3B3B3F3D3B3B3C38393A3E3D3C3738383A3E3F3C3B3D3F3E3738373539393F4038434E49
47373E4E4F48757D8CA08CA28C9F828F839998AAB9B9A88E7E746F73817673858A919699
98A3AB92877E5B517262637A7B8877746F797281878E7B735049443E3D374746403F3840
39483839494B58616D6F656E6372757B797A887786759880958E9BA8ACBAC5D4D4E1DCD9
CDDDC3CCB5AE95978D7D767B828F9B9DAAACADBAC5C6BDA6ADA7A2989D9DA8A8BCD0D8D5
B7B8B0C9BBC7C7C5C1C2CED0D6D4CFBFC1CCD0DCD1D1D2CED1D1CDC6D7CAD6D6DAD6D7D8
E1E3EDE8DEEDD2E3C8DAD2CBADA4694B454B4D585E54675C787B968C7F6347413B40474B
4B47413D3B3C3C3C3A393A3B3939393A393938383F3A3738393635363635343538393937
3F68935F2D3B3B393836383C3C38373A37373636353536363A363B3D383D3F34393B3B39
3635373A3938373534343637353435393B3C41486A9ABABE9B8363393F483A383735393A
3630363E3932333734343535353636373A3E393537333136323437353F37393F4568ABC9
C8D9CEB8A0896D666D8BA9A2A67A7B4E3D3F4240
4D4D4E4F4E4D4C4C4B4E51514F4C4A4A454C57504949474C4844454D52514E4F4D4D4B47
484B4A464A4745474B4C49454C4E4844464544494C47454747464A504C4A4A4B4945464A
43484A4B4E4A4952505556514D4E50505650735E857286696D614A5C4C5D5358514C6484
A4A9AEA98B887D8984847B68705C655046524A577F9EAEA887887A7D62686B7E60638B8B
89797A6B796862615E5245473F4C465454547782837F7E79856D775A4F3A3F363C36403E
3D384447403D42363F3D423E3E3E3839403A36413C3A3C3B383E3B3F3A3E3941363E393A
39433943504757453D4144473D42383E3D3E3B3A3C42403C3738383B3D343B3A33393B3A
3A3A3B3C44433C3E3A343C403F3E42443E3D3E3A3940413E3E3B393E393D383B3C3A3F39
52796464493A3A393D3D3A37393E403E3B3635393C39363537363536393B3B3B353A3D3A
383A3C3D3C3B3A3A3A3A3B3C3E3C433E3A3A32363D413F37363D424239393A3D3E3A3B40
393B3B3B3B3B3B393E413B403B403B3F3B39383B3D3A383B3B3B39383B403F3A363A3C38
36383A3836363A40423F3F423C3A3837383939383E3633393B373538333D403D3D393434
3737383A3D3E3E3D3C3A3B3D3C37383D383C3F3F3E3D3D3C373A3D3A3634383C3F403D39
3B41423E393E413F3D3D3D3B3C4349473F3A3B3F3E37353838363A423B3736393C3B3C3F
3E3A3736383B3B3B3E3D3E403E3C3E433D3C3A3939393A3B3938383A3C3D3B39383B3D3C
3A3A3D41557E988E8E847C6E7077899799A0A9A8BBB8A885776565675B5D52555D8198A7
BFB4AAB3AC9176546F57584B62525347464344484B494747373B413D394334433F3C3F3A
46443F44566970777A6F60545A5E64978DA89FBDBDCCCAD4DADEDCD8DED4D8D5D9CCBFAA
9B8A6F715E62566F6682909CA2B2B9C6C1C6AABABDD5C3CEC4C0B9C6C1CECAC7CCD0CECC
C7B9BAB3C0C4D1D5DDD3E2D7E0D5D8D1CAD2D6DDD4DAD0D1D0DAD5DAB3B3B4BDC3C6C5D1
D0D0D9E1D9DCDFD0D6D1E1D8DED2CAA6B0ACB7AE907B78847F97A2C8A2BDA1A27C907B9B
96A4736D453D36373936333334363C403F3A3737373935384441383C33393A3D33383B42
535C473C38333B3937383937343336393735383D3B35363D3A3F423E3936373832393A35
3335383B3940303A303D37343A363A40435B7B7EA8C4B484634835373C3A373433333434
333C3132312F3C35332F383936383536383A3B3A373534343732343937333E517BB7CAC0
A3937C6155434845507B786B523A3B3B3C4F5858
4B4B4B4A49494A4B4A4B4B4B4A4A4A4A41454D49494E4C4F4846484D504F4B4947484845
454847444A4B4B4C4C4A47454A4B46434748484D4D4C4946474A4C4D4B4A4B4D4B484A4E
4B4E4C4A49434249484B4A444244474742404F444E49574D4F5B596A5F776D68625A6163
696469655B554D5A66798F93958F9481766D52566C8CACBDBACBC8D0BCB7A9B5A2ADD3D5
CFBEBBB0BCB4AFB3A09C8994879692978E7A534347404543433E444D3D433C413B3F4640
453F434434383B3E3D3E3D3E3F48463C3C41403B3C38413B3E3B413D3836413942344045
436A7F9185625A4337383E3E3C3F3A3E343E374139443A403C32402B454B42403C3B3D3E
3B393A3B3639373C3D3A40413C383A3A36383B38373E404143403C3E3D3E3940433D3C35
71775A6D5C40373E3A3B3A393C40413F3D3D4042403B3A3D3A3938393A3A3837373B3D3A
383A3C3D3C3C3C3B3A3A3C3D3E3B403B393C393E3A3F403A383B3C383836383A3836383A
3A3A3B3C3C3B3B3C3D4040443B3F3F433E39383B3B3C4043383B3C3A3B3E3F3E373B3C3A
3A3D3E3E3C39373839393A3D3D3C3C3C3C393431433C3A3F413C3A3C383F3E393A39393C
3B3B3B3B3C3D3E3E3E3E3D3937383B3C38393C3D3B393839383A3C3B38373A3E3C3A383A
3D3E3F403D40413F3F41413E393C3F41403E3C3A393B3F403A353E4D3E3D3E4142403E3E
3C3F413E39383B3F3A393A3C3A38393D3B3B3B3B3B3B3C3D34373B3E3F3E3C3B3A3A3936
35384046758F8B80646A6161595F6B74777A7D7C757572615F504B483B3B434E61878C95
8A81777B76685C47413F483D453B403C3A393B3D3E3E4248383C363F423F42423C3C3740
39453E4D4A5F565651475556827FB4C0D2CCD6BDCCC3C9C1CCBEC1BFAFA9958A79707B76
7C8E7FA98BA584A395B4CAD6D0D5D3D9D5D4D6C8DBCECAC1C9BAC5B8D1CEE6E0DCE4E7EE
E4E5DCDED3DCDDE7DFE3E7E1DACDD4D7D3D3D2D8D8D6E2CCE2CFD9D0C0B2BFBCCFCFC6CE
C8C0B0BCB1D2C9D9D5DBD9E3D4E7E0D3C6D0D19F5F43434F465D827EA0A1AEB6C6A18086
85948756473F3D3E3937373236383636383B3D42363C3C3A3A39383C343734333A3D424C
635047373538303B3436383837383A3C3A393B3C37333A4648413C39363334392F333636
373837353B3039343F3B34373B3D63707B928C8E78867553433A343934393A3535393A37
354A5663563B37303A353A3631373A3D3637373837373738333032383939435164877575
4D553F393C3A3E3C30463B3D3B39454D6187A1AE
4F4F4E4B4A4A4D504E4D4B4B4C4D4E4F4D4B4E4A4C524D4D494949484A4B484446494B4A
4A4B4A494A4C4E4E4A464444454644454B4D4B4C4D4D4944454B4B47494A4C4C4947484C
494A4847464243494747433F3E4144454448464C3F4543474251535E556E685F615D6158
5852524752473F434B53686F686D75726F64514F4F597F7C928A9492A29F8D9994A4C6CD
D9CFCBC3C1B9B4C0D2CDCFCCD0C0BFA595874B41453C4441413B3D4642433D44393F4138
4441413E433D4636423342413D45463E3A40433F444238423A473F3842453D41424D6081
87A5A8A37D564C40433D453B413E40413A3A48394B363F3E383B3C385888808768534947
3F3C3D3A343A383A3A393E3B38383C3F3D3D3C38373C3E4248453E3D3F3B3740443E3B36
648C786348484537393B3B3B3D403F3C3C3E41423E3A393B3B3A3A3B3B3A3735383C3D39
37393C3C3B3C3D3C3A3A3C3E3C3A3E3B3B3E3D41373C3F3C3B3D3C383F393D413B3D4342
3C393A3F3F3B3B3F3C3E43473A3E44463F383A3C36363B39373B3E3C3A3C3E403A3D3E3D
3D3F4040393A3A3B3E403E3B38393A3C3D3C3937403A393D3F3A37383F44413A3938373A
3E3E3D3C3C3C3D3D3F423E3634393C3B3A38393D3B363539393B3B3B3A3A3C3E413B393D
3C3736393C3E3E3E40444441423F3E4044433C36393D44443B353E4C3D3F414141414140
3C3F403D373435383837393D3D3B3C403F3E3D3B3A3938383F3C39393B3B39363E3D3B38
383D454B68605E41423E4B45464A4947454140444541423E4941413F4744555053665459
56524A494747483E4345413B3B3E3F393A3B3E42424041453F30443B3C3E353E3B373A49
424B47544A4E575256656F848A958AA393A6786F6A68677A69705C67807886688A619B8A
B3ADB096977F8597ACC3D5DED1D3CECCC0C9AFCCACC8B0BDB0B7BCD6D2E6E2E3ECE7F5E6
EBE2E4E5DED9E8D7E9D6E7D8D5C2BFC2C3C5CCDACFDEC8DEC0D7BEC8C5CCBECDC4C2BDC5
C3B3947F9893BAC8CABBCFB5D0B7BB93A2A2976C48403B36453C3F3A4C4C6C9AAAC2A294
614F3D3F423C3D3F3B3B3B373B3D36373B3C373B3C38393734383A343539393248414144
423238393A3D3438393A3A3A393939393C3B3B3C39363C454D3F3638383333383D383534
3433333238333B3A34433C6079788C8985806157464941383838343336393A38383A3C3D
577C959872423938393338383E4B484036353536373839393F3B38383736393E4047393A
363C3A3B373445364133363E3B4F6A8BBBD8C8B5
484948464444474A4A474443454748484A484A44444943414A4A46424247474340444747
464544444A4B4B4A484543424142454A50504B484B4A454243474641484A4B4945424345
444344464645464C484642404144454544443C493D453E44524F48514A56514C4948504E
595C57404A3F3F40463E45484947454845474E4A42494A5A4D5C515E5D685D6760657982
7E7E7F848697ACD2CBD2D3DED0CEBBA28D86676C646168625C55424B3C433A48413E3C33
3D3B3F40424944494246444444403A3C3F3B3A41404149455B555F575A5C785D896A8B94
8D896C6150515757504F4D5351605B625658536150544A4F4B45434387A2B3968D674F49
3F3C3C353D423C3937383D383B3C3F4242413E3A393C3B3E46453F3E3E37343C3F3B3C3F
3D635F5138383D403C3C3C3B3C3C3A373E3B3A3B3C3B38353B3A393A3B3B3A393A3D3C39
37393B3B3A3B3C3C3A393B3D393A3E3E3E3E3C3C3A3D3E3B3A3D3E3C423B424740454F4B
3E393A40413B3B413C3A43473B3E4644413D464A3E3C3D35383B3D3C3A3A3B3C3E3F3F3E
3D3D3D3C3A3D3D3D4144413A3F3D3A3838393B3C3C38373A3B3633333C43423D3C393535
3D3D3D3D3C3B3C3C3E3F3D38363839383E39393E3E37373C3C3B3B3B3B3B3C3C3A38383C
3C3A393B373C3F3E3F4344433F3B383D4447443F3D3C3D3E3B37383D383A3A39393D4142
3B3735363A3C3A373B3A3B3E3F3D3D403F3E3C3A383839395E544B4C54554D433B3C3C3C
3C3F4346433C3C4038413C383C403E3D3F3B383F443D404252515A5D514B574B474F3B3F
3E3F3B393B40403A3F453C3E363B3C3B43414245433F3C3D453B3F3B433D4E474F525188
76967B868998939E98868B8192756C6558544F4A4E659186918199ABC1C4A8B1998E8A78
6F6258514A546B90BCC9D4DCCCCAB9A99783A395C2ACD1CBD2D3DEE4E6E6E9E5EAE9E0E6
D8E3D5DAD5D5CAD6C8CEC6CBCCBEB6B3ACA5A8B2B4AECEB3D8B4C7B6BFAEBB9A9A9193AD
B1B7A2AA91B296B8B8BEACCBB0BD84645E5751423B403E3F393F4C573A413F4A568EAB96
BD75534D4038363B3C393431393D373C3A39394B533D3A3F3B3E40343A3B41384E403F3B
3538363F3A353F353D3C3B39393838373E39393D403D3A3A4139363B3D3835363B353435
3335393A373A313D457580A6A096725D51403A323C35303236383735383333393A373D47
6585928258373638333543484F584C3B37363536383837353C3A3735363838373C393534
3E3835333B3B343D3E434A6D749DBDD1E2D3AD98
4C4D4E4D4B4B4B4C4F4C4A494A4B4A4946484E49494D494A4C4E4D494A4D4D49484A4D4F
4D4A49494D494747494A48454443464A4D4E4A464C4643444644424245484A4844424243
454345484644444643413F40424342414B46434445444951524A474E4848444247454E52
656F6E59645A574C483A3F4853555058544D51444C4B49554956526451605555453E4146
46494D55525C6789ABB4DBCEDDD2DED1CCBDB5B4A4AEB4BA9CA688A06F7A5E7058505550
4D4656608891A195A2888A707D71554D61665E636E8686918A9492AA9A9E8A736D6A6B78
819199AAACB4B0ADAB9CB49CBCA7B3A8B7A1B3A4B7A6BEB4A798808A94A5977A64463D42
3F3F44433E443F3D3B3B413C3E3E3B39393A3C3E3D3D393940413D3E3E393B3F3D393B44
3A3934424038333C3D3B3A3A3B3A38373F3B38383B3E3B373D3B3938393A3B3A3A3C3C39
383A3B3A393A3B3B3939393A37393A3D3E3D3D3A3C3D3C3A3A3B3B393C373D413A414A46
3E393A40413B3B403D373F423C3E453E3D3D4A4F434142393C3A393A3B3A38363D3C3B3B
3B3A393942413C37393D3D383A393736373C41453E3C3C3E3D3A3736343C3C3B3D3D3939
393A3B3C3C3C3C3B3B393A3D3C3835363E38373D3E39393F3E3C3B3A3A3A3A3935393B3A
3B3E3D3B37404644403F40413F3B38383B3C3C3A3C3937393B393635383A3A3A3A3C3F42
453D36373D413D373E3B3B3D3C39383A3C3B3A393B3E42454C48474E5654473B37373838
383A3C3D3D394246383D39403E3C383E49453B3B4C474D4D544D53545148473F43473E3B
393A39373D423D38363C37443E3C3C3D3B3C40434240444A51576969756E84789B78918B
BAABBDB0CABCC4B4A6A397A49D9E8B6C5C514F6C82B3B3B69DB5C0DADDC7C1A7B393977A
936F8E6B8D6896A0CBD2D9DECDCBBBAAA3AFA4D7BFE8D1D5CDD1DAE1DCDDDDDBDCD4D1C3
C8B0AB98A494A38D9D8199A4ABA79D91847A7C82798876A087B1A2B4A6A684816B6E7D94
B2C4CEC1CAA4A88CB0A2B59EC1B2C6B1B69C816A5F584B4A463B587464483E4B4F7287A1
C6CFA89D634A3E403C3C3F38393B363E3536456A73626D72523B3C3A39353D343F363C39
3F3F3C48443D473E3A393837383A3B3C3C39393D3F3C373334373A3C3C3A373535343A3B
3534393732475370A3B9BA9E70684236373139393C32303637343333353031393B393E48
4D55514639313534343F53534B4A3E3335353537393937343534323235393937393D303B
313D2E37372F3D48736D92ACCCDEE1DED2A7755F
474748494948464548474645454444433D414945434846483F424647474743404545474A
494543444E4946474C4E4D4A4B47464646484A474C464448494544464246484746474746
4542444845434343424040444645424243434B42493C454C464549453F3F444342424F53
6064695D6C6662524842495B5E64575C615A5C5563546752654F5E605A6456564D4A494B
4E4C4F5D5B584B5A7197C0CBC0C6C2CDD0CED9D7CED4D7E8D8D3DEBEBC93A49E9E9AA8A2
928296A6C8DAD9E2DBD7D5C9C6BE8D6E90B4B3AEA7A6AD989E93A1BBE0D8D5A4B5A0B4AF
AEC3DAE1DAD5CAC9C3C8BCD4C0D4B5B79FA4B0D2CEE1DBD7D9A79D6C61504B433E353B45
3F37393C3D454445413C3E3B3C3E3C3939393A3E3E3E39373B3C3B3F3F3E45453F3A3942
3E3F3C3A3D443A333A38383B3C3B3A3A38383837393C3C3A413E3A3837383939393B3C39
393B3B3939393A3A3A3A3939373935393C3C413F3637383A3B3C3A3839363B3B353A403C
3E3A3B3F3F3B3A3D3D373E3E3D3C41393D3F48483D3B3E393D39373A3C3B37353A383739
3A39393A403F3C3A3B3D3D3A3F3F3D3B3838383A3E3D3D3E3D3B3938363B39363A3B3A3B
3938383A3C3E3D3B3936393F403A36373C37363A3B393A3E3F3D3C3A3A393938383D3F3B
393C3C383C454A47413E3D3C38373637393D40423838393A3B3A39393E3E4044433F3D3F
433F3A39393A3A3A3E3A3A3D3E3E3F41403F3D3C3D4044463C3E414444413C383B3A3836
373A3D4046394B414B464C53615243464E4B413C4A454A44433A3E3B43413E3A3F3E4441
3C3A39373E443C3C403F373F41383F3D3E434B515560758797807C5C646E848F9085759F
9FC5B1BAB5A7918D837A84869189AF878081AC99C4CFC9AABCBCD0C4C1C0A9C1A2BC9E9F
817D698E678372909DB3C8D9D3D4C5BABBB2C9B4D4C8D7BAC0BFD2CBCFBEC1B6ACAA9192
7B6F594A4C4F515F5865749C98A9B4BBB6A59B9596808F779F9AC7C9D6C8D3B4B1A8ABC5
D0DBD9E6C7E4BBB5919E8CA997C3C1D2D3C4B7ADAEADA09F63674F5649625975ADBAE6C3
D9CACCBA9C725544374B635D604E3A443D4D63868B93B8BD7B40373C39383B3937363A39
37335370786A4C473B3B3A393838393A3A3B3B3A3734363834393C393737373639383D39
2F343D3B466C7795A0987E48403936323A3C31363832333A3934343A383A3A39393A3936
3B363235363434353D414C463B3B363132333436383938383736343333343433373A3837
33383543434B568491A2BED8DCDAC7AE87594443
4D4C4C4D4F4E4B484A4A4A484747484947484D48484D4B4C47484B4F4F4C49494846484B
4C494849484746474A4C4C4B4C4747474345484547464647484746464144454546494844
433E414542424443434243484947454641464E464C3F424547474C413D404B4848465355
554B4E4A4C4C4B454348445253594F555B54524B50494F4F53514D514B52484E4D545454
504B5263685A4041496E999BA69CA6B1BEC8D0D5DAD4DBE2DCD6BCB492928F8B9FA1AEAE
ACA3B5C5C1C8D0CCD2BCD4D5D1D8B797B2D9E2DCD3C1C2C2BAC5C2DCE5EEE7E6D8DDD6D9
E4E0E6DCD9D2C0B79F8F9A85978380715E78A6C4E0D8CDBCB6876D4F3D3F353E39373D45
4139383C4046464841373938383F4140413D3B403A3E3B393C3B3A3F3F3E46413D3C373D
39363D3C393B373F3A383A3F403E3B3C363737393E42403A3F3D393838393938373A3B3A
3B3D3C393C3A3A3B3D3D3B39393B363A3D3C413E3C3B3A3A3C3C3B3A3A3C3E3C393C3E3C
3C3C3C3D3C3A393A3B3A413D3E383C3940454A453C393B3A3B393A3D3E3A39393B38373A
3B3A393A3B3A3B3F403E3D3D393B3C3B3A393A3B3B3B3B3A393938383A3E3A35383A383A
3E3A37383C3F3F3D39383A3E403F3D3B3E3B38393A3B3C3D3E3E3D3C3B3A3A3B35383A3A
3A3C3D3E3C414442403F3C383C3B3A3A3B3C3C3C37393B3C3B3B3B3C403C3E46463E3A3D
35383A3938393D423F3B393D4042444741403F3D3C3B3B3B3A3B3B373333373B403E3B3A
3B3F43464D4A4D5C5B69515A54473F403E3C3D404841453D3F3E47424043423C3B333F40
3F3B3B393E413A413D3D39354239525069768DA3AFB2B4B78C7B5A58695C746C836B6F57
72636D6B705963676B726A737B8E9AAA9CCDCEC4B9B2A1A6A2B9B8B0AD9C9E837D69665C
4A534B60536758707B8E97A09FA8A3A38A93819F90B8A8AB8E9B9BAF8E8D6E664B494C47
4D45484348435549615B6D7D8D93929FACAFBBC6BFBAA7BDAECCCBD8D3DCD7DBCBC2BFCD
DEDFDED8DED7DDC7CEC7CABBCAC7D4D0D4D5D2C0B2ADB2C7BDB798B2A7C1ACC9CAD4D1C0
B5B49C9A92816B5A6798C0C4BFA28283727F828A7884ADBA834B3D3F3D41373F39433E46
504F6D888F7448413D3E3F3E3A383737393A3A373334373B393837373634363938353733
304457557C867278515345383B353535393933363C36333639373D4A45453F373537342D
36343638363230333E373A3633383736343434353536393A343434353434363936313E32
3D3543564D5067868D90BBC4BC956856473C3D37
4D4A494A4D4E4A47474747454445484A48464944474F4D4D464343464643444844414247
4A48464741434546464647484846494B454546414045464344474744404243424446443E
463E40423E3E414042404247484544464345403C42403D3F4440463E42424B44483F4849
47393E41403E3B3F475240414946404747434538453D4142494942414F5752575257534F
4F413F464F4A404B48605C5C60637184AAA49099AEACC3BBCFB7C1A4BA96A3765655544F
5A565D646B7C8A9D998194A0B7D0D3C7CEDBDFDFD2B9D7E0DEE1DBE8E8E9E8E4D8D6DAE0
E5DDE4D3D4D0C5C0ADA5959C93A4939595B2B8C1B8AB878057473E3D483A403B49413A3C
3F3C3B40404443453D33393D383F403D3D3C3D46363D3E3D3E3B3A403E3B3E37363B383C
43393D393A3E373C3D3B3E43443F3A3A3E3B393E4A51493D3A3938383A3B3B3A35393B3B
3C3E3C383E3B3A3C3F403D393B3F3A3F413C3E37504A423C39383737393F403D3E404040
3C3D3D3B3A3A3937393D443D3E34383A333D423D3836363838393C403E3A3B3F403B393C
3C3937383E3936373634363A3A3B3B3A38383B3D3B3C3B3A39393A3A363B39363B3D3B3C
433C36363B40403F393C3C3A3E43433F42403D3B3C3E3F3D3E3E3E3D3C3C3D3E3B393A3C
3A35363B373838393D403D37363434363A3B3A383B3B3B3A3B3B3A383E35353F4138363D
404243403B38393B423D393A3B3A3B3D3A3A3A3A3937353439393938393B40433D3C3A3B
3D4044465A4F5347504B3B42363845493A323B444C45473E403F4439413E3D383E394342
3D3A3D3A3C3B333F423E3E40696C887791939EB2C0BFB4AB98897D767969768E797B5E64
485E4B634E567C9B9A88736B887CA89EB4ABBC9EA1756E6C6C706F5E584C4C4249566E79
7AA092AE8FA16D7D6B705F554E5146474744455658554B4D4A48565259525B555B5E6665
5C5B53574B484D4C5F66595661666C8EAEBACFDFD9CACCCBD3CFD7D1DFD5D8D5DCDAD3DC
DCDED8DFD7E6E0E6DFE4DAE4DDEADFE0DAD5D5D6D9D2C7D0C9AFBEB0C7C1C8B3B7ACACA8
ABABBBC9C4D4BE9EAFD2DFDFDFDBD9E6CAC6AF9C7E778EA596817C7770765D6968817B8E
7977656761463E3B383C41413E3B3A3B3837363537393A393B3332383935353B39373A37
3A54675F674A444037383935373E3443433640363536363B413D3D484C443A3333363736
3637383334383736373138363135373C393836333233363A353435373533363C45403E41
3A404668695B5D8C898D8F70654C3C433E3B4234
47494A4A4848494B4A49474646474849454647464545464847494A494847494A4B4A4846
4544434345474745464A4C4B444244484745464B40444543434748474143484945494B46
414445423F41484C404343414144444141424048433C444140453C4340484B4952473F42
494A47453E3F43494A4643433D404144463F3B403D47473F3E3E404456726968675D4845
3D3F394046495250484E4F4C4C5153516365676B756E7C7A808A8FA8B2C8C7CAB1A87553
4F3F3D514F4A8EA5C3BEC4B9D4E5DFE5DFDCDED1DED3D1D6D5D6DBDFD9E0D9DBD8DBE1D8
E0D6D6CFD1CBC6B5AC9A9C7A9283A381A6909D6F6950493E3C423B3D413C3C3E3E483A40
41464544463B4140403A43423838423A383846433C3E444548413B4B41403E3640393A3D
3E3F3A3C3D3D423E3F383E42413C373F443B3E42617353414443413F3B393A3B3D3C3B3A
3B3D3F41363A3E3F3C3A3B3C3A39393A3C3C3B39433D414E4D3D34383D3F323D393C4247
3C3F3D39393D3D3B363C46473C363838373C403F3B393E433B3B433B363D44534941403F
3B3B3B35383F3B363C403D3A373B3D3C3D3F3F3C373B3835393A3D443C3A3837393B3C3C
3C3A3635363A3F4239393A3D4041403E3C3C393E3741403C3A3A393A3B3C3E3F3D393A3E
3C36363C383639373C44403F3B3B393734333436423F3C3B3D3E3D3C3234373A3B3B3A39
3A39393B3C3D3C3B3A3C393C3D3B403E373C363939363E3C39373E39373A373E3E3E3F40
424446474248473F3C3F3E393C3D3E3F42464A4B40473A373C3A3C3A3B3E4148393B4048
403D4442383E48434955576F6F9173858EAB9BAA9FA69B91846A6F5B666A89839F725048
4C4D454A4A6274868F86817E7A858787747A5E57434544404C5245433F3F46567B8CB2A8
A996A3808E646663694D4645454A4748555460656E626F666A627578838788828F7A9986
947D82807F7E7894969E999AAEB3BAC4D2DAD8D2D1CBC1CCD4D4D1D7D3D5DBDAE6DCDCE0
DCDFE4DEECE4E7E8DFEBF0E3E7E9DFD8D1C7C0B8B2CED4D8CBC4C6C8BFCABEB5A49997A3
9AB0B7CECACCC4D4CBD7D6E4E2E6E2E6DFDCD7C6C6C2CBD0CEC8C5CFC4C1BAB2BAD0CFD6
D1BEA7808B533F443C3A3F3735323F3A3A3744363B36383A373634373B3C3D3B433D3443
3B4840473B333F393B3B2A3E363E363F403940373731393B4C553F3D4037333838343337
37373838373635343039343433333B36343D3E3733363530372F2F3D3A355883627E4537
3F39414E869BB0B9A7775049393B38373B3A393C
494A4B4B49494A4B4C4B49484748494A46484A4A48474748424345454546494B4D4C4A48
4644434345474847474949464646474743403F4243474845424447474343454440434540
3E3E3F3F3F40454A3F424240404343414C4A474C47424A48484A3E42414C5252534A4346
4C4D4B4A444140424342444741434142433E3A3F4449453E3E40444B62705D554F493D3E
3C42404443404746444647484B52595D6A5F626F7B73796E7C727E759595B0B2A5B0987D
6C5B68887E5A6694ACC7BEBEB2C1B7D1CFDDE0DFBDC6D3D1C3BAB8B3B2ACBDABBFA7BCBF
CFD7D9D4D4D6D2CCBCA7A07B83768B77736C765E4D403F43373E3F413E3C42414351443F
383B3C3B403B3E3637364244403E423A3B3C45423B3A3F3C3C3B373F3F3F423D46414647
3F3F3C3C3D3D403F3A353B3E3F3E393F424149475E7961454138333B423C3536383A3C3D
3D3C3C3C393B3D3D3B3A3B3D3E3B39393A3C3C3C3937383C3D3A3A3C42443B443E3C3D3E
3B3D3D3A393B3A373B3C41413B3A3D3D383B3D3E3C3B3C3D37373F3C3B3F3D433D3D4243
3B383835383E3A33373B3938373C3E3B393C4042353A39383C3B3A3F3F3B38383A3B3B3B
3A3A3C3E414242423B3B3B3D40444648393A39413C4846423B3E403F3B3A3D413B37383D
3F3C3E453B383C393C433D3C393A3A3A393A3C3E3736353537393B3B3838373738393A3B
38393A3C3D3D3B39363C3E454540403A363E3C3D39364043403E444140434045393A3A3B
3D3F41423C40403B3A3E413F38383A3C3D3B3A3A363D36373C3F48475052565B4D4E5056
484E5B5A4E535D586651504B5661728FACA9A18B956F715A49544D4A668A999F8C7E6069
698E78735B605A626D6D6E6B4B4C4444394A3F42423F3F3C45505156565E65757582837E
6B765660434E414A4A3C41424044484F7E6F93759F77957D82808E87857D7773707589A4
A3C2C0D3BBB7A7B6B8C5CDD5DEDEDBD6CEC0AB9A96838D879C99A9A7A9AFC0CCDDD8D8D7
DBE2DBE2E0E7DFE5DDE9E4E3E3DCE7D8D9CDBEAFA4B1ACACABB7B7C2BCC2BCC3BAB1B1B0
A0A1949388908A948FA5ABB8D3D1E1E1E2D2CABBBDB5BBC2C4C3C6D5D4D6CBD1D2E8D3D1
D4D2C9D9CFAE827F44353839413E403C3635393D393D33373E3C3838383A3C3C383A3A3E
3938343C3D3D3434393B3D3735433F413C35413C3A373A35393F373A352D3A30402C3735
3535353536363636333632363531373731353431323739362A3933323C52768487683E3A
383B5A96BBC6D2BF87503B3C3C3A373939353B4B
4B4C4C4B4A494A4A4746454342424344444648484745434345454544434345464C4B4846
4442414144484A48484846424145484643424344424546423E3F42454A4747443F42443F
48403D4043414042434445434445464444414045403C4240525344464045444049444042
4748484746423F3F3F3F42474545403E413D3B3F4143414146484C555055484846444343
40444244413D4141484441404042484F5C4A4F5F66595A4B4A4A41534D5E5F6C6D6E5D58
5A565A636543593F6F7B9A87847C7386AABDD5D1CFCFCAB09A8D8370716A6D5F60626F93
9AAEAEAEA2A9A4ACB0A9B0A6B1B5C0C1C8C3CEA98E5748333D404145444C5A545C604C3F
383D3E3B434748383A373D3D3D3D3D373D3C3F3F413D423B363C3C3D413E423D403B403A
4140403E3E3D3B3D3E3A3C3B3D403B3C574B4C4F6E9275453F3E393C45423938393C3F3F
3E3D3E3E3D3D3C3C3B3B3C3D3E3D3B3A3B3C3C3C3E403E38373D403D3F403B413D3B3B3C
3B3A383536393C3E403D3F403C3E403D4040414242413E3C3D393B393B3E3B3C3D3C3D3C
36363939383E3C3637393736333C42403B3A3C3D3A3D3B3A3B383739433C37393B3A393A
38393C3F42413D39393A3B3B3C3D3F403D3D3A4039403A333A4045423A363A403D38373B
3D3C3E433D3B3E3A3C413A383B3C3C3C3B3A3B3C38383939393B3E403B3A393837383838
38383A3C3D3D3A37383B373A3A383D3B383A373C3F40464639383C3B3B3D3B3D38383838
393B3C3D383B3C3C3D3E41423C38373A3B393A3F373938393A404B4955525151413E3D40
3D4249453B3F443E404134514E6C7CA99DA171946B745054595B6F5D7A7E8F7274627374
9C9BA09792886E5E554A4843403F393F39453B3F3C3A464C54636F7B7869785B6153554F
3C473A3B3B363E3C3B3A403E3B41464D4F595A6B515D56666972828080766E6F828BB7BF
D0CFD4D6C5BDBAACBBAFC1BFD2D2CCBDAA9785787D7590899A96A09FB0B3C2CBD3D3DBDC
E1E5DFE4E1E4DADBDFD9DCD6D6C0C5B0A99D89776C6D646758766D81848D96AECCCDDBDA
D8CFBDAC9DA2948C7C867F7B9AA0B7CFC8C7B2B09686878E969DA8BECFCDCFC9D8D8CBC0
C8B8BFCDD9C1B0A27B55473F433E3739413C3E3E3A3938423F40413E3B3936353C3F3C31
3E363E3E3F3C363B3836444A647C8481684A413536373A37353838383535373838343333
393837353534343534333238373034363836333233353737363D3E353D5059654D3A3643
4167A0CFD7B69A7847303537483F383836334668
4C4C4B4B494948484C4B4A484747474746474848474544434A494745444444454A494846
444343424448494847484642454A4C46434446464B4B494746484A4B4A47474541444640
423E40474743474F4445454545464645413E4146423F413F3B413A434246423B3F3D3C3D
40424243413F4042423F3E4043433E3C40403D403D3F41474E4C4B514848414645434642
44413D3F42444542474241454542464E433A43494C414440413E43494D474B515752474A
4E4B4A41443F4046384E5564646E628895C0CDD7D6D4D3C4C0B9AD93ABA3C08E94685C64
4F64676F595F586161626F767D8D8EA1A2B3B6C2A4906E5357626C797F7F765E524C3D35
363B3E3D3F4949373C3A3B38373D3C393E3D3C42423A423F343A40413F3B443E3E3C433B
3A3A3C3C3E3D3A403E3A3C383D4743414543453D485F58453A4F52484A4A3E343B3C3D3C
3A3B3D403E3E3D3C3C3C3C3C3C3C3C3C3C3C3B3A3D40413B363B3C353E3D393A393A3D3E
45413D3B3A3B3E413F3E4144403F403C4343434342413F3E433E3B393B3D3B3B413C3836
37393A39373E403D3C3B3936383E43403B3938363D3D3A38393A3B3E453D383A3C39383A
3E3D3D404243413F3A3D4142413E3D3C3A3B3A423D464038373D423F3835383C3A363538
3938393C3E3D403B3C4039373B3B3B3A38373636393B3B393736393C393A3B3C3B393735
3938393B3C3B39373C3E393B3C3A3F3D3A38373B414443403B3A3C3C3C3D3B3B3A3A3939
3A3A3B3C383A3E41403E3D3E403A393E3F3B3D443D3A3A3C3B424841423C3B3C35353A3D
3C3F45443C393D40414558447B5E7B80877880778C6365545A5A656A625E5B414D5B6598
94AE97A47B705649423C3D39393A38413A3D363B3F4055605F666E776D5C56423C40393D
42433A4341423B4243433F3A3B3E3E4041414557536D779594A3B4BDC4B8A8A3B1B9C1C2
AAA3939A87927C8D819A9CABB7BFC2B9ADA7A7A8ACBAD0D0CCCDBDC8C6C4CAC8C2C5D5DA
D9D4DCD1DECECEC4BEA88F946C835C6A5E5B4F484A4E53606C948EABB4BEC7D6D8D7DFD9
DFDBDDD7D7DBD1CDC1C5B4A8A5A5C8CADDCFD6CFAA928785868891A7CEDBD1E0D5E3CCCD
CDC2A2AB87937E80928C9E967F624A5272686451433340516C6965574A443D3D36423644
413356814B343B413D3E568DAAA48F7F65483D343935333434353731373A323A343F393A
3B3A393736353534333333373734353639393C3F3D373536453D4D403D422D3C34516277
6A8CC0B89A6B4B3E33383F363F38343739394F71
4B4A4949484847464645444342414141464544444343424246454445464748484A494847
4747474745474745454848463F44464343494E4F4A45403F42434240424143423F434540
3E424A4D443D465743434344444444444B44464844434343464C434A474B47413E3F3F40
414344443E3D4044443F3B3B3D403C3C414240424143444A4F484245504A42413F3D4440
403C3B3D4246434138353941423B3B423C40443A3E383A3F3D3E444F4C443F433F444649
423F4541433D4A3E49434B463C4A575D768BA5A4AEB3C6C9D1CDCFC2C4CABDBF9CAB819F
88A0B4BE9D9478605C575D636173708A8894A6ADC2BFC5A8ADBCBEBFB89B74504F433F3F
3E3A3D463E4545363F3E403E4047433E3C3A3C48473F525B53576066747478624B3B403B
42413D3C3F3C3A423D3B3E3D465452505861604F52697B8987836F5A534E423C39393A39
38383A3B3D3D3D3D3D3C3B3A3C3B3B3A3A3A3B3C38393F403B3D3F3A413F3E39393A3C3D
3936363A3A38393C3D3D4345404043413E40403E3A393B3E3E3F3E3E3E3B39373D3C3B3C
3F3D3936393D403E3C3C3C3A41403C3736393A38393838393B3F4344443E3A3C3D3A3939
3D3C3C3D40424342363A3F41413F3E3E353738413D47423C383B3D3D3B39393B35343538
39393A3C3D3C403B3C403B3A39393838383837363B3C3D3A3635373A38393B3C3C3A3837
3B3A39393A3A3A393D3F393B3B393E3C383A3E3E3D3C39393A3A3839393838373C3B3A3A
39393A3A38393C3E3D3B3B3C3B393C44443B36393E37393D4048473C3732363A3A3C4243
3E3A3A42453E3B425C8176796C6E7389686D5670535E4A4F3C483D3E47414550656D9481
9C8A8A726758423D4041413741403A3E383D485778747F7A6659535644403F3C3F3F3D3E
423F404B4A614C5E4A463E4349403C467474808090A5BCD2D0D3CBC8C2AB8C7B79757A6C
63555B696A827B9996ADAAB7BBC0BFB7ADA7A5A4ACB1B9AB9B937C82747273736A70797B
827982737F6C6F626753574C5A6B6D858F94918E92939DABC3DDD2E0DCDED7D0CCD2DBDA
D9CDCFD0C3C6C5CBCACFCCCCCDD5D5DED6DCDFDADDC6BAB5B1ACADBCD0D6DDDAE4D7CFC4
D4D0D8AEB39AACA5C5CEE4D9C0B3A9BBBFC29EA2666C5D77786C5D4233383A433E404445
8C718D6C734730303D5076B4C9985D463F3738383937363C3D3A3B3A38363B3139333B39
363636363636363632343635363A38363D3A393835353F4B3F3B3F34323A3436586E7A86
67667A6D4838353A393A3A35393A3A3B3A343744
4A494848484847464B4A4A49484847474D4C4A4A4A4B4A49444443444546454445444444
444444454547464444484A494647464342434546504842434545413F4142464541454845
49484848423D40484746464848474749544847433E4040425B5C4B493E41413E3E414241
424343423F3E3F42413D3C3D3A3F3D3C4143414241444445494540424C49433D3E3A423E
3E3D41403F403B3D3F3D4147453C393D3E4343333E3D3B414945514A503A3C37383A3B41
4042473F364144363D48493D3F50454B3D5954535E637B828E8A95919C95969593918092
86A1C7D8D1D7CAA69E93989EA0B7BDD5D1DBD0D9D0DFDACACCD9D3CEC8B39B8965473D3A
3B363A454144473D40383C3C3B424246454E5B6E8E818C949098A5B1B2B6B28860414140
3D4139414A44474C494D5D6B81999EA19EA9A3949AAEC1D1BD8959484339353A3B3C3E40
403F3C3A3B3C3D3D3C3C3B3B3E3C3A3737393E413D393F433C3E44433C3A3F383B3B3A39
3F39383D3E3A3C423D3C40423E4148493E3F403D39393D413D3E3A3B39373B393B40413F
3F3B3A3D3E3C3C3B383A3D3C3E3C3835383D3D3939383B3E3E40413D3F3E3D3D3D3C3B39
3F3F3F3E3C3A38373A3A3A3939393A3A3A3B3A3E353C37313C3B3B3C3E3E3D3C393A3C3C
3B393A3C3C3C3F3B3B403D3D3F3D3B3A393937363B3C3D3B38373A3D3B3A3A39393A3B3C
3D3B3938393A3A3A3C3D373838363B3935353B3C3E3F393840423E3F3E3C403F3C3B3A38
373736363738383736393B3D3A383B41423C393B40393B3D424941383B363D40403A3B37
3F3C383F47464D5F8A737158795E6B4F4D46433D3A373F3F394040354C4C727D84817279
667359593C39353C4142453C3F423E423E404F5B726C6C5D483D363A3B3A423546344545
5D5F86748E857871575853606652526894B4B3C8B4D6C6D0BDAF8F80726554484F4E735F
89739AA1B3B8BEB2BEA1A199999284766E6860596C5C6B585C4C4A414C49454743494743
4340434748494944414F65688F8BAFB7CFD7DAD7D8D3DCDFDDE1D9D8D1D3C9C0B7C0B9B2
977F73766C6B6B72727A8798B4B8CCC7E0D5EAD6E1D4D5D7D8D5D1DACBD5C7DDD9E5D3D1
CBDAD2C9C2CECCD0D1DAE5E3DCDCCDD1DBD1DEBBC79EB8B5B8A7936D585A586078AFA5B8
9383604843493F47454F89AE9069433A3B37353737343433322E39546260594E3F363437
383736353534353534363934363D3A3733353A3D3A373B423C3B374C473846404B4E564F
383B343E3735353735313236323839393C383335
4A484748494A49474747474646464545424140414242413F474646474747444244444343
434343444648474445494A4944424245474646474743414242403F4046484B4842454B4A
4944404044464545484646494947474A544849454143414341463B3D363D42423E414140
4042403D403E3D3F3F3D3D3F3C42403C3F403F403D434341454441434349463E413A3F38
4A4546403D3F393C3A38393D3D3A3B3F4141483F4B4A484C4C50404C3643353D42444041
403F41383B413E433F3E44573F4B524A474A4A434D444A4049475958575E5378789FA2BA
BFBCC8B7B1A6A48A8D88A1B5C3D2D6DBDEDBE3DCDECAC3AC9298989FA5A4A49E93664F40
3F39383C413E46413F3A4F5F6A717B8E93A6B7C8E3D7DBD5C2AE96887A807D5E4C3C4143
384A4D6D87818686979CADBBCBD8D6D6C8CCC6B4A19CABBD8B5D4142423F3F3F3F3F4043
45433F3B3A3C3D3C3A3A3C3E3C3C3C3B3B3C3F423F3A3F40373B4340433F463A3E3F3D3C
413B3D454339353A403D3F41404447453F3F3E3E3E3F40423F3F363839393F3D3C41403D
3F3D3D43423D3E3F3B3C3E3A37393A3A3B3D3C383B383B3E3D3E3E38393F403D3C3F3E3A
494A49443E39373742403E3B3B3A3A393B3D3C40363E3C3A3C3C3B3C3C3D3D3D3E40423F
3B393B3D3D3C3F3A3A403E3F43403D3A39383735383939373536383B3C3B3A3A3A3A3B3B
3D3B3A3A3A3B3A393B403E42413C3C373833383A3F453D3B3A3E393B39373F3E3D3C3B39
37363535363A3C38383C3D3B3C3B3A3B3C3D3F41403F413C41453A373C373F40423A3E39
35424442474B5B76716958634C4F443C3F3C3A45393F3B3E414E495D556F888B88625C47
553A4044383D414740393D363B424147454045453D3F4139383B3A4245493B3F3B3C404A
657C908A877364575F6D635F60525565899DA9B4C0BFB09E827A64645E687273738B929F
A2B7BBC6B3AD877B675A4D5558534A424043423E4639473F493A433E3C43414440464142
454857636B6E726D648876A18CB2B1BCC6CACCC8CAC7D0C6CABAB7A190806C6E5D6E5D66
576974898E857E7E7C7E87938B91A6BBD1DBE3DADDD7DCDEE0E0DBE0DCDDD1D2D9D1CCC4
D1CCC4B0BBC0CFD2DEE7E4E2DCDFD7DCD8E6CEDCB5C0B8C6DCD6D5C0B7BEB7BBD2C8D1BC
AC684D3C41424B6C6E666E52483F3B3C3D39363839353531363D5994928867644345343C
3B393736383B3E413C383B37383D383939393A3B393636373E3E5F795F403E3B363C3D32
2C3D323A3E393738393837383A3D393739363437
4A4948494A4B4A4949494949494948484848484A4C4C4947444546494C4D4B484C4C4B4A
494949494749484546494A484743444A4C494647444446494845484E47494B463D404748
4849484340414547423F3F42434040434A3F464643453F403D48434A4245444140434341
4143413C3F3D3D3F3F3D3D3F4045423C3C3D3C3E3C45464344433E3D3944433A433F4641
5C4D463C3D433D3F3E3C3A393A3C41474E48544D4D433D403637413B453C403A3D423E3F
3F40443D384441363C424B514C4C434846564C4844414D41473E4A4243474247525F736F
887884787D5E60535549607390AEC9D0DCD5DDDFD2AD8A6E524B48535A5F665D76534A3E
42414447493E4747495588AEACAEB8CCC8D4DADFE8DDD9CBB69B73574F514C3D484B5050
61808EBFE0D5D5CBDADAE3E4E3DBC9C2B6957B726254585E463A3B3C373F453B3E3B393A
3D3E3C393A3C3C3A38383D41373B404242404040424148463D444C465A52554244444343
3F43546A6D5F5251443E3F444546433A3C3A393B3E403F3D3D3E373E4341433A383D3D40
47453D3D433F444844413E36393C3C3836383B3B37323539393E433F353F433E3C403F3A
4546443F39373A3E3A39393A3B3A38363538383B313A3B3B3A3B3B3A38383A3C3A3E403D
3A3A3F443E3D3F39393F3E403E3B3838393A3A3A3F3F3F3D3B3B3D3E3A3B3D3D3D3B3937
3C3B3B3B3C3C3A383F40393938363C3A3D3B423E3B3E393E3D423D3F3D3B4647403F3D3B
39373736363F44403F413E373B3C3C3B3A3A38363B3F423B4043383D3B343B393C373E3D
47514A4653564E4E4F463F3C3B3E3F3B4035323E3A44474F5D7066626E62696A584B463E
40423F403D3D3B3F3B3A413B3E40393B3C393E39353C40393E41393D4742454053464847
46635A695B52636B88A28B6D69686B6B878D88919280746D70777887808996978EA5A998
9490887A5C5D454E48433741383E43403D3E3F3F3A3F3C423F3C41535C758089868B8892
9392B2ACBEA7AE9BAEA7BCA1B8B5C8B6B8AFA18D8376786065516052585A5B7D6D918AA7
9BB8B7C4CBBFB6B7BCBDBAB8C0AFC1BFD5D1D8D3E1DDDFDCDCDFDCE1DAE6DBE6E0DBD1CE
BCBEA7AD94AEB7D0D6DFDBE4E4E7DFE2E0E0DFBFB89FBBBEDEDFEADDD9DFD1D0D8E4DDCB
A4B686735F527688644F50484B48464140403B3636353B383933417F8D6E4E3F3D383536
373636383E48515743393B3A3A3B343A3F3C3837393A37343B3F8169393E2E3737402F37
393937383130363A3635393A3537363638343239
4848484847474747463F434549494141423D4749484A464741434443464A494445434946
494F4542403F4245454344493F42424649423F46434548484441464D4243454643404247
46494742414444414146494643444544424542494840444340464945424243433F404439
363F424B3D423F413A4241434247453F3F4546423F464A4C4E483F3E3D44403A4044403C
4E4944403C393C413C3A3C363B454E654F4D484251474144404142403D3B3A3A373B3F41
464C4C493A3D373E434249454C4A4542454B4B47424849423A3A4044403F413F3B434A46
42454C52514B4A4D4547536CAACBB6B7CDCFCFD6CFBB8C7D605A4D434144413A40558C7F
776B7B7588838C81909DC2CDAE848383918CB7CFD9D3D9D8D9C2B2A39A8875679794B19D
BACAE0E6E4E4D7D2D7D5DBD3D2C6B495875F63485142423E3D3D3A3F3C3F3A4D44403B41
3C3840393C3E40494437393D3E40413F3E404345434244493D584769485D464A4A5D798B
8CA2A0A1A085805E50414844443E3C3C3A3A42444545463F423B48484A4F464F3C3D3E47
4F484147403C3E3A403B3D3A393C45403B3B3A413A393944453C3D3E393A3B3D3F434443
3D3A3F423E3D3D373B423C3C403A363839373C3A3A3C383B383B3E3F3F3E3D3D383A3B3A
393B404538383B3E3D3A3C4147443F3A37383E43463D393C3B373A433D3C3E403C3C403C
3F41403E3F413F3B383A3D3C3B3B3E413A3C3E3E3C3A39383A38393C3C3A3D433F3A3738
3837393D3A3A3F3A3536353B3D3D3E3C36383C36383B3D3C39383A3D373D3A3C47463F45
434C4C4644413F433F3A3A414039383D3735374050616E74806C5F5B544C48453F3F3F41
42403C39383F3F453D413C3D383B3C363F3E373930343738403C495D626A665F6C857162
5B7578957EA27E8D91A2A294818078859E938D695F5F6B778A817F807B797B7971615E56
53494B463C3A363D343D3C3B403B3F403D3F42433F454C434250747EA9AEBEB2C5CBCFCF
D1D5DCE6D8D7C3C8BAC9A6C2A8B98687635E4F5052584E557473A29EB8A2BBACC3C2CFC9
DBD5E2E0DCD6CBD0C3C2BFCAA8B2AAC7AEC9CBC9C2CACCCCCDC8C2C3CAD3DEDAE1DBE3CA
D4C8CBB3B8B0C3BDC3CACCD6D7E4E3E4E3E2DACF9DB3A3CCC0D9DCD2D8DCD9DCDFDCD0BD
BAC1D7BCC29E9E7C9891B39BA79D917C6245483D3B38363839394B674632383C35383936
333A384A4B3C57413B383D423C38393737353439373136364044433C37393C3B33333435
34323436323137363639363A3439373B3731393B
4F4E4D4C4C4C4D4D49474C4945474B58684E47464548444247494A494B4E4C4744434846
494F47444442424444424448424848464848474B474647484643474C4744454747434040
4343454645424142424546423F41424142444046464046463C424746444544423F424942
3E423F423F423C413E4743414346443E3D41423F444848484A4640403741403B3F434242
3F3D3D3E3F3F43493D3C41424950505D4845433F4C4442443F3F3F3D3B3B3C3E3B3D3E3E
4044433F3B3D383D3E3C403C3F3F3C3A3C41413F3E4243403F403F3D3E3C40413E42443F
3F4044484744444743434547678382939A90878B8B907E7F727D807368635B505177B5CF
B7AAADC0C9BBBDBAD2D8DDCAAB8B9A91B6B0D6D3D8D9E1DBDBD4DEE4D5CDA5B3B5D5D5DE
CBDCE4E9DCE9D9D7C7CBCFC2BEAEA4979684947E7A5B473C3D3F40423C41435B59424A70
6A4740453E3E3B42413B3F41403D3B3E4244444441384338414A42534A5C5D6B849CC3CE
CCC7AB947F5D5B4946473D4B3B49474B54667B8F84817875746664554A45373D3C3B3A3F
45413F47423F3F3C3F3C3E3D38383E3D3C403C403A3A383B3C3C3F403837393D403F3D3B
3C393C3E3C3F4340353C37393D3B3A3538353A393B3F3A3D393B3C3C3A393A3A37393B3A
393A3E4238383B3E3E3B3D403E3E3D3B393A3F42413D3C3E3E3B3C423734373A38383832
373D413F3C3C3B39413F3C3B3B3C3E3F393737373737383B38383A3B3C3C3F433E3B3A3C
3D3B3B3E393A403C393C3B42373B413E36363A373637393A3A393A3B383F3E4554514442
3840403E42423F3F3A37373C3D3B3C413B3D434E5E6C747866564C49433E3C3837393B3E
404141403C3C393F3B42414138413A3B3339393F3D3F3F45466386A1AD8E90849D8D8678
9D9FB2919D9697968F877F74768885A1B6AB897B5B6F697B635A585954525452433A3F3C
3E393F3A3834433C453B453E3A3A3B3D3F474F4A4E4B627B7B9E98B8C0D0D9D9D5E1E0ED
E5E4E6DCD0B5AAA18879665F575C4F5859666F8392A8B0BCB4C5C9D4C9D7DEE1D1CDC4C9
C3C8C0BCB2A2A294997C73675E604F6659777C7C727B848378747D8691A6ABBAB9CCD5D2
D2D4DEDAD6D2D4CDB9BAB5B7BDCFDBE3DFDCDDB57D6162738E9CA4A09EA7BACAC9D3CCDB
C5DADAD9C9CA9EA096CACBD6CBBB97684B39423A3637383C3C3434413832393B37343541
4F5264736A4D4D3E3F3F474C453D3935383B3A3734323943453F37333232343633353634
33343536313135353537383A343133394235335E
4E4C4A484748494A44444A443F424B5D7C56474643454341454647464647454144434746
494E4946474442424343444640484741414547494A46444545444548494443484C48413C
403F444A48413F424243423F3E40424143433E41413F43434646433F3E40414141424844
41413B3A41413A40424C443E4444423E3D3D3D3C4344403E41403B3C3A42433D3D3F3F40
424040413E3B3B3E4440414246443B3E423D3E3C443D40403D3D3B3A393B3E423D3E3C3A
3B3C3A373739373B3E3D403E3B3C3B393A3C3C3B3B3D3E3D3E41403D3E3A3D4242403E39
3F3E3E403F3D3D3F4142473F475A63786A5A4F504F5E5C6178878874656360587379A4AB
B9A1AFBECACDDAD1D6D5E0D8C0BBBBC4CADDE2D8CFD8E6E7E8E0DDD8D3C0B69EADA4AAAB
C0C2DFCEEADEDEC7C7CAC8BABBA9A09C8B7A74524D413E44383C41423C3C3A4A503C3B4F
4B3B3D3F3D403D434542433E423F414544404044484E476766A296B3A9B8B1C7C0D5DAD6
D5B08064594C5656696770607875988E9E99AAA7A483725D574D4D433F413C433F3C3838
393739413A3B3A39383A3B3C463F3D3B3A3F393B3C3D403E3D3E3B3A3F39383D403C3939
423E3E3D39393A383B37333B3933383438343735383C37393D3D3C3B383738393A3B3C3A
3736383A39393B3E3F3D3D3F3B3D3E3D3A38393B3A3C3F403F3E3E3F423D3E3D3A3B3A36
363F46453F3B3C3D413D39393A3A3734403B393B3B393A3D4041403C393939383B3B3C3E
3E3C3B3C3D3D433E3A3B3A40393C413F393A3A37393B3C3B393B3F43494E4A4A524E4340
3D41403E42423C383B3A393839393B3C3E40454C54575654473E3B3C3B3E413E37393A3B
3C3D3F403D3B3C41393B39363339433F484357514D42585E778DBEC9B4927B8D858F8287
94A38D90709271786F6A57687A8596A8C1A39A6E72565B544A4442433F3D3D3B3D3A3F3A
3D3A403A3F3C3B3D373938373E4446586B85A1A1AEADC1B1CEC3CDC2C9C0CBB7D2CCDADB
E6ECD1D8B3AD9A998282739C79A88BA8B0B9BCC6C6D5D7D5D3CBD3A2C2A1BA9EAE9B917F
786C695C5C5149494B4743414241413D48454E47504A4E53535F747FA8B2BEB5C7C3D5D1
DFD9E5D4E0D3E0D6D2CCC3B6B6BBC5C9D0D9DDCF996D5D50584C4D4F4A556C779A8FA099
AD9DA9A9C2B3C09A9598C2B7A59D7C4E3D343B33393A393B3D3731343A39393536323653
775C5E59503B363733343B3F3A3535352E39373437383C454A3D34353836363834383934
333638363A3834353839383335373F3C3B3C5A9F
4E4D4C4A494949494642474646484A53664B484841454744484847454544444245454647
494B48474744424344454545464A4A454245484A4B45404244444343474342484D4A4440
3F41474B4943404141414040414343434A484544434242424A46403C3C3E404142403F3D
3C3D3C3B4040393E3F4A433F4442403F3E3C3B3C40403C3B403F3A3A3E42413D3C3E3E3C
3F3E3F413F3B3B3E433F3D3E403D393B40393D3A3F383C3A3C3B3A39393B3F423D3C3B39
3A3A3937393A393C3F4144443D3F3F3D3B3A3A3A3A3E3F3B383B4042413B3A40423E3A38
41403F3E3E3C3C3C403F4540414D5159554A484F4E606063656963575766707075776176
6A7E6C7A8E9CB2AEB2B6C8C6CCC2D5BACBB6CABBC3C9D1D5DADAD3C9B9C0B0BCADBFABB2
BCCCD8E4D8DABFB88A7A6B5B5F534F4E4E4A493741423F43454346444140393C363F3F3C
3E42423D3C44444A4E5156504D4441484E535E6AAEA7BBABC5BFC0B5BDB8C1B9C0C3D9CD
D1B9A69D9DA2B3BFB8C7B3C2ACD1CAC5B09B82877168493C443F423C3B3C373B403F3D3B
39393C41444644403C3C3B3A403A393D3C453E42423C3A3635393C43443A353C413F4044
3B3B3D3D3A3838363C39353B393F4E424942413D3F433F403F3F3F3D3B393A3B393A3B39
3736363839393B3E3F3F3E3D393C3E3D3A373637363D413F3E3F3E3C3636414037373638
383F4545413D3D3E42424243433F3A353A36373B3C3736383B3E3D39393B3C39393A3B3C
3B3938393C3C413B3737363C423E3F3C3E413A34383E44464445494E4954565350463B38
373A3A393B3D3B373B3D3C3736383836383A3E4347474440413D3D3C3A3F423F3A3B3B3A
39393B3D37363C403B3A3D3E404A4C5A4C5B544E4A45578999B3B6B68B72876B91778D7B
7E7488698E797861644D52515A7179938A81686D53553C3E403D3C3C3B3A3937403E4038
3D3C3E363838323F38413A3C425D7BA7C1CEDED3C8DABCCAB4C5B4B7A3AAA2BEC3DED5E1
E0DADECCD6C1CFC7C5B2C7B0BFABB0ACC2C6C3CDCDDCD5C0AAAA7F72525B565154495043
453A443B3D3F3D423C42434B3F56506A5F7B798F91868694A5B8CAD2D4E3D0E4D4E8D4DD
DCE0DBE5DBE0D2CFC6BEB5A09B949997ACAFC3BDC3A0AC9B917C726B5C585B56524F4759
5E6260706E8C8F9581887B9157564A373D383C3B3C3D39373C3C393B3B3835343A3A3F5C
5C413C3B3F363B3C3A37373634353D453E4938333B383938423C393C3F3E3B39353B3B34
33383A363637323133363B38343F303D445DA0AB
4D4D4D4D4C4A494848424647494A44474B414848434A4A444A4846444242434447474547
48464746454443444647474549474748434043474C454143464543434744454849464545
42484B4947464340404040414241404044444441403F3D3C3E3D3D4043434140423E3939
3C3E40403F40393C3A44414141403F3F3F3E3D3E3F4240424846403F3F3C3A3A3E42423D
3B3A3C3F3F3E404343413F3F3B373A3C3E383D3B40383C393B3C3C3B3A3B3E40403E3C3C
3D3C3B3A4341403D3C3D3E40393A3C3C3A38393A3C40403C393B4042473F393C403D3A3A
3E3E3F3F3F3F3E3D433D3F3E44555D5F4D46474D4B5D5E6158524944474F54555F605E4A
554B5253494A514F58616B646367657A677373847C8FA4B3B9BEBCB8C5D5D6DDE2E6DDD6
DBC8D8C8DBAF8A5F4C3F4140454047453E414337434441413D3B44424345403E3F434041
463E3F5557789AB8C6C4BEB0B39A878A9BADBDC8C5D3C5DCBACAA39D9AA8BED6CADFDCD5
D6CFCFCABAB2A9A3ABA8BFA5C2BDC6A995786C595944463D3E3D4140404340413E40413F
3D3F41424043443D3C3C3D3A423F3D433C423A42453C3C444A4D5A6A52463D3F3F393739
3A3D3D3D3C3A3A3C3741393A466A815F48403D38393F3C3E3C3D3E3D3C3B3B3B36373838
38383A3B38393A3D40413E3B37383A3B3B3B3B3B373D403C3B3E3D3A38333B3A363B3839
393A3C3E3D3B3A3A3D404444413D3A393836373B3C39393C383B3B38393C3C383B3D3D3B
3837383837373D393639383F443F3F393C423A383A3F474E51504D4B404B4E4A47423C3A
3C3D3D3936383A39373B3C38383B3A363637393C3E3F3E3D3F3B3B3A383B3E3B3B3B3A39
38393C3F3E3938393B3C42495D566B53514A483F5750657D9E968C7A69736D7F80908281
6E7157725B6F4446434036403F476C69554B4A43473A3D3B3C3C3A3A3C3C3B3A3D3D3F3A
4545443B3F383C34403C4E567A9DBAD4DAD4D1B6BB9298707A59617D93A0BEBCD1C1D0D3
DFE2D7E2D2E3D4DBCAD7BCD5B7D5B6BCC4C6BAC1BDC3B39288735B4A3B37423C3F403A45
3643434746495D5060566D70849FA6BBADB7AABCB9BBBEC7D1D3D5DBE3DFE3D6E5D5D6D6
DBD7D8C4C0ACADAAB3ABA18B8681888888998FA596A4A0B3C5CACCC2AE9F97926C756368
59463C403E52605F7D6F53554B413C36423B3E48363B3B383A3936373834393C3B373748
3435353D44374236343433363A3F49545E6542373930363235393B3A3A3B3935373D3C35
33393B3732393E3A373737363731455783B4A98E
4A4B4C4D4C4A4847494447464544404546424644454E4942494644434140424648484447
46434645434545454648474547414245413D3F414C484547494745454947474745414245
464A4B464648464042414243413D3B3C3C3E43403E403B3C403D3D3F42414040403E393E
424144423E413A3C374040423E3F3F3F3F40403F3B3F40434946403F433C393A3D414039
3D3C3D3F3E3C3D413B3D3F433E3A41423B383C3B453D3D3C3C3D3D3D3C3C3E3F43403F40
3F3D3B3B4541413B3839383B37373A3C3C3A3C3F3C3E3F3D3E403E3B48423A383D3D3A3C
373B3D3E3E40403E4A453F3A3E4A52545853504E454F494B443F3B3A3A3A3C3E49584354
4353464F474547413E424B4A493C49454F39464D4A52555A5B69747F94B0AED0C9E0CCCE
A9A390A794985D47424457595141433F40414638413A3F3D4340483F414B545864605D62
71788AB5C0D0D8DEDEDBDED9DFD3CDD3DAD8D2CED5CED7C7D6C5D2C3D4CDE4CFD0D0DFDB
D3C7B9A88D8475655D6563766F9886814E473D483B433D413E3F3F3C3C3F3F3E3D3E3F3C
393F43404646483B3F3D433E403C39413944404E4C586E9096827B79443D3A3E403D3A3B
4143403C3C3D40463F463C445A7F947047403F3B3D43414538393B3B3A39393A3C3B3A39
383838393838393B40423E393C3B3B3B3D3D3C3B3B3D3D3B3B3E3D3A4133404F6069513D
3C39383B3E3D3B3B37393B393635383B42423F3C39393C3F3B3C3C3A3B3B3A373E40403B
38393B3C3A3A403B383A393F3E3D41373A423D444E474143494A443C3F423F3B3E42403B
4545443E37393D3B3B3E3E3B3A3B39353C3B3938373736363E38383A383A3E3C403F3D3A
39393B3C3F3C3837443E3D4460646B593D50485850625770718B72706355625984647067
5A52444745443B433932443D394449413E3E3B3B3B353A393C3E3B393D3F3E3E43444844
4F4B4A454D4D4C484F5A7896B2CFDAD0BAA68F665D503D534F7A8EC3B9C5B0BCAABAB5C2
C0B2C1ADC8C7D5D3CECFDEC8E1C6C4A9A7A9928D817F755C553E37403C454C4C5C605F6B
6C767578868FA49DA69A9E96ACB0CCBDD1B2AFA9A7B2B7BDC7C9C9D0C3C4B6BEA4A896A6
919F939B839399B5D5D3CDBFBBBBC2C3C1C6B6AB9D958F9FBDD6E5DED2C5BCBACDD1CEB9
B78174574546424A5B6C493B4436393842393840363B3B393B39383B3D3944453C393A42
3B403538454356473A3D41484F4F5157535A403A392F3A39343B3D37333637363A3D3C36
34383A393936383237403936375B8693AEA76857
4E4E4F504F4E4D4C4D484B494848454B49454340464C4444494748494744464A47474146
4540464645474845444647464A4445474445474448464648484544454846454644414143
484746464748454245444546433F3F433F434B464245414348423E3D3D3C3E413F3F3A42
4540434040423B3D38423F3F3C40403D3D40403C393D3D3E43413C3D453E3C3C3A3D3D38
38383A3D3E3C3D414545444A423A3F3C3B3B3D3C4A403B3B3C3D3E3E3E3E4042433F3F41
413E3B3B3F3C413C393B373C3C3A3B3E3E3C3D403A3D3F3D3C3E3E3B44433B373C3D3A39
393E403E3C3D3D3C48494441464C5254444745413A4035384343413F4043454542444445
554C4D3F3E3F484D49474A4A41433B50465049554B4B484F4C514F535C5B817BA9A0BCC5
B0BBB49D6E64515643434C4B50494E4D55505C54635A655C615D69687D9EBFCDCBCBCCC4
C5CCCFDDE6EBE7E6E3DFE4E1E9EAECECE7E0D8D4C8C8B7CBBFCCCBC9C6C0C7B5A4ADA8AB
9E90796749494B47423A443647475348413A42414843473F4244423E3C3D3D3A3E3D3D3C
3F505C5B645E5D444C434D44484C546C6B7A717E7E909BB2A3735A433D3B3A3C3E3D3C3B
3C403D3A3E40454D474940525B6071603D393B38393D3A3E393A3A393838393B403E3C3A
3939393A3738383A3F423E37433F3C3D40403D393D3C3B3B3E403F3D3743718E978A593A
3D3A393D3F3D3C3D3B3A3938383A3E403F43413934363A3A3937393D404040403B3F3F3B
383A3D3E3E3D423D3839373D3A3B423A414D495553493D383A3C3A37393C3E3C3F433E35
3C393A39383E433E40403F3D3B3B39383E3D3C3C3B3C3C3D473D3B3D3A383B3B43413E3C
3B3B3C3C38434646564844547D80875B473F3E49566F6C747381706C625B495C554D4040
464335373537353F35424243443C4C3C343D38403C3D3D393B3E3A363A3D3B3C3E40433E
47434C546E77707E788A95B3B1B9B6A7958C7F67505D7484ABB5D5CBBFAE8C7580859390
8C8B8893A1BABFC2AFB2A4AE909D7F78545D46464043453B3F3B37594A73728FA1A9B1AC
B6A8A2A0A3B1BBC0C0C3BEB6BFBEC9C9C6B3998F94948D86888D8D8B8879887C7E696C71
728797A5A6AAB4C9D3D9DBDBD9DEE0E3DAE3D0D9BEB79B9EBACFDEE0E1E0DCDCD5E2D3E9
D9D8BAAB6F7958585D754451494045383B3C3A363E3E3A393D3D3D423E3A41403A3B3838
3E3B39374A545B514042414447413B3D3E3E373839373B3D383B3C393636393B3C3C3B38
3637393A3B3643424D5C48415CB2B2B299564A3C
494949494949494947414444464742454743413F46463F49414042454440404445463F45
453F4747474A494442444746454242413F464A4242424446454140434642414446444343
494341464A474443464647494745484E3B3F48403A3D393C423F3E41413E3E413F3F3941
433C3F3C42423B3E3B443F3C3A40403B3B40403A3D403F3E413F3D40403B3C3D393C403D
39393B3E3D39383B3A38363E3A353D383E3F3E3C4C4037383D3D3E3E3E3F42453F3C3C41
423F3C3D3E3C433F3C3D373B403C3B3D3C38383B373E413B35373E433F433D373C3E3836
4145453F3A3A3A383D4038363D40424339413E3C3A4339413F42413D4148473F38443E40
3A40443D433E4146403C3D3E414543413D414143504C434B4A5559646655564E525F709A
8CACA6B994B99EA35E5A5C6A94A7B0AFC0B0BBB4C8BAC3AFC3BDC7C1CEDDE7E1E7DCE2DD
D9E2E4E7E9EAE4E5E3DCDCD6D7DCE1E3DFD7CBC3C0B2A6A6A5969A8A918288675F5F5D5E
5D4F40463B44473E4044404942454944444241423B3E3E3A3C4141414041413B403F4044
516F878A988E8F72817A8A818F9AACCCC6C29F9A848975756343463A3E3D3B393B3E4040
3D43403C3D3B3A413F4A47554B394A463F3C413E3D3F3A3C3E3D3C3A38393C3E3A393839
3B3E4143363738393F433E35413D3B3E4345423D3E3B3A3D41434240507ABFC9A4774739
3836373B3B38383B393735373B3D3C3B3640443E3A404443403C3C40423F3D3F353B3D39
37393C3D39393F3B383A39403C3A423E4C5C56603D3D3D3B3838393B363C3E3A3940423F
413B3B3C3E45463E3D3C3C3C3D3E3F413C3D3D3D3C3B3B3C4337353C3C3B3F413E3C3A3B
3E414242485E635A634D4E6B7B8884674E463A40577B7C9A85936C68655B4F443F37443B
3D3B3C35453A3D373C4B4F4546383C3D393F3B3B3E3B403641453F393E403E3F3A3E423E
494D667EBDB1A4908B757176847A7D8A99AEBEC6B5A6B3BEBFC8B1AC737659595A717D82
96928F889487867279626353424643414958454A4A4743393E3A445B618078917B8C8084
7B858198A6AFC8B5BDA19C85A093948E8F8B81816E6F7272778A96929E90A1ACADA8A3A6
B9C7C3D3C7CFC8DAD7DFDFE4DFE7E6E9E7E6DFDED8CCCECBD0DAE1E1E0E0E2E3E8E3E9E3
EAE2E1DACBB0B39CA89F948C9A8B7C4E3E444536423F3A3B413D383A393C4C5C707F7A76
736F7E6F716C5851403F393A413F3C424A383634373C363A3634353A3B38393D3D3C3A38
3636383B3E5489939184503C7293A16845423240
494B4D4D4B4A4A4A48494A49474748494849494846454748444647474544454640454943
46454256564C47494A4545484743443F425C654F41444746434244474643474742444948
454849454344474A444C4545464145463F3F4246474443443D3D3D3E4145494B3F444240
43403D423A3F42403D3E3E3E373C3E3B3C4041403E383E3B3B3E383D3C3D3D3C3E434341
3B3B3A3A3A3A3A3B383A3D3E3D3B3B3A3A413D403E393F3E3D3B393A3C3F3F3F3B403A3E
3D383F3C41403F3F3F3F3D3B393A3F3D373C413E373D413E3B3A3937413C3A3C3D3D4044
383A3437393A403D373B3C39383B3A373A3B393A3F3C3A413F41403E3E3A3C453B414445
4646413A3A3E3F3D3B3B3A37383E3C3B3E3B373C433E3E48555B5C5C58544C444041454A
5E626F73858A908A89807F95A3ACBDC2AAAAA3BEBDB297B8BECDC8CBD6DCE6E7E3E1D4E5
DAE0E3E4E0E6DEDBDABDC0CDD5D5DFDCD8D8D0D1CCDDC1AE8D9472764F5F475848494041
4042404744393A3B393D3A454B42423D3E3F44464140413E353E443C4A3F444240454744
4F596A766C7C87A3C5D2D8D5D7D5C4D6AB7F795A5342434B4B3C354A524844403E4C5B5B
84737E666B5A533F404141443A3C483B3E3A3B39434A41443E3F3F3C38393C3F3B40413B
383A3D3E3C4245413D3C3B3936403F3F3E3D413A4338424544443D5389B7CDB77A443A3B
383A3945443839383C383B36373C393D38393B3E41423F3D3A3A3F4D483A3B373C3A3A3B
38363A3F40423E36403D363F3A3E3B4B53443F3F353C3B393D3D3A3939413E403F3C4038
3D3E3E3C39393C3E3A3E403E3E403E393B3F3F3936393B3C3A36353B40403F3F3E383D40
4549454B6776615A594E585F84787755413E474B656C86838573715F4F423D3D3B3C403F
39424339363E413D4953473A40423A3A3C3B3D3A484545444B423C3D3D3C3C3C41454F4D
576B80A6A5AC7C634F4554657A858A8FA8C3CDD1CDCBC1A3AE9585736583849096B3A99F
95857A676950454542444A4145514E688A8A725C55524B3D4240424952584A52656D5451
56646E777B8A837C72768B7E8D86969DAFAEA6A39A98ADBECBD9D7D8D5D9DBD9D5CDCBD8
D4CFCDD0D3D1D2D3DBDDE0E1E3E5E4E1DEE4E0E8E0E6DEDEDCE3DDDBE1DBD7E3D6DCD8DE
D5E1DEE1E0E1E4D5D5CED6D5DEDAC7AB9E8B6E67685D6F52474541383A7B9CACC2C7C5AC
A8B9A6B69EA387784E3D3A3E37403D3E3A393E393738333C333C3F3E374141393D32353B
45444C748198BBC3A950423D414C594253606067
494B4C4C4A4949494647474644434344474747464545464740424445434242423F424440
4546435451494447484444474A4645423F494E4443444544424142444342474A47484A46
474241434341424644474241413B3B3F47423F404244484D44434241404040414044413F
413F3D4244464542424444413B3F42413F3F3F3E3A3B413C3E45404040413F3D3E40403C
3C3C3C3B3B3A38383637383838393C3E41453F413F3C413F3D3C3C3C3E3F3E3D3C3D373A
3E414C4C3F40413F3C3938373A393C3C3A3E4039393B3B38383E4243403C3A3A3835363A
3C3B35393B383C3A3F4142403F3F3F3E3B3C3A3B3F3B383E363C3E3E3D383A443C414443
403D3C3A3A3D3D3A383A3B3A3A3D3D3D3F4040444B49494E535455574948464340414549
4847494450555F5E5D636A74757987887C778B91A58278888D989AA8BFD1DBD5BDAFA3A7
B7C3D2CAB1A89AA49DACAABDC8C5CED2D9DED6D4C8C2BAABA291818760664A45414C4D48
3D3F3B3D3E3D46483D3D43424F40473E3E3E43454140403C43403F444E8983987B896268
6181748C87A0B0CFDDD5D6CBB5A68E8A5E524B474B484C525046557E86909186756C798E
A6AAA69981725C5659595951403A423E4141433A3C45403D393B393B373B393B373C4545
3D4047463D4244403C3B3938373934373A3D444240494143384A508FC5BB9E6C463B383A
3436343C3D373D3F3939393C3D3B3B3A38383A3D3F4141403F3B3D44403B3E3D3637403E
37393A3B3647394037363F4244483F4146403F3C363D3D3D41423E3E373D393C3E3F443E
3E3D3C3C3E4245483A3E424241403D3A3C3F3F3B393A3C3C3E3A383B3D3D3D3E3D353F3B
3F50596F6E71584E4B465863705D57403C3F4F5D6378757F4D54454E41393A3E3C3C3D3A
373F4039383E413F3F453E373D403C3C3D3C3D39443F3E3D3F3E3A3A40474A4D4B524555
62657F7F867E626E62888297AFB4ABA5ADB9C4C9B4AD9B9E8B95929A9EA494968F9D979D
908B7E8E888E7D81758D768775817C8A807F67534D49473F453F483C49434851445A514C
46484B534F575F6B768FAFB9C6C1CFD2DEDDD8D8DBD2DCE1E0E1DBDBCBD5D4CCC3C0C1CB
CBC7C9CCD9D3DBD8D7D8DCDEDBD6D9DFD3CFC9C8C8CBCBCDC1BDB0A9AAA1999CA6AAB0AF
BEC9D7DDE4E6EAE5EAE8ECE9E2E1DAD1D6D0BBB8ADB6A6C18A9B635388C2D4E5E6EBE7DD
CCBB8B74647A9170503F443847383D453730383A3B3D3A403638353B34403D36353C4040
45434152779EA18B5E3F414C6884A0A4B7AEC7B5
4A4B4C4B4A4848484A4A4A4947454546454443444445454544464748474645454445433F
44433F4A4B44404446444446464545474544464944444443424140404141464B4A4A4844
4E4441474A454347424242424544414A5148403E3F41464B43434342413F3D3C4143413E
3E3D3D40413F3B393B3F3D3940424546423D3B3D373B3F373842413E40403F3D3E41413E
3A3B3C3C3C3B39384141403E3B3A3B3C41403A3A3A383C3A3D3D3E3F40403E3C42423C3E
3F3D3F3B414445423E3938383C3938393B40413B3C3C3A393B3E3E3D3C3B3B3B3936383B
3A39353D403A3A363E3E40413F3C3C3F3D3D3B3D3E3A373A3D4345433E35333A383B3E3F
3C393B403B3D3B3736393B3C3F3E41424043474846464849464344493C3F41413F3F4144
4443433D43454A4945494A525E71827C808390A09C8B7883767D7D818B9BA39887726757
6E71826F75596C678298AAB3B4B0B4BCCCD8D6D8BDA2827F6E7367756061574342414A49
464F4C47444347404345424B48494741433E3F414043474650567980AFC0D8CDCFC3BCB0
C7CFD5C6C9CDC0C5B18C826C635F5D6C52644A533D44444846394A6EAAC7CCB89C755D64
566858634E533F434A4547423F3C3C3D3B3C403B3B413D393C413D433639323651505751
3E3C43403C40413F3C3B3A393B3D3B413F383A383E4246343C5689CACFAB624239374534
3F3F393A39373F423B3A31383B383F3F3E3E3D3C3B3B3C3D423B3E3C3A3D3F3E413C423C
3A423F3D3C3C424456505844474C40383A3E3F393D43434144433D3C3E3F3A3A3C3D403C
43413F40434544423B3E4447453F3C3C3E403F3D3C3C3C3B413D3B3B3B3A3B3D483A4748
597375875454484A453E4A4F5E4A42373E3D495B5D5C674C442E3B393C393D413F3D3D3B
3B3F403C393A3B3A3D3C3A393A3A3A3A3A3C3C373E393839343D3D41525C5A595C58465A
61617A6A817D8A9B909B9CA2A89F858395A2AAA1A99DA88A8B7481717C756267697E8291
A6A7AAC0C1C6BEBBC9C8B1987C775D664A5047424240424140453E4E48615E72617D7E7A
767B81898E8A909898A2AEBED6D3DCDDE4E2E1E3E6D9D9D8CEC7C1C3BABEB3AAA7B3BDC5
D8D7D7DAE5D9E0D7E1DAD5CDB99E908F888174786E706A6F6663646C757B818696AEADCC
C9E3D6E2E5E5E6E3E6E6E3DDD5C8BAB6C8D8DBE8E6DAE8DEE8C9C3A1C6E2EDE4ECDBE7E2
D7C59EA1847E7C514E424D8587A076564C37383B3C3C3C3A3B3C34433340363737413A37
3D3D40444C4A533F4A717FB4ACD0CCEFDAE8E7D6
4B4B4B4A494847474646454544434343454342434546464543434444434343434646413E
43433F4346413F4346454547484A47474944424A45444242434342404242444748484642
49424045474240414141443D3F423B414D464141424244464142434342403D3B4041413F
3E3D3D3E3F3F3D3B3C3F3E3B3F404345413A3A3E4547453D3C4447464142403D3D403F3C
393A3A3B3B3C3C3C393C3E3F3D3C3A3A44403A393A3C3D3C3D3D3E3F40403F3F4A433B38
3A3C3D3C424241403E3C3B3A3E3A38383A4043433D3B393A3D3D3A35383A3D3C3A383A3D
36353440453D3A3539383A3D3B37383D3E3C3B3C3C39383A383C3E3F403A373C3736393D
3C393B403C3E3C3836393B3B434043443F4145433C3D3F3F3C38393D3C3F41403C3A3C3F
3B3D3F3F41424443484A4E60778A8E7B796D8A798D6E736D6C6B665E5B686E6150434338
464652466354616B789FA5B2A5A2A0A3AEB8C0CACDBCA1A2899068554A3F453A48425968
879BA19D979594878C799C7DA8819877807A7C858A939A9B9D9A9996948F9E989B9FAEC2
CBD8D5C5B4A6908C7B6C7673968CAA91976754443F483D40483F414B7196A2978F755346
3C46363F39403C3B3C343C3A43403B3E3C3D3F42433C373D3B4647544549424B48464742
393A43453A3C3E3D3B3B3C3D4D44383B3C373D4043343F405A94C4CEA26D4A3A3E453C3C
3E3D3B3B3C3E44484A43383A3B373D40393A3B3B3B3C3F41413B413B39413C39433A3A37
3C41373B48485968677A50453E433E38393E3E383E45454244423D3B3C3B383A3E424442
3B3A3B404647433E3E3F4448453E3C3F3E3E3E3D3D3D3C3A3F3D3C3D3B393B3F5E4E4F4D
565F514F3F3B39433F3945474942413E4940424D443F413A3E3B403E3E3D3E3D3B3A3C3D
3C3D3E3D3A38383940393B3E3A383A39363A3A373A373639353E3F47595748444E415062
7292A6A6A29A96A18F747D6C676D647C9EAEAA8979766458474C4845444743434256565C
7A748E84997C8A76806E794457443F3F3B444144484852596C637472999BAFADAFBBB2A5
A8B9C5CCD3D0D0D6CECECCD7DDDBDFE0E4E3E0DEDACBC6C5BFBFC9D3D9DFDADBD8DADCDB
DAE0D7DDD4CBC7C0AB967D6B5D524E514E4C4250434C48575A658098A2A9B0B1C3CAD8D2
E5D8DAD9DFDBEBD9EAD4D8C8BCB1ACB0C4D4D9E7DFDED5EADBE6DEDEDDE9D7DFD3D8D6E0
CDAEA395BBB2C1A29C758382BDCBCA94835C4D494A484C4542353B3A42383E394042384D
6A79929DA68D4D4C7E7AB8C7CCDDEAE2ECE8E1CD
4C4C4A4949484747444444444445444446444344464747464544434242434444484A4546
4C4E4E4E4440404347484848454944404747444845434243454644434645424244444241
434445464543413F454A4B40434B4344413E3F434646464843434443423F3C3A3E404242
3F3E3D3C3D4143413F4041403B3B3D403E393B4041423F3E3C3C40424746433E3C3C3935
3C3B3A393A3B3C3D3B3D40403F3C3B3B3F3C3A393A3C3C3C3C3C3D3E3F40404149423C3B
3E4342413D3936373A3C3A383D3E3E3D3D3D40443C3735383F42413F383B3D3B37363738
3938343D423D3C373837393D3D3A3C403E3A3A3C3B393A3C3D3C383B3F3B34353D39383D
3F3B38383D3F3E3A383A3B3A403D42433C3D403C3F3D3E40403D3C3E4142413D3A383B3E
3939393A3A3F454B595C617076746F5D585A4F68506851594741403F485E64574B424346
464A4E5058565A677D9EA2AD9B9C948D88858E9FC9C6D1C8CDCCB58F9377717187849095
AEC7D5DADBDEE1D7CCC3CADAD9DED1BCBBB4B8C3CAD2DADBC9A49A71605B53564C607888
9BA2B1BFC9C0C1BFB2AEBAC4D1CCAEA2785640403F47393844433F3A3C50544C4B4A413B
3C3B3F39413845383B36423C443F414942443D3D4343536F787D767D655A434042423B37
3A3A3B423C3C3C3C3B3A3B3D443A313C444041403D4A597D8AD0CEB382673E444134473F
3C393A3C3D3E3F43423A3B3A3A3A373B3E3F3F3D3A383839413C423C38403B363A3A3B3C
434144609691A582775D423C39383A3A3A3D3C3A383F403F43433F3F3E3A3B3D41444343
3D3A3A3E4344403B3F3F4346423D3D423D3C3C3D3D3C3B3B3B3B3D3F3D3B3C4042403D3D
3E3F3E3C3B373C49443F4849474C4D444839373742463843333E3339393B3A373636383B
3737393B3B3A3B3E3E353A3F3A383D3C363B3A393938353A3A3E3C414A3F353D5C577380
9CCDCFC2A693646C4A464D4F4F758B9FA69E8C6453493A3F38444A58545B5D5141494243
464D44594650484142523C4A444D3D3D4257667A898D9AA5A5A89CBBBFE0D8D9D3D0C0AB
B1C4D3DADEE3DCE5DEE2E2E8E3E2DFE4E5E3D9CFC5BDBDC3C3C7D6DFD5D7D8DEDFD3D7D1
C5CAADAA8078636258504743454949484945545464627D8EB3B7CAD9D8DAE0DFDAE7D5E7
D1E1CCD8D2DACDD6C1CFC2C6B7B9C7D5E3E6DCE0DCD6DFDFDCD4D3D4DBD7D8D0DECFDEE2
D8C39A6A7CB8D3DEC1C88C7D82B5ADD0B39698A5B5B0B3A488715557454D4C564A566295
BFC8D4D1BE97774149456499B1DBD5E7C4D6B4AE
4D4B4A494949494847464647484949484746454546464747494746454647474740444041
4445484544424245494A4948464A4440484D4B4A45434243454645444747434042414042
44484A48464746433C4241393E45414041404144454344474141424241403F3F3E3E4345
4140403D383E413E3B3B3C3C39393A3C3C3B3D3F40434348464043444343403C3B3C3B37
3F3E3B39393A3B3D454544413E3D3D3E38373C3A3A3B37393B3C3D3D3D3E3F40433E3F3E
41433B383C3835373B3E3D3B3D424444423C393D3A37383F47484440383C3E3C3A3B3C3C
403F36373A393D393837383B3D3C3C3E3C38393C3A3A3C3C43403B3E44413B3B3D39383D
403F3B373B3E3F3B393A3A3939393D3E3B3A3B3A43403F4243403D3D42413E3B393A3C3E
3D3E3C403C41465059555157534C4D47443D423F444441403F3C3E3A3E4A494450423F42
3E4342474649535C8E98A0A39CA2978B7E6C707F8F898C898EA3ABA98F898AA2B9C7C2B3
B5C7D2DBE0DFDCCFCAAFBABCC7CBD4C4B4A8A5ADB6C3D3DBDFD4C2BDA29E6B534E597395
92AFC0C3C2BCC3C4C1C4C6D0AF9E655F4840434238403E3E4344433F41403D3C3D3F4041
3E35443B4E414A3241373E36403C454535464D565D5E6E808C78584F40433F463F413A39
43413C43413E3C3C3B39393B373A3B44423A434B5675B0A9DBCAC9A1856B63594F504C4C
483E3E3F413F3A3F453F413A383C383D3A3A3B3A3A3B3C3D423F403B373D3D393A3D3C40
464C73A9BBB3846D483D373C3D36393B393B3A3E393F3F3D40413E3D433E404041423C3E
46423E3C3E3F3E3C3F3F40403F3D3E423C3A3B3D3C3B3C3E3B3A3D3F3E3C3D403B403B3C
3D3D4441383B49544E45423E3E47473C3E38403C3D393C333E353C3E343A3B393A3B3A3C
3838393A3A3A3B3D3D36393D37363A3B393F3B3C393934393B3C3B3F454555728C929395
AEC7B48A735C4B453A47566F6E919F93755F553C413645425358797F967F6D544142393C
3D473446394A48434752425145553F4C6C89A3BCC8C5C9CCCDC6CCC3D6CDDBCDD4CFCAB9
BECAD5DBD6E1DAE5E0E8E3E6DEE0DAE0DDD7C8B7B9B7B6BCBCBECBCDD5C5BAB5B89C9982
656A595C424F454E46474A53668197A398A8A0C0A7C1BBD4D6D4DCE5E3E1E1DCDCD9E1D8
DAC9C9C3C9C0D5B4D2BAD5CBD0CED6DCE3E5DBDBD7DCCAE4C4DAC0CDD4DBD7E3D7DAD6E1
E4DAE3ABB2BDD2DBDFE1D5989F848EA3C0AEB1BACBC7D4CCBDBDB3C7ABB6B0C19EAAAECA
DEDCD9C8A3774341443A4E7FC5E0DFC29F6B6F59
4D4B49494A4B4A49454443444646464446464645444445464443434445454442484E4A4A
49474D48444344464A4B49464E4E4A454647464544444343444443434447454345423F42
47434042434343434A4B44434642404147474747433F3E4242414140404142433F3E4345
414143403F42423E3D3E3D3B3B3C3D3D3E3F3E3C39413F403D393E3A3C3D3C3A3C3F3F3C
3C3B3A393A3C3E3F3C3D3D3D3C3D3F413A3D484642403A3E3A3C3E3E3D3B3B3B3E373937
3B403B3C3C3D3D3E3E3E3D3D3E414142443C373A3B393C4449463D383A3D3E3C3C3F403F
3E413937383A3E3837373637393C3A373A363A3F3C3A3B3949484444453E3739393A3A3B
3E403E3A373A3B39383A3B3A373A3A393A39383B3E3C3D403F3B393A3E3C3B3A3B3B3B3B
35393A40393A3941443F3B424240453F40423B423540333F3B3D433D3C403F48493D4A45
4F4E514D5761586C7A8A7A85717668635E4D4E585B52485245534E5D4E5E567680B4C3C1
C4C3BEC8CFC9BFAF987B7F8D889EAAACAC9B92969CAABFCCCDCECAC0C6A4916D9A99CBC6
D2BFC79A8578685F65717A868F8157564D534C394238393D3E3F3E41403C3B4146443F3D
3D38414A6272736B605252485049514049403B4444444F4D47423F4948463F403E3F3A3B
403D393F403D3B3C3B3A3B3E3A3F3C3A3742698781999EC3BFBF968E6F6F6F8589869384
513E3A3E4343404B5C5B54463D3E3F3F403E3A383839393A403E3D3D393A403C3B3B3D53
5E678DA8A6895E463E2F433D42383D3C393C3C403F44423D3F3F3B3B3E393E3F40423D42
3E3D3D3D3E3F41423B3D3D3C3C3E3F3F3B3A3B3D3D3B3E43403D3D3F3D3A3B3E49453C3C
444B4C443F434C4E47403D3C3F434138383541393B3935353B39373C373E3E3B3E3F3C3D
3D3D3B39383939383B39393937373B3C393E393D3A3C363B42403F434B5A7896A9A78E81
89856F5C513C494B61647376737975614A43474140473A544D7A829488645240373C373D
333D5947765F8B7D97819360725C667B9FB8C7D2D4CED0D2C5CEC8D6CBD6D8D4D8D3DAD0
D4D4D4D6D7DCD7DFD8E2D3DBD8E0DAE1DAD2C1B0B6B2A9A6A3A8B7B6937966526250644F
51505F6375888D93898D97A8B8C3CBCFD2D5E5DBE0CCD1CDDBD8D9DBD9D7D8D9D7D5CBD7
BBC1B4B5C0CCC8DACDDCCDCCCBC3C3C4D0DDDAD8CDC3CEBAD6C1DBD3E4E4ECE5E7DFE2E1
E7E3DFE3D5D7D9E4DCDDDDE0C1CCC0C0AFA8A69898859697A7A1B8B0BBA9C1C8C7D4D3D7
D5CCC6B39D66615B52505CB3D2E1CBBC8D59423E
4D4B49494A4B4B4A4A494748494948464546464543424445454547494B4A46433D454344
41404945454444464A4B484544434444424143464444434342414140404748474A454043
51443D42484746494A483F474C41424746474A4B463F3E41494744413E3E3E3E403E4345
414246434644403C3D3F3D383E40413F41433F383E48413B36363E383C3D3B393B3E3E3B
3536383A3C3F42434042444442403E3E373D4C49423E363B3A3D40403D3937373C383F3F
41443938383D42413C38383A403E393B413E3A3E3D38373D413F3B393D3F3D39383A3936
343E3C3B3C3E40353A3A38373A3E3B3439353B413D3A3A36373B3D3F413B393F3B3F403C
3A3B3B373437383636393C3B383D39363938363C37383B3D3B36363A3A39393A3C3B3835
393D3D443A3A39413E3D3B3F3D3D433C3F3B46323E313B454240403B4045414F6661806C
7E6D705F6C6863555E55515D4748383C463D40484B394146524540444B6E648E84B8C0BC
AB98848F9FA09C9197709F8EB099C3B8B9A79B958E8D959B9B9D959D889B839D9DCBD7D2
D7D0B1A476745F54585E6B76A597B68CB99CB189845B4C4A484743483D43424045474545
3942415969979BB1B3ACB1A7A799A68E8A57363D3B3E4C403E3E4246423B3F4844413F3F
3E3D41473D39383B3D3D3F435C5C534E494D65758D69717A87666960605560767873736B
5B4037383C3C39484F5952494240453D403C3736373A3C3D3A3D3C423D3A423C3F3F5081
938B87685E4B4C4C3B3A3D41413A423F3B413F404045423E41413F40433C413E3D3C363D
393C40403E3C3A3A393C3C3A3B3F403D3C3B3C3E3D3C404745413E3E3C38393B44393334
465D616144494E48413E3D403B3B3D3B3C384437353A383A3A36323B3A403C36393A3839
3B3C3A37373B3D3A343637383A3E4347353B363C3B3F393F4F474242495A707F89796758
5F5D5B865F584863605E5F4A4B42413F3B3F413E4043434F625A4B4E4435403C363A363F
47787C9C91A4ACBAAAB38B93687B7CA8B6CDD5D8D4CCCCCDD0D4D7D7D3CACFC0D8D0DCD9
E1DDD8D6C6BFB9BAB4C4B3C8BCCAC5CEC3BBAD9E828784858181877C5A5760547270A29A
BAABC7B2D1CAC7BCB3ABAFC2D5DDE1E5D8E2DDE8D8DDCECECFD5DEE0DAD0CCCED2CAD0D8
CCCED3CFD5CCCDB8C1AFAE9F9C92929AB4D2D7D6C6D9C5E2D1E1E1E5E4E2DFDDDCE4E1DE
D5E3D5DDD6CDD7CDD9DAE6DADCE1DFD3CBC7B88F765160666C675F8085AEBDD2CBD9DEE0
DAD4D5CCC8C5CEC4B2717178A39FB2ADC391666C
4B4846474A4B4A4745454444444546464444444444454748484848494A4946444845464B
4D49444343424142454A4E504C504B43403C3E454041464B4943414241454745413F4347
433F3F4344413D3B3D46443E42443E3C3D3E3D3C404645404047433B3F4341403F404140
3B393F48444647433B373A403B3D3D3E41423E373C3B41413735383535383C3F3C37373A
393D3F3D3C4043423C3F3F3A383A3C3C38393D42423D3A3A383B3D3C39393C3F3C3C3C3A
393A3C3F3D413E3D3F3B384039393C3A4042363B38393D43423D3C3E3E3D3B3A393A3B3B
3E38373836393A353B3B3A3A3A3A3A3B3A3A3A3B3C3B3A3837363A40413D3B3D3C3C3F41
3D3635383E393C3D37373B393C3A3C40413C393A3A3B3F3E393C3F393B3B3A3938393C3E
4041413F3B39393A43433E37394040393B35383B3A3C3E37373A45413B4D48555D7B8683
7C696E5A585C55483D3943553F3C3E403E4144423F3B494A484E5A64868D9A98A3A09E92
877A706A697172685B5A69757182798F7A866E7575808C77766D866991839D8EA79CB8AD
C2AEBAB8C1BDB8B5A3A5A5AAA0B18B9B90A792AA8BA09BA681926C697F6F857C8B829174
6564545257637E99A3A0A39E8F8A8F91694D3E433A3F3D47434242555F66746E6A5C545B
576C5B664B3F3D394559626E71624C3D3B40413E42404042454542403E3D42494C484342
3E4041413F3F4244454746423C39393B3E3B3A3D404140403846414736424145424E7593
906F473C3C3B3C453E464643494542403C383A3F3C393D3E3B3E45444745403B3C3E3C36
353E45413C3B3C3C383D383B3B3943433441403E45413C443E3E30383D373F37423E3D48
5D6D6D6546423C3B3C3E3D3C3A3A3A393737393A3838393B3D3C3B393C3B3938383A3B3B
38373637393A3938373A343536353C3F353C37363E3A3B4B505F49363B3D424D4B404D3E
50628E90775D524D48463F3E3D3C3B3A393B3F413C3D404344423E3A3A3C39373939404F
7984A68D8C8198869F716B5654596D9EBAD0E0DFD7D3D2CEC7DBD9DBC6D5C3CFBCCBD9D6
CCCFC8B5A88686756A5E817494808D798F86846F75695F586C8A94A2A0B7A9BCB5CACFDD
CFE3E0E6DDE1D4C2ADA9BFD3DBE1DFE3E2E1E5D9E2CFDDD3DFD8DFDAD2D0CDD2D8D6D1E6
D5DED7DDBFC0A5958384706B798E9BAECCD9D6D9DAD8E0E1DAE0DCDAE2D9DECDD0C9CCB6
B4B8BFC7C6C4B9C9B3CDC3E0D2DEDCD9CCCABFB29087ADB9B8A1929296A4B2B5B9B8D2DB
DAD7DAC2CBCADCDFC0907782A7C3A8AFA5C6BAB9
4A4847484B4B494647474746464748484746464748494949424243454747464449454345
454444464343434344484C4F524E46444A4A45444847494A484342444141414141424344
46413F42454442433C3E3C3F4545454C40403F3F424543404047443E4145413F38393C3F
3F3B3A3C414142413F3E3F403C3D3D3C3D3F3D38393A3E3F3A393A3A3B3C3F42403C3C3F
373B3E3C3B3D3E3C3B3D3D3A393D40403B3A3B3F403C3A3B3A3B3D3C3A3A3C3F3C3C3C3B
3B3C3E40443E393C403F3C403C3C3E3A3E40373C383A3D3F3D3937373536383A3B3D3D3D
3E38393C3B3C3D393C3C3D3C3B3B3C3D393D41403C39393B37393D403D393A3E40414242
3F3D3E413D3E41413D3D3F3E3736373939383839423E3F3E3D41423A3A3A3A39393A3D3F
3E3E3E3D3C3B3B3B3C3E3C393C444541413B3838383C3F3D3D3B403F3D4D414648535652
53474E4244454241433E3C4139394148494B4D49494A525C57636470737D757665736D71
59534E4743494E4A42434846424B414644574B585E676856495E587D77AAA8B8939C7C92
7DAA9FC1CDDAD6BD978D765F4E50514D564C4F545A6B877F6C69606D758F81AD80A58C9F
87AC9AA3815E5B51544C4E534F4B4945424049534C524B4D3E5277A2B7C1CFD4BDB9AEBE
B0B792965E4D41393B4340443E4446413E4044453D3B3A3C40413E3B3B3C4044423D3B3D
3D3E3E3D3C3C3D3E3D3F403E3A393B3D34373B3C3B3A3A3C38413F3F465A4E604B4F5E6E
674F44453535363A363B3D3F3C3B3B3E3E3C3D413A383B3C37393E3D3D3D3B3A3C41413E
393E42403E3F403E3638353D43454D4A3E3C404B4D3E373D353F3E443F404E424242454B
565B544B3F3C393A3C3E3D3B3B3B3B3938383B3D37393B3B393737383335383B3D3C3A39
45423D3A393A3C3D333A37393A363B3C2E3F454549484549424F40353C3D3D3E323C3B58
5A878987695248413D3E3A393738383B3F3F3C3A383A3D3E3E3D3C3C383735363A3E4550
5455515446464145524B3F4E4F8197BECED3D6D5D1CFCECEC0C9C8BED0AEC6A5A9A5B5A4
AA8879594B464A514A4C5C585E5E5B7D769F9298879499A4B4C1CCD1D8D5DBC9E2D4EBE3
E7EEEAE6E8DEE3D5CACAD8E5E9E7E1E1DFE8D9EADAE4DBDCDAD3CEBCADA6A5B2B9BBD5CF
DED1D8C8C6C8C0AAA7A2A8ACB7C0C6CED9DDD8D3D2C5C5C4BCBDB9BBA9B29FA7A1B29D9C
99A2BFC1D1C2C3C2BCC4D0CBD9CED9CCCCCECAD0C4BAC9C4B2A8A7B1BDC9D1D2C9C2CFCF
D0D3DDCFC3C0CDD7D5C6B1AFCCD4CDBCABA9BCC6
4A49484A4C4B474444434343434343444442424346474544414142444647464447454343
414042464444444443454A4E514C43444F51494447454443413F40434542404246494845
4C47444647444140423D3E474C4545504E47413F3E3D3C3C414644404446423D423D3B3D
3F3D3C3C41403F4042433F3B3C3E3D3A3A3C3C39373A3B3C3E3E3C3E42404142413D3B3D
3A3E403F3E3E3D3B3D3E3D3A3A3D40413E3A393B3D3C3B3C3C3C3C3C3C3C3D3E3E3C3B3B
3C3D3E3F67503F3B3B3B3C3D3E3E403B3C3C373C383D404040403F3D3C3E3F40403E3A39
403A3B3F3C393A383D3E3F3F3D3D3E3F3B3F43423E3B3A3C393C3F3E3835383E4546443E
39393B3C3C44443D3A3937363A3B3A38393C3E3E47403B3B3D43423A393A3A39393B3E41
403F3D3C3C3A39373D41403C3D41423F4A463D393A3A393A413E40413F4A3B3C44495454
55464239403D3A3D44423F433D414E595B5D5D584D4853495448484A4A4B4A44474B4F4B
4C4B4B4742434543443D433A423A45493C4C444C4A49484C54496C5EA59CC0ABAE8A8C6E
8D9DC4BBB6C2C3B7A2987C5A5B666F8A73725851574E5B41434640453F45494F4B494B58
5B75A098B08C968276635755514E5053718093979094877E7588B1CCD0CED1DBD1BDB693
997566554F453E38353E44516A7679695549423E423F3C3C3F403C373C3E403F39333438
3F3E3C3B3B3B3A3938393B3A38383B3D3B3C3B3B3C3F3E3C3F3E3E41637658693F42424F
4A37373844443F3C3D3C3C403B3A3B3E3F3D3C3C3C3A3D3D3A3B3E3D3B3C3C3A3B3E3E3C
3B3C3C3C3D3F3E3C3E3F3C3F3F3D403E443C404A473F3D3E403B394747495A514F4D4943
413F3B353A39393B3E3F3E3C3C3C3C3B3A3A3D3F3D4042403B383A3D3B3D4042413E3B39
403E3A373536393B383E3D3D353440424E504D474444413D3B413A393934383C48476A55
7E69785C645149413C403D3B3A3F3D3D423D36363537393937373A3D433B373B4042423F
3F374C453D41584B565A797EB1ACD0CDCDBFB0AAADB2B8BDA1AA8BAE89A585785C58534E
493F414A4E638A84A393B5B8C3AAC5AAC3ACC3B3C0C3D8D2D8E5DCECE3EACEE5C9E6DAE0
E0E7DAE6DEDEE1E1E0E3E3E7E8E4E3E3E4D7E8D0F1D0E4D1CBB5957C776F6063779897BB
A5D3C1C1BCCABFCCBACECADCE0DEDDD8CEC5BAADAD929C8492798380909E9F9EB0B5B4BB
C3CFCEDAC9CFC9C8BBBCB0AB99A6989C9AA9B5CFDAD2CFC2C1BEBCC2CFD6D9DEDDD8DDD7
D9D6DBD2DCD6D4CFD2D7CAC1C3C6BAC5A89E9CAD
4B4A494A4B4A47454949484848484849494847494C4D4B48474646474848474543454848
45424143444546444243474B4B4B4644494945464A4947454546484B46434143474A4946
494646494A453F3C434147555952525A5A504642403D3F43424443414244413C48423E3D
3D3C3D40404142424444403B3C3E3E3B3A3C3C3A393D3A3A403F3B3E403C3B3D3D3B393A
363839393938373643423F3C3A3B3D3D403A373A3C3C3B3B3E3C3B3B3D3E3D3D3F3D3B3A
3C3C3C3B614A3F413F3D3D3A3C3E403D3A383639343A3D3B3B3E3E3C3B3F3F4043403C3D
3F383A3D393638393D3F40403E3D3E3F3F3E3D3E403F3D3A3B3C3D3B3736393E4648443B
363739393946443C3D3E3D3E3E403E3734373836453E3836393D3D38393A3A3A3A3C3F42
3C3A393A3D3E3C3A3F43433E3C3D3C3A3E403B3B42413C3E423D39373343424D6C6F7E71
6853443D3B3E3E3E3E393D4B4F4F5558514A433A41453F4B464F3C474340463C4B46493F
4D48433F3E3F403E3D3C2A55454A37434A5B606D6C6A7192A2ABA0A69BAAB1B99EB08191
76AC8CA18E9099A59A87807AA899B393A08AA49AB3B1A68163624F4B5144514D5E4D5651
6C6E74747D929FAEA19DA2ABA79A979DC7D0DBD6D3D7CBC0C4C8DBD3C0AD9493937F6947
4A3F463C444440413B444D5E717772604F47413A3C3A393A4045433E383A3B3B38383B3F
43403D3C3D3E3C3A3A3B3B3A39383A3C35393A3A3C3F3D3740404345545647594F473F46
48414242534E41383E3D383A3E3E3E40413F3C393A3A3C3D3D3E3F3F3D3E3E3C3A393938
3F3F3E3D3C3C3C3B3B4042403B383D4148433F3E404442393F3B496C705A524C48453F38
373B3D3C3D3C3C3E40403E3D3B3D3E3E3D3C3D3E3A3B3C3A37363738434242403E3D3D3D
3A3C3D3D3B393839433A383C3B4D6967634C3D3A3A3D3E3A3A39373B363347585C6E6E77
6366575B4F44423B383E3B373A413E3B3F3C393F383837363738393B3A363739393A3B37
4C6066856F767AA385A198CEC0D3B8B79285756F71757572765B704A5B4E493C40443C48
45505A7990B8C2CEC3CACEDDD6D5CEDCBFD5D0D1BDCBC8D2DBDAE4E5E5DEE3DCDFDCEAE5
E4DFE9DCEBD6E3DCDAE2DCDDDDD7D8D4CFC9AEB6A1AA999A797258454846485D7081A29B
BAC3DACDD1CAD4C7DCD0DFDDE3D9CEBFAFA2978D9189889292A1A4B3C3CCC9CBCDD1CED4
D3CDC5B9A8908D7B81707E59645E66697894ADCDE1DFDDDAD7D6CDC8CDCDCCD2D5D4D8D3
D6CCC9C1CBD2D8CDCBD2CCC7BCA99A95A48C98AA
4C4B4A494949484744444342424242424442414447484542494847484949474643484C4B
474443434445464441414548494C48444441414643424140404243434040404041414343
423F414648464240393A4148494546484C454040403F4145434242403F41403C3F3E3F3F
3C3A3D4342484A48464645413B3F403E3D3E3D3A3D403B3A403E393B3A3635383B3B3B3C
393838393A3A3A3B45423F3C3B3A3B3C403B383A3D3C3A3A3E3C3A3A3C3D3C3B3F3C3A3A
3A3A38364538383E3D3B3C3A393C3F3F393536363A3E3F3B393B3A37373B39383D3C393D
3F38383B37373C3D3B3D3F3F3E3D3D3D3E3B393A3D3F3E3C3D3B3937383B3C3C3B3E3D36
33363939414A453939393738363A3C393A3F4242403D39363737383B3A3B3A3A3A3B3E41
3E3B393A3C3D3B38393D3F3D3B3C3D3D393D3A3B43423C3E3B3E434E5262646E6763664B
423C37363640484A44393C4C413F4446413E3C363F384034463A3839454B43493D484448
4646444343424143404146464F4A71848299A9B8B7B4B0C9C7B2B68BA981977E8C7F8E70
706A735B5952566A6B6275858E9D939D749487979AB8C8BFA6A1A2A68E8A9CA2B5B0BBB7
CCC8D4B6CB9FCCC2D2D1D6DEDCD4D8E5E6E4E8E2E3E4DEDDD7D4DECDBEAD85755B4C4D42
4A3E483E43443C413A403D3F4044413A393F403C41403C393B3E3A343D3C3A38393A3C3C
423E3B3C3E403E3B3D3D3D3C3B3B3C3D3841433C3B434B4C68504861777C7A7164565154
5F6E778287724D393A3D383A3A3A3B3D4042403E383939393B3B3A3B3A3B3C3D3D3B3B3B
444545433E3A3B3D3C3F43413D3E444B4A46414042403D3E455B728579533D3D3C3C3B3C
4044413C403F3E3E3E3D3C3A3A3C3F403F3D3C3C413E3D3D3F403F3D3B3B3A3937393C3F
3C3E40403C37343342363D5052637259523D34373A3E3E35363736393A45627268646857
553D43473A343A38363C39363A3D39363B3A373A3E3B38383B3C3A37363A3C383337424B
6B6D9B7772618F7D8B91AD9ABB8E8664615C50444347443C404444433A473843414A606E
8E92A4B2C0CFE4CFE4CBDACCDED5E1C8CCBFD4C5CAC6D9D4DBE6D7E5DADDD7EDD6E8D9DB
DEDCD7D2C6CBC0C2B5BDBABBB5A69F938F7B7D636D52534945493E466778849AAAC4C5DA
CBE2D5D9DBD8C5D4C8DCD3D9E1D9C9BFBCBABABCC7C9D8D0D2C7C1C0C5B6B59EB69D9C90
91847E7D766261536C617A6476727E879EB9CADAE5E2E4E9DADEDAD5D8D4CFD1CDCCCFCA
D1C8C7C4B3BCC8C4C6D3D6DACDBCA5939E92B0CD
4C4B4A49494949494A49484747474747484747484B4B4A484544444446474646474B4D49
4545454644454543414143464B4C47434543414449494745454645423F41434240404346
46413E414342414242434645404143423F3F414343403E3E434142413D3E3F3C3C3D3F3E
3B3C45504E54554D4644423F3B3E3F3D3E403E3B40403D3B3E3C39393E3A383A3C3A393A
403E3D3F41414243403C3B3C3D3C3C3E403B393C3D3B3A3A3D3B39393B3B3B3A3D3C3A3A
393837353D393A3B3937393A373B3D403A3539353E40403E3C3C3C3B3B3F39353B3A383F
46403E3C37393D3A3B3B3C3D3D3D3C3A38393B3B3A3B3D3F3C3A38373A3E3E3B3D3F3E3A
37393C3E3B403C3535393A3A404343403D3D3F3F3D3E3C3A3936373E3C3C3B3A393A3C3E
3C3A383A3D3E3C3A383A3C3C3B3C3D3E403F3B3A3E3D3A39333D4A60626355514B464835
393E3F3E3B3F444A493F3E4A3E3B3D3F3C3D403D3C3C38423D493D483D3D3B3E3E434242
383D404041404650545A6B5F8F96B59E99ACB3BAB7B4A2A192927D6C5648525449514B41
4A52494F4C586A828A7D7F717062684A5D626C6A7F87918E8B7680807C9699C2C0DDC9CC
B7B2A7A89EA7BED1C5C8CEDADFD9D9E2EAE1E2DCDED5D0D8E2DEE3D9DBDEC7C2BFA09B7C
764B48433C44394039433E393D3E3E3C3C3E3D3A41423F3B3C3F3E383E3C3937383B3A38
3E3B38393C3E3C3A3C3C3D3D3E3F404145443C384B6F8A9392696292AFB49C7C777B8D97
9FA6A2A7826D4A423F483D3937393A3A3C3F3F3D3E3F3C3B3D3C393A3A3A3B3F403E3D3D
404244433D373739423E3F3C3D4241444442444740374A6D83968C6C5340373B3E3F3F40
44453F363E3E3D3C3B393837393C3E3F3D3B3A393A3735373C3E3B38393B3C3B39383A3C
3B3C3C3B393838383B41576A646464483E3A3B3B3A3E3D32363E39373F54686656434339
44353D393C363E3E3A3C3939393736393C3C3833413D3A3A3D3E3B37363B3838434D565F
6D635546454A5C6D6C79667E68714A4C4E4E4438373F423D413D483941504C62728DA9B6
AEA2A1ADC2D7D0DCCED4C7C1B4C1A9C3A5CAC3CDC8D5D6E0E2D8D6D5D5C7D7CDDFCBC5B2
B2A4A48A90858884908A868273645B4D403A3F40423F3C413F4A507AB8D0D1D3D1DADDDC
D3CAC3C7C0B9CABFD7CFE1D9DDD7CFCDD3D3D1D3C7CDBFBA9C9F888E76785B6961694D57
554F4762637478838E8C8A9A93A3A2B7C1CED3D5D9D8D8DDD7DCDCDBDEDEDDDCDEDADDD9
E0D9DAD9CFC8C6C1C7D2D4D8D7DBC8C7AAADBAD1
4A4A4A4A4A4A4949464645444343434344434343454546464544434344454443474A4A46
4243444444444342424243444648444246454245434443404042403C4243444444454749
4D464142424140413B3A3E403B3E4444424549494846423E424145453E3D3F3C3F3E3E3D
3B3E4A565155534941403E3A3C3C3B3A3D403F3C3F3C3C3D3B3B3C39403D3B3D3D3A393A
3D3A3A3E403F3E3F3A37373B3E3D3D3F413D3B3C3C3A3A3C3C3A3938393939383A3B3B3B
39383838343A3D3E403F3C3C383B3B403A373D383A3A3A3A3937383B3C4039363D3E3D46
4542403B373D3E373C3B3B3C3E3E3B3937393B3C3C3B3B3B393B3B393B3E3E3B46444442
403F44494643403D3A3B3C393A3B3B3B3836383C3B3D3B3B3D38373E3E3E3C3A3838393B
353535393E4142423D3D3D3C3B3B3B3C3D39383A3C40413E484E4F594F483B3A3C3A413A
3F3B3B39413A343A413B38403C383A3B383A3D3B3D34403A403D42464039403A4C414236
424545464B505B6C7D9A86967CAAA4AA95948889807A695F4A48383E4341463D40414653
465E6471717E878D89726F586F5A4F50576A5A59524C464B463F434C4F5D8082A29C9A7A
88768D869CA6A7A8A9A49C9EA9B2BECECBBBBBBCCCC8C8D5E2DEDED3CFCCC6D4CFD7CFD8
B9A772785E706A746C786D5F49433E3E3F3E3C3B4648453E3C3E3D3836393A393A3E403F
3C3A38383A3B3A393B3B3B3C3E3F41424243465A86B2BFB4856A759093957986AFBDD1D9
D1BB9F8F8A83717C6E7255463A3E3E3C3B3C3C3943443F3D403F3C3E3E3B3D4143413D3D
3D3D4043423D39393E383B393C423F42403E42423D4B7295ACA28058443F3D3F3C3D3C3C
3F43423E3A3B3D3D3D3B39373B3C3D3C3A3838383B3B3B3D3F403E3C3B3D3F3D3A38393B
3C3B3A3B3C3F40413F4F544F443B3C3635373A3A3B40423D38413B38414B5149453C373E
394240383F373C3C3636363C4241494B4341423D3E3D3C3B3A3A3B3C31404550686B5D59
4433433346506A4E4D4B544B634746423B3D3C3A3C403E3A3E3042416A8294A0819599A3
787B83A3B9BFBEADB5A6AEA9C6B8B9A5C0ACC8C6D2CDD8D3D0C5A7A89C9D849F869C7278
60615569686E6F7277605C574845433C433D48464C4C56656E889BBBD9DAD9DEDEDFD5CD
BBAFA8B3B4BEC9D6D5DFDDD6D9CEC8C8C4BCB2A9988C907176564F49504F484B4F4A454E
5C596A6B8485949C9785858BA399B1BAC5CBCFD1D8DDDBD9D7D7D8D7D7DDE1DFE4DCE0DD
E2DCE1DFE2DCDAD3D3D6CECDD4DBD8D0C2B8C1C4
47494B4C4C4B4949494847464545454546454545454648494A4845444443424044484945
4243423F44434242424243433D434342454342464344424042454440403F3F4144464747
4A454345474543423D3A41453F3C4040393E403E3E41403C41414749403D3F3C3A3A3C3E
3D3D42494649473F3C40403B3C3B38373B40403C3D393C3D393B3F3B3736383C3E3E3F41
3D3A3B4042403D3E3936363B3E3D3C3D423E3C3C3B393B3E3A3A393837373838383A3C3C
3A3A3A3C39403A34393D3C3E3A3C3A403B38413B43403E3E3B36363A42463C353937333B
39393A363742443A3D3B3A3C3F403C383A38393C40403A34373C3F3C3A3C3D3B39363638
38394049433B3C3E3A3B3C373B393A3B39363940393A38393E39353B3F3F3D3A37363839
413F3D3C3B3A38363E3D3C3C3C3C3D3E3E383B3F3D40413A333C3E4539393D493C3A413D
3C323B43493D3339423D373C3A37393B393B3E3C40393F403639393D383B3A433F443C3D
3E464E5B6867636787727764857582737A69555D52484141453F4239574159475A5C536A
5F75687B7667595F696071678A5F6A485B42463F414A435F475D495965687A7375848B69
6672799EA9B7A88E8C8B80787671707788737482ADBECBDADBDADAC7A6806E80798E8783
899B849E96AEACC1C0C7AA885E4C3C393C3B3A3A3B40403A383E3F3B404647403A383938
3D3B3A3A3A3B3A3A3B3A3A3B3C3D3E3F4A6284ACD2DCB98B78545C697CA496D5DCE1DBD5
C4A78D757E745E69525D483F3B4042403E3F3E3B3F403B393E3E3C3F3D3A3B4246444140
413F424A4E4A4441413E45403D403C4244403D384574958F96765A4C443B373E3C3F3F3D
3C3D3D3B373A3E41413F3D3B3C3C3B393736373837393B3C3C3B3B3B3537393736363A3E
383736373839393746584C4146403D403C37353B403F3E3E353C373B403A3A3B35344437
363441323D32373935373D4863636D6344383E3D3A3C3D3A36363B4045677A8690785245
4A4642504A544A41515D47403D4039373E3A38393A3A38363E4A41718F8693686E626366
5F617789878D7C8397ACBAC7C2BD99AEA4AFACC2C4B39E928E806B63635651444E484045
464C4568706267605A3D41433A40444241486A77888C99ABBECDCEDCE6DDDDE0D4DAD2D3
C7C6C5D7D3D3E0D6D9D0CFBBA9948E8E84817E72837384708C6B69637F71777B827C8482
919DA5A7A8B3AEBDA1987CAAABB8BDCAD4D7DDDFE1E3DBD2D6D4D7D8D5DBDFD9DCCFD0CE
D3D3E0E1E2E4E8DCD4D5D4D8C7DCC6D4BECABDCB
4D464D524E464A4B4343484F4B44454C434C464843424440444A4A444348484244424347
464241433E43474744403E3F3E4444454946424446414043474644444341424546454342
43474B49433E3F4140414149443C413D3F434C47403D3B423D3E453F41483F3A3A3D3F41
414141423B3F43423E3C3F42453E3A3A3B3A3B3E3E403F3D3F43403A3A3C383C3C3A3F3C
373E453F414337393640353B3C4443433C4043403A383C423B3D3C38373A3B393F3D3C3D
404143433B3E383D3E3B3F39413F3C3A3B3B3A39373B3A353234383A3A3F3E3C413F3C3E
3A3D383A3A3A403C3B34333D413D3D3C3C3D35403C3D3B3A3C3F413D38373A3D38393945
50443A453A4246413B3B3F423A3A393C383945443A3D483F383C383F3C3A39383A3B3C3C
3C3B3B3A3B3D3F4141403F3F40403F3E35383C3F3F3E3B393A42453F3B3E403B3A3C3E3E
3C3A3A3B3D403A38393B413B363A3F42413E3C3B423E3E3C36383D3C3C3940423E44483D
50585B65625657554E495A5B5A5A515E42413F3E3E3E3F40473C405C77818180735E5B59
595F59564F3D49666B666869555B4A434944454D5A646C77736A6A5E5E5C5E677F9CA08C
737E77838A7A7666615E5C554C556569805E6E5A98B1CCC8D7D7DECFAD9C8B6A6746434A
4B49514A5D647873A6BAC7AA93754A3A433C403C453B373D394D4241373B40413C393A3D
43393A3B403F423D3E423747354C52609EB6CCE5E4CAA4919090A7A6CACCE1DBE2DED7CC
A47761534846463F403F373B373C413C3A443E3A353F3E3D3D393A40393C433744424653
556A7E84724646403C403E403D393B4D443D465C809C8993544C4B42393736403A3B3E3F
3F3D3C3B36363C4445403A383C38383B3A37383D3D393F433C3A3F423B3A3A3B3B3A3B3A
383E41393A3D415255584D3F3B38373B383A3B3A3837383A393D38343A3C393A3937373C
36372F433A3935384B616A897F705A49403D3A383A3B38393C3C465A737D8487685F4750
6A6355525D6465696B463B3F3839413A373C3439483F3646605D8C928D7B63675F5D434A
484B5F6F5A647195B5C0BBA8A793A09DAFA38E84816355554A4343403D3C3E423D404140
3B44445041483C41393C4968656A6B79648EA8BCC5C5CCD9DEDDE4E2EAE5E6E2DCE1D6E4
D6DADCE6D7DED5BCAC8C7C7C5764585A5A5973878F99959DA08F7F93939A8FA6BAC4C8D2
D2D5D3C9D0C4CABBA98E9090A59BB0C2DCD6E1E3DDDCDBDFD0D7D4E0CEDECDD6C9C5AEB9
BCD5CED7D7DBDFD8D8D7D1DCDFD1D5CCD7C7CFD0
4A4949564C504D5046474C504E494A504B4C4E4549434B46434546454545444143464643
4245444144424244474744413F434344484643453F40444A4A4643434344424143454440
404242413F4041444343424A464046423B3D46423D3E3C423D3F4641434A433F3D3E4040
3E3E3E3F4442403D3B3B3B3C433F3C3D3C3B3B3E3D3E3E3D3C3C3B38393A36393B3A3E3C
373B413E43463E4237433B424245403D414141403D3C3C3E393B3C3A3A3E3F3D3D3B393A
3B3C3D3D373A363C3F3E423E3A3B3C3E403F3B3835393B3A3A3D3E3D363635393E3A363B
363C39393A3C423D3E3A393E3E3A3C42383F343C3B3C3C443B3B3B3E3F3E3D3D3B3C4356
5F4A3943393D3F3D3C3D3E3D3A3C3B3E3937413E393A413E3B3C3B40403D3A393A3D3E3F
403E3C3A3A3A3C3D3C3B393A3C3D3E3E37393B3D3E3D3C3B3940423D3939393636383A3B
3B3B3D3F3B3A363E413F45463D3D3C3B3A3A3B3C36353A3C37383C3A3B383D3E3B475452
51535354514B4E50574A4F4A4848404B41403F3E3E3E3D3D454246566A77777361504E4B
4A4C46453F38414E515659534D4853716B4E5C7F7A7C79786A5A544647454B566473766D
53614A5A494F464A465463625E6E8DA4A59A89969CBEABAEB2BAC6C7C1C5C3B2AB807C60
6752695D6F849A7E8789A39F9A957957453A423F403A4843433D3F413A3F434443404043
41463D3E3B443E3E393F48485D84ADB8D4DDDDEEE2DEC2C3C1D0D2DDD5DED7DBCFC2AC96
71524A434644423A3C3F3D47433D413A3E403D3B404039393F414043404F414F58707A9C
7B8E807746393E4E3D3B403B3F333B443D668495BC9F89674F4645403E3F3D443F3E3C3C
3C3D3D3D3B3B3E43433F3D3E383A3E403D39393B3832383C3C403D383A373837353A4040
4744433B3B40414B474C484142403B3B37373838393B3D3F3C403B363A3C39383737393D
393E353B3B3844536C7E8186584F423A383A3B3B353838383C41546E726A5F56444A4858
5D606471828070654D37353C37373B36313C39343A41587DAD9A9F8A76635A604C4E3C3F
36406282868E97ACB4A9A095A1A1A1A38E7A5454423A3C413D373A403D383E41413B4540
3B40373E3D444F5468738B9DA4A5A7A3ACBECDD0DCD8E3E0DFDDE5DFE5E4E6E9D6DED6E0
DBDFD5CCBCA6855E5E4E4B4B414757597B738C858A897D7A6D72656A5B727998B4C1C5CE
CCD0C6C6B6ACA8A6989F90B39BB9B7D8DCD6DEDCD6D6D5D7D1CCD6D0D6D1D0D0D4C1BDAB
C7C2C6BFC0C5CCCDCECBC5C7BDC5B5CCB0C4BFD7
7F6C645861616D6B75736F6A656263666A6E696756554441454343464645464842454542
4245454247433F414547444144464544454341423E40464B4A4542434545423D3E43423C
49474243434644444C474244403D433F4340433D3A3D3E453D3E423D3D413B3842434342
3F3E3D3E3E3D3C3F42413C3741403F3F3E3B3C3E3B3C3D3F3D3B3C3E3E40393A3C3A3C38
3B393B393B3A35393C43383A3B3B3A393F3D3C3E4243423F393B3C3C3D40403E3F3E3C3A
3B3D3C3B373A383D3F3F42403D3B3938393C3D3E35363534353838353C38373E433C393E
35403C39393B413C4147463B39403F3A38433841433F3941423A35393D3C3836393B383A
413B353C383938383C3F3C37393D3D3F3A363C383A3E3D403F3C4243403D3937383B3E40
413F3C3A393A3B3C43403D3B3B3C3C3B3A3A3B3C3C3D3D3D3F4343403D39373738393939
3838393B3E3B363C3F3B41433B393737393C3F403A3B3F413C3B3E3E494548463F454F4D
4C4B4A423E414145483A3C3A3E433E463D3D3C3D3F403E3C474843404651534C4E454643
40403C3C3A3C413D3B484D4043516F86735F72826664605F564E4D434842444B4B464340
3C4542423D3E414B516C7F7B6D6A7A8E91918990938D746E6C7274747D8E97949D9788A6
8AA89D9F96B6D8C4C1B9CBC9C7B1A387917B7F6A86777E636452564B4951524F4E453B3A
3F4240373B454A425E7E87AEA6DBD9DFE2DBE1D5D2C7C6D5CFCBD9BDDAC0C9BCCEC3AF9E
897E848181715A413B3D3C474135403345393B383C3D3D3C3F3E393A445BA298BC8E9F6F
64584A424541403C47433C433840444F7DB2C1DBC2A65A47433A39373A3E3A3D413F3C3C
3D3D3C3B36383B3E3C38383A383E42403D3C3C3C433A3D3B3D453F3C3D3C3C3A383D403A
594D4A44444B4B4D3C3D38363A3D3A393C3B39393A3C3D3E40413D393B3A373739383837
353D35323E497A83897161443E3C3B3B3C3B39363A3A393A3D435367514945403D3F3B40
4449515E696453473B35383D3A383A38393D3A3742597A989F948E81736465644D4A3F43
41587FA49B9DA4B8BEB2ACA8A79994796D473E3E3A3836383C3C3F453D3838433A383F36
38404B5472708E8898B1BDCCB6C5C3C4BFD0D1DFD5E0DED9D9DBE6E1E1DDD8D7DEE4DAD8
D0C7AF9264604D3F434D5C708E939FA8AFA5947A665B574C444B433F3F525266859BA4B2
C5BEC8B2B794A6A5BDB9D2BCD4B9CFC9D3D1D6D1CAC9C1BDBBBBB0C7B9D2C2D0D1CAA4B4
98B48B908889898D8C87847C857B80717B6F838C
A09B84918BABADB8B0ACA49A92909090998C916D6C544F4447464342424447494C4D545B
5B534C4A4342403F3F3E3E3D4444444343434243444242454542424442413E3C4044443F
44423C43454C47454542444947474843423E403C3C403E424042433F3E403D3A45464746
44413F3F3D3D3E4246453F394141413F3D3C3D3F403C3A3C3A353335383D37383D3B3B37
3D39393B3C3A393D44483C3C3D3C3D3D46423F3E3F3E3C383C3D3D3D3E3E3D3B3F3F3C3A
3B3D3D3B3B3C3C3D3E3D3E3C3C3B3A3A3A3A39393B3935343A4144423C39393D403C393A
3945403837383D39404948393B463F363F4439434649494E584B3F3E3E3B38393F443F39
3D403F40383938373A3D3A34373C3C3E3B363B3939453E3E3A3845423D3A363536393C3D
3C3B39393A3D3F3F44423F3D3C3B39383C3B3B3A3B3C3D3E434542403E3A383C3C3B3A38
363636373C3E363636363B373C3B3A3B3C3C3B393A393B3C39383D43655D585147464845
44424439363C383A3F373B3C3E40393D3A3A3A3A3E41413E3F413E3A3E47474040404241
3E3D3C3D3D40433B3740463C4C697C745D5C63504642414342434540463E3E4649454242
495468676E68656B7D8B8A796B626774747978717550443F4244454750606966898BA6B7
C5C7C6B0A0AFBEB3B9BBC6C0BEA59D958B70767E9DC2C1D19CB8A7B19CA9ADADAA957768
4A424E44536D999CBAB8DBCFDFC8CEBFC2C9CDD4B2B8AAC9C7CFA6BDA4C29EA5908C8077
6E6E7772837159423C3C353A3F423E413A42373F404247413D40455079C7C0CE919B5A46
423C433D46373D4548343C334C56818BBDC4E2C0B15F433F403A3B383B3E3A3B403E3E3F
403F3A36353B41423F3A393A3D403F3B3B3E3F3D3D38424141443C404045433F454C4E4E
46393A37363F403E413D37363B3E3D3B3E3C3A3A3C3D3D3C3F3F3D3B3A393737303A3E3D
3B3D3C42597784A0686840353D3E3F3F3E3B38373F3B383B40414347403B3E3A3E393734
3C3E3E3E3D3A38383C3D3D3B3B3A3A3A3B3A3A4050637072787B75756A565044433B333F
4D6C81979B9EA8B6B7A59489746A5A564340434E404042474C4E4B463C3D353D2C37443C
527371A197B9BCC8C7BCC4BAC0BAC1B2C3CBD2C2C6B9C9C2CECFCAC3BFB8B6B0BAB5A598
887059434549425B7298A4B6BEC0C9CDB39669474A3B423B413C3B4149708796AAB6BECE
D7DCD4DCC5C7C4D3CCD9CBDBC1C9B8BABBBDC4BFB9B6A8A0A38DA390B7A8BEBCBAA09D7B
836C60515A534B4E4A484D424742444448444A4E
D6D6DAD5DDDBDFDDE0D7C5AE998B817D817B7265555647474D5457585F6B706F7E81868A
806C5A51474747484746454440404142434547474A433F404241404142404043484B4A49
47443C43424C47474C474847454746423D3B404041433C3C3B3E3D3D3E40434141444747
4542403F4B4945413E3D3D3E4141403D3B3B3D3F4C45424446423F403E48414145413E39
3F3B393C3B37383A49483C383D3A414343413F3C3B3A3A3B3D3B3B3C3E3D3B39393A3835
373B3B383D3D3E3D3C3B393A3F3E3C3B3A3B3D3E47443F3B3D42423E3A3B3C3A3B3F3E39
3C483F3737373C3B4040413A3D3F39423B41445651555A5B574E46413D38383B383A3A3C
3F3B383B393C3C39393A3936353B3A3C3C383D3D41544B443B3A4D473B393737393A3A3A
3A3837393C4041413A39393A3A3A38373D3C3B3A3A3B3D3E40413D393B39373E3B3A3837
373838383539363B3D3A3C373536383C404241403536383C3E3E434B584C423C393C3F3E
3F3D3F36353C3738413E413E3B3A373C3C3D3B393B40403D37383B40474A453F393E3F3E
3C393A3B3C3A3D3E3B3C41425A66665C4C444235413C3D3E3D40413D43403C3C3F3E3E3F
5064728B86947C858B89766056515158515C494F433A3B504950647785969D939EA39CB2
A0B39C8D6D6B66585B636F7069574556494F506CB0BFD6C9D2CDD5C0D0D8DADDE1D6BCAB
9B98859F92C5CED9BEBCB5C59E9E7D848A8FB3B2B0A8A9BBD2CCD6BBCA9B825F514F453F
3A3E463E4543433D40413B413E4858454B464B507061554542515E6DB1B3B17C4B484D3B
3E453E494857586B6E645E66677C8C968FA993A35D3D37463B3A3E3A383A383C403F3E3F
403E3A35373D42413C393A3B3E3E3A383C42403A443B3D3E4043455359717C79725A4039
3E363C3A373F4141413C3A3D40403C373939393C3F403F3E3B3A3B3B39383838353E3C37
3B3A475C756E7E57603E4F3F3C3B3A3837383A3C3A36363C403F3C38413D3D3439353F3E
3D3D3E3C3736393B3B3C38363A3C3A393C4551565658564D5D6055554E42423D3C45495D
7187888E9596958C7B675349453F3F423339474A484E6271717069593E4559454C517F7D
98A4AAAEADB7C3CBBBAB9DA38A949FAFB9C4AFB2A7ABA0A48185777979777B707A6E5D58
4B3B40494F5D7C91B4B8BDB9B89FA0877F5B564748494F6D677E7F978BAFCAD2DBDEDEE5
E1DAEDD4E5CCDBD5D6D2D9C6CEADBDB7B0B4BAB4B2B0A49E888478897E91818B78746268
4E5C4346443F383D3B3C443B3D3E3D3F38393B43
DFDEC5D5C9D9C3C6BEBDBAB4AA9E9795988C9171796265595C666C6C70787871797B776C
60564A3F3F3D3D414648443F434143434143454348423F4143413F3E3F40403E4042423F
47473C433D4A474B3B4D718686785A43514A494342443F413A3D393A3A3A403F3B3E4142
413F3D3C4B4A48433E3B3C3F40413F3B3A3C3D3D433E3B3C3D3C3A393F4C46444743403D
3E3D3A3B353238373D403B3C433B3D3C393A3B3B3B3D40423C39383B3D3D3B3B393B3936
383D3E3A3A393D3B3A3B383A44413D39393C434737393A393B3E3C38383C3E3A3841443D
3B453C373A383C3F434344383B403C4C525A626C5145423B4041413E3937383A383B3C3A
3B3C3C3D3B3E3E3A38393938363D3A3C3D393E4044564E463C3B4C483B3B3B3C3D3E3C3B
3A39393B3F41403E39393A3B3C3C39373C3B3B3A3A3B3B3C3E433D393E3E3C423E3C3A39
3939383737373A4A4C3F3C3A3D3D3C3C3D3D3D3C393A3D4347434148443D393C40434544
413D3A36373C3C3C4241403B36373E464042403A393D3E3B3E39383C3F3D3B3B3C433F3D
3C393B3A3A373B42413E424A50554C47423A3B3C433E434240434241393E3D3A3B3F444A
5E666A726D705A5D56575047444341413F423C3E4E547791777A8995989E9D8F7C72625D
535F5B504143413E3B3F40403D3D4A3E4D47566376938CB093C0C7DDDFDAD4D5DDDFD0BC
ACA6BDA9DBC8DDD0D9B2B485907E99A1B5BBC3D8C9D9C7CFCACEB1C7A3AC756242433F40
3E41473E393E423C3F4B586E889CB3989988898D8C716562789FB3C19B8B614C3C453751
495F6A81A4BEBCB3AC9A9B7D806266575A5B6A4D482F483A35383F393437373D423F3C3B
3C3C3A393A3E3F3A3636393C3B3A393B41433F38413D3A43515E6E7E9B9F8F735A40343C
39373E3B373B3C413F39393C3D3D3D3B393A3C3D3E3E3C3A3836393C39383A3A3C39333D
565D676C5A5F4747373D353A37383939393939393736393D3B3C3D3B393D3F393C37413F
3C393A3C3A3A39353A3937383E41403E4553605E534B47434D4B413F383636404B6F777E
8081747672695E4D44423C3B44323F2F485475708076797B706A624E557B858F6D91A3BF
C2C2BBC0BEC9BBB2957879676467A3C4D5C5A78F987B6B5C4D6570888D85765E584E3E41
3A3C56716E9090B58A946D7455556F879988847B8F8EB4ACC1B1CFC4D4D6DBD1D8DEDFDB
DBDDDADED1D6C7C9B7C5B0D4B5BCABB3A3A09B8C837D717166596E556F58605447454344
3E3E3E3B3B3C3C403E3D403D39413E5046554F58
D2B993847C766766605D5E63697282928E857560574C4D45464C5152545755504F504C45
43464644444344484D4F4C4945414445414244404443434543404144414B4C42424D4F47
4B504951454F4B525F6D8E9B9A9179675F554F444044424643453F3F3D3A41413A3B3D3E
3D3C3C3C3F404242403F3F3F3E3F3E3A3A3C3C394345433E3B3A3A3A30413C393F3E3E3E
383B3A3C383B4A49333B424A53423C343D3D3E3E3E3E3C3B3F3A383B3D3C3B3B3B3E3D39
3A41413D38373D39383A363A3B3D3E3E3D3C3D3E383C3F3C3A393734393A3C3833383F3C
3C43393A4039393F4245463B4B5E555B56575257413B3B3A373F423E3B3D3F3D333A3D38
373B3C373D3E3C39383A3B3939413D3D3F393D3F3A443E3E38343E3D3B3B3C3D3E3E3D3B
3B3A3A3D4142403D3D3C3C3D3E3D3B393A3A3B3B3B3A3A393D46413B42444144403F3D3C
3C3B38363B393A494A3C39383B3C3C3C3B3C3D3D3B3B3A3F433B363B34353940423E3C3C
413D37393C3C3E3D414444413C3A3E413E43433D3A3D3F3D3F3D3B3B3A393D4240473F3C
3E3C3E3C3C3E4041414043463F47403B3B3B4041443E45423C3F3C3C3F44444348494B52
525051464C4440403F3F403E3C40423E403D4B4C6B69858B87837B70665F564C52484636
3B3A463E3E403F4440433F40413B5552958F9389B1A8B3A7C7C1DFD0D6C8C1C3C9D0C1A4
99BCAFC1AECCBFD7DBCBCBC4BDCBCCDAE5DDDEDEDFE1D9CCB38E765254494F3A40444852
54565B53555450454B5F779491AC9899667256716E739ABAD1DCC6B7A07E5C56535C6474
85B4D4D0DFCAC2AA9489775F554743414640433F304F3A3A3C3E453E3A3E3D41403E3C3B
3A3A3A3A4145443E3A3B3F4139383A3F42413F3E3955667E9399A4A2927F69554339393E
3A3B3F39393B3A42423C3D413E3E43433D3D3E3D3B3938373834393E3A393C3D3F3E4C65
80837F63454739393834373B3B3C3D3D3D3B37353C383A3B383A3E3B353D3D3B3B373F3B
3C37383937393C38443F3E3F3F404444434A4D49453F3B3C3F3B3E3E393E374F69988B77
685B4D4E493F3D393A3E3A3E3B3A43496C949D9C705F524C4747463F69799C7F8582A2BB
D9D6D5C6C7AB95735F4A4C657AA0C1C9AA93655B514B43486F82929A8C7E5B45474C4048
425264727E73685E5B534C4440515D8592928D8CA8C6CEE3D1DEDDD0D1CAD5CAC8CCCFC9
C7B4BAA3AA9495949E9AA896A874816B5A5752484645414B565A5655454E3C3B40443F4C
47494E474D4E4E474342434C50567E7CA08FA096
B7A983785B54434F4745494E4C474B544E4A4A3B493C4C4043414243434242434241454A
4A4440403A3E4243414042443D3A404442464A4742444646413E444D596D7062667D867B
727A73765D5C4D50495470797876665B4E494A45434540433E413A3C3A3741413C3D3D3C
3B3B3D3F3E3C3A3A3C3E41423C3E3D3B3B3D3B36333C423F3D424A4E4151473D3E393839
353A383833394C4A3B3B393943383D3D3B3B3C4043433E3A443E3A3C3D3B38393A3D3B36
373E3E3939363D38363833373B3C3B3836343637373C3E3A37393B3C4642434138383E40
3E433A3D4338353B3D383D44698171724945363D3A3B3A3A363E3F37353B3D393D3B3B3B
39383B3F3E3D3936393D3D393C44404040393A3C3C3C394141393D3E3A39393B3C3C3B39
39383A3E4344413E363636383B3D3D3C39393B3B3B3A39373844403941443E3F3B3B3B3D
3F403E3C3838353C3D3839363C3E403F3B383635403D383C423D3940383B40423E37373C
3F3D363F423C3E3A3840474C4B44403B3841443F3C404240343C43423D38393C3C443938
3C3B3F3D3C44433A383D3E39403D373E3D35393D3F3A423E393D3A3C403E393E47433D40
40463940364037413D3B3E403E44474044524F7B6B7F5F5C4F52484043423D3F3E3C453A
3E38433E3B3C39403C4447504A5662859DA99AB7A6B8A3C4B0D7CDC9B59E949AAAC3C5AD
AFB9B899A09DA5A1B9A9C9C3D8D3DCE1D5CFBFBFB0B3A3927B736F73636B675A63687081
8A92A09DA79B876C5D564E55525A5A4F546581ABC7C4DADAD3D5C9C9B7CDABB8A5BEBAD6
CFEEE2E5DDC9A37F6059553D4939403F3E393C3D433C413F3F3F433B393D3A3C3B3C3E3E
3D3B38373D42433E3B3B3C3B3A393B3F3F3D4148689DB9CFD5CAC6B4966D554E46444338
393B3B35383B374238363E443F3B3C3A393B3C3B3A393A3B39353B403B3A3E3E555A707A
746A6942463F35353A333B39443F393535383B3D3E363538393E3F37373F3B3C3A363B34
363438393438414450474340383840443E403D3C403D393B3B343E403F4F4C715E8A6849
3F3B35393E383F3D3732303F384D7A6F9E95816A403E3C3C3936373D4449504D4F7084B4
B9D1BDBA8770534345507D96A8A8A5845B4C4042484D6E85A9A59F8A768277817D8C7D7A
67716558535A47583A4C3B443F4B535C7C769396C1D8D9C7CBB1B6A0B6A0A4938A8B8E84
736263656E747F9490A18F936D5A514F3F3E3E3B3E3F40504A4D55474C5255534B565475
7D8A9991A5A39D8B858A90A6A8BDC6D6C4CCC9D5
6A687E72725A504C4B4749474F58514C554A4B48494A4145474E4C48424A41493F4E4C43
434544414844434E4243444B41433F3E4547484C46443D474E5C71939AAFAEAEA2929384
7B5E694F54454541423B444947413F4D4C4245413C43474B3B3D3E3E3E3E3F40383A4143
3E3E403E45413F3B383E413B3B3F43433F3C3B3B3943383C3845617F3A393A3E4142403E
3B36393B37393E3B383D44433B383E433F39393E3E3A3C433F3C3E413F393638363F3A39
3A3D443B3C3837383837383B3736373A3A383A3F3A3C3C3A37373C41383D3D443D30383D
363A363E4339383D383C3E5D6E635D4B413E3D39383F423D363E423E3A3B3D3C353B3D39
383C41433A39363C4747424437363E423C3A3F413E3A37394045464446323E343A363947
4D4754594E4D5042373B4142403D393B3F39383A3A3D363D3B453E3B48423740423B3D37
3E444D4332353A343536303B373C3E3A36383B3C383C34323D3C363B3C373C393B40393C
363B3B37394140394143454A4C4A443F3B3B373940403E45393F3E3A3F413D3B3C3A3839
3C3F41413E4041403D3B3A3A373835373A3633393D3C3D403F3D3D3F42433C40423E423B
393D41413F3D3E40393C383D4448525058597067694F453F3B403F3A3A3D3D3B393D464A
3E3E404044565B6B617671848586868B9499AB90A483A08FA797A88D9070636E778D919D
9EAB9DA797C0A7B0A8BDD4DAD8D4D0C9B1A696897674666B7394BEB6C9B9CFC1C4C3C3B5
B0B1ABB4C7D5C7BCA68278707F6F788DB1C1D5E4D6E4DFDCD2BEBDC5CFD1D6CFCCD1DDDF
E6E6DED9C2B18D6D674B3B4E433F373F3B3B3D37443A3F454943403C3B3C393A3B393C39
3B3B3C3C4038403F3C3A353B3D413C453C4D6F76B3D8D5D8DED3DAD2B0A0938372716B55
47414340383E463F404344423E3C3E40383C353C41393839383A393C405F777C8479795F
4F44423C343A3A383A3531343738393938383A3B38383E413B393A3639373B39393C383A
383F3836474D4646474A3B343A453F3D3438373C3E3C413F34443C4D715C5250444A3F35
3E40373435363B393C3A344256807B81684C4A3A3A3C2F393D353C37393C4B52886F707E
A8857962484F5E646B79839A8E6450403F454A656C9F93C5B9AA847D86888C8597829271
7955674C53514F4E57454351628DA6B8BFBBC5C6BEBC9FA56D6B54616A72696C6D756764
50577880AAAFC3BDC2ADA978884F4E46454F4E50616F80979EA29A9E9E939CA9A7B1A0B8
BCC0B2BFC3BCBBC0C3CACECAD0DDDFDDE1D1D5D2
4E48574F584C4C4C45434541444B47464B454A4B4F524E52545B5A5A5556424147505147
494D46413F413D4441433D404646413E4141404341384E658A878C8693A0968D7A645C48
4F434A434447423D403B3F3F3E3F404A4A434443414549483D3E3F3F3E3E3F403A3A3F41
3C3D41413D3B3D3D3B3D3E393A3D40403E3C3B3B39403C3F45574E46403E3D3E3D3A3B3E
36363B3C39383B3B343B4041413E39373B3A3C3F3D393C433E3E3D3B393A3A3A3A413C3C
3D3F453E3A393A3E3F3C393A38383A3D3B38383C383A3B3A39393C403B3C3A4240353839
36393841433A3D4164563D42453E433C3E3B3D3D3B3F433F3D3E3D3A3A3C3F40393A3A39
3B3E3F3E3D3D383638383C483B36393E3C3C40403E3B37373A3F43454E3D40434D5B5E75
69767D8A57523F383D3B3C3D3F3E3A3743394039413A393936423F3A403B37423F3A3F39
3C3B45403C3B3F3B3B3D363A393D3E3B393A3B3A383F39343937363F3A363B393A3E383A
393D3E3B3C3F3E3833383C3D393636363E3C3D3E3B393C3F3C3E3C3C403E3A3C3D3C3A3B
3D3E3E3E37393B3B3A3A3B3C3739393C403A363A4240404343403F413E3F393C3D3A3C36
3939383736373A3D3C3E464E565B5D5F5D5156474C4143453B3B3F3F3B383A3B39384244
52586A6E777A8A728A848F909A9F9593A19C9C80736D637466705A6246444655565B5966
8E7D9270A49AAA99A9B5C1BEB8AB9D8E8B8C96A39B958489759788B3B4CDDDD8CAC6C4B8
B0A8A3B1BFCFCDD6D8D0D5D0CAC6CAC4C9C9DAE7DEDDD3D3CDC8C6CAC4C9C6CDC3D1D2D4
CEBFAD8E736E5B4F5043394B3D3F39433C3D36403D433E4542403E3B3A3C3D40383D373D
3C403F41413936373E423D3D40555C7E6A7C95A6AFC3D1CDD2D3BFBCBBB4AB9A84786C58
483D3B3A3741473E3B3C3C3B3B3E4348353D3F40403A3B42314C42465A9AA9A965544F3A
37383D3A3B3E3B383937353835373A3A39393B3D38383D3F39383A3639373D3B3B3D3839
393D3E47544A3C3D3C3B3F3C4341433D3A3F3C3D3B3B484D54584A4C5741403F363D3632
3E433F403A393835383C404B73776B55443F383B37343F37353D373C556C67928C855056
574446443E516672525F56544A3D444062689476B29AB3AAAC91746C767974756F595648
3D474E525F6D666E5E6D708396BDCBCFC9B8AE9B98706B5C605A748AA69EA4898F6E6B5C
566C749897B2A9AD94916D684B54516262727F93B2C2C6CECCCEC5C9CDC7CED5D6D5CED4
DED3D0CEC0BFC4D1D5DEDED9CBDBCCD5BDB9A9AC
53484E434D46484748474A45444846494C484D4D4E4F4A4D464F5B6C7682716F60574F41
49574C4846493E40414942454546434145444143464B58786D6D5C57525B52504B45493E
424443433B474442403F443E3A3E404A454242404140433C3D3E3F3E3D3C3D3E3C3A3D3E
393C434439363B3E3B3A3C3A3C3C3D3D3C3B3A3A403C3B3E404F3E3539393C3F3F3C3C3E
3E40413D3F3A38363C4340393D3C383A373C40403C393C413C3F3E39383C3C383F423E3E
3D3C3F3C3A383A3F413E3B3A393B3E403C37363935383B3C3B3B3C3E3E3B3840413A3835
3938363C3837464E68583B383936403E3C393E423F3F4241433E3A3A3B3C3C3D3D39373A
3D3E3C3B393C3C3C3A36373F3E3634393B3E41403B3B3938383A3E403B3F656C8F858995
918A887D57484139383A3C41423F39303E3A39413C463C413B41403B3A3839403E383E3B
3F3B413E3A383D3B393A3738383B3B38373838353A403A353735363F383539393A3C3737
393C3E403F3E3C3B393D3F3D3936373A3E3B404137343B3C3F3C393D413B373C3E3D3D3D
3E3D3B3A393A3B3B3B3C3E4040403C3B3E3C3B4042404042423F3E4040403B3D3E3B3B35
3E3C3A3A3D4043444B4C5B61605747474D41443B44403F3F3A37424B44404445434C4C61
687C79806780667259816779717266657B7C77565E5B4F4B51493E57546870807E7A757F
787368707F928785748B778A5B6A45465369889B988E6B594E415E6DADB0BBA8B8BAC0BD
B5A7A1AECEDAD7DEDADCE5DED9D9D3BDB6B5C8D0CCBFBEC6B9BAAC9EAB909C748E728B78
776B6A4B3D443F3E433A46394233413E3B3C42453F39393A40413F3C39383A393A413D3D
41393B3D3642434C5F696E728C96A9B6AC909C979EA8A7947D7F656D6B6D6A5F534E4B46
493C37393D47483B3E3D3B39393B3E40393C3C3A3A3839404044465F7C95A871493E4238
3C3D3E3944423C373839393C393C3E3D3936373839383B3C3838393839383E3C3C3E3839
43413E43493E33383B34383F3B3D3F3A3B3E3839393B484C6154424042363B31353A3534
3C3E3C403B3A37393C475659585B463A39313B36393933393844656B97898F7587554634
3A353C403B4143473E4235373B3848556385729F74A4829F7D7452545C545A5046413946
4E57787D9CA8BE999988A09AB3C1B3A28A70665558506E929CB6B3BEA79C7A7C52533A3E
52556A607468736A4948383E3A4C5F657B8EA0B5CFD8D1CEBFC7C7CCD2D3DADEE2DFD9E5
E0E2DED2C8CBD0DDD6D5C6BBB0999E718F5F6E57
504A4D464D474946484549454447434544444849484744455048404652717B8A8B817755
44463C4243444049464942434346444448453F3F42404B4B483E4345444C494845424640
414747443E3E41404540444240403E444645443E423D40383D3E3E3D3B3A3B3B3D3B3D3D
3A3D44443E383B3E3A383D3F3F3F3D3C3B3A3939453F3E42383E3A3F3C3E3E3B3B3F413F
3B4142363A35393F45514B3F3F3C383F3A3F42413D3C3D3D3C3F3F3E3D3E3B36413F3C3C
3A3637363B37363A3C3C3B3C3C3E41403B37363835383B3D3D3C3B3A3D3A393F413C3734
3B363541444855544C4436393C383C393E3B4045403D3F403F3A393D3E3B3A3B3E38363A
3D3C3C3D3A393B42464139353D3734383B3D3F403A3B3C3D3D3C3A383D5B80A7B7B19197
7F66594A3F3A4139353C4045423F413943394E425345483E4543403C3B3D3D3A4036393B
4741423D38393F3E393838384343403D3D403F3C3B3C36343939373A3737393A3C3C3836
39393C403F3B3B3E3D3C3B3B3A3937363B393D3F3A373B3D3C3C393B3F3B383C3C3D3E3F
3E3D3A383E3D3D3C3B3C3D3E3D3E3A393F4143494442414343403F40403F3C3E3F3E3B38
37383B434C5253514C474E504C42393E403B414046474140413B464F4845463F4F525E59
6C5C574E576064434F484E55585E646673797E636667515653655F81737F777F7A777270
705E7D578A5B6F5E6176877B73646464707F8F8F8C896E594A4749756A8E6679798898A0
A09998A2BFCED3DACFDAE8E5DFDEDAD1D7D4DAD1BBA69F9471736B6554515B5248465E67
7B6F6C4A3D4042403E42423E3E44443E53625971404C3A473D3F3B3C3F41443F373E4239
40333A43456E8496A7ACB6BFC9C8C2C2AC91938A867D714E4F3B453E3A3D3B37373B4146
4E454142444741313939393B3D3E3D3C3F3B353A3E393939425461876D7D6C3D3E394237
3936383846423B3737393A3B3A3D403E3A3636373B3A3A3A38393A3A3A383D3B3B3C3739
45413A373838393C3C353839373B403A3B3A34393E3F433E443E373A36313B393E3F3A37
3A3634393739393E40495850394339373E303D363B355666687885988F76614746393B36
3838353A373B353738413B4251565B5B8862624A534D516B6A5E543B3B44363939384764
6A9290AAA8C9C3C79FB2A1A4A7956F5D4E3E44425360A393A7959B7D78554D394230403C
3F40453F453F4038424156516B55716791ABC3D1D8CFC0B9B7BEC1C3CAD2D9DBD5CBE2D9
E9D1DCB9B5B7B7BEACA38B7B60594C46403E3E42
48494D484B44484548444746494A4343404243444442424044424247434C454A68676F5A
4A4B434840445C7D777168645757514C4C4741424343433C423F485067757C7D73655F58
5147473B493C46444B3D3D4247453F45413F40353D3C45443F40403F3D3C3C3D3E3C3F41
3E404443433D3F423D3A3E413F3E3D3D3D3D3D3D4146434B403D3C3E4B5553443F4B595D
5E64614A473F4B55575D503F3F3E3D474041414040403D3A423F3E41413D39383E3B3B3A
383836383C38373A3C3C3C3E3F40403D3937393A38393B3D3E3C39373B3A3C3F3E3B3738
3B383E55616057423F3C35383A393C3C443F42453F3B3D3E3736393D3D3A3B403C38373A
3B3A3D42433B383E43423B353838383A3A383B403F3D3C3E403F3C38494D696F967C6A5E
4C4538483240383A3D3F3B3B383C494244444E564D5246404442413E3B3E3F393F37393A
463F3F3B413E3837383B40413E3D3935363939363739363639393739393A3A3C3D3C3A37
3C3A3B3F3D38383D40403F40403E3C39393A393C403C3A3E383C3A373C3E3C3C3B3C3E3F
3E3D3B3A3C3B3938383939393A3F3F3F43413D3E403C3B3E3F3C3A3A3B393A3B3D3E3A37
3A3A3D43494B48443A38373F3F383D4244413F3C3A43424946424C5553595A4A434D434B
4247373D3C48403F3C504F67818E998D8275796C6F596A4464526E6A6562525750545349
4C4E4B544D554E6087A6A6A8858370787C7A7A6A5E564C4844423E514A444653556D828F
999FA5ABB0C1C9D2C4CED3CFDCDBDADEE9E0E3D8E1D8CBAE887C71776F7C8C95726D727E
9888775649464F4B5B5B6F6086818D7788847D72504441454A575F727F7F78675D665B5E
444D466084A8B0ACA38D80797786677B4E5B5158494A444B4549464047443F3F4346494D
423F3F414448453B3A3A3A3C3F403E3C3E3E3944433B4546557B8C5A49463E3F3D394138
3B37393D423E3A383738393835383C3D3B3A3A3C3C3B39383A3B3B3C3B383C38383A3739
3A383A3B3A3C3E3C34464753404D42423B3C373E43403F37343632373634383A3D3E3B39
3937363A3639383C383A42373B3340323B3D37433F59A1BEAB91746D5E523C3F313E3736
3A3E353B39403A3D4C6159474F605C45442E45455F607B946361413738363F383D3D4B4B
76628981A3ADBFA1B89EA599826B49484E515E5C687F6D854D6E473C43362F3F3A414043
3F47415A5B797478737E8994948796A8C3D1DCDBD0BEB0AD9DA3ACB1BCCDD7D9C8C9D1D8
CABFB19075726E6E5E57483E3F423847313D333E
4C504E4947424743494347494C4C444444474344454446424B4543443A423F4743414C48
454B423F47496890857C736E5E5C524A4A4744473D4A41463D4846566A7A8C9594908F8F
886F6C596D524A3B4A404549484447585553583E403B3E4142434442403F40403F3E4245
4243444144404446413E3F3D3C3C3D3E3E3F414243473D4A433B4255778D96847377838A
98908568685F6561625A463A3D40424A43403D3E40403E3C463F3C3F403C3A3C3A393C3A
3B3F3E403C3B3D41413E3D3F40403E39383A3C3D3C3B3B3D3E3D393639383E3D3C3C383C
545A6373746555413F3D3939393A3E41454042433D3B3D3C3D3C3C3C39383A3E3B3A3A3B
3B3B3E42423B3B3E3C3A373435393B3B3A35373F44413D3C3D3F40404849454F57544241
3F3B3A483B3E3A3B3B3B37414957695E7867735456434C403B41423C373A3E3D3A3A3E38
3E35383A3D413D4754534D46403F3B38383C3C3A33393C3B3836383D3B3D3A3D3E3B3C37
403D3C3D3B36363935383B3C393736363B3D3A3C433E383C373D3A363B403E3D3B3C3E3E
3D3C3C3D3B3A393A3B3C3D3C3D42403C3F3E3B3B3F3B3A3D3F3C3A3A3C393C3C3F413B3A
43413F3D3C3B3836373A374041393D3D3F41403F36403A41403E4244444A4838403D4135
4039434442453E4A4E6D7186868A8168604D4949494746523F574E4B444039413A43443D
413F3F47435954718D8F946A6E4D514945505F524A47474A453B414649464C5B5E7A8D9B
A7AEB3B1B2BDBCC2B1B5AAA4B2B9C1CED9CEDFE2D8D8CDC0C7C3B9BDB2ACC3BDAC8A8A7E
847B757177849A9FA4B1B4C0CCDBCDBF9B957A826474697494A6B0C7D5D0C5ACA695966C
633C4B4D5C665E565751473F444B43443F3C4741525C7B9D99A98B8858483C3A3B3D4042
4745413C3A3B3B37403D3B3B3D3E3F3E3B3F3E3E3B4057605A7A5257494841383A353C36
403C3A3E3C393A3A3839393637383A3B3B3A3A3B3B3C38373A3B3B3D3D393C37373A373A
3731373E3A38393542507F5E6F43513B363B393C3B3739363A3B3235383A35383B3C3B38
393A3A3B393A39383534373338323A363C3C333E4C89C2D6AB745B405641473242314034
37423941363E3D4165685C483E403E333F42577AA39F9465563E3A3139403140413D514F
728187939BAA97A699A2858B615F51545960726C7E73686A5E5348403E45525C5B5C5F61
646B7F8FACB8BFB9AFA6939887909BC0D7D6D5CFBFA5928E99A6BAB8AFB2B6BCB4AAA990
8B6C694C48413F3D3A3B3E3A3D35424147404243
464A454648474D474541454646453F42474B4446494B504A494140453D47464D44454B46
3D3E3F3E4640495E504B45424848423F42413E4044424738423A413C424B565D5F62666B
746B75728473544144434C4B454247596A6D805F59473939424343424140404142404548
45454540444243423E40403A3B3D3F3F3E3E40424545383F3D3A446992AABDB6A1918D8D
8B7D7660686265554D443C3D403E3B3E403B393C3D3C3D42413D3A3B3E3E3D3C393A3F3A
3C4542433E3E3F413F3C3D413E3E3B37383D3F3E3E3C3A3B3E3E3C383A373C3A3B3F3A3D
4E59595951423D383D3F413F3B383636413F40403D3F413B41413F3D3C3D3B393C3C3B3B
3E403F3B3B383E423C373633363A3B3A3934343D4343413E3B3D4248444149404A393E3B
42373C3A3C333C3D424545545D6B7D6D685B5C483A39403D3E46443A373A3D3E383D3F35
3A34373A394D53626F5F4A3F3A3B3937373A3937373C3F3D38373B3F3B3E393D3D3A3D38
3E3C3C3D3D3B39383B3D3F4040403F3E3B3C3E41423D3B3D3A3C39373D3E3C3E3D3D3D3C
3B3B3C3E3C3B3B3D4041403F393D39353A40424645403F43454341403F3B3F3E41443B3B
3C3C3B3A393A3D3F3E3C393A3B3C4041363E40473C46383A3B3A3C3F4043433F42423C41
373E3B3B383744435264717459524536413B3B42434048484246413E3D3C3B403A403C42
595268595E5A4E5F596148484458505B5B636C544A464543423A47443C4B466075868990
98999E9C9DA192907D81767C7E91A5BDCABECECFC8AE937B8488968F9D9EACCDB9C1BEC1
B8ABA9ACACBDCDDDDCE4E7E1E5DED3CABBB1ADAAB5ADAAA5C8D2CCD5DCDFE6D8C6C2A0A4
705E4F49514E4A48546466675C58605A7B739D9EAA95B8B4CDB3A685644D3F3D383A4040
43423E38383B3C3B3A3A393B3D4042433B3A40384160665F4F5D4E8EAC857C4841404843
493E373A39373C3F3B3B3D393B3A39393A393837393A36353A3A393B3E3B3E3A393C383B
3B333538363E46415D776E8C4D5F3D403438353735323735393E3A3A3539363E3A3C3B37
363B3B3839393B393938373E363B383E3C383B497095BEAA7C5E47474A3D363536383E41
3B4B4549333D4C595A4D463F34363D3D627C7EA777854F3942393139403C41506B747476
999BA9A3918886727D6969665C666468686F858192998D9C70643F4D607284848E96A4AA
9AA9B6C5C2BDA99C9274726C8196B5D1D0BDAEA79C8E8C93AAADB49E7C6D686E666A5253
45473D3F433C423C413D453F4451557E63817186
4A4E474B505154494A474D4B4745424957584B4948474B43463E40494249424342424445
404349444C443E48424746483D42424449453E3E3F4243463C43413A3D3E424241403D3E
454851555E674943403D424142433E4144547E696B5A44443F4040403E3D3E3F44424649
464646414542403B393F423C3D4042403D3A3B3D40483F3A3E443E59687B929C927E726F
605A604C4C434B3D3C34343A3934373D3C37363A3A373D47383B3B3B3E423E373A3C4138
3A44403F403E3D3C38373C443C3C3936393F413E3E3B393A3E3F3E3B3B363A373B423C3D
43483D3B3F3B3A3A3B414A4A4744403F3C3C3F3F3E43443C3A3C3D3F4448423A3D3D3B3C
41443E343A363B413C3A3B38393B39383935333B3D4246423B3A424A4F48454140393D3B
3B3F3D4E3A3F3D496060565347465340443D5443433B463D4A4E44383A3E3C3B3A3E3D33
3D3A3D3C485C524E4F3C343B3C3F403F3F403F3B403E3E3D3B3B3D3D3B3E383C3C383D37
39393B3E40413E3B3E3A373B4144403B393941463F3C40403E3C383A3F3B39403F3F3E3B
39393C3F3A39393B3E3E3D3B3F433F393B3C3A3B3D38373B3E3C3A393C383D3B3D403636
3A3D3E3C3837393C3B383B37393F3A3B3C403C433A4D42463F3F4041413C3D453F383D40
4243473F38424A4B384A423E40383C393F393F4640423C41363E33443939383A3A423B4C
62577151504437493E4837404A65616B625758474640404242465558736A848198978581
83838F958F907A725E696A83778695AAB9ADB6ACAB897E65535680708F7A9FABCCC0D8CA
C0B3BABEB5C2C4DACFDFD6DCCBD2C7D2C2C6CCD3DECCB7ACA4B0A8ADB5BCCFC9D9D6CBD5
C69EA78692939E9D9FA7A5A79AA68DA78CA0ADCAAEA07D8A706761494D39373E3B3D4441
3F403D3A3D403F3D3D3E3F3F3F3D3A393D3645405E8C6D47658BA1C4D4BE857659667E7D
795B454238373E423D3D403D3A3836373A3B3A39373934333939373A3F3C403D3C3E393B
393639373A53645A816C78625942513F383934393B393B353B3A353A363E383A383B3A34
353C3D3637373C393B38313F3A334038324B52839AB6B29C6E433D373D363D414A414445
70847C74453F465043434334375C6D5B905E8650573F3A3A35323B3B4455688C919B848A
879E8689635C4E4B4655637162646376838EA39E9E8D885B5B4A48526F858B8A95AAB6BE
C7CEC6C1A79C867F8161786F8C9EBECAB69C88827B75809295807257403F41483B4A3A42
434339424040585F74738078928BADB3C4B5B2AB
4B4A4744464B4B474646464545464748544C46464541414540414546423D404745464848
4745424046444242434545443F4345433F3E40433D3E403F3F3E3F403E3F3A3940413E41
3C414B4B434447433C3D3E3F3E3D3C3B3E3E474F4E4D49404347484442413E39484C433E
40434044454441433E4B3C3C3F3F3E3C433F3C3F4038473846403C5A70828B83735E4D47
3A3E41403C3A3C3F383D403E3D3E3D3A38343A3A3C3E38394035353B3C3D3C363737393A
39373B413C3D3E3E3F3E3E3E393C4042413D3A393C39383B3E3D3F4444394033424E564D
453B3E39373E3C3C3B3C4341434741403F3A3B3636423E4250445158615E3F36373C4040
3D393736383C3F3E3B3A3C3E3B434437383D36373C4138373C3A3D41424E4A3C393A3838
423D393C3E3B455C5F544C3E3E464244393F3E3B3D3A383E3B41423D3A3B3D3C3B3E3F3D
3D40403F433F3E3F3D393739383C3A44443D4445383B3D3C41454540473D403C39404140
3B3B393B37353B36373C3F3C3B3E404037403A3C45454440383A3E3F3F35403637393B3A
3837383A343D413C3B403F393D3E3E3C383433323C38373B3E3C3B3D3C39393B3C3A3A3B
373C3E3A383939373A3C3C39393E41413B3D454443423C3D3A3E3E3936393D3F3738423D
3839343B393A373D3D363A393B36404747403842353937383F3D36363B3B3C3F41434648
484B5143383939423D403F465558504D3E44393D3B3A525A6075798E8D9E9BAB8D8A7978
6D717D89999A9D7B7B6F928990747275737B747F757A777E748B98A39A9F97B3B2C7B8B2
ABA4A1B4C5C8CCCBCDC8D2D2D0C1C0B9D6D5DDCBC299816956534C53575F79A2AAC7BDDD
D6D1CFCBC8D1C9C6BCB1B7B2B2A9A18C775D5D64524B473F494243433B42433C3A414747
3F3B3C3D3A3A3E3E3A384140443D474E46659189B56A7674A3BBD0CBD5BDB7A5A7B2BFBB
B8946D4E443F455242423E3B3B3E3C37363839383A383D393536343A363831393B413F4B
4A45414379958168646D666C41443A38363737373636373836383D3F3A35373C39373536
3A3C3B393742313A36373B3A364B465161688496969A8F6F4B393C44353649767F635A60
88A18A604838353B383D383D475363654E44423C3837343C363F3E3D59818B7A82725558
765D684A393F383F4A6572806F7E838DA7AD9C8F69634F46313E41454C7065737F939BB4
BCC8B29D9375735A6F686A7F869EA8AF9D9581846B6C8386815A4D4A50525D53675A7662
7E6E866F7C8492A3AAB6B4CABAD1CDDBD5D9D2D3
4A4A4745464A4A47484949494848494A494846444446474744444546423E404542454746
43403F4045434343444443413E4041413F3F414441424342424345474045454548454244
3E424847404144404243434443424140413E414442434541464847444344423E3D3D413B
474546414E5258534F49423D41403C3D3D483A403F3C3D454376658F7674665249444245
373F433C383A3F3F373A3B38393D41423C3C3E37394040463E383A3F3D3C3B383838393C
3B393B3F413E3C3D3F3F3C393A3A3B3C3C3D3E3E3C38383B3C39363635363C535F94717C
3F34363638403C3937383E3B3D423E3E3536473F403E4C5C56484C4B5054424040424343
403D3D3D383A3C3C3A393A3C363A3A373938373F333B414C504E504A4042403D3D3C3A3C
3B3A393C3D373B49403B3C35384243473B3E3E3D3D3B3A3B3B3A38373A3D3D3B3B3C3B38
393D3E3D3F3D3D40403E3E403D3F3A3E3C363A383F3D4F49635A63574F42403B383E3B39
3E4137373B383B3C31393E3D3A3A3B3C35404047504C453C393739383B36443E393A3C3C
3A3A3A3B34383B3C3D3E3F3D3F3D3B3A3A3A3A3A403D3C3D3E3D3C3B3B3736383837393C
393B3B39393A3B3A373B3E3E3F403F3B413F433F3E403C3F373C403E3C3C3C3B3B373B39
3C413B3C36383740433F42413E3C3E3E3E3F4147393D3C3A3D3D3C423D3B393B3F43413D
3A3B403D3B4041403B3E3C3C40403D3F303E44565E5F737991949A98A499938C7A746063
6171879899A49A937876746A6D63656F61747288969DAFB2BABECAC8B195A9A5B799A088
8C9092A1AEB5C1C4B7B9B3CFC5D8CAC8C6CBC5C3A28D6E6067666E69665059686C7B8D9F
C8BED3C7D7D0CCC6BFB9B5B9ABAB999265534049474533424050454D464143444143433B
3E3C41454244443C3E3C403D454D66779ACDC7CA967C80AE9EBBD7D6DABBAE9AA1A6A89D
987D624D39384045343A3A3A32373938383A3B3A393A403C3738363C3C3E373D3B465775
8171666C9499847171685753373D3A37353A3F403E3B3A3A37383C3D3A36373C34343539
3D3E3C393A42363C3C3C393D4A6C78898C79767463635C4C3D393A3C36587B8571585151
54695A443D383B40333C3F444440433F3F393A363538383F4249453D495F615244414641
463E3E35303A415C77908E8D817C7C868E856F5D443A373D343644556388939D827E7977
80806D655052404851638888A4A4BCB1A8AA9E9A878B91827462516F6C8C88867C8D89AF
A1C2B0B1A3BAC8C8C5CEC0BFBECBC8D4D8D9D4D0
48494847474948464445464443424446444948434247474448464544413E3F4242454846
413E3F41434343444443413F454442403E3D3C3C3C3D3E3E3E3F4244474E514F4C433D3D
414244413D3E403D3F3F3F3F3F3E3E3D4540403F3B3D4241454542414244434047505468
67766C666A7A75795B5543403B39483441403C3F68627161897B8A7050524A413F3B3636
3F39393A4140403D3E3E3C3836383B3C413F3A323B433A3A36384147443E383339383A3E
3D3A3A3C413D393B40413C373E3C3A3939393A3B3F3A383A3B3B3B3A3A49757BAA897D58
453A3A3A3D423E383B3C4240444E4E523E5D737A5B5346534740453F42473B3A403F3E3D
3B3A3B3D3638393A3B3A3A3A373A393A3934363C4243464D4843463B4138383F3F3A393A
373937383C3A3A424040443E3D4242443C3A3A3B393837343C3735373B3D3E3F41403C38
393C3D3A4040414342403F40393B373839393C393D3E3F4E51574F4C3F36383B3D453F3E
42463E3B3A353B3E494B49423B3C4145424F51524D43403D3C383A383C39443E3A3B3B3B
3A3A3A3B3D3A3A3D3D3A393A3C3B3A39393A39394343413F3E3E3C393E3B39393A393C41
3D3A3839393A3B3E3D3E3D3C3C3F3F3E413D3F3B3C403D413A3D3D3A3B3F414037343535
3B423B363638353C3E393A363B3E3F3B393C3E3B373C3C3837383E4744413C3A3E423B2F
3736373B3B40463F4948413D3E40444B4F5D66787C767E7E82817678726E595252504553
5E758B999C8C936978566D5C6C636F66666D7A8A9AA7A9C8C0D9CDCBA9AC83AC8AA4798D
7D82808790959C98AAA1BAAFD2C4D4C2CFC5D8BCC2A1AD9DAAB2B6BEA59A9097939D779B
8FBCB0BDB8B29DA7A9A0B3B4B29B91635D3B4A4B454D515E5D5746464243576968676356
5E524E4A45525B514F5B6E798DA4C1D1D6D8D9A4A061797B909DA8A4A78A785E57575146
48413C3A3E363B3B343E383435373A3A393B3D3C3C3739373A3F3A3A43483D3938516B85
94877D85A3A09A907F5D453C333538373A3937353434363739393A3B3A38383B39383739
3B3B3835393C3735373A384D99A99D8E7758514F3F3E3A37373939363A5C7360473F3934
323D363235363D3D383E3F44413B3D3834343834343B3C41424C4D423D40403A443F4A39
3835433A555E627A8C9683775D555B61564A433A39353F3743507481ACBBAB966A5D5046
4F45433A4045536D7AAAACC6B9D2C0B19D978D8B8283755E5F5A74749F9097859495AEAC
CEC3CBC0C1C1BEBAB6BABAC7C8CCC3D3D6DBCFCA
4749494948474746494948464444474A464949454345464648464342403F3F4045464746
444344444343434343424140403F3E40434443414042444443434546494C4E4C47403938
4241403F3D3D3E3C3F3F3F3F404040414744464540414544413F3D3D4043423F57566A65
6D5F604C56616A5D593F443944473C434D777C8C99AA8A976E6E5E4A3A414341413D393C
4140443F423C3F3E3B3D3D3C3B3A3B3C393C3C34383A353F3C3B3C3E3E3D3C3B3A393B3F
403C39393D3A383B3F413E3B3C3B3A3A3A3938373E3B3C3D3A3B3E3E3C636795756A4F38
423A3939383B3A355D59574A444540415D728362543D413F3739403B3A3F36343C393838
3837393C3E3D3E3F40413F3E3A3F3B38373B44483D3D393D3B3B433F4337393F3B373838
393C3A3A3E3E3B3D3D3F413F3F424140494141423E40413A3D3B3C3F3F3C3F444846413C
3D3F3E393F4042434240404040413D393A3D3D39453C423C46393D3A4842414440463F44
3D3C3D403D4C6D79847865544B4F585F535A534C41383D3F3E3739363B3A433E43413E3D
3D3E3E3F423E3C3D3D3B38383C3E3F3E3B3837374345443E3D3E3C383E3B3A3B3B3A3D42
413B37383A393B3E42403C3A3B3D40403A373B3B3E433F414644403A393C3C3A3B3D3F3F
4244403B3B3B373D413E403B393A403D3A3F3C37373A3A3938393F4643433F3B3F443D30
3A3A393E393B4843433E3B3E45494B4E575D5D635F5455534A4D42493E463E43444C4E67
74838787827A6464576260645C5A505F57797584948B9B97B5B2BCAAA9899E819282997F
786B575A6C82979CA0B7B1D3BCDECCD5C3C7BACEB0C6BEC4BEB9CDBDBDA5B3ADBBA8AE81
A1818F7B79625D555D737F998E8A6C7E6C8D879790A8ACC29F8C605F5372A2C3CACAC5BC
B9A99E938D9DA89CA9B8C6CBD3DDE5E6E4D495845659484A474C504C5042443A3C40403D
403D3B3D40343A3B3D473E3A38383C3C39393B383E3C3F3B40505A6683725143435E7180
8997A6B5CCC7C2AE7A4F3E3A3F383B3F433D363436393B3B3A3939393939393A38363434
383B3E3F38393B363B414466909681664B36393F383A3B3B3A3A393945484A3A333A3431
3537343838373D3A413E383A37363B3536393F3A393F3C3D3D4143403B38353437323535
403D68577B7B6F6F6A67554F3A35383C393A3B343A44467C688589AE97976F544846353A
353A3B3F5456869FC0C6B99EB19D9A735452585B535156626F8F7DA69CBFA0B0A6AD9EBE
AEC9B8BFBDAFA5A8ADB6C4D8D1BCC4A5C099A08B
4849494A494746464A4947454345484B474646474746494E464542403F40414046444345
4748464543434241414141423E3D3E42474947433D3F4141403F3E3E4341404141413F3C
41403E3E3F3F3E3F3E3E3E3F40414344403E41413C3D413F3E3C3B3E4142403E3E464652
404A423E404E444D3C3F3C3B3F3E44528A9EAE9DA1878A615344423E4546413D3E3D3F45
4A54574041454E444141403F3C3A3A3B3F3F413B3A3837463D3A37383D403E3B3B3A3C40
403C39393A3B3B3D3E3F3F3E373738393B3C3C3D3A3B414139393C3A4C495E504F3C413E
3B393A3B37383F3D3B3A3D37363D3E42505F4D43313E393D393C3F38373C3C3D3C3A3A3C
3C3B3D42494745444544423F39393938363B464D4448403F3F3A3C3C3D383B3C36383E3E
3C3F3C3B3F3D35333B3B39393D41403B423A393A383D403A413F4043423D3D404544413F
4043413C383B3E40404143444343413C3C403E3B443D443A41343E413D3D3D423C474758
66656A716D7B999F968368554F52585C514C3F3E3C3A3F3B41383D383D3E46434C484341
414344443E3E3E3D3E41403C3E4245423C383A3D4143423D3B3D3C383737383A3937383B
443C38393938393C403E3D3E3F3F3D3C3A363A3A3D423E404041403E3F3F3C3636363639
3C3B3A373D3D353739383A353D35403D3A4340413B3B3C3E3F414342373D3E3C3F444139
3839383E3A39444038363A454A48444140413E413F3A3E40474146373E3543434B55576D
73777066786359414A4049484D45494A636F736F6E75728D87A0949085967E886A83585E
47484E677D899AA1B9B8D1B1C7A9BEB3B7A8B8A6BEB1C8BEBDBCBBBAA6A5A5A6A0B6A0B0
8392626256686E848E8C9791AD9A9E86A8A3C1BDD1D1E6D8E0AB9886A4C6DDE0DFE0E1E3
D6CFCECDCCD9DDCEC5CFD4D6DBE6E7E2DCC79B866461554B4745423F4138413D41443F3C
3B3B3B42443C42413F3F3D3F3934373A383B403D413D41475F8398A7A17243434E687C92
A7B5C3C9CFC0B08D573B3A373D363437393A3B3D3F3E3D3B3A3A3938393A3A393E3C3836
373839393E3B3B37404040585C6965574537363835393D3E3C3A393B3F383C3A3C403A3D
393A3A403D393F3D3A3A383833353E373A3D443F3D4039373D3634383B383331313B4066
596A817F686451493F3F393F3E3C353236393C414E669D8895738069484E3D34363C3542
48666D86828B99ACA89E6E665F5B4F4041414B5F7E91989CB1B4C4B1D5C5D0C7C9AFBBA4
B49AAC9D9BA2A7A9B4C0C1B5998C7A6C5D564C47
4B49494B4A48464647454343434547484C4746494845474D444543414143434144424244
46474543424242414041424443414043474844404547494947454444433D3B3C3E424440
41403E3E413F3E423F3E3E3E3F4144454844464642444847403D3D404342404044424A3D
44404D4A4F4C503E4739443C3F514E768D99856C6C564D463C42393B46433D3E44423E3F
5B5D5E4A545A69624B4743403B37383B3B3A4347474439373739383B43443B343B3A3C3F
3E3A393B3D3E3F3F3F3E3E3E3B3C3B3A393A3D3F3F3C41413B424B494E4C3C403F3D393D
3D3F40413A3841403B3C423C3C4242463D3E3C34493E423D3B3C3C3837393C3E3B3A3C3F
3E3B3F464845413E3D3D3B3A39354854524B48534A4F4442443E3E3F36383B38373F4647
3D3D37353A3C393A44443C3C3F3F3F36403A383A3D424543423E3C3F43413C373C3D3C3C
3F444340393C3E3D3B3D3F403E3D403C3D403C3C373B3A403A3E3F473B454E5E5B68677D
90979A9C9184817970614F4643413F3E3F3B363C3C393D373C39494B5252545048433E3D
404242403E40403F3F42413D3D3F403D3A3A3E423E40403D3B3B3B3A38393C3F3C38383A
413E3A3939383839403D3B3E403E3D3C3F3A3C39393E3B3E3F403E3B3C3E3D393C37333D
4440413E4B4B413F3E3C3F393B343E3D39403E3A3C383A3E4042403B353B3E3C3B3E3D39
3738363C3E3A3A384945474C474242433D3C3B3E3E3D3F43403B403E44434945444A444F
4F55514B4B4442393E3B363737413A4F4A5C4A4D6066867F8E7A8171765D665042414943
49596D858B8694A19AA48B997F94828D8A8A71867A9D99A8AEA1AC98A798AEACBABACF9F
B6929D8A8791B6BEC4C8B1B0A7B6AEC4B7D4CCD4DCD2D2D7E3CDB7A9B7D4DBD2D7DFE2E6
D9D2C9BFB9BAB7ACC3CED2D8DBE5E1DBDEDCCAD8BFC2A292887B6C6255423F373A403E42
3F3C373E3D3C4040444245414C403F454A5B6E72706A707FA0BEBFB99D7454637796AABD
AC9B91858274694D443E443E393E383D3D3F403D3937383B393A3A39393B3A383637383A
3C3C3C3C403A333948464A4B555E5C4F413938363A39393C3D3A38373434393B3C3B3839
3639383D3B353B3B33393B383139473E3939403E3D3E36343835383C3A34384149396962
716071684C4938373336323A3A3B3235495565808E979997695142493A393D37314E7187
9CA1A9927B71585E514D3D3F3D363D404E7A9DA9B9BEC3C0B4BEABD1B7E0CACCC0B6A8BC
9BA2939298999A9893857C6A554B4739363D4242
4E4A484B4B494646484747494C4D4C4A4B49484848474647454747444345454343454748
46444444404142424242434543413F4145474643404142413F3F4041433E3E3E3C3F4441
42413D3C3F3D3D454644434242444749403C3E3F3C3E403D413E3D3F403E3F41454A4145
434E4A4D4545443F3C403D3D42464547574E5146444439403C363F3A403E3A3D44423E40
403B433B453F5056444140403E3B3D41535B72756A634C363D3F3A373D403C3A3B3A3C3D
3B393A3E403F3E3F4142403E3F4142403B38393B403A3F4547535A5241442E3B41363F3B
3B3D3D403A353B3634373F3B3A3F3D3F4146333A3D3F3D453B3B3B3D3B3837373B3A3C3E
3B363B453F3C3938393C3E3F4B45636F695F4F5A4849403E3D393E3D3B3D3B393E434546
3C3C3A3E464746493E413B3B3D3C3F383A3A36363B3D3C3D3F3C3A3B40433E38383A3A3A
3C4244423C40403B37393B3C3F3C423F3D3B34373D384435473C494347515563595D5264
6D798283705E5D564F4741403F3B38373A393A413C394140514D5D58564E47403E3B393B
3F413F3C3F3F4042413E3D3E3F3E3D3F434544423F3E3E3E3C39393C3C3E4143403B3A3D
3C3D3D3A383838373F3B3A3D403E3C3C3E3B3F3C3A3C383B484640393637373537353547
4B3E3C3C3D403A3A3A3C413D373A3A3D3A4049383D37383B3A3C3C373A3C3D3D3C3C3A38
3A3D3E3D43413C47524642433D3B40423D3A3A3C3C3936383F3E3D4A464D453E3C423A41
3E45454244433E37363F3B4539434B4E51494649525D676D5B564A4245413E433846415D
6F859CAEA68E837C716567566D5F69666861584C62697C88817B7C809199A7B3C4D1BBB9
ABC1B8B8B7BDC4CDCDC4BCB4B5BED2C7D5CCD5CDCEC3C9C5D7BBB4ADC3D1CEC2C3CCD1D5
D0C9B7A49A928C8B85949FB0BBD2DBE2DDD4D4CECFC5C2BAB8B0A493704E453F3F423C40
3C3E3C464457626A7B7D8472685E677D92AFCAD0B8BDC7CBD2D5C4B6B59A7F828492918E
765A534948444336393A3E41364B4B657A6C56433A393C3F373A3C3A393B3A383A3B3D3D
3D3B3938383F425A6D646E594347473E383A3B3A413C393C3D3A37373B3C393838373936
363A363838323536373B3A3634434D3A393439393B3C353634373E4039323C4D4742495A
435946484140363937383137343B3C527F9AA7B8B19C80583D3339353A3439384C8AB9CB
B69B8F585042373C39393D3837374B539EBECED0CFAD9A8A7281A6BFD4D3D2C5BDAAC0AD
B88B8F7E787274766A4D4E4A43444C4B4C5E605D
504A484A4C494747434345494D4E494442454645474C4B46464A4B4745464644444A4F4D
474344473E404344434344454C48424040413F3C3F3F3E3C3C3D40423C3A3F403B3E4646
44433C393C3A3C4743413F3D3D3E4042454246494746443E403C3B3C3B393B4044474543
504E4640403E4B3D444142413D403A3D3E3C3739433D403B3E3F36363C3F3E40423D3C43
4339403A4A40443E42414244413B393B3B45616D727C643D3C43403B3E3E3A3B3B3A3B3C
39373B40403D3B3E444744403A404646403B393A3835404F555D57413C3340423D3D3F4A
3A3D3C44423D4238393D45403D3E393A3D4B443E42383C3F45413E413F39393A3E3D3E3F
3A343B473C3B3A3C40464C506B5D7064524A373F3C3B3A3E3A39403946453D3B43433D3E
3A4149565E564B493E4540403D393E3941433F3C413E393B3A3D3E3C3D42433F3B3D3C39
3B4043433A3E3E39373A3E3F37343E40403F383F42403C393F454742444640493F463B50
41526B6F4E3D4944423F3D3D3B393B3F423C394040424E4E51495348474444443C3A3B40
4648443F3A373B44443D3E454744454C55554C43403E3E403D38383D3C3D40423E39383C
373C3E3A3839393738373C4447413935373841403F3E3839393C3C3B3B3D3C39363C475E
5A403C3E3A403B3A3A3A3F3B3844373B3B48654E413C3C3C383B3E3B3A393A3E41424140
3A42464147494C664737343B3D3D3D393A373A3E40403E403E374846544A504338434048
42433F393F4144383C403E463D4B485044403B4743404940463F463C4134404642596B88
B1B6B2B1A7907A64514F434A4D50474D4A554751576B6D826D6771749692A1A9BCBBB19A
B1B3BFAFB9AFBBC4CAC9B9BDBDC6C4C3BDC6C3C0BBC4C8D1C1B6B1C3CCD2D4CECACFD5D7
D8D8CDBFB5A394938B8E8685849DB3C8D2C9B8AF9C9A959D97989BA08B70665D6066656F
7074727C7CA6BCC4D0CED5BAB1ABB9CFD9E3E7DED4D9E1DDDBDBCBC0A489747C7A807974
5C464B403B3B3E374642455B537480B2B8986C4E43413E39363A3D3A393B3A373B3B3B3B
3B3B3C3D355163858D6F724A3C40433D3A3E3C373E3A393B3A37383C4042393835323936
393D35363A363737383A3A3F4B6366453C3335373A3B35383734353A373338423A393B38
39344232343832393638333C40596C83A6B5ACA58D6145343D373E39363A3C4784C1C4BA
71623F37343D3B3F3C3A3B3B456F96A9D3D1C1B9A4614C4C5986A0CCCAD0B7C09BA597B8
9290676E7B8EA09A89706D597C75A687B3A1B59B
4E4C4A4A4B4B4947454A4C4844454646434647464344484C4D4A46444445444342454747
454241414140414343404246414040414242403E3E3E3F403F3D3B3B3F4044444042423A
3B3E4345413C3D423E3F403F3C3D40443D40423F3D3E4143383E454043463D4143423F3E
42464138413E3E3E3D3B3E433C3B3B3E424443413E3F41434444434242433F3D3F3B3A43
3F3A3D3C3F3C37463A403F443C403C3F3B3D424740455145454A47403C3839403B40383B
413D3A37383C3642463A4B4D4C5C67734C3F37433E3745465E544D3C3B39353B393A443E
3B3F3D3F4044473B394340403D3B413B3A3F353F4149473D474242413D37353E3439383B
3E38373F323841424B524F5A50544F46403C3A40403D3C3F36423F3A3A394440425C5979
666D707F6D4E4D434451463E42403E3D3A433B41393D383F435557494346474845474846
403B3A3C363F403E393D3E3F3844484B534B3D3D393E43363A4036484844493F373E4242
3D44566641333D413C394D43323A3A3B3A3B3D3F40424548423C37383D403D39423E463B
454A433B393F3E3A3D3F3D3E42464C4D463E414A3C4244403D3D3E3C413B3C3F3C3B3D3C
3B403D3A3E3F3C3A38393C3C3B393A3C3D3B3E3A393D3A3E3A3B4140383A403C544D5755
3C384038373D3F3D3D404140403A37393A3A3B3E45453C453D3B393939393A3B3C3B3A3A
4844473E3C423D3F3C3F353A3D343537373F363A393646474144484B48424245373A4045
443F3D3E393A393A41484844443C3E423D3B3D3C3F3D3F3D36383D3C34455363779993A9
97978E8C80695844443E41454C473B47465151656C6F848B8E7D7C7E92A9AAA3A19F9797
95A0969E8FA8AEC2C8C0ACA4ADBABFC5C0C3BFBCC7D2DCCCC4AEC1C5C7D9CEC9BCBFCBD8
D1D0C4B287967D9CA5C7BFAA94899592AFD7D4CEB7B8B6C5BCC7C7BCAFA094928BA5BACD
C9C7C3D1D3DDE6E1E1E7E2EBD8D6DDE2E5EAE6DECFDBD7DED3D5CAB4908E798070786461
5C5051454F52635F817EAA89A49EB6BFB4926D646E6D66665C5E4D413E3F3F423C47516A
68784643486CA4B47A5E484140323D333A3A3D393A39403F3A38353C39353C373F3B333D
39413B3B3E39363D3F555F5A564E423C3932393631373538373B3B3837393B3A373A3933
3033373931353E33333745517D8F918A8679624E453C3F33353A383A313D3C75A1A59A61
484235313A3E3A3A40465A798DBBBBD0C5A680805845445B8A8ABCC4CCBDB89DA9858A8C
99949A9FA5A6A4A28F7A828F95BEBDC7B6D9CBCA
4B4A484849484745454A4B47444546454245484947454546444342434548494843444544
434243443E3C3D4144413F3E413F3D3C3D3E3E3D414242414141403E393A3E3F3C3E3F39
35373B3E3D3B3E433E40403F3D3D40423A3B4045443F3D403C40453F42453D403B3C3D3E
4245444139393C40403C3A3B3B3E41413F3D3E403C3C3B3B3B3D3E3E44433E3C3E3B3A42
3D3B3D393C3E3A443C403E423B403D413B3B3E443E3B423B373D3D404846404240443C3B
3D38383833535165647B7059474947513938323B3B3B45404B3E443C3638363839414F4A
423D3739383D453B3D433B38393D443E393E39413E44424039373E46463B383E3D3F3A39
3D3D3F46424145434A4B41443B413B413F43393D3D4440423E47485153554E4F6B78A4B3
B1A795825F4448525B675647413B3B3E3C3A4032433742424754564D494B515A4E4E4D48
424040413A3C453F423F4E5761655D56574B3B393E393E3A40433846433A3E3E3E454648
3D3637483D3F443E41373D3F38383A3B3E3E3F3F3F4041413B3B3B3D4042413F3A363D35
3F44403A3D3D3C3F464A453D40424445413E3E4043454645403E3F43443B3B3E3E3F3F3C
3740424144423C3A3B3A39393A3C3E403E3D43403E3E393C3E3D3D3B3C444B4A4A434949
3C3A3E363837383A3D4244413B37363A3B3A393A383D38413A383B3F393A3B3B3B3B3A3A
413F433C3B413C3D363A33373C393E4143423E41403D4345514B4644424040423A393A3D
3C39393C3E3B3B3D4041403F3B383D424140403D363F3F3A3C3F404449689E8BA188857A
6D615454524A433B403A3C3C444C474B43544C69697F94A3B59B9A88A19C9E87817A8875
8D81898896A99DA19F9D9999A1ABAEB5AAB5B3BBC2C9C5BDA6A7ADBEC0D0CFD2CDD2D4DD
DCD5CEBDA7AB9DB4C6E2E9E0D1BDAFA2B5D6DAE2D1D9DBE1E1E2D4BCAB9F9A9EACBDC8D8
D6D6D1DCD2E1DFECDEEDDFE7E2DEE0E1E0DDD0BFA4B2B4BAB0AEA5929B917D6F605E5C61
68888D7F7893A5B2ADCACED0A09878796E665D647885888B958B614E4B4C666F8E96B0A4
BFB99D78727B9C88664642383C353F3B3B3C3C3A383A403B383B3739323E363F34363E3E
3746593242353E5B5B5F5647423E393935353138393B49453C3D3B3635393B3B373B3D3B
383835322D372E363D597B8B9388715A4C423C39303F323F373440466B705A7462624E3B
33383C3E39303A527B88B2AACBA6AB857256414A3844587F8AA6B5CEB1A78981637289A7
BCC9B0A48D8A7C746A657B92B0C4D2BAC4C3CCC3
4F4E4C4C4C4C4A4945484A48454545454345474948464442474644444444434243434241
41424446423E3D424746424046433F3E3E404142424444403F42423F3D3C3F3F3C3E403B
3F3E3F41403E4045404141403F3F40403E3C414C4C43404444464741444740423D3C3E3F
3F3D3D3F3B3B3E4445413D3C404344423D393738414140403F4040403E3F3E40413D3839
393C3F3D40433C3D3C3F3B413B3E3A3D423F383C3831373A3E4645495552484954564B45
40383A3B4F7B878773806C56443E3540353D3C433E3F3E363B31454548494037343F5050
4C453F3F383D473B393C3737393C3D34383B3E464041383C4138394044414B5445474239
393B37353F3C3D3A41433F413C40373D3A3F373C3C483D40454F546A8570704B6C668A8F
85786A564440506C757B6451453E3C3E3B403A3D393E373D3840423F3E3D434F484A4740
3E41423F4046485B596972857970594947423A3B4C3E3F3D3F42415259453E3A393D3C40
3F3E393F393B3F3B413C3B40403B3C3C3D3C3C3C3C3B3A3936383A3C3D3E3F404440433D
44474542423E3A3A4044423D40403F3D3E3E3C383E3E3F403C383C445748403E3B3A3934
4146443F403D39393A3D3F3D3B3938373D373A3A3F433C3C434B4E4E4E4A433E3E393B3F
3F4140394139383C3C3F403A423D3A3A3B3D40433D413B423D3939393A3A3B3B3B3B3A3A
3A3A3E39393E3B3B3D413B3839383B3B3F3F44484A4E5662574B403D3E3D3C3C3C393739
3938383A3F3C3C403F3B393B3B3A3D3E3E403F39333D3C3B413B37426996999D68735252
453D3A3A3F403A3A434043424B5C5C54536B5F79688290A293846E6E69706A5D5C65586C
6080748A95AA97958F8E929295898D95A7B1A29C9D98A994A0A0B8C8D5DADADAD8DDD9DF
DFDED9DCD5DCD3E2E3E4E8E3E3E1D5D4D7DACBD1C9DBDCD6E1E6DFD4CEC9C6C8BEC3C3CC
CACBC4CAD0CFE4D4EAD3E2D4DEDFDFD5BFA383665C5961515951655D7C807788747E737C
93959674939EB7AEB2A9BD846C55505D6A76808CA1B5C3CDD1CDA9B595B8A4BDC7D1DDD9
DEDDC4A07372806E6659585363564E453E403B3939363C3B3C3F3C3F3E3B3B383F444E66
576048383C4866735E5543373637393D32413C4A4236473C3E3D393535393C3D36373636
373836333A353740558995A788694D3F3733353C36383D30424569959B75594340383A35
3A39383E4C607E9BB0BB9AAF76804F3E483937463E506388AABBC2AC9E6A615A6688B6B0
CAAA95867D8178787C7E90A3A3BEAFBFA4C0AEB8
494848474646454445474948464545454645444445464544434343434343424242414140
4042444645403F4346464444403E3A3838393B3D4043413C3B3F403D434041413C3D3F3B
403D3D3E3D3B3B3D4342424242414140423F404749454448444745414546414047434344
423D3C3E423E3D40424141423D3C3C3F42423F3C3F41444443403E3C413F3B3A3C3D3D3E
3B3B3C3D3F3F3B3A393B38413C3F393B3B413C41453D3D3F414B474753524D555E5D504A
453E403E4751675A51403B3A3E3F3C4742494A535651423B433E565456544B433E45535B
60615F5644444B373C39373B3E3E3F404C403D413D41363E403B3A3C44475A5E4746453D
3F46413E3C3C40393C363737373A3D3A423D434B545A47484A4C4D5B655A55433F4F4952
4E4844403E3C4252585B47433F413D3B3A3C473D473E40433B403F3D3F3D3B3F3E413F39
3B444641514C595A706C78775B54453F45443C3B3E3840403A393945483D3C3B3D3F3839
38413E3F3C393933343A3F40403F3B3A3C3B3B3C3C3C3B3A3A393939393B3D3E3E3A3937
3C40403E39424240423E3A3F4041403D3D403D383C3F43423F3F43494C3F393A3B404747
5D584A3F3E3E3E42363C3F3D3A3A3C3D3E3D433D383B404D535E5D534C413A3C43413F40
43423D393D34373E3D40433E3E3B373536393D4038403D42433E40413B3B3B3B3B3B3A3A
3A3B3B37373A3A393A3F3D3837393B3B415363655B504D4D4A413A3B3D3C38363C39393C
3E3C3A3A3B3C3E3F3E3B3B3B3E3D3B37373C3D383B383B413E3C506D96918C58523F4D3C
4041443B3A3D383F47464E55607172646677686A4F59606C544C493F463E504650585F6B
748A8D9E9AAB8B7E73727775857F9C9BA89B8D899C9B9B9B9BAEBCCED2D0D6D4D2D4CCD1
C8D3D0DBDAE4DCE1E6D5D8D5DBE3D7E0CFC9C6B8C2BFD2CBDADCD6D2D5D3CBC6B6BCC1D3
D6DCD5D7C3CEC2DAC6D1C5C1C4D0D4CAAA876A4D4F465244595E858AABA6B4B2B1958979
7365516C6F9398A296A87B955576769E9DACB6BCC5CED8E3E3E1E4CFECC4E4C9C9BDD0BC
CEACBEA7AFB3B2B6A9A0807C61544E3F433F4340403B3D393B3F3C3F40383E404F78AF78
7458323F38556F58463F38383B3B3C3F566869684E353C363B393635373A3C3B36343232
3538373637363F4B8B91AD8E75523C373838363B413C384F65827CA26F563D3C2F3D353A
3A373B568AB2B7A8A5798D5D6C4F49393D3E476268819DBAC4B58F735A5260748BA9AABD
B0B19FB9B9B8A69F9F97989CABB3B3ACAAA6A5AA
4E4E4D4C4B4A4A4A45464849484645454543424245474645424243434242424241414141
424343433F3E404343403F41434341403F40414240413F3B3A3E3F3D423D3E3F3B3B3D3B
434041444542424344444343434342413D3D3D3D3F4143433E44413F43433F3C423C3A3E
413E3D3E423C393A3C3C3E424341404041403D394143464543403E3D403F3F4042444441
443D393E3E393A3D3A3A37423F444247464E433E403B39373F464244535859634F4C4344
4341443F45303A3A493D393F3A3F4049474A494F5A5544404640504A4B464444413F4656
5D6D746B5C65705F4D3F3A3E3F414E6286674B433D443C45474E58585B545C4C43373F48
4A453A3F4B45443B3F39403C3837493F56424C4D585947473E40474D424544393B3C443D
3D3E40494A423F3F464B3C403B3D373339403C3F323F374A3F4340404C55534F5453493D
3C4345403D433B48414F43413E3D3B414D4F47423F41494843423F403C3D423F41443C3A
404135323C41464045444E4B4C4E43474040403F3F3F3F3E3D3B393B3E3F3D3B413F393A
3D4344414E5A5144433934433D41423F3D3E3D3A353E423C393E403E46403F403B3C4244
5B5242393D3F3F4244423D383A424848403E45434147506152585245403D3D443A3C3B3A
3D3B393B38353A3E3A3C3F3C35373A3A3A3A3938313C3A3B403C41443C3C3C3B3B3A3A3A
3F403B3736383B39373A3B3431373C3E60716C604C3D3F363D39393C3E3C38373D39393C
3E3D3C3D373F423D3B3E3E3A393B3833363B3C3B42343B433A48728E796B504339413D34
3A383A363A3F41535651555E6368675A5B5C5446413F4A4A3F393C3A494A6869877D9172
8D7582806478676C75858F90938C8C897A837A8D9DA29DA8A9B7C3CBCABDB9AA9E9896A0
B5BECDBDD4C8D5CBD5C8D4D7DCDECED3BFD1C3D6BFC9BBC1B5AFA3A2B1BEBFBEC7CBD2E5
E4E5D8D3D2C9D9C2D9B0BCA3B2C4D0D5CAC0BCAA9FA997B69CC8C1D2DBD9D6E0CBC7B8B2
AD98A7A7BBADC4CAC094B277936D93ABC6CFD6DBDDD8D8DFE4EAE8E9D3DDBFBA99946C80
6491A9C5D2CFC0BAA182504A44444D4E5D575C574341443F3D3F38383D3A4B8096D7B0A0
5E314138394445363C383A3F3E39383952565E50382F333B383636373939373636353639
3A393634393A3D6271A0786F44323033393A353C39476D95AD887C5E3D3D3641353D3735
36384E7DACB89973554A55614C5E39423A4B58798392AAB0A7817165647796A4B3B6C5BE
D8C8D4D6C9C0A8A2A7A5A7A7A1A9A2B0A9B2ADBD
48484947464445454646474A4A4745464241424447474543424343424141414242424242
434341403E40454947403E3F3C3D3E3D3C3C3D3E4341403E3E3E3F40403C3E413F3F4241
3D3A3A3C3C39383942434342424142423C3F403F3F424342404843434644423F3F3B383B
3F403E3D413D3C3E3E3D3D3F3C3F41413F3F4143454544413E3D3F42393D464C4C4C473F
4742444F4D41413F3D3D3C48464C4C5561634F413F3F4241474542465257555544413C40
403F433C4038373D3C43393F3D3E3B4043443F413F413B3B3C353D38403636393C3C455E
6A7E81746B77857A57443E3F3D3D49628A6C4B443E453F45566173777F7A8B798557433E
3B3C496B84746B5F62514F3C4139423A513D413D484B3E41385075829B8F8B6457534E47
403C3D44413C3E3A3B453B43383D3D413F45474F516F748F9E9A897E858982796E665542
393939363A3C4438413B423A3B3C3E464F50494340413F3E42443D38393D4037393F3A3C
39464B4A4F5161657D65635B544C393D3F403F3E3C3B3D3E3938393D41413C38393D363D
4554595363614B3A3C3634443A3E42403D3C3B3B3F494B434046463E3C3B41453F3B3E3E
3E3B34353C3C3A3D49443D3D4956575055484645474742474143403C3F42403E3E414342
414144483B3F3F3B37373635383B3D3C3B3B3B39373D37394944413A3D3D3C3B3A3A3B3B
41423B3837383E3B38383F3A34393E425E624C423B3A483F3D3B3A3D3E3C3B3C3D393637
393A3C403842433B383F3E37393C3A37393938393A354556596A7669594E3D3F3E463A3A
393A404C58544E5A57514C51514C4B454842463F4D484D4341434965758E9EA4AD998361
5B55565F7589848A8D90837D896D7E56796782818B93A0AABBB4BEB59C8D8A8382869AAC
B8CDBFCFBED5C7CDD6D0D9DDDFE1DADAD1C8D2A8B7828D7C83848694B3CBD4D6D1CCCAD8
D8DED6D2D2DCCCDDCAC9ADABC3D1D6DDDAD5D1BAC7B8C7B4CFCEE0D6E3DCEFE0E6D6E7DD
D3D8C4D3C9DBCBD4B5A7829581889DBDD0D3D5DAE0DDDCE2DDE5E5D5CD9F9B744C544C50
5E86AEB8AC937E64706D788C87947BA696B49595645047433E3D455C7074A8A6CFBABE7D
6E626155473F3747403C3D3E393537393F39423A333D414C393737393936343433333538
3837383B3E403D455951563F3A38403E3E3D3A4D5472A0BB805E49383B36343236323C33
374773A2A5815D4C3D44514A463E39393F5358768491A79D6F555F77778F9AA0A3C5C8DA
C7D8CDCBC5C0B8BDB9A89A8C9290A09BAD959B9C
4B4C4D4B494848494745474B4B48464743424243444544443D3E40404143464945444343
4342403E4644454848434040404142424142434545403F41413D3E42413C3F4442424545
423F3E3F3D3A3B3D3F40413F3E3E40434243444544434548434C45444541434045454442
42444443403F4144423E3C3E404142403D3C3D4040403E3A37363A3D3C3D434441454843
404349555146453D3F4245534E4E494F46473C3A3C3B3F3D443E3D404243413A40414042
3D3A413D383E413D3438363C3D3E38393F403B3B373A3A3A3A373A393D36383D48525E7A
828B7B665B5A5D564B3F403F3D3B39454B45363D3A3F3F434D4D56575D55746C6E4A4543
3F40445C6D656C728478775D3F3C38424A4A454B3E4945535A88C0D3D0C1AD9571957B83
5F4745433D43443D373F36433D4F5D6AA491AF86AF95A6A3BCAE947E756959514945403C
3D414648393E3A3F363C37393A3D434A4C483F3840423E444F493D3A393B3D3A40454148
4E6A878A7E6D7A7D6B52504F47423A3B3C3E3F3D3B3B3F44414142434342403E3D463D46
51686D624F463B383D3C3B3F3A3C3F42413E3C3C3C42423C3C40403B3C393D413D3A3B3A
3538393B3F3E40484042434855615E544C454745413C383F403C3A393A3F403A3D3D3E3C
37383D3F414942373B3E3A393A3B3A35333538393D4A4F566B5E4E3D3E3D3C3B3A3A3B3B
3C4039393A3B423F3B3D4F524B4945473B3D3A43484340363F3A383B3E3D3C3C3D393738
38373B3F393F3F39383C3C373D403D3B3B37363D394D62727E7C62444A3E3F2F413E414C
566261636759494442433C40433E4242414145474843403F51507582A39CA4987967503F
44566172949C93887C745C5B6365656465758492909990A1909884837C72777D8078878C
9EA0B3AEC8BEC5C3DADCD9D9D3D0D0C3B3B6A8AB8F8E8F9698A3ADBBCED6D2CFD2C4B9C5
C7D0C6BDC6C3C4B5C4AEA4A4CED9D4D2C5B2A48270766D9699D9CFD5D5D5E0DBD3D1D6CB
CCCCC8BFCED3D7D5D2B7C0ABB69CA7B4BEC1BEBEC5C8C6C7BFBDB0B48B8365634F738199
93A0918A637395A7CBCDC8C6D0BBB692AF868B716A504546506992C1C4D3C6D4B6BA8B9E
737F58593B343040413A393A36393F3E3C39393B38393F3C3A3737383736383C3C3C3E3E
3A383C423B323B33383634383532342F38424B73A69EB08556403B3D383B30453140404C
4C6694AA8C5C3E36363B40353B3E415066716C777D80846B513A594C6F5D8A93B6C4C2AD
A0949E998C8F9CAC9E806E5A727C708B74795D69
494A4B49474546474745474C4C494647484542403F424547444443413F3F414348464342
42423F3D4B443E3F41403F3F3F4040403F404346443E3D42413B3B423F3A3D413F3D3F3F
3D3B3A3C3C3C40453C3E3E3D3B3B3F4247424145423E434D4049403D3D383C3A3A40413D
3A3D41413C3C3F413F39383A3E3C393B3E414141404242403C3A3C3F38393E3D393E433E
3A3E3E443F3C443C3E454D5D544B3D3F4641393D3E3A404139363B3E393C413D383C4042
39364241473A3E3242353F3B363A37363D3D393C413D3A373739393A3A3A4247535C5F73
65675346454142423E393E3E4042393939423D463C393E42473E4242402B49454639433D
3A443E414B42474A5F5A69584B574F6E627160705E6D66717697BEC1C8B5A87A8B7C9C80
845C574F49564B3E3E443D59668FADC2D0D1C6CFB7C08F90655B4E494A423C3F3F3F3F40
3E3B39383E383B3F453F3D3B42414142403F3E3C3D3E353B463E38423C373A445C717F94
767C827662494E48463D404339393F3A3E42444341434B515454514C47464A4E4D554240
404F4B394C3D383A36383A353E3C3F4547423E3E3B3B3B3A3C3F403F433A383A37383A39
3B3F3E3B393740514C52544F4E514F4949404242403D3A43403E413F393D403A3B393D41
40475153525A4A383F433A363B3F3F3B393A3A3947677E84896952423F3E3C3B3A3A3B3B
373D373A3C3D46424A4F69706252403B3A32343F433C36393C3634393F3F3B393B3B3C3E
3C39393C383A3A38383A3B3A3D3E3B393B393D4A4D737F78745B3C36383B3D3E4C646785
6B7F6D544D49453B3D463D3D3F383A3B3B424248363E4358646070746F67595343453E51
59766E7B797C74665B5C4C59544C5E56847D8D798D7F73635A5D585C59525761614D524B
525E6F9BADC3B8C7C2C8BCB9AFA8AE9794859896AA9BB5A7C6D0D3D0CFC8BDB9BBABA2B1
B3B49C87888F848D98A89BB4B8C9C9CEC6BDBA9F9F92ABA2CCD0CDAEC3BAC6B6C0BECEBB
B9B7B5C7C2D1D2D7BEC4A8C29CA5929F78817F797C7C71676D5B625B684F6F718993AEA7
B9A1B2BCC2D0D2D8D8E5CFC99BA47D7F595A4950585C636376A0C7E4DBD8C7A696726A51
4F4D4E48413E3E3C3D363638393F443F3A41363E382E3D303A36343536383F474C505454
493D3B3F3839353D373434393C383C435F717CAC9C986A493D3938363C343E5259627181
828F947C5847403540303A354A675F887D7763585861624B3E4A5A65746B8DAEBFAE888D
86868185736E767E664E4E47554D5047513D4043
494A4B494746474943424447464343464343434445464748454546484541434946474746
4543403E41443F42423E45423946443E42403C413E3F41423F3B3E433E3E44463F3E4241
3A3F423F39383C423F3E4043413C3B3F43443F3D444440423E3C423D403942473F3F3F3D
3B3B3C3E3B4044423D3A3B3E3D42403C404342433D3E3E3D3B3B3C3E3B393B3F41404042
3F3D3D3F3E3D40463B494851453F3C3B393A3B3B3A3A3D3F444A3E3B3B363E433F3B3E46
48423C3B403E3E3F3D3A3A3D3A393F4039393F403D3C3E3C3A434A444D53555D52524A4D
4446434447403B403E3B373D4640393D40494E413F423F4B4746403E403D3F47393D3D3F
423D3C42383B3B414F534F4F745E785E6E555D474445454A464E5A6A6F7E87847F7F7A71
51453F3F3E434D513F3D43516B83AEB7C4ADC2B7C7AEA878434C414C3839423F3F3B454A
4F4C4D4241474347373C3446453C413F3F373E3C443C4A394A4C43463E4F55779A919C7D
7150463E443937403A3D46443E42393D3E414549515D6D787E6A6054575456494D444040
3B393D393F4141403B3235443F433E3F35473F4442433D3D3B3941423B343840403F3F3B
46363E3B4E5F4F5C58544F4141473F423D433D4A393B3844443B3E3E424741453F424E53
5666674F533D3642433A36363A383A3E3D415F4A6B7F81755E5745393C3A3D443D3C4236
3B3241404D6C798661806B62513C3942383A3C373836443738373C3A363B3E393A433E40
423A3838382F393C3D3B383F37393B425069617D5759645240443B39334B646687688872
6358464546403E383B3A3A393A3E3E373C3E4348423A3C455147444746403E41435F836A
7A575E584D4F4B4B453E45494B556B756E727A745D514D4D48494E4D414346494A4B4B48
45587C84B7AFADAAC1B7A3948C94A5A692A39EB6B7D2C1CBC2C3B7BEAEA187858A8E8B90
9E8382727E789C90B799B3AFC4C7C3BFC0BFBFC5C0CCC1D6CCDAAE917877A6B6A7B0BBAC
ACB5BEC4CBCCBFAFA499ABA0C2B0A9816C5644464D505155535F7274828697BDC0C7CDD2
D8D7D7DDDAE7E5E3DCBAAB8A71615B716F6E7998B9BFC3C5CAD0D2D0BEAE866D4D403F42
3A3F3947404B404138413843455E674B4C3D3C35393D3A32353A3A3E5665879492857B66
484136373B3B3830373E363B373C3F5776888A78735B3C423D3938384C5D76929196969A
7F7B6457413A34403C3A35557D8782735454413E44453F505A6B889195A398A29A8C90A3
979F9E9260484B4B403F3D3F3B393E432F38363C
484849484748494A47464749484546494645444444444545454343464846464842434444
4444444441443E41413E44423F49464043413E44424142423F3C3D413F3E43443F404443
3C3F4243423F3E3D3E3D3E3F3F3E3F423F413E3C3F3F3D403B393F3F443D3F3F3B3C3D3C
3C3D40423A3E42423F3E40423F44403B3E403E403B3D403F3D3C3C3E3B3C4045453F3B3A
39393C3F3D39383B393C3D433E423B3D3A3D3E3E3C3D3E3E37403C3E403B3E3F35363D44
443F41484A423C3B3C3D404336363C3E3A3C3F3C3D3C3F414149575F796968595B424340
3839383A3E3B3A403F3E3B3F433E3B423F3D3E383A403B3F3C414241403C3D463B3F3E3C
3B393D4848453E3F4E5B646D6A6050553D4744433C3F394C4B646E807D73645A54504A44
403D424846444441413F40424847575255595C737D9DA6A9758276815E5547444D4E776B
85636B564C5A5D4A4A4D433E403F46443E3A4144464C61666A887B6B56685A8B6A7C4E4E
3E3C43484D4142434339423C433F41474346494D525A646B5A4C483E403C413A4039393D
3C3D413F393D3D3F44413C3D41404D464840404346413837393B3D3B3B383C3F3C3D403F
3F3E4F5C6F78686B4B4743393B3F393E3C3B39443B3E363F3A4C616766645C56524F545A
5A5D57463A4541393F413A383938414F5E657157615C4F443A3D3E3C33393940413C3E3C
3A3A5763899CA6997D6A4743413F363936323D3E453E3D37383A37383C3E3D373D433D3D
3E38393A403B354142463B3E39343C546C8A8C594241463841314F4661857F9D6E68504C
44423C424440423F3B3F3D393B3E3F3F3B3C4246423B3C4348413D3F403D3D3F587C706B
4E4A486746443E4041424D53635F615B4D4D514A49434446423F403E3C3E3F413F3B3F49
68A48CAC8AA18D96968C767A7571898C9D96C4AAC9A7BA90998E877E79615B61688997B1
B0A6A6A693ABA0C19AA890A89DAAB4B9BBB7B3B6BCBAC6B7CDC2C1AAB3A8CBC0BDB1B8A0
9CA4ADB4BDC1BAADA7C2B7C7C2C49B9967666B798998A3A9ACB6CECAD7C7D0DEDEE3E5E0
E5E1E2E4DCE2E0DBD5B9AE96A3ACB7CACACED0DBD6DADEDCD7CEC2B995836C6862666063
50524D544B4F4C5454524552586B613B3F303B3A3C2C384039576877A0B4C1BD9F7E5C4D
373D33393C3B36383F3E414E544E505963655D5747343C2D403E506281A7B5A48B968E78
51463D39422F3F2C343555777B75654C3A3E343A4C4A7D76919AA5A3A88F948A9CA0B0BE
ACA3907A473B3B38383C37373A4232333E3F484C
48474647484A4A4A484848494846474A4645444443444445474342464949464444454543
4140424341433F41413F4240434B464042403E4446434142403C3C3E413F40413F414545
424141444645403B403F3D3B3C4042413D41403E3D3B3C41413E42444A4442403E3E3E3D
3B3C3D3F444445433F3D3D3E41443F3B3D3D3B3D393D41413F3D3D3E3E3F434849444141
3E3C3B3B3A3A3C40433D3B3E3D473C3E3E4243403E3E3D3A3A3F3B3D3F3C3E3F3C3B3E42
3E383B44473D3636393B3C3D4744413E414D56545E5F5F60606270837D685551483D363B
3D3D3A393B39383D3A3B3C40423F414A4A3C39393D413C383C3E3C3B3B383A433B404140
403F4655605B514B4D4E50555041443A443144373C3F4F5F73777C7A6E58454143403F41
3F3C4044403E3E3C3938393A3B383F3A40433E423E4E565F61718992967E78736F838996
837E686A80A58EAB7F954B424343444646576870968EA383908588736F696E665E443E3E
43453F3C403D4A475C55505D53584B564848484849494A4B4943453E3F3B4240403A3D41
3F3D3B3B40443E363C44423F504E47533F463541413B38383C403F3E393A3E3D37373A39
424C58656A5E504A42403E3B3F3F3A4041393E3E3D403E4A5B82A1A4927C664F574B4548
4B47423F3D3F3D3A39383F49565D6E7072665D47483936393B3C4342353D383A3E41566B
6E6D7E798B7C7A5C61463A342F41363B46373B37403836413B4B474744393A3A373B353A
403F3F3A373E3A3A3A37333B423B4D6D6F8758493C3B373D42456369A18D8365513B3D36
3B3E3C403E373A383B433F393B3A3B42403F41443F37363A403D393A3E3F3E3E655B543A
543A4644403F393E403F46484F4948463F41433A3C3A3E413E3C3C3B3D413F3F403F4E68
9AA0AD6B6F5D5E61725D5A57586673858DA78CA57E8360554D574D634C5A6089A3B0C5BB
CBA8B3A4B2B0B899936D777D839BB2BEBAA7948D8A988EA696B0A4ABA4B3C2CCBDC8BDB9
B3B6B9BCC2C2B3A1A4A4C0A6B294A69EA8B3BFC7CDD6DCDDD2DDDDE6DDDDD9DCDDE3E5DA
DFD9D8D3C8CBD8DBE0D4D4D1D4DBDBDAD5DBDDDFE5E6E7E4D8C4B1A79F959AB0BECCBDC0
A7A39F9D96908C8E846C525143434039403F3A46323B4D696C99A6999B9087836A4D4837
3C2E373B333C3A4B5D677776775E50453F3A323B36393D53598A7EA2BAC7AF7A55605B41
3F3A403734463E3A403A5863544B3E353A37384A57899AA99F8B82817791798191979C9A
87796048493E38373A3937433E415449725C8D75
4A474546494B4A4847474746454446484243444546464645474544454745423E45464745
403E3F41404140414241403D4448443F403E3C4147423F403F3D3C3D44403E3D3E404343
46423E3E4142413E42423F3A3B40403D3F4446433F3C3F44444243464844444440403E3D
3B3B3C3D424241404040404040423E3B3E3E3C3F3B3E41413F3E3E3F3C3A3B3D3D3C3E42
38393C3F40403F3F403B373A384138393A3E403D3E4343403F403D3D3F404243403A393E
3E3A3A3F3F3B3A3D3F3E3C3D4042434654676F6B687174726C5D555B5E523E453C423B43
44423F3D3B39383943414041403C3B3F4536353A3A3C3C3841403D40464139393D424345
4744465050504F4E49413A383F3E314C3C4A42435662617C6E765B564E433E40413C3C41
4B4543403A3D44463D3B3A393A3A40403E39413F3F3E463F4E5C5E726C6F5E697984A28F
9D70695B8B808C71855A575D5A5B60788DB3C2C3AFA07C7A72786B7F6A7F5C7E4F52444D
4D4C4850626F7B79897B7D6D6E54514C45434241403D3A373B393D383B373D3C3F393E42
423F3B3F3E443F3D546F746D725C5144443E393B3C3B3D3B3A3C3A3C403F3E3D3E474F52
595C5250463739373F3E3D3F423E3940413949424446495B63879B9B866C573E483F3639
423F3A3F414246434C748977797A7F6657453C39372D3940443B3F3A3E3C393E4150748B
87786D5B53424337394335453A36453C3A393F383D3B547874807165523C4242383E3A3D
3E3B3B35353C4138443D353B415A5C4D5547413A39384952536972857C5254393F393D36
393D3A3D3B373C3B39423D383D39333B3E3C3C3E3C38383B3B3C39373B3A36343F3A4340
443F3D373B41434B4B424240484345453F3D3A314140403E3A393A3B3B4543444E556784
77795C483C4041504D636F8B989CAC9C95837F5E5F52415453525E5D747595ADC7CBB7C2
B6B8A79C8D8D737F5A6E697D84919A9C998D82828F859E82A3849A8E8C99B6A3C2B4C4BD
BCC0C1BFBDB8A9989CB0A3A4959F9FBFCDD5DCDFDFDDDAD6D3D4DAD1DCCDD8C8CED6D9CB
CEC2BCB1ADAFC5CCD4C9C6CACDD0D4DADCDEDDDDE7E4E4E4DBCBBEBAB8B6BFD5DBDFD4D8
DAD3CEC1BCAA9A896F5543463A3B3B443A3E48405266939DAFB0906B5F5346423839383F
394654685E68677F96ADBD9C6C54423A383838403C457679B8BABDBCBB986D4E3D3D3D38
3B3938354877574E3E3A3E3A3A37303F3B3142589AB18E836C5762608B85906E7C746559
524C3D3137363B3E3938558081A373856A8E85A2
4D4A4747494A484648484846454546474143464848474544434445454342403E40434646
424041423F3F414344443F3D44464341423F3D40453F3C3D3E3D3C3D45423D3B3D3E3E3F
42403D3B3B3D3F4041423F3C3D41403C40454947403D41453E404245413D3D423D3C3B3B
3D3E404042413F3F3F3F3F3E3C3F3D3D41403F443F3F3F3E3E3E3F40403D3B3A38363A3F
37393B3D3E3F3E3C373C37403B3E3D3D3E3F3E3B3B3F413F39393D4042454545423C3A3E
3E39373A3736363737363B41444D555C6971685A58605D555149403F433D40353F38403C
3B3B3B3A393A3A39443F3E40403D3A363934383E39384042443F37373E3E3A3D44444141
443F3A3D39373B403F3C3C3E4440444D4C5B616D78726D5B54433D353E4042423E393636
3F3E403F3B3D413F3B3C3C3D3C3D3A3C44413D423D4444465A504F445B58646B737C7975
6B5D4B4A514C424A424B5E96969698ABB3C0B19E90675845674F5949424B474646334138
37415D7987867873686A5858414237393F3E3D3F4142403E413F423D443F424042393C3C
3D3D3B47545C5F6D93B0A79167554D3C41403F3E3D3C3A3A3B3E404247413D455C778B97
9281604F433B444441403B3D413F424B64576455534B48544D5A5B5D5549453A3E3F3B3F
49463D3D3F47515D7A9FA185625B5A42403A3539393138373B39413D3E3745564F566C66
635042433538343C3B3932403D3B373F38363A517B8386818073564D41384036363D3937
3335403F43443946516B525B42584249353F3B494149776E75635E554832393F35473A3D
383B383C3E3C3F3B363E3A3B443E3437413E3C3A3836373A373D3C3C42413C3C393E4A47
40514C534E5455574E3E3B38444142413C3C3E3D3B3C3B38383A3D40334A55585F594F52
45483640384C51709093AA9E98A0897E6D5746423B43646A7A836E847BA19EB2B8A7AA91
A4868B726E62726E7C7E9B9B9C9B928D92979EA89F9B989B99978F8C96A89DA9B0C5BDC4
B7BCBBB2ABA9A6A0AFA5B7ABA79EB9B6CAC8C9CDCBC1B2A9A7AFA1B1ABBDBBB6BBC5C7BA
BAB0A89E8E7E888B9B9EA1ABC0C3CDD5DAD7DBE1E5E2E1E3E0D9D5D5D1CEC1C7C0C3CCD9
D3D0CCB7B09A866C5C524E62728372615D615F737B9CA1A18273543A363C3A3B3B455D55
777FA0A29F85758DA2B1AC7B44423C3E4141433F5A8B9AC9C3CCA29C724E3B41443B393C
3D39334A8F9E8A4F36383A3A3C383238364F5083AF8A7046495972A7A39C7E5E594E413C
403D3837383A3C39385288B2C196875B56729BA2
504D49484A4A4745494B4B48474848484546484A494643413E4243424243434242444746
44414040413E4242454741404544434444414043443F3C3D3E3D3D3F44433E3C3E3E3B3C
3B3C3E3E3C3C3C3D3D3E3E3E3F41413F404347463F3C40423B40444A423E3B3F3F3D3C3B
3D3E3E3E444342403E3C3A393A3D3C3F4442404543403D3B3C3E3F403F3E3F413F3C3E43
41403E3B3B3E3F3E37433E473E3D4040413E3B3A3A3C3D3E3C383D3C3B414345413E3E40
3D35353B3B3A3A3C414B5D6C5054545660645C53383E3D393B3D3935393D403A3A393A35
38383A3A383B3D393E38393E40423F39393D40433C384143383B3C3F433F3C4148443D3D
42403B3D4039393D3B3A3F434D5D5C715471667D575B494E38453C423D3F3F3C3B3E3D3A
35373E423F40413B3A3C3D3F3F453E443A3E3D3647434C5A4E54495F61756E72695F4E3F
3B393C403E3F3D413B454B657571707675776C5E5846394E47656E4F5045553E4E484E4B
435070857B674B4D4141443A443C48423F3D3D3E41434342413F403A433D3F3D473C3E3C
40434255717B7C7F8F937D6452545354474B3D403B3B364456637170766D65718A9FACB5
AE937764584F48403A3D383F4D596B79856E685450453F44413E3B40413C3B393F433F3D
434139383D525C6B7E7056553F383F3741413C3B403D3A363B3D403E3E445D6A51464D3B
403938423235323F4349423F3B413C4E3E5B7C939E8576615747353A3D3F463943433D42
4D5D6D69827992728D615B4A4E494235443D426F7F84837362464B393A33414841453633
393D393C3E3C3B323539393F48443A3B413F3D3B393A3D403F44413F433F3C4342534C5A
587452594D4F4B4B433A3E403F3E3F3F3B393C3F373B3B393C3E3F414451504849463C38
3C3944494D71688C8B8F8883715E543F41443B3E53618D8B89868371828693928E847274
615D4D4754676C9B83A7A0AAA6A399949A9FA3AAAEADB9BAC8BEBDB5BABBC3B2D0BFCDC4
BAB6ADA5A8B0B0AAAEC4ABB0A5AB91A59290939B9D9282787D7D7C78898D989486929696
989B999B8D77787E9CAFBDC8CDD4DBD4D0CDD6DBE5E3E2E2E1DEDCDDCAC5AEACA4AEC3D2
D8DBDCCBC5B7AE9F9C9C9AB1C1CAB49A866470708A756F64464B4940373B363B47738DA9
B6CBC2B2865C4E5F635F5F59616F70767D879899AFC4D6C2C894886A483E3F3E3D383D3C
3C4259748B8A6F483E353C3B313B453E798578885F434242656EBFC3BA79644A3F3A3A3A
3D35373B3A38323F6494ACA1876B544A609596AB
514E4B4A4A4A4846484B4C49474848464848494948464443414241414347464245454645
44424140453F424044494445454140424341434545403E3E3F3D3E414244403E413F3B3D
3A3B3E40403F3E3C3E3D3E403F3E3F41424146463F3E403F4043444C44433D4042403D3C
3C3D3C3B3E3F4040403F3E3E3A3C3C4044403C4146413B3A3C3F3E3D36373B3E3D3B3E43
4042424141423F3A373F3D41373A3A3F3B36353B3E3F4145433C403B363D40453D39393E
3F3B3C4248423D3C3D424E59524E433D4244424446423E3B383C42423E443D473B453A3C
3D3B3D3B373C3F3A413C3D3F3D3D3D3738413E40403D403E414445474A48484F42403B3C
43434247443B3C4444464D5163677D61694F5B534446464241403E3A3E3E3B37373B3C3A
4444494A484A4A4243433F3D3A3F353E47515853685C5F6B6D76737871665C464740413D
413E413C463D373C37473F414A403D3A393A403E40363E3949588C7866666F7973785E5F
42475368655F5459414134403E434240403F3E3D3E3E3E3E4141423A423D3F4246404D53
5C605C70838A83756A5E514A5E5B73676D4F49433E4746637E8EA5A19E8B767277716A6D
7A67675C535245456D716461666D7C836A56493F3F3B3B3F39383E4243403A3B42413D3A
3C3D3E4150646458534635323E373E393F3D403D3F453F3D3C3A373F41515B58453A3E37
38393F3E3F3D565E6E90645D46344C445E6F8B9085634C363B38373D3E3C3D3B434A556E
89A1AFA3928D7A70655B6873768A524F5B748A9E9D9271674B414540383B334137463B3B
353B383A3C3C3E3737383A4043403D3F3A3C3E3F4044494C46473F393C373A4A4C606D5F
74584D4647453D3E3B363A3937383B3F3F3B3A3C4246413B3E3D39393D41403C3E414241
39424E5C707375757C64614E3F403842383F46454F806684616652605E776B6E55444F46
52425150707694889B84928C97968F8B8F949AA2B0BDC7CFCACAC5C4C7C7B9BAAFA8A6A5
A5A4A1A1A9AEA597978C9A6D836174666C717675716B625B5A635C66626E5E6658676C79
7985848F86808B92A5A7AAACAAB2BDBAC1C3CAC9DFDFDCD9D7D8D9D8D8D8CAC4B9C4D0DD
DFDFE2DFDDD7D7D6D2CFC0D2DBDDD2C2855A5A55594B3C40403C3636373C374B8FBAD4D4
D4BD9A6E483A404040465E93B2BABCB9BCC8D4D8D8D8C0B18D84655E463E3E35373E5359
80889B845457353D3F313C3A3F64787994757651494A638088A3B9C28A55563D3C393F3A
3A343A3937414B6F949C8E75795B766C9A9AA68E
514E4C4B4B4A494744494A4745464542484847474747484847454140454A463F41414143
444647484840423E424A464A433D3C3E3F3F4246474340403F3E3F424044424144413D3F
3E3C3C3F4243413E413F3F413F3B3C41454246474140423E44423D443F423B3E3E3C3B3B
3D3F3F3F42434443403D3B3A3B3D3D40433D383C47413A393D3F3D3A3C3C3D3E3C3A3D43
3F3F3C383A3E3F3C393A3D3F3842404A453C3A3F3F39383C3D3944423D434346483D373B
403E3A3A3E3A37393A3A3C3F3A3C393B43423D3F3732373D38373C3D3F383B3942393B39
3B393A38343B403C3D3B3F3F3A3C413E39443D424E4F4F483F4040454C4842433A3B3A3B
403E3E453F3539454A525F65636A584E4143443F4042393C37423C3B3D3F403F3D3D3F41
4A4A4C4B4748453C393C3C3E3D453943576A648476836B7767725E64484B45353F3A3A3F
393E403D4B353D3C413B414142393F3E41393D3A3D45383E443B4F5649576387897A685C
4345476D84908B835C4B383A423B413E3F3F3F3F3F4040403D4041383F393F454F4F6571
7B796A7A757569574A403E4452506270716153554B5E6181969BB1AAA98E6D5D55463C43
3E34493F3744465C6D7260554F4A504E4E474143413A393B41424C4742403A3F43414347
48494E5489604D4A39343E3F3D353C3C423E403636433D3E3D414865414F3E333D3F3F41
40434F4863597E6F857B6E5448574C5C6058655A504442413B3E3F3E3E3A3A454B637E97
A0A3A39282706E678F6A8A719369505D7299A89999726849483A3B3D3A3F373437383E3A
3A3F3A383738403D3A383C3E3A373A3E45484846434243443D3F393B474D5C787F88555F
464B3B433D3B363E433F3E38403D3C3F403B38393B3F39343B3F3E4038393E413E3C3C3B
3948607E717A464B42393F423E3E3C3F49484647504A604E4A4E4B4946413A3C3D39484E
473F4B5A5E7B597A547756725A606265707D8B99ACC0C1C5ADB6B5C1AE988A81877E9089
92A2AFAEA4958170767A6F5B4F4E5051505D61554A494947484E4E4F575F56665B6B6D7C
737A727E778092929285888B9A8D868196A7BCC2CBCBC7C1C0C6CACACCD3D5CBBDCBD0DF
DFD6D5DDDFD7D6DADCC89AA1B8D1D3BEB285875858454042404241443F425494B4DADDDF
CCB37B494340443C608B9DD3D3D5DFDDDDDED1CCCCB4AD826B604B49543E404E667392A6
AAA48E4C383C3E403C3C4E4F73A1A0AA6C71535E778A9EB1ADA5AC7A523A513C38343A34
38383E343A58789C9871789F86938098949D8788
4B4A49494A4B4A494542414346484542404749494C463F4042434442403F40413D424441
4144433E4D4843424445444342393743423C42403B3D3E3D3B3C3F433D423F42413C3E3A
3B3D3F40414243423A3D40414140414140444444474B4A45403E3F43443F3C3C3B423F3A
3D3E3E423A3C3E3E3C3A3A3A363C3F3D3C3E3F3D373B3C37363A3C3B3B403B40403D4441
3D473E3C3E3B3D383A3C3F403F3F40413E4040464A423C42353E43443C3B443E3E3C383C
413B38403C41443E373A3B333B3B3A3837393C3F3E3D3A3B4146423A3C3B373C3C373C3D
403B3A3D3C393A3E37373B3D3C4141393A4046544F4C403F3C3F423F3D474A3F3A373839
43473E403146515E6A54524447433A3D413E403C443C3E433F3F4342433A3C3A3E413B42
403D4946433C4B513A443D40453C3E4962646B6468616058504C40414E493B3A3445453E
3F39343E3D3C453E363D4041413A3E393738374342433E3D3A4246524E717987765C5845
36474D6B8A989D85704E45403E4A49423A3A3E3A3F433B423C3B4145404261867A97778D
6661574F4C414651454660659B6C5B50504A4A464450585858616C73725E534E433B3C3C
393B42453F414A484848443B403F4D4A433D3C3B363B394240535E53515B554945445B7C
769982915E5B4039423E3B3B3733353C3E3E3C3E3E41515A6651554F5643413E48565C5B
5D616C6F78848EA7999C79936D866B795F5048443E3D3E3A3D3D40353D3F465058818588
766C6B667895969A7677525B4B4F50668AA58D8A6D5E4D44403C3B3C36383B3C3B3B3C3D
38353B443F323542383A3E3738444A515C69595B40443D3F3D3C485C687E8C777B55413E
423F37413E3A3E403D364539353A3A3F3B2F393D3D393633433B39383C413D3C4446403E
4D6B6A6F64423B3C3F3D3B3F3D383D3E574D58543E433A3B3537393D3F3D3B3939384245
3F474F485146414446413E404E62728284849398A4AEAC9B9C8B81816C675780888E98A4
A5B7B0A492867980807A605C4846464C5759615E686260565B5F837D8D78797689939286
8B7A7C8F828A928F928883857C826881779B95A39DA2969F999A9C9AC0C1CCA7C2B8D3D0
D3C5C5C3CACEDDDEDDD1AA99A7C1D4C7A5BDA1B89BAB85AC95A69A998A98A9BDCCDFDCDA
D1BBBB9393727D7EA892C6C2D4D5DCD9D0BFA2927F604B52444D605F4942475B758DAAC2
C18D553B3D4342405F5C898DC1B5C7968D8899B3BDB7BCB093876B46394A4C3B3A343B3C
3B38353D466B9B916966877984768B8A98778570
4C4B494A4C4D4E4E4A484647494B4A494E4A42414746424343434342414041423F414241
42434442454543413F4041413E3F4047423D423D3D3D3D3E404142433E423E41423F4340
3C404343403E3F413C3E404242424242434345494C4B4948433F3E40413F3E3F3C42403B
3D3E3D403B3D3F3F3E3D3F413A3F413E3C3C3B393C3E3E3C3A3C3E3E383E3D41403C4342
383F3B40433B3B39393A3C3E3F4041423A3A3A3F443E3A423B3C3D44414049473E3D3B40
45403D4544444640393C3F393C3D3C3A38383A3B3F3D3B3A3F44413B393D3D413D384146
3E404141403E3B383A383B3C3D4448433C4146524C493E3D3E3C3F413F41433F3A38393A
454D474C4A5A5A56543D4441413D373E3E373C3E3F3D4045423E3C3A423736363D433F43
393C443A383A443F364142526665605F5C554E414442443E373D3D4450493C3C3C413D3B
3F3C3E4B4542473F383D3E3E3B3B434242443D3E40434A4663557C718D7977614E404647
53636572776E68534D3F403D393F3D393D3B3C383E423E4564655A453D5480A3B4A1926D
645A5856485768767A6E779B91604F3F3834393D393D40404145494A3F38393B383B4142
3D393839393C403E3E3E3C393F3B423C394136483450414E435250534D4043435E5E987F
946E675641413A3A3F3F3E3E384242434045505A5E746E8A5E604756606C7B867D857E83
8287A58FA99BA8A8AC96A0809A7885746856484138373B3D373C3C4541484C635F6E5C5E
5F718A96A5938B6F4E413F3F3D56747E9472765948413D3D3E3B393A39393A393939393A
39383A3D3F3C3834383B44465062686E715F5C534E5B516162656B7A82827B684E403F3F
41403A3F3B36393A3935443A3A3D373A3A3A403D39373A373E373B3E2F3B414244414044
666D5E564D3A3C403B3B40413F40444E614A4D3C3A333F3A3A3E373B3B38403D48454A49
404448403B3439433D3343616F828F9D9E94918C8A7D805B654E5F57567078989CA9ADA2
9B969775886D6F67605A695E756076707B818C888A84847F8598A2ABA39A8EA19DA197A2
9098919C918E9A909B8D908A91718D769A80A6918E8E8A88808784898092859B97BBB3BB
938F85ACAED0C6C8D0C1B7A7B0C2B4A69990C0C7DDCAD2C1CEC4AC9EA7A6ACA6A1BEC7DD
CBD6D8D5B5BAA0C49FB3B4BEB7B9C2C0B59F80705F5B5F4F657D9B8085687C8FB095AFC8
AE704A3E5D827C82768E8ACBB8CEA9A69E9D9FBEB8B69D81464440343340433836383C36
323A3F4A566A6F62595B665D608691A3797F7978
4947454446484949484745454547484950494243494742424543424141414141423F3F42
42414245444A4C474344454542474647433F403645423F3F41413F3C44454041413F4441
3D4246443E3A3C403F3F404143434342474343494A47464A45403D3D3E3E40414448443D
3B3A3839383A3C3B38373A3C393C3E3D3D3E3E3D414040403F3E3F413E4241403B343737
3A3D3B43473E3D4142403E3D3C3B3A393E3C3A3E403D3C42423F3C44443F45433D3C3C3F
403A363B454344433D3D3F3B3B3C3C3C3B393A3B3D3B3836393C3B38373C3B3C3731393C
3C42433F3D3E3B353C3C4144444647403E43444D45443C3D463E3E44423F444A403E4042
4F5A596053574F474636403D3F3A36403E353C453C3F4043433D3838403534353B403B3A
4342443C3C3E4744414F55687C78685A4E463F383E3E3F393B3F3D3E413A343A403F3D3C
3D3F3F3F3D3A403E3C413E3D3C3D403B3C413B36404D4B8179B2A1A684674F493A596C82
7B7A68605446473F3E3E423E3B3C383A3B3B3D3C454A474D636B6550495B727E7A6F4B51
496A7580878F9DA6A2795567633A3F4141423E3E43403E3C3937373A3A3B3E3C383B3E3B
3A3C3D3E403D393B44433F3D3E383F3D45434A474F544E4947414A464343435D626F766C
564E38373C3B413E38393C3F3D445F5389748E7A927B8E6C93789894A9A9B2A5ACA8A8A5
B0B8A5A5899887927282708D68784F4D493F3D41403C3D3D3E3A3C49636A788378786980
95A5A69E835654473B3C4C3F698191A57470524C403E3C3C3B3837383C3B383737373837
383E3E38373E3E39383D50606D736E706664687B6F8A7385827769686459524641424743
42443F3D3E3A3D3E3C3A443B363E333A343F3B363A373E403F383B3B3B414442403F444F
6D604C403A383D423A383D3B3C42444F4B45394537413E3E3D3E343F47464B4045414443
3B3D413A3833353A3940628888908B8B87776860574E4A3C444A5D617F8D92A390827B6F
6A6A6254584D4440566F6E9D8CA08E93828F9D9992888785A3A7C6A7BC89A2A7B3ADB097
A8979E94A1A09999908F878389897593839C8D9F808A75776F6D7D7779677D588E74917D
6D668088AAA2AB9DB9C5B2B09F7D6C474C5376B6AACAB9ADB2B08B9E959F7B6A626BA2AD
D0CADBDADAD5DACDD1B9C1A5ABA5AEBAC4C2B2ACA8B89D946B827F7A787D7C9894A6A6B7
A6907285A0A3A18C9181B9A4D1A9CFA09E939D9BA88A7749413B383A3A3C3D383C3F433C
343A383D4C5E493D44433E4787ABD89A915C6D4D
4D4B4948484847474A4A4A4948484A4C4E4C4A4C4C4742424542403F40414140423E3E43
433E3E433F4648433F403F3D41433E3F403F4037403E3C3C3F41424144453F4142404442
3F4041413D3A3C4142413F4041424140494441424241434645413C3B3D3F41423F41403C
3C3F3F3F3D40413F3B38393B3B3B3C3C3D3E4041433F3F42413E3E4241413F3E3D3A3B3A
363733353936363B3F3D3A3A3C3D3C3B413E3C3E3E3A3A3E3B3E3D44454246423F404244
423B393C3E3B3F423F3D3C3739393A3C3C3B3C3F3E3C3937373939393D3E393B3A353836
3D3E3C37373A3C3A4342464743413E37404341463E403D4049413E403F3E4651504C4943
474B464C46453F3C443C423B3C3A353C3C3740463F43403D403C393E3F383839383A3834
373B424245484D4D5A635C5A5C544B41403D3C3B3F3F3D39383B3A3A3D38363D373A3C39
3C4949393D3B414243443C39393A3B383B414445554E8E95CEBDB7874D555E68847F9488
76674C44403C434347433C393A3736403F43464A545652556E695F524B4A49474C494751
62728B8CAA9EA7AEA8A09A9C7E4B403A39423F4144403C3B3B41506043413F3D3B3C3D3D
494E4E453F3D42555E615D5951464A4A58584C5D50695C695556495052597C877F7E5E53
3E473D47453E423C3A3F3E4140564F626F7D8C938FAAA8CEA8C1A6B79EA7A1B0AAC1ABAC
B29AA475895E726A70717A605E45473C403A3B41413B3839475956818FB4AFB89B96899E
A59B7E644C363B4D49607474917C8E6B5E47443A3E3F41403E3C3E403D3B383839393837
3F44443D36373B3F49495D727F83828D8F96999493827A686252464641454F435450483F
3F46433D3D383A3A393B43403D3C45334036433B463A3C403E3B3E3C4743404145495056
64514B433E403F3F3E3B37383F42404139363C384042443D414542464641443F3B383A3A
35383C39393C3A3A4963767C7070625855493D3B40423A3F4D616D7C79736D765E4C4946
42414239494348486E789996AC888C776F76797066646A707D9BA0C2A2ACA8B499A989A1
96A7859A96908F7780646B61826897829F83A58F8D8581706A736C6F696B566355695A5E
5868558B6E926B718E949694856C5645524C6B63846E726A72758596BCAEA083818285AE
A9CBBED7D4DDD2E5D7DCC1A48B8A9CB3C6CECBD1D9D2D5A797647B819AA1AF788E8BAD9B
A294ADA6A4A990A096B3ABB9BFD6C7BA9F9C8693757254415E4A393B39343B3C3A313138
3639323C525F43383A3D48679BC4B39F5E62453D
4B4A49494948464447494A4947464849464343454849474343413F3F40403F3E423D3D44
433C3A3F464949464445423E3E3F3A3F424046474342403C38383B3D41423C4042414542
403C3A3D3F3E3E4244413F3E3F403F3E454745403F40413F43403C3C3F41413F3E3F3E3C
3D4143403D3F41403D39393A423F3D3C3B3C3D3E403D3D40403D3D3F4A44403F4144413F
3D403E383B3D3A3C3E3C3A3A3C3D3D3C3C3A3A3B3A37373837423F3A37373B36383B4144
413D3E403B373A3F3E3E3E393C3A3A3D3C3A3C41423F3D3B3A3A3A3B393D393B3B393D39
3E39363738393D434842413F39393C3B40423C3E383F3F4442413E3A38393F474443433F
4448444B46413E3A403B423C3B3B3435383B44424348433D3E3C3A3F3E3C3D3C373B4545
3E535E5F616A68615E655D55514B4B474D4A46433E3E3E413C3A37383C3C3D4244434441
43515443413F44464A4D46474345484D4E50585F779098B3A0867C55667A7A9387806C5E
4A40353B413E3D3A524B3D3B3D363B4E62645E5B5A524A48564B4241454A4F534E5C7298
7DA684987F80837C687087859A6C524038424147484441403E3D444E4A413A3E4344474D
4F5050484F6584AEBFC2BBB5A18A7C718B69704D6852737E92797760515E5F64655B4A3E
463C3E3F3E3C403D42443A3C4B474A5789879F95B3AABA9FB2959E8E999FADA4A59D9591
868A758C74897E8C7F977C9456693D43453F3A3D465059617574967AA17D92868C867573
645E544F625C596674848A885858404639393E3A3C4043423E3A37353B3A393A3C3C3A38
3D393B403F3B4251657088969EA4A4ACA29F7C7D656B564B3A3E4451565E614D524A3D37
3A3F403B413E3D3B35383B3C3D3E393C37403F44483C3C443F3C3C3B4A47484E55585651
504249463D3D3735353F37424C47463E413C3F3040514E494941403C3F4540413E3A3A3A
38383A3932393D4455635D4B4547443F413F3B4039394A47625A635F53524646383F3E37
3E47435D5E706266627370806B65514A4B4F4F4C494D52568087AF99B087A0868C828D8C
A37F797A68766768615C5B636A8B76927A9F7997848C7A81867D897678718A6B7F5B6856
68667B71846F7975706E69757E7B7A726F76566055684A615E726D9FA3B99E9A968AA69E
B89CAEB6D0D4E4DAE0C5BB9B8694B4C7CAC7C7D5D0E1CEDFBBC0B6C8BBC3A89B799296A5
ADBCB5B6A28EA8B5CBC5DBD8DAC6C8A088736D575C3E4A3F483B334147495B63694A3741
39383B5A77633E3E4963819C9F9687594B383C38
434445474848464342444545434242434B48484C5359503E4242414141403F3E413D3E44
443D3B3F41403F3E3E3D3C3B3C413E43433C40443D3E3E3C393A404446453E40413E413C
413B393F4341404243413E3D3D3E3F40404649454243403A413F3D3D4044423D4442413E
3B3F403B393A3C3C3B3A3A3A413D3B3C3D3D3E403D3B3B3E3F3E3D3D4B433F3C3E413B39
383D3F373A3D3635403F3D3C3C3C3B3A3A383B3D3C3C3D3C4B574E403B3B3E3835384042
3B383B3B403B3C3E3F43443E413D3C3E3C38393E3F3C3A3B3A383737373F3F3E39353B3B
3E39393D3F3D3F443F3A3C3D39393D3E3E3F383A364040443F46453E3A393A3D3F40423E
4245424A53443D363F3F453D3E413A393D424944454947423F3C3A3B3E3D3D3D38435C61
5661605E5C625E5F616763636159554E41413D3D36383A4147413B3A3B3B3B3F3F3A3D41
3F403E353D3B3F40474D4C565354545D60616E77A0909676805E7D6D9878806758443D3D
3B37353B3D3A38383D3D394045414F644C4F4643423C3B3B3C3D3D3F43494F536265988C
906E6A5D4C5A524743444A43554A403C3A45485045413F4143413E3C4C41393B403D3E47
3C3B49546A8BA8CCD2DAD5D7CBBFAF9E8160494B4C4F4B5A4F49404A454251463F3C383F
433F3D403D3F3D363946566B687F7DA490978C937E856B6B59748A9E9A978A93757F6462
7C768D728A67775E6C5E64425239483D5154555E72858F949586636954654E5F4B4B4346
48667E8CAA9479617A68604E3D423D3D3B36363A3A3C3C3B3B3C3C3A39393A3B3C3C3B3A
3C35363D3D3F567591A8BEB6AAA18C7C7A5E5C4244413A4241505258615E534040413C3C
3B383A37383B4041393A3539393E3E534F605052504741443B383B456463625E57544E44
413943413A3B3A3E3C50454C4F3F41373A3F3C3F4A6A514F49393A3A485445413D39383A
3A3939393C38394144403C3C3A3A3F3D3C40434A423D4B51524A4A3E4240324037423E48
5E5B75667C5B5F50474D4D4744393E39393C3D47546A767C8C987F8766715B5C5E696B96
758F74666A6E6C575E4456556F6884647E788C87837B827F8581726B6D837B976F83686B
70836E855B72627D727C667A7E6D7E6D7A64684D6C5F6863646C7779897D8889869089A4
8F978CA4B7CBCFE0CDD4C0B9A6ADC1C7C4C4C9D9DADCE5D0E0CBDCD1D8C8CFACB89DB8BB
C9BDD2C6BFC8C1DDD5E4D0DAC4B28D885D533745343B39433F4854707D8396969570565D
4C4A56868F603E577DA1B3AD825F4B3C3F3A393A
4747484A4C4C4B49474747464545454641444B53617069524243454543424140413F4044
44414043464344464542454C444D4A4F554D443A444342403F3F3F404A483E3F3F3E413D
423F404748413E40403F3E3D3E4043453E41444442403E3D403F3D3D4145423C3F3D3E3D
3C424540403F3D3E3F4041413C393A3F42403F403B3C3D3D4042413E3E3A3E3B3C403A3C
3C3E413D40423A3F3A3C3D3E3E3F40403D3A3E403E4043403C473F393A3B3C373D3F4746
3C383B3B42404243454A483D423E3E413E38373D3C39393C3C3835343C4544423C383D3B
3E3D3D3E3F3E3E3F3A373D413D3A3C3B3C3E373A3742403F404948403D3A3B403C3D3F39
3C3E3C4451403C384244473D3C413E4141404644424447443D3D3E3B3F3E3C3D3A49676B
635C4C4C4B4E4B54615F55544F464743403F3C433E413F453D3C3E42413D3C3D3F40474E
4C474340545457565A5D5D6B5B5D5A636B6E77768771637A72A07B8B5E464B4C39413644
403D3B3938393D413C403B3E3F3B424541473F3E3E393E404043454443444648424E596A
58474A3E4B48393540444144555C483E393F434B49433B383D464A4A4C4C4845453D3B42
49445B6C7D9197A7ADC2C7CEC7C6BEB2997B72778071584E453E434243433B42443A3F37
3E3B4341443F3C445577A1B6B8A0977C766067585362687A918E937A8169646A636D6964
6065585D46484036413C403D463F423E626B6D71818C867E7B5D4546506C5E70666D6F78
86AFBFBFA6896549503B403B3D37463B403E354147443E39393D3D3A38393A3A3A3A3A3B
42414140404D6E8CAEB4B09176685243453C414038473C4F464C44444B48433937424242
3D383B363D3F434239424350857F987E8E71674F594D3D3F3E465065726E65544545443A
3E3B41413E40454D515F4D484A404645414653475E55473E403D454344453C3C37343438
3A383739423C3939363339434039423F39404549564C4149343E3D3E3946415F535B506C
6A6465564F3C3E3D373E3B3836353E3E454E576A778784808D736C4B52404C4C57667979
8196926C5A5C52534845585561776381719D738A75756D757A697167807995758E718368
786D6A58675B676B787C7C7D776F6E6D716C617765827172637265725E6462737A747D71
7E6C747A9FA3C3AAC9B7C8B6B2ACACABB0BBC0CACCD6CBD7C3CBC9CBCFD0C8CEC9D4CFD1
CEC9C2CFD8D6DBD9D7BDB68D8A61694E433A3837494457587C8A93A8B2B3B59F7E695C6A
5E68749E946A556F95A6A9966741373B3F3D3534
484746464848474646454341414143444045474347575642434548484643424242404043
444445484644474B47434A575E67646E7F7D674B444342434647444245433A3C40424947
4343484E4B403C3F3E3E3F3E3E41464A3E3B3C3F3D3A3D42403F3D3C4145423C413E3F3E
3C41443E433F3A393B3D3E3E3D3B3D43443F3B3A3B3E3F3E4145443F424149444040393D
3B3638373C3D38443F4042413E3C3C3C3E3A3D3E3A3D403C3B433E4148433F39383B4342
38363A3A3F42474A4B4E47353F3C3D424039383D423E3F4344403B39353B38393A393C36
3F413F3A383C3C38433D3F403A373A3B3B3D373B39433E3B3E44413B39373B473E3F413C
3F43434D3F394442433F423B33383A403D353B3E3E3F43413A3E4541403E3B3E3C496462
514E3D4046524A4B3F3F3C41403C45494A453A3F383A35393F3D3D3D3A393E45474D4F4B
4644434243474F51565756656C726C71736D65525B4A7769936D645447423B393B363B3B
37383B3B3D403F4041453D3E4142423338423D3E3E373B3D413E3D40413D3B3B40374349
3B413D403F36424A443B384343563F3A3C403F403C3F3E3C3E454A4A737D7D756D625B5E
715D656058574D52597F939F92928F887C7E71987D8754543A433A373F3E404B49423D3C
34464442423D4C7BA4C3D0BA9D7D6E4A4549645F87A6AAB9AE907E5A504F627B5854403A
3F3941404735443A4041384539413C46464D4743515F5B514D4D726F909D9EABA1B1BAB9
AEB7A0837A6240473B3939393E3D323D403D3F3B3E3D3B3B4045423C39393A383737393B
363E434655718C999A8A7555403B373C3A3C37363D414B473C38353D4141453E3543413F
3C3C41393A3A3B3E466C88ABC4CDC7B795916E614541384C5A6667785B564D3C333E443A
3737393A39383C434C503D3B4E5F727E737C6E645443333B35383C3A3634363B3B38363A
3C38353630393E3C3E4441393A324246404B4F4D453D3E393F3840425E8B8C94747B5C65
51453A3736393D41343E3D3C37363B393947556E79857B74644841473B474C5945604E55
5F7F665C453C4047494D74697D6785769C929486887E7C797D727D848083777D6B7A6655
5653454B52616675768069706C5F736975668564836575666F6E6063656469717274716D
686C657467857B9177A2929A87868E929DA9A7A9ABB0BCC3C6C0C9C1CABBBFC2D9D1D3CD
C7B6BAC2D1D9CDCE9F8A584F40443D413C494E63758C9FA7C8CCC0C6CAC6B98F786F656F
6574758C90776464706973735D3E4B4043344041
47494A484443454843403F424342444844444342414142423F424545444241413B453D44
484751464041414243484E535C615B70827F76594D474248545E605E4A443F3E49626B5E
5659645F686B4B3D3D3C3B3B3C3E464E443F3E41403B3C423F42433B463F40423C3A413F
3B3B3D4A44423E3D4348423940464A423B42433637393F3E4442433F3838403D423A3B38
3D3D3D3F3F3D3B3A3D403E45443E4441423F3F42413D3E423A3B3A3B3D3F3E3B38403F3B
3C3B37393D3D3F494F4740453B3D3D443B343F40383B3E3E3C3A393945403A38393A3A39
363C3B393B3A373B423B3A40413D3E433D3E3C38373B3D3B3D41423E3A3B3C3B393F4040
423C3C46453F39383C3F403F3E423D3A3E3C3E493D45463F3E4447453A4247434F577158
474852625A484948403D393A3C363B4B413E3B3B3E3F3D3B3B393C3C373C4649685A4846
4A42393D3C4242434A515A666062605952504E4B4E5C59554D4648413740353E3B3A3A41
3A3E40515357624D3F3C413F3E40393B3A423C3F3F453D3E3D47453F3D383740393D3E41
433E3A3E3B444F424240423E453A363D43413C3C3841363F3F445D849FBEC8C7B0937472
5855524B3D44414D5361776E594A3F46494F5A4F5647473837344144423E3A4649403B45
5D4D5B51515E7FB1CAD0CEB4846655494B6A8EAFBCCABABBCAB89C8D55544D4941414A42
3F423A3D394139363841383B3F3C3D3C36403A46483D4F5E608385979FA5959593908B75
7C5C6256493E3D373A3B4034373A3F3A3F4145413E403A3F3E383E3D3B39423A3F3D323B
3E556D8395A7AF9E654A48403E323E3A3E3B3F3B423E413E373D3C3B3C3B3A3E3D323D3E
414033453B4A72839CADC1D4D0C9C4A9A1868A73745C6A74896E6B6150413C3F3B383E42
333D36414239344140556A8995989E8B88646B54443A3B36313A3B38364034363C343B32
3B3C39373B3A3E4148443E383949545A5D584B3B373D474E4B4565769397A278664A4740
37383E393E3A403F323937343D343E403C45535F645A4D4F3E383A3F46413742423F423B
403B3D38323C4D5C6B898D937D867D8C899C828F7988847D7873757270605F4A45433F39
373F506169767A746B70736C70746E7570766F7266605660575D576A7087786E6E67695E
6265655763505E556965737072777A7C8287827782869998A6AFBAC0B3B7C1CBCFD1CDC6
BBBEC2C7CDCAB7A39A8E685A54696175647C99B6C2C8CCBCBEBCC0BACAC5A58F90887E7A
746C686C5858474A4D516E79747877745C44567F
434547464545484A423F3E403F3D3E40424241404041424341434444424040403B423A41
433F473F3A3A3A3A3B3E434543483F4953515241413D3B414C5455534A4846454A5B625A
55545B565E61484147403C3E424446483F3C40494C4644484140413C413A3C3E39363D3E
3F3E393D43423E3C3F474F52545A5D52413F413C353C36403A483F3E3F3E433F433D403D
383F44433F3C3B3C3B3D3E4B4D42403C3D3D4043413C3A3C3F3D3D403F3B3A3D323C3D38
393A3B3F3C3F3F4146433F41303439413C363C37393B3E3F3E3B3A393F3C3A3A3C3C3A37
373736393F3F424C433E3B3D3C39393D35373736393F44443C3F3F3A383C404146433E3C
3D3C3D433A3837393D4245463A3D4951483F41473B40413C3B3F43424B534E5856636E58
585250584F3F3E393B3D3D3F403A39423D3B393B3E403E3C413C3E41404447423F3E3C3F
4542404745464141484B4D525052514B47474745383E3E3F3B3F473A3D41383F3D403F47
465C768D87726143413E423F40423E41404640413B403B3E4044413C3E413D393B3D3C3E
413E3E453D41483E403D413D3C3F4548443C393B3D484759627692AEB7B8ABA292765C5D
57565551454B46504F50564F4641393B363B3C4541423B3B3E3A424444464752554B4757
7B7B8E83818A9AAFB6BDC3B19A7E6D5F5863707F72899CB4CCCDB9A56D503D37373A3E3E
3B3D383A363D3A39423E37393E3B3E4039443F4E62718E9BABB0B6999078606D5957503F
41464B523B38314436403D4B43443E493D4C50594B463E40413E3E3D38394338353B4765
739CBAC1BDB69661444241484346423E3E3F383C423D443B363C3D3E413E3A3C443F3B36
37374F739098ADB2BBB7B3AE948A7C7067646D6F53606A978AA28B7E434043443D3B3B37
383B474B5E425161768AADB8B1A48A7C6344403E323C373B353D3B373440383D3E353F3C
4239373D333A3E443C424850596E7B6B5145464C535D6481726F75836A756157433A4440
3635393338343B3C383836364440423F44474542433F3B3E36383C3A3B3A38453B393C38
3F3A3C3C4152798192878A8787828A6D7D6B717871796F645F5650483F3B463C3D3F4240
4B595E786876635D5A61656268656765675E624F5D4549453C4A4E6367796A625D5E5B4A
514E4E4A4B46464B495D5A5958626A6B6F75736C7374817C878F989DA5A6ACBCCACCC9CA
C7CCD0D2CFC6B7ABB4B8AE979FA3B2B8A9B8CDD5D2CBBCADA9A99E9F9DAC9694949F939E
7E8471735E63616B6E718691A59E937C6D596A83
47474645444444454744434442403F4041403F3E3F41424442434342403F3F3F46484045
443C403B474542403E3E3D3D40453C3F3F3C453F46423F3F42413D3942444646464B504D
48424540474A3A3C474340424242464C4540434E51484345524948413E383F423D3A4041
42413A3B45454543424A5B6B6D70736A5546413F3D3845394635403E3E3E413E413E3E3B
3B41433F3B3C3E3E3B3C383F433E3E3B403E3D3B3A3B3E413F393A3F3D35343B3842433D
3D3F3D3C3B403D3A3C3E3D3F3F3F3E3F3B3A3D353A3B3C3C3B3A3A3A3B3A393A3C3D3B39
403A363B3F3C3D474C49443F3B37373840403D3938393A3A3C3F403C393B3E3F4B403A3A
3A3C3E3D393A3B3C3D3F4041434158644C3A3D3D434444403C3C3E405A5056475C516B54
564E4446423B3B34393D3E3F413E3A3A3C3B3A3B3D3E3D3B3D3A3C4142423F393D40403E
3E3B393B45423C3C464945453E41434240403F3D403D3C3C3A46503E413F393F414D4E5B
7D878D856F584A404341464342433E3F42474343383F404441403E3B424F4A353B3E3D3E
413E3E453D3E4441474348463D3F4447454450605A676D8080888E8F8C83756966544E57
55575553474A4349413F413D3A3C3C414136443A4A353F3D3A3A414242444145484B5467
898893837E7C7A7A7C8992846B574C443F3F3C3E4D4F62798B937E615B3F3B3F3F3B3744
3B3D3E3F3C3E3C3940363D3E3F393F474964748CA5B7CBCACCD8C7BF9D9C7F97716F4346
40414844453E4D405B47524B4B404A414A3D4B49453D3A393A3B3B3F41403A494065709D
ACCED7BB93796240404356435D505C4F463F443E363F313A3B41444648423B3B48373E48
608D8CBEC2C0BBB2AD9A8469514650455040484C5B659D8FA1858C61585752453B3F4542
3E45305460858CA395B0A5A3896261504E455C3C483C4132384041403F4C454B433B4543
463A383C3E3B3E3C40598095A7AF8A7A6456736C91939F877A585E51544A483C303B303C
3737403E433A3B37403B3C3B4747423F393D37333636353636393D37393F3B3E3A393837
3F383B4353738598837F7273686F5D5D4855485C4A5046454A49463D3A36423D444A5251
67676A5D564F5653515760616B6471665355404A3842323A39484C59525A4C454D4E493C
45434642564C50444B4F514B475863636366645D6763685F646B6F7274767C92ABAFABB2
B2B1B1B0ABA29B97AACED4D4C7CBCCC5BEC0CBC9C1B5A5AAC0B4B59BA79CA3A3B3B1BC9F
978798908E9198A19F9CA5ADA8A17D6B4A4E4654
494745444443424142424141403F3E3F41403E3E3E3F4142424241403F3F40413E3D3941
433D413F413F3D3E3F403F3E41474344403C434243413F3F3F3E3A373D3E424443424344
473F3E3B40423A4244404042434248514C4342494B433F414E4446463E3A4041403F4541
3D3E3B414244494D4E5365777C7C8181725B4B45535C5D76544733443A3D3F3F41403E3A
3D3F3D3A3C403F393D4342424543403E4344444241403E3C3B36363D403D3C3F4246433C
3B3E3D3A3B3F3C393B3B3C414643403D3C42463E3A3A3939383839393D3A3737393B3D3D
413D3B3E414141454948433E3A393A3A3F3F3E3C3A3A3938343A3F3E3D3F3F3E4137373C
3A3C3E393E3D3D3D3E3D3A384241555D463A403F3D3E3F403F4044484348405449565552
4442393A3B3B3F393B3D3C393B3E3D393F3D3B3A3B3B3A3936373C403D3938394344413C
3C3E3C3843413A3A44464241383C3F4141403D3B413D3C3A3A484F413C3C43525B6E6D7A
787568513E373A453B3B434241413B3C454B4948393F4246403D3E3E455955383B3E3F41
433D393E3D3D4142473C4342403D43505B6475876B797C8A8076675F5B534A4456555757
50524D4D4141393C3C3E41403E3E3D403E383D3E403D3B414342424040413E3C52617176
7D6C6957524D49474A565D554A403B3C3E3E3C3D3E3441494B50473D483C414C4A414253
5D66637B67735D594A45434A33464F6987A5BACAD0D0D2C9D2DBD1B7C2A2ACA1896A4B40
4354556D7A96889786996C585A625061485135373C39403D3B3E3F4A7258796595829BA1
BAC5BEA47D6161606B72656554645F60586E546B404A3E474E53514D483E393E3E4E677D
BBB7CFCFBFBBA89A917D664548443B423A494256587676945D71514D5F5E584C44444440
40496C7CBAACAD90867C7A574A545475869F9B8052543F3E434B4B4A4750454A403F4640
453E3D393F40576786A1C4CACCAF9683838E89818E9F8F834F5145453A373A3944353E38
3B3639353B363C3D3D393D383B3D3638383C35363B3837363B40443C3C433B363D3C3838
3E393E4E718487736353564840433A3D3D443B4142463B393E3D3B353F3C484D5E68716A
58584A493D5159655D5B6660665B6657423E403538323B3E494F4A4B3F42393648414141
4C4E5547534C404C3E4F434D4F5E69666260594E534E4D44464C4B4C4D5559667A796F73
726F71797D7B77779CB5B2B19BABAEADA39F9F9F9B9296B3BDC3B7C7B8CBC3D0CFD4BBC3
8EAEADBBBCB8BEC3BCB5B2B4B49C965E61434F49
45434242444545443F404040414344444241403E3E3F404041403F3F3F41424244423D42
423C3C3B3F3D3C3D3E3F3E3D3D403F41403D41413E3D3C3D4041413F3E3E3F4245434243
47413F3E43433F49473F3D464C4A494A47403E43464341443F3D444D474546443F3D403B
393C3A3F3C3E444D52576470757980847A655551707395928C50443E3F41414142464440
393B3B3B3E403C363C3E3F41444142505E6F828E8F836B56423E3C40484C48434044453E
37383D3F3D3C3A3D3F3A3B46433F3F3C3C424138393A3C3E3E3C39373D3B3938393A3B3C
3B3B3A383A4144413A3A3836373A3D3E38393B3E3F3E3C3C383E403E3B3C3C3B3C363B3F
3B3B3E3D3D3A393B3F403B3640424B4A3E3B3E3C3C3D3E3E3C3B3D414B44564556394C41
3B403C3C3D3C3F3C3C3C3A37383E3F3A403D3A38393A3B3B38393C3E3E393A3F3D40413E
3E43454148473F3C403F3C3D4040404141403F3F4545423A383C39343B3E4D5F646F6569
4948453D393A3F4843434A49494C494D4C534F4C3C3E3C403F3D4141425352373A3D3E40
423C373C3E3D3D3E42354142505864727F878A8983887572625043484347545F70655A51
454740433A3C3839393C3E444645423E3A373F3B3C3E3B403D3E3E444E5659576C76796A
5D49453B3C3A3E3D393B3F42413F3B3D3E3C3D3F41374044403D383F3D3C3F5161697883
8A89A7AABBA39C829079845F6C6C97A6B7BCBAB8B3B2BABBB8C29A96766B534D4E503C41
54588490B1B2B890A58E8A6D879091777B605143443E454958748DA89D947B946D866379
858F8E84705D5F646B5B6B53655A79728D7691575A3B3C403E4445433E373A4768A79EDC
D1D4C1B28B877066636563544D445143504A4D4E5E5D655154414843423E3B3E44484C51
71949ECEBAB68D847C866D71797CA0ACADAAAE716544535456554A423A41373E363A423E
43404B4C667B8FBEC2DAC5B7A79C7F7B746E786593898F6757363E383835373940323A37
413E4547504C51533E393D39363B3538404033353A373D41444A4F41383C3835393A383C
3F3F485B686C5E48413A403337323A314A3B3F343D433B393B3A3D3C48485457605D5C4D
3F464250516460625C515D4C4E45493D353339333B3A47484D4B413E373D3C3E4845484D
59575E4E494943554C5E515D585E605B56534A41433F3F3A3C44414242504F4E57544A4B
4A4B525D625E5A596E69715C656877767B807A78736B7C96AFA9B9B2CAC0D1CBCDC2D4C0
C3B6D0CAC5C0C6CBC3B8AB9F93A294AC7F997B8C
47454343444443424142424244484B4B42424140403F3F3F403F3E3E4042434344424144
454343424847454342413F3E403E3C3F40404344413F3C3C3D3E3D3C3C3D3C3E43423E3F
3F3D3A3B403E3C434843454F5249434341404042444442404444454A464A4948413C3E3B
3F453D3A3F3E3F44484D535858626968615650526374788B7065454043453F3E3E484744
3E3E3D3B3A3B3F42494244505B59608097A5B2B9B9AE937A66615B595D5E574D3C4A5D61
4F3F3B3C3E3B393F423B3B4648403F3A373D3B38383C414646423B353A3B3C3C3C3B3938
3A3C3C3838444A443C393637393B3C3D39393C40403D3B3B3D3F3E38363A3E41413E3F3F
3B3A3E423C3937393D3F3B37404545403C3C3A36373C3F40404143454549444F4146444B
3B444345443F403F3E3C3C3A3A3E3F393B3A3938393C3E403A38373C403C3A3F43484E4A
424246444646403C3E3D3A3D48433F3E3F3F41444444474342423C3E414045514C51494A
433F3B3D3E4047485552534D4B4E4F564A534D4A40413A3F403D43433E4546343B3D3B3C
3F3C3B413E3F3F48575467677B888C86878F8C7F76755A534A4243564D52647372574644
3D40383F3B4041423D4446494741444242394E39473F494D424A546876736B5E5F5E5748
413B3D39403B3F3E3C3C3A3E3C403B3D3F3B3B3A3D35373D3E3A3B47465B6981959B9F9A
95A8ABDCBAC9A0979295819785AEA8B89D8873675F5F676A8B788661684F4954586B867F
94A0A6A596875F6A5D77738780957979607C6F80868A99AAB7BDBBBDB28A835B5B484F54
4E5D574C48484B4549424250414F55584C4B4944443C403D45443F3D434E6680BCC7DABA
CA908E664D4E45474E64737863584E504A5C62674B503F443E483C3F3A3D4B647A828996
B7BDC5A3A58EADAFBCA5A6908F9887968987746E5E6662695B5240363442414E51535A5C
615D7585AEB4D2C4D4B1A587826C6E636174757A8379645E3E45363A3F383A423D554B5F
6E707E83846B5B4F3E39393B373E3C3C333D394451535E5F564F4C3F363A383734393E47
4347505E675E4344373F393A393E38413E403C3A37403C3B3B383E4241454D49483F453B
424C58555C56585751474D3C3E3B3B37393D34483E564E504B473F3B383C3E4049535253
5D50564F5657615863615C59504C474341403C383A3A3B3C3E4B484B46514D4345474444
4144484A4846494E51494F49585D5B5C53615F5B55505B5F656C67878CACB1B598A7A6CA
B2CEC4CBC4C3C8CBBFAF9C817670A58BA9889C96
4A4846444341403F3E3F3E3C3E434747414142424242414041403F3F414242414342423F
3F3F3C393F40404040414244403C3B3C3D3E3F433F3C3A3B3E3F3D3B393F3E3D3F3E3A3B
3E3F3C3E444240424A45474D4B403D413E42423E3E413F3941463E3E3D464241403D3F3E
434A413C41403E3D40434443404C4D46454645464A4D584D554B4D42444741413F4A4541
46413E3F3F3E434A403C435162615E76939EA6A9AAA2876A5D575251504C464241537588
765641393E3D393B3F3C3A40463B3E3B383E40453A3C404445423C373A3B3D3D3D3C3A39
3B3E4446454D524D443C383C3E3C3A3B39383A3F403E3D3F383A3834353D464B42413D3C
3B393B423B3B3A3A39393A3A3F4040404041414041474A454141403C423D4B40503F4741
3C444246494140414541403F3B3D403C3839393A3C3D3F403A3B3C41443D3A414B4C504D
434247463D3E393940403C3D45413F41434242444940464845423A3B403E3B463F464B4D
453E384141414D464E4B4C433F414148434F454242443A42433E42453F3E3E383D3E3D3E
403D3C43404345587477877D878A84757076746A595B4849474D545F6D5C50554E423B41
41443A423F444645474F4D4C42393E3E433F46494454566E73716E7A7C69574646423E3A
3E41413F423D3E3A3E45403F393D363A403D3B373A3D3D3E3D435765829CABACAAA1968D
A09FBFBCBA98937D857D887E9B82847264524642404344414942555250615679759DA1A8
B1BFC4AE8F6E665B65515B5D525350516083A2AFB0B1B2B8B7AA9F96745B5143383D373D
42473D3F4D534E403C31403540313F38413543414960556259534C556C87AACAC9CD9898
6057443740434446434E5059503D494855495A4B4644454045424648586C8CAEC0B9B0B4
C1D0BAB4A2BBC3C4BBAD9A97938A877C786A716779686F63544E464B5770748386807C7B
84839EADB3CABCBA968F6D6C5B56506065697564765C543B3B3438343D4C436A738A979A
A097968A7E5C473A383A383F363A3D3C3D5E6C7E8C8A8877655047403B3E3B3B3E46525C
4D4D4F5149393C3442373B3A393C3C3B3C353F3D343F3E403F3A3E423D3F403A3A384B48
52615358434F46534A4843383C3B3B3A473F4F45584E57474746423F3B3D40444F595453
594A534E5458524E484E3D3F413B383B3B37373A3637383A3A4945494D4D463C3A3C3B3A
36393A38383E464C49493C424957535B4E4F5253504D4C47454248495E627364666D7E7E
8C92A19FA3A8A7A5968C876B626763795C84758A
46454444434343434243413D3E4447474041424444444342424140404242414040414340
4146433F3E3F3F3E3D3D4042413D3E3F3E3D3C41423F3C3D3F3F3B373C464742413E3A3C
3E423E404645434250423B40433D3B3E3B403F37363D3E3934423E424650433F3B3A3F3B
3D44403F393C3D3C3F4443403C4642383E47433D3E4342433E424347464D4A4D4951473F
463F414C504943424444434251564B544D52545866726A59443F40474742424849547692
89684D3E3D3E3A373B3C393A423942423C3C383D3E3C3B3B3C3D3C3A3C3C3B3B3A3B3D3E
3B3C464B45403D373F36323A3F3C3A3C3E3C3B3E3E3B3B3D41423F3834373C3E3D3D3837
3D3A373D35393C3A36363C4149434446413E41433F484A443F3F3C364640403E46484847
3E433E43483F3C3C4E4643403A3C4140383A3C3D3D3D3C3C3B43494D4B3F3D4A534A4642
3C3D42403939353740413B393E3D41484B47434247343F4743423C393D3E3A473E404645
433C3745413E4D4141404642404241474350413D4243353E453F4248443F3E3F3E414143
443E393E4547485E7C7A7C6564605D5E5F5A514A4B50464D4E5E65635D5244453D444B58
4B4D3F464142433F3C403C42444145405847574C55546681917B5B534D41403B423D3B3B
3E403C3B34383D33343F3B3D4345373A43403D35383D3C45526B898DB0B6B29B949A9CA7
9CA4A9B38779635E5F5F4C5C5C55464542393A3A393F413D3B3A48373E3A414C51777780
7CA1A1A2898788876A56453D3F47588892B8B6AEB0B6B3B19B775F4B463A413F38403B3F
383B3B4D55463D3E3F3F3F3C3F3E40413D4E7293A3B4A4A492959EB3C7CDCED5CC968B5D
53544C53433F3D3D384A51646E504D4F4A39473842404D52575C7D93B5C2CFD9D9CBC6CF
DDD8CDC5CFD0D0BDADA3B8C2C0B5907C6B56545F5A484D5650535A6F87A3A5B09A8D7A72
7E859B9BA6B4AE8C7D5F52524F545F72706A6D5B543B373F3C41425264687E90A7B1AAA4
988678665D4742413E494A513F3E47496D9CB0BCBEB09A7566524E4A413E3E444E586871
555049403F424D544F4E3B39393A3B373C313F3A404947474439373839393A3941455B57
6D69584B49473D3A353C31313B3E4445464B4E55484D453E3B3E414140434C5457555053
564C5B4F504348334434383D39363A43433C3B413D3E3D3E3A484449443D3938393B3B39
393B3A393B3F3D3838444B4762545953644D4E54534E454442474149484F4E3C47564E4D
455E6269656D68655B60725F5F4F5C464D535855
4543414143464748434241424446494B49433E3E3E3E4043403F3E3E3F41434544444444
44434241403D3E43464544463C3C3D3E3E3E3D3D3A3E41403E3F41433D49534E4036383F
3E413F404849474A4E4C4245433B3F3B3E42423E3C3E403F3F3C403C3B3D393B3C3A3D42
434242454938403D3E473E3E4047453E3D3B393B3A373A3D3B3D41413A424B4E4C474546
3F40474D4A414148383F3F414A4E4741494343493B434541453D3B42464242454B56616F
786B524542403E3D3F403D38363E3C393C3C3B404141403C3440383D383A4045433D3A37
363B3D3B3A3C3D3B373B3E3E3F403E3B3A3A3A3D41413E3B3B383C3E38383B38393F3341
3542393C32363B39353C423F4344423F3E3E3E4040413B3D3E3B3E3A423E3E4345413C3B
3B3B3C404445423E44433B373B3C3C403D3C3E42423F40454450595A43444647423E3D3E
3C393B403A373B3C373A403F3D40424040424341383B3A3C44423C3B323D423D3C414340
3B3B413C3A3F424C5A4644413F413F4343464644434443403D3F3D48483D41423E434742
3B393E45413A4451545959515764666C6248444B444A5256534F4C4B45433B465B575F4E
504645433E464B42383A4040393A4040434E4B3D4046465656463C3C383F333A3D403B35
3E3A3F433A39413C3E403D3E3D3F3E443F3B433D4C5D5A755E8A8AAD9CA5A69F91909A94
998377665248403E40413A4143373A40393C3A3F3B453F403C433E443C413D3D423E433F
414D515D807CA2878C5E594143587289A7B6BABABBBEB6A67D4F403F3E3F3C37393F383F
32425356483A373A363B353B373F424A528EC3C1CDCCD7CDCFC6C5CEDADCCFC49B908077
87A887854A4642423D50727379574B414D334E5455697090B2BFD2D5D8DCDBDCDBE0D1DB
D7DACFDDCCC9B9A998A2A1A09E8462553B3F3B4C4241384761717A949DAAB3B4A38B8570
6F7E7E7E738B707A4E5650574A6A6F725F4D574540413B474B64647A8591A3A6B1B6B599
795D554C5040454265688769845B7483B0C0BCB4A5876E60484C384037454A70637B655D
505B4F4D606D755D4F49443D3B3240353F40475D6A544639383C35373E3742514F6E687A
706854533737393A373A444256515C51534B535150423B3F414F55594E4F4847403F3B3F
424C5257473B3B403538353C3D3E393E4139524A4B3D43444E55534C3D383F3C43423B38
353C383339364045495756595352525D535A50514748433D4641424644464B4D3A433E3D
403E424242403E3D3E424649413E423B383D3D45
454442424446474744434343444547483F3F40414040444B434242424344464741424242
4141414142414449494441403D3E3E3F404243433C3C3F43413E40463D4349463F3A3C40
3C3F3D3E454644464B494042423E454543423F3D4045433F3C393E3B3C3F3C3F39383A3F
403D3C3D423B463D363F3D443D403C393F423F3E3936383A3C413F343F40414142424242
413E3F434139373B414240434A463D3B3F3E454F4447423A3D3C3B3B3C3F444A4B505256
5F5B4E474F555D5E53433C3D3D4F554C48494D53443E3C3D3B443E4453493E393A3A3E46
393D3F3C3A3B3B39393C3C3A3B3E3E3D3E3B3A3B3E403F3D3A3937363B3D3B393A383938
3D3B3E3B393C43453E3C40404845424140403E3D3E3F3A3C3E3C403D3C3B3C3E3E3C3D41
3D3B3A3B3F4344453C3E3C3E45464242393A3D4244444548484F47443C3F383B3D3C3D3E
3D3C3E413D3B3F403B3B3E3C37393B3D4144433E383B39393E3D393A393E403D3C3F403D
3C3A403F414542454B4045433C3A394040464A47434343433D41414741363C413F42433F
3A383B3F3E3846423C536367837C6B5F54484A52524E484341403F3F3D4544494E44524C
43393B41465255493F3E41413D3D40434C45403A404542493D373740424C3F403C3C383F
3B4534403A3D3A3A3D544C474546464F50515852756A7058615F737E8B98968D7C6C6257
554A4A464143414142423D41433C3A3F40413B3B37403D3E3E3D4D454E3F413B393B484F
5B6B737E817984685E45464448565D74869C9B9F9BA3987F5B4242443D3845384B3E3D3C
485A594235393E3C3A403D3B32496C8AA8C6CAC4B9C5C7CBCAC7C4BCB4AA9E9690828D70
847D84645A544D473F465451544B545C6B678B9CA9C1C7D2D3CEDDE0DBDBD4D3D2DCD9E0
C4B3A49B9B8D877072746E63584C413E38383E46463B3A504D606F8B8D8F949B97846A5C
4B54504E525A465340504B5046505D574D4A4444403F535B797F8A9498A1AAA9AEB0A58D
6F5E514E43414A55708B97A8A2A194A3999A7E6862524644443E4F3B6B5C9099887E7166
7C6E76767F6F6B44484337363549475043615677584D463C3939374356516B6280667862
50474140433B423C474D5755645A615457524E584F5443484148494E45463D3A363B4746
545455494035323C363E363C3D4650514D494D444041465146534A4D43413B443E4C3E41
30393C2D3E3C51505C595C4A574B595C5E6254534746454348403F4343413F3A37413C3B
3E3D414134343536383B3E3F3C3A3F3A383B393F
4C4A48464543413F454545444444444440424646413C40483F3F40404041424243444545
434345474445474A4944414042413E3C3A393939403B3E44433D3F474443413F3D3C3B3A
3E3F3D3D40403E3F41403A3D3D3A40434B443E3F474D4A423E3C3F3C3B3E3A3C3D3B3C3E
3E3D3E403A3D4A3F363D3D434D4E474043423D3B413D3D3F47524E3D46423D3D40434241
443D3B3F403D3B3D49433A3C413E3C41403D40463B3C39323A40423F3D424B504D4D4745
4C514E4A525158605B4A3F3F49595E585B656C6E4C423D41424844497770605145363442
4243413C3A3B3C3C38393835363B3E3D3837373A3E41403F43443B3740443D3A403F423D
3C383C3F3C3D403F3E464B47434141413F3E3E3E44443D3E3E3C3F3C3C3C3C3C3A3A3F45
3F3D3B3B3C4043443F3F3A3C45464241404242424242403D454C3C393E42363D3E40413F
3D3D3C3B3E3E42433F3E3E3B41403F3F4346433D393B3A3B3E3D3B3D43434241403E3D3C
403E434242443F41443D43433B38393E3E464B48424244463E4040443E353A3F3D3C3C3C
3C3C3E404B454A3F4A6E7A7D756252433C4041414C463F3E424545423A46484742364444
4942444A515E6257494746484946454945383B3D3E42444B443F3839394741424040403C
4C354841464955455B6C7871737676787471746F5C574A4D45585661767D6E5E5547413C
4640433F3C42403F3D3E3D3E42453D4144453F3E3B42403D413F47463C3C3A4A4F5C7584
8C8A7E79756D665447454D60837E7B687062605A656C6967655F5847524E5D545D473F3C
424C473A3A3D3C3C3D3F4751567BA7C4DBC8B4847E6F8591A6B1B8AD9E8C83796B825962
4C57414A4240403D3D3F3D403D5985ABB8B9C7CBC9D8D6CEBDB8CCD1CDCFCDCFC7C6BFB3
7D775D664D574B483F4042403F4445403E4847514550517C6974768070686D7D876E564D
6061786F806A6247493E444649544B4E463A423B495A679797AA8E979290837D81867260
665B4A503C474B5B869BA4A399897C7C6561493D3F424A4C6380698E7B9FA2AF99957296
85896B785C5A463C41333E4A7A62805C7166745646433F3A3C42506C717D718666664C40
424E3A534658525F7171706466575E55564B584C6055544A4E4B4449454944464E535059
5256463F3D3B374443504957516352554A465B4D4A3D4C40534C51485C56614B4C3B3E3E
353E3B484A4C51585C604C59495E515C5A594C524D4E4D4C52443C3E3F403E383C443D3A
3B383A39343537383838373637363A3737393638
454545464848464543454644444544413E404445413D4148424343444444434342444645
4342454843444545444344474241403F3E3E3E3E413D3E42413C3D43413E3B3B3E41403F
41413F3D3D3B393941424245433E404248413B3D464B4842403D403C3B3D383B413E3C3B
3C3E4245383D47403E453E3A4349463F3E3E3D40443C393C444F4D4145423F3F4242403D
45403F42434242444F483D383A38363B4B4645443C3D3F3C373C40413E3F444840413D3B
4047453F4A403D454C4A4442454C525C6C756D5E504B4544434645475C656565624B3D47
4B4B4946423F3D3B3C3D3D3A393C3C3A3D3D3F434544403C41423C373E423F3B363E3C48
374744565B6977797A7B633E3B393C3E3A3A3F413E3F3A3E4141474541403E3C3B3C4044
3E3F3F3F3F3E3D3D43423D3F474842404042413E3F42413C3B483F40414239434044433E
3B3C3B383B3D40424141403E43413D393A3C3C383A3A3B3E4344413F393A3C3F3D393A3E
3F3F443F3B3E4049483F3F403C3C3E3F3F444743404244453F3C3B40413D3C3C423D3A3C
3E3D3C3D3E4F5450636B59555345453F3F4C494245413C3D4143413D3F43404140393E3A
4743444342494E49534E484849433E413F3A403E3A3B3B413C46494D474E443F403F3F46
34554A5F565E5C645E766E7466737B776759524E4F435742634D5C4E53584C45443F3F3B
3D3A3C34323937363A3C3A393B473B3F3F433F404246453C423D404233444C73888D969C
9B948882877D7567605D60715C615356484D3F453C4241474B4D524D7B8797A3896B4037
3D413E3D413B373E474A678497B7CDD3CDB28F70524F6183AEBDC2AE967768574D424245
453941413C3D3F3C403E3746577EAFD8D8D7CCC3CAC6B9B3AEBAD0D0C4C5C1BDA58F7D5D
524841444141403A4244403B3C43474769678C6B967894A39B9B8A80707688A4B0A07A8F
95A7A9A599906E7A4E6E59796569504F474A6F678381B1B0CE9E8C736A6A5B504B53494D
4E4B4F6467747476767F8A7B7453504845413E4344597679979DA7829E85A5979E938C82
825A5048473B413A3C4D5E8E849A818F6A8A60694F4D4644484A5772887082605F494748
52585C566A59626664615B4E4E45514F5257505E526752533E3E3E4F545F61686A5B6254
5E41464248475046514C52616062645E545E525243443B4C425F58655860545D3F53475A
504854546C55635F5E515F465E4B57504B493F5053544F4A4E403A3C3E41413D3F463D3A
3A363735393A3B3C3B3836343635353537383535
44444547494948464145464444464541494543413E3A3A3D42434444444342413C3F4140
3E3D3F423F4142414142444541414141403F3E3D4141403E3C3C3C3D4745413F3E3D3B3A
4140403F3D3C3C3B3B3A3D3D3C39383C403B383A3E40403E3C393E3B3C3F3C3F403F3C3A
3A3C3E3F3A3E433F434940383C43423D3F404144453A383D3E3E3E3A3E3E3E3E3D3C3B3B
41414142413E3E413C403C3A3F403C3A3C3B3F403F3D3E3A3F3C3E43423D3D433A3B3C3D
40444038413F3D3C3E424445413E43515E5D5041484D4A3F3D3F4441394758718679625F
525253524D443B353D41434241403C373C3B3C3F41413E3A3D3D3F3C393E423E494C4F64
617C7A8EA1B2C1C2C0B9976A443A393D3C3D403F3B3C383C3F3F4543413F3C3B3D3F403F
3C3E4041403E3C3B3E4243474F4C433F3F403E3A3C40403C394040443B3C383F3C40403C
3B3E3F3D3B3C3D3E40403F3F3C3F3F3B38393B3B3A38393E4244403A3A3D454A4742464E
3A3A403B393E424D45403E413E3D403E4142403D3E414341403C3D4143423C3A3D38373B
3E3E3F414B6D706A664C3B3E3E363C37384545404A46403D3E4246484340393E41423F38
3D3E42464B545A585F564B45413C393B3A3D413D40443E3F586E7779675F4E4242414238
4E4D7666775A5340493E44484751564C413B3A3D4347444E47483B353D403F43403E4036
393A3D37383F3C3D3C3F3B383643383D3E444248555C6053503F504A5D6988ABAAA9A5A2
9B90867E7F6D6B565747454450494A3C4B3E403C3E45403B39455E6B788698A7886E4743
3A44423C434F596169698694969A958B947F6F644B4A547691A5AE9B886E6F6465464945
46473F443C3D3B353C3E436495B1D4E9DBD0B9ACB6ACA6AEB8C4C6B5969393917F6F674A
464040413A3B40453D4744404D60768CA0ABB3C3BFB292987B7C6A6165849FBDCBC1C1B7
BFA7A79D9D89A78CA87E867C8B7F7A6E6D90ADA9A1A7ADC2A69563574445403E3D463C46
4C4B5F6E807C78686060505A443F3A3E3A3B4658617A98979BA88883738E848C7B7C6365
4B44383F3D393E3959558984A0788F6A7F65764D414446515B57575F594A565F565F5263
53654F6B5E6343473C3C3A383D3B494A4B45533A494049433A424D6161635D605958565E
524B47515161556C536D59735D644C5B5852554846475D4854495E686556564552525B5D
58584E5A5C6565615D5F505B3E543F4B494941504E4C45403C363A403F3E3D3A3A413A39
3C3A3C3A35363737383837373937343537373836
49484747474643414044454343474642433E3A3C3F4042443F3F4040403E3D3C3C3E4040
3E3D3E3F3D40424241413F3C4040403F3E3B39384243413D3B3D3D3B4242414140404040
3D3C3F403E3F4241423D3E3D3D3F40473F3E3D3F3F3D3E403E3B3F3C3C3E3A3D41424240
3E3E3C393C41403C4044413F4447423F43443F3D433A3D45423B3B3B3D3F3F3E3B3B3D40
3B3D4041403E3F423D433F393D3F3A3741404543464243404B413E43433D3E443E3C3E42
4344413B3B40434240414242433E424745413F3E3A45453A393B463F3F526A84968A7064
5B56504C47403C3B434A51555858544F45403B393A3B3B3B3B3B444A48505D617E717C84
99A5A4ABBAC1C7C1B6AC9A835E483E414143433A3E3F393B3B383A363A3938383C403F3B
3C3C3C3D3F4141423F43434346423B3A3F3E3D3B3B3D3D3B3C393B43383E3F403E3F3F3D
3B3C3D3D3D3E3B3B3E3E3C3D3C4347433D3B3B3A3B37383B3C3E3D39383C41433C363840
3D3B3F3C3C3F3B3E3A3D40443E3A403D41403C393C40403D3F3E444341403A3B3C38393D
3F3D4046586456524B37383C3E3D403C3A42434254514B45403F4144413F393E4044403D
404041464D535047574E4740393C43433C464E484A504C50616E655D48464544473E3F4D
4A79747553463C463B3D32413E4040363840404543463C443D403C3B3B3A393D38384039
37393D37383933363C453F413A4740484D53525E788795877E69686A7A8B9AB1A89D8779
6E66645F5A494F424C484B425049343C3C483C403844413E4555656268687B776C564A47
444C535C728E98928D7F897D746D6159503F4D48493F424E617D928C86738685887B585C
487142553F413D3F4F5A73A1C8C9D4CBB8ABA4A2B2B1B9C9CEC0A2856A68747870605741
3E403B472F46506D5B58494C6D91B1CFCDC9CBC0AE7B635D49514B4D5F8391A4A9B8BBB7
988D7C8A868D7FA28985594E5268859FADC1C8A69B88A17A875658433E383E454E503A38
3B384A4653484D404A3C323C414054546266687480898F878D7E9364916E7D5F4B4B3E45
3C3A3A403A3D4152568B877E7080626C4557415B43454751534A43393F32524E71485A47
555957515E443B343837343941424E4F52564A493448414F505A606B615C51514B4A5A46
5341514C5B5468546954595460504A474E57484C48514F5F5666545C5C5E4E63516D575F
5951574F61525F525A4D6449534046414C50474F474441403C393D413D3B3C3B3B413A39
3C3B3C3938373636363738383C3B353638383C39
4444444547484846404546424246464145403D3E3F3F40434343434241403F3F3E404242
42403F3E3E4141403F403D393E3F40414243444444413F3F3E3D3E40484542403F3F3E3D
3C3B3F413E40444340383937393E3D4542414243423E3D40403D403C3B3D383A41434340
3F403F3C3C403C3B3F3F3F413D413D3B40413C393D373B413E3B3B3A3D3D3E3E3D3E4042
3B3B3C3E404242413F403A363B3E3E42423E3E373B373C3C433F3C3E3D3A3B3F3F373940
3E3C3C3A3B3B3E4243424040403E444743403F3B363F403A3F3F4B44475A6E7B7C705E51
554C433F3E3E414550586064686A67625951473F3B3B3A393B3B414A505969777E6D777B
8A8D80828390A1A6A19E948571574A484242433C3B3E3A3D3F3C3F3A383A3B3A3B3E3D3A
3D3B3A3C404344444347453F3D38363B39393B3E3F3E3F413D3839443A4143423F3E3F3F
3D39383A3B3D3A3A3F3F3C3E3E42433F3B3B3A38413E403F393E494C444444423E3A3B3D
413E433F3D3C3536363A3C423E3C443F3E3F3E3B3B3E3E3B3F3D424040413A3B45434547
433D414B514D3A3D4641403D393E3C3C3D3B3C3C3D3F414242413F3E3D3E3B403C423E40
404040424A504D48434148473F48544C515159524949494C424A3E3E38455258594A4D4F
5651645046444E43443E4144444B504B5054484547433B363C37403C363A383C3B3B4445
4240403A3B3C384245534C53474D4A535B615D698897A591746D64797989848F6D645048
45414540433A444A4A5D5E54564A40374441474B4D545051575C5E5250454B474C545D62
6D6C788A99A49E88806A664F4C493F3D42424D66596C545B5F768A87856E8281795E6C61
6E7C856D65655D6571738BB3B7988E74747185918B93A4B7BDA98B7B5A55676B65514336
4438444552637F95907251557CA3BED1D0D1BDAD7F5D4F484D5149464C5B50586C727862
5A4A484E53614C66534A433C4A7F99BDBEA79D6F525059504A4C5051554E6265655E5154
484A514C4641413A39394A5D706E8C848388848991908C8270766E896971533F3C3E3B43
44434A4B646C7F758B7180576150563F4B38473A434443463D3A3F34404B49635258504E
515A45514042343D373635404B4D5351524B534045434F555E625E5C4D4A413F464A4D44
47474B47555B4E654A654E5852554C505E585244584F56506861564B5456616667675B57
51535760585154505251545B475440454B4E4349464A4741453E3E3E3A383C3C3D433A38
3B3939363B3A3837363738393C3D37393A383E3B
4645444546474645414646414146454042403F4040404246403F3F3E3D3C3B3B3C3D3F40
403E3B3941413F3B3C40403C3F3F3E3D3E3E3F40463F3D42423E3F4547423E3D4042413F
3E3C41423D3E4240423A3D3C3E423D43403D3D403F3A37393D3A3E3C3C3F3B3E3C3D3B37
383D41403A3D383B43403C3C3D45464242403C3E423E3D3C393B3C373636383B3D3D3C3A
403C38383C3E3B3742403B3C3F3B393F3E3B3C353C383E3E3D4144424040404043383A43
413C3D3D413C3C41403C3E46483F3B3B3E4541333B3E3E3E4945504A50565D5E5B584F43
413C393C3F4043464F5458585857534E48433C39393B3C3C4C473F3E403D42534D494E5F
566349544E5A66676B797A6C755F544E3F3B424341444043433F413C3B40423E3A3B3C3B
3D3C3B3E4244434140494C49453F3D42403F4144403937393C3A3C463A3B3A3B39393C40
3F3B3A3D373A383A41423F414444403D3E44474648474A463D4459654644414143474848
3B3D44403A3A383E3C3A353C40434B423B40413E3C3C3C3B40383B3A40473E3B3D40484E
4C4A54624A4F4038423E3841394138393C3637383A3B3D4144433F3B3D3E3B3F39403B3F
3A3D3D3C414A5053484C6064586068585A474A4A4143413C3E4438413F4950504A3A424E
3D3F45473A43483F3E4D4740464D514545473C3D4B443C363F363F35383F39393E3F4C56
4F49423A3B3C3E4E55675C64514E4A535D6058607A7F85695457666E7460574D42433C43
4845463D545255634A6356483D3E393A3D455062665F555C645F57494746465E5E7E777A
83828B8B7C776E58534549373F423E445B5B737A7A81706A70787B706D50615A555D4661
5E7F7C7C7875686E6F5D667F75535C556F67706F74777F898E7F6E7160515A5451423D3E
403F485C5B798AA89D79606B8BA5B1B5C5C0CD99A570875647463D3C41493A4643433938
41483E38456B577347373A3B7695A0927A5E4B45534F6B52605469626F6076757673727A
77858B9682816D62577571A37E9A9B9F808B959E998D83706D5D766B6B4866443E473E46
455E717B86898787755A4B453F493C4143483B3B34393D3F343A4F494F4E7A575B464741
4A483A3F413C373536393D505A544E4449494D4F4C56565F383E3C3F39413C3A3F3B4942
554A5148544D544B45495154534F493949514F4B4D535555545A56624D514E625B6B5555
3C47554C4944564E60505A4D4B4D48474B493A444A544B3B413A3A3C39363531383F3736
3B3A3B383434333435383A3C3B3E383B3B383E3B
44434143484B3F43484C4242443D403F3B3E4C40483C444042403F43463E393F42403F3F
3F3F3D3A3E45413A3C3D3B3E3A383E393C443F423F4443403D3E4148454B4640413E3C42
443F4244404245403E3E3E3B38393E4246414042413C3A3A3C3F41403E3C3E403B3F413F
3A383B3F393F3C373A3B37383C403D3D423F393C353A3D3E3F4142413B40403B3A3E4242
3B40433F3C3C3A373C3F3E3A3A40413F3D3F41403D3A38383B3C3E3E3D3E4042423A3E40
393C413A43403E393E3F39403D41423B3E40373A3A42423E42484D5551524A454B4C4239
3C3D42413B404745474446454246483F42403C3A3A3B3E403F454440413D3B40363F4044
413C44443E4044474A4C4D4D565053505245474A40463C3C3F393C3D383C3E3C3B3C3B39
393E443F4961758F73737172705E49434B403C3B3C3F4741403E333D3736373D3942453C
3C374747434D3E3F3F4D434649433848555252473E41463A46425C59424D4846494F513F
3C3C393E364345423E3B433E3C353D3B3B3D3B48493739413D3C3D3F41423F3D454C4E4B
51524B4A49453E43414045393E3B38363F42393D3C3B3C4047443B3E353B383F40403739
403D39484F5D60665F5A54544D494D44413B404142413C403F353943423F41433D3D3D3D
40403F3E3A3C4E514B4B454441474541423F3F4737413F373738393A3D34383C3A485B5C
47473E3739404A5758505C5F50464754545A666D6F646D62716B696150474A4C41434A48
3C3C4446565B60544742433C374544534E686F7D726F7A6B655A54504C435E67716E6D7C
8B897867574F545355494C5042494869596A64746176707B78816F5C494D524F5545524C
59595D504F554C57595C5E66676C6C756C6E6F7A606E5F6D5C6864645F58584A4C414745
3D425858595E637A6C6A6B768690929298B6B6BA8D845A494039343D414C3C443F3B403A
49414B44575D775546393E45496B6350483C55877F9C898A64644C5C4B49506054576880
7F85ABADBFA2A18BA599B9978E7682838790968F8379726E6662665A56615A644D4F4952
546C747C8B8179614C433C423E3C3C3F403C39383943393C3B39484555646E5B48423935
393939343541473F383E454B4E4E4D4D584C524F5F4F4C40323839403A3E3D4344495459
57544D3F44494C3A3F4A3F4A3C4A484C5A605A49534B5454574F534C48494F594F595345
4047474B5845444B55575C4C4E4946493F49403943423B3F32363531343B3D38353B3D38
383A38313C383536393A37343435363738373534
4F4B5251696B646064634E454746453E3B413F443C43444B403E3B40443F3B423D3F4040
3F3E3F3F3D42434243413E3D3C3A3D3739403E403D433A4937463B403D3F3F3F403F4046
423D3F424042433E424343403E3D3F414040414545423D3B3E3F414242424242373A3D3E
3D3D3F413B403E3B3F403D3C383B3C3E41403D3E3A3F413E3D3E3E3A4042413D3A3A3C3C
383B3D3C3C3D3D3C3C3B3A3A3A3A3C3E3C3D3D3C3B3A3C3D3F3F3F3F3D3C3C3C3E394044
3E40433C3C40423A3B3F3A3F3A3B42403F423B383942423F4244454946473D363E45433F
3C3D403D373B403E3E3C3C3B393E413B3939393B3F424445363C3C3B3C39383D3D414141
3D3A3E3F4243444443413F3E423C4140463E454A464A403E3F393B3A3C40403D3B3B3A38
3C3C3D3B4B66798E87796C6E6C5948493F3F3D433A423D3F40413A47423D3A3C3A3F413C
3F38423E3E42473D4351605D4A605C70674649363D44363D36444B503F4540403F40433C
38393A413C4647463C363D3E464444383D413B42464041433F43494A48433F3D393F4042
4948403E3F3D3B4347494F463D3D3F393B3D383B3D403E434C473C3F3E3D4652695B5953
3C434E6871776B675250484743404541443C3D3C3C3D383C3935393F3B393D4037393E41
3F3E3E3C403E4A4A43433C3B3A3D4145453D37383B3D3B3A3A36363D3935383B373C4340
3A403F3E454E5D6C6B5B5956504F4E514F566570766E74686F66615A4D44424040414447
4545474547445039403A524E54617573766F7574686060565851545A55595D6D6A7E7189
6C6A65696C6F736766525748504E4F584F5869676F6C73726C645A434A43544E43403B43
3F483E494C514C5B5A58535462615A5A52595F6B646465575C4C5850464644454950514E
46564B5C4B654A685753525760696D6B85899481755244353E3940464D473E47433F485A
5E6B637155594E493B4B313C404E4F5966687686968C785A54483F3F3B3E3F4D484C5E86
8F98A6C9ADB396A4A1B0AEBA7F987E8C7B7A7770696562606A59624D4858665A494A5256
606B6D6D615C5953504D4745403E3E403E3B3F464851464644414F4B575B62513D3D3D3B
3F404343444B4E48404246484948494A504D564D52404038373D393C3845474A54555753
4A4949434C51533F404942514B5A5C636E6E67585B57605C594F56554E4F545A4849443B
3842484E5B4D525762626452534C484A3E43413F4340393835393835373D3D373A40413D
3D403F393A393738393938353636363636363535
66737C9098AA9793918C6E544946443D41424D464C42494747474343433E3F4A43454543
403D3D413F3E43494845423E4041443F3D3F3A3849414A45453D443B3E3A3D423F3F4344
423E3E414244433D4443423F3D3A39393E40414141403C373C3C3D3F41413F3C3D3E3F3F
403F3F3E41413B373B3E3E3F3A3B3D3E3C3C3C393940423D3C40403B3D3C3C3D3B39393B
3F3D3C3E3E3C3C3C453F3C3D3A3434373B3B3A39393B3E413F3F3F3F3E3D3B393D393D3F
38383B353940443939403A3A393642413D423F3A3940413F3F3E3C3D3C413D393F433F3B
3B3D3E3B36393C3B38383D3F3E3F3E383B3B3C3F4242413F4143413D3C3B3E433E3E403E
3D3F40443F404142434241403D383E3E433B4245484A4240403B3C3B4043423E3B3B3A38
3B3B3C3D4D5D6066625A4F4949433D3E423E4B3B443F434A5652434A413E3C3E413E3D3C
433B433E48573B5067A09DAC97865E5849323F3F42433C3A3B3A3F3E48483E3C3634373B
3A39393E393C3C3C3E3A3D393C3D3E323D45403E4242423F3F43484A49443E3A3D414243
434041463F4041494A474439404148413C4142443C413E444F4A40403D3F576887635E4E
4B535B6D6965544F494A403C3A363A3B443C3D3C3E3F393A37393D3D37373B3D3B393E40
3A3A3E3D3F3B41403B3D3A38403E414543403F3E423C393E4037364245403C3835363838
3B40403E414651616A584F45444A4643434A585D61575D565C524E4D47423F3B3E3E3D3D
3F3D3B3C3A3F3C464361707A738285856B645A5D515356616D5E585A676C84687C646266
595E677A888C88756B534B3D424441464E666084688269705C5941463B4542444C304A39
453654525F58474E46434041504F4846444F575F5E61545947474347463F483C544C5548
64506E566B5E66575752525354626C666E6F71706454464139444152424C3C4C443D4A4B
735B796B624863546F69715C55596470676169636E6854523E53444E424A485159708095
8D818D889265878AA491C186A47383626C6764656765605B515341434860524F48545A70
6B7E65666E706D685C4F4944423F3F403C3A45555D61544F49444D49443E453D30394447
4E4A4B4C4A4C4E4A474745434141424445464E4245383C37444A4445455759594C44403E
3D4448444B4F5448494E4B5D536061676E6B68636963675F5B5056575552545B4B4A4745
50555755594B4D475B58584548423D3D3B373C42403F3F3A41423D3635383733363E4546
46453F3738383939393837363837363535353535
A2A6B5A0A9A7B2B2B7B7A38367534C4D5562807989787867626767615748444B42434243
45413E41463D3F44413F403E3A3E4241424646454842434B3C42454344393C423B3A3F3C
433F3F424547443F3D3C3B3A3B3D3E3F3F41403D3E41403C3C3D3E3F3F3D3B3A45424040
41413F3D42403C3A3C3E3D3D413F42413B3D3F3A3A42433D3C41413C3F3D3E42413E3D41
45403E41413D3B3C413E3C3D3D3A3A3D3939393A3B3C3E3F3C3B3C3E3F3F3D3A443F3F3E
38393E3C3E3F423A3A4039373B39403C394040403B3D3E3D3C3B3939394345424647403B
3B3E3E3B393C3F3E403F3E3E3E4041404140404041403C39383A3A39393A3D423B393F3F
434B494F4240404041414141433E4645463C403E43444140403E3F3F4043423E3C3C3D3B
44474747505249444347463F3B3D4043414749504D64576D615A46473D3C3D404D46413F
453C454472524D476884A1929B684B43494738413C3C3C39403D454A525245443E3C373C
403F3F413D3C3C3E4141433E3A3E433D3842423F403F3E3D423F3E424848423C3C404044
423C4146423E3B3C3E40413E42414840373D3F3C3F403D434945413B44464F536243453F
44494A5147453F4342483D393A35383C413C404145473E3B3C40423D393A3D3C423B3D41
3E424B4A3F393A3B393B3B373E3D403E39404845463F3A40443C3A4441403C3A3B3A3635
383A37373A3D444F4F44413B3B413F424649524C4A424A4A453D3E413F3E3E3B393D3B3A
3E3C3D474840564A6D6B8980777C6864434C475663787A7970585D6E6F83767A57644B62
495C6B7E8B8880735E47433E47485060756F705F5F4F524C48453D373B37403C414F4154
4B645778534939423D3F4141494C4A47474D4E4D4B5242553C483C494A49444F515A5453
566C52725C8754685B575A5753626E666D637657725565534A525541403A3C3C393B3D4B
446958665B69537D7BA7819565697B87746E7B757A628450623C4D413F4340444A6C7A78
6C5352484751637D8FA191AB6D8455593F3C3C4247453D383E474944645248454E4D5C5B
717B797A80888379644E4B46443E3C3D3B3A46575C5D4F463E393F3B37323A3A38434C54
51474444404146484746423E3A393B3D3C393C34404146404D4F484B485049453B36383D
424C524F4E49494443424359535E5E63655E5E5E6D635F56574E515059514F5C54565151
5E5E5C55574E5042514D4D3D43403C3C3C3037403A3D443F46443C333134353330394144
4441393034363939383636363837373635353434
B2B6A692717F7F8F8D96998D775F545C86A6BECAC6C6AE967B83858175604D4A42444751
5C574C4A62534C49424348494C51525253575C5C56484851484B4A424A3C3E433C3E453F
413F3D3F4446423F44413E3C3C3F42443E40403E404646433D414444413F404243403D3D
3E4041403E3D404444423F3B414043423D4347414146463F3C3F3E393D3B3D403E39383B
3F3B3C41423E3B3C4143413D3B3B3A3738393B3C3D3D3C3B39393A3D3F403E3C3E3C3D3D
3B3E4445423F433E3A3B383C3B3E40393B3F3C423E3B3A3A3A3B3C3C3B44433E41464646
3D403F3B3B3D3E3E3A3D4043433F3B3A403F3E3E3F3F3E3D3B3D41423F3E3F40423F4544
484E4A4E3E3C39393C3F4142413B42404039403C3E3D3E3E3D3F3F3F3D40403E3D3F403F
3F423C383C3C3A383B3A3C3E3C3A3F454F485643544C43464A4B404740403E3E3D3B3D40
4A4555584F543346405E5776543D44505E5D403A3940344134423D53484A3E4141493D3E
43464A4A4A4543444140403E3A41474543423F3E42413E4345424043494A45403D3F3E45
43383B383C3936353A3F40433C3A43413D433F39403E3A40403F44383D454349483F3D3F
3A3A373F3B403D423D443C3B3E393C40423E424246493F3C4144413C3C3F3E3A433D424E
53565855423C3A3C3B3B3C3437424B443B444B4443403A3B403E3C413B393434393B3A39
3837353B444341463E383B3C3F42434F4441443A3E393E403E3A3D403A383A39383C3D41
4A4B4E595C64647467756F6F665A4E3E3E4256617A76585058565354665D70515E445657
465B5D626A605855454839614D70637D5E5D4D4F3D443D433D3F3D3D4B515D556557745E
6A5E71615D594C55525454534F514F474342413D3F3B47424B40484B4B3D494258475554
6B5173556B5E705A5C595C564C565F555054435247625C644D5D4A4C37483D4242475642
60456C5C6649605778768C79736E74817E7C8176766B72695353424142413A3A34454B4A
4444353B535F8C83938397727446493C3D3B393A3C3E3E3E4E5E66745857515750574B59
5571616C7078757162504D48433B383A3B3B414B42433B3532333937393B404045464049
423937393638404641403D3A3635373836333534444A4D443C3E3F4E4D4C3F3D34384246
41424B4F4538333437353C52515D606562544F4D5B534F474C464B4E595352615A564D4D
565A5B53534D574E4946483B43423F3F4033383F3839403B3C3A35313135373634373939
3838353132343738363434353637373837353433
7C777D61584E54525D616A6C675B55627F99B1B0B1A9977C7677737373675851575B606E
7D73605A7063574D46474C5065727C889197A09FA1888B828D78745D5043403F393F453E
3E3E3A3B4143403F4543413E3D3E41433D3F3F4041413E3B3C3F42434141434541403E3C
3C3C3D3E3C3A3E42404041404040413E3D42423A404343403E3E3F3D383A3D3E3B38393C
3A3A3B3E3E3A3736363A3B393A40413D3B3B3C3D3E3D3A383B3B3C3C3D3D3B3A37393D3F
3D3C3E3F423F47443A393B42383F423B3E4039404039383B3B3C3F3E3C4340383A3E3F40
3D413D38393B393A40413E3E3E3C3B403F3E3C3B3A3C3E403C3B3C3B383C44484D4B4B48
464541423F3B38393D424546433A3F3A37343E3A3E393E3D3B3E3C3C3A3E3F3D3D404140
3F443C383A3B3F403E3B3B3F465259555651494B434E3B3F383F3A453F3F3D3C3A3D4244
4A434F4F5A3F47474437454039413E49525253453D444953575955685D5A48484956484F
585F6158564A443F3D3F434A4A5F77886152464043413D464344454543403D3C363D3C41
3A3341413A3A3D3C40413A3B3D3A4347484A413D3A3B363D3E414D44414643474344383C
4840353D3D433C3A41443D3D3C383A3A4540413C3E433C3B3F413D393D403E3C44454D5C
625C524D3F3B383E3E3F41383A4950463E4448413D3D38353A3B3A3D453E39393E454847
3E3B3A434D473D3B453D3C3C40413F4B4B44443C4845413E3E3C41423B373B3D3E3B3A41
484744485C5C77646C54665F58504443424A4F57585D4E484748474B4C544D644E5B4749
4B54484246403E3F4C41614C775B6D5A41424146413F3B3C3D48425B6479716553695661
597964796B73666864635B584645443B3A3B454946464B4F4E504C51534D485251535159
586A59735472455646444641393D413A423A3B3842414A4C464C4C4C554F535355535561
5769545E53644B5F4E685165535556616460635F816A8C657C5462503F4A464B4F574943
374144585F86827A665E4A553D43343E353A3D3D40464A4C555D6A534D44545B595C574D
554B423C4D585F5F544745443F3A383A3C3C3C3D3F413E3A383839363C42464348423238
383234373434393C3A3A39373534363735373B3E4647453F3B3D4355514A3B3A35353B3D
3634393C363335393B3B404B4B5451514D403C3B403F413B423E495354575A675C53494B
535D5E514C414D4E4241453942403B3A3C37393D3B3C3D39363535353536343235363736
3635333131343636353434353536373838363433
4F4C4D4D404843454A46464142413D495B637A6B7B6C6F5D5A5A5451555450505D61616C
786B585657554B413F404246566A7C94A9B8CACCCBBFB5BFBAB5A39B7265584A3F434439
3F403C3B424341443B3E4244434344463F3E3E41423F3D3C42413F3F4142414041434442
3F3D3E40433F44484240444443484643464840373B3B3D3E3E3D3F423B4145433F404345
393C3D3C3B3A3937393B3C3C3D3E3E3E403D3B3A3B3C3C3B3C3C3D3C3B3A3A3B3C404343
403D3D3E423E45433F444341393C423C3B3F3C404139393E3E3D3D3A3A43423C3C3C3734
3C403C373A3B393A3D414042443E3B413F3E3D3937383C3F3F3C3D3F3F4A595F4B4B4643
3F3C3D3B47433F3D3E3F3F3D443B423C38353F383D373E3D393D3B3B3A3E403E3D3E3E3C
374039393C3A3D3B3A3A3A3842575E514A3E3E363E3F45413D453F463E3F3F3F3A3F4342
49444D484641324B4449343A37413B44494853493D394B475F4B474F4949414E54635566
666D6A56544A46403E41464F495A748D71635646403D3B4B464645413C39383942474142
393340373C3B3B373C413B434640414144423C443C473A3D45444E4D4841453C41424454
4E44373C3C433F4144433C3D3A373D38423F403A3A403B3A393D3B393E40414543494C53
574B40443B39353D3F40453D3B414039373A3A3B3C3C3735393A393D443D41484A4E4D43
403C3A4149433B3C44413F393C3D373E413C4037423F38393D3A3E403B393D3F4138373D
3D3B3D3F4950575B4C4D4F5350503F4D3A46383F47433C3F3D41373A4C53605361515449
404039393C424D4C5C5E525F545B463E39373A393D393F4345444C526B61614D5A525744
474B585B6074655C544C3B37393A3F3B40425460565C4F5F475F474F413940394E4B554F
6B516149463B3F373E3E3F3E3B3D3E3D343C35473C4D444947554D61595A4F53514C5550
6B5765535250644E534255483842464D4C464C515D5D6469636261655F6B686E6F705543
3A3F54496F4D714E4B453D3C3A3A3F4642505B5D61696963565B50454351485954604448
3E403738323945443E3B393D3A3C3C3C3D3D3A35373D44474B4E4B473E43484446443739
3533373A35343635373737363535383A393A3E42433F3C3A33393E4C47443B3D3B323236
363737343B4A4F463D3E3E393E443B373631333334353936403E4A555255555D54514A4F
4F59574B4C3D44484142493E47433D3C3A3D3A373D3E3B3D3A3937373735333234353738
3836333234353636353536373536363737363535
4D444B46424143434343453E4146424B4446474846474747474E4D47423D3C4146474348
52483C413F48443E41434245424E515C6773878B9D98A4A6B9AFB7BAAFA18A6E5D5A5447
4345403E44454549474C51514B443E3C423E3E4448494C504F4942414546423D3D424849
4745474B494A575E554B47424952514F58594D443E3B3B3E3D383A3F3941443E37373A3B
363B3E3C3C4042413B393A4042404145443F3937383B3E3F3A3B3C3B3A3A3B3D383C3D3C
3A3A3C40443D3F3F46534A3A3D3A413B353D414340393B42403D3A343842423E40413C39
3A3F3B373C3E3C3F3C3E3C3D403C3B443A3B3B3836373D423E3D424541454C4C3F423B3C
3B38403F3F3C393A3D3E3D3B3C3742403D3840363C353E3D393F3C3C3C3F413E3C3C3B38
39423B3D4241444045403F3D3C44473E423D3A3E393E423E424B474E454544454144433F
48454E45433E464F443F40403E39414544403B434039383F4C493B4A4950587376765A6B
4D5450393D3F4645434246554C5056626866614C3D3A3E55524B433E3D3D3E3E41423D50
5D5F5D403D3C3D373C3E353D463E3B3B444A4F65495C46414A4144475A55746367483E4A
46443D413B41424A3F3B373C3A3D48423D3C413C3D423D3B343B3C3C4041454F3E433E3D
413836483E3C363D3D3C42393B3B36363C39353A3F3D39383C3A3A423B31373F3F454639
4C453D3E413A363D353E423A3B3F393D393B45393F3C3C473E393A3D383739393D35393F
3C41515B534D554D50454B4349433F3D3B3636383F393E453B403C4C4A65605448463C3C
38363B413D475B545F534645433C3A3A39393A403E41454D524E434E4C494442434C4548
414E495F4C624B3C393E3A413D404C4A4E48586560595D4E4F4E46424040403D4E5B5D50
433D3D473846343D393939393A393A3D3B424B3D474A53494759585F5D57534E4F585F56
51545452474D463D3C3E3D37434440474A4546455A5151464F435051565355615550423C
3D4440514342484B4A46384146524D4950606A6A6D746F6450374340383D3B3949563C3B
3B3436353C343734383D3434373E413F3E3E3A343D444D50504E443D3A3B403B3A3D3736
3232373935373B393636363535373A3C3E3A383D3F3C393A3B424144393A343638313237
373738363F595A4030394135333B3433363639373634353444434A5154504549454B474C
4F554C4550413F403E40494048433D3B42493C31393B363C3E3A36343537393A37353332
3334363836363636363738383636353535363637
56544D46454746433C404746424549453F42434245494844404345444546454240414245
48474543414243413F3F40424440414241464C4C54595F585F5F6F7C9BAEA8A392818276
3F4041404A4D6A76888D95856F676572735E5C61635E6A937E877877504B393E4A5C8A9D
9D949A90967FB098A46F797B887F7A81775E4F42403B3D3A3D373D40413E3E413E3C393F
3D3A3A3F413E3D3E433A363C434442413D3C3E403E3A3839403C413E3F353838413C3B36
3E42383E413D3B3A3A42463E343B3A3940403E433F3D3D4143423E3A3837413837403B41
3D433C343B403C3746413B4047443C3D3A43393639383F40403D4543454944484248413B
3F3C39433D3D3B37393E3F3C384654473A3B383E383B393A404141453C3F3D3D423F393A
3C3D3E3F40403F3E45493C3C403B3F40423E3B3B3E403E3C3B3D44453D3B3E3D3D404446
45434141464041494A413C40424141413F3B3939403C3B3D3E3D3D3F4D595E716D555146
3F4244413C3B40453E3D56584A555B554A4B464940413B3D3B3D4747474741433B444D75
818A68533E36363B3A3B3C39393F3A3D4B6885837E75616260676D82888E9CAC8F786B72
626B544E404140473E413B3A383F4D4340393D373D3F3D3D3938393C3F40403E38393739
3E3A373B383D353D3B463E3638393A3937353536363A3A3A3B3637433D363C3C3337413E
3C3734383C3D3F413937373A39383B4137373A3A3A39373A343A35413B373A3D3B34393D
3B4B58514A4745433E39393D3B393F3A383A34383B3B3C3D3E3F41423A3D3A3B423F3838
363F4961594046413F383A3D3D404039363B4040495E4E5344443B3F403E423D3D444A4D
4C47414040413D3C3E3836403A3A4D524C4B4A52464E4B464A4B443F464A464345403B3D
34383A3A3B3F3F3C36383E4141484C453F3F41454F5656524B5953575E6657555D5B564F
5C4E4646473C3B3A3B3B3A433F40424D4E454A4E514B4340444645454442403F3E3E3C3B
424B5248393C4646423C3B40403D3F46414C4D474D5D5E50423D3A3A3B3B3E43544C3F37
393E3A333536363636383D403B494D514A514B473A464648473C393831373A3E44403836
393534353535373B373434393B3835363C3B353839363834353835393B37393437353334
373B3D3D3F37323438373535313737363A3A3634383F40434B4A4547555B484F505C515C
3E3F4346413A3A3E4037393B3F41393934353739383734323735373833313F5342393334
3431333936353435363838373235383835343639
4747433F3F434441444346453F4145433B3E3F40434849463D4142414143413E3D3C3C3E
3F40403F424343413F3E3F403F3C3E3F3C3E42404043443C413D444A4E656B73716B7269
54403E414645678F878D96897569636A736C69616163677B8B8B8576645856585E7691B5
AEC1C5CBB8B3ADC7A6B7A1BEA9A396907D5C4A4547474445393F40413C3B403F45393F3D
38393B3E3F3E3E4039383A3E403E3D3D3C3B3E42423E3C3C3C3B423F42393F42393C3F39
3D423D433D3B3937393F403B373C3A383A3A3B41373D424141413E3935373B3E3E3E3F41
42443D383D3F3B39373734364143403E37413D3E43434847433E413E4045404239403C3A
4240393B373C3F3E3D3E3E3D3D3B4139353C3A38363A3A3D44423B3A3D3F3B3A3F3E3B3D
3C3B3A39393B3C3D3B4037393E3C3F3E3D3B3A3C4042413F3B3E474A423F403D3F3F403F
3F404142403E3F42454645443C3C3C3B3D40434437363A424340434A434946534F3E413C
3B3D3F3D3A383B3E423F505043484B473C3F3B403B413D3D43444D4E4E4D45463E4B5168
646B5B59564D4A4C4744433E4045484F5A6E7D786C6A6067687073829387A199A583918F
99918D6B564D3D443B453B3B474B4D4A3C3D3B433A44373B423E3A3837393B3C3A393636
3A38373D3D3B3F363B46413E41403E3B38383B3D393F3C3637383E473B393F4139393C37
39393C3E3B37373B403D3A3A3734363934353A3B3C3F403E423938333D303D363A373C3D
383D433F423F3E3E3D3A3C4139373C38383C393E393B3D3E3E3C3A38383A373941444447
5D6568694F353D403D3B3E3F3B3C3F3D3B4C5A5748493B42403F373A3D3C423F3D3F4445
403C3B393C3B38373A3A3D434640494B494C4A4B474C47414549474444474340413D383A
37393A38393D3E3C3A3B414544484C48434444464D54514A4C5D5B5C5E62575951525048
50423D4140393C3C3A3939443B3E414C4E484B4C514B443F3B3D43453F3D3A393B3C3D3C
37424E493B383B394038343637373C433D403F3C3F46453E3936343637383B403F3E3A36
35363634393A3B3B3B3D4043474A4344434E49443D443F3F3F393B3D3438383A403D3837
39363537363535383938393B3C3A3838373A363839373A35353A383B3A363A3837363535
373838373733323333313336333C3E4045464241383A393C44464444424A3F4B4B54464B
3E3D3E3D3B383A3D403838373939313237363535363737373736383A3633373F3D363335
35313237313235383A3B39373636373736353433
4B4A484545474745464141433F4045464242403F4042413F424445444445444143414040
42434343434342413F3E3E3F403E41423F3F413D3F41423E454141423B49484B48454C45
59464845453F455A55595F56494341474C4E4A3F40444246565056424838444358647782
8B92A1AAB797AF85B08FAAADB3AC9D8C70617589948D7665484943403B4439483E403D3B
4142413D3B3D3E3D373E42413E3D3F413E3C3B3E3E3C3C3F3E3A3C39413A3D3D3B42453C
393B3B4243403A36383A3A3A3D3E3B383737393E393F3F38373D3E3A43433E4340373D3F
3D3D38373B3C3A3B3A3E3B343C3E3B36333E40474D4B4944433D3C393B3F3C3D3F443E3C
4749423F3D4347433C3837373F363A3A3C423F383D3C36363D3F3D3E3E3D39373B3D3E41
3F3E3E3E3D3E3E3F373B373A3F3D3E3D3F3D3C3C3D3C39373C3E46494240424043403C3A
3A3D40424849453E4046453E3C3F3F3B3D4244413B3B3F423E3738403F40373E3C323A3A
3D3E403F3E3D3D3E433F46463F3F3F4142443E3E3D4847454F4B4E4947463E3E3A474B55
4851535F534A4848423E3C374140484B4F57554E4A4C45494952525A6B71789380827D8A
899E87824E3F3D3F585F4F5471725E524238453648424D4D514F48413E3C3D4038393839
3D3A394036493440304040393D3E3F3F3D3B3A393A3E3933363D3E3E3C3A3B3B393A3C3D
3B3C3E3F3B373638413C393939393A3D43403F3B363B403A383B3344323D3D4138393C3D
393637393B3938393A3A3E423F3B3B38383B393B383A3B3C3C3936343A3B393A41474B51
5856555042383C3F39383B3C393A3D3D414B5253403E383C3B3B373C3F40423F443E4041
3C3E3F393C3939393B4249484A404140444C48414347433E4247474540413F3C3D3A3637
3A3B3A38393B3D3C3F3E434643424545464948484E5450455760574F4E524D524B4F5148
4C3E3D44443E4243444340474649464B4C4A4C494D474742383B4446423E3937393A3A38
3E444A463A373C3F3B3534383B39393C403C3A3B3C3B39383835353739383A3E3D3B3939
3736373A363738393A3B3C3E4B483D3C3D48443E40443A383A36393B383A37363A3A3739
39363638373434363537383736363533363D3A3938373A343238383A383236343B3A3939
39383534323334332F2C2F35333A3B3A3E3F3D3D3F39383C42494B483D423D4A464B3C3A
3C3D3C3A393B3B3B4840413F3E3D37393C39343234363839363637373735323036333336
35313135383838393A3936333534333536373634
4848474544444443463E3F4240404446403F3E3E404343433F4242403F41403D42414142
44444241424241403F3F3F3F42404446434445413E42424044413E3F3F46403F3C3B423E
3E3D403C3E423E3C404346433E3D3F4442413E3C41413E42403C4439453A433F3D41483D
49414D5556564D5A5E776F836E676A6A555E8BA19A949970705061626159493A4435463A
3D3E3C3C434E52504449494038383B3C3D3B3B3D3C38383935373C3B453F4140383E4442
3D38363B42413E3E414140433B37393D3E3E3E3D3D3F3E3B3D4245453E3D403C3A3D4049
3B3C3B3A3D41413F383C3E373F3C3C3A3B3F42474B49443F3F3C3A38393B3A3B42453D38
404643413E41423F3B3A3B3C403D3D3E3D3D3B3A3C3D3A393D3D393B3D3C39383A3D3F42
393C3F403F3C3A393D3E3C3D3F3E3D3C3939393A3B3B3A393E3E42423D3D424247433E3B
3B3D3F3F4B4C463F414847403C43443F3F4240383D3E3E3C3A393C3E3E3E383C3C363D3E
3A3A3A3A39393939413D3E40414040464546403D44555B594D45433D3E434246484C4749
3D42434A433C3D403E3C3C3A413A4346484D47443C43424846504D4E6B638372815A6A62
5855604F46424A4B474E4B52676D645E4F4F4456517067745557534D4A4440423A3B393A
3E3E414B4848573E3E443B3934373B3E3D3A37353D3D3D40494D473F3D3C383535373A3E
403C393A3C3C3B3A3E3B37383A3E414241403E3C3539413839363A3A3339494D3D3E3B3B
3D38373F3A39373738393C3F413D3A37373837363736353637373737393938373A3D4043
42393935373B35333936363A3F41403C3A37353E343B3D3C383A3D434746423D4235373D
3B4041353B393B3C3C454B45413A38393F49463A3C40403E4043423F3B3C3B3A3A383737
3A3B3B3A3B3D3E3E403E41433E38393D454949484E5550455352443B3D413F4044464943
483C3E43493E3E41474941424F4F464345474D47474147473D404844433F3B3A3C3E3C3A
3F40413F3A3C464F3834343A3D3B38383B37363A3B3836373A38383A3A37373939343338
3B3836373334363738383939393B393A3D44444143453B3A3B3636353A3B37343737363A
3836353736343437383D3F3B383A3A373944423D39383B3337393435353237353A3A3938
3735333235383A3A38383C4042464039393B3B3E463C3A3E41494D463E3E3A4440463D39
3B3E3F3D3E413E393D383C3B3A3934383F3B363434363636363735333336343034323437
353233373F3D3937373635343534343435363737
424242434343434449414245403E404042403F40424344443F41413F3E403F3D40414447
4846423F4140404040414141423F42434041423F394041434647464C41454242403D3E39
3B413F403B3A3F3F3F43454745414140413F393C42403F4441403E3F3F3F3C3A3C463C41
3B423A463F403F3C42443E44493E424C42475E5E5B746A795F6E74A29E93615742494942
3A393A41515F60593E413F39373B3D3C38393D413F3A383941403D37433E3C393F3A3B42
444148505D554E4B4A4A4F584B3E3D4345494D4A4A4E54554D4341454D4D604E47503D42
3F41403E41494A434041453E44383A3E413F414242413D3A40403D3E3F3E3E3C3D413F3C
3F4241403F3D3D3D3E3D3C3C3B403E3E413E4046373D3D3C3C3936393C3B3C3C3C3D4040
3B3F4243403D3B3A423E3E3D3D3E3D3D3C3C3D3C3C3C3C3D3F3E41413C3E434248454341
41403E3C4A4742404142413F3B41433E3F43413B444641393B4446413C3C383C3D3B4040
4442403F40414141413F3A3E424041474444403C455156514F47433D3E45454A4C494041
3D4341433C373A403F3F4140483F4749494E49493F4B525B575C514A5B5153514F44433D
43413A48385750554B45494741474D48463A4C44655E6256494E4C4848413B3D36393B40
4A525F6F586E565F444B473F3838393A3B3C3C3C3939404A4F4B4642393B3A3837353537
3D3B38383A3C3C3A3F3C3836373B3D3D373B3B3D38384138444143464147494741413A3A
403B363C3B3A3937383A3C3C3B393637383839373B3A393A3D3F3E3E3A3A3C3C3B3B3B3A
3C393E37363A33363C3B3B3E43443F3C373738433A4042403B3B3F4346453F3B3E373D43
3E40423738363B3C3A3F41383838393C3E434337393B3C3B3A3C3D3A3837383938393B3A
39393B3D3F3F3F403C3C3D3E3B35353B40444544484E4A403C3D3934393A3937413F423F
484042444C424242474A43434A4A403C40454C46463D41443E42463E3A38383B3F42413F
3B3E3E3D39373A3F38333032353738383537393A3C3C3A3737353638383534353634383F
423E3A3A393A3B3C3D3D3C3C38393B3A3D3E3C3743453B3B3E393836393B373436363539
383533353534363A3A3F403C393B3B393B4645403C3B3F3737362F3338393D3937363533
323233343436383B3F434647393F3E3C41474C52493E3A3B3A3D3D353736343E3E474341
3C3F3E3D3E413F3939363B3C3B3A363A3938373737373635343838333236363335353537
3635373B3D3B383737393939383838363536393B
494848484745454845414345413F4140474442444442424241434341414343403F414448
4947433F41403F4041424343454142423E3E3F3C3E4441413D3D393F3E3F3D3E3E404241
3E433B44403F4242444643454442464443473F3E414041414444394038423B3D393E3B3D
3F3F393D383C3D3D3E3E3C3F403E3C45474348463F3F423C47405877928772595C525A49
43414149555A5247393A3A3C3F4242403C3C3D3D3C3B424A6664573E3E373D454C464654
5A5B6364625A5D656568747D5E463E42475C757D939AA3A2907D7D89A1A0B49D908D6255
403B38373A4346413B3A423B43353E47433F464845433D3B3D3C373D4444423A3B3E4246
47443E3C3F3E3E41423F3A38393E3D40423E3D39373D3D3C3E3C3B403D3D40413E3E403E
43454543403E3F413F383B39383E3E3E44454644413E3E3E3F3F44464241434045454545
44413E3B46413D3E3D3A393C4042403B3B40413F4C4B43393A4241383F3D3A3B3D3E4142
403E3C3B3B3C3D3E42423B3E3F3C3E3E4342423E4546453B4E4847403E413D414B473F3E
3D4142433E393D42403E403E423D4345434543403D454A524A4E453D443B3F3C413C433E
3A42404A534C56454B404D4E3F454B434D4B44575261453F3E44413F423D373B383E4245
474547515E585F4843453E403C3D3F41434443413C3C44483F36363A36383B3B38393C3E
393D3E3C393839393B3A373435393B3B393F383C3D3D4D516B766D76555A3C3D40413D3D
423D383A3A3B3A383A3D3D3C393A363838373A373A3A3C404343403D3C3A3C3E3C3D3D39
383A3F38373B3841393D3E3D3D3A36373A3B3C423C443F403E3A3B393B3E3A3A3C3E484A
403D403D3B3B3E3E3C3C3A34393C3F43403E40373B39393834373B3A37353738373A3D3C
38383A3E403F3F40373A3A3A3B39393E3B3E3E3E3F3F3C3735383C373835393C413C3F3E
4943464649464A4643454349494A424143454942473C3A3B393D3E363536373A3C3D3C3B
3C403F3A37343133373534353839393934393B393A3C3A353735373A3B38383A3335393D
40444B533C3C3C3E3F3F3E3C403C3A363B393731404238383C3A3D3D383B373536353439
383432343434373B393B3B39383838373741403F3D3D423E353B3E4B524F4B413A393836
36383B3E3C3C3B3C404444403C44454142413F413B363537393C3C39383A394046494341
3E3D3A37383B3C3A3531363535343034333437383938383733393B383636363338373737
37383A3C3B3A393A3A3937353637393B3E414447
49474646444041453F4044443F424644413F3F44474646483D3F3F3D3D3F403E3C3C3D3F
4141403E4341404042434342454244443F3F413D41453F4342463F4343403E3C3C3E4144
454239403D413E3F42423A3B3C3D46463F4A4341423F413E47453D3F3D444244423E453B
493D40393D373D373E37413E394141484941414141393E3F443A3E4049554F504955524D
433F3E454D4C453E46424040413F3D3C3F3E3D3B373A47547383836555434C5E464E596B
706D6B5B59566C817A71716D6752525C617EA5B5C0C8D1D2C7BDC0CAC8C9CFD0D4D0B095
624D413F3C3A3C3C494A5041493E4C554C4246433E4040454E473E4D6067645549423F43
443F3A393A3A3D42434141443E3E3E41393B44354A4C484648443E3E403F4445403E403C
4041413E3A393B3D3D343A38373E3E3E3E424749464443443F3E44464241413D40414344
42403E3D3D3B3A3B3A3A3D4245433F3B3A3B3D3E42423F3D3D3F3D3942403E3D3E404040
40403F3E3D3D3E3F3F413C3E3D3C413A3C3A3E3D4643433C413E403C3B3E3C413A3A393B
3F44484B423E4145413F403E37393B3F3D4046423E3F3F463E464442413C453F443E453E
36373D494B5F3F3E3436494A3F414447574A4F44514942383D44413F46423A3E3F484F51
4E433D42434A3742343B3A3A3D3E42454846423E43434744383336383A3941433B3D4545
3F43433F3C3D3E3E37393937383D41413C473E4852546C7E9DA29D83705F4D514A4E4C46
423F3E403B3C3B393B3D3C393A3D373938363D3B3E3F41474C4F4C49443C393834363935
3A3A3A363837343C383C3A38393634373839383739493C3E3F383833353A3638363A3F3F
3A3738394242403E3D39373B3D3E3F4540393E393936393935363A393834363836393C3A
3837383C3D3B3C3F353B39373A3B3A3D39393A3B3935333539393E3738333A3C3C373B3B
433E43433D3E453F3A3C3C44474840414240433E413B3837383A38343738393938373737
363D3933373B3C3D3637393A3C3C3A3933363634343535333938393C3C3A3A3C40403C36
33363C403B3A393A3B3C3A39383537343B393E3D3A3D35353A393D3E373A38353635353A
38343335353435383D3A3A3B3C3B3A3B343A393C3B3A403E39444C585B5551493B3B3B3A
3A3C4144444544414243413D3E484945433E383840403D3A393734363B403E4149463C3A
3F3B37373737383A3D373938393A373C3336383736353738353738383838373439383737
393A3B3B3C3B3A3A3A38363439383B424B504E4B
4342424443414449424447433D40454144414145474443443F41413F4043434243413F3F
4144454645434141424342413F3D40423F40413D42443B42444A40413E3E4140403F3D3F
403B3F4A413E34423E413A3D3D3B423F38444144453E41404741403B403D3F3C3F3F3A42
3E443D3C3F3636393A3A43403A39373F403E45413E3D495545464640454E51413B3F4543
433C393D3F3D3C3D413C393B3C3B3E43383C41413B39414C70848E7F7758443D3E4C5560
64686A55564F667A6B5E5D544B414F5C56637D858C939A9C99938D899A9B94B1D0D5D1B5
9B775F594C3C393D6369715F6B697E878D766C5D566373847D72667C9BA8A59167534342
43404043424142433F3C4148433C40453C53776C766B554644423D3D43414647403E403C
404244433E3B3B3C3E353C3A383F3D3D3E444A4B46413D3C403E40413D3D3F3D3B3E4040
3F3E3F404444413C38383B3E42403E3E3D3C3D3E403E4247453E3B3E413F3F3E3F3F3B39
3A3B3C3B3A39393A3A3E3C403E40483D3D383B39423D403D433F4039373B3B413A3A3A3D
4041403F3B373B403D3B3C3B3B3F3B3B3638433D43403F453A3D3A37423B373C3D444138
434D42413E3C39383B3A3D3B4348424C4A44403F3D4339383C4543444C463B3D383F4241
3E36363F3836363B3B403C40403E3D3D3F403F3D3A393B38353B3E373F404F52433E413A
4B49433F414749463A3E3F3D3D424646435551616E677A8F939F8F8C7B856C7A61646050
413E42453D3E3D3A3A3C393435393438393A454659595A60686E706F5C4F453E373A3F3C
393D3D3D3E38353E3F3F383840413D3E40464B464959474C3D363834353B343739383537
3C3E3B3942423B383A34343E3E3C3A423D363E3A35343B3E39383A373934373834373B38
3A3736393938393D363C3933373936373837393B38323338333139383F393B36413D4341
464047483C3C423E3C3F3D423D3C343537373E3E3A3A3A3B3E3C3735363739383637393B
373F3B32363A3735363634333336393B3C3B3A3A39393B3D3937373938353435383A3939
3E423E373B3A39393B3B3A38383A41393830383C353B34363A363838373B37343635363C
383535363633333539343337383636383437343838353B3B343B393B38353E4036363736
36383D4035393A3837393A383A42433F3E3A3637343A39373A393941353C383945403536
3D3A393C3B363538383132313336353B393A3A363230333737343234383B3A3939383738
3A3B3B393B383635373A3C3C4541414954564D43
41474441413F43493E424444444147403F3F3E404441404745414042434140423F41413F
3E41423F4241423A3D404D3F404040403F3E3E3E414C464047463D4141403E3E3F3F3D3B
3C3D34473E393F3D3A3F3D44423A40403D3E3E3D3E3F3F3F3F433D4242453D403F3F403A
453E404141384041443D443F3A38393A3F4242444544504B373B44383E3A3E413B393C3C
3F403D393A3D3B363E3E3F3E3C3B3B3C3D3A3F413C404E555A675B65525147423D3E4042
45484B4C4445514A4A4548423F42464645464A4D4E55534F54565559525B687F7892938B
7580816B5D403F4D6D97947B8394A5C0BCB0948F7B8C9FBEBBA39EACC1CDC7C5AB88775A
4C59595F697A6D52525F6364697B685B567F909E7B795E4C4E51514A494D54506C5D6557
554046393F3B413A3D3C3B3E4447433B3C3E4E464A4A4134383C3D443E45394940373B3A
473F3A4146433A3B3D46433E3B444A4742403F3E41383F464339393537423642434D3A42
4240433D3C403B3A3D3F403C4041393E363B3F423B3C443D3D3C43454042454038383A3C
495D423A343D3F393B46484144423F3F41403C39353C3B3637393F493E383D3D41373F47
4041413E3C3E3C353B3E374F5D4E4C49433B374146393443414D4D4646433B37393F403A
36393C3D3838393B3E3F3E3C3C3B38373A3E3D39313A393B4340404D405C53504F3A3C44
3F413C3B43454143474A49464239353B3E424B4F5B516C6280726C64687271766D716C5E
54555756514542393540423E393E393C3E586B7A7E85838295928D7B6E705E3C3F433A59
4F54423F393B3A3B3F3743373C3F5A5763605F6461644F49403E3C3A38373737404E493F
403B363D3B3D3D3A38393D3F413F3D3B3A3A3C3C393E393C3A373F3E373A3835373B3936
40383D3E3B353A37393433383B3B3B3B3B393932383833373B3B37353633353D393D403F
40413E393B3E3B383A38373B393A3F3E3534383831383C3B3B3F4242393B3A3534373736
3636373838383838333435373838373733363A3B3A3837373636383B3936373B3B3A3938
393A3B3B3838383A3B3B383632383B393537393A35383B3A3837393B3A3A393836363637
3736343435383C3D38393938363536383A3836353435383931343835343837372E333238
31363439353934393A373C38373640473E373A3E403B3D3C374642423A3E3D3C46453E3B
3A47473B3D353C39353C32393A353A4238373737383736343333353738393B3B3B3A3736
38393C3B34363436333844404743384147473C42
434642404646454542473B4A47504A494645404146443F41433F3D41434241424242403E
3F4343403A3C404146424A4136404141454442474045413E44433F423E3D3C3C3E3F3E3D
384A586B584642403D3F3B3F3E3A43473F3E4043444342443B403D3D3B403F42373D433D
443C3C3C37393541393E3B3C3D3E40404344413F383945463D444A3E413C3E403B393B3A
4040403E3E3E3C393738393A3A3B3D3F3A3C3E3C3F4D534A474E3E44363C39383C3B3B3B
3C3E3F3F3B3B3B38393A4F4B373C4245434140403940424142423F3E383F404D445B5C58
4A545A504F3C3B45536E6C5E656D7588867F6D71626B6F817A818C91999FA8C0B19D886B
63696A787C8F8B7D849092949E98996D817A999A8F8F87919B96959597938F8E929A9D8F
67564C56545C48413C414442424749485C4C7F5054414D464740483F48424041423B403B
44403B3B3C4245403B393A3A434545403B3C40433D363F3C44373D3A4138443E4A3F3D45
3D3C403E4249434138393C3A3F413B413E4444433C39403C3F3B403F3B3D3D3F383B3C3B
3943373F3940423D3F4547413F3F3F3E3E3E40413C3E3F3F3F3E3F433E3B413F463F4240
43423F3D3D3E40444A595D6F6C50443C403B373C413F40484048453C3C3C3A3938393939
38383B3F3A3937383B3D3F3F393C3D3A38393A38383E3F434C4E515D4351424041353D46
3D3D3A3B3F3D3A3B3A3D3C3D3E3A383F363B4449564C645A504848485363686F5C68695D
5861645E5F524A3C353B3B3D353C3E4B56768FA39FA096898B7E7F798889795755554657
4E4E3E423C3938413F4946634E7376807C7D7F7E6E654A433D3C3C3C3E4145474B4F463B
3B3A373C413A37383A393A3E383838393A3C3C3C3D403A3B3A3A434435363737393A3A38
3A373E39413C3E3435333538393736383E3E3F39393933393539383A3B37353C393B3C3B
3C3E3C38343B3C3C3E3D3F463C3A3D3B333339393236393B3F4343403C3E3C38373A3A39
37373737383837363536373939393939343537373737393B3736383A3936373A36383A39
37393E423938383839393838343636333335373538393A393635383B3B383636393B3C3B
3636363636373A3B383838383939393938383838393A3A3938383836373836342F35363C
363936393B3B343637363C3A3D3B434941393C3F3C3743353C38423D403946425B46453D
384341373C363C38343834363B32373B3635333334353534323436383838383835353335
37383837363A3B3F3E434E4A3F38454862504F46
494A464447454144485559626C5F554C45443E3D44453D3946403C3E403F3F3F3E414141
4547433F41423F40463E454646524F484B49464D4945403F3F3D3C3D3B3A3B3C3E3F3F3E
393C40483B373C4242423E404143505747434143413D3C3F3C40413D393A3D3B4044463C
413C3E3B373E393B3E3C413E3C3F41414143423C413F403D3B424640453D3D3E3A383A38
424242433F3B38383B3B3B3A39393A3C3E3A3A3D4045453F4145383F38423E3C3F3C3A3A
3C3C3C3B3E3E3C3E3B3B5348383C4244423E3C3B393D42413D3E3D383B41393D35444243
373D3F3C433A383E414948464B48464E56534A554C4F464B48545A565D6060746D6E5B49
4C4B4D5F6B736D66738695A19897807D6B7876869197A0BACAC4C3C6BCB2C5A8B9A7B39F
A492A795AF85786664798679645C6065587967755655454A4D4D4A5E5C6B52494B454941
4344413E41403A39383F3E3C373B4043423E3A393B413A443D433A404E3A403F44453838
423D3D393C423D3B403F413E3F3F383D39424041403B3D3B3C393F3F413F3841403F3A3E
393B333B404244404241413D373A3D3C3A3A3D40453E3A3C3C3C4044474241383F3D3F39
3A3E3D3F44404352626E6C6F64494038403E3D3B3C4145424247433B3B3D3E3E403B3A3C
3B37383D3B393838393B3C3C353C403B36373A3C3F444C5557514A493C41373C3F363C3E
3A35383D3C39393A3B3C3A3A3E3B3A3F45414045564E5746433E3F40464E4D4F454F5046
434A4E49464445403F3F3B42494D4E5858666E7B8C908D817A6467677E7D7762605F4B4A
4A473A453F3637466B677A727D7B908B90908B7F6559444449474441404144454C483F38
373939383F37343B3F3A393C3D3C3C3C3C3B3835373C3B3E3D3839353C393A393A373B3B
3B383D35453D3E373637393B3B3736393B413E41373E313B393934393D3D383D4343403D
3C3B3834343C3F3D3B37373E3E3B3B3933353A393637393D4244413B3D3E3C39383A3A39
383635363838363436363738393939383535343334363A3D3837383A393636383B3B3A38
37383B3D393838373637383A3B3B3734353938353A3A3A373434373A3B373233383C3C3B
36383939373637393838383A3B3C3C3B3C3E3B37383A38343C393537383735323639383A
3538383B3939333638383D3C38363C413C37393D39413B43313D3F433E3A374E4E473438
3A4141393F394039383939363E333A3A373533323436383835393B3C3B3836373D3C3A3C
393C3B3E3942485053555C555055557B76836C68
464548484A494B5C7BA093A07C754E4B484C4744494B4541433F3F4447454240454C4B47
464440404A4B4246565F717E8F8E7D685D564E4C4E423E403D3E403F3B3C3D3F40403F3E
443C3C3F3B3C3E3F43423E3E3F434D52413F3D3D3E3F41443C3B4043413F413F3F3F3F35
3C3C3F39404D3C3F3D4141413E4140403E40443C3E3E3A3639404343453D3C3D3A393A38
3E3D3F413E38383C393A3B3B3C3E41433D38455B573F363E3E4039403F49433E3F3B3A3E
41403E3D393B3D42393745363C3D3F3F3D3C3C3D403F4240383C413D414940413D453F43
41423D393D3A393E42404044443E393844433D4741433A3D3C474B434547444F4E58473E
433A39434A4A423F474F5761635F54534C51525C5868778FA2ACB6B6B6BBB0A6929D99AE
ACBFC3D7BCB08C9F8D9FA38966524B495D4C836D95799A80A3A0BBA9BFACB6A599836E52
4242454947484D4C524F4C4347434040414244474D50584E60575E5F7462694A54454A3E
39393E3B3B403A393D3A3E3D3E3E383D3D42393A403C3B3A3C383C3D424139484541353C
3A3E38383C3A3E3B403A3B383A3C3F403E3D3D3E40383A41403C3D40453F3D353C3A403F
3D433E3C464C586F726E5C534B4140393E3C3E3E3A3F4139393D3C38383A3A3846413D3F
403E3D3E38393A3B3B393735363C3F3B38393E414E49494A453E39363839374041393C3B
3E3539403B373A3C393A37393F4141454F464041504949373D3E42474A4B464343423F3A
3535393D434549484D4D4B5A47494750484A495157626B6C6F626763655D5B5556584C47
454539453F3738465A565F5C5F62717275747067555650595B57514B45413F3E3F3A3B3B
373A3B363F3F4345413936393A39393A3C3B38353839393A3A393B3B413A3E3C3C373F41
423D36383E39363E40403D3E3F3B383C3D37402E3F343A3C393B363C3B3C363C39383737
393A393733393B3B3D3A383C3E3A3B3A37383A383A3B3D3F403F3B363B3A383636373736
37353436393A383534343535363636363635333233363A3D3838393938373637403A3536
3A3B3834373838373536383A3D3D3B373639393638393937353537393A37343436383837
383A3B3A3634363836393B3C3B3A3B3D46474037393C39363A393538383537363B3D3C3C
3838383A3739393C3D3C3B383A383B3F3D3A3B3E3B3C3E3C3A3545424B41464C53413E40
3C444741443B423B3F3E393939393B3C38373637383A3A3A383D3E3D3D3937393B3A393A
353F44535966707B7F7E7F777E6D8B85A9919E87
50494B4C4E4F556E99B2A5836A53463F5057544C4A48464750566372766E6259616D716D
6F71767F777A6F758A9FB2BDC4B49F88746B635652433E413E3F423E3E40424342403E3C
3C3941413C3B3F42423F3E3C3D4041423B3E3F3D3F434543443D3C44444140443A3B423C
413F433E3F414131453A463F3D4141454040463B3B40403E3F3E3C3D433B3A3C3A3A3C3A
39393C3F3E3B3E45393B3C3C3D3E41433A384659553C35423D3C373A3B46403E3A36373D
413E3B3A3F3D41433A3F443C3A3A393938393B3C3F3E403D3539403E3D453D3C3D413A40
4345403C3B3C3C404643444540403F393E3E3B403A3D3B3F383E463E3A3F3D40444C4040
433B3E3E45433F3E403B393D463E45354236443F3440454B515B655F5A59745B6A505D68
9598B89BAD7D8999A5A49884746A5F545A848CC0B8CDA1B0C2D3D5E4D7DFD3D0CCBFB5A5
8C76605D7482BCA2BE8FA2929B8C76655E5F6469737B6D7068726C777077595C434D4041
3F424944414545494B42444342413C3F48493C3E4744413F3F3E43484E483D4640433C3C
333A3B3D3D393E3C453D403D3F3E3D3F4141403E3D393C42413B3B40423D413F41363A3E
3E48433E49535D6D645B49403E3E3F383B36393D3A3C3E3A36383939393A3A37403F3C3C
4147464236383A3C3C3B3A393D3F3E3A3A3D40414B413A37353537393D3B393C39363E40
43383A3F39363A3C3B3C38373D3F3E403E3E3C3A3F393E3A4345464745403B36403E3C3B
39383C4245484E4F54524E5C484640453D40414B444B51515A585E515947414041464545
3F463C423C39394143463B4734444149404243443C433E464E4C4945423E3C3B38353B3F
393A3E3A4652594F3F38393C3B3A3939393735333A3A3B39373837393A35414041384241
3B3E3A40464949554F4A403D403C373B3B3A35383A43383E363E3B423A39323B3D3A3839
3C3D3B3A3C3E3C3D43423D3D3B393C3F3C3C3C373C3E3F3F3C3938393B38353536363535
35343336393B39373535353535363636373634343536383939393939393937363A363335
3B3D39343638393836363739363B3C3834343535363738383737383936383A3A3837383A
3A3B3B3935343639353A3F3D37353A3F4749423A3D3E3B3B373B373938333A393C3E4140
3E3A3836393A3C3C3C3A37363F3E3D3F413F3D3E3C3D3F41413842393C3C4344453E4245
485057524F4249434D47403C393E3E3F38393A3D3E3C3936363B3A383B39373C3636383D
3A505F7B828F959DA19F9F9996948DA99FB1A39E
7C71706B6F75768AB2C1977E57615558555E5E5856565C65717C91A4A89A887C849BAAB1
BABEC2CDBDBBAAADB4BEC0BBAF9B8D806D6661535044404344484A4544454645423F3D3C
3F3D403D393643443A383B3C414843403D40413F3F403E3C44413843454A47554C494D44
413A4342414044414C4A48434B5055625D575D505455514A443F3A3940393A3D3A3A3C3C
404042413E3C3F433D3E3E3D3B3A3A3B41433E393A3B3B3D3F3F41414248403D3B38393F
413C38383D3D3E3F383F3C3A393A3B3C3D3D3D3D3C3F43403A3A3D3B42453D3B3C3F3C42
404644423C3F3C3F4140413F3A3C3F3C3C3E3E3F3A3B3C414340443F3F443E3947494041
3F3B413F4B454040403D3F453E413C42353F3B3B3E403E413E4049454E4B444B35403E4C
505A5461565C4D6767635C595A5B554D535C929DC5A1BCA1C4BEC0B2CEC1CEC4D4D2D1D2
C9BBA9B2A8C1D4E1D5D3CBCCC3C3BFBAB6B2A9A1A09189656449504D566059666A62635D
59616F6F6F75747862514B4642413C3E424B50606960564C404042494D484446484B4C4B
3D433E3D3F3A3F3A453C403B3D3A383A3E403F3D3F3E3C3E433F3D44453F444345394047
5158524A4E504D4F45413D3C3B3E423E4139373A39383A3C3C393A3A393D3F3D3D3D3A38
3D45443E3839393A3C3F44474645413C3B3E3E3B393735393D3B3A3C3C3C3B3834353B3E
3B34343838393D4144463F3A3D3D3A3A383B3A363936393C40423F3F3C383A3833383B3A
3A3C3D3C4142484848453E423F413E453F4443494043444048484D3A4C3F3C3F3F40413F
3B463D3F3A3C3A3C3F3A423B4138403F3D3D3D3F383F363A3B3C3D3E3E3F3F3E3D393D3F
3A3A3F4045555B4E3E3D44494342423F3C393634393B42413F413F434C4A5C5A594B524B
4A4B694870586F5C544E40393C38343A383C3645465E535E4A46364040483E4250494342
42403D3C42413B3B43433D3B3B393E413F3F403B3F3F3F3E3A383B403E3A373739383737
35353537393B3A3839393838383839393736363638383837393A3A39393B3A3739393939
383836363738383837373838353B3E3A36353738353637383939393934393E3E3B3A3C3F
3A3B3A383635373A353B403D36343A4142453F3A3D39353A39413B3D3C3B44404644443F
413E42423C3B3E3B3B40434A4A4A494D545552535157556655564B474855556555676368
686E75716B5C625A6C53693F62455E4D45474B4E4E49413B3C413C3A3F3D383D3B3B414D
4E6B7796949F9EA0A3A1A3A0A898AD9ABCA3B3A0
A6A6AA9DA3B3B3BFBDB79F847F81908E898C877E787377848D929EA9ACA8A3A2AFC5D2D7
DFDAD3D7CCBDA6AAA5A3988A7D6E6560544E4E4D514B474A51585852494947433F3D3D3F
3F3E3E41443C44374542484B56615A564B4441434340434A45564D5A5C6F6B7F705D574D
4A414745454E4E7B6B9170786F72758479696E605C544E49464545423D393B3E3A393C3C
434546423E3D3C3C393B3E3E3E3D3D3E474B42373C423E373C3E454341443B3A403B3C41
413B393C3F48414542443F3D3C3D3E4040403F3E3A4244403C39373842423D3B3B3C3C3F
414642433B403D3C3F3D3D3D3A3B3D3D3F40403F3D3D3E3F3A3C403B3C3E393D383D3D3E
3D3B4143433F3D3F3D39393D3D3C40423C3C3F3D3F3C393E3B3A45443A3B473F453C473C
443C4A384F3A3F423C3E4143413D3B3C3E4144565B826E9794A0899594988C9596A9B7C6
CDC9B4BECDCBD1C8D2CCCEC5C6C9C6C0C1C8C7C0BBABA18A7A646463798D94A99B9DA2A5
A6ABB4ADA29782786F564A433F434347495D768D89715E4B43443F4A51556563665A5755
484B3C3B3C38403A4A454D474C4F53575855504C454C484E5F5C5052554F524F57535C60
7065544847484746403D43474444454344403B3A3C3A393D3B353637363A3E3B3F3C3838
3B3E3C393D3E3E3E40454B504647443F3C3C3A37383A36373E3B3940383D3D37373A3837
353432343B3D3E414044403B3F403E3F3F403E3A3E3D3A3D3C403B3C3A363C3A373A3E3F
3E3D3C3B4F47453C383E3C3D3D45464D46473F3C3C3F46464B474E414143464645474740
38433A3F3B3E3B3B3837393B3B3736393B3A3A3C363E383E3C3D3E3F414244443F3A393C
3B3B3D3F3C454A45404145483B3F4243413F3E3E3C3B4340424C54615C5B6F68665A655B
5F75677D608161554A4A3F383A3738454B4D6D617E6464595D54404E5564565650463E3C
3E3E3F403F3E3939414341423E3B3E403E41454348433E3B3A3A3E44403B37393B393838
37373838393938383B3A39383839393A373636383A3B3A39393A3A393A3D3C38403F3D3A
373636363A39373737383939393C3D3A393B3C3C383838383838393937393C3C3B3A3B3D
3839393938383839393C3D3B38393E4341433C3A403D3F4E4C564D51585D685C5E5A5B55
5B59606058565A54545F67756E706E727D7F7B7B7B76898284737670777884828788918B
8D8C908D897B80747E7E6E7F66846F726A6D7174726A5F57595C524C4F483D3F3D3B465D
65817F9697A29F9FA19D9C99A2A39FA3A6A69D9A
B4C2CCB5B4CAC9CFCDC2A99E959CABAFA3A39D97949197A6A19D9B9DA3AFC1CFD2DEDEDA
DED7CDCFB1967A817873675A544C484B4B4B566568635B55585B53494C4A45403B3B3E41
45433D424F5169616E686D6E7A867D776B574B4D4A41485962847A827D9186998F736866
6D64605572649194B3A8A09185817D867158594A4E4441434446433A3D393C3F3A383B3B
3A40423F3E3F3F3B40424443403D3B3A46433A39403F3B3F403F433A383D3A3E3F3A3A3E
3E393A403745333A3B3C3E3E3C3B3B3B3B3B3B3B424C4B44423E3A3E3C3B3B3B3B3A3A3A
3F403A3B353F3D3D433E3D41413E3E4142403E3C3D3D3C3A3C4140393D3A313B3A454A47
4138373C39373A3E3E3D4044403A4245413B404144413D413E404C49465A50473E40423D
3E3E423C3E3F404C3A393B3D3A3639403F39443E443B3E4B4C54434B5C554E555B75818D
9AA08E9C809986AB82A58A97909BA19FA3ABA6999A8C9F94A0899C98B9B6C3AEA9A4B9AF
AEABACA6A6A89F9B8D6D5A4E494D4F536C809AA88F69503B46525A74808595888365584E
3E4338424343504D666976716D77848A867B70695B61585D797D70717773746D736C6B64
67523F3A3B3E3F3F534F585D564D443C3C413D3C43433F423D373A3E3C3F413C3E373539
3D3C3C3E4143454546484C4F414546413C3B39373A3E35333B3734403A403D34393F3936
3B3E38363D3D393A3D423E38393936363B4244403F3D3B43353C393E3C363B38413C3D43
433C3C43433A3C393A494C49444D4E534C5149464B4B514D473A464239444238363E423B
3740373F3D3E3B3C3A3A393D3B39373C3A3D3F413A40393F37373637383A3C3D3B353338
3E3D3A3937383B3F413E3936353A40413D3836363737403B383F434F4544574C4E4A5E56
5E5A71627B6F72503F453F393C3A4052616E727D757F717C595F5A6E6E766568584C403C
3C3C3E404A4A433F41403F43413D3E3E3C41494A53483E3A3B3C3F44403A36383A393738
393A3A3A393837373938373636373838373636383B3D3C3B393B3A393B3E3D39443E3837
3A3C3C3B3D3A363536393A3A38393734363B3C3A3C3A3837373838393B39373737373636
3637383A3B3A39383C3B3A3A3B3E424444443D3F4B4F5B746671666D7C88938272747E7E
8680807B8482867D7A838B9A91928D8E9797908D95959EA19294919A9F9D97A397A5A09F
A0999997978B8E7F8A79947B978894828E919698958B7F7778796C62615443413E3C4D6E
7D998B99909E9D9FA198938D969298869B888A83
769BB4B1A69C9AA0969992837D858D8F9088878F9597A0ABA895848091B2CACECED4D7DC
D9C1C1AB90756E787C705F6245444741575B78798F8286696D6A65504945413E3E404040
45475F808AAAA2AEA09D90A49FADA69C806E5D434A4E7474A4A4A793969590938B7E7F86
8F8C869992B6C4D9CCB9918D6361504F504444463F393D4340463E3C3A403B43373F393F
3B3C46473939374748544944454A4040565652444C4640383939403E3E3D383B423E3C42
3E39403E3C3C40413E423C3E3F3B3E4343415864635743434F3F45433D43434347433D3E
393F3E3B3E3F3E403C3B494641394344443E413C40383D3E3E3C3B3C3E3F3D3A3A3C423F
4336394039403D393E414042403D3F3D3F423C3D404746585962686266534B3F3A413F3F
414242403C3C47553A3D3A3A403F3B3E3F4142413F3F404041453F434B474440474A524A
515150474B4E564B4F4A484D52616B6B6B6762685B625A7F78878FA59793898979888599
908B92949C98A8B3A89F8172728A7D7B7582807E7B72706F727993A6A7B39D8665504E43
443C4D515C6777858D949A9F9B9EA0A79A9D88846B6C5C716D716C78838377656A5C635B
4A4A4A5047514D5B5F6B6960534A4941443F41453E4A423E434D454E4D5D574F403C403B
4F3C534C5D58524A444B4F4540384539383E3B3C39363D3C4A373C423C3635393D434137
333E3C3B3A3C363A3D43393A373B37413B5558484A3C3C39373C374240403E49443C3D40
41413D3A38353E353B3E5050565254484A413941444F4A3B3B41434245413F3F3C373639
353E3D393C3C393B3A3836363839393837393E3D383B3D3538424036363A3A3936393A3D
3F39353A383B3E3F3D3B3C3D323838383C3B393D353B3E3A363739393D40413D38383E45
40504D606276575D494E404344445756716A776C826570606E6767696767655C56514C4C
4F52575A56535A4E4A493C4E42403C3C3E4041413E41343C393B3D3D3838393A39383736
393C3E3D3B38363635333933373B3C3F3A32423B3B393A393D423D3B3A313A393C40373B
3437333E373737343A3E403C43363C363C35403233383A40383C35393B3C3B383C3C3B36
3739324234413B3B3D444954555866617B5B765A89698C908F9192909497A094848D9290
939899958A94899C899F99A697A7A5A39EA0A796A492A79FAA98A695A29AA89AA49C9FA0
A2A69E9C95928C828191819185937F8C889B97A39998979C8B8A87767B664C4C48596C80
9C9DA299A09BA29F9C9A92988CA091AA87AA95B2
5165706E6B6662635A5E5D5755595D5C5C5B5F697072767B7463595C677C8D917D8591A6
B2A5A38A7A707985826B514E4A3F423C58667A7A82787C696B6D6C5F4946434243454748
6061779BACCFC8D0C8C0AAB2AABFC9CCAB9F7A6B5E8095B0B9C2B6AC949F8E97979399A2
B6C0BABFC7D2E2D7D6A98A745E57545867716E6E5D5657493E3D3E3F43423F3C393B4045
423E4E3C453A4650655354424F526353565552484F4745413D3A413C3B3F3F413A3A393F
3C3A43413D3840353E3D3A3539465B7678757A7B73635947494A565C55514D4944413F3C
4046433E3F3F3C3D404751473D3C44433C3A4040463F4242403D3D3F403E3E4037393A34
3E3B3C3B393F403F42403B3C3A42463F3F3C3E556671737E6F6967605345423A373D3C3B
3E393A3D3C3B3B383A3E3C3B3E3C3A3D3B3D40413E3C3E41393F3D414B4444403F3F4237
3F42494549494148424D3D454248484141444548495A596A67757878746959574B5C5B6C
6B67685E61647B8A919078817A94746D5363666D78808C939994ABA7AC9E93755B645C69
48575E7B747E88898991A0ACAEAABFADBCA49F937F74555E5962697D7C7D6E7578777370
6A6A5D6F5A6B535B606F73706A64665F706373616D606B656666746E7574665B4E4E495C
516E5D6C666257473D3F413C2F38453E4B3C463D3A3F3D433E3F364039393C3C3A3F4038
3F4345383E3A42463F40373D3B423C405662604E483E45413F3842385041535957403C40
393C43403C39393D4250575546494A58525A474D3E47443A3B4144453A393A3D3F3F4041
343B3A36393937393B3836363739393939383C3D393C3F3C37393938393E3E38373A3A3C
3F3A373C373A3D3C38363739393C3A383C3A3638363C3E3C3A3A3A383838393B3C3E4041
323E3A444557444E3F463E4445414C484A4C4E59615C5D5846454B505358564C4D4D4B49
4B50565A5E55554B4A4A3F45423F3A37373A3E40403F3C383F353D363D383434383A3937
393A3B3A3A39393A39303F3740343D463F353C3436393E3F3C463D46393B3A3C3E3C3F39
453A3E403C3F3B413D47484F3F473A403F43363C3C3B363B373E3839353D40413C3F3E3E
3A383A3B373D505C5C586575818C8F8E8D8B769C81A08AA5939E9BA99DA49B8E88879989
A196A2939F96A994B49CAB9F9CA0A49E9CA5A398939C91AD97AB9CA69CA499AC92AA94A0
9499908D907F8A7B7B7A8D779B818F8A8090969CA19A9FA19CA99AA2A9B2919C8FA9A1BC
BCCBBCC1ADB3B5B8B1A8ABAFAEAAC0ADC5B6BEBE
4A4D4D4C4E4C4B4C4344454544434140464544464A4C4D4D524644494B4E545750525766
70696A575952585C594D4042433A453E545B5C575651524B4A50504E4545444445484C4E
5854638396B9B5BAAAA48F948EA6BBCAC3B2B6859D92B1BFD2CFD4A4A796A5A3B6B7B7B7
C9DACFC2BFD1C3DAB5C2A5AC8D9992A1AAADBBA9A68D8969604D55586E5E4D4245474A48
414C3F53547B798F70715153405A535F4E4846434D4543404242404433463F42494B4846
3E3C444141433E41394B444B556E82A696948A897F806F6560596F5C6156504A403E3F39
383D3B383C3D3B3C3B3C404743434343423D3D3B3D383B3C3C3E4346443E3D40373D3E38
4142403C41413E3D3E3C393C505758494345537369696164514B453E473F413F3C41403F
483F3C3C3B3E3F373A3A36373C3E3C3D47434243403937393C403E3A43393D3B4042443A
40404842473D453B4B3F3C3D47484540424F58536671757474706D614E483F4744544E57
4D49463D484C57586A5964486A585A47404E525A626771746E716E7F70746658545C6E68
6E6478877F82817F83909DA3ACB5AFB5A9AB91997A6D5260626D768B968D9387A2889289
8981867B796B6462707E8485817C7D767D827C977A8D7A8A7B8A75907B7E6C62725C704E
6953584C4D4F493E3C4042434B50575B606752514A47473C3C403638383939353540453E
3B43413B3636363A3B3E454C4F5253505A5B594B433B47414A5649634C5F51685046383C
484545515248524658515D4F4A3F4F4B5A4F4E454045433D3D3E3F423D3D3C3C3E41403D
363B3936373837393A393736373839393A37393C3A3C4143433D3E3F3D3E3F39383B3B3C
3E3B393E393B3D3B373536383C3C39383C3B3737393C3E3E3D3D3B383B3B3C3D3C3A3735
3B423D3C3A423841393E3840413B413B3B36433E5543514845444547484D4A4141454540
3F464C4E453F3C3B3B403F3B38393A3B3A3837373C393D353E333C333A35333841454039
3B3C3D3F403F3D3B3B353F423F383C4F4840443E403F3C373B4141443D3A3D3D41443941
3B3E343B403B423D4B444D4B56495D495C48584C4346434A474B444140403F424549443C
3C333F313F436C7D80837B929C96A295A58AA188AB8A9D9AA0A0AA9CA4939C868B958E9E
98AA9C9889A596B997B296AA9299919D9E9EAC9AA089AC97A58CAD98A29AAF97AA959F97
98989AA49DACA2AE9BAE92B194B294A6AEBAAFC2BCC4B9BCC5B7CDBFD5C6C4A8CFC6DFCD
D8C0D8BCC7BCCBC6C6CBBBC4C5D1C5DAC5DAC2CE
464543434240444C4A454345454140414242403D404647444844484B4642434244434045
44424B43453C3C3C40423E41474A5850544C4741434340423B4040454041424243454A4D
4A40414E5369646568685D686673828C96A2A2A79CAAA8BBC0D1BDBFA0BDB4C0BDC0BCB7
C5D7CFBEB6A9BEA2B7A3C5C1C1BDC5BDBFD4D5D1B79E7B937284738D7B836A7B5971616F
545C7773ADA9B3A7AE818470867F906A60524C4A5246413D42474D5A4D635B5A8488837A
695F5E535B5159484F4B5E6B777B9E8E9F7E9B939079725452584E454B44413F3C3C3C38
363C3A393F424142433A3545484C44453A383B3E413F3E3F3C4753554F46403D3F46453E
3F3F3F423D3C3C40464A4E536866695D505359605D564B4C3E403E3E3F3B3E3F3B3D3E3B
3D3F3F3D3B3C3D3B40424343413F3D3E443B393E403B383B3E444641483C42404145453C
403C423A4342424540403B4E4D53555555626B5F66656A5D61504E404444424E4C504545
4644433A413E44474542433F3E423A3B3C46474948464A474945464A4D464F45404F566A
737C767D807E7978808B8D88959693888B837A85797263767A7A788188918896909B959F
8B908294798D7989848F91938E8787808976927D9A7E9496907B866F766A61626F6D5256
4C4B463A3F4746464F525051535B5557715974585C4E5137444E4B4743424444464D4837
393F363D3646454C455A5478516C555B4C4C4B454744555369637E5E7047555853464B5C
5A5D65585A5446423541454742443D594357444643454443403D3C3E3E3E3C3A3D42423D
3A3C3B3939393A3C39383838393938383B37383C3C3B3F443B37373B3D3C3C3E393D3C3B
3E3C3B403E3D3B3B3B3B3A39393836383C3E3C3B3C3C3D3D3E3E3C39363B403F3B373739
393D3B3A3C3E393E3C3B34393A373C393D3F3A4444424241524A4341424343413E43413A
383F423F3A3A383C38394036383838373536383A3D423643314038383A36353A41443F39
3D3B3A3B3C3D3C3B3E41404638433F4E3F3B3B3B41474743413F4841453D494747484745
4A46474E5257526668796D696678606B5F71576F5B676770696A6764584D5C4A5F4E5745
434035403D6A7C91948F9A9B9EA59DA19E9C85A286A1879A949E909F8B9E98948C849B83
A58E9F8E9B939E89A98D8E8083798E969BA9A5A8A4B2A4B5AAB9A9B7ADB7B4C2B6C4BABE
B6BABBBFCDB9D1CAD3CAD3B8D1B8C5BFD5CECDC7DACCCBC4C5DBC8D9CDDAACA7B0D0BEDB
C2D9C4CECDCDC5CFD3CCCFC8D3D1DEC8D8C4CFCE
4D49494A46434850474240444642414340434341424746413D414848424346423E3E3D42
3E404642433D3E3C3F4541434D55584F4A404846424640473E403D433F40414041424649
50494646404844424649414B484645464C59787D8776847EA0A2B599AC99A7948D929191
9AA6A5997F84769781AAA6B2B4B8A5ABACAEC0A8B07F80657955615F737C978A917B8887
9FB39EB5B6DDD0DCC4D1B7C5B1BCA2B1A18D817471616264746FA290BEA7BEA9BEC5C6C4
B8AEAC9E8B7C6868525A5A74606F5D7655716F7D6F64453A453C45383D3F3D3E413F3B3B
363B3936393B393A40433C3E383F3D41474E5A68685E4E464354605D554F473F40413E3F
4040424C5051565F676D7171675B5B5549464241413F40453739393F403E3E3F3A393D39
373E3F3E43474E5751565954473F3E404A434145433E40474750514D4C3B3A373C403D34
3A37423A3F3E3E403D444A646C7779756B6B705F555155424C44483D4042404844444042
403D3E3C4639383C41443F4536453C44414642403C3B423F44413E3F423D4B4737485164
717B74766E6D6A68696A635A6768625C5F5E5768686559676961595A68667458766C7F79
897B8478877E8382737A79797570716B767A6D91788E748A737851694D554F534F47473E
5B4B61504B4F4C4E595B53514A4C525A51626A6B6C7B6D865E8554564A474745464A4433
3B33493B625B7469706C856D7558624E454D52535F5A6461616D5F7653664A6355655B5D
6C675C564F444D3743384C444A4555535745493D3F3E4143413E3D3D43423D393B403F3A
3D3C3C3B39393B3C37383A3C3B3A38373B393A3D3D3A3B403E3E383E494135383A3F3D3B
3D3D3C40413C383A40423F3B3636373A3D40413F403D3B3C3E3E3C3B383B3F3F3C3B3C3E
3A3B3839403E3C3B3F3B353839373B3C3B3E3743404142434D423A3E4343454C4447443E
3E44433D3F3F3D464441473A393A3A3837383B3D3E3543313D33423746413C3A3C3F4041
45413E3D404448494744583A5653675D494D4D545D64625D54584D6249645E695A6D5778
56725B7275747F788E8B8D7C957B937B81779085808C888F898C8E8B777A6C8773896C61
413C383A4A7B8F9899A89AA09C8D9584947F9478977D8E888B8A978795879785828D8496
86998E93879A8C9F879B8EA2858792B3B8B4C6C0D3C0D5CCD6CADCC5CFD1DED2DFD3DDD4
DCD8DEE4D6E4CFDFCAD4C1D8C6DDCBD6D0D2C8D1C7C8B7BDBFB6D5C4CBB0B58C9E9DCBC0
D1BDE1C3D1C5D5CDCDD5C7D5C6D8C1DCC0DBC9DB
4C454446434041424541424646423E3E4244423E3E4345443F4349464045494444403D42
3E42413C403D403C3C414045474C46413E3943413B423A413C3C393C4141414140414345
444346463F43423F44453F4A4D49484A3B465C6664535C525764576B5566554E494D4F53
5353544A514561507163827A7F7A817D79796C6767594C53414B3F47576A7184747F7A86
A2ABB6A0BBB2CDCEDBC7D9CCD3BBC8B5BAA79B887F76879394A4AFCEC5D5BABCBFC1C0C4
C0BEC2B89D7A6C575846474D3F3B4138453E4E41493A4235444538444145413C3E393438
3D444340424342444B5A636352484B5D767C848F87775F52465157514A494641464B5164
6F71696D7B77736D6868655D4F4544423E393847453F41493E413B3F43413E403B3A413D
3F3F424C5A66737F776C5F52474444424444454541404B5961675D574E434244494F4B48
514F5C514D48565166626C767A867F76665B5D4F4A3E4238413D424444464247403A3B3D
3A363941554841434D464E3F423F413A414542413C3C433E40473F4B404D4D524C5E566E
6177656A66615D5E605D52494F495347594D50585F60565E615A535155594C4A4C645A58
4F524C5C4C5E4F5C51534E4D4A4548456258776E8D6E726F74626A575C534D515152546A
607052564947454A565F61616566656568547C6073658D637F555F47413E3E3E4049514E
4E5B4C73608670736B805A8D59916671555D5E585F575B5565566F5874585A5862655F5F
595A5F4848453F403B484D4E48534561445242483F3D3E403C3B3C3A46443F3B3A3C3B38
3C393B3C3837393A373A3C3D3C3B39393C3E3D3E3E3B393D383C38425A543F3F3B403E3B
3D3D3B3E403B393C4245423E3A3B40423F3F4140423E3C3D3E3E3E3F3F3D3C3D4041413F
43413A3E413F3F3D3E3A393E3F3B3B3E3C383E3B483C4A464B433E444B47454B46484744
464A494447423C484E4B4A3F3C3D3D3E3D3D3D3E3B33503C52495E515656565556585C5F
5E6063686B6D6D6C677A63785C8F767B67726F7576766E65795F7D52735373635E6A6773
676A606C6B76737D7685808184887883708F7F9784918A96969A9A8F8B72987BB0879466
453D433B4F7587898D8E938E8E8C7D7A7B847394779A819289978FA090A19D989A95AA95
B09BB0A8B8A1B190B99FB8A8A18EB0C9CED4D0DCD2E3C9E5D4F0D1DCD0E1D2E6D1E8DCDF
D6D7DAD6DECDD7CFCBBED8BBE1BFD3C2CBCBD9C2BD9E9EA4A3C2B9CDB8B48D868DB7B4D3
C5DCCCD5D2D3CDD3D4CFD3D1CBCBCEC4D6C7CFC9
4D4644454343443F41414143423E3B393F403F3C3C424A4F48474A484243464344424044
3B424040403D4243464742444546443F3E3E403D40483E414343424142413F3F40404140
4C4C4C4B454748424B4B4145453C3E4442424545413E464D51494C41493A48394144464C
4A484D444046414C3D4A4A54444E48524E3C4343423F4340383E3C3E38474B574B5A6173
7F8D7D82758B9AACA8B4B5C4ABACA7B7AD9A9387898FA9B5BAB4CFBAD7AFAAA0A29F9EA6
A39C988B6D59484A484C3B3A3A404345464547373F3D3E3B40363C3C43423D38393F4850
586264616467696D848B9592836663737C7A7479706A5B57434343423F3E41455868768E
9897837D736D63534849463A3D424E4C474849534F413E4641473D3F3F3D393D3B3B4540
483F4F666D737A7870625A5A5F6A726F6D6960554C4A50584C55494E494F535D666A625F
69667366676B6977788573796D77686055494D47453A3D3F403D3942393D3C44423C403F
40444848574F515A555B595C4655433D4548484A4749524C595C6A5B62585C565E626D61
6158594E4E48485055514A4753554E6253614D5B595D54555854504B63595D445B545143
4B49574B4B3E424844443C3C3A363A383C434055495443565B64556C616F6D716F5D826A
82544C3C3E3B3F47536372798075716E63645F4D535D527B5B76585E4D4A4F585C626969
77697B62796475626B646B5B7872796A69675F4D4A48574E575A5B6D616D51616273615B
635D5C5654515D4F554B575053554B4D4B41403E45403F3D383C403D3E3C3B3D3E3D3D3E
3D393C3F3A373A393A3B3D3D3C3B3B3C3D43413E3F3D3A3C383E3B404D4839383B413F3B
3C3C3A3C3F3F41434546454540434B4B413E424144403F4142403F413C3A393C42464747
3B3D37413F3E41413A383D43433E3B3F3C41384640454549494A46464D4C4543464B4E4E
4D4D4F50564D434B534D49494A453E39393D414548545F796A8A808172767B7F82848483
7F858D9496938F8D9C8F9E8397868C807884777774787673786F6F766A7B767661696471
6B7168726B69716B6D61676A6D5B6B5E616770726A7C7A8C90959689808888A38E9F897D
5C5B5A6E6D9B929B93998E9899899092A797B18DAB8EA198B0B3B9B0B6B0BEB1B3B7B4BE
B9C2BCBFB6BBABC5A8C9C4D1AA95A5CAD1CDD5D6DED0E2CDE0CFDECADBDAE6CDE3CDE4D4
DDD8DDD8CED9C6CCC0CBBBD8C3DCC6CCC8CBCCBBA08D869AB0B7CCCBD0B3AF96B9C6DFD1
DACADCCBD7CBD3D1D4D9CACEB9CDB5D8C2DCCAD5
48444544404346434041414142434343404244433F3E4043453E4144403D404140444A4E
3D403E424E424042494C43414342463E3B413F4241493D3D4342443F403E3C3C3D3E3D3C
4744403D3A3E443D474A4447473D414B46414639413A3E4A42423B473F4149463D3F3E43
42454E454C464C414C4147414142435053413941403A443F3C3B3C3D3B3B3A3D40454648
4750575B6261726F8676868D8279827787746F6D7E8DA5A9A6B09BB0989B6F7F5F626F86
89796752443E454A5C665D54505D5F5E4E4C4B403F36473F40413F3F474243454B627E8C
9EA8ACAAACAFB2B8AFA79A857B5E504C5C54464740433E41433B3A40413D424D5B707A85
817C665D42454742434F51434B56665748575F5644393D453E43393F42413C424345514C
634F61776B686E626467757E7F858C8C81735F4D4442403D41524D615F6C6E7878766359
605F7165716B6B616B685F5C525B484341363D3B3B3E43433D463A3B44443E43433C413E
4950524E5E554D4A666176525C52655B605E58565359686567737A74686958554F64646E
445041423C404A54514749525A4D58535A4E4D4D5359504C52545753504F54505B5D504E
4A47494840403B433E3E37393A393F3E3A3B453F443A3B4745424142444F51565B5C5264
58443B383A373D4447556870736F696061515642544052597D707E707568656B6E6F6E6A
696D686E5A5F544E4F61496353765C62606064595253614E5754655B5D555163616C6265
655C5F55575B625547414C4F4B5542564D4F3E3F45413F3C39434C49403E3E413F393739
403B3F433D3A3C3B3C3D3D3C3A3A3C3F3F47443E3F403D3E3A4243403E3B3A403B42403B
3C3C3A3A40454A4A4846484C43485251443F43444442424545424143404142403E3E4043
3D44404B413B3C3D39373D44443E3C423B393E3C473C4946464F4D49525A554F4C535A5A
5551565D4F4840474F4B4C5B4C47413D3D3F40415B598A7D9990A08C93929395989A9998
9496999A9998999A97938DA2939A87958E9E91918B8E8D8C9E84A384A0889B879B919687
9E8D97959D9696A09A8E89917878716D65725E6F586F6F81848E9993A195AEA0B3A1AE95
A98DAF96BEA9B09FAEABA5A8A2949EB8B4C1A7C59DC8AEC4B7C0C1C5BFC4C8BFBEB8BFB9
C7BDBFB7C8B3C2B4C3BBD2C3B591A4C5CFD2D0D7D2DED0DED0E4D6DDD1DFD1D8CCD8D9D6
D7D5D7CDCDCEC9C5D3C7D2BFD3C1CCC1D2CBCEB5AD9BA2B7C1CDC4CDCEC6BCBBC2DDD9D8
D2D4D0D2CDCDD3D4D2CDC8CAC9CCD7C3D8BDD3CE
4747464341414447433F3E41434242434346453F3C4042413E3F414241403F3E3B404446
444343454342413E3D404448404E4E413E42424042453F3C444948494E49403A3D42423E
3F3A4048413B3E423E41403E404546434240403F3C3B4047473F3D463748424D45535048
4347504C45434244474744413B3D3F3F3E3C3C3D3D3E3E3C3A3B3F4340423E42403D464B
514A5968685A505A4F4A4C3F434B3E444B4B3D4F626C7E778675856E71554D404347576C
72634F4544404C67807969757A8D7F6E4C4E454D4F4644414539496367686A6B7494B7C6
CACDCDCCCFD0CBC2AE9A7E60463D3E3D40403D3B3C3839413B393E3B413D444657536252
4C53444A4448455363686554484F574B4D4B4A4F3C3F423C3D463D42413D404D53556563
655F6264696D66675D757773687371695C564F41403F45455C686B6E696D705E595D5050
544E5050524E4946474B4F5143423F4046433C43443A3F4951403A393A433F504A514852
4B555755534B474D506668635355586856624C454D556562786875637461554449495251
44454B4540484F555E5F55564D514B4B4745455347534D5354515A4F524D53555E534D46
5144404849413D41403B3A3C3D3B3E43423D3A3D3D3B3A3C3C3A3D3E3A3C4140453F4042
3D3B3D3D333939393E3E3D43404345474B4F4E4A4A595B62637B6D74516155555B585D54
564B4A423E3F3D473E3D4549515C5F6668625C5B5D5C5753525F5B504E4A4B5A5169696A
5E5C5959544F4847473F3E4A53484F43513D433B3D3B3F3A3E3A4142413E3A3F373B3E3B
383C3D4035383843423C394442473B4541474340373D40453F413F3F3E363C3B3F404041
3E3C41423C4451585B5B5757504B53434140464446453C46483D434F4441493B4B3E4A40
4F3B4743434A484A404C485152534642443F3D45434842595C72667D74837C8177757B73
735E7B677A54574F453C47505A4742444341475C66818D9A969F9CA596A395A9A09FA1A4
9F9FA6979A95A295AB9CAEA4B89EA89EA7A8A9A199999DA4A3A49EAB94A5969D93A093A6
A5AFAEB6B1BAB3B6B9B7B8A6B394A287AE949F634F678B929799989F9FB6B1B5AFC3B3BF
A6B5B8C8B9C3AFC0BCBCAAA7ACB1C1C9CDC6C3B2BDBCC4BCCDB7C7C0CDBEC5C6BCC0BFC5
B8C5BAC2B3C5BFC0B2BFC9CFB3A8ACBCC7CBD0D3D5D9D4D7D6D1D5D0DBC8CECBD9D6D9DF
D4CED7D0D0D7CFD6C9CBBEC8CECECBCFCBCBC9C5C2C4CBD1D1D2CDD2CED5D2D5DFDEDDCF
D9D1DBCFD3CFD5D5D4D4D1D8CAD6C9D0C3C9CAD6
44444443424243443D3B3D43464442424644434343414346444442403F40444840434443
413F41434849494847474747414D4D44434544434949423F4547424142413E3C4044423E
473F40433F3C3E3E3D4142403E4043464341403F3D3B40474444495445514C574E585146
434950464543414243433F3C3A3C3D3E3E3E3E3E3D3E41424449505644494D5959505355
58515759544A41484640433D475041413F41394147474F49463C4D424D4343393A3D4754
5A57545652474A5E726D657982907B64454F56696F6A696162576A8394887D736D7C94A2
ADB0B8BFC0B7A99F988E86775D49413E373A3B3D3F3B3B4342464E494B464D4E4944544F
5563565B575D5F6D7671665345473D413F4F4043404C464935463D5242485D5F73647263
5B53596468665C604B56494E46464A443E423A40384643464C605063596A564D4249444A
525152503D4042403C3B3D413E3B3A3E44433F414D434B4D5141413E454F4D5B5355464D
4C524D444243454B424F4F4E4546454F434A3F485357646168666B655E594B4A45444B49
3F4249434E535758584D413E43444A3D453A464F4B58565B52455151584F4E4A4E45433F
47414045443E3F453E3C3A3B3B3C3E413E3A3A3D3E3C3B3C39373C3E3C3F44433E37383B
393B40423A3D3A373B3C3D443B3C3B3B3E42403C43484A51495C51543544414B55555C52
4E3F3B3B41453D3D413E454B5662626560595253595C575150524D494A44444F5668615D
4E4C4A4D4C49434042404450494E3B533A4B353D3F3E423A3C373E4042403B4439413C3A
393D393A36423E3C3D39414C4C4F454846414838463F4C473E413842404747454B443C3A
3C3D3B3538414E5555514F514B485446413F474A42413E4B5B565D6259535347464C4648
48524E6E5C816880687667737169615358454F3C57495B68818B90909F9AA29F9E969595
88859192898B76754F574D6E48533B373D4F77778B8EA490A9929F999D9B9E9E9D92ADA9
A9AAAFB1AABFB8B9A4B39EBDA3B59BAFA8ADA5A39B929C9EA5A6B9B2ACA1A09DA7ABADA4
B5ACBAB5BFBDBBB6B9C2C2C0B3BFA8C1B6D5C0B6828297B1AEB5ACAEA69EA999AFA4A8A4
A9AEB8AFAFAAA8B4BABFB8BCC4C7D1D5C4C6ADC2B3D1C2C7C4BEC9D0CBC3C0C3BDC1C2C6
BABFB2B6B9BBC8B4C7B7CFC7B4A1A6C1CFCDCFD4D5D8D3D6D5D1D5D1D2CACDD1D4D7D0D5
D5CDD4CECDD3CAD0CDCACBC6D4C6D1CDCACDD0D1D2D3D7D9CED3D2D9D4D9D6DAD4DBD1D4
D0D8D8D2D1CDD3D3D3D4D2D9C9D1D1CCD0C4CCCE
4443424343434342403C3B3D3F3F4143423C3C44443D3C423D4146464340404140414241
4142464948484746454441403D45444042423F4149453F3F44433D3C4343424041413F3B
3F3B3C3D3B3C3D3C3D3F41403C3D465046423E3D3C3D444B5C5C5C6251564D53585D5247
474D514543403E3D3E3E3C3A3A3A3B3C3E3F3E3E42444646484D5459484D525E5C4F4C4A
49484E4B4742393B3F3C413D464C3C3B3E4141403C393B3B3F3945404542433D3C414749
474446494B3E3C45514E4E65687361523E4B50606B7078706C5D66747F766753474C595E
736F71797B75706F7579868A7253403844443F3C40444E5B63686B5A534B514F544B5654
5F6D5F606568686B65564E4650434735504B4C454347564A51474F5B647C829188857267
655746574449354546483E42393B3C3E403B4332423C4B474C5661546656594B42484344
494A48423D3F403E3B3B4044434042464544464548404A44493F48424F53494E44463C44
474B463D3B3A39393C3F3D413F3F3A3E42443F4950525A4E5E576A525E49524D4B494D4B
44494F4A4A4C4E4D4D403E403F4B414D415048524A5453574B3A454B4B44423F423F4141
484441413F3C3B3D3B3C3B39393C3E3E3938393D3F3D3B3B3B393C3E3A3B3E3D40393839
353539393D3F3C38393A3B403F3E3C3C3E413F3B403E3F483A4741423B403F4B5151574D
50433E414A4D413B433D40434C534E4D4B454046535C5A555E544D4E4D45424844544B48
3D3E4045504D49464C474443443F433C443C42403E3C3E383E3C42414D4940483D483F3E
38433E3E3F52524A4E4054464F42483E4A4F3C4B3B5243463D3E403846414D42544A413E
41403B3A40464E5554515860605B5E594A4B4B51515B4B71718C7F857D757156694E6959
796796859A879D8F989A9B9C989A827C79785D79658879948FA38DAD95B4A1ABA69FA09B
A782A99CA88E9C707A59634D4943444043576F8A8C987EA187A88F9F99B299AF9EAEACC5
C8C2C9B6CFB5CDB3B79EC2A5C49EC0ADB5AFB9B1A8A59AA5A5BEBFDFB0C6A7B3ADC1ABC5
ACC5B2B8B7BDADB4B6B1C0B7C0B6CBB6CCBDD9BBC5A3B5C1C7BBC3BDB39A878B88989399
97A798A3798B82A2ADB7BAC4CDCCCDCDCEB6C3ABD2BACCBDC6BFD6C4D0B1C5BDBEBFC4C4
BBBBB2B6B7C6B2CFB8CEC0C5B09599BDCECACED7D5D6D3D4D4D1D5D2D3CBDBCDDED1D6D0
D4CDD1CCCDD3CBCEC7CBC0CEC1C8C6C7CFCDCDC9CBCACECECCD2D3DAD5DAD7DBD7D6DCCA
DACBD9CACFCBCFCECED0CDD3C8D7C8D8C7CFC5CD
48454242444543414B454241414042464540414646403E413E424544403E40433F404141
4244484B45423E3C3C3D3C3B3C3F3E3E413F3B3E423F3D3F41403F403E3E3C3B3B3D3E3F
3A3E42424040403F3F3E3E3E3B3B44504D47424142464F575D584F524A5047484E4E4441
404146403F3D3A3A3B3D3D3D3C3B3A3B3D3E3D3C424445454445484C444A494B473F3F3A
3939404141413C403B3D423E4142383D403E423C393B3C43403E484D494446473B414646
42403F3F3F3B3B3B40403F4F454E44423E4740414D56625C57464645525953403943473E
403F41474B4A48494A526670655448414948403E4A5C71858F8D85695E565B574F454B49
515D515255575753463B3E4640474054526F626F4E584C6D657E6D7B808AA491A7848678
775C554A4E42454F4A535755484A4143444B3E4C3F58535C627260744E61484B53524942
4244423B3F3C393A3D4142424041454A4445504F4544424B4352534F565647443B3F3C46
3A3A3A3C3E3D3A3A3E3B393F413F3A3C4043404449555C494F4A49454847464444424442
3E4346413C3A39373A313D444E4D5A495C4D55484247444843393E3E403F3F3F403E3D3C
433E393A4044423D3A3C3B38383D3F3C36383B3E3F3D3B393A393C3D383739373C38393B
38383A373A3C3D3C3B3A393B3B3B3A3B3E3F3D3A39373640373D3B40443D363B39383E34
3D383636393A3532403A3B393C3F383846423E404950504B5A4E484845403E40414F4746
3D3D3E425249423C484A4A43423F3D3A3B3C41443E3A3C3743454A454F453F3B3D444141
394946443D4C535163536E5A67586758675D6A526A5763544A594E53424B474554494442
403B3D505E636973736C70748B7285667B607068817C847F99949A8C90898581778F828E
88A58CB794BD8FAC97AB9DAEA9A0A393A68FA284AB8CA297AAA3B39AB7A0B3A5A6A29EAB
97A599AA8EAD91A482966F8466856E6D66648B8099839C7CAD8BA99DB5ADC4B7C0AAC9BA
C2BCB8C2B5CFB3B9ADBDA0BFB2CAADC0B8C1BBC6C0ACB1AABBBEE3CDD4B6BDB2BBB3C6AC
C8ACBEB1C1B3B8B2B4BAADB1A7C5A5C0BADAC1D0CCB6B8D9C7CBC7CBD5ADB293B8A6B9AE
A6A4B58E815A7891B3BDC3CAD0CCC6C4BFBEA7CAB8D3BCC6BDC1B5BFAAB1BAC1C5C2C6C1
BAB7B4BABFBAC8BBD3BBCCBFBC9D9FBDC7C2C8D3D6D6D3D3D2D1D3D2D2D7D5D7D1D9D3D3
D3CDD0CDD0D5CFD1CCC6C8C9CAC4CEC5CECACAC5CBCACFCECDCFCDD4D0D6D1D3CFD7D4D3
D5D6DAD1D4D0D2CECCCECBCFCED5CDCECECACBCD
4D4944434446444244424244434040424345433D3C3F4344474847443F3D3E4140414141
4040414242403C3B3C3D3D3C40413F4043403C3F3F3E3F3F3D3D3E3F4644413E3B3A3B3D
3B3E3E3D3C3A38373C3B3C3E3C393B403B373436393D42484E4D424340444040413F3A3F
3E373E433F3D3A3A3A3C3D3D3E3C3B3B3C3C3B3A393C40403F3E3F403D45403B3A3D433C
3E373A3A3B3D3E48393C3E3B3D3E3B44433D413A393E3B423D3F4B584D41454E3F403F3D
3D3F3F3F393E423B3C403D423C423B3C3F473F3C44454B42413A3C363744453A39423F35
373B3D3D40444340434447464246494344464345546475848681765D585559544840433E
414741464A4B4E4B423A3B444040574D6B64727675676766847C7F78788684918484727D
797C5F815F8A6E826E7C5E66584F61595E5B6A5A6E637068756B735D6C595E524F4A453E
3C403E3A3B3A3C4043433F3B4142404541424E48564C644E6C596A534B4F464540423D42
443A363B3D3B3C413C383B3F403C3D3E3E3F3E4045535A4A4C463E3E4142413C42414140
3E41423C403F4242483E4E4F505B505B445243443E423F3F3F3E3F39393C3F4243433E3B
3E3C393A4046443F393C3C38393D3F3C383B3E3F3E3D3A3737373C3E3B3B3D3B3F3B3B3B
3A3D3F3B38393B3B39393B3B3B3B3D40403E3B393B3D383F3D3C3A444E443B3C393A3F38
3A3C3A3A3A3C40413C3A3E3A393C393D40413F3B3C41413E4744423F3B3D41434C584F4F
464645494D44423B47474E494342423E3E3D3F3F414247424D5057535145433B43484444
41504E554E58666F777C7C987A9582837F8B7C90788D7A7F737B806F7160685B65524945
3E36436E8585808A8F8F98999795819C7C9C879791A385AD86B897A29E9C9D8DA38DA998
B198B998B091A78D989FADB0A8B1A6AB9BA68EB598B79CA39CA797B29DBFAFB8B0B3A99E
AB96B4ABC4A7C3ACC6A8C2A2B5A2A9978F94889B99A790C09FC5A9B9ABC3B0C7BBC7AEB9
B9B0B4A2C3A0B9A2B8A1BDABC5AEC7B1B9B3C2BEBBBBACB4B2C4BBD7AECDB1BABCC0AAC3
A5BCA9B7BEBAA7AFB6B1B6A9BBADBDA4C4B2CFB9D0BDC5C4CEC0D0D1C6CCB6CFBADAB8BD
A8B3A9B47F7B7FA7C6CBCECED0CCC5C5C1B1BCB4CDB8C3BFC5B9C1AFC2B1D3CECAC6C8C2
B9B3AFB6BFC8BECFC2C9C2C5BAA3ABC5CACAD4DDD8D6D5D3D1D2D1D2CFCFDBC9DACCD9CE
D3CECECDD0D3CFCFCBC5C5C7CBC8D0C3CBC8CECBD4CED0CBCDCDC9D2D1D5CAC5CDD5D4D2
D4D4D8D0D9D5D6D0CED2CFD1CED5CDCFD0CCCDCE
4F4A45434546454443403F404143484F6E72674F4144494742424141424241413C3D3E3F
3F3E3E3E3C3C3C3D3E3E3D3C3F403D3D403E3B3F3D3D3E3C393B3B353D3C3C3E3F3E4042
3F3F3D3E403E3B3C393C424645413E3E3C39393E41403F40454D46443E3A39393E3D3A42
3F373F48413F3D3B3A3A3B3B3E3D3B3A3A3A3A39373B3F403D3A39393C443F39393F463E
3F393D3D3C3D3D45403E39373C3C3B40413C3F3C3E423B3D4A4B535C4D3B4046433F3B3A
3B3A3938373D4238373F3C3B383F3B393B403D3E403C3F373B3A413A3E4343404345413F
3E3F3B363A444C4C524E483F3C43453A434643444E565A5F5A5652434643464049434743
4245444C4B464642403F3B3D444C4A5B55675A6A686F59746D806E716F687C68775B6262
73697D688984958C947871646074677C73796B73606E626459685365566D536A514B4D4A
45443E3B414446464442424243443C44494B534856645A6E5B694D453B423F3E3D3D393B
51433D3F3C383A3D3E3B4140403D454748454344454849434E484A3D4839443C3B3B3B39
383A3A363A3F474951434D404B495745493C4E4C424949444041423E393C3C414146423F
3C3F403F3E3E3F3F3B3C3C3B3B3E3E3E3B3F413F3D3C3A383B3B41433F3F403C443F3C3A
393F443F3B383939363A3F404546494B48423F3F40463E41413A3A4245403B3A3A3D3E3A
3F413A393A3C42403C3C43403D403E44494D4D4846494A474246443E3C3F474D4F584E4F
4745444745414B464D4752504A4B55505950514947505C58606470706E72587050724A58
58636073757E8E979D8CAB95AD95A5969C9AAB96A6929E95919C939B8E9288806E52443F
3F40558C8E938E99A09EA29AA88FB382A77C9D909E93AB8BA494A89A9D9C9DA197AE9DA6
99B18EAF96BA93A791A59EAEA4A1AFA8B1A7BCA8C7ACC2AEBFB1CCAECEBBD1C4CED3C3C6
B1CBB3C7C1D7C3E3C7D5BDCFBDC0A7A3A19CA593ACA3C6B1D3B0C3B0AA9DB6ABBFAFBFA6
B0ABA5ADA3B49EAEA0BB9EC3A4C7A8C2B3B9B0B6B6B0BBB6BDB3C9AFC0B0BBACB5A5BEA5
C0A9BCB3BFB0B8B4BFCDBAB9B2CAA5B6AAC5B7CDC7CDC2D0CACDC4C5CACBD2C1CFD1D0CA
CCC2D5BEC79FBDC0D1D1D0CACBCAC3C7BBB6AEBEBBC2BDC6BDBBB0C1B3BFBFC5C4C3C7C7
BBB6AEB7C4C8C9C8CAC2C9C4B9A9B6CDCDCCD3D4D7D5D7D3D2D4D0D2CDD6D4D9D5D8D5D0
D4D1CECCCDCDCAC8C4C8BCCAC3CEC9C3CDC8CEC6D1C9CEC9CBCDCBD7D7D8C8C0D1D3DBC9
D7C7D5C7D4D0D0CACBD1CED1C9D7C8DACDD6CBD0
4A474444454646454E474240434C5A66979E92725852524E524D47454644403B3D3E3F40
414242413A3B3C3C3C3C3D3E3A3E3B383C3D3C3F3F3F4142464E4A3A423D39393937383B
3942484B493F3E494F555A585351525446403C3E3F3C39383644403F3C373A3A3D3F3A3B
39343C3F403F3D3C3A3A3A3B3C3C3B3A39393A3B3B3F42423E3A383840433D3C3B3B403C
393B413E3D413C3E3F3E39393C38373C3836393A3D3F3A39404145463F333C393C38383C
3E3A393B3E3D403B3A3F3C3D363C3A373A3B393A38353C383B3A403A3F403C3B41423F42
3B3C3C3C40454A4D49474948474B493F3D403F40494E4B494241453E423D403C3F3D4242
4345474F413C3E3839414044554F56474F43464C5A6364646C62645E5C5C616156585055
5A6250675681717C6A71516869626F5F605B5C4B524B534F4349504452464353574F5859
504A424243434241404143463C49444F595A625B6C6E81627A5657453E44403C3C3E3D3F
423D3E403F42443F44434A444445525151524D45444442433F473B46383C393B4143423E
3E41424145494E4D5749553D4647454F3F494A52474A4C48413F3F4140413C3F3C433B37
36393E403E3C3E423D3C3C3E3E3E3E403E42423F3C3D3D3B3E3D4345403E3E3A3B38393B
3D4549443D393B3B383C434344464A4B463F3E413A403C3F3C363B3C40433F393C403E3B
44473F3E3E3D423C3E3D444241423D3E474B4A4340423F3940433E393C3C4251565F565A
524C46474E44504F5D59696A66756A846E846B6C606773707B7F8884927F94708F74756C
70787185878A9495A09E95A897A998A2A3ABA2AB9BA79EA1999DA2A0A69B9F9685695645
414251849AA196989A989F9398A298AD8AA794A0959E8FA685AD9AA5A7A8A79FAB9FADA1
B1ACBBABB9A8B1A1A9ADB2B7AFBBBBBDC0CBBFD6C3D8D3D2D0CFD2D3C9D7D2D4D1D8CBC8
CBC0C0C5CFC8D8D3E5C9D1BBC1ACAAA8A29992A2A4B0AAC7B2C9B7B7ACB4AAB0B2BAAAAB
B0ABAEA1B59BB1B2BCAFC8ABBC9FB9ACB7B5B8AFB0BCB9BCB4BBB7C4B1C8B6B5A8ACABB0
A4BCB5B6AEB0AFB2BBC1BDB2BEB3BB9FAC96B3A6C0C5C4C2CFC8CFCAC7CBBFC0AECCC7CD
C6CBC8CFC9CCD3CDD6D3D1C8C8C9C2C9C9BCB4B3BABBBEC0C6B7C1BBC1B5BFC2C3C3C6CC
BDBEB5C2C7CDCAC9C9C8CAC2B4A2B1CDD0CFD4D3D5D2D7D4D4D7D2D5D5D6DBD4E0D2DDD2
D4D3D0CECCCAC9C8C6CACEC5D2C7D1CAD0CACEC4D0CAD4D2C8CDCED9D6D8CCC8CBD6D0D3
CCD1D2CED1CDCDC6C7CECCCECAD1D2D0D8CFD4D3
454444444647464547413D3D41495864657578665350535343444B576160554A47464545
4444434240403E3C3B3D42463B413F3A3D41424546464A505C6C664E524A413F3E3F4349
53687A7D6E59596D737977695D5C6368564C423E3C3A393A3B463E3E423F424045483F3A
37393F3B3C3C3C3B3B3B3C3D3A3B3B3A38393B3D3B3E42423F3D3C3D4440393E3E383E40
3C404337353F3D3B33393A3C3B3539423B3B3C3C3D3E3D3D3B3D3D383A384539403A393D
3C3739403F383C3D3C3C363A41413B383F423E3D3B37403B3B38413E3F443F3940454241
3C393A3F3F3D3E423D3A3F45444546423E4444474F4E423A393B433F423C424346424443
413E3C413E41493F3A40404748484640383A394B475A50584F5454565751604F4E4B4F49
5F565A4B585A5E5A4D514E4F4E5B5049484B4747424643423D3F3E48414835414138464C
46423D433F3D3E42484B47434159575C5D545C5B5E6D665B55493B404046443E3F3F3D3E
3A3C3E3B3B474B4048464C44464A59565F655A443F423F403A3E3D3E423A423D3D3F3D39
3A3E41423F414240525168524F4346484B46474048444645413C3A3F383B373D3C453D38
3E3C3D403F3A37383F3C3C40403E3E423F43433E3C3E3F3E36373E423E3E3F3B3A3A3E40
414442383C3A3F413D3F434140434849443E3F453A3E3F443F3E4943404640363B413E3F
3C4542423F3D443F3D3C434447483E3C45484845484D4A413D3E3637403E445A58676572
6E6A616071606C71857C827996929E8F9F8F9181818083808E919082898A7F8A7B947483
7481798B89898F8B917D977FA17F8B839493969097979C99959FA1A8A19B9EA0907F725D
5759649390A09BA0A2A3ACA0AAA3B8A4B1A5ACA0B4A9B6A6ABABB1ACADAEABABAAB5B2B3
ADC4BECBC2C8B7BCB5BAB4C1BDC8D1CACED1D5D1D2CCDBCFDBCFE3CBD5CAD4CCD5D6C4CC
C2CAB9D2BAD8D2D4C9BCB5C1B2C1AFA290879D9EB4AEB6B0B8B8C0B4B9B3BEB4C0BBBFB5
B0AEADAAABA7ACBEB2BDADBFADC2B6C2B4BAB7B2B4BABEB6B5B5C6BEC1C0BCB0B7AFB595
9CABBBB2B7B4B8ADB0BFB9B9ABBEA0C0A0C0AEBAB7C4C2C9C7C5C8C6BEB4C9B6BAB7C5B8
C4C8D1BFCDC7DAC0D1CECCC3C2C3BBC2C9B9ACADB7C2C7C8C4B6B9BDB4B9BDCECECDC9D0
BDC1B8C9C9D0CAC9CACDCCBFC0A7B2CFD2CFD3D1D3D0D7D4D5D9D3D7D8D8D2D2D6D0D8D4
D4D5D2D1CFCCCDCCBFCFC9CBC7C8C8CCD4CFD5C8D1C4CAC4C7CCCDD5D0D4D0D3D4D8DBCE
D4CAD4CAD8D4D2CACAD1CFCFCAD6CAD5CED5D4DB
404244423F3E40434241403F4143464846474B494144463F4143505A65795E524A4D5555
494447463C43413F454745473A3E393D3E3C464543464C535A626A6F66644F4D4940483F
6477A39A8E6C686E857F72574F59657B706B666156493F3C3B3B3A39393A3A3B3A3A393D
403731373145493C373A3C4043403E42443D3A42393D403E3A37393D383D3E3B3B3E3F3E
3F3F4243403A38393838393938373A3E353B413D393A39383C393B3A37393E3D3C3C3C3B
3A393737423B393D3D383941464A423E3B3B423D3A3C3D3A3F353E3C3F37413D3C403841
3E3D44453A353B3E3A3C3F4141403F3F3D42414147443D3E3E3F444948413D3E393B3D3F
403F3C3A353F45413F4344413D403C3E3E3D44454847413D3F3D404A4A4A53444443474A
47454B50484F5045444C47445051494A524F4641443F3C43374045403B3A3B3A3C3C3D3F
3F3E3D3D3B3A3F424041423E494D4A424043413C4745464949443F3E3B3E46463D3A3E3E
3C3E42423E3C4551494A4447434F555E535E463E413B3F3F3B3B3E443A3A474141443B3F
414842473E40414D50554D4A45444541403C3F423E4247443D3B3C42403C3C3A423F3D36
39373F3B43453F393A413F3A3D3E3D3F3F3F453D423D4442343B3F403837413C3D3F3E41
42433E3A383E3E3D403F414A3F4045444540494F4A4051334E46494A3B4843404F453E45
414A4745494F4F53474F434E495747464F564C49473F4B42403A403C3B55686D79848D8F
958E888988938A9894A198A4A0AA8F9B8DA0979E8C8E97969F9E9D88A386A691A88A988A
98969691979598A590A39D9D8E96888A77897B7F7A847B8A929C93A3AAA3ADA0A792AC82
A0839F9EADA6A6A9ACB3B6B2B9C3B6C9A7C2AFC6B2BCB1B9ADB8B6B6B4ACB6B4B5AABAAE
CCC7CEC8D5C7C4B8C2BCC1C7CBCDD0CBCCD5CAD2D6DED4DDD2D4D9D0D2CDD3D2D9D2C3C5
C6C2C7C4CDCECEC8B9ADB7B6C5AEA392929F9EABAAC0B2C0ADC5B7C1BAC3C2BFC3C1B6B1
B3B6B4AEAFB8C2C6C5B8BCB5C5B7BAB3CBBDB5B4B1B4BABBB8C5BCBAB5BFB6B69BB1A9B1
B1B2B9B8ADBDBCAEACB2B6B7BDBBB6AFB7BEBEB4C2B6BEB5BBC2CACDC2C4C2C1B7B3B4BB
BAC0BCC2B8C1C0C7C9CCC8C5C4BDBCC5C5B9A5B1AFC9C8C9C9BAC1BCBDB7BCC1C8CDD1CB
C5C4BEC9C7CED2CDCEC5CECAC3B3C0D1D1CACBDBCFD7CED6CED8D5E1D3D8D8DCD3D5D2D5
D6D2DBD6CDCDCCCBC7C8CEC5CDBECCC7D2D0D1D1D4C0CCCDBBCBC8D2D2D7CDD9D5DCD5DA
D4D5D2CCD2D0CECDCED0D3D4CAD2D3D5D6D5D9D5
42444543403F424444434141414141403E40434240434644403E45474B5D4D4C484A504F
464245443F44403C404241423D413D40403E4645393B3E42464C52565A5B4A4B4941473E
525C7A6F6A535255575A594A474F57697271716F635140383C3C3C3C3C3C3C3C3C3C3D43
47403C423D4A4A3F3D444A504E4E4D4E4E4540453C3D3F40403F3D3C3A3B3B3A3D3F3B36
3E3D3E403F3C3C3E373B3D3B3B3F403E3D3B3B3E42423E3C3A363739373B403E3838393A
3B3B3B3B3835373D3E3B3B3F3B403F3F3E3D3E39373A3B3A403943414842443F3E3F3841
3D3A4044403D40403B3A3B3E4242403E3C403F4045433E3E3E3F43464643424339383839
3A3C3E3F393F43403F4142403F413B3C3C3C444543433E3E4242454E47454F464C4B4946
4D434F525854584B454C46424B4D474A524D464444413F43373B3F42414041443D3C3C3D
3E3E3E3D3B393E413E3F403C393E3F3C3D4446423C3A3A3D3E3B3B3C39393E403C3D413F
3A3A3B3C3A3A3E43434540443E47494F4C514442413C413E4040404843414F444041383F
454D47493B394745564D51494B4942414248433C393E44433F3E4145383D39433C453E41
36393C413D483D3D3840413E41413F40393D39433B433D433D3D3E43403F48453F3C413C
423C4242424C624F61505D5B5658596359635C6858605268537D63755E70595E5D555252
6F69785F7D68776F767081747B6F7B6E6971616B64625D503F403E3A435A769B8D9999A3
A1A59EA4A197AC94B098AEA3A1A4A49AA79EA8A4A5A1AD9FA0A5A6A3A1AB98B496B090A5
9CA59AAAAAABAAADB8BDC2AFB6A7AAA5ACA39F889088928F979391939CA5A9AC9CB0A1B3
8EB7A4B6AFADB1B6BAC1C1B9BFB7C6B8BEB0B5BAB1B5BBB7BFB5BEB7B2AAB4B8B5C2B3C1
C6CAC8D3CCCCBAB4B9BCBFC9C3CECFD0CBD1CFCED9D7D3D8D5D6D8CED2D1D9D8D1CBC3C4
C4C4CACDC7CFCDD4C3C3C7C6BEACABA8AFB9B5BEBBC1BBB8BCC0BAB8C3C9C7C5C6C1B8B5
B3B6BBBEBEBEC1C5C4C6BAC6B4BDB3BCBCB6B7BAB9BABCB9B5BEC0BFBEB8ADAAA4A8A8A9
BFB5C3B6B9BEB7ADB0B8BAB9BBBBB3B2ADB4B4B6B8B0BAB9BFBCC0BDB6BFB9CAB7BEB1B9
B5B6B8B5B4B0B4B8CDCBC5C1C1B9B4B8BBABAFAAC0C3D3CBCBC0C9C1BBB2B9C1C3D0CCD3
BDC9BCCFC5D2C4D5C5D3CACBC5B9C2CFD3D4D3D9CACFD8D3DDD3D7D8D6D1DACEDDD1DAD4
DDDAE1DED5D2CBC8C1CBC3D2C6CECDD1D1D3CDD0CCC7CECFCAD1D2CFDCD5D1D4DAD9DED0
DCCDD9CDD4D3D2D1D1D3D5D7CADACAE1CDE1D7DB
43454544424143454442414142413E3B3F403F3F413F4045453F423E3A4239403F3F4141
3B393B3B40423E393A3D3E3F393D3A3C3B393D3C393A3B3B3B3D414340433B40423E433B
3D3C493D423A3D3B3940433A383B3C465150525450473F3D3C3D3E3F3F3F3E3D3B3D3E44
484340453E43413C3D43494F5157595854483D3B3D3B3B3F43433F3A3D3A383C454B4943
3C3937393A38393B3A3F3E383942433D3E3A3940423D393740393839383A3C393B3B3B3B
3B3A39393A3A3A3A3A3939393A393B393A3E3C3D393A3B393D37413C403E3A383D3D3B44
413F43443E3A39373C39383C4143413D3D3F3F4043413C3C3D4041403F414242403E3C3A
393A3D3E3D3F403F3F3F3E3D3E403B3B3B3B4445474541424442414647454E4549464340
424750634F504746454A443F454745494D464444414040403F3C3D42433F3E423D3D3B3B
3D3F3E3C3C393D3F3C3D3F3B3E41403B3A3D3D39413E3D3F403F4247413D3D3E3B3D403D
3C3C3B3A3B3C3B383E413D413B403C4043414144413F423F403E3D454745524749474046
4B5048464046404B404A4144464B45403A433F3A3C4143423E3F44484540453C443C4341
3A393E383A3E3B3C4246443E3D3B393A493F413B433A424342403E454440464449473C4A
434F4C575A77708A73917E887C828083947C9585947B9B6F977B918388848A757F7A797A
868F7E99889F8C96839D86A185A085988F8F8E8D977E73556042443D466A92949C9DA59C
A79EA6A79CA296B69ABAAEB4A4BB9EBE9AB8A2B0A1ABAAA9A29AADA4B0A1BFA3B499ADA0
B0A5B5AABDBBB7BCBECDB6CFB2CCB7C6BED0A9B8ABC2A1B2AAB397A2A191A18E968DBC82
B891B69DA2A3ABB4BCC6C9C2C3C4B0CAAABFA8BCB0BDAECAB4C5B9C1BEA8BAA9BAAFACB4
C2BCD0BDD2B5BBABBFC2D0C6CBC7D5D1C6D4C9D8CFDBCBD6D4D3D5CCD1CFD5D2C5BFBEBD
BEC1C4CBCFD4DCD2D5C9D5CAD1C1C1C0C2C0B3B8B0BCB1C0B2C5BCC8C4C2BEBBB9B6B5B9
C1BFC2C7C5C0C1C7BFBAC3B1B8A7B2B1B9B8BDC1BEBEBDB6B5BAB6BEB8BAB3BAA8AB9EB8
B7C1BFBAC5C4BCB4B6B8BABCB9B7B6B5B6B6BABDBFB6B8B8BDB7C1BEBDBCC7C3C8B6B6B1
BABABCBCB9B3B7BDD3CCC2BFC1BEBCBEB8BAA3C1ABD0C4CDCEC1C6B9B3ADB4BAC0C6D4C4
C7BCC3CDD4CCD6C0D9C1D0BDC4BBC1C7CED6D1CCC9DACAE1CAE1CEDBD5D9CBDDD0E2D6DA
DDD7DBD8D3D0C6C3CCC7D8C1DABBD3C7D2CED3C2D1C5D6CFCEDAC7DBD1E3CED8D1DDCDDD
CCDCD5D7D4D5D5D3D2D3D6D9D6D3DCCCDFCDDED1
444545444242434542403F4041413E3C42433F40443F3C44403C42423F3E383E3F3E3D3C
3B3B3B3B3E3F3C38393D3E3E3D3F3F3F3D3B3B3B3E3F403F3E3D3D3E393C383E413F433E
3F3C3F343D3E443F3D41403B3E403F42413E3C3C3C3B3D403B3C3E40403E3D3B3A3B3A3C
403B393E393938393A3B3B3D41494B4A4A443E3E3C3A3A3C40403D393D3A383C47505251
4E4843423F3B383843433E383A434540454B4C4C453B3C3A463C393B3A3A3B363E3E3E3D
3C3B3A3944443F38353839383E383B37383D3B423B3C3E3B3E3841383C3E36363C38373D
3A3C3F3F3B38393A3C3B3A3C3F403F3D3F403F40413F3B393E41403B383A3B393F3F3E3C
3A3A3A3B403E3E40413E3B3A3C3F3A3C3C3C4444423F3F424644434543424B3F3E3A3E43
504852474A3C443C4145413E41424349473E3F423D3C3F3C433E3C3E403D3A3A3C3D3C3C
3E403F3B3E3B3E3F3C3D3F3C393C3D3B3D42434244413F40403F42474742413F3A3C3F3D
3F41413E3F413E383B3E3C413B3F3A3B3D393E424140424548424341423F473F45474950
555753514747483E40404849524D493E4341423B4144403C393A43444B3F3F3947414844
4D44493845444A48494844404044494E4E3D43374834403E3C4344494C515E60664E5E4F
7A68827D8B879B87A493A296989D95A99CAD9BA09A9A8AA383A6919A95A58D9E9299A39B
A494B190B88EA79AAA93B59CB095B298A8AA97A599977F6E56694953548985AC9EA69FA8
9CA69FA7B3A7BBAFC1B5C9BDC1BACBA7BF99B3A7B1A9B8AEAAB3B0B8A8CCAEC7B3CEA7C2
BAC6B2C6BDC1C4C2C9BDCBB5CCB4C4BFCBBAD1BAD2B9C6AABBB2BBAFABAC9390899B88AC
93BB9DA07D8194ACBAC0C1BCC4B7C1BEC9B4B5B5BCB4C0B2C8B1C8C4C4B8B0C0BBB7BABA
B7C1B2C4AABAA7AEB3C2C1C8BCCECDD1C8CED4CFD8D0D2D5D4D3D7D0D5D0D0C9CAC2C5C3
C5C9C4CACBD9D1DACDD9D5D0CFC3C7C7C5BFB6BDB8B2B0ADB6B7BCBDC4BAB5B5B2B2BAC4
BBB9B9BBBAB8BBC0C0C5BBC1B1BAB0B3BDBDC0C1BDBEBFBAB9C1BAC5B7BFB5BBABA6ACB7
BCB4C0BCC3C5C3BCB1AAAFBABBB7BBB6C1BEC2BBBFBDBCBCC1BCC7BCBAC2B3CCB5C4AFB6
B7B7B9BDB9B7BBC5CFC8C2C2C3C2C2C3C2AFBDA3C1B1CFC7D2C0BEB0B1B2B9BBBBCAC1D0
B5C9B7CCCBD7BCD8BEDAC8CBCDC5CACCD0D7D1CAD7D5DEC9DBCAD5D2D5CADDC5E3CCDFD3
D9D0D0CDCCCCC5C5C4D3BCD9BCD4C7D1D2D1C8CDC9D1D1D4D2D0D5CADDD2D7D5D9D4E2C7
E0C5DCCDD2D4D5D4D2D2D6D9CDDEC1E2C3E5D1D9
444444434242424443413F3E3F3F3F3E40413E4045413E45423B3F3F403C383C403F3C3B
3D3D3C3C3E3F3F3C3B3D3E3C3D3E403F3D3B393A3C3E41413F3D3C3C3D3E3B3E3E3D3F3C
3E3E3E373C3C413C3E4039363C3E3C3A403E3D3F3F3D3D3F3B3C3D3E3E3C3A393C3C3837
3A37363B3B38393B3C3A383742443F383838383C3D3D3C3C3B3B3B3B3938393B3F434648
3C39383B3D3B3A3B46413E3E4245454443504D4439353C38463B383C3D3E3F3B3B3C3D3E
3F3F40404848423A373B3E3C3C363C3C3B3B38413B3C403E403D473B3A3D393C403B393E
3B3B3A3A3D3F3E3D3C3E3E3D3B3A3C3E3D3D3E4040403E3B3E41413B383938353A3A3A39
393A3D40403E3F41423F3B38383D3B3F3F3D4342403D3E43444341413D3B453B3D3B4149
4A514749384843433B3F3E3E40404247443C3D413D3C3F3C3E3D3B3B3F43413B3B3E3E3D
3F413F3A403D3F403D3F413F4243423F3D3F3E3D413E3E3F403F4043413F41403A3B4141
3C41444140413F3B3A3D3A413D423D3E3D3C3D3E4141424C4B41483D403E41403D434D52
5352535251515143423F4747554C4C41463A41424047424141424B49535044524B54484B
4C4F3E53456957604D4945423F42494D49433D4844433B3E415964666A7586878B897091
819E8E9D98A089AF90B19BAAA1A9A3A5BA9CB69BA590A78AA28BA194A198A998A2A2A7A4
9DA99AB998AC98A694A891B298B599ACABA7ACA7B3A09F8FB787967C9993B29BAEADBBB3
BDB2BCB8BEC4B9CEBFD4C9CFB8C9B1D1AAC3B3C0B7BCB7C8C9C2C8B9C8BFD9B5D8B8D2BD
CBC3DAC6CCC5C2C5C7CEB5D9B5D1B8C8BFD6BACEBED2AFBDB6C6B3BFBEAEB9A2A8A1B39D
BDA9B39B757183A1B0B5BCC2C7C2B4C7BDC1BAC4C1C8B2CBB4C6BFCCC6BDB4C5BEB6AFAD
B7AFBDA5B7A0B0AAC5C9D2C2CEC8D1C9C9D6CCDCCCDACFDAD7D7DCD6DCD6D4CBC6BDC0C1
C5C7BEBFC9D1D9CFDCD0D7C8D0CCCFCBC1B6B0B8BCB2B0A8ADACB6B7BAB0B4BBB6B3BABF
B1B4B6B5B6BBBEBDBCC2B6B9AAB8B1B4BAB8BBBDBABEC2BFBFC0C8B9C0B9C1B7A9A5AFB9
BBB2BFC0BEBFC1BAA99FA9B9BDC8BAC1B2C9BDBABEC0C0BCC2C2CBBBC1B8BEB3BDABAEA6
B4AEC1B0C4AFC5C7C2BFC1C3C1BCBBBBB4B8A2BEA6CBC4D1CBBDBFB5BBC1C8C6C2C0CDBE
CABFC2C5D0C9D8BCD9BFD9CAD1C7CED2D2D3CFCEC6D9C6DFC8E6D1DECAD3CAD9C7D5C9D0
D9D0CFCDCFCFC9CCCFC7D5BDD8BED8CED6C8D3C7DBCAD5D3D2DECCDEC7DACAD7D1DED0E0
CFDDD6D9D4D6D7D6D4D4D7DBDBD5DEC8DFCADDCE
44444343424243434644413E3D3D3F4143423E3E403E3C3F423B3B393D3A3D403E3F3C3C
3E3D3A3A414142403C3D3D383B3A3F3C3A3A36383A3D4041403F3E3D3B3B393A3B3C3F3F
42464543423E433F4348403E4341403C3A393B3F403E3E403E3E3D3D3C3B3A3A3E3F3B39
3C3B3B403E3A3A3B3A3B3D3B3A3B38383C3B3A3F3F40403E3B3A3C3F35373B3E3D3B3C3F
403E3E40403C3A3A3B383A404443403F4C5649403E424E45483C3A3E3E3D3D3B3C3D3E3F
3F3F3F3F4A4A463F3C3D3D3A3D383B3C3A383C484441443F3F3C47383C3A3E3F3E3C3C40
434039394348433F3D40413E39373B3F3A393C40414344413E40413E3D3D3D3C4543403C
393B41463F40404142413E3A393E3D41413D4240433E4043413F3F3E413C453F45414042
454D584342394036393A3C3F403F4145453F3F41403F40403C3F3F3D4146453E3B3F413E
3E41403C423E40403E4044413F3F3F3E3F404141423F3F43454444443E3E42413A3A3E3E
393E41403D3D3E3E3A3D3A413E454142424540404240464D473E463B443F43403D424F4F
4C474C4C495552584B595559565F4B653F5042594F5B5A6165666E6673647F6383596C5E
786881658C7988787873706B6159575559524A4C48453E4045718C9394979C96A992AE85
AF83A499A295A999A98C9E9AA1A69FAC9FAF9D9F9AA589AD82A78EA09AA795AAA1A2AAA4
A99EBDA0BD98B2A5B29EC5AEBC9FC2ADBFC1B7BFB5BDBAC1ABC99AB388B996C6BCC3C4D1
C4CCC5C7CCBFD0B8D4BCCEC1C4BAD6BAD9B1CEBCC7B6BBBFBFCBBFC2B9D6B2C5BAD3B9CF
C7D5C8D3C0C1C6C3D0C4D2C3D1BAC6BDC7B9D3BCD2BCD2BDC0BCCBBDBAC2B0B2A8BEACC0
A8C5B3AF848193B0BBBABCC0C4B8C5BBD2B6C8C2CAC2CEBCD1B8CEC6CBBECABFCABAA1A7
B1BCACBFA3B5A5AEBDC7C0C8C4D1C8C9CFD2D8D4D8D2D6D8D4D4D8D2D9D5D7D0CBC5C7CB
CFCEC6C5C3D5D1DDD5D7C9C2CDCFD2CDC0B5B2B7B0B4ADB2A1B1B8C4B1ABB9C6BFB8B7B1
BDBFBBB5B6BFC5C5C0BEC3AAB3AEC0BDB9B4B8BDBBBBBCBBBAC7B4C6A9CABABCA9AAA8BF
B9C2BFC6C4C0C1BCAFAAB6C4C5C9D6B4C3BACFC3C5C5C7C2C8CAD1C2B9BDAEC5B1BFACB1
B1BEB8CAB5C7C1CEC1BCBCBEBBBABFC1C3B2C4ABC6B0C6B8CBC5CDC0BEBEBFBAC1CBC0D1
C0D3BCC8C6D6C2D9C0D7CDD5CDC4CDD3D2D0CED3D4D5DCC9DAD1D9D4D2CBE2C7DFC2D6CC
D8D2D3D2D4D0C8CECBD7BFDBC2DCD1DCD5CECED8D5D5CDD6D5D4DCD2D9D0D9DADEDAEBD0
E8CBE3D4D8DADBDAD9D9DBDED4E4CAE6CAE7D6DD
4645444444444444444443403D3E41454A46423E3C3E403D404147454A454A4A42454342
46433D3E414043413C3E3E38403E43403E403C3F3E3F414140404041403F3F3E3F414345
3C3F3D403E383F3F3C474240403C4142403E3E40403E3D404543403E3C3C3C3D3E413D3B
3E3E3C3F3D3B3C3B36393D3B3C3B393D423B35383D3D3E3D3C3B3D3E39383B3E3E3C3E42
3838393C3B38373A383A3B3C3F403D38454A3B3C424853474A3D3A3E3C3939383D3D3E3E
3D3C3B3B4947433E3B3C3C3C3F3C3B413E3A47575A5452494645514151454B443737363B
3E423F3D444846463F3F3F3C3A393C3F3C393D41414447433E3E3E3F3F3E3F424D4B4740
3B3A3E423F42423F3F43423E3E423F42403C3F3D3B373C4241424748453F4843473F3B3C
3A423D3F3B4844413A393B3F3F3E404345423F4042403F433F4042424242403E3C42433D
3B404240423E3F403D4045433F3F3F4041424444433E3D414543403F3F3E43454141403C
403F4042414041433F413E4643494445484C484943414B474A454544574D544654556160
5F5C6666656C7A6E787079717D6C84688B687F7474827F878C8D958A898B86988B8F8289
838D839D8AAC959E928E9192887E7974736B675D5B4F4A44487A9CAAACA8A59D9CA499A6
919F97A3989D9BAE99A19AA1A2A8A8A3AD9FAC9FA89DB092AD8DA5A1A5A1AAAAB6B1B4B9
B2B8B6C8BACAC2C2B6BEBBCDBAC4BCC6CDCAD1CACCC1C6C8CAB8C198A39CB6ADC2C1CDCA
CCC4CAC5C1C5B4D3B6D5C5C9C3C6C1D4C7CAC6C3C1C0B9CAC4C1C5C2CBC2D3B4D0B0CEC0
C6C0CDC0C0C3C8C9C3C9BED6BCCFC0C5C0CBBFC7C2CBBABDBAC8C2C3BFB8BEB2BABBCBB0
C9B1C6B2A6A3ACB9BEBFC3C4C1CAB0CDB0C6BCCAC5CEC4CCC2C7C5C5CAC7BEC0B1B991A0
B8B6BDB2B6AAAFACC8CBD0CAD5CDCDCCD0D8D3DFD1D9D0D5CECFD5CFD6D2D3CDC7C7C7CB
CAC4C4C4BFC9D0D1DBCDCBC3CCCFCCC4B9B4B3B3B3B0B7AAADAFC0BEBBB2BFCBC2BFC0B5
C1BDB6B2B3BBC4C9BAC2B2B2A3BAB7BBBEB5B8C2C1BCBCBCBDB7C2B7C1BAC2B5B0AAB5B5
CBC2C9C8C9C6C9C8BDBAC3CBC6D7CCD0B8CFC8CDCAC3CDCDD4D0CEC5C9C3C4C0C3B9B6B2
ADB5CABCC9BECCC7CAC0BEC0BFC1C6C6B9B8B2C3BBC9C0BDC0BDC8BEC1C5C6BEBEC1CBC6
CEC9C4C7CECED7C9D8C7D6CBD3C9D2D8D7D8D5D8D2E0CFDACAE0D1D7D6D8D6D7D3D3CFD0
D6D3D5D3D4CFC8D3D6D3D5CDD8CBD8D1D7CDDCD2DED2D3D3D0D7CEDED0E1D9E1D7DFDBDD
D9DBE0DFDADBDBDBDBDCDDDEDDDDE1D6DFD4E0D8
47464545454545453F4142413F40454A4C46433E3B444B45505964605C4A47403E434141
45403A3A3F3D41403C3F413B3D3B413D3B3F3A3F3F40403E3D3D3F404442413D3B3A3839
3C3E3A42423E484B4E5C554C413942473B3B3F4445423F404A47433F3E3E3F403C3F3D3B
3D3B37393D3D413E37393C373F3831363D3A38403939393A3B3C3B3A413C38393A3B3E44
3D3D3E403E3B3C3F4447443D3D43423B3F453B454E4E554A4439373D3B393B3C38383A3B
3C3D3D3D433F3A38383C42473A3E414E4C42505D7068645A575968595F4D564A383C3E44
3E4B4D443E3A3A41413E3C3B3B3D3E3E403C3F43414345403F3C3B3E3D3B3E434243423E
3936383B4044433C3D444642424541413F3A3D3B3E3A3E43404148493F3D4943433A3A40
3C424643433E3E3C3D3A3A3E3E3D3F4243433D3C423F3C423C3B3E43423D3C3F3E44443C
393F4444413D3E3F3D40454445444444434343444943404346433E3C3D3B41494B4D4A43
4A454347494747494547444B484D47474C504E514441504041434151736B7C66837E8580
7F7C868386929698939C9B9A8B958E9E909F9297939F969B9D9EA79BA4929B8DA48E9992
9F9CA797A09BA09EA09DA5ABA49D9B97869085947A7D5F5A6389A1A9A8A2A3A1A8A0AD95
A793A39BB0ABB9B2BAB0B9AEB8BCBFBDB8C0BABCB9C5B2C2ACB7ACBFB0B5AFC0C6C1C5CD
C7C0CBC2CFC8CEBDC8B8C9C6CABECABDC9C9CACBC3BFBAC0B6BEA2A790ACA1C0BEC0C6CC
C5C9CCCBC6B4C4BFC3BECDBCCEC1CBC1D0BACBBDC2C0C5CFC2C4C4D0BED6BCD9B8C9B7C7
BBBFC3CAC7CED1CACECCD1D0C9C7C8C2CFC5CABECBC5CCBEC0C3C8BCB7BDBABCBCBFB6C3
C2C1C1BEB5B6BCC0C0C4C5BFC2C2BFBBBEB4C3C2C5C7CABEC6BDC9C1C2C0B6B9BBBBBEBE
BABEB5BBABB2AAAEC3CBCCD0D2D0CCD2D3D7D8DDD6D5D0CFCED1DAD5DAD3D1C9CACFCDD0
C9BFC6C7C6CFCACFCEC5BFBFCACBC1B6B0B1B4B1A6B4B6B7A3B4BCC4C1B2B7BDB4BAC4BC
B7B3B3B9BFC2C9D0C7C2C3B0C1C1C9B9C0B4B7C5C7C3C5C9BBB6ACBBB3C8C8CDB3B8B7C0
C6CCC5CDC5C6CFD0C4BEC3C7CDCFD4C8CBC4C6BED4C0C7C6CDC9C9CCCFCCC0C7BBBEB4B7
A6BDC3CFC1D0CACCCDC4C4CAC9C6C0B6C0B5BEB9C9C2C7B9CFC6CABDC4CAC8BBB5C1C4CC
C4CBBEC9C0CBC8D4D3DAD8D4D4CBD1D4D5D9D4D1CDD9DBD9DBDCD3CDD8CFD6C7D8C9D1C9
D9D6D6D3D4D0CEDECAD2C8D7CED8D5D6D7D4DDD6D9D9D3D2D5D3D1D5D7DCDBD9D8D8E0D0
DED0E3DCD9D9D9D9DADBDBDBD6E1D6E1D4DEDBDC
48474442414141423C3D3E4147515E676C716F5D50605C6F709389A586997374514A4F58
524846464145423F42403D413E3F4148433D433F4A554E50484C3B484C5050544B434247
3C444A424D455C5B5F68665A4F464940433E4243463C3C3D485B443E3F40443F3F3F4137
3F393A3F433F4E3F393F3B383D373B3C3B39353B3D413A40384239383940483F3D3F3D48
3B3840404841423F3F4242413B453D3F3B4A4C5B5F55523F474143413F3D3840444F4746
49484E4E4142403F42384545434A4E5B575E626D7A777F6C6C73746B5E554A433F3E4248
3C3A413D3B3E3A403D3F363C3C3F394144404C53453E413C3C403D3B403E3B41413F3C45
463E3A44453F3E3F3D4248464045413D433F3F4142423C4049424547423C47464C484144
4541524C424044423D3C403B383C3F48464947404649463D3C3C3B3D3D413F3F3E414A42
4041453F3F4343384341444544453E393F434344484B444B474C403F45433C574955484C
494D49475C4C51505554605D775F5E5F6062575153505447483D4A6E7D8F919F8D9A8EA0
96A698A39BA19FA0A4A1A79EA59DA293A899ADA4B09C91939A94949791969292999E8C96
8590829388998C9899A5A9B3B4AEAFA8AD9FB4A5AE8F8C8DA0A4B4BDBAB6B7BDADC0B9BC
AFC0B1C9B7C7C8C7C0C3C2CCCEC9D1D1CBCAC4C1C6C3CEB8C5B3CBBDCEBFC3BDCAC6C4C2
C0C7C0CABECBC3C5B7C7C8C4C1C7C7CEC7C4C9C8BBB5B6B3BBB3A9A0A8A6B8B8D0C8CDCD
C8CAC9CDC3C8BEC7BFC5C0D2C7C7C4CCCDD3CDCBC0C7CDCDC9C7CACFCECACFCCC9C9D3BF
C2C6CFC8CBD5CEC8CBD0CED2C9CCCACFCFD1D6CFD3CDCEC9CDC9BFC2BFB6BEC3B9BCBDB7
C0BDC6BEBEBAC5C1C9C6C3C0C2CAC6C2B8B9BEB7B5B5B0C1BABEC2C4B9BEBEBFB9BFC4CB
BDBFB5B7ADADA6AEC3D1CDCDCECBD4D6D3D8D5D9D5D1D2CFD5D5DCD1D8CFD2C9C8D1CED0
C0C4C5CFC7D1C6C8BCC6B9C0CBCCCBBFB3A599A3ABB0C0ACB4B4C8C0CCB6B5ACB6B7C6BB
B6B7B4C2C0CCCDD6C9CDB8CAB8D0CAC9BEB0BBC7C4C9CABEB3A5AAB2C2C5CBC3C0B4BCC1
C9C6D1D3D0C7C7CDC5D0C5D4C8D2C7CCBECAC0C5BFC4BFCBC3C1CCCAC9C5C4C0C0BABDAC
B8B2C8BDD4BDD3C1C6C3C3C8CDC7C0C7B2C5B6CBB9D2C0CAC6C5BDC1C7C0C0B5B8BCC4C8
CCC0A1B6D3D2DBD0E1D0DACBD0CAD7DDD8D6D4D7D3DED9DBCFDBD6D7CDD4D2D1D6D0D4D5
D2D9D5D2D5D6D7D6D4D2D1D2D4D5DDD1DBD6D9D5DAD3D7D7D1DADADAD0D9DCE2D9DDD8D8
DADCE4E1D9D8E1E1DEDCD9E0D8DEDBD9E1D4D6D7
47464443414141413F3E3E3E424850556C6872566160606376849E99A99694856C61687B
79634E434548454245423F423C404D656D69685E877B855B6C585E677E7A8678766A5F5B
606C616B5F696A6E5B796F8359685C665F5254474F3E4748515E503A433746413F3E3D35
3F3A3B3D393E3C453D483B40453E403F4248484F4B45463E4B494C443D413D3748534746
414749404B45423C43423F3E3A4742465A60534E463E47414E50554C4345485258645B5A
61584D4654504C4C55505F5F5B59545D5D69707B7E777A7073727165584F45403E3E4348
3D393D393A3E3C403A3C34383638333C37353C3F393A41413A3F4140403D3B3C393B3D3C
443F3D3E423F42433F3F403C373C3E46434542413D443E4747464345403F5343483A4349
4840534A4640474339414145423D444453443C423E43433E3B3D403E4142413D3E493C44
444E44473B434A484944424242484643464847494B3E5246574553444D40495254566160
64726D7A7D776F746C856F96829770857C7F6D6D65665846433A616D9793A3A0A6A2A59E
A39EA5A39BA39BA3A0A9ABAAA5B3A3C0AEC2B6BCB5AFAAB7B3B2ABB2B5ADBAACBCB0AEA8
AEA9B7A0B79AA2989AA3A5AEB1B0B8B6AAB2ACC7A6B39AB0AAB5B6C3C9C2C3C0C5C6C8BF
C9CCC7CCCED1D8C5D1C3CBC9CFCAD1CEC9CCC9C6B6C9C3CEB2C5C6C4C4BEBFBFC0C3C1C7
C2C0C9BDC9C0C7C0C1C0C8BCC7C3C8BCCCCBCFCDC1B6B5B7B7BDA9BBAEC3C4CECBC4CCCD
CAC9C5C5CDC9C8C0C5C0C9CFD0CAD1C8D4CACFC8CDCECFCFCECCCCCCC4CCC5CEBDCDD2CF
BFBFC9CBD0D6D0D1CFD2CED3CCD2D0D5D1CFD1C9CFCED3D0D5D1C8CBC6BCC1C4BCC1C0C1
C3C2C8C4BEBCC9C5CCC8C5C2BFCFBAC3B8C2B0AEADAAA9B8BFC2C5BCC2BEC4B7BBB1BCBE
C3C3BCB6B5ADA9B0BECDCCCDCFCDD4D7D1DBCEDFCED8CFD1CCD4D6DAD5D7CFCBCFD0CEC8
C3C3CBD1CCCACCBBC9BEC1BCCCCBCDC3B6A7999E9CAAAAB9ACC8C8CABAB1ADBBB6C5C2BB
AEB1BBC5CCCED4D8D1C3CEB6CFBAD3BFC6B4C6C8C1CAC5C3B2AEA4C0BAD4CCCFBFBDB5CE
C0D2CDD7CEC9C8CCCDC8CCD0CCC4D4C6CBBAC3B4B9B3C3C0C7BEC8C8C4CABCCAB8C1BAB8
ADBAB6D2C0CFCACCC8CAC1C8CABEBFC1C6C4CEBACDBCC6C2C8C2C5BBCEBDC8BABEBEBDC9
C5D1C1DAD3D9D3D6D4D6D8D4D5CED9DFDBD8D5DAD5D9DED5D7D7DBD6D5D5D9CCDDCAD7D1
D1D5D2D0D4D4D3D4D5D7D0DAD4DDDDD5DCD7DAD6DCD4D6D6D7DDD9DBD5DDDBDCDCE0DBDB
DBDBE0DCDDDADFDEDBDBD8DFDAE1CDCDB6B2A9AE
4645444342414140403E3C3C3E4143444D4B4C464C594F515168618F6F8F747D6C5F6980
80674F424647444244413F4043424E6C7C7C7B718280746D5B77698B8C998C9C91918D86
9D929F7B8E68776062708C8292778A84857D73767072737D768B70705A5F595D57524C43
4A413E394751625B7468747165626562656D6A6A7371616C6877655E6A6C5945535E5559
5564655664635E554C47414140515057636556514C495551565C625349546373717B6F70
7F7A6D6A7C7572737F7B86858779635F5A646871776D6C6A6F6765545850474342424549
423D3C383B413F403C3E393B383938413F40403D3C40464744474A453F3F3E393A433D3B
3D46403D434243413C3C4041453C464F57544B393D4848494B4648484A4856494F474A46
4A43524C4944474347434B423F47444E4C4F46444944414F464547404340413B4A48554B
4D3C53434643564A55455755575D5B56575A5D625D705978657A5D715C6C55726B857491
8A8F9C90A18185809C8AAE90A880977D888784747B6D674D445052857CACA0B09EA693B2
8FAE9BA2A5A7AEAABAB8C9C6C5C0D6C0DDBBD0BFCCC6CEC9D0C3CFD5C0C0BED6C0D7C7C7
C6D4BEDBBED4B6BEC2C6C3C3BEB9BDBDBBA1BE90B283A09BB3A3B8BCBACBC6BBC3CCBCD8
C2E3C6CCC9D2C0CFBFD3C4CBC7C7D0CDCBCEC8C3C1C1DCB5C4ACCEB4C4BCCAB6C0B3BFC3
C1CEBCD2B7D1BDC5C6C5B9C4B6CDC7C3C5C8CDD2CEC2C1CBCCC5CEBCD0BDD2CAD6CACCCC
CACDCCCDC6CDC4D2C0D3CACDC9CDC7D2C8D3CCD0D5D0CCCDD1D2CECACCCED2C6CFC8D8D0
C8C2C8D0D3D0CCD1D5D4CDD0CBD0CCCED6D2D1C7CECDD2CDD3D1CDD0CDC5C9CBCBCABDC5
BFC1C1C1C0BEC8C2C7C2C0BFC4BBC0B9BBB4BCA4AEAFA7B6B6C2C0B6BCBEB3C1AFBAB5C3
C0C9B3BCADB3A1B0BECDCFD0D2D0D4D6D4D3D6D1DBCFD8D0D8D4E2CBDAC5D1C6D3D5C5CD
BCCECBD6CBD2B3C9B5D3BFC7C8C4CAC4B6AA9B98A69BB89EC1ADCDBFC6B4C8B5CCB4C1A9
AFBDBFD8CAD4C9D1CAD5B6D8B5D8C5C8C3BDBFC9C1C0CDC5C7B7C5B5D0BFD0C4CCBCCDBB
D5C0D6CFD4CCCDD5C5D6BED1C2D5B7D3BAD1B1C4B5BEAECDBCBEC6C7C9C8D1C2CFB4BDB4
BDB7D6BCDAB4D1BFCEC5CBC4C4C3B7C5C0CFB4D4B3D2BACEC7C9BDC7C1C9C5C5C9C0CAC3
C9CACAD3D4D0E1C7E3C9E3D5D9CFD7DEDBD6D3DBD2DED2E1CDE3D5D9D6DECFD8D1D6D1D4
D8D7D4D4D9D9D5D9D6D4D9D4DFD8E2D6DCD6D9D7DED7D9D8DBDDD8DDDBE2DCD9DCE1DDDD
DCDCDFDAE1DADCDAD9DAD7DDDAD7D1AE977B8986
45454544434241403E3C3B3D4042413E40413B3D384A40464C494F5752525656534B5360
5B4D444142413F3F3F3E3C3C413A3C525D5C5D556F64684C525A667F94889C8A9695979E
A4AB97A5828C6E6756736D9682978794998D968797828F8E969FA997A78E998D8B81766A
6C5B54465D7D818D7D948B938B90989392907E717F6A6E5B827C8D7D777C70616365646C
6471776C7777736759534C4D4F62636B6D6B6063696A685B5855574D4A5E7689888E8888
92908A8D8B878C919D979D9E8F7D60564C53575F6F6A66646860614D4B443F3F3F3F4043
403B38353A3F3D393F3E3D3D3B3A3D443D413F3A3B3E3E3C3E3C3F3E3D454A43474F4042
3B4C41424242413D393C43494C41504A584E5148414C4F485049545359555C5A63615A49
4A4B4A59424D3C403E4C404A4B485E58655969494B4363574F4C454A4346434944695567
646F656D5D6357785D7D798B7E8688878A898585977FA0879D7995818E7D8F84998A9E94
9AA79CAE9EA3919A99AF95A8889E808E8A968D91828D7F787E698C75A08FB0AAB4A5B69E
B9A6BFB5BEC5BECBC2D0CED3CFDBCCDFCBD6CCD1CBD0CAD6C6CBC6D2CCBDD6C7DAC7D8C6
D6CDD7C6D9C8D0C6CFD1D1D1CBC4C4C5ACAF8DAF8CB39BAF9EA88A8EADB8C3C2B7B5CEC6
D6C9D2C3D1C5CFB6CEB9C7BDC7C6CAC3C2CAC8C7C0CDB7CFA4C9C0BDBCBFC2C2B7BEBCC9
C4C2CABEC8C0C6BFC8C1CDB9C7BDD1CACCCCCED5D8CBC5D0C6D0C3D6C7D5D1D6CFC5C9CC
CCCFCAC8C2C4CACCCBD5D8CECECFD4D0D2CCCFCED2CCC8CACFD2D0CDCED7CDD1D3D5CEC9
D2CACBD0D1CCCACFD5D3CBD0CCD1CBCACECCCDC8D2D2D4CDCFCDCCCFCECACDD1CDC0B6B2
BFBAC7C5D0CBD3C8CAC5C5C6B8CCACBAACBEABB7ACB3A7B4ABC1C4C1C4B7C0B2BFAAB9BB
C5BFC4A7C1A1A8A8C1CED4D3D4D2D1D4D1DBC7E0CBDED1D6D3DBD2D8C7D2CBD0D4D0D0C6
CAC8D3D6D7C2C4AAD0BED6C7CAC5CFCDC2BCB0A8A6B09DBF9EC6BCCEC3C4B9CDBBCCBDBA
B1B8CBD1D7CDD0D0D8CDD7C1D6C1D4BFBFABC0BEBDCDC6CCC6CFB7D8B9D9C1CCC6CDB8D5
BCDBCBD8D7D6CED2D5C2CEC8D5B9D5BCD4B4CEB8C7B1C9B9C7BCC5CCC2D5BEDAC1CFB9C5
B8C4BFD3C8D0CBCBC6CFC1C9C9BCC6C5C7C2C8BCCABAC2C5CCC1CDB7CFBBCFC6C8CEC8D5
C6DAC7D2CEDACCDFD1E0D7D7D8CDD3D9D8D1CDD7D3D2DDD1DED6DDD5D9D3DAC6E2CADCD3
D6D1CFD0D7D6CFD6D1DACFDED4E0DAD7DBD5D7D6DED9DDDCD9DBD7DFDEE5DEDCD9DEDBDC
DDDDE2DDE0D9DAD8D8DAD6DBD3D9CAAA73657276
45454544444342413F3E3E41454644413E3D4A3C44414D4F4C43444944454C4F45444746
3E3B3E3F3E3C3C3C3D3E3D3B3F3A3A484941423B4C4C4746445B647D889A858C7B869293
A592A87E9269755A4E5E6D74857C878A91908D978F8D858A82958FA79BA592918B857D7B
81757464676F947D8884918B959DA9A39C91745F5B56465760807C7C746F6B6E6F6F757A
75768280837E7E706C6661646474737B77706568737873656B5B5A5B6074869489919C9F
999390928E8A93959B9195998A7B6156484C4E575E61605758555C483E3A3A3D3F3F4042
3E3E3B3C4247463F4A454543413D4043393E3D3A3D41403E433D3E40434C4F454F4C4D41
4F464743474948454345494F4E50515A53584852475D52635768656D77718A768E76866E
7F6E8A6F84626D60635F5F53525F636C6B8A7478657C61674E4B465549453E496C7D9285
8B7B957B9881A182A985A797A2A49E9CA2A5A2A092A78AAA91AC8FAA94A4899DA0B197AA
B2ABB7AABDAAAEA9B9A5C4A5AD94B397AAADB9ABB6ADB1A7A1A393BC9DC2AEC5C3CFBCD5
BFD7BFCACFC8CFC3D0C8D3D3D9D5DDCCDAC6D7CFD5CCCFBFC7BDCBCDC8D1C4DEC8DECED3
CFD2C3D4C5D8CBD0C9C9CED1D0CDCCD1D1BFCBAFCCACBBAABE9C8A7A8FB9BCBBB3C4BEDD
BBD5C5C8C6CBB8CBB2C7B7C0BFC2C9C7C8CBC4C2CCC3C9BDBFB6CABDC9C2D2BBC7B7C0BD
BDC5BCC6B9C7BDBFBDCFC7D3BFCBBEC8CECBCAD5DDD3CBD3D1D0D0CBD2C8D1CCCEC3C8CC
CED1CCCACAC9C9C6C5D3D9D0CED1D8D4D5CFD2D3CDCBCACACDCFD1D1C6D0C7CFD4D5CCC8
CFCDCACBCECFD2D3CFD0CBD3D2D9D3D2D4D0D0C9D1CDCCC3D1CECFCECCCBCCD0C7CAA9C3
A9C2BAC8CBC8D0C7C9C3C2C2C6B7BCB3B5AEC3B1B7B4B4A7B1B2C6BABBBBADC1AFBBB1BF
BFCEAFC8ABC0A1B4BFCCD3D2D2D1CED2D5D2D5CEDDD1DDD5D3D0E3CBDDC6D4C9CCD6CCD9
C4D3CCD8CFD0ADCCBBD9CACCBDB9C5C6C2C3BBB4B8ABC7A8C3A9CFCCD2C1D3B8D2B6C7B6
B3C1C1DAC9D6CBD5CCD4BFD8C1D9CCC9B7B2AFC0C6C9D4C9CDC5D4C0D8C4D1C7D4C8D7B9
D8C0D5CBD2CCC9D5C4D6C1D4BDD0B4D7C3D9B4C7C4CAB6D2BEC5C8CCCBCCD1C4D8C4CFCB
D1C9D4C2DABCC7B5C7C2CCC4C6C9BDCABFCAB9D2BED0BECFCCCDC2CABECBC4CBCACDD1C7
D5D4D3D7D4CCDBC7E8D0E4D0D6CED3D6D5CFCAD5CEDACCE1CCE3D2D8D5DDCCD8D0D9D2D6
D6CFD0CFD5D6CDD5D3D5DAD2E1D6E0D6DED7D9D5DCD7DDDDD8DBD9E1DDE1DCDDD9DEDADB
DCDDE3DFDDD6D8D8DADBD6D9D2D7C7A56E667371
46464545444443434342414447484642484B5550484347474A434443423D3F4040404340
3C3F433E3F3B3C3E3E40403C403F3F46433E433F4140564D67606F70777D8D6A6B727777
78796F78586A5A5B53635D6E727B767B786F7C74826D74717F7E8E899D8B8D817C766F6E
726569585E5E6979687E707A7E85908A82775D4B483F4B42605B65576B62626E6D6B767B
7D76858A8B85897D7B75727775807B837E7B76767B807E787D696B7177838A8D878B9E9F
918882828178807D80787E89837863594847454C4E53554747485142403E3E40403F4042
3E4444484E52554C564D4C484740413E3F3E3F3E3F434745403E434C545958534C594463
4A5E404C4B4A444044484E565A4C664B71566061697082779380938C949C97AB95A39D9A
87907CA47C9F80958898868A847683737B6E9B7396719578856F7B5D6C42585A679A939C
96A199A6A1AE8BBC8CBB98A8A4A7A5A6AFAFA6A0B09CB499AD98B9AABCA5B6A3BEADC3B0
BEC1B9CEC2D3BEC6BCD5BCDAB7D8BBCBCACBC8D1C7CEBCBBB69FBCACCDB5CDCBD3C8D7B7
DDC1D4CCCFCBC2C9C3D3CFDACADAC2E2C5DFCFD9D0D4CCD4CAD3C9CAD2D0DACAE0CAD7CE
D9CADFC3DFC2D6C5D5CFD1D1D0CECDD4CDD8C6DAC2D1C1C4BDBA8C89B3C4C8C5C7C2D0C1
CDBED0C2C9BDCBB8C7B1C0B7C1C1C4C2C6C9C5CBC3CBC1D1BBC4C4CAC5C6C8C7C2C9C1C4
C0C5C2C6C1C9C4C5BFC3CDBFD1C1C8C7D4CDCCD4D9D2CACBCDCDC8CACECDD3D0D4C8CACB
CDD3D1D2CED4C6CFBDD4CBCAC4CDCBD6C9D2CDD4CFD0D0CECDCED1D3CACED1C9D8CAD2CE
CED0CAC9CBD0D6D3CACDCBD3D0D6D0D0D1CCCBC4CDCDD0C9CFCDD0CDCDCFCED3CEC5CEB5
C5AAC4BFC8C7D4D0D5CFCBC9C3CFB0C1B9C7B1B7ABB59EB9A4C8BFBEBBB1BAAFBFAEB9B7
C9B9D0ABD0A3B6A9BCC7D1CFD0D2CFD5D3DCC9DFCDDED5DBD7DED8DBCDD3CACBCBD0D9D4
D3CCD1D3D8C8D1C0DEBED0B7BCBBC5C8CACFCAC6ADBEB0CFA6C6BDD2C6C9BFCDBFCBBFC1
BFC0C9CCD2CDD1D3D3C4D8BADBBBD6BCC1ADBCBFC8D8CBCEC0D1BADBC0E2CAD7CCD8C1D3
BFDBCBD5D4D5C8CECFBCCAC4D3BCD7BED7B7CEB6C7B6D3C3D0C9C8C9C6DBC6E1C4D9C4CA
C7D1B8D5C5D8C3C4C5CFC4CACBC2C8C5CBC6D8C3DEC4D2CDD5C8D6BED2C3CFCACBD6C9D6
CFDECED9D3DAC6D9CEE0D6D4D5D3D7D7D5D1CCD7D2D1D9D1DBD3DAD6DAD6DCCAE1CADAD2
D8D3D6D1D7DAD1D9D4DFD4DED8E0DADBE1DBDDD7DBD4D9DBD9DCD9E0D8DBD7DBDCE0DBDB
DADADFDBDBD5D9D9DADBD5D8D6D3CB9C81718371
48474645444445454342424346474543464B4A59495149484043404443433E403C3A3D3E
3D414441413C3D3F3E40413B3C3D3A3C393B4440444F5470627A5D635A6B615F4F535651
544A664B5241534955645961686E6665666568706F6965676C707080797F747767625B5B
5E545F505649574F584D4F52585C65615D5A4B423F443A453D4E4749454A516060575D5F
645D696D736E736C6A67676E6B746E777C7F807B77757270685B6164656F726F7E7C8584
7A70636267585E5B64626A78675F4F4C414340454D4A504243454A423F3D3D3E3D3C3F45
444F4F53575B605963555451534C4B414B44484B47494F4D56575B61635C585C5E5E6562
6C5D585647443C3D4B57616B6E696D716D7D7D9691A094ADA2ADA1A8A59BA9A5B1A0B1A0
9583937A917B8F9298A1A3A2A3A7AAA4939C848A7688859F889884A16E7B5C6D9BA1AAA1
ADA5ACA4B1A5B593B399B0A6B3B6B2B1B9BDB9B7B6C2AAB2A6C1BACAC9CAC3C5CAD0CDD2
D6CFD9D4D9D3CFD0D8C8E7C9E1C2DECAD5C9D0C9CDC1BAB9AAA9A4BFB3D0C8D6CCCDC5CC
C9D1CACBD7C9CDC6D0CFD0D3D2CCD8C7DEC5D7CAD0CED1C7CECACFCAC6D3C7D9D0D8D0D3
C8CFC2DBC2D8C9CDD5CBCDCECFD0CED7D4D8D6D2D3CCD0C8D0BDBAB3B6C9CCC6CBD2C2CD
BCC7C3C2BFBFB9CCBECAC2C4B6B6BEC4CAC8C1C9C6CFC9C6C0BBC0C2CAC5D1BFC9C1C5C1
C1C4C5C6C7CBCBCAC2C6BDC7C2CFCBD2CBC7CAD1D2D0CECDC8C9BFC8C9CFD2D0CDC4CACE
CED0CAC8CCCFD1C8CECBCBC6CBC9D2C5CCC0C9C8D1D2D2D0CECED0D3D2DACCD7CDD3CED0
CFD2CBCBCDCED4CFC8CCCAD0CACECACDD3CECCC2CAC9CDC7CBC9D0CDCCD0CCD1C8D2BFCE
B8C9C3C9C0BFCCCAD2CECBC8CCC4C3C6C8C2C5B5B4B0B5ADBAB5C5B7B0B3AEBCB8C4BEC2
B7BDB1CCB5C7B5BAC1CAD4D0D2D5D2DAD6D7D6D4D9D4DDDBD8D4DDCCDACED9D2CCD5D1DD
CED6CDD2C6CCC1DCD2D3CDC3B7BCC3C4CAD0C9C9BFBDCCB9BDB0C3C0C6BFCDBED2C1CCC4
C1C5BFD2CCD8D0D7CAD3BCD8BDD7C8C7C3BCBBC6CDD0D3CDCBCDCEC7D3D1D3D1D7D5D9C0
D4CAD5CECACAC4D4CAD3CAD5CCD5C4CEC6D3C4CCC4CAC9D7CBD3CBC6BFCFD7D3CFCCD4CC
D6CDD8C0E2C3D3C2D1CFD1CBCED1C8CFC5D8C6E2CAE5D0DDD8D4D2D2CED6CDD1D2D3D7DD
E2E0DEDDD3D2D7CBDACEDBCFD2D6DBD7D5D3CED7D1D9D0DFCFDCD3DBD7DFD5DAD7D7D5D8
D4D2D7CFD3DACFD7D6DCDBD4DED7DDD9DEDADFDADCD3D8DADAD9D4DBD5D8D5D9DDE2DDDC
DAD9DBD6DCD7DADAD9D9D3D7D4DDC3A575777263
49474644444546474040404144454545443B41444C474A3C47484B3E4C3E3F3C3F393A3C
37394044423B3C3E3C3E3F383E413E3E3B3E453C4D41594E5C594B4747424848473F4047
4244585340403F3E465C5656555550524442525A685E636368656E6E6E6463645450494B
4E47594D424842423F3D3A433B3D464444463F3E414544423C3E3C3B3C45424A4C434343
474449474F4A4D4A48474B54535C57605B5E615B55534F4E4B454F4D49575E5B5B585F63
6A634E4D6D595A545B5759635E56474943484447493E463B3E3F403D3C3C3E4042454E57
5A6767696A6C736C7A6A6A696E68665A68606A726C6C7370767A7B7D7B6F6D7B6F7B6D7C
6A7561684C4E4D586F808890A58EA798A99EA3A3B0AFACACB7A8ACA9A9ABA7C1AEB3B0A9
8681717D6E85839D889C9CAAB3B7C6BBC5B7C3A7B08C907F939AAF9FA796A5A4B7BEB7B9
C0C0B9C8B1C0ADB8A7BCB0BCBAC1C1C1C7C9C7C7C2BDBBAAB2BDD0CFD9CEDECFD5C8DACF
CCCBCCD3C8D3CBD7CCD5C9D6C9D6CCD7D1C8C9C8BEBAB4C2B9B2BEB9C2C5C9C3D5C5CEBE
CDC1D1C6CEC6CAD0D4D9CFD2C8D1C1D7C8D8CFD2CFD3D1CECACFCECCCCD2D2D3D6CACFC7
D2C7D7C7D5C6D6CCD1C7CDD1D6D8D4DCCED8CFDBD6DBD2C7D6D2CDC1AEB3CAD0CAD0CEC9
C9BFC8C1C0B5BBBEC3BDBDB4B0AEB5BDC6C3BDCABFC9BDB6BCC0C3C3C4C4CBC1C2C5C6C7
B9C0BDC4BFCAC6C7C8C3CAC9C9C9D2D0CFCCD1D2CAC6C8C5C9C6BFC1C9C9CFC9D5CACDCE
CDCFCDCDC8D1C5CBC7D2CAD2CED0CDCEC6CBCCD2CFCFCFCFCECFD0D1D5D1CDCED6CFD2C7
CED0C9CED0CED4D0C7CCCCD1CAD0CFD5CDC9CAC3CBCACEC9CCCBD2CCCACBC3C6D6CEC9BB
CDC5D1C3C6C1CBC6CFCECDCCC6CEC3CEC6C9C3C4B4BCB3C0AFBCBFC1BABABDBCC3C2C3BF
CEC0CFC4CCB6BDAECBD2DBD5D5D9D5DED6DCD2DCD2D9DADED7D9DCD8D8D5D2CCD1D3D2D6
D3D5D0CFD5D2D4D5DAC0CBB8BDC5CBC9D1D6CDCFC7CCC4C9B5C5C5CACBCBCAC8CAC9C8C8
CECBC8D1D1D3CCCCD5CCD4C4D6C5D5C2C4BAC2C5C9D1CED1C8D3C2D0C8DED2DBD5DCD1CC
CBD7D3D4D0D3CBD9D5CED2D1D1CED9CCD8CFD6CACFCBDAD0D0D4CDC7C8DCD3D5B4C8D0D4
CFD9CAD9D4DDD5D9D7D9D2D1D6D6D7D8D4D7E0D0DED3D8D3DED4DDD1DBD7D6D4D9D6D3E2
D7DCDAD7CAD6D4DAD2D2D1CECED6DCD5D3D2CDD6D5D8D8DAD6D7D8DCD5DADCD5E1D4DEDC
D7D7DED3D6DFD4DBD4DDD5D5D7D7D7D7D7D7DEDBDED5DADCD9D5CED6D4D9D6DADBE0DDDD
DCD9DAD4DED9DBDAD8D7D2D7D3DDCC986D575643
48494845474B4B463B3C3B3D413F3E463D404344434140403F46443F41403E403D3C3C3C
3D3F4143443D3B40423E3D413F3F4041434445464143403F45433D3F44423F3E3F3F3F3E
405F959C53363E42494E4F4A4442403F403E49535E565E645C5F636B555A5B5B4A49423E
49495248404140423E3A3E433B3B3A393A3C3E403F41423E373D393D3E3E384443434343
393C4042443E46474044434543545245454445474D46454A404045494E46474E4647545F
66646055605D596D616C555E4A524A4F47423C4247464944403F44403D42453F465C7277
7C878D8D8F95948D88917D927C9D849A899F869D879F949D9EA9A49DA292A392A996AD85
A57983635F4C557899AAB1C1B1CCB1C1B0B6A3BDA8B0ABB5ADBAB3B3B4B7B2B4B9B1B3AB
AF98A687B099B4A8AFA7B8BCC6CAD2D4CBD0CAD4C4C2B3B6A3AEA9AEA0A3A2B6C0C0CCCD
CCD0CDCCCBC4C2B6C1B3B2AEB9B2B8BEBEC5BDA2ACC6BEC7CBCDC9DAC7C7CAD3CDCFCECD
C6CACCCACACCCAC6C9CDD2CAD1C8C8C7CBC0C2BDB3B2B2B9C1C5C1CFC5CDC9D3C5C8C8C6
C8CDCFCEC5C7CECACACEC8C6CDCDCECFD7CFD6D1CEC8D1C6C9CFD0C3ACC6C3CDCFDED0D6
CCC8CECEC7CFD9D3D5D7D3CDD2DCDBD3CDD8D9D4DBD3CED3DAD2D8D3CEC2C6C5C7C8C8C0
BEB3B8C2B6BABCBFBCBBB7B7AEB6B8BFC3C5C3CBC1C7C7C9CDC9CCC6C5C4C6C8C6C1C3C8
C2C4CAC4CBC8CCC7CDC6CBC4D1C8D1CECDD0D1D2C9C4C3C9C6C8BDCAC3D4CDD2CBC8CFD1
CAC8CACEC9C6CDC9CAC8D1CED3C9D3C9CEC5D0C8C8D0D7CECCCECBD4BED1C8D5CBD4CFD5
CEC8CFCCD0CDCCD0CECDD2CBD0CACFCECCC4CDC1CAC6D2C7D1D2D1CCC3CDCAD1C3D2BFD5
BED2C8CEC4C8C7D0C7C3CCCCD4D3D2CFD4C1CFBDCEBCC6B6BBC0CCC6C7C5C5C7C4CAC1D1
BBC6BFCBB8CEC2C3BBC8DBD9DDD8DDDCD8DAD6DBDCDADBD6DBD6DBD3DBD1D5CFD2D2D4D5
CCD1CBD5CBD3CAD3C5C5C0C1B1C2CBCCCECECDD2CAC7D1C3B9B7C8C4DBCBD6C8C6C4CAC3
C4C8C5D3C8D5C4CBC0D1CFCDD1D1D0C9BFC1CCCFD4D8D3D5CFD2C9D5D6DBD8D4D9D3CBC6
CECBD6D2D7D2D0D5D1D7CFD6D1D7D5D6D6D4D7D0D8D3D1D5D8D7D5D5D6D7D6CCAFBCD1DA
D5D1D8D4D5D2D9D6D6D0D3D3D5DADAE2D4E0D7DBD7DAD7D7D1D2D9D7DDD9DEDDD6DDDDE2
D9DBD7DACDD5D2D8D6D6D6D1D5D3DED8DBD5D4D7D4D4D7DBD2D5D8D8D9D7DCD3DBD8E0DC
D1CED2DBDDD9D8DCCDD9D0D3D3D7D6D6D5D7DAD2D4D5DBDBD5D9D5D5D6D8D8DEE0DDE3D4
E4D4E2D5DCDEDDD9D8DBDBD8CCE0C39E69664742
474848474849494640424141423E3D44413F3E3F40413F3D4146433D3F403F42403F3E3D
3D3E4041413E414747403D403C3F42454644413F40423F3E43413D3E3A3A3B3D3F403E3D
343D505E4742403E3F42413D3B3F43443F3E5054595759524E4C5B554E47555147454541
49444841403D3B3A3C3C4144373D42403D3D3E3E3C3C473C403D3E3E38373D3C4738433F
3E4132423B3B4742434541424054564F424C4856575B585E596C596D5260517057555868
656E665D5D4D5F52675457545B556554604A413F414745483E4845444C61577A779B90A4
9AA7B1B1ADACABA8A495AF92AF9AADA6A9B1AFA7AEA6AEABAEB6B9B8B2BCB7B7A4B9A4BE
A4B3898A5350688FB1C3C5CFC7BFC0B2BBA7B5B1C1BBCAB4CAB8C6B9BEC7C0C9C1C2C3C4
BDC6B1C1AECDC5CFC6BECBCCD1D1D5D5CFC9D5D2D2C6C9C2C2BBB2A2A2989FA8A9A8BBC8
CCD3D2CFBAC2A8B8A3B8A4AEA5A8B3B9B9C2C8C0B7C9C9CDD6CCCCD5D9CFD8D0D3C6D1CF
C9CBCCCACACDCDCAC1CBC0D5C7D3C6D4CFC6C9C1B7B8B9BEC9C4C8C6CCC6C9C9C5C7C8C8
CBCFD0CDC6C7CCC7C6CDCDD2CDD1D3D1D6CFD9D5D8D2D7C9CCCECFCAC8D4CCCDC9D1C7CB
CDCACFD0CBD2D9D2D5D4D2D2D5D8D6D2C9D3CFD0CECAC0C8D1CCD1CBC9C0C5C1BFC2B9BD
B8BCB6BEB7B9BEBABBB3B4B2B1B4B8B1BCB9C0C3C7C8D0C5D6C6D4C8C7C8C9C8C5C3C7CD
C5CDC1CFBFD4CAD0C6C2BBC9C4CAC5CED1CCD0CBCFC5C7C6C5BDC8BED2C9D4CECAC2D1CD
C7CDC8D2C7CBC5D4C4D4D1D6CFCEC4D0C7D3CBCAC6CED3CCCCD0CED6D0D4D9CBDBC9D2C9
CCC3D1C6D3C9CDCDC7CEC2D3C3D5CBD3CACBC3CCC0D0CBCACBCFD0D0C8D1CACED0CED5C3
D2C0D0C5D1CDCFCCCBC0CFCDC9CFC5D7CED1D3CBC9C5C9CFC3D4D0CEC5CBC0C3C0C5C5CA
CBB8CDB3C4B5C9AFC7CDD8D4D8D2D6D2D4DCCBE1D1E0D5D7D3D4D1D6D4D9D5D5D1D0D3D8
D1D4CDD7D0CAD5BBCAAABDB1B0C0CACDD0CECCCFC5CAC4CFAFC1C0C6D0CDD1C9C3C9C6C5
AFAEB6B1B0ACA9ADB4C7CDCED1D3D6D0CCCBD2D2D4D8D3D6D3D6CDD8D7DBD8D5DCD8D3D0
D8D3DCD6D7D1CFD4D1DAD4DBD5DBD8DAD9D7D9D3D4D1D1D5D8D7D5D5D2D4D6D7C6D0DAE0
D7D3DBD8D9D4DBD6DAD4D7D6D7DAD9E0D7E2D7D9D4D4D1D1D2D2D9D6DCD8DEDDD0D5D5DE
DBE0DBDCD3D7DAD4DAD0D6CCD8D6E0D5D7D3D3D3D4D9D6E3D3DFDBDFD9DBDAD9D8DDDDDC
D3D1D4DCDDD9D9DDDBD8DCD1DDCFDCD2D3D1DCD1E0D9E1D9D4DED1DED2E1D8E4D9DED7DC
DCE0E2DCDCDCDCD9D8D9D9D7D9CCCB81624A4B47
464647494846454746494845433D3B4143403D3F4344403B42474642424342424342403E
3E3E3E3F4141454946403F433D41474B4B463F3A3F403E3D403F3C3E3D3C3B3C3D3D3C3A
3D403C423B3D3C454143423E3D3F403E4A475D56565B5B504C4A554E4843504E4F4A5049
4C44444345413F3B3E3F413F3B3D3F403D3A38383D3E413C394141463F453E463C3E3F42
4739423F424240404C514A534C666667626C7473837A86828D708D708A6A8D7C887B8684
8A8387746D665962556156615A6D4E6E4B5540455A5F7E705C56706798829C96AF9CB3A6
BDC0C3C6C5C2BDB9AEB2ABC1A3BBACB4ACB9ACBAACB7B1B9B8BDC6B6C5B1C5B6C4B0CCB8
D2B2B8907E7E8FA5BAC7C6CAC4D5B4D5C4DABECED0D5C9D5C8D7CCCFD4D2D7CED2C4CFCA
D5CED3BCD0CDDACDD5CDD7D5D6D4D3D4CBCCC0DBBBD6CFD6D0D3BFCBB6BA9F9F948EA7BF
C9D4D5D0CBBFC79CB79BAFA4ABAFB4B8BBC1C5C7BECCC1D7CBD1C7D2D6D0C7D7C8D0CAD1
CFCFCDCAC9CBCCCBCBC2CFBFD3B7C5C8CECACFC7BEC2C4C8CACCBFD1C4D3C5CBC3C5C6C7
CBCECDC9C3C6CFCCCBD0CFD3CAD3D6CFD0CAD5CFD5D1D4C8CECED2D9D0D0CBCCCACFCED1
D0CCD0D2CFD4D9D2D2CFD1D6D9D7D4D4D7DAD6D1CEBCB2B7D1CDD2CACAC4C9C2C6BFC5AB
BEA9B3ACB6BABBBBB6B4B3B5B8BFB2B3AAB8B4BBC2CBC3CCC2CBC9C6C3C6C6C1BEC0C6CB
CCC3CFB5CBBBCEC6D0BECCBED6BACAC9D1CFC4D0C8CFC3C5BFCBB6D7BBDBC2CDD0CDC8CE
C9C4CCC7CEC4D5C5D6C5D7CFD7C7D5B9DEC3D0BFCDD0D3CBCCCFCBD2CADDC1E1C4E0C9D0
CCCACDD1CDD1C8CED3C7D3BDD4C0CEC4D3C4D6B8D5BED3C2CCCDCCCCC7D3CFD3C8D4C0D3
BFD4CACECFD0C8D5C6CACACCD0CAD6C8DCC2D9C6CDC1DEC6DAC7D8C8D1CDCEC1BFD3C2CF
BACDA2C7AAD9B4C1CCCED4D0D7D4D8D4D5D0D5CCDED1DED4DED4DFCADDC9D5CCCFCBCED8
D4D6CDD7C4D4B8D0A8BCACB7B6C2CBCDCFCECED1CDC2D7C3CBB5CBC5D3D3DEC4D0C4C5B9
A3968F8C878D8F9BA0BACBD2D1D6DED8D7D4D8D5D6DAD7DAD7DBD3DCD8DAD9D6DAD8D7D5
DDD6DDD6DCD6D4D8D6DFD7DDD4DAD7D8D7D5D7D0D2D1D2D7D8D7D6D7D4D5D2D8D1D5D1D5
D9D7DFDCDDD7DCD7DED8DBD9D9DBD8DED6E0D7DCD9DCDBDEDBD9DDD6D9D2D7D5D6D7D4DD
DBDFD5D2D1DBD4DDD5DAD7D3DCDCE3D4D6D5D6D5D8D7DEDAD8D2D6D2DCD8E3D2E2D6E1D9
D7D6D9DDDCD8D9DFDBDDCDE4CEDED7D8D7D9D7DCDBE1DBD7DEDDE0D5DFD6DCDEDED6E4CD
EDD4EAD8DCDAD9DAD9D7D6D8C8DEA78450504B67
4644454746424347484E4D48453E3C42424142454847423E40474B4A4948444143424140
3F3E3E3F42434546413C3F4642464B4D4C47403B3E3E3E3D3E3E3D3E44413D3B3B3D3E3F
44413B41393E3E4343494E5051504C464B435855626A60544F524D5844525056554B5247
48403F453E3C423B4141403E433A363B403F3D3D3F4442463A4B444C44483E413C414647
3E3F3F435D485F56625F736380788E8584988C99919896988BA38CA9829B87A5979699AE
9FACA69EA58C9B708A61756A7F708A676F504A47578D9999868A8CAFA7B895C0A9CDAECD
C8C2BFC1C3C1BEBDC7BAD4B4C9A9BCAFB9B0C0A5BC9EB3ACB6BABFC2B1CCB7C7B1C0ABC1
C3D5B6B8A7A1AAB5C1C8C3C5D3C7CED5DBD4DCCBDBD4DACFDDD4DDD6D6D5CCDBCFD8D0D1
CED9C0D9C1E5CED1D4CED4D3D3D3D0D4D4C8DACCD5C5D5C9D9D1DBD0E2CAC6B4988BA1BA
C5D1D3CFC6D2B1B898B6A5B2B0B5B7BCC5C6C5CAC8C5C8CAD0C5D1D1D6C1D1C8E0CAD9CF
CFCECCCAC9CACBCCC2CABECCBCC7BDCCC6C7D0CAC4CBCECFD3D1CECECBC9C6C5C7C7C7C8
CBCDCBC9C7C8D0CFD0D2CED1CCD5D9D3D7D4DCD3D3D0D3C8CEC7C8D5D4CCCDD2CFCFD1CF
D4CFD1D3D1D5D8D3D0CFD1D4D5D2CFCED0D0D5D1D5BFBBBEC6C4CBC4C8C9D0C8BCC6B9B8
AAB4ACB3ACB3B3BCB5BEBDC4BEBCBFABB6B3BFB9C7C4D2BCD0BCD3C2C7CCCCC6C2C7CED1
C2D0B7D4B4DAC6D4C2C5B6D0BCCEC0CED0C6CAC3D1C5C9C2C9BCD5B8DBBBD0C1D4BFCBC5
C8D5C7CEC4CABFDAC2D8CBD3CBD4BCD3C6DBC2C9D2D1D1CACCCEC9CFD0C9DCBEDFBED6C3
CFC4D6C6D6C5CBC8CAD2B7D6B8DAC2CEC8CFBCD1BDD9C9CECDCCC9CAC7D6D2D7D2C5D9B2
DAB5D5C0CFC3C7BEC8C0D2D1C7D1C1DCC5D7CECFC5CDC9D9C3D9D0D4CCD4C1C4C2C5C7C5
CEB2CBADD1B8DAB8D3D4DAD6DAD4D7D4D4DFC4E2C8E2D2D9D9DBD0DACED9D0D4D5CDCDD6
D1D1C6CFCFC9D7B9CAA9C2B8C7CCCECECECFD3D8D4D6D0E0C6CFC7D0D1DAD8D6D0DAC9B8
8C656F5A7A6377778FB1CDD7D5D9E3DDD9D6DAD7D8DCDADED8DDD5DDD7D9D9D8DAD9D9D8
DFD8DED8E1DDDCE0DDE4D9DAD4DAD7D7D6D4D5CFD5D4D6D9D9D7D7D9D7D8D0D7D8DBD5DE
DCD8E0DCDDD7DDD8DFD9DCDADADAD7DCD6DFD5DAD6D8D8DBE0DDDED5D7CFD3D2D4D6D4DD
DADFD6D3D3D4DED3E4D5E3D7E0E1E7D6D7D9DCDAD6DED6E6D2E0D3D9DADEDADDD7DED9D9
DBDBDDDEDCD8DADFDFD0DBCDE4CBE1D4DED6E1D0E1D3DFD7D7E3D0E3CFE5D5E4DBE4D2E3
D6E6DDDBDCD9D9DBDBD6D5D8DBC8BF734541495B
4644444644404247484E4D4845403F4441434445454444443F4449494747444042424140
403F3F3F3F4143433E3B3E43444648494744403D3E3E3F403F3F3F3F403E3B3B3D414345
453D44524044443B494E52535556534E544B5B607975574A4F534B59485A555C524A5249
49413F45453F493D413E3F4142413E3F464F514E413E5B445B4751475B565A485D4F5E4F
46423E5560816982788B799F85AD9AAA9DA4A89AA698A39EB88FB392B996BB97A8A3B8B4
B8AFBDB3B4C2A8C89CAF8D95889B799E71785E5B8094BBB4B1A9C1C1CEBAD7BFD1B8D4C3
D8D6D6D8D6D2D4DBCDDEC8E2C2D9C2D1C2C6B2CBACC2B0BFBEC6C6BDCBB5D3C7CDBBD9BD
D1B9D4BBB8ABAEB8C4CAC9D1CCDEC2D4D6DECBDDDED9D4D5D6D7D5D5D4C8D4CFD9CED5CD
CBC6D6C5D7C2CDC4CCC8CACBCCCFCBD3C7D1BCD5B8D6C8D6CFD5CDE0D3E3D3D3B6A5AFBF
C7D0D1CFD2CCCBA6B3A5B5B1B4BDBEBFC4C2C1CBCCD1C3D9C6D2CED3D0CBC5D6CAD1CACE
CAC9C9CACACACBCCBEC3C8BDC7C4CBCCC1C3CFCCC7CECFCFC8CCCDCCC8C8C9CCCECCCACB
CCCCCCCCD1CBCCCACED3D1D5D2D8D9D3D9D3D5C6CDCBD2CAD0C6C4CFD4CACED5D1D0D2CF
D6D1D0D2D1D3D5D3D5D6D6D4D2D2CECABCC6C1D9CACEBDC9CBC9CEC7CACAD1C9C6C2CAAB
BDA9B7B1B8B4C1B1BFB0BDB9B7BFB6BCB2C6C1C1C2CCC3CBBAC8C8C3C1C7C8C3C0C4C9CA
C9C3D3BDD3C1D1C7CBC3D2BCD0BCCBC2C9CAC0CDC2CBC1C7C5D1BADAB9D7BEC9CDC9C2CB
CCCBD6D0D1C3D7C7DAC1D1C5D5CADCB9DFBBCBBFCFCDCDC9CED1CCD3C1D6BEDEBAD8C6D0
CCCACACFC7CBBFC5CFC3CFBBD5C3D3CAD5C6DAB6D9BCD2C2C9CACCCFCEDAD2D3CADBB7DB
B3D9C1CAC2C0BCCBC0CECACFCCC3D4C5D8C3D8CAD7CEE4C6DDC3DCCFD8CED3CDCBD7C2D3
C6DBB7D1C5DDC4D0CACEDAD9DED6DBDBE0D9DFCFE0CDDDD3E0D4E2CBE2CCDBD2CEC8C8D2
D2D9D2DCCBD9CBDDC5D1CCD5D7D6D5D4D3D4D9DDDCD6DFDBDCD0D7D7D9D3E1D0E2D8D7AE
84584E505A535C6886B1D1DCDADBE3DDD9D6DAD8D9DDDADED6DCD5DCD6D9DADADEDEDDDB
E1DAE1DCE2DFDDDEDAE3D9DBD7DDDADBDAD7D9D2DBD9D8DADAD7D8DAD7DAD0D6D7DAD5E2
DCD7DED9DAD5DCD8DDD7DAD9D8D9D5DBD7DFD4DAD6D6D6DADAD8DAD3D7D1D7D7D3D7D6DD
D8DCD6D7D6DED8DFDBDEDEDAE3E3E8D6D7D9DCDADBDBE0D9DDD4D5D2DBD7E3D0E1D3DED5
DEDEDFDEDBD8D9DEDCE3C9E2CFDDCCD5D5D9D6DBD3D8D8DFDFDCE0D1DDCFD7D7DCD5E4CD
ECD4EBD9DCD9D9DCDBD7D6D8C5DBA0664847536C
4746464645434446454B4A4443424246434342403E3F4347404144423E41434041404040
404040403A3E4243413E3D3E4141424241403F3E3F3F4344424143413E3D3D3F41414140
464354614543453D494A474343484B4C555665697560474845484A494445494D4C4B5654
584E49454B3D4639424147504D5D61585762655D617369856583677361715B745C72574F
483C5857A88AA594AF9FBA90BE94B4A8ADB5ADB1A9B2A9B1A6BBA3C0A7C5B2CBB7BDBDC8
B9C3C2C8C9CAD6CED5BDC2B7B696A685A196A6A5A7C2C7D5D3DAD1DDC5E2C8E3C6E7CEE5
DCDBDDE1E0DDDDE0E4E2EAD0E6C6D3CCD4C1CCC0CBBBC3C1C0C7C4CFBBD4C7D9BED1C0CF
C7D9C6D2BEB2B5BCC5CACAD3DCD2DDD0DFC6D7CBD8C8D7C1DEC7D8CDC6C2C6D3C2C8C2C7
B4BEB6D2C0D1BEC5C1C0BFC1C1C5BFC9BDBDCABDCDC0C9C4CBC8DCD0E2D4E1D5D4C5C6CA
CED3D0D0CDD1BFB8ACB7B3BAB3B8B6B6BFC5C9D0CDCFD1D0D2CAD0C9CEC1D4BFD0B8CFC9
CECCCCCCCAC6C3C4BCC5C3BBBEC1C1BFC2C2CDCDC9CDCBCAC6D2C8D2BAC7BDC6CBC8C7C7
C7C5C6C9D0C9CBCCD0D5D1D5D2D4D3CED4CCCBBCC9C6D1CDD4CDCACFCDC7C8D2CED3D6D7
D4D0D0D1D1D0D1D1C3C5C5C4C7CAC8C4C3BED3C7DABEC8C2D2CED3CCCDCBD2CCC7CCB8C2
B8C7B7BBB0BAADC2AFC3B6C0BCB9C2B7C1BEC6BCC2C0CFBAC6B8D0BDC9CCCDCBC9CBCDCF
BBCCB8D8B9DBC3CDC4D1C3D4BDD6C7CEC9C2C9C2CBC0C8C7CABED6B9DBBED5C9D1C5D5CD
C7D0CBD9CDCEC4DEC9D8CAD1C9D3C5D5C3D2C4CDD0CCCCCACFD0CAD1CBC6DEC0DABBDACA
D3C8D7C8D6C6CAC8C3D0B8D9BADCC8D6CCD5C4D0C0D3C5CCCDCECED0CEDAD2D4D6D0D8C2
D5C0D2C5CEC0C9C0C9C6D1D2C1CABFD9C1D9CED5CCD8D0DECDD9D4D5CED2C6D2D0CCCACF
DCD0D9CBDBC4DAC3CDD0DBD8D9CED1D2D0DDC9E5CDE5DCE6D9DBD4DDD5DFD8DBDBD5D2D6
D2DAD4DBDDE0E5DDDFD1DBD8E0DBDCDDDADADDDEDAD9DCDDDCDADDDFDDDAD5DBD6DFCFA9
86596355684B5A5C87B8D6DFDFDEE1DDDCD9DCD9D9DBD7DAD6DBD3DBD6D9DADBDEDDDBD7
DDD6DFDADFDDD8D7D2DED9DED5DBD8D9D8D6D8D1DBD8D8DADAD7D6D7D3D8D2D7D5D7D2DA
D9D5DBD6D7D3DBD7DCD6D8D7D6D7D4DAD8DFD5DCD9D8D7DCD8D6D9D2D7D2D8D8D6D9D6DB
D5D9D6D9D6D5E1D2E6D5E6D9E1E0E6D6D6D6D7D7CCD6CDDDD2E0D4DCD8DCD8DAD5DBD8D7
DEDEDEDDDAD8D8DBDCD9DDCDE6CDD9D3D4D2E1D3DDCBD9D9D3DECDDECCDFD2DFD9E4D3E4
D4E4DBDBDAD9DADBDAD7D6D6DFC6B75C5052656B
484A4A4A4A49474442484540414344474644413F3F404141414042403B3F444140404040
403F3F3F3C3E41434443413F3E3E4041414141414141474945454643424141434343413F
474446514648454345484845464B50534A556969654A434E414D545245424853565D696E
786D67595B4550495E636B7877888F867F83847F8B849E829C8A9B94989AA78C9A787755
4246649BAFCEB2B8B7C0A9C3AEC7B5C8BFBAC3B8C1BDB9C0CABCCBBACEBDCDBFCDCDD0C7
CCC3C5C5CCDBCDE3D0DED7DDD3C5A3A396A9BFCCD2D1E3E4E2D9E0DAE0D9E8D8DCD4E6DF
E4E3E3E5E6E5E3E2DDECD1EBCADBC6CDCBBDBDC9C3C7BEC3C5C9CEC9CAC3CED0D0B9D4B0
D5B3CBACAFB5C5CBCED0CACDC3D5BDD9C7D5BECAC7C5BBC9C2CDC4C8B9ACC0C1C2BEC5C7
C0B7CDB9D9C0CCB8BCBCBBBFBEC1B7C1BDC6BCCDBAD2CBD1CFD2D5DAD2DBDBD8DAD5D4D1
D5D5CCCDD0CEC5B7B5AEADAFBEBFB9B4B9C3C7C8C7D6CCD6CAD2CBCACFCDCECDC9CCCFCC
D4D0CECDC9C3BFC0B5BEBABCBDC3BCBDC7C2CACCCACCCACAC5C8CDC4C6C2C7C5C4C3C5C6
C4C1C3C7CCCAD0D1D1D1CDD2CFD0D1D1D9D2D7CED3CBD4CFD2CECCC9CCCDC9D2CAD2CFD3
CFCED0D2D1CDCBCDC7C5C7CDD4D6D5D4C5CFC7D9C5D1C3CAC7C2CAC8CAC7D1D1D3CEC8C4
CBC3BBB8B9B3C1B3C7B8C4BDC1C0BCC3BAC3C0BDC6CECDCFC1CBD2C6CBC9C8C9C8C8C9CB
CBCCD1CACFCBCEC8C7C6CCC2C8C0C5C2C9C7C1CAC5CAC6CAC6CDC4D4C6D5CBD1CCCACCD2
CFD0D9DBD8C9D3CCD7C7D2CDD1C7D7C2D5C1D2C8D0CDCECCCFCFC8CFC4CFC6D7C5D5D3D3
D3CED2D3D1D2CCD1CCCBD0C9CCC5CCCCD1CDD8BDD4C0CEC7D3D3D0CFCBD8D3D7CBD6C7D7
C5D5CFD2CDC8CBD2C8D0C9CFCEC9D3CBCEC7CFCACDD0DDCEDEC8D7CAD2D1D6D5D3DECEDB
D0DBC6CDD6D2CDCCCBCAD2D1D6CED3D4D9DBDED7DAD0DCDAE0D9E2D3E2D2DAD2DCDAD7D7
D3DFD9DEDDE4E1E4DFDDE0E1E4DDDDE0DDDDE1E1DBDEDBDDD8DEDDDFD9D4D6CEDED7D7B4
88675A5650565D638EC1DADEE2DFDFDEE0DDDFDAD9DCD8DBD8DCD3DBD6DADBDADCDBD9D4
D9D1DBD7DCDCDAD7D0DCD7DCD1D7D5D6D6D4D6CFD5D2D3D7D9D5D2D1CFD5D3D8D6DDD8DB
D6D2DAD6D7D3D9D5DED7D8D6D5D6D3D9D6DCD2D9D4D0CED2D8D6D9D3D7D1D7D6D4D4CED4
D3DCDBDDD1D6D7D6DCD9E0DADCD9E1D7D9D6D8DAD6DADAD9DFDDDBDEDBD8DFD1DDD4DED7
DDDEDDDBD9D8D7D7D1DCCFDDD2DCD4D5D9D9D9D9D4D0D1D6D6D7D8D2DAD6DADEDDDDE3D5
E1D3E0D6D6D8D9D8D7D7D5D2C7D59F8478918A9B
494D4E4D4E4F4A434146433D40434447484644454745403A414145443F43464141414140
403F3E3D42414041444645443D3F4244454544444242494C474748444443424345484949
4F4F40434448414B565D62605C5A58565E687A7A6F4F4745536E70805F6C6B8479838D95
A299958193757E799292959EA4A8ADAFADAAABAEA8AFB1B8AEBDB3BAA5B9B7BDAFAF9D8B
595693ADD1C1CBBBC9C1CABBD4C0CBCCD2CBD2CECFD2C2CFBDD1CCD7CCD2C6D5CDD3D0D4
DBDAD1D3D9DBE4D9E6D2E4DDE8D5D9BAB9ABC7CFD3DDD9E0EBE6DDE9DFE7DEE8DCE5DBE3
E5E8E9E5DFDFE3E8E5DAEBD4E9C6DEC7D6B9CFBCD2B4BBB1B4B6C3C5BBCCBFD1CBD5BDD2
BAD3B9BEAFBED1CFCCCFCCCECEC1C6C2C7BAC8BBC6B7C2B1C9B4C0B7C0B1BAC3BFC6C4C6
B7CAC0D2BBD2BEBFBEC0C0C5C4C7BAC4C4C2C7C8BEC5CAC2D0CEDBD4DAD5DDD2D3D6D6D2
D7D5C7C9D0CFC7C2C0BCB9BDB7C0C3BBB7C0CBCFC9DAD3D1D0D5D6D4D3C8D1C3D5CCD0BA
D0CCCBCCCAC6C4C6BCBEBFC0C8C4C1C1C9C0C8CCCBCDCCCFCBD1C9CDC1CCC3C4C5C6CACD
CAC6C8CED2CFD4D0CAC8CAD5D5D6D6D3D6CBD1CDD2C7D1CCD0D1D2CBC5CEC9D5CAD4CCD1
CBCCD0D4D2CBC7C9CBC3C4D0D6D2CFD2CBCCD3CACDC5CAC6D2CAD0CBCAC1CACBC8CFC4D5
C9CFBDC5BCBEBAC4C1C9C3C4C2BABDBFC1C3C9C6C7CAD4CAC9C7D8C6D1CBC9CBCCCACBCF
C9D1C4D1BFD1C6CAC6C9C3CEC2C7C0C8CDC6C4C5CCCBCBCACBC8D3C9D6CAD2CDD9CBCFD0
D2D9D4D4D4CAC6D0CACDCED3CDC7C9CCCACFD3CECBC9CBCCD1D1CBD3D1CCD2C8D1C6D4C5
CDC6D0C9D1CBCDCFC2CEC6D5C0D0C8D3C7CECCC7CACCCDD2D1D3D4D5D0D9D0D2D1CFDAC4
D7C0D4C7D1C8D2CECCCCCCCFCCCECCD5C6D1CBCFCAD4D3D6D7D2D6D0CCD5D4D4D2DCD6DB
D7D4C7C6D5C6CDBFD1CACDCCD5D0D4D5D1DCD4DFD0D6D7DED7D6D9D9DDDBDCDAD9DAD9D6
D2E0DBDEDFE3E0E1DFDBE0DFE7DDDBDCDADDE4E5E1E3E1D9DBDCDEDCDDDFD5D1D9D5D0BA
866555474B5E6B6894C8DBDCE3E1DEE0E2DEE0DBDADEDCE0DADDD4DBD7DADBDADFDEDCD8
DCD3DCD8DBDFE1DFD5DDD4D6D3D9D7D8D8D7D9D3CECCCED5D8D4CECCD1D4CFD1CCD4CEC9
D3D0D9D6D8D3D9D4E0D9D9D5D4D5D2D9CFD6CFDAD8D7D6DCD3D2D7D2D8D4DADADED8CDD1
D0D9D5D4D6D6DCD0DDCFDCD1D7D4DFD9DEDBDEE2D5DCD4DBD8DFD6DDDBDBDCD6D9D9DDDA
DDDDDCDAD9D8D6D5D2D4D7D4D3CFD6C9DDD5D6CFD7CFD8DBD0D8D1D9D6E1DDE7D5DED9DE
D8DCDEDDD4D8D8D5D5D6D4CFDAD2CEA9C4C3C4C0
4D5158735A57414747453F4445484E5359474945594A4F4B4C3F46453B43454042444140
3D414141434F3F52444F434B3D46414646434D484C4A604E52545D544F535D57575F6560
5F5D5D5B535C565F596B718E8A8C898A85818B796C4843516B87AD9EA89CA89DA9A2A9B2
BCC0B7B59FB29FB9A2BEAFC4C0BFC0C7C9C4C2C0C7C6D1C9C5BBCCC0CEC6CEC2CFBBB6A6
8C8A97C6D3D5CDD9D1D8D2D8D2D3DBDED6D9DADEE1D8CFCFCDD7D7D2D8CBDCD1DEDAE2D9
DEDDE0E3DCE0E0E9E5E9E4E4E2DDE0D9D9CBC9C6BFC7D9E8E3EBE3E4E3E2E2E3E5E5E5E4
E5E4E6E0E1E8E7E9DDE6D9E0CFD5D0CFC6BFC4C7BFBFBEB2B0AFB9BABEC4C3CCCDCDD2CE
D6C4C6B8BBC2CDC7C2C5C4C9C2BDBCC8BFC0BAB7ADB1B8BDBCBABDC2BBC4C7C7CED2CDCA
C7CCCDC9D1CDCFC0CFCECECEC9C5C8CEC9CAC5C5C5CECFCECBD6E0D1C9C3D2DAD5D7DBD4
D5D5CFDBD4CCC9C6BCBBBAB4BEBDC1BAB8BEC4CFCDD2D3D1D6D2D8D1CBC5D1CAD4C9C7D0
D4D4D0D1CDCDC5C1BEC5BACAC0C7BEBBC1C6C8CACACAD0D3D0CBCCBDCEC2C4BBBDC1D4C8
C5BACAC8C6CEC6CFC6D7CCDDCFDDD0D9D2D8D0D3D1D3D1C6CFCBCDCCCDC6CDCECEC2C7C9
C9CBD3C9D4C6C7C5C9D0D2D5CCD9D2D7C0C6C4D3C2C9C2D1C6CECECFCBCBCAC6C8CCD0C7
D1C0C8C5D1C7C8BFCEC7C9C0C0B2C0BCB7BFC1D5BECDC8D0CCCBCBD1D0CCCBCECFCBCACD
D0CECDCDC5BDBCC2CFC2C3BAC2B6C0C2C9CCCFCBCCCDCAD2C3D0C8D7CCD8CCD5CCCCD1D2
D1D7D5DCCECDCECAC1C0CABCBAB7C1C0CAC2D5CED2CDD2D1D1D1D0D8C8D0CBD7CFD1CFD0
CFCDCCCCCECFCFCECBCDCDD1C9D2D0CCCDCED5C4D0CDD7CED4CCCBD6D5D9CDD2CCD2CCD3
CECFD2D2D4CBCFD2D2D0CDD6D1D7D5D6CCD1CCCCD3CFD2CFD8D5D9D7D2CDD2D0CBDAD1DD
D1DECCC5D2CFCACDCAC9D2D1D0D1D0D8D0D9D5DBD3D3D7DADAD7DDD1D6D8D9D8D6D6D7DA
D1D9D8E5DDDFDCDEE1DDE4E1E5E6E6DDDCDCD9E3DBE2D3E0D0DBD9DED9D3D9DCD6D8D3A9
71544B3F45556E5C96C5E3E0E1DAE1DEE0DADED7D3DCDDDED1DDD4DFCFE0D5D9D4DCDFD7
D5D9DDDADFD8E2DAD6DAD3E0DED5D9D2DECDDBD3D7D1D7D5D6D3D0D4C4D5CEDFC4D4CBDA
D1D6D2CFD7DAD7D7D5D5D7D9D7D5D7DDDBD5DBD5DCCEDACDD8D2D7D0DDD6DBD6D7D9DAE0
D5DAD1DBCEDAD1DED2D7D1D5CED7DDD8E4E1E2E1DBDAD7DADADDDCDCDCDEE2D9E2D5DDD2
DFD9DCDAD5E1D3DAC8D5CBDFD0DDD6DAD0D7D9DAD2D5D5DAD2D1CFD5D7DCD9D8DED4E6DA
DDCEDED3D5D1DDDAD2D4D0D1C6D1C9D5CCD1D5D9
585366656D505C48423E51515D5C5B5F6053525057545B5B514A524F494C4D4B403B4240
463D464B45495D51564F3E3D464B4F48464B50545E726B8B72937B8E7B8787979298988C
988E9C848D7B7E7983889099A59EA9A7A5A5A2977359547592AFC5C9C4CACAC7C4C4C9C8
CFD6CFCACBC5D4B9D0B3C7C7CFCECED3D4D1D0D0CFD3D3D8C8CCD3CDCDCED5D5DAD3D0CA
AA9EA1B9D3DBDDDEDBDCDFD9E1D6E4E0DDDFDEE0E3DCD4D5CCD5C9D8CECDD1D2D9D6DFDA
E0E0E1E3E1E3E0E6E1E8E5E8E0DEE4E1E3D5D1CCB4BCCEE0DFEBE7EAE3E2E2E3E4E5E4E3
E3E2E6E1E2E8E5E7DDE5DBDFD2D4D0CDD1C4C3C7C3C2BCAEB0AAAEAFB2BABECBC8CEC9D5
D4D7D5D2C8C9CDC4BFC3C2C7B9B4B1BCB8BFBAB5B0B1B5BABCBDC1C7C7CFD0CED1D3D6DD
CBD0D2CDD6D3D9CECCCDD0D2D2CFCDCDBFCAC7D6CDDACECDCFD3DBD4D8D3D5D1D6D6D7CF
CECFCCD6CECDCBC3B5AFB2B4B5B2B6B3B7C1C6CFC9D5CCD9D0D9D4D2C6C3C7C9CDCFCCDB
DBD2D2C6D0C6CBC7BEC0C7C1CBBCC7C0C3C3C3C7CACCCCCAC3D1BAD2BCD8BEC6C7CBC9CC
BCC6C9CCC8CBCCCCCBD2CCD6D2D8D8D0DCD1D6CFD0D2D2C9D1CDCFCDC6CEC2D0C8D0C4D3
C2C9C3C9C5CBC5CDCACDD6D1D0D4D2D4CFCBD7C6D1C0C7C1C9CBD6C5CDD3D2CDC5D1C8D2
CBCFCDD4CCCCC5CFCCD4CAC8C7BFC2C1BCBFC7D0CFCBCDBFD6C4CFC7D0CCCACCD0D2D4D6
D0D6C6D2BCCEC2CAC4C4BABEB9C5C3C6CACCD0CED2D3CCD1C8C6D6C6DDCAD4CFD1CDD8CF
D6D3D5D7D7D4CACCB3AFAFA8959792A7AEC7D3D5D4D0D4D2D2D4D2D7CCD1D0D3D3CDD0CC
CBCACACBCDCFCFD0CCCECCD0C8D2D1CFD1CED5CAD7D1DCD8D9D2D1DAD8DBCED4CACAD0C9
D3C6D2CCD1C9CCCDCFD2D1DAD1D5CFD1CCD3CECDD5D2D6D2D9D4D7D4D0D0D4D7D2DCD4DB
D2DED5D6E2DDD8D8D4CFD5D6D5D4D1D8D6DBD0D7CED1D1D2D4D3DCD4DBDCDCDBD5D5D8DD
D5DAD5E0DCE0D6DED9DEE0E2DFE0E1DBDDDFDCE6DDE0D7DAD5D7DADBDED2E0D6DBCED1A3
72554A5455606B6990D0DDE5D8DFD8E6DCD7DDD7D4DBDBDAD2D2D7D6D8D5D9DBD6D4E2CD
DFD1DFD6DBD3DCD6D5D9D4E0D0E1C2E4CCE4CDDDD9D6D5D9D1D6CCD2CFCED8CED4C6CECE
D3CFDCC5E1D0DCD3D8D5D4D6D8D8D9DCCED6D1E1D1DADCDED5D5D1D6D5DAD7D8D9D6DCD9
D6D4D1D8D6D1DBD3D5C6D4C7CDD4DAD4DFDCDEDED7DDD1E0D2E1D6DCD4DDD6DFD8DFDEDB
DEDADDDAD2DDD1DBD4D2CECFD4CFD6D2D6D5DED6DCD1DADACBD1CBD9CFDDD6DCD5D3D5D4
D2D4DADBD8D0D5CDC5C9CBCFC8CECFD3D5CFD3CF
55515468526D54574F5B5063585657576C5C684F5E4A5F544C4C5852535151555B574E5B
4B4A495C567553784E54424A637872777472857F9A82B49CB88FAC9AAC9FB4ABB6B5B1AC
ACB7AEC5ACC2ABB59FA899AD9CAFAEBBC3B7C4A3915D6680BCC1E2C7DFC4D7C9D3D2D7D3
D4D8D3D2D1D9CBD9C2CEC4D6D9D7D9DAD9D8D8DBDAD5E3D4DDCDE4D6DDD6E3D3E5D1D9CF
BCBBAEC9CFEADFDEDEE5D7E5D5DFD8DBE0DFDBDADBD3CCCDCDC7C9C9D6C1D2D0DEDBE2DD
E1DEDAD9E3E5E0E5E0E7E5E8E0DFE6E5E9DDDBD7CBCEDAE4DDE6E0E3E2E1E1E2E4E4E3E2
E2E1E5E1E2E7E3E5DEE4DCDBD3D0CFCACEBFBCC2C0BDB8ADB0A5A6A8ACB0B8C7C3C2CEC6
DBCAD8CECDC8C5B8B2B5B4B9BAB6B0B9BBC7C1B9BBB8B8BBBFC2C7CDD1D4D1CECCC8CAD3
D2D5D3CCD1CCD4CAD0D1D2D3D4D1CCC7CBCDD4D1D5D1D3CFD8D4D6D3DEDCDBD2D9DADAD3
D1D1CDD2C8CCBABFAEB8AEB6BCB6B7B6BCC5C6CBD1D2D9D0DBCBD4C9D9CDD4C1D1C1CAD1
DDD9C6D2C1CBC0C9BDCFBDD8B8CCBFCACAC4C2C5CBCDC5BFC3BDCCB1D1BBCCC2D7CAD9BE
D5C4D9CDD3DBD1DECDDFCCD7D2E1CBE1CDDFCDD0CED1D4CDD5D0D2D0D3C2D3C6D0C3D6C8
D6CDD8B9CFB2C1BBCAD2CED9C8D9CBD4CDDDC3DDBCDCC0C2C2CFBDC8C4D2D6CED4D3DEC7
DCC2D7D3D6CBDDC8E1C6D1C2CAB9CABEBAC8BFCCC8D0B3CDBFD9CCD4D8D4CFCDD0D5D6D5
D6D2D7C1CBC0C9BFCDC8D6B8D4C6D6C3C9C9CAC8CED1CBD0C5D7C0E1C4E0C3D0CED0CFD6
CCD7CCD3D8CED1C2AF8887797D758786B7BCDCCCD5D3D6D1D2D7D3D5CCD6C8DACBD6CDCD
D3D3D2D1D0D0D0D1CECECBCFC8D2D3D2D5CED7D0DCD1D9D8D8D3D2D8D2D3C6CCD1D9CED9
CACFCACBD0CCD0CFD1D5D4D9D6D6CED0CCD4CECCD4D3D8D3DAD5D8D3D8D7D3D5D0DAD9E1
D4DAD6DDE4DDDAD7D9D0D1D3D3CFCAD0D8DACAD3C9D0CDCDC9CAD7D3DCDCDAD8D8D6D8DC
D5DBD4DCDADBE0DBE4D6DED6DEDDDEDADDE1DEE5DDE5D0E2CFDED5DADCDBD9E6D5E0CFA7
5D505B55675F665AAAC5E7D6E4D6E8D0DAD7DCD9D6DBD9D6D6DECBE7C6DAC8D9D5DBD1DD
CEDBD0D4D8D0D7D5D6DBD7E0DFCDE2CEE2C4DFC9DAD2DCD1D9D0D1D1D0D3CADBCDD6CBD1
CDD8CBDCCDE0D0D7DBD5D2D5D9DADBDCDAD3E7CFE4C6E1D5D7CEDCCAE0CFDED7D6D9D3E0
CDD8C8D3C4DBC0DBC7DAC4D3CDD1D6D1DAD7DBDBD7D4DBD3DCD4DCD9DED9E5CEE6CDE1D3
DAD9DEDCD2DAD0D9D2D8BBDCC6DFD0D9D4D7CEDECDD6CCD6D1D0D3CFD2CDD1D0DAD4E4CD
E5CEDDD5D6CFCDC4BDC1C5CBC5CEC4D5CBD7D3D6
4E4C465160576659695C6F5D655F5E6766695F6D556A62625361626E64736A7B7B71796E
6D525C65836C8A656949506F8992A8A2A1ABA1A3A7BFA7D0AEC29AB6B2BAAECAC0C3C7C1
C5BDD7C0DDC1D2C5CEC4C5A8AD9DB3B6C6C9C1C9A8A292AFC8D5CFDFCCDBCED3DBD5DADB
D8D4CFD7DCD6E7C9DBC3D9D5DBDADEDBDADBDADEDAE2D6E5CFDEDCDBDCD9D1D6D6DBD2CE
C3C4CCCCDADBDED6DED7E0D0E1D0DDD4DBDBD7D8DAD5D1D4C4CBB6D5C3D4CCD7DEDAE0DF
E2E3DDDDE1E4E1E7E2E6E1E3E3E0E5E3E8DFE1E0DFDFE4E9DFE6E0E2E1E1E1E2E3E3E2E0
E2E0E3E0E1E5E1E4DEE1DAD6D1CDCEC7C6BBBABEBAB7B8B6ABA1A0A6A9A8AEBCB7BFC4CE
D3CFD0CAC0BCBBB0AAADAFB7BCBAB3BDC3D3CDC5CAC4C0C2C6C9CDD0D2D0CFD4D8D0CBD0
CBCECEC8CEC9D2CCD1D3D3D0CFCECDCACCD4C8D7C6DAD3DDD9D5D7D3DCD9DBD5D0D4D5D2
D0CDC7C4C5C1BEA7AFA0A8ABB3AFB3B4BBC5C7CDCBD8C8E0CADBCED2CFCFC7CDCCD3D2DF
E1D0D6C6D4BBC2BEC8C5D8C1D8B9D1C5D1C9C8C8CDCEC2BBB8C3B3C3B7D0C7D3D3D9CAD8
C8DCD0D3D0CFD8CFD5D3D2D1D8D4DFCCE4CDDBCACFD0D6D2D8D2D5D2CDDEC0D4C3DBBFCF
CAD4C4D1C0CDBEC9CFCDD7CFD3D0D0D0D7CDDEBCDDBED3BCD0BDCCBED2D4D5DAD1E1CDE0
C8D8CEDBD1D9CFE0CDD9C8CBC2C3BFC5C4C4CEC6CCC3D0B5D3B9D8D1D4D3CFCED3DADAD5
CADAC7DEBDD7C1CAC6D3C6D2C5DDCDC7C6C8CBC9CED0CAD1D0CADCC4E2C6D1C6D0CAD9CD
D9D1D4D2C9CDC3C69A826D6767756B97A4D6D5D4D4D3D5CFD1D7D3D1CED0D0CED6D0D7CF
D5D6D6D4D2D1D2D3CFCECCD2CAD3D4D5D6D1D9D1DACACFCAC9C7CBD3CFD4CCD3C9CCCCCB
D0C9D2CFD4D3D7D4D4D7D2D4D3D6D1D4CFD7D4D3D2D2D6D1D8D6DAD6D6DAD5DBD4D9D8DB
D5D4D2DADCD7D9D7E1D3D1D2D3D1CBD2D3D0CEC9D2CAD3CEC9C9D7D5DEDCDAD8DED9D7D9
D4DAD4DDCFDBD5E8DFE7E0E0E2DEE0DCDEE2DDE0E0DEDAD7DDD7DED9E2D8E7CFDEC9C384
51474A6D685E506D9BDEDCE7D3E4D2E6DBD9DCDBD8DCDBD5D6CFDCCEDBCAD8D8DBCFE3C6
DEC0D5CDD6D0D5D6D9DCD8DDCEE5C6E2CEE1C7D7D5D6D2DBD0DCCFD7D6CADCCCE5CBDCD5
D1C7E1C3E9CAE1D3D9D5D4D8DADADADBD6E2CBE8CCE2D0D5D4D8D0DBD0DCD6DCD5D0DAD4
D8CEC9CAD1C2DAC8D9BFDDC6CFD0D7D3DAD5DAD9D3DDCDE2CAE0D1DCD5E0D0E3D2E0D8DB
D7D8DADCD5DBD1D6D6CBD0C8DCC7D5CED9CBD6CADBC5D0CED0D6CADACBDDD1D7D1D7D1DB
D1DDD5D7D4D1CFC9C5C7C9CDCBCAD1C7CFC4CECB
51464A5661705F71627162796D6E737484738E6A8F73917B89889C8198828D929CA5A3AD
96958A92879E759A625F6790A6B9B9C2C2B9BAA8C4B6D7C1D3B4CEBBD7C2D4C3CAC8CED8
CAD7C5E4CAE5D1DBD5DCD1D9BFC4AFB1C9C3D4C4D6C6D1D8DFD6EACFE9CEDFD4DDD7DDDF
DCD6D1DBD4E5D5E4C6E3D8E1DEDDE3DFDDE0DCE0DEDAE2D3E0D1E3D6DBD1D8CBDFD3DCD2
D2DAD0E0CFE0D7E0D8DCCFDFD1E4D8DFD9D7D1CFCFC7C0C2C3C1C7C0D3D0E0D9E2DEE1E1
E2E6DFE0E0E3E0E6E0E4E0E1E5E2E7E4EAE1E4E3E2E0E3E6DDE6E1E4E1E1E1E2E4E3E1DF
E4DFE2DEDFE2E0E5DEE0D7D3CECBCDC7CBC2BFBEBAB7B8B8A89F9BA3A5A2A8B3B5BDC2CA
CDC6C5BFB2B3BAB5B1B5BAC7B8BAB5BFC8D8D2CDCFC9C4C7CCCED0D1D0CFD1D9DDD3CBD0
CDD0D0CCD2CBD3CDC9CED3D2CFCFD3D7D4D2D6D0D3CCD1D0D4D2D8D6DDD6D6D2D5D9DAD8
D5D3CEC6B8C3A0B699B7A1B5B3B4BCBBBDC5C8D0D8D6D8D0D9CAD4CDD4CFD7C9E0CFDCDB
DEDBCBDDC9CFBDC4C8D7C1DFC3D9C6CCD3CDD0CECFD1C6C4C7C5CFBAD1C3D1CED3CBDFC2
DFC7DCD0D3D9D3DDCDE2D6DDD6E1CDE3CEE0D1CFD1D1D8D5D9D3D7D5D6C5D5C9D3C9D9C6
D0C8D8BAD8BCD0CAD0D5CEDCCADAC9D3C7D7BADDBCD9C7D0C2C6B0CAC6CBD0D0D5D5E0CC
E1C7DBD6DCD2E6C9E1C1D1C4CABECFC9CAD8CBCEC0D1BBD6B5D0C9D9D2D3D2D2D6DAD6CE
D3D0E2D3DEC7D4D3DFD3E3C5E3CBDAC7C7CCD4D3D5D4CED5D1DACCDBCCD8C4C9D3D5D2DC
D1DED1D7D7D4D3B69D706C5C65647779B3BEDDCED2D1D4CED0D6D0CECED9C8DACBDCD3D3
CDCFD0D1D1D2D4D7D0CFCED6CFD6D5D5D6D4DCCFD6C8C9BFD0CFD1D6D1D6CED5C9CBCBCA
D0CBD6D5D7D5D8D3D2D5D1D3D9E0DDDDD1D4D0D1D3D3D6CED5D4DAD7D7DBD5DAD3D6D5D8
D7D4D3DCDDDAE0DFDBCECCCCCFD0CED5C9D8C2DEC2D9CAD4D5D2DFDCE3E0DEDDDFDAD8DB
D6DDD6DDE1DFE3DBE7DAE7E0E5E0E2E0E0E3DEDEDDE4D2E3D5E3DCDFD3DBD4DFD5E7C690
4E4E5B4F5B4E566BC2CEEAD5E8D7E7C9DFDEDDDDDBDDDFD8CFDDCBE1C4E0D0DBD2DBCEDA
C0CEC6D4D3CED1D4D7D8D4D6D7CCDED4DBC9DEC9D6D0DCCFDAD3D7D4D1DEC7EAC5E2CADC
CCD5C7E1CCE3D3DAD5D5D8DCDAD7D7DADBD3E3CCE8C8DACAD9D0E0CBE2CEDFD7D4D5CBD9
C6D4C2CBC3DCC0DAC8DBC6D7D0D0D9D7DDD7DBD9D5D1DBCFDAD0DAD7D9D1E3CDE9CAE1D2
D8D6D3D6D2DBD3D6C6D1BBDBC1D6C9D4CDCBBCD2C3CFC3CECECDD3CDD2CDD4D5DECFDDC5
D5C9E1D3CECFCDCCCBCACCCDC4CFD0D7C5C7BCC2
4C4A58648D758E8C8A82988F9A97979E9CA88DAA8FB7A5B1A8B6A7B9A1BAA4B9BCBFC9BB
BFB5BEBBBBABC496917282A3C8C3D4CECFD7C4C5BFDBC9D7CEDCCDDBCED7CDE2D4D5DDDD
DED5E2CEE7CFE3D7DDD1DECBE1D2D5C7C1CEC9D7C8DAC8D5D9E2D7E6D4E5D9DFDBD9DFDD
DBDBD7DADBD9E8CFDBCFE1D6DFDCE4DDDCE2DBDFDBE5D4E4D1E1D9D9D6DBD6DBD1D7D4D9
D6D0CFCCD2CED1D2DDD3DFCFDFD4DBD6DBD9D3D1D1CBC6C9C0CFC3D0C7E6E0E0E7E4E4E4
E0E5DDE0E2E3DEE3DDE3E0E3E5E3EAE9EEE3E3E1E5E1E3E5DCE5E1E3E1E1E2E3E4E3E0DE
E5DFE1DEDEE1DFE5DEE1D5D4CDCDCDC7D1C9C2BDB9B5B0AAAEA69DA3A6A5AFB8BDBCC7BC
CBB6C3B9B4B6BEBCB8BBBFCBC1C5BFC6C9D3CDCDCDC7C4C8CED0D1D1CCCFD0D4D2C8C5CE
D3D3D3CFD3CAD0C8CBD0D6D8D3CFD3DBCED3CADACBD9CFD7D8D2D4D1DAD4D6D2D4D6D2D0
CCCBCBBFC3AEB693B79EB3A8BEC1CBC8C4C8CAD4D1DBC7E1CBDDD2DAD5DBD4DBDCDCD8DA
E1D5DBCFDECCD4CFD1C8D7C4E3C8DCCBD1CDD4D0D1D6CED2C0D1BFD8C2DCC7D2D1DDD4DD
CEDBD3DBDAD5DDCBCDCFD8D8DBD4E1CEE3CDE0CDD6D2DAD7D9D2D8D7CEDDC0D9C7DDC0D1
CCD3C3CBC0CFC9D6D6D1D9D4D7D3D1D3D3CCDBBFDCB6D4C4CCC0CFC2D1D3D2D4D2E3CEE4
CDDCCED8D1D8CFDBCBD8CED5CCCDC8D2D2CDD4C9CCC5D5C0D4BCD7CCD8D8D8D8D9D7D0C9
D5DFD1E9C9D8CADCD5D4C5D2C7D6CED3CED0D3CED0D3D1DAD6D5DBCEDCCCCECAD6CFDACE
D8D1D2CFCED8CAC19479615856685F8F9FCFCACED1D0D4D0D1D5D0D1D4D8D6D1D5D3D9D1
D1D2D3D3D3D4D6D8D1D0D1DAD3D8D5D5D6D5DDCED6CACDC3D1D0D1D5D1D9D3D9CFD7CBD7
CBD4D3D7D8D2D2CECED3D2D8DCE4E2E0D1D2CED0D6D7D9CED3D2D9D5DAD9D4D4CDD5D4DB
D8DAD8DEDED9DCD8DDD3D0C9C5C5C0C5CDCBD9CADCC5D7CEDAD6E0DDE3DEDDDDDCDADBE1
DCE1D7DDDEE5DBE8DFE6E3E4E4DEE3E2E1E5E1DFDEDDDDD9E1D9E4DEE1DAE3CDDECBBF81
5754566E666A6798B9E8DCE7D9E3D2E4E1E0DCDDDBDDE1D8D6D4E0CADACDDAD0D2CBDDBF
D2BBD4D2CFCBCACDCFCECDCEC3E1BEE4C4E4C4D7D3D6D3D7CCD9CDD1CCCED3D0D0CED4D7
D5C4DBC5E6CBE1D2D3D5DADDDAD4D4D7C8DDCAE7CBDECEDAD6D9D2DBD2DBD4D6D9CCCBC3
C7C6C8CCD1C4DBC7D7BCDAC7D0CED8D8DCD6DAD8D0D8CADCC8DBCED7CED6CBDFD2DAD3D6
D7D5CDD0CBD4D2D5D3CFD6C5D2BED0C8C9BCC3BACDC0CDCBC7D2CAD4BDC9C3D0D4D2C9CE
B6C8C7C2CACFCBCCCECACBCAC5C4D4C2C6B6BCBC
525B719C9AB4A9B6A8AFA7B7B6BAC1C4C6BFCBABCBB2C6C3CEC5D7C0D5C4D0CDD8DCD5D6
CDD7D7DCCAD9C0CDABA6AEC8D2D3D3D7D8D6D9DAD7DBE2DADCD0DCD3E2D7E4DCDFDDDFE0
DCE4D3E5D6E2DADCE1DFDEDFDCE7DCDBCACBD5D0D7CFC8CBE0E0EBD9E4D7E0D8E0DADEDD
DEE0DCDFD6DED0EACDE6D9E3E0DAE1D7D7E1D9DDDCDEDCD9DFDAE0D7CFD1DBD5DAD4DEE0
E0DFD1DCD3E1D6D7D7D7D5DBD0DACBD0D9D5CDC9C9C4C0C4CACED8C7D9DDE9DEE0E0E1E4
E0E8E2E7E2E4DFE5DFE5E2E4E3E1E7E6EBE0E1DEE3DFE2E6DEE9E5E7E2E2E2E4E5E3E0DE
E5DFE1E0DFE1DEE4DDE2D5DAD0D3CEC9C8CAC6BEB8B5ADA4ADA89EA2A7A9B6BBBFC5C0C8
C3C6C9CAC0BCBFBDBCBEBFC8CCD0C9CDC9CCC7D0CEC9C6CACFD0D0D1CBCECFD1D2CED0DA
CECDCDCCD4CCD3CCD4D2D4D7D3CCD0DBD8D4D2D2D4D3D5D8DBD2D3D0D8D4D9D9D9DBD4D2
CDCCCDBEADB1A3AD97ABABB8BBBFCAC9C9CED0D9D7D8D4D9D9D4D7D7DADBDDD5E6D6DFD8
DCDCD3DDD5DED5D8D4D8CAD8CED8D2D2D3CCD5CFD1D9D2D9CEC9DBBEDDC3D2C6D5D7E6D1
E4D0D9D4D5D5D0CABBCFD5DDD8DDD5DDD2DADAD4DBD5DBD8D7D0D8D8D9CCCFD1CFCBD0CC
D2CBD2BCD1C1D2D3D8D7D4DFD3DDCFD8CEDECAD9C8D0CCC6C7CDC3D1CCCFD3D5D4D8D9D5
E1D6DEDCDAD3DFCCDDCBD8D2D4C8CFD0CFD1CCCEC6CEC3D8C6D7D4D7D8D6D7DBDCDAD7D5
CFCFD8D3DAD3DADBDED4DDCADDCCD8D0D2CFCDC8CED3D0D7D5D7D8D4D8D2D0D2D4D3D1D4
CED7CDD0D0D4D4C1A26B5444464D5E7DB7CCDBD4D3D1D6D6D5D6D2D7D3DFD2DACDDAD7D5
DBDAD8D8D8D8D7D7D5D3D3DDD5D9D6D7DAD3D9CED7CAD1CFD8D5D2D2CBD2CACEC7C8CFCA
D7CDDBD7D8D0D2D2D2D4D3DCD1D9D8DAD2D9D7DAD7D9DCD1D4D4DAD6D2D2D5D7D1DAD1D8
D7DDD8D7D6D0CFCACECDD1CBCACFCDD1C9D7C3E0C7DCCBD0D8D2DDDAE0DBDADCDBDADDE3
DEE3DBE1E0E2E6E4E9DDE1D9E2DCE3E3E0E3E0DFDBE1D7E0D9DDDDDFE3E0D9E1DADACAAC
8C8F9D98A1A7A7BBDCDEE4D8E6D8E2D7DFDFDADCDADBDFD4D0D5CCD9CDDBD1D5CFD5CDCC
C1CCCBCECEC9C5C6C7C7CACDCFC9DAC8D5C1D6C3D0CDD6CAD0CECECBC4D1C3D2BDD7CDD5
D4CFC7D7CED9D1D0D5D5D7DAD9D4D1D2D1D6DBD1DCCBD6D4D7D0DBCDDECFD7CED3CBBDC3
B9C9C1CCBECFC3CEC5C9C5D0CCC8D2D4D7D0D7D5CFCDCFCCD1CED2D0D5CFD8CBDBC2D0C7
CDD1CDD1C7CBC9CEC8D3C4D0C2CEC8C5C6C4B8C0B9C6C3C9C1C2C3C1C1C0C4C6C4C2CDBF
C1BBC5B9BAC2BDC0C2BAB7B4B7B2B0A59A9B959B
696EA0B5C9C1D7C5CBC8CECFD4D4D4D7CCDBD0D4CED3CADCD6D6D5DBD4E0D7DCD6D7DAD9
DCDADBDAE1D9DFD9D3B9B9CDDCD5DDDAD7DAD7E4D3E3DDE3E3DCDCE0DEDDDBE2E0E3E3DC
DEDFDEDFE7DEE5DDDBDAE8D6DCDBE1E4E0DAD0D7D0D4C3CED1DDDFE0DAE2E0DFE2D3D4D9
DCDAD6E0E2CDE3D1E8C8DED6E4DCE2D6D7E3DBDFD7DFD4DFD9E1DCD9D1D5D7DBDADFDFE2
DFDDD3CFCED9D9D7D0CEDAD6DAD9D2D2D2CFC7C4C8C7C7CECFD5D9D1D6E0E4DEE1E2E3E6
DEE5DDE3DFE3E2EAE5E8E2E2E2DEE1DEE3DBDEDEE5E1E2E5DCE4DEE0E2E2E3E4E5E4E0DE
E4DEE2E1E1E1DDE3DCE4D6DFD2D8CEC9BCC9CEC5BCB9B4AEA2A1979DA3A6B2B4C3C3C7C0
C8BBC7C2C7BEBEBEC2C7C7CEC9CEC8CBC6C8C7D7D4CECACDD0D0D0D1D3D3D0D1D5D3D0D4
D6D3D0CDD4CCD2CBD8CECAD0CFCBD2DFD4D4CEDBD6DDD8DDD3D1D9D8DED5D9DAD5D8D2D2
CCC9C8B4BDB0BEA8B4A7C3C0C7C8D1D0D0D4D4DAD2D9CDE2D5DED7DCD6DCD6D8E2DDE3DF
D8D7D9D7DCD9D8D2DED9D8CDD7C9D6CFD7CED4CDD0D9D1D8D3DACCD3CAD8CED3CAD6DBD9
DBD4CAC6B8B5BAACABBDD2DADAD7DDD4DAD1E0D4DED6DCD8D5CED8D8D1D1C2D5C9D5CBD9
CED1CECACECDCFD4DAD6D8DCD9DBD3D9D5DEDCCDD9CAD5BBD3CACFD5D7D0D4E1DDE6D6E1
D9DED7DADADAD9D7D7D5D7D7D9D1CDD6D5D0D6D5D1D0D5D3D3CBD8D2E1DCDBDDDDD8D7D9
D0D8D4DFD7E3D8D4D6D9DBD9D9D7D3CDD0CED0D2DBDDCFCDD3D6D9D2DAD3D5D7D9D4D8D4
D9DBD8D9D4D6D0C9A26E5048464D4B7DA9D3D7D9D6D2D9DAD9D8D5DCD2DCD6D6D2D8DDD9
D8D6D5D6D7D9D8D7D7D4D4DED5D9D7D8DED1D4CCD6C7D2D6D9D6D1D0CAD3CBCFC9D1CED8
D5D7D9D9D9D2D7DBDCD9D4DBD6DAD4D6CFD6D2D3D4D9DED3D8D8DED9D4CFD4D2CDDCD3DF
D2DBD3CECFCCCCC9C8CCD3CBC7CBC9CACDCDCACFD7D4D6CDD8D2DEDCE3DEDDDFDEDCDCE1
DCE3DEE8DDE1DCE2E0E0E1DFE2DCE4E3DEE1DEDCDBDEDCDBDCD6DDDCE5D8DCDDE2D1D6C6
CAC5C6CAC8D4C8DEDBEADEDEDEDCDAE5DCDCD7DAD9D8DDD0D8D1D3D2D7CECECDD5D2D4C1
CAC6CDC3D0CBC4C4C4C4CBD0BFD2BFD6BFD5C8CEC9CACDCBC9D1CBCCCCCCD0C0C9C9D1CA
D9C9CFCAD6CCD3C8D8D4D3D6D8D5D0CFCED8C9D7D3DCD6DCD5D2D3D2D6D3D0CBCDC3BDBE
BDC4C0C6C6C7CFC3C5B4C3BEC9C3CDCED1CCD4D2CCCEC6CFC8D2CBCECCCCC9CECFC8CDCC
C1CED1D6C8C4C1C4BCC2C3BEC6C3C3B2BCB6B0A8ABACB2B1BAB4A6AEACB6ABA7A8AFAAA3
9A9F9D9C939F9BA1A2948D86908488787C767372
8097B6D1D7E0DFDCDADADFDAD5D6D4DAD7DCDDDCDAD3D9D8E1DCDEDAE2DFE1DDDDE0DCDF
D8DEDDE2D9DFDCDCD6D1D7D8D8DDDEDEE2E0DEE2DEDFE0DFE7DFE4DDE1DFE4E3E2E4DFE1
D8DEDCDFD9E2E0E3D5D9E3DEE1DBE1E3DFE0DBDFD5D6D1D7E1DDE0DCE3DEE0DDE0DDD6DE
DBE2E1E7D0DED2D6DADFDBDFE1DFDDDBDADBDDDED8D9D8E1DDDFDFD2D3D5DAD4DADAE0DD
D4D2CED1CFD4D4D8D1D6DBD4D7CAD5D1C7CAC5CBCCC8D1D3D1D5D4D4D4DDE1E5DFDDE5E7
E8E8E1E5E0E2DFE5E0E4DEDFE2DEE3DBE3DBE0DCE2E2DDE3DFE5DFE0DEE2E2E4E6DFE2DC
DDDAE1E1E0DFDBE1E0DEDFD5D7D4D9D6CEC8CDC3C4B1B0ABA9A49E9BA0B1B2C1BCC6BFC9
C1CFC8CDCDCAC4C3C6C7C9C6CCCBCBD1C9CBD5D0D5CBD7CDD5CECFD2CFCFCBD9D2D3CDD4
C5D8CAD6D2D3C6CECED0D6D2D2D8D6D8DBDAD5DCDCD8D9D8D7D9DFD3DDDADED3D4D7D1D5
C6C6BEC2A4BDA6C3B0C9BED6B9C3D0D8D8D5D4D5D6D4D4D8D6D2D2D6E3DDE0DBE2DAE7DD
DCD1DBE1D7E0D7E4D4DAD2D8D3D5D7D8CED2D6D9D8D6D3D1D5D7DAD4D7D6D8D4DCD8E4D8
DBC8B8A8A5A19A969DAFC7DCD0D4D0D6D6D8DDDDD9D7D9D1D1D8D4D3D3D1D0D0D1D1CFCD
D9D6D4CECEC9D3C7D4CDDBD9D6D7D2E2D8DFDDDCD8D5D7D0CDCECECED1D5DADDDAD8D8DA
DEE0DFDDDDD5D9D9DDD3D8DEDADADBDED5D9D2DAD4DADADEDDD9DDDAD7DEE1DCD7D7D9D9
D4D8D6DDD7DDDBDFDAD9DBD8D9D4D4D1D4CCCED7D1D7CED0D5D9D8CED9CED6D1D7D6DBD9
D8D9D2D3D1D5CDC495655051504B5976B4D2DEDDD8D6D7D3D6D6D1DCD7DDD5DDD5D7D6D5
DAD0DAD7D8DBCFD7D1D4D0DED1E6D4DDD4D0D2CFCBCCD3D3D3CDD1CACBCBC9CDD3D3DBCB
DDCDE0D7D7D8D8D4D9DBD5DDD2DACFDCCBDAD3DDD6DDD9DADFD8D9D9D8D5D5D0CED0D1D6
D8D2D7CDD1C0CBBECFCAD5C5C8C6CCD4C8C9BED3C4D5CFDBCDD4D6E1D9D9DBD7DCDFDDE8
E1DFDBDDDDE2E8DEE5D8E0D5E0DFE0E1E0DDDFE5DBDFDAE4D7DED9E2DAE3DBDED7D8DBD7
DFDCDBDCDCDCDFE4E0DDE8DCE8D7EAD8E5D6DDD3D6D8DAD8C6D9C8DBCADAC4D5C8D1D4D5
CDCFCCCDC8C6CABFBDCACACCCFCCCCCDCBBEC9C4C7C1CDCBC6CBCACBB8BCAFC0B9D2C1D7
C8CCC3CBC8D7C7CFD7DCD9D6D6CFC8C8D0D3D6D3DACCD5CDD5D2CECCCBCAC6C3C7BCBCBB
BEC0BAC0C1CDBEC8C2BEC6C4B7C2C8CBCEC8C3C6C1BFCCC7C8C0C8C3BEBEBFC0C1BDB6B1
B4B3B7C0B3A9AEA4A8A4B0A4A098989496968D8E8C858985947F86748778847385787A7D
7472726966666261625B565B535550544C4F494B
93A5CDD5DFDBE7DFE5DBD8D3D8DFDDDFCFD8D5E1DBE0E1E3DFDBDDD9E2DEE1DDDADDDAE1
DCE3E1E4DEE2DDDCD7D3DADADDE1E0DEE0DFDEE2DCDDDFDEE4DBE1DAE0DEE2E0E0E3E0E2
DBE0DDE0DAE1DFE0DAD9DEDAE0DCE0DFDCDDDAE1DADBD8DDE0DDE0DCE4DFE2DFDBD9D2D9
D5DAD8DCD7E4DADADDDAD5D5DBDBDBDBDCDDDFDFDADDDDD6DBD7DBCBCECDD2CED8DADFDB
D5DAD1D8C8D2CACFCACECCD3D5D2D0C8CDCDCBCECFCED4D8D4D5DBD4DCDBE4E3E3DFE4E5
E5E5E1E5DCDFDEE5E2E8E5E7E1E1E1E2E1E2E2E2E2E3DEE4DEE4DFE1DCDAE2D8E8D7E6DD
DCD9DFE0DFE0DDE3D9DFD3DCCDDDD3D7CDCCC8CCC4C0B7B8B0A7AA99AAADB8C2C8C2CFC6
CDC5CFC2C0C1C0C0C1C4C9CDC1D1C4D9C9D8D1DBD7D3D4D7D2D9D0D6D4D1D3D8D9D3D3D6
D0D5D8CDDBC9D1CFD1D3D8D4D4DAD8DAD6DDCDE6D7E5DCE2DCDFD9D9D6DEDBD9DBDDDBD3
CECAC5BDBAB6BCA8D0BACBC1C7CED4D6D6D7DBDED5DCCEDCC9DDD3DCDCDCD7DFDAE0E6E3
E2D6DDE1D8E0D3DADAD8DBCFDACAD9D3C9CED3D4D4D3D4D6D0D6D1DAD3DFD8D9D3D5D8D9
D0CBAC9C8C8A85828AA4C3D6D2D3D4D2DAD4E0DDD9D5D6D0D0D5D2D3D4CFCAC8CCD2D8DC
D5D3D4CFD2CED9CFD3CFDBD9D7DBD6E1DAE0DCDCDAD7DAD4D6D5D5D5D8DBDDDFD8DADCDC
DBDCDFE2DCD7DAD7DCD3D9DDDAD8D9DBD3D8D2DCD6DBDADDDBD6D9D7D7DCDEDAD6D6D8D9
D6D9D7DCD5DBD9DDDCD7DED1DBCED4CFCAC9D0D7CDD2CDD1CED8CED2D1D5D4D4D7D3D6D1
D0D2CED1CBCACDB1986466646959587CB8D1DAD8D6D5D8D5D7D6CFD8CFDCCBE3CEDFD5DB
D2CEDAD6D2D3CBD6D3CED5D3D8D9D5D7D0C8D9C9D7C7D9D2CDCDCCCFC9D3CCD1C8D6C6DD
C6DDD4D8D5D4D6D4D7DCD8DED5D6D9D5D4D1D5D6DBD9DFCEE4CFE0DADED5DCD2D0D8D2DC
D2D3C6D3C3CDCCCBC7CED0D2CECACBCBD1CDCEC8CEC7CBCCD4D1DDD8E4D4E1D5D7DAD9E3
DEE1DEE3DAE4DDE7DFE4E2E2DEDDDDDEDDDBDCE1DFDCE3DDE2D6DDDEE2E3E5D9E0D2DED5
DDDCDEE0DFDEE0E5DAE7DAEDD2E2DCDDDDD5E1DCDEDBD7D1CBCAD5C7D6C9D4D3CFCBD4C2
D0C3CDC4C7CBD0C7C8D0CCCFCBD3C8D7C5CECCCABFBDC6C5C3C6C3C6C1BBB6BBBECBC7D2
D3C8D4C2D8C6CBCCD3D9D2CED1CAC4CFC4C8C5CDCFCECFCACECDCAC4BEBBBCBFC0BCB9B5
B5B9B8B9C4C5B3B6ABABB2B0AEB5B5B3B1AAA4A6B1AAA8AAA7A6A19892939493918F8F8F
918A88918B85887B7E717770706A66626561585D5F5A5D5B5654545951524F4A49454C50
4843454241423F40433E3B4041413B403D423E3E
A4B0C0E3D4E4E0E3E7DAD4CFD6DFDCDDDDDDE1DCE5D8E1DADDDADDD9E1DEE1DDDEE0DCE2
DEE3DFE0E0E2DDDDDBD8DFDFE3E5E1DDDEDEDEE3DBDEE0DEE3DAE0DBE4E0E3DFDFE3E0E4
DEE3DFE1DAE1DDDEE0DADAD6E0DDDFDADBDDDBE4DEE0DDE2E4E1E4DEE3DCDEDAE2E0DAE1
DBDED9DDD3DEDBDBE2DBDAD8D9DADBDCDDDEDEDED4E1D2D4CDDBD5CED4D0D1CDD7D6D8D2
D0D3D6CCCDCDD3D0CCC7D0CADDCAD3C6D4D1D3D3D4D5D7DED7DFDAE2D9E5E0E3E7E1E4E2
E2E3DFE5E6E8E3E8E1E5E1E2E7E0EADBE9DAE4DEE2E4E0E5DEE3DFE1DEE4D9E4DCE3E1E3
DFDBE0DFDEDEDBE2E4DCE5D0E1D2DBD0D0C6D4C2D4BCC8BFB9BBABB1A7BEB8CABFD4BDD4
C3DBBDCAC2C3C5C2BEBFC6CED4C8D4C9C8BEDBD0DDD2DFCBDDCFD6CFD7DAD0E3D4DED2DB
D0DFC9E4C7DED2DED7D6DAD6D6DBDADDE2DDE2D9E7D6E3DBE2D9E5D0E4D3E2D9D8E2D4DB
CBDBC9C3C0CDB5C6C0D4C4C5C5CED4D4D4D8DBDBD9D7DFCCD8D1DED7E6DDE6D3E3CEE3D9
E3DBDEE0D8E0D1D3D0DACADFCADAD3D8CCCFD2D1CECED1D5D3CED6C7D7CED8CFE1D7E4C8
D9BFB1928B87868285A0C2D0CED4C9D6CED7D6D9D7D2D6D5D6D7D1D4D3D1D0D1D4D7D9DA
DBDADAD4D5CFD9D0D8D3DDDBDADDD7DFDBDFDBDCDCDADDD8D7D5D3D5D7D8D8D8D9DBDDDC
DADBDDE0DCD9DCD5D9D4DADADAD7D7DAD2D7D3DED9DFDDDEDBD5D9D7DEE0DFDCDADBDDDD
D9DCD8DCD5D9D6D9DCDCD6D6D0D2CFD0C9CAD0D3C9D3CFD2D3D3D9C7DCCAD9D0DDD8D9D4
D2D4D0D3CFD9BDB77D7264716B585384BFD2DCD8D6D4D7D5D6D5D0D8D8D6DFD2DFC9D7CE
D3D0DBD7D3D4CED7D0D5C5E1C6E0C7D5D0D2CBDBCBD8CECED0CCD6C6CECACBC7C8C6D2C8
D3C7DACDDAD4D8D5D3D7D6D8D2DFCDE6C7DEC9D5D5E0D2E2D7DFD5D8DCDFD7D7D5D2DBDA
D8CBD7BFD8BDD6C6D7C6DBBFCBC6C5CBC4D8BDD8BDDCC1D1D3DBCFE5D3E0D8D6E0E0DEE2
DBDED9DEE4DDE9D6E9CEE1D8DEDCDDDFDDDDDEE0DAE3D5EDD5E6D7E4D8E0D4E0D2DEDADC
DCDCDDDFDFDEE1E6E2DEF0D6E5CAE2D6DCD7DED9DADAD8D5C9D5C1DDBCDACAD8CBCEC0CB
C1D1C5C6C6CFD0C6C8CAC5CACAC5D1BBC6B3C4B3C3C5C9C6C6C4BDC0BFBBB4C1B3C7C2CC
CBC9C9D0CACABECBCECFC6C9D5CBBEC7C5BEC5BBCEBEC7BABABAB7B1AAA6A7A8A8ACA6A0
9DA0A5A3ACA296968A929592838684807D79767983747A6C7B6C7161666766605854575C
6158555A5755584D524448444441403F4B3F343B403C3C3C3D403B4537413C3E3C3C4043
3F3C3E41393B39393D3B393E3F3C373C3D423F3D
B79CB7C9E4D3E4DDE2DCDDD8D7DBD8DBDFE5D8E5DAE2DCDDDCD9DDD9E1DDE0DDE1E1DCE1
DDE2DDDDDEE0DBDDDEDDE3E1E3E5E1DDDEDDDDE2DBDFE2E0E5DBE3DFE7E3E6E1E0E3DFE3
DFE3DFE2DBE2DDDDE1DBDCD8E1DDDED8DEDFDDE5DFE1DCE0E4E1E4DEE2DADBD7DFDFDAE1
DADBD6D9D4DCDDDAE3D8DAD7DDDDDDDCDCDBDAD9D3D8D5C5D6CED8D0D3D0D3D0DAD8DDD9
D5DDCAD1BFD6CDD0D1D6CFD7CDCCCED3D8D3DAD9D9DCD9E1DEDEE8DDE8DFE6DFE9E2E4E1
E0E1DEE4E2E5E2E7E1E6E4E7DDE0DDE3DEE5E1E4E2E5E2E6DEE2DFE2E6DFEAD6ECD4E9DE
E5DFE2DEDCDBD9DFDDE6D0E7CDE9D3D8CFD1C7D1C4CCC1C4C3BABFA9BEB3C5C9D1BED9C2
D5C0D4B9CECCCEC9C4C4C7D1CBE4C8E0C9DDCADFD2D6CAD9CEE3D5D8DCD7DAD5D8CDCFCE
E0D5E7CDE1C5E3D6DBD8DBD7D8DCDBDEDAE7CFEED2EBDBE4DDE1D9E5D8E0D6DAE0DFE0D3
D5D0CEC3CBCAD1B7D6C2D1C0C8D1D6D4D3D5D6D4CADAC9E4C9E8D7E1E1E6D8E2D3DCDBE0
DFDDDEDED7DFD4D5D3CDDECCDFC6DACBD1D1D0CFCECFD1D2CACFC1D0C5DDD3D8D6D9D0D3
C8D1AB958681878C8DA6C7D3D0CED3CCDACEDBD3D5D1D8DCDEDCD4D6D9D8D6D6D7D9DBDC
D8DADBD6DAD5DFD9E0D8DDDFDEDBD4DCDCDED8DBDCDCDFDBDBD7D5D8DBDAD8D7DDDBD9DA
DCDCDAD7DADBDED4D8D5DAD7D9D6D7DBD4D8D3DFDDE2DFE0DDD8DCDADBDAD7D5D4D5D6D6
DBDEDADFD7DAD4D5DDD5DECCDBCAD5CFD2CFCECFC9D8D4D2CAD9C9D9CFDFD8DEDAD6D7D1
CFD0CBCDD2CBC79183576B666356668CCFCBE2D5D8D4D6D3D3D4D3DBD0DECDE5CBDBCED4
D7D2D7D5D6D8D1D4D3C8D5CADBC8D1CDD9C7DBC4E2C8D7C1CACEC8CBC0D1C5C8B9CDB1E1
B1E1CDD7DDD4D9D5CFD4D4D3D3D0DFD1DFCDD7D0D7D1E4CFEECEE1D0DCD2DFD3D1DBCEDA
CCD8C1E0C4DAC7CBCAD1C4CDC6C6C8C5C8CCD7BCD9C6CFC8D6CDE1CDE4C8E1D1DBDCDBDE
D7DDD7DDDDE6D2ECD4E2D7E1D8D5D7DAD9DADCDBDCD3E4D0E2C8D6CFDED7E4CEE3CEDFD7
DDD9D6D9DCDDDFE3DDE4DCE4D2DBD5DADCD9D8D2D2D5D7D6CACACFC7CBC3C9C9CEC3D5B8
D8BECEBCBCC7C2BAC0C4C4CFC1C7B5C9ADC2B6BBBABFBFBDC0BBB4B7B4A9BCB1B8AEC1BB
AFACBCB6BEB3B4B8BDAFA3ADBEB9AAA6A1A29AA0999C9492918E8C8B8986807B7A817B78
737179777A6B696A5C665E57545554514F4E4F524D4E4A4E464B4748434544413C3B3E43
433F40413B3B403C4039403C383B3E43503E3239403D3D403E3A3A393D3E403D3C3B3C40
433E39393A3C39383B39373B3C3B383A3C3E3C3B
C5AFA6D4D1E2D8DFE2E1E6E1DDDEDBE1DFDBDDD5E4DAE7E0DCDADFDBE2DDE0DDDDDED8DE
DBE2DFE1DDDFDBDFE0DDE1DDDFE2E0DDDEDDDCE0D9DDE1E0E5DCE4E0E2DFE3E0E0E2DEE1
DDE2DEE2DCE3DEDDE0DDE0DCE2DCDDD9DEDFDCE4DFE0DBDEDCDBE0DCE1DBDEDCDADBD7DF
D8D9D3D7D5DADBDAE0D6DBD9DFDFDDDCDAD9D9D9D7DECBD4CDD3CDD4D4D3D9D5DAD6DDDE
DBD7D3C5CFD2D5CBD4D1DBCBD4BDD4D6D9D6DEDEDEDFDBE1DFE7E1EADFEBE0E1E9E3E4E2
E1E1DDE2E3E6E2E6DFE3E0E4E6DFEADAEAD9E4DDE2E5E2E6DFE3E0E3DEE6D9E6D9E0DBDC
E6E0E2DFDCDCD9E0E4DCE3CEDECED5C9D5CBD8C1D8C2D0C4C3C9B4BFB1C4BDCAC2D7BDD5
C8E2C6D5D5CED1CFCED1D0DAD6CDDFD3D6C0D2BEC7BFCAC4DFD7E2D7D4DACFE3D4E3D8E1
D6E0CDEBC8E2DAE0DCD8DBD8D9DDDBDFDFDCE4D5E7D5E6DDDFD7E8D3E9D1DFD6D9E0D3E0
CDDBD1D9CADAC0D7C9E7D7D8DBDEDDD7D4D6D8D8D8D0DED0E1CEDBD8E7E0E8D1E5CDE3DB
DCDEDDDCD5DCD6DBCDD6C7E1C5D9D1D4D2CFCDCFD5D8D7D5CDC7D5C7DFD6E3D9D7D1E6CD
E4C6B1876A67778993ACCDDBD4DBD1E1D7DFD9D8D6D1D7DBDDDCD6D9D7D7D7D7D7D9DBDC
DADDDCD7DED8E0DAE4D7DAE2E1D8D3DEDCDCD6DADCDADEDCDCD7D5DADDDBD8D8DCDAD9DA
DBD9D5D1D9DBDED4D8D6DAD6D8D5D7DED7D9D3E0DBDEDADCDBD8DDDCE0DDDAD9D8D8D8D9
DBDEDBE1DADCD4D3D8D9D4D9D1D6D1D3D4D1D1D1CAD8D1CDD1D3D8CADECFDED6E1DCDCD5
D2D4D1D4D0DCBAB4828B818B798886BCC6D8D6D4D6D1D6D5D4D6D5DBD6D2E1CDE0C5D9CE
D3D0D2D0D1D4CFD0CDD5C1DEC4D9C5CFCACDC4D8C7DACECFD5CCD3BFC9C3C7C1CBBFD6B7
D5B8DAC7D9D1D6D4D0D5D6D5CBD9CAE6CBE3CED7D7DECDE1D0DFD6D7D4DAD4D8D6D0D6D1
D7D0DFC8E2C0D0BECCBAD4BACECBCACFBAD6BDD6BFE2C4D2CFDAD1E3CBD6D3D7D6D6D9DA
D4DDD5DBDED6E2D2E6CADDD6DCD7DADDDCE0E3DDD4DDD0E8D2E3D3DEDCDED6DED3DDD4D9
DED7D4D9DEDFDDDBD9D3DCD0DFD4DBD9D8DBD7D5D2D2CDC8C5D4C5D1BFC8B4BFB9C3B6C6
B3C6B8BDB9C1B7ADB1B0B0B9B7A1AF9AAB92A49F9AA19FA1A7A5A1A4A6A2A6B0A4A9ABA1
8D9A91A48AA998A5AB907F81878A8272706A786675646F6B5F5E5C5C5D5B56524F524E52
4E454C4D4E42474C414B4039414141403D3D3E3E3B394836453444433B3B3B3B3B3B3A3A
3E3C3E3D393C3E3D3B3B423D363F42455B473A3B3D37343837363B39413C3B37413F3C3D
3F3B393C3B3E3B383A3A383B363739393A383939
DAC5CDCCE2D7E2DCE2DEE0DDDDE1DEE1DEE2D4DFD8E1DFE0DEDCE1DDE3DDE0DDDFDFD9DE
D9E0DDE0DFE2DEE0DFDBDDD8DCE1DFDEDFDDDCE0D8DADDDDE3DAE2DDDBD9DDDCDDE1DDE0
DCE1DDE1DDE4DEDDDDDCE2DEE3DCDEDBDCDBD8E1DDE1DCDFDBDAE1DCE1DADDDBDDDEDCE4
DDDED9DDD5D9D9DCDED6DCDDDDDDDCDBDBDBDCDCDAD6D5D0DCCDD7D7D8D8DED8D9D1D8DC
D7DBCCD8CEE0D0CCCCCFC9D3CECBD0D5DAD9DEE1E0DFDDE1E3E2E9DFEAE2E7DFE8E2E4E2
E2E2DEE3DDE1E0E5DEE3E1E6E1E3E1E6E3E8E6E8E2E5E1E6E0E5E2E4DFDBE7D8ECD6E7DB
E2DDE1DFDEDFDEE5DBE5CEE5C9E6D0D7D4D7CED5CED7CFCED0CBCBBCD0C2D1CEDAC8E1C9
E0CDE6D0DCD1D5D3D5D8D3DCD4EBCFE3CED1ADB39AA39DC5C9E2D8DAE1DFE1DEE2DDDFDE
E2D6E8D1E6CAE4D3DDD8DBDADCDFDCE0D5E4CFE8D0E8DDE4DEE2DAE0D5DED9DDE2DFE1DA
D9D2D8DCDEDCE1CBDCCBDDD2DCDDDDDDDBDADBDCD7DCC9E4CBE0D2E3DFE6D8E0D8DFDEE3
DDDFD9DBD6DAD5DDE1D4DDCAD4C1D9CCD7D3D0D3D8DBD9D5CBD5CEDED3E3D5D5D2D7D7DE
D7D8AF966868778A98B2D0DED9D8DBD8E4D8DFD5DAD4D5D3D5D8D5DAD4D5D6D6D5D4D4D5
DDE1DDD7DFD8DDD6E0D5D6E0E1D8D7E2DCDCD6DBDBD8DCDBDBD6D5DADCD9D7D9D8DADCDB
D7D4D3D4D7D9DED6D9D6DAD5D8D4D7DFD8D9D2DFD5D7D1D5D7D7DBD9D7D5D4D5D4D2D2D3
D8DBD9E0DADCD4D3D8D2DDCEDCCDD8D1CED0D6D8CBD1C9C9C4D4C3D6CCDED7DDDCD5D2CA
C8CDCCD1CFCDD0AFB7A1B6ACB2B0CFC3E6C8E5D2D2CED6D7D4D5D3D6CBDAC9E0C6D8CED7
CED2D5D2CECED0D2CFCAD3C6D7C4D1C6CEC5DCC3D3BBD2C9CECAC3C8C1D1C8CFC4D3BAD2
B7D1C6CFD8D3D7D4D1D4D2D3D0CCDCCFE2D2DDD6D9CFDECCE5CCE1D0D8D0DFD6D4DBCCD5
CCDCC4DFC3D7C4CDC4CAC4CECBCACBC7C0C4D3BAD7C6D1C8D3CDE4CDE1C3E0D3D8D8DDDB
D5E0D6DDD2DDCBE4CCDDD2DADAD5D8DAD9DEE0D7DBD1E1CEE4CBDAD3DFD1E3CDE4CEDAD4
D3CFD0D6DAD7D0CCCACFBDD3BED6BDC9CDD4CAC9C5C3BAB0AAADB8A0B5989B999D99A48E
9E90A29D939A928F918D8D908C8273876F7D708070736F727674767580727F7484748065
6D6478596F687E756F5C5452505C5B45414447463E434149434444423F3F42453F3E3E43
423A3C3F3C363B423C48403F3C3A3D3E3B3C3D3B3C413D3F3B3E3B40403E3C3D3F3F3A36
3C383A3739403D3C38373C3B343C393A423635373A3A3840373E3E423E3E3A3F393B4042
3C36373A373B3835393A393C39393C3B3F3C3F3F
DDE0D6DFD8E0D8DFE0DADBD9DBE0DBDBD9D9DAD9E2DCE6E1E0DFE4DFE4DEE0DDE1E3DEE1
DADEDBDEDFE2DEE0DFDADEDADEE2E0DEE0DEDCE0DBDCDDDCE3DAE0DADDDADDDADBDFDDE0
DCE0DDE1DDE3DDDBDDDBDEDBE2DDDFDBDBDAD6DFDCE1DCE0DEDEE4DFE2DADCD9DCDEDCE3
DCDED9DEDEE1DDE3DCD5D7D8DADBDCDDDEDEDEDDD8DBD4DFD7DADBDAD7D4DAD8DDD7DEE1
DDDCDBDADAD7D1CAD0C9CFCFDFCFDCD8DDDDDDE1E1DEE1E3E2E5E0E4E0E9E3E2E8E2E4E2
E2E3E0E6E2E7E4E7DDDFDADDE7E2EBDFEBE0E8E3E2E4E0E6E1E7E3E5E0E5DFE6E2E2E2E0
E1DCE1E0E0E1E0E7E3E2E1DADBDBDCD9D8D2DCCCDED2DACFD6DCC9D4D1D9D5D8D3DFD3DB
D8E5DAE2E2D6DDD9D8D9D0DBDBDBE0DBD3AD92706A6E84ACD4DAE3DFD9DED5E0D4DFD7DC
DCE1D5E3D7DFDBDADED8DBDCDFE1DEE2DFE1E1D8DDD5E0DADFDDE7D4E1D7E4DCDCE1D7DF
D2E0D9DED1DFC8DBBAD0C9D7D8D6D9DEDDD8D8DBDEDADDD5DBD4DCDDE5E2E3D3E5D2DED8
DDDCD2DBDBDDD6DDDCDCD0DDC7D5D8D8DBD9D7D6D8D9D9D8CDCDD7D0DDD8DED8DBD1DCC8
D3BCA98F8084878A99B7D1DBD8DCD2DCD8DCD8D5DDD9D8D2D2D7D3D5D7D6D5D2D0D1D4D7
D5DAD6D4E2DEE2DCDBD7D6DBDBD9DBE1DDDDD9DDDCD6DBDBE0DADADEDEDAD9DDD8DADBDA
D7D5D7D9D5D6DDD8DCD6D9D5D9D3D5DDD6D6D0DFD3D2CBD0D5D6DAD6D5D5D7DBDBD8D8DA
D6D8D4DBD7DBD5D4D8D7D4D3D1D2D2D2D1D0D5DACDD0C8CBC9D0CECBD6D2D9D7DBD6D7D1
CFD3D1D5D0DACBD5C7D3CECDD2D9D3E6D3DFD7D7D5CDD3D3CED0D0D4D1D4D5CFCFC4CECC
CDD3D4D0CCCDD0D1CBD6C6D2C4CFC7C3C1C5C5CDC1CBCDD2D1C4C7C1C9C4C5C8C8CDCCBD
CDC0CBC9D8D7D9D4D4D4CDD0D1D8D0DED1DED4D8D3D5D0DED5DAD6CED6D8D7D7D5D2D4D3
D3D5D5C8D1BFC8C4CABDCEBAC5C2C2C6B8C5BCCCC0D4C7CBCDD1D0D7D1D0D4CFD1D0D5D3
CEDED5DED8D9D8CFD3C8D3CCD7D0D3D4D1D7D8CBCCCCC6CFC5CAC3C7CDC5C6C1BEB8AEAF
ACACAFB2B0AAA6A6A297A691A89397979FA6959593948C837C8D7A8E74856D7A71796570
576B5E6666696162615A5A56614C55474E4046464E4C464846444A454946434645444839
4742433E3C494B4B444245454C64664C4039463640383E3F3D3E3E3C3A3B3F433E3C3E3F
41423F403B3A3A3E373E383A38363A3C3A3D3F3C3D3B413444373D3B3C3A393B3E403F3D
3A393C3739413F413F3A424A3F3F3A423C39414240403C4440444A444C4345463F43545C
5146413B444845414548484A433D3D3942414440
DADBDAD9E1D7D6DDE0DDE0DEDEE0D8D8D9DDDAE0DFDFE2DFE1E0E6E1E5DEE1DEDCE0DEE3
DDE1DEE1DCE0DDDFDFDCE2E1E1E4E2DFE0DEDDE1E0E0E0DFE5DCE1D9E6E1E1DCDBDFDCE0
DDE1DDE1DCE3DCD9DED9DAD7E1DEE0DBDEDCD7DFDCE0DBDFDCDDE4E0E4DDE0DDDDDFDDE4
DDDEDADFDADFDBE6DDDBDCDFDADBDDDFDFDEDDDCDEE0E1E0DBD8DED2E0DADDDAE1D9DDDD
D7DBD7E0D7DBD6DAD7D4D3DAE1D9E2E4DFE1DCE1E1DCE4E5E2E2E2DEE2E4E6E2E8E1E3E1
E1E3E2E9DCE2E2E7DFE2DFE3E2E1E4E1E5E3E6E5E2E3DFE5E2E9E4E5E2E1E3DCE4D7E0D9
E2DEE2E1E0E1DFE6DAE2D5E0D0E3DAE0D8D7D7D3D7D7D5CED7D8CECFDBD6DAD5DCD9E3D7
E0D8E2D9E3D9E3DEDBDBD2DFD7E3D4DBC9AD7A615E6978B4D0DFDBDADDDFDCDFDCE0DEDF
E3DFE0D7E4D5DFD5DED8DCDEE2E3DFE4D7E1D7DFD5E0E0E2DAE1E5DEDEE0E1DCDDE0DAD6
D4DDD9D3D9CBD6BEDBC4E2D9E6DDD9DAD7D1D3DBD3DCD8DFD6E4DFE1DBDFD8D7E0DBDFDF
DCD8CCDAE0E1D8DDDBD6DBDBD7D3E0D6D6D8D8D7D6D8DDE1DCDED8D7D3DADBDDDAD4D7D0
CCBDA29087908A8193B9D4DCDEDCD7D8DCD9DDD8DFDDDFD7D5D9D2CFCAD0D6DBDBDAD9D9
D7DAD6D3E2DDDFD8D8DCD9D7D6D9DDDCDEDFDBDFDDD6DADBDCD6D5D9D8D2D2D8DCD9D6D6
D9DBDCDBD4D4DCD9DED6D8D5D9D3D3DAD3D3CFDED4D2CACFD5D7DBD6CFD0D5DBDCD9D8DB
D4D5D0D7D3DAD5D6DAD5D7CCD3CCD2D0DCD2D1D7CFD5CCCFC7D4C9D3D1DBD9DCD5D3D9D7
D6D6D0D1CCCECECED8D5DAD1E2D4E0D6DFD1D7CDDACED0CCC6CACFD4C7D3C6D5C2CECBD3
CBCDCAC8C9CBCCC8CCD2CFC7CAC5CABBD0C5CAC1CAC2C9BFCCC0BEC3C3C3BDC5BAD3B6CF
BDD5C3D3D2D5D6D3D7D7CED4D8D6D9D5DAD5D8D5D9D1D4CFD8D0DDD0D7D3D8D2D0D4CFD5
CCD9CBD3C5C6BDC3B2B5C1C2C6C2BFBDC4C2C8C2C5C0C3BCCCC5CFC7D7C7D5C5CDC9CCC4
BCCBC1C9BFC8BBC2B6C1C2C3B5ADAFB0ABB1B0A2A9A0A3979D8C908C9B8C9986917E7C78
7D7F817F7872757C6369637163715D6F616B5A5D5E61584E494650454C404A4741453F43
3E48444541413B3F3F3C403A433A3C3F3A443E4248443D403C3C463E393C40383A33453E
423A3C423E48424240423D35415D5C3E3D373D363B3E3C3F3B39383A3D3F3E3C3A383B36
3B443E3C363C3B403A3E3A3E3C383B3D3A3C3E3A363B3D39403C3D41403D3A3838383939
3F424A403D4547514A4754635149465A444754524B4841474B465E486F4E5747584F5558
4D4A4C454045413C3F4241435448423D4A494A42
E1E2DDD9DDDAE1DBE3DEE1DAD6DDDBD7D1DED9E5E5E8DEEBE0E2E4DFE1E2E1DBDDDFDEE1
DEE1DFE1DADDE2DAE3D9E4DCE7E0E1DFDDDDDAE0D8DED6E7E0E6E1E2D7D5DBDADDE2E0E3
DADEDAE0DEDDDFDDDFDBE1DDE4D8DBD8D7DBD3DAD4E2DDDEDEDEDEDEDFE0E1E2E0DDD8DB
DFDAD8E2DADCDAD7DCD7DDD5DCDADDDADADEDDE2D9DDD3E2D7DBD9DFD9D9DAD9DDDBE1E0
E0E0DCDDDBDFDFE1DFD6DBCFE7D4DDD8E3DEE3DDDADFDFE8DAE2DFE6DFDFE2E3DFDEE3E1
E2E6E2E5E2E1E2E8E4E1DFE3E5E0E6DEE8E1E8E4DDE0E2E3DBE2DDE6DEE5DEE0DCE0E3E1
DEDCE0DEDEE2DFE2E6E1DDD4D8D9DCD7DAD6D9CED4CED7D8D6D7D1DAD9DCDCEADBE0DFDE
D8DEE0E4DFDEE3DFDCDDD9DCDCD7DDDBCC976B5B636381B9D6DDE3DADCDEDADED9E0DEE2
D3DBD9D9D8D9E1DFDBD8DCD9DBE2E1E5D8DBD9DEDFDDE2DFD9D7DCD9E1DBDDD9DCDFD7DA
D8DFDBE2CBD0CBD6D7DCDDDCD9DADBDAD7D6D9DBDADCDBDEDFE3DDD8DFD9DFDEE1D6DADD
E2DBDEDDDEDDD7DAD9DFD8D5DDD8D9D6DCD8DEDBCACDDDE2D8DED3DBCED1CFD2CFC9D5CE
D0B0938A95937F7997BFDAE6DADEDED2E1D5DEDAD6D9D9D4D2D5D7D5D1DBD6DBD1DFD7D6
D0D8D2DBDAE0E1DDE1D7D8DBDDDBD6DCDCCEE2D4E1C6DBD9D9D7D6D2D5D5DADAD4DAD5DD
D1DCD8E1D5DAD1DBD5D3D6D8DAD7D1D8D4D8D5DAD9C8D8C8E7CDE5CADAD0D4CDCED4D7DA
C5D8CBE3C7E3D2DBCEDACBDAD1D9D0D6D2D1CACED5CFC9C7CFC9D9C0DDC9D5C7DAD2D5CD
CCD2D4D2C5C8C6CCCBDBCCDBC8D8D8D7D4DAD4D3CBCECECFD1CBCAD3D4CDD3C9D6C9CAC0
D5C7CDC8D0C7D0CBC7CEC7CCC4C5BDC9BAC0BDC7BEC7C1C6BFC1C7BBC0BEBFB7C7C1C8C0
CDC3CDCBDCD9D8CFD2D4CDD6CFD4C6DBCBDCCFD8D0D2CCD5CBD2CED6D0D4D4CCCEC8D0C9
D2C6D2B8C5B5AAA9A5ACAFABACB2B1ABA5AC9CB2A3AC9AAA9DA6A2AAA4A89FA595999697
94969C8D9F8394779481928489807F7F78747675716D666A60605D64565A525B4F564948
4A454853564D434042483C4644403E433B3E41403C3A3B3C383F383E42383A3C393B393F
3C4240423D383F423E3C3D3E3C38443A493B41393E4439423B3B3C3A3A3A3C353C3B353B
3E3E3E403C3A3B403C3C3A3C403D3C4338413A393B3B353E39403D42363C3B423F3D3C42
3B4345443D39393E363D3E393A3A3B3C3B393A3C3B393F3A3F45423E3B3C403D41414A4E
4251565A56525855595471536A52584B4F514F514847495253485463575552434453485C
40474B3F41493E3B3F3F45453F3C4A42464D5252
DDE4D6DFD6E0DDDCDDD6DBD8D7DEDEDCD6DADBDAE8E4E9F3E7DFE6D6E7DAE1D6E0E7E0EA
DBE3DBE1D3DCD7DEDBE1E5E4DED8DDDDDEE1DFE5DBDDE1DDE6DCE4DCDBD8DBD9DAE0DFE4
DCE5D6E7D8E3DADCD8D7D7DBDCDBDBDEDBD8D5CBD0D2DAD9DDD6E4D4E9DAE9E3E1DFDBDD
E0DCDBE2D3E2D9E5D4DDDADDDEDCE1DDDDDFDDE1D6D6DAD8E0D4DDD9DFDBE3D9E5D9E2DC
D8DED4E4D8E9DFE5D5DFD9DDDADED4D2DADAE1DEDBDEDCE3E0E0E8DEE9D8E5DFDFDEE3E1
E3E6E3E6DFE6DAE7D7E8E1E9E0E0DCE1E0E6E4E6E0E1E2E3DBE2DCE4E1E2E5DAE2D8E4DD
E1E0E6E2DFE2E1E8E2E4D8DDD5E2DBDCD5D6D6D6D5D6D8DBD5D8D5E0DEDDD7E1DADAE3DA
E6DFE5DEE1E0E5E2E0E2DEE2DCDFD8E0C39E64514A547CB6D2DAE4E1DEE0DBE0DBE1DDDF
E0E3DCDBDBDCE0DCDDD9DDDADCE2E1E5D8DCD9DEDFDDE1DFDCD9DEDAE1DBDDD9D9DDD6DA
D9DED8DDD8D6DAD4E2D6E1D9DAD8D7D7D9DADBDADBDEE6DDE1DDE3E1DDD7DDDDE2D6D9DB
DDD8DBDCDBDBD5D9D4DDD3D9D5D9D5D3D8D8DDD9CDCDD6D6D6D9DAD7D9D0D6D1D1CED5D4
CEB799949C989193A9C8D7D3CEDAD0D9D4D9D5D4D8D8D6D3D3D4D5D4D8D6D9CEDAD7D8CC
D7D7DFD5E4D8E6DBD7D1D6D7D8D7D3D9D3D1CADBCAD5CED4D6D8D3D9D3D9D5D8D4D1D7D1
DBD6DEDBD1CFD7D0DECCDBD5D7D4CCD4D1D6D3D8C3D7C2E1C7DFD2DFD0CCD2D9CFDAD4D5
D4CFE1CDE3CFDED3D9D2E1C4E4C1D6C9D2CCD0D1D9DCD1D8C5DAC6DAD0E7D0DED6D4D5D6
CCD8D1D1CFD2D3CDD7CEDAD8D1D5DECAD6C8CFCACFD0CDCDCFCCCDD5C7CDC7D4CAD4CACD
C9C7C8D1C9CDCBCACAC3D0BBCCB2BEBAB8B3C8B2C7AFC3BDC2BACBB6BAC4B8BCB7BCA6C7
ADC9BBD1D1D1CDC8CACBC8CEC8BFCBBFD0BFC8C2C7BBC9B5CBB3C3BCB9BBB9B2B4AAB1AA
A7ADA5A58B977F917F848684858887838174866D8B6A7B74707076697566696761635E5C
5B606A5F5D5C565B4B5E54564E494B4D48484A48464843443E423F413C403C453E463F41
433E3D4345413C3C3F44394243413C3C3C3E40403F3F4042383F3B3E3F3B3D39383A3C3B
38383B3E3A35383D3C3B3B3A3C3D3A424147403F3E4239403B3D3E3D38373A383A3F3A40
3B3B3F40403E434941413E3E413C393D3C3F3F3948424042393B404349494A49483F483D
4239453F403F473F3E3741403E3B3E45454041474242444745493E423F433B4840514E56
47504F514E4A4C4542454B524E564F564B4E444C3D45424E4E404B4C4B454D424546474F
4744524C444D46474C4C504F4D51556359726B71
DCDADFD1E1D5E3D8E2D8DCDAD6D8D6D6D7E1CEE0D3E4D7EAECE7DAE2DBE3DADADDDEE3DD
DCD5D9D9DFDCE4D2E2D2E5DBDEDADEDDDDDFDCE1D9EBDAEED5E8DCDFDFDBDCD8D8DEDEE3
E1DFE0DBE5DAE2DAE7DDE5D6E3D2DDDADAE1CEDBC7E0D9E4E0E4D9E5D7E3D9DFE1E2E0DF
E1DFDEE2DDDFECD7E4CEE2D9E1DFE4E1DFE0DCDFD5E3D2EBD6E8DADCDCDDDCE0DCE2DFE2
E1DDE3DBE5DBDED8DDD4E2B6CFB1C7C1D3DAE5E4E4E4E0E5DBE7D7EDDBEAE0E5E0DDE2E1
E3E6E3E7E3E3E8D9E1DDE6E1EAE0ECD8EDDBEAE2E3E2E1E2DCE4DCE2DAE5D8E6D7E4DFE2
E2E3EAE5E0E1E2EAE8E0E6D4E2D6DED4DDD7E1D0DECFDCD7DFDFD8E0DEDED7DFD9E0D6E6
DCECDFDEE1DFE4E2E2E4E0E4DEDCE1D2C88F64434F5F87BCD4D9E3E0E0E0DBE1DDE2DCDC
DFE1DBDDE0E0E1DADEDADDDBDCE1DFE4D8DCD9DEDFDDE1DEE0DDDFDAE0DBDDDAD7DCD5DA
D9DDD4D7DAE0D4E1D6DDD7D7DAD5D1D3D8DCDBD8D6DFDADED1DCDAE1DDD8DDDEE4D9DBDA
DDD9DDDEDBDCD6DCD4D5DBD3DACFDACFD7DBDDD8D3D4D7D6D1E0D0E2CDDFD4D6D6D2D9D1
D4BEB0AEB4ADB2BAC6DADED0D0CDDECEE4CEE0CFD9D5D2D4D6D6D5D5D2DFCFDEC5DBCACF
D3E0D1E2D0E0D7D9D9D6D8D4D1D2CFD5DCCFD8C9D9CCD6CBD2CED6CED8CED4D0DCE2CFE5
D0E5D1D6CED6C9DDCBD6CDD5D1CEC6CDCBD2CFD2DBC4D6CBDECDE4C8D0C4D4CDD1CFDAD2
D0D4CBDCD1DDD2D6D0E0C3E1C2DAC5D0CDD5CAD4DBD3DAD7D3C4E2C3DFC1DEC9D9D0DACA
CFCCD4D0D0D6CED8BDDCC9D5CCD9CADAC7D5C5D0D9D6D0CBCAC7C7CCD1C8DBBED4B4C5B9
C4BFD1C1CFBFCCC2B9C0B0C9ACC1AEB7B0BAA2BC9CBAA7B6ADB3AAA5A7A2ACA2B29BB295
B68EACABB3B4ACA8A7A3A4A5A0A698AE99A7949A979C869F869B87918D8B8885887C817C
8A788D5F74525E5A595A59575553504E4D4A474D494D4A484542493B4C3E45424647413F
3E444C46424451403F3F433F3F3E40403D3E3E3A3D423F3E3B423F3B40413E423D3F3E40
423F3D3E3F3E3D3D3C41393F4245403C3B3B3B3B3A3A3B3C3E3D3B3D3A383D38403B3C36
3D393D3B403A3A3F3F3F413D3C413D453C433E4241423A3E3C3E3F3D3B3A394036443D43
4041494949404447494946474A4641424A4C484854514A4A44473F5350615555504D424A
3C463F404346424243424046433E4049493F3F47494545424643404C4744413F42434646
4A4A424346484C474B404F44544853575952534A4F4A54575C5A57675F6E6F736F716885
6D827D88828885868A8B8E8D9D96B0A3BBB4C3BA
D6E1D0E1D2E2DADBDDD2D7DAD9DBDADDD8D6DED5E7DAE1E4EEDEE8D5EDD7E9E3E1E7DAE8
D5E4D9E0DAE5D4E2D1E2DFE3E3DEE1DDDCDEDADDDBDFEED6E8D4E8D9E2DDDED9D9DEDCE1
DCE6D2EBD6EADDE1E3E2DCE2DCE0DCE2E4E1E7D7E0D8E3DEE1D6EACFECD3E8DDE1E3E2DF
DFDFE0E0DCE9D3E7D0E7DDE4E4E2E6E1DFE0DCDFDDDBE8D6EEDAEAD9E5DAE5D1E1D4DFDC
DBE3D3EAD5EAD7DDD7DFC4C899A28CA5C5D3DFE1E2E1DEE2E5DEEAD7EFD5E7D9DFDBE0E0
E1E4E2E7D7E5D9EED8F0E1E8E2E5DBE7DEECE5EAE4E2E0E2DDE6DDE1E4E1E9DAE8D4E4DA
E1E1E8E4E1E2DFE5DDE4D6E3D2E4D6D9DBDBD4D8D2DBDBE1E4E4DCE1E0E1D9E0E0D9E2D1
E6DBE7DDDFDBE0DFDFE0DCE1DCE1D8D7BA8D5E484B608BC1DADCDDD4DDDED9E0DDE3DBDA
D8DCDADFE1DDDCD5DED9DCDADBDEDCE2D9DCDADDDEDCE0DDE3DFE0DAE0DADDDAD8DCD5D9
D8DCD3D5D3D5D6D6DBD3D8D2D9D4D1D2D6D9D8D6D7D4DBCCD8D1DBD6DFD9DDDDE4DBDDDB
DDDADBDDD6DAD4DCD4DBD2DECCD7D7D3D4D9D7D2D4D9DBDBD9DADDCFD9CEDACFD8D3DACC
D9C7CCCED6CDD2D4D7E0DDD4D2DDCFE7CDE0D5D3D5CFCDD2D5D3D1D1D1D0E1C8D8C3D5CD
D2CEDEC5DFC5DCCDDDD6D4CCCCD1CFD2CDD9BFDEC0E6CED6D5D7CFDACED7CFD5D8CEDDCB
E4D0DCD1D8CDE0C8E1C3D7CECFCDC6CDCBD3CFD0BFD6C1DFC8E0C6D6CCCBCEDDCAD8D5D2
DACFDCCEE0CAD4CEDCD3DCC4DBC1D6CBD5D0DAD2D6DDCFDBC7DDC7D8C8D9C1D5D8D7D1D3
C2D2CBCED0D1D0C1D3BCE0C4D0CADAC6DDC0CBC7CDCAC6C4C4C3C3C5BAC4B0C7A7BDA7B0
B1B9ADB7A5B5A9AAA596A794A38D9C8D968592799A8392828E8A8C807E827E7F79826F8F
6E826E817E807675726C706D6D5E75597955685A6F60665566525C5357535252584C524E
48473F4438483C463F3F404141403F3F43403E463F48464142433E3D3F3F3A3C4344413E
3C3F413D4241543E4538403D3E41413D3C3E3E3A3E403E3D3D403F3C3C3B3C3D3C3C3E43
403F3E3C3C3C3B39373B39393C4243403D3C3B3C3D3E3F40423B3B3F3A3C4342423D3F37
3F3A403E45413E413F40464246454B42463D424041403B3D3D3E3D3C433747384139443F
444F4F5E4B4C3D424948434247443F3F494A4A46524A46434F464A44575358504B423F3A
4240413B454D3F47434638424A47494E4E48484E4C494E434E494C5951525256575B5D5F
585C616B757B7C79747C6D8C7796899B9A9B8F9C93A5A2ABADAAB4ACBBB4BFBEC8BBCDC1
CBBEC8C4C8C9C4C3C4C5C9CACAD1C9E4CEE8D8DC
D9D6DFD1E4D5E4D8DDD3D9DCDBDDDCDED7E1D1E9D6E7D4DFE1E3DAE7DAE6E4F1E7DFDDD6
DEDADDD9E1DFE4D3E2D4E6DEE1DEE0DCDCE1DFE3D8EBDAEAD1E5DADBE2DEE1DCDCDFDCDF
E0DEE1DAE8DBE7DFE3DAE5D6E6D4DFDBD7E4D6EAD3EBDDE6DDE4D7E7D5E6DAE2E1E1E2DF
DCDDDFDFE7E1EBD3E8D1E6D8E6E3E5E0DDDFDCE0D9E7D3E8D4E9DCDDDBD9DADCD8E4DDE4
E2DCE3D8E4D9DFD9E2D3DA9F996E7F8BBED1DBDEE0DEDFE3D9E4D0EBD7EBDDE1DFD9DDDE
E0E1DFE6E2DEEAE3EDDEE4E1E6DBE8D2E9D4E4DBE3E1DFE2DFE8E0E3DCE7D8ECDAE6DEE3
E1DFE5E4E4E6DFDFE7E1EBD5E4D2DACFE4DAE2CEDDCDDBD5DCE1DCE5E3E3D8DADCE4D5E1
CFE3D9DFDFD9DDDDDDDCD7DCDADDD2D1AE7C58504B658FC0D7D9DBD5D9DAD6DEDCE2DBD9
D9DEDCDFDBD4D6D3DDD7D9D9D9DBD9E0DADDDADDDEDBDFDCE3DEE0D9DFDADDDADADDD5D9
D7DBD3D7CFD3D5D7DCD3D8D2D9D8D8D6D6D7D8D9D8DED5DCCFDCD5D8DED8DBD7DED8DBD9
D9D6D3D5CCD2CCD6D7D3D9CED3CADCD1CDD1D0CED1D5D7D7D2DFCBDFC7DBCCCECFD6CCD6
CED7D2DEDBD3D8D6D7DBD9DDE0D7E4CEDCC7DBC8D4CECDD1D2CECACACDD6C5D9C4DBCBD1
CDD8C8D8C7D6CED0D5CDCCC8CDD4D0D0CFC6DEBADDC1DACBDBD2D7CDD8CBD5D5D1DBCEE3
CDE0D0D7C8CFCADDCCD6C6CECBCCC7CCC9D0CBCBD0B4D4C5E1CBDCB9D3C9D4CBCFC8DAD1
CDD3C8DECAD8CBD7C9D2BAD2B8D0C7D0C9D5CAD1D4CBD3CED0BDD7C2CEB8D1BFCCC5D4C4
C9C0C2B9BFBDB0BBA4C6B2B2A8B1A0B7A2B19EAEA3A2A2A09E9C9A97A0919F839D808E7F
8F8A917D8E80877B76756D79667268655A5D4E635767504E565555504D504C4C41405143
51404C4648494345444148444A474548464440414A463E4441454144413D3D3F463B413E
453F4A3C443D45453E3D3E40403F3F40403C3940373F3B353F423D4041443D404243423E
3D3E3C3C3E38473A4335393C3B3E3C38393E3F3E3E3B3B3C3E3B3D403836373939383B40
4644413E3E3F3F3E4041433C3B42484A3A3A3A3C3E4143443E3D43423E44494541474C44
3E38424A464742433E3D484448444A41483C403A3B3A3D3E43464647474347493D464346
47455E5061424C434D4D4643484844444149454E494F474B4E5047524C5951545351534F
57565B5C5C5F715B7757656A787A7C7C7E81848685948F998C9E8E9B94A299B39EB6AAB6
AEB1B8BDC1C2BFBFC3BBCFB6D3BED4C7D6CDD2C4D2CAD4CED2D9D1DCD4E1D9E1D8DBDAE3
D1E7D9DFE2DEDDDBD9DADCDDDDD2E7D8EFDAEBDC
D6E1D3E3D6E4DCDBDAD3DADCDDE2E1E2E1DBDFD7E0D4D7D5DAD5E6D4E7D6EDEEF2F1DEEA
DCECDEE1D9E5D4E5D2E4DFE3E0DEE1DCDCE2E0E2E4E1EED7ECD7EADAE1DFE2DFDFE1DDDF
DFE9D7EBD6E6DCE1DDDDDCE3E0E2DFE3E1E0E6DAE2DCE3DEE6DBECD3EBD3E4DAE2DFE0DF
DAD9DEDFD9EADCEED7E6DDE1E5E2E4DFDCDFDDE1E3DDE7D3EAD4E8DBE1D7EBD9E8DDDEDC
DAE2D4E6D3E6D9E2D5E1BFAD68786385C0D7DEDFE1DEE1E5E0DBE4D6EBD5E5D8E0D9DDDE
DFE0DDE5DEE4D8F0DCEBDFEDDDDFD8E2DBE5DFE2E3E1DFE3DFE9E1E5E4E2E9DFEBD6E2DA
E3DFE4E4E7E9E0DFDFE6DCE6D7E5D8DAD8DAD7DCD8DCD7D7D7DCD8DEDDDFD7DBDBD9E5D4
E1D4DED6E1DADDDDDDDBD5DADBD7D0BDA462534C50739EC8D8D7DAD8D7D9D6DDDAE0DADA
DADDDADCD8D3DADCDCD4D7D8D8D9D7DFDADDDADDDDDADEDAE0DCDDD7DDD9DCDADADED6D8
D5D9D4DAD3DCD3E1D5DAD5D6D9DCDEDCD8D7DADDD6D8E2D4D9D0DAD8DAD5D7D2D7D2D6D4
D8D4CFD4C9D3CBD5D1D6C9D0C3CED0D0CCCDD1D3D1D1D1D1D5D5D7D1D8C7CBC0CBC8D7C2
E0C4DAD4D4CAD3D4D4D7D3DFD1DCC9E0C8E0D7DAD9D7D5D4D2CFCCCCCDC5D5C1D9C6D8D0
D5CEDCC2E0C6DECDD4CDCECED3D5CDCBC6D4CBD8CADDD4DCD9D7CDD7CCD2CDD6D3CCDDC7
DCC4D2C8BDB6D9C7E5C7D3C9CCCEC9CCC7CDC8C8B4CDCADEC3D3BFD5C3CBC7D5C6CAC6C5
CEC8D1C4D0BFC8C3C4B5C4A6C1A2C0B1BBBAC1B8B9BDAEB5A5B49BB6A1B8A0B1A5A4A1A6
97A396949C9694839B839C818B80867082697372777779766F6C69625F654E68506B545B
4D564756485744474541433F4240433D423E433C453D423D3E493A46433D483F41484645
3E42403E4342404240404542463E423C453C41403D3D38413D43404542414242483D443F
433B463B443A433D424342403F3F3E3D413F3D433F423D3B3739403D4A4142404646463F
40413E43403B404347423C47494A443F40434447454043434640454A413F3E4643444349
504A43414244474A4D484C424043494C4545464646464748434C554B444A474047504D4F
3F42434D45494447423F4B4340474B4B434142464542484246454546454847514050464E
515C4F6B4F624E5A60625D5B626666686D6284608E6A8B7E85839088978C969193A2A0A9
9DA7A7B7A8BDA8C7ADC1A7C0BDC1C1BDBDC3C6C6C6C3D9C0D3C6D2CBD1CBE3CBE5CADED5
D8D4D7D6D6DADBE3D6E2D5E2D5E5DCDADADCD6DCDBE6E3E3E7E3E6D9E3DBE2DEE5DDF0D2
E5DAE8E1E3DDE3E3E1E1DFE0D1D9CFEBD8E9DFE1
DADCE0DAE5DBE4D9E3DDE2DEDBDFDBD8DEE1D6E8DAE7DBE1D8DEDDDFDAE1E3E9EAE7E4E0
E0DEDDDBE0E3E2DBDCD5DCD6E1E0E4DEDDE0DBDBDBE0D6E1DDE4E1DEE1DFE3E1E1E3DFE2
E1E3E2DFE1D9E2E0E8E1E9DFEADBE2DFDEE6DBE7D9EBE0E3DDE0DBE3DCE5E1E4E5DEDFE0
D9D7DDE1E6E7ECDEE8D9E6DCE4E1E5E0DFE1DEE2E4E8DDE7DDE0DFE1DEDAE3DFDFE6DCE2
E1E0E3DCDDD7DADADCD3C384635B6E8EC0DBDEDCDCD7DBDFD7E0D4E6DBE6E0E2E3DBDEDF
E0DFDDE6E5E2E4DFE2DEE3E4E5DEE8DAEADBE4DCE4E2E1E4DFE8E0E4DDE3DBEADFE1DCDF
E0DEE2E1E2E5E0E1DFDEE5D8E0D7DCD6DBD7E0D6E3D6DAD3D7DDD6DAD7DDD9E0D9DFD9E2
D9E3D7D4E1D8DADCDCD9D3D8D5DDC4C49C7863646286B0D4E0DBD9D4D8DAD7DED9DED9DA
D7D8D5DBDBD8DDDFDCD4D7D8D9D9D7E0DBDEDADDDDDADDDADBD8DAD6DCD8DCD9D7DDD6D8
D3D7D3DAD9D8DBD2DACDD9D4D6D9DBDBD8D7D8DAD0D7D4D7CED6D4D8D7D5D8D1D5CFD3D1
D6D3CED6CDD8CDD6CFD1CCC4CCC7D0CCD0CCD3D8CFCBCFD0C7CDC0D8CCD5CCD1C6D2C4D1
C9D1CDD3D6C3CED3D0D2CCD2D5D8D8CFD8CDD3CCD3D5D4CFCBCCCFD2C6CCC8CFC5CECBD2
D2D4CBCECED1D1CBD3CCCECECDCAC3C7CACBD5C7D7C9D1CED2CBCFCCD1C5C9CACCCDC7D0
C9D1C8C9B3B5C0C8C7C7BDC0BFC2BBBBB3B9B7B8B5A2C4A8B7A0B5A7AAAEACA6ACA1ACAB
A7AC9AAD9AB09D9F919B82A17E998A918E989090918987808D6F8C6D8C68866D73686C60
656669625C5855544E5B4A524C51434D414A3E464243474641444742423C4238463D4641
3E414440463D3D404546423C3D3C3B3940403C3C3A3E42463E3C3F403C453D433E403E40
3C413F41403A3E3D393C3D3C3F3D393E3C3E3C3F43414A4247383D3C40434541463E443E
444342483F42424043474847494F514F473C513B5A3A4B43444A4F4F5149403E4B4B4D47
47463E45464E4359465840514E4D45404240404646464B45453E43443E3F3D4F4C524E56
4E453F414547494E50454D47484849474547494846454648464C534943433F45444B3D4F
3B4E4149474B464E4D4B524251555C5858535A5D5F5C67626A6E737A807A917A927F8C8A
9D93A494A993A29DA2A7A5A3AAAFB0B2A9B4A2BEA8C5B6C1B8BBBEC3C3C5C4C5BFC6D3C7
D1C6D3DADED3E1C9E4C0CCC9DDDEDDDAD8D8D9DADDDDD8E5CDE3DAE0DDE2D7E7D9E7DBDF
E3DDE2E1E1E2DCE1DBDCDBDAE1DAE2DADFDAE0D5E3DEE7E0DEDFDAE0DBE6E3E2DBDCE0DC
DBDEE1E6E0D8E0E1DDDEDBDDCECCDBDDEADAE8DE
DAE1DCE2E0E2E1DBDEDBE1DCDAE2DFDADEDCDCE3E1DFDAD9E0E0E6DAE2DEE6E0E0E5E1E6
DADFDADFD6E0D7E0D6DDDBDADDDEE4DFDEE0D9D7CBC6C9C9DCD4DED6E2DFE3E1E1E5E1E4
DCE4DCE5DADFE0E5DEDBDEDFE4E0E3E5DFE2E1E2E1E3DDD8E3DEE5DBE5DCE3E0E7DDDEE1
D9D5DDE3EDEDDEE1DFE7E7E2E2E1E6E3E1E3E0E3E3DFE2DCE4D3DEDCE6DAE5D4DBDCDAE0
D8DFDBE3D7DFDBE2D9D4B6945A636597C7E3E4E1E0D9DCE0DBDDDEDFE5DEE5E0E6DDDFE1
E1E0DEE6DDE5DFE3D9E5E1E2DFDEE0DFE2E0DFDDE5E4E3E4DEE6DFE4DFE0E1E3E4D8DCDA
DCDBE0DDDCDFDDE2D5D9D8D9D6DBD9D8DAD8DAD8DEDCDEDBD5DDDBE0DDE0DADFDDDADBD9
E1E1DDD3DED4D7D9DAD7D1D6D2D9CEC5B896948DA1B5C6D7DEDCDDD9DADDDADFD9DDD9DB
D6D6D3DCDFD9D8D4DCD4D7D9DADAD8E2DBDEDADDDDD9DCD9D8D5D9D4DCD8DBD8D4DBD6D9
D3D5D2DAD5D8CED1CACCD0D2D0D2D4D6D6D5D5D5D3D2D1CDD3D7D9D5D8D8DCD5D7D0D4D2
CFCEC9D5CCD8CBD3CED5C9C8CCCDCDCCD0C6CDD3C6C2CCD0DAD3C8CFCCC5C7CACDCDCCC2
D3C6D7D4CAADBFCCCBD5D3D4C2D2C6D1CBD1C7C9C2C7C6BFBCC2CBD0CDC5C9C1CFC8CEC8
D0C9CCBDD1C3CFC0C9C1C3C2BEBBBAC7B4C0B0C5B6C7B3BEB9B6B7BFBBB4AFB2B7ADAFA6
B3A8AA9FA298AA99A7979C9B9A9D9592888F8E917F887C906D8C798E737D7171716E737A
7666715676616C555B555E565E4F5E5254595B575A5A514F554B454B4B4D48434A424341
3F49433E42404739473C3F443D4145424B444240404145433D434A48464A404839423B41
3E463E45393C38483D433C373A3D3A3D3838393C40413F3D424A3B47413F45413F3C3E40
433F3F41413A42413E45444542433A473D473E443A42474F47444045434A4D484C464E46
4B4E5D524E41535353595B585B6366625A625369595F4B5A4B5C5469555E464B52555A55
544E40455251634F604F51504E4C46454845454F51565C4E4C444743444540544E554C53
4F46444C525150545C4C57565E5B5752555A5F626264676A6E696E6E6E686A87717F6E89
6E8A7A87878B859196949680A795A08DB19FAC9AA9A4AEA4AAADB4BDB4BFBCC4BCC7B9C6
C0C2BFCDC8CFC9CDCED4D1CDCFD1CFD0D6C6D6BDDCC6DBCEDAD6DAD3DBD5DBD8D3DAD6DA
DADDD8DEDAE0D8E1D1D0C9D9E0DEDEE0DEDADADEE0D1E2E1DEDAE1DDE4D6E0CEE7D7E1D4
DED4D8D8DCE1DCE1DDE5CAE9D1E4D7E0DEDCDCD6DBDDE0DCE0DDE1DFE0E1E2D7E1DCE9DD
E8D3DDDEE2D6DCDBD6D9D8DBCBD2D5E8E1DEDFDB
DBDFE0DFE5DEE1D6E4DBE3DDE4DEDDDED7E5DDE3DFE4DAE6DBDEE3E2E2DFE1E2DFDFE0E3
DCE4E5E0DCDFE2DBE4D9DFD5E2DFDCDADCDFD3BDA3A19EBFD8E2DEDCDFE3DEE2E3DFE5E2
E1E3E1E1E2DCE0DCE0DDDFD9DFDCE2E1E1E3DFE2DCE1E0E5E0DFE4E3DCDCE2E3DCDCDEDF
DCDADCE2DBE1E0E4E3E0E5E4E3E4E5E0E2E4DFE7D9E1D9DED8DDDFDEDFDCDFDBE2DDDEDA
DDDDD9DEDADFDADAE0CAAD7D5D6770A9D6DEE1E8DFE2DFE5DBE1DBE4E0E2E1E0E0DBE1E2
E2E0DDE4E1E4DEDFD9E3E1E2E6D7DEE4E7DADEDFDFE4E5E4DCE6DFE2DCE0DEE1E0DDE1DF
DBDCDDDCDDDEE0E0D4D4D9D9DFDCDCD8DAD5D7D9DFD9D9D8D7D7DAD9DBD9DAD9DAD8DBE0
DDD9D8DCDED8DBD4D3D7D3D7D3D9C9D5C3CABDCDCCD5D8DAD7DCD9D6DBD8DAD7D6D1D4D8
D8D2D8DBD6CDDED5D5D5E1D8D0D2CEDAD7DCD5DFD3DED6DCD5D2D3DAD5DAD9D4D1D7D7D5
D2CCD5D4D7D9D5CDD0C8D2CACECADBDEE5DAD4D6CAD1C0D3C7D8CEE1CDDDD6D4D1D4D2CF
CECECCCAD1D0CFD0D0C5D4C0D4BCCECAD2CBD0CBCECABED7C9C6C0C7BECAC3CFBDCABBD4
C3D4C2D3C0B3BECBC3C4C8BCC7B3CEB6C5B2C5B6BEB8B3B3B7BAB8B5A7B99DC5A0B8A7B7
A6ACABB0A7ABA8ADA2A4A1A3A498A698A589A2899B84998B968E8B909089858779797979
74786D7A5F6B5C725F705E6D5C605957594C5A53574955514F3E4E49494848464344494E
4D4A474647464340484C463F424646484543474F504945474F4641443F43454649414243
3C3B41443D41413F3B3F38423F403E3F3C3E3E403D3D3B44464042413B3F3E3A47474440
3B3A3A41404047404147433C3F3F3C3B413E44423E403E4A4948464444474C5043433F46
415444473E3E4147404351454F3D4C414A3E51464A5252534A4B464548484452564E514F
5B5D5251455A515F4E5F5B645C64666270636D5B644D5954595C5055535A554C465A5C57
5B5C4F535359556355654C535A6057535C555F596A626E6778676C646E62656F827F817F
7C7A7F7C7D8B8D987F9782A386A290AE95A19BACA2A2AEAAA9ABB1AAB3A5B0A8B2B0BCAA
B9B0C0BCC3BDC0C3CACCC0BAB7CDBEC6B8CECDD3C9C8D2CED1D3D6DBD7D5D7DCD5D8D8D5
D5D4DDDBDFD2DCD2D8D6DCD6D2DADAD8CDD9CFDBCEDAD0DCD4D5D1DBD8D7D8CED0D3D4DA
D5E0E0DCD8DBDBD4DCCCD0CAD9DBDDD9DDDDD5DBD6E3DFDCD7DFDCE0D8DAD0DBDFD8E2DD
DFD6DBDCDDE3DFDAD5DEDEDFE0DFDDD0DBD8DEDEE5DBDBD8DBE1E0E6E0E3DEE0D8DEDEE1
DFDADFDEDFDDDDDEDBD7D7DACCCED7E2DFE1E1E2
DBE6DBEADFEAE1DEDFD8E0DCE2E0E0E4DEE2DFD8E3DDDBE0E0DCE9DBE9DBE7E4DFE3DDE7
D8E7E1E0DBE2DBDFDBE0E5E5DDDCDFE0DFDFCBAB857D92AEDCD9E6DED8DCD8DEE0DFE5E2
DEE3DBE4DDDFDEDDDDDADED9E0DDE3E3E0E3DFE4DDE2DFE2E5E3E5E5E1E0E1DEDEDFE0E1
DEDADBDFDBDFDDE2E2E1E6E4E2E3E5DFE1E1DCE3DBE2DADFD9DEDFDEE0DDE1DDE3DEE0DC
DCDEDAE0DBE0DBDDDDC7AB7D637183BCD9DFDDDFD7DDDDE1DDE2DBE3DEE0E1E0E0DCE1E0
E0E1DEE3E0E3DEDFD8E1DFE1DFD4DADEE2D9DEDEDEDDDDDFD8DFD8E0DDDFDBDEDEDBE0DE
DDDCDDDFE0E0DFDFDCDAE2DBE4DADDD7D9D2DAD0DCCFD8D7D4D9D7DFD8DDD8DAD6D6DCDC
DFDADCDCDAD6D9D5D5D8D3D6D3D7D9D7DBD4D4D8DAD9E4D6DFD1D9D3D6D5CFD7D2D7D3D8
CCD0C6E0CDD9D5D5D8D8D5D4D3D4D9DBD6D4DED3DCCFD6D1DED7E0D8DDD3DBD3D0D7D3DF
D5D3D4DAC9D6C5D3C5D8D4D3D5D3E4E4E6D7CFD1CDCCD3C7DACFD7D4D0D6D7CBD6CACFC6
C7CCC5CCCDD5CFD4C8CDBCD1B9CDBFCCC7C1C3C3CBC6B8C8C9B6C7AAC1A8B6B1B1A7C1A7
C9A7BAB0B5A9ACB1AAACAFA6A1A98BAA7CAC97B08D8E91979994897F8D828F7792718778
7D7E797B74756E6E646466686B626D615E5A61685B625B5B5350525A5C5751504E4D4E4E
4D4C4148494F4251454F404A44464442473C4640433D474B49414845414242403F3E3D3B
434342403F3F40404346423D404341423F40474F4E464347433B3D3E3D3C4141403E4042
3F3D4040403D4739453D3E403F3F423D3F3B3F3F3A3E3E43433F444539403A3F3E453C3F
3E3E3E4444444C47454846414241454E444045424042434D4A4A4A48464445454A444E43
4F51524F4E4C484B4A4F5A51514C4C524B4C4F564950474C3E4B484E4A4C4B534F434648
6654604B575766604D595B5C5F60696261665C5F5C605B665C68566D5D746E75727F7C74
7E747C7886709473957A948394979A8D9390959997A594B99EB9A3B09DA39DB5A9B7ADB7
AEAFB3B1B7B1BDBEBDB6CBBED0BCD0CCC9CAC6CEC6CACECBC3CBC4D1CAD0CFD0CCD2D2D2
CED5D9DCD6D1D4D6DBDDD0CACCDAD8CED0D0D6D3D9D1DDD0DED8DEDDD5D7D2DFD0DED9DA
D7DAD7E0D7D7D9D5D7D3DAD7D2D7D5D4D1D6D4D3D4D4D3D9DAD5D5D4DBD4DED3D1D3D4DA
D4DFDEDBCED6D0D5D7D4D4D4DBDBDCD7DBDDD7DED9E4DEDCD7DFDBDDDADCD3DEE1D9DFD8
DDD7DEDDDBE0DEDED6DFDEDFE2E3E4DAD5D6DFDDE0D7DDE0DDE0DEE4DEE2DEE0DAE0DFE1
DEDADFDEDEDDDEE0DFDCDCDFCDCCDCE0E5DDE1DC
E4E2ECDBEEDAE8D9E2DCE2DDE0DEDEE2DFE7D0E0D4E6D4DFE0E3DCE4DBE5E0E6E3E0E4DF
E1DFE3DDDDDBE7D4E4D0E4D8DDDBE0DFDDDEC79E797C85C8CFE7DFE0E2E2DEE0E2E0E2DE
DDDDE0DAE4D8E2DBE2E0E2DCE0DADDDADFE0DCE2DCE1DBDCE1DDDEDFDDDEDDD6D8DADEE2
E1DFE1E5DDDFDBDFE1E0E4E1E1E1E4DFDFDFD9DFDDE4DBE0DBE0E0DDE2DFE2DEE4DFE1DE
DDE0DCE1DBE0DDE0DEC6A67A637288BBDEE4DFE0D8E0DDDEDEE3DAE2DCDFE0DFE0DEE1DC
DDE3E0E2DFE3DEDFD8DEDDE0E1D9DEDDE2DCE2DFE1DCDBE0D9DDD8E3E0E1DCDEDEDDE1DF
DDDADADFE1DEDBDCD3DAD5E2D6E0D7DBDFDDD7DBD7DAD7D9D9D7E0D7DDD0D5D0D6D6DED5
DED4D8D3D8D4D5D2D2D3CDCDCCDDCBE5CBE5CDD6DCE0DAE1D3D8D2D9DBD2D6CFDCD1D6D2
DACEDDCCE4C5D3C2D4CCD9D3D5DFD2DAD4DDC7DFC2DAC3CBD5D8CFDCCAD9D1D6D8D1D2CC
D0BDCACDD4CED8BED6C1D4C3D3D1E1DEDDCDC5C6C1CDB5CAB7D8C5CDC1CBBBCBBEC6BABC
C0BDC0B5C2B7BBB9BEAAC09BBE9AB5A9ACA9A6ADB8B1A7AC9DA08AA2829E8291818D749C
74967A87777578797575716770696D575E565F675F5B58575959565258544E4C524E4F45
4E4C46494648403D433E4342453E4239434648483F463F44454343464846424044444844
47403B4145473E443F41393F3F3F4240463F433E3F40414741433D3E3E41413F4144433D
3A3E4242403D3E3F40423E3C41423F403F3D4044423C3B3F423C4242423C413F3B3F3E3C
3D3C3B3C3C443E4539453845474A494A41413F423A444649464247454345454446404043
3D3F3D403F4048444444534854415058554D4F454541444A4E4D4B474444464849494A47
47504E504F4F48494E535751564D5F4963465B5E5F5D5F51595A696A62615F646460696F
6D7F65806F927081748178867C8C888895829B7E9580A1909D93A48EAD91ADA2ABAAABAD
A6B9ACB8AEC1A8C2AAC9ACC4BDC8BBB8BEB3C5BED1C9DAC9DAC1CCC5CDC8DEC8DDC4D5CE
D2CDD8DCD0DCC8D9CFE2CEE2D7E5CCDEE1DAD8D9D3D9D7D6D7D0DCCAE1C7DBCFDAD3E9CB
E3C9E0D7DAD4D8D9DCDCCEC8C9E4CEE4C8E2D1D7DED9D5D5D4DDD6DADCD7DBD7D8D5DAD6
DCD5E1D1E0CBE0D4D8D2DAD9D4D4D2D3D1DCC9DDC8DECCD9D6D8D3E0D8DDDAD4D2D4D4DB
D3DCDCDAD6D6D9CEDECCD6D1DCDADBD6D9DCD9E0DBE4DDDBD8DFD9DBD8DBD5DFE1DADDD6
DCD8DFDCD8DCDDE0DFE5E0DFDEDEE0D8DDDBE1DBDCD2D8DBDEDFDADFDBE1DEE0DDE1DEE0
DDD9DEDCDEDDDEE1E0DDDDE0D3D5D3E3D7E0DCE0
DBE9D6EDD7ECDFE2E4DFE4E1E0DFDBE0DFDBDED1E3D8DFDDE2D8E7D2E9D5E7DFE0E6DAE9
D7E7DBE0D4DCD4E3D6E0DCD7DFDBDBD7D4DAC69B786A9ABCE7D4EBD9EAE8E3E3E3E1DFDB
DCE3D7E5D9E1DCDDDDDBE0DCE2DCE0DDDDDDD8DDD8DDD8D8DFDDDFDFDDE0E1DCDFDEE0E2
E1DEDFE2E1E1DADDE0DFE2DDE0DFE4E0DFDFDADEDFE5DBE1DCE1E0DCE1DFE2DDE3DEE1DE
DFE2DEE2DBDFDDE0DBCAB59B929DACCCDBE3E1E3DDE4DCD8DBE1D9E2DDDFDFDFE1E0E2DB
DCE3E1E1DEE2DEE0D8DDDCE0E5E0E2DCE1DDE1DEE2DEDDE0DAE0D9E2DDDFDADDDDDBDFDB
E3DDDDE2E4E1DDDED2D3DCD8DFD9DEDCDFD3DCCEE2D2DACFD2D9D4DFD2DCD4DACED8D5D9
D7DFD8D9D8D5D4D3D3D3CFCDCFCFDAC6D7CCD6CBD8CEE0CBDFC4D7D4DADBD1DCCFD7CDD2
D1DCC6E4C7D9BDC5C4CFCBD4D2C9D2CBD3C7D8BCD6BED6CFD8CBD1BDCDBFCCC5CACDBDC8
B8BDBBC3B7C0A8C5ACC7B2BBB0ACB9B6BCB4B0B1B8A9B194B29FB0A1AAA5AD9FAC919C94
9BA1949B91988C93878F728E6A886F7B6E6F68707A7471716D5D6D536A545D545F53574D
4F474E464B4D4A47484C4A464A43513C4C3D43434845424142444545404339403C49423D
444240424344413E4139414046424641414345383E403E41484644434445434040414640
443B3E453F4241414340414A423F433E443F3F3B3B3F3A433D4C42484044433D3E464946
3F414242403E3F4043434041474745484E4A484947423E3E4644444C41424041464C463E
4143414440454A444242414C4A514B5341473F453C484B4D4C48484049454D454D3E474A
484D494946464D4A57605D68565A525E5D5D515848564F595959595857585B5D6B607654
725A7368707775767E7F7B797E88798D798C808E8A967C9073998E9D9C999AA1A5A3A2A1
AC98BBA0BA9FB597ADADB5ACB9B3BAB1ACC3A9BAABC7B3C7BCC2B3D1C8D7CDD1D6D3D2D1
DAC8DDCDD6C7DFD0D8C8DBCBE0D6DAC8D4DBD4D9D5D9D2E2D6DFD4DAD4E1CCE7CDEBD5DB
D5D4D9D9E2C9D7D3D9C9E2D2E0CCE0CDDFD9D9D7D2D6D6D5CFD7C3DDC8DACFD7CDD9D1DE
CAD9D1DBD9D4D8D7DAD8CAC3CBD4DECCDCCAD6CCE2D5E0CCDED4DDDAD6DBD0E1D1E2D6DC
D8DDD2DFCED6D5D5D9D1D9DAD5D4D2D6D4D1D5CADAD1D7D5D7CFDDD3E2D3DFD2D3D4D4DB
D3DAD9D8D4DED2DDD5DAD2D5DAD7D9D6D7DCD9DEDCE2DADBD9E0D9DAD5D8D4DCDFDCDED7
DCD8DBD8D7DBDADED8DEDADADBDCE0DADED8DAD7DED7DBDBDFDFD8DCD8E0DDDFDDE1DDDE
DBD7DCDBDEDDDEE0DEDAD9DBD8D0DBD5DFD6E3DF
E6E2EED8EDD5E7D9E1DDE1E2E1E3DEE3D9E5D4E8D1E5D4E1DDE1D9E5DAE4DBDFE0DEE2DC
E3DDE0DFE6D9E3D0E6D2E5CED9D7D8D3D0D3BC90787D8FDAD1E5DCDBE2DFDEDEE1E3E0DE
E0DEE2DAE4D6E1D9DBDAE0DCE2DDE0DDDEDED7DCD7DDD8DADCDEE1DDD7DBE1DFE3E1DFE0
DFDDDEE2E0DFD9DCE0DFE2DEDFDDE4E1DFE1DDDFDFE4DBE1DDE1E0DBE0DEE1DCE1DBDFDE
E1E3DFE2DADEDBDFD7D3D0CDD3D5D6DDD5DCDBE1DCE1D9D5D7DDD8E3DEE0DFDEE2E1E3DB
DAE2E0E0DEE0DCE0D9DDDBDFE1DFDFD6DDDADDDADBDDDCDCD7E1D8DBD6D9D7DADAD6D8D4
E2DCD9DCDEDCD9D9D2DBD2E3D1DFD3DAD0D4D2DBD8DDD5D3D7D2DACDD6CBD5D2D7D4E3C6
E4CBD9CED3D2CFCFD0CFCFCDC8D5BECFB3D5C6CBCED1C8D5C5CCC4CED4D0D8CCD2C1C9C9
D0C6DCC1DAB7C5BCC3BDC7BEBCC1B9C1B7C4AFC19DB5A8BBAAA8909D91A69AA0A2A4A89B
A3949D919F8A9C86A483928A94888B838984807F827B717974786E6C656F647B646B646E
676365555E4E524F5651564C564E544E464A42484D494E4D4B4A444B424E3F424D48444A
404A4A474044413E4246454443423D493E50444840414243444443414041413D3F43423E
47454542424142424C414643464044413C42403D434B404442413F3E4144434148474845
4F45454641494B4B48454B5A4C4648414641413E3F413F4945584D554A4F4D433E434746
514D474545474849474541454B4A4950505152524C4542434343424E4249474B484E4841
4547454747484844454A465050515C535A505959545B595D5F5F5F555B6356725B716574
6E7773706E6D747381778F6E8B70897C928892798C778A82898E959A9B99979696A789AB
84AC94A29AA5A9A7ADADA8ACAEA5B4A0B7AABBADBCB2BE9AB6A9C7BFC4BFBFC2C7CACACC
C1DBBDD8C0DCBFD2CCD1CCD6CEDBD0D1DACAE3C9D8C5E0CBD8C7DFC3EFC5E1CFDDD2D8E0
D2E7D7DECCE1CEDFD4E1CCDCDADDCCC8D4CEDCD4DED9D9DBDFDBD9D6E0D3E3C4E5D0E1CE
D9D0D9DFD1DFC9DFCCE1CDDFCEDFC9DBD9D9DAD9D3D0D7D5D5CCD7C8DEC5DAD2DCD4E9CD
E3C6DAD2D9D4D7D6D8D6C8C3C2DBC6E0C9E3D2DBD9D8D7D7D0DAD7DFDEDCDFD9DFD6D5D0
D9D0DFCDDEC6DDCFD7CED5D6D1D2D2D6CFD8C6DACBE0CFDADAD5D1D5CED7D8D9D3D4D5DC
D2D8D7D8D6D9DCD5E1D0D5CED7D4D9D7D7DBD8DBDBDFD7DADAE0D9DBD5D7D3D7DADADCD7
DDD7D7D3D7DCD8DBD6DBD8DADAD9DDD9DDD7DBD8DFD8DBDADFDED7DBD7DFDDDFDCDFDBDC
DBD7DBD9DEDDDFE0DEDAD8DAD0D3D3E6DAE4DBDC
DEECDBEEDAEBE1E4E1DCDDE1DFE3DCE1DEDEE6DCE1D5DAD9DFD9E9D8EBD7E4DBDDE3D7E6
D9E4D8E1E0DFD5E1D6DED8C9CDD4D9D7D4CCAC83857CAAC7E5D0E5D5DEDBDEDDE0E4E1E2
DDE4D9E4D9DED9D9DFDDE1DCE1DADDDAE0E0DADED8DEDBDEDBDEE0DAD1D5DCDAE1DDDCDD
DEDEE1E5DCDCD7DCE1E1E4E0E0DDE3E1DEE1DFE0DCE3DBE1DCE0DFDBDFDDE1DBDFDADEDD
E0E2DDE0D8DDDADDD9D8D8DCE5E0E0D9D7DAD8DFDBE0DBDDD4DBD7E3DFE1DFDDE2E0E2DB
D8DCDBDEDCDCD8DED9DDDADDDEDCDCD5DEDADDDCDADDDDDBD6E2D9D8D3D9D8DBD9D4D6D3
DCD9D7D5D6D6D4D2D6D5DCD6DDD6DBD8BEC1D3C8D7C9D3CCCDD0C8D1CAD6D3D8CCDCC5DB
C7DFC8D6D2D3CCCAC6C0C1BEC4BCC4ABB7AFC0B6BCB5BFB2BFB2BEBBBFC4BDC2AEAEA6AE
A3ABA2BA9DB19DAB9AA0919A9B90988C9E8F9D809A7F91848C7D7864786C726A6A75696D
606860585A594A6750624B5B5A4E50485253535256484B485349514D464450484F3B4D49
434B424A444C454D4549434A414A43434349434546454D4C44434645464D464641444348
424743403F43454547474442453D4540454545413F3F3E3D3C3D3F403E4241453B453C40
4442423C3E3C4142463F45474A434D4B5550574658515455544C444244484D4F58554F56
635B544B4E585454464443534F4C4B454A444A4745414A51515C5357525757504B4C4C4A
565452535554504C4F4C4A4E534F505B575A5C574F4D545D574964527059746B6B6E6E6E
7273706F7A7C6B7B7189747E70807191769485958E8E878B91959993A291A890AF91A595
98A5A29F9FA0A7A8A1AF9CB999BCA7ABA5B4A1BAA0B8ADB5B0B4BBBFC1BFBEBDBBB4C1AD
C9B6CBBDBDC6CAC5C7CAC9D1C7CEBBD4BDDCCBCCCAD8B1CAA1D5C4D5C9CBD3D3D0CEC8CB
DACCE7CBE0C3E2CAD7D1DED2E2DBE0DBCBE2C9E2CBE6CBDFD6E0CEE4CEDED7E0E2DEDAD5
DBCFE3D3E3D0E8CBE0C0E0C9DDD4DDC6CED6D3E1D8E0C8E8CAE5CCD7D1DCC9DDC7E4D5DD
D7D5D8D6DECEDEDDD8CAE3D1DACBE3D2D6D7DBD7D1CAD3D0C9D2BFDBC5D5CCD8D4DBD1E2
CFDDD2DCD6D2D5D4D5D4C8C4D3D7DECCDFCDDAD2D6CFE0CEDBD0DBDCD6DED2E2D7E3D2D6
D3D8D1DDCED4D3D1D2CCD2D1CCD0D0D3D0CED5CADDD3DAD7DBCDDECADACDDBD5D4D4D5DD
D3D7D7D9D3DFD2E0D3D6C9CBD7D3DBDAD8DBD8D8DADED6DAD9DFD9DCDAD9D5D5D7D9D9D5
DED8D5D2D8DDD7D9DADFDCDDDBD7DAD6DDDCE2DDDED3D8DADEDED8DDD8DFDCDFDADEDADD
DCD9DDDADEDDE0E2E1DDDBDED3CDDBDBE5DCE3DC
E4E5EBDFE9D9E5DBE0D9D6DBDAE2DAE0DEE4DAE7D5E0D3D8D9DDDDE2DCDDDADBDFDFDDDC
E0DBD9DEE0D8E3D8DECBD6BDCAD6DAD8D7C9A788838C9FD3D0DCDBDADFDCE0DDDEE2DDE0
DBDCDDD9DFD5DDD7DBDADFDBE1DCE0DEDDDFDADFD8DEDBDEE0E1E3DCD6DCE0DBE3E0DDDE
DDDBDCDFDCDDD9DEE1E0E3DEE2DDE3E1DCDFDEDFD9E1DBE1DBDFDFDCDFDDE1DBDED9DFDE
DEDED8DDD7DEDADDD7D8D7D8E0DAE3DCDBDAD7E1DCDFDDE4D5DCD7E1DDDFDEDDE0DDE0DB
D6D5D4DBD9D7D2DBD8DCD7DADDDBDBD5DFD8DADCDBDAD8DAD5DFD6D9D0D7D6D8D4CFD3D2
D5D7D6D1D0D2D0CBD1D2D0D5D1D5D1D1C2C5C6C7C8CBC8C4C4BEC0BAC2BFC4C1C0BDBEAE
C2B1B5B6B6B9B1AEA59B9C979A9F959B85948D8E888D7E8C7D91878E8D8A8E8684767979
76677C6E76656B63605F6162626058555A57495755655A595959494F4A54494E4A4B4A44
4C485148463C4E4153464C4A4C4449404848494A544A4843434249474347404F42494B4B
4143463F49424749494E494B434A45453E424141414245414340483D4442413E3C47434D
4650454848444445444447483E43444A464E434B454648474747494B4D46534952494A49
4E48464148484E4D4E4B4F55574957536A5E6D52655261635E554D4E505053585A5B505C
65635E595A6558604A4F44545254515157515F5B5C4F6364696C6A6D6868696A6C6C6966
676A6D7071706C6973717075776F6F7B8384837F7D818990838D7CA586A996A39E9B9EA3
A4A5A4A2AAA7A8A5ADB1ABAEACACB5B2BCBAC3C4C2C0B9BEC1C2C8C8BBC1B2D1BCD7BDB9
AFBFBEBBBBBCC3C5C6BFD0C3CFBDC5B7C2C4D2C1D2BBCEC2C8CACCCECECFD1D2C6D3B8D8
C1DECACBC9CACDC6C7CECCD3CECACACBD4CFD0D2D0C9CFAFC6C0D9D1CECFD7D4D4D8D6DC
CDDFCEDCD4DDD0D4D6D2D5D4D4DBD7DCDAD3DEDCDCD6DED8D7D7DCD1DBD0E0DCDDDBD9D6
CFE1DBDFD0E5C0E2C4E3CCDDD8DAD5C8CECDDAE0DED6E4D2E3CDDBD7DDD8E3D0DED0DFDA
D5D2D9D8D0DCD0DDD7E3D2E2D0E4D2D8DCD5DFD7D5D2D4D3D5D2D5D2D6C5D1D3DDD5DFD3
E0D0DAD7D9D5D8D7D9DAD0CDCFDDCFDBCFD9D2D6DBDADEDCDBDED9DDDADCD9D8DEDAD4D2
D6D1DBD0DBCADCD1D2CED5D1CDD1D1D0CDD5CDD8D3DDD2D9D9D2DED9D9D8D6D3D4D4D5DE
D3D7D7DBD1D8D6D8DCD4D3D0DAD5DDDDDADDDAD9DADED7DBD9DDD7DCDBDAD8D5D7DBD9D5
DDDBD9D5DADDD7DCD6DAD8DCDBD9DFDED8D8DFDDE0D8DFE3DCDFDBDFD9DFDCE0DADDDBDF
E0DDE1DDDEDEE0E2E0DBDADBD7D4D3E0DAE2E0E2
DCE5E0E5DEDFDFDCDAD2CED5D7E4DFE5DFDDDADDDCDED9D6D5D5DFD6DCD2D9D7DFE2D9E0
DBDDD4DDD9D7DBDBD4D4E0D4D0DCDBD6D7CAAD999C9FB8D3DDD6DFD8D8D5DBD8D8DDD8DC
D7DBD6DBD9D8DAD7E1DEE1DBDFD9DCD9D7DBD8DDD7DBD8DBDBDBDCD9D7DEE0D7DCDADADD
DEDEDFE2DFE1DDE0E1DDDFDAE3DDE3E0D9DDDDDDD7E0DAE1DADEDEDCDFDEE2DBDFD9DFDF
DBDBD5DAD7DEDBDDD4DADBDCDFD4DFD6D7D5D4E0DBDBD8E1D7DDD7E0DBDEDDDCDEDADFDA
D3D0CED8D7D4CED8D6DBD6D8DAD7D6D1DAD0D0D4D8D1CFD4D0D5CED6C8CFCECEC9C4CACA
C1C8C8C1BFC2BFB8C2BEC1B8BFB6B7B2B8ACA89FAFADAA9A9B9894989A9E9C9B8D947D8D
818E7B8C787F7A79716668645D5D66615E5A5F58595A4E4E46534F504D4D4D524F4E4C4F
51464E574A524743464E484A463F49474742473A463F4C4C474948424944444642454049
494746423F434747414E434542414B424645474A48484A474146494349444241423F463A
404542434445444A434647424344484742444646474A473F3D404343414A4547444E4B48
48494345423D424845424342434A50454E4948574F50505050545A5E5B4F5B525B504C4B
574C48414D4D524E4C4F535F6151625E6163696C5F605D6A5C595E6A6E6761616E756A76
777A7E85758070846E7F708070767478817A8D899880968D908A8E8F95908D92999B9692
98999A99999BA1A6A09E9FA4A49998A5ADACADB2BABDB8B2B9AEBFB8C9BCC8C0CDC3C5CB
C9C9CDCBBCC8C3CFBFCEC0CFCDD4C7D8C6D7CCD5D0D0CDD2D1CBD0D2D5CCD5D0DDD2CAAE
B7C9C8C3C4C3C9CBC7CAC1DAC0D0C5CDC0D0CCD5C8C9C7C3C7CACFD3D3D3D2D2D2CBD1C4
DFCBD7C1CFCBCEC7C8D0CCCECAD0C0D6CED2C2DAC8D3C4C9BCD7D2D4D5D1D6D4D7DCD3D4
E1DBDBD0DDD1DFCFE0D6DED1D9D7DADED3DACFE3D4E0D3E0D7E1D0DFCFDFD5D4D7DCD9D2
D5D8DDD7DFD7DBCDDBC7D7C9DCD4D6C3CED6D8E1D5E2D3EBCBDFD1E2D8DAD5D9D3D7D4D8
D5D7DDD9D9D7D8D9E2CEE7C8E7CCE3C8DFD1DFD4D7DAD6D7CFD5CEDFD1D3D4DED7D6D1D9
D5D8D5D9D8D4D7D6D8DAD2D0D5DBD9D3D9D1D5D2DCD5DDD5DED9D6D2D6DBD2DADAE0D5D8
D6D6D6D7D5D1DAD5D4D3DAD5D0D5D3D0CFD2D5D3DBD6D5D6DFD4E5D5DED5DBD7D4D4D5DE
D4D7D7DBDBE4D8E0D9D8D0D0DED8DFDFDADEDCDADBDFD8DBD8DBD5DBD9D8D8D6D9DEDCD9
DCDDDED8DBDCD7E0DADDD9DAD8D4DADAE1DBDDDBE1DBDEDEDBDFDCE1DBDFDCE0DADDDCE1
E3E0E3E0DFDEDFE1DDD7D4D5D7D2D9DFE2E0E1DD
E0E6E0DAE2DADCD7DCB890A1D9DAD9DDD9DDDDE4DFE2DBDBDBE0E1DDDDE0DBD1D4DAD0DD
D2E3DADDD9DBDBD8DBCFD8D2D6D5D9D5D5CFC1C8BECCCDD6DED7E0D3CFD3D8DAD9D8DADC
DBDBD7DBD9DDD8D7DAD9E1DCDCD2DADFD9DADDD9D9D7DCDFDCDDE1D4DDD8D8CBD5D4D7DC
DEDEE1E6D5DFDBE0DCE0E3E0DFDFDEDCDADBDEE2D8DADCD8E3DCE1D3D9DDDDD7D2D3D6D8
D0DACCD4CDDCD1D7D1D5D0D6D1DAD4D3D3D5D7D7D4D2D6DBD1D5DAD4D9D6D6CFD2D5D3D1
D3D1CFD2CACEBFC7BEC3C5C6C1C1C3C5C7C6C2BFBFBEBDBBC2B9BCB3B4B3BBA6A9A5A5A0
AA9B9B9B9A93878A828E858C818B8085797E73786B766B6B646B6258575E635953525952
56585C4D434A4E4F4F4F4C4845444E4B4746424C46423F40414143474443403E40434646
4846444241424446424041444342454B4242424840474748443E45444445424B49424541
4043414A4547504A474B4649474544525048504F4D464948504A4E4E464E474A484C444A
4D474D4E4F4F484B48454C4C444D554D404D48524D4E4C444548464A534B475654555357
4C5C4C4D444851514A484B4952465152535457605C52615E5F636E6C6C6A6B696D6B6B68
766C6A6A75656D6B6C6F767C7D7E848B7C8B7B8B808C87938A888E999B928B8B989CA1A0
A6A0A6B0B5ACB0AFAFA8ADA8ACA7AAA9ADB5B4B7ACB9ACBDBEC9BCB8BAB8BDC4C6BDCAB8
BAB6B2B4BBC0C0BEBEB4C5BCC9AAB6BCCBC7C4CBD2CECAD0C4D0C7D2C9D3C9D4C9CBD1CC
C7C9D0CDCCC9CFCCD0C5C8C8D2CBD6C7DACCD9D3C6CDD0CDC8D0C8D8C3D1CCDCCCD6CEC6
B9CACECFC8CCCCC9C6C4D0CFCCD0CCC6CDC8D3C8CEC1C9C3C9AFABCFD8D8D3D9CBD8D1D3
CCD4D5D2C7CACECBCECFCEC9C8D0CFD5D3CED1CECFC2C6BDCACBD8CDD7D6D6D6D6D8DBDD
CEDED1D9D2D8D4D9D6DCDCD5DAD6D9DDD8D9DAD6D9DBDDDADBD1DCCED5D6D9D4DBD6DAD9
D9D9D8E0D4DBD7DCD9DAD9D4D5DEDDCCCCD7D7DCD5DEDBDBD9D8DBD5DCD8DAD3DAD7DEDE
DCDED7D6D7DBD0DFD1DCD2D9DADEDADAD8D6D4D5DDD3DCD8D6D6CED0CAD1D1D5D8D4DBD7
D8D4DBD7D7D0D4DAE0DFD3D1CDE0D8D7D1D8D8D7D8D9DDD5DAD9DDD7D6D8D5DCD7DBD4D3
CFD1D3D8D3D3D3D9DAD6D8D4D4D8D6DAD2DAD0D1D5D6D6D4DBD9DDD8DEDADEDCD9DBDBDE
D3DBD4DCD6DAD7DFDEDACED1DFD8DCDDDEDCD5D9D8D5D9DBDFD9DBDCD6D4DEDADBD5E4D5
D6D7DBD6D8E0DDDED2E2D7DFD5DBD7DCDCDADBD9DFDDDEDCDBDCE0DCDDD9DEDFDEDEE2DB
E4D8E3DEE2DFDFD8D6D9D5D7D4D7D5DFD9DDE1DE
DAE6D8E2DCE5DEE0D5BC9EA6D2DAE3E8DEE1DEE4DEE1DBDCDFE1E0DCDCDFDCD6DDE0DBDC
D7DDDAD9D7DAD9D7DBD1D7D1D9D6D6D2D4D4CFD9D3E3D8E5D9DBDBD6D4D3D3D4D5D5D6D6
D4D1D9D0DAD2DAD8DDD7D9D6DAD3D5D5D6DAD8E1DCE1D9D8D6DADADBDBDDD5CCD8D6D7DB
DDDBD9D9DDDCDDD6E4DDE9DFDCDCDBDBDBDCDDDECEDED0E5CEDDD1D5DADDDAD2CBCBCED0
D2CECEBCCDC6D0CECFCAD5C0CFBDC4B8BBBDBFC1C3C5C6C5C4C6BCC4B6BEB6BAB5B9B8B8
BAB6AFAFA7A6A6A0A5969B92929191908F8B888588898A888C7F7E73717879796A6F5E5C
625F64615C584F51555D51564F5950534A4F474F46524A4A414843414042494541404743
47484D42444443424447433D464043414246454E47434040403F414547433F3E4144484B
494743403E3E3F4048474644403E40434243484E494A4845414046434448434545414445
484C5058504D504B4C5553554B484853524D534F4E4B5150564F5150545957605F5D545A
5452555654524F53564F524D454C52514B55525A5658585354595A5F6662606963656669
6371686C69686B6B64656C6F796177658575877F8079837D838791959294909996A09C9E
9A9F8EA99CAAA2A99CA0A7ACACACB2BAB3B0B4A8C1B4C7C3C0C0C6CFCFC7BFBCC0C9C4CF
C6CCC7D5CCCCC5D3C1CECBD2CAC5C7C4C6CCC9CCC2C8CDC4D3C5CEC8D0C6D0CDCDCACCC1
BCC5B8CDB6CAB9C1BCCAB7D0BCC0ACC9CAC6C3C9D0CDCBD1CAC4D1C6D6CAD4CCCBC6D5C5
D0C6D5CDC4CAC0D3C2D0C6D0C7CDCED5CED1CCCED0D5CBCFCBCECCD0D2D0D9CCD7C8D0BA
C1C3D9CAD1CBCBC9C6CBC4D7BFDACACFC6D1C8CFC8CEC2CCCBC0BFD4D0D0CDD4D2D2DAC9
D8C9D7C9CECAD4C4D3C6CEC4C6D2C3D9C7D4CCD0CBCAC2C7C1D1D2D4D5D3D1CFCFD0D1D1
D9DBDAD1DAD0D6CED7DDE4CFDBD3DAD6D1D7D3D9D4DDD9D9D6D2D5D6D1DED9D9D8D5D9D7
D7D9D7DDD8DADED6DFD3DBD1D6D8D5CACDD6D5DBD8E2D2E1CFDCD7DBD6D4D8D3DAD7DCDB
D9DBD4D5D6DACFDDD3DDD3D9D9DDDAD8DBD8D5D5DBD1D8D4D7D8D2D4CDD2CFD3D3CFD8D5
D7D3D9D5D5D0D6DAE0E0D3D0CEE0D9D8D3DADAD8DBDBE0DAE1DDE1DED5D7D3D9D6DEDCDF
D5CBD4D4D9D2DBD8DAD7D9D5D5D8D6D9CDDAC9D9D0E0D8DCDCDADED9DFDADFDDD7D7DFDC
DBDDDBE0DCD8E0D4E3CFD1CED9D5DADBDEE0DBDED9DCD5E2D7DED5DBD8DBDBE3D7DDE3DB
DDDBDDD9DAE0E0E3D8DFE0D7E1D6DEDADFD9E1D6E4D9E0DAD8DFDAE5DAE3DDE3DBE3DBE5
DEE2E2E3E2DEE0DDDBDCD7DAD8D4DFD9E4D7E6DB
DEE0E1D7E3D6DDD3DBD7CFCDE0DBDBD4DADCD9DED9DEDADDDBDBDBDADADAD7D4D7E0D3E1
CDE0D3D9D8DADADADDD6D9D3D2D1D3D1D3D4D1DAD8DCE1D5DECADDD3DEDAD5D4D7DBDBD9
D2DAD0DCCBD8D1DADCD7D6D4D8D4D5D4DCD5D9D2DFD6D8CED9D5E0D6E5D8DDD2D5D1D0D5
DADBD8D7D6D9C5D5CDDED7D5D9D7D4D4D4D3CFCCD0C7D5C3DDBFCFBFC2C8CCC9C4C2C1C0
C0C5A7B29AB3A4B1A6B0A0AD919F8A8D9E9F9D99999A948A93888B818979818181837F7D
7F79706F6D6763585D51585156565553504D4B4A5555534F52474C454749474B414B4147
47494D474445403F494C404240484144454842453F453E3D3F444245433F444445414442
433F413C4544413F40444542443E3F404243404348444141403F414549413C3E4041464C
4645434243474A4B434647444244484A56555E605F5B5951564E4A49556055484A4A4748
48474D50524E4D4A505A595956545359575557505253595A5C575B5D5E6166757670676B
686B6C6E6B666B6F746C706B6A6F70787078767B787B7D7C84898A8D8C8C898B989A9E9C
9B9F9B9DA29C9EA09A9AA2A8ABA5A2ABA4B4B0B3B5B2B9B1BBBCC0C6C3BFC4BEC7C2C8C6
D1CACAC1CEC3D0C9CACCD0D1CECCCFD5D3DAC1D6C8DBCED2D2D3D6D9D9D3CDC9D2D2DBD0
DECFD9DCE0D5E4CED7BFCFCACFCBCCC8C9CDCACDBFD4BED6BAD3C6D2D2D2CCD2D3C7D7C4
BFBDCFBAC6AFBDB9CAB7D2BBCBA5C0BDCCC8C4C7CECCCAD0CCD0BADAB8DAC5CBCACCC8D1
C6D2D0CFD0C6D4BED1BACBC5CFC7E1C0DDBBD3C9D8CCD3CCC4D4C6D0C5D2B8DABEE1CCC8
BCCFC6DCCDCCC8C5CAC1D5C1D2C7D3CAD3C1DCC3D6BBD4C1CECECED6CCCECBCECAD7C3DE
C7DCCDD0CED1C9CFC5CFC7C7D3CED3C7D5C5D1C9D2CBD8B9D1BDD4D0D5D3D0D0D2D4D4D4
D2DCC8E1CCE2D5D5D4E1DED7D2DAD6D3D2D2DBD1DCD5DCD5DED2E4CEDED1DDD1D8D8DCD8
D7DBD8DBD6E2D4E3D3DDD5D4DBD5D1CBD0D7D6DCDBDAD9D7DBD2DCDAD5D4DAD7DDD7DAD7
D9DAD4D6D6DBD1DED6DFD5DAD7DBD9D7DDD9D8D6DCD3D9D6D6D9D5D9D1D4D1D4D3D0D9D6
D7D2D7D2D4D2D9DADEE0D4CDD1E1D9D9D5DCDAD8D7D5DBD9E1DBDFDEDDDFD9DDD6DBD8DC
E1D5D2E0D3D8D4D1DBD7DAD7D6D8D5D9D9DBDAD1DCD3DBD3DDDBDFDAE0DBDFDDDCE2DDE8
D5E3D4DDDDE5D3E3CED9C6D1DCDADDD9DADED9D9E2DBE3D7E1D1D7D3DED6E6D6E4D1E8D8
DFDBDEDCDDE0DEE3D8E8D2E6D1E3D4DADFE0DCDFDBDFDBDCDEDAE5DAE6D9E0DBE1DCEAD5
EDD1E7DBE1DADEDFDEDCD7DDD6DFD2EBD5E6DDDD
DBE2DCE1DEDFDCD6D8D9DFDBE2DFE4DED9DBD6DBD5DAD7D9D3D4D8DBDBD6D1CFD2D5DBD4
D8D5D9D6DADBDDDFE1DDDCD9D6D5D6D7D7D4D3D8D7E3D2E5D2DED7DAD5D2CECBCDD1D2D0
D4CED9C8D7C5D2CCD2D2D3D2D1D0D3D6D2D2C7D4CEDDD4D5D5D6CDD7CDD6CED1D5CEC9C9
CDCECBC6C7BCBEB0C7B9C8BAC5C1BFBFC0BEB7B0A5B1A0B89BA2949D8D9599968F8A8683
8C81816B786B7672726F7A656F5D655C6164625D5C5F594F5353505751514C4E4C4C4747
4C4D494A555242453B444145434545454342434546464441463F494647414A4048424445
4A46423E3F43413F4648414041433F4247474446454744433F4341444442454246424346
47444445414647423E3F4345464345474846444649464545444345494B423E414341454C
4545434143474A4A43494C49484B4D4C58555F5F6460645D63594E494F5856514E524F54
55535A5967666564696F6F6D6D6A6B6E6E70716972757979797A828985888F9B9E9B9595
8F97979B97929EA3A19DA6A7A9ABA6B0A8ABAAACAAACB0B3C0C5C4C5BDC2BEBCC2C4CAC7
D0CDCAC8CBC4C8CECAC6CBD0D0C9CAC7C9CDD2CECECAD4CDD3D0D0D0D2D7CBD8C7D5C9CE
D6D9D1D1D0D3D6D0D7D4D4D5D4D2D2D4D4D3D2D1DCD2D6CDD7D7D6D5D4D3CFCCCCD9C9DD
CADCCCDAD4DCCEE4C7D5C2CBCAC7C9C7C8CCCACDCEC9D6B9D4B9D1C4D2C4D4CACDCFC9C7
C2D3BCD6AAC6B0C2BFCFBBC8BABBA9C9CFCDC8C9CDCBC9CED3C0D4B3D2B7D4C7D0C3D4C0
D7C5D7CACAD5BCD9B6D5C1D1C7D2C6DBC5DBCED9CFD2CAD1C3C5D2D1D1C3D4B5D7BCD6BA
CCBBD6BCD1C2CACFC4D2C0DDB9DCBDC7C1D5BFD2C5D7C0D2CECECBD3CFD5D0CFD1CADDC7
E2C0D6C8CEC4D3BDD6C4D5CCD0D9C2DEC4DFCBD4C9D5C3CCBFD4CCDBD9D5D2D3D7D9DAD9
D7CFDECDE1CFE4D0D5D6E3CEDED1DDD3D7DED6DED1DDD4D7D8DBD6E0D1E0D9D9DCDDE2DB
D9DDD9DAD5D5E0D1E1D0DFD3DFDAD8CFD1DADADFD6DCD3E2D7D9D5D9DBDAE0DBE0D8D9D5
DBDBD7DAD9DFD6E2D8E0D7DBD6DAD8D6DDD8DAD8DFD8DCDBD4D8D6DAD3D8D6DADBD7DED8
D8D1D6D1D7D6DBD9DCDFD3CCD4E2D9DAD7DCD9D6DBD7DDDEE5DDE1E2DBDEDCE0D8DBD7DA
DFCFDCD5E3D2DDD4DCD7DAD8D8D8D4D9D3E2CDE2CDE2D6DADDDBDFDADFDADEDCDCDAE4DD
E2DEDEDFDFD8E5CCE2C7D3CDD7D6DAD5D8E0DCDBD7DFD0E5D0E4D6DFDBDFD6E3D1DAD9D7
DAD5DBDDDDDDD9DFDCD8E2CEE5CEDFD0E0D9E4D4E5D5E1DAD4DDD0E7D4E9D9E1D5E0D3E7
D6E4DCE1E0D8DBDDDDD9D5DDDCD3E3D4EAD4EADA
D7DEDAE1DDDFDCD5DDD7DCD5D8D6DEDFDADBD5D8D1D4CFD1D5D7DBDEDDD9D5D4CED9D1DE
CCDBCFD3D2D4D7D9D8D8D4D3DBD6D2D2D0CED1D3D7CFD6C9DBC6CFC1CDCFCDC8C7C9C9C6
CBCFC0D0C0CEBDBFC4C6C6C5C2C4C5C7C3BDC4B9C4B7BCB5BFB8BCB1BBAFB5B1B0ACA7A8
ABACA6A09398849686948A8D787675777B7A756F6B6A72696F5763605A5E5D57504F5051
53524C524C524D4F4C524D4F454D484A4B52524C494E4E4A3C4242464247423F45443E3C
41403C3C44453E453D453C3F3E3F403F3E3F41433C3F424249404742443C443A423D3F40
4B453F3F403F414244474744474242464643434245434544424742444A4F524945424045
45413D40454C4F4C474546464749494A47464E564947484A4A484B504D47464C4F4C4E54
50525150545B5D5B51575C5B5C5F5F5B676774777F7E85806A6768737C7C7A767B83838A
8D8B918E9C9F9E9C9DA0A2A0A09B9EA1A3A9AAA6A9ADAFAFACB1B9C0B8BCC1C2C5C7C5BE
B7BFC0C6C1BCC8CFCBC9D0D2D3D1CAD1D0CECFCCCDCDD1D5D6DCD8D9CFD9D6D4D6D4D2CD
DBD0CDC8D4CDD1D9D6D2D5D8D6CCC5CBCFD8D8CED4CAD6D1D1D0D2CCCECDD1CDD1CBCECC
CED5D4D4D7D6D9CFD4CECBD0D5D6D5D5CFD6D1DBD3D5D2D0D3D3D3D2D2D0CCC8CFD0D7CD
DCD2D8D7D0C5D5C3DBC0CAC0CCC9CDCBCCD0CED2C4D3BDD8BBD6C9CFCED1CCCFD1C2CDBF
CBC3D2B9CCB4C6C0C8B9CDC1C6AFC6C5CFCFCBCBCFCECCD0C2D3BAD6B6D7C4D9CFCDC3D1
C5D2CACAD4CAD7BFD3C0D4CDD2C6E0C4E8C7D9C7D4C8D5CEC1D3C9D6BFCFB5D7B7DDCCCE
BECABED7CCC9CDCDCDC6DCC3DAC5CDC3D3BCDCBFD7B9D7BFC9C8C4D0D3D9D3D5C6D9C7E6
C5D9C9D5CACEC5D0C6D4D0D8DCD2DCCBDDCCD3C8D5CBD6B4D7C1D7D1DBD7D3D2D4D6D5D4
D1DDCFE7CBDFD7D7D6D8D5DCD5D9D5D7DBD9E0D1DAD1DBD7DCD3E6D0E4D1E4D6DDDFE3DB
D8DCD7D7D1DED0E1CEDCD4D6DEE0E1D2CEDADDDED5DBD2E2D7D9D5DADEDCE1DBDFD8D9D5
DBDAD8DCDAE0D8E2D9E0D9DED6DAD9D5DED7DAD7DDD7DADAD7D9D5DAD4DAD9DDDFDADED8
D7D1D8D3DCDADDD8D9DDD3CED5E2D9DCD8DBD7D5DDD8DDDDE3DADEDFDBDEDADED6DAD6D9
D6DAD6DDDCDCD4DBDCD6DAD9D9D9D5DAD8D8DED3DED2DFD5DCDADED9DFDADEDCDCE0D9E6
D5E7D8E3D7E3D0E3CCDEC9D2D6D6D9D4D6DEDAD9DFDBE1D5DED5DCD8DBD3E2D0E3CAE1D5
DAD4D8D9DBDBD9DFD9E4CFE4CEE2D4D4DADDD9DFD9DFDBDEDFDAE1D7E1D7DEDADFD8EAD2
EDCDE4D6E3DADCDDDCD9D5DED7DFCEEAD3E9DFE1
DCDADFD7E1D6E1D3DDD7DFDADED9DADCDADBD5D9D2D7D3D5D0D1D2D1D0D1D1D1CFD0D7CE
D5D0D5D0CDCED1D2CCCEC7CAC8C3BEC3C1BEC1BDB6B8ACC2BDCCBEBFB0B4B3ADA9AAA7A3
B3A8AEA0AF9D9F919B9C9798959994928B8F868C7F87818681877E88798275766C6D6F72
767670685F5A5F55624F5D564E4D4C4E504F4C48474A434A4644434244484A4541424647
444046494A4747434245434140434444464C4D453E3F42434141493B4741484040434142
47464242403D49414941403D414141403F3E3F40444445444A42494343423E413A483F45
40424144403B4145444448424A4144484D4648424A444948494D47474D52564C4B4C4B55
5B5D585C5356595A5D5F5C5761686A6B635B646B66676B6F6F6D6F74706E70777C7B7C7F
838687888F989A969295999CA0A2A09C9B9EAAAFB0AFB1ADB1A89EA7AFAEB0AEB7BEC0C2
C2C0C0BCC6C9C5C4C3C5CBC9D0C7CACAC9CFCFCFCBD0CFD0CCD1D2D5D2D2D5CED0D2D3C7
C5CACFD2CFCAD0D6D7D7D8DAD8D5D7D7DBD4D7D1D4D3D4D8D3DBD2D4CAD4CDD0CFCEC7C5
D6CED0CFD3CBCCD1CFCFD2D3D5C7CCC4D6CAD8CADCCED9D3D2D4DAD3CCD5C9DAC7D8CBD3
D7DFD0D9CDD9D6D6D6D0CDD1D6D7D6D5D2CEDCCCDAC4DAD0D4D5D8DBDBD6CFCBCAD8C7DC
CBE2CFD8D1D5C2D6C7D7C4CBCBC9CDCACACDCACECBC6DABFD4B8D3C4CCC3D6C8CACBC1C5
C3CFB9D6B8D3BCC7BFD3B7CFB6C5A9C8CACDCDCED2D1CED2CFCCE4C1E0BBD0CBD4C4D1C2
D6C4D2C6C9D7BFDBBADDC9D7CBD1C2DAC9DFCCD0D8D8CCD4CDD0D2CED0C6DBBDDBC0DBC2
C5B8D8C1D9C8D1D4CCDAC8DFC3E1C4D1C3D2C0D0C7D6C2CFC5C7C5D2D3D5D1DAD6D6E7CF
DFBFD3C7D2CAD8C5D8C5D9D7D1D8C9E0C9E2C9D1CCCFBEC7C1D8D2D9D8D5D3D2D5D7D8D7
D4D3E5D1E4CEE4D6DCD1DED3DFCDD9D4D4DBD4D8CDD9D6DBDDE2DAE2D3DBDAD6DBDADED8
D5D8D4D6D6D7DFD1DCCCDAD1DADEE2D2CAD7DBD9D9D8D8D6DAD2DCDBDAD8DDD9DED7DAD6
DAD8D7DCD8DED7DFD9DFDAE1D7DBDCD6DED6DAD4DAD4D3D5DBDBD5D9D3DAD8DCDDD7DCD6
D6D2DAD6DFDBDDD9DADCD4D2D4E2DADEDADCD9D8DCD8DCD8DDD7DBDADFDFD7D8D1D7D6DB
D9DBE3CCE4D0D8D6DDD6D9D9DAD9D6DDD1DECFE5CFE3DBDDDBDADED9E0DBDFDEE3DEE4DC
DFDDDCDDDAD7E2CDE3CFD6CDDBD8DBD7D7DBD5D5D9E2D0E4CDE6D7E0D6DBD3E1D7DCDCDF
DFD9DAD6D7DCDCE3DFD8E5D1E7D2E6D4DBD7E3D5E4D6E1DDDAE4D4EAD3EADBE5D8E3D8EA
DCE6E0E3E6DEE0DEDEDDDAE1DBD3E0D5EAD9ECDD
D8DBCFDBCEDCDDDADCD6DBCFD4D1CFD3D1D0C8CAC3C8C6C9C5C9C9C5C4C7CAC8B9BCB5B8
B2BCB8B9B3B5B7B4A9ABA2A89F99949D9D989A908A7F827D8B8286828285848080827D75
75756B72686D605E616561625C605A57645E5D51554E53524C50534E4E4C4A43474A4C4C
4C4B4640474A3E4C43474446484848474644434240484646403D444443484B4742404140
473D4642483D433D4443453F43424541414445423E3E414543473F473C47404345484645
47454042423E4B3F4640424340404041434444434544424049454E4944484749424F4241
424B4A4C4B4A54545B53534B5B53595B6860645D6A636D6D7A7D797B7B797D7A8487838D
93978D8E939496989EA2A09B9DA6A7A99E909496A0A2A8ADADAAABAFACACAFB4B8BABABA
BDC0C0BFC3CAC8C1C5C2C1C5C8C6C1BEC0C3C9CDC4C3C2C0C5C6C0C4C6C3C9C6C8CCD1CF
CFD1CECDCACEC9CCD0D1D6CFDACDD0CFCBCDCDD3D3D6D1D3CED5D3D3D8D4D8D2D4D3D5C8
C1C3CBCECDCACAD0D3D6D3D8D2D1DDD3DACFD4CDD4D1D0D3D2DCD0D5CDD4CAD2D1D6CCCC
D6CBCCCFD3CDCDCFCED0D3D0D1D1C6D8CCD1D1D2DDD2D9D2D4D4D8D5D3D5D2D4CFD4D4D8
DBD5D9C7D9CAE0D9D7D4D2D2D1CECFD3CED7CDE1CCDBD8DCD4D2D4D9D8D0CAC9CCD2D1D1
D6D9D5D4D4CDCFC1D0BEC1BECBCACECBCACCCACEC9D1C8D5C5CFCECAC6C9CEC8CAC1C7C7
CBC6CEC5D2C9D2CDC8BBCEBBCAADBDB7C9CECFD0D4D1CCCDC7D2CCDBCBD7CDD6D3CBC8D0
CBD0CDCBCFCFD2C8CCC8CDCAD3CAD3C3D6C9D5CED9D3D4D1CDD8C6CEC2CBC0D4CADDD6CD
B7C3C8D2D2CAD1CED1D1DCCCDAD1CFCCD2C4D7C5D6C3D3C3C5CBC9D2D1D4D0D9D2E1D3E1
CEDAD0CFD6D7D5D7CDCED0DADAD3DCD2D9D3D0CDD4C7CEB9CDC5D9D0D5D4D4D5D7DBDDDF
D9E4DAE1D8DBD5D3DAD6D7DAD5D7D8D7D5D6DBD2D6D3DBDADBD8E1D4E0D2E6DADAD6D9D7
D5D6D4D9D5E0D6DED1D7D5D5DBD9DDD2CCD7D9D7D4DFCFDFCEDCD7DCD9D8DEDADFD8DAD6
DBD8D8DDD8DED7DFD7DEDCE4D9DDDED8DFD6DCD4DAD5D3D5DCDAD3D8D4DCD9DBDED9DED8
D8D4DBD8DED8DCDBDDDDD6D7D3E1DCE1DDDEDDDFE0DEE1DADFDCE1DEDADAD2D6D2DBDBE0
D5DBD7CCD7DBDDDADDD5D8D9DAD9D7E0DBDDDFDDDBD6DFD6DCDADFDBE2DEE2E1DCDFDBE5
DAE9DCE4DCE3D5DDD3DECCCDD6D2D8D9DCDFDBDEE0E0DDD8D7DADBDAD9D6DFD7E7D3E3DD
E0DDDED7D7DDDBDEDADFD8E2D8E1E0DADCDEDEDFDDDDDDDFE0E2E3E2DEDDDDDEE0DEEADC
EDD7E7DCE3DEE1DFDFE1DEE2D9DED6EADEE9E3DF
D4CDC7BFBEBDC9C0C6C6CAB9BFBFBBBEB6B3A6A3989B979A91999B96959A9A95928E887E
7F80827F7E7F807C6C6E636B71675C636362675E5B544E514F5452584D4E4C4A4F555044
48484B494D4A4C4B48525353474B484A4C4C494C4B4C4745454E494A414E48453F424441
4245474645413C3F474147434243444442414345474B46424241453F3E43443F3C3F4447
4A4043434440464346484545444845414747474644424448484347474B424445494B4846
4A4B4B50494D50544A544A544F4F51565B5F606057595C606D6970686B686F606D757C79
737C77767C858F889E8F8B8198919999ADA1A499A599A4A3AFB2B2B9B6AEB6BBB9BDB8C2
C9CFC3C1C6C8C9C6C5C6C7C5C7CDC9CAC1B4BBBDBDC1C7CDCCC9C9CDC9CACBCDD0D2D1CF
C4C8C9C9CED5D3CBD3CCCAD1D7D7D4D3D1D3D4D8CACECFD2CED0C6CAD1D2D1C2D0D1D8D2
D1D6D1D2C2C7C3CCD4D5D5C8DACBCFD0CDD1D3DDD8D8CFCFCBD7D6D7D6CED5D5D9D4D6CC
BFBFCBCFCFD0CBD1D5DAD6DDD4D1E1CFDBCED4CED6D4D1D3C6D3C8D1CED5C8D6C9D5D0D4
D8CAC8CED2CFD0D2D1D4D4CDD2C2CBC8E1CCDFD2DED7DDD3DAD6D2D1CFD4CAD5C8D8D4DE
D3DAD1DCD2D5D1D1D0D2D4D2CDC9CED5D8D3DFD5DFCCDCCEDED7D5D9D8D0CDD0C8D3C7D4
CCDCCDD0C6CDCBD2D3D4CED6C8C7CDCAC9CCCACFD2CACCC5D0C7D1BED0CDD9CAC9C4C2CA
C6C9BFC8BECDCAD3BEC9BCCFC1C9B7C7CBD1D2D2D3CEC7C6D8CED7CBD1C6D2C9D4C8CECB
D4CCD3CDC2CDC3D1C0D4CAD0C6CBCBD4CFD6D3D6CED5D1D1CDCEC4CCCDC8CDC6D6CDD3B9
BABACEC1CEC2CFCFCCD7D4DAD0D8C2C5CECFCDCED1D0CCCBC6CFCAD0D1D7D1D5D7DBDAD4
DBD8DBCCD9D7DED4D5C8D4DADAD9D7DDD3DFD0D6D0C9C8C3C1CBD6D4D6D6D5D4D5D7D9DB
D7DBDCD4E6DBDFD7D7D2DAD2D8D7E1D8D8DDDCDAD5D8D9DBDEE0DDDCD8D5E0D8DAD4D8D8
D7D8D7DFD5DBDCD8D9D4DCD8DED5D8D4D2D9D9D8D2DAD8DAD8D8DBD6DDDCE2DEE2DADAD5
DEDBDBE0DAE1DAE0D6DDDCE5DBDEE0D9E0D6DED7DDDAD8DBD8D7D0D7D6DFDBDCE2DEE3DD
DDD7DCD7DBD5DBDEE0DFD8DAD1E0DDE3DFE1E1E5DDDDDFD6DBDBE1DDDFDED6DAD4DAD6D7
E0DBDBC3D5D6E0D0DDD4D7D9DADAD8E2D5DCD8E4D7E1E3DFDDDBE0DCE3E0E5E3E1E0E2E3
E0E5DCDFE3E2DDD3DBD6D0C8DAD5DADDDFDFDADEDAE1D5DED0E3DBE0DADCDBDEE0D6DADA
DCDCE1DAD9DDD7D5D8D6DED8DFD7E5D9E0DEE5DCE2DAE0DEDAE3DBE9D7E2D8DFDBE0E0E3
E4DEE2DFDDDCE0DDDEE2DEE0DDDCE0E6EBE4E8DB
9B97918F8695919E8995808C828E9089907B6D61626462656B6A6160595C595C5B55564E
4F464E54464E505457524848514A4D48484B4446474A494845494A4A4747474747474646
434746474145454844594F4649454648464549464C4451474442444D49433F4544464A44
4B414346494A424B3F443F484347424646424845464D473E4E41454746434A484C4C4745
4D4D4A4B4D49484F525053514C544E565C5A60625C5F66656E616064666D6C7B7C756F7C
7775707977757C82848B929185868E9596999C9A92969B9FA2A3A2A2A7A9AFB0A2A5B5AF
B8B9B9BCBEB6B6C2BFBFB6C9C5CBC0CBCCC8CBCEC9CAD2D7D9D1CED1CFC9CCD4D1CFCED5
D3D3DBD5D6D5D8D0CFD6D3D4D1D6D4DBC8C2BCC8C8C7CACFCFCCCDD2CFD2CDD4CBD3CED1
D1D3CAD0CFD1D3D0D5D9D9DADCDAD5CBD4D2D6D4D7D4D7D4DBCAC3C5CFCBCBCAD1D2CECD
CBCCC0B5BECCC3CBC1D0D1D1D1C9CACDD4D4CED9D6D2C4C0CCD6D3D4D6D0D5C6CECDD5C7
BBC6C8CDC7CFC6D2CBDBCFD7CED3CED2D6D2D4D1D1D4CFD0CECACDCAD0CDD0CCD1CADDC9
D5C6CBCAD0CED1D4D1DBD2D8C4D0C9DCCFD7D6DED4D2DDD8D9DBD8D0D6D6D2CFCFD4D7D8
D9D7D7C9D5D0DECFD5D0D0D0D2D4D4D8D3DCD1E0D4DCDBDFDCD9D4D7D4D5C3C8D7D2D2CE
D2CFCFCBD3C5CECCD7CDD4CCCCCCC7CDC7CDCFD7BDD6C8D5BACCC7D2C3C4CDC8C7C7C8CE
CBC8C5C2CBC4CCC5D4C1CEBFC8BCBFB9C9CBD1D2D4D1CAD2C8DAC8D9C5D1C8D5C6CDCDD3
D3D1CCD4CFCCC9CACDCFCECCD1CBD1CCDBD2D4CBD4D1D3D0CFC9C5D2CBCDCBD2D4CFCEC7
BFCBD5D4CECDD0D3D2D9D3D6D4DAD4D7D2D0D5CDCDCDD6D1D9CED5D0D3DAD3DED3DFD5DA
DADCD9D9DADBE1DBDDD7E0E3D5DED1DBD8DAD4D5D4CFCCC1C8CCD7D7D5D5DBD8D7DBDAE0
D8D9D7D7DCD6DAD3D6D5D7DDDFDCD9D9D4DBD2E0D9DED9D7D6DFE5DCDBD9DCD8D6D5DBD6
D5D8D9E0D6D8DED8E1D3DED8DCD9DCD6D2D4D5DED2DFD6E0D0E4DADDD9DADDDCDFDDDEDD
DCDDE0E2DFDAD9DCDCDCDFD7E3D9E1D6DDDEE4DDE0D9DEDEDADFD2E0D1E1D8E0D9DCE0DF
DCDADCDEDDDDDBE2DFE5DBDAD4DEE3D9E6D9E2E0E2E0E3DBDFDBE2E3DCE1DBE3D7DDD6D9
DAE3DCD8DCDADFE0DDD9D7D9DAD9DADCDBDDDCD9DFDBE2DAE0DDE3DBE3DAE0DCDFE4DDE0
E0E5E0E7DADFD4DBD6D1CBCFDDDADEDAE1DCDDD9D9DCDBE0DDDED9D7DCD8DED8E2DBE0DB
DFDADBD7D7DBD7D9D1E1D5E0D7E0DCE3DDDDE3DEE2DBDFDED8E1DFE4DFDFD5D9DDDCE2DF
E6E2E6E3E5DEE0DFDFE0DBE0DDE3DBEBE0E2DDDF
625E5D5A555E5B645C68545D535D5F5A534553485C4D4D45504A4F424C424A474D464746
4E484A49424B3F4C424F424A4B474644464A494B44464A4549494F4E4346494C4C4A4948
46434C444E454E4D3D4B444144454C504A4A464D49484F4B484B4152424C424D4653574D
504A52544A464B494E4950534E57585D5A5459575D645A5C605F60646162646C6A756B6F
7771696C797F82888E899587908A8F918D939C9E999AA0A4A39F96A59BAEA5B4ACA7A4B1
B2B6B5BDB6B5BCC2C0C2C3BFBABCC3C6C1C1C3C1C4C4C4C5C8CBCDCFC0C5CACDC6C8D5D0
CDCCC9CBD0CCCCD3CCCDC5D1D0D5CDD5D7D1D3D4D0D0D7DAD8CFCACCCECDCFD2CFCCC8CD
D0D4DCD3D5D3D7D2D2D5D0D0D0D3D8DBD0C5C3CACCCCCDCECECDD0D3D3D2D2D0CFCDCBC9
D1D0D2CBD4C9D5D0D3D5D5D5D6D6D2CAD2D6CFDACFD9D1D5CFCCBFCAC5D2CCD0D1CACBC7
D0CBCECACDD2D4CBD3CED9D0D3CECECED3D2CAD2D0DACAD9CAE0D4DDD7D4CBD1CAD8D2C9
C7CAD1CCCCC7C1C7CED6D7CDD6CBD4D1D7D3D6D2D1D3CED0CCD1C7D4C8D5CBD0C8C9D0D1
D0D6D1D6C9CECBD5D2D7D5D5D2CCD1C8D6C4D3CEDBD1DFCFD7D2D8D0D1DACCD9C7DDD2D7
CDDED0D7D2DCD5D9D3D6D1D5D1CAD4D8D9D7DBD3DDD0DCD6D9D6D0D2D1D6CBD4D1D5CED6
CAD3CDD2CECBC9D4CBD3D0D0CACAC5CBC5CACAD1D2CFD6C5C7BBCEBFC6C3D7C4CEC1CBCD
C2CFC2D6C4D2CED5C9C7C3CFBAC9BCC5C9CBD2D4D7D4CAD0CBCFD7D0E2D0D7CFD1CED2C9
D6CBD2D5D2D0CECDCDCCCBC9CFCFCAD2D1D8D3D2D1CED1D0D1CFCCDAD5D6D1D5D7D2D1C9
C4CBD1D3D3D5D4D2D1D9D4D7D4DAD4D7D5D2D8CFCFCDD5CFD4CBD3D1D4DCD5DEDAE2D8DC
D7D9D6D4DCDADED8DEDAE0E0DAE0DBDCE1DADAD8D4CFCCC2CACEDADBD4D3D9D7D8DCDCE1
D4DBD0DED7DFDBDAD4D2D4DADDDDDEDFD7D9D9DAE0D9DED9DCDCE5D4E0D9E1D8D7D6DAD7
D6DBDAE0D4DCD4E1DAE0E0E2E1DDDCD1CCD1D4DDD9DDDED6D8DBDFDCDDD8E5D7E6D7DFD8
DDDDDFE2DFDBDADDD7E0D7E2DBE2DDD8DCDBE0DADEDAE0E0D4D6DCDCDED9D9D6DAD6E6D5
E6D4E2DDDED8DEDDD9E4D2D8D5E2DBE4DDE2DFDFDFDCDFD8DCD8DFE0E0E0E3DCDDD7DAD9
DADBE1CDE2D0E2DCD9D8D9D9D8D5D8DDD5DFD3E2D8E7E2E2D9DCDAE0DEE5E4E7E0E5DEE2
E0E4DFE5DEDADBCCDBC2CCC7D8D5D9D6DED9DBD7D6DDD7E5DAE4DADDDDDDDBDDDEE0DFDE
DEDADCD8D9DDD8DBD7DDE1D5E2D4E0DCDEDCE1DBDFD9DEDDDEE4DDDFDBDDD8DFDFDEE4E0
E6E1E4E1E5DEE0DFDFE0DCE0E0E0E2E3E8DDE4E0
524E544C4F4C4E4F46534750474D4D484C48444B454D42474C4F464E414A424657504C44
434147484D4C4942454143464C4B4443444448484A4D4C4A474A4B4A4A4A4B494747484A
4A4C4252434E454F4A4F4E4F4E4E56595A515A56635669656E676D60695E6968627A7C6F
6C6A7979787F7488788B828E88939AA09C949695A7A3A69AA799A8A2A9A4B2AAB8B4B7B5
AEA69C9FAEB6B9BEBDC3BDC7B6C6BBC6C4C6C5C5C8C6C3C3C2BAC4B9C8C3CAC9C9C5C0C9
CBD0D0D4CECCCCCECBCFD2D2CFD0D6D6CECCCDCBD4D1CECED1D5D7D8CBD3D3D4D1CFD4D1
D3D0CACAD0D2D0D2D3D4CDCFD0D3CED0D8D2D0D0CCCDD2D3CFC7C0C0C6CBCBC9CED1CFD0
D0D3D9D0D7D1D3D1D2D4CED0CED1CED4C3BFB9C1D1D2D1CECDD0D3D4D7DCD0DDCDD9C9CB
C9D4C7D7C7D3D1D7D4D3D3D2D3D5D1CDD1CDD6CBD9CDD4D0D3CCD1C0CFC6D2CBD1CEC4D2
CBD4D0DACBDAC6DAC5DBCDCED0D0D2D0D5D6CFD5D8D1DBCDDAD0DACFDCC9D8C3E0CEDCC8
C1C8C5D3CAD4C4D1CADBC8DCC7DBD0D9D8D5D8D3D1D2CED1D6D0DBC9D7C5D1CAD5C8E0C3
E1C9D8CDD6CED4CEC8D7C8D5C9D2B5DBC0DDCAD4D4D3D8D9D0D8D1CFD4D3DDCBD8CFD8CD
DDD0E7CEDEC0DFCADAD0D9D4CFD0CADAD2DFC8E4C9E1D1D8DBDAD8D7D3D2C6CDD6D5DECD
D4C6D2D2D5CADCC3D8C1D4C7CAC9C4CAC4C8C7CEC9E0B4D3B7DDBFCDCACDCDD1C5CEC4CC
CBCAD8C5D4BBCEC6CEBFDBBCD1B2C8C1CDCDD2D2D6D5CCD1CFD9BBDAC6E0CBD1D0D5CAD9
CED8CAD2D6D7D7D5D3D0D0D0D9D0D8C7D8C9D4CDD4D1D3D2D3D1CDDAD4D5CFD3D6D3D2CA
C9CFD3D5D6D7D5D2CFD9D6D9D5DAD4D8D9D5DBD3D2CED3CDD9D1D7D5D7DBD4DBD8DDD6DC
D5DBDDD8DED9DBD7DFDCE0DDD7E3D4E5D6DED3D7D7D1CEC3CCD0DBDBD9D6DBD8D7DBD8DC
DCD8DED4E3D3E0D6DBD7D5D8DADBDCDFD7E3D2E8D4E3D9DFE0E1DADAD9E3DFDBD9D7DAD9
D8DEDBE0E3DCE6D2E8CFE2D6E0DDDBCECBD4D7DCDAE8D1E5C8E8D7E1D7DCD9E4DCE4DCDE
DEDDDEE1E0DDDCDEDEDBE8D4EAD2E1D0DDDBDED8DDDAE0E0D4E1D0EBCDE5D1DCD8DED6E4
D7E5DBE1DCE1D7DFD9D8D8D4DFDBEBD7EBD4E7D6E2E0E3DDE2DEE5E5E1E9DAE9D0E1D5DF
D8E4D3DED2DED9DED9DADCDCD8D5DAE0E3DFE7D5E8D5E5D7E6DDEAD6E9D7E6DFE1E5E0E4
E0E4DEE2E3ECD0E4C8D5C4CDD5D4D8D5DDD8DBD7DDDCE1DEE2DBDCD9E1DAE4D6E6DAE5DF
DEDADDDBDCDFDADCD6E9D2E8CEE4D5DDDEDCDFD9DDD8DDDCE1E5DDDEDADEDAE1E2E0E5E0
E6E0E2DFE5DEE0DFE0E1DDE2DFE6D8EDDEE8E0E5
4B5147544350434946524A51474C4D4B4B444C464C494B4F4C4B4D484B45474448494E4D
4A4A4D4A4A4A4C494D4B4F5057584F50504D54515058565C576361646B6E7273716F6E6F
6D606D657B6A7A7B7979818987868D8F8F8C879B919A99A19EA79AAA99AEA5AFA4BAB8AE
A7A5B3B6C4BDC7B8C8B9C5C0BFC7CDD1CFCAC9C7C6C9C1D0C4CFD0D0CFD1CED6CBD8CBD1
CAC8C3C4CDD0CFD2D1CDDCCAD8C7D4D1D6D6CECED7D7D1D1CDD6CBDAC9DDCED3D4CEC7C8
CACCCCCCCBCDCDD2CDD1CDCDCCCBCFD0CCCBCBC7CCCBCACCD0D2D0CED0D9D2D0D1CCCBC9
D1CFCBCACDD0D0CFCCCFC9C4CACDCBCBD9D1CFCECBCDD1D0CFCBC4C1C6CECFCAB1C3CCCE
CBCED6D1D9CFCFCED1D2CED3CFD3CAD3C1C8C4D1D3D6D4CFCFD3D4D3D1CDD0CBD3CDCDC7
CECBD4C6D8C6D9D2D7D4D6D4D5D7D3D2D0DBCBDFCCDFCDD7D1D3C3D2C3D7CDD4D4CED6CD
D8CBD4D3D1CDD9C7E0CDDECDD1D2D4D1D6DBD6DBD7DCC8E1C1DFCDD0D7D4C6DACBDED1D1
CFC9D3CAD7C9C7CBD7D6E1CBDFC7DACED8D5D8D3D0D2CFD4CEDAC8E1C4DDCAD6D2D7CBD9
CCDECED0CCD5CDD8D3D2D5D3D2C3D6C0E8C6DECCD1C9DFD0DDD0D8CFC6D8C7DEC4E7D4D9
D0E3C6D9C9D7C6D9DBD9CAD7D8CBD5D2DCD4E2C9E4C8DDCCD8D8DAD8D6D1C7CED0DCCCDD
C7DBCFDECFD6C8D5C3D8CCCDCDCBC5CBC6CACAD0D8C5CFC0D1C5DCC2D3C6D8C0D7C3CDC5
CBD4C6D8C7D2C9CCC4CAC3D3BFCBC2CDD4D1D1CDD2D5D0D6DBCBCBB7D3C3D7CAD4CBD7CB
E0CCD4CDD4D7D9D9D6D5D5D7D4D2D1CFD0D1D4D5D5D3D6D4D5D3CDD7D6D7D1D3D5D1CEC3
CAD3D9D7D3D1D1D0CEDAD8DBD6DBD5D9DBD6DCD6D6D0D4CDDFD7DAD8D9DBD6DBDEE0D9DE
D3D8DBD4DEDADCD7DEDADFDCD9DCDDD9DDD2D9D5D8D2D0C6CED1DAD8D5D2D7D6D9DEDCE0
DCE5D3E5D2DED4D7E0DBD8D8D9D9DADDDCDCE2DAE5D7E4DEE2DBE3D1E5DBE6DBDDDBDADC
D9E2DBDFDBE4CFE6D1E2D5D9D8D9DAD0D0DBDCDEE0DBE4D0E0D6E5DFE0D8E9D4EBD4E3D9
DFDDDDE0E1DEDEE0D6E5D3E9D4E7D9DBE1DEE0DADFDADFDDDED9E5D5E4D4E2DDDDD2E6CE
EDD5E9DDE2DAE3DCD5E3D0DCD5DFD3EED7EEE4E1E0DEE2DCE2DEE4E3E4E1E8D9E1D5E0E0
DED9E9CEEBD0E7D9DEDDDEDFDDDBDEE3DCE9D4EAD3E8DBDEE0E4DCE7DBE6DEE3E0E3E0E5
E1E4DEE0E3D9E5C8E2C0D5C7D9D8DDD9DFDADDDADDE5DAE9D6E3D4DADFE1DBE0DBE2E0E3
E0DCE0DDDEE0DBDCDADDE1D7E1D5E1DADFDDE0DADED9DDDCDFE4DEE2DEE1DADFE2E0E5E1
E6E0E3E0E5DEE0DFE0E2DFE4E0E1DCE3E4E2E5E5
5250544F564F534F5259545750565B5D5C58605B5B57575D58575C595F5A5D5A5B595C60
616C6F676871697B6A7C737B8085818688878E8C918F9E90A298A6A0A4A4A3A3A5AAB1B6
A5A496AEA2B3ABB9B4AFB9C1BDBCC1C2C8BCC7C4CCBFC8C8CDC8D6C3D4C2CFC8D4DED8D4
CEC8D0D8CED5CBDCD0E2D9E0D6D5D7D8D9D8D5D4D7D2DBD8DED5E4D8DDD6E2D3DDD4D7D6
CDCECACBD4D6D2D1D3DDD2E1CCD9CDD4CFD5D3D1D5D2CED3CBCBDAC8DACBD7CAD5CFCBCA
CDCED0D1C9CDC9CFC8CCC5C7D0CBCCD0D0D2D1CACECDCDD0D4D5D3D0CFD8CFCED4D1D0CF
C9CACBCCCCCFD2D1C7CBC6C3CAD1D1D0D3CDCBCAC8CDD0CDCFD0CCC6C6CCCFCDAFC3CBCD
CCCDD4D2D6CDCECFD2D4CFD4D9D4DACCCFC1CCCFD3D6D5D2D1D4D3D0D3D7C9DACCDCCFD3
D3D8C4D7C8D6CCCED7D3D7D5D6D9D2D5CFD0D5CAD9CED2D1DCCACEC2D7C5D1CCD0D9D2D9
CAD5CED1CDD9C5DECCE0D1D1D5D4D3CED4D9D4DAD6D1E3D2DCD0E3D9D8C7DCC4DFC6DDD0
C6C9C6D2CFDBCFDBCDDDCDE5CEE2D7D9D6D4D7D3D1D3D2D6D9D3DFCDDBCAD5D0D8CEDEC3
E0C9DAC8D8CFD9D2CCDED0E1CBD7BCE3C7E3CED8D6D1D3D7CFD9D4D8D2D0DDC8DACFDCD0
DEC6DEC5DFC0E3CBDDCED6D3D5D8CBD5CEDEC7E3CBE6D6D9DDDADAD2D2CECAD4D8D6D7C9
D7CCD2D2DCCFDDBDDCC4D3C1CFCCC5CBC6CDCCD3C8DCBED3CADCC8D3CFD2CDD3C4CFC2CA
C7C8CBC8D1C9D4CFCAC2CFC2D6C2CFCAD5D3D2CDD2D6D1D6D5D6C4D3C9D5D0CFD5D5C5D8
C9DACFD6CFD1D4D4D3D3D3D5D2D2D3D1D2D2D5D6D0D1D5D5D8D7D1D8D2D7D3D7D9D7D4C7
C9D2D8D6D2D0D0CFCFDBD9DCD8DCD7DBDBD5DCD8D9D3D7D1DCD5D6D6D8DBDAE0DDDFD9DE
D3D9DCD5DCDADED8DCD8DEDEDCE5D5E6D1DDD6DAD5D0CFC6D0D2D9D6DCD8DBD8D8DBD8DA
DCD8E0D2E2CFDFD6DDD9D7D9DBDBDCDFDBE8D5EDD5E6DBE3DDE1DDE1DBE2DEDFE0DEDBDF
DAE3DADDE1DAE4D3E9D0E0D2D8DADCD2D3DFE1E2DBE6D1E8CEEBDAE4D9DDD6E2D9E7E1E8
E1DEDEE0E1DFDFE1E3DFE9D4E7D0E2D4E1DFE2DDE2DDE0DDD8E5D3EDD1E9D5E0DBE0D3E5
D7E9DCE2DDE4D8E0DAD9DCDADFD8E9DAEDD9EBD6E1DFE3DFE5E1E5E3DFE8D8EBD1E6D9E5
D9E5D7E9D7E5DBDAE2DDDBDEE1E1E1E2E2DDE7D2EAD3E6D7DDD5E8D6EEDAEAE1DFE1E0E7
E0E5E0E0D8E5CDE9CADFCDD2DDDCE1DCE1DBDDDBDADBE1DCE1DADEDCE1DAE5D5E6D8E6E1
E3DFE2DFDFE1DBDCDAE4D8E4D5E0DCDCE0DEE2DDE3DDE0DDDEE4DFE4E1E4DBDFE1DFE5E1
E7E1E4E2E6DFE0DFE1E4E1E6DFDFDAE1E3E1E5E4
6E6A72677969786F70798088898D8F9194958D96859690A19398929E939D9497A5A7A9A8
A0ADB2ABADA2BBA1BBA2BBB1B8BDBFC4C6C6CAC9B8C4B9CDBAD2C6CDC0C1C3C6C9CBCDCE
D0C2C9BFD1C3CDCAD3CAD0D1CBCDCFD3D2CFCCDBCAD5CBD2CED4CFDCCFD8CFD4DDDBD4D6
CFCAC8D7D8D2DECDE1D3DFD6E0DADAD7DADDD8D9D6DBD2E2CFD7D1CDD4D5D3D8CEDAD1D8
D2CDC3C3D0D5CFCAD4D2DBCFDBC9D4CCCCD0D2D3D4D0CBCAC8D5CEDBD0DAD3D2D0C9C9C8
CDCAD0D3CDD2C9D0CBD4CFD6D0C9C9CDCFD1CFC7CFCDCBCBCED1D1D1CAD2CACAD1D0D0CE
C3C2C6CBCBCED2D3CCD0C8C7CAD2CECFCDC9C9C8C7CCD0CBCDD0CFC8C6C9CDCDC8D2CFCF
D1D1D4D0D3CED2D2D4D6CFD1C3D2C3DBBBD0C0CFD2D4D4D3D3D3D1CDD1CDCECAD0CDD0CD
D5CDCFC6DACDD9CDD5CFD6D3D3D7D0D6CBD9C6DAC8DCC7D5CDC6B7CDC7D6CDD7D0D2D9CA
D2CED9D5D5CFDAC8E2CADACAD2CECCCAD2D7D4DAD4E0D1E9CFE9D6DAD1D4CDDAC8D7D1D3
C8C5D3C8DDD6DBDDD6D2E3D2E6D0E3D2D6D3D6D1D1D5D3D7D0DBC9E3C8E3D0DCCBD7C8D8
CADDD4D4D4DDD6DFD7D6D7D6DBC9D7BDE0C0DCCEDBCCDCCFDCD0D8D2CFDAC8DEC6E1D1D9
CDDEC7DBD5E3D1D9D2D9D2DAD8CED7D2D5D1E2C9E6CEE4D2DDD9DBD2D3CDC9D0CDD8C0D5
C8DFCAD7D2D7C8D3CBD9CBCDCFCCC5CBC8CECDD3D6CFD6D5D1C9D5C6CFCAE1C8D3BFCCCC
C5CBCBCBC8C3CACBCECDC8CBD2CBCAC7D1D3D6D2D6D8CFD2D1D0CED3D4D4D9D3D7CBD4CB
DBCFDAD4D4D4D4D4D5D5D4D3D7D1DCCCDBCBD7D1D2D3D7D6D9D9D1D6CED6D4D7D7D5D2C5
C9CED3D4D5D7D5D1D2DCD9DCD9DFD9DDDBD4DAD9DBD5DAD5DBD5D3D4D6D7D8DCD6DBD5DD
D7DDE0DCDCDBE0D9DCD7DEDEDDDCDCDADAD3DCD6D2CDCDC6D1D4DBD7D7D5DAD8DADEDDE1
DAE2D4E2D2DBD5D9DEDAD8DADCDBDCDEDFDFE3DEE6DAE4DEDEDBE8D9E6D7E3DEE1E0DCE2
DAE5D9DED9E5D2ECD6E8D9DEE0DFDFD4D3DDE0E5DFD8E3D3E7D9E7E0E3DAE7D3E7D7E7E1
E3E0DFE1E0DEE0E3DAE8D4E9D2E7DCE1DEDDE3DEE4DFE3E1DED6E1D0E2D4E3DDE1D6E7D0
ECD6E8DDDFD7DFDBD5E4D2DDD6E4D4EED9EDDFDEE5E2E6E2E9E4E8E4E0DDE4DBE4DBE3E1
DDD7E8D4EBD2E6D2E1DBD8DCE0E1E0E0D9E4D3E7D5E8DEE0DEE3DEE8DEE5DCDEDFE0E0E7
DFE5E1E0DDD7E8D5EAD0E3D1DEDDE3DDE1DADDDADAE2DAE8D6E2D8DFDEE0DDE1DCE1E0E3
E4E0E2DFDFE2DDDEE0E5DDE3D8DDDDD8E1DFE3DFE6E0E3DFE1E5DEE2E1E5DEE2E0DFE4E1
E7E2E6E3E6DFE0DFE1E5E3E8DEE3D3E8DBE8E0E5
A7B09EB2A2AEA5A7A0A8B4BEC2C3C1C1CDC6CBC0C0BBC0C8C9C5CEC4CEC2C8C3CACCC8BF
ADBFCECFC2C9C4D8C3D6CED4D3D4D9D9D8D8D6D8D9D5E2CFDECEDAD1D6D3D0D0D2D4D5D4
D0D0C8D5D1DBD1D2D2CCD2D1D0D7D8DED6CED5D3D1D3D2D3D9D1DDD2DFCCD6D5DFD7D6D6
D0D0C6DAD7DAD7DAD8E0DCDADDD8DBD7D7DBD7DAD4D6D6DADAD6DBD5D9D4DDD3D8D6D9DB
D5D0C4C0CCD3D0CDCDD5CBD8CFD3CDCBCFCED1D4D4D5D5D1CCCDD7CDDAC8D6CCD2C9CBCA
CEC5CCD3BEC8C4D1CED7CDD4CFCBCDD0CECFCFCBD1CFCCCACBCDCFD0CCD2CED0D3D2D4CF
CEC6C8CFCFD0D4D4CFD3C7CBC8D0C8CCCFCECFCECCD2D5D0D2D3D2CFCDCED0D1CAD0CACB
D1CFD1D0D6D3D6D1D1D5D1D2C7CAD8CACEBFC9C9D2D0D0D2D3D1CECDD3D7CEDACEDAD0D4
D0D3C6D3CED7D4D3D6CDD4D0D0D5CFD9D4DBD6D5DBD9D4DACFC4C7C2D0CAD3D3D0D4D0D4
CCD4D4DADADED3DDD6D9D4D2D2CAC9CBD6D9D4DCDED9D9D2E1DDDAD0D3CCDCCADBCEDBCA
C6CED4D3D8E0D9DCD2D9D4E0D6DEDDD7D8D3D4D0D1D5D2D5D9D7D8D5D8D5D6D4D1D5DACB
D7CCDBCFD5D2DAD7D0DDD2DFD0CEB8CDC8D9D4D7D7CED4D9D7D9D2D0D9D4D8D2D9D0D5D3
DAD3E3D0E0CDE1CBD3D3DCD7D6D9D0D2CAD8D0DCD2E0DDDBD5D2D8D2D8D1CCD1D3D6CFCD
D6D5CFD3D7D1DBC8DCC6CFCCD2D0CAD1CDD2CED2CBD6CFD3D5D1CED2D0D2D6D5CBCFC9D0
C9D1CED5CECED0D1CACBC8CBD6CDCFCDCED3D8D4D6D7CFD1D0D1CAD7D0D7D9D5D4D2CEDE
D3DCD5D5DCD8D5D6DADBD9D5D3D4D0D5D1D8D5D7D6D7D9D5D9DAD3D8D3DCD9D6D2CDCABD
C9D0D6D8D8DAD9D7D5DDD9DCDBE1DCDFDCD3D9D9DCD6DBD7DDD9D5D7D7D6D8D9D7E0D7DC
D9DDDBDADFDCDED8DEDADEDCD8DCD3E3D3DBD7D4D7D1CEC5CFD3DAD7DBDADFDBD9DCDADE
DEDDDFD7DFD2DED9DFDBD8DADBDBDDE0DDE6D8EADBE6DDDEDEE0E0E1DEDEDDDEDEDFDCE3
DAE6DAE0E2E2E4DEE3D6DED8E3E0E1D9D5DADCE4DEE1D6E3D7E6DDE2DFE0DCE0DCE3E2E6
E4E2E1E1DFDDDFE4E0E3E5DDE2D9E3DBDEDEE3DDE2DDE2E2DFDFD0DBD0E2DDE4E0E2DBE1
DAE2DDE0DEE0D8DFDBDEDBDADBE0E4DEE9DDE1D8E0DDE1DDE4DFE1DDDCE2D8E8DAE7DADE
DDE2DBE5DAE1DFD7E0DCDADDE0E0E0E2E2E1E5D9E6D9E4D9E0DBE8DCECDDE7E0E2E1E0E7
DEE4E1DFD7E1D6E7D1DDD3CDDEDEE4DEE2DBDEDDDFE2E4E2DFDCDDDEE0DDE6DBE6DBE5E2
E3DEE1DEDFE3E0E2E2E3E0E2DCDCE1D8E2DFE3DFE6E2E5E2E2E6DEE3E2E6DFE3E0DFE5E1
E7E2E6E3E6DFE0DFE2E5E4EAE1DEDDDFE8E0E6E2
D3CED2C5D4BECBBECECFD3D3D3D3D2D5D8D6D0D3C5D2CEDECED0CFD4D1D5D1D2D1D4D3CE
BBC9CCC3CBC7DAD0D8C7D2C9D9D8DFDBD9DAD4D8D0D7D5DAD3DBD7D8D7D5D4D6D9D9D6D2
CFCDCFCFD7D4D1C8D0CFD5D1D2D8D3D8DCD8D7D8CBD7CFD2CFCACDD1D4CFD4DBDDD7DAD8
D0D6C9E0D6D4DBD1DCD7DCD4D5D3DAD6D4D8D4DAD2D9D0DBD4D9D6D6DAD8D9D5D0D4CFD5
CFD0C9C4CCD3D6D8D2D5D3D6DCD4D8CFD5D3D7D2C5C5CDD0D2D7D5D6D5CACFCBD3CACDCD
D0C4CBD4C4CDC4CFCBD6CED7CECED3D4CFCFD3D2D1D1CFCECCCCCDCECAD0D0D4D6D6D9D2
D9C9C6CDCECECECDCBCFC3CECAD6CCD3CBCBCDCCC9CED1CCCFCDCCCCCCCCCCCDCED6D2D3
D4CCCCCEDDD9D7CCCAD2D3D6C5D1CDD5C1CAC7D2D2CECDD1D2CFCCCDCFD2D2D7D4D7D4D4
D7D7D3D0D2CBD1CDD9CED5CFCFD6D0DDCDDACBD7D0DACBD7CBCDC9CBC9D2D5D9D5D2D4D5
D5CFD1D6D7D4D6D0DBCDD6CEDAD0CDD0DADAD1D8DBE1D2D7D6E3D8DDD1D2D5D4D6DBD7C7
C5CDDCD0DEDFDEDADCD9DFD7DCD1DCCEDAD4D4D0D0D4D1D3D6DBCFDECFDFD2D7C9D7D2D5
CFD6DCD9D5D8D9DBD1D5CFD3D6C6C2C0D9D0D9CCDACAD2CED8D5D8D5D3D4CEDCD3D9D2DA
CEDAD7D2D3D5DBD8D4D8D6D7DADAD5C9CCD3DBD0DCD4E1D6E0D9DACED3CBC8CED1DDCED9
D4E0D0DDCFD4D5D4D4CBCBD5D6D4D0D8D3D6D0D2D4D5D3D5D1CBCFC9D9CFD6CCD8D3D1CC
CECFCDD0D5CFD0C8CDD0CDCCD7C8CCCAD0D5D8D2D3D6CFD3D2D4CBDED2DDD8D1DDD3D5D5
D7D5DCDADCD6D1D3D9DDDAD5DCD5D9CED8CED5D1D4D5D7D4DADFDBE1CCD7D7D7D6D6D7CE
C9D6DFDED8D7DADDD7DED9DCDBE3DDE0DDD4D9D8DCD6DCD8DAD8D6DBDDDCDEDFD0DDD4DB
DCE0DEE0E2DCDBD7E0DDDFDADBDCDAE4DEDEDED5DFD7D0C5CED0D8D4D9D9DFDBDADDDCE2
D7DCD7DEDADCE1E2DAD6D4D7DCDFE3E8DEE2DDE3E3E1E0DBE2DDE2DBE3DBDFDBDCDEDBE4
DAE8DCE3D8E0D6E2D7DFDDE1DFDDE2DED9DAD9E1E2DDDED9E0DDE1DFE4E0E5DBE4DBE2DF
E5E3E3E2DFDCDFE5DBE6DDE7DCE3E0E0E1E0E4DCDED9E0E1DED9DAD7E1E0E3E0E3DEE4D9
E3D9E1DDE4DFDFE1DDE6D9DCD2E3D9E5E1E8DEDFE1DFE3DFE6E0E2DDDEDEDEE2E2E2DCD9
E4E0E4DDE4DCE8D9E0DEDFE1E1E0E2E7DAE1DAE1E0E6E7E3E1E1E3E2E5E3E5E4E4E2E1E8
DDE2E0DEE0E0E4DEDCD3D8C9DFDFE6E1E5DEE2E1DCE2E0E7DDE4E0E5E0E0E4E2E4E0E4E4
E1DDDFDDDFE4E2E5DFE3DCE5DAE2E3DCE3DFE2DDE5E2E7E4E0E5E0E5E5E8DFE1E1E0E5E1
E7E2E5E2E6DFE0E0E2E6E5EBE1E3D8E8E2E7E2E3
D8E0D8D6D3DBD3D2D0D5D7D5D5D8DAD9DADDD4D2CDDAD6D3D0D1D7D3D7D0D3D1D1D5D5D3
CED9CFCDC9CFCFD4D4D0D3D0D3D4DBDAD9DBD7DAD4D7D2D3D6D7DCD7DAD4D7D6D5D4D0D6
C7D0CFD7D5D3C9D1CED3DCCFD7D6D5D9CFD4D4DAD3D6D2D4CFD1D8D5D8D7DDE2E0D4D0CD
D0D5D4DAD2D9D8DAE2DBDDDBD9E0D7D1DADBD5D8D3DBD5D8D4D6D8D5D7D4DAD4DDD6D3D9
D2CECAC5CCC8CDD5D1D5D9D1D9CFD9D0CBD1DCD9D3D4D6E1CDD6CDD1C9CED0CECFCECECB
C9D2CCCCC4C5CAC6D0D1D1C9D1CCD9CAD8C9D5D0D5D0D4D3D3D3CFD5CCD5D0D9D5DAD9D5
D4D4D2CFCDCED1D4CED2CDC8CFD4CEC8D1C8D3C9DCCDD8D4D3D3D1D3CED0C6D0C5D4CDD8
D3DACCD5D2CFD9D2D7D4D4D5C9D4D6CCCDBFC8CDD3C9D0CEDACCD2D1D7D1CFD8D2D9D2DF
CDDBCFD7CAD3D3D9D4D9D4D8D6D0D5D2D9D5D7DAD5D6D6D2D7C8D3C5D1CDDECDD6D9D8D9
CFCDC7DBCDD9D7DCD4D6D8D6D0D2DAD7D4D6D7DFDCDCD9D7D2D2D0D2DAD6DACDDFD0DACB
CECCCFD9DAE3DCE3D8DED9DBD8D8D8D3CFD2D3D2CFCFD1D4D8D7D5D6D7D7D5D3D0D2DAD6
DAD3D8D7D9D4D9DAD7D6D6E2CCD0C6D5D9D8D6DED4D3D8D3D8D3DADAD3D4D1D9D6DBD3D1
D7D4DBD0DBD5DCD4D9D7DBD7D5D7D1D2CEDADBDCD8D6DEDED4D6D7D2D3C9C0D0D3DBD5DC
D3D2D2D2D6D3D7D1D7D2D7D5D8D7D3D5D6D4D3CFCBD2D4D1D3CED5D1DADBDFD4D3CCD2D2
CCD2D1DCD0D2C9CFC8D0CFD2CDCAC8D4D6D4D4D7D7D4D4D6D2D9DCCFD8C8D5D8D6D1D6D3
D9D4DADCD7D8D3E2D4E3D5E0DAD7D7D4D7D7DBDCD7D4DADADADBD8DFD9D7DADBDCD4D9CF
CDCBD5D2DAD0D9DBD3D9D4E0D6E0DBE0D4DFD8E0CEC8D4D2D5D1D7D8D7D7D6E0DBDAE2D9
DCD2E2D8E4DDE4D9E0DCDEDFD6E2DBE8D3E1DCE8D6D8CECCC8D9DCDFDDD8DDDEDEDED9DE
DADEE5DDE7DBE3D6DEDAE1DAE1E2E5E7E1E5DFE7DCE4DFE4E0DEDFDFE4E2E0DCDEE1DCE3
DFE4E2E4DDE2E4DFECDEE3DEE2DEE6DCDFDDE1E6DCD8D5E3E1E2DBDFE1E1E7E2E8E4E5DE
DBE1E0E6DFE3E1E5E0E5E3E3E4E0E4DDE2DDE4DCE2E0E1E2DDDEDDE5E0E4E2E9E0E6E5D8
E4E4E6E3DDDCE2E0E1E3DEE1DEE2E1E5E3DDDFDDE4DBE5E4E9E0E1E8D8E3DCDFE0E3DCE7
DAE1E0E4E2DEE3E2E5E3E2DEE2E6DFE4DFE2DFE3E5E3E6E3E3E2E7E2E9E4E9E8E2E3E5E7
E0E7E1E7D9E8E4DDE1D6D5D8E2E1E7E4E2E4E1E5DEE1DEE4DFE3DDDEE3E0E0DCDEDCE0E0
E1DDE1DEDEE2E0E3E3E3DADDDCDDDFDDE2E3E9DFE5E1E8E4DCDEDBE7DFE4E0E7DCE3E0E7
E2E2E4E3E5E2E4E1E2E6E4E8E2E3E2E2E9E2E8E2
D9E1D8D6D4DBD2D0D7DADAD6D5D9DDDDCFD6D4D6D0D8D4D3D3D2D7D1D5D0D4D3D7D9D4CD
C3D0CBCECAD0D0D6D6D3D6D4D6D6DCDAD9DBD8DBD5D9D5D5D7D7DBD6DAD4D7D7D7D7D2D7
CCCFCBD1CCCECAD1D0D3DBD0D7D4D4D9D2D6D5DBD4D7D2D4D2D0DBD0DCD3E0E0DBD5D5D1
D0D3D4DCD5DFD4E0DADDD4D6D6D2C0BCCFDBDADDD6D8DBD2DAD0DCD4D9D5DBD4DCD5D1D6
D0D3C8D1CBD3CBD5D2D9D4D9D5D8D9D6D3D3DAD7D6D9D7DBD8D6DCCBDACADAD0D6CFD3C5
CDCFD3D3C7CAC0D1CAD8CED1CBCECED3D2D6D5D8D2D0D5D3D1D1D0D9D1D1DACDDFD0DFD4
D8D5D2D2D3D3D3D2C8D6C3D3C5E0CFD5CFCDCBD2D2D3D1D4D2D2D0D2CED1C8D4D4CDDED7
DACFDAD0D4D1DBD3D8D5D5D6CDDAC9D7C4CFC9D3CCCBC7D5D1D7D2D8D5CFD6DADCD9D5DB
D7D2D9D0D5CCDED1D9DDD8DAD8D4D9D6D2D7CEE3CEE0D4D6D5CFCCCFCCD9DDD7DBD4D4DB
D2D2C5C9D6D7DFD3DFD1DCD1D4D5DBD8D5D8D7DDD7DDD1DECDDAD0D8D4D5D0D2D6D5D6CC
CDD1D8DDD3D7D4E0D9DCDDD7DCD4DBD2D2D4D5D4D2D2D5D8D6D4D4D5D7D9DAD9D0D1D9D6
DBD7DDDEDBD5D9DAD8D7D6E1D1CEC2D2D7DAD8DADCD9DBD3D7D4DDDFD6D7D2D9D7DCD5D4
D2D6D3D7D3DAD5D3D5D2D8D7D8DBD8DCD8DFDCDBDAD8DCD8D6D8D8D2D0C5BAC7D0D8D3DB
D3D4D5D7CFCDD3CFD7D4D9D8D6D4D2D3D5D4D2CFCCD7CFD9CDD5D3D3D7D4DAD5D4C9CED1
D3D2D7D4D4CBCDCED4D3D7C9D0C1CAD1DAD7D6D7D6D4D4D7CEDAD3DCD2D5D6DCDAD5D9D7
DDD7DDDEDED9DCDBDBDCD9DEDED7E0D1E0D3DFDAD9D6DBDBDADAD7DDD4D9D0E4D6E1DBD7
CFD2D7DCDBD9D9DEDAD9E0D9E0D7DCD9DBDBE0DAE1CCE0D2D7D5DBDAD9DCDBE2D1DAD7E2
D8E1E3E0E3E0E2E0DFE3DFE3DFE1E5DFDCD7DCDFDED6DAC2D4D0E3DDDDD9DEDEDEDFDADF
D4DFDAE6E0E6E3DFDEDAE3DDE6E6E8EADFDFE5E2E6E0E1DFE7DFE9DCEDDEE5DBE2E4E0E5
DFE3DFE0DAE4DDE6E5E5E1E2E4DFE5DBDFDEE2E6E4E0DDEAE8E9E2E6E2E2E7E1E8E4E6DF
E1E3DFE5E1E5E0E1DBE4DDE6E0E6E5E2E2DDE4DCE1DFE0E1DCDEDBE4DEE2E0E6E1E4E4DA
E4E3E4E1E1DFE4E1E1E2DEE0DCE2E0E3E1DEE1DEE3DCE6E2E7E0E0E5DBE4DEE2E1E3DCE3
DFE4E3E5E3DDDFDCE4E2E2DDE1E4DDE2DEE3E1E6E6E2E5E2E4E2E6E2E7E3E7E5E4E4E6E7
E0E7E0E6D4E5DDE2DCDDD9DDE2E0E5E3E2E5E1E4E1E4E1E7E1E5E0E2DFDAE3D8E5DBE4E0
DDDADEDBDCE0DEE2DEE6D6E8DAE5DCDDDBDFE0E0E0E5E6E5DEDEE0E1E1DEE1E5DEDDE2DC
E7DCE9E3E6E2E5E2E3E7E5E9DFE7D9EBE0ECE7E9
DBE1D8D8D6DCD1CED0D5D8D8D7D7D5D3C9D0D2D8D1D6D3D6D6D4D7D0D4CFD5D5D5D6D2CB
C2CFCDD4CBD1D1D7D8D6DAD8D9D8DCD9D9DBD8DBD5DBD8D8D8D6DAD6D9D3D6D6D8DAD5D8
D5D3D0D6CED1D1D5D4D2D9D1D7D2D3D9D5D9D6DCD4D7D1D3D3D6D3D6D1D7D9DDD7D5DAD5
D0D1D3DEDAD9DED3E5D1D9D0DBD2C0BCCFDCDBDDD6E1D2DECEDAD5D7DBD5DBD4DAD2CFD3
D6CFD3C8DACED6D5DED9E2CFE2CEDFD2D9D7DBD9D9DBD7DAD1DDC7DFC8E0D3D9D5D5D1D5
CDDBD1D6D0C3CEC6DDCEDAD5D9CEE1C6E2C7DACED1D0D7D4D0D0D2DDD0DECAE1CAE0D3D8
DBD7D3D4D8D9D5D1D4D1D9C0D7CAD6CED9CBDDC3DFC2D4C9D2D2CFD0CDD3CBD8CCDECDE6
CCE3CEDDD6D3DCD4D9D5D6D7DACFD9C5D7BFD4C8D9CDDDC5DDC4D4CBD6D5CFE0D1E0D1DE
D2E7C8DFCCE2CBD6D8DBD8D9D7D3D7D5D7D1DFD4DFD0D8CED8CADCC2E1CCE1D1D2C8CDDB
D7DDD4D2D3DECDE3D2E3D7D8D9D7DBD8D7DAD7DCDBD8DED3DAD0D6D4DAD3DDC9E4CEDFCD
CDD4DCDED0D1CEDCD9E2D6DFD4DBD7D4D7D8D8D7D5D5D9DCDBD8D6D6D7D9DADADAD9DED7
DBD5DBDCDDD6D9D9D9D9D6DED2CCC2D3D4D9DAD9DAD9DFDADED7DBD9D8D8D2D8D4DAD5D6
D4D0DCCDDFD1DAD0DCD5D9DADAD9D6DCD8DBD6D9DDDEE2DBDADADAD4D1C5BAC6D2D9D3DB
D3D5D7D8DAD8DBD4D7CFD0CCD5D3D3D4D6D7D4D2D3D5DED0DBCAD7CED6D1D7D7D8C9CED4
D2D8CADDC7D7CCD9D4DACDD4C4CCC8D8DFDBD8D8D7D4D5D8D7D2E3D1E4CBE1D5DDD8DBD9
DFD9DEDEE0E3D4E8D0E6D2E0D8DCD7E0D9E3DEE2E1DDE1E0DEDEDBE1E0D7E2D4E5D0DECB
D2D0E1D7E6D5DFDBDBE6D6ECD0E5D1DADAE1D0E9D8E4DCD6DBDADEDADADFDCDFDDD9E9D6
E9D2E5D3E2DAE9D8E8DDE5E2DDE9D6EECEE7D4E1DBE2CCD9C3E0D5DBDEDADEDFDFDFDBE0
E1DEECD9EFD5E6D6DFDBE4DFE7E5E6E8DCE5D9EDDAEDDCE2E5E7E0E9E1E9DFE0E4E6E2E6
DFE4DEE0E4E3EBDDEFD8E4DAE5DFE4DADFDEE2E5E4E2DFEAE7E9E2E5E4E4E8E1E8E5E7E1
E6E6E0E6E2E8E1DFE3E5E8DFE8DCE5DCE4DEE5DDE2DFE0E0DCDDDBE2DDE0DDE3E3E2E4DD
E6E1E2E0E6E3E6E2E1E3DEE0DCE4E2E1DFDFE3DDE2DEE7E0E4E0E0E2DFE4E1E6E1E3DDE0
DCE1E1E6E6E1E3DFE4E2E1DDE0E1DBE1DEE4E4E8E6E2E5E3E5E2E6E1E7E2E5E3E7E7E7E8
E1E7DFE5E1E7EADDE2D2DAD3E2E0E4E2E3E6E1E3E0E2DEE3DDE2DEE0DCDFDDE2DFE4E1E2
DFDBDFDDDEE3E1E5E3E2E4DFE9DEE6DFE7E2ECDCEBDDE6DDE2E8DFEDDBE8E0EAE5EBDBE7
DAE2DCDEE7E3E7E4E4E8E6EAE6E1E8DCEEDCECE2
DCE0D7D9D8DDD1CED2D6DADDDDDBD8D5CFD0CDD4D0D6D6DBD8D5D8D1D5D0D6D6D3D4D3D1
CBD6CFD1CCD2D2D8D9D6DBD9DBD8DBD8D7DAD7DAD2DAD8D9D8D6DAD6D8D2D4D3D7DCD7D9
D1CECED8CED2D0D0D7D1D9D3D8D2D3D9D7DAD6DBD4D6D0D1D5D0DCCFE0D6ECE3D6D4D9D4
CFD0D2DED5E1CFE2D6E1D3D7DADAD4D2DADBD7D8D9D8E1D0DFCDDDD2DBD5DBD4D8D2D0D3
D7DCC4D6C8DFD1DED9E0D2DFD4DEDBDDD9D9E0DCD9DAD8DDDCD2E0C6E4C7DFCFD7D0DCD0
DDD5D8D5D0D6C1E0CAE5D2DCD5DACDDDCEDED2D7D5D2D7D4D2D3D4DDD7D1E2C8E5CAE2D1
DAD7D5D6D9DAD8D5CEDDBEDBC0E5CBD7D1D6CBDACAD9CDD3D4D3CFD1CDD3CDDADCC8E7D1
DCC4E1CDD8D4DDD4D8D5D5D7CFD9C1E6C0DCCBD3CED5C9D9C9DCD2D8D2CDDAD9E0D8D5D5
DECEE4CFE2CAE7CCD7D9D9D9D7D5D5D5D5E1D0EBCAE0C7CFC8CFC5D9D1E3D4D8DED9DADF
D4D8D2D7DCD6E3CFE6CCDECFDBD6D9D6D8DCD8DBD3DDCEE3CCE2D3DEDDE2D4DED4DCD5D0
D1D2D7DCD3D7CFD8DCDCE0D4DFD2DDD3DADADAD8D6D6D8DBDEDCD9D7D7D9DBDCD9D7DCD6
DBD8E0E1DFD8DADADADBD7DCCFCDCAD8D2D6DCDBDCD9DCD5DAD6DCDBD7D7D1D5D1D7D4D5
D7D7D8D7DADAD9D6E2D9DBDBD9D6D2DADCDED8D9DBDDE0DADEDCDDD8D5CCC3CED8DED6DC
D3D4D5D5DBDADED8DCD4D5D1D7D3D5D5D8DBD7D6C7D8CDE0CEDDD5D8D8D4DAD9DBD0D4D9
D7D1D8CDD8CCD7D8D7CFDDC6D8C1D5D5DFDCDADBDAD7D8DBD2DBCEE9D0E4DDDFDDD8DBD9
DFD9DDDCE1D8E3D8E2D9DCDDE0D8E9D4EBD5E4DAE5E0E4E2DFDFDBE1D9E0CDE6CFE4D4D1
CFD5D6DFD9DDD8DAE0DAE7D6E6D4E1DADBCEDECEECD2E8D2DDDDDFD8D8DEDAD9D2E1D2EB
D7EBDFE1DDDDDEE1DCE4DCE1E8E0E9D7E4D3DDD7E0D1E0B8DBC6E3D4E0DBDFDFDFE0DCE1
DCE9D8EFD9EADCE0E2DCE4DEE4E0E0E3E4DFE6DAE8E0E9E3E4DBEBD7F0DCEAE0E6E5E2E4
DEE6E0E5DEE9DBEEDEE9DFE2E7DFE3D9DFDFE2E4E2E1DEE7E4E6E0E3E6E5E8E1E8E5E9E3
E7E8E2E7E3E8E2E2DFE9DEEADFE9E5E4E6E1E8DFE3E1E1E2DDDEDBE3DDDFDDE2E5E2E4E0
E7E1E3E1EAE5E7E3E2E4DFE1DFE8E5E1DFE0E4DCE4E1E9DFE3E1E1E1E2E4E2E7E0E4E0E1
E4E7E4E7E6E1E2DDE5E2E2DEE1E1DAE2DEE4E4E8E6E2E7E6E5E2E6E1E8E3E7E4EAE9E8E8
E1E8DFE4E0EBE1EAD8DEDAD8E3E0E3E2E4E7E2E3E6E8E3E7E1E6E3E5E4DEEADBECDCE7E1
E0DDE1DEDFE4E2E6E3EDD6EDD6E9DEE5E3E5E1E8E4EBE6E6E4E4EBE5E8E1E8E9E8E0E9D7
EED8EBDFE7E4E8E5E5E9E6EADBE8D2F1D9F1E1E8
DCE0D7DADADFD3D1D8D6D6D7D8DADBDDD8D5CDD4D2DBD8DAD8D6DAD4D8D2D6D5D7D5D3D4
D0D7CAC8CED3D3D8D8D6DAD8DCD8DAD6D6D9D6D9D0D7D7D9D8D7DBD6D9D3D4D1D4DBD8D9
CFCCCDD9D0D4D2D1D9D0D9D5D9D3D5D9D8DAD5DAD3D6D0D1D3D7CFD8D1DCE3DED7D2D4D0
CED1D3DDD9D8DFD3E9D5E0D8D6DBDCDDDEDAD6D8D4E1D3E3CFDCD3D4DBD3DAD4D8D3D3D5
D9D3D3C6D8D3DCDBE3DBE4CFE4CBE0D5D9D9E0DDDADCDADFD5E1C7E6CCE6D7DFDBD9D1D8
CEDDD3DCD6D1DDCEE2D7E2D7DFD2E3C9E5CCDFD3DCD5D6D5D6D8D5DBD1E3CCE8CBE3D1D5
D6D7D7D7D7D8DADCDBCFD8C2E4D3DED1DBD1E3C8E1C7D9CED7D6D2D3CFD4CDD9C8E1C8DE
CEE3C9E1D9D4DCD3D7D3D4D5DDD2E0CFDBC0D9D0DAD0E2C5E1C7DBD0D8D9D0DFCEE1D3DF
CFEACDE4D0E4CDDCD9DBDFDEDDDBD8D8D7D4E3D3E2CDD6CED4C8DAC3E5CDDDD1D9DCDCDE
D8DCD7E4CEDDCCE6CDDED3DCDAD5D6D4D7DDD9DBDDD9E1D5DED1D9D5DFD9E1CCE1CBDBCB
D4D3D5DCD7DCD2D7D9E2D6E0D4DDD8D8DCDCDAD8D6D5D6D8DBDAD9D8D9DCDFE1DAD8DBD6
DBD8DFE0E0D9DBDADBDDD8DACFD0CEDCD4D9DDDBDDD9DCD6DCD9DEDCD8D9D3D7D2D8D4D6
DAD7D7D6D9D9DAD9DED5D8DADAD8D5DED7DDDADADADBE1DEE3DEDEDAD7D0C9D3DCE1D8DD
D5D5D5D5D7D6DDD9DFD9DBD8D8D3D7D5D7DDD6D8D0D3E0D1E0CCDACED9D8DDD7DAD5DBDC
DBE1CEE2C8D9CAD5D6D9D4DDCDD1CBD3DDDBDBDEDEDBDBDEE1D8E6D5E5CEE5D5DED8DCDA
E1DBDEDCD9DDD4E9D4E9D5E2D6DDD8E5DBE7DEE2E1DCDFDDDADAD7DDE1D8E4D1E7D2E3CC
D2CFDFD1E3D3DFD7DBE7D2EBCEE8D6E3D4D8CDE1D1E1DADADDDCDFD9D9DFDCDBE0DDE8D4
EAD4E5D7E1D8E8D6E7DAE2DEDBE5D1EBD1ECD9E3DEE1C5CEBBDDD7E0E1DCE0E0E0E1DDE3
E3DEEAD9EED5E7DBE6DDE4DEE3DFE0E4E2EBD9ECD7F1E2E8E1E5DDE9DFEBE2E5E9E6E3E3
DCE7E0E8E0DDE7DDEDDCEBE0E7DFE4DADFDFE1E3E4E5E1E9E5E9E3E6E7E6E8E1E8E6E9E4
E4E8E5E9E1E6E3E7E4E5E9E0ECE1EDE4E9E3EAE1E6E3E3E4DFE0DDE5DEE1DEE4E7E2E6E3
E8E2E5E2EAE5E7E3E4E6E1E2DFE8E5E2E1E3E7E0E6E3EBE0E4E2E2E3E4E4E0E6DFE6E3E5
E8EAE5E7E5E1E4E0E7E4E4E1E3E1DCE5DFE4E3E6E4E2E9E9E5E2E6E2EAE6EAE6EBE9E7E8
E1E8E0E4E6E7ECDFE4D6E1D6E4E0E4E3E5E8E3E5E8EAE5E9E3E8E4E6E6E8E3E8E2E7E3E6
E1DEE1DEDFE3E0E4E7E3E6DBE6D8E6E0EAE1ECDDEFDEE9E1DEE8DFEFDCECE1E9E5EADEEB
E2E9E5E4E6E3E7E5E5E9E6E9E6E3EBDFF0DCE8DC
DDE0D8DCDBDFD5D5D5D3D2D5D7D8D9DBDCDAD2D8D7E0D8D5D8D7DCD6DAD3D6D4D6D2CFD1
CED6CACACED4D3D7D8D5DAD8DCD8DAD6D7DAD6D8D0D7D6D8D9D8DCD7D9D5D6D1D4DAD7D9
D4D1CDD6D1D7D6D9D8D1DBD6DAD6D8D8D8D9D5DAD4D8D2D3D7D2D8CEDBD1E8D5D8D1D2CF
CFD2D3DCD8E5D5E5D9E1D8DDE1DEDCDCDCDAD8D9D6D7DFD2DFCFDCD1DCD2DBD5D8D5D6D7
D0DCC7DACAE3D2DDD9DED4DFD5DADADFDCD8DCDBDDE1DCDDDFD5E1CDE5CADFD4DDD3DCD1
DBD4D7D7D1E1CEE5CAE9D5DCD8DED0E0D0E1D6DDDFD6D6D6D8DAD6D9D7D4E3CFE7CDE0D0
D6D7D8D8D7D8DBDED5DEC2E0CEEFD5DECFD9CFDFCEE1D7DDD8D8D5D7D3D6CDD8DBCFE6CD
E4CBE0D3DAD5DDD3D6D3D3D5CFDBC1E3BAD3C9DDD7DCD2DFD0DBD2DAD9D5DEDADFDCDADB
DBD0E8D1E2CAE8D1D7D8DEDDDCDCD8DAD6E4D2E7CCDEC9D5D3D3C4D8CCE2DAE1D9DDDADC
DCE0D3DCD6D3E0D1DFC7DAD5DBD5D6D4D7DDD9DBD4DED1E5D0E3D6DFDCE3D4DFD2DCD6D4
D4D6DBE0D8DAD2DADBDCDED5DFD5E1D8DDDDDBDAD8D7D7D7DCDDDDDCDBDBDDDEDDDBDED8
DCD7DCDADFDADDDBDCDED9DBD1D2CCDBDADEDDD8DCDAE0DDE4DEDFDBDCDDD8DDD7DCD8DA
DBD1DBCDDED0DCD8DBD5D9DADADAD7DED1DADADCDBDDE6E5E5DEDFDBD6CFC9D1DBE0D8DF
D8DAD9D8DAD8DED9DED6D7D4DBD3D7D2D5DCD4D8CDDCD2E1D1DCD5D7D8D8DCD4D9D6DDDB
DED8DDD5DBCFD4D2D8CEE4D1E2C7D8CFDCDADCDFE0DEDEE1D9E4D2EAD1E4DADFE0DADDDC
E5DEE1DFDAD2E2D9E7DCE0DFE0D9E9D7EAD5E1D8E2DDE0DDDBDBD8DFDBE5D4E9D5EADFD9
D2D7D8DDDAE0DCDCE0DBE4D6E2D5E1DDDBCEE5CEE7CEE7DADCDBDFDCDDE2E0E3DBEBD4E8
D2E5D8DFE2E1E1E2DEE5DEE2E3DBE5D5E7D7E3DBE0D0DFB9DFCCE9DBE3DDE1E0E1E2DFE4
DBE6D3EED8E9DDE5E7DDE4E0E6E2E4EAE2E3EADFE9E5EAE2E9E1EFDCF0DEEBE3EDE7E6E2
DBE6DDE6E1E9DAEFDAE8DFE0E6DFE5DBE0DEE0E2E4E5E2E9E5E9E5E8E7E6E9E1E8E6E9E4
E2E7E5E8E0E5E4E9E6EEE3EBE0E8E4E2E9E4EBE2E7E5E5E6E1E2DFE6E0E3E0E6E7E3E7E2
E6E3E8E2E9E4E6E3E5E8E2E2DCE4E3E3E4E5EAE5E8E3EAE2E5E1E2E5E4E5DFE3E0E7E4E8
E4E7E3E5E4E2E7E5E8E4E5E3E4E2DDE8E1E5E2E4E3E2E9E9E6E2E6E2EBE8EBE7EBE8E5E7
E1E9E1E6DEE9DEE6DCE2DEDEE2DFE4E2E4E7E3E5E5E7E3E7E1E5E0E2E5DFEADCEBDEEAE5
E6E2E5E1E0E3E0E4E2EEDDF2DCEADFE4E9E8E3E8E4E7E4E7E3E4E9E4E8E6EAE7EAE3EEDB
F1D8EBDEE4E1E6E3E4E7E4E7DDEBD5F5DBF2E0E6
E0E3DADDDBDED5D8D7D6D8DDDFDDDADADCDED8DBD7E0D9D4D9D8DDD7DAD3D7D5D4D2D0D2
CCD4CDD3CED4D3D8D9D7DDDBDDD8DBD8D9DDD8DAD5DAD7D9DBDADDD7DAD8DBD6D6DBD7D7
D1D0C8CECDD3D0D7D6D1DDD7DADADBD6D9DAD5DBD6DCD6D7D6D9D4DCDBE2F1E0D6D2D6D3
D1D3D4DEDADFE1D9E4D6DFDCE7E1DCDCDCDAD7D7D4DED3DCD1D8D6D6DFD4DDD7D9D6D9D9
D2D6D2D0D5DADADDDDDAE2D6E1CDDEDBDBD8DDDBDCDFDBDDD6DDCDE0CFDAD4DBDAD7D7DE
D7DCD0D5D3D5D9D5D7D6DBDDE3DDE4D3DECFD9D4DBD5D7D7D8D9D6DAD4E1D2E2D2DFD6D6
DAD9D9DADBDBDBDADCD6D7CBDCD3D8D5D5D3DFD0DDD4DFD9D7D9D8DBD6D9CED8D4DFD3DD
D9E1D3DCDCD7DED4D7D3D4D6D2D2D1CECFC0CCD3DBD2E1D3E5D0DEDCDADBD6DDD2E1D6DF
D6E4D3DCD6DDD4D7D6D4DBD8D7DBD7DBDCDDE1D5DCD0D3D5DDCBD3CBD9D1E1D9DBDAD9DD
DBE2D5D6D0D7CDDFD2D9D6DCDDD8D8D5D8DDD9DCD9D9DEDADDD9DCDBE2E1E2D7E0D5DFD5
D2D6DDE2D8DAD3DDD8E0D7DDD7DDDEDCDEDEDEDEDDDCDBDADEE0E1DFDCDAD9D9D8D7DCD9
E0DCE0DEDEDBDEDCDCDFDADCD0D5CCD8DADEDBD9E3DEDFD8DFDBE0DEDCDFDCE1DBDED9DA
D9D7D2D9D5D9D6DADDDADDDBDBDCD7DAD9E1DFE0DEDDE2DFE4DDDFDDD7D0C9CEDADFD8E1
DCDDDCDBD8D7DDD9DFD9DCD9E2D8DCD4D6DED6DBD9DCE0D5DCD1DDD6D9D6DBD7DCD6DBDB
DADDD2E2D2DDD1D9D7D4DADDD7D3D5D4DDDBDCDFE0DFE0E3DDE0E2DCE3D5DCD8DED9DCDC
E5DFE1DFDCDDDBE6DCE5D9E1DBDEDDE3DFE2DDDEE5E0E3E1DFE0DEE5E4E1E7D9E3D8E3D1
D2D2E0D6E5DCE2DAD9E2D6E7D3E3D6DEDBDADDE0DADEDDDCDCDADFDDDDDFDDE4DAE0E0D7
E1D7E1DEE3DBE7D9E6DEE4E3DDE1D7E4D8E6DCE1D8D9CECFCEDFDEDCE4DEE2E1E1E2E0E5
E4E1E2DEE5D7E0DBE6DCE4E1E8E2E4EADFEAE1EADBEDE2E3E6E8E5E8E4E8E5E7EBE5E7E4
DDE8DCE5DFDEE1E2E5E0E9E2E4E0E7DDE0DDDFE2E0E3E1E7E2E8E4E7E6E5E9E2E9E6E9E3
E4E6E2E6E0E6E4E7E1E4E5E0E8E2ECE5E8E2E9E1E7E4E5E6E1E2DFE7E1E4E1E7E5E2E6DF
E2E3EAE1E8E3E6E4E5E8E0E0DCE2E1E5E5E2E6E3E8E0E8E2E6DFE1E6E2E7DEE2E3E8E1E8
E5E8E5E5E1DCE0DEE7E3E4E3E5E2DDEAE3E6E2E5E4E1E6E4E7E3E5E2EAE7E9E5E9E6E4E5
E1EAE3E7E1E9E5DBE2D7DAD7DEDDE2E0E1E4E0E4E6E9E5EAE3E7E1E3DFE0E0E1E0E0DFDF
E5E1E3DEDCDEDADDDDE0E1E0E3DBE2DFEAE1E7DAE3D4DDDCE2E7DDE5DAE9E2E4E0E3DFE1
E2E0E6E5E2DFE4E2E2E5E2E4DFE0DEDFE3DEE3DE
E2E5DCDEDBDCD4D8DAD6D4D7D9D8D8D9DCE2DCDAD4DEDAD7DBD9DDD7DAD3D7D6D7D8D9D8
CCD1CBD4CED3D3D9DAD9DFDEDED9DCDADBDFDADBD9DDD9DADCDCDED7DADBDFDAD9DCD7D6
D3D5CCD1D2D6CFD8D5D1DFD8DBDDDED6DADAD6DCD8DED9DADBD9D7D5D8D4E6CED4D3DAD7
D3D3D5E0D6E1DBE0DDDBDCE0DCD9DBDEDDD7D4D4D6DAD7D3D5D2DBD7E1D5DED9D9D6D9D9
D3DCCDD5CBDFD9E3D9DCDCDEDCD4DDE1D8DAE2DED9DAD9DFDFDDDCDADED2DCDBE1D8DAD6
D8D7D4D8D0D6CCDECCD9D4E3DCDEDADCD5DAD9DDD5D3D8D7D6D7D5DCD8DBDBD6DCD6DDD6
DEDBD9DBDFDFDAD6CED3C7D0CAD7D2DDD0D6D6D9D4DDDCDED6D9D9DDD9DBCFD9DED3DFD7
DED4DDD0DED9E0D5D8D4D5D7CFDBCCE2D2D6CAD7DCD8DBE0DFD7D8DED5D4D7D8D5DBD4D7
DFDADBD2DED4DDCEDAD7DDD8D8DEDBE1D5DFD6DCD3DBD5E0D5C9CAD6CFD8DBD6DCD7DADF
D8E2DCDBD6D3D3D5DCD4DBD8E0DADBD7D8DDD9DCD4DAD6E1D8E1DCE1E1E5DBDCD6D7D6D1
D0D3DAE1D9DCD5DED9DCDAD8DBDAE1DDDEDFE0E1E2E1E0DEDADDE0E0DEDCDBDADCDBE0DC
E2DCDEDADDDBDFDCDCDFDBDDCCD8D0D7D6D9D8DEDEDBDFDAE0DADBD6DADEDCE2DBDDD7D8
DCD4DBD5E1D5DCDADCDBE0DCDCDFDADBDAE0DEE1E2E2E6E2E2DBE1E1DBD4CCCFDBE0DAE2
DDDFDDDBDCDAE0DCE1DCDFDCE9DEE1D8D9E2D9E0D8DFD8DAD5DAE0E1DBD5DBDCE1D6DADE
DEDCD9DCD8D7D4D6E1D6E3D6DCCAD6CFE0DDDCDEDFDEE1E4D5E4D9E5DCDFD7DDDBD5D9D9
E3DDDFDCE3DDE4DFE2DFDCDFE1DEE5DDE5DBDFDAE3DEE1E0DFE0DEE6D8DEDADED7DFE1D7
CDD3DBDBE1E0DFD8D5D9DCDFDEDEDCDCDFD5E5D8E6D8E1D6DED9DEDDDAD8D6DFD6E5D9E0
D7DEDADFDFDAE0DADFE0E1E4E3E0E2DCE0DBDDDBE0D3D2B9D0D0E5DFE4DFE2E1E1E3E0E6
DBE0D5E5DCE1DFE4E5DBE4E1E7DFDFE4E2E8E5DFDCE3E5E4E3E0E7DFE8E1E9E7E5E1E6E4
DFEBDDE6E3E5DEEADCE2E1DDE2DFE8DEE1DDDEE2E1E4E2E8E3E9E7E9E6E5E9E2E9E6E9E3
E6E6DFE4E1E8E3E4E2E8E2E3E1E2E5E1E6E1E8E0E6E4E4E6E0E2DFE7E1E4E1E7E3E0E5DC
DFE3EBDFE8E3E6E4E5E7DFDDDFE3E2E6E4DEE0DEE8DEE5E2E6DEDFE7E1E9DFE2E6E9DEE6
DCE2E1E4E1DCE1E0E6E2E4E3E5E1DDEAE5E7E3E6E5E1E4E0E8E3E5E1E9E5E7E3E8E5E2E4
E1EBE4E8D6E4DADADFDDDADEDBDBE1DFDEE1DEE3E1E4E1E6DFE2DCDDDEDCE2DBE1D7DAD5
DCD8D9D3D1D2CED1CED5CAD5CBD2D4D8D1CED0CFD3D0D7DCDDDDD5D4D2DBDAD9E4E0E5D6
E2D2E3DDE0DEE3E1E1E4E0E3D4DCCCDFD2E1DCE0
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{398.938, 198.312},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007b0000mb000`400?l00000o`00003ooooooooc
ooooo`00ooooooocooooo`00ooooooocooooo`00ooooooocooooo`00ooooooocooooo`00oooooooc
ooooo`00ooooooocooooo`004?ooool01`1OGel0H61P05eMG@1LG5`0Fe]K065QH@1NGUh00P1MGEd0
101IFET0EUIF05ADE01JFUX305MGE`80E5AD00<0EeMG05QHF01GEeL00P1EEED0201ADE40De=C059B
DP1BDU80De=C05IFEP1EEED0E5AD0`1@D5004@1CDe<0EeMG05MGE`1@D500De=C055AD@1EEED0Cdm?
051@D01BDU80De=C055AD@1>CTh0De=C051@D01ADE40CTi>0080CDe=00@0EEEE055AD@1>CTh0BTY:
0P1@D50204m?C`0I051@D01=CDd0De=C04i>CP1=CDd0CTi>04m?C`1>CTh0EEEE051@D01<C4`0Bd];
04e=C@1;Bd/0B4Q804a<C01=CDd0Bd];04Y:BP16ATH0BDU904Q8B01:BTX0Bd];04i>CP0204Q8B009
04a<C01=CDd0D51@04e=C@1<C4`0BDU904e=C@1>CTh0AdM70080BTY:01X0BDU904e=C@1:BTX0Bd];
04U9B@1<C4`0BTY:04U9B@1>CTh0AdM704Q8B017AdL0BDU904E5A@16ATH0B4Q804Y:BP16ATH0CDe=
04M7A`16ATH0B4Q804U9B@18B4P0ATI604E5A@80B4Q801T0DE5A06i^KP21PH40Shn?0:>SX`2n_[h0
_;bl09VIV@1bLW80EUIF04a<C01>CTh0BDU904A4A016ATH0AdM704Q8B012@T80AdM704];B`17AdL0
ADE504I6AP13@d<0AdM70080ADE50200A4A404Y:BP1<C4`0DE5A04m?C`1FEUH0CDe=051@D01?Cdl0
D51@04];B`19BDT0C4a<04];B`1>CTh0DE5A04M7A`18B4P0AdM70492@P18B4P0BTY:059BDP15ADD0
ATI60492@P14A4@0ATI604Y:BP1DE5@0DU9B04a<C0<0ATI600H0ADE504=3@`13@d<0ATI604A4A016
ATH204];B`0L04e=C@1>CTh0DE5A055AD@1EEED0Bd];04a<C01=CDd0Hf=S08F5Q@2;Rh/0PH6106m_
K`1OGel0DE5A04];B`1?Cdl0H61P06a/K028R8P0S8b<08n?S`1oOgl0EUIF04];B`15ADD0@D5104A4
A080ADE500/0@d=30451@@13@d<0CTi>06i^KP2BTY80QXJ606i^KP1MGEd0DU9B04i>CP0204M7A`0>
04=3@`0m?Cd0KFe]04A4A013@d<0BDU905iNGP1JFUX0EEEE05YJFP1/K6`0NWYj08b<S02HV9P209JF
UP0?09VIV@2NWYh0Y:BT09jNWP2>SXh0LW9b06=SH`1QHF40Jf][08R8R02PX:00Vi^K06=SH`1=CDd0
@T920080?Cdm00/0>CTi0410@00o?cl0>SXj03dm?@0n?Sh0@T9203`l?00n?Sh0>c/k03`l?0020410
@00403`l?00m?Cd0?3`l04=3@`80?Cdm00h0>c/k03Ti>@0l?3`0?3`l03dm?@11@D40?clo03Xj>P0i
>CT0>c/k03Xj>P0k>c/0>SXj03dm?@<0?3`l0140?Cdm03`l?00k>c/0?Shn03dm?@0l?3`0?Cdm0451
@@0l?3`0>SXj03hn?P10@400>CTi03/k>`0m?Cd0?3`l03/k>`0203`l?080?Cdm0P0l?3`01`0n?Sh0
BTY:03`l?00l?3`0=cLg03Xj>P0h>3P00P0l?3`00`0i>CT0>3Ph03`l?00203Ti>@0303Ph>00j>SX0
>c/k0080=SHf00D0>3Ph03Xj>P0l?3`0?3`l03Xj>P0303/k>`<0>CTi00<0=cLg03Ph>00h>3P00`0i
>CT303/k>`0803Xj>P0h>3P0>CTi03Ti>@0j>SX0?3`l03Ph>00k>c/203dm?@0303`l?00j>SX0>SXj
0080>SXj0P0k>c/203Ti>@0:03Ph>00f=SH0>CTi03Hf=P0j>SX0>CTi03/k>`0i>CT0>3Ph03Xj>P@0
>3Ph00`0>c/k03Xj>P0g=cL0>CTi03Ph>00i>CT0=cLg03Ti>@0g=cL0>SXj03Lg=`0e=CD203/k>`03
03Xj>P0h>3P0>CTi0080>SXj00/0>CTi03Ph>00h>3P0=SHf03Ph>00g=cL0>3Ph03/k>`0j>SX0=cLg
03Ti>@0203Xj>P0>03/k>`0f=SH0>3Ph03Lg=`0i>CT0>SXj03Lg=`0f=SH0>CTi03Ph>00f=SH0>3Ph
03Ti>@0h>3P203Ti>@80>3Ph0`0g=cL0100h>3P0>CTi03Ph>00k>c/303Ph>080=SHf00<0>c/k03Ti
>@0h>3P03Oooool0013ooooo0P1DE5@02P1ADE40Cdm?055AD@1DE5@0DE5A051@D01BDU80CTi>055A
D@1=CDd2051@D004055AD@1BDU80Cdm?04i>CP80C4a<00L0DE5A04i>CP1;Bd/0C4a<04];B`1>CTh0
Bd];00@0C4a<0P1;Bd/0101CDe<0Cdm?04a<C01BDU8204i>CP0:04];B`1>CTh0BDU904];B`1:BTX0
C4a<04U9B@16ATH0Bd];04i>CP80Bd];00<0BDU904a<C01=CDd00P1:BTX02P18B4P0BDU904M7A`1>
CTh0BTY:04M7A`19BDT0C4a<04Q8B01:BTX205EEE@0K055AD@1>CTh0BTY:04Y:BP19BDT0B4Q804i>
CP1:BTX0AdM704I6AP1<C4`0CDe=04M7A`19BDT0B4Q804];B`1:BTX0ADE504i>CP15ADD0ATI604=3
@`16ATH0BDU904E5A@13@d<0ADE50080B4Q800T0@d=304A4A014A4@0ADE504=3@`1:BTX0Bd];04I6
AP17AdL00P18B4P01`1:BTX0BDU904A4A016ATH0@d=30492@P11@D400P13@d<0>`15ADD0AdM70492
@P13@d<0AdM70492@P16ATH0CDe=051@D01BDU80Fe]K04a<C01>CTh0Cdm?04U9B@1lO7`0Ti>C06MW
I`1=CDd0BDU904Q8B01;Bd/0BTY:04M7A`16ATH0@D5104M7A`12@T80@D5104=3@`12@T80@d=304M7
A`1:BTX0B4Q804];B`16ATH0B4Q804I6AP1=CDd0C4a<04i>CP1;Bd/0DE5A04e=C@1<C4`0Bd];04E5
A@19BDT0De=C05mOG`13@d<0@T9204];B`1=CDd0Bd];0492@P19BDT0ADE50080AdM700l0@D5104=3
@`12@T80AdM704A4A01:BTX0GEeM06QXJ01eMGD0KVi^06ATI01NGUh0EeMG04Q8B015ADD00P13@d<0
3`19BDT0AdM703lo?`14A4@0AdM704=3@`14A4@0@T9204=3@`10@400NWYj0:f][@33`l<0_kno0:^[
Z`020:>SX`0609VIV@27QhL0LW9b06QXJ01dM7@0VIVI0P2KVi/0202PX:00UIFE07MgM`1SHf<0E5AD
04Q8B010@400DU9B0P1kNg/02`2DU9@0OWin08:2PP2<S8`0WYjN09>CT`2RXZ80YJFU09JFUP1fMWH0
L71`0080HV9R01`0F5QH04m?C`1:BTX0DU9B04];B`13@d<0@T9204I6AP1@D500GEeM05iNGP1SHf<0
EEEE059BDP1ADE40F5QH05mOG`1eMGD0NGUi07moO`21PH40Kfm_06=SH`1NGUh0BDU90451@@0k>c/0
?Cdm0P0n?Sh01P0m?Cd0?3`l03Xj>P0l?3`0?Cdm03/k>`80>SXj0`0l?3`04P0n?Sh0>c/k03hn?P0i
>CT0?3`l03hn?P0j>SX0>c/k03dm?@0n?Sh0>SXj03hn?P0m?Cd0>3Ph03hn?P0m?Cd0?3`l03/k>`<0
>SXj00P0?Cdm03Ti>@0m?Cd0>CTi03Xj>P0k>c/0>SXj03lo?`80?3`l00D0>CTi03Xj>P0h>3P0>SXj
03/k>`0203Xj>P0<03hn?P0k>c/0>c/k03`l?00k>c/0>CTi03`l?00j>SX0>3Ph03hn?P0l?3`0>c/k
0P0i>CT0100k>c/0>3Ph03/k>`0g=cL303Ph>00303Ti>@0g=cL0>SXj00@0>CTi00L0>3Ph03De=@0g
=cL0>SXj03hn?P0l?3`0>SXj0080>c/k00H0=CDe03Ph>00m?Cd0>c/k03Xj>P0i>CT203Xj>P0<03Hf
=P0g=cL0?3`l03dm?@0j>SX0>c/k0410@00n?Sh0@41004I6AP17AdL0BDU90P0n?Sh0100k>c/0>3Ph
03Hf=P0g=cL203Ti>@0703Xj>P0o?cl0?Shn03Lg=`0f=SH0=cLg03Ph>00203Ti>@0403/k>`0j>SX0
>CTi03Xj>P80>3Ph00<0>c/k03Xj>P0l?3`00P0k>c/0100j>SX0>CTi03hn?P0h>3P203Xj>P0;03/k
>`0j>SX0>3Ph03/k>`0j>SX0=SHf03Xj>P0f=SH0=cLg03Ph>00g=cL00P0h>3P303Lg=`0:03Hf=P0h
>3P0=cLg03Lg=`0f=SH0>3Ph03Xj>P0i>CT0=cLg03Hf=PD0>3Ph00<0>CTi03Ph>00f=SH00`0f=SH0
1P0i>CT0>SXj03Lg=`0i>CT0=cLg03Xj>P80>CTi0`0j>SX0200g=cL0>CTi03Xj>P0j>SX0=cLg03De
=@0h>3P0?3`l3Oooool0013ooooo00P0DU9B055AD@1?Cdl0Bd];051@D01CDe<0C4a<04i>CP80CDe=
0P1@D50204e=C@0:04a<C01;Bd/0CDe=04];B`19BDT0BTY:04];B`1:BTX0Bd];04Y:BP<0BDU900T0
BTY:04U9B@1=CDd0Bd];04Y:BP1?Cdl0DE5A04Y:BP18B4P0101=CDd02`1:BTX0B4Q804I6AP19BDT0
B4Q804I6AP14A4@0B4Q804M7A`18B4P0BTY:00<0B4Q800D0BDU904I6AP14A4@0BDU904Y:BP0204A4
A00304I6AP1=CDd0B4Q80080B4Q800h0Bd];04M7A`16ATH0BDU90492@P17AdL0B4Q804I6AP1=CDd0
ATI60492@P14A4@0ADE504I6AP80A4A40P18B4P03`19BDT0AdM704A4A012@T80@D510492@P11@D40
@T9204=3@`11@D40AdM704E5A@12@T80BTY:04E5A@020492@P0404I6AP11@D40@d=304M7A`80ADE5
00D0AdM704I6AP14A4@0B4Q804A4A00204=3@`80@D510P10@4002P17AdL0A4A405=CD`1MGEd0CDe=
04=3@`14A4@0B4Q804E5A@1;Bd/2055AD@0804Q8B01;Bd/0DU9B05EEE@1GEeL0DU9B051@D017AdL2
04I6AP0l04a<C01LG5`0C4a<04I6AP0n?Sh0@d=30451@@14A4@0BTY:04I6AP1;Bd/0ATI604a<C01:
BTX0C4a<04Y:BP1@D500BTY:04I6AP1?Cdl0@T9203hn?P0o?cl0@41003`l?00m?Cd0ADE504U9B@13
@d<0@D5104m?C`1`L700NWYj069RHP1WIfL0Fe]K04];B`0k>c/0?Cdm04=3@`12@T80@d=30410@011
@D40ADE504=3@`1CDe<0JFUY08V9R@2TY:@0_;bl0<30`02SXj<0QHF507QhN01fMWH0PX:208N7Q`1h
N7P0J6QX0P1MGEd0@01HF5P0DE5A04Y:BP15ADD0D51@05mOG`1TI6@0IFEU06UYJ@1oOgl0P82008B4
Q026QXH0WYjN0:>SX`2KVi/0ZZZZ0;6a/@2b/[80]KFe0;^k^`2n_[h0/;2`09VIV@1/K6`0I6AT07Mg
M`2<S8`0VIVI0:>SX`2QXJ40P82008J6QP2=SHd0Ng]k07MgM`1lO7`0LG5a08>3P`21PH40V9RH09VI
V@2DU9@0OGem0820P022PX80Rh^;07QhN01NGUh0De=C04I6AP1FEUH0L71`06YZJP1`L700FEUI04=3
@`11@D40>SXj03dm?@0n?Sh0@T9203/k>`0l?3`303Ti>@0803Xj>P0k>c/0>c/k03Xj>P0l?3`0>SXj
03`l?00n?Sh303`l?00;03Xj>P0l?3`0?clo03/k>`0i>CT0?3`l0492@P0i>CT0>SXj03lo?`10@400
0P0m?Cd01@0o?cl0?3`l03Xj>P0o?cl0>CTi0080?3`l00H0>SXj03Ti>@0j>SX0>CTi03`l?00j>SX3
03/k>`0>03Xj>P0l?3`0?3`l03dm?@0h>3P0>c/k03Ti>@0j>SX0?3`l0410@00n?Sh0?Cdm03hn?P10
@40203hn?P0;03/k>`12@T80>c/k03Ph>00f=SH0=cLg03`l?00k>c/0>SXj03Ti>@0j>SX00P0i>CT0
2@0o?cl0>c/k03Xj>P0h>3P0=SHf03Ph>00i>CT0=cLg03/k>`0203Lg=`0B03Ph>00l?3`0>SXj03Ti
>@0j>SX0>3Ph03/k>`0j>SX0>c/k03Ti>@0g=cL0>SXj03`l?00k>c/0>SXj03/k>`0n?Sh0>3Ph0`0j
>SX02`11@D40HV9R07]kN`22PX80QHF5061PH01ADE40BDU904=3@`0h>3P0>CTi0080=cLg00<0>c/k
03Xj>P0i>CT00P0l?3`203Xj>P0303Lg=`0f=SH0>3Ph0080>3Ph00/0>SXj03/k>`0g=cL0=cLg03Ti
>@0g=cL0>SXj03/k>`0i>CT0?3`l03Ph>00203@d=00503Lg=`0j>SX0>3Ph03Ti>@0k>c/00P0j>SX0
0`0g=cL0>SXj03Ph>00203Ti>@0503`l?00m?Cd0>c/k03Hf=P0h>3P00P0g=cL0100f=SH0>CTi03Ph
>00e=CD203Ph>00503Ti>@0g=cL0<c<c03<c<`0f=SH0100g=cL02@0f=SH0=cLg03Xj>P0f=SH0=cLg
03Ti>@0g=cL0>SXj03Ti>@0203Lg=`80=SHf0P0g=cL203Ph>00703Ti>@0j>SX0>3Ph03Lg=`0h>3P0
>SXj03Lg=`0203Hf=P0303Ph>?oooooooooo00_ooooo000@ooooo`0:05=CD`1ADE40DE5A04i>CP1B
DU80De=C04];B`1=CDd0DE5A04e=C@80Bd];0P19BDT02018B4P0BDU904i>CP1@D500B4Q804M7A`1;
Bd/0B4Q81019BDT06@1;Bd/0BTY:04Q8B01<C4`0Bd];04I6AP19BDT0CDe=04i>CP1?Cdl0Bd];04e=
C@17AdL0A4A404];B`19BDT0B4Q804];B`16ATH0AdM704U9B@1FEUH0C4a<04E5A@17AdL00P15ADD0
3P17AdL0ATI604A4A016ATH0BDU904I6AP14A4@0@T9204U9B@1:BTX0ATI60492@P18B4P0A4A40P16
ATH01P14A4@0@T920492@P18B4P0@T9204U9B@80ADE500<0A4A40410@012@T800P14A4@02016ATH0
AdM704I6AP19BDT0AdM704E5A@16ATH0A4A40P12@T803@15ADD0@d=304=3@`12@T80A4A4055AD@10
@400@D5104E5A@17AdL0A4A404U9B@13@d<00P14A4@0:@15ADD0@T9204=3@`19BDT0B4Q804E5A@13
@d<0ATI60410@00n?Sh0ADE504I6AP1HF5P0N7Qh06a/K01CDe<0E5AD061PH01UIFD0HV9R04m?C`16
ATH0?clo04A4A00o?cl0?Cdm03lo?`12@T80@4100451@@0n?Sh0?clo04M7A`1ADE40JVYZ06EUI@1R
HV80Jf][06ATI01BDU80E5AD00<0EUIF00P0CTi>04=3@`14A4@0ATI604e=C@1EEED0AdM704E5A@80
B4Q80100?clo04=3@`19BDT0BDU904E5A@1ADE40Cdm?04Y:BP14A4@0@D5104Y:BP14A4@0ATI604A4
A019BDT0@4100P0o?cl04@0n?Sh0@4100451@@11@D40?clo04I6AP19BDT0A4A403hn?P15ADD0CDe=
05eMG@1YJFT0LW9b07EeM@1VIVH0GemO0080J6QX00d0H61P06EUI@1ZJVX0Ph>308^;R`1hN7P0K6a/
07EeM@1nOWh0N7Qh07YjNP24Q8@0Shn?0080YZJV00l0Xj>S08j>SP28R8P0UYJF09fMW@2IVIT0WYjN
0:^[Z`2a/K40^k^k0<C4a03?cll0alO70;2`/02?Shl00P25QHD01`1oOgl0Rh^;07YjNP1SHf<0IFEU
06MWI`1<C4`00P11@D402`0o?cl0Cdm?05YJFP1ZJVX0O7al06QXJ01mOGd0RHV9092@T02UYJD0[Jf]
0080^;Rh0180S8b<04m?C`1GEeL0O7al09BDU01ZJVX0BTY:04U9B@1GEeL0@41003dm?@0n?Sh0?Cdm
03Xj>P0n?Sh0>CTi03dm?@0k>c/203`l?00:03/k>`0m?Cd0>c/k03dm?@0o?cl0?Shn03lo?`0n?Sh0
>c/k03Ti>@80>SXj00<0>c/k03dm?@11@D400P0k>c/01`0l?3`0@41003hn?P0l?3`0?Shn03/k>`12
@T800`0k>c/0100l?3`0?Cdm03dm?@0n?Sh303Ti>@0503Xj>P0l?3`0?Cdm03dm?@0i>CT00P0k>c/0
7`0j>SX0=cLg03Ti>@0h>3P0>SXj03/k>`0h>3P0?Cdm04Q8B017AdL0?Shn03Ti>@0h>3P0@D5103Xj
>P0h>3P0>CTi03Xj>P0h>3P0>CTi03/k>`0m?Cd0>c/k03Ph>00j>SX0?3`l03Ti>@0h>3P0=cLg03De
=@0g=cL00P0j>SX07P0i>CT0=cLg03`l?00m?Cd0>SXj03Hf=P0g=cL0?3`l03Xj>P0h>3P0>CTi03dm
?@0k>c/0>CTi03Xj>P0i>CT0>SXj03Ph>00j>SX0?clo03/k>`18B4P0Hf=S07emO@2OWil0bl_;0<S8
b02][Jd0Ng]k04Y:BP80>CTi00D0=cLg03Ph>00l?3`0>SXj03Lg=`0203Ti>@0603Xj>P0o?cl0?Shn
03Xj>P0h>3P0=cLg100h>3P03P0g=cL0>CTi03Ti>@0h>3P0>CTi03Lg=`0j>SX0>c/k03Ti>@0h>3P0
=cLg03Ph>00k>c/0>CTi0`0k>c/0100l?3`0=cLg03Ti>@0h>3P203Ti>@80>SXj00<0>3Ph03Xj>P0j
>SX00`0g=cL203Hf=P80>SXj00<0=cLg03Xj>P0g=cL00`0f=SH01@0e=CD0=SHf03Lg=`0g=cL0=SHf
0080=cLg00/0>3Ph03Ti>@0f=SH0=cLg03Ph>00e=CD0=cLg03Hf=P0g=cL0>3Ph03De=@0203@d=080
=SHf0P0e=CD01P0g=cL0=SHf03dm?@0m?Cd0=SHf03Lg=`80=SHf00<0=CDeooooooooool02oooool0
013ooooo00T0DU9B04e=C@1@D500D51@04a<C01=CDd0Bd];04m?C`1<C4`00P1:BTX204e=C@0404Y:
BP1<C4`0D51@051@D080BTY:00/0Bd];04I6AP19BDT0C4a<04Y:BP17AdL0B4Q804];B`17AdL0BDU9
04Y:BP0204];B`80BTY:00l0BDU904Y:BP18B4P0Bd];04Q8B01:BTX0C4a<04Q8B01;Bd/0C4a<04A4
A018B4P0CDe=04a<C017AdL00P15ADD01P13@d<0ADE504E5A@17AdL0BTY:04U9B@80ATI60140A4A4
04M7A`1>CTh0Cdm?0410@013@d<0@D5104M7A`1:BTX0A4A404m?C`10@400@T9203lo?`19BDT0Bd];
04=3@`020451@@80ATI60P13@d<01`14A4@0ATI604A4A011@D40@41003lo?`18B4P00P0o?cl01P10
@400@D5103lo?`13@d<0A4A404=3@`80@D5100<0?Shn04A4A012@T800`10@4003`12@T80@4100451
@@0n?Sh0@d=304I6AP17AdL0?clo0451@@0o?cl0@4100451@@16ATH0B4Q804U9B@0204e=C@0>04Q8
B013@d<0BDU90492@P0n?Sh0@D5103lo?`11@D40@41004A4A013@d<0?clo04=3@`10@4020451@@08
03lo?`10@400@T9204I6AP1CDe<0GUiN06ATI01LG5`204m?C`0>05EEE@1>CTh0Cdm?04U9B@1>CTh0
Bd];04Y:BP1<C4`0ADE504Q8B01:BTX0B4Q8051@D018B4P204I6AP0B04U9B@1=CDd0CDe=04m?C`19
BDT0@d=30492@P10@400A4A404=3@`19BDT0BTY:04e=C@1CDe<0DU9B055AD@19BDT0@4100P12@T82
04=3@`0503hn?P0l?3`0@T920410@00o?cl00P0n?Sh02@16ATH0A4A404A4A016ATH0B4Q804U9B@1;
Bd/0A4A404=3@`0204I6AP0U04=3@`1:BTX0EUIF05aLG01XJ6P0MWIf08f=S@2HV9P0YJFU0:j^[P2l
_;`0_Kfm0:j^[P2DU9@0Q8B407alO01nOWh0LG5a0861P@2>SXh0TI6A09FEU@20P800N7Qh09FEU@2<
S8`0Lg=c06IVIP28R8P0QhN707YjNP1cLg<0K6a/06MWI`1GEeL0De=C06MWI`0205]KF`0<04m?C`1:
BTX0FEUI07EeM@1jNWX0PX:207QhN01fMWH0PH610820P01:BTX0?Shn0P17AdL01010@400ATI605=C
D`1DE5@404a<C00604];B`16ATH0>SXj03Xj>P0i>CT0>c/k0P0l?3`02@0k>c/0>SXj03Ph>00j>SX0
>c/k03Ti>@0k>c/0?Cdm03hn?P0203dm?@0703lo?`0m?Cd0?3`l03Xj>P0m?Cd0>c/k03`l?00303/k
>`0703lo?`0m?Cd0>c/k03dm?@0j>SX0>c/k03`l?00203/k>`0803`l?00j>SX0?3`l03dm?@10@400
>c/k03`l?00j>SX203Ti>@0@03/k>`0i>CT0?Cdm03/k>`0j>SX0?Cdm03Ti>@0h>3P0?3`l03lo?`0k
>c/0>SXj03dm?@0n?Sh0>SXj03`l?080?Cdm00P0>SXj03/k>`0j>SX0?Shn03`l?00i>CT0>c/k03Lg
=`80>3Ph0`0i>CT0200j>SX0?clo03Ti>@0i>CT0>c/k03Xj>P0h>3P0=cLg0P0i>CT01@0g=cL0?3`l
03`l?00m?Cd0>3Ph0080>CTi01P0=cLg03Ph>00k>c/0?3`l05YJFP1aLG40VIVI0:2PX02i^KT0/k>c
09BDU01eMGD0I6AT04M7A`0j>SX0=SHf03`l?00f=SH0>CTi03/k>`0h>3P0=SHf03Ph>00i>CT203Xj
>P0403Ti>@0j>SX0=CDe038b<P80=SHf0P0g=cL01@0i>CT0>c/k03Ph>00g=cL0>SXj0080>3Ph00@0
>c/k03Xj>P0i>CT0>SXj100k>c/02P0l?3`0>CTi03Lg=`0h>3P0?3`l03Ph>00g=cL0>c/k03Ti>@0k
>c/303Ph>080=cLg0P0f=SH203De=@0303Hf=P0j>SX0=SHf0080>CTi00T0=SHf03Lg=`0i>CT0=cLg
03Hf=P0h>3P0>SXj03dm?@0k>c/00P0e=CD203Ph>0@0=SHf0P0i>CT203De=@0903<c<`0f=SH0>CTi
03Hf=P0e=CD0=SHf03Lg=`0h>3P0=cLg0080=SHf0`0g=cL=ooooo`004?ooool204m?C`06059BDP1<
C4`0Bd];04e=C@1?Cdl0Bd];0P1<C4`0101?Cdl0D51@04Q8B01:BTX204m?C`0704U9B@17AdL0AdM7
04Y:BP1;Bd/0BTY:04];B`0204U9B@0304Y:BP18B4P0BDU90080Bd];0140BDU904Q8B018B4P0B4Q8
04a<C01;Bd/0CTi>04];B`18B4P0AdM704a<C017AdL0CDe=055AD@16ATH0B4Q804e=C@0204U9B@80
A4A401d0AdM704Y:BP11@D40@d=304U9B@17AdL0B4Q804a<C012@T80ATI604e=C@1:BTX0BDU904M7
A`12@T80ATI604U9B@18B4P0BTY:04=3@`11@D40ATI604A4A017AdL0ADE50492@P14A4@0ATI604=3
@`0203lo?`0404M7A`10@400?clo03lo?`80@41000h0A4A403`l?00o?cl0ATI604E5A@12@T80?Shn
0492@P17AdL0ADE503dm?@15ADD0?clo04A4A080?clo00P0@D5104Q8B00o?cl0ADE504A4A012@T80
?clo0451@@80A4A401@0@D5104I6AP19BDT0ADE50410@012@T80@d=303lo?`0n?Sh0@D5104I6AP0m
?Cd0?3`l04=3@`12@T80ATI604E5A@18B4P0@D510410@080@T9200P0@41003dm?@0o?cl0AdM705UI
F@1PH600Cdm?04a<C080DE5A00d0C4a<04];B`1;Bd/0BDU904m?C`1ADE40CDe=04m?C`1CDe<0CDe=
04A4A018B4P0Bd];0080DE5A00L0BTY:0492@P14A4@0ADE504Y:BP1;Bd/0@D510080ADE500@0Cdm?
04Q8B01;Bd/0BDU90P18B4P0101@D500Cdm?059BDP1IFET2059BDP0;05aLG01BDU80@T920410@00o
?cl0@41004A4A015ADD0A4A403lo?`15ADD00P11@D404P12@T80@D510410@015ADD0A4A404I6AP19
BDT0MWIf08:2PP1eMGD0JVYZ08N7Q`2PX:00Shn?07moO`1`L700J6QX05]KF`80FEUI00<0De=C059B
DP1NGUh00P1PH6004@1LG5`0I6AT06i^KP20P800SHf=0;Bd]034a<@0[Jf]07=cL`1ZJVX0UYJF09>C
T`2IVIT0QXJ6079bLP1lO7`0T92@0080Z:RX00P0ZZZZ0:>SX`2PX:00ZJVY08j>SP1OGel0D51@04E5
A@80BDU90200B4Q804e=C@1:BTX0EUIF051@D01PH600HV9R061PH01QHF40GUiN05eMG@1UIFD0H61P
06IVIP1bLW80NWYj06][J`1LG5`0E5AD055AD@1SHf<0G5aL065QH@1EEED0A4A403lo?`0m?Cd0>c/k
03dm?@0i>CT0>SXj03/k>`80@4100P0l?3`03@0n?Sh0?Cdm03/k>`0m?Cd0@41003dm?@10@400?Shn
03lo?`14A4@0@d=30492@P0m?Cd00`0l?3`01@0k>c/0>SXj03Xj>P0l?3`0@D510080>c/k0P0l?3`0
100j>SX0?3`l0410@00m?Cd203`l?00A03Ti>@0k>c/0>SXj03Ti>@0j>SX0>c/k03Ti>@0k>c/0>CTi
03/k>`0m?Cd0>c/k03`l?00k>c/0>SXj03`l?00i>CT00P0j>SX0400i>CT0>3Ph03Ph>00i>CT0>3Ph
03`l?00i>CT0>c/k03Lg=`0m?Cd0?3`l03/k>`0m?Cd0>c/k03Ti>@0k>c/203Ti>@0303`l?00o?cl0
>c/k0080?3`l00P0?Shn03`l?00j>SX0>CTi03/k>`0n?Sh0A4A405QHF080J6QX00P0De=C05MGE`1M
GEd0B4Q803Xj>P0k>c/0>CTi03Ph>080=cLg00/0>3Ph03Ti>@0h>3P0>3Ph03Xj>P0i>CT0?Cdm03/k
>`0i>CT0>c/k03Ph>00203Hf=P0803Lg=`0e=CD0>SXj03`l?00i>CT0=cLg03Ti>@0j>SX203Ti>@08
03Ph>00n?Sh0>c/k03Xj>P0l?3`0>SXj03dm?@0h>3P203/k>`0D03Lg=`0e=CD0>SXj03Ph>00i>CT0
=SHf03Lg=`0h>3P0>SXj03Ph>00i>CT0>SXj03Ti>@0j>SX0?Shn03lo?`0l?3`0>CTi03Ph>00g=cL2
03Hf=P0903Lg=`0d=3@0=SHf03Ph>00c<c<0>SXj03Ti>@0k>c/0>3Ph0080=cLg00P0=SHf03Ti>@0k
>c/0>SXj03Lg=`0f=SH0=cLg03Ph>080=CDe0`0f=SH00`0h>3P0>CTi03Hf=P0303Ti>@0603Lg=`0i
>CT0=3@d03De=@0h>3P0>c/k3Oooool0013ooooo00X0Cdm?04a<C01=CDd0BTY:04];B`1<C4`0Bd];
04a<C01;Bd/0BDU90P1:BTX09@19BDT0ATI604Q8B01;Bd/0CTi>04a<C01=CDd0BDU904a<C019BDT0
ADE504Y:BP18B4P0C4a<04Q8B017AdL0BTY:04Q8B01=CDd0A4A404U9B@14A4@0B4Q804M7A`16ATH0
BDU904Q8B016ATH0AdM704E5A@16ATH0A4A404M7A`1:BTX0ATI604M7A`16ATH00P18B4P00`19BDT0
C4a<04U9B@0204I6AP0604=3@`18B4P0AdM704Q8B01;Bd/0@T920`14A4@00`13@d<0A4A404M7A`02
04A4A00404=3@`10@400ADE504=3@`80AdM70P11@D405`16ATH0@d=303hn?P0o?cl0?Shn0492@P0l
?3`0AdM70410@011@D40?clo03dm?@11@D40?clo0410@014A4@0?Shn04=3@`14A4@0?clo04E5A@0n
?Sh0@4100080?clo0180@T9204=3@`17AdL0A4A40451@@0n?Sh0@41004=3@`0o?cl0@T9204A4A012
@T80@41004Y:BP1;Bd/0A4A404Q8B010@4020492@P0304=3@`16ATH0@41000<0?Shn00<0A4A403lo
?`13@d<00P10@4001@14A4@0AdM7051@D01OGel0G5aL0080E5AD00T0D51@04M7A`14A4@0AdM704I6
AP15ADD0@d=304M7A`15ADD00P0o?cl01P11@D40@d=303/k>`0m?Cd0?Shn0492@P<0@41000<0?clo
03/k>`10@4000P12@T804@0m?Cd0ATI60492@P16ATH0@d=30410@013@d<0?Shn0451@@0o?cl0@T92
0410@00l?3`0@4100492@P0n?Sh0@41000<0@D5100D0@T9204Y:BP1ADE40HF5Q06UYJ@0306ATI00>
05YJFP1EEED0GemO05IFEP1ADE40DU9B04e=C@15ADD0GemO08:2PP2FUYH0VYZJ0;jn_P3=cLd20=OG
e`0/0<g=c@33`l<0[:b/0:JVYP2HV9P0RXZ:07EeM@1VIVH0EUIF04m?C`16ATH0=cLg04=3@`11@D40
Cdm?06MWI`2?Shl0V9RH06ATI016ATH0CTi>055AD@1IFET0E5AD04A4A013@d<0ATI605YJFP1VIVH0
Kfm_065QH@1NGUh0K6a/079bLP1^KVh0HV9R04Q8B01<C4`0BDU904i>CP1XJ6P0PX:209VIV@2][Jd2
0<G5a@0P0<o?c`3@d=00/[:b09RHV01iNGT0LG5a06MWI`1]KFd0M7Ad08N7Q`28R8P0MWIf05UIF@1?
Cdl0Bd];06UYJ@23Ph<0NGUi08Z:RP27QhL0NGUi08B4Q01]KFd0A4A40451@@0o?cl0?Cdm03Ti>@0j
>SX0?Cdm03Xj>P0l?3`303Xj>P0:03`l?00h>3P0>SXj03Xj>P0k>c/0?Cdm03`l?00i>CT0>c/k03hn
?P80?3`l00@0>SXj03`l?011@D40?clo0P0n?Sh0200l?3`0@d=303dm?@0k>c/0>SXj03`l?00k>c/0
?Cdm0`0k>c/203Ti>@0<03/k>`0o?cl0?3`l03Xj>P0m?Cd0>c/k03dm?@0l?3`0>CTi03/k>`0m?Cd0
=cLg0P0i>CT02@0h>3P0>CTi03Ti>@0j>SX0>CTi03dm?@0n?Sh0?Cdm03/k>`0203Ti>@80?3`l00l0
>SXj03dm?@0n?Sh0>SXj03Ph>00j>SX0?3`l03/k>`0j>SX0>CTi03`l?00h>3P0=cLg03Xj>P0k>c/0
0`0i>CT0100l?3`0>CTi03/k>`0j>SX203/k>`0403Ph>00j>SX0>c/k03Xj>P80?Shn00H0>SXj03Ti
>@0i>CT0>CTi03Lg=`0j>SX203Ti>@0803/k>`0i>CT0=cLg03Ph>00k>c/0>SXj03Ti>@0h>3P203Xj
>P80>3Ph00<0>CTi03`l?00j>SX00P0j>SX02P0m?Cd0?Shn03Hf=P0j>SX0?3`l03/k>`0g=cL0>SXj
0410@00i>CT203De=@0303Ti>@0j>SX0>CTi0080>3Ph00H0>CTi03Ph>00g=cL0>3Ph03Lg=`0h>3P2
03Ti>@0303Ph>00g=cL0=cLg0080>3Ph00d0>SXj03Ph>00g=cL0=cLg03Ph>00g=cL0>CTi03Ph>00g
=cL0>SXj03Ph>00g=cL0>CTi0080=SHf00@0>CTi03Ph>00g=cL0>3Ph0P0g=cL01@0e=CD0=3@d03Hf
=P0h>3P0=cLg0080=SHf00L0=cLg03Hf=P0i>CT0=cLg03Hf=P0e=CD0=SHf00gooooo000@ooooo`80
CTi>00X0CDe=04U9B@1>CTh0C4a<04U9B@1;Bd/0B4Q804M7A`19BDT0BTY:0`17AdL01P1<C4`0Cdm?
04];B`1;Bd/0AdM704Q8B080ADE501@0Bd];04M7A`18B4P0BDU904a<C01=CDd0BTY:04i>CP13@d<0
ATI604];B`1?Cdl0ADE504=3@`15ADD0A4A404I6AP1;Bd/0B4Q804E5A@80ATI600X0B4Q804E5A@11
@D40ATI604U9B@15ADD0@D5104I6AP15ADD0@d=30P15ADD01`13@d<0@D5104A4A016ATH0@d=304E5
A@13@d<00P15ADD204A4A00I04E5A@11@D40@T920451@@14A4@0@D5104=3@`15ADD0A4A40492@P13
@d<0A4A404E5A@13@d<0A4A40451@@12@T80ADE50410@011@D40?clo0451@@10@400@d=30451@@02
0492@P030410@00n?Sh0?Shn0080A4A400H0@41003lo?`0k>c/0?Shn03lo?`11@D420410@00?03lo
?`13@d<0?clo04E5A@1<C4`0BTY:04E5A@1@D500Kfm_06EUI@1>CTh0@d=303lo?`14A4@0@T920080
?clo00D0?Shn03lo?`0m?Cd0?Shn04I6AP0304A4A00<05ADE01TI6@0JFUY06QXJ01TI6@0EeMG04Q8
B01;Bd/0C4a<0492@P0m?Cd0@4100P11@D401`15ADD0@D5103hn?P0o?cl0@D510410@012@T800`0n
?Sh01P0o?cl0@41004E5A@15ADD0@T920410@080@D5100d0@T9204I6AP15ADD0@d=304A4A017AdL0
@T9204E5A@11@D40?3`l0451@@0o?cl0?Shn00<0?clo0140?Cdm03Ti>@0l?3`0@41003hn?P10@400
ATI604Q8B016ATH0@T9204a<C01@D500FUYJ06IVIP1^KVh0MgMg06e]K@02065QH@0N07emO@21PH40
Ng]k071`L01VIVH0F5QH05IFEP1]KFd0PH6108n?S`2DU9@0Shn?08V9R@2EUID0WIfM0;Vi^@32`/80
_;bl0;^k^`2c/k<0Ti>C06YZJP1VIVH0Fe]K075aL@29RHT0Ph>308F5Q@1VIVH0MWIf0P2ATI402P2;
Rh/0RHV908^;R`2OWil0JVYZ04I6AP12@T80@d=303dm?@0k>c/20410@00X03`l?01<C4`0B4Q804];
B`1HF5P0B4Q804Y:BP1QHF40LG5a07]kN`1hN7P0OGem096AT@2g]kL0/K6a0:RXZ02PX:00W9bL09BD
U01nOWh0KVi^07]kN`2FUYH0WinO0;Rh^01lO7`0Bd];0451@@10@400ATI604=3@`1:BTX0GUiN06MW
I`1IFET0ATI60451@@0o?cl0?Shn03`l?080?Cdm00<0>SXj03Ph>00i>CT00`0k>c/0:`0h>3P0>c/k
03Ph>00j>SX0>c/k03`l?00m?Cd0@D5104E5A@12@T80?3`l03Xj>P0l?3`0@41003dm?@0j>SX0?Cdm
03`l?00m?Cd0>SXj03`l?00m?Cd0>3Ph03/k>`12@T80?Cdm03Xj>P0m?Cd0>c/k03hn?P0m?Cd0>c/k
03lo?`15ADD0C4a<04I6AP11@D40?Cdm03Ti>@0n?Sh0@T9203/k>`0j>SX00P0i>CT203Xj>P0403dm
?@0k>c/0>c/k03Lg=`80>CTi00D0?Cdm03`l?00k>c/0?3`l03Ti>@0203Ph>0<0>SXj00@0>3Ph03Ti
>@0h>3P0>CTi0`0j>SX02`0h>3P0>CTi03Xj>P0i>CT0>SXj03`l?00k>c/0>3Ph03Ti>@0m?Cd0?3`l
0080>SXj00d0=cLg03@d=00f=SH0>3Ph03Lg=`0h>3P0>SXj03Ti>@0g=cL0>CTi03/k>`0j>SX0>3Ph
0080>SXj00H0>3Ph03Xj>P0j>SX0=cLg03Hf=P0i>CT203Xj>P80=SHf00d0=cLg03Ph>00l?3`0@T92
03Xj>P0e=CD0>3Ph03Ti>@0k>c/0>SXj03Lg=`0m?Cd0?3`l0080=cLg00<0?3`l03Ti>@0h>3P00P0g
=cL0200f=SH0>3Ph03Ti>@0i>CT0=CDe03Xj>P0k>c/0=SHf100g=cL02`0j>SX0@41003/k>`0f=SH0
>3Ph03Xj>P0i>CT0>c/k03Ph>00i>CT0>3Ph00@0=SHf00L0=CDe03<c<`0e=CD0=SHf03Ph>00g=cL0
=SHf00<0=cLg00P0>3Ph03Ti>@0i>CT0>3Ph03De=@0f=SH0=CDe03Ph>080=cLg00<0>3Ph03Xj>_oo
ool03?ooool0013ooooo00<0DE5A04m?C`1<C4`00P1<C4`04`1;Bd/0CTi>04i>CP19BDT0B4Q804];
B`1<C4`0AdM704Y:BP18B4P0AdM704U9B@1:BTX0B4Q804Y:BP17AdL0ADE504U9B@17AdL00P19BDT2
04a<C00304I6AP19BDT0BDU90080BTY:00l0AdM704U9B@14A4@0ADE504A4A015ADD0ATI604Y:BP15
ADD0AdM704I6AP1<C4`0AdM70451@@15ADD00P16ATH06`18B4P0A4A404I6AP12@T80A4A404M7A`1:
BTX0BDU904I6AP11@D40A4A40451@@1;Bd/0BDU904I6AP12@T80A4A404=3@`12@T80A4A404Y:BP11
@D40ADE504I6AP13@d<0@D5104=3@`020492@P0<04A4A015ADD0ADE504M7A`13@d<0?clo03dm?@10
@400?Shn04A4A015ADD0A4A40P11@D4204=3@`050410@00l?3`0?clo03lo?`10@4000P0o?cl0>00n
?Sh0@D510451@@14A4@0ATI60492@P0o?cl0@T9204=3@`1<C4`0EeMG05iNGP17AdL0DU9B069RHP1C
De<0A4A403dm?@11@D40?Shn0492@P0m?Cd0?clo03dm?@15ADD0CTi>04];B`1=CDd0BDU904a<C01F
EUH0HF5Q05mOG`1IFET0DE5A04];B`17AdL0@T9204Q8B014A4@0@41003dm?@11@D40@T920451@@10
@400@d=303lo?`10@400?Cdm03`l?00o?cl0A4A40492@P0o?cl0?3`l0P0m?Cd01@14A4@0?Shn03dm
?@0m?Cd0@D5100@0?clo00T0?Cdm0492@P0o?cl0ATI60451@@12@T80ATI604E5A@16ATH00P1<C4`0
1`1;Bd/0CTi>04U9B@16ATH0E5AD07EeM@2DU9@00P2EUID05@2FUYH0T92@07IfMP1OGel0EeMG05EE
E@1GEeL0D51@04];B`16ATH0A4A404e=C@1@D500EEEE06UYJ@1`L700JFUY05mOG`1BDU80BDU904A4
A00204=3@`0L04A4A018B4P0CTi>05EEE@1SHf<0MGEe09>CT`2MWId0TI6A09JFUP2JVYX0YZJV0;Rh
^032`/80_[jn0;:b/P2GUiL0Vi^K0:ZZZP2e]KD0/K6a0;>c/`33`l<0aLG507EeM@1<C4`0A4A404E5
A@80?clo00H0BTY:05MGE`1=CDd0@T920451@@13@d<204U9B@0304=3@`11@D40AdM70080@d=300D0
AdM704Q8B017AdL0JFUY0:BTY0030=;BdP80clo?01T0]kNg09fMW@2_[jl0fMWI0=3@d02e]KD0N7Qh
04Q8B00j>SX0?Shn04a<C01NGUh0HV9R065QH@1VIVH0@41003lo?`0m?Cd0>c/k03dm?@0l?3`0>c/k
03Xj>P0i>CT0?Cdm0080>SXj00H0>3Ph03/k>`0j>SX0?3`l03Ti>@0l?3`503Ti>@0303/k>`0l?3`0
?3`l0080?Cdm00H0@41003Lg=`0j>SX0>SXj03`l?00i>CT203dm?@0C03lo?`0m?Cd0>c/k03`l?00g
=cL0?3`l04=3@`1NGUh0SXj>0:f][@2o_kl0/k>c08j>SP1RHV80BDU904a<C017AdL0@T9203/k>`02
03Ti>@80>c/k00L0>CTi03/k>`0h>3P0>c/k03`l?00m?Cd0@4100080>c/k0P0i>CT0100j>SX0>CTi
03Ti>@0h>3P203Lg=`0303/k>`0f=SH0>SXj0080>c/k0P0j>SX03`0h>3P0>CTi03Ti>@0m?Cd0>3Ph
03`l?00j>SX0=SHf03Ph>00f=SH0A4A403/k>`0l?3`0=cLg03Hf=P0203Lg=`0303Hf=P0j>SX0>c/k
0080>SXj00L0>CTi03Xj>P0j>SX0>c/k03Ti>@0f=SH0>3Ph0080=SHf00P0>SXj03/k>`0k>c/0>3Ph
03Hf=P0h>3P0=SHf03/k>`80>CTi00l0?Shn03Xj>P0f=SH0>3Ph03/k>`0l?3`0>c/k03Ti>@0f=SH0
>3Ph03Hf=P0k>c/0?Shn03Ti>@0f=SH00P0h>3P303Ti>@0403Lg=`0h>3P0>3Ph03Ph>080=CDe0P0f
=SH00`0g=cL0>CTi03Ti>@0203Ph>00303`l?00g=cL0>SXj0080>CTi00@0=cLg03Hf=P0i>CT0>3Ph
0P0e=CD01P0g=cL0=CDe03Lg=`0i>CT0=SHf03De=@@0>3Ph00<0=SHf03Ph>00h>3P00P0g=cL01P0e
=CD0=cLg03Lg=`0f=SH0=cLg03Ph>0gooooo000@ooooo`80Cdm?00<0D51@04i>CP1<C4`00P1;Bd/2
04a<C00304Y:BP1;Bd/0BTY:0080B4Q800D0BTY:04E5A@1<C4`0Bd];04Q8B00204U9B@0B04a<C017
AdL0DU9B05IFEP1:BTX0AdM704Q8B017AdL0ATI604M7A`16ATH0B4Q804A4A017AdL0A4A40492@P15
ADD0AdM70P19BDT01`16ATH0BTY:04I6AP18B4P0@d=304I6AP11@D400`13@d<304A4A080AdM700<0
ADE50451@@11@D400P15ADD00`0o?cl0@D5104=3@`020492@P0C0410@011@D40?clo0451@@13@d<0
?Shn0410@00o?cl0ATI60451@@12@T80BTY:0492@P13@d<0A4A404=3@`15ADD0@d=30492@P0203lo
?`0803hn?P13@d<0A4A404=3@`11@D40A4A403lo?`10@4020492@P0k04=3@`10@400?Shn04I6AP1@
D500BDU904E5A@16ATH0Cdm?055AD@1?Cdl0BDU9055AD@1:BTX0A4A404E5A@14A4@0?clo0451@@0n
?Sh0?Cdm03lo?`0m?Cd0?clo0451@@17AdL0@4100451@@16ATH0Fe]K05mOG`1?Cdl0@T9204A4A010
@400BDU904I6AP17AdL0ATI60492@P0o?cl0@D5104=3@`11@D40?Cdm03`l?011@D40@T9203hn?P12
@T80>CTi0410@00m?Cd0@41003lo?`12@T80@d=30410@011@D400P12@T803P10@400>c/k03lo?`0m
?Cd0@41003lo?`12@T80@D510410@00l?3`0?Shn03/k>`10@400?Cdm0P0o?cl08P0n?Sh0A4A4059B
DP2<S8`0Shn?05EEE@1QHF40JVYZ07UiN@1aLG40PX:208Z:RP29RHT0O7al07MgM`26QXH0U9BD08n?
S`28R8P0OWin07=cL`1SHf<0J6QX06e]K@1dM7@0K6a/065QH@1HF5P0C4a<03lo?`0l?3`0@d=303lo
?`11@D420410@00O0451@@14A4@0?3`l04i>CP2BTY80/[:b0;bl_02PX:00QhN70:FUY@2`/;00alO7
0;no_`39bLT0e]KF0=GEe@3@d=00^;Rh0<?3``2l_;`0[:b/0:^[Z`2DU9@0QhN70861P@1oOgl0NGUi
0820P02ATI40SHf=08:2PP0207QhN00/07YjNP1XJ6P0FUYJ06=SH`1YJFT0D51@04E5A@1:BTX0DE5A
051@D017AdL0BDU9055AD@1FEUH0DE5A05=CD`1WIfL0QhN708F5Q@2PX:00/;2`09^KV`2:RXX0QHF5
08R8R02g]kL0alO70<c<c03=cLd0W9bL06][J`1MGEd0BTY:04M7A`1EEED0MWIf08J6QP1lO7`0M7Ad
06e]K@1HF5P0BDU90451@@0l?3`203dm?@0403Xj>P0n?Sh0>CTi04A4A080?Shn0P0k>c/00`0g=cL0
?3`l03hn?P0203Xj>P0303Lg=`0n?Sh0>CTi0080>SXj00P0>c/k03Xj>P0g=cL0=cLg03`l?00h>3P0
?3`l03dm?@80?Shn0P0l?3`06`0m?Cd0>c/k04I6AP17AdL0IVIV07AdM01gMgL0Jf][061PH01DE5@0
Bd];04a<C01RHV80JFUY04E5A@0o?cl0>CTi03dm?@10@400>3Ph03lo?`0m?Cd0>CTi03Xj>P0l?3`0
?Shn03lo?`0303Ti>@0303`l?00m?Cd0?3`l0080>3Ph00l0>CTi03Ph>00j>SX0>CTi03Ph>00f=SH0
>SXj03lo?`0m?Cd0>CTi03hn?P0l?3`0>CTi03Lg=`0m?Cd00P0j>SX0400g=cL0>CTi0410@00i>CT0
=SHf03Ti>@0g=cL0>SXj03Ti>@0f=SH0>3Ph03`l?00k>c/0>SXj03Lg=`0k>c/203Ph>00603Xj>P0l
?3`0=cLg03De=@0f=SH0=cLg0P0i>CT04`0e=CD0>SXj03Ti>@0i>CT0>SXj03/k>`0h>3P0>CTi03Xj
>P0g=cL0>3Ph03Ti>@0j>SX0=SHf03hn?P0i>CT0>SXj03Hf=P0k>c/00P0h>3P01`0g=cL0>3Ph03Lg
=`0e=CD0=SHf03Ph>00i>CT00P0j>SX00`0i>CT0=3@d03<c<`0203Lg=`0303Hf=P0i>CT0?Shn0080
A4A400@0B4Q80492@P0i>CT0=SHf0P0g=cL06P0h>3P0=cLg03De=@0g=cL0>3Ph03Hf=P0g=cL0>CTi
03Hf=P0e=CD0=cLg03De=@0f=SH0=CDe03@d=00g=cL0>CTi03Lg=`0f=SH0=CDe03Lg=`0f=SH0=cLg
03Ph>00i>CT0>SXj3Oooool0013ooooo00T0CTi>051@D01?Cdl0CTi>04m?C`1;Bd/0CDe=04];B`1=
CDd00P1;Bd/02019BDT0C4a<04a<C01?Cdl0Bd];04e=C@1:BTX0AdM70P18B4P05@17AdL0BDU904a<
C01=CDd0ATI604Q8B019BDT0B4Q804Y:BP1=CDd0BDU904E5A@14A4@0B4Q804A4A016ATH0ADE504Y:
BP15ADD0A4A404E5A@0204Q8B0<0ATI600L0ADE504U9B@15ADD0B4Q804A4A015ADD0@d=30080A4A4
00X0@d=30410@012@T80ADE504I6AP14A4@0@T920451@@13@d<0ADE50P13@d<01010@400A4A404=3
@`13@d<203hn?P0A04M7A`12@T80ATI60492@P15ADD0@D5104Q8B016ATH0@41003dm?@0o?cl0@D51
03hn?P0m?Cd0A4A40451@@12@T800`11@D40100o?cl0@41004A4A016ATH20451@@0=04E5A@16ATH0
A4A40451@@13@d<0ADE504];B`18B4P0AdM70451@@12@T80?Cdm04A4A0020492@P0C04A4A016ATH0
@T920492@P15ADD0@d=30492@P15ADD0B4Q80410@011@D40?Cdm0451@@0n?Sh0@41003lo?`0n?Sh0
@D5103dm?@0204E5A@0<0410@00o?cl0?clo04=3@`0n?Sh0@d=303lo?`10@400@D5103lo?`0n?Sh0
BTY:0P0o?cl01`0n?Sh0@D510451@@10@400?3`l0492@P11@D400P10@4001@11@D40?Shn03hn?P13
@d<0A4A40080@T9200D0ATI604=3@`11@D40?clo0451@@0203hn?P0804=3@`12@T80Fe]K08:2PP2/
[:`0SHf=05QHF01:BTX204M7A`0V0451@@16ATH0B4Q804M7A`1;Bd/0@d=304I6AP1?Cdl0CDe=04Y:
BP1=CDd0B4Q804I6AP1=CDd0EUIF05eMG@1PH600I6AT05mOG`1FEUH0ADE50410@016ATH0De=C0492
@P17AdL0@d=304E5A@12@T80?Cdm04=3@`1;Bd/0Cdm?06QXJ01_Kfl0M7Ad08F5Q@1lO7`208:2PP0G
08^;R`2KVi/0[:b/0:FUY@2`/;00/[:b0;Fe]@2i^KT0/;2`09nOW`2:RXX0MGEe06ATI01BDU80Bd];
04Y:BP1EEED0H61P06ATI01ZJVX0KVi^08n?S`2l_;`00P3AdM40:@2XZ:P0JVYZ0451@@19BDT0DU9B
04a<C013@d<0EEEE0861P@28R8P0GUiN04Y:BP1=CDd0De=C06ATI01[Jf/0JFUY06EUI@1ZJVX0FUYJ
07EeM@23Ph<0ZZZZ0<O7a`30`<00b/[:0;Zj^P27QhL0PH6106m_K`1VIVH0Ng]k09FEU@2][Jd0_Kfm
0;>c/`2OWil0QXJ607IfMP1KFe/0C4a<0080>3Ph00L0>SXj0492@P0k>c/0?clo03Xj>P0i>CT0>3Ph
00<0?3`l00L0>3Ph03Xj>P0n?Sh0>3Ph03Xj>P0m?Cd0?3`l0080>3Ph0P0m?Cd03P0i>CT0>c/k03hn
?P0m?Cd0>SXj03Ti>@0o?cl0@D510410@00n?Sh0@D5103hn?P0m?Cd0>CTi0P0j>SX0200n?Sh0@T92
0410@011@D40@41003Lg=`0i>CT0>3Ph0P0i>CT02P0j>SX0?Shn03Ti>@0h>3P0>CTi03lo?`0i>CT0
>SXj03Hf=P0h>3P203Xj>P0F03Ti>@0j>SX0>c/k03`l?00m?Cd0>3Ph03`l?00j>SX0>CTi03Lg=`0k
>c/0>CTi03Ph>00m?Cd0>SXj03Ti>@0f=SH0>CTi03Hf=P0m?Cd0?3`l03Ti>@80>3Ph0280?Cdm03Ph
>00h>3P0=3@d03Lg=`0i>CT0?3`l03Ti>@0e=CD0=cLg03Xj>P0h>3P0>CTi03hn?P0j>SX0>CTi03`l
?00i>CT0>3Ph03Lg=`0h>3P0?Cdm03Xj>P0h>3P0>SXj03@d=00j>SX0>c/k03Xj>P0o?cl0?Cdm03Xj
>P0f=SH0=cLg0P0i>CT203Hf=P80>CTi0P0g=cL203Ti>@0603Lg=`0c<c<0=cLg03Xj>P0f=SH0=cLg
1@0h>3P04`0d=3@0>3Ph03/k>`10@400De=C061PH01FEUH0E5AD04E5A@0g=cL0=3@d03Ph>00l?3`0
>SXj03Ti>@0j>SX0=CDe03Ph>00i>CT00P0d=3@303Hf=P0303Lg=`0f=SH0=cLg0080=cLg00H0=SHf
03De=@0g=cL0=CDe03Lg=`0f=SH503Ph>0gooooo000@ooooo`09055AD@1@D500CDe=051@D01=CDd0
Bd];04m?C`1<C4`0D51@0080CTi>00D0Bd];04Y:BP19BDT0C4a<04];B`0204M7A`0L04a<C01>CTh0
BTY:04M7A`18B4P0BDU904a<C01:BTX0C4a<04U9B@18B4P0BDU904];B`18B4P0ADE504M7A`19BDT0
ATI604U9B@1;Bd/0BDU904a<C01:BTX0A4A404Q8B01>CTh0Bd];04E5A@80A4A400D0AdM70492@P17
AdL0@d=304A4A0030492@P0;0410@015ADD0A4A40451@@10@400B4Q804=3@`10@400@D5104Q8B014
A4@00P15ADD03@18B4P0@D510410@013@d<0BTY:04E5A@13@d<0@D5104=3@`0l?3`0@D5105IFEP15
ADD00P0k>c/03`0l?3`0@D5103lo?`0k>c/0?Shn03`l?013@d<0@41003lo?`11@D40?Shn03dm?@10
@400ATI604A4A0020451@@0:0410@00n?Sh0@41004I6AP1:BTX0AdM703hn?P15ADD0@D5103dm?@<0
@D5100H0>SXj04E5A@13@d<0@d=30410@012@T820410@00>0451@@13@d<0@41003hn?P0j>SX0?3`l
03/k>`0l?3`0>3Ph0410@014A4@0?Shn04Q8B017AdL203lo?`0403hn?P12@T80>SXj0451@@80?Cdm
00D0?Shn0410@00n?Sh0ATI604E5A@020492@P0;03hn?P11@D40@d=304=3@`18B4P0@d=30410@011
@D40@4100492@P0o?cl00P1=CDd06@0j>SX0@T9204=3@`11@D40?Shn0410@012@T80?Cdm0492@P1:
BTX0ATI605ADE01]KFd0MGEe08>3P`25QHD0OWin065QH@1ADE40De=C04m?C`1@D500GUiN061PH01C
De<00P12@T801017AdL0@D5104E5A@10@4030492@P0C04E5A@0l?3`0AdM704e=C@16ATH0B4Q80492
@P17AdL0CTi>04Q8B01?Cdl0ADE504U9B@18B4P0A4A403lo?`10@400?Shn03`l?00203dm?@0F03hn
?P0o?cl0@D5104A4A012@T80ADE504M7A`15ADD0CTi>04Y:BP1?Cdl0JFUY07moO`22PX80Ph>307al
O01mOGd0Lg=c06e]K@1ZJVX0I6AT051@D080DE5A0400K6a/0:6QX@3IfMT0eMGE0<k>cP31`L40Vi^K
075aL@1fMWH0GUiN05IFEP1=CDd0CTi>06YZJP27QhL0L71`0492@P0m?Cd0BDU907EeM@13@d<0ATI6
04M7A`1@D500ATI605=CD`1MGEd0LG5a08B4Q02;Rh/0U9BD09:BTP26QXH0/[:b09nOW`2:RXX0Lg=c
07inOP24Q8@0RXZ:08R8R02@T900QHF507YjNP1]KFd0LG5a04a<C00l?3`0=cLg03dm?@0g=cL0?3`l
03dm?@0l?3`0>3Ph03Ti>@0j>SX0?3`l03Ti>@0g=cL0>c/k03Ph>00l?3`0>CTi0P0j>SX203`l?003
03hn?P0j>SX0ATI600<0>SXj0`0k>c/01P0o?cl0?3`l03hn?P0i>CT0?3`l03Ti>@80>SXj00T0?Cdm
03lo?`0k>c/0?Shn03lo?`0l?3`0>3Ph03Xj>P0i>CT00P0h>3P203Ti>@0303Lg=`0l?3`0=SHf0080
>CTi00D0>c/k03Ti>@0d=3@0=SHf03Ph>00203/k>`0>03Ti>@0j>SX0>SXj03`l?00i>CT0=cLg03Ti
>@0l?3`0=SHf03Lg=`0n?Sh0>SXj03Ti>@0e=CD303Xj>P0<03Ti>@0f=SH0>CTi03Hf=P0i>CT0=cLg
03Hf=P0e=CD0=cLg03/k>`0j>SX0>3Ph0P0g=cL02`0m?Cd0?3`l03Lg=`0j>SX0=cLg03Ti>@0j>SX0
>3Ph03Ti>@0h>3P0=cLg0080>3Ph00<0>CTi03Ph>00i>CT00`0j>SX0200i>CT0>SXj03/k>`0f=SH0
=3@d03lo?`0j>SX0>3Ph0`0g=cL02`0i>CT0>3Ph03Lg=`0i>CT0>3Ph03@d=00e=CD0>3Ph03<c<`0e
=CD0=SHf0080=cLg00<0=SHf03Ph>00f=SH00P0i>CT203`l?00;03/k>`0f=SH0?3`l03Lg=`0e=CD0
=SHf03Lg=`0k>c/0>CTi03Lg=`0i>CT00P0h>3P01@0f=SH0=3@d038b<P0c<c<0=CDe0080=SHf00`0
=cLg03Hf=P0f=SH0=cLg03Ph>00d=3@0=SHf030`<00i>CT0?Cdm0451@@0h>3P303Lg=`gooooo000@
ooooo`06051@D01?Cdl0Bd];051@D01>CTh0Bd];0P1<C4`03`1=CDd0BTY:04];B`1:BTX0Bd];04Q8
B01;Bd/0C4a<04Q8B019BDT0AdM704I6AP18B4P0C4a<04Q8B00204U9B@0504Y:BP1<C4`0ATI604I6
AP15ADD00P16ATH02@15ADD0A4A404I6AP12@T80ADE504M7A`16ATH0B4Q804M7A`0204A4A00304I6
AP12@T80A4A40080@d=301H0A4A404Q8B01;Bd/0BDU904I6AP13@d<0@T920451@@10@400@T920451
@@0o?cl0@T9204E5A@14A4@0@T920451@@12@T80@D5104E5A@12@T80ADE50P11@D403014A4@0@d=3
04A4A011@D40@4100451@@15ADD0@d=306IVIP1SHf<0?Shn0492@P80@D5100L0@d=303lo?`11@D40
@41004A4A00o?cl0?Cdm0080?Shn00/0@T9203lo?`12@T80?clo0410@012@T80?clo0451@@0n?Sh0
@41004I6AP020492@P060410@011@D40@d=304=3@`10@400@d=30P14A4@01@0o?cl0ADE50451@@13
@d<0@T920080@41000@0ATI603lo?`0i>CT0?3`l0`13@d<02`0n?Sh0?Cdm03/k>`0m?Cd0@d=304A4
A00o?cl0?Shn0451@@0o?cl0>c/k00<0?Shn00T0?Cdm0451@@0o?cl0?Shn0451@@0n?Sh0@D510410
@012@T800P15ADD01`19BDT0A4A404=3@`16ATH0?Cdm03hn?P0k>c/00P13@d<01`0o?cl0@D510451
@@15ADD0?Shn0410@00n?Sh00`12@T808`16ATH0A4A404Y:BP1?Cdl0EeMG05eMG@1VIVH0JVYZ061P
H01CDe<0EUIF05YJFP1bLW80P82008V9R@1iNGT0I6AT055AD@1?Cdl0C4a<04e=C@1BDU80G5aL051@
D01BDU80CTi>04m?C`1EEED0E5AD05EEE@1;Bd/0@T9204=3@`1>CTh0De=C0080A4A400H0ATI604i>
CP1DE5@0CDe=04Y:BP11@D4203dm?@0A03lo?`18B4P0@T9204E5A@13@d<0?clo0410@011@D40@410
03dm?@0o?cl0B4Q8059BDP1ADE40BDU904A4A018B4P00P1:BTX07@1EEED0I6AT069RHP1UIFD0Hf=S
06IVIP1nOWh0WIfM09bLW02PX:00ZZZZ0:^[Z`2/[:`0ZJVY09nOW`2ZZZX0YjNW09fMW@2UYJD0[jn_
0;Bd]02UYJD0R8R805eMG@1GEeL0@41003hn?P18B4P0ATI60080ADE501H0@d=304];B`1FEUH0KVi^
07EeM@1cLg<0K6a/08R8R02<S8`0Shn?08b<S02GUiL0UIFE06][J`1MGEd0MWIf079bLP1KFe/0FEUI
05EEE@17AdL0@T920P0o?cl01@0l?3`0?clo0410@012@T80?3`l0080>SXj00<0?3`l03Xj>P0j>SX0
0P0k>c/02P11@D40?Cdm03Ph>00i>CT0?3`l03hn?P0o?cl0>c/k0451@@0j>SX203/k>`0U03Xj>P0m
?Cd0>CTi03/k>`0i>CT0>c/k03dm?@0l?3`0?Cdm03/k>`0n?Sh0?Cdm03hn?P0i>CT0?Cdm03Ti>@0k
>c/0=SHf03Ph>00j>SX0?3`l03dm?@0k>c/0?3`l03/k>`10@400>3Ph03lo?`0i>CT0>3Ph03`l?00o
?cl0>c/k03Ph>00l?3`0>c/k03Lg=`0203Xj>P80>CTi00L0>3Ph03Xj>P0l?3`0>3Ph03Ti>@0n?Sh0
?3`l0080>SXj00h0>3Ph03Xj>P0i>CT0?Cdm03/k>`0h>3P0>SXj03/k>`0h>3P0=CDe03Ti>@0h>3P0
>SXj03Ti>@80>SXj00H0>CTi03Ph>00l?3`0>SXj03Ti>@0g=cL203Ph>00@03Ti>@0l?3`0?3`l03/k
>`0j>SX0>CTi03dm?@0k>c/0?3`l03Ph>00i>CT0?3`l03/k>`0j>SX0?Cdm03/k>`@0>SXj00T0>c/k
03Ph>00g=cL0>CTi03Xj>P0h>3P0>CTi03Ph>00g=cL00P0j>SX00`0h>3P0>SXj03/k>`0203Lg=`09
03/k>`0i>CT0>CTi03/k>`0g=cL0>CTi03Ph>00f=SH0=cLg0080>3Ph00<0=SHf03Lg=`0i>CT0100h
>3P0100i>CT0=cLg03De=@0e=CD203Hf=P80=cLg00`0=3@d03Hf=P0h>3P0?Cdm04=3@`14A4@0>c/k
03Ti>@13@d<0A4A403lo?`0i>CT303Lg=`0303Ph>?oooooooooo00_ooooo000@ooooo`0=04a<C01?
Cdl0BTY:04a<C01;Bd/0BDU904Y:BP1@D500C4a<04Y:BP1<C4`0Bd];04Y:BP0204I6AP0704U9B@15
ADD0BDU904Y:BP19BDT0Bd];04a<C00204E5A@0604M7A`1:BTX0B4Q804E5A@14A4@0ADE50P17AdL0
2`1:BTX0ADE504U9B@15ADD0A4A404=3@`17AdL0ATI604M7A`13@d<0ADE50080ATI600L0ADE504A4
A016ATH0A4A403lo?`12@T80ATI600<0@d=30P11@D40300o?cl0@4100410@012@T80?clo04=3@`14
A4@0ATI60410@015ADD0ATI60410@080?Shn00D0@41004M7A`12@T80@d=30451@@020492@P0704=3
@`11@D40@41004E5A@0n?Sh0@d=30451@@0204=3@`0G0410@00o?cl0?Shn03hn?P0o?cl0@41003lo
?`11@D40A4A403hn?P12@T80A4A403lo?`10@400A4A404=3@`16ATH0?Shn03dm?@0o?cl0@D510492
@P15ADD00`16ATH0:00o?cl0@D5103dm?@10@400@D510492@P14A4@0?Shn0451@@0n?Sh0ADE50492
@P0o?cl0@4100451@@0o?cl0@T920451@@10@400?clo03`l?00o?cl0@d=30410@011@D40@41003lo
?`0n?Sh0?Cdm0451@@10@400?Shn0410@00m?Cd0?Shn03dm?@0o?cl0@T9203hn?P0l?3`20410@003
03`l?00m?Cd0?Shn0080A4A403<0@D510492@P0n?Sh0@4100451@@0m?Cd0>c/k04A4A011@D40ATI6
04=3@`17AdL0FEUI06UYJ@1OGel0Cdm?04Y:BP1=CDd0BTY:04M7A`1;Bd/0BTY:04E5A@16ATH0A4A4
0451@@18B4P0IfMW08R8R02;Rh/0OGem07AdM01MGEd0Hf=S08V9R@2FUYH0SHf=07]kN`1]KFd0JFUY
06YZJP1fMWH0PX:209:BTP2^[Zh0Ogmo04a<C019BDT0AdM704=3@`14A4@00`10@4008@15ADD0A4A4
04=3@`0l?3`0?Cdm0410@01:BTX0BDU904Y:BP1<C4`0Cdm?04M7A`1;Bd/0A4A404M7A`15ADD0?clo
0410@00l?3`0@D5104E5A@0k>c/0@41003hn?P1GEeL0G5aL04];B`13@d<0?3`l03Ti>@12@T80?Shn
0410@00204I6AP1704M7A`18B4P0D51@05aLG025QHD0Rh^;08n?S`2DU9@0UYJF09nOW`2PX:00Xj>S
09RHV024Q8@0FEUI03hn?P1KFe/0QhN707]kN`20P800RHV908Z:RP1oOgl0QHF509jNWP2@T900QhN7
096AT@1hN7P0Fe]K06UYJ@1aLG40Shn?08>3P`2?Shl0[jn_0:f][@22PX80S8b<08>3P`1oOgl0Fe]K
04M7A`10@400BDU904A4A01RHV80IVIV04=3@`0n?Sh0>SXj03Ti>@0m?Cd0>3Ph03dm?@0l?3`0ATI6
0492@P0k>c/0?3`l03lo?`0j>SX0?Cdm03lo?`0l?3`0>CTi03/k>`0l?3`0?Cdm03/k>`0h>3P00P0j
>SX02P0m?Cd0?Shn03`l?017AdL0@41003Xj>P0k>c/0>CTi03Xj>P11@D4303/k>`0303Ph>00i>CT0
?Cdm0080>CTi00<0?3`l03Ti>@0i>CT00`0i>CT00`0h>3P0>SXj03/k>`0203`l?00603dm?@0k>c/0
=cLg03`l?00j>SX0=CDe0P0m?Cd0100l?3`0>SXj03Ti>@0k>c/303dm?@0903hn?P10@400>SXj03Ph
>00i>CT0>SXj03Ti>@0n?Sh0>3Ph0080>SXj00X0?3`l03Ti>@0h>3P0>c/k03`l?00i>CT0>3Ph03Hf
=P0g=cL0=SHf0P0h>3P0200f=SH0>3Ph03Ti>@0h>3P0=cLg03Ti>@0j>SX0=3@d0P0i>CT01P0m?Cd0
?3`l03Ph>00h>3P0>c/k03Ph>080>CTi00T0?3`l03Hf=P0j>SX0>CTi03Lg=`0i>CT0>SXj03@d=00j
>SX00P0i>CT203Xj>P80>CTi00<0>3Ph03Xj>P0h>3P00`0h>3P203Lg=`0503Ph>00i>CT0=cLg03Lg
=`0e=CD00P0g=cL01P0i>CT0>3Ph03Hf=P0h>3P0=cLg03Hf=P80>3Ph0`0f=SH02P0d=3@0>3Ph03Hf
=P0b<S80=3@d03dm?@1FEUH0M7Ad07]kN`1TI6@204e=C@0404U9B@15ADD0>CTi03De=@<0=SHf0P0h
>3P=ooooo`004?ooool04@1ADE40DU9B04i>CP1;Bd/0DE5A04e=C@1?Cdl0C4a<051@D01<C4`0BTY:
04I6AP1<C4`0B4Q804M7A`19BDT0BTY:00<0C4a<00L0BTY:04I6AP17AdL0ATI604Q8B01<C4`0BTY:
00<0ATI602T0A4A404=3@`17AdL0ATI604Y:BP16ATH0@d=30410@018B4P0@d=304A4A019BDT0ADE5
04A4A01;Bd/0B4Q80492@P17AdL0A4A404=3@`15ADD0@d=304A4A019BDT0ADE50451@@10@400@d=3
0410@00o?cl0@D5103hn?P16ATH0ADE504I6AP0o?cl0B4Q804U9B@16ATH0@D510410@0020492@P0:
03/k>`11@D40A4A403dm?@0n?Sh0@T9204=3@`11@D40ADE504=3@`80@D5102P0A4A40492@P14A4@0
@D5103`l?00n?Sh0@D5103lo?`10@400ADE504U9B@0o?cl0ATI60410@00m?Cd0ATI604M7A`15ADD0
@T9204M7A`0l?3`0@41004=3@`0n?Sh0?clo04E5A@0o?cl0?3`l0492@P14A4@0AdM70451@@0k>c/0
?clo0492@P0o?cl0?Shn03lo?`14A4@0@D510`12@T803013@d<0@41003hn?P12@T80@4100492@P10
@400@D5103dm?@0n?Sh0@T9204=3@`80?clo00L0@d=30492@P10@400?clo03/k>`0i>CT0>c/k00@0
?Cdm00X0?clo03Ph>00m?Cd0?clo04E5A@13@d<0?clo0410@013@d<0?clo0P13@d<02`17AdL0B4Q8
04e=C@1ADE40C4a<059BDP1PH600Kfm_06=SH`1;Bd/0A4A40080@d=300D0?3`l03lo?`17AdL0@D51
03dm?@020451@@0M03/k>`11@D40DE5A05IFEP1ADE40EeMG05IFEP1DE5@0FEUI06ATI01YJFT0O7al
06UYJ@1;Bd/0EUIF071`L01iNGT0MWIf075aL@1gMgL0GemO05ADE013@d<0ADE50451@@0o?cl0@D51
04=3@`12@T800P0l?3`07010@400@d=30451@@17AdL0BDU904I6AP1EEED0E5AD059BDP1>CTh0EEEE
06=SH`2OWil0ZZZZ09bLW01fMWH0EEEE04a<C01CDe<0Fe]K06][J`1WIfL0J6QX05iNGP1EEED0GUiN
06IVIP1UIFD2065QH@0n05QHF01;Bd/0C4a<059BDP1<C4`0B4Q806UYJ@29RHT0UYJF0;:b/P32`/80
aLG50<S8b030`<00/k>c0:VYZ@2IVIT0PX:207=cL`1SHf<0H61P09ZJVP3;bl/0clo?0<W9b@2QXJ40
];Bd0:JVYP2?Shl0UYJF0:^[Z`2KVi/0HV9R04];B`1LG5`0IfMW06a/K021PH40TI6A0:f][@2YZJT0
_[jn0<_;b`2m_Kd0X:2P071`L01/K6`0ATI603hn?P15ADD0@41003hn?P0k>c/0=cLg03`l?00h>3P0
>c/k03Xj>P0l?3`0?Cdm03Xj>P0o?cl203`l?00503hn?P11@D40@d=303dm?@0i>CT00P0k>c/0300m
?Cd0>SXj03Xj>P0j>SX0?Shn03/k>`0i>CT0>SXj0451@@10@400>SXj03dm?@<0?3`l00@0>c/k03Ti
>@0i>CT0>c/k0P0g=cL05P0i>CT0>SXj03/k>`0k>c/0>CTi03`l?00k>c/0=SHf03/k>`0l?3`0=SHf
03Ti>@0l?3`0>SXj03`l?00i>CT0>3Ph03Xj>P0i>CT0?clo03/k>`0j>SX203Ph>080>c/k00T0?3`l
03dm?@0i>CT0=SHf03Lg=`0i>CT0>SXj03Ti>@0f=SH00P0k>c/02P0j>SX0>c/k03/k>`0j>SX0>3Ph
03Xj>P0k>c/0>CTi03Ph>00f=SH303Lg=`<0>3Ph0P0g=cL203Ti>@0803Ph>00f=SH0>SXj03/k>`0n
?Sh0>SXj03Lg=`0f=SH203Ti>@80?Cdm00T0>CTi03Lg=`0g=cL0>CTi03Xj>P0k>c/0>CTi03Ph>00f
=SH0100g=cL303Ti>@0<03Lg=`0i>CT0=cLg03Lg=`0i>CT0=CDe03Lg=`0f=SH0>CTi03Hf=P0e=CD0
=SHf1@0h>3P0100g=cL0=CDe03Hf=P0h>3P203De=@0?03Ti>@0f=SH0<S8b03Lg=`0f=SH0?Cdm05IF
EP1eMGD0QHF507EeM@1NGUh0A4A403dm?@0k>c/0>SXj0080>3Ph00@0=SHf03@d=00g=cL0=cLg0P0h
>3P=ooooo`004?ooool01P1ADE40DU9B05EEE@1@D500CDe=04a<C080Bd];00<0CDe=04Q8B019BDT0
0P1;Bd/00`18B4P0BDU904Y:BP0304Y:BP0=04a<C01;Bd/0B4Q804];B`17AdL0BDU904E5A@1;Bd/0
BTY:04M7A`19BDT0@T9204I6AP0204E5A@0@04I6AP15ADD0ATI604E5A@12@T80ADE504e=C@1?Cdl0
BTY:04I6AP14A4@0AdM704I6AP19BDT0A4A404I6AP80@T9200X0ADE504=3@`12@T80A4A404I6AP14
A4@0@4100492@P13@d<0A4A40P17AdL01015ADD0@T9204=3@`11@D4304E5A@080492@P11@D40@410
04A4A012@T80B4Q804M7A`11@D420492@P0404M7A`1:BTX0@T9204=3@`80A4A40P15ADD01013@d<0
?Shn03lo?`0m?Cd20492@P0304=3@`14A4@0BDU90080ADE500l0@T9204=3@`13@d<0?Shn03dm?@12
@T80AdM704A4A010@400@d=304Q8B012@T80@d=30492@P15ADD00P12@T803@0m?Cd0A4A404A4A012
@T80ADE50492@P15ADD0?clo04E5A@12@T80?Shn0492@P15ADD00P0o?cl01`0n?Sh0CTi>0492@P0o
?cl0A4A403hn?P0m?Cd00P0l?3`02@0m?Cd0@d=303hn?P0m?Cd0?3`l03lo?`10@400?Shn03`l?002
0451@@0=03dm?@0l?3`0?3`l03/k>`0o?cl0A4A40410@011@D40@d=304I6AP13@d<0CTi>04Y:BP02
051@D00604U9B@1>CTh0B4Q804e=C@18B4P0A4A40P0o?cl00`12@T80AdM703lo?`020410@00404A4
A00l?3`0@D5104=3@`80?clo03<0BTY:04I6AP10@400?clo04=3@`14A4@0CDe=05ADE01/K6`0OGem
09:BTP1hN7P0DE5A04=3@`1;Bd/0ATI603lo?`1;Bd/0H61P05YJFP1IFET0@T9203dm?@11@D40A4A4
03lo?`0l?3`0?clo0410@013@d<0?Cdm04A4A011@D40@T920451@@0i>CT0?Shn03lo?`11@D40?3`l
03/k>`0l?3`0C4a<05eMG@1WIfL0J6QX05eMG@1EEED0BTY:04=3@`17AdL00P15ADD0>P10@400?clo
04E5A@1:BTX0De=C05UIF@1XJ6P0Kfm_079bLP1[Jf/0LG5a07inOP22PX80Rh^;09>CT`2NWYh0UIFE
09JFUP2TY:@0^k^k0=GEe@3IfMT0g=cL0=3@d035aLD0/k>c0:b/[02a/K40UIFE0:>SX`3=cLd0d];B
0;bl_031`L40YJFU0:JVYP2>SXh0Ti>C0:ZZZP1OGel0CDe=08Z:RP2a/K40Vi^K0:BTY02_[jl0ZJVY
0:FUY@2FUYH0aLG50<o?c`3=cLd0`<3009jNWP1XJ6P0@d=303dm?@0o?cl20410@080>SXj00l0>CTi
03`l?00j>SX0?3`l03Xj>P0i>CT0?Cdm03/k>`0m?Cd0@41003`l?011@D40>c/k03`l?00o?cl00P0n
?Sh04P0k>c/0@41003Ti>@0i>CT0?Cdm03Xj>P0n?Sh0?clo0451@@0l?3`0>c/k03Xj>P0m?Cd0?3`l
03/k>`0j>SX0>3Ph03dm?@80>CTi00<0>SXj03/k>`0l?3`00`0l?3`02`0j>SX0=SHf03Ph>00j>SX0
>CTi03`l?00m?Cd0>CTi03Xj>P0m?Cd0>SXj0080>c/k00l0?3`l03Ti>@0k>c/0>SXj03Ti>@0g=cL0
>CTi03Ph>00j>SX0>CTi03`l?00i>CT0>SXj0410@00l?3`00P0j>SX01P0h>3P0>c/k03Ti>@0m?Cd0
?3`l03Lg=`<0>CTi00P0>SXj03Ph>00i>CT0>CTi03Ph>00k>c/0?3`l03Ti>@80>3Ph00D0>CTi03Xj
>P0j>SX0>SXj03Ti>@0203Xj>P0303Ti>@0h>3P0=cLg0080>3Ph00D0?3`l03dm?@0i>CT0>CTi03Ph
>00203Xj>P0403Ph>00d=3@0>CTi03Lg=`@0>CTi00D0>SXj03Ph>00i>CT0=cLg03Ti>@0203Ph>080
>CTi0P0h>3P203Ti>@80>3Ph00<0=SHf03Lg=`0h>3P00P0h>3P05P0k>c/0>SXj03De=@0g=cL0>SXj
03Lg=`0f=SH0=cLg03Xj>P0o?cl0A4A404e=C@1MGEd0EUIF04Y:BP0o?cl0?3`l03Xj>P0l?3`0>SXj
03Ph>00g=cL203Ph>00303Hf=P0h>3P0>3Ph0080>3Ph3Oooool0013ooooo00T0D51@04m?C`1?Cdl0
Bd];04m?C`1ADE40C4a<051@D01?Cdl00P1:BTX01@1;Bd/0BDU904Y:BP1<C4`0Bd];0080B4Q801@0
BDU904Y:BP19BDT0ADE504Q8B014A4@0ATI604M7A`1:BTX0Bd];04Q8B015ADD0A4A404E5A@16ATH0
B4Q804A4A017AdL0ADE504Y:BP<0@T9200D0A4A404Y:BP1<C4`0ADE504Q8B00204I6AP0304];B`16
ATH0@d=30080ATI600T0@d=304I6AP17AdL0ATI604=3@`12@T80ATI604A4A01:BTX00P15ADD03P12
@T80?Cdm0492@P11@D40A4A404=3@`15ADD0B4Q804I6AP14A4@0ADE504=3@`12@T80@d=30P11@D40
0`10@400ATI604Q8B00204I6AP0704E5A@13@d<0@d=303hn?P0o?cl0?Shn03lo?`020410@00U0451
@@13@d<0BDU903lo?`11@D40?Shn04M7A`18B4P0ATI603dm?@0l?3`0A4A403dm?@0l?3`0?Cdm03hn
?P11@D40@d=304E5A@0o?cl0@41004];B`15ADD0@41004E5A@0o?cl0@D510492@P10@400@T920451
@@13@d<0@41003lo?`16ATH0A4A403lo?`020410@00A04E5A@0o?cl0?Shn0492@P10@400>SXj03dm
?@0n?Sh0?clo0410@00l?3`0A4A404=3@`10@400ATI603lo?`0k>c/00P0n?Sh02@0o?cl0A4A40410
@00n?Sh0@T9203lo?`10@400@T9204A4A00204I6AP0904A4A013@d<0A4A404=3@`0m?Cd0@D510492
@P0m?Cd0@T920080@41002H0?clo03`l?00m?Cd0>SXj03hn?P10@400?clo03dm?@0o?cl0@41003hn
?P14A4@0B4Q804A4A01;Bd/0D51@04m?C`1GEeL0K6a/07]kN`2<S8`0UIFE09BDU01hN7P0I6AT04M7
A`0l?3`0@T9204E5A@14A4@0B4Q804=3@`15ADD0DU9B05MGE`1<C4`0B4Q804A4A080?clo00H0@410
04A4A01=CDd0GEeM05UIF@15ADD204=3@`80@T9200P0A4A404=3@`0n?Sh0?Shn03/k>`10@400?Cdm
04A4A0<0@41000<0BDU904Y:BP16ATH00P16ATH05014A4@0BDU904Q8B01DE5@0HF5Q069RHP1bLW80
MWIf079bLP1eMGD0Lg=c06YZJP1EEED0CTi>04m?C`1DE5@0G5aL06e]K@1dM7@0QHF50P2DU9@0:P2X
Z:P0]KFe0;fm_@34a<@0_kno0;Jf]P2g]kL0_kno0:RXZ028R8P0KVi^055AD@1CDe<0E5AD06MWI`20
P800IFEU092@T02^[Zh0WinO09JFUP2=SHd0Zj^[0:VYZ@2BTY80PH610::RXP2][Jd0Zj^[09>CT`2U
YJD0Shn?04i>CP0o?cl0>c/k03dm?@0o?cl0?Shn03lo?`0m?Cd0?clo0451@@<0>SXj00h0>c/k03dm
?@0n?Sh0@41003dm?@0o?cl0@T9203hn?P10@400?Shn03lo?`0n?Sh0@D5103Xj>P80?Cdm00l0?Shn
03lo?`0l?3`0@41003dm?@0n?Sh0>SXj03/k>`0l?3`0?Shn03`l?00j>SX0?3`l03Xj>P0n?Sh00P0j
>SX203/k>`0<03hn?P0j>SX0=cLg03Xj>P0h>3P0>CTi03Ph>00m?Cd0@D5103dm?@0k>c/0?3`l0`0k
>c/0200i>CT0>c/k03Ti>@0j>SX0?3`l03dm?@0i>CT0>3Ph0P0l?3`01P0g=cL0>SXj03dm?@0o?cl0
>CTi03/k>`<0?3`l00<0>SXj03`l?00m?Cd00P0i>CT203Ph>0<0>SXj0P0k>c/00`0m?Cd0?3`l03Ph
>00203Ti>@0403Xj>P0k>c/0>SXj03`l?080=cLg0P0i>CT203/k>`0403Ti>@0m?Cd0>CTi03Ph>080
>SXj00H0>CTi03dm?@0h>3P0>SXj03Lg=`0e=CD503Lg=`0503Ph>00g=cL0>3Ph03Xj>P0i>CT00P0j
>SX0100i>CT0>SXj03Ph>00i>CT203Xj>P80>CTi0P0f=SH303Ph>00A03Lg=`0h>3P0>CTi03Ph>00i
>CT0?3`l04I6AP15ADD0A4A404a<C01ADE40CDe=04];B`0o?cl0>SXj03Ti>@0f=SH00P0i>CT01@0h
>3P0=SHf03Ti>@0g=cL0=SHf00<0>3Ph0P0g=cL=ooooo`004?ooool02@1>CTh0D51@04i>CP1?Cdl0
CTi>04Y:BP1=CDd0B4Q804e=C@0204a<C00604U9B@16ATH0BTY:04a<C018B4P0AdM70P1:BTX01017
AdL0A4A404E5A@1:BTX204M7A`0904E5A@18B4P0Bd];04Q8B015ADD0B4Q804=3@`14A4@0AdM700<0
ATI600D0BDU904Q8B014A4@0ADE50492@P0204=3@`090492@P1=CDd0D51@04U9B@15ADD0A4A404Y:
BP16ATH0A4A400<0ATI601T0BTY:04=3@`13@d<0A4A40451@@0n?Sh0@T9204I6AP18B4P0ADE504Q8
B012@T80AdM704U9B@14A4@0?Shn04A4A016ATH0A4A40492@P14A4@0@T9203lo?`13@d<0?clo0080
ADE500P0ATI604A4A016ATH0@4100492@P14A4@0@D5103lo?`80@41000`0?clo0410@016ATH0BTY:
04A4A00o?cl0@41004=3@`14A4@0@T9204U9B@13@d<30410@00804=3@`10@400?clo0451@@0o?cl0
@D510410@013@d<203lo?`0303dm?@12@T80ADE50080?clo00@0?Cdm0451@@10@400?clo0`13@d<0
2011@D40?Cdm03lo?`0o?cl0?Shn03dm?@0n?Sh0@D510P0n?Sh01P0l?3`0?Cdm0410@015ADD0ATI6
04A4A080ADE50`0o?cl01011@D40@41004E5A@13@d<203hn?P0Z03/k>`0l?3`0?Shn0410@013@d<0
ADE503lo?`0m?Cd0A4A404I6AP0n?Sh0?Cdm03hn?P0m?Cd0@T920410@00n?Sh0?clo0410@00n?Sh0
@T9204M7A`14A4@0?clo04M7A`14A4@0@41003hn?P17AdL0ATI604A4A017AdL0ADE504I6AP1?Cdl0
I6AT0861P@20P800Jf][06IVIP1@D500ADE50P1;Bd/0:P15ADD0B4Q804Q8B015ADD0AdM704I6AP19
BDT0DE5A04I6AP17AdL0ATI604Y:BP1?Cdl0CDe=05eMG@1`L700NWYj06a/K01KFe/0De=C055AD@1=
CDd0CTi>05ADE01IFET0H61P05IFEP1QHF40K6a/07MgM`27QhL0KVi^05]KF`1FEUH0GUiN06MWI`1K
Fe/0BTY:0492@P13@d<0@D510492@P80BTY:00h0AdM705=CD`1HF5P0GemO069RHP1`L700M7Ad07em
O@1iNGT0MWIf06YZJP1WIfL0DE5A04];B`80A4A403@0@D510492@P15ADD0EEEE06EUI@1eMGD0SXj>
0:j^[P38b<P0_kno08>3P`1>CTh0?clo04I6AP13@d<0@41003hn?P15ADD0HV9R08n?S`2JVYX0UIFE
07]kN`1mOGd0LG5a05=CD`1BDU80FEUI075aL@2>SXh0UiNG06MWI`1VIVH0IFEU05ADE01=CDd0EeMG
055AD@1;Bd/0@d=30410@011@D40A4A403dm?@0o?cl0?Shn0492@P10@400?3`l03Xj>P0n?Sh0?Cdm
0P0o?cl03P0m?Cd0?clo03`l?011@D40AdM704a<C01NGUh0KFe]06m_K`1RHV80EEEE04M7A`0k>c/0
@4100P0l?3`0300j>SX0?3`l03Xj>P0j>SX0>3Ph03/k>`0g=cL0>c/k03Xj>P0i>CT0?3`l03/k>`<0
>CTi00L0?3`l03/k>`0k>c/0>c/k03hn?P0o?cl0?Cdm0080>CTi00<0=cLg03/k>`0j>SX00P0k>c/0
200j>SX0>CTi03dm?@0j>SX0>c/k03dm?@0j>SX0?Cdm0P0i>CT01P0n?Sh0?3`l03`l?00n?Sh0?Cdm
03Ph>080>SXj0P0k>c/203Xj>P0=03Ph>00j>SX0>CTi03Xj>P0l?3`0>c/k03hn?P0l?3`0>3Ph03Xj
>P0k>c/0>SXj03/k>`0203Ti>@0503Ph>00i>CT0>CTi03Ph>00j>SX00P0m?Cd0200o?cl0?3`l03Ph
>00g=cL0>CTi03Ph>00i>CT0>SXj0P0i>CT01@0j>SX0>c/k03dm?@0k>c/0>3Ph0080=cLg0P0j>SX0
1`0l?3`0>c/k03Ti>@0g=cL0>SXj03Ph>00e=CD00P0i>CT00`0l?3`0=SHf03Ti>@0303Ph>00703Ti
>@0g=cL0>3Ph03`l?010@400DU9B05UIF@0205EEE@0:04e=C@11@D40@D510410@00m?Cd0?3`l03Ti
>@0g=cL0<S8b03Ti>@80>3Ph00@0>CTi03Xj>P0h>3P0=cLg0P0f=SH0100h>3P0=cLg03Lg=`0h>3P=
ooooo`004?ooool0501@D500DE5A04m?C`1?Cdl0C4a<04];B`1=CDd0C4a<04i>CP1;Bd/0BTY:04a<
C01>CTh0C4a<04Q8B017AdL0Bd];04U9B@18B4P0BDU90P18B4P01`17AdL0ATI604E5A@14A4@0B4Q8
04I6AP18B4P00`19BDT03P18B4P0BDU904M7A`15ADD0BTY:04e=C@1:BTX0A4A404=3@`15ADD0@d=3
04A4A019BDT0A4A40P16ATH01P14A4@0AdM704U9B@12@T80ADE504U9B@80A4A401<0@4100492@P15
ADD0ADE504=3@`12@T80ADE50492@P15ADD0@d=30410@012@T80?clo04A4A013@d<0?clo0492@P14
A4@0ADE50080@T9200H0?Shn0410@011@D40?3`l03lo?`12@T820451@@0704A4A00o?cl0@T920410
@00m?Cd0?Shn0451@@020492@P0:0451@@0o?cl0@T920492@P16ATH0@T9204A4A013@d<0ADE504A4
A080@D5101X0@41003dm?@12@T80AdM703lo?`0n?Sh0?clo0451@@0o?cl0ATI603hn?P0m?Cd0?Shn
0410@012@T80?Shn03lo?`0k>c/0?3`l03dm?@10@400@D5104=3@`0k>c/0?Cdm03`l?0<0?clo00D0
@D5103lo?`0l?3`0?Shn0451@@020492@P070410@011@D40ADE504U9B@17AdL0ATI60492@P030451
@@0?04=3@`0m?Cd0?Shn03lo?`0l?3`0>c/k03lo?`0k>c/0?Cdm0410@00m?Cd0?Shn03`l?011@D40
ADE50080?Shn0`13@d<05010@400A4A40451@@11@D40?Cdm0451@@15ADD0@41003`l?011@D40@410
03`l?013@d<0?Shn04U9B@18B4P0ATI60451@@1BDU80IfMW0P1lO7`206UYJ@1606a/K01WIfL0L71`
06e]K@1_Kfl0J6QX069RHP1KFe/0FEUI04Q8B014A4@0@D5104=3@`0o?cl0?Cdm0410@016ATH0@410
0451@@16ATH0@d=304U9B@18B4P0C4a<055AD@1DE5@0GemO06YZJP1gMgL0NWYj09VIV@2PX:00YJFU
0:j^[P2TY:@0]kNg0:NWY`2FUYH0WIfM0;:b/P2h^;P0]KFe0:^[Z`26QXH0LW9b06m_K`1VIVH0F5QH
05]KF`1GEeL0Jf][0820P02FUYH0Z:RX0:ZZZP2SXj<0UiNG08n?S`2=SHd0MgMg071`L01bLW80OGem
08:2PP1YJFT0Cdm?04A4A012@T80?Cdm0492@P80@D5102`0@d=3061PH028R8P0/;2`0:JVYP2EUID0
Vi^K08B4Q01]KFd0I6AT05mOG`1SHf<0Kfm_07MgM`29RHT0RXZ:079bLP24Q8@0VIVI08^;R`20P800
JVYZ096AT@2@T900WYjN08B4Q028R8P0WIfM09NGU`2MWId0Zj^[0:FUY@25QHD0K6a/07emO@2>SXh0
LW9b05]KF`1MGEd0Fe]K05EEE@1@D500?clo0410@080EUIF01h0@d=304Y:BP1@D500HV9R09BDU02l
_;`0`L710<c<c02m_Kd0Vi^K05YJFP1:BTX0?Shn03dm?@10@400>CTi03`l?00k>c/0?3`l03Ph>00l
?3`0>c/k055AD@0m?Cd0=cLg03Xj>P0i>CT0?Shn03`l?00k>c/203`l?00503Xj>P0h>3P0>CTi03`l
?00j>SX00P0i>CT0100h>3P0>CTi03Ph>00h>3P203Ti>@0703Ph>00i>CT0>CTi03dm?@0l?3`0>CTi
03Ph>00203Xj>P0503/k>`0i>CT0=SHf03Ti>@0h>3P00P0n?Sh00`0f=SH0>SXj03Xj>P0203/k>`04
03Ti>@0l?3`0>3Ph03Xj>P80>CTi00H0>c/k03Ti>@0l?3`0>SXj03Ti>@0l?3`203Xj>P040410@00j
>SX0=cLg03Xj>P80?Cdm00P0>c/k03Xj>P0l?3`0?3`l03Ti>@0h>3P0?Cdm03Ti>@<0>3Ph0P0l?3`0
4@0k>c/0>CTi03Lg=`0j>SX0?Cdm03Lg=`0j>SX0>3Ph03/k>`0l?3`0>c/k03Xj>P0l?3`0>CTi03Hf
=P0i>CT0=3@d0080>3Ph0100?3`l03/k>`0h>3P0>3Ph03Ti>@0l?3`0?clo0410@019BDT0EEEE05QH
F01?Cdl0@D5103Xj>P0k>c/0>CTi0P0f=SH203Ph>0D0=cLg00D0>CTi03Ph>00d=3@0=SHf03Lg=`02
03Hf=P80=cLg00<0>CTi03Xj>P0h>3P03Oooool0013ooooo00H0Cdm?04i>CP1@D500CDe=04Y:BP1>
CTh204Y:BP0404a<C01@D500Cdm?04];B`80CDe=00<0CTi>04Y:BP1:BTX00P19BDT01@1:BTX0ATI6
04U9B@1;Bd/0AdM70080ADE500d0AdM704=3@`17AdL0Bd];04E5A@17AdL0A4A404Q8B015ADD0@T92
04I6AP1:BTX0B4Q800@0ADE501@0ATI604A4A01<C4`0B4Q804E5A@14A4@0AdM704];B`16ATH0BTY:
04i>CP12@T80ADE504A4A019BDT0A4A40492@P10@400@d=304A4A080@D5100D0?Shn0410@013@d<0
A4A404e=C@030492@P80@41000@0?Shn0410@012@T80@d=30P12@T8204A4A080@d=30280@T9203dm
?@11@D40@D5103lo?`0n?Sh0@D5104E5A@12@T80@41003hn?P11@D40ADE50492@P0n?Sh0?Cdm03`l
?00o?cl0@4100492@P0o?cl0>SXj03hn?P11@D40A4A403hn?P11@D40@d=30410@011@D40@41003dm
?@0o?cl0@D510P10@4003P0i>CT0>SXj03hn?P14A4@0?clo03/k>`0n?Sh0@T9203lo?`0m?Cd0?clo
03dm?@0i>CT0>c/k0P0n?Sh00`0m?Cd0?Shn03dm?@0203hn?P0D03dm?@0o?cl0A4A404=3@`12@T80
?clo0451@@10@400?Shn0451@@17AdL0?Shn0492@P10@400@d=304M7A`11@D40?Cdm03`l?010@402
03dm?@0:03/k>`0m?Cd0@d=304A4A00n?Sh0A4A404=3@`11@D40>c/k04A4A080?clo01D0@D5104I6
AP0n?Sh0?clo03hn?P11@D40?Cdm0492@P14A4@0?Cdm0492@P13@d<0H61P08N7Q`2FUYH0Rh^;08B4
Q01eMGD0HF5Q05]KF`1RHV800P1<C4`02012@T80?Shn0410@012@T80@4100451@@10@400A4A40P12
@T800`0m?Cd0>c/k04A4A0020451@@1R03hn?P10@400Bd];05IFEP1`L700NWYj0861P@1kNg/0PX:2
08N7Q`29RHT0QhN708n?S`2IVIT0ZZZZ0:BTY02BTY80WIfM07emO@2<S8`0W9bL0:>SX`2JVYX0R8R8
07AdM01aLG40Q8B409^KV`33`l<0clo?0=;BdP3=cLd0alO70;no_`2l_;`0_Kfm0;Fe]@2j^[X0b<S8
0=CDe03GemL0fm_K0<K6aP34a<@0`L710<W9b@2[Zj/0VIVI07moO`1KFe/0BTY:04I6AP0m?Cd0?clo
03dm?@11@D40?clo055AD@1]KFd0UIFE0;Fe]@39bLT0a/K60;Vi^@33`l<0c<c<0=?Cd`3De=@0g=cL
0=[JfP2l_;`0XJ6Q07emO@1UIFD0HF5Q05QHF02GUiL0Ti>C09:BTP23Ph<0N7Qh08N7Q`2@T900WinO
0;6a/@2_[jl0]kNg0;Rh^02i^KT0[Jf]06UYJ@1<C4`0A4A40451@@1:BTX0B4Q804E5A@10@40204i>
CP0I04];B`1ADE40ADE504M7A`1JFUX0R8R809>CT`1eMGD0DE5A0492@P10@400?Shn03`l?012@T80
?3`l03/k>`0j>SX0>CTi03dm?@0k>c/0?clo03Lg=`0m?Cd0>3Ph03Ti>@0203/k>`80>SXj00@0>c/k
03Ph>00l?3`0>CTi0P0h>3P03`0k>c/0>SXj03Ti>@0l?3`0?clo03Xj>P0f=SH0=cLg03Xj>P0i>CT0
>SXj03Ti>@0k>c/0>SXj03De=@0203Ph>00303/k>`0g=cL0>CTi0080>CTi00@0?Shn03Ti>@0h>3P0
>3Ph0P0j>SX00`0i>CT0>3Ph03Xj>P0403/k>`80>SXj00`0>c/k03Xj>P0j>SX0>c/k03`l?00n?Sh0
?clo03Xj>P0k>c/0>CTi03Ph>00g=cL303Ti>@0403Ph>00g=cL0=SHf03Ph>0@0=cLg00L0=CDe03Ph
>00g=cL0>CTi03Ph>00i>CT0>c/k0080>SXj00D0=cLg03Ph>00h>3P0>CTi03`l?00203Xj>P0G03`l
?00h>3P0=CDe03Ph>00d=3@0>CTi03Lg=`0i>CT0>3Ph03/k>`0n?Sh0?clo04A4A018B4P0@D5104=3
@`12@T80>SXj03Ph>00f=SH0>c/k03Lg=`0d=3@00P0h>3P00`0e=CD0=3@d03Hf=P0303Ph>00:03Lg
=`0j>SX0=CDe03`l?00k>c/0?clo03Hf=P0d=3@0>c/k03Lg=`<0>3Ph3Oooool0013ooooo0`1ADE40
1P1?Cdl0CDe=04m?C`1?Cdl0BDU904a<C080BTY:00D0C4a<04];B`18B4P0B4Q804Y:BP0204];B`07
04a<C01>CTh0Bd];04Q8B014A4@0ATI604U9B@0204I6AP0E04A4A017AdL0BDU904Y:BP19BDT0AdM7
04Q8B019BDT0B4Q804M7A`18B4P0ATI604A4A016ATH0AdM704=3@`16ATH0CTi>04M7A`15ADD0@d=3
00<0Bd];0P18B4P02@11@D40@d=304A4A013@d<0@T9204=3@`10@400ADE503lo?`020492@P0G0410
@00o?cl0@d=30410@00o?cl0?Cdm04E5A@1:BTX0ATI60451@@0o?cl0?Shn0451@@1:BTX0ADE504A4
A011@D40@d=303lo?`0n?Sh0@T9204=3@`0o?cl00`13@d<01`10@400?clo0492@P11@D40@d=30451
@@12@T800P11@D408@10@400?Shn03/k>`0o?cl0?3`l03hn?P10@400@D5103dm?@0o?cl0@d=304A4
A00o?cl0@T920410@011@D40@41004=3@`0m?Cd0>c/k04A4A010@400?clo0410@012@T80@d=304A4
A011@D40@T9203`l?011@D40@41003lo?`0203`l?00@0410@00o?cl0?Cdm03dm?@11@D40@41003dm
?@0n?Sh0?clo04A4A013@d<0?Shn0451@@0n?Sh0@d=30492@P80@D5100H0@d=303hn?P0n?Sh0@T92
0451@@14A4@20451@@0A0410@011@D40@D5103Xj>P0o?cl0@T9203lo?`12@T80A4A403`l?00k>c/0
@41003hn?P13@d<0@D5103dm?@0n?Sh00P0k>c/0P`0o?cl0?Cdm0451@@0n?Sh0@T9204I6AP1>CTh0
GEeM06e]K@28R8P0WIfM09jNWP2=SHd0IfMW04a<C015ADD0?Shn04A4A015ADD0B4Q80451@@0m?Cd0
@D5104A4A017AdL0?3`l0410@013@d<0@D5104=3@`0n?Sh0@T920410@013@d<0?clo03/k>`15ADD0
AdM70410@019BDT0CTi>05UIF@1CDe<0Hf=S07AdM01hN7P0OGem07IfMP1aLG40KVi^07]kN`21PH40
RHV909>CT`2MWId0R8R806UYJ@1KFe/0F5QH04m?C`1>CTh0FUYJ07MgM`2IVIT0[Zj^0<W9b@3Hf=P0
gMgM0=SHf03Bd]80d=3@0<30`02e]KD0^;Rh0;fm_@30`<00^;Rh0;:b/P2d];@0a<C40<G5a@39bLT0
]KFe08R8R01UIFD0Bd];05YJFP1iNGT0FEUI05ADE01MGEd0B4Q804M7A`1OGel0NWYj0:JVYP3=cLd0
eMGE0<_;b`3EeMD0clo?0<W9b@3?cll0e]KF0=CDe03Hf=P0eMGE0<K6aP2f][H0YJFU07AdM01BDU80
IFEU071`L01hN7P0IfMW04Y:BP19BDT0C4a<05ADE01OGel0KFe]07alO02:RXX0QXJ609:BTP2NWYh0
TI6A09NGU`2EUID0LW9b0080FEUI01H0D51@05=CD`10@400@D5104E5A@10@400@D5104=3@`10@400
@D5103lo?`16ATH0CDe=05=CD`14A4@0?Shn03Xj>P0n?Sh0?Cdm03`l?00n?Sh0>c/k0P0l?3`203dm
?@0603/k>`0h>3P0>c/k03Ti>@0j>SX0>CTi0P0h>3P303Xj>P0303/k>`0i>CT0>CTi00D0>CTi00D0
?Cdm03Ti>@0j>SX0>3Ph03Ti>@0203Lg=`0403/k>`0n?Sh0?Cdm03Xj>P<0>CTi00D0>c/k03Ti>@0j
>SX0?3`l03hn?P0203Xj>P80>CTi00@0?clo03Ph>00i>CT0>c/k0P0i>CT02@0k>c/0>SXj03Ti>@0h
>3P0>CTi03/k>`0m?Cd0>CTi03/k>`0203Xj>P0303/k>`0n?Sh0>c/k0080>3Ph00H0=cLg03Hf=P0h
>3P0>c/k03Xj>P10@40203Ti>@80>c/k00T0?3`l03Lg=`0f=SH0>SXj03`l?00i>CT0>SXj03Ph>00i
>CT00P0k>c/04@0i>CT0>3Ph03Xj>P0i>CT0>c/k03Xj>P0g=cL0>CTi03Ph>011@D40HF5Q07UiN@1h
N7P0J6QX05=CD`16ATH0>CTi0080=CDe00@0=3@d03Ph>00h>3P0?Cdm0P0h>3P0400e=CD0>3Ph03`l
?00i>CT0=cLg03Ph>00j>SX0>3Ph03Lg=`0j>SX0=CDe03dm?@0n?Sh0>SXj03Ti>@0h>3P403Lg=`03
03Ph>?oooooooooo00_ooooo000@ooooo`0704i>CP1ADE40DE5A04m?C`1<C4`0BDU904e=C@0304Y:
BP0B04a<C01:BTX0C4a<04e=C@18B4P0BDU904];B`1?Cdl0CDe=04Q8B01>CTh0BTY:04Q8B015ADD0
ATI604Q8B01;Bd/0AdM70P18B4P01P1ADE40ATI604I6AP16ATH0BTY:04Q8B0<0AdM70P19BDT0<`17
AdL0B4Q804Q8B019BDT0C4a<04U9B@14A4@0CTi>04];B`17AdL0BTY:04U9B@13@d<0A4A404E5A@1;
Bd/0@D5104I6AP11@D40ADE503lo?`11@D40@T920451@@0n?Sh0@D5104E5A@10@400@D5104E5A@17
AdL0A4A404I6AP13@d<0A4A40451@@13@d<0@D5104M7A`12@T80A4A404=3@`11@D40@T9204I6AP14
A4@0@D510410@012@T80@D5103lo?`020451@@<0?clo00@0@41003lo?`12@T80@T920P11@D400`14
A4@0?clo03hn?P020451@@80ATI60140AdM703hn?P11@D40?Shn0451@@10@400AdM704E5A@0n?Sh0
>c/k03`l?012@T80@D510492@P13@d<0A4A40492@P020451@@0K03`l?011@D40@41003`l?00n?Sh0
@D5103lo?`0n?Sh0@d=304I6AP0o?cl0?Shn0492@P11@D40A4A40451@@13@d<0@D5104A4A015ADD0
?clo03dm?@10@400?clo0451@@10@400@D510080ATI600X0@d=304A4A012@T80A4A40451@@0o?cl0
@41003lo?`0m?Cd0?clo0P12@T801P11@D40>SXj03Ph>00l?3`0@D510410@0<0@D5101H0@4100492
@P13@d<0@D51055AD@1jNWX0Hf=S05mOG`1FEUH0J6QX07EeM@1lO7`0KFe]05IFEP1=CDd0ADE50492
@P18B4P0ADE50492@P11@D40?clo0P11@D401P14A4@0?Cdm03`l?00n?Sh0@4100492@P80?Cdm00D0
@D510410@010@400ATI6059BDP0206i^KP0607IfMP23Ph<0Shn?08V9R@2FUYH0YZJV0P2WYjL0402>
SXh0OGem06MWI`1QHF40GEeM05mOG`1hN7P0SHf=0:2PX02VYZH0WinO08B4Q025QHD0T92@06ATI01<
C4`204U9B@0W05IFEP1NGUh0MgMg092@T02OWil0Y:BT0:NWY`2l_;`0alO70<k>cP38b<P0V9RH06i^
KP1SHf<0Kfm_07IfMP27QhL0Shn?08>3P`1ZJVX0?clo03hn?P16ATH0D51@07IfMP2SXj<0Ti>C07em
O@29RHT0TY:B0:b/[033`l<0aLG50;Zj^P2o_kl0bLW90<?3``39bLT0alO70080b<S80280d];B0=GE
e@3Hf=P0clo?0;Vi^@1oOgl0PH6108F5Q@1lO7`0Kfm_05]KF`1LG5`0DE5A04i>CP1NGUh0M7Ad08:2
PP1nOWh0O7al08R8R02ATI40U9BD0<G5a@3Ogml0b<S80;^k^`2g]kL0]KFe0;Jf]P2QXJ40MgMg05=C
D`1?Cdl0@D510P10@4000`1=CDd0JFUY09JFUP020;Vi^@090:ZZZP2CTi<0MgMg055AD@0o?cl0?3`l
03dm?@0n?Sh0?Cdm0080>SXj00<0?3`l03Xj>P0d=3@00P0j>SX01P0m?Cd0>c/k03/k>`0j>SX0>c/k
03Xj>P80>c/k0180?Cdm03Xj>P0h>3P0=cLg03/k>`0m?Cd0>CTi03`l?00k>c/0>CTi03Xj>P0i>CT0
>c/k03Ti>@0h>3P0=cLg03Ph>00g=cL203Xj>P0703/k>`0i>CT0>CTi03Ti>@0j>SX0@T9203Xj>P02
03`l?00C03/k>`0m?Cd0>CTi03Xj>P0k>c/0>CTi03/k>`0l?3`0>c/k03`l?00k>c/0?3`l0492@P0l
?3`0>CTi03Xj>P0i>CT0>c/k03`l?00403Xj>P0=03Ti>@0h>3P0=SHf03Lg=`0i>CT0>c/k03Hf=P0g
=cL0>CTi03/k>`0j>SX0>3Ph03Lg=`0203Ti>@0603dm?@0j>SX0?Cdm03Ti>@0l?3`0>CTi0P0f=SH0
300k>c/0>SXj03lo?`1>CTh0F5QH05eMG@1VIVH0OGem09nOW`27QhL0HV9R04E5A@<0>3Ph00D0=cLg
03Ph>00f=SH0=SHf03Ti>@0203Lg=`0303/k>`0g=cL0=CDe00<0>3Ph00@0>CTi03/k>`0h>3P0>CTi
0P0h>3P0100c<c<0>CTi03De=@0f=SH203Lg=`0403Hf=P0i>CT0=SHf04Q8B0gooooo000@ooooo`03
04i>CP1=CDd0CTi>0080Cdm?00L0C4a<04];B`17AdL0B4Q804];B`1?Cdl0C4a<0080CTi>00L0BTY:
04M7A`1;Bd/0BTY:04Q8B019BDT0D51@0080BTY:00D0B4Q804Y:BP19BDT0B4Q804E5A@0204Q8B007
04I6AP17AdL0ADE504I6AP19BDT0A4A404E5A@0304Y:BP0M04A4A015ADD0A4A40492@P14A4@0ADE5
04A4A010@400BDU904I6AP15ADD0BDU904E5A@16ATH0@d=30492@P16ATH0A4A40492@P13@d<0@410
03lo?`12@T80@41004A4A012@T80@d=30492@P11@D400P12@T8204I6AP0604M7A`12@T80@d=304=3
@`12@T80@D510`16ATH02P0n?Sh0@D5104=3@`0n?Sh0@d=30492@P0m?Cd0@4100451@@0l?3`503hn
?P070410@011@D40@d=304=3@`11@D40ADE504M7A`020451@@0303lo?`12@T80AdM70080ADE500h0
?clo0492@P0n?Sh0?Shn03`l?013@d<0ATI603lo?`11@D40@T920410@00n?Sh0?clo0492@P80?clo
00@0@41003lo?`11@D40@T920P0k>c/04@0o?cl0?Cdm0451@@0o?cl0@T9203lo?`0m?Cd0@41004U9
B@12@T80>SXj03/k>`0m?Cd0@T9203lo?`10@400@T9200@0?Shn00D0@T9204E5A@0o?cl0@41004=3
@`0203dm?@0i0410@00k>c/0?Cdm0492@P11@D40?clo03dm?@16ATH0@41003hn?P0m?Cd0?clo0410
@014A4@0@T920410@011@D40@41004E5A@12@T80>c/k04U9B@1jNWX0[jn_08R8R01kNg/0Hf=S05EE
E@18B4P0CDe=0492@P14A4@0@41004=3@`0j>SX0A4A40410@014A4@0@41003`l?00j>SX0?Cdm04A4
A00k>c/0?clo04=3@`14A4@0?clo04=3@`16ATH0@d=304A4A013@d<0ATI604Q8B01DE5@0C4a<0080
Cdm?00`0DU9B05MGE`1LG5`0IVIV06i^KP26QXH0O7al06i^KP1[Jf/0K6a/07EeM@1[Jf/3055AD@08
05=CD`1KFe/0B4Q804i>CP1CDe<0B4Q804Y:BP14A4@204E5A@1604Y:BP15ADD0?Shn04M7A`18B4P0
BDU904i>CP1DE5@0FEUI06ATI01WIfL0Kfm_07alO02LW9`0[Jf]0;Vi^@2SXj<0Ng]k07emO@1kNg/0
JFUY04m?C`18B4P0ADE505EEE@20P800TY:B09jNWP2^[Zh0^[Zj0;bl_039bLT0dM7A0=SHf03=cLd0
Vi^K08b<S021PH40Ng]k075aL@1iNGT0P82009^KV`2VYZH0^;Rh0;^k^`2o_kl0`<300;Ng]`2[Zj/0
X:2P08F5Q@1ZJVX0J6QX07QhN02@T900bLW90=OGe`3Hf=P0dm?C0;Jf]P2@T900YJFU0<K6aP3>c/h0
bl_;0;bl_02i^KT0^;Rh0;>c/`80`L7101`0^k^k09JFUP2<S8`0Ti>C0:RXZ02_[jl0Xj>S08B4Q023
Ph<0Rh^;09JFUP2/[:`0XJ6Q0861P@1<C4`0?Cdm0492@P0l?3`0>c/k03`l?00m?Cd0?3`l03/k>`0m
?Cd0?Shn03lo?`0l?3`0>SXj0P0k>c/02`0h>3P0?Cdm03dm?@0k>c/0>CTi03`l?00i>CT0>3Ph03/k
>`0h>3P0>SXj0080>c/k00@0>3Ph03/k>`0m?Cd0?3`l0P0j>SX00`0k>c/0>3Ph03/k>`0203dm?@05
03/k>`0i>CT0>SXj03dm?@0l?3`00P0i>CT0200j>SX0>c/k03Ti>@0h>3P0>c/k03`l?00k>c/0>CTi
0P0k>c/01@0g=cL0?3`l03Xj>P14A4@0>SXj0080?Cdm00<0=cLg03Xj>P0k>c/00P0j>SX09`0i>CT0
=SHf03Ph>00i>CT0>c/k03Ph>00j>SX0?3`l03Ph>00j>SX0>c/k03Ti>@0k>c/0@D5103Ti>@0k>c/0
>SXj03Ph>00j>SX0>c/k0410@00n?Sh0=SHf03Ti>@0m?Cd0DE5A08>3P`2_[jl0bl_;0=gMg@3EeMD0
a/K609fMW@1dM7@0C4a<03`l?00i>CT0=cLg03Hf=P0203Lg=`0303Xj>P0g=cL0=SHf00@0>3Ph0`0g
=cL01@0h>3P0=SHf03Ph>00m?Cd0>3Ph0080=cLg00/0>3Ph03Lg=`0i>CT0=CDe03Lg=`0h>3P0>CTi
03Ph>018B4P0CDe=05UIF@0=ooooo`004?ooool0101=CDd0DE5A055AD@1=CDd204Y:BP0404i>CP1<
C4`0BDU904Q8B080BTY:00d0Bd];04U9B@1;Bd/0ATI604U9B@17AdL0CTi>04e=C@16ATH0AdM704Q8
B015ADD0AdM700@0B4Q800<0ATI604A4A015ADD00P16ATH01017AdL0ADE504E5A@17AdL204A4A080
AdM700P0Cdm?04U9B@15ADD0AdM704Q8B013@d<0Bd];04A4A080@T9200D0@D510492@P11@D40@D51
04Q8B0030492@P0404=3@`0o?cl0@d=30451@@80@d=300@0A4A404E5A@13@d<0@T920P16ATH04@15
ADD0@d=30451@@10@400@D510492@P0o?cl0@D5104E5A@14A4@0@T920410@00o?cl0?Cdm0451@@0o
?cl0?Shn0080@41000T0@d=304E5A@11@D40?clo03hn?P12@T80@D5103hn?P11@D400P14A4@06015
ADD0@d=304A4A010@400?clo0451@@14A4@0?clo04A4A011@D40@41003hn?P0m?Cd0?Shn04E5A@12
@T80?3`l04E5A@10@400@d=30492@P13@d<0ADE503lo?`80>c/k00P0?3`l03hn?P10@400?Shn0410
@00o?cl0@41004A4A080?clo01L0@d=30492@P12@T80ADE504Q8B00o?cl0@41003dm?@12@T80?3`l
03/k>`11@D40?Shn0492@P16ATH0ADE504m?C`19BDT0?clo0410@00n?Sh0@T920451@@0203hn?P04
03dm?@0n?Sh0?Cdm0410@080?3`l0P10@40203`l?00403hn?P15ADD0?clo03hn?P80@T9201@0ADE5
0451@@1=CDd0MGEe07YjNP1MGEd0AdM703hn?P12@T80@41003hn?P12@T80?clo0492@P0o?cl0AdM7
03lo?`11@D40@4100492@P80@41001<0?Cdm03hn?P0l?3`0@T9204=3@`16ATH0@D510410@00o?cl0
A4A404=3@`0o?cl0ADE504=3@`12@T80ADE5051@D01IFET0Jf][0080NWYj00D0MWIf05iNGP17AdL0
B4Q804I6AP0204Y:BP0404=3@`0o?cl0ADE504A4A080ATI601D0DE5A071`L02:RXX0WYjN09VIV@2L
W9`0XZ:R09VIV@2>SXh0QhN708J6QP1iNGT0MGEe06=SH`1>CTh0AdM704A4A015ADD0B4Q804=3@`12
@T800P18B4P02P19BDT0Cdm?061PH01ZJVX0O7al09nOW`2m_Kd0^KVi09:BTP1DE5@20410@00Q03lo
?`1<C4`0De=C06EUI@1lO7`0MGEe07inOP25QHD0Q8B408R8R01VIVH0JVYZ07emO@1VIVH0MWIf08f=
S@1oOgl0SHf=09BDU02FUYH0RXZ:07moO`1mOGd0S8b<092@T02DU9@0VYZJ0:6QX@39bLT0^KVi08:2
PP1`L700UIFE0080[Zj^01X0LG5a05QHF01ZJVX0NWYj07inOP20P800OWin07YjNP22PX80RHV908^;
R`2a/K40`<300<?3``2l_;`0[:b/07inOP29RHT0/;2`09ZJVP1`L700DU9B06ATI01PH600I6AT07Ui
N@80T92@00H0JVYZ04M7A`0k>c/0?3`l03hn?P0m?Cd403/k>`80?3`l01<0>c/k03Xj>P0k>c/0>c/k
03Xj>P0i>CT0>SXj03/k>`0f=SH0>3Ph03Xj>P0h>3P0>CTi03dm?@0j>SX0>c/k04=3@`0k>c/0>SXj
0080>c/k0100>CTi03Xj>P0j>SX0>c/k03Lg=`0j>SX0?3`l03dm?@0n?Sh0>CTi03`l?00k>c/0?clo
03`l?00j>SX0>c/k0P0l?3`0300k>c/0>3Ph03Ti>@0k>c/0?3`l03/k>`0i>CT0@41003`l?00h>3P0
?3`l03hn?P80?Cdm00<0?Shn03/k>`0i>CT00`0i>CT03`0n?Sh0=cLg03Ti>@0i>CT0?clo03Ti>@0h
>3P0>c/k03Xj>P0h>3P0=CDe03`l?00j>SX0>c/k03Xj>P0203/k>`0A03Ti>@1:BTX0K6a/0::RXP37
alL0g]kN0=cLg031`L40WYjN09>CT`1/K6`0Cdm?03lo?`0j>SX0=cLg03Xj>P0h>3P00P0g=cL01P0h
>3P0>CTi03Lg=`0g=cL0>3Ph03Lg=`80>3Ph00<0=cLg03Ph>00g=cL00P0f=SH01P0h>3P0>SXj03Xj
>P0h>3P0>CTi03Hf=P<0>3Ph00L0=cLg03Ph>00j>SX0B4Q805eMG@0j>SX0>CTi00gooooo000@oooo
o`0404i>CP1?Cdl0D51@05=CD`<0CDe=00D0Bd];04Q8B01<C4`0CDe=04E5A@0304Q8B080BTY:00D0
ADE504];B`19BDT0ADE504U9B@0204M7A`0<04A4A019BDT0Bd];04Y:BP15ADD0ATI604M7A`15ADD0
B4Q804M7A`16ATH0BTY:0P16ATH00`1:BTX0AdM704Q8B00204];B`0704Q8B01;Bd/0ADE504I6AP14
A4@0AdM704Q8B00204A4A00:0451@@13@d<0@d=30492@P1:BTX0BDU904I6AP12@T80B4Q804U9B@80
@T920P0o?cl07@12@T80A4A40492@P15ADD0@T9203hn?P11@D40BDU904E5A@14A4@0@d=30451@@12
@T80?Cdm0410@011@D40?clo0410@013@d<0?clo0410@013@d<0@4100451@@10@400@d=30492@P15
ADD0?clo00<0@41000L0?Cdm0451@@13@d<0@d=30410@00o?cl0@D510080?Cdm00`0?3`l04=3@`0n
?Sh0?clo0451@@13@d<0?Shn03lo?`12@T80ADE50451@@0m?Cd20451@@0304=3@`15ADD0@D510080
@D5100@0?clo0492@P0n?Sh0>SXj0P0m?Cd0:010@400@d=303lo?`0o?cl0@T9203dm?@11@D40?Shn
0451@@15ADD0B4Q803`l?010@400?clo0410@00l?3`0@41004A4A019BDT0@T920451@@0o?cl0@T92
04I6AP10@400?3`l04=3@`14A4@0@41003hn?P10@400?clo0451@@0k>c/0@41003hn?P0o?cl0?Cdm
03Ti>@0m?Cd203hn?P0?04I6AP11@D40A4A404Q8B013@d<0@41004I6AP13@d<0@T9204=3@`17AdL0
A4A40492@P14A4@0?clo0080?Shn00H0@41003hn?P0l?3`0@D510492@P0l?3`203/k>`0303hn?P0l
?3`0?Shn0080@D5100X0?Cdm04M7A`11@D40@d=304M7A`18B4P0?clo0492@P13@d<0>c/k0P0o?cl0
1P11@D40ATI604a<C01;Bd/0AdM704I6AP80CDe=00P0@D5104A4A012@T80Bd];04U9B@18B4P0CTi>
04];B`80CDe=0100EeMG069RHP1lO7`0VIVI0:ZZZP2MWId0UYJF08J6QP1aLG40J6QX06EUI@1[Jf/0
IVIV075aL@1gMgL0P8200P26QXH04`2NWYh0/k>c0:6QX@2:RXX0PH6106m_K`1/K6`0Ng]k06ATI01L
G5`0De=C05QHF01KFe/0EUIF051@D01BDU80B4Q804=3@`11@D400P13@d<0>012@T80IFEU07UiN@2D
U9@0[jn_0:b/[031`L40alO70<S8b03Fe]H0YZJV09FEU@25QHD0K6a/06IVIP1gMgL0OGem075aL@28
R8P0V9RH08R8R029RHT0[Jf]0<W9b@2m_Kd0`L710;fm_@2d];@0WinO06][J`1?Cdl0IVIV065QH@1a
LG40K6a/071`L01YJFT0MgMg06QXJ01FEUH0HV9R075aL@1TI6@0Q8B409VIV@2XZ:P0QXJ606MWI`1E
EED0IfMW08>3P`2;Rh/0Lg=c05]KF`1WIfL0NGUi0P2CTi<01`2IVIT0U9BD0:VYZ@2c/k<0OWin04I6
AP0n?Sh00`0j>SX01`0k>c/0>CTi03/k>`0n?Sh0?Cdm03Ti>@0m?Cd00P0n?Sh01P0i>CT0?3`l03/k
>`0i>CT0?3`l03Ti>@80>c/k00<0?Cdm03`l?00k>c/00P0m?Cd01P0i>CT0?Cdm03Ti>@0f=SH0>c/k
03`l?080?Cdm00L0>CTi03`l?00l?3`0>c/k03Ti>@0g=cL0>CTi0080>c/k00X0?3`l03/k>`0k>c/0
?Cdm03`l?00k>c/0>SXj03Ti>@0l?3`0>3Ph0`0j>SX0100n?Sh0=SHf03/k>`0j>SX203Ph>00703Ti
>@0k>c/0?3`l03Xj>P0h>3P0>SXj03Lg=`0203Ph>00I03Ti>@0k>c/0>SXj03Lg=`0k>c/0>SXj03Ti
>@0e=CD0>CTi03dm?@0h>3P0>CTi03hn?P1>CTh0SHf=0:j^[P2OWil0UiNG08>3P`1SHf<0BDU903lo
?`0m?Cd0>SXj03Ti>@0203`l?00403Ti>@0j>SX0=cLg03Hf=P80=cLg00<0=CDe03Lg=`0j>SX00P0i
>CT00`0h>3P0=cLg03Lg=`0203Lg=`80=SHf0100>SXj03Ph>00h>3P0>SXj03Ti>@0g=cL0>3Ph03Lg
=`0i>CT0=cLg03Hf=P0g=cL0>3Ph03Xj>P0f=SH0>3Ph3Oooool0013ooooo01@0C4a<051@D01?Cdl0
DE5A04e=C@1<C4`0CDe=04];B`1<C4`0B4Q804];B`19BDT0AdM704Q8B017AdL0CDe=04Q8B016ATH0
BTY:04U9B@80B4Q800D0BDU904];B`17AdL0B4Q804I6AP0204E5A@0704i>CP16ATH0BTY:04Y:BP13
@d<0A4A404M7A`0204=3@`0704M7A`11@D40AdM704a<C017AdL0A4A404M7A`0204=3@`0604M7A`16
ATH0B4Q804I6AP1;Bd/0ADE50P18B4P02014A4@0@D5104=3@`12@T80AdM705IFEP19BDT0?clo0P15
ADD01P0o?cl0@d=303lo?`0o?cl0@T9203dm?@80?Shn0P0o?cl03P13@d<0@D510410@012@T80@D51
03lo?`15ADD0@4100492@P0o?cl0?Cdm0410@00o?cl0@T920P0o?cl01P12@T80@D510410@00n?Sh0
@41003`l?080?clo00T0@41003hn?P0m?Cd0?clo0410@011@D40@41003dm?@0l?3`00P0o?cl01P10
@400?Shn03lo?`12@T80?Cdm0410@080@T9200H0@d=304M7A`17AdL0@D5104Q8B016ATH203lo?`08
04E5A@1:BTX0@d=303hn?P15ADD0@d=303dm?@0o?cl20410@00903lo?`12@T80?clo0492@P13@d<0
ATI604=3@`0o?cl0@T920080@D5100@0>CTi0492@P0n?Sh0@T920P10@4001`14A4@0ADE503hn?P11
@D40?Shn0451@@0o?cl00P11@D400`13@d<0@41004A4A00203lo?`0803dm?@0o?cl0?clo03hn?P0k
>c/0@D510410@012@T8204E5A@0A0492@P0o?cl0@D5103dm?@1;Bd/0G5aL05YJFP1=CDd0ATI60451
@@0n?Sh0?Cdm0451@@0l?3`0>c/k03hn?P0o?cl00`11@D400`0n?Sh0ADE504=3@`0203lo?`0E03hn
?P15ADD0ATI605ADE01TI6@0IfMW05MGE`14A4@0>CTi0451@@12@T80@41003/k>`0n?Sh0@T9203`l
?00m?Cd0@T9203lo?`0l?3`0?clo0080A4A400T0AdM70451@@10@400?Cdm03lo?`13@d<0Bd];06=S
H`1dM7@00P2<S8`208R8R01U08b<S01gMgL0PX:208N7Q`29RHT0Ogmo065QH@1?Cdl0A4A404M7A`1D
E5@0DU9B06ATI01mOGd0Ph>308^;R`22PX80OGem08b<S028R8P0UiNG0:n_[`2b/[80Zj^[09:BTP1m
OGd0Lg=c06YZJP1aLG40Ph>309JFUP2NWYh0UIFE08F5Q@1KFe/0BDU903lo?`12@T80@d=304A4A018
B4P0EEEE06a/K01oOgl0Y:BT09jNWP2EUID0KVi^051@D01>CTh0B4Q804I6AP1LG5`0JFUY08>3P`2T
Y:@0YZJV08j>SP2:RXX0VYZJ09fMW@2ATI40SHf=09BDU028R8P0KVi^06MWI`26QXH0ZJVY0<C4a03>
c/h0cLg=0=?Cd`3<c<`0aLG50;Bd]02[Zj/0WYjN08V9R@1fMWH0OWin09bLW02MWId0IfMW06EUI@21
PH40MWIf05mOG`1JFUX0Fe]K05eMG@1UIFD0P8200:VYZ@2n_[h0^k^k0;Bd]02HV9P0Hf=S05EEE@1:
BTX00`10@400300k>c/0>CTi03dm?@10@400AdM705MGE`1WIfL0Lg=c04Y:BP0o?cl0@41003hn?P80
?3`l00d0?Cdm03/k>`0k>c/0=cLg03`l?00m?Cd0?3`l03Xj>P0m?Cd0>3Ph03Lg=`0i>CT0>c/k0080
>CTi00L0>SXj03Ti>@0h>3P0>CTi03Hf=P0h>3P0?3`l0080>c/k0140?3`l03Hf=P0i>CT0?3`l03/k
>`0h>3P0>CTi03Xj>P0f=SH0=cLg03Xj>P0m?Cd0=cLg03`l?00g=cL0>CTi03`l?00203Xj>P0503`l
?00k>c/0>SXj03/k>`0i>CT00P0j>SX00`0i>CT0>c/k03Ph>00203Ph>00403Ti>@0f=SH0>3Ph03Lg
=`80>SXj0P0h>3P01@0g=cL0=CDe03dm?@13@d<0@T920080?Cdm00L0>CTi03/k>`0h>3P0>CTi03/k
>`0j>SX0>3Ph0080>CTi01H0?3`l03Ti>@0f=SH0=SHf03Ph>00i>CT0=CDe03Hf=P0j>SX0=SHf03Ti
>@0g=cL0=CDe03Xj>P0h>3P0>SXj03Lg=`0f=SH0>CTi03Hf=P0e=CD0>3Ph0P0i>CT203Ph>0<0=SHf
0P0g=cL00`0i>CT0<c<c03Lg=`0=ooooo`004?ooool01P1ADE40Cdm?051@D01=CDd0CTi>04Y:BP80
C4a<00D0HF5Q06ATI01;Bd/0C4a<04M7A`0204Q8B00304a<C016ATH0ATI600<0B4Q800@0ATI604M7
A`19BDT0ATI60P18B4P06P15ADD0B4Q804e=C@16ATH0A4A404a<C017AdL0B4Q804M7A`13@d<0ATI6
04E5A@12@T80Bd];04M7A`16ATH0AdM704Q8B011@D40A4A404M7A`12@T80A4A404=3@`14A4@0@410
0`13@d<01@16ATH0ADE504=3@`12@T80B4Q80080@D5100T0B4Q80492@P0o?cl0@41003hn?P12@T80
?Shn03lo?`10@4000`11@D400`15ADD0ATI604A4A00203hn?P0;0410@013@d<0@T920492@P0n?Sh0
?Cdm0410@00n?Sh0@D5104A4A011@D400P0j>SX0400l?3`0@41003lo?`10@400?clo04=3@`12@T80
?clo0410@00l?3`0?clo03dm?@0l?3`0?Cdm0451@@10@40303lo?`0903hn?P10@400?Shn03`l?014
A4@0ADE504A4A016ATH0@T9200<0?clo0P12@T801P11@D40?clo03hn?P10@400?Cdm03lo?`80@410
01D0@D5103lo?`10@400@d=30410@011@D40?Cdm04=3@`15ADD0@T9204E5A@13@d<0@41003lo?`12
@T80@D5103/k>`0j>SX0?Cdm0451@@12@T800P0n?Sh06P0l?3`0?Shn03`l?00m?Cd0>c/k0492@P14
A4@0@d=30410@00l?3`0?Shn03Xj>P0m?Cd0?3`l0410@014A4@0@D5103lo?`0n?Sh0@T9204E5A@14
A4@0FUYJ07EeM@1bLW80FUYJ0P0n?Sh0100i>CT0?3`l03lo?`0m?Cd203/k>`0803dm?@0l?3`0?clo
03lo?`0m?Cd0?Shn03`l?00o?cl203`l?080?clo04/0A4A4051@D01GEeL0EUIF04i>CP1;Bd/0?clo
03`l?013@d<0C4a<04A4A01EEED0Cdm?05MGE`1LG5`0FEUI05]KF`1RHV80J6QX06=SH`1@D500A4A4
03hn?P0o?cl0@41004=3@`12@T80@D510410@013@d<0ADE504Y:BP1;Bd/0@d=304M7A`1HF5P0Hf=S
07=cL`28R8P0TY:B08F5Q@1eMGD0IVIV06e]K@1SHf<0J6QX079bLP1kNg/0PH61071`L01VIVH0Jf][
05QHF01=CDd0D51@04m?C`1FEUH0JFUY07]kN`20P800H61P04a<C01FEUH0Fe]K05ADE01IFET0Lg=c
08V9R@2/[:`0W9bL05iNGP10@400AdM704Y:BP0o?cl00P0n?Sh03@10@400B4Q804a<C01?Cdl0J6QX
05IFEP1=CDd0C4a<04I6AP0o?cl0@T9206YZJP2;Rh/00P2FUYH05P26QXH0FUYJ04a<C01ADE40E5AD
05iNGP1nOWh0TY:B09NGU`24Q8@0KFe]06][J`1bLW80M7Ad092@T02`/;00dM7A0=gMg@3QhN40g=cL
0=OGe`3Bd]820<30`00T0;Vi^@2ATI40HV9R04i>CP1FEUH0FEUI05aLG01]KFd0JFUY05YJFP1DE5@0
@d=305ADE01WIfL0P82009fMW@2FUYH0V9RH0;>c/`2WYjL0Ng]k05UIF@13@d<0?Cdm03`l?01:BTX0
N7Qh0:JVYP34a<@0dM7A0;Fe]@2:RXX0EeMG04U9B@0n?Sh0?clo0P0k>c/0100m?Cd0>CTi03Ti>@0j
>SX203`l?00603/k>`0h>3P0>SXj03Ti>@0g=cL0>CTi0P0j>SX01P0l?3`0>c/k03Ph>00j>SX0=cLg
03Xj>P80?3`l0`0k>c/00`0j>SX0>CTi03Ti>@0203Ti>@0903Xj>P0h>3P0?3`l03dm?@0g=cL0>3Ph
03`l?00n?Sh0?Cdm0080?3`l00<0>SXj03Ti>@0i>CT00`0i>CT0100j>SX0>3Ph03Ti>@0j>SX203Lg
=`0303Ph>00i>CT0>CTi0080>CTi0P0h>3P01@0l?3`0=CDe03Lg=`0k>c/0>SXj0080>CTi00@0?Cdm
03`l?00i>CT0=cLg100h>3P00`0j>SX0>3Ph03Lg=`0203Ph>00403Lg=`0f=SH0=cLg03Ph>0<0>CTi
00L0>3Ph03Xj>P0i>CT0=cLg03Xj>P0g=cL0>CTi0080>3Ph00L0>CTi03Lg=`0e=CD0>3Ph03Ti>@0g
=cL0=SHf0080=cLg00<0=SHf03De=@0e=CD00P0f=SH00`0d=3@0=cLgooooo`0<ooooo`004?ooool0
2P1@D500CTi>051@D01?Cdl0Bd];04e=C@1>CTh0C4a<04e=C@1@D50204e=C@0504m?C`1=CDd0BDU9
04Q8B019BDT00P16ATH01018B4P0AdM704E5A@18B4P204];B`0804e=C@18B4P0B4Q804a<C01=CDd0
Fe]K04e=C@17AdL304];B`0804I6AP1;Bd/0B4Q804M7A`16ATH0A4A404=3@`16ATH404A4A00504I6
AP13@d<0A4A404M7A`1:BTX00P15ADD01P1CDe<0C4a<04U9B@14A4@0AdM704=3@`80@T9200@0C4a<
04i>CP12@T80A4A40P13@d<04P16ATH0@d=303lo?`0o?cl0ADE50451@@13@d<0B4Q804E5A@13@d<0
@D5104E5A@13@d<0A4A403lo?`14A4@0@4100451@@80?Shn00H0ATI60492@P14A4@0ADE503lo?`10
@40203lo?`050451@@13@d<0@D510492@P14A4@00P12@T801010@400?Shn03lo?`12@T8203lo?`80
?Shn01<0?3`l0410@00o?cl0?clo03`l?00o?cl0A4A40451@@0m?Cd0@D510492@P0o?cl0@T9204M7
A`15ADD0A4A403lo?`0m?Cd0?clo0080@41000X0?Cdm04=3@`14A4@0@4100451@@0o?cl0@d=304E5
A@11@D40BTY:0P13@d<07P16ATH0@D5104I6AP1=CDd0@D5103dm?@11@D40@d=30492@P0n?Sh0?3`l
03dm?@0l?3`0@D510492@P0o?cl0?Shn04E5A@18B4P0@T9203`l?00n?Sh0@T9204A4A016ATH0A4A4
04M7A`13@d<0A4A404I6AP80@T9200T0?Shn04M7A`1HF5P0DE5A04=3@`0o?cl0?Shn03`l?00o?cl0
0P0m?Cd02P0o?cl0>c/k03/k>`10@400@D510492@P11@D40@41003lo?`0n?Sh30451@@0I03`l?00m
?Cd0AdM70492@P13@d<0?Cdm03Xj>P0o?cl0ADE503lo?`16ATH0ADE504i>CP1FEUH0Fe]K07IfMP2<
S8`0Shn?08R8R01hN7P0IFEU05QHF01=CDd0ADE503dm?@020410@00L0492@P11@D40@41003hn?P14
A4@0@D5104=3@`16ATH0Bd];05iNGP21PH40Vi^K09bLW02SXj<0Zj^[0:JVYP2PX:00T92@08N7Q`1l
O7`0SXj>09ZJVP2SXj<0/;2`0;Vi^@2o_kl0aLG508^;R`80BDU900D0C4a<051@D01=CDd0CDe=04a<
C00205=CD`07059BDP1DE5@0EUIF05mOG`1SHf<0GUiN05UIF@0204e=C@0H04M7A`18B4P0?Shn0451
@@0o?cl0@d=304Q8B01=CDd0DE5A051@D01>CTh0ADE503lo?`0n?Sh0@d=303hn?P13@d<0ATI604E5
A@1CDe<0FUYJ05IFEP1ADE40BTY:0P14A4@0401<C4`0GEeM08^;R`2h^;P0b/[:0;^k^`2l_;`0];Bd
0:>SX`2:RXX0Ogmo08N7Q`2IVIT0ZZZZ0<K6aP3AdM420<O7a`0A0<g=c@3Hf=P0emOG0;no_`2QXJ40
Kfm_05QHF018B4P0CDe=04a<C017AdL0ADE503lo?`18B4P0De=C04m?C`1CDe<00P1GEeL04P1aLG40
Rh^;09JFUP2ZZZX0Ph>304m?C`10@400?Cdm04U9B@1KFe/0UIFE0<G5a@2h^;P0JFUY04A4A00n?Sh0
ADE50410@080>SXj0100?Shn03`l?00k>c/0>SXj03dm?@13@d<0>c/k03Xj>P0n?Sh0>SXj03dm?@0j
>SX0>3Ph03Hf=P0j>SX0>c/k0P0i>CT203Ph>00603Ti>@0l?3`0?clo03Xj>P0o?cl0>SXj0`0k>c/0
1@0j>SX0>CTi03Xj>P0m?Cd0>SXj0080>3Ph00<0=SHf03Ph>00m?Cd00P0l?3`01@10@400?3`l03Xj
>P0i>CT0>3Ph00<0>SXj00D0?3`l03Ti>@0i>CT0>CTi03Xj>P0203`l?00:03/k>`0i>CT0=cLg03/k
>`0h>3P0=CDe03Ti>@0l?3`0>CTi03Xj>P80>c/k00P0>SXj03Ti>@0i>CT0>SXj03Lg=`0h>3P0>CTi
03Ph>0<0=cLg0`0f=SH203Lg=`80>c/k00@0>3Ph03Lg=`0i>CT0>CTi0`0h>3P0100f=SH0=CDe03Hf
=P0g=cL203Hf=P0:03Ph>00i>CT0=cLg03Ph>00f=SH0>3Ph03Hf=P0g=cL0>SXj03Lg=`<0=SHf3Ooo
ool0013ooooo0100E5AD059BDP1=CDd0CTi>04];B`1>CTh0C4a<04Y:BP17AdL0BTY:04e=C@19BDT0
De=C051@D01<C4`0ATI60P18B4P04`17AdL0B4Q804U9B@1<C4`0BTY:04U9B@1=CDd0DE5A04Y:BP16
ATH0BDU904M7A`16ATH0@D5104Q8B019BDT0B4Q804M7A`1:BTX00P17AdL03018B4P0C4a<04];B`18
B4P0ATI604E5A@13@d<0ADE504Q8B015ADD0CDe=04I6AP80@D5102@0A4A40492@P14A4@0ADE504M7
A`16ATH0AdM704E5A@12@T80?Shn04A4A012@T80@41004A4A013@d<0@41004E5A@0n?Sh0@D5103dm
?@11@D40?3`l04I6AP11@D40@41003lo?`13@d<0?clo0410@014A4@0@41004I6AP12@T80@4100451
@@0o?cl404=3@`060410@00n?Sh0?clo03lo?`11@D40ADE50P12@T805P10@400@D510410@011@D40
@4100492@P10@400?3`l03hn?P12@T80A4A403lo?`0j>SX0ADE50410@011@D40@T9204E5A@10@400
?Shn0410@00o?cl203`l?0060451@@10@400?clo03/k>`0l?3`0@4100P0o?cl02P10@400@T9203lo
?`0m?Cd0@T9204A4A012@T80?clo04I6AP1=CDd203/k>`0503hn?P0l?3`0@D5104=3@`0n?Sh00P0o
?cl20410@00503hn?P0i>CT0>SXj03Ti>@0l?3`00P0n?Sh04`0o?cl0@41004I6AP0o?cl0>SXj04=3
@`0n?Sh0A4A403lo?`0k>c/0?Shn04A4A00m?Cd0?Shn0492@P0n?Sh0>c/k03dm?@10@4000P0m?Cd0
1@0j>SX0>c/k03Ph>00o?cl0>SXj0080>c/k00`0?Cdm0492@P15ADD0ADE50451@@0l?3`0>c/k03hn
?P0m?Cd0@T9203lo?`0j>SX203lo?`0603/k>`11@D40@T9203dm?@0n?Sh0?Cdm0P0o?cl08@0n?Sh0
@41004A4A01<C4`0IFEU06i^KP1QHF40EEEE04I6AP13@d<0>SXj03lo?`11@D40?Cdm03hn?P0o?cl0
A4A40410@00m?Cd0@d=304E5A@16ATH0CDe=05mOG`1hN7P0UIFE0::RXP2^[Zh0Z:RX09FEU@1mOGd0
Lg=c06a/K00206][J`0`07emO@2DU9@0UYJF08^;R`29RHT0Rh^;07emO@1dM7@0QhN708^;R`2:RXX0
VIVI09NGU`1mOGd0JVYZ05mOG`1SHf<0L71`07alO023Ph<0TI6A0:JVYP2d];@0c<c<0=;BdP2DU9@0
JFUY05aLG01;Bd/0ADE50492@P10@400@D510410@012@T80?Shn0410@01:BTX0De=C055AD@1;Bd/0
ATI60451@@15ADD0B4Q804=3@`1;Bd/0?clo0P17AdL02P1:BTX0C4a<061PH01fMWH0PX:208B4Q021
PH40UYJF0<C4a03Ng]h20>?Sh`0=0>3Ph03Lg=`0c/k>0<;2`P2`/;00QXJ607alO01fMWH0PH6109>C
T`2LW9`0WIfM0;6a/@020<c<c00^0<S8b02f][H0/;2`0:BTY02BTY80Shn?07moO`1TI6@0Kfm_06MW
I`17AdL0ADE504Y:BP14A4@0B4Q804E5A@14A4@0H61P071`L01aLG40MgMg08B4Q02=SHd0JFUY04];
B`1GEeL0TY:B0:n_[`2KVi/0K6a/0410@013@d<0>SXj03`l?00k>c/0?Shn0410@00h>3P0>c/k03`l
?00m?Cd0>3Ph03Ti>@0k>c/0=cLg03Ti>@80>SXj01@0=cLg03Ti>@0h>3P0>CTi03hn?P0l?3`0>c/k
03dm?@12@T80B4Q804e=C@1>CTh0FEUI07inOP28R8P0HF5Q0410@00j>SX0>c/k03Xj>P80?3`l00<0
>c/k03lo?`0n?Sh00P0j>SX203hn?P80>c/k0P0j>SX203dm?@0403`l?00j>SX0?3`l03/k>`80>SXj
0P0k>c/0500j>SX0=cLg03Ph>00h>3P0>c/k03Ph>00i>CT0=SHf03Xj>P0i>CT0>SXj03Ti>@0h>3P0
=cLg03/k>`0f=SH0=cLg03Xj>P0h>3P0=cLg0P0h>3P0200e=CD0=SHf03Ph>00h>3P0=cLg03Ph>00i
>CT0>3Ph0P0f=SH0100g=cL0>3Ph03Ph>00j>SX303Hf=P0@03Lg=`0f=SH0=CDe03Lg=`0h>3P0=cLg
03/k>`0h>3P0=cLg03Hf=P0h>3P0?3`l03De=@0i>CT0=cLg03Hf=Pgooooo000@ooooo`0404i>CP1?
Cdl0Cdm?04i>CP80C4a<0P19BDT06@18B4P0BTY:04];B`1:BTX0ATI604U9B@1<C4`0B4Q804Y:BP18
B4P0Bd];04I6AP15ADD0BDU904];B`19BDT0ATI604Y:BP1;Bd/0AdM704U9B@1:BTX0ATI604A4A015
ADD00P16ATH03`15ADD0BDU904I6AP17AdL0ATI604=3@`16ATH0BDU904E5A@13@d<0AdM704=3@`14
A4@0@d=304I6AP020492@P0S0451@@14A4@0@D5104I6AP11@D40A4A404=3@`10@400?clo0410@016
ATH0BDU904Q8B00m?Cd0@41004I6AP18B4P0AdM703hn?P13@d<0B4Q804E5A@0j>SX0@D5103`l?013
@d<0@D5104M7A`12@T80@4100451@@12@T80A4A40451@@0l?3`00`13@d<20492@P0E04A4A011@D40
@d=303lo?`14A4@0@d=30410@012@T80AdM704=3@`11@D40@4100492@P13@d<0@D5103lo?`11@D40
?clo03hn?P12@T80A4A400<0?clo00<0?3`l03lo?`10@4000P0o?cl01`14A4@0?Shn0451@@15ADD0
?clo0492@P0m?Cd00P0n?Sh01@11@D40@41003hn?P10@400?3`l0080?Shn00@0@D5104M7A`15ADD0
@4100P12@T80300m?Cd0?Shn03dm?@10@400?Shn0410@00m?Cd0@T9204E5A@0o?cl0@41003lo?`80
?Shn00H0@41003hn?P12@T80?clo0410@00m?Cd20451@@050410@019BDT0?clo04=3@`15ADD00P11
@D402P0o?cl0?Cdm04=3@`18B4P0>SXj03lo?`11@D40?Shn03`l?012@T8203lo?`030410@012@T80
ADE500<0?clo01l0@d=30492@P10@400@D5104Q8B014A4@0@T9204=3@`11@D40?Cdm03hn?P10@400
?3`l03/k>`0m?Cd0@d=303lo?`0m?Cd0@41003lo?`12@T80?clo04I6AP1;Bd/0ATI604=3@`0o?cl0
@D510410@013@d<0?clo0080@d=301X0@41003dm?@0k>c/0?3`l0410@011@D40?Shn04U9B@1OGel0
Lg=c0861P@28R8P0N7Qh06i^KP1VIVH0Hf=S06YZJP1YJFT0I6AT06i^KP20P800TY:B09fMW@2KVi/0
XJ6Q09nOW`80V9RH01@0Ng]k06i^KP1UIFD0JVYZ07alO02EUID0[jn_0:VYZ@2NWYh0VYZJ09:BTP2K
Vi/0[jn_0<?3``37alL0b<S80=3@d03Cdm<0e]KF0=_Kf`80gmoO0280d=3@0<?3``2GUiL0Ng]k08b<
S02LW9`0Shn?07inOP1aLG40HV9R05]KF`1CDe<0Cdm?04A4A01;Bd/0@T9203hn?P16ATH0B4Q80492
@P19BDT0K6a/069RHP19BDT0GUiN09FEU@2RXZ80VIVI0;6a/@3>c/h0iNGU0>[ZjP3Ph>00^;Rh0P2W
YjL07`2TY:@0YZJV0:FUY@2h^;P0cLg=0<k>cP3:b/X0alO70;Zj^P2f][H0V9RH09FEU@2<S8`0Jf][
05eMG@1VIVH0NGUi0861P@2FUYH0`<300=7Ad@2k^k/0V9RH07]kN`1_Kfl0JFUY06=SH`1GEeL0Cdm?
0410@00o?cl00P0n?Sh05P1:BTX0HV9R08V9R@2XZ:P0YjNW096AT@1JFUX0AdM704m?C`1[Jf/0O7al
05ADE00o?cl0>c/k03hn?P0m?Cd0?Shn0451@@0k>c/0?Shn03dm?@0j>SX203Ti>@0303/k>`0i>CT0
>c/k0080>SXj0`0h>3P04@0k>c/0A4A405]KF`1oOgl0Vi^K0;Jf]P38b<P0bl_;0<71`@2f][H0YjNW
07IfMP17AdL0?Cdm03`l?00k>c/0?3`l0080>3Ph00<0>SXj03Ph>00j>SX00P0m?Cd303Xj>P0:03`l
?00j>SX0>3Ph03`l?00k>c/0>CTi03Xj>P0l?3`0>CTi03dm?@80>SXj00@0>CTi03Ph>00j>SX0>CTi
0P0h>3P0100n?Sh0>c/k03Lg=`0i>CT203Hf=P80=cLg0P0h>3P01P0f=SH0>CTi03Ti>@0g=cL0=3@d
03Lg=`80>SXj00P0=cLg03`l?00h>3P0>3Ph03Lg=`0j>SX0>c/k03Lg=`80>3Ph00T0>CTi03Hf=P0f
=SH0=cLg03Ti>@0f=SH0=cLg03Hf=P0e=CD00P0h>3P0100e=CD0>CTi03Ti>@0e=CD303Lg=`0403De
=@0i>CT0=SHf03Ph>0gooooo000@ooooo`@0CTi>0`1;Bd/04018B4P0Bd];04a<C01=CDd0CTi>04U9
B@1;Bd/0C4a<04M7A`1=CDd0C4a<04Q8B015ADD0ATI604U9B@1;Bd/204Q8B00:04];B`1:BTX0BDU9
04U9B@16ATH0AdM704Y:BP13@d<0ATI604M7A`80ATI600D0Bd];04U9B@18B4P0A4A40451@@0204I6
AP0304A4A012@T80@D510080@41000D0A4A40451@@13@d<0@41004=3@`020492@P0N04];B`1<C4`0
AdM704A4A015ADD0DU9B04Y:BP14A4@0?Shn0492@P14A4@0@D5104A4A018B4P0@T9204=3@`16ATH0
@d=30451@@12@T80@41004A4A011@D40@41004=3@`14A4@0@41003lo?`12@T80@d=30P11@D404013
@d<0AdM70410@00m?Cd0?Shn0410@014A4@0?Shn0451@@16ATH0@T920410@015ADD0@D5104=3@`14
A4@20451@@0N03/k>`0n?Sh0ADE503hn?P0o?cl0@D5103hn?P14A4@0?clo0410@00o?cl0@41004A4
A00o?cl0?3`l0451@@0j>SX0@D5104E5A@12@T80@4100492@P13@d<0?Shn0410@00m?Cd0>c/k03hn
?P0m?Cd0?clo0P10@4001P0m?Cd0?clo0410@011@D40?Shn03/k>`80?Cdm00`0@T9203hn?P14A4@0
B4Q80492@P11@D40?Cdm0492@P0o?cl0@41003dm?@0n?Sh20451@@0904=3@`11@D40?Shn03lo?`14
A4@0@d=303dm?@0o?cl0@T920080?clo00@0@41003`l?00o?cl0@4100P0n?Sh203Xj>P060410@00o
?cl0AdM704I6AP0m?Cd0?Shn0`10@4002P11@D40?Shn03dm?@0n?Sh0@d=30410@015ADD0BTY:0492
@P0o?cl203/k>`0503Xj>P0i>CT0?3`l03dm?@10@4000P0m?Cd01@11@D40ATI603dm?@10@400?Shn
0080?Cdm00`0?3`l03Xj>P0i>CT0@41003Xj>P10@400@D5104A4A00o?cl0?Shn03dm?@0j>SX203lo
?`0L04E5A@1QHF40Shn?0:j^[P2g]kL0Z:RX09FEU@29RHT0PH6108>3P`1mOGd0NGUi07QhN01nOWh0
S8b<08f=S@28R8P0MgMg06UYJ@1LG5`0Hf=S061PH01XJ6P0KVi^08>3P`1eMGD0L71`0861P@80TI6A
06@0Rh^;08j>SP2IVIT0WIfM09BDU02GUiL0X:2P0::RXP2XZ:P0[jn_0;Jf]P2i^KT0]KFe0;:b/P2[
Zj/0XJ6Q09bLW02CTi<0QXJ607emO@23Ph<0O7al07]kN`20P800PH6108N7Q`2IVIT0];Bd0;Fe]@2f
][H0Ogmo09JFUP35aLD0]kNg0:NWY`2`/;00d=3@0<o?c`39bLT0alO70=[JfP3UiND0g]kN0=CDe03E
eMD0fm_K0=cLg03Bd]80]kNg0:f][@2@T900SXj>08^;R`25QHD0PH6108f=S@2GUiL0/k>c0<W9b@3;
bl/0cLg=0;bl_02i^KT0[jn_0:>SX`28R8P0Hf=S04m?C`18B4P0A4A405IFEP20P800VIVI07moO`1d
M7@0JVYZ05]KF`1YJFT0U9BD0:^[Z`24Q8@0Fe]K04Y:BP15ADD0@T9203lo?`12@T80CDe=06=SH`2B
TY80WinO065QH@0m?Cd0>c/k04];B`1DE5@0?Cdm03/k>`0g=cL0?Cdm0`0k>c/203dm?@80>SXj1P0i
>CT303Xj>P0?05aLG02=SHd0XJ6Q09nOW`2@T900Rh^;08V9R@1`L700Fe]K04E5A@11@D40>SXj03De
=@0i>CT0?3`l0080>3Ph00<0>SXj03/k>`0i>CT00P0k>c/01@0i>CT0>SXj03Ph>00j>SX0>3Ph00<0
>CTi00/0=CDe03Ph>00j>SX0=cLg03lo?`1NGUh0KFe]04];B`0j>SX0>3Ph03Lg=`0203Ti>@0703Hf
=P0h>3P0>3Ph03lo?`0i>CT0>SXj03Lg=`0203Ph>080>CTi00h0>3Ph03@d=00e=CD0=CDe03Xj>P0h
>3P0>SXj03Lg=`0f=SH0>CTi04M7A`0k>c/0>3Ph03Lg=`80>3Ph00H0=cLg03Ti>@0j>SX0>SXj03Ph
>00f=SH203Ph>00403Hf=P0g=cL0=cLg03Hf=P80>CTi00H0=SHf03Lg=`0f=SH0=CDe03Hf=P0e=CD2
03Hf=P0303Ph>00e=CD0=cLg00gooooo000@ooooo`0<055AD@1>CTh0D51@04i>CP1=CDd0BDU904e=
C@1:BTX0CDe=04Q8B01:BTX0Cdm?0`1<C4`01`18B4P0AdM704U9B@19BDT0Bd];04U9B@1>CTh00P18
B4P01P1<C4`0B4Q804I6AP17AdL0BDU904M7A`<0B4Q800L0BTY:04I6AP16ATH0ADE504Q8B01:BTX0
ATI60080ADE500/0@T9204=3@`1;Bd/0ADE50451@@10@400@T920451@@12@T80A4A40410@00204A4
A00M04Q8B019BDT0Bd];04I6AP11@D40AdM704U9B@14A4@0AdM704A4A010@400@T9204=3@`12@T80
@d=30492@P14A4@0@D5104=3@`11@D40?Shn04A4A010@400?clo04=3@`15ADD0@d=30410@00n?Sh0
0P10@4002`16ATH0?clo03dm?@0n?Sh0@4100451@@10@400?Cdm0451@@0l?3`0?Shn0080ADE500D0
@4100451@@0n?Sh0@41004=3@`020410@080?clo00@0@D5103lo?`14A4@0AdM71@0o?cl01@12@T80
A4A403hn?P12@T80@D510080A4A400@0@T920410@00o?cl0@d=30P10@4001@16ATH0A4A403dm?@0m
?Cd0@4100080?Cdm0`0o?cl00`11@D40ATI604M7A`0203hn?P0?03dm?@15ADD0@41003dm?@0o?cl0
@D5104A4A00n?Sh0@D5103lo?`12@T80?clo03hn?P11@D40@T9200<0@41000X0@D510410@013@d<0
?Shn03dm?@0o?cl0?Cdm03/k>`13@d<0?clo0P0k>c/303hn?P0E03lo?`0m?Cd0?Shn03hn?P0o?cl0
@4100492@P0n?Sh0?3`l03lo?`0l?3`0?Shn03/k>`13@d<0A4A40451@@14A4@0@41004A4A00i>CT0
>c/k00<0?Cdm00H0>SXj03lo?`11@D40@D510492@P0n?Sh203lo?`0<0410@00o?cl0>c/k03Ph>00j
>SX0>c/k03`l?00j>SX0?Cdm03`l?010@400@T920P11@D40600l?3`0?Cdm03dm?@17AdL0Cdm?05]K
F`1RHV80Fe]K05MGE`1@D500EeMG06i^KP1fMWH0QhN706a/K01EEED0IFEU075aL@1oOgl0N7Qh07=c
L`1SHf<0FEUI04a<C080B4Q800@0@d=30492@P0o?cl0?Cdm0P12@T800`10@400?Shn03lo?`0204E5
A@0:04=3@`0o?cl0BDU905EEE@1XJ6P0MGEe06YZJP1QHF40G5aL059BDP80CDe=00L0ATI605IFEP1R
HV80KFe]07UiN@1lO7`0J6QX0080I6AT01P0H61P05mOG`1VIVH0S8b<0;Vi^@3@d=00cLg=0<W9b@3H
f=P0c/k>0:VYZ@25QHD0NGUi0::RXP3Bd]80h>3P0>CTi03Shn<0bLW908J6QP20P800S8b<0:FUY@2g
]kL20<71`@0<0;2`/02HV9P0Ph>307IfMP25QHD0VIVI0;2`/02o_kl0^KVi0:RXZ02JVYX0TY:B0P28
R8P0101[Jf/0GUiN05=CD`1;Bd/204A4A00S0492@P14A4@0@d=304E5A@1;Bd/0C4a<04i>CP1OGel0
PH610:RXZ03?cll0c<c<0;Bd]02IVIT0K6a/05aLG013@d<0ADE50451@@0m?Cd0A4A404I6AP0l?3`0
>c/k04U9B@1^KVh0IfMW03lo?`0n?Sh0>SXj03Ti>@0o?cl0?3`l03/k>`0i>CT00`0j>SX01@0h>3P0
?Shn03`l?00j>SX0>3Ph00@0>CTi00T0?Cdm03/k>`0k>c/0>c/k03Xj>P0m?Cd0>c/k03`l?00h>3P0
0P0j>SX203Lg=`0303Xj>P0i>CT0>3Ph0080>CTi0P0k>c/01P0j>SX0=cLg03Lg=`0g=cL0>c/k03Ti
>@80=cLg0100>3Ph03Ti>@0h>3P0>CTi051@D029RHT0PX:205aLG00k>c/0=cLg03Hf=P0i>CT0=SHf
03Ti>@0f=SH0=cLg0P0f=SH00`0e=CD0=cLg03Hf=P0303Ph>00A03Lg=`0f=SH0=SHf03Ti>@0e=CD0
>3Ph03Ti>@0j>SX0=cLg03Ti>@0e=CD0=SHf03@d=00f=SH0=3@d03Hf=P0g=cL00`0f=SH01`0e=CD0
=SHf03Hf=P0f=SH0=CDe03@d=00e=CD00P0f=SH203Lg=`0303@d=00e=CD0=3@d0080=CDe0P0c<c<0
100h>3P0=cLg03@d=00f=SH=ooooo`004?ooool404i>CP80CDe=01H0Bd];04e=C@1<C4`0C4a<04m?
C`1:BTX0BDU904Q8B01:BTX0Bd];04Q8B019BDT0ATI604M7A`15ADD0AdM704Y:BP18B4P0AdM704Q8
B016ATH0B4Q80P19BDT01P1:BTX0ATI604Q8B018B4P0BTY:04Q8B080AdM70100ATI60492@P13@d<0
AdM704U9B@18B4P0AdM704I6AP15ADD0A4A404E5A@14A4@0AdM70451@@10@400@d=30P18B4P01`1F
EUH0AdM704Q8B016ATH0A4A40492@P10@4000`12@T803P17AdL0A4A40410@013@d<0@T920451@@10
@400?clo0492@P13@d<0B4Q804=3@`10@400@D510P15ADD01@12@T80@41003lo?`0l?3`0?clo00<0
?Cdm00<0?clo03hn?P0n?Sh00P10@40203lo?`0304=3@`0o?cl0@D510080@4100P0n?Sh00`0m?Cd0
?clo03lo?`0203hn?P080492@P11@D40@d=304A4A011@D40@4100451@@10@4020451@@0`0492@P13
@d<0?Shn0451@@14A4@0@d=303hn?P11@D40@T9204E5A@12@T80ATI604E5A@17AdL0@41003lo?`0m
?Cd0?3`l03lo?`10@400@T9204E5A@17AdL0BDU903hn?P16ATH0@T9203hn?P11@D40?Shn03lo?`0n
?Sh0?3`l0410@013@d<0AdM70410@00o?cl0@T9204=3@`15ADD0?Cdm0410@011@D40?Shn04E5A@1;
Bd/0@T920P10@4005P11@D40?3`l03`l?00l?3`0@41003hn?P0o?cl0@d=303`l?00m?Cd0@4100492
@P0m?Cd0?Shn04A4A012@T80?Cdm03/k>`0o?cl0@D5103hn?P0k>c/203lo?`0<0410@015ADD0@410
03lo?`0n?Sh0?clo0451@@10@400?3`l04=3@`12@T80@D510P0o?cl03010@400?3`l0410@00n?Sh0
?clo03hn?P0i>CT0?3`l03dm?@10@400>CTi0410@080>c/k00L0?3`l03hn?P14A4@0@41004=3@`14
A4@0?Cdm0080A4A401`0@T92059BDP1]KFd0Ogmo07emO@1`L700FUYJ05QHF01ADE40Cdm?04i>CP1;
Bd/0AdM70410@012@T80@D510492@P13@d<0@41003lo?`13@d<0?clo03Xj>P10@400?3`l0451@@0o
?cl0?Cdm0P11@D40<P0o?cl0@4100492@P14A4@0BTY:05=CD`1KFe/0HV9R06MWI`1bLW80S8b<09nO
W`2EUID0R8R807inOP22PX80RXZ:08N7Q`1kNg/0E5AD059BDP1OGel0Jf][071`L01dM7@0Ogmo08N7
Q`2>SXh0V9RH08j>SP27QhL0QXJ609NGU`2QXJ40Xj>S0:6QX@29RHT0Ph>308:2PP24Q8@0Ph>307em
O@1fMWH0LW9b071`L01eMGD0TI6A0;2`/03<c<`0fMWI0P3GemL07P3EeMD0f=SH0=OGe`3Fe]H0f=SH
0=_Kf`3Shn<0gmoO0>;RhP3Shn<0gmoO0=cLg03<c<`0/k>c0:BTY02@T900MgMg075aL@1jNWX0Ogmo
08>3P`1dM7@0HV9R05EEE@1@D500GEeM071`L02@T900]KFe0<?3``80cLg=01l0YJFU09ZJVP2?Shl0
O7al06e]K@1ADE40?Cdm03hn?P0o?cl0ATI607AdM01oOgl0CDe=03Xj>P0g=cL0?Shn03/k>`0m?Cd0
?Shn03/k>`0i>CT0>SXj03`l?00m?Cd0?Shn03Xj>P0k>c/0>SXj03Ti>@0j>SX0?Cdm0080>3Ph00T0
=cLg03`l?00i>CT0=cLg03Xj>P0i>CT0>3Ph03Xj>P0m?Cd00P0k>c/02P0h>3P0>SXj03Ti>@0j>SX0
=cLg03Hf=P0j>SX0?3`l03Ph>00j>SX203Ti>@0@03/k>`0j>SX0>3Ph03Xj>P0k>c/0?Shn04E5A@1P
H600DU9B0451@@0i>CT0>c/k03Lg=`0e=CD0>SXj03Lg=`80>3Ph00@0=cLg03Ph>00g=cL0>CTi0P0j
>SX203Ph>00=03Lg=`0f=SH0>SXj03Lg=`0i>CT0>3Ph03Xj>P0g=cL0>SXj03Ph>00i>CT0=SHf03@d
=00203Hf=P0803De=@0g=cL0>3Ph03Lg=`0h>3P0=cLg03Ti>@0g=cL203De=@0403<c<`0d=3@0=3@d
03Hf=P80=cLg00P0=CDe03@d=00f=SH0=SHf03De=@0f=SH0=CDe03Hf=P@0=cLg3Oooool0013ooooo
00<0CDe=051@D01ADE400P1?Cdl0101@D500BTY:04i>CP1=CDd204Y:BP0R04a<C01:BTX0C4a<04];
B`1?Cdl0Bd];04e=C@1>CTh0B4Q804a<C019BDT0ATI604M7A`13@d<0ATI604Q8B019BDT0AdM704E5
A@14A4@0AdM704];B`17AdL0A4A404Q8B019BDT0B4Q804I6AP18B4P0CTi>04e=C@16ATH0ADE504Q8
B080ADE50200ATI604Q8B018B4P0BTY:04E5A@11@D40@4100492@P10@400A4A403lo?`16ATH0ADE5
03lo?`11@D40@41004=3@`15ADD0@d=304E5A@1FEUH0CDe=04=3@`14A4@0?clo0451@@0n?Sh0@T92
04E5A@12@T80@D5103lo?`80@41000H0A4A404=3@`11@D40?Shn03dm?@0l?3`203lo?`0;03hn?P10
@400@d=30410@011@D40@41004=3@`0n?Sh0ADE503hn?P12@T800P0m?Cd203lo?`0403`l?00n?Sh0
@41004A4A080?clo01H0A4A404=3@`13@d<0A4A403lo?`11@D40@T9203hn?P0m?Cd0?3`l03/k>`0o
?cl0@41004Y:BP16ATH0@D5103lo?`10@400CTi>04A4A012@T80@D51100m?Cd02@0o?cl0@41003lo
?`15ADD0@d=304M7A`19BDT0?clo0410@00203hn?P0803lo?`0j>SX0?Cdm04A4A00l?3`0@T9204E5
A@1EEED203lo?`80@d=300X0?clo0451@@10@400@D5103lo?`16ATH0ADE503lo?`12@T80?clo0P0n
?Sh02P0l?3`0?clo0451@@10@400@D5104=3@`18B4P0C4a<0410@00l?3`203lo?`040451@@13@d<0
@d=303hn?P80@41000P0?Cdm03hn?P0l?3`0@T9203dm?@0l?3`0?clo03Xj>P80@41000H0@T9203lo
?`10@400A4A403lo?`0j>SX303hn?P060492@P0n?Sh0?3`l03lo?`10@400?Cdm0P11@D400`0l?3`0
?Cdm03`l?00203Xj>P0O03Ph>00j>SX0@41003dm?@0l?3`0@D5103lo?`16ATH0@d=30410@012@T80
@D5104E5A@0o?cl0?Shn03`l?00k>c/0?3`l03dm?@0o?cl0?Shn03lo?`0k>c/0?Shn04=3@`0o?cl0
?3`l03lo?`0k>c/0?3`l0492@P0203/k>`0503hn?P0m?Cd0?Shn03`l?00o?cl00P0n?Sh05`0o?cl0
?Shn0410@01>CTh0GUiN07UiN@2MWId0YZJV09RHV02EUID0R8R805iNGP1CDe<0C4a<051@D01FEUH0
HF5Q06ATI01hN7P0R8R80861P@1hN7P0MWIf0080NGUi0100I6AT06e]K@1NGUh0F5QH05iNGP1QHF40
DE5A059BDP1KFe/0Lg=c08B4Q021PH40LG5a071`L01HF5P0Cdm?0P11@D40AP17AdL0BDU905ADE01V
IVH0PX:209>CT`2][Jd0Z:RX09ZJVP2NWYh0X:2P0:JVYP2a/K40_Kfm0<?3``3=cLd0bl_;0<c<c03?
cll0cLg=0=SHf03Ng]h0gmoO0=_Kf`3GemL0eMGE0=WIf@3Hf=P0g]kN0=cLg03MgMd0d=3@0:b/[01g
MgL0QhN70::RXP25QHD0O7al0:NWY`34a<@0cLg=0=SHf03Kfm/0eMGE0<?3``27QhL0E5AD04a<C010
@400?clo03Xj>P1^KVh0TY:B06a/K01>CTh0?clo03/k>`0m?Cd0?Shn03`l?00m?Cd0?3`l03Xj>P0h
>3P0?Cdm03/k>`0o?cl0?Cdm03hn?P0k>c/203`l?00903Ti>@0j>SX0>SXj03Ti>@0o?cl0=SHf03dm
?@0g=cL0?3`l00<0>CTi00/0=cLg03Ti>@0h>3P0>CTi03`l?00j>SX0>CTi03Xj>P0i>CT0>c/k03Xj
>P0203Ph>00;03hn?P1GEeL0I6AT06e]K@1JFUX0?Shn03Ti>@0k>c/0?3`l03Ti>@0h>3P00P0i>CT0
1@0k>c/0>SXj03Hf=P0h>3P0=CDe0080>3Ph00<0>CTi03Ph>00h>3P00P0j>SX203Ph>00<03Lg=`0h
>3P0>CTi03Ph>00i>CT0=cLg03Ph>00g=cL0>3Ph03De=@0f=SH0=CDe0P0g=cL01P0e=CD0=cLg03Ph
>00e=CD0=cLg03Ph>080=SHf00D0=CDe03<c<`0f=SH0=SHf03Lg=`0203Ph>080=CDe00P0=cLg03Ti
>@0f=SH0=cLg03De=@0g=cL0=SHf03Ph>080>CTi3Oooool0013ooooo01T0CTi>04a<C01>CTh0CDe=
04];B`19BDT0BTY:04m?C`1<C4`0CDe=04Q8B01:BTX0Bd];04e=C@19BDT0Bd];04U9B@1:BTX0C4a<
04M7A`18B4P0BDU904M7A`1@D500@d=300<0BDU900d0Bd];04Y:BP17AdL0BTY:04e=C@1:BTX0AdM7
04a<C01;Bd/0CTi>04];B`18B4P0BDU90080ATI600<0BTY:04Q8B016ATH00P13@d<04@16ATH0Bd];
04];B`18B4P0@D5104E5A@14A4@0@d=304U9B@14A4@0@T9204A4A012@T80@D5104=3@`12@T80?clo
0080@41000<0@T920451@@15ADD00P13@d<06`14A4@0@d=304M7A`15ADD0@d=304A4A010@400AdM7
0492@P11@D40@T9204e=C@12@T80?3`l03/k>`0m?Cd0@D510492@P0o?cl0?Cdm03Ph>010@400@D51
0410@00n?Sh0@d=303lo?`0203dm?@0503lo?`0m?Cd0?Cdm0451@@13@d<00P0n?Sh05011@D40?Shn
0492@P0o?cl0@T9204U9B@13@d<0@D5104=3@`11@D40ADE50492@P0l?3`0?clo04=3@`0n?Sh0>c/k
03hn?P0m?Cd0?Shn0P13@d<01@0o?cl0B4Q803lo?`13@d<0@4100080?Cdm00T0@D510492@P0l?3`0
>CTi03hn?P19BDT0>c/k03lo?`11@D400P12@T801`0n?Sh0>c/k0410@012@T80@4100492@P14A4@0
0P10@400200m?Cd0@T9203/k>`0l?3`0?Shn0451@@0o?cl0?Cdm0P13@d<03P17AdL0@D5103dm?@0k
>c/0?3`l03lo?`11@D40ATI60492@P0o?cl0@41004Q8B010@400?3`l0P0n?Sh02`15ADD0?Cdm03dm
?@0n?Sh0@D510410@00n?Sh0@41003dm?@0o?cl0>SXj0080?3`l0P0m?Cd03P0l?3`0?clo03dm?@0o
?cl0@D5103lo?`0h>3P0>CTi03`l?00n?Sh0>c/k03dm?@0l?3`0?clo0P0m?Cd0100o?cl0?Cdm03/k
>`0h>3P203dm?@0903/k>`0i>CT0?3`l0492@P14A4@0@D5104Q8B00l?3`0@T920080?clo00D0@D51
03dm?@0l?3`0?clo03hn?P0203dm?@0303`l?00o?cl0@d=30080@41002D0?Cdm03lo?`0o?cl0?Cdm
03lo?`0k>c/0?clo03`l?00n?Sh0?clo03/k>`0n?Sh0@D5104A4A018B4P0De=C065QH@1ZJVX0NGUi
08j>SP2KVi/0ZJVY0;6a/@2ZZZX0ZJVY09^KV`2ATI40UIFE09BDU02>SXh0Ogmo07IfMP1^KVh0LW9b
06IVIP1QHF40GEeM0080EEEE02X0E5AD05EEE@1OGel0J6QX06IVIP1/K6`0Lg=c079bLP1hN7P0MgMg
075aL@2>SXh0Zj^[0:ZZZP2PX:00Shn?05aLG01BDU80IfMW07alO01cLg<0FUYJ04a<C014A4@0@D51
03lo?`16ATH0De=C07=cL`28R8P0/K6a0;Rh^02`/;00WinO09VIV@29RHT0QXJ608N7Q`2:RXX0UIFE
09jNWP2MWId20:6QX@0T0:BTY02KVi/0Y:BT0;bl_036a/H0d=3@0=SHf03IfMT0d];B0=CDe03IfMT0
eMGE0<71`@3?cll0eMGE0<[:bP2a/K40VYZJ08n?S`2a/K40bLW90<_;b`3Jf]X0cLg=0;6a/@2TY:@0
S8b<065QH@1@D500@D5105]KF`24Q8@0RHV907YjNP1GEeL0@4100P0n?Sh03`0i>CT0?Shn03`l?00i
>CT0>c/k03`l?00n?Sh0@D5103hn?P14A4@0?Cdm03lo?`0h>3P0>SXj03dm?@020410@0050451@@0l
?3`0?Cdm03`l?00n?Sh00P0k>c/01`0j>SX0?3`l03Xj>P0k>c/0?Shn03dm?@0g=cL00P0f=SH02P0g
=cL0>SXj0492@P1TI6@0ZJVY0=?Cd`3>c/h0alO709>CT`1=CDd203Xj>P0303`l?00j>SX0=SHf00D0
=SHf00<0>c/k03dm?@0n?Sh00P0i>CT0100h>3P0>CTi03Xj>P0k>c/303Ph>080=cLg00<0=SHf03De
=@0d=3@00`0d=3@02@0c<c<0>3Ph03Ti>@0h>3P0=SHf03Lg=`0i>CT0>c/k03Ti>@0203Lg=`0403De
=@0i>CT0=SHf03Lg=`80=CDe0`0g=cL0300e=CD0=cLg03Ph>00h>3P0=3@d0410@018B4P0=cLg03De
=@0d=3@0=CDe03Ph>0gooooo000@ooooo`0:04];B`1>CTh0CTi>04U9B@17AdL0ATI604U9B@1=CDd0
BDU904];B`80AdM70P1<C4`304Y:BP0704Q8B016ATH0@41004=3@`1<C4`0ATI604M7A`0204A4A009
04=3@`14A4@0A4A404E5A@14A4@0ADE504M7A`1<C4`0CDe=0080BDU900L0Cdm?04Q8B00o?cl0?3`l
04A4A013@d<0B4Q800@0AdM700H0ATI604A4A013@d<0@D5103dm?@13@d<204A4A00304Q8B01:BTX0
@d=30080@41000D0@D5103dm?@10@400@T9203/k>`0203lo?`0:0410@00l?3`0?clo04A4A018B4P0
CDe=04];B`17AdL0?Shn04=3@`80?clo01l0@d=304A4A00l?3`0@T9203/k>`0l?3`0?clo03Xj>P10
@400?Shn0410@011@D40>c/k03Xj>P0m?Cd0?3`l03lo?`14A4@0@D5103dm?@0n?Sh0?clo03Ph>012
@T80?Cdm03hn?P0j>SX0?Cdm04=3@`0l?3`0@D510080?Shn00`0@T920410@010@400@D5103lo?`15
ADD0A4A40451@@0m?Cd0>c/k03dm?@0l?3`203Ti>@0603/k>`12@T80?clo03lo?`18B4P0@d=30P10
@4000`14A4@0@d=303lo?`0204=3@`0303dm?@0o?cl0DU9B0080?clo00`0?Shn03Xj>P11@D40>c/k
03lo?`17AdL0@41003lo?`0j>SX0?clo04=3@`0l?3`203hn?P0D0410@00k>c/0?Cdm03`l?00k>c/0
=cLg04E5A@0l?3`0@D5103lo?`10@400?Shn0451@@0l?3`0>3Ph03dm?@0n?Sh0?Cdm03Ti>@0m?Cd2
0410@00503`l?00j>SX0>c/k03Hf=P0l?3`00P0n?Sh203Ti>@<0?Shn00l0>SXj03hn?P0m?Cd0>SXj
03lo?`0n?Sh0@d=303Xj>P0l?3`0?Shn03`l?00m?Cd0>c/k03`l?00k>c/00`0j>SX01`0i>CT0?clo
03/k>`0j>SX0>c/k0451@@0k>c/00P0j>SX02`0o?cl0@4100492@P0o?cl0>SXj03dm?@16ATH0?Shn
04A4A00m?Cd0>CTi0080?clo00L0?Shn0451@@0o?cl0>SXj03/k>`0i>CT0>SXj0080?Shn00P0@D51
03hn?P11@D40?clo03Ti>@0k>c/0>SXj03/k>`80?3`l0200>CTi04U9B@1:BTX0HV9R07]kN`2DU9@0
V9RH0:ZZZP2d];@0^KVi0;>c/`2OWil0Shn?07inOP1RHV80DE5A04E5A@12@T80ATI604M7A`12@T80
ATI603dm?@0i>CT0@d=303Lg=`0l?3`0>3Ph03/k>`0j>SX0@41004I6AP80@41000d0?clo04=3@`0j
>SX0?Cdm04A4A01CDe<0J6QX0:2PX03GemL0c/k>0:2PX02EUID0J6QX0080ADE505d0EeMG06i^KP20
P800QHF5065QH@1YJFT0PX:207EeM@1MGEd0Fe]K05=CD`23Ph<0[jn_0=7Ad@3Cdm<0c/k>0;6a/@2>
SXh0PH6108R8R02TY:@0alO70=SHf03MgMd0h>3P0=oOg`3IfMT0d=3@0<g=c@39bLT0`L710;fm_@37
alL0fm_K0=GEe@3?cll0e]KF0<S8b03Kfm/0hN7Q0>CTi03EeMD0/;2`07AdM01KFe/0N7Qh08J6QP2]
[Jd0a/K60<W9b@38b<P0a<C40:f][@2FUYH0H61P04I6AP1:BTX0@d=3051@D01>CTh0AdM704E5A@0m
?Cd0>CTi03`l?00n?Sh0?clo03`l?00o?cl0@T9203lo?`11@D40@d=30410@015ADD0Cdm?05IFEP1Y
JFT0M7Ad05iNGP1DE5@0GemO079bLP1YJFT0J6QX04e=C@0o?cl0<S8b03Xj>P0i>CT0>SXj03/k>`0l
?3`00`0j>SX04@0i>CT0?Cdm04];B`21PH40^;Rh0;6a/@2MWId0JVYZ05IFEP0k>c/0=cLg03Xj>P0g
=cL0>3Ph03`l?00j>SX0=SHf00<0=3@d0P0g=cL0100e=CD0>CTi03/k>`0j>SX203Ti>@0D03/k>`0f
=SH0>CTi03Lg=`0e=CD0=SHf03De=@0d=3@0=SHf03De=@0d=3@0=CDe03Hf=P0h>3P0=cLg03Hf=P0e
=CD0>3Ph03Xj>P0f=SH203@d=00503De=@0c<c<0>3Ph03Lg=`0m?Cd0100e=CD0100f=SH0=CDe03De
=@0g=cL303De=@0604];B`0e=CD0=CDe03<c<`0d=3@0=cLg3Oooool0013ooooo00/0DE5A05=CD`1A
DE40D51@04e=C@1>CTh0CDe=04a<C017AdL0BDU904Q8B00204U9B@0>04Q8B01:BTX0BDU904Y:BP18
B4P0BDU904I6AP19BDT0AdM704Q8B012@T80@d=304I6AP19BDT204Q8B080BDU90P16ATH04019BDT0
BTY:04U9B@18B4P0Bd];04Y:BP14A4@0@d=304M7A`19BDT0BTY:04A4A015ADD0BDU904Q8B012@T83
04E5A@0:04I6AP11@D40ADE504E5A@13@d<0@T9204I6AP11@D40A4A404=3@`80@41000L0?Shn04I6
AP13@d<0?clo04I6AP12@T80?3`l0080?clo00L0@d=304Q8B015ADD0@D510410@00m?Cd0@T920080
@D5100/0@d=303lo?`0o?cl0?Cdm03hn?P0m?Cd0@D5103lo?`11@D40A4A40410@00203hn?P0<0410
@00n?Sh0@D510410@00o?cl0@41003hn?P12@T80@d=303dm?@0k>c/0?clo0P0n?Sh01P12@T80?clo
03lo?`0o?cl0?Shn0492@P80@d=300H0?clo0492@P11@D40?clo03dm?@0i>CT303`l?080?Shn00X0
@T9204=3@`0o?cl0ATI604M7A`11@D40?Cdm0451@@10@400?clo0P0n?Sh01@0k>c/0ATI604I6AP0n
?Sh0?clo0080@d=30P12@T80201:BTX0?clo0410@010@400@d=304A4A018B4P0BTY:0P13@d<04@11
@D40?Cdm0451@@0n?Sh0A4A40451@@1>CTh0ADE50410@00o?cl0?Shn03/k>`0n?Sh0@D5104A4A00n
?Sh0@d=30080?clo0P0l?3`203lo?`0;03hn?P0m?Cd0?Cdm03lo?`11@D40A4A403hn?P0k>c/0?3`l
0410@012@T800P0l?3`0200j>SX0?clo04=3@`12@T80@41003`l?00n?Sh0B4Q80P0o?cl00`10@400
@D5103dm?@0203Xj>P0P03`l?00o?cl0?Shn0492@P11@D40?Shn0492@P11@D40?Cdm0410@012@T80
@41003lo?`0l?3`0>SXj04=3@`11@D40?Shn04E5A@16ATH0?Shn03`l?00k>c/0@4100451@@0n?Sh0
?Cdm03lo?`0n?Sh0?clo04A4A013@d<203dm?@80@D5102D0?Shn0492@P16ATH0EUIF05ADE01MGEd0
KVi^07inOP1lO7`0Q8B408F5Q@1mOGd0OWin08V9R@2ATI40MgMg069RHP1FEUH0D51@04I6AP0n?Sh0
@T920451@@0n?Sh0?Cdm04M7A`15ADD0@d=303hn?P0o?cl0@41003hn?P15ADD0?Shn0451@@10@400
?clo00<0@d=301d0B4Q805]KF`1[Jf/0JVYZ05iNGP1WIfL0LG5a096AT@2^[Zh0Shn?05iNGP1FEUH0
Fe]K05YJFP1GEeL0Fe]K06a/K021PH40Ph>307]kN`1bLW80RXZ:08b<S02>SXh0U9BD09:BTP2GUiL0
YJFU0;jn_P030=?Cd`0l0<71`@2e]KD0[Jf]0;Bd]03=cLd0f][J0=cLg03Kfm/0eMGE0=SHf03IfMT0
g=cL0<[:bP2^[Zh0VYZJ08n?S`2b/[80cLg=0=7Ad@3Bd]80[:b/09jNWP2d];@0e=CD0>7Qh@3Ph>00
bLW909FEU@2JVYX0[Jf]09NGU`2UYJD0a<C40=3@d035aLD0][Jf0;Ng]`2OWil0HV9R04A4A01IFET0
HF5Q05iNGP1FEUH0IfMW07MgM`1kNg/0H61P04M7A`1=CDd0MWIf08J6QP2DU9@0[Zj^0:NWY`2YZJT0
/K6a0;jn_P2i^KT0_kno0P32`/802`2k^k/0]KFe0;>c/`2SXj<0R8R808N7Q`1mOGd0K6a/059BDP10
@400>3Ph0080?3`l00/0>c/k03Xj>P0l?3`0>c/k03Ph>00i>CT0?3`l04E5A@1:BTX0@T9204E5A@02
03`l?080>SXj00H0>c/k03Ti>@0h>3P0>CTi03Xj>P0h>3P203De=@0<03/k>`0i>CT0>CTi03Ti>@0h
>3P0>SXj03Ph>00i>CT0>3Ph03Ti>@0g=cL0>3Ph0`0f=SH00`0e=CD0=3@d03De=@0203@d=00903De
=@0h>3P0=SHf03Hf=P0d=3@0=CDe03Lg=`0h>3P0=CDe0080=cLg00L0=3@d03<c<`0h>3P0=SHf03Xj
>P0d=3@0=SHf0080<c<c00<0=CDe03Hf=P0c<c<00P0d=3@01@0g=cL0<c<c03Xj>P0h>3P0=SHf0080
=cLg00<0=SHfooooooooool02oooool0013ooooo0100CDe=055AD@1?Cdl0Cdm?04a<C01?Cdl0C4a<
04m?C`1;Bd/0BDU904Q8B019BDT0Bd];04Q8B01<C4`0B4Q80`1:BTX01@15ADD0BDU904Y:BP19BDT0
BTY:0080AdM700P0BTY:04M7A`18B4P0Bd];04a<C014A4@0ADE504Q8B080Bd];01X0B4Q804U9B@1@
D500BDU904I6AP13@d<0B4Q804Y:BP18B4P0AdM704Q8B017AdL0A4A404E5A@16ATH0ADE504Y:BP14
A4@0@T9204E5A@1:BTX0B4Q804Y:BP15ADD0@d=30410@080@D5100D0@d=304];B`19BDT0A4A40451
@@020410@00J04M7A`12@T80A4A404A4A012@T80@4100492@P0n?Sh0?clo0410@013@d<0?clo0451
@@12@T80@41003`l?00o?cl0@D5104=3@`0n?Sh0@41003hn?P10@400?3`l03hn?P15ADD20451@@0<
03lo?`0l?3`0?Shn0451@@0o?cl0?3`l03/k>`0l?3`0>c/k03Xj>P0l?3`0?Shn0P10@4001@0n?Sh0
@41003hn?P13@d<0@D5100<0@41000<0?Cdm03hn?P0m?Cd00P13@d<02P0n?Sh0?Cdm04E5A@11@D40
@41003`l?012@T80@D5103`l?00m?Cd303hn?P0504E5A@0o?cl0ADE50451@@0j>SX00P10@4002@0m
?Cd0?clo03dm?@0m?Cd0?Shn0451@@15ADD0B4Q804=3@`020492@P0=04Q8B013@d<0?Cdm03lo?`11
@D40?Cdm03hn?P0o?cl0A4A404=3@`0m?Cd0?clo03`l?00403lo?`060492@P11@D40?Cdm0492@P0n
?Sh0>SXj0`11@D402@0n?Sh0>c/k0410@010@400@D5104I6AP0o?cl0>CTi03/k>`020410@080@T92
00h0?clo03dm?@0o?cl0>CTi03`l?00o?cl0@T9203hn?P11@D40?clo0492@P0o?cl0@41004A4A0<0
@D5100<0A4A40492@P13@d<00P13@d<01@16ATH0ADE503`l?00k>c/0?3`l0080?clo00H0?Cdm03hn
?P0m?Cd0>c/k03dm?@0n?Sh303dm?@80?Shn01/0?Cdm03/k>`0k>c/0?clo0410@00n?Sh0>c/k0410
@00o?cl0Cdm?06=SH`28R8P0SXj>08V9R@1kNg/0IFEU05aLG01IFET0Bd];04Q8B01:BTX0FUYJ071`
L01cLg<0L71`06IVIP1NGUh00P1BDU80101>CTh0@D5103hn?P0o?cl20451@@0U0492@P0o?cl0?Cdm
03dm?@0l?3`0@T9203/k>`0o?cl0?Shn0492@P11@D40?Shn0410@012@T80EUIF07]kN`2m_Kd0fMWI
0<C4a02`/;00ZZZZ0:FUY@2MWId0XJ6Q0:f][@2/[:`0[Zj^0:6QX@2@T900Jf][051@D01QHF40MgMg
07inOP1^KVh0IFEU065QH@0205MGE`0T05eMG@1^KVh0M7Ad06MWI`1RHV80IVIV06a/K01gMgL0U9BD
0;2`/02_[jl0W9bL08j>SP2UYJD0`L710;no_`2OWil0TY:B09JFUP2^[Zh0ZJVY096AT@2>SXh0N7Qh
07AdM026QXH0TY:B09RHV02@T900MWIf07=cL`20P800[Jf]0<?3``34a<@0a/K60P2j^[X01P2ATI40
UiNG0:>SX`2UYJD0/K6a0:b/[080[jn_02@0XZ:R0;6a/@3<c<`0e]KF0<C4a036a/H0f=SH0>[ZjP3W
inL0eMGE0<W9b@3<c<`0eMGE0=SHf036a/H0alO70=KFeP3Ti>@0g=cL0;Vi^@26QXH0Jf][05MGE`1?
Cdl0B4Q804I6AP14A4@0@41003hn?P0k>c/0?Shn03/k>`0n?Sh0?clo03/k>`0j>SX203`l?00303Xj
>P0k>c/0?Cdm00<0>SXj00P0=SHf03Lg=`0h>3P0?clo03`l?00j>SX0>CTi03`l?0<0>3Ph100i>CT0
100h>3P0=cLg03Lg=`0i>CT203Hf=P0803De=@0c<c<0=SHf03Lg=`0f=SH0>CTi03Lg=`0d=3@203Ph
>080=CDe00<0=SHf03Lg=`0g=cL00P0f=SH02P0b<S80=SHf03Lg=`0i>CT0=cLg03Hf=P0g=cL0>3Ph
03Hf=P0e=CD203Lg=`80=CDe00L0=SHf03Xj>P0i>CT0=cLg03De=@0i>CT0>SXj0080=SHf0P0d=3@0
1P0h>3P0=SHf03Ph>00f=SH0=CDe03Lg=`gooooo000@ooooo`0604i>CP1@D500Cdm?04e=C@1<C4`0
CDe=0P1<C4`07019BDT0Bd];04a<C01<C4`0B4Q804Y:BP1<C4`0B4Q804M7A`1;Bd/0B4Q804E5A@18
B4P0BTY:04e=C@17AdL0ATI604E5A@19BDT0ATI604Q8B019BDT0AdM704I6AP1;Bd/0BTY:04a<C01:
BTX204U9B@80A4A40180B4Q804U9B@19BDT0GEeM05QHF015ADD0AdM70492@P14A4@0?Shn0410@015
ADD0@D5104E5A@14A4@0AdM7059BDP16ATH204Q8B00904M7A`15ADD0A4A404I6AP15ADD0B4Q804A4
A012@T80?Cdm0080?Shn0100?clo0451@@13@d<0A4A404I6AP0o?cl0AdM703lo?`11@D40?Cdm0492
@P0m?Cd0?clo0492@P0m?Cd0?clo0P10@4004`0l?3`0@D5103hn?P0n?Sh0?Cdm03hn?P10@400@d=3
03hn?P0m?Cd0?3`l03/k>`0l?3`0>c/k03hn?P0k>c/0@41003lo?`0l?3`00P0m?Cd04`0j>SX0?Shn
04=3@`0m?Cd0?clo0451@@0o?cl0?Shn03/k>`12@T80@D5104E5A@0l?3`0?Shn0410@00o?cl0@D51
0410@00l?3`00P0k>c/00`17AdL0?clo0451@@020410@00;03hn?P11@D40?Cdm03dm?@0o?cl0@d=3
03lo?`0n?Sh0?clo03hn?P10@4000`0n?Sh02@0o?cl0?3`l0410@010@400?clo03hn?P12@T80BTY:
03lo?`0403hn?P0303`l?00o?cl0ATI60080@D510140>c/k03hn?P13@d<0@D510410@012@T80A4A4
03hn?P12@T80?Shn03`l?00i>CT0@D5104=3@`0m?Cd0>c/k0492@P0203hn?P0803`l?010@400?Shn
03hn?P10@400?clo03hn?P0o?cl303dm?@0803lo?`10@400>c/k0410@00o?cl0?3`l03Xj>P0k>c/2
03lo?`0503dm?@14A4@0@T9204=3@`0n?Sh00P10@4005011@D40@41004A4A010@400ATI60410@00n
?Sh0@T9204=3@`0j>SX0?3`l0492@P18B4P0>CTi03lo?`0j>SX0?clo03/k>`0n?Sh0ADE50P0m?Cd0
200i>CT0?Shn03lo?`10@400?Shn03dm?@10@400AdM70P1eMGD02P1OGel0F5QH04a<C016ATH0ADE5
0410@00m?Cd0AdM705ADE01XJ6P207AdM00M071`L01YJFT0EeMG04m?C`19BDT0@D510410@00o?cl0
>SXj03`l?013@d<0ADE50492@P0j>SX0?3`l03hn?P0m?Cd0@D510410@012@T80ADE505ADE01XJ6P0
PX:209:BTP2WYjL0[Zj^0:2PX02@T9000P2ATI40202KVi/0[:b/0;Rh^02k^k/0YZJV09bLW02ATI40
Ng]k0P1]KFd02@1MGEd0E5AD05eMG@1MGEd0FUYJ05mOG`1SHf<0IFEU065QH@0206e]K@0J07=cL`1m
OGd0GemO055AD@1:BTX0De=C05aLG01`L700P82007]kN`1`L700DE5A069RHP2FUYH0][Jf0;Bd]02U
YJD0VIVI09:BTP2>SXh0UYJF0::RXP2TY:@0XJ6Q0:ZZZP2/[:`20:ZZZP0[0:>SX`2a/K40]KFe09bL
W027QhL0LG5a07moO`1ZJVX0Hf=S04e=C@14A4@0Cdm?065QH@1eMGD0MWIf06e]K@1fMWH0RHV90::R
XP2k^k/0f][J0=GEe@3GemL0inOW0=KFeP2j^[X0`l?30=GEe@3Cdm<0_[jn0;^k^`2b/[80_[jn0=KF
eP3EeMD0a<C40;>c/`2/[:`0YjNW08n?S`1fMWH0H61P04M7A`0203hn?P80?3`l0180?Cdm03`l?00i
>CT0>3Ph03Ti>@0h>3P0>CTi03`l?00k>c/0>3Ph03Lg=`0h>3P0>c/k03Xj>P0h>3P0>CTi03Xj>P0i
>CT203Ph>00803/k>`0i>CT0?Cdm03hn?P0i>CT0>SXj03Ti>@0h>3P203Xj>P0H03/k>`1CDe<0HF5Q
04A4A00f=SH0=CDe03@d=00i>CT0>3Ph03Ti>@0g=cL0>CTi03Xj>P0g=cL0>3Ph03De=@0d=3@0=SHf
03Ph>00i>CT0=SHf03Ph>00d=3@0=CDe0`0f=SH00`0e=CD0=3@d03De=@0303Hf=P80=CDe0P0f=SH0
200i>CT0=cLg03Ph>00h>3P0>SXj03Ti>@0e=CD0>3Ph0P0g=cL01P0k>c/0=SHf03@d=00h>3P0>CTi
03Xj>Pgooooo000@ooooo`80Cdm?00<0CDe=04Q8B01;Bd/00P1;Bd/204U9B@80Bd];0P19BDT204M7
A`0N04Q8B017AdL0B4Q804M7A`15ADD0B4Q804A4A016ATH0AdM704U9B@1;Bd/0ADE504I6AP18B4P0
BTY:04Q8B017AdL0Bd];04Y:BP18B4P0ATI604Y:BP17AdL0A4A404E5A@14A4@0CTi>04Y:BP17AdL0
ATI60P17AdL20492@P0804=3@`16ATH0BDU904=3@`1:BTX0@D5104Q8B017AdL204];B`0P03lo?`11
@D40@T920451@@15ADD0B4Q8055AD@17AdL0ADE503dm?@0o?cl0@T9204E5A@10@400?3`l04M7A`0o
?cl0@T920451@@13@d<0@41003lo?`12@T80?Cdm03lo?`14A4@0?clo03hn?P0o?cl0@41003hn?P10
@40203`l?00>0451@@12@T80?clo03hn?P0m?Cd0@41003dm?@0n?Sh0?Cdm04=3@`16ATH0@D5103hn
?P12@T8204I6AP0=03hn?P0m?Cd0?3`l0410@00m?Cd0?clo03dm?@0n?Sh0>c/k04=3@`17AdL0?Shn
0410@00203lo?`0503`l?00k>c/0@T920410@00m?Cd00P0o?cl03@0m?Cd0@d=303/k>`14A4@0?clo
0451@@0n?Sh0?Cdm03/k>`11@D40?Cdm0492@P10@4000P0n?Sh03011@D40@4100410@00m?Cd0@T92
0410@012@T80?Shn03dm?@10@400?Cdm04=3@`80@D5101<0?Shn03`l?01ADE40@d=30451@@10@400
A4A40451@@10@400@d=304E5A@13@d<0ATI604A4A013@d<0A4A404M7A`13@d<0?Shn0080@D5100H0
?3`l03Xj>P12@T80ADE50451@@10@4020492@P0303hn?P0m?Cd0@d=30080@41000<0?Cdm0410@011
@D400P0n?Sh02`0k>c/0@T920451@@0m?Cd0?3`l03hn?P0m?Cd0?3`l03dm?@0o?cl0ADE50080A4A4
00L0ADE503dm?@10@400A4A403lo?`16ATH0GUiN0080@d=300<0?Cdm03`l?00l?3`00P0l?3`03P0m
?Cd0C4a<04=3@`10@400?3`l03lo?`0k>c/0?clo04=3@`10@400?Shn03Xj>P0m?Cd0@d=30P0l?3`0
6`0k>c/0?Shn0492@P14A4@0B4Q804M7A`10@400@d=30492@P0o?cl0@T9204M7A`1ADE40DU9B04];
B`14A4@0?Shn03lo?`0m?Cd0@D5103lo?`10@400@D5103hn?P0o?cl0?Shn03`l?0020492@P0E03lo
?`0n?Sh0ADE504a<C01DE5@0BDU9069RHP2CTi<0[:b/0;^k^`3?cll0d=3@0<O7a`2c/k<0VYZJ07al
O01iNGT0Rh^;09JFUP2ATI40Shn?0080P82000@0UIFE0:FUY@2XZ:P0XZ:R0P2][Jd05`2XZ:P0YjNW
08J6QP1iNGT0MgMg08j>SP2JVYX0U9BD08V9R@27QhL0Ph>306QXJ01JFUX0HF5Q05eMG@1XJ6P0MGEe
092@T02>SXh0RHV908:2PP1]KFd0IfMW0080JVYZ00l0H61P05iNGP1]KFd0MGEe06a/K01bLW80KFe]
07=cL`1eMGD0MgMg07]kN`1hN7P0U9BD09NGU`2e]KD00P39bLT04P38b<P0_Kfm0<30`031`L40^KVi
0:>SX`2@T900Ogmo06QXJ01NGUh0IVIV06UYJ@1_Kfl0T92@0;Vi^@2f][H0ZJVY0<30`080aLG502D0
clo?0;fm_@25QHD0Fe]K06e]K@1nOWh0YZJV0<k>cP3AdM40cLg=0<K6aP3?cll0a<C40<[:bP3GemL0
e]KF0=CDe03IfMT0clo?0:RXZ01hN7P0F5QH03hn?P0l?3`0@41003hn?P0m?Cd0>SXj03Ph>00i>CT0
>SXj03/k>`0i>CT0=cLg03Ph>00g=cL0=SHf0080>SXj0P0h>3P00`0k>c/0>3Ph03Xj>P0203`l?00<
03Xj>P0l?3`0>3Ph03Ph>00l?3`0>3Ph03Xj>P1?Cdl0UIFE0=3@d02NWYh0CTi>0P0i>CT04@0l?3`0
C4a<06IVIP1lO7`0KVi^05UIF@1NGUh0Fe]K04U9B@0k>c/0=cLg03@d=00e=CD0>3Ph03Xj>P0f=SH0
=cLg0080=SHf00@0=CDe03@d=00d=3@0=CDe100f=SH0300g=cL0>3Ph03Hf=P0e=CD0=cLg03De=@0g
=cL0=3@d03Ti>@0h>3P0=SHf03De=@80>3Ph0P0j>SX0100o?cl0Cdm?08j>SP2;Rh/=ooooo`004?oo
ool01P1>CTh0C4a<04];B`1;Bd/0Cdm?04Y:BP<0Bd];0140AdM704U9B@19BDT0CTi>04e=C@1:BTX0
ADE504=3@`16ATH0AdM704I6AP18B4P0A4A404M7A`1<C4`0CDe=04];B`0204E5A@0304I6AP19BDT0
BDU90080ADE500T0A4A404I6AP18B4P0Cdm?04I6AP1;Bd/0B4Q804U9B@1:BTX00`18B4P0301=CDd0
Bd];04Q8B016ATH0B4Q804E5A@11@D40A4A404=3@`14A4@0AdM704=3@`80BTY:00<0@D5104E5A@14
A4@00P15ADD01@10@400@d=303lo?`15ADD0@D510080@4100P13@d<01`10@400@D510451@@0m?Cd0
?Shn03lo?`10@4000P0o?cl03@12@T80?clo03dm?@10@400?3`l0451@@0o?cl0?Cdm03lo?`11@D40
@41003lo?`12@T800P0n?Sh01`14A4@0?Cdm0410@00j>SX0?clo04E5A@11@D400P12@T800`11@D40
?Cdm03dm?@0303`l?00803lo?`0k>c/0?clo03lo?`10@400?clo0451@@0n?Sh30410@00803dm?@0l
?3`0?Cdm03hn?P0m?Cd0?Shn0451@@10@40203dm?@0503`l?00k>c/0@41003`l?011@D400P10@400
301IFET0?clo04=3@`13@d<0@T920451@@0m?Cd0?3`l03lo?`0n?Sh0@T9203hn?P<0?clo00h0?3`l
03/k>`0n?Sh0?3`l0451@@0m?Cd0?clo05mOG`12@T80?Shn04=3@`11@D40@41003lo?`80@41000`0
?clo0492@P14A4@0@d=304Y:BP11@D40A4A40410@013@d<0@41003dm?@0l?3`204A4A00704=3@`10
@400A4A404A4A010@400?Shn0492@P0204=3@`0:03lo?`11@D40A4A40492@P10@400?Shn0410@00n
?Sh0>SXj03dm?@80@41000<0@T920410@00o?cl01010@4002014A4@0?Shn0451@@10@400?Cdm04];
B`16ATH0@4100P0o?cl01P0n?Sh0?Cdm03dm?@0m?Cd0@d=303hn?P80?clo01P0?Cdm03Ti>@0j>SX0
?3`l0451@@0o?cl0?Cdm03`l?011@D40?3`l0410@014A4@0@41003hn?P0l?3`0@D510492@P11@D40
A4A404=3@`12@T80ADE503hn?P14A4@203`l?0040451@@0l?3`0?Cdm03Ph>080?clo00d0?Cdm03/k
>`0n?Sh0@41003dm?@11@D40A4A404M7A`1OGel0S8b<0:VYZ@2][Jd0YjNW0080VYZJ0100YJFU08j>
SP2?Shl0R8R809NGU`2_[jl0]kNg09FEU@1aLG40RHV909BDU02MWId0[:b/0<71`@30`<00aLG50P3@
d=002@3Ph>00gmoO0=OGe`3=cLd0]kNg0:JVYP2BTY80Shn?0:>SX`020=KFeP080:6QX@2WYjL0ZJVY
0:NWY`2JVYX0R8R808Z:RP2?Shl20:2PX00F0:RXZ02][Jd0VIVI07moO`1eMGD0Lg=c079bLP1cLg<0
FUYJ05]KF`1nOWh0T92@08B4Q01MGEd0Cdm?04e=C@18B4P0Bd];04A4A01<C4`0AdM704a<C080GemO
02<0EEEE05eMG@1SHf<0MgMg092@T02_[jl0]kNg0<71`@3Bd]80b/[:0:VYZ@1/K6`0De=C04e=C@1D
E5@0OWin0:ZZZP2/[:`0R8R806QXJ01^KVh0RXZ:09NGU`2<S8`0P82006EUI@1ADE40BTY:05eMG@24
Q8@0YZJV09RHV02ZZZX0[Zj^0<G5a@020=?Cd`0:0=7Ad@3MgMd0emOG0=[JfP37alL0UYJF08:2PP28
R8P0IfMW03dm?@80?3`l00L0>SXj03Ti>@0i>CT0>3Ph03Hf=P0g=cL0>CTi0080=cLg0P0h>3P0100g
=cL0=SHf03Lg=`0h>3P203Xj>P0F03/k>`0f=SH0>CTi03Xj>P0k>c/0>CTi059BDP1mOGd0/;2`0;Bd
]01mOGd0?clo03hn?P0l?3`0>CTi03/k>`1=CDd0GUiN06QXJ01ADE40?clo03Ti>@80>SXj00<0>c/k
03Hf=P0i>CT00P0h>3P00`0j>SX0>3Ph03Hf=P0203Ph>00403Lg=`0e=CD0=CDe03Hf=P80=cLg00<0
=SHf03De=@0f=SH00P0h>3P01`0f=SH0=cLg03Lg=`0k>c/0>SXj03Hf=P0h>3P00P0i>CT0200j>SX0
?clo04Y:BP1kNg/0Zj^[0;Bd]029RHT0CDe=3Oooool0013ooooo00`0CDe=04a<C01<C4`0Bd];04i>
CP19BDT0BTY:04Q8B019BDT0ATI604];B`1:BTX204Q8B00404M7A`16ATH0A4A404A4A080B4Q801T0
ATI604A4A015ADD0A4A404Q8B016ATH0B4Q804=3@`15ADD0ATI604=3@`12@T80ATI604E5A@19BDT0
ATI604A4A013@d<0@T9204U9B@1:BTX0B4Q804M7A`18B4P0Cdm?0080AdM70180ADE504A4A012@T80
?clo04a<C013@d<0@T9203lo?`15ADD0@D5103lo?`19BDT0BTY:04=3@`11@D40@T9204E5A@12@T82
0451@@070410@014A4@0@D510410@00o?cl0@T920451@@0203lo?`0603`l?010@400?Shn04A4A00m
?Cd0?3`l0P0m?Cd01@0o?cl0@D5103dm?@0o?cl0?Cdm0080?Shn01P0ADE50492@P0o?cl0?Cdm03hn
?P0m?Cd0@41003hn?P0o?cl0?Shn0492@P10@400>c/k03lo?`10@400@D5103hn?P0o?cl0@41003/k
>`0i>CT0?Cdm03hn?P0l?3`203lo?`0B0410@017AdL0@D510492@P0m?Cd0A4A403dm?@0k>c/0@410
0451@@12@T80?clo0410@00o?cl0>c/k0451@@0o?cl0@410100k>c/01011@D40@41003`l?00o?cl2
03hn?P0=0410@00l?3`0?Shn04=3@`12@T80?Cdm03hn?P0k>c/0?clo03dm?@0o?cl0?Shn03lo?`02
03dm?@080492@P0l?3`0>c/k04E5A@13@d<0@T920451@@13@d<20451@@0404I6AP17AdL0?Shn04E5
A@80B4Q800X0?Shn04E5A@10@400AdM703dm?@11@D40@41004=3@`0n?Sh0A4A40`0n?Sh01011@D40
@T920410@012@T820410@00903/k>`0m?Cd0?clo03/k>`0m?Cd0@41003hn?P0j>SX0?3`l0080B4Q8
00l0CDe=04I6AP13@d<0?Cdm03`l?00n?Sh0@41003lo?`0k>c/0?clo03hn?P14A4@0>CTi0492@P0m
?Cd00P0n?Sh04@0m?Cd0?clo03hn?P0l?3`0>c/k03Ti>@0n?Sh0?3`l03/k>`10@400?Cdm03Ti>@0m
?Cd0>SXj03`l?010@400?clo0080@d=301<0@D5103hn?P0m?Cd0?3`l03hn?P0l?3`0@41004E5A@0j
>SX0?Shn03Xj>P0k>c/0>3Ph03/k>`0h>3P0?Shn03Ti>@0n?Sh0>SXj0080>c/k04/0>SXj0451@@10
@400?clo03Xj>P17AdL0FEUI096AT@2f][H0XZ:R0:JVYP2?Shl0QHF506m_K`1OGel0H61P06YZJP1g
MgL0MGEe08^;R`2:RXX0UYJF0<G5a@3;bl/0_kno0:f][@2b/[80_kno0<;2`P2m_Kd0`<300;no_`2l
_;`0`L710;no_`3Cdm<0eMGE0<W9b@2WYjL0QHF507alO02HV9P0/K6a0<S8b03:b/X0d];B0=?Cd`3;
bl/0_;bl0;2`/02QXJ40RXZ:08V9R@2<S8`0U9BD09nOW`2f][H0c<c<0;fm_@2VYZH0WIfM0820P01L
G5`0Fe]K04e=C@1JFUX0I6AT05UIF@1HF5P0AdM704Y:BP1=CDd0A4A404=3@`1HF5P00P1QHF405@1S
Hf<0KVi^075aL@1YJFT0F5QH05MGE`1>CTh0EUIF069RHP1lO7`0NWYj08V9R@2EUID0WinO0;no_`2i
^KT0/;2`0;jn_P3AdM40aLG50:BTY00209>CT`0>07=cL`1]KFd0KVi^07alO02IVIT0VYZJ06MWI`1B
DU80A4A40451@@19BDT0E5AD05]KF`1eMGD209:BTP0:09^KV`2RXZ80Z:RX0;Fe]@2][Jd0/[:b0<g=
c@38b<P0P82004e=C@80>CTi00@0>c/k03Xj>P0i>CT0>CTi0P0h>3P02@0i>CT0?3`l03Ti>@0g=cL0
>SXj03Ti>@0f=SH0>3Ph03Xj>P0203Lg=`0G03Ti>@0j>SX0>c/k03Xj>P1FEUH0Rh^;07alO01VIVH0
B4Q803Xj>P0k>c/0>CTi04A4A01EEED0D51@03`l?00j>SX0>c/k03Lg=`0d=3@0>CTi03Lg=`0k>c/0
0P0h>3P0300i>CT0<c<c03Xj>P15ADD0Bd];04i>CP1FEUH0@41003/k>`0j>SX0=cLg03Hf=P80=cLg
0P0f=SH0200g=cL0=SHf03Hf=P0f=SH0>SXj03Ph>00j>SX0?3`l0P0j>SX02P0l?3`0B4Q807alO02c
/k<0d=3@0>7Qh@36a/H0U9BD06][J`1BDU8=ooooo`004?ooool01@1>CTh0CDe=04];B`1=CDd0C4a<
0080BTY:0P17AdL204U9B@0904Y:BP16ATH0B4Q804M7A`1<C4`0CDe=04M7A`1:BTX0AdM70080B4Q8
00`0A4A404Y:BP1:BTX0ATI604Q8B014A4@0AdM704I6AP13@d<0A4A404E5A@14A4@204E5A@0404U9
B@14A4@0A4A404E5A@80AdM700H0ADE5051@D01>CTh0@T9204U9B@16ATH204A4A00604E5A@18B4P0
@T920492@P15ADD0Bd];0P12@T801`16ATH0B4Q803lo?`11@D40ADE504=3@`0o?cl00P0m?Cd01`16
ATH0?Cdm03lo?`0n?Sh0@41004=3@`12@T800P11@D400`12@T80?Shn03/k>`0203hn?P0903/k>`10
@400?Shn03lo?`0n?Sh0A4A404Y:BP0n?Sh0>c/k0080@41000L0?clo03dm?@13@d<0A4A40451@@10
@400>c/k0080?Shn00<0>c/k03dm?@0l?3`00P0l?3`00`0m?Cd0@41003hn?P0203`l?00<03/k>`0l
?3`0@T9203/k>`0m?Cd0@D5104=3@`15ADD0@41003/k>`0m?Cd0?clo0P0l?3`02@0n?Sh0?3`l03hn
?P0m?Cd0A4A40451@@12@T80?3`l03dm?@0303hn?P060410@00k>c/0?3`l03hn?P11@D40@T920P0l
?3`01`0o?cl0@D5103lo?`16ATH0?clo03hn?P11@D400P14A4@09P15ADD0@d=30492@P0n?Sh0?clo
0410@014A4@0?clo04A4A011@D40ADE50451@@19BDT0@D5104=3@`11@D40@4100492@P0o?cl0@D51
0492@P1FEUH0BTY:0492@P10@400@T9203dm?@0n?Sh0A4A40451@@0j>SX0?clo0451@@0n?Sh0?Cdm
0410@00k>c/0?3`l0`0o?cl03P13@d<0>SXj03Xj>P11@D40@41004=3@`12@T80G5aL07UiN@1ZJVX0
BTY:03`l?014A4@0@T920P0n?Sh204=3@`0;0410@00j>SX0?3`l03/k>`12@T80@D510492@P0l?3`0
>CTi03lo?`10@4000P0n?Sh00`10@400>SXj03dm?@0203/k>`0A03dm?@10@400@d=305UIF@18B4P0
AdM705iNGP22PX80HF5Q04U9B@10@400?Cdm0410@012@T80AdM704=3@`0n?Sh00P0o?cl00`0l?3`0
@d=303lo?`020410@00>03/k>`0m?Cd0=cLg03Xj>P0i>CT0>c/k03Ti>@11@D40?Shn0410@011@D40
?Cdm061PH02=SHd2071`L01J08>3P`1mOGd0N7Qh08:2PP1jNWX0GEeM04m?C`1=CDd0EeMG069RHP1X
J6P0H61P0:>SX`2f][H0VYZJ07YjNP1/K6`0IFEU06MWI`1bLW80I6AT05UIF@1MGEd0K6a/07moO`2E
UID0^;Rh0=CDe03Kfm/0aLG507moO`1LG5`0GemO06EUI@1YJFT0LG5a0:FUY@2n_[h0[jn_07MgM`1A
DE40BTY:04E5A@11@D40A4A404M7A`1<C4`0Fe]K07]kN`2][Jd0`<300;no_`2/[:`0TY:B08V9R@26
QXH0TY:B09VIV@2JVYX0WinO0;^k^`2c/k<0_Kfm0;Bd]02NWYh0T92@09bLW02XZ:P0XZ:R08F5Q@1l
O7`0QhN708j>SP1bLW80MWIf06MWI`1[Jf/0Fe]K05eMG@1GEeL0Bd];04i>CP1NGUh0KFe]07inOP2g
]kL0g=cL0>WYj@3Ti>@0h^;R0P3IfMT0;03Lg=`0e]KF0<C4a02^[Zh0Ti>C0<;2`P3Fe]H0c<c<0:j^
[P26QXH0HF5Q05mOG`18B4P0@D5104E5A@18B4P0BDU905IFEP1VIVH0Ng]k0:>SX`2o_kl0/K6a0:ZZ
ZP32`/80/[:b07inOP14A4@0>SXj03`l?00i>CT0=cLg03Ph>00g=cL0>3Ph03Ti>@0h>3P0@T9203dm
?@0h>3P0=3@d03Lg=`0j>SX0>3Ph0P0f=SH01P0g=cL0?3`l03/k>`0h>3P0A4A40410@080>c/k00d0
A4A407IfMP2IVIT0WIfM06ATI012@T80>CTi03Ph>00i>CT0=SHf03Lg=`0e=CD0>3Ph0080=SHf0P0h
>3P0400i>CT0ADE505aLG01IFET0Bd];03hn?P0i>CT0>3Ph03Ti>@0g=cL0>SXj03Ph>00f=SH0=3@d
03De=@0g=cL403Hf=P0?03/k>`17AdL0A4A40451@@1^KVh0YZJV0=;BdP3Rh^80jn_[0=cLg02n_[h0
S8b<06YZJP1ADE40E5AD00gooooo000@ooooo`0605UIF@1JFUX0CDe=04e=C@19BDT0Bd];0P1:BTX0
1`1;Bd/0C4a<04i>CP1:BTX0Bd];04U9B@16ATH00P13@d<05`15ADD0Bd];04a<C01<C4`0ATI604=3
@`19BDT0B4Q804=3@`12@T80BDU904M7A`1;Bd/0BTY:04M7A`18B4P0@T9204M7A`1:BTX0BDU904];
B`17AdL0@d=30080ADE500@0A4A404I6AP10@400ATI60P17AdL01@13@d<0@T9204A4A014A4@0@d=3
0080Bd];00<0BTY:04A4A012@T800P13@d<01010@400?clo03dm?@0n?Sh20410@00303hn?P13@d<0
?clo0080?clo0P11@D403`10@400@T920492@P12@T80@41003`l?00k>c/0?clo04E5A@11@D40?Shn
03dm?@14A4@0?Shn03`l?00203hn?P0=03`l?010@400@41003`l?010@400ADE503hn?P0l?3`0>SXj
03`l?010@400>SXj03hn?P0203`l?080?Cdm00d0?clo0410@012@T80?clo03hn?P11@D40ADE503lo
?`10@400@D5103hn?P13@d<0ADE50080?clo0P11@D403010@400?Cdm03dm?@0o?cl0ADE50451@@14
A4@0ADE503lo?`0l?3`0>CTi03/k>`80?3`l0140?Cdm04=3@`10@400?Shn0410@00m?Cd0@4100451
@@13@d<0A4A40492@P13@d<0?Shn03lo?`11@D40>c/k03lo?`020492@P0503lo?`0m?Cd0?clo04A4
A012@T800P15ADD20492@P0>04I6AP10@400?clo03`l?011@D40A4A40451@@0n?Sh0>c/k05ADE015
ADD0@D5103lo?`11@D430410@0030451@@0o?cl0?clo0080?Cdm00<0?Shn03`l?00k>c/00P0m?Cd0
1@10@400@D5103hn?P12@T80?clo0080>c/k00P0De=C06][J`2CTi<0K6a/04M7A`0m?Cd0>CTi0410
@080?Cdm00T0@D5103dm?@15ADD0?clo03`l?00n?Sh0?clo03dm?@0n?Sh00P0i>CT05@0l?3`0@d=3
03dm?@0m?Cd0>CTi03Xj>P0i>CT0=cLg03dm?@0k>c/0?clo05MGE`1dM7@0OGem05iNGP1ADE40F5QH
04i>CP0m?Cd0@41003`l?0020410@00703lo?`11@D40@41003lo?`0m?Cd0@41003hn?P0203`l?005
03dm?@0k>c/0?clo03`l?00k>c/00P0j>SX02P0l?3`0>c/k0451@@0j>SX0?3`l04A4A01DE5@0MGEe
08j>SP2LW9`20;Jf]P0809JFUP1dM7@0L71`07QhN01cLg<0KFe]061PH01OGel205IFEP0Y055AD@1F
EUH0CDe=04I6AP17AdL0A4A40492@P0o?cl0ATI604M7A`1CDe<0M7Ad09jNWP2f][H0`L710=;BdP3E
eMD0cLg=0<C4a032`/80`L710;Jf]P2WYjL0SHf=0861P@1bLW80G5aL04Y:BP16ATH0@T9204=3@`0n
?Sh0@D5103dm?@0o?cl0AdM704=3@`1@D500DU9B05IFEP1PH6000P1LG5`0501OGel0I6AT06a/K01l
O7`0RXZ:0:RXZ02l_;`0emOG0>3Ph03De=@0[Jf]08R8R01fMWH0QXJ60;2`/02l_;`0_Kfm0<?3``2n
_[h0bLW90P3Bd]80;@2m_Kd0]kNg0:^[Z`24Q8@0KVi^06MWI`1YJFT0IFEU05UIF@1_Kfl0Ti>C0=_K
f`3/k>`0j^[Z0=GEe@2a/K40^k^k0<S8b034a<@0clo?0=3@d038b<P0`l?30<S8b039bLT0`l?30<[:
bP38b<P0][Jf09fMW@1oOgl0I6AT05mOG`17AdL0?Shn04U9B@1/K6`0UYJF09NGU`2HV9P0YZJV0;jn
_P3=cLd0V9RH05eMG@0203dm?@80>3Ph00D0>c/k03Ti>@0j>SX0>c/k03Xj>P0203/k>`0J03Hf=P0m
?Cd0>CTi03Hf=P0h>3P0>CTi03Ph>00i>CT0=cLg03Ti>@0m?Cd0>c/k03dm?@1lO7`0`/;20=KFeP2E
UID0G5aL03/k>`0h>3P0>CTi03Ph>00i>CT0<c<c03Lg=`0i>CT403Ph>00603Hf=P0m?Cd0@D510492
@P0i>CT0>3Ph0P0i>CT00`0n?Sh0=CDe03@d=00203Hf=P0303@d=00e=CD0=SHf0080=cLg0100>c/k
03Lg=`0h>3P0@D5104Q8B01mOGd0^k^k0=oOg`3Shn<0inOW0=SHf02l_;`0OGem05IFEP13@d<0@D51
0P0l?3`=ooooo`004?ooool00`1?Cdl0Bd];04a<C00204e=C@0604i>CP1;Bd/0Bd];04];B`19BDT0
BTY:1019BDT04017AdL0ATI604A4A018B4P0AdM704Y:BP19BDT0BTY:04U9B@16ATH0Bd];04Q8B01:
BTX0B4Q804E5A@14A4@204E5A@0404A4A018B4P0@d=304=3@`80AdM700P0A4A404E5A@12@T80A4A4
0451@@14A4@0ATI604];B`<0ADE500H0ATI604Q8B00o?cl0A4A404I6AP15ADD20492@P050451@@12
@T80ADE50492@P0o?cl00P12@T802P10@400?clo04=3@`12@T80@d=30492@P10@400@D5103hn?P10
@40304A4A0050492@P10@400?clo0451@@10@4000P0o?cl01`13@d<0@D5103`l?00n?Sh0@41003`l
?00n?Sh00P0o?cl0300m?Cd0>SXj03lo?`0l?3`0@D5103`l?00n?Sh0?Cdm04=3@`0k>c/0>CTi03hn
?P80?Cdm00@0ADE503hn?P0m?Cd0>c/k0P0n?Sh0100j>SX0@41003/k>`0l?3`20410@00:03dm?@0j
>SX0>c/k03hn?P0m?Cd0>c/k03hn?P0o?cl0A4A40451@@80?clo0P0n?Sh02@0l?3`0?clo03lo?`0o
?cl0@D5103lo?`0l?3`0?clo0451@@0203lo?`0@0410@015ADD0?Cdm03hn?P1:BTX0ATI60451@@10
@400?clo0410@00n?Sh0>c/k03dm?@10@400?3`l03hn?P80?clo00X0B4Q80410@011@D40@D5103lo
?`0k>c/0?Shn0410@016ATH0?Shn0P0m?Cd01011@D40AdM703/k>`0n?Sh30492@P0603dm?@0l?3`0
?Shn04=3@`10@400?Cdm0P10@400100o?cl0?3`l03hn?P0n?Sh403Xj>P0V03/k>`15ADD0De=C04Y:
BP15ADD0?Cdm03/k>`10@400?Cdm03Xj>P0k>c/0>CTi03hn?P0m?Cd0?3`l03dm?@0n?Sh0?clo03`l
?00m?Cd0>c/k03`l?01:BTX0>CTi03Xj>P0l?3`0>c/k03`l?00o?cl0>SXj03hn?P0k>c/0?clo04Q8
B01DE5@0Cdm?04I6AP11@D4203lo?`0403`l?00m?Cd0?clo03hn?P80?clo04d0@41003lo?`0k>c/0
?3`l03dm?@14A4@0@D5103/k>`0o?cl0@41003hn?P10@400?3`l03Xj>P0n?Sh0ATI604=3@`15ADD0
>c/k04=3@`1?Cdl0JVYZ08V9R@2PX:00/k>c09VIV@24Q8@0N7Qh06QXJ01HF5P0D51@04I6AP14A4@0
@D510410@00o?cl0@D5103`l?011@D40>SXj03hn?P12@T80@d=303lo?`10@400ADE504e=C@1UIFD0
T92@0:VYZ@2VYZH0[Zj^0;Rh^02f][H0Y:BT09RHV02@T900OGem06i^KP1RHV80EeMG04Q8B011@D40
@T9204m?C`1eMGD0Shn?08Z:RP1gMgL0IVIV06UYJ@1mOGd0PX:207inOP24Q8@0S8b<092@T00209VI
V@180:JVYP2n_[h0a<C40<K6aP2[Zj/0S8b<0861P@1gMgL0M7Ad07YjNP2LW9`0_;bl0<?3``37alL0
/k>c09>CT`1kNg/0Ogmo08F5Q@29RHT0T92@09JFUP2OWil0X:2P0:NWY`2QXJ40VIVI09JFUP2LW9`0
[Zj^0=GEe@3Kfm/0g=cL0<O7a`2d];@0][Jf0;bl_038b<P0c<c<09JFUP1cLg<0Kfm_07IfMP2CTi<0
W9bL09^KV`2MWId0]KFe0<c<c03Kfm/0f][J0=KFeP3IfMT0f=SH0<o?c`3>c/h0cLg=0:n_[`1iNGT0
DU9B06EUI@2<S8`0Rh^;09fMW@2`/;00b/[:0<g=c@32`/80VYZJ061PH012@T80@4100`0m?Cd07@0l
?3`0>SXj03/k>`0j>SX0>3Ph03`l?00n?Sh0>SXj03Ti>@0h>3P0>CTi03Ph>00i>CT0=SHf03Ti>@0m
?Cd0A4A409:BTP3EeMD0`<30071`L00m?Cd0>CTi03Ph>00i>CT0=SHf03Ph>00m?Cd0=cLg0080>3Ph
00T0=SHf03Lg=`0h>3P0=CDe03Lg=`0f=SH0<S8b03Lg=`0e=CD00P0i>CT0100g=cL0?Shn03De=@0i
>CT203De=@@0=SHf01<0>SXj03Ph>00h>3P0CDe=08R8R036a/H0hn?S0>[ZjP3Shn<0d=3@0:FUY@1S
Hf<0AdM703/k>`0l?3`0>CTi03Xj>P0h>3P0>SXj00gooooo000@ooooo`80CDe=00L0C4a<04];B`19
BDT0BTY:04a<C01:BTX0AdM700@0BTY:00P0Bd];04U9B@17AdL0BDU904A4A017AdL0ATI604U9B@80
BTY:00h0ATI604M7A`17AdL0ATI604A4A016ATH0ADE504M7A`15ADD0B4Q804E5A@16ATH0@T9204=3
@`80ADE500d0AdM704Q8B012@T80B4Q80451@@13@d<0@D5104I6AP15ADD0@D510492@P14A4@0@d=3
0080@D5100T0@d=304E5A@11@D40@T9203dm?@11@D40@T9204M7A`11@D400P14A4@01@0o?cl0@T92
0451@@0m?Cd0?Shn0080?clo0P0n?Sh20410@0030492@P16ATH0A4A40080@T9200<0@4100451@@0m
?Cd00P0n?Sh01@0o?cl0?Shn03hn?P0j>SX0@D510080@41000D0?clo03hn?P10@400@41003`l?002
03hn?P060451@@14A4@0?Shn03`l?00m?Cd0@4100P0n?Sh02`0o?cl0?3`l0451@@0m?Cd0@41003dm
?@0n?Sh0?Cdm0451@@10@400?Cdm0080?3`l0P0k>c/0100m?Cd0>c/k03Ti>@0n?Sh203`l?0030492
@P0o?cl0@4100080@41000`0>c/k03lo?`0l?3`0?Cdm0451@@0n?Sh0@4100451@@0n?Sh0?clo0492
@P13@d<203lo?`0903dm?@10@400?Shn0410@00m?Cd0ATI60451@@0o?cl0?Cdm0080@4100P11@D40
2P13@d<0?Shn04];B`10@400?Shn03lo?`0m?Cd0>SXj03`l?015ADD303`l?00303dm?@14A4@0@d=3
0080?clo00/0?Shn04A4A012@T80?Cdm03`l?00k>c/0?3`l03dm?@0l?3`0@d=303hn?P020410@005
03/k>`0o?cl0?clo03Xj>P0k>c/00P0m?Cd00`0k>c/0?Shn03/k>`0203hn?P0=03dm?@0o?cl0?clo
03/k>`0g=cL0>CTi03/k>`0l?3`0?Shn03lo?`0m?Cd0@D5104=3@`0203hn?P0B03/k>`0l?3`0?Shn
03hn?P0k>c/0@41003hn?P10@400>c/k03hn?P0m?Cd0ADE50492@P16ATH0>CTi03`l?00n?Sh0>3Ph
0P0l?3`01@0h>3P0?clo03Xj>P0l?3`0?clo0080@41002D0?Cdm03/k>`0j>SX0?Shn04A4A010@400
?Shn03/k>`10@400?Cdm03hn?P0k>c/0@41004];B`16ATH0EEEE05IFEP1HF5P0EUIF065QH@1oOgl0
OGem05IFEP18B4P0@4100492@P0m?Cd0?clo0451@@0j>SX0ATI603`l?00n?Sh0@T9203dm?@0n?Sh0
@4100080?clo01<0?Shn03lo?`11@D40DE5A08F5Q@2k^k/0clo?0=_Kf`3Hf=P0d];B0<K6aP2/[:`0
TY:B07QhN01YJFT0E5AD0492@P0o?cl0@T920080?Cdm0P0n?Sh06@1>CTh0J6QX07IfMP2=SHd0Vi^K
09JFUP2>SXh0XJ6Q0:2PX01mOGd0JFUY069RHP1MGEd0FUYJ05iNGP1_Kfl0R8R80:ZZZP34a<@0fMWI
0=kNgP3Ph>00cLg=0:JVYP2JVYX00P2NWYh0502ATI40X:2P0:^[Z`2_[jl0_kno0<k>cP3De=@0f][J
0=GEe@2g]kL0X:2P08f=S@24Q8@0Ph>30820P01jNWX0PH6107moO`2DU9@0];Bd0P3Fe]H0;@3@d=00
^k^k0;jn_P2f][H0YZJV0;6a/@2c/k<0XJ6Q08N7Q`22PX80UiNG0;6a/@2XZ:P0MWIf06=SH`1_Kfl0
TI6A0:>SX`2g]kL0`L710;Rh^02g]kL0[Jf]0:^[Z`2^[Zh0TY:B08R8R02b/[80/;2`08N7Q`1iNGT0
X:2P0;Rh^02YZJT0U9BD09bLW01nOWh0BTY:0410@00n?Sh0BDU905=CD`1:BTX0>c/k03`l?00203Xj
>P0403`l?00h>3P0>CTi03Ti>@80>3Ph00d0>c/k03Ti>@0l?3`0IfMW0;no_`3Fe]H0OGem04Q8B00h
>3P0?Cdm03Ti>@0l?3`0=SHf00<0>CTi00@0=SHf03Lg=`0g=cL0>3Ph0P0j>SX01@0h>3P0=cLg03Ph
>00d=3@0=cLg00<0=SHf00@0=3@d03Ph>00e=CD0>3Ph0P0e=CD203@d=00=03De=@0g=cL0?Shn04m?
C`2ATI40cLg=0>?Sh`3]kNd0jn_[0>CTi033`l<0H61P0410@00203Xj>P0603Lg=`0m?Cd0?3`l03Lg
=`0h>3P0A4A43Oooool0013ooooo00T0Cdm?04Y:BP1;Bd/0BTY:04M7A`1:BTX0BDU904Q8B015ADD0
0P19BDT03@15ADD0ATI604Q8B018B4P0BTY:055AD@15ADD0BTY:04M7A`18B4P0ADE504A4A016ATH0
0`15ADD204M7A`0<04];B`18B4P0ADE504E5A@18B4P0ADE504A4A018B4P0BDU904];B`18B4P0BDU9
0P17AdL06015ADD0Bd];04I6AP15ADD0BDU904Q8B01:BTX0B4Q80492@P16ATH0?clo0451@@13@d<0
@41003dm?@0n?Sh0@D510410@011@D40A4A40451@@10@400?Cdm03lo?`80@T9200@0@4100492@P0n
?Sh0@D510P0o?cl00`13@d<0ADE50451@@020451@@0=0410@011@D40?clo03lo?`12@T80?clo0451
@@0m?Cd0?Shn0492@P0o?cl0?3`l0410@00203hn?P0503lo?`10@400@41003/k>`0l?3`00P11@D40
1P0m?Cd0@D5103hn?P0m?Cd0?Shn0451@@80?Shn0100@d=30410@00n?Sh0@d=30492@P11@D40@410
03hn?P0l?3`0@D5104I6AP0l?3`0>3Ph03Xj>P0m?Cd0?Shn0`0m?Cd203hn?P0303Xj>P0m?Cd0?Shn
0080?Cdm00L0?Shn03lo?`0l?3`0?Cdm0410@00o?cl0?Shn0080?clo0100?Shn03dm?@0j>SX0@D51
03lo?`0m?Cd0?3`l03hn?P13@d<0@T920410@013@d<0@D5103lo?`10@400?Shn0P0l?3`20451@@0>
03`l?00m?Cd0?Shn0451@@10@400?Shn04A4A013@d<0@T9203hn?P1:BTX0@4100451@@0l?3`203lo
?`0@03hn?P0l?3`0>CTi03`l?00j>SX0@T920451@@0l?3`0@D5103dm?@0k>c/0?3`l0410@00l?3`0
?clo03Xj>P80?Cdm00T0?3`l03lo?`0m?Cd0?clo0410@00k>c/0@D5104=3@`11@D400P0n?Sh0300i
>CT0?Cdm03hn?P0m?Cd0@D5104M7A`0m?Cd0>SXj03hn?P0l?3`0?Cdm0410@080?clo00P0@T920451
@@19BDT0BTY:04E5A@0m?Cd0>c/k03`l?080>SXj00<0?Cdm0451@@0j>SX00P0n?Sh0200k>c/0>SXj
03lo?`0m?Cd0?clo03hn?P0h>3P0?Cdm0P0n?Sh02`0i>CT0?3`l03Ti>@0m?Cd0>SXj03lo?`12@T80
@4100451@@1@D500EEEE0080De=C00H0E5AD04Y:BP19BDT0BTY:04A4A013@d<203lo?`0Q03hn?P0m
?Cd0?3`l0410@00m?Cd0>SXj03`l?00k>c/0?clo03hn?P0m?Cd0@T9203dm?@0n?Sh0?Cdm0492@P1=
CDd0LG5a0:VYZ@3@d=00gMgM0=CDe038b<P0/[:b08Z:RP1TI6@0C4a<04I6AP0m?Cd0@41003dm?@0n
?Sh0?Cdm0080?clo05H0BDU905YJFP1[Jf/0NWYj079bLP1OGel0D51@04a<C01ADE40GEeM05mOG`1`
L700PX:208J6QP2SXj<0[jn_0:f][@2SXj<0UiNG09ZJVP2NWYh0WinO0;:b/P2j^[X0]kNg0:VYZ@2c
/k<0ZZZZ0:^[Z`2g]kL0`L710<30`032`/80_Kfm0;Rh^02NWYh0V9RH09NGU`2][Jd0]kNg0;>c/`2_
[jl0`L710<S8b03:b/X0YZJV0:2PX02HV9P0TY:B09BDU02/[:`0ZZZZ0;2`/02l_;`0_[jn0;Vi^@2f
][H0^;Rh0:^[Z`2WYjL0Rh^;09BDU02TY:@0XZ:R0:j^[P2g]kL0Xj>S09:BTP2MWId0Y:BT092@T01W
IfL0E5AD04a<C01HF5P0IfMW071`L01jNWX0RXZ:0:FUY@2i^KT0WinO08j>SP2HV9P0Shn?06MWI`80
OWin00/0[:b/08J6QP2PX:00/[:b0;fm_@2VYZH0L71`03Xj>P0n?Sh0>3Ph03Xj>P0203/k>`80?3`l
00/0>c/k03Lg=`0l?3`0?Cdm08Z:RP37alL0`<3006e]K@1>CTh0>SXj03/k>`0203Ph>00@03Ti>@0h
>3P0>SXj03De=@0i>CT0>3Ph03/k>`0f=SH0=3@d03Xj>P0i>CT0=CDe03Ph>00i>CT0>c/k03Lg=`<0
=SHf0P0e=CD0100f=SH0=3@d03Hf=P0f=SH203De=@0>03Hf=P0j>SX0HV9R08J6QP1oOgl0PX:209JF
UP3;bl/0d=3@0;^k^`1lO7`0@41003Xj>P0g=cL203Ti>@0503/k>`0j>SX0@D5104e=C@1DE5@03Ooo
ool0013ooooo00@0JFUY04i>CP1;Bd/0Cdm?0P1<C4`01P19BDT0B4Q804];B`1:BTX0B4Q804I6AP80
B4Q800D0BTY:04E5A@19BDT0B4Q804U9B@0204Y:BP0404U9B@14A4@0ADE504Q8B080AdM700D0BDU9
04Y:BP1=CDd0BDU904M7A`0204E5A@80A4A400T0Bd];04Q8B016ATH0B4Q804m?C`19BDT0ATI604E5
A@19BDT00P14A4@02`17AdL0A4A404=3@`13@d<0@T9203hn?P10@400ADE504I6AP12@T80B4Q80080
@d=300@0?clo04A4A011@D40?Shn0P0o?cl20410@0030451@@0o?cl0@D5100<0@41000@0@D5103lo
?`16ATH0@T920P11@D420410@00<0451@@0n?Sh0?3`l03lo?`12@T80?Cdm03/k>`0n?Sh0?clo03/k
>`0m?Cd0>SXj0P10@4020451@@0;0410@00o?cl0?3`l0451@@12@T80@41003/k>`0j>SX0?Shn0451
@@0j>SX00`0m?Cd02P0l?3`0?Shn0451@@0n?Sh0>c/k03dm?@14A4@0@41003`l?00i>CT203hn?P0K
03`l?00n?Sh0?Cdm03`l?00m?Cd0?3`l03dm?@0j>SX0?3`l03hn?P0l?3`0@41003lo?`0m?Cd0?3`l
0451@@0n?Sh0@T9203`l?00m?Cd0?Shn03dm?@0k>c/0?Shn04A4A013@d<0@T920080@d=300D0A4A4
0492@P10@400@d=30451@@030410@0<0?clo00d0?Cdm03lo?`0m?Cd0@D510410@00o?cl0?Shn03lo
?`0n?Sh0@T9203hn?P11@D40?Cdm00<0?3`l01P0@D5103lo?`0m?Cd0?clo03hn?P0l?3`0@T9203`l
?00k>c/0>SXj03lo?`0k>c/0?clo03`l?00k>c/0>3Ph03/k>`11@D40>c/k0410@00m?Cd0?clo03Xj
>P0i>CT203Xj>P0403`l?00o?cl0?Cdm03`l?080?Shn0180@D5103dm?@12@T80A4A403lo?`10@400
?Cdm03/k>`0n?Sh0?3`l04=3@`0n?Sh0B4Q804i>CP18B4P0@41004A4A00o?cl203/k>`0:03Xj>P10
@400?Shn03lo?`12@T80C4a<03hn?P0j>SX0?3`l03lo?`80?Cdm00/0?clo03Xj>P0k>c/0?3`l03/k
>`0n?Sh0>SXj03lo?`0m?Cd0BDU9059BDP0204e=C@0A04i>CP1ADE40CTi>04Y:BP12@T80@41003`l
?00j>SX0?clo03hn?P0l?3`0>CTi03lo?`0k>c/0>CTi03`l?00k>c/00P0j>SX203`l?0030410@00l
?3`0@4100080?clo00d0@d=3069RHP21PH40YJFU0<?3``37alL0/K6a09fMW@29RHT0JVYZ055AD@15
ADD0?Cdm0080@d=30`0n?Sh02@15ADD0F5QH06QXJ01aLG40NWYj07MgM`1UIFD0FEUI059BDP0205QH
F00<069RHP1_Kfl0P82008j>SP2/[:`0alO70<W9b@3Hf=P0gMgM0=WIf@3De=@0f][J0P3Ph>000`3F
e]H0d=3@0<W9b@020<;2`P050<_;b`3Hf=P0e=CD0=KFeP3Kfm/00P3Ogml03`3QhN40e=CD0;^k^`39
bLT0alO70<S8b03:b/X0_kno0<K6aP2o_kl0U9BD09^KV`2f][H0`/;20<30`0020<W9b@0X0:n_[`28
R8P0H61P07QhN027QhL0UYJF0:RXZ02c/k<0`l?30<30`035aLD0c/k>0=?Cd`3;bl/0XJ6Q06QXJ01T
I6@0Lg=c096AT@2[Zj/0[Zj^0:VYZ@2^[Zh0XJ6Q0<71`@3Cdm<0^;Rh08:2PP2CTi<0UIFE09^KV`2F
UYH0MgMg06EUI@1`L700H61P04a<C01WIfL0Ti>C08F5Q@80Zj^[00D0N7Qh0861P@1lO7`0F5QH04e=
C@020492@P0C0410@00m?Cd0>SXj03Ti>@0k>c/0>SXj03/k>`1dM7@0dm?C0;Ng]`1VIVH0?Shn0492
@P0k>c/0=cLg03hn?P0j>SX0=cLg03Ph>00203Lg=`0>03Ph>00f=SH0=CDe03Xj>P0g=cL0>SXj03De
=@0c<c<0=cLg03Hf=P0h>3P0=cLg03Ti>@0g=cL203De=@0L03Lg=`0e=CD0=cLg03Ph>015ADD0Hf=S
03lo?`0g=cL0>CTi0410@018B4P0G5aL06YZJP1XJ6P0H61P05UIF@16ATH0>SXj03Lg=`0l?3`0>c/k
03Ph>00g=cL0BTY:075aL@27QhL0GemO03`l?0gooooo000@ooooo`80Cdm?0`1<C4`01P1=CDd0C4a<
04i>CP1:BTX0AdM704Q8B080Bd];00`0B4Q804Y:BP18B4P0BDU904M7A`19BDT0Bd];04Y:BP18B4P0
A4A404=3@`16ATH204A4A00504I6AP18B4P0B4Q804Q8B015ADD00P16ATH04018B4P0@d=304Q8B018
B4P0A4A404I6AP1=CDd0Cdm?04M7A`13@d<0AdM704=3@`14A4@0BDU904m?C`19BDT204E5A@0504=3
@`17AdL0ATI604E5A@16ATH00P14A4@01@15ADD0@41004I6AP10@400?Shn0080@41000h0?clo03dm
?@10@400@T9204A4A011@D40?Cdm0451@@0o?cl0?Cdm0410@014A4@0AdM704E5A@80@41000<0?Shn
0410@013@d<00P0n?Sh01@0o?cl0?3`l03`l?00o?cl0>c/k0080?Cdm00T0?clo0451@@12@T80?Cdm
0451@@0m?Cd0@41003dm?@0n?Sh00P0o?cl02P0m?Cd0>c/k03`l?00o?cl0>c/k03`l?00n?Sh0?Cdm
03hn?P10@40203/k>`0703`l?00n?Sh0?3`l03dm?@0i>CT0>3Ph03`l?00204E5A@0603hn?P0l?3`0
?Shn03Xj>P0n?Sh0>SXj0P0n?Sh00`0k>c/0@41003hn?P0203`l?00303lo?`0j>SX0@D510080@D51
00d0?Cdm03Xj>P0m?Cd0?3`l03dm?@0o?cl0@41003lo?`0l?3`0?clo0410@011@D40@T920080@410
00L0@T9203hn?P0n?Sh0@D510410@00m?Cd0@T9200<0?clo00@0?Shn03lo?`0o?cl0?Shn0P0o?cl0
1P13@d<0A4A403dm?@0j>SX0?3`l03dm?@80?clo00D0?Cdm03`l?00l?3`0@41003`l?00203hn?P07
03lo?`0j>SX0?3`l03dm?@12@T80@41003dm?@020451@@0A03dm?@0k>c/0?Shn03Ti>@0j>SX0>c/k
03hn?P0o?cl0?3`l03/k>`0l?3`0@D5103dm?@11@D40?3`l03hn?P0k>c/00P0n?Sh0100k>c/0?Shn
03hn?P0o?cl20451@@0:03hn?P12@T80@T9203hn?P10@400@d=303`l?00j>SX0>c/k03lo?`<0?Shn
00H0?3`l03Ti>@0m?Cd0?3`l03dm?@0n?Sh20410@00:03/k>`0j>SX0?Cdm03lo?`0j>SX0>CTi04E5
A@1KFe/0Kfm_06=SH`80ATI60240@T9203lo?`0n?Sh0?Cdm0410@00k>c/0?Cdm03/k>`0h>3P0?Cdm
03`l?00n?Sh0?Cdm0451@@0l?3`0>CTi03Xj>P0i>CT0>c/k03`l?00j>SX0?Cdm03`l?017AdL0F5QH
07alO02MWId0/K6a0;Rh^02ZZZX0SXj>069RHP1<C4`00P12@T80800l?3`0?Shn0451@@10@400@T92
0410@013@d<0@D5104A4A01MGEd0MgMg08:2PP1gMgL0MGEe07inOP2=SHd0X:2P0;Ng]`2TY:@0]KFe
0<30`02_[jl0ZZZZ0:f][@2f][H0/K6a0;:b/P2TY:@0WinO09JFUP2>SXh0TI6A0P2HV9P0K`2RXZ80
XJ6Q09>CT`1iNGT0Jf][06=SH`1eMGD0Q8B408f=S@2LW9`0WIfM09jNWP2EUID0Q8B4075aL@25QHD0
PH6107=cL`1gMgL0Lg=c07IfMP1_Kfl0GEeM059BDP1FEUH0KVi^071`L022PX80V9RH08R8R021PH40
HV9R051@D017AdL0C4a<079bLP27QhL0RXZ:08>3P`1YJFT0KVi^07]kN`1mOGd0MGEe065QH@1VIVH0
TI6A0;6a/@2g]kL0]KFe0:j^[P2h^;P0aLG50=OGe`3Cdm<0`l?30:JVYP3:b/X0a<C40:JVYP2UYJD0
_[jn0<O7a`2b/[80Vi^K08B4Q01`L700LG5a07moO`2FUYH0YJFU09RHV022PX80Ti>C0;bl_031`L40
YJFU09NGU`2EUID0P82007alO01OGel0H61P05]KF`20P800^KVi0>3Ph034a<@0[:b/09RHV01nOWh0
B4Q803dm?@0o?cl0>3Ph03Hf=P0h>3P0>SXj03Ph>00f=SH0>3Ph03`l?00g=cL0=SHf03Ti>@0e=CD0
=SHf03Ph>00f=SH0>3Ph03De=@0303Hf=P0M03Lg=`0d=3@0=SHf03Ti>@1:BTX0[jn_0;>c/`1SHf<0
Bd];04m?C`1<C4`0AdM703lo?`0g=cL0>CTi03Lg=`0f=SH0>CTi03/k>`0f=SH0=cLg03Ph>015ADD0
R8R809nOW`2?Shl0Hf=S03hn?P14A4@03Oooool0013ooooo00@0Cdm?059BDP1=CDd0Bd];0`1:BTX0
3P1=CDd0B4Q804M7A`18B4P0Bd];04U9B@18B4P0BTY:04M7A`1;Bd/0ATI604U9B@14A4@0ATI60P17
AdL04@16ATH0ADE504=3@`13@d<0ATI604Q8B014A4@0B4Q804E5A@19BDT0A4A404U9B@15ADD0B4Q8
04Y:BP16ATH0A4A40080ADE500D0AdM70492@P12@T80B4Q804E5A@020492@P0=04E5A@12@T80@D51
0410@013@d<0A4A404=3@`11@D40AdM704I6AP11@D40@41004E5A@0204=3@`0D0492@P13@d<0@D51
0410@014A4@0@d=303lo?`0n?Sh0?3`l04I6AP10@400?clo03/k>`18B4P0@d=30410@011@D40@T92
0410@00o?cl20492@P0D03dm?@0k>c/0>c/k03dm?@10@400>c/k0451@@17AdL0@41003`l?00o?cl0
?3`l03dm?@0n?Sh0?Cdm0410@013@d<0?Shn03lo?`0n?Sh203dm?@<0>c/k0P0l?3`203lo?`0C03/k
>`0n?Sh0>SXj03Ti>@0o?cl0@D5103Xj>P0n?Sh0?Cdm03hn?P0m?Cd0>c/k03dm?@10@400>CTi04=3
@`0k>c/0>SXj03hn?P0203dm?@0803/k>`0m?Cd0?Cdm03lo?`10@400?clo03hn?P0o?cl204A4A004
03hn?P17AdL0?3`l03lo?`80?Cdm00<0?clo0451@@0m?Cd00P11@D404`0o?cl0@41004=3@`0o?cl0
?Shn03lo?`0n?Sh0?Cdm03hn?P0m?Cd0?Shn0410@00l?3`0?clo0492@P0l?3`0ADE504Q8B013@d<0
0P0o?cl02@0n?Sh0@T9203hn?P0m?Cd0@41003dm?@10@400?Cdm03hn?P0203lo?`0303dm?@0i>CT0
@D510080?Shn0P0j>SX02@0o?cl0@d=303`l?00m?Cd0?Shn03dm?@0i>CT0>c/k03hn?P0203lo?`04
03`l?00n?Sh0>SXj03/k>`80?clo00/0?Shn03dm?@0m?Cd0?clo03hn?P0l?3`0>SXj03`l?00n?Sh0
@d=303`l?0020410@00504I6AP15ADD0?clo03hn?P0m?Cd00`10@4001`0l?3`0@4100492@P0k>c/0
?Cdm03Xj>P11@D400P0l?3`0<`0k>c/0?clo03lo?`0j>SX0?3`l03hn?P0f=SH0?Cdm04A4A01:BTX0
Bd];03lo?`0l?3`0?Cdm03Xj>P0m?Cd0@41003`l?00n?Sh0>SXj03dm?@0n?Sh0?3`l0410@00j>SX0
?clo03Ti>@0m?Cd0>SXj03dm?@0l?3`0?Cdm03lo?`0m?Cd0>SXj04E5A@1MGEd0O7al09nOW`2LW9`0
TY:B071`L01HF5P0ADE503`l?00o?cl0?3`l03dm?@13@d<0@D5103hn?P0203`l?00c03dm?@13@d<0
@41003hn?P11@D40@41003hn?P12@T80@D5104=3@`1:BTX0KFe]09:BTP2][Jd0];Bd0;Zj^P30`<00
SHf=06IVIP1iNGT0Ogmo08N7Q`2;Rh/0SHf=096AT@2JVYX0S8b<08Z:RP2?Shl0SHf=08R8R02;Rh/0
RHV90:b/[038b<P0/[:b0861P@20P800WYjN0:BTY02_[jl0[Zj^0:VYZ@2][Jd0YJFU07IfMP1DE5@0
G5aL05iNGP1TI6@0H61P0080IfMW01/0IFEU07=cL`1mOGd0P82009BDU02UYJD0Y:BT09NGU`23Ph<0
Lg=c05]KF`1UIFD0aLG50=?Cd`3=cLd0_Kfm09nOW`1]KFd0G5aL07MgM`1fMWH0Ph>307IfMP1XJ6P0
IVIV065QH@1JFUX00P1GEeL08@1UIFD0Lg=c07emO@2>SXh0R8R80:VYZ@35aLD0`/;208Z:RP2RXZ80
^;Rh0;Ng]`2RXZ80MGEe06YZJP1`L700Hf=S05aLG01gMgL0WYjN0;Rh^034a<@0e=CD0=?Cd`36a/H0
^KVi0;Rh^02XZ:P0YJFU0:RXZ03>c/h0eMGE0=cLg0020>3Ph00:0=7Ad@2l_;`0Q8B405ADE00n?Sh0
>SXj03Lg=`0i>CT0>SXj03Ph>080>CTi00<0>3Ph03Ti>@0e=CD00P0e=CD0200h>3P0=CDe03Hf=P0h
>3P0=3@d03Lg=`0e=CD0>CTi0P0h>3P02P0j>SX0=CDe03Ph>01EEED0W9bL0::RXP1TI6@0@T9203`l
?00j>SX203Hf=P80=CDe00l0=SHf03<c<`0f=SH0=CDe03Ph>00i>CT0=SHf03Lg=`0n?Sh0DE5A04i>
CP0m?Cd0A4A407EeM@2`/;003Oooool0013ooooo0100GemO069RHP1DE5@0Bd];04i>CP19BDT0CTi>
04Q8B016ATH0AdM704U9B@1;Bd/0B4Q804];B`16ATH0B4Q80P16ATH204Q8B00504I6AP14A4@0BTY:
04M7A`18B4P00P14A4@02`16ATH0B4Q804Q8B016ATH0ADE505eMG@18B4P0BTY:04Q8B015ADD0@d=3
0080BDU900/0A4A40451@@17AdL0ADE50492@P13@d<0ADE50492@P15ADD0@T9204=3@`020492@P0:
03lo?`11@D40BTY:04Q8B01:BTX0DE5A0410@00n?Sh0ATI604e=C@<0@D5100D0ATI60492@P12@T80
?clo03`l?00203hn?P0504I6AP12@T80@41004=3@`12@T800P10@4020451@@070492@P10@400@410
0492@P0l?3`0?Cdm03/k>`0203`l?00303hn?P13@d<0A4A40080?3`l00<0?Shn0451@@0n?Sh00`0m
?Cd05011@D40>c/k03dm?@10@400?clo0492@P11@D40?Shn03dm?@0o?cl0>CTi0451@@0l?3`0@410
03hn?P0o?cl0@41003dm?@10@400@D510P0n?Sh0200m?Cd0?3`l03Xj>P10@400A4A40492@P0o?cl0
@T920P0m?Cd02@0j>SX0?clo0492@P0l?3`0?Shn0410@00n?Sh0?clo03`l?00203lo?`050492@P0m
?Cd0@41004M7A`10@4000P0n?Sh01@10@400ATI603dm?@0m?Cd0?3`l0080?Cdm00T0?Shn03lo?`0o
?cl0@T9203`l?00o?cl0@41003lo?`0m?Cd00P0n?Sh01010@400@d=30492@P15ADD20492@P80@410
00L0?clo03`l?00l?3`0?clo03hn?P0j>SX0?3`l0080>c/k0P0n?Sh303lo?`80>c/k0P0n?Sh03P0i
>CT0?Shn0410@010@400@D5103lo?`11@D40ATI60492@P0o?cl0?Cdm03/k>`0l?3`0?Cdm0P0o?cl0
1`0h>3P0?3`l03dm?@10@400@D5103Xj>P0l?3`00P0n?Sh00`0k>c/0@4100451@@0203Xj>P0D03lo
?`12@T80?Shn03hn?P0o?cl0@T920451@@14A4@0>c/k03`l?00o?cl0?Shn03`l?00k>c/0>SXj03lo
?`0m?Cd0>SXj03hn?P0k>c/203Ph>00?03`l?00g=cL0?3`l03`l?00k>c/0=SHf03Ph>00m?Cd0>c/k
03hn?P10@400?3`l03lo?`0j>SX0?3`l0080?Cdm00h0>c/k03`l?010@400@41003Ti>@0k>c/0>3Ph
03hn?P0j>SX0?clo03/k>`0o?cl0@d=304e=C@80Fe]K01d0E5AD04U9B@13@d<0?Shn03`l?00k>c/0
@T9203dm?@11@D40?Cdm03hn?P12@T80@D5103`l?00i>CT0>c/k03`l?00m?Cd0?Shn03/k>`13@d<0
?Cdm03hn?P1KFe/0L71`0861P@1jNWX0PX:208n?S`0208Z:RP0D07moO`1jNWX0U9BD09FEU@24Q8@0
MGEe06MWI`1^KVh0Ogmo09RHV02a/K40b/[:0<_;b`30`<00_[jn0<_;b`3Kfm/0iNGU0>3Ph03>c/h2
0<C4a00n0;Jf]P2XZ:P0[jn_0;6a/@2XZ:P0T92@07inOP1ZJVX0F5QH04i>CP1GEeL0CTi>05YJFP1F
EUH0De=C05UIF@1QHF40GemO069RHP1YJFT0LG5a09RHV02d];@0XZ:R08b<S01oOgl0RXZ:0;Rh^03:
b/X0a<C40;^k^`2PX:00MgMg07YjNP2b/[80_Kfm0<O7a`33`l<0]KFe071`L01LG5`0E5AD06EUI@1e
MGD0OGem08J6QP2;Rh/0N7Qh07IfMP1cLg<0NGUi07QhN01gMgL0U9BD08N7Q`1dM7@0IfMW06e]K@1h
N7P0HV9R06QXJ02FUYH20;Rh^00D0;Ng]`38b<P0^k^k0:JVYP1jNWX0GEeM05EEE@17AdL0B4Q805UI
F@2GUiL0bl_;0;bl_02JVYX0LW9b05UIF@1<C4`0?clo03`l?010@40203`l?00503/k>`0i>CT0?Cdm
03`l?00k>c/00P0m?Cd02@0i>CT0=CDe03`l?00j>SX0>c/k03Ph>00e=CD0=cLg03/k>`0203Ti>@09
03Xj>P0h>3P0>SXj03Ti>@0g=cL0@41004];B`0m?Cd0>3Ph00<0>CTi00D0=cLg03Hf=P0g=cL0=CDe
03@d=00203De=@0<03<c<`0e=CD0=cLg03Lg=`0f=SH0=cLg03Ti>@0o?cl0Kfm_0;Ng]`3@d=00_;bl
3Oooool0013ooooo0P1BDU803P1>CTh0Bd];04a<C018B4P0BDU904Y:BP1<C4`0AdM704U9B@18B4P0
Bd];04a<C01:BTX0BDU91016ATH03@1:BTX0BDU904Q8B016ATH0A4A404I6AP18B4P0BDU904M7A`18
B4P0A4A404I6AP1?Cdl00P14A4@03`16ATH0DE5A04M7A`15ADD0?Shn0451@@13@d<0ATI604U9B@16
ATH0@D5104=3@`12@T80@d=30492@P020410@00=04A4A012@T80ADE50410@00o?cl0EeMG05EEE@16
ATH0?clo03dm?@12@T80?clo04=3@`020451@@0303hn?P10@400@D510080?clo00H0?3`l0451@@10
@400@d=304A4A010@40203lo?`090492@P11@D40?clo03lo?`0m?Cd0?Shn03dm?@0n?Sh0>SXj00<0
?Cdm00X0@D5103hn?P0j>SX0@41003`l?013@d<0?Cdm03hn?P0m?Cd0>c/k0P0l?3`203hn?P090410
@014A4@0?clo03Xj>P0k>c/0@T920451@@10@400@D5100@0?Shn00<0?3`l03hn?P0n?Sh00P0l?3`6
03/k>`0;0410@015ADD0?3`l03`l?00i>CT0>SXj03`l?00j>SX0?Shn03dm?@0k>c/00`0l?3`04@0j
>SX0>c/k03dm?@11@D40@T9204A4A013@d<0@41003dm?@0o?cl0>c/k03Ti>@0l?3`0?clo0451@@0k
>c/0?3`l0080?Shn00D0?3`l03dm?@0m?Cd0?Cdm03`l?00203dm?@0703hn?P0o?cl0@41003dm?@10
@400?clo0492@P0303lo?`80?3`l0P0k>c/02@0l?3`0?Cdm03Xj>P0l?3`0@41004A4A00m?Cd0>SXj
03`l?00203hn?P0903/k>`0m?Cd0@41003`l?00n?Sh0?Cdm03`l?011@D40?3`l00<0?Cdm0P0j>SX2
03dm?@050451@@0n?Sh0?3`l03/k>`0f=SH00P0k>c/02`10@400?clo0410@00j>SX0?Cdm03hn?P0m
?Cd0?3`l03/k>`0n?Sh0>3Ph0080?3`l00X0?clo03`l?00m?Cd0>SXj03/k>`0m?Cd0>c/k03Ti>@0k
>c/0?3`l0P0n?Sh20410@00803hn?P0j>SX0>CTi03Ti>@0k>c/0>CTi03Ph>00j>SX203Ti>@070410
@00h>3P0>c/k03lo?`0n?Sh0?clo03/k>`020410@00603`l?00m?Cd0>SXj03dm?@0j>SX0@d=30P0m
?Cd20410@00403`l?00k>c/0@d=303lo?`<0>c/k01L0@D5103dm?@0o?cl0>c/k03lo?`10@400>SXj
03Ti>@0n?Sh0@41003hn?P0l?3`0>c/k0451@@0o?cl0>c/k03hn?P0k>c/0>SXj03/k>`0o?cl0F5QH
09>CT`020<c<c0100;Ng]`2VYZH0R8R807EeM@1ZJVX0GemO04m?C`1>CTh0B4Q80410@013@d<0ADE5
05mOG`2:RXX0[jn_0<[:bP2^[Zh0X:2P0:6QX@2PX:00WYjN0:JVYP2[Zj/0Y:BT09nOW`2c/k<0`L71
0;^k^`2b/[80W9bL07inOP1gMgL0IfMW061PH01UIFD0H61P05iNGP1RHV80EUIF04Q8B016ATH0B4Q8
059BDP1dM7@0MGEe0861P@1lO7`0Ph>309FEU@2YZJT0^k^k0<?3``3;bl/0^[Zj0:j^[P2f][H0];Bd
0<G5a@3;bl/0_;bl0:ZZZP1gMgL0CTi>069RHP80IfMW00L0Hf=S05YJFP1VIVH0E5AD0820P02o_kl0
g]kN0080fm_K02`0dm?C0<c<c02c/k<0Ph>306ATI01VIVH0S8b<09NGU`2][Jd0VYZJ07emO@1hN7P0
Rh^;09VIV@2LW9`0YjNW0;2`/03;bl/0/k>c0:NWY`2VYZH0Y:BT0:ZZZP2UYJD0Ogmo079bLP1jNWX0
Ti>C0:^[Z`2HV9P0I6AT05QHF01QHF40JVYZ07UiN@25QHD0Ogmo07UiN@23Ph<0Ogmo07EeM@1XJ6P0
EUIF04A4A080ADE500<0JFUY05ADE019BDT00P0j>SX01`0k>c/0?3`l03Ti>@0g=cL0>3Ph03Ti>@0h
>3P00P0f=SH203Lg=`0<0492@P1>CTh0>3Ph03Hf=P0g=cL0=SHf03Lg=`0e=CD0<c<c03De=@0i>CT0
>3Ph0P0e=CD303Lg=`0903Hf=P0i>CT0>CTi04m?C`1oOgl0Z:RX09fMW@1`L700ADE500gooooo000@
ooooo`0704i>CP1?Cdl0Cdm?04a<C01;Bd/0C4a<04];B`0204Y:BP0<04];B`17AdL0ATI604M7A`16
ATH0BDU904Q8B016ATH0B4Q804M7A`15ADD0B4Q80P19BDT01P18B4P0A4A404E5A@15ADD0ATI604M7
A`<0ATI60`13@d<05@14A4@0ATI604I6AP18B4P0ATI60492@P14A4@0B4Q804Y:BP15ADD0@d=304I6
AP12@T80@d=304I6AP12@T80@4100451@@14A4@0@D5104=3@`020410@00E0451@@14A4@0?Shn03lo
?`0m?Cd0B4Q804A4A00o?cl0@d=30451@@0m?Cd0@d=30451@@13@d<0?3`l03Ti>@0n?Sh0@T920451
@@12@T80A4A40080ADE500D0A4A40492@P0m?Cd0?3`l03dm?@020451@@<0?Shn00<0?Cdm03hn?P0l
?3`00`0l?3`403/k>`0403Xj>P11@D40?Shn03dm?@80@41000X0?Shn03`l?00l?3`0?Shn03dm?@10
@400?Shn04=3@`10@400@D510P0o?cl20492@P0803dm?@0k>c/0>c/k03dm?@0o?cl0?Shn03Ph>00i
>CT203dm?@0303`l?00i>CT0>SXj0080>SXj00P0?3`l03/k>`0o?cl0?Cdm03hn?P0l?3`0?clo03`l
?080>c/k0`0o?cl01010@400?clo03lo?`0m?Cd20451@@0303dm?@10@400?Cdm0080?Cdm00H0?3`l
0410@010@400@41004E5A@11@D4203`l?00;03dm?@0l?3`0?Cdm0410@014A4@0@T9203lo?`0l?3`0
@T920410@00m?Cd00P0n?Sh0200o?cl0@D5103lo?`0j>SX0?3`l03Lg=`0j>SX0?3`l0P11@D401@0n
?Sh0?Cdm03lo?`0m?Cd0>SXj0080?Cdm0P0n?Sh00`15ADD0@T9203`l?00203dm?@0703/k>`0n?Sh0
?clo03`l?00o?cl0?Shn04A4A00203hn?P0=03lo?`0n?Sh0>c/k03Ti>@14A4@0?Shn03dm?@0j>SX0
?clo0410@00m?Cd0?3`l03hn?P0203Ti>@80?3`l00<0?Shn03Xj>P0i>CT00P0l?3`203/k>`0;03dm
?@0l?3`0>c/k03`l?00i>CT0@41003dm?@0l?3`0?clo0410@00m?Cd00`0j>SX0300g=cL0>CTi03dm
?@0j>SX0>CTi03/k>`0l?3`0?Shn03/k>`0l?3`0@d=30410@080?3`l01D0>CTi03`l?00m?Cd0?clo
03Xj>P0l?3`0?Shn03Ph>00n?Sh0?Cdm03lo?`0l?3`0>c/k03lo?`0k>c/0?3`l03dm?@0k>c/0@T92
03dm?@11@D400P0m?Cd05@0i>CT0@41003/k>`0j>SX0A4A40410@00k>c/0?3`l03hn?P0k>c/0?Shn
04m?C`1lO7`0[Jf]0;Jf]P2FUYH0MGEe069RHP19BDT0@d=303`l?0020451@@0T0410@011@D40@T92
04];B`1HF5P0Jf][0820P02RXZ80[jn_09>CT`1ZJVX0JFUY06YZJP1SHf<0KVi^07moO`2<S8`0ZZZZ
0;Zj^P2f][H0WYjN09bLW02YZJT0_;bl0;fm_@2/[:`0TY:B08N7Q`1jNWX0Ph>30:j^[P2n_[h0/;2`
09nOW`2SXj<0[:b/0P2l_;`01@2h^;P0^[Zj0<G5a@38b<P0`l?30080^[Zj00D0^k^k0<C4a02_[jl0
T92@0:BTY0020:^[Z`0Z0:RXZ02GUiL0PH6106m_K`1TI6@0D51@05ADE01FEUH0B4Q804m?C`17AdL0
BTY:0:JVYP3Fe]H0g]kN0=OGe`3:b/X0gMgM0=oOg`3Jf]X0d];B0:j^[P2;Rh/0Ng]k07IfMP2<S8`0
YZJV096AT@1_Kfl0G5aL07emO@2HV9P0UiNG07inOP1aLG40QHF50:2PX02EUID0YJFU0;>c/`33`l<0
gMgM0P3Ng]h09@3GemL0`L710<71`@2k^k/0XZ:R0;Ng]`34a<@0^[Zj0;jn_P2^[Zh0a<C40=kNgP3L
g=`0clo?0<?3``2n_[h0_kno0;bl_036a/H0fm_K0;fm_@2PX:00T92@09>CT`2;Rh/0Q8B407emO@1U
IFD0ADE503Ph>00g=cL0>c/k03Ph>00f=SH0=3@d05YJFP1<C4`00`0g=cL503@d=00403De=@0d=3@0
=3@d03Lg=`80<c<c00P0=CDe03Lg=`0i>CT0Bd];07moO`1dM7@0DU9B03/k>`80>CTi3Oooool0013o
oooo00l0CTi>055AD@1ADE40Cdm?04e=C@1>CTh0Cdm?04e=C@1JFUX0B4Q804U9B@1:BTX0BDU904E5
A@19BDT00P16ATH01`1:BTX0Bd];04I6AP17AdL0BDU904I6AP18B4P00P17AdL204E5A@0704I6AP14
A4@0BTY:04A4A015ADD0BDU904I6AP0204U9B@0504m?C`18B4P0A4A404I6AP12@T800P15ADD09`18
B4P0@D5104Y:BP14A4@0BDU904A4A015ADD0@d=30451@@17AdL0@D5104=3@`17AdL0@T9203lo?`10
@400@d=30451@@14A4@0Bd];0451@@12@T80?Cdm04=3@`0o?cl0?Shn04E5A@1:BTX0@D5104I6AP14
A4@0@T9204I6AP13@d<0@T9204A4A016ATH0A4A40410@00203hn?P0503`l?010@400?Shn03lo?`0m
?Cd00P0n?Sh01@0l?3`0?Shn03/k>`0n?Sh0?3`l00<0>c/k00l0?Cdm03lo?`0m?Cd0?3`l03/k>`11
@D40@41003lo?`14A4@0@D5104=3@`0l?3`0@T9203hn?P12@T800P0n?Sh0400o?cl0?Shn04A4A014
A4@0?clo03hn?P0l?3`0?Cdm03`l?00m?Cd0>CTi03/k>`10@400?Cdm03Xj>P0k>c/203dm?@0G03Xj
>P0l?3`0>SXj03`l?00k>c/0?Shn03Xj>P0m?Cd0>SXj03hn?P0l?3`0?Shn03Ph>00o?cl0?3`l0410
@00l?3`0?clo0492@P10@400@D5104A4A00n?Sh00P0l?3`203/k>`040451@@0l?3`0@T9203lo?`<0
?Shn00X0?3`l03dm?@0n?Sh0?Cdm0451@@0l?3`0>c/k03dm?@11@D40@4100P0l?3`0100m?Cd0?3`l
03`l?00h>3P203`l?00>0451@@0l?3`0?Shn0451@@10@400?Shn03lo?`0m?Cd0>SXj0410@00m?Cd0
?Shn04U9B@12@T8203dm?@0303/k>`0i>CT0>SXj0080?clo00h0@T9203dm?@0j>SX0>c/k0410@00o
?cl0?Cdm0410@012@T80@4100492@P13@d<0?clo03Ti>@80?3`l00d0?Cdm04i>CP0j>SX0>CTi03Ph
>00j>SX0>CTi03/k>`0h>3P0=cLg03dm?@0h>3P0>c/k0080?Shn00X0?Cdm03/k>`0o?cl0>c/k03hn
?P0m?Cd0>c/k03Xj>P0k>c/0>3Ph0P0j>SX04@0l?3`0>CTi03Ti>@0i>CT0>SXj03/k>`14A4@0?Shn
03lo?`0j>SX0?Cdm04=3@`0n?Sh0?3`l03Xj>P0i>CT0=cLg0080>c/k0100>CTi03Xj>P0k>c/0=cLg
03/k>`0m?Cd0@d=30492@P10@400?Shn03/k>`10@400>CTi03/k>`0m?Cd0?3`l0P0n?Sh04@0k>c/0
?3`l03lo?`0m?Cd0>SXj03dm?@11@D40?3`l03Ph>00l?3`0?clo04Q8B01CDe<0IfMW06=SH`1=CDd0
@d=30080@T9200D0@D5103lo?`12@T80?Shn0410@00204E5A@0^05iNGP1ZJVX0J6QX05iNGP1@D500
ADE504=3@`10@400@d=304Q8B01WIfL0Lg=c09FEU@2KVi/0O7al07inOP21PH40Rh^;08F5Q@1jNWX0
IVIV065QH@1HF5P0Cdm?04I6AP14A4@0?clo04=3@`1<C4`0De=C05]KF`1SHf<0GUiN069RHP1PH600
GemO05aLG01IFET0FUYJ05QHF01MGEd0FUYJ069RHP1/K6`0N7Qh08f=S@80Ti>C0180QhN708Z:RP2<
S8`0UYJF0:JVYP2i^KT0b/[:0<30`02:RXX0Lg=c06a/K01hN7P0Ph>307moO`1fMWH0TI6A09JFUP2g
]kL20:BTY0050;Vi^@3?cll0gmoO0=KFeP2e]KD00P2n_[h07P2`/;00][Jf0:VYZ@2g]kL0[Jf]09ZJ
VP21PH40M7Ad07QhN01fMWH0JFUY06QXJ01YJFT0MGEe08f=S@2?Shl0[Zj^0<C4a036a/H0`L710;6a
/@39bLT0gMgM0>7Qh@3Rh^80hN7Q0>3Ph03Shn<0f][J0=oOg`80gMgM00<0dm?C0<?3``38b<P00P2e
]KD04P3@d=00emOG0=;BdP3;bl/0b/[:0=gMg@3Ti>@0gmoO0=WIf@39bLT0YjNW06e]K@10@400>CTi
03Lg=`0a<C40>3Ph03/k>`80=SHf0P0d=3@303Hf=P0303De=@0d=3@0=3@d0080=SHf00/0<c<c03@d
=00d=3@0=CDe03Ph>01>CTh0HF5Q05=CD`0h>3P0=CDe03Ph>00203Lg=`gooooo000@ooooo`0I051@
D024Q8@0Rh^;09^KV`22PX80KFe]061PH01IFET0D51@04a<C01=CDd0C4a<04M7A`19BDT0B4Q804U9
B@17AdL0Bd];04e=C@1;Bd/0AdM704i>CP17AdL0ATI604U9B@0204M7A`0F04E5A@18B4P0BDU904U9
B@18B4P0ADE504=3@`17AdL0@T9204M7A`18B4P0@T9204=3@`17AdL0@D5104A4A012@T80ADE50451
@@15ADD0B4Q804A4A0<0@41000T0@T9204E5A@12@T80@d=304U9B@13@d<0BDU90492@P14A4@00P15
ADD07`10@400@T920451@@0m?Cd0@d=303lo?`14A4@0@D510410@017AdL0BTY:04A4A016ATH0@d=3
04I6AP13@d<0?Cdm03lo?`14A4@0@41003`l?010@400?clo04=3@`10@400>c/k03`l?00m?Cd0@410
03`l?00n?Sh00P0l?3`01@0n?Sh0?Cdm03dm?@0o?cl0@T920080@4100P0m?Cd03`0k>c/0?Cdm03hn
?P14A4@0@D5104E5A@0o?cl0A4A403hn?P12@T80@D5103`l?00j>SX0?Shn03/k>`020410@00903`l
?00m?Cd0?3`l03Xj>P0n?Sh0>SXj03dm?@0i>CT0?Shn0080?Cdm00T0?3`l03dm?@0k>c/0?3`l03dm
?@0k>c/0>SXj03`l?00o?cl00P0n?Sh20451@@0?0492@P0k>c/0?3`l03hn?P12@T80?clo03hn?P13
@d<0@D5104=3@`0o?cl0A4A404I6AP11@D40?clo0080?Cdm00l0>3Ph03dm?@10@400?clo03/k>`0o
?cl0@D5103lo?`11@D40@4100492@P0n?Sh0?3`l03hn?P0o?cl00P0n?Sh01010@400?3`l03dm?@0l
?3`203Xj>P0?03dm?@0l?3`0?Shn0492@P0n?Sh0?clo03dm?@10@400?clo0410@01ADE40C4a<04U9
B@14A4@0?Cdm0080?clo0P0m?Cd04P0n?Sh0@D510410@00n?Sh0?Cdm0410@00l?3`0>SXj03Ti>@0l
?3`0@D5103`l?00n?Sh0?clo03hn?P0l?3`0?Shn03`l?080>c/k00X0?Shn03dm?@0m?Cd0>c/k03Xj
>P0h>3P0?3`l03Lg=`0l?3`0>SXj0P0l?3`00`0n?Sh0?Cdm03Xj>P0203`l?00603dm?@0k>c/0?Cdm
03`l?00i>CT0?3`l0P0k>c/03`0j>SX0>c/k03`l?00h>3P0>SXj03dm?@11@D40@d=303dm?@0k>c/0
?Shn03dm?@0j>SX0?3`l0451@@0203Xj>P0:03/k>`0n?Sh0>c/k03/k>`0l?3`0@T9204a<C013@d<0
A4A404M7A`<0?Cdm00<0@41003/k>`0j>SX00P0l?3`203dm?@030410@00k>c/0>CTi0080?3`l00@0
@D5103Xj>P0o?cl0@4100`0n?Sh00`14A4@0AdM704A4A00204M7A`0804=3@`10@400@41003/k>`0n
?Sh0@D5103/k>`11@D4204=3@`030451@@13@d<0?clo0080@4100140ATI605UIF@1TI6@0N7Qh08J6
QP2GUiL0RXZ:09BDU021PH40O7al05]KF`1CDe<0@d=30410@015ADD0>SXj0451@@0203`l?080?clo
00X0?Shn0451@@0k>c/0?clo03hn?P11@D40@41003hn?P10@400?clo0P0n?Sh07@11@D40AdM704e=
C@1BDU80KVi^07UiN@20P800QhN70:2PX02c/k<0^;Rh0;bl_02k^k/0a<C40<W9b@3AdM40f][J0=oO
g`3MgMd0hN7Q0=OGe`38b<P0XZ:R09>CT`2KVi/0T92@0:VYZ@2[Zj/0TI6A0080L71`03@0IFEU09FE
U@2SXj<0UiNG0:ZZZP2GUiL0VYZJ09fMW@1aLG40JVYZ08V9R@2ATI40V9RH0:2PX02_[jl0/k>c09fM
W@2@T900LW9b059BDP1eMGD0WYjN0;bl_03=cLd0clo?0<[:bP33`l<0^[Zj0<?3``3=cLd0f=SH0=[J
fP3GemL0gMgM0>;RhP3AdM40ZZZZ0;bl_02o_kl0Zj^[0<_;b`3Bd]80]KFe0<71`@2l_;`0^k^k0<;2
`P34a<@0cLg=0=GEe@31`L40PH610P1VIVH02`1jNWX0IFEU03Ti>@0e=CD0=SHf03Ti>@13@d<0CDe=
03Hf=P0d=3@0=CDe00@0=cLg00d0=SHf03@d=00g=cL0>3Ph03De=@0g=cL0=CDe03Lg=`0m?Cd0>CTi
03Xj>P0f=SH0=cLg00@0>3Ph3Oooool0013ooooo0200VYZJ08:2PP1aLG40PX:208j>SP2^[Zh0^[Zj
0:^[Z`2a/K40Xj>S07]kN`1SHf<0Cdm?04e=C@1<C4`0FEUI065QH@1NGUh0Hf=S05aLG01BDU80DE5A
04Y:BP14A4@0B4Q804M7A`15ADD0BDU904];B`17AdL0BTY:04I6AP<0B4Q80P15ADD03@13@d<0ADE5
04=3@`15ADD0A4A404=3@`10@400A4A404=3@`14A4@0C4a<04E5A@14A4@00P13@d<02`12@T80@410
0492@P15ADD0CTi>04I6AP15ADD0@d=30451@@18B4P0A4A40080@T9200<0@41003`l?00k>c/00P12
@T80100o?cl0ATI604M7A`11@D420410@00;0451@@13@d<0@T9204=3@`11@D40@41003dm?@0l?3`0
>c/k03hn?P0m?Cd00P0n?Sh01P0l?3`0>CTi03/k>`0k>c/0@D510410@080>c/k01H0>SXj03lo?`0n
?Sh0?clo03/k>`15ADD0A4A403/k>`0j>SX0?Cdm03Xj>P0m?Cd0?clo0451@@10@400@d=303lo?`0m
?Cd0@41003/k>`0l?3`0@d=30P0m?Cd303hn?P0D03dm?@0k>c/0?Shn03Xj>P0n?Sh0>c/k03`l?00k
>c/0=cLg03/k>`0o?cl0?3`l03dm?@0o?cl0?Shn03Xj>P0k>c/0?Cdm03hn?P0o?cl203dm?@0H03`l
?00m?Cd0?Shn0410@012@T80@4100492@P0k>c/0?Shn04M7A`10@400>c/k03dm?@0n?Sh0@D5103lo
?`13@d<0?Shn03Ti>@0n?Sh0?clo0410@011@D40?Cdm0`0o?cl03`0m?Cd0?clo03lo?`0o?cl0?Shn
03`l?00o?cl0@D5103hn?P18B4P0@41003/k>`0m?Cd0@41004=3@`0203dm?@0503Xj>P0n?Sh0A4A4
04E5A@10@4000P0n?Sh00`11@D40?Shn03`l?00203dm?@060492@P11@D40?clo03hn?P10@400?3`l
0P0n?Sh01@0k>c/0?Cdm03`l?011@D40@d=30080@41000/0?3`l03hn?P0m?Cd0@41004=3@`12@T80
?Cdm03`l?014A4@0>c/k03hn?P0203dm?@0603Ph>00n?Sh0?3`l03`l?00n?Sh0>c/k0`0l?3`06P0m
?Cd0?clo03`l?011@D40@41003/k>`0j>SX0>3Ph03Xj>P0i>CT0@D5103Xj>P0k>c/0?3`l03Xj>P0h
>3P0>CTi03dm?@0j>SX0=SHf03Xj>P0i>CT0?3`l03Xj>P0m?Cd0@4100P0o?cl03011@D40?3`l03hn
?P13@d<0?Cdm0451@@14A4@0@D5103Ph>00o?cl0>SXj0410@080?Cdm00X0?3`l03Ti>@0j>SX0?Cdm
03hn?P0k>c/0@41003/k>`0l?3`0@4100P0l?3`0300m?Cd0@41003hn?P0k>c/0@41005YJFP1_Kfl0
PH610820P01`L700BTY:03`l?080@41000/0CTi>04=3@`0l?3`0ADE503dm?@13@d<0ATI604m?C`1K
Fe/0IFEU07inOP020:^[Z`030:RXZ02IVIT0SXj>0080R8R800h0KVi^05IFEP13@d<0@41003dm?@0o
?cl0?3`l03dm?@11@D40?clo03`l?00m?Cd0?3`l03hn?P80?3`l0P0m?Cd02@0l?3`0?Cdm03Ti>@14
A4@0@D5103lo?`10@400?Shn0451@@0204U9B@0X0492@P14A4@0AdM704E5A@17AdL0BTY:05IFEP1V
IVH0LW9b07emO@27QhL0UYJF09RHV02GUiL0X:2P0;2`/02l_;`0cLg=0=gMg@3EeMD0bLW90;^k^`2Q
XJ40KVi^06MWI`20P800V9RH09BDU01kNg/0NWYj06e]K@1OGel0J6QX07inOP1lO7`0UYJF0;Fe]@2f
][H0ZZZZ0:NWY`80UiNG03D0QXJ6069RHP1FEUH0Kfm_0::RXP2XZ:P0R8R8069RHP1PH600MgMg09ZJ
VP2YZJT0_kno0;Bd]02SXj<0OGem071`L01jNWX0SXj>0:b/[02d];@0f][J0<W9b@2^[Zh0^KVi0;bl
_02[Zj/0ZJVY0<G5a@37alL0^[Zj09fMW@1TI6@0BTY:04U9B@1QHF40PX:209JFUP2>SXh0Cdm?03Hf
=P0m?Cd0@4100451@@17AdL0>c/k0410@01hN7P0OGem03/k>`0j>SX0=cLg03Xj>P0203Ph>00703Ti
>@0g=cL0>CTi03Lg=`0e=CD0=cLg03Ph>00203Hf=P090410@00i>CT0>SXj03Lg=`0f=SH0=CDe03Hf
=P0g=cL0>3Ph00gooooo000@ooooo`0M0<;2`P2o_kl0_;bl0;Bd]02[Zj/0ZZZZ0;no_`3?cll0bLW9
0;Ng]`2CTi<0MgMg05YJFP1@D500Lg=c08j>SP2][Jd0^KVi0;Ng]`2`/;00Zj^[09>CT`1cLg<0Jf][
05ADE019BDT0B4Q804Y:BP17AdL00P1;Bd/01@16ATH0B4Q804M7A`1:BTX0A4A40080AdM700l0ATI6
0492@P13@d<0ADE504=3@`14A4@0ATI604M7A`14A4@0?clo04E5A@13@d<0@D5103lo?`11@D400P13
@d<01P12@T80@D5104A4A011@D40ADE504A4A080@41001D0@d=30492@P0m?Cd0@D5103`l?013@d<0
@D5104=3@`16ATH0@T9204M7A`12@T80?clo0492@P10@400AdM70410@013@d<0@D5103lo?`11@D40
0P0m?Cd02P0l?3`0>c/k03`l?00n?Sh0>c/k03hn?P0o?cl0A4A403dm?@10@4020492@P0803dm?@0n
?Sh0@d=303dm?@0n?Sh0@D5103dm?@0o?cl303hn?P0C03`l?00k>c/0?Cdm03hn?P0l?3`0@41003/k
>`0h>3P0>c/k0451@@0m?Cd0?clo03`l?00m?Cd0?3`l03/k>`0o?cl0@d=303dm?@0203`l?00603Xj
>P0l?3`0@D510451@@10@400?Shn100l?3`303/k>`80>CTi00<0>c/k03`l?00n?Sh00P0o?cl00`0n
?Sh0@D5103hn?P020410@080?Cdm00D0>c/k0451@@0n?Sh0@T920451@@0204A4A00903lo?`10@400
@41003hn?P11@D40?clo04=3@`10@400?clo0080@4100`0n?Sh04@0m?Cd0?Shn03lo?`0l?3`0@410
03hn?P10@400@d=303lo?`13@d<0@41004M7A`13@d<0?Shn0410@00o?cl0?Cdm0080@41000H0ADE5
0451@@0k>c/0>c/k03dm?@12@T8203lo?`0703/k>`0m?Cd0?Cdm03`l?00i>CT0?3`l03/k>`0203`l
?00503hn?P0l?3`0>3Ph03/k>`0n?Sh00P0l?3`203/k>`0303dm?@11@D40@T920080?clo00H0@410
03dm?@0k>c/0?Shn03`l?010@40203`l?0090451@@0n?Sh0?clo03dm?@0j>SX0?Shn0451@@0h>3P0
=SHf0080>3Ph00L0>SXj03Ti>@0j>SX0>SXj03`l?00h>3P0>SXj0080>3Ph00`0>CTi03Lg=`0m?Cd0
?Cdm04=3@`0g=cL0>3Ph03hn?P0o?cl0>SXj03lo?`0j>SX203dm?@0604=3@`0i>CT0?3`l03Xj>P0h
>3P0>SXj0P0n?Sh30410@080?Cdm01H0>3Ph0492@P10@400@4100492@P0m?Cd0?3`l03dm?@0n?Sh0
>SXj03hn?P1?Cdl0Hf=S07EeM@1dM7@0KVi^05mOG`1BDU80ATI603hn?P11@D40?Cdm0P0n?Sh05@17
AdL0?Shn03dm?@10@400?Cdm04];B`1=CDd0Hf=S08b<S02VYZH0bl_;0<C4a02ZZZX0VYZJ07AdM01D
E5@0@T9203lo?`10@400?3`l03/k>`0203`l?00V0410@00l?3`0?Shn03hn?P0k>c/0>SXj03hn?P0l
?3`0?Shn03`l?00k>c/0>SXj03hn?P10@400?Cdm0492@P0l?3`0?clo0451@@10@400@T9203`l?013
@d<0ATI604Q8B01<C4`0CTi>04m?C`1BDU80HF5Q06e]K@1dM7@0PX:209:BTP2TY:@0];Bd0<;2`P35
aLD20<c<c0130=GEe@3Bd]80][Jf07alO01aLG40MGEe07moO`2=SHd0TY:B09jNWP2LW9`0QhN709ZJ
VP2b/[80^KVi0:n_[`2d];@0/k>c09bLW02n_[h0b/[:0=_Kf`3Ph>00h^;R0=kNgP3Ti>@0inOW0=SH
f02f][H0TI6A06YZJP2WYjL0XJ6Q0;no_`33`l<0_Kfm0;Rh^02[Zj/0aLG50;no_`2h^;P0X:2P08b<
S027QhL0K6a/051@D01HF5P0N7Qh0861P@2GUiL0WIfM0:f][@2o_kl0`<300:ZZZP2`/;00^[Zj0<?3
``2k^k/0T92@07IfMP1JFUX0@d=304M7A`1_Kfl0QhN705ADE00203`l?00603/k>`13@d<0DE5A09JF
UP2ZZZX0H61P0P0i>CT00`0j>SX0>CTi03Ph>00303Lg=`80>CTi00h0<S8b03/k>`0n?Sh0?3`l03Ti
>@0g=cL0>CTi04E5A@0j>SX0=CDe03Hf=P0g=cL0>3Ph03Ti>@gooooo000@ooooo`0I09>CT`2OWil0
YjNW0<_;b`2XZ:P0Ng]k07moO`2^[Zh0dM7A0<;2`P2LW9`0T92@08V9R@1TI6@0GEeM055AD@1IFET0
L71`08>3P`1lO7`0Ph>309NGU`2TY:@0Vi^K07EeM@0206MWI`0904M7A`18B4P0Fe]K051@D016ATH0
B4Q804Y:BP1HF5P0BTY:0080CDe=0P16ATH204U9B@80B4Q80P16ATH204A4A0080492@P18B4P0CDe=
04E5A@13@d<0A4A403lo?`13@d<204A4A0060451@@14A4@0@d=304=3@`0n?Sh0?clo0P14A4@03@15
ADD0@41003hn?P13@d<0@T9204U9B@14A4@0ATI604E5A@0o?cl0@T9204E5A@11@D400P12@T802P14
A4@0@41003hn?P10@400>SXj03`l?00k>c/0?Cdm03lo?`0j>SX403`l?00903lo?`0l?3`0@41003lo
?`0j>SX0@41003lo?`0n?Sh0?Cdm0080@41000/0?clo03hn?P0k>c/0>CTi03`l?00m?Cd0>SXj03`l
?00m?Cd0>CTi03/k>`0303Xj>P0303lo?`0l?3`0?Shn0080?Cdm00/0?clo0492@P11@D40?clo03dm
?@0j>SX0>CTi03`l?00m?Cd0?3`l03/k>`0303Xj>P0@03hn?P0l?3`0?3`l03`l?00j>SX0>c/k03Ph
>00g=cL0>SXj03`l?00n?Sh0?Cdm03lo?`0l?3`0?Shn0451@@80?Cdm0P0l?3`02@10@400@D510451
@@10@400?Cdm03Xj>P0l?3`0@D5103hn?P020410@00303/k>`0l?3`0?3`l00<0?Cdm00@0@41003lo
?`0l?3`0?3`l0P10@400200h>3P0?Shn03lo?`17AdL0@41004I6AP11@D40?clo0P0m?Cd20451@@04
03`l?00n?Sh0?3`l03/k>`80?clo01<0?Cdm03/k>`0j>SX0?Cdm0451@@0m?Cd0>c/k03Ti>@0h>3P0
>c/k03Lg=`0h>3P0>c/k03Hf=P0i>CT0>3Ph03dm?@12@T80?3`l0080>SXj01<0>CTi03`l?012@T80
@D5104A4A00l?3`0?Cdm03Ph>00k>c/0>SXj03dm?@0n?Sh0A4A403`l?010@400=cLg03/k>`0n?Sh0
?3`l0080>CTi00P0>c/k03Ph>00h>3P0>SXj03Ti>@0j>SX0=SHf03Ph>080>c/k0P0h>3P203Xj>P<0
>3Ph00l0>SXj03dm?@0g=cL0>3Ph03dm?@0i>CT0>SXj03`l?012@T80@41003/k>`0n?Sh0>CTi0451
@@0d=3@00P0i>CT00`0m?Cd0>SXj03lo?`0203hn?P0I03/k>`0j>SX0?Shn03dm?@0o?cl0>CTi03/k
>`0i>CT0>c/k03lo?`1IFET0KVi^08F5Q@1gMgL0IfMW04e=C@12@T80?3`l03hn?P0l?3`0>3Ph03Xj
>P0l?3`0>c/k03hn?P0203/k>`0<03dm?@0j>SX0?Shn04M7A`1JFUX0H61P071`L01aLG40IFEU05IF
EP18B4P0ADE50P0o?cl00`11@D40?Cdm03Xj>P0203Xj>P80?Cdm00/0>CTi03Xj>P12@T80?Cdm03Ph
>00l?3`0?Cdm03Ph>00k>c/0?Shn03/k>`0203dm?@0;03lo?`14A4@0Cdm?05iNGP1eMGD0PX:207Yj
NP20P800W9bL0:NWY`2XZ:P00P2/[:`0H02b/[80/k>c0;:b/P2h^;P0_[jn0;fm_@32`/80alO70<W9
b@32`/80`<300;Jf]P2a/K40[jn_0:NWY`2DU9@0S8b<08R8R021PH40L71`06a/K01YJFT0JVYZ06e]
K@1lO7`0R8R80:>SX`2TY:@0XJ6Q0:NWY`2_[jl0_;bl0<?3``2e]KD0YjNW0:f][@2n_[h0^k^k0<[:
bP3EeMD0emOG0<W9b@38b<P0_kno0<;2`P2YZJT0];Bd0;Zj^P2VYZH0U9BD0:>SX`2l_;`0WIfM092@
T02YZJT0[Zj^0;Fe]@2b/[80[:b/09bLW02b/[80^KVi0:FUY@2>SXh0[Zj^0<G5a@2][Jd0^k^k0;Rh
^03;bl/0aLG50<;2`P2ZZZX0Y:BT0:b/[02k^k/0/k>c092@T02HV9P0NWYj09^KV`2l_;`0KFe]04e=
C@0j>SX0>c/k03Ti>@1:BTX0EeMG04m?C`0o?cl0>SXj03Ph>00k>c/0>SXj03Ti>@80=cLg00P0?Shn
05UIF@1]KFd0GEeM04Y:BP0i>CT0=CDe03Ph>0<0=cLg1@0f=SH=ooooo`004?ooool0901fMWH0Ng]k
07emO@2<S8`0ZJVY0:BTY02CTi<0WYjN0;Ng]`2@T900HV9R05mOG`1XJ6P0LG5a07moO`1]KFd0E5AD
05eMG@1[Jf/0L71`08f=S@37alL0bl_;0:JVYP2:RXX0KVi^07alO01kNg/0H61P04e=C@19BDT0B4Q8
04Y:BP1?Cdl0C4a<051@D080BTY:00@0B4Q804A4A016ATH0CDe=0P18B4P03P17AdL0A4A404=3@`18
B4P0@41004Y:BP1<C4`0@D5104A4A011@D40@d=30451@@10@400@D510P17AdL0100o?cl0>c/k0492
@P0l?3`203Ti>@0@0492@P0o?cl0?3`l03hn?P11@D40B4Q804A4A018B4P0ATI603dm?@10@400?3`l
04=3@`11@D40@T920410@080?clo01X0?Cdm03Ti>@0m?Cd0@T9203/k>`0o?cl0>CTi03`l?016ATH0
?Shn03/k>`0h>3P0?Shn03lo?`0n?Sh0>c/k03`l?011@D40?Cdm03/k>`11@D40>CTi0492@P0n?Sh0
>CTi03dm?@80?clo00D0>SXj03Lg=`0g=cL0?Shn03lo?`0203/k>`0403Xj>P10@400?Cdm03`l?0<0
?Cdm00h0>SXj03/k>`0l?3`0?3`l03dm?@0k>c/0?3`l03Ph>00j>SX0?3`l03dm?@0j>SX0>CTi03/k
>`80>3Ph00T0>SXj03Hf=P0h>3P0>SXj03/k>`0l?3`0?Cdm03`l?00k>c/00`0n?Sh01@0o?cl0>c/k
03/k>`11@D40?3`l0080@D5100@0?Cdm0410@00k>c/0>c/k0P0n?Sh03@0i>CT0>c/k03hn?P14A4@0
?clo03Xj>P0n?Sh0?3`l0410@00m?Cd0?clo0410@00l?3`00P0k>c/0600l?3`0>c/k03lo?`16ATH0
@D510410@00n?Sh0@D5103`l?00j>SX0?Shn03`l?011@D40?Shn03/k>`0j>SX0?Shn0410@00n?Sh0
?3`l03Ph>00m?Cd0@4100451@@80>CTi0140>SXj03hn?P0k>c/0>c/k03Ti>@0h>3P0>c/k0410@00m
?Cd0?3`l03Ph>00k>c/0?Cdm03/k>`0i>CT0?clo0451@@0203dm?@0>03/k>`0h>3P0?Shn03Xj>P0m
?Cd0?3`l03Xj>P0l?3`0>SXj03Lg=`0i>CT0@d=30451@@10@40303Xj>P0803Ph>00j>SX0>SXj03/k
>`0l?3`0>SXj03Ti>@0m?Cd203/k>`0;03Xj>P0m?Cd0>SXj03lo?`10@400>CTi03Xj>P0n?Sh0@D51
03Xj>P0k>c/00P0l?3`02`0j>SX0>CTi03hn?P0k>c/0>SXj03Ti>@0f=SH0?Shn03dm?@0j>SX0?Shn
0080@4100`0l?3`04@0o?cl0?3`l0410@011@D40?clo04=3@`1EEED0LG5a07]kN`1WIfL0Cdm?03dm
?@0o?cl0@41004A4A00l?3`0@d=30080>c/k01L0?Cdm03hn?P0i>CT0>SXj03dm?@0i>CT0?Shn05IF
EP1^KVh0PX:207QhN01JFUX0ATI604U9B@0o?cl0@41003`l?012@T80?Cdm0451@@0i>CT0>c/k03dm
?@020492@P0303/k>`0i>CT0=SHf0080?Shn02/0ATI603Xj>P0h>3P0@T9203/k>`0h>3P0?clo03hn
?P18B4P0GUiN07YjNP2VYZH0[:b/0:f][@2ZZZX0/k>c0:JVYP2MWId0YjNW0:ZZZP2HV9P0QHF5079b
LP1KFe/0GemO05ADE01BDU80CDe=04i>CP1KFe/0Hf=S06e]K@1dM7@0Q8B40820P02>SXh0UYJF08B4
Q01QHF40EUIF04];B`1BDU80D51@0080De=C0500FEUI04Y:BP13@d<0@D5104E5A@1:BTX0CDe=04];
B`1=CDd0M7Ad09^KV`35aLD0emOG0<S8b02TY:@0RXZ:09VIV@2e]KD0/[:b0:JVYP2?Shl0M7Ad06IV
IP1RHV80JVYZ07UiN@2IVIT0clo?0=SHf031`L40S8b<07]kN`24Q8@0T92@09nOW`3EeMD0fMWI0;>c
/`2/[:`0`L710:2PX02ZZZX0^k^k0<C4a037alL0aLG50;>c/`2b/[80/;2`0;Ng]`2o_kl0Y:BT08N7
Q`2?Shl0U9BD0:FUY@2j^[X0d=3@0=WIf@3Lg=`0bLW909BDU01=CDd0?3`l03Ti>@12@T80AdM706IV
IP1bLW80MWIf05]KF`0n?Sh0=CDe03Ph>00j>SX0Fe]K08n?S`1oOgl0LW9b03lo?`80=cLg00X0>3Ph
03Lg=`0c<c<0=CDe03@d=00e=CD0=3@d03Ph>00d=3@0>3Ph3Oooool0013ooooo02/0IFEU06e]K@23
Ph<0WinO0;Bd]03;bl/0[Zj^071`L01eMGD0H61P05QHF01RHV80SXj>0:NWY`2^[Zh0Ti>C07YjNP1a
LG40MgMg08:2PP28R8P0W9bL0:BTY023Ph<0QHF507=cL`2@T900][Jf0;Zj^P2c/k<0TY:B08b<S02H
V9P0Xj>S09^KV`1fMWH0IfMW04Y:BP1@D500A4A404Q8B01<C4`0ADE50080A4A400@0Bd];04I6AP17
AdL0BDU90P14A4@07P16ATH0@D510410@013@d<0A4A40492@P0n?Sh0ATI60451@@10@400?Shn0410
@00o?cl0BDU903hn?P11@D40B4Q804];B`14A4@0?3`l03lo?`12@T80@d=304M7A`13@d<0@D5103hn
?P12@T80@41003lo?`80@D5100H0A4A40451@@0k>c/0?Shn04I6AP0o?cl203`l?00:03/k>`0l?3`0
?3`l03hn?P0k>c/0?clo03`l?00n?Sh0?Cdm03`l?080?clo00T0?Cdm0492@P11@D40@d=303hn?P0i
>CT0=cLg03Ph>00m?Cd00P0l?3`01P0k>c/0?Cdm03hn?P0m?Cd0?Shn03Xj>P<0?3`l00@0>c/k03dm
?@0l?3`0?Shn0P0m?Cd0100o?cl0?Cdm03Xj>P0m?Cd203`l?00503/k>`0j>SX0>3Ph03Ti>@0k>c/0
0P0l?3`01P0j>SX0?3`l03/k>`0k>c/0>CTi03lo?`80@41000<0@d=303/k>`0n?Sh00P10@4001P0l
?3`0>c/k0451@@0m?Cd0@4100451@@80?clo00<0?Cdm0492@P0k>c/00P0k>c/04`0l?3`0?Cdm03hn
?P0n?Sh0A4A40451@@0n?Sh0>CTi03/k>`0m?Cd0?3`l03/k>`0l?3`0?clo04=3@`12@T80?clo03`l
?00i>CT00`0l?3`0600m?Cd0A4A40451@@0k>c/0?Cdm03/k>`0l?3`0>CTi03`l?00m?Cd0?Shn03lo
?`0k>c/0>CTi03`l?00o?cl0?Shn03lo?`0l?3`0?Cdm03hn?P0o?cl0@41003lo?`80?Shn00L0>SXj
03/k>`0l?3`0@41003/k>`0l?3`0?Shn0080@D5100D0?3`l03/k>`0k>c/0>CTi0410@0020451@@0=
03lo?`0j>SX0>CTi03dm?@16ATH0D51@04Y:BP0k>c/0>CTi03Ph>00k>c/0>SXj03Lg=`0303Ti>@0P
03Xj>P0l?3`0=cLg03/k>`0j>SX0>c/k03lo?`0n?Sh0EEEE05=CD`11@D40?Cdm03Xj>P0k>c/0?clo
04I6AP12@T80?Shn03/k>`0m?Cd0?Shn03lo?`0n?Sh0>c/k03Xj>P0l?3`0>CTi03/k>`0l?3`0>CTi
03dm?@0n?Sh203`l?00303Ti>@0j>SX0>SXj0080?clo00P0?Cdm04a<C01>CTh0BDU90492@P0o?cl0
@41003Ti>@80?Cdm00@0?3`l03Lg=`0n?Sh0>SXj0P0l?3`02`0j>SX0?Cdm0410@013@d<0L71`08F5
Q@1bLW80HF5Q04e=C@16ATH0@T920080?Shn00@0>SXj03dm?@11@D40@T920P0n?Sh00`0l?3`0>c/k
03hn?P0203hn?P0L03Xj>P10@400?Cdm03lo?`0n?Sh0?3`l03Ph>00n?Sh0@41003hn?P0o?cl0De=C
071`L02>SXh0/;2`0;:b/P2OWil0P820079bLP1RHV80HF5Q05ADE01;Bd/0B4Q804=3@`14A4@0@T92
03lo?`80@T9200/0?3`l04A4A010@400AdM705EEE@1TI6@0PH6109:BTP2LW9`0YZJV09>CT`0209RH
V00R096AT@28R8P0OGem08F5Q@28R8P0UiNG0:VYZ@2[Zj/0VIVI08Z:RP23Ph<0R8R808:2PP2<S8`0
Q8B408b<S02HV9P0XZ:R0:j^[P2n_[h0c<c<0=;BdP33`l<0/k>c0;jn_P3?cll0b<S80<[:bP37alL0
`/;20:^[Z`2OWil0V9RH0:6QX@80_[jn00`0]kNg092@T01jNWX0U9BD0:f][@2m_Kd0c/k>0=OGe`34
a<@0^KVi0<K6aP2j^[X20;Rh^0040=CDe03GemL0h>3P0<k>cP80`L7101h0YJFU09fMW@2EUID0QhN7
08F5Q@1nOWh0Ti>C09RHV02NWYh0_[jn0=3@d034a<@0_kno0;6a/@2HV9P0TY:B0:NWY`2l_;`0b/[:
0<k>cP3<c<`0aLG50:b/[01cLg<0IFEU07]kN`1PH600FEUI0410@00i>CT203/k>`0303Xj>P0g=cL0
>c/k0080=cLg00<0?Cdm03Hf=P0h>3P00`0g=cL=ooooo`004?ooool2055AD@0U05EEE@1RHV80J6QX
06e]K@1NGUh0HV9R09NGU`2TY:@0][Jf0;jn_P3<c<`0`<300:b/[03@d=00dM7A0<_;b`2l_;`0YZJV
0:>SX`2:RXX0RHV907QhN01YJFT0HV9R06ATI01kNg/0Q8B407=cL`1/K6`0Q8B408Z:RP23Ph<0VYZJ
09bLW02ATI40I6AT05QHF00204U9B@0;04e=C@1/K6`0NWYj07inOP29RHT0TI6A08B4Q01aLG40M7Ad
061PH018B4P00P17AdL05P11@D40@T920492@P15ADD0@d=304I6AP10@400?Shn04=3@`11@D40AdM7
04E5A@10@400Fe]K04Q8B012@T80?clo04A4A011@D40?Cdm04E5A@17AdL203dm?@0403hn?P11@D40
?3`l0451@@80?Shn00H0@D510492@P0k>c/0?clo0410@00o?cl20451@@0803lo?`0n?Sh0A4A40451
@@10@400?Shn03lo?`10@40203`l?0<0?Shn00H0@41004I6AP0n?Sh0>c/k03Xj>P0l?3`203dm?@08
0410@00o?cl0?3`l03`l?00m?Cd0?clo03`l?010@40203/k>`0303`l?00o?cl0?Shn0080?3`l00@0
>c/k04=3@`17AdL0?Cdm0P0l?3`0100o?cl0?Shn03/k>`0k>c/203Xj>P0<03/k>`0l?3`0>SXj03Xj
>P0k>c/0?Cdm0410@00n?Sh0@T920451@@10@400?Cdm0`0o?cl02`0m?Cd0>c/k0451@@0l?3`0?Cdm
03lo?`10@400?Shn03Xj>P15ADD0@T920080?clo00@0?Cdm03lo?`0k>c/0?Shn0P11@D402P0o?cl0
?Shn03`l?00k>c/0?3`l03hn?P0m?Cd0?clo04A4A011@D4203lo?`0603/k>`0n?Sh0A4A403`l?014
A4@0>c/k0P0l?3`203hn?P0503/k>`0m?Cd0?Shn03`l?00m?Cd00P0k>c/00`0j>SX0@41003hn?P03
0410@00303/k>`0o?cl0?clo0080>c/k00@0?Shn0410@00m?Cd0?3`l0P0k>c/02`0l?3`0?Cdm03dm
?@0k>c/0?Cdm03hn?P0l?3`0>SXj03Ti>@0k>c/0>CTi0080?3`l00P0@41004A4A013@d<0?Shn03Xj
>P0l?3`0?Shn03Xj>P80>3Ph02H0>CTi03Ph>00i>CT0?3`l03dm?@0k>c/0?clo03Ti>@0l?3`0>SXj
03hn?P14A4@0BTY:05MGE`0o?cl0@41003/k>`1@D500HF5Q05=CD`1@D500>SXj03/k>`0l?3`0@410
03Ph>00l?3`0?Shn03Xj>P0h>3P0?Cdm03/k>`0i>CT0>SXj03/k>`0m?Cd0?Shn03/k>`80>SXj00D0
>3Ph03/k>`0m?Cd0>c/k03Xj>P0203`l?00303hn?P0h>3P0>3Ph0080?Shn00@0?Cdm03lo?`0l?3`0
?3`l0P11@D403`0m?Cd0@D5103`l?013@d<0DU9B05mOG`1CDe<0AdM703/k>`0m?Cd0@41004=3@`0o
?cl0@41003`l?00203hn?P080410@00n?Sh0@d=304=3@`0l?3`0>SXj0410@012@T8203/k>`0A03lo
?`10@400>c/k03dm?@0l?3`0>3Ph04A4A01>CTh0GUiN07MgM`21PH40NGUi06MWI`1KFe/0CDe=0451
@@0n?Sh00P0m?Cd0100o?cl0?3`l03hn?P0m?Cd30410@00304U9B@1BDU80IFEU0080RHV902L0TI6A
09jNWP2XZ:P0ZZZZ0;Rh^035aLD0_;bl0;Fe]@2WYjL0]KFe0;bl_02g]kL0Z:RX07]kN`1BDU80Bd];
05EEE@1PH600J6QX071`L021PH40W9bL09nOW`2NWYh0[Zj^0;Bd]02e]KD0/k>c0:BTY02HV9P0WYjN
0;:b/P30`<00_;bl0;Ng]`2VYZH0UYJF09BDU02^[Zh00P2i^KT02P2g]kL0_;bl0:f][@2OWil0WYjN
09JFUP2JVYX0WIfM09jNWP2/[:`20<71`@0:0;Rh^02c/k<0_;bl0<S8b03>c/h0b/[:0<O7a`32`/80
bl_;0<O7a`80dM7A01X0g=cL0>7Qh@3MgMd0a<C40;:b/P2ATI40KFe]05UIF@1hN7P0Ph>308Z:RP2N
WYh0Zj^[0:2PX02DU9@0VIVI0:j^[P2k^k/0a/K60=KFeP3=cLd0]kNg0<?3``30`<00Z:RX06YZJP80
E5AD00@0GUiN06a/K01JFUX0ADE50P0n?Sh02`0h>3P0>CTi03dm?@0i>CT0>3Ph03Lg=`10@400@T92
03Xj>P0k>c/0>SXj00gooooo000@ooooo`0m05]KF`1NGUh0EUIF05MGE`1MGEd0IVIV05eMG@1FEUH0
DE5A05EEE@1XJ6P0SXj>0;no_`31`L40WYjN08F5Q@2LW9`0]KFe0<30`033`l<0cLg=0<71`@2l_;`0
^[Zj0<W9b@33`l<0[jn_0;Jf]P2][Jd0UYJF08^;R`1lO7`0JFUY071`L02FUYH0^;Rh0:^[Z`2BTY80
PH6108R8R02HV9P0WinO0<O7a`3Bd]80^;Rh0:f][@2d];@0VYZJ06QXJ01>CTh0BDU904E5A@13@d<0
?clo04E5A@17AdL0ADE50451@@14A4@0@D5103lo?`020492@P0?0410@013@d<0?3`l0410@013@d<0
A4A40451@@0o?cl0@41003dm?@10@400?clo0492@P0l?3`0?Cdm0080?Shn0P0o?cl01P0n?Sh0?clo
0451@@0m?Cd0>SXj03lo?`80?3`l00d0?Cdm03lo?`0o?cl0?Cdm03hn?P0o?cl0?Shn03/k>`0n?Sh0
?Cdm03lo?`0m?Cd0?3`l0080?Shn00D0?3`l0492@P0o?cl0?Cdm03hn?P0203lo?`0803`l?010@400
?clo03dm?@0l?3`0>SXj03hn?P0m?Cd303hn?P0503`l?00n?Sh0?Cdm03dm?@0n?Sh00P0l?3`01P10
@400>SXj03hn?P10@400?clo03`l?0<0>c/k0P0h>3P203`l?00803Xj>P0i>CT0>SXj03dm?@0o?cl0
@T920410@00o?cl203hn?P80?clo00D0?3`l03Ph>00n?Sh0>SXj03/k>`0203hn?P0=0410@00k>c/0
>c/k03hn?P0l?3`0A4A403hn?P0m?Cd0?Shn03lo?`0k>c/0?3`l03Xj>P0203hn?P80@41001/0?Shn
03dm?@0l?3`0?clo0410@013@d<0?Cdm03hn?P11@D40>c/k03`l?01JFUX0?clo03Xj>P0n?Sh0?3`l
03/k>`0j>SX0?clo03hn?P0l?3`0?Cdm0492@P14A4@0?Cdm03Xj>P0h>3P00P0k>c/0200n?Sh0>SXj
03`l?00i>CT0?Shn03`l?00m?Cd0@4100P0n?Sh00`0o?cl0?3`l03Ph>00203Ti>@0303/k>`0m?Cd0
?3`l0080?Shn00<0>c/k03Xj>P0n?Sh00P0j>SX01`12@T80>c/k03/k>`0l?3`0?Shn03Ti>@0j>SX0
0`0i>CT0300k>c/0?Shn03`l?010@400@D5103dm?@0l?3`0?clo03hn?P0j>SX0?Cdm0410@080?Cdm
0200@D5104m?C`1/K6`0QXJ605MGE`16ATH0?clo03hn?P0k>c/0>3Ph03Ti>@0g=cL0?3`l03hn?P0l
?3`0?Cdm0410@00h>3P0>SXj03dm?@0i>CT0?Cdm03`l?00k>c/0?Cdm03hn?P0k>c/0?3`l03/k>`0l
?3`0?Shn03Ph>080?3`l00P0>CTi03hn?P12@T80@T9204E5A@0n?Sh0?Cdm03hn?P80>3Ph00d0?Shn
03dm?@11@D40?Shn03dm?@0k>c/0ATI60410@00l?3`0?Shn0492@P10@400>SXj0080?3`l01T0@410
03Xj>P0l?3`0?3`l03Xj>P0k>c/0?Shn059BDP1@D500>c/k0410@00k>c/0?Shn0410@012@T80?Shn
0492@P19BDT0E5AD05UIF@1KFe/0EEEE04I6AP0l?3`0@D510080>c/k03X0@D5103hn?P0m?Cd0@D51
04A4A01:BTX0GEeM06EUI@1mOGd0S8b<09>CT`2BTY80UYJF0:b/[030`<00`l?30<;2`P37alL0][Jf
0:RXZ02EUID0UYJF0::RXP2XZ:P0YZJV0:RXZ02VYZH0X:2P09ZJVP2][Jd0/;2`0:b/[027QhL0OGem
07=cL`25QHD0SHf=0;Fe]@35aLD0b/[:0<;2`P2EUID0O7al06UYJ@1lO7`0Xj>S0;bl_03<c<`0f=SH
0=kNgP3Kfm/0g=cL0=kNgP3Lg=`0gmoO0>;RhP3Ogml0g]kN0`3Kfm/0@@3IfMT0b/[:0<K6aP2c/k<0
[:b/0:RXZ02a/K40^[Zj0<W9b@3=cLd0dm?C0=[JfP3Lg=`0f=SH0=KFeP3=cLd0a/K60;jn_P2d];@0
^;Rh0:b/[02e]KD0b<S80<o?c`3;bl/0a<C40:n_[`2UYJD0`<300;jn_P2WYjL0R8R807alO02BTY80
YjNW0:>SX`2ZZZX0_Kfm0;Zj^P2PX:00XZ:R0;>c/`2f][H0^KVi0<;2`P2b/[80Rh^;0<O7a`3Bd]80
alO70;Rh^030`<00YJFU08^;R`1iNGT0EEEE03lo?`0j>SX0>3Ph03Xj>P0k>c/0?Cdm04=3@`14A4@0
?Shn00gooooo000@ooooo`0;04i>CP1ADE40DU9B05ADE01EEED0EeMG05=CD`1GEeL0EUIF05QHF01D
E5@00P1PH6008`1`L700QHF508f=S@1JFUX0E5AD059BDP1TI6@0UIFE0<o?c`36a/H0/[:b0:>SX`2X
Z:P0VYZJ08N7Q`2MWId0_Kfm0<g=c@38b<P0_Kfm07]kN`1MGEd0Hf=S09VIV@2_[jl0/[:b0:n_[`2o
_kl0bLW90;6a/@2d];@0_Kfm0;Vi^@2d];@0XZ:R0080QHF500<0SHf=07QhN01IFET00P15ADD204A4
A0060492@P11@D40@D510410@00n?Sh0A4A40P17AdL05@10@400@d=30492@P15ADD0@D510410@012
@T80?clo0492@P0k>c/0@D5103lo?`10@400?clo03`l?010@400@D510410@00n?Sh0@T920410@002
03`l?00503/k>`0n?Sh0?clo03hn?P0k>c/00P0m?Cd01@12@T80ADE50410@00l?3`0>CTi0080@410
0`0o?cl02@10@400?Cdm03lo?`0n?Sh0>CTi03Xj>P10@400?clo0451@@0303dm?@0303Xj>P0l?3`0
>c/k0080?Cdm00@0?3`l03Ti>@0j>SX0?3`l0P0m?Cd203hn?P0603Xj>P0k>c/0?Shn03dm?@0k>c/0
?Cdm0P0n?Sh0100o?cl0?3`l03Ti>@0n?Sh203Ph>00:03Ti>@0h>3P0>c/k03/k>`0m?Cd0?clo03dm
?@0j>SX0?Shn03lo?`80?Shn00h0>3Ph03/k>`0k>c/0>SXj03dm?@0l?3`0@D510410@00n?Sh0?Cdm
0492@P14A4@0?Cdm03Ph>080?Cdm0P0k>c/0100o?cl0?Shn03`l?00k>c/203dm?@80>c/k00X0?3`l
03dm?@0m?Cd0>c/k03dm?@0n?Sh0?clo03dm?@0n?Sh0?Cdm0`0k>c/0100m?Cd0>c/k03dm?@0j>SX3
03`l?00803dm?@0k>c/0>CTi0410@011@D40>CTi03Hf=P0h>3P203Ti>@80=cLg0P0l?3`0100i>CT0
?Cdm04E5A@15ADD203Ti>@80>c/k00<0?Cdm03lo?`0i>CT00P0l?3`01@0j>SX0?3`l0410@01>CTh0
C4a<0080>CTi01d0?3`l03/k>`0j>SX0>SXj03Hf=P0k>c/0@41005]KF`1ADE40@D5103`l?00n?Sh0
?3`l03Ti>@10@400?3`l03Ph>00j>SX0>3Ph0492@P1;Bd/0GEeM05QHF016ATH0>c/k03Xj>P0k>c/0
>CTi03dm?@0203Ph>00603Ti>@0j>SX0=cLg03Ti>@0k>c/0?3`l0P0h>3P203Ti>@0903Xj>P0i>CT0
>CTi03/k>`0m?Cd0?Shn03Xj>P0n?Sh0>3Ph0080>c/k00T0>SXj03dm?@0h>3P0?clo0410@00m?Cd0
>c/k03`l?00k>c/00P0m?Cd08P0k>c/0@D510451@@0l?3`0?Shn03/k>`0j>SX0@41003hn?P14A4@0
?Shn03/k>`0i>CT0?Cdm03Xj>P0f=SH0?3`l03lo?`0i>CT0>SXj0451@@0k>c/0?3`l03dm?@0o?cl0
@D5104Q8B01ADE40GUiN07AdM01_Kfl0KFe]05mOG`1@D50204=3@`0703dm?@10@400?Shn0451@@0l
?3`0>c/k03dm?@0203hn?P0W04a<C02@T900[Jf]0:f][@2e]KD0aLG50;Rh^02b/[80WinO09JFUP2X
Z:P0`l?30=cLg03Ogml0c/k>0;Bd]02WYjL0^;Rh0=SHf03?cll0_Kfm0<;2`P39bLT0];Bd0;2`/02/
[:`0[Jf]0;>c/`2/[:`0WIfM096AT@1lO7`0MGEe06a/K01cLg<0L71`07EeM@23Ph<0UiNG0080XZ:R
00P0VIVI09JFUP2@T900U9BD09RHV02RXZ80YjNW0:j^[P80^[Zj04X0_Kfm0<O7a`36a/H0`l?30<K6
aP3?cll0d=3@0=GEe@3Lg=`0emOG0>3Ph03Ti>@0h^;R0=3@d038b<P0`<300<c<c03Bd]80c/k>0<S8
b03<c<`0c/k>0<[:bP3>c/h0dM7A0=CDe03GemL0d];B0<k>cP2j^[X0UIFE09fMW@2NWYh0][Jf0<c<
c03Fe]H0f][J0=GEe@3Ng]h0hn?S0=oOg`3<c<`0_kno0<;2`P2[Zj/0VIVI0;Bd]03AdM40`/;20;2`
/02WYjL0U9BD08Z:RP2@T900Y:BT0:j^[P3:b/X0e=CD0<k>cP30`<00a/K60<c<c03>c/h0gMgM0;^k
^`2UYJD0RHV908B4Q01iNGT0P82008n?S`30`<00b/[:0:f][@gooooo000@ooooo`0604e=C@1>CTh0
CTi>04e=C@1;Bd/0CDe=0P1@D500?`1:BTX0BDU905=CD`1[Jf/0HF5Q059BDP1IFET0L71`06MWI`1C
De<0D51@05IFEP1[Jf/0OGem07=cL`1KFe/0Cdm?04];B`1CDe<0Cdm?04i>CP1PH600PX:209VIV@2`
/;00];Bd0;2`/023Ph<0EEEE06=SH`1`L700KFe]07QhN01gMgL0IFEU05IFEP1RHV80PX:20;Bd]03=
cLd0alO709FEU@1TI6@0PH610:BTY02?Shl0MGEe05UIF@1?Cdl0BTY:04E5A@10@400A4A404=3@`12
@T80@41003hn?P0l?3`0A4A40492@P16ATH0BDU904=3@`020410@0040451@@0o?cl0@41004=3@`80
@T9200<0?Shn03`l?00n?Sh00P0n?Sh01P11@D40A4A403dm?@0k>c/0?Shn03`l?080?Cdm00D0?3`l
03hn?P0l?3`0>c/k03dm?@0203`l?00P03Xj>P10@400?clo0451@@0k>c/0?Cdm03/k>`0o?cl0@T92
0451@@0n?Sh0@d=304E5A@0o?cl0?Cdm03`l?00n?Sh0?clo03hn?P0o?cl0>c/k03Xj>P0o?cl0?Shn
03`l?00m?Cd0?Shn03dm?@0j>SX0>c/k03Xj>P0l?3`403dm?@0303Xj>P0i>CT0?Cdm00<0?Cdm00P0
@T9203dm?@0j>SX0?Shn03dm?@0o?cl0?Cdm03`l?0<0?clo0180?Shn03dm?@0l?3`0?Cdm03/k>`0j
>SX0@41003`l?010@400?clo04=3@`0m?Cd0>c/k03dm?@11@D40?Shn03/k>`0j>SX203lo?`0703hn
?P0o?cl0@d=30410@00o?cl0?Shn03dm?@0203`l?00<03dm?@0i>CT0@41003lo?`0l?3`0>SXj03hn
?P13@d<0?Shn03Xj>P0o?cl0?3`l0`0k>c/203Ti>@0<03Xj>P0k>c/0?Cdm03`l?00i>CT0>SXj03`l
?00n?Sh0?clo03Ti>@0h>3P0=SHf0P0j>SX0200i>CT0>c/k03lo?`0k>c/0>SXj03`l?00n?Sh0?3`l
0P0j>SX203hn?P0:03Ph>00i>CT0>SXj03lo?`0n?Sh0A4A404U9B@1PH600EEEE04M7A`@0?3`l00/0
>SXj03Ti>@0h>3P0>SXj0451@@1ADE40DU9B051@D012@T80?Cdm03Ti>@0203Ph>00903lo?`0l?3`0
?Shn03hn?P12@T80@D5103Xj>P0f=SH0?Shn0080?3`l00D0>CTi03/k>`0m?Cd0=SHf03Ti>@0203hn
?P0603dm?@0k>c/0@4100410@00n?Sh0?Cdm0`0k>c/203Ti>@0>03`l?00o?cl0@D510492@P0o?cl0
?Cdm03`l?00n?Sh0?clo03hn?P0l?3`0?Cdm03lo?`0m?Cd303/k>`0703`l?00j>SX0>3Ph0410@013
@d<0@41004=3@`0203dm?@0J03Xj>P0o?cl0@4100410@00k>c/0>CTi03`l?011@D40>SXj03`l?00o
?cl0@41003/k>`16ATH0?3`l04=3@`1>CTh0Hf=S07=cL`1iNGT0NWYj071`L01RHV80EEEE04U9B@14
A4@203/k>`0603hn?P0l?3`0@4100451@@0o?cl0>c/k0P0l?3`0@P0o?cl0BDU907IfMP22PX80Ph>3
07]kN`1/K6`0J6QX05aLG01VIVH0MGEe09JFUP2e]KD0_Kfm0=CDe02n_[h0YJFU0:NWY`2;Rh/0OWin
07moO`1RHV80D51@04i>CP1<C4`0D51@071`L02<S8`0WinO0:RXZ02LW9`0Shn?08>3P`2ATI40VYZJ
0:BTY02h^;P0`<300;jn_P39bLT0c<c<0<30`033`l<0`<300;Vi^@2g]kL0_Kfm0;Zj^P34a<@0b<S8
0<;2`P33`l<0`L710<K6aP34a<@0][Jf09RHV02@T900W9bL09fMW@2RXZ80/;2`0;>c/`35aLD0clo?
0=cLg080hN7Q00<0h>3P0>KViP3Ti>@00P3Vi^H01@3WinL0hn?S0=oOg`3Fe]H0clo?0080`L710140
]kNg0:n_[`2ZZZX0WYjN07UiN@1]KFd0[Jf]0=?Cd`3Rh^80h>3P0=SHf03Bd]80`<300;fm_@33`l<0
^[Zj0:BTY0020:JVYP0;0;jn_P3MgMd0j>SX0>SXj03Vi^H0g]kN0<c<c02XZ:P0SHf=05aLG02>SXh0
0P38b<P03`2YZJT0TY:B0;Jf]P3?cll0e]KF0<c<c03EeMD0emOG0=SHf03Fe]H0cLg=0<[:bP3Lg=`0
a<C408^;R`0=ooooo`004?ooool01`1?Cdl0CTi>04m?C`1=CDd0D51@055AD@1BDU800P1<C4`02P1=
CDd0DU9B05aLG01]KFd0LW9b07=cL`21PH40KFe]05ADE01@D502055AD@0805=CD`1?Cdl0CTi>05=C
D`1ADE40GEeM051@D019BDT204e=C@0P051@D01ADE40CTi>05eMG@1SHf<0DE5A04a<C01PH600F5QH
06=SH`1ZJVX0MgMg0820P027QhL0N7Qh06YZJP1iNGT0Zj^[0;Bd]02][Jd0UiNG07moO`1eMGD0];Bd
0<_;b`2m_Kd0[:b/08Z:RP1`L700FUYJ04a<C012@T8303hn?P040451@@0n?Sh0ADE504U9B@80@d=3
00<0A4A40410@012@T800P12@T801@0n?Sh0?clo0451@@11@D40?clo0080?Cdm00<0?clo0410@00m
?Cd00P0m?Cd203hn?P<0?Cdm0P0l?3`03`0i>CT0?3`l0410@00k>c/0?Cdm0410@011@D40?Shn03Ti
>@0l?3`0?Cdm0410@00n?Sh0?Cdm0410@00203lo?`0303dm?@11@D40?Cdm0080?3`l00`0@41003lo
?`0k>c/0?3`l03dm?@0o?cl0?Shn03`l?00n?Sh0>CTi03Xj>P0h>3P203hn?P0303dm?@0k>c/0>c/k
0080>c/k00L0>SXj03/k>`0h>3P0>SXj03dm?@0l?3`0?Cdm00<0?clo01@0?3`l03dm?@0n?Sh0>c/k
0410@00n?Sh0?3`l03Ti>@0j>SX0?3`l03Ti>@0o?cl0?Cdm03lo?`0l?3`0?clo03dm?@0i>CT0?3`l
03dm?@80?Shn01D0@41003lo?`0m?Cd0ADE50410@00o?cl0?Shn0410@00n?Sh0?clo0492@P0k>c/0
@41003hn?P0l?3`0?Shn03`l?00m?Cd0?Shn0410@00o?cl00P0l?3`403Xj>P0703hn?P0l?3`0?Shn
03hn?P0m?Cd0?Shn03Ti>@0203Xj>P80>CTi00D0>c/k03Ti>@0k>c/0>c/k03Ti>@0203Xj>P0403dm
?@0l?3`0?3`l03hn?P80?3`l00<0?Shn03Xj>P0k>c/00P0n?Sh01`19BDT0Bd];04A4A011@D40@d=3
04E5A@0k>c/00P0n?Sh204Q8B080?Cdm00D0?3`l03Xj>P0l?3`0?3`l03Ti>@0203lo?`0903Xj>P0i
>CT0>SXj03Xj>P0n?Sh0>SXj03dm?@0j>SX0?Cdm00<0>CTi01@0>3Ph03Xj>P0k>c/0?3`l03Xj>P0i
>CT0>c/k03Xj>P0n?Sh0>c/k03`l?010@400?3`l03/k>`0m?Cd0?3`l03/k>`0m?Cd0>c/k0451@@<0
>c/k00<0?3`l03lo?`13@d<00P0m?Cd03P0k>c/0?Shn03/k>`0j>SX0?3`l03Ti>@0k>c/0>CTi03`l
?00j>SX0?Shn03dm?@0j>SX0?3`l0P0k>c/00`0i>CT0@41003lo?`0203`l?00503/k>`10@400>CTi
03/k>`0m?Cd00P0j>SX05@0n?Sh0?Cdm03/k>`0l?3`0@D5104E5A@1ADE40FEUI061PH01OGel0FEUI
04Y:BP18B4P0@d=303/k>`12@T80?Shn03lo?`0n?Sh0?Cdm0410@0020451@@0603/k>`0j>SX0?Shn
0410@013@d<0@T920P1BDU806P1ADE40AdM704i>CP1TI6@0O7al09ZJVP2a/K40_kno0<k>cP3=cLd0
_;bl09bLW01jNWX0FEUI04Q8B010@400@D510410@00n?Sh0@T9204=3@`15ADD0JFUY092@T02i^KT0
fMWI0P3Shn<00`31`L40Xj>S0;>c/`020<g=c@0R0<K6aP3;bl/0d=3@0=OGe`3Hf=P0b<S80<71`@34
a<@0_kno0;Fe]@2c/k<0`L710;jn_P2c/k<0Zj^[0:BTY02RXZ80YJFU09^KV`2PX:00[Zj^0::RXP2S
Xj<0]KFe0<S8b039bLT0bl_;0<G5a@2l_;`0_[jn0;Ng]`33`l<0bl_;0=WIf@80f=SH00@0e=CD0=3@
d03De=@0f=SH0P3AdM409@38b<P0`l?30<;2`P2n_[h0^KVi0<?3``32`/80a/K60<S8b03<c<`0bLW9
0=3@d037alL0bl_;0<W9b@2h^;P0W9bL0:j^[P3?cll0emOG0>7Qh@34a<@0^;Rh0<_;b`3Hf=P0h^;R
0>3Ph03QhN40d=3@0<?3``3De=@0^KVi09>CT`28R8P0YZJV0;fm_@31`L400P39bLT02`2j^[X0UYJF
0:FUY@2^[Zh0b<S80;bl_02RXZ80Ogmo06UYJ@1FEUH0@D5100gooooo000@ooooo`04051@D01>CTh0
C4a<04e=C@80C4a<02T0CDe=04m?C`1EEED0IfMW079bLP1aLG40J6QX05YJFP1HF5P0DE5A05UIF@1?
Cdl0CTi>04m?C`1DE5@0CTi>059BDP1NGUh0JFUY05YJFP1GEeL0DE5A04a<C01=CDd0D51@05=CD`1G
EeL0CDe=04];B`1NGUh0GemO05IFEP1ZJVX0MgMg09bLW02XZ:P0];Bd0;^k^`2LW9`0MWIf06EUI@02
061PH00O05mOG`1eMGD0R8R808F5Q@1PH600IfMW06e]K@1iNGT0VIVI09FEU@2:RXX0IfMW04Q8B011
@D40?Shn0410@015ADD0A4A40451@@17AdL0A4A40492@P15ADD0A4A40410@012@T80@d=30451@@12
@T80@d=30492@P0203lo?`0D03hn?P0m?Cd0?3`l03hn?P15ADD0A4A403lo?`10@400?Shn03`l?00o
?cl0@41003hn?P10@400?clo0451@@12@T80?3`l03/k>`10@40203hn?P0304=3@`10@400?3`l0080
?3`l00D0>SXj03lo?`0o?cl0?Shn03/k>`0203dm?@0?03hn?P10@400@T9203dm?@0l?3`0@4100451
@@0o?cl0?3`l03Xj>P0l?3`0>c/k03Ti>@0l?3`0?Cdm0080?3`l0P0k>c/01`0o?cl0?Shn03Xj>P0m
?Cd0@41003lo?`10@4000P0n?Sh01P0m?Cd0?3`l03dm?@10@400>SXj03/k>`80?Shn00<0?Cdm03`l
?00k>c/00P0l?3`04`0m?Cd0>c/k03/k>`0n?Sh0>SXj03`l?00k>c/0?Shn0492@P13@d<0?Shn03lo
?`18B4P0ATI60492@P15ADD0ATI604A4A012@T800P0n?Sh01P10@400?Shn03lo?`15ADD0?Shn03Xj
>P<0?Cdm0P0o?cl01011@D40?Cdm03Ti>@0k>c/203`l?00303/k>`0n?Sh0?3`l0080?3`l02H0?Shn
03/k>`0j>SX0?Cdm03Xj>P0k>c/0>CTi03/k>`0i>CT0?3`l03hn?P0k>c/0>SXj03Ti>@0j>SX0?3`l
03dm?@10@400?3`l03lo?`0m?Cd0?Shn03/k>`13@d<0FUYJ07UiN@1YJFT0A4A403`l?00m?Cd0>c/k
0410@00o?cl0@D5104a<C01?Cdl0AdM703lo?`80?Cdm00L0?3`l03hn?P0i>CT0@41003Xj>P0k>c/0
?Cdm00<0?3`l00@0>SXj03Ti>@0k>c/0@T920P0l?3`02`0n?Sh0>c/k03/k>`0i>CT0>SXj03`l?00n
?Sh0@41003dm?@10@400?clo0080?3`l00<0?Cdm03hn?P0m?Cd00P0k>c/203`l?080>SXj0P0k>c/0
3`0j>SX0>c/k04=3@`0l?3`0?Cdm03`l?00o?cl0?3`l03/k>`0o?cl0>3Ph03lo?`0k>c/0?Cdm03Xj
>P0203dm?@0T03`l?00n?Sh0@T920451@@0m?Cd0?3`l03Xj>P0k>c/0>CTi03`l?00j>SX0>3Ph03Xj
>P0f=SH0=cLg03Xj>P0m?Cd0@D5103hn?P13@d<0@T920410@012@T80ATI60410@00m?Cd0?Shn03dm
?@0k>c/0?clo0492@P0n?Sh0@41003Xj>P0k>c/0?3`l0P0m?Cd0:00o?cl0?3`l03Xj>P0n?Sh0@T92
04i>CP15ADD0B4Q8051@D01dM7@0Vi^K0<71`@3EeMD0d=3@0;>c/`2NWYh0Rh^;07=cL`1PH600C4a<
0492@P16ATH0@41003dm?@0o?cl0?Cdm03lo?`13@d<0CTi>079bLP2OWil0alO70=KFeP3@d=00e]KF
0=_Kf`3?cll0_[jn09BDU02:RXX208n?S`0[09bLW02WYjL0Xj>S09NGU`2=SHd0Q8B40820P01hN7P0
IFEU05=CD`1:BTX0ATI603lo?`11@D40?clo0451@@1;Bd/0DE5A05iNGP1iNGT0S8b<08J6QP2EUID0
SHf=0820P01bLW80G5aL05iNGP1EEED0DE5A05=CD`1BDU80JVYZ08F5Q@2;Rh/0T92@09>CT`2KVi/0
YjNW0;^k^`2o_kl0e=CD0=OGe`020<g=c@0_0<71`@2l_;`0/k>c0:ZZZP2TY:@0];Bd0<g=c@3Fe]H0
gMgM0=OGe`3Bd]80cLg=0<K6aP2e]KD0bl_;0=WIf@3Lg=`0hn?S0=WIf@2j^[X0]kNg0;Fe]@2i^KT0
^k^k0;Zj^P2_[jl0]kNg0;jn_P2h^;P0];Bd0:NWY`2PX:00[jn_09fMW@2QXJ40[:b/0:2PX02HV9P0
Vi^K0;bl_039bLT0dm?C0;Rh^02?Shl0Ng]k069RHP1HF5P03Oooool0013ooooo0`1=CDd01`1?Cdl0
CDe=04Y:BP19BDT0D51@04a<C01;Bd/00P1<C4`06@1DE5@0FUYJ05YJFP1RHV80J6QX05aLG01PH600
D51@04U9B@1:BTX0AdM704Q8B019BDT0C4a<04Q8B019BDT0AdM704Y:BP1=CDd0EEEE06EUI@1JFUX0
EUIF05eMG@1XJ6P00P1MGEd0601RHV80NGUi08:2PP2BTY80_[jn0<o?c`3@d=00clo?0<S8b02d];@0
Z:RX0:ZZZP2HV9P0UiNG08:2PP1MGEd0U9BD0;6a/@2PX:00Ph>308:2PP1iNGT0Fe]K051@D0<0@d=3
0180ATI604A4A015ADD0@D5104=3@`14A4@0ATI604A4A016ATH0@T920410@016ATH0A4A40410@012
@T80@d=30492@P10@40303hn?P0303lo?`10@400@T920080@4100`0m?Cd08`0o?cl0@D510410@00o
?cl0?Shn03dm?@0o?cl0?Shn055AD@2OWil0?Shn03`l?00o?cl0?Cdm03`l?00m?Cd0?clo0451@@0m
?Cd0?clo04=3@`12@T80?Shn0451@@0l?3`0?Shn0410@012@T80?clo03dm?@0k>c/0>SXj03`l?00i
>CT0@D510080>c/k0140?Cdm03hn?P0o?cl0?clo03`l?010@400?clo04I6AP10@400?3`l0410@00o
?cl0>SXj03dm?@10@400?3`l03/k>`020410@0030492@P0m?Cd0?Shn0080?Cdm00T0>SXj0451@@0n
?Sh0?3`l0451@@0m?Cd0?clo0410@013@d<00P12@T801`13@d<0@41004E5A@13@d<0C4a<04M7A`13
@d<00`0n?Sh01@0m?Cd0?clo0451@@0n?Sh0?Cdm0080?Shn00T0?clo03hn?P0j>SX0>SXj04A4A011
@D40?3`l03dm?@0j>SX00P0m?Cd01P0n?Sh0?Cdm03hn?P0k>c/0?Cdm0410@080>c/k00<0?Shn03lo
?`0m?Cd00P0j>SX03`0i>CT0=SHf03dm?@0m?Cd0>SXj03`l?00m?Cd0>3Ph03/k>`0o?cl0>CTi03`l
?00g=cL0?Shn0410@00204e=C@0C04M7A`0k>c/0?3`l03dm?@13@d<0?3`l0410@00j>SX0?Shn03lo
?`0l?3`0AdM703lo?`0j>SX0?3`l03Ti>@0j>SX0>3Ph03/k>`0203Ph>00503/k>`0l?3`0?Shn03`l
?00i>CT00P0l?3`02@0k>c/0>CTi03/k>`0m?Cd0?3`l03hn?P0i>CT0=cLg03Ph>00203/k>`0603Xj
>P0k>c/0>CTi03Xj>P0n?Sh0?3`l0P0j>SX00`0h>3P0=cLg03Ph>00203/k>`80?3`l0P0k>c/01@0h
>3P0>c/k03Xj>P0g=cL0>SXj0080>CTi00@0?3`l03lo?`0i>CT0>c/k0P0i>CT02P0l?3`0>c/k03Xj
>P10@400@D5103lo?`11@D40?clo03/k>`0j>SX203/k>`0603Ti>@0j>SX0@41003lo?`0h>3P0>SXj
0P0k>c/01@0n?Sh0?Cdm0492@P0o?cl0>SXj0080?3`l02D0>c/k03hn?P11@D40?Shn03Ti>@0m?Cd0
?3`l03/k>`0o?cl0?Shn03Ti>@0l?3`0@41003lo?`11@D40@d=304a<C01ADE40F5QH06a/K02;Rh/0
/[:b0<o?c`3Lg=`0e]KF0;Zj^P2=SHd0IFEU04e=C@13@d<0@D5103hn?P0m?Cd0@D5103`l?00m?Cd0
?Shn0080?3`l00l0?Cdm06i^KP2UYJD0][Jf0;fm_@2c/k<0XJ6Q09VIV@28R8P0O7al071`L01JFUX0
CTi>04I6AP11@D400P0o?cl0D@13@d<0@T9203hn?P12@T80?clo03hn?P10@400?clo03dm?@0k>c/0
>CTi03hn?P0m?Cd0?Shn03`l?00m?Cd0@D5104M7A`1FEUH0LW9b08V9R@1nOWh0Ph>308J6QP27QhL0
Shn?09ZJVP2QXJ40ZJVY0:ZZZP2VYZH0O7al05MGE`1ADE40ATI604E5A@1HF5P0KFe]07]kN`26QXH0
ZJVY0<o?c`3MgMd0iNGU0>SXj03Ng]h0`<3009bLW02ATI40Vi^K08f=S@2BTY80ZJVY0<C4a03AdM40
alO70=?Cd`3EeMD0bl_;0<S8b033`l<0_kno0;6a/@32`/80_Kfm0:n_[`2RXZ80W9bL08:2PP1kNg/0
LW9b07UiN@22PX80W9bL0;Rh^03<c<`0d=3@0=;BdP3@d=00alO70;no_`020;fm_@090:^[Z`2UYJD0
_[jn0=;BdP3Hf=P0`/;20<G5a@3Bd]80b/[:00gooooo000@ooooo`0@051@D01>CTh0Cdm?04i>CP1<
C4`0CTi>04Y:BP17AdL0CDe=04a<C01:BTX0BDU905ADE01;Bd/0C4a<04i>CP80C4a<00H0De=C05AD
E01KFe/0EUIF05EEE@1IFET205=CD`0V04m?C`1OGel0DU9B04a<C016ATH0AdM704];B`1?Cdl0GUiN
06IVIP1ZJVX0EUIF05MGE`1<C4`0GemO05QHF01CDe<0GEeM06m_K`1bLW80QHF509^KV`2TY:@0];Bd
0=3@d03:b/X0`l?30=;BdP30`<00]KFe0;Jf]P34a<@0`/;20;Jf]P2c/k<0][Jf0:j^[P2ATI4208:2
PP0A08J6QP25QHD0R8R807moO`1fMWH0Lg=c075aL@1[Jf/0HV9R05IFEP1CDe<0CDe=04Q8B015ADD0
@D5104E5A@1IFET00P1/K6`03P1DE5@0?Shn03dm?@11@D40A4A404=3@`17AdL0@T920451@@10@400
@d=30410@00o?cl0?Cdm0P0k>c/03P0n?Sh0?Cdm04Y:BP2f][H0ADE503`l?00o?cl0>SXj03dm?@0o
?cl0?3`l0451@@0l?3`0>SXj0P0l?3`01`0i>CT0?3`l03`l?00o?cl0?Cdm03hn?P0j>SX00P0k>c/0
5`0j>SX0>CTi03`l?011@D40>SXj03`l?00o?cl0>SXj0410@00o?cl0@41003lo?`0j>SX0?Shn03/k
>`0g=cL0>SXj03/k>`0h>3P0?3`l03/k>`0n?Sh0?3`l0080>c/k00L0?clo03dm?@0o?cl0@41003hn
?P0k>c/0?Cdm0080>SXj00`0@T9203hn?P0j>SX0@D5103hn?P11@D40@T9203/k>`0m?Cd0?Shn03/k
>`13@d<203dm?@80?Shn00h0?Cdm03Xj>P0m?Cd0@D5103hn?P0k>c/0?3`l03hn?P12@T80?clo03Ti
>@0l?3`0@T9203hn?P80?3`l01D0>c/k03`l?00l?3`0>CTi03`l?00m?Cd0?3`l03hn?P0l?3`0?Cdm
0410@014A4@0?3`l03hn?P0m?Cd0>c/k03hn?P0i>CT0>SXj03/k>`0h>3P00P0l?3`0100o?cl0>CTi
03`l?00i>CT203`l?00304=3@`1?Cdl0@T920080>SXj00L0?3`l03dm?@0l?3`0@41003/k>`10@400
?Cdm0080>SXj0P0m?Cd02P0o?cl0>SXj03hn?P0k>c/0>SXj03Ph>00l?3`0=cLg03Hf=P0i>CT203Xj
>P0403lo?`0m?Cd0>CTi03Lg=`80>c/k01@0>SXj03Ti>@0f=SH0?3`l03Lg=`0i>CT0>c/k03Ph>00l
?3`0?clo03`l?00j>SX0>c/k03hn?P0o?cl0>SXj03Ti>@0h>3P0>SXj03/k>`80?Cdm0P10@4002P0l
?3`0>SXj03Xj>P0l?3`0>CTi03Hf=P0g=cL0>3Ph03lo?`0j>SX203Ph>00903/k>`0l?3`0?Cdm03`l
?010@400?clo03/k>`0o?cl0>SXj0080?3`l0P0k>c/02P0l?3`0?Shn03/k>`0k>c/0?3`l03Ph>00i
>CT0?Shn03Ti>@0j>SX203`l?00803/k>`0h>3P0>c/k03`l?00j>SX0>c/k03hn?P12@T8303hn?P0L
0410@00n?Sh0?Shn03`l?00n?Sh0?Cdm0492@P0l?3`0AdM705mOG`2JVYX0`L710=;BdP3De=@0dM7A
0<_;b`2f][H0UYJF07alO01GEeL0@d=303lo?`0l?3`0>c/k03dm?@0l?3`0>SXj03dm?@80>c/k00d0
>SXj0492@P1<C4`0GemO07UiN@1`L700F5QH04e=C@1:BTX0BDU904E5A@12@T80?Shn0080?Cdm00L0
?Shn03`l?00m?Cd0@T9203lo?`0n?Sh0?3`l0080>c/k00@0?Cdm03`l?00k>c/0?3`l0P0m?Cd0?00k
>c/0?3`l03hn?P0m?Cd0@4100492@P10@400@d=304A4A01;Bd/0EUIF05QHF01XJ6P0N7Qh08R8R029
RHT0T92@08^;R`2?Shl0TI6A09jNWP2VYZH0[Jf]0:NWY`2UYJD0Zj^[0:n_[`2e]KD0e=CD0=[JfP3R
h^80hN7Q0=kNgP3De=@0b/[:0<K6aP31`L40^k^k0<?3``3@d=00fMWI0<o?c`3<c<`0a<C40=3@d03<
c<`0d];B0<c<c02n_[h0[Zj^09:BTP28R8P0KFe]06ATI01/K6`0M7Ad08J6QP27QhL0SXj>0:^[Z`80
][Jf0P2UYJD02P2b/[80dM7A0=_Kf`3Lg=`0gmoO0>3Ph03QhN40h^;R0=_Kf`3@d=020<[:bP060<O7
a`30`<00`L710<W9b@35aLD0`L713Oooool0013ooooo00L0Cdm?04a<C01<C4`0Bd];04i>CP1;Bd/0
AdM700H0BDU90P1=CDd02017AdL0B4Q804M7A`15ADD0B4Q804U9B@17AdL0B4Q80`1=CDd0?P1;Bd/0
DE5A04U9B@1;Bd/0BDU904Q8B019BDT0CTi>05mOG`1HF5P0DU9B04];B`1<C4`0AdM704Q8B01=CDd0
EUIF065QH@1YJFT0EUIF055AD@1MGEd0HV9R05MGE`1RHV80G5aL06UYJ@1lO7`0TY:B096AT@1WIfL0
FEUI055AD@1>CTh0FEUI07YjNP2@T900ZZZZ0;Fe]@2k^k/0`L710;2`/02/[:`0];Bd0:VYZ@2VYZH0
Z:RX0;Zj^P2XZ:P0TI6A0;Jf]P2TY:@0OGem07UiN@2=SHd0/[:b0<K6aP3>c/h0bl_;09bLW01]KFd0
BTY:0P12@T802`17AdL0?clo0492@P0o?cl0@T9204I6AP11@D40@T9203lo?`0l?3`0>c/k0080?Shn
00<0>SXj051@D00k>c/00P0l?3`0200j>SX0?Cdm03/k>`0h>3P0>c/k03Ti>@12@T80@4100`0h>3P2
03hn?P0503/k>`0o?cl0>c/k03Xj>P0g=cL00P0j>SX03`11@D40?Cdm03dm?@11@D40?Cdm03`l?011
@D40>c/k03hn?P0l?3`0?Shn0410@00n?Sh0>CTi03Xj>P0203Ti>@0803`l?00j>SX0?clo03lo?`0j
>SX0?3`l03lo?`0n?Sh303dm?@0E03/k>`0m?Cd0?Cdm0410@00m?Cd0?Shn03lo?`1;Bd/0@D5103lo
?`0k>c/0@D5103/k>`0j>SX0?Cdm04=3@`0n?Sh0?clo03dm?@0o?cl0>c/k0080>SXj01D0ATI604M7
A`13@d<0@d=30451@@0k>c/0=cLg03`l?00n?Sh0@41003lo?`0l?3`0>c/k03hn?P0o?cl0@D5103Xj
>P0n?Sh0?Cdm03`l?00o?cl00P0l?3`04@0n?Sh0@41003`l?011@D40?Cdm03Lg=`0o?cl0>SXj03/k
>`0j>SX0>CTi04=3@`0n?Sh0?clo0410@012@T80@D510080?clo00@0@d=30492@P11@D40=SHf0P0h
>3P04P0g=cL0>SXj03Ti>@0i>CT0ADE503Xj>P0i>CT0?Cdm03`l?00j>SX0@D5103lo?`0j>SX0?3`l
03lo?`0k>c/0>CTi03Lg=`80>SXj00H0>CTi03Ph>00m?Cd0?3`l03Xj>P0k>c/303Lg=`0=03Ti>@0m
?Cd0?Cdm03Hf=P0k>c/0?3`l03/k>`0j>SX0?Cdm03hn?P0l?3`0>c/k03`l?00203Lg=`0503Ph>00l
?3`0?Shn03dm?@0n?Sh00P0l?3`0300o?cl0?Cdm03dm?@0n?Sh0?Cdm03hn?P0i>CT0>SXj03Hf=P0l
?3`0>c/k03hn?P80>CTi00h0>c/k03Ph>00j>SX0>c/k03Xj>P0i>CT0AdM70451@@0m?Cd0?3`l0410
@00o?cl0?Shn03dm?@80?3`l00D0>c/k03dm?@0j>SX0>CTi03hn?P0203/k>`0303Lg=`0i>CT0>SXj
0080>c/k01/0>CTi03`l?00l?3`0?clo03dm?@0h>3P0?Shn0451@@10@400>c/k0410@016ATH0@410
03hn?P1ADE40RXZ:0;:b/P2h^;P0Y:BT096AT@1fMWH0GUiN059BDP1;Bd/0@T9203lo?`10@4000P0m
?Cd04P0n?Sh0?3`l03Ti>@0h>3P0>c/k03Ph>013@d<0CTi>05MGE`1XJ6P0Kfm_065QH@15ADD0ATI6
0451@@0o?cl0?Shn03dm?@80?3`l00P0>SXj03Ti>@0l?3`0?3`l03Ti>@0k>c/0?Shn03dm?@80>CTi
00<0>3Ph03<c<`0k>c/00P0i>CT0E@0n?Sh0AdM705MGE`1KFe/0IFEU07AdM02BTY80WYjN0:BTY02S
Xj<0W9bL0:6QX@2d];@0a<C40=OGe`3Ph>00iNGU0>KViP3Hf=P0c<c<0=WIf@3Jf]X0e]KF0=CDe03M
gMd0gmoO0>3Ph03Fe]H0/[:b09NGU`2NWYh0/k>c0<G5a@3;bl/0e=CD0=_Kf`3Ng]h0g=cL0=KFeP2`
/;00LW9b061PH01^KVh0MgMg07UiN@2FUYH0WIfM0:ZZZP36a/H0f][J0=OGe`3Lg=`0g]kN0=OGe`3E
eMD0dm?C0<[:bP2n_[h0Z:RX09NGU`2BTY80Ti>C09:BTP21PH40PX:209FEU@2SXj<0RHV908:2PP2L
W9`0^k^k0<g=c@37alL0_[jn0<?3``3IfMT0e=CD0<g=c@3@d=00a/K60<S8b02][Jd0UIFE08Z:RP2U
YJD03Oooool0013ooooo00T0DE5A04i>CP1?Cdl0Cdm?04a<C01?Cdl0CDe=04];B`1<C4`00P19BDT0
201:BTX0B4Q804E5A@1?Cdl0DU9B04e=C@15ADD0C4a<0P1?Cdl2051@D00305=CD`1KFe/0EeMG0080
DE5A01P0E5AD05EEE@1ADE40C4a<04];B`17AdL0BTY:04I6AP17AdL0BTY:04U9B@1BDU80CTi>051@
D01DE5@0Jf][06m_K`1DE5@0BDU9059BDP1DE5@0DE5A05=CD`1BDU8204];B`0;05iNGP1MGEd0GUiN
04m?C`16ATH0B4Q805MGE`1KFe/0L71`07YjNP25QHD00P2>SXh0801gMgL0Lg=c08J6QP2ZZZX0^KVi
0:ZZZP2VYZH0TY:B07alO02:RXX0OGem07EeM@1mOGd0T92@0:^[Z`1oOgl0OWin08F5Q@2NWYh0^;Rh
09jNWP1nOWh0De=C04=3@`0n?Sh0ATI60410@00o?cl0@d=30492@P11@D40@4100P0m?Cd00`11@D40
?Cdm03hn?P0203`l?00403dm?@0k>c/0?3`l03/k>`80?Cdm00T0@41003lo?`0o?cl0>SXj0410@00j
>SX0>3Ph03`l?00k>c/00P0m?Cd02@0k>c/0?clo03Xj>P0o?cl0?Shn03lo?`0k>c/0?Shn0492@P02
0451@@80@4100P0n?Sh0300k>c/0?Shn03/k>`0i>CT0?clo03`l?00n?Sh0>SXj03dm?@13@d<0@T92
03`l?080?Cdm00H0>c/k03hn?P0n?Sh0>CTi03`l?00n?Sh203dm?@0403lo?`10@400?Shn04=3@`<0
?3`l00D0?Cdm03`l?00j>SX0>c/k03lo?`0303/k>`0403lo?`10@400?Cdm0410@080B4Q801<0@d=3
0451@@0n?Sh0>CTi0410@014A4@0?Shn03/k>`10@400?Shn0451@@14A4@0ATI60410@00i>CT0?3`l
03/k>`0j>SX0?Shn0080>SXj01D0>c/k03`l?00g=cL0?Cdm03/k>`0m?Cd0>SXj03/k>`0j>SX0?3`l
03Xj>P0l?3`0?Shn04A4A01>CTh0?Cdm03Xj>P0o?cl0@T9203hn?P0m?Cd00P0l?3`02@0n?Sh0?Cdm
03/k>`0j>SX0?Cdm03/k>`11@D40>SXj03/k>`0203Ti>@0903hn?P0h>3P0>c/k03`l?00m?Cd0@T92
03dm?@0l?3`0>SXj0080>c/k00h0?3`l03hn?P0m?Cd0>SXj03Ti>@0k>c/0>CTi03Ph>00j>SX0?Shn
03/k>`0o?cl0>c/k03lo?`80?3`l00H0=cLg03Ph>00f=SH0>3Ph03/k>`0n?Sh203/k>`0I03dm?@0k
>c/0?Cdm03Xj>P0k>c/0?3`l03Ti>@0k>c/0?3`l03dm?@0k>c/0>3Ph03hn?P0j>SX0?Shn04M7A`16
ATH0?Shn03`l?00g=cL0>CTi03`l?00h>3P0?3`l03Xj>P0203/k>`0503hn?P0m?Cd0=SHf03Ti>@0l
?3`00P0m?Cd02`0l?3`0?Shn03`l?00m?Cd0>c/k03dm?@0o?cl0?3`l03Ti>@0o?cl0>CTi0080?3`l
00/0?clo03dm?@0j>SX0?3`l0410@00o?cl0?Shn03Xj>P12@T80@D5103lo?`0203Ti>@0803`l?016
ATH0CDe=07AdM021PH40J6QX051@D016ATH204=3@`050410@00l?3`0>SXj03hn?P0m?Cd00P0k>c/0
3P0l?3`0?Cdm03Xj>P0f=SH0>CTi0492@P1FEUH0LW9b06][J`1QHF40FUYJ04e=C@0o?cl0>SXj0P0l
?3`303dm?@0503`l?00m?Cd0?3`l03Xj>P0o?cl00`0j>SX07P0m?Cd0@D5103`l?00l?3`0?Cdm03Xj
>P0n?Sh0Cdm?06MWI`2:RXX0ZZZZ0<O7a`38b<P0d=3@0<K6aP34a<@0`/;20;Vi^@2h^;P0_Kfm0<O7
a`3:b/X0dm?C0>;RhP3YjNT0k>c/0>OWi`3Ti>@0g]kN0=cLg080i>CT01h0hN7Q0>?Sh`3UiND0h^;R
0=WIf@3<c<`0b/[:0=?Cd`3MgMd0h^;R0>7Qh@3Rh^80gMgM0=OGe`3:b/X0clo?0=;BdP3?cll0bl_;
0<71`@32`/80WYjN075aL@1OGel0DE5A06ATI02LW9`0clo?0=[JfP3@d=020<30`0040<W9b@3Hf=P0
gMgM0>7Qh@80hn?S00`0gmoO0=OGe`2m_Kd0[Jf]0;Bd]03>c/h0dm?C0<c<c038b<P0]KFe0:j^[P30
`<020=CDe00:0<C4a038b<P0^[Zj0;fm_@2OWil0Ph>309RHV02n_[h0a<C40;Rh^0gooooo000@oooo
o`06059BDP1CDe<0De=C055AD@1?Cdl0C4a<0P1=CDd0401;Bd/0BDU904U9B@1=CDd0D51@05EEE@1T
I6@0EeMG055AD@1;Bd/0AdM704Y:BP1;Bd/0DU9B05YJFP1@D50204a<C00304Q8B017AdL0ADE50080
BTY:0P18B4P05`1>CTh0CDe=04Q8B017AdL0CDe=05aLG01QHF40KFe]069RHP1HF5P0G5aL05mOG`1G
EeL0J6QX07YjNP1aLG40JVYZ06m_K`1GEeL0GEeM05aLG01ZJVX0EEEE00<0B4Q800@0A4A404e=C@1@
D500BDU90P16ATH02013@d<0B4Q804M7A`16ATH0B4Q806ATI01fMWH0U9BD0P2OWil02@1lO7`0De=C
059BDP1mOGd0]KFe0<O7a`3:b/X0Zj^[06i^KP0206EUI@0407]kN`2[Zj/0`L710;2`/080Ti>C00`0
RHV907AdM01<C4`0@41004=3@`0m?Cd0?clo03`l?00n?Sh0@d=30492@P10@40203dm?@0L0410@00l
?3`0?3`l03dm?@0l?3`0?Cdm03lo?`10@400?Cdm03lo?`0l?3`0>SXj03`l?00m?Cd0>c/k03lo?`0m
?Cd0@4100492@P0j>SX0?Cdm03`l?00i>CT0?Cdm0410@00l?3`0?Cdm0451@@@0>c/k00X0?3`l03hn
?P0i>CT0?3`l0492@P0n?Sh0@41003/k>`0j>SX0?clo0P0n?Sh03P10@400?Shn03dm?@0o?cl0>CTi
03hn?P10@400?Cdm03Ti>@0m?Cd0@41003hn?P0o?cl0?Cdm0P0i>CT0200n?Sh0@D5103`l?00k>c/0
?Shn0410@00i>CT0?Shn0P0j>SX01P0k>c/0>CTi03dm?@0n?Sh0?clo03Xj>P80>c/k0100>SXj03lo
?`0o?cl0@41003hn?P13@d<0?3`l03Xj>P0n?Sh0ATI603hn?P0k>c/0?Cdm03Ph>00j>SX0@D510P0l
?3`03@0i>CT0>3Ph03`l?00m?Cd0?3`l03lo?`0m?Cd0?Shn03dm?@0l?3`0>c/k03`l?00o?cl0100m
?Cd0100h>3P0>SXj0492@P0o?cl203Ti>@80>SXj00H0?3`l03dm?@0k>c/0?Shn04=3@`0j>SX203`l
?00903/k>`0i>CT0?Cdm03Xj>P0o?cl0>CTi03Xj>P0k>c/0>CTi0080>SXj00D0?Cdm03hn?P0n?Sh0
>c/k03Ph>00203Ti>@0903Ph>00f=SH0>SXj03Xj>P0f=SH0?Shn03/k>`0o?cl0?Shn00<0>SXj00@0
>c/k03Ph>00i>CT0?Cdm0P0g=cL05@0j>SX0>c/k03`l?00k>c/0?3`l03hn?P0k>c/0?clo03Hf=P0k
>c/0?clo03dm?@1<C4`0MWIf08b<S01ZJVX0@41003Xj>P0i>CT0=cLg03`l?00203/k>`0703`l?00k
>c/0>c/k03Ti>@0g=cL0>CTi03Lg=`0303Ti>@80>c/k01H0>3Ph03De=@0i>CT0>c/k03dm?@0j>SX0
@41003hn?P0i>CT0>c/k0492@P0o?cl0@D5103dm?@0k>c/0?3`l03dm?@0k>c/0?Shn03Xj>P11@D40
?Shn0P12@T802`10@400ATI605aLG01MGEd0DE5A04=3@`0o?cl0?Shn0451@@0l?3`0?Cdm0080>c/k
00<0@D510410@00k>c/00P0i>CT02`0h>3P0>CTi03Xj>P0h>3P0>c/k0492@P10@400?Shn03/k>`0o
?cl0@T920080?Shn00@0?3`l03hn?P0l?3`0?Cdm0P0l?3`203dm?@80?3`l01P0>SXj03Ti>@0m?Cd0
>SXj03dm?@0o?cl0>CTi0451@@1ADE40JVYZ07]kN`2<S8`0QHF507MgM`1RHV80GemO05iNGP1OGel0
Lg=c09:BTP2ZZZX0`l?30=KFeP3Kfm/20=OGe`0<0=SHf03GemL0fm_K0=kNgP3Kfm/0f=SH0=?Cd`3H
f=P0i^KV0>GUi@3Lg=`0fm_K0P3Ng]h03@3Jf]X0fm_K0>?Sh`3YjNT0kNg]0>k^kP3[jn/0hn?S0=oO
g`3Cdm<0clo?0=;BdP3GemL00P3Kfm/0:`3GemL0bLW90;2`/02PX:00UIFE09VIV@2FUYH0UiNG0:JV
YP31`L40b<S80<K6aP2k^k/0];Bd0;no_`3>c/h0c<c<0<g=c@37alL0_;bl0;Jf]P2VYZH0WYjN0:FU
Y@2d];@0/k>c0;Bd]02/[:`0X:2P0:ZZZP2m_Kd0f][J0>KViP3Rh^80e=CD0<G5a@2ZZZX0SXj>07If
MP1iNGT0/k>c0=KFeP3MgMd03Oooool0013ooooo00P0DE5A05MGE`1IFET0E5AD04a<C01:BTX0CDe=
04Y:BP80B4Q800D0ATI604Q8B01<C4`0@d=304];B`0204M7A`0404];B`1<C4`0C4a<04];B`80C4a<
00D0B4Q804E5A@16ATH0AdM704Q8B00204Y:BP0L04Q8B019BDT0DE5A05aLG01IFET0FUYJ04a<C01>
CTh0DE5A04=3@`18B4P0BTY:04i>CP1CDe<0I6AT061PH01LG5`0GEeM04i>CP17AdL0Bd];04Y:BP1F
EUH0LW9b07MgM`23Ph<0JFUY055AD@80D51@02D0E5AD04U9B@18B4P0B4Q804E5A@1:BTX0ATI604M7
A`15ADD0A4A404U9B@1;Bd/0EUIF05MGE`1OGel0LW9b07alO01TI6@0Fe]K06][J`2?Shl0/[:b0<C4
a036a/H0`<300:>SX`2PX:00^KVi0<71`@2m_Kd0]kNg0<G5a@20P800Ogmo09NGU`1]KFd0B4Q80080
?clo00D0>SXj03hn?P0o?cl0?3`l03/k>`0203hn?P030410@00k>c/0?Shn0080?clo0180?Cdm03lo
?`0n?Sh0@41003`l?00j>SX0?3`l03Xj>P0k>c/0>SXj03dm?@0n?Sh0@D5103lo?`0l?3`0?Cdm03/k
>`0j>SX203`l?0<0>c/k00P0?3`l03Xj>P0k>c/0>CTi03`l?00j>SX0>CTi03`l?0@0@D510140@410
03hn?P0l?3`0>SXj03dm?@0l?3`0>SXj03dm?@0j>SX0@4100451@@0n?Sh0?3`l03dm?@0o?cl0AdM7
03/k>`0203dm?@0;03Xj>P0k>c/0?Shn03`l?00m?Cd0>SXj03`l?00k>c/0@41003/k>`0m?Cd00P0o
?cl02@0k>c/0?Shn0492@P0k>c/0>3Ph03/k>`0j>SX0?clo03dm?@030410@00303Xj>P0l?3`0?Cdm
0080@D510P0l?3`0100i>CT0>c/k0410@00n?Sh203Xj>P0:03`l?00k>c/0>c/k03dm?@0o?cl0>c/k
03dm?@0n?Sh0?3`l03/k>`80>CTi00`0=cLg03Xj>P0j>SX0>SXj03`l?00n?Sh0ADE50410@00l?3`0
?Cdm03`l?00j>SX203`l?00303Xj>P0i>CT0?3`l0080?Shn00T0>CTi03Ph>00j>SX0?Shn03/k>`10
@400>SXj03Ti>@0m?Cd00P0k>c/00`0i>CT0?Cdm03hn?P0203`l?00603hn?P0g=cL0=cLg03Ti>@0m
?Cd0@4100`0k>c/00`0i>CT0?clo03/k>`0203Ti>@0303Xj>P0m?Cd0>CTi0080>SXj01H0>3Ph03Xj
>P0i>CT0>c/k03Lg=`0k>c/0>CTi03hn?P11@D40ADE504Q8B01;Bd/0E5AD06=SH`1`L700XJ6Q09fM
W@1`L700CDe=0492@P0n?Sh0>SXj0P0n?Sh0100k>c/0?3`l03/k>`0j>SX303/k>`0A03`l?010@400
?3`l03Ti>@0k>c/0>SXj03Lg=`0i>CT0?Shn0410@00l?3`0?Shn0451@@0m?Cd0?Shn03lo?`11@D40
0P0m?Cd01010@400?Cdm0451@@14A4@20410@00=03dm?@13@d<0B4Q804Y:BP1ADE40D51@04Q8B017
AdL0A4A403lo?`10@400@T9203`l?00203/k>`0604A4A00o?cl0>c/k0410@013@d<0?clo0P0l?3`0
2@0i>CT0?3`l03/k>`0l?3`0>c/k03`l?00k>c/0?Shn03`l?00203dm?@0603`l?00m?Cd0>SXj03Xj
>P0i>CT0>c/k0P0l?3`203dm?@0G03/k>`0m?Cd0?Cdm03`l?010@400Fe]K071`L023Ph<0UiNG0:>S
X`2?Shl0NGUi05ADE017AdL0?Shn0492@P1=CDd0N7Qh09jNWP2f][H0aLG50<K6aP2g]kL00P2WYjL0
2`2KVi/0SHf=09JFUP2QXJ40/K6a0=WIf@3QhN40i>CT0>GUi@3QhN40h>3P0080i>CT00T0h>3P0=kN
gP3GemL0cLg=0=7Ad@3EeMD0c/k>0=CDe03Hf=P00P3Kfm/0<`3IfMT0d];B0=;BdP3EeMD0e=CD0=3@
d039bLT0b/[:0;no_`2g]kL0][Jf0;:b/P2_[jl0[:b/0:f][@2_[jl0`l?30<g=c@3Bd]80emOG0=;B
dP32`/80_[jn0=;BdP3MgMd0emOG0=GEe@3<c<`0a<C40;fm_@31`L40^k^k0<K6aP3:b/X0bl_;0=7A
d@3?cll0e]KF0=_Kf`3UiND0i>CT0>7Qh@3Rh^80gMgM0=SHf03Bd]80_Kfm0:>SX`2WYjL0_Kfm0<O7
a`0=ooooo`004?ooool0201@D500DU9B059BDP1?Cdl0Bd];04Y:BP1<C4`0BDU90P18B4P204M7A`0<
04Y:BP1<C4`0BTY:04E5A@1;Bd/0CDe=04U9B@16ATH0B4Q804U9B@1:BTX0BDU90`18B4P03P17AdL0
BTY:04Q8B014A4@0AdM704e=C@1<C4`0ATI604M7A`18B4P0BDU904M7A`16ATH0CDe=0P1:BTX0301?
Cdl0CDe=051@D01HF5P0GUiN04i>CP17AdL0ATI604M7A`1;Bd/0FEUI061PH080Hf=S00P0EeMG05mO
G`1[Jf/0Lg=c069RHP1ADE40G5aL075aL@80Ogmo02/0KVi^04e=C@16ATH0Bd];04e=C@1<C4`0Cdm?
05IFEP1:BTX0EUIF06MWI`1EEED0B4Q804I6AP1>CTh0GemO07inOP2ATI40Xj>S0:b/[02`/;00^[Zj
0;bl_02k^k/0_;bl0;6a/@2FUYH0HF5Q04e=C@1EEED0B4Q803hn?P1EEED0K6a/07=cL`1[Jf/0Fe]K
05UIF@1CDe<0ADE503hn?P10@400A4A40080?clo00P0@T9203`l?00o?cl0?Cdm03`l?00m?Cd0?3`l
03dm?@80@41000D0@D5103hn?P0l?3`0?3`l03/k>`0203`l?00<03Xj>P0l?3`0>CTi03/k>`0o?cl0
>SXj03`l?00o?cl0>SXj03`l?00i>CT0>c/k0P10@4001P0o?cl0?3`l03`l?00m?Cd0@D510410@080
>c/k00<0?3`l03Xj>P0l?3`00P0l?3`04011@D40?Shn03`l?00m?Cd0?Shn03lo?`14A4@0?Shn03dm
?@0j>SX0?3`l03lo?`0n?Sh0?3`l03dm?@0n?Sh203dm?@80?clo00`0@d=30492@P0k>c/0?3`l03hn
?P0l?3`0?Cdm03`l?00h>3P0?Cdm03lo?`11@D4203`l?00403Ti>@0n?Sh0?Shn03`l?080>c/k01<0
?3`l03hn?P0l?3`0?Shn0451@@0k>c/0?3`l03/k>`0i>CT0?3`l03dm?@0k>c/0?Cdm03hn?P0h>3P0
>SXj03dm?@0j>SX0>c/k0080>3Ph00H0=cLg03Xj>P10@400@41003lo?`0j>SX203hn?P0603/k>`0j
>SX0>c/k03/k>`0m?Cd0?Shn0P0l?3`203/k>`0503Hf=P0k>c/0>c/k03Ph>00k>c/00P0i>CT0300j
>SX0>CTi03/k>`0j>SX0?Cdm03hn?P0m?Cd0>SXj03/k>`0l?3`0>3Ph03Xj>P80>CTi00<0>c/k03Lg
=`0k>c/0100k>c/06P0l?3`0>CTi03Xj>P0j>SX0?3`l03/k>`10@400?3`l03Xj>P0n?Sh0>SXj03Ph
>00i>CT0ATI607UiN@24Q8@0F5QH05ADE01`L700QhN707AdM01^KVh0Fe]K04Y:BP0m?Cd0>SXj0P0h
>3P20410@00603`l?00j>SX0>c/k03Ti>@0h>3P0>SXj0P0h>3P203lo?`0A03Ti>@0g=cL0?3`l03Xj
>P0i>CT0>SXj03hn?P0j>SX0@T9204A4A00m?Cd0?Shn03`l?00n?Sh0?Cdm0410@00o?cl00P0k>c/0
200o?cl0@41004U9B@1GEeL0Hf=S06m_K`1NGUh0DE5A0P0o?cl04P10@400?Cdm03/k>`0m?Cd0>c/k
03Xj>P0l?3`0>c/k03lo?`0k>c/0>CTi03`l?00o?cl0?3`l03/k>`0h>3P0>CTi03Xj>P80>c/k00d0
>3Ph03dm?@0l?3`0?Cdm03`l?00m?Cd0?3`l0451@@0n?Sh0>c/k03hn?P0g=cL0>SXj0080?Cdm02D0
?3`l0451@@11@D40?Shn05iNGP23Ph<0^[Zj0<O7a`2d];@0UYJF07emO@1JFUX0D51@059BDP1LG5`0
KFe]0861P@2XZ:P0^[Zj0;Fe]@2FUYH0Ng]k05eMG@1=CDd0BTY:04M7A`1>CTh0IVIV08J6QP2c/k<0
b<S80=gMg@3Ogml0fMWI0<k>cP2o_kl0[Zj^0080Zj^[03d0/K6a0;Vi^@3?cll0f=SH0>?Sh`3Ph>00
b<S80;Ng]`2j^[X0_;bl0;:b/P2n_[h0clo?0=SHf03Jf]X0c/k>0;no_`2h^;P0]KFe0;Jf]P2o_kl0
[Zj^0:n_[`2l_;`0alO70=7Ad@3Ng]h0g=cL0=gMg@3Lg=`0f][J0=GEe@3Bd]80e]KF0=3@d03AdM40
fm_K0=?Cd`3>c/h0`L710:f][@2VYZH0[Jf]0:JVYP2[Zj/0YZJV0:^[Z`2o_kl0_Kfm0;Vi^@30`<00
b<S80<G5a@33`l<0a<C40<?3``2k^k/0`<300<S8b03;bl/0cLg=0080e=CD3Oooool0013ooooo0P1>
CTh01@1;Bd/0BDU904a<C01=CDd0C4a<00<0BDU90180BTY:04M7A`1;Bd/0AdM704I6AP19BDT0AdM7
04Q8B019BDT0ATI604M7A`19BDT0B4Q804M7A`18B4P0BDU904E5A@14A4@204I6AP0L04A4A019BDT0
Bd];04E5A@18B4P0BTY:04A4A016ATH0ADE503hn?P13@d<0@T9204U9B@15ADD0ATI604E5A@16ATH0
Bd];04I6AP13@d<0AdM70410@014A4@0AdM705EEE@1NGUh0IVIV051@D080ATI603H0Bd];04i>CP1F
EUH0IfMW07YjNP1lO7`0IVIV05EEE@1UIFD0N7Qh09NGU`2LW9`0I6AT04Y:BP11@D40@T9204Q8B015
ADD0?Shn04=3@`12@T80AdM704I6AP1@D500BDU905MGE`22PX80[Jf]0;^k^`2][Jd0UiNG0;Bd]02c
/k<0[Zj^09fMW@25QHD0Y:BT09jNWP1gMgL0IVIV05ADE01WIfL0P8200;Fe]@2d];@0TY:B08Z:RP1e
MGD0I6AT0492@P11@D40?clo0451@@10@40403dm?@80>c/k0`0o?cl01`0l?3`0?clo03dm?@0j>SX0
?3`l03dm?@0k>c/00P0i>CT203Xj>P0503Ti>@0j>SX0@D5103hn?P10@4000P0n?Sh01P10@400?clo
03`l?00j>SX0>CTi03/k>`80?Cdm00<0?clo03hn?P0l?3`00P0k>c/06`0l?3`0?Shn03dm?@0k>c/0
?Cdm03Ph>00k>c/0A4A404E5A@10@400>c/k03`l?00m?Cd0?clo0451@@0k>c/0?clo0410@00m?Cd0
?Shn04M7A`0m?Cd0@4100451@@0l?3`0?Shn03/k>`0303lo?`0603`l?00j>SX0?3`l03hn?P0i>CT0
?3`l0P0k>c/01@0m?Cd0?3`l03Xj>P0k>c/0?3`l00<0?Cdm0`0l?3`203Xj>P0803dm?@0k>c/0>3Ph
03Xj>P12@T80?Cdm03Ph>00n?Sh203/k>`0903Ti>@0m?Cd0>SXj03/k>`0o?cl0?3`l03lo?`10@400
@D5100@0>c/k01L0?3`l03Ti>@0h>3P0>c/k03Ph>00i>CT0>c/k03Ph>00k>c/0>SXj03Ti>@0k>c/0
=cLg03`l?00h>3P0=cLg03/k>`0l?3`0?Cdm03lo?`0n?Sh0?clo0451@@0203Xj>P<0?Cdm00T0>CTi
03Lg=`0o?cl0?3`l03/k>`0l?3`0>c/k03dm?@0j>SX00P0i>CT07P0l?3`0?Cdm03dm?@0h>3P0=CDe
03`l?00h>3P0?Cdm04I6AP1dM7@0UIFE08N7Q`1kNg/0NWYj07]kN`1[Jf/0Bd];03Xj>P0l?3`0>SXj
03Ph>00l?3`0>SXj03/k>`10@400>SXj03Ti>@0k>c/0>CTi03Lg=`80>CTi00d0>SXj03dm?@0m?Cd0
>CTi03/k>`0i>CT0>3Ph03Lg=`0j>SX0>3Ph03lo?`0k>c/0@4100080@D5102<0?3`l03Xj>P0l?3`0
>c/k03dm?@0k>c/0?3`l0410@013@d<0G5aL06i^KP1/K6`0I6AT04m?C`0l?3`0?Cdm03`l?00o?cl0
?Cdm0451@@0k>c/0>CTi03/k>`0o?cl0?Shn03`l?00o?cl0?Shn03dm?@0l?3`0>c/k03Xj>P0k>c/0
>SXj0410@00203dm?@0=03Ph>00k>c/0?Cdm03/k>`0m?Cd0>SXj03`l?00k>c/0?3`l03/k>`0j>SX0
?Cdm03Xj>P0203Ti>@0e03Xj>P12@T80G5aL08Z:RP2][Jd0/K6a0:VYZ@2=SHd0O7al07emO@2:RXX0
V9RH0:b/[02e]KD0^[Zj0<K6aP3>c/h0]KFe08^;R`1MGEd0DU9B0492@P11@D40BDU9065QH@22PX80
Vi^K0;^k^`3AdM40f][J0=cLg03<c<`0`<300:RXZ02ATI40O7al08N7Q`2;Rh/0X:2P0;6a/@2o_kl0
b/[:0<71`@2ZZZX0SXj>07]kN`1hN7P0P82009jNWP2j^[X0cLg=0=_Kf`3UiND00P3Ogml0203Ti>@0
h>3P0=cLg03MgMd0g]kN0>3Ph03MgMd0hN7Q0`3Shn<09@3Ti>@0hn?S0=kNgP3GemL0dM7A0=GEe@3H
f=P0g]kN0>7Qh@3Ng]h0fm_K0=3@d033`l<0^[Zj0:VYZ@2SXj<0/;2`0;fm_@2o_kl0[jn_0:6QX@2V
YZH0/[:b0;6a/@2i^KT0][Jf0:n_[`2][Jd0[Zj^0:RXZ02e]KD0a/K60<O7a`2o_kl0^KVi0<G5a@3K
fm/03Oooool0013ooooo00P0DE5A051@D01=CDd0CDe=04U9B@1=CDd0Bd];04M7A`<0B4Q800H0ADE5
04M7A`1:BTX0B4Q804A4A015ADD304I6AP0904M7A`19BDT0B4Q804I6AP15ADD0A4A404E5A@17AdL0
B4Q80080AdM700H0BTY:04];B`18B4P0Bd];04U9B@15ADD204I6AP0604Q8B016ATH0@T920451@@10
@400@d=30P17AdL07`16ATH0A4A40451@@18B4P0BDU904a<C018B4P0Bd];055AD@1HF5P0E5AD05MG
E`1TI6@0MWIf09NGU`2FUYH0M7Ad05EEE@19BDT0Cdm?05mOG`1]KFd0OWin08j>SP1oOgl0H61P06EU
I@1KFe/0EUIF05aLG01PH6000P1FEUH0:@1ADE40Bd];04Y:BP1;Bd/0BTY:04m?C`1CDe<0I6AT06EU
I@1SHf<0Ogmo08N7Q`2EUID0Y:BT0:VYZ@33`l<0emOG0<_;b`2b/[80TY:B09bLW02f][H0ZJVY08J6
QP24Q8@0MGEe08V9R@2JVYX0UiNG079bLP1ADE40@41005ADE01/K6`0MgMg075aL@1WIfL0HF5Q05iN
GP1ADE40B4Q80080?Shn0P0m?Cd01`0o?cl0?3`l03hn?P1=CDd0?Cdm03`l?00n?Sh00P0m?Cd03@0k
>c/0?Cdm03/k>`0j>SX0?Cdm03lo?`10@400?3`l03lo?`12@T80@D5103`l?00j>SX00P0k>c/02@0j
>SX0=cLg03Ph>00i>CT0>SXj03`l?00o?cl0?3`l03Xj>P0203dm?@80?3`l00D0?Shn0451@@0m?Cd0
?Shn03Ti>@0203lo?`0803Ph>00k>c/0?Cdm03hn?P0o?cl0AdM70410@011@D4203`l?00303dm?@0j
>SX0?Shn00<0?Cdm0P0k>c/00`0n?Sh0>SXj03Ti>@0203/k>`0603Lg=`0j>SX0>c/k03/k>`0i>CT0
>3Ph0`0k>c/00`0m?Cd0>SXj03Ti>@0203Xj>P0;03hn?P0l?3`0>CTi03`l?011@D40BTY:04=3@`10
@400?3`l03Xj>P0l?3`00`0n?Sh203dm?@0=0410@013@d<0?Shn04A4A00o?cl0>SXj03dm?@0l?3`0
?Shn03dm?@0g=cL0?Cdm03/k>`0203`l?00:03/k>`0j>SX0>c/k03Lg=`0j>SX0=CDe03Xj>P0m?Cd0
>SXj03/k>`80>SXj00@0@41003hn?P0n?Sh0?clo0P0i>CT0300j>SX0>3Ph03Ph>00k>c/0?Shn03lo
?`0k>c/0?Cdm03`l?00j>SX0>CTi03/k>`80>SXj0140?Cdm03`l?00i>CT0?clo059BDP1SHf<0Ph>3
09JFUP2PX:00SHf=06MWI`1:BTX0?Shn03dm?@0h>3P0?Cdm03Ti>@0303`l?00C03Ti>@0l?3`0?clo
03/k>`0l?3`0?clo03dm?@0k>c/0?3`l03Ph>00i>CT0?Cdm03Xj>P0h>3P0>SXj03Hf=P0l?3`0?Cdm
04E5A@0203Ti>@0K03`l?00o?cl0?Shn03hn?P13@d<0?Shn03dm?@0k>c/0?3`l03Ph>00k>c/0ATI6
04M7A`12@T80?Cdm03Ti>@0m?Cd0>SXj03/k>`0n?Sh0>SXj03lo?`0m?Cd0?clo03dm?@0n?Sh0>CTi
0080>c/k00@0?3`l03dm?@0h>3P0>3Ph0P0m?Cd04P0l?3`0>CTi03Xj>P12@T80?3`l03hn?P0j>SX0
?Shn03Xj>P0i>CT0>3Ph03Ti>@0j>SX0>3Ph03Xj>P0i>CT0>SXj03`l?080>c/k02H0ADE506MWI`2V
YZH0W9bL08B4Q01/K6`0EEEE05=CD`1bLW80U9BD09NGU`2@T900Q8B408J6QP2>SXh0N7Qh06i^KP1C
De<0AdM703lo?`18B4P0GemO071`L02OWil0a<C40<G5a@39bLT0[:b/09NGU`27QhL0O7al06m_K`1h
N7P0TY:B0;no_`3>c/h0b/[:0=7Ad@80d=3@00`0a<C40:JVYP2CTi<0QXJ6096AT@2MWId0`<300<g=
c@3EeMD0g]kN0=WIf@3Kfm/20=kNgP0N0=GEe@3De=@0g=cL0<_;b`2a/K40Zj^[0;Vi^@3:b/X0f=SH
0=OGe`3MgMd0g]kN0=OGe`3EeMD0e=CD0=7Ad@2m_Kd0[:b/09jNWP2CTi<0WIfM0;Bd]03EeMD0f][J
0=OGe`3Cdm<0clo?0<S8b03@d=00e=CD0P3Bd]804P38b<P0_[jn0;^k^`33`l<0bl_;0<c<c034a<@0
`L710<W9b@36a/H0/k>c0:NWY`2LW9`0QXJ60820P01hN7P0PH6109FEU@gooooo000@ooooo`<0CTi>
00D0CDe=04a<C01>CTh0CTi>04];B`0504Y:BP80BDU900@0B4Q804E5A@15ADD0ATI60P14A4@03P16
ATH0AdM704E5A@15ADD0A4A404E5A@1<C4`0CDe=04U9B@1;Bd/0AdM704I6AP17AdL0B4Q80P15ADD0
1`14A4@0ADE504I6AP17AdL0BDU904Y:BP15ADD00P12@T801017AdL0CTi>05=CD`18B4P204m?C`0L
04Y:BP1;Bd/0DE5A05ADE01HF5P0DE5A059BDP1ADE40G5aL07=cL`1oOgl0MWIf06EUI@1]KFd0JFUY
05mOG`1?Cdl0C4a<04Y:BP1>CTh0ADE5055AD@1EEED0BDU904I6AP1<C4`0E5AD04m?C`80DE5A00L0
C4a<04i>CP1?Cdl0CDe=04m?C`1VIVH0JFUY0080ATI602h0C4a<05ADE01GEeL0CTi>05QHF01VIVH0
KFe]06a/K01PH600Ng]k0:RXZ02QXJ40Zj^[0;no_`2WYjL0Ph>307IfMP1NGUh0PH6106QXJ017AdL0
G5aL09>CT`2m_Kd0`L710:n_[`27QhL0Ti>C08^;R`1oOgl0L71`04Q8B010@400BDU903hn?P10@400
@T9204A4A00n?Sh0?Cdm03`l?00k>c/0?Cdm03hn?P0m?Cd0?Shn0P0k>c/00`0l?3`0>c/k03Ti>@02
03/k>`0303dm?@0l?3`0>CTi0080?3`l00<0>SXj03hn?P0j>SX00P0j>SX04@0l?3`0@T9203/k>`12
@T80@D5103dm?@10@400?Cdm04=3@`15ADD0?Shn03lo?`0m?Cd0>c/k03dm?@0l?3`0>CTi0080?Shn
01P0?3`l03lo?`12@T80?Cdm03lo?`11@D40?Cdm03hn?P0k>c/0?3`l03hn?P0l?3`0?Cdm03hn?P0j
>SX0?Shn03/k>`0j>SX0?Cdm03Ph>00k>c/0>SXj03`l?00k>c/203`l?080>c/k00@0?Shn03dm?@0l
?3`0>c/k0P0j>SX0100m?Cd0>c/k03/k>`0l?3`203lo?`0=03`l?00o?cl0>3Ph03/k>`0j>SX0@T92
03Ti>@0l?3`0>SXj03dm?@12@T80@D5103hn?P0204=3@`0803`l?00h>3P0>c/k03`l?00k>c/0@T92
03Ph>011@D4203`l?00803Ti>@0j>SX0>SXj03/k>`0i>CT0>3Ph03`l?00m?Cd303/k>`0<03Xj>P0k
>c/0?Cdm03hn?P0k>c/0?3`l03Xj>P0m?Cd0>c/k03dm?@0k>c/0?Shn0P0i>CT203/k>`0>03Ph>00l
?3`0>SXj03`l?00n?Sh0>c/k04a<C01VIVH0Lg=c06=SH`1VIVH0KFe]05]KF`13@d<203Ti>@0H03dm
?@0h>3P0?Shn03`l?00i>CT0=SHf03/k>`10@400?Shn03Xj>P0h>3P0>CTi03/k>`0l?3`0?clo03`l
?00i>CT0?3`l03Ti>@0l?3`0?Shn03Xj>P0h>3P0>c/k0P0j>SX01@14A4@0?3`l03Ti>@0o?cl0@T92
0080>c/k00X0?clo03hn?P0l?3`0>SXj03Ti>@0n?Sh0@41004=3@`10@400@D510P13@d<05P0n?Sh0
?Cdm03lo?`11@D40?Cdm03/k>`0l?3`0?Shn03Xj>P11@D40>SXj03dm?@0l?3`0?Shn03dm?@0k>c/0
?3`l03lo?`0n?Sh0?3`l03Xj>P0l?3`203lo?`0603`l?00k>c/0?clo03lo?`0l?3`0>3Ph0P0i>CT0
4P0h>3P0>c/k03Ti>@0i>CT0?Shn04i>CP1WIfL0OGem06YZJP1;Bd/0@D5104a<C01MGEd0MgMg07in
OP1YJFT0DE5A0492@P<0?clo0180>SXj03lo?`0l?3`0?3`l0492@P13@d<0E5AD071`L01nOWh0Ogmo
07=cL`1KFe/0DE5A051@D01ADE40EeMG05IFEP1NGUh2061PH080IFEU0140JFUY06a/K02;Rh/0WYjN
0;Bd]03<c<`0f=SH0>3Ph03Ng]h0gmoO0=kNgP3Hf=P0d=3@0<O7a`30`<00]KFe0:JVYP0209>CT`0:
09BDU02ATI40TI6A09RHV02UYJD0][Jf0<_;b`3MgMd0h^;R0>?Sh`80i>CT00T0hN7Q0>3Ph03Kfm/0
fm_K0=KFeP3?cll0`l?309jNWP2XZ:P00P33`l<06P39bLT0`L710:RXZ02MWId0WYjN0:ZZZP2XZ:P0
aLG50=3@d03<c<`0^;Rh0;Bd]032`/80d=3@0=SHf03>c/h0/k>c09FEU@2:RXX0Q8B409>CT`2HV9P0
XZ:R0:JVYP2LW9`0SHf=3Oooool0013ooooo00H0BTY:04a<C01@D500CDe=04a<C01:BTX204];B`06
04I6AP17AdL0BDU904Y:BP18B4P0ADE50P16ATH01013@d<0ADE504E5A@14A4@304E5A@0704A4A015
ADD0ATI604E5A@19BDT0CDe=04I6AP0204E5A@0304I6AP15ADD0ADE50080A4A40P15ADD02014A4@0
@d=30492@P16ATH0A4A404=3@`18B4P0ATI60P18B4P02`15ADD0@D5104=3@`16ATH0AdM704I6AP14
A4@0ADE50492@P13@d<0@4100080ATI600/0ADE504Q8B01ADE40EEEE06=SH`1bLW80GEeM04];B`1:
BTX0C4a<04M7A`020492@P0504];B`18B4P0B4Q804e=C@1;Bd/00P1>CTh01P1GEeL0GUiN06EUI@1S
Hf<0Fe]K05aLG080IFEU00h0FUYJ04Q8B011@D40BTY:06QXJ01cLg<0J6QX05QHF01:BTX0CTi>04e=
C@1HF5P0DE5A05QHF080MGEe01/0FEUI05ADE01ADE40DE5A06IVIP1/K6`0HV9R04i>CP1ADE40I6AT
05aLG01GEeL0Fe]K06IVIP1dM7@0QhN709NGU`24Q8@0M7Ad06a/K01DE5@0AdM703`l?00o?cl0?Shn
04M7A`1ADE400P1BDU803@13@d<0?Shn03/k>`0k>c/0?3`l03/k>`0l?3`0?Cdm03/k>`0l?3`0?Cdm
03Ti>@0g=cL00P0h>3P00`0l?3`0>c/k03/k>`0203/k>`0;03lo?`0m?Cd0?clo03/k>`0m?Cd0@T92
03`l?00o?cl0@d=303lo?`10@4000P0k>c/01@0n?Sh0?clo03`l?00k>c/0?3`l00<0?Cdm00`0?Shn
04E5A@0m?Cd0>c/k03lo?`0k>c/0?clo03dm?@0j>SX0>c/k03Xj>P0f=SH203/k>`0503Ti>@0k>c/0
=cLg03hn?P0m?Cd00P0k>c/203`l?00703hn?P0m?Cd0?Shn03hn?P0m?Cd0@D5103lo?`0203hn?P80
?3`l00@0?Shn03`l?00k>c/0?3`l0P0m?Cd01`0j>SX0?Shn04=3@`16ATH0?Cdm03/k>`0l?3`00P10
@4003@0n?Sh0@T9203dm?@0n?Sh0>3Ph03Ti>@10@400@D5103lo?`0j>SX0?clo03`l?00j>SX00`0i
>CT203hn?P0=03/k>`0l?3`0>CTi03Ph>00k>c/0?3`l03hn?P0i>CT0>SXj03/k>`0o?cl0?Shn03`l
?00203Xj>P0:03hn?P0j>SX0>c/k03Ph>00n?Sh0>c/k03hn?P0h>3P0ADE504e=C@80@d=300@0>SXj
03hn?P0o?cl0?clo0P13@d<0200k>c/0>SXj03De=@0h>3P0>SXj03dm?@0n?Sh0?3`l0P0h>3P03`0k
>c/0?Cdm03/k>`0j>SX0>c/k03`l?00i>CT0>3Ph03Ti>@0g=cL0>SXj03/k>`0m?Cd0>CTi03Xj>P02
03hn?P0S03Xj>P0l?3`0?3`l03/k>`10@400?Cdm03Lg=`10@400>c/k03Xj>P0l?3`0?Shn04=3@`15
ADD0A4A40410@012@T80>CTi03/k>`0n?Sh0?3`l04U9B@1TI6@0GemO05QHF018B4P0?Cdm03/k>`0i
>CT0>SXj03/k>`0g=cL0?3`l03De=@0m?Cd00P0h>3P02@0j>SX0?3`l03/k>`0m?Cd0@41003hn?P0j
>SX0A4A403hn?P0303Xj>P0603/k>`0h>3P0=SHf03Ti>@0h>3P0>CTi0`0k>c/03@1<C4`0NWYj07em
O@1DE5@0@D5103Xj>P1>CTh0GemO07=cL`1YJFT0GEeM04M7A`0k>c/00P0n?Sh04`0o?cl0>c/k03dm
?@0l?3`0@D510410@017AdL0B4Q804=3@`1;Bd/0De=C05]KF`1bLW80OGem07AdM01UIFD0C4a<04I6
AP0n?Sh00`0l?3`07@16ATH0DU9B05MGE`1NGUh0KVi^092@T02TY:@0ZJVY09^KV`2?Shl0Ogmo07Mg
M`1bLW80IVIV05aLG01BDU80ATI60410@012@T80AdM705YJFP1hN7P0TI6A0:BTY02k^k/0bl_;0=KF
eP3Bd]80c/k>0080b/[:01/0alO70<71`@30`<00_[jn0<_;b`3Bd]80d=3@0;Vi^@33`l<0emOG0=cL
g03Hf=P0dM7A0<30`031`L40`<300;Vi^@2n_[h0`<300<k>cP3?cll0e=CD0=KFeP33`l<0];Bd0:VY
Z@2OWil00P2^[Zh02@2KVi/0Ogmo06IVIP1MGEd0LG5a09>CT`2IVIT0UiNG0:NWY`020:^[Z`gooooo
000@ooooo`<0C4a<00D0Bd];04a<C01:BTX0BDU904];B`0404U9B@80B4Q800P0AdM704I6AP15ADD0
A4A404=3@`14A4@0ADE504I6AP<0ADE500<0AdM704I6AP15ADD00P17AdL02P1;Bd/0AdM704I6AP14
A4@0ATI604A4A013@d<0A4A40451@@12@T8304E5A@80@T9201h0A4A40451@@0o?cl0@D510492@P15
ADD0BTY:04I6AP13@d<0@D510410@014A4@0ADE504=3@`14A4@0@d=304E5A@0o?cl0?Shn0492@P15
ADD0@41004Q8B014A4@0@41004=3@`15ADD0A4A40451@@12@T820410@00804=3@`0n?Sh0@41003lo
?`14A4@0@T920451@@16ATH20492@P0A04e=C@1PH600KFe]06YZJP1XJ6P0IfMW06a/K01fMWH0OWin
07YjNP1iNGT0Kfm_069RHP1WIfL0IVIV06YZJP1bLW800P1iNGT06@1eMGD0KVi^07=cL`1WIfL0Ogmo
09FEU@2MWId0Vi^K08R8R01OGel0GEeM05]KF`1TI6@0IfMW05QHF01WIfL0[Zj^0;Rh^01kNg/0EeMG
04a<C013@d<0?Shn03lo?`0m?Cd00`10@4001`11@D40?clo03dm?@0m?Cd0?3`l03hn?P0k>c/00`0l
?3`01P0m?Cd0?3`l03/k>`0l?3`0?Cdm03`l?080>SXj00D0?3`l03hn?P0n?Sh0?clo03`l?00203dm
?@0;03lo?`14A4@0@41003hn?P12@T80?3`l03dm?@0l?3`0>SXj03Ti>@0h>3P00P0j>SX04@0i>CT0
>3Ph03`l?00j>SX0?Cdm0492@P0o?cl0?3`l03/k>`0m?Cd0>c/k03lo?`10@400?3`l03Ph>00j>SX0
>CTi0080>SXj0P0l?3`03`0o?cl0>c/k03Xj>P0n?Sh0>3Ph03/k>`0l?3`0?Cdm03/k>`0m?Cd0?3`l
03/k>`0n?Sh0?clo03/k>`0203dm?@0?0410@00j>SX0>c/k03lo?`0l?3`0@D5103dm?@10@400>SXj
04A4A010@400>SXj03`l?00n?Sh0>SXj0080?3`l01<0?Cdm03`l?00j>SX0?Shn0410@00l?3`0>CTi
03`l?00j>SX0?3`l03Xj>P0k>c/0>3Ph03`l?00j>SX0>CTi03Xj>P0i>CT0>SXj00<0?Cdm00L0>c/k
03Ti>@0j>SX0?Shn03Ti>@0k>c/0?Shn0080?3`l00`0@d=303hn?P0m?Cd0>3Ph03hn?P0g=cL0B4Q8
04I6AP1>CTh0@41003`l?00n?Sh203Xj>P0503lo?`0j>SX0?Shn03lo?`0l?3`00P0k>c/203Xj>P03
03Ph>00j>SX0=cLg0080>SXj00l0>c/k03Xj>P0m?Cd0?Shn03Xj>P0n?Sh0?Cdm03Ti>@0k>c/0>SXj
03Ph>00g=cL0>SXj03Lg=`0i>CT00P0l?3`08`0k>c/0>CTi03lo?`12@T80?clo0451@@0l?3`0?Cdm
03`l?00k>c/0=cLg0410@016ATH0Bd];04=3@`0l?3`0?Cdm0492@P1;Bd/0EUIF06EUI@1WIfL0GEeM
05=CD`12@T80>c/k03Ti>@0j>SX0>CTi0451@@0n?Sh0>SXj03`l?00k>c/0@T920080>c/k00D0?Cdm
03hn?P0j>SX0>CTi03lo?`0203`l?080>CTi00<0?Cdm03lo?`0n?Sh00P0l?3`05`0i>CT0>SXj03Ti
>@0i>CT0>SXj03Ti>@15ADD0JFUY04];B`16ATH0Cdm?05eMG@1SHf<0Fe]K04E5A@0n?Sh0?clo03/k
>`10@400>c/k03`l?00j>SX0@4100080?Cdm00@0?Shn04=3@`12@T80E5AD0P1[Jf/04P24Q8@0RXZ:
08>3P`1dM7@0GUiN04M7A`0o?cl0>CTi03hn?P14A4@0ATI604U9B@1ADE40FEUI05=CD`1<C4`0@d=3
0451@@80>c/k00<0?Shn03`l?00n?Sh00P0n?Sh08P10@400ADE503`l?00o?cl0@D5104I6AP1HF5P0
N7Qh09RHV02[Zj/0YjNW08n?S`1gMgL0L71`06UYJ@1`L700NGUi07moO`2:RXX0Ti>C09fMW@2k^k/0
alO70<k>cP3EeMD0clo?0;no_`2e]KD0/K6a0;:b/P2d];@0_;bl0<o?c`3AdM420=?Cd`80f=SH01D0
e]KF0=[JfP3EeMD0a/K60<;2`P38b<P0eMGE0=KFeP3@d=00cLg=0<;2`P2m_Kd0_;bl0;Vi^@3=cLd0
bl_;0<71`@2n_[h0^;Rh0;Ng]`2c/k<03Oooool0013ooooo00P0DU9B055AD@1<C4`0CDe=04];B`1<
C4`0BTY:04a<C080B4Q80P17AdL01018B4P0A4A404I6AP14A4@204I6AP0404Q8B014A4@0B4Q804M7
A`80ADE500D0A4A404I6AP17AdL0AdM704U9B@0304M7A`0704Q8B017AdL0ATI604I6AP11@D40ATI6
04Y:BP0204I6AP050492@P14A4@0@T920492@P10@4000P15ADD04016ATH0A4A40410@013@d<0@T92
04E5A@17AdL0ADE504=3@`15ADD0@T9204I6AP10@400@d=30492@P0n?Sh20410@00603dm?@17AdL0
@41003`l?00n?Sh0@4100P14A4@02`0o?cl0?Cdm04E5A@12@T80?Cdm03`l?010@400?clo03hn?P10
@400@d=30080@D5102`0?Shn0492@P11@D40?clo04I6AP12@T80ATI60492@P13@d<0@D510410@01A
DE40LW9b06i^KP1DE5@0Fe]K061PH01VIVH0HF5Q075aL@1dM7@0N7Qh07IfMP1gMgL0PH6109FEU@28
R8P0M7Ad075aL@1iNGT0IFEU05iNGP1IFET0BDU905QHF01]KFd0KVi^059BDP16ATH0J6QX06m_K`20
P800I6AT04];B`<0AdM700h0Bd];05IFEP1QHF40Lg=c08N7Q`24Q8@0M7Ad05iNGP16ATH0?Cdm03lo
?`0k>c/0?3`l03lo?`<0?3`l01`0>c/k03`l?00m?Cd0?Cdm03`l?013@d<0B4Q80410@00n?Sh0@D51
03hn?P0l?3`0>c/k0410@00n?Sh0>CTi03/k>`0j>SX0?Cdm03hn?P0l?3`0=SHf03`l?00j>SX0>3Ph
03/k>`0l?3`0?Shn0P0l?3`04P0o?cl0>CTi03`l?00o?cl0>3Ph03Ti>@0n?Sh0>c/k03`l?00k>c/0
?Cdm03Xj>P0k>c/0?Cdm03hn?P11@D40>c/k03hn?P<0>SXj00<0>c/k03lo?`0m?Cd00P11@D406018
B4P0@41003lo?`0m?Cd0>CTi03/k>`0o?cl0@T9203lo?`0n?Sh0@D510410@012@T80ADE503/k>`0i
>CT0>SXj03Ph>00n?Sh0>SXj03/k>`0o?cl0>SXj03Lg=`80>SXj0240?3`l03Ph>00l?3`0>c/k03dm
?@0l?3`0>3Ph03dm?@0j>SX0?Shn0451@@0i>CT0>SXj03/k>`0j>SX0>CTi03Xj>P0l?3`0>SXj03Ph
>011@D40?Cdm03`l?00j>SX0?Cdm04A4A00h>3P0>c/k03hn?P0o?cl0D51@06ATI00n?Sh00P0j>SX0
1P0o?cl0>SXj03Hf=P0f=SH0?Shn03Xj>P80>c/k00d0?3`l03hn?P0l?3`0>3Ph03Xj>P0l?3`0=cLg
03Xj>P0f=SH0>3Ph03Ti>@0l?3`0?Shn0080>CTi01<0?Cdm03`l?00j>SX0>3Ph0451@@0o?cl0?Cdm
03Xj>P0f=SH0>CTi03dm?@0g=cL0=SHf03Xj>P0k>c/0>SXj03Ti>@0j>SX0>CTi0080?Cdm00H0>SXj
0410@00n?Sh0?Shn0492@P11@D420492@P0:04U9B@1:BTX0?Shn03/k>`0m?Cd0>SXj03/k>`0h>3P0
?clo0410@080>c/k00L0@d=303hn?P0k>c/0>SXj03/k>`19BDT0?clo0080?3`l00D0?Cdm03`l?00j
>SX0?Shn03Xj>P0203Ti>@0703Xj>P0f=SH0>SXj03Lg=`0k>c/0@D5103dm?@0303Xj>P0@03/k>`15
ADD0Cdm?05iNGP1mOGd0Xj>S092@T01WIfL0A4A403Ph>00j>SX0?3`l03dm?@0k>c/0>CTi03dm?@80
?3`l01/0?Cdm03/k>`0k>c/0CTi>061PH01hN7P0OGem0861P@1]KFd0Fe]K059BDP11@D40>CTi03Xj
>P0h>3P0?clo03dm?@0l?3`0BTY:04Q8B010@400>CTi03Xj>P0i>CT0>3Ph03Xj>P0f=SH00P0j>SX2
03`l?00c03dm?@0h>3P0?Shn03`l?00m?Cd0@d=304];B`1KFe/0JVYZ06IVIP1bLW80Kfm_07IfMP1i
NGT0Q8B409^KV`2c/k<0^;Rh0;no_`3@d=00e]KF0=GEe@3Fe]H0dM7A0<c<c02l_;`0b<S80=_Kf`3L
g=`0e=CD0=GEe@38b<P0^k^k0;fm_@2g]kL0[:b/0:FUY@2XZ:P0Y:BT0;2`/02b/[80a/K60<k>cP3:
b/X0_[jn0;bl_037alL0c<c<0<C4a02l_;`0/K6a0080^[Zj00T0];Bd0;6a/@2b/[80eMGE0>?Sh`3A
dM40TI6A06e]K@1LG5`03Oooool0013ooooo0P1?Cdl01P1>CTh0Bd];04Y:BP1:BTX0B4Q804Y:BP80
BDU90P16ATH04014A4@0ATI604a<C018B4P0AdM704U9B@1:BTX0@T9204I6AP13@d<0ATI604E5A@13
@d<0AdM704];B`1:BTX504M7A`0T04U9B@17AdL0AdM704M7A`13@d<0A4A403lo?`13@d<0ATI604A4
A016ATH0Bd];04Q8B017AdL0ADE504=3@`14A4@0ADE504I6AP11@D40@41004=3@`16ATH0B4Q804=3
@`1:BTX0B4Q804A4A012@T80@d=30492@P0o?cl0?Shn03lo?`11@D40?3`l0P0o?cl01`13@d<0ADE5
04A4A011@D40?Shn04=3@`10@4000P12@T802011@D40?clo03lo?`10@400?clo04M7A`15ADD0@d=3
0P10@40203hn?P0L04E5A@19BDT0ATI604U9B@1CDe<0J6QX06i^KP1[Jf/0C4a<04M7A`14A4@0@T92
04=3@`11@D40BTY:04Q8B01GEeL0Hf=S07IfMP1ADE40@T9204=3@`12@T80CDe=06EUI@1RHV80IFEU
07=cL`80KVi^00<0P82007QhN01YJFT00P1LG5`05P1HF5P0NGUi0:b/[02o_kl0_Kfm0:j^[P2ATI40
S8b<0:NWY`2k^k/0clo?0<[:bP32`/80dm?C0;jn_P1gMgL0Bd];04A4A00l?3`0?clo04A4A00n?Sh2
0410@00404e=C@1:BTX0@T9203lo?`80?3`l00d0@41003lo?`0l?3`0AdM704A4A00k>c/0?Cdm04=3
@`0m?Cd0?3`l03hn?P0j>SX0>CTi0080>c/k00d0?Cdm0410@00i>CT0?3`l03/k>`0l?3`0?Cdm03lo
?`0n?Sh0>SXj03`l?00n?Sh0?Cdm0080>CTi00L0?Cdm03Xj>P0j>SX0>c/k03dm?@0h>3P0>CTi0080
>SXj00@0?3`l03Xj>P0l?3`0>c/k0P0n?Sh00`0j>SX0>CTi03Xj>P0203lo?`0<0410@00l?3`0?3`l
03`l?00o?cl0>c/k03hn?P11@D40?clo03dm?@0o?cl0@D510`0j>SX01`0k>c/0>CTi03Ph>00i>CT0
>3Ph03`l?00o?cl00P0k>c/02@0j>SX0>3Ph03Lg=`0i>CT0=SHf03Xj>P0m?Cd0>c/k03`l?00203Xj
>P0403Ti>@0j>SX0?Shn03/k>`80>3Ph01T0=cLg03Ph>00h>3P0>CTi03De=@0h>3P0?Cdm03lo?`0n
?Sh0DU9B04=3@`10@400>CTi03Xj>P13@d<0D51@04M7A`10@400>SXj03Ti>@11@D40>CTi03Lg=`0k
>c/0>SXj0080?3`l00`0>c/k03`l?00j>SX0>SXj03`l?011@D40?clo03Ph>00j>SX0=SHf03Lg=`0k
>c/203Xj>P0903Hf=P0i>CT0>c/k03/k>`0l?3`0>SXj03dm?@0l?3`0>c/k0080=cLg00/0>CTi03dm
?@0k>c/0?Cdm0492@P13@d<0>SXj03dm?@0o?cl0?3`l03Xj>P0203`l?00I03Xj>P10@400?clo0410
@00o?cl0>c/k03Ti>@0j>SX0>CTi03Xj>P0i>CT0>c/k03`l?011@D40>c/k03`l?00n?Sh0>SXj03hn
?P0j>SX0>CTi0451@@13@d<0?Shn0451@@0203/k>`80>3Ph00D0>SXj03`l?00l?3`0>c/k03Xj>P02
03`l?00;03/k>`0l?3`0>3Ph0410@00l?3`0>c/k03dm?@1>CTh0Jf][092@T02MWId00P2LW9`06@25
QHD0F5QH04A4A00j>SX0?Cdm03Ph>00i>CT0>SXj03/k>`12@T80@41004M7A`13@d<0A4A404];B`1C
De<0Jf][07QhN01]KFd0GemO055AD@18B4P0@T9203hn?P0g=cL00P0f=SH04@0k>c/0>SXj03Xj>P0k
>c/0>SXj03lo?`14A4@0?3`l03Ti>@0g=cL0>SXj03`l?00h>3P0>CTi03Ph>00i>CT0>3Ph0080>CTi
0P0l?3`07`11@D40?Shn0492@P12@T80CDe=06ATI023Ph<0Y:BT0=7Ad@3Ti>@0gMgM0<_;b`2f][H0
X:2P096AT@1lO7`0Jf][069RHP1KFe/0EEEE05ADE01JFUX0KVi^08b<S02YZJT0/;2`0;Fe]@2_[jl0
XJ6Q08R8R01gMgL00P1/K6`06P1hN7P0O7al07moO`2PX:00]KFe0<S8b03AdM40clo?0=?Cd`3GemL0
fMWI0=KFeP3?cll0bLW90=3@d039bLT0`l?30<S8b034a<@0_[jn0;Vi^@31`L40b<S80:n_[`2IVIT0
Xj>S3Oooool0013ooooo00D0CTi>04a<C01>CTh0CDe=04a<C00204U9B@0904a<C018B4P0BDU904Q8
B017AdL0BDU904M7A`13@d<0BDU90080BTY:00`0B4Q804I6AP1<C4`0AdM704=3@`15ADD0ATI604M7
A`18B4P0ATI604A4A015ADD204=3@`0F04A4A015ADD0A4A404I6AP14A4@0@d=305]KF`1CDe<0ADE5
0492@P16ATH0Bd];04E5A@11@D40?clo0492@P14A4@0@T920410@012@T80@d=30492@P80@D5100T0
@T9203lo?`15ADD0A4A404=3@`0n?Sh0@41003lo?`0l?3`00P0n?Sh00`11@D40@T9203lo?`0203hn
?P0:03lo?`10@400@D510492@P10@400?Shn03dm?@0l?3`0?clo0492@P80?Cdm1010@4003013@d<0
@D5104e=C@1SHf<0LG5a05ADE01CDe<0H61P05EEE@1@D500?Shn0410@080?clo02H0?Cdm03`l?00l
?3`0@41004=3@`1ADE40J6QX09fMW@2/[:`0Ng]k06IVIP1aLG40KFe]069RHP1FEUH0CDe=04m?C`1B
DU80E5AD05YJFP1aLG40WinO0;fm_@2j^[X0];Bd09VIV@1lO7`0Ng]k08b<S02;Rh/0NWYj08F5Q@2R
XZ80Zj^[0;2`/02e]KD0^;Rh0:NWY`80Rh^;00d0S8b<071`L01YJFT0IVIV071`L01bLW80RHV908^;
R`2<S8`0YjNW08F5Q@1TI6@0@T920080@4100P0m?Cd204A4A00:04=3@`0m?Cd0?Shn03dm?@0l?3`0
?Shn0451@@0m?Cd0?3`l03dm?@80>c/k0100?Cdm03Ph>00k>c/0>c/k03dm?@0l?3`0=CDe03Ph>00i
>CT0>c/k03dm?@0i>CT0>SXj03Hf=P0j>SX0>CTi0P0j>SX01P0k>c/0>CTi03/k>`0k>c/0>3Ph03Ti
>@80>3Ph01D0?Cdm03hn?P0l?3`0>c/k03Ti>@12@T80?Cdm03Ti>@0m?Cd0>3Ph03`l?00n?Sh0@T92
03hn?P0o?cl0?Cdm03Xj>P0l?3`0>3Ph03/k>`0m?Cd00P0k>c/06P0i>CT0?3`l03lo?`0j>SX0>3Ph
03`l?00o?cl0?3`l03/k>`0l?3`0>c/k03dm?@0k>c/0>CTi03`l?00m?Cd0=cLg04I6AP10@400?clo
03dm?@0j>SX0?3`l03Xj>P0n?Sh0>3Ph0P0g=cL00`0j>SX0?Shn03`l?00203hn?P0D03/k>`0m?Cd0
?Shn03`l?00k>c/0?Cdm03hn?P13@d<0>c/k04M7A`12@T80>SXj03Ti>@0l?3`0?Cdm03Xj>P0l?3`0
>3Ph03Lg=`0h>3P203Ti>@0503Ph>00m?Cd0?clo03Xj>P0h>3P00`0i>CT02@0h>3P0>SXj03Xj>P0m
?Cd0>SXj03Lg=`0j>SX0?3`l03Xj>P0203hn?P0Z0410@00j>SX0>CTi03Ph>00i>CT0>SXj03dm?@0j
>SX0>c/k03Xj>P0o?cl0?3`l03dm?@0n?Sh0@41003/k>`0m?Cd0ADE50451@@0l?3`0?clo03dm?@0l
?3`0>CTi03De=@0i>CT0@41003/k>`0j>SX0=cLg03/k>`0m?Cd0?Shn03dm?@0l?3`0?Cdm03Ti>@0m
?Cd0@T9203dm?@0g=cL0=3@d0P0j>SX07@0i>CT0?Shn03dm?@0m?Cd0>SXj03Ph>00j>SX0?3`l03dm
?@0l?3`0>c/k03`l?00i>CT0@D5104a<C01hN7P0a<C40=WIf@3;bl/0YZJV06EUI@13@d<0?Shn04A4
A013@d<0?3`l03hn?P0o?cl0?3`l0080?clo00d0BDU905EEE@1`L700Ng]k08Z:RP1nOWh0G5aL05MG
E`11@D40=SHf03Xj>P0i>CT0=cLg00<0>CTi00d0=cLg03Hf=P0g=cL0>CTi03Lg=`0k>c/0?3`l03Xj
>P0k>c/0=SHf03/k>`0l?3`0>CTi0080>c/k01L0>CTi03Ph>00i>CT0>3Ph03Xj>P11@D40DU9B06EU
I@1YJFT0MgMg096AT@2SXj<0`L710=7Ad@3Shn<0i^KV0<W9b@2VYZH0QhN705mOG`18B4P0@41003`l
?00303dm?@0F03/k>`0h>3P0@D5104a<C01ADE40CDe=05ADE01TI6@0Ph>308f=S@2TY:@0_kno0<K6
aP3<c<`0dm?C0=[JfP3IfMT0c<c<0<W9b@2n_[h0`<300=3@d080g=cL0140h>3P0=_Kf`2n_[h0Z:RX
0:FUY@2i^KT0/k>c0:^[Z`2][Jd0VIVI09ZJVP2e]KD0/;2`0:RXZ02PX:00YjNW0:>SX`0=ooooo`00
4?ooool0401?Cdl0CDe=04i>CP1>CTh0CDe=04];B`1<C4`0CDe=04I6AP17AdL0BTY:04U9B@18B4P0
BDU904M7A`18B4P304I6AP0304M7A`18B4P0AdM70080BDU90P18B4P01017AdL0ATI604I6AP17AdL3
04I6AP0K0492@P13@d<0A4A404A4A011@D40D51@04a<C010@400A4A40492@P19BDT0@d=304A4A015
ADD0ATI604A4A019BDT0ATI604E5A@12@T80?Shn0451@@15ADD0B4Q803hn?P0o?cl0@d=300<0@410
0P0o?cl01@13@d<0@D5104I6AP1<C4`0AdM70080@D5100<0ADE504=3@`10@4000P0n?Sh04P14A4@0
@41003lo?`17AdL0ADE50451@@10@400ADE504I6AP11@D40?Cdm03hn?P0k>c/0@41004A4A00m?Cd0
>CTi0410@080@D5103T0DU9B0451@@0o?cl0?Shn03Ti>@0l?3`0DU9B06IVIP1ZJVX0MgMg092@T02:
RXX0Shn?08R8R02CTi<0TY:B0:6QX@2CTi<0QHF508J6QP20P800Ogmo096AT@2PX:00XZ:R09VIV@2F
UYH0O7al079bLP21PH40YJFU0<G5a@2c/k<0WYjN0:ZZZP2NWYh0Shn?09^KV`2FUYH0MgMg05eMG@1F
EUH0FUYJ04Y:BP1_Kfl0Y:BT0;Bd]02o_kl0YZJV08b<S02;Rh/0[Zj^0=CDe03?cll0a/K606=SH`13
@d<00`10@4002P0k>c/0@d=304e=C@15ADD0@T9203Ph>011@D40?Shn0410@015ADD203dm?@040451
@@13@d<0@41003Xj>P80?Cdm00@0>CTi03De=@0m?Cd0?clo0P0j>SX00`0i>CT0?Cdm03lo?`0203/k
>`0>03Ph>00i>CT0>3Ph03`l?00i>CT0>c/k03`l?00n?Sh0?3`l03Ph>00i>CT0>c/k03`l?011@D42
03/k>`0703`l?00n?Sh0?3`l03hn?P0j>SX0>3Ph03Ti>@0203`l?00:03hn?P0m?Cd0@D5103hn?P0g
=cL0>3Ph03dm?@0l?3`0?Cdm03/k>`80?clo00L0?Shn03lo?`0j>SX0>c/k03dm?@0j>SX0>c/k0080
?clo00d0>c/k03lo?`0n?Sh0@d=303`l?00i>CT0=SHf03dm?@0h>3P0>c/k03Xj>P0g=cL0>3Ph0080
>CTi00<0=cLg03hn?P0j>SX00`0l?3`02@15ADD0?clo03Ph>00k>c/0?3`l0410@012@T80@41003Xj
>P0203/k>`040410@00n?Sh0>c/k03lo?`80?3`l00X0>SXj03dm?@0n?Sh0=SHf03Ti>@0k>c/0?3`l
03Ph>00i>CT0>c/k0P0g=cL203/k>`0503hn?P0l?3`0?Cdm03Ph>00j>SX00P0i>CT01P0l?3`0>SXj
03Ph>00n?Sh0?3`l03lo?`80>SXj00D0?3`l03hn?P0n?Sh0>c/k03Ti>@0303/k>`0=03dm?@0i>CT0
>3Ph03/k>`0l?3`0?Shn0410@00i>CT0>c/k0410@00o?cl0>SXj03hn?P0203Ti>@0<03/k>`0i>CT0
?Cdm03Xj>P0n?Sh0@T9203lo?`0i>CT0?clo0451@@0l?3`0>c/k0`0l?3`01@0j>SX0>c/k03dm?@0k
>c/0?clo0080?3`l0P0i>CT203Xj>P80?3`l00`0>c/k0410@00k>c/0FUYJ0:VYZ@3Fe]H0bLW909>C
T`1bLW80Bd];03lo?`12@T8204U9B@0504=3@`0n?Sh0@T920492@P10@4000P11@D40201CDe<0LG5a
0861P@1`L700FEUI04E5A@0h>3P0>c/k0P0i>CT203Xj>P0<03Hf=P0i>CT0>3Ph03@d=00k>c/0>3Ph
03Ti>@0j>SX0>CTi03Hf=P0i>CT0?Cdm0P0l?3`0>00k>c/0=cLg03dm?@0o?cl0CTi>051@D01<C4`0
@D5104m?C`1PH600Ng]k0:6QX@2o_kl0WYjN0;Zj^P3Ph>00i>CT0>_[j`3MgMd0dM7A0;Bd]01iNGT0
Lg=c05iNGP1:BTX0?Shn03Xj>P0n?Sh0>SXj03hn?P10@400BTY:05YJFP1[Jf/0MWIf08>3P`2JVYX0
]KFe0<?3``3Hf=P0gMgM0>CTi03Ogml0c<c<0<;2`P2j^[X0`<300;^k^`2m_Kd0`<300;Ng]`2o_kl0
c/k>0<G5a@2b/[80c/k>0P3Cdm<0303Shn<0g=cL0=cLg03Jf]X0g=cL0=OGe`3?cll0c/k>0=GEe@3G
emL0cLg=0<W9b@80clo?3Oooool0013ooooo00`0CTi>051@D01=CDd0CDe=04a<C01;Bd/0CDe=04];
B`19BDT0AdM704Y:BP1;Bd/304Y:BP0:04I6AP18B4P0C4a<04a<C01;Bd/0B4Q804M7A`1:BTX0Bd];
04Q8B080BDU901@0ATI604M7A`15ADD0@d=304I6AP17AdL0ADE504U9B@15ADD0A4A404];B`15ADD0
?clo04M7A`1<C4`0BDU9059BDP1>CTh0@D5104M7A`80B4Q800d0ADE504=3@`14A4@0A4A404=3@`15
ADD0A4A40492@P16ATH0AdM704E5A@0n?Sh0@4100080?Shn00@0?clo0492@P13@d<0?Shn0P13@d<0
6@10@400?Cdm0410@011@D40?clo0492@P10@400@T920451@@0m?Cd0@D5104M7A`11@D40?clo04E5
A@12@T80@d=303hn?P0o?cl0@D5103dm?@11@D40?Shn03/k>`0n?Sh00P0m?Cd0>`0o?cl0@D5104=3
@`0n?Sh0@T9204A4A01RHV80N7Qh071`L01TI6@0GemO05IFEP1CDe<0I6AT08f=S@2<S8`0JFUY06=S
H`1BDU80FEUI05eMG@1JFUX0GEeM061PH01dM7@0L71`06IVIP1KFe/0C4a<061PH01iNGT0Q8B407em
O@2NWYh0^;Rh0<g=c@3>c/h0c<c<0<o?c`37alL0[Zj^08B4Q01/K6`0GUiN08n?S`2n_[h0b<S80=;B
dP3;bl/0a/K608j>SP1cLg<0Ogmo0:VYZ@2SXj<0LG5a05aLG01>CTh0BDU90080BTY:00D0@4100451
@@0l?3`0@D5103/k>`0203`l?00>0492@P14A4@0@T9203`l?00o?cl0@41003dm?@0k>c/0?3`l03dm
?@10@400=cLg03/k>`11@D4203`l?00E03dm?@0l?3`0>SXj03hn?P0k>c/0?3`l03/k>`0i>CT0?3`l
03Xj>P0n?Sh0?3`l03/k>`0l?3`0>c/k03Ti>@0o?cl0?Shn03Ti>@0m?Cd0@D510080?3`l00P0@410
03lo?`0j>SX0>3Ph03Ti>@0l?3`0>c/k03`l?080?Shn00D0?3`l03lo?`0k>c/0>c/k03Xj>P0203Ti
>@0@03`l?00k>c/0?3`l03lo?`0l?3`0?Shn03dm?@0i>CT0>c/k03dm?@0k>c/0?Cdm03/k>`11@D40
@41003`l?080>3Ph0`0j>SX203Ti>@0803Xj>P0k>c/0>SXj03`l?00k>c/0>CTi03/k>`0i>CT203hn
?P0803dm?@0i>CT0?clo03hn?P10@400@d=304E5A@0l?3`203dm?@0@03Ti>@0o?cl0>3Ph03dm?@0j
>SX0?3`l03dm?@0j>SX0>c/k03Ph>00j>SX0>c/k03Xj>P0g=cL0>3Ph03Ti>@80>3Ph00H0?Cdm03hn
?P0m?Cd0>CTi03dm?@0j>SX203Ti>@0403Xj>P0l?3`0>SXj03Ph>080>c/k00D0>SXj03Ti>@0i>CT0
?3`l03dm?@0203Xj>P0;03Lg=`0k>c/0?Shn03dm?@0o?cl0>CTi03lo?`14A4@0@D5103hn?P0k>c/0
0`0j>SX203Ti>@0303hn?P0h>3P0?3`l0080>SXj00D0?clo03Xj>P12@T80@T9203`l?00203lo?`03
0451@@12@T80?Cdm0080?3`l02h0>SXj03lo?`0k>c/0@41003Ti>@0n?Sh0>c/k03`l?00m?Cd0?3`l
03Xj>P0i>CT0?Cdm03lo?`0n?Sh0@41006e]K@2EUID0WIfM07moO`1IFET0AdM704A4A01:BTX0GEeM
065QH@1HF5P0G5aL055AD@1:BTX0@d=303`l?00k>c/0>SXj03`l?01<C4`0CDe=04Q8B00o?cl0?Shn
03/k>`0h>3P0=cLg03Ti>@0j>SX0>CTi0P0h>3P0B@0i>CT0=SHf03Hf=P0l?3`0=SHf03Xj>P0e=CD0
>CTi03Ph>00g=cL0>3Ph03/k>`0f=SH0@T9205ADE01OGel0JFUY06MWI`1ADE40C4a<04Q8B017AdL0
DE5A061PH026QXH0YZJV0=3@d03Ng]h0emOG0<O7a`2VYZH0TI6A075aL@1HF5P0ATI604E5A@0o?cl0
@41003`l?010@400A4A405mOG`1VIVH0PH610;Ng]`36a/H0cLg=0<O7a`33`l<0`/;20;Fe]@2TY:@0
WYjN0:2PX02RXZ80Ti>C07moO`2KVi/0Zj^[0<K6aP3;bl/0e=CD0=KFeP3Cdm<0a/K60;^k^`2`/;00
UIFE09:BTP2DU9@0V9RH09VIV@2DU9@00P2FUYH02P2IVIT0Vi^K0;fm_@32`/80]kNg0;bl_02k^k/0
/;2`0:>SX`2HV9P=ooooo`004?ooool0101;Bd/0CTi>04e=C@1<C4`304];B`0804i>CP19BDT0BDU9
04U9B@1<C4`0AdM704Y:BP18B4P204E5A@0G04m?C`17AdL0B4Q804U9B@14A4@0C4a<04Q8B01;Bd/0
BDU904Q8B017AdL0A4A404=3@`17AdL0BDU904A4A013@d<0BDU904Y:BP18B4P0AdM704=3@`11@D40
0P12@T800`19BDT0ATI604E5A@0304=3@`0404I6AP14A4@0ATI60492@P80@D5100T0@T9204=3@`11
@D40@D510410@013@d<0@T9203lo?`10@4000P11@D403@10@400CTi>04E5A@0o?cl0?Shn04I6AP13
@d<0?clo03hn?P11@D40A4A404E5A@13@d<00P11@D402`0o?cl0@d=304U9B@16ATH0A4A40492@P11
@D40@T9204I6AP0l?3`0?clo0080@D5100@0?Shn0492@P18B4P0@d=30P16ATH01@17AdL0ATI60492
@P0n?Sh0?clo0080ATI600/0C4a<065QH@1IFET0BTY:061PH025QHD0T92@06e]K@1bLW80HF5Q04Y:
BP0204a<C00[05ADE01HF5P0CDe=04m?C`1FEUH0FEUI061PH01NGUh0I6AT08:2PP1^KVh0I6AT08F5
Q@2PX:00/K6a0:n_[`2c/k<0[jn_0;Vi^@31`L40b<S80;bl_02^[Zh0Xj>S09RHV027QhL0Lg=c09RH
V02WYjL0X:2P07alO01^KVh0RXZ:0;Bd]034a<@0`<300;>c/`2i^KT0^;Rh09nOW`1HF5P0AdM70410
@00204E5A@0:0451@@12@T80CTi>0410@00k>c/0@T9204E5A@0o?cl0?3`l03Ti>@80?clo00@0BTY:
03hn?P0n?Sh0?3`l0P0j>SX02P0n?Sh0>CTi03dm?@0j>SX0?3`l03Xj>P0k>c/0?3`l03Xj>P0h>3P2
03Ti>@0=03hn?P0m?Cd0?Cdm0410@00i>CT0?3`l04=3@`11@D40?3`l03hn?P10@400?Cdm0410@002
03dm?@0G03/k>`0j>SX0?3`l03/k>`10@400@T9203lo?`0j>SX0?Cdm03`l?00n?Sh0>c/k03Ti>@0k
>c/0@41003hn?P0k>c/0?3`l04A4A00k>c/0>CTi03`l?00n?Sh00`0l?3`00`0j>SX0=cLg03`l?002
03dm?@080451@@0l?3`0>CTi03hn?P0j>SX0?Cdm03/k>`0g=cL203Xj>P0703hn?P10@400?clo03/k
>`0n?Sh0?3`l03Ti>@0203lo?`0<04=3@`0o?cl0>c/k03dm?@0j>SX0>c/k03dm?@0i>CT0>SXj03/k
>`0h>3P0>SXj0P0l?3`03@0h>3P0?Cdm03Ph>00j>SX0>CTi03dm?@0j>SX0>3Ph03Xj>P0k>c/0>CTi
03Xj>P0l?3`00P0j>SX0100o?cl0>CTi03Ti>@0h>3P203Xj>P0603/k>`0l?3`0>CTi03`l?00m?Cd0
?Shn0P0h>3P02P0j>SX0>c/k03hn?P0m?Cd0>c/k03Ph>013@d<0?clo0410@00o?cl303/k>`0403Xj
>P0m?Cd0?clo03Xj>P@0>c/k00`0>CTi03lo?`13@d<0@D5103`l?00k>c/0@41003lo?`0j>SX0?3`l
03Ti>@0j>SX203Ph>00404=3@`0j>SX0>CTi03Xj>P80>c/k00@0>SXj03/k>`0n?Sh0?Shn0`0l?3`0
400j>SX0ADE505UIF@19BDT0@41004M7A`1KFe/0NWYj0:>SX`2d];@0]KFe0:NWY`2CTi<0KVi^04a<
C00n?Sh203Ti>@0803Xj>P0h>3P0>CTi03Ti>@0g=cL0?3`l03Ti>@0f=SH303Ti>@80>3Ph00<0=cLg
03Hf=P0i>CT00P0h>3P06`0i>CT0>c/k03Ph>00i>CT0>SXj03Lg=`0k>c/0?3`l03/k>`11@D40EUIF
05mOG`1DE5@0C4a<04M7A`0n?Sh0>3Ph03`l?00j>SX0A4A4065QH@2VYZH0`L710;>c/`2EUID0R8R8
06i^KP0206=SH`0f05YJFP1HF5P0Cdm?03lo?`0j>SX0>CTi03`l?00j>SX0?clo04E5A@1LG5`0GUiN
06m_K`1aLG40LW9b07=cL`1UIFD0E5AD04Y:BP1?Cdl0BDU904M7A`11@D40A4A404I6AP1DE5@0Lg=c
08Z:RP2CTi<0UiNG08^;R`21PH40JVYZ05QHF01>CTh0ADE504I6AP17AdL0Cdm?059BDP1CDe<0IVIV
08>3P`2EUID0Y:BT0:>SX`2OWil0];Bd0:f][@2l_;`0/;2`0:n_[`2YZJT0Xj>S3Oooool0013ooooo
0P1>CTh01@1<C4`0BTY:04M7A`18B4P0BTY:0080AdM700<0A4A404];B`1:BTX00P18B4P02`17AdL0
ADE504Q8B01:BTX0AdM704=3@`18B4P0AdM704=3@`16ATH0B4Q80080BTY:00T0B4Q804I6AP14A4@0
ADE504M7A`19BDT0AdM704E5A@17AdL00P16ATH01@14A4@0@d=304E5A@1;Bd/0B4Q80080AdM700<0
A4A404Y:BP19BDT00P15ADD00`14A4@0ATI604E5A@0204A4A01104I6AP18B4P0A4A404=3@`0o?cl0
@41004=3@`11@D40ATI60492@P15ADD0DE5A04U9B@12@T80?clo0492@P0o?cl0@D5103lo?`10@400
@D510492@P11@D40?clo04=3@`12@T80ATI6059BDP1DE5@0Fe]K059BDP14A4@0ADE503Xj>P0m?Cd0
>c/k03`l?010@400?clo05MGE`1VIVH0H61P065QH@1ZJVX0P82007UiN@1:BTX0@d=30451@@16ATH0
BDU904e=C@1ADE40GUiN06i^KP24Q8@0QXJ608^;R`22PX80KFe]05ADE014A4@0ATI604A4A010@400
0P0n?Sh0:016ATH0BDU904I6AP12@T80A4A404Q8B01UIFD0Kfm_05IFEP1NGUh0N7Qh08N7Q`2?Shl0
LG5a079bLP2<S8`0WYjN092@T02;Rh/0U9BD09VIV@2<S8`0JVYZ06a/K02BTY80Xj>S0:^[Z`2=SHd0
QHF506i^KP2JVYX0YjNW09NGU`1iNGT0LW9b09FEU@2m_Kd0]kNg096AT@1VIVH206ATI007065QH@1J
FUX0IFEU04I6AP0k>c/0AdM703Xj>P0203lo?`0704E5A@1]KFd0O7al09NGU`2CTi<0GEeM03lo?`02
03`l?00503Ph>00j>SX0>SXj03hn?P0k>c/00P0j>SX203Ti>@0503dm?@0n?Sh0>CTi03lo?`10@400
0`0o?cl01@11@D40@d=303lo?`10@400?3`l0080?clo00<0?Cdm03Ti>@0j>SX00`0i>CT0900o?cl0
>c/k03Ph>00j>SX0>CTi03Xj>P0i>CT0>SXj03hn?P0m?Cd0>c/k0451@@0i>CT0>3Ph03dm?@0l?3`0
?Cdm03Ph>00j>SX0?clo0410@00k>c/0>SXj03hn?P0o?cl0?Cdm03lo?`0h>3P0?Cdm03/k>`0o?cl0
>c/k03Ti>@0l?3`0?Cdm03`l?080>SXj00L0>CTi03dm?@0m?Cd0>3Ph03/k>`0j>SX0>c/k0080?3`l
01D0?clo03Hf=P0k>c/0?3`l03dm?@0g=cL0>CTi03`l?00i>CT0>SXj03/k>`0l?3`0>c/k03Xj>P0m
?Cd0?clo03/k>`0j>SX0>3Ph03Lg=`0h>3P00P0f=SH203Ti>@0Z03Ph>00i>CT0?Shn03Ph>00g=cL0
>CTi03Xj>P0k>c/0>SXj03Ph>011@D40>3Ph03dm?@0o?cl0?Shn0410@00j>SX0>c/k03dm?@0j>SX0
?Cdm03hn?P0i>CT0@41003`l?016ATH0@d=30410@00n?Sh0@D5103lo?`10@400>c/k04U9B@0n?Sh0
>c/k03Xj>P0k>c/0?3`l03/k>`0n?Sh0?Cdm0P0l?3`01@0k>c/0@41004E5A@0l?3`0>SXj0080>3Ph
00D0>c/k03Xj>P0n?Sh0>CTi03/k>`0203Ti>@0:03Xj>P0k>c/0?3`l03`l?00j>SX0?Cdm03/k>`12
@T80@41005=CD`80Jf][00d0QhN70:f][@2c/k<0`/;20<30`02OWil0NGUi05UIF@15ADD0?clo03Lg
=`0k>c/0>3Ph0080>CTi0`0k>c/02@0f=SH0=cLg03Hf=P0l?3`0=cLg03Hf=P0h>3P0>CTi03Xj>P02
03Ti>@0403Xj>P0k>c/0>CTi03Ph>080?3`l00`0?Cdm03Xj>P0e=CD0>CTi03dm?@0l?3`0@D510492
@P10@400?Shn03`l?00m?Cd203Xj>P0?04];B`1NGUh0OWin0820P01eMGD0KVi^06IVIP1ZJVX0GemO
05ADE011@D40?3`l03Xj>P0l?3`0>CTi0080=cLg0P0h>3P0;`0i>CT0@41003lo?`0m?Cd0>3Ph03Ti
>@0k>c/0>3Ph03Xj>P0n?Sh0>c/k03hn?P0l?3`0>c/k03Xj>P0o?cl0BTY:05YJFP29RHT0XZ:R0:RX
Z02MWId0QXJ607IfMP1oOgl0PX:209jNWP2WYjL0WIfM09RHV02b/[80bLW90<O7a`33`l<0c<c<0<G5
a@3:b/X0bLW90;no_`2k^k/0bl_;0=?Cd`3De=@0b<S80<[:bP3=cLd0f=SH00gooooo000@ooooo`09
04a<C01=CDd0BDU904a<C019BDT0BTY:04a<C017AdL0BDU90080B4Q800h0Cdm?04M7A`16ATH0AdM7
04Q8B017AdL0@d=304I6AP15ADD0BDU904Q8B014A4@0BDU904E5A@80AdM700L0ATI604Q8B016ATH0
ATI604Q8B016ATH0A4A40080ATI600@0A4A404I6AP15ADD0ADE50P14A4@01010@400A4A404I6AP11
@D4204=3@`0404A4A017AdL0ADE504I6AP80A4A40`13@d<03010@400ADE504E5A@15ADD0B4Q804U9
B@14A4@0@41003`l?013@d<0@D5104A4A080?Shn00@0?Cdm04=3@`0o?cl0?Shn0P0m?Cd01P0n?Sh0
?3`l0410@010@400?clo04E5A@80@d=300h0@D5104I6AP10@400?Shn0410@00o?cl0?3`l03dm?@0o
?cl0?3`l0410@012@T80@41005EEE@80LW9b04L0HF5Q06EUI@1QHF40MgMg08>3P`1^KVh0FEUI05YJ
FP1ZJVX0I6AT05YJFP1BDU80CDe=0492@P0o?cl0>CTi03lo?`11@D40?clo03hn?P0o?cl0@T9204=3
@`14A4@0@T920410@00m?Cd0ATI604A4A018B4P0CTi>05EEE@1GEeL0D51@04=3@`19BDT0C4a<05aL
G01YJFT0Jf][07QhN02CTi<0YjNW0:VYZ@25QHD0Ph>30:6QX@2b/[80YJFU07UiN@1PH600OGem09FE
U@2`/;00^k^k0;Bd]02DU9@0PX:2096AT@2m_Kd0X:2P07=cL`1/K6`0MGEe08n?S`2VYZH0SHf=05IF
EP10@400?Cdm03`l?00203hn?P0=05ADE01@D500B4Q804=3@`12@T80@41003Xj>P0k>c/0?clo0492
@P0k>c/0?Shn03`l?00203lo?`080410@00n?Sh0>c/k03hn?P0j>SX0?Shn03dm?@0n?Sh403/k>`07
03Xj>P0n?Sh0>c/k04M7A`0o?cl0?Cdm0451@@0303hn?P0603`l?00n?Sh0?3`l03`l?00m?Cd0?3`l
0`0k>c/01010@400?Shn0451@@10@40203lo?`060451@@0m?Cd0>c/k03`l?00k>c/0>CTi0`0j>SX0
200k>c/0?3`l03Hf=P0j>SX0=SHf0451@@0l?3`0?Cdm0P0l?3`02@0k>c/0@4100451@@0o?cl0?Shn
03Xj>P0l?3`0>c/k03Ph>00203Xj>P0303`l?00j>SX0>CTi00<0>SXj00D0?3`l0451@@0k>c/0>c/k
03lo?`0303Xj>P0>03dm?@0k>c/0?3`l055AD@10@400>CTi03De=@10@400>CTi03Xj>P0i>CT0?Shn
03dm?@0j>SX203Lg=`0903hn?P0j>SX0>c/k03dm?@0j>SX0?Shn03lo?`0j>SX0@D510080>SXj00@0
>CTi03Ph>00o?cl0>SXj0P0m?Cd03@0i>CT0>c/k03`l?00k>c/0?Shn03Xj>P0m?Cd0>CTi03`l?010
@400@D5104A4A018B4P00P0o?cl02@0l?3`0>SXj03Xj>P0l?3`0?Shn03/k>`0l?3`0>c/k03lo?`02
03`l?00603hn?P0j>SX0>CTi03/k>`0m?Cd0>CTi0P0m?Cd00`0j>SX0=cLg03Ti>@0203dm?@0F03hn
?P11@D40@D5104U9B@1@D500G5aL06MWI`23Ph<0S8b<0861P@2EUID0Ti>C0;Zj^P2IVIT0JVYZ05AD
E017AdL0@D5104=3@`0k>c/0>CTi03/k>`<0>CTi01<0>SXj03Ph>00i>CT0=cLg03Ph>00i>CT0>c/k
03Ti>@0g=cL0=SHf03Ti>@0k>c/0>SXj03Ph>00g=cL0>3Ph03Xj>P0k>c/0?clo0080@41000<0?3`l
03Ti>@0j>SX00P0i>CT0600m?Cd0?3`l03hn?P0k>c/0?Shn0410@011@D40DE5A06][J`21PH40Ti>C
09JFUP1lO7`0M7Ad06UYJ@1XJ6P0Fe]K04=3@`0h>3P0>SXj03Ph>00j>SX0>CTi03/k>`80>CTi00P0
>c/k03Ti>@0h>3P0=cLg03Ti>@0k>c/0>CTi03`l?080>c/k0P0j>SX07@0k>c/0>CTi0410@00l?3`0
?Shn03lo?`1CDe<0JVYZ07IfMP2CTi<0P82006UYJ@1/K6`0OWin09jNWP2j^[X0c/k>0<;2`P2`/;00
Vi^K08j>SP2UYJD0^;Rh0<g=c@3GemL0dm?C0<o?c`3De=@0f][J0080e]KF00L0e=CD0=WIf@3Cdm<0
d];B0=3@d03Kfm/0f][J00gooooo000@ooooo`0;04e=C@1HF5P0C4a<04];B`1:BTX0Bd];04U9B@18
B4P0AdM704U9B@18B4P00P1:BTX00`17AdL0B4Q804U9B@0204I6AP0;04E5A@13@d<0ADE504=3@`15
ADD0BTY:04Q8B016ATH0A4A404M7A`18B4P00P13@d<02@17AdL0B4Q804A4A012@T80AdM704Q8B014
A4@0ADE504I6AP020492@P0904=3@`16ATH0ATI604Q8B015ADD0@D5104A4A013@d<0AdM70080ADE5
0`12@T820410@00;04E5A@16ATH0?Shn03lo?`11@D40A4A403lo?`0n?Sh0BDU903Ti>@0j>SX00`0o
?cl04011@D40?Cdm0410@011@D40?Shn0451@@0l?3`0?Shn03dm?@0n?Sh0@41004=3@`0m?Cd0?clo
0492@P11@D420492@P0B04A4A016ATH0@T920410@00m?Cd0BDU903dm?@1:BTX0D51@05]KF`1HF5P0
Fe]K05IFEP1LG5`0GUiN05QHF01=CDd0ADE50P13@d<0A`0m?Cd0?Shn03/k>`12@T80?Shn03/k>`0m
?Cd0?3`l03/k>`0o?cl0?Cdm04E5A@1FEUH0I6AT06QXJ01YJFT0Jf][07MgM`1fMWH0N7Qh079bLP1P
H600Hf=S06IVIP1PH600GEeM071`L020P800WinO0:>SX`1mOGd0IVIV05ADE017AdL0C4a<04m?C`1J
FUX0M7Ad08V9R@2?Shl0MgMg06QXJ01UIFD0K6a/07=cL`1hN7P0MgMg06m_K`1CDe<0EeMG05UIF@1_
Kfl0O7al065QH@1:BTX0BDU905IFEP1]KFd0Ogmo08J6QP1SHf<0FEUI06YZJP2CTi<0^k^k0<71`@2]
[Jd0RHV906ATI011@D40@d=30080@41000@0>3Ph03`l?00k>c/0>c/k0`0l?3`0100k>c/0>3Ph03/k
>`0j>SX20410@00403`l?00k>c/0?3`l03lo?`80>SXj00L0=cLg03`l?00o?cl0>SXj03lo?`10@400
>c/k0080?3`l01@0>SXj03Ti>@0j>SX0>SXj03/k>`0l?3`0>CTi03/k>`0h>3P0?3`l03lo?`0k>c/0
@D5103lo?`0n?Sh0?3`l0410@00o?cl0@41003dm?@80>c/k00P0?Cdm03/k>`0k>c/0@41003Ti>@0k
>c/0@41003hn?P80?clo00@0@D5103Xj>P0i>CT0>SXj0P0i>CT203Ph>00D03Xj>P0k>c/0?3`l03Ti
>@0n?Sh0?3`l03Xj>P0o?cl0>SXj03dm?@0j>SX0?3`l03hn?P0j>SX0=cLg03/k>`0j>SX0?Cdm03Xj
>P0m?Cd303Ti>@0903Xj>P0k>c/0?3`l03/k>`0j>SX0?3`l03Ph>010@400?clo0080?Cdm00L0>c/k
03Xj>P0j>SX0?Shn03`l?00i>CT0?3`l0080?Cdm00H0?3`l03Ti>@0l?3`0?Shn03Xj>P11@D4203Xj
>P0603lo?`0l?3`0?Shn03hn?P0k>c/0?clo0P0j>SX06`0o?cl0>c/k03/k>`0i>CT0@d=303lo?`13
@d<0?3`l03/k>`0n?Sh0@T9204A4A00k>c/0?3`l0410@00m?Cd0@41003hn?P0k>c/0?clo0410@00l
?3`0>CTi03`l?00j>SX0?Cdm03hn?P0203`l?00A03Xj>P0k>c/0?Shn04A4A01RHV80VIVI0:VYZ@2F
UYH0QHF50861P@1iNGT0KVi^05mOG`1QHF40EEEE04I6AP0o?cl00`0k>c/00`0o?cl0?Shn03Ti>@02
03Xj>P0703Ti>@0j>SX0?3`l03Ti>@0j>SX0>CTi03Xj>P0303Ph>0<0>CTi00L0=cLg03Ph>00g=cL0
>3Ph03Ti>@0j>SX0@T920080?Cdm01/0?clo03Xj>P0h>3P0>3Ph03Xj>P0m?Cd0?3`l03dm?@0l?3`0
?clo0492@P1JFUX0QHF50:NWY`2][Jd0VIVI08N7Q`1fMWH0Lg=c05]KF`1@D500?Shn03dm?@0j>SX0
>CTi03/k>`0i>CT00P0k>c/01P0n?Sh0>CTi03Xj>P0g=cL0>c/k03hn?P80>3Ph0P0l?3`203lo?`05
03`l?00h>3P0>SXj03/k>`0m?Cd00P0n?Sh08`0m?Cd0@4100410@013@d<0A4A40410@011@D40IVIV
09bLW02/[:`0WinO09JFUP28R8P0QHF508N7Q`2HV9P0/;2`0<30`03EeMD0d=3@0=CDe03Cdm<0b/[:
0;Rh^02_[jl0]KFe0<71`@3>c/h0d];B0=GEe@3Cdm<0g=cL0=_Kf`3QhN40gMgM00gooooo000@oooo
o`0404m?C`1BDU80CDe=04a<C080CDe=0P19BDT01`17AdL0B4Q804I6AP19BDT0AdM704I6AP1:BTX0
0`18B4P01P17AdL0ATI604Q8B014A4@0ATI604Q8B0<0A4A40200AdM704Y:BP17AdL0ATI604M7A`18
B4P0ADE504Q8B017AdL0ATI604A4A013@d<0@T9204=3@`11@D40@T9204A4A015ADD0B4Q8055AD@1>
CTh0@T920410@014A4@0ATI604M7A`12@T80@d=304A4A011@D40@41004Q8B080@D5100D0?Shn04=3
@`13@d<0@T920451@@0303hn?P050451@@0m?Cd0?Shn0410@00o?cl00P10@4000`0n?Sh0?clo03lo
?`0303lo?`0K0451@@13@d<0ATI60410@00n?Sh0?clo04I6AP10@400@d=303dm?@10@400?Shn03dm
?@15ADD0Bd];05EEE@1?Cdl0De=C04=3@`10@400@D5104I6AP0o?cl0?3`l03/k>`11@D40>SXj0080
>c/k00D0?Shn03`l?00n?Sh0>c/k03Ti>@0203`l?00303Xj>P0k>c/0?Cdm0080@T9201D0ATI603hn
?P1:BTX0JFUY06e]K@1VIVH0IfMW05YJFP1BDU80EUIF05ADE015ADD0@D5104M7A`1=CDd0Bd];04E5
A@11@D40?Shn04A4A00h>3P00P0n?Sh0500o?cl0@d=30451@@13@d<0A4A405EEE@28R8P0UYJF08:2
PP1JFUX0EeMG05eMG@1GEeL0GUiN06a/K01ZJVX0MGEe07MgM`1XJ6P0CTi>0P18B4P0101]KFd0YJFU
0;jn_P3AdM420=?Cd`0=0<K6aP30`<00/k>c0;2`/02LW9`0Shn?0:NWY`2OWil0O7al05aLG00m?Cd0
@T9205YJFP0206e]K@0405MGE`11@D40?Cdm03hn?P80@41000/0>SXj03dm?@10@400?Shn0410@00k
>c/0>3Ph03/k>`0m?Cd0>CTi03/k>`020410@00@03/k>`0j>SX0?3`l03`l?00k>c/0>SXj03`l?00m
?Cd0>CTi03dm?@0l?3`0>c/k03Xj>P0l?3`0@4100451@@80?3`l00H0>c/k0492@P0n?Sh0?Cdm03hn
?P0k>c/203Xj>P0I03dm?@0j>SX0>SXj03Ph>00l?3`0AdM70451@@0j>SX0>c/k03hn?P0k>c/0>CTi
03/k>`0l?3`0>c/k03Lg=`0i>CT0?3`l03hn?P0h>3P0>c/k03Xj>P0l?3`0>SXj03dm?@0203hn?P09
03`l?00m?Cd0?3`l03lo?`0i>CT0>SXj03/k>`0m?Cd0=CDe0080>3Ph00X0?clo03`l?00h>3P0>c/k
03Xj>P0l?3`0?clo03hn?P0k>c/0>3Ph0P0i>CT00`0k>c/0?Shn03`l?00303Ti>@0803Ph>00m?Cd0
?Shn03Xj>P0i>CT0>SXj03/k>`11@D4203hn?P0H04=3@`0n?Sh0@T9204Q8B013@d<0@T9204=3@`11
@D40>SXj03lo?`10@400?3`l03Xj>P0k>c/0>CTi03Xj>P0i>CT0?3`l03Hf=P0h>3P0?3`l03hn?P0j
>SX0?3`l0P0n?Sh00`0l?3`0@D510451@@020492@P0J04E5A@1JFUX0EEEE03lo?`0h>3P0?Cdm03lo
?`0j>SX0>CTi03hn?P10@400EUIF08B4Q01nOWh0K6a/05MGE`19BDT0De=C06ATI01^KVh0PX:208F5
Q@1TI6@0A4A403`l?00i>CT203`l?00503Xj>P0k>c/0>c/k03Xj>P0h>3P01@0k>c/0100i>CT0?3`l
03Ph>00g=cL203Ti>@0<03Lg=`0j>SX0>3Ph03Lg=`0h>3P0=cLg03Ti>@0h>3P0>SXj03Lg=`0i>CT0
=cLg0P0j>SX203Ph>00C03Ti>@0n?Sh0@41005=CD`1jNWX0ZZZZ0=kNgP3EeMD0[Jf]09FEU@2<S8`0
JFUY05MGE`0j>SX0>c/k03Ph>00j>SX0>c/k03dm?@0203Xj>P0@03Ti>@0h>3P0=cLg03Xj>P0h>3P0
=cLg03Ti>@0m?Cd0>SXj03`l?00k>c/0?Shn03`l?011@D40@41003`l?080>SXj02L0>c/k0451@@12
@T80>c/k03dm?@0n?Sh0@D5104e=C@1WIfL0NWYj08Z:RP2<S8`0QXJ607alO02IVIT0Z:RX0:ZZZP2e
]KD0/K6a0;fm_@33`l<0[Zj^09>CT`1fMWH0G5aL04i>CP1EEED0Cdm?05QHF01IFET0GUiN065QH@1l
O7`0YJFU0=7Ad@3Ng]h0gmoO0=SHf03>c/h03Oooool0013ooooo00D0CTi>04a<C01<C4`0CDe=04Y:
BP0204Q8B080ATI60P17AdL01019BDT0BTY:04Q8B018B4P304E5A@80ATI600@0B4Q804E5A@15ADD0
AdM70P16ATH00`17AdL0ADE504I6AP0204M7A`0304E5A@17AdL0AdM70080ATI600X0B4Q804A4A013
@d<0A4A404E5A@18B4P0BDU904E5A@0o?cl0ADE50P13@d<01`14A4@0B4Q804I6AP15ADD0@T9204A4
A011@D400P13@d<03@11@D40@T9204=3@`0o?cl0AdM704E5A@14A4@0?Shn03lo?`0m?Cd0@41003hn
?P0o?cl00P10@400600n?Sh0?clo04=3@`13@d<0@D5104E5A@16ATH0A4A403lo?`10@400@d=30410
@012@T80?Cdm03hn?P12@T80@41004=3@`15ADD0@4100451@@0m?Cd0@4100451@@<0>c/k00D0?Cdm
03`l?013@d<0?Cdm03/k>`0203Xj>P070410@011@D40?3`l03`l?00k>c/0>SXj03/k>`0203dm?@0^
03Xj>P0n?Sh0>c/k03dm?@15ADD0CDe=04M7A`16ATH0@D5103dm?@0k>c/0?Cdm0492@P10@400?Shn
0492@P0o?cl0?Cdm0410@00o?cl0ATI604=3@`0m?Cd0?clo04Q8B016ATH0Cdm?04=3@`0o?cl0DE5A
05MGE`1>CTh0De=C04m?C`1NGUh0K6a/061PH01MGEd0HF5Q04a<C018B4P0Bd];051@D01>CTh0H61P
06e]K@80Ng]k00/0P82007moO`21PH40VIVI09^KV`1gMgL0LG5a07moO`29RHT0T92@0;Fe]@020;Ng
]`0V0<O7a`32`/80/;2`0:6QX@2][Jd0^KVi0;jn_P2ZZZX0IfMW04];B`1PH600Q8B409VIV@2BTY80
N7Qh06i^KP1WIfL0EEEE04Q8B011@D40?3`l03dm?@12@T80@D5103dm?@0n?Sh0?Cdm03hn?P0m?Cd0
?3`l0410@00j>SX0?3`l03hn?P0m?Cd0>c/k03Ti>@0k>c/403`l?00>03hn?P0i>CT0?Cdm03dm?@0n
?Sh0?3`l03/k>`10@400?Cdm03/k>`0i>CT0>c/k03`l?00k>c/203Xj>P0703lo?`0k>c/0>c/k03/k
>`0g=cL0?3`l03hn?P0203Xj>P0303/k>`0i>CT0>SXj0080>SXj00<0?3`l03Xj>P0j>SX00P0j>SX0
3`0l?3`0?Cdm03Xj>P0h>3P0>SXj03/k>`0l?3`0>CTi03Xj>P0h>3P0>c/k03Xj>P0m?Cd0>CTi03Lg
=`0303Ti>@0503Xj>P0i>CT0>c/k03Xj>P0k>c/00P0h>3P01@0i>CT0>SXj03Xj>P0i>CT0=cLg0080
>CTi00@0=cLg03Ti>@0k>c/0>SXj0P0h>3P05@0l?3`0>c/k03Lg=`0h>3P0=cLg03hn?P0i>CT0@410
03hn?P10@400>c/k04A4A015ADD0@41003lo?`10@400?Cdm03Xj>P0l?3`0@d=303`l?00203dm?@06
03`l?00k>c/0>CTi03Xj>P0l?3`0>3Ph0P0j>SX403`l?00M03dm?@0l?3`0@D5105ADE022PX80Ti>C
09jNWP1JFUX0?clo03dm?@0i>CT0?clo03`l?00o?cl0?Cdm03lo?`1:BTX0Cdm?05ADE01UIFD0PX:2
08F5Q@27QhL0VYZJ079bLP1OGel0De=C04=3@`0n?Sh00P0l?3`00`11@D40>c/k03/k>`0203dm?@0A
03/k>`0l?3`0?3`l03Xj>P0i>CT0?Shn03Ph>00f=SH0=cLg03Xj>P0h>3P0>SXj03Ph>00e=CD0=cLg
03Ti>@0h>3P00P0f=SH00`0g=cL0>SXj03Ti>@0203/k>`80?Shn00L0?3`l03Ti>@14A4@0GemO07al
O02SXj<0d];B0080iNGU0100f][J0=SHf03=cLd0Z:RX0820P01bLW80G5aL04M7A`0o?cl0?3`l0492
@P10@400?Cdm03Ti>@0f=SH0>CTi0P0g=cL01P0f=SH0?3`l03/k>`0j>SX0=cLg03Hf=P<0>3Ph00h0
>CTi03Xj>P0l?3`0>SXj03lo?`0n?Sh0@D5104a<C01TI6@0MGEe09:BTP2MWId0[:b/0<71`@80fm_K
01d0_kno0:6QX@21PH40T92@0:NWY`2e]KD0_;bl0<30`02XZ:P0TI6A07]kN`1UIFD0H61P05EEE@1G
EeL0Cdm?051@D01CDe<0GEeM06QXJ01nOWh0SXj>0:FUY@2WYjL0^;Rh0<C4a03;bl/0c/k>0=KFeP0=
ooooo`004?ooool204a<C00904i>CP1;Bd/0CDe=04];B`1<C4`0BTY:04i>CP19BDT0AdM70080BDU9
00D0BTY:04U9B@17AdL0ADE504I6AP0304E5A@0B04I6AP17AdL0ATI604A4A018B4P0BTY:04M7A`16
ATH0ADE504A4A016ATH0B4Q804];B`17AdL0ATI604M7A`18B4P0AdM70`15ADD05016ATH0@d=304I6
AP15ADD0ATI604E5A@13@d<0@T9203lo?`11@D40@41004=3@`11@D40@d=304I6AP14A4@0ADE504=3
@`10@400@d=30`0n?Sh303dm?@0?0492@P11@D40?clo03dm?@0n?Sh0?clo0410@012@T80@4100451
@@12@T80@d=303hn?P12@T80@d=300<0?Cdm01X0>c/k03hn?P0l?3`0>c/k03lo?`11@D40@d=303dm
?@10@400?clo0410@015ADD0?Shn03Lg=`0j>SX0>c/k03dm?@0j>SX0?clo0492@P15ADD0@41003`l
?00j>SX0?clo03`l?080>SXj02@0?Cdm03Xj>P15ADD0BDU905mOG`1_Kfl0N7Qh07moO`1UIFD0J6QX
079bLP1WIfL0E5AD04];B`11@D40?Cdm0410@00o?cl0@41003lo?`0n?Sh0@d=304Y:BP1XJ6P0L71`
06EUI@1@D500F5QH05UIF@1NGUh0IFEU06UYJ@1ZJVX0Lg=c07AdM01LG5`204Y:BP0704Q8B017AdL0
Bd];04E5A@16ATH0@41004E5A@0204U9B@0k04i>CP1@D500HV9R07YjNP2>SXh0W9bL0:6QX@2^[Zh0
/K6a0;:b/P2IVIT0LG5a07=cL`1eMGD0N7Qh06ATI01VIVH0IFEU06m_K`23Ph<0UYJF09RHV02ZZZX0
^KVi09RHV01nOWh0NWYj07alO01gMgL0KFe]06a/K02KVi/0][Jf0;Fe]@2PX:00S8b<06m_K`1@D500
@d=303hn?P0l?3`0?clo03`l?00k>c/0@D5103Xj>P12@T80@d=303Xj>P0n?Sh0?Cdm03/k>`0n?Sh0
?Cdm03hn?P0m?Cd0?clo03Xj>P0m?Cd00P0l?3`02`0k>c/0?3`l03hn?P0j>SX0?3`l0451@@0m?Cd0
?clo03hn?P0l?3`0?Shn0080?3`l00<0>CTi03Ph>00l?3`00P0l?3`04`0h>3P0?3`l03`l?00i>CT0
?3`l03Xj>P0h>3P0>SXj03`l?00f=SH0=CDe03Hf=P0h>3P0>CTi03/k>`0l?3`0>CTi03Ph>00k>c/0
0`0j>SX0100i>CT0@4100410@00j>SX203Lg=`0<03Xj>P0k>c/0>CTi03Xj>P0g=cL0>3Ph03/k>`0j
>SX0>3Ph03Lg=`0f=SH0=cLg0P0i>CT0200m?Cd0@41003`l?012@T80>SXj03hn?P0l?3`0=SHf0`0h
>3P03P0k>c/0?Cdm03Hf=P0n?Sh0E5AD04m?C`13@d<0@41003/k>`0l?3`0>c/k03Xj>P0l?3`0?Shn
0`0k>c/03@12@T80>c/k03/k>`0i>CT0?Cdm03`l?00i>CT0>SXj03Ti>@0j>SX0>c/k03Xj>P0l?3`0
0P0k>c/06P0l?3`0?clo03lo?`11@D40EUIF05MGE`1=CDd0@D5103hn?P0j>SX0?3`l03Xj>P0n?Sh0
?Cdm04I6AP1WIfL0MgMg08J6QP2ATI40Ogmo07MgM`20P800GUiN05=CD`10@400?Shn0P0k>c/0100n
?Sh0>SXj03Ti>@0i>CT303dm?@80?3`l00@0?Cdm03Xj>P0j>SX0>SXj100k>c/08`0h>3P0?Cdm03Xj
>P0k>c/0>SXj03Ti>@0k>c/0>3Ph03Xj>P0n?Sh0>c/k03Ti>@12@T80CDe=05IFEP1:BTX0AdM705AD
E01IFET0N7Qh0;Ng]`3Lg=`0jNWY0>SXj03WinL0i^KV0=oOg`3GemL0a/K60:FUY@21PH40FUYJ051@
D01=CDd0A4A40080?Cdm00<0@d=303`l?00j>SX00P0h>3P0>@0j>SX0?clo04U9B@18B4P0?Cdm03/k
>`0i>CT0>3Ph03Ti>@0h>3P0>SXj04I6AP1;Bd/0H61P07emO@23Ph<0Rh^;096AT@2NWYh0Zj^[0;no
_`2g]kL0bl_;0=gMg@3Ph>00i>CT0>;RhP3Cdm<0^KVi0:JVYP2ATI40SXj>08F5Q@26QXH0UIFE09ZJ
VP2EUID0RXZ:08:2PP1iNGT0OGem06m_K`1TI6@0KVi^07moO`2XZ:P0_kno0<c<c03Bd]80clo?0<c<
c035aLD0`L710;Fe]@2QXJ40VYZJ09NGU`0=ooooo`004?ooool2051@D00904m?C`1<C4`0BDU904Y:
BP18B4P0BDU904e=C@18B4P0AdM70080B4Q800L0BTY:04Q8B01;Bd/0B4Q804E5A@16ATH0AdM700@0
ATI600L0@d=304Q8B018B4P0@d=304E5A@16ATH0ADE50080A4A400P0BTY:04I6AP13@d<0@41004A4
A013@d<0@D5104Q8B080@T9200P0?clo04A4A011@D40@D5104=3@`15ADD0@D5103hn?P<0A4A400H0
ADE50451@@14A4@0@4100451@@17AdL20410@00904=3@`12@T80@d=303dm?@11@D40?Shn0492@P11
@D40?Shn00<0?Cdm0P0n?Sh20451@@0A03hn?P12@T80?3`l04=3@`12@T80?3`l03/k>`0j>SX0?clo
03Xj>P0o?cl0@41003lo?`11@D40@d=30451@@16ATH00P19BDT01`15ADD0@D5103Xj>P12@T80?3`l
03hn?P0o?cl00P12@T80?00o?cl0?3`l03hn?P0l?3`0?clo0410@00k>c/0?3`l05IFEP1HF5P0E5AD
04m?C`1DE5@0F5QH05YJFP1LG5`0C4a<04m?C`1>CTh0BDU903lo?`11@D40@T9204M7A`0n?Sh0ATI6
069RHP1ZJVX0IVIV069RHP1`L700Ti>C08N7Q`1LG5`0CDe=05UIF@1QHF40JFUY06QXJ01VIVH0L71`
06IVIP1MGEd0B4Q804=3@`14A4@0@T9204I6AP1;Bd/0F5QH05UIF@15ADD0AdM704a<C01OGel0HV9R
07=cL`1mOGd0SXj>08n?S`80NWYj0P23Ph<0=P2;Rh/0R8R80820P025QHD0QXJ60861P@1dM7@0GemO
05=CD`1EEED0NWYj0;Rh^02`/;00SHf=0:b/[034a<@0W9bL07emO@1VIVH0EUIF05=CD`18B4P0BTY:
05=CD`1SHf<0MGEe08F5Q@2NWYh0^k^k0::RXP22PX80JFUY04M7A`10@400@d=304Q8B01BDU80ADE5
0492@P0m?Cd0?3`l0451@@12@T80@D5103hn?P11@D40>c/k03hn?P10@400?3`l03hn?P0m?Cd0>c/k
03`l?0<0?Shn00<0?clo03/k>`0m?Cd00`0l?3`03P0i>CT0?3`l03/k>`0j>SX0>CTi03Ph>00m?Cd0
?Shn03/k>`0i>CT0>SXj03hn?P0g=cL0=SHf0P0j>SX03`0h>3P0=SHf03Hf=P0i>CT0=cLg03Ti>@0l
?3`0=cLg03Xj>P0n?Sh0>3Ph03Ti>@0n?Sh0>CTi03Xj>P0203Lg=`0;03Ph>00i>CT0>SXj03/k>`0h
>3P0>CTi03Xj>P0f=SH0>c/k03Lg=`0i>CT00P0h>3P203Lg=`0803/k>`0j>SX0@D5103dm?@11@D40
?Cdm03`l?00j>SX403Ti>@0=03Ph>00i>CT0A4A405=CD`14A4@0?3`l04A4A00m?Cd0>CTi03`l?00m
?Cd0>3Ph03lo?`0203dm?@0303/k>`0l?3`0>c/k00@0?Cdm0180?3`l03Xj>P0l?3`0>3Ph03/k>`0h
>3P0?Cdm0410@00l?3`0>SXj03/k>`0l?3`0?Shn03dm?@0n?Sh0>3Ph03hn?P0m?Cd203`l?00D03lo
?`1DE5@0H61P07IfMP1oOgl0UiNG07YjNP1/K6`0Fe]K04Y:BP12@T80?Shn03dm?@0l?3`0?Cdm03/k
>`0i>CT0>c/k03Xj>P0i>CT203`l?00303Ti>@0j>SX0?Cdm0080>CTi00D0?Cdm03Ti>@0h>3P0>CTi
03Xj>P0203/k>`0703Ti>@0j>SX0>3Ph03Lg=`0j>SX0>CTi03Hf=P0203Lg=`0X03Xj>P0l?3`0DE5A
07]kN`1iNGT0Kfm_075aL@1bLW80Ti>C0:VYZ@2d];@0d=3@0>;RhP3Ti>@0h>3P0=kNgP3=cLd0ZJVY
07YjNP1JFUX0CTi>0410@00l?3`0>c/k03hn?P0h>3P0>c/k03Ph>00i>CT0=cLg03Hf=P0j>SX0>c/k
0492@P1=CDd0@D5103hn?P0j>SX0=cLg03/k>`<0?3`l0P0m?Cd0101?Cdl0PX:20;no_`3Fe]H20=OG
e`0X0=;BdP3Cdm<0b/[:0<g=c@38b<P0d=3@0<k>cP2b/[80W9bL08b<S01dM7@0GemO055AD@18B4P0
C4a<059BDP1OGel0GEeM06][J`1dM7@0MGEe07MgM`1cLg<0Hf=S069RHP1[Jf/0RXZ:0:>SX`2XZ:P0
VYZJ08J6QP1hN7P0J6QX055AD@18B4P0A4A404I6AP0o?cl0@41004A4A0gooooo000@ooooo`0804];
B`1=CDd0CDe=04e=C@18B4P0BDU904Y:BP1=CDd204I6AP0704a<C019BDT0ADE504I6AP18B4P0BTY:
04M7A`0204E5A@0304I6AP1:BTX0AdM70080ADE500h0@d=304E5A@16ATH0AdM704Y:BP17AdL0BDU9
04M7A`18B4P0AdM704I6AP15ADD0A4A404E5A@80ATI600L0AdM704A4A013@d<0@T9204=3@`12@T80
@D510080A4A400X0@T920451@@13@d<0@D510410@013@d<0A4A40451@@0n?Sh0@4100P12@T805@10
@400A4A40410@011@D40?Shn04I6AP0n?Sh0@41003dm?@0l?3`0?Cdm03/k>`0o?cl0?Shn0410@00l
?3`0@4100492@P0m?Cd0>SXj03dm?@0203hn?P0403/k>`0i>CT0?clo0451@@80?3`l00d0@D5103hn
?P10@400@T9203dm?@10@400?clo03dm?@0j>SX0?3`l03dm?@0i>CT0>c/k0080?Cdm00@0@D5103Ti
>@10@400>SXj0P10@4003@0n?Sh0@D5104];B`1MGEd0D51@03lo?`0l?3`0@4100451@@0m?Cd0A4A4
03lo?`12@T800P10@4005P14A4@0@D5103dm?@14A4@0C4a<05IFEP1RHV80Hf=S05eMG@1HF5P0De=C
061PH01HF5P0@d=30451@@1;Bd/0De=C061PH01LG5`0EeMG065QH@1XJ6P204m?C`1504a<C01JFUX0
Cdm?04e=C@1UIFD0NGUi08J6QP1IFET0C4a<06EUI@1TI6@0LG5a06QXJ01KFe/0EeMG05EEE@1;Bd/0
CTi>05=CD`1DE5@0F5QH04a<C01;Bd/0CTi>04A4A013@d<0@4100451@@13@d<0@D5104e=C@1^KVh0
TY:B06YZJP1YJFT0WYjN0:6QX@2IVIT0WinO0:j^[P2XZ:P0Zj^[0;:b/P2PX:00SHf=075aL@1LG5`0
DU9B07]kN`1lO7`0S8b<09RHV02UYJD0UIFE08f=S@2>SXh0Z:RX0;6a/@2RXZ80RHV906i^KP1OGel0
A4A40451@@0m?Cd0>c/k03Ti>@10@400?3`l0080?Cdm00@0>CTi03/k>`0l?3`0>c/k0P0m?Cd02010
@400?3`l03dm?@0j>SX0?clo03Xj>P0l?3`0>c/k0P0l?3`01P0k>c/0?3`l03/k>`0k>c/0?Cdm03Ti
>@80@4100P0h>3P01P0m?Cd0>CTi03/k>`0l?3`0=SHf03`l?080>CTi00h0?3`l0410@00j>SX0?clo
03Ti>@0k>c/0>CTi03Ph>00i>CT0>3Ph03Lg=`0f=SH0>3Ph03`l?080>CTi00P0>c/k03hn?P0i>CT0
?Shn03Lg=`0o?cl0=SHf03/k>`<0>CTi0P0n?Sh03@0m?Cd0@D5103Ti>@0m?Cd0>3Ph03/k>`0h>3P0
>SXj03dm?@0n?Sh0@T9204E5A@10@4000P0i>CT03@0l?3`0?Cdm03dm?@0k>c/0>CTi03/k>`0n?Sh0
?Cdm03hn?P0j>SX0?Shn03/k>`0m?Cd00P0o?cl0100j>SX0>CTi03/k>`0n?Sh303Xj>P0303/k>`0l
?3`0>SXj0080?3`l0`0m?Cd03`10@400>c/k03`l?00j>SX0>c/k05EEE@1^KVh0PH6108B4Q02LW9`0
KVi^059BDP11@D40@4100451@@0203lo?`0403`l?00g=cL0>CTi03/k>`80>3Ph00T0?Shn03`l?00j
>SX0>CTi03hn?P0f=SH0>CTi03Xj>P0k>c/00P0j>SX05@0h>3P0>SXj03Ti>@0i>CT0=cLg03dm?@14
A4@0ATI603`l?00k>c/0>3Ph03/k>`0i>CT0>SXj04=3@`1CDe<0IVIV075aL@1ZJVX0HV9R079bLP02
07=cL`0@07YjNP2>SXh0Shn?07AdM02?Shl0_kno0:JVYP1oOgl0DE5A04E5A@0n?Sh0>c/k03hn?P0m
?Cd0>c/k03Xj>P80>c/k00P0=cLg03Ph>00h>3P0=cLg03Ti>@0j>SX0=SHf03dm?@<0>SXj00@0?3`l
03Hf=P0k>c/0>c/k0P0m?Cd04017AdL0F5QH08n?S`2n_[h0dm?C0=GEe@3Bd]80a<C40<;2`P39bLT0
bl_;0;^k^`2FUYH0N7Qh05IFEP14A4@203hn?P0:0451@@1?Cdl0K6a/08j>SP2@T900U9BD092@T01`
L700FEUI04];B`80?3`l00<0?clo03Xj>P0n?Sh00P1ADE403@18B4P0?Shn0410@00l?3`0?Shn03/k
>`10@400?Cdm04E5A@1;Bd/0FEUI06m_K`2?Shl03Oooool0013ooooo0`1?Cdl0401=CDd0B4Q804Q8
B01;Bd/0BDU904e=C@18B4P0BDU904M7A`18B4P0AdM704Q8B01;Bd/0BTY:04I6AP17AdL204E5A@0=
04M7A`18B4P0ADE504=3@`14A4@0ADE504Q8B01;Bd/0BDU904I6AP15ADD0BDU904Q8B00204A4A007
04M7A`16ATH0ADE504I6AP18B4P0Bd];0492@P020451@@0604=3@`14A4@0@d=303lo?`10@400@D51
0P14A4@02@11@D40@d=304A4A012@T80@41003lo?`12@T80@41004=3@`020451@@050492@P0l?3`0
@D510410@012@T800P0n?Sh01`10@400?3`l03lo?`10@400?clo03`l?00m?Cd00P0o?cl0400l?3`0
?Shn03hn?P0n?Sh0?Cdm03lo?`0n?Sh0A4A403`l?00n?Sh0?clo03`l?00n?Sh0?3`l04=3@`11@D42
03hn?P050410@00m?Cd0?Cdm03/k>`11@D400P0n?Sh02@16ATH0@d=30492@P0o?cl0?Shn04a<C014
A4@0@T920451@@0203hn?P080410@012@T80@41003lo?`0n?Sh0@D5104I6AP13@d<204e=C@0Q04a<
C01EEED0GUiN06IVIP1TI6@0G5aL05IFEP1DE5@0Fe]K05IFEP1?Cdl0D51@04A4A013@d<0@D5103hn
?P16ATH0BTY:0451@@13@d<0ADE504Y:BP15ADD0AdM70492@P1<C4`0A4A404I6AP10@400@D5104M7
A`15ADD0A4A40080@D510240A4A40451@@0l?3`0@41003hn?P0m?Cd0@T9203dm?@0n?Sh0@T9203`l
?012@T80@41003hn?P0m?Cd0BDU904Q8B01;Bd/0AdM704I6AP15ADD0E5AD06MWI`1jNWX0VIVI07Ui
N@1^KVh0NWYj08:2PP2HV9P0_;bl0<[:bP31`L400P34a<@0:02c/k<0XJ6Q09NGU`2>SXh0UYJF09^K
V`2LW9`0Xj>S0;:b/P3Bd]80f=SH0=gMg@3Ng]h0bLW90;Jf]P2SXj<0Ti>C07YjNP1:BTX0ATI604U9
B@15ADD0B4Q804U9B@0m?Cd0>c/k03`l?00i>CT0?3`l03dm?@0l?3`0@d=303hn?P0l?3`0?Shn03/k
>`0j>SX0>c/k0410@00m?Cd303Xj>P0403`l?00j>SX0>3Ph03hn?P80>c/k00@0?Shn03Xj>P0i>CT0
>CTi0P0o?cl01@0m?Cd0>c/k03/k>`0m?Cd0?3`l00@0>CTi00D0>c/k03Ti>@0g=cL0>3Ph03Ti>@02
03Ph>00403Xj>P0m?Cd0>CTi03dm?@80>c/k00<0>SXj03Ti>@0h>3P00P0j>SX02`0m?Cd0=cLg03Ti
>@0k>c/0?Cdm03`l?00h>3P0>CTi03Ph>00k>c/0=SHf0080>CTi00<0?3`l03/k>`0i>CT00`0j>SX0
1@0k>c/0?3`l03/k>`0j>SX0>3Ph0080>CTi0100>3Ph03Lg=`0i>CT0?3`l03Ph>00g=cL0>SXj03Ti
>@0j>SX0?3`l03hn?P0m?Cd0>SXj03Lg=`0k>c/0?3`l0P0i>CT01P0m?Cd0>c/k03Xj>P0i>CT0>c/k
03`l?080>SXj0P0m?Cd02`0o?cl0BDU905EEE@1JFUX0CTi>04a<C015ADD0>c/k03`l?00k>c/0?Cdm
0080?Shn00@0?Cdm03Xj>P0j>SX0>c/k0P0l?3`00`0k>c/0?3`l03Ti>@0203Ti>@0703Ph>00e=CD0
>CTi03/k>`0i>CT0>SXj03Ph>00203Xj>P0K03/k>`0i>CT0CDe=05]KF`1<C4`0A4A40410@00k>c/0
?3`l04M7A`1EEED0FEUI05YJFP1ADE40BDU9065QH@20P800SHf=09:BTP1YJFT0HV9R05ADE01GEeL0
EUIF05aLG01TI6@0Cdm?0080@D5100/0?Cdm03Xj>P0k>c/0>SXj03/k>`0l?3`0?clo03`l?00h>3P0
=SHf03Xj>P0203Ti>@0403Xj>P0i>CT0?3`l03Ph>0<0>SXj0280?3`l03Xj>P0o?cl0@D5104m?C`1Y
JFT0R8R80:f][@3<c<`0gMgM0=kNgP3Fe]H0f=SH0=GEe@3IfMT0d=3@0;>c/`25QHD0FEUI0451@@16
ATH0@D5103`l?011@D40Bd];06EUI@2ATI40TY:B07YjNP1KFe/0AdM70451@@0i>CT0=cLg0P0i>CT2
03Lg=`0A03De=@0h>3P0?3`l03hn?P0j>SX0?3`l03dm?@14A4@0F5QH06MWI`2=SHd0XZ:R0;6a/@30
`<00c/k>0=SHf03Lg=`03Oooool0013ooooo00@0CDe=04a<C01>CTh0Bd];0P1:BTX01P1;Bd/0B4Q8
04Y:BP18B4P0AdM704E5A@80AdM700<0ATI604Q8B01;Bd/00P18B4P02016ATH0AdM704U9B@1:BTX0
AdM704I6AP14A4@0ADE51018B4P01015ADD0ATI604E5A@1ADE4204M7A`0;04A4A015ADD0ATI604U9
B@16ATH0A4A404M7A`16ATH0@T9204I6AP14A4@00P11@D401013@d<0A4A403lo?`10@4030492@P04
0451@@0o?cl0@D5103hn?P80?Cdm00d0@D5104=3@`13@d<0@d=304E5A@16ATH0@D5103dm?@10@400
?Shn03lo?`10@400?Cdm00<0?3`l00<0?Cdm03lo?`10@4000`0l?3`01@0m?Cd0>c/k04=3@`0k>c/0
?Cdm00<0?clo00T0?Cdm03Xj>P0o?cl0?clo0410@00o?cl0?Cdm03hn?P0k>c/00P0n?Sh06P0k>c/0
?Cdm0410@012@T80?Cdm03lo?`10@400?Shn0492@P13@d<0@4100451@@1GEeL0Fe]K04I6AP10@400
@d=304A4A01>CTh0FEUI071`L01YJFT0HF5Q05UIF@1?Cdl0CDe=0`13@d<01014A4@0@D510451@@15
ADD204A4A0050451@@0o?cl0@d=303/k>`10@4000P0l?3`203hn?P0703`l?00o?cl0@4100410@012
@T80?Shn03`l?00203lo?`0/04M7A`0m?Cd0@41003`l?00o?cl0?3`l03hn?P0o?cl0@T9203lo?`0n
?Sh0>c/k03hn?P0o?cl0?3`l03dm?@11@D40ATI6069RHP1^KVh0M7Ad07]kN`2@T900UiNG08J6QP21
PH40JFUY05YJFP1mOGd0Shn?08f=S@29RHT0U9BD0:BTY02VYZH0UIFE08^;R`27QhL0PH6107UiN@1V
IVH0Hf=S07MgM`2<S8`209:BTP0;08n?S`1hN7P0P82008N7Q`26QXH0OWin06m_K`1SHf<0F5QH06IV
IP2HV9P00P2a/K402@2;Rh/0XZ:R0:^[Z`2b/[80SXj>06a/K016ATH0?Cdm03/k>`0203Xj>P080410
@00l?3`0?clo04e=C@1<C4`0>SXj03hn?P10@40203dm?@0503/k>`0m?Cd0?clo03/k>`0j>SX00P0n
?Sh01`0m?Cd0>CTi03`l?011@D40>CTi03/k>`14A4@00P0l?3`203/k>`80>SXj00<0>CTi03Lg=`0i
>CT00P0j>SX01P0h>3P0=cLg03Ti>@0h>3P0>CTi03Xj>P80>c/k00D0>CTi03Ph>00k>c/0>SXj03Lg
=`0303Ph>00303Xj>P0g=cL0>CTi0080=SHf00H0>3Ph03Lg=`0e=CD0>CTi03hn?P0k>c/203Ti>@06
03`l?00j>SX0?3`l03hn?P0l?3`0>c/k0P0i>CT02P0k>c/0?3`l03`l?00j>SX0?Cdm03/k>`0m?Cd0
>c/k03`l?00k>c/203`l?00603Ti>@0l?3`0?3`l03hn?P0m?Cd0?3`l0P0j>SX0100l?3`0>c/k03`l
?00n?Sh203Ti>@0<03dm?@0l?3`0>c/k03dm?@0o?cl0@d=303lo?`0n?Sh0>SXj03dm?@0k>c/0>SXj
0P0i>CT01@0o?cl0?Cdm03/k>`0j>SX0>CTi0080?Cdm00X0>c/k03Ti>@0m?Cd0@41003`l?00m?Cd0
>SXj03Lg=`0j>SX0>3Ph0P0i>CT04P0l?3`0>3Ph03`l?00g=cL0>c/k03Lg=`0j>SX0?clo0410@00l
?3`0?clo03/k>`0i>CT0>SXj03dm?@13@d<0D51@0451@@80B4Q801<0J6QX07]kN`29RHT0_;bl0<?3
``30`<00/[:b08Z:RP1VIVH0AdM703hn?P10@400>SXj03dm?@0l?3`0>c/k03Ph>00i>CT0>3Ph0080
>SXj00H0>CTi03dm?@0k>c/0>CTi03Xj>P0i>CT203Ph>080>CTi01H0>3Ph03/k>`0i>CT0>c/k0410
@01=CDd0IVIV08^;R`2/[:`0d=3@0=KFeP3IfMT0e]KF0=3@d03Kfm/0h>3P0=SHf02n_[h0V9RH07em
O@1UIFD0De=C0P14A4@0200l?3`0@41004=3@`15ADD0D51@04];B`19BDT0@T920P0i>CT203/k>`0H
03Ti>@0h>3P0=cLg03Ti>@0f=SH0>SXj03Ti>@0h>3P0?Cdm03`l?01=CDd0GEeM0861P@2VYZH0_Kfm
0=KFeP3QhN40hn?S0>OWi`3Vi^H0h>3P0=WIf@3Bd]80d=3@3Oooool0013ooooo00l0Bd];04Y:BP1?
Cdl0Bd];04e=C@1;Bd/0B4Q804U9B@17AdL0ATI604M7A`1<C4`0B4Q804Y:BP18B4P00P14A4@00`16
ATH0B4Q804A4A00204Q8B00504I6AP15ADD0ATI604E5A@16ATH00P17AdL02P14A4@0ATI604M7A`1;
Bd/0AdM704=3@`1;Bd/0ATI604A4A013@d<20492@P0304A4A011@D40@D510080A4A400@0AdM704=3
@`12@T80@d=30P10@40203lo?`<0@4100P11@D40300o?cl0?Cdm03dm?@0o?cl0@T9204=3@`14A4@0
@d=30451@@10@400?Shn03Xj>P80?clo00<0?Shn03lo?`0l?3`0100n?Sh01@0m?Cd0?Shn03lo?`0m
?Cd0?3`l00D0?Cdm00X0?3`l03lo?`0n?Sh0?clo03hn?P0m?Cd0?3`l03lo?`17AdL0@4100P0o?cl0
200j>SX0?Cdm03`l?00n?Sh0>c/k03Ph>00l?3`0>3Ph0P13@d<203lo?`0703dm?@13@d<0BTY:0451
@@0l?3`0?clo04=3@`0204E5A@0404e=C@1>CTh0AdM705QHF080GemO00P0E5AD04I6AP17AdL0DU9B
05]KF`1MGEd0EEEE04a<C080@41000H0@d=303hn?P0m?Cd0?Shn0451@@0j>SX303lo?`0:03`l?00m
?Cd0>SXj03/k>`0o?cl0?3`l03dm?@0k>c/0?clo04A4A080?Shn00T0@D510410@010@400?3`l03lo
?`0k>c/0?Cdm0451@@0o?cl00P10@400100n?Sh0?clo03dm?@0m?Cd204=3@`0505ADE01jNWX0S8b<
08^;R`1`L7000P1mOGd01P1eMGD0KVi^05iNGP1CDe<0EEEE05]KF`80DE5A02<0ADE5055AD@1NGUh0
GUiN06QXJ01PH600J6QX08^;R`21PH40SXj>08J6QP2?Shl0I6AT055AD@1bLW80V9RH09fMW@20P800
MGEe06=SH`1=CDd0Bd];06MWI`23Ph<0VYZJ0<K6aP2n_[h0VIVI08R8R02>SXh0Shn?07moO`1QHF40
FUYJ04I6AP020410@00907AdM02QXJ40Ng]k06EUI@1IFET0CTi>04Q8B014A4@0@D510080?Cdm00l0
>SXj03hn?P0l?3`0?Cdm03/k>`0m?Cd0?clo04A4A00m?Cd0>SXj03`l?00k>c/0?Cdm03`l?00k>c/0
0P0i>CT01`0j>SX0>c/k03Xj>P0i>CT0?3`l03Ti>@0e=CD00P0h>3P01P0i>CT0>SXj03Xj>P0j>SX0
?3`l0410@0<0>CTi00D0=cLg03Xj>P0k>c/0?3`l03Hf=P0203Ti>@0503/k>`0i>CT0=cLg03Ph>00j
>SX00P0k>c/303Ti>@0J03Xj>P0i>CT0>SXj03/k>`0i>CT0=cLg03/k>`0n?Sh0?Cdm03Ti>@0h>3P0
>CTi03Hf=P0l?3`0?Cdm03lo?`0n?Sh0>c/k03`l?00j>SX0?Shn03Xj>P0k>c/0>3Ph03Lg=`0i>CT2
03`l?080>c/k00/0>SXj03Ti>@0l?3`0@D5103lo?`0j>SX0?Cdm03Ti>@0j>SX0>CTi03Xj>P0203`l
?00703Xj>P0l?3`0?Cdm03lo?`1;Bd/0CDe=0492@P0203hn?P040492@P0n?Sh0?clo03`l?080BTY:
00D0>CTi03hn?P0k>c/0>CTi03`l?00203Ti>@0703Ph>00o?cl0>SXj03Ph>00l?3`0C4a<03Ph>003
03Xj>P0R03`l?00h>3P0>SXj03Ph>00n?Sh0@T9205aLG01GEeL0G5aL07=cL`1`L700RXZ:0;:b/P2K
Vi/0TI6A06][J`1HF5P0AdM70410@00o?cl0ADE503hn?P0m?Cd0?3`l03Ph>00l?3`0>SXj03Ph>00k
>c/0>3Ph03Ti>@0k>c/0>CTi03Xj>P80>CTi0140?Cdm03Xj>P0k>c/0>c/k03Xj>P0i>CT0?Cdm0492
@P1IFET0MgMg0:VYZ@3Bd]80hN7Q0>KViP3Ti>@0d=3@0<C4a0020<30`00_0<k>cP3AdM40a/K609BD
U01_Kfl0CTi>03lo?`0l?3`0A4A405mOG`23Ph<0UYJF08n?S`23Ph<0JVYZ04e=C@0o?cl0>c/k03`l
?00i>CT0>SXj03/k>`0i>CT0>3Ph03hn?P0h>3P0=cLg03Ti>@0j>SX0@41006MWI`2<S8`0ZZZZ0<C4
a03Cdm<0b/[:0;Bd]02`/;00`L710=_Kf`3Ti>@0j>SX0>CTi03Shn<0i>CT0>GUi@3YjNT03Oooool0
013ooooo00@0Bd];04a<C01:BTX0Bd];0P1:BTX00`18B4P0BTY:04I6AP0204M7A`0604Y:BP17AdL0
BTY:04Q8B015ADD0ATI60P15ADD04@1<C4`0ADE504E5A@12@T80ATI604E5A@16ATH0A4A404I6AP13
@d<0A4A404M7A`16ATH0A4A40492@P18B4P0A4A40080@T9200`0A4A40451@@14A4@0@D5104I6AP13
@d<0A4A404I6AP13@d<0@T9204I6AP18B4P204A4A00>04=3@`14A4@0@T9203dm?@10@400@d=304A4
A015ADD0@41003`l?012@T80@d=30410@00m?Cd20451@@030410@011@D40?3`l0080?Shn00T0>c/k
0410@010@400?3`l03/k>`0m?Cd0@T9203dm?@0n?Sh00`0l?3`01P0m?Cd0>CTi03hn?P0j>SX0?3`l
03dm?@<0?Shn00@0@41003hn?P0l?3`0>CTi0P0k>c/01P10@400?Cdm03Xj>P0i>CT0?Shn03dm?@80
>SXj00D0>CTi03hn?P10@400?Cdm03/k>`0303dm?@0<04=3@`17AdL0A4A40451@@12@T80@41003hn
?P0o?cl0@D510492@P17AdL0A4A40P15ADD01P14A4@0ADE504Q8B019BDT0ATI60492@P80@4100P0o
?cl01P13@d<0?Shn04U9B@16ATH0BDU903lo?`80@41000d0>SXj03dm?@0n?Sh0?3`l03hn?P12@T80
?clo03/k>`0l?3`0>SXj03lo?`10@400?3`l0080?Cdm0P0k>c/03`0l?3`0?Shn03`l?00m?Cd0>SXj
04A4A00n?Sh0>c/k03dm?@0k>c/0?Shn03dm?@19BDT0D51@04i>CP0304A4A0<0?Shn01<0@T9204M7
A`19BDT0B4Q805mOG`1fMWH0KFe]08f=S@2ZZZX0[Zj^0;Bd]02WYjL0WIfM09^KV`2FUYH0RHV90861
P@1gMgL0QHF50080W9bL0300QhN706i^KP1OGel0FEUI04e=C@10@400ADE504a<C016ATH0ADE506YZ
JP2EUID0/K6a0;Ng]`31`L40/K6a08J6QP2IVIT0YjNW0:JVYP2SXj<0ZZZZ0<G5a@2i^KT0];Bd09jN
WP2IVIT0UiNG0:BTY02RXZ80V9RH07MgM`1NGUh0@D5103dm?@0k>c/0?Cdm03hn?P0m?Cd0?clo03hn
?P0o?cl0=cLg03dm?@0k>c/0Bd];03`l?00k>c/203Xj>P0403Lg=`0l?3`0?3`l03dm?@<0>3Ph00L0
>CTi03/k>`0l?3`0>SXj03Ti>@0k>c/0>CTi0080>c/k00@0=cLg03Ph>00i>CT0=CDe0P0g=cL0100j
>SX0>CTi03`l?00k>c/203Xj>P0B03Hf=P0j>SX0>CTi03Ti>@0h>3P0>SXj03Ph>00j>SX0>3Ph03Lg
=`0h>3P0?3`l03/k>`0j>SX0>3Ph03Ti>@0m?Cd0>CTi0P0g=cL02`0k>c/0>SXj03`l?00l?3`0?Shn
03/k>`13@d<0?Cdm03Ti>@0h>3P0>SXj00@0?3`l00H0@41003/k>`0h>3P0>SXj0410@011@D4203`l
?0<0>c/k0P0i>CT01@0h>3P0>SXj03`l?00l?3`0?clo0080?Shn0P0j>SX08P0n?Sh0>c/k03dm?@0j
>SX0?3`l03dm?@1@D500BDU903Ti>@0k>c/0@41003`l?00k>c/0?3`l03dm?@0k>c/0=cLg03Ti>@0f
=SH0>SXj04=3@`0h>3P0>CTi03/k>`12@T80?Shn0492@P1;Bd/0F5QH079bLP22PX80NGUi04a<C01R
HV820:>SX`0@08Z:RP1gMgL0GEeM04U9B@0n?Sh0?3`l0492@P1;Bd/0Cdm?04Y:BP0n?Sh0?3`l03dm
?@0k>c/0?Cdm03`l?080>c/k02/0>3Ph03/k>`0l?3`0>CTi03Ph>00j>SX0>CTi03`l?00m?Cd0@410
04];B`1OGel0PX:20:2PX02`/;00fMWI0>?Sh`3Xj>P0jNWY0>SXj03MgMd0dm?C0<W9b@2f][H0/;2`
0;Zj^P3;bl/0/[:b08R8R01hN7P0H61P051@D01GEeL0KVi^07UiN@2CTi<0T92@07IfMP1QHF40BDU9
0451@@0g=cL0>CTi0080>SXj01`0>3Ph03/k>`0k>c/0>SXj03Lg=`0k>c/0>SXj0410@01>CTh0S8b<
0;Zj^P3Ph>00dm?C0:j^[P2:RXX0QXJ608V9R@2b/[80d=3@0>CTi03Rh^80i^KV0>GUi@3QhN40f=SH
0=?Cd`3;bl/0`/;23Oooool0013ooooo00d0D51@04a<C01<C4`0C4a<04U9B@1:BTX0AdM704Q8B01:
BTX0B4Q804U9B@17AdL0BDU900<0AdM700T0B4Q804U9B@16ATH0AdM704I6AP17AdL0BDU904Q8B016
ATH00P15ADD00`14A4@0ADE504A4A00304A4A00D0492@P15ADD0@d=304=3@`11@D40@d=30492@P11
@D40@41004I6AP14A4@0ADE504M7A`12@T80@D510410@016ATH0AdM704=3@`14A4@204=3@`040451
@@14A4@0@T920410@080@D5101d0ADE50410@00n?Sh0?Shn03`l?011@D40@T920410@013@d<0@T92
03hn?P0o?cl0@D5103lo?`0k>c/0?Shn03lo?`0m?Cd0>c/k03hn?P0m?Cd0?Shn03`l?00m?Cd0?clo
03/k>`0l?3`0>SXj03/k>`0203hn?P80?3`l0P0m?Cd203hn?P0>03`l?00k>c/0?Shn03/k>`12@T80
>SXj03/k>`0m?Cd0?Shn03`l?00n?Sh0?clo03hn?P0j>SX203Ti>@0804=3@`0o?cl0?Shn03/k>`0m
?Cd0>SXj03lo?`0l?3`203lo?`0A0451@@10@400@D5103hn?P0o?cl0?Shn03dm?@0l?3`0?clo04=3
@`14A4@0?Shn03/k>`0n?Sh0@41003lo?`11@D400P0m?Cd04`11@D40?Shn03hn?P0m?Cd0@T9203lo
?`0m?Cd0?3`l04=3@`1@D500Cdm?0451@@0m?Cd0?clo03hn?P0l?3`0@41003Xj>P0i>CT00`0l?3`0
E`10@400Bd];05]KF`1CDe<0CDe=04Y:BP12@T80?clo0410@00o?cl0A4A404a<C011@D40?clo0410
@013@d<0@D510492@P0j>SX0>c/k03Xj>P0o?cl0BDU9059BDP1QHF40KFe]07IfMP1mOGd0RHV90:6Q
X@2[Zj/0_[jn0;no_`2e]KD0VYZJ08J6QP1gMgL0MGEe07AdM01`L700IVIV05]KF`1=CDd0@T920451
@@0l?3`0AdM705ADE01VIVH0L71`06i^KP1`L700UIFE0::RXP2^[Zh0][Jf0;fm_@2b/[80SHf=08R8
R02YZJT0b<S80<71`@39bLT0bl_;0;Fe]@2o_kl0/K6a08V9R@1NGUh0DU9B06=SH`1WIfL0I6AT08N7
Q`25QHD0P82008n?S`2DU9@0K6a/05=CD`10@400>SXj03lo?`0l?3`0?Cdm03`l?00203/k>`0403Xj
>P0k>c/0?Shn03Xj>P80>3Ph00P0>c/k03Ph>00f=SH0=cLg03Xj>P0k>c/0>CTi03Xj>P<0>CTi00<0
>c/k03Xj>P0k>c/00P0h>3P01@0i>CT0>3Ph03Ti>@0j>SX0=cLg00<0>CTi00@0=CDe03Lg=`0l?3`0
>c/k0P0i>CT0200l?3`0=cLg03/k>`0h>3P0>SXj03Lg=`0i>CT0>c/k0P0j>SX0100k>c/0>3Ph03/k
>`0i>CT203Lg=`0;03dm?@0k>c/0?Cdm03/k>`0i>CT0=cLg03Xj>P0g=cL0>CTi03`l?00h>3P00P0i
>CT03`0h>3P0=cLg03`l?018B4P0?3`l03Xj>P15ADD0?Shn03`l?00k>c/0?3`l03/k>`0j>SX0>3Ph
03Ti>@0203Xj>P0503Ph>00g=cL0>SXj03`l?00k>c/00P0j>SX01`0n?Sh0?Cdm03Hf=P0f=SH0?3`l
03/k>`0m?Cd00P0l?3`00`0n?Sh0>SXj03Ph>00203Lg=`0303Xj>P0i>CT0>CTi0080>SXj00@0?Shn
0451@@1<C4`0GemO0P17AdL04P1CDe<0KVi^06YZJP1_Kfl0PH6107IfMP29RHT0TI6A08^;R`1oOgl0
Lg=c07EeM@1^KVh0F5QH0410@00l?3`0?clo03dm?@80>SXj00X0>c/k03`l?00l?3`0>c/k03Ph>00g
=cL0>SXj03hn?P0m?Cd0>CTi0P0k>c/08`0n?Sh0Bd];069RHP1`L700W9bL0;Bd]033`l<0d];B0<[:
bP2o_kl0dM7A0=KFeP3Bd]80d=3@0=gMg@3Ph>00fm_K0=WIf@3Hf=P0clo?0=;BdP3;bl/0[:b/08j>
SP2MWId0WinO07moO`1PH600BDU904];B`10@400?Cdm03/k>`0n?Sh0ADE50080>SXj0200>CTi03`l
?00g=cL0>CTi03/k>`0f=SH0>SXj03Ti>@0o?cl0DE5A07alO02LW9`0`<300=KFeP32`/80YJFU09RH
V02SXj<0_kno0=WIf@3Xj>P0h>3P0=WIf@3EeMD0dM7A0<71`@2QXJ40SXj>07AdM01VIVH0GemO05MG
E`gooooo000@ooooo`0304m?C`1=CDd0CDe=00<0BTY:0`17AdL03P18B4P0BTY:04U9B@19BDT0ATI6
04M7A`1:BTX0Bd];04Y:BP19BDT0AdM704Q8B017AdL0BTY:0`16ATH204M7A`0304U9B@15ADD0A4A4
0080@d=300@0@T9204=3@`15ADD0@d=30P10@4003@13@d<0?clo0410@013@d<0@41004A4A012@T80
?clo0410@00o?cl0ADE504=3@`16ATH00P12@T802@13@d<0@T9204=3@`12@T80@D5103lo?`11@D40
@41003hn?P0204=3@`030492@P11@D40?clo00<0?Shn0P0m?Cd03`0n?Sh0@D5103lo?`0l?3`0?Cdm
0410@00i>CT0>c/k03lo?`0l?3`0?Shn0492@P0o?cl0?Cdm0410@00203`l?00:03dm?@0n?Sh0?clo
0451@@13@d<0@T9203hn?P0m?Cd0@41003hn?P80?Cdm00D0@T9203hn?P0k>c/0>CTi03Ph>00203/k
>`0403dm?@0j>SX0>SXj03hn?P80?clo0P0m?Cd0200k>c/0?3`l0451@@0l?3`0@d=30492@P14A4@0
@D510P10@4004`11@D40ATI604=3@`13@d<0ADE504=3@`0n?Sh0@T9203hn?P0l?3`0?Shn03dm?@0l
?3`0@T9204];B`11@D40AdM704I6AP0o?cl00P11@D4203hn?P030451@@0i>CT0?Shn0080@T9201h0
AdM704E5A@15ADD0CTi>04A4A012@T80?Shn04e=C@1JFUX0D51@05aLG01iNGT0RXZ:08R8R01jNWX0
G5aL04M7A`19BDT0CDe=04a<C01?Cdl0EeMG06=SH`1RHV80Cdm?04E5A@10@400@T9203`l?010@402
0451@@0704I6AP17AdL0D51@05YJFP1QHF40J6QX08F5Q@020;Bd]00T0:JVYP24Q8@0JFUY05EEE@19
BDT0ADE503dm?@10@400?Shn0410@00o?cl0@4100451@@12@T80@D5104M7A`1JFUX0GemO05]KF`1H
F5P0FEUI06=SH`1jNWX0XJ6Q0<K6aP2g]kL0MgMg096AT@2PX:00XZ:R0:JVYP2KVi/0/k>c0;Bd]02;
Rh/0Shn?0P2KVi/03P2GUiL0NWYj04];B`1UIFD0OWin06MWI`29RHT0T92@09:BTP2ATI40Ph>306e]
K@18B4P0?Cdm0P0o?cl04@0n?Sh0>SXj03`l?00j>SX0?Cdm03`l?00k>c/0?3`l03/k>`0l?3`0>SXj
03/k>`0l?3`0>c/k03Ph>00l?3`0>SXj0080?3`l00/0?clo03`l?00h>3P0>CTi03Lg=`0n?Sh0>SXj
03Hf=P0g=cL0>3Ph03Lg=`0203Ti>@0803Lg=`0j>SX0>CTi03Ti>@0j>SX0?3`l03dm?@0g=cL203Xj
>P0303/k>`0g=cL0>SXj0080>3Ph00<0?3`l03Ti>@0h>3P00P0j>SX01`0i>CT0>3Ph03Ph>00i>CT0
?Shn03/k>`10@4000P0m?Cd01@0l?3`0>c/k03hn?P0k>c/0?Cdm0080>SXj00X0?Cdm03Ti>@0i>CT0
H61P05MGE`0n?Sh0>SXj03/k>`0m?Cd0>c/k0P0l?3`203Xj>P0303Ph>00i>CT0>SXj00@0>SXj0P0h
>3P01P0k>c/0>3Ph03dm?@0m?Cd0?3`l03Ti>@80>c/k00<0?Shn03Xj>P0l?3`00`0k>c/07`0j>SX0
=cLg03dm?@0j>SX0CTi>04a<C01CDe<0KVi^08J6QP2=SHd0L71`051@D01KFe/0FUYJ05aLG01GEeL0
Ph>308R8R01iNGT0Lg=c06=SH`1WIfL0JFUY05IFEP1OGel0D51@03hn?P0i>CT0>3Ph03Xj>P0h>3P0
0`0g=cL203/k>`80>CTi0P0h>3P303Xj>P0M05=CD`1fMWH0YJFU0;^k^`3Fe]H0f][J0=_Kf`35aLD0
UiNG07AdM01oOgl0[Jf]0<g=c@2b/[80Vi^K09fMW@33`l<0/[:b09^KV`2FUYH0V9RH09NGU`2VYZH0
NWYj05EEE@1;Bd/0B4Q80492@P0i>CT00P0k>c/01`0m?Cd0>SXj03Ti>@0i>CT0>c/k04A4A00i>CT0
0P0h>3P00`0l?3`0>3Ph03`l?00203Xj>P0J04A4A01/K6`0W9bL0<k>cP3Ng]h0d];B0<_;b`2h^;P0
];Bd0<S8b03Ogml0hn?S0=CDe039bLT0XJ6Q08R8R01[Jf/0EUIF04U9B@16ATH0@D5104E5A@17AdL0
Bd];04Y:BP1@D50=ooooo`004?ooool00`1<C4`0Bd];04U9B@0204];B`0404a<C019BDT0AdM704E5
A@80BDU90P18B4P02`19BDT0BTY:04];B`1:BTX0A4A404M7A`16ATH0AdM704E5A@16ATH0@d=30080
AdM70180ADE504M7A`16ATH0AdM704I6AP13@d<0A4A404M7A`11@D40A4A40492@P14A4@0@T9204I6
AP14A4@0@d=304E5A@11@D4304=3@`050451@@12@T80@D5104=3@`12@T801011@D400`10@400ADE5
04=3@`0203lo?`0:0410@00o?cl0A4A404=3@`0n?Sh0?clo0451@@10@400?Shn0410@080?Shn01d0
@T920410@00m?Cd0?Shn03`l?00j>SX0?clo03dm?@10@400?3`l03lo?`11@D40?Shn04=3@`11@D40
?3`l03hn?P0j>SX0>c/k0410@011@D40?3`l03dm?@0n?Sh0?Cdm0451@@0n?Sh0>c/k03`l?00203hn
?P0E03/k>`0h>3P0?Cdm0492@P0l?3`0>c/k03lo?`0l?3`0?clo03Xj>P0l?3`0>c/k03lo?`11@D40
?clo03`l?00i>CT0?3`l03lo?`14A4@0@T920080?Shn00P0?clo03hn?P0k>c/0@D5103dm?@0n?Sh0
?clo03dm?@80?Shn00h0?3`l03/k>`0l?3`0?Cdm04U9B@12@T80@D510410@00m?Cd0@D5103hn?P0m
?Cd0@D5103hn?P80>c/k00X0@41003hn?P0m?Cd0ATI604M7A`1CDe<0Bd];05IFEP1OGel0E5AD0P1@
D5001@1GEeL0EUIF05IFEP1@D500FEUI0080Bd];01d0BTY:0492@P15ADD0ATI604Q8B01FEUH0GemO
06EUI@1DE5@0BDU904=3@`12@T80A4A404E5A@12@T80B4Q805ADE01BDU80BDU905=CD`1PH600M7Ad
08B4Q01SHf<0C4a<04I6AP15ADD0@41004A4A00303hn?P050410@00l?3`0>c/k03/k>`0l?3`00P0n
?Sh02016ATH0FEUI071`L01`L700G5aL06m_K`1lO7`0NWYj0P23Ph<0901`L700IFEU079bLP2@T900
];Bd0;Fe]@2h^;P0a<C40=3@d036a/H0];Bd09nOW`2KVi/0Z:RX0;bl_02QXJ40Lg=c06e]K@1RHV80
Jf][0:6QX@31`L40^;Rh0;Vi^@2e]KD0[Zj^08b<S01cLg<0K6a/07=cL`1_Kfl0Fe]K03dm?@0o?cl0
@4100451@@80>c/k00<0?Cdm03/k>`0j>SX00P0k>c/203Ti>@0;03`l?00k>c/0?3`l03lo?`12@T80
?Shn03Xj>P0g=cL0>SXj03Hf=P0j>SX00P0h>3P0400g=cL0>SXj03Ph>00l?3`0@D5104Q8B00n?Sh0
?3`l03/k>`0m?Cd0>3Ph03`l?00h>3P0=cLg03Hf=P0i>CT203Xj>P@0>CTi00l0?3`l03Xj>P0g=cL0
=cLg03Xj>P0m?Cd0>c/k03`l?00j>SX0>c/k03Ti>@0j>SX0>CTi03Lg=`0i>CT00P0k>c/0300j>SX0
?Cdm03lo?`13@d<0?Cdm03lo?`10@400>SXj03dm?@0j>SX0?Cdm03`l?0<0>CTi0P0h>3P203Ti>@07
03Ph>00g=cL0>CTi03Ti>@0g=cL0=SHf03dm?@0203Xj>P0W03Hf=P0g=cL0>c/k03/k>`0l?3`0>SXj
03Ph>00g=cL0>CTi03Lg=`0i>CT0DU9B09>CT`2^[Zh0/k>c08f=S@1iNGT0JFUY05EEE@1<C4`0Cdm?
04e=C@1?Cdl0F5QH05iNGP1HF5P0EEEE04Q8B017AdL0CTi>04=3@`11@D40>CTi03`l?00j>SX0>3Ph
03Ti>@0k>c/0?3`l0080>3Ph01l0>c/k03Ph>00h>3P0>CTi03Hf=P0i>CT0>SXj03`l?013@d<0EEEE
079bLP2NWYh0_;bl0;Vi^@2][Jd0WinO09BDU01UIFD0I6AT08N7Q`2ZZZX0`/;20<G5a@2h^;P0VYZJ
08J6QP1QHF40E5AD04];B`15ADD0?clo0080?Shn00P0?clo03Xj>P0j>SX0=cLg03Xj>P0h>3P0?3`l
03Ph>080>SXj0P0k>c/00`0j>SX0=cLg0492@P0303/k>`0G03hn?P10@400DU9B06m_K`2EUID0alO7
0>CTi03Xj>P0inOW0>7Qh@3WinL0j>SX0>OWi`3Ti>@0d];B0:^[Z`22PX80HV9R05IFEP16ATH0@T92
03/k>`0m?Cd00P0j>SX00`0k>c/0?Cdm03dm?@0203`l?00303hn?_oooooooooo00_ooooo000@oooo
o`80CDe=00<0Bd];04Y:BP18B4P00`19BDT204Q8B080CDe=0180AdM704E5A@1<C4`0BTY:04I6AP17
AdL0ADE504A4A018B4P0BDU904E5A@1:BTX0B4Q804E5A@14A4@0@T9204M7A`16ATH404A4A00404=3
@`1;Bd/0AdM704I6AP80ADE500<0ATI604Q8B012@T800`12@T804014A4@0@41004A4A013@d<0A4A4
04=3@`14A4@0@41003lo?`12@T80AdM70492@P0m?Cd0@T9204A4A010@40203lo?`0K0492@P0n?Sh0
@D5103lo?`10@400?clo03hn?P0k>c/0?Shn03/k>`0j>SX0?clo0451@@0l?3`0?Cdm03lo?`0l?3`0
@D5103dm?@13@d<0@41003`l?00n?Sh0@D5103Xj>P0k>c/0?clo0080?Shn00/0?Cdm03lo?`0m?Cd0
?clo03/k>`10@400>c/k03Xj>P12@T80?Cdm03lo?`0203dm?@0803/k>`10@400@T9203`l?00n?Sh0
?clo0451@@12@T8303`l?00403lo?`12@T80@D510492@P80?Cdm01D0?3`l03hn?P0o?cl0?Cdm03lo
?`0l?3`0>3Ph03/k>`0m?Cd0>SXj03lo?`0l?3`0?clo03Ti>@0k>c/0>SXj03/k>`0m?Cd0>SXj03hn
?P0k>c/00P0m?Cd00`0k>c/0?clo03`l?00203hn?P0504=3@`10@400@T9204Q8B014A4@00P19BDT0
2P1:BTX0EUIF05mOG`1SHf<0EeMG04=3@`14A4@0@d=303lo?`0n?Sh20451@@0903Xj>P0n?Sh0?Cdm
03hn?P0j>SX0?3`l03lo?`15ADD0?clo00<0AdM700/0@41003lo?`0n?Sh0DE5A05ADE01=CDd0BDU9
04Q8B012@T80DE5A04m?C`0204i>CP0T04];B`12@T80@D5103/k>`0o?cl0?Shn03dm?@0k>c/0?Shn
03dm?@0n?Sh0>3Ph03hn?P1@D500H61P06i^KP28R8P0WIfM09^KV`26QXH0JFUY05EEE@1BDU80AdM7
04E5A@14A4@0CDe=055AD@1FEUH0De=C04a<C018B4P0CTi>05IFEP1ZJVX0Ng]k0P22PX80702EUID0
_;bl0=OGe`31`L40J6QX05ADE01SHf<0M7Ad0:>SX`36a/H0fMWI0<K6aP2TY:@0PX:205eMG@1RHV80
N7Qh06EUI@1OGel0LG5a07emO@1`L700DU9B03hn?P0i>CT0>SXj03Lg=`0j>SX203/k>`0403`l?00k
>c/0=cLg03Xj>P80>c/k00X0>3Ph03Xj>P0m?Cd0?3`l03Lg=`0k>c/0?3`l03Ph>00j>SX0>CTi0P0l
?3`01@14A4@0JFUY08J6QP1VIVH0?clo00<0>c/k00X0>SXj03/k>`0g=cL0?3`l03Xj>P0l?3`0>CTi
03/k>`0i>CT0>SXj0P0i>CT00`0m?Cd0>3Ph03Ti>@0203Xj>P0303Ph>00j>SX0>c/k0080>3Ph0P0m
?Cd02P0j>SX0>CTi03/k>`0n?Sh0?3`l03/k>`12@T80?3`l03/k>`0o?cl203/k>`0503dm?@0k>c/0
>c/k03dm?@0n?Sh00P0k>c/0:P0h>3P0=CDe03Xj>P0h>3P0=SHf03Ti>@0h>3P0?Cdm03Lg=`0f=SH0
>c/k03dm?@0i>CT0=cLg03hn?P0m?Cd0=cLg03/k>`0j>SX0?Cdm03Ti>@0l?3`0?Cdm03hn?P1UIFD0
QhN70:NWY`2OWil0L71`05=CD`15ADD0>c/k05ADE018B4P0BDU904i>CP1YJFT0GEeM05YJFP0n?Sh0
?Cdm03`l?080>SXj00H0?Cdm03/k>`0i>CT0=cLg03Ti>@0j>SX303/k>`0303Ti>@0j>SX0?Shn00<0
>c/k01D0?Shn04E5A@1_Kfl0OGem096AT@2DU9@0P82006ATI01>CTh0BDU904E5A@1<C4`0EeMG08:2
PP2d];@0bLW90;jn_P2IVIT0JVYZ05EEE@13@d<00P0m?Cd203hn?P80?3`l00T0>SXj03`l?00j>SX0
>CTi03Ph>00i>CT0=cLg03/k>`0g=cL00P0h>3P0300l?3`0>CTi03`l?00l?3`0>SXj04=3@`19BDT0
Cdm?06EUI@1mOGd0Y:BT0<O7a`80c<c<00h0hn?S0>SXj03Vi^H0j>SX0>_[j`3WinL0f][J0;>c/`1h
N7P0CTi>0410@00l?3`0>c/k03dm?@80>CTi0P0j>SX0200g=cL0>SXj03`l?00l?3`0>CTi03lo?`0j
>SX0?3`l3Oooool0013ooooo00T0Cdm?04i>CP1;Bd/0BTY:04U9B@18B4P0AdM704Q8B01:BTX00P18
B4P01`16ATH0BDU904U9B@1;Bd/0ATI604M7A`16ATH00`15ADD01017AdL0@d=304M7A`16ATH204E5
A@0304I6AP19BDT0ADE50080ADE50240@d=304A4A013@d<0AdM704I6AP19BDT0AdM704A4A015ADD0
@T9204A4A016ATH0@T9204E5A@13@d<0A4A404=3@`12@T80ATI604E5A@16ATH0ADE504A4A012@T80
@D5103lo?`10@400ADE504=3@`0o?cl0@4100451@@0m?Cd00`0n?Sh303dm?@0903hn?P10@400?Shn
0410@00o?cl0?Cdm04A4A00n?Sh0?Cdm0080@T9200<0>c/k03dm?@0l?3`00P0k>c/05P0n?Sh0>SXj
03`l?00j>SX0>c/k03hn?P0m?Cd0?Shn0410@00o?cl0?Cdm03lo?`0n?Sh0?Cdm0451@@0n?Sh0@D51
03dm?@0l?3`0?Cdm03lo?`0n?Sh203/k>`0;0492@P0m?Cd0@41003dm?@0n?Sh0>c/k03Ti>@0l?3`0
?Cdm03hn?P0m?Cd00`0o?cl01@0n?Sh0?Cdm03hn?P0n?Sh0?Cdm0080@D510P0j>SX00`0k>c/0?Shn
03hn?P0203`l?00]0451@@0l?3`0?Cdm03`l?00h>3P0>CTi03`l?00k>c/0?Shn03dm?@0k>c/0@d=3
04e=C@16ATH0BDU904];B`15ADD0@d=304a<C016ATH0AdM704A4A019BDT0B4Q80451@@0j>SX0?Cdm
03`l?012@T80?3`l0451@@0k>c/0>CTi03lo?`12@T80>c/k0410@00l?3`0?clo03`l?00m?Cd0>SXj
0410@00k>c/0@4100080?Cdm0P10@4001P0n?Sh0?clo0410@010@400>c/k03lo?`80?Cdm00H0?clo
0451@@0k>c/0@D5103dm?@11@D420410@080?3`l00`0A4A405aLG01ZJVX0Lg=c06m_K`1dM7@0Lg=c
06EUI@1]KFd0MgMg071`L01DE5@20492@P0B0410@011@D40?clo03lo?`13@d<0@T920410@014A4@0
AdM705IFEP1`L700K6a/07QhN02ATI40`l?30<[:bP2a/K40UYJF0P2;Rh/05`2ATI40SXj>09BDU02;
Rh/0O7al06][J`1MGEd0G5aL069RHP1QHF40GEeM07]kN`2KVi/0TI6A0:>SX`2d];@0Lg=c055AD@0j
>SX0@41003Ph>00l?3`0?clo0080?3`l0P0k>c/203lo?`0C03hn?P0k>c/0?Cdm03/k>`0g=cL0?3`l
03dm?@14A4@0LG5a04=3@`0j>SX0>c/k04U9B@1SHf<0@D5103lo?`0k>c/0?Cdm03Xj>P0203`l?0<0
>c/k00`0>SXj03Ti>@0k>c/0>3Ph03dm?@0o?cl0?3`l03Ti>@0h>3P0?Shn03/k>`0j>SX203`l?003
03Xj>P0i>CT0?Shn0080?Shn00P0?Cdm03Xj>P0l?3`0>3Ph03hn?P0j>SX0?Cdm03hn?P80?3`l00D0
?clo03Xj>P10@400?Cdm03Xj>P0303/k>`0403Ti>@0h>3P0=cLg03Hf=P80?3`l0P0k>c/203Ti>@0:
03Lg=`0f=SH0>CTi03Ti>@0h>3P0?Cdm03Ti>@0l?3`0>3Ph03Xj>P80>c/k0180>CTi0451@@1XJ6P0
QhN709fMW@22PX80GemO04];B`0m?Cd0@41004i>CP1QHF40FEUI04M7A`1<C4`0AdM703lo?`0m?Cd2
03Xj>P0403Ti>@0h>3P0=cLg03Ti>@@0>SXj02D0>c/k03Ti>@0g=cL0>SXj03Hf=P0n?Sh0?3`l03/k
>`0i>CT0@T9205eMG@1/K6`0M7Ad0;fm_@2a/K40Ph>3065QH@16ATH0@D5104A4A01KFe/0JFUY07em
O@2GUiL0/;2`0<30`02IVIT0JVYZ04];B`10@400?3`l03/k>`0l?3`0>SXj03Ti>@0k>c/0?Cdm00@0
>3Ph00<0=SHf03Ti>@0h>3P00P0i>CT04@0h>3P0>c/k03`l?00o?cl0ADE504];B`1OGel0RXZ:0:n_
[`30`<00/k>c08^;R`1fMWH0RXZ:09VIV@2][Jd0bl_;0080k>c/00L0gmoO0<g=c@2j^[X0Ti>C06EU
I@17AdL0>CTi00<0>SXj00@0>3Ph03Ti>@0j>SX0>SXj0P0h>3P0100i>CT0>3Ph03Ph>00i>CT203Xj
>P0303Ph>00i>CWooooo00cooooo000@ooooo`80CDe=00P0C4a<04Y:BP1=CDd0BTY:04M7A`16ATH0
A4A404E5A@80BDU90P17AdL00`1:BTX0B4Q804Q8B00204M7A`0H04Q8B016ATH0B4Q804I6AP17AdL0
ATI604U9B@1;Bd/0BTY:04E5A@17AdL0ADE504I6AP18B4P0ADE504I6AP13@d<0ADE504U9B@17AdL0
A4A404E5A@16ATH0@d=30`15ADD05@12@T80A4A404=3@`10@400@d=30410@00n?Sh0ATI60492@P11
@D40@T9203hn?P10@400@D5103hn?P12@T80@41003lo?`0n?Sh0@D5103lo?`0203`l?00903lo?`0n
?Sh0@4100451@@0m?Cd0@T920451@@0k>c/0@T920080@41002H0@T9203hn?P0l?3`0@D5103hn?P0l
?3`0>SXj03dm?@0l?3`0?clo03Ti>@0j>SX0?Shn03/k>`0m?Cd0?Shn03`l?012@T80?clo03dm?@0k
>c/0?clo03hn?P0o?cl0ATI603lo?`0n?Sh0?clo04E5A@0n?Sh0?3`l03hn?P12@T80@D5103/k>`0m
?Cd0?Shn03Xj>P80>c/k00H0?Shn03/k>`0n?Sh0@D5103hn?P0k>c/203hn?P0903lo?`10@400@410
03lo?`11@D40?Cdm03`l?00k>c/0?clo0080>c/k00@0?Cdm03Ti>@0l?3`0>c/k0P0j>SX0500k>c/0
?Cdm04=3@`16ATH0Bd];04I6AP14A4@0@T9204=3@`0o?cl0@D510492@P1FEUH0ATI603lo?`0m?Cd0
@4100451@@15ADD0>c/k0P11@D404@14A4@0@T920451@@0n?Sh0?Cdm03lo?`13@d<0?3`l0492@P16
ATH0@d=303/k>`0j>SX0@d=303/k>`0l?3`0>SXj0080>c/k03X0?Shn03dm?@0n?Sh0A4A403/k>`0o
?cl0?Cdm03/k>`12@T80?Cdm0451@@10@400?Cdm04A4A01=CDd0DE5A05IFEP1TI6@0FUYJ055AD@1/
K6`0Lg=c07]kN`21PH40JFUY05]KF`1NGUh0Cdm?059BDP19BDT0@D5103lo?`12@T80@D5103lo?`1>
CTh0HF5Q07]kN`2=SHd0QHF509NGU`2HV9P0Ti>C08b<S02XZ:P0V9RH08:2PP1eMGD0LW9b071`L01H
F5P0Cdm?04];B`18B4P0@41004I6AP17AdL0@4100P0o?cl03`14A4@0AdM704e=C@1DE5@0HV9R06i^
KP1eMGD0PH6108N7Q`2TY:@0^;Rh0;no_`1hN7P0Cdm?03hn?P0203lo?`0804E5A@1HF5P0DU9B05AD
E01<C4`0ATI604M7A`0o?cl204U9B@0<04=3@`0n?Sh0?Shn0492@P1LG5`0@d=303`l?012@T80?Shn
03Lg=`0l?3`0>CTi0P0k>c/01`0j>SX0@41003`l?00k>c/0?Shn03`l?00k>c/00P0m?Cd02@0i>CT0
ADE504E5A@0m?Cd0>CTi03Lg=`0j>SX0>CTi03/k>`0203hn?P0=03/k>`0l?3`0@d=303`l?00i>CT0
>SXj03Lg=`0i>CT0>c/k04M7A`13@d<0>c/k03Xj>P0203`l?00703lo?`0m?Cd0A4A403hn?P0j>SX0
>c/k03Ti>@0203/k>`0703Ti>@0h>3P0>CTi03/k>`0i>CT0>c/k03Ti>@0203Lg=`0303Ph>00g=cL0
>CTi00<0>SXj00<0>c/k03hn?P0l?3`00P11@D402@12@T80Fe]K096AT@2CTi<0LW9b04e=C@0n?Sh0
EEEE05mOG`0203`l?00>05QHF01PH600De=C04A4A00l?3`0>3Ph03/k>`0l?3`0>CTi03De=@0g=cL0
>3Ph03Ti>@0j>SX203Lg=`0D03Xj>P0i>CT0?Cdm03Xj>P0h>3P0?Shn04A4A01NGUh0Kfm_06][J`1>
CTh0DE5A04i>CP1:BTX0C4a<055AD@17AdL0?Shn04e=C@1aLG4208n?S`0:09nOW`27QhL0QHF509>C
T`21PH40FEUI04M7A`0m?Cd0?3`l03dm?@80>3Ph00P0>SXj03Ph>00i>CT0>c/k03Lg=`0h>3P0>c/k
03Xj>P80>3Ph00@0>c/k04E5A@1FEUH0GemO0P1FEUH07P19BDT0@d=305QHF02EUID0_kno0;jn_P2[
Zj/0Ng]k06ATI01_Kfl0XJ6Q0=7Ad@3MgMd0h>3P0=kNgP3Hf=P0/[:b08>3P`1LG5`0A4A403Xj>P0i
>CT0>SXj03/k>`0g=cL0>CTi03Xj>P0h>3P0>CTi03Lg=`80>3Ph00<0>CTi03Ph>00g=cL00P0g=cL2
03Ti>@0303Lg=`0i>CWooooo00cooooo000@ooooo`0804];B`1<C4`0C4a<04a<C01:BTX0Bd];04Y:
BP18B4P204M7A`80BDU900P0AdM704E5A@1:BTX0B4Q804M7A`18B4P0BDU904];B`80B4Q800H0ATI6
04M7A`15ADD0AdM704I6AP1;Bd/204M7A`0804Y:BP18B4P0A4A404I6AP1:BTX0@d=304E5A@16ATH2
04E5A@0704I6AP17AdL0@T9204I6AP1;Bd/0ADE504=3@`020451@@040492@P16ATH0A4A40451@@80
@d=300H0@T920410@015ADD0@T9203hn?P0l?3`20492@P0B0410@011@D40?Shn0451@@0o?cl0?Cdm
0492@P0n?Sh0@41003hn?P0m?Cd0?Shn03dm?@0k>c/0?3`l0451@@0n?Sh0?Cdm0P0k>c/02012@T80
@41003lo?`0k>c/0?Cdm0410@013@d<0>c/k0P0l?3`01`0k>c/0?Cdm0410@00j>SX0?clo03dm?@0n
?Sh00P0l?3`01P0k>c/0@4100410@00m?Cd0>c/k03dm?@80>c/k00/0?3`l03/k>`0n?Sh0?Shn03/k
>`0l?3`0?clo03dm?@0j>SX0>CTi0410@00203dm?@0>03lo?`0l?3`0>SXj03hn?P0o?cl0?Shn03lo
?`0n?Sh0>CTi03dm?@0l?3`0?Shn03/k>`10@40203dm?@0303`l?011@D40@D510080@41000L0?clo
03Xj>P0o?cl0@d=304I6AP13@d<0@T920080?Cdm0P0n?Sh01`0m?Cd0?3`l03/k>`0k>c/0>CTi03lo
?`0n?Sh00P0l?3`01P0m?Cd0@D5103`l?00n?Sh0?Cdm03hn?P80?clo00/0?3`l03hn?P0m?Cd0?clo
03hn?P0m?Cd0?3`l03/k>`0i>CT0>SXj03lo?`0203`l?00703Ti>@0m?Cd0?3`l03dm?@0l?3`0@d=3
0451@@0203/k>`0303dm?@12@T80?Shn0080?clo00h0?Cdm04=3@`1DE5@0EUIF05QHF01CDe<0FEUI
05aLG01DE5@0BDU90451@@0n?Sh0>3Ph03/k>`<0@D510P0m?Cd05P17AdL0DU9B06EUI@1`L700Lg=c
06i^KP1dM7@0RXZ:0;2`/02SXj<0OGem06MWI`1?Cdl0ADE50451@@0m?Cd0@d=30492@P15ADD0BTY:
04Q8B01>CTh205UIF@0J061PH01GEeL0BTY:04];B`1<C4`0EEEE061PH01VIVH0Ng]k09BDU02RXZ80
ZJVY0<O7a`3Cdm<0emOG0;Fe]@2DU9@0Rh^;07]kN`1MGEd0DU9B071`L02XZ:P0/;2`0:j^[P2RXZ82
09:BTP06096AT@2KVi/0QHF506a/K01CDe<0BDU90P17AdL07P0o?cl0@T9206=SH`1RHV80JFUY06MW
I`1>CTh0?Cdm04i>CP1RHV80MGEe07]kN`1dM7@0IfMW05UIF@1CDe<0EEEE0451@@0j>SX0?clo03/k
>`0j>SX0?Cdm03hn?P0i>CT0>c/k03dm?@0n?Sh0?Cdm03Xj>P80?3`l0P0k>c/01`0o?cl0?3`l03dm
?@0i>CT0?Shn03Ti>@0h>3P00P0i>CT0100j>SX0>c/k03dm?@0m?Cd203Xj>P0803/k>`0j>SX0?3`l
03hn?P0m?Cd0>SXj03/k>`0l?3`203Xj>P0703/k>`0j>SX0=cLg03Xj>P0g=cL0>CTi03Xj>P0203dm
?@0505QHF01RHV80CTi>04E5A@1CDe<00P1;Bd/04P1?Cdl0?Cdm03Xj>P0j>SX0@41006ATI01?Cdl0
=cLg03Xj>P0i>CT0?Cdm03Ti>@0h>3P0=3@d03Hf=P0h>3P0=cLg03Xj>P80>CTi0P0h>3P08P0i>CT0
=cLg03Ph>00h>3P0=SHf03Xj>P0g=cL0B4Q807=cL`2?Shl0RHV907=cL`1GEeL0AdM704E5A@0n?Sh0
@41003Ph>00g=cL0@410065QH@2VYZH0`L710;:b/P23Ph<0Hf=S04m?C`0n?Sh0?clo03dm?@0h>3P0
>c/k03Ti>@0h>3P303Xj>P0403Lg=`0i>CT0>c/k03`l?080>SXj02H0>CTi03`l?00l?3`0?Shn05MG
E`1UIFD0GemO04];B`10@400@d=3071`L02DU9@0[Zj^09nOW`1`L700IFEU06m_K`2=SHd0ZZZZ0;Bd
]03>c/h0fm_K0=3@d02][Jd0TI6A06IVIP14A4@0?3`l03/k>`0j>SX0>c/k03De=@0g=cL0=SHf03Ph
>00i>CT0>3Ph03Lg=`80>3Ph100g=cL203Ph>00503Lg=`0i>CT0>CTi03Xj>P1:BTX03Oooool0013o
oooo00T0DE5A04a<C01>CTh0CDe=04];B`1<C4`0BDU904a<C01;Bd/00P18B4P01017AdL0ATI604=3
@`15ADD204U9B@0404I6AP18B4P0ATI604M7A`80ADE500L0Bd];04I6AP17AdL0AdM704Q8B014A4@0
B4Q80080ATI600D0A4A404M7A`1:BTX0ATI60451@@0204A4A00504=3@`18B4P0ATI604E5A@11@D40
0`13@d<01P10@400@D510492@P16ATH0@D510492@P80?Shn00D0@D5104A4A010@400@41003lo?`02
03hn?P0604I6AP0m?Cd0@D5103lo?`12@T80?Cdm0P12@T80100o?cl0@d=30451@@11@D4203lo?`0:
03hn?P0k>c/0?3`l03hn?P0m?Cd0ATI603Xj>P0l?3`0>c/k0451@@<0?clo00D0?Cdm03/k>`0i>CT0
>3Ph03dm?@0203hn?P0503Ph>00o?cl0>CTi03/k>`0g=cL00P0i>CT03`0m?Cd0>CTi03Ti>@0n?Sh0
>c/k03dm?@0k>c/0>SXj03lo?`0l?3`0?Cdm03Ph>00m?Cd0?clo0492@P0303`l?00@03lo?`14A4@0
ATI603Xj>P0l?3`0>c/k03hn?P0j>SX0>c/k0451@@0j>SX0?Shn03dm?@0l?3`0>SXj03hn?P80?clo
00`0A4A404=3@`14A4@0B4Q80451@@10@400?clo03hn?P0l?3`0?Cdm03lo?`0l?3`203dm?@0403hn
?P13@d<0?3`l03/k>`80>CTi00X0>SXj03lo?`10@400?Cdm03Ti>@11@D40@T9203lo?`0h>3P0?clo
0P0l?3`05`0o?cl0A4A403dm?@11@D40?clo03Xj>P0k>c/0?Cdm03`l?00i>CT0?clo03dm?@0l?3`0
?clo0410@00m?Cd0>SXj03`l?00o?cl0@41003hn?P0m?Cd0A4A400@0BTY:01L0CTi>04e=C@17AdL0
FEUI04i>CP14A4@0?clo0451@@0n?Sh0@T9203`l?015ADD0C4a<04M7A`16ATH0DE5A05=CD`1@D500
De=C05YJFP1?Cdl0GemO05ADE00205=CD`0J04m?C`1BDU80CDe=04Q8B011@D40@T920410@00n?Sh0
?clo0451@@1KFe/0JFUY07inOP22PX80R8R808B4Q02KVi/0/;2`0:>SX`2o_kl0d=3@0:BTY02IVIT0
ZJVY0<S8b03?cll20=7Ad@140;Zj^P2a/K40a<C40<k>cP3<c<`0clo?0<[:bP3?cll0e=CD0=OGe`2m
_Kd0FUYJ04a<C01VIVH0Ng]k08V9R@2KVi/0U9BD079bLP23Ph<0PX:204I6AP11@D40CTi>05eMG@2B
TY80Zj^[09JFUP1QHF40Lg=c08Z:RP2][Jd0`<3008^;R`1VIVH0De=C05MGE`1TI6@0Ph>30:BTY02S
Xj<0Zj^[0:j^[P2WYjL0VYZJ07UiN@1EEED0?Shn03`l?00i>CT0?clo03/k>`0j>SX0>c/k03dm?@0n
?Sh0@41003Ti>@10@400?Cdm03`l?012@T80?3`l03Ph>00m?Cd0>c/k03Xj>P0g=cL203Ti>@0;0410
@00l?3`0?Cdm03/k>`11@D40>SXj03Ph>00l?3`0>c/k03Ti>@0j>SX0100k>c/203`l?00303Ti>@0h
>3P0>SXj0080>SXj00X0?Cdm04a<C01EEED0IVIV055AD@0k>c/0>SXj03Ph>00g=cL0?Shn0P0m?Cd0
1@0k>c/0@D5103hn?P0n?Sh0>3Ph0080>SXj00@0>c/k03Xj>P0n?Sh0>c/k100j>SX01@0h>3P0=cLg
03Ti>@0k>c/0?3`l00<0>c/k01P0>SXj03Ph>00j>SX0ADE506IVIP1cLg<0GUiN04A4A01:BTX0B4Q8
03lo?`0l?3`0>SXj03Ti>@17AdL0GemO0861P@24Q8@0PX:206QXJ01FEUH0?3`l03Xj>P0h>3P203Lg
=`0303Hf=P0i>CT0>CTi0080>c/k00@0?3`l03Ti>@0i>CT0>CTi100h>3P08@0m?Cd0>3Ph03hn?P0i
>CT0A4A403dm?@0l?3`0EeMG08^;R`2IVIT0[Zj^0<k>cP2j^[X0W9bL09ZJVP2^[Zh0bl_;0=cLg03Q
hN40bl_;0;fm_@2][Jd0QXJ605aLG01:BTX0?Shn04U9B@16ATH0A4A404=3@`15ADD0?Shn03dm?@03
03hn?P0703Ph>00j>SX0>SXj03Xj>P0h>3P0>CTi03Lg=`0203/k>`0703Ti>@0h>3P0?Shn04i>CP1/
K6`0Xj>S0;jn_P0=ooooo`004?ooool0101PH600D51@04a<C01;Bd/204Y:BP0304Q8B016ATH0Bd];
0080BDU900<0AdM704U9B@16ATH00P15ADD01016ATH0AdM704I6AP19BDT204M7A`0904A4A018B4P0
B4Q804I6AP17AdL0ATI604Y:BP15ADD0ATI60080A4A40180AdM704U9B@16ATH0ATI604Y:BP17AdL0
@d=304E5A@14A4@0ATI604Q8B013@d<0ADE50451@@15ADD0@d=304I6AP12@T840451@@040492@P14
A4@0@D5103lo?`80@T920P10@4002`0n?Sh0?clo03lo?`11@D40?Shn03dm?@0o?cl0@4100451@@0n
?Sh0@T920080?clo01<0@T920410@011@D40@d=303hn?P12@T80?clo03Xj>P0n?Sh0?Cdm03lo?`0m
?Cd0>c/k03hn?P0k>c/0>SXj03dm?@0l?3`0?Shn0080?3`l00D0@D5103`l?00j>SX0>3Ph03Hf=P02
03/k>`0403Ph>00k>c/0?3`l03Ti>@<0?Cdm00P0>CTi03/k>`0n?Sh0?3`l03/k>`0o?cl0@41003dm
?@<0?3`l0180>SXj0410@00i>CT0@41003dm?@0l?3`0?clo03/k>`10@400>c/k03Ti>@0m?Cd0@T92
03hn?P10@400@T920410@00o?cl303hn?P80?clo00L0?Cdm03lo?`0n?Sh0?3`l03dm?@0k>c/0?Shn
0080?3`l00P0>3Ph03/k>`0n?Sh0>c/k03Xj>P0l?3`0?Cdm03hn?P@0?Cdm00@0>3Ph03Ti>@0o?cl0
@4100P0m?Cd03@12@T80@D5103lo?`12@T80>c/k03Ti>@0k>c/0>SXj03/k>`0n?Sh0>c/k03`l?00m
?Cd0100n?Sh01015ADD0@D510492@P16ATH2059BDP0404U9B@1<C4`0Bd];04M7A`80@D5100<0A4A4
03hn?P10@4000`12@T80200k>c/0@41004Y:BP1KFe/0CTi>04a<C01CDe<0FEUI0P17AdL01`16ATH0
@T9204I6AP15ADD0@D5103dm?@0l?3`00P10@400=00j>SX0@T9204I6AP1?Cdl0FUYJ071`L02=SHd0
XZ:R09^KV`2EUID0U9BD08N7Q`1cLg<0OWin08N7Q`23Ph<0SXj>0:2PX02CTi<0T92@09BDU02OWil0
W9bL09fMW@2@T900MGEe06IVIP1ZJVX0J6QX06i^KP29RHT0UiNG0:RXZ031`L40`l?30:j^[P2e]KD0
^KVi0;:b/P2^[Zh0];Bd0;2`/02^[Zh0Zj^[0:NWY`2BTY80OWin0:RXZ02k^k/0_;bl0;:b/P2UYJD2
0:^[Z`0M09^KV`2HV9P0Ti>C09FEU@2UYJD0ZZZZ09>CT`2TY:@0[:b/0:RXZ02YZJT0UYJF0;6a/@3;
bl/0bLW90;Ng]`2ATI40MWIf05ADE01<C4`0?Shn03`l?00j>SX0>c/k03Xj>P0i>CT0>c/k03`l?00i
>CT00P0l?3`02`14A4@0?3`l03Xj>P1<C4`0@d=303Ph>00i>CT0?clo03Xj>P0l?3`0?clo0080?Shn
00L0@4100451@@0j>SX0>CTi03Lg=`0h>3P0>CTi0080@T9201/0?3`l03/k>`0m?Cd0?Cdm03hn?P10
@400>3Ph03`l?00i>CT0BTY:06a/K01ADE40?clo03`l?00k>c/0>CTi03/k>`0n?Sh0>CTi03`l?00j
>SX0=cLg03`l?00j>SX0>c/k03`l?00j>SX00P0k>c/01@0j>SX0>CTi03/k>`0i>CT0=cLg00<0>SXj
00<0>3Ph03Lg=`0i>CT00`0k>c/05@0i>CT0?3`l03De=@0k>c/0?Shn0451@@10@400ADE503hn?P11
@D40?Shn03Ti>@0k>c/0A4A404Q8B01`L700TY:B09RHV01ZJVX0CDe=0451@@0203Ph>00=03Xj>P0h
>3P0=cLg03@d=00b<S80=cLg03Xj>P0g=cL0?Cdm03/k>`0n?Sh0>SXj03Ph>00403Xj>P0Q03`l?00o
?cl0>SXj03dm?@0j>SX0?clo04i>CP1lO7`0c<c<0=cLg035aLD0eMGE0=cLg03Cdm<0f=SH0=cLg03T
i>@0h>3P0=oOg`35aLD0VYZJ06QXJ015ADD0@T9205MGE`1[Jf/0QXJ609NGU`2>SXh0KVi^05]KF`1=
CDd0?Shn0080@41000H0>CTi03Lg=`0h>3P0=SHf03Ti>@12@T8203Ti>@0:03Ph>00m?Cd0@T9205EE
E@1dM7@0Zj^[0<g=c@3Bd]80d=3@0<_;b`gooooo000@ooooo`070:b/[023Ph<0KVi^05YJFP1>CTh0
BDU904Q8B00204Y:BP0404E5A@16ATH0AdM704M7A`80ATI601h0ADE504A4A013@d<0@T9204Q8B016
ATH0BDU904A4A016ATH0A4A404Y:BP13@d<0ATI604A4A013@d<0Bd];04Y:BP16ATH0@T920451@@13
@d<0A4A404I6AP15ADD0A4A404E5A@17AdL0@D5104A4A011@D4204=3@`0804A4A015ADD0@d=303lo
?`12@T80@d=303lo?`12@T830451@@0?0410@014A4@0@4100492@P0o?cl0@4100492@P0l?3`0?Shn
0410@011@D40@T9203dm?@13@d<0?clo0080?Shn0P10@400A@0o?cl0@T9204=3@`0l?3`0?Shn0492
@P11@D40AdM70410@00l?3`0?clo0492@P11@D40?3`l03Ti>@0m?Cd0>SXj03`l?00j>SX0?3`l03hn
?P0l?3`0>SXj03dm?@0k>c/0>3Ph03/k>`0i>CT0=SHf03Xj>P0i>CT0?Cdm03Ph>00k>c/0>SXj03Ph
>00m?Cd0?3`l03Xj>P0o?cl0?Shn03dm?@0l?3`0?clo03hn?P0m?Cd0?clo0451@@0n?Sh0>SXj03lo
?`12@T80A4A4059BDP12@T80?Shn0410@00o?cl0>CTi03`l?011@D40@41003dm?@10@400@T9203`l
?00k>c/0?clo03dm?@0203`l?00703dm?@0n?Sh0>3Ph0410@014A4@0B4Q803lo?`0203/k>`0303Ti
>@0k>c/0?3`l0080>CTi00X0?3`l03Ph>00g=cL0>CTi03Lg=`0h>3P0>SXj03`l?00m?Cd0>c/k0P0m
?Cd02@0k>c/0@4100492@P0n?Sh0>c/k03`l?00k>c/0?Cdm03/k>`0303hn?P80>c/k00D0@41004I6
AP0m?Cd0AdM704=3@`0204E5A@0A0410@00j>SX0>3Ph03`l?00j>SX0A4A404U9B@16ATH0@41004Q8
B017AdL0?Shn03lo?`0n?Sh0ATI604U9B@18B4P00P14A4@01012@T80>3Ph03`l?00i>CT203/k>`0H
03dm?@0n?Sh0>SXj03Ph>00k>c/0>SXj04A4A01TI6@0Ogmo09ZJVP2IVIT0S8b<092@T02DU9@0VYZJ
0::RXP2[Zj/0Q8B406m_K`1kNg/0W9bL09jNWP27QhL0J6QX0P1ADE40801:BTX0AdM70451@@14A4@0
@T9204=3@`11@D40CTi>05aLG01eMGD0MgMg06YZJP1]KFd0UYJF0;Vi^@3>c/h0hn?S0>;RhP3>c/h0
QXJ60:RXZ02o_kl0`<300<[:bP37alL0/[:b0:f][@3;bl/0emOG0=oOg`3Hf=P0`l?30P2b/[805P33
`l<0f][J0=3@d02WYjL0U9BD0:RXZ02][Jd0QXJ607emO@2WYjL0dm?C0=CDe03?cll0a<C409>CT`1V
IVH0EEEE04i>CP11@D40?Shn03`l?012@T8203Ph>00303Xj>P0n?Sh0>SXj0080>CTi00l0?Cdm03Xj
>P0o?cl0@41005YJFP1QHF40@41003hn?P0g=cL0>CTi03dm?@17AdL0@D5103lo?`13@d<00P1:BTX0
2@0i>CT0@D510451@@12@T80DU9B04e=C@15ADD0@d=303dm?@0203Xj>P0803`l?00m?Cd0>CTi03Xj
>P1:BTX0IfMW06ATI00k>c/203Ti>@0603Ph>00i>CT0>c/k03hn?P0g=cL0>3Ph0P0l?3`0100j>SX0
>c/k03Ph>00o?cl303/k>`0503Ti>@0h>3P0>3Ph03Ti>@0h>3P00P0j>SX00`0i>CT0=cLg03Ti>@02
03Ti>@0I03Ph>00i>CT0=3@d03Lg=`0i>CT0A4A404E5A@10@400=cLg03Ti>@0j>SX0>3Ph03De=@0h
>3P0@41006IVIP1TI6@0MGEe06m_K`17AdL0>3Ph03/k>`0g=cL0=SHf03Ti>@0203Ph>00;03Hf=P0e
=CD0=CDe03Xj>P0l?3`0=cLg03lo?`0i>CT0>SXj03Ph>00j>SX00P0k>c/203Xj>P0:03Ti>@0e=CD0
>3Ph0410@01;Bd/0J6QX0::RXP3Bd]80h>3P0=oOg`80f][J00d0e]KF0=SHf03Fe]H0c<c<0;Zj^P2O
Wil0SXj>06ATI01?Cdl0A4A404I6AP1;Bd/0H61P0080KFe]00H0IVIV05ADE014A4@0>c/k03hn?P0j
>SX203Lg=`0B03Ti>@0h>3P0=CDe03dm?@0i>CT0=cLg03/k>`0i>CT0Cdm?08N7Q`2OWil0`L710=oO
g`3Hf=P0alO70:j^[P2>SXh0MgMg3Oooool0013ooooo00X0UYJF08b<S02=SHd0Ph>3065QH@1@D500
B4Q804];B`1<C4`0BTY:0P1=CDd04@17AdL0B4Q804M7A`16ATH0AdM704I6AP17AdL0B4Q804M7A`19
BDT0AdM704I6AP13@d<0BDU90451@@19BDT0ADE50080AdM70P13@d<01015ADD0A4A404I6AP16ATH2
04E5A@80A4A400<0ATI60451@@12@T800P11@D4204=3@`0404I6AP15ADD0@D510410@080@D5101D0
A4A40410@011@D40@D5103lo?`12@T80@d=30451@@15ADD0@T920410@011@D40?clo0410@011@D40
@d=303lo?`18B4P0AdM704=3@`10@4000P11@D400`0o?cl0@D5104E5A@020451@@80?clo01<0@D51
03dm?@0n?Sh0?3`l03/k>`0m?Cd0>c/k03Xj>P0m?Cd0>c/k03dm?@0n?Sh0?3`l03Xj>P0n?Sh0?3`l
03dm?@0l?3`0?Cdm0080>SXj00T0?Cdm03Xj>P0m?Cd0?Shn03/k>`0j>SX0?Shn0492@P0j>SX00`0l
?3`02P0h>3P0>SXj03/k>`0m?Cd0?3`l03Xj>P0g=cL0?3`l03Xj>P0k>c/203`l?00503Xj>P0n?Sh0
?Shn03`l?00m?Cd00`0n?Sh00`0o?cl0?Cdm03hn?P0203`l?0090410@00o?cl0@d=30492@P0m?Cd0
?3`l03dm?@0n?Sh0>3Ph0080>CTi00@0?Shn03Xj>P0m?Cd0>SXj0P0l?3`303Xj>P0503`l?00n?Sh0
?clo03hn?P0k>c/00P0j>SX203Ti>@0;03`l?011@D40?Cdm03`l?00j>SX0?clo03/k>`0h>3P0?Cdm
0410@014A4@00P13@d<01@0n?Sh0?3`l0410@012@T80Bd];0080@D5100<0?Cdm03`l?00n?Sh00`0m
?Cd01012@T80@41004E5A@18B4P204];B`0303lo?`10@400A4A40080?clo00@0?Shn0410@013@d<0
?Shn0`0k>c/0100l?3`0>c/k03/k>`0m?Cd303`l?00803Ph>00l?3`0?Shn03Ti>@10@400D51@055A
D@1FEUH2059BDP80E5AD0P1HF5P02@1KFe/0DU9B04Y:BP18B4P0EEEE05MGE`1>CTh0AdM70451@@02
03hn?P0804];B`1GEeL0Jf][07EeM@2TY:@0];Bd09FEU@2?Shl2096AT@0G08b<S02=SHd0VYZJ0:BT
Y02a/K40alO70<o?c`2l_;`0[:b/0:RXZ02][Jd0^KVi0;Rh^02FUYH0QHF508N7Q`29RHT0VIVI0;2`
/02f][H0[Zj^0<30`038b<P00P3?cll05@2m_Kd0`/;20;^k^`2f][H0_kno0:RXZ02EUID0X:2P0;Fe
]@29RHT0OGem06IVIP18B4P0@T9204=3@`0j>SX0?Shn03dm?@0n?Sh0>SXj03`l?00203Xj>P80?3`l
01H0?clo03`l?00j>SX0?3`l051@D01hN7P0MGEe0451@@0i>CT0?3`l03Xj>P0n?Sh0?Cdm03lo?`1M
GEd0MWIf071`L01RHV80GEeM03/k>`0n?Sh0AdM70P1:BTX01`0n?Sh0>c/k03Xj>P0i>CT0>SXj03Ti
>@0k>c/00P0j>SX0100n?Sh0F5QH04=3@`0m?Cd203Ph>080>SXj0P0o?cl01`0m?Cd0>c/k03Xj>P0k
>c/0>SXj03Ti>@0n?Sh00`0j>SX01`0k>c/0>SXj03Ti>@0o?cl0>3Ph03Ti>@0m?Cd00`0i>CT0200g
=cL0>3Ph03Ti>@0i>CT0>3Ph03Lg=`11@D40?clo0P0j>SX0100l?3`0?clo03Xj>P0f=SH203Ph>00=
03/k>`0l?3`0C4a<05=CD`17AdL0BDU90451@@0l?3`0>CTi03Lg=`0j>SX0=cLg03Xj>P0203Lg=`06
03Hf=P0g=cL0=cLg03Xj>P0k>c/0>3Ph0P0j>SX00`0k>c/0>SXj03`l?00203`l?00803Xj>P0i>CT0
>CTi03/k>`1[Jf/0PX:207AdM02c/k<20=OGe`0=0=WIf@38b<P0_;bl0;Rh^02SXj<0V9RH08n?S`1_
Kfl0GEeM05EEE@1?Cdl0@T920451@@0303/k>`0603lo?`0n?Sh0?3`l03dm?@0h>3P0?3`l0P0h>3P0
0`0f=SH0>CTi03Ti>@0203Ph>00@03Hf=P0j>SX0>CTi05IFEP1eMGD0WIfM0<?3``3Fe]H0dM7A0<71
`@2KVi/0LW9b05aLG01BDU80F5QH06=SH`gooooo000@ooooo`03059BDP1TI6@0L71`0080NWYj00H0
LG5a06m_K`1`L700HV9R04a<C019BDT204Y:BP0B04e=C@19BDT0B4Q804U9B@17AdL0BDU904I6AP17
AdL0BDU904Q8B016ATH0ADE504Q8B014A4@0AdM704E5A@18B4P0A4A40`17AdL02`1ADE40BTY:04I6
AP17AdL0ATI604E5A@16ATH0@D5104A4A016ATH0A4A40080@d=300D0AdM704e=C@14A4@0?clo0451
@@020492@P80@D5100D0B4Q804=3@`0o?cl0?Cdm0410@00204=3@`80?Shn00<0?Cdm03hn?P12@T80
0P10@4001`13@d<0@41003`l?00o?cl0?Cdm03hn?P0m?Cd00P0o?cl03P10@400?Shn0410@00m?Cd0
>c/k03hn?P0m?Cd0@D5103`l?00j>SX0?Shn03/k>`0m?Cd0?clo0P0n?Sh04011@D40?Cdm03Ti>@0j
>SX0>c/k03`l?00m?Cd0>3Ph03Xj>P0l?3`0>SXj03Ph>00l?3`0>c/k03hn?P0i>CT203`l?00703Xj
>P0k>c/0?Cdm03Ti>@0f=SH0>CTi03`l?00203Xj>P0<03dm?@0k>c/0>SXj03dm?@0g=cL0>CTi03Xj
>P0g=cL0>CTi03/k>`0o?cl0?Shn0P0j>SX01@0m?Cd0?3`l0410@00n?Sh0?Cdm0080>c/k00<0>CTi
03hn?P0n?Sh00P0l?3`0300k>c/0?Cdm03dm?@0i>CT0?clo03`l?00i>CT0?Cdm03hn?P0m?Cd0?3`l
03/k>`80@41000/0>c/k03Xj>P10@400@41003lo?`0m?Cd0>c/k03Ti>@0h>3P0=cLg03lo?`0303/k
>`80>CTi01@0?3`l03/k>`0l?3`0?Cdm03/k>`0m?Cd0?3`l03dm?@0o?cl0?Shn03lo?`0k>c/0@410
03/k>`0l?3`0?clo04E5A@0n?Sh0?Cdm04A4A080Bd];00@0?clo0410@012@T80@4100P0m?Cd02P0l
?3`0>SXj03/k>`0j>SX0>CTi03`l?00j>SX0?3`l03hn?P0l?3`503Xj>P1A03`l?00j>SX0?3`l03dm
?@0k>c/0@T9203Xj>P0m?Cd0De=C06a/K01aLG40HF5Q05YJFP14A4@0?Cdm03/k>`10@400?Cdm03hn
?P0l?3`0?clo03Xj>P13@d<0ATI605=CD`1mOGd0XJ6Q0;bl_02b/[80WYjN09^KV`2HV9P0UIFE09VI
V@2XZ:P0ZZZZ09>CT`24Q8@0O7al07IfMP1oOgl0LG5a06UYJ@1OGel0GEeM05aLG01PH600JVYZ07If
MP1bLW80Ph>3092@T02CTi<0UiNG0:FUY@2b/[80/k>c0<30`02m_Kd0^KVi0:>SX`2>SXh0MgMg06i^
KP28R8P0[Zj^0<_;b`35aLD0a/K60;Zj^P2VYZH0LG5a05YJFP13@d<0>CTi03dm?@0n?Sh0?3`l03dm
?@0l?3`0>c/k0080>SXj00/0>c/k03hn?P0m?Cd0?clo03hn?P0o?cl0EeMG08f=S@1TI6@0@41003Xj
>P0303/k>`80?clo00@0A4A404E5A@13@d<0?Shn0P0l?3`04@13@d<0De=C055AD@0n?Sh0?Cdm0410
@00j>SX0>CTi03Xj>P0g=cL0>3Ph03Ti>@0j>SX0>3Ph03`l?00i>CT0>SXj0080>c/k00D0?clo03`l
?00m?Cd0>CTi03Xj>P0203Ph>00503Xj>P0k>c/0@D5104A4A00i>CT00P0g=cL0100h>3P0>CTi03Ph
>00h>3P203De=@0503/k>`0j>SX0>SXj03/k>`0g=cL00P0f=SH0200h>3P0>SXj03/k>`0g=cL0?3`l
03Lg=`0i>CT0=SHf0P0j>SX01P0k>c/0?Cdm03Xj>P0k>c/0BDU904A4A0<0>SXj00P0=3@d03Lg=`0i
>CT0>SXj03dm?@0i>CT0>3Ph03Lg=`80=SHf0P0g=cL00`0e=CD0>3Ph03Ti>@0203De=@0G03Lg=`0h
>3P0?3`l03Xj>P0g=cL0>CTi03hn?P1QHF40Ng]k09:BTP2OWil0U9BD096AT@2][Jd0WYjN09BDU020
P800LG5a05iNGP1FEUH0ATI60410@015ADD00P0m?Cd03@0k>c/0?3`l03/k>`0i>CT0=cLg03/k>`0m
?Cd0=cLg03`l?00f=SH0>3Ph03Ti>@0g=cL00P0j>SX05@0h>3P0=cLg03/k>`0l?3`0ATI6069RHP2;
Rh/0Zj^[0<W9b@3AdM40alO709bLW01hN7P0EeMG04a<C018B4P0GemO08R8R02WYjL0_;bl0:j^[P0=
ooooo`004?ooool02@20P800VIVI0;2`/02UYJD0XZ:R09jNWP2<S8`0MgMg05aLG002051@D006055A
D@1?Cdl0Cdm?04a<C01;Bd/0AdM70`16ATH204U9B@0I04M7A`16ATH0ADE504M7A`15ADD0BDU904M7
A`15ADD0ATI604Q8B015ADD0@T9204a<C01:BTX0A4A404E5A@18B4P0ADE504Q8B012@T80ATI604M7
A`15ADD0@d=30410@00204E5A@090492@P11@D40ADE50451@@10@400@D510410@011@D40@T9200<0
?clo00`0@T920451@@0o?cl0@D5103lo?`0m?Cd0?clo0492@P0n?Sh0>c/k03Xj>P0m?Cd203lo?`03
0410@00l?3`0?clo0080@T9200X0@D510410@010@400?Cdm0410@00o?cl0?3`l03/k>`0m?Cd0?3`l
0P0j>SX203/k>`0@03Ph>00m?Cd0?Cdm03hn?P0o?cl0?Shn03/k>`0i>CT0>c/k03Ti>@0n?Sh0@D51
03dm?@10@400>c/k03dm?@<0>SXj00L0>c/k03dm?@0n?Sh0>c/k03Xj>P0h>3P0>SXj0080>c/k0P0m
?Cd04P0n?Sh0@d=303hn?P0h>3P0>c/k03`l?013@d<0?Cdm03lo?`0l?3`0?Cdm03hn?P0o?cl0>SXj
03/k>`0l?3`0?Cdm03Ph>080>SXj00@0?Shn03`l?00k>c/0?clo0P0l?3`03@0o?cl0?Cdm03lo?`0h
>3P0>c/k03`l?00o?cl0>c/k03dm?@0o?cl0@d=303/k>`0m?Cd00P0n?Sh01`0k>c/0?3`l03dm?@0l
?3`0>3Ph03Ti>@0k>c/00P0o?cl02`0k>c/0?Cdm03dm?@10@400@T9203lo?`0n?Sh0>c/k03Ti>@0j
>SX0@4100080?Cdm00X0?clo03`l?00n?Sh0@d=303lo?`0m?Cd0?3`l04=3@`0m?Cd0@D510`0o?cl0
1@0h>3P0?Shn03lo?`0o?cl0?3`l0080?Shn00@0?3`l03dm?@0l?3`0>SXj0P0i>CT05@0j>SX0>c/k
03Xj>P0i>CT0>c/k03Ti>@0j>SX0?3`l03Ph>00j>SX0?3`l04E5A@1KFe/0JFUY06=SH`1TI6@0EEEE
04U9B@16ATH0?clo03hn?P0203dm?@0I0410@00m?Cd0>c/k03dm?@12@T80D51@06ATI028R8P0QHF5
09FEU@2SXj<0WYjN08b<S01kNg/0QhN708R8R01mOGd0Kfm_06=SH`1FEUH0Bd];04E5A@0n?Sh0@d=3
0451@@020410@00903`l?010@400A4A404=3@`18B4P0CDe=05aLG01_Kfl0O7al0080Shn?03H0QHF5
06m_K`1QHF40D51@04];B`17AdL0BTY:04i>CP1GEeL0LG5a09ZJVP2l_;`0`/;20=?Cd`3EeMD0g=cL
0=OGe`32`/80Z:RX08N7Q`1IFET0Cdm?069RHP1?Cdl0?clo0410@00n?Sh0?Cdm03`l?00k>c/0@410
03lo?`0l?3`0@d=3055AD@1GEeL0E5AD05]KF`1gMgL0Rh^;05mOG`0l?3`0?Cdm0410@01BDU80H61P
06a/K01[Jf/0Fe]K04a<C00n?Sh0>CTi0410@011@D4203/k>`0303dm?@0o?cl0>c/k0080>3Ph00<0
>CTi03`l?00i>CT00P0j>SX203Ti>@80=cLg0P0f=SH03P0h>3P0>c/k03/k>`0i>CT0>SXj03Ph>00j
>SX0?Cdm04i>CP1;Bd/0>CTi03Hf=P0k>c/0>CTi1P0j>SX00`0h>3P0>CTi03Xj>P0203Ti>@0903`l
?00k>c/0>SXj03Ti>@0g=cL0?Cdm03Hf=P0g=cL0=SHf0080>CTi00h0>3Ph03Xj>P13@d<0ATI604Y:
BP0o?cl0>3Ph03Ti>@0f=SH0>c/k03`l?00m?Cd0=cLg03Ph>080=cLg00T0>CTi03Ph>00k>c/0=CDe
03Lg=`0j>SX0>CTi03Xj>P0h>3P00P0g=cL0500h>3P0=CDe03Ti>@0h>3P0AdM708^;R`31`L40/;2`
08F5Q@26QXH0PX:20820P01YJFT0FEUI05EEE@10@400?Cdm03Lg=`0n?Sh0?3`l0P0k>c/303Ti>@80
>c/k0240>3Ph03De=@0i>CT0>CTi038b<P0g=cL0>3Ph03Ti>@0f=SH0>c/k03Xj>P0n?Sh0B4Q8069R
HP2JVYX0[Zj^0;2`/02b/[80_Kfm0:VYZ@21PH40Hf=S051@D01FEUH0M7Ad09:BTP2f][H0d=3@0=?C
d`3?cll0^[Zj08V9R@1UIFD03Oooool0013ooooo01@0EUIF05ADE01WIfL0Jf][07inOP2?Shl0SHf=
07moO`1iNGT0UYJF08^;R`24Q8@0Kfm_051@D01=CDd0C4a<04i>CP1<C4`0BTY:04U9B@<0B4Q800@0
BTY:04U9B@16ATH0AdM70P1<C4`02@1:BTX0B4Q804I6AP15ADD0ATI604A4A015ADD0A4A404=3@`03
04I6AP0604M7A`1:BTX0BTY:04I6AP14A4@0ATI61013@d<02@11@D40@4100410@011@D40@41004A4
A013@d<0?Shn0451@@0203hn?P0>03`l?012@T80@d=30451@@0l?3`0@D5104A4A013@d<0?Cdm03hn
?P0o?cl0>c/k0410@011@D420410@00603lo?`0n?Sh0?Shn03hn?P0o?cl0>SXj0P0m?Cd0100i>CT0
?Shn03lo?`0k>c/203Xj>P0:03dm?@0l?3`0?3`l03`l?00j>SX0>CTi03Xj>P0l?3`0?Shn03lo?`80
>CTi00H0?3`l03dm?@13@d<0@T9203/k>`11@D4203/k>`80?3`l0P0j>SX04@0m?Cd0?Shn03/k>`0l
?3`0?Shn03Xj>P0m?Cd0?3`l03Xj>P0o?cl0?3`l03/k>`0l?3`0>SXj0410@00l?3`0>c/k0080>CTi
00P0>SXj03Ph>00g=cL0>CTi03/k>`0j>SX0>CTi03/k>`80>SXj00H0>CTi03Xj>P10@400>SXj03Ti
>@0m?Cd303`l?00A0451@@0k>c/0?Shn03dm?@10@400?Shn03/k>`0m?Cd0?Shn03Xj>P0k>c/0>CTi
03/k>`0m?Cd0>c/k03lo?`10@4000P0l?3`203hn?P80?Cdm00@0@D5104=3@`0o?cl0?Shn0P11@D40
200o?cl0?Cdm03/k>`0o?cl0?Shn0410@00l?3`0>c/k0P0h>3P01`0n?Sh0>SXj03/k>`0o?cl0@D51
0492@P0j>SX00P0k>c/303`l?00603/k>`0j>SX0=SHf03/k>`0l?3`0?Cdm0P0l?3`0;@0m?Cd0?3`l
03Xj>P0k>c/0>SXj03Ti>@15ADD0B4Q80451@@1BDU80JFUY071`L01NGUh0I6AT04Y:BP0m?Cd0?Shn
03`l?00k>c/0?Shn0410@015ADD0BTY:04a<C01=CDd0EeMG06=SH`1lO7`0S8b<0820P01`L700IfMW
06=SH`1hN7P0QhN708B4Q01cLg<0DE5A04Q8B01>CTh0H61P06a/K01EEED0A4A403lo?`0203hn?P0=
03`l?00o?cl0ADE504U9B@1FEUH0MgMg07]kN`2BTY80RXZ:06][J`1OGel0AdM70410@00203dm?@0>
0451@@18B4P0E5AD04i>CP1?Cdl0C4a<04Y:BP17AdL0CTi>05EEE@1UIFD0JFUY06e]K@1_Kfl207Ee
M@0S08>3P`2QXJ40[jn_09ZJVP2ATI40P820075aL@1PH600EUIF04a<C017AdL0@T9204Q8B01IFET0
K6a/05iNGP2BTY80`<300;no_`2i^KT0a<C40<_;b`39bLT0Vi^K07YjNP20P800YjNW0=3@d03De=@0
_;bl0:FUY@2IVIT0Lg=c04A4A013@d<00P15ADD03`12@T80>c/k03hn?P0o?cl0?Cdm03Ph>00k>c/0
>CTi03Xj>P0i>CT0>c/k03Lg=`1;Bd/0@d=303Ph>00203Ti>@0903Xj>P0k>c/0>c/k03lo?`0i>CT0
@41003dm?@0l?3`0@T920080>SXj00T0=cLg03Ph>00h>3P0?Cdm03Ti>@0g=cL0=SHf03Ti>@0l?3`0
0P0k>c/0100g=cL0>c/k03lo?`0j>SX203Ti>@0403Ph>00g=cL0>c/k03Xj>P80?3`l00H0>CTi03Xj
>P0k>c/0@d=30410@00n?Sh203Ph>00D03Ti>@0g=cL0>CTi03Lg=`0j>SX0=CDe03Xj>P0k>c/0?Cdm
03Ti>@0g=cL0>3Ph03Hf=P0g=cL0>CTi03`l?00h>3P0>c/k03dm?@0k>c/203Xj>P80>CTi01L0@410
06e]K@2_[jl0_kno09fMW@2VYZH0[Jf]08R8R01@D500@T9203Ph>00j>SX0?Cdm03Ti>@0k>c/0>CTi
03Xj>P0i>CT0=cLg03Ti>@0f=SH0>3Ph03Lg=`0203/k>`80=CDe0P0j>SX0200f=SH0>3Ph03/k>`0k
>c/0>CTi051@D026QXH0[jn_0P3Cdm<04`3AdM40][Jf096AT@1WIfL0AdM70492@P1:BTX0T92@0<K6
aP3IfMT0gMgM0>?Sh`3<c<`0^KVi09>CT`1dM7@0Fe]K04A4A00k>c/03Oooool0013ooooo00D0CTi>
04m?C`1ADE40D51@04i>CP0204a<C00C04i>CP1?Cdl0EUIF05IFEP1EEED0E5AD079bLP2EUID0U9BD
09JFUP2GUiL0LW9b059BDP1@D500C4a<04Q8B016ATH0BTY:04M7A`0204Y:BP80BDU900D0BTY:04a<
C01>CTh0BDU904Q8B00204I6AP0404M7A`1:BTX0E5AD04U9B@<0ADE500/0A4A404E5A@12@T80C4a<
04Q8B012@T80A4A404=3@`18B4P0@T9204A4A0030451@@@0?Shn00D0?clo0451@@10@400@41003/k
>`0204=3@`0?04I6AP10@400?Cdm03hn?P0o?cl0A4A403lo?`0l?3`0>c/k0410@012@T80?Shn03`l
?00m?Cd0>3Ph00<0>c/k00D0?clo03hn?P0i>CT0>3Ph03Ti>@0203/k>`80?3`l00<0?Cdm03Ti>@0j
>SX00`0k>c/00`12@T80>SXj03/k>`020451@@0503hn?P0j>SX0@41003Xj>P0k>c/00P0l?3`02P0n
?Sh0>c/k03/k>`0k>c/0>SXj03`l?00n?Sh0?Cdm03`l?00n?Sh203Xj>P070410@00l?3`0>c/k03Ti
>@0m?Cd0>SXj03/k>`0203Lg=`0;03Ti>@0e=CD0=cLg03Ti>@0l?3`0>3Ph03/k>`0j>SX0>3Ph03De
=@0h>3P00`0j>SX00`0i>CT0>SXj0492@P0203lo?`0703dm?@0j>SX0>c/k03`l?00m?Cd0?clo0410
@00203/k>`80>SXj00H0>c/k03Hf=P0j>SX0>c/k04=3@`12@T8303`l?00303Xj>P0h>3P0>c/k0080
?Cdm0P0n?Sh04P0l?3`0>SXj03/k>`13@d<0?clo0410@00o?cl0@T9203dm?@0k>c/0?Cdm0410@00o
?cl0>3Ph03dm?@0o?cl0?3`l0410@080?clo0`0j>SX01@0o?cl0?3`l03dm?@0i>CT0=cLg0080?Cdm
00P0?clo0410@012@T80@T9203hn?P19BDT0@d=30492@P80C4a<00L0@41003lo?`10@400?clo03hn
?P0k>c/0@D510080?3`l00T0?Cdm03lo?`0n?Sh0?Shn04=3@`1CDe<0D51@05=CD`1EEED00P1BDU80
3P1?Cdl0ATI604A4A01>CTh0EEEE05eMG@1VIVH0G5aL04a<C012@T80?Cdm04U9B@16ATH0Cdm?0P12
@T803@1HF5P0Cdm?04i>CP1>CTh0GEeM07=cL`29RHT0QXJ607QhN01YJFT0DE5A04A4A013@d<00P10
@4002015ADD0?Shn03dm?@0n?Sh0?clo04Y:BP1=CDd0DU9B0P1>CTh0>012@T80?Shn0410@014A4@0
CTi>05ADE01IFET0HF5Q06a/K028R8P0];Bd0<[:bP34a<@0Z:RX08B4Q02@T900UiNG09ZJVP2HV9P0
R8R80820P023Ph<0UiNG0;Zj^P3:b/X0c/k>0=oOg`3QhN40fm_K0=7Ad@33`l<0aLG50;fm_@2b/[80
U9BD0820P02MWId0UiNG09:BTP2MWId0][Jf0;Ng]`2/[:`0`L710;jn_P2_[jl0YZJV08^;R`1UIFD0
F5QH03Lg=`0l?3`0?clo03Ph>00j>SX0>CTi0P0k>c/00`1GEeL0@41003Ti>@0203Ph>080>c/k00@0
?Cdm03`l?00j>SX0>c/k0P0l?3`203Ti>@0M03Ph>00i>CT0>c/k03dm?@0k>c/0>SXj03`l?00o?cl0
@4100451@@0o?cl0>c/k03`l?00m?Cd0?3`l03Lg=`0f=SH0=cLg03Ti>@0j>SX0?clo04A4A00n?Sh0
>CTi05=CD`1TI6@0C4a<03Xj>P0o?cl00`0h>3P203Hf=P0703Xj>P0f=SH0=SHf03`l?013@d<0>3Ph
03Xj>P0203/k>`0603dm?@0j>SX0>SXj03dm?@11@D40>SXj0P0i>CT03@0f=SH0=cLg03Ti>@0j>SX0
DU9B08b<S02l_;`0^k^k0:f][@34a<@0TI6A061PH00o?cl00`0i>CT0100g=cL0?3`l03Ti>@0h>3P2
03Lg=`0903Xj>P0g=cL0>CTi03Hf=P0h>3P0=SHf03Lg=`0h>3P0=cLg0080>CTi01h0>3Ph03Ti>@0j
>SX0?3`l05QHF02BTY80c<c<0=SHf035aLD0/;2`08>3P`1MGEd0ATI603hn?P0o?cl0EEEE07QhN02P
X:00c<c<0<o?c`32`/80Zj^[07UiN@1JFUX0D51@04I6AP0m?Cd0?3`l03Ph>00k>c/=ooooo`004?oo
ool0=`1EEED0FEUI05eMG@1QHF40IVIV06m_K`2@T900X:2P0:BTY02VYZH0/k>c0<;2`P2h^;P0W9bL
08J6QP1hN7P0M7Ad0861P@26QXH0I6AT051@D01>CTh0DU9B05YJFP1PH600Fe]K05mOG`1QHF40LG5a
0:2PX02ZZZX0ZJVY0;6a/@2TY:@0XZ:R0:6QX@2OWil0XZ:R092@T028R8P0KFe]04U9B@16ATH0EEEE
05mOG`1EEED0DU9B061PH01BDU80K6a/07inOP20P800RXZ:09^KV`23Ph<00P1TI6@01P19BDT0@D51
03hn?P0o?cl0@41004A4A080?clo0P0n?Sh02013@d<0?clo0410@00o?cl0@4100451@@0l?3`0?Shn
0P0l?3`01P0n?Sh0?Cdm03/k>`0n?Sh0@D5103lo?`80?Shn00D0>c/k03lo?`0o?cl0?clo03hn?P02
03lo?`0603hn?P0m?Cd0?3`l03dm?@0l?3`0>SXj0`0i>CT203`l?080>c/k00@0?3`l03Xj>P0k>c/0
>3Ph0P0j>SX03@0k>c/0>SXj03hn?P0o?cl0?Cdm03`l?00m?Cd0@41003dm?@0l?3`0>c/k03`l?00m
?Cd00P0l?3`04`0m?Cd0?3`l03dm?@0n?Sh0@41003Ti>@0g=cL0>CTi03`l?00m?Cd0>CTi03lo?`0m
?Cd0>3Ph03Lg=`0j>SX0>3Ph03Lg=`0e=CD00P0i>CT203Ph>00603Ti>@0j>SX0>c/k03Hf=P0j>SX0
>CTi0P0k>c/0100j>SX0?Cdm03`l?00j>SX203dm?@0803Lg=`0i>CT0>c/k03Xj>P0h>3P0?clo04=3
@`0n?Sh203/k>`0903dm?@0l?3`0>c/k03`l?00o?cl0?Cdm0410@014A4@0?Cdm0080>SXj00P0>c/k
03`l?00k>c/0=SHf03Ti>@0j>SX0?Shn03`l?080AdM700<0>CTi03dm?@0n?Sh00`0n?Sh0100m?Cd0
>c/k03`l?00h>3P203Ti>@0603/k>`0h>3P0>3Ph03lo?`0i>CT0?3`l1@0k>c/00`0i>CT0>c/k03/k
>`0203hn?P80?clo0180?Cdm03`l?00n?Sh0ATI60492@P0n?Sh0A4A404E5A@1=CDd0F5QH06MWI`1_
Kfl0Jf][06a/K01JFUX0B4Q803dm?@0o?cl303hn?P0I03Xj>P0m?Cd0?Cdm03hn?P0m?Cd0>c/k03lo
?`10@400?Cdm0451@@17AdL0@T920410@00l?3`0?clo03hn?P0m?Cd0>c/k03hn?P12@T80?Cdm03`l
?00n?Sh0@D5103/k>`0204M7A`0a04E5A@0n?Sh0@41004=3@`15ADD0C4a<05IFEP1KFe/0HF5Q06m_
K`1eMGD0Ti>C0:NWY`2NWYh0UIFE0:>SX`2YZJT0WIfM09FEU@2LW9`0UIFE08R8R02<S8`0NWYj07If
MP2=SHd0WIfM0:VYZ@35aLD0eMGE0=3@d038b<P0^k^k0:n_[`2a/K40]kNg0<c<c03Jf]X0g]kN0=oO
g`3Shn<0g=cL0=7Ad@3Bd]80fMWI0<W9b@2h^;P0][Jf0<;2`P020;bl_0060<o?c`3Ph>00j>SX0=oO
g`2d];@0HV9R0P1CDe<01P1gMgL0GemO05EEE@12@T80?Cdm03lo?`<0>SXj00<0AdM703dm?@0k>c/0
0P0k>c/00`0h>3P0>CTi03Ti>@0303Ti>@0603Ph>00j>SX0>c/k03Xj>P0h>3P0>c/k0P0i>CT09`0k
>c/0>SXj03Xj>P0l?3`0?Shn03lo?`14A4@0?clo03Lg=`0i>CT0>SXj03dm?@0k>c/0?Cdm03`l?00j
>SX0>3Ph03Lg=`0m?Cd0B4Q805=CD`1@D500>3Ph03Xj>P0g=cL0>3Ph03`l?00j>SX0=cLg03Hf=P0j
>SX0=SHf03De=@0d=3@0>c/k0451@@0k>c/0?clo03dm?@0203Xj>P0F03Lg=`0c<c<0=3@d03Xj>P0f
=SH0ADE505IFEP1TI6@0CTi>07moO`2d];@0Xj>S08B4Q01aLG40MGEe05]KF`0n?Sh0?Cdm03Xj>P0i
>CT0?Cdm03/k>`80>3Ph02d0>CTi03Lg=`0g=cL0=cLg03Ph>00g=cL0>CTi03De=@0d=3@0>3Ph03@d
=00f=SH0>3Ph03Xj>P1:BTX0DU9B06m_K`21PH40YZJV0<71`@2n_[h0Ti>C06ATI014A4@0@D5103lo
?`19BDT0CDe=05eMG@20P800ZZZZ0;:b/P2d];@0UiNG06i^KP1OGel0CTi>03lo?`0k>c/0?3`l03hn
?P0m?Cd0>c/k03Ph>00l?3`03Oooool0013ooooo00X0/[:b0<?3``3=cLd0f=SH0=GEe@38b<P0[Jf]
092@T024Q8@0QXJ60P2;Rh/0;`2IVIT0Xj>S0:n_[`2QXJ40WYjN0::RXP2EUID0Shn?09jNWP2^[Zh0
][Jf0<k>cP3=cLd0`L710;Ng]`2k^k/0_kno0;2`/02KVi/0W9bL0;:b/P3Cdm<0gMgM0=cLg03Bd]80
e]KF0<G5a@2PX:00MgMg051@D01?Cdl0J6QX07AdM01YJFT0GEeM05MGE`1LG5`0H61P06ATI01XJ6P0
HV9R07IfMP23Ph<0QHF507moO`1IFET0BTY:0080?clo00T0@d=30492@P0n?Sh0?clo03hn?P10@400
>c/k0410@012@T800`10@400200n?Sh0@41003/k>`0g=cL0?Shn0410@00o?cl0?Cdm0P0l?3`01016
ATH0>SXj03Xj>P0n?Sh303dm?@0R03hn?P11@D40?clo03lo?`0n?Sh0?Cdm03`l?00o?cl0>c/k03Ti
>@0j>SX0>3Ph03Xj>P0k>c/0>SXj03Ph>00j>SX0?Shn03Ti>@0h>3P0?Cdm0451@@0o?cl0?Cdm03hn
?P0k>c/0>SXj03/k>`0o?cl0?3`l03dm?@0i>CT0>3Ph03Xj>P80>c/k00/0>SXj03/k>`0k>c/0>CTi
03Lg=`0f=SH0>CTi03Ph>00m?Cd0>c/k03Lg=`0203Ph>00A03Lg=`0j>SX0>3Ph03Ph>00g=cL0>3Ph
03dm?@0k>c/0=cLg03/k>`0m?Cd0>SXj03Ph>00i>CT0>SXj03Ti>@0g=cL00P0j>SX01P10@400?Cdm
03Ph>00h>3P0>CTi03Hf=P80>c/k0`0i>CT01P0l?3`0>c/k03Xj>P0j>SX0>CTi03Xj>P<0?3`l00<0
>CTi03Ph>00k>c/00P0l?3`0;@0h>3P0>CTi03dm?@0j>SX0=SHf03Ph>00j>SX0?Cdm03`l?00o?cl0
A4A403Xj>P0h>3P0>c/k03dm?@0k>c/0>SXj03dm?@0i>CT0>SXj03dm?@0i>CT0>3Ph03Ti>@0l?3`0
?Shn03`l?00h>3P0?Shn0451@@0k>c/0@41003`l?00j>SX0?Shn03Ph>00o?cl0@D5103dm?@0l?3`0
@D5104e=C@1DE5@0ADE50410@00203Xj>P0303lo?`13@d<0ATI60080CDe=00D0C4a<04Q8B014A4@0
?clo0451@@0203dm?@1=03hn?P0l?3`0>CTi03Xj>P0l?3`0>3Ph03`l?011@D40FEUI06][J`2BTY80
VIVI09ZJVP2PX:00VYZJ08N7Q`25QHD0P82007YjNP1TI6@0CTi>03dm?@0n?Sh0C4a<05ADE01EEED0
JFUY07UiN@2;Rh/0S8b<09RHV02RXZ80VIVI09^KV`2HV9P0U9BD09fMW@2EUID0WIfM09^KV`2IVIT0
Vi^K09FEU@1mOGd0H61P05YJFP1GEeL0DE5A05mOG`1]KFd0PH610:2PX02][Jd0YZJV09ZJVP2WYjL0
^[Zj0<g=c@3Bd]80c<c<0=7Ad@3<c<`0_kno0:b/[02NWYh0VIVI08V9R@2<S8`0TY:B09ZJVP2m_Kd0
bl_;0=7Ad@2f][H0^KVi0=3@d03Jf]X00P3=cLd03P3GemL0f][J0=;BdP2k^k/0/K6a0:>SX`2d];@0
U9BD04m?C`0l?3`0@D51059BDP29RHT0Jf][0P1;Bd/0301<C4`0?Shn03dm?@0n?Sh0@T9203lo?`0k
>c/0?3`l03Ti>@0k>c/0>SXj03Ti>@80>SXj01T0>3Ph03/k>`0j>SX0>c/k03Xj>P0h>3P0>CTi03`l
?00j>SX0>c/k03`l?00m?Cd0>SXj03Ti>@0j>SX0?Cdm03Ph>00k>c/0?3`l03/k>`0l?3`0>c/k03`l
?00k>c/0?3`l0080>SXj0`0i>CT03`0k>c/0?3`l03dm?@0i>CT0?Shn03/k>`0g=cL0>3Ph03Xj>P0i
>CT0=cLg03Xj>P0d=3@0=cLg03De=@0203Hf=P0L03/k>`0l?3`0>3Ph03Lg=`0j>SX0GemO08F5Q@2P
X:00ZJVY09NGU`1UIFD0Ti>C08b<S01QHF40B4Q804];B`12@T80>CTi03Ph>00l?3`0>SXj03Ph>00i
>CT0>c/k03Xj>P0h>3P0>c/k03Ph>080=cLg01h0=3@d03Ti>@0e=CD0=CDe03Hf=P0e=CD0B4Q805eM
G@1jNWX0WinO0<O7a`3:b/X0][Jf0::RXP2EUID0JFUY04];B`0k>c/0?Shn05YJFP2IVIT0/[:b0:^[
Z`2MWId0VYZJ08j>SP1bLW80JVYZ05]KF`1>CTh203/k>`0903Lg=`0h>3P0>c/k03/k>`0i>CT0?3`l
03/k>`0i>CT0?Cdm00gooooo000@ooooo`0J0:NWY`2d];@0clo?0=;BdP3Cdm<0cLg=0<30`02`/;00
Zj^[0:f][@2^[Zh0[Jf]0;2`/02_[jl0/k>c0:^[Z`2UYJD0]KFe0<C4a03>c/h0`/;20<g=c@3Hf=P0
dM7A0;^k^`31`L420<_;b`050=;BdP3Hf=P0g]kN0=_Kf`3IfMT00P3Hf=P03`3Lg=`0fm_K0;Zj^P22
PX80KFe]05=CD`1=CDd0C4a<04i>CP19BDT0AdM704I6AP1>CTh0EeMG05eMG@0205ADE00<04E5A@16
ATH0ADE504M7A`15ADD0@D5104E5A@0o?cl0?Shn04E5A@14A4@0DE5A0P1@D5001`1SHf<0EUIF04E5
A@0o?cl0ADE503lo?`10@4000P0o?cl02P10@400?Shn03/k>`11@D40ADE503Ti>@0l?3`0?clo03/k
>`0n?Sh203/k>`<0?3`l00T0?Shn03lo?`0n?Sh0?Cdm03`l?010@400?clo03Xj>P0m?Cd00P0i>CT0
3@0n?Sh0>c/k03Ti>@0k>c/0>CTi03dm?@0j>SX0>3Ph03/k>`0i>CT0>SXj03hn?P0k>c/00`0m?Cd0
1P0j>SX0?Cdm03/k>`0l?3`0>c/k03dm?@<0>SXj00<0=cLg03Ti>@0k>c/00P0k>c/203Ph>00F03`l
?00g=cL0?3`l03Xj>P0g=cL0>SXj03`l?00h>3P0>SXj03dm?@0j>SX0=cLg03Ti>@0j>SX0?Cdm03Xj
>P0i>CT0?3`l03Ph>00j>SX0=cLg03Xj>P80>c/k0P0h>3P00`0i>CT0>3Ph03Ti>@0403Ti>@0903Xj
>P0f=SH0>3Ph03Lg=`0h>3P0>c/k03hn?P0g=cL0>CTi00<0>3Ph00<0=cLg03Ph>00j>SX00P0k>c/0
3@0h>3P0>CTi03Ti>@0k>c/0>3Ph03Ti>@0k>c/0>SXj03/k>`0l?3`0@41003dm?@0n?Sh00P0m?Cd0
4`10@400?Cdm03`l?00l?3`0>SXj03Ph>010@400?Shn03`l?00j>SX0>3Ph03Xj>P0n?Sh0>c/k03Xj
>P0i>CT0?3`l03Ph>00i>CT00P0l?3`01`0i>CT0?clo0451@@16ATH0@D5104=3@`10@4000P11@D42
055AD@0H0492@P0n?Sh0>3Ph03/k>`0j>SX0@T9203lo?`0k>c/0>CTi03`l?00k>c/0@d=30451@@14
A4@0?Cdm04U9B@1:BTX0ADE504U9B@1OGel0IfMW05MGE`1OGel0FUYJ0P1FEUH05@1BDU80C4a<04Y:
BP14A4@0ATI604E5A@0k>c/0?3`l04I6AP1XJ6P0PH6108B4Q02SXj<0b/[:0=CDe02m_Kd0WYjN08B4
Q01[Jf/0DE5A04i>CP0204E5A@0C0492@P17AdL0DU9B06a/K01jNWX0SXj>09NGU`2KVi/0R8R809^K
V`2a/K40];Bd0:FUY@2ATI40SHf=09:BTP2HV9P0Rh^;07YjNP0207MgM`0W075aL@1]KFd0HF5Q05EE
E@18B4P0ATI60492@P14A4@0CTi>05ADE01ADE40HF5Q06MWI`1cLg<0MWIf071`L01/K6`0LW9b08R8
R02TY:@0a/K60<_;b`3@d=00][Jf09NGU`2MWId0QXJ607AdM02:RXX0IVIV0820P02[Zj/0`/;20<K6
aP3Bd]80alO70:6QX@1dM7@0@4100080?Cdm00@0?Shn03dm?@0k>c/0>c/k0P0l?3`01@0h>3P0?Cdm
03Ph>00j>SX0BTY:0080>c/k00D0>SXj03dm?@0i>CT0>c/k03Lg=`0303Ti>@0>03Xj>P0g=cL0=cLg
03Ti>@0l?3`0>CTi03Xj>P0m?Cd0>SXj03Lg=`0k>c/0?Cdm03Ph>00j>SX203`l?00;03Ph>00i>CT0
>SXj03Ti>@0k>c/0CDe=0492@P0m?Cd0>CTi03Hf=P0h>3P00P0g=cL203Ph>00F03@d=00i>CT0=cLg
03De=@0d=3@0>3Ph03/k>`0j>SX0=cLg04Y:BP1aLG40KVi^05QHF01<C4`0AdM703dm?@15ADD0?3`l
03lo?`0h>3P0?clo03Ti>@80>SXj00D0>c/k03Ph>00i>CT0=cLg03De=@0303<c<`0/038b<P0e=CD0
>3Ph03Ti>@0h>3P0>c/k03Ph>01;Bd/0LG5a0;6a/@37alL0]KFe09FEU@1fMWH0GemO04Q8B013@d<0
?clo03Ph>00n?Sh0Fe]K0:FUY@3:b/X0^[Zj08^;R`1fMWH0JFUY05aLG013@d<0>SXj03Ti>@0j>SX0
>c/k03Lg=`0i>CT0>3Ph03Lg=`0h>3P0>CTi03Ph>00m?Cd0Bd];075aL@2NWYh=ooooo`004?ooool0
6@1?Cdl0FUYJ06=SH`1XJ6P0P820092@T01nOWh0Q8B408f=S@21PH40N7Qh07alO02GUiL0YjNW0:>S
X`2NWYh0VYZJ0:2PX02NWYh0^[Zj0=OGe`3De=@0eMGE0=[JfP3IfMT00P3Lg=`01`3MgMd0fm_K0=CD
e039bLT0aLG50;bl_02i^KT00P2m_Kd08@32`/80YjNW0820P01jNWX0JFUY05UIF@1RHV80IFEU06QX
J01UIFD0EeMG04m?C`1ADE40C4a<04I6AP1=CDd0A4A40410@015ADD0@d=304E5A@14A4@0DU9B04m?
C`1:BTX0Cdm?04e=C@18B4P0ADE504I6AP1:BTX0C4a<04e=C@0204=3@`030410@00n?Sh0@T920080
ADE500P0@d=304M7A`1<C4`0D51@04E5A@0m?Cd0?Shn03lo?`80?3`l00<0>CTi03dm?@10@4000P10
@40203dm?@0?03lo?`0n?Sh0?3`l03`l?00k>c/0>3Ph03hn?P0m?Cd0?Shn03`l?00k>c/0?3`l03dm
?@0i>CT0>c/k0080?3`l00H0?clo03dm?@0m?Cd0>CTi03/k>`0o?cl203`l?00703dm?@0k>c/0?Cdm
03dm?@0o?cl0?Cdm03/k>`0203Ti>@0703Xj>P0k>c/0?Cdm03hn?P0k>c/0?Cdm04];B`0203Ti>@80
>3Ph00T0>CTi03/k>`0n?Sh0?Cdm03/k>`0l?3`0?clo03dm?@0i>CT00`0k>c/303Xj>P0403dm?@0j
>SX0?Shn03Xj>P80>CTi0P0h>3P02`0j>SX0>c/k03Xj>P0h>3P0>CTi03Xj>P0g=cL0>CTi03Lg=`0j
>SX0>CTi0080>c/k00L0?3`l03Xj>P0h>3P0>c/k03hn?P10@400>SXj0080>c/k00X0?Cdm03/k>`0g
=cL0?Shn03/k>`0i>CT0>c/k03hn?P0k>c/0>SXj0P0k>c/02P0o?cl0>c/k03`l?010@400?clo0451
@@10@400?Shn03lo?`0l?3`203dm?@0403`l?00o?cl0>SXj03/k>`80>CTi00P0>c/k03hn?P0n?Sh0
@D5104a<C016ATH0?Shn03Ti>@80?Cdm00L0@4100492@P16ATH0CDe=04E5A@1=CDd0AdM70080?Shn
00X0?Cdm0410@016ATH0?Cdm03/k>`0h>3P0?3`l03lo?`12@T80AdM70P12@T803P0l?3`0@d=30451
@@0n?Sh0?3`l03dm?@13@d<0AdM7051@D010@400?Cdm03`l?00i>CT0>c/k0`0j>SX05P13@d<0B4Q8
05EEE@1OGel0J6QX07MgM`2=SHd0Y:BT09nOW`25QHD0CDe=04m?C`11@D40?Shn03lo?`12@T80CDe=
065QH@1gMgL0[Zj^0:n_[`2l_;`20;Bd]00909^KV`2PX:00TI6A0820P01LG5`0Cdm?04Q8B014A4@0
?clo0080@D510180@4100451@@0n?Sh0@41003lo?`10@400?Cdm04E5A@0n?Sh0ADE505EEE@1hN7P0
Z:RX0;^k^`39bLT0clo?0=3@d030`<020:ZZZP040;:b/P2`/;00YJFU092@T080Ogmo02L0RHV909^K
V`2j^[X0dm?C0;bl_01bLW80DE5A05EEE@1eMGD0QHF508b<S02PX:00_[jn0<g=c@2VYZH0QHF505IF
EP18B4P0>c/k03hn?P0l?3`0?Cdm03/k>`0m?Cd0>SXj03dm?@10@400BDU905mOG`1`L700Cdm?03`l
?011@D40?3`l03/k>`0n?Sh0>CTi03`l?00k>c/00P0i>CT00`0h>3P0>CTi03/k>`0203Xj>P80?3`l
00l0>SXj0492@P15ADD0>CTi03`l?00i>CT0>SXj03Ph>00i>CT0>c/k03Xj>P15ADD0@d=304e=C@0i
>CT00P0h>3P01`0j>SX0>3Ph03Lg=`0f=SH0=cLg03De=@0d=3@00`0f=SH03P0h>3P0>c/k03`l?00k
>c/0>3Ph03Hf=P0g=cL0>3Ph03Hf=P0i>CT0?3`l03Xj>P0g=cL0?Cdm0P1BDU80201>CTh0?clo03/k
>`0l?3`0>c/k03Lg=`0e=CD0>3Ph0P0g=cL03P0f=SH0>3Ph03/k>`0i>CT0=3@d03Hf=P0b<S80?clo
05YJFP2IVIT0QhN7075aL@1KFe/0B4Q80P0l?3`05`0f=SH0?Shn03hn?P19BDT0FUYJ09fMW@3?cll0
b/[:08Z:RP1ADE40A4A40410@00i>CT0=cLg03Xj>P0g=cL0>3Ph03De=@0h>3P0>c/k03Ti>@0h>3P0
=cLg0080>SXj00D0Bd];0861P@2k^k/0hN7Q0>KViP0=ooooo`004?ooool0:`1<C4`0CDe=04i>CP1=
CDd0C4a<04];B`1=CDd0Bd];04a<C01BDU80CTi>04e=C@1>CTh0Cdm?04i>CP1?Cdl0D51@05EEE@1C
De<0EUIF06=SH`1WIfL0MGEe092@T02MWId0YZJV0:ZZZP38b<P0e]KF0=WIf@36a/H0]kNg09jNWP1k
Ng/0VIVI0;Zj^P32`/80_[jn0<g=c@3Ng]h0dm?C0<_;b`3Bd]800P3>c/h02@2m_Kd0_kno0<C4a034
a<@0]kNg096AT@1GEeL0B4Q804M7A`0204I6AP0:04E5A@12@T80ATI604I6AP10@400ADE50410@012
@T80A4A404=3@`80@41001D0?clo04A4A01dM7@0S8b<08f=S@2DU9@0Xj>S0;Ng]`2m_Kd0_;bl0<W9
b@38b<P0YjNW06][J`1=CDd0?clo0492@P11@D40?Shn03`l?00j>SX0100m?Cd01`13@d<0?3`l03hn
?P0n?Sh0?3`l03Ti>@0k>c/00P0m?Cd0100j>SX0?Shn03`l?00n?Sh203`l?00<03Xj>P0o?cl0?3`l
03hn?P0l?3`0>3Ph03Xj>P0n?Sh0>3Ph03Xj>P0k>c/0>SXj0P0k>c/203Ti>@80>SXj00D0>CTi03/k
>`0l?3`0>c/k03Xj>P0203`l?00503hn?P0i>CT0>3Ph03Xj>P0k>c/00P0j>SX01`0k>c/0?3`l03dm
?@0k>c/0>CTi03Lg=`0i>CT00P0m?Cd05@0o?cl0@41003Xj>P0m?Cd0ADE503Ti>@11@D40>SXj03Ti
>@0j>SX0?Cdm03Lg=`0i>CT0?3`l03Ph>00j>SX0?Cdm03Ti>@0k>c/0=cLg03@d=00303Ti>@0703dm
?@0k>c/0>SXj03`l?00j>SX0=3@d03hn?P0203`l?00<03Xj>P0k>c/0?3`l03Xj>P0m?Cd0>c/k03Ti
>@0h>3P0?Cdm0451@@0k>c/0?3`l0P0o?cl03@0i>CT0>c/k03hn?P0l?3`0@41004=3@`0n?Sh0=cLg
03Xj>P0h>3P0>c/k03Xj>P0k>c/00P0m?Cd0E@0k>c/0>SXj03/k>`1;Bd/0C4a<0451@@0l?3`0@D51
0410@00l?3`0@41003hn?P12@T80?clo04A4A00m?Cd0>SXj03lo?`0k>c/0?3`l03hn?P0o?cl0?3`l
03dm?@0h>3P0=cLg03Ph>00j>SX0>CTi03`l?00k>c/0?Shn0451@@0l?3`0>c/k03hn?P15ADD0?3`l
04A4A00o?cl0BTY:04E5A@0m?Cd0?clo0410@012@T80?clo04A4A01KFe/0LW9b07UiN@1aLG40GUiN
051@D015ADD0BDU904e=C@13@d<0ATI605QHF01SHf<0HF5Q061PH01ZJVX0PX:20:JVYP2d];@0^k^k
0:NWY`2l_;`0`<3008^;R`1YJFT0FEUI04U9B@12@T80@41003hn?P12@T80?Shn03`l?00n?Sh0>CTi
03`l?011@D400P14A4@0;@12@T80C4a<059BDP1VIVH0Kfm_07QhN01_Kfl0Ogmo0;6a/@3De=@0i>CT
0=gMg@39bLT0`l?30;no_`2YZJT0Ogmo07=cL`1^KVh0UYJF09bLW02UYJD0W9bL0:n_[`30`<00d];B
0<_;b`3@d=00bLW90;2`/02?Shl0Jf][05YJFP1@D500Bd];04U9B@1ADE40Lg=c09BDU02b/[80b<S8
0<?3``1cLg<0ADE503`l?0020410@00>04Q8B01IFET0O7al07AdM01fMWH0Ph>308B4Q01hN7P0F5QH
04e=C@0n?Sh0>c/k0492@P13@d<203lo?`0<0410@011@D40?3`l03/k>`0j>SX0?Cdm05ADE01LG5`0
Bd];0410@016ATH0BTY:0P0n?Sh00`0l?3`0>c/k03Ti>@0203/k>`0;03`l?01<C4`0>c/k03/k>`0i
>CT0=cLg03Ti>@0k>c/0>SXj03Ti>@0g=cL00`0f=SH02P0g=cL0>CTi03Ph>00j>SX0=cLg03Ph>00f
=SH0=CDe038b<P0i>CT203De=@0603Lg=`0l?3`0=cLg03Ti>@0l?3`0@T920P0m?Cd09P0i>CT0=cLg
03Lg=`0j>SX0=SHf03De=@0f=SH0=cLg03Ph>00g=cL0=3@d03Ph>00g=cL0=3@d03Hf=P0j>SX0@T92
05ADE01:BTX0>CTi03Xj>P0i>CT0=cLg03Hf=P0n?Sh0Fe]K08J6QP2ZZZX0/;2`09RHV027QhL0OGem
05EEE@0n?Sh0>SXj03`l?00f=SH0>SXj0`0i>CT03P0b<S80>3Ph04I6AP1<C4`0D51@05MGE`16ATH0
B4Q805MGE`29RHT0]kNg0:FUY@2>SXh0RHV93Oooool0013ooooo00<0C4a<04];B`1<C4`00P1;Bd/0
201:BTX0B4Q804];B`19BDT0AdM704Y:BP1=CDd0C4a<0P1=CDd08@18B4P0CDe=04e=C@1;Bd/0D51@
05MGE`1TI6@0DE5A059BDP1DE5@0CDe=05ADE01SHf<0M7Ad0:>SX`2GUiL0JVYZ05UIF@1CDe<0E5AD
05QHF01MGEd0JVYZ079bLP20P800Shn?096AT@2UYJD0`L710=SHf03>c/h0Z:RX0<71`@020=oOg`06
0;jn_P2GUiL0Ogmo06QXJ01DE5@0BTY:0P15ADD204I6AP0M05QHF01YJFT0EeMG04a<C018B4P0Bd];
0451@@12@T80@D51075aL@2KVi/0Y:BT0;Bd]02h^;P0`<300<K6aP2h^;P0YZJV09:BTP25QHD0NWYj
07emO@1^KVh0MgMg08R8R01]KFd0AdM704E5A@0o?cl00P10@4002P15ADD0?3`l0451@@0k>c/0>CTi
03`l?00n?Sh0?Cdm0410@00n?Sh203dm?@0503Xj>P0i>CT0>CTi03`l?00j>SX00P0l?3`01`0g=cL0
>SXj03Xj>P0j>SX0?Cdm03lo?`0m?Cd00P0g=cL00`0l?3`0>SXj03/k>`0403/k>`0803Xj>P0l?3`0
>SXj03`l?00j>SX0@41003/k>`0l?3`203dm?@0303`l?00k>c/0?Cdm0080>CTi0`0k>c/00`0l?3`0
>c/k03Ti>@0203Xj>P80>CTi00P0=cLg03`l?00j>SX0>3Ph0410@00k>c/0>CTi03Lg=`80>SXj01/0
>c/k03Ph>00i>CT0=cLg03dm?@0l?3`0>c/k03dm?@0k>c/0>CTi03Xj>P0l?3`0>c/k03Xj>P0k>c/0
?Cdm03/k>`0o?cl0>c/k03dm?@0n?Sh0?Cdm03hn?P0h>3P0=cLg03Xj>P0h>3P00P0k>c/02P0l?3`0
?Cdm03/k>`0k>c/0?clo0492@P0i>CT0>3Ph03/k>`0i>CT203`l?00503Xj>P0f=SH0=cLg03Xj>P0o
?cl00P0n?Sh02`0m?Cd0?3`l0492@P0l?3`0>SXj03lo?`0h>3P0?Shn03dm?@10@400?clo0080?Shn
00l0?Cdm03/k>`0j>SX0>CTi03Ph>00j>SX0>CTi03Xj>P0k>c/0?3`l03lo?`14A4@0@d=30451@@0k
>c/00P0i>CT03@0n?Sh0@T9203lo?`11@D40?Shn03Ti>@0k>c/0?Cdm0451@@0m?Cd0>CTi03Xj>P12
@T800P0m?Cd02@1BDU80PX:207alO023Ph<0Ogmo07EeM@20P800O7al071`L00205ADE006055AD@17
AdL0B4Q805ADE01XJ6P0LG5a0P1fMWH0;@1aLG40Kfm_08>3P`2?Shl0PH6108j>SP26QXH0Ogmo07]k
N`1aLG40K6a/05IFEP14A4@0?Cdm0451@@0o?cl0@D5104E5A@16ATH0F5QH06UYJ@25QHD0Shn?08V9
R@1/K6`0NWYj0:b/[034a<@0e]KF0=3@d03=cLd0/K6a096AT@28R8P0Shn?092@T01mOGd0H61P05UI
F@1QHF40KVi^0820P01WIfL0Ph>30:6QX@020;bl_0180;Bd]02e]KD0/K6a0:FUY@2XZ:P0_;bl0<_;
b`3GemL0f=SH0=[JfP3GemL0b/[:0<G5a@30`<00]KFe0:RXZ02PX:00[Jf]0<o?c`3Fe]H0eMGE0:ZZ
ZP1nOWh0M7Ad08N7Q`2SXj<0bLW90=_Kf`3Hf=P0eMGE0<_;b`3AdM40fMWI0;Fe]@2=SHd0YZJV09RH
V02?Shl0ZJVY0:^[Z`2?Shl0H61P04a<C013@d<0?Cdm0410@012@T80MGEe07]kN`1PH600F5QH079b
LP1`L700OGem09RHV01QHF40>SXj03dm?@0k>c/0AdM70410@00j>SX0>3Ph03`l?00g=cL0>CTi03Xj
>P0h>3P0>CTi03Ph>00g=cL0>3Ph0`0g=cL0100i>CT0>SXj03/k>`0f=SH303Lg=`0503Hf=P0g=cL0
=cLg03Ph>00d=3@00P0e=CD0300f=SH0=cLg03Ph>00f=SH0>3Ph03Lg=`0e=CD0=3@d03Lg=`0h>3P0
>CTi03Lg=`<0=SHf02d0>3Ph03Ti>@0g=cL0>3Ph03Hf=P0h>3P0=cLg03Ti>@0f=SH0>SXj03/k>`0f
=SH0>CTi05iNGP2NWYh0aLG50:NWY`25QHD0F5QH03hn?P0j>SX0=cLg03De=@0g=cL0>c/k03Xj>P0f
=SH0>c/k04];B`1UIFD0LG5a05EEE@1bLW80TY:B08R8R01NGUh0EeMG06MWI`1MGEd0D51@05=CD`17
AdL0@T9204U9B@1`L7003Oooool0013ooooo00P0C4a<04];B`1=CDd0C4a<04];B`19BDT0AdM704Y:
BP80B4Q800l0Bd];04e=C@1<C4`0C4a<051@D01:BTX0C4a<04Y:BP1;Bd/0EEEE061PH01XJ6P0CTi>
051@D01CDe<00P1@D500?@1QHF40E5AD05MGE`1JFUX0F5QH06][J`1ZJVX0M7Ad07QhN01ZJVX0FUYJ
055AD@1<C4`0HV9R06UYJ@1ZJVX0KFe]08n?S`35aLD0X:2P09fMW@2i^KT0clo?0<c<c03IfMT0clo?
0=CDe03=cLd0];Bd09JFUP21PH40QXJ60;:b/P3EeMD0]KFe07inOP1iNGT0V9RH08n?S`1gMgL0H61P
05IFEP1LG5`0FEUI069RHP1nOWh0Jf][059BDP1:BTX0AdM704U9B@1<C4`0CDe=0451@@12@T80@D51
04U9B@1MGEd0E5AD04e=C@1KFe/00P1CDe<01`1ADE40G5aL06][J`1HF5P0CTi>04A4A012@T800P0k
>c/00`0l?3`0?Cdm03/k>`0203`l?00B03Ti>@0l?3`0>SXj03`l?00h>3P0>SXj03/k>`11@D40?clo
03/k>`10@400?3`l03lo?`0l?3`0>c/k03`l?00k>c/0?3`l0P0n?Sh0200o?cl0?Shn03dm?@0j>SX0
>CTi03Xj>P0l?3`0?Shn0P0i>CT02@0k>c/0?Cdm03/k>`0k>c/0?Shn03Xj>P0i>CT0>c/k03dm?@02
03`l?00303/k>`0j>SX0?3`l0080>c/k00P0>3Ph03Ti>@0k>c/0>CTi03dm?@0k>c/0>3Ph03Ti>@<0
?3`l00<0?Cdm03Ti>@15ADD00P0m?Cd203/k>`0=0410@00n?Sh0?3`l03/k>`0m?Cd0>CTi03Lg=`0k
>c/0>SXj03Ti>@0l?3`0>SXj03Ti>@0203Xj>P0403dm?@0j>SX0>CTi03/k>`80?3`l01`0?Cdm03hn
?P0m?Cd0?Shn03`l?00n?Sh0@D5103hn?P0j>SX0?Cdm03Ti>@0k>c/0?Cdm03`l?00i>CT0?3`l03dm
?@0j>SX0?3`l03hn?P0k>c/0>CTi03/k>`11@D40?Shn03`l?00k>c/0>CTi0P0g=cL01010@400>c/k
03/k>`0n?Sh203lo?`80>SXj00/0?Cdm03`l?00k>c/0?3`l0492@P1:BTX0AdM70451@@0o?cl0@T92
0410@00203/k>`0:03`l?00m?Cd0@41003/k>`0h>3P0=cLg03/k>`0l?3`0@41003`l?080>SXj00l0
CDe=05=CD`1UIFD0OGem07AdM020P800Kfm_06ATI01LG5`0BTY:04A4A019BDT0?clo0410@00l?3`0
0P0o?cl01`12@T80@D510410@011@D40?Cdm04A4A011@D400P10@4000`15ADD0?Shn03dm?@020451
@@0Y0492@P1?Cdl0H61P05YJFP1IFET0EeMG04m?C`1IFET0IfMW08Z:RP2>SXh0O7al08^;R`2MWId0
W9bL0;Bd]03<c<`0gMgM0>?Sh`3Jf]X0b/[:09^KV`21PH40UIFE0:j^[P2GUiL0WYjN07AdM01cLg<0
IfMW065QH@1[Jf/0G5aL06e]K@1nOWh0LW9b05IFEP1<C4`0DE5A06=SH`1mOGd00P2DU9@0@02LW9`0
T92@0820P01oOgl0QXJ609jNWP2c/k<0_[jn0;bl_02m_Kd0alO70<S8b02j^[X0_;bl0=3@d03IfMT0
g]kN0<O7a`2PX:00XJ6Q0;Zj^P3Cdm<0eMGE0=[JfP3YjNT0iNGU0=kNgP3Hf=P0f][J0>3Ph03Jf]X0
eMGE0=_Kf`3MgMd0bLW90;Vi^@2RXZ80OGem05EEE@10@400?Cdm04A4A01hN7P0S8b<0;2`/03Fe]H0
hN7Q0=KFeP2RXZ80MWIf061PH01VIVH0Bd];03lo?`0j>SX0>CTi03Hf=P0k>c/0>SXj03Ph>00j>SX0
>CTi03Xj>P0i>CT203Ph>00703Ti>@0k>c/0>SXj03Lg=`0d=3@0=cLg03De=@0303Lg=`80>3Ph00D0
>c/k03Ti>@0e=CD0>3Ph03Xj>P0203Lg=`0603Ti>@0g=cL0=cLg03Hf=P0e=CD0=3@d0P0f=SH00`0i
>CT0@4100410@00203`l?00D03/k>`0j>SX0=SHf03Lg=`0h>3P0=SHf03Lg=`0j>SX0>3Ph03/k>`0g
=cL0@D5108N7Q`2o_kl0YJFU06IVIP0m?Cd0>SXj03Ti>@0h>3P203Hf=P0?03De=@0g=cL0>CTi03dm
?@12@T80@41003hn?P1;Bd/0EEEE05=CD`1[Jf/0JFUY059BDP0l?3`0A4A40080?3`l00H0>SXj04A4
A01FEUH0Ogmo0:f][@3:b/X=ooooo`004?ooool01`1;Bd/0BTY:04a<C01:BTX0B4Q804U9B@17AdL0
0P18B4P0101>CTh0Cdm?04e=C@1=CDd204a<C00404m?C`1<C4`0BTY:04Y:BP80Bd];00D0B4Q804M7
A`18B4P0Bd];05EEE@0204Y:BP0D04Q8B01:BTX0ATI604a<C01FEUH0IFEU07QhN02=SHd0T92@07If
MP1gMgL0PH6109VIV@2i^KT0_Kfm0<G5a@3;bl/0_[jn09>CT`1^KVh206UYJ@0C07AdM01kNg/0UIFE
0;Zj^P38b<P0a<C40=CDe03GemL0f=SH0=[JfP3<c<`0]kNg0:JVYP2CTi<0Kfm_05eMG@1<C4`0A4A4
04M7A`0204=3@`0904Q8B013@d<0@T9204A4A012@T80@41004i>CP1BDU80Hf=S0080G5aL00T0KVi^
07MgM`1/K6`0EEEE051@D01=CDd0@d=303lo?`14A4@00P1HF5P05P16ATH0@41003dm?@0k>c/0@410
03/k>`0m?Cd0>SXj03Ph>00k>c/0?clo03/k>`0m?Cd0?clo03Ti>@0m?Cd0>SXj03`l?00j>SX0?Cdm
0451@@0l?3`203Ti>@0=03/k>`0n?Sh0?Cdm03dm?@0j>SX0@41003dm?@0j>SX0?Cdm03lo?`0k>c/0
?3`l03/k>`0203hn?P0303lo?`0h>3P0>CTi0080?Cdm0P0n?Sh0100k>c/0>CTi03/k>`0o?cl203/k
>`0503Xj>P0i>CT0?Shn04Y:BP0k>c/00P0j>SX203/k>`0?03hn?P0m?Cd0?3`l03dm?@14A4@0?3`l
03Ti>@0m?Cd0@T9203Ph>00i>CT0?3`l03dm?@0k>c/0?Cdm0080@41000P0?3`l03/k>`0j>SX0>CTi
03/k>`0n?Sh0?clo03Ti>@80?Cdm00@0>CTi03Ph>00i>CT0?3`l0P0j>SX00`0n?Sh0@41003lo?`02
03hn?P0403`l?00k>c/0>c/k03`l?080>c/k0P0l?3`203Xj>P0403Ti>@0h>3P0?Shn03dm?@80>CTi
00H0?Shn03dm?@0n?Sh0>SXj03/k>`0j>SX203`l?00803hn?P0k>c/0ATI603Ti>@0k>c/0?3`l03Ti
>@0h>3P203/k>`0903`l?00m?Cd0?3`l03Xj>P0i>CT0?clo0451@@0l?3`0@4100080>c/k0`0m?Cd0
6@10@400?clo03dm?@0n?Sh0?clo03hn?P11@D40@41004=3@`10@400>c/k0410@018B4P0DU9B05=C
D`1EEED0C4a<04Y:BP19BDT0@T9203hn?P13@d<0?Shn03`l?00n?Sh00P0o?cl0100n?Sh0?Cdm03Xj
>P0m?Cd203lo?`0V03`l?014A4@0@T9204=3@`12@T80C4a<05EEE@1]KFd0QhN709BDU02@T900Shn?
08R8R02?Shl0UYJF08R8R01bLW80PH6108>3P`1eMGD0Ng]k09BDU02ZZZX0WYjN09ZJVP2BTY80VIVI
0::RXP2TY:@0/[:b0;jn_P3;bl/0a<C40:NWY`1iNGT0I6AT05UIF@15ADD20451@@0;03hn?P10@400
@41004A4A01;Bd/0EEEE06YZJP29RHT0Vi^K08b<S01[Jf/00P1DE5@04@1>CTh0FEUI06UYJ@29RHT0
Zj^[0;Jf]P2h^;P0^KVi0;^k^`2`/;00/K6a0<C4a03?cll0e=CD0=gMg@3De=@0`<300080/[:b00<0
[:b/0;bl_03AdM400P3IfMT01P3Lg=`0gmoO0=3@d02^[Zh0ZZZZ0<o?c`80f][J01@0fMWI0=KFeP3C
dm<0fm_K0=kNgP3QhN40cLg=0:NWY`2:RXX0/[:b0=kNgP3QhN40iNGU0<_;b`2DU9@0JVYZ05YJFP1D
E5@0BDU904E5A@80>SXj0P14A4@00`0l?3`0?Shn03/k>`0203Ti>@0303Xj>P0l?3`0>SXj00<0>CTi
0100?3`l03/k>`0k>c/0=cLg03Ti>@0h>3P0>CTi03Hf=P0g=cL0>CTi03Ph>00j>SX0GemO0451@@0i
>CT0>3Ph0P0f=SH00`0h>3P0>CTi03Ph>00203Lg=`0603Hf=P0l?3`0?Shn0451@@0l?3`0?clo0`0i
>CT0700g=cL0<c<c03Hf=P0h>3P0=cLg03Ti>@0h>3P0>SXj04];B`1iNGT0V9RH08J6QP1KFe/0?Cdm
03Ti>@0j>SX0>3Ph03Lg=`0h>3P0=SHf03Ph>00g=cL0>3Ph03Ti>@0j>SX0=cLg03@d=00e=CD203Lg
=`0>0410@00g=cL0?Cdm04Q8B01/K6`0VIVI0:NWY`1mOGd0Ng]k09nOW`2`/;00_[jn0:BTY01]KFd=
ooooo`004?ooool204a<C00504e=C@1;Bd/0Bd];04i>CP1;Bd/00P1:BTX0401@D500CTi>04Y:BP1:
BTX0BDU904];B`1?Cdl0Bd];04U9B@18B4P0C4a<04];B`15ADD0CDe=04Q8B019BDT204M7A`1704A4
A01;Bd/0ATI604Q8B01;Bd/0DU9B05EEE@1@D500ATI604Q8B017AdL0Bd];04a<C01=CDd0EeMG06=S
H`1YJFT0LW9b07MgM`25QHD0Ogmo06m_K`1LG5`0Cdm?04i>CP1@D500EUIF08N7Q`2l_;`0_Kfm0:f]
[@2NWYh0SHf=071`L01UIFD0GUiN069RHP1OGel0MgMg0861P@1eMGD0I6AT05]KF`1GEeL0GUiN061P
H01]KFd0HV9R05]KF`1GEeL0Cdm?04E5A@1=CDd0EUIF06UYJ@1lO7`0U9BD09>CT`2ATI40Ph>306EU
I@14A4@0?3`l03hn?P12@T80?Shn0451@@0o?cl0?Cdm03hn?P19BDT00P0m?Cd503`l?00303/k>`0n
?Sh0?Cdm0080>c/k01h0?Cdm03hn?P17AdL0AdM70410@014A4@0?Shn03/k>`0n?Sh0>c/k03hn?P0o
?cl0?3`l03/k>`0m?Cd0>CTi03Ph>00k>c/0?Cdm03`l?012@T80?clo03/k>`0j>SX0?clo03dm?@0n
?Sh0?3`l03/k>`0n?Sh303`l?00=03dm?@0l?3`0?3`l03/k>`1MGEd0IfMW03lo?`0l?3`0@41003dm
?@0k>c/0@41003Xj>P0203Ti>@0703Ph>00g=cL0=SHf03`l?010@400>CTi03dm?@0203Xj>P0703dm
?@0l?3`0?Shn03dm?@0l?3`0?clo03dm?@0203Ti>@0803lo?`0i>CT0?Cdm03Xj>P0k>c/0?Shn03lo
?`0n?Sh203Ti>@0703/k>`0l?3`0?clo0410@00o?cl0?Shn03Ti>@0303/k>`0I03dm?@0k>c/0?Shn
0451@@0l?3`0>CTi03Lg=`0j>SX0>CTi03lo?`10@400?Shn03lo?`0k>c/0>SXj03Lg=`0j>SX0=cLg
03Xj>P0g=cL0?Cdm03hn?P0k>c/0=CDe03Ti>@0203dm?@0403hn?P0m?Cd0>SXj03dm?@80>c/k00X0
?Cdm03hn?P0m?Cd0?3`l03/k>`0j>SX0>3Ph03`l?00m?Cd0>SXj0`0o?cl02P0m?Cd0@4100410@018
B4P0ATI603dm?@0o?cl0?3`l03Xj>P0i>CT20451@@80>SXj0P0l?3`303/k>`0303`l?00o?cl0?3`l
0080?Cdm00<0?3`l03/k>`0m?Cd00P0h>3P0?P0k>c/0?Cdm03Ph>013@d<0@T9203`l?01=CDd0MGEe
08Z:RP2;Rh/0Ph>308V9R@2ATI40WinO0;:b/P2a/K40Ph>306a/K01^KVh0IfMW075aL@2@T900YZJV
0:b/[02OWil0NGUi069RHP1NGUh0Hf=S06i^KP1RHV80GEeM061PH01[Jf/0GemO04=3@`11@D40?3`l
0492@P0o?cl0?Cdm04=3@`0n?Sh0EEEE06QXJ01bLW80HV9R06ATI01kNg/0RXZ:09NGU`2RXZ80[Zj^
0;Ng]`2l_;`0`l?30<_;b`3Fe]H0dm?C0;^k^`2WYjL0UIFE0P1oOgl04@22PX80Shn?0:JVYP2d];@0
/k>c0;jn_P37alL0^[Zj0;6a/@2_[jl0^;Rh0;jn_P3Bd]80b<S80;Ng]`2n_[h0a/K60080cLg=02d0
e]KF0=SHf03>c/h0bl_;0=SHf03EeMD0dM7A0=CDe03AdM40`/;20<S8b03?cll0d];B0=[JfP3Ti>@0
hN7Q0=[JfP3Cdm<0e]KF0<71`@2:RXX0O7al08>3P`1gMgL0K6a/07IfMP2CTi<0WYjN08:2PP1WIfL0
IFEU079bLP1XJ6P0Bd];03/k>`0j>SX0>3Ph03Lg=`0j>SX0?Cdm03Ti>@0j>SX0>3Ph03`l?00j>SX0
0P0g=cL0600h>3P0>SXj03dm?@1FEUH0GUiN03De=@0j>SX0>3Ph03Xj>P0g=cL0>CTi03Lg=`0i>CT0
=cLg03Ph>00k>c/0?clo03Xj>P0i>CT0>3Ph03Ti>@0e=CD0>SXj03/k>`80=SHf0P0g=cL02@0h>3P0
?Shn05EEE@1fMWH0/k>c092@T01IFET0>c/k03dm?@0303Hf=P0303De=@0g=cL0=CDe0080=CDe0P0g
=cL0100h>3P0>c/k03Ph>00d=3@203De=@0?03Ti>@0e=CD0@T9207QhN030`<00][Jf09VIV@1aLG40
FEUI075aL@2<S8`0Jf][051@D012@T80CDe=00gooooo000@ooooo`0:04e=C@1<C4`0BTY:04e=C@1<
C4`0Bd];04a<C01=CDd0B4Q804a<C080CTi>0P19BDT204a<C00704M7A`1:BTX0B4Q804Y:BP19BDT0
CDe=04a<C00404M7A`0Q04];B`1=CDd0Bd];04I6AP1<C4`0BTY:04];B`1<C4`0BDU904a<C01;Bd/0
BDU904=3@`16ATH0BDU904E5A@12@T80ATI604A4A01:BTX0AdM704a<C01@D500GEeM06MWI`1XJ6P0
GemO061PH01NGUh0FUYJ05=CD`1;Bd/0H61P0080Ogmo01H0P82006i^KP1CDe<0GUiN08F5Q@2RXZ80
[Jf]0;2`/02SXj<0XJ6Q0;^k^`3Cdm<0aLG50;fm_@2e]KD0^[Zj0;6a/@2^[Zh0ZZZZ09RHV01XJ6P0
A4A40P12@T804`0o?cl0ADE50410@00o?cl0@T9203`l?013@d<0@T9203`l?00n?Sh0?Cdm0410@013
@d<0@T9203hn?P10@400?clo03hn?P0o?cl00`0n?Sh03@12@T80FUYJ07MgM`2GUiL0Kfm_04];B`0l
?3`0@41003lo?`0m?Cd0?3`l03hn?P10@4000P0m?Cd03@0k>c/0@D5106IVIP1KFe/0ADE50410@00l
?3`0>3Ph03Ti>@0l?3`0?Cdm03`l?00j>SX00P0l?3`03@0h>3P0?Shn04A4A010@400?Shn03dm?@0l
?3`0@D5103Ti>@1gMgL0JFUY04];B`0m?Cd00P0k>c/203lo?`0303hn?P12@T80?Cdm0080>c/k01<0
>SXj03/k>`0g=cL0>SXj03`l?00i>CT0?Cdm03`l?00m?Cd0>SXj03/k>`0n?Sh0?Cdm03/k>`0l?3`0
?Cdm03lo?`0k>c/0?3`l0080>SXj0P0l?3`01@0m?Cd0>c/k03hn?P0k>c/0?Shn00<0@D5100H0@T92
03Ti>@0k>c/0?3`l03hn?P0j>SX203`l?00:03lo?`0k>c/0?Cdm03dm?@0o?cl0>c/k03Xj>P0m?Cd0
?3`l03/k>`80?3`l00L0=SHf03lo?`0l?3`0?Shn03Xj>P0o?cl0?Cdm0080>SXj00@0?Cdm03`l?00l
?3`0?Shn0P0o?cl0200g=cL0>c/k03/k>`0j>SX0?3`l03Ph>00i>CT0?3`l0P0j>SX01@0o?cl0>SXj
03dm?@0k>c/0?Cdm0080@41001D0@d=303lo?`0o?cl0@T920451@@0j>SX0>c/k0492@P0h>3P0ATI6
03hn?P11@D40@T920410@00n?Sh0@41003Lg=`0j>SX0>CTi03`l?00k>c/00P0m?Cd04P0l?3`0>c/k
03/k>`0j>SX0>c/k03dm?@0j>SX0?3`l03/k>`0g=cL0?clo05aLG01gMgL0FUYJ05EEE@1BDU80F5QH
05iNGP80GemO00H0Fe]K059BDP18B4P0@d=304I6AP1EEED207AdM00j06IVIP1QHF40EEEE04=3@`14
A4@0?3`l03lo?`0n?Sh0>SXj03lo?`10@400ADE503Ti>@0m?Cd0?clo03hn?P0k>c/0?clo04=3@`1:
BTX0DE5A05IFEP1EEED0J6QX08R8R02YZJT0][Jf09nOW`2IVIT0Vi^K09VIV@2?Shl0UYJF092@T01n
OWh0NWYj08b<S02KVi/0VIVI08b<S02OWil0a/K60=KFeP3Cdm<0clo?0<W9b@37alL0a<C40;jn_P2m
_Kd0cLg=0=oOg`3Shn<0j^[Z0>WYj@3Rh^80g]kN0=_Kf`80hN7Q02H0h^;R0=3@d03<c<`0c<c<0=CD
e03GemL0eMGE0=;BdP3<c<`0`L710<;2`P3:b/X0a/K60<30`02PX:00[:b/0<[:bP3>c/h0d=3@0=7A
d@31`L40]kNg09fMW@1DE5@0@D5104E5A@1GEeL0JFUY08:2PP2`/;00XZ:R0820P01ZJVX0B4Q803hn
?P0m?Cd0>CTi03Lg=`80>CTi00l0>c/k03`l?00k>c/0>3Ph03Ti>@0g=cL0>3Ph03Xj>P11@D40B4Q8
04Y:BP0l?3`0>SXj03Hf=P0h>3P00P0i>CT203/k>`0703`l?00g=cL0@D5104I6AP0i>CT0=CDe03Lg
=`0303Hf=P0E03De=@0f=SH0>CTi03dm?@12@T80Fe]K07QhN01oOgl0P82006UYJ@1RHV80@T9203Lg
=`0f=SH0>SXj03Lg=`0k>c/0@41006e]K@1aLG40?3`l0080=cLg00P0>3Ph0451@@0k>c/0=SHf03Lg
=`0h>3P0>CTi03Hf=P80>3Ph00d0@d=305eMG@1HF5P0ATI603`l?00i>CT0?Shn03/k>`0l?3`0@410
069RHP2OWil0];Bd00gooooo000@ooooo`80Bd];00@0B4Q804Y:BP1<C4`0AdM70P19BDT03018B4P0
BTY:04U9B@16ATH0C4a<04Y:BP16ATH0BTY:04E5A@19BDT0Bd];04Q8B080BTY:00@0BDU904M7A`14
A4@0ADE50P1=CDd00`1:BTX0ATI604A4A00204E5A@0A04Y:BP17AdL0@d=304E5A@14A4@0AdM704E5
A@17AdL0ADE50451@@13@d<0A4A404M7A`14A4@0@d=304Q8B01@D5000P1<C4`02@19BDT0B4Q8051@
D01SHf<0F5QH059BDP19BDT0@T9204E5A@0204i>CP80C4a<04L0AdM704Y:BP1BDU80EUIF05aLG01O
Gel0FEUI05QHF01SHf<0IFEU06e]K@22PX80]KFe0<g=c@3GemL0clo?0;Bd]02HV9P0RXZ:08^;R`25
QHD0LW9b06IVIP1FEUH0EEEE04Q8B012@T80@d=304i>CP1YJFT0LG5a06e]K@1QHF40GEeM04M7A`1A
DE40Cdm?05iNGP1ZJVX0M7Ad07emO@1lO7`0MGEe07=cL`21PH40RXZ:08F5Q@21PH40Ph>307YjNP1m
OGd0QXJ608N7Q`26QXH0P82008B4Q021PH40OWin06UYJ@1kNg/0YJFU0861P@1?Cdl0@d=303lo?`0m
?Cd0@D5103Xj>P0m?Cd0?3`l03dm?@0203hn?P80?3`l01D0@4100451@@0n?Sh0>3Ph03/k>`0l?3`0
?clo04E5A@1:BTX0>SXj03/k>`0m?Cd0>c/k03`l?00h>3P0?Cdm03Xj>P0m?Cd0>3Ph03`l?00i>CT0
0P0k>c/00`0l?3`0>c/k03Ti>@0203/k>`0503`l?00j>SX0>SXj03Xj>P0k>c/00P0n?Sh00`0k>c/0
?Cdm03/k>`0303dm?@0?0451@@18B4P0A4A403Xj>P11@D40>c/k03lo?`0m?Cd0@D510492@P10@400
@d=304M7A`10@400=cLg00<0>c/k00P0>SXj03hn?P0m?Cd0?3`l03/k>`0o?cl0?3`l03lo?`80?3`l
00/0>3Ph03Xj>P10@400?3`l03/k>`0j>SX0=CDe03`l?00n?Sh0?3`l03Lg=`0203`l?00<03dm?@0l
?3`0?Cdm03`l?00j>SX0>3Ph03/k>`0i>CT0?Shn03Ph>00n?Sh0?3`l0P0k>c/203Xj>P80?3`l01H0
>CTi0451@@11@D40@T920451@@0j>SX0?Shn0492@P0o?cl0?3`l03/k>`0j>SX0>3Ph03Ti>@0j>SX0
?3`l0451@@0m?Cd0=cLg03hn?P0j>SX0?3`l0P0m?Cd02P0l?3`0?Shn03/k>`0k>c/0?clo059BDP1;
Bd/0EEEE04E5A@0i>CT203Xj>P0403lo?`11@D40?Cdm03hn?P<0?Cdm01D0@D5103dm?@13@d<0ADE5
04i>CP1CDe<0EEEE04e=C@15ADD0A4A403dm?@0l?3`0>SXj0410@00j>SX0?Shn0451@@0k>c/0?3`l
03lo?`13@d<00P12@T80;@1:BTX0De=C05UIF@1UIFD0KFe]07inOP2MWId0W9bL0:ZZZP2[Zj/0VYZJ
09:BTP2ATI40Lg=c05MGE`1EEED0NWYj0:2PX02IVIT0[Jf]0<W9b@2n_[h0ZJVY096AT@1mOGd0KVi^
06EUI@1`L700[Zj^0=?Cd`3EeMD0`l?30:BTY02OWil0_;bl0<k>cP3@d=00emOG0>;RhP3Shn<0h^;R
0=cLg03Cdm<0aLG50;^k^`020;Fe]@0h0:j^[P2d];@0^;Rh0:JVYP2DU9@0UYJF09VIV@2VYZH0/[:b
0;Fe]@2_[jl0UiNG08:2PP2EUID0^;Rh0;Ng]`2][Jd0XJ6Q0;:b/P2c/k<0^KVi09RHV022PX80H61P
04e=C@19BDT0@d=304Q8B01KFe/0@T9204m?C`2=SHd0[jn_092@T01TI6@0?Shn03dm?@0k>c/0=cLg
03Xj>P0k>c/0?3`l05mOG`1BDU80D51@03hn?P0i>CT0?3`l03lo?`0m?Cd0>SXj03/k>`0o?cl0?3`l
03lo?`0l?3`203Ti>@0503Xj>P0k>c/0>c/k03lo?`0h>3P00P0j>SX0400k>c/0=SHf03Lg=`0h>3P0
=CDe03Ti>@0k>c/0CDe=08J6QP2PX:00Q8B405YJFP17AdL0>SXj03Ti>@0b<S8303Hf=P06038b<P0j
>SX0>c/k055AD@1`L700EeMG0P0e=CD01@13@d<0CTi>04];B`0g=cL0=SHf0080>3Ph0140=cLg03Hf
=P0e=CD0>CTi03Ph>00k>c/0=SHf03Xj>P0d=3@0=cLg03hn?P1IFET0OWin0:n_[`3De=@0c<c<08N7
Q`0=ooooo`004?ooool01P1:BTX0Bd];04a<C018B4P0BDU904Q8B080ATI601<0A4A404U9B@19BDT0
BTY:04A4A019BDT0Bd];04Q8B016ATH0AdM704];B`17AdL0BDU904M7A`19BDT0CDe=04a<C017AdL0
ATI60080B4Q800@0ATI604U9B@16ATH0A4A40P16ATH02@18B4P0ADE50492@P16ATH0@d=304A4A012
@T80A4A404M7A`0204A4A00304U9B@15ADD0AdM70080AdM701`0?clo04M7A`15ADD0De=C05YJFP1H
F5P0Fe]K059BDP16ATH0Cdm?05aLG01FEUH0Fe]K05ADE01JFUX0EEEE05MGE`1CDe<0EUIF05EEE@1@
D500Cdm?051@D01?Cdl0HF5Q051@D01FEUH0V9RH0P2c/k<08P33`l<0d=3@0=GEe@3GemL0h>3P0=7A
d@2`/;00UiNG09ZJVP2UYJD0Z:RX09VIV@2^[Zh0bl_;0=KFeP3AdM40d];B0<c<c02CTi<0];Bd0<S8
b02i^KT0/k>c0:b/[02o_kl0hn?S0=;BdP33`l<0aLG50<k>cP3Ph>00emOG0<?3``2_[jl20:b/[00M
09^KV`2:RXX0WIfM0=7Ad@3IfMT0bLW908j>SP1GEeL0A4A403lo?`0i>CT0@d=303Ti>@0n?Sh0ATI6
04A4A00k>c/0>SXj03lo?`0m?Cd0>c/k03hn?P0l?3`0>SXj03`l?00o?cl0?Shn04E5A@0m?Cd00`0l
?3`01P0n?Sh0>CTi03Ti>@0k>c/0?Shn03/k>`80>3Ph00<0?Shn03`l?00o?cl00`0i>CT00`0j>SX0
>c/k03/k>`0303/k>`0=03`l?00k>c/0>CTi03Ph>00l?3`0?clo03`l?00i>CT0>c/k03`l?00j>SX0
>c/k03Xj>P0203dm?@0<03`l?00n?Sh0>c/k03`l?00m?Cd0?Shn03dm?@0l?3`0ATI60492@P0l?3`0
>SXj0P0k>c/02@0l?3`0>3Ph03Xj>P0i>CT0>c/k03Xj>P0n?Sh0?Cdm03hn?P0203dm?@0903`l?00i
>CT0>SXj03dm?@0l?3`0>c/k03Ti>@0k>c/0>3Ph0080>SXj00X0>c/k03Ph>00k>c/0?clo03/k>`0i
>CT0@41003`l?00k>c/0>3Ph0P0k>c/04P0o?cl0?Shn03/k>`0j>SX0>CTi03`l?00k>c/0?Cdm03`l
?015ADD0@d=303hn?P0j>SX0>CTi03Xj>P0m?Cd0?clo03Ti>@<0>c/k00D0?Shn0492@P12@T80?Cdm
03`l?00203Xj>P80?Cdm00@0?3`l0410@013@d<0@D510P0n?Sh02@11@D40?3`l03hn?P0k>c/0>SXj
03hn?P0k>c/0>CTi03lo?`0204M7A`0:055AD@1DE5@0FEUI04M7A`15ADD0@T9204A4A016ATH0@D51
0410@080@D5100<0?3`l03hn?P10@4000P0k>c/203lo?`0d03/k>`0j>SX0?Shn04Q8B01IFET0Lg=c
08J6QP2JVYX0R8R806=SH`1VIVH0OGem0861P@1gMgL0Shn?096AT@2:RXX0NWYj07MgM`1jNWX0RHV9
09nOW`2KVi/0][Jf0<30`02_[jl0]KFe0<C4a02i^KT0ZJVY09VIV@2;Rh/0LW9b065QH@1ZJVX0KFe]
08J6QP2YZJT0^k^k0;Vi^@2YZJT0Y:BT0:j^[P30`<00[Jf]0;:b/P2f][H0WinO08F5Q@1eMGD0JFUY
05IFEP80BDU903P0E5AD05mOG`1oOgl0VIVI0:RXZ02^[Zh0[Jf]0:BTY02KVi/0[Jf]0<g=c@3De=@0
clo?0;Zj^P2o_kl0f][J0=kNgP3IfMT0aLG50;:b/P2_[jl0^k^k0<k>cP3AdM40_[jn0;2`/02[Zj/0
XZ:R08:2PP1nOWh0Rh^;0:j^[P3Bd]80aLG50;Zj^P2QXJ40KFe]04m?C`22PX80TI6A06][J`1NGUh0
KFe]08F5Q@2PX:00WYjN0410@00m?Cd0>c/k03Xj>P0m?Cd0@41004=3@`1^KVh0NWYj04M7A`80?Cdm
0P0i>CT01`0k>c/0>SXj03De=@0i>CT0>3Ph03Ti>@0g=cL00`0h>3P0200f=SH0BDU906e]K@1nOWh0
N7Qh055AD@0k>c/0=SHf0P0g=cL01P0h>3P0=3@d03Ti>@0h>3P0@D5103lo?`80>3Ph00P0=SHf03De
=@0g=cL0<c<c03Ti>@10@400>c/k03Ti>@80=3@d00@0=cLg03Ti>@0h>3P0=CDe0P0d=3@03@0f=SH0
=cLg03Ph>00h>3P0ADE504];B`1bLW80U9BD0<K6aP32`/80SHf=05UIF@0o?cl03Oooool0013ooooo
0P1:BTX01P1;Bd/0BTY:04U9B@17AdL0ATI604U9B@80AdM700/0B4Q804];B`17AdL0AdM704Q8B016
ATH0BDU904I6AP18B4P0ATI604A4A00204I6AP0G04U9B@18B4P0ATI604Q8B016ATH0@d=304I6AP14
A4@0B4Q804A4A015ADD0ATI604Q8B013@d<0@T920451@@10@400ATI60492@P14A4@0ADE504A4A013
@d<00`11@D401@13@d<0@D5104=3@`19BDT0B4Q80080ADE500H0@d=303lo?`12@T80Bd];0492@P13
@d<204A4A00303hn?P11@D40@d=30080@d=303H0Bd];069RHP1OGel0E5AD04Q8B00n?Sh0AdM704Y:
BP1;Bd/0EeMG05EEE@1NGUh0NGUi0861P@2:RXX0UiNG0::RXP2UYJD0[Zj^0;:b/P2BTY80LW9b055A
D@1@D500E5AD061PH02GUiL0YjNW0:f][@3AdM40f=SH0=[JfP3Lg=`0clo?0=SHf03Kfm/0h>3P0>?S
h`3QhN40fMWI0=gMg@3Ogml0emOG0=7Ad@31`L40YjNW09:BTP2DU9@0Vi^K09FEU@2VYZH0UIFE07=c
L`1EEED20451@@0603dm?@11@D40@41003lo?`11@D40@d=30P11@D402`0k>c/0?3`l03lo?`0l?3`0
?Shn03lo?`10@400@T9203dm?@13@d<0?Shn00<0>c/k00D0?clo03`l?00m?Cd0?Cdm03`l?0020451
@@0703/k>`0n?Sh0?Shn05aLG017AdL0?clo03dm?@0203/k>`0803Xj>P0k>c/0?Cdm03hn?P0k>c/0
?Cdm03hn?P0m?Cd203/k>`0903hn?P0m?Cd0@D5104=3@`14A4@0>CTi03Xj>P0l?3`0?Cdm0080@410
00H0?Shn03Xj>P0l?3`0>CTi0451@@10@40203Lg=`0>03lo?`0l?3`0>CTi03hn?P0j>SX0?clo03/k
>`15ADD0@T9203hn?P0k>c/0>3Ph03`l?00h>3P303Xj>P80?3`l01H0?Cdm03/k>`0i>CT0>SXj03hn
?P0j>SX0>3Ph03/k>`0l?3`0?Shn03Hf=P0h>3P0?clo03dm?@0k>c/0?Shn0492@P0o?cl0?Cdm03`l
?010@400?Cdm0P0l?3`02`0m?Cd0?Shn03Xj>P0l?3`0=SHf03Xj>P0h>3P0>c/k0451@@0j>SX0>3Ph
00<0=cLg00P0?Shn03`l?00m?Cd0>c/k03Lg=`0j>SX0?3`l03Xj>P80?Shn00T0?3`l03/k>`0n?Sh0
>SXj03`l?00n?Sh0>SXj03Ti>@0h>3P00P0i>CT05@0k>c/0>SXj03lo?`0n?Sh0?Cdm03lo?`14A4@0
Bd];04e=C@15ADD0@D5103`l?00o?cl0@D510410@017AdL0A4A403dm?@0o?cl0?3`l03lo?`0203hn
?P0C0492@P0o?cl0?3`l03hn?P14A4@0Bd];05QHF01fMWH0OWin09RHV02VYZH0/[:b0:>SX`24Q8@0
L71`06e]K@25QHD0PX:205MGE`02051@D00G05ADE025QHD0SXj>07QhN021PH40UYJF09BDU024Q8@0
J6QX05QHF01OGel0FUYJ04m?C`18B4P0EeMG0861P@2BTY80Vi^K09>CT`1gMgL0KFe]05UIF@1<C4`0
0P1;Bd/09`1@D500HF5Q05eMG@1JFUX0GUiN06YZJP1`L700LG5a07IfMP1gMgL0K6a/06UYJ@1SHf<0
JVYZ07moO`1iNGT0Rh^;09jNWP35aLD0emOG0=3@d03:b/X0dm?C0=CDe03GemL0fMWI0=kNgP3Kfm/0
g]kN0=oOg`3Ti>@0i^KV0>CTi03UiND0i^KV0=kNgP3Bd]80bLW90<K6aP020<o?c`0V0;jn_P30`<00
aLG50;6a/@2SXj<0YJFU0;Bd]03:b/X0bLW90;^k^`3Hf=P0h^;R0>3Ph03Ng]h0b/[:0:ZZZP2UYJD0
]kNg0:>SX`2OWil0U9BD092@T02WYjL0/[:b0:2PX01mOGd0HV9R0410@00k>c/0?Shn03Ti>@0l?3`0
>3Ph03Xj>P0i>CT0>SXj03Lg=`0f=SH203Xj>P0O03`l?00j>SX0ADE505ADE018B4P0@41003Xj>P0f
=SH0>c/k03De=@12@T80?3`l03Lg=`0f=SH0@D5104A4A015ADD0>c/k03Hf=P0e=CD0=cLg03Ph>00f
=SH0=cLg03De=@0f=SH0=3@d03Lg=`0h>3P0>c/k03@d=00203Hf=P0=038b<P0i>CT0=3@d05ADE01J
FUX0?clo03dm?@1@D500NWYj09FEU@2=SHd0IfMW04Y:BP0203`l?00303/k>ooooooooooo00_ooooo
000@ooooo`0=04];B`1<C4`0BTY:04];B`1:BTX0AdM704E5A@17AdL0ATI604U9B@17AdL0ATI604A4
A00204E5A@0G04I6AP1;Bd/0Bd];04I6AP13@d<0A4A404U9B@18B4P0BDU904A4A017AdL0ADE50451
@@13@d<0AdM70492@P14A4@0AdM704I6AP12@T80A4A40492@P0o?cl00P11@D401@15ADD0@T9204=3
@`13@d<0A4A40080AdM700/0@T9204E5A@1>CTh0@d=304E5A@1:BTX0Bd];04=3@`1;Bd/0BTY:04A4
A0020451@@0A04E5A@14A4@0@D510410@00m?Cd0@d=304E5A@11@D40ATI605EEE@1KFe/0CDe=04A4
A010@400@T9204=3@`12@T800`15ADD09P1>CTh0GEeM05MGE`1/K6`0J6QX061PH01OGel0Jf][0861
P@2<S8`0QHF506][J`1NGUh0K6a/065QH@1UIFD0V9RH0:RXZ02MWId0XJ6Q0<G5a@3Jf]X0bLW90<S8
b02ZZZX0V9RH08n?S`2=SHd0Rh^;0:2PX02l_;`0`l?30;jn_P2l_;`0[jn_09fMW@2HV9P0YZJV0P2M
WId0501iNGT0B4Q803/k>`10@400@T9204U9B@1>CTh0DE5A03`l?00m?Cd0?clo0492@P0h>3P0?3`l
0410@00o?cl0>c/k03lo?`10@400?clo0P0k>c/203lo?`040410@011@D40@T920410@0<0?Shn00d0
>SXj03dm?@0o?cl0?3`l04Y:BP1;Bd/0MWIf05QHF00n?Sh0>CTi0492@P0g=cL0>SXj0080?Shn00H0
?Cdm03`l?00m?Cd0>c/k03`l?00n?Sh203/k>`<0?3`l00D0>SXj03dm?@0o?cl0?clo0451@@0303`l
?00303Ph>00k>c/0?Cdm0080?clo00`0?Shn03dm?@0o?cl0@41003hn?P0m?Cd0>CTi03`l?00m?Cd0
?Shn03dm?@10@40203Ph>00803/k>`0h>3P0>CTi03Ph>00i>CT0?clo03/k>`0o?cl203Xj>P80>c/k
00H0?clo03Ti>@0k>c/0>c/k03Xj>P0l?3`20451@@0>03`l?00k>c/0?Cdm0492@P10@400>c/k03hn
?P12@T80>c/k0451@@0n?Sh0>SXj03lo?`0h>3P203dm?@050410@00l?3`0>c/k03lo?`0j>SX00P0k
>c/03@0j>SX0?Cdm03Ph>00g=cL0>CTi03hn?P0j>SX0>3Ph03Ti>@0j>SX0>CTi03/k>`0m?Cd00P0j
>SX203hn?P0603dm?@0j>SX0?3`l03`l?014A4@0?3`l0P0o?cl03010@400>CTi03Ti>@0k>c/0?Shn
03dm?@0n?Sh0?3`l0410@00n?Sh0>CTi03`l?080>SXj00H0>CTi03Xj>P15ADD0CTi>05=CD`1?Cdl2
04M7A`0I04e=C@1;Bd/0CDe=04m?C`16ATH0CTi>05eMG@2:RXX0YJFU08f=S@1iNGT0G5aL05EEE@1I
FET0NWYj08n?S`1hN7P0KFe]08b<S029RHT0MWIf069RHP1OGel0FEUI04I6AP020451@@0603lo?`0n
?Sh0A4A405ADE01PH600J6QX0P1ZJVX0G01/K6`0GUiN05ADE017AdL0@D5104=3@`0n?Sh0?clo04E5
A@1KFe/0KVi^07AdM01`L700M7Ad0861P@24Q8@0MgMg07EeM@2@T900][Jf0<[:bP3;bl/0^[Zj0;6a
/@2j^[X0bLW90=SHf03?cll0];Bd096AT@23Ph<0S8b<09ZJVP2TY:@0[jn_0<O7a`3GemL0f][J0>7Q
h@3Ph>00i>CT0=oOg`3Ph>00gmoO0=KFeP3=cLd0^k^k09bLW028R8P0S8b<08J6QP2EUID0XJ6Q0:VY
Z@2n_[h0`l?30<71`@2a/K40VYZJ09BDU02;Rh/0UYJF0:VYZ@33`l<0emOG0<K6aP2`/;00X:2P0:^[
Z`2d];@0c/k>0=3@d03AdM40f=SH0<W9b@3:b/X0c<c<0<K6aP2EUID0De=C03hn?P10@400?3`l03/k
>`0m?Cd0>c/k03Xj>P0o?cl0?3`l03Xj>P0i>CT0?3`l0P0j>SX02@0k>c/0?Shn03Lg=`0i>CT0@D51
05MGE`1RHV80FUYJ0451@@0203Ti>@0903Lg=`0j>SX0=cLg03De=@0h>3P0<c<c03Hf=P0g=cL0=SHf
0080=CDe01P0=3@d03Lg=`0d=3@0=SHf03De=@0c<c<0=cLg03@d=00j>SX0>CTi055AD@1_Kfl0GUiN
03dm?@17AdL0V9RH0<C4a02YZJT0E5AD03Ti>@10@400>CTi03Hf=P1>CTh=ooooo`004?ooool0201<
C4`0BTY:04U9B@18B4P0BDU904M7A`15ADD0A4A40P16ATH01P15ADD0@d=304Q8B016ATH0ADE504I6
AP80BDU900d0AdM704E5A@15ADD0B4Q804M7A`18B4P0@d=304Q8B014A4@0BDU904];B`17AdL0A4A4
0080ATI600T0ADE50492@P15ADD0@41004=3@`18B4P0@41004e=C@14A4@00`15ADD02014A4@0ATI6
0492@P12@T80A4A404=3@`17AdL0@T920P0o?cl04012@T80A4A403lo?`12@T80@D5103hn?P11@D40
?Cdm0451@@10@400?clo0492@P1<C4`0BDU904a<C016ATH204=3@`1<0492@P0n?Sh0@41004E5A@11
@D40?Cdm04A4A010@400A4A40451@@14A4@0?Shn0410@011@D40CDe=04I6AP1;Bd/0BDU904Y:BP17
AdL0ADE50451@@14A4@0ADE505=CD`1FEUH0J6QX09JFUP2l_;`0`l?30<[:bP36a/H0]KFe0;Rh^02c
/k<0TI6A07UiN@1gMgL0Ti>C07]kN`1UIFD0GUiN06YZJP1hN7P0Ogmo09JFUP2YZJT0][Jf0:6QX@20
P800TY:B09bLW021PH40E5AD04=3@`0j>SX0?Cdm0451@@17AdL0>c/k03dm?@0l?3`0@D5103dm?@0l
?3`0ADE504A4A019BDT0CDe=05MGE`1HF5P0EeMG0451@@0o?cl0?Shn03dm?@80?Shn0140?Cdm03`l
?018B4P0BTY:055AD@1=CDd0FEUI06UYJ@1UIFD0FEUI04i>CP0l?3`0>c/k03`l?00j>SX0?Cdm03hn
?P0203dm?@<0?3`l0`0k>c/0200o?cl0?3`l03dm?@0l?3`0?Cdm03Xj>P0l?3`0?clo0`0k>c/02P0o
?cl0@41004=3@`11@D40@4100492@P10@400?Cdm03hn?P10@40203dm?@0903Xj>P0n?Sh0>SXj03/k
>`0i>CT0>c/k03lo?`0l?3`0>SXj0080?Shn0280>CTi03Ph>00k>c/0>CTi03`l?010@400@T9203Xj
>P0l?3`0>SXj03hn?P0m?Cd0@41004=3@`0m?Cd0?Shn0492@P0o?cl0>c/k03Ti>@10@400A4A403Ti
>@0n?Sh0?3`l03Ph>00j>SX0=CDe03Ti>@0j>SX0?Cdm03lo?`0l?3`0?Cdm0P0j>SX00`0i>CT0>3Ph
03Lg=`0203/k>`0603Lg=`0j>SX0>SXj03`l?00k>c/0=cLg0P0j>SX02P0k>c/0>CTi03hn?P0j>SX0
>c/k03hn?P0i>CT0?3`l0410@00n?Sh303/k>`0E03Xj>P0k>c/0>c/k03Xj>P0k>c/0>SXj03`l?010
@400?Cdm03hn?P0k>c/0@T9203/k>`0o?cl0>SXj03hn?P17AdL0?Shn03Ph>00j>SX0?3`l0080?clo
00`0@T9203`l?018B4P0IFEU05mOG`1]KFd0OWin07IfMP1`L700JFUY05EEE@1>CTh205=CD`0904e=
C@1OGel0QHF509ZJVP2>SXh0Jf][04Q8B010@400?3`l0080?Cdm02<0>c/k04A4A01KFe/0K6a/069R
HP1QHF40H61P04e=C@0o?cl0?Shn0410@00o?cl0AdM704];B`1<C4`0@T920451@@0n?Sh0Cdm?05mO
G`1_Kfl0TY:B0;>c/`2n_[h0`l?30:JVYP2BTY80Vi^K08n?S`1jNWX0OWin08Z:RP28R8P0V9RH0:ZZ
ZP020;fm_@0C0:ZZZP2VYZH0/K6a0<;2`P2b/[80XJ6Q09bLW02OWil0VIVI0:VYZ@2[Zj/0ZJVY0:JV
YP2IVIT0RHV9079bLP1]KFd0Kfm_07QhN00206i^KP0C07EeM@2?Shl0]KFe0<O7a`3?cll0dm?C0=WI
f@3Kfm/0eMGE0=7Ad@3>c/h0bLW90<G5a@2j^[X0a/K60=OGe`3IfMT0cLg=0:NWY`0209fMW@0D0<71
`@3Hf=P0gMgM0=KFeP39bLT0cLg=0;Fe]@2JVYX0U9BD0:f][@2m_Kd0UYJF0861P@2GUiL0OWin05=C
D`1JFUX0Kfm_05MGE`0o?cl203hn?P0=0451@@1MGEd0MGEe04m?C`0h>3P0@T9208B4Q02/[:`0MWIf
05]KF`0n?Sh0>3Ph03Hf=P0203Ti>@0303Lg=`0h>3P0=cLg0080>SXj00D0>3Ph03Lg=`0f=SH0=3@d
03De=@0203Lg=`0E03Ti>@0k>c/0>c/k03Ph>012@T80@D5103Ti>@0n?Sh0=CDe05=CD`1gMgL0LG5a
09RHV01RHV80?Shn03Ph>00j>SX0>c/k03Ph>00i>CT0Cdm?00gooooo000@ooooo`0404Y:BP18B4P0
BDU904Q8B080BDU900P0AdM704I6AP18B4P0ATI604M7A`15ADD0ATI604E5A@80ATI61014A4@01@16
ATH0B4Q804E5A@1:BTX0AdM70080ADE500@0ATI604Y:BP14A4@0A4A40P12@T802@17AdL0ADE504Q8
B019BDT0ADE504A4A012@T80ADE504M7A`0204Q8B00:04U9B@1>CTh0ATI60451@@12@T80D51@04=3
@`0m?Cd0@D510410@080@T9200@0@D5103lo?`10@400?clo0`0n?Sh20451@@0;03lo?`14A4@0ADE5
04=3@`16ATH0AdM703lo?`0n?Sh0@41004=3@`0o?cl00P0m?Cd02P0l?3`0@T9203/k>`0o?cl0A4A4
03lo?`13@d<0BDU904Y:BP17AdL203`l?00Z03lo?`11@D40@D510410@00m?Cd0?clo0451@@19BDT0
AdM704a<C01:BTX0CDe=05EEE@1RHV80Jf][07IfMP1jNWX0OWin08n?S`2LW9`0ZJVY0<S8b030`<00
Z:RX09:BTP2TY:@0_;bl0<[:bP3Hf=P0fm_K0=WIf@3Bd]80]KFe0;Rh^02g]kL0YZJV08R8R01?Cdl0
?Cdm03Ti>@11@D40A4A40P10@400;01ADE40GEeM06][J`22PX80ZZZZ0;2`/02_[jl0XJ6Q09ZJVP2K
Vi/0QXJ604];B`12@T80@D5104e=C@1VIVH0J6QX07=cL`2<S8`0/;2`0;^k^`2g]kL0[Jf]0::RXP2o
_kl0S8b<04U9B@10@400?3`l03hn?P11@D40@T9203dm?@0l?3`0?Cdm03/k>`0l?3`0?Cdm03`l?00i
>CT0?Cdm0410@00m?Cd0?Shn0P11@D401`10@400>c/k03dm?@0n?Sh0>c/k0451@@0j>SX00P0o?cl0
2011@D40ATI604=3@`0o?cl0?Cdm03hn?P12@T80?clo0P0i>CT00`0l?3`0?clo0410@00203hn?P0;
03lo?`0m?Cd0>c/k03dm?@0k>c/0>CTi03`l?00k>c/0>CTi03dm?@0o?cl0100n?Sh01`0l?3`0ADE5
04A4A00o?cl0>CTi03/k>`0m?Cd00P0j>SX06P0k>c/0?3`l03/k>`0l?3`0>CTi03`l?00m?Cd0?Shn
03dm?@0n?Sh0?Cdm03Xj>P0m?Cd0?Shn03/k>`0o?cl0@41003hn?P0j>SX0>CTi03Lg=`0k>c/0>SXj
03Lg=`0k>c/0?3`l0P0j>SX203`l?00B03Xj>P0k>c/0>SXj03hn?P0l?3`0>c/k03Xj>P0f=SH0>c/k
0451@@0k>c/0?clo03dm?@0k>c/0@41003dm?@0l?3`0>3Ph0P0g=cL0<P0j>SX0>3Ph03`l?00l?3`0
>c/k03lo?`0m?Cd0?clo03dm?@10@400@d=303Xj>P0k>c/0@D5103`l?00i>CT0?clo04A4A01?Cdl0
MGEe06YZJP1NGUh0GEeM04m?C`14A4@0@41003/k>`0n?Sh0@T9204M7A`1HF5P0PH6107alO01TI6@0
Fe]K04i>CP0k>c/0?clo0410@00m?Cd0@41004=3@`11@D40CDe=05MGE`1ADE40?Shn03Ph>00o?cl0
@D510P0n?Sh08@1EEED0OGem08F5Q@1eMGD0H61P05mOG`1RHV80De=C07]kN`2/[:`0_;bl0<?3``2/
[:`0R8R806e]K@1UIFD0H61P07QhN02;Rh/0X:2P0;Bd]02c/k<0WIfM08V9R@1gMgL0MWIf069RHP1G
EeL0Cdm?059BDP1CDe<0Bd];04A4A00304E5A@80A4A400l0DE5A05]KF`1LG5`0H61P07YjNP2GUiL0
]KFe0<k>cP3Bd]80dM7A0=;BdP3De=@0bl_;0;Ng]`2SXj<00P2ATI403@22PX80M7Ad07moO`1gMgL0
N7Qh08:2PP2KVi/0[jn_0<g=c@3Ph>00g=cL0=SHf03Lg=`00P3IfMT0?`3Cdm<0fMWI0=KFeP3;bl/0
dM7A0<C4a033`l<0d=3@0=gMg@3Ti>@0gMgM0=GEe@3Kfm/0dM7A0;Ng]`2k^k/0aLG50:JVYP2:RXX0
Rh^;0;6a/@2k^k/0Rh^;04e=C@14A4@0D51@05]KF`1nOWh0H61P03lo?`0l?3`0=cLg03Ph>00e=CD0
<c<c0410@01gMgL0JVYZ04e=C@0i>CT0>SXj03Ph>00g=cL0>CTi03Xj>P0i>CT0=cLg03/k>`0g=cL0
>CTi03/k>`0h>3P0?Cdm04A4A01KFe/0?3`l0410@013@d<0ATI603Lg=`0h>3P0>CTi03Lg=`0203Hf
=P<0>CTi00<0=CDeooooooooool02oooool0013ooooo1019BDT03@16ATH0AdM704U9B@15ADD0A4A4
04U9B@1;Bd/0B4Q804A4A015ADD0B4Q804];B`18B4P00P19BDT02@1:BTX0ADE504E5A@16ATH0AdM7
04I6AP13@d<0BTY:04E5A@0204I6AP0404Q8B015ADD0BTY:04M7A`80@d=300P0B4Q804U9B@12@T80
@d=304E5A@13@d<0A4A404=3@`80A4A400D0ATI604E5A@12@T80@d=304M7A`0204=3@`80@D5100<0
?clo04=3@`0o?cl00P0o?cl03`10@400A4A40451@@10@400@D5103hn?P17AdL0BDU904=3@`0m?Cd0
@d=303hn?P13@d<0BTY:04Q8B00203hn?P0803lo?`0k>c/0>SXj04E5A@1CDe<0CDe=04a<C012@T82
03lo?`0C0410@00m?Cd0>SXj03lo?`10@400ADE504I6AP0m?Cd0>c/k0451@@1;Bd/0C4a<04E5A@1<
C4`0BTY:04A4A017AdL0?clo04A4A00204=3@`0d04a<C01MGEd0HV9R06MWI`1NGUh0De=C04];B`1U
IFD0[Jf]0<30`03=cLd0e=CD0=KFeP2PX:00J6QX04m?C`1=CDd0De=C05ADE01PH600GUiN05]KF`1T
I6@0IVIV06UYJ@2?Shl0][Jf09bLW02[Zj/0_Kfm0=cLg03IfMT0cLg=0:6QX@1iNGT0KFe]05YJFP1`
L700O7al09ZJVP35aLD0h>3P0=?Cd`3IfMT0g]kN0=KFeP2f][H0SHf=06IVIP1CDe<0CTi>03lo?`80
?Cdm00<0@T920410@00l?3`00`0l?3`01@10@400?Shn03Xj>P0m?Cd0@4100080@D510200@d=304A4
A013@d<0C4a<05EEE@1CDe<0AdM705QHF01WIfL0MgMg08N7Q`1^KVh0DE5A0492@P15ADD0@D5103/k
>`0l?3`0@D5104=3@`0n?Sh0?clo0492@P18B4P0ADE503`l?011@D40BDU90451@@10@400@D510410
@080>c/k00X0?clo03Xj>P0m?Cd0>3Ph03/k>`0n?Sh0@41003Xj>P0o?cl0@4100P11@D401012@T80
?clo03/k>`0k>c/203dm?@0>03Ti>@0g=cL0>CTi03Ti>@0k>c/0>SXj03`l?00m?Cd0?3`l03/k>`0m
?Cd0>c/k03hn?P10@40203`l?00303dm?@12@T80?Shn0080>CTi00T0?Shn0451@@0m?Cd0>SXj03lo
?`0l?3`0?clo03dm?@0l?3`00P0n?Sh02P0o?cl0?3`l03dm?@0k>c/0>SXj03hn?P0l?3`0?clo03`l
?00j>SX203dm?@0903`l?014A4@0@41003`l?00j>SX0>3Ph03Ti>@10@400?3`l0080>c/k00T0?Cdm
03Xj>P0j>SX0>3Ph03lo?`0m?Cd0?3`l03/k>`0j>SX00P0o?cl01@13@d<0CDe=04U9B@1:BTX0B4Q8
0080?clo0200?Cdm03`l?00i>CT0>SXj04a<C01OGel0Kfm_065QH@1LG5`0FEUI04U9B@12@T80@D51
03hn?P0m?Cd0@41003dm?@0n?Sh0?Cdm03Xj>P0m?Cd0>SXj03Hf=P0k>c/0?clo0451@@1ADE40EUIF
05QHF01RHV80De=C06][J`80MWIf00`0QHF509fMW@1kNg/0Lg=c08J6QP2>SXh0Ng]k071`L01hN7P0
O7al0861P@25QHD208B4Q00<07IfMP1/K6`0EUIF04a<C012@T80?clo03`l?00m?Cd0@D5103hn?P11
@D40@4100P14A4@0201RHV80Rh^;09nOW`2YZJT0[jn_0;>c/`38b<P0aLG50P2f][H05P2b/[80];Bd
0:>SX`2;Rh/0M7Ad06][J`1UIFD0I6AT079bLP20P800QHF509NGU`2/[:`0^[Zj0<[:bP3Cdm<0a/K6
0<;2`P2o_kl0^k^k0;Bd]033`l<20=3@d080eMGE0P3Bd]802P3MgMd0hN7Q0=_Kf`3<c<`0a/K60;Fe
]@2[Zj/0`/;20=7Ad@3IfMT30>;RhP0T0=;BdP2ZZZX0^[Zj0=KFeP3Ng]h0g=cL0=KFeP3Ng]h0c/k>
0;Jf]P2TY:@0QHF508J6QP1gMgL0NWYj07IfMP1/K6`0F5QH04=3@`0j>SX0>3Ph03Ti>@0n?Sh0Kfm_
04Y:BP0l?3`0>3Ph03Hf=P0h>3P0@d=304];B`16ATH0>c/k03dm?@0i>CT0>SXj0P0h>3P0200g=cL0
>SXj059BDP16ATH0?3`l03Lg=`0h>3P0=3@d0P0g=cL0200b<S80>3Ph03Lg=`0i>CT0=cLg03Ph>00f
=SH0>3Ph3Oooool0013ooooo00T0Cdm?04e=C@1<C4`0CDe=04Q8B01;Bd/0ATI6059BDP1KFe/00P17
AdL01@13@d<0B4Q804Y:BP1:BTX0CDe=0080ATI600/0B4Q804];B`14A4@0@T9204A4A013@d<0ADE5
04Q8B017AdL0B4Q804U9B@0204M7A`0404E5A@1:BTX0ADE504M7A`80@T9200@0A4A404I6AP12@T80
@T920P14A4@00`10@400@T9204=3@`0204=3@`0804I6AP0o?cl0AdM704E5A@13@d<0@D5104I6AP10
@4020451@@0M03lo?`13@d<0@T9204E5A@11@D40?clo0451@@14A4@0B4Q804U9B@13@d<0?3`l0451
@@0m?Cd0@d=30451@@0m?Cd0?clo0451@@13@d<0?clo04I6AP1@D500De=C04A4A016ATH0@d=30492
@P0o?cl00P0l?3`0300m?Cd0?Shn03hn?P12@T80@D5103`l?00k>c/0?Cdm03hn?P0o?cl0>c/k03lo
?`80@41000P0@T920410@00n?Sh0?Cdm0451@@10@400@T920410@0<0ATI602D0@d=304I6AP1eMGD0
PX:209NGU`2<S8`0Rh^;08N7Q`1iNGT0Ogmo06i^KP1OGel0DE5A09JFUP33`l<0[:b/0<G5a@2l_;`0
a/K60=_Kf`2k^k/0Ti>C0:BTY033`l<0e]KF0=gMg@3Kfm/0fMWI0=gMg@3=cLd0[:b/0<G5a@3Jf]X0
e=CD0>OWi`3Shn<0f=SH0080bLW90340][Jf09jNWP2=SHd0RHV906][J`12@T80?Shn0451@@0o?cl0
Cdm?04i>CP1MGEd0FEUI04=3@`0n?Sh0?clo0451@@0m?Cd0@D5103`l?010@400A4A404=3@`0n?Sh0
?Cdm04I6AP1?Cdl0GEeM07QhN02`/;00cLg=0;Vi^@2:RXX0G5aL04Q8B012@T80@d=304Q8B01@D500
LG5a08Z:RP1mOGd0MGEe06e]K@1MGEd0B4Q803Xj>P0l?3`0?Cdm0080@d=300D0@D5103hn?P0n?Sh0
?Shn03Ph>00303hn?P80>SXj00`0?3`l0410@00h>3P0>c/k0410@00l?3`0>c/k03`l?00m?Cd0@D51
03/k>`0j>SX203/k>`0903Lg=`0h>3P0>SXj03dm?@0k>c/0?3`l03/k>`0j>SX0>CTi0080>SXj00L0
?3`l03dm?@0j>SX0?Shn03`l?00o?cl0?Shn0080>SXj00h0@D5103lo?`0m?Cd0?Cdm03lo?`0f=SH0
>CTi03Ph>00e=CD0>SXj0410@00l?3`0>SXj0410@080?3`l01L0?clo03Ph>00g=cL0=cLg03Xj>P0h
>3P0>c/k03`l?011@D40?Shn03/k>`0m?Cd0>c/k03`l?00m?Cd0>c/k03`l?00m?Cd0?Shn03Xj>P0h
>3P0=cLg03Ph>00303Xj>P0403lo?`1=CDd0Bd];03dm?@80@41000<0@D5103dm?@0g=cL00P0l?3`0
2`0o?cl0?3`l04U9B@1UIFD0MWIf05iNGP1;Bd/0@D5103Xj>P0h>3P0?Cdm0080@D510P0l?3`0400o
?cl0@D5103dm?@0k>c/0=SHf03`l?00n?Sh0@T9205EEE@26QXH0YjNW08n?S`2ATI40RXZ:08^;R`2Y
ZJT209NGU`0=09>CT`23Ph<0MGEe08N7Q`2/[:`0VYZJ06][J`1/K6`0Kfm_05UIF@1GEeL0De=C04];
B`0203dm?@0303`l?00i>CT0=3@d0080@41000@0@T9203Xj>P0l?3`0@d=30P1=CDd0B01_Kfl0SHf=
0:RXZ038b<P0fMWI0=_Kf`3WinL0iNGU0>7Qh@33`l<0YZJV0861P@1SHf<0FUYJ05ADE01PH600NGUi
09:BTP2/[:`0^;Rh0<O7a`3?cll0fm_K0=WIf@39bLT0a/K60<C4a02g]kL0XZ:R09NGU`1hN7P0Hf=S
05QHF01PH600NWYj07MgM`20P800OWin07UiN@2<S8`0ZJVY0;Zj^P3AdM40d];B0=?Cd`3Lg=`0e=CD
0=7Ad@2j^[X0][Jf0<K6aP3Ogml0g]kN0<W9b@1_Kfl0Jf][09FEU@2RXZ80Xj>S0<;2`P3>c/h0e=CD
0=3@d03Jf]X0b/[:09nOW`2`/;00dM7A0<?3``2GUiL0FUYJ03hn?P80>3Ph0100?3`l03@d=00m?Cd0
=SHf03Ti>@0e=CD0B4Q805]KF`1_Kfl0CDe=03lo?`13@d<0BDU903/k>`0g=cL0>c/k0P0f=SH04@14
A4@0>c/k03<c<`0b<S80=CDe03@d=00e=CD0=3@d03Hf=P0a<C40=CDe03Hf=P0i>CT0<c<c03Hf=P0l
?3`0BDU900gooooo000@ooooo`0:04i>CP1:BTX0BDU904Y:BP14A4@0AdM704A4A01BDU80HF5Q04Q8
B080A4A40P17AdL204I6AP0704A4A016ATH0B4Q804];B`17AdL0@d=304A4A00204E5A@0A04U9B@13
@d<0AdM704];B`14A4@0ADE504A4A017AdL0A4A404];B`16ATH0?clo04=3@`1:BTX0@T920451@@12
@T800P11@D407@13@d<0AdM704=3@`12@T80@d=304M7A`10@400?Shn0451@@12@T80@d=303lo?`0l
?3`0@D5103dm?@16ATH0@T9204A4A010@400?Shn03`l?012@T80@41003lo?`0n?Sh0?3`l0492@P0m
?Cd0?clo00<0@41000P0>c/k0451@@10@400@T9203hn?P0o?cl0?Cdm03lo?`80?Cdm00L0?3`l03Xj
>P0m?Cd0@41003dm?@0j>SX0>c/k0080>CTi00D0>SXj03lo?`12@T80?Cdm03`l?00203/k>`0:03dm
?@0n?Sh0?Cdm0410@00n?Sh0?clo0451@@0k>c/0@41003lo?`80?Shn01h0@D5104=3@`1<C4`0FUYJ
06EUI@1?Cdl0D51@05mOG`1YJFT0MgMg069RHP1WIfL0K6a/07inOP2BTY80Shn?0:BTY02n_[h0`/;2
0<g=c@3;bl/0a<C40<G5a@3@d=00b/[:0=OGe`3Ph>00fm_K0<c<c030`<020;2`/00?0:f][@33`l<0
fm_K0=oOg`38b<P0YZJV09>CT`26QXH0MgMg06QXJ01BDU80ADE50492@P10@400A4A40080?clo01<0
@D510492@P12@T80?clo0410@014A4@0BTY:04a<C018B4P0@T9204Q8B01=CDd0JFUY07inOP2@T900
[Zj^0;Bd]02i^KT0`<300080dm?C01H0Y:BT07inOP1nOWh0SXj>09FEU@2BTY80ZZZZ0:VYZ@2HV9P0
TI6A06YZJP1=CDd0BTY:04A4A00n?Sh0?Cdm03lo?`0k>c/0>CTi03hn?P10@400?Shn0P0k>c/00`10
@400?3`l03lo?`0203hn?P0603`l?00k>c/0?Shn03hn?P0j>SX0@4100`0n?Sh01@0l?3`0>CTi03Xj
>P0f=SH0>SXj0080?Shn00<0?3`l03/k>`0n?Sh00P0n?Sh06@0k>c/0>CTi03Xj>P0l?3`0>CTi03Lg
=`0i>CT0>SXj03lo?`0n?Sh0?3`l03hn?P0l?3`0>3Ph03Ti>@0k>c/0@41003lo?`0n?Sh0>c/k0410
@00i>CT0>3Ph03/k>`16ATH00P0n?Sh01@11@D40?Shn03hn?P0g=cL0>c/k00<0>SXj00<0?clo03dm
?@0j>SX00P0j>SX0500l?3`0?Cdm03/k>`0l?3`0@41003/k>`0i>CT0?Shn03lo?`0m?Cd0?3`l03Ph
>00o?cl0@4100492@P19BDT0DE5A051@D015ADD0>c/k0`0n?Sh03P0j>SX0?3`l03Ph>00i>CT0>SXj
03`l?015ADD0Cdm?04a<C011@D40?3`l03dm?@11@D40>SXj0P0k>c/00`0n?Sh0>SXj03lo?`0203/k
>`0>03hn?P1;Bd/0CDe=05=CD`18B4P0IVIV09BDU02j^[X0/;2`08:2PP24Q8@0QXJ608F5Q@2<S8`2
07inOP0;06a/K01IFET0I6AT08:2PP2RXZ80RXZ:06UYJ@1ADE40AdM70410@00o?cl00P0l?3`00`0n
?Sh0>c/k03dm?@0203Xj>P80>c/k02@0>SXj04U9B@1aLG40X:2P0;fm_@30`<00_kno0<?3``2o_kl0
][Jf0;Vi^@3@d=00fm_K0>?Sh`3EeMD0_[jn0;>c/`2OWil0XZ:R0:>SX`2TY:@0_Kfm0<G5a@3:b/X0
f=SH0<G5a@2b/[80RXZ:08>3P`1mOGd0LW9b061PH01EEED0CDe=04I6AP15ADD204A4A00W04];B`1D
E5@0HV9R06i^KP1YJFT0N7Qh09JFUP2d];@0bLW90<k>cP3Fe]H0emOG0=kNgP3Ogml0g=cL0=KFeP39
bLT0];Bd0:VYZ@2`/;00`L710<_;b`2KVi/0OWin06e]K@1OGel0EEEE06IVIP1cLg<0MgMg08>3P`29
RHT0W9bL0:2PX02>SXh0XZ:R07alO01SHf<0@4100080>CTi0P0k>c/0200h>3P0>SXj03Ph>00g=cL0
>CTi065QH@1>CTh0BDU90P0i>CT03`0h>3P0>CTi03Lg=`0j>SX0?Cdm03Lg=`0j>SX0@d=303Xj>P0k
>c/0>SXj03Ti>@0h>3P0=cLg03De=@0203Ph>00703<c<`0g=cL0>3Ph03Ph>00k>c/0AdM7096AT@0=
ooooo`004?ooool01@1<C4`0CDe=04];B`19BDT0ATI60080AdM700T0A4A404I6AP17AdL0B4Q804M7
A`19BDT0ADE504=3@`12@T800`17AdL01P16ATH0ADE504E5A@16ATH0B4Q804M7A`80ADE500D0@410
04Q8B015ADD0AdM704E5A@0204I6AP0L04Q8B014A4@0ADE504Y:BP18B4P0AdM704=3@`11@D40@T92
0451@@0n?Sh0@D5104=3@`10@400?3`l03hn?P0o?cl0@d=30451@@10@400>c/k0410@012@T80@410
03/k>`0n?Sh0@T920410@0<0?clo00P0?Cdm0451@@16ATH0@d=30410@00k>c/0?3`l0492@P80?3`l
00<0?clo03hn?P11@D400P0o?cl0100l?3`0?Shn03/k>`0o?cl203`l?00503dm?@0l?3`0?Cdm0451
@@0o?cl00P0n?Sh08`0k>c/0@d=303lo?`0k>c/0?Cdm03Ti>@0l?3`0>SXj03`l?00n?Sh0?clo03dm
?@0o?cl0ADE503Xj>P0n?Sh0>c/k03`l?00o?cl0@41003lo?`14A4@0?Shn04U9B@1HF5P0EeMG04e=
C@1;Bd/0EEEE059BDP16ATH0@41004M7A`1?Cdl0EeMG0080CTi>00<0CDe=04Y:BP1:BTX00P1GEeL0
?`1EEED0GUiN05YJFP1VIVH0MgMg08V9R@2FUYH0YJFU0<?3``3=cLd0gMgM0=CDe02l_;`0][Jf0:j^
[P1TI6@0ADE504e=C@16ATH0A4A40410@00o?cl0@D510410@00o?cl0A4A404E5A@1;Bd/0DU9B055A
D@1LG5`0MGEe09RHV032`/80d];B0<o?c`37alL0/K6a0;Fe]@36a/H0c<c<0=3@d03=cLd0`/;20;Bd
]036a/H0d=3@0=_Kf`3GemL0b<S80:n_[`2EUID0Q8B408b<S02DU9@0ZJVY08B4Q01KFe/0CTi>04=3
@`0o?cl0?Shn03lo?`020410@080?clo00@0?Cdm0492@P14A4@0@D510P0n?Sh02@10@400?clo03lo
?`13@d<0BTY:061PH01/K6`0Kfm_04M7A`0203hn?P0303Xj>P0o?cl0?clo0080?Cdm00T0?Shn0410
@018B4P0P82005QHF00o?cl0>c/k0410@00n?Sh00P0l?3`203Xj>P@0>CTi00D0>SXj03hn?P10@400
>SXj03/k>`0303`l?00D03/k>`0n?Sh0?Cdm03`l?00h>3P0@T9204m?C`10@400>c/k03`l?00m?Cd0
>c/k03`l?010@400>c/k03Xj>P0m?Cd0?3`l03Xj>P0m?Cd303/k>`0?03Xj>P0m?Cd0?clo03Xj>P0i
>CT0>SXj03`l?00i>CT0>SXj0410@00o?cl0>SXj03lo?`11@D40A4A40080Bd];00X0@T9204M7A`13
@d<0@41003hn?P11@D40>SXj03/k>`0j>SX0?Cdm0P0j>SX01P0h>3P0>CTi03Xj>P0k>c/0>SXj03dm
?@80>SXj00@0?Cdm03hn?P0k>c/0>CTi0P0m?Cd01@0h>3P0?clo04A4A01NGUh0HF5Q0080BTY:01D0
EeMG06][J`2=SHd0Ogmo06i^KP1VIVH0MgMg07YjNP1/K6`0F5QH05MGE`1=CDd0@T9203/k>`0n?Sh0
DE5A051@D014A4@0@41003Xj>P0k>c/00P0l?3`203hn?P0304=3@`15ADD0B4Q80080@d=307D0@D51
04Y:BP1]KFd0YZJV0<k>cP34a<@0WinO07moO`1WIfL0J6QX08b<S02][Jd0^[Zj0;jn_P37alL0cLg=
0<[:bP3AdM40e]KF0=3@d03>c/h0cLg=0;Rh^02g]kL0YjNW09nOW`2KVi/0Lg=c055AD@11@D40@d=3
04U9B@1?Cdl0EEEE05eMG@1SHf<0MgMg07emO@1oOgl0SXj>0;6a/@2n_[h0/K6a0;:b/P2i^KT0alO7
0<o?c`3EeMD0d=3@0<S8b02k^k/0_[jn0;Vi^@2c/k<0XJ6Q0:ZZZP32`/80[Zj^0:2PX02VYZH0Zj^[
0:JVYP2LW9`0XJ6Q0<W9b@3EeMD0^KVi0:RXZ02PX:00UIFE07IfMP1BDU80AdM705=CD`1]KFd0Bd];
0492@P0k>c/0?Cdm03/k>`0m?Cd0>c/k03Xj>P0h>3P0>SXj03/k>`0o?cl0>CTi03lo?`0h>3P0@410
04E5A@0k>c/0>SXj0492@P1:BTX0F5QH055AD@0i>CT0=3@d03Hf=P0k>c/0>3Ph03Ti>@0g=cL0>c/k
03Ti>@0g=cL0>SXj03Lg=`0i>CT0>SXj03Lg=`0o?cl0KVi^0:BTY01nOWh03Oooool0013ooooo00@0
C4a<04e=C@1<C4`0Bd];0`18B4P204I6AP030451@@18B4P0ADE50080ADE501P0AdM704=3@`17AdL0
A4A404I6AP14A4@0AdM704U9B@14A4@0ATI604M7A`14A4@0@d=304Q8B014A4@0ADE504M7A`13@d<0
ATI604A4A015ADD0@d=304I6AP15ADD204Q8B00C04A4A016ATH0AdM704A4A017AdL0?clo04M7A`10
@400?clo04=3@`0o?cl0?Shn0410@00o?cl0?Shn0451@@10@400@T9203dm?@0203lo?`@0?Shn00P0
>c/k03lo?`10@400?clo0451@@0m?Cd0?3`l03hn?P80>SXj00/0?Shn03/k>`0o?cl0?Shn0451@@0k
>c/0?3`l03hn?P14A4@0?Cdm03`l?00203hn?P030410@013@d<0?Shn0080@D5100D0?3`l03hn?P10
@400?3`l03Xj>P0203dm?@0D03`l?00m?Cd0?3`l03hn?P0j>SX0?clo04=3@`0j>SX0?Cdm03Ti>@10
@400@D5103`l?00k>c/0A4A403dm?@14A4@0BTY:04I6AP13@d<203dm?@0;03lo?`12@T80@41004I6
AP10@400@d=304I6AP18B4P0@4100492@P18B4P00P13@d<0:@12@T80ATI604M7A`1=CDd0BDU904a<
C01DE5@0GemO05QHF01YJFT0Ogmo0:>SX`2YZJT0[:b/08R8R01kNg/0D51@05QHF01eMGD0Ogmo08J6
QP28R8P0T92@08f=S@2@T900UiNG0;:b/P3EeMD0emOG0=CDe03Cdm<0g]kN0>[ZjP3Vi^H0hn?S0=oO
g`3Ng]h0iNGU0>KViP3GemL0b<S80080][Jf00l0/[:b0:^[Z`2UYJD0R8R808F5Q@22PX80IfMW04e=
C@18B4P0@T920451@@13@d<0BTY:04E5A@10@4000P12@T805`0m?Cd0@D510451@@0o?cl0?Cdm03lo
?`10@400E5AD07=cL`1jNWX0JFUY06=SH`1XJ6P0L71`08j>SP2LW9`0RXZ:08N7Q`2>SXh0Kfm_04Q8
B00m?Cd0>c/k0080?Shn02D0@41003lo?`0m?Cd0?clo04E5A@17AdL0E5AD05IFEP19BDT0?Cdm03/k
>`0l?3`0?Cdm03`l?00i>CT0>SXj03dm?@0k>c/0>SXj03dm?@0k>c/0>3Ph03dm?@11@D40?3`l03dm
?@10@400@d=303hn?P0m?Cd0?3`l0451@@10@400DU9B0::RXP2@T900ADE50080>SXj01`0?3`l03/k
>`0j>SX0>3Ph03/k>`0n?Sh0?clo0410@00i>CT0?clo03`l?00m?Cd0@D510410@00h>3P0?Shn03Ti
>@0l?3`0?Cdm03hn?P0j>SX0>CTi03dm?@0o?cl0@T9205=CD`1BDU80@4100P0j>SX01@0i>CT0?Cdm
03`l?011@D40?Cdm0080>c/k00<0A4A403lo?`0n?Sh01@0m?Cd00`0l?3`0?Cdm0410@00203/k>`0O
03hn?P10@400?3`l03hn?P0o?cl0BDU905=CD`1DE5@0EEEE0820P01dM7@0AdM70451@@1VIVH0OWin
08>3P`1^KVh0IfMW05ADE01=CDd0@T920410@00l?3`0>SXj03Ti>@0j>SX0B4Q804E5A@0o?cl0>SXj
03`l?00203hn?P0>03/k>`10@400>SXj03hn?P0m?Cd0@D5104=3@`1ADE40P82009BDU029RHT0PH61
08b<S02KVi/209ZJVP0C09^KV`23Ph<0Vi^K0;Zj^P30`<00UYJF06e]K@1dM7@0RHV9092@T02=SHd0
WYjN09nOW`2?Shl0Ph>306i^KP1OGel0EEEE04M7A`0204E5A@80?Cdm00/0F5QH07QhN02?Shl0VYZJ
09VIV@2EUID0XJ6Q0;Vi^@2m_Kd0/;2`0:NWY`020:b/[00G09JFUP25QHD0PH6107inOP2?Shl0TI6A
08f=S@2EUID0RHV908b<S02OWil0]KFe0;Zj^P38b<P0fMWI0=oOg`3Ph>00iNGU0>?Sh`3Jf]X0alO7
0;Fe]@3=cLd00P3QhN402`3Ph>00hN7Q0>;RhP3Ph>00bLW909VIV@20P800QhN706i^KP1/K6`0HF5Q
0080@41000T0>c/k03dm?@0m?Cd0?3`l03dm?@11@D40DU9B05]KF`1HF5P00P1IFET0201MGEd0BDU9
03lo?`12@T80?Shn0492@P0i>CT0=cLg0P0j>SX0400i>CT0>SXj03Lg=`0k>c/0?Cdm03Xj>P0g=cL0
>SXj0451@@1YJFT0L71`04I6AP25QHD0W9bL05iNGP0n?Sh=ooooo`004?ooool0201:BTX0CDe=04];
B`1:BTX0B4Q804U9B@16ATH0AdM70P18B4P02`16ATH0B4Q804=3@`16ATH0ADE504A4A012@T80ATI6
04A4A015ADD0EEEE0080BDU90140ADE504U9B@15ADD0@D5105MGE`16ATH0ADE504A4A013@d<0ATI6
04E5A@17AdL0B4Q804M7A`15ADD0A4A404=3@`0204M7A`0304A4A011@D40@T920080@T9200L0ADE5
04Q8B011@D40@4100492@P16ATH0@T920080@D5100<0@4100451@@13@d<00P11@D401@0l?3`0?clo
03lo?`10@400?3`l0080?Cdm0`0o?cl0200n?Sh0@T9203hn?P0l?3`0>c/k03Xj>P0i>CT0>SXj0P0k
>c/00`0m?Cd0@D510410@00203hn?P80?3`l00H0?clo03dm?@0l?3`0?3`l03hn?P15ADD20410@00A
03dm?@0j>SX0>SXj03hn?P0k>c/0?clo03Xj>P0m?Cd0>c/k03hn?P0o?cl0>c/k03Xj>P0m?Cd0>c/k
03Lg=`0j>SX00P0m?Cd00`0n?Sh0?Cdm03dm?@0203/k>`0<03dm?@0k>c/0?Shn03lo?`0n?Sh0>SXj
0451@@13@d<0A4A40451@@0j>SX0?Shn0P0k>c/0100i>CT0?Shn03hn?P0m?Cd204A4A01@051@D01I
FET0EUIF04i>CP17AdL0@D5104Q8B01DE5@0G5aL06i^KP1fMWH0Lg=c07emO@2@T900Y:BT09:BTP2P
X:00YZJV09BDU02][Jd0][Jf0=7Ad@3Ph>00c<c<0<71`@3>c/h0fMWI0<S8b02n_[h0_;bl0;Fe]@3:
b/X0d];B0=SHf03GemL0clo?0<O7a`2SXj<0QhN706a/K01FEUH0BTY:04U9B@12@T80@4100492@P0n
?Sh0?clo03hn?P19BDT0@d=303hn?P12@T80A4A40451@@0m?Cd0?Shn0451@@1HF5P0JFUY06=SH`1F
EUH0Hf=S07QhN024Q8@0Zj^[0=?Cd`3De=@0`/;20:f][@1gMgL0FUYJ04Y:BP1<C4`0B4Q805EEE@1/
K6`0IfMW05]KF`1`L70209:BTP0607]kN`1OGel0C4a<04e=C@14A4@0@4100P0o?cl01@0m?Cd0ADE5
03lo?`0m?Cd0>SXj0080>c/k00P0@D5103hn?P10@400@41004A4A00o?cl0>c/k03Ph>080?3`l00<0
?Cdm0451@@12@T800P13@d<02@1LG5`0/;2`0:BTY01@D500>SXj03Lg=`0l?3`0?Cdm03`l?00203Xj
>P80>c/k00T0>CTi03dm?@11@D40@41003`l?014A4@0@41003`l?00i>CT00P0k>c/01@0i>CT0?3`l
0451@@0l?3`0>c/k0080@41000<0BTY:0451@@0j>SX00P0m?Cd02P0n?Sh0>SXj03hn?P0o?cl0@410
03dm?@0n?Sh0?3`l0410@00o?cl30410@00703`l?00n?Sh0?Cdm03Ti>@0l?3`0>SXj03Ti>@0203lo
?`0A03/k>`0n?Sh0B4Q805IFEP1`L700FEUI04i>CP1MGEd0Lg=c05UIF@0o?cl0D51@06][J`20P800
IfMW05]KF`1@D5000P0m?Cd03P0n?Sh0>c/k0492@P0h>3P0@4100451@@18B4P0?3`l03hn?P0l?3`0
?Cdm0410@012@T80@d=30P0n?Sh01@13@d<0ATI604];B`1GEeL0M7Ad0080UIFE02/0K6a/061PH01e
MGD0VIVI09^KV`2e]KD0bl_;0;no_`2XZ:P0VIVI08Z:RP2;Rh/0T92@09jNWP2OWil0SXj>07alO01d
M7@0HV9R06=SH`1RHV80Hf=S06m_K`25QHD0Hf=S055AD@1<C4`0@D5104=3@`19BDT0C4a<05ADE01L
G5`0Cdm?05YJFP1UIFD0LG5a07AdM02@T900Xj>S0:b/[030`<00`l?30080_Kfm00`0dm?C0=_Kf`3E
eMD0f=SH0=3@d037alL0d];B0<k>cP3=cLd0e=CD0=OGe`3Jf]X20=oOg`0S0>3Ph03Jf]X0emOG0=OG
e`3Fe]H0d=3@0<G5a@32`/80_;bl0<71`@36a/H0d=3@0=gMg@3Shn<0h^;R0=kNgP3Ph>00gmoO0=7A
d@2l_;`0XZ:R08j>SP2;Rh/0NWYj065QH@1DE5@0[:b/0<o?c`3Hf=P0`<300:ZZZP2;Rh/0SXj>069R
HP0o?cl00P0m?Cd0100n?Sh0>3Ph03Xj>P0i>CT303Xj>P0>0451@@0l?3`0>3Ph03dm?@15ADD0EEEE
08b<S02[Zj/0IVIV04A4A01OGel0N7Qh08J6QP2ATI4=ooooo`004?ooool00`1;Bd/0C4a<04U9B@03
04Q8B0<0ADE500@0A4A404I6AP16ATH0ADE50P16ATH204E5A@0504A4A012@T80@D5104Q8B012@T80
0P15ADD304M7A`0804A4A018B4P0A4A404=3@`12@T80@D5104A4A019BDT204Q8B0040492@P18B4P0
A4A404=3@`80@T9200H0@d=30492@P1;Bd/0@D510492@P17AdL204=3@`040451@@0m?Cd0@T920410
@080?Shn0180@41003/k>`0n?Sh0?3`l0451@@15ADD0?clo03dm?@0n?Sh0@T9203Xj>P14A4@0@T92
0451@@0n?Sh0@D5103`l?00k>c/303`l?00603lo?`0n?Sh0>c/k03lo?`0m?Cd0>SXj0P0l?3`01P0n
?Sh0@4100410@012@T80@41003/k>`80?Cdm00/0@d=30492@P0m?Cd0>SXj03`l?00i>CT0?Shn0451
@@0m?Cd0>SXj03dm?@0203/k>`0N03`l?00i>CT0>c/k03Ph>00j>SX0@41003Ph>00l?3`0?Shn03`l
?00j>SX0?Shn03`l?00m?Cd0>CTi03/k>`11@D40@41003Lg=`0j>SX0>c/k03dm?@0j>SX0?Shn03dm
?@0g=cL0>SXj03lo?`11@D40@T920P14A4@204=3@`0603lo?`10@400?clo0451@@0n?Sh0@D510P10
@400C013@d<0AdM704U9B@1CDe<0MGEe08:2PP1kNg/0SHf=08V9R@1gMgL0Lg=c075aL@1kNg/0Ph>3
06ATI01?Cdl0Fe]K06=SH`1RHV80J6QX07emO@2RXZ80/;2`0:ZZZP2g]kL0b/[:0<_;b`2QXJ40QhN7
07EeM@1MGEd0Cdm?0492@P1:BTX0H61P07IfMP1`L700KFe]06IVIP1WIfL0KVi^06][J`1OGel0GEeM
06ATI01^KVh0LG5a07QhN02:RXX0YJFU0;Ng]`2c/k<0]kNg0<o?c`3>c/h0_Kfm0:VYZ@29RHT0MWIf
07YjNP22PX80KVi^04i>CP12@T80@d=30492@P1BDU80WinO0;2`/026QXH0EeMG051@D017AdL0Bd];
04A4A011@D420410@080?Cdm0P0o?cl0200m?Cd0?3`l04=3@`15ADD0?Shn04M7A`1=CDd0@d=30`0o
?cl00`0m?Cd0>c/k0410@00203hn?P0803Ph>00l?3`0?Shn03lo?`1PH600^[Zj0:>SX`1:BTX203dm
?@0803lo?`0k>c/0>c/k04A4A011@D40=cLg03Xj>P0o?cl303`l?080?clo00H0?Shn03dm?@0m?Cd0
@T9203dm?@0k>c/203lo?`0304Q8B01KFe/0GEeM0080A4A402/0>CTi03lo?`0l?3`0A4A404=3@`10
@400?Cdm03/k>`0l?3`0@D5103lo?`0n?Sh0@d=304E5A@0o?cl0@T9204Q8B012@T80?Cdm03lo?`0n
?Sh0?Cdm03`l?00o?cl0?3`l03/k>`0m?Cd0C4a<04];B`1QHF40IfMW04U9B@14A4@0?clo04Y:BP1=
CDd0?clo0492@P1=CDd0D51@04a<C00k>c/0?Shn0080?Cdm00L0?Shn03dm?@0l?3`0?clo03`l?00j
>SX0?Cdm0080>c/k03P0>SXj03Ti>@0k>c/0>SXj03Ph>00g=cL0?Shn04e=C@1FEUH0DU9B04a<C01T
I6@0QHF508f=S@2<S8`0UiNG08b<S02:RXX0QhN707]kN`2QXJ40X:2P08j>SP1lO7`0IFEU061PH01O
Gel0E5AD061PH01bLW80Shn?09nOW`2WYjL0WinO0:2PX022PX80I6AT055AD@17AdL0A4A404E5A@17
AdL0DU9B05MGE`1YJFT0Ph>308b<S02JVYX0T92@09nOW`2^[Zh0[jn_0;Fe]@2k^k/0dm?C0=_Kf`80
h^;R00@0hN7Q0=7Ad@3;bl/0a<C40P3;bl/05@32`/80b/[:0=3@d03Kfm/0f][J0=SHf03@d=00_kno
0:>SX`22PX80L71`06UYJ@1PH600G5aL05iNGP1RHV80NWYj08n?S`2KVi/0]KFe0<W9b@020=_Kf`0J
0>7Qh@3Ti>@0hn?S0=WIf@33`l<0/k>c0;fm_@3Hf=P0i^KV0=kNgP3Shn<0eMGE0<W9b@3Ti>@0hN7Q
0=gMg@3Jf]X0[Zj^09jNWP2LW9`0N7Qh069RHP2CTi<0Zj^[06m_K`17AdL204=3@`0A0410@00i>CT0
?Cdm03`l?00i>CT0?clo03hn?P1HF5P0KFe]07=cL`1;Bd/0KFe]0:f][@3:b/X0h^;R0>KViP3Kfm/0
3Oooool0013ooooo00@0CDe=04Y:BP19BDT0B4Q80P16ATH204M7A`0304I6AP15ADD0AdM70080AdM7
00<0ADE504A4A016ATH00P15ADD01P16ATH0Bd];04M7A`11@D40ATI604U9B@80AdM700D0A4A404U9
B@17AdL0@d=304A4A00204I6AP0404E5A@12@T80@T9204=3@`80AdM70140ADE504=3@`14A4@0@T92
04E5A@12@T80@4100492@P16ATH0AdM70492@P13@d<0@D5103hn?P0o?cl0A4A40410@00203hn?P08
0451@@0n?Sh0?clo03Xj>P0m?Cd0?3`l03hn?P11@D420492@P0<0410@014A4@0A4A403dm?@0k>c/0
>SXj03`l?00j>SX0?3`l03lo?`12@T80@4100P0m?Cd04P0k>c/0>SXj03/k>`0l?3`0?Cdm03hn?P10
@400A4A403lo?`0m?Cd0@T9203hn?P0k>c/0=cLg03`l?00k>c/0?clo0451@@80?clo00h0>CTi03Xj
>P14A4@0@T9203Xj>P0m?Cd0>CTi03Xj>P0m?Cd0>3Ph03dm?@0k>c/0>3Ph03/k>`80?3`l00L0?Shn
03Xj>P0l?3`0>c/k03hn?P0l?3`0@4100080>c/k01@0>CTi03lo?`0l?3`0>SXj03lo?`0j>SX0>c/k
03`l?00n?Sh0?clo03dm?@0n?Sh0?clo0492@P0n?Sh0@4100492@P0n?Sh0>SXj03dm?@80?3`l01/0
?Shn04Y:BP1IFET0GemO06=SH`1HF5P0CDe=04m?C`1@D500Bd];0451@@0n?Sh0C4a<05=CD`18B4P0
@d=304E5A@1:BTX0D51@05eMG@26QXH0WYjN0::RXP2KVi/0R8R807alO02NWYh00P2/[:`06P2d];@0
UiNG07moO`2EUID0Z:RX0:^[Z`3>c/h0gMgM0=oOg`3?cll0_[jn0<k>cP3De=@0_;bl0:n_[`2l_;`0
dM7A0=_Kf`38b<P0Xj>S07moO`1JFUX0EEEE08>3P`2PX:00_Kfm0P32`/80=@2j^[X0aLG50;^k^`26
QXH0EUIF0492@P10@400?3`l04A4A00o?cl0A4A404M7A`15ADD0@41003/k>`12@T80@D5104=3@`0j
>SX0?3`l03hn?P11@D40@T9204E5A@1=CDd0FEUI07emO@1aLG40GEeM04Q8B012@T80?clo03`l?00m
?Cd0@D5103dm?@0l?3`0>SXj03dm?@0h>3P0@T9203dm?@14A4@0EEEE08b<S030`<00^k^k07MgM`1@
D500ADE504Q8B00o?cl0?Cdm0080?clo00@0@D5103`l?00j>SX0>SXj0P0m?Cd01@0j>SX0>c/k0410
@00o?cl0?3`l0080>SXj00`0?3`l0492@P1BDU80UiNG09bLW01/K6`0ADE503`l?00i>CT0>c/k03`l
?00k>c/20410@0040451@@10@400?Cdm0410@080@T9200T0?Cdm03lo?`11@D40?Shn0451@@13@d<0
?clo0410@00l?3`00`0m?Cd06P0k>c/0?Shn03dm?@0o?cl0@41003dm?@0n?Sh0@41003Xj>P19BDT0
ATI604E5A@17AdL0ADE503hn?P0k>c/0@41003/k>`0j>SX0>3Ph03Xj>P0k>c/0>3Ph03Ti>@0j>SX0
>CTi0P0k>c/00`0n?Sh0>3Ph03`l?00203Xj>P0503`l?00j>SX0=cLg03/k>`0m?Cd00P14A4@05@1V
IVH0O7al09RHV036a/H0VYZJ07QhN01IFET0ADE505UIF@1aLG40UiNG08N7Q`1QHF40ADE50451@@1:
BTX0IfMW075aL@1LG5`0A4A403lo?`0204I6AP0E04M7A`15ADD0C4a<04M7A`1;Bd/0@T9206ATI02@
T900ZJVY0:j^[P2i^KT0][Jf0<G5a@3IfMT0e=CD0<_;b`2e]KD0c/k>0=_Kf`3Ogml0h^;R0080i>CT
01`0gmoO0>;RhP3GemL0`L710;Zj^P30`<00b/[:0=KFeP3<c<`0bl_;0;Rh^02ZZZX0V9RH08>3P`1S
Hf<0EUIF04i>CP1:BTX0GUiN07=cL`1dM7@0PX:208b<S02WYjL0a/K60=WIf@3Ng]h0h>3P0P3Ng]h0
;`3Fe]H0cLg=0<k>cP3;bl/0b<S80<_;b`34a<@0clo?0=kNgP3QhN40g=cL0=OGe`3IfMT0dM7A0=GE
e@3IfMT0fm_K0=SHf03Ph>00alO7096AT@37alL0emOG0<?3``2>SXh0WYjN0;Zj^P2TY:@0^;Rh0<30
`02^[Zh0SXj>08B4Q022PX80QHF507YjNP2LW9`0dM7A0=;BdP2LW9`0Cdm?04A4A01cLg<0cLg=0=SH
f02ZZZX0Rh^;00gooooo000@ooooo`0704a<C019BDT0Bd];04];B`18B4P0ATI604Q8B00304I6AP0>
04A4A016ATH0ADE504E5A@18B4P0AdM704=3@`19BDT0ATI604Q8B016ATH0A4A404Q8B01:BTX204Q8
B0<0ADE500@0A4A404=3@`13@d<0@T920P17AdL08@12@T80B4Q80492@P14A4@0ADE504I6AP1:BTX0
A4A404I6AP13@d<0AdM704U9B@12@T80@41004E5A@12@T80@4100451@@0o?cl0A4A40492@P14A4@0
@d=303lo?`0n?Sh0?3`l03hn?P0o?cl0@D5103dm?@0l?3`0@d=303`l?00203/k>`0>03dm?@0k>c/0
?clo03/k>`0i>CT0>c/k03lo?`10@400@D510410@00o?cl0?Cdm04A4A015ADD203`l?080?Shn00P0
>SXj03/k>`0j>SX0>c/k0410@00j>SX0?3`l0410@080?3`l00<0@41003hn?P10@4000P0k>c/00`0n
?Sh0A4A403/k>`0203dm?@80?3`l00l0?Cdm03Xj>P0k>c/0>c/k03Ti>@0g=cL0?3`l03/k>`0h>3P0
>CTi03lo?`0k>c/0?3`l0492@P13@d<00P0k>c/03`0m?Cd0?3`l03hn?P0h>3P0>SXj03Ph>00k>c/0
>SXj03/k>`0i>CT0>3Ph03`l?00k>c/0?Shn03Ti>@0203/k>`0?03Xj>P0l?3`0>CTi03Ti>@0o?cl0
>SXj03dm?@10@400?Shn0410@011@D40@41003hn?P0j>SX0?Cdm0080?clo01D0@D5104I6AP1DE5@0
GemO06=SH`1LG5`0I6AT061PH01/K6`0Jf][06MWI`1HF5P0DE5A04I6AP1BDU80ATI604a<C01:BTX0
Cdm?069RHP22PX800P2l_;`04@2XZ:P0/[:b0;:b/P2LW9`0Ph>309FEU@2ZZZX0/k>c09bLW02FUYH0
Xj>S0;Bd]02e]KD0/;2`0:BTY028R8P0YjNW0080clo?00/0[Zj^07YjNP1OGel0I6AT07UiN@2CTi<0
O7al07inOP1`L700EeMG04A4A00204=3@`80@41002d0ATI60492@P0l?3`0@D5105aLG026QXH0S8b<
0861P@1jNWX0MgMg06UYJ@13@d<0@D5104Q8B015ADD0@D5104M7A`10@400@d=303lo?`0n?Sh0?Cdm
0451@@0k>c/0?3`l03dm?@16ATH0Bd];0492@P18B4P0Lg=c08B4Q02DU9@0Vi^K07alO01UIFD0Lg=c
07moO`1nOWh0Bd];03Xj>P10@400A4A405QHF01>CTh00P10@4005P0o?cl0>3Ph03Ti>@0l?3`0?Shn
03lo?`0k>c/0?clo03dm?@12@T80LW9b08:2PP25QHD0H61P04=3@`0k>c/0@D5103dm?@0l?3`0?clo
0410@014A4@203lo?`040410@00n?Sh0?clo03dm?@80?Shn00P0?clo03hn?P0l?3`0?Cdm03/k>`0n
?Sh0?clo03`l?080?Cdm00`0@T920451@@0o?cl0>c/k03`l?013@d<0>3Ph04e=C@1EEED0A4A404a<
C012@T8203hn?P0:03dm?@0i>CT0?Shn03Ti>@0h>3P0>SXj03De=@0k>c/0?Shn03/k>`<0?3`l00D0
>3Ph03/k>`0i>CT0>3Ph03Ti>@0203dm?@0303/k>`0l?3`0>c/k0080@d=300d0AdM706MWI`2BTY80
QXJ6075aL@1[Jf/0IFEU04Y:BP1@D500HF5Q06EUI@1OGel0EUIF0080@T9201<0@d=304U9B@1QHF40
K6a/05YJFP14A4@0>CTi03/k>`1<C4`0Kfm_08>3P`2LW9`0WYjN08F5Q@1]KFd0PX:20;Ng]`3Bd]80
e=CD0080c/k>00D0dM7A0=?Cd`3Bd]80dM7A0=OGe`020=SHf00P0=?Cd`3;bl/0b/[:0<_;b`3>c/h0
dm?C0=CDe02o_kl0XZ:R09ZJVP2DU9@0VYZJ08R8R01VIVH0GemO079bLP1eMGD0PX:208n?S`2VYZH0
ZJVY09fMW@2/[:`0c<c<0=SHf03IfMT0h^;R0=WIf@3?cll0e]KF0=gMg@3GemL30=?Cd`0@0<K6aP33
`l<0c<c<0<[:bP37alL0^[Zj0;2`/02[Zj/0^KVi0=WIf@3AdM40c<c<0=7Ad@3Hf=P0h>3P0>GUi@80
h^;R0P3Ogml06`3Kfm/0eMGE0=[JfP3Ogml0e]KF0=CDe034a<@0];Bd08j>SP1cLg<0QHF508R8R02L
W9`0[:b/0<K6aP3@d=00fm_K0=CDe037alL0YJFU09BDU01bLW80Ogmo0;jn_P2j^[X0Shn?05EEE@0=
ooooo`004?ooool0101:BTX0B4Q804];B`19BDT304I6AP0804M7A`16ATH0ATI604M7A`19BDT0ADE5
04I6AP18B4P204M7A`0A04E5A@19BDT0ATI604A4A013@d<0A4A404];B`1@D500C4a<04E5A@13@d<0
ADE504I6AP1:BTX0@d=30492@P14A4@00P12@T801016ATH0@41004A4A013@d<30410@00>04E5A@13
@d<0?clo03hn?P14A4@0@T9204A4A011@D40@T920451@@0m?Cd0@41003`l?010@40204A4A00503`l
?00o?cl0?Cdm03dm?@10@4000P0k>c/02`0n?Sh0?Cdm03Ph>00h>3P0?3`l0410@00j>SX0>c/k03hn
?P0m?Cd0@4100080?Shn00P0>SXj03dm?@0l?3`0>c/k0451@@0l?3`0>SXj03`l?080>c/k0140?Shn
03`l?00k>c/0>c/k03lo?`11@D40?Cdm03lo?`0m?Cd0>c/k03`l?010@400>SXj03Ti>@0o?cl0?Shn
03/k>`0203Xj>P0403/k>`0l?3`0>c/k03Ti>@80>SXj0P0l?3`303/k>`80?Cdm00H0>SXj03Ti>@0j
>SX0@41003/k>`0n?Sh20410@00=03Xj>P0n?Sh0?Shn03dm?@0l?3`0>c/k03Ti>@0m?Cd0>SXj03`l
?00n?Sh0?Cdm0410@00203/k>`80>SXj00<0?Shn0410@00o?cl00P0k>c/09011@D40>c/k03lo?`10
@400>c/k03Ti>@0k>c/0?Cdm03/k>`12@T80ADE504Y:BP1MGEd0KFe]061PH01FEUH0D51@04U9B@10
@400?Shn04A4A00n?Sh0A4A404Q8B015ADD0BDU9059BDP1LG5`0M7Ad08N7Q`26QXH0R8R807UiN@1S
Hf<0F5QH05mOG`80E5AD00/0G5aL069RHP1UIFD0IVIV06UYJ@1gMgL0IfMW06=SH`1aLG40SXj>0:>S
X`0209fMW@0@0:JVYP2e]KD0b/[:0<30`02KVi/0RXZ:07alO01aLG40MgMg07QhN01mOGd0TY:B07]k
N`1YJFT0OGem08b<S080SHf=00X0Ogmo07MgM`1dM7@0IfMW07UiN@1hN7P0M7Ad06a/K01QHF40ATI6
0P17AdL00`16ATH0E5AD08B4Q00209^KV`0H08J6QP29RHT0QHF506YZJP13@d<0?Cdm051@D01IFET0
CTi>03hn?P10@400@d=303lo?`0n?Sh0@d=303lo?`0m?Cd0A4A404E5A@10@400?clo0410@00n?Sh0
@D510P12@T80100j>SX0>c/k03Ti>@0l?3`303hn?P0:0492@P16ATH0CTi>04M7A`1MGEd0Ogmo05=C
D`0m?Cd0>CTi03dm?@80@T9200@0@41003hn?P0k>c/0?Shn0P0k>c/0700o?cl0@T920410@00l?3`0
@41003Ti>@11@D40?clo03hn?P0j>SX0>CTi03`l?00o?cl0B4Q803`l?013@d<0ADE503hn?P0m?Cd0
>c/k03dm?@12@T80@D5104I6AP1OGel0GEeM0451@@0k>c/203dm?@0503/k>`0j>SX0>3Ph03/k>`0i
>CT00P0k>c/303Ti>@80>c/k00@0?Cdm03`l?00i>CT0>c/k0`0h>3P00`0i>CT0>3Ph03hn?P020451
@@1904Y:BP1>CTh0>CTi03lo?`13@d<0@D51051@D021PH40OWin05QHF01:BTX0@d=303dm?@0j>SX0
>c/k03dm?@0n?Sh0>c/k0410@011@D40?3`l03Xj>P0g=cL0>c/k04Y:BP1ZJVX0MgMg06MWI`1ZJVX0
K6a/05ADE01PH600V9RH0<_;b`3Kfm/0e=CD0=7Ad@39bLT0d];B0<c<c034a<@0]kNg0<30`02l_;`0
YjNW0861P@1WIfL0GemO069RHP1`L700LW9b07moO`2?Shl0PH6107inOP27QhL0Zj^[0;^k^`34a<@0
b<S80=KFeP3Ph>00h^;R0>KViP3Rh^80e=CD0;^k^`3De=@0hn?S0>7Qh@3Shn<0hN7Q0=cLg0020=[J
fP0E0=7Ad@2n_[h0_[jn0<W9b@3GemL0fMWI0=KFeP34a<@0ZZZZ09BDU02<S8`0X:2P0;6a/@39bLT0
fMWI0=KFeP3AdM40clo?0<g=c@39bLT0`l?30080^[Zj01d0Z:RX0;Jf]P38b<P0`L710;no_`3:b/X0
e]KF0=WIf@3@d=00bLW90;Jf]P2^[Zh0^[Zj0:6QX@2VYZH0]kNg0<?3``2o_kl0dm?C0=GEe@3Cdm<0
a/K60=SHf02k^k/0UiNG0<?3``2i^KT0/;2`0;jn_P0=ooooo`004?ooool01@1;Bd/0BTY:04a<C016
ATH0AdM70080ATI600D0AdM704I6AP16ATH0BTY:04M7A`0204A4A00604M7A`18B4P0ADE504I6AP15
ADD0@T920P15ADD01P14A4@0AdM704i>CP19BDT0B4Q804Y:BP80AdM70P14A4@05`17AdL0@T9204E5
A@1:BTX0BDU904I6AP19BDT0ADE503lo?`11@D40BDU9051@D01ADE40D51@04=3@`0n?Sh0?clo04A4
A013@d<0A4A40410@013@d<0?Cdm0080?Shn0P11@D401014A4@0?Shn03dm?@0m?Cd203/k>`0903Ph
>00l?3`0?Cdm03hn?P10@400?Shn0410@00k>c/0>SXj0080?3`l00L0>c/k03dm?@0o?cl0>c/k03hn
?P0o?cl0>CTi0080?3`l00L0?Cdm03`l?00m?Cd0?Cdm03lo?`0l?3`0>c/k0080?Cdm00@0FEUI03lo
?`0m?Cd0?Cdm0P0n?Sh00`0k>c/0>CTi03Ti>@0203lo?`80?Shn00<0@4100451@@0k>c/00P0m?Cd0
100j>SX0>CTi03hn?P10@40303hn?P80@41000`0?Cdm03/k>`0m?Cd0>c/k03Ph>012@T80ATI603/k
>`0i>CT0>c/k04E5A@0m?Cd203/k>`0803dm?@0h>3P0>c/k0410@00m?Cd0>SXj0410@00i>CT203Xj
>P0603/k>`11@D40?Shn03/k>`0m?Cd0>SXj0P10@40203hn?P0D04A4A00k>c/0?Shn03`l?010@400
?Cdm0410@012@T80FUYJ06IVIP1FEUH0?clo03hn?P0m?Cd0@D5103hn?P17AdL0CDe=05QHF01BDU82
04Q8B00604a<C017AdL0B4Q804M7A`15ADD0Bd];0P19BDT20492@P060451@@0j>SX0ATI60410@015
ADD0De=C0P1LG5`0?`1_Kfl0Ng]k08B4Q02RXZ80][Jf0::RXP24Q8@0U9BD0:^[Z`2VYZH0[Zj^09NG
U`1dM7@0PH61092@T024Q8@0NWYj08>3P`1aLG40E5AD04Q8B017AdL0CTi>051@D01CDe<0Jf][08Z:
RP2?Shl0UIFE09:BTP1oOgl0OWin07AdM02:RXX0/;2`0;Fe]@2`/;00WYjN0;Ng]`3<c<`0^KVi0;Fe
]@2GUiL0L71`05QHF01:BTX0@T9203/k>`15ADD0Hf=S07MgM`1LG5`0B4Q803lo?`0n?Sh0>c/k0492
@P0n?Sh0>c/k03hn?P0h>3P0>SXj0410@00203dm?@0A03/k>`0j>SX0>c/k03Ti>@0l?3`0>SXj03/k
>`0n?Sh0?3`l0410@012@T80HF5Q05UIF@17AdL0@d=304Y:BP0m?Cd00P15ADD203`l?080?Cdm00H0
@41003dm?@0k>c/0?3`l03dm?@0n?Sh203dm?@0703/k>`0l?3`0?3`l03hn?P0m?Cd0?Shn03dm?@02
0410@00503`l?010@400@d=30492@P13@d<00P0n?Sh01`1>CTh0EeMG05=CD`1;Bd/0@D5103dm?@0k
>c/00P0l?3`02`10@400?Shn03dm?@0m?Cd0?3`l03hn?P0m?Cd0?Shn03Ph>00i>CT0?Cdm0080@D51
00<0?Cdm03`l?00m?Cd00P0i>CT203`l?00C03/k>`1;Bd/0EeMG04Y:BP10@400@D5103`l?00k>c/0
>CTi03Xj>P1>CTh0I6AT06a/K01XJ6P0Fe]K04];B`12@T80?Cdm03/k>`0203dm?@0303lo?`0j>SX0
>3Ph0080>3Ph02T0>c/k03`l?00i>CT0?Shn03dm?@19BDT0GemO05UIF@1`L700MWIf09RHV02m_Kd0
`l?30:VYZ@2@T900Shn?09JFUP2BTY80PH6107MgM`1aLG40E5AD04];B`19BDT0Bd];06UYJ@2JVYX0
[Zj^0;Vi^@3<c<`0aLG50<;2`P36a/H0`L710<c<c03Fe]H0h>3P0>OWi`3Ogml0fm_K0>;RhP020>?S
h`040>;RhP3Ph>00hN7Q0>3Ph080hN7Q02<0gMgM0=GEe@37alL0`l?30;^k^`2KVi/0K6a/05iNGP1J
FUX0PH610:BTY02n_[h0bl_;0<W9b@3:b/X0cLg=0=WIf@3Ogml0e]KF0<K6aP2_[jl0WYjN092@T02?
Shl0TI6A0::RXP2e]KD0^[Zj0<;2`P3:b/X0c<c<0<;2`P2^[Zh0X:2P09NGU`020861P@0908J6QP2X
Z:P0e]KF0=SHf03=cLd0b<S80<[:bP3Bd]80e]KF0080f=SH00<0eMGE0<k>cP3De=@00P3Bd]801@38
b<P0_;bl0:b/[02NWYh0Xj>S00gooooo000@ooooo`0604a<C01:BTX0BDU904U9B@17AdL0ATI60P15
ADD00`16ATH0ADE504Y:BP0204M7A`0604I6AP17AdL0B4Q804I6AP1<C4`0B4Q80P15ADD02`16ATH0
@d=304=3@`19BDT0BTY:04E5A@12@T80ATI604E5A@13@d<0A4A40080@T9200d0@D510492@P15ADD0
@41004E5A@14A4@0@T9203lo?`16ATH0A4A404E5A@14A4@0@T920080@D5100<0@d=30492@P0o?cl0
0P0n?Sh0200o?cl0?3`l04I6AP1;Bd/0CTi>04I6AP12@T80?Cdm0P0o?cl0100m?Cd0?clo03hn?P0m
?Cd203/k>`0903Ph>00k>c/0>c/k03`l?00k>c/0?Cdm03hn?P11@D40?Shn0080?3`l00D0?clo03Xj
>P0l?3`0>c/k03`l?00203/k>`0303`l?00m?Cd0>c/k0080>SXj00l0=cLg03dm?@0k>c/0>SXj03/k
>`0j>SX0?clo03Ph>00g=cL0?Shn03lo?`0l?3`0>SXj03/k>`0h>3P00P0l?3`01@10@400?3`l03Ph
>00m?Cd0?3`l0080?Shn00@0?Cdm03`l?00j>SX0?3`l0P0n?Sh03P0j>SX0>3Ph03dm?@0l?3`0?clo
03Lg=`0j>SX0?Cdm04=3@`0g=cL0>CTi03Xj>P10@400?Cdm0P10@4000`0m?Cd0>3Ph03Ph>00203`l
?080>c/k00@0?clo03`l?00j>SX0?Shn0P0k>c/02@0n?Sh0?3`l03hn?P0n?Sh0>c/k0451@@0l?3`0
>c/k04m?C`0205mOG`0>05MGE`1<C4`0?Shn03/k>`0m?Cd0B4Q804M7A`0m?Cd0ATI603lo?`11@D40
?Shn03`l?00k>c/203lo?`040451@@12@T80@D5104E5A@<0@T9204/0@d=304Y:BP1DE5@0HF5Q08:2
PP2@T900ZJVY0;Rh^02_[jl0]KFe0:RXZ02;Rh/0Lg=c06m_K`1ZJVX0Hf=S05iNGP1JFUX0E5AD06][
J`1fMWH0Ng]k0820P01iNGT0LW9b07inOP2GUiL0ZZZZ09>CT`2BTY80Rh^;0:NWY`31`L40`/;20<30
`02n_[h0/[:b0;Bd]03;bl/0d=3@0=gMg@3Hf=P0i^KV0>CTi03Ph>00f][J0=cLg03MgMd0d=3@0;Jf
]P2EUID0MGEe061PH017AdL0@D510410@00n?Sh0@41003hn?P11@D40>c/k03lo?`0m?Cd0@D5103`l
?00n?Sh0>CTi03dm?@0i>CT0>SXj03/k>`0o?cl0>c/k03hn?P0l?3`00`0m?Cd05`0o?cl0@D5103dm
?@1>CTh0KVi^06e]K@1XJ6P0UYJF0861P@1^KVh0K6a/07]kN`2<S8`0SHf=05iNGP0n?Sh0?clo03Xj
>P0k>c/0?Cdm0451@@0m?Cd0?3`l00<0>c/k00T0?3`l03lo?`0m?Cd0?clo04E5A@11@D40>CTi03dm
?@10@4000P0o?cl204I6AP0704A4A00o?cl0CDe=06m_K`1lO7`0F5QH03/k>`0203hn?P0>04A4A00m
?Cd0?clo03hn?P0l?3`0>SXj03/k>`10@400?Cdm03/k>`0m?Cd0>SXj03lo?`0m?Cd203/k>`0;03Ti
>@0j>SX0?Cdm03hn?P0m?Cd0=cLg03/k>`13@d<0G5aL06QXJ01=CDd00P0j>SX05@0n?Sh0=CDe03Xj
>P0k>c/0FEUI06IVIP1EEED0Bd];03dm?@0n?Sh0=CDe03`l?00j>SX0>CTi03Xj>P0h>3P0?3`l03Ph
>00n?Sh0>CTi03dm?@0303Ti>@0J03lo?`1ADE40JVYZ06a/K01IFET0MWIf0861P@2;Rh/0RHV9061P
H01GEeL0A4A403dm?@13@d<0?clo04A4A00n?Sh0AdM705MGE`1iNGT0V9RH09nOW`2i^KT0emOG0=SH
f03AdM420<S8b0050<30`039bLT0bLW90=?Cd`3MgMd00P3Kfm/01`3EeMD0g=cL0=GEe@37alL0a<C4
0;Jf]P2ZZZX00P2TY:@05@2PX:00SHf=07MgM`1RHV80F5QH055AD@17AdL0ATI605ADE02JVYX0/K6a
0<O7a`3Fe]H0dm?C0<k>cP3<c<`0bLW90=?Cd`3Jf]X0g=cL0<c<c0020<O7a`0C0<S8b03<c<`0_[jn
0:b/[02SXj<0T92@08R8R01lO7`0M7Ad06MWI`1_Kfl0K6a/07AdM01mOGd0PX:208j>SP2XZ:P0b/[:
0=cLg0020=kNgP0@0=cLg03Jf]X0fMWI0=OGe`3EeMD0e=CD0=GEe@3@d=00`/;20<G5a@3=cLd0emOG
0<o?c`2b/[80XZ:R0<;2`Pgooooo000@ooooo`0604Y:BP1;Bd/0Bd];04U9B@18B4P0ATI60P14A4@0
1@15ADD0A4A404I6AP18B4P0AdM700@0A4A400H0BTY:04A4A013@d<0@d=304A4A012@T8204=3@`0J
04E5A@14A4@0@d=304E5A@14A4@0@D5104=3@`10@400@T9204A4A017AdL0BTY:04A4A015ADD0@d=3
0492@P0k>c/0@T9203dm?@12@T80@41004E5A@14A4@0?clo0492@P17AdL203hn?P0:03dm?@0n?Sh0
?Cdm04];B`1>CTh0BDU90410@00m?Cd0?3`l03Xj>P<0?Shn0P0l?3`02`0m?Cd0>c/k03Xj>P0n?Sh0
?3`l03hn?P0k>c/0@41003lo?`0m?Cd0=cLg0080?Cdm00L0@41003dm?@0l?3`0>c/k03`l?00j>SX0
>3Ph0080>CTi0P0l?3`303Xj>P0903/k>`0n?Sh0?Cdm03/k>`0n?Sh0>SXj03dm?@0n?Sh0?3`l0080
>CTi00P0@D5103Ti>@0k>c/0?Cdm03lo?`0k>c/0?3`l03dm?@80?3`l00@0?clo03`l?00i>CT0>SXj
0P0m?Cd00`0h>3P0?Cdm03/k>`0203hn?P80?Cdm00<0?clo04M7A`0o?cl00P0l?3`05@0j>SX0>c/k
03Xj>P0h>3P0?3`l03/k>`0l?3`0>3Ph03hn?P0o?cl0?3`l03Ph>00j>SX0>c/k03Xj>P0n?Sh0?Cdm
03hn?P0m?Cd0?3`l03dm?@0203`l?080?clo0140@T9204];B`13@d<0?clo03/k>`0o?cl0>c/k03dm
?@11@D40=cLg0492@P0j>SX0?Cdm03Ti>@0j>SX0?Cdm03hn?P0203`l?00f03dm?@0o?cl0?3`l04=3
@`11@D40?Cdm04Q8B01FEUH0GUiN07IfMP23Ph<0Ogmo09:BTP2<S8`0MgMg06i^KP1KFe/0D51@04I6
AP0m?Cd0AdM704U9B@1>CTh0EUIF05mOG`1^KVh0M7Ad07=cL`1aLG40J6QX06e]K@1EEED0F5QH04i>
CP1;Bd/0CDe=04];B`1=CDd0GemO07alO02>SXh0Ph>307IfMP23Ph<0Vi^K0:b/[02KVi/0Ti>C08j>
SP2EUID0YjNW09RHV02^[Zh0alO70P3Lg=`03034a<@0X:2P0:NWY`2_[jl0Z:RX08j>SP23Ph<0SHf=
09VIV@2FUYH0I6AT04=3@`80?Cdm00<0>c/k04=3@`10@4000P0l?3`07P0n?Sh0?clo03/k>`0m?Cd0
?3`l03Ti>@0k>c/0>SXj03/k>`0l?3`0?Shn0451@@1=CDd0M7Ad0;Zj^P2^[Zh0Kfm_07=cL`2CTi<0
Vi^K0<K6aP3Cdm<0dM7A0:BTY023Ph<0LW9b06YZJP1LG5`0?clo0410@0<0?Shn01L0@41003dm?@0n
?Sh0?clo03`l?014A4@0@D5103lo?`10@400B4Q80492@P0o?cl0?Shn03dm?@0o?cl0@4100451@@0o
?cl0DE5A08^;R`2GUiL0H61P0451@@0203dm?@0703hn?P0o?cl0?clo03Xj>P0o?cl0?Shn03Xj>P02
03`l?080>3Ph00H0>SXj03`l?00n?Sh0?Cdm03Xj>P0k>c/203Ti>@0Z03`l?00i>CT0>SXj03dm?@10
@400DU9B04M7A`0n?Sh0>SXj03Ph>00m?Cd0@41003/k>`0l?3`0?Shn04E5A@10@400>c/k03Xj>P0n
?Sh0>SXj03De=@0k>c/0=cLg03hn?P1CDe<0FEUI0451@@0o?cl0?Cdm03`l?00h>3P0?Cdm04Q8B01V
IVH0MgMg05ADE012@T80@d=304e=C@1ADE40DU9B0P1:BTX0800o?cl0?Cdm03Xj>P0k>c/0?3`l03/k
>`10@400Jf][08b<S01nOWh0OGem07UiN@1fMWH0Vi^K0::RXP2OWil0[jn_0;jn_P2b/[80[Zj^0;Bd
]038b<P0_[jn0;6a/@2FUYH0Ph>307=cL`1^KVh0IVIV05mOG`1EEED0Fe]K0P1ZJVX03P1LG5`0CTi>
0492@P12@T80@d=305aLG01[Jf/0P8200:6QX@31`L40g]kN0=gMg@3Kfm/0d];B0P2n_[h02`37alL0
e]KF0=SHf03@d=00^KVi0:^[Z`2XZ:P0W9bL08j>SP25QHD0NGUi0080GemO00l0H61P06IVIP1TI6@0
L71`08:2PP2@T900WinO0:FUY@28R8P0XJ6Q0;2`/038b<P0e=CD0=_Kf`3Ng]h00`3GemL01@3Lg=`0
g]kN0=_Kf`3GemL0f][J0080hN7Q00L0gMgM0=GEe@3Bd]80eMGE0=7Ad@31`L40a<C400gooooo000@
ooooo`0;04Y:BP1@D500C4a<04e=C@15ADD0CDe=04Y:BP1;Bd/0BTY:04U9B@15ADD00P16ATH01018
B4P0ADE504M7A`13@d<204E5A@0E04A4A012@T80A4A404I6AP13@d<0@41004A4A017AdL0ADE504A4
A012@T80B4Q804E5A@14A4@0@d=304A4A015ADD0@T9204I6AP13@d<0?clo0080@T9200D0ATI60492
@P12@T80?clo04M7A`0203lo?`0703hn?P13@d<0ATI603lo?`0m?Cd0@D510410@0030451@@0303dm
?@0n?Sh0@T920080?3`l01P0?Cdm03hn?P0o?cl0?Shn03lo?`0j>SX0>CTi03`l?00m?Cd0>SXj0410
@011@D40@41003/k>`0m?Cd0?clo04A4A010@400@T9203hn?P0k>c/0?Cdm03`l?00i>CT203dm?@80
?3`l0140?clo0410@00k>c/0>SXj03hn?P0o?cl0?Shn03`l?00n?Sh0>SXj03Ph>00j>SX0>3Ph03`l
?00j>SX0>c/k03lo?`0203/k>`0303Xj>P0k>c/0?clo0080>SXj00@0?Shn03dm?@0m?Cd0>SXj0P0m
?Cd203hn?P0803dm?@0l?3`0?3`l03dm?@1CDe<0@D5103lo?`12@T8203hn?P0303dm?@0k>c/0>c/k
0080?Shn00L0@D5103dm?@0k>c/0?clo03`l?00j>SX0>c/k0080?Shn00D0>c/k03`l?00o?cl0?clo
03dm?@0203lo?`0603Ph>00m?Cd0?clo03/k>`0n?Sh0@D510P0k>c/00`0i>CT0?Cdm03`l?00203dm
?@0603Xj>P0m?Cd0@41003hn?P0m?Cd0?clo0P0l?3`00`0k>c/0>SXj03/k>`0203`l?00<03lo?`1:
BTX0CDe=05MGE`1LG5`0DU9B05=CD`1@D500DU9B04e=C@1<C4`0@4100P0n?Sh01P0o?cl0@d=304i>
CP1gMgL0Ng]k065QH@80E5AD03@0Cdm?0451@@1@D500GUiN061PH01BDU80EEEE059BDP1LG5`0KFe]
07IfMP1YJFT0FEUI059BDP1JFUX0OGem08B4Q01ZJVX0HF5Q06e]K@1RHV80EUIF05eMG@1IFET0KVi^
08f=S@1lO7`0RHV90;Zj^P30`<00c/k>0<71`@2/[:`0S8b<069RHP1GEeL0EUIF05eMG@1oOgl0R8R8
0:b/[02NWYh0M7Ad04M7A`0k>c/0@41003lo?`10@400@T920451@@0k>c/0@d=30P0o?cl00`11@D40
?Cdm0410@00203lo?`0C04A4A01IFET0QXJ60<;2`P3Ph>00g=cL0:n_[`2][Jd0`<300=?Cd`3Lg=`0
fMWI0<W9b@2NWYh0GUiN04U9B@15ADD0?Shn03dm?@0203lo?`0403`l?010@400>c/k03hn?P80?Cdm
01H0@41004A4A019BDT0GEeM071`L01nOWh0KFe]0451@@12@T80?clo03hn?P0j>SX0@T9204Y:BP1_
Kfl0WYjN08>3P`1>CTh0ADE503`l?00n?Sh0?Cdm0P0n?Sh03P0m?Cd0>CTi0451@@12@T80?3`l03Xj
>P0m?Cd0>SXj03/k>`0i>CT0?Shn03dm?@0n?Sh0?3`l0P0i>CT01@0l?3`0?clo0492@P0k>c/0@410
0080Cdm?01L0@41003/k>`0j>SX0>SXj03Ti>@0j>SX0?3`l03dm?@0h>3P0>c/k03Ti>@0h>3P0>c/k
03Lg=`0m?Cd0>CTi0492@P1VIVH0Ogmo06IVIP18B4P0?3`l03/k>`0203Ti>@0X03hn?P1IFET0M7Ad
075aL@1FEUH0CTi>06=SH`1PH600LG5a06UYJ@1>CTh0>c/k03Ph>00k>c/0>3Ph03Lg=`11@D40A4A4
07EeM@29RHT0R8R806MWI`1MGEd0Bd];0492@P1DE5@0MGEe07moO`2[Zj/0/[:b0::RXP2NWYh0X:2P
0820P01WIfL0C4a<04Q8B00n?Sh0?clo03`l?080@D5102D0@41003lo?`13@d<0@d=304U9B@1EEED0
MgMg08N7Q`2<S8`0UiNG0<71`@3@d=00fm_K0=kNgP3Shn<0inOW0>KViP3MgMd0g=cL0=_Kf`3IfMT0
a/K609fMW@1iNGT0I6AT055AD@1HF5P0Hf=S07=cL`2:RXX0SHf=08Z:RP1jNWX0Ng]k08F5Q@2[Zj/0
aLG50080d=3@01/0a/K60;Vi^@2YZJT0U9BD0:6QX@2_[jl0eMGE0=_Kf`3MgMd0fMWI0=KFeP3De=@0
eMGE0=SHf03AdM40bLW90;Bd]037alL0bl_;0<k>cP3EeMD0d];B0<o?c`3=cLd0bLW90<G5a@3>c/h0
3Oooool0013ooooo00H0RXZ:07EeM@1nOWh0T92@09:BTP26QXH207]kN`0?0820P01dM7@0Fe]K04M7
A`16ATH0@d=304A4A016ATH0B4Q804];B`1?Cdl0Bd];04I6AP12@T80@D510080@T9201`0ADE504A4
A013@d<0@T9204=3@`18B4P0@d=304A4A012@T80?Shn04A4A013@d<0@T9204A4A019BDT0ATI604M7
A`15ADD0@d=304A4A011@D40@41003dm?@11@D40@4100451@@10@400>c/k0P15ADD02@11@D40?clo
03hn?P0o?cl0A4A403/k>`11@D40@41003dm?@0203hn?P0703`l?00m?Cd0>3Ph03/k>`0l?3`0>c/k
03`l?00203Xj>P0403/k>`0i>CT0?Shn0410@080?3`l0P0o?cl20410@00403`l?00m?Cd0?Shn03lo
?`80?Shn00D0>SXj03`l?00l?3`0>SXj03`l?00203lo?`0803`l?00j>SX0>c/k03`l?00h>3P0=CDe
03/k>`0m?Cd203/k>`0803lo?`0k>c/0?Cdm03`l?00i>CT0?Cdm04E5A@11@D4203lo?`0703Xj>P0o
?cl0A4A404=3@`1;Bd/0?clo03dm?@0203Xj>P0803hn?P0m?Cd0?3`l03/k>`0i>CT0>SXj03dm?@0g
=cL203dm?@0903Ti>@0j>SX0@41003hn?P0o?cl0@D5103`l?00g=cL0>CTi0080?Shn0P0k>c/0100n
?Sh0@d=303dm?@0l?3`303/k>`0603dm?@0n?Sh0@d=30492@P0l?3`0>CTi0P0j>SX01`0g=cL0>CTi
03dm?@0h>3P0>c/k03`l?00m?Cd00P0j>SX0200m?Cd0?3`l03`l?00m?Cd0?3`l04a<C01ADE40B4Q8
0P19BDT01P17AdL0?3`l03hn?P12@T80>c/k03dm?@80?clo00/0?3`l03hn?P11@D40?Cdm04A4A00o
?cl0AdM704Y:BP15ADD0@d=303lo?`0203dm?@80?clo01H0A4A405=CD`1jNWX0Hf=S06YZJP1EEED0
DE5A04];B`16ATH0A4A404E5A@18B4P0@T9204Q8B01EEED0EUIF05=CD`1QHF40PH6107=cL`1/K6`0
PX:20P23Ph<08@1VIVH0EeMG05aLG01SHf<0O7al08R8R02DU9@0[:b/0;Fe]@2RXZ80_kno0;fm_@32
`/80a<C40:JVYP2>SXh0MWIf07QhN02HV9P0WIfM08>3P`1oOgl0N7Qh07moO`1eMGD0EEEE04A4A013
@d<0D51@075aL@2DU9@0^;Rh0<_;b`020=;BdP0E0=KFeP31`L40a<C40<c<c02o_kl0`<300;>c/`2_
[jl0X:2P08B4Q01jNWX0OWin06IVIP0o?cl0>c/k0451@@0n?Sh0?Cdm03`l?00m?Cd0@D510080?clo
0380DU9B0:6QX@2][Jd0RHV905MGE`19BDT0@d=303hn?P15ADD0?3`l03/k>`17AdL0J6QX0:b/[03@
d=00WinO04U9B@0n?Sh0>CTi03dm?@0k>c/0@41003hn?P0o?cl0>SXj03Ph>00o?cl0?3`l03Xj>P0m
?Cd0@41003dm?@0n?Sh0?Cdm03lo?`12@T80?Shn03lo?`11@D40?Shn04I6AP1:BTX0@d=303hn?P16
ATH0@d=303/k>`0i>CT0?Cdm03`l?080>c/k0200?Cdm03lo?`0o?cl0>c/k03Ti>@0f=SH0>SXj03Ti
>@0k>c/0@d=3061PH029RHT0Lg=c04M7A`0n?Sh0?Cdm03`l?00h>3P0?3`l03Xj>P11@D40DE5A04I6
AP10@400?Cdm03Xj>P12@T80Bd];055AD@13@d<0>c/k03`l?080>SXj0P0k>c/09`19BDT0JVYZ08V9
R@25QHD0MGEe05aLG01>CTh0?Shn04A4A01aLG40WIfM0::RXP2i^KT0YZJV09BDU01mOGd0H61P04=3
@`12@T80?3`l0492@P15ADD0@T9203Ti>@0j>SX0?Cdm03Ti>@1@D500KFe]08f=S@2WYjL0];Bd0<;2
`P2n_[h0_kno0<S8b03Bd]80c/k>0=7Ad@020=GEe@0A0<k>cP36a/H0cLg=0;bl_02TY:@0N7Qh05EE
E@1;Bd/0IfMW08Z:RP2XZ:P0];Bd0;Jf]P2?Shl0GEeM04a<C014A4@00P12@T80201WIfL0Rh^;0:f]
[@37alL0c/k>0<?3``2b/[80`L710P3<c<`05P33`l<0aLG50<[:bP35aLD0^k^k0:n_[`2WYjL0/[:b
0;fm_@33`l<0_[jn09fMW@2?Shl0M7Ad071`L01/K6`0JVYZ06ATI01SHf<0GemO05iNGP1ZJVX=oooo
o`004?ooool05P3Kfm/0dm?C0=OGe`3Bd]80cLg=0;Vi^@2LW9`0Rh^;08V9R@1gMgL0HV9R05=CD`1I
FET0HV9R06EUI@1cLg<0MWIf07moO`1fMWH0FUYJ04I6AP12@T8204I6AP80@T9200D0@d=304E5A@17
AdL0@D510492@P020451@@0Q0410@013@d<0AdM704I6AP11@D40@T9204];B`18B4P0AdM7069RHP1S
Hf<0BTY:04E5A@14A4@0@d=303lo?`0m?Cd0?3`l03dm?@11@D40@41004E5A@12@T80?clo04];B`15
ADD0?Cdm03hn?P11@D40?Shn03`l?00n?Sh0B4Q80080@D510P0n?Sh02@17AdL0ADE50451@@0m?Cd0
>c/k03Xj>P0g=cL0?Shn0410@00203dm?@0803lo?`0n?Sh0?3`l03dm?@0n?Sh0>SXj03dm?@0l?3`2
03Xj>P0H03Hf=P0j>SX0>c/k03`l?00m?Cd0>c/k03Xj>P11@D40?3`l03/k>`12@T80?clo03`l?00n
?Sh0?Cdm03/k>`0l?3`0?Cdm03hn?P12@T80>c/k03Ti>@0m?Cd0@T920P0n?Sh0300k>c/0AdM7055A
D@1IFET0CTi>04a<C016ATH0?Shn03Ph>00j>SX0>c/k03`l?080>c/k00`0?Cdm03Xj>P0j>SX0=cLg
03/k>`0m?Cd0?3`l0451@@1ADE40@D5104A4A012@T8203Xj>P0703`l?00k>c/0>SXj03Ti>@10@400
@D5103Xj>P0203/k>`0703Ph>00m?Cd0>c/k03/k>`0m?Cd0@D5103/k>`0203dm?@0>03`l?00i>CT0
>CTi03Ph>00g=cL0?Shn04E5A@0m?Cd0>CTi03Xj>P0n?Sh0@41003/k>`0j>SX20492@P0304a<C012
@T80?Cdm0080@D510180?Cdm03Hf=P0k>c/0?Shn0451@@0k>c/0>SXj0410@00o?cl0>SXj03lo?`0l
?3`0>SXj03`l?014A4@0?clo03hn?P0o?cl203/k>`0803Xj>P0n?Sh0?Shn04A4A01JFUX0EUIF04=3
@`0l?3`20410@080@D5101h0?clo03`l?00n?Sh0@d=305iNGP1^KVh0OGem07MgM`1aLG40JVYZ055A
D@1:BTX0Bd];04U9B@18B4P0D51@06UYJ@1^KVh0Rh^;09bLW02?Shl0QHF50861P@23Ph<0Hf=S05IF
EP1;Bd/0EEEE05IFEP19BDT204];B`0C05iNGP2NWYh0]kNg0;fm_@3?cll0fMWI0=SHf03MgMd0_Kfm
0::RXP2SXj<0_kno0=KFeP32`/80[Jf]09>CT`2?Shl0Xj>S0<30`0020;no_`0G0<k>cP33`l<0[Zj^
06m_K`1:BTX0ATI603hn?P14A4@0?clo0492@P0o?cl0B4Q805iNGP1lO7`0LG5a06UYJ@1gMgL0Hf=S
05UIF@21PH40WinO09BDU01DE5@00P15ADD01@1CDe<0KVi^08^;R`2>SXh0OWin0080LW9b02<0N7Qh
07alO01lO7`0ADE50410@00i>CT0?Cdm03Ph>00k>c/0@41003dm?@0n?Sh0>CTi03`l?010@400>CTi
03/k>`0m?Cd0>SXj0451@@0m?Cd0@41003lo?`1=CDd0FUYJ079bLP27QhL0KVi^04A4A00l?3`0>SXj
03Ti>@0n?Sh0@D5103/k>`0203hn?P0703Ti>@0k>c/0?Shn03lo?`0k>c/0>CTi03/k>`0203Ti>@08
03Xj>P12@T80DU9B06IVIP1WIfL0FEUI04E5A@10@40203Xj>P0:03Ti>@0k>c/0>3Ph03/k>`0n?Sh0
?3`l03dm?@0k>c/0>CTi0410@080?3`l0P0i>CT05@0k>c/0>3Ph03hn?P0m?Cd0AdM705YJFP1EEED0
DE5A04m?C`1ADE40AdM703`l?012@T80GEeM07AdM021PH40Ph>307emO@1WIfL0Cdm?04A4A00203`l
?00]05=CD`1QHF40J6QX07AdM01ZJVX0Cdm?06QXJ01TI6@0PH6109jNWP2`/;00]KFe0;^k^`2o_kl0
WIfM08R8R01kNg/0[Zj^0<K6aP2VYZH0VYZJ08>3P`1^KVh0Ng]k0861P@1`L700I6AT04i>CP10@400
E5AD06][J`2EUID0Xj>S09JFUP21PH40R8R808Z:RP1`L700IfMW07MgM`2ATI40X:2P0:n_[`3;bl/0
e]KF0080gmoO01D0h>3P0=[JfP3AdM40bl_;0<W9b@38b<P0]KFe0;2`/02[Zj/0WYjN096AT@20P800
LG5a07=cL`1eMGD0LG5a05mOG`1EEED0BTY:0451@@0o?cl00P0m?Cd01@0o?cl0?Shn04=3@`13@d<0
BTY:00gooooo000@ooooo`190;^k^`25QHD0JFUY05QHF01CDe<0EeMG05aLG01]KFd0Jf][05MGE`1:
BTX0B4Q804I6AP1:BTX0C4a<04e=C@1:BTX0BDU904Q8B014A4@0@D510492@P17AdL0B4Q804A4A010
@400A4A404I6AP14A4@0ADE504A4A011@D40Bd];05eMG@1CDe<0J6QX061PH01RHV80Fe]K05IFEP1?
Cdl0Fe]K08F5Q@27QhL0JFUY05=CD`19BDT0A4A404=3@`12@T80?Shn03/k>`11@D40?3`l03dm?@0l
?3`0?Shn03lo?`0n?Sh0?clo0451@@0n?Sh0?Cdm03`l?00j>SX0>c/k0492@P0n?Sh0@41003lo?`16
ATH0?Cdm03`l?00203Xj>P0903Ph>013@d<0@D5103dm?@17AdL0?Cdm03/k>`0m?Cd0@4100080?clo
00`0>c/k03dm?@0k>c/0>c/k03dm?@0h>3P0?Cdm03hn?P0h>3P0>c/k03Ph>00g=cL203`l?00403Ti
>@0k>c/0>SXj03dm?@80>CTi0P0o?cl05P0g=cL0?clo0410@00k>c/0?Shn03Xj>P10@400@D5106EU
I@1SHf<0G5aL04U9B@14A4@0>c/k03Ti>@10@400>SXj03dm?@0j>SX0?3`l03Ti>@0k>c/203dm?@0C
03Ti>@0l?3`0>SXj0451@@10@400>c/k03dm?@0n?Sh0?clo03/k>`0m?Cd0>SXj03`l?00m?Cd0>c/k
03Xj>P0l?3`0@d=30410@00203Xj>P0303dm?@0l?3`0>SXj0080>c/k00P0>CTi0410@00n?Sh0@d=3
0451@@0n?Sh0?Cdm03hn?P80>SXj00X0?Shn04A4A00j>SX0>SXj03hn?P0m?Cd0>SXj03`l?00k>c/0
@D510P0j>SX01P0k>c/0@D5103/k>`0n?Sh0>SXj03hn?P80?Cdm01<0A4A404I6AP0o?cl0?Cdm04=3
@`0m?Cd0@41003lo?`0l?3`0?clo03/k>`0m?Cd0@T9203/k>`0m?Cd0?Shn03lo?`10@400?Shn0080
@D5100T0?Cdm03Xj>P0n?Sh0?clo0492@P0m?Cd0?3`l0451@@10@4000P17AdL01@1:BTX0ADE50492
@P0o?cl0@4100080?Shn01@0A4A40451@@1;Bd/0J6QX07=cL`1`L700IfMW05MGE`1>CTh0AdM704A4
A00k>c/0?clo03hn?P0m?Cd0@41004A4A017AdL0De=C08>3P`80W9bL03`0[Zj^0;6a/@34a<@0d];B
0;fm_@2][Jd0`/;20;Jf]P2`/;00/K6a0:j^[P2g]kL0`/;20<O7a`3=cLd0fMWI0=[JfP3?cll0bLW9
0;Ng]`2<S8`0Jf][05]KF`1CDe<0DU9B05UIF@1]KFd0NGUi07]kN`1bLW80EeMG05mOG`1dM7@0OWin
06UYJ@1/K6`0UIFE0:^[Z`3>c/h0dM7A0;Jf]P2EUID0PX:208j>SP2XZ:P0e]KF0=gMg@2o_kl0R8R8
06a/K01>CTh0B4Q80451@@10@400?clo0410@00n?Sh0?clo0451@@0l?3`203hn?P0K03dm?@0l?3`0
>CTi0492@P11@D40>c/k03hn?P0j>SX0?Cdm0410@012@T80IFEU09bLW02c/k<0]KFe0:2PX01[Jf/0
C4a<03lo?`0k>c/0?3`l03Ph>00j>SX0@41003`l?011@D40?clo0080?Cdm00`0?3`l03Ti>@0i>CT0
>3Ph03dm?@0l?3`0A4A405EEE@1eMGD0MWIf04e=C@13@d<203Lg=`0D03Xj>P0o?cl0>SXj03Xj>P0i
>CT0>SXj03Ti>@0k>c/0?3`l03Xj>P0l?3`0>CTi03/k>`0h>3P0>CTi03Ph>00o?cl0AdM70451@@0l
?3`204=3@`0i04A4A013@d<0?3`l03dm?@0k>c/0?Shn04E5A@1RHV80QXJ605YJFP16ATH0A4A403dm
?@0j>SX0=cLg03dm?@1BDU80LG5a09:BTP1^KVh0Bd];0492@P0o?cl0Bd];06a/K01XJ6P0QXJ60;Rh
^03?cll0aLG509^KV`1XJ6P0D51@079bLP2KVi/0[Jf]07YjNP1ADE40CDe=061PH02@T900UYJF0861
P@1VIVH0IfMW061PH01LG5`0IFEU06QXJ01JFUX0CTi>04A4A017AdL0F5QH07alO02:RXX0Xj>S0080
d];B00l0bLW90;jn_P2i^KT0[:b/0:j^[P2RXZ80SHf=08R8R027QhL0UYJF09fMW@2@T900J6QX05EE
E@1:BTX00P12@T804@1?Cdl0EEEE04a<C01@D500B4Q804Y:BP1FEUH0IVIV071`L01iNGT0L71`06EU
I@1bLW80Ph>30:JVYP2`/;00][Jf00gooooo000@ooooo`0l05YJFP1VIVH0G5aL04e=C@17AdL0ATI6
04i>CP1;Bd/0C4a<04];B`1=CDd0BTY:059BDP1CDe<0Cdm?04U9B@14A4@0Cdm?04I6AP17AdL0@d=3
0492@P16ATH0@T9204E5A@13@d<0@D5104A4A016ATH0@T92065QH@1iNGT0TY:B0:FUY@2FUYH0NWYj
06IVIP1FEUH0Bd];04I6AP12@T80?Shn04=3@`12@T80ATI604M7A`14A4@0@T9204U9B@0m?Cd0?clo
03hn?P10@400>SXj0451@@0n?Sh0@D510410@00m?Cd0?3`l0P0m?Cd06P12@T80?Shn03/k>`0i>CT0
?Shn03lo?`1CDe<0D51@03`l?00o?cl0?Shn03`l?00h>3P0>SXj03/k>`0i>CT0?clo0410@00l?3`0
?Cdm03/k>`0o?cl0>c/k0451@@0n?Sh0?Cdm0P0i>CT0100n?Sh0>c/k03dm?@11@D4203Xj>P0Q03/k
>`0j>SX0>3Ph03/k>`0j>SX0?3`l03Xj>P0k>c/0>3Ph03lo?`0l?3`0@41003Ti>@0j>SX0>3Ph03`l
?00o?cl0?Cdm04a<C017AdL0EUIF051@D012@T80?Cdm03/k>`11@D40?3`l03lo?`0k>c/0?Cdm03/k
>`0l?3`0>SXj0080?clo00D0>CTi03dm?@10@400@41003Ti>@0203hn?P0S0410@00i>CT0>c/k04A4
A018B4P0>3Ph03hn?P17AdL0EEEE05eMG@1^KVh0DU9B04=3@`0k>c/0@41003lo?`0j>SX0?Cdm03/k
>`0m?Cd0>SXj03lo?`0m?Cd0@T9203`l?00n?Sh0>c/k03lo?`16ATH0>3Ph03/k>`0h>3P0=cLg03Xj
>P0n?Sh00`0j>SX0100k>c/0=cLg03Ph>00l?3`203Xj>P0;03`l?00j>SX0?Cdm03Xj>P10@400>SXj
0410@014A4@0?clo03`l?00k>c/00P0m?Cd01012@T80?Cdm03`l?010@40203`l?00O03Xj>P0n?Sh0
@41003`l?00n?Sh0?3`l03/k>`0h>3P0>CTi03/k>`0h>3P0?clo0451@@10@400?clo0451@@0m?Cd0
?Shn03`l?00j>SX0?Cdm03`l?00k>c/0?Cdm03hn?P1:BTX0EEEE05YJFP1LG5`0FEUI04I6AP0203lo
?`80?3`l00d0>SXj0410@018B4P0D51@05]KF`1^KVh0Lg=c07moO`2=SHd0TI6A09FEU@2KVi/0UYJF
0080PX:203T0QXJ607emO@1SHf<0G5aL06i^KP1lO7`0UIFE09:BTP2VYZH0YjNW0;6a/@3<c<`0a<C4
0;:b/P2LW9`0UYJF08N7Q`1hN7P0QHF50:b/[031`L40d];B0<O7a`35aLD0];Bd0:ZZZP2k^k/0c/k>
0<C4a02XZ:P0Xj>S09jNWP2c/k<0clo?0>3Ph03MgMd0e=CD0<?3``39bLT0c/k>0<_;b`3EeMD0f][J
0<g=c@2XZ:P0PX:205eMG@11@D40CDe=0410@00m?Cd0?3`l03/k>`10@400@T9204A4A00n?Sh00P0l
?3`203/k>`0M03dm?@0o?cl0?Cdm03/k>`0n?Sh0>c/k04E5A@1GEeL0G5aL08R8R030`<00dm?C0=KF
eP3=cLd0_kno0:FUY@25QHD0LG5a051@D00o?cl0>c/k04A4A00o?cl0@41003hn?P0o?cl0?Shn03`l
?010@4000P0j>SX04`11@D40AdM708N7Q`24Q8@0IVIV04Q8B00o?cl0>SXj03`l?00j>SX0>3Ph03De
=@0g=cL0>SXj03Ti>@0l?3`0>3Ph03lo?`0j>SX00P0h>3P05`0k>c/0?3`l03Ti>@0l?3`0?Cdm04e=
C@12@T80@d=303/k>`11@D40?clo03Xj>P0l?3`0?Cdm0451@@15ADD0BDU905UIF@1<C4`0@d=30410
@00i>CT0?clo00<0>CTi0200>c/k05IFEP1hN7P0HF5Q04A4A00j>SX0>3Ph03Ti>@0j>SX0@D5105MG
E`1nOWh0KFe]06YZJP1cLg<0FUYJ04Y:BP1WIfL0IVIV079bLP1OGel0ADE505ADE01_Kfl0UYJF0:j^
[P2YZJT0NGUi0820P01oOgl0NGUi06UYJ@80EEEE01`0G5aL05eMG@1JFUX0HV9R096AT@2i^KT0a<C4
0;Zj^P2^[Zh0SXj>07AdM01TI6@0Ogmo08R8R01mOGd0KVi^05YJFP1/K6`0UiNG0;Bd]02`/;00UIFE
06e]K@1ADE40E5AD06ATI01nOWh0WYjN0P2d];@03`2e]KD0[Jf]0;Zj^P31`L40_kno0<c<c034a<@0
`<300<G5a@3@d=00e=CD0=GEe@3Hf=P0b/[:0;no_`0=ooooo`004?ooool01P1>CTh0BTY:04Y:BP18
B4P0AdM704Q8B080ATI60140AdM704];B`1;Bd/0B4Q804a<C01>CTh0GemO07QhN01jNWX0J6QX04U9
B@1:BTX0ADE504=3@`15ADD0ATI604A4A00204E5A@80@d=300/0C4a<05mOG`1CDe<0CDe=055AD@1:
BTX0ATI60451@@16ATH0@D5104=3@`030492@P0303hn?P13@d<0ADE50080@D510P0n?Sh0400o?cl0
?3`l03dm?@0l?3`0?Shn03`l?014A4@0>SXj03dm?@0j>SX0?Cdm03hn?P0m?Cd0?3`l03Xj>P13@d<2
03hn?P0I0492@P0k>c/0?Cdm03dm?@0o?cl0?Shn0492@P0l?3`0>CTi03hn?P18B4P0?Cdm03Xj>P0k
>c/0@41003lo?`0l?3`0?Shn03lo?`0l?3`0?Cdm03`l?00o?cl0?Cdm03/k>`0203Xj>P0803/k>`0n
?Sh0>c/k03`l?010@400>SXj03Ph>00g=cL303`l?080?Cdm00L0?Shn03Lg=`0i>CT0>c/k03lo?`1@
D500E5AD0080>CTi01H0?Shn03dm?@0m?Cd0@T920410@011@D40>c/k03dm?@0l?3`0?Cdm03Ph>00l
?3`0?Cdm03/k>`0l?3`0@41003Xj>P0l?3`0=SHf03Xj>P0o?cl0?Shn0P0k>c/203`l?00904e=C@1o
Ogl0WinO09:BTP20P800Jf][04I6AP0m?Cd0>CTi0080@D5100@0>CTi03hn?P13@d<0AdM70P11@D40
2@0n?Sh0>c/k03`l?00k>c/0?3`l0451@@10@400>CTi03hn?P0203Ti>@0603/k>`0o?cl0>c/k03`l
?00j>SX0>c/k0P0g=cL03@0k>c/0>3Ph03/k>`0j>SX0>3Ph03`l?010@400?Cdm03`l?00m?Cd0>c/k
03Ph>00k>c/00P0m?Cd01`0i>CT0?Cdm03dm?@0k>c/0?Shn03Xj>P0m?Cd00P0n?Sh0100j>SX0?3`l
03`l?00l?3`203lo?`0303/k>`0o?cl0@T9200<0@T920P10@4000`0m?Cd0?Shn03Ti>@0203/k>`08
0492@P1:BTX0C4a<051@D01HF5P0AdM704E5A@11@D420492@P80?clo0380BTY:04A4A016ATH0DU9B
06ATI01ZJVX0Hf=S06][J`1HF5P0H61P06IVIP1WIfL0Kfm_07]kN`1/K6`0HV9R055AD@1EEED0GUiN
06a/K01jNWX0Ng]k07IfMP1_Kfl0K6a/07inOP1gMgL0MWIf0861P@1WIfL0EEEE06][J`2ATI40Shn?
06=SH`18B4P0Hf=S09JFUP2ATI40VIVI0:NWY`2][Jd0WinO0;Rh^03EeMD0fMWI0>7Qh@3Ogml0f][J
0<O7a`80bl_;01D0/K6a0:6QX@2BTY80PH6107MgM`1WIfL0JFUY07EeM@1/K6`0A4A40492@P10@400
@D5103`l?00n?Sh0@D5104];B`1EEED0@T9203hn?P10@4000P0m?Cd0400n?Sh0?Cdm03hn?P0l?3`0
?Shn04];B`1[Jf/0QhN709JFUP2][Jd0^KVi09nOW`2EUID0Ti>C07moO`1RHV8205EEE@0805ADE018
B4P0ATI604U9B@0o?cl0@41004I6AP0i>CT203/k>`0D03hn?P0m?Cd0>c/k03/k>`0i>CT0?clo051@
D01dM7@0RXZ:04i>CP0o?cl0>SXj03/k>`0o?cl0@T9203Xj>P0i>CT0>c/k03`l?00o?cl203Ph>005
03Xj>P0k>c/0>CTi03Xj>P0i>CT00P0m?Cd0400i>CT0@d=303dm?@0n?Sh0>3Ph03Ti>@0j>SX0>c/k
03dm?@0l?3`0>3Ph03`l?012@T80C4a<04=3@`0m?Cd203Ph>00j03/k>`0i>CT0>CTi03/k>`0i>CT0
?Cdm051@D01?Cdl0B4Q803/k>`0g=cL0>3Ph03hn?P1@D500JVYZ08^;R`1lO7`0Hf=S04A4A00e=CD0
>3Ph03/k>`0l?3`0?Shn03lo?`0k>c/0AdM705EEE@1eMGD0L71`06m_K`1hN7P0Kfm_04i>CP1<C4`0
AdM703lo?`1;Bd/0JFUY08b<S02^[Zh0^KVi09fMW@2PX:00[:b/096AT@1fMWH0EUIF055AD@1aLG40
Vi^K0:NWY`2GUiL0Kfm_05=CD`10@400@d=3059BDP80EeMG01T0C4a<04I6AP1>CTh0GEeM07IfMP2X
Z:P0c<c<0<o?c`30`<00a<C40<_;b`3Cdm<0g=cL0=WIf@3Ogml0h>3P0=;BdP30`<00bLW90;no_`2R
XZ80PH6106UYJ@1LG5`0DU9B00gooooo000@ooooo`80C4a<0P16ATH00`17AdL0B4Q804];B`0404A4
A00V04=3@`16ATH0@d=304=3@`15ADD0D51@05UIF@1=CDd0AdM704A4A01EEED0Ph>307=cL`1RHV80
EUIF04];B`15ADD0@d=304E5A@11@D40ATI605iNGP1nOWh0QhN707UiN@1aLG40Fe]K05=CD`17AdL0
A4A404E5A@14A4@0AdM704U9B@1:BTX0@d=303hn?P13@d<20492@P80?clo00P0?Shn0492@P11@D40
@d=30492@P13@d<0?Shn03lo?`<0?Shn0180@4100492@P14A4@0AdM703hn?P1FEUH0Lg=c05mOG`1X
J6P0N7Qh07MgM`1IFET0E5AD05aLG01DE5@0?Shn0410@016ATH20410@00503lo?`10@400?Shn0451
@@0l?3`00P0k>c/01@0j>SX0>c/k03/k>`0k>c/0?3`l0080?Shn01D0@41003dm?@0i>CT0?3`l03Xj
>P0l?3`0?Shn03Ph>00j>SX0?Shn03dm?@0i>CT0BDU905]KF`1WIfL0C4a<03hn?P0h>3P0>SXj03dm
?@12@T800P11@D4203`l?00@03Xj>P0l?3`0>SXj03hn?P0i>CT0>c/k03dm?@13@d<0>c/k03lo?`0l
?3`0=SHf03Xj>P0k>c/0>3Ph0451@@80?Shn01H0?clo04=3@`1;Bd/0Fe]K071`L01CDe<0@d=30451
@@0k>c/0>SXj03dm?@0l?3`0ATI605EEE@1JFUX0Fe]K04m?C`15ADD0@D510410@00k>c/0?Cdm0P0k
>c/02`0n?Sh0?3`l0410@00m?Cd0ATI604M7A`12@T80?3`l03Lg=`0k>c/0=cLg0080>CTi01T0>3Ph
03/k>`0k>c/0?Shn03`l?00k>c/0?3`l03dm?@0g=cL0>c/k03dm?@0n?Sh0>SXj03Ti>@0k>c/0?clo
03/k>`0m?Cd0>c/k03Ti>@0n?Sh0?Cdm03`l?00o?cl0?Shn0080?3`l00<0>CTi03/k>`0k>c/00P0o
?cl03011@D40?Cdm03hn?P0m?Cd0?Shn03Xj>P0k>c/0?3`l03lo?`0j>SX0?clo03hn?P80@T9200@0
>c/k03Ph>010@400>c/k0P11@D40600k>c/0@41004A4A014A4@0CDe=059BDP12@T80A4A40451@@0o
?cl0@41004=3@`15ADD0H61P07inOP2=SHd0MWIf065QH@1NGUh0EUIF059BDP1DE5@0GEeM05=CD`80
BDU900D0B4Q804M7A`1:BTX0D51@05eMG@0209>CT`0A075aL@1QHF40Hf=S06IVIP1BDU80BTY:0492
@P16ATH0B4Q8051@D01JFUX0OWin09^KV`2ZZZX0/;2`0<71`@33`l<00P31`L40@@3<c<`0g=cL0=cL
g03MgMd0d];B0;2`/02KVi/0UYJF09jNWP2LW9`0OGem08J6QP1lO7`0HV9R06e]K@1kNg/0S8b<092@
T02/[:`0Y:BT092@T01kNg/0Fe]K05UIF@1gMgL0Ti>C0:VYZ@2EUID0P82006m_K`1=CDd0D51@07al
O024Q8@0MWIf061PH01TI6@0Fe]K04Y:BP1=CDd0DE5A06YZJP1dM7@0JFUY05YJFP12@T80?Shn04A4
A017AdL0@D5103lo?`11@D40>c/k03`l?00m?Cd0?clo03dm?@0n?Sh0@41004I6AP1FEUH0MGEe055A
D@14A4@0?3`l0080>c/k00P0>SXj03lo?`0l?3`0>SXj03Ti>@0h>3P0=cLg03`l?080>c/k00H0?3`l
03Ti>@0k>c/0?3`l03/k>`0j>SX203Ti>@0803Lg=`0k>c/0>SXj03/k>`13@d<0GUiN051@D015ADD2
03/k>`0403lo?`0l?3`0=cLg03Hf=P80=cLg00@0>c/k03`l?00i>CT0>CTi0P0j>SX00`0i>CT0>SXj
03Ph>00203Ph>00703Ti>@14A4@0TY:B0;^k^`1fMWH0FEUI04I6AP0203Xj>P0?03De=@0m?Cd0>c/k
03`l?00n?Sh0GemO059BDP1<C4`0ADE503dm?@1GEeL0PH6108>3P`1GEeL0>CTi0080>SXj0100?Shn
04i>CP1cLg<0RHV90:JVYP2XZ:P0YJFU09BDU01/K6`0CDe=055AD@1QHF40K6a/079bLP1WIfL0EEEE
0P10@4007@1=CDd0D51@059BDP1MGEd0OGem09ZJVP2EUID0T92@09:BTP2CTi<0`L710=OGe`3?cll0
ZZZZ09fMW@2/[:`0][Jf0<30`039bLT0_;bl0;Vi^@2QXJ40OWin05eMG@1GEeL0Bd];0410@00m?Cd0
@D510080?Shn3Oooool0013ooooo00l0BTY:04Q8B01<C4`0CDe=04I6AP19BDT0ATI604A4A01ADE40
B4Q804U9B@1;Bd/0A4A40410@014A4@00`16ATH204=3@`0404E5A@13@d<0CTi>04Q8B0<0A4A40P11
@D405014A4@0?clo0410@00n?Sh0BDU9051@D01BDU80FEUI05mOG`1[Jf/0KFe]04U9B@11@D40AdM7
04A4A018B4P0G5aL079bLP1JFUX0?clo0P12@T820410@0030492@P18B4P0ATI60080A4A401T0@D51
03hn?P0n?Sh0?Shn0451@@0m?Cd0?clo04=3@`12@T80?Shn0410@01_Kfl0WYjN0::RXP24Q8@0NWYj
06a/K01HF5P0EUIF04M7A`0j>SX0?Cdm03Ti>@0n?Sh0>CTi0080?3`l00T0@D5103`l?00m?Cd0?clo
03Xj>P0n?Sh0>CTi0410@011@D400P0o?cl05`0k>c/0@41003dm?@0i>CT0?3`l03lo?`0m?Cd0>c/k
03lo?`0l?3`0>CTi03Xj>P0n?Sh0?3`l04e=C@1;Bd/0A4A403/k>`0n?Sh0ATI60410@00k>c/0?Cdm
0080?clo00D0@T9203dm?@0o?cl0?clo0451@@0203`l?00B03hn?P11@D40>SXj03Xj>P0o?cl0>CTi
03Lg=`0k>c/0>CTi03De=@0n?Sh0A4A403hn?P0o?cl0BTY:04E5A@14A4@0?clo0P0m?Cd09`11@D40
>SXj0410@01BDU80DE5A05IFEP1PH600DE5A04m?C`0m?Cd0@41004M7A`0o?cl0>c/k03dm?@0l?3`0
>CTi03Xj>P0k>c/0Bd];05IFEP1OGel0AdM703`l?00m?Cd0>c/k03dm?@0k>c/0?Shn03`l?00k>c/0
?Cdm03`l?00m?Cd0>c/k03Xj>P0l?3`0?clo03dm?@0203`l?00?0410@011@D40?3`l03hn?P13@d<0
?Shn03lo?`0l?3`0>CTi03hn?P0m?Cd0?Shn03dm?@0j>SX0?Shn0080>c/k0100@41003hn?P0n?Sh0
>SXj03dm?@10@400?clo03dm?@11@D40?Shn03`l?00n?Sh0@D5103Ti>@0l?3`0?Cdm0P0j>SX0:00n
?Sh0>SXj03Xj>P0n?Sh0?3`l03lo?`10@400A4A403lo?`0n?Sh0@D510410@012@T80?Cdm03lo?`11
@D40>c/k0492@P16ATH0FEUI05=CD`13@d<0?3`l03Xj>P11@D40@T9204A4A00o?cl0?Shn03/k>`0l
?3`0?Shn0492@P1JFUX0HF5Q05=CD`1<C4`0DE5A0492@P1CDe<205iNGP0B05QHF016ATH0@d=30451
@@1>CTh0FUYJ06][J`27QhL0Rh^;08b<S02CTi<0V9RH092@T01hN7P0Lg=c07inOP2EUID0^k^k0P2l
_;`0402CTi<0KVi^07emO@2;Rh/0VIVI0<30`036a/H0`L710;6a/@2c/k<0aLG50=WIf@3QhN40gmoO
0=SHf03>c/h20;jn_P090<C4a02][Jd0_;bl0;jn_P3<c<`0e]KF0<k>cP2j^[X0SHf=0080LW9b01<0
M7Ad0820P027QhL0OGem07alO027QhL0[Jf]0:BTY02MWId0UYJF08B4Q01PH600?clo03`l?00o?cl0
@D510410@00j>SX0?Shn0080?3`l01H0?Shn03lo?`0m?Cd0?Shn04I6AP1`L700EeMG07IfMP2e]KD0
TY:B05IFEP1KFe/0HF5Q04I6AP0l?3`0=cLg03lo?`0l?3`0?Cdm03Xj>P0h>3P0>SXj0P0i>CT00`0e
=CD0>SXj03Xj>P0203hn?P0<03`l?00j>SX0>3Ph03Ph>011@D40DU9B075aL@1eMGD0DU9B04A4A00h
>3P0=cLg0`0h>3P0200j>SX0>3Ph03Xj>P0k>c/0?3`l03Hf=P0l?3`0>3Ph0P0j>SX04`0f=SH0?3`l
03Xj>P0i>CT0ADE507IfMP2_[jl0S8b<04Y:BP12@T80>SXj03hn?P0o?cl0@d=305mOG`1PH600?Cdm
04m?C`1<C4`00P10@4002`1ADE40Lg=c07moO`1UIFD0@41003Ti>@0h>3P0ATI6069RHP23Ph<0OWin
0080UiNG02d0MWIf06EUI@1QHF40JFUY069RHP1TI6@0Lg=c08Z:RP2DU9@0Shn?075aL@1>CTh0G5aL
08:2PP2=SHd0YjNW0;>c/`2m_Kd0_;bl0:>SX`2<S8`0L71`07]kN`2ZZZX0bLW90:BTY02ATI40Q8B4
09ZJVP2EUID0KFe]05IFEP1HF5P0EUIF04U9B@15ADD0?Shn0410@01>CTh0FUYJ061PH01]KFd0SHf=
09RHV02FUYH03Oooool0013ooooo00@0Bd];04I6AP19BDT0BDU90P18B4P01017AdL0BDU904e=C@16
ATH204E5A@0904=3@`15ADD0A4A403lo?`15ADD0AdM704I6AP12@T80@d=30080A4A400H0ADE50451
@@13@d<0@D510410@012@T820451@@80@T9200@0@D510492@P12@T80@4100P16ATH01@13@d<0A4A4
0410@012@T80@D510080?clo01d0AdM704Q8B014A4@0AdM704I6AP13@d<0?Shn04A4A010@400A4A4
04=3@`1;Bd/0C4a<04U9B@0n?Sh0@41003dm?@12@T80?Shn0410@00n?Sh0@T9205IFEP1dM7@0NWYj
06EUI@1=CDd0@4100451@@0303`l?00403dm?@0k>c/0?clo03`l?080>SXj00<0?Shn0410@00h>3P0
0P0m?Cd03`0h>3P0>CTi03/k>`0i>CT0?Shn03lo?`0n?Sh0?clo03dm?@0k>c/0?clo03hn?P0l?3`0
>c/k03Xj>P0203`l?00603/k>`11@D40HF5Q06EUI@0m?Cd0>CTi0P0l?3`0100j>SX0@41004=3@`10
@40203dm?@0703/k>`13@d<0DE5A04];B`1FEUH0CDe=03`l?0020451@@0403/k>`0i>CT0?Cdm03`l
?080>c/k01@0?clo03Ph>00i>CT0>SXj03hn?P14A4@0ATI604A4A018B4P0@D5103/k>`0j>SX0?Shn
03/k>`0l?3`0BTY:04a<C00o?cl0@41004E5A@80?Cdm00H0?3`l03/k>`0m?Cd0?3`l03/k>`0m?Cd2
03`l?00303dm?@0o?cl0@4100080?clo0`0l?3`03011@D40?Cdm03hn?P11@D40Bd];059BDP1<C4`0
@41003/k>`0o?cl0?Cdm03/k>`80>CTi00H0=cLg03dm?@0l?3`0?Cdm03Xj>P0o?cl204M7A`0K03hn
?P0i>CT0?3`l03Xj>P0n?Sh0>CTi03`l?00i>CT0>SXj03Ph>00m?Cd0?Shn03dm?@0n?Sh0?3`l03Ph
>00g=cL0?Cdm03/k>`0n?Sh0?3`l03Xj>P0i>CT0>SXj03/k>`0j>SX0?Cdm0080>SXj00h0>CTi03dm
?@0l?3`0@41003hn?P11@D40@T9203lo?`0l?3`0?Shn03/k>`0l?3`0>c/k03`l?080>c/k00<0>SXj
03Ph>010@4000P0m?Cd0200l?3`0@d=30410@011@D40>CTi03Xj>P0n?Sh0>c/k0P0l?3`0<`12@T80
A4A40492@P15ADD0?3`l03lo?`0n?Sh0@41004a<C017AdL0?3`l04E5A@1=CDd0IfMW07moO`2?Shl0
Vi^K09ZJVP24Q8@0MWIf06][J`1jNWX0UIFE09jNWP21PH40Ng]k07emO@1/K6`0KVi^07IfMP25QHD0
T92@09RHV02[Zj/0[Zj^09fMW@2a/K40[Zj^09fMW@2JVYX0/k>c0<?3``35aLD0`/;20=7Ad@3<c<`0
`l?30<o?c`3<c<`0Xj>S06m_K`0205iNGP0H05aLG01gMgL0UYJF0;:b/P3<c<`0cLg=0=7Ad@39bLT0
^[Zj0;Jf]P2][Jd0UYJF06=SH`1CDe<0Bd];03lo?`17AdL0A4A404E5A@13@d<0?clo04A4A010@400
?Shn0P10@400600m?Cd0?Shn0492@P1>CTh0JVYZ0:>SX`2XZ:P0MgMg09VIV@38b<P0eMGE0;Rh^02R
XZ80/;2`0:ZZZP1iNGT0AdM703`l?018B4P0?Cdm03`l?00i>CT0>SXj03Ph>080>SXj01d0?Cdm03Lg
=`0h>3P0>SXj03Ph>010@400EUIF065QH@1FEUH0Shn?07QhN01[Jf/0H61P03lo?`0i>CT0>3Ph03`l
?00j>SX0>CTi03Ph>00k>c/0?3`l03Lg=`0j>SX0=SHf03Xj>P0m?Cd0>CTi03/k>`0203Xj>P0I03hn
?P1NGUh0LW9b07MgM`21PH40Ng]k055AD@0j>SX0>c/k05EEE@1kNg/0FUYJ05UIF@1jNWX0HV9R03hn
?P0k>c/0>SXj03lo?`18B4P0De=C04=3@`0l?3`0>3Ph03Xj>P020410@00F065QH@1^KVh0GemO04i>
CP1FEUH0BTY:03Ti>@16ATH0KVi^08B4Q01kNg/0P82009>CT`2@T900IfMW04U9B@0k>c/0?clo05=C
D`1lO7`0QHF508Z:RP80VYZJ00D0NWYj05mOG`1IFET0L71`08f=S@020:ZZZP0D09RHV024Q8@0Ph>3
0820P01GEeL0GUiN06m_K`1`L700Lg=c08F5Q@2DU9@0UYJF09RHV02b/[80_Kfm0<30`035aLD0d];B
0=SHf03Cdm<=ooooo`004?ooool204U9B@0504Q8B017AdL0AdM704I6AP14A4@00`17AdL02P15ADD0
ATI604M7A`14A4@0@T9203lo?`13@d<0AdM704E5A@12@T8204=3@`0304A4A012@T80@T9200<0@D51
00L0?clo0451@@11@D40@d=304M7A`1?Cdl0C4a<0080?clo00@0@T9203lo?`0n?Sh0?Shn0P0o?cl0
8P10@400?clo04A4A013@d<0?clo04A4A013@d<0@41004=3@`12@T80DE5A06=SH`1[Jf/0H61P06MW
I`1^KVh0DU9B0451@@10@400?clo059BDP1QHF40PH6108:2PP1lO7`0MGEe055AD@19BDT0@D5103Xj
>P0m?Cd0?Shn0410@00o?cl203hn?P80>SXj0P0m?Cd0400g=cL0?3`l03/k>`0m?Cd0@T9203`l?00i
>CT0>SXj03lo?`0m?Cd0>c/k03hn?P0j>SX0@D5103/k>`0m?Cd203Xj>P0?03Ti>@0m?Cd0>c/k03/k
>`0m?Cd0BDU907]kN`25QHD0EeMG03lo?`0j>SX0?Cdm03Xj>P1<C4`0BDU90080AdM700H0C4a<079b
LP1SHf<0ATI604A4A010@40203hn?P0403/k>`0l?3`0>c/k03Xj>P80?3`l0P0n?Sh07P0k>c/0?3`l
03Ti>@0k>c/0@D510410@014A4@0@T920410@00h>3P0?3`l03/k>`0i>CT0>SXj03Ti>@0m?Cd0?Shn
0410@011@D40@4100492@P11@D40?clo03`l?00j>SX0>c/k03Xj>P0m?Cd0@D5104A4A080?Cdm02L0
?3`l0410@013@d<0@T920410@00o?cl0?3`l03Xj>P0l?3`0?Cdm03lo?`19BDT0AdM704A4A00m?Cd0
@41004=3@`11@D40@41003dm?@1;Bd/0HV9R05eMG@17AdL0BTY:04m?C`1DE5@0Bd];03lo?`0n?Sh0
>c/k03Ti>@0k>c/0@D5103lo?`0m?Cd0?3`l03dm?@0n?Sh00P0l?3`0500i>CT0?Cdm03dm?@0j>SX0
>3Ph04A4A011@D40?Shn03/k>`0m?Cd0>SXj03/k>`10@400?Cdm03Ph>00j>SX0>c/k03lo?`0n?Sh0
?3`l0P0o?cl203`l?00E0410@011@D40@41003Xj>P0o?cl0>c/k03Xj>P0m?Cd0@D5103Ti>@0h>3P0
?clo03dm?@0j>SX0?Shn03/k>`0n?Sh0>c/k03Ti>@0j>SX0>CTi0080@d=300d0?Cdm0451@@0f=SH0
>CTi03/k>`0l?3`0A4A404E5A@0n?Sh0A4A404];B`1HF5P0J6QX0080JVYZ00/0IfMW05mOG`1IFET0
C4a<04];B`1<C4`0Hf=S08>3P`2@T900P82006QXJ002069RHP10061PH01QHF40MWIf08n?S`2NWYh0
][Jf0<K6aP2b/[80UYJF09>CT`2>SXh0PH61079bLP1hN7P0Ti>C0:2PX02a/K40`L710<c<c03>c/h0
b<S80<O7a`2g]kL0];Bd0;Fe]@30`<00ZJVY0::RXP2UYJD0TI6A09bLW02NWYh0TY:B07inOP27QhL0
X:2P09ZJVP1hN7P0IFEU06e]K@1cLg<0R8R807QhN01CDe<0Cdm?06a/K02HV9P0UiNG08^;R`1jNWX0
K6a/07emO@1jNWX0TY:B0:VYZ@3:b/X0gMgM0<O7a`28R8P0GemO06QXJ01iNGT0NWYj069RHP80Bd];
01l0@d=303hn?P0n?Sh0=CDe03/k>`0n?Sh0>CTi03Ph>00k>c/0>SXj03/k>`0l?3`0>c/k04=3@`1=
CDd0H61P04=3@`1;Bd/0NGUi08n?S`2HV9P0][Jf0:NWY`1ZJVX0?clo03Ph>00k>c/0?Cdm03Hf=P0e
=CD0>3Ph00<0>SXj00D0>CTi03Xj>P0g=cL0>CTi03/k>`0203Xj>P0C03Ph>00n?Sh0N7Qh09RHV01^
KVh0ATI60492@P0l?3`0>CTi03Xj>P0l?3`0FEUI04E5A@0j>SX0<c<c03Lg=`0e=CD0=cLg03dm?@02
03hn?P0303/k>`0j>SX0=SHf0080>SXj00D0?Shn04A4A015ADD0?3`l03Ti>@0203`l?00_03/k>`1@
D500Jf][06m_K`1mOGd0J6QX04U9B@1:BTX0C4a<0451@@0i>CT0@41005QHF01eMGD0WIfM09^KV`1W
IfL0Bd];0451@@10@400A4A405iNGP2BTY80][Jf0;Bd]02c/k<0QXJ607AdM01_Kfl0J6QX06ATI01g
MgL0UYJF0:RXZ02LW9`0WinO0:j^[P32`/80`L710;bl_02b/[80]KFe0<S8b039bLT0`<300<?3``2b
/[803Oooool0013ooooo0P1:BTX01@19BDT0ATI604Q8B015ADD0A4A40080BDU90P17AdL01@1;Bd/0
ADE504=3@`11@D40@T920080@d=300D0ATI604M7A`14A4@0@d=30451@@020492@P0603lo?`15ADD0
B4Q80492@P14A4@0ADE50P12@T80100o?cl0@4100492@P10@40303lo?`090410@00o?cl0?clo0451
@@15ADD0@d=304A4A010@400A4A40080?Shn0180@T920410@013@d<0B4Q804A4A016ATH0Bd];04Q8
B00o?cl0?Shn04A4A01GEeL0U9BD092@T027QhL0KVi^04i>CP11@D420492@P80@41001L0Bd];05YJ
FP18B4P0EUIF04e=C@13@d<0?Shn03Ti>@0l?3`0@4100451@@0k>c/0?Cdm03Ti>@0m?Cd0@41003Xj
>P0k>c/0@41003dm?@0j>SX0?Cdm03hn?P0203lo?`80>SXj00l0>c/k03hn?P0m?Cd0@D5103`l?013
@d<0C4a<04];B`12@T80?Shn03`l?00n?Sh0>CTi0410@00k>c/00P0m?Cd04`10@400ATI604Y:BP0m
?Cd0?Shn03`l?00m?Cd0>3Ph03`l?00m?Cd0>c/k03hn?P0m?Cd0AdM704E5A@11@D40@41003/k>`0l
?3`00P15ADD0501<C4`0AdM70492@P0m?Cd0?3`l03Ph>00k>c/0>SXj04=3@`0n?Sh0>CTi03dm?@0g
=cL0@41003/k>`0o?cl0?Cdm03hn?P0j>SX0?Shn0P11@D404010@400@D5103dm?@11@D40?clo0492
@P10@400>c/k03lo?`0n?Sh0@4100492@P11@D40?Cdm03lo?`0m?Cd203hn?P0<03`l?010@400A4A4
04i>CP1HF5P0Lg=c0820P023Ph<0QhN708R8R01WIfL0C4a<0P1;Bd/03010@400?Cdm03`l?00i>CT0
?3`l04=3@`18B4P0C4a<04Q8B010@400@T9204=3@`80?clo00`0@D5103lo?`10@400@T9203Xj>P0n
?Sh0@D5103lo?`0l?3`0>c/k03Ph>00l?3`203Xj>P0<0410@00i>CT0>CTi03Ti>@0n?Sh0?Cdm03lo
?`0n?Sh0?Cdm03Xj>P0k>c/0?clo0P10@40203hn?P0403Ti>@0f=SH0?Shn03hn?P80@4100P0l?3`2
03Xj>P0503`l?012@T80?clo03/k>`0m?Cd00P11@D40300i>CT0?Cdm03lo?`0l?3`0>CTi03Xj>P0k
>c/0?Shn0410@015ADD0AdM704=3@`80?clo00<0?Shn0451@@11@D400P0o?cl03015ADD0B4Q804m?
C`1PH600I6AT05iNGP1ADE40@D5103lo?`11@D40@d=3059BDP80Hf=S0540MGEe08V9R@2<S8`0P820
07IfMP1QHF40FUYJ04e=C@1HF5P0OGem092@T02VYZH0[Zj^0:FUY@2QXJ40X:2P09fMW@2FUYH0XZ:R
0;:b/P2c/k<0[jn_0:>SX`2ZZZX0/k>c0;2`/02HV9P0Ng]k07IfMP2JVYX0ZZZZ0:>SX`2YZJT0YZJV
0;Jf]P38b<P0eMGE0=[JfP3?cll0Z:RX0:>SX`3EeMD0f][J0>7Qh@3Ogml0clo?0<G5a@3:b/X0`L71
0=7Ad@3IfMT0iNGU0=kNgP33`l<0XJ6Q08N7Q`1/K6`0G5aL04i>CP0o?cl0?3`l0451@@0n?Sh0>c/k
0451@@0l?3`0@D510492@P11@D40?clo03hn?P16ATH0F5QH05MGE`1NGUh0TI6A0:j^[P29RHT0D51@
075aL@2NWYh00P2YZJT02@2RXZ80OGem04I6AP0m?Cd0>c/k03Ph>00l?3`0?Shn03`l?00203/k>`04
03Xj>P0i>CT0>c/k03Xj>P80>CTi00P0>c/k03dm?@0i>CT0?Shn04A4A01FEUH0Hf=S04];B`80>3Ph
00D0>SXj03dm?@0j>SX0>SXj03Ti>@0203`l?00503/k>`0i>CT0?3`l03Xj>P0m?Cd00P0i>CT0400e
=CD0?clo03/k>`11@D40?Shn03Lg=`0i>CT0>3Ph03Ti>@0h>3P0?3`l05eMG@1UIFD0MgMg05UIF@13
@d<203Xj>P0P03`l?00d=3@0>SXj04a<C01XJ6P0SHf=08R8R01RHV80CDe=0451@@0e=CD0C4a<06a/
K028R8P0QXJ607alO021PH40IVIV055AD@18B4P0A4A406UYJ@2@T900Zj^[0;6a/@2i^KT0a<C40=?C
d`3<c<`0_;bl0;6a/@2SXj<209bLW0070:6QX@2TY:@0V9RH079bLP1JFUX0BTY:04I6AP0=ooooo`00
4?ooool0201=CDd0BTY:04];B`17AdL0ATI604Q8B01>CTh0BDU90P17AdL04P19BDT0B4Q804Q8B019
BDT0ADE504I6AP14A4@0BTY:04U9B@14A4@0@d=30492@P13@d<0A4A404M7A`13@d<0@T9204A4A080
@4100P0o?cl02P11@D40?Shn03hn?P12@T80A4A40410@00m?Cd0?3`l0492@P14A4@20451@@0604E5
A@11@D40@d=30492@P10@400?clo0P0m?Cd01@0o?cl0AdM704A4A01<C4`0B4Q80080@d=300T0@D51
0410@012@T80@D5104Q8B012@T80A4A403lo?`0n?Sh00P0k>c/0200n?Sh0@D5103lo?`12@T80?Shn
0492@P15ADD0AdM70P11@D402@0k>c/0@d=305eMG@1`L700I6AT03`l?00o?cl0?3`l03dm?@0203/k
>`0:03dm?@0i>CT0?Cdm03lo?`0n?Sh0A4A40451@@0o?cl0A4A403`l?080>SXj01@0ADE505=CD`1B
DU80?Shn03/k>`0m?Cd0@D5103`l?010@400?3`l03/k>`0i>CT0@41003hn?P0k>c/0?Shn04=3@`0n
?Sh0?Cdm0451@@80?Shn01@0>CTi03/k>`0m?Cd0?Cdm03Ph>012@T80>c/k03`l?013@d<0DU9B05iN
GP1TI6@0C4a<04Q8B010@400?Cdm03`l?00n?Sh0@D5103/k>`80@T9200H0?Cdm04I6AP1ADE40BDU9
0451@@0n?Sh203`l?00803lo?`0j>SX0?Shn03`l?00m?Cd0?3`l0451@@0o?cl203/k>`0:03lo?`14
A4@0?Cdm03dm?@0g=cL0?3`l03dm?@0l?3`0@41003Xj>P80?Shn01L0?Cdm04E5A@15ADD0C4a<055A
D@1=CDd0FEUI06m_K`1/K6`0DE5A04];B`11@D40?Shn03Xj>P0m?Cd0>c/k0410@013@d<0AdM704i>
CP1DE5@0C4a<04A4A00203`l?00304A4A010@400?3`l0080@D5100D0@4100492@P14A4@0CDe=04I6
AP0203lo?`80>c/k00H0?Cdm0492@P0m?Cd0>c/k03`l?00n?Sh203Ti>@80>SXj00P0@d=303hn?P0j
>SX0?Cdm03hn?P0k>c/0?Shn0410@080>SXj00T0=cLg03`l?01CDe<0?Shn03dm?@0n?Sh0>SXj03hn
?P0j>SX00P0l?3`00`14A4@0CDe=03dm?@0403/k>`0803dm?@0o?cl0?Cdm03dm?@11@D40ADE504i>
CP16ATH203dm?@0;03lo?`0k>c/0?3`l03hn?P0k>c/0?Cdm04I6AP1=CDd0ATI603Xj>P10@4000P13
@d<02@10@400@T9203Ti>@0o?cl0@D5104U9B@1=CDd0@d=304Y:BP0205ADE01P04Y:BP11@D40?Cdm
0451@@1CDe<0PX:20:>SX`2/[:`0QhN706UYJ@1HF5P0D51@05]KF`1IFET0FUYJ051@D01TI6@0OGem
07AdM01iNGT0UIFE0:VYZ@33`l<0/;2`0;Bd]02h^;P0]kNg0<G5a@3:b/X0^[Zj0;jn_P38b<P0bLW9
0<[:bP35aLD0b/[:0<?3``2c/k<0`<300=;BdP38b<P0dM7A0=GEe@3:b/X0[Jf]09JFUP2<S8`0TY:B
09jNWP30`<00emOG0<_;b`2k^k/0[Zj^0:ZZZP2RXZ80S8b<05]KF`1?Cdl0De=C05MGE`1HF5P0HF5Q
07moO`2CTi<0YZJV0::RXP29RHT0Vi^K0<30`03Hf=P0bLW90=CDe03Hf=P0`/;20:2PX01mOGd0Q8B4
08>3P`1MGEd0BTY:0451@@0l?3`0?clo04Q8B01CDe<0NGUi08j>SP1EEED0?clo03dm?@0j>SX0?3`l
03Xj>P0k>c/0>SXj0P0l?3`01`0k>c/0>CTi04i>CP1gMgL0KFe]04U9B@15ADD00P0l?3`0100m?Cd0
>SXj03`l?00i>CT203`l?00403Ph>00g=cL0=SHf03Xj>P<0=cLg00@0>SXj03/k>`1:BTX0CDe=0P0h
>3P07@0l?3`0=SHf03Hf=P0l?3`0=SHf0451@@10@400ATI604=3@`11@D40?3`l03Lg=`0h>3P0=SHf
0492@P1DE5@0Ogmo0:VYZ@2WYjL0LG5a0492@P0i>CT0>3Ph03Ti>@1DE5@0/k>c0:b/[01cLg<0ADE5
0080?Cdm01P0>c/k03`l?01RHV80W9bL0<S8b030`<00OGem06UYJ@2DU9@0bl_;0=;BdP34a<@0ZZZZ
0;2`/02JVYX0NGUi07emO@29RHT0KFe]05QHF01OGel0LG5a0820P024Q8@=ooooo`004?ooool00`1=
CDd0BTY:04];B`0204Q8B00<04Y:BP15ADD0ATI604E5A@17AdL0A4A404Y:BP1<C4`0ATI604A4A015
ADD0@d=30P16ATH03P12@T80@D510451@@13@d<0@D5104A4A010@400@T920451@@0n?Sh0?clo0410
@00l?3`0?Cdm0`12@T807`0k>c/0@D5104=3@`0l?3`0@41003lo?`10@400?Cdm0492@P0o?cl0@D51
03hn?P12@T80>c/k04=3@`15ADD0?clo04=3@`0o?cl0A4A403dm?@10@400?Shn03`l?011@D40?3`l
03dm?@13@d<0@T9203hn?P10@4000P14A4@02012@T80@D5103hn?P0k>c/0@D5103`l?00n?Sh0>SXj
0`10@400:P0n?Sh0?Cdm0410@014A4@0Bd];04E5A@19BDT0?Shn03Ti>@0n?Sh0?3`l03/k>`0o?cl0
>CTi03Xj>P0l?3`0@41004a<C01DE5@0KFe]04I6AP0m?Cd0>c/k04I6AP1IFET0ADE503Xj>P0h>3P0
>SXj0451@@0m?Cd0?Shn0492@P11@D40?Shn0410@00l?3`0@D5103/k>`0j>SX0@41004Q8B080@T92
02X0?clo03Hf=P0i>CT0>CTi03dm?@0h>3P0>CTi03dm?@17AdL0DE5A05EEE@1BDU80@d=303/k>`10
@400?Cdm03/k>`11@D40>SXj03Ti>@12@T80Cdm?06UYJ@1ZJVX0N7Qh05iNGP18B4P0Bd];0492@P11
@D40?Shn03lo?`0n?Sh0>c/k03`l?01<C4`0D51@04E5A@18B4P0ATI604M7A`0n?Sh203/k>`0>03lo
?`0i>CT0?Shn03`l?016ATH0Cdm?04A4A00k>c/0@D5103Ph>00k>c/0B4Q804M7A`0k>c/20410@00D
04e=C@1DE5@0>3Ph03lo?`13@d<0>c/k03Xj>P0k>c/0?3`l0410@014A4@0B4Q803lo?`0h>3P0?clo
03/k>`10@400@D5104Q8B00o?cl203`l?080?Shn00H0A4A404e=C@12@T80ATI603lo?`12@T8203dm
?@80?Shn00X0?3`l03dm?@0n?Sh0?Cdm03`l?00n?Sh0>CTi03/k>`0l?3`0>SXj0P0m?Cd0400j>SX0
?3`l03`l?00n?Sh0?3`l03dm?@18B4P0DU9B04U9B@0l?3`0>3Ph03hn?P0m?Cd0@D510410@00i>CT2
03Xj>P0403dm?@15ADD0@D5103`l?080>CTi00H0>c/k03`l?00j>SX0ATI604=3@`0o?cl203hn?P04
03Ph>00i>CT0=SHf03/k>`80>3Ph0140AdM704=3@`1:BTX0ADE504A4A00g=cL0?Cdm04E5A@0n?Sh0
?3`l03Xj>P0n?Sh0B4Q804A4A00m?Cd0@41003`l?00203hn?P0P03Xj>P0k>c/0>3Ph04a<C01]KFd0
UYJF0:2PX02CTi<0QXJ6065QH@14A4@0@41004E5A@1:BTX0@D5104a<C01KFe/0KVi^08R8R026QXH0
OGem09jNWP2WYjL0X:2P09NGU`2KVi/0VYZJ09bLW02h^;P0a<C40:RXZ02d];@20<;2`P0O0;jn_P3=
cLd0e=CD0;Vi^@31`L40a/K60=CDe033`l<0aLG50=GEe@3:b/X0WIfM08Z:RP2QXJ40`l?309nOW`2?
Shl0XJ6Q0=KFeP33`l<0]kNg0<71`@37alL0][Jf09ZJVP2?Shl0/;2`0<_;b`35aLD0d];B0=gMg@02
0>CTi00L0>OWi`3GemL0h>3P0>SXj03Rh^80eMGE0=_Kf`3De=@0_kno08n?S`1mOGd0M7Ad06=SH`1F
EUH0Bd];055AD@1QHF40P82009ZJVP2QXJ40^k^k0:>SX`1YJFT0KVi^06YZJP1QHF40EUIF0410@080
?clo00`0C4a<06UYJ@1OGel0ATI608R8R02GUiL0De=C0451@@0h>3P0=cLg03`l?00j>SX203dm?@05
03Lg=`0k>c/0>CTi03/k>`0g=cL00P0m?Cd0@00k>c/0?3`l03Xj>P1:BTX0GEeM059BDP0o?cl0=SHf
03Ph>00d=3@0=cLg03Ti>@0j>SX0>3Ph03/k>`0i>CT0=SHf038b<P0h>3P0<c<c03Ti>@0e=CD0Bd];
08J6QP2ATI40R8R806i^KP1:BTX0?Shn03@d=00i>CT0=SHf03dm?@2;Rh/0X:2P05EEE@0l?3`0=SHf
03`l?00m?Cd0D51@08>3P`2k^k/0bl_;09>CT`1/K6`0ADE507=cL`2SXj<0b<S80;fm_@2[Zj/0UiNG
08^;R`2GUiL0WIfM0:JVYP2SXj<0QHF508V9R@2ZZZX0`/;20<S8b03;bl/=ooooo`004?ooool0401=
CDd0BTY:04];B`18B4P0AdM704Y:BP15ADD0ATI604A4A019BDT0AdM704E5A@16ATH0@d=304E5A@16
ATH204A4A0<0@d=300/0?Cdm04A4A013@d<0@T920410@00n?Sh0@4100451@@13@d<0@D510492@P02
03dm?@0<03hn?P0o?cl0>SXj03`l?010@400?Cdm0492@P10@400@D5103hn?P11@D40?3`l0P15ADD0
1`11@D40@T9204=3@`15ADD0@41003`l?00o?cl00P11@D40200j>SX0@4100451@@0l?3`0@41004=3
@`0m?Cd0?3`l0P0o?cl01P0n?Sh0?clo0410@010@400?clo03/k>`<0?Cdm00`0?Shn03lo?`0o?cl0
?clo03hn?P0o?cl0?3`l03hn?P0j>SX0>c/k0492@P1:BTX204Q8B00X04U9B@10@400?3`l03Xj>P1D
E5@0LG5a07EeM@1SHf<0ADE504A4A00i>CT0>c/k03dm?@0o?cl0?Shn04=3@`10@400>SXj03`l?01?
Cdl0A4A403`l?00k>c/0@D5103hn?P0i>CT0>c/k0451@@0i>CT0?Cdm0492@P10@400?Shn03Xj>P14
A4@0@41004E5A@11@D40>SXj03`l?080@41000D0@d=304A4A010@400?Cdm03hn?P0203dm?@0?04=3
@`12@T80CDe=06EUI@1SHf<0EUIF06i^KP2LW9`0UYJF07IfMP1:BTX0EUIF06e]K@1EEED0@4100080
?Cdm00T0>c/k03dm?@0o?cl0ADE504U9B@14A4@0D51@04a<C017AdL00P11@D402@0o?cl0BTY:04i>
CP1JFUX0KVi^06=SH`1@D500@D510410@00203hn?P040410@01=CDd0?clo03`l?080@D5100P0>CTi
0410@010@400?clo03/k>`0n?Sh0>c/k03dm?@<0?Shn00<0?Cdm03Xj>P0l?3`00P10@40203dm?@05
04A4A011@D40?clo03`l?015ADD00P11@D404@12@T80?clo03dm?@12@T80@d=303dm?@11@D40B4Q8
03hn?P0m?Cd0>SXj0410@013@d<0@D5103hn?P0k>c/0?3`l0080>c/k0P0m?Cd203hn?P0C03lo?`15
ADD0ADE504M7A`14A4@0@4100451@@0o?cl0>c/k03Ph>00l?3`0@T9203lo?`0i>CT0>c/k03`l?00n
?Sh0?Cdm03hn?P0203/k>`0403Xj>P0k>c/0>c/k03Xj>P80?Shn01P0?Cdm03`l?00l?3`0>3Ph03Xj
>P0n?Sh0@D5104=3@`16ATH0DE5A051@D012@T80@41003lo?`0k>c/0>CTi03/k>`0i>CT0?Cdm03`l
?010@400?Shn03`l?00k>c/20410@00<03Ph>00n?Sh0?Cdm03dm?@1>CTh0SXj>08f=S@1eMGD0H61P
04];B`18B4P0@T920`0o?cl06`1>CTh0DE5A05IFEP1TI6@0MGEe09^KV`2JVYX0P82008J6QP1kNg/0
L71`075aL@1lO7`0Q8B40:2PX02KVi/0UiNG09JFUP2KVi/0XZ:R0:j^[P2/[:`0/K6a0;2`/02TY:@0
/k>c0<O7a`020=GEe@0=0=SHf03Ng]h0emOG0<K6aP2n_[h0d=3@0>KViP3Ng]h0bLW90<71`@3Fe]H0
e=CD0=_Kf`020=oOg`0:0<?3``2b/[80];Bd0<?3``3AdM40c/k>0=;BdP3Hf=P0hN7Q0>;RhP80h>3P
00T0g]kN0<S8b02OWil0Ph>308V9R@23Ph<0Ogmo08^;R`1kNg/00P1/K6`07@27QhL0QXJ6092@T02_
[jl0]KFe0;Rh^01oOgl0J6QX06e]K@1dM7@0SHf=0::RXP2`/;00VIVI07UiN@24Q8@0XJ6Q0;jn_P37
alL0_[jn0820P023Ph<0LG5a04m?C`1;Bd/0AdM703lo?`0m?Cd0>SXj0080>c/k00l0?3`l03Xj>P0k
>c/0>c/k0492@P1BDU80CDe=04=3@`0o?cl0GEeM05aLG016ATH0?3`l03Xj>P0h>3P00P0l?3`02015
ADD0?Cdm03Ph>00g=cL0?3`l03Ph>00j>SX0>3Ph0P0e=CD0600g=cL0GEeM096AT@24Q8@0GemO04Q8
B00j>SX0=cLg03Xj>P0k>c/0BDU907UiN@1WIfL0EeMG04U9B@0h>3P0>SXj0451@@1BDU80QhN70:BT
Y02WYjL0R8R8061PH080@T920180E5AD08n?S`2g]kL0/k>c08V9R@1bLW80LG5a0:JVYP2o_kl0W9bL
08J6QP1hN7P0Lg=c096AT@2f][H0_kno0;^k^`2n_[h=ooooo`004?ooool01`1<C4`0Bd];04U9B@18
B4P0ATI604U9B@17AdL00P15ADD00`13@d<0ATI604I6AP0404=3@`030492@P11@D40@D510080A4A4
00X0@41004A4A013@d<0@d=30410@00l?3`0?Shn0410@011@D40?3`l0`10@400200n?Sh0?Cdm03lo
?`0o?cl0@D5103lo?`10@400A4A40P13@d<02P12@T80?clo0451@@14A4@0ADE504A4A012@T80ADE5
03lo?`13@d<20410@00:03hn?P10@400?3`l03lo?`11@D40@41003lo?`12@T80?Cdm0410@080A4A4
0P0o?cl203hn?P070451@@10@400?3`l03lo?`0l?3`0>c/k03Xj>P020410@00`0451@@14A4@0@T92
03`l?00n?Sh0AdM704e=C@1DE5@0FUYJ051@D017AdL0@T920451@@14A4@0CTi>04I6AP0l?3`0?Shn
04=3@`18B4P0CTi>05IFEP11@D40@T92055AD@1?Cdl0ATI60451@@1CDe<0Hf=S06IVIP1CDe<0EEEE
0451@@0k>c/0@41004M7A`1MGEd0C4a<0410@00n?Sh0@d=304M7A`1=CDd0EEEE04e=C@11@D40A4A4
0`12@T801P0l?3`0>SXj03Ti>@0n?Sh0ADE504A4A080DE5A01<0ATI604Q8B01DE5@0D51@04I6AP12
@T80B4Q804E5A@14A4@0@T9204E5A@1ADE40@T9203hn?P0i>CT0?3`l0410@00n?Sh0@T920080@410
00<0B4Q804M7A`1:BTX00P10@4001P14A4@0B4Q804i>CP1IFET0GUiN05EEE@80ADE500H0ATI603lo
?`11@D40@T9203dm?@13@d<303hn?P0903/k>`0n?Sh0>c/k03lo?`0l?3`0@d=304I6AP13@d<0@410
00<0?Shn00<0?3`l03/k>`0j>SX00P0m?Cd0200o?cl0>CTi0410@011@D40BDU904I6AP10@400?3`l
0P10@4001`0n?Sh0>c/k03`l?011@D40?Shn04=3@`15ADD00P0m?Cd02@16ATH0FEUI04I6AP0m?Cd0
?clo0410@00o?cl0>c/k0410@0020451@@0G03lo?`15ADD0EEEE05YJFP19BDT0?Shn0410@00n?Sh0
?clo03dm?@0k>c/0=cLg03dm?@10@400?3`l03Ti>@0h>3P0>SXj03`l?00j>SX0?Shn0410@012@T80
0P0l?3`07@0k>c/0>SXj03hn?P0i>CT0>3Ph03Xj>P0k>c/0>CTi03Hf=P0m?Cd0FUYJ06IVIP1>CTh0
A4A40451@@0k>c/0?Cdm03Ph>00m?Cd0>CTi03dm?@0l?3`0>c/k03lo?`0n?Sh0?Cdm03`l?00k>c/0
=SHf0080?Cdm00l0>CTi03lo?`1BDU80Ph>307IfMP1:BTX0@d=303/k>`0n?Sh0>SXj03hn?P1<C4`0
Cdm?05YJFP1XJ6P00P1VIVH0L01KFe/0BTY:05QHF017AdL0@41004I6AP1JFUX0K6a/07AdM021PH40
S8b<08V9R@1gMgL0N7Qh08>3P`29RHT0Ti>C092@T028R8P0WYjN09nOW`2[Zj/0`<300<k>cP38b<P0
_;bl0;Bd]02l_;`0c<c<0=;BdP3Hf=P0f][J0=?Cd`3IfMT0f][J0=7Ad@39bLT0a<C40<K6aP37alL0
`/;20;no_`37alL0`L710<O7a`3MgMd0g=cL0=3@d03<c<`0c/k>0<W9b@2j^[X0`l?30=7Ad@2_[jl0
R8R807QhN01iNGT0QhN70:VYZ@32`/80alO70;Jf]P2LW9`0R8R808>3P`2KVi/0/[:b0:FUY@2?Shl0
Lg=c09FEU@2h^;P0bLW90=7Ad@3Fe]H0hn?S0>KViP3Ng]h0d];B0;Zj^P2TY:@0W9bL0:ZZZP2l_;`0
_Kfm0:n_[`1mOGd0Fe]K04e=C@1<C4`0CTi>04M7A`10@400?3`l03dm?@0n?Sh0?clo06YZJP2/[:`0
S8b<05MGE`0k>c/0@d=3055AD@0o?cl0>c/k03`l?00k>c/0FUYJ061PH00k>c/203Ti>@0Z03Hf=P0i
>CT0>SXj03Hf=P0e=CD0>CTi03Hf=P0h>3P0Bd];08b<S029RHT0D51@03Hf=P0g=cL0>3Ph03dm?@1;
Bd/0OWin0861P@1[Jf/0@T9203Ti>@0j>SX0>3Ph03lo?`23Ph<0[jn_08J6QP1ZJVX0GUiN04a<C00m
?Cd0Bd];079bLP2GUiL0][Jf08j>SP1VIVH0IFEU08B4Q02XZ:P0^k^k0P31`L40202o_kl0Y:BT0:6Q
X@2QXJ40ZZZZ0:f][@2[Zj/0[jn_3Oooool0013ooooo0P1:BTX304M7A`0304U9B@1:BTX0AdM70080
@d=300L0ATI604E5A@11@D40@T920451@@13@d<0ADE50080@d=300H0@T920451@@14A4@0BDU90451
@@0o?cl30410@00=04=3@`11@D40@41003lo?`11@D40?Shn0492@P13@d<0@T9203dm?@0n?Sh0>SXj
03/k>`020492@P0>0410@012@T80@4100492@P13@d<0ADE504I6AP14A4@0ADE50492@P11@D40?clo
0492@P11@D420410@00D03lo?`0n?Sh0?clo0492@P0n?Sh0@D5104=3@`12@T80?Cdm03`l?00n?Sh0
@D5104Q8B019BDT0@d=304E5A@1ADE40A4A403hn?P11@D4204a<C00?05=CD`1>CTh0?Shn03lo?`13
@d<0@D5104M7A`1<C4`0ADE50410@011@D40?Shn0410@00l?3`0?Cdm0080>c/k00L0?Shn03`l?012
@T80?Shn03dm?@0k>c/0>CTi0080>c/k01h0>CTi04E5A@1OGel0OWin07IfMP1VIVH0KFe]04Y:BP0o
?cl0?Cdm0451@@1PH600CDe=03lo?`11@D40Bd];05iNGP1[Jf/0M7Ad07MgM`1;Bd/0?clo04=3@`1_
Kfl0KFe]06i^KP1TI6@0AdM703`l?016ATH204A4A00<04I6AP1:BTX0Q8B40;6a/@2XZ:P0SHf=06a/
K01UIFD0BDU904=3@`10@400?clo0P0n?Sh0:011@D40DU9B06m_K`1cLg<0PH6109>CT`2YZJT0QhN7
07]kN`1ZJVX0FEUI04E5A@0l?3`0@41003`l?00n?Sh0?3`l03dm?@0k>c/0?clo04];B`18B4P0?clo
0451@@15ADD0@T9203Ti>@0n?Sh0>c/k0410@013@d<0HF5Q06UYJ@1WIfL0Lg=c05]KF`1BDU80@D51
03dm?@0o?cl203dm?@0G0451@@0m?Cd0?clo0492@P0m?Cd0?clo03hn?P1EEED0GemO05MGE`0n?Sh0
>c/k03dm?@0l?3`0@D5103hn?P0l?3`0@T9204A4A011@D40@41003/k>`11@D400P0m?Cd06P0j>SX0
=cLg03/k>`0m?Cd0A4A40492@P19BDT0G5aL059BDP17AdL0ADE50410@012@T80?clo03`l?011@D40
?Cdm0410@00n?Sh0?clo0451@@13@d<0>CTi03Xj>P0h>3P0?3`l0P0h>3P02P0j>SX0?clo04I6AP1F
EUH0@T9203hn?P0l?3`0>SXj03/k>`10@40203Xj>P1303lo?`0k>c/0AdM70451@@14A4@0Cdm?04=3
@`11@D40@41003dm?@0k>c/0?Shn03`l?00m?Cd0>3Ph03Ti>@0k>c/0?Cdm0451@@0i>CT0?Shn03Ti
>@0m?Cd0>SXj03Ph>00k>c/0Bd];06QXJ01`L700EEEE0492@P0l?3`0@41004I6AP1@D500G5aL059B
DP1>CTh0AdM704U9B@18B4P0ATI604A4A015ADD0BDU904A4A01:BTX0JVYZ096AT@2PX:00RXZ:05eM
G@1CDe<0Hf=S08b<S02;Rh/0Q8B406i^KP1`L700J6QX06m_K`27QhL0TY:B09nOW`2VYZH0XJ6Q09BD
U0020861P@0a08R8R02TY:@0^;Rh0<71`@38b<P0d=3@0=SHf03Jf]X0emOG0<W9b@2n_[h0YjNW08^;
R`2<S8`0UiNG0;Fe]@3Bd]80dm?C0<G5a@3@d=00dm?C0<[:bP3@d=00bLW90<;2`P2YZJT0clo?0=OG
e`3:b/X0[Jf]09ZJVP2PX:00a<C40=OGe`3Kfm/0hn?S0=WIf@3Jf]X0dM7A0<S8b03Bd]80dm?C0;Zj
^P2QXJ40UiNG0:j^[P39bLT0bl_;0=?Cd`020=;BdP0O0<k>cP2i^KT0RHV905eMG@1VIVH0MgMg09ZJ
VP2EUID0QhN709:BTP2OWil0Zj^[0:6QX@2PX:00UiNG07EeM@1;Bd/0ATI6061PH02EUID0[Zj^0<30
`02`/;00SXj>075aL@1JFUX0?Shn03`l?00n?Sh0?3`l03Ph>00203`l?00503dm?@0i>CT0@T9203Ti
>@0h>3P00P0g=cL0<@0h>3P0>c/k03Ti>@0m?Cd0>c/k03`l?017AdL0@D5103Lg=`0j>SX0>CTi0492
@P1_Kfl0V9RH08J6QP19BDT0>c/k03Hf=P0h>3P0?3`l0451@@1^KVh0X:2P05mOG`0n?Sh0ADE50451
@@0n?Sh0C4a<069RHP1lO7`0T92@079bLP1BDU80Jf][07IfMP2FUYH0^KVi0<G5a@2e]KD0];Bd0:VY
Z@2`/;00X:2P07alO024Q8@0SXj>08b<S020P8003Oooool0013ooooo0P1:BTX00`17AdL0B4Q804E5
A@0204Q8B00504I6AP15ADD0@d=304=3@`17AdL00P15ADD01@14A4@0@D5104M7A`16ATH0A4A400@0
@T9200<0@D5103lo?`13@d<00P10@4002013@d<0?clo0451@@0l?3`0@D5103lo?`12@T80@4100P0n
?Sh03`0m?Cd0>SXj0451@@0n?Sh0@41003dm?@0o?cl0A4A40451@@12@T80ADE50451@@0o?cl0?3`l
0410@00203lo?`0K03`l?010@400?Cdm0492@P0l?3`0>c/k03lo?`0m?Cd0@D510492@P0o?cl0@410
03hn?P0l?3`0?Cdm03/k>`0n?Sh0@D5103lo?`0n?Sh0@D510410@00o?cl0BDU9059BDP11@D40?clo
0080?3`l00D0?Cdm0410@00o?cl0?3`l03dm?@0203hn?P0404A4A00o?cl0?clo0410@080?3`l01h0
?Cdm03Ti>@0k>c/0>c/k03dm?@0n?Sh0>c/k03`l?011@D40ATI604m?C`1EEED0Fe]K05IFEP18B4P0
A4A40410@00l?3`0?Cdm0492@P0i>CT0?3`l04I6AP11@D40?clo04M7A`12@T80@41003`l?013@d<2
03hn?P0403lo?`12@T80@41004m?C`80FUYJ00X0H61P06MWI`1QHF40EeMG05QHF01NGUh0P82009VI
V@2JVYX0S8b<0P22PX804`1NGUh0BDU904U9B@1:BTX0@41004];B`1iNGT0][Jf0<G5a@34a<@0^k^k
092@T01DE5@0BTY:0410@00o?cl0?Shn04A4A016ATH00P10@4001`11@D40?Shn03`l?013@d<0@410
0451@@0m?Cd00P0o?cl02@11@D40@T920451@@16ATH0KFe]08R8R01oOgl0IFEU05MGE`020492@P80
@4100P0m?Cd01P14A4@0B4Q805IFEP1UIFD0I6AT05EEE@80CTi>00d0CDe=0451@@11@D40?clo04=3
@`0m?Cd0=cLg03/k>`10@400@D510492@P10@400?clo0080?3`l00<0@D5103/k>`0k>c/00P0l?3`2
03hn?P0;0410@01:BTX0EEEE05=CD`18B4P0BTY:04E5A@11@D40@T9203/k>`13@d<00P0o?cl05012
@T80?clo0492@P1;Bd/0FUYJ059BDP16ATH0?clo03`l?00i>CT0?Cdm03`l?00n?Sh0B4Q806IVIP1o
Ogl0JVYZ04E5A@0m?Cd0?clo0P0l?3`0300i>CT0?Cdm04e=C@1RHV80GemO06YZJP1ADE40?Shn03Ph
>00j>SX0?3`l03/k>`80>CTi00P0?3`l03/k>`0k>c/0?Shn03lo?`0j>SX0>CTi03Ph>080>c/k0P0l
?3`06P12@T80D51@05]KF`1/K6`0H61P04I6AP0g=cL0BTY:05iNGP1_Kfl0LW9b06=SH`1<C4`0A4A4
03/k>`0n?Sh0>c/k03`l?00k>c/0?Shn04I6AP0l?3`0B4Q805QHF01LG5`0F5QH0P1;Bd/0=@1PH600
JFUY06QXJ01UIFD0GEeM04m?C`1=CDd0DE5A06IVIP1iNGT0OWin06m_K`1LG5`0DU9B05=CD`1ADE40
CDe=05IFEP1>CTh0Bd];06UYJ@2QXJ40][Jf0;jn_P2h^;P0Xj>S0:BTY02IVIT0V9RH0:b/[02i^KT0
_kno0<S8b033`l<0[:b/0:6QX@2JVYX0YJFU09JFUP20P800Q8B4092@T02UYJD0[Jf]0<?3``37alL0
`L710;Rh^02`/;00^KVi0=7Ad@2_[jl0W9bL0080][Jf01H0_Kfm0;Fe]@30`<00bl_;0<K6aP2`/;00
[Zj^0:f][@2GUiL0Kfm_065QH@1UIFD0I6AT05mOG`1TI6@0Kfm_07MgM`2NWYh0][Jf0<?3``31`L40
c/k>0P3Lg=`03P37alL0V9RH07QhN01^KVh0Hf=S07moO`2ATI40VYZJ0<?3``3De=@0]KFe07inOP1G
EeL0BTY:0P16ATH04@13@d<0?clo03`l?00k>c/0AdM704i>CP11@D40>SXj03Ph>00g=cL0>3Ph03Ti
>@1;Bd/0JFUY06e]K@1SHf<0A4A40080>SXj01H0=cLg03Ph>00h>3P0>SXj03hn?P1LG5`0P82008f=
S@1WIfL0@T9203Ti>@0n?Sh0DU9B07AdM020P800R8R80861P@1LG5`0?Shn03dm?@0g=cL0EEEE0P1d
M7@0301LG5`0CDe=059BDP1=CDd0IVIV0820P027QhL0WYjN0:FUY@2BTY80TI6A08j>SP80Hf=S00@0
CDe=04E5A@16ATH0ATI60P0n?Sh=ooooo`004?ooool204Q8B00704U9B@1:BTX0B4Q804U9B@17AdL0
BDU904I6AP0204A4A080ADE500<0@d=304Q8B017AdL00P15ADD01014A4@0@d=304=3@`12@T830451
@@0804Q8B012@T80@41004A4A012@T80@D5103dm?@10@4020451@@0;04=3@`12@T80@D5104A4A012
@T80?Shn03lo?`0n?Sh0?clo0492@P10@4000P0n?Sh0200o?cl0?Cdm0492@P14A4@0@D5103dm?@0n
?Sh0?Cdm0P10@4002014A4@0?clo0410@012@T80?Shn03lo?`0n?Sh0>SXj0P0o?cl03`0m?Cd0?Shn
0410@017AdL0@41003dm?@0l?3`0?Cdm03Xj>P0n?Sh0?Cdm0410@011@D40?Cdm0451@@0203hn?P04
03/k>`0n?Sh0?clo03dm?@80?3`l01D0@d=303lo?`12@T80ADE503Ti>@0l?3`0?clo03hn?P0o?cl0
@T9204Y:BP1>CTh0D51@05ADE01[Jf/0LW9b05YJFP19BDT0?Shn03/k>`0j>SX00P0l?3`0300m?Cd0
?Shn0451@@0n?Sh0ATI603dm?@0k>c/0?clo03`l?010@400?Shn03/k>`80@41004P0?Shn03lo?`1B
DU80C4a<04Y:BP1HF5P0GemO04i>CP15ADD0@41003dm?@12@T80Fe]K079bLP1jNWX0IVIV059BDP1:
BTX0A4A403lo?`14A4@0@T920410@00m?Cd0?Shn0451@@19BDT0CDe=05ADE01ZJVX0PH6107=cL`25
QHD0LW9b05iNGP1TI6@0PH6107]kN`1UIFD0Lg=c07UiN@1UIFD0G5aL0451@@13@d<0A4A404m?C`1T
I6@0N7Qh07UiN@25QHD0JFUY06MWI`1_Kfl0De=C04A4A011@D40ADE504=3@`1;Bd/0B4Q804a<C019
BDT0Bd];04Q8B01=CDd0EEEE05]KF`1=CDd0@d=303hn?P10@40203dm?@80?Shn04T0?clo03dm?@12
@T80?clo04Q8B01<C4`0A4A403lo?`11@D40>3Ph03dm?@0n?Sh0>SXj03hn?P0j>SX0?Cdm04=3@`1D
E5@0IfMW06ATI01ADE40@d=303`l?00m?Cd0?clo03/k>`0o?cl0?Cdm04Q8B01dM7@0PH6106UYJ@1D
E5@0CDe=059BDP1@D500@4100451@@0k>c/0?Cdm04E5A@1BDU80I6AT06IVIP1KFe/0D51@0451@@0l
?3`0@41003Ph>00k>c/0@41004m?C`1DE5@0KFe]08^;R`26QXH0I6AT03lo?`0l?3`0>3Ph03Xj>P0l
?3`0?clo03/k>`0o?cl0@41003hn?P0k>c/0>SXj03`l?00n?Sh0?3`l0080>c/k00L0?Shn03/k>`0n
?Sh0?clo06QXJ01nOWh0B4Q80080?clo01@0BTY:06e]K@25QHD0LG5a04e=C@11@D40?Shn0451@@0m
?Cd0?3`l0410@00i>CT0?3`l03lo?`0n?Sh0A4A403dm?@0l?3`0@T9203`l?080?clo0140IVIV05]K
F`1:BTX0Cdm?04=3@`0n?Sh0@D5104a<C01GEeL0De=C04M7A`16ATH0@D5104=3@`0o?cl0?Shn03dm
?@020410@01M0492@P1]KFd0X:2P08F5Q@1kNg/0P82006m_K`1XJ6P0MGEe08n?S`2TY:@0YZJV096A
T@1cLg<0Kfm_06YZJP1NGUh0OWin0:JVYP2j^[X0ZZZZ0:BTY02^[Zh0[Jf]096AT@2<S8`0VYZJ0;Rh
^02e]KD0Xj>S0:JVYP2][Jd0][Jf0:n_[`2][Jd0alO70;fm_@2d];@0Zj^[0;Jf]P31`L40[jn_0:f]
[@2j^[X0/k>c09nOW`2;Rh/0Vi^K0:^[Z`2l_;`0`L710=3@d03IfMT0e=CD0=kNgP3Ti>@0h>3P0=gM
g@3GemL0f][J0=_Kf`34a<@0^;Rh0<O7a`3AdM40e]KF0=kNgP3Rh^80g=cL0<;2`P2UYJD0R8R808j>
SP2DU9@0TY:B07alO01hN7P0LG5a06m_K`1VIVH0Cdm?05=CD`16ATH0?3`l03hn?P0f=SH0C4a<06IV
IP28R8P0X:2P0::RXP1fMWH0BTY:0080>3Ph00D0>SXj03dm?@1ADE40GemO05iNGP02051@D00E04a<
C014A4@0>SXj04M7A`1VIVH0T92@0;Fe]@20P800N7Qh05=CD`10@400>SXj03dm?@0g=cL0B4Q806][
J`1IFET0?Shn03Ti>@1:BTX0Ng]k0080U9BD00T0TI6A092@T027QhL0VYZJ0:VYZ@2DU9@0KFe]04=3
@`0i>CT00P0j>SX0100o?cl0@D5105=CD`1VIVH=ooooo`004?ooool00`1;Bd/0AdM704Y:BP0204Q8
B00704M7A`15ADD0AdM704=3@`16ATH0AdM704I6AP0304E5A@0504=3@`11@D40ATI604A4A010@400
0P11@D404@13@d<0@T920451@@16ATH0@D5103hn?P14A4@0@41003lo?`0m?Cd0@D510410@00m?Cd0
@41004=3@`10@400?Shn0080@41000d0@T9203dm?@0o?cl0?clo04=3@`17AdL0?clo04=3@`11@D40
ADE504=3@`12@T80?clo0080?Cdm00<0?clo0492@P10@4000`10@400100m?Cd0@4100410@00m?Cd2
0410@080?clo0P0l?3`08`0k>c/0?Cdm03/k>`0o?cl0@41003dm?@0j>SX0?3`l03hn?P0l?3`0?clo
03dm?@12@T80?Shn03dm?@10@400A4A404=3@`0k>c/0?Shn03`l?00k>c/0>SXj03Ti>@0k>c/0?Shn
04E5A@1?Cdl0IVIV06QXJ01UIFD0IfMW05UIF@1<C4`0CDe=0080?Shn02l0?clo0410@00m?Cd0>SXj
03Ti>@12@T80@41003lo?`0k>c/0?Cdm03Hf=P0k>c/0?3`l0410@00m?Cd0?clo03dm?@0n?Sh0@d=3
04E5A@11@D40ATI604E5A@16ATH0?Cdm03lo?`0m?Cd0BDU905=CD`1PH600JFUY06MWI`1EEED0ATI6
0492@P11@D40?Shn03/k>`14A4@0@D5103`l?013@d<0?3`l03/k>`0l?3`0?Shn03lo?`020410@00H
04A4A01EEED0FEUI06ATI01VIVH0Ng]k08R8R01fMWH0EeMG06YZJP1SHf<0I6AT05MGE`1iNGT0Ng]k
09VIV@2j^[X0ZJVY07MgM`1WIfL0Hf=S05eMG@1LG5`0EeMG0P13@d<0201=CDd0KFe]07]kN`1hN7P0
Kfm_05iNGP18B4P0@d=30P11@D400`0o?cl0>c/k03dm?@0203hn?P0303lo?`0m?Cd0?Shn0080?clo
00L0CDe=059BDP22PX80QhN706=SH`18B4P0@D510080?Cdm0P0l?3`0;P0n?Sh0@T920410@01FEUH0
LG5a07=cL`1IFET0Bd];03`l?00o?cl0?Shn0410@00o?cl0CDe=051@D01<C4`0BDU905QHF01fMWH0
MGEe05EEE@10@400?3`l0451@@10@400?clo04U9B@1JFUX0T92@07IfMP1/K6`0D51@0410@00i>CT0
=3@d03/k>`0m?Cd0?Shn03`l?015ADD0CTi>07EeM@1]KFd0E5AD0451@@0k>c/203`l?00=03/k>`0n
?Sh0>CTi0451@@1NGUh0MGEe07YjNP1OGel0@T9203lo?`0g=cL0?3`l03Xj>P0203/k>`0L03lo?`15
ADD0C4a<04M7A`1DE5@0B4Q80451@@10@400DE5A069RHP1WIfL0J6QX04E5A@0k>c/0?Shn03Xj>P0k
>c/0?Cdm03`l?00j>SX0?Shn03Xj>P0o?cl0=cLg03lo?`0l?3`0>CTi03Xj>P80>c/k00@0?clo03Ti
>@0l?3`0ATI60P15ADD01018B4P0Cdm?04M7A`0n?Sh204A4A00D03hn?P0j>SX0?Shn03dm?@0j>SX0
?3`l03/k>`1:BTX0De=C05UIF@1UIFD0EEEE03lo?`18B4P0J6QX08B4Q02GUiL0WIfM08N7Q`1XJ6P2
04m?C`0I06=SH`1YJFT0MGEe09>CT`2h^;P0]KFe0:b/[02LW9`0Ph>307QhN01eMGD0LG5a08N7Q`2C
Ti<0UYJF09BDU02CTi<0U9BD09FEU@2FUYH0TI6A09VIV@2XZ:P0^k^k0<71`@020;bl_0070;>c/`2R
XZ80ZJVY0:^[Z`2OWil0];Bd0<k>cP020=GEe@0A0<_;b`2o_kl0`<300<?3``38b<P0`/;20<o?c`34
a<@0][Jf0:>SX`2OWil0/[:b0;Bd]031`L40c/k>0=[JfP3Lg=`00P3Shn<0<03QhN40c/k>0<O7a`31
`L40c/k>0=7Ad@3IfMT0eMGE0<G5a@2/[:`0QXJ605eMG@1?Cdl0Fe]K05EEE@1>CTh0EeMG07AdM02M
WId0UYJF06=SH`1:BTX0@41003dm?@1;Bd/0GUiN0820P01kNg/0NWYj0:JVYP2QXJ40DU9B03lo?`0m
?Cd0?Shn04I6AP1hN7P0/;2`0;Zj^P2RXZ80I6AT04E5A@0l?3`0>c/k03Ph>01FEUH0OWin04E5A@80
>c/k00d0=CDe03/k>`15ADD0RXZ:08n?S`1PH600HF5Q08j>SP2ATI40MgMg06IVIP1?Cdl0AdM70080
>3Ph00L0?3`l03lo?`24Q8@0WinO07MgM`1`L700VIVI00gooooo000@ooooo`06051@D01:BTX0BTY:
04M7A`1:BTX0Bd];0P18B4P02`17AdL0BTY:04Q8B013@d<0@D510492@P13@d<0ADE504=3@`16ATH0
ADE50080@T9200P0@D5104=3@`16ATH0A4A404=3@`14A4@0@T9204E5A@80?clo00`0?Shn0492@P12
@T80?clo03dm?@0l?3`0?Cdm03lo?`0n?Sh0?Cdm03hn?P0o?cl20410@00<0492@P17AdL0?Shn0451
@@10@400B4Q80492@P0n?Sh0@41003dm?@0n?Sh0?Cdm0P11@D404`0o?cl0?3`l03`l?00n?Sh0@d=3
0451@@15ADD0?clo03`l?00o?cl0?Cdm03`l?00o?cl0?Cdm0492@P11@D40?Shn0410@00j>SX00P10
@4005`0m?Cd0?clo03Ti>@0l?3`0?clo0451@@0m?Cd0>c/k0451@@12@T80?3`l03lo?`0k>c/0?3`l
0410@00l?3`0@d=305eMG@1ADE40Bd];05=CD`1>CTh0@4100080?3`l00T0?Cdm03lo?`10@400?Cdm
03Xj>P0k>c/0?3`l03Xj>P0l?3`00P0m?Cd08010@400?Shn03Ti>@0o?cl0@41003hn?P0o?cl0@D51
04E5A@13@d<0AdM703lo?`10@400@D510492@P0k>c/0@D5104=3@`1ADE40J6QX06ATI01QHF40Fe]K
04e=C@13@d<0@41003hn?P0o?cl0?3`l03/k>`0l?3`0?Shn0P15ADD05P13@d<0@41003hn?P10@400
?Shn04E5A@18B4P0E5AD05eMG@1RHV80IFEU06a/K01QHF40E5AD04=3@`0m?Cd0?clo0410@00m?Cd0
>CTi04I6AP1JFUX305QHF00=04e=C@0m?Cd0ATI606i^KP1PH600G5aL05mOG`1KFe/0C4a<05MGE`1d
M7@0FUYJ04Y:BP0203lo?`0804=3@`11@D40?Shn03lo?`11@D40@4100451@@0n?Sh20410@00G04=3
@`17AdL0D51@05UIF@1oOgl0OGem07]kN`1OGel0F5QH065QH@1DE5@0@d=303lo?`19BDT0LW9b08Z:
RP23Ph<0L71`08F5Q@2>SXh0RHV906m_K`1KFe/00P1<C4`03@1CDe<0EEEE06a/K01kNg/0GUiN04U9
B@0o?cl0@41003`l?012@T80?Cdm03hn?P10@4000P0n?Sh01@12@T80GUiN06IVIP1ADE40@T920080
?3`l00<0?clo03dm?@11@D400P0l?3`04`0n?Sh0ATI605mOG`16ATH0@41003/k>`0n?Sh0>CTi04Y:
BP1SHf<0DE5A03hn?P17AdL0FUYJ08^;R`23Ph<0EeMG04E5A@0i>CT00P0n?Sh07@13@d<0B4Q8069R
HP27QhL0R8R808F5Q@1eMGD0H61P065QH@1JFUX0BDU9061PH02;Rh/0Ph>3069RHP16ATH0>c/k03Ti
>@11@D40@41003Lg=`0k>c/0?3`l03dm?@0f=SH0>SXj0410@014A4@0?Cdm00<0?Shn0P15ADD203hn
?P0g0451@@1ADE40GEeM06IVIP1@D500BTY:04E5A@0l?3`0?Cdm03/k>`0n?Sh0?3`l03dm?@0o?cl0
?3`l03hn?P0l?3`0?clo04U9B@13@d<0@T9203`l?014A4@0FEUI075aL@23Ph<0N7Qh065QH@1;Bd/0
?clo0492@P1:BTX0MWIf07moO`1aLG40KFe]07moO`1iNGT0Hf=S05aLG01@D500EeMG06m_K`29RHT0
Ti>C09ZJVP2NWYh0TY:B09RHV02SXj<0/[:b0<?3``37alL0_kno0<71`@020;Zj^P040;Rh^02_[jl0
YJFU0:b/[080YZJV00@0VIVI08f=S@25QHD0P8200P27QhL0201iNGT0Jf][06i^KP1cLg<0OGem07If
MP1oOgl0RHV90P2@T900101oOgl0UIFE0;2`/02k^k/20<S8b00o0<c<c03Jf]X0h>3P0=gMg@3Kfm/0
e]KF0<K6aP2d];@0`/;20=SHf03MgMd0f][J0<c<c02o_kl0]kNg0;Rh^03AdM40^KVi07=cL`1TI6@0
JFUY05ADE014A4@0?Shn03Xj>P0m?Cd0PH610;Rh^035aLD0WinO05UIF@1<C4`0De=C06][J`2@T900
UYJF09^KV`2_[jl0_kno0<g=c@2c/k<0PX:205IFEP0o?cl0>SXj0492@P1EEED0L71`07IfMP1RHV80
@D5103Ph>00j>SX0F5QH079bLP1jNWX0HF5Q04e=C@1/K6`0Xj>S0;>c/`1WIfL0DE5A0080?3`l00X0
>CTi03Xj>P0k>c/0Bd];08Z:RP2DU9@0LW9b061PH02;Rh/0WYjN3Oooool0013ooooo00@0CDe=04];
B`1;Bd/0BDU90P16ATH02`17AdL0A4A404I6AP18B4P0BDU904A4A015ADD0@d=30492@P14A4@0@410
0080@d=300/0ADE504M7A`14A4@0@T9204M7A`15ADD0>c/k0451@@10@400@T920410@00203hn?P0A
0451@@12@T80@d=303lo?`0m?Cd0?Shn0451@@13@d<0@D5103hn?P11@D40?clo0410@013@d<0ATI6
04E5A@14A4@00P11@D402@12@T80?Cdm03hn?P0l?3`0?Shn0410@00o?cl0@D5103dm?@0203/k>`80
?clo00L0?Cdm03lo?`0m?Cd0>CTi03dm?@0l?3`0?Cdm0080?clo0P10@4002@0k>c/0?Shn03Xj>P0m
?Cd0?Shn0451@@14A4@0?Shn04A4A00203`l?080@41000`0@T9204=3@`0k>c/0?3`l03lo?`0k>c/0
?Shn03dm?@0j>SX0>c/k03`l?00j>SX203hn?P0603Xj>P0k>c/0?Shn03hn?P0l?3`0>SXj0`0l?3`0
2`0k>c/0>CTi03dm?@0j>SX0?Shn03dm?@11@D40>c/k0492@P1=CDd0Bd];0080@D5100P0A4A404M7
A`0n?Sh0>CTi03hn?P11@D40?Shn0492@P80EUIF00D0EEEE051@D014A4@0@T920410@00203hn?P0<
0451@@10@400?Cdm03hn?P0o?cl0@41004E5A@1:BTX0A4A404Q8B00m?Cd0?Shn0P11@D402P1RHV80
KVi^075aL@1WIfL0GUiN055AD@1;Bd/0?3`l03dm?@10@40203`l?080?clo00H0?3`l03lo?`12@T80
?Cdm03`l?00j>SX20410@00?03lo?`15ADD0D51@06UYJ@24Q8@0IVIV04M7A`18B4P0NWYj09BDU01e
MGD0ATI603lo?`14A4@0?clo0080?Shn03@0@4100451@@0n?Sh0@41003lo?`1KFe/0K6a/07MgM`1_
Kfl0Hf=S05iNGP1FEUH0ATI6059BDP1[Jf/0H61P05aLG01?Cdl0D51@06EUI@1kNg/0Shn?08:2PP1K
Fe/0AdM703hn?P0j>SX0ATI603lo?`16ATH0EeMG05QHF018B4P0BTY:04];B`11@D40?Shn03Xj>P10
@400D51@04a<C01;Bd/0A4A404U9B@1QHF40KFe]07AdM01CDe<0@41003/k>`0l?3`0=cLg0P0n?Sh0
5@0l?3`0?Shn04Y:BP1>CTh0EEEE04];B`0m?Cd0AdM704i>CP1ADE40GEeM06m_K`29RHT0SXj>07Ad
M01UIFD0I6AT05YJFP1CDe<0A4A403lo?`0203dm?@0A03hn?P16ATH0DU9B07YjNP2>SXh0R8R807em
O@23Ph<0PX:2071`L01[Jf/0EUIF071`L02MWId0Rh^;069RHP16ATH00`0k>c/01`0i>CT0?3`l03/k
>`0k>c/0?Cdm03Ph>00m?Cd00P0k>c/02@0l?3`0ADE505EEE@1ADE40@d=30451@@0n?Sh0AdM705mO
G`0207IfMP0304e=C@15ADD0?Shn0080?Cdm0P0n?Sh02P0l?3`0?Cdm03Xj>P0j>SX0?3`l03Hf=P0n
?Sh0?3`l03/k>`0n?Sh30410@00;061PH01aLG40D51@04=3@`0l?3`0@41003`l?018B4P0CDe=04];
B`1:BTX00`13@d<06@0m?Cd0>c/k03lo?`17AdL0B4Q805EEE@1QHF40EUIF05EEE@1BDU80Fe]K06m_
K`1nOWh0U9BD0;2`/02d];@0Xj>S09jNWP27QhL0NGUi08N7Q`2FUYH0YJFU0:f][@2EUID00P1kNg/0
301RHV80Bd];04e=C@1HF5P0GUiN05UIF@1FEUH0DE5A061PH01/K6`0JVYZ071`L080P82003P0NGUi
08:2PP2<S8`0TY:B08N7Q`2:RXX0P82008B4Q02UYJD0];Bd0;>c/`2_[jl0/[:b0;bl_03>c/h0_Kfm
0<[:bP3Hf=P0e=CD0<o?c`3De=@0fm_K0=GEe@2PX:00_Kfm0<c<c02WYjL0SXj>07UiN@1]KFd0L71`
06m_K`1YJFT0U9BD0<o?c`3MgMd0`l?308F5Q@1RHV80GemO08Z:RP2o_kl0eMGE0=kNgP3IfMT0aLG5
0:^[Z`23Ph<0HF5Q05MGE`1BDU80@T92069RHP2?Shl0]KFe08J6QP80@41001T0AdM705aLG024Q8@0
/;2`08n?S`1jNWX0TY:B0:NWY`2YZJT0TI6A05=CD`12@T80ATI603Lg=`0j>SX0>CTi03Xj>P1ADE40
TI6A07MgM`26QXH0QHF508b<S02@T900PH6100gooooo000@ooooo`0F04Y:BP17AdL0BTY:04a<C019
BDT0ATI604Q8B019BDT0CDe=0492@P18B4P0@d=304A4A013@d<0@T920451@@12@T80@D510492@P13
@d<0ADE504Q8B080@d=300L0@T9204=3@`15ADD0@41003hn?P0o?cl0@4100080@D510`12@T801`0o
?cl0@d=30492@P0l?3`0@41003lo?`11@D400P13@d<01P14A4@0AdM704Y:BP19BDT0@T9203lo?`80
@41000`0@d=303lo?`0l?3`0?3`l03/k>`0n?Sh0>c/k03hn?P0l?3`0?clo03dm?@0l?3`203lo?`<0
?Shn0P10@40203/k>`0503dm?@14A4@0?Cdm03hn?P0m?Cd00P0n?Sh01P0m?Cd0>c/k0451@@0m?Cd0
@D5103hn?P80A4A400P0@T9203dm?@10@400@41003dm?@15ADD0A4A403`l?080?Cdm00X0?3`l03Xj
>P0k>c/0?Cdm03Ti>@0n?Sh0?3`l03/k>`0n?Sh0>3Ph0P0o?cl03@11@D40?clo03Ti>@0k>c/0?clo
04=3@`18B4P0@41004A4A01=CDd0@T920410@00n?Sh00P12@T804@11@D40?3`l04A4A01BDU80De=C
05MGE`1>CTh0?Shn0410@00j>SX0?clo03Ti>@10@400?clo04A4A00l?3`0?Cdm0080=SHf01/0?clo
03hn?P0o?cl0@41003/k>`14A4@0@T9205EEE@1`L700HF5Q059BDP12@T80@D5103lo?`0l?3`0?clo
04I6AP0j>SX0?clo03dm?@0n?Sh0@T920410@012@T80>SXj03lo?`0m?Cd00P0o?cl09P10@400?Cdm
04Y:BP1YJFT0RXZ:08^;R`1ZJVX0CDe=05=CD`1VIVH0Jf][06QXJ01IFET0B4Q80410@00l?3`0?Cdm
03/k>`0l?3`0?Shn04E5A@19BDT0IVIV05IFEP1>CTh0QHF5092@T01WIfL0GEeM06UYJ@1^KVh0RHV9
0861P@1dM7@0I6AT04A4A00l?3`0?Cdm0P0o?cl0200n?Sh0@D5103`l?00l?3`0>SXj0410@00l?3`0
>c/k0P0m?Cd00`0o?cl0@41003dm?@0203hn?P0>0451@@15ADD0CDe=04U9B@1<C4`0Bd];04=3@`1H
F5P0MgMg07IfMP1GEeL0@d=303hn?P0l?3`203dm?@0604Y:BP1HF5P0GEeM06e]K@1hN7P0OGem0P1c
Lg<09028R8P0UiNG09JFUP2DU9@0WIfM0:2PX02JVYX0Vi^K08j>SP28R8P0OGem06IVIP1BDU80@T92
03/k>`0m?Cd0>c/k0492@P1FEUH0Jf][06a/K01[Jf/0MGEe09:BTP2GUiL0Lg=c051@D013@d<0BDU9
07QhN02;Rh/0Jf][04a<C00o?cl0?Cdm03Ti>@80>SXj01@0>3Ph03Ti>@0i>CT0?3`l03/k>`0l?3`0
>3Ph04=3@`1CDe<0IFEU06e]K@1WIfL0IFEU06UYJ@1[Jf/0L71`06i^KP1aLG40GemO04E5A@80@T92
00X0?Shn03/k>`0l?3`0>SXj0410@00k>c/0>3Ph03Xj>P0l?3`0>CTi0P0l?3`03`0k>c/0>CTi0451
@@12@T80@D5105YJFP1NGUh0B4Q803/k>`0n?Sh0?Cdm03hn?P13@d<0De=C04I6AP0203dm?@0303`l
?00j>SX0?clo0080@d=300D0ADE50492@P13@d<0?3`l03@d=00203/k>`0M06ATI023Ph<0TI6A08f=
S@1jNWX0K6a/05UIF@1ADE40GEeM07EeM@2BTY80UYJF08n?S`22PX80LG5a06MWI`1GEeL0H61P07Ee
M@21PH40PX:208B4Q02CTi<0SXj>08J6QP2;Rh/0ZZZZ0:f][@2EUID00P2VYZH03P2MWId0V9RH09VI
V@2IVIT0UYJF08f=S@2:RXX0Ogmo08Z:RP2DU9@0T92@08J6QP1lO7`0OWin0P1oOgl06@27QhL0WIfM
09bLW01nOWh0Shn?0;>c/`2f][H0a<C40;6a/@2TY:@0Q8B407=cL`2][Jd0alO70;no_`2m_Kd0WIfM
0:6QX@2>SXh0S8b<0;fm_@3?cll0fMWI0<S8b033`l<00P2g]kL0:@2`/;00^;Rh0;fm_@2UYJD0RHV9
08B4Q01]KFd0QhN707inOP1hN7P0Vi^K0:FUY@2e]KD0Kfm_075aL@2ATI40QXJ609FEU@2o_kl0_;bl
0:6QX@2KVi/0[jn_09FEU@1EEED0?Shn03Lg=`0n?Sh0?3`l03/k>`0m?Cd0=cLg0410@01KFe/0EUIF
04m?C`1BDU80QhN70:ZZZP1jNWX0Jf][00gooooo000@ooooo`0404a<C019BDT0BDU904M7A`80BTY:
00L0B4Q804Y:BP19BDT0B4Q804U9B@14A4@0@d=30080@4100P11@D401`0n?Sh0A4A403dm?@12@T80
BDU904A4A012@T800P0o?cl01P10@400@T920451@@0o?cl0?3`l03hn?P80@D5100h0@T9204=3@`11
@D40?Shn03lo?`0l?3`0@4100492@P0o?cl0@D510410@017AdL0@T920451@@80@d=300`0?3`l03lo
?`11@D40@41003hn?P0o?cl0@D5103lo?`11@D40>c/k03Xj>P0n?Sh203dm?@070410@012@T80?Shn
0451@@0n?Sh0A4A40492@P0203lo?`0=03`l?00k>c/0>CTi03Ti>@0n?Sh0?3`l03/k>`0m?Cd0?Shn
03`l?00m?Cd0>CTi03Xj>P0303lo?`0603`l?010@400A4A403lo?`0m?Cd0>c/k0P0o?cl203/k>`80
?3`l00<0?Shn03lo?`0j>SX00P0j>SX0200m?Cd0>SXj03Ti>@0j>SX0?Cdm03Ph>00i>CT0?Shn0P14
A4@0100n?Sh0?Cdm03dm?@11@D4203lo?`0:04A4A010@400?Cdm0410@01;Bd/0AdM704A4A018B4P0
BDU90451@@80?clo01d0?3`l03Ph>00j>SX0?Shn04=3@`14A4@0?Shn03/k>`0o?cl0>SXj03/k>`0j
>SX0?Shn0451@@1ADE40EUIF05UIF@1PH600Fe]K05ADE018B4P0ATI60410@00o?cl0?Shn03/k>`0i
>CT0?3`l03dm?@0203lo?`80AdM705`0?Shn04A4A017AdL0ADE503lo?`11@D40A4A404a<C01LG5`0
PH610:j^[P2NWYh0I6AT06YZJP22PX80P82006YZJP1;Bd/0@D5103lo?`16ATH0@T9203/k>`0h>3P0
C4a<05=CD`1EEED0DE5A04m?C`1NGUh0CTi>04U9B@1=CDd0D51@06UYJ@1nOWh0SHf=09:BTP2EUID0
R8R8096AT@1dM7@0@d=303hn?P12@T80A4A403lo?`0n?Sh0DE5A04A4A00n?Sh0@41004A4A01>CTh0
Cdm?04M7A`1JFUX0RHV908n?S`20P800IVIV06QXJ01PH600FEUI06=SH`1dM7@0I6AT05EEE@1UIFD0
M7Ad065QH@16ATH0@41004=3@`0o?cl0?Shn03lo?`13@d<0CTi>06e]K@22PX80UIFE0:JVYP2d];@0
[:b/0:>SX`2PX:00ZJVY0:b/[02PX:00UiNG08N7Q`80NWYj00d0OWin07]kN`1IFET0@D510410@00m
?Cd0ADE504];B`1SHf<0NWYj09VIV@2PX:00U9BD0080QhN700h0Lg=c05UIF@1:BTX0GEeM07UiN@1j
NWX0JFUY05=CD`11@D40?3`l0451@@10@400>c/k03`l?0<0>SXj0100>c/k0410@00m?Cd0?3`l051@
D01XJ6P0Q8B409:BTP2HV9P0VYZJ08Z:RP1jNWX0HF5Q04];B`19BDT0Cdm?0P1@D500200o?cl0@410
03lo?`0m?Cd0?3`l03Ti>@0o?cl0?Cdm0P0l?3`20451@@0;03lo?`0n?Sh0?Cdm04=3@`15ADD0Bd];
059BDP1GEeL0BTY:0492@P0m?Cd00P0j>SX01`12@T80A4A403lo?`0l?3`0>SXj04Y:BP14A4@00P12
@T805@13@d<0?clo03Xj>P0i>CT0>SXj03Ph>00k>c/0?Shn05UIF@1WIfL0G5aL051@D018B4P0?Cdm
03hn?P13@d<0Fe]K06][J`1UIFD0G5aL04U9B@020492@P1>04M7A`1GEeL0EUIF06m_K`28R8P0PX:2
06QXJ01PH600HF5Q05QHF01LG5`0LG5a09fMW@2/[:`0WinO09RHV02ATI40VYZJ08V9R@25QHD0Ogmo
075aL@1RHV80K6a/0861P@2<S8`0T92@08j>SP24Q8@0NGUi07YjNP1bLW80Kfm_06UYJ@1RHV80FUYJ
06ATI01cLg<0OGem07=cL`20P800Ph>307]kN`1RHV80HF5Q069RHP1/K6`0HV9R06i^KP2:RXX0/[:b
09NGU`29RHT0WYjN0;>c/`2o_kl0e]KF0=kNgP3GemL0[jn_08b<S02XZ:P0`l?30<[:bP3De=@0e]KF
0;Jf]P2FUYH0Z:RX0:n_[`27QhL0VIVI0:BTY02][Jd0ZJVY09bLW02^[Zh0`<300P3;bl/01P2QXJ40
PH6106m_K`1DE5@0BTY:03dm?@80?clo00d0CTi>04Q8B00i>CT0>CTi0451@@1SHf<0?Shn04U9B@1d
M7@0YJFU08f=S@1ADE40?Shn00gooooo000@ooooo`0404I6AP18B4P0BTY:04Q8B080ATI600H0A4A4
04E5A@16ATH0CDe=061PH01CDe<304=3@`060451@@10@400?clo04A4A00o?cl0@d=30P12@T802`11
@D40@T9204I6AP1;Bd/0A4A40410@011@D40?Cdm03lo?`15ADD0@d=300<0@41000L0?Cdm04E5A@11
@D40@4100451@@0n?Sh0?clo0080@T9200P0ATI60492@P0n?Sh0@41003dm?@13@d<0@4100451@@80
?clo00D0@D5103dm?@0m?Cd0?Cdm03hn?P0203dm?@80@4100P0l?3`0200o?cl0@4100492@P0o?cl0
?Cdm03hn?P0k>c/0?clo0`0l?3`02@0n?Sh0?Cdm03hn?P0m?Cd0>c/k03hn?P0o?cl0@D5104];B`02
03`l?00503Ti>@10@400A4A403Xj>P0k>c/00P10@4001015ADD0@T920410@00o?cl203/k>`0803dm
?@0k>c/0>SXj03Hf=P0n?Sh0@D5103Ti>@0l?3`203dm?@0503lo?`11@D40>c/k03hn?P0k>c/00P0m
?Cd05P0l?3`0>CTi0451@@11@D40B4Q803hn?P0k>c/0?clo0410@00n?Sh0@D5104e=C@10@400?3`l
04A4A00m?Cd0?clo03hn?P15ADD0A4A404M7A`11@D4203dm?@0503hn?P0m?Cd0@41006ATI01NGUh0
0P1FEUH02`1HF5P0HV9R05aLG01DE5@0C4a<0451@@0o?cl0?3`l0410@011@D40?Shn0080?Cdm01H0
?Shn04E5A@15ADD0?Shn04U9B@1;Bd/0DE5A05EEE@1LG5`0F5QH06=SH`1^KVh0QXJ607moO`1iNGT0
OWin07alO01SHf<0DU9B03lo?`10@400>CTi0P0k>c/203dm?@0T0451@@14A4@0CTi>04M7A`11@D40
?3`l03hn?P0o?cl0@T9204E5A@1=CDd0EUIF07YjNP1XJ6P0E5AD04m?C`12@T80@d=304E5A@1DE5@0
@D5103hn?P1:BTX0ADE503dm?@12@T80A4A404Y:BP11@D40@4100451@@12@T80DU9B06YZJP2GUiL0
_Kfm0P3>c/h01`2m_Kd0Vi^K06IVIP1TI6@0FEUI04m?C`13@d<00P15ADD03@13@d<0?3`l03hn?P0o
?cl0@D5103hn?P12@T80KVi^096AT@2=SHd0RXZ:07alO01hN7P00P1_Kfl01P1kNg/0SXj>08N7Q`1k
Ng/0LG5a06EUI@80KVi^01h0H61P05=CD`1BDU80BDU904A4A012@T80GEeM06EUI@22PX80RXZ:07em
O@1FEUH0GUiN05mOG`1IFET0Fe]K06=SH`2EUID0YjNW07moO`1MGEd0DE5A0451@@10@400?Cdm03Ph
>010@400?clo03Xj>P0m?Cd203Xj>P80>c/k0140?Cdm03`l?00o?cl0E5AD096AT@2c/k<0Y:BT08^;
R`1XJ6P0EeMG04Q8B011@D40@T9204U9B@1=CDd0EEEE04A4A00203lo?`0D03Xj>P0i>CT0?3`l0492
@P0l?3`0@D5105mOG`1ZJVX0K6a/05MGE`1@D500@D5103hn?P16ATH0H61P06MWI`1DE5@0Bd];0410
@00n?Sh203lo?`0L04M7A`1ADE40C4a<0492@P0n?Sh0ATI604a<C01FEUH0ATI603hn?P13@d<0AdM7
03dm?@0g=cL0>SXj03Ti>@0l?3`0>SXj03/k>`0l?3`0?Shn03`l?010@400?Shn04M7A`19BDT0BTY:
04A4A080@D5102@0ADE504Y:BP1ADE40HV9R06IVIP1IFET0Bd];04=3@`12@T80>SXj03dm?@12@T80
DU9B06IVIP1kNg/0QXJ607inOP1SHf<0EeMG05QHF01]KFd0PX:208^;R`1VIVH0HV9R05ADE01>CTh0
GemO079bLP1fMWH0QXJ608>3P`1hN7P0OGem07AdM01`L70208>3P`0T07QhN01ZJVX0MWIf06i^KP1T
I6@0KFe]07UiN@1gMgL0MGEe079bLP1_Kfl0I6AT06e]K@1/K6`0JVYZ079bLP1cLg<0NWYj0861P@27
QhL0QHF508R8R02a/K40alO70<W9b@2n_[h0[Jf]0;Ng]`2j^[X0`l?30=?Cd`3IfMT0dm?C0<o?c`3A
dM40c<c<0P2o_kl05039bLT0alO70<c<c03?cll0fMWI0<[:bP2^[Zh0Ph>305iNGP10@400?clo04A4
A01FEUH0Kfm_09:BTP2KVi/0XJ6Q07alO01OGel0EeMG0P1lO7`01`1GEeL0UiNG0:RXZ01SHf<0?clo
03hn?P0g=cL03Oooool0013ooooo0P18B4P00`16ATH0AdM704A4A0020492@P0904E5A@14A4@0A4A4
04Q8B017AdL0@d=304M7A`16ATH0@d=30080@D5100l0ADE504U9B@15ADD0A4A404I6AP19BDT0FEUI
069RHP1hN7P0MgMg04i>CP14A4@0BTY:05=CD`1<C4`00P11@D402P1FEUH0D51@059BDP1IFET0EUIF
0451@@0n?Sh0?Cdm03lo?`19BDT203lo?`0903dm?@10@400@D5103hn?P13@d<0@41003hn?P10@400
?Cdm0080@d=300`0?3`l0451@@0n?Sh0@41004A4A011@D40?3`l03Ti>@0n?Sh0@D5104A4A00n?Sh2
0451@@80?3`l0180>c/k03dm?@0l?3`0?clo0410@012@T80?clo0410@00n?Sh0?clo03hn?P0m?Cd0
?Shn0451@@10@400>CTi0410@00o?cl203Xj>P0>03lo?`17AdL0C4a<0451@@0m?Cd0@41003/k>`0n
?Sh0?Cdm0410@00o?cl0>SXj03hn?P0i>CT203Xj>P0603dm?@0l?3`0>c/k03Xj>P10@400?clo0P0l
?3`02@0n?Sh0?3`l03Ti>@0o?cl0?Cdm04=3@`0l?3`0>c/k03lo?`030410@00<04I6AP0n?Sh0?clo
0410@00k>c/0?Cdm03hn?P0k>c/0@D5104A4A00n?Sh0A4A40P10@4003011@D40Bd];06ATI01<C4`0
CDe=04m?C`1:BTX0?clo03dm?@0l?3`0ADE504A4A080?3`l01h0>SXj03`l?00m?Cd0>SXj04E5A@1F
EUH0Bd];04I6AP0o?cl0@d=304Y:BP1@D500EUIF06IVIP1XJ6P0I6AT05eMG@1BDU80GUiN06QXJ01H
F5P0ADE503dm?@0l?3`0>SXj03`l?00m?Cd0AdM704m?C`14A4@30410@00503Ph>010@400?clo03dm
?@0n?Sh00P11@D40>`0m?Cd0?3`l03`l?013@d<0@41003hn?P0m?Cd0B4Q80451@@0o?cl0ATI603`l
?011@D40?Shn03dm?@0l?3`0@T9205iNGP2DU9@0XJ6Q08F5Q@1XJ6P0GemO05aLG01ADE40Bd];05=C
D`1kNg/0Ogmo06][J`1UIFD0IfMW06m_K`1KFe/0@41003dm?@10@400?Shn04U9B@0o?cl0ADE504e=
C@1:BTX0FUYJ0:NWY`3=cLd0Y:BT06YZJP19BDT0FUYJ0820P02][Jd0][Jf0;2`/021PH40De=C05eM
G@1<C4`0@T920080?clo00H0?Shn03`l?00o?cl0?3`l03hn?P0o?cl204=3@`0404i>CP1GEeL0H61P
0820P080WIfM0100VYZJ0::RXP2FUYH0QXJ606QXJ018B4P0?Cdm03`l?00i>CT0>c/k03hn?P11@D40
?Shn03dm?@0n?Sh0@4100P0l?3`02@0j>SX0>3Ph03/k>`1ADE40KFe]09FEU@2>SXh0IFEU04];B`02
03/k>`0403`l?00j>SX0@41004E5A@80>c/k0P0o?cl06`0j>SX0?clo03lo?`0m?Cd0?clo05aLG01o
Ogl0/k>c0<_;b`2k^k/0U9BD07=cL`1FEUH0FEUI06i^KP1YJFT0HV9R04U9B@0k>c/0?Shn03Xj>P0i
>CT0?Shn03Ti>@14A4@0E5AD06YZJP0208:2PP0506m_K`1DE5@0>c/k03Hf=P0k>c/00P0h>3P05P0k
>c/0>3Ph03Ti>@0i>CT0=cLg03Xj>P0o?cl0A4A403dm?@0l?3`0CTi>055AD@19BDT0?Shn04A4A012
@T80F5QH08F5Q@2?Shl0J6QX05=CD`12@T8203Xj>P0>0410@00h>3P0>CTi03Ph>00m?Cd0@D5105iN
GP1_Kfl0JVYZ05YJFP0o?cl0@T9204=3@`19BDT204a<C00M05QHF013@d<0@T9205IFEP1fMWH0OWin
07alO02:RXX0TI6A08J6QP22PX80Ng]k07IfMP1jNWX0Kfm_05iNGP1IFET0AdM704Q8B01ADE40IFEU
07=cL`1eMGD0KVi^06a/K01`L700LG5a07=cL`1/K6`00P1UIFD06@1RHV80LG5a075aL@1_Kfl0JVYZ
06MWI`1VIVH0J6QX071`L01jNWX0Q8B407inOP24Q8@0S8b<09NGU`2DU9@0Xj>S0;:b/P2m_Kd0`<30
0;fm_@3>c/h0dM7A0<K6aP2l_;`00P3:b/X06@2[Zj/0MWIf051@D01CDe<0EUIF06a/K02EUID0/;2`
0;^k^`32`/80aLG50<K6aP2OWil0P82007AdM01_Kfl0MWIf06i^KP1GEeL0GUiN07AdM01RHV80GUiN
04I6AP1FEUH03Oooool0013ooooo00H0ATI604M7A`15ADD0AdM704A4A012@T820410@0030492@P10
@400@D510080@d=300<0A4A40492@P10@4000P11@D403P14A4@0@D5103lo?`0o?cl0?Cdm03lo?`12
@T80@d=304M7A`1:BTX0@T9203lo?`14A4@0BTY:0P16ATH06`17AdL0EUIF059BDP1>CTh0Cdm?05IF
EP10@400ADE503lo?`13@d<0B4Q80410@017AdL0Bd];04I6AP18B4P0@T9203dm?@0o?cl0>SXj0410
@011@D40>c/k04A4A011@D40ADE505YJFP0206=SH`0>04M7A`10@400>CTi03`l?00o?cl0@41003lo
?`10@400@D5103lo?`0k>c/0@T9203lo?`0m?Cd203`l?00304M7A`10@400?Shn0080?clo00X0?3`l
03lo?`0l?3`0?clo03Ph>00i>CT0@41003/k>`0l?3`0?Cdm0P0n?Sh01011@D40?clo03Ti>@0n?Sh2
03Xj>P0@03/k>`0n?Sh0?3`l03Xj>P0l?3`0>SXj03dm?@0j>SX0>c/k03Ph>00o?cl0ADE504I6AP0o
?cl0>SXj03Ph>080>c/k00T0>CTi03hn?P0n?Sh0@41003Xj>P0n?Sh0ADE503lo?`0l?3`00P0m?Cd0
5@0i>CT0?3`l0492@P12@T80B4Q805=CD`0n?Sh0@D5104=3@`0m?Cd0@41004Y:BP1BDU80DE5A05YJ
FP1RHV80E5AD04e=C@13@d<0>SXj03`l?00203lo?`80?3`l00L0>c/k03lo?`0m?Cd0?Cdm03lo?`12
@T80@D510080?clo00D0@D5103lo?`15ADD0?clo04M7A`0304Y:BP0>04I6AP14A4@0?clo03hn?P0m
?Cd0B4Q803hn?P0m?Cd0?clo04M7A`1JFUX0NWYj08:2PP1NGUh20492@P<0@D5102<0ADE503hn?P0o
?cl0@D510492@P0n?Sh0A4A403hn?P0m?Cd0?Shn0410@012@T80?clo04=3@`12@T80A4A403hn?P17
AdL0@d=304Y:BP1BDU80I6AT07QhN02HV9P0X:2P08^;R`1aLG40F5QH05MGE`1EEED0C4a<04Q8B01;
Bd/0BTY:04=3@`0303dm?@0K04=3@`0m?Cd0?3`l03hn?P13@d<0ADE504i>CP1=CDd0LG5a08Z:RP22
PX80QhN709NGU`2WYjL0Shn?06ATI01?Cdl0DE5A05]KF`1VIVH0Rh^;0:j^[P2@T900EUIF03`l?00k
>c/0?Shn00<0?3`l01<0>SXj03hn?P0k>c/0?Cdm0492@P1;Bd/0I6AT08b<S02`/;00`<300;Jf]P2A
TI40NGUi06EUI@1GEeL0@T9204M7A`16ATH0?Cdm0080ATI600P0BDU904=3@`15ADD0BTY:04e=C@0o
?cl0?Shn03dm?@<0?Shn01d0EUIF08V9R@2o_kl0/k>c08Z:RP1:BTX0B4Q804I6AP1>CTh0Bd];0451
@@0n?Sh0?Cdm03/k>`0l?3`0@T9204=3@`0l?3`0@D5103hn?P1GEeL0Q8B40:^[Z`2c/k<0[jn_09BD
U01^KVh0HF5Q05MGE`0205eMG@0F08b<S02EUID0S8b<05mOG`1<C4`0@D5103lo?`0l?3`0?Shn05QH
F01ZJVX0Q8B40:>SX`2VYZH0OGem061PH01:BTX0?Cdm03`l?00g=cL0?clo03/k>`80@d=300<0?Cdm
0492@P0i>CT00P0k>c/0400o?cl0ATI606a/K028R8P0Ng]k05EEE@1MGEd0MGEe08>3P`1]KFd0JVYZ
061PH01@D500>c/k03`l?00g=cL403/k>`0403Ti>@15ADD0@D510451@@80?Cdm01H0>SXj03Ph>00k
>c/0>SXj03`l?00o?cl0>SXj03`l?00k>c/0ADE5075aL@2<S8`0PH6107]kN`1gMgL0I6AT05mOG`1T
I6@0H61P05EEE@1>CTh0@4100P0o?cl0@`18B4P0BDU905eMG@1XJ6P0HF5Q05]KF`1IFET0Hf=S06QX
J01YJFT0G5aL04m?C`18B4P0?clo0492@P1FEUH0I6AT05QHF01FEUH0Bd];04Y:BP18B4P0CDe=04Y:
BP1@D500E5AD05MGE`1WIfL0J6QX06e]K@1YJFT0LG5a079bLP21PH40Rh^;096AT@2a/K40_;bl0;jn
_P30`<00_kno0:n_[`2XZ:P0`/;20;Fe]@2k^k/0^[Zj0<C4a03=cLd0^KVi0;6a/@2][Jd0X:2P0:BT
Y02MWId0YZJV0:BTY029RHT0Q8B407QhN022PX80QhN709^KV`2TY:@0OWin05QHF01RHV803Oooool0
013ooooo00@0ATI604A4A014A4@0A4A40`11@D420492@P80?clo0180@D510492@P10@400@4100451
@@12@T80?Shn04=3@`0n?Sh0?clo03hn?P0o?cl0@41003lo?`13@d<0@T920410@012@T8303lo?`05
03dm?@10@400A4A404=3@`16ATH00P10@400=P13@d<0@T9204=3@`12@T80AdM704a<C016ATH0@d=3
04I6AP12@T80A4A404Q8B012@T80@d=303lo?`11@D40?3`l03hn?P10@400BTY:05=CD`1]KFd0NWYj
08:2PP1[Jf/0CTi>069RHP1aLG40NWYj04A4A00o?cl0@4100451@@12@T80?3`l03dm?@0l?3`0?clo
03/k>`11@D40A4A40492@P1<C4`0GemO06QXJ01LG5`0A4A403Xj>P12@T80A4A40451@@15ADD0?Cdm
03Xj>P80?Cdm00@0>c/k03`l?010@400@d=30P0o?cl02010@400>SXj03`l?00k>c/0>CTi03`l?00h
>3P0>SXj0P0m?Cd01P0k>c/0@41004=3@`12@T80?3`l03Xj>P80?3`l0P0m?Cd0100l?3`0>3Ph03hn
?P0m?Cd203hn?P0<03Ph>00m?Cd0?Cdm03dm?@0l?3`0?Shn03dm?@0l?3`0BDU904];B`0m?Cd0?Shn
0P0o?cl00`10@400ATI604I6AP0204a<C00404i>CP11@D40>c/k03`l?080?Cdm00D0>SXj03`l?00l
?3`0?clo03Xj>P0203/k>`0503Ph>00n?Sh0?3`l03/k>`11@D400`0o?cl02015ADD0?3`l0492@P11
@D40?Shn03lo?`11@D40?clo0P10@4002P0j>SX0@d=303`l?013@d<0GEeM06a/K01ZJVX0Fe]K0492
@P0k>c/204=3@`0<04I6AP15ADD0AdM704i>CP13@d<0?clo04=3@`0o?cl0@41004e=C@16ATH0?Cdm
0P10@4002@0k>c/0?Shn0410@00o?cl0@T9204Y:BP1KFe/0LW9b08B4Q00207alO00O06YZJP1EEED0
CTi>055AD@1PH600EeMG04a<C017AdL0@d=303`l?00k>c/0?clo0492@P11@D40?Shn03/k>`0n?Sh0
?Cdm0451@@10@400ADE504a<C01EEED0LG5a06m_K`1IFET0B4Q804A4A012@T80C4a<04U9B@0203hn
?P0m03dm?@0n?Sh0>c/k04A4A017AdL0?clo0410@018B4P0EUIF06ATI01fMWH0S8b<08j>SP1fMWH0
IVIV05eMG@1EEED0OWin0:RXZ02n_[h0`/;20<C4a03:b/X0[jn_09:BTP1lO7`0K6a/055AD@17AdL0
HV9R08^;R`2RXZ80UIFE08R8R01ZJVX0MGEe06MWI`1>CTh0?clo0410@017AdL0H61P0861P@1hN7P0
Ogmo08:2PP2GUiL0Z:RX08J6QP1PH600IfMW06QXJ01LG5`0GUiN06][J`1cLg<0JVYZ04Q8B011@D40
BDU904Y:BP0203lo?`0?06MWI`2HV9P0a/K60<G5a@2SXj<0QXJ607IfMP1IFET0B4Q804E5A@18B4P0
CDe=06=SH`1aLG40FEUI0080CDe=00h0C4a<04E5A@17AdL0DE5A07YjNP2`/;00YjNW08J6QP1kNg/0
Hf=S075aL@2FUYH0YJFU06][J`80Bd];00D0CTi>04A4A014A4@0@4100451@@020492@P0F04];B`1N
GUh0Ph>30;6a/@33`l<0/;2`08F5Q@1mOGd0NWYj09>CT`22PX80C4a<0451@@0h>3P0>CTi03/k>`0j
>SX0?3`l03lo?`14A4@0B4Q803`l?080>c/k00L0=cLg03dm?@0e=CD0>c/k03Ti>@0n?Sh0B4Q80080
?Cdm02D0>CTi03Xj>P0m?Cd0@410065QH@1fMWH0F5QH04U9B@0m?Cd0>c/k03hn?P0o?cl0?Shn0410
@00k>c/0?3`l03lo?`18B4P0FEUI06EUI@1LG5`0CTi>04Y:BP1ADE40HF5Q05YJFP1LG5`0EEEE055A
D@0k>c/0>CTi03Ph>012@T80C4a<04I6AP0n?Sh0>c/k0080ATI60P1CDe<03P1=CDd0BTY:04i>CP1@
D500FEUI06EUI@1OGel0EUIF04Y:BP17AdL0@41004M7A`18B4P0E5AD0P1RHV807@1OGel0H61P06i^
KP1[Jf/0MgMg096AT@24Q8@0Shn?096AT@2?Shl0RXZ:08B4Q02^[Zh0]kNg0;no_`36a/H0c<c<0<g=
c@35aLD0[Zj^0<71`@2o_kl0aLG50;bl_02][Jd0XZ:R08f=S@1_Kfl0J6QX00gooooo000@ooooo`08
04Q8B015ADD0A4A40492@P11@D40@41004A4A019BDT20492@P050451@@10@400@D5103lo?`10@400
0P13@d<20492@P80@D5100P0A4A40492@P11@D40@D5103dm?@0o?cl0@4100492@P80?Cdm00@0?Shn
03`l?00n?Sh0@4100P0n?Sh01@0m?Cd0@4100410@011@D40AdM70080BTY:0`11@D402P12@T80?clo
04A4A013@d<0ADE504I6AP0o?cl0?Shn04E5A@0m?Cd20410@00:04I6AP1=CDd0DU9B05UIF@1ADE40
C4a<05MGE`1UIFD0J6QX055AD@80@d=301H0@41004Q8B013@d<0?clo03dm?@0o?cl0ATI60492@P1H
F5P0GUiN08R8R02WYjL0/[:b09^KV`1ZJVX0FUYJ05IFEP1BDU80A4A405aLG01eMGD0EeMG0P0m?Cd0
300k>c/0?clo03lo?`13@d<0?Cdm03/k>`0o?cl0>c/k04=3@`14A4@0>CTi03/k>`80?Cdm00P0>SXj
03`l?010@400A4A404a<C00n?Sh0>CTi03`l?080>c/k00<0>SXj0410@00m?Cd00P0l?3`0300f=SH0
?clo04A4A00o?cl0?Cdm03`l?00o?cl0>SXj03/k>`0l?3`0?Cdm04=3@`80?clo00@0?3`l04A4A012
@T80@T920P13@d<07018B4P0ATI604I6AP10@400ADE504A4A010@400@D5103hn?P0m?Cd0?Shn03Xj
>P0i>CT0?3`l0410@00j>SX0?Cdm0410@00m?Cd0BDU904i>CP13@d<0ATI60492@P0l?3`0?clo03dm
?@12@T820451@@040492@P16ATH0ADE504E5A@80?clo01@0@41004U9B@1;Bd/0B4Q803dm?@10@400
ATI604e=C@1@D500AdM704Q8B01;Bd/0CDe=04A4A00o?cl0@D510410@014A4@0@D5103`l?080?Cdm
0P0o?cl04`10@400BDU906IVIP1eMGD0QHF508>3P`20P800Ng]k06QXJ01@D500BDU905ADE01JFUX0
GemO05MGE`12@T80@D5103Ti>@0o?cl00P13@d<03P1:BTX0B4Q803lo?`12@T80@d=304A4A01=CDd0
GEeM061PH01eMGD0J6QX05=CD`1>CTh0@D510P0o?cl0700n?Sh0?Cdm03lo?`0m?Cd0?3`l03hn?P0l
?3`0>SXj03/k>`0l?3`0?clo051@D01`L700TI6A09nOW`2HV9P0X:2P0<71`@2f][H0TY:B08^;R`28
R8P0U9BD09JFUP1gMgL0FEUI055AD@1FEUH206ATI00R05YJFP1LG5`0IfMW08b<S02LW9`0/k>c09nO
W`1_Kfl0HV9R06IVIP1^KVh0KFe]06=SH`25QHD0VYZJ0::RXP2d];@0/K6a09nOW`1_Kfl0CDe=04=3
@`19BDT0CTi>04U9B@1>CTh0@d=303hn?P13@d<0@D5104U9B@14A4@0ADE504];B`80CTi>02L0B4Q8
069RHP2GUiL0alO70;6a/@25QHD0G5aL04Q8B016ATH0DE5A06IVIP1CDe<0C4a<059BDP1LG5`0BTY:
0492@P14A4@0@D5104M7A`1QHF40Ti>C09jNWP2a/K40a<C40:RXZ02_[jl0^k^k0:FUY@2CTi<0S8b<
08F5Q@1fMWH0K6a/06QXJ01OGel0BTY:04A4A01JFUX00P1[Jf/05`1`L700OGem0:FUY@2o_kl0`l?3
0:^[Z`22PX80J6QX065QH@1YJFT0LW9b07AdM01EEED0?Cdm03Lg=`10@400Bd];06ATI01gMgL0QXJ6
08V9R@1cLg<0Bd];0080>c/k00`0>SXj03dm?@13@d<0FUYJ06m_K`1aLG40IFEU04e=C@0m?Cd0>c/k
03Ti>@14A4@204e=C@0>05QHF016ATH0?Cdm03/k>`0j>SX0?3`l03hn?P0m?Cd0>CTi03lo?`0n?Sh0
?3`l0451@@15ADD30492@P0D055AD@1GEeL0DU9B059BDP1;Bd/0@D5103`l?00j>SX0?clo04E5A@1?
Cdl0D51@04Q8B00o?cl0?3`l0451@@1ADE40De=C05ADE01BDU8305MGE`0Z04e=C@17AdL0@41003lo
?`0k>c/0>CTi03Xj>P0l?3`0BDU904Y:BP1=CDd0@4100451@@0n?Sh0@4100451@@15ADD0CDe=04Q8
B01<C4`0FEUI05MGE`1IFET0EEEE059BDP1DE5@0F5QH06m_K`27QhL0T92@08F5Q@2KVi/0Z:RX0;Bd
]02e]KD0^;Rh0:FUY@24Q8@0K6a/08>3P`25QHD0SHf=3Oooool0013ooooo00T0ADE504=3@`14A4@0
ATI604=3@`11@D40@d=304U9B@14A4@00P11@D402`13@d<0@D5103lo?`10@400@T9204=3@`14A4@0
@d=304A4A010@400?clo00<0@T9200<0?Shn03lo?`0n?Sh0100o?cl05`0m?Cd0Bd];04E5A@0j>SX0
?Shn0451@@14A4@0AdM704I6AP1;Bd/0@D510410@00m?Cd0?clo03hn?P0l?3`0?Shn03dm?@0o?cl0
A4A403hn?P0k>c/0?clo0080@T920P0n?Sh00`13@d<0@41004=3@`020410@00=03dm?@0l?3`0?Shn
03lo?`11@D40@T9204Y:BP1=CDd0BDU904=3@`12@T80CDe=04A4A0020492@P0J04Q8B01>CTh0Bd];
04a<C01ADE40FUYJ04U9B@0n?Sh0ATI60492@P19BDT0HF5Q0861P@1fMWH0BDU90410@00k>c/0?Shn
03Xj>P0l?3`0?clo03`l?00m?Cd0@41003dm?@0l?3`203/k>`0703lo?`0n?Sh0?3`l03/k>`13@d<0
?clo03/k>`0203Xj>P0<03lo?`0l?3`0?3`l03/k>`0o?cl0?Shn03dm?@0n?Sh0>CTi03Xj>P0k>c/0
>SXj0P0k>c/06P0i>CT0>SXj03Ph>00l?3`0@d=304A4A012@T80?clo0451@@14A4@0@41003dm?@0n
?Sh0?clo0410@016ATH0@T9203hn?P10@400A4A403hn?P17AdL0?Shn03`l?010@400>c/k0P0o?cl0
2@10@400ADE505=CD`15ADD0ATI604Q8B011@D40?3`l0410@00203Ti>@0D03`l?00n?Sh0?Cdm0451
@@15ADD0A4A40451@@0k>c/0@d=303lo?`0i>CT0?Shn0410@013@d<0@D5103`l?010@400A4A404];
B`14A4@20451@@0D04A4A018B4P0@T920410@00o?cl0@41004A4A012@T80@D510410@014A4@0?Shn
03lo?`12@T80Cdm?06UYJ@1SHf<0H61P06ATI01IFET204];B`0;04m?C`1DE5@0F5QH04i>CP13@d<0
CDe=05ADE01<C4`0@T9204=3@`16ATH00P0n?Sh04P10@400@D5104M7A`1>CTh0B4Q8059BDP1`L700
EeMG04I6AP0m?Cd0?Shn03dm?@0k>c/0?Shn03/k>`0l?3`0>CTi03hn?P80?clo00h0@41003hn?P0m
?Cd0B4Q805ADE01ZJVX0U9BD0:ZZZP2UYJD0U9BD09fMW@2HV9P0Shn?06MWI`80D51@02<0BDU904];
B`12@T80?Cdm03`l?00n?Sh0@41003hn?P11@D40?Shn0492@P1:BTX0G5aL061PH01hN7P0Ph>308b<
S021PH40EEEE0410@01KFe/0Ti>C0;Rh^02e]KD0^;Rh09bLW01JFUX0A4A403hn?P0j>SX0?Cdm03Xj
>P13@d<0DE5A03dm?@0303`l?00403dm?@14A4@0Fe]K0:>SX`80_;bl05H0/;2`0;Zj^P3Cdm<0c/k>
0:BTY01hN7P0MWIf06][J`15ADD0@41004A4A01WIfL0I6AT04Y:BP11@D40BDU9055AD@1XJ6P0RXZ:
0:RXZ02n_[h0d];B0=_Kf`3AdM40f=SH0=CDe03@d=00bLW90:^[Z`2XZ:P0/;2`08^;R`1NGUh0BTY:
059BDP14A4@0E5AD06IVIP2:RXX0ZZZZ0:VYZ@26QXH0M7Ad08R8R02=SHd0X:2P08V9R@1QHF40De=C
05IFEP1]KFd0HV9R05UIF@14A4@0?Shn04a<C01MGEd0NGUi09JFUP2`/;00Z:RX07inOP1PH600CTi>
04=3@`1FEUH0Hf=S05QHF01RHV80WinO0;Ng]`2b/[80T92@065QH@19BDT0@D5104=3@`1JFUX0JFUY
05eMG@1ADE40C4a<05eMG@1DE5@0ATI603/k>`80>SXj0200?Shn055AD@1;Bd/0?clo03Ti>@0j>SX0
>c/k04M7A`1NGUh0JFUY06a/K01CDe<0@41003/k>`0i>CT0>c/k04U9B@1>CTh0C4a<059BDP1:BTX0
@41004=3@`1<C4`0B4Q804a<C01;Bd/0B4Q804a<C01EEED0ATI603hn?P80>SXj00T0>c/k03Xj>P12
@T80@D5104E5A@0o?cl0@d=304i>CP16ATH00P0l?3`03@0m?Cd0>3Ph03/k>`0h>3P0?Cdm0410@01@
D500EUIF05EEE@1JFUX0DU9B051@D018B4P00P13@d<03`17AdL0Bd];04U9B@17AdL0ATI604U9B@1D
E5@0EUIF059BDP1?Cdl0F5QH04a<C018B4P0ATI604a<C00=ooooo`004?ooool03018B4P0ADE504E5
A@14A4@0ADE504A4A015ADD0ATI60451@@14A4@0@41004I6AP80@D5100@0@T9204A4A014A4@0A4A4
0P13@d<01P14A4@0ADE504Y:BP13@d<0@41003lo?`@0?Shn01@0@d=303lo?`14A4@0A4A40451@@0l
?3`0?Cdm03hn?P11@D40@d=30492@P16ATH0?clo03hn?P14A4@0ADE503lo?`17AdL0A4A403`l?080
?Shn00<0?Cdm03/k>`0m?Cd00P0n?Sh03@0m?Cd0@d=303Xj>P11@D40ATI60410@012@T80?Shn03dm
?@0k>c/0@41004U9B@0n?Sh00P10@40204=3@`0@03hn?P11@D40>SXj0451@@10@400@d=30410@00o
?cl0@D5104I6AP10@400>CTi03lo?`0m?Cd0ADE504e=C@80CTi>0140EUIF04a<C01BDU80GEeM04m?
C`0n?Sh0C4a<05IFEP1EEED0GemO04A4A00n?Sh0@d=304A4A01QHF40BTY:03`l?00203lo?`0A03hn
?P0k>c/0?3`l03Xj>P0i>CT0>c/k03hn?P0l?3`0>CTi03dm?@11@D40?clo03`l?00k>c/0?clo03`l
?00m?Cd00`0l?3`20410@00704A4A015ADD0@d=30451@@0o?cl0@41003lo?`0203hn?P0?03dm?@0l
?3`0?Cdm03`l?011@D40?Cdm03/k>`10@400ADE503lo?`0l?3`0ATI60492@P0n?Sh0@D510080@d=3
00L0Bd];0451@@0o?cl0>SXj03hn?P0o?cl0?Cdm0080?Shn00T0@T9203dm?@0n?Sh0?3`l03dm?@10
@400A4A403`l?00k>c/00P0l?3`05@0m?Cd0@D5103lo?`0o?cl0?Shn03lo?`12@T80@d=304I6AP12
@T80@41003Ti>@0o?cl0BDU904I6AP14A4@0ADE50410@014A4@0>c/k03hn?P0203lo?`0;03/k>`0o
?cl0@T9204E5A@1BDU80LG5a07IfMP1HF5P0ATI604Q8B01=CDd00P13@d<02P12@T80@D5104M7A`13
@d<0BTY:0492@P10@400BDU905YJFP1:BTX204A4A00>04=3@`18B4P0?clo03hn?P14A4@0ATI603Xj
>P0n?Sh0ADE50410@00m?Cd0@D5103hn?P11@D4204I6AP07065QH@1LG5`0GUiN06=SH`1QHF40I6AT
06EUI@0205QHF00706][J`26QXH0O7al069RHP1>CTh0BTY:04E5A@020451@@050410@00o?cl0@T92
03hn?P13@d<00P0m?Cd203lo?`0>04Q8B012@T80@D5104A4A01FEUH0Kfm_07YjNP1lO7`0M7Ad05UI
F@18B4P0G5aL06][J`1eMGD207moO`0608F5Q@1ZJVX0Cdm?04M7A`1:BTX0CDe=0P11@D40301BDU80
>c/k03`l?00l?3`0@D5104I6AP1CDe<0VIVI0<G5a@2b/[80Vi^K0:ZZZP80^[Zj01@0XZ:R08f=S@20
P800KVi^06UYJ@1MGEd0C4a<04E5A@11@D40BDU904i>CP1iNGT0TI6A0:n_[`33`l<0d=3@0<K6aP3E
eMD0emOG0=?Cd`80clo?0580][Jf08^;R`1kNg/0KVi^05]KF`1IFET0Cdm?04I6AP0m?Cd0@T9204U9
B@16ATH0HF5Q06m_K`23Ph<0Ogmo08j>SP1]KFd0EUIF061PH01TI6@0HV9R055AD@16ATH0BTY:04e=
C@1DE5@0ATI60492@P19BDT0Jf][08n?S`2ATI40UiNG09FEU@2JVYX0PX:206ATI01?Cdl0@T92059B
DP27QhL0XZ:R09ZJVP2<S8`0Ogmo05aLG01ADE40BDU904i>CP1NGUh0K6a/08b<S02KVi/0OWin0820
P01gMgL0Lg=c05mOG`13@d<0>c/k04a<C01MGEd0F5QH06EUI@1KFe/0ATI603/k>`11@D40GUiN06][
J`1dM7@0I6AT055AD@1:BTX0A4A404Q8B01<C4`0GUiN065QH@1OGel0Fe]K0P1CDe<0:01GEeL0Bd];
04U9B@1:BTX0AdM70451@@15ADD0CTi>05ADE019BDT0?3`l03/k>`12@T80ADE504i>CP1ADE40D51@
04i>CP17AdL0A4A404];B`1?Cdl0CTi>04e=C@17AdL0@D5103Xj>P0l?3`0@41004];B`1HF5P0FEUI
055AD@1EEED0G5aL05MGE`1?Cdl0BTY:04];B`10@4020451@@0=03`l?00o?cl0?3`l03`l?00n?Sh0
=CDe03Lg=`0i>CT0>c/k03Ti>@0k>c/0>CTi03Xj>P0=ooooo`004?ooool01@15ADD0ATI604U9B@17
AdL0A4A40080ADE500H0@d=304A4A014A4@0?Shn0451@@13@d<304A4A0070451@@13@d<0@T920451
@@13@d<0A4A404=3@`0204A4A00:0451@@10@400?clo0410@00o?cl0@41003dm?@12@T80@41003hn
?P80?clo00H0@D5103hn?P0l?3`0>c/k03hn?P11@D4203hn?P090451@@0k>c/0A4A40492@P0m?Cd0
?Shn03dm?@0l?3`0@4100080?3`l00d0@D5103`l?013@d<0A4A403`l?013@d<0@D5103lo?`11@D40
ADE503Xj>P0o?cl0AdM700<0@41000L0?clo0410@011@D40@T920410@015ADD0@D510080>c/k0100
@4100492@P10@400?Shn03/k>`0n?Sh0@D510410@012@T80?Shn03`l?013@d<0@41004=3@`0o?cl0
ATI60P14A4@0:P1ADE40IfMW05QHF01<C4`0ADE50492@P15ADD0DE5A06EUI@1[Jf/0DU9B04m?C`1=
CDd0ADE503Xj>P0n?Sh0?clo03hn?P0l?3`0>c/k03dm?@12@T80@D5103dm?@0o?cl0>c/k0451@@0o
?cl0ATI6055AD@1QHF40N7Qh09FEU@2NWYh0S8b<04Y:BP0k>c/0?Cdm03hn?P0o?cl0?3`l03lo?`80
@d=300P0@41003dm?@0m?Cd0@D5103hn?P10@400?clo03dm?@80@T9200D0Bd];0492@P11@D40?Shn
0410@00203lo?`030451@@0o?cl0?Cdm0080@4100`0l?3`01`10@400@D510451@@10@400?clo03Xj
>P0l?3`00P0j>SX04@11@D40@d=303`l?00o?cl0A4A403lo?`12@T80@41003`l?010@400BDU90410
@00o?cl0?Shn0410@014A4@0@4100080@d=301l0?Shn03lo?`11@D40?3`l03hn?P0k>c/0?Shn03lo
?`1BDU80H61P065QH@1:BTX0A4A403hn?P13@d<0A4A404I6AP0n?Sh0@T9204A4A012@T80?clo0410
@00l?3`0@T9204=3@`16ATH0DU9B05EEE@1>CTh0ATI60080?Shn00@0?clo03hn?P0o?cl0ADE50P1M
GEd09`1@D500@D510451@@10@400FEUI06EUI@1JFUX0De=C05YJFP1KFe/0IVIV05]KF`1:BTX0ATI6
04M7A`1;Bd/0D51@04M7A`1:BTX0ADE50451@@0m?Cd0>c/k03Xj>P0i>CT0>SXj03dm?@0j>SX0?clo
03`l?012@T80@d=304m?C`1>CTh0A4A404M7A`1@D500OGem09VIV@0209fMW@1>08f=S@22PX80Lg=c
05iNGP1CDe<0FEUI059BDP1:BTX0@d=303lo?`13@d<0@T92055AD@1[Jf/0T92@09NGU`1IFET0?Cdm
0492@P10@400AdM705ADE01YJFT0S8b<0:2PX02`/;00YJFU07EeM@1>CTh0K6a/0:VYZ@2_[jl0PH61
06EUI@1?Cdl0ATI604=3@`12@T80?Cdm03/k>`0n?Sh0BDU908N7Q`3Bd]80emOG0;jn_P2m_Kd0/K6a
0;Vi^@3;bl/0^;Rh0:^[Z`2MWId0NGUi051@D013@d<0@D5103lo?`10@400A4A40492@P1IFET0N7Qh
09FEU@2QXJ40U9BD09FEU@23Ph<0KVi^08V9R@2h^;P0Z:RX0:NWY`2XZ:P0WYjN08f=S@27QhL0NGUi
0P1fMWH06P1RHV80I6AT08^;R`2CTi<0];Bd0:ZZZP1_Kfl0F5QH04];B`19BDT0AdM704a<C01PH600
MWIf07=cL`1^KVh0K6a/05=CD`14A4@0?clo04Q8B01CDe<0NGUi096AT@2NWYh0QXJ60P2@T9007020
P800KVi^04Y:BP13@d<0?Cdm04=3@`1SHf<0SXj>08V9R@1iNGT0LW9b059BDP18B4P0Cdm?05ADE01]
KFd0IFEU05iNGP1ADE40EUIF05UIF@1LG5`0HF5Q05EEE@1@D500AdM704=3@`1=CDd204m?C`0B055A
D@1=CDd0?Shn04m?C`1NGUh0HV9R05iNGP1KFe/0Cdm?04U9B@1ADE40EUIF05QHF01PH600HF5Q05QH
F01JFUX0EUIF0P19BDT07P1;Bd/0F5QH06=SH`1HF5P0CDe=059BDP1HF5P0DE5A05iNGP1QHF40GemO
05QHF01@D500CTi>04a<C015ADD0DE5A04e=C@15ADD0>c/k03lo?`10@400?Shn0451@@0k>c/0>SXj
03Ti>@0h>3P0>SXj03Ti>@80=cLg00<0=CDe03Ph>00g=cL03Oooool0013ooooo00D0AdM704I6AP17
AdL0ADE504=3@`0204E5A@0<04A4A012@T80?Cdm0410@013@d<0@D510492@P11@D40?clo03hn?P10
@400@D510P0o?cl01012@T80@D510410@00m?Cd20410@00303lo?`11@D40@D510080?Shn00@0@T92
04=3@`11@D40@4100P0n?Sh20410@00504=3@`0n?Sh0>c/k03dm?@13@d<00P11@D401P10@400?clo
03hn?P0n?Sh0?Cdm03/k>`80@T920140?clo03dm?@0o?cl0?Cdm0451@@10@400@d=303lo?`13@d<0
?Cdm0410@00k>c/0@T9203/k>`0l?3`0?clo03dm?@0203hn?P0303dm?@10@400@D510080@41000@0
>SXj03hn?P10@400@D510P0o?cl01P13@d<0?clo0451@@0m?Cd0@D5103/k>`80@D510P0m?Cd20492
@P0H0451@@10@400ADE504=3@`0n?Sh0?Cdm03lo?`0m?Cd0ATI604e=C@1fMWH0Ph>3065QH@1EEED0
B4Q80451@@10@400CTi>05]KF`1QHF40GUiN05ADE015ADD0?3`l0P0k>c/00`0o?cl0Bd];05aLG002
07EeM@0;08V9R@2FUYH0Vi^K0:n_[`2`/;00WYjN07IfMP1:BTX0A4A404=3@`0l?3`00P0m?Cd01@0l
?3`0>CTi03Xj>P0j>SX0?Shn0080?Cdm00<0?3`l0451@@13@d<00P13@d<01010@400>SXj03`l?00m
?Cd203hn?P0403/k>`0o?cl0?Cdm0451@@80?clo0P0l?3`00`0m?Cd0>c/k03lo?`0203hn?P0304A4
A00o?cl0>c/k00<0?3`l0P11@D400`12@T80@41003Ti>@0203lo?`0503hn?P0k>c/0>CTi03dm?@11
@D400`0o?cl03P0k>c/0?clo03`l?00o?cl0@d=30451@@0k>c/0@4100451@@0o?cl0ADE505MGE`18
B4P0@d=30`0m?Cd0100n?Sh0@41004U9B@15ADD20451@@0>03lo?`0m?Cd0@D5103lo?`10@400@D51
04Q8B01ADE40Bd];04Q8B010@400AdM704Q8B01@D50204a<C00@051@D01GEeL0AdM704U9B@1?Cdl0
ADE504m?C`1YJFT0F5QH04E5A@13@d<0?3`l0492@P17AdL0@d=304Y:BP80ADE50`0m?Cd08@0j>SX0
>c/k03Xj>P11@D40?Cdm03`l?00k>c/0>CTi04M7A`18B4P0ATI604Y:BP1GEeL0GUiN08R8R02EUID0
LW9b06a/K022PX80V9RH08^;R`1gMgL0GUiN05EEE@1@D500ATI604U9B@1DE5@0Cdm?0492@P0m?Cd0
A4A404E5A@0204];B`2905iNGP1KFe/0GEeM05iNGP1EEED0EeMG065QH@1mOGd0VYZJ08Z:RP1gMgL0
IVIV05iNGP1>CTh0ADE5059BDP1DE5@0D51@06e]K@2<S8`0O7al08B4Q01gMgL0HF5Q06UYJ@1SHf<0
De=C051@D01TI6@0UIFE0;Vi^@2YZJT0TY:B09RHV02QXJ40^;Rh0;jn_P2GUiL0LG5a06MWI`1_Kfl0
De=C03lo?`0n?Sh0A4A405mOG`1lO7`0FEUI06=SH`2YZJT0d=3@0<W9b@2WYjL0Hf=S04m?C`1>CTh0
D51@071`L025QHD0V9RH08>3P`1WIfL0KFe]07MgM`1eMGD0Jf][04Y:BP1QHF40WinO0;Fe]@2OWil0
LW9b075aL@1MGEd0Cdm?04M7A`1CDe<0FEUI04I6AP12@T80C4a<04U9B@12@T80?clo04I6AP1HF5P0
KVi^07EeM@1kNg/0RHV908j>SP22PX80OWin07YjNP1/K6`0BTY:0451@@12@T80@D5104];B`1KFe/0
Jf][0861P@1ZJVX0HV9R04m?C`16ATH0AdM704E5A@1:BTX0@T9203`l?017AdL0GUiN05=CD`1;Bd/0
EeMG051@D019BDT0>CTi03Ph>00i>CT0AdM7055AD@1BDU80BTY:0492@P1=CDd0Fe]K069RHP1EEED0
BDU904Y:BP1=CDd0BDU904a<C01HF5P00P1LG5`05P1EEED0EUIF04];B`1ADE40De=C04a<C01BDU80
G5aL05eMG@1FEUH0FEUI065QH@1RHV80F5QH05EEE@1KFe/0EUIF05ADE01FEUH0D51@04M7A`18B4P2
04Y:BP0904I6AP11@D40?Cdm03hn?P0j>SX0?3`l03lo?`0j>SX0>c/k0080>SXj0P0g=cL01@0i>CT0
?3`l03Lg=`0i>CT0?3`l00gooooo000@ooooo`0504E5A@14A4@0B4Q804A4A017AdL00P13@d<04@12
@T80?clo04=3@`11@D40@d=30451@@0o?cl0@T9203`l?00n?Sh0?clo0410@00n?Sh0?Cdm0492@P0l
?3`0?clo0080?Cdm00<0?3`l0410@012@T800P11@D400`0o?cl0AdM704E5A@020410@0060451@@10
@400@D510410@012@T80?Shn0P0m?Cd20451@@050410@00n?Sh0>SXj03dm?@0o?cl00P0n?Sh203dm
?@0703Xj>P0o?cl0?3`l03Xj>P0o?cl0>SXj0410@0020451@@80?3`l0P0m?Cd01@0o?cl0>c/k03`l
?00l?3`0?clo0080?Shn0P0l?3`02@0k>c/0?clo03`l?00n?Sh0?clo03hn?P0l?3`0>SXj03`l?003
0410@00A0492@P0k>c/0@T9203dm?@0n?Sh0@41003dm?@0o?cl0@4100492@P0m?Cd0@D5103Xj>P0n
?Sh0?clo04M7A`1@D5000`1CDe<01`14A4@0?Shn03lo?`0o?cl0ATI604a<C01?Cdl00P1>CTh02016
ATH0?clo03Xj>P0l?3`0@T9204A4A010@400?Shn0P16ATH06P1?Cdl0C4a<04U9B@1ADE40FEUI06AT
I01RHV80EUIF04a<C013@d<0A4A40492@P11@D40?Shn03`l?00n?Sh0?clo03`l?00k>c/0?3`l0410
@01=CDd0HV9R05aLG01OGel0EEEE0P13@d<00`10@400?Cdm03hn?P0203dm?@0I03Ti>@0k>c/0?3`l
0410@00l?3`0@T920451@@0l?3`0@41004E5A@16ATH0@41004M7A`1<C4`0ADE504I6AP11@D40Cdm?
059BDP17AdL0ADE504a<C010@400?Shn03`l?00203lo?`0803`l?00n?Sh0@41003dm?@0o?cl0@d=3
03/k>`0n?Sh203dm?@0L04=3@`0n?Sh0A4A404a<C01?Cdl0De=C04Y:BP0o?cl0@D5103hn?P0m?Cd0
>3Ph03dm?@0j>SX0>c/k03lo?`15ADD0?Cdm03/k>`0m?Cd0?clo03/k>`0m?Cd0>c/k04E5A@1FEUH0
FEUI05MGE`80F5QH00L0CTi>04=3@`14A4@0@D5103lo?`0k>c/0@T920080AdM703@0?Shn04=3@`11
@D40?clo04I6AP17AdL0BDU904=3@`1;Bd/0A4A404=3@`10@400@T9203/k>`0i>CT0>SXj03/k>`0j
>SX0@41005MGE`1:BTX0?Cdm03`l?01<C4`0FUYJ05mOG`1>CTh0Cdm?05]KF`1SHf<0M7Ad071`L01R
HV80J6QX05]KF`1?Cdl0@T9204=3@`14A4@0@d=304a<C01IFET0De=C051@D00n?Sh0@D5104M7A`1L
G5`0KVi^06QXJ01UIFD0FUYJ0P1<C4`0201VIVH0M7Ad0861P@24Q8@0LW9b069RHP1EEED0BDU90P14
A4@05P1=CDd0GemO079bLP1eMGD0LW9b07UiN@1^KVh0EEEE05QHF01CDe<0DU9B06ATI01ZJVX0IFEU
05mOG`1QHF40Jf][06MWI`1UIFD0KFe]07=cL`1_Kfl207EeM@0D06UYJ@1VIVH0EeMG04m?C`12@T80
@D5104U9B@1JFUX0LW9b08^;R`1/K6`0OGem09nOW`2ZZZX0_kno0::RXP1fMWH0BTY:03dm?@0o?cl2
04=3@`0X03hn?P0o?cl0ADE504I6AP1TI6@0IVIV0410@00n?Sh0L71`07YjNP1GEeL0Fe]K071`L01d
M7@0GemO05eMG@1IFET0IfMW06EUI@1eMGD0P82009nOW`2JVYX0Ogmo08>3P`2IVIT0QhN7092@T029
RHT0UiNG08j>SP1oOgl0KFe]06MWI`1RHV80Fe]K04e=C@18B4P0CDe=06a/K080Ph>30140Jf][04Y:
BP12@T80@4100451@@0n?Sh0>CTi03dm?@0k>c/0@d=304e=C@1WIfL0EUIF0492@P0k>c/0@T9203Xj
>P0203dm?@0Y03Xj>P18B4P0De=C04a<C01>CTh0D51@05EEE@1ADE40>3Ph03hn?P0m?Cd0?Shn0492
@P1?Cdl0De=C04Y:BP1<C4`0BTY:04I6AP1<C4`0Bd];04U9B@1;Bd/0EeMG04e=C@1BDU80EUIF05EE
E@1ADE40CTi>05YJFP1KFe/0ATI604];B`1?Cdl0BDU905ADE01HF5P0CDe=04U9B@17AdL00P13@d<0
3@17AdL0?3`l03Ph>00g=cL0>CTi03Lg=`0j>SX0>CTi03Xj>P0h>3P0=cLg03De=@0h>3P00P0i>CT0
0`0h>3P0>CTi03Ti>@0=ooooo`004?ooool0401MGEd0K6a/08J6QP1lO7`0NWYj05IFEP17AdL0@T92
0410@016ATH0A4A404Q8B014A4@0?clo04=3@`0n?Sh204=3@`0>0451@@0n?Sh0?clo0492@P16ATH0
@T9203hn?P10@400>c/k03hn?P10@400@T9204=3@`11@D4203hn?P80@D5100L0A4A403lo?`12@T80
@d=30451@@13@d<0@T920080?Cdm00T0@4100492@P12@T80>c/k03hn?P10@400@T920410@00k>c/0
0P0o?cl20410@00@03/k>`0n?Sh0?Shn03Xj>P0n?Sh0?clo03dm?@0j>SX0@D5103hn?P0o?cl0?Cdm
03lo?`0l?3`0>c/k03`l?0<0?Cdm00@0?clo03`l?00k>c/0>3Ph0P0l?3`00`0k>c/0?3`l03lo?`02
03lo?`80?Cdm00d0?3`l0492@P0l?3`0?3`l03hn?P0o?cl0?Cdm03`l?00j>SX0@T920410@00k>c/0
?Cdm0080@D5101X0@T9204=3@`0k>c/0@T9203lo?`0m?Cd0?Shn03Ti>@0n?Sh0>c/k03dm?@0n?Sh0
@41003Xj>P0k>c/0?clo04=3@`0o?cl0@41003`l?00k>c/0?clo0451@@0o?cl0?Shn0492@P80@d=3
01l0@D510410@00m?Cd0@T920451@@18B4P0ATI60410@00k>c/0?Cdm0492@P10@400>c/k03Ti>@0l
?3`0?Cdm05MGE`1dM7@0L71`05eMG@1EEED0A4A40410@012@T80@41004=3@`1;Bd/0A4A40410@00l
?3`0?clo0080?Shn01/0@D5104Q8B014A4@0EEEE07alO01kNg/0J6QX05iNGP10@400?Shn03lo?`0k
>c/0@T9204I6AP13@d<0?Cdm03`l?00k>c/0>SXj03hn?P12@T80?clo03/k>`0o?cl0@D5103Ti>@11
@D400P12@T820451@@0>04Y:BP17AdL0?Shn03hn?P12@T80ADE50492@P0o?cl0@T9204U9B@15ADD0
?clo0451@@0n?Sh203lo?`0@0451@@1<C4`0?clo03hn?P1FEUH0K6a/05MGE`18B4P0EEEE06a/K01W
IfL0EEEE04U9B@11@D40?Shn0451@@80?Cdm00D0?3`l03Xj>P0i>CT0?3`l03Xj>P0203`l?00303lo
?`0m?Cd0?clo0080@T920240?Shn03`l?010@400ADE503lo?`0k>c/0?Shn03/k>`0j>SX0>c/k03dm
?@0j>SX0>3Ph03dm?@0n?Sh0?clo04M7A`1OGel0Hf=S055AD@1<C4`0BTY:04e=C@1SHf<0J6QX06AT
I01QHF40EUIF04M7A`10@400?clo0451@@12@T800P11@D403P14A4@0@D5105QHF01TI6@0N7Qh07Mg
M`1YJFT0Hf=S05]KF`1PH600EeMG05aLG01ZJVX0Kfm_0P1^KVh04@1UIFD0MWIf07inOP1/K6`0DU9B
04=3@`19BDT0C4a<05MGE`1^KVh0LW9b071`L01RHV80BTY:04A4A01:BTX0@4100080@D5100/0C4a<
05IFEP1@D500Cdm?04];B`1IFET0DE5A051@D01PH600HV9R05]KF`0204i>CP1204U9B@15ADD0B4Q8
055AD@1@D500F5QH05YJFP1MGEd0G5aL05=CD`1HF5P0JVYZ079bLP20P800Lg=c04a<C00l?3`0@410
04Y:BP14A4@0AdM704A4A01NGUh0JFUY06EUI@1ADE40E5AD05QHF01?Cdl0D51@061PH01VIVH0Lg=c
07inOP1NGUh0C4a<04E5A@12@T80BTY:05QHF01oOgl0SXj>0::RXP2FUYH0Ti>C0::RXP2/[:`0S8b<
07alO01cLg<0KFe]06QXJ01SHf<0GUiN05ADE018B4P0G5aL04m?C`1CDe<0IFEU06m_K`1YJFT0IFEU
05YJFP1;Bd/0@d=30`0o?cl0:P1ADE40De=C04U9B@19BDT0C4a<055AD@0o?cl0?Shn0451@@16ATH0
B4Q804Y:BP1<C4`0ADE504I6AP15ADD0AdM704];B`1=CDd0A4A403/k>`11@D40@41004M7A`1ADE40
Cdm?04];B`16ATH0AdM704i>CP1<C4`0BDU904m?C`1FEUH0GemO06YZJP1[Jf/0H61P065QH@1LG5`0
De=C05ADE080De=C01<0B4Q80492@P1>CTh0EUIF04i>CP1GEeL0GUiN04e=C@15ADD0@D5103hn?P12
@T80?Shn03Xj>P0m?Cd0=SHf03/k>`0h>3P0?3`l0080@d=300@0?3`l03Ti>@0i>CT0>CTi0P0g=cL2
03Hf=P0303De=Ooooooooooo00_ooooo000@ooooo`0K0:b/[02TY:@0T92@09fMW@2UYJD0Ti>C06AT
I01CDe<0NGUi0:6QX@2TY:@0RHV9079bLP1fMWH0K6a/04m?C`17AdL0ADE504i>CP19BDT0CDe=04M7
A`15ADD0@d=304A4A019BDT0Bd];0080D51@0180ATI604Q8B018B4P0ADE503`l?010@400?clo0410
@00o?cl0@d=304M7A`11@D40@41003`l?00m?Cd0@D510410@00o?cl20492@P0703hn?P12@T80?clo
03hn?P13@d<0?clo0451@@020410@00;03lo?`10@400?Cdm0451@@13@d<0?Shn0451@@0n?Sh0ADE5
03dm?@10@4000P0m?Cd02P11@D40?3`l0410@00n?Sh0@T9203dm?@0o?cl0@41003dm?@0k>c/203Xj
>P0403`l?00m?Cd0?3`l03/k>`80?clo0`0n?Sh0300k>c/0@D510410@010@400?3`l03Xj>P0l?3`0
?Shn03dm?@10@400?Cdm03`l?080>c/k00d0?clo0492@P16ATH0@T9203hn?P0m?Cd0?3`l03lo?`0n
?Sh0@4100451@@0n?Sh0?clo0080@41000<0?clo03/k>`0m?Cd00P0m?Cd01@10@400?clo04A4A01<
C4`0B4Q80080?Shn00L0@D510492@P11@D40@d=303hn?P0o?cl0@D5100<0?clo00L0@T920410@00n
?Sh0?Shn04A4A011@D40AdM700<0@41000P0?3`l0492@P18B4P0CDe=05EEE@1DE5@0EEEE04E5A@80
?clo01L0@d=30410@015ADD0CTi>05YJFP14A4@0E5AD07MgM`1nOWh0CTi>04m?C`17AdL0?Cdm03/k
>`0l?3`0@D5104i>CP18B4P0@T9203lo?`10@400A4A404E5A@020451@@0>0492@P0l?3`0@d=30410
@012@T80@41003lo?`10@400@d=30451@@19BDT0@D5103lo?`12@T8203lo?`0603hn?P0i>CT0?Shn
0451@@0o?cl0A4A40P0m?Cd02010@400?clo04A4A00o?cl0A4A404a<C01;Bd/0@4100P11@D402015
ADD0@D510492@P12@T80>c/k03Ti>@10@400?clo0P14A4@02@0n?Sh0@T9203`l?00n?Sh0?clo03hn
?P19BDT0Cdm?04U9B@0203/k>`0E03`l?00i>CT0@d=303hn?P12@T80B4Q804=3@`0l?3`0@41003lo
?`0n?Sh0>3Ph03/k>`0h>3P0>CTi03Ph>010@400AdM704=3@`0m?Cd0@4100080ADE501X0AdM70451
@@15ADD0?clo0410@00l?3`0>c/k03Ti>@0m?Cd0@D5104E5A@1ADE40F5QH06EUI@1fMWH0M7Ad06=S
H`19BDT0Bd];06IVIP1`L700IFEU05QHF01VIVH0LW9b065QH@80De=C01X0H61P07IfMP1`L700Fe]K
04=3@`1@D500De=C06EUI@1XJ6P0Fe]K04a<C018B4P0@d=303`l?014A4@0C4a<05=CD`1JFUX0GUiN
06UYJ@1EEED0B4Q804U9B@1;Bd/0CTi>04Y:BP80AdM701@0ATI604U9B@14A4@0@T9204];B`15ADD0
Cdm?05=CD`1KFe/0HF5Q06ATI01[Jf/0GemO05YJFP1DE5@0HV9R05mOG`1MGEd0FEUI05mOG`80E5AD
01/0@T9203lo?`0o?cl0ATI604e=C@1MGEd0HF5Q05UIF@1RHV80QHF508N7Q`1/K6`0OWin07MgM`1j
NWX0L71`06a/K01BDU80ADE50492@P0n?Sh0C4a<069RHP1BDU80@d=305=CD`1lO7`00P2BTY804`1[
Jf/0CDe=03dm?@0m?Cd0@T920410@011@D40EUIF05eMG@1ADE40Cdm?05=CD`1OGel0LW9b07IfMP1n
OWh0K6a/04i>CP16ATH00P0l?3`01010@400D51@04];B`0k>c/203Ti>@0?03Xj>P0n?Sh0ATI604m?
C`15ADD0?clo03`l?015ADD0A4A403hn?P0h>3P0>SXj03Ph>00g=cL0A4A40080ATI600P0BDU904e=
C@13@d<0>3Ph0410@015ADD0Cdm?04I6AP80?Cdm0140Bd];05QHF01OGel0I6AT05QHF01MGEd0FEUI
055AD@1<C4`0E5AD059BDP1KFe/0De=C05EEE@1LG5`0EEEE055AD@0204];B`80@41000<0?Shn03De
=@0m?Cd00P0o?cl01@0l?3`0<S8b03De=@0f=SH0=CDe0080?Shn0P0d=3@00`0i>CT0=SHf03Hf=P02
03Lg=`0303Hf=P0d=3Cooooo00cooooo000@ooooo`0=07YjNP1_Kfl0De=C05=CD`1OGel0Jf][065Q
H@1LG5`0S8b<0;6a/@2][Jd0RXZ:07MgM`0207=cL`07061PH01DE5@0GUiN07IfMP1ZJVX0IFEU05eM
G@0204Y:BP0R05]KF`1gMgL0SHf=09bLW02PX:00RXZ:08R8R01fMWH0EeMG0492@P0l?3`0@T9203hn
?P0l?3`0?Shn04=3@`10@400A4A40410@00n?Sh0@T9203hn?P10@400@D5103dm?@0n?Sh0@d=30451
@@14A4@0@D5103dm?@0l?3`0?Shn03/k>`80@41000L0@D510410@010@400@41003hn?P10@400@d=3
0080?clo00@0>c/k03`l?00m?Cd0>CTi0P0k>c/01P0n?Sh0>CTi03Hf=P0k>c/0>SXj0451@@80?3`l
0100?Shn03`l?00j>SX0?3`l03dm?@0l?3`0>CTi03/k>`0o?cl0?Cdm03lo?`11@D40ATI603Xj>P0o
?cl0?3`l0P0o?cl203dm?@0403Xj>P0l?3`0?clo0410@080?3`l00<0@41003lo?`0k>c/00P0j>SX0
3011@D40?Shn03dm?@0k>c/0@41003dm?@0k>c/0?Cdm03hn?P0l?3`0>SXj0410@080Bd];00P0AdM7
04=3@`11@D40>SXj03/k>`14A4@0ADE503dm?@80>CTi0`0l?3`02P0m?Cd0>c/k03hn?P0n?Sh0?clo
0451@@12@T80>SXj03/k>`10@40203dm?@2604a<C01GEeL0E5AD04Y:BP19BDT0?Cdm03`l?010@400
?clo03dm?@0l?3`0@d=304M7A`1?Cdl0CDe=04M7A`14A4@0?Shn03dm?@10@400CTi>05=CD`11@D40
AdM705EEE@1GEeL0Hf=S055AD@19BDT0Cdm?05ADE01PH600EeMG04M7A`0n?Sh0@D5104Y:BP1[Jf/0
MGEe04a<C012@T80?clo04I6AP14A4@0ADE50492@P0m?Cd0>SXj03lo?`0g=cL0@D5103Xj>P0m?Cd0
@D5103/k>`0l?3`0ADE504U9B@0o?cl0>c/k03Xj>P10@400BDU904A4A015ADD0A4A403Xj>P14A4@0
=CDe03dm?@10@400?Shn0451@@0m?Cd0>CTi0410@011@D40?Cdm0410@00m?Cd0?clo03/k>`0o?cl0
@41004U9B@1OGel0EeMG04I6AP0j>SX0?Shn0410@00i>CT0CDe=0492@P14A4@0ADE503dm?@0g=cL0
>c/k03`l?012@T80>CTi0492@P18B4P0?Cdm03lo?`1:BTX0?3`l0451@@0l?3`0@D5104E5A@18B4P0
@41004M7A`10@400?Cdm0492@P0i>CT0?3`l03hn?P0k>c/0ADE504I6AP1BDU80JVYZ06QXJ01MGEd0
G5aL04Y:BP13@d<0CDe=05QHF01FEUH204Q8B00H04a<C01ADE40FEUI055AD@1:BTX0CTi>04A4A00o
?cl0ATI6055AD@1<C4`0JFUY06ATI012@T80A4A40410@00l?3`0@d=304m?C`1_Kfl0Jf][05iNGP1L
G5`0JFUY0P1_Kfl03@1WIfL0I6AT05YJFP16ATH0@41003/k>`17AdL0ATI604e=C@1?Cdl0C4a<059B
DP1;Bd/00P1BDU803P1IFET0HV9R06ATI01LG5`0CTi>04E5A@0m?Cd0?clo03hn?P0k>c/0?Cdm04I6
AP19BDT0C4a<0P1ADE4205ADE00505aLG01OGel0FEUI06ATI01EEED00P1KFe/0701DE5@0G5aL069R
HP1QHF40MWIf07UiN@1XJ6P0FEUI04E5A@19BDT0De=C04I6AP0l?3`0CTi>07=cL`1nOWh0HV9R051@
D010@400>CTi03Ph>00m?Cd0@41004Q8B01ADE40I6AT051@D01<C4`205YJFP0<055AD@17AdL0ADE5
05aLG01JFUX0ATI60492@P0i>CT0>c/k03`l?00n?Sh0@4100`0i>CT07`14A4@0ATI603Xj>P0h>3P0
=CDe03Hf=P0d=3@0>c/k03Xj>P0h>3P0=CDe03Lg=`0f=SH0?Cdm04M7A`12@T80?3`l04a<C01>CTh0
>c/k03De=@0l?3`0=CDe03/k>`0e=CD0=cLg03/k>`16ATH0D51@055AD@1?Cdl00P0n?Sh03@10@400
?clo04A4A01DE5@0FEUI069RHP1>CTh0Cdm?05iNGP1?Cdl0AdM704Q8B013@d<00P0n?Sh01@0k>c/0
>3Ph03`l?00m?Cd0>3Ph0080=CDe00P0=SHf03<c<`0f=SH0=cLg03Hf=P0b<S80<c<c03Hf=P80=CDe
00@0=SHf03Ph>00g=cL0=3@d3Oooool0013ooooo0P1;Bd/00`13@d<0A4A404I6AP0204=3@`0=04E5
A@1CDe<0GUiN05iNGP1GEeL0De=C055AD@1<C4`0B4Q804i>CP1CDe<0H61P059BDP0204a<C00>0410
@012@T80BDU9069RHP20P800X:2P0;2`/02][Jd0]kNg0;2`/02NWYh0NWYj05EEE@1>CTh20451@@0>
0410@014A4@0ADE504=3@`1;Bd/0ATI60451@@10@400@D5104E5A@16ATH0AdM70451@@14A4@20451
@@0A04I6AP12@T80ADE504I6AP1ADE40BDU904E5A@1:BTX0Bd];051@D013@d<0?Cdm03`l?00n?Sh0
?3`l03hn?P13@d<00P0n?Sh0100l?3`0?Cdm03`l?00n?Sh203/k>`0903lo?`10@400@T9203`l?00j
>SX0?Cdm03`l?00m?Cd0?3`l0080>c/k00`0?clo0410@00m?Cd0?Shn0451@@12@T80B4Q804=3@`0k
>c/0?clo03/k>`11@D4203dm?@0803hn?P0j>SX0?Shn0410@00o?cl0>CTi03hn?P0j>SX203`l?080
?clo00T0@41003/k>`10@400?Cdm03Ph>00k>c/0@41003lo?`11@D400P1>CTh01`14A4@0?clo03dm
?@10@400?Shn03dm?@0o?cl00P0n?Sh06@0m?Cd0?3`l03Xj>P0j>SX0>c/k03dm?@0l?3`0?clo0410
@00m?Cd0?3`l03dm?@0k>c/0?clo0410@00o?cl0?3`l04M7A`1>CTh0@T9203/k>`0n?Sh0@T9204A4
A017AdL00P12@T802P10@400@T9204M7A`1;Bd/0@d=304E5A@14A4@0?clo03`l?00n?Sh204I6AP06
04=3@`0n?Sh0CDe=04I6AP1;Bd/0CDe=0P1SHf<03`1RHV80GemO04U9B@16ATH0@T9204A4A01?Cdl0
GEeM07=cL`1QHF40A4A403dm?@1@D500Bd];0492@P0203`l?080A4A401T0BTY:04I6AP0m?Cd0>SXj
03hn?P0l?3`0@d=303hn?P15ADD0CTi>04];B`10@400ATI604Y:BP1>CTh0EeMG04e=C@18B4P0AdM7
03Xj>P0n?Sh0@T9204A4A00m?Cd0?3`l0080?clo00L0@41003`l?00o?cl0>CTi03`l?00m?Cd0@T92
0080ATI600T0BTY:03lo?`12@T80>CTi03hn?P11@D40>c/k03dm?@0i>CT00P0j>SX01`0n?Sh0>3Ph
03/k>`0m?Cd0?3`l0410@018B4P00P14A4@0>`0n?Sh0@T9203/k>`0o?cl0?Shn03dm?@0k>c/0?Cdm
03hn?P10@400?Cdm03`l?00n?Sh0>CTi03`l?00o?cl0>3Ph03hn?P13@d<0CTi>05=CD`1ADE40Bd];
04a<C015ADD0@41003/k>`10@400?Shn03lo?`0n?Sh0AdM705iNGP1EEED0BTY:0410@00k>c/0?Cdm
04e=C@1GEeL0De=C059BDP1<C4`0?Shn03Ti>@0l?3`0?Shn04E5A@1;Bd/0C4a<05UIF@1>CTh0Cdm?
04Y:BP19BDT0EeMG065QH@1BDU80ATI60080?3`l0100ADE504I6AP1MGEd0Fe]K05MGE`1ADE40AdM7
04E5A@0o?cl0ADE505IFEP1DE5@0Bd];04A4A00n?Sh0>c/k0`0l?3`05@0k>c/0@4100492@P1<C4`0
B4Q805EEE@1NGUh0EEEE055AD@1FEUH0FEUI05YJFP1@D500Cdm?04i>CP14A4@0ADE50451@@17AdL0
BDU904Y:BP0205YJFP0O05IFEP1JFUX0GEeM06ATI01QHF40ATI603lo?`1<C4`0DE5A05EEE@19BDT0
?Cdm04=3@`17AdL0DE5A06ATI01WIfL0KVi^05aLG01:BTX0@D5104E5A@1<C4`0CTi>0410@00i>CT0
=cLg03/k>`0l?3`0>SXj03Ti>@0203hn?P0>03`l?00h>3P0ADE504e=C@1;Bd/0?clo0492@P10@400
?3`l03Ph>00d=3@0>CTi03Hf=P0h>3P203Lg=`0503Hf=P0j>SX0>c/k03hn?P10@4000P0k>c/01@14
A4@0@41003Ti>@0f=SH0=CDe0080=cLg00L0B4Q804a<C00j>SX0?3`l03dm?@0h>3P0=SHf0080=CDe
00@0=SHf03`l?016ATH0De=C0P1@D5003`1<C4`0Cdm?05EEE@1;Bd/0@D510492@P15ADD0A4A40410
@00m?Cd0?clo03Ph>00k>c/0?Cdm03Ti>@0403Hf=P0303De=@0f=SH0=CDe00<0=SHf00<0>3Ph03Hf
=P0f=SH00P0f=SH=ooooo`004?ooool02P1?Cdl0ATI604A4A014A4@0@D5104M7A`12@T80ATI603lo
?`11@D4204M7A`0:0451@@14A4@0@d=304A4A010@400?clo04=3@`14A4@0@T9204=3@`80@41001H0
@T9203lo?`10@400ADE504Q8B01@D500CDe=05ADE01/K6`0RXZ:08N7Q`1hN7P0GEeM0410@015ADD0
BDU907IfMP2;Rh/0Shn?06e]K@1YJFT0K6a/0P1RHV80301hN7P0QhN707]kN`1FEUH0BTY:05mOG`2L
W9`0ZJVY0:n_[`2PX:00/;2`09bLW080UIFE01/0RHV906a/K019BDT0A4A40451@@0n?Sh0?Cdm0410
@00n?Sh0@D5103`l?00m?Cd0>c/k0410@00n?Sh0?clo03Ti>@10@400@D5103hn?P0m?Cd0@D5103/k
>`0m?Cd0?clo0410@00j>SX00P0m?Cd0400h>3P0@41003hn?P0n?Sh0>SXj03hn?P10@400>CTi03Xj
>P0m?Cd0@41003`l?011@D40@T9203`l?00g=cL203dm?@0A03lo?`12@T80>SXj03hn?P0j>SX0?Shn
03Xj>P14A4@0?Shn03`l?00o?cl0?3`l0451@@13@d<0@D510492@P15ADD00P12@T803P0n?Sh0?3`l
03dm?@0m?Cd0>c/k03lo?`0l?3`0ATI603`l?00k>c/0>CTi03/k>`0o?cl0@4100P0o?cl00`0l?3`0
@41003/k>`0203`l?080?Shn00<0@d=303/k>`0n?Sh00P0o?cl02@0l?3`0@41003lo?`0m?Cd0AdM7
03lo?`0n?Sh0?clo04=3@`020492@P060451@@13@d<0B4Q804=3@`11@D40?clo0`0n?Sh05@0j>SX0
@D510410@017AdL0DU9B061PH01:BTX0?clo0451@@0m?Cd0?3`l0451@@19BDT0CTi>055AD@19BDT0
@d=30492@P0o?cl0?Cdm0410@00204];B`0R04A4A013@d<0GemO07MgM`1LG5`0ATI60492@P11@D40
?Shn0410@014A4@0GemO0820P01cLg<0Hf=S06QXJ01iNGT0SHf=0:6QX@2<S8`0P82007inOP1aLG40
E5AD04=3@`12@T80?clo03hn?P19BDT0@d=303`l?00m?Cd0?Shn03dm?@80>c/k00H0?Shn03/k>`0h
>3P0>SXj03Ph>00l?3`203/k>`0>04=3@`0l?3`0?Cdm03Ti>@0g=cL0>CTi03/k>`0j>SX0>3Ph0410
@00j>SX0?clo03Lg=`0m?Cd203Xj>P0803/k>`0m?Cd0?3`l03Xj>P0g=cL0>c/k03Hf=P0k>c/203`l
?00303/k>`0i>CT0>3Ph0080>c/k00T0>CTi03`l?019BDT0AdM704=3@`10@400>c/k03dm?@0k>c/0
0P0i>CT0100k>c/0?3`l03hn?P0n?Sh203/k>`0B03hn?P10@400ADE505IFEP1MGEd0?clo0410@00k
>c/0?Shn03dm?@0n?Sh0?clo04e=C@1?Cdl0B4Q80492@P0k>c/0?Shn0P10@4001018B4P0A4A403hn
?P0n?Sh203/k>`0>03hn?P0o?cl0CDe=04a<C01=CDd0BTY:04M7A`19BDT0ATI604A4A017AdL0@d=3
03dm?@0i>CT203Xj>P0O03lo?`0j>SX0?Cdm04=3@`1:BTX0A4A404=3@`1:BTX0EEEE04e=C@1IFET0
G5aL05iNGP1GEeL0EEEE055AD@15ADD0A4A403/k>`0l?3`0>c/k03lo?`0n?Sh0B4Q804];B`1<C4`0
CTi>0492@P11@D40ADE50451@@0303dm?@0=0492@P1=CDd0>SXj0451@@0n?Sh0>SXj03/k>`12@T80
@d=304A4A016ATH0DU9B04=3@`0203Ti>@0603`l?016ATH0@D5103Lg=`0i>CT0=SHf0P0i>CT01P0m
?Cd0@T9204U9B@19BDT0CDe=0451@@80A4A400L0>c/k03Lg=`0i>CT0?clo03`l?00g=cL0>3Ph0080
=SHf00P0>3Ph03Lg=`0i>CT0>c/k03Lg=`0k>c/0=cLg03Ph>080=cLg0P0i>CT01`0h>3P0=cLg03De
=@0i>CT0>c/k03Ph>00c<c<00P0e=CD03@0f=SH0>c/k03hn?P0n?Sh0>SXj03dm?@14A4@0AdM704U9
B@1<C4`0CTi>059BDP19BDT00P10@4001@0j>SX0?clo03Ti>@0k>c/0>CTi0080=SHf0P0g=cL03`0f
=SH0=cLg03Lg=`0b<S80@T9203`l?00d=3@0<c<c03Hf=P0d=3@0=SHf03Ti>@0h>3P0=CDe03Ph>002
03Hf=Pgooooo000@ooooo`0:04Y:BP17AdL0ATI604E5A@13@d<0@T920410@016ATH0@D5103lo?`<0
@T9200<0A4A40492@P13@d<00P11@D402012@T80A4A404=3@`13@d<0@41003lo?`10@400@D510P13
@d<01P0o?cl0@T920492@P11@D40?clo04I6AP80A4A400/0AdM704=3@`12@T80@D5104M7A`1=CDd0
D51@0492@P13@d<0B4Q80451@@020492@P0C04U9B@16ATH0@41004=3@`1?Cdl0H61P06YZJP1lO7`0
Ogmo07MgM`25QHD0Ti>C08j>SP20P800HV9R08^;R`2GUiL0SHf=06ATI002051@D00?04Q8B011@D40
?clo03dm?@10@400?Shn04M7A`13@d<0ADE503hn?P0l?3`0?clo03`l?00n?Sh0>SXj0080>c/k00T0
?clo03hn?P0m?Cd0@d=303lo?`0k>c/0?3`l0492@P0k>c/00P0n?Sh00`0l?3`0>c/k03/k>`0403dm
?@80@D5100D0@41003`l?012@T80?Cdm03Xj>P0203hn?P0H03/k>`0j>SX0?Shn03`l?00h>3P0@410
04Y:BP19BDT0@T9203`l?00j>SX0?3`l03lo?`12@T80?clo04I6AP0o?cl0A4A403lo?`0i>CT0?Cdm
03/k>`0m?Cd0?clo0`0k>c/02@0m?Cd0?Shn03dm?@0i>CT0?3`l0451@@0m?Cd0?clo03hn?P0203`l
?00<03/k>`0o?cl0?Shn03`l?00k>c/0?3`l03Ti>@0n?Sh0ADE50410@012@T80A4A40P0l?3`02P11
@D40Bd];04=3@`11@D40AdM703hn?P12@T80?Shn0492@P0m?Cd203hn?P0603Ti>@0o?cl0?3`l03dm
?@0h>3P0?3`l0P0m?Cd0;@0k>c/0?clo0410@012@T80@41004A4A012@T80@410051@D01?Cdl0Bd];
04I6AP14A4@0@D5104I6AP1<C4`0AdM7051@D017AdL0A4A403lo?`0k>c/0?clo04Q8B01?Cdl0C4a<
04I6AP17AdL0CDe=059BDP1[Jf/0PH6107QhN01eMGD0MWIf07AdM01JFUX0@d=304];B`1BDU80H61P
06UYJ@1ADE40ADE504Y:BP0205YJFP0G055AD@16ATH0@41003dm?@0j>SX0?3`l03dm?@13@d<0B4Q8
03/k>`10@400>CTi03`l?00n?Sh0>c/k03Ph>00m?Cd0>c/k04=3@`11@D40?3`l03Ti>@0h>3P00`0m
?Cd03`0k>c/0>CTi03hn?P0i>CT0>c/k03lo?`11@D40?Shn03Ph>00m?Cd0>CTi03/k>`0g=cL0ADE5
03/k>`0203`l?00803Lg=`0l?3`0>CTi03Ti>@0l?3`0@D5103`l?00h>3P203Ti>@0B03Ph>00j>SX0
>3Ph03Ph>00j>SX0?3`l04A4A01<C4`0B4Q80410@00j>SX0>CTi03Ph>00k>c/0?Cdm03hn?P10@400
AdM70P0l?3`01@0k>c/0?Cdm04=3@`10@400?clo0080?Shn0440?3`l03/k>`0k>c/0@41004U9B@12
@T80?Cdm04M7A`13@d<0@T920410@013@d<0ADE50410@00n?Sh0?3`l03Ph>00i>CT0>c/k03Xj>P0m
?Cd0?clo0410@013@d<0?Shn04A4A019BDT0Bd];05=CD`1=CDd0E5AD04I6AP18B4P0BDU904a<C018
B4P0?Shn04I6AP0n?Sh0@D5104I6AP13@d<0C4a<04M7A`19BDT0Bd];04M7A`16ATH0?Cdm04I6AP11
@D40>SXj03`l?00j>SX0@D5104E5A@0j>SX0A4A403Ph>00g=cL0>c/k03Xj>P0l?3`0>SXj03`l?002
03Ti>@0603Lg=`0j>SX0>CTi03`l?00g=cL0>CTi0`0g=cL02P0i>CT0>c/k03lo?`0o?cl0?3`l04E5
A@11@D40@41003Xj>P0g=cL203Ti>@0503Lg=`0h>3P0>SXj03Ph>00g=cL00P0f=SH0100i>CT0>c/k
03Ph>00g=cL203dm?@0>03Ti>@0h>3P0=cLg03Lg=`0e=CD0=SHf03/k>`0i>CT0>3Ph03@d=00e=CD0
=cLg03<c<`0i>CT203hn?P0E03/k>`0m?Cd0@D5103Xj>P10@400Bd];04=3@`0n?Sh0ADE504=3@`0k
>c/0?Shn03`l?00n?Sh0?clo03hn?P0m?Cd0>CTi03`l?00h>3P0=3@d00<0=cLg00D0=CDe03Hf=P0b
<S80=3@d03Hf=P0203@d=00303`l?00i>CT0>CTi00<0=CDe0P0g=cL=ooooo`004?ooool204I6AP80
ADE50P14A4@01010@400@D5104A4A012@T8204=3@`080451@@12@T80@4100492@P10@400@d=304U9
B@15ADD20410@0030451@@12@T80@d=300<0@D5100H0?Cdm0492@P12@T80@D5104=3@`11@D420410
@00803dm?@10@400@41003dm?@11@D40A4A404E5A@14A4@204=3@`0S03dm?@11@D40@T9204=3@`0n
?Sh0?clo03`l?00o?cl0?Shn03lo?`0n?Sh0?Cdm03hn?P11@D40@4100492@P14A4@0ADE505=CD`1=
CDd0F5QH05MGE`1OGel0Ti>C07alO01DE5@0D51@04=3@`0n?Sh0C4a<05]KF`16ATH0?Shn03/k>`10
@4000P0l?3`0;@0o?cl0?3`l04];B`1>CTh0?Shn03`l?013@d<0@D5104];B`1?Cdl0F5QH05aLG01G
EeL0FEUI06MWI`1<C4`0@D5104e=C@1SHf<0LW9b07alO01XJ6P0Hf=S07MgM`20P800KVi^04i>CP0o
?cl0?3`l0492@P15ADD0?Shn0451@@0n?Sh0?3`l04=3@`12@T80ADE50410@00m?Cd0?3`l0410@011
@D40?3`l0451@@020492@P0903lo?`0n?Sh0@41003dm?@0j>SX0?clo0451@@0o?cl0?3`l0080?Cdm
00T0>SXj03dm?@0l?3`0?clo03hn?P10@400@D5104A4A00o?cl00P0n?Sh00`0l?3`0?Cdm03hn?P02
0451@@80?Shn00/0?clo04A4A010@400@T9204I6AP14A4@0@T9203dm?@16ATH0@41003lo?`0203hn
?P0M0492@P0m?Cd0@T9204=3@`16ATH0>SXj04A4A00n?Sh0>c/k03dm?@0o?cl0@T9203lo?`0n?Sh0
?clo0451@@0n?Sh0@41003lo?`14A4@0@T920451@@1=CDd0ATI604a<C012@T80@D5104A4A01:BTX0
0P10@4000`13@d<0>c/k03lo?`020410@0050492@P16ATH0B4Q804I6AP13@d<00P1CDe<01018B4P0
Bd];04Q8B014A4@20451@@0;03dm?@18B4P0De=C04a<C017AdL0ATI604U9B@18B4P0ATI605EEE@1J
FUX00P18B4P03@15ADD0?3`l03Xj>P0n?Sh0ATI6051@D01NGUh0GemO04a<C016ATH0?Cdm03`l?00o
?cl00P10@4006@0k>c/0ATI604A4A00n?Sh0>CTi03/k>`0h>3P0>SXj03`l?00k>c/0>SXj03/k>`0l
?3`0=cLg03Ph>00l?3`0>c/k03`l?00k>c/0ATI605YJFP1KFe/0CTi>04=3@`11@D400P0o?cl01P0j
>SX0>c/k03/k>`0i>CT0?Cdm03/k>`80>3Ph0P0i>CT04@0k>c/0?clo0410@00m?Cd0>c/k03dm?@0l
?3`0>SXj03dm?@0h>3P0>CTi03`l?00m?Cd0?Shn0410@00k>c/0>CTi0080?clo00@0@D5103`l?00n
?Sh0@T920P0l?3`01015ADD0?clo03hn?P0j>SX203dm?@80>SXj00/0?Shn0410@00m?Cd0>SXj03/k
>`0i>CT0?3`l03Ti>@0g=cL0>CTi03/k>`0203Xj>P80?clo00P0?Cdm03`l?00l?3`0=cLg03hn?P12
@T80@d=304E5A@80>c/k0140>3Ph03Ti>@0n?Sh0@41004A4A013@d<0B4Q804A4A015ADD0AdM704E5
A@1:BTX0@41004A4A018B4P0@T9203lo?`0203hn?P0303Ph>00j>SX0?clo00<0?Shn00P0=cLg03Ph
>00f=SH0<c<c03Ph>00i>CT0=cLg03Xj>P80>c/k00<0=cLg03Hf=P0j>SX00`0g=cL01010@400@T92
0451@@0l?3`203hn?P0303`l?00k>c/0>SXj0080>c/k00D0?clo03`l?00k>c/0>SXj03Ti>@0203Hf
=P0Q03Ti>@0g=cL0=3@d03De=@0i>CT0?3`l03dm?@0j>SX0>CTi03lo?`12@T80?Cdm03hn?P0h>3P0
>c/k04E5A@11@D40>CTi03Hf=P0e=CD0>3Ph03Ti>@0k>c/0@T9204E5A@0o?cl0@T920451@@15ADD0
ATI603Ti>@0j>SX0?Cdm0080>3Ph00X0@D5104I6AP0o?cl0?Cdm03/k>`0n?Sh0>CTi03Lg=`0i>CT0
=CDe0P0g=cL203Ph>00503De=@0j>SX0=CDe03Hf=P0e=CD00`0g=cL0100k>c/0?3`l03Ti>@0i>CT2
03Ph>00303Ti>@0k>c/0@41000gooooo000@ooooo`0:04I6AP15ADD0@d=304E5A@12@T80ADE50410
@015ADD0@T9204=3@`80ATI600L0?clo0410@00o?cl0@T920410@00o?cl0@4100080@d=30P12@T80
0`13@d<0@T920451@@020451@@0I0410@011@D40@d=304A4A012@T80@41003hn?P0o?cl0@d=303hn
?P12@T80@41003dm?@11@D40>c/k03dm?@14A4@0@T9204=3@`12@T80@41004E5A@0n?Sh0@4100451
@@020410@00:04=3@`0m?Cd0>c/k03Ti>@0k>c/0@D5103`l?010@400@d=30492@P80@41000d0B4Q8
0451@@14A4@0DE5A04I6AP1;Bd/0ATI603dm?@14A4@0@d=30451@@0n?Sh0?clo00<0?Shn03/0?3`l
03lo?`1QHF40QhN706a/K01;Bd/0B4Q8059BDP1VIVH0Jf][069RHP1FEUH0M7Ad06i^KP1TI6@0DU9B
05MGE`1WIfL0UiNG0:ZZZP2g]kL0[:b/0:VYZ@2b/[80^[Zj0=?Cd`2c/k<0LG5a04i>CP10@400?3`l
05QHF01IFET0EeMG06EUI@1^KVh0Fe]K04e=C@1FEUH0IVIV05QHF01bLW80QhN706IVIP16ATH0A4A4
03lo?`0n?Sh0?clo0492@P10@400A4A403hn?P0o?cl0De=C05UIF@1FEUH0ATI60451@@020410@007
04I6AP0o?cl0?Shn0451@@12@T80>c/k03`l?00203Xj>P0903`l?00n?Sh0@D5104Y:BP15ADD0@410
03lo?`13@d<0@4100080?clo00T0@T920410@00o?cl0@D5103dm?@0i>CT0>c/k0492@P11@D400P0m
?Cd01P10@400@D510492@P0n?Sh0?clo0410@080?clo01L0?Cdm03hn?P0m?Cd0?3`l03dm?@0n?Sh0
?clo0492@P0m?Cd0>c/k0410@011@D40?Cdm0451@@0n?Sh0>c/k03lo?`0j>SX0>c/k0492@P15ADD0
?Cdm0451@@0203hn?P0<03/k>`0l?3`0>c/k04=3@`11@D40@d=303lo?`0n?Sh0?clo03hn?P11@D40
?clo0P10@40204E5A@0A03Xj>P0n?Sh0@T9204A4A01>CTh0B4Q804E5A@12@T80>c/k04A4A016ATH0
@41003dm?@17AdL0B4Q803`l?010@4000P0l?3`00`0m?Cd0?Shn03lo?`0204=3@`0:0410@00o?cl0
@41003Lg=`0i>CT0?Cdm04Y:BP0o?cl0@T9204I6AP80@D510100@d=303/k>`0k>c/0?Shn04A4A017
AdL0Cdm?05mOG`1mOGd0WIfM08n?S`1dM7@0HV9R05IFEP1HF5P0AdM70P10@400100m?Cd0>c/k03`l
?00h>3P203Ti>@0803dm?@17AdL0CDe=05MGE`1OGel0EUIF04=3@`0i>CT203Xj>P0A03`l?00k>c/0
=cLg03dm?@0l?3`0>3Ph03dm?@0j>SX0?Shn0451@@19BDT0A4A403/k>`0f=SH0>3Ph03Lg=`0i>CT0
0P0k>c/00`0j>SX0@T9203dm?@0203Xj>P0>03hn?P11@D40?3`l03`l?00f=SH0>c/k03Lg=`0j>SX0
>CTi03Hf=P0g=cL0>SXj03Ti>@0g=cL203/k>`0>03Xj>P0k>c/0=cLg03Ti>@0j>SX0>CTi03Xj>P0d
=3@0=cLg03Ti>@0j>SX0>CTi03`l?00m?Cd30492@P0D03dm?@12@T80?Cdm0410@012@T80>c/k03dm
?@10@400?Cdm03Ti>@0k>c/0=cLg03Ph>00i>CT0=cLg03Ti>@0k>c/0=cLg03Ti>@0j>SX203Lg=`0@
03Ti>@0j>SX0>CTi03Ph>00g=cL0>3Ph03Ti>@0h>3P0>c/k03Ph>00k>c/0?3`l03Ti>@0m?Cd0?3`l
03Xj>P80>c/k00X0>CTi03Xj>P0i>CT0>3Ph03/k>`0i>CT0>3Ph03Xj>P0i>CT0>SXj0P0f=SH02P0k
>c/0=cLg03De=@0e=CD0=SHf03Ti>@0h>3P0>SXj03Ti>@0g=cL203Ti>@0503hn?P0l?3`0AdM704Q8
B017AdL00`0i>CT04P11@D40?Shn03hn?P0n?Sh0?Cdm0451@@16ATH0@T9203Xj>P0i>CT0?3`l03Xj
>P0h>3P0>SXj03dm?@12@T80?Shn03/k>`80>SXj00D0=cLg03Xj>P0e=CD0=SHf03Lg=`0203Ti>@09
03Hf=P0d=3@0=cLg03Hf=P0g=cL0>SXj03Ph>00i>CT0>3Ph00<0>c/k00L0>3Ph03Ti>@0i>CT0?Shn
0492@P1BDU80Bd];00gooooo000@ooooo`0;04E5A@12@T80A4A404I6AP13@d<0A4A404Q8B017AdL0
@d=30410@014A4@00P12@T800`0o?cl0@d=30492@P020492@P0303lo?`13@d<0?clo0080@41000X0
AdM703hn?P11@D40@T920451@@12@T80AdM704=3@`12@T80@D510P0n?Sh0100o?cl0>c/k04E5A@1B
DU820410@00B03hn?P0o?cl0?Cdm04=3@`0n?Sh0@4100451@@12@T80@41003lo?`11@D40@41003dm
?@0o?cl0@D5103lo?`0k>c/0?Shn0P0o?cl04@0l?3`0?Cdm0492@P12@T80?clo04E5A@12@T80A4A4
03hn?P0m?Cd0?Shn03/k>`0n?Sh0@41003`l?00m?Cd0>SXj00<0?3`l0P0m?Cd0>`0o?cl0C4a<055A
D@1DE5@0CDe=04A4A00m?Cd0?Shn03lo?`12@T80ATI60410@014A4@0@D5104Y:BP0m?Cd0ADE504A4
A016ATH0B4Q804Y:BP1<C4`0Bd];04U9B@1MGEd0Jf][07EeM@1UIFD0IVIV04Y:BP13@d<0LW9b07Mg
M`1kNg/0SHf=0:>SX`2=SHd0N7Qh08:2PP2NWYh0U9BD0:JVYP2g]kL0^KVi08Z:RP1NGUh0HV9R071`
L021PH40JVYZ07YjNP20P800QXJ606QXJ029RHT0TI6A07alO01bLW80M7Ad0080L71`01<0LG5a07in
OP1jNWX0EEEE04U9B@1;Bd/0@T9203hn?P10@400ADE504A4A019BDT0FEUI04];B`12@T80?clo04=3
@`14A4@0@D510080?Cdm00d0@d=303dm?@12@T80?clo03`l?010@400?Shn04M7A`12@T80?clo0410
@00k>c/0@d=30080>SXj00L0?Cdm04A4A011@D40@T920410@00o?cl0@T920080?Cdm0P0n?Sh0100m
?Cd0@D510410@00o?cl203dm?@0@0492@P0o?cl0@D5103Ti>@0l?3`0BDU903dm?@0k>c/0?Shn0492
@P15ADD0@T9203lo?`10@400?Shn03/k>`80?3`l00L0@d=303`l?00o?cl0@41004=3@`12@T80@410
0080?Shn02D0@41004];B`1RHV80C4a<04=3@`0i>CT0@T9203/k>`14A4@0BTY:0451@@0n?Sh0>CTi
03dm?@0i>CT0>c/k03`l?00i>CT0?3`l03lo?`0m?Cd0?3`l03Ti>@0l?3`0>c/k03Ti>@0n?Sh0B4Q8
04m?C`1=CDd0BTY:0410@011@D40?clo03/k>`11@D40?clo0080@d=300D0?Cdm03Xj>P0m?Cd0BTY:
05ADE00206=SH`0P05QHF01UIFD0L71`06EUI@1/K6`0FUYJ05eMG@1IFET0BDU903Ph>00o?cl0>c/k
03dm?@17AdL0LW9b08n?S`2@T900Rh^;08N7Q`1kNg/0MGEe04Y:BP16ATH0E5AD04U9B@0n?Sh0>SXj
03lo?`13@d<0CDe=04m?C`1ZJVX2071`L00306MWI`1:BTX0?Shn0080?3`l00X0?clo04];B`13@d<0
?Cdm03Xj>P0m?Cd0>SXj03Ti>@0n?Sh0?Cdm0P0k>c/03`0l?3`0?Cdm03/k>`0j>SX0@D5103`l?00h
>3P0=cLg03/k>`0j>SX0>c/k03dm?@0k>c/0=cLg03@d=00203Ti>@80?3`l00<0>3Ph03Hf=P0h>3P0
0P0i>CT05`0e=CD0>c/k03dm?@0n?Sh0?clo03Ti>@0m?Cd0>c/k03`l?00n?Sh0>c/k03hn?P0d=3@0
>CTi03De=@0k>c/0?clo0492@P0l?3`0>CTi03Ph>00i>CT0=cLg00<0>3Ph00D0=CDe03Lg=`0i>CT0
>3Ph03De=@0203Ti>@80>3Ph00<0=cLg03Xj>P0g=cL00P0j>SX04@0i>CT0?3`l03`l?00h>3P0>SXj
03Ti>@0e=CD0>3Ph03De=@0g=cL0>3Ph03Xj>P0i>CT0>3Ph03/k>`0i>CT0>3Ph0080>CTi00@0=cLg
03De=@0g=cL0?3`l0P0i>CT01`0h>3P0>CTi03Ti>@0g=cL0>3Ph03Ti>@0f=SH00`0g=cL0400b<S80
=cLg03Hf=P0g=cL0>CTi03Hf=P0h>3P0>c/k03Xj>P12@T80A4A403Xj>P0o?cl0?Cdm03Xj>P11@D42
03lo?`0604Q8B014A4@0>c/k04E5A@0k>c/0>CTi0P0g=cL00`0j>SX0=cLg03/k>`0303Hf=P0A03@d
=00e=CD0>3Ph03Ti>@0j>SX0>3Ph03Hf=P0i>CT0>SXj03Lg=`0j>SX0?3`l04M7A`11@D40@T92055A
D@15ADD03Oooool0013ooooo01/0B4Q804M7A`18B4P0Bd];06m_K`1lO7`0Kfm_04m?C`18B4P0@T92
04Q8B00o?cl0@d=303hn?P13@d<0@T920451@@17AdL0ADE504A4A013@d<0A4A404U9B@1EEED0IfMW
06][J`1FEUH00P1=CDd06@12@T80?clo03hn?P0m?Cd0?3`l03lo?`10@400?clo03dm?@10@400>SXj
03lo?`13@d<0?clo0492@P1BDU80@d=30410@00o?cl0@D5103dm?@11@D40?Cdm03hn?P11@D400P0n
?Sh01P0m?Cd0@D5103`l?00o?cl0@D5103lo?`80@D510P10@400200n?Sh0>SXj04=3@`14A4@0?Cdm
03`l?00j>SX0?3`l0P11@D40200i>CT0>SXj03/k>`0k>c/0?Cdm03lo?`0m?Cd0C4a<0P10@40203hn
?P0504A4A00n?Sh0>c/k03`l?00o?cl00P0m?Cd0400o?cl0>SXj04I6AP0l?3`0@T9203lo?`0l?3`0
?Shn0492@P0l?3`0?Cdm0492@P0n?Sh0?clo0492@P0n?Sh203dm?@0503`l?014A4@0ADE504I6AP10
@4000P18B4P07P1;Bd/0ADE504=3@`1ADE40Cdm?05=CD`1PH600FUYJ04I6AP13@d<0EUIF05aLG01H
F5P0LG5a0820P01cLg<0HV9R06EUI@1cLg<0QXJ60:j^[P2k^k/0_;bl0;Ng]`2a/K40Y:BT0:NWY`2Y
ZJT0][Jf0:VYZ@80Ph>300h0Rh^;05iNGP1GEeL0GemO07=cL`1_Kfl0Jf][07QhN024Q8@0SHf=07in
OP1[Jf/0De=C04=3@`<0A4A400h0ADE504I6AP10@400@4100492@P10@400@T9204U9B@1<C4`0CDe=
05UIF@1BDU80BDU904=3@`80?Cdm00<0>c/k03lo?`0m?Cd00P0o?cl203`l?0030410@00o?cl0?3`l
0080>c/k00P0?Shn0451@@0o?cl0@T9203/k>`0l?3`0>3Ph03hn?P80@41000H0?Cdm03Xj>P0n?Sh0
?3`l03hn?P0o?cl203dm?@0K0451@@14A4@0>c/k03dm?@0n?Sh0?clo03hn?P12@T80BTY:06IVIP1Y
JFT0GEeM04=3@`0l?3`0?Shn03`l?012@T80?Shn0451@@0j>SX0?3`l03lo?`0m?Cd0?Shn03/k>`0l
?3`0>CTi0080>SXj0100>3Ph03hn?P0i>CT0>3Ph03hn?P17AdL0CTi>04];B`11@D40?3`l03/k>`0l
?3`0?Cdm03Ti>@0l?3`0>SXj0P0k>c/04@0j>SX0?clo0410@017AdL0@T92051@D018B4P0?clo04=3
@`1;Bd/0BTY:04A4A019BDT0?Shn0492@P14A4@0ATI60080ADE50P1;Bd/06@1BDU80FUYJ06a/K01k
Ng/0MWIf06EUI@1/K6`0Jf][05aLG01DE5@0BDU90410@012@T80>3Ph05EEE@1VIVH0IfMW06m_K`20
P800Ph>307UiN@1KFe/0CDe=055AD@19BDT00P12@T803@14A4@0?3`l03Ti>@0i>CT0?Cdm03hn?P0m
?Cd0>SXj03`l?00k>c/0?3`l03Lg=`0j>SX00P0k>c/0200j>SX0?3`l03/k>`0k>c/0>SXj03lo?`0k
>c/0?Cdm0P0k>c/04P0l?3`0?Cdm03Ph>00l?3`0?Shn03Xj>P0h>3P0>c/k03Ph>00l?3`0>SXj03hn
?P0m?Cd0>c/k03Xj>P0e=CD0>c/k03dm?@80>c/k00L0?Cdm03/k>`0f=SH0>SXj03Ti>@0m?Cd0@T92
0080?3`l00T0>CTi03Ph>00i>CT0=cLg03Hf=P0i>CT0=SHf03De=@0g=cL00P0h>3P0400f=SH0=3@d
03@d=00h>3P0>c/k03Ti>@0j>SX0=cLg03/k>`0j>SX0>3Ph03Xj>P0i>CT0>3Ph03Lg=`0h>3P203/k
>`0403Hf=P0i>CT0>3Ph03Xj>P80=SHf00P0>c/k03De=@0f=SH0>SXj03Ti>@0h>3P0>SXj03Hf=P80
>3Ph0P0k>c/01P0l?3`0@T9203/k>`0j>SX0=cLg03Xj>P80=cLg00L0=CDe03Xj>P0k>c/0>3Ph03Xj
>P0i>CT0>3Ph0080>c/k0100>3Ph03`l?00o?cl0>SXj03`l?00n?Sh0>c/k03hn?P14A4@0?clo04m?
C`0o?cl0?3`l04A4A010@400?Shn0P0k>c/00`0j>SX0>CTi03Xj>P0203Hf=P0703Ti>@0h>3P0?3`l
03dm?@0i>CT0>3Ph03`l?00203/k>`0304E5A@1?Cdl0HF5Q0080JVYZ00@0I6AT07QhN02=SHd0Ogmo
3Oooool0013ooooo01d0HV9R05eMG@1QHF40LG5a0;2`/02@T900GUiN04e=C@1GEeL0EUIF051@D01D
E5@0IFEU07YjNP2=SHd0OGem06m_K`29RHT0TY:B09ZJVP2PX:00U9BD09RHV02d];@0^k^k09nOW`1k
Ng/0IVIV05=CD`020492@P0:04E5A@12@T80A4A404=3@`0o?cl0?Cdm03hn?P0m?Cd0>CTi0492@P80
?Cdm0P12@T808@0n?Sh0?clo0451@@11@D40@T9203lo?`16ATH0BDU904=3@`14A4@0?clo0492@P11
@D40?Shn04I6AP14A4@0AdM7051@D01>CTh0C4a<04Q8B01:BTX0@d=303dm?@0o?cl0>SXj03`l?00k
>c/0?3`l03hn?P0o?cl0?Shn0410@00303dm?@0B03lo?`10@400BDU903Xj>P0o?cl0?Cdm03lo?`14
A4@0?Cdm03Ph>00n?Sh0?clo03Xj>P0n?Sh0@D5103`l?00n?Sh0>SXj0P0k>c/03@0m?Cd0?clo0451
@@0i>CT0?Shn04=3@`0m?Cd0?clo03hn?P14A4@0@D5103dm?@0n?Sh00P13@d<06@0n?Sh0?clo03`l
?00n?Sh0?Cdm03`l?00o?cl0@T9203hn?P10@400@T9204I6AP11@D40?Shn04A4A012@T80@41003`l
?012@T80@D5103`l?00n?Sh0>c/k0451@@17AdL00P1CDe<07`1BDU80F5QH04a<C01DE5@0MWIf08:2
PP1hN7P0MWIf08F5Q@1eMGD0IFEU05IFEP1TI6@0WinO0;^k^`2/[:`0a/K60<_;b`3Bd]80c/k>0<g=
c@30`<00XZ:R08N7Q`2HV9P0aLG50<[:bP2d];@0[jn_0::RXP2=SHd00P28R8P00`21PH40JFUY05iN
GP0206=SH`0a05aLG01EEED0CTi>05MGE`1IFET0GEeM05aLG019BDT0A4A403lo?`12@T80B4Q805AD
E01?Cdl0ATI60410@016ATH0Bd];04A4A016ATH0A4A403`l?00m?Cd0?3`l03dm?@11@D40?Shn03dm
?@0l?3`0@D5103lo?`0m?Cd0?Shn0410@00o?cl0@D510492@P0n?Sh0@41004a<C01;Bd/0B4Q805AD
E01JFUX0BDU903hn?P10@400?Cdm03Ph>00203/k>`<0>SXj100m?Cd01@16ATH0?3`l03Xj>P0l?3`0
?Shn0080@D5101@0>c/k03hn?P0o?cl0?clo03Ph>00i>CT0>SXj03dm?@0j>SX0=cLg03hn?P0k>c/0
>SXj03Ti>@0n?Sh0@D5103/k>`0n?Sh0?Cdm03`l?080>SXj00h0?3`l04=3@`13@d<0?clo03Ti>@0j
>SX0?3`l03/k>`0l?3`0@D5104Q8B01=CDd0BDU904Y:BP<0@T9200`0ATI604U9B@1=CDd0De=C04e=
C@11@D40@41004=3@`10@400@T9203hn?P0k>c/20410@00l0451@@0m?Cd0@d=30410@011@D40?Shn
03dm?@15ADD0@d=30410@00n?Sh0>CTi03hn?P0j>SX0?Shn04e=C@1EEED0?Cdm0451@@0o?cl0?Cdm
03Xj>P0e=CD0>c/k03hn?P0l?3`0>c/k0451@@18B4P0CDe=04I6AP15ADD0C4a<051@D01GEeL0EUIF
04I6AP0m?Cd0>3Ph03/k>`0i>CT0@41004a<C017AdL0?Shn03lo?`0m?Cd0@d=30410@00o?cl0?Shn
03dm?@10@400?3`l04=3@`0m?Cd0>SXj03lo?`0n?Sh0?3`l0P0o?cl02P0j>SX0?3`l03/k>`0f=SH0
>3Ph03Hf=P0e=CD0=SHf03Xj>P0i>CT303Lg=`0?03Ph>00g=cL0=CDe03Lg=`0h>3P0>CTi03Xj>P0i
>CT0>SXj03Ti>@0g=cL0>CTi03Xj>P0f=SH0>CTi00<0>3Ph00@0?3`l03Lg=`0f=SH0=cLg0P0h>3P0
6`0i>CT0=cLg03/k>`0k>c/0>SXj03dm?@0k>c/0>SXj03Hf=P0i>CT0>3Ph03lo?`0f=SH0?Cdm04I6
AP0n?Sh0?Cdm03Xj>P0k>c/0>SXj03Ti>@0n?Sh0@D510492@P0n?Sh0?Cdm03/k>`0203dm?@0303lo
?`15ADD0@d=30080BDU901H0B4Q804Y:BP1@D500AdM70451@@1;Bd/0DE5A05=CD`1HF5P0Hf=S061P
H01CDe<0EUIF055AD@16ATH0B4Q804=3@`12@T80ATI60410@00i>CT0?Cdm0`0k>c/0300i>CT0@D51
055AD@1jNWX0TI6A09fMW@2QXJ40WinO09^KV`2PX:00[:b/0:FUY@gooooo000@ooooo`1>0;6a/@2b
/[80][Jf0<?3``31`L40Vi^K08f=S@2OWil0UiNG08n?S`24Q8@0SXj>09RHV02MWId0YZJV0:n_[`2m
_Kd0eMGE0=cLg03EeMD0bLW909fMW@2CTi<0QXJ606i^KP1JFUX0De=C051@D01KFe/0E5AD05=CD`1H
F5P0CDe=04Q8B010@400?Cdm0451@@10@400ATI604M7A`1BDU80F5QH05aLG01^KVh0JVYZ05EEE@17
AdL0A4A404a<C01QHF40JFUY07MgM`23Ph<0M7Ad05eMG@1HF5P0DE5A05]KF`1lO7`0UYJF08N7Q`1j
NWX0Ogmo06][J`1MGEd0EEEE04Y:BP16ATH0ADE503hn?P0k>c/0?Cdm03/k>`0n?Sh0A4A40410@00n
?Sh0?Cdm0P10@4001`0m?Cd0@T9204=3@`0k>c/0?clo03dm?@12@T800`0n?Sh02@0k>c/0@41003dm
?@0l?3`0@D5103dm?@10@400?clo03`l?00203hn?P0>03dm?@13@d<0ADE503hn?P0j>SX0?clo03`l
?00k>c/0?3`l0492@P0o?cl0?3`l03dm?@10@40303hn?P80@4100240?Shn03dm?@0l?3`0@41003`l
?00i>CT0>c/k04=3@`11@D40>c/k03lo?`0l?3`0?clo03`l?010@400?Shn0492@P0n?Sh0@D5103dm
?@0o?cl0@d=304A4A01;Bd/0B4Q80410@011@D40?clo0410@012@T80A4A403`l?00o?cl00P0l?3`0
6@0n?Sh0AdM705QHF01TI6@0MGEe06][J`1hN7P0LG5a08B4Q02SXj<0]KFe0:NWY`2][Jd0/k>c0:ZZ
ZP2c/k<0[Jf]0;>c/`2a/K40^KVi0:b/[02NWYh0SXj>07alO02<S8`00P2WYjL0902XZ:P0ZZZZ0:j^
[P2WYjL0VIVI08B4Q01JFUX0AdM704U9B@1DE5@0O7al09BDU01RHV80@d=304Q8B01FEUH0Jf][07Yj
NP1[Jf/0EEEE04E5A@0m?Cd0?clo04I6AP1HF5P0GemO061PH01_Kfl0K6a/05iNGP1DE5@0De=C06e]
K@1QHF40I6AT065QH@80Hf=S00X0I6AT04Y:BP11@D40@d=304M7A`1:BTX0D51@04M7A`10@400?clo
0`0n?Sh02P0g=cL0>SXj03lo?`0n?Sh0>CTi03/k>`0m?Cd0?Shn0492@P13@d<204Y:BP0704I6AP0n
?Sh0?3`l03Ti>@0k>c/0=SHf03/k>`0203`l?00503Xj>P0k>c/0>3Ph03Ti>@0e=CD00P0m?Cd01011
@D40?Cdm03dm?@0k>c/203lo?`80?Shn0P0l?3`05`0i>CT0>c/k03`l?00m?Cd0@D5103dm?@14A4@0
@D5103Xj>P14A4@0@T9204Y:BP1=CDd0B4Q804=3@`19BDT0BTY:04I6AP10@400A4A403lo?`14A4@0
>c/k0080?Shn00P0?Cdm03/k>`0i>CT0?3`l03Xj>P0i>CT0?3`l03hn?P80?3`l00l0>SXj03/k>`0n
?Sh0@D5103/k>`0h>3P0?Cdm03`l?00m?Cd0@d=30451@@0o?cl0>c/k0492@P0n?Sh00P0j>SX01010
@400@T9204a<C01EEED305YJFP0G05aLG01ZJVX0Kfm_075aL@1<C4`0A4A403Xj>P0k>c/0DE5A06MW
I`1eMGD0Kfm_06=SH`1DE5@0H61P06IVIP1JFUX0A4A403dm?@0n?Sh0@d=304A4A00m?Cd00P12@T80
300n?Sh0?clo03lo?`17AdL0BTY:03dm?@0k>c/0@T9203hn?P0h>3P0>SXj03Ph>0<0>CTi00D0>3Ph
03Xj>P0h>3P0>3Ph03Ti>@0203Lg=`0503/k>`0l?3`0>SXj03/k>`0j>SX00P0n?Sh01P0m?Cd0>CTi
03Ti>@0k>c/0>CTi03Lg=`80>SXj00H0>c/k03Ph>00l?3`0>c/k03Ti>@0h>3P203Ti>@80>SXj00<0
>CTi03Xj>P0h>3P00P0j>SX03`0i>CT0?3`l03`l?00k>c/0@T9204A4A00m?Cd0ATI605MGE`1OGel0
GEeM06m_K`1gMgL0J6QX06a/K00206m_K`80KFe]0180K6a/0861P@21PH40OWin08F5Q@29RHT0QXJ6
08f=S@2?Shl0Q8B408R8R02=SHd0TI6A09RHV02FUYH0U9BD096AT@25QHD207moO`0G07inOP24Q8@0
Ng]k08:2PP25QHD0MGEe06QXJ01UIFD0F5QH04i>CP10@400?Cdm05QHF01oOgl0Shn?09ZJVP2OWil0
WYjN09JFUP2LW9`0VIVI09bLW02BTY803Oooool0013ooooo01h0LW9b096AT@25QHD0P82007YjNP1c
Lg<0K6a/07IfMP1dM7@0N7Qh08B4Q02?Shl0QHF506m_K`1eMGD0XZ:R0:^[Z`2a/K40a<C40;>c/`2@
T900M7Ad07moO`1SHf<0D51@04A4A01<C4`0KFe]08:2PP1oOgl206][J`0U055AD@14A4@0@D5104A4
A01<C4`0H61P09FEU@2m_Kd0^[Zj0;:b/P2TY:@0[Zj^0;Jf]P2?Shl0HV9R05iNGP2<S8`0/K6a0:RX
Z02HV9P0TY:B08f=S@2@T900YJFU0:JVYP2i^KT0e]KF0<71`@28R8P0GemO05=CD`1LG5`0FUYJ04i>
CP19BDT0@d=30410@00203lo?`0603`l?00m?Cd0@D5104A4A011@D40?Cdm0P1BDU802017AdL0D51@
051@D01DE5@0BTY:04E5A@0l?3`0?Shn0P0m?Cd05P0n?Sh0?3`l0451@@0l?3`0@D5103`l?00n?Sh0
?clo03/k>`0o?cl0EEEE05eMG@1]KFd0I6AT04Y:BP19BDT0Cdm?04Y:BP17AdL0A4A403hn?P10@402
03lo?`0;03hn?P10@400BTY:03dm?@14A4@0@T9203lo?`11@D40?Shn0410@00m?Cd00P0o?cl05@0k
>c/0?Cdm03hn?P0j>SX0?3`l0410@00n?Sh0@41003hn?P12@T80?clo03hn?P1>CTh0GEeM06QXJ01W
IfL0GemO04a<C012@T80?3`l03hn?P0203lo?`0903`l?014A4@0?3`l03/k>`0o?cl0?Cdm03hn?P11
@D40?clo00<0@41000H0BDU90492@P14A4@0ATI604U9B@1:BTX204];B`0504U9B@18B4P0BTY:05QH
F01FEUH00P1EEED0A@1LG5`0Lg=c0861P@2;Rh/0N7Qh06UYJ@1aLG40PH6107]kN`1lO7`0R8R809jN
WP2;Rh/0N7Qh08B4Q01/K6`0Lg=c07QhN01lO7`0PH6108N7Q`2SXj<0ZZZZ08^;R`1MGEd0EUIF04Q8
B01NGUh0KVi^08B4Q02?Shl0XZ:R0:FUY@2][Jd0YZJV092@T01cLg<0HF5Q06MWI`1cLg<0P820071`
L01^KVh0JFUY05YJFP1DE5@0FEUI05MGE`1NGUh0KVi^06ATI01HF5P0EEEE05IFEP1EEED0EUIF05AD
E01LG5`0H61P06ATI01>CTh0ADE504i>CP1GEeL0GemO05UIF@15ADD0AdM703dm?@0203lo?`0603dm
?@0o?cl0>c/k03lo?`10@400?Cdm0P0j>SX06`0o?cl0?Cdm03dm?@0n?Sh0?3`l03hn?P10@400>SXj
03`l?00n?Sh0De=C05ADE013@d<0?clo03/k>`0m?Cd0ADE504e=C@1>CTh0?Shn03lo?`10@400?3`l
03Xj>P0l?3`0CTi>055AD@0204m?C`0;04M7A`14A4@0BDU903/k>`13@d<0@T9203dm?@0n?Sh0>c/k
03Ti>@0m?Cd00P0j>SX00`0k>c/0=cLg03Hf=P0303Ti>@0403dm?@0k>c/0?3`l03/k>`80>SXj0100
>c/k03Ti>@0l?3`0?Cdm03Ti>@0j>SX0?Shn03Xj>P0k>c/0>3Ph03Ti>@0l?3`0>SXj03Ti>@0m?Cd0
>CTi0P0j>SX0200m?Cd0>c/k03dm?@0n?Sh0ATI605=CD`1KFe/0CDe=0P15ADD0=@1;Bd/0EeMG05mO
G`1[Jf/0I6AT05]KF`1HF5P0GEeM05mOG`1CDe<0CTi>04a<C01DE5@0FUYJ05ADE01CDe<0BTY:04A4
A011@D40>c/k03`l?011@D40@41003Ti>@0j>SX0?3`l03Xj>P0g=cL0>CTi03Ph>00j>SX0?Cdm03Xj
>P0h>3P0=CDe03Ti>@0j>SX0@41003Ti>@0l?3`0>CTi03/k>`0m?Cd0@D5103hn?P0h>3P0?3`l03dm
?@0l?3`0>CTi03dm?@0j>SX0?3`l0080A4A40P0m?Cd02`0l?3`0>3Ph03Ti>@0k>c/0>SXj03Ti>@0n
?Sh0?Cdm03hn?P0j>SX0>CTi0080>c/k00l0BDU904i>CP1NGUh0Kfm_07YjNP1lO7`0NGUi08F5Q@2C
Ti<0UIFE09ZJVP2LW9`0V9RH08R8R02BTY800P2IVIT0202EUID0VIVI09nOW`2SXj<0WinO0:FUY@2O
Wil0Y:BT0P2JVYX0102TY:@0XZ:R09nOW`2PX:0209nOW`0;09jNWP2LW9`0U9BD08Z:RP1oOgl0QhN7
08Z:RP29RHT0R8R809NGU`2OWil00P2JVYX03@2FUYH0Shn?08b<S01bLW80MgMg09>CT`2`/;00[Zj^
0:NWY`2/[:`0Y:BT0::RXP2QXJ400P2[Zj/00`2a/K7oooooooooo`0;ooooo`004?ooool03P19BDT0
B4Q804M7A`1:BTX0ATI604E5A@14A4@0@D5104A4A012@T80AdM704Y:BP19BDT0ATI60P1:BTX204a<
C00505QHF01IFET0CTi>04U9B@1=CDd00P14A4@0E@19BDT0CTi>05=CD`1=CDd0BTY:04E5A@18B4P0
AdM704=3@`14A4@0BDU9051@D01>CTh0Kfm_096AT@2?Shl0R8R807YjNP24Q8@0YJFU0:b/[02QXJ40
WYjN0;Fe]@3=cLd0_[jn0:NWY`2`/;00^k^k0;Vi^@3@d=00b<S80;bl_030`<00]KFe0;Jf]P2YZJT0
[Zj^0;^k^`33`l<0[jn_08b<S01dM7@0IfMW07AdM01WIfL0EeMG05UIF@1DE5@0F5QH079bLP2DU9@0
UIFE079bLP1SHf<0L71`05iNGP1;Bd/0C4a<04A4A011@D40ATI604Q8B01ADE40Fe]K06QXJ01PH600
DE5A04i>CP1<C4`0BDU904Q8B01FEUH0KVi^09FEU@2BTY80TI6A08>3P`1WIfL0FEUI05QHF01BDU80
AdM703hn?P0l?3`00P0j>SX203lo?`0703dm?@11@D40AdM704A4A011@D40?3`l03hn?P0203dm?@0F
04M7A`1<C4`0@D5103dm?@12@T80?Shn0451@@0o?cl0?Shn0451@@14A4@0DU9B061PH01?Cdl0DE5A
06MWI`1KFe/0D51@04A4A011@D40?Cdm0410@080?Shn00`0@D5103hn?P0l?3`0?3`l03hn?P0m?Cd0
?clo03hn?P13@d<0@41003dm?@0i>CT20410@00L0451@@0o?cl0@d=30410@00o?cl0@T9204=3@`12
@T80ATI603hn?P18B4P0CTi>04a<C01NGUh0H61P06i^KP1ZJVX0GemO04e=C@14A4@0BTY:04i>CP1<
C4`0ATI60451@@1:BTX0E5AD055AD@80C4a<01T0@41004a<C01DE5@0Fe]K05iNGP1LG5`0H61P05iN
GP1EEED0D51@06IVIP1aLG40OGem0820P01mOGd0R8R809JFUP2TY:@0X:2P09VIV@2;Rh/0MGEe06=S
H`1aLG40Ogmo0080Shn?02<0UYJF09BDU02:RXX0Q8B40861P@1fMWH0N7Qh08V9R@2:RXX0PX:207mo
O`22PX80RXZ:08N7Q`2;Rh/0PH6107emO@1^KVh0JVYZ06=SH`1GEeL0Cdm?04E5A@1:BTX0A4A404U9
B@1=CDd0EUIF065QH@1PH600G5aL04m?C`13@d<0A4A40451@@0203hn?P0704=3@`11@D40?Shn03`l
?00j>SX0@D5104I6AP0205QHF00J05EEE@1DE5@0CDe=04=3@`1<C4`0G5aL06=SH`1IFET0FUYJ059B
DP14A4@0Cdm?05=CD`1FEUH0CDe=04I6AP1=CDd0BDU904A4A01ADE40CTi>04A4A015ADD0@41003hn
?P0o?cl203dm?@080492@P0k>c/0>c/k03Ph>00i>CT0>c/k03Ti>@0g=cL303Ti>@0503/k>`0l?3`0
@T9203dm?@0l?3`00P0m?Cd0100k>c/0?3`l03dm?@0m?Cd203`l?080>CTi00D0>c/k03Ph>00m?Cd0
>SXj03`l?00203hn?P0?03`l?00i>CT0?Cdm03dm?@0h>3P0>CTi03hn?P0k>c/0?Cdm03hn?P0j>SX0
?Shn03`l?00k>c/0?Cdm0080AdM700d0BDU904I6AP15ADD0B4Q80451@@14A4@0?Cdm04E5A@14A4@0
?Cdm03/k>`0l?3`0?Cdm0080>CTi00D0>3Ph03Ti>@0n?Sh0>c/k03Ti>@0203Ph>00603Lg=`13@d<0
?Cdm03`l?00m?Cd0?Shn0P0l?3`02`12@T80?Cdm04M7A`11@D40?clo0451@@13@d<0?Shn04=3@`12
@T80@41000<0@d=301P0@41004M7A`1:BTX0EUIF05iNGP1LG5`0H61P05aLG01KFe/0EeMG05IFEP1K
Fe/0FEUI051@D01;Bd/0C4a<04e=C@11@D40?Cdm03Xj>P1;Bd/0OWin08Z:RP2ATI4209jNWP0F09^K
V`2DU9@0V9RH09JFUP2MWId0WYjN09VIV@2DU9@0SHf=09>CT`2NWYh0VIVI09NGU`2NWYh0X:2P09BD
U02:RXX0T92@09bLW02WYjL0XZ:R0:>SX`80YjNW0240Z:RX0:j^[P2_[jl0[Jf]0:VYZ@2ZZZX0];Bd
0;Ng]`2j^[X0^;Rh0;Bd]02a/K40^k^k0<71`@38b<P0aLG50<?3``3:b/X0clo?0=3@d02`/;00a/K6
0=;BdP3=cLd0b/[:0<S8b03:b/X0cLg=0<K6aP3?cll0d];B0<o?c`3<c<`03Oooool0013ooooo01/0
BTY:04Q8B014A4@0AdM704A4A013@d<0A4A40451@@13@d<0@T9204=3@`15ADD0@41004U9B@14A4@0
ATI60492@P0n?Sh0@41004=3@`11@D40?Shn03dm?@12@T80AdM7051@D016ATH00P12@T820451@@0:
03dm?@10@400@D510451@@14A4@0BDU904I6AP13@d<0ATI60492@P80ATI600<0BTY:04Q8B01:BTX0
0P1^KVh03P1/K6`0P82008B4Q021PH40N7Qh06i^KP1aLG40NWYj07QhN01WIfL0L71`0820P02EUID0
VYZJ0P2DU9@08P2?Shl0S8b<06UYJ@1MGEd0D51@05aLG01lO7`0QHF507moO`2DU9@0[Jf]0;:b/P3<
c<`0dm?C0<[:bP36a/H0^KVi0;6a/@2DU9@0Ng]k075aL@20P800VYZJ0;Vi^@2m_Kd0^KVi0<?3``34
a<@0^KVi0;6a/@28R8P0IFEU05=CD`1IFET305=CD`0605mOG`1FEUH0?Shn04=3@`0o?cl0@D510P0n
?Sh00`0i>CT0?Cdm03dm?@0203lo?`0P04];B`1ADE40ADE504A4A01GEeL0JVYZ07YjNP1QHF40BDU9
05QHF01DE5@0BTY:0492@P17AdL0EEEE05QHF01RHV80IFEU06MWI`1[Jf/0HF5Q051@D018B4P0?clo
04A4A010@400@D5103`l?011@D40@41003lo?`0k>c/203dm?@0R04=3@`1CDe<0IVIV06=SH`1HF5P0
ADE50451@@16ATH0A4A40451@@1;Bd/0F5QH05EEE@16ATH0?Shn04I6AP11@D40ADE504];B`15ADD0
BTY:059BDP1GEeL0L71`07inOP1`L700IFEU05ADE01:BTX0@T9204=3@`12@T80@d=304E5A@80?clo
02l0>c/k04M7A`0o?cl0A4A404I6AP0o?cl0@D510410@014A4@0?clo0410@00o?cl0@d=30492@P13
@d<0CDe=04];B`1OGel0LG5a06m_K`1YJFT0I6AT06EUI@1GEeL0FUYJ05MGE`1IFET0FUYJ06ATI01N
GUh0HV9R05IFEP1PH600FEUI06EUI@1[Jf/0JVYZ06QXJ01ZJVX0K6a/06UYJ@1VIVH0HV9R05aLG01R
HV80KVi^08:2PP0207UiN@0G06IVIP1KFe/0DE5A055AD@1>CTh0FEUI05aLG01?Cdl0BTY:059BDP1L
G5`0FEUI05]KF`1OGel0Fe]K06e]K@1`L700NGUi06i^KP1EEED0ADE504=3@`17AdL00P16ATH0401A
DE40JFUY071`L01bLW80MgMg06i^KP1RHV80DE5A05MGE`1LG5`0GUiN06=SH`1WIfL0HV9R05QHF01L
G5`2065QH@0=061PH01>CTh0ATI603hn?P17AdL0BDU904e=C@1DE5@0BDU90451@@0o?cl0@D5103dm
?@020451@@0503/k>`0n?Sh0>c/k03`l?00k>c/00P0i>CT01@0j>SX0?Cdm03`l?00i>CT0?3`l00<0
?Cdm0P0l?3`00`1?Cdl0>c/k03hn?P0203dm?@0<03hn?P0o?cl0>SXj04=3@`0o?cl0>CTi03dm?@0o
?cl0@D510410@00m?Cd0?Shn0`0m?Cd0100n?Sh0?clo03lo?`0l?3`203lo?`0E03hn?P0i>CT0?3`l
03Xj>P0m?Cd0>c/k0492@P13@d<0BDU90410@014A4@0ADE504U9B@17AdL0@T9204M7A`12@T80@D51
0492@P18B4P0@d=30080?3`l00X0>c/k03dm?@0i>CT0@D5104=3@`1:BTX0CDe=04U9B@1;Bd/0Cdm?
0P1BDU809`1HF5P0Fe]K05]KF`1LG5`0IFEU06i^KP1LG5`0HV9R06YZJP1[Jf/0I6AT065QH@1LG5`0
Hf=S065QH@1VIVH0Jf][06IVIP1`L700MgMg07moO`28R8P0QXJ608B4Q01lO7`0QXJ608R8R02<S8`0
TY:B09BDU027QhL0O7al08Z:RP24Q8@0I6AT0410@00m?Cd0Hf=S08j>SP0209NGU`07096AT@24Q8@0
QHF508F5Q@2:RXX0Rh^;08j>SP0209BDU00409FEU@2@T900UiNG09^KV`80WinO00L0W9bL09nOW`2T
Y:@0Shn?0:6QX@31`L40b<S80080dM7A00H0emOG0=[JfP3AdM40fMWI0=[JfP3Ng]h20=[JfP040=cL
g03Fe]H0dM7A0<_;b`80clo?01D0cLg=0=3@d036a/H0[jn_0;6a/@32`/80a/K60;:b/P2EUID0X:2P
0<G5a@3<c<`0d];B0<o?c`3AdM40d];B0=3@d03>c/h0c<c<0<k>cP3?cll03Oooool0013ooooo00D0
B4Q804E5A@13@d<0@d=30451@@020492@P0803lo?`11@D40@D5103lo?`17AdL0ADE504I6AP14A4@2
0492@P0@04A4A013@d<0@41004A4A011@D40ATI604M7A`14A4@0ADE503hn?P10@400@D5104A4A011
@D40@d=30451@@<0?clo00<0A4A404M7A`12@T800P13@d<0101:BTX0ADE50492@P14A4@204=3@`0B
03lo?`17AdL0B4Q804A4A011@D40ADE50451@@15ADD0AdM704Y:BP16ATH0AdM704I6AP1:BTX0ATI6
04a<C018B4P0@4100P11@D4203dm?@0L03`l?012@T80B4Q8059BDP1QHF40KFe]06i^KP1nOWh0Ti>C
09ZJVP2PX:00U9BD09VIV@24Q8@0Ogmo09^KV`2`/;00];Bd0;Ng]`2IVIT0RHV908B4Q02FUYH0TI6A
07QhN01CDe<0BDU905IFEP80BTY:00D0DU9B04Y:BP13@d<0?Cdm0410@00203hn?P0S04A4A010@400
BTY:06UYJ@20P800QhN708Z:RP2ATI40VYZJ09:BTP1aLG40FUYJ06IVIP1RHV80G5aL059BDP18B4P0
?clo0451@@10@400DU9B079bLP2<S8`0P82006ATI01GEeL0BDU904a<C012@T80De=C04e=C@1BDU80
D51@03hn?P13@d<00P10@4005`0o?cl0?Shn0410@019BDT0Cdm?06ATI01]KFd0LG5a06QXJ01ZJVX0
M7Ad07moO`1cLg<0FEUI04M7A`1:BTX0CTi>059BDP1IFET0IVIV071`L01PH600I6AT0080K6a/00/0
Jf][079bLP1`L700IVIV065QH@1?Cdl0@d=30451@@0n?Sh0@41003hn?P0203lo?`0804A4A00o?cl0
@T9204a<C01CDe<0DE5A05QHF01SHf<205ADE00S051@D01BDU80Cdm?05MGE`1IFET0I6AT06e]K@1S
Hf<0F5QH05eMG@1YJFT0E5AD04];B`15ADD0CTi>051@D01<C4`0E5AD05MGE`1HF5P0DE5A05UIF@1B
DU80EEEE059BDP1GEeL0DU9B05YJFP1=CDd0BTY:051@D018B4P0?clo04A4A00n?Sh00`0k>c/04`11
@D40BDU904=3@`1@D500Cdm?05EEE@1OGel0IFEU06ATI01ZJVX0B4Q803/k>`0l?3`0BTY:06EUI@1h
N7P0L71`06EUI@1KFe/00P1BDU80<01NGUh0L71`06UYJ@1MGEd0GUiN06MWI`1[Jf/0KVi^06e]K@1V
IVH0GemO061PH01MGEd0KFe]06UYJ@1UIFD0Fe]K04i>CP1EEED0EeMG069RHP1PH600FUYJ069RHP1Y
JFT0HV9R05iNGP1FEUH0Fe]K051@D01<C4`0D51@04i>CP1?Cdl0A4A40492@P10@400>c/k04=3@`11
@D40?Cdm03lo?`0k>c/0?Shn03`l?00o?cl0>SXj03/k>`80?Cdm00D0>c/k03dm?@12@T80@D5103lo
?`0203dm?@080410@014A4@0>c/k03lo?`0n?Sh0?3`l03/k>`11@D4204M7A`0404Q8B014A4@0Cdm?
0451@@80@d=301@0@T9204=3@`10@400@41003hn?P0o?cl0@d=30451@@0o?cl0@d=303hn?P0m?Cd0
>c/k04A4A00m?Cd0?clo03`l?013@d<0A4A404Q8B080C4a<00P0D51@04U9B@1BDU80De=C055AD@1E
EED0Bd];04I6AP80Cdm?04d0BDU903hn?P0m?Cd0@T9205EEE@1hN7P0R8R808b<S024Q8@0RHV908j>
SP2?Shl0S8b<09FEU@2GUiL0U9BD09JFUP2EUID0Ti>C08^;R`2:RXX0Q8B40820P023Ph<0QXJ608:2
PP21PH40QXJ607moO`1mOGd0PH610820P024Q8@0PX:208F5Q@1hN7P0NGUi06a/K01UIFD0JVYZ06UY
J@1fMWH0RHV909FEU@2@T900UIFE0::RXP2NWYh0RHV907alO024Q8@0W9bL09nOW`2RXZ80WIfM09NG
U`2NWYh0[Jf]0:^[Z`2XZ:P0Zj^[0;Ng]`2l_;`0^k^k0;jn_P2i^KT0^k^k0<30`02m_Kd0^k^k0;Zj
^P2l_;`0bl_;0::RXP2UYJD0c<c<0=;BdP020=SHf00<0=OGe`3Jf]X0eMGE0=gMg@3Fe]H0fMWI0=SH
f03IfMT0dM7A0<k>cP3:b/X0b<S80P3<c<`02`3:b/X0c<c<0;2`/02DU9@0/K6a0<G5a@3>c/h0_Kfm
0;2`/038b<P0fMWI0080dm?C00P0clo?0=?Cd`3Cdm<0bl_;0<O7a`3:b/X0cLg=0=7Ad@gooooo000@
ooooo`0<04I6AP14A4@0@T9204E5A@0o?cl0@41004A4A013@d<0ADE504=3@`11@D40A4A40P12@T83
0451@@0604=3@`14A4@0@T9204E5A@16ATH0@d=30P15ADD00`1>CTh0@T9204A4A00204A4A00;0492
@P17AdL0AdM70492@P0m?Cd0@d=30451@@0o?cl0@d=303`l?00o?cl00P10@4001@11@D40ADE50492
@P10@400?3`l0080A4A400d0B4Q804I6AP1=CDd0D51@04a<C016ATH0CDe=04A4A013@d<0ADE50451
@@0l?3`0?clo0080?Shn00P0?Cdm03lo?`0o?cl0ADE504Q8B016ATH0CTi>04Y:BP80De=C02/0H61P
04i>CP1>CTh0AdM70492@P17AdL0A4A40451@@1?Cdl0HF5Q06=SH`1QHF40G5aL04Y:BP0n?Sh0BDU9
061PH01RHV80D51@04Q8B01GEeL0MWIf06m_K`27QhL0Lg=c04a<C01EEED0G5aL05ADE01>CTh0IfMW
07]kN`1bLW80OGem0:f][@2n_[h0aLG50<K6aP2f][H0W9bL07MgM`1;Bd/0@41000<0?Cdm0340>SXj
0451@@13@d<0A4A404I6AP1=CDd0E5AD055AD@1DE5@0DE5A05=CD`1WIfL0JVYZ04i>CP1;Bd/0ATI6
04U9B@14A4@0ADE503hn?P12@T80ATI604=3@`1CDe<0H61P06QXJ01MGEd0HF5Q06YZJP1SHf<0GEeM
065QH@1JFUX0Fe]K04e=C@13@d<0@41004E5A@1LG5`0I6AT06MWI`1MGEd0DE5A04a<C01BDU80DE5A
04Q8B015ADD0@T920080ADE502d0?Shn0492@P11@D40ATI60492@P1>CTh0@41003hn?P18B4P0De=C
04e=C@1>CTh0De=C04a<C017AdL0Bd];05aLG01CDe<0Cdm?05EEE@1>CTh0C4a<05iNGP1RHV80K6a/
06YZJP1SHf<0C4a<04M7A`1>CTh0@d=304M7A`1;Bd/0EEEE05UIF@1;Bd/0BTY:04Q8B013@d<0C4a<
051@D01EEED0Cdm?05=CD`1BDU800P1ADE403016ATH0B4Q80410@017AdL0?clo0451@@0k>c/0?3`l
03dm?@11@D40>c/k03hn?P80?3`l00D0>c/k03dm?@11@D40@T9203`l?00203dm?@0?03`l?00k>c/0
>c/k03dm?@11@D40@41004=3@`19BDT0ADE504a<C01GEeL0HF5Q069RHP1;Bd/0CTi>0080F5QH00/0
C4a<0451@@11@D40@41003lo?`18B4P0FUYJ06ATI01QHF40EeMG05aLG00205EEE@0D055AD@1:BTX0
Cdm?05ADE01WIfL0GEeM05=CD`1BDU80BDU904E5A@11@D40CTi>04Q8B019BDT0@41003dm?@0o?cl0
?3`l03dm?@12@T8203dm?@0903hn?P0j>SX0?3`l03Xj>P0l?3`0@41003`l?018B4P0BDU90080A4A4
00@0@D5103lo?`16ATH0@4100P0o?cl00`11@D40A4A403hn?P0203dm?@0D03lo?`1DE5@0EeMG05AD
E01<C4`0CDe=0451@@17AdL0A4A404=3@`1>CTh0D51@05ADE01<C4`0ADE504M7A`18B4P0BDU905EE
E@1OGel205eMG@0T069RHP1IFET0CDe=04A4A017AdL0C4a<06QXJ01mOGd0RHV908n?S`2>SXh0QhN7
0861P@1lO7`0P820071`L01UIFD0BTY:05EEE@1?Cdl0?clo04A4A01UIFD0PH6109NGU`2MWId0WinO
09fMW@2OWil0W9bL0:NWY`2UYJD0Z:RX0:JVYP2ZZZX0Z:RX0P2/[:`00`2UYJD0ZZZZ0:FUY@0209ZJ
VP0C0:>SX`2YZJT0Z:RX09nOW`2MWId0Xj>S0:VYZ@2a/K40]kNg0;Zj^P2h^;P0_Kfm0;>c/`2XZ:P0
Zj^[0;>c/`1kNg/0Ph>30:>SX`020:FUY@0Q0:b/[02[Zj/0/K6a0;:b/P2][Jd0^[Zj0;Jf]P2c/k<0
_Kfm0;:b/P2j^[X0c<c<0<S8b02i^KT0`<300<?3``32`/80b<S80<O7a`34a<@0_kno0<C4a02n_[h0
^KVi0;^k^`2o_kl0_;bl0<c<c02][Jd0ZJVY0<G5a@3>c/h0eMGE0080emOG00/0dm?C0=CDe03<c<`0
dm?C0=KFeP3Hf=P0d];B0<o?c`3AdM40clo?0<S8b0020<c<c080cLg=00P0bl_;0<o?c`3Cdm<0d];B
0=CDe03GemL0e]KF0=cLg080eMGE00T0e]KF0=3@d03De=@0e=CD0=KFeP3?cll0c/k>0<W9b@3?cll0
3Oooool0013ooooo00T0ADE504=3@`14A4@0@d=304A4A00o?cl0@41004A4A011@D400P12@T820410
@00404I6AP14A4@0@4100451@@80@T9200`0ADE504U9B@14A4@0@D510410@00n?Sh0@T920451@@0o
?cl0@d=30410@011@D430410@00603hn?P0o?cl0?Cdm03hn?P0o?cl0?Shn0P0o?cl06`10@400?3`l
04];B`18B4P0@4100451@@1>CTh0G5aL05QHF01ADE40C4a<05EEE@18B4P0ATI604Q8B010@400?3`l
03hn?P0m?Cd0>c/k03`l?00o?cl0?Shn0492@P15ADD0ATI604a<C00204e=C@0805ADE017AdL0@T92
04A4A015ADD0?clo03hn?P10@4020451@@0;03hn?P11@D40?Cdm03/k>`10@400@T9204M7A`14A4@0
?clo04A4A018B4P00P14A4@02P11@D40?Shn04Q8B01ADE40G5aL04m?C`14A4@0CDe=061PH01ZJVX2
05YJFP1106UYJ@1DE5@0A4A404m?C`1IFET0GEeM069RHP1LG5`0Hf=S07YjNP1PH600A4A40492@P13
@d<0@D5105QHF01eMGD0NWYj05iNGP1DE5@0De=C04e=C@1DE5@0GemO05]KF`1PH600Fe]K04Q8B017
AdL0ADE504];B`1JFUX0DU9B055AD@1LG5`0HF5Q06m_K`23Ph<0TY:B08n?S`1fMWH0I6AT051@D018
B4P0A4A404];B`1<C4`0@T920410@013@d<0@41004I6AP1ADE40GUiN06=SH`1KFe/0CTi>04a<C015
ADD0AdM70492@P0n?Sh0?Cdm03`l?010@4000P13@d<03P17AdL0B4Q804U9B@14A4@0AdM704a<C01>
CTh0Cdm?04E5A@10@400@d=30492@P0m?Cd0>c/k0P0l?3`03`10@400?Cdm03lo?`12@T80BTY:05QH
F01<C4`0E5AD05=CD`1>CTh0Bd];04M7A`18B4P0A4A404U9B@0204=3@`0903lo?`10@400BTY:04e=
C@1?Cdl0CTi>04Y:BP1>CTh0@D510080A4A40P10@4001@0o?cl0A4A403dm?@0o?cl0@4100080?3`l
00H0>CTi03hn?P0k>c/0>CTi03lo?`0l?3`203/k>`0303`l?00k>c/0?3`l00<0>CTi00`0>SXj03hn
?P0j>SX0>SXj03hn?P0l?3`0?Cdm0410@00m?Cd0?3`l0410@00n?Sh20410@02203lo?`15ADD0ATI6
04=3@`0k>c/0@d=303Ti>@0o?cl0?Shn04M7A`13@d<0AdM70451@@1BDU80De=C05MGE`1;Bd/0ATI6
0492@P13@d<0CTi>0492@P0o?cl0Bd];04U9B@16ATH0B4Q804=3@`10@400?Shn03lo?`10@400?3`l
03dm?@14A4@0BDU904A4A010@400@d=303dm?@14A4@0@410055AD@1DE5@0EUIF051@D01DE5@0DU9B
05QHF01ADE40E5AD051@D018B4P0AdM704E5A@17AdL0Cdm?0492@P10@400@D51059BDP1PH600HV9R
06MWI`1_Kfl0JFUY05eMG@1NGUh0Jf][071`L02;Rh/0SHf=08R8R01mOGd0KVi^07=cL`1kNg/0S8b<
09^KV`2LW9`0Vi^K0:2PX02SXj<0V9RH08b<S022PX80Q8B408b<S02JVYX0XZ:R0:FUY@2ZZZX0YjNW
0:2PX02QXJ40Vi^K09nOW`2NWYh0TI6A07]kN`1YJFT0GUiN05QHF01JFUX0PH61096AT@2>SXh0VYZJ
09fMW@2/[:`0/K6a0:j^[P2n_[h0`/;20;no_`32`/80^k^k0;2`/02b/[80^;Rh0;Ng]`2h^;P0^k^k
0;Bd]02XZ:P0[:b/0<S8b03<c<`0^;Rh0;Bd]080^[Zj0P2i^KT02P2f][H0];Bd0;Ng]`2d];@0^k^k
0;no_`3=cLd0b<S80;:b/P3:b/X20<C4a00S0:6QX@2HV9P0Xj>S0:BTY02SXj<0X:2P07QhN02<S8`0
]KFe0<?3``3>c/h0b/[:0<71`@2h^;P0a/K60<?3``31`L40a<C40;Ng]`30`<00`/;20<C4a02j^[X0
][Jf0;jn_P31`L40a/K60<C4a02XZ:P0W9bL0<C4a039bLT0e]KF0=GEe@3De=@00P3Cdm<30=GEe@0E
0=?Cd`3?cll0c/k>0=7Ad@3=cLd0alO70<W9b@38b<P0bl_;0<c<c039bLT0cLg=0<k>cP3AdM40eMGE
0=SHf03Fe]H0eMGE0=CDe03EeMD0e=CD0080d=3@00H0c/k>0<o?c`3AdM40clo?0<c<c03;bl/=oooo
o`004?ooool01@1<C4`0A4A404I6AP14A4@0@d=30080@T9200P0AdM705]KF`1>CTh0@D5104I6AP15
ADD0A4A40492@PH0@4100P0m?Cd203hn?P030410@011@D40?Shn0080?clo0P0m?Cd0100n?Sh0@410
03hn?P0m?Cd203lo?`0H03hn?P0l?3`0>SXj03`l?011@D40?clo03hn?P0j>SX0>CTi03hn?P13@d<0
C4a<04A4A00o?cl0?Cdm03lo?`0n?Sh0>c/k04=3@`0o?cl0?3`l03/k>`0l?3`0?Shn0`0k>c/0800h
>3P0?Shn03lo?`0l?3`0?Cdm04=3@`0j>SX0@T9203hn?P0j>SX0?3`l03hn?P12@T80?Cdm03/k>`0l
?3`0@T9203lo?`0l?3`0?Shn0492@P1:BTX0E5AD0451@@16ATH0?clo03`l?00m?Cd0?3`l03/k>`0n
?Sh0?Cdm0P0n?Sh01@0k>c/0@D5103hn?P12@T80@D510080?3`l01P0@4100451@@11@D40?Cdm03`l
?00k>c/0@D5104M7A`1:BTX0ATI60492@P17AdL0@T9204E5A@1;Bd/0Hf=S075aL@1XJ6P0D51@04i>
CP1:BTX0A4A40492@P15ADD204Y:BP0I04A4A00l?3`0@T9204a<C01JFUX0IVIV071`L01VIVH0Lg=c
07]kN`1eMGD0MgMg07moO`1gMgL0KFe]07EeM@1bLW80OWin08F5Q@1nOWh0IfMW05mOG`1XJ6P0JVYZ
06UYJ@0206QXJ00<06UYJ@1RHV80HV9R05aLG01>CTh0AdM70492@P0m?Cd0?clo0492@P14A4@0@T92
0P11@D402`15ADD0C4a<04m?C`1LG5`0HF5Q05mOG`18B4P0ATI60451@@0n?Sh0ADE50080?Cdm01X0
>c/k03hn?P0l?3`0@41003lo?`13@d<0@T9204A4A01@D500AdM704Y:BP11@D40@T920410@00o?cl0
?Shn03dm?@0l?3`0?Shn04I6AP17AdL0Bd];051@D01BDU80AdM704U9B@80@d=300l0@41003lo?`0k
>c/0@41004A4A00o?cl0?Shn03dm?@0n?Sh0@T9203dm?@0l?3`0>SXj03lo?`0l?3`00P0o?cl05`0l
?3`0>CTi03`l?00o?cl0?Shn03lo?`0m?Cd0>c/k0410@00l?3`0>SXj03Ti>@0l?3`0?clo0492@P15
ADD0@41003dm?@10@400?Shn03dm?@0o?cl0ATI60080>c/k00`0?3`l03hn?P0j>SX0>c/k0451@@0l
?3`0?clo03dm?@0o?cl0ATI604A4A013@d<204E5A@0;0451@@0m?Cd0ATI604i>CP1DE5@0Bd];04I6
AP19BDT0ADE504I6AP1<C4`00`1:BTX04@18B4P0A4A404i>CP1BDU80GemO065QH@1EEED0D51@059B
DP1>CTh0FEUI06=SH`1cLg<0QhN708b<S02GUiL0UIFE0080TI6A01<0U9BD092@T02;Rh/0QhN708R8
R01mOGd0Lg=c05iNGP15ADD0?Cdm06EUI@2;Rh/0SHf=09RHV02LW9`0VIVI09FEU@2?Shl0Ti>C0080
VYZJ01D0WYjN0:2PX02NWYh0WIfM09ZJVP2QXJ40XZ:R0:FUY@2TY:@0XZ:R09RHV02TY:@0Zj^[0:ZZ
ZP2XZ:P0YZJV0;2`/02a/K40[:b/0:n_[`2c/k<00P2o_kl09@2m_Kd0/;2`0;>c/`2n_[h0_kno0<K6
aP33`l<0_Kfm0;Fe]@2SXj<0V9RH09NGU`2TY:@0/[:b0;Zj^P2f][H0[Zj^0;Jf]P2l_;`0];Bd0;:b
/P2[Zj/0[jn_0:ZZZP2][Jd0/k>c0;Rh^02i^KT0][Jf0;Zj^P2i^KT0]KFe0;Ng]`2o_kl0_Kfm0;^k
^`2f][H00P2d];@0:02c/k<0^[Zj0;>c/`2g]kL0_;bl0;Bd]02g]kL0/[:b0<30`038b<P0aLG50<_;
b`39bLT0b/[:0<S8b037alL0cLg=0<C4a02k^k/0_;bl09RHV02YZJT0cLg=0<k>cP3=cLd0aLG50;Vi
^@2g]kL0`L710<;2`P2n_[h0^KVi0;Zj^P3:b/X0a/K60<O7a`2h^;P0/k>c0<G5a@38b<P20<K6aP0:
0;2`/02a/K40bl_;0=3@d03IfMT0e]KF0=?Cd`3Bd]80d=3@0=KFeP80eMGE00X0d];B0<o?c`3>c/h0
clo?0<[:bP34a<@0b<S80<c<c038b<P0bl_;0P3>c/h01`3;bl/0c<c<0=GEe@3GemL0a/K60=;BdP3C
dm<00P3Bd]801@3EeMD0d=3@0=3@d03@d=00dM7A0080d=3@00<0c/k>ooooooooool02oooool0013o
oooo0180AdM704A4A017AdL0ATI604Q8B010@400AdM705mOG`24Q8@0NGUi05ADE01BDU80BTY:04U9
B@1ADE40Cdm?04=3@`12@T8204=3@`030410@00n?Sh0?3`l00<0?clo01L0>c/k03lo?`13@d<0ADE5
04e=C@1KFe/0AdM70451@@0l?3`0?Cdm04A4A01KFe/0H61P04a<C01DE5@0I6AT06EUI@1HF5P0GEeM
04Y:BP0o?cl0?Cdm03Ti>@0203lo?`0503dm?@0n?Sh0@d=303`l?00h>3P00P0n?Sh0200m?Cd0>c/k
03`l?00l?3`0>c/k03Ti>@0l?3`0>c/k0P11@D400`0k>c/0?clo03lo?`0303dm?@030410@00j>SX0
?clo0080>c/k00T0?3`l03Ph>00m?Cd0>SXj03`l?00n?Sh0?Cdm0410@00n?Sh00P0l?3`0100i>CT0
?Cdm03/k>`0l?3`303dm?@0J03/k>`0n?Sh0>SXj03hn?P0l?3`0>3Ph03`l?00j>SX0?clo0451@@0l
?3`0@d=30492@P0l?3`0?Cdm0451@@16ATH0@T9204I6AP17AdL0B4Q80410@012@T80B4Q804];B`10
@4020451@@0P03lo?`12@T80@T9204=3@`12@T80A4A40492@P0k>c/0@D5104];B`1=CDd0A4A40410
@01?Cdl0GEeM05iNGP1LG5`0FUYJ05MGE`1MGEd0DU9B051@D01MGEd0EeMG06=SH`1ZJVX0GemO05IF
EP1NGUh0FUYJ05ADE01>CTh204Y:BP080492@P17AdL0BDU904=3@`18B4P0DE5A04U9B@12@T820451
@@0<04A4A016ATH0@T92051@D01IFET0Fe]K061PH01aLG40I6AT04e=C@11@D40A4A40P0n?Sh02`0o
?cl0?Shn03hn?P17AdL0@d=304Q8B015ADD0Cdm?05IFEP1HF5P0A4A40080@T9200D0@41003lo?`0l
?3`0?Cdm0410@00203hn?P090492@P14A4@0B4Q8055AD@1DE5@0B4Q804U9B@17AdL0BDU90080B4Q8
0100@41003lo?`0m?Cd0?3`l0410@00j>SX0>c/k03hn?P10@400>c/k03hn?P0l?3`0?clo03hn?P10
@400@d=30P0n?Sh0100l?3`0?Shn0492@P0o?cl203/k>`1<03lo?`16ATH0?Shn03`l?00m?Cd0@D51
0492@P17AdL0B4Q803lo?`11@D40?Cdm0410@00l?3`0@D5104=3@`0l?3`0?clo03hn?P13@d<0@D51
03hn?P11@D40?Shn04A4A015ADD0?Shn04Q8B017AdL0ATI60451@@10@400>CTi03hn?P1=CDd0EeMG
065QH@1SHf<0F5QH05YJFP1HF5P0JFUY075aL@1hN7P0Q8B408V9R@24Q8@0M7Ad07QhN01oOgl0RXZ:
08V9R@28R8P0PH6107emO@1eMGD0NGUi08R8R02>SXh0UIFE09:BTP2DU9@0V9RH09>CT`2NWYh0WIfM
09bLW02MWId0Vi^K0:>SX`2PX:00WIfM0820P01KFe/0CDe=07AdM080Vi^K00H0WYjN0:2PX02RXZ80
ZJVY0::RXP2PX:020:FUY@050::RXP2VYZH0ZZZZ0:ZZZP2XZ:P00P2][Jd03P2k^k/0_Kfm0;Jf]P2_
[jl0];Bd0;Vi^@34a<@0a/K60<c<c03@d=00eMGE0=CDe03EeMD0clo?0P3Bd]80:@3@d=00bLW90<71
`@39bLT0d=3@0=GEe@3=cLd0`L710;Vi^@2YZJT0UIFE09bLW02^[Zh0][Jf0;^k^`2i^KT0];Bd0;>c
/`2j^[X0/k>c0:n_[`2ZZZX0ZJVY0;Bd]02g]kL0^;Rh0;>c/`2h^;P0]kNg0;Fe]@2b/[80_;bl0;Ng
]`2l_;`0_Kfm0;no_`2b/[80[jn_0::RXP2f][H0];Bd0080/k>c0200_[jn0;Jf]P2d];@0Zj^[0:j^
[P2f][H0a<C40<W9b@3:b/X0a/K60<;2`P2h^;P0a<C40<?3``38b<P0b/[:0<_;b`3?cll0dm?C0<_;
b`36a/H0`l?30<;2`P2`/;00_;bl0<C4a02n_[h0_Kfm0;Vi^@33`l<0bLW90<_;b`80_kno00`0c<c<
0<[:bP3;bl/0a/K60;2`/02b/[80d=3@0=;BdP3Cdm<0e=CD0=GEe@3Fe]H30=OGe`070=KFeP3De=@0
dm?C0<o?c`3;bl/0alO70<g=c@020<_;b`090<o?c`3@d=00c<c<0<_;b`3:b/X0c/k>0=GEe@3Fe]H0
c/k>0080e=CD00D0clo?0=3@d03Cdm<0c<c<0<g=c@020<o?c`030=7Ad@3Cdm<0e]KF00gooooo000@
ooooo`030492@P14A4@0@4100080@d=301H0@D510492@P14A4@0@d=304M7A`13@d<0A4A40451@@1;
Bd/0EEEE065QH@1<C4`0D51@04e=C@15ADD0@T9204=3@`11@D40A4A40451@@0n?Sh0?clo0P12@T80
2P13@d<0CTi>05]KF`1RHV80EeMG04];B`15ADD0CDe=07emO@21PH42061PH00906i^KP1LG5`0D51@
06QXJ01`L700JVYZ05EEE@0m?Cd0?3`l0080>c/k0100?3`l03/k>`0n?Sh0@41003Xj>P10@400A4A4
03dm?@16ATH0B4Q804M7A`15ADD0@D5103/k>`0o?cl0?Shn0P0k>c/02P0m?Cd0?3`l03hn?P0m?Cd0
?clo0451@@0k>c/0>SXj03/k>`0j>SX203`l?00403dm?@0n?Sh0?Cdm03/k>`80>CTi00<0?Cdm03`l
?00k>c/00P0k>c/03@0i>CT0>c/k03/k>`0l?3`0?Cdm04=3@`10@400?Cdm03hn?P0j>SX0>c/k03`l
?010@4000P11@D409@0o?cl0?Cdm03dm?@14A4@0>c/k03lo?`0k>c/0?clo0492@P10@400?Shn0451
@@14A4@0@D5103hn?P12@T80B4Q80451@@0m?Cd0>c/k03dm?@0n?Sh0>SXj0492@P10@400@d=30410
@00o?cl0?Cdm0451@@16ATH0@d=30410@012@T80Bd];04Q8B01;Bd/00P18B4P09@17AdL0Cdm?055A
D@1>CTh0BDU904E5A@1?Cdl0BDU9051@D015ADD0@T920451@@0k>c/0@T9203hn?P0o?cl0?Cdm03hn
?P0o?cl0?Shn03/k>`11@D40?clo0451@@0o?cl0ATI603lo?`14A4@0@D510410@014A4@0?clo03`l
?00o?cl0@41003hn?P0m?Cd00P0n?Sh0400o?cl0B4Q804E5A@14A4@0CDe=05ADE01?Cdl0@D5103hn
?P0o?cl0?Shn04=3@`0o?cl0AdM70492@P0m?Cd204M7A`0<03dm?@17AdL0DU9B04e=C@18B4P0@d=3
0492@P10@400?Shn04E5A@0n?Sh0@T920P0m?Cd03P11@D40?Cdm03Ph>00n?Sh0?clo04=3@`0j>SX0
@D5103hn?P0o?cl0?Shn03lo?`10@400@D510P0n?Sh0200o?cl0@4100410@00o?cl0@D510410@00n
?Sh0Bd];0P1<C4`03@1?Cdl0CTi>059BDP1BDU80F5QH055AD@1@D500FUYJ05]KF`1EEED0Cdm?059B
DP1:BTX00P1IFET06P1PH600HV9R061PH01RHV80Hf=S05iNGP1PH600FEUI05ADE01?Cdl0?clo03dm
?@1<C4`0NWYj08>3P`2ATI40VYZJ09NGU`2FUYH0V9RH09bLW02PX:00Xj>S0:6QX@2KVi/0X:2P0P2M
WId01@2NWYh0XZ:R09bLW02LW9`0XJ6Q0080VIVI00`0Vi^K0:2PX02QXJ40YjNW0;2`/02VYZH0XJ6Q
09VIV@2DU9@0RHV908J6QP2:RXX209NGU`0?0:BTY02YZJT0XZ:R0:6QX@2JVYX0YZJV0:b/[02^[Zh0
]kNg0;Vi^@2m_Kd0`<300;Jf]P2i^KT0][Jf0080]kNg0100^[Zj0;Fe]@2`/;00][Jf0;Ng]`31`L40
b/[:0=3@d035aLD0^[Zj0;jn_P38b<P0clo?0<g=c@3@d=00e=CD0P3Hf=P0403GemL0dM7A0=?Cd`3E
eMD0bLW90<G5a@36a/H0b/[:0<o?c`3>c/h0^k^k0;no_`2h^;P0XZ:R0:NWY`2`/;020;Zj^P050;bl
_02k^k/0`l?30<C4a033`l<00P2e]KD02P2g]kL0^KVi0<C4a032`/80_Kfm0;bl_02h^;P0_kno0;Ng
]`2e]KD20;Vi^@0>0<30`02l_;`0]kNg0:RXZ02[Zj/0/k>c0;Vi^@2e]KD0_;bl0:j^[P2g]kL0^[Zj
0;Rh^02b/[820;Vi^@070;Rh^02j^[X0`/;20<71`@30`<00_kno0;Jf]P020;Zj^P0M0;^k^`2h^;P0
_Kfm0<c<c035aLD0_kno0;bl_02i^KT0[:b/0;no_`3<c<`0a<C40<;2`P2i^KT0_[jn0<_;b`3?cll0
a<C40<G5a@3;bl/0c/k>0<_;b`3<c<`0_Kfm0<71`@3AdM40clo?0=CDe03Cdm<00P3Fe]H03@3IfMT0
emOG0=OGe`3EeMD0f=SH0=[JfP3Fe]H0c/k>0<O7a`3:b/X0bl_;0<[:bP3?cll00P3AdM420<W9b@0@
0<k>cP3De=@0e]KF0=?Cd`3Jf]X0f=SH0=GEe@3Bd]80dm?C0=3@d03AdM40eMGE0=3@d03EeMD0emOG
0=SHf0gooooo000@ooooo`80ADE500h0@T9204A4A012@T80@D510492@P0m?Cd0@T920410@011@D40
@T920451@@12@T80?clo03dm?@80?clo0100?Cdm03/k>`0m?Cd0?clo03Xj>P0n?Sh0?Cdm03hn?P0m
?Cd0>c/k03`l?00n?Sh0?Cdm03hn?P0o?cl0?Cdm0P11@D402@0n?Sh0@41003dm?@0l?3`0?clo03hn
?P0o?cl0?Cdm0451@@0204Q8B00D04A4A00o?cl0?Cdm03lo?`10@400?Cdm03`l?00n?Sh0@T920410
@00m?Cd0?3`l03hn?P14A4@0CDe=059BDP1;Bd/0?Shn03dm?@0k>c/20410@00A03`l?00i>CT0@D51
04i>CP18B4P0?clo03hn?P0j>SX0?Cdm0410@00i>CT0A4A40451@@13@d<0ADE503`l?00n?Sh00P0j
>SX203/k>`0603dm?@0l?3`0?3`l03Xj>P0o?cl0>c/k0P0i>CT01`0k>c/0>SXj03`l?00n?Sh0>c/k
03`l?00k>c/00P0n?Sh01`0h>3P0?3`l03dm?@0n?Sh0@T9203/k>`0i>CT00P0k>c/02@11@D40@410
03hn?P10@400@D5103hn?P0m?Cd0@D5103dm?@0203lo?`0B03hn?P0k>c/0>c/k03hn?P0o?cl0@410
03hn?P0m?Cd0?Shn03`l?010@400ADE50451@@14A4@0@d=304I6AP14A4@0B4Q80P12@T802P19BDT0
De=C04Y:BP14A4@0ATI60451@@14A4@0AdM704I6AP13@d<403lo?`0L0410@00m?Cd0?Cdm03`l?00o
?cl0?Shn03`l?00o?cl0?3`l03hn?P0l?3`0?clo03`l?010@400@D5103lo?`10@400@D5104I6AP10
@400?Cdm03lo?`0n?Sh0?clo03dm?@0n?Sh0>c/k03lo?`80?Shn0P0o?cl00`12@T80@D510492@P02
0492@P0>04A4A018B4P0AdM704Q8B01BDU80CDe=04I6AP15ADD0@d=304I6AP1<C4`0@d=30451@@0n
?Sh20451@@0?03dm?@15ADD0A4A403lo?`13@d<0ADE50492@P14A4@0?3`l0492@P14A4@0ATI603lo
?`11@D40B4Q80080@41002/0?3`l0410@012@T80B4Q804i>CP1EEED0C4a<05IFEP1RHV80Kfm_08>3
P`2;Rh/0TI6A08f=S@2>SXh0UiNG09FEU@2FUYH0TI6A08j>SP2?Shl0T92@09:BTP2;Rh/0RXZ:08f=
S@2DU9@0UiNG09bLW02IVIT0V9RH09nOW`2KVi/0VYZJ09fMW@2FUYH0TY:B06i^KP1IFET0B4Q806AT
I02FUYH0WIfM0080XZ:R03L0Xj>S0:RXZ02WYjL0/K6a0;Zj^P2f][H0^;Rh0;2`/02ZZZX0Zj^[0:j^
[P2YZJT0Zj^[0:f][@2g]kL0]KFe0:n_[`2c/k<0]KFe0;^k^`2n_[h0`/;20<?3``32`/80`<300<71
`@35aLD0^k^k0;no_`2a/K40/k>c0:VYZ@2SXj<0UIFE09:BTP2MWId0YZJV0:FUY@2ATI40Z:RX0;no
_`32`/80`L710;no_`2j^[X0];Bd0;Rh^02k^k/0_Kfm0<71`@32`/80/k>c0;Rh^02c/k<0^[Zj0080
`<3000T0]KFe0;>c/`36a/H0a/K60<k>cP3<c<`0d=3@0=CDe03Cdm<00P3EeMD01`3AdM40d];B0<_;
b`32`/80`L710<G5a@3<c<`00P3GemL20=7Ad@0F0<W9b@34a<@0`/;20;Rh^02f][H0];Bd0;Vi^@30
`<00`L710;Vi^@2e]KD0_;bl0;fm_@30`<00_[jn0<71`@30`<00_;bl0;>c/`2b/[80^k^k0<30`080
_[jn03L0^;Rh0;^k^`2m_Kd0^KVi0;>c/`2WYjL0^KVi0;jn_P30`<00`l?30;Jf]P2c/k<0^k^k0;Rh
^02i^KT0_;bl0;jn_P2j^[X0_Kfm0;no_`2m_Kd0_[jn0<C4a02h^;P0];Bd0;Vi^@2l_;`0]kNg0;fm
_@3>c/h0`/;20<71`@30`<00^KVi0;6a/@2l_;`0b/[:0<W9b@2l_;`0/K6a0;Vi^@33`l<0bl_;0<71
`@35aLD0dM7A0<_;b`3=cLd0b<S80<G5a@36a/H0cLg=0=CDe03>c/h0e]KF0080e=CD00<0e]KF0=?C
d`3Fe]H00P3IfMT0103EeMD0d];B0<[:bP36a/H20<c<c00F0<_;b`3?cll0clo?0<_;b`3@d=00dM7A
0=;BdP3EeMD0fm_K0=GEe@3GemL0eMGE0=CDe03Fe]H0e=CD0=GEe@3Cdm<0f=SH0=KFeP3Cdm<0eMGE
0=OGe`gooooo000@ooooo`80A4A401T0@T9204A4A014A4@0?clo03hn?P10@400@T9203lo?`12@T80
@41003lo?`0m?Cd0?Shn03/k>`0o?cl0?Shn03dm?@0l?3`0?Shn0451@@0m?Cd0?Shn03/k>`0n?Sh0
?Cdm0080>SXj00l0@4100451@@0n?Sh0?Cdm03`l?00m?Cd0?Shn03lo?`12@T80?Shn03dm?@10@400
@d=303`l?010@4000P0m?Cd02`0n?Sh0?clo03lo?`0m?Cd0?Shn03dm?@0j>SX0?Shn03Ti>@0j>SX0
?3`l00<0>c/k00L0>SXj03lo?`0j>SX0>SXj03`l?00n?Sh0?clo0080?3`l0180>SXj03Ti>@0n?Sh0
@4100451@@0l?3`0?clo03/k>`0n?Sh0?Cdm0451@@14A4@0ADE504m?C`0o?cl0@D5104=3@`0k>c/2
03hn?P0<03`l?00n?Sh0?clo03lo?`10@400BDU90451@@0k>c/0?Cdm03Xj>P0l?3`0>c/k0P10@400
8@11@D40?clo0451@@0l?3`0?Cdm03hn?P0m?Cd0?clo03Xj>P12@T80@41003hn?P0o?cl0>SXj03`l
?00n?Sh0?3`l0451@@12@T80?Shn0451@@0l?3`0>c/k03dm?@0n?Sh0>SXj03dm?@12@T80@4100492
@P0o?cl0>CTi03dm?@020410@00C0492@P0o?cl0@d=30451@@10@400?3`l0451@@10@400A4A404a<
C01;Bd/0?clo0410@00l?3`0?Shn0410@014A4@0@T920410@00203lo?`0803hn?P0m?Cd0@d=30410
@00m?Cd0?clo0410@00n?Sh20410@00803hn?P12@T80@D510451@@0o?cl0@4100451@@0o?cl30492
@P070451@@0n?Sh0?Shn03hn?P12@T80@41003lo?`0203`l?0090410@012@T80@4100410@011@D40
@d=304e=C@15ADD0@T920080@D5100<0@410051@D01?Cdl00`1@D5002P1:BTX0Cdm?05IFEP1@D500
A4A404Q8B01=CDd0D51@05ADE01KFe/305mOG`0:05QHF01OGel0H61P06=SH`1aLG40J6QX05eMG@1D
E5@0Cdm?055AD@80B4Q80P11@D40<01_Kfl0OWin08b<S02EUID0Shn?09:BTP2EUID0W9bL09ZJVP2Q
XJ40WYjN0::RXP2UYJD0Zj^[0:JVYP2TY:@0WYjN09ZJVP2FUYH0VIVI09nOW`2PX:00XZ:R0:NWY`2T
Y:@0[Jf]0:NWY`2VYZH0Xj>S0:j^[P2ZZZX0[Zj^0;Fe]@2c/k<0/[:b0:^[Z`2][Jd0V9RH09bLW02[
Zj/0]KFe0;bl_032`/80`<300<?3``34a<@0alO70<[:bP80`l?301<0a<C40;jn_P2o_kl0^KVi0<C4
a036a/H0`<300<W9b@33`l<0a/K60<S8b03?cll0b/[:0<C4a038b<P0alO70<k>cP35aLD0`L710080
a/K60100b<S80;no_`2n_[h0_kno0;Zj^P2`/;00[:b/0;2`/02e]KD0[:b/07]kN`2JVYX0]kNg0;no
_`32`/80_kno0P32`/804P36a/H0`/;20<71`@37alL0bLW90;no_`33`l<0/;2`0:n_[`2f][H0/;2`
0:^[Z`2g]kL0bLW90<O7a`3=cLd0bl_;0=?Cd`80eMGE0`3Hf=P02P3Fe]H0c<c<0<?3``38b<P0alO7
0<C4a03Cdm<0e]KF0=OGe`3;bl/20<o?c`080;bl_02e]KD0]KFe0:j^[P2[Zj/0^k^k0;:b/P2l_;`3
0;Vi^@0X0;Ng]`2j^[X0`/;20;no_`2h^;P0/K6a0;Vi^@2h^;P0_;bl0;^k^`2n_[h0_Kfm0<71`@2k
^k/0`<300;:b/P2ZZZX0^k^k0;fm_@32`/80`L710;Bd]02[Zj/0`<300<W9b@2k^k/0a<C40<71`@34
a<@0`/;20<[:bP2n_[h0^KVi0;Zj^P2a/K40[:b/0;Fe]@2m_Kd0_;bl0<O7a`80`<3000l0_Kfm0;jn
_P2i^KT0];Bd0;Zj^P35aLD0a/K60<71`@2o_kl0`/;20<C4a038b<P0alO70<?3``3>c/h00P3<c<`0
3P3Bd]80bl_;0<k>cP3Cdm<0dM7A0<o?c`3De=@0dm?C0=WIf@3De=@0dm?C0=;BdP3>c/h0e=CD0P3A
dM440<g=c@0A0=7Ad@3Fe]H0c/k>0=CDe03AdM40eMGE0=OGe`3De=@0eMGE0=KFeP3Jf]X0fm_K0=SH
f03Jf]X0emOG0=WIf@3GemL00P3Kfm/00`3Fe]H0emOG0=SHf00=ooooo`004?ooool04017AdL0ADE5
04E5A@15ADD0@d=30492@P0o?cl0ATI604U9B@11@D40?clo04A4A01;Bd/0EUIF05=CD`19BDT204=3
@`0804A4A00o?cl0?Shn0451@@0o?cl0@41003dm?@10@40203hn?P0603lo?`11@D40@4100410@012
@T80@D51100n?Sh03P11@D40>c/k04E5A@1<C4`0BDU903hn?P14A4@0?Shn0451@@12@T80?clo04M7
A`11@D40?Cdm0P0o?cl0300l?3`0?Shn03/k>`0m?Cd0?Shn03Ph>00k>c/0?3`l03Ph>00n?Sh0>SXj
03/k>`<0?3`l01H0?Cdm03Xj>P0l?3`0?Cdm03lo?`0l?3`0?Shn03Xj>P0n?Sh0@D5103hn?P11@D40
?Shn0492@P15ADD0D51@04Q8B00j>SX0?Cdm03Xj>P0k>c/0?3`l0P0m?Cd08@0l?3`0ADE503dm?@0k
>c/0@D5103dm?@13@d<0@T9205=CD`1RHV80EeMG04m?C`1EEED0DE5A04a<C00i>CT0?Cdm04=3@`14
A4@0@D510492@P10@400?Cdm03/k>`0m?Cd0?clo03dm?@12@T80ADE50451@@0m?Cd0?clo03hn?P02
04I6AP0903dm?@0j>SX0@41004=3@`0n?Sh0A4A40410@012@T80@D510080?Cdm0180>c/k0492@P15
ADD0ATI603hn?P16ATH0@D5103dm?@0o?cl0@T920451@@10@400>c/k03dm?@0o?cl0@T9204A4A00n
?Sh20451@@0803hn?P12@T80@D5103lo?`10@400@D5103dm?@13@d<20410@00303dm?@13@d<0@d=3
0080@T9200`0A4A404E5A@10@400A4A40451@@0n?Sh0@41004M7A`16ATH0@d=30492@P15ADD204A4
A00A04=3@`18B4P0BDU904Q8B01=CDd0BDU904Q8B014A4@0ADE504M7A`1QHF40GemO06][J`1bLW80
KVi^07IfMP1kNg/00P26QXH0:@28R8P0Ph>308J6QP29RHT0R8R808^;R`2>SXh0UYJF09VIV@2CTi<0
TY:B09BDU02>SXh0Ti>C09FEU@2HV9P0X:2P09bLW02IVIT0Vi^K08b<S022PX80NWYj079bLP1NGUh0
De=C096AT@2ZZZX0YJFU0:6QX@2SXj<0WIfM09^KV`2RXZ80YjNW0:f][@2ZZZX0Zj^[0;>c/`2b/[80
/;2`0080/K6a02l0[Zj^0:RXZ02][Jd0Zj^[0;6a/@2l_;`0`<300;fm_@33`l<0alO70<C4a02m_Kd0
a/K60<;2`P33`l<0bl_;0<g=c@34a<@0`/;20;jn_P2YZJT0WinO0;:b/P30`<00a/K60<[:bP39bLT0
a/K60;fm_@33`l<0b/[:0<K6aP35aLD0c<c<0<K6aP31`L40`<300<S8b034a<@0alO70<[:bP36a/H0
`<300<?3``34a<@0aLG50<_;b`020<[:bP0e0=?Cd`37alL0a<C40<S8b034a<@0b<S80<71`@32`/80
`l?30;^k^`2j^[X0_;bl0;jn_P30`<00_[jn0:j^[P2i^KT0`L710<?3``34a<@0_[jn0;Zj^P33`l<0
b<S80<K6aP33`l<0alO70<G5a@2o_kl0^[Zj0;6a/@2d];@0^[Zj0;Bd]02^[Zh0^[Zj0<g=c@3AdM40
c/k>0=7Ad@3GemL0fMWI0=CDe03@d=00e=CD0=GEe@3Cdm<0b/[:0<_;b`3<c<`0a<C40<G5a@3<c<`0
0P3?cll08@33`l<0c<c<0<;2`P2d];@0/k>c0;2`/02d];@0[Jf]0<30`02h^;P0`<300;bl_02n_[h0
^[Zj0;Jf]P2l_;`0b/[:0<;2`P2f][H0^;Rh0;fm_@2j^[X0_[jn0<C4a031`L40`<300;Ng]`2j^[X0
`l?30;Zj^P2d];@0`/;20<O7a`020<W9b@0U0<O7a`30`<00b/[:0=;BdP37alL0bLW90<_;b`36a/H0
c/k>0<g=c@3;bl/0aLG50<;2`P2i^KT0]KFe0;:b/P37alL0a/K60<_;b`37alL0`l?30<C4a031`L40
^[Zj0;^k^`34a<@0`<300<G5a@34a<@0a/K60<;2`P2n_[h0bLW90<[:bP35aLD0b/[:0=3@d0020=CD
e0080<o?c`3Bd]80e]KF0=OGe`3Cdm<0fMWI0=OGe`3Hf=P20=GEe@0>0=?Cd`3?cll0dm?C0=KFeP3D
e=@0c/k>0=GEe@3AdM40dm?C0=GEe@3Fe]H0emOG0=SHf03EeMD20=?Cd`070=OGe`3Ogml0g=cL0=[J
fP3Kfm/0fMWI0>3Ph0020=[JfP060=cLg03MgMd0gMgM0=cLg03Jf]X0g=cL3Oooool0013ooooo01L0
B4Q804A4A011@D40@T9203hn?P0o?cl0BDU905]KF`1]KFd0IVIV05eMG@1TI6@0P82009BDU02LW9`0
SXj>06i^KP1IFET0J6QX051@D014A4@0ATI604=3@`020410@00<04A4A01HF5P0EEEE05aLG01YJFT0
F5QH051@D01OGel0J6QX06ATI01DE5@0D51@0`1GEeL03`1TI6@0IfMW06e]K@1FEUH0De=C04e=C@18
B4P0A4A404=3@`1EEED0@d=303lo?`13@d<0?clo03/k>`0203dm?@0403lo?`14A4@0@41003`l?080
?Shn00X0@4100492@P14A4@0@T920451@@15ADD0?Cdm0492@P0o?cl0ATI60P13@d<09015ADD0@d=3
0410@012@T80?Shn04=3@`17AdL0De=C05ADE01<C4`0ATI604];B`14A4@0@D5104a<C01FEUH0D51@
05=CD`1<C4`0BTY:04I6AP18B4P0DU9B055AD@1GEeL0GemO06m_K`1jNWX0MWIf079bLP1^KVh0EeMG
04E5A@0o?cl0ATI603`l?080?Cdm0180?Shn03dm?@0h>3P0>c/k03Hf=P0o?cl0@41004A4A00o?cl0
?Cdm0410@00o?cl0?Cdm03hn?P0m?Cd0@d=303hn?P13@d<20410@00804=3@`0o?cl0@D5104=3@`12
@T80@D510410@016ATH204A4A01003hn?P19BDT0ATI604E5A@14A4@0Cdm?0492@P15ADD0?Cdm0451
@@0m?Cd0A4A404Y:BP12@T80A4A40492@P0m?Cd0?Shn0451@@0o?cl0@T9204=3@`15ADD0A4A40410
@014A4@0ATI604=3@`14A4@0ADE50451@@16ATH0BDU904Q8B01<C4`0BTY:04I6AP13@d<0DU9B05IF
EP1GEeL0GUiN06MWI`1QHF40HV9R06][J`1lO7`0LG5a071`L01ZJVX0GUiN05UIF@17AdL0@D51069R
HP2>SXh0WIfM09bLW02MWId0X:2P0:6QX@2OWil0X:2P0:BTY0<0YjNW00D0[Jf]0;6a/@2][Jd0XZ:R
0:FUY@030:>SX`030:VYZ@2NWYh0W9bL0080WIfM0P2IVIT08@2VYZH0/[:b0;:b/P2^[Zh0[Jf]0;2`
/02JVYX0XZ:R0;6a/@31`L40_Kfm0;bl_032`/80_Kfm0<71`@37alL0c/k>0<S8b035aLD0cLg=0<k>
cP3=cLd0bl_;0<K6aP32`/80a/K60;bl_035aLD0a<C40<30`035aLD0a<C40<?3``020<G5a@0@0<C4
a030`<00a<C40<G5a@37alL0bLW90<c<c02j^[X0][Jf0;Vi^@2/[:`0/;2`0<71`@3>c/h0b/[:0<_;
b`80bLW900P0a/K60<?3``34a<@0clo?0<[:bP3>c/h0clo?0<W9b@80cLg=00d0bl_;0<c<c03;bl/0
b<S80<o?c`34a<@0b<S80<c<c03Cdm<0cLg=0=3@d03Cdm<0cLg=00@0d=3@0P3?cll07036a/H0_[jn
0<;2`P2m_Kd0_[jn0<71`@34a<@0_Kfm0<G5a@39bLT0`l?30<O7a`32`/80^k^k0;Fe]@2a/K40]KFe
0;no_`34a<@0_kno0<30`02k^k/0_;bl0<?3``2m_Kd0];Bd0:^[Z`2h^;P20<k>cP060=3@d03EeMD0
e]KF0=OGe`3Cdm<0dM7A0P3GemL0;03Bd]80bl_;0=3@d037alL0a/K60<g=c@3>c/h0a/K60<?3``2n
_[h0c<c<0<O7a`2^[Zh0WIfM0:VYZ@2d];@0]kNg0<O7a`2l_;`0/k>c0;Zj^P30`<00/k>c0;jn_P3:
b/X0e=CD0<_;b`32`/80aLG50<[:bP2j^[X0aLG50<?3``39bLT0^[Zj0:VYZ@2l_;`0cLg=0<G5a@2i
^KT0alO70<k>cP3Bd]80b<S80P3;bl/05`3>c/h0cLg=0<O7a`32`/80_Kfm0;no_`36a/H0aLG50<S8
b034a<@0`L710;fm_@2b/[80]KFe0<C4a038b<P0bl_;0<O7a`35aLD0b<S80<;2`P31`L40`l?30080
aLG500P0a/K60<30`035aLD0_[jn0;bl_035aLD0bLW90;fm_@80eMGE0140emOG0=GEe@3@d=00f=SH
0=cLg03Fe]H0emOG0=cLg03Fe]H0fMWI0=CDe03Fe]H0eMGE0=;BdP3Cdm<0e]KF0=?Cd`020=GEe@04
0=?Cd`3EeMD0fm_K0=SHf080fMWI0P3Fe]H02P3Kfm/0emOG0=_Kf`3Ng]h0gMgM0=[JfP3Lg=`0hN7Q
0=[JfP3Ph>030=gMg@030=CDe038b<P0`/;200gooooo000@ooooo`0L04I6AP14A4@0@T920451@@0o
?cl0?3`l0410@014A4@0C4a<04U9B@1CDe<0D51@05eMG@1QHF40Ogmo08:2PP1eMGD0I6AT0820P01K
Fe/0A4A404I6AP13@d<0@4100492@P18B4P0M7Ad07alO080NWYj01l0I6AT071`L02<S8`0Ti>C09NG
U`2?Shl0TY:B09VIV@25QHD0J6QX06a/K01YJFT0QhN708F5Q@27QhL0PH6107EeM@1aLG40N7Qh0861
P@1`L700GEeM05]KF`1EEED0B4Q804I6AP0l?3`0C4a<05mOG`1^KVh0Lg=c0080I6AT01@0JFUY06YZ
JP1cLg<0JFUY06YZJP1^KVh0I6AT06=SH`1<C4`0FUYJ05MGE`1UIFD0GEeM065QH@1ADE40A4A40451
@@1ADE40GEeM05iNGP80Cdm?0180E5AD05mOG`1>CTh0G5aL079bLP1eMGD0L71`07emO@1/K6`0NGUi
07=cL`1mOGd0QXJ60820P01QHF40GemO06e]K@1bLW8206][J`0=05eMG@1DE5@0ADE50492@P17AdL0
@41003Xj>P0n?Sh0@41003dm?@0j>SX0>CTi03Ph>0020410@00N03dm?@13@d<0ATI604U9B@12@T80
?clo03Xj>P10@400?3`l04=3@`10@400@d=303lo?`0n?Sh0@d=30451@@1CDe<0D51@03/k>`18B4P0
BTY:04M7A`19BDT0B4Q8051@D01;Bd/0B4Q804M7A`1?Cdl0AdM70P15ADD09017AdL0@d=304U9B@1>
CTh0ADE504M7A`18B4P0ATI604A4A012@T80?Shn04U9B@1@D500ADE504];B`15ADD0D51@05EEE@1>
CTh0EUIF05aLG01GEeL0G5aL061PH01UIFD0Kfm_06a/K01WIfL0HF5Q06m_K`1mOGd0SXj>09JFUP2I
VIT0Ph>308j>SP80W9bL00`0S8b<08>3P`26QXH0N7Qh06YZJP1=CDd0BTY:06a/K02DU9@0Z:RX0::R
XP2SXj<209nOW`0Y0:JVYP2/[:`0^KVi0<S8b033`l<0bl_;0<c<c038b<P0bLW90<c<c03:b/X0d];B
0<30`03:b/X0c<c<0<O7a`3=cLd0_[jn0<g=c@35aLD0`<300<G5a@31`L40^k^k0;bl_02`/;00XJ6Q
09:BTP2WYjL0[Zj^0;^k^`39bLT0_kno0<C4a03=cLd0eMGE0<_;b`39bLT0alO70<c<c039bLT00P3<
c<`01P3>c/h0a/K60<71`@39bLT0^;Rh0<71`@80`<3001<0^[Zj0<71`@38b<P0alO70<C4a031`L40
a/K60;no_`32`/80aLG50<O7a`3@d=00b<S80<K6aP39bLT0aLG50<O7a`3>c/h0e]KF0080bl_;02L0
cLg=0<[:bP39bLT0bLW90<o?c`3;bl/0b/[:0<g=c@3@d=00dm?C0<k>cP3?cll0d=3@0<_;b`3@d=00
bl_;0=3@d03<c<`0aLG50=;BdP3>c/h0dm?C0=7Ad@3@d=00c/k>0<g=c@3De=@0c<c<0<k>cP3@d=00
d];B0<o?c`39bLT0b/[:0<_;b`31`L40`<300<71`@2o_kl00P35aLD20<30`0030;fm_@2h^;P0/;2`
0080[jn_00@0_;bl0<30`02i^KT0^KVi0P2h^;P02032`/80_[jn0;Fe]@2ZZZX0]kNg0<k>cP3AdM40
d];B0P3EeMD01P3Fe]H0e=CD0=CDe03Kfm/0dm?C0<_;b`80cLg=01P0aLG50<g=c@3AdM40d];B0;jn
_P34a<@0`l?30<K6aP37alL0/;2`09ZJVP2QXJ40Zj^[0;Ng]`36a/H0_Kfm0;no_`30`<00]KFe0;Jf
]P3<c<`0clo?0<g=c@3@d=030<O7a`070<30`034a<@0`L710<O7a`36a/H0_[jn0<?3``020<S8b004
0<G5a@38b<P0bl_;0=;BdP80cLg=0P3:b/X06P36a/H0alO70<71`@2m_Kd0][Jf0<G5a@32`/80b<S8
0<g=c@39bLT0^KVi0;Bd]02j^[X0bLW90<O7a`38b<P0b/[:0<S8b034a<@0_[jn0<S8b034a<@0`l?3
0<C4a038b<P0`/;20`35aLD04`37alL0b/[:0<o?c`3Bd]80e=CD0=KFeP3Lg=`0e=CD0=OGe`3MgMd0
eMGE0=OGe`3Hf=P0emOG0=cLg03Hf=P0emOG0=GEe@3De=@00P3Fe]H20=OGe`0C0=SHf03GemL0f][J
0=gMg@3IfMT0f=SH0=_Kf`3Hf=P0f][J0=_Kf`3Lg=`0h^;R0=_Kf`3Ogml0gMgM0=cLg03MgMd0g]kN
0=_Kf`020=[JfP040=WIf@30`<00RHV908R8R0gooooo000@ooooo`80ADE500T0A4A40492@P0n?Sh0
?Shn04A4A012@T80?clo0410@012@T800P19BDT02@1:BTX0CTi>04m?C`1@D500Bd];051@D013@d<0
@41003lo?`0303hn?P0I03/k>`1@D500D51@05=CD`1HF5P0BTY:061PH026QXH0TI6A08Z:RP2BTY80
WinO0:2PX02>SXh0Ng]k06YZJP1NGUh0NGUi08N7Q`2;Rh/0TY:B096AT@2>SXh0Rh^;09>CT`0209jN
WP0609>CT`27QhL0MgMg071`L01MGEd0K6a/0P28R8P03`2?Shl0U9BD09jNWP2DU9@0LG5a06e]K@1M
GEd0IFEU08:2PP1jNWX0LW9b06UYJ@1/K6`0L71`07UiN@0207YjNP0>06QXJ01JFUX0FUYJ06][J`1c
Lg<0JFUY06YZJP1`L700HF5Q05UIF@1EEED0M7Ad08b<S02ATI4209BDU00Y08n?S`2;Rh/0TY:B09RH
V02KVi/0QHF505aLG01=CDd0EeMG06MWI`1QHF40GUiN05EEE@12@T80?Shn03lo?`12@T80?Shn03Xj
>P11@D40?clo04A4A011@D40?Cdm03lo?`10@400?clo03/k>`10@400?clo03hn?P10@400Bd];04Q8
B01;Bd/0A4A404M7A`14A4@0ATI60410@014A4@00P1=CDd0901DE5@0D51@04U9B@1CDe<0EEEE05]K
F`1TI6@0Hf=S06i^KP1cLg<0IVIV065QH@1WIfL0GUiN05=CD`1DE5@0D51@059BDP1RHV80KFe]06QX
J01LG5`0HF5Q04i>CP1;Bd/0ATI604E5A@1VIVH0MGEe07MgM`1iNGT0MgMg07emO@23Ph<0RHV9096A
T@80U9BD01h0UYJF09BDU02DU9@0V9RH09>CT`2DU9@0Shn?09NGU`2MWId0Xj>S0:ZZZP2][Jd0Y:BT
0:JVYP2/[:`0XJ6Q09ZJVP2GUiL0Xj>S09fMW@2KVi/0T92@08^;R`2EUID0Y:BT0;Bd]02k^k/0^[Zj
0;jn_P30`<020<O7a`040<_;b`3Bd]80e]KF0=KFeP80dM7A0180clo?0<c<c036a/H0cLg=0<W9b@3@
d=00d];B0=3@d03Bd]80cLg=0<k>cP3?cll0c<c<0<o?c`3@d=00bLW90<G5a@2b/[830:j^[P0509JF
UP2ATI40_Kfm0;Zj^P32`/800P3>c/h04@39bLT0a/K60<71`@30`<00`L710<O7a`35aLD0bl_;0<K6
aP37alL0`l?30;Vi^@31`L40`/;20<G5a@2m_Kd0`L7100<0`l?300T0`L710<K6aP38b<P0a<C40<W9
b@3=cLd0dM7A0=GEe@3=cLd00`3>c/h01P3AdM40clo?0<O7a`3=cLd0c/k>0<S8b080bLW901<0emOG
0<o?c`3Cdm<0dm?C0=3@d03AdM40bl_;0<c<c03AdM40cLg=0<o?c`3Bd]80dM7A0<g=c@3<c<`0clo?
0<k>cP3Bd]80clo?0080d];B00D0clo?0=3@d03<c<`0dM7A0<c<c0020<o?c`0N0<c<c03?cll0b<S8
0;Jf]P2i^KT0a<C40<c<c03=cLd0alO70<C4a031`L40][Jf0;Bd]02f][H0/k>c0:j^[P2d];@0aLG5
0;no_`2h^;P0^KVi0;Bd]030`<00`L710;Ng]`2[Zj/0]kNg0=7Ad@3Cdm<0dM7A0P3Cdm<07@3Fe]H0
f=SH0=GEe@3IfMT0d];B0<k>cP3?cll0dM7A0<c<c03?cll0eMGE0<W9b@2j^[X0bLW90<g=c@32`/80
b/[:0<71`@2b/[80[jn_0;>c/`2e]KD0b/[:0<O7a`35aLD0a<C40;fm_@2h^;P0c/k>0080dM7A00/0
d];B0<c<c03=cLd0b/[:0;Fe]@2l_;`0`/;20<c<c03;bl/0b<S80<_;b`020<c<c00K0<[:bP39bLT0
clo?0=CDe03?cll0dM7A0<[:bP3<c<`0aLG50<_;b`34a<@0`l?30;no_`35aLD0a<C40<[:bP3=cLd0
c/k>0<O7a`38b<P0a/K60<_;b`3<c<`0aLG50<S8b037alL0a/K60080aLG500@0a<C40<G5a@35aLD0
b/[:0P35aLD02@3:b/X0c<c<0<k>cP3Cdm<0dM7A0=;BdP3De=@0fm_K0=WIf@020=?Cd`0E0=SHf03>
c/h0e=CD0=KFeP3GemL0fm_K0=OGe`3Fe]H0e=CD0=GEe@3Fe]H0d=3@0=?Cd`3Bd]80e=CD0=OGe`3J
f]X0g=cL0=[JfP3GemL0f][J0080fm_K00@0f][J0=oOg`3Shn<0gMgM0P3Lg=`02P3MgMd0hN7Q0=cL
g03IfMT0f][J0=SHf03Fe]H0^KVi06a/K01dM7@=ooooo`004?ooool01017AdL0ATI604A4A014A4@2
04=3@`0:04Q8B015ADD0BDU905=CD`1:BTX0B4Q804A4A012@T80A4A40410@080?clo00d0?Shn0492
@P10@400?Cdm03lo?`11@D40?Cdm03hn?P10@400@D510492@P1?Cdl0HV9R0080JVYZ00d0MWIf065Q
H@1UIFD0IFEU06MWI`1LG5`0EUIF05EEE@1LG5`0HV9R075aL@1_Kfl0KFe]0080LW9b00/0KFe]07Mg
M`22PX80R8R807moO`1_Kfl0IFEU06=SH`1LG5`0EeMG069RHP0206=SH`0Q06i^KP1iNGT0KFe]04i>
CP14A4@0@d=304Y:BP1FEUH0E5AD05QHF01WIfL0IVIV06m_K`1aLG40OWin07alO01dM7@0KVi^079b
LP1hN7P0OGem07alO01iNGT0NWYj07AdM01TI6@0KFe]07alO021PH40Rh^;09:BTP21PH40Lg=c0080
KVi^00X0L71`07]kN`1aLG40EUIF04E5A@16ATH0Cdm?04a<C016ATH0B4Q80`0o?cl01012@T80ATI6
04a<C01EEED205MGE`0304m?C`1:BTX0ATI60080@d=300@0A4A404U9B@1:BTX0CDe=0P1JFUX01@1G
EeL0FEUI05mOG`1EEED0CDe=0080A4A400T0E5AD06=SH`1SHf<0IfMW06e]K@1mOGd0RXZ:09NGU`2I
VIT00P2LW9`00`2TY:@0Xj>S0::RXP0208b<S00408Z:RP2>SXh0UiNG09JFUP80TY:B02`0QXJ608R8
R022PX80SHf=08J6QP20P800IVIV05mOG`2@T900WinO0:>SX`2TY:@0ZZZZ0:BTY02PX:00YjNW0:ZZ
ZP2^[Zh0/;2`0;>c/`2`/;00[jn_0:RXZ02d];@0_kno0;^k^`2l_;`0a<C40<K6aP39bLT0d=3@0<g=
c@3;bl/0dM7A0<o?c`3=cLd0c/k>0<_;b`3<c<`0`/;20;Zj^P2ZZZX0/k>c0<;2`P80c/k>00L0b<S8
0<k>cP3>c/h0clo?0<S8b03>c/h0e=CD0080dM7A00d0d];B0=?Cd`3AdM40clo?0<k>cP3;bl/0clo?
0=;BdP3EeMD0dm?C0<o?c`3AdM40d=3@0080clo?01P0c/k>0=3@d03?cll0e=CD0=?Cd`3AdM40c<c<
0<O7a`2`/;00ZZZZ0<W9b@38b<P0b/[:0<K6aP37alL0`l?30<30`033`l<0`<300;fm_@2o_kl0a/K6
0<W9b@37alL20<W9b@050;no_`34a<@0alO70<S8b036a/H00P33`l<06035aLD0alO70<S8b033`l<0
a<C40<W9b@3<c<`0cLg=0<o?c`3De=@0c<c<0<_;b`37alL0cLg=0=;BdP3AdM40b<S80<k>cP3@d=00
cLg=0<o?c`39bLT0c/k>0<S8b080cLg=00H0b/[:0<o?c`3AdM40clo?0=3@d03AdM420=;BdP0<0=3@
d03?cll0c/k>0<_;b`3Bd]80cLg=0<c<c03Bd]80d=3@0<k>cP3@d=00b<S80`3<c<`20<o?c`040=3@
d03<c<`0aLG50;fm_@80a<C401/0clo?0=;BdP3:b/X0bLW90;no_`33`l<0^KVi0;:b/P2_[jl0]kNg
0<;2`P2i^KT0/k>c0;Vi^@2k^k/0_kno0;jn_P30`<00][Jf0;Vi^@3>c/h0dM7A0=?Cd`3GemL0eMGE
0=OGe`3IfMT00P3Jf]X04P3De=@0d];B0<k>cP3De=@0eMGE0=3@d03AdM40b/[:0<c<c03AdM40a/K6
0;^k^`35aLD0cLg=0<W9b@2j^[X0`L710;Ng]`80aLG500l0a/K60<S8b035aLD0`/;20<[:bP3AdM40
dm?C0<k>cP3:b/X0bl_;0<W9b@2l_;`0`<300<_;b`3Bd]800P3:b/X04`3>c/h0eMGE0=?Cd`3Bd]80
b/[:0=;BdP3AdM40bl_;0<o?c`39bLT0clo?0<c<c03;bl/0alO70<C4a037alL0c/k>0<c<c036a/H0
0P3Bd]803@3@d=00bl_;0<o?c`3:b/X0dM7A0<O7a`3=cLd0bl_;0<c<c039bLT0c<c<0=7Ad@3EeMD0
0P3Cdm<02@3>c/h0clo?0<k>cP3Bd]80eMGE0=cLg03IfMT0eMGE0=7Ad@020=KFeP040=GEe@3IfMT0
e]KF0=3@d080eMGE00h0emOG0=SHf03IfMT0f][J0=OGe`3EeMD0e]KF0=GEe@3Cdm<0eMGE0=OGe`3K
fm/0f][J0=cLg080gMgM00`0fm_K0=OGe`3Kfm/0fMWI0=_Kf`3Jf]X0f=SH0=oOg`3Lg=`0f][J0=_K
f`3IfMT20=[JfP050=KFeP3GemL0];Bd07QhN01cLg<03Oooool0013ooooo0140BDU904I6AP17AdL0
B4Q803hn?P0o?cl0@d=304A4A010@400@d=304I6AP12@T80ADE504Q8B013@d<0?clo03hn?P0203/k
>`0403lo?`14A4@0?3`l03lo?`80?Shn0P10@4001P13@d<0A4A404Q8B01<C4`0BDU904E5A@80@d=3
01/0@4100492@P1UIFD0HF5Q03/k>`10@400Cdm?059BDP1=CDd0BDU90451@@1CDe<0GemO06=SH`1R
HV80Jf][065QH@1PH600CTi>04I6AP1:BTX0DE5A04=3@`12@T80?Shn0410@00l?3`00P10@4000`0o
?cl0@41004=3@`0303dm?@060410@018B4P0@d=30492@P13@d<0B4Q80`17AdL0>01<C4`0EeMG059B
DP1BDU80DE5A04a<C019BDT0AdM704a<C01ADE40De=C05EEE@1QHF40IVIV05ADE01QHF40GUiN061P
H01LG5`0E5AD04];B`15ADD0@d=304E5A@14A4@0?clo0451@@0n?Sh0@D5104];B`1TI6@0LG5a07]k
N`1oOgl0PH610820P01iNGT0O7al07EeM@1jNWX0O7al0861P@25QHD0RHV9096AT@2>SXh0QHF508Z:
RP2;Rh/0QHF507EeM@1NGUh0Cdm?07IfMP2IVIT0ZZZZ0P2][Jd0702WYjL0[Zj^0:j^[P2b/[80/K6a
0:n_[`2a/K40];Bd0;>c/`2^[Zh0U9BD08N7Q`2?Shl0X:2P09nOW`2_[jl0_kno0<[:bP36a/H0`l?3
0;6a/@2OWil0X:2P0:ZZZP2QXJ40ZJVY0;jn_P33`l<20<O7a`0@0<30`02h^;P0];Bd0;Fe]@2h^;P0
_;bl0<;2`P35aLD0][Jf0<30`02l_;`0bLW90=?Cd`3@d=00dM7A0=3@d0<0c<c<00d0c/k>0<g=c@3@
d=00clo?0<g=c@3?cll0aLG50;jn_P2e]KD0_[jn0;fm_@32`/80alO70080b/[:01H0alO70<W9b@3=
cLd0bLW90<g=c@3Bd]80c<c<0<g=c@3>c/h0d];B0=?Cd`3?cll0c/k>0<g=c@3<c<`0a<C40<k>cP3D
e=@0d=3@0<c<c03Cdm<0cLg=0P3Bd]801`3@d=00d];B0=WIf@3Cdm<0e]KF0=WIf@3De=@00P3Cdm<0
6P34a<@0`/;20<[:bP3<c<`0aLG50;fm_@2o_kl0^[Zj0<30`02k^k/0/k>c0;Fe]@32`/80a<C40<K6
aP34a<@0`L710<G5a@37alL0aLG50<O7a`34a<@0alO70<30`034a<@0alO70P38b<P03P39bLT0bl_;
0=7Ad@3>c/h0d];B0<S8b037alL0b<S80<;2`P3;bl/0c/k>0=3@d03<c<`0c/k>0P3<c<`01@3;bl/0
b/[:0<k>cP3AdM40clo?0080bl_;00<0cLg=0=;BdP3>c/h00P3?cll01@3>c/h0d];B0=;BdP3>c/h0
c<c<0080clo?0`3>c/h01P3=cLd0dM7A0<[:bP37alL0b/[:0<c<c080clo?0P3:b/X01@3?cll0a/K6
0<W9b@3;bl/0aLG50080b/[:00h0cLg=0<o?c`3=cLd0bLW90<G5a@2o_kl0_;bl0;Zj^P36a/H0`l?3
0<71`@33`l<0a<C40<O7a`80aLG500T0`L710;jn_P3De=@0f=SH0=WIf@3Jf]X0f=SH0=[JfP3Kfm/0
0P3Jf]X00`3Hf=P0e=CD0=3@d0020=?Cd`80dM7A00h0dm?C0=;BdP3:b/X0`/;20;jn_P3;bl/0dM7A
0<o?c`3:b/X0bLW90;^k^`37alL0clo?0<c<c080b<S801h0b/[:0<g=c@3AdM40b/[:0<g=c@3>c/h0
d=3@0<g=c@30`<00bLW90<o?c`3Cdm<0d=3@0<g=c@3AdM40fMWI0=SHf03Cdm<0bl_;0=?Cd`3De=@0
dM7A0=GEe@3Bd]80dm?C0=GEe@3De=@0eMGE0=7Ad@3Cdm<20=CDe0050<o?c`3Hf=P0`/;20<[:bP3G
emL00P3De=@01`3GemL0f=SH0=KFeP3Cdm<0emOG0=_Kf`3Hf=P00P3IfMT00`3GemL0e]KF0=SHf002
0=[JfP0F0=WIf@3MgMd0f][J0=WIf@3AdM40e]KF0=CDe03Bd]80e=CD0=gMg@3GemL0dm?C0=KFeP3G
emL0f=SH0=OGe`3IfMT0fm_K0=WIf@3Kfm/0f=SH0=KFeP80fMWI0P3GemL0103EeMD0emOG0=OGe`3J
f]X20=SHf00<0=[JfP3EeMD0e]KF0=WIf@3Jf]X0gmoO0=gMg@3Lg=`0f][J0=gMg@3Kfm/0fMWI0P3H
f=P00`2b/[80IFEU04U9B@0=ooooo`004?ooool03017AdL0B4Q804Q8B017AdL0ADE504A4A011@D40
@4100451@@0o?cl0@d=303hn?P80ADE500l0@D510492@P12@T80@41003hn?P0o?cl0@D510492@P18
B4P0?clo0410@013@d<0BDU904=3@`0o?cl00P10@4000`0o?cl0?Cdm03/k>`0203hn?P0303/k>`13
@d<0BDU90080@41000d0@T920410@00n?Sh0@T9204A4A01FEUH0FEUI05IFEP1<C4`0EEEE04Q8B01B
DU80BTY:0080B4Q801H0A4A40451@@0l?3`0?Shn0492@P0k>c/0@D5103dm?@0k>c/0?Cdm0451@@0m
?Cd0@41003lo?`0n?Sh0@T9203hn?P12@T80?3`l0410@012@T80ADE50P19BDT04P1NGUh0EeMG05eM
G@1YJFT0KFe]079bLP1aLG40Kfm_06YZJP1cLg<0K6a/07IfMP1iNGT0L71`061PH01KFe/0GEeM05UI
F@80GUiN02<0De=C0492@P1ADE40GemO04i>CP1IFET0LW9b0861P@2HV9P0Y:BT0;2`/02k^k/0^;Rh
0;>c/`2WYjL0[:b/0:ZZZP2][Jd0[:b/0;:b/P2_[jl0/;2`0;>c/`2m_Kd0^[Zj0;^k^`2f][H0]kNg
0;^k^`2ZZZX0Ng]k079bLP2XZ:P0a/K60<[:bP020<;2`P110;jn_P35aLD0bLW90<O7a`39bLT0alO7
0<g=c@3<c<`0alO70<S8b03:b/X0`L710<K6aP3?cll0b/[:0=7Ad@3De=@0eMGE0<c<c03AdM40bl_;
0<c<c038b<P0^;Rh0:^[Z`2RXZ80WIfM0;^k^`3@d=00d];B0<;2`P2a/K40[Jf]0:ZZZP2YZJT0/;2`
0;Zj^P35aLD0`<300<S8b03Bd]80cLg=0=KFeP3@d=00dM7A0<g=c@3>c/h0cLg=0<[:bP3=cLd0bLW9
0<S8b03<c<`0a/K60<o?c`3:b/X0`<300;jn_P33`l<0bLW90<S8b03;bl/0bLW90<G5a@38b<P00P3=
cLd01`36a/H0c<c<0<c<c03AdM40clo?0=?Cd`3@d=000P3EeMD0103@d=00c/k>0=;BdP3?cll40<g=
c@0N0=3@d03?cll0e]KF0=?Cd`3Bd]80e]KF0=OGe`3Bd]80eMGE0=3@d02n_[h0bLW90=3@d03;bl/0
aLG50<?3``30`<00^;Rh0;Bd]02f][H0_;bl0;Zj^P2d];@0]KFe0;Rh^02c/k<0^KVi0;fm_@38b<P0
b/[:0P3;bl/04P36a/H0alO70<;2`P3:b/X0bLW90<G5a@37alL0c<c<0<K6aP34a<@0b<S80<[:bP3@
d=00c<c<0<_;b`36a/H0`l?30<G5a@<0cLg=0P3;bl/01P3:b/X0c<c<0<_;b`3=cLd0dM7A0=?Cd`80
c<c<00H0cLg=0<S8b03AdM40c<c<0<o?c`3AdM420=?Cd`0A0=;BdP3=cLd0bl_;0<k>cP3<c<`0c/k>
0<_;b`38b<P0c<c<0<g=c@3<c<`0b<S80<W9b@3;bl/0cLg=0<k>cP3=cLd00P3?cll01P3;bl/0b/[:
0<c<c03@d=00clo?0<O7a`80cLg=00X0clo?0=3@d03@d=00alO70=3@d03?cll0e=CD0<_;b`3:b/X0
`L710P38b<P01@2n_[h0^[Zj0<?3``31`L40d];B0080eMGE00/0e=CD0=?Cd`3Hf=P0f][J0=SHf03F
e]H0eMGE0=?Cd`3AdM40d=3@0=KFeP020=7Ad@060<o?c`37alL0][Jf0;Fe]@2j^[X0c<c<0P3?cll0
4@38b<P0c<c<0;bl_036a/H0dM7A0=3@d039bLT0`l?30:JVYP2QXJ40WIfM0:2PX02f][H0c/k>0=?C
d`3GemL0dM7A0080eMGE0P3GemL0103EeMD0fMWI0=[JfP3IfMT20=OGe`0;0=WIf@3Hf=P0dm?C0=GE
e@3Jf]X0fMWI0=[JfP3IfMT0emOG0=?Cd`3Bd]800P3GemL20=GEe@070=;BdP3EeMD0fm_K0=OGe`3L
g=`0fMWI0=[JfP020=WIf@050=[JfP3Lg=`0g=cL0=WIf@3Hf=P00P3GemL03P3IfMT0f=SH0=[JfP3E
eMD0f][J0=kNgP3Hf=P0e]KF0=SHf03GemL0e=CD0=[JfP3Rh^80e]KF0P3EeMD03@3IfMT0fm_K0=WI
f@3Jf]X0gMgM0=[JfP3MgMd0f=SH0=KFeP3MgMd0fMWI0=gMg@3Hf=P00P3IfMT02`3EeMD0f=SH0=_K
f`3Ng]h0fMWI0=cLg03Jf]X0g=cL0=kNgP3Kfm/0f][J0080h>3P00P0g=cL0=_Kf`3IfMT0f=SH0=?C
d`2NWYh0De=C055AD@gooooo000@ooooo`0404E5A@16ATH0@d=304E5A@80Bd];00X0@T920451@@12
@T80A4A404M7A`12@T80@d=304Y:BP19BDT0ATI60P12@T800`10@400?clo0410@00204=3@`0603hn
?P14A4@0B4Q804];B`13@d<0?Cdm0`0o?cl06P11@D40?Shn03`l?010@400A4A40410@014A4@0@D51
0410@019BDT0DE5A05=CD`1=CDd0C4a<05]KF`1_Kfl0EUIF055AD@1CDe<0CTi>05IFEP1@D500CDe=
04E5A@12@T80@4100P11@D401P10@400@D5103`l?015ADD0AdM70410@080B4Q800l0BTY:04e=C@1>
CTh0BDU904e=C@17AdL0@41005IFEP1UIFD0KFe]07IfMP22PX80U9BD09FEU@2LW9`00P2KVi/06P2O
Wil0WIfM09jNWP2MWId0WinO0:>SX`2a/K40[Jf]0:j^[P2ZZZX0WinO08j>SP21PH40QHF508>3P`1Z
JVX0De=C07moO`2YZJT0Vi^K0;2`/02j^[X0^k^k0<30`035aLD0c/k>0P3<c<`20<_;b`0:0<g=c@34
a<@0_kno0;no_`2j^[X0][Jf0;6a/@2h^;P0`/;20;no_`80`l?300L0`<300<G5a@36a/H0]KFe0:VY
Z@2m_Kd0b<S80080c/k>0P3GemL03`3IfMT0emOG0=KFeP3Hf=P0e]KF0<o?c`3Cdm<0e=CD0=7Ad@3?
cll0cLg=0=3@d03=cLd0c/k>0<o?c`020=7Ad@80c/k>02H0bl_;0=3@d03De=@0e]KF0=WIf@39bLT0
X:2P0;>c/`3<c<`0dM7A0<k>cP2g]kL0YZJV0:j^[P2b/[80^[Zj0<;2`P34a<@0bl_;0<W9b@3?cll0
c/k>0=?Cd`39bLT0d];B0=3@d03>c/h0c<c<0<[:bP3;bl/0a/K60<G5a@34a<@0aLG50<S8b03;bl/0
bLW90<k>cP80clo?00`0c/k>0<[:bP39bLT0bl_;0<[:bP3=cLd0c<c<0<_;b`3>c/h0dM7A0=;BdP3C
dm<20=KFeP0>0=?Cd`3?cll0c/k>0<_;b`3<c<`0d=3@0=7Ad@3@d=00dM7A0=?Cd`3AdM40d];B0=KF
eP3Cdm<20=CDe00A0=7Ad@39bLT0bl_;0=?Cd`32`/80alO70<[:bP38b<P0c/k>0<G5a@33`l<0/k>c
0;6a/@2b/[80]kNg0;Vi^@2j^[X00P2m_Kd08P2d];@0_Kfm0;no_`37alL0b<S80<C4a039bLT0alO7
0<S8b034a<@0cLg=0<S8b037alL0bLW90<g=c@36a/H0aLG50<K6aP37alL0bl_;0<O7a`39bLT0aLG5
0<O7a`39bLT0b/[:0<K6aP3AdM40a/K60<W9b@3@d=00cLg=0<W9b@3@d=030<k>cP0:0<g=c@39bLT0
bl_;0<o?c`3<c<`0c/k>0<g=c@3?cll0c/k>0<g=c@80c<c<00T0cLg=0<O7a`3:b/X0alO70<W9b@3;
bl/0c<c<0<g=c@38b<P00`3;bl/0303<c<`0d];B0=CDe03?cll0b<S80<O7a`38b<P0a/K60<C4a036
a/H0clo?0<[:bP80c/k>0180d=3@0<k>cP3De=@0clo?0=KFeP3Bd]80c/k>0<S8b03:b/X0bl_;0<C4
a035aLD0cLg=0<[:bP3Fe]H0f][J0=OGe`3IfMT20=OGe`0?0=SHf03Jf]X0fMWI0=KFeP3EeMD0dm?C
0<_;b`3Cdm<0dM7A0=;BdP3AdM40c/k>0<?3``37alL0d=3@0080d];B0180fMWI0=OGe`3Kfm/0dM7A
0=;BdP3Fe]H0f=SH0=WIf@32`/80M7Ad05YJFP1SHf<0KFe]09jNWP3EeMD0fMWI0>3Ph03Hf=P20=WI
f@030=cLg03Kfm/0fMWI0080f][J00@0fm_K0=cLg03MgMd0gMgM0`3Ng]h02`3Ogml0fMWI0=_Kf`3I
fMT0emOG0=GEe@3GemL0f][J0=SHf03IfMT0eMGE0080f=SH00@0h>3P0=[JfP3MgMd0fMWI0`3Kfm/0
403Jf]X0fMWI0=_Kf`3Hf=P0emOG0=WIf@3Lg=`0f=SH0=CDe03EeMD0e]KF0=WIf@3Lg=`0e]KF0=OG
e`3Jf]X20=gMg@050>;RhP3Xj>P0emOG0=_Kf`3Jf]X00P3Lg=`0503GemL0fMWI0=gMg@3Jf]X0fm_K
0=[JfP3Ng]h0gMgM0=WIf@3Ogml0e]KF0=WIf@3Fe]H0f=SH0=[JfP3Hf=P0fMWI0=_Kf`3Lg=`0f=SH
0P3Jf]X0103MgMd0f][J0=oOg`3Ogml20=_Kf`060=WIf@3GemL0dM7A08n?S`16ATH0FEUI3Oooool0
013ooooo0P18B4P01@17AdL0ATI604M7A`15ADD0@d=30080ADE500P0@D510410@013@d<0@D5104=3
@`0o?cl0@T920451@@<0@41000<0?Shn0410@013@d<00P10@4002@11@D40@T920451@@10@400@d=3
04I6AP14A4@0@D5103lo?`020492@P0_04A4A019BDT0D51@04I6AP13@d<0B4Q804I6AP18B4P0Cdm?
05=CD`1XJ6P0HF5Q04Q8B017AdL0Cdm?04E5A@1=CDd0De=C065QH@1SHf<0E5AD04Y:BP16ATH0DE5A
05mOG`1[Jf/0M7Ad06m_K`1bLW80MWIf0820P023Ph<0Q8B40861P@24Q8@0OWin06i^KP1<C4`0D51@
09>CT`2/[:`0[Jf]0;6a/@2`/;00/[:b0;Ng]`2h^;P00P2e]KD04`2i^KT0^[Zj0;bl_031`L40a<C4
0<K6aP38b<P0`l?30<K6aP3?cll0e]KF0=7Ad@3<c<`0^[Zj09fMW@2NWYh0][Jf0<C4a03IfMT00P3K
fm/01@3IfMT0fm_K0=SHf03Ng]h0h>3P0080h^;R02H0hN7Q0>CTi03Ng]h0eMGE0<g=c@3?cll0`/;2
0<K6aP31`L40`l?30<W9b@38b<P0c<c<0<k>cP38b<P0alO70<S8b02k^k/0^KVi0<O7a`3<c<`0d=3@
0=7Ad@3De=@0cLg=0<k>cP38b<P0bl_;0<c<c036a/H0]kNg0<O7a`33`l<0a/K60;^k^`34a<@0bl_;
0<;2`P80_kno01L0`/;20<30`030`<00a<C40<O7a`3;bl/0cLg=0=OGe`3IfMT0fm_K0=;BdP3>c/h0
dm?C0<o?c`3@d=00_Kfm0;6a/@2b/[80]kNg0;Zj^P2i^KT0a/K60<_;b`020=7Ad@050<k>cP3=cLd0
c<c<0<[:bP39bLT00P3>c/h0203<c<`0`l?30;jn_P31`L40_Kfm0<71`@32`/80alO70P3<c<`20<[:
bP030<_;b`33`l<0a<C40080alO700@0aLG50<O7a`3<c<`0clo?0`3Bd]80103AdM40dm?C0<_;b`3<
c<`20=7Ad@80c<c<0180c/k>0=3@d03De=@0dM7A0=3@d03Bd]80clo?0<[:bP36a/H0c<c<0=3@d038
b<P0b/[:0=3@d037alL0b/[:0<c<c03;bl/20<k>cP080<O7a`33`l<0_kno0;Rh^02g]kL0^k^k0;jn
_P2o_kl20;jn_P060<71`@30`<00a/K60<[:bP33`l<0b/[:0P3;bl/0203:b/X0c<c<0<S8b03;bl/0
c<c<0<[:bP39bLT0b/[:0`37alL01P36a/H0alO70<S8b037alL0b/[:0<k>cP80clo?00L0cLg=0<k>
cP3AdM40emOG0<c<c03Cdm<0clo?0080c/k>00<0c<c<0<_;b`3>c/h00`3=cLd03`3<c<`0clo?0<k>
cP3@d=00dM7A0=3@d03AdM40c<c<0<_;b`39bLT0dM7A0<[:bP3>c/h0d=3@0<_;b`020<[:bP090=7A
d@3@d=00dm?C0=GEe@3Bd]80clo?0<c<c03?cll0bLW90080b/[:00T0clo?0<W9b@3>c/h0c<c<0=3@
d03AdM40emOG0=CDe03Fe]H00P3@d=000`3Cdm<0dM7A0=KFeP020=?Cd`0B0=3@d03:b/X0d];B0=OG
e`3@d=00e=CD0=SHf03IfMT0g=cL0=oOg`3Kfm/0f][J0=WIf@3Jf]X0emOG0=GEe@3Jf]X0gMgM0P3R
h^80803Kfm/0g]kN0=oOg`3Ng]h0g=cL0>3Ph03Lg=`0gMgM0=_Kf`3Ng]h0fMWI0=KFeP3Kfm/0`L71
07AdM01KFe/0EeMG05iNGP2TY:@0g=cL0>3Ph03Ogml0gMgM0=cLg03IfMT0f][J0=WIf@3Hf=P0fMWI
0=_Kf`3Lg=`0fm_K0P3IfMT0103Lg=`0fm_K0=CDe03Kfm/30=SHf00@0=KFeP3De=@0e]KF0=[JfP3E
eMD0dm?C0=GEe@3GemL0f=SH0=_Kf`3Fe]H0fMWI0=GEe@3Hf=P0f][J0=SHf080emOG01L0fm_K0=SH
f03Fe]H0eMGE0=OGe`3Fe]H0eMGE0=SHf03Fe]H0eMGE0=SHf03Jf]X0eMGE0=SHf03Lg=`0gmoO0=kN
gP3Ti>@0f=SH0=OGe`3EeMD0e]KF0=[JfP020=cLg0060=_Kf`3Hf=P0f][J0=_Kf`3Ng]h0fm_K0P3H
f=P20=WIf@80e]KF00<0f][J0=SHf03Bd]800P3GemL0103Fe]H0fm_K0=_Kf`3Ng]h30=cLg0080=WI
f@3Jf]X0f=SH0=GEe@3AdM40SXj>06][J`1nOWh=ooooo`004?ooool0401=CDd0FUYJ05ADE016ATH0
ADE50451@@15ADD0Bd];04a<C016ATH0C4a<04I6AP14A4@0ATI60451@@15ADD20492@P80@41000@0
@D5104A4A017AdL0B4Q80P13@d<01`16ATH0AdM704M7A`1>CTh0CDe=055AD@1;Bd/00P1>CTh205IF
EP0I05=CD`1>CTh0DU9B055AD@1NGUh0LG5a07=cL`1aLG40M7Ad07moO`1MGEd0B4Q806e]K@2?Shl0
Q8B408j>SP2BTY80X:2P0:j^[P2QXJ40UiNG09BDU02QXJ40ZZZZ0;>c/`020;Vi^@030;Ng]`2h^;P0
_[jn0080_[jn00L0_;bl0<;2`P30`<00/;2`08J6QP23Ph<0a/K60080c<c<0140c/k>0<o?c`3?cll0
eMGE0=CDe03GemL0clo?0<[:bP3Cdm<0e=CD0=3@d03EeMD0f=SH0=OGe`3MgMd0f][J0=gMg@020>;R
hP090>?Sh`3Ogml0e=CD0<;2`P3:b/X0c/k>0=oOg`3Xj>P0i>CT00<0hn?S01L0h^;R0>KViP3Vi^H0
h^;R0>OWi`3QhN40g]kN0=GEe@3GemL0cLg=0<?3``36a/H0_;bl0;:b/P2i^KT0_kno0<G5a@3>c/h0
cLg=0<c<c036a/H0^;Rh0<S8b0020<W9b@0>0<[:bP30`<00a<C40;no_`2j^[X0^KVi0;fm_@2k^k/0
_[jn0;^k^`33`l<0b/[:0<W9b@35aLD20<_;b`050<C4a037alL0bLW90<O7a`35aLD00P37alL01P36
a/H0bl_;0=3@d03IfMT0clo?0=OGe`<0e]KF0100clo?0=3@d036a/H0_[jn0;^k^`2j^[X0`L710;Zj
^P34a<@0cLg=0=GEe@3Bd]80e]KF0=7Ad@3<c<`0c/k>0P3<c<`03@3?cll0c/k>0<S8b031`L40`<30
0<G5a@33`l<0`/;20<K6aP3;bl/0cLg=0=7Ad@3>c/h00P38b<P04`32`/80`l?30<g=c@34a<@0b/[:
0<k>cP3?cll0c<c<0=;BdP3Fe]H0eMGE0=?Cd`3AdM40d=3@0<g=c@3?cll0c/k>0<[:bP3?cll00P3<
c<`04`3;bl/0d];B0=7Ad@38b<P0bLW90<_;b`3Bd]80e=CD0<k>cP3;bl/0c<c<0<O7a`3<c<`0c/k>
0<c<c038b<P0bLW90<c<c03>c/h00P36a/H02`32`/80aLG50<O7a`32`/80^k^k0;fm_@31`L40b/[:
0<S8b03>c/h0b/[:0080clo?01T0c<c<0<g=c@3=cLd0clo?0<c<c035aLD0a<C40<W9b@34a<@0`L71
0<?3``3:b/X0bLW90<c<c03=cLd0b/[:0<o?c`3AdM40d=3@0=?Cd`3>c/h0d];B0=OGe`3EeMD0bl_;
0080b/[:00<0a/K60<;2`P38b<P00P3?cll02@3=cLd0d=3@0=3@d03Bd]80clo?0=3@d03?cll0cLg=
0<c<c0020<k>cP050<_;b`3<c<`0dm?C0<_;b`3>c/h00P3<c<`01P3=cLd0dM7A0=;BdP3Cdm<0e]KF
0=7Ad@80d=3@00P0c/k>0=3@d03?cll0dM7A0<o?c`3@d=00dM7A0=CDe080cLg=00@0dM7A0=?Cd`3F
e]H0f=SH0P3Bd]802`3AdM40f=SH0=SHf03Bd]80cLg=0<c<c03:b/X0cLg=0=7Ad@3Bd]80e=CD0080
f=SH0200e]KF0=_Kf`3IfMT0f=SH0=_Kf`3IfMT0f=SH0=GEe@3Lg=`0h>3P0>7Qh@3Ogml0g]kN0>7Q
h@3Ti>@0gmoO0=cLg03Rh^80hN7Q0=cLg03IfMT0gMgM0=[JfP3GemL0f=SH0<;2`P1]KFd0BTY:055A
D@1XJ6P0[Zj^0=oOg`80h>3P0140gmoO0=cLg03GemL0gMgM0=_Kf`3IfMT0f=SH0=_Kf`3Jf]X0g]kN
0=WIf@3Jf]X0fm_K0=oOg`3Jf]X0f=SH0=[JfP020=SHf00C0=KFeP3Cdm<0dM7A0=KFeP3Bd]80c/k>
0=;BdP3@d=00dM7A0=;BdP3Cdm<0eMGE0=SHf03GemL0fMWI0=SHf03Fe]H0f=SH0=KFeP030=OGe`80
e=CD00<0f=SH0=[JfP3Jf]X00P3GemL0103Fe]H0eMGE0=OGe`3Fe]H20=GEe@0:0=kNgP3MgMd0gmoO
0=gMg@3IfMT0f][J0=cLg03MgMd0g]kN0=_Kf`80f][J00<0g=cL0=WIf@3IfMT00P3Cdm<20=KFeP0@
0=GEe@3GemL0eMGE0=GEe@3Fe]H0dm?C0=OGe`3Ogml0g]kN0=[JfP3Ng]h0f=SH0=_Kf`3EeMD0f][J
0=GEe@80dM7A00<0a/K60<W9b@3=cLd03Oooool0013ooooo00H0EEEE069RHP1PH600E5AD04];B`1F
EUH205YJFP0705mOG`1GEeL0EEEE05]KF`1=CDd0EEEE051@D00204m?C`0404U9B@1<C4`0ATI6055A
D@80G5aL01`0BDU904e=C@1RHV80GemO06EUI@1cLg<0QHF509FEU@2CTi<0U9BD09VIV@2SXj<0YZJV
09nOW`2TY:@0XJ6Q09nOW`2FUYH0UIFE09bLW02TY:@0[jn_0;6a/@2XZ:P0Kfm_06a/K02`/;00c/k>
0P3=cLd02@3<c<`0clo?0=GEe@3@d=00clo?0<g=c@35aLD0bl_;0=CDe0020=KFeP80eMGE00/0f=SH
0=GEe@3EeMD0e=CD0=OGe`3Jf]X0e=CD0<30`02[Zj/0bLW90>7Qh@020=kNgP80gMgM00d0gmoO0=kN
gP3Ng]h0e=CD0<o?c`3<c<`0d];B0<g=c@3GemL0gMgM0=cLg03Ph>00g]kN0080hn?S00X0iNGU0>OW
i`3Ph>00i>CT0>3Ph03De=@0`l?30=_Kf`3Ti>@0i^KV0P3Shn<0103UiND0i>CT0>?Sh`3Ti>@20>GU
i@0B0>;RhP3MgMd0dm?C0=3@d03>c/h0`L710<C4a02m_Kd0[jn_0:VYZ@2^[Zh0^;Rh0<S8b03:b/X0
dm?C0=CDe03>c/h0bLW90P2l_;`03`2m_Kd0/k>c0;^k^`31`L40]kNg0;Jf]P2m_Kd0`/;20<_;b`3B
d]80d=3@0<o?c`3De=@0dM7A0=3@d0020=;BdP0B0<o?c`3Bd]80d];B0<c<c039bLT0dM7A0=CDe03@
d=00e=CD0=OGe`3Jf]X0eMGE0=SHf03EeMD0d=3@0=7Ad@3<c<`0`/;20P2b/[802P2g]kL0][Jf0;Rh
^035aLD0cLg=0=CDe03Fe]H0dm?C0<o?c`3;bl/20<[:bP0<0=WIf@3AdM40bl_;0<S8b033`l<0aLG5
0<S8b034a<@0a/K60<C4a039bLT0bl_;0P35aLD03P33`l<0bLW90<G5a@3=cLd0bl_;0<O7a`3?cll0
dM7A0=;BdP3Cdm<0d];B0=SHf03Fe]H0emOG0P3AdM400`3?cll0dM7A0=3@d0030<_;b`060<k>cP3<
c<`0c/k>0<K6aP31`L40alO70P3AdM40803Cdm<0dM7A0=7Ad@3=cLd0bLW90<C4a03<c<`0b<S80=CD
e03>c/h0dm?C0=7Ad@3>c/h0dm?C0<o?c`3Bd]80c/k>0<O7a`31`L40_[jn0<C4a039bLT0cLg=0<?3
``3=cLd0c/k>0=;BdP3=cLd0d];B0=KFeP3De=@0cLg=0P36a/H03@38b<P0`/;20<O7a`39bLT0bl_;
0<c<c03AdM40clo?0<_;b`3@d=00dm?C0<k>cP3@d=000P3Bd]804P3Cdm<0emOG0=3@d02l_;`0W9bL
08f=S@2:RXX0YJFU0<g=c@3Cdm<0e=CD0=;BdP3EeMD0dM7A0=3@d03Cdm<0dM7A0<k>cP80clo?00X0
d=3@0<o?c`3=cLd0d=3@0<g=c@3Bd]80dM7A0=;BdP3Fe]H0f][J0`3Fe]H00`3=cLd0d=3@0=3@d002
0<g=c@80c/k>00<0d];B0=OGe`3EeMD00P3@d=000`3>c/h0e=CD0=GEe@020=SHf0<0e=CD0`3IfMT0
2@3Ogml0fm_K0=SHf03Bd]80eMGE0=3@d03Fe]H0e=CD0=7Ad@020=3@d00C0=GEe@3Hf=P0g=cL0=WI
f@3GemL0fMWI0=SHf03MgMd0g]kN0=cLg03MgMd0g]kN0=oOg`3Ng]h0gmoO0>;RhP3Ph>00fMWI0=OG
e`020=[JfP0H0=kNgP3Hf=P0^k^k05iNGP1DE5@0GemO06IVIP2d];@0h>3P0=gMg@3Ng]h0fMWI0=_K
f`3EeMD0fm_K0=KFeP3EeMD0emOG0=GEe@3Hf=P0fMWI0=KFeP3GemL0f=SH0P3Fe]H01@3Hf=P0g=cL
0=GEe@3Hf=P0eMGE0080emOG01<0eMGE0=7Ad@3AdM40dM7A0=?Cd`3>c/h0d=3@0=;BdP3Cdm<0f=SH
0=KFeP3Hf=P0eMGE0=WIf@3Kfm/0eMGE0=[JfP3Fe]H0gMgM0080e=CD00D0f=SH0=[JfP3Hf=P0fm_K
0=CDe0020=;BdP040=?Cd`3?cll0cLg=0=3@d080f=SH00@0g=cL0=[JfP3Hf=P0fMWI0P3Jf]X01@3M
gMd0fm_K0=_Kf`3Jf]X0g=cL00<0emOG00<0cLg=0=;BdP3EeMD00P3Fe]H01@3Hf=P0e=CD0=?Cd`3@
d=00dm?C0080eMGE00L0e]KF0=OGe`3GemL0f][J0=CDe03=cLd0`l?30080bl_;00<0clo?0=;BdP3C
dm<03Oooool0013ooooo00P0CDe=04i>CP1SHf<0I6AT06MWI`1ZJVX0J6QX06a/K080LW9b01`0LG5a
07EeM@1bLW80Ogmo07]kN`1lO7`0RXZ:08f=S@28R8P0M7Ad0861P@23Ph<0Lg=c05QHF02<S8`0[:b/
0;:b/P2`/;00[Zj^0;fm_@35aLD0^;Rh0;no_`30`<00a/K60<W9b@3;bl/0c<c<0P3Cdm<20=7Ad@0?
0<K6aP2d];@0/k>c0<O7a`39bLT0^[Zj0;^k^`3EeMD0f][J0=SHf03Fe]H0fMWI0=gMg@3Hf=P0eMGE
0080fm_K00@0d];B0=[JfP3MgMd0gmoO0P3MgMd03@3Lg=`0gMgM0=[JfP3Lg=`0fm_K0=GEe@3Fe]H0
emOG0<k>cP3?cll0e]KF0=gMg@3Kfm/00P3IfMT04`3Kfm/0f][J0=OGe`3EeMD0c<c<0<S8b033`l<0
bl_;0=CDe03Lg=`0gmoO0>3Ph03Ti>@0gmoO0>?Sh`3Ti>@0hn?S0>;RhP3Shn<00P3UiND00`3Shn<0
hN7Q0>KViP020>;RhP0:0>7Qh@3Rh^80i>CT0>7Qh@3Rh^80hN7Q0>;RhP3Shn<0h>3P0=OGe`80c/k>
01`0b<S80;jn_P2l_;`0^;Rh0;6a/@2OWil0YZJV0:RXZ02g]kL0`L710<k>cP3;bl/0_kno0;Zj^P2a
/K40/k>c0;fm_@2g]kL0`/;20=?Cd`3;bl/0aLG50<O7a`3>c/h0dM7A0=3@d03De=@0emOG0P3>c/h2
0<g=c@050=3@d03?cll0d];B0<o?c`3AdM400P3Bd]80<03@d=00eMGE0=KFeP3GemL0fm_K0=OGe`3E
eMD0emOG0=;BdP38b<P0`L710:n_[`2TY:@0ZJVY0;:b/P2e]KD0^[Zj0<O7a`3AdM40e=CD0=GEe@3B
d]80dM7A0<o?c`3AdM40e=CD0=oOg`3De=@0dM7A0<?3``35aLD0c/k>0<o?c`3;bl/0c/k>0<c<c03=
cLd0b/[:0<30`032`/80`<300<O7a`3?cll0dm?C0=7Ad@3Cdm<0e=CD0=?Cd`<0e]KF00D0fMWI0=OG
e`3Hf=P0d];B0=7Ad@020=KFeP050=GEe@3Bd]80cLg=0<o?c`3<c<`00P3>c/h01@39bLT0a/K60<g=
c@3Bd]80dm?C0080dM7A01L0clo?0<g=c@3=cLd0b<S80<30`038b<P0d];B0=CDe03IfMT0e]KF0=?C
d`3Hf=P0fMWI0=KFeP3=cLd0alO70<C4a037alL0c/k>0<c<c038b<P0a/K60<G5a@020=?Cd`0?0=7A
d@3Hf=P0eMGE0=;BdP3GemL0clo?0<g=c@3Cdm<0dM7A0=CDe03>c/h0bLW90<o?c`3Bd]80d=3@0080
d];B00d0dm?C0<[:bP3Bd]80dm?C0=GEe@3Fe]H0dm?C0<k>cP2][Jd0Lg=c06ATI01_Kfl0VYZJ0080
d];B00P0e=CD0=3@d03EeMD0clo?0=7Ad@3Cdm<0e]KF0=7Ad@@0dm?C00<0c/k>0=CDe03AdM400P3E
eMD04`3Fe]H0dM7A0<W9b@3<c<`0d];B0=?Cd`3AdM40bl_;0<c<c03=cLd0dm?C0=GEe@3Fe]H0eMGE
0=?Cd`3IfMT0f=SH0=?Cd`3Bd]800P3Cdm<00`3Fe]H0f][J0=OGe`040=SHf0040=CDe03Lg=`0fm_K
0=gMg@80d=3@00L0clo?0=7Ad@3>c/h0clo?0=7Ad@3@d=00eMGE00<0gMgM00H0fMWI0=SHf03IfMT0
fm_K0=gMg@3Ogml30>;RhP070>3Ph03QhN40gmoO0>3Ph03Jf]X0fm_K0=gMg@020=_Kf`0:0=WIf@2X
Z:P0CTi>05UIF@1LG5`0H61P0<?3``3QhN40g]kN0=_Kf`80gMgM01<0f][J0=gMg@3EeMD0eMGE0=CD
e03EeMD0fMWI0=OGe`3@d=00bl_;0=?Cd`3AdM40emOG0=SHf03GemL0e]KF0=SHf03De=@0dm?C0080
eMGE00P0e]KF0=GEe@3Cdm<0f=SH0=GEe@3IfMT0clo?0=?Cd`80fMWI00<0e]KF0=SHf03Jf]X00P3J
f]X00`3IfMT0f=SH0=?Cd`020=KFeP070=OGe`3Kfm/0e=CD0=GEe@3@d=00bLW90<g=c@020<o?c`03
0=7Ad@3@d=00f=SH0080fMWI00T0emOG0=KFeP3Fe]H0emOG0=WIf@3Jf]X0fm_K0=WIf@3Hf=P00`3G
emL02`3Bd]80b/[:0=7Ad@3?cll0d];B0<[:bP3?cll0b/[:0<o?c`3AdM40d];B0080eMGE00`0e]KF
0=CDe03Cdm<0f=SH0=7Ad@3=cLd0bLW90<c<c03;bl/0d=3@0<S8b036a/H=ooooo`004?ooool0801A
DE40Lg=c09FEU@2OWil0VIVI0::RXP2YZJT0[jn_0;>c/`2/[:`0/K6a0;Rh^02m_Kd0_kno0;bl_02m
_Kd0alO70<o?c`38b<P0bLW90<S8b032`/80Z:RX09:BTP32`/80d=3@0=CDe03Cdm<0c/k>0=WIf@3G
emL0e]KF0P3Hf=P04@3MgMd0g=cL0=kNgP3Lg=`0gMgM0=WIf@3MgMd0g=cL0=[JfP3Ng]h0eMGE0<[:
bP3Bd]80dm?C0<c<c03Ogml0hN7Q0080gMgM00/0g=cL0=kNgP3Ng]h0g=cL0=_Kf`3MgMd0f=SH0=gM
g@3Ng]h0gmoO0=kNgP020=cLg0080=gMg@3Lg=`0g]kN0=KFeP3Hf=P0emOG0=SHf03Lg=`20=CDe008
0=KFeP3Hf=P0f=SH0=OGe`3EeMD0emOG0=CDe03=cLd20<K6aP050<o?c`3>c/h0i>CT0>;RhP3Shn<0
0P3Ti>@0103Rh^80hn?S0>;RhP3QhN420>?Sh`0<0>WYj@3Xj>P0hN7Q0>;RhP3UiND0h^;R0>CTi03R
h^80hn?S0>CTi03Ogml0h^;R0P3Ph>004P3Rh^80h>3P0=KFeP3@d=00c/k>0<_;b`37alL0_;bl0;:b
/P2[Zj/0Xj>S0:FUY@2][Jd0_;bl0<?3``35aLD0`/;20;jn_P80_;bl00T0_[jn0<W9b@38b<P0b/[:
0<g=c@3?cll0alO70<c<c03AdM400P3?cll04@3Bd]80clo?0=3@d03AdM40clo?0=3@d03>c/h0dM7A
0=OGe`3AdM40emOG0=CDe03Bd]80dm?C0=GEe@3Fe]H0dm?C0080emOG00D0f=SH0=;BdP3=cLd0a/K6
0;Bd]0020:NWY`0>0:ZZZP2g]kL0a/K60<S8b03<c<`0e]KF0=CDe03Hf=P0emOG0=WIf@3Jf]X0gMgM
0=_Kf`3Lg=`20=SHf0030=GEe@3De=@0dM7A0080e=CD0`3AdM402@3De=@0e]KF0<[:bP3<c<`0d=3@
0<g=c@3GemL0f][J0=SHf0020=OGe`060=7Ad@3:b/X0fMWI0=[JfP3IfMT0f=SH0P3GemL02`3Jf]X0
eMGE0=SHf03EeMD0clo?0=3@d03<c<`0clo?0<_;b`37alL0bl_;0080e]KF00H0f=SH0=CDe03De=@0
e=CD0<o?c`3:b/X20<S8b0050<g=c@3Bd]80e=CD0=WIf@3Jf]X00P3Hf=P02@3GemL0e=CD0=?Cd`3B
d]80c<c<0=7Ad@3?cll0c/k>0<[:bP020<c<c0080=CDe03Hf=P0fMWI0=[JfP3Bd]80eMGE0=[JfP3D
e=@20=OGe`070=3@d03Bd]80dm?C0=3@d03>c/h0dM7A0=GEe@020=KFeP040=GEe@3?cll0eMGE0=CD
e080d];B00T0d=3@0=?Cd`2^[Zh0IfMW04i>CP1MGEd0VIVI0=7Ad@3Bd]800P3Cdm<20=CDe0040=SH
f03De=@0f=SH0=GEe@80e]KF00D0emOG0=KFeP3Bd]80g=cL0=OGe`020=KFeP050=GEe@3AdM40c<c<
0=CDe03Cdm<00P3Bd]802P3>c/h0clo?0=7Ad@3GemL0eMGE0=7Ad@3Bd]80emOG0=_Kf`3MgMd20=CD
e0040=SHf03Fe]H0e=CD0=[JfP80e]KF00P0dm?C0=KFeP3IfMT0f][J0=_Kf`3Fe]H0e=CD0=7Ad@80
bLW900L0bl_;0=3@d03De=@0dM7A0=CDe03Jf]X0gmoO0080gMgM00@0fm_K0>3Ph03Ng]h0gmoO0P3T
i>@00`3Shn<0hN7Q0>3Ph0020>?Sh`040>3Ph03Ng]h0g=cL0=cLg080h>3P01X0fm_K0=SHf02^[Zh0
LW9b07moO`27QhL0VIVI0=OGe`3Ph>00gmoO0=cLg03Ph>00g=cL0=_Kf`3Ng]h0eMGE0=KFeP3Cdm<0
eMGE0=;BdP3Cdm<0b<S80<[:bP3@d=00bLW90<_;b`80c<c<00`0dM7A0=;BdP3@d=00d=3@0=CDe03@
d=00dM7A0<_;b`3>c/h0c<c<0=;BdP3Fe]H20=3@d0050=KFeP3EeMD0eMGE0=_Kf`3GemL00P3De=@0
0`3Hf=P0eMGE0=GEe@020=KFeP030=OGe`3De=@0dM7A0080a<C40P39bLT02P3=cLd0bLW90<k>cP3=
cLd0eMGE0=SHf03Fe]H0e=CD0=3@d03AdM430=?Cd`0@0=KFeP3@d=00dM7A0=3@d03=cLd0clo?0=3@
d03?cll0bl_;0<W9b@38b<P0_kno0<30`036a/H0alO70<W9b@80aLG500H0b<S80<_;b`39bLT0_kno
0<;2`P36a/H20<G5a@050<30`02m_Kd0^k^k0:f][@2[Zj/03Oooool0013ooooo00L0O7al0;Ng]`3A
dM40e]KF0=;BdP3Fe]H0eMGE0080emOG00L0f=SH0=CDe03Fe]H0fm_K0=[JfP3Kfm/0g]kN0080g=cL
01@0fm_K0=cLg03Ng]h0gMgM0=SHf037alL0emOG0=cLg03MgMd0g=cL0=kNgP3Ph>00hn?S0=oOg`3P
h>00gmoO0>;RhP3Shn<0gMgM0=kNgP80h>3P0140h^;R0=WIf@3Ph>00gMgM0>?Sh`3Ogml0fMWI0=CD
e03?cll0fm_K0=oOg`3Ph>00gmoO0=gMg@3IfMT0gMgM0>3Ph0020=SHf00C0=_Kf`3Lg=`0hN7Q0=gM
g@3Lg=`0g]kN0=SHf03IfMT0g]kN0=oOg`3De=@0emOG0=WIf@3Ogml0gMgM0=GEe@3@d=00emOG0=GE
e@020=OGe`080=?Cd`3@d=00b/[:0<W9b@3:b/X0dM7A0=KFeP3De=@20>7Qh@030>;RhP3WinL0iNGU
0080h^;R0P3UiND01P3QhN40h>3P0>3Ph03Ogml0g]kN0>?Sh`80h^;R00@0h>3P0>7Qh@3Ti>@0i>CT
0P3Ogml0303Rh^80hN7Q0=oOg`3Ph>00fm_K0=KFeP3De=@0bl_;0<c<c032`/80];Bd0:ZZZP80WinO
00H0[jn_0;jn_P34a<@0aLG50<O7a`39bLT20<?3``070<S8b03;bl/0c<c<0<_;b`3<c<`0eMGE0<o?
c`020=3@d0040=;BdP3AdM40d];B0=CDe080d];B00<0d=3@0=;BdP3=cLd00P3AdM40103Bd]80f=SH
0=SHf03GemL20=[JfP080=GEe@3IfMT0fm_K0=[JfP3GemL0dm?C0<W9b@2o_kl20;Bd]00@0;:b/P2m
_Kd0a/K60<c<c03De=@0eMGE0=KFeP3De=@0f][J0=OGe`3Kfm/0g=cL0=kNgP3QhN40g=cL0=OGe`80
fm_K00L0f][J0=SHf03De=@0dm?C0=CDe03Cdm<0e=CD0080eMGE00`0emOG0=CDe03De=@0e=CD0=GE
e@3MgMd0eMGE0;bl_02][Jd0YZJV0:f][@3De=@20=KFeP080=OGe`3Lg=`0f][J0=SHf03Cdm<0e]KF
0=;BdP3>c/h20=3@d00B0=CDe03AdM40cLg=0<k>cP3Cdm<0e]KF0=[JfP3Fe]H0fm_K0=kNgP3GemL0
dm?C0<_;b`3>c/h0dm?C0=GEe@3Ng]h0fm_K0P3MgMd03`3Lg=`0fMWI0=WIf@3Fe]H0fm_K0=GEe@3H
f=P0eMGE0=KFeP3De=@0fMWI0=GEe@3IfMT0gMgM0=kNgP020=WIf@0@0=GEe@3Jf]X0g=cL0=[JfP3I
fMT0f][J0=SHf03Bd]80d=3@0=;BdP3Hf=P0clo?0=KFeP3EeMD0e]KF0=GEe@@0f=SH01`0eMGE0=?C
d`2b/[80GEeM04a<C01?Cdl0UIFE0=OGe`3IfMT0e]KF0=SHf03EeMD0fMWI0=[JfP3GemL0fMWI0=SH
f03Fe]H0f=SH0=OGe`3Fe]H0dm?C0=kNgP3Jf]X0fMWI0=GEe@3AdM40c/k>0P3De=@0403?cll0cLg=
0<c<c03@d=00e=CD0=KFeP3Kfm/0emOG0=SHf03Kfm/0fMWI0=OGe`3Fe]H0dm?C0=KFeP3Hf=P20=[J
fP0@0=cLg03Hf=P0e=CD0=3@d03De=@0f=SH0=KFeP3?cll0bLW90<S8b03@d=00b<S80<[:bP3=cLd0
b<S80=3@d080e=CD02@0emOG0=oOg`3Lg=`0g=cL0=kNgP3Rh^80gmoO0>3Ph03Rh^80hN7Q0>3Ph03N
g]h0h>3P0>;RhP3Ogml0h>3P0=gMg@3Ng]h0f][J0=gMg@3Ogml0gMgM0=WIf@3De=@0dm?C0=;BdP3E
eMD0fm_K0>7Qh@3Ph>00gmoO0>7Qh@3MgMd0fMWI0=SHf03Jf]X20=;BdP040=CDe03?cll0d=3@0=?C
d`80c<c<00@0b/[:0<S8b032`/80bLW90P3;bl/00`3<c<`0b/[:0<W9b@020<[:bP0>0<g=c@37alL0
`/;20<71`@3<c<`0dM7A0<k>cP3:b/X0dM7A0<g=c@3Hf=P0e]KF0=GEe@3<c<`20=?Cd`80e]KF00H0
e=CD0=3@d03@d=00bLW90<G5a@2m_Kd20<30`080alO700P0_kno0<?3``32`/80bl_;0<o?c`3;bl/0
b/[:0<S8b080b/[:00h0alO70<G5a@38b<P0`l?30;fm_@33`l<0aLG50;Rh^02c/k<0]kNg0;:b/P2^
[Zh0YZJV0:>SX`80W9bL00T0XJ6Q09RHV02FUYH0UiNG09>CT`2FUYH0TI6A08R8R026QXH00P20P800
1P1mOGd0LW9b071`L01YJFT0I6AT05mOG`gooooo000@ooooo`0<0:BTY03Bd]80gMgM0>?Sh`3QhN40
e=CD0=_Kf`3Ng]h0fMWI0=gMg@3Ng]h0h>3P0P3MgMd0303Ng]h0h>3P0=gMg@3MgMd0h>3P0>;RhP3Q
hN40h>3P0=_Kf`3Jf]X0gmoO0>;RhP80gmoO00P0h>3P0=oOg`3QhN40g]kN0=oOg`3QhN40h>3P0>;R
hP80h>3P00D0g]kN0>7Qh@3Ogml0g=cL0=[JfP020=oOg`090=gMg@3Ogml0gMgM0=kNgP3QhN40h>3P
0>7Qh@3Ogml0g]kN0080f][J0`3Kfm/06`3Ng]h0f=SH0=_Kf`3Lg=`0g]kN0=oOg`3GemL0g=cL0=GE
e@3IfMT0clo?0=7Ad@3Cdm<0f][J0=GEe@3Fe]H0clo?0=3@d03>c/h0cLg=0=CDe03@d=00c<c<0<o?
c`3Bd]80e=CD0=WIf@020=_Kf`030>7Qh@3Ti>@0h^;R0080i>CT0P3Shn<00`3Ti>@0iNGU0>CTi002
0>?Sh`80h^;R00@0hn?S0>;RhP3QhN40h>3P0P3Ng]h0503Ph>00h^;R0=cLg03Ph>00gmoO0>3Ph03O
gml0fMWI0=SHf03GemL0d];B0<c<c03:b/X0_kno0;Vi^@2^[Zh0YjNW0;Ng]`35aLD0bLW90P3;bl/0
1034a<@0`l?30<71`@35aLD30<g=c@070=7Ad@3Hf=P0emOG0=GEe@3De=@0eMGE0=KFeP020=SHf004
0=KFeP3EeMD0eMGE0=?Cd`80eMGE0140emOG0=SHf03Kfm/0gMgM0=cLg03Ogml0h>3P0=kNgP3Jf]X0
fm_K0=cLg03MgMd0f=SH0=3@d034a<@0`<300;Rh^0020<S8b0030<G5a@3AdM40eMGE0080f][J00<0
fMWI0=?Cd`3Hf=P00P3Ng]h01P3Lg=`0g]kN0>7Qh@3Lg=`0gMgM0=WIf@80e]KF00@0eMGE0=CDe03A
dM40dM7A0P3Bd]800`3Fe]H0d];B0=?Cd`020=KFeP80f=SH00H0cLg=0:>SX`2;Rh/0Q8B409FEU@3;
bl/20=;BdP030=GEe@3Kfm/0e]KF0080eMGE00/0dm?C0=;BdP3=cLd0dm?C0=[JfP3Hf=P0emOG0=?C
d`3De=@0dm?C0=OGe`020=[JfP80g]kN00D0g=cL0=_Kf`3GemL0eMGE0=OGe`020=_Kf`80g=cL00P0
gMgM0=oOg`3Jf]X0fMWI0=OGe`3Kfm/0f=SH0=OGe`80f=SH00@0fm_K0=gMg@3IfMT0f=SH0P3MgMd0
7@3IfMT0fm_K0=[JfP3Jf]X0f=SH0=[JfP3Kfm/0emOG0=?Cd`3AdM40b/[:0=?Cd`3?cll0d=3@0=CD
e03AdM40e=CD0=GEe@3Jf]X0emOG0=;BdP3AdM40d=3@0<c<c02PX:00J6QX06][J`1HF5P0WYjN00<0
emOG00L0e]KF0=?Cd`3Fe]H0emOG0=WIf@3EeMD0e=CD0080eMGE00X0dM7A0=GEe@3@d=00f][J0=KF
eP3Bd]80clo?0=;BdP3AdM40d];B0`3>c/h01@3<c<`0bl_;0=3@d03@d=00eMGE0080e]KF00@0f=SH
0=WIf@3Hf=P0fMWI0P3Cdm<00`3Kfm/0fMWI0=_Kf`020=_Kf`0H0=[JfP3De=@0e]KF0=SHf03?cll0
c<c<0<_;b`3<c<`0d=3@0<_;b`38b<P0bl_;0<g=c@3;bl/0c<c<0=;BdP3Fe]H0g]kN0=cLg03IfMT0
gMgM0>3Ph03Ng]h0h>3P0P3QhN401@3Ogml0h>3P0=kNgP3Ng]h0gMgM0080gmoO00P0hN7Q0=gMg@3N
g]h0h>3P0=gMg@3IfMT0fm_K0=gMg@80gmoO00X0i>CT0>7Qh@3Ti>@0fMWI0=gMg@3Jf]X0g]kN0=cL
g03Jf]X0clo?0P3>c/h05P3AdM40d];B0<c<c038b<P0b/[:0<K6aP3?cll0b<S80<_;b`3<c<`0cLg=
0<S8b035aLD0`<300<G5a@36a/H0`l?30<;2`P2h^;P0_;bl0<O7a`3?cll20<c<c00<0<g=c@39bLT0
dm?C0<c<c03?cll0a/K60<C4a035aLD0bl_;0<O7a`34a<@0_[jn0P2c/k<0402d];@0[Zj^0:^[Z`2_
[jl0][Jf0:JVYP2MWId0Xj>S09bLW02MWId0VIVI092@T02EUID0T92@08j>SP29RHT207emO@0907Qh
N01cLg<0N7Qh071`L01dM7@0Kfm_06IVIP1NGUh0FUYJ0080EEEE00D0Bd];04i>CP1<C4`0Bd];04U9
B@0204Y:BP0304E5A@12@T80B4Q80080@T9200P0?Shn03dm?@0o?cl0?Cdm0410@00l?3`0@41003lo
?`gooooo000@ooooo`060;:b/P2o_kl0fm_K0=kNgP3QhN40h>3P0P3Lg=`01@3Ph>00g=cL0=oOg`3Q
hN40fm_K0080g]kN00P0gmoO0=kNgP3MgMd0g]kN0>3Ph03Ogml0g]kN0=oOg`80h>3P00L0hn?S0=kN
gP3MgMd0g]kN0>3Ph03Shn<0h>3P0080hn?S0P3QhN404@3Ph>00hN7Q0=oOg`3Shn<0g]kN0=oOg`3L
g=`0h>3P0=cLg03Ogml0hN7Q0>3Ph03Ng]h0gmoO0>3Ph03Ogml0g=cL0080gMgM0140f][J0=OGe`3H
f=P0fm_K0=gMg@3Jf]X0g]kN0=gMg@3Kfm/0f][J0=GEe@3Fe]H0d=3@0=;BdP3Cdm<0e=CD0=OGe`02
0=[JfP090=GEe@39bLT0dm?C0=7Ad@3EeMD0dM7A0<_;b`3GemL0fMWI0080g=cL00L0h>3P0>CTi03T
i>@0i>CT0>GUi@3Ti>@0h^;R0080hN7Q0P3UiND00`3Shn<0i>CT0>7Qh@030>;RhP80i>CT02L0hN7Q
0>;RhP3Shn<0h>3P0=oOg`3Ph>00hn?S0>7Qh@3Lg=`0gMgM0>7Qh@3Kfm/0fMWI0=CDe03Bd]80clo?
0<c<c038b<P0a<C40;jn_P2f][H0_kno0<[:bP3;bl/0c/k>0<o?c`3=cLd0clo?0<_;b`3<c<`0e=CD
0=OGe`3EeMD0clo?0<k>cP3;bl/0dm?C0=gMg@3Hf=P00P3IfMT01P3GemL0e]KF0=_Kf`3Kfm/0eMGE
0=gMg@80f][J00d0fm_K0=gMg@3Ph>00g]kN0=oOg`3QhN40gMgM0=oOg`3MgMd0f][J0=oOg`3Jf]X0
e=CD0080clo?00l0b<S80=3@d03EeMD0clo?0=WIf@3EeMD0emOG0=CDe03EeMD0f=SH0=[JfP3QhN40
h^;R0=_Kf`3Jf]X00P3Ng]h20=[JfP070=CDe03Cdm<0eMGE0=?Cd`3AdM40d=3@0=7Ad@020=CDe080
c<c<00`0e]KF0=[JfP3Fe]H0e]KF0=7Ad@2NWYh0MWIf08F5Q@2MWId0dM7A0=CDe03EeMD20=SHf00O
0=CDe03Jf]X0gMgM0=OGe`3Hf=P0emOG0=SHf03Lg=`0fm_K0=cLg03Jf]X0g=cL0=kNgP3Jf]X0hN7Q
0=OGe`3MgMd0f][J0=cLg03MgMd0g=cL0=KFeP3Kfm/0f][J0=_Kf`3Jf]X0fm_K0=[JfP3GemL0gMgM
0=KFeP020=SHf0040=OGe`3Jf]X0fMWI0=[JfP80g]kN00d0f][J0=cLg03MgMd0f=SH0=OGe`3Hf=P0
gMgM0=kNgP3Jf]X0e=CD0=WIf@3Fe]H0dm?C0080d];B00<0d=3@0=7Ad@3Bd]800P3Bd]802@3GemL0
fm_K0=kNgP3Jf]X0d];B0=3@d03AdM40bl_;09>CT`0207AdM00807=cL`2h^;P0emOG0=KFeP3EeMD0
e=CD0=GEe@3GemL20=SHf00C0=;BdP3Cdm<0dm?C0=CDe03Cdm<0dM7A0<g=c@3De=@0dM7A0<g=c@3>
c/h0clo?0=?Cd`3>c/h0clo?0<[:bP38b<P0a/K60<C4a0020<S8b00@0=;BdP3GemL0emOG0=?Cd`3E
eMD0d];B0=WIf@3GemL0e=CD0=SHf03IfMT0fm_K0=cLg03Fe]H0f=SH0=GEe@80e=CD0280d];B0=CD
e03=cLd0b<S80<W9b@37alL0bLW90<K6aP3>c/h0bl_;0<o?c`3@d=00emOG0=SHf03EeMD0emOG0=[J
fP3IfMT0f][J0=gMg@3Ng]h0gMgM0=[JfP3Kfm/0f=SH0=_Kf`3Lg=`0g]kN0=SHf03Kfm/0f=SH0=KF
eP3Lg=`0f][J0P3IfMT01P3Kfm/0emOG0=kNgP3Ogml0g=cL0=_Kf`80fMWI00X0f][J0=KFeP3Bd]80
dm?C0<c<c03=cLd0bLW90<?3``34a<@0aLG50P33`l<01`2l_;`0`L710;Ng]`2j^[X0`<300;>c/`2_
[jl00P2/[:`0802`/;00/[:b0:j^[P2^[Zh0[:b/0;2`/02a/K40[Zj^0:6QX@2ZZZX0ZJVY0:^[Z`2Z
ZZX0U9BD0:>SX`2ATI40R8R808J6QP24Q8@0PH6107MgM`1dM7@0LW9b06UYJ@1XJ6P0IFEU05iNGP1S
Hf<0GUiN05YJFP1DE5@0C4a<0P1;Bd/01@18B4P0AdM704I6AP17AdL0A4A40080@d=300H0@41003dm
?@0l?3`0@41003lo?`0m?Cd303hn?P0303Xj>P0o?cl0CDe=0080?Cdm00H0>SXj03`l?00j>SX0?3`l
03dm?@0l?3`203hn?P0803lo?`0j>SX0?3`l03Ti>@0k>c/0>SXj03Ti>@0j>SX203/k>`gooooo000@
ooooo`0?0=SHf03De=@0gMgM0=kNgP3Ogml0gMgM0=oOg`3Ng]h0gMgM0=[JfP3Ng]h0h^;R0=oOg`3S
hn<0hN7Q00<0gmoO00<0gMgM0=kNgP3Ogml00P3Ph>00103MgMd0fm_K0>7Qh@3Ogml20=gMg@030=cL
g03Ph>00g]kN00<0g=cL00D0gmoO0=kNgP3Ogml0gmoO0>CTi0020=gMg@030=oOg`3Ph>00gMgM0080
g=cL00T0gmoO0=kNgP3MgMd0hN7Q0=kNgP3Lg=`0g]kN0>3Ph03Ng]h00P3Lg=`00`3Ng]h0f][J0=_K
f`020=cLg080gMgM00@0fMWI0=OGe`3IfMT0emOG0P3IfMT0103Jf]X0f=SH0=gMg@3Hf=P20=OGe`0@
0<g=c@3<c<`0e=CD0=;BdP3Jf]X0gMgM0>7Qh@3Ogml0hn?S0>GUi@3Ti>@0i^KV0>GUi@3Shn<0h^;R
0>?Sh`80h^;R00L0i>CT0>3Ph03Ph>00i>CT0>GUi@3Vi^H0inOW00@0i>CT01D0h>3P0>7Qh@3Rh^80
h^;R0>3Ph03QhN40h>3P0>?Sh`3Rh^80g=cL0=[JfP3Fe]H0emOG0=GEe@3De=@0eMGE0=7Ad@3?cll0
cLg=0=7Ad@3EeMD00P3GemL03`3MgMd0g=cL0=OGe`3GemL0e]KF0=[JfP3Ng]h0f=SH0;2`/02:RXX0
SHf=0<C4a03Ng]h0gMgM0=oOg`020=gMg@050=cLg03Ng]h0gMgM0=[JfP3Lg=`00P3Kfm/30=oOg`0:
0=cLg03Kfm/0gmoO0>3Ph03Ng]h0fm_K0=kNgP3Ph>00gMgM0=SHf080fm_K00/0e=CD0<_;b`3AdM40
f=SH0=_Kf`3MgMd0f][J0=cLg03GemL0f=SH0=WIf@020>7Qh@030=gMg@3Lg=`0g]kN0080f][J01`0
fMWI0=kNgP3Hf=P0dM7A0=;BdP3Fe]H0eMGE0=OGe`3Jf]X0emOG0<o?c`3EeMD0fm_K0=WIf@3Fe]H0
emOG0=3@d02PX:00MGEe08F5Q@2WYjL0emOG0=[JfP3IfMT0g=cL0=WIf@3Jf]X0eMGE0`3Fe]H07P3E
eMD0dm?C0=GEe@3Lg=`0f][J0=cLg03Ng]h0g=cL0=KFeP3Ng]h0fMWI0>3Ph03Kfm/0g=cL0=[JfP3M
gMd0f=SH0=gMg@3IfMT0f][J0=_Kf`3IfMT0eMGE0=OGe`3Kfm/0fMWI0=SHf03GemL0eMGE0=_Kf`80
f=SH00D0eMGE0=7Ad@3GemL0f][J0=KFeP020=OGe`070=KFeP3IfMT0fm_K0=_Kf`3EeMD0emOG0=GE
e@020=CDe0040=3@d03Hf=P0clo?0<[:bP80cLg=00`0eMGE0=WIf@3Lg=`0e]KF0<g=c@3@d=00d];B
0=7Ad@31`L40_[jn0<30`03;bl/20=WIf@0:0=GEe@3Bd]80dm?C0=?Cd`3Bd]80dm?C0=;BdP3>c/h0
d=3@0=CDe080clo?00h0d=3@0<o?c`3<c<`0c<c<0<W9b@37alL0cLg=0<O7a`3?cll0c<c<0<G5a@38
b<P0b/[:0<_;b`80a/K601`0bl_;0=OGe`3Fe]H0e=CD0=7Ad@3Bd]80emOG0=WIf@3Hf=P0e=CD0=KF
eP3Hf=P0g=cL0=?Cd`3Hf=P0e]KF0=CDe03Bd]80dm?C0<o?c`39bLT0b<S80<O7a`36a/H0alO70<;2
`P37alL0b<S80P3=cLd0403EeMD0e]KF0=;BdP3Cdm<0emOG0=GEe@3Kfm/0f][J0=_Kf`3Fe]H0d];B
0=?Cd`3Fe]H0emOG0=SHf03GemL20=;BdP0S0=3@d03>c/h0dM7A0<k>cP3:b/X0`l?30;no_`32`/80
`l?30;Zj^P2e]KD0/[:b0;Bd]02][Jd0^[Zj0;2`/02/[:`0Z:RX09NGU`2KVi/0UYJF08Z:RP29RHT0
QhN707emO@1oOgl0P82007inOP1iNGT0M7Ad07EeM@1VIVH0Hf=S05eMG@1QHF400`1NGUh05P1QHF40
GemO065QH@1PH600Cdm?05MGE`1EEED0F5QH06=SH`1EEED0CDe=05MGE`1EEED0@41004=3@`0o?cl0
@T920451@@10@400?Cdm04=3@`0n?Sh20410@00603lo?`0j>SX0?Shn03lo?`0m?Cd0>CTi0P0l?3`0
9P0n?Sh0?Cdm03lo?`0m?Cd0?3`l03hn?P0l?3`0?Shn03lo?`0k>c/0>SXj03Ph>010@400?Shn03`l
?00o?cl0?3`l03lo?`0j>SX0?Cdm03`l?00o?cl0@d=304A4A011@D40@T9203hn?P1=CDd0@d=303`l
?010@400?Cdm0410@012@T80?Cdm03`l?010@400@D513Oooool0013ooooo00X0gmoO0=_Kf`3Lg=`0
g=cL0>3Ph03Ogml0gMgM0=WIf@3Jf]X0gmoO0P3Shn<01P3QhN40iNGU0>;RhP3QhN40gMgM0=oOg`80
h>3P00@0g]kN0>3Ph03Ogml0gmoO0P3Rh^803P3Ogml0gMgM0=oOg`3MgMd0hn?S0>7Qh@3Ogml0gMgM
0=cLg03Ph>00gmoO0=kNgP3Ogml0h>3P0P3MgMd01P3Lg=`0gmoO0=cLg03Lg=`0fMWI0=gMg@80g]kN
00D0h>3P0>7Qh@3QhN40gmoO0=kNgP020=gMg@060=cLg03MgMd0fm_K0=cLg03Kfm/0gMgM0P3Ng]h0
0`3Lg=`0gMgM0=gMg@030=_Kf`80gMgM00P0g]kN0=cLg03Lg=`0g=cL0=gMg@3Fe]H0gMgM0=cLg080
h>3P00<0gmoO0>3Ph03Shn<00P3Rh^802P3Shn<0i>CT0>;RhP3QhN40i>CT0>GUi@3QhN40iNGU0>;R
hP3QhN420>?Sh`030>GUi@3Vi^H0hN7Q0080hn?S00H0i>CT0>;RhP3Ph>00g]kN0>3Ph03Ogml20>7Q
h@040>;RhP3QhN40f][J0=WIf@80fm_K00/0f=SH0=CDe03EeMD0eMGE0=CDe03Hf=P0f][J0=kNgP3O
gml0g=cL0=kNgP020>3Ph00@0=kNgP3IfMT0g=cL0=_Kf`3Cdm<0Rh^;061PH01bLW80aLG50=oOg`3L
g=`0gmoO0=gMg@3Ng]h0h>3P0=cLg080fm_K00X0gMgM0=_Kf`3Lg=`0hN7Q0>?Sh`3Kfm/0g=cL0=gM
g@3QhN40fm_K0P3Ogml06@3MgMd0gmoO0=WIf@3Jf]X0fm_K0=3@d03>c/h0fMWI0=SHf03Ng]h0fm_K
0=WIf@3EeMD0fMWI0=_Kf`3MgMd0hN7Q0=gMg@3Lg=`0g]kN0=_Kf`3Ogml0f=SH0=kNgP3Lg=`00P3K
fm/0903IfMT0f][J0=SHf03Jf]X0eMGE0=SHf03Rh^80g=cL0=SHf03De=@0emOG0=;BdP3Cdm<0`l?3
09BDU02@T900PH610:VYZ@3Lg=`0gMgM0=SHf03Kfm/0g=cL0=_Kf`3IfMT0e]KF0=CDe03Bd]80fMWI
0=[JfP3Hf=P0emOG0=CDe03Kfm/0h>3P0=cLg0<0f][J00D0gMgM0=_Kf`3MgMd0eMGE0=_Kf`020=OG
e`0@0=GEe@3IfMT0f=SH0=SHf03Kfm/0f][J0=OGe`3Jf]X0e]KF0=WIf@3De=@0emOG0=KFeP3GemL0
d];B0<o?c`80f=SH00D0dm?C0=GEe@3Fe]H0f][J0=;BdP020=KFeP0;0=OGe`3Fe]H0d];B0=?Cd`3B
d]80eMGE0=7Ad@3Bd]80bl_;0<g=c@3>c/h00P3EeMD01`3Hf=P0eMGE0=;BdP3Cdm<0c/k>0<_;b`3@
d=000P3Fe]H20=WIf@0:0=KFeP3Bd]80clo?0<g=c@3<c<`0dM7A0<o?c`3>c/h0c<c<0<g=c@80bl_;
00H0c<c<0<[:bP3>c/h0b/[:0<K6aP33`l<20<C4a00@0<G5a@34a<@0a<C40<71`@32`/80_[jn0<K6
aP34a<@0bLW90<c<c03GemL0e=CD0=KFeP3Bd]80eMGE0=CDe080e]KF00H0e=CD0=7Ad@3Bd]80e]KF
0=CDe03EeMD30<o?c`070=3@d036a/H0^KVi0;6a/@2e]KD0^;Rh0;Vi^@020;Fe]@0<0;Ng]`2c/k<0
];Bd0;Rh^02l_;`0^KVi0;>c/`2a/K40Zj^[0;2`/02][Jd0YZJV0P2SXj<04@2WYjL0Vi^K09RHV02C
Ti<0T92@08Z:RP23Ph<0Ng]k07QhN01fMWH0M7Ad06e]K@1RHV80Hf=S06MWI`1TI6@0GEeM0080EUIF
0140EeMG05ADE01BDU80Cdm?04e=C@1<C4`0@d=304A4A015ADD0?clo0410@00n?Sh0?clo04A4A012
@T80?Cdm0410@00203hn?P0503dm?@10@400@4100451@@10@4000P0o?cl01P0k>c/0?Cdm03Ti>@0j
>SX0?Cdm03hn?P80?clo00<0@41003lo?`0k>c/00P17AdL00`0l?3`0>SXj03`l?00203`l?00303dm
?@0l?3`0?Shn0080?3`l00P0@4100451@@0k>c/0?Cdm03/k>`0l?3`0>SXj03/k>`80?3`l00l0>SXj
03`l?00m?Cd0@D5103lo?`0m?Cd0?3`l0410@013@d<0CDe=04a<C01>CTh0De=C05UIF@1MGEd00`1?
Cdl04`1>CTh0AdM704i>CP1@D500GEeM059BDP1=CDd0D51@05EEE@18B4P0AdM704A4A00n?Sh0@410
04A4A016ATH0@d=304Y:BP1<C4`03Oooool0013ooooo00h0g]kN0=[JfP3Lg=`0gMgM0=cLg03Kfm/0
fMWI0=[JfP3Kfm/0fMWI0>7Qh@3Xj>P0inOW0>3Ph080gmoO00<0g=cL0>?Sh`3Ph>000P3Kfm/01P3M
gMd0g=cL0>3Ph03Ogml0g=cL0=kNgP80gmoO00/0hN7Q0>;RhP3QhN40g]kN0=_Kf`3IfMT0gmoO0>;R
hP3Ogml0h>3P0=oOg`020=gMg@@0g=cL0P3Cdm<0103MgMd0g]kN0=kNgP3Ph>020>7Qh@090=kNgP3P
h>00h>3P0=gMg@3QhN40fMWI0=gMg@3Ogml0hN7Q0080gmoO00<0e]KF0=[JfP3Ogml00P3MgMd01`3N
g]h0gmoO0>3Ph03Ng]h0gMgM0>3Ph03QhN400P3Lg=`02P3@d=00bl_;0=7Ad@3Ogml0hN7Q0>3Ph03Q
hN40h^;R0>CTi03Rh^830>7Qh@80iNGU00X0hn?S0>7Qh@3Ph>00iNGU0>?Sh`3QhN40i>CT0>KViP3R
h^80hn?S0P3Ph>002@3QhN40h>3P0=kNgP3QhN40h^;R0>KViP3QhN40i^KV0>CTi0020=cLg0030=gM
g@3IfMT0f][J0080emOG0P3Jf]X04P3Ogml0fm_K0=gMg@3MgMd0hN7Q0>CTi03Ph>00hn?S0>;RhP3Q
hN40h>3P0=kNgP3@d=00OWin04a<C01^KVh0a/K60=oOg`80h>3P00D0g]kN0=oOg`3Ng]h0hN7Q0=cL
g0020=kNgP80g=cL00H0gmoO0>?Sh`3Jf]X0g=cL0=kNgP3Ph>020=gMg@0J0=kNgP3Lg=`0fm_K0=SH
f03Lg=`0f=SH0=[JfP3IfMT0g=cL0=_Kf`3IfMT0e]KF0=OGe`3Kfm/0fMWI0>3Ph03Lg=`0g]kN0=oO
g`3Kfm/0hN7Q0=WIf@3Lg=`0fm_K0=cLg03IfMT20=SHf0070=OGe`3Fe]H0eMGE0=cLg03EeMD0e=CD
0=KFeP020=WIf@0@0=KFeP3EeMD0d];B0=GEe@36a/H0Xj>S0:JVYP2UYJD0aLG50=OGe`3Bd]80e]KF
0=SHf03GemL0f=SH0=CDe080eMGE00T0f=SH0=GEe@3EeMD0d=3@0=WIf@3Hf=P0fm_K0=kNgP3IfMT0
0P3Fe]H00`3Cdm<0f=SH0=7Ad@030=;BdP0E0=CDe03EeMD0eMGE0=KFeP3GemL0fMWI0=_Kf`3EeMD0
d];B0=KFeP3Cdm<0eMGE0<g=c@3@d=00e=CD0=?Cd`3?cll0dM7A0=GEe@3Hf=P0c<c<0080dm?C00@0
e]KF0=;BdP3Fe]H0f=SH0P3GemL02@3Cdm<0dM7A0<k>cP3AdM40d=3@0=WIf@3GemL0c/k>0=;BdP02
0=KFeP0<0=SHf03EeMD0clo?0=?Cd`3AdM40dm?C0<o?c`3De=@0dm?C0=KFeP3AdM40cLg=0P3AdM40
3`3=cLd0b/[:0<o?c`3>c/h0c<c<0<K6aP35aLD0b<S80<_;b`39bLT0a<C40<71`@32`/80^k^k0;Rh
^0020;Jf]P050;Bd]02h^;P0^;Rh0;Fe]@2b/[800P2a/K401@2][Jd0[jn_0;Vi^@33`l<0^k^k0080
^;Rh00<0];Bd0;Fe]@2d];@00P2^[Zh01P2YZJT0Z:RX0:FUY@2UYJD0XZ:R09fMW@<0UYJF00X0PH61
079bLP1aLG40L71`06i^KP1]KFd0J6QX06=SH`1TI6@0H61P0P1MGEd03@1JFUX0EEEE05EEE@1CDe<0
CTi>05MGE`1BDU80D51@055AD@1:BTX0C4a<04I6AP17AdL00P13@d<01@14A4@0@D510410@00o?cl0
@4100080@D5100P0@4100451@@0o?cl0@D5103dm?@11@D40?Cdm04=3@`80?Cdm00<0?Shn03dm?@0n
?Sh00P0m?Cd0200n?Sh0?3`l03/k>`0l?3`0>SXj03/k>`0m?Cd0>CTi0P0n?Sh01@0l?3`0?Shn0492
@P12@T80@D510080?Shn01X0?clo03`l?00j>SX0>SXj03lo?`12@T80?Shn04E5A@12@T80ATI604E5
A@13@d<0A4A403lo?`15ADD0@d=304a<C016ATH0@41004I6AP1ADE40D51@04U9B@15ADD0@4100451
@@80@d=302<0?clo0492@P0o?cl0?clo04M7A`10@400AdM704E5A@16ATH0@d=304E5A@11@D40@d=3
04Y:BP1<C4`0Bd];04Y:BP1;Bd/0AdM704Q8B01>CTh0D51@05EEE@1>CTh0BDU904Y:BP1DE5@0Cdm?
05QHF01JFUX0GEeM05]KF`1QHF40GemO06UYJ@0206MWI`0606a/K01_Kfl0MGEe08>3P`2?Shl0UiNG
3Oooool0013ooooo00d0f][J0=WIf@3Lg=`0gMgM0=SHf03Jf]X0fm_K0=gMg@3Jf]X0g=cL0>3Ph03O
gml0iNGU0080hN7Q00<0hn?S0>OWi`3Ph>000P3MgMd02P3Ng]h0gmoO0=_Kf`3Ogml0h^;R0>3Ph03M
gMd0gmoO0=gMg@3UiND20=oOg`080=kNgP3Ogml0fm_K0=kNgP3Ogml0g]kN0>7Qh@3Shn<20>7Qh@07
0=oOg`3Ng]h0gmoO0>7Qh@3Ph>00g]kN0>7Qh@020=kNgP0:0=oOg`3QhN40h^;R0>7Qh@3Ng]h0h>3P
0>CTi03Ng]h0g=cL0>3Ph080i>CT00<0gmoO0=kNgP3Kfm/00P3Ph>001`3Shn<0g]kN0=gMg@3Jf]X0
gMgM0>3Ph03Ng]h00P3Ogml07@3Lg=`0e=CD0:NWY`27QhL0[Jf]0=SHf03QhN40h>3P0>7Qh@3Ogml0
h^;R0>7Qh@3Ng]h0gMgM0=oOg`3Rh^80i>CT0>3Ph03Vi^H0iNGU0>CTi03Rh^80h>3P0>;RhP3Ti>@0
hn?S0>7Qh@3Shn<0hN7Q0080h^;R0140gmoO0>3Ph03QhN40i^KV0>CTi03QhN40hn?S0=oOg`3Kfm/0
f=SH0=[JfP3Kfm/0e]KF0=SHf03Ng]h0h>3P0>?Sh`030=kNgP0?0=[JfP3Ph>00gmoO0=gMg@3Ng]h0
g=cL0=gMg@3Jf]X0a<C4071`L01<C4`0N7Qh0<g=c@3Lg=`0f=SH0080g=cL00H0h>3P0=_Kf`3Kfm/0
gMgM0=cLg03GemL20=_Kf`070=cLg03Ng]h0g=cL0=cLg03MgMd0gmoO0>7Qh@020=gMg@080=cLg03K
fm/0emOG0=[JfP3EeMD0dm?C0=OGe`3Lg=`30=KFeP060=GEe@3Hf=P0f=SH0=WIf@3De=@0f=SH0P3K
fm/0503Ng]h0fm_K0=_Kf`3Hf=P0eMGE0=?Cd`3Hf=P0emOG0=?Cd`3Fe]H0d];B0=GEe@3Bd]80f=SH
0=WIf@3Jf]X0e]KF0=?Cd`3AdM40eMGE0P3Bd]80103Cdm<0eMGE0=GEe@3Kfm/20=[JfP0C0=_Kf`3E
eMD0dm?C0=;BdP3@d=00dm?C0<k>cP3AdM40d];B0<o?c`3@d=00d];B0=?Cd`3AdM40d];B0=CDe03A
dM40c<c<0=;BdP020=3@d0030<k>cP3De=@0eMGE0080e=CD00D0d];B0=GEe@3Fe]H0f=SH0=OGe`02
0=;BdP0:0=GEe@3>c/h0c/k>0<[:bP3<c<`0d];B0<k>cP37alL0clo?0=KFeP80cLg=0140dm?C0<o?
c`3EeMD0dm?C0=CDe03Cdm<0d];B0=?Cd`3;bl/0b/[:0<o?c`3AdM40d];B0=GEe@3Cdm<0cLg=0<k>
cP020<[:bP0F0=;BdP3AdM40bLW90<S8b036a/H0a<C40;fm_@35aLD0_;bl0;jn_P30`<00]kNg0;Zj
^P2e]KD0/[:b0;2`/02^[Zh0ZZZZ0:BTY02MWId0W9bL0:6QX@80VYZJ00l0TI6A08R8R027QhL0Ph>3
07inOP1eMGD0Kfm_07MgM`1]KFd0LG5a06e]K@1XJ6P0IVIV05mOG`1UIFD00P1QHF401@1TI6@0GEeM
05UIF@1KFe/0F5QH0080EeMG00P0DE5A05QHF01@D500D51@04m?C`1<C4`0B4Q804a<C080AdM70180
A4A403lo?`12@T80@d=303lo?`11@D40@4100451@@0m?Cd0?clo04=3@`0n?Sh0@D510410@00o?cl0
@D5104=3@`0n?Sh203lo?`0503dm?@15ADD0?Shn03dm?@0o?cl00P0m?Cd203hn?P0403dm?@0n?Sh0
?Shn03Xj>P80>c/k00@0@41004=3@`0o?cl0?Shn0`0m?Cd01@0o?cl0ATI603`l?00l?3`0?Shn0080
@D5102H0?Shn03lo?`13@d<0@d=304A4A00o?cl0?Cdm04E5A@12@T80@D5104=3@`15ADD0B4Q804E5
A@0o?cl0?Shn03dm?@0o?cl0@T9204A4A012@T80@4100492@P13@d<0B4Q805MGE`1?Cdl0A4A404];
B`14A4@0AdM70492@P18B4P0BDU904i>CP17AdL0CDe=04Y:BP80E5AD00X0CDe=04M7A`1<C4`0CDe=
05ADE01EEED0EUIF05=CD`1QHF40Hf=S0P1VIVH01`1ZJVX0Kfm_06i^KP1aLG40MgMg07QhN020P800
0P27QhL03`2:RXX0V9RH09nOW`2LW9`0WIfM0:>SX`2][Jd0]KFe0;>c/`2b/[80^[Zj0;no_`33`l<0
a/K60<_;b`020<k>cP040=?Cd`3AdM40d];B0=GEe@80d=3@00D0e=CD0=?Cd`3Kfm/0h>3P0=oOg`0=
ooooo`004?ooool02@3Lg=`0gMgM0=oOg`3MgMd0g=cL0=kNgP3Ogml0g]kN0=oOg`020=kNgP80f][J
00D0h^;R0=kNgP3Rh^80kNg]0>OWi`020>;RhP070=kNgP3Ph>00g=cL0=kNgP3Ogml0hN7Q0=gMg@02
0>3Ph0050>;RhP3QhN40h^;R0=oOg`3QhN400P3Ph>000`3QhN40h^;R0>7Qh@020>3Ph0050>7Qh@3R
h^80h^;R0>7Qh@3Rh^800P3QhN402@3Rh^80h>3P0>3Ph03Ph>00hN7Q0>;RhP3Ph>00fMWI0=oOg`02
0>GUi@090>3Ph03QhN40i>CT0>?Sh`3Ogml0h>3P0>CTi03Shn<0hN7Q0080gmoO0`3Ph>020=oOg`80
gMgM00X0g=cL0<k>cP20P800JVYZ0:FUY@3Lg=`0gmoO0=gMg@3Ogml0gMgM0P3QhN401@3Ph>00g=cL
0=oOg`3Ph>00h^;R0080hn?S01`0h^;R0>GUi@3Ph>00gmoO0>;RhP3QhN40hn?S0>;RhP3Ti>@0hn?S
0>;RhP3Ti>@0hN7Q0=kNgP3QhN40hn?S0>KViP3Ph>00hN7Q0>3Ph03MgMd0f][J0=WIf@3Kfm/0g=cL
0=WIf@3Fe]H0f][J0P3Kfm/0103Lg=`0g]kN0=cLg03Lg=`20=_Kf`0>0=gMg@3GemL0fMWI0=;BdP2a
/K40I6AT05UIF@2BTY80eMGE0=[JfP3GemL0f][J0=_Kf`3MgMd30=[JfP070=SHf03MgMd0f=SH0=SH
f03IfMT0g=cL0=gMg@040=cLg00>0=[JfP3Kfm/0fm_K0=cLg03GemL0e]KF0=OGe`3Hf=P0fMWI0=SH
f03Fe]H0emOG0=cLg03Jf]X20=SHf00>0=[JfP3EeMD0eMGE0=WIf@3GemL0e=CD0=?Cd`3EeMD0d];B
0=3@d03AdM40dm?C0=3@d039bLT20<k>cP070=3@d03Cdm<0clo?0=7Ad@3@d=00dM7A0=3@d0020<_;
b`090<c<c03@d=00e=CD0<k>cP3Cdm<0e=CD0=GEe@3GemL0eMGE0080e=CD01P0e]KF0=CDe03?cll0
clo?0<[:bP3<c<`0cLg=0=;BdP3Cdm<0e=CD0=3@d03Bd]80d=3@0<k>cP3?cll0c<c<0<W9b@3@d=00
dM7A0=?Cd`3Fe]H0d=3@0=7Ad@3<c<`30=3@d00<0<c<c031`L40`/;20<o?c`38b<P0a/K60<G5a@31
`L40`l?30<30`02g]kL0aLG50P2l_;`0302j^[X0_;bl0;Rh^02i^KT0^k^k0;Rh^02g]kL0/[:b0:ZZ
ZP2TY:@0WinO0:>SX`80YjNW00`0Y:BT09^KV`2FUYH0Ti>C09BDU02ATI40S8b<08N7Q`21PH40Ph>3
07alO01fMWH2075aL@0=06][J`1WIfL0HF5Q05YJFP1MGEd0GemO05]KF`1HF5P0DU9B04e=C@1>CTh0
DE5A04Y:BP0204U9B@0=04I6AP15ADD0A4A403hn?P0o?cl0?Cdm0410@00n?Sh0?clo0492@P11@D40
@4100451@@020492@P0304=3@`10@400@4100080@41000D0?Shn0410@011@D40?Shn03lo?`020410
@0070492@P10@400?clo0451@@13@d<0ADE50451@@030492@P80@D5101L0ADE504A4A018B4P0ADE5
04=3@`16ATH0@D5103lo?`15ADD0BTY:04=3@`14A4@0BTY:04A4A011@D40A4A404E5A@18B4P0BTY:
04E5A@1<C4`0@d=30492@P0204E5A@0B04I6AP13@d<0ATI60410@015ADD0BTY:04e=C@1<C4`0@D51
04E5A@1:BTX0Bd];04U9B@15ADD0BTY:04I6AP18B4P0ATI60P17AdL02@1@D500AdM704E5A@15ADD0
BTY:04I6AP15ADD0BDU904Q8B00204Y:BP0U04I6AP1ADE40D51@04a<C01BDU80E5AD05EEE@1KFe/0
HV9R06MWI`1XJ6P0JFUY06a/K01hN7P0OGem07alO01jNWX0Ph>30820P029RHT0S8b<08^;R`2ATI40
VYZJ0:6QX@2OWil0YjNW0:^[Z`2/[:`0[jn_0;Vi^@2g]kL0`l?30<K6aP37alL0aLG50<30`0020<o?
c`0U0<c<c03?cll0dM7A0=GEe@3Bd]80e]KF0=OGe`3Jf]X0g=cL0=_Kf`3Lg=`0fm_K0=cLg03MgMd0
g]kN0=cLg03MgMd0h>3P0=cLg03Kfm/0g=cL0>CTi03Shn<0hN7Q0=kNgP3QhN40h^;R0=oOg`3Ph>00
g]kN0>GUi@3Ogml0h^;R0>3Ph03Ng]h0d];B0=gMg@020>;RhPgooooo000@ooooo`050=kNgP3Ph>00
h^;R0=gMg@3Ng]h00P3Ph>00403MgMd0g]kN0>3Ph03QhN40gMgM0=oOg`3UiND0h>3P0>;RhP3QhN40
h^;R0>3Ph03QhN40gMgM0=oOg`3Ng]h20=cLg0060>3Ph03MgMd0fm_K0<71`@2d];@0clo?0P3MgMd0
203QhN40h^;R0>?Sh`3QhN40h^;R0>7Qh@3Ng]h0hN7Q0P3Ng]h00`3Ph>00hn?S0>;RhP020>7Qh@0?
0=oOg`3QhN40h^;R0=oOg`3Shn<0h>3P0=oOg`3Jf]X0h>3P0>KViP3QhN40hn?S0>GUi@3Shn<0i>CT
0080hn?S00P0g]kN0=oOg`3Ng]h0g=cL0>3Ph03Ogml0g=cL0=gMg@80g=cL0P3MgMd02`3Ng]h0`L71
07=cL`1XJ6P0^;Rh0>;RhP3Shn<0g]kN0=oOg`3Ng]h0hn?S0080h^;R00<0g]kN0>;RhP3QhN400P3R
h^80103Ph>00gmoO0>;RhP3Ogml20>7Qh@0:0=oOg`3Shn<0i>CT0>;RhP3QhN40gmoO0>7Qh@3Ogml0
g]kN0=cLg080g]kN00L0h>3P0=KFeP3IfMT0g=cL0=_Kf`3IfMT0f=SH0080g=cL00<0f=SH0=_Kf`3M
gMd00P3Lg=`01P3Jf]X0g]kN0=cLg03Kfm/0f=SH0=OGe`80eMGE00P0dm?C0<K6aP2][Jd0/[:b0<[:
bP3Jf]X0g=cL0=[JfP80fm_K00X0f=SH0=WIf@3Fe]H0fMWI0=OGe`3Hf=P0emOG0=_Kf`3Fe]H0fMWI
0P3Kfm/20=[JfP0K0=KFeP3GemL0fMWI0=SHf03Fe]H0emOG0=;BdP3Fe]H0f=SH0=7Ad@3=cLd0c/k>
0<o?c`3Cdm<0g=cL0=OGe`3Cdm<0c/k>0<o?c`3Fe]H0emOG0=[JfP3EeMD0dm?C0=3@d03=cLd0d=3@
0080dM7A00/0c/k>0<[:bP3:b/X0c/k>0<c<c03=cLd0a/K60=CDe03@d=00b<S80<O7a`020<W9b@0E
0<S8b03<c<`0dM7A0;^k^`36a/H0b/[:0<_;b`34a<@0alO70<G5a@33`l<0`<300;^k^`2l_;`0`l?3
0;fm_@2k^k/0_;bl0;jn_P2k^k/0_;bl0080^[Zj02@0]kNg0;>c/`2b/[80[Jf]0:n_[`2WYjL0Z:RX
0:JVYP2WYjL0XZ:R0:NWY`2MWId0Vi^K09BDU02BTY80SXj>08N7Q`23Ph<0QHF50861P@20P800Ng]k
07=cL`1^KVh0Lg=c06YZJP1]KFd0HV9R06QXJ01QHF40GEeM05YJFP1QHF40GEeM05EEE@1JFUX2059B
DP0G04m?C`1>CTh0D51@04i>CP1BDU80E5AD04];B`1>CTh0ATI604M7A`16ATH0BTY:04=3@`10@400
@T920451@@13@d<0?clo03dm?@11@D40@T9204=3@`11@D400P10@4003P13@d<0A4A404=3@`12@T80
@D5104=3@`0o?cl0?Shn0410@00o?cl0@T9204=3@`0j>SX0?Shn0P0l?3`01`0o?cl0@4100492@P18
B4P0A4A404=3@`19BDT00P11@D401`16ATH0@d=303hn?P13@d<0@T9204Q8B015ADD00P14A4@07`17
AdL0ATI604m?C`19BDT0@d=304I6AP19BDT0Cdm?04e=C@1?Cdl0EeMG04i>CP1@D500EEEE05aLG01M
GEd0IFEU06ATI01RHV80HF5Q05ADE01EEED0EeMG05YJFP1EEED0C4a<05YJFP1GEeL0Cdm?051@D01E
EED00P1KFe/0201ADE40EEEE04i>CP1@D500De=C05eMG@1PH600G5aL0P1GEeL00`1KFe/0JFUY06QX
J00206=SH`0506][J`1cLg<0L71`07EeM@1iNGT00P1jNWX208:2PP0608N7Q`2;Rh/0SHf=08n?S`2:
RXX0UIFE0P2GUiL01P2MWId0Y:BT0:BTY02][Jd0[Zj^0:JVYP80/;2`00L0^[Zj0;Rh^02k^k/0_;bl
0<?3``39bLT0b/[:0080cLg=00d0c/k>0<_;b`3AdM40dm?C0=;BdP3De=@0eMGE0=CDe03EeMD0dM7A
0=3@d03Cdm<0e]KF0080emOG00/0f=SH0=OGe`3EeMD0f=SH0=cLg03MgMd0g=cL0=_Kf`3Cdm<0d=3@
0=gMg@020=kNgP0C0=[JfP3Lg=`0g]kN0=gMg@3Ng]h0gmoO0=SHf03Lg=`0gMgM0=cLg03Hf=P0g=cL
0>3Ph03Lg=`0fm_K0=oOg`3Ng]h0fm_K0=cLg0020=gMg@070=cLg03Ph>00h^;R0>;RhP3Ng]h0gMgM
0>;RhP030=kNgP050=gMg@3IfMT0f][J0<k>cP3Ng]h00P3Ph>0=ooooo`004?ooool0603Rh^80i>CT
0>GUi@3QhN40g]kN0=oOg`3Ph>00hN7Q0>;RhP3Jf]X0gmoO0=cLg03Ph>00hn?S0>7Qh@3Rh^80hn?S
0>;RhP3Ph>00hn?S0=kNgP3Ph>00gMgM0=oOg`80g]kN00X0gmoO0=CDe02BTY80QHF50<W9b@3Rh^80
g]kN0=gMg@3Ph>00h^;R0P3Ogml0103Ph>00g=cL0=kNgP3Ogml20=kNgP050>3Ph03QhN40hN7Q0>3P
h03Ng]h00P3Rh^802P3Ogml0gMgM0=cLg03QhN40gmoO0>3Ph03Ng]h0gmoO0>;RhP3Ti>@20>;RhP05
0>3Ph03Ng]h0g=cL0=oOg`3MgMd00`3Ph>00103QhN40h>3P0=gMg@3MgMd20=kNgP080=oOg`2h^;P0
L71`07alO03<c<`0h>3P0=cLg03Ng]h20=oOg`050>3Ph03QhN40h>3P0=oOg`3Ng]h00P3QhN403@3R
h^80gmoO0=cLg03Ph>00g=cL0=gMg@3Ogml0h>3P0=oOg`3Ng]h0g=cL0=gMg@3Ph>000P3MgMd0503P
h>00g=cL0=kNgP3Ph>00g]kN0=WIf@3Ng]h0gMgM0=[JfP3Kfm/0fMWI0=SHf03GemL0f=SH0=[JfP3K
fm/0emOG0=KFeP3Jf]X0g=cL0P3IfMT04@3Fe]H0e=CD0=?Cd`3AdM40e]KF0=WIf@3GemL0fMWI0=kN
gP3Kfm/0e]KF0=SHf03De=@0dm?C0=KFeP3EeMD0dM7A0080e=CD00T0d=3@0=CDe03Fe]H0emOG0=WI
f@3GemL0e]KF0=;BdP3>c/h00P3IfMT03`3EeMD0e]KF0=CDe03EeMD0c/k>0=;BdP3AdM40c<c<0<k>
cP3AdM40d=3@0=_Kf`3Rh^80c/k>0<[:bP020<W9b@0G0=7Ad@3=cLd0cLg=0<_;b`37alL0`l?30<C4
a035aLD0a/K60<G5a@2m_Kd0^KVi0;Ng]`2k^k/0]KFe0;fm_@2f][H0^[Zj0:n_[`2XZ:P0Xj>S09nO
W`2JVYX00P2OWil02@2KVi/0Ti>C09BDU02ATI40S8b<08V9R@1oOgl0MgMg08B4Q00207IfMP0307Qh
N01]KFd0Kfm_0080JFUY00X0IFEU06IVIP1PH600H61P05]KF`1EEED0De=C05MGE`1DE5@0Cdm?0P1C
De<01P1ADE40CTi>04];B`1ADE40CDe=04U9B@80BTY:00h0@T9204I6AP16ATH0AdM704=3@`14A4@0
@d=304A4A00n?Sh0@T920410@017AdL0A4A404=3@`<0@D5100d0?Shn0410@012@T80?clo0410@013
@d<0?clo0492@P11@D40?clo04M7A`15ADD0@D510080@41000<0?Shn0451@@0n?Sh00P0o?cl203hn
?P0;0492@P0o?cl0?Shn04=3@`16ATH0@T9203lo?`0n?Sh0@T9204I6AP14A4@00`12@T801011@D40
@41003lo?`12@T8204I6AP0<04Y:BP15ADD0ATI604m?C`1:BTX0AdM704=3@`18B4P0C4a<04Y:BP15
ADD0AdM70P19BDT03@1>CTh0D51@04m?C`19BDT0Cdm?05EEE@1ADE40DU9B051@D01HF5P0EUIF055A
D@1@D5000P1IFET02P1FEUH0Fe]K05EEE@1SHf<0IfMW06EUI@1`L700JFUY06a/K01`L70307QhN00:
07AdM01gMgL0O7al07inOP22PX80RHV908j>SP2EUID0TY:B09JFUP80VIVI01/0WIfM0:6QX@2RXZ80
[Jf]0:NWY`2VYZH0[Jf]0;Jf]P2l_;`0_Kfm0;Zj^P2f][H0_kno0<71`@32`/80_kno0<O7a`36a/H0
b<S80<W9b@3?cll0dm?C0=;BdP3De=@0d];B0<g=c@3Cdm<00P3?cll04@3Bd]80dM7A0=;BdP3IfMT0
e=CD0=KFeP3IfMT0eMGE0=[JfP3Fe]H0b/[:0=WIf@3Cdm<0emOG0=WIf@3GemL0e]KF0080fm_K00d0
emOG0=SHf03Jf]X0f=SH0=WIf@3Kfm/0emOG0=WIf@3Fe]H0fMWI0=GEe@3De=@0eMGE0080e=CD00T0
eMGE0=SHf03GemL0f][J0=SHf03Cdm<0f=SH0=WIf@3Lg=`00P3De=@03`3Fe]H0e=CD0=cLg03Lg=`0
fMWI0=_Kf`3MgMd0hN7Q0=[JfP3MgMd0fm_K0=SHf03Ph>00g=cL0=[JfP020=cLg0060=kNgP3MgMd0
hN7Q0>3Ph03Rh^80fMWI0P3MgMd01@3Hf=P0g]kN0=kNgP3Ph>00h^;R0080gmoO00D0h>3P0=cLg03N
g]h0g]kN0>3Ph0020=oOg`040=7Ad@3MgMd0gmoO0=oOg`gooooo000@ooooo`030>CTi03Shn<0h^;R
0080hN7Q00D0hn?S0>7Qh@3Ph>00g]kN0=_Kf`020=gMg@040=oOg`3Ph>00gmoO0=oOg`@0h>3P01X0
gmoO0=cLg03Lg=`0gMgM0=SHf03Jf]X0e=CD0<c<c027QhL0QHF50=CDe03QhN40h>3P0>?Sh`3Rh^80
hN7Q0=kNgP3Ogml0h>3P0=cLg03MgMd0g=cL0=kNgP3Ph>00gmoO0=kNgP80fm_K00D0fMWI0=kNgP3O
gml0g=cL0>3Ph0020>7Qh@040=oOg`3QhN40hN7Q0=cLg080h>3P00/0gmoO0>?Sh`3Ph>00g]kN0=oO
g`3Ph>00gmoO0>7Qh@3Ogml0hN7Q0>3Ph0020=oOg`0J0>7Qh@3Ogml0g]kN0=gMg@39bLT0];Bd0;fm
_@3GemL0gmoO0>3Ph03Ogml0f=SH0=cLg03QhN40h>3P0>7Qh@3Rh^80fm_K0=oOg`3QhN40h>3P0=oO
g`3Kfm/0g]kN0>;RhP3MgMd20=kNgP040=oOg`3Ng]h0gMgM0=cLg0<0fm_K00l0f][J0>3Ph03MgMd0
h>3P0=cLg03EeMD0fm_K0=[JfP3IfMT0f][J0=KFeP3IfMT0f=SH0=?Cd`3GemL00`3EeMD06P3IfMT0
emOG0=OGe`3EeMD0dm?C0=;BdP3@d=00cLg=0<o?c`38b<P0d=3@0<o?c`3Bd]80dM7A0<_;b`3De=@0
e]KF0=GEe@3?cll0cLg=0=7Ad@3Bd]80cLg=0<71`@35aLD0bLW90`36a/H08@32`/80^[Zj0<;2`P2n
_[h0[jn_0;6a/@2c/k<0^;Rh0;>c/`2/[:`0Zj^[0:RXZ02TY:@0Z:RX0:BTY02SXj<0WYjN0:2PX02J
VYX0Vi^K09:BTP2=SHd0SXj>08R8R02:RXX0Rh^;07moO`21PH40P82007QhN01aLG40L71`06YZJP02
06MWI`06061PH01IFET0H61P061PH01OGel0F5QH0P1DE5@01`1=CDd0DU9B04e=C@19BDT0BTY:04Q8
B015ADD00P17AdL204E5A@0404I6AP15ADD0A4A40492@P80A4A400D0@D5103hn?P12@T80@41004E5
A@0304=3@`0A04A4A011@D40A4A404=3@`10@400@d=303hn?P13@d<0A4A404=3@`12@T80A4A404=3
@`16ATH0AdM70451@@13@d<00P16ATH01@15ADD0CDe=04E5A@13@d<0@4100080?clo00X0@T9204Y:
BP1<C4`0B4Q804A4A012@T80AdM704Q8B015ADD0@d=30P15ADD05P12@T80BDU904Y:BP1?Cdl0CTi>
04M7A`11@D40ADE504Q8B014A4@0ADE504M7A`1:BTX0@T9204A4A015ADD0B4Q804A4A015ADD0CTi>
05=CD`1ADE4204a<C00=059BDP1FEUH0E5AD04m?C`1CDe<0F5QH05MGE`1MGEd0H61P05aLG01NGUh0
IVIV075aL@0206][J`0A06i^KP1fMWH0KVi^06UYJ@1^KVh0Lg=c07QhN01iNGT0NWYj08>3P`20P800
Ogmo08F5Q@2:RXX0Shn?09JFUP2CTi<00P2GUiL02@2JVYX0WYjN0:BTY02IVIT0Vi^K0:^[Z`2_[jl0
[Jf]0;Bd]0020;Ng]`0=0;^k^`2m_Kd0_;bl0;Vi^@30`<00`l?30<K6aP32`/80alO70<;2`P38b<P0
b/[:0<O7a`020=?Cd`040=GEe@3De=@0f=SH0=WIf@80e=CD01d0f=SH0=KFeP3De=@0g=cL0<k>cP3E
eMD0f=SH0=[JfP3Kfm/0g=cL0=SHf03Jf]X0emOG0=cLg03Hf=P0eMGE0=_Kf`3GemL0eMGE0=CDe03I
fMT0emOG0=GEe@3Kfm/0fMWI0=?Cd`3EeMD0e=CD0=3@d0020=?Cd`090=GEe@3Jf]X0emOG0=?Cd`3H
f=P0e]KF0=SHf03@d=00aLG50080eMGE00X0e]KF0=WIf@3Jf]X0eMGE0=WIf@3Lg=`0f][J0=_Kf`3I
fMT0e]KF0P3Hf=P01@3Bd]80e]KF0=CDe03Hf=P0dm?C0080e=CD00<0d=3@0=KFeP3Fe]H00P3Fe]H0
1`3GemL0fMWI0=CDe03IfMT0e]KF0=SHf03IfMT00P3Hf=P01@3Cdm<0f=SH0=WIf@3GemL0fm_K0080
gMgM00@0fm_K0=gMg@3Hf=P0e]KF0P3Lg=`01@3Jf]X0fMWI0=OGe`3Kfm/0f][J0080fm_K01H0gMgM
0=cLg03Jf]X0g=cL0=[JfP3MgMd0g=cL0=[JfP3Ph>00g]kN0=oOg`3MgMd0fMWI0=_Kf`3Ng]h0h>3P
0=cLg03Jf]X0dm?C0=_Kf`3MgMd0gmoO3Oooool0013ooooo0P3UiND20>;RhP0;0=kNgP3Lg=`0h>3P
0=kNgP3Ph>00hN7Q0=_Kf`3Hf=P0g=cL0>?Sh`3QhN400P3MgMd0103Ng]h0gmoO0=gMg@3Ph>020=cL
g00:0=KFeP38b<P0f=SH0=OGe`2k^k/0QHF509FEU@3De=@0fm_K0=cLg080g]kN00@0hN7Q0=oOg`3N
g]h0g]kN0P3Jf]X0203MgMd0g]kN0=kNgP3Ng]h0h>3P0=gMg@3Kfm/0gMgM0P3Ogml00`3GemL0gMgM
0>7Qh@020=kNgP0:0>7Qh@3MgMd0fm_K0>7Qh@3Rh^80gmoO0>;RhP3Ogml0h>3P0=_Kf`80gmoO00<0
h>3P0=kNgP3Ogml00P3MgMd02P3Ogml0g]kN0=cLg03Lg=`0fm_K0=SHf03Ogml0h>3P0=[JfP3IfMT2
0=kNgP080=_Kf`3Jf]X0h>3P0>3Ph03Ogml0h>3P0=_Kf`3Hf=P20=_Kf`050=WIf@3Kfm/0fm_K0=gM
g@3IfMT00`3Lg=`04@3Kfm/0g=cL0=WIf@3EeMD0fMWI0=GEe@3De=@0fMWI0=GEe@3De=@0dM7A0=CD
e03Fe]H0emOG0=KFeP3;bl/0b<S80080c<c<01h0bLW90<K6aP36a/H0c<c<0<[:bP38b<P0aLG50<C4
a035aLD0`l?30;Vi^@2_[jl0[Jf]0:j^[P2QXJ40YJFU0::RXP2PX:00WinO0:>SX`2VYZH0YjNW0:FU
Y@2FUYH0TY:B08^;R`2BTY80Rh^;08J6QP1oOgl207alO00807EeM@1hN7P0L71`07EeM@1cLg<0Kfm_
05iNGP1QHF4205eMG@0C05YJFP1GEeL0EEEE04i>CP1@D500DU9B051@D01CDe<0Bd];04U9B@1>CTh0
DU9B04Y:BP19BDT0BTY:04Q8B017AdL0Bd];04M7A`0304I6AP0304M7A`19BDT0BDU90080AdM700<0
@d=304A4A014A4@00P17AdL00`13@d<0A4A404M7A`0204=3@`0504M7A`18B4P0A4A404A4A015ADD0
0P16ATH01011@D40ADE504Q8B015ADD204=3@`0U0492@P15ADD0ADE504U9B@17AdL0A4A404M7A`14
A4@0@D5104E5A@19BDT0B4Q8051@D01<C4`0F5QH05eMG@1FEUH0EeMG05]KF`1=CDd0BDU904i>CP1G
EeL0E5AD05mOG`1LG5`0De=C05]KF`1ADE40AdM705=CD`1?Cdl0CTi>04];B`1CDe<0CDe=05UIF@02
065QH@80GemO00H0G5aL05YJFP1OGel0HF5Q06=SH`1MGEd2061PH00>069RHP1VIVH0KVi^06i^KP1W
IfL0Lg=c06a/K01fMWH0OWin08J6QP25QHD0QXJ608Z:RP2;Rh/208j>SP09092@T02GUiL0TY:B09FE
U@2NWYh0YZJV0:^[Z`2TY:@0YjNW0080[jn_0180Zj^[0;Bd]02c/k<0YZJV0;6a/@2][Jd0/[:b0;Jf
]P2g]kL0_[jn0;Vi^@2d];@0^;Rh0;bl_02j^[X0_Kfm0;jn_P36a/H20<S8b00;0<?3``30`<00b<S8
0<S8b036a/H0bLW90<[:bP3?cll0c<c<0<[:bP3@d=000P3?cll03`2o_kl0`<300<o?c`3@d=00dM7A
0=?Cd`3AdM40e=CD0=WIf@3GemL0eMGE0=?Cd`3Fe]H0emOG0=cLg0020=SHf0<0f][J00d0fMWI0=SH
f03Jf]X0gmoO0=cLg03Fe]H0g=cL0=[JfP3Kfm/0e]KF0=;BdP3EeMD0fMWI0080d=3@00H0g=cL0=_K
f`3Jf]X0f=SH0=KFeP3IfMT20=OGe`080=_Kf`3EeMD0f=SH0=KFeP3Jf]X0f=SH0=_Kf`3GemL20=SH
f0070=[JfP3Cdm<0dM7A0=7Ad@3>c/h0dm?C0<k>cP020=SHf00K0=[JfP3GemL0fMWI0=KFeP3GemL0
d];B0<g=c@3IfMT0e]KF0=GEe@3GemL0f][J0=SHf03IfMT0fm_K0=[JfP3Lg=`0fMWI0=CDe03EeMD0
emOG0=;BdP3EeMD0d=3@0=?Cd`3?cll0d];B0080dM7A00@0f=SH0=OGe`3EeMD0f=SH0P3GemL02P3D
e=@0f][J0=GEe@3IfMT0emOG0=SHf03GemL0c/k>0=OGe`3Lg=`20=_Kf`070=[JfP3Kfm/0f][J0=_K
f`3Lg=`0fMWI0=KFeP020=[JfP040=WIf@3GemL0f][J0=[JfP80g=cL0P3Kfm/20=kNgP070=WIf@3N
g]h0gMgM0=cLg03Ogml0g]kN0=cLg0020=gMg@80g]kN00L0hN7Q0=oOg`3Lg=`0dm?C0=_Kf`3Ph>00
hN7Q00gooooo000@ooooo`090>;RhP3Ph>00gmoO0=cLg03@d=00]KFe0=cLg03Ogml0gMgM0080gmoO
0P3Jf]X08`3Ph>00g=cL0=[JfP3GemL0f][J0=_Kf`3Lg=`0fm_K0=[JfP3IfMT0emOG0=?Cd`3Jf]X0
e]KF0<;2`P2_[jl0_Kfm0=[JfP3Lg=`0eMGE0=OGe`3IfMT0f][J0=_Kf`3IfMT0f][J0=_Kf`3Hf=P0
gMgM0=oOg`3Jf]X0g=cL0=[JfP3Kfm/0fMWI0080g=cL0P3Kfm/01`3GemL0f=SH0=_Kf`3Ng]h0h^;R
0=gMg@3Ng]h00P3Ogml20>3Ph0080=_Kf`3Ogml0f=SH0=cLg03Ng]h0gmoO0=[JfP3Ogml30=WIf@03
0=KFeP3EeMD0f][J0080emOG0P3IfMT0103EeMD0e]KF0=[JfP3GemL20=WIf@80f][J00<0emOG0=WI
f@3Fe]H00P3Bd]801`3AdM40c<c<0<g=c@3?cll0cLg=0<c<c03>c/h00P3:b/X00`37alL0b<S80<G5
a@020<30`080]kNg01/0];Bd0;2`/02/[:`0XZ:R0:BTY02SXj<0XJ6Q09bLW02KVi/0TY:B08f=S@2?
Shl0PX:207moO`1iNGT0Ogmo07EeM@1_Kfl0KVi^071`L01VIVH0IFEU069RHP1KFe/0E5AD05IFEP1E
EED00P1ADE40101;Bd/0ATI604Y:BP1;Bd/204Q8B00504U9B@1:BTX0BTY:04];B`18B4P00`16ATH0
0`13@d<0B4Q804A4A00204=3@`0304Y:BP15ADD0ADE50080ATI600P0ADE504A4A015ADD0ADE504A4
A01;Bd/0A4A404U9B@80ATI600<0Bd];04Y:BP1<C4`00P19BDT00`1:BTX0BDU904M7A`0204I6AP0:
04E5A@17AdL0BTY:04Q8B019BDT0B4Q804I6AP1<C4`0ATI604Q8B080Bd];00<0@T9204=3@`16ATH0
0P1;Bd/01P1?Cdl0D51@04m?C`19BDT0@d=304a<C080AdM700P0BTY:04m?C`1@D500EUIF05ADE01H
F5P0FUYJ06EUI@<0HF5Q00@0Fe]K069RHP1IFET0G5aL0P1MGEd0>@1RHV80Kfm_06i^KP1bLW80MGEe
07IfMP1dM7@0NGUi07AdM024Q8@0NWYj07emO@28R8P0SHf=092@T02HV9P0Ti>C09FEU@2BTY80TI6A
08n?S`2DU9@0V9RH0:6QX@2PX:00Xj>S0:VYZ@2UYJD0YZJV0:RXZ02^[Zh0Zj^[0:VYZ@2WYjL0[:b/
0;:b/P2/[:`0/K6a0:f][@2/[:`0^k^k0;bl_036a/H0`L710;no_`34a<@0bLW90<[:bP3;bl/0bLW9
0<[:bP3<c<`0b<S80<W9b@3;bl/0alO70<k>cP020=3@d00A0=?Cd`3@d=00clo?0<o?c`3=cLd0dM7A
0=3@d03Fe]H0d=3@0;Vi^@3;bl/0b<S80<[:bP39bLT0b<S80=GEe@3;bl/00P3:b/X03P3@d=00b<S8
0<K6aP33`l<0alO70=KFeP3EeMD0dM7A0<o?c`3Cdm<0d=3@0<_;b`3<c<`0c/k>0P3=cLd02P3?cll0
dM7A0<o?c`3<c<`0a<C40<[:bP3EeMD0e=CD0=GEe@3Fe]H20=WIf@0:0=[JfP3GemL0f=SH0=SHf03K
fm/0emOG0=WIf@3Jf]X0f=SH0=[JfP80fm_K01D0f=SH0=GEe@3IfMT0emOG0=[JfP3GemL0f][J0=_K
f`3IfMT0emOG0=KFeP3De=@0fMWI0=7Ad@3Bd]80g=cL0=_Kf`3MgMd0emOG0=WIf@3Jf]X00P3GemL2
0=[JfP80fMWI0P3Hf=P00`3GemL0fm_K0=SHf0020=SHf0040=[JfP3Hf=P0e]KF0=;BdP80dm?C0180
fMWI0=KFeP3Hf=P0emOG0=SHf03De=@0f][J0=SHf03AdM40g=cL0=GEe@3Fe]H0f=SH0=[JfP3IfMT0
f][J0=KFeP3GemL20=[JfP070=KFeP3De=@0emOG0=?Cd`3GemL0e]KF0=OGe`020=GEe@0<0=CDe03C
dm<0emOG0=KFeP3Jf]X0g=cL0=_Kf`3Lg=`0f=SH0=_Kf`3GemL0fMWI0P3Lg=`01P3Kfm/0d=3@0=cL
g03Ng]h0gMgM0=_Kf`80f][J00<0g=cL0=WIf@3Jf]X00P3IfMT02`3MgMd0f=SH0=cLg03IfMT0g=cL
0=_Kf`3Lg=`0f][J0=WIf@3MgMd0g=cL0080gMgM00`0g=cL0=kNgP3Ng]h0g=cL0=oOg`3MgMd0gmoO
0>3Ph03QhN40h>3P0=kNgP3IfMT20=KFeP030=_Kf`3Ogml0h>3P00gooooo000@ooooo`0<0>3Ph03M
gMd0hN7Q0=oOg`39bLT0XZ:R0=KFeP3Vi^H0h>3P0>7Qh@3Ph>00g=cL0P3Ph>005P3Lg=`0g]kN0=[J
fP3Ng]h0f][J0=cLg03Hf=P0f][J0=WIf@3De=@0eMGE0=KFeP3Cdm<0d];B0=KFeP3Ng]h0gmoO0=_K
f`3EeMD0dm?C0=GEe@3Fe]H30=GEe@0d0=;BdP3IfMT0f][J0=SHf03GemL0eMGE0=SHf03MgMd0gmoO
0=WIf@3Hf=P0fm_K0=cLg03AdM40emOG0=WIf@3Lg=`0fMWI0=gMg@3Jf]X0hN7Q0>CTi03Lg=`0fm_K
0=cLg03Ng]h0c/k>0=OGe`3Jf]X0emOG0=SHf03Lg=`0clo?0<g=c@3AdM40c/k>0<G5a@3;bl/0clo?
0=3@d038b<P0`L710;Zj^P2n_[h0`/;20<K6aP35aLD0`L710;fm_@2j^[X0^;Rh0;Vi^@80^;Rh00T0
[jn_0:NWY`2SXj<0WYjN09NGU`2BTY80TI6A08f=S@27QhL00P29RHT02`26QXH0NGUi07EeM@1iNGT0
KFe]05eMG@1QHF40Hf=S05YJFP1@D500FEUI0080E5AD00D0D51@04m?C`1;Bd/0Bd];04i>CP0204I6
AP0:0451@@16ATH0@d=304A4A015ADD0Bd];04=3@`14A4@0@d=304E5A@<0@T9200<0ATI604];B`12
@T800P10@400<`16ATH0@d=303lo?`13@d<0BTY:04Q8B012@T80?Shn0410@018B4P0ADE503lo?`12
@T80@d=304];B`1:BTX0AdM70451@@15ADD0ATI604A4A013@d<0ADE504Y:BP1DE5@0Cdm?04i>CP1<
C4`0E5AD051@D018B4P0De=C051@D01?Cdl0CTi>05=CD`1@D500DU9B05QHF01PH600FEUI05MGE`1D
E5@0EEEE055AD@1EEED0DE5A04U9B@1?Cdl0CTi>05ADE00205QHF00705=CD`1GEeL0GEeM06ATI01U
IFD0I6AT06QXJ00206YZJP0;06UYJ@1[Jf/0IFEU06i^KP1]KFd0KVi^07emO@23Ph<0OGem0820P025
QHD00P2CTi<08`2EUID0Vi^K09fMW@2MWId0SXj>0:>SX`2VYZH0Xj>S0:BTY02/[:`0[jn_0;Ng]`2b
/[80]KFe0;jn_P32`/80`l?30<o?c`33`l<0_[jn0<O7a`3;bl/0b/[:0=7Ad@39bLT0b/[:0<g=c@3>
c/h0a/K60<G5a@3<c<`0bl_;0<G5a@39bLT0c<c<0080bl_;0140clo?0<c<c037alL0`L710<?3``30
`<00_Kfm0<?3``34a<@0_[jn0;^k^`38b<P0a/K60<o?c`3>c/h0alO70<c<c0020=3@d0060<_;b`3>
c/h0bl_;0<k>cP39bLT0aLG50P3;bl/00`3<c<`0c/k>0=;BdP020<o?c`080=3@d03=cLd0cLg=0=7A
d@3EeMD0d];B0<c<c02n_[h20<k>cP040<_;b`38b<P0b<S80=OGe`80cLg=0P3<c<`01P3;bl/0alO7
0<K6aP3:b/X0d=3@0=7Ad@80d];B00L0dM7A0=3@d03<c<`0c<c<0<g=c@39bLT0c<c<00<0c/k>00/0
bl_;0<G5a@39bLT0d];B0=GEe@3Bd]80clo?0=7Ad@3EeMD0fm_K0=KFeP020=?Cd`080>7Qh@3EeMD0
emOG0=CDe03EeMD0emOG0=_Kf`3Hf=P20=CDe0060=cLg03IfMT0emOG0=OGe`3Hf=P0fm_K0P3Jf]X0
703IfMT0e]KF0=OGe`3@d=00d];B0=SHf03MgMd0f][J0=KFeP3IfMT0eMGE0=KFeP3IfMT0g=cL0=[J
fP3EeMD0f=SH0=KFeP3Hf=P0e]KF0=_Kf`3IfMT0f][J0=GEe@3Kfm/0eMGE0=KFeP3EeMD20=7Ad@0;
0=?Cd`3De=@0e]KF0=KFeP3EeMD0dm?C0=gMg@3Jf]X0clo?0=gMg@3Fe]H00P3Jf]X20=kNgP0;0=oO
g`3Jf]X0eMGE0=SHf03MgMd0gmoO0=3@d03De=@0e]KF0=[JfP3IfMT00P3GemL03@3Hf=P0e=CD0=7A
d@3Hf=P0f][J0=_Kf`3Lg=`0gMgM0=kNgP3GemL0g]kN0=cLg03Ng]h00P3Jf]X02@3IfMT0d=3@0=OG
e`3Jf]X0gMgM0=kNgP3Lg=`0fMWI0=gMg@020=[JfP030=_Kf`3MgMd0h>3P0080g=cL00H0f][J0>3P
h03Ng]h0h>3P0=cLg03Jf]X40=gMg@060=WIf@3MgMd0h>3P0>?Sh`3Ph>00gmoO0P3Ph>002@3Shn<0
h>3P0=oOg`3Lg=`0fMWI0=KFeP3Lg=`0g]kN0>7Qh@0=ooooo`004?ooool00`3Ogml0g]kN0=kNgP02
0=WIf@030=KFeP3Ogml0gMgM0080fm_K0P3Jf]X01`3Hf=P0f][J0=_Kf`3Fe]H0e=CD0=WIf@3GemL0
0P3IfMT05@3Lg=`0g]kN0=_Kf`3EeMD0e=CD0=GEe@3Cdm<0fMWI0=gMg@3Kfm/0emOG0=WIf@3De=@0
dM7A0=OGe`3De=@0eMGE0=;BdP3?cll0dm?C0=KFeP020=CDe0050=GEe@3Fe]H0d];B0=WIf@3De=@0
0P3GemL02`3Hf=P0e=CD0=?Cd`3>c/h0eMGE0=7Ad@3=cLd0`l?30<_;b`3<c<`0c/k>0080b/[:00d0
`L710;^k^`2l_;`0_Kfm0;:b/P2[Zj/0/K6a0:f][@2UYJD0Y:BT09bLW02<S8`0SXj>0080Shn?0140
QHF507]kN`1kNg/0PH6107]kN`1jNWX0L71`06i^KP1]KFd0IVIV06QXJ01VIVH0HV9R06EUI@1MGEd0
GemO055AD@0204a<C00F04i>CP1=CDd0BDU904Q8B01>CTh0BTY:04Q8B019BDT0ATI604Q8B016ATH0
ADE504U9B@16ATH0@d=30410@019BDT0@D5104A4A010@400ADE504I6AP80A4A40280@41004=3@`15
ADD0@d=304E5A@13@d<0ADE504=3@`12@T80ADE50410@013@d<0ADE50492@P15ADD0A4A404M7A`14
A4@0@d=30492@P19BDT0@T9203lo?`12@T80BDU904I6AP13@d<0ADE504];B`16ATH0BDU904M7A`1;
Bd/0EUIF0P1PH6001@1KFe/0FEUI04];B`1GEeL0DU9B0080CDe=00P0CTi>05EEE@1LG5`0F5QH05eM
G@1UIFD0Hf=S05mOG`80I6AT02X0H61P06MWI`1[Jf/0K6a/07=cL`1hN7P0RHV908:2PP1nOWh0PX:2
08>3P`21PH40RXZ:08R8R02:RXX0S8b<092@T02ATI40Ti>C09JFUP2HV9P0YJFU0:RXZ02VYZH0Y:BT
0:j^[P2c/k<0][Jf0;>c/`2d];@0]KFe0;6a/@2j^[X0^k^k0;Rh^02l_;`0`L710<30`033`l<0alO7
0<[:bP3;bl/30<[:bP030=?Cd`3>c/h0c<c<0080clo?01`0dM7A0=;BdP3@d=00eMGE0=7Ad@3Cdm<0
eMGE0=?Cd`3Fe]H0emOG0=7Ad@3=cLd0e=CD0=KFeP3EeMD0fm_K0=WIf@3De=@0b/[:0<c<c03:b/X0
bLW90<g=c@3<c<`0bl_;0<W9b@37alL0c<c<0P3?cll0303>c/h0bl_;0<G5a@37alL0^[Zj0;^k^`34
a<@0aLG50;Zj^P2l_;`0cLg=0<O7a`80cLg=02X0c<c<0<O7a`37alL0bl_;0<g=c@3;bl/0c<c<0=3@
d03=cLd0bl_;0<S8b037alL0bl_;0=7Ad@3@d=00c/k>0=?Cd`3?cll0b/[:0<g=c@3>c/h0bLW90<[:
bP3@d=00`l?30<[:bP3>c/h0b<S80<W9b@3;bl/0clo?0<c<c039bLT0bl_;0<g=c@3<c<`0b/[:0<k>
cP3AdM40d=3@0<o?c`3@d=020=;BdP030<o?c`3=cLd0b/[:0080c<c<00<0dm?C0<o?c`3@d=000P3?
cll20<W9b@0@0=3@d03GemL0dm?C0=CDe03GemL0e]KF0=GEe@3GemL0fm_K0=CDe03Ogml0e]KF0=SH
f03De=@0fMWI0=SHf080fMWI0100f][J0=SHf03Jf]X0f=SH0=gMg@3IfMT0fm_K0=WIf@3Lg=`0f][J
0=WIf@3GemL0fm_K0=7Ad@3EeMD0fm_K0P3Jf]X02`3Hf=P0f][J0=SHf03Kfm/0g=cL0=SHf03Kfm/0
emOG0=_Kf`3Jf]X0g=cL0080fMWI00X0f=SH0=_Kf`3Hf=P0g]kN0=WIf@3GemL0f=SH0=KFeP3EeMD0
emOG0P3Hf=P0303EeMD0e=CD0=OGe`3Lg=`0f][J0=3@d03Ng]h0f=SH0=_Kf`3Hf=P0fMWI0>3Ph080
g]kN00@0gMgM0=_Kf`3Jf]X0fm_K0P3IfMT0203Hf=P0e]KF0=[JfP3IfMT0f=SH0=OGe`3Kfm/0emOG
0P3Hf=P0403Lg=`0gMgM0=kNgP3Ng]h0gMgM0>;RhP3Ogml0g=cL0=oOg`3Jf]X0e=CD0<k>cP3IfMT0
g=cL0=SHf03MgMd30=cLg0030=WIf@3Kfm/0gMgM0080g=cL0P3Kfm/0403MgMd0g]kN0=kNgP3MgMd0
fm_K0=[JfP3Kfm/0gmoO0=gMg@3Lg=`0f][J0=cLg03Ogml0hN7Q0=kNgP3MgMd20=oOg`090>3Ph03M
gMd0g]kN0=gMg@3Jf]X0fMWI0=kNgP3Ogml0h>3P00gooooo000@ooooo`030=_Kf`3MgMd0gMgM0080
f][J00d0fm_K0=[JfP3MgMd0fm_K0=OGe`3De=@0d];B0=CDe03GemL0f=SH0=CDe03AdM40eMGE0080
e=CD00<0dM7A0=?Cd`3De=@00P3AdM402`3;bl/0b/[:0<S8b038b<P0`l?30<W9b@38b<P0`<300<71
`@2j^[X0^KVi0080^[Zj01D0^;Rh0;Jf]P2[Zj/0/K6a0:n_[`2^[Zh0[Jf]0:NWY`2TY:@0XJ6Q09nO
W`2PX:00WIfM09ZJVP2EUID0SXj>08b<S02ATI40R8R807UiN@1dM7@00P1cLg<01@1SHf<0HV9R06IV
IP1OGel0FEUI0080Fe]K01D0DE5A051@D01DE5@0C4a<04Y:BP1<C4`0BDU904e=C@1<C4`0B4Q804Y:
BP16ATH0AdM704Q8B01@D500AdM704Q8B013@d<0A4A404=3@`15ADD00P12@T802P0o?cl0A4A403lo
?`12@T80A4A404=3@`0n?Sh0@4100451@@0o?cl20451@@0504A4A016ATH0ATI60492@P10@4000P11
@D401@15ADD0@D5103lo?`13@d<0ADE50080ATI600@0@d=304U9B@16ATH0ADE50P16ATH01P18B4P0
BDU905=CD`1:BTX0AdM704m?C`80CDe=0P1CDe<2059BDP0N05YJFP1HF5P0EEEE05eMG@1IFET0GEeM
05aLG01QHF40Fe]K05mOG`1UIFD0J6QX06][J`1/K6`0MWIf07]kN`1dM7@0O7al0820P01nOWh0PX:2
096AT@2HV9P0VIVI08^;R`28R8P0UYJF09BDU02MWId0Y:BT0P2WYjL0502c/k<0/K6a0;2`/02e]KD0
]kNg0;>c/`2f][H0_Kfm0;^k^`2o_kl0_[jn0<C4a038b<P0bLW90<[:bP3=cLd0`L710<O7a`3:b/X0
b<S80P3Bd]802@3Fe]H0d];B0=GEe@3Bd]80d=3@0=;BdP3GemL0fMWI0=KFeP030=;BdP040<_;b`3D
e=@0c/k>0=3@d080d];B00<0eMGE0=3@d039bLT00`3Bd]801@3EeMD0d];B0=?Cd`3?cll0dM7A0080
clo?00/0emOG0=;BdP3EeMD0f=SH0=CDe03>c/h0e=CD0=OGe`3Cdm<0eMGE0=KFeP020=;BdP0<0=GE
e@3GemL0dM7A0<c<c03Bd]80eMGE0=OGe`3EeMD0cLg=0<o?c`3:b/X0bLW90P3;bl/01@3?cll0c/k>
0<_;b`3<c<`0b<S80080c<c<00D0clo?0<_;b`35aLD0b<S80<O7a`020<?3``80aLG501H0_;bl0<30
`03>c/h0cLg=0=7Ad@3?cll0cLg=0<k>cP3:b/X0c/k>0=;BdP3:b/X0c<c<0<g=c@3<c<`0c/k>0<[:
bP3?cll0dM7A0<o?c`3De=@0dm?C0P3AdM400`3<c<`0d=3@0<g=c@020<[:bP060=;BdP35aLD0a/K6
0=3@d03<c<`0clo?0`3AdM401`3:b/X0bLW90<_;b`3<c<`0b/[:0<S8b03;bl/00P3EeMD0103Cdm<0
fMWI0<o?c`3>c/h20<g=c@030<k>cP3GemL0e]KF0080eMGE00d0c/k>0<o?c`34a<@0cLg=0=GEe@3H
f=P0eMGE0=CDe03GemL0eMGE0=WIf@3Jf]X0fm_K0080f=SH00P0fMWI0=GEe@3GemL0f][J0=GEe@3G
emL0fm_K0=kNgP80fm_K00d0fMWI0=oOg`3IfMT0f=SH0=KFeP3Kfm/0fMWI0=GEe@3Fe]H0g]kN0=[J
fP3Cdm<0g=cL0080fMWI00H0f=SH0=[JfP3Kfm/0gMgM0=cLg03Hf=P20=[JfP040=cLg03MgMd0gMgM
0=gMg@80fMWI01<0fm_K0=SHf03Lg=`0emOG0=WIf@3Hf=P0emOG0=[JfP3Ng]h0fm_K0=OGe`3Fe]H0
f][J0=cLg03Jf]X0fMWI0=?Cd`3Ng]h0fm_K0080f][J00D0fm_K0=kNgP3Kfm/0gMgM0=cLg0020=SH
f080f][J00<0fMWI0=_Kf`3Hf=P00`3Jf]X0103IfMT0f=SH0=[JfP3IfMT20=_Kf`030=cLg03Ng]h0
g]kN0080h>3P01`0g]kN0=gMg@3Kfm/0fMWI0=SHf03@d=00f=SH0=[JfP3GemL0fm_K0=[JfP3Lg=`0
f][J0=cLg03Kfm/0fMWI0=_Kf`3IfMT0g=cL0=SHf03IfMT0g=cL0=oOg`3Lg=`0fm_K0=cLg03Hf=P0
g=cL0P3MgMd01P3Ng]h0gMgM0=kNgP3QhN40gmoO0=gMg@<0h>3P00P0hN7Q0=kNgP3Lg=`0g=cL0=WI
f@3Lg=`0h>3P0>?Sh`gooooo000@ooooo`030=GEe@3<c<`0b/[:0080d=3@00l0c<c<0<W9b@37alL0
`l?30;Ng]`2`/;00/K6a0:j^[P2b/[80[Zj^0;:b/P2[Zj/0XZ:R09ZJVP2NWYh00P2KVi/03`2BTY80
R8R808V9R@1lO7`0P82007moO`1eMGD0JFUY06YZJP1/K6`0Jf][06UYJ@1WIfL0JVYZ05iNGP0205eM
G@0?05aLG01FEUH0FEUI05]KF`1DE5@0DE5A05MGE`1ADE40Cdm?04e=C@1<C4`0CDe=04];B`17AdL0
ADE50080B4Q800@0ADE504I6AP12@T80ADE50`16ATH304A4A00N04Q8B013@d<0@T920492@P17AdL0
@D510492@P17AdL0@T9204E5A@12@T80@d=304I6AP13@d<0ADE504=3@`16ATH0@d=30492@P17AdL0
A4A404I6AP14A4@0ATI604U9B@16ATH0BDU904Q8B016ATH0C4a<0P19BDT02018B4P0Bd];055AD@1B
DU80Cdm?051@D01IFET0G5aL0P1HF5P02P1MGEd0GUiN061PH01QHF40IVIV071`L01gMgL0Jf][07If
MP1iNGT208>3P`0N08:2PP24Q8@0Shn?09NGU`2JVYX0UiNG09fMW@2PX:00Zj^[0:j^[P2[Zj/0[jn_
0;6a/@2d];@0/K6a0;Vi^@2e]KD0YJFU0:f][@2e]KD0_Kfm0;Zj^P2m_Kd0^k^k0;no_`35aLD0a/K6
0<?3``35aLD0cLg=0P3:b/X03`39bLT0d=3@0<[:bP3:b/X0dM7A0<S8b039bLT0bl_;0<G5a@3<c<`0
bLW90<k>cP3Cdm<0d];B0=3@d0020<W9b@030=;BdP3EeMD0dm?C0080c/k>00@0d=3@0=OGe`3De=@0
clo?0P3Fe]H0203De=@0e]KF0=GEe@35aLD0a/K60<o?c`3<c<`0dm?C0P3GemL00`3Hf=P0e]KF0=;B
dP020=;BdP0H0=?Cd`3Bd]80d=3@0=;BdP3?cll0d];B0<o?c`3AdM40cLg=0=7Ad@3@d=00dM7A0=;B
dP3>c/h0cLg=0=?Cd`3EeMD0f][J0=OGe`3Fe]H0e=CD0=?Cd`3Bd]80dM7A0P3Hf=P02P3EeMD0e=CD
0=GEe@3EeMD0dm?C0=7Ad@3>c/h0e=CD0=KFeP3IfMT20=OGe`0F0=GEe@3IfMT0c/k>0<c<c03@d=00
d];B0=KFeP3@d=00cLg=0<k>cP39bLT0b/[:0<c<c03;bl/0c<c<0<g=c@3>c/h0c<c<0<_;b`3:b/X0
bl_;0<o?c`80alO70180bLW90<O7a`3:b/X0clo?0<?3``35aLD0`L710;fm_@3=cLd0dM7A0=;BdP3:
b/X0d=3@0=?Cd`3?cll0d=3@0=CDe03;bl/20<o?c`030<_;b`3=cLd0b/[:00<0cLg=01T0d=3@0=;B
dP3Cdm<0e=CD0<o?c`3<c<`0bl_;0<W9b@3?cll0eMGE0;jn_P35aLD0cLg=0<_;b`3?cll0e]KF0=?C
d`3EeMD0bLW90<g=c@3>c/h0clo?0<c<c03:b/X0c/k>0080e=CD00@0f][J0=WIf@3GemL0d];B0P3H
f=P04P3>c/h0e]KF0=SHf03IfMT0f=SH0=7Ad@3=cLd0aLG50<S8b03Hf=P0e=CD0=GEe@3Fe]H0f][J
0=_Kf`3Ng]h0gMgM0=_Kf`<0emOG00X0f][J0=SHf03Kfm/0e]KF0=SHf03Lg=`0g]kN0=[JfP3Lg=`0
f][J0`3GemL04P3IfMT0g]kN0=[JfP3Fe]H0f=SH0=[JfP3GemL0e=CD0=WIf@3Hf=P0fMWI0=OGe`3I
fMT0fm_K0=kNgP3MgMd0f=SH0=cLg0<0gMgM01H0fm_K0>7Qh@3Lg=`0g=cL0=_Kf`3Jf]X0g=cL0=OG
e`3IfMT0e]KF0=OGe`3Lg=`0g]kN0=oOg`3Kfm/0fMWI0=_Kf`3Jf]X0g]kN0=_Kf`3Fe]H0gmoO0P3P
h>003@3QhN40gmoO0=_Kf`3Ogml0g]kN0=SHf03Fe]H0f][J0=cLg03Kfm/0dM7A0=SHf03Jf]X00P3I
fMT02`3Jf]X0gMgM0=_Kf`3Ogml0fm_K0=kNgP3Lg=`0g]kN0>7Qh@3Shn<0h>3P0080h^;R00L0gmoO
0>;RhP3IfMT0fMWI0<g=c@3Fe]H0fMWI0080gMgM01<0g]kN0=gMg@3Hf=P0gMgM0=cLg03Kfm/0h>3P
0=[JfP3MgMd0gmoO0=WIf@3Kfm/0f][J0=_Kf`3MgMd0h>3P0=cLg03Ph>00gmoO0080g]kN0P3QhN40
103Ph>00gMgM0=oOg`3Shn<20>;RhP080=oOg`3Ph>00hN7Q0>3Ph03Lg=`0h^;R0>KViP3Rh^8=oooo
o`004?ooool04`1mOGd0MWIf07AdM01lO7`0NGUi071`L01aLG40MGEe06UYJ@1KFe/0G5aL05MGE`1L
G5`0F5QH059BDP1ADE40De=C04m?C`1=CDd00P1:BTX0401;Bd/0Cdm?04];B`1<C4`0BTY:04M7A`19
BDT0B4Q804U9B@17AdL0Bd];04U9B@18B4P0BTY:04U9B@16ATH204M7A`0704E5A@1;Bd/0BTY:04M7
A`16ATH0Bd];04Q8B00204U9B@0904e=C@17AdL0BTY:04M7A`15ADD0BDU904e=C@1:BTX0C4a<0080
BDU900P0AdM704];B`1<C4`0D51@04i>CP1@D500DU9B05EEE@80DU9B0P1EEED09P1KFe/0GEeM05iN
GP1MGEd0H61P06EUI@1^KVh0LG5a06e]K@1_Kfl0MGEe07]kN`1nOWh0P82008N7Q`1nOWh0Ph>308b<
S02FUYH0S8b<09NGU`2FUYH0UiNG09JFUP2OWil0YJFU0:ZZZP2QXJ40[:b/0:f][@2_[jl0[:b/0;6a
/@2f][H0^KVi0;Jf]P2n_[h0][Jf0`33`l<07P34a<@0a/K60<K6aP36a/H0c/k>0<O7a`3AdM40c/k>
0<o?c`3AdM40fMWI0<k>cP3?cll0cLg=0=;BdP3=cLd0d];B0=SHf03EeMD0e]KF0=7Ad@3De=@0d];B
0=KFeP3De=@0`/;20<[:bP3;bl/0clo?0<k>cP80d];B00`0dM7A0<o?c`3=cLd0d];B0<k>cP3@d=00
d];B0=KFeP3Hf=P0fMWI0=3@d03De=@30=GEe@0;0=3@d035aLD0cLg=0<g=c@3@d=00c<c<0<g=c@34
a<@0bl_;0<c<c03:b/X00P3Bd]801P3<c<`0dM7A0=3@d03EeMD0clo?0<c<c080f=SH00d0dM7A0<c<
c03De=@0aLG50<_;b`3<c<`0b<S80<g=c@3Fe]H0d];B0=3@d03EeMD0e=CD0080d];B00/0d=3@0<k>
cP3=cLd0clo?0<k>cP3<c<`0d];B0=7Ad@3?cll0c/k>0=;BdP020=KFeP090<g=c@3@d=00dM7A0=KF
eP3EeMD0fMWI0=SHf03De=@0e]KF0080d];B0P3GemL04@3De=@0d];B0=SHf03De=@0d];B0=?Cd`3B
d]80emOG0=SHf03Jf]X0fMWI0=_Kf`3EeMD0e=CD0<o?c`3AdM40d];B00<0d=3@00@0b/[:0=7Ad@3A
dM40cLg=0P39bLT05`3<c<`0dM7A0<k>cP3>c/h0`l?30<[:bP35aLD0c<c<0<S8b03<c<`0b/[:0<S8
b03:b/X0cLg=0<[:bP38b<P0`/;20;no_`3:b/X0dm?C0=GEe@3>c/h0d=3@0080dm?C00H0dM7A0<c<
c03?cll0d];B0<o?c`3Cdm<20<g=c@<0c/k>00l0dm?C0=GEe@3AdM40dM7A0=3@d03;bl/0dm?C0=3@
d03EeMD0dM7A0<G5a@3?cll0dm?C0=;BdP3Cdm<00`3GemL06@3Fe]H0dm?C0=?Cd`3>c/h0dm?C0=;B
dP3Cdm<0f=SH0=WIf@3Lg=`0fMWI0=[JfP3Hf=P0fm_K0=gMg@3Lg=`0hN7Q0=cLg03IfMT0g=cL0=OG
e`3Bd]80alO70<_;b`3IfMT00P3GemL0103Hf=P0g=cL0=cLg03GemL20=_Kf`0H0=KFeP3EeMD0gMgM
0=gMg@3IfMT0f=SH0=gMg@3Lg=`0fMWI0>;RhP3Kfm/0g=cL0=SHf03IfMT0emOG0=[JfP3Kfm/0f][J
0=_Kf`3Lg=`0g]kN0=gMg@3Hf=P0dM7A0P3Jf]X01P3Kfm/0f][J0=gMg@3Jf]X0g]kN0=oOg`80gMgM
00<0hN7Q0=gMg@3Lg=`00P3Lg=`00`3Ogml0fm_K0=gMg@020=oOg`030=gMg@3Kfm/0fMWI00<0fm_K
0P3Ng]h00`3Kfm/0g]kN0=cLg0020=kNgP080=OGe`3Ph>00hN7Q0>3Ph03QhN40h>3P0=cLg03Ng]h2
0>3Ph00:0=gMg@3IfMT0fMWI0=gMg@3IfMT0f][J0>3Ph03Jf]X0fMWI0=SHf0<0fm_K00P0gmoO0>3P
h03MgMd0gmoO0>7Qh@3Rh^80hn?S0>3Ph080hn?S00D0gMgM0=KFeP3Bd]80c<c<0=[JfP030=cLg004
0=SHf03Kfm/0h>3P0=kNgP80g=cL00P0g]kN0=oOg`3Ng]h0fm_K0=SHf03Jf]X0emOG0=gMg@80g=cL
00<0gmoO0>3Ph03Ogml00P3MgMd01P3QhN40h>3P0=kNgP3Jf]X0g]kN0>;RhP80i>CT00P0h^;R0>3P
h03Ph>00g]kN0>7Qh@3Shn<0h^;R0>7Qh@gooooo000@ooooo`04051@D01?Cdl0C4a<04];B`80CDe=
00`0BTY:04a<C019BDT0BDU904Y:BP19BDT0CDe=04Y:BP19BDT0AdM704];B`1=CDd204Q8B080Bd];
0P18B4P0401?Cdl0CTi>04Y:BP1<C4`0CDe=059BDP1ADE40EeMG05UIF@1NGUh0GEeM05]KF`1MGEd0
EeMG05iNGP1LG5`206=SH`0U06YZJP1[Jf/0Lg=c079bLP1eMGD0NGUi08:2PP27QhL0QHF508B4Q02:
RXX0Shn?09FEU@29RHT0UiNG09jNWP2OWil0XJ6Q0:JVYP2YZJT0]kNg0;>c/`2_[jl0]kNg0;Fe]@2f
][H0^;Rh0;^k^`2n_[h0`L710<C4a030`<00];Bd0;Rh^034a<@0b<S80<_;b`020<S8b00P0<g=c@3<
c<`0cLg=0<g=c@39bLT0b<S80<[:bP3>c/h0clo?0<O7a`39bLT0cLg=0<o?c`3=cLd0clo?0<k>cP3@
d=00c/k>0=?Cd`3=cLd0bl_;0<o?c`3=cLd0dm?C0=CDe03Bd]80dm?C0=3@d03?cll0dM7A0<_;b`3@
d=020=7Ad@0>0<_;b`3?cll0cLg=0=CDe03AdM40c/k>0=3@d03AdM40a/K60<C4a03=cLd0aLG50<c<
c03?cll20=GEe@@0dM7A00T0clo?0<_;b`32`/80c/k>0=CDe03?cll0dm?C0=CDe03EeMD00P3Bd]80
103:b/X0c/k>0<o?c`3?cll20=GEe@030=CDe03EeMD0dM7A0080dm?C00X0eMGE0=?Cd`3AdM40b/[:
0<c<c03@d=00dM7A0<o?c`3AdM40eMGE0P3AdM403P3Cdm<0eMGE0=3@d03Bd]80e=CD0=KFeP3Hf=P0
eMGE0=?Cd`3Fe]H0eMGE0<o?c`3Cdm<0emOG0P3;bl/02`3@d=00bl_;0=3@d03GemL0e=CD0=?Cd`3F
e]H0emOG0=;BdP3AdM40dm?C0080e=CD00H0d=3@0<o?c`3Bd]80d];B0=KFeP3AdM440=;BdP070<g=
c@3:b/X0dm?C0=;BdP3AdM40fMWI0=KFeP020=;BdP0>0=CDe03EeMD0eMGE0=WIf@3GemL0e=CD0=3@
d03GemL0e=CD0=GEe@3?cll0emOG0=SHf03GemL20=KFeP0<0=WIf@3GemL0cLg=0=7Ad@3GemL0d];B
0=7Ad@3EeMD0dM7A0<g=c@3?cll0bl_;0P38b<P01039bLT0c<c<0=;BdP36a/H20<_;b`060<g=c@3>
c/h0c<c<0<W9b@3=cLd0clo?0P3;bl/02P37alL0c<c<0<C4a036a/H0d=3@0=7Ad@3EeMD0dM7A0=CD
e036a/H20=3@d00=0=;BdP3AdM40eMGE0=7Ad@3Cdm<0f=SH0=KFeP3Cdm<0e]KF0=?Cd`3@d=00dM7A
0=?Cd`020=CDe00B0=3@d03GemL0dm?C0=GEe@3AdM40bLW90=CDe03Fe]H0e=CD0=3@d03IfMT0f][J
0=WIf@3GemL0f=SH0=WIf@3Bd]80dM7A0P3Hf=P02P3Jf]X0f=SH0=gMg@3Kfm/0emOG0=WIf@3Lg=`0
f][J0=gMg@3Ogml20=cLg00;0=WIf@3Fe]H0eMGE0<[:bP3?cll0fm_K0=WIf@3GemL0f=SH0=cLg03M
gMd00P3Lg=`03P3Jf]X0fm_K0=SHf03IfMT0fm_K0=cLg03MgMd0gmoO0=kNgP3Ph>00gmoO0=_Kf`3Q
hN40fm_K0P3Jf]X04@3Ng]h0h>3P0>3Ph03Lg=`0fm_K0=[JfP3Lg=`0eMGE0=?Cd`3Lg=`0h>3P0=_K
f`3Jf]X0gmoO0=_Kf`3Ogml0h>3P0080g]kN0P3Ph>002@3Ng]h0gMgM0=oOg`3Ng]h0f][J0=kNgP3L
g=`0g]kN0=gMg@020=cLg0090=gMg@3Lg=`0g=cL0=_Kf`3Ng]h0h>3P0=oOg`3Ng]h0fm_K0080fMWI
01D0g]kN0>;RhP3Ti>@0gmoO0>7Qh@3Ph>00h^;R0>CTi03Shn<0gMgM0=_Kf`3Ph>00gMgM0=[JfP3K
fm/0g]kN0=cLg03Ng]h0f][J0=oOg`3Rh^800P3Ogml01@3Ng]h0h^;R0>7Qh@3QhN40h^;R00<0hn?S
00H0h>3P0>?Sh`3IfMT0d=3@0<c<c03GemL40=_Kf`80h>3P00H0g=cL0=gMg@3Ogml0g]kN0>7Qh@3P
h>020=gMg@030=kNgP3Jf]X0gmoO0080g=cL00X0g]kN0=oOg`3Lg=`0fm_K0=kNgP3Rh^80g]kN0>3P
h03MgMd0hN7Q0P3Shn<20>;RhP070>3Ph03QhN40hN7Q0>;RhP3QhN40hn?S0>CTi00=ooooo`004?oo
ool205mOG`06069RHP1SHf<0IFEU06e]K@1`L700MWIf0P1hN7P0101dM7@0NWYj07MgM`1gMgL207]k
N`0L07emO@22PX80Ph>308n?S`2:RXX0SXj>096AT@2CTi<0VIVI0:6QX@2VYZH0ZZZZ0:RXZ02[Zj/0
[jn_0;Jf]P2e]KD0/k>c0;Jf]P2m_Kd0_kno0;:b/P2i^KT0^k^k0;no_`31`L40alO70<G5a@80b/[:
0180cLg=0<_;b`3<c<`0c/k>0=;BdP3@d=00clo?0=_Kf`3Fe]H0c<c<0=;BdP3De=@0eMGE0=[JfP3L
g=`0f][J0=WIf@3Kfm/30=OGe`040=[JfP3IfMT0e]KF0=WIf@80e]KF00h0e=CD0<_;b`3=cLd0e=CD
0=7Ad@3Hf=P0e]KF0=7Ad@3?cll0dm?C0=CDe03?cll0cLg=0=;BdP80e=CD00H0dM7A0<_;b`39bLT0
cLg=0=7Ad@3>c/h50<g=c@040=7Ad@3=cLd0c/k>0<g=c@80d];B00/0dM7A0<g=c@3Bd]80d=3@0<K6
aP3;bl/0c/k>0=;BdP3<c<`0a/K60<k>cP020=3@d00=0<_;b`39bLT0clo?0<g=c@3?cll0alO70<g=
c@35aLD0c<c<0<o?c`3Bd]80dm?C0<o?c`020=;BdP80dM7A00@0cLg=0<S8b03AdM40eMGE0P3Cdm<0
7@3AdM40d];B0<o?c`3Bd]80d=3@0=CDe03=cLd0d];B0=7Ad@3De=@0e]KF0=OGe`3De=@0dM7A0=3@
d03Cdm<0d=3@0<o?c`36a/H0clo?0=7Ad@3Cdm<0e=CD0=3@d03De=@0dm?C0=;BdP3GemL0e]KF0080
dM7A00<0d=3@0=KFeP3Hf=P00P3Jf]X0203MgMd0f=SH0=;BdP3Bd]80dm?C0<g=c@3:b/X0d];B0P3G
emL00`3Hf=P0fm_K0=_Kf`020=KFeP030=;BdP3De=@0emOG0080e]KF0P3EeMD02`3Cdm<0dM7A0=CD
e03Cdm<0e]KF0=WIf@3Fe]H0f=SH0=;BdP3=cLd0dm?C0080e=CD0`3Fe]H20=?Cd`0K0=CDe03Fe]H0
e=CD0=?Cd`3EeMD0e]KF0=GEe@3De=@0emOG0=;BdP3Cdm<0emOG0=SHf03Lg=`0f][J0=_Kf`3Cdm<0
c<c<0=?Cd`3Bd]80d=3@0=;BdP3Fe]H0dm?C0<k>cP3?cll0bl_;0080bLW900h0c/k>0=3@d03Cdm<0
clo?0=7Ad@3>c/h0clo?0=?Cd`3:b/X0bLW90<S8b03;bl/0b/[:0<k>cP80b/[:00h0c/k>0<_;b`3C
dm<0d];B0=KFeP3Bd]80dm?C0<k>cP3Bd]80dm?C0=KFeP3?cll0d];B0=GEe@@0e=CD0P3EeMD30=?C
d`0=0=CDe03Hf=P0eMGE0=CDe03Fe]H0f=SH0=GEe@38b<P0dm?C0=GEe@3De=@0dM7A0=_Kf`020=cL
g0080=[JfP3Hf=P0f][J0=OGe`3Fe]H0fMWI0=GEe@3Hf=P20=cLg0030=_Kf`3Hf=P0g=cL0080g=cL
00X0f][J0=kNgP3Ogml0gMgM0=OGe`3IfMT0d];B0<[:bP3Bd]80f][J0`3IfMT0303Lg=`0gMgM0=cL
g03Jf]X0f=SH0=_Kf`3IfMT0fm_K0=cLg03Ng]h0h>3P0>;RhP80h>3P00@0hN7Q0=oOg`3Ogml0h>3P
0P3Ng]h00`3Ogml0g]kN0>3Ph0020=kNgP090=_Kf`3MgMd0fMWI0=WIf@3Shn<0g]kN0=cLg03Ogml0
h^;R0080gMgM00<0h>3P0>GUi@3QhN400P3Ph>000`3QhN40h^;R0=oOg`020=gMg@0>0=oOg`3QhN40
hn?S0>3Ph03MgMd0g=cL0=gMg@3Ng]h0gmoO0=cLg03Ogml0hN7Q0=oOg`3MgMd20=_Kf`0C0=cLg03O
gml0i>CT0>CTi03Ogml0hn?S0>CTi03UiND0h^;R0>7Qh@3Ogml0h>3P0>?Sh`3MgMd0h>3P0=oOg`3L
g=`0gmoO0=cLg0020>7Qh@0<0>3Ph03MgMd0gmoO0=oOg`3MgMd0hN7Q0>?Sh`3Rh^80h>3P0>CTi03S
hn<0hN7Q0P3MgMd01`3IfMT0eMGE0=kNgP3Rh^80gmoO0=cLg03Kfm/00P3Ogml01`3MgMd0gmoO0=oO
g`3Ng]h0h>3P0>?Sh`3QhN400P3Ogml00`3MgMd0h>3P0=kNgP020=kNgP040>7Qh@3Rh^80hN7Q0=oO
g`80h^;R00h0iNGU0=oOg`3Ph>00hn?S0>GUi@3Ti>@0hn?S0>3Ph03Shn<0iNGU0>3Ph03Ng]h0h^;R
0>CTi0gooooo000@ooooo`060;jn_P2j^[X0^KVi0;Jf]P2j^[X0alO70P3;bl/01`3AdM40c<c<0<G5
a@3=cLd0c<c<0<o?c`3>c/h00P3=cLd02P3?cll0_[jn0<W9b@38b<P0c<c<0=7Ad@3@d=00dm?C0=WI
f@3Jf]X20=OGe`0@0=WIf@3GemL0emOG0=KFeP3Cdm<0eMGE0=OGe`3Bd]80c/k>0=?Cd`3Hf=P0clo?
0=3@d03Cdm<0eMGE0=WIf@80e]KF0P3Bd]803P3AdM40e=CD0=CDe03GemL0fm_K0=SHf03Bd]80dm?C
0=OGe`3Hf=P0fm_K0=[JfP3Hf=P0fMWI0P3Hf=P01`3Cdm<0e]KF0=WIf@3IfMT0f=SH0=WIf@3De=@0
0P3EeMD00`3<c<`0alO70=?Cd`020=;BdP0A0=OGe`3De=@0d=3@0=?Cd`3@d=00clo?0=3@d03De=@0
eMGE0<k>cP3@d=00bl_;0<c<c03:b/X0d=3@0<K6aP3:b/X00P3Bd]801@3>c/h0dM7A0<o?c`3@d=00
dM7A0080cLg=0140clo?0<k>cP3AdM40eMGE0=CDe03>c/h0bl_;0<o?c`3AdM40clo?0<W9b@3>c/h0
b/[:0<o?c`3>c/h0c<c<0=;BdP020=3@d0<0c/k>0P3AdM40303?cll0eMGE0=OGe`3?cll0dm?C0<g=
c@3AdM40c<c<0<O7a`3@d=00clo?0=?Cd`80clo?0`3EeMD01@3Cdm<0eMGE0=3@d03AdM40d];B00<0
dm?C0P3Fe]H0603De=@0f=SH0=GEe@3;bl/0b<S80<k>cP3EeMD0dm?C0=CDe03Bd]80e]KF0=WIf@3F
e]H0fMWI0=CDe03Cdm<0c<c<0=?Cd`3GemL0g=cL0=[JfP3IfMT0gMgM0=GEe@80e=CD00L0emOG0<S8
b03Cdm<0emOG0=kNgP3IfMT0f][J0080fm_K00<0e]KF0=CDe03AdM400P3De=@02P3IfMT0emOG0=OG
e`3EeMD0d];B0=?Cd`3Bd]80f=SH0=GEe@3Jf]X20=GEe@080<o?c`32`/80dm?C0=GEe@3Cdm<0e=CD
0=SHf03De=@20=GEe@<0e]KF00@0gMgM0=KFeP3Hf=P0dm?C0P3Hf=P0303GemL0cLg=0=KFeP3GemL0
gMgM0=[JfP3Hf=P0dm?C0<c<c03AdM40eMGE0=CDe0<0e]KF00L0dm?C0<_;b`3Cdm<0d=3@0=?Cd`3D
e=@0dM7A0080dm?C00D0dM7A0<o?c`3Cdm<0e=CD0=;BdP020<k>cP80dM7A00H0clo?0<g=c@3<c<`0
dM7A0<g=c@3Bd]820=KFeP030=7Ad@3Bd]80dm?C0080e]KF00X0fMWI0=?Cd`3Hf=P0fMWI0=[JfP3E
eMD0f=SH0=_Kf`3GemL0eMGE0P3De=@02P3EeMD0emOG0=SHf03Jf]X0emOG0=WIf@3Fe]H0d];B0<S8
b03GemL20=[JfP030=SHf03Lg=`0g=cL0080gmoO0`3IfMT01`3Jf]X0fm_K0=SHf03Jf]X0g=cL0=[J
fP3IfMT00P3MgMd01`3Ogml0fm_K0=kNgP3MgMd0fm_K0=kNgP3Kfm/00P3Hf=P0203:b/X0dM7A0=WI
f@3Hf=P0gMgM0=_Kf`3Lg=`0g]kN0`3Lg=`02@3Ng]h0f=SH0=_Kf`3Ogml0hN7Q0>3Ph03Shn<0h^;R
0=oOg`020>3Ph00C0=kNgP3MgMd0g]kN0=oOg`3QhN40h>3P0>7Qh@3Ogml0g=cL0=kNgP3Ph>00gmoO
0=WIf@3Ogml0h>3P0=cLg03Ogml0h>3P0>7Qh@020>3Ph0040>?Sh`3Ti>@0h^;R0=kNgP<0h^;R00L0
gmoO0>3Ph03Ph>00hN7Q0>3Ph03Ng]h0hN7Q0080fMWI00H0hN7Q0>;RhP3Ph>00g]kN0=oOg`3Ph>03
0=kNgP0=0=WIf@3QhN40i>CT0>;RhP3Ogml0h>3P0>;RhP3QhN40gMgM0=kNgP3Rh^80h>3P0=cLg002
0>7Qh@080=oOg`3Ng]h0gmoO0=kNgP3QhN40hn?S0>3Ph03Ogml20>;RhP0?0>3Ph03Shn<0iNGU0>CT
i03Shn<0iNGU0>7Qh@3Ph>00gmoO0>3Ph03Hf=P0dM7A0=oOg`3UiND0h^;R0080gmoO0P3Rh^800`3P
h>00hN7Q0>;RhP020>;RhP030>?Sh`3Ogml0gmoO0080hn?S00/0hN7Q0>3Ph03QhN40gmoO0>7Qh@3R
h^80i>CT0>;RhP3Shn<0i>CT0>OWi`020>7Qh@0;0>?Sh`3UiND0iNGU0>?Sh`3Ph>00i>CT0>SXj03Q
hN40h>3P0>GUi@3Ti>@03Oooool0013ooooo00T0gMgM0=OGe`3Hf=P0d];B0=KFeP3Hf=P0emOG0=cL
g03Hf=P00`3De=@02`3Bd]80emOG0=CDe03Bd]80dm?C0=KFeP3=cLd0dM7A0<c<c03@d=00eMGE0080
e=CD00@0fMWI0=[JfP3Jf]X0f=SH0P3Fe]H02`3Jf]X0fMWI0=KFeP3GemL0e=CD0=7Ad@3?cll0dm?C
0=7Ad@3>c/h0dM7A0080e]KF00`0emOG0=?Cd`3Hf=P0e]KF0=?Cd`3AdM40emOG0=SHf03Ph>00f][J
0=7Ad@3Bd]820=SHf00:0=[JfP3MgMd0fMWI0=WIf@3:b/X0f=SH0=[JfP3EeMD0fMWI0=KFeP80emOG
00`0f=SH0=WIf@3De=@0eMGE0<g=c@3<c<`0cLg=0=CDe03GemL0e]KF0=OGe`3AdM430=OGe`030=WI
f@3Fe]H0d=3@0080dM7A01h0d=3@0<S8b03>c/h0d=3@0<O7a`39bLT0dM7A0<o?c`3>c/h0d];B0=?C
d`3EeMD0d];B0=CDe03Bd]80e=CD0=7Ad@3De=@0f=SH0=WIf@3Fe]H0d];B0=7Ad@3Cdm<0d=3@0<_;
b`3Bd]80clo?0=3@d03=cLd20=?Cd`0P0=CDe03Bd]80dM7A0<c<c03@d=00e=CD0=SHf03De=@0dm?C
0=GEe@3Fe]H0eMGE0=7Ad@3De=@0c/k>0<S8b03@d=00bl_;0=CDe03Bd]80e]KF0=3@d03Fe]H0f=SH
0=WIf@3EeMD0e=CD0=3@d03GemL0fMWI0=SHf03EeMD20=KFeP060=WIf@3GemL0eMGE0=7Ad@3=cLd0
dM7A0`3Hf=P00`3AdM40c<c<0=GEe@020=[JfP030=OGe`3Cdm<0f=SH0080emOG00@0g=cL0=WIf@3F
e]H0dm?C103Fe]H02P3=cLd0d];B0=WIf@3Kfm/0g]kN0=cLg03Jf]X0f=SH0=;BdP3De=@20=;BdP06
0=KFeP3GemL0e]KF0=SHf03GemL0dM7A0P3Hf=P02@3Kfm/0f=SH0=[JfP3Hf=P0g=cL0<o?c`3<c<`0
fMWI0=[JfP020=OGe`0<0=KFeP3MgMd0e]KF0=KFeP3Jf]X0e=CD0=GEe@3GemL0e]KF0=WIf@3Fe]H0
f=SH0P3GemL0103EeMD0gMgM0=_Kf`3Jf]X20=SHf0050=;BdP32`/80clo?0=OGe`3Hf=P00P3De=@0
103Cdm<0e=CD0=KFeP3GemL20=GEe@060=CDe03AdM40dM7A0=CDe03AdM40dm?C0P3IfMT02`3@d=00
dM7A0=7Ad@3Fe]H0dM7A0<g=c@3@d=00dM7A0<_;b`3>c/h0emOG00<0e]KF00<0eMGE0=OGe`3Bd]80
0P3Hf=P01@3Fe]H0f=SH0=WIf@3Lg=`0fMWI0080g=cL0100g]kN0=[JfP3Hf=P0fMWI0=[JfP3Hf=P0
fm_K0=[JfP3Kfm/0emOG0=gMg@3Kfm/0dM7A0=?Cd`3IfMT0emOG0P3Jf]X0203MgMd0g=cL0=gMg@3K
fm/0gMgM0=7Ad@3Fe]H0eMGE0P3IfMT01P3MgMd0f=SH0=kNgP3Jf]X0h>3P0>;RhP<0h>3P02@0gmoO
0>;RhP3Jf]X0h>3P0=WIf@3>c/h0d];B0>3Ph03Ng]h0g=cL0=kNgP3MgMd0fm_K0>3Ph03Shn<0h^;R
0=gMg@3Ng]h0h>3P0>KViP3UiND0h^;R0>?Sh`3QhN40hn?S0>;RhP3Ti>@0h^;R0=kNgP3QhN40h^;R
0>?Sh`3Ogml0hn?S0>;RhP3Vi^H30>7Qh@0<0=oOg`3Ti>@0g]kN0>3Ph03Vi^H0hN7Q0>;RhP3UiND0
i^KV0>?Sh`3Ph>00hn?S0`3Rh^830>?Sh`80h>3P00@0h^;R0>7Qh@3Ph>00gMgM0P3Rh^820>GUi@03
0=oOg`3UiND0hN7Q00<0hN7Q00@0gmoO0>;RhP3Shn<0gmoO0P3QhN400`3Vi^H0hN7Q0>7Qh@020>7Q
h@090>3Ph03UiND0h>3P0>CTi03QhN40h>3P0>CTi03Ph>00i>CT0080hN7Q00T0hn?S0>GUi@3UiND0
hn?S0>GUi@3Vi^H0j>SX0>CTi03WinL00P3Ti>@01P3Ogml0hN7Q0=gMg@3IfMT0h^;R0>KViP<0hn?S
00`0h^;R0>?Sh`3Rh^80hN7Q0>3Ph03Ng]h0gmoO0>3Ph03Ng]h0gMgM0>3Ph03Rh^820=oOg`0;0>3P
h03Ng]h0hn?S0>;RhP3UiND0hN7Q0=kNgP3Rh^80hN7Q0>CTi03Ogml00P3Rh^801@3UiND0i>CT0>CT
i03UiND0inOW0080hn?S00<0i^KV0>OWioooool03?ooool0013ooooo00D0gmoO0=WIf@3Jf]X0d=3@
0=CDe0020=[JfP070=KFeP3>c/h0dm?C0=CDe03GemL0e]KF0=SHf0020=?Cd`060=GEe@3De=@0bl_;
0=7Ad@3@d=00d];B0P3IfMT20=[JfP050=WIf@3Jf]X0f=SH0=[JfP3IfMT00P3Hf=P01P3De=@0emOG
0=WIf@3Fe]H0d=3@0=?Cd`80d];B01X0e=CD0=KFeP3EeMD0e]KF0=SHf03IfMT0e]KF0=;BdP3De=@0
e]KF0=SHf03Rh^80e]KF0=SHf03AdM40fMWI0=_Kf`3IfMT0g=cL0=GEe@3IfMT0bLW90=WIf@3Jf]X0
f=SH0=cLg080emOG0P3Hf=P0303GemL0dM7A0=GEe@3AdM40d=3@0=KFeP3Kfm/0g=cL0=WIf@3Jf]X0
fMWI0=_Kf`<0f][J00<0e]KF0=GEe@3GemL00P3EeMD03`3Cdm<0emOG0=KFeP3?cll0c/k>0=OGe`3H
f=P0e]KF0=GEe@3Fe]H0eMGE0=;BdP3Fe]H0d];B0=SHf0020=KFeP0>0=OGe`3Hf=P0fMWI0=GEe@3J
f]X0eMGE0=CDe03=cLd0d];B0=7Ad@3De=@0dm?C0=;BdP3@d=020=7Ad@050<o?c`3@d=00emOG0=OG
e`3Hf=P00P3Fe]H0103IfMT0emOG0=KFeP3Fe]H20=7Ad@0;0<o?c`3AdM40d];B0=7Ad@3Bd]80dm?C
0=7Ad@3IfMT0fm_K0=OGe`3Jf]X00P3GemL00`3EeMD0fMWI0=WIf@020=KFeP090=SHf03Lg=`0emOG
0=3@d03?cll0d=3@0=WIf@3Hf=P0eMGE0080fMWI00P0e=CD0=WIf@3IfMT0g=cL0=[JfP3GemL0fMWI
0=SHf080f][J00D0fMWI0=OGe`3GemL0fm_K0=[JfP020=SHf00<0<o?c`3GemL0f=SH0=;BdP3Kfm/0
gMgM0=[JfP3IfMT0emOG0=WIf@3GemL0f=SH0P3Lg=`20=SHf0060=_Kf`3IfMT0f][J0=WIf@3Ogml0
fm_K0`3Jf]X02P3?cll0c/k>0=KFeP3Kfm/0f][J0=_Kf`3Jf]X0fm_K0=SHf03EeMD20=KFeP040=GE
e@3Jf]X0f=SH0=SHf080fMWI00H0fm_K0=KFeP3Kfm/0f][J0=_Kf`3Ph>020=cLg0090=GEe@34a<@0
d=3@0=WIf@3Hf=P0e]KF0=WIf@3Kfm/0f=SH0080dm?C00H0e=CD0=KFeP3IfMT0eMGE0=;BdP3GemL3
0=GEe@060=WIf@3De=@0e=CD0=GEe@3Cdm<0dM7A0P3Fe]H02P3AdM40bl_;0=?Cd`3Ng]h0f][J0=SH
f03IfMT0e]KF0=_Kf`3IfMT20=gMg@040=[JfP3Lg=`0g=cL0=oOg`80gMgM00D0g=cL0=kNgP3MgMd0
g]kN0=oOg`020>7Qh@0>0>3Ph03MgMd0gmoO0=[JfP3Lg=`0f][J0=3@d03Hf=P0g]kN0=_Kf`3MgMd0
h>3P0>7Qh@3Lg=`30=[JfP030=oOg`3Kfm/0g=cL00<0g=cL00<0fm_K0>3Ph03Ph>000P3Ng]h01@3Q
hN40h^;R0>;RhP3Ti>@0h^;R0080fm_K00<0g=cL0=3@d03AdM400P3Lg=`02@3MgMd0gmoO0=kNgP3P
h>00hn?S0>CTi03QhN40g]kN0>3Ph0030>?Sh`030>7Qh@3Shn<0iNGU0080i>CT00@0iNGU0>CTi03S
hn<0i>CT0`3Rh^801@3Vi^H0iNGU0>CTi03Ph>00hn?S0080gmoO00D0i>CT0>?Sh`3Ti>@0inOW0>?S
h`020>GUi@060>OWi`3UiND0inOW0>CTi03Vi^H0h^;R0`3Ti>@40>?Sh`060>7Qh@3Ogml0gMgM0>3P
h03Ogml0i>CT0P3Shn<07P3Rh^80iNGU0>KViP3Shn<0h^;R0>3Ph03UiND0h>3P0>;RhP3Ph>00i>CT
0>;RhP3QhN40h^;R0>?Sh`3Ti>@0h^;R0>7Qh@3Rh^80iNGU0>CTi03QhN40i>CT0>3Ph03QhN40gmoO
0>7Qh@3Vi^H0i>CT0>KViP80i>CT00H0i^KV0>GUi@3YjNT0j>SX0>GUi@3Rh^820>GUi@060=_Kf`3H
f=P0h^;R0>CTi03Shn<0iNGU0P3Shn<02`3Rh^80hn?S0>;RhP3Rh^80hn?S0>;RhP3QhN40g]kN0=oO
g`3Shn<0iNGU00<0hn?S00D0i>CT0>KViP3UiND0iNGU0>?Sh`020>KViP030>GUi@3WinL0inOW0080
hN7Q00L0h^;R0>KViP3WinL0inOW0>SXj03Shn<0h^;R0080i^KV3Oooool0013ooooo00/0gmoO0=[J
fP3MgMd0e=CD0=KFeP3EeMD0fMWI0=_Kf`3IfMT0dm?C0=[JfP020=SHf0050=_Kf`3GemL0eMGE0=KF
eP3Cdm<00P3AdM40503<c<`0e=CD0=SHf03Hf=P0f][J0=WIf@3GemL0f=SH0=GEe@3GemL0fMWI0=[J
fP3Hf=P0eMGE0=?Cd`3Jf]X0e]KF0<k>cP3EeMD0e]KF0P3EeMD30=SHf00@0=WIf@3Hf=P0e]KF0=;B
dP3EeMD0e=CD0=OGe`3Ph>00eMGE0=;BdP3AdM40f=SH0=cLg03Kfm/0g]kN0=cLg080gMgM00L0g=cL
0=SHf03EeMD0fm_K0=WIf@3GemL0f=SH0080emOG00D0eMGE0=KFeP3Cdm<0dM7A0=WIf@020=gMg@03
0=[JfP3Hf=P0fm_K0080g=cL00<0gMgM0=cLg03Hf=P00P3Jf]X01`3Kfm/0emOG0=GEe@3GemL0f=SH
0=OGe`3Hf=P00P3Kfm/00`3Jf]X0f=SH0=WIf@020=[JfP080=KFeP3Hf=P0f=SH0=SHf03Jf]X0fMWI
0=KFeP3GemL20=SHf0050=cLg03Hf=P0clo?0=gMg@3Jf]X00P3GemL20=KFeP050=OGe`3Fe]H0dm?C
0=7Ad@3Fe]H00P3Hf=P02@3Fe]H0f][J0=WIf@3EeMD0e=CD0=KFeP3De=@0d];B0<k>cP020=SHf00:
0=KFeP3De=@0emOG0=OGe`3Jf]X0fm_K0=[JfP3IfMT0fm_K0=SHf080fMWI00H0gmoO0=gMg@3IfMT0
f][J0=cLg03GemL20=7Ad@040<o?c`3IfMT0fm_K0=_Kf`80g=cL00H0fm_K0=GEe@3IfMT0e]KF0=GE
e@3Jf]X20=KFeP0?0=_Kf`3Jf]X0fm_K0=[JfP3IfMT0g=cL0=gMg@3Hf=P0emOG0=;BdP3GemL0fm_K
0=OGe`3Jf]X0gMgM00<0fm_K00D0g=cL0=SHf03GemL0f=SH0=cLg0020=_Kf`0<0=oOg`3Kfm/0f][J
0=[JfP3Ng]h0gMgM0=cLg03MgMd0f][J0=7Ad@3EeMD0f][J0`3Lg=`20=kNgP0=0=_Kf`3Hf=P0f=SH
0=OGe`3Hf=P0fMWI0=OGe`3Hf=P0fm_K0=OGe`3Jf]X0f=SH0=WIf@020=_Kf`080>3Ph03Shn<0gmoO
0=WIf@3=cLd0emOG0=gMg@3Kfm/20=SHf0040=_Kf`3Lg=`0fMWI0=SHf080eMGE0100gMgM0=OGe`3D
e=@0fMWI0=OGe`3Fe]H0fMWI0=[JfP3Hf=P0g=cL0=gMg@3IfMT0dm?C0=;BdP3Fe]H0f][J0P3Bd]80
103Lg=`0g]kN0=kNgP3Ogml20=kNgP040=[JfP3MgMd0gmoO0=_Kf`80gmoO00@0g=cL0=[JfP3Ph>00
gmoO0P3Ng]h01P3QhN40gmoO0>3Ph03Ogml0g=cL0=[JfP<0g]kN00@0h>3P0=?Cd`3Hf=P0fm_K0P3L
g=`0203Ng]h0hN7Q0=cLg03Ng]h0e]KF0=WIf@3Jf]X0g]kN0P3MgMd00`3Ng]h0gmoO0>7Qh@020=kN
gP040=gMg@3Ph>00hN7Q0>;RhP80h>3P00H0g]kN0=oOg`3Ogml0g=cL0<_;b`3AdM420>3Ph0090=oO
g`3QhN40h>3P0>;RhP3QhN40i>CT0>7Qh@3Ti>@0hN7Q0080h^;R0P3UiND0103Shn<0jNWY0>GUi@3U
iND20>KViP070>SXj03Vi^H0h>3P0>?Sh`3Ti>@0hn?S0>CTi0030>?Sh`80h>3P00L0h^;R0>GUi@3V
i^H0inOW0>KViP3WinL0iNGU0080inOW00D0i^KV0>OWi`3Ti>@0i^KV0>SXj0030>KViP<0inOW00H0
i>CT0>?Sh`3Ph>00hn?S0>7Qh@3Vi^H30>GUi@80i^KV00/0i>CT0>GUi@3Ph>00iNGU0>?Sh`3WinL0
iNGU0>OWi`3Shn<0h^;R0>CTi0020>?Sh`0>0>KViP3WinL0j>SX0>GUi@3Ti>@0iNGU0>KViP3Ti>@0
hn?S0>;RhP3Shn<0i>CT0>?Sh`3YjNT20>CTi080jNWY00T0j^[Z0>OWi`3UiND0hn?S0>GUi@3Ti>@0
g]kN0=gMg@3Rh^800P3Ti>@20>KViP050>OWi`3UiND0iNGU0>GUi@3Vi^H00`3UiND0203Rh^80h>3P
0>;RhP3UiND0i^KV0>CTi03Rh^80i^KV0P3WinL0303UiND0hn?S0>GUi@3Vi^H0jNWY0>OWi`3Xj>P0
iNGU0>KViP3UiND0i>CT0>KViP80inOW0P3UiND00`3WinL0hn?Sooooo`0<ooooo`004?ooool0103S
hn<0gMgM0=cLg03GemL20=SHf0030=cLg03Jf]X0g]kN0080fm_K01d0f=SH0=[JfP3MgMd0fMWI0=GE
e@3Fe]H0eMGE0=7Ad@3@d=00dM7A0=CDe03Jf]X0fm_K0=kNgP3Kfm/0f][J0=cLg03IfMT0f][J0=_K
f`3MgMd0fMWI0=cLg03Hf=P0f][J0=GEe@3?cll0d=3@0=GEe@020=CDe0060=_Kf`3Lg=`0f][J0=[J
fP3IfMT0f][J0P3IfMT0703Hf=P0fm_K0>;RhP3De=@0emOG0=?Cd`3Jf]X0g=cL0=kNgP3MgMd0g]kN
0>3Ph03MgMd0fm_K0=KFeP3EeMD0fMWI0=KFeP3GemL0g=cL0=[JfP3IfMT0f=SH0=KFeP3EeMD0d];B
0=cLg03Ng]h20=gMg@030=SHf03Lg=`0gMgM0080g=cL0180gMgM0=WIf@3Jf]X0emOG0=gMg@3IfMT0
f][J0=WIf@3EeMD0e=CD0=OGe`3EeMD0g=cL0=oOg`3Lg=`0f=SH0=WIf@3Fe]H20=SHf00E0=WIf@3J
f]X0f][J0=WIf@3Hf=P0fm_K0=[JfP3MgMd0f][J0=GEe@3?cll0e=CD0=GEe@3Fe]H0f=SH0=OGe`3L
g=`0f][J0=WIf@3Jf]X0eMGE0080fMWI0100fm_K0=[JfP3Jf]X0g=cL0=OGe`3EeMD0e=CD0=?Cd`3E
eMD0bl_;0=WIf@3Jf]X0g]kN0=SHf03Kfm/0f=SH0P3IfMT0203Hf=P0gMgM0=OGe`3Jf]X0e]KF0=OG
e`3Jf]X0fm_K0P3Lg=`01P3Kfm/0emOG0=SHf03Bd]80d=3@0=GEe@80fm_K00/0g=cL0=kNgP3IfMT0
e=CD0=GEe@3GemL0f=SH0=gMg@3Jf]X0emOG0=_Kf`020=[JfP80gMgM00P0h>3P0>7Qh@3Kfm/0fMWI
0=;BdP3IfMT0g]kN0=SHf080g=cL00X0f][J0=kNgP3Ng]h0gmoO0>3Ph03Ogml0g=cL0=kNgP3QhN40
g=cL0P3Jf]X0103MgMd0gmoO0=kNgP3MgMd20=kNgP0<0=cLg03Cdm<0dm?C0=[JfP3Kfm/0gmoO0=cL
g03Ng]h0g=cL0=gMg@3Ogml0gMgM0P3IfMT01@3GemL0fMWI0=SHf03Lg=`0gMgM0080g=cL00<0fm_K
0>3Ph03QhN400P3Rh^805@3Ng]h0g=cL0<o?c`3EeMD0gMgM0>3Ph03Ng]h0fm_K0=cLg03Ng]h0gMgM
0>7Qh@3MgMd0emOG0>3Ph03Kfm/0g=cL0=[JfP3Hf=P0g]kN0=SHf0020=_Kf`090=cLg03MgMd0fm_K
0=SHf03Fe]H0fMWI0=gMg@3EeMD0e=CD0080g]kN00T0h>3P0>?Sh`3Ng]h0h>3P0=gMg@3Kfm/0gMgM
0=WIf@3Ph>000`3Ogml05P3QhN40gmoO0=oOg`3Ph>00hN7Q0=oOg`3Ph>00hN7Q0>3Ph03Ogml0h^;R
0>7Qh@3MgMd0gmoO0=;BdP3IfMT0g]kN0>3Ph03Hf=P0g=cL0>?Sh`3MgMd20=_Kf`060=oOg`3Ng]h0
g=cL0=cLg03Ng]h0g=cL0P3Ng]h0203MgMd0g=cL0=oOg`3Ng]h0gmoO0>7Qh@3Ti>@0hN7Q0P3Ogml0
1@3Ng]h0fMWI0<[:bP3De=@0h^;R00<0hN7Q00d0h^;R0>?Sh`3Ogml0h^;R0=kNgP3Shn<0h>3P0>GU
i@3Rh^80i>CT0>KViP3QhN40i^KV00<0iNGU00@0i^KV0>SXj03UiND0hN7Q0P3Ti>@0303Rh^80hn?S
0>7Qh@3Shn<0h^;R0>?Sh`3Ogml0hN7Q0>?Sh`3UiND0i^KV0>OWi`80i^KV00X0j>SX0>KViP3Vi^H0
hn?S0>CTi03UiND0i>CT0>?Sh`3Ti>@0i^KV0P3UiND02`3WinL0iNGU0>CTi03QhN40i>CT0>?Sh`3V
i^H0i>CT0>3Ph03WinL0i>CT0080iNGU00X0i>CT0=oOg`3Shn<0i^KV0>;RhP3UiND0hn?S0>CTi03P
h>00iNGU0P3Ti>@01`3UiND0inOW0>?Sh`3Ti>@0gmoO0>3Ph03UiND00`3Ti>@02P3Vi^H0iNGU0>?S
h`3Ti>@0i^KV0>CTi03Xj>P0i^KV0>SXj03Ti>@20>KViP090>;RhP3Ng]h0g]kN0=_Kf`3MgMd0h^;R
0>3Ph03QhN40i>CT0080iNGU00D0h^;R0>3Ph03Ph>00h>3P0=gMg@020=kNgP030=SHf03Fe]H0emOG
00<0fMWI00@0gMgM0=[JfP3Hf=P0e]KF0P3Ng]h03`3Jf]X0h^;R0=oOg`3Rh^80gmoO0=kNgP3Shn<0
h>3P0>?Sh`3Ti>@0hn?S0=cLg03Jf]X0g]kN0>3Ph00=ooooo`00ooooooocooooo`00ooooooocoooo
o`00ooooooocooooo`00ooooooocooooo`00ooooooocooooo`00ooooooocooooo`00\
\>"],
  ImageRangeCache->{{{4.9375, 497.625}, {246.875, 0}} -> {-32.6856, -13.0213, \
2.45086, 2.45086}}],

Cell[TextData[{
  "Fig. 7.5 Nonlinear water waves, created in a wave tank at the Ship \
Division of the National Physical Laboratory, England. (Photograph by J. E. \
Frier, in ",
  ButtonBox["T. B. Benjamin (1967)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  ". )"
}], "Caption",
  CellTags->"Fig. 7.5"],

Cell[TextData[{
  " \tOne can see from this photo that real nonlinear waves are even more \
sharply peaked than cnoidal waves. This has to do with the approximate form \
of dispersion used in the KdV equation. Equation ",
  ButtonBox["(7.2.2)",
    ButtonData:>{"Chapter7.nb", "(7.2.2)"},
    ButtonStyle->"Hyperlink"],
  "  is a poor approximation to the exact linear dispersion relation ",
  ButtonBox["(7.2.1)",
    ButtonData:>{"Chapter7.nb", "(7.2.1)"},
    ButtonStyle->"Hyperlink"],
  "  at large wavenumbers, which contribute to the sharp peak. More accurate \
equations that keep the exact linear dispersion can be constructed, and show \
the desired slope discontinuity at the wave peak. [See, for instance,  ",
  ButtonBox["Whitham (1999)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  ".]"
}], "Text"],

Cell[TextData[{
  "\tThe wavelength ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  " is not all that depends on the wave amplitude. The speed ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " of the cnoidal wave also depends on ",
  Cell[BoxData[
      \(TraditionalForm\`a, b\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  ". This can be easily seen by substituting  Eq. ",
  ButtonBox["(7.2.6)",
    ButtonData:>{"Chapter7.nb", "(7.2.6)"},
    ButtonStyle->"Hyperlink"],
  "  into ",
  ButtonBox["(7.2.9)",
    ButtonData:>{"Chapter7.nb", "(7.2.9)"},
    ButtonStyle->"Hyperlink"],
  " . The coefficient of ",
  Cell[BoxData[
      \(TraditionalForm\`f\^2\)]],
  " on the right-hand side of Eq. ",
  ButtonBox["(7.2.9)",
    ButtonData:>{"Chapter7.nb", "(7.2.9)"},
    ButtonStyle->"Hyperlink"],
  "  is ",
  Cell[BoxData[
      \(TraditionalForm\`\(1\/6\) \((a + b + c)\)\)]],
  ", but the coefficient of ",
  Cell[BoxData[
      \(TraditionalForm\`f\^2\)]],
  " on the ",
  "left-hand",
  " side is ",
  Cell[BoxData[
      \(TraditionalForm\`v/2\)]],
  ". Therefore, we find that the wave speed is"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`v = \(1\/3\) \((a + b + c)\)\)]],
  "."
}], "NE2",
  CellTags->"(7.2.16)"],

Cell[TextData[{
  "In the limit of a linear wave oscillating about ",
  Cell[BoxData[
      \(TraditionalForm\`f = 0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`b \[Rule] \ \(a \[Rule] 0\)\)]],
  " and we have ",
  Cell[BoxData[
      \(TraditionalForm\`v \[Rule] \(1\/3\) c\)]],
  ". This is the correct result for the linear wave speed as seen in a frame \
moving at velocity ",
  Cell[BoxData[
      \(TraditionalForm\`c\_o\)]],
  ". In this frame, the linear wave speed is given by ",
  Cell[BoxData[
      \(TraditionalForm\`v = \[Omega]/k - c\_o\)]],
  ". Using Eq. ",
  ButtonBox["(7.2.2)",
    ButtonData:>{"Chapter7.nb", "(7.2.2)"},
    ButtonStyle->"Hyperlink"],
  "  for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  " yields ",
  Cell[BoxData[
      \(TraditionalForm\`v\  = \ \(-c\_\(\(o\)\(\ \)\)\) \(k\^\(\(2\)\(\ \)\)\
\) h\^\(\(2\)\(\ \)\)/6\)]],
  ".  This does not look like ",
  Cell[BoxData[
      \(TraditionalForm\`v = c/3\)]],
  ". However, remember that the wavelength ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda] = 2  \[Pi]/k\)]],
  " for these waves is given by Eq. ",
  ButtonBox["(7.2.15)",
    ButtonData:>{"Chapter7.nb", "(7.2.15)"},
    ButtonStyle->"Hyperlink"],
  "  with ",
  Cell[BoxData[
      \(TraditionalForm\`a = 0\)]],
  ":  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\  = \(\(\@\(\(12\ \[Alpha]\)\/\(-c\)\)\)\(\
\ \ \)\(\[Pi]\)\(\ \)\)\)]],
  ".  Squaring this equation and substituting  ",
  Cell[BoxData[
      \(TraditionalForm\`c = 3\ v\)]],
  " implies that ",
  Cell[BoxData[
      \(TraditionalForm\`v = \(-\[Alpha]\)\ k\^2\)]],
  ", which may be seen to agree with the  linear dispersion relation if we \
recall that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] = c\_o\ h\^2/6\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tAnother important case is the limit ",
  Cell[BoxData[
      \(TraditionalForm\`m \[Rule] \ 1\)]],
  " (i.e. ",
  Cell[BoxData[
      \(TraditionalForm\`b \[Rule] \ c\)]],
  " ). In this limit, the period ",
  Cell[BoxData[
      \(TraditionalForm\`P(m)\)]],
  " of ",
  Cell[BoxData[
      \(TraditionalForm\`sn\)]],
  " approaches infinity [see Eq. ",
  ButtonBox["(7.2.13)",
    ButtonData:>{"Chapter7.nb", "(7.2.13)"},
    ButtonStyle->"Hyperlink"],
  "  and Cell ",
  ButtonBox["7.35",
    ButtonData:>"Cell 7.35",
    ButtonStyle->"Hyperlink"],
  "], and as a result so does the period of the cnoidal waves.  The reason \
for this divergence in the period can be understood by examining motion in \
the potential ",
  Cell[BoxData[
      \(TraditionalForm\`V(f)\)]],
  ". The limit ",
  Cell[BoxData[
      \(TraditionalForm\`b \[Rule] c\)]],
  " corresponds to an energy ",
  Cell[BoxData[
      \(TraditionalForm\`E\)]],
  " for which there is a turning point just at the top of the potential curve \
(Fig. ",
  ButtonBox["7.6",
    ButtonData:>"Fig. 7.6",
    ButtonStyle->"Hyperlink"],
  ")."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.247899 0.112045 0.369262 0.0664776 [
[.02381 .29028 -6 -9 ]
[.02381 .29028 6 0 ]
[.47199 .29028 -3 -9 ]
[.47199 .29028 3 0 ]
[.69608 .29028 -3 -9 ]
[.69608 .29028 3 0 ]
[.92017 .29028 -3 -9 ]
[.92017 .29028 3 0 ]
[1.025 .30278 0 -6 ]
[1.025 .30278 10 6 ]
[.2354 .10335 -12 -4.5 ]
[.2354 .10335 0 4.5 ]
[.2354 .23631 -12 -4.5 ]
[.2354 .23631 0 4.5 ]
[.2354 .36926 -6 -4.5 ]
[.2354 .36926 0 4.5 ]
[.2354 .50222 -6 -4.5 ]
[.2354 .50222 0 4.5 ]
[.2479 .64303 -14 0 ]
[.2479 .64303 14 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30278 m
.02381 .30903 L
s
[(-2)] .02381 .29028 0 1 Mshowa
.47199 .30278 m
.47199 .30903 L
s
[(2)] .47199 .29028 0 1 Mshowa
.69608 .30278 m
.69608 .30903 L
s
[(4)] .69608 .29028 0 1 Mshowa
.92017 .30278 m
.92017 .30903 L
s
[(6)] .92017 .29028 0 1 Mshowa
.125 Mabswid
.07983 .30278 m
.07983 .30653 L
s
.13585 .30278 m
.13585 .30653 L
s
.19188 .30278 m
.19188 .30653 L
s
.30392 .30278 m
.30392 .30653 L
s
.35994 .30278 m
.35994 .30653 L
s
.41597 .30278 m
.41597 .30653 L
s
.52801 .30278 m
.52801 .30653 L
s
.58403 .30278 m
.58403 .30653 L
s
.64006 .30278 m
.64006 .30653 L
s
.7521 .30278 m
.7521 .30653 L
s
.80812 .30278 m
.80812 .30653 L
s
.86415 .30278 m
.86415 .30653 L
s
.97619 .30278 m
.97619 .30653 L
s
.25 Mabswid
0 .30278 m
1 .30278 L
s
gsave
1.025 .30278 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.2479 .10335 m
.25415 .10335 L
s
[(-4)] .2354 .10335 1 0 Mshowa
.2479 .23631 m
.25415 .23631 L
s
[(-2)] .2354 .23631 1 0 Mshowa
.2479 .36926 m
.25415 .36926 L
s
[(0)] .2354 .36926 1 0 Mshowa
.2479 .50222 m
.25415 .50222 L
s
[(2)] .2354 .50222 1 0 Mshowa
.125 Mabswid
.2479 .13659 m
.25165 .13659 L
s
.2479 .16983 m
.25165 .16983 L
s
.2479 .20307 m
.25165 .20307 L
s
.2479 .26955 m
.25165 .26955 L
s
.2479 .33602 m
.25165 .33602 L
s
.2479 .4025 m
.25165 .4025 L
s
.2479 .43574 m
.25165 .43574 L
s
.2479 .46898 m
.25165 .46898 L
s
.2479 .07011 m
.25165 .07011 L
s
.2479 .03687 m
.25165 .03687 L
s
.2479 .00364 m
.25165 .00364 L
s
.2479 .53546 m
.25165 .53546 L
s
.2479 .5687 m
.25165 .5687 L
s
.2479 .60193 m
.25165 .60193 L
s
.25 Mabswid
.2479 0 m
.2479 .61803 L
s
gsave
.2479 .64303 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(V) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(H) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.000 moveto
(L) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ .05 .03 ] 0 setdash
.02381 .36926 m
.06244 .36926 L
.10458 .36926 L
.14415 .36926 L
.18221 .36926 L
.22272 .36926 L
.26171 .36926 L
.30316 .36926 L
.34309 .36926 L
.3815 .36926 L
.42237 .36926 L
.46172 .36926 L
.49955 .36926 L
.53984 .36926 L
.57861 .36926 L
.61984 .36926 L
.65954 .36926 L
.69774 .36926 L
.73838 .36926 L
.77751 .36926 L
.81909 .36926 L
.85916 .36926 L
.89771 .36926 L
.93871 .36926 L
.97619 .36926 L
s
0 0 1 r
[ ] 0 setdash
.02381 .01472 m
.06244 .1369 L
.08255 .18889 L
.10458 .23731 L
.14415 .30347 L
.16372 .32704 L
.18466 .34609 L
.19488 .3532 L
.20597 .35937 L
.21644 .36378 L
.22611 .36667 L
.23076 .36767 L
.23333 .36811 L
.23577 .36847 L
.23804 .36874 L
.2405 .36897 L
.24159 .36905 L
.24275 .36912 L
.24376 .36917 L
.24483 .36921 L
.2455 .36923 L
.24623 .36925 L
.24751 .36926 L
.24823 .36926 L
.249 .36926 L
.24974 .36924 L
.2504 .36923 L
.25169 .36919 L
.25242 .36915 L
.2531 .36912 L
.25565 .36895 L
.25791 .36874 L
.2604 .36845 L
.26546 .36767 L
.27037 .36668 L
.27555 .36538 L
.2848 .36245 L
.30566 .35311 L
.3254 .34112 L
.34377 .32753 L
.38281 .29222 L
.42431 .24771 L
.46429 .20112 L
.50276 .1557 L
.54368 .10982 L
.58308 .07096 L
.62097 .04125 L
.64042 .02976 L
.65126 .02464 L
.66131 .02079 L
Mistroke
.67144 .01781 L
.67679 .01663 L
.67953 .01613 L
.68248 .01567 L
.68532 .01532 L
.68792 .01506 L
.69041 .01488 L
.69166 .01482 L
.69237 .01479 L
.69303 .01476 L
.69428 .01473 L
.69542 .01472 L
.69665 .01472 L
.69734 .01472 L
.69798 .01473 L
.69904 .01476 L
.70021 .01481 L
.70144 .01487 L
.70259 .01494 L
.70503 .01514 L
.7073 .01539 L
.71244 .01617 L
.71746 .01721 L
.72281 .01865 L
.73252 .02213 L
.74132 .02629 L
.76055 .03883 L
.78136 .05811 L
.80127 .08248 L
.82233 .11497 L
.86027 .19234 L
.90066 .30379 L
.93954 .44225 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oF?ooool0
0ol0003oooooooooo`3oooooo`kooooo001Hooooo`;o0000ooooool?ooooo`00F?ooool00ol0003o
ooooooooo`3oooooo`kooooo001Hooooo`03o`000?oooooooooo0?oooooo3_ooool005Sooooo00?o
0000ooooooooool0ooooool>ooooo`004?ooool00ol00?ooooooooooo`15ooooo`03o`000?oooooo
oooo08Kooooo3_l00?miooooo`004?ooool00ol00?ooooooooooo`15ooooo`03o`000?oooooooooo
08Cooooo0_l00?l>ooooo`Co003oMOooool0013ooooo00?o003oooooooooool0AOooool00ol0003o
ooooooooo`20ooooo`Co003o5?ooool2o`00og?ooooo000Aooooo`03o`00oooooooooooo04Cooooo
00?o0000ooooooooool0OOooool3o`00oa[ooooo00?o003oooooooooool0L?ooool0017ooooo00?o
003oooooooooool0A?ooool00ol0003oooooooooo`1looooo`03o`00oooooooooooo01cooooo0_l0
0?m`ooooo`004Oooool00ol00?ooooooooooo`14ooooo`03o`000?oooooooooo07[ooooo0_l00?lQ
ooooo`03o`00oooooooooooo06gooooo000Booooo`03o`00oooooooooooo04?ooooo00?o0000oooo
ooooool0N?ooool2o`00obCooooo0_l00?m]ooooo`004_ooool00ol00?ooooooooooo`13ooooo`;o
0000Moooool2o`00obSooooo00?o003oooooooooool0J_ooool001;ooooo00?o003oooooooooool0
@oooool00ol0003oooooooooo`1dooooo`;o003o:oooool2o`00of[ooooo000Cooooo`03o`00oooo
oooooooo04;ooooo00?o0000ooooooooool0Loooool00ol00?ooooooooooo`0]ooooo`03o`00oooo
oooooooo06Oooooo000Cooooo`03o`00oooooooooooo04;ooooo00?o0000ooooooooool0L_ooool0
0ol00?ooooooooooo`0_ooooo`03o`00oooooooooooo06Kooooo000Cooooo`03o`00oooooooooooo
04;ooooo00?o0000ooooooooool0L?ooool2o`00oc?ooooo00?o003oooooooooool0IOooool001Co
oooo00?o003oooooooooool0@Oooool00ol0003oooooooooo`1_ooooo`03o`00oooooooooooo03Co
oooo00?o003oooooooooool0I?ooool001Cooooo00?o003oooooooooool0@Oooool00ol0003ooooo
ooooo`1^ooooo`03o`00oooooooooooo03Kooooo00?o003oooooooooool0Hoooool001Cooooo00?o
003oooooooooool0@Oooool00ol0003oooooooooo`1]ooooo`03o`00oooooooooooo03Sooooo00?o
003oooooooooool0H_ooool001Cooooo00?o003oooooooooool0@Oooool00ol0003oooooooooo`1[
ooooo`;o003o>oooool00ol00?ooooooooooo`1Rooooo`005Oooool00ol00?ooooooooooo`10oooo
o`03o`000?oooooooooo06[ooooo00?o003oooooooooool0??ooool00ol00?ooooooooooo`1Qoooo
o`005Oooool00ol00?ooooooooooo`10ooooo`03o`000?oooooooooo06Wooooo00?o003ooooooooo
ool0?_ooool00ol00?ooooooooooo`1Pooooo`005Oooool00ol00?ooooooooooo`10ooooo`;o0000
JOooool00ol00?ooooooooooo`10ooooo`03o`00oooooooooooo05oooooo000Fooooo`03o`00oooo
oooooooo03oooooo00?o0000ooooooooool0Ioooool00ol00?ooooooooooo`11ooooo`03o`00oooo
oooooooo05oooooo000Fooooo`03o`00oooooooooooo03oooooo00?o0000ooooooooool0I_ooool0
0ol00?ooooooooooo`13ooooo`03o`00oooooooooooo05kooooo000Fooooo`03o`00oooooooooooo
03oooooo00?o0000ooooooooool0IOooool00ol00?ooooooooooo`15ooooo`03o`00oooooooooooo
05gooooo000Gooooo`03o`00oooooooooooo03kooooo00?o0000ooooooooool0I?ooool00ol00?oo
ooooooooo`17ooooo`03o`00oooooooooooo05cooooo000Gooooo`03o`00oooooooooooo03kooooo
00?o0000ooooooooool0Hoooool00ol00?ooooooooooo`18ooooo`03o`00oooooooooooo05cooooo
000Gooooo`03o`00oooooooooooo03kooooo00?o0000ooooooooool0H_ooool00ol00?oooooooooo
o`1:ooooo`03o`00oooooooooooo05_ooooo000Hooooo`03o`00oooooooooooo03gooooo00?o0000
ooooooooool0HOooool00ol00?ooooooooooo`1<ooooo`03o`00oooooooooooo05[ooooo000Hoooo
o`03o`00oooooooooooo03Cooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo
063ooooo00?o003oooooooooool0COooool00ol00?ooooooooooo`1Jooooo`006?ooool00ol00?oo
ooooooooo`0eooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Goooool00ol00?oo
ooooooooo`1?ooooo`03o`00oooooooooooo05Wooooo000Hooooo`03o`00oooooooooooo02[ooooo
1_l00002ooooo`Go00001_ooool3o`0005kooooo00?o003oooooooooool0DOooool00ol00?oooooo
ooooo`1Hooooo`006Oooool00ol00?ooooooooooo`0aooooo`04odA4A?oMgMgoooooo`0000Oooooo
00?o0000ooooooooool0GOooool00ol00?ooooooooooo`1Cooooo`03o`00oooooooooooo05Oooooo
000Iooooo`03o`00oooooooooooo037ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003ooooo
ooooo`1Looooo`03o`00oooooooooooo05Cooooo00?o003oooooooooool0Eoooool001Wooooo00?o
003oooooooooool0<_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo05cooooo00?o
003oooooooooool0EOooool00ol00?ooooooooooo`1Fooooo`006_ooool00ol00?ooooooooooo`0a
ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0Foooool00ol00?ooooooooooo`1G
ooooo`03o`00oooooooooooo05Gooooo000Jooooo`03o`00oooooooooooo03;ooooo00?oMgMgo`00
0?ooool01_ooool00ol0003oooooooooo`1Jooooo`03o`00oooooooooooo05Sooooo00?o003ooooo
ooooool0EOooool001[ooooo00?o003oooooooooool0>oooool00ol0003oooooooooo`1Iooooo`03
o`00oooooooooooo05[ooooo00?o003oooooooooool0E?ooool001_ooooo00?o003oooooooooool0
>_ooool00ol0003oooooooooo`1Hooooo`03o`00oooooooooooo05_ooooo00?o003oooooooooool0
E?ooool001_ooooo00?o003oooooooooool0>_ooool00ol0003oooooooooo`1Gooooo`03o`00oooo
oooooooo05gooooo00?o003oooooooooool0Doooool001_ooooo00?o003oooooooooool0>_ooool0
0ol0003oooooooooo`1Fooooo`03o`00oooooooooooo05kooooo00?o003oooooooooool0Doooool0
01cooooo00?o003oooooooooool0>Oooool00ol0003oooooooooo`1Eooooo`03o`00oooooooooooo
063ooooo00?o003oooooooooool0D_ooool001cooooo00?o003oooooooooool0>Oooool2o`0005Ko
oooo00?o003oooooooooool0H?ooool00ol00?ooooooooooo`1Booooo`007?ooool00ol00?oooooo
ooooo`0iooooo`03o`000?oooooooooo05Cooooo00?o003oooooooooool0H_ooool00ol00?oooooo
ooooo`1Aooooo`007Oooool00ol00?ooooooooooo`0hooooo`03o`000?oooooooooo05?ooooo00?o
003oooooooooool0Hoooool00ol00?ooooooooooo`1Aooooo`007Oooool00ol00?ooooooooooo`0h
ooooo`03o`000?oooooooooo05;ooooo00?o003oooooooooool0IOooool00ol00?ooooooooooo`1@
ooooo`007Oooool00ol00?ooooooooooo`0hooooo`03o`000?oooooooooo057ooooo00?o003ooooo
ooooool0I_ooool00ol00?ooooooooooo`1@ooooo`007_ooool00ol00?ooooooooooo`0gooooo`03
o`000?oooooooooo053ooooo00?o003oooooooooool0J?ooool00ol00?ooooooooooo`1?ooooo`00
7_ooool00ol00?ooooooooooo`0gooooo`03o`000?oooooooooo04oooooo00?o003oooooooooool0
JOooool00ol00?ooooooooooo`1?ooooo`007oooool00ol00?ooooooooooo`0fooooo`03o`000?oo
oooooooo04oooooo00?o003oooooooooool0JOooool00ol00?ooooooooooo`1?ooooo`007oooool0
0ol00?ooooooooooo`0fooooo`03o`000?oooooooooo04kooooo00?o003oooooooooool0Joooool0
0ol00?ooooooooooo`1>ooooo`008?ooool00ol00?ooooooooooo`0eooooo`03o`000?oooooooooo
04gooooo00?o003oooooooooool0K?ooool00ol00?ooooooooooo`1>ooooo`008?ooool00ol00?oo
ooooooooo`0eooooo`03o`000?oooooooooo04cooooo00?o003oooooooooool0K_ooool00ol00?oo
ooooooooo`1=ooooo`008?ooool00ol00?ooooooooooo`0eooooo`;o0000C?ooool00ol00?oooooo
ooooo`1_ooooo`03o`00oooooooooooo04gooooo000Qooooo`03o`00oooooooooooo03Cooooo00?o
0000ooooooooool0B_ooool00ol00?ooooooooooo`1aooooo`03o`00oooooooooooo04cooooo000Q
ooooo`03o`00oooooooooooo03Cooooo00?o0000ooooooooool0BOooool00ol00?ooooooooooo`1b
ooooo`03o`00oooooooooooo04cooooo000Rooooo`03o`00oooooooooooo03?ooooo00?o0000oooo
ooooool0B?ooool00ol00?ooooooooooo`1dooooo`03o`00oooooooooooo04_ooooo000Rooooo`03
o`00oooooooooooo03?ooooo00?o0000ooooooooool0B?ooool00ol00?ooooooooooo`1dooooo`03
o`00oooooooooooo04_ooooo000Rooooo`03o`00oooooooooooo03?ooooo00?o0000ooooooooool0
Aoooool00ol00?ooooooooooo`1fooooo`03o`00oooooooooooo04[ooooo000Sooooo`03o`00oooo
oooooooo03;ooooo00?o0000ooooooooool0A_ooool00ol00?ooooooooooo`1gooooo`03o`00oooo
oooooooo04[ooooo000Sooooo`03o`00oooooooooooo03;ooooo00?o0000ooooooooool0AOooool0
0ol00?ooooooooooo`1iooooo`03o`00oooooooooooo04Wooooo000Tooooo`03o`00oooooooooooo
037ooooo00?o0000ooooooooool0A?ooool00ol00?ooooooooooo`1jooooo`03o`00oooooooooooo
04Wooooo000Tooooo`03o`00oooooooooooo037ooooo00?o0000ooooooooool0@oooool00ol00?oo
ooooooooo`1looooo`03o`00oooooooooooo04Sooooo000Uooooo`03o`00oooooooooooo033ooooo
0_l00013ooooo`03o`00oooooooooooo07gooooo00?o003oooooooooool0B?ooool002Gooooo00?o
003oooooooooool0<?ooool00ol0003oooooooooo`12ooooo`03o`00oooooooooooo07gooooo00?o
003oooooooooool0B?ooool002Kooooo00?o003oooooooooool0;oooool00ol0003oooooooooo`11
ooooo`03o`00oooooooooooo07oooooo00?o003oooooooooool0Aoooool002Kooooo00?o003ooooo
ooooool0;oooool00ol0003oooooooooo`10ooooo`03o`00oooooooooooo083ooooo00?o003ooooo
ooooool0Aoooool002Oooooo00?o003oooooooooool0;_ooool00ol0003oooooooooo`0oooooo`03
o`00oooooooooooo087ooooo00?o003oooooooooool0Aoooool002Oooooo00?o003oooooooooool0
;_ooool00ol0003oooooooooo`0nooooo`03o`00oooooooooooo08?ooooo00?o003oooooooooool0
A_ooool002Oooooo00?o003oooooooooool0;_ooool00ol0003oooooooooo`0mooooo`03o`00oooo
oooooooo08Cooooo00?o003oooooooooool0A_ooool002Sooooo00?o003oooooooooool0;Oooool0
0ol0003oooooooooo`0looooo`03o`00oooooooooooo08Gooooo00?o003oooooooooool0A_ooool0
02Sooooo00?o003oooooooooool08_ooool5o`0000Kooooo00?o0000ooooooooool0>oooool00ol0
0?ooooooooooo`27ooooo`03o`00oooooooooooo04Gooooo000Yooooo`03o`00oooooooooooo027o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo03_ooooo00?o003ooooo
ooooool0Qoooool00ol00?ooooooooooo`15ooooo`00:Oooool00ol00?ooooooooooo`0Iooooo`Ko
00000oooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo03[ooooo00?o003ooooooooo
ool0ROooool00ol00?ooooooooooo`14ooooo`00:_ooool00ol00?ooooooooooo`0Rooooo`03oiRH
V?lQ8B7ok^k^00Kooooo0ol0000iooooo`03o`00oooooooooooo08[ooooo00?o003oooooooooool0
A?ooool002[ooooo00?o003oooooooooool08oooool00omgMgOoIVIVooooo`05ooooo`03o`000?oo
oooooooo03Sooooo00?o003oooooooooool0Roooool00ol00?ooooooooooo`14ooooo`00:oooool0
0ol00?ooooooooooo`0Sooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=oooool0
0ol00?ooooooooooo`2=ooooo`03o`00oooooooooooo04?ooooo000[ooooo`03o`00oooooooooooo
01oooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo03Kooooo00?o003o
ooooooooool0S_ooool00ol00?ooooooooooo`13ooooo`00;?ooool00ol00?ooooooooooo`0Noooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0eooooo`03o`00oooooooo
oooo08oooooo00?o003oooooooooool0@oooool002gooooo00?o003oooooooooool0:?ooool00ol0
003oooooooooo`0eooooo`03o`00oooooooooooo093ooooo00?o003oooooooooool0@_ooool002go
oooo00?o003oooooooooool0:?ooool00ol0003oooooooooo`0dooooo`03o`00oooooooooooo097o
oooo00?o003oooooooooool0@_ooool002kooooo00?o003oooooooooool09oooool00ol0003ooooo
ooooo`0cooooo`03o`00oooooooooooo09;ooooo00?o003oooooooooool0@_ooool0017ooooo1Ol0
000Hooooo`03o`00oooooooooooo02Oooooo00?o0000ooooooooool0<_ooool00ol00?oooooooooo
o`0=ooooo`Go0000AOooool2o`000003oa0@4?oooooooooo03Sooooo00?o003oooooooooool01_oo
ool01Oo^k^ko<S8bo`000?l@413oc<c<03Kooooo000Aooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
6Oooool00ol00?ooooooooooo`0Vooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0
3_ooool01OnHV9So8B4Qonk^k_ooooooA4A404Kooooo00?o0000ooooooooool0>Oooool00ol00?oo
ooooooooo`06ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40=_ooool000Wooooo1_l00003ooooo`03
oiRHV?lQ8B7ok^k^01_ooooo00?o003oooooooooool09Oooool00ol0003oooooooooo`0`ooooo`03
o`00oooooooooooo013ooooo00?oV9RHob4Q8Oo^k^h0A?ooool5o`0003[ooooo00?o003ooooooooo
ool01_ooool01Ol0003ooooooooooooooooo000003Kooooo000Cooooo`03oiRHV?lQ8B7ok^k^01[o
oooo00?o003oooooooooool09Oooool2o`00033ooooo00?o003oooooooooool04_ooool00onHV9So
8B4Qonk^kP13ooooo`04odA4A?oMgMgoooooo`0003cooooo00?o003oooooooooool01Oooool01Ol0
003oV9RHoooooonHV9So8B4Q03Kooooo000Dooooo`03ogMgMomVIVKooooo01[ooooo00?o003ooooo
ooooool09?ooool00ol0003oooooooooo`0^ooooo`03o`00oooooooooooo01Cooooo00?oMgMgofIV
I_ooool0@_ooool01?oMgMgoEEEEooooool0000looooo`03o`00oooooooooooo00Gooooo00Go0000
oeEEEOl0003o410@olc<c00fooooo`005Oooool00ol0003oooooooooo`0Iooooo`03o`00oooooooo
oooo02Cooooo00?o0000ooooooooool0;Oooool00ol00?ooooooooooo`0Fooooo`03o`000?oooooo
oooo04;ooooo00?oMgMgolc<c?l00000?Oooool00ol00?ooooooooooo`04ooooo`03oeEEEOn7QhOo
oooo03Sooooo000Aooooo`05o`000?nj^[[ooooooiRHV?l@41007?ooool00ol00?ooooooooooo`0S
ooooo`03o`000?oooooooooo02cooooo00?o003oooooooooool04oooool01Ol0003o^[ZjoooooonH
V9So410@04Cooooo00?ok^k^odA4A?l00000?Oooool00ol00?ooooooooooo`04ooooo`03omgMgOl@
413oV9RH03Sooooo000Aooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`07Oooool00ol00?oooooooooo
o`0Rooooo`03o`000?oooooooooo02_ooooo00?o003oooooooooool05?ooool01OnHV9So410@o`00
0?lQ8B7oc<c<04Gooooo00?oMgMgo`000?ooool0??ooool00ol00?ooooooooooo`05ooooo`04olc<
c?m4A4Co0000oa0@43Kooooo000cooooo`03o`00oooooooooooo02;ooooo00?o0000ooooooooool0
:_ooool00ol00?ooooooooooo`2Oooooo`03o`00oooooooooooo03kooooo000dooooo`03o`00oooo
oooooooo027ooooo00?o0000ooooooooool0:Oooool00ol00?ooooooooooo`2Pooooo`03o`00oooo
oooooooo03kooooo000dooooo`03o`00oooooooooooo027ooooo00?o0000ooooooooool09oooool2
o`00oj?ooooo00?o003oooooooooool0?_ooool003Gooooo00?o003oooooooooool08?ooool00ol0
003oooooooooo`0Vooooo`03o`00oooooooooooo0:Cooooo00?o003oooooooooool0:_ooool00ol@
413o0000o`000002o`000003oa0@4?oooooooooo00_ooooo000fooooo`03o`00oooooooooooo01oo
oooo00?o0000ooooooooool09Oooool00ol00?ooooooooooo`2Uooooo`03o`00oooooooooooo02co
oooo00?o0000ooooooooool03_ooool000Sooooo;_l000000ol00?oo0000o`000016o`000003o`00
ool0003o00000:Ko000000?o003oo`000?l000007ol0000=ooooo`03o`000?oooooooooo00kooooo
000@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool01?l0003ooooooooo
ool00?l>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooo003o00oooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool01?ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03_ooool0013ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooo`00o`kooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo
00?o0000o`00ooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool02?ooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0>ooooo`00>?ooool00ol00?oooooooooo
o`0Mooooo`03o`000?oooooooooo027ooooo00?o003oooooooooool0Z_ooool00ol00?oooooooooo
o`0Yooooo`03oa0@4?l0003o000000?o00003Oooool003Wooooo00?o003oooooooooool07?ooool0
0ol0003oooooooooo`0Pooooo`03o`00oooooooooooo0:cooooo00?o003oooooooooool0:_ooool0
0ol0003oooooooooo`0>ooooo`00>_ooool00ol00?ooooooooooo`0Kooooo`03o`000?oooooooooo
01oooooo00?o003oooooooooool0[Oooool00ol00?ooooooooooo`0Zooooo`03oa0@4?nj^[[ooooo
00kooooo000kooooo`03o`00oooooooooooo01[ooooo00?o0000ooooooooool07_ooool00ol00?oo
ooooooooo`2^ooooo`03o`00oooooooooooo02[ooooo00Co^[Zjoa0@4?l0003o410@3Oooool003co
oooo00?o003oooooooooool06Oooool00ol0003oooooooooo`0Mooooo`03o`00oooooooooooo0;3o
oooo00?o003oooooooooool0>_ooool003gooooo0_l00?lIooooo`03o`000?oooooooooo01_ooooo
0_l00?ncooooo`03o`00oooooooooooo03[ooooo000oooooo`03o`00oooooooooooo01Kooooo00?o
0000ooooooooool06_ooool00ol00?ooooooooooo`2cooooo`03o`00oooooooooooo03[ooooo0010
ooooo`03o`00oooooooooooo01Gooooo00?o0000ooooooooool06Oooool00ol00?ooooooooooo`2e
ooooo`03o`00oooooooooooo03Wooooo0011ooooo`03o`00oooooooooooo01Cooooo0_l0000Ioooo
o`03o`00oooooooooooo0;Kooooo00?o003oooooooooool0>Oooool004;ooooo00?o003ooooooooo
ool04oooool00ol0003oooooooooo`0Gooooo`03o`00oooooooooooo0;Oooooo00?o003ooooooooo
ool0>Oooool004?ooooo00?o003oooooooooool04_ooool00ol0003oooooooooo`0Eooooo`;o003o
^_ooool00ol00?ooooooooooo`0iooooo`00A?ooool2o`00oa;ooooo00?o0000ooooooooool04_oo
ool3o`00okgooooo00?o003oooooooooool0>?ooool004Kooooo00?o003oooooooooool03oooool0
0ol0003oooooooooo`0@ooooo`;o003o`?ooool00ol00?ooooooooooo`0hooooo`00Aoooool2o`00
o`oooooo00?o0000ooooooooool03_ooool2o`00ol;ooooo00?o003oooooooooool0>?ooool004Wo
oooo00?o003oooooooooool03?ooool00ol0003oooooooooo`0<ooooo`;o003oaOooool00ol00?oo
ooooooooo`0gooooo`00B_ooool2o`00o`cooooo00?o0000ooooooooool02_ooool2o`00olOooooo
00?o003oooooooooool0=oooool004cooooo0_l00?l01?lb<S;o0000oc8b<_o^k^h6ooooo`03o`00
0?oooooooooo00Sooooo0_l00?o9ooooo`03o`00oooooooooooo03Oooooo001=ooooo`05ogMgMol0
0?oo003oo`00oomgMgL01_ooool00ol0003oooooooooo`05ooooo`?o003oboooool00ol00?oooooo
ooooo`0gooooo`00COooool01?l@413oooooooooooooool5o`00o`;ooooo00?o0000ooooooooool0
1Ol00?o?ooooo`03o`00oooooooooooo03Kooooo000@oooooa7oo`002OoooolAool000Sooooo4Ooo
00000ooooooo003oo`00o`04o`00o`;ooooo4Ooo0009oooooa7oo`002?oooolAool000Wooooo4Ooo
0009oooooa7oo`002?oooolAool000Wooooo4Ooo0009oooooa7oo`002?ooool5ool00003o`00oooo
003oo`0000Woo`00;Oooool004gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo0=Cooooo00?o003oooooooooool0=_ooool004gooooo00Go410@oooooooooooooooooa0@
4006ooooo`03o`000?oooooooooo0=Gooooo00?o003oooooooooool0=Oooool004gooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0=Gooooo00?o003oooooooooool0=Ooo
ool004gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0=Gooooo00?o
003oooooooooool0=Oooool005Sooooo00?o0000ooooooooool0e_ooool00ol00?ooooooooooo`0d
ooooo`00F?ooool00ol0003oooooooooo`3Fooooo`03o`00oooooooooooo03Cooooo001Hooooo`03
o`000?oooooooooo0=Kooooo00?o003oooooooooool0=?ooool005Sooooo00?o0000ooooooooool0
e_ooool00ol00?ooooooooooo`0dooooo`00F?ooool00ol0003oooooooooo`3Gooooo`03o`00oooo
oooooooo03?ooooo001Hooooo`;o0000f?ooool00ol00?ooooooooooo`0cooooo`00F?ooool00ol0
003oooooooooo`3Gooooo`03o`00oooooooooooo03?ooooo001Hooooo`03o`000?oooooooooo0=So
oooo00?o003oooooooooool0<_ooool005Sooooo00?o0000ooooooooool0f?ooool00ol00?oooooo
ooooo`0booooo`00F?ooool00ol0003oooooooooo`3Hooooo`03o`00oooooooooooo03;ooooo001H
ooooo`03o`000?oooooooooo0=Sooooo00?o003oooooooooool0<_ooool005Sooooo00?o0000oooo
ooooool0fOooool00ol00?ooooooooooo`0aooooo`00F?ooool00ol0003oooooooooo`3Iooooo`03
o`00oooooooooooo037ooooo001Hooooo`03o`000?oooooooooo0=Wooooo00?o003oooooooooool0
<Oooool005Sooooo00?o0000ooooooooool0f_ooool00ol00?ooooooooooo`0`ooooo`00F?ooool0
0ol0003oooooooooo`3Jooooo`03o`00oooooooooooo033ooooo001Hooooo`;o0000foooool00ol0
0?ooooooooooo`0`ooooo`00F?ooool00ol0003oooooooooo`3Kooooo`03o`00oooooooooooo02oo
oooo001Hooooo`03o`000?oooooooooo0=_ooooo00?o003oooooooooool0;oooool005Sooooo00?o
0000ooooooooool0foooool00ol00?ooooooooooo`0_ooooo`00F?ooool00ol0003oooooooooo`3K
ooooo`03o`00oooooooooooo02oooooo001Hooooo`03o`000?oooooooooo0=cooooo00?o003ooooo
ooooool0;_ooool005Sooooo00?o0000ooooooooool0g?ooool00ol00?ooooooooooo`0^ooooo`00
F?ooool00ol0003oooooooooo`3Looooo`03o`00oooooooooooo02kooooo001Hooooo`03o`000?oo
oooooooo0=cooooo00?o003oooooooooool0;_ooool005Sooooo00?o0000ooooooooool0gOooool0
0ol00?ooooooooooo`0]ooooo`00F?ooool00ol0003oooooooooo`3Mooooo`03o`00oooooooooooo
02gooooo001Hooooo`;o0000g_ooool00ol00?ooooooooooo`0]ooooo`00F?ooool00ol0003ooooo
ooooo`3Mooooo`03o`00oooooooooooo02gooooo001Hooooo`03o`000?oooooooooo0=gooooo00?o
003oooooooooool0;Oooool005Sooooo00?o0000ooooooooool0g_ooool00ol00?ooooooooooo`0/
ooooo`00F?ooool00ol0003oooooooooo`3Nooooo`03o`00oooooooooooo02cooooo001Hooooo`03
o`000?oooooooooo0=kooooo00?o003oooooooooool0;?ooool005Sooooo00?o0000ooooooooool0
g_ooool00ol00?ooooooooooo`0/ooooo`00F?ooool00ol0003oooooooooo`3Oooooo`03o`00oooo
oooooooo02_ooooo001=ooooo`Go00001_ooool00ol0003oooooooooo`3Oooooo`03o`00oooooooo
oooo02_ooooo001=ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`3O
ooooo`03o`00oooooooooooo02_ooooo001>ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003Ooooo
o`03o`00oooooooooooo02_ooooo001?ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000oooooooo
ool0h?ooool00ol00?ooooooooooo`0Zooooo`00D?ooool00omgMgOoIVIVooooo`05ooooo`03o`00
0?oooooooooo0>3ooooo00?o003oooooooooool0:_ooool0057ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`3Pooooo`03o`00oooooooooooo02[ooooo001=ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3Pooooo`03o`00oooooooooooo02[ooooo001=
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3Pooooo`03o`00oooo
oooooooo02[ooooo001Hooooo`03o`000?oooooooooo0>7ooooo00?o003oooooooooool0:Oooool0
05Sooooo00?o0000ooooooooool0hOooool00ol00?ooooooooooo`0Yooooo`00F?ooool00ol0003o
ooooooooo`3Qooooo`03o`00oooooooooooo02Wooooo001Hooooo`03o`000?oooooooooo0>7ooooo
00?o003oooooooooool0:Oooool005Sooooo00?o0000ooooooooool0h_ooool00ol00?oooooooooo
o`0Xooooo`00F?ooool2o`000>?ooooo00?o003oooooooooool0:?ooool005Sooooo00?o0000oooo
ooooool0h_ooool00ol00?ooooooooooo`0Xooooo`00F?ooool00ol0003oooooooooo`3Rooooo`03
o`00oooooooooooo02Sooooo001Hooooo`03o`000?oooooooooo0>?ooooo00?o003oooooooooool0
9oooool005Sooooo00?o0000ooooooooool0hoooool00ol00?ooooooooooo`0Wooooo`00F?ooool0
0ol0003oooooooooo`3Sooooo`03o`00oooooooooooo02Oooooo001Hooooo`03o`000?oooooooooo
0>?ooooo00?o003oooooooooool09oooool005Sooooo00?o0000ooooooooool0hoooool00ol00?oo
ooooooooo`0Wooooo`00F?ooool00ol0003oooooooooo`3Tooooo`03o`00oooooooooooo02Kooooo
001Hooooo`03o`000?oooooooooo0>Cooooo00?o003oooooooooool09_ooool005Sooooo00?o0000
ooooooooool0i?ooool00ol00?ooooooooooo`0Vooooo`00F?ooool2o`000>Gooooo00?o003ooooo
ooooool09_ooool005Sooooo00?o0000ooooooooool0iOooool00ol00?ooooooooooo`0Uooooo`00
F?ooool00ol0003oooooooooo`3Uooooo`03o`00oooooooooooo02Gooooo001Hooooo`03o`000?oo
oooooooo0>Gooooo00?o003oooooooooool09Oooool005Sooooo00?o0000ooooooooool0iOooool0
0ol00?ooooooooooo`0Uooooo`00F?ooool00ol0003oooooooooo`3Vooooo`03o`00oooooooooooo
02Cooooo001Hooooo`03o`000?oooooooooo0>Kooooo00?o003oooooooooool09?ooool005Sooooo
00?o0000ooooooooool0i_ooool00ol00?ooooooooooo`0Tooooo`00F?ooool00ol0003ooooooooo
o`3Vooooo`03o`00oooooooooooo02Cooooo001Hooooo`03o`000?oooooooooo0>Kooooo00?o003o
ooooooooool09?ooool005Sooooo0_l0003Xooooo`03o`00oooooooooooo02?ooooo001Hooooo`03
o`000?oooooooooo0>Oooooo00?o003oooooooooool08oooool005Sooooo00?o0000ooooooooool0
ooooool>ooooo`00F?ooool00ol0003oooooooooo`3oooooo`kooooo001Hooooo`03o`000?oooooo
oooo0?oooooo3_ooool005Sooooo00?o0000ooooooooool0ooooool>ooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00EOooool00omgMgOo
IVIVooooo`08ooooo`03ofIVI_mgMgOooooo0?oooooo1_ooool005Cooooo00?ogMgMoa0@4?o^k^h0
2Oooool00oo^k^ko410@omgMg@3oooooo`Kooooo001<ooooo`;o<S8b1_ooool00omEEEGoV9RHoooo
o`02ooooo`03oa0@4?l0003o000000;o000000Go410@ooooooooooooQhN7ofIVIP3oooooo`Kooooo
001;ooooo`04omgMgOl@413o410@olc<c0Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03onk^k_l0003ooooo0?oooooo1Oooool004_ooooo0_mVIVH00omgMgOoIVIVoooo
o`04ooooo`03oc8b<_oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`3oooooo`Cooooo001;ooooo`04o`000?oMgMgogMgMo`0000Gooooo00?o<S8booooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo1?ooool004[ooooo00KoV9RH
oc8b<_oooooooooooc8b<_nHV9P4ooooo`03o`000?o^k^kooooo00Cooooo00?o0000ooooooooool0
0oooool00oo^k^ko0000ooooo`3oooooo`Gooooo001:ooooo`06odA4A?nHV9SooooooooooonHV9So
A4A41?ooool00omEEEGoMgMgooooo`02ooooo`03oa0@4?l0003o000000?o00000_ooool00omgMgOo
EEEEooooo`3oooooo`Gooooo0019ooooo`03omgMgOl0003ooooo00?ooooo00?o0000omgMgOooool0
0_ooool00ooMgMgo410@onk^kP04ooooo`03o`000?oooooooooo00;ooooo00?ok^k^oa0@4?oMgMd0
ooooool6ooooo`00BOooool3o`0000;ooooo0ol00004ooooo`03ogMgMomVIVKooooo00?ooooo00?o
410@okZj^_ooool00_ooool00omVIVKoMgMgooooo`3oooooo`Kooooo001Kooooo`04okZj^_l@413o
0000oa0@4?oooooo2_ooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-2.45636, -5.55473, \
0.0347613, 0.0585886}}],

Cell[TextData[{
  "Fig. 7.6 Potential ",
  Cell[BoxData[
      \(TraditionalForm\`V(f)\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`v = 2, \ \ A = 0\)]],
  " (solid), and energy ",
  Cell[BoxData[
      \(TraditionalForm\`E\)]],
  "(dashed) for which a soliton solution exists."
}], "Caption",
  CellTags->"Fig. 7.6"],

Cell["\<\
Particles that start with zero velocity at the top of the hill take \
an infinitely long time to fall down the slope, which is why the period of \
the oscillatory motion goes to infinity for this energy. \
\>", "Text"],

Cell[TextData[{
  "\tSince the period of the motion is infinite, the wave peaks becomes \
infinitely separated, resulting in a single isolated peak. This peak is \
called a ",
  StyleBox["soliton, ",
    FontSlant->"Italic"],
  "or",
  StyleBox[" solitary wave.",
    FontSlant->"Italic"],
  " in Cell ",
  ButtonBox["7.38",
    ButtonData:>"Cell 7.38",
    ButtonStyle->"Hyperlink"],
  ", we plot the case of a soliton of unit amplitude (",
  Cell[BoxData[
      \(TraditionalForm\`a = 1\)]],
  ") for which ",
  Cell[BoxData[
      \(TraditionalForm\`f \[Rule] 0\)]],
  " at large ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  " (i.e. ",
  Cell[BoxData[
      \(TraditionalForm\`c \[Rule] \ \(b \[Rule] \ 0\)\)]],
  "). "
}], "Text",
  CellTags->"i:30"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[f[s, 1, 0, 0], {s, \(-20\), 20}, 
        PlotLabel \[Rule] "\<m =\>" <> ToString[1] <> "\<(soliton)\>", 
        AxesLabel \[Rule] \ {\*"\"\<s/\!\(\@\[Alpha]\)\>\"", "\<\>"}, 
        PlotRange \[Rule] {\(- .2\), 1}\ ];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.38"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0238095 0.103006 0.515028 [
[.02381 .09051 -9 -9 ]
[.02381 .09051 9 0 ]
[.2619 .09051 -9 -9 ]
[.2619 .09051 9 0 ]
[.7381 .09051 -6 -9 ]
[.7381 .09051 6 0 ]
[.97619 .09051 -6 -9 ]
[.97619 .09051 6 0 ]
[1.025 .10301 0 -6.71875 ]
[1.025 .10301 32.5625 6.71875 ]
[.4875 0 -24 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -41.0625 0 ]
[.5 .63053 41.0625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .10301 m
.02381 .10926 L
s
[(-20)] .02381 .09051 0 1 Mshowa
.2619 .10301 m
.2619 .10926 L
s
[(-10)] .2619 .09051 0 1 Mshowa
.7381 .10301 m
.7381 .10926 L
s
[(10)] .7381 .09051 0 1 Mshowa
.97619 .10301 m
.97619 .10926 L
s
[(20)] .97619 .09051 0 1 Mshowa
.125 Mabswid
.07143 .10301 m
.07143 .10676 L
s
.11905 .10301 m
.11905 .10676 L
s
.16667 .10301 m
.16667 .10676 L
s
.21429 .10301 m
.21429 .10676 L
s
.30952 .10301 m
.30952 .10676 L
s
.35714 .10301 m
.35714 .10676 L
s
.40476 .10301 m
.40476 .10676 L
s
.45238 .10301 m
.45238 .10676 L
s
.54762 .10301 m
.54762 .10676 L
s
.59524 .10301 m
.59524 .10676 L
s
.64286 .10301 m
.64286 .10676 L
s
.69048 .10301 m
.69048 .10676 L
s
.78571 .10301 m
.78571 .10676 L
s
.83333 .10301 m
.83333 .10676 L
s
.88095 .10301 m
.88095 .10676 L
s
.92857 .10301 m
.92857 .10676 L
s
.25 Mabswid
0 .10301 m
1 .10301 L
s
gsave
1.025 .10301 -61 -10.7188 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.4375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 14.438 moveto
(\\220) show
0.000 0.000 0.000 setrgbcolor
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 9.062 moveto
(\\217) show
83.188 9.062 moveto
(!!) show
88.000 9.062 moveto
(!) show
83.562 14.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
91.562 14.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.50625 0 L
s
[(-0.2)] .4875 0 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.4)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.6)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.8)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -102.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
75.125 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
81.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.125 13.000 moveto
(H) show
93.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(soliton) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
135.125 13.000 moveto
(L) show
141.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .10303 m
.03279 .10303 L
.04262 .10304 L
.05288 .10305 L
.06244 .10306 L
.0731 .10307 L
.0828 .10309 L
.094 .10311 L
.10458 .10315 L
.11428 .10318 L
.12455 .10323 L
.13333 .10329 L
.14299 .10336 L
.15313 .10346 L
.1624 .10358 L
.17311 .10375 L
.18328 .10396 L
.19287 .10421 L
.20309 .10454 L
.22147 .1054 L
.23176 .10608 L
.24289 .10703 L
.25339 .10819 L
.26306 .10955 L
.28188 .1133 L
.29257 .1163 L
.30254 .11988 L
.313 .12465 L
.3229 .13036 L
.34145 .14526 L
.35111 .15581 L
.36136 .16973 L
.37978 .20347 L
.38915 .22586 L
.39925 .25455 L
.41753 .31935 L
.43718 .40573 L
.45867 .50765 L
.4686 .55004 L
.47405 .57024 L
.4792 .58662 L
.484 .59913 L
.48653 .60454 L
.48921 .60931 L
.49146 .61255 L
.49265 .61397 L
.49394 .61526 L
.49511 .61623 L
.49619 .61694 L
.49727 .61747 L
Mistroke
.4983 .61781 L
.49955 .61802 L
.50025 .61803 L
.5009 .61797 L
.50209 .6177 L
.50334 .61719 L
.50447 .61653 L
.50552 .61573 L
.50791 .61333 L
.5105 .60978 L
.51285 .60573 L
.51814 .5939 L
.5276 .56442 L
.53654 .52883 L
.57492 .35077 L
.59435 .27533 L
.60466 .24285 L
.61576 .21364 L
.62635 .19083 L
.63605 .17374 L
.64591 .15955 L
.65508 .1488 L
.67404 .13241 L
.68406 .12621 L
.69475 .121 L
.70502 .11709 L
.71614 .1138 L
.72664 .11139 L
.7363 .10965 L
.74537 .10835 L
.7551 .10723 L
.76578 .10627 L
.77576 .10557 L
.78592 .10501 L
.79697 .10454 L
.80742 .1042 L
.81709 .10395 L
.82605 .10376 L
.83573 .10361 L
.84635 .10347 L
.85632 .10337 L
.86588 .10329 L
.87634 .10323 L
.88726 .10318 L
.89743 .10314 L
.90793 .10311 L
.91786 .10309 L
.93644 .10306 L
.94615 .10305 L
.95643 .10304 L
Mistroke
.97488 .10303 L
.97619 .10303 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{315.562, 195.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006:0000lb000`400?l00000o`00003ooooooon;
ooooo`00oooooon;ooooo`00oooooon;ooooo`00oooooon;ooooo`00oooooon;ooooo`00oooooon;
ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000hoooool0
09;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A40>?ooooo002:ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h0i?ooool009;ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ
8B7ok^k^00Kooooo0ol0003Jooooo`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool01Oooool00ol0003oooooooooo`3Jooooo`00T_ooool01Ol@413ooooooooooooo
oooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3Jooooo`00T_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`00
0?oooooooooo0=[ooooo002Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@
o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0f_ooool00:gooooo00?o0000ooooooooool0
f_ooool00:gooooo00?o0000ooooooooool0f_ooool00:gooooo00?o0000ooooooooool0f_ooool0
0:gooooo00?o0000ooooooooool0f_ooool00:gooooo0_l0003Kooooo`00[Oooool00ol0003ooooo
ooooo`3Jooooo`00[Oooool00ol0003oooooooooo`3Jooooo`00[Oooool00ol0003oooooooooo`3J
ooooo`00[Oooool00ol0003oooooooooo`3Jooooo`00[Oooool00ol0003oooooooooo`3Jooooo`00
[Oooool00ol0003oooooooooo`3Jooooo`00[Oooool00ol0003oooooooooo`3Jooooo`00[Oooool2
o`000=_ooooo002]ooooo`03o`000?oooooooooo0=[ooooo002]ooooo`03o`000?oooooooooo0=[o
oooo002]ooooo`03o`000?oooooooooo0=[ooooo002]ooooo`03o`000?oooooooooo0=[ooooo0008
ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^04Gooooo1?l000002?l@413ooooooooo
ooo^k^ko<S8bo`000?lb<S;ok^k^Aoooool00ol0003oooooooooo`18ooooo`Co000000So410@oooo
ooooooook^k^oc8b<_l0003o<S8bonk^kTGooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h0=?ooool000Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL0Aoooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Aoooool0
0ol0003oooooooooo`1:ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`15ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Co
oooo0006o`0000?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@03co
oooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4017oooo
o`03o`000?oooooooooo04[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@04Kooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@03Cooooo000:
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000017ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000017ooooo`03o`000?oooooooooo04[ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000004Oooooo00?oV9RHob4Q8Oo^
k^h00oooool01Ol0003ooooooooooooooooo000003Cooooo000;ooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`000017ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000017ooooo`;o0000Boooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000B?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000
=?ooool000cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo04Gooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@04Oooooo00?o0000oooooooo
ool0B_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100BOooool01Ol0
003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0<_ooool000Sooooo00Go0000okZj
^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Aoooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Aoooool00ol0003oooooooooo`1:ooooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`15ooooo`05o`000?nj^[[ooooooiRH
V?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Cooooo0008ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^04Gooooo00?oEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^04Oooooo00?o0000ooooooooool0B?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0AOooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`03oiRHV?oooooooooo013ooooo002]oooo
o`03o`000?oooooooooo0;cooooo00?o8B4QomgMgOooool01oooool00oo^k^ko0000olc<c00Aoooo
o`00[Oooool00ol0003oooooooooo`2dooooo`06oa0@4?lb<S;o0000o`000?l@413oZJVY0_ooool0
0onHV9SoEEEEooooo`07ooooo`03ogMgMol0003oIVIV00Cooooo00OoV9RHo`000?l0003oEEEEonk^
k_mVIVKo000000Kooooo002]ooooo`03o`000?oooooooooo0;Cooooo00Ko0000ojVYZOoooooooooo
okZj^_l00003ooooo`03o`000?oMgMgooooo00Gooooo00Cok^k^o`000?nHV9So8B4Q1?ooool01_l0
003oZJVYoooooon7QhOo<S8bofIVIPOooooo002]ooooo`03o`000?oooooooooo0;Gooooo00Go^[Zj
ohN7QomVIVKoIVIVoa0@4003ooooo`;oMgMg1_ooool01OmgMgOoEEEEooooool0003ogMgM00?ooooo
00Ko0000ooooooooooooooooohN7Qom4A4@7ooooo`00[Oooool00ol0003oooooooooo`2dooooo`06
oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^0oooool00oo^k^ko410@onk^kP05ooooo`05o`000?o<c<co
oooooeEEEOn7QhL00oooool01_lQ8B7oc<c<ooooooooooooV9RHoc8b<POooooo0003oooooooo0000
Eol0000;ooooo`06o`000?nj^[[oooooonk^k_mgMgOo00001?ooool00omEEEGoV9RHooooo`02oooo
o`03oc8b<_mEEEGo<S8b00;ooooo00?oZJVYob4Q8Oooool00_ooool01onYZJWo8B4QomgMgOo^k^ko
<S8boeEEEOnj^[X01_ooool000_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02OoooolAo`0000Cooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`02oooooa7o00002oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0A
ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o00001?ooool00ooMgMgo410@ooooo`02ooooo`03okZj
^_lb<S;o^[Zj00?ooooo00?o0000omgMgOooool00_ooool01_nHV9So0000o`000?nHV9So^[Zjoc8b
<PKooooo000;ooooo`03o`000?oooooooooo04[ooooo1ol0001>ooooo`03o`000?oooooooooo04co
oooo1ol0001=ooooo`03o`000?oooooooooo01cooooo00?oEEEEoiRHV?ooool01oooool00omEEEGo
QhN7ooooo`0>ooooo`00Goooool3o`0004_ooooo00?o0000ooooooooool0BOooool3o`0007?ooooo
00?o^[ZjodA4A?ooool01oooool00onYZJWo<S8booooo`0>ooooo`00H_ooool4o`0004Oooooo00?o
0000ooooooooool0AOooool4o`00083ooooo00?ok^k^o`000?o^k^h03_ooool006Kooooo0ol00014
ooooo`03o`000?oooooooooo04;ooooo0ol00025ooooo`03odA4A?nHV9Sooooo00gooooo001Yoooo
o`Co0000@?ooool00ol0003oooooooooo`0oooooo`?o0000R?ooool00onHV9SoA4A4ooooo`0=oooo
o`00KOooool2o`0003kooooo00?o0000ooooooooool0?Oooool2o`0008_ooooo00?ok^k^o`000?l0
00002Ol00004ooooo`00Koooool2o`0003cooooo00?o0000ooooooooool0>oooool2o`0009gooooo
001aooooo`;o0000>_ooool2o`0003_ooooo00?o0000ooooooooool0WOooool007?ooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`0hooooo`;o0000X?ooool007Cooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo0:3ooooo001eooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`2Qooooo`00
M_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
X_ooool007Oooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo0:?ooooo001gooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`2Tooooo`00N?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool0YOooool007Wooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo0:Kooooo001jooooo`03o`000?oooooooooo033ooooo
0_l0000aooooo`03o`000?oooooooooo0:Oooooo001jooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`2Xooooo`00Noooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0Z?ooool007cooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo0:Wooooo001mooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`2Zooooo`00
O_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
Z_ooool007kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo0:_ooooo001oooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`2[ooooo`00Ooooool00ol0003oooooooooo`0[ooooo`;o0000;?ooool00ol0
003oooooooooo`2/ooooo`00P?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool0[Oooool0083ooooo00?o0000ooooooooool0:_ooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo0:gooooo0021ooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`2^ooooo`00P_ooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0[oooool008;ooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0:oooooo0023ooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`2`ooooo`00
Poooool00ol0003oooooooooo`0<ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo1Ol00006ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0/?ooool008Cooooo
00?o0000ooooooooool02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
0;3ooooo0024ooooo`03o`000?oooooooooo00_ooooo00Go410@oooooooooooooooooa0@400<oooo
o`03oiRHV?lQ8B7ok^k^00Oooooo0ol0000Vooooo`03o`000?oooooooooo0;7ooooo0025ooooo`03
o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^
00Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`2aooooo`00QOooool00ol0003o
ooooooooo`0:ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05oooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0/Oooool008Gooooo00?o0000oooooooo
ool02_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo0;;ooooo0026ooooo`03o`000?oooooooooo00Wo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo0;;ooooo0026ooooo`03o`000?oooooooooo
00Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_oo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo0;?ooooo0026ooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`2cooooo`00Qoooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0/oooool008Oo
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo0;Co
oooo0028ooooo`03o`000?oooooooooo02;ooooo0_l0000Tooooo`03o`000?oooooooooo0;Cooooo
0028ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`2eooooo`00R?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool0]Oooool008Wooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo0;Gooooo0029ooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`2fooooo`00R_ooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool0]_ooool008[ooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0;Oooooo002:ooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`2gooooo`00Roooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0]oooool008_o
oooo00?o0000ooooooooool07oooool2o`00023ooooo00?o0000ooooooooool0^?ooool008_ooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo0;Sooooo
002<ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`2hooooo`00S?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool0^Oooool008cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo0;Wooooo002=ooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`2iooooo`00SOooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool0^_ooool008gooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo0;[ooooo002=ooooo`03o`000?oooooo
oooo01gooooo0_l0000Nooooo`03o`000?oooooooooo0;[ooooo002>ooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`2kooooo`00S_ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0^oooool008kooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo0;_ooooo
002>ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`2kooooo`00Soooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool0_?ooool008oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo0;cooooo002?ooooo`08o`000?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h5ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`2looooo`00T?ooool01ol0003oooooogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo0;cooooo002@ooooo`03o`000?oooooo410@00?ooooo00?o410@ooooooooool02Ooo
ool5o`0000Kooooo0ol0000Kooooo`03o`000?oooooooooo0;cooooo002@ooooo`03o`000?oooooo
000000?ooooo00?o0000ooooooooool02Oooool01?m4A4CogMgMooooool00007ooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool0_Oooool0093ooooo00?o0000ooooool000000oooool0
0ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`2mooooo`00TOooool00ol0003o410@ooooo`02ooooo`03oa0@4?oooooo
oooo00[ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo0;gooooo002Aooooo`06o`000?mgMgOoV9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`00
0007ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0_Oooool0097ooooo00Ko0000
onk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`2nooooo`00TOooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0__ooool009;ooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo0;kooooo002Booooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`2nooooo`00T_ooool00ol0003o
ooooooooo`0Hooooo`;o00006Oooool00ol0003oooooooooo`2oooooo`00T_ooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0_oooool009?ooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo0;oooooo002C
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`2o
ooooo`00Toooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool0_oooool009?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo0<3ooooo002Dooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`30ooooo`00U?ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool0`?ooool009Cooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0<3ooooo002Dooooo`03o`000?oooooooooo
01Kooooo0_l0000Gooooo`03o`000?oooooooooo0<7ooooo002Eooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`31ooooo`00UOooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0`Oooool009Gooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo0<7ooooo002E
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`31
ooooo`00UOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0`_ooool009Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo0<;ooooo002Fooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`32ooooo`00U_ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0`_ooool009Kooooo00?o0000ooooooooool05?ooool2
o`0001Kooooo00?o0000ooooooooool0`_ooool009Oooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo0<?ooooo002Gooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`33ooooo`00Uoooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0`oooool009Oooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0<?ooooo002H
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`34
ooooo`00T_ooool01oo^k^ko<S8bo`000?lb<S;ok^k^ooooool000000oooool2ob4Q8@Cooooo00Go
k^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
a?ooool009;ooooo00OoMgMgoiRHV?ooooooV9RHogMgMooooooo000000?ooooo0_lQ8B44ooooo`05
oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
0<Cooooo002Booooo`07oa0@4?ooooooooooooooool@413oooooo`000009ooooo`05o`000?oooooo
ooooooooool000001_ooool3o`0001?ooooo00?o0000ooooooooool0a?ooool009;ooooo00Go0000
ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Kooooo00Go0000oiRHV?ooooooV9RH
ob4Q8@06ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0a?ooool009;ooooo00Go
0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Kooooo00Go0000oeEEEOl0003o
410@olc<c006ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0aOooool009;ooooo
00Go410@oooooooooooooooooa0@4002ooooo`03o`000?oooooooooo00Kooooo00?oEEEEohN7Qooo
ool02?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0<Gooooo002Booooo`05ogMg
MonHV9SooooooiRHV?mgMgL00_ooool00ol0003oooooooooo`06ooooo`03omgMgOl@413oV9RH00So
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`35ooooo`00T_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00;ooooo00?o0000ooooooooool01oooool01?o<c<coA4A4o`000?l@4106oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0aOooool009[ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo0<Kooooo002Jooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`36ooooo`00V_oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0a_oo
ool009[ooooo00?o0000ooooooooool04?ooool2o`0001;ooooo00?o0000ooooooooool0a_ooool0
09[ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
0<Kooooo002Kooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`37ooooo`00Voooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0aoooool009_ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo0<Oooooo002Kooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`37ooooo`00Voooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0aoooool009cooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0<Sooooo002Looooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`38ooooo`00W?oo
ool00ol0003oooooooooo`0>ooooo`;o00004?ooool00ol0003oooooooooo`38ooooo`00W?ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0b?ooool0
09cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
0<Wooooo002Mooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`39ooooo`00WOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0bOooool009gooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo0<Wooooo002Mooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`39ooooo`00WOooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0b_ooool009kooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0<[ooooo002Nooooo`03o`00
0?oooooooooo00cooooo0_l0000>ooooo`03o`000?oooooooooo0<[ooooo002Nooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`3:ooooo`00W_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0boooool0
09kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
0<_ooooo002Oooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`3;ooooo`00Woooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0boooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
00Woooooo`000?ooooooooooolc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo0<_ooooo002Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@09ooooool0003ooooooooooolQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`3<ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00So
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0c?ooool009;ooooo00Go0000ooooooooooooooooo`000009oooo
o`07o`000?oooooo<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o00002oooool00ol0003ooooooooo
o`3<ooooo`00T_ooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooo<c<`00ol0
00000oo<c<coooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0c?oo
ool009;ooooo00Go410@oooooooooooooooooa0@4009ooooo`07o`000?oooooo410@okZj^_oooooo
^[Zjoa0@4006ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0c?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`09ooooo`07o`000?oooooo0000okZj^_oooooo^[Zjo`000006
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0cOooool009;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP09ooooo`07o`000?ooooooZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0cOooool00:7ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0<gooooo002Qooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3=ooooo`00XOooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0c_ooool00:7o
oooo00?o0000ooooooooool02Oooool2o`0000[ooooo00?o0000ooooooooool0c_ooool00:7ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0<kooooo
002Rooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`3>ooooo`00X_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0coooool00:;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo0<oooooo002Rooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`3?ooooo`00Xoooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0coooool00:?ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0=3ooooo002Sooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3@ooooo`00Y?ooool00ol0
003oooooooooo`06ooooo`;o00002?ooool00ol0003oooooooooo`3@ooooo`00Y?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0dOooool00:Cooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0=7ooooo
002Uooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`3Aooooo`00YOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0d_ooool00:Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0=;ooooo002Vooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`3Cooooo`00Y_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0doooool00:Kooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0=?ooooo002Wooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`03o`000?oooooooooo0=Cooooo002Wooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3Dooooo`00Z?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0e?ooool00:Sooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0=Gooooo
002Yooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`3Eooooo`00ZOoo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0eOooool00:?ooooo1?l0
00000ol@413oooooo`000003ooooo`05o`000?ooooooooooooooool00000f?ooool00:Gooooo00?o
0000ooooooooool00_ooool2o`000005ooooool0003oooooooooool00000fOooool00:Gooooo00?o
0000ooooooooool00oooool5o`000=[ooooo002Uooooo`03o`000?oooooooooo00Gooooo0ol0003J
ooooo`00YOooool00ol0003oooooooooo`3Rooooo`00YOooool00ol0003oooooooooo`3Rooooo`00
YOooool00ol0003oooooooooo`3Rooooo`00Xoooool00omEEEGoIVIVo`00003Tooooo`00oooooon;
ooooo`00oooooon;ooooo`00Woooool00omgMgOoIVIVooooo`0eooooo`03ofIVI_mgMgOooooo0;3o
oooo002Nooooo`03omgMgOl@413ok^k^03Kooooo00?ok^k^oa0@4?oMgMd0/?ooool007cooooo0_l0
0002ooooo`05o`000?ooooooooooo`000?l@41004?ooool4o`000003oa0@4?oooooooooo00;ooooo
00?oEEEEoiRHV?ooool00_ooool01_l@413o<S8bo`000?l0003o410@ojVYZ@;ooooo00Kok^k^oeEE
EOl0003o0000oeEEEOo^k^h2ooooo`Go00001?ooool5o`0000?ooooo00GoV9RHo`000?l0003oA4A4
okZj^P02ooooo`06onk^k_mEEEGo0000o`000?mEEEGok^k^0_ooool01?l@413o0000o`000?ooool2
o`000003o`H61_oooooooooo0:kooooo001mooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool01_ooool6o`0000Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`06o`000?nYZJWooooooooooonj^[[o00000_ooool01_mEEEGoMgMgooooooooooooMgMgoeEE
E@Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`05oa0@4?nj^[[ok^k^
ogMgMol@41000_ooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@?ooooo00Co0000oooooooooooo
oooo0_l0002`ooooo`00OOooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool01?ooool00olb<S;oooooooooo`03ooooo`05okZj^_n7QhOoIVIVofIV
I_l@41000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo0_l0002`ooooo`00OOooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00Kooooo1_l00005ooooo`03o`000?oooooo
oooo00Cooooo00?o<S8booooooooool00_ooool01_lb<S;o8B4QogMgMomgMgOoQhN7onk^kP;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`000003ooooo`;o0000/?ooool007gooooo00Oo0000olc<c?o<c<co
0000ojVYZOoMgMgo8B4Q01?ooooo00?o0000ooooooooool01?ooool00ol0003ok^k^ooooo`02oooo
o`06o`000?nj^[[oooooonk^k_mgMgOo00000_ooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@Co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00KoEEEEogMgMoooooooooooogMgMomEEED3ooooo`04o`000?n7QhOoooooojVYZ@;o0000/?oo
ool007cooooo00So410@o`000?lQ8B7o0000ogMgMol@413o0000ojVYZA?ooooo00?o0000oooooooo
ool01?ooool00omEEEGoMgMgooooo`02ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o00000_ooool0
1_o^k^koEEEEo`000?l0003oEEEEonk^kPCooooo00?o0000ooooooooool01?ooool00ol@413o0000
o`000003ooooo`03oa0@4?l0003o000000?o00000oooool01_o^k^koEEEEo`000?l0003oEEEEonk^
kP;ooooo00?o410@o`000?mgMgL00_l000000om6ATKoEEEEooooo`2_ooooo`00Uoooool00ol0003o
ooooooooo`04ooooo`03omgMgOl@413ok^k^01Cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0@ooooo`03onk^k_l@413ogMgM0;3ooooo002Eooooo`03oeEEEOmVIVKo000000Oooooo
00?oMgMgofIVI_ooool04oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool04?ooool00omVIVKoMgMgooooo`2`ooooo`00/oooool00ol@413o0000o`00
0008ooooo`03oa0@4?oooooooooo0<Wooooo003ooooooh_ooooo003ooooooh_ooooo003ooooooh_o
oooo003ooooooh_ooooo003ooooooh_ooooo0000\
\>"],
  ImageRangeCache->{{{0, 393.438}, {242.812, 0}} -> {-21.3855, -0.252315, \
0.153925, 0.00711589}}]
}, Open  ]],

Cell["This soliton has a simple analytic form:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[f[s/\@\[Alpha], a, 0, 0]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.39"],

Cell[BoxData[
    \(a\ Sech[\(\@a\ s\)\/\(2\ \@3\ \@\[Alpha]\)]\^2\)], "Output"]
}, Open  ]],

Cell["Written as an equation, the soliton solution is", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`f(s)\  = \ 
        a/\(\(cosh\^2\)(\(\@\(a/12\ \[Alpha]\)\) s)\)\)]],
  "."
}], "NE2",
  CellTags->"(7.2.17)"],

Cell[TextData[{
  "From this expression, one can see that the length of the soliton increases \
as the amplitude ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " decreases. Cell ",
  ButtonBox["7.38",
    ButtonData:>"Cell 7.38",
    ButtonStyle->"Hyperlink"],
  " shows that the length (from end to end) is roughly"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`L = \ 20\ \@\(\[Alpha]/a\)\)]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "  Also, according to Eq. ",
  ButtonBox["(7.2.16)",
    ButtonData:>{"Chapter7.nb", "(7.2.16)"},
    ButtonStyle->"Hyperlink"],
  " , the speed of the soliton increases as the amplitude increases:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`v\  = \ a/3\)]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "(This is the speed as viewed from a frame already moving at speed ",
  Cell[BoxData[
      \(TraditionalForm\`c\_o\)]],
  "). These expressions for the length and velocity are in scaled units. If \
we go back to real units the soliton height is ",
  Cell[BoxData[
      \(TraditionalForm\`z\_o\  = \ 2\ h\ a/\((3\ c\_o)\)\)]],
  ", and the soliton speed ",
  Cell[BoxData[
      \(TraditionalForm\`v\_lab\)]],
  " as seen in the lab frame depends on height  ",
  Cell[BoxData[
      \(TraditionalForm\`z\_o\)]],
  " according to"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`v\_lab = \ c\_o\ \((1 + \ z\_o/2\ h\ )\)\)]],
  ","
}], "NE2",
  CellTags->"(7.2.18)"],

Cell["and the length is", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`L = \ 20\/3\ \@\(h\^3/z\_o\)\)]],
  "."
}], "NE2",
  CellTags->"(7.2.19)"],

Cell["\<\
The earliest recorded observation of a soliton in the wild is found \
in a famous paper by Scott Russell (1844).  There, he describes a a soliton \
that he had witnessed ten years earlier:\
\>", "Text",
  CellTags->"i:31"],

Cell[TextData[{
  StyleBox["I was observing the motion of a boat which was rapidly drawn \
along a narrow channel by a pair of horses, when the boat suddenly stopped -- \
not so the mass of water in the channel which it had put in motion; it \
accumulated around the prow of the vessel in a state of violent agitation, \
then suddenly leaving it behind, rolled forward with great velocity, assuming \
the form of a large solitary elevation, a rounded, smooth and well-defined \
heap of water, which continued its course along the channel apparently \
without change of form or diminution of speed. I followed it on horseback",
    FontSize->10],
  ",",
  StyleBox[" and overtook it still rolling at a rate of some eight to nine \
miles an hour, preserving its original figure some thirty feet long and a \
foot to a foot and a half in height. Its height gradually diminished, and \
after a long chase of one or two miles I lost it in the windings of the \
channel. Such, in the month of August, 1834, was my first chance encounter \
with that singular and beautiful phenomenon.",
    FontSize->10]
}], "IndentedText"],

Cell[TextData[{
  "This exciting narrative shows that solitons are not mere artifacts of some \
mathematical idealization. In fact, it turns out that solitons are ubiquitous \
in nonlinear systems with dispersion. Some examples of other systems \
exhibiting solitons may be found in the exercises. They may even have useful \
practical applications: it has been proposed that soliton pulses could be \
used to transmit information in fiber optics networks. Even the best optical \
fibers are slightly dispersive, so that pulse trains eventually spread and \
lose coherence. However, pulse trains consisting of optical solitons (pulses \
with sufficiently large amplitude so that nonlinear effects in the index of \
refraction become important) are not affected by dispersive spreading. As of \
the year 2000, 10-Gbit/s bit rates have been demonstrated in fibers over \
distances of ",
  Cell[BoxData[
      \(TraditionalForm\`10\^4\)]],
  "- ",
  Cell[BoxData[
      \(TraditionalForm\`10\^5\)]],
  " km (see nearly any issue of ",
  StyleBox["Optics Letters",
    FontSlant->"Italic"],
  " from around this time). This is still an area of ongoing research, and \
the interested reader is referred to ",
  ButtonBox["Hasegawa and Kodama (1995)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text",
  CellTags->"i:73"]
}, Closed]],

Cell[CellGroupData[{

Cell["7.2.3 Time-Dependent Solutions: The Galerkin Method", "Subsubtitle",
  CellTags->"c:18"],

Cell[CellGroupData[{

Cell["Introduction", "Section",
  CellTags->"c:19"],

Cell["\<\
\tWe have seen that steady soliton and cnoidal wave solutions to \
the KdV equation  occur because of a balance between nonlinear steepening and \
dispersive spreading. But how do we know that such a balance is stable? If a \
steady solution is slightly perturbed, does the result remain close to the \
steady solution, or diverge from it?  If the latter is true, then these \
steady solutions are not of much more than academic interest. Although Scott \
Russell's description indicates that solitons are in fact stable, it would be \
nice to see this fact arise from the mathematics. \
\>", "Text"],

Cell["\<\
\tThere has been considerable analytical work on the stability of \
steady solutions to the KdV equation. This work is of a highly technical \
nature and will not be discussed here. Rather, we will use numerical \
techniques already at our disposal to test the stability of the solutions.  \
We will also study the interaction between solitons, and wavebreaking. \
\>", \
"Text"],

Cell[TextData[{
  "\tWe will use the Galerkin method, solving the ",
  "KdV",
  " equation with periodic boundary conditions on an interval running from  \
",
  Cell[BoxData[
      \(TraditionalForm\`\(-L\)\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  ".  A set of basis functions for these boundary conditions are"
}], "Text",
  CellTags->"i:74"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(v\_n\)(
          x)\  = \ \[ExponentialE]\^\(\(\ \)\(i\ k\ x\)\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`k\  = \ n\ \[Pi]/L\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(-M\) \[LessEqual] \ n \[LessEqual] \ M\)]],
  "."
}], "NE2",
  CellTags->"(7.2.20)"],

Cell[TextData[{
  "The solution for ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, t)\)]],
  " is then written in terms of these functions:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`f(x, 
          t)\  = \ \[Sum]\+n\(\( c\_n\)(
              t)\)\ \[ExponentialE]\^\(\[ImaginaryI]\ k\ \ x\)\)]],
  "."
}], "NE2",
  CellTags->"(7.2.21)"],

Cell[TextData[{
  "The basis functions are orthogonal with respect to the inner product ",
  Cell[BoxData[
      \(TraditionalForm\`\((f, 
          g)\)\  = \ \[Integral]\_\(-L\)\%L\( f\^*\) g \[DifferentialD]x\)]],
  ", so this is the inner product we will use. Substituting this series into \
the ",
  "KdV",
  " equation, we obtain"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          
          RowBox[{\(\[Sum]\+n\(\[PartialD]\/\[PartialD]t\) \(\(c\_n\)(
                  t)\) \[ExponentialE]\^\(\[ImaginaryI]\ k\ x\)\), "+", 
            RowBox[{
              UnderscriptBox[
                StyleBox["\[Sum]",
                  FontSize->9], \(\(n\&_\)\&_\)], 
              RowBox[{
                UnderscriptBox[
                  StyleBox["\[Sum]",
                    FontSize->9], \(n\&_\)], \(\(\(c\_\(n\&_\)\&_\)(
                    t)\) \(\(c\_n\&_\)(
                    t)\) \[ImaginaryI]\ \(k\&_\) \[ExponentialE]\^\(\
\[ImaginaryI]\ \((\(k\&_\)\&_ + k\&_)\)\ x\)\)}]}], 
            "-", \(\[Alpha] \(\[Sum]\+n \[ImaginaryI]\ \(k\^3\) \(\(c\_n\)(
                    t)\) \[ExponentialE]\^\(\[ImaginaryI]\ k\ x\)\)\)}], "=", 
          "0"}], TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(7.2.22)"],

Cell[TextData[{
  "We now take an inner product with respect to ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\[ImaginaryI]\ k\ x\)\)]],
  ", and note that,",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              FormBox[\(\[ExponentialE]\^\(\[ImaginaryI]\ k\ x\)\),
                "TraditionalForm"], 
              ",", \(\[ExponentialE]\^\(\[ImaginaryI]\ \((\(k\&_\)\&_ + 
                        k\&_)\)\ x\)\)}], ")"}], 
          "=", \(L\ \[Delta]\_\(k, \ \(k\&_\)\&_ + k\&_\)\)}], 
        TraditionalForm]]],
  ". Therefore, ",
  Cell[BoxData[
      \(TraditionalForm\`\(k\&_\)\&_ = k - k\&_\)]],
  ", and Eq. ",
  ButtonBox["(7.2.22)",
    ButtonData:>{"Chapter7.nb", "(7.2.22)"},
    ButtonStyle->"Hyperlink"],
  "  becomes"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]\/\[PartialD]t\) \(\(c\_n\)(
              t)\) + \[Sum]\+\(n\&_\)\(\(c\_\(n - n\&_\)\)(t)\) \(\(c\_n\&_\)(
                t)\) \[ImaginaryI]\ k\&_ - \[Alpha]\ \[ImaginaryI]\ \(k\^3\) \
\(\(c\_n\)(t)\) = 0\)]],
  "."
}], "NE2",
  CellTags->"(7.2.23)"],

Cell[TextData[{
  "We will solve these coupled nonlinear ODEs for ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\_k\)(t)\)]],
  " using ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Before we do, however, we note that ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, t)\)]],
  " is a real function, so this implies"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(c\_\(-n\)\)(t)\  = \ \(\(\(c\_n\)(t)\)\^*\)\)]],
  "."
}], "NE2",
  CellTags->"(7.2.24)"],

Cell[TextData[{
  "Therefore, we do not need to solve for the coefficients with ",
  Cell[BoxData[
      \(TraditionalForm\`n < 0\)]],
  ": "
}], "Text"],

Cell[BoxData[
    \(\(\(c[n_]\)[t_]\  := \ 
        Conjugate[\(c[\(-n\)]\)[t]]\  /; \ n < 0;\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.40"],

Cell[TextData[{
  "\tAlso, note that the nonlinear term in Eq. ",
  ButtonBox["(7.2.23)",
    ButtonData:>{"Chapter7.nb", "(7.2.23)"},
    ButtonStyle->"Hyperlink"],
  "  couples modes with different wavenumbers. Even though the sum over ",
  Cell[BoxData[
      \(TraditionalForm\`n\&_\)]],
  " runs only from ",
  Cell[BoxData[
      \(TraditionalForm\`\(-M\)\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  ",  coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\_\(n - n\&_\)\)(t)\)]],
  " may fall outside this range . In fact, this is sure to happen \
eventually",
  ",",
  " even if ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\_n\)(t)\)]],
  " is initially zero for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(n\)\(|\)\(\(>\)\(M\)\)\)\)]],
  ". For example, say that initially only ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(-1\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`c\_1\)]],
  " are the only nonzero coefficients (i.e., the solution is a sinusoidal \
wave with wavenumber ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]/L\)]],
  "). Then according to Eq. ",
  ButtonBox["(7.2.23)",
    ButtonData:>{"Chapter7.nb", "(7.2.23)"},
    ButtonStyle->"Hyperlink"],
  " , there is an initial rate of change for ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(\[PlusMinus]2\)\)]],
  "given by\n\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]\/\[PartialD]t\) 
            c\_2 + \ \[ImaginaryI]\ \[Pi]\/L\ \((c\_1)\)\^2 = 
        0, \[IndentingNewLine]\(\[PartialD]\/\[PartialD]t\) 
            c\_\(-2\) - \ \[ImaginaryI]\ \[Pi]\/L\ \((c\_\(-1\))\)\^2 = 
        0. \)]]
}], "Text"],

Cell[TextData[{
  "When ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(\[PlusMinus]2\)\)]],
  "has grown to large amplitude, these coefficients couple in turn to modes \
with ",
  Cell[BoxData[
      \(TraditionalForm\`n = \(\[PlusMinus]3\), \ \(\[PlusMinus]4\), \)]],
  " and so on, until a broad range of wavenumbers are excited. This is called \
a ",
  StyleBox["cascade",
    FontSlant->"Italic"],
  ".  If it is unchecked, eventually waves with arbitrarily high wavenumbers \
are excited. This is what leads to wavebreaking in the case of Eq. ",
  ButtonBox["(7.1.30)",
    ButtonData:>{"Chapter7.nb", "(7.1.30)"},
    ButtonStyle->"Hyperlink"],
  " : as the wave attains infinite slope, this corresponds to Fourier modes \
with infinite wavenumber. "
}], "Text",
  CellTags->"i:53"],

Cell[TextData[{
  "\tWe can hope that the cascade is suppressed by the dispersive term in the \
KdV equation. However, one can see in Eq. ",
  ButtonBox["(7.2.23)",
    ButtonData:>{"Chapter7.nb", "(7.2.23)"},
    ButtonStyle->"Hyperlink"],
  "  that this term, proportional to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  ", causes only a rapid oscillation in the phase of ",
  Cell[BoxData[
      \(TraditionalForm\`c\_n\)]],
  " for large ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ", and does not affect its amplitude. On the other hand, we might imagine \
that this rapid oscillation does cause phase mixing, which has an equivalent \
effect to the suppression of the amplitude, so we will simply neglect all \
modes with ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(n\)\(|\)\(\(>\)\(M\)\)\)\)]],
  ", explicitly setting them equal to zero: "
}], "Text"],

Cell[BoxData[
    \(\(\(c[n_]\)[t_]\  := \ 0\  /; \ Abs[n] > M;\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.41"],

Cell["The hope is that these modes will not be needed.", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 1: Cnoidal Wave", "Section",
  CellTags->{"i:44", "c:20"}],

Cell["\<\
For our first test, we will try a cnoidal wave  as the initial \
condition:\
\>", "Text"],

Cell[BoxData[{
    \(\(\(f[s_, a_, b_, 
          c_] = \ \ a\  - \ \((a - b)\)\ JacobiSN[Sqrt[\((a - c)\)/12] s, 
                  m]^2 /. m \[Rule] \((a - b)\)/\((a - c)\);\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(f0[x_]\  = \ f[x, 1,  .1, 0];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.42"],

Cell[TextData[{
  "In order to fit this cnoidal wave into our periodic boundary conditions, \
we choose ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " to be a multiple of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda](a, b, c)\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(\[Lambda][a_, b_, c_]\  = \ 
        2\ EllipticK[m]\ Sqrt[12/\((a - c)\)]\  /. 
          m \[Rule] \((a - b)\)/\((a - c)\);\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(L\  = \ 2\ \[Lambda][1,  .1, 0]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.43"],

Cell[BoxData[
    \(35.72309221529325`\)], "Output",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell[TextData[{
  "As usual, the initial conditions on the Fourier modes are determined by  \
",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(f\_o\)(x)\)\(\ \)\)\)]],
  " according to"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(c\_n\)(
          0)\  = \((\[ExponentialE]\^\(\[ImaginaryI]\ k\ x\), \ \(f\_o\)(
                x))\)/2  L\)]],
  ".",
  Cell[BoxData[
      FormBox[Cell[""], TraditionalForm]]]
}], "NE2",
  CellTags->"(7.2.25)"],

Cell["We will keep 15 modes in our solution:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(M = 15;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(k[n_]\  := \ n\ Pi/L;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(ics\  = \ 
        Table[\(c[n]\)[0]\  \[Equal] \ 
            NIntegrate[
                Exp[\(-I\)\ k[n]\ x]\ f0[x], {x, \(-L\), L}]/\((2  L)\), {n, 
            0, M}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.44"],

Cell[BoxData[
    \(NIntegrate::"ncvb" \(\(:\)\(\ \)\) 
      "NIntegrate failed to converge to prescribed accuracy after \!\(7\) \
recursive bisections in \!\(x\) near \!\(x\) = \!\(35.72309221520074`\)."\)], \
"Message",
  GeneratedCell->False,
  CellAutoOverwrite->False],

Cell[BoxData[
    \(NIntegrate::"ncvb" \(\(:\)\(\ \)\) 
      "NIntegrate failed to converge to prescribed accuracy after \!\(7\) \
recursive bisections in \!\(x\) near \!\(x\) = \
\!\(-35.72309221520074`\)."\)], "Message",
  GeneratedCell->False,
  CellAutoOverwrite->False],

Cell[BoxData[
    \(NIntegrate::"ncvb" \(\(:\)\(\ \)\) 
      "NIntegrate failed to converge to prescribed accuracy after \!\(7\) \
recursive bisections in \!\(x\) near \!\(x\) = \!\(35.72309221520074`\)."\)], \
"Message",
  GeneratedCell->False,
  CellAutoOverwrite->False],

Cell[BoxData[
    \(General::"stop" \(\(:\)\(\ \)\) 
      "Further output of \!\(NIntegrate :: \"ncvb\"\) will be suppressed \
during this calculation."\)], "Message",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell["\<\
The errors in the  integration can be ignored: they arise from the \
fact that several of the modes have zero initial amplitude. These errors can \
be avoided by setting these mode amplitudes equal to zero directly without \
evaluating the integrals.\
\>", "Text"],

Cell[TextData[{
  "\t We now integrate the ODEs forward in time using ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and plot the result over a time range ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < t\_max\)]],
  " in steps of ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ", with plot range from ",
  Cell[BoxData[
      \(TraditionalForm\`f\_min\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`f\_max\)]],
  " We do so using a module, since we will be studying several examples. The \
ODEs that we will solve are given by Eq. ",
  ButtonBox["(7.2.23)",
    ButtonData:>{"Chapter7.nb", "(7.2.23)"},
    ButtonStyle->"Hyperlink"],
  " , taking ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] = 1\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(kdVmod[tmax_, \[CapitalDelta]t_, fmin_, fmax_]\  := \ 
      Module[{k, \ ODEs}, \[IndentingNewLine]\[IndentingNewLine]k[n_]\  = \ 
          n\ Pi/L; \[IndentingNewLine]\[IndentingNewLine]ODEs\  = \ 
          Table[D[\(c[n]\)[t], t]\  - I\ k[n]^3\ \(c[n]\)[t]\  + 
                Sum[\ I\ k[nb]\ \ \(c[nb]\)[t]\ \(c[n - nb]\)[
                      t], {nb, \(-M\), M}] == 0, {n, 0, 
              M}]; \[IndentingNewLine]\[IndentingNewLine]vars\  = \ 
          Table[\(c[n]\)[t], {n, 0, 
              M}]; \[IndentingNewLine]\[IndentingNewLine]sol\  = \ 
          NDSolve[Join[ODEs, \ ics], vars, {t, 0, tmax}, 
            MaxSteps \[Rule] 6000]; \[IndentingNewLine]\[IndentingNewLine]f[
            x_, t_]\  = \ 
          Sum[\(c[n]\)[t]\ Exp[I\ k[n]\ x], {n, \(-M\), 
              M}]; \[IndentingNewLine]f[x_, t_]\  = \ 
          f[x, t] /. 
            sol[\([1]\)]; \[IndentingNewLine]\[IndentingNewLine]Table[
          Plot[f[x, t], {x, \(-L\), L}, 
            PlotRange \[Rule] {{\(-L\), L}, {fmin, fmax}}, 
            PlotLabel \[Rule] "\< M = \>" <> \ ToString[M]\  <> "\<, t = \>" <> 
                ToString[t]], {t, 0, tmax, \[CapitalDelta]t}];]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.45"],

Cell[TextData[{
  "We now evaluate the solution over the time range ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 200\)]],
  ", as shown in Cell ",
  ButtonBox["7.46",
    ButtonData:>"Cell 7.46",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(kdVmod[200, 5, 0, 2]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.46"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.01333 0 0.309017 [
[.1001 -0.0125 -9 -9 ]
[.1001 -0.0125 9 0 ]
[.2334 -0.0125 -9 -9 ]
[.2334 -0.0125 9 0 ]
[.3667 -0.0125 -9 -9 ]
[.3667 -0.0125 9 0 ]
[.6333 -0.0125 -6 -9 ]
[.6333 -0.0125 6 0 ]
[.7666 -0.0125 -6 -9 ]
[.7666 -0.0125 6 0 ]
[.8999 -0.0125 -6 -9 ]
[.8999 -0.0125 6 0 ]
[.4875 .07725 -24 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -18 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -24 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1001 0 m
.1001 .00625 L
s
[(-30)] .1001 -0.0125 0 1 Mshowa
.2334 0 m
.2334 .00625 L
s
[(-20)] .2334 -0.0125 0 1 Mshowa
.3667 0 m
.3667 .00625 L
s
[(-10)] .3667 -0.0125 0 1 Mshowa
.6333 0 m
.6333 .00625 L
s
[(10)] .6333 -0.0125 0 1 Mshowa
.7666 0 m
.7666 .00625 L
s
[(20)] .7666 -0.0125 0 1 Mshowa
.8999 0 m
.8999 .00625 L
s
[(30)] .8999 -0.0125 0 1 Mshowa
.125 Mabswid
.12676 0 m
.12676 .00375 L
s
.15342 0 m
.15342 .00375 L
s
.18008 0 m
.18008 .00375 L
s
.20674 0 m
.20674 .00375 L
s
.26006 0 m
.26006 .00375 L
s
.28672 0 m
.28672 .00375 L
s
.31338 0 m
.31338 .00375 L
s
.34004 0 m
.34004 .00375 L
s
.39336 0 m
.39336 .00375 L
s
.42002 0 m
.42002 .00375 L
s
.44668 0 m
.44668 .00375 L
s
.47334 0 m
.47334 .00375 L
s
.52666 0 m
.52666 .00375 L
s
.55332 0 m
.55332 .00375 L
s
.57998 0 m
.57998 .00375 L
s
.60664 0 m
.60664 .00375 L
s
.65996 0 m
.65996 .00375 L
s
.68662 0 m
.68662 .00375 L
s
.71328 0 m
.71328 .00375 L
s
.73994 0 m
.73994 .00375 L
s
.79326 0 m
.79326 .00375 L
s
.81992 0 m
.81992 .00375 L
s
.84658 0 m
.84658 .00375 L
s
.87324 0 m
.87324 .00375 L
s
.07344 0 m
.07344 .00375 L
s
.04678 0 m
.04678 .00375 L
s
.02012 0 m
.02012 .00375 L
s
.92656 0 m
.92656 .00375 L
s
.95322 0 m
.95322 .00375 L
s
.97988 0 m
.97988 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .07725 m
.50625 .07725 L
s
[(0.25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(0.75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(1)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(1.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(1.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(1.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
147.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .3073 m
.06244 .1773 L
.07216 .1347 L
.08255 .09861 L
.08852 .0828 L
.09396 .07121 L
.09948 .06169 L
.10458 .05451 L
.11433 .04382 L
.11937 .0395 L
.12492 .03557 L
.12974 .03291 L
.13206 .03189 L
.13426 .0311 L
.13545 .03074 L
.13675 .03041 L
.13794 .03016 L
.13902 .02998 L
.14031 .02982 L
.14102 .02976 L
.14168 .02972 L
.14287 .0297 L
.14415 .02973 L
.14539 .02982 L
.14652 .02995 L
.14783 .03017 L
.14907 .03043 L
.15127 .03104 L
.15366 .03189 L
.15908 .03454 L
.16409 .0378 L
.1743 .04667 L
.17996 .05303 L
.18515 .06006 L
.19453 .07681 L
.19945 .08837 L
.20463 .10303 L
.22291 .1756 L
.23318 .22476 L
.24287 .26727 L
.2471 .28231 L
.25158 .29483 L
.25392 .29977 L
.25516 .3019 L
.25649 .30381 L
.25771 .3052 L
.25883 .30617 L
.25995 .30684 L
.26101 .30721 L
.26225 .30729 L
Mistroke
.26337 .30704 L
.26467 .30639 L
.26588 .30541 L
.26701 .3042 L
.26805 .30282 L
.2704 .29881 L
.27277 .29353 L
.27537 .28644 L
.28062 .26848 L
.30158 .17247 L
.31162 .12934 L
.32112 .09722 L
.32637 .08338 L
.33208 .07116 L
.34205 .05531 L
.35148 .04472 L
.36186 .03631 L
.36709 .03327 L
.37003 .03194 L
.37271 .03099 L
.37508 .03035 L
.37643 .03009 L
.37767 .0299 L
.37899 .02977 L
.38019 .02971 L
.38086 .0297 L
.38158 .0297 L
.38289 .02977 L
.38412 .02989 L
.38525 .03005 L
.38656 .0303 L
.38779 .03059 L
.38999 .03124 L
.39238 .03215 L
.39779 .0349 L
.4028 .03825 L
.41301 .0473 L
.41866 .05379 L
.42386 .06097 L
.43321 .07808 L
.43813 .08989 L
.4433 .10484 L
.46158 .17829 L
.47183 .2274 L
.48152 .26938 L
.48574 .28403 L
.49021 .29608 L
.49255 .30074 L
.49379 .30272 L
.49512 .30447 L
Mistroke
.49634 .30571 L
.49746 .30653 L
.49858 .30706 L
.49965 .30729 L
.50089 .30721 L
.502 .30682 L
.50329 .30601 L
.50451 .30488 L
.50564 .30352 L
.50668 .30202 L
.50902 .29774 L
.51399 .28487 L
.51924 .26648 L
.54018 .1701 L
.54967 .12953 L
.55983 .09546 L
.56476 .08269 L
.56943 .07261 L
.57817 .058 L
.58784 .04644 L
.59313 .04149 L
.5981 .0376 L
.60267 .03463 L
.60686 .03248 L
.60908 .03157 L
.61151 .03078 L
.61395 .03019 L
.61528 .02997 L
.61652 .02982 L
.6178 .02973 L
.61844 .0297 L
.61915 .0297 L
.62041 .02973 L
.62158 .02982 L
.62229 .0299 L
.62296 .02999 L
.62422 .03021 L
.62558 .03051 L
.62705 .03091 L
.62955 .03178 L
.63221 .03293 L
.63699 .03558 L
.64675 .04307 L
.65559 .05234 L
.66048 .0588 L
.66565 .067 L
.67489 .08646 L
.68003 .10064 L
.68483 .11626 L
.69572 .16013 L
Mistroke
.71441 .24795 L
.71953 .26908 L
.72496 .28743 L
.7272 .29345 L
.7296 .2988 L
.73098 .3013 L
.73223 .30322 L
.73353 .30482 L
.73471 .30593 L
.73602 .30678 L
.73673 .30708 L
.73741 .30725 L
.73862 .30727 L
.73992 .3069 L
.74061 .30654 L
.74137 .30602 L
.74289 .30456 L
.7443 .30273 L
.74562 .30061 L
.75063 .28914 L
.75344 .28055 L
.756 .27155 L
.77614 .18009 L
.78539 .13898 L
.79521 .10352 L
.80034 .08893 L
.80599 .07571 L
.81597 .05842 L
.82088 .052 L
.82606 .04631 L
.83531 .03824 L
.84047 .03481 L
.84527 .03234 L
.84803 .03127 L
.85053 .03053 L
.85192 .03022 L
.85265 .03008 L
.85343 .02996 L
.85411 .02987 L
.85485 .0298 L
.85616 .02972 L
.85746 .0297 L
.85865 .02974 L
.85997 .02985 L
.86071 .02994 L
.86137 .03004 L
.8626 .03027 L
.86392 .03057 L
.86632 .03129 L
.87116 .03335 L
Mistroke
.8756 .0359 L
.88576 .04391 L
.89138 .04966 L
.89649 .05591 L
.90599 .07111 L
.91121 .08218 L
.91616 .0949 L
.92495 .12356 L
.9345 .1632 L
.95392 .25405 L
.95923 .27501 L
.96203 .28433 L
.96496 .29263 L
.96755 .29851 L
.96891 .30104 L
.97037 .30328 L
.97172 .30492 L
.97294 .30604 L
.97417 .30681 L
.97532 .30721 L
.97619 .3073 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^@?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hLooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=_ooool0
03Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Oooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`12ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0=_ooool002oooooo1_l00006ooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41005?ooool6o`0000Gooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@01gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01oo
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03Cooooo000jooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000012ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`00>Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000007oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000@_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
7oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool00000=_ooool003[ooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@023ooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@03Kooooo000gooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0@_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL07?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Kooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Ko
oooo000gooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Ooo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0@?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Kooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo000Koooooooo0000<_l0000Looooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Pooooo`00>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo0014ooooo`Ko0000@oooool5o`00027ooooo00?o0000ooooooooool0
8?ooool4o`0004?ooooo1Ol00016ooooo`00@_ooool3o`0000Cooooo0ol0000nooooo`?o00001Ooo
ool2o`0001oooooo0_l0000Nooooo`?o00001?ooool3o`0003kooooo0ol00004ooooo`?o0000@ooo
ool0047ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooo
oooo00Sooooo0_l0000Mooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02?ooool2
o`0003_ooooo00?o0000ooooooooool02?ooool2o`00047ooooo000oooooo`;o00003?ooool2o`00
03Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
01[ooooo0_l0000=ooooo`03o`000?oooooooooo03Kooooo0_l0000=ooooo`03o`000?oooooooooo
03kooooo000nooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0mooooo`00?_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0Hooooo`;o00006Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0looooo`00?Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool0>oooool003cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo03_ooooo000kooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0jooooo`00>_ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool0>_ooool003Wooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
5?ooool2o`0001Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0/ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0>Oooool003Wooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo03Sooooo000hooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0<ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@04ooooool0003oooooooooo`Go00001?ooool01Om4A4Co0000
o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0hooooo`00
>?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
3Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B42ooooo`07o`000?ooooooV9RHob4Q
8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0gooooo`00>?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool03Oooool01Ol@413ooooooooooooooooo410@00Wooooo00Ko0000
ooooooooooooV9RHob4Q8Oo^k^h9ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0gooooo`00=oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool03_ooool01Ol0003ooooooooooooooooo000000[ooooo
00Ko0000ooooooooooooV9RHob4Q8Oo^k^h7ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Aoooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo03Kooooo000fooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0?ooooo`05o`000?ooooooooooooooool000002_ooool01_l0
003oooooooooooooooooMgMgofIVIPCooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool0=Oooool003Kooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00oooooo00Go410@oooooooooooooooo
oa0@400;ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool0=Oooool003Gooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00oooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool0=Oooool003Gooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo013ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`05o`000?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0000A
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo03Cooooo000eooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`0dooooo`00=?ooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool0=?ooool003Cooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03?ooooo000dooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0cooooo`00<oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0>ooooo`;o00003oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0cooooo`00<oooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0<_ooool003?o
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03;o
oooo000booooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`0booooo`00<_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0<Oooool003;ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool03Oooool2o`0000gooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool0<Oooool003;ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo037ooooo000aooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0aooooo`00<Oooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool0<?ooool0037ooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03?oo
ool2o`0000cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool0<?ooool0037ooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo033ooooo000`ooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0`ooooo`00<?ooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool07?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B400ooooooo0000ooooo`02ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02oooooo000`oooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Loooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@03ooooool0003ooooo00Gooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02oooooo000`oooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Moooo
o`05oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00?ooooo0ol0000:ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02oooooo000_ooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Mooooo`05o`000?oooooooooo
ooooool000002Oooool00ol0003oooooooooo`03ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool0:_ooool00ol0003oooooooooo`0_ooooo`00;oooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool07Oooool01Ol0003ooooooooooooooooo
000000Wooooo00So0000oooooooooooo0000ob4Q8Ol0003o<S8bolc<c0Gooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`0^ooooo`00;oooool00ol0003oooooooooo`0/ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool07Oooool01Ol@413ooooooooooooooooo410@00Wo
oooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
02kooooo000_ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0Mooooo`05ogMgMonHV9SooooooiRHV?mgMgL02Oooool01?l0003oooooooooool00009
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0;_ooool002oooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP09ooooo`03o`000?oooooooooo00Co00001_ooool2o`0000[ooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool0;_ooool002kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0]oooo
o`03o`000?oooooooooo02gooooo000^ooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`0]ooooo`00;_ooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool0;Oooool002kooooo00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool02Ooo
ool2o`0000Wooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool0;Oooool002gooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02gooooo000]ooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0/ooooo`00;Oooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;?ooool002cooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02cooooo
000/ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo00Sooooo0_l00008ooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02cooooo000/
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0[
ooooo`00;?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03;ooooo00?o0000oooo
ooooool0:oooool002_ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo02_ooooo000[ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`0[ooooo`00:oooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`07ooooo`;o00001ooo
ool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`0[ooooo`00:_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool0:_ooool002[ooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo01[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02[ooooo000Zooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Jooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01Oooool01?l0003oooooogMg
Molb<S85ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:_ooool002[ooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01[ooooo00Go
410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Gooooo00Co0000oooooooooooo
00001Oooool3o`0000Gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo03Cooooo00?o0000ooooooooool0:_ooool002Wooooo00?o0000ooooooooool0
=oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01[ooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ob4Q8Ooooooooooo00Cooooo00Co0000oooooomgMgOo<S8b1Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo02Wooooo000Yooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Jooooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Wooooo000Yooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Kooooo`05oa0@4?oooooooooo
ooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`0Yooooo`00:?ooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool06oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooo000000Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`0Yooooo`00:?ooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`0000Gooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0:Ooo
ool002Sooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo03Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo03Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooo
oooo02Sooooo000Xooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0gooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0>?ooool00ol0
003oooooooooo`0Xooooo`009oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03So
oooo00?o0000ooooooooool0:?ooool002Oooooo00?o0000ooooooooool0>_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0hooooo`03o`000?oooooooooo02Sooooo000Wooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00Cooooo0_l0
0004ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo02Sooooo000Wooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0>Oooool00ol0003oooooooooo`0Wooooo`009_ooool00ol0003oooooooooo`0loooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo03[ooooo00?o0000ooooooooool09oooool002Kooooo00?o0000oooooooo
ool0??ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02Oooooo000Vooooo`03o`00
0?oooooooooo03gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Wooooo`009Ooo
ool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0??oo
ool00ol0003oooooooooo`02ooooo`;o00000oooool00ol0003oooooooooo`0looooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Wooooo`009Oooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0?Oooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0?Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool09_ooool002Gooooo00?o0000
ooooooooool0?_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03gooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo02Kooooo000Uooooo`03o`000?oooooo
oooo03oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0mooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`0Uooooo`009?ooool00ol0003oooooooooo`10
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`02
o`0000;ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool09Oooool002Cooooo00?o0000ooooooooool0@Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo03oooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0?oooool0
0ol0003oooooooooo`0Uooooo`009?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0>Oooool4o`000007oa0@4?ooooooooooooooool0003oooooo`00
0002ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`10ooooo`03o`000?oooooooooo02Cooooo000Sooooo`03o`000?oooooooooo04?ooooo00?o0000
ooooooooool00_l0000mooooo`03o`000?oooooooooo00?ooooo00Go0000ooooool0003oooooo`00
0013ooooo`05o`000?ooooooooooooooool00000@oooool2o`0002Gooooo000Sooooo`03o`000?oo
oooooooo04?ooooo1?l0000nooooo`03o`000?oooooooooo00Cooooo0ol00015ooooo`Co0000A?oo
ool2o`0002Cooooo002[ooooo`03o`000?oooooooooo00Gooooo0ol0002booooo`00Zoooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0;;ooooo002[ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0/_ooool00:_ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`2booooo`00ZOooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo0;;ooooo002c
ooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooooooo
ool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool0
0ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/ooo
ool00;?ooooo00?o0000ooooooooool0/_ooool0097ooooo1?l000000ol@413oooooooooo`02oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0;;ooooo002Cooooo`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;;ooooo002Coooo
o`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03oooo
o`?o0000/_ooool009?ooooo00?o0000ooooooooool03?ooool00onHV9So8B4Qonk^kP07ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool0
3Oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003o
ooooooooo`2booooo`00Toooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`2booooo`00Toooool00ol0003ooooooooo
o`0:ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0;;ooooo002Aooooo`03oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c004ooooo`Co00001_ooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_oo
ool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?o
oooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooooooo
o`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2boooo
o`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002Iooooo`Co000000?o
410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`00
0?oooooooooo0;;ooooo002Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0/_ooool009_ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;;ooooo002Kooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool01?ooool3o`000;;ooooo002Kooooo`03o`000?oooooooooo00_o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;;ooooo002Kooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2booooo`00
Voooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
/_ooool009Wooooo00?oEEEEofIVI_l000003Oooool4o`0000Kooooo00?o0000ooooooooool0/_oo
ool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/ooo
ool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?o
oooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0
002cooooo`00/oooool00ol0003oooooooooo`2booooo`00TOooool4o`000003oa0@4?oooooooooo
00;ooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00Cooooo0_lQ8B46oooo
o`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2boooo
o`00Toooool00ol0003oooooooooo`0<ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000oooooooo
ool00oooool3o`000;;ooooo002Cooooo`03o`000?oooooooooo00gooooo00?o8B4Qooooooooool0
1_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oo
oooooooo00gooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool03Oooool00onYZJWoMgMgoooo
o`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000
ooooooooool02_ooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`2booooo`00TOooool00omEEEGoIVIVo`00000<ooooo`Go00001?ooool4
o`0000Kooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooooooo
o`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/ooo
ool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?o
oooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0
002cooooo`00/oooool00ol0003oooooooooo`2booooo`00Z?ooool5o`0000Kooooo00?o0000oooo
ooooool0/_ooool00:Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo
0;;ooooo002Yooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/_ooool00:[ooooo
00?oV9RHob4Q8Oo^k^h01_ooool3o`000;;ooooo002[ooooo`03ogMgMomVIVKooooo0;[ooooo002/
ooooo`03o`000?oooooooooo0;Wooooo002Xooooo`05o`000?nj^[[ooooooiRHV?l@4100^oooool0
0:Sooooo00GoV9RHoa0@4?l0003o8B4Qolc<c02kooooo`00oooooomYooooo`00]Oooool00ol0003o
^[Zjooooo`2`ooooo`00]Oooool2oc8b<[7ooooo0026ooooo`;o000000Ko410@oooooooooooo410@
o`000?l@410Hooooo`Co000000Go410@ooooooooooooooooodA4A002o`000007oc8b<_oMgMgooooo
oooooon7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^08;ooooo0027ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1oooool6o`0000cooooo00?o0000ooooooooool01_ooool01omgMgOo<S8booooooooooooc<c<o`00
0?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00009ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL0P_ooool008Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0J
ooooo`05oa0@4?ooooooooooooooool@4100P_ooool008Oooooo00Ko0000oooooom4A4CoA4A4oooo
ool00009ooooo`Ko00003?ooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo013ooooo
00?o0000ooooooooool02oooool6o`0000Wooooo00Go0000ooooooooooooooooo`000022ooooo`00
Qoooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001_ooooo00?o0000ooooooooool00oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<017ooooo00?o0000ooooooooool06_ooool01Ol0003ooooooooooooo
oooo000008;ooooo0027ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo00006oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo017ooooo00?o410@o`000?l000000ol0000Iooooo`05oa0@
4?ooooooooooooooool@4100P_ooool008Oooooo00Ko0000oc8b<_oooooooooooc8b<_l0000Koooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Joooo
o`05ogMgMonHV9SooooooiRHV?mgMgL0P_ooool008Kooooo00?o410@o`000?n7QhL00_ooool00on7
QhOo0000oa0@400Hooooo`03oeEEEOmVIVKo000000Gooooo1?l0000Booooo`03o`000?oooooooooo
01[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP22ooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-44.3769, -0.160437, \
0.309031, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.01333 0 0.309017 [
[.1001 -0.0125 -9 -9 ]
[.1001 -0.0125 9 0 ]
[.2334 -0.0125 -9 -9 ]
[.2334 -0.0125 9 0 ]
[.3667 -0.0125 -9 -9 ]
[.3667 -0.0125 9 0 ]
[.6333 -0.0125 -6 -9 ]
[.6333 -0.0125 6 0 ]
[.7666 -0.0125 -6 -9 ]
[.7666 -0.0125 6 0 ]
[.8999 -0.0125 -6 -9 ]
[.8999 -0.0125 6 0 ]
[.4875 .07725 -24 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -18 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -24 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1001 0 m
.1001 .00625 L
s
[(-30)] .1001 -0.0125 0 1 Mshowa
.2334 0 m
.2334 .00625 L
s
[(-20)] .2334 -0.0125 0 1 Mshowa
.3667 0 m
.3667 .00625 L
s
[(-10)] .3667 -0.0125 0 1 Mshowa
.6333 0 m
.6333 .00625 L
s
[(10)] .6333 -0.0125 0 1 Mshowa
.7666 0 m
.7666 .00625 L
s
[(20)] .7666 -0.0125 0 1 Mshowa
.8999 0 m
.8999 .00625 L
s
[(30)] .8999 -0.0125 0 1 Mshowa
.125 Mabswid
.12676 0 m
.12676 .00375 L
s
.15342 0 m
.15342 .00375 L
s
.18008 0 m
.18008 .00375 L
s
.20674 0 m
.20674 .00375 L
s
.26006 0 m
.26006 .00375 L
s
.28672 0 m
.28672 .00375 L
s
.31338 0 m
.31338 .00375 L
s
.34004 0 m
.34004 .00375 L
s
.39336 0 m
.39336 .00375 L
s
.42002 0 m
.42002 .00375 L
s
.44668 0 m
.44668 .00375 L
s
.47334 0 m
.47334 .00375 L
s
.52666 0 m
.52666 .00375 L
s
.55332 0 m
.55332 .00375 L
s
.57998 0 m
.57998 .00375 L
s
.60664 0 m
.60664 .00375 L
s
.65996 0 m
.65996 .00375 L
s
.68662 0 m
.68662 .00375 L
s
.71328 0 m
.71328 .00375 L
s
.73994 0 m
.73994 .00375 L
s
.79326 0 m
.79326 .00375 L
s
.81992 0 m
.81992 .00375 L
s
.84658 0 m
.84658 .00375 L
s
.87324 0 m
.87324 .00375 L
s
.07344 0 m
.07344 .00375 L
s
.04678 0 m
.04678 .00375 L
s
.02012 0 m
.02012 .00375 L
s
.92656 0 m
.92656 .00375 L
s
.95322 0 m
.95322 .00375 L
s
.97988 0 m
.97988 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .07725 m
.50625 .07725 L
s
[(0.25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(0.75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(1)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(1.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(1.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(1.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
147.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24505 m
.02846 .26461 L
.03279 .28032 L
.03754 .29391 L
.0402 .29956 L
.04262 .30336 L
.04385 .30479 L
.04516 .30592 L
.04627 .30657 L
.0475 .30694 L
.04882 .30693 L
.04957 .30675 L
.05024 .30647 L
.05156 .30561 L
.05281 .30442 L
.05397 .30299 L
.0552 .30114 L
.05742 .29697 L
.06244 .28375 L
.06791 .26435 L
.07382 .23906 L
.08454 .1882 L
.0941 .14495 L
.10458 .10614 L
.10956 .09159 L
.11489 .07865 L
.12452 .06106 L
.13018 .05333 L
.13554 .04725 L
.14031 .04264 L
.14558 .03831 L
.15023 .03513 L
.15524 .03242 L
.158 .03127 L
.16053 .03046 L
.16295 .02989 L
.16416 .02969 L
.1648 .02961 L
.16549 .02954 L
.16674 .02945 L
.16791 .02943 L
.16905 .02945 L
.17011 .02952 L
.17125 .02965 L
.1725 .02984 L
.17381 .03011 L
.17503 .03041 L
.17931 .03191 L
.18172 .03303 L
.18391 .03422 L
Mistroke
.19378 .04143 L
.20294 .05086 L
.21298 .06532 L
.21859 .07613 L
.22367 .08812 L
.23372 .11915 L
.24296 .15635 L
.25374 .20685 L
.26379 .25327 L
.26847 .27193 L
.2729 .28661 L
.27535 .29322 L
.27801 .29902 L
.27918 .3011 L
.28042 .30298 L
.28151 .30433 L
.28265 .30545 L
.28393 .30635 L
.2851 .30683 L
.28636 .30698 L
.28707 .30691 L
.28773 .30672 L
.28894 .30613 L
.29003 .30529 L
.2913 .30397 L
.29249 .30239 L
.2952 .29762 L
.2977 .29184 L
.30333 .27442 L
.32373 .18302 L
.33369 .13874 L
.34279 .10578 L
.35218 .08043 L
.36109 .06343 L
.37049 .05068 L
.38073 .04064 L
.38524 .03717 L
.39011 .03407 L
.3929 .03262 L
.39546 .03152 L
.3979 .03067 L
.39925 .03029 L
.40048 .03001 L
.40177 .02977 L
.40299 .0296 L
.40427 .02948 L
.405 .02945 L
.40567 .02943 L
.40679 .02944 L
.40801 .02951 L
Mistroke
.4093 .02964 L
.4105 .02982 L
.41192 .03011 L
.41326 .03045 L
.41579 .03127 L
.41851 .0324 L
.42148 .03392 L
.4268 .03735 L
.4318 .04137 L
.44116 .05102 L
.45124 .06561 L
.45692 .07663 L
.46214 .08909 L
.47189 .1194 L
.48098 .15603 L
.4916 .2057 L
.50165 .25225 L
.50638 .27124 L
.51141 .2878 L
.51403 .29462 L
.51542 .29768 L
.51692 .30051 L
.51829 .30266 L
.51955 .30426 L
.52075 .30545 L
.52202 .30634 L
.52318 .30682 L
.52424 .30698 L
.52546 .30684 L
.52661 .30637 L
.52768 .30567 L
.52866 .30478 L
.53088 .30194 L
.53313 .29796 L
.53559 .29234 L
.54058 .27739 L
.56167 .18374 L
.57167 .13922 L
.58094 .10561 L
.59048 .07999 L
.59551 .06974 L
.60087 .06082 L
.6108 .04823 L
.61978 .03986 L
.62468 .03625 L
.62984 .03319 L
.63425 .03125 L
.63675 .03045 L
.63908 .0299 L
.64038 .02969 L
Mistroke
.64111 .0296 L
.64179 .02953 L
.64303 .02945 L
.64435 .02943 L
.64553 .02947 L
.64663 .02956 L
.64784 .0297 L
.64915 .02993 L
.65053 .03023 L
.65203 .03064 L
.65477 .03161 L
.65992 .03412 L
.66523 .0376 L
.67023 .04166 L
.67958 .05141 L
.68966 .06617 L
.69533 .07731 L
.70055 .08993 L
.71028 .12048 L
.71937 .15732 L
.72998 .20707 L
.74003 .25347 L
.74475 .27225 L
.74977 .28856 L
.75239 .29523 L
.75378 .29821 L
.75528 .30095 L
.75665 .30302 L
.7579 .30455 L
.75911 .30567 L
.76037 .30648 L
.76153 .30689 L
.76259 .30698 L
.76381 .30676 L
.76496 .30623 L
.76603 .30546 L
.76701 .30451 L
.76923 .30155 L
.77147 .29745 L
.77394 .2917 L
.77892 .27652 L
.79999 .18267 L
.80999 .13833 L
.81925 .10492 L
.82877 .07953 L
.8338 .06938 L
.83916 .06053 L
.84908 .04803 L
.85806 .03971 L
.86295 .03613 L
Mistroke
.86811 .03311 L
.87251 .03119 L
.87501 .0304 L
.87622 .0301 L
.87734 .02987 L
.87864 .02967 L
.87932 .02958 L
.88004 .02951 L
.88126 .02944 L
.88195 .02943 L
.8826 .02943 L
.88381 .02948 L
.88491 .02957 L
.88612 .02973 L
.8874 .02996 L
.89007 .03063 L
.89255 .03148 L
.89817 .03421 L
.90323 .03753 L
.90871 .042 L
.91866 .05262 L
.92336 .05906 L
.92834 .06721 L
.93726 .08632 L
.94671 .11457 L
.95686 .15466 L
.97518 .24053 L
.97619 .24505 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^@?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hLooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=_ooool0
03Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Oooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`12ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0=_ooool002oooooo1_l00006ooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41005?ooool6o`0000Gooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@01gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01oo
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03Cooooo000jooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000012ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`00>Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000007oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000@_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
7oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool00000=_ooool003[ooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@023ooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@03Kooooo000gooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0@_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL07?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Kooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Ko
oooo000gooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Ooo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0@?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Kooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo000Koooooooo0000<_l0000Looooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Pooooo`00>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo001<ooooo`Ko0000@_ooool6o`0001Wooooo00?o0000ooooooooool0
9_ooool6o`0004?ooooo1Ol0000nooooo`00B_ooool2o`0000Kooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`03ooooo`?o00005oooool2o`0002Gooooo0ol00005ooooo`;o0000?_oo
ool3o`0000Gooooo0_l0000looooo`00B?ooool2o`0000Wooooo0_l0000kooooo`?o00002Oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02;ooooo0_l0000:ooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0iooooo`00Aoooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool02oooool2o`00
03Wooooo00?o0000ooooooooool02_ooool2o`0003Wooooo0016ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0fooooo`00AOooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0Aooooo`;o00008Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0eooooo`00A?ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0=?ooool004?ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03?ooooo0013oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0coooo
o`00@_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0<_ooool0047ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool03Oooool2o`0001gooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
<_ooool0047ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo037ooooo0010ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`05ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0
0004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo033ooooo000oooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`05ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo
00KoV9RHob4Q8Oo^k^koooooodA4A?l00006ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0`ooooo`00?oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool01_ooool01Ol@413ooooooooooooooooo410@
00cooooo00?oV9RHob4Q8Oo^k^h00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0_ooooo`00?_ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01_ooool01Ol0003o
oooooooooooooooo000000gooooo00GoV9RHob4Q8Oo^k^koooooo`000005ooooo`03ogMgMolb<S;o
oooo00Cooooo0ol0000Hooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02kooooo000nooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`07ooooo`05o`000?oooooooooo
ooooool000003_ooool02omgMgOoIVIVoooooooooooo0000ooooool0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0^ooooo`00?_ooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01oooool01Ol@413o
oooooooooooooooo410@00oooooo00Ko0000oooooooooooo0000ooooool00009ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool0;Oooool003gooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Sooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool2o`0000Wooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`0]ooooo`00?Oooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`Go00001_ooool2o`0001Sooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool0;?ooool003gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo02cooooo000looooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0/ooooo`00??ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool0:oooool003_ooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo02_ooooo000kooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Oo
oooo0_l0000Gooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo02_ooooo000kooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Zooooo`00>_ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0:_ooool003[ooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02[ooooo000joooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Zoooo
o`00>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`06ooooo`;o00005Oooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Yooooo`00
>Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
:Oooool003Wooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo02Wooooo000iooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0Yooooo`00>Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`05ooooo`;o00005?ooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0Xooooo`00>?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool0:?ooool003Sooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo02Sooooo000hooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o0000omgMg@05ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool0:?ooool003Sooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q2?ooool00ol0003o<S8booooo`04ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool09oooool003Oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo01Gooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?o
oooo0ol0000Booooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0[ooooo`03o`000?oooooooooo02Oooooo000gooooo`03o`000?oooooooooo02_ooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Eooooo`05o`000?ooooooooooooooool0
00003oooool00omgMgOo0000ooooo`04ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool09oooool003Oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo01Gooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b
<_l000001Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo02Oooooo000gooooo`03
o`000?oooooooooo02_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Fooooo`05
oa0@4?ooooooooooooooool@41003?ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`0Wooooo`00=_ooool00ol0003oooooooooo`0]oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool05_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo02gooooo00?o0000ooooooooool09_ooool003Kooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo01Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`Co000000?oooooo`000?ooool00oooool2o`0001;ooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool09_ooool0
03Kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
02Kooooo000fooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`0Vooooo`00=_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool09_ooool003Gooooo00?o0000ooooooooool0;oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo02kooooo00Co0000oooooooooooooooo0_l0000Aooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo02Gooooo000eooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0^ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`0Uooooo`00=Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0;_ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
9Oooool003Gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo02oooooo00Go0000ooooooooooooooooo`00000Aooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02Gooooo
000eooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0_ooooo`05o`000?ooooooooooooooool000004Oooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Uooooo`00=?oo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`02o`00013ooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool09?ooool003Cooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo033ooooo00Co0000
oooooooooooo00004Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`0Tooooo`00=?ooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0<Oooool01?l0003oooooooooool0
000@ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo02Cooooo000dooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0aooooo`04o`000?ooooooooooo`00013ooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool09?ooool003Cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo037ooooo00Co0000oooooooooooo00004?ooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0<_ooool00ol0003ooooooooo
o`0Tooooo`00<oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0<_ooool01?l0003oooooo`000?l0000?ooooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02?ooooo000c
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0c
ooooo`03o`000?oooooo000000oooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool08oooool003?ooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o
0000oc8b<_oMgMd00oooool00ol0003oooooo`00000?ooooo`03o`000?oooooooooo03Cooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02?ooooo000c
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0B
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01ooo
ool00omgMgOo<S8booooo`03ooooo`;o00003oooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Sooooo`00<oooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04oooool0
1Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003ooooooooo
o`02ooooo`Co00003Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`0Sooooo`00<_ooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04oooool01Ol0003ooooooooooooo
oooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`03ooooo`;o00003_oo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`0Rooooo`00<_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool04oooool01Ol0003ooooooooooooooooo000000kooooo00?o
EEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo0_l0000>ooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo02;ooooo000booooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0Cooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMg
ooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`0Rooooo`00<_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool05?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooo
oooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`0Rooooo`008oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Dooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool5o`0000Cooooo1?l00006ooooo`;o00003?ooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Rooooo`00
8oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0gooooo`;o00003?ooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0Foooool002?ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0=ooo
ool2o`0000cooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo05_ooooo000Tooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Sooooo0_l0000<ooooo`03o`000?oooooo
oooo03Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Looooo`009?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0hooooo`;o00002oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0G?ooool002Cooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>?ooool3o`0000[o
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05co
oooo000Tooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooool000002_ooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0G?ooool002Cooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0>Oooool00ol0003oooooo`00000:ooooo`03o`000?oooooooooo03[ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`1Looooo`009Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo05gooooo000Uooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Wooooo00?o0000oooo
ool000002Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0GOooool002Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0looooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0>Oooool2o`000003ooooool0003ooooo00Oo
oooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05go
oooo000Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0?Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo03Wooooo00Co0000oooooooooooo00002?ooool00ol0003o
ooooooooo`0looooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0G_ooool002Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0>_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo03go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Nooooo`009_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0jooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo05kooooo000Wooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0?oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03[ooooo
0_l00002ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo05oooooo000Wooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0?oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03_ooooo00Co
0000oooooooooooooooo0_l00005ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`1Pooooo`009oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo043ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0aooooo`Co000000?o
410@ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0@?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo063ooooo000X
ooooo`05o`000?ooooooooooooooool00000@oooool01Ol0003ooooooooooooooooo000003Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0004Co
oooo00Go0000ooooooooooooooooo`00001Rooooo`00:Oooool3o`0004Gooooo0ol0000gooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool4o`0004Cooooo1?l0001Sooooo`00
Zoooool00ol0003oooooooooo`05ooooo`?o0000/_ooool00:_ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`2booooo`00Zoooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0;;ooooo002[ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/_ooool00:Wo
oooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo
002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002coooo
o`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0
/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool0
0;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003ooooo
ooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2b
ooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`00
0?oooooooooo0;;ooooo002Aooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Cooooo1Ol0
0004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2booooo`00Tooo
ool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2booooo`00Toooool00ol0003ooooooooo
o`0;ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`000;;ooooo002C
ooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00gooooo00?oMgMgofIV
I_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/_ooool0
09?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool02_ooool01Ol0003o
^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2boooo
o`00TOooool00omEEEGoIVIVo`00000<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`00
00Kooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooo
ooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2b
ooooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`00
0?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool0
0;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo
00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002c
ooooo`00/oooool00ol0003oooooooooo`2booooo`00VOooool4o`000003oa0@4?oooooooooo00;o
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2boooo
o`00Voooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo0;;ooooo002Kooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`2booooo`00Voooool00ol0003oooooooooo`0>ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol0002booooo`00Voooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2booooo`00Voooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_ooool009_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;;ooooo002Iooooo`03
oeEEEOmVIVKo000000gooooo1?l00006ooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000
/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool0
0;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003ooooo
ooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2b
ooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`00
0?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooo
oooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo
00?o0000ooooooooool0/_ooool0097ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_oo
ool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`2booooo`00Toooool00ol0003oooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGoZJVYoooo
o`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000
ooooooooool03?ooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002b
ooooo`00Toooool00ol0003oooooooooo`0=ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`0=ooooo`03
oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo
0;;ooooo002Cooooo`03o`000?oooooooooo00gooooo00?oZJVYogMgMoooool00oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00[ooooo
00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0/_ooool0097ooooo00?oEEEEofIVI_l000003?ooool5o`0000Cooooo1?l00006ooooo`;o0000
/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool0
0;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo
0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2b
ooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`00
0?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooo
oooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo
00?o0000ooooooooool0/_ooool00:Sooooo1Ol00006ooooo`03o`000?oooooooooo0;;ooooo002X
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`2booooo`00ZOooool0
0onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0;;ooooo002Zooooo`03oiRHV?lQ8B7ok^k^
00Kooooo0ol0002booooo`00Zoooool00omgMgOoIVIVooooo`2jooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00Z?ooool01Ol0003o^[ZjoooooonHV9So410@0;_ooooo002Xooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`0^oooool00?ooooooJOooool00;Gooooo00?o0000okZj^_ooool0/?ooool0
0;Gooooo0_lb<S:aooooo`00Q_ooool2o`000006oa0@4?oooooooooooa0@4?l0003o410@6?ooool4
o`000005oa0@4?oooooooooooooooom4A4@00_l000001olb<S;ogMgMooooooooooooQhN7o`000?nj
^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Wooooo00GoA4A4o`000?l0003o<S8bomgMg@21
ooooo`00Qoooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l0000<oooo
o`03o`000?oooooooooo00Kooooo00OoMgMgoc8b<_ooooooooooolc<c?l0003o410@00cooooo00Go
410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003Oooool00omgMgOo<S8booooo`20ooooo`00Qooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0Oooo
ool008Oooooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00003?ooool00ol0003ooooo
ooooo`06ooooo`03ogMgMolb<S;ooooo013ooooo00?o0000ooooooooool02oooool6o`0000gooooo
00?oMgMgoc8b<_ooool0P?ooool008Oooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Kooooo`03
o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Aooooo`03o`000?oooooooooo
01_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c021ooooo`00Qoooool01_l0003oQhN7ojVYZOnj^[[o
EEEEo`0001_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03oa0@4?l0
003o000000?o00006_ooool00ol0003oooooooooo`23ooooo`00Qoooool01_l0003o<S8boooooooo
oooo<S8bo`0001_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool0Poooool008Kooooo00?o410@o`000?n7QhL00_oo
ool00on7QhOo0000oa0@400Hooooo`03oeEEEOmVIVKo000000Gooooo1?l0000Booooo`03o`000?oo
oooooooo01_ooooo1?l00022ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-44.3769, -0.160437, \
0.309031, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.01333 0 0.309017 [
[.1001 -0.0125 -9 -9 ]
[.1001 -0.0125 9 0 ]
[.2334 -0.0125 -9 -9 ]
[.2334 -0.0125 9 0 ]
[.3667 -0.0125 -9 -9 ]
[.3667 -0.0125 9 0 ]
[.6333 -0.0125 -6 -9 ]
[.6333 -0.0125 6 0 ]
[.7666 -0.0125 -6 -9 ]
[.7666 -0.0125 6 0 ]
[.8999 -0.0125 -6 -9 ]
[.8999 -0.0125 6 0 ]
[.4875 .07725 -24 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -18 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -24 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1001 0 m
.1001 .00625 L
s
[(-30)] .1001 -0.0125 0 1 Mshowa
.2334 0 m
.2334 .00625 L
s
[(-20)] .2334 -0.0125 0 1 Mshowa
.3667 0 m
.3667 .00625 L
s
[(-10)] .3667 -0.0125 0 1 Mshowa
.6333 0 m
.6333 .00625 L
s
[(10)] .6333 -0.0125 0 1 Mshowa
.7666 0 m
.7666 .00625 L
s
[(20)] .7666 -0.0125 0 1 Mshowa
.8999 0 m
.8999 .00625 L
s
[(30)] .8999 -0.0125 0 1 Mshowa
.125 Mabswid
.12676 0 m
.12676 .00375 L
s
.15342 0 m
.15342 .00375 L
s
.18008 0 m
.18008 .00375 L
s
.20674 0 m
.20674 .00375 L
s
.26006 0 m
.26006 .00375 L
s
.28672 0 m
.28672 .00375 L
s
.31338 0 m
.31338 .00375 L
s
.34004 0 m
.34004 .00375 L
s
.39336 0 m
.39336 .00375 L
s
.42002 0 m
.42002 .00375 L
s
.44668 0 m
.44668 .00375 L
s
.47334 0 m
.47334 .00375 L
s
.52666 0 m
.52666 .00375 L
s
.55332 0 m
.55332 .00375 L
s
.57998 0 m
.57998 .00375 L
s
.60664 0 m
.60664 .00375 L
s
.65996 0 m
.65996 .00375 L
s
.68662 0 m
.68662 .00375 L
s
.71328 0 m
.71328 .00375 L
s
.73994 0 m
.73994 .00375 L
s
.79326 0 m
.79326 .00375 L
s
.81992 0 m
.81992 .00375 L
s
.84658 0 m
.84658 .00375 L
s
.87324 0 m
.87324 .00375 L
s
.07344 0 m
.07344 .00375 L
s
.04678 0 m
.04678 .00375 L
s
.02012 0 m
.02012 .00375 L
s
.92656 0 m
.92656 .00375 L
s
.95322 0 m
.95322 .00375 L
s
.97988 0 m
.97988 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .07725 m
.50625 .07725 L
s
[(0.25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(0.75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(1)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(1.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(1.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(1.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .13394 m
.04262 .21908 L
.0522 .2616 L
.05746 .28075 L
.06244 .29459 L
.06506 .29988 L
.06644 .30208 L
.0679 .30394 L
.06912 .30513 L
.06982 .30566 L
.07047 .30604 L
.07162 .30647 L
.07286 .30659 L
.0741 .30635 L
.0748 .30606 L
.07545 .30568 L
.07665 .30472 L
.07792 .30334 L
.08035 .29969 L
.08255 .29526 L
.088 .28015 L
.0939 .25823 L
.10458 .20963 L
.12413 .12301 L
.12948 .10465 L
.13522 .0882 L
.14558 .06611 L
.15066 .05812 L
.15619 .05097 L
.16624 .04093 L
.17098 .03723 L
.17602 .034 L
.18032 .03185 L
.18277 .03089 L
.18507 .03018 L
.18625 .02989 L
.1875 .02964 L
.18869 .02946 L
.18977 .02933 L
.19103 .02925 L
.19175 .02923 L
.19241 .02922 L
.19362 .02926 L
.1949 .02936 L
.19613 .02952 L
.19745 .02975 L
.19983 .03034 L
.20266 .03131 L
.20525 .03244 L
.20979 .03498 L
Mistroke
.21475 .0385 L
.22376 .0469 L
.22909 .05321 L
.2341 .06031 L
.24347 .07766 L
.24873 .0904 L
.25356 .10437 L
.26446 .14429 L
.28492 .23858 L
.29005 .26062 L
.2949 .27859 L
.29926 .29149 L
.30172 .29716 L
.304 .30128 L
.30505 .3028 L
.30618 .30415 L
.30725 .30516 L
.30823 .30586 L
.30932 .30636 L
.31051 .30659 L
.31175 .30648 L
.31291 .30605 L
.31414 .30524 L
.3153 .30416 L
.31748 .3013 L
.31982 .29704 L
.32236 .29113 L
.32733 .27598 L
.33259 .25573 L
.34202 .21277 L
.3522 .1646 L
.36186 .12436 L
.37052 .0958 L
.37996 .07304 L
.38486 .06411 L
.39008 .05629 L
.39944 .04541 L
.40938 .03702 L
.41504 .03349 L
.41779 .03213 L
.42035 .03108 L
.42262 .03034 L
.42504 .02975 L
.42642 .02951 L
.42772 .02935 L
.42889 .02926 L
.43017 .02922 L
.43141 .02925 L
.43212 .02929 L
.43278 .02934 L
Mistroke
.43347 .02942 L
.43411 .0295 L
.43555 .02975 L
.43676 .03002 L
.43809 .03038 L
.44051 .03121 L
.44515 .03337 L
.4501 .03646 L
.45901 .04396 L
.4693 .05605 L
.4751 .06505 L
.48043 .07522 L
.49025 .10007 L
.50061 .13636 L
.52049 .22696 L
.52916 .26467 L
.53374 .28103 L
.5386 .29451 L
.54108 .29958 L
.54239 .30174 L
.54381 .30363 L
.54511 .30496 L
.5463 .30584 L
.54743 .30637 L
.54863 .30659 L
.54977 .3065 L
.55098 .30606 L
.55212 .30533 L
.55316 .3044 L
.55439 .30299 L
.55572 .30108 L
.55812 .29661 L
.56064 .29064 L
.56341 .28265 L
.56901 .26259 L
.57904 .21789 L
.58987 .16656 L
.60014 .12367 L
.60936 .09371 L
.61463 .08038 L
.6194 .07041 L
.62917 .05495 L
.63453 .04854 L
.63956 .04347 L
.64855 .03628 L
.6536 .03324 L
.65825 .03115 L
.66072 .03033 L
.66297 .02978 L
.66421 .02955 L
Mistroke
.66487 .02946 L
.66556 .02937 L
.66684 .02927 L
.66802 .02922 L
.6691 .02923 L
.67026 .02929 L
.67135 .02939 L
.67235 .02952 L
.67352 .02973 L
.6748 .03001 L
.67712 .03068 L
.67985 .03171 L
.68231 .03287 L
.68785 .03622 L
.69781 .04466 L
.70783 .05666 L
.71705 .07219 L
.72187 .08271 L
.72717 .09662 L
.73786 .13302 L
.759 .2289 L
.76385 .25067 L
.76901 .27129 L
.77379 .28697 L
.77827 .29789 L
.78046 .3017 L
.78159 .30324 L
.78282 .30461 L
.78409 .30565 L
.78479 .30606 L
.78544 .30633 L
.7866 .30659 L
.78784 .3065 L
.78854 .3063 L
.78918 .306 L
.78989 .30557 L
.79064 .30498 L
.7919 .3037 L
.79329 .30188 L
.79585 .29738 L
.79824 .29191 L
.80301 .27774 L
.80737 .26155 L
.81717 .21774 L
.82716 .17026 L
.83779 .12532 L
.84783 .09268 L
.85692 .07153 L
.86185 .06281 L
.86638 .05613 L
Mistroke
.87661 .04445 L
.88563 .03697 L
.89017 .03408 L
.89515 .03162 L
.89767 .03068 L
.899 .03028 L
.9004 .02992 L
.90163 .02967 L
.90229 .02956 L
.90299 .02945 L
.90422 .02932 L
.90538 .02924 L
.90651 .02922 L
.90775 .02925 L
.90904 .02935 L
.91024 .02949 L
.91137 .02968 L
.91239 .02989 L
.91469 .03051 L
.91738 .03148 L
.91986 .0326 L
.92546 .03589 L
.93039 .03961 L
.93562 .04437 L
.94507 .05547 L
.95028 .06334 L
.95522 .07234 L
.9648 .0953 L
.97354 .12383 L
.97619 .13394 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^@?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hLooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=_ooool0
03Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Oooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`12ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0=_ooool002oooooo1_l00006ooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41005?ooool6o`0000Gooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@01gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01oo
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03Cooooo000jooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000012ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`00>Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000007oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000@_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
7oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool00000=_ooool003[ooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@023ooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@03Kooooo000gooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0@_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL07?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Kooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Ko
oooo000gooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Ooo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0@?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Kooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo000Koooooooo0000<_l0000Looooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Pooooo`00>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo001Cooooo`Ko0000@oooool5o`0001;ooooo00?o0000ooooooooool0
;_ooool6o`0004;ooooo1_l0000fooooo`00D?ooool4o`0000Gooooo0_l0000nooooo`?o00001Ooo
ool3o`0000oooooo0_l0000/ooooo`?o00001_ooool2o`0003kooooo0_l00006ooooo`;o0000=?oo
ool004oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0iooooo`;o00002oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Wooooo0_l0000;ooooo`03o`000?oooooo
oooo03Wooooo0_l0000:ooooo`;o0000<_ooool004oooooo00?o0000ooooooooool02_ooool2o`00
03Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0;oooool004kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0dooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo02oooooo001=ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Wooooo
0_l0000Xooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo02kooooo001<ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0]ooooo`00Boooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0;?ooool004[ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02_ooooo0019ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Zooooo`00
B?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`05ooooo`;o00009?ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Yooooo`00Aooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0:Ooo
ool004Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Zooooo`05o`000?lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Sooooo0016ooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool0:?ooool01_l0003oMgMgoiRHV?ooooooV9RHogMgM`Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00ol0003o<S8booooo`04oooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0:?ooool004Kooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Xooooo`03o`000?l@413ooooo00;ooooo00?o410@oooooooo
ool02_ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Xooooo`00AOooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooool000000oooool00ol0003oooooooooo`0;ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgo`000?ooool01?ooool3o`00023ooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
9oooool004Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooo000000?ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`03ooooo`06o`000?lQ
8B7o0000oc8b<_o<c<co00001?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Oo
oooo0015ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09?ooool01?l0003ooooo
ooooool@4103ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0Vooooo`00A?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Cooooo
00So0000ooooooooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@
4004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo02Kooooo0014ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool08oooool02?l0003oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So
410@o`000?lQ8B7oc<c<00Cooooo1?l00002ooooo`04o`000?ooooooooooooooo`;o00008?ooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0Vooooo`00A?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool08?ooool01Ol0003ooooooooooooooooo0000023ooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool09Oooool004?ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo023ooooo00Go0000ooooooooooooooooo`00000Pooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo02Gooooo0013ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0Rooooo`04o`000?ooooooooooo`0001oooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool09?ooool0
04?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
02;ooooo00Co0000oooooooooooo00007oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Tooooo`00@oooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`02o`0001kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Poooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool09?ooool004;ooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Cooooo00?o0000ooooool0
00007_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0Sooooo`00@_ooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool09?ooool00ol0003oooooo`00000Nooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo02?ooooo0012ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooo000001kooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool08ooo
ool0047ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo02Kooooo0_l0000Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02;ooooo0011ooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Vooooo`?o00007?ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0Rooooo`00@Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool09_ooool2o`0001gooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool08_ooool0043ooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Kooooo
0_l0000Mooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo02;ooooo000Sooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0Rooooo`008oooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0X
ooooo`;o00006oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool0C?ooool002?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1<oooo
o`008oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04gooooo000Tooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo00kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo0_l0000Jooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`1=ooooo`009?ooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0>ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool2o`00
01[ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
04gooooo000Tooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo00kooooo00Go410@oooooooooooooooooa0@400@oooo
o`03o`000?oooooooooo00?ooooo0ol0000Iooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`1=ooooo`009?ooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo02_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0>ooooo`05
o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`;o00006_ooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0C_ooool002Co
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool03oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`;o00006_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool0C_ooool002Gooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03oooool01Ol@
413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooo`00000H
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1>
ooooo`009Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0?ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooo000001Sooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04oooooo000Uooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool3o`0001Sooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04oooooo000Uoooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooool000006?ooool00ol0003oooooooooo`0]oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0Coooool002Gooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0:oooool01?l0003oooooooooool0000Fooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`1?ooooo`009_ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0[ooooo`04
o`000?ooooooooooo`0001Kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo053ooooo000Vooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02_ooooo0_l000000ooooooo
0000ooooo`0Eooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`1@ooooo`009_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02oooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0[ooooo`04o`000?ooooooooooo`0001Ko
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo053o
oooo000Vooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0<?ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo02cooooo00Co0000oooooooooooo00005_ooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0D?ooool002Kooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0;?ooool01Ol0003ooooooooooooooooo000001Cooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo053ooooo000Wooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo02cooooo00Go0000ooooooooooooooooo`00000Dooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Aooooo`009oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0/ooooo`;o00000_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Aooooo`009oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0/ooooo`05o`000?ooooooooooooooool000005?ooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool0DOooool002Oooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0booooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo057ooooo000Wooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo02gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Aooooo`00:?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0D_ooool002So
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool0;Oooool2o`0000?ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0D_ooool002Sooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05;ooooo
000Xooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo05;ooooo000Xooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00_ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Cooooo`00
:Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0;ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol00003ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo05?o
oooo000Yooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo05?ooooo000Yooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0Doooool002Wooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0Doooool002[o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooo
oooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`1Dooooo`00:_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
03Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`;o00001_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1D
ooooo`00:_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0E?ooool002[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0hooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo05Cooooo000Zooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`1Dooooo`00:oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo03Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0EOooool002_ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0<?ooool2
o`0000Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0EOooool002_ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0jooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0<?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo05Gooooo000/ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Eooooo`00;?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0E_ooool002cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Kooooo000]
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo037ooooo0_l00008ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0?Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Kooooo000]oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo03gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Foooo
o`00;Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0Eoooool002kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0nooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo05Oooooo000^ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03?ooooo0_l00009ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo05Oooooo000^ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0@?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1Hooooo`00;oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
043ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Zooooo`Co000000?o410@oooo
ooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Sooooo000_ooooo`;o
00000_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo00;o0000;_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`000013oooo
o`05o`000?ooooooooooooooool00000Foooool0033ooooo1?l00015ooooo`?o0000;oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo0ol00015ooooo`?o0000G?ooool00:_o
oooo00?o0000ooooooooool01Oooool3o`000;;ooooo002[ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0/_ooool00:_ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`2booooo`00Zoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;;ooooo002Yoooo
o`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00
/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool0
0ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;o
oooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000oooooooo
ool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_oo
ool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003o
ooooooooo`2booooo`00TOooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`Go0000
1?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/_ooool009?ooooo
00?o0000ooooooooool01?ooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool0
2oooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0002booooo`00Tooo
ool00ol0003oooooooooo`0<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`0=ooooo`03ogMgMomVIVKo
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;;ooooo002C
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00[ooooo00Go0000okZj
^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_ooool0
097ooooo00?oEEEEofIVI_l000003?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006
ooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooooooo
ool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_oo
ool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/ooo
ool00;?ooooo00?o0000ooooooooool0/_ooool009Wooooo1?l000000ol@413oooooooooo`02oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/_ooool0
09_ooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`2booooo`00Voooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0/_ooool009_ooooo00?o0000ooooooooool03_ooool00omgMgOo<S8b
ooooo`04ooooo`?o0000/_ooool009_ooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/_ooool009_ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;;ooooo002Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2booooo`00VOooool00omE
EEGoIVIVo`00000=ooooo`Co00001_ooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?o
oooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000oooooooo
ool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_oo
ool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooooooo
o`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03
o`000?oooooooooo0;;ooooo002Aooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Kooooo
00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooooooo
ool0/_ooool009?ooooo00?o0000ooooooooool01?ooool2ob4Q8@Kooooo00?oEEEEojVYZOooool0
1oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oo
oooooooo00cooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000/_oo
ool009?ooooo00?o0000ooooooooool03Oooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool03Oooool00omE
EEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2b
ooooo`00Toooool00ol0003oooooooooo`0=ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`0:ooooo`05
oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
0;;ooooo002Aooooo`03oeEEEOmVIVKo000000cooooo1Ol00004ooooo`Co00001_ooool2o`000;?o
oooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o
0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_oo
ool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooooooo
o`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03
o`000?oooooooooo0;;ooooo002Xooooo`Go00001_ooool00ol0003oooooooooo`2booooo`00Z?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/_ooool00:Wooooo00?o
V9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`2booooo`00Z_ooool00onHV9So8B4Qonk^kP06
ooooo`?o0000/_ooool00:_ooooo00?oMgMgofIVI_ooool0^_ooool00:cooooo00?o0000oooooooo
ool0^Oooool00:Sooooo00Go0000okZj^_ooooooV9RHoa0@402kooooo`00Z?ooool01OnHV9So410@
o`000?lQ8B7oc<c<0;_ooooo003oooooofWooooo002aooooo`03o`000?nj^[[ooooo0;Cooooo002a
ooooo`;o<S8b]Oooool008;ooooo0_l000001_l@413oooooooooool@413o0000oa0@41Sooooo1?l0
00001Ol@413oooooooooooooooooA4A400;o000000Oo<S8bomgMgOooooooooooohN7Qol0003o^[Zj
00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Iooooo`Co000000So410@ooooooooooook^k^oc8b
<_l0003o<S8bonk^kWkooooo0023ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1oooool6o`0000cooooo00?o0000ooooooooool01_ooool01omgMgOo<S8booooooooooooc<c<o`00
0?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1nooooo`00Poooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@07kooooo0023ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000cooooo
00?o0000ooooooooool01_ooool00omgMgOo<S8booooo`0@ooooo`03o`000?oooooooooo00_ooooo
1_l0000<ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001nooooo`00
Poooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001_ooooo00?o0000ooooooooool00oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<017ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool00000O_ooool008?ooooo00Ko0000ohN7QonYZJWo^[ZjoeEE
EOl0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol@413o0000
o`000003o`0001cooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@07ko
oooo0023ooooo`06o`000?lb<S;ooooooooooolb<S;o00006oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL0O_ooool008;ooooo00?o410@o`000?n7QhL00_ooool00on7
QhOo0000oa0@400Hooooo`03oeEEEOmVIVKo000000Gooooo1?l0000Booooo`03o`000?oooooooooo
01_ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07kooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-44.3769, -0.160437, \
0.309031, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.01333 0 0.309017 [
[.1001 -0.0125 -9 -9 ]
[.1001 -0.0125 9 0 ]
[.2334 -0.0125 -9 -9 ]
[.2334 -0.0125 9 0 ]
[.3667 -0.0125 -9 -9 ]
[.3667 -0.0125 9 0 ]
[.6333 -0.0125 -6 -9 ]
[.6333 -0.0125 6 0 ]
[.7666 -0.0125 -6 -9 ]
[.7666 -0.0125 6 0 ]
[.8999 -0.0125 -6 -9 ]
[.8999 -0.0125 6 0 ]
[.4875 .07725 -24 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -18 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -24 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1001 0 m
.1001 .00625 L
s
[(-30)] .1001 -0.0125 0 1 Mshowa
.2334 0 m
.2334 .00625 L
s
[(-20)] .2334 -0.0125 0 1 Mshowa
.3667 0 m
.3667 .00625 L
s
[(-10)] .3667 -0.0125 0 1 Mshowa
.6333 0 m
.6333 .00625 L
s
[(10)] .6333 -0.0125 0 1 Mshowa
.7666 0 m
.7666 .00625 L
s
[(20)] .7666 -0.0125 0 1 Mshowa
.8999 0 m
.8999 .00625 L
s
[(30)] .8999 -0.0125 0 1 Mshowa
.125 Mabswid
.12676 0 m
.12676 .00375 L
s
.15342 0 m
.15342 .00375 L
s
.18008 0 m
.18008 .00375 L
s
.20674 0 m
.20674 .00375 L
s
.26006 0 m
.26006 .00375 L
s
.28672 0 m
.28672 .00375 L
s
.31338 0 m
.31338 .00375 L
s
.34004 0 m
.34004 .00375 L
s
.39336 0 m
.39336 .00375 L
s
.42002 0 m
.42002 .00375 L
s
.44668 0 m
.44668 .00375 L
s
.47334 0 m
.47334 .00375 L
s
.52666 0 m
.52666 .00375 L
s
.55332 0 m
.55332 .00375 L
s
.57998 0 m
.57998 .00375 L
s
.60664 0 m
.60664 .00375 L
s
.65996 0 m
.65996 .00375 L
s
.68662 0 m
.68662 .00375 L
s
.71328 0 m
.71328 .00375 L
s
.73994 0 m
.73994 .00375 L
s
.79326 0 m
.79326 .00375 L
s
.81992 0 m
.81992 .00375 L
s
.84658 0 m
.84658 .00375 L
s
.87324 0 m
.87324 .00375 L
s
.07344 0 m
.07344 .00375 L
s
.04678 0 m
.04678 .00375 L
s
.02012 0 m
.02012 .00375 L
s
.92656 0 m
.92656 .00375 L
s
.95322 0 m
.95322 .00375 L
s
.97988 0 m
.97988 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .07725 m
.50625 .07725 L
s
[(0.25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(0.75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(1)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(1.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(1.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(1.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .06604 m
.06244 .19701 L
.07216 .24251 L
.0775 .26495 L
.08255 .28279 L
.08542 .29101 L
.08852 .29813 L
.0899 .30062 L
.09135 .30282 L
.09259 .30432 L
.09396 .30556 L
.09466 .30603 L
.09534 .30637 L
.0966 .30672 L
.0973 .30675 L
.09796 .30668 L
.09868 .30648 L
.09944 .30613 L
.10011 .30572 L
.10083 .30515 L
.10214 .30382 L
.10458 .30029 L
.10705 .29538 L
.10936 .28965 L
.1146 .27296 L
.12519 .22795 L
.14415 .1399 L
.1546 .1019 L
.15975 .0873 L
.1645 .07606 L
.17339 .05999 L
.17808 .05354 L
.18306 .0478 L
.19243 .03935 L
.1977 .0357 L
.20253 .03306 L
.20678 .03132 L
.20919 .0306 L
.21144 .03011 L
.21266 .02992 L
.21381 .02978 L
.21485 .02971 L
.21597 .02967 L
.21719 .02968 L
.21849 .02975 L
.21959 .02986 L
.22081 .03004 L
.22211 .03028 L
.22331 .03057 L
.22602 .0314 L
Mistroke
.22842 .03235 L
.23097 .03357 L
.24026 .03978 L
.24591 .04487 L
.25122 .05064 L
.25596 .05674 L
.26115 .06474 L
.27094 .0848 L
.27629 .09921 L
.28127 .11515 L
.29975 .19327 L
.31023 .2424 L
.31538 .26411 L
.32015 .28119 L
.32446 .2934 L
.32664 .29817 L
.32905 .30227 L
.3303 .30389 L
.33145 .30507 L
.33271 .306 L
.33334 .30633 L
.33404 .30659 L
.33521 .30676 L
.33646 .30658 L
.33764 .30607 L
.33871 .30533 L
.33991 .30418 L
.34103 .30281 L
.34358 .29865 L
.34606 .29324 L
.34872 .28606 L
.35794 .25211 L
.37875 .15491 L
.38891 .11442 L
.39427 .09717 L
.39996 .08203 L
.40493 .07129 L
.41041 .06166 L
.42008 .04896 L
.42498 .04402 L
.43015 .03963 L
.43462 .03645 L
.4394 .03366 L
.4421 .03239 L
.44455 .03143 L
.44702 .03067 L
.44935 .03014 L
.45067 .02993 L
.45134 .02984 L
.45207 .02977 L
Mistroke
.45337 .02969 L
.45458 .02967 L
.45531 .02968 L
.45601 .02971 L
.45731 .02982 L
.45804 .02991 L
.45872 .03001 L
.46025 .03029 L
.4629 .03099 L
.46533 .03185 L
.47083 .03454 L
.47567 .03771 L
.48079 .04185 L
.48966 .05105 L
.4994 .065 L
.50464 .07489 L
.50961 .08623 L
.51892 .11364 L
.52895 .15252 L
.53984 .20276 L
.55005 .24996 L
.55505 .27011 L
.55963 .2855 L
.56193 .29184 L
.56444 .29758 L
.56697 .30201 L
.56834 .30383 L
.56962 .30513 L
.57031 .30568 L
.57106 .30615 L
.57176 .30647 L
.57242 .30666 L
.57365 .30674 L
.57495 .30645 L
.57563 .30613 L
.57635 .30568 L
.57766 .30455 L
.57922 .30268 L
.58064 .3005 L
.58316 .29557 L
.58543 .28997 L
.59053 .27392 L
.59968 .23585 L
.61049 .18424 L
.62042 .13956 L
.62963 .10557 L
.63972 .07819 L
.64497 .06761 L
.64987 .05957 L
.655 .05264 L
Mistroke
.66056 .04645 L
.66602 .04143 L
.67105 .03757 L
.67577 .03459 L
.67828 .03327 L
.68097 .03207 L
.6834 .03118 L
.68562 .03054 L
.68669 .03029 L
.68786 .03007 L
.68896 .0299 L
.68999 .02979 L
.69123 .0297 L
.69241 .02967 L
.69347 .02968 L
.69461 .02975 L
.69586 .02987 L
.69718 .03007 L
.69831 .03029 L
.69954 .03058 L
.70205 .03134 L
.70478 .03242 L
.70974 .03503 L
.71457 .03831 L
.71904 .04199 L
.72918 .0528 L
.7343 .05988 L
.73996 .0694 L
.75004 .09232 L
.75929 .12165 L
.78015 .2133 L
.78929 .25483 L
.79432 .27436 L
.79906 .2893 L
.80176 .29594 L
.80318 .29883 L
.80468 .30143 L
.80594 .30322 L
.80733 .30478 L
.8086 .30581 L
.80978 .30644 L
.81107 .30674 L
.81229 .30667 L
.81339 .3063 L
.81459 .30558 L
.81589 .30441 L
.81727 .30275 L
.81976 .29867 L
.82237 .29294 L
.82513 .28542 L
Mistroke
.83006 .26859 L
.8412 .21977 L
.85095 .17311 L
.86138 .12811 L
.87167 .09366 L
.88105 .07142 L
.88557 .06331 L
.89047 .05601 L
.89939 .04572 L
.90881 .03781 L
.91417 .03442 L
.9192 .03201 L
.92177 .03109 L
.92317 .03068 L
.92448 .03036 L
.92569 .03011 L
.92679 .02994 L
.92801 .02979 L
.92932 .0297 L
.93 .02967 L
.93072 .02967 L
.93201 .0297 L
.93273 .02975 L
.9334 .02981 L
.93413 .0299 L
.93492 .03001 L
.93634 .03027 L
.93769 .03059 L
.94021 .03136 L
.94451 .03319 L
.94927 .03592 L
.95889 .04361 L
.96781 .05348 L
.97619 .06604 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^@?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hLooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=_ooool0
03Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Oooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`12ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0=_ooool002oooooo1_l00006ooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41005?ooool6o`0000Gooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@01gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01oo
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03Cooooo000jooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000012ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`00>Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000007oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000@_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
7oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool00000=_ooool003[ooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@023ooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@03Kooooo000gooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0@_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL07?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Kooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Ko
oooo000gooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Ooo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0@?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Kooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo000Koooooooo0000<_l0000Looooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Pooooo`00>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo001Kooooo`Go0000@oooool5o`0000_ooooo00?o0000ooooooooool0
=Oooool6o`0004;ooooo1_l0000_ooooo`00F?ooool3o`0000Gooooo0ol0000mooooo`?o00001Ooo
ool2o`0000Wooooo0_l0000dooooo`?o00001?ooool3o`0003oooooo0_l00005ooooo`;o0000;Ooo
ool005Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo00Sooooo0_l00007ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0jooooo`;o00002Oooool2o`0002_ooooo001Fooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0<?ooool2o`0000cooooo00?o0000ooooooooool0=oooool2o`00
00gooooo00?o0000ooooooooool0:?ooool005Gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo00gooooo0_l0000fooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool09oooool005Cooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool2o`0002oooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool09_ooool005;ooooo0_l0000Cooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool04Oooool01Ol0003ooooooooooooooooo000002oooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
9Oooool0057ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo01;ooooo00Co0000oooooooooooo0000;_ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Tooooo`00DOoo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool04ooo
ool01?l0003oooooooooool0000]ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02Cooooo001@ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooo000002cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool08oooool0053ooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Oooooo0ol0000[ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo02?ooooo000Sooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0Rooooo`008oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool08_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo00?o0000oooo
ooooool00_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool0?_ooool002?ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo027ooooo00OoMgMgoiRHV?ooooooV9RHogMgMooooooo000000?ooooo0_lQ
8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`;o0000
:_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
?_ooool002Cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo027ooooo00Oo410@oooooooooooooooooa0@4?oooooo000000[ooooo00?oV9RHob4Q8Oo^
k^h02Oooool00ol0003oooooooooo`03ooooo`;o0000:Oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0?_ooool002Cooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo
oooo0_l0000<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0002Oo
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03oo
oooo000Tooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0Pooooo`04o`000?ooooooooooooooo`;o00003Oooool00omgMgOoIVIVooooo`03ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooo`00000Wooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0oooooo`009Oooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool08?ooool01_l@413o
oooooooooooooooo410@o`0000kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07
ooooo`04o`000?ooooooooooo`0002Gooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo043ooooo000Uooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0Pooooo`05ogMgMonHV9SooooooiRHV?l000002ooo
ool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool01?l0003ooooo
ooooool0000Uooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`10ooooo`009Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool07oooool01Oo^k^ko<S8bo`000?lb<S;o000000_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c004ooooo`Co00001_ooool2o`0000;ooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0@?ooool002Go
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool07?ooool01Ol0003ooooooooooooooooo000002?ooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo047ooooo000Vooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo01gooooo00Go0000ooooooooooooooooo`00000Sooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`11ooooo`009_ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0@Oooool002Kooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo04;ooooo
000Vooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo01kooooo0_l00003ooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo04;ooooo000W
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`12
ooooo`009oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool0@oooool002Oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo04?ooooo000Xooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`13ooooo`00:?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Pooooo`;o00001Ooo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`14ooooo`00:?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool0A?ooool002Sooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo04Cooooo000Yooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`14ooooo`00:Oooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Qooooo`;o00001_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`15ooooo`00:Oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0AOooool002Wooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04Gooooo000Zoooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo00Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`16ooooo`00:_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`07ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo04Kooooo000Zooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Oooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo0ol00006ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04Kooooo000[
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`16ooooo`00:oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`00:ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`08ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Aoooool002_ooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool02?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Oooooo000/ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`0000Sooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool0B?ooool002cooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo04Sooooo000/ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`18ooooo`00;?ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0B?ooool002gooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool09?ooool2o`0000Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0B?ooool002gooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04Wooooo000]ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`19ooooo`00;_ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0BOooool0
02kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
04Wooooo000^ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo02Gooooo0_l0000:ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04Wo
oooo000^ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`19ooooo`00;oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool0BOooool002oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0b
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo04[ooooo000_ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0<_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03;ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`1:ooooo`00;oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Vooooo`;o
00002oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`1:ooooo`00;oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo03?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool0B_ooool0033ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0B_ooool0033ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo04[ooooo000`ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo
00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000oooooooo
ool00oooool3o`0000_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool0Boooool0033ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
1?ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0Boooool0033ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?oo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`1;ooooo`00<Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`04ooooo`05oa0@4?oooooooooooooo
ool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`1;ooooo`00<Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`04ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04cooooo000aoooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4
o`0000Kooooo0_l0000=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04cooooo000aooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
03Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1<ooooo`00<_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0COooool003;ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04gooooo
000booooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`1=ooooo`00<oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Yooooo`;o00003_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1=
ooooo`00<oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0C_ooool003?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0jooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo04kooooo000cooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`1>ooooo`00=?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0C_ooool003Cooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0looooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0:_ooool2
o`00013ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0looooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0Coooool003Cooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0looooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0?Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo04oooooo000dooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02_o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1?ooooo`00=Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0[ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Coooool003Gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0;?ooool2o`00017ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0D?ooool003Kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0@?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo053ooooo000foooo
o`;o00000oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool08_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool04Oooool01Ol0
003ooooooooooooooooo000004?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1A
ooooo`00=oooool01?l0003oooooooooool00014ooooo`;o000000?oooooo`000?l000009oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo0_l00002ooooo`03o`000?oooooo
oooo047ooooo0_l00002ooooo`03o`000?oooooooooo05;ooooo000gooooo`Co0000AOooool3o`00
02Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Booooo`Co0000A?ooool4o`00
05Cooooo002[ooooo`03o`000?oooooooooo00Gooooo0ol0002booooo`00Zoooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0;;ooooo002[ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0/_ooool00:_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2b
ooooo`00ZOooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o
0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_oo
ool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooooooo
o`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03
o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oo
oooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?o
oooo00?o0000ooooooooool0/_ooool0097ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q
1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;;o
oooo002Cooooo`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000
/_ooool009?ooooo00?o0000ooooooooool03?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool03Oooool0
0omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`2booooo`00Toooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`0:oooo
o`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0;;ooooo002Aooooo`03oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004
ooooo`Co00001_ooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oo
oooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?o
oooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0
002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2boooo
o`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/ooo
ool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002Iooooo`Co000000?o410@oooo
ooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0;;ooooo002Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/_ooool009_ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo0;;ooooo002Kooooo`03o`000?oooooooooo00kooooo
00?oMgMgoc8b<_ooool01?ooool3o`000;;ooooo002Kooooo`03o`000?oooooooooo00_ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;;ooooo002Kooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2booooo`00Voooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_ooool0
09Wooooo00?oEEEEofIVI_l000003Oooool4o`0000Kooooo00?o0000ooooooooool0/_ooool00;?o
oooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooooooo
o`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03
o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oo
oooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?o
oooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o
0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002coooo
o`00/oooool00ol0003oooooooooo`2booooo`00TOooool4o`000003oa0@4?oooooooooo00;ooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00Cooooo0_lQ8B46ooooo`03oeEE
EOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2booooo`00Tooo
ool00ol0003oooooooooo`0<ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00ooo
ool3o`000;;ooooo002Cooooo`03o`000?oooooooooo00gooooo00?o8B4Qooooooooool01_ooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo
00gooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000
ooooooooool0/_ooool009?ooooo00?o0000ooooooooool03Oooool00onYZJWoMgMgooooo`03oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000oooooooo
ool02_ooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`2booooo`00TOooool00omEEEGoIVIVo`00000<ooooo`Go00001?ooool4o`0000Ko
oooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooooooo
o`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2boooo
o`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oo
oooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?o
oooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o
0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002coooo
o`00/oooool00ol0003oooooooooo`2booooo`00Z?ooool5o`0000Kooooo00?o0000ooooooooool0
/_ooool00:Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0;;ooooo
002Yooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/_ooool00:[ooooo00?oV9RH
ob4Q8Oo^k^h01_ooool3o`000;;ooooo002[ooooo`03ogMgMomVIVKooooo0;[ooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002Xooooo`05o`000?nj^[[ooooooiRHV?l@4100^oooool00:Sooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c02kooooo`00oooooomYooooo`00/Oooool00ol0003o^[Zjoooo
o`2dooooo`00/Oooool2oc8b<[Gooooo0022ooooo`;o000000Ko410@oooooooooooo410@o`000?l@
410Hooooo`Co000000Go410@ooooooooooooooooodA4A002o`000007oc8b<_oMgMgooooooooooon7
QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06Oooool4o`000005oa0@4?oooooo
oooooooooom4A4@00_l000000olb<S;ogMgMooooo`1looooo`00Poooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Oooooo1_l0000<ooooo`03o`000?oooooooooo00Kooooo00OoMgMg
oc8b<_ooooooooooolc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko
00003?ooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo07cooooo0023ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo07_ooooo0023ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000co
oooo00?o0000ooooooooool01_ooool00omgMgOo<S8booooo`0@ooooo`03o`000?oooooooooo00_o
oooo1_l0000<ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool0O?ooool008?ooooo
00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c00Aooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<07gooooo0023ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo0000
6oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o410@o`000?l00000
0ol0000Looooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Ooooool008?ooooo00Ko
0000oc8b<_oooooooooooc8b<_l0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0Ooooool008;ooooo00?o410@o`000?n7QhL00_ooool00on7QhOo0000oa0@400Hooooo`03oeEE
EOmVIVKo000000Gooooo1?l0000Booooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l00000
1Oooool4o`0007kooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-44.3769, -0.160437, \
0.309031, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.01333 0 0.309017 [
[.1001 -0.0125 -9 -9 ]
[.1001 -0.0125 9 0 ]
[.2334 -0.0125 -9 -9 ]
[.2334 -0.0125 9 0 ]
[.3667 -0.0125 -9 -9 ]
[.3667 -0.0125 9 0 ]
[.6333 -0.0125 -6 -9 ]
[.6333 -0.0125 6 0 ]
[.7666 -0.0125 -6 -9 ]
[.7666 -0.0125 6 0 ]
[.8999 -0.0125 -6 -9 ]
[.8999 -0.0125 6 0 ]
[.4875 .07725 -24 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -18 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -24 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1001 0 m
.1001 .00625 L
s
[(-30)] .1001 -0.0125 0 1 Mshowa
.2334 0 m
.2334 .00625 L
s
[(-20)] .2334 -0.0125 0 1 Mshowa
.3667 0 m
.3667 .00625 L
s
[(-10)] .3667 -0.0125 0 1 Mshowa
.6333 0 m
.6333 .00625 L
s
[(10)] .6333 -0.0125 0 1 Mshowa
.7666 0 m
.7666 .00625 L
s
[(20)] .7666 -0.0125 0 1 Mshowa
.8999 0 m
.8999 .00625 L
s
[(30)] .8999 -0.0125 0 1 Mshowa
.125 Mabswid
.12676 0 m
.12676 .00375 L
s
.15342 0 m
.15342 .00375 L
s
.18008 0 m
.18008 .00375 L
s
.20674 0 m
.20674 .00375 L
s
.26006 0 m
.26006 .00375 L
s
.28672 0 m
.28672 .00375 L
s
.31338 0 m
.31338 .00375 L
s
.34004 0 m
.34004 .00375 L
s
.39336 0 m
.39336 .00375 L
s
.42002 0 m
.42002 .00375 L
s
.44668 0 m
.44668 .00375 L
s
.47334 0 m
.47334 .00375 L
s
.52666 0 m
.52666 .00375 L
s
.55332 0 m
.55332 .00375 L
s
.57998 0 m
.57998 .00375 L
s
.60664 0 m
.60664 .00375 L
s
.65996 0 m
.65996 .00375 L
s
.68662 0 m
.68662 .00375 L
s
.71328 0 m
.71328 .00375 L
s
.73994 0 m
.73994 .00375 L
s
.79326 0 m
.79326 .00375 L
s
.81992 0 m
.81992 .00375 L
s
.84658 0 m
.84658 .00375 L
s
.87324 0 m
.87324 .00375 L
s
.07344 0 m
.07344 .00375 L
s
.04678 0 m
.04678 .00375 L
s
.02012 0 m
.02012 .00375 L
s
.92656 0 m
.92656 .00375 L
s
.95322 0 m
.95322 .00375 L
s
.97988 0 m
.97988 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .07725 m
.50625 .07725 L
s
[(0.25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(0.75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(1)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(1.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(1.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(1.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .03773 m
.03279 .04523 L
.04262 .05677 L
.04758 .06441 L
.05288 .07437 L
.06244 .09829 L
.07379 .13823 L
.08451 .18604 L
.09425 .23238 L
.09958 .256 L
.10458 .27533 L
.10916 .28967 L
.11151 .29553 L
.11408 .30062 L
.11554 .30286 L
.11689 .30452 L
.11818 .3057 L
.1189 .3062 L
.11955 .30654 L
.12079 .30692 L
.12149 .30697 L
.12213 .30691 L
.12331 .30656 L
.12455 .30582 L
.1257 .30483 L
.12675 .30365 L
.1291 .30011 L
.13128 .29574 L
.13334 .29068 L
.14299 .25712 L
.16121 .17201 L
.17159 .12744 L
.18132 .09478 L
.19084 .07199 L
.19619 .0625 L
.2011 .05542 L
.21133 .04424 L
.21648 .03996 L
.22211 .03613 L
.22739 .03332 L
.22999 .03225 L
.23238 .03145 L
.23456 .03088 L
.23567 .03066 L
.23686 .03046 L
.23805 .03031 L
.23917 .03022 L
.23985 .03018 L
.2405 .03017 L
.24172 .03017 L
Mistroke
.24304 .03024 L
.24424 .03036 L
.2449 .03044 L
.24562 .03056 L
.24692 .0308 L
.24943 .03145 L
.25174 .03223 L
.25706 .0347 L
.26267 .03827 L
.27217 .04652 L
.27749 .05254 L
.28234 .05913 L
.29177 .07604 L
.30069 .09873 L
.31037 .13218 L
.32064 .17679 L
.33907 .26171 L
.34365 .27869 L
.34847 .29283 L
.35099 .29845 L
.35232 .30087 L
.35375 .30302 L
.35506 .3046 L
.35625 .30569 L
.35745 .30645 L
.35858 .30686 L
.35964 .30697 L
.36081 .30678 L
.36202 .30624 L
.36316 .30542 L
.36422 .30439 L
.36519 .30321 L
.36737 .2998 L
.3697 .29499 L
.37225 .28848 L
.37688 .27356 L
.39624 .18654 L
.40652 .14007 L
.41193 .11903 L
.41762 .10006 L
.42266 .08607 L
.42817 .07352 L
.43785 .05722 L
.44261 .05122 L
.44769 .04586 L
.45686 .0383 L
.46218 .03498 L
.46709 .03264 L
.46965 .0317 L
.47247 .03092 L
Mistroke
.47389 .03063 L
.47468 .0305 L
.47542 .0304 L
.47611 .03032 L
.47686 .03025 L
.47818 .03018 L
.47884 .03016 L
.47955 .03017 L
.48083 .03022 L
.48209 .03033 L
.48324 .03048 L
.48449 .0307 L
.48586 .031 L
.48863 .0318 L
.49105 .03272 L
.49364 .03391 L
.49832 .0366 L
.50851 .04477 L
.51426 .05093 L
.51958 .05787 L
.52934 .07493 L
.53427 .08632 L
.53971 .1015 L
.55907 .17835 L
.56903 .22581 L
.5743 .24973 L
.57993 .27231 L
.58273 .28191 L
.58537 .28974 L
.58795 .29608 L
.59032 .3007 L
.59257 .30395 L
.59371 .30515 L
.59496 .30612 L
.59621 .30673 L
.59691 .3069 L
.59756 .30697 L
.5988 .30681 L
.59998 .30631 L
.60067 .30588 L
.60132 .30537 L
.60252 .30415 L
.60382 .30247 L
.60523 .30022 L
.61008 .2892 L
.61288 .28077 L
.61582 .27044 L
.62109 .24898 L
.64101 .1556 L
.6497 .12023 L
Mistroke
.65913 .0903 L
.66436 .07756 L
.66919 .06792 L
.6787 .05363 L
.68353 .04813 L
.68885 .04306 L
.69438 .03871 L
.69963 .03534 L
.70447 .03293 L
.70721 .03188 L
.70976 .03112 L
.71097 .03083 L
.71211 .03061 L
.71315 .03044 L
.71424 .03031 L
.71544 .03021 L
.71654 .03017 L
.71773 .03017 L
.71903 .03023 L
.7197 .03028 L
.72043 .03036 L
.72175 .03055 L
.72304 .03079 L
.72424 .03107 L
.72695 .03188 L
.72982 .03301 L
.73461 .03548 L
.7399 .03904 L
.74999 .04824 L
.75924 .06019 L
.76409 .06834 L
.7694 .07921 L
.78009 .10879 L
.79036 .14778 L
.7997 .19033 L
.81059 .24176 L
.81538 .26218 L
.82064 .28133 L
.82296 .28834 L
.82545 .29474 L
.82761 .29926 L
.82996 .30304 L
.83133 .30468 L
.8326 .30581 L
.83381 .30653 L
.83511 .30692 L
.83638 .30692 L
.83758 .30656 L
.83866 .30595 L
.83982 .30499 L
Mistroke
.84112 .30355 L
.84233 .30185 L
.84509 .29677 L
.84778 .29029 L
.85065 .28179 L
.86061 .24264 L
.88045 .14966 L
.89166 .10685 L
.897 .09091 L
.90201 .07853 L
.91122 .06134 L
.9161 .05449 L
.92136 .0484 L
.92659 .04338 L
.93208 .03899 L
.93723 .03563 L
.9419 .03322 L
.94402 .03234 L
.94632 .03155 L
.9485 .03096 L
.9505 .03056 L
.95159 .0304 L
.95262 .03028 L
.95375 .0302 L
.95496 .03016 L
.95622 .03018 L
.95742 .03025 L
.9585 .03036 L
.95967 .03052 L
.96165 .0309 L
.96383 .03148 L
.96825 .03315 L
.97234 .03527 L
.97619 .03773 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^@?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hLooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=_ooool0
03Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Oooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`12ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0=_ooool002oooooo1_l00006ooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41005?ooool6o`0000Gooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@01gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01oo
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03Cooooo000jooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000012ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`00>Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000007oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000@_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
7oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool00000=_ooool003[ooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@023ooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@03Kooooo000gooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0@_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL07?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Kooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Ko
oooo000gooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Ooo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0@?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Kooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo000Koooooooo0000<_l0000Looooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Pooooo`00>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo001Sooooo`Co0000A?ooool4o`0000Cooooo00?o0000ooooooooool0
?Oooool4o`0004Gooooo0ol0000Yooooo`00H?ooool3o`0000?ooooo0ol00010ooooo`?o00000ooo
ool3o`000003ooooool0003o000003cooooo0ol00003ooooo`?o0000?oooool3o`0000?ooooo0ol0
000Vooooo`00G_ooool2o`0000Wooooo0_l0000looooo`;o00002Oooool2o`0003_ooooo0_l00009
ooooo`;o0000>oooool2o`0000Wooooo00?o0000ooooooooool08oooool002?ooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0;ooooo`;o0000>?ooool2o`0000cooooo0_l0000hoooo
o`;o00003Oooool00ol0003oooooooooo`0fooooo`;o00003?ooool00ol0003oooooooooo`0Roooo
o`009?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo000003Kooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo037ooooo000Uooooo`03o`00
0?oooooooooo03?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0booooo`03o`00
0?oooooooooo00gooooo0_l000000ooooooo0000ooooo`0dooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`0aooooo`009_ooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0<_ooool00ol0003ooooooooo
o`0=ooooo`04o`000?ooooooooooo`0003?ooooo0_l0000Cooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool0<_ooool002Oooooo00?o0000ooooooooool0;oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool03_ooool01Ol0003ooooooooo
oooooooo0000037ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo03?ooooo000Xooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`0dooooo`00:?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool0=?ooool002Wooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool04?ooool2o`00
00Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool0=Oooool002[ooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo03Gooooo000Zooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@;ooooo00?o0000ooooool000001?l00004ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03Kooooo000[ooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Jooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@09ooooool0003ooooooooooonHV9So8B4Qonk^
k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo03Oooooo000[ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Iooooo`05oa0@4?ooooooooooooooool@41002?ooool01ol0003ooooo
ooooooooooooV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool0=oooool002_ooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo01Wooooo00Go0000ooooooooooooooooo`000008oooo
o`03o`000?oooooooooo00;ooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04oooo
o`?o00001_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0hooooo`00;?ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo0000
00Oooooo00?o0000ooooooooool01?ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo000/oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Hoooo
o`05oa0@4?ooooooooooooooool@41001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo03Wooooo000]ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0Gooooo`05ogMgMonHV9SooooooiRHV?mgMgL01oooool02Ol0003ooooooooooooo
oooo0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`0iooooo`00;Oooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool05oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Ko
oooo00?o0000ooooooooool00_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006oooo
o`;o00002Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`0jooooo`00;Oooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool0>_ooool002kooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03[ooooo000^ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0kooooo`00;oooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0>oooool0
02oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool05oooool2o`0000[ooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0>oooool002oo
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03_o
oooo000`ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`0kooooo`00<?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool0??ooool0033ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo03cooooo000aooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Sooooo0_l0000<oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo03cooooo000aooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0mooooo`00<Oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool0?Oooool003;ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo03gooooo000booooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo01Wooooo0_l0000=ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03kooooo000booooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0nooooo`00<_ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0?_ooool003?ooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01[ooooo
00Ko0000onk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo02[ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0oooooo`00<oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool06?ooool01ol0
003oooooogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo03oooooo000cooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
410@00?ooooo00?o410@ooooooooool03_ooool00ol0003oooooooooo`03ooooo`?o00003Oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0oooooo`00<oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool06?ooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo
00gooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
03oooooo000cooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool02_ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`10oooo
o`00=?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02cooooo00?o0000oooooooo
ool05oooool00ol0003ooooooa0@4003ooooo`03oa0@4?oooooooooo00[ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo043ooooo000dooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Fooooo`08o`00
0?ooooooooooogMgMonHV9SooooooiRHV?mgMgL<ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`10ooooo`00=?ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool05_ooool02?l0003oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^3?ooool4o`0000Kooooo0_l0000?ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo043ooooo
000dooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`10ooooo`00=?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0@Oooool003Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo047ooooo000eooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool0;oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01cooooo0_l0000@ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo047ooooo000eooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`11ooooo`00=Oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0@Oooool003Gooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo04;ooooo000fooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`12ooooo`00=_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Mooooo`;o00004Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`12ooooo`00=_ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0@_ooool003Kooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04?ooooo000f
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`13
ooooo`00=oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03;ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0@oooool003Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool07_ooool2o`0001;ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0@oooool003Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo04?ooooo000gooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`0=ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo
00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03?ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`14ooooo`00=oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool03Oooool01OmgMgOo0000oooooonHV9SoMgMg00Go
oooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo04Cooooo000hooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0=ooooo`05oa0@4?l0003oooooooooool@
41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0000Booooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo04Cooooo000hooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`0=ooooo`;o00000_ooool00ol0003oooooooooo`0<ooooo`03ob4Q
8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo04Cooooo000hooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`0=ooooo`;o00000_ooool00ol0003oooooooooo`0<ooooo`03oeEEEOo<
c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0A?ooool003Sooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo00cooooo00Go0000oooooooooooooooooa0@400>ooooo`03ojVY
ZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo04Gooooo000hooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`0<ooooo`05o`000?nHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooo
oooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo04Gooooo000iooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`0<ooooo`05o`000?lb<S;o0000oc8b<_o^k^h02oooool5o`0000Co
oooo1?l00006ooooo`;o00005Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`15ooooo`00>Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0gooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0AOooool003Wooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04Kooooo000i
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`16
ooooo`00>Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Sooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0A_ooool003[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0hooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool08Oooool2o`0001Kooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0A_ooool003[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0iooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo04Oooooo000jooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`17ooooo`00>oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0Aoooool003_ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo04Oooooo000kooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02?o
oooo0_l0000Gooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0??ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo04Sooooo000kooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0??ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03cooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`18ooooo`00??ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0B?ooool003cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0?_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Sooooo000loooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo02Cooooo0_l0000Hooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0?_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Sooooo000mooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo043ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`19ooooo`00
?_ooool01Ol0003ooooooooooooooooo000004?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Kooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo04Wooooo000nooooo`05o`000?ooooooooooooooool00000A?ooool01?l0003o
ooooooooool0000Pooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`02o`0004?ooooo00Go0000ooooooooooooooooo`00001<ooooo`00?oooool3o`00
04Gooooo1?l0000Pooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06Oooool4o`00
04Gooooo0ol0001=ooooo`00Zoooool00ol0003oooooooooo`05ooooo`?o0000/_ooool00:_ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`2booooo`00Zoooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0;;ooooo002[ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0/_ooool00:Wooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2boooo
o`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oo
oooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?o
oooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o
0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002coooo
o`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`00
0;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002Aooooo`Co000000?o410@ooooooooool0
0_ooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`2booooo`00Toooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Q
onk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2booooo`00
Toooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool0
0oooool3o`000;;ooooo002Cooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooo
oooo00gooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000oooo
ooooool02_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`2booooo`00TOooool00omEEEGoIVIVo`00000<ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2boooo
o`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo
0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0
/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00VOooool4o`00
0003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`2booooo`00Voooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;;ooooo002Kooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2booooo`00Voooool00ol0003ooooo
ooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002booooo`00Voooool00ol0003ooooooooo
o`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2booooo`00Vooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_oo
ool009_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0;;ooooo002Iooooo`03oeEEEOmVIVKo000000gooooo1?l00006ooooo`03o`000?oooooooooo
0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o
0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002coooo
o`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`00
0;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002coooo
o`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool0097ooooo1?l000000ol@413ooooo
ooooo`02ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01Oooool00ol0003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`04ooooo`;o8B4Q
1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
/_ooool009?ooooo00?o0000ooooooooool03?ooool00onYZJWoEEEEooooo`08ooooo`03o`000?oo
oooooooo00?ooooo0ol0002booooo`00Toooool00ol0003oooooooooo`0=ooooo`03ob4Q8Ooooooo
oooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2booooo`00Toooool00ol0
003oooooooooo`0=ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005
ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00gooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03
o`000?oooooooooo00[ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0/_ooool0097ooooo00?oEEEEofIVI_l000003?ooool5o`0000Co
oooo1?l00006ooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o
0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`00
0;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002coooo
o`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00:Sooooo1Ol00006ooooo`03o`00
0?oooooooooo0;;ooooo002Xooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003ooooo
ooooo`2booooo`00ZOooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0;;ooooo002Z
ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0002booooo`00Zoooool00omgMgOoIVIVooooo`2joooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00Z?ooool01Ol0003o^[ZjoooooonHV9So410@0;_o
oooo002Xooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0^oooool00?ooooooJOooool00;7ooooo00?o
0000okZj^_ooool0]?ooool00;7ooooo0_lb<S:eooooo`00P_ooool2o`000006oa0@4?oooooooooo
oa0@4?l0003o410@6?ooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000001olb<S;ogMgM
ooooooooooooQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo1Ol00003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0O_ooool008?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`07ooooo`Ko00003?ooool00ol0003oooooooooo`06ooooo`07ogMgMolb<S;o
ooooooooooo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wo
oooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0O_ooool0
08?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Kooooo`03oiRHV?lQ8B7ok^k^
00Cooooo00Go410@oooooooooooooooooa0@401nooooo`00Poooool01_l0003oooooodA4A?m4A4Co
ooooo`0000Wooooo1_l0000<ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool04?oo
ool00ol0003oooooooooo`0;ooooo`Ko00002oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oo
ooooooooooooool00000O_ooool008?ooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Kooooo`03
o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Aooooo`03o`000?oooooooooo
01gooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000007kooooo0023oooo
o`06o`000?n7QhOoZJVYokZj^_mEEEGo00006oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo017ooooo00?o410@o`000?l000000ol0000Mooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`1looooo`00Poooool01_l0003o<S8boooooooooooo<S8bo`0001_o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01[o
oooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0O_ooool0
08;ooooo00?o410@o`000?n7QhL00_ooool00on7QhOo0000oa0@400Hooooo`03oeEEEOmVIVKo0000
00Gooooo1?l0000Booooo`03o`000?oooooooooo01[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0O_ooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-44.3769, -0.160437, \
0.309031, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.01333 0 0.309017 [
[.1001 -0.0125 -9 -9 ]
[.1001 -0.0125 9 0 ]
[.2334 -0.0125 -9 -9 ]
[.2334 -0.0125 9 0 ]
[.3667 -0.0125 -9 -9 ]
[.3667 -0.0125 9 0 ]
[.6333 -0.0125 -6 -9 ]
[.6333 -0.0125 6 0 ]
[.7666 -0.0125 -6 -9 ]
[.7666 -0.0125 6 0 ]
[.8999 -0.0125 -6 -9 ]
[.8999 -0.0125 6 0 ]
[.4875 .07725 -24 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -18 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -24 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1001 0 m
.1001 .00625 L
s
[(-30)] .1001 -0.0125 0 1 Mshowa
.2334 0 m
.2334 .00625 L
s
[(-20)] .2334 -0.0125 0 1 Mshowa
.3667 0 m
.3667 .00625 L
s
[(-10)] .3667 -0.0125 0 1 Mshowa
.6333 0 m
.6333 .00625 L
s
[(10)] .6333 -0.0125 0 1 Mshowa
.7666 0 m
.7666 .00625 L
s
[(20)] .7666 -0.0125 0 1 Mshowa
.8999 0 m
.8999 .00625 L
s
[(30)] .8999 -0.0125 0 1 Mshowa
.125 Mabswid
.12676 0 m
.12676 .00375 L
s
.15342 0 m
.15342 .00375 L
s
.18008 0 m
.18008 .00375 L
s
.20674 0 m
.20674 .00375 L
s
.26006 0 m
.26006 .00375 L
s
.28672 0 m
.28672 .00375 L
s
.31338 0 m
.31338 .00375 L
s
.34004 0 m
.34004 .00375 L
s
.39336 0 m
.39336 .00375 L
s
.42002 0 m
.42002 .00375 L
s
.44668 0 m
.44668 .00375 L
s
.47334 0 m
.47334 .00375 L
s
.52666 0 m
.52666 .00375 L
s
.55332 0 m
.55332 .00375 L
s
.57998 0 m
.57998 .00375 L
s
.60664 0 m
.60664 .00375 L
s
.65996 0 m
.65996 .00375 L
s
.68662 0 m
.68662 .00375 L
s
.71328 0 m
.71328 .00375 L
s
.73994 0 m
.73994 .00375 L
s
.79326 0 m
.79326 .00375 L
s
.81992 0 m
.81992 .00375 L
s
.84658 0 m
.84658 .00375 L
s
.87324 0 m
.87324 .00375 L
s
.07344 0 m
.07344 .00375 L
s
.04678 0 m
.04678 .00375 L
s
.02012 0 m
.02012 .00375 L
s
.92656 0 m
.92656 .00375 L
s
.95322 0 m
.95322 .00375 L
s
.97988 0 m
.97988 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .07725 m
.50625 .07725 L
s
[(0.25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(0.75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(1)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(1.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(1.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(1.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .03024 m
.02499 .03012 L
.02605 .03005 L
.02729 .03002 L
.02846 .03004 L
.02954 .0301 L
.03053 .0302 L
.03163 .03034 L
.03279 .03054 L
.0352 .0311 L
.03746 .0318 L
.04262 .03404 L
.04761 .03699 L
.05217 .04035 L
.06244 .05045 L
.0678 .05746 L
.07277 .0654 L
.07869 .07712 L
.08405 .09031 L
.09398 .12219 L
.10458 .16642 L
.11473 .2145 L
.12545 .26242 L
.12986 .27866 L
.1346 .2925 L
.13732 .29848 L
.1398 .30256 L
.14099 .30403 L
.14229 .30527 L
.14351 .30607 L
.14465 .30651 L
.1458 .30664 L
.14685 .30649 L
.14801 .30602 L
.14923 .30519 L
.15029 .30418 L
.15128 .30301 L
.15353 .29954 L
.15602 .29442 L
.15827 .28869 L
.16334 .27244 L
.1832 .1834 L
.19252 .14166 L
.20238 .10535 L
.20753 .09028 L
.2132 .07664 L
.22318 .0589 L
.22839 .05203 L
.23334 .04662 L
.24263 .03865 L
Mistroke
.24781 .03529 L
.25262 .03286 L
.25539 .03178 L
.2579 .03102 L
.25929 .03069 L
.2608 .0304 L
.26149 .0303 L
.26221 .0302 L
.26352 .03009 L
.26474 .03003 L
.26544 .03002 L
.26607 .03003 L
.26725 .03007 L
.26849 .03018 L
.2696 .03032 L
.27065 .03049 L
.27302 .03102 L
.27558 .03181 L
.27792 .03272 L
.2832 .03541 L
.28747 .03822 L
.29214 .04192 L
.30154 .05166 L
.30685 .05886 L
.31184 .06715 L
.32119 .08778 L
.33126 .11918 L
.34216 .16406 L
.36168 .2548 L
.36703 .27548 L
.36997 .28505 L
.37277 .29268 L
.37536 .29838 L
.37673 .30081 L
.37818 .30295 L
.3794 .30437 L
.38005 .30499 L
.38075 .30555 L
.38198 .30625 L
.38313 .30659 L
.38432 .30661 L
.3856 .30626 L
.38681 .30558 L
.38791 .30467 L
.3892 .30324 L
.3906 .30126 L
.39315 .29656 L
.39581 .2902 L
.39864 .28196 L
.4037 .26386 L
Mistroke
.42258 .17733 L
.432 .13597 L
.44213 .10022 L
.44703 .08662 L
.45169 .0758 L
.46044 .06014 L
.46547 .05327 L
.47003 .04806 L
.47495 .0433 L
.48026 .03899 L
.48519 .03571 L
.48973 .0333 L
.49407 .03159 L
.49625 .03095 L
.49742 .03068 L
.49865 .03044 L
.49996 .03025 L
.50116 .03012 L
.50246 .03004 L
.5032 .03002 L
.5039 .03002 L
.50514 .03006 L
.50629 .03015 L
.50754 .0303 L
.50887 .03052 L
.51117 .03104 L
.51331 .03169 L
.51817 .03372 L
.52348 .03678 L
.52829 .0403 L
.53354 .04497 L
.53909 .051 L
.54385 .05726 L
.54909 .06562 L
.55829 .08522 L
.56348 .09961 L
.56904 .11806 L
.5791 .15885 L
.59886 .25091 L
.60427 .27246 L
.60724 .28251 L
.61004 .29057 L
.61265 .29676 L
.61402 .29944 L
.61547 .30182 L
.6167 .30347 L
.61804 .30489 L
.61926 .30582 L
.62039 .30637 L
.62168 .30664 L
Mistroke
.62287 .30653 L
.62418 .30603 L
.62484 .30563 L
.62556 .30507 L
.62678 .30385 L
.62809 .30217 L
.63045 .29817 L
.6329 .29276 L
.63523 .2865 L
.63961 .27214 L
.66017 .17969 L
.66975 .13736 L
.67997 .101 L
.68493 .08712 L
.68961 .07618 L
.69835 .0604 L
.703 .05397 L
.70811 .04808 L
.71309 .04326 L
.71842 .03894 L
.72342 .03563 L
.72797 .03323 L
.73017 .0323 L
.73255 .03146 L
.73481 .03084 L
.73689 .03042 L
.73807 .03024 L
.73931 .03012 L
.74036 .03005 L
.74152 .03002 L
.74277 .03004 L
.74347 .03008 L
.74411 .03013 L
.74534 .03026 L
.74651 .03044 L
.74877 .03091 L
.75085 .0315 L
.75555 .03337 L
.76031 .03597 L
.76555 .03964 L
.77099 .04434 L
.77615 .04977 L
.781 .05593 L
.7863 .06409 L
.79558 .08322 L
.80083 .0974 L
.80642 .11551 L
.81647 .15567 L
.83648 .24885 L
.84196 .27096 L
Mistroke
.84495 .28128 L
.84774 .28954 L
.85033 .29586 L
.85268 .30042 L
.85393 .30235 L
.8553 .30406 L
.85604 .30481 L
.85673 .30539 L
.8574 .30585 L
.8581 .30622 L
.8593 .30658 L
.8604 .30662 L
.86158 .30635 L
.86287 .30567 L
.86399 .30477 L
.86519 .30348 L
.86735 .30035 L
.8701 .29488 L
.8727 .2883 L
.87755 .2727 L
.8982 .18 L
.90794 .13698 L
.91825 .10045 L
.92704 .07761 L
.93204 .06768 L
.93671 .06002 L
.9417 .05322 L
.94714 .04711 L
.95193 .0426 L
.95703 .03857 L
.9616 .03558 L
.96665 .03297 L
.96887 .03207 L
.97125 .03128 L
.9735 .0307 L
.97557 .03033 L
.97619 .03024 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^@?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hLooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=_ooool0
03Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Oooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`12ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0=_ooool002oooooo1_l00006ooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41005?ooool6o`0000Gooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@01gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01oo
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03Cooooo000jooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000012ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`00>Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000007oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000@_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
7oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool00000=_ooool003[ooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@023ooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@03Kooooo000gooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0@_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL07?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Kooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Ko
oooo000gooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Ooo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0@?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Kooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo000Koooooooo0000<_l0000Looooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Pooooo`00>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo000Sooooo`?o0000A?ooool4o`0004Cooooo1Ol00014ooooo`Co0000
A?ooool00ol0003oooooooooo`0Rooooo`009_ooool4o`0003gooooo1?l00003ooooo`?o0000?ooo
ool5o`000003ooooool0003o000000;o0000?_ooool3o`0000?ooooo1?l0000nooooo`?o00009Ooo
ool002[ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`08ooooo`;o0000>oooool2
o`0000?ooooo00?o0000ooooooooool01?ooool2o`0003[ooooo0_l0000:ooooo`;o0000>oooool0
0ol0003oooooooooo`0Vooooo`00:oooool00ol0003oooooooooo`0fooooo`;o00003Oooool00ol0
003oooooooooo`0fooooo`;o00001Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
03Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0fooooo`;o0000:Oooool002co
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Wo
oooo000]ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo00Gooooo0_l00008ooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool03oooool2o`0003Cooooo00?o0000ooooooooool0:_ooool002kooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02_ooooo000^
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0/
ooooo`00;oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0;_ooool2o`0001Kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0/oooo
o`00<?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool0;Oooool0033ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool02Oooool2o`0000cooooo00?o0000ooooooooool0
:oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
;Oooool0037ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo02kooooo000aooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1_l0
0003ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo02oooooo000booooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Cooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo
00KoV9RHob4Q8Oo^k^koooooodA4A?l00006ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`0_ooooo`00<_ooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool04_ooool01Ol@413ooooooooooooooooo410@
00cooooo00CoV9RHob4Q8Oo^k^ko00002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool0<?ooool003?ooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01;ooooo00Go0000ooooooooooooooooo`00000=
ooooo`03oiRHV?lQ8B7o000000Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0000kooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool0<?ooool003?ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo017ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?mVIVKo
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0<?ooool003Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@400>ooooo`;o00001?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0<Ooo
ool003Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[oooooo`000?l@4100
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
<Oooool003Gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`01?ooool4o`0000Kooooo0_l0000@ooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03;ooooo000eooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0booooo`00=_oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0<_oo
ool003Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo03?ooooo000fooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0cooooo`00=oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0?ooooo`;o00004_ooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`0cooooo`00=oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool0=?ooool003Oooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo03Cooooo000hooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0dooooo`00>?ooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool0=Oooool003Sooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool04Oooool2o`0001?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool0=Oooool003Sooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo03Gooooo000iooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0eooooo`00>Oooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0=_ooool0
03Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool04_ooool2o`0001Cooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0=_ooool003Wo
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03Ko
oooo000iooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0fooooo`00>_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool04oooool01_o^k^ko<S8bo`000?lb<S;ok^k^o`0000Cooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
03Oooooo000jooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`0Cooooo`06ogMgMonHV9SooooooiRHV?mgMgOo00001?ooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0:_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo03Oooooo000joooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Coooo
o`06oa0@4?ooooooooooooooool@413o00003oooool00ol0003oooooooooo`03ooooo`?o00005Ooo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0gooooo`00>_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo02[ooooo00?o0000ooooooooool04oooool01?l0003oooooooooooooool2o`0000kooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo03Oooooo000j
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0B
ooooo`04o`000?ooooooooooooooo`;o00002oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02_ooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0hooooo`00>oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool04_ooool01_l@413ooooooooo
oooooooo410@o`0000_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo03Sooooo000kooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`0Booooo`06ogMgMonHV9SooooooiRHV?mgMgOo00002oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0>?ooool003_o
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01;o
oooo00Gok^k^oc8b<_l0003o<S8bo`00000<ooooo`Co00001_ooool2o`0001Oooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool0>?ooool003_ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo03Sooooo000looooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0iooooo`00??ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0>Oooool003cooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05?ooool2
o`0001Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool0>Oooool003cooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo03Wooooo000looooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0jooooo`00?Oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0>_ooool003gooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03[ooooo000m
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo01Kooooo0_l0000Iooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03[ooooo000moooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0joooo
o`00?Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0>oooool003kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0booooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo03_ooooo000nooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0kooooo`00?_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Gooooo`;o00006_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0kooooo`00?_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0>oooool003oooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0dooooo`03o`000?oooooooooo00Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04oooo
o`03o`000?lQ8B7o8B4Q00Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0looooo`00?oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000ob4Q8OlQ8B401_ooool00omEEEGoZJVYooooo`07
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0l
ooooo`00?oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool01_ooool01Ol@413ooooooooooooooooo410@00?ooooo00?o0000ooooooooool01oooool0
0onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0000Jooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo03cooooo000oooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`08
ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo03cooooo000oooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`08ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0?Oooool0043ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Gooooo00Go410@
oooooooooooooooooa0@4003ooooo`03o`000?oooooooooo00Sooooo00?oZJVYogMgMoooool00ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0?Ooo
ool0043ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`03o`000?oooooooooo00Kooooo00Go
410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0mooooo`00@?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool01Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo
00?o0000ooooooooool01_ooool5o`0000Cooooo1?l00006ooooo`;o00007?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0mooooo`00@?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Oooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0?Oooool0043ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0h
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo03kooooo0011ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0nooooo`00@Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0iooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool0?_ooool0047ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
6_ooool2o`0001gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0iooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0?_ooool0047ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03kooooo0012ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0oooooo`00@_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0?oooool004;o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03oo
oooo0013ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0??ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo01cooooo0_l0000Oooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0??ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo043ooooo
0013ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0?Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`10ooooo`00@oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0@?ooool004Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo047ooooo0014ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01gooooo0_l0000Oooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo047ooooo0014ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`12ooooo`00AOooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo043ooooo0_l00004ooooo`03o`000?oooooooooo01?ooooo1?l000000ol@413ooooooooo
o`03ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`10ooooo`05o`000?ooooooooooooooool00000AOooool004Kooooo00Co0000oooooooooooo0000
A?ooool00ol0003oooooooooo`02o`0001Sooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo00;o0000@oooool2o`0000;ooooo00?o0000ooooooooool0
@oooool004Kooooo1?l00014ooooo`Co00006Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo027ooooo0ol00015ooooo`?o0000A_ooool00:_ooooo00?o0000ooooooooool01Oooool3
o`000;;ooooo002[ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/_ooool00:_o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2booooo`00Zoooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0;;ooooo002Yooooo`03oeEEEOmVIVKo000000Oooooo00?o
0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2boooo
o`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/ooo
ool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo
0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0
/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00TOooool4o`00
0003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool01?ooool2ob4Q
8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool0/_ooool009?ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP09oooo
o`03o`000?oooooooooo00?ooooo0ol0002booooo`00Toooool00ol0003oooooooooo`0<ooooo`03
oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2booooo`00
Toooool00ol0003oooooooooo`0=ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;;ooooo
002Cooooo`03o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0/_ooool0097ooooo00?oEEEEofIVI_l000003?oo
ool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000/oooool00;?ooooo00?o
0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0
003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002coooo
o`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0
/_ooool009Wooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/_ooool009_ooooo00?o0000ooooooooool01?oo
ool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2booooo`00Voooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/_ooool0
09_ooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`04ooooo`?o0000/_ooool009_o
oooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0/_ooool009_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0;;ooooo002Kooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`2booooo`00VOooool00omEEEGoIVIVo`00000=ooooo`Co00001_oo
ool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo
0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0
/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0
003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooo
ooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002Aoooo
o`Co000000?o410@ooooooooool00_ooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000oooo
ooooool01?ooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00cooooo00?oZJVYoeEEEOoo
ool02?ooool00ol0003oooooooooo`03ooooo`?o0000/_ooool009?ooooo00?o0000ooooooooool0
3Oooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
/_ooool009?ooooo00?o0000ooooooooool03Oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2booooo`00Toooool00ol0003ooooooooo
o`0=ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`2booooo`00Toooool00ol0003oooooooooo`0:ooooo`05oa0@4?oooooooooooooooolb<S801?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;;ooooo002Aooooo`03oeEEEOmVIVKo
000000cooooo1Ol00004ooooo`Co00001_ooool2o`000;?ooooo002cooooo`03o`000?oooooooooo
0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0
/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0
003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooo
ooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002Xoooo
o`Go00001_ooool00ol0003oooooooooo`2booooo`00Z?ooool01OnHV9So8B4Qonk^k_ooooooA4A4
00Kooooo00?o0000ooooooooool0/_ooool00:Wooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003o
ooooooooo`2booooo`00Z_ooool00onHV9So8B4Qonk^kP06ooooo`?o0000/_ooool00:_ooooo00?o
MgMgofIVI_ooool0^_ooool00:cooooo00?o0000ooooooooool0^Oooool00:Sooooo00Go0000okZj
^_ooooooV9RHoa0@402kooooo`00Z?ooool01OnHV9So410@o`000?lQ8B7oc<c<0;_ooooo003ooooo
ofWooooo002aooooo`03o`000?nj^[[ooooo0;Cooooo002aooooo`;o<S8b]Oooool008;ooooo0_l0
00001_l@413oooooooooool@413o0000oa0@41Sooooo1?l000001Ol@413oooooooooooooooooA4A4
00;o000000Oo<S8bomgMgOooooooooooohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4
okZj^P0Hooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM07gooooo0023ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`0000cooooo00?o0000ooooooooool0
1_ooool01omgMgOo<S8booooooooooooc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo
410@00Wooooo1_l00009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8boooo
o`1looooo`00Poooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01_ooooo00?oV9RH
ob4Q8Oo^k^h02Oooool00ol0003oooooooooo`1kooooo`00Poooool01_l0003oooooodA4A?m4A4Co
ooooo`0000Wooooo1_l0000<ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool04?oo
ool00ol0003oooooooooo`0;ooooo`Ko00002oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo07cooooo0023ooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo00006oooool00ol0003ooooo
ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`04Oooool00ol0003oooooooooo`0Mooooo`03
ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c01mooooo`00Poooool01_l0003o
QhN7ojVYZOnj^[[oEEEEo`0001_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0A
ooooo`03oa0@4?l0003o000000?o00007Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo07oooooo0023ooooo`06o`000?lb<S;ooooooooooolb<S;o00006oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool06_ooool01Ol0003o^[Zjoooo
oonHV9So410@00Cooooo00?o0000ooooooooool0Ooooool008;ooooo00?o410@o`000?n7QhL00_oo
ool00on7QhOo0000oa0@400Hooooo`03oeEEEOmVIVKo000000Gooooo1?l0000Booooo`03o`000?oo
oooooooo01[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co0000O_ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-44.3769, -0.160437, \
0.309031, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.01333 0 0.309017 [
[.1001 -0.0125 -9 -9 ]
[.1001 -0.0125 9 0 ]
[.2334 -0.0125 -9 -9 ]
[.2334 -0.0125 9 0 ]
[.3667 -0.0125 -9 -9 ]
[.3667 -0.0125 9 0 ]
[.6333 -0.0125 -6 -9 ]
[.6333 -0.0125 6 0 ]
[.7666 -0.0125 -6 -9 ]
[.7666 -0.0125 6 0 ]
[.8999 -0.0125 -6 -9 ]
[.8999 -0.0125 6 0 ]
[.4875 .07725 -24 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -18 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -24 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1001 0 m
.1001 .00625 L
s
[(-30)] .1001 -0.0125 0 1 Mshowa
.2334 0 m
.2334 .00625 L
s
[(-20)] .2334 -0.0125 0 1 Mshowa
.3667 0 m
.3667 .00625 L
s
[(-10)] .3667 -0.0125 0 1 Mshowa
.6333 0 m
.6333 .00625 L
s
[(10)] .6333 -0.0125 0 1 Mshowa
.7666 0 m
.7666 .00625 L
s
[(20)] .7666 -0.0125 0 1 Mshowa
.8999 0 m
.8999 .00625 L
s
[(30)] .8999 -0.0125 0 1 Mshowa
.125 Mabswid
.12676 0 m
.12676 .00375 L
s
.15342 0 m
.15342 .00375 L
s
.18008 0 m
.18008 .00375 L
s
.20674 0 m
.20674 .00375 L
s
.26006 0 m
.26006 .00375 L
s
.28672 0 m
.28672 .00375 L
s
.31338 0 m
.31338 .00375 L
s
.34004 0 m
.34004 .00375 L
s
.39336 0 m
.39336 .00375 L
s
.42002 0 m
.42002 .00375 L
s
.44668 0 m
.44668 .00375 L
s
.47334 0 m
.47334 .00375 L
s
.52666 0 m
.52666 .00375 L
s
.55332 0 m
.55332 .00375 L
s
.57998 0 m
.57998 .00375 L
s
.60664 0 m
.60664 .00375 L
s
.65996 0 m
.65996 .00375 L
s
.68662 0 m
.68662 .00375 L
s
.71328 0 m
.71328 .00375 L
s
.73994 0 m
.73994 .00375 L
s
.79326 0 m
.79326 .00375 L
s
.81992 0 m
.81992 .00375 L
s
.84658 0 m
.84658 .00375 L
s
.87324 0 m
.87324 .00375 L
s
.07344 0 m
.07344 .00375 L
s
.04678 0 m
.04678 .00375 L
s
.02012 0 m
.02012 .00375 L
s
.92656 0 m
.92656 .00375 L
s
.95322 0 m
.95322 .00375 L
s
.97988 0 m
.97988 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .07725 m
.50625 .07725 L
s
[(0.25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(0.75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(1)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(1.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(1.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(1.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04216 m
.02846 .0384 L
.03279 .03548 L
.03754 .03293 L
.04018 .03181 L
.04262 .03098 L
.04518 .03033 L
.04652 .03008 L
.04721 .02998 L
.04795 .02988 L
.04919 .02977 L
.05035 .02972 L
.05106 .0297 L
.05174 .02971 L
.053 .02977 L
.05413 .02986 L
.05534 .03002 L
.05648 .03021 L
.05752 .03043 L
.06005 .03111 L
.06244 .03194 L
.06757 .03436 L
.07299 .03778 L
.08269 .04614 L
.08808 .05223 L
.09312 .05913 L
.09861 .06835 L
.10458 .08089 L
.11503 .11068 L
.12493 .14874 L
.14349 .23496 L
.1484 .25639 L
.15369 .27648 L
.15612 .2843 L
.15868 .2914 L
.1609 .2965 L
.16326 .30083 L
.16456 .30268 L
.16573 .30403 L
.16692 .30507 L
.16803 .30576 L
.16933 .3062 L
.17053 .30626 L
.17185 .30593 L
.17252 .30561 L
.17325 .30514 L
.17468 .30386 L
.17599 .30228 L
.17894 .29734 L
.18168 .29113 L
Mistroke
.18427 .28388 L
.19388 .24783 L
.20412 .20038 L
.22252 .12034 L
.23283 .08817 L
.23863 .07452 L
.24397 .06441 L
.25379 .05045 L
.25873 .04512 L
.26415 .04026 L
.26941 .03641 L
.27438 .03353 L
.27885 .0316 L
.28137 .0308 L
.2837 .03025 L
.2849 .03004 L
.28619 .02987 L
.28741 .02976 L
.28853 .02971 L
.28977 .02971 L
.29047 .02973 L
.29112 .02977 L
.29244 .02989 L
.29318 .02998 L
.29385 .03008 L
.29652 .03064 L
.29802 .03106 L
.2994 .03152 L
.30463 .0338 L
.30932 .03657 L
.31435 .04026 L
.32343 .04898 L
.32897 .05589 L
.33423 .06394 L
.33891 .07264 L
.34408 .08429 L
.35372 .11269 L
.36397 .1528 L
.38238 .23856 L
.38729 .25964 L
.39246 .27874 L
.39687 .29163 L
.39937 .29728 L
.4017 .30135 L
.403 .30311 L
.40369 .30389 L
.40442 .30459 L
.40505 .3051 L
.40575 .30556 L
.40698 .3061 L
Mistroke
.40817 .30627 L
.40946 .3061 L
.41067 .30558 L
.41178 .3048 L
.41315 .30345 L
.41442 .30182 L
.4173 .29681 L
.41984 .29095 L
.42255 .28332 L
.43285 .24403 L
.44398 .19196 L
.4536 .14812 L
.46415 .1081 L
.46913 .09299 L
.47447 .07947 L
.48411 .06106 L
.48977 .05303 L
.49513 .04684 L
.49991 .04224 L
.50518 .03801 L
.50983 .03497 L
.51484 .03243 L
.5176 .03137 L
.52013 .03062 L
.52139 .03033 L
.52255 .03011 L
.52377 .02993 L
.52441 .02986 L
.5251 .02979 L
.52634 .02972 L
.52748 .02971 L
.52874 .02974 L
.52937 .02978 L
.53007 .02984 L
.53124 .02998 L
.53249 .03018 L
.53476 .03068 L
.53711 .03139 L
.53934 .03223 L
.54352 .03423 L
.54858 .03735 L
.55315 .04084 L
.55807 .04532 L
.56339 .05114 L
.56833 .05768 L
.57287 .06488 L
.58179 .08334 L
.59156 .11182 L
.60067 .1468 L
.6113 .19538 L
Mistroke
.62135 .24248 L
.6261 .26251 L
.63113 .28064 L
.63376 .28847 L
.63666 .29559 L
.63929 .30057 L
.64047 .30231 L
.64176 .30386 L
.643 .30499 L
.64415 .30573 L
.64525 .30614 L
.64643 .30627 L
.64758 .30609 L
.64867 .30563 L
.64965 .30498 L
.6507 .30403 L
.65187 .3027 L
.65314 .30089 L
.65572 .29614 L
.66033 .28428 L
.66557 .26629 L
.67053 .24584 L
.67983 .20265 L
.68997 .15558 L
.70074 .11315 L
.7102 .08515 L
.71558 .07295 L
.72064 .06359 L
.7295 .05101 L
.73906 .04132 L
.74401 .03748 L
.74862 .03457 L
.75368 .03212 L
.75652 .0311 L
.75909 .03041 L
.76041 .03015 L
.76113 .03003 L
.7618 .02994 L
.76299 .02981 L
.7643 .02973 L
.76503 .02971 L
.76572 .02971 L
.76702 .02975 L
.76774 .0298 L
.76842 .02986 L
.76994 .03007 L
.77128 .03031 L
.77254 .0306 L
.7749 .03129 L
.77744 .03223 L
Mistroke
.78019 .03348 L
.78971 .0396 L
.79512 .0443 L
.80016 .04959 L
.81033 .06379 L
.81604 .07458 L
.82123 .08671 L
.83116 .11707 L
.84034 .15362 L
.85106 .20336 L
.86112 .24979 L
.8655 .26757 L
.87012 .28342 L
.87253 .29028 L
.87517 .29649 L
.87758 .30087 L
.87874 .30254 L
.87981 .30381 L
.8811 .305 L
.88178 .30547 L
.8825 .30585 L
.88371 .30622 L
.88439 .30628 L
.88504 .30623 L
.88623 .30589 L
.88732 .30529 L
.88858 .30425 L
.88978 .30293 L
.89242 .29887 L
.89487 .29378 L
.90042 .27793 L
.91003 .23963 L
.91905 .19726 L
.92908 .15116 L
.93964 .11042 L
.94874 .08405 L
.95355 .07321 L
.9587 .06365 L
.96776 .05082 L
.97619 .04216 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^@?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hLooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=_ooool0
03Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Oooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`12ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0=_ooool002oooooo1_l00006ooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41005?ooool6o`0000Gooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@01gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01oo
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03Cooooo000jooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000012ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`00>Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000007oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000@_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
7oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool00000=_ooool003[ooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@023ooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@03Kooooo000gooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0@_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL07?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Kooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Ko
oooo000gooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Ooo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0@?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Kooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo000Koooooooo0000<_l0000Looooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Pooooo`00>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo000Yooooo`Go0000@oooool5o`0003gooooo00?o0000ooooooooool0
0oooool6o`0004?ooooo1Ol0001Qooooo`009_ooool3o`0000Gooooo0_l0000nooooo`Co00001?oo
ool3o`0003[ooooo0_l00002ooooo`;o00001Oooool2o`0003oooooo0ol00004ooooo`Co0000G_oo
ool002Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0iooooo`;o00002oooool2
o`0003Sooooo00Co0000oooooooooooo00002Oooool2o`0003cooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`1Kooooo`009?ooool00ol0003oooooooooo`0:ooooo`;o0000>?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03Gooooo0ol0000<ooooo`03o`000?oooooo
oooo03Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Jooooo`008oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo00gooooo0_l0000gooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Rooooo`00=?ooool00ol0003o
ooooooooo`0booooo`;o00004Oooool00ol0003oooooooooo`0cooooo`?o00004?ooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`0Rooooo`00=Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0<Oooool00ol0003oooooo`00000Aooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02?ooooo
000fooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0_ooooo`04o`000?ooooooooooo`0001;ooooo00?o0000ooooooooool0<?ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool09?ooool003Oooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02kooooo00Co
0000oooooooooooo00004oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Uooooo`00>?ooool00ol0003ooooooooo
o`0[ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0;Oooool01Ol0003ooooooooo
oooooooo000001Cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool09_ooool003Sooooo00?o0000ooooooooool0:ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool00_oo
ool2o`0001?ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool09oooool003Wooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02Oooooo000iooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0<ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_l000001Ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02Sooooo000iooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0;ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03o`00
0?lb<S;ooooo00Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Xooooo`00>_oo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02ooo
ool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02?ooool2o`0000Gooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0Xooooo`00>_ooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oMgMgoc8b<P05ooooo`?o0000
5Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0Yooooo`00>oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000kooooo
00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0Yooooo`00>oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool02Oooool01Ol@413ooooooooooooooooo410@00oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool0:_ooool003cooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo00Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41001?ooool2o`0000Sooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0Zooooo`00??ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`0001Sooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0:oooool0
03cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
02_ooooo000mooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`0[ooooo`00?Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool0;?ooool003gooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo02cooooo000nooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Sooooo0_l0000J
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo02cooooo000nooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0]ooooo`00?_ooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool0;Oooool003kooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02gooooo000oooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0^ooooo`00?oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`09ooooo`;o00006oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0^ooooo`00?oooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0;_ooool0043o
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02ko
oooo0010ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0_ooooo`00@?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0:ooooo`;o00007?ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0_ooooo`00@?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool0;oooool0047ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo02oooooo0011ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`0<ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@03ooooool0003ooooo00;ooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0<?ooool0047ooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q00?oooooo`000?ooool01Oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool0<?ooool0047ooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo00_ooooo00Go410@oooooooooooooooooa0@4008
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool3o`0001cooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool0<?ooool004;ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0[oooo
o`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo
oooo00Gooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo033ooooo0012ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo037ooooo0012ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`0;ooooo`05oa0@4?ooooooooooooooool@41001oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0aooooo`00@_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool02_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0<Ooo
ool004?ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo00[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00?ooooo1?l0
0006ooooo`;o00007_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02cooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`0aooooo`00@oooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0<Oooool004?ooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03;ooooo0013ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0booooo`00
@oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0=ooooo`;o00007oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0booooo`00A?oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0<_oo
ool004Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo03;ooooo0014ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0cooooo`00A?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0<oooool004Gooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03_ooool2o`00023ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0<oooool004Gooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo03?ooooo0015ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0dooooo`00AOooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0=?ooool004Kooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0<oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Cooooo0016ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo00oooooo0_l0000Qooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
<oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Cooooo0016ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0eooooo`00A_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03?ooooo00Oo0000ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`04o`000?oooooo0000onk^kPGooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0=Oooool004Ko
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0dooooo`07o`000?ooooooMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01?l0003ooooooeEEEOnYZJT8ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0eooooo`00Aoooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooool@41000oooool0
0ol@413oooooooooo`09ooooo`04o`000?ooooooZJVYoeEEE@Wooooo00?o0000ooooooooool00ooo
ool3o`00027ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool0=Oooool004Oooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0eooooo`;o00000oooool00ol0003oooooooooo`09ooooo`04o`000?oooooo
ooooob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo03Gooooo0017ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0=Oooool2
o`0000?ooooo00?o0000ooooooooool02?ooool01_l0003oooooooooooooooooEEEEolc<c0Cooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0=_ooool004Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0eooooo`03o`00
0?l@413ooooo00;ooooo00?o410@ooooooooool02?ooool01_l0003oooooooooooooooooZJVYogMg
M`Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
03Kooooo0017ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0=_ooool01_l0003o
MgMgoiRHV?ooooooV9RHogMgM`[ooooo00?o0000oa0@4?ooool00_ooool00olb<S;oooooooooo`02
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0f
ooooo`00B?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Oooooo00Go0000oc8b
<_l0003o<S8bonk^kP0:ooooo`Ko00001?ooool4o`0000Kooooo0_l0000Sooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo03Kooooo0018ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0fooooo`00B?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0=oooool004Sooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>?ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo03Oooooo0018ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0>Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0gooooo`00BOooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0B
ooooo`;o00009?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0gooooo`00BOooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0joooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0=oooool004Wooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0>_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Oooooo001:ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo03[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0hooooo`00B_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>?oo
ool004[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0looooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool05?ooool2o`0002Kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0looooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>?ooool0
04_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
03Sooooo001;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0?Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0iooooo`00Boooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0>Oooool004_ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0oooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05Oooool2o`0002Oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0>_ooool004cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo03[ooooo001=ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo1?l000000ol@
413oooooooooo`03ooooo`03o`000?oooooooooo02Oooooo00Go0000ooooooooooooooooo`000014
ooooo`05o`000?ooooooooooooooool00000?Oooool004gooooo0_l000000ooooooo0000o`000013
ooooo`;o00000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0:?ooool01?l0003oooooooooool00014ooooo`04o`000?ooooooooooo`0003kooooo
001>ooooo`?o0000AOooool3o`0001;ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Xooooo`?o0000A_ooool3o`0003kooooo002[ooooo`03o`000?oooooooooo00Gooooo0ol0002b
ooooo`00Zoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;;ooooo002[ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0/_ooool00:_ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`2booooo`00ZOooool00omEEEGoIVIVo`000007ooooo`03o`000?oo
oooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?o
oooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0
002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2boooo
o`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/ooo
ool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo
0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool0097ooooo1?l000000ol@
413oooooooooo`02ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00Cooooo0_lQ8B44oooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo0;;ooooo002Cooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0
003oooooooooo`03ooooo`?o0000/_ooool009?ooooo00?o0000ooooooooool03?ooool00onHV9So
8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/_ooool009?ooooo
00?o0000ooooooooool03Oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2booooo`00Tooo
ool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;;ooooo002Aooooo`03oeEEEOmVIVKo000000cooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`000;?ooooo002cooooo`03o`000?oo
oooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo
0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o
0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0
003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002Iooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8b
omgMg@05ooooo`03o`000?oooooooooo0;;ooooo002Kooooo`03o`000?oooooooooo00Cooooo0_lQ
8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/_ooool009_ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;;ooooo002Koooo
o`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool3o`000;;ooooo002Kooooo`03
o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo
0;;ooooo002Kooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2booooo`00Voooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0/_ooool009Wooooo00?oEEEEofIVI_l000003Oooool4o`0000Kooooo00?o
0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2boooo
o`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/ooo
ool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo
0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0
/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00TOooool4o`00
0003oa0@4?oooooooooo00;ooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo
00Cooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`0<ooooo`03ojVYZOmEEEGooooo00So
oooo00?o0000ooooooooool00oooool3o`000;;ooooo002Cooooo`03o`000?oooooooooo00gooooo
00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;;ooooo
002Cooooo`03o`000?oooooooooo00gooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool03Ooo
ool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_oo
ool009?ooooo00?o0000ooooooooool02_ooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2booooo`00TOooool00omEEEGoIVIVo`00000<
ooooo`Go00001?ooool4o`0000Kooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2boooo
o`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo
0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0
/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00Z?ooool5o`00
00Kooooo00?o0000ooooooooool0/_ooool00:Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A006oooo
o`03o`000?oooooooooo0;;ooooo002Yooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000oooooooo
ool0/_ooool00:[ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;;ooooo002[ooooo`03ogMgMomV
IVKooooo0;[ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Xooooo`05o`000?nj^[[ooooo
oiRHV?l@4100^oooool00:Sooooo00GoV9RHoa0@4?l0003o8B4Qolc<c02kooooo`00oooooomYoooo
o`00/Oooool00ol0003o^[Zjooooo`2dooooo`00/Oooool2oc8b<[Gooooo0022ooooo`;o000000Ko
410@oooooooooooo410@o`000?l@410Hooooo`Co000000Go410@ooooooooooooooooodA4A002o`00
0007oc8b<_oMgMgooooooooooon7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X0
6?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1noooo
o`00Poooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l0000<ooooo`03
o`000?oooooooooo00Kooooo00OoMgMgoc8b<_ooooooooooolc<c?l0003o410@00cooooo00Go410@
okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002Oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`1nooooo`00Poooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo01kooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo07co
oooo0023ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000cooooo00?o0000oooo
ooooool01_ooool00omgMgOo<S8booooo`0@ooooo`03o`000?oooooooooo00_ooooo1_l0000<oooo
o`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00001nooooo`00Poooool01_l0
003ogMgMoc8b<_mEEEGogMgMo`0001_ooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<017ooooo00?o0000ooooooooool07?ooool00ol@413o0000okZj^P03ooooo`05o`00
0?ooooooooooooooool00000O_ooool008?ooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Koooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol@413o0000o`000003o`00
01cooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@07kooooo0023oooo
o`06o`000?lb<S;ooooooooooolb<S;o00006oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool06_ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`1nooooo`00P_ooool00ol@413o0000ohN7Q`02ooooo`03ohN7
Qol0003o410@01Sooooo00?oEEEEofIVI_l000001Oooool4o`0001;ooooo00?o0000ooooooooool0
6_ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1noooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-44.3769, -0.160437, \
0.309031, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.01333 0 0.309017 [
[.1001 -0.0125 -9 -9 ]
[.1001 -0.0125 9 0 ]
[.2334 -0.0125 -9 -9 ]
[.2334 -0.0125 9 0 ]
[.3667 -0.0125 -9 -9 ]
[.3667 -0.0125 9 0 ]
[.6333 -0.0125 -6 -9 ]
[.6333 -0.0125 6 0 ]
[.7666 -0.0125 -6 -9 ]
[.7666 -0.0125 6 0 ]
[.8999 -0.0125 -6 -9 ]
[.8999 -0.0125 6 0 ]
[.4875 .07725 -24 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -18 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -24 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1001 0 m
.1001 .00625 L
s
[(-30)] .1001 -0.0125 0 1 Mshowa
.2334 0 m
.2334 .00625 L
s
[(-20)] .2334 -0.0125 0 1 Mshowa
.3667 0 m
.3667 .00625 L
s
[(-10)] .3667 -0.0125 0 1 Mshowa
.6333 0 m
.6333 .00625 L
s
[(10)] .6333 -0.0125 0 1 Mshowa
.7666 0 m
.7666 .00625 L
s
[(20)] .7666 -0.0125 0 1 Mshowa
.8999 0 m
.8999 .00625 L
s
[(30)] .8999 -0.0125 0 1 Mshowa
.125 Mabswid
.12676 0 m
.12676 .00375 L
s
.15342 0 m
.15342 .00375 L
s
.18008 0 m
.18008 .00375 L
s
.20674 0 m
.20674 .00375 L
s
.26006 0 m
.26006 .00375 L
s
.28672 0 m
.28672 .00375 L
s
.31338 0 m
.31338 .00375 L
s
.34004 0 m
.34004 .00375 L
s
.39336 0 m
.39336 .00375 L
s
.42002 0 m
.42002 .00375 L
s
.44668 0 m
.44668 .00375 L
s
.47334 0 m
.47334 .00375 L
s
.52666 0 m
.52666 .00375 L
s
.55332 0 m
.55332 .00375 L
s
.57998 0 m
.57998 .00375 L
s
.60664 0 m
.60664 .00375 L
s
.65996 0 m
.65996 .00375 L
s
.68662 0 m
.68662 .00375 L
s
.71328 0 m
.71328 .00375 L
s
.73994 0 m
.73994 .00375 L
s
.79326 0 m
.79326 .00375 L
s
.81992 0 m
.81992 .00375 L
s
.84658 0 m
.84658 .00375 L
s
.87324 0 m
.87324 .00375 L
s
.07344 0 m
.07344 .00375 L
s
.04678 0 m
.04678 .00375 L
s
.02012 0 m
.02012 .00375 L
s
.92656 0 m
.92656 .00375 L
s
.95322 0 m
.95322 .00375 L
s
.97988 0 m
.97988 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .07725 m
.50625 .07725 L
s
[(0.25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(0.75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(1)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(1.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(1.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(1.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(35) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .07658 m
.02846 .06723 L
.03279 .05992 L
.03793 .05268 L
.04262 .04721 L
.0522 .03857 L
.05746 .03507 L
.06244 .03255 L
.06487 .03161 L
.06754 .03081 L
.06889 .03049 L
.07034 .03023 L
.07104 .03013 L
.0717 .03005 L
.07295 .02994 L
.07411 .02989 L
.07535 .02988 L
.07653 .02993 L
.07759 .03002 L
.07884 .03017 L
.08019 .0304 L
.08265 .03097 L
.0853 .03181 L
.0882 .03299 L
.09407 .03617 L
.09951 .03998 L
.10458 .04431 L
.10959 .04938 L
.11503 .05602 L
.11983 .0631 L
.12493 .07225 L
.13457 .09537 L
.14349 .12482 L
.16318 .21255 L
.17181 .25203 L
.17669 .27146 L
.18124 .28642 L
.18358 .2927 L
.1858 .29763 L
.18702 .29991 L
.18835 .30201 L
.18954 .30357 L
.19066 .30474 L
.19186 .30567 L
.19317 .3063 L
.19445 .30653 L
.19517 .30649 L
.19583 .30635 L
.19699 .30585 L
.19827 .30493 L
Mistroke
.19947 .30373 L
.20059 .30232 L
.20332 .2977 L
.20589 .29191 L
.21069 .27771 L
.22144 .23388 L
.23986 .14818 L
.2503 .10833 L
.2554 .09278 L
.26005 .08082 L
.26969 .0618 L
.275 .05402 L
.28002 .04796 L
.29013 .0387 L
.29583 .03491 L
.29858 .03345 L
.3011 .03232 L
.30332 .03149 L
.30575 .03078 L
.30693 .03051 L
.30819 .03027 L
.30888 .03016 L
.30952 .03008 L
.31075 .02996 L
.31192 .02989 L
.31299 .02988 L
.31417 .02991 L
.31541 .02999 L
.31649 .03011 L
.3175 .03026 L
.3198 .03072 L
.32247 .03149 L
.325 .03243 L
.32975 .03474 L
.33486 .03795 L
.34042 .04229 L
.3498 .05181 L
.35515 .05884 L
.36017 .0669 L
.37027 .08882 L
.37595 .10529 L
.38117 .12327 L
.40167 .21443 L
.41167 .2594 L
.4164 .27715 L
.42076 .29037 L
.42292 .29559 L
.4253 .30022 L
.42769 .30363 L
.429 .30495 L
Mistroke
.43022 .30583 L
.43138 .30634 L
.43247 .30653 L
.43346 .30646 L
.43453 .30613 L
.43569 .30546 L
.43693 .30441 L
.4381 .30309 L
.43916 .30163 L
.4417 .29713 L
.44403 .29179 L
.4493 .27596 L
.45884 .23709 L
.47927 .14259 L
.48925 .10555 L
.49834 .08034 L
.50286 .07063 L
.50776 .06184 L
.51668 .04958 L
.52164 .04433 L
.52689 .03972 L
.53182 .03619 L
.53634 .03362 L
.54091 .03167 L
.5432 .03095 L
.54572 .03037 L
.54704 .03015 L
.54825 .03001 L
.54892 .02995 L
.54964 .02991 L
.55095 .02988 L
.55218 .0299 L
.55349 .02999 L
.5546 .03011 L
.55582 .03029 L
.5582 .0308 L
.56038 .03143 L
.56527 .0334 L
.5698 .03588 L
.57411 .03878 L
.58373 .0472 L
.58901 .05315 L
.59397 .05991 L
.59861 .06752 L
.60363 .07747 L
.61237 .10009 L
.62191 .13343 L
.63236 .17915 L
.6434 .23154 L
.65345 .2735 L
Mistroke
.65827 .28879 L
.66099 .29553 L
.6635 .3004 L
.6657 .30353 L
.66695 .30482 L
.66812 .30571 L
.66935 .3063 L
.67047 .30652 L
.67177 .30641 L
.67301 .30594 L
.67433 .30505 L
.67552 .30389 L
.6769 .30215 L
.6782 .30012 L
.68302 .28947 L
.68575 .28141 L
.68826 .27287 L
.69394 .25032 L
.71436 .15553 L
.72433 .11575 L
.73342 .08784 L
.73792 .07696 L
.74282 .06708 L
.75174 .0533 L
.75668 .04745 L
.76194 .04229 L
.76686 .03829 L
.77138 .03529 L
.77594 .0329 L
.77826 .03194 L
.78074 .0311 L
.78205 .03075 L
.78324 .03048 L
.78445 .03026 L
.78556 .0301 L
.78687 .02996 L
.78755 .02992 L
.78828 .02989 L
.7895 .02988 L
.79019 .0299 L
.79084 .02993 L
.79197 .03003 L
.7932 .03018 L
.79436 .03037 L
.79544 .0306 L
.79748 .03112 L
.79965 .03183 L
.80462 .03403 L
.80912 .03665 L
.81916 .04458 L
Mistroke
.82839 .05479 L
.83323 .06169 L
.83853 .0709 L
.84402 .08272 L
.84922 .09642 L
.85945 .13123 L
.86876 .17124 L
.87891 .21943 L
.88447 .24501 L
.88969 .26663 L
.89464 .28378 L
.89917 .29572 L
.90162 .30045 L
.90287 .30235 L
.9042 .304 L
.90491 .3047 L
.90555 .30525 L
.9068 .30603 L
.9075 .30631 L
.90825 .30649 L
.90897 .30653 L
.90963 .30646 L
.91069 .30614 L
.91183 .3055 L
.91291 .30461 L
.91389 .30357 L
.9163 .30011 L
.91858 .29565 L
.92312 .28369 L
.92806 .26657 L
.94741 .17853 L
.95843 .13058 L
.96879 .09532 L
.97619 .07658 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^@?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hLooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=_ooool0
03Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Oooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`12ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0=_ooool002oooooo1_l00006ooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41005?ooool6o`0000Gooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@01gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01oo
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03Cooooo000jooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000012ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`00>Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000007oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000@_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
7oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool00000=_ooool003[ooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@023ooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@03Kooooo000gooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0@_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL07?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Kooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Ko
oooo000gooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Ooo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0@?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Kooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo000Koooooooo0000<_l0000Looooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Pooooo`00>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo000`ooooo`Go0000@oooool5o`0003Kooooo00?o0000ooooooooool0
2oooool4o`0004Cooooo1Ol0001Jooooo`00;_ooool3o`0000?ooooo1?l0000nooooo`?o00001?oo
ool2o`0003Cooooo0_l00009ooooo`?o00001?ooool3o`0003kooooo0ol00004ooooo`Co0000Eooo
ool002cooooo0_l0000:ooooo`03o`000?oooooooooo03Wooooo0_l00009ooooo`;o0000<_ooool0
0ol0003oooooooooo`06ooooo`;o00002_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0E?ooool002[ooooo0_l0000=ooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool02oooool2o`00033ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0;ooooo`;o0000>?ooool2o`0000gooooo00?o0000ooooooooool0Doooool002Wo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05;o
oooo000Xooooo`03o`000?oooooooooo013ooooo0_l0000dooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0;Oooool2o`0000Cooooo0_l0000Aooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`1Aooooo`00:?ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0`ooooo`;o00004oooool00ol0003oooooooooo`1@ooooo`009oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0Coooool002Kooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0:_ooool01Ol0003ooooooooooooooooo000001Oooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04kooooo000Uooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
02Wooooo00Co0000oooooooooooo00006Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool0C_ooool002Gooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0:?ooool3o`00
01[ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
04gooooo000Tooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo02Oooooo00?o0000ooooool000006oooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0COooool002Cooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool01?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go
00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo0_l0000Looooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1<ooooo`009?ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q
8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo0_l0000Looooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1;ooooo`008oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`03ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09
ooooo`03o`000?oooooooooo00?ooooo0_l0000Mooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02;ooooo0012oooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;o
oooo00Cooooo0ol0000Looooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02;ooooo0012ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?oo
ool2o`0001kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool08oooool004?ooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool2o`0001oooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool08oooool004?ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0P
ooooo`09o`000?oooooooooooooooomgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oo
ooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Kooooo0_l0000Oooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
02?ooooo0013ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08?ooool02Ol0003o
ooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
1?ooool4o`0000Cooooo00Co0000ooooool0003o00007oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Tooooo`00
A?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
8_ooool00ol0003oooooo`00000Pooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02Cooooo0014ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooo0000023ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool09?ooool004Gooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo023ooooo00Co0000oooooooooooo00008Ooo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0Tooooo`00AOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool08?ooool01?l0003oooooooooool0000Qooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo02Gooooo0015ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00;o00008?ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0U
ooooo`00A_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool07oooool01?l0003oooooooooool0000Rooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Gooooo0016oooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Noooo
o`05o`000?ooooooooooooooool000008_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Vooooo`00A_ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool01Ol0
003ooooooooooooooooo000002;ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_ooool004Oooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01gooooo00Go0000oooo
ooooooooooooo`00000Sooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo0017ooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
00;ooooo0_l0000Rooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo0017ooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Wooooo`00Aoooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool09oooool004Sooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Oooooo0018
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo00?ooooo0_l0000Sooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Oooooo0018oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Xoooo
o`00B?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool0:?ooool004Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo00Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;o000000Gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Xoooo
o`00BOooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02[ooooo00?o0000oooooooo
ool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03o`000?lb<S;ooooo
00Cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Xooooo`00BOooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool01?ooool01Ol@413o
oooooooooooooooo410@00oooooo0_l00005ooooo`?o00008oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Xoooo
o`00BOooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo000000oooooo00?o0000oc8b<_ooool01?ooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo02Wooooo0019ooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooooooo
ool000003?ooool01Ol0003o8B4Qo`000?l0003oc<c<00Gooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0Yooooo`00B_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool00oooool01Ol@413ooooooooooooooooo410@00cooooo00Co0000
oooooooooooo00001_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02Wooooo001:
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooo`000007ooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0:Oooool004[ooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`Co00001_ooool2o`0002Gooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0:Oooool004[ooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02[ooooo001:oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Zoooo
o`00Boooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0:_ooool004_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool01_ooool2o`0002Kooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
:_ooool004_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo02_ooooo001;ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0[ooooo`00C?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0:oooool004cooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo02_ooooo001<ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Oooooo
0_l0000Wooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo02_ooooo001<ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0/ooooo`00C?ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0;?ooool004gooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02cooooo001=ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0/ooooo`00
COooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`08ooooo`;o0000:Oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo03?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0]ooooo`00COoo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0;Ooo
ool004gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0^ooooo`07onk^k_lb<S;o
0000oc8b<_o^k^koooooo`000003ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`03ooooo`06o`00
0?m4A4Co0000o`000?lb<S;ogMgM1Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
02gooooo001>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0;_ooool01omgMgOo
V9RHoooooonHV9SoMgMgooooool000000oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool00oooool0
1_l0003oooooooooooooooooMgMgoc8b<PGooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0]ooooo`00C_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02oooooo00Oo
410@oooooooooooooooooa0@4?oooooo000000_ooooo00?oZJVYoeEEEOooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo0ol0000Yooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02go
oooo001>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0;oooool01ol0003ooooo
oooooooooooo0000ooooool000003?ooool01OlQ8B7ooooooooooooooooo000000Cooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02kooooo001>oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0;oooool01ol0003ooooooooooooooooo
0000ooooool000003?ooool02omEEEGoc<c<oooooooooooo0000ooooool0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0^ooooo`00C_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo02oooooo00Go410@oooooooooooooooooa0@4002
ooooo`03o`000?oooooooooo00Wooooo00OoZJVYogMgMoooooooooooo`000?oooooo000000Wooooo
00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0^ooooo`00C_ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo033ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`03o`00
0?oooooooooo00Kooooo00Go410@oooooooooooooooooc8b<P02ooooo`03o`000?oooooo000000Wo
oooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0^ooooo`00Coooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo033ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`03
o`000?oooooooooo00Kooooo1Ol000001?oooooo0000ooooooooool4o`0000Kooooo0_l0000[oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo02oooooo001?ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Oooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0_ooooo`00Coooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0gooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0;oooool004oooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02oooooo001@ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo03Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0_ooooo`00D?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0;ooooo`;o0000;?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0`ooooo`00D?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0<?ooool0057ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0>_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo033ooooo
001Aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0aooooo`00DOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0<Oooool0057ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0loooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool2o`0002gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0<Oooool005;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0looooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo03;ooooo001Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0booooo`00D_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo03kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0mooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0<_ooool005?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03_ooool2
o`0002kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0<oooool005Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0oooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0?oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo03?ooooo001Dooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Go
oooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo02oooooo00Go0000oooooooo
ooooooooo`000013ooooo`05o`000?ooooooooooooooool00000=_ooool005Cooooo0_l00002oooo
o`03o`000?oooooooooo04;ooooo00?o0000ooooooooool00_l00009ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`02o`0004?ooooo0_l00002oooo
o`03o`000?oooooooooo03Cooooo001Eooooo`?o0000AOooool4o`0000[ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0`ooooo`?o0000AOooool3o`0003Oooooo002[ooooo`03o`00
0?oooooooooo00Gooooo0ol0002booooo`00Zoooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0;;ooooo002[ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/_ooool0
0:_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2booooo`00ZOooool00omEEEGo
IVIVo`000007ooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o
0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0
003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002coooo
o`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0
/_ooool0097ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool5o`0000Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oo
oooooooo00Cooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00_ooooo00?o
V9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000/_ooool009?ooooo00?o0000
ooooooooool03?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool0/_ooool009?ooooo00?o0000ooooooooool03Oooool00omgMgOoIVIVooooo`03oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2booooo`00Toooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[ooooooiRH
V?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;;ooooo002Aooooo`03
oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`00
0;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002coooo
o`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0
/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0
003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooo
ooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002coooo
o`03o`000?oooooooooo0;;ooooo002Iooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Go
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;;ooooo002Kooooo`03
o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0/_ooool009_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo0;;ooooo002Kooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool01?oo
ool3o`000;;ooooo002Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo0;;ooooo002Kooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`2booooo`00Voooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_ooool009Wooooo00?oEEEEofIVI_l0
00003Oooool4o`0000Kooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0
003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002coooo
o`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0
/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool0
0;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003ooooo
ooooo`2booooo`00TOooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B46ooooo`03o`000?o^
k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;;ooooo
002Cooooo`03o`000?oooooooooo00Cooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`0<
ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000;;ooooo002Coooo
o`03o`000?oooooooooo00gooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00gooooo00?oEEEEolc<c?oo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/_ooool009?o
oooo00?o0000ooooooooool03Oooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool02_ooool01Ol@413ooooo
oooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2booooo`00
TOooool00omEEEGoIVIVo`00000<ooooo`Go00001?ooool4o`0000Kooooo0_l0002cooooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0
003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo
002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002coooo
o`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0
/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool0
0;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003ooooo
ooooo`2booooo`00Z?ooool5o`0000Kooooo00?o0000ooooooooool0/_ooool00:Sooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0;;ooooo002Yooooo`03oiRHV?lQ8B7o
k^k^00Oooooo00?o0000ooooooooool0/_ooool00:[ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`00
0;;ooooo002[ooooo`03ogMgMomVIVKooooo0;[ooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002Xooooo`05o`000?nj^[[ooooooiRHV?l@4100^oooool00:Sooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c02kooooo`00oooooomYooooo`00/Oooool00ol0003o^[Zjooooo`2dooooo`00/Oooool2oc8b
<[Gooooo0022ooooo`;o000000Ko410@oooooooooooo410@o`000?l@410Hooooo`Co000000Go410@
ooooooooooooooooodA4A002o`000007oc8b<_oMgMgooooooooooon7QhOo0000okZj^P0<ooooo`05
oiRHV?l0003o0000odA4A?nj^[X06?ooool01OnHV9So410@o`000?lb<S;oc<c<00Cooooo00GoA4A4
o`000?l0003o<S8bomgMg@1mooooo`00Poooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Oooooo1_l0000<ooooo`03o`000?oooooooooo00Kooooo00OoMgMgoc8b<_ooooooooooolc<
c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002Oooool01Ol@413o
^[ZjoooooomgMgOo<S8b00Oooooo00?oMgMgoc8b<_ooool0O?ooool008?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0Noooool008?ooooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00003?ooool00ol0
003oooooooooo`06ooooo`03ogMgMolb<S;ooooo013ooooo00?o0000ooooooooool02oooool6o`00
00cooooo00?oZJVYoa0@4?ooool01_ooool00omgMgOo<S8booooo`1looooo`00Poooool01_l0003o
gMgMoc8b<_mEEEGogMgMo`0001_ooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<017ooooo00?o0000ooooooooool07?ooool00ol@413o0000okZj^P04ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`0OOooool008?ooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Kooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol@413o0000o`000003o`0001co
oooo00?o^[Zjob4Q8Oooool00oooool00ol0003oooooooooo`1oooooo`00Poooool01_l0003o<S8b
oooooooooooo<S8bo`0001_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo01[ooooo00Go410@oiRHV?oooooo^[Zjo`000004ooooo`03o`000?oooooo
oooo07oooooo0022ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool00omE
EEGoIVIVo`000005ooooo`Co00004_ooool00ol0003oooooooooo`0Jooooo`05ojVYZOl@413o0000
oa0@4?nYZJT01?ooool4o`0007kooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-44.3769, -0.160437, \
0.309031, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.01333 0 0.309017 [
[.1001 -0.0125 -9 -9 ]
[.1001 -0.0125 9 0 ]
[.2334 -0.0125 -9 -9 ]
[.2334 -0.0125 9 0 ]
[.3667 -0.0125 -9 -9 ]
[.3667 -0.0125 9 0 ]
[.6333 -0.0125 -6 -9 ]
[.6333 -0.0125 6 0 ]
[.7666 -0.0125 -6 -9 ]
[.7666 -0.0125 6 0 ]
[.8999 -0.0125 -6 -9 ]
[.8999 -0.0125 6 0 ]
[.4875 .07725 -24 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -18 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -24 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1001 0 m
.1001 .00625 L
s
[(-30)] .1001 -0.0125 0 1 Mshowa
.2334 0 m
.2334 .00625 L
s
[(-20)] .2334 -0.0125 0 1 Mshowa
.3667 0 m
.3667 .00625 L
s
[(-10)] .3667 -0.0125 0 1 Mshowa
.6333 0 m
.6333 .00625 L
s
[(10)] .6333 -0.0125 0 1 Mshowa
.7666 0 m
.7666 .00625 L
s
[(20)] .7666 -0.0125 0 1 Mshowa
.8999 0 m
.8999 .00625 L
s
[(30)] .8999 -0.0125 0 1 Mshowa
.125 Mabswid
.12676 0 m
.12676 .00375 L
s
.15342 0 m
.15342 .00375 L
s
.18008 0 m
.18008 .00375 L
s
.20674 0 m
.20674 .00375 L
s
.26006 0 m
.26006 .00375 L
s
.28672 0 m
.28672 .00375 L
s
.31338 0 m
.31338 .00375 L
s
.34004 0 m
.34004 .00375 L
s
.39336 0 m
.39336 .00375 L
s
.42002 0 m
.42002 .00375 L
s
.44668 0 m
.44668 .00375 L
s
.47334 0 m
.47334 .00375 L
s
.52666 0 m
.52666 .00375 L
s
.55332 0 m
.55332 .00375 L
s
.57998 0 m
.57998 .00375 L
s
.60664 0 m
.60664 .00375 L
s
.65996 0 m
.65996 .00375 L
s
.68662 0 m
.68662 .00375 L
s
.71328 0 m
.71328 .00375 L
s
.73994 0 m
.73994 .00375 L
s
.79326 0 m
.79326 .00375 L
s
.81992 0 m
.81992 .00375 L
s
.84658 0 m
.84658 .00375 L
s
.87324 0 m
.87324 .00375 L
s
.07344 0 m
.07344 .00375 L
s
.04678 0 m
.04678 .00375 L
s
.02012 0 m
.02012 .00375 L
s
.92656 0 m
.92656 .00375 L
s
.95322 0 m
.95322 .00375 L
s
.97988 0 m
.97988 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .07725 m
.50625 .07725 L
s
[(0.25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(0.75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(1)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(1.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(1.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(1.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .15789 m
.03279 .12133 L
.04262 .09018 L
.04758 .07804 L
.05288 .06736 L
.06244 .05286 L
.06788 .04664 L
.07379 .04113 L
.07899 .03719 L
.08451 .03392 L
.0869 .0328 L
.08947 .0318 L
.09095 .03134 L
.0923 .03097 L
.09367 .03067 L
.09494 .03045 L
.09609 .0303 L
.09731 .03019 L
.098 .03015 L
.09866 .03013 L
.09988 .03013 L
.10106 .03019 L
.10214 .03028 L
.10333 .03043 L
.10458 .03064 L
.10713 .03124 L
.10954 .03201 L
.11406 .03393 L
.11892 .03668 L
.12422 .0404 L
.13374 .04912 L
.14255 .06027 L
.14718 .06785 L
.15218 .07779 L
.16122 .10149 L
.17196 .14044 L
.18182 .18484 L
.19097 .22871 L
.20074 .27063 L
.20363 .28076 L
.20636 .28901 L
.20902 .29568 L
.21147 .30054 L
.21379 .30393 L
.21496 .30517 L
.21625 .30616 L
.21755 .30677 L
.21827 .30693 L
.21893 .30697 L
.22022 .30676 L
Mistroke
.22144 .3062 L
.22269 .30525 L
.22404 .30383 L
.22649 .3002 L
.22887 .2954 L
.23105 .28997 L
.23603 .27429 L
.24129 .25367 L
.25969 .16789 L
.26919 .12766 L
.27936 .09388 L
.2843 .08118 L
.28897 .07115 L
.29771 .05661 L
.30739 .04521 L
.31228 .0408 L
.31766 .0368 L
.32224 .0341 L
.32465 .03295 L
.32717 .03194 L
.3294 .03123 L
.33057 .03093 L
.33183 .03066 L
.33299 .03045 L
.33404 .03031 L
.3351 .03021 L
.33609 .03015 L
.33725 .03013 L
.33849 .03015 L
.33967 .03023 L
.34074 .03034 L
.34199 .03052 L
.34336 .03078 L
.34584 .03142 L
.34843 .0323 L
.35119 .03347 L
.35615 .03614 L
.36492 .04252 L
.37461 .05225 L
.37952 .05863 L
.38469 .06681 L
.39393 .08644 L
.39909 .10081 L
.40389 .11664 L
.41478 .16094 L
.43349 .24888 L
.43862 .26982 L
.44405 .28788 L
.44629 .29377 L
.44869 .29896 L
Mistroke
.45007 .30138 L
.45133 .30322 L
.45262 .30474 L
.4538 .30578 L
.45511 .30656 L
.45583 .30682 L
.45651 .30695 L
.45772 .30691 L
.45902 .30648 L
.45971 .30609 L
.46047 .30553 L
.462 .304 L
.46341 .30211 L
.46473 .29994 L
.46974 .28833 L
.47512 .2707 L
.49526 .1796 L
.50544 .13486 L
.51081 .11477 L
.51652 .09658 L
.52149 .08334 L
.52697 .07132 L
.53664 .05546 L
.54156 .04936 L
.54674 .044 L
.556 .03664 L
.56117 .03368 L
.56364 .03257 L
.56597 .0317 L
.56729 .03129 L
.56873 .03091 L
.56992 .03066 L
.57124 .03043 L
.57192 .03034 L
.57266 .03026 L
.57344 .03019 L
.57417 .03015 L
.57489 .03013 L
.57558 .03013 L
.57686 .03017 L
.57812 .03026 L
.57882 .03034 L
.57947 .03043 L
.58064 .03062 L
.58192 .03089 L
.58414 .03148 L
.58649 .03229 L
.59179 .03473 L
.59673 .03773 L
.60562 .04482 L
Mistroke
.61513 .05525 L
.62044 .06288 L
.62534 .07153 L
.63061 .08295 L
.63643 .09852 L
.6462 .1325 L
.65656 .17798 L
.66734 .22958 L
.67266 .25349 L
.67759 .27306 L
.68242 .28864 L
.68452 .29409 L
.68679 .29897 L
.6881 .30127 L
.6893 .30305 L
.69052 .30453 L
.69165 .3056 L
.69286 .3064 L
.69417 .30688 L
.69546 .30696 L
.69618 .30683 L
.69684 .3066 L
.69798 .30597 L
.69924 .30492 L
.70055 .30343 L
.70179 .30167 L
.70399 .2977 L
.70637 .29226 L
.71178 .27586 L
.71674 .25677 L
.7356 .16917 L
.74474 .13012 L
.75451 .09686 L
.76013 .08203 L
.76523 .071 L
.77008 .06237 L
.77521 .05483 L
.77996 .04902 L
.78519 .04368 L
.79439 .03645 L
.79956 .03354 L
.80247 .03227 L
.80513 .03137 L
.80759 .03074 L
.80899 .03048 L
.81028 .03031 L
.81153 .03019 L
.81265 .03014 L
.81396 .03013 L
.81518 .03018 L
Mistroke
.81635 .03027 L
.81759 .03043 L
.81877 .03063 L
.81985 .03085 L
.82247 .03156 L
.82496 .03243 L
.82991 .03475 L
.83529 .03805 L
.84489 .04594 L
.85377 .05596 L
.85841 .0627 L
.86342 .07149 L
.87246 .09262 L
.88322 .1283 L
.89308 .17058 L
.90302 .21812 L
.90848 .24355 L
.91363 .2653 L
.91844 .28245 L
.92097 .28991 L
.92365 .29645 L
.9259 .3008 L
.9271 .30265 L
.92838 .30428 L
.92956 .30544 L
.93063 .30622 L
.93172 .30673 L
.93274 .30695 L
.93387 .30692 L
.93492 .30661 L
.93608 .30597 L
.93733 .30492 L
.93857 .30352 L
.93988 .30168 L
.94222 .29742 L
.94641 .28697 L
.951 .27182 L
.97089 .18225 L
.97619 .15789 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^@?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hLooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=_ooool0
03Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Oooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`12ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0=_ooool002oooooo1_l00006ooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41005?ooool6o`0000Gooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@01gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01oo
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03Cooooo000jooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000012ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`00>Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000007oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000@_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
7oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool00000=_ooool003[ooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@023ooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@03Kooooo000gooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0@_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL07?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Kooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Ko
oooo000gooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Ooo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0@?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Kooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo000Koooooooo0000<_l0000Looooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Pooooo`00>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo000hooooo`Co0000A?ooool4o`0002oooooo00?o0000ooooooooool0
4_ooool4o`0004Cooooo1Ol0001Cooooo`00=?ooool4o`0000Cooooo0ol0000oooooo`?o00000_oo
ool4o`0002cooooo0_l0000@ooooo`Co00000oooool3o`0003kooooo1?l00003ooooo`?o0000DOoo
ool003?ooooo00?o0000ooooooooool02Oooool2o`0003_ooooo0_l00009ooooo`;o0000:_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`08ooooo`;o0000Coooool003?ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0gooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo0_l0000iooooo`03o`000?oooooooooo
00_ooooo0_l0001=ooooo`00<Oooool2o`0000oooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`1:ooooo`00<?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0Uooooo`;o00003?ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`19ooooo`00;oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0BOooool002kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo04Sooooo000^ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`17ooooo`00;Oooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0A_ooool002cooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
8Oooool2o`0000Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Zooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool0AOooool002cooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04Gooooo000[ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Iooooo`05o`000?lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04Cooooo000[ooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Jooooo`05ogMgMol0
003ooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`14ooooo`00
:_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
6_ooool01Ol@413o0000oooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0A?ooool002[ooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01_ooooo
00Go0000ooooool0003oooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_oo
ool01?ooool3o`0000Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool0@oooool002[ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01_ooooo00Go0000ooooool0003o
ooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@oooool002Wooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01_ooooo00Go410@oooooooo
oooo0000oa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo04;ooooo000Yooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Looooo`05ogMgMonHV9Soooooo`00
0?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo04;ooooo000Xooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Looooo`05onk^k_lb<S;o0000
o`000?o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o00001?oo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`11ooooo`00:?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool0@Oooool002Oooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo047ooooo000Wooooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01co
oooo00Go0000ooooooooooooooooo`00000Tooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`10ooooo`009oooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Looooo`05
o`000?ooooooooooooooool000009?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool0@?ooool002Kooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool06oooool2o`0000;o
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool0@?ooool002Kooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool06oooool01?l0003ooooo
ooooool0000Vooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`0oooooo`009_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0002Ko
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03oo
oooo000Uooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01[ooooo00Co0000oooooooooooo00009oooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0?oooool002Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool06_ooool01?l0003oooooooooool0000Wooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0oooooo`009Oooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0Jooooo`;o000000?oooooo`000?ooool09_ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool0?_ooool002Gooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooo`00000Yooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0nooooo`009Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
000002Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo03kooooo000Tooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo01Wooooo00?o0000ooooool00000:Oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0?_ooool002Co
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool06Oooool3o`0002Wooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo03gooooo000Tooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooool00000:_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool0?Oooool002Cooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06?ooool2o`0002_ooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03gooooo000T
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Y
ooooo`05o`000?lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8b
omgMg@05ooooo`;o0000:oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool0?Oooool002?ooooo00?o0000ooooooooool0:_ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo02[ooooo00Go0000oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
2?ooool00omgMgOo<S8booooo`04ooooo`;o0000;?ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool0??ooool002?ooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02[ooooo00Go0000oooooooooooooooo
oa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0000[ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0:oooool00ol0003oooooooooo`0looooo`008oooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0:_ooool2o`0000;ooooo00?o
0000ooooooooool03Oooool00omgMgOo<S8booooo`04ooooo`;o0000;?ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0Rooooo`00D?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02[ooooo0_l00002
ooooo`03o`000?oooooooooo00[ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool08_ooool0057ooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0[ooooo`05oa0@4?l0003oooooooooool@41003?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0[ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool08_ooool0057ooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0[ooooo`05ogMgMol0003ooooooiRHV?mgMgL03?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool08_oo
ool0057ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0[ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0000]ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02?ooooo001A
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool08oooool0057ooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Gooooo0_l0000_oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo02?ooooo001Booooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`0Eooooo`;o0000;oooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Sooooo`00
D_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
5Oooool3o`0002kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool08oooool005;ooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Cooooo0_l0000_ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo02?ooooo001Booooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooo0000033ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool09?ooool0
05?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooool00000<?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Tooooo`00Doooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool04oooool00ol0003o
ooooo`00000`ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo02Cooooo001Cooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Booooo`04o`000?oooooo0000o`0002oo
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool09?ooool005?ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo017ooooo00Co0000oooooooooooo0000<?ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Tooooo`00Doooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool04Oooool01?l0003oooooooooool0000aooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02Go
oooo001Dooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`0Aooooo`04o`000?ooooooooooo`00037ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool09Oooool005Cooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo017ooooo
00Co0000oooooooooooo0000<Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Uooooo`00E?ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool03oooool01?l0003ooooo
ooooooooool2o`00033ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool09Oooool005Cooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00oooooo00Go0000oooooooooooo
ooooo`00000aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo02Gooooo001Dooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool09oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B400ooooooo
0000ooooo`03ooooo`03o`000?o^k^kooooo00Cooooo00OoA4A4o`000?l0003o<S8bomgMgOoooooo
000000?ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Vooooo`00EOooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo02Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q00?oooooo`000?ooool00oooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;o
000000Cooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Vooooo`00EOooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo02Oooooo00Go410@oooooooooooooooooa0@4009
ooooo`06o`000?oooooooooooooooonYZJWoEEEE2Oooool2o`0000Cooooo0ol0000`ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo02Kooooo001Eooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0:?oo
ool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool00_ooool00olQ8B7ooooo
ooooo`06ooooo`03ogMgMolb<S;o000000Cooooo00?o0000ooooooooool0<?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0Vooooo`00EOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02Sooooo00Go
0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo00;ooooo00?oEEEEolc<c?ooool0
0oooool01_l0003o8B4Qo`000?lb<S;oc<c<o`0000Cooooo00?o0000ooooooooool0<?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0Wooooo`00E_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02So
oooo00Go410@oooooooooooooooooa0@4009ooooo`03o`000?oooooooooo00;ooooo00?oZJVYogMg
Moooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0Wooooo`00E_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
02Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`09ooooo`03o`000?oooooo410@00?ooooo00?o<S8b
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0Wooooo`00E_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo02Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0:ooooo`Ko00001?ooool5o`0000Gooooo0_l0
000booooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0=_ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo02Oooooo001Fooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Oooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0Wooooo`00Eoooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo03Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0:?ooool005Oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Sooooo001Gooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Xooooo`00Eooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`04ooooo`;o0000<oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo03[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Xooooo`00F?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0:?ooool0
05Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
02Wooooo001Hooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0>_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Yooooo`00FOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0:Oooool005Wooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0looooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool2o`0003Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0:_ooool005Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0l
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0d
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo02[ooooo001Jooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0?Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0=?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0[ooooo`00F_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo03Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0nooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0:oooool005[ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1_ooool2o`0003Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0nooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0;?ooool005_ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0?ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02cooooo001Kooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`02ooooo`Go000000?o410@
ooooooooool00oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0@?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02cooooo001Loooo
o`04o`000?ooooooooooo`0004Cooooo00?o0000ooooooooool00_l00002ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0=_ooool01Ol0003ooooooooooooooooo000004Cooooo00Co
0000oooooooooooo0000;oooool005gooooo0ol00015ooooo`?o00000oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo03Oooooo0ol00015ooooo`Co0000;oooool00:_ooooo00?o0000
ooooooooool01Oooool3o`000;;ooooo002[ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0/_ooool00:_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2booooo`00
Zoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;;ooooo002Yooooo`03oeEEEOmV
IVKo000000Oooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0
003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooo
ooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002coooo
o`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`00
0?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool0
0;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo
00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2b
ooooo`00TOooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`Go00001?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000oooo
ooooool01?ooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool02oooool00onH
V9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0002booooo`00Toooool00ol0003o
ooooooooo`0<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`2booooo`00Toooool00ol0003oooooooooo`0=ooooo`03ogMgMomVIVKooooo00?ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RH
oa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_ooool0097ooooo00?o
EEEEofIVI_l000003?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000
/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool0
0;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo
0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2b
ooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`00
0?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooo
oooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo
00?o0000ooooooooool0/_ooool009Wooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Ooo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/_ooool009_ooooo00?o
0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`2booooo`00Voooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0/_ooool009_ooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`04oooo
o`?o0000/_ooool009_ooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool0/_ooool009_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo0;;ooooo002Kooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`2booooo`00VOooool00omEEEGoIVIVo`00
000=ooooo`Co00001_ooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002coooo
o`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`00
0?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool0
0;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo
00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2b
ooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00
/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooo
oooo0;;ooooo002Aooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Kooooo00?o0000onk^
k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/_ooool0
09?ooooo00?o0000ooooooooool01?ooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00co
oooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000/_ooool009?ooooo
00?o0000ooooooooool03Oooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool03Oooool00omEEEGoc<c<oooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2booooo`00Tooo
ool00ol0003oooooooooo`0=ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`0:ooooo`05oa0@4?oooooo
oooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;;ooooo002A
ooooo`03oeEEEOmVIVKo000000cooooo1Ol00004ooooo`Co00001_ooool2o`000;?ooooo002coooo
o`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`00
0?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool0
0;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo
00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2b
ooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00
/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooo
oooo0;;ooooo002Xooooo`Go00001_ooool00ol0003oooooooooo`2booooo`00Z?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/_ooool00:Wooooo00?oV9RHob4Q8Oo^
k^h01oooool00ol0003oooooooooo`2booooo`00Z_ooool00onHV9So8B4Qonk^kP06ooooo`?o0000
/_ooool00:_ooooo00?oMgMgofIVI_ooool0^_ooool00:cooooo00?o0000ooooooooool0^Oooool0
0:Sooooo00Go0000okZj^_ooooooV9RHoa0@402kooooo`00Z?ooool01OnHV9So410@o`000?lQ8B7o
c<c<0;_ooooo003oooooofWooooo002aooooo`03o`000?nj^[[ooooo0;Cooooo002aooooo`;o<S8b
]Oooool008;ooooo0_l000001_l@413oooooooooool@413o0000oa0@41Sooooo1?l000001Ol@413o
ooooooooooooooooA4A400;o000000Oo<S8bomgMgOooooooooooohN7Qol0003o^[Zj00cooooo00Go
V9RHo`000?l0003oA4A4okZj^P0Jooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h0O_ooool008?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07oooo
o`Ko00003?ooool00ol0003oooooooooo`06ooooo`07ogMgMolb<S;oooooooooooo<c<co0000oa0@
400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000cooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg07kooooo0023ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool06_ooool5o`0000?ooooo00Go410@oooooooooooooooooa0@401nooooo`00
Poooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000<ooooo`03o`000?oooooooooo
00Kooooo00?oMgMgoc8b<_ooool04?ooool00ol0003oooooooooo`0;ooooo`Ko00002Oooool01?m4
A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool00000O_ooool008?ooooo00Ko0000
omgMgOlb<S;oEEEEomgMgOl0000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c00Aooooo`03o`000?oooooooooo01[ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0
003ooooooooooooooooo000007kooooo0023ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo00006ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o410@o`000?l000000ol0
000Jooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@401nooooo`00Pooo
ool01_l0003o<S8boooooooooooo<S8bo`0001_ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo01_ooooo00?ok^k^odA4A?l000001?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg07kooooo0022ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@
41006?ooool00omEEEGoIVIVo`000005ooooo`Co00004_ooool00ol0003oooooooooo`0Looooo`03
ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1nooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-44.3769, -0.160437, \
0.309031, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.01333 0 0.309017 [
[.1001 -0.0125 -9 -9 ]
[.1001 -0.0125 9 0 ]
[.2334 -0.0125 -9 -9 ]
[.2334 -0.0125 9 0 ]
[.3667 -0.0125 -9 -9 ]
[.3667 -0.0125 9 0 ]
[.6333 -0.0125 -6 -9 ]
[.6333 -0.0125 6 0 ]
[.7666 -0.0125 -6 -9 ]
[.7666 -0.0125 6 0 ]
[.8999 -0.0125 -6 -9 ]
[.8999 -0.0125 6 0 ]
[.4875 .07725 -24 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -18 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -24 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1001 0 m
.1001 .00625 L
s
[(-30)] .1001 -0.0125 0 1 Mshowa
.2334 0 m
.2334 .00625 L
s
[(-20)] .2334 -0.0125 0 1 Mshowa
.3667 0 m
.3667 .00625 L
s
[(-10)] .3667 -0.0125 0 1 Mshowa
.6333 0 m
.6333 .00625 L
s
[(10)] .6333 -0.0125 0 1 Mshowa
.7666 0 m
.7666 .00625 L
s
[(20)] .7666 -0.0125 0 1 Mshowa
.8999 0 m
.8999 .00625 L
s
[(30)] .8999 -0.0125 0 1 Mshowa
.125 Mabswid
.12676 0 m
.12676 .00375 L
s
.15342 0 m
.15342 .00375 L
s
.18008 0 m
.18008 .00375 L
s
.20674 0 m
.20674 .00375 L
s
.26006 0 m
.26006 .00375 L
s
.28672 0 m
.28672 .00375 L
s
.31338 0 m
.31338 .00375 L
s
.34004 0 m
.34004 .00375 L
s
.39336 0 m
.39336 .00375 L
s
.42002 0 m
.42002 .00375 L
s
.44668 0 m
.44668 .00375 L
s
.47334 0 m
.47334 .00375 L
s
.52666 0 m
.52666 .00375 L
s
.55332 0 m
.55332 .00375 L
s
.57998 0 m
.57998 .00375 L
s
.60664 0 m
.60664 .00375 L
s
.65996 0 m
.65996 .00375 L
s
.68662 0 m
.68662 .00375 L
s
.71328 0 m
.71328 .00375 L
s
.73994 0 m
.73994 .00375 L
s
.79326 0 m
.79326 .00375 L
s
.81992 0 m
.81992 .00375 L
s
.84658 0 m
.84658 .00375 L
s
.87324 0 m
.87324 .00375 L
s
.07344 0 m
.07344 .00375 L
s
.04678 0 m
.04678 .00375 L
s
.02012 0 m
.02012 .00375 L
s
.92656 0 m
.92656 .00375 L
s
.95322 0 m
.95322 .00375 L
s
.97988 0 m
.97988 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .07725 m
.50625 .07725 L
s
[(0.25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(0.75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(1)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(1.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(1.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(1.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(45) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26839 m
.04262 .18332 L
.0522 .14079 L
.06244 .10382 L
.0679 .08836 L
.07286 .07669 L
.08255 .05931 L
.08798 .05197 L
.09388 .04542 L
.0994 .04036 L
.10458 .03648 L
.10913 .03375 L
.11147 .0326 L
.11402 .03157 L
.11546 .03108 L
.1168 .0307 L
.11819 .03037 L
.11945 .03013 L
.12069 .02995 L
.12185 .02984 L
.12308 .02977 L
.12378 .02976 L
.12442 .02976 L
.12563 .02981 L
.12694 .02992 L
.12817 .03009 L
.12929 .03028 L
.13204 .03096 L
.13464 .03183 L
.13982 .03421 L
.14545 .03769 L
.15485 .04547 L
.16522 .05757 L
.17043 .06569 L
.17606 .07658 L
.18623 .10346 L
.1958 .13833 L
.20627 .18544 L
.21732 .2382 L
.22737 .27887 L
.23221 .29305 L
.23494 .29901 L
.23624 .30129 L
.23746 .30308 L
.23861 .30446 L
.23966 .30546 L
.24083 .30626 L
.24208 .30676 L
.24328 .3069 L
.24459 .30665 L
Mistroke
.24583 .30605 L
.24698 .30517 L
.2483 .30378 L
.24972 .30183 L
.2523 .29716 L
.25713 .28476 L
.26276 .26512 L
.26793 .2434 L
.28839 .14873 L
.29838 .11076 L
.30747 .08466 L
.31691 .06528 L
.32583 .05228 L
.33526 .0423 L
.34058 .03795 L
.34549 .03471 L
.35014 .03235 L
.35275 .03134 L
.35515 .03063 L
.35725 .03018 L
.35845 .02999 L
.35956 .02987 L
.36073 .02979 L
.3618 .02976 L
.36303 .02977 L
.3642 .02984 L
.36539 .02997 L
.3667 .03016 L
.36807 .03043 L
.36935 .03074 L
.37409 .03237 L
.3768 .03363 L
.37926 .03496 L
.38481 .03859 L
.39471 .04723 L
.40387 .05836 L
.40865 .0659 L
.41393 .0761 L
.42462 .10441 L
.4347 .14168 L
.44395 .18346 L
.45474 .2351 L
.46001 .25828 L
.4648 .27658 L
.46949 .29098 L
.47165 .29618 L
.47393 .30062 L
.47509 .30244 L
.47637 .30409 L
.47753 .30526 L
Mistroke
.47861 .30608 L
.47989 .30668 L
.48106 .3069 L
.48171 .30688 L
.48241 .30674 L
.4837 .30619 L
.48437 .30575 L
.4851 .30515 L
.48642 .30375 L
.48889 .30007 L
.49178 .29409 L
.49443 .28711 L
.50439 .25057 L
.52482 .1559 L
.5348 .11644 L
.54389 .08886 L
.55332 .06825 L
.56224 .05443 L
.57165 .04387 L
.57693 .03928 L
.58189 .03575 L
.58642 .03319 L
.58875 .03213 L
.5913 .03119 L
.59393 .03046 L
.59537 .03017 L
.59606 .03006 L
.59671 .02997 L
.59797 .02984 L
.59911 .02977 L
.60034 .02976 L
.60104 .02977 L
.60168 .0298 L
.60289 .0299 L
.60419 .03006 L
.60542 .03027 L
.60654 .03051 L
.60928 .03128 L
.61189 .03224 L
.61706 .03479 L
.62269 .03843 L
.63304 .04748 L
.64242 .05901 L
.64762 .06744 L
.65323 .07875 L
.66341 .10662 L
.67295 .1423 L
.6834 .18995 L
.69444 .24239 L
.69966 .26457 L
Mistroke
.70448 .2819 L
.7093 .29519 L
.71184 .30031 L
.71314 .30237 L
.71454 .30417 L
.71576 .30538 L
.71687 .30618 L
.71799 .30668 L
.71906 .30689 L
.7203 .30679 L
.72144 .30638 L
.7227 .30557 L
.72341 .30495 L
.72404 .30429 L
.72674 .3005 L
.72922 .29559 L
.73482 .28001 L
.73976 .2619 L
.74498 .23956 L
.76483 .14767 L
.7735 .11435 L
.78294 .08645 L
.78814 .0746 L
.79295 .06553 L
.80244 .05177 L
.81258 .04131 L
.8177 .03728 L
.82335 .03378 L
.82826 .03158 L
.83073 .03079 L
.83215 .03044 L
.83344 .03018 L
.83463 .02999 L
.83575 .02987 L
.83694 .02978 L
.83823 .02975 L
.83935 .02978 L
.84055 .02986 L
.84157 .02996 L
.84269 .03012 L
.84408 .03039 L
.8454 .0307 L
.84788 .03145 L
.85055 .03248 L
.85346 .03387 L
.86354 .04054 L
.86887 .04521 L
.87388 .05045 L
.88324 .06322 L
.8885 .07273 L
Mistroke
.89333 .08343 L
.90423 .11587 L
.91398 .155 L
.92308 .19759 L
.9337 .2476 L
.93892 .2691 L
.94375 .28555 L
.9477 .29587 L
.94969 .29987 L
.95084 .30178 L
.95189 .30327 L
.95294 .30451 L
.95408 .30557 L
.95524 .30633 L
.95645 .30678 L
.95752 .3069 L
.95867 .30672 L
.95975 .30627 L
.96073 .30562 L
.96169 .30476 L
.96272 .30362 L
.96455 .30098 L
.96652 .29731 L
.96869 .29234 L
.97619 .26839 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^@?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hLooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=_ooool0
03Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Oooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`12ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0=_ooool002oooooo1_l00006ooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41005?ooool6o`0000Gooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@01gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01oo
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03Cooooo000jooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000012ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`00>Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000007oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000@_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
7oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool00000=_ooool003[ooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@023ooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@03Kooooo000gooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0@_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL07?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Kooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Ko
oooo000gooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Ooo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0@?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Kooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo000Koooooooo0000<_l0000Looooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Pooooo`00>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo000oooooo`Go0000@oooool6o`0002Kooooo00?o0000ooooooooool0
6_ooool4o`0004Cooooo1Ol0001;ooooo`00??ooool3o`0000Cooooo0ol0000oooooo`;o00001_oo
ool2o`0002Cooooo0_l0000Hooooo`?o00001?ooool3o`0003gooooo1?l00005ooooo`?o0000B?oo
ool003[ooooo0_l0000:ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01oooool2
o`0002?ooooo00?o0000ooooooooool05Oooool2o`0000[ooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04Gooooo000iooooo`03o`000?oooooooooo
00_ooooo0_l0000iooooo`;o00003?ooool2o`00027ooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`14ooooo`00>Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0@oooool003Sooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool07Oooool2o`0001Cooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0@_ooool003Oooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0<_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo047ooooo000fooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`11ooooo`00=Oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0_oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0@?ooool003Cooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03oooooo000dooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo01[ooooo0_l0000@ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03kooooo000cooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0nooooo`00<_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool04_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo00?o0000ooooooooool00_lQ8B44ooooo`Go00001?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0mooooo`00<_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool04oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Co0000oooooolQ8B7o
8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo03cooooo000aooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Cooooo`05oa0@4?oooooooooooooo
ool@41001?ooool00ol0003oooooooooo`05ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo03cooooo000aooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Cooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`06ooooo`03oiRHV?lQ8B7ok^k^
00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0000cooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0>oooool0037o
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01Co
oooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00Kooooo00?oMgMgofIV
I_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0kooooo`00<?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool05?ooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0kooooo`00<?ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool05?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo00?o0000ooooooooool00oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03[ooooo000`
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`02ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0000;ooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03[ooooo
000_ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`0jooooo`00;oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool0>Oooool002oooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Poooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo03Wooooo000^ooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`0hooooo`00;_ooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Dooooo`;o0000
2_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0hooooo`00;_ooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool0>?ooool002gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo000]ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0gooooo`00;Oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0=oooool002cooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool04_ooool2o`0000Sooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=_ooool002cooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Kooooo000/
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0f
ooooo`00;?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool0=_ooool002_ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo02Sooooo00?o0000ooooooooool04Oooool2o`0000Oooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool0=Oooool002_ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo03Gooooo000[ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`0eooooo`00:oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool08_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo00?o
0000ooooooooool00_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo03Gooooo000Zooooo`03o`000?oooooooooo02_ooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0Rooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool01?l0003oooooob4Q8OlQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`0dooooo`00:_ooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool08_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`?o00001Oooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`0dooooo`00:_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool08oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool02Oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02cooooo00?o0000oooooooo
ool0=?ooool002[ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo02?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Ko
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0:_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool0=?ooool002Wooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo02?ooooo00Go410@oooooooooooooooooa0@4004ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
03Cooooo000Yooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`0Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0coooo
o`00:Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00?o0000ooooooooool01Oooool4o`00
00Kooooo0_l00005ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo03?ooooo000Yooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0cooooo`00:Oooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0<oooool002Sooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo03?ooooo000X
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo00kooooo0_l00004ooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo03?ooooo000Xoooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0_oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0coooo
o`00:?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool0;oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool0<_ooool002Sooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo03;ooooo000Wooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`0booooo`009oooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0=ooooo`;o00000oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`0booooo`009oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0=ooooo`05o`000?oooooooooo
ooooool00000=?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool0<_ooool002Oooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool03Oooool01Ol0003ooooooooooooooooo
000003Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo037ooooo000Wooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo00gooooo00Go0000ooooooooooooooooo`00000d
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0a
ooooo`009_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0<_ooool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool00000=?ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0<Oooool0
02Kooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool03?ooool2o`0000;ooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0<Oooool002Ko
oooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool03?ooool01?l0003oooooooooool0000fooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0`ooooo`009_ooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^ko000000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`04o`000?ooooooooooo`0003Kooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo033ooooo000Vooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Oooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOl000001oooool00omgMgOo<S8boooo
o`04ooooo`04o`000?ooooooooooo`0003Kooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0dooooo`03o`000?oooooooooo033ooooo000Uooooo`03o`000?oooooooooo03Gooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0Oooooo`05oa0@4?ooooooooooooooool@4100
3Oooool01?nYZJWoEEEEooooool00007ooooo`03o`000?oooooooooo00?ooooo1?l0000fooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0_ooooo`00
9Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
7oooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooool000001_ooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooo000003Oooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo02oooooo000Uooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Oooooo`05o`000?ooooooooooooooool0
00003_ooool00omEEEGoc<c<o`000003ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0
003oooooo`00000hooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`0_ooooo`009Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool08?ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Mol000000oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo000003Sooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02oooooo000Uooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Pooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01_l@413ooooooooooooooooo<S8bo`0000?ooooo00?o
0000ooooooooool01oooool00ol0003oooooo`00000hooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`0^ooooo`009?ooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool08?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol000001?oooooo0000ooooooooool4o`0000Kooooo0_l0000iooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0^ooooo`009?oo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`0:ooooo`;o0000>_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo03Oooooo00?o0000ooooooooool0;_ooool002Cooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02_ooool2
o`0003[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooo
oooo02kooooo000Tooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0hooooo`03o`000?oooooooooo00Wooooo0_l0000jooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0^ooooo`009?ooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo02gooooo000Sooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Wooooo
0_l0000kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>Oooool00ol0003ooooo
ooooo`0]ooooo`008oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0>Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03[ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02gooooo000S
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo00Oooooo0_l0000looooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02;ooooo001Ooooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`07oooo
o`;o0000??ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Rooooo`00H?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool01oooool2o`0003gooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool08_ooool0063ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo00Oooooo0ol0000looooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02?ooooo001Pooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooo000003gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0looooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool08oooool0067ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool00000?Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Sooooo`00HOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool01?ooool00ol0003oooooo`00000nooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
02Cooooo001Rooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0?oooool00ol0003o
ooooooooo`04ooooo`04o`000?oooooo0000o`0003gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09?ooool006;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooool00000?oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Tooooo`00Hoooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo03kooooo1?l000001?l@413oooooooooool00002ooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`10ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool09Oooool006?ooooo00Go0000oooooooooooo
ooooo`000013ooooo`;o00000_ooool01Ol0003ooooooooooooooooo0000043ooooo00Go0000oooo
ooooooooooooo`000013ooooo`04o`000?ooooooooooo`0002Sooooo001Tooooo`?o0000A?ooool4
o`0000Cooooo00?o0000ooooooooool0?_ooool4o`0004Cooooo1?l0000Xooooo`00Zoooool00ol0
003oooooooooo`05ooooo`?o0000/_ooool00:_ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2booooo`00Zoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;;ooooo
002[ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/_ooool00:Wooooo00?oEEEE
ofIVI_l000001oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03
o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oo
oooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?o
oooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o
0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2boooo
o`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo
0;;ooooo002Aooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Cooooo1Ol00004ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2booooo`00Toooool00ol0003o
ooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`0;ooooo`03
oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`000;;ooooo002Cooooo`03o`00
0?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/_ooool009?ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool02_ooool01Ol0003o^[ZjoooooonH
V9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2booooo`00TOooool0
0omEEEGoIVIVo`00000<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0
002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2boooo
o`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/ooo
ool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo
0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o
0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/ooo
ool00ol0003oooooooooo`2booooo`00VOooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2booooo`00Voooool0
0ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo0;;ooooo002Kooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`2booooo`00Voooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Co
oooo0ol0002booooo`00Voooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`2booooo`00Voooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0/_ooool009_ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;;ooooo002Iooooo`03oeEEEOmVIVKo
000000gooooo1?l00006ooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?o
oooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o
0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2boooo
o`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo
0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000oooo
ooooool0/_ooool0097ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_ooool00ol0003o
k^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2boooo
o`00Toooool00ol0003oooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool0
3?ooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002booooo`00Tooo
ool00ol0003oooooooooo`0=ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`0=ooooo`03oeEEEOo<c<co
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;;ooooo002C
ooooo`03o`000?oooooooooo00gooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00[ooooo00Go410@oooo
oooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_ooool0
097ooooo00?oEEEEofIVI_l000003?ooool5o`0000Cooooo1?l00006ooooo`;o0000/oooool00;?o
oooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o
0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002coooo
o`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo
0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000oooo
ooooool0/_ooool00:Sooooo1Ol00006ooooo`03o`000?oooooooooo0;;ooooo002Xooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`2booooo`00ZOooool00onHV9So8B4Q
onk^kP07ooooo`03o`000?oooooooooo0;;ooooo002Zooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0
002booooo`00Zoooool00omgMgOoIVIVooooo`2jooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00Z?ooool01Ol0003o^[ZjoooooonHV9So410@0;_ooooo002Xooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`0^oooool00?ooooooJOooool00;7ooooo00?o0000okZj^_ooool0]?ooool00;7ooooo0_lb
<S:eooooo`00P_ooool2o`000006oa0@4?oooooooooooa0@4?l0003o410@6?ooool4o`000005oa0@
4?oooooooooooooooom4A4@00_l000001olb<S;ogMgMooooooooooooQhN7o`000?nj^[X03?ooool0
1OnHV9So0000o`000?m4A4Co^[Zj01[ooooo0_l000000ol@413oooooooooo`02ooooo`05odA4A?l0
003o0000oc8b<_oMgMd0OOooool008?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`07ooooo`Ko00003?ooool00ol0003oooooooooo`06ooooo`07ogMgMolb<S;oooooooooooo<c<co
0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000cooooo00?o0000oooo
ooooool01_ooool00omgMgOo<S8booooo`1looooo`00Poooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo01[ooooo1Ol00008ooooo`03o`000?oooooooooo07_ooooo0023ooooo`06o`00
0?ooooooA4A4odA4A?oooooo00002Oooool6o`0000cooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0@ooooo`03o`000?oooooooooo00_ooooo1_l00009ooooo`04odA4A?oMgMgooooo
o`0000Sooooo00?oMgMgoc8b<_ooool0O?ooool008?ooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0
000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Aooooo`03o`00
0?oooooooooo01[ooooo00CogMgMoeEEEOoooooo00001Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
07gooooo0023ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo00006oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo017ooooo00?o410@o`000?l000000ol0000Jooooo`03ogMgMoo<c<co
000000Gooooo00?o0000ooooooooool0Ooooool008?ooooo00Ko0000oc8b<_oooooooooooc8b<_l0
000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Kooooo`03onk^k_m4A4Co000000Gooooo00?o0000ooooooooool0Ooooool008;ooooo00?o410@
o`000?n7QhL00_ooool00on7QhOo0000oa0@400Hooooo`03oeEEEOmVIVKo000000Gooooo1?l0000B
ooooo`03o`000?oooooooooo01cooooo00?oMgMgo`000?ooool01?ooool4o`0007kooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-44.3769, -0.160437, \
0.309031, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.01333 0 0.309017 [
[.1001 -0.0125 -9 -9 ]
[.1001 -0.0125 9 0 ]
[.2334 -0.0125 -9 -9 ]
[.2334 -0.0125 9 0 ]
[.3667 -0.0125 -9 -9 ]
[.3667 -0.0125 9 0 ]
[.6333 -0.0125 -6 -9 ]
[.6333 -0.0125 6 0 ]
[.7666 -0.0125 -6 -9 ]
[.7666 -0.0125 6 0 ]
[.8999 -0.0125 -6 -9 ]
[.8999 -0.0125 6 0 ]
[.4875 .07725 -24 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -18 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -24 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1001 0 m
.1001 .00625 L
s
[(-30)] .1001 -0.0125 0 1 Mshowa
.2334 0 m
.2334 .00625 L
s
[(-20)] .2334 -0.0125 0 1 Mshowa
.3667 0 m
.3667 .00625 L
s
[(-10)] .3667 -0.0125 0 1 Mshowa
.6333 0 m
.6333 .00625 L
s
[(10)] .6333 -0.0125 0 1 Mshowa
.7666 0 m
.7666 .00625 L
s
[(20)] .7666 -0.0125 0 1 Mshowa
.8999 0 m
.8999 .00625 L
s
[(30)] .8999 -0.0125 0 1 Mshowa
.125 Mabswid
.12676 0 m
.12676 .00375 L
s
.15342 0 m
.15342 .00375 L
s
.18008 0 m
.18008 .00375 L
s
.20674 0 m
.20674 .00375 L
s
.26006 0 m
.26006 .00375 L
s
.28672 0 m
.28672 .00375 L
s
.31338 0 m
.31338 .00375 L
s
.34004 0 m
.34004 .00375 L
s
.39336 0 m
.39336 .00375 L
s
.42002 0 m
.42002 .00375 L
s
.44668 0 m
.44668 .00375 L
s
.47334 0 m
.47334 .00375 L
s
.52666 0 m
.52666 .00375 L
s
.55332 0 m
.55332 .00375 L
s
.57998 0 m
.57998 .00375 L
s
.60664 0 m
.60664 .00375 L
s
.65996 0 m
.65996 .00375 L
s
.68662 0 m
.68662 .00375 L
s
.71328 0 m
.71328 .00375 L
s
.73994 0 m
.73994 .00375 L
s
.79326 0 m
.79326 .00375 L
s
.81992 0 m
.81992 .00375 L
s
.84658 0 m
.84658 .00375 L
s
.87324 0 m
.87324 .00375 L
s
.07344 0 m
.07344 .00375 L
s
.04678 0 m
.04678 .00375 L
s
.02012 0 m
.02012 .00375 L
s
.92656 0 m
.92656 .00375 L
s
.95322 0 m
.95322 .00375 L
s
.97988 0 m
.97988 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .07725 m
.50625 .07725 L
s
[(0.25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(0.75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(1)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(1.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(1.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(1.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30282 m
.06244 .20531 L
.07216 .16003 L
.08255 .11832 L
.08852 .09897 L
.09396 .08439 L
.09948 .07224 L
.10458 .06304 L
.11433 .04953 L
.11937 .04412 L
.12492 .03913 L
.12942 .03579 L
.13426 .0329 L
.13692 .03164 L
.13937 .03071 L
.14054 .03034 L
.14182 .03 L
.14295 .02974 L
.14415 .02953 L
.14479 .02943 L
.14548 .02935 L
.1467 .02925 L
.14739 .02922 L
.14813 .02921 L
.14883 .02921 L
.14946 .02923 L
.1507 .02932 L
.15139 .0294 L
.15203 .02948 L
.15322 .02968 L
.15447 .02995 L
.15676 .03058 L
.15892 .03135 L
.16382 .03367 L
.16909 .03699 L
.17392 .04072 L
.17918 .04554 L
.1848 .05169 L
.18993 .05846 L
.1946 .06582 L
.20372 .08472 L
.20883 .09853 L
.21437 .11647 L
.22442 .1567 L
.24391 .24776 L
.24924 .26956 L
.25219 .27993 L
.25498 .28842 L
.25757 .29498 L
.25894 .2979 L
Mistroke
.26039 .30056 L
.26174 .3026 L
.26296 .3041 L
.26419 .30526 L
.26534 .30604 L
.26653 .3065 L
.26763 .30664 L
.26884 .30646 L
.27014 .30589 L
.2708 .30545 L
.27151 .30485 L
.2728 .30348 L
.27521 .29991 L
.2775 .29534 L
.27993 .28933 L
.28428 .27579 L
.30474 .18533 L
.31436 .14243 L
.32448 .10551 L
.33311 .08186 L
.34255 .06325 L
.34741 .05591 L
.35259 .04934 L
.36193 .04004 L
.36756 .03576 L
.37287 .03264 L
.37519 .03157 L
.37764 .03065 L
.37892 .03026 L
.38033 .0299 L
.38153 .02965 L
.3828 .02945 L
.3841 .0293 L
.38531 .02923 L
.3866 .02921 L
.38734 .02922 L
.38803 .02926 L
.38928 .02937 L
.39042 .02952 L
.39167 .02975 L
.39299 .03005 L
.39529 .03072 L
.39743 .03151 L
.40229 .03387 L
.40758 .03726 L
.41239 .04104 L
.41764 .0459 L
.42319 .05206 L
.42794 .05832 L
.43316 .06663 L
Mistroke
.44235 .08606 L
.44753 .10033 L
.45309 .1187 L
.46314 .15949 L
.48287 .25151 L
.48827 .27299 L
.49124 .28299 L
.49403 .291 L
.49664 .2971 L
.49801 .29974 L
.49946 .30208 L
.50069 .30368 L
.50203 .30505 L
.50325 .30593 L
.50439 .30644 L
.50567 .30664 L
.50686 .30649 L
.50816 .30593 L
.50882 .3055 L
.50954 .30491 L
.51075 .30365 L
.51206 .30192 L
.51442 .29782 L
.51675 .29263 L
.51919 .28601 L
.52357 .27155 L
.54412 .17934 L
.55367 .1375 L
.56387 .10149 L
.5735 .07672 L
.58224 .06068 L
.59224 .04759 L
.60144 .03887 L
.60626 .03536 L
.61155 .03235 L
.61422 .0312 L
.61568 .03067 L
.61708 .03024 L
.61837 .02991 L
.61978 .02962 L
.62106 .02943 L
.62225 .0293 L
.62354 .02922 L
.62419 .02921 L
.6249 .02921 L
.62617 .02926 L
.62735 .02937 L
.62806 .02946 L
.62874 .02956 L
.63001 .0298 L
Mistroke
.63285 .03055 L
.63534 .03144 L
.63763 .03245 L
.64282 .03534 L
.65186 .04223 L
.66145 .05225 L
.67085 .06593 L
.67614 .07608 L
.68097 .08738 L
.69035 .11575 L
.69927 .15083 L
.70958 .19853 L
.71929 .24421 L
.72801 .27872 L
.7304 .28623 L
.73293 .29302 L
.73529 .29822 L
.73745 .30192 L
.73857 .30343 L
.73979 .30475 L
.74108 .30577 L
.7423 .30638 L
.74344 .30663 L
.74465 .30656 L
.74568 .30623 L
.74682 .30557 L
.74747 .30505 L
.74816 .30441 L
.74938 .30299 L
.75213 .29857 L
.75451 .29344 L
.75712 .28652 L
.76798 .24595 L
.77808 .19885 L
.78718 .1568 L
.79681 .11842 L
.80184 .10188 L
.80737 .08654 L
.81712 .06599 L
.82243 .05756 L
.82814 .0501 L
.83845 .03975 L
.84385 .03569 L
.84898 .03268 L
.85121 .03164 L
.85358 .03074 L
.85495 .03031 L
.85619 .02998 L
.85744 .0297 L
.8586 .0295 L
Mistroke
.85973 .02936 L
.86093 .02925 L
.86162 .02922 L
.86227 .02921 L
.86349 .02922 L
.86477 .0293 L
.86596 .02943 L
.86726 .02964 L
.86865 .02992 L
.87091 .03054 L
.87304 .03128 L
.87788 .03354 L
.88311 .0368 L
.88791 .04047 L
.89313 .04521 L
.89871 .05125 L
.90386 .05794 L
.90853 .06522 L
.91766 .08388 L
.92278 .09754 L
.92832 .1153 L
.93837 .15523 L
.97619 .30282 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^@?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hLooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=_ooool0
03Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Oooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`12ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0=_ooool002oooooo1_l00006ooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41005?ooool6o`0000Gooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@01gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01oo
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03Cooooo000jooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000012ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`00>Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000007oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000@_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
7oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool00000=_ooool003[ooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@023ooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@03Kooooo000gooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0@_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL07?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Kooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Ko
oooo000gooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Ooo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0@?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Kooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo000Koooooooo0000<_l0000Looooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Pooooo`00>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo0016ooooo`Ko0000@_ooool6o`0001oooooo00?o0000ooooooooool0
8?ooool6o`0004;ooooo1ol00013ooooo`00A?ooool2o`0000Kooooo0ol0000mooooo`;o00001_oo
ool3o`0001cooooo0_l0000Oooooo`?o00001Oooool2o`0003kooooo0ol00005ooooo`?o0000@Ooo
ool004;ooooo0_l0000;ooooo`03o`000?oooooooooo03Sooooo0_l0000;ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`08ooooo`;o0000>oooool0
0ol0003oooooooooo`09ooooo`;o0000?oooool0047ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0gooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo03cooooo0011ooooo`03o`000?oooooooooo00co
oooo0_l0000fooooo`03o`000?oooooooooo00gooooo0_l0000Iooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0??ooool003oooooo0_l0000Aooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Fooooo`;o00006oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0kooooo`00?_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0>_ooool003kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo03Wooooo000mooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02oooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0hooooo`00??ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0=oooool003_ooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
4_ooool2o`0001Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool0=oooool003_ooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo03Kooooo000jooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0;ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@?ooooo1_l00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo03Kooooo000iooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0;ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go0000ob4Q8Oo^k^koooooodA4A007ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0eooooo`00
>Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
3?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Co0000oiRHV?lQ8B7ok^k^2Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0=Oooool003Wo
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00co
oooo00Go0000ooooooooooooooooo`00000<ooooo`04o`000?nHV9So8B4Qonk^kPOooooo00?oMgMg
oc8b<_ooool01?ooool3o`0001?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0=?ooool003Sooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00gooooo00Go0000oooo
ooooooooooooo`00000<ooooo`04o`000?ooooooMgMgofIVIPCooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0=?ooool003Sooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00gooooo00Go
410@oooooooooooooooooa0@400=ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03?ooooo000hooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0=ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjo`000?nHV9So410@00Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03?ooooo000gooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0>ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006oooo
o`;o00004_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0cooooo`00=oooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool0<_ooool003Kooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03;ooooo000fooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0booooo`00=Oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0<Oooool0
03Gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool03?ooool2o`00017ooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0<Oooool003Go
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo037o
oooo000dooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`0`ooooo`00=?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0<?ooool003Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo033ooooo000dooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00_ooooo0_l0000?oooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo02oooooo000cooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`0_ooooo`00<oooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool0;oooool003?ooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02oooooo000cooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo00[ooooo0_l0000>ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02kooooo000booooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0^ooooo`00<_ooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0;_ooool003;ooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q0oooool00ol0003oooooodA4A002o`000003
oc8b<_oMgMgooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0^ooooo`00
<_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
6oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B43ooooo`03o`000?oooooooooo00;o
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02go
oooo000booooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0Kooooo`05oa0@4?ooooooooooooooool@41002_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo0ol0000<ooooo`03o`000?oooooooooo02[ooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo02gooooo000aooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Kooooo`05o`00
0?ooooooooooooooool000002oooool01_l0003oooooooooooooooooMgMgoc8b<PGooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`0]ooooo`00<Oooool00ol0003oooooooooo`0[oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06oooool01Ol0003ooooooooooooooooo
000000_ooooo0_l000001?lQ8B7o0000oc8b<_o<c<`5ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02_ooooo00?o
0000ooooooooool0;Oooool0037ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo01cooooo00Go410@oooooooooooooooooa0@400;ooooo`;o00002Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02cooooo000aooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Looooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool2o`0000Wooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`0/ooooo`00<?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool07?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o00003?oo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`0/ooooo`00<?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo02gooooo00?o0000ooooooooool0;?ooool0033ooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo02_ooooo000`ooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0[ooooo`00;oooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`07ooooo`;o00002oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`0[ooooo`00;oooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0;oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0;oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0:oooool002oooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02[ooooo000_oooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Zoooo
o`00;oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool0:_ooool002kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool01Oooool2o`0000[ooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
:_ooool002kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo02Wooooo000^ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`0Yooooo`00;Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool0:Oooool002gooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo02Wooooo000]ooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Cooooo
0_l00009ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0dooooo`03o`000?oooooooooo02Sooooo000/ooooo`03o`000?oooooooooo03Cooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`0Xooooo`00;?ooool00ol0003oooooooooo`0d
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o0000
omgMg@05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:?ooool002cooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Sooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03o`00
0?lb<S;ooooo00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Xooooo`00:ooo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool06?oo
ool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003ooooo
ooooo`03ooooo`?o00001oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Wooooo`00:oooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooo
oooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo0000ooooo`04ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool09oooool002_ooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Sooooo00Go0000oooooooooooooooo
o`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bo`000005ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool09oooool002[ooooo00?o0000ooooooooool0
=oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Wooooo00Go410@oooooooooooo
oooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00Go0000ooooooooooooooooo`000005oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo03Kooooo00?o0000ooooooooool09oooool002[ooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Wooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool01Ol0003ooooooooooooo
oooo000000Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0gooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Wooooo`00:Oooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool06Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co000000?oooooo`000?ooool00ooo
ool2o`0000Oooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo03Sooooo00?o0000ooooooooool09_ooool002Wooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Kooooo000Yooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Vooooo`00:?ooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool09_ooool002Sooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02Gooooo
000Xooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0iooooo`04o`000?ooooooooooooooo`;o00001_ooool00ol0003oooooooooo`0iooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Uooooo`009ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>Ooo
ool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool0>Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool09Oooool002Oooooo00?o
0000ooooooooool0?Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Wooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Gooooo000Vooooo`03o`000?oo
oooooooo03kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0jooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Tooooo`009_ooool00ol0003ooooooooo
o`0oooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>_ooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo03cooooo00?o0000ooooooooool09?ooool002Kooooo00?o0000ooooooooool0?ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool00_l0
0005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0looooo`03o`000?oooooooooo02Cooooo000Uooooo`03o`000?oooooooooo043ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0looooo`04o`000?ooooooooooo`0000Gooooo00?o
0000ooooooooool0??ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03gooooo00?o
0000ooooooooool09?ooool002Gooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo03cooooo00Co0000oooooooooooo00001Oooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0?_ooool00ol0003ooooooooo
o`0Sooooo`009Oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0?_ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo03gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo02?ooooo000Toooo
o`03o`000?oooooooooo04;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0noooo
o`04o`000?oooooo0000o`0000?ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool08oooool002Cooooo00?o0000oooo
ooooool0@_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo043ooooo0_l00004oooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0ooooo
o`03o`000?oooooooooo02?ooooo000Tooooo`03o`000?oooooooooo04?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0gooooo`Co000000?o410@ooooooooool00_ooool2o`0000?o
oooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo043o
oooo00?o0000ooooooooool08_ooool002?ooooo00?o0000ooooooooool0AOooool01?l0003ooooo
ooooool0000looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_l00013ooooo`05
o`000?ooooooooooooooool00000@oooool00ol0003oooooooooo`0Rooooo`00Joooool4o`0003co
oooo00?o0000ooooooooool01Oooool4o`0004Gooooo0ol0001Yooooo`00Zoooool00ol0003ooooo
ooooo`05ooooo`?o0000/_ooool00:_ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`2booooo`00Zoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;;ooooo002[oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/_ooool00:Wooooo00?oEEEEofIVI_l0
00001oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oo
oooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo
0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o
0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0
003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002Aooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2booooo`00Toooool00ol0003ooooooooo
o`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`000;;ooooo002Cooooo`03o`000?oooooo
oooo00cooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo0;;ooooo002Cooooo`03o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool00oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0/_ooool009?ooooo00?o0000ooooooooool02_ooool01Ol0003o^[ZjoooooonHV9So410@
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2booooo`00TOooool00omEEEGo
IVIVo`00000<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0002coooo
o`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`00
0;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0
/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0
003oooooooooo`2booooo`00VOooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2booooo`00Voooool00ol0003o
ooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;;o
oooo002Kooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2booooo`00Voooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0
002booooo`00Voooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`2booooo`00Voooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0/_ooool009_ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;;ooooo002Iooooo`03oeEEEOmVIVKo000000go
oooo1?l00006ooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o
0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0
003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002coooo
o`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0
/_ooool0097ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_ooool00ol0003ok^k^oooo
o`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2booooo`00Tooo
ool00ol0003oooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool03?ooool0
0onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002booooo`00Toooool00ol0
003oooooooooo`0=ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`0=ooooo`03oeEEEOo<c<cooooo00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03
o`000?oooooooooo00gooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00[ooooo00Go410@oooooooooooo
oooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_ooool0097ooooo
00?oEEEEofIVI_l000003?ooool5o`0000Cooooo1?l00006ooooo`;o0000/oooool00;?ooooo00?o
0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0
003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002coooo
o`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0
/_ooool00:Sooooo1Ol00006ooooo`03o`000?oooooooooo0;;ooooo002Xooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01_ooool00ol0003oooooooooo`2booooo`00ZOooool00onHV9So8B4Qonk^kP07
ooooo`03o`000?oooooooooo0;;ooooo002Zooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0002boooo
o`00Zoooool00omgMgOoIVIVooooo`2jooooo`00[?ooool00ol0003oooooooooo`2iooooo`00Z?oo
ool01Ol0003o^[ZjoooooonHV9So410@0;_ooooo002Xooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
^oooool00?ooooooJOooool00;7ooooo00?o0000okZj^_ooool0]?ooool00;7ooooo0_lb<S:eoooo
o`00P_ooool2o`000006oa0@4?oooooooooooa0@4?l0003o410@6?ooool4o`000005oa0@4?oooooo
oooooooooom4A4@00_l000001olb<S;ogMgMooooooooooooQhN7o`000?nj^[X03?ooool01OnHV9So
0000o`000?m4A4Co^[Zj01Wooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h0O_ooool008?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07
ooooo`Ko00003?ooool00ol0003oooooooooo`06ooooo`07ogMgMolb<S;oooooooooooo<c<co0000
oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000gooooo00WoMgMgoc8b<_oo
ooooooooogMgMonHV9SooooooiRHV?mgMgL0O_ooool008?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Oooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool0O?oo
ool008?ooooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00003?ooool00ol0003ooooo
ooooo`06ooooo`03ogMgMolb<S;ooooo013ooooo00?o0000ooooooooool02oooool6o`0000gooooo
00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo07cooooo0023ooooo`06o`00
0?oMgMgo<S8boeEEEOoMgMgo00006oooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`04Oooool00ol0003oooooooooo`0Kooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_oo
ool01Ol0003ooooooooooooooooo000007kooooo0023ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo
00006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o410@o`000?l0
00000ol0000Jooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@401noooo
o`00Poooool01_l0003o<S8boooooooooooo<S8bo`0001_ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg07kooooo0022ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7
o`000?l@41006?ooool00omEEEGoIVIVo`000005ooooo`Co00004_ooool00ol0003oooooooooo`0K
ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07kooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-44.3769, -0.160437, \
0.309031, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.01333 0 0.309017 [
[.1001 -0.0125 -9 -9 ]
[.1001 -0.0125 9 0 ]
[.2334 -0.0125 -9 -9 ]
[.2334 -0.0125 9 0 ]
[.3667 -0.0125 -9 -9 ]
[.3667 -0.0125 9 0 ]
[.6333 -0.0125 -6 -9 ]
[.6333 -0.0125 6 0 ]
[.7666 -0.0125 -6 -9 ]
[.7666 -0.0125 6 0 ]
[.8999 -0.0125 -6 -9 ]
[.8999 -0.0125 6 0 ]
[.4875 .07725 -24 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -18 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -24 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1001 0 m
.1001 .00625 L
s
[(-30)] .1001 -0.0125 0 1 Mshowa
.2334 0 m
.2334 .00625 L
s
[(-20)] .2334 -0.0125 0 1 Mshowa
.3667 0 m
.3667 .00625 L
s
[(-10)] .3667 -0.0125 0 1 Mshowa
.6333 0 m
.6333 .00625 L
s
[(10)] .6333 -0.0125 0 1 Mshowa
.7666 0 m
.7666 .00625 L
s
[(20)] .7666 -0.0125 0 1 Mshowa
.8999 0 m
.8999 .00625 L
s
[(30)] .8999 -0.0125 0 1 Mshowa
.125 Mabswid
.12676 0 m
.12676 .00375 L
s
.15342 0 m
.15342 .00375 L
s
.18008 0 m
.18008 .00375 L
s
.20674 0 m
.20674 .00375 L
s
.26006 0 m
.26006 .00375 L
s
.28672 0 m
.28672 .00375 L
s
.31338 0 m
.31338 .00375 L
s
.34004 0 m
.34004 .00375 L
s
.39336 0 m
.39336 .00375 L
s
.42002 0 m
.42002 .00375 L
s
.44668 0 m
.44668 .00375 L
s
.47334 0 m
.47334 .00375 L
s
.52666 0 m
.52666 .00375 L
s
.55332 0 m
.55332 .00375 L
s
.57998 0 m
.57998 .00375 L
s
.60664 0 m
.60664 .00375 L
s
.65996 0 m
.65996 .00375 L
s
.68662 0 m
.68662 .00375 L
s
.71328 0 m
.71328 .00375 L
s
.73994 0 m
.73994 .00375 L
s
.79326 0 m
.79326 .00375 L
s
.81992 0 m
.81992 .00375 L
s
.84658 0 m
.84658 .00375 L
s
.87324 0 m
.87324 .00375 L
s
.07344 0 m
.07344 .00375 L
s
.04678 0 m
.04678 .00375 L
s
.02012 0 m
.02012 .00375 L
s
.92656 0 m
.92656 .00375 L
s
.95322 0 m
.95322 .00375 L
s
.97988 0 m
.97988 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .07725 m
.50625 .07725 L
s
[(0.25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(0.75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(1)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(1.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(1.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(1.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(55) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .21776 m
.03279 .25826 L
.03793 .27777 L
.04262 .29182 L
.04517 .29769 L
.04758 .30197 L
.0489 .30376 L
.05012 .30507 L
.05081 .30565 L
.05146 .3061 L
.05214 .30646 L
.05288 .30673 L
.05412 .30689 L
.05529 .30671 L
.05634 .30626 L
.05749 .30548 L
.05873 .30429 L
.06006 .30263 L
.06244 .29864 L
.06529 .29228 L
.06791 .285 L
.07382 .26425 L
.08454 .21651 L
.09491 .16735 L
.10458 .12661 L
.11366 .09631 L
.1234 .0727 L
.12895 .06266 L
.13421 .0549 L
.14407 .04368 L
.15372 .03582 L
.1586 .03293 L
.1614 .03163 L
.16398 .03067 L
.1662 .03004 L
.16732 .02979 L
.16855 .02957 L
.16978 .02941 L
.1711 .02931 L
.17235 .02927 L
.17348 .02929 L
.17462 .02936 L
.17568 .02947 L
.17684 .02964 L
.17807 .02987 L
.18013 .03039 L
.1824 .03115 L
.18761 .03355 L
.19256 .03663 L
.20184 .04429 L
Mistroke
.21184 .05553 L
.21749 .0638 L
.22274 .07319 L
.23333 .099 L
.2433 .13329 L
.26192 .21782 L
.27171 .26163 L
.27705 .28117 L
.27966 .28902 L
.28204 .29503 L
.28408 .29928 L
.2863 .30286 L
.28751 .30436 L
.28864 .30544 L
.28971 .30619 L
.29085 .30669 L
.292 .30689 L
.29323 .30675 L
.29439 .30629 L
.29545 .30559 L
.29663 .3045 L
.29792 .30295 L
.30052 .29867 L
.30307 .29307 L
.30582 .28555 L
.31082 .26849 L
.32017 .22819 L
.33016 .18055 L
.34113 .13256 L
.35143 .09727 L
.36105 .07361 L
.36636 .0638 L
.37121 .0564 L
.37649 .04968 L
.38211 .04373 L
.38681 .03954 L
.392 .03569 L
.39673 .03291 L
.40117 .03098 L
.4037 .03019 L
.40498 .02988 L
.40637 .02962 L
.40757 .02945 L
.40885 .02933 L
.41005 .02928 L
.41115 .02928 L
.41182 .0293 L
.41253 .02935 L
.41381 .02947 L
.41451 .02957 L
Mistroke
.41518 .02968 L
.41669 .02999 L
.41921 .0307 L
.42192 .03171 L
.42717 .03438 L
.43203 .03761 L
.44307 .04743 L
.4528 .0595 L
.45823 .0683 L
.46316 .07802 L
.4732 .10435 L
.48242 .13739 L
.50325 .23304 L
.51234 .27145 L
.51744 .28814 L
.51986 .29439 L
.52209 .29912 L
.52472 .3033 L
.52611 .30487 L
.52682 .30551 L
.52758 .30606 L
.52886 .30667 L
.53005 .30689 L
.53075 .30686 L
.53148 .30671 L
.53278 .30612 L
.53397 .30524 L
.53525 .30392 L
.53755 .30062 L
.54028 .29518 L
.54276 .2889 L
.55275 .253 L
.56196 .21066 L
.57271 .16007 L
.58276 .11927 L
.59181 .09087 L
.60154 .06895 L
.60707 .05964 L
.61233 .0524 L
.62218 .04188 L
.62714 .03778 L
.6318 .03461 L
.63439 .03314 L
.63718 .0318 L
.6395 .0309 L
.64073 .03049 L
.64204 .03013 L
.64331 .02983 L
.64446 .02962 L
.64562 .02946 L
Mistroke
.64671 .02935 L
.64794 .02928 L
.64907 .02928 L
.65032 .02933 L
.65164 .02944 L
.65268 .02958 L
.6538 .02978 L
.65583 .03026 L
.65824 .03102 L
.66045 .0319 L
.66521 .03435 L
.67029 .03773 L
.67942 .04564 L
.68502 .05175 L
.69029 .05863 L
.69499 .06595 L
.70014 .07566 L
.7099 .10012 L
.72021 .13616 L
.73868 .22054 L
.74869 .2648 L
.75362 .28238 L
.75818 .29493 L
.76072 .3001 L
.76202 .3022 L
.76342 .30404 L
.76415 .30482 L
.76482 .30543 L
.76613 .30632 L
.76682 .30662 L
.76758 .30683 L
.76838 .30689 L
.76912 .30682 L
.77042 .30637 L
.77164 .30559 L
.77275 .30459 L
.77394 .30318 L
.77662 .29885 L
.77909 .29348 L
.78376 .28005 L
.78878 .26157 L
.79785 .22118 L
.81848 .12806 L
.82861 .09444 L
.83434 .07989 L
.83965 .06892 L
.84938 .05373 L
.85482 .04728 L
.85975 .04237 L
.86464 .03824 L
Mistroke
.86979 .03467 L
.8742 .03229 L
.87668 .03123 L
.87902 .03043 L
.88033 .03008 L
.88175 .02976 L
.88304 .02954 L
.88423 .0294 L
.88551 .0293 L
.88625 .02928 L
.88693 .02927 L
.88765 .02929 L
.88831 .02932 L
.88904 .02937 L
.8898 .02945 L
.89101 .02962 L
.89229 .02986 L
.89461 .03045 L
.89736 .03141 L
.89985 .0325 L
.90472 .03521 L
.90986 .03885 L
.91907 .04723 L
.92898 .05949 L
.93461 .06864 L
.93988 .07917 L
.94962 .10508 L
.95886 .13839 L
.97619 .21776 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^@?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hLooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=_ooool0
03Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Oooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`12ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0=_ooool002oooooo1_l00006ooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41005?ooool6o`0000Gooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@01gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01oo
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03Cooooo000jooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000012ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`00>Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000007oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000@_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
7oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool00000=_ooool003[ooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@023ooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@03Kooooo000gooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0@_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL07?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Kooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Ko
oooo000gooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Ooo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0@?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Kooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo000Koooooooo0000<_l0000Looooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Pooooo`00>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo001=ooooo`Ko0000@oooool5o`0001Sooooo00?o0000ooooooooool0
:?ooool5o`0004?ooooo1_l0000looooo`00Boooool2o`0000Kooooo0ol0000mooooo`?o00001Ooo
ool2o`0001Kooooo0_l0000Wooooo`;o00001Oooool2o`0003oooooo0_l00006ooooo`;o0000>_oo
ool004Wooooo0_l0000;ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01oooool2
o`0003cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0gooooo`00B?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo03Kooooo0_l0000<ooooo`;o00004oooool00ol0
003oooooooooo`0Sooooo`;o00003?ooool00ol0003oooooooooo`0gooooo`;o00003?ooool2o`00
03Oooooo0017ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0dooooo`00Aoooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`;o00008_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0cooooo`00A_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0aooooo`;o00004_ooool00ol0003ooooooooo
o`0cooooo`00AOooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool0<_ooool004Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0]oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo037ooooo0013ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02cooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`0`ooooo`00@_ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0;ooooo`;o0000
7_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0`ooooo`00@_ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool0;oooool0047ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`000005ooooool0003ooooooooooom4A4@00_l000000olb<S;ogMgM
ooooo`04ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0;_ooool0047ooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01onHV9So8B4Qonk^k_ooooooA4A4oooo
ool000001Oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool0;_ooool0047ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool0;Oooool0043ooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000=oooo
o`03oiRHV?lQ8B7ok^k^00?ooooo00Ko0000ooooooooooooooooogMgMolb<S85ooooo`?o00006ooo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0]ooooo`00@?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool00_ooool2o`000004ob4Q8Ol0003o<S8bolc<c0Gooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0]ooooo`00?oooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool0;?ooool003oooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo00Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool0;?ooool003oooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo00Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0000Jooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
02cooooo000nooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`0[ooooo`00?_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool0:oooool003kooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo02_ooooo000mooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`0Zooooo`00?Oooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`05oooo
o`;o00006?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`0Zooooo`00?Oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool0:_ooool003cooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Wooooo000looooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Yooooo`00??ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0:Oooool0
03_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool00oooool2o`0001Oooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0:?ooool003_o
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02So
oooo000kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0Xooooo`00>oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool09oooool003[ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool00_ooool2o`0001Kooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool09oooool003[ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo02Oooooo000jooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`0Wooooo`00>_ooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool04oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`07odA4A?l0003o0000oc8b<_oMgMgoooooo`000003ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool09_ooool003Wooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool01?mgMgOo<S8booooool00003ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool09_ooool003Wooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo01Cooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oo
oooo000000?ooooo0ol0000Dooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02Kooooo000iooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Dooooo`05o`000?oooooo
ooooooooool000003oooool01?mgMgOo<S8booooool00003ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02[ooooo
00?o0000ooooooooool09_ooool003Wooooo00?o0000ooooooooool0:oooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo01Cooooo00Go0000ooooooooooooooooo`00000<ooooo`07o`00
0?lQ8B7o0000oc8b<_o<c<coooooo`000003ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool09_ooool003Sooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo01Gooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo
00Cooooo00Co0000oooooooooooo00005Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Uooooo`00>?ooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool05Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0
000Eooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo02Gooooo000hooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`0Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?oo
ool4o`0000?ooooo00?o0000ooooooooool00_l0000Cooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02Gooooo000h
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0]
ooooo`04o`000?ooooooooooo`0001Cooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool09Oooool003Oooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02kooooo00Co0000
oooooooooooo00005?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`0Uooooo`00=oooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0;oooool00ol0003oooooo`00000D
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo02Cooooo000gooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0_ooooo`04o`000?oooooo0000o`0001?ooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool09?ooool003Oooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo02oooooo00?o0000ooooool000004oooool00ol0003oooooooooo`0_oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Toooo
o`00=oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooo`00000Cooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02Cooooo000fooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooo000001?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool09?ooool003Kooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo037ooooo0_l0000Cooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo02?ooooo000fooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0aooooo`?o00004_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Sooooo`00=_ooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0<Oooool2o`00
01;ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool08oooool003Kooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo03;ooooo0_l0000Booooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02?o
oooo000eooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0booooo`;o00004_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Sooooo`00=Oooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo02;ooooo000Sooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03?ooooo0_l0000A
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0c
ooooo`03o`000?oooooooooo02;ooooo000Sooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0F?ooool002?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool04Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo05Sooooo000Sooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0F?ooool002Cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04Oooool01Ol@
413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03
ooooo`?o00003oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool0F?ooool002Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool04Oooool01Ol0003ooooooooooooooooo
000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`;o00003oooool0
0ol0003oooooooooo`0eooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0FOooool0
02Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool04Oooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEE
olc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo0_l0000?ooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Iooooo`009?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0Booooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgoooo
o`03ooooo`03o`000?oooooooooo00Oooooo0_l0000?ooooo`03o`000?oooooooooo03Gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`1Iooooo`009?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0B
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo
00?o0000ooooooooool01oooool00ol0003oooooo`00000>ooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Iooooo`009?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`?o0000
3_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
FOooool002Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0gooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool0=Oooool00ol0003oooooo`00000=ooooo`03o`000?oo
oooooooo03Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Iooooo`009Oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0eooooo`03o`000?oooooo000000gooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Wooooo000Uooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
03Gooooo00Co0000oooooooooooo00003?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool0F_ooool002Gooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0=Oooool01?l0
003oooooooooool0000<ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`1Jooooo`009Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0fooooo`;o000000?oooooo`00
0?ooool02_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0F_ooool002Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0iooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0=_ooool01?l0003oooooooooool0000;oooo
o`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Joooo
o`009_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0fooooo`05o`000?ooooooooooooooool000002_ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool002Ko
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0=_ooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05_ooooo000Wooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo03Oooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Kooooo`009oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0gooooo`;o00000_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Looooo`009oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0gooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0looooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0G?ooool002Sooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0>?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0?Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05cooooo000X
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1M
ooooo`00:?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0iooooo`;o00001?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo03kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Moooo
o`00:Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03oooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0GOooool002Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`10ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0<?ooool4o`000003oa0@4?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000004?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`1Nooooo`00:_ooool01Ol0003ooooooooooooooooo000004?o
oooo00Go0000ooooooooooooooooo`00000dooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool01?l0003oooooooooool00014ooooo`04o`000?ooooooooooo`00067ooooo000Z
ooooo`Co0000AOooool3o`0003Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`?o0000AOooool4o`00067ooooo002[ooooo`03o`000?oooooooooo00Gooooo0ol0002boooo
o`00Zoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;;ooooo002[ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0/_ooool00:_ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`2booooo`00ZOooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooo
oooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo
00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002c
ooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00
/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2
o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;o
oooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002c
ooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool0097ooooo1?l000000ol@413o
ooooooooo`02ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
0;;ooooo002Cooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003o
ooooooooo`03ooooo`?o0000/_ooool009?ooooo00?o0000ooooooooool03?ooool00onHV9So8B4Q
onk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/_ooool009?ooooo00?o
0000ooooooooool03Oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2booooo`00Toooool0
0ol0003oooooooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0;;ooooo002Aooooo`03oeEEEOmVIVKo000000cooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`000;?ooooo002cooooo`03o`000?oooooo
oooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;o
oooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000
ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooooooo
ool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool0
0ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002I
ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@05ooooo`03o`000?oooooooooo0;;ooooo002Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/_ooool009_ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;;ooooo002Kooooo`03
o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool3o`000;;ooooo002Kooooo`03o`00
0?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;;o
oooo002Kooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`2booooo`00Voooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0/_ooool009Wooooo00?oEEEEofIVI_l000003Oooool4o`0000Kooooo00?o0000
ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00
/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2
o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;o
oooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002c
ooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooooooo
ool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_oo
ool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00TOooool4o`000003
oa0@4?oooooooooo00;ooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00Co
oooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`2booooo`00Toooool00ol0003oooooooooo`0<ooooo`03ojVYZOmEEEGooooo00Sooooo
00?o0000ooooooooool00oooool3o`000;;ooooo002Cooooo`03o`000?oooooooooo00gooooo00?o
8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;;ooooo002C
ooooo`03o`000?oooooooooo00gooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Gooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool03Oooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_ooool0
09?ooooo00?o0000ooooooooool02_ooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`2booooo`00TOooool00omEEEGoIVIVo`00000<oooo
o`Go00001?ooool4o`0000Kooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00
/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool0
0ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;o
oooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002c
ooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooooooo
ool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_oo
ool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00Z?ooool5o`0000Ko
oooo00?o0000ooooooooool0/_ooool00:Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03
o`000?oooooooooo0;;ooooo002Yooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0
/_ooool00:[ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;;ooooo002[ooooo`03ogMgMomVIVKo
oooo0;[ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Xooooo`05o`000?nj^[[ooooooiRH
V?l@4100^oooool00:Sooooo00GoV9RHoa0@4?l0003o8B4Qolc<c02kooooo`00oooooomYooooo`00
/Oooool00ol0003o^[Zjooooo`2dooooo`00/Oooool2oc8b<[Gooooo0022ooooo`;o000000Ko410@
oooooooooooo410@o`000?l@410Hooooo`Co000000Go410@ooooooooooooooooodA4A002o`000007
oc8b<_oMgMgooooooooooon7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06Ooo
ool01Om4A4Co0000o`000?lb<S;ogMgM00?ooooo00GoA4A4o`000?l0003o<S8bomgMg@1mooooo`00
Poooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l0000<ooooo`03o`00
0?oooooooooo00Kooooo00OoMgMgoc8b<_ooooooooooolc<c?l0003o410@00cooooo00Go410@okZj
^_o^k^koMgMgoa0@4009ooooo`Ko00003Oooool00omgMgOo<S8booooo`05ooooo`03ogMgMolb<S;o
oooo07cooooo0023ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo07_ooooo0023ooooo`06o`000?ooooooA4A4odA4
A?oooooo00002Oooool6o`0000cooooo00?o0000ooooooooool01_ooool00omgMgOo<S8booooo`0@
ooooo`03o`000?oooooooooo00_ooooo1_l0000=ooooo`03ogMgMolb<S;ooooo00Gooooo00?oMgMg
oc8b<_ooool0O?ooool008?ooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Kooooo`03o`000?oo
oooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Aooooo`03o`000?oooooooooo01_ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c003ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0OOooool008?o
oooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool04Oooool00ol@413o0000o`000003o`0001[ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1oooooo`00Poooool01_l0003o<S8boooooooooooo<S8bo`0001_ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1oooooo`00P_ooool00ol@413o0000ohN7Q`02
ooooo`03ohN7Qol0003o410@01Sooooo00?oEEEEofIVI_l000001Oooool4o`0001;ooooo00?o0000
ooooooooool06oooool4o`0000Cooooo1?l0001nooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-44.3769, -0.160437, \
0.309031, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.01333 0 0.309017 [
[.1001 -0.0125 -9 -9 ]
[.1001 -0.0125 9 0 ]
[.2334 -0.0125 -9 -9 ]
[.2334 -0.0125 9 0 ]
[.3667 -0.0125 -9 -9 ]
[.3667 -0.0125 9 0 ]
[.6333 -0.0125 -6 -9 ]
[.6333 -0.0125 6 0 ]
[.7666 -0.0125 -6 -9 ]
[.7666 -0.0125 6 0 ]
[.8999 -0.0125 -6 -9 ]
[.8999 -0.0125 6 0 ]
[.4875 .07725 -24 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -18 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -24 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1001 0 m
.1001 .00625 L
s
[(-30)] .1001 -0.0125 0 1 Mshowa
.2334 0 m
.2334 .00625 L
s
[(-20)] .2334 -0.0125 0 1 Mshowa
.3667 0 m
.3667 .00625 L
s
[(-10)] .3667 -0.0125 0 1 Mshowa
.6333 0 m
.6333 .00625 L
s
[(10)] .6333 -0.0125 0 1 Mshowa
.7666 0 m
.7666 .00625 L
s
[(20)] .7666 -0.0125 0 1 Mshowa
.8999 0 m
.8999 .00625 L
s
[(30)] .8999 -0.0125 0 1 Mshowa
.125 Mabswid
.12676 0 m
.12676 .00375 L
s
.15342 0 m
.15342 .00375 L
s
.18008 0 m
.18008 .00375 L
s
.20674 0 m
.20674 .00375 L
s
.26006 0 m
.26006 .00375 L
s
.28672 0 m
.28672 .00375 L
s
.31338 0 m
.31338 .00375 L
s
.34004 0 m
.34004 .00375 L
s
.39336 0 m
.39336 .00375 L
s
.42002 0 m
.42002 .00375 L
s
.44668 0 m
.44668 .00375 L
s
.47334 0 m
.47334 .00375 L
s
.52666 0 m
.52666 .00375 L
s
.55332 0 m
.55332 .00375 L
s
.57998 0 m
.57998 .00375 L
s
.60664 0 m
.60664 .00375 L
s
.65996 0 m
.65996 .00375 L
s
.68662 0 m
.68662 .00375 L
s
.71328 0 m
.71328 .00375 L
s
.73994 0 m
.73994 .00375 L
s
.79326 0 m
.79326 .00375 L
s
.81992 0 m
.81992 .00375 L
s
.84658 0 m
.84658 .00375 L
s
.87324 0 m
.87324 .00375 L
s
.07344 0 m
.07344 .00375 L
s
.04678 0 m
.04678 .00375 L
s
.02012 0 m
.02012 .00375 L
s
.92656 0 m
.92656 .00375 L
s
.95322 0 m
.95322 .00375 L
s
.97988 0 m
.97988 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .07725 m
.50625 .07725 L
s
[(0.25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(0.75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(1)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(1.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(1.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(1.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .11183 m
.04262 .19082 L
.0522 .23648 L
.06244 .2784 L
.06525 .28728 L
.0679 .29433 L
.07027 .29944 L
.0715 .30161 L
.07286 .30359 L
.07412 .30507 L
.0753 .30612 L
.07655 .30687 L
.07726 .30712 L
.0779 .30725 L
.07904 .30724 L
.08028 .30688 L
.08146 .30619 L
.08255 .30526 L
.08394 .30368 L
.08543 .30148 L
.08815 .29623 L
.09321 .28236 L
.09913 .26059 L
.10458 .23678 L
.11444 .1897 L
.125 .1418 L
.13413 .10784 L
.14407 .08046 L
.14937 .06954 L
.15427 .06126 L
.16393 .04875 L
.17271 .04041 L
.17725 .03698 L
.18204 .03401 L
.18437 .03282 L
.18693 .03172 L
.18928 .0309 L
.19141 .03034 L
.19271 .03007 L
.19394 .02988 L
.19524 .02974 L
.19597 .02969 L
.19664 .02966 L
.19777 .02965 L
.19901 .0297 L
.2003 .02982 L
.20151 .02998 L
.20264 .03018 L
.20387 .03046 L
.20611 .0311 L
Mistroke
.21032 .03279 L
.21523 .03551 L
.21979 .03867 L
.23038 .04836 L
.24035 .06115 L
.2493 .0774 L
.25434 .08933 L
.25897 .10242 L
.27783 .17716 L
.28866 .22887 L
.29851 .27115 L
.30333 .28723 L
.30586 .29403 L
.30856 .2998 L
.31091 .30354 L
.31224 .3051 L
.3135 .30619 L
.31464 .30687 L
.31569 .30721 L
.31685 .30728 L
.31806 .30701 L
.31937 .30632 L
.32057 .30534 L
.32195 .3038 L
.32324 .30194 L
.32556 .2977 L
.32806 .29182 L
.33375 .27402 L
.33899 .25321 L
.35938 .15781 L
.36935 .11765 L
.37844 .08959 L
.38294 .07872 L
.38784 .06885 L
.39675 .05505 L
.40694 .04379 L
.41638 .03628 L
.42101 .03355 L
.42343 .03238 L
.42599 .03136 L
.42824 .03065 L
.42943 .03035 L
.4307 .03009 L
.43187 .0299 L
.43294 .02978 L
.43401 .02969 L
.43502 .02966 L
.43621 .02966 L
.43752 .02973 L
.43818 .02979 L
Mistroke
.43888 .02988 L
.44016 .03007 L
.44143 .03033 L
.44264 .03063 L
.4449 .03134 L
.45003 .0336 L
.45562 .03702 L
.46594 .04573 L
.4753 .05662 L
.4805 .06439 L
.48611 .07469 L
.49628 .10005 L
.5058 .13302 L
.51624 .1786 L
.52726 .23125 L
.53207 .2529 L
.53731 .27372 L
.53983 .28236 L
.54252 .29031 L
.545 .29644 L
.54733 .30101 L
.54951 .30418 L
.55073 .30548 L
.55185 .30637 L
.55301 .30698 L
.55428 .30728 L
.55492 .30728 L
.5556 .30718 L
.55683 .30671 L
.55751 .30629 L
.55824 .30573 L
.55954 .30441 L
.56093 .30256 L
.56247 .30002 L
.56522 .29417 L
.56779 .2873 L
.57775 .25033 L
.59634 .16294 L
.60615 .12233 L
.61659 .08944 L
.62237 .07585 L
.62759 .06591 L
.63778 .0514 L
.64277 .04598 L
.64815 .04104 L
.65319 .03716 L
.65789 .0342 L
.6625 .03196 L
.66508 .03102 L
.66743 .03037 L
Mistroke
.66877 .03009 L
.67001 .0299 L
.67065 .02982 L
.67136 .02974 L
.67211 .02969 L
.6728 .02966 L
.67408 .02966 L
.67525 .02971 L
.67589 .02976 L
.6766 .02983 L
.67788 .03001 L
.67931 .03028 L
.68066 .03061 L
.68317 .0314 L
.68588 .0325 L
.68881 .03397 L
.69897 .04107 L
.70846 .05047 L
.71889 .06489 L
.72415 .07458 L
.72979 .08741 L
.73996 .11827 L
.75976 .20456 L
.7702 .25306 L
.77593 .27561 L
.77873 .28489 L
.7813 .29215 L
.78356 .29745 L
.78604 .302 L
.78732 .30383 L
.78852 .30519 L
.78978 .30626 L
.79049 .3067 L
.79114 .30699 L
.79181 .30719 L
.79253 .30728 L
.79382 .30714 L
.79453 .3069 L
.7952 .30655 L
.79593 .30605 L
.79672 .30538 L
.79813 .3038 L
.79947 .30188 L
.80199 .29718 L
.80674 .28474 L
.81115 .26954 L
.82114 .22616 L
.83996 .13901 L
.85056 .1011 L
.86031 .07617 L
Mistroke
.86528 .06661 L
.87074 .05804 L
.87606 .0512 L
.88175 .04511 L
.88721 .04023 L
.89219 .03654 L
.89719 .03355 L
.89964 .03237 L
.90193 .03145 L
.90414 .03073 L
.90653 .03016 L
.90782 .02993 L
.90852 .02984 L
.90918 .02977 L
.91034 .02968 L
.9116 .02965 L
.91225 .02966 L
.91294 .02968 L
.91421 .02977 L
.91544 .02992 L
.91657 .03011 L
.91915 .03072 L
.92187 .03162 L
.92641 .0337 L
.93065 .03624 L
.9403 .04396 L
.94993 .05456 L
.95906 .06848 L
.96726 .08587 L
.97619 .11183 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^@?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hLooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=_ooool0
03Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Oooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`12ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0=_ooool002oooooo1_l00006ooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41005?ooool6o`0000Gooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@01gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01oo
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03Cooooo000jooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000012ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`00>Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000007oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000@_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
7oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool00000=_ooool003[ooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@023ooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@03Kooooo000gooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0@_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL07?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Kooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Ko
oooo000gooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Ooo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0@?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Kooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo000Koooooooo0000<_l0000Looooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Pooooo`00>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo001Eooooo`Go0000@oooool6o`00013ooooo00?o0000ooooooooool0
<?ooool5o`0004?ooooo1Ol0000eooooo`00D_ooool4o`0000Cooooo0ol0000nooooo`?o00001?oo
ool4o`0000gooooo0_l0000_ooooo`;o00001Oooool2o`0003kooooo0ol00005ooooo`?o0000<_oo
ool0057ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0iooooo`;o00002oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02_ooooo0ol00009ooooo`03o`000?oooooo
oooo03Wooooo0_l0000;ooooo`03o`000?oooooooooo02oooooo001@ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0^ooooo`00Coooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo02Wooooo0_l0000>ooooo`;o0000=oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo02gooooo001>ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo
0_l0000Yooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo02cooooo001=ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0[ooooo`00COooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0:_ooool004cooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02Wooooo001;ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Yooooo`00
B_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`03ooooo`;o00009_ooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Xooooo`00B_oo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0:?oo
ool004Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Xooooo`05onk^k_l0003o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_l00000
1Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
:_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Oooooo0019ooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool09oooool01OmgMgOo0000oooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8bo`000004ooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool09oooool004Sooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Wooooo`05o`000?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP09ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Vooooo`00B?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Gooooo
0_l00003ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01oooool01?mgMgOo<S8b
ooooool00003ooooo`?o00008_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`00Aoooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo02Gooooo0_l00003ooooo`03o`000?oooooooooo00cooooo
00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Co0000oooooooo
oooo00008oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0Uooooo`00Aoooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooool@41000oooool00ol@413oooooooooo`0=ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0000Soooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo02Cooooo0016ooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool08oooool01ol0003oooooogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonH
V9So410@00Cooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0000Rooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo02Cooooo0016ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool08ooo
ool01ol0003oooooonk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
00Cooooo1?l00004ooooo`04o`000?oooooo0000o`00027ooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool09?ooool0
04Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
027ooooo00?o0000ooooool000008_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Sooooo`00AOooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08Oooool00ol0003o
ooooo`00000Qooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo02?ooooo0015ooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Rooooo`;o00008Oooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`0Sooooo`00AOooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool08oooool2o`00027ooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08oooool004Cooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02?ooooo0ol0000O
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo02;ooooo000Sooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0Rooooo`008oooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo04Wooooo000Sooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
BOooool002Cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool09Oooool2o`0001kooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04[ooooo000Tooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo02Gooooo0_l0000Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`1:ooooo`009?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Vooooo`;o00007_ooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0B_ooool002Co
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool09_ooool00ol0003oooooo`00000Looooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1:ooooo`009?ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooo000001cooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo04_ooooo000Uooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Kooooo0ol0
000Looooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`1;ooooo`009Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo000001cooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04_ooooo000Uoooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo02Oooooo00Co0000oooooooooooo00006_ooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Boooool002Gooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool03?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01Oooool01?l0003oooooooooool0000Jooooo`03o`000?oooooooooo02[ooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`1<ooooo`009Oooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0
1?ooool01?l0003oooooooooool0000Jooooo`03o`000?oooooooooo02[ooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`1<ooooo`009_ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0=ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`Co00006_ooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0C?ooool002Kooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool03Oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_oo
ool01?ooool01Ol0003ooooooooooooooooo000001Wooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo04cooooo000Vooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00go
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
1Ol0003ooooooooooooooooo000001Sooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo04cooooo000Vooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00gooooo00Go410@
oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00Go0000oooooooooooooooo
o`00000Hooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`1=ooooo`009_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000006?ooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0COooool002Oooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool03_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o
00000_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`1=ooooo`009oooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool0COooool002Oooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04kooooo000Wooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1>ooooo`009oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0Zooooo`;o00000oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1>ooooo`00:?ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0C_ooool002Sooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0:_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04kooooo
000Xooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`1?ooooo`00:?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0Coooool002Wooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0:oooool2o`0000Cooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0Coooool002Wooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo04oooooo000Yooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`1@ooooo`00:Oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool0D?ooool002Wooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo053ooooo000Zooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
02cooooo0_l00005ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo053ooooo000Zooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1@ooooo`00:_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`09ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_oo
ool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`1Aooooo`00:_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`09ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool0DOooool002[ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool02Oooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0
003oooooooooo`03ooooo`?o00001Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
03Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Aooooo`00:oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0:ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Aoooo
o`00:oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0:ooooo`05o`000?ooooooooooooooool000003_ooool00omE
EEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo05;ooooo000[ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo00Go410@oooo
oooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0=Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05;ooooo000[ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0D_oo
ool002cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0gooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol0
0004ooooo`Co00001_ooool2o`0000Oooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0gooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0D_ooool002cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05?ooooo000/oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Coooo
o`00;?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Wooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0Doooool002gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0iooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo05?ooooo000]ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02kooooo0_l00008ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo05?ooooo000]ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`1Dooooo`00;Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
03[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0E?ooool002gooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo05Cooooo000^ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`1Dooooo`00;_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0`ooooo`;o00002_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`1Eooooo`00;_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0m
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0EOooool002oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0?Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Gooooo000_ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Eooooo`00
<?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0aooooo`;o00002oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Fooooo`00<?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0E_oo
ool0037ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0:?ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo043ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1Fooooo`00<Oooool01Ol0003ooooooooooooooooo
000004Cooooo00Co0000oooooooooooo0000;Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00_ooooo0_l00002ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool00_l0
001Iooooo`00<_ooool3o`0004Gooooo1?l0000]ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool03?ooool4o`0004Gooooo0ol0001Jooooo`00Zoooool00ol0003oooooooooo`05oooo
o`?o0000/_ooool00:_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2booooo`00
Zoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;;ooooo002[ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0/_ooool00:Wooooo00?oEEEEofIVI_l000001oooool0
0ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;o
oooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002c
ooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooooooo
ool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_oo
ool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooooooo
o`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002Aooooo`Co
000000?o410@ooooooooool00_ooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`04ooooo`;o
8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Wo
oooo00?o0000ooooooooool00oooool3o`000;;ooooo002Cooooo`03o`000?oooooooooo00cooooo
00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;;ooooo
002Cooooo`03o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_oo
ool009?ooooo00?o0000ooooooooool02_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2booooo`00TOooool00omEEEGoIVIVo`00000<
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0002cooooo`00/oooool0
0ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_oo
ool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?o
oooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003ooooooooo
o`2booooo`00VOooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2booooo`00Voooool00ol0003oooooooooo`04
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;;ooooo002Koooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2boooo
o`00Voooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002booooo`00
Voooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003o
ooooooooo`2booooo`00Voooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0/_ooool009_ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0;;ooooo002Iooooo`03oeEEEOmVIVKo000000gooooo1?l00006
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000oooooooo
ool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_oo
ool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooooooo
o`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oo
oooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool0097o
oooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2booooo`00Toooool00ol0003o
ooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool03?ooool00onYZJWoEEEE
ooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002booooo`00Toooool00ol0003ooooooooo
o`0=ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`2booooo`00Toooool00ol0003oooooooooo`0=ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooo
oooo00gooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0;;ooooo002Cooooo`03o`000?oooooooooo00[ooooo00Go410@oooooooooooooooooc8b<P04
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_ooool0097ooooo00?oEEEEofIV
I_l000003?ooool5o`0000Cooooo1?l00006ooooo`;o0000/oooool00;?ooooo00?o0000oooooooo
ool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_oo
ool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooooooo
o`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oo
oooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00:So
oooo1Ol00006ooooo`03o`000?oooooooooo0;;ooooo002Xooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01_ooool00ol0003oooooooooo`2booooo`00ZOooool00onHV9So8B4Qonk^kP07ooooo`03o`00
0?oooooooooo0;;ooooo002Zooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0002booooo`00Zoooool0
0omgMgOoIVIVooooo`2jooooo`00[?ooool00ol0003oooooooooo`2iooooo`00Z?ooool01Ol0003o
^[ZjoooooonHV9So410@0;_ooooo002Xooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0^oooool00?oo
ooooJOooool00;7ooooo00?o0000okZj^_ooool0]?ooool00;7ooooo0_lb<S:eooooo`00P_ooool2
o`000006oa0@4?oooooooooooa0@4?l0003o410@6?ooool4o`000005oa0@4?oooooooooooooooom4
A4@00_l000001olb<S;ogMgMooooooooooooQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4
A4Co^[Zj01Sooooo00Gok^k^oc8b<_l0003o410@olc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h0O_ooool008?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko0000
3?ooool00ol0003oooooooooo`06ooooo`07ogMgMolb<S;oooooooooooo<c<co0000oa0@400<oooo
o`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoEEEEogMgMoooooooV9RHob4Q
8@03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0O_ooool008?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool000000oooool01Ol@413ooooo
oooooooooooo410@07kooooo0023ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`00
00cooooo00?o0000ooooooooool01_ooool00omgMgOo<S8booooo`0@ooooo`03o`000?oooooooooo
00_ooooo1_l00009ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooo
oooo000007kooooo0023ooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo00006oooool00ol0003ooooo
ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`04Oooool00ol0003oooooooooo`0Jooooo`05
o`000?mEEEGo0000oa0@4?o<c<`00oooool01Ol0003ooooooooooooooooo000007kooooo0023oooo
o`06o`000?n7QhOoZJVYokZj^_mEEEGo00006oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo017ooooo00?o410@o`000?l000000ol0000Iooooo`03oeEEEOn7QhOooooo00Gooooo00Go
410@oooooooooooooooooa0@401nooooo`00Poooool01_l0003o<S8boooooooooooo<S8bo`0001_o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01[o
oooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOoV9RHoooooonHV9SoMgMg07kooooo0022ooooo`03
oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool00omEEEGoIVIVo`000005ooooo`Co
00004_ooool00ol0003oooooooooo`0Kooooo`04olc<c?m4A4Co0000oa0@40?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1nooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-44.3769, -0.160437, \
0.309031, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.01333 0 0.309017 [
[.1001 -0.0125 -9 -9 ]
[.1001 -0.0125 9 0 ]
[.2334 -0.0125 -9 -9 ]
[.2334 -0.0125 9 0 ]
[.3667 -0.0125 -9 -9 ]
[.3667 -0.0125 9 0 ]
[.6333 -0.0125 -6 -9 ]
[.6333 -0.0125 6 0 ]
[.7666 -0.0125 -6 -9 ]
[.7666 -0.0125 6 0 ]
[.8999 -0.0125 -6 -9 ]
[.8999 -0.0125 6 0 ]
[.4875 .07725 -24 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -18 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -24 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1001 0 m
.1001 .00625 L
s
[(-30)] .1001 -0.0125 0 1 Mshowa
.2334 0 m
.2334 .00625 L
s
[(-20)] .2334 -0.0125 0 1 Mshowa
.3667 0 m
.3667 .00625 L
s
[(-10)] .3667 -0.0125 0 1 Mshowa
.6333 0 m
.6333 .00625 L
s
[(10)] .6333 -0.0125 0 1 Mshowa
.7666 0 m
.7666 .00625 L
s
[(20)] .7666 -0.0125 0 1 Mshowa
.8999 0 m
.8999 .00625 L
s
[(30)] .8999 -0.0125 0 1 Mshowa
.125 Mabswid
.12676 0 m
.12676 .00375 L
s
.15342 0 m
.15342 .00375 L
s
.18008 0 m
.18008 .00375 L
s
.20674 0 m
.20674 .00375 L
s
.26006 0 m
.26006 .00375 L
s
.28672 0 m
.28672 .00375 L
s
.31338 0 m
.31338 .00375 L
s
.34004 0 m
.34004 .00375 L
s
.39336 0 m
.39336 .00375 L
s
.42002 0 m
.42002 .00375 L
s
.44668 0 m
.44668 .00375 L
s
.47334 0 m
.47334 .00375 L
s
.52666 0 m
.52666 .00375 L
s
.55332 0 m
.55332 .00375 L
s
.57998 0 m
.57998 .00375 L
s
.60664 0 m
.60664 .00375 L
s
.65996 0 m
.65996 .00375 L
s
.68662 0 m
.68662 .00375 L
s
.71328 0 m
.71328 .00375 L
s
.73994 0 m
.73994 .00375 L
s
.79326 0 m
.79326 .00375 L
s
.81992 0 m
.81992 .00375 L
s
.84658 0 m
.84658 .00375 L
s
.87324 0 m
.87324 .00375 L
s
.07344 0 m
.07344 .00375 L
s
.04678 0 m
.04678 .00375 L
s
.02012 0 m
.02012 .00375 L
s
.92656 0 m
.92656 .00375 L
s
.95322 0 m
.95322 .00375 L
s
.97988 0 m
.97988 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .07725 m
.50625 .07725 L
s
[(0.25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(0.75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(1)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(1.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(1.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(1.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(65) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .05655 m
.06244 .16979 L
.07216 .21604 L
.08255 .26267 L
.08852 .28404 L
.09135 .29205 L
.09396 .29804 L
.09658 .30259 L
.09795 .30437 L
.09866 .30511 L
.09942 .30578 L
.10069 .30659 L
.10187 .30701 L
.1026 .3071 L
.10329 .30707 L
.10458 .3067 L
.10586 .30595 L
.10707 .30488 L
.10816 .30364 L
.10933 .30199 L
.11197 .29716 L
.11439 .29142 L
.11882 .27801 L
.1235 .26038 L
.14415 .16463 L
.15363 .1251 L
.16379 .09235 L
.16871 .08018 L
.17338 .07059 L
.18212 .05668 L
.19178 .04561 L
.19707 .04084 L
.20203 .03706 L
.2066 .03419 L
.21079 .03212 L
.21305 .03124 L
.21544 .0305 L
.2166 .03022 L
.21783 .02997 L
.21854 .02986 L
.21919 .02977 L
.22045 .02964 L
.22165 .02957 L
.22276 .02956 L
.22399 .0296 L
.2253 .02971 L
.22596 .02978 L
.22668 .02989 L
.22798 .03013 L
.23043 .03075 L
Mistroke
.23275 .03154 L
.23521 .03259 L
.23964 .03498 L
.24526 .03891 L
.25055 .04347 L
.25527 .0483 L
.26044 .05455 L
.27022 .07014 L
.27557 .08146 L
.28055 .09427 L
.28948 .12336 L
.29904 .16294 L
.31889 .25541 L
.32433 .27648 L
.3273 .28611 L
.3301 .29367 L
.33267 .29924 L
.33502 .30309 L
.3363 .30464 L
.33764 .30587 L
.33833 .30635 L
.33898 .30669 L
.33969 .30694 L
.34045 .30708 L
.34176 .307 L
.34242 .30681 L
.34314 .30647 L
.34442 .30558 L
.34562 .3044 L
.34703 .30258 L
.34832 .30052 L
.35122 .29458 L
.35643 .27965 L
.36137 .2613 L
.38035 .17336 L
.38999 .13175 L
.40023 .09696 L
.40898 .07549 L
.41396 .06615 L
.41865 .05886 L
.42846 .04702 L
.43382 .04198 L
.4388 .038 L
.44343 .03493 L
.44763 .03268 L
.44987 .03171 L
.45231 .03085 L
.45364 .03047 L
.45487 .03018 L
.45604 .02995 L
Mistroke
.4573 .02976 L
.45855 .02963 L
.45974 .02957 L
.46089 .02956 L
.46196 .02959 L
.46324 .02969 L
.46439 .02983 L
.46572 .03006 L
.46698 .03033 L
.46925 .03098 L
.47133 .03174 L
.47604 .034 L
.48083 .03703 L
.48608 .04115 L
.49152 .04632 L
.49667 .05217 L
.50157 .05879 L
.50689 .06748 L
.5162 .08767 L
.52147 .10258 L
.52707 .12147 L
.53712 .16287 L
.54672 .20822 L
.55683 .25475 L
.561 .27136 L
.56545 .28627 L
.56802 .29324 L
.57034 .29843 L
.57146 .30052 L
.57268 .30247 L
.57374 .3039 L
.57489 .30515 L
.57609 .30613 L
.57722 .30674 L
.57791 .30697 L
.57856 .30708 L
.57978 .30701 L
.58107 .30656 L
.58226 .30579 L
.58357 .30456 L
.58496 .30281 L
.58747 .29855 L
.58984 .29331 L
.59425 .28056 L
.60428 .24053 L
.61511 .18911 L
.62546 .14233 L
.6351 .10675 L
.64516 .0796 L
.65049 .0689 L
Mistroke
.65619 .05966 L
.6664 .04719 L
.67178 .0421 L
.67748 .03758 L
.68246 .03438 L
.68511 .03298 L
.68795 .03172 L
.69056 .03081 L
.69294 .03018 L
.69409 .02996 L
.69534 .02977 L
.69652 .02964 L
.69762 .02957 L
.6989 .02955 L
.69955 .02957 L
.70026 .0296 L
.70152 .0297 L
.70269 .02986 L
.70408 .03011 L
.70534 .0304 L
.70818 .03126 L
.71063 .03224 L
.71329 .03353 L
.71813 .03648 L
.72779 .04449 L
.73674 .0547 L
.74136 .06139 L
.74636 .07003 L
.75539 .09056 L
.76614 .12509 L
.77599 .1664 L
.78591 .21347 L
.79651 .26133 L
.80165 .28033 L
.80418 .28811 L
.80651 .29421 L
.80859 .29872 L
.81087 .30261 L
.81206 .30416 L
.81317 .30532 L
.81434 .30623 L
.8156 .30685 L
.81683 .30709 L
.81814 .30695 L
.81937 .30645 L
.82049 .30568 L
.8218 .3044 L
.82323 .30256 L
.82581 .29807 L
.82827 .29247 L
Mistroke
.83086 .28524 L
.83551 .26936 L
.8537 .18676 L
.86392 .14083 L
.87359 .1055 L
.88227 .08183 L
.89171 .06358 L
.89664 .05638 L
.90186 .05 L
.91125 .04093 L
.91604 .03726 L
.9212 .03402 L
.92416 .03253 L
.92686 .03141 L
.92945 .03058 L
.93075 .03025 L
.93217 .02996 L
.93282 .02986 L
.9335 .02976 L
.93472 .02964 L
.93603 .02956 L
.93678 .02955 L
.93747 .02956 L
.93873 .02963 L
.93988 .02974 L
.94052 .02982 L
.94121 .02993 L
.94247 .03017 L
.94482 .03078 L
.94732 .03165 L
.95181 .03376 L
.95695 .03697 L
.96177 .04072 L
.97277 .05207 L
.97619 .05655 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^@?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hLooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=_ooool0
03Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Oooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`12ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0=_ooool002oooooo1_l00006ooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41005?ooool6o`0000Gooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@01gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01oo
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03Cooooo000jooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000012ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`00>Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000007oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000@_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
7oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool00000=_ooool003[ooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@023ooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@03Kooooo000gooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0@_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL07?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Kooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Ko
oooo000gooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Ooo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0@?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Kooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo000Koooooooo0000<_l0000Looooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Pooooo`00>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo001Mooooo`Go0000@oooool5o`0000Wooooo00?o0000ooooooooool0
>?ooool4o`0004?ooooo1Ol0000^ooooo`00Foooool2o`0000Gooooo0_l0000oooooo`?o00001?oo
ool3o`0000Kooooo0_l0000fooooo`?o00001?ooool3o`0003gooooo1?l00004ooooo`Co0000:_oo
ool005Wooooo0_l00009ooooo`;o0000>oooool2o`0000[ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Oooooo001Hooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0<_ooool2o`0000cooooo00?o0000ooooooooool0>?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo02Oooooo001Fooooo`;o00003oooool00ol0003o
ooooooooo`0dooooo`;o00003oooool01Ol0003ooooooooooooooooo000003;ooooo0_l0000?oooo
o`03o`000?oooooooooo03Gooooo0_l0000>ooooo`03o`000?oooooooooo02Kooooo001Eooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00;o0000<?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Uooooo`00EOooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
o`00000aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo02Cooooo001Dooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`0Cooooo`;o0000<?ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Sooooo`008oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`0Dooooo`;o0000;oooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0R
ooooo`008oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo03[ooooo000Sooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo01Kooooo0_l0000]ooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`0kooooo`009?ooool00ol0003oooooooooo`0Zooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Gooooo`;o0000
;?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
>oooool002Cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo023ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`03o`000?lQ8B7o8B4Q00Cooooo
1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooo`00000[ooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0looooo`00
9?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
8?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Co0000oooooolQ8B7o8B4Q1?ooool01OnH
V9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooo`00000[
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0l
ooooo`009Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool07oooool01Ol@413ooooooooooooooooo410@00;ooooo00?o0000ooooooooool01oooool0
0onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000:Ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0?Ooo
ool002Gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo01oooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Sooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`Co0000:?ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0?Oooool002Gooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo00Go0000
ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Wooooo00?oMgMgofIVI_ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00Go0000ooooooooooooooooo`00000Wooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0nooooo`00
9_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
7_ooool01ol@413ooooooooooooooooo410@ooooool000003Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00000Vooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0nooooo`009_ooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool07_ooool01omg
MgOoV9RHoooooonHV9SoMgMgooooool000002Oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03oooooo
000Vooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`0Mooooo`07onk^k_lb<S;o0000oc8b<_o^k^koooooo`000009ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l00003ooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03oooooo000Wooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`10ooooo`00
9oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
@?ooool002Oooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo043ooooo000Xooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`11ooooo`00:?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Looooo`;o00001Oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`11ooooo`00:?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool0@Oooool002Wooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo04;ooooo000Yooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`12ooooo`00:Oooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@_ooool002Wooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool07Oooool2o`0000Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0@oooool002[ooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04?ooooo000Zooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`13ooooo`00:_oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0@ooo
ool002_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool07_ooool2o`0000Oooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0A?ooool0
02_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
04Cooooo000[ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`14ooooo`00;?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02[ooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`04ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool0A?ooool002cooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`15ooooo`00;?ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`05ooooo`05
oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`?o00001oooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`15ooooo`00;Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool0AOooool002gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo0000
00cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool0AOooool002gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo04Gooooo000^ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`16
ooooo`00;_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l00009ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04Kooooo000^ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`16ooooo`00;_ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`0^ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0A_ooool002oooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04Kooooo
000_ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo02;ooooo0_l0000:ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04Oooooo000_
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`17
ooooo`00;oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0Aoooool002oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo04Oooooo000`ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`18ooooo`00<?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Sooooo`;o00002ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`18ooooo`00<?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool0B?ooool0033ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo04Sooooo000`ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`18ooooo`00<Oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0BOooool0037ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool09?ooool2o`0000gooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0BOooool0037ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Wooooo000aoooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0?oooo
o`09o`000?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`00
0?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0BOooool003;ooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0dooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04Wooooo000booooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00So
oooo00?o0000ooooooooool00oooool3o`0000cooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0dooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0B_ooool003;ooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qoooooooo
ool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool0B_ooool003;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03Gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`1:ooooo`00<_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`05
oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
03Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1:ooooo`00<oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo
<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo04[ooooo000cooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`Go00001?ooool4o`0000Kooooo0_l0000>ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04_ooooo000coooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1;oooo
o`00<oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Oooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0Boooool003?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo04_ooooo000dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`1;ooooo`00=?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo03Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Wooooo`;o00004?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`1<ooooo`00=?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
03[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0C?ooool003Gooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0>_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo04cooooo000eooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03[ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`1<ooooo`00=Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0looooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0COooool003Kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0:Oooool2o`00017ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0l
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0COooool003Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0??ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04gooooo000fooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1>ooooo`00
=oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
C_ooool003Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0:_ooool2o`0001?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0C_oo
ool003Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0oooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo04kooooo000hooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0@?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo027ooooo1?l000000ol@413oooooooooo`03oooo
o`03o`000?oooooooooo01;ooooo0_l00004ooooo`03o`000?oooooooooo043ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1?ooooo`00>Oooool01?l0003oooooooooool00014oooo
o`05o`000?ooooooooooooooool000009Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo01?ooooo00Go0000ooooooooooooooooo`000013ooooo`;o00000_ooool00ol0003ooooooooo
o`1@ooooo`00>Oooool4o`0004Cooooo1?l0000Vooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool05?ooool3o`0004Gooooo1?l0001Booooo`00Zoooool00ol0003oooooooooo`05oooo
o`?o0000/_ooool00:_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2booooo`00
Zoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;;ooooo002[ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0/_ooool00:Wooooo00?oEEEEofIVI_l000001oooool0
0ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;o
oooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002c
ooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooooooo
ool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_oo
ool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooooooo
o`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002Aooooo`Co
000000?o410@ooooooooool00_ooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`04ooooo`;o
8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Wo
oooo00?o0000ooooooooool00oooool3o`000;;ooooo002Cooooo`03o`000?oooooooooo00cooooo
00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;;ooooo
002Cooooo`03o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_oo
ool009?ooooo00?o0000ooooooooool02_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2booooo`00TOooool00omEEEGoIVIVo`00000<
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0002cooooo`00/oooool0
0ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_oo
ool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?o
oooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003ooooooooo
o`2booooo`00VOooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2booooo`00Voooool00ol0003oooooooooo`04
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;;ooooo002Koooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2boooo
o`00Voooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002booooo`00
Voooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003o
ooooooooo`2booooo`00Voooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0/_ooool009_ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0;;ooooo002Iooooo`03oeEEEOmVIVKo000000gooooo1?l00006
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000oooooooo
ool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_oo
ool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooooooo
o`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oo
oooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool0097o
oooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2booooo`00Toooool00ol0003o
ooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool03?ooool00onYZJWoEEEE
ooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002booooo`00Toooool00ol0003ooooooooo
o`0=ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`2booooo`00Toooool00ol0003oooooooooo`0=ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooo
oooo00gooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0;;ooooo002Cooooo`03o`000?oooooooooo00[ooooo00Go410@oooooooooooooooooc8b<P04
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_ooool0097ooooo00?oEEEEofIV
I_l000003?ooool5o`0000Cooooo1?l00006ooooo`;o0000/oooool00;?ooooo00?o0000oooooooo
ool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_oo
ool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooooooo
o`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oo
oooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00:So
oooo1Ol00006ooooo`03o`000?oooooooooo0;;ooooo002Xooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01_ooool00ol0003oooooooooo`2booooo`00ZOooool00onHV9So8B4Qonk^kP07ooooo`03o`00
0?oooooooooo0;;ooooo002Zooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0002booooo`00Zoooool0
0omgMgOoIVIVooooo`2jooooo`00[?ooool00ol0003oooooooooo`2iooooo`00Z?ooool01Ol0003o
^[ZjoooooonHV9So410@0;_ooooo002Xooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0^oooool00?oo
ooooJOooool00;7ooooo00?o0000okZj^_ooool0]?ooool00;7ooooo0_lb<S:eooooo`00P_ooool2
o`000006oa0@4?oooooooooooa0@4?l0003o410@6?ooool4o`000005oa0@4?oooooooooooooooom4
A4@00_l000001olb<S;ogMgMooooooooooooQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4
A4Co^[Zj01Sooooo00Gok^k^oc8b<_l0003o410@olc<c004ooooo`05odA4A?l0003o0000oc8b<_oM
gMd0OOooool008?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko0000
3?ooool00ol0003oooooooooo`06ooooo`07ogMgMolb<S;oooooooooooo<c<co0000oa0@400<oooo
o`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoEEEEogMgMoooooooV9RHob4Q
8@07ooooo`03ogMgMolb<S;ooooo07cooooo0023ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool06_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0Nooo
ool008?ooooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00003?ooool00ol0003ooooo
ooooo`06ooooo`03ogMgMolb<S;ooooo013ooooo00?o0000ooooooooool02oooool6o`0000Wooooo
00Go0000oiRHV?ooooooV9RHob4Q8@07ooooo`03ogMgMolb<S;ooooo07cooooo0023ooooo`06o`00
0?oMgMgo<S8boeEEEOoMgMgo00006oooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`04Oooool00ol0003oooooooooo`0Jooooo`05o`000?mEEEGo0000oa0@4?o<c<`01?oo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<07gooooo0023ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo
00006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o410@o`000?l0
00000ol0000Iooooo`03oeEEEOn7QhOooooo00Kooooo00?o0000ooooooooool0Ooooool008?ooooo
00Ko0000oc8b<_oooooooooooc8b<_l0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0Jooooo`03omgMgOl@413oV9RH00Kooooo00?o0000oooo
ooooool0Ooooool008;ooooo00?o410@o`000?n7QhL00_ooool00on7QhOo0000oa0@400Hooooo`03
oeEEEOmVIVKo000000Gooooo1?l0000Booooo`03o`000?oooooooooo01_ooooo00Coc<c<odA4A?l0
003o410@1?ooool4o`0007kooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-44.3769, -0.160437, \
0.309031, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.01333 0 0.309017 [
[.1001 -0.0125 -9 -9 ]
[.1001 -0.0125 9 0 ]
[.2334 -0.0125 -9 -9 ]
[.2334 -0.0125 9 0 ]
[.3667 -0.0125 -9 -9 ]
[.3667 -0.0125 9 0 ]
[.6333 -0.0125 -6 -9 ]
[.6333 -0.0125 6 0 ]
[.7666 -0.0125 -6 -9 ]
[.7666 -0.0125 6 0 ]
[.8999 -0.0125 -6 -9 ]
[.8999 -0.0125 6 0 ]
[.4875 .07725 -24 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -18 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -24 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1001 0 m
.1001 .00625 L
s
[(-30)] .1001 -0.0125 0 1 Mshowa
.2334 0 m
.2334 .00625 L
s
[(-20)] .2334 -0.0125 0 1 Mshowa
.3667 0 m
.3667 .00625 L
s
[(-10)] .3667 -0.0125 0 1 Mshowa
.6333 0 m
.6333 .00625 L
s
[(10)] .6333 -0.0125 0 1 Mshowa
.7666 0 m
.7666 .00625 L
s
[(20)] .7666 -0.0125 0 1 Mshowa
.8999 0 m
.8999 .00625 L
s
[(30)] .8999 -0.0125 0 1 Mshowa
.125 Mabswid
.12676 0 m
.12676 .00375 L
s
.15342 0 m
.15342 .00375 L
s
.18008 0 m
.18008 .00375 L
s
.20674 0 m
.20674 .00375 L
s
.26006 0 m
.26006 .00375 L
s
.28672 0 m
.28672 .00375 L
s
.31338 0 m
.31338 .00375 L
s
.34004 0 m
.34004 .00375 L
s
.39336 0 m
.39336 .00375 L
s
.42002 0 m
.42002 .00375 L
s
.44668 0 m
.44668 .00375 L
s
.47334 0 m
.47334 .00375 L
s
.52666 0 m
.52666 .00375 L
s
.55332 0 m
.55332 .00375 L
s
.57998 0 m
.57998 .00375 L
s
.60664 0 m
.60664 .00375 L
s
.65996 0 m
.65996 .00375 L
s
.68662 0 m
.68662 .00375 L
s
.71328 0 m
.71328 .00375 L
s
.73994 0 m
.73994 .00375 L
s
.79326 0 m
.79326 .00375 L
s
.81992 0 m
.81992 .00375 L
s
.84658 0 m
.84658 .00375 L
s
.87324 0 m
.87324 .00375 L
s
.07344 0 m
.07344 .00375 L
s
.04678 0 m
.04678 .00375 L
s
.02012 0 m
.02012 .00375 L
s
.92656 0 m
.92656 .00375 L
s
.95322 0 m
.95322 .00375 L
s
.97988 0 m
.97988 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .07725 m
.50625 .07725 L
s
[(0.25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(0.75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(1)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(1.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(1.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(1.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(70) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .03345 m
.02846 .03634 L
.03279 .03964 L
.04262 .0494 L
.0522 .06272 L
.05756 .0725 L
.06244 .08328 L
.07283 .11346 L
.0841 .15793 L
.09385 .20325 L
.10458 .25265 L
.10951 .27216 L
.11224 .28146 L
.11482 .28913 L
.11722 .2951 L
.11983 .30028 L
.12098 .30209 L
.12221 .30369 L
.12337 .30488 L
.12442 .3057 L
.12573 .30636 L
.1264 .30654 L
.12713 .30661 L
.12842 .30644 L
.12962 .30593 L
.13035 .30545 L
.13104 .30489 L
.13233 .30353 L
.13373 .30164 L
.13525 .29909 L
.13781 .29364 L
.14054 .2864 L
.14545 .27004 L
.16514 .18094 L
.17376 .14239 L
.1832 .10739 L
.19262 .08133 L
.19776 .07053 L
.20254 .06226 L
.21263 .04899 L
.21823 .04335 L
.2234 .03898 L
.22828 .03554 L
.23364 .03254 L
.23643 .03134 L
.23904 .03046 L
.24045 .03008 L
.24179 .02979 L
.24253 .02965 L
.24333 .02953 L
Mistroke
.24401 .02944 L
.24475 .02937 L
.24546 .02932 L
.24612 .02929 L
.2474 .02928 L
.24858 .02933 L
.24981 .02943 L
.25045 .02951 L
.25114 .02961 L
.25238 .02984 L
.2552 .03057 L
.25781 .03151 L
.26028 .03261 L
.2649 .03523 L
.27458 .04293 L
.27946 .04797 L
.28485 .0546 L
.29436 .06995 L
.30328 .09023 L
.31314 .12126 L
.3235 .16373 L
.34202 .24984 L
.34695 .26972 L
.35159 .28534 L
.35416 .29237 L
.35694 .2985 L
.35817 .30068 L
.35947 .30263 L
.36069 .30411 L
.3618 .30517 L
.36292 .30595 L
.36398 .30641 L
.36511 .30661 L
.36633 .30649 L
.36739 .3061 L
.36852 .30539 L
.36949 .30455 L
.37056 .30337 L
.37294 .2998 L
.37552 .29456 L
.38018 .28169 L
.38974 .24458 L
.4002 .19541 L
.41124 .14497 L
.42129 .1074 L
.42612 .09295 L
.43136 .07986 L
.44087 .0619 L
.44616 .05441 L
.45177 .04786 L
Mistroke
.45702 .04273 L
.46182 .03874 L
.46632 .03557 L
.47124 .03279 L
.47393 .03158 L
.47643 .03067 L
.47882 .03001 L
.48016 .02973 L
.48137 .02953 L
.48251 .0294 L
.48373 .02931 L
.48476 .02928 L
.4859 .02929 L
.48712 .02936 L
.48843 .02949 L
.48967 .02968 L
.49079 .0299 L
.49298 .03047 L
.49535 .03128 L
.49967 .03327 L
.50453 .03626 L
.50908 .03973 L
.5145 .04472 L
.51946 .05018 L
.52958 .06472 L
.53489 .07482 L
.54047 .08787 L
.55003 .11694 L
.56023 .15764 L
.5786 .24322 L
.58358 .26415 L
.58885 .28282 L
.59161 .29072 L
.59464 .29771 L
.59596 .30018 L
.59739 .30239 L
.59864 .30395 L
.59996 .30523 L
.60067 .30574 L
.60131 .3061 L
.60255 .30653 L
.60325 .30661 L
.604 .30657 L
.60471 .30641 L
.60537 .30615 L
.60656 .30543 L
.60787 .30426 L
.60923 .30262 L
.6105 .30072 L
.61293 .29608 L
Mistroke
.61515 .29079 L
.62012 .27552 L
.64087 .18311 L
.64999 .14224 L
.66004 .10531 L
.66467 .0917 L
.66966 .07939 L
.67867 .06235 L
.68396 .05478 L
.68899 .0488 L
.69844 .0399 L
.70337 .03626 L
.70802 .03346 L
.71059 .0322 L
.71338 .03107 L
.71591 .03027 L
.71703 .02999 L
.71823 .02974 L
.71939 .02955 L
.72044 .02942 L
.72149 .02933 L
.7225 .02929 L
.72366 .02928 L
.72474 .02933 L
.72592 .02942 L
.72717 .02959 L
.72829 .02978 L
.72949 .03004 L
.73166 .03065 L
.73425 .0316 L
.73662 .03268 L
.74136 .0354 L
.74642 .0391 L
.75553 .04784 L
.76111 .0547 L
.76638 .06255 L
.77107 .07095 L
.77623 .08209 L
.78595 .10953 L
.79624 .14858 L
.81468 .23413 L
.81945 .25513 L
.82466 .27521 L
.82957 .29037 L
.83191 .29602 L
.83412 .30029 L
.83546 .30235 L
.8369 .30414 L
.83821 .30534 L
.83941 .3061 L
Mistroke
.84071 .30654 L
.84146 .30662 L
.84215 .30656 L
.84288 .30639 L
.84354 .30612 L
.84431 .30568 L
.84504 .30513 L
.84624 .30396 L
.84752 .30235 L
.84982 .29855 L
.85229 .29319 L
.85501 .28586 L
.86513 .2481 L
.87439 .205 L
.8852 .15456 L
.89526 .11486 L
.90442 .08736 L
.91421 .0666 L
.9198 .05784 L
.92506 .05108 L
.93492 .04123 L
.93995 .0373 L
.94466 .03427 L
.94957 .03181 L
.95217 .03083 L
.95362 .03038 L
.95496 .03003 L
.95609 .02979 L
.95733 .02957 L
.95859 .02942 L
.95927 .02936 L
.95992 .02932 L
.9611 .02928 L
.96218 .0293 L
.96336 .02937 L
.96462 .0295 L
.96567 .02965 L
.96679 .02987 L
.96882 .03037 L
.97123 .03117 L
.97343 .03207 L
.97619 .03345 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^@?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hLooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=_ooool0
03Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Oooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`12ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0=_ooool002oooooo1_l00006ooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41005?ooool6o`0000Gooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@01gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01oo
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03Cooooo000jooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000012ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`00>Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000007oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000@_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
7oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool00000=_ooool003[ooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@023ooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@03Kooooo000gooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0@_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL07?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Kooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Ko
oooo000gooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Ooo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0@?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Kooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo000Koooooooo0000<_l0000Looooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Pooooo`00>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo001Tooooo`Ko0000@_ooool6o`000003ooooool0003ooooo043ooooo
1Ol00013ooooo`Go00009_ooool002?ooooo00?o0000ooooooooool0??ooool2o`0000Kooooo0_l0
000nooooo`;o00001_ooool3o`0003gooooo0ol00005ooooo`;o0000?oooool2o`0000Gooooo0_l0
000Tooooo`009?ooool00ol0003oooooooooo`0iooooo`;o00002_ooool2o`0003[ooooo0_l00009
ooooo`?o0000>_ooool2o`0000[ooooo0_l0000kooooo`;o0000;Oooool002Gooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool02Oooool01?l0003oooooooooool0000hooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`0]ooooo`009_ooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0:oooo
o`04o`000?ooooooooooo`0003Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo02kooooo000Wooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00_ooooo0_l00002oooo
o`;o0000=?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool0;oooool002Sooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo033ooooo000Xooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0aooooo`00:Oooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool0<_ooool002[ooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0/ooooo`03o`000?oooooooooo03?ooooo000[ooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
00oooooo0_l00006ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo03?ooooo000[ooooo`03o`000?oooooooooo02_o
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0dooooo`00;?ooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0dooooo`00;Oooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B43ooooo`06o`000?nHV9So8B4Qonk^k_ooooooA4A41ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=Ooo
ool002gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo01Sooooo00Go410@oooooooooooooooooa0@400:ooooo`05o`000?ooooooV9RHob4Q8Oo^k^h0
2Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
=Oooool002kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo01Oooooo00Go0000ooooooooooooooooo`000009ooooo`07o`000?oooooooooooooooonH
V9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00008ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
03Kooooo000^ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0Gooooo`05o`000?ooooooooooooooool000002Oooool00ol0003oooooooooo`02oooo
o`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0=_ooool002kooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo01Oooooo00Go410@oooooooooooooooooa0@4009
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0=_ooool002kooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01Kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`08ooooo`08o`000?ooooooooooo`000?nj^[[ooooooiRHV?l@4104ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0gooooo`00
;oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
5_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00So0000ooooooooooooV9RHoa0@4?l0003o
8B4Qolc<c0Cooooo1?l00006ooooo`;o00002_ooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0gooooo`00;oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0>?ooool0
02oooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
03Sooooo000`ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`0hooooo`00<?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool0>Oooool0033ooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool05Oooool2o`0000cooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool0>Oooool0037ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo03Wooooo000aooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0jooooo`00<Oooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool0>_ooool0037ooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo03[ooooo000booooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo01Kooooo0_l0000=ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo03_ooooo000booooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0kooooo`00<_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0>oooool003?o
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo03_o
oooo000cooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo01Oooooo0_l0000>ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03cooooo
000cooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0looooo`00=?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0??ooool003Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo01Wooooo00Go0000oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0looooo`00=?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool06Oooool01Ol0003oV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0mooooo`00=Oooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool06?ooool0
0ol0003o410@ooooo`02ooooo`03oa0@4?oooooooooo00kooooo00?o0000ooooooooool00oooool3
o`0000oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool0?Oooool003Gooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo01Sooooo0_l00003ooooo`03o`000?oooooooooo
00gooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
03gooooo000eooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`0Gooooo`;o00000oooool00ol0003oooooooooo`0:ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03gooooo000eooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Gooooo`03
o`000?l@413ooooo00;ooooo00?o410@ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0?_ooool003Kooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Oooooo00Ko0000ogMgMonHV9So
oooooiRHV?mgMgL<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0nooooo`00=_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02co
oooo00?o0000ooooooooool05_ooool01ol0003oooooonk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0000Aooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo03kooooo000fooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0nooooo`00=_ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0?_ooool003Kooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03oooooo
000gooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo01[ooooo0_l0000Booooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03oooooo000g
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0o
ooooo`00=oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0?oooool003Oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo03oooooo000gooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`10ooooo`00>?ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Kooooo`;o00004ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`10ooooo`00>?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool0@?ooool003Sooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo043ooooo000hooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`10ooooo`00>Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0booooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0@Oooool003Wooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool07?ooool2o`0001Cooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0@Oooool003Wooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo047ooooo000ioooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0<oooo
o`05onk^k_lb<S;o0000o`000?o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`11ooooo`00>Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Cooooo00?o0000
ooooooooool03?ooool01OmgMgOoV9RHooooool0003oMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnY
ZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo04;ooooo000jooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0=Oooool0
0ol0003oooooooooo`0;ooooo`05oa0@4?ooooooooooo`000?l@41003Oooool00onYZJWoEEEEoooo
o`08ooooo`03o`000?oooooooooo00?ooooo0ol0000Dooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04;ooooo000j
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00;o00003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`12ooooo`00>_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02oooool01Ol0
003oooooo`000?oooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`12ooooo`00>_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02oooool0
1Ol@413oooooo`000?oooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0@_ooool003[ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00_ooooo00GoMgMg
oiRHV?l0003oV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0@oooool003_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00[ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0000Fooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo04?ooooo000kooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`13ooooo`00>oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo03Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0hooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool0@oooool003_ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo04Cooooo000looooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`14ooooo`00??ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Oooooo`;o00005oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03[ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`14ooooo`00??ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0jooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0A?ooool003gooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04Gooooo000moooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo03cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`15oooo
o`00?Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0AOooool003gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0mooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool08Oooool2o`0001Wooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
AOooool003gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0mooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo04Kooooo000mooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0?Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`16ooooo`00?_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
03gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0A_ooool003kooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0oooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool08_ooool2o`0001[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0Aoooool003oooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0@?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo04Oooooo0010ooooo`05o`000?ooooooooooooooool00000
@oooool01Ol0003ooooooooooooooooo000001cooooo1?l000000ol@413oooooooooo`03ooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`10ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0B?ooool0043ooooo00?o0000ooooooooool0
0_l00013ooooo`;o00000_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool06oooool01?l0003oooooooooool00014ooooo`04o`000?ooooooooooo`00
04_ooooo0011ooooo`?o0000AOooool3o`0001oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Kooooo`?o0000A_ooool3o`0004_ooooo002[ooooo`03o`000?oooooooooo00Gooooo
0ol0002booooo`00Zoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;;ooooo002[
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/_ooool00:_ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`2booooo`00ZOooool00omEEEGoIVIVo`000007ooooo`03
o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_oo
ool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?o
oooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooooooo
o`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2boooo
o`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oo
oooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo
0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool0097ooooo1?l0
00000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8b
omgMg@05ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00Cooooo0_lQ
8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h02Ooo
ool00ol0003oooooooooo`03ooooo`?o0000/_ooool009?ooooo00?o0000ooooooooool03?ooool0
0onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/_ooool0
09?ooooo00?o0000ooooooooool03Oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01Oooool00ol0003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2boooo
o`00Toooool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;;ooooo002Aooooo`03oeEEEOmVIVKo000000co
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`000;?ooooo002cooooo`03
o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oo
oooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?o
oooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o
0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2boooo
o`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo
0;;ooooo002Iooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;;ooooo002Kooooo`03o`000?oooooooooo00Co
oooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/_ooool009_ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;;ooooo
002Kooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool3o`000;;ooooo002K
ooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oo
oooooooo0;;ooooo002Kooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`2booooo`00Voooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0/_ooool009Wooooo00?oEEEEofIVI_l000003Oooool4o`0000Ko
oooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003ooooooooo
o`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2boooo
o`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oo
oooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo
0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o
0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00TOoo
ool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oo
oooooooo00Cooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`0<ooooo`03ojVYZOmEEEGo
oooo00Sooooo00?o0000ooooooooool00oooool3o`000;;ooooo002Cooooo`03o`000?oooooooooo
00gooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
0;;ooooo002Cooooo`03o`000?oooooooooo00gooooo00?oEEEEolc<c?ooool00oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000oooooooo
ool03Oooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0/_ooool009?ooooo00?o0000ooooooooool02_ooool01Ol@413ooooooooooooooooo<S8b00Co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2booooo`00TOooool00omEEEGoIVIV
o`00000<ooooo`Go00001?ooool4o`0000Kooooo0_l0002cooooo`00/oooool00ol0003ooooooooo
o`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2boooo
o`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oo
oooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo
0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o
0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00Z?oo
ool5o`0000Kooooo00?o0000ooooooooool0/_ooool00:Sooooo00GoV9RHob4Q8Oo^k^koooooodA4
A006ooooo`03o`000?oooooooooo0;;ooooo002Yooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000
ooooooooool0/_ooool00:[ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;;ooooo002[ooooo`03
ogMgMomVIVKooooo0;[ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Xooooo`05o`000?nj
^[[ooooooiRHV?l@4100^oooool00:Sooooo00GoV9RHoa0@4?l0003o8B4Qolc<c02kooooo`00oooo
oomYooooo`00/Oooool00ol0003o^[Zjooooo`2dooooo`00/Oooool2oc8b<[Gooooo0022ooooo`;o
000000Ko410@oooooooooooo410@o`000?l@410Hooooo`Co000000Go410@ooooooooooooooooodA4
A002o`000007oc8b<_oMgMgooooooooooon7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4
A?nj^[X06_ooool00ol0003ok^k^ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0O_ooool0
08?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00003?ooool00ol0
003oooooooooo`06ooooo`07ogMgMolb<S;oooooooooooo<c<co0000oa0@400<ooooo`05oa0@4?nj
^[[ok^k^ogMgMol@41002Oooool6o`0000_ooooo00?oEEEEojVYZOooool00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg07kooooo0023ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
7?ooool00onYZJWoEEEEooooo`03ooooo`05oa0@4?ooooooooooooooool@4100O_ooool008?ooooo
00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00003?ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo013ooooo00?o0000ooooooooool02oooool6o`0000cooooo00?o8B4Qoooo
ooooool00_ooool01Ol0003ooooooooooooooooo000007kooooo0023ooooo`06o`000?oMgMgo<S8b
oeEEEOoMgMgo00006oooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
4Oooool00ol0003oooooooooo`0Mooooo`03oeEEEOo<c<cooooo00;ooooo00Go0000oooooooooooo
ooooo`00001nooooo`00Poooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001_ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Aooooo`03oa0@4?l0003o000000?o00007?ooool00onY
ZJWoMgMgooooo`02ooooo`05oa0@4?ooooooooooooooool@4100O_ooool008?ooooo00Ko0000oc8b
<_oooooooooooc8b<_l0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0Jooooo`05oa0@4?oooooooooooooooolb<S800oooool01OmgMgOoV9RH
oooooonHV9SoMgMg07kooooo0022ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@4100
6?ooool00omEEEGoIVIVo`000005ooooo`Co00004_ooool00ol0003oooooooooo`0Jooooo`Go0000
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07kooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-44.3769, -0.160437, \
0.309031, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.01333 0 0.309017 [
[.1001 -0.0125 -9 -9 ]
[.1001 -0.0125 9 0 ]
[.2334 -0.0125 -9 -9 ]
[.2334 -0.0125 9 0 ]
[.3667 -0.0125 -9 -9 ]
[.3667 -0.0125 9 0 ]
[.6333 -0.0125 -6 -9 ]
[.6333 -0.0125 6 0 ]
[.7666 -0.0125 -6 -9 ]
[.7666 -0.0125 6 0 ]
[.8999 -0.0125 -6 -9 ]
[.8999 -0.0125 6 0 ]
[.4875 .07725 -24 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -18 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -24 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1001 0 m
.1001 .00625 L
s
[(-30)] .1001 -0.0125 0 1 Mshowa
.2334 0 m
.2334 .00625 L
s
[(-20)] .2334 -0.0125 0 1 Mshowa
.3667 0 m
.3667 .00625 L
s
[(-10)] .3667 -0.0125 0 1 Mshowa
.6333 0 m
.6333 .00625 L
s
[(10)] .6333 -0.0125 0 1 Mshowa
.7666 0 m
.7666 .00625 L
s
[(20)] .7666 -0.0125 0 1 Mshowa
.8999 0 m
.8999 .00625 L
s
[(30)] .8999 -0.0125 0 1 Mshowa
.125 Mabswid
.12676 0 m
.12676 .00375 L
s
.15342 0 m
.15342 .00375 L
s
.18008 0 m
.18008 .00375 L
s
.20674 0 m
.20674 .00375 L
s
.26006 0 m
.26006 .00375 L
s
.28672 0 m
.28672 .00375 L
s
.31338 0 m
.31338 .00375 L
s
.34004 0 m
.34004 .00375 L
s
.39336 0 m
.39336 .00375 L
s
.42002 0 m
.42002 .00375 L
s
.44668 0 m
.44668 .00375 L
s
.47334 0 m
.47334 .00375 L
s
.52666 0 m
.52666 .00375 L
s
.55332 0 m
.55332 .00375 L
s
.57998 0 m
.57998 .00375 L
s
.60664 0 m
.60664 .00375 L
s
.65996 0 m
.65996 .00375 L
s
.68662 0 m
.68662 .00375 L
s
.71328 0 m
.71328 .00375 L
s
.73994 0 m
.73994 .00375 L
s
.79326 0 m
.79326 .00375 L
s
.81992 0 m
.81992 .00375 L
s
.84658 0 m
.84658 .00375 L
s
.87324 0 m
.87324 .00375 L
s
.07344 0 m
.07344 .00375 L
s
.04678 0 m
.04678 .00375 L
s
.02012 0 m
.02012 .00375 L
s
.92656 0 m
.92656 .00375 L
s
.95322 0 m
.95322 .00375 L
s
.97988 0 m
.97988 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .07725 m
.50625 .07725 L
s
[(0.25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(0.75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(1)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(1.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(1.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(1.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(75) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .03108 m
.02605 .03044 L
.02729 .03016 L
.02846 .02995 L
.02954 .02979 L
.03072 .02967 L
.0318 .02961 L
.03279 .02959 L
.03396 .02961 L
.03506 .02968 L
.03626 .0298 L
.03756 .02999 L
.03891 .03026 L
.0402 .03058 L
.04262 .03133 L
.04753 .0335 L
.0521 .03622 L
.06244 .0448 L
.06795 .05083 L
.07314 .05766 L
.08284 .0745 L
.08828 .08699 L
.09328 .10085 L
.10458 .14111 L
.125 .23473 L
.13012 .25709 L
.13497 .27561 L
.13933 .28916 L
.14158 .2948 L
.14407 .29981 L
.14521 .30168 L
.14645 .30336 L
.14752 .30454 L
.14868 .30553 L
.14993 .30624 L
.15124 .30659 L
.15246 .30655 L
.15359 .3062 L
.15473 .30554 L
.15582 .30464 L
.15679 .30359 L
.15784 .30222 L
.16021 .29823 L
.16239 .29349 L
.16694 .28059 L
.17194 .26239 L
.18204 .21722 L
.19285 .16576 L
.20312 .12276 L
.21233 .09275 L
Mistroke
.21761 .07942 L
.22238 .06949 L
.23214 .05421 L
.23749 .04795 L
.24252 .04303 L
.2515 .03615 L
.25656 .03327 L
.2612 .03131 L
.26367 .03056 L
.26592 .03005 L
.26716 .02985 L
.26782 .02977 L
.26851 .0297 L
.26979 .02961 L
.27096 .02958 L
.27204 .0296 L
.2732 .02967 L
.27429 .02979 L
.27529 .02993 L
.27641 .03013 L
.27762 .0304 L
.28007 .03111 L
.28278 .03214 L
.28525 .0333 L
.29078 .03662 L
.30074 .04501 L
.31075 .05697 L
.31997 .07253 L
.32479 .08308 L
.33008 .09703 L
.34078 .1335 L
.3619 .22921 L
.36675 .25091 L
.3719 .27146 L
.37668 .28708 L
.38117 .29797 L
.38335 .30175 L
.38448 .30328 L
.38571 .30464 L
.38698 .30567 L
.38768 .30608 L
.38832 .30635 L
.38948 .3066 L
.39072 .30651 L
.39142 .30631 L
.39207 .30601 L
.39277 .30558 L
.39352 .30499 L
.39478 .30371 L
.39617 .30188 L
Mistroke
.39873 .29738 L
.40112 .29191 L
.40589 .27775 L
.41024 .26154 L
.42005 .21765 L
.43002 .17003 L
.44065 .12487 L
.45068 .09204 L
.45977 .07082 L
.4647 .06214 L
.46923 .05552 L
.47946 .04409 L
.48847 .03689 L
.49301 .03413 L
.49799 .0318 L
.5005 .03092 L
.50183 .03055 L
.50323 .03021 L
.50446 .02998 L
.50511 .02988 L
.50581 .02978 L
.50705 .02966 L
.5082 .0296 L
.50933 .02959 L
.51057 .02963 L
.51186 .02973 L
.51306 .02988 L
.51419 .03007 L
.51521 .03028 L
.51751 .0309 L
.5202 .03185 L
.52268 .03296 L
.52827 .0362 L
.53321 .03988 L
.53843 .0446 L
.54788 .05562 L
.55318 .06363 L
.55802 .07245 L
.56742 .09487 L
.57634 .12385 L
.59642 .21243 L
.60517 .25229 L
.60976 .27058 L
.6146 .28659 L
.61713 .2933 L
.6199 .29918 L
.62112 .30125 L
.62242 .3031 L
.62364 .30448 L
.62477 .30546 L
Mistroke
.626 .30619 L
.62665 .30643 L
.62734 .30658 L
.6285 .30657 L
.62977 .3062 L
.63091 .30555 L
.63213 .30452 L
.63328 .30323 L
.63433 .30179 L
.637 .29703 L
.63947 .29127 L
.64509 .27389 L
.65532 .23096 L
.67411 .14344 L
.68469 .10416 L
.69444 .07797 L
.6994 .06795 L
.70484 .059 L
.71015 .05194 L
.71584 .04573 L
.72129 .04082 L
.72627 .03709 L
.7309 .03424 L
.73353 .0329 L
.73601 .03183 L
.73851 .03095 L
.74081 .03033 L
.74201 .03008 L
.74327 .02987 L
.74453 .02972 L
.74525 .02966 L
.74591 .02962 L
.74711 .02959 L
.74824 .02961 L
.74925 .02967 L
.75035 .02978 L
.75154 .02994 L
.75281 .03018 L
.75508 .03074 L
.75754 .03157 L
.76019 .03268 L
.76497 .0353 L
.77065 .03934 L
.77584 .04392 L
.78571 .05525 L
.79486 .06999 L
.80012 .08108 L
.8049 .09316 L
.81559 .12818 L
.83649 .22174 L
Mistroke
.84565 .26212 L
.8505 .2798 L
.85317 .28793 L
.8557 .2944 L
.85813 .29942 L
.85942 .30156 L
.86078 .30342 L
.86192 .30467 L
.86319 .30569 L
.86433 .30629 L
.86541 .30658 L
.86652 .30659 L
.86769 .30628 L
.86868 .30577 L
.86977 .30494 L
.87095 .30374 L
.87221 .30211 L
.87447 .29828 L
.87704 .29261 L
.87982 .28499 L
.88486 .26772 L
.89429 .22689 L
.9138 .13682 L
.91915 .11642 L
.92489 .09773 L
.93524 .07225 L
.94031 .06308 L
.94583 .05498 L
.95587 .04389 L
.9606 .03984 L
.96564 .03624 L
.9703 .03354 L
.97469 .0316 L
.97619 .03108 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^@?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hLooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=_ooool0
03Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Oooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`12ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0=_ooool002oooooo1_l00006ooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41005?ooool6o`0000Gooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@01gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01oo
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03Cooooo000jooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000012ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`00>Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000007oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000@_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
7oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool00000=_ooool003[ooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@023ooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@03Kooooo000gooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0@_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL07?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Kooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Ko
oooo000gooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Ooo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0@?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Kooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo000Koooooooo0000<_l0000Looooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Pooooo`00>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo000Sooooo`Go0000@oooool6o`0004;ooooo1_l00013ooooo`Go0000
Ioooool002?ooooo00?o0000ooooooooool00_ooool3o`0003kooooo0ol00004ooooo`Co0000?_oo
ool3o`0000?ooooo1?l0000nooooo`;o00001Oooool2o`0003kooooo0ol0000Tooooo`00:oooool0
0ol0003oooooooooo`0iooooo`;o00002oooool00ol0003oooooooooo`0iooooo`;o000000?ooooo
o`000?ooool01oooool00ol0003oooooooooo`0iooooo`;o00002Oooool2o`0003_ooooo00?o0000
ooooooooool09Oooool002cooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo03Oooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooo
oooo03Oooooo00?o0000ooooooooool02oooool2o`0003Oooooo0_l0000Xooooo`00;Oooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0=?ooool2o`00
013ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Xooooo`00;_ooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`03ooooo`;o00002_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Xooooo`00;oooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0:Oooool0033ooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02[ooooo000`
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0[
ooooo`00<Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool0:oooool0037ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool02?ooool2o`0000kooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool0;?ooool003;ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo02cooooo000cooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol00002ooooo`03o`000?ooooooA4A400;o000000?o<S8bomgMgOooool01?ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo02gooooo000cooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A002ooooo`03o`000?oooooooooo00;o
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02ko
oooo000dooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo02kooooo000dooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0@ooooo`05o`000?ooooooooooooooool000003Oooool01OnHV9So
8B4Qonk^k_oooooo000000Gooooo00?oMgMgoc8b<_ooool01?ooool3o`0000oooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool0;oooool003Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo00oooooo00Go0000ooooooooooooooooo`00000>ooooo`04ogMgMomVIVKooooo
o`0000;ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0;oooool003Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo00oooooo00Go410@oooooooooooooooooa0@400?ooooo`;o00000ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0;ooo
ool003Kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo00oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`06o`000?nj^[[ooooooiRHV?l@413o
00000oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool0<?ooool003Kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo00kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Ol000001?ooool4o`0000Kooooo0_l0000Booooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo033ooooo000gooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0`ooooo`00
=oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
<Oooool003Sooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo037ooooo000hooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0booooo`00>?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0=ooooo`;o00004oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0booooo`00>Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool0<_ooool003Wooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo03?ooooo000iooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0cooooo`00>Oooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0<oooool003[ooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool03oooool2o`0001Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool0<oooool003[ooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo03Cooooo000jooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0dooooo`00>_oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0=?oo
ool003_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool04?ooool2o`0001Kooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0=?ooool0
03_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
03Cooooo000kooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0dooooo`00>oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02[ooooo
00?o0000ooooooooool04Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Co0000oooooolQ
8B7o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0eooooo`00??ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo00?o0000
ooooooooool00_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0eooooo`00??ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00;ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`03ooooo`?o00005_ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0e
ooooo`00??ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool04Oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool02_ooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0=Oooool0
03cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
013ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Oooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0=Ooo
ool003cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo
oooo013ooooo00Go410@oooooooooooooooooa0@4002ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool0:oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03Kooooo000m
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0@
ooooo`07ogMgMonHV9SooooooiRHV?mgMgOoooooo`00000:ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02cooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0fooooo`00?Oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool04?ooool01oo^k^ko<S8bo`00
0?lb<S;ok^k^ooooool000002_ooool4o`0000Kooooo0_l0000Hooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo03Ko
oooo000mooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0fooooo`00?Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool0=oooool003gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo03Oooooo000nooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01?ooooo0_l0000Ioooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo03Oooooo000nooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0gooooo`00?_ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0=oooool003kooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03Sooooo000oooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0hooooo`00?oooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0Dooooo`;o00006_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0hooooo`00?oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0>?ooool003oooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03Wooooo
000oooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0<_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0iooooo`00@?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0>Oooool0043ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0boooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool05Oooool2o`0001_ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0>Oooool0043ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo03Wooooo0010ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`05ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00olQ8B7o
0000ooooo`05ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0coooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0>_ooool0043ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`03o`000?lQ8B7ooooo00Gooooo00?oEEEEojVYZOooool01oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0>_ooool0047o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Co
oooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo00Gooooo00?oZJVYoeEE
EOooool02?ooool00ol0003oooooooooo`03ooooo`?o00006oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0joooo
o`00@Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool01_ooool00olQ
8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0jooooo`00@Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000oooo
ooooool01_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0=Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03_ooooo0011ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`03ooooo`05oa0@4?oooooooooo
ooooool@41001Oooool00ol0003oooooooooo`06ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03_ooooo0012oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`04ooooo`05oa0@4?oooooo
oooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0>oooool004;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`03o`000?oo
oooooooo00Cooooo1Ol00004ooooo`Co00001_ooool2o`0001gooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0>ooo
ool004;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0hooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo03cooooo0013ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0looooo`00@oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03So
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0??ooool004?ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo03cooooo0013ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Sooooo0_l0
000Oooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo03gooooo0013ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0mooooo`00A?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0joooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0?Oooool004Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03kooooo0014ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0nooooo`00A?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Jooooo`;o00008?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo03cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0nooooo`00AOooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0looooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0?oooool0
04Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
03oooooo0016ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0oooooo`00A_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Kooooo`;o00008_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`10ooooo`00A_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0@?ooool004Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`10
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04_ooool4o`000003oa0@4?oooooo
oooo00?ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo043ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`10ooooo`00Aoooool2o`00
00;ooooo00?o0000ooooooooool0@_ooool01?l0003oooooooooool0000Gooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`02o`0004?ooooo00Go0000
ooooooooooooooooo`000013ooooo`00B?ooool4o`0004Cooooo1?l0000Gooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool08oooool3o`0004Gooooo0ol00014ooooo`00Zoooool00ol0
003oooooooooo`05ooooo`?o0000/_ooool00:_ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2booooo`00Zoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;;ooooo
002[ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/_ooool00:Wooooo00?oEEEE
ofIVI_l000001oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03
o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oo
oooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?o
oooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o
0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2boooo
o`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo
0;;ooooo002Aooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Cooooo1Ol00004ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2booooo`00Toooool00ol0003o
ooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`0;ooooo`03
oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`000;;ooooo002Cooooo`03o`00
0?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/_ooool009?ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool02_ooool01Ol0003o^[ZjoooooonH
V9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2booooo`00TOooool0
0omEEEGoIVIVo`00000<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0
002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2boooo
o`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/ooo
ool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo
0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o
0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/ooo
ool00ol0003oooooooooo`2booooo`00VOooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2booooo`00Voooool0
0ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo0;;ooooo002Kooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`2booooo`00Voooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Co
oooo0ol0002booooo`00Voooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`2booooo`00Voooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0/_ooool009_ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;;ooooo002Iooooo`03oeEEEOmVIVKo
000000gooooo1?l00006ooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?o
oooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o
0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2boooo
o`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo
0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000oooo
ooooool0/_ooool0097ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_ooool00ol0003o
k^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2boooo
o`00Toooool00ol0003oooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool0
3?ooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002booooo`00Tooo
ool00ol0003oooooooooo`0=ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`0=ooooo`03oeEEEOo<c<co
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;;ooooo002C
ooooo`03o`000?oooooooooo00gooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00[ooooo00Go410@oooo
oooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_ooool0
097ooooo00?oEEEEofIVI_l000003?ooool5o`0000Cooooo1?l00006ooooo`;o0000/oooool00;?o
oooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o
0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002coooo
o`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo
0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000oooo
ooooool0/_ooool00:Sooooo1Ol00006ooooo`03o`000?oooooooooo0;;ooooo002Xooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`2booooo`00ZOooool00onHV9So8B4Q
onk^kP07ooooo`03o`000?oooooooooo0;;ooooo002Zooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0
002booooo`00Zoooool00omgMgOoIVIVooooo`2jooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00Z?ooool01Ol0003o^[ZjoooooonHV9So410@0;_ooooo002Xooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`0^oooool00?ooooooJOooool00;7ooooo00?o0000okZj^_ooool0]?ooool00;7ooooo0_lb
<S:eooooo`00P_ooool2o`000006oa0@4?oooooooooooa0@4?l0003o410@6?ooool4o`000005oa0@
4?oooooooooooooooom4A4@00_l000001olb<S;ogMgMooooooooooooQhN7o`000?nj^[X03?ooool0
1OnHV9So0000o`000?m4A4Co^[Zj01[ooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM07gooooo0023ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01ooo
ool6o`0000cooooo00?o0000ooooooooool01_ooool01omgMgOo<S8booooooooooooc<c<o`000?l@
41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000;ooooo`03oeEEEOnYZJWooooo
00Oooooo00?oMgMgoc8b<_ooool0O?ooool008?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0Looooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool0Noooool008?ooooo
00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00003?ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo013ooooo00?o0000ooooooooool02oooool6o`0000cooooo00?o8B4Qoooo
ooooool01_ooool00omgMgOo<S8booooo`1looooo`00Poooool01_l0003ogMgMoc8b<_mEEEGogMgM
o`0001_ooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<017ooooo00?o
0000ooooooooool07Oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
OOooool008?ooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Kooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool04Oooool00ol@413o0000o`000003o`0001cooooo00?oZJVYogMgMooo
ool00oooool00ol0003oooooooooo`1oooooo`00Poooool01_l0003o<S8boooooooooooo<S8bo`00
01_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
01[ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo07oooooo0022oooo
o`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool00omEEEGoIVIVo`000005oooo
o`Co00004_ooool00ol0003oooooooooo`0Jooooo`Go00001?ooool4o`0007kooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-44.3769, -0.160437, \
0.309031, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.01333 0 0.309017 [
[.1001 -0.0125 -9 -9 ]
[.1001 -0.0125 9 0 ]
[.2334 -0.0125 -9 -9 ]
[.2334 -0.0125 9 0 ]
[.3667 -0.0125 -9 -9 ]
[.3667 -0.0125 9 0 ]
[.6333 -0.0125 -6 -9 ]
[.6333 -0.0125 6 0 ]
[.7666 -0.0125 -6 -9 ]
[.7666 -0.0125 6 0 ]
[.8999 -0.0125 -6 -9 ]
[.8999 -0.0125 6 0 ]
[.4875 .07725 -24 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -18 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -24 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1001 0 m
.1001 .00625 L
s
[(-30)] .1001 -0.0125 0 1 Mshowa
.2334 0 m
.2334 .00625 L
s
[(-20)] .2334 -0.0125 0 1 Mshowa
.3667 0 m
.3667 .00625 L
s
[(-10)] .3667 -0.0125 0 1 Mshowa
.6333 0 m
.6333 .00625 L
s
[(10)] .6333 -0.0125 0 1 Mshowa
.7666 0 m
.7666 .00625 L
s
[(20)] .7666 -0.0125 0 1 Mshowa
.8999 0 m
.8999 .00625 L
s
[(30)] .8999 -0.0125 0 1 Mshowa
.125 Mabswid
.12676 0 m
.12676 .00375 L
s
.15342 0 m
.15342 .00375 L
s
.18008 0 m
.18008 .00375 L
s
.20674 0 m
.20674 .00375 L
s
.26006 0 m
.26006 .00375 L
s
.28672 0 m
.28672 .00375 L
s
.31338 0 m
.31338 .00375 L
s
.34004 0 m
.34004 .00375 L
s
.39336 0 m
.39336 .00375 L
s
.42002 0 m
.42002 .00375 L
s
.44668 0 m
.44668 .00375 L
s
.47334 0 m
.47334 .00375 L
s
.52666 0 m
.52666 .00375 L
s
.55332 0 m
.55332 .00375 L
s
.57998 0 m
.57998 .00375 L
s
.60664 0 m
.60664 .00375 L
s
.65996 0 m
.65996 .00375 L
s
.68662 0 m
.68662 .00375 L
s
.71328 0 m
.71328 .00375 L
s
.73994 0 m
.73994 .00375 L
s
.79326 0 m
.79326 .00375 L
s
.81992 0 m
.81992 .00375 L
s
.84658 0 m
.84658 .00375 L
s
.87324 0 m
.87324 .00375 L
s
.07344 0 m
.07344 .00375 L
s
.04678 0 m
.04678 .00375 L
s
.02012 0 m
.02012 .00375 L
s
.92656 0 m
.92656 .00375 L
s
.95322 0 m
.95322 .00375 L
s
.97988 0 m
.97988 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .07725 m
.50625 .07725 L
s
[(0.25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(0.75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(1)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(1.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(1.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(1.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(80) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04797 m
.02846 .0435 L
.03279 .03995 L
.03793 .03641 L
.04262 .03382 L
.04498 .03276 L
.04754 .03181 L
.04996 .0311 L
.0522 .03062 L
.05342 .03042 L
.05456 .03029 L
.05582 .0302 L
.05653 .03017 L
.05717 .03016 L
.05846 .03019 L
.0592 .03023 L
.05987 .03028 L
.06112 .03043 L
.06244 .03064 L
.06383 .03093 L
.06529 .03131 L
.06791 .03216 L
.07073 .03334 L
.07382 .03493 L
.079 .03824 L
.08454 .04268 L
.08996 .04799 L
.09491 .0538 L
.10458 .0688 L
.10939 .07861 L
.11449 .09121 L
.12366 .12019 L
.14443 .21153 L
.1538 .25435 L
.15872 .27364 L
.1639 .28998 L
.1661 .29543 L
.16845 .30014 L
.1698 .30231 L
.17103 .30393 L
.17227 .3052 L
.17343 .30608 L
.17449 .30661 L
.17562 .30687 L
.17657 .30686 L
.17763 .3066 L
.17876 .30603 L
.17998 .30508 L
.18113 .30387 L
.18218 .30249 L
Mistroke
.18468 .29822 L
.18696 .29318 L
.19205 .27823 L
.2012 .24146 L
.22194 .14468 L
.23132 .10895 L
.24122 .08094 L
.2464 .06997 L
.25208 .06032 L
.26206 .04781 L
.26731 .04284 L
.27229 .03891 L
.27681 .03594 L
.2816 .03341 L
.28408 .03237 L
.28682 .03144 L
.28801 .03111 L
.2893 .03081 L
.29051 .03058 L
.29163 .03041 L
.29233 .03033 L
.29296 .03027 L
.29366 .03022 L
.29441 .03018 L
.29513 .03017 L
.29591 .03017 L
.29664 .03019 L
.29732 .03023 L
.29853 .03034 L
.29921 .03043 L
.29985 .03052 L
.30115 .03076 L
.30253 .03107 L
.30513 .03185 L
.30753 .03276 L
.31297 .03552 L
.31767 .03865 L
.32286 .04287 L
.33242 .05306 L
.34141 .0665 L
.34609 .0756 L
.35122 .08761 L
.36157 .11949 L
.38006 .19976 L
.39013 .24679 L
.39508 .26723 L
.39965 .28317 L
.40215 .29042 L
.40491 .297 L
.40768 .302 L
Mistroke
.4092 .30402 L
.40988 .30475 L
.41062 .30543 L
.41191 .3063 L
.41313 .30678 L
.41432 .3069 L
.41542 .30671 L
.41674 .30611 L
.41793 .30522 L
.4193 .30378 L
.42059 .30203 L
.423 .29777 L
.42525 .29268 L
.43037 .27747 L
.44069 .23511 L
.45916 .1484 L
.46962 .10826 L
.47477 .09258 L
.47953 .08044 L
.48842 .06306 L
.49311 .05612 L
.49809 .05002 L
.50747 .04112 L
.51274 .03728 L
.51758 .03444 L
.52183 .0325 L
.52424 .03165 L
.52649 .03102 L
.52771 .03075 L
.52886 .03054 L
.5299 .0304 L
.53102 .03028 L
.53224 .0302 L
.53354 .03017 L
.53465 .0302 L
.53586 .03027 L
.53716 .03041 L
.53836 .0306 L
.53968 .03086 L
.54108 .0312 L
.54368 .03201 L
.54603 .03294 L
.55082 .03538 L
.55532 .03833 L
.56537 .04715 L
.57103 .0537 L
.57622 .06105 L
.58094 .06912 L
.58599 .07956 L
.5951 .10411 L
Mistroke
.60593 .14393 L
.61578 .18841 L
.62507 .23252 L
.63492 .27368 L
.64006 .28991 L
.64298 .29694 L
.64439 .29969 L
.64572 .30191 L
.64692 .30357 L
.64823 .305 L
.64942 .30596 L
.65053 .30655 L
.65184 .30688 L
.65303 .30683 L
.65369 .30665 L
.6544 .30635 L
.6557 .30549 L
.65694 .30431 L
.65807 .30292 L
.66061 .29874 L
.66297 .29362 L
.6652 .28774 L
.67563 .24928 L
.69669 .15086 L
.70634 .11294 L
.71162 .09612 L
.71659 .0829 L
.72534 .06502 L
.72999 .0578 L
.73501 .05137 L
.74457 .04193 L
.74999 .03784 L
.75504 .03477 L
.75779 .03341 L
.76038 .03232 L
.76274 .03152 L
.76524 .03087 L
.76653 .03061 L
.76722 .0305 L
.76796 .0304 L
.76925 .03026 L
.77046 .03019 L
.77119 .03017 L
.77198 .03017 L
.77273 .03019 L
.77343 .03023 L
.77474 .03035 L
.77547 .03044 L
.77613 .03054 L
.77846 .03102 L
Mistroke
.78102 .03176 L
.78369 .03276 L
.78618 .0339 L
.79541 .03983 L
.80067 .04437 L
.80547 .04932 L
.81069 .05578 L
.81624 .06416 L
.82617 .08449 L
.83535 .11114 L
.84523 .14905 L
.85613 .19915 L
.86557 .24345 L
.87072 .26507 L
.8755 .2821 L
.87823 .29011 L
.88071 .29614 L
.88346 .30135 L
.88497 .3035 L
.88639 .30506 L
.8876 .30601 L
.88889 .30665 L
.88998 .30688 L
.89118 .30681 L
.89248 .30636 L
.8932 .30593 L
.89386 .30543 L
.89515 .30417 L
.89637 .30263 L
.89873 .2987 L
.90094 .2939 L
.906 .27935 L
.91624 .23801 L
.93465 .15143 L
.94446 .11283 L
.94982 .09583 L
.9548 .08262 L
.96363 .06469 L
.9683 .05751 L
.9733 .05115 L
.97619 .04797 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^@?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hLooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=_ooool0
03Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Oooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`12ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0=_ooool002oooooo1_l00006ooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41005?ooool6o`0000Gooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@01gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01oo
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03Cooooo000jooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000012ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`00>Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000007oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000@_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
7oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool00000=_ooool003[ooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@023ooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@03Kooooo000gooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0@_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL07?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Kooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Ko
oooo000gooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Ooo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0@?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Kooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo000Koooooooo0000<_l0000Looooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Pooooo`00>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo000[ooooo`Co0000A?ooool4o`0003cooooo00?o0000ooooooooool0
1Oooool5o`0004Cooooo1?l0001Pooooo`00:?ooool3o`0000Cooooo0ol0000nooooo`Co00000ooo
ool3o`0003Wooooo0_l00004ooooo`?o00000oooool3o`0003oooooo0ol00003ooooo`Go0000G?oo
ool002Kooooo0_l0000:ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02?ooool2
o`0003Oooooo00Co0000oooooooooooooooo0_l00009ooooo`;o0000??ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo05Wooooo000Uooooo`03o`000?oooooooooo00_ooooo0_l0000h
ooooo`;o00003Oooool00ol0003oooooooooo`0dooooo`04o`000?ooooooooooo`0000gooooo0_l0
000hooooo`;o00003Oooool00ol0003oooooooooo`1Hooooo`009?ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0c
ooooo`?o00004?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0F?ooool002Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0coooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<_ooool2o`0001;ooooo00?o0000oooo
ooooool0<_ooool00ol0003oooooooooo`0?ooooo`;o0000F?ooool002?ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0<?ooool2o`0001Cooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool08_ooool003Sooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02oooooo0_l0000Eooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo02;ooooo000hooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooo000001Gooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool08ooo
ool003Wooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo02cooooo00Co0000oooooooooooo00005_ooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Tooooo`00>_ooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0:_ooool0
1?l0003oooooooooooooool2o`0001Gooooo00?o0000ooooooooool0:oooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool09?ooool003[ooooo00?o0000
ooooooooool0:_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Wooooo00Go0000
ooooooooooooooooo`00000Gooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02Gooooo000kooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0:ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`06odA4A?l0003o0000oc8b<_oMgMgo
00001?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02Gooooo000kooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`09ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007oooo
o`03ogMgMolb<S;o000000Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Voooo
o`00??ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool02Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool2o`00
00Cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Wooooo`00??ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02Oooool01Ol0003o
oooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo0000ooooo`04oooo
o`?o00005oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0Wooooo`00??ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo0000
00kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;o000000Gooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0Xooooo`00?Oooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool02?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0Xooooo`00?Oooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`04o`000?ooooooooooo`0000Ko
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Yooooo`00?_ooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`00
01Wooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool0:Oooool003kooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo02[ooooo000oooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Zooooo`00?oooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0:_ooool003oooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02_ooooo0010oooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo00Kooooo0_l0000Kooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02_ooooo0010ooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0[ooooo`00
@?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
:oooool0047ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo02_ooooo0011ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0/ooooo`00@Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`07ooooo`;o00007?ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0/ooooo`00@Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool0;?ooool004;ooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo02cooooo0012ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0]ooooo`00@_ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`08
ooooo`;o00007Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0]ooooo`00@_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0;Oooool004;ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02gooooo0013ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0:ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@?ooooo00?o0000oooooom4A4@00_l000000olb<S;o
gMgMooooo`04ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0;_ooool004?ooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00[ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q0oooool00ol0003oooooooooo`02ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0^ooooo`00
@oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
2Oooool01Ol@413ooooooooooooooooo410@00[ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`?o00007_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0^ooooo`00@oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool02Oooool01Ol0003ooooo
oooooooooooo000000Wooooo00?o0000ooooooooool00oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool0;_ooool004Cooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Wooooo00Go0000oooooooooooo
ooooo`000009ooooo`08o`000?ooooooooooo`000?lQ8B7o0000oc8b<_o<c<`5ooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0;oooool004Cooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Wooooo00Go410@oooooooooooooooooa0@
4009ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0_ooooo`00A?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02cooooo00?o
0000ooooooooool02Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Wooooo00Co0000oooooooooooo
00002Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02oooooo0014ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`08ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02Oooool00ol0003oooooooooo`04o`0000Kooooo0_l0000Pooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo02oooooo0014ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0`ooooo`00AOooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0<?ooool004Gooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo033ooooo0015ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
00_ooooo0_l0000Qooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo033ooooo0015ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0`ooooo`00A_ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0<Oooool004Kooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo037ooooo0016
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0a
ooooo`00A_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0<ooooo`;o00008_ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo033ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0aoooo
o`00A_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0<_ooool004Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo03;ooooo0017ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0booooo`00Aoooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0<_ooool004Oooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool2o`00
02?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0<oooool004Sooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo03?ooooo0018ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0=?ooool01Ol0003o<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03
o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0<oooool004Sooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0dooooo`05ogMgMol0003ooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?o0000ojVY
ZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0<oooool004Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0dooooo`05
oa0@4?l0003oooooooooool@41003Oooool00ol0003oEEEEooooo`08ooooo`03o`000?oooooooooo
00?ooooo0ol0000Sooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo03?ooooo0019ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0=?ooool2o`0000;ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooob4Q8@08ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0dooooo`00BOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Gooooo
0_l00002ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooomEEEGoc<c<1?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0doooo
o`00BOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Gooooo00Go410@o`000?oo
oooooooooa0@400<ooooo`04o`000?ooooooZJVYogMgM`Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Cooooo0019ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0=Oooool01OmgMgOoV9RHo`000?nHV9SoMgMg00_ooooo00Go410@
o`000?oooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0dooooo`00BOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo03Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0
000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0=oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo03Gooooo001:ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Oooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0eooooo`00B_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo03Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0=Oooool004[ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Gooooo001:ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo03Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0fooooo`00B_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Aooooo`;o00009_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0fooooo`00Boooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0=_ooool0
04_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
03Kooooo001;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0fooooo`00Boooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0=oooool004cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool2o`0002Sooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0=oooool004cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0l
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo03Oooooo001<ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0?Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0gooooo`00COooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo02Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0nooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0>?ooool004gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
5?ooool2o`0002Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0>?ooool004kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0@?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Sooooo001>ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00[ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0>Oooool004oooooo00?o0000ooooooooool00_l00013ooooo`05o`000?oooooooooo
ooooool000003oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Wooooo0_l00002
ooooo`03o`000?oooooooooo047ooooo0_l00002ooooo`03o`000?oooooooooo03[ooooo001@oooo
o`?o0000AOooool3o`00013ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Zoooo
o`Co0000A?ooool4o`0003cooooo002[ooooo`03o`000?oooooooooo00Gooooo0ol0002booooo`00
Zoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;;ooooo002[ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0/_ooool00:_ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`2booooo`00ZOooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo
0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o
0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002coooo
o`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`00
0;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002coooo
o`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool0097ooooo1?l000000ol@413ooooo
ooooo`02ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;;o
oooo002Cooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003ooooo
ooooo`03ooooo`?o0000/_ooool009?ooooo00?o0000ooooooooool03?ooool00onHV9So8B4Qonk^
kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000
ooooooooool03Oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2booooo`00Toooool00ol0
003oooooooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0;;ooooo002Aooooo`03oeEEEOmVIVKo000000cooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`000;?ooooo002cooooo`03o`000?oooooooooo
0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0
/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0
003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooo
ooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002Ioooo
o`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo0;;ooooo002Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/_ooool009_ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;;ooooo002Kooooo`03o`00
0?oooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool3o`000;;ooooo002Kooooo`03o`000?oo
oooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;;ooooo
002Kooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`2booooo`00Voooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0/_ooool009Wooooo00?oEEEEofIVI_l000003Oooool4o`0000Kooooo00?o0000oooo
ooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`00
0;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002coooo
o`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0
/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool0
0;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00TOooool4o`000003oa0@
4?oooooooooo00;ooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00Cooooo
0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`2booooo`00Toooool00ol0003oooooooooo`0<ooooo`03ojVYZOmEEEGooooo00Sooooo00?o
0000ooooooooool00oooool3o`000;;ooooo002Cooooo`03o`000?oooooooooo00gooooo00?o8B4Q
ooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;;ooooo002Coooo
o`03o`000?oooooooooo00gooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool03Oooool00onY
ZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_ooool009?o
oooo00?o0000ooooooooool02_ooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`2booooo`00TOooool00omEEEGoIVIVo`00000<ooooo`Go
00001?ooool4o`0000Kooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0
003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002coooo
o`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0
/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool0
0;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00Z?ooool5o`0000Kooooo
00?o0000ooooooooool0/_ooool00:Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`00
0?oooooooooo0;;ooooo002Yooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/_oo
ool00:[ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;;ooooo002[ooooo`03ogMgMomVIVKooooo
0;[ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002Xooooo`05o`000?nj^[[ooooooiRHV?l@
4100^oooool00:Sooooo00GoV9RHoa0@4?l0003o8B4Qolc<c02kooooo`00oooooomYooooo`00/Ooo
ool00ol0003o^[Zjooooo`2dooooo`00/Oooool2oc8b<[Gooooo0022ooooo`;o000000Ko410@oooo
oooooooo410@o`000?l@410Hooooo`Co000000Go410@ooooooooooooooooodA4A002o`000007oc8b
<_oMgMgooooooooooon7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool0
1Oo<c<co8B4Qo`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1nooooo`00Pooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l0000<ooooo`03o`000?oo
oooooooo00Kooooo00OoMgMgoc8b<_ooooooooooolc<c?l0003o410@00cooooo00Go410@okZj^_o^
k^koMgMgoa0@4009ooooo`Ko00002Oooool01OlQ8B7oV9RHoooooonHV9So8B4Q00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`1nooooo`00Poooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo01[ooooo00Go0000ooooooooooooooooo`000003ooooo`05oa0@4?ooooooooooooooool@4100
O_ooool008?ooooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00003?ooool00ol0003o
ooooooooo`06ooooo`03ogMgMolb<S;ooooo013ooooo00?o0000ooooooooool02oooool6o`0000Wo
oooo00Go<S8boiRHV?ooooooV9RHoc8b<P03ooooo`05o`000?ooooooooooooooool00000O_ooool0
08?ooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Kooooo`03o`000?oooooooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c00Aooooo`03o`000?oooooooooo01[ooooo00Goc<c<o`000?l0003o
0000olc<c003ooooo`05o`000?ooooooooooooooool00000O_ooool008?ooooo00Ko0000ohN7QonY
ZJWo^[ZjoeEEEOl0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool0
0ol@413o0000o`000003o`0001Wooooo00Go410@okZj^_oooooo^[Zjoa0@4003ooooo`05oa0@4?oo
ooooooooooooool@4100O_ooool008?ooooo00Ko0000oc8b<_oooooooooooc8b<_l0000Kooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Jooooo`05
o`000?nj^[[ooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg07kooooo0022oooo
o`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool00omEEEGoIVIVo`000005oooo
o`Co00004_ooool00ol0003oooooooooo`0Jooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^07kooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-44.3769, -0.160437, \
0.309031, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.01333 0 0.309017 [
[.1001 -0.0125 -9 -9 ]
[.1001 -0.0125 9 0 ]
[.2334 -0.0125 -9 -9 ]
[.2334 -0.0125 9 0 ]
[.3667 -0.0125 -9 -9 ]
[.3667 -0.0125 9 0 ]
[.6333 -0.0125 -6 -9 ]
[.6333 -0.0125 6 0 ]
[.7666 -0.0125 -6 -9 ]
[.7666 -0.0125 6 0 ]
[.8999 -0.0125 -6 -9 ]
[.8999 -0.0125 6 0 ]
[.4875 .07725 -24 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -18 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -24 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1001 0 m
.1001 .00625 L
s
[(-30)] .1001 -0.0125 0 1 Mshowa
.2334 0 m
.2334 .00625 L
s
[(-20)] .2334 -0.0125 0 1 Mshowa
.3667 0 m
.3667 .00625 L
s
[(-10)] .3667 -0.0125 0 1 Mshowa
.6333 0 m
.6333 .00625 L
s
[(10)] .6333 -0.0125 0 1 Mshowa
.7666 0 m
.7666 .00625 L
s
[(20)] .7666 -0.0125 0 1 Mshowa
.8999 0 m
.8999 .00625 L
s
[(30)] .8999 -0.0125 0 1 Mshowa
.125 Mabswid
.12676 0 m
.12676 .00375 L
s
.15342 0 m
.15342 .00375 L
s
.18008 0 m
.18008 .00375 L
s
.20674 0 m
.20674 .00375 L
s
.26006 0 m
.26006 .00375 L
s
.28672 0 m
.28672 .00375 L
s
.31338 0 m
.31338 .00375 L
s
.34004 0 m
.34004 .00375 L
s
.39336 0 m
.39336 .00375 L
s
.42002 0 m
.42002 .00375 L
s
.44668 0 m
.44668 .00375 L
s
.47334 0 m
.47334 .00375 L
s
.52666 0 m
.52666 .00375 L
s
.55332 0 m
.55332 .00375 L
s
.57998 0 m
.57998 .00375 L
s
.60664 0 m
.60664 .00375 L
s
.65996 0 m
.65996 .00375 L
s
.68662 0 m
.68662 .00375 L
s
.71328 0 m
.71328 .00375 L
s
.73994 0 m
.73994 .00375 L
s
.79326 0 m
.79326 .00375 L
s
.81992 0 m
.81992 .00375 L
s
.84658 0 m
.84658 .00375 L
s
.87324 0 m
.87324 .00375 L
s
.07344 0 m
.07344 .00375 L
s
.04678 0 m
.04678 .00375 L
s
.02012 0 m
.02012 .00375 L
s
.92656 0 m
.92656 .00375 L
s
.95322 0 m
.95322 .00375 L
s
.97988 0 m
.97988 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .07725 m
.50625 .07725 L
s
[(0.25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(0.75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(1)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(1.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(1.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(1.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(85) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .09071 m
.02846 .07923 L
.03279 .07024 L
.03793 .06139 L
.04262 .05475 L
.0522 .04429 L
.05746 .03987 L
.06244 .03643 L
.06754 .03364 L
.07034 .03244 L
.07295 .03153 L
.07517 .03094 L
.07632 .0307 L
.07757 .03048 L
.07827 .03039 L
.07893 .03031 L
.08022 .03021 L
.0814 .03017 L
.08265 .03018 L
.08337 .03021 L
.08413 .03026 L
.08478 .03032 L
.08549 .0304 L
.08709 .03065 L
.08857 .03096 L
.09126 .03171 L
.09415 .03278 L
.09961 .03552 L
.10458 .03881 L
.10939 .0427 L
.11449 .04767 L
.12366 .05936 L
.12875 .06789 L
.13353 .07763 L
.14443 .10757 L
.15426 .14467 L
.16461 .1919 L
.1743 .23785 L
.18311 .27411 L
.18802 .28956 L
.19027 .29516 L
.19266 .29995 L
.19387 .30192 L
.1952 .3037 L
.19642 .30497 L
.19755 .30585 L
.19824 .30624 L
.19889 .3065 L
.20011 .30673 L
.20142 .30658 L
Mistroke
.20216 .30632 L
.20285 .30596 L
.20401 .30511 L
.20526 .30384 L
.20752 .30064 L
.20973 .29644 L
.21175 .29169 L
.21636 .27796 L
.22122 .25976 L
.24112 .16776 L
.24981 .13065 L
.25924 .09823 L
.26447 .08414 L
.26929 .07337 L
.27879 .05732 L
.28362 .05118 L
.28895 .04554 L
.2942 .04093 L
.29972 .03695 L
.30456 .03417 L
.30711 .03297 L
.30984 .03192 L
.31236 .03117 L
.31464 .03066 L
.31575 .03048 L
.31694 .03033 L
.31807 .03023 L
.31911 .03019 L
.32031 .03018 L
.32161 .03022 L
.32283 .03032 L
.32394 .03046 L
.32525 .03067 L
.32667 .03097 L
.32925 .03168 L
.33195 .03266 L
.33482 .03396 L
.33998 .03694 L
.34933 .04439 L
.35459 .04989 L
.35942 .05598 L
.36832 .07069 L
.3728 .08031 L
.3777 .09288 L
.38795 .12694 L
.39728 .16643 L
.40817 .21812 L
.41822 .26284 L
.42303 .28032 L
.42753 .29318 L
Mistroke
.42979 .29816 L
.43222 .30229 L
.4336 .30405 L
.43492 .30532 L
.4361 .30612 L
.43739 .30662 L
.43806 .30673 L
.4388 .30672 L
.43949 .3066 L
.44012 .30638 L
.44133 .30572 L
.44261 .30465 L
.44398 .30308 L
.44526 .30123 L
.44817 .29569 L
.453 .28271 L
.45817 .26433 L
.478 .17337 L
.48845 .12852 L
.49418 .10808 L
.49955 .09193 L
.5094 .06945 L
.51463 .06061 L
.52027 .05291 L
.53026 .04261 L
.53942 .03594 L
.54417 .03343 L
.54677 .03233 L
.54923 .0315 L
.55153 .0309 L
.55282 .03064 L
.55402 .03045 L
.55502 .03033 L
.55613 .03023 L
.55728 .03018 L
.55836 .03017 L
.55964 .03022 L
.56036 .03027 L
.56104 .03033 L
.56227 .03049 L
.56358 .03072 L
.56608 .03131 L
.56834 .03202 L
.57387 .03446 L
.57906 .03761 L
.58886 .04579 L
.59379 .05118 L
.5992 .05837 L
.60382 .06584 L
.60877 .07553 L
Mistroke
.61769 .09837 L
.6279 .13418 L
.63898 .18325 L
.64856 .22895 L
.65365 .2518 L
.65912 .27344 L
.66186 .28267 L
.66446 .29023 L
.667 .29634 L
.66936 .30081 L
.67157 .30391 L
.67282 .30515 L
.67394 .30597 L
.67518 .30653 L
.67588 .30669 L
.67652 .30673 L
.6777 .30656 L
.67895 .30602 L
.68026 .30506 L
.68145 .30384 L
.68283 .30203 L
.68413 .29993 L
.68897 .28897 L
.69424 .27202 L
.69997 .24897 L
.71935 .15854 L
.72964 .11706 L
.73505 .09937 L
.74074 .08393 L
.74579 .07276 L
.7513 .06284 L
.76099 .04985 L
.76575 .04497 L
.77083 .04058 L
.77528 .03735 L
.78 .03455 L
.78253 .0333 L
.78532 .03216 L
.78786 .03134 L
.79023 .03076 L
.79167 .03051 L
.79237 .03041 L
.79303 .03033 L
.79425 .03022 L
.7949 .03019 L
.79558 .03017 L
.79633 .03016 L
.79714 .03018 L
.7979 .03022 L
.7986 .03027 L
Mistroke
.79924 .03034 L
.79993 .03042 L
.80133 .03064 L
.80269 .03092 L
.80397 .03124 L
.80637 .03199 L
.81176 .03435 L
.81642 .03711 L
.82148 .04085 L
.8309 .05003 L
.83626 .05689 L
.84129 .06475 L
.85141 .08623 L
.8571 .10238 L
.86231 .12005 L
.88286 .21096 L
.89288 .2566 L
.89761 .27486 L
.90197 .28863 L
.90414 .2942 L
.90653 .2992 L
.90893 .30299 L
.91024 .30452 L
.91147 .30559 L
.91263 .30628 L
.91373 .30664 L
.91471 .30673 L
.91579 .30656 L
.91695 .30606 L
.91819 .30519 L
.91925 .30416 L
.92042 .30273 L
.92297 .29856 L
.92531 .2935 L
.93058 .27819 L
.94012 .23989 L
.97619 .09072 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^@?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hLooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=_ooool0
03Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Oooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`12ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0=_ooool002oooooo1_l00006ooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41005?ooool6o`0000Gooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@01gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01oo
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03Cooooo000jooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000012ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`00>Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000007oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000@_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
7oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool00000=_ooool003[ooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@023ooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@03Kooooo000gooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0@_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL07?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Kooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Ko
oooo000gooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Ooo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0@?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Kooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo000Koooooooo0000<_l0000Looooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Pooooo`00>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo000booooo`Go0000A?ooool4o`0003Cooooo00?o0000ooooooooool0
3Oooool4o`0004Gooooo0ol0001Iooooo`00;oooool4o`0000?ooooo1?l0000nooooo`?o00000ooo
ool4o`00037ooooo0_l0000;ooooo`Co00000oooool2o`00043ooooo0ol00003ooooo`?o0000E_oo
ool002kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0iooooo`?o00002Oooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Sooooo0_l00009ooooo`;o0000?Oooool0
0ol0003oooooooooo`07ooooo`;o0000E?ooool002gooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo0_l0000hooooo`?o00003?ooool00ol0
003oooooooooo`1Aooooo`00;?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03Go
oooo0_l0000>ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`1@ooooo`00:oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool03oooool2o`0002cooooo0_l00006ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0<_ooool2o`00017ooooo00?o0000ooooooooool0Coooool002[ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04kooooo000Y
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1=
ooooo`00:?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0C?ooool002Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo04cooooo000Wooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02Oooooo0_l00002ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo04_ooooo000Vooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02Kooooo00Go0000oooooooooooooooo
o`00000Kooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`1:ooooo`009Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool01?l0003o
ooooooooool0000Looooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`1:ooooo`009Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;o
oooo00Cooooo00Co0000oooooooooooo00007Oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool0BOooool002Cooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooo000001kooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo04Wooooo000Tooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0Looooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?oo
ool3o`0001kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo04Sooooo000Tooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0Mooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`0<ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`;o0000
8?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
B?ooool002Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo01gooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00gooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`;o00008?ooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0Aoooool002?ooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01kooooo00So
0000ooooooooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4004
ooooo`03o`000?oooooooooo00Oooooo0_l0000Qooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`17ooooo`008oooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08?ooool01ol0003oooooonk^k_lb<S;o
0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000
8Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`0Rooooo`00A_ooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo02;ooooo0016ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`0Qooooo`;o00008oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Rooooo`00A_ooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08?ooool2o`00
02?ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool08oooool004Oooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo023ooooo0_l0000Sooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02?o
oooo0017ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`0Oooooo`04o`000?oooooo0000o`0002?ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool08oooool004Oooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01kooooo
00?o0000ooooool000009?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Sooooo`00Aoooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07Oooool01?l0003ooooooooo
ool0000Tooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo02?ooooo0018ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0Mooooo`04o`000?ooooooooooo`0002Gooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool09?ooool004Sooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo01gooooo00Co0000oooooooooooo00009Oooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0Tooooo`00B?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool06oooool01?l0003oooooooooooooool2o`0002Cooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
9?ooool004Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo01_ooooo00Go0000ooooooooooooooooo`00000Uooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Cooooo
0019ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`0Kooooo`05o`000?ooooooooooooooool000009_ooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Uooooo`00BOoo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool06ooo
ool01Ol0003ooooooooooooooooo000002Kooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool09Oooool004Wooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool00_ooool2o`0002Gooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool09Oooool004[ooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Gooooo001:oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Uoooo
o`00B_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`06odA4A?l0003o0000
oc8b<_oMgMgo00001?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Kooooo001:
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_l000001?oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Kooooo001;ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`?o00009Oooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Vooooo`00Boooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgo`000?ooool01?oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Kooooo001;ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;o000000Gooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0Wooooo`00Boooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo02gooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00[ooooo
00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool09oooool004_ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0]ooooo`09o`00
0?oooooooooooooooomgMgOoV9RHoooooonHV9SoMgMg00cooooo00Go0000ooooooooooooooooo`00
0005ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool09oooool004cooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`0]ooooo`09o`000?ooooooooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o00009oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Wooooo`00
C?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
9oooool004cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo02Sooooo001<ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0Xooooo`00C?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`05ooooo`;o0000:?ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0Xooooo`00COooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool0:?ooool004gooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo02Wooooo001=ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Yooooo`00COooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0:Oooool004kooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool01_ooool2o`0002Wooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0:Oooool004kooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02Wooooo001>ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Zooooo`00C_oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0:_oo
ool004kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo02[ooooo001?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo0_l0000Zooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
02[ooooo001?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0[ooooo`00Coooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02gooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`03o`000?oooooooooo00;o8B4Q1_ooool00ol0003o
k^k^ooooo`04ooooo`?o000000?o<S8bomgMgOooool01?ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo02_ooooo001?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Co0000oooooolQ8B7o8B4Q1_ooool00omE
EEGoZJVYooooo`04ooooo`05o`000?ooooooooooogMgMolb<S801Oooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo02_ooooo001?ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0;Oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o0000ooooooooool01oooool0
0onYZJWoEEEEooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool3
o`0002[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0:oooool0053ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0]ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`08
ooooo`03ob4Q8Ooooooooooo00;ooooo00Ko0000ooooooooooooooooogMgMolb<S85ooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0:oooool0053ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0]ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`08ooooo`03oeEEEOo<c<cooooo00;ooooo0_l000001?lQ8B7o0000oc8b<_o<c<`5ooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0;?ooool0053ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0^ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol0003o
ooooooooo`08ooooo`03ojVYZOmgMgOooooo00;ooooo0_l00009ooooo`03o`000?oooooooooo02_o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0;?ooool0053ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0^ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`04ooooo`05
oa0@4?oooooooooooooooolb<S800_ooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool0;?ooool0057ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0^ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool00ol0003oooooooooo`04oooo
o`Go00000_ooool00ol0003oooooo`000003o`0000Kooooo0_l0000/ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
02cooooo001Aooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0;?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0]ooooo`00DOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0;Oooool005;ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0=oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo02gooooo001Booooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0>Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0]ooooo`00D_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:oooo
o`;o0000;Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0^ooooo`00D_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0iooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0;_ooool005?ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
>_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02kooooo001Cooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0^ooooo`00Doooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0;oooool0
05?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool02oooool2o`0002oooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0looooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0;oooool005Co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02oo
oooo001Dooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0??ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0`ooooo`00E?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03kooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0<?ooool005Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool2o`00033ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0<Oooool005Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0ooooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo037ooooo001Fooooo`05o`000?ooooooooooooooool00000@oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo1?l000000ol@413oooooooooo`03oooo
o`03o`000?oooooooooo033ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`10oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0<_ooool005Kooooo0_l00002ooooo`03
o`000?oooooooooo047ooooo0_l00002ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0aooooo`04o`000?ooooooooooo`0004Cooooo00?o0000oooo
ooooool00_l0000dooooo`00Eoooool3o`0004Gooooo1?l00008ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0<Oooool4o`0004Cooooo1?l0000eooooo`00Zoooool00ol0003ooooo
ooooo`05ooooo`?o0000/_ooool00:_ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`2booooo`00Zoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;;ooooo002[oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/_ooool00:Wooooo00?oEEEEofIVI_l0
00001oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oo
oooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo
0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o
0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0
003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002Aooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2booooo`00Toooool00ol0003ooooooooo
o`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`000;;ooooo002Cooooo`03o`000?oooooo
oooo00cooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo0;;ooooo002Cooooo`03o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool00oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0/_ooool009?ooooo00?o0000ooooooooool02_ooool01Ol0003o^[ZjoooooonHV9So410@
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2booooo`00TOooool00omEEEGo
IVIVo`00000<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0002coooo
o`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`00
0;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0
/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0
003oooooooooo`2booooo`00VOooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2booooo`00Voooool00ol0003o
ooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;;o
oooo002Kooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2booooo`00Voooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0
002booooo`00Voooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`2booooo`00Voooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0/_ooool009_ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;;ooooo002Iooooo`03oeEEEOmVIVKo000000go
oooo1?l00006ooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o
0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0
003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002coooo
o`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0
/_ooool0097ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_ooool00ol0003ok^k^oooo
o`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2booooo`00Tooo
ool00ol0003oooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool03?ooool0
0onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002booooo`00Toooool00ol0
003oooooooooo`0=ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`0=ooooo`03oeEEEOo<c<cooooo00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03
o`000?oooooooooo00gooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00[ooooo00Go410@oooooooooooo
oooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_ooool0097ooooo
00?oEEEEofIVI_l000003?ooool5o`0000Cooooo1?l00006ooooo`;o0000/oooool00;?ooooo00?o
0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0
003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002coooo
o`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0
/_ooool00:Sooooo1Ol00006ooooo`03o`000?oooooooooo0;;ooooo002Xooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01_ooool00ol0003oooooooooo`2booooo`00ZOooool00onHV9So8B4Qonk^kP07
ooooo`03o`000?oooooooooo0;;ooooo002Zooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0002boooo
o`00Zoooool00omgMgOoIVIVooooo`2jooooo`00[?ooool00ol0003oooooooooo`2iooooo`00Z?oo
ool01Ol0003o^[ZjoooooonHV9So410@0;_ooooo002Xooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
^oooool00?ooooooJOooool00;7ooooo00?o0000okZj^_ooool0]?ooool00;7ooooo0_lb<S:eoooo
o`00P_ooool2o`000006oa0@4?oooooooooooa0@4?l0003o410@6?ooool4o`000005oa0@4?oooooo
oooooooooom4A4@00_l000001olb<S;ogMgMooooooooooooQhN7o`000?nj^[X03?ooool01OnHV9So
0000o`000?m4A4Co^[Zj01Sooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c004ooooo`05odA4A?l0003o
0000oc8b<_oMgMd0OOooool008?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07
ooooo`Ko00003?ooool00ol0003oooooooooo`06ooooo`07ogMgMolb<S;oooooooooooo<c<co0000
oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00Go8B4QoiRHV?oo
ooooV9RHob4Q8@07ooooo`03ogMgMolb<S;ooooo07cooooo0023ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool06_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooo
ooooool0Noooool008?ooooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00003?ooool0
0ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo013ooooo00?o0000ooooooooool02oooool6
o`0000Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P07ooooo`03ogMgMolb<S;ooooo07cooooo0023
ooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo00006oooool00ol0003oooooooooo`03ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`04Oooool00ol0003oooooooooo`0Jooooo`05olc<c?l0003o0000o`00
0?o<c<`01?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<07gooooo0023ooooo`06o`000?n7QhOoZJVY
okZj^_mEEEGo00006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o
410@o`000?l000000ol0000Iooooo`05oa0@4?nj^[[ooooookZj^_l@41001?ooool00ol0003ooooo
ooooo`1oooooo`00Poooool01_l0003o<S8boooooooooooo<S8bo`0001_ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01[ooooo00Go0000okZj^_oo
oooo^[Zjo`000004ooooo`03o`000?oooooooooo07oooooo0022ooooo`03oa0@4?l0003oQhN700;o
oooo00?oQhN7o`000?l@41006?ooool00omEEEGoIVIVo`000005ooooo`Co00004_ooool00ol0003o
ooooooooo`0Jooooo`05ojVYZOl@413o0000oa0@4?nYZJT01?ooool4o`0007kooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-44.3769, -0.160437, \
0.309031, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.01333 0 0.309017 [
[.1001 -0.0125 -9 -9 ]
[.1001 -0.0125 9 0 ]
[.2334 -0.0125 -9 -9 ]
[.2334 -0.0125 9 0 ]
[.3667 -0.0125 -9 -9 ]
[.3667 -0.0125 9 0 ]
[.6333 -0.0125 -6 -9 ]
[.6333 -0.0125 6 0 ]
[.7666 -0.0125 -6 -9 ]
[.7666 -0.0125 6 0 ]
[.8999 -0.0125 -6 -9 ]
[.8999 -0.0125 6 0 ]
[.4875 .07725 -24 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -18 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -24 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1001 0 m
.1001 .00625 L
s
[(-30)] .1001 -0.0125 0 1 Mshowa
.2334 0 m
.2334 .00625 L
s
[(-20)] .2334 -0.0125 0 1 Mshowa
.3667 0 m
.3667 .00625 L
s
[(-10)] .3667 -0.0125 0 1 Mshowa
.6333 0 m
.6333 .00625 L
s
[(10)] .6333 -0.0125 0 1 Mshowa
.7666 0 m
.7666 .00625 L
s
[(20)] .7666 -0.0125 0 1 Mshowa
.8999 0 m
.8999 .00625 L
s
[(30)] .8999 -0.0125 0 1 Mshowa
.125 Mabswid
.12676 0 m
.12676 .00375 L
s
.15342 0 m
.15342 .00375 L
s
.18008 0 m
.18008 .00375 L
s
.20674 0 m
.20674 .00375 L
s
.26006 0 m
.26006 .00375 L
s
.28672 0 m
.28672 .00375 L
s
.31338 0 m
.31338 .00375 L
s
.34004 0 m
.34004 .00375 L
s
.39336 0 m
.39336 .00375 L
s
.42002 0 m
.42002 .00375 L
s
.44668 0 m
.44668 .00375 L
s
.47334 0 m
.47334 .00375 L
s
.52666 0 m
.52666 .00375 L
s
.55332 0 m
.55332 .00375 L
s
.57998 0 m
.57998 .00375 L
s
.60664 0 m
.60664 .00375 L
s
.65996 0 m
.65996 .00375 L
s
.68662 0 m
.68662 .00375 L
s
.71328 0 m
.71328 .00375 L
s
.73994 0 m
.73994 .00375 L
s
.79326 0 m
.79326 .00375 L
s
.81992 0 m
.81992 .00375 L
s
.84658 0 m
.84658 .00375 L
s
.87324 0 m
.87324 .00375 L
s
.07344 0 m
.07344 .00375 L
s
.04678 0 m
.04678 .00375 L
s
.02012 0 m
.02012 .00375 L
s
.92656 0 m
.92656 .00375 L
s
.95322 0 m
.95322 .00375 L
s
.97988 0 m
.97988 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .07725 m
.50625 .07725 L
s
[(0.25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(0.75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(1)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(1.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(1.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(1.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(90) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .185 m
.03279 .14469 L
.04262 .10788 L
.04758 .09291 L
.05288 .07951 L
.06244 .06123 L
.06788 .05348 L
.07379 .04665 L
.07899 .04171 L
.08451 .03742 L
.08947 .03433 L
.09211 .033 L
.09494 .03181 L
.09754 .03095 L
.09992 .03037 L
.10106 .03016 L
.10231 .02998 L
.10349 .02986 L
.10458 .02979 L
.10587 .02977 L
.10651 .02978 L
.10722 .02981 L
.10848 .0299 L
.10966 .03004 L
.11104 .03026 L
.11231 .03052 L
.11515 .03131 L
.1176 .0322 L
.12026 .03339 L
.1251 .03611 L
.13477 .04363 L
.14371 .05343 L
.14834 .05996 L
.15334 .06846 L
.16237 .08877 L
.17312 .12302 L
.18298 .16402 L
.1929 .21084 L
.2035 .25871 L
.20865 .27793 L
.21118 .28587 L
.21351 .29216 L
.21559 .29686 L
.21787 .30099 L
.21898 .30258 L
.22017 .30398 L
.22142 .3051 L
.2226 .30583 L
.22383 .30625 L
.22514 .3063 L
Mistroke
.22637 .30599 L
.22749 .30539 L
.22881 .30432 L
.23023 .30272 L
.23282 .29866 L
.23527 .29347 L
.23787 .28668 L
.24251 .27154 L
.26071 .19065 L
.27094 .14445 L
.28061 .10821 L
.2893 .08349 L
.29873 .0642 L
.30366 .0566 L
.30889 .04993 L
.31828 .0407 L
.32342 .03685 L
.32824 .03396 L
.33081 .03271 L
.33352 .03162 L
.33494 .03115 L
.33649 .03071 L
.33791 .03038 L
.33921 .03014 L
.34045 .02997 L
.34175 .02984 L
.34307 .02978 L
.34381 .02977 L
.34451 .02978 L
.34577 .02983 L
.34692 .02994 L
.34756 .03001 L
.34825 .03011 L
.34951 .03034 L
.35186 .0309 L
.35436 .03171 L
.35886 .03365 L
.36399 .03663 L
.36882 .04014 L
.37407 .04478 L
.37982 .05097 L
.38964 .0652 L
.39499 .07562 L
.39998 .08747 L
.40892 .11472 L
.41848 .15248 L
.43837 .24499 L
.44381 .26744 L
.44959 .28677 L
.45196 .29303 L
Mistroke
.45452 .29849 L
.45598 .301 L
.45732 .30288 L
.45866 .30437 L
.45994 .30539 L
.46124 .30605 L
.46246 .30631 L
.46356 .30625 L
.46474 .30586 L
.46604 .30507 L
.46669 .30452 L
.4674 .30381 L
.46985 .3005 L
.47215 .2962 L
.47461 .29039 L
.47905 .27703 L
.48995 .23249 L
.49989 .1855 L
.50916 .14392 L
.51899 .10727 L
.52412 .09193 L
.52978 .07792 L
.53976 .05951 L
.54468 .05272 L
.54986 .04678 L
.55912 .03855 L
.56428 .03511 L
.56908 .03263 L
.57185 .03154 L
.57435 .03077 L
.57574 .03043 L
.57725 .03014 L
.57794 .03004 L
.57867 .02994 L
.57998 .02982 L
.58119 .02976 L
.58251 .02976 L
.58376 .02982 L
.58492 .02992 L
.58606 .03006 L
.5871 .03023 L
.58943 .03075 L
.59194 .03151 L
.59465 .03257 L
.59957 .03507 L
.60422 .0381 L
.60912 .04199 L
.61789 .05095 L
.6274 .06463 L
.63273 .07485 L
Mistroke
.63758 .08619 L
.64701 .11471 L
.65593 .1497 L
.6742 .23485 L
.67921 .25674 L
.68459 .27711 L
.6872 .28538 L
.68968 .29211 L
.69212 .29755 L
.69433 .30139 L
.69548 .30296 L
.69671 .30432 L
.69802 .30538 L
.69925 .30602 L
.7004 .30629 L
.70162 .30624 L
.70267 .30593 L
.70381 .30529 L
.70451 .30476 L
.70516 .30415 L
.70639 .30274 L
.70916 .29836 L
.71156 .29324 L
.71416 .28638 L
.72508 .24582 L
.73519 .19881 L
.74493 .15385 L
.75543 .11278 L
.76535 .08381 L
.77444 .06501 L
.78322 .05216 L
.79282 .04212 L
.79767 .03823 L
.80285 .03484 L
.80536 .03349 L
.80774 .0324 L
.80988 .03157 L
.81218 .03085 L
.81343 .03053 L
.81457 .03029 L
.81573 .03009 L
.81681 .02994 L
.81805 .02983 L
.81871 .02979 L
.81942 .02976 L
.82072 .02977 L
.8219 .02982 L
.82254 .02987 L
.82322 .02994 L
.82444 .0301 L
Mistroke
.82576 .03033 L
.8272 .03066 L
.82978 .03142 L
.83218 .03232 L
.83685 .03459 L
.84109 .03723 L
.85063 .04515 L
.85545 .05032 L
.86057 .05692 L
.86975 .07262 L
.87485 .08411 L
.87963 .09706 L
.89052 .13507 L
.90902 .21959 L
.91409 .24295 L
.91951 .26554 L
.92418 .28199 L
.92664 .28919 L
.92925 .29554 L
.93059 .29828 L
.93206 .30084 L
.93342 .30278 L
.93466 .30419 L
.93593 .30527 L
.93664 .3057 L
.9373 .30601 L
.93848 .3063 L
.93977 .30624 L
.94091 .30587 L
.94217 .30511 L
.94349 .30392 L
.94472 .30244 L
.94693 .29896 L
.94932 .29403 L
.95468 .2789 L
.96032 .2579 L
.97043 .21242 L
.97619 .185 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^@?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hLooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=_ooool0
03Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Oooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`12ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0=_ooool002oooooo1_l00006ooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41005?ooool6o`0000Gooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@01gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01oo
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03Cooooo000jooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000012ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`00>Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000007oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000@_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
7oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool00000=_ooool003[ooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@023ooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@03Kooooo000gooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0@_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL07?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Kooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Ko
oooo000gooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Ooo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0@?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Kooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo000Koooooooo0000<_l0000Looooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Pooooo`00>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo000jooooo`Co0000@oooool5o`0002gooooo00?o0000ooooooooool0
5?ooool5o`0004?ooooo1Ol0001Aooooo`00=oooool3o`0000Cooooo0ol0000mooooo`Co00001?oo
ool4o`0002Wooooo0_l0000Cooooo`?o00001?ooool2o`0003oooooo0ol00004ooooo`;o0000Cooo
ool003Kooooo00?o0000ooooooooool02?ooool2o`0003[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo0_l00009ooooo`;o0000>oooool2
o`0000Wooooo0ol0001<ooooo`00=?ooool2o`0000gooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03_ooool2o`00
00gooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
04[ooooo000cooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0=?ooool2o`0000oo
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04Wo
oooo000booooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo02?ooooo0_l0000=ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`0?ooooo`;o0000BOooool0037ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04Kooooo000`
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`16
ooooo`00<?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0AOooool002oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo04Gooooo000^ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
:oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01oooooo0_l0000:ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo04Cooooo000^ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`13ooooo`00;Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool05oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`13ooooo`00;?ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHooooool0003oMgMg00Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool0@_ooool002cooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01Sooooo00Go410@oooooooooooo
0000oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo04;ooooo000[ooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00;o0000
3Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00006ooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo047ooooo000[ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIV
ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo047ooooo000[ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0Jooooo`05oa0@4?ooooooooooooooool000003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`10ooooo`00:_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool06_ooool01_mgMgOoV9RHoooooonHV9SoMgMgo`0000[ooooo00Go0000okZj
^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`10ooooo`00:_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool06oooool01_o^k^ko<S8bo`000?lb<S;ok^k^o`0000[ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`0000Gooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
@?ooool002[ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo03oooooo000Yooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0oooooo`00:Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool0?oooool002Wooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo03kooooo000Xooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01[ooooo
0_l00004ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo03kooooo000Xooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0nooooo`00:?ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0?Oooool002Oooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03gooooo000Wooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0mooooo`00
9oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0Hooooo`;o00000oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0looooo`009_oo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool00000:Oooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0??ooool002Kooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000002Wooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03cooooo000Vooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo01Oooooo00Go0000ooooooooooooooooo`00000Yooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0kooooo`009_ooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0Gooooo`;o00000_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`0kooooo`009Oooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0G
ooooo`04o`000?ooooooooooo`0002[ooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo03_ooooo000Uooooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Oooooo00Co0000
oooooooooooo0000:oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool0>oooool002Gooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo02Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Ooo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00Co0000oooooooooooo0000:oooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0>_ooool002Gooooo
00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02Sooooo
00GoMgMgoiRHV?l0003oV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`04
o`000?ooooooooooo`0002_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0[oooo
o`03o`000?oooooooooo03[ooooo000Uooooo`03o`000?oooooooooo02[ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0Yooooo`05oa0@4?oooooo0000ooooool@41004?ooool00ol0
003oooooooooo`03ooooo`?o0000;?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool0>_ooool002Cooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo02Wooooo00Go0000ooooool0003oooooo`00000?oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooool00000;?ooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0>_ooool002Cooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool00_l0000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooo`00000]oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0joooo
o`009?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool0:Oooool01Ol@413oooooooooool0003o410@00cooooo00?o0000ooooooooool01oooool00ol0
003oooooo`00000]ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`0iooooo`009?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool0:Oooool01OmgMgOoV9RHooooool0003oMgMg00cooooo00?o0000oooo
ooooool01oooool2o`0002kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0]oooo
o`03o`000?oooooooooo03Wooooo000Tooooo`03o`000?oooooooooo02cooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0Zooooo`05onk^k_lb<S;o0000o`000?o^k^h03?ooool4o`00
00Kooooo0_l0000^ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`0iooooo`009?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Eooooo`;o0000;oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0>Oooool002?ooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool05?ooool2o`0002oooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo03Wooooo000Sooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0>?ooool002?ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool05?ooool2o`0002oooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool08_ooool005Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0_oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Roooo
o`00EOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool0;oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02;ooooo001Eooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Booooo`;o0000
<Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0Rooooo`00EOooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool04_ooool2o`00037ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool08_oo
ool005Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo01;ooooo0ol0000`ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02?ooooo001Eooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Booooo`;o0000<_ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Sooooo`00E_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool04_ooool2o`0003;ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool08oooool005Kooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo013ooooo
00?o0000ooooool00000<_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Sooooo`00E_ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04?ooool00ol0003oooooo`00
000booooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo02?ooooo001Fooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`0@ooooo`04o`000?oooooo0000o`0003;ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool08oooool005Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0c
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooool00000<oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0S
ooooo`00Eoooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02Gooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q0_ooool01_l0003ooooooooooooooooo0000onk^kPGooooo
00GoA4A4o`000?l0003o<S8bomgMg@03ooooo`03o`000?oooooo000003?ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool09?ooool005Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Uooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@?ooooo00Go0000ooooooooooooEEEEojVYZ@08oooo
o`05ogMgMolb<S;oooooooooool000000_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo02Cooooo001Gooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool09Oooool01Ol@
413ooooooooooooooooo410@00[ooooo00Go0000ooooooooooooZJVYoeEEE@09ooooo`04o`000?oo
ooooooooo`0000;ooooo0ol0000booooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02Cooooo001Gooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool09_ooool01Ol0003ooooooooooooooooo000000[ooooo
00Go0000ooooooooooooooooob4Q8@08ooooo`05ogMgMolb<S;oooooooooool000000_ooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo02Cooooo001Hooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool09_ooool01Ol0003ooooooooooooooooo000000[ooooo00Ko0000oooo
oooooooooooooeEEEOo<c<`4ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01?l0003ooooo
ooooool0000dooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo02Gooooo001Hooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool09_ooool01Ol@413ooooooooooooooooo410@00[ooooo00Ko0000oooooooo
ooooooooojVYZOmgMgL4ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000=?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0Uooooo`00F?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo02Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?oooooooooooooooolb<S80
1?ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000=?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Uooooo`00F?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000;ooooo00Co0000oooooooo
oooooooo0_l0000dooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo02Gooooo001Hooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0<ooooo`05o`000?oooooooooooooo
ool00000=Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0Uooooo`00FOooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo0000
03Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool09_ooool005Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo02Kooooo001Iooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Vooooo`00FOooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`02ooooo`;o0000=Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Vooooo`00F_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool09oooool005[ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Oooooo001Jooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Wooooo`00
Foooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
:?ooool005_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0looooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool00oooool2o`0003Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0:?oo
ool005_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo02Sooooo001Kooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0?_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Yooooo`00Foooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0:Oooool005cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool2o`0003Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0:_ooool005gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0gooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0?oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo02[ooooo001Mooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0@?ooool01?l0003oooooooooooooool4o`000003oa0@4?oooooooooo00?ooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo047ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Zooooo`00GOooool2o`0000;ooooo00?o0000
ooooooooool0@_ooool01_l0003oooooooooool0003oooooo`0000Oooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`02o`0004Cooooo00Co0000oooooooooooo0000;Oooool005kooooo
1?l00014ooooo`Co000000?oooooo`000?ooool01_ooool00ol0003oooooooooo`0iooooo`?o0000
AOooool3o`0002kooooo002[ooooo`03o`000?oooooooooo00Gooooo0ol0002booooo`00Zoooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;;ooooo002[ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0/_ooool00:_ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2booooo`00ZOooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo0;;ooooo
002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0
003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo
002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002coooo
o`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000
/oooool00;?ooooo00?o0000ooooooooool0/_ooool0097ooooo1?l000000ol@413oooooooooo`02
ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;;ooooo002C
ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03
ooooo`?o0000/_ooool009?ooooo00?o0000ooooooooool03?ooool00onHV9So8B4Qonk^kP07oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000oooooooo
ool03Oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0
003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2booooo`00Toooool00ol0003ooooo
ooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0;;ooooo002Aooooo`03oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c004ooooo`Co00001_ooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002coooo
o`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0
/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool0
0;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooo
ooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2b
ooooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002Iooooo`Co0000
00?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0;;ooooo002Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0/_ooool009_ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;;ooooo002Kooooo`03o`000?oooooo
oooo00kooooo00?oMgMgoc8b<_ooool01?ooool3o`000;;ooooo002Kooooo`03o`000?oooooooooo
00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;;ooooo002Koooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2boooo
o`00Voooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0/_ooool009Wooooo00?oEEEEofIVI_l000003Oooool4o`0000Kooooo00?o0000ooooooooool0
/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0
003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo
002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002coooo
o`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000
/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool0
0;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo
0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00TOooool4o`000003oa0@4?oooooo
oooo00;ooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgM
g@05ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00Cooooo0_lQ8B46
ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2b
ooooo`00Toooool00ol0003oooooooooo`0<ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000oooo
ooooool00oooool3o`000;;ooooo002Cooooo`03o`000?oooooooooo00gooooo00?o8B4Qoooooooo
ool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`00
0?oooooooooo00gooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool03Oooool00onYZJWoMgMg
ooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_ooool009?ooooo00?o
0000ooooooooool02_ooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`2booooo`00TOooool00omEEEGoIVIVo`00000<ooooo`Go00001?oo
ool4o`0000Kooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0
003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooo
ooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002coooo
o`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000
/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool0
0;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo
0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00Z?ooool5o`0000Kooooo00?o0000
ooooooooool0/_ooool00:Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooo
oooo0;;ooooo002Yooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/_ooool00:[o
oooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;;ooooo002[ooooo`03ogMgMomVIVKooooo0;[ooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002Xooooo`05o`000?nj^[[ooooooiRHV?l@4100^ooo
ool00:Sooooo00GoV9RHoa0@4?l0003o8B4Qolc<c02kooooo`00oooooomYooooo`00/Oooool00ol0
003o^[Zjooooo`2dooooo`00/Oooool2oc8b<[Gooooo0022ooooo`;o000000Ko410@oooooooooooo
410@o`000?l@410Hooooo`Co000000Go410@ooooooooooooooooodA4A002o`000007oc8b<_oMgMgo
oooooooooon7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool01?l@413o
0000odA4A?o<c<`4ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0O_ooool008?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00003?ooool00ol0003oooooooooo`06oooo
o`07ogMgMolb<S;oooooooooooo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@4100
2Oooool6o`0000_ooooo00?oV9RHoa0@4?oMgMd00oooool01OmgMgOoV9RHoooooonHV9SoMgMg07ko
oooo0023ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07Oooool00on7QhOoEEEE
ooooo`02ooooo`05oa0@4?ooooooooooooooool@4100O_ooool008?ooooo00Ko0000oooooom4A4Co
A4A4ooooool00009ooooo`Ko00003?ooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo
013ooooo00?o0000ooooooooool02oooool6o`0000Wooooo00Goc<c<ob4Q8Ol0003oEEEEo`000003
ooooo`05o`000?ooooooooooooooool00000O_ooool008?ooooo00Ko0000omgMgOlb<S;oEEEEomgM
gOl0000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Aooooo`03
o`000?oooooooooo01[ooooo00Go8B4QohN7QoooooooV9RHo`000003ooooo`05o`000?oooooooooo
ooooool00000O_ooool008?ooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Kooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool04Oooool00ol@413o0000o`000003o`0001Wooooo00Go
0000ooooooooooooooooo`000003ooooo`05oa0@4?ooooooooooooooool@4100O_ooool008?ooooo
00Ko0000oc8b<_oooooooooooc8b<_l0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0Jooooo`05ob4Q8OnHV9SoooooogMgMomEEED00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg07kooooo0022ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7
o`000?l@41006?ooool00omEEEGoIVIVo`000005ooooo`Co00004_ooool00ol0003oooooooooo`0J
ooooo`05olc<c?l@413o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07kooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-44.3769, -0.160437, \
0.309031, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.01333 0 0.309017 [
[.1001 -0.0125 -9 -9 ]
[.1001 -0.0125 9 0 ]
[.2334 -0.0125 -9 -9 ]
[.2334 -0.0125 9 0 ]
[.3667 -0.0125 -9 -9 ]
[.3667 -0.0125 9 0 ]
[.6333 -0.0125 -6 -9 ]
[.6333 -0.0125 6 0 ]
[.7666 -0.0125 -6 -9 ]
[.7666 -0.0125 6 0 ]
[.8999 -0.0125 -6 -9 ]
[.8999 -0.0125 6 0 ]
[.4875 .07725 -24 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -18 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -24 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1001 0 m
.1001 .00625 L
s
[(-30)] .1001 -0.0125 0 1 Mshowa
.2334 0 m
.2334 .00625 L
s
[(-20)] .2334 -0.0125 0 1 Mshowa
.3667 0 m
.3667 .00625 L
s
[(-10)] .3667 -0.0125 0 1 Mshowa
.6333 0 m
.6333 .00625 L
s
[(10)] .6333 -0.0125 0 1 Mshowa
.7666 0 m
.7666 .00625 L
s
[(20)] .7666 -0.0125 0 1 Mshowa
.8999 0 m
.8999 .00625 L
s
[(30)] .8999 -0.0125 0 1 Mshowa
.125 Mabswid
.12676 0 m
.12676 .00375 L
s
.15342 0 m
.15342 .00375 L
s
.18008 0 m
.18008 .00375 L
s
.20674 0 m
.20674 .00375 L
s
.26006 0 m
.26006 .00375 L
s
.28672 0 m
.28672 .00375 L
s
.31338 0 m
.31338 .00375 L
s
.34004 0 m
.34004 .00375 L
s
.39336 0 m
.39336 .00375 L
s
.42002 0 m
.42002 .00375 L
s
.44668 0 m
.44668 .00375 L
s
.47334 0 m
.47334 .00375 L
s
.52666 0 m
.52666 .00375 L
s
.55332 0 m
.55332 .00375 L
s
.57998 0 m
.57998 .00375 L
s
.60664 0 m
.60664 .00375 L
s
.65996 0 m
.65996 .00375 L
s
.68662 0 m
.68662 .00375 L
s
.71328 0 m
.71328 .00375 L
s
.73994 0 m
.73994 .00375 L
s
.79326 0 m
.79326 .00375 L
s
.81992 0 m
.81992 .00375 L
s
.84658 0 m
.84658 .00375 L
s
.87324 0 m
.87324 .00375 L
s
.07344 0 m
.07344 .00375 L
s
.04678 0 m
.04678 .00375 L
s
.02012 0 m
.02012 .00375 L
s
.92656 0 m
.92656 .00375 L
s
.95322 0 m
.95322 .00375 L
s
.97988 0 m
.97988 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .07725 m
.50625 .07725 L
s
[(0.25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(0.75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(1)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(1.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(1.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(1.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(95) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .28797 m
.04262 .2118 L
.06244 .1238 L
.07286 .09031 L
.08255 .06827 L
.08813 .05886 L
.0932 .05188 L
.09872 .04562 L
.10458 .04023 L
.10932 .03668 L
.11454 .03359 L
.11682 .03251 L
.11928 .03154 L
.1216 .03081 L
.12373 .03031 L
.12501 .03008 L
.12571 .02998 L
.12637 .0299 L
.12765 .0298 L
.12882 .02975 L
.1295 .02975 L
.13021 .02976 L
.13149 .02983 L
.1322 .0299 L
.13287 .02998 L
.13438 .03021 L
.13569 .03047 L
.13694 .03078 L
.13927 .03149 L
.14451 .03373 L
.1491 .03637 L
.15416 .03998 L
.1591 .04419 L
.16442 .04961 L
.16938 .05567 L
.17392 .06229 L
.18284 .07931 L
.18758 .09105 L
.19264 .106 L
.20176 .13943 L
.22246 .23473 L
.23271 .27658 L
.23551 .28553 L
.23848 .29346 L
.24102 .29883 L
.24245 .30126 L
.24381 .30314 L
.24506 .30451 L
.24573 .30508 L
.24643 .30559 L
Mistroke
.24768 .30619 L
.24883 .30643 L
.24953 .30642 L
.25029 .30628 L
.251 .30603 L
.25166 .30569 L
.2529 .30478 L
.25422 .30342 L
.25663 .29993 L
.25887 .29555 L
.26396 .28186 L
.26898 .26401 L
.27444 .24099 L
.28435 .19441 L
.30292 .11518 L
.31235 .08662 L
.31771 .07412 L
.32273 .06451 L
.33286 .04998 L
.33855 .04392 L
.34376 .03936 L
.34851 .03596 L
.35359 .03311 L
.35605 .03203 L
.35837 .03119 L
.36046 .0306 L
.36155 .03035 L
.36272 .03013 L
.36401 .02994 L
.36522 .02982 L
.36595 .02977 L
.36665 .02974 L
.36796 .02974 L
.36863 .02976 L
.36934 .0298 L
.37061 .02992 L
.37132 .03001 L
.37199 .03011 L
.3735 .0304 L
.37599 .03104 L
.37828 .03181 L
.38343 .03416 L
.38816 .03701 L
.39322 .04075 L
.40233 .04942 L
.4079 .05626 L
.41317 .06418 L
.41786 .07275 L
.42302 .08422 L
.43273 .11259 L
Mistroke
.44301 .15277 L
.46146 .23884 L
.46666 .26114 L
.4716 .27928 L
.47604 .29216 L
.47855 .29776 L
.48088 .30176 L
.48219 .30348 L
.48289 .30424 L
.48361 .30491 L
.48425 .3054 L
.48495 .30583 L
.48619 .30631 L
.48739 .30643 L
.48867 .30619 L
.48989 .3056 L
.49099 .30477 L
.49237 .30334 L
.49364 .30164 L
.49653 .29648 L
.49907 .29048 L
.50177 .28276 L
.51115 .24713 L
.52125 .20014 L
.53954 .12047 L
.54912 .0901 L
.55959 .06669 L
.56488 .05801 L
.57053 .05049 L
.5807 .04031 L
.58603 .03635 L
.59095 .03349 L
.59374 .03221 L
.59635 .03124 L
.59907 .03049 L
.60051 .03019 L
.60126 .03006 L
.60206 .02995 L
.60276 .02987 L
.6034 .02982 L
.60464 .02975 L
.60534 .02974 L
.6061 .02974 L
.60681 .02976 L
.60746 .0298 L
.60865 .02991 L
.60996 .03009 L
.61132 .03033 L
.61259 .03062 L
.61503 .03133 L
Mistroke
.61724 .03214 L
.62221 .03452 L
.62704 .03753 L
.63216 .04144 L
.64135 .05047 L
.65124 .06415 L
.65686 .07462 L
.66213 .08676 L
.67251 .11846 L
.68237 .1583 L
.70089 .24481 L
.70582 .26535 L
.71047 .28178 L
.71304 .28934 L
.71583 .29608 L
.71836 .30082 L
.71948 .30248 L
.72069 .30394 L
.72184 .30503 L
.72289 .30575 L
.72395 .30622 L
.72495 .30642 L
.72611 .30637 L
.72719 .30603 L
.72837 .30535 L
.72963 .30427 L
.73074 .30301 L
.73194 .30134 L
.73411 .29751 L
.73907 .28515 L
.74403 .2684 L
.74864 .24973 L
.7591 .2013 L
.76995 .15119 L
.7802 .11144 L
.79001 .08293 L
.79554 .07075 L
.80065 .06161 L
.80967 .04924 L
.81467 .04397 L
.81923 .03994 L
.82374 .0366 L
.82866 .03368 L
.83136 .03241 L
.83386 .03145 L
.83625 .03072 L
.83758 .0304 L
.8388 .03017 L
.83995 .02999 L
.84118 .02986 L
Mistroke
.8424 .02978 L
.8431 .02976 L
.84375 .02975 L
.84492 .02978 L
.846 .02985 L
.84723 .02998 L
.8484 .03016 L
.85057 .03061 L
.85258 .03116 L
.85711 .03291 L
.86175 .03535 L
.86675 .03868 L
.8758 .04653 L
.88104 .05234 L
.88656 .05977 L
.89172 .06831 L
.89641 .07773 L
.90598 .103 L
.91619 .13998 L
.93456 .22457 L
.9439 .26526 L
.949 .28315 L
.95378 .29576 L
.95626 .30052 L
.95766 .30259 L
.95894 .30411 L
.96033 .30533 L
.96112 .30583 L
.96185 .30616 L
.96248 .30635 L
.96318 .30644 L
.96392 .30642 L
.96461 .30628 L
.96582 .30577 L
.96711 .30485 L
.9682 .30377 L
.96941 .30227 L
.97209 .29777 L
.97458 .29221 L
.97619 .28797 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^@?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hLooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=_ooool0
03Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Oooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`12ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0=_ooool002oooooo1_l00006ooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41005?ooool6o`0000Gooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@01gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01oo
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03Cooooo000jooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000012ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`00>Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000007oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000@_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
7oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool00000=_ooool003[ooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@023ooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@03Kooooo000gooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0@_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL07?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Kooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Ko
oooo000gooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Ooo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0@?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Kooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo000Koooooooo0000<_l0000Looooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Pooooo`00>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo0011ooooo`Co0000A?ooool5o`0002Gooooo00?o0000ooooooooool0
6oooool5o`0004?ooooo1Ol0001:ooooo`00?Oooool4o`0000Cooooo1?l0000mooooo`?o00001?oo
ool3o`0002?ooooo0_l0000Iooooo`?o00001Oooool2o`0003kooooo0ol00005ooooo`?o0000Aooo
ool003cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo00Sooooo0_l0000Qooooo`03o`000?oooooooooo01Kooooo0_l0000:ooooo`;o0000>oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo04Cooooo000kooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0=_ooool2o`0000gooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0;ooooo`;o0000A?ooool003[ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0dooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo00kooooo0_l0000fooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0@Oooool003Wooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0booooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool07?ooool2o`0001Cooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0@?ooool003Wooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo03oooooo000hooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0nooooo`00=oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0?_ooool003Kooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo03gooooo000fooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo01Sooooo0_l0000Aooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
:oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03gooooo000eooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0looooo`00=?ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool04?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00?o0000ob4Q8OlQ8B401?ooool5o`0000Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
>oooool003Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?lQ8B7ooooo00?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0kooooo`00<oooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00Go
oooo00?o0000ooooooooool01?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0jooooo`00<oooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04Oooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool01?ooool00onHV9So8B4Qonk^kP07ooooo`03
ogMgMolb<S;ooooo00Cooooo0ol0000>ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo03[ooooo000booooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Booooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`05ooooo`03ogMgMomVIVKooooo00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool0>_ooool003;ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo01?ooooo00Go410@oooooooooooooooooa0@4007ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool0>Oooool003;ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo01?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07oooo
o`09o`000?ooooooooooooooool0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03Wooooo000aooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Dooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02?ooool02?l0003ooooooooooonHV9So410@o`000?lQ8B7oc<c<1?ooool4
o`0000Kooooo0_l0000=ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03Sooooo000aooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0hooooo`00<Oooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0>?ooool0033ooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03Oooooo
000`ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`0gooooo`00<?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`0Booooo`;o00002oooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0g
ooooo`00;oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool0=_ooool002oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo03Kooooo000_ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0fooooo`00;_ooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0=_ooool002kooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool04?ooool2
o`0000[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool0=Oooool002kooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo03Gooooo000^ooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0eooooo`00;Oooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=Oooool002gooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool03oooool2o`0000Wooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=?ooool002gooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Cooooo000]oooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0doooo
o`00;?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool08?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00?o0000ob4Q8OlQ8B401Oooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0d
ooooo`00;?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool08?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ob4Q8Oooool01oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0<oooool0
02cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
023ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool00oooool3o`0000Oooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0<oooool002cooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo027ooooo00Go0000oooo
ooooooooooooo`000005ooooo`03o`000?oooooooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo000/ooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Qooooo`05o`000?oooooooooo
ooooool000001Oooool00ol0003oooooooooo`04ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03?ooooo000[ooooo`03o`000?oooooo
oooo02gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Qooooo`05oa0@4?oooooo
ooooooooool@41001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`0booooo`00:oooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool08Oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo02cooooo00?o0000ooooooooool0<_ooool002_ooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo027ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP06ooooo`03o`000?oooooooooo00?ooooo1?l00006ooooo`;o00001_ooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`0booooo`00:oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool0<_ooool002[ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo037ooooo000Zooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`0aooooo`00:_ooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0<ooooo`;o0000
1Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`0aooooo`00:_ooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool0<Oooool002Wooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo037ooooo000Yooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0`ooooo`00:Oooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0<?ooool002Wooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool02oooool2o`0000Cooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0<?ooool002Wooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo033ooooo000X
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0_
ooooo`00:?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03;ooooo00?o0000oooo
ooooool0;oooool002Sooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo02oooooo000Xooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00[ooooo0_l00003ooooo`03o`00
0?oooooooooo03?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0booooo`03o`00
0?oooooooooo02oooooo000Wooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`0^ooooo`009oooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool07Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B46ooooo`05o`000?o^k^koooooooooool000000_ooool01Om4A4Co0000o`000?lb<S;ogMgM00Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0^ooooo`009oooool00ol0003ooooo
ooooo`0dooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07Oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`05oeEEEOnYZJWoooooooooool000001Oooool00omg
MgOo<S8booooo`04ooooo`05o`000?ooooooooooooooool00000=oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0;_ooool002Oooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01gooooo00Go410@oooo
oooooooooooooa0@400=ooooo`05ojVYZOmEEEGoooooooooool000001_ooool00ol0003ooooooooo
o`03ooooo`?o000000?oooooo`000?ooool0=_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool0;_ooool002Oooooo00?o0000ooooooooool0=Oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01gooooo00Go0000ooooooooooooooooo`00
000>ooooo`05ob4Q8Oooooooooooooooool000001?ooool00omgMgOo<S8booooo`04ooooo`05o`00
0?ooooooooooooooool00000=oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool0;Oooool002Kooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo01kooooo00Go0000ooooooooooooooooo`00000>ooooo`0;
oeEEEOo<c<coooooooooool0003oooooo`000?lQ8B7o0000oc8b<_o<c<`01Oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0fooooo`03
o`000?oooooooooo02gooooo000Vooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0Nooooo`05oa0@4?ooooooooooooooool@41003_ooool01onYZJWo
MgMgoooooooooooo0000ooooool000002Oooool01Ol0003ooooooooooooooooo000003Sooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02gooooo000V
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0N
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00;ooooo
00?o0000ooooool000002Oooool01?l0003oooooooooool0000iooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0]ooooo`009_ooool00ol0003ooooo
ooooo`0gooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool07_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo1Ol00003ooooo`Go00001_ooool2o`000003ooooool0003ooooo03So
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02co
oooo000Vooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0gooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo0000>Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0;?ooool002Gooooo
00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool02?ooool01?l0003oooooooooool0000iooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0/ooooo`009Oooool00ol0003ooooo
ooooo`0iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>?ooool00ol0003ooooo
ooooo`07ooooo`04o`000?ooooooooooo`0003[ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo02cooooo000Uooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooool00000>oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool0;?ooool002Gooooo00?o0000ooooooooool0>Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool01oooool3o`0003_ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02_ooooo000U
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool00000>oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0:oooool002Cooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool01oooool00ol0003oooooo`00000kooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`0[ooooo`009?ooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooo000003cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0jooooo`03
o`000?oooooooooo02_ooooo000Tooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Kooooo0_l0000mooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Zooooo`009?oo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0??oo
ool00ol0003oooooooooo`06ooooo`;o0000?Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo03cooooo00?o0000ooooooooool0:_ooool002Cooooo00?o0000ooooooooool0??ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool01_ooool2
o`0003kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0looooo`03o`000?oooooo
oooo02[ooooo000Sooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0mooooo`03o`000?oooooooooo00Gooooo0_l0000nooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Zooooo`008oooool00ol0003o
ooooooooo`0mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0?Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0mooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool08_ooool006Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Cooooo
0_l0000oooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo02;ooooo001Tooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0?oooool00ol0003oooooooooo`03ooooo`;o0000@?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Rooooo`00I?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03gooooo1?l00000
0ol@413oooooooooo`02ooooo`;o0000@Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo043ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Sooooo`00IOooool01?l0
003oooooooooool00012ooooo`04o`000?oooooo0000o`0000;ooooo00?o0000ooooool00000@_oo
ool01?l0003oooooooooool00014ooooo`04o`000?ooooooooooo`0002Kooooo001Vooooo`?o0000
@_ooool00ol0003oooooooooo`03o`0000;ooooo00?o0000ooooooooool0@?ooool3o`0004Kooooo
0ol0000Vooooo`00Zoooool00ol0003oooooooooo`05ooooo`?o0000/_ooool00:_ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2booooo`00Zoooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0;;ooooo002[ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0/_ooool00:Wooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2booooo`00/ooo
ool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo
0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o
0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0
003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo
002cooooo`03o`000?oooooooooo0;;ooooo002Aooooo`Co000000?o410@ooooooooool00_ooool2
ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooooooo
o`2booooo`00Toooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2booooo`00Toooool0
0ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3
o`000;;ooooo002Cooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h01oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00go
oooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0/_ooool009?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool0
2_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2booooo`00TOooool00omEEEGoIVIVo`00000<ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`01?ooool4o`0000Kooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0
003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002coooo
o`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0
/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool0
0;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00VOooool4o`000003oa0@
4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`2booooo`00Voooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo0;;ooooo002Kooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`2booooo`00Voooool00ol0003oooooooooo`0>
ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002booooo`00Voooool00ol0003oooooooooo`0;oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2booooo`00Voooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_ooool009_o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;;o
oooo002Iooooo`03oeEEEOmVIVKo000000gooooo1?l00006ooooo`03o`000?oooooooooo0;;ooooo
002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0
003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo
002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002coooo
o`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000
/oooool00;?ooooo00?o0000ooooooooool0/_ooool0097ooooo1?l000000ol@413oooooooooo`02
ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`04ooooo`;o8B4Q1_ooool0
0omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/_ooool0
09?ooooo00?o0000ooooooooool03?ooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo
00?ooooo0ol0002booooo`00Toooool00ol0003oooooooooo`0=ooooo`03ob4Q8Ooooooooooo00Ko
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2booooo`00Toooool00ol0003ooooo
ooooo`0=ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00gooooo00?oZJVYogMgMoooool0
0oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oo
oooooooo00[ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0/_ooool0097ooooo00?oEEEEofIVI_l000003?ooool5o`0000Cooooo1?l0
0006ooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0
/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0
003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo
002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002coooo
o`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000
/oooool00;?ooooo00?o0000ooooooooool0/_ooool00:Sooooo1Ol00006ooooo`03o`000?oooooo
oooo0;;ooooo002Xooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`2b
ooooo`00ZOooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0;;ooooo002Zooooo`03
oiRHV?lQ8B7ok^k^00Kooooo0ol0002booooo`00Zoooool00omgMgOoIVIVooooo`2jooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00Z?ooool01Ol0003o^[ZjoooooonHV9So410@0;_ooooo002X
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0^oooool00?ooooooJOooool00;7ooooo00?o0000okZj
^_ooool0]?ooool00;7ooooo0_lb<S:eooooo`00P_ooool2o`000006oa0@4?oooooooooooa0@4?l0
003o410@6?ooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000001olb<S;ogMgMoooooooo
ooooQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo00Co410@o`000?m4
A4Coc<c<1Oooool01Om4A4Co0000o`000?lb<S;ogMgM07gooooo0023ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01oooool6o`0000cooooo00?o0000ooooooooool01_ooool01omg
MgOo<S8booooooooooooc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo
1_l0000;ooooo`03oiRHV?l@413ogMgM00Oooooo00?oMgMgoc8b<_ooool0O?ooool008?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Mooooo`03ohN7QomEEEGooooo00Oooooo00?o
0000ooooooooool0Noooool008?ooooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko0000
3?ooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo013ooooo00?o0000ooooooooool0
2oooool6o`0000Wooooo00Goc<c<ob4Q8Ol0003oEEEEo`000007ooooo`03ogMgMolb<S;ooooo07co
oooo0023ooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo00006oooool00ol0003oooooooooo`03oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`04Oooool00ol0003oooooooooo`0Jooooo`05ob4Q8On7QhOo
oooooiRHV?l000001?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<07gooooo0023ooooo`06o`000?n7
QhOoZJVYokZj^_mEEEGo00006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017o
oooo00?o410@o`000?l000000ol0000Iooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`1oooooo`00Poooool01_l0003o<S8boooooooooooo<S8bo`0001_ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01[ooooo00Go8B4Q
oiRHV?ooooooMgMgoeEEE@04ooooo`03o`000?oooooooooo07oooooo0022ooooo`03oa0@4?l0003o
QhN700;ooooo00?oQhN7o`000?l@41006?ooool00omEEEGoIVIVo`000005ooooo`Co00004_ooool0
0ol0003oooooooooo`0Jooooo`05olc<c?l@413o0000oc8b<_o^k^h01?ooool4o`0007kooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-44.3769, -0.160437, \
0.309031, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.01333 0 0.309017 [
[.1001 -0.0125 -9 -9 ]
[.1001 -0.0125 9 0 ]
[.2334 -0.0125 -9 -9 ]
[.2334 -0.0125 9 0 ]
[.3667 -0.0125 -9 -9 ]
[.3667 -0.0125 9 0 ]
[.6333 -0.0125 -6 -9 ]
[.6333 -0.0125 6 0 ]
[.7666 -0.0125 -6 -9 ]
[.7666 -0.0125 6 0 ]
[.8999 -0.0125 -6 -9 ]
[.8999 -0.0125 6 0 ]
[.4875 .07725 -24 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -18 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -24 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1001 0 m
.1001 .00625 L
s
[(-30)] .1001 -0.0125 0 1 Mshowa
.2334 0 m
.2334 .00625 L
s
[(-20)] .2334 -0.0125 0 1 Mshowa
.3667 0 m
.3667 .00625 L
s
[(-10)] .3667 -0.0125 0 1 Mshowa
.6333 0 m
.6333 .00625 L
s
[(10)] .6333 -0.0125 0 1 Mshowa
.7666 0 m
.7666 .00625 L
s
[(20)] .7666 -0.0125 0 1 Mshowa
.8999 0 m
.8999 .00625 L
s
[(30)] .8999 -0.0125 0 1 Mshowa
.125 Mabswid
.12676 0 m
.12676 .00375 L
s
.15342 0 m
.15342 .00375 L
s
.18008 0 m
.18008 .00375 L
s
.20674 0 m
.20674 .00375 L
s
.26006 0 m
.26006 .00375 L
s
.28672 0 m
.28672 .00375 L
s
.31338 0 m
.31338 .00375 L
s
.34004 0 m
.34004 .00375 L
s
.39336 0 m
.39336 .00375 L
s
.42002 0 m
.42002 .00375 L
s
.44668 0 m
.44668 .00375 L
s
.47334 0 m
.47334 .00375 L
s
.52666 0 m
.52666 .00375 L
s
.55332 0 m
.55332 .00375 L
s
.57998 0 m
.57998 .00375 L
s
.60664 0 m
.60664 .00375 L
s
.65996 0 m
.65996 .00375 L
s
.68662 0 m
.68662 .00375 L
s
.71328 0 m
.71328 .00375 L
s
.73994 0 m
.73994 .00375 L
s
.79326 0 m
.79326 .00375 L
s
.81992 0 m
.81992 .00375 L
s
.84658 0 m
.84658 .00375 L
s
.87324 0 m
.87324 .00375 L
s
.07344 0 m
.07344 .00375 L
s
.04678 0 m
.04678 .00375 L
s
.02012 0 m
.02012 .00375 L
s
.92656 0 m
.92656 .00375 L
s
.95322 0 m
.95322 .00375 L
s
.97988 0 m
.97988 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .07725 m
.50625 .07725 L
s
[(0.25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(0.75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(1)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(1.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(1.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(1.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .29151 m
.02605 .29682 L
.02846 .30132 L
.02962 .30304 L
.03072 .30439 L
.03171 .30536 L
.03279 .30615 L
.03397 .30672 L
.03527 .30695 L
.03592 .30692 L
.03663 .30677 L
.0379 .30621 L
.03916 .30527 L
.04036 .30404 L
.04262 .30083 L
.045 .29623 L
.04753 .29003 L
.0521 .27584 L
.06244 .23296 L
.07287 .18338 L
.08414 .1337 L
.09479 .09695 L
.09985 .08341 L
.10458 .07287 L
.11422 .05651 L
.11933 .04998 L
.1248 .04419 L
.13054 .03923 L
.13597 .03548 L
.14085 .0329 L
.14361 .0318 L
.14616 .031 L
.14734 .03071 L
.14858 .03046 L
.14964 .03029 L
.15079 .03015 L
.15205 .03005 L
.15275 .03002 L
.15338 .03001 L
.15462 .03003 L
.15579 .0301 L
.15688 .03021 L
.15805 .03038 L
.16013 .03079 L
.16236 .03139 L
.16483 .03225 L
.16996 .03465 L
.17547 .03806 L
.18543 .04632 L
.19556 .05816 L
Mistroke
.20129 .06716 L
.2066 .07758 L
.21634 .10324 L
.2267 .14111 L
.24672 .23408 L
.2522 .25824 L
.25799 .27992 L
.26293 .29405 L
.26573 .29991 L
.26708 .30214 L
.26834 .30383 L
.26955 .30512 L
.27084 .30612 L
.27213 .30673 L
.27286 .3069 L
.27355 .30694 L
.27479 .30674 L
.27592 .30624 L
.27717 .30533 L
.27848 .304 L
.28077 .30072 L
.28289 .29665 L
.28771 .28399 L
.29298 .26553 L
.29775 .24559 L
.30846 .19532 L
.31859 .14878 L
.3293 .10804 L
.33845 .08219 L
.34364 .07093 L
.34849 .06227 L
.35821 .04908 L
.36707 .04049 L
.37197 .03683 L
.37731 .0337 L
.37975 .03257 L
.38235 .03159 L
.38456 .03093 L
.38583 .03063 L
.38701 .03041 L
.38814 .03024 L
.38935 .03011 L
.39004 .03006 L
.3907 .03003 L
.39192 .03001 L
.39321 .03005 L
.3944 .03014 L
.3957 .0303 L
.39709 .03053 L
.39936 .03106 L
Mistroke
.40149 .03172 L
.40633 .03374 L
.41158 .03672 L
.41638 .04011 L
.42161 .04451 L
.42718 .05012 L
.43235 .0564 L
.43704 .06324 L
.44618 .08092 L
.45131 .094 L
.45686 .11111 L
.46691 .15005 L
.48647 .24166 L
.49183 .26446 L
.49757 .28468 L
.50036 .29244 L
.50299 .29837 L
.50536 .30242 L
.5067 .30415 L
.50793 .30539 L
.50911 .30624 L
.5102 .30673 L
.51138 .30695 L
.51263 .30682 L
.51373 .3064 L
.51474 .30576 L
.51585 .30478 L
.51704 .30342 L
.51975 .29913 L
.52231 .29363 L
.52709 .27988 L
.53686 .24105 L
.54744 .19108 L
.55772 .1444 L
.56733 .10827 L
.57736 .08028 L
.58267 .06912 L
.58838 .05945 L
.59852 .04665 L
.60426 .04124 L
.60957 .03717 L
.61468 .03408 L
.61931 .032 L
.62188 .03116 L
.62323 .03081 L
.62465 .03051 L
.6259 .0303 L
.62656 .03022 L
.62727 .03014 L
.62852 .03006 L
Mistroke
.62968 .03003 L
.6309 .03005 L
.6316 .03009 L
.63225 .03014 L
.63357 .03028 L
.63431 .03039 L
.63498 .03051 L
.6375 .03108 L
.63989 .03183 L
.64519 .03412 L
.65097 .03757 L
.66141 .0461 L
.67111 .05728 L
.67618 .06495 L
.68167 .07521 L
.69162 .10047 L
.70131 .13463 L
.71023 .17362 L
.72008 .22075 L
.7255 .24582 L
.73064 .26722 L
.73541 .28389 L
.73793 .2911 L
.74061 .2974 L
.74285 .30151 L
.74405 .30324 L
.74533 .30474 L
.74651 .30578 L
.74759 .30645 L
.74862 .30683 L
.7497 .30696 L
.75092 .30677 L
.75208 .30627 L
.75312 .30556 L
.75424 .30449 L
.75547 .30301 L
.75676 .30106 L
.75909 .29664 L
.76325 .28597 L
.76783 .27062 L
.78766 .18098 L
.79763 .1369 L
.8071 .10292 L
.81232 .088 L
.81801 .07463 L
.82799 .05723 L
.83331 .05031 L
.83833 .04491 L
.84769 .03713 L
.85295 .03397 L
Mistroke
.85778 .03185 L
.8603 .03105 L
.86176 .0307 L
.86308 .03044 L
.86448 .03023 L
.86525 .03015 L
.86597 .03009 L
.86727 .03004 L
.868 .03003 L
.86867 .03004 L
.86986 .0301 L
.8711 .03022 L
.87216 .03036 L
.87332 .03057 L
.87591 .03119 L
.87832 .03196 L
.8827 .03385 L
.88737 .03647 L
.89293 .04038 L
.89817 .04484 L
.90285 .04952 L
.90798 .05563 L
.91772 .07111 L
.92305 .08249 L
.92802 .09548 L
.93693 .125 L
.94649 .16515 L
.97619 .29151 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^@?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hLooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=_ooool0
03Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Oooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`12ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0=_ooool002oooooo1_l00006ooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41005?ooool6o`0000Gooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@01gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01oo
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03Cooooo000jooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000012ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`00>Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000007oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000@_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
7oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool00000=_ooool003[ooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@023ooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@03Kooooo000gooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0@_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL07?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Kooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Ko
oooo000gooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Ooo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0@?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Kooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo000Koooooooo0000<_l0000Looooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Pooooo`00>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo0018ooooo`Co0000A?ooool5o`0001kooooo00?o0000ooooooooool0
8oooool4o`0004Cooooo1?l00013ooooo`00A_ooool3o`0000?ooooo0ol0000nooooo`Co00000ooo
ool4o`0001_ooooo0_l0000Rooooo`;o00001?ooool2o`0003oooooo0ol00004ooooo`Co0000?ooo
ool004Cooooo0_l00009ooooo`;o0000>oooool00ol0003oooooooooo`09ooooo`;o00006Oooool0
0ol0003oooooooooo`0Nooooo`?o00002?ooool2o`0003cooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0looooo`00@oooool00ol0003oooooooooo`0;ooooo`;o0000>?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`0:ooooo`;o0000>Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
03_ooooo0012ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool07?ooool2o`0000oo
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03[o
oooo0010ooooo`;o00004_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00oooooo
0_l0000Fooooo`;o00007?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03;ooooo
0_l0000Aooooo`03o`000?oooooooooo03Wooooo000oooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0hooooo`00?oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0=oooool003kooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03Kooooo000nooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0fooooo`00
?Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0@ooooo`;o00006Oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo02gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0eooooo`00??oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0=?oo
ool003cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo00Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
=?ooool003_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo00Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So0000
onk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo03?ooooo000kooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`09ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
0000onk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0cooooo`00>_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ob4Q8Oo^
k^h01oooool00omgMgOo<S8booooo`04ooooo`?o00005Oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0booooo`00
>_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
2oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ofIVI_ooool00oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0boooo
o`00>_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool02oooool01Ol@413ooooooooooooooooo410@00kooooo0_l00004ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0booooo`00>Oooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool03?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo0000oa0@4004ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0aooooo`00>Oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool03?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qo`000004ooooo`Co00001_oo
ool2o`0001Cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool0<Oooool003Wooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo033ooooo000hooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0`ooooo`00>?ooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0;oooool003Sooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02oooooo
000gooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo00_ooooo0_l0000Booooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02oooooo000g
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0^
ooooo`00=oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0;_ooool003Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo02kooooo000fooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`0]ooooo`00=_ooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`09ooooo`;o00004Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0]ooooo`00=_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool0;Oooool003Gooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo02gooooo000eooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0]ooooo`00=Oooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`08ooooo`;o00004?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0/ooooo`00=Oooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0;?ooool003Cooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02cooooo000doooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo0ol000000olb<S;ogMgMooooo`04
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0;?ooool003Cooooo00?o0000oooo
ooooool0:_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1Oooool01Ol0003ooooooooooomgMgOo<S8b00Gooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`0/ooooo`00=?ooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool01Ol@413ooooooooooooo
oooo410@00cooooo00Go0000ooooooooooooooooo`000005ooooo`?o00003_ooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0:_ooool00ol0003ooooo
ooooo`0/ooooo`00<oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool06_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000oooooooooooo
MgMgoc8b<P05ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0:oooool003?ooooo
00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01[ooooo
00Go0000ooooooooooooooooo`00000<ooooo`?o000000?o<S8bolc<c?ooool01?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo02_ooooo000cooooo`03o`000?oooooooooo02_ooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0Jooooo`05oa0@4?ooooooooooooooool@
41003?ooool2o`0000Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0[ooooo`00
<_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
6_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo0_l00008ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02co
oooo00?o0000ooooooooool0:oooool003;ooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo01[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co
00001_ooool2o`0000kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool0:oooool003;ooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02[ooooo000booooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Zooooo`00<Oooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0:_ooool0
037ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool01Oooool2o`0000gooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0:_ooool0037o
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02Wo
oooo000aooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0<?ooool00ol0003ooooo
ooooo`0Yooooo`00<?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool0:Oooool0033ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo02Wooooo000`ooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Cooooo0_l0000;oooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo02Wooooo000`ooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`0Xooooo`00<?ooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo03;ooooo00?o0000ooooooooool0:?ooool002oooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0booooo`03o`000?oooooooooo02Sooooo000_ooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Xooooo`00;oooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`03ooooo`;o00002_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Wooooo`00;oooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool09oooool002oooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`06
odA4A?l0003o0000oc8b<_oMgMgo00001?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo02Oooooo000^ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Fooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEE
ojVYZOooool01oooool00omgMgOo<S8bo`000004ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Cooooo00?o0000
ooooooooool09oooool002kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo01Kooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGo
oooo00Sooooo0_l00004ooooo`?o00002Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Vooooo`00;_ooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool05_ooool01Ol0
003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8bo`000004
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool09_ooool002kooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Kooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Oo0000ob4Q8Ol0003o<S8bolc<
c?oooooo000000?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Vooooo`00;_oo
ool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05ooo
ool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003ooooo
ooooo`03ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003oooooooooo`0fooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Vooooo`00
;Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
5oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04oooo
o`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo02Kooooo000]ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0Gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00002
ooooo`04o`000?ooooooooooooooo`;o00002Oooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Uooooo`00;Oooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0=oooool0
1?l0003oooooooooool00009ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Gooooo000]ooooo`03o`000?oooooo
oooo03Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0hooooo`04o`000?oooooo
ooooo`0000Wooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo03Sooooo00?o0000ooooooooool09Oooool002cooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Sooooo00Co0000oooooooooooo00002Ooo
ool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>?oo
ool00ol0003oooooooooo`0Uooooo`00;?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0>Oooool00ol0003oooooo`000009ooooo`03o`000?oooooo
oooo03Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo02Cooooo000/ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0jooooo`04o`000?oooooo0000o`0000Oooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool09?ooool0
02cooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
03[ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Tooooo`00;?ooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0>_ooool00ol0003o
ooooo`000008ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo02Cooooo000[ooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooo000000Sooooo
00?o0000ooooooooool0>_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool08oooool002_ooooo00?o0000ooooooooool0??ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo03cooooo0_l00007ooooo`03o`000?oooooooooo03cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02?ooooo000[
ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0l
ooooo`?o00001_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0??ooool00ol0003oooooooooo`0Sooooo`00:oooool00ol0003oooooooooo`0loooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0??ooool2o`0000Oooooo00?o0000oooo
ooooool0??ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03cooooo00?o0000oooo
ooooool08oooool002[ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo03cooooo0_l00007ooooo`03o`000?oooooooooo03cooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo02?ooooo000Zooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0mooooo`;o0000
1_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
?Oooool00ol0003oooooooooo`0Rooooo`008oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo03kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0nooooo`;o00001Ooo
ool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`0Rooooo`008oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo03oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0oooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo06?ooooo000Sooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0@Oooool01Ol0
003ooooooooooooooooo000003Sooooo1?l000000ol@413oooooooooo`03ooooo`;o00001?ooool0
0ol0003oooooooooo`10ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Hoooool0
02Cooooo00Go0000ooooooooooooooooo`000013ooooo`;o00000_ooool00ol0003oooooooooo`0h
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`12
ooooo`05o`000?ooooooooooooooool00000I_ooool002Gooooo0ol00015ooooo`?o0000>oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooo000000?o0000A?ooool4o`0006Oooooo002[oooo
o`03o`000?oooooooooo00Gooooo0ol0002booooo`00Zoooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0;;ooooo002[ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
/_ooool00:_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2booooo`00ZOooool0
0omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?o
oooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o
0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2boooo
o`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo
0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000oooo
ooooool0/_ooool0097ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool5o`0000Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03
o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00_o
oooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000/_ooool009?ooooo
00?o0000ooooooooool03?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool03Oooool00omgMgOoIVIVoooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2booooo`00Tooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[o
oooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;;ooooo002A
ooooo`03oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_oo
ool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo
0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0
003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo
002cooooo`03o`000?oooooooooo0;;ooooo002Iooooo`Co000000?o410@ooooooooool00_ooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;;ooooo002K
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool0/_ooool009_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo0;;ooooo002Kooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_oo
ool01?ooool3o`000;;ooooo002Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo0;;ooooo002Kooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`2booooo`00Voooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_ooool009Wooooo00?oEEEE
ofIVI_l000003Oooool4o`0000Kooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002coooo
o`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo
0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0
/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0
003oooooooooo`2booooo`00TOooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B46ooooo`03
o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
0;;ooooo002Cooooo`03o`000?oooooooooo00Cooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oo
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2booooo`00Toooool00ol0003ooooo
ooooo`0<ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000;;ooooo
002Cooooo`03o`000?oooooooooo00gooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00gooooo00?oEEEE
olc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/_oo
ool009?ooooo00?o0000ooooooooool03Oooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool02_ooool01Ol@
413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2b
ooooo`00TOooool00omEEEGoIVIVo`00000<ooooo`Go00001?ooool4o`0000Kooooo0_l0002coooo
o`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`00
0;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0
/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0
003oooooooooo`2booooo`00Z?ooool5o`0000Kooooo00?o0000ooooooooool0/_ooool00:Sooooo
00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0;;ooooo002Yooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/_ooool00:[ooooo00?oV9RHob4Q8Oo^k^h01_oo
ool3o`000;;ooooo002[ooooo`03ogMgMomVIVKooooo0;[ooooo002/ooooo`03o`000?oooooooooo
0;Wooooo002Xooooo`05o`000?nj^[[ooooooiRHV?l@4100^oooool00:Sooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c02kooooo`00oooooomYooooo`00[_ooool00ol0003o^[Zjooooo`2gooooo`00[_oo
ool2oc8b<[Sooooo001oooooo`;o000000Ko410@oooooooooooo410@o`000?l@410Hooooo`Co0000
00Go410@ooooooooooooooooodA4A002o`000007oc8b<_oMgMgooooooooooon7QhOo0000okZj^P0<
ooooo`05oiRHV?l0003o0000odA4A?nj^[X06Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o
0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0NOooool0083ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00003?ooool00ol0003oooooooooo`06oooo
o`07ogMgMolb<S;oooooooooooo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@4100
2Oooool6o`0000cooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`1iooooo`00P?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@401iooooo`00P?ooool01_l0003oooooodA4A?m4A4Co
ooooo`0000Wooooo1_l0000<ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool04?oo
ool00ol0003oooooooooo`0;ooooo`Ko00003?ooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000007Wooooo0020ooooo`06o`00
0?oMgMgo<S8boeEEEOoMgMgo00006oooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`04Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000NOooool0083ooooo00Ko
0000ohN7QonYZJWo^[ZjoeEEEOl0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool04Oooool00ol@413o0000o`000003o`0001cooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@401iooooo`00P?ooool01_l0
003o<S8boooooooooooo<S8bo`0001_ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1iooooo`00Ooooool00ol@413o0000
ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo00?oEEEEofIVI_l000001Oooool4o`0001;ooooo
00?o0000ooooooooool06oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07Wooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-44.3769, -0.160437, \
0.309031, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.01333 0 0.309017 [
[.1001 -0.0125 -9 -9 ]
[.1001 -0.0125 9 0 ]
[.2334 -0.0125 -9 -9 ]
[.2334 -0.0125 9 0 ]
[.3667 -0.0125 -9 -9 ]
[.3667 -0.0125 9 0 ]
[.6333 -0.0125 -6 -9 ]
[.6333 -0.0125 6 0 ]
[.7666 -0.0125 -6 -9 ]
[.7666 -0.0125 6 0 ]
[.8999 -0.0125 -6 -9 ]
[.8999 -0.0125 6 0 ]
[.4875 .07725 -24 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -18 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -24 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1001 0 m
.1001 .00625 L
s
[(-30)] .1001 -0.0125 0 1 Mshowa
.2334 0 m
.2334 .00625 L
s
[(-20)] .2334 -0.0125 0 1 Mshowa
.3667 0 m
.3667 .00625 L
s
[(-10)] .3667 -0.0125 0 1 Mshowa
.6333 0 m
.6333 .00625 L
s
[(10)] .6333 -0.0125 0 1 Mshowa
.7666 0 m
.7666 .00625 L
s
[(20)] .7666 -0.0125 0 1 Mshowa
.8999 0 m
.8999 .00625 L
s
[(30)] .8999 -0.0125 0 1 Mshowa
.125 Mabswid
.12676 0 m
.12676 .00375 L
s
.15342 0 m
.15342 .00375 L
s
.18008 0 m
.18008 .00375 L
s
.20674 0 m
.20674 .00375 L
s
.26006 0 m
.26006 .00375 L
s
.28672 0 m
.28672 .00375 L
s
.31338 0 m
.31338 .00375 L
s
.34004 0 m
.34004 .00375 L
s
.39336 0 m
.39336 .00375 L
s
.42002 0 m
.42002 .00375 L
s
.44668 0 m
.44668 .00375 L
s
.47334 0 m
.47334 .00375 L
s
.52666 0 m
.52666 .00375 L
s
.55332 0 m
.55332 .00375 L
s
.57998 0 m
.57998 .00375 L
s
.60664 0 m
.60664 .00375 L
s
.65996 0 m
.65996 .00375 L
s
.68662 0 m
.68662 .00375 L
s
.71328 0 m
.71328 .00375 L
s
.73994 0 m
.73994 .00375 L
s
.79326 0 m
.79326 .00375 L
s
.81992 0 m
.81992 .00375 L
s
.84658 0 m
.84658 .00375 L
s
.87324 0 m
.87324 .00375 L
s
.07344 0 m
.07344 .00375 L
s
.04678 0 m
.04678 .00375 L
s
.02012 0 m
.02012 .00375 L
s
.92656 0 m
.92656 .00375 L
s
.95322 0 m
.95322 .00375 L
s
.97988 0 m
.97988 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .07725 m
.50625 .07725 L
s
[(0.25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(0.75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(1)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(1.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(1.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(1.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(105) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .19036 m
.03279 .2334 L
.04262 .27459 L
.04758 .29022 L
.05035 .29694 L
.05288 .30163 L
.05403 .30329 L
.05524 .30473 L
.05587 .30534 L
.05657 .30591 L
.0578 .30662 L
.05895 .30698 L
.0602 .307 L
.06137 .30668 L
.06244 .30611 L
.06314 .30559 L
.0638 .30499 L
.06504 .30361 L
.0678 .29927 L
.07019 .29418 L
.07277 .28737 L
.07864 .26752 L
.08405 .24508 L
.10458 .14986 L
.11366 .11465 L
.1234 .08589 L
.12899 .07336 L
.13409 .06404 L
.14407 .05017 L
.14887 .04502 L
.15398 .04039 L
.15839 .03703 L
.16315 .03408 L
.16581 .03275 L
.16824 .03173 L
.17057 .03096 L
.17302 .03035 L
.17432 .03012 L
.17504 .03002 L
.17572 .02994 L
.17703 .02984 L
.17822 .0298 L
.17891 .0298 L
.17964 .02983 L
.18095 .02992 L
.18168 .02999 L
.18236 .03008 L
.18391 .03035 L
.18516 .03063 L
.1865 .03099 L
Mistroke
.18889 .03179 L
.19432 .03427 L
.1995 .03746 L
.2042 .04097 L
.21375 .05012 L
.22274 .06202 L
.22741 .07007 L
.23253 .08081 L
.24285 .11 L
.25242 .14673 L
.26134 .18763 L
.27182 .23773 L
.27697 .26021 L
.28173 .27816 L
.28605 .29124 L
.28826 .29653 L
.29063 .30109 L
.29187 .30297 L
.29301 .30438 L
.29409 .30546 L
.29523 .30629 L
.29649 .30685 L
.29765 .30704 L
.29893 .30687 L
.29965 .30661 L
.3003 .30626 L
.3015 .30537 L
.30262 .30423 L
.30516 .30058 L
.30765 .29565 L
.31031 .28894 L
.31952 .25634 L
.34033 .16009 L
.35049 .11911 L
.35585 .10144 L
.36155 .08577 L
.36651 .07453 L
.37199 .06435 L
.38166 .05074 L
.38657 .04541 L
.39174 .04067 L
.39621 .03723 L
.40099 .03423 L
.40369 .03286 L
.40614 .03182 L
.40861 .03099 L
.41094 .03041 L
.41226 .03016 L
.41298 .03006 L
.41366 .02998 L
Mistroke
.41485 .02987 L
.41616 .02982 L
.4169 .02982 L
.41759 .02984 L
.4189 .02992 L
.41963 .02999 L
.4203 .03008 L
.42183 .03033 L
.42312 .03061 L
.42448 .03097 L
.42692 .03176 L
.43241 .03426 L
.43716 .03714 L
.44237 .04102 L
.452 .05027 L
.46098 .06226 L
.466 .07102 L
.47145 .08277 L
.48135 .11137 L
.49099 .1488 L
.49991 .18991 L
.5089 .23304 L
.51859 .27381 L
.52129 .28298 L
.52414 .29122 L
.52677 .29743 L
.52922 .30189 L
.53041 .30356 L
.53153 .30485 L
.53282 .30597 L
.53399 .30665 L
.53529 .30702 L
.53649 .307 L
.53781 .3066 L
.53847 .30623 L
.5392 .30572 L
.5405 .30449 L
.5417 .30301 L
.54442 .29845 L
.54682 .29312 L
.54937 .28618 L
.55866 .25193 L
.57956 .1551 L
.58988 .11459 L
.59531 .09743 L
.60103 .08245 L
.60605 .07166 L
.61155 .06198 L
.62121 .04906 L
.62648 .04363 L
Mistroke
.63145 .03933 L
.63598 .03608 L
.64078 .03333 L
.64326 .0322 L
.64599 .0312 L
.64719 .03084 L
.64848 .03052 L
.64969 .03027 L
.65081 .03009 L
.65154 .03 L
.65221 .02993 L
.65294 .02988 L
.65373 .02984 L
.65441 .02983 L
.65516 .02983 L
.65586 .02985 L
.6565 .02989 L
.65771 .03 L
.65839 .03009 L
.65903 .03019 L
.66033 .03043 L
.66171 .03075 L
.66431 .03153 L
.66671 .03246 L
.67215 .03521 L
.67686 .03827 L
.68205 .04235 L
.69162 .05202 L
.70061 .06472 L
.7053 .07338 L
.71043 .08493 L
.72078 .116 L
.73036 .15438 L
.73928 .19606 L
.7498 .24579 L
.75496 .26736 L
.75973 .28402 L
.76406 .29566 L
.76624 .30008 L
.76864 .30373 L
.7699 .30511 L
.77105 .30606 L
.77169 .30644 L
.77238 .30676 L
.77364 .30704 L
.77481 .30696 L
.77606 .30651 L
.77724 .30575 L
.77831 .30479 L
.77952 .30338 L
Mistroke
.78064 .30176 L
.7832 .29706 L
.78569 .29115 L
.78836 .28348 L
.79759 .24834 L
.81842 .15176 L
.82861 .1124 L
.83399 .09574 L
.83969 .08112 L
.84467 .07066 L
.85015 .0612 L
.85982 .04851 L
.86475 .04348 L
.86993 .03904 L
.87441 .03586 L
.8792 .03315 L
.88191 .03196 L
.88436 .03109 L
.88555 .03075 L
.88684 .03044 L
.88804 .03021 L
.88917 .03004 L
.89048 .0299 L
.89118 .02985 L
.89192 .02982 L
.89271 .02981 L
.89345 .02982 L
.89411 .02984 L
.89484 .02989 L
.89615 .03003 L
.89682 .03012 L
.89755 .03024 L
.90006 .03081 L
.9024 .03153 L
.90497 .03252 L
.91013 .03515 L
.91938 .04172 L
.92459 .04648 L
.93017 .05258 L
.9354 .05954 L
.94022 .06735 L
.94909 .08633 L
.95871 .11542 L
.97619 .19036 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^@?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hLooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=_ooool0
03Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Oooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`12ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0=_ooool002oooooo1_l00006ooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41005?ooool6o`0000Gooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@01gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01oo
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03Cooooo000jooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000012ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`00>Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000007oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000@_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
7oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool00000=_ooool003[ooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@023ooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@03Kooooo000gooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0@_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL07?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Kooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Ko
oooo000gooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Ooo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0@?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Kooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo000Koooooooo0000<_l0000Looooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Pooooo`00>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo001@ooooo`Co0000A?ooool5o`0001Kooooo00?o0000ooooooooool0
:_ooool5o`0004?ooooo1Ol0000kooooo`00C_ooool2o`0000Cooooo0_l00010ooooo`;o00001?oo
ool2o`0001Gooooo0_l0000Xooooo`Co00001?ooool2o`0003oooooo0ol00003ooooo`?o0000>Ooo
ool004_ooooo0ol00008ooooo`;o0000??ooool2o`0000Sooooo0ol0000Booooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool02?ooool2o`0003_ooooo0_l00009ooooo`;o0000=oooool0
04[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Tooooo`;o00003Oooool00ol0
003oooooooooo`0gooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0=?ooool004Wo
oooo00?o0000ooooooooool03Oooool2o`0003Oooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo00gooooo0_l0000dooooo`00B?ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0=ooooo`;o00009?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0aooooo`00Aoooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0<?ooool004Oooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02oooooo0016oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0_oooo
o`00AOooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool0;_ooool004Gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool02Oooool2o`00023ooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
;_ooool004Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo02gooooo0013ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0:Oooool0
2Ol0003oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000?o
oooo00Ko0000odA4A?l0003o0000oc8b<_oMgMd5ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool0;?ooool004;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Cooooo00Go0000ooooooooooooMgMgoc8b<P05ooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool0;?ooool004;ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00?ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00Go0000ooooooooooooooooo`000005ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool0:oooool004;ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00Co0000oooooomgMgOo<S8b1Oooool3o`00
01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool0:oooool0047ooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo00?ooooo0ol000000olb<S;oc<c<ooooo`04ooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool0:oooool0047ooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00;ooooo0_l00008ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool0:_ooool0047ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001?ooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool0:_ooool0043ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo00Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0000Looooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02Wooooo0010
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Y
ooooo`00@?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool0:Oooool003oooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo02Sooooo000oooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0Xooooo`00?oooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`03ooooo`;o00006_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`0Xooooo`00?_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool09oooool003kooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo02Oooooo000nooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Wooooo`00?_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool09oooool003gooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool00_ooool2o`0001Sooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool003gooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo000moooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Woooo
o`05o`000?ooooooooooooooool000006Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`00??ooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool09oooool01Ol0
003ooooooooooooooooo000001Wooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool09_ooool003cooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Oooooo00Co0000oooo
oooooooooooo0_l0000Gooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Kooooo000looooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Xooooo`05o`000?oooooooooo
ooooool000006?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`0Uooooo`00??ooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:Oooool01?l0003oooooooooool0000H
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo02Gooooo000kooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`04o`000?ooooooooooo`0001Sooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool09Oooool003_ooooo00?o0000ooooooooool0:_ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
2?ooool01OmgMgOo<S8boooooooooooo000000;ooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`0[ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0Uooooo`00>oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@013ooooo00Co0000oooooooo
oooo00000_ooool3o`0001Gooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool09?ooool003_ooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01;ooooo00Go0000oooooooo
ooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00;ooooo00?o0000ooooool000005oooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`0Tooooo`00>_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool04_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c003ooooo`03o`000?oooooo000001Oooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool09?ooool0
03[ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
01;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooool000005_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`0Tooooo`00>_ooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool04_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool01Oooool00ol0003oooooo`00000Fooooo`03o`000?oooooo
oooo02gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo
oooo02Cooooo000jooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo0ol0000E
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo02?ooooo000jooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0]ooooo`;o00005_ooool00ol0003oooooooooo`0]oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Soooo
o`00>Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0;Oooool2o`0001Kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool08oooool003Wooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02gooooo0_l0000Eooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo02?ooooo000iooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0^ooooo`?o00005?ooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Sooooo`00>Oooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02;ooooo000Sooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Rooooo`008oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo05Cooooo000Sooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0E?ooool002?ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0<?ooool2o`0001?ooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05Cooooo000T
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo033ooooo0_l0000Cooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`1Eooooo`009?ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0`oooo
o`;o00004oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0EOooool002Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool0<Oooool2o`0001?ooooo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05Gooooo000Tooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooool000004Oooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool0EOooool002Cooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<Ooo
ool3o`00017ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo05Kooooo000Tooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo037ooooo00?o0000ooooool000004Oooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0E_ooool0
02Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool03_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46
ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooo0000017ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo05Kooooo000Uooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooool000004Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool0E_ooool002Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03oooool01Ol@413ooooooooooooo
oooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`Co00003ooo
ool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0E_oo
ool002Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03oooool01Ol0003ooooooooooooooooo000000kooooo00?o
8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`04o`000?ooooooooooo`0000oooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo05Oooooo
000Uooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00oooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEE
EOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`04o`000?ooooooooooo`00
00oooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
05Oooooo000Uooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo013ooooo00Go410@oooooooooooooooooa0@400>oooo
o`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool01?l0003oooooooooool0000?
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1G
ooooo`009_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool01Ol0003ooooooooo
oooooooo000000kooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo05Oooooo000Vooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo013ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l00002ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Sooooo
000Vooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0=oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo03?ooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Hooooo`009_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0dooooo`05o`000?ooooooooooooooool000003Oooool00ol0003ooooo
ooooo`0gooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0F?ooool002Oooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Sooooo000W
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1I
ooooo`009oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0dooooo`;o00000oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Ioooo
o`009oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03[ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0FOooool002Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0jooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo05Wooooo000Xooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`1Iooooo`00:?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0F_ooool002Wooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0looooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=_ooool2o`00
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0F_ooool002Wooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0mooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0?Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo05[ooooo000Yooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0?Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Jooooo`00:_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Foooool002[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0=oooool2o`0000Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Foooool002_ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05cooooo000[ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo02kooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0G?ooool002_ooooo0_l00002ooooo`03o`000?oooooooooo047ooooo
0_l00002ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`06ooooo`05o`000?ooooooooooooooool00000A?ooool01?l0003oooooooooool0001Ooooo
o`00;?ooool4o`0004Cooooo1?l0000cooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01oooool3o`0004Gooooo0ol0001Pooooo`00Zoooool00ol0003oooooooooo`05ooooo`?o0000
/_ooool00:_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2booooo`00Zoooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;;ooooo002[ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0/_ooool00:Wooooo00?oEEEEofIVI_l000001oooool00ol0003o
ooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o
0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_oo
ool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?o
oooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooooooo
o`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2boooo
o`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002Aooooo`Co000000?o
410@ooooooooool00_ooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1Oooool00ol0003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`04ooooo`;o8B4Q1?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`2booooo`00Toooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o
0000ooooooooool00oooool3o`000;;ooooo002Cooooo`03o`000?oooooooooo00cooooo00?oV9RH
ob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;;ooooo002Coooo
o`03o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_ooool009?o
oooo00?o0000ooooooooool02_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`2booooo`00TOooool00omEEEGoIVIVo`00000<ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0002cooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooooooo
o`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03
o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oo
oooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?o
oooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o
0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2boooo
o`00VOooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`2booooo`00Voooool00ol0003oooooooooo`04ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;;ooooo002Kooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2booooo`00Vooo
ool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002booooo`00Voooool0
0ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`2booooo`00Voooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0/_ooool009_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo0;;ooooo002Iooooo`03oeEEEOmVIVKo000000gooooo1?l00006ooooo`03
o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_oo
ool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?o
oooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooooooo
o`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2boooo
o`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oo
oooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo
0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool0097ooooo1?l0
00000ol@413oooooooooo`02ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2booooo`00Toooool00ol0003ooooooooo
o`04ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool03?ooool00onYZJWoEEEEooooo`08
ooooo`03o`000?oooooooooo00?ooooo0ol0002booooo`00Toooool00ol0003oooooooooo`0=oooo
o`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2boooo
o`00Toooool00ol0003oooooooooo`0=ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c005ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00go
oooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;;o
oooo002Cooooo`03o`000?oooooooooo00[ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_ooool0097ooooo00?oEEEEofIVI_l00000
3?ooool5o`0000Cooooo1?l00006ooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_oo
ool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?o
oooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003ooooooooo
o`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2boooo
o`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oo
oooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo
0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00:Sooooo1Ol0
0006ooooo`03o`000?oooooooooo0;;ooooo002Xooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_oo
ool00ol0003oooooooooo`2booooo`00ZOooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooo
oooo0;;ooooo002Zooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0002booooo`00Zoooool00omgMgOo
IVIVooooo`2jooooo`00[?ooool00ol0003oooooooooo`2iooooo`00Z?ooool01Ol0003o^[Zjoooo
oonHV9So410@0;_ooooo002Xooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0^oooool00?ooooooJOoo
ool00:kooooo00?o0000okZj^_ooool0]oooool00:kooooo0_lb<S:hooooo`00Ooooool2o`000006
oa0@4?oooooooooooa0@4?l0003o410@6?ooool4o`000005oa0@4?oooooooooooooooom4A4@00_l0
00001olb<S;ogMgMooooooooooooQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj
01Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1?ooool01Om4A4Co0000
o`000?lb<S;ogMgM07Sooooo0020ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1oooool6o`0000cooooo00?o0000ooooooooool01_ooool01omgMgOo<S8booooooooooooc<c<o`00
0?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`03ogMgMolb<S;ooooo07Oooooo0020
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`1fooooo`00P?ooool0
1_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000<ooooo`03o`000?oooooooooo00Kooooo
00?oMgMgoc8b<_ooool04?ooool00ol0003oooooooooo`0;ooooo`Ko00003?ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001oooool00omgMgOo<S8booooo`1gooooo`00
P?ooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001_ooooo00?o0000ooooooooool00oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<017ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<07Sooooo
0020ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo00006oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo017ooooo00?o410@o`000?l000000ol0000Looooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@4004ooooo`03o`000?oooooooooo07[ooooo0020ooooo`06
o`000?lb<S;ooooooooooolb<S;o00006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01?ooool00ol0003oooooooooo`1jooooo`00Ooooool00ol@413o0000ohN7Q`02
ooooo`03ohN7Qol0003o410@01Sooooo00?oEEEEofIVI_l000001Oooool4o`0001;ooooo00?o0000
ooooooooool06oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?oo
ool4o`0007Wooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-44.3769, -0.160437, \
0.309031, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.01333 0 0.309017 [
[.1001 -0.0125 -9 -9 ]
[.1001 -0.0125 9 0 ]
[.2334 -0.0125 -9 -9 ]
[.2334 -0.0125 9 0 ]
[.3667 -0.0125 -9 -9 ]
[.3667 -0.0125 9 0 ]
[.6333 -0.0125 -6 -9 ]
[.6333 -0.0125 6 0 ]
[.7666 -0.0125 -6 -9 ]
[.7666 -0.0125 6 0 ]
[.8999 -0.0125 -6 -9 ]
[.8999 -0.0125 6 0 ]
[.4875 .07725 -24 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -18 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -24 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1001 0 m
.1001 .00625 L
s
[(-30)] .1001 -0.0125 0 1 Mshowa
.2334 0 m
.2334 .00625 L
s
[(-20)] .2334 -0.0125 0 1 Mshowa
.3667 0 m
.3667 .00625 L
s
[(-10)] .3667 -0.0125 0 1 Mshowa
.6333 0 m
.6333 .00625 L
s
[(10)] .6333 -0.0125 0 1 Mshowa
.7666 0 m
.7666 .00625 L
s
[(20)] .7666 -0.0125 0 1 Mshowa
.8999 0 m
.8999 .00625 L
s
[(30)] .8999 -0.0125 0 1 Mshowa
.125 Mabswid
.12676 0 m
.12676 .00375 L
s
.15342 0 m
.15342 .00375 L
s
.18008 0 m
.18008 .00375 L
s
.20674 0 m
.20674 .00375 L
s
.26006 0 m
.26006 .00375 L
s
.28672 0 m
.28672 .00375 L
s
.31338 0 m
.31338 .00375 L
s
.34004 0 m
.34004 .00375 L
s
.39336 0 m
.39336 .00375 L
s
.42002 0 m
.42002 .00375 L
s
.44668 0 m
.44668 .00375 L
s
.47334 0 m
.47334 .00375 L
s
.52666 0 m
.52666 .00375 L
s
.55332 0 m
.55332 .00375 L
s
.57998 0 m
.57998 .00375 L
s
.60664 0 m
.60664 .00375 L
s
.65996 0 m
.65996 .00375 L
s
.68662 0 m
.68662 .00375 L
s
.71328 0 m
.71328 .00375 L
s
.73994 0 m
.73994 .00375 L
s
.79326 0 m
.79326 .00375 L
s
.81992 0 m
.81992 .00375 L
s
.84658 0 m
.84658 .00375 L
s
.87324 0 m
.87324 .00375 L
s
.07344 0 m
.07344 .00375 L
s
.04678 0 m
.04678 .00375 L
s
.02012 0 m
.02012 .00375 L
s
.92656 0 m
.92656 .00375 L
s
.95322 0 m
.95322 .00375 L
s
.97988 0 m
.97988 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .07725 m
.50625 .07725 L
s
[(0.25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(0.75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(1)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(1.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(1.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(1.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(110) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .09409 m
.04262 .16434 L
.06244 .25665 L
.06747 .276 L
.07024 .28501 L
.07286 .29225 L
.07529 .29777 L
.07657 .30017 L
.07793 .30232 L
.07908 .30381 L
.08034 .30509 L
.08148 .30595 L
.08255 .30647 L
.08326 .30666 L
.08391 .30673 L
.08463 .3067 L
.08539 .30653 L
.08612 .30623 L
.08681 .30585 L
.0881 .30482 L
.08936 .30343 L
.09053 .30184 L
.09317 .29712 L
.09581 .29091 L
.09872 .28254 L
.10458 .2614 L
.12572 .16442 L
.13574 .12325 L
.145 .09354 L
.15457 .0713 L
.15962 .0624 L
.16498 .05458 L
.17398 .04427 L
.18391 .036 L
.18883 .03303 L
.19151 .03175 L
.19401 .03079 L
.19614 .03014 L
.19724 .02987 L
.19843 .02963 L
.19973 .02944 L
.20096 .02931 L
.20216 .02924 L
.20326 .02923 L
.20446 .02927 L
.20575 .02937 L
.20697 .02953 L
.20808 .02972 L
.21081 .03038 L
.21339 .03126 L
Mistroke
.21852 .03367 L
.22412 .03722 L
.23446 .04617 L
.24383 .0574 L
.24903 .06548 L
.25464 .07624 L
.26481 .1027 L
.27434 .13685 L
.28479 .18332 L
.29582 .23587 L
.30064 .25704 L
.30587 .27703 L
.3084 .28521 L
.31109 .2926 L
.31358 .29816 L
.31591 .30217 L
.31697 .30358 L
.31809 .3048 L
.31931 .30579 L
.32043 .3064 L
.32167 .30673 L
.32282 .3067 L
.32407 .30632 L
.32478 .30594 L
.32542 .3055 L
.32673 .3043 L
.32811 .3026 L
.33059 .29848 L
.33326 .29258 L
.33619 .28447 L
.34635 .24592 L
.36747 .14848 L
.37747 .11058 L
.38674 .08418 L
.39629 .06476 L
.40133 .05697 L
.40669 .05006 L
.41568 .0409 L
.42042 .0371 L
.42561 .03373 L
.43052 .03136 L
.4332 .03043 L
.43448 .03007 L
.43569 .0298 L
.43681 .02959 L
.43803 .02942 L
.43914 .02931 L
.44016 .02925 L
.44126 .02924 L
.44248 .02928 L
Mistroke
.44375 .02938 L
.44494 .02953 L
.44622 .02975 L
.44763 .03006 L
.45018 .03081 L
.45267 .03177 L
.45498 .03283 L
.46021 .03587 L
.46578 .03997 L
.47608 .04997 L
.48188 .05732 L
.48721 .06562 L
.49702 .08619 L
.50197 .09982 L
.50739 .11762 L
.52855 .2105 L
.53857 .25633 L
.54297 .27352 L
.54783 .28903 L
.55007 .2947 L
.55248 .29966 L
.55381 .30185 L
.55502 .30351 L
.55619 .30479 L
.55741 .30579 L
.55866 .30644 L
.55936 .30665 L
.55999 .30674 L
.56122 .30664 L
.56239 .30622 L
.56305 .30583 L
.56375 .30532 L
.565 .30411 L
.56634 .30241 L
.56783 .30007 L
.57254 .28949 L
.57761 .27345 L
.58676 .23553 L
.60652 .14442 L
.6177 .10375 L
.62304 .08866 L
.62806 .07685 L
.63817 .0588 L
.64733 .04721 L
.65719 .03809 L
.66274 .03428 L
.66541 .0328 L
.66784 .03166 L
.6701 .03079 L
.67256 .03005 L
Mistroke
.67391 .02975 L
.67515 .02952 L
.67634 .02937 L
.67761 .02926 L
.67869 .02922 L
.67984 .02923 L
.68094 .02928 L
.68194 .02937 L
.68311 .02952 L
.68439 .02975 L
.68671 .03032 L
.68943 .03123 L
.6919 .03227 L
.69744 .03532 L
.7074 .04304 L
.71741 .0539 L
.72663 .06795 L
.73146 .07757 L
.73675 .09042 L
.74745 .12481 L
.76859 .21982 L
.7786 .26421 L
.783 .28018 L
.78551 .28786 L
.78786 .29399 L
.79028 .29911 L
.7925 .3027 L
.79365 .30412 L
.79487 .3053 L
.79609 .30612 L
.79678 .30644 L
.79743 .30663 L
.79808 .30672 L
.79878 .30671 L
.80006 .30639 L
.80131 .3057 L
.80246 .30475 L
.8037 .30338 L
.80507 .30146 L
.80783 .29632 L
.81255 .28397 L
.81761 .26636 L
.82676 .22674 L
.8465 .13675 L
.85191 .11651 L
.85767 .09813 L
.86802 .07296 L
.87319 .06359 L
.87877 .05528 L
.88888 .04369 L
Mistroke
.89367 .03941 L
.89872 .03564 L
.90304 .03306 L
.90777 .03095 L
.91029 .03015 L
.91171 .02981 L
.91302 .02956 L
.91417 .02939 L
.91544 .02927 L
.91676 .02921 L
.918 .02922 L
.91914 .02927 L
.92034 .02939 L
.92136 .02953 L
.92248 .02973 L
.92498 .03035 L
.92731 .03112 L
.93262 .03358 L
.93743 .03656 L
.94824 .04567 L
.95522 .05355 L
.96166 .06273 L
.96872 .07579 L
.97619 .09409 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^@?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hLooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=_ooool0
03Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Oooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`12ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0=_ooool002oooooo1_l00006ooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41005?ooool6o`0000Gooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@01gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01oo
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03Cooooo000jooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000012ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`00>Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000007oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000@_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
7oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool00000=_ooool003[ooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@023ooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@03Kooooo000gooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0@_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL07?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Kooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Ko
oooo000gooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Ooo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0@?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Kooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo000Koooooooo0000<_l0000Looooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Pooooo`00>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo001Gooooo`Go0000@oooool5o`0000oooooo00?o0000ooooooooool0
<Oooool6o`0004?ooooo1Ol0000cooooo`00E?ooool3o`0000Gooooo0ol0000mooooo`?o00001Ooo
ool3o`0000cooooo0_l0000`ooooo`?o00001?ooool3o`0003kooooo0ol00005ooooo`?o0000<?oo
ool005?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo00Wooooo0_l0000:ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool02?ooool2
o`0003[ooooo0_l0000;ooooo`03o`000?oooooooooo02gooooo001Booooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0;?ooool2o`0000gooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo02cooooo001Aooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0[ooooo`00D?ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`05ooooo`;o0000:oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0Zooooo`00Coooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0:Oooool004kooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02Sooooo001=oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Xoooo
o`00COooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool09oooool004cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool00_ooool2o`0002Sooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
9_ooool004cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo01Sooooo00Go0000ooooooooooooooooo`00000Xooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02Kooooo
001;ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool09_ooool01Oo^k^ko<S8bo`00
0?lb<S;o000000Gooooo0_lQ8B44ooooo`Go00001?ooool01om4A4Co0000o`000?lb<S;ogMgMoooo
ool000000oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Gooooo001:ooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool09Oooool01OmgMgOoV9RHooooool0003oMgMg
00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool01OmgMgOo<S8boooooooo
oooo000000;ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Uooooo`00B_ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Cooooo00Go410@oooooooooooo0000oa0@
400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo02Cooooo0019ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool09?ooool01Ol0003oooooo`000?oooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`02ooooo`03o`000?oooooo000000;o00009?ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Tooooo`00BOooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02?ooooo00Go
0000ooooool0003oooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c003ooooo`03o`000?oooooo000002Gooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool08oooool004Sooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Sooooo`05oa0@4?l0003oooooooooool@
41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo0_l0000Uooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo02?ooooo0018ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
8oooool01OmgMgOo0000oooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004oooo
o`03o`000?oooooooooo00Kooooo0_l0000Tooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02?ooooo0018ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool08_ooool01Ol0003o<S8bo`000?lb<S;ok^k^
00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`0002?ooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool08_ooool002?ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo02;ooooo000Sooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo023ooooo0_l0000Rooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`15ooooo`00
8oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`0Qooooo`;o00008_ooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool0AOooool002Cooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08Ooo
ool2o`0002;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo04Kooooo000Tooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo027ooooo0_l0000Rooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`16ooooo`009?ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooo0000023ooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo04Kooooo000Tooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02;o
oooo00?o0000ooooool000008?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool0Aoooool002Gooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool08_ooool00ol0003ooooo
o`00000Pooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`17ooooo`009Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo000001oooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04Oooooo000U
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo02?ooooo0ol0000Oooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`18ooooo`009Oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Soooo
o`04o`000?ooooooooooo`0001kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo04Sooooo000Vooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Cooooo00Co0000oooo
oooooooo00007Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool0B?ooool002Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool09?ooool01?l0003oooooooooool0000M
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`19
ooooo`009_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Tooooo`;o000000?oooooo`000?ooool07?ooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0BOooool002Ko
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool09?ooool01Ol0003ooooooooooooooooo000001_ooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04Wooooo000Vooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo02Gooooo00Go0000ooooooooooooooooo`00000Kooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`19ooooo`009oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0:ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`05o`000?ooooooooooooooool000006oooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0B_ooool002Oooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool02_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo00Cooooo00Go0000ooooooooooooooooo`00000Kooooo`03o`000?oooooooooo02[ooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`1:ooooo`009oooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0:ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`?o0000
0_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`1:ooooo`009oooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0;ooooo`05o`000?oo
ooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool0B_ooool002Sooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02oooool01Ol0003ooooooooo
oooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool0B_ooool002Sooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo04_ooooo000Xooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00_ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`1;ooooo`00:?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0<ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03?ooool4o`0000Kooooo0_l00004ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04_ooooo000Yooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1;ooooo`00:Ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0C?oo
ool002Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo04cooooo000Yooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo02Oooooo0_l00005ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
04cooooo000Yooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`1<ooooo`00:_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0C?ooool002[ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo04gooooo000Zooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`1=ooooo`00:_ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Yoooo
o`;o00001_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`1=ooooo`00:_ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool0COooool002_ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04kooooo000[ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1>ooooo`00:oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0C_ooool0
02_ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0:_ooool2o`0000Oooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0C_ooool002co
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04ko
oooo000/ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo04oooooo000/ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo03Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1?oooo
o`00;?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`08ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onY
ZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol00007ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
04oooooo000/ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo04oooooo000]ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0D?ooool002gooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool02?ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0fooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0D?ooool0
02gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@
oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`1@ooooo`00;Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo03Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`09ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`;o00002Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`1@ooooo`00;Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Oooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0DOooool002kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo057ooooo000^ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0>Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`1Aooooo`00;_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo03Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0iooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0DOooool002oooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0;Ooo
ool2o`0000[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0D_ooool002oooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo05;ooooo000_ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
03[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Booooo`00<?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0^ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0D_ooool0033ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05?ooooo
000`ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0??ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo02oooooo0_l0000<ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0??ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05?ooooo000a
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1C
ooooo`00<Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0Doooool0037ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0nooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo05Cooooo000aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
?oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo033ooooo0_l0000=ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo05Cooooo000aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0?ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1Eooooo`00<_ooool2o`0000Cooooo00?o0000ooooooooool0?oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Kooooo1?l000000ol@413oooooooooo`03
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`10
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0EOooool003?ooooo00?o0000oooo
ooooool00_l00013ooooo`05o`000?ooooooooooooooool00000:oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00gooooo0_l00002ooooo`03o`000?oooooooooo04;ooooo00?o0000
ooooooooool00_l0001Gooooo`00=?ooool3o`0004Gooooo0ol0000/ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool03_ooool3o`0004Gooooo1?l0001Hooooo`00Zoooool00ol0003o
ooooooooo`05ooooo`?o0000/_ooool00:_ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`2booooo`00Zoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;;ooooo002[
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/_ooool00:Wooooo00?oEEEEofIV
I_l000001oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`00
0?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooo
oooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo
00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000
ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00
/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool0
0ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;o
oooo002Aooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2booooo`00Toooool00ol0003ooooo
ooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`0;ooooo`03oiRH
V?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`000;;ooooo002Cooooo`03o`000?oo
oooooooo00cooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0/_ooool009?ooooo00?o0000ooooooooool02_ooool01Ol0003o^[ZjoooooonHV9So
410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2booooo`00TOooool00omE
EEGoIVIVo`00000<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0002c
ooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00
/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2
o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;o
oooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000
ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooooooo
ool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool0
0ol0003oooooooooo`2booooo`00VOooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2booooo`00Voooool00ol0
003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
0;;ooooo002Kooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`2booooo`00Voooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo
0ol0002booooo`00Voooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`2booooo`00Voooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0/_ooool009_ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;;ooooo002Iooooo`03oeEEEOmVIVKo0000
00gooooo1?l00006ooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo
00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000
ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00
/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool0
0ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;o
oooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000oooooooo
ool0/_ooool0097ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_ooool00ol0003ok^k^
ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2booooo`00
Toooool00ol0003oooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool03?oo
ool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002booooo`00Toooool0
0ol0003oooooooooo`0=ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`0=ooooo`03oeEEEOo<c<cooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;;ooooo002Coooo
o`03o`000?oooooooooo00gooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00[ooooo00Go410@oooooooo
oooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_ooool0097o
oooo00?oEEEEofIVI_l000003?ooool5o`0000Cooooo1?l00006ooooo`;o0000/oooool00;?ooooo
00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000
ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00
/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool0
0ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;o
oooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000oooooooo
ool0/_ooool00:Sooooo1Ol00006ooooo`03o`000?oooooooooo0;;ooooo002Xooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`2booooo`00ZOooool00onHV9So8B4Qonk^
kP07ooooo`03o`000?oooooooooo0;;ooooo002Zooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0002b
ooooo`00Zoooool00omgMgOoIVIVooooo`2jooooo`00[?ooool00ol0003oooooooooo`2iooooo`00
Z?ooool01Ol0003o^[ZjoooooonHV9So410@0;_ooooo002Xooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`0^oooool00?ooooooJOooool00:kooooo00?o0000okZj^_ooool0]oooool00:kooooo0_lb<S:h
ooooo`00Ooooool2o`000006oa0@4?oooooooooooa0@4?l0003o410@6?ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000001olb<S;ogMgMooooooooooooQhN7o`000?nj^[X03?ooool01OnH
V9So0000o`000?m4A4Co^[Zj01Wooooo1?l000001?l@413oooooooooooooool4o`000008oa0@4?oo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^iiooooo`00P?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Oooooo1_l0000<ooooo`03o`000?oooooooooo00Kooooo00OoMgMgoc8b<_oo
ooooooooolc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`1iooooo`00P?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
NOooool0083ooooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00003?ooool00ol0003o
ooooooooo`06ooooo`03ogMgMolb<S;ooooo013ooooo00?o0000ooooooooool02oooool6o`0000co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000NOooool0083ooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Kooooo`03o`000?oooooo
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Aooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
NOooool0083ooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Kooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool04Oooool00ol@413o0000o`000003o`0001cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100NOooool0083o
oooo00Ko0000oc8b<_oooooooooooc8b<_l0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg07Wooooo001oooooo`03oa0@4?l0003o
QhN700;ooooo00?oQhN7o`000?l@41006?ooool00omEEEGoIVIVo`000005ooooo`Co00004_ooool0
0ol0003oooooooooo`0Kooooo`03oeEEEOmVIVKo000000Gooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^07Wooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-44.3769, -0.160437, \
0.309031, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.01333 0 0.309017 [
[.1001 -0.0125 -9 -9 ]
[.1001 -0.0125 9 0 ]
[.2334 -0.0125 -9 -9 ]
[.2334 -0.0125 9 0 ]
[.3667 -0.0125 -9 -9 ]
[.3667 -0.0125 9 0 ]
[.6333 -0.0125 -6 -9 ]
[.6333 -0.0125 6 0 ]
[.7666 -0.0125 -6 -9 ]
[.7666 -0.0125 6 0 ]
[.8999 -0.0125 -6 -9 ]
[.8999 -0.0125 6 0 ]
[.4875 .07725 -24 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -18 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -24 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1001 0 m
.1001 .00625 L
s
[(-30)] .1001 -0.0125 0 1 Mshowa
.2334 0 m
.2334 .00625 L
s
[(-20)] .2334 -0.0125 0 1 Mshowa
.3667 0 m
.3667 .00625 L
s
[(-10)] .3667 -0.0125 0 1 Mshowa
.6333 0 m
.6333 .00625 L
s
[(10)] .6333 -0.0125 0 1 Mshowa
.7666 0 m
.7666 .00625 L
s
[(20)] .7666 -0.0125 0 1 Mshowa
.8999 0 m
.8999 .00625 L
s
[(30)] .8999 -0.0125 0 1 Mshowa
.125 Mabswid
.12676 0 m
.12676 .00375 L
s
.15342 0 m
.15342 .00375 L
s
.18008 0 m
.18008 .00375 L
s
.20674 0 m
.20674 .00375 L
s
.26006 0 m
.26006 .00375 L
s
.28672 0 m
.28672 .00375 L
s
.31338 0 m
.31338 .00375 L
s
.34004 0 m
.34004 .00375 L
s
.39336 0 m
.39336 .00375 L
s
.42002 0 m
.42002 .00375 L
s
.44668 0 m
.44668 .00375 L
s
.47334 0 m
.47334 .00375 L
s
.52666 0 m
.52666 .00375 L
s
.55332 0 m
.55332 .00375 L
s
.57998 0 m
.57998 .00375 L
s
.60664 0 m
.60664 .00375 L
s
.65996 0 m
.65996 .00375 L
s
.68662 0 m
.68662 .00375 L
s
.71328 0 m
.71328 .00375 L
s
.73994 0 m
.73994 .00375 L
s
.79326 0 m
.79326 .00375 L
s
.81992 0 m
.81992 .00375 L
s
.84658 0 m
.84658 .00375 L
s
.87324 0 m
.87324 .00375 L
s
.07344 0 m
.07344 .00375 L
s
.04678 0 m
.04678 .00375 L
s
.02012 0 m
.02012 .00375 L
s
.92656 0 m
.92656 .00375 L
s
.95322 0 m
.95322 .00375 L
s
.97988 0 m
.97988 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .07725 m
.50625 .07725 L
s
[(0.25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(0.75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(1)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(1.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(1.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(1.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(115) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04991 m
.03279 .06191 L
.04262 .08046 L
.04758 .09279 L
.05288 .1086 L
.06244 .14421 L
.07283 .19121 L
.0841 .24428 L
.08927 .26592 L
.09475 .28496 L
.09943 .297 L
.10071 .29952 L
.10209 .30182 L
.10339 .30362 L
.10458 .30491 L
.10522 .30547 L
.10591 .30597 L
.10664 .30637 L
.10733 .30664 L
.10798 .30678 L
.10866 .30683 L
.10988 .30664 L
.11057 .30637 L
.11131 .30597 L
.11201 .30546 L
.11265 .30491 L
.1142 .30315 L
.11568 .30097 L
.1183 .29592 L
.12073 .28996 L
.12622 .27245 L
.14603 .18348 L
.15501 .14321 L
.16469 .10728 L
.17023 .09091 L
.17532 .07847 L
.18014 .06867 L
.18529 .06001 L
.19509 .04738 L
.20422 .03883 L
.20979 .03485 L
.21253 .03324 L
.21506 .03199 L
.21731 .03105 L
.21979 .03023 L
.22099 .02991 L
.22228 .02963 L
.22299 .02951 L
.22364 .02941 L
.22492 .02926 L
Mistroke
.22621 .02918 L
.22742 .02916 L
.22852 .02919 L
.2297 .02928 L
.23099 .02943 L
.23164 .02954 L
.23235 .02967 L
.23479 .03026 L
.23707 .03102 L
.23952 .03203 L
.24394 .03437 L
.24952 .03818 L
.25479 .0426 L
.26468 .05321 L
.27436 .06767 L
.27924 .07721 L
.28463 .09 L
.29414 .1194 L
.30306 .155 L
.32157 .24146 L
.32664 .26306 L
.33206 .2825 L
.33469 .29019 L
.33716 .29621 L
.33939 .30053 L
.3418 .30397 L
.34305 .30524 L
.34422 .30609 L
.3455 .30665 L
.34622 .3068 L
.34688 .30682 L
.3482 .30657 L
.34895 .30624 L
.34964 .30582 L
.3509 .30475 L
.35225 .30322 L
.35461 .29953 L
.35683 .29497 L
.36188 .28089 L
.36717 .2615 L
.37203 .24065 L
.38299 .18883 L
.39212 .1473 L
.40189 .11019 L
.4075 .09315 L
.41261 .08029 L
.41745 .07017 L
.42258 .06128 L
.43255 .04811 L
.44174 .03929 L
Mistroke
.44685 .0355 L
.45164 .0327 L
.45433 .03145 L
.45689 .03051 L
.4583 .03009 L
.45984 .02972 L
.46123 .02946 L
.46253 .02928 L
.46382 .02918 L
.46447 .02915 L
.46518 .02913 L
.46644 .02916 L
.46761 .02924 L
.46833 .02932 L
.469 .0294 L
.47027 .02962 L
.47163 .02992 L
.47311 .03032 L
.47562 .03119 L
.47828 .03235 L
.48307 .03503 L
.49192 .04176 L
.50168 .05188 L
.5066 .05834 L
.51178 .06649 L
.52104 .08571 L
.53101 .11508 L
.5419 .15831 L
.55285 .20956 L
.56317 .25669 L
.56768 .27416 L
.57244 .28926 L
.57493 .29548 L
.57767 .30082 L
.57887 .30265 L
.58016 .30425 L
.58137 .30541 L
.58249 .30617 L
.58375 .30667 L
.5849 .30681 L
.58553 .30674 L
.58622 .30657 L
.58746 .30597 L
.58864 .30508 L
.58987 .30379 L
.59208 .30062 L
.59466 .29555 L
.59707 .28957 L
.60253 .27205 L
.62155 .18664 L
Mistroke
.63062 .14561 L
.64024 .10934 L
.64526 .09407 L
.65079 .08007 L
.66053 .0615 L
.66583 .05391 L
.67152 .04716 L
.68183 .03775 L
.68722 .0341 L
.68987 .03264 L
.69234 .0315 L
.69475 .03059 L
.69694 .02994 L
.69819 .02966 L
.69937 .02944 L
.70062 .02927 L
.70132 .02921 L
.70196 .02916 L
.70323 .02912 L
.70442 .02914 L
.70549 .0292 L
.70666 .02932 L
.70793 .02951 L
.70927 .02979 L
.71169 .03045 L
.71392 .03124 L
.71601 .03215 L
.72078 .03476 L
.73072 .04239 L
.74144 .05397 L
.751 .0685 L
.75643 .07937 L
.76147 .09171 L
.77167 .12424 L
.78257 .16988 L
.79223 .21573 L
.80247 .26163 L
.80782 .28114 L
.81065 .2896 L
.8137 .29695 L
.81513 .29975 L
.81649 .30199 L
.81782 .30377 L
.81905 .30506 L
.82021 .30595 L
.82144 .30656 L
.82215 .30674 L
.82281 .30681 L
.82405 .30665 L
.82525 .30615 L
Mistroke
.82638 .30538 L
.82761 .30419 L
.82892 .30254 L
.83161 .29795 L
.83406 .29243 L
.83879 .27848 L
.84326 .2619 L
.86402 .16625 L
.8737 .12574 L
.88396 .09239 L
.89273 .0719 L
.90239 .05593 L
.9125 .04417 L
.92177 .03641 L
.92663 .03337 L
.92941 .03197 L
.93194 .03093 L
.93462 .03008 L
.93609 .02973 L
.93748 .02947 L
.93877 .02929 L
.93996 .02919 L
.94126 .02914 L
.94191 .02914 L
.94263 .02916 L
.94371 .02923 L
.94471 .02933 L
.94581 .02949 L
.94698 .02971 L
.94893 .03019 L
.9511 .03089 L
.95508 .03261 L
.95882 .03471 L
.96717 .04091 L
.97619 .04991 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^@?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hLooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=_ooool0
03Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Oooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`12ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0=_ooool002oooooo1_l00006ooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41005?ooool6o`0000Gooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@01gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01oo
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03Cooooo000jooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000012ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`00>Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000007oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000@_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
7oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool00000=_ooool003[ooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@023ooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@03Kooooo000gooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0@_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL07?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Kooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Ko
oooo000gooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Ooo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0@?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Kooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo000Koooooooo0000<_l0000Looooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Pooooo`00>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo001Nooooo`Ko0000@_ooool6o`0000Oooooo00?o0000ooooooooool0
>?ooool6o`0004?ooooo1Ol0000/ooooo`00G?ooool2o`0000Gooooo0_l0000oooooo`;o00001_oo
ool2o`0000Gooooo0_l0000hooooo`03o`000?oooooooooo00Cooooo0_l0000nooooo`?o00001Ooo
ool2o`0002[ooooo001Jooooo`;o00002Oooool2o`0003_ooooo0_l0000:ooooo`;o00000oooool0
0ol0003oooooooooo`0eooooo`;o00002Oooool2o`0003_ooooo00?o0000ooooooooool02?ooool2
o`0002Sooooo001Iooooo`03o`000?oooooooooo00_ooooo0_l0000hooooo`03o`000?oooooooooo
00cooooo00Co0000oooooooooooo0000=Oooool2o`0000gooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Gooooo001Hooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo0000
03Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool09?ooool005Oooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo00oooooo0ol0000booooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02?o
oooo000Sooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Rooooo`008oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`0Aooooo`;o0000<Oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0=oooool002Cooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool04_ooool2o`00033ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo03Sooooo000Tooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ool00000;oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool0>?ooool002Gooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo02_ooooo00?o0000ooooooooool05?ooool2o`000003ooooool0003ooooo02co
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo03Wo
oooo000Uooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo01Gooooo00Go0000ooooooooooooooooo`00000/ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0jooooo`00
9_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
7_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ob4Q8Oooool00oooool5o`0000Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`05o`000?ooooooooooooooool00000:oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0>_ooool0
02Kooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
01kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?lQ8B7ooooo00?ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`0kooooo`009oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool07Oooool01Ol@413ooooooooooooooooo410@00Cooooo00?o
0000ooooooooool01Oooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0kooooo`009oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07Oooool01Ol0003ooooooooooooo
oooo000000Cooooo00?o0000ooooooooool01_ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol00002ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03cooooo000Xooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Mooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`08ooooo`03ogMgMomVIVKooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
??ooool002Sooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo01cooooo00Go410@oooooooooooooooooa0@4003ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0??ooool002Wooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo01_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`03o`00
0?oooooooooo00Kooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0mooooo`00:_ooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool06oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00;ooooo00?o0000ooooooooool01_ooool01OnHV9So410@o`000?lQ8B7oc<c<
00Cooooo1?l00006ooooo`;o00001Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0mooooo`00:_ooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0?Oooool002[ooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03kooooo
000[ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`0nooooo`00:oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool0?_ooool002_ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool06oooool2o`0000Kooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool0?oooool002_ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo03oooooo000[ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`10ooooo`00;?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool0@?ooool002cooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo043ooooo000/ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
01cooooo0_l00008ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo047ooooo000]ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`11ooooo`00;Oooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0@Oooool002gooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04;ooooo000]
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo01gooooo0_l00009ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04;ooooo000^oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`12oooo
o`00;_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool0@_ooool002kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Zooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo04?ooooo000^ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool0@oooool002oooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`0000[ooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool0@oooool002oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
04?ooooo000_ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000<oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo04?ooooo000_ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400<
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`14
ooooo`00;oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0A?ooool0
033ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool01Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006
ooooo`;o00003?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`14ooooo`00<?ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo02cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Poooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0]oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0A?ooool0033ooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04Gooooo000`ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`15ooooo`00<?oo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0Qooooo`;o00003?ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`15ooooo`00<Oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0AOooool0
037ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
04Gooooo000aooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`16ooooo`00<Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0A_ooool003;ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool08_ooool2o`0000gooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0A_ooool003;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo04Kooooo000booooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`16ooooo`00<_ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool0Aoooool003?ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
<oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Oooooo000cooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo02?ooooo0_l0000>ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Oooooo000cooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`17ooooo`00<oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool03_ooool02?l0
003oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool0
1?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`17ooooo`00=?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool03_ooool02?l0003ooooooooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0B?ooool003Cooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo410@0oooool0
0ol@413oooooooooo`0;ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3
o`0000kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0B?ooool003Cooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo00gooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo00cooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0B?ooool003Cooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00cooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo00cooooo00?oEEEEolc<c?ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`18ooooo`00=Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool03?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool03?oo
ool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`18ooooo`00=Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool03?ooool02Ol0003oooooooooooooooooMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0BOooool003Gooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00cooooo00Wo0000oooooooo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`;o00004?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`19ooooo`00=Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool0BOooool003Gooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo04Wooooo000fooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03So
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`19ooooo`00=_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0iooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0B_ooool003Kooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool09Oooool2o`0001;ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0iooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0B_ooool003Kooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0>Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04[ooooo000foooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1:oooo
o`00=oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03[ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0Boooool003Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0jooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo04_ooooo000gooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0??oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Oooooo0_l0000Cooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo04_ooooo000hooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0??ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1;ooooo`00>?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
03cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0C?ooool003Sooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo04cooooo000iooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Sooooo
0_l0000Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo04gooooo000iooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0@?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`1=ooooo`00>_ooool01Ol0003ooooooooooooo
oooo000004?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Oooooo`Co000000?o
410@ooooooooool00oooool00ol0003oooooooooo`0Eooooo`05o`000?ooooooooooooooool00000
@oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04gooooo000jooooo`;o00000_oo
ool00ol0003oooooooooo`12ooooo`04o`000?ooooooooooo`0002Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Eooooo`04o`000?ooooooooooo`0004Cooooo00?o0000oooooooo
ool00_l0001@ooooo`00>oooool3o`0004Gooooo1?l0000Tooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool05_ooool3o`0004Gooooo0ol0001Aooooo`00Zoooool00ol0003ooooooooo
o`05ooooo`?o0000/_ooool00:_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2b
ooooo`00Zoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;;ooooo002[ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0/_ooool00:Wooooo00?oEEEEofIVI_l00000
1oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooo
oooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;o
oooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000
ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooooooo
ool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool0
0ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002A
ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`04
ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7o
k^k^00Wooooo00?o0000ooooooooool00oooool3o`000;;ooooo002Cooooo`03o`000?oooooooooo
00cooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
0;;ooooo002Cooooo`03o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool00oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0/_ooool009?ooooo00?o0000ooooooooool02_ooool01Ol0003o^[ZjoooooonHV9So410@00Co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2booooo`00TOooool00omEEEGoIVIV
o`00000<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0002cooooo`00
/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool0
0ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?o
oooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000oooooooo
ool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_oo
ool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003o
ooooooooo`2booooo`00VOooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2booooo`00Voooool00ol0003ooooo
ooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;;ooooo
002Kooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`2booooo`00Voooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002b
ooooo`00Voooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2booooo`00Voooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0/_ooool009_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo0;;ooooo002Iooooo`03oeEEEOmVIVKo000000gooooo
1?l00006ooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000
ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooooooo
ool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool0
0ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_oo
ool0097ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2booooo`00Toooool0
0ol0003oooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool03?ooool00onY
ZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002booooo`00Toooool00ol0003o
ooooooooo`0=ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`2booooo`00Toooool00ol0003oooooooooo`0=ooooo`03oeEEEOo<c<cooooo00?ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`00
0?oooooooooo00gooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00[ooooo00Go410@oooooooooooooooo
oc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_ooool0097ooooo00?o
EEEEofIVI_l000003?ooool5o`0000Cooooo1?l00006ooooo`;o0000/oooool00;?ooooo00?o0000
ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooooooo
ool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool0
0ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_oo
ool00:Sooooo1Ol00006ooooo`03o`000?oooooooooo0;;ooooo002Xooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@01_ooool00ol0003oooooooooo`2booooo`00ZOooool00onHV9So8B4Qonk^kP07oooo
o`03o`000?oooooooooo0;;ooooo002Zooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0002booooo`00
Zoooool00omgMgOoIVIVooooo`2jooooo`00[?ooool00ol0003oooooooooo`2iooooo`00Z?ooool0
1Ol0003o^[ZjoooooonHV9So410@0;_ooooo002Xooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0^ooo
ool00?ooooooJOooool00:kooooo00?o0000okZj^_ooool0]oooool00:kooooo0_lb<S:hooooo`00
Ooooool2o`000006oa0@4?oooooooooooa0@4?l0003o410@6?ooool4o`000005oa0@4?oooooooooo
oooooom4A4@00_l000001olb<S;ogMgMooooooooooooQhN7o`000?nj^[X03?ooool01OnHV9So0000
o`000?m4A4Co^[Zj01Wooooo1?l000001?l@413oooooooooooooool4o`000005oa0@4?oooooooooo
oooooom4A4@00_l000000olb<S;ogMgMooooo`1gooooo`00P?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Oooooo1_l0000<ooooo`03o`000?oooooooooo00Kooooo00OoMgMgoc8b
<_ooooooooooolc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko0000
3?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool0
Moooool0083ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1fooooo`00P?ooool0
1_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000<ooooo`03o`000?oooooooooo00Kooooo
00?oMgMgoc8b<_ooool04?ooool00ol0003oooooooooo`0;ooooo`Ko00003?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool0Moooool0083ooooo00Ko
0000omgMgOlb<S;oEEEEomgMgOl0000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c00Aooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0N?ooool0083ooooo00Ko0000ohN7
QonYZJWo^[ZjoeEEEOl0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Ooo
ool00ol@413o0000o`000003o`0001cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo07[ooooo0020ooooo`06o`000?lb<S;ooooooooooolb<S;o0000
6oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
N_ooool007oooooo00?o410@o`000?n7QhL00_ooool00on7QhOo0000oa0@400Hooooo`03oeEEEOmV
IVKo000000Gooooo1?l0000Booooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000001Ooo
ool00omEEEGoIVIVo`000005ooooo`Co0000NOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-44.3769, -0.160437, \
0.309031, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.01333 0 0.309017 [
[.1001 -0.0125 -9 -9 ]
[.1001 -0.0125 9 0 ]
[.2334 -0.0125 -9 -9 ]
[.2334 -0.0125 9 0 ]
[.3667 -0.0125 -9 -9 ]
[.3667 -0.0125 9 0 ]
[.6333 -0.0125 -6 -9 ]
[.6333 -0.0125 6 0 ]
[.7666 -0.0125 -6 -9 ]
[.7666 -0.0125 6 0 ]
[.8999 -0.0125 -6 -9 ]
[.8999 -0.0125 6 0 ]
[.4875 .07725 -24 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -18 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -24 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1001 0 m
.1001 .00625 L
s
[(-30)] .1001 -0.0125 0 1 Mshowa
.2334 0 m
.2334 .00625 L
s
[(-20)] .2334 -0.0125 0 1 Mshowa
.3667 0 m
.3667 .00625 L
s
[(-10)] .3667 -0.0125 0 1 Mshowa
.6333 0 m
.6333 .00625 L
s
[(10)] .6333 -0.0125 0 1 Mshowa
.7666 0 m
.7666 .00625 L
s
[(20)] .7666 -0.0125 0 1 Mshowa
.8999 0 m
.8999 .00625 L
s
[(30)] .8999 -0.0125 0 1 Mshowa
.125 Mabswid
.12676 0 m
.12676 .00375 L
s
.15342 0 m
.15342 .00375 L
s
.18008 0 m
.18008 .00375 L
s
.20674 0 m
.20674 .00375 L
s
.26006 0 m
.26006 .00375 L
s
.28672 0 m
.28672 .00375 L
s
.31338 0 m
.31338 .00375 L
s
.34004 0 m
.34004 .00375 L
s
.39336 0 m
.39336 .00375 L
s
.42002 0 m
.42002 .00375 L
s
.44668 0 m
.44668 .00375 L
s
.47334 0 m
.47334 .00375 L
s
.52666 0 m
.52666 .00375 L
s
.55332 0 m
.55332 .00375 L
s
.57998 0 m
.57998 .00375 L
s
.60664 0 m
.60664 .00375 L
s
.65996 0 m
.65996 .00375 L
s
.68662 0 m
.68662 .00375 L
s
.71328 0 m
.71328 .00375 L
s
.73994 0 m
.73994 .00375 L
s
.79326 0 m
.79326 .00375 L
s
.81992 0 m
.81992 .00375 L
s
.84658 0 m
.84658 .00375 L
s
.87324 0 m
.87324 .00375 L
s
.07344 0 m
.07344 .00375 L
s
.04678 0 m
.04678 .00375 L
s
.02012 0 m
.02012 .00375 L
s
.92656 0 m
.92656 .00375 L
s
.95322 0 m
.95322 .00375 L
s
.97988 0 m
.97988 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .07725 m
.50625 .07725 L
s
[(0.25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(0.75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(1)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(1.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(1.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(1.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(120) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .03147 m
.02846 .03357 L
.03279 .03615 L
.04262 .04407 L
.0522 .05473 L
.06244 .07082 L
.06788 .08227 L
.07379 .09764 L
.08451 .1344 L
.10458 .22611 L
.10951 .24864 L
.11482 .27033 L
.11974 .28687 L
.12217 .29343 L
.12442 .29846 L
.12692 .30277 L
.12824 .30448 L
.12891 .30519 L
.12964 .30585 L
.13093 .3067 L
.13215 .30714 L
.13333 .30723 L
.13442 .30702 L
.13575 .30638 L
.13698 .30541 L
.13833 .30393 L
.13978 .30188 L
.14275 .29624 L
.14545 .28948 L
.15025 .27408 L
.15536 .25384 L
.16453 .21147 L
.17452 .16397 L
.18529 .11961 L
.19024 .10298 L
.19545 .08819 L
.20476 .06798 L
.21349 .05463 L
.22304 .04406 L
.22833 .03948 L
.23332 .03589 L
.2378 .03329 L
.24031 .03212 L
.24265 .0312 L
.24517 .03044 L
.24651 .03013 L
.24795 .02988 L
.24867 .02978 L
.24945 .02969 L
.25019 .02963 L
Mistroke
.25088 .02959 L
.25217 .02957 L
.2529 .02959 L
.25355 .02963 L
.25485 .02974 L
.25604 .0299 L
.25735 .03014 L
.25873 .03047 L
.26106 .03117 L
.2636 .03216 L
.26886 .03489 L
.27383 .03827 L
.28315 .04651 L
.29318 .05867 L
.29885 .0677 L
.30408 .07797 L
.31373 .10313 L
.32278 .13511 L
.3434 .22953 L
.35326 .2716 L
.35821 .28795 L
.36105 .29529 L
.36362 .30053 L
.36477 .30239 L
.36601 .30408 L
.36718 .30534 L
.36826 .30622 L
.36941 .30686 L
.37067 .30719 L
.37199 .30713 L
.37322 .30671 L
.37437 .30598 L
.37547 .305 L
.37752 .30241 L
.37973 .29856 L
.38214 .29317 L
.38698 .27888 L
.39152 .26191 L
.40189 .21505 L
.41211 .16628 L
.42289 .12141 L
.43251 .09088 L
.43797 .07766 L
.44305 .06763 L
.45198 .05413 L
.46154 .04371 L
.46651 .03944 L
.47177 .03569 L
.47452 .03405 L
.47754 .03251 L
Mistroke
.48032 .03136 L
.48286 .03055 L
.48409 .03024 L
.48543 .02997 L
.4867 .02977 L
.48788 .02964 L
.48858 .02959 L
.48925 .02956 L
.49049 .02955 L
.49118 .02958 L
.49182 .02961 L
.49253 .02967 L
.49327 .02975 L
.49443 .02992 L
.49567 .03016 L
.49791 .03074 L
.50058 .03167 L
.50301 .03273 L
.50782 .03541 L
.51293 .03903 L
.52211 .04742 L
.53198 .05972 L
.5376 .06891 L
.54287 .07952 L
.55272 .10588 L
.56307 .14404 L
.58158 .22994 L
.59114 .27082 L
.59648 .28847 L
.59901 .29501 L
.60134 .29986 L
.60354 .30337 L
.60465 .30472 L
.60587 .30587 L
.6071 .30667 L
.60841 .30714 L
.60966 .3072 L
.61079 .30693 L
.61193 .30636 L
.61298 .30555 L
.61414 .30437 L
.61537 .30277 L
.61765 .2989 L
.61971 .29442 L
.62461 .28041 L
.62977 .26127 L
.63901 .21972 L
.64908 .17154 L
.65985 .12566 L
.67016 .0921 L
Mistroke
.67954 .07055 L
.68406 .06267 L
.68897 .05554 L
.69789 .04536 L
.70733 .03741 L
.71269 .03403 L
.71772 .03165 L
.72043 .03073 L
.72177 .03037 L
.72301 .0301 L
.72413 .0299 L
.72532 .02974 L
.726 .02967 L
.72665 .02962 L
.72785 .02958 L
.72848 .02958 L
.72917 .02959 L
.7299 .02963 L
.73057 .02968 L
.73178 .02982 L
.73308 .03003 L
.7346 .03036 L
.73604 .03075 L
.73875 .03169 L
.74333 .03386 L
.74839 .03704 L
.75865 .04579 L
.76814 .05698 L
.77706 .07148 L
.78175 .08132 L
.78689 .09428 L
.79724 .12833 L
.81574 .21121 L
.82582 .2573 L
.83077 .27639 L
.83534 .29059 L
.8379 .2968 L
.8406 .30188 L
.84201 .30387 L
.84332 .30532 L
.84406 .30596 L
.84476 .30645 L
.84557 .30687 L
.84631 .30712 L
.84751 .30724 L
.84879 .30699 L
.84999 .3064 L
.85108 .30556 L
.85237 .30422 L
.85376 .30234 L
Mistroke
.85629 .29782 L
.85867 .2923 L
.86122 .28514 L
.86581 .26934 L
.87626 .22375 L
.89733 .12801 L
.90752 .09414 L
.91328 .07962 L
.9186 .06877 L
.92837 .05385 L
.9333 .0481 L
.93873 .04275 L
.94332 .03893 L
.94814 .03556 L
.95232 .0332 L
.95677 .0313 L
.95929 .03052 L
.96158 .03001 L
.96268 .02984 L
.96388 .0297 L
.96501 .02963 L
.96605 .0296 L
.96726 .02962 L
.9684 .02968 L
.96964 .02982 L
.97034 .02992 L
.97098 .03002 L
.97365 .03064 L
.97619 .03147 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^@?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hLooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=_ooool0
03Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Oooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`12ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0=_ooool002oooooo1_l00006ooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41005?ooool6o`0000Gooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@01gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01oo
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03Cooooo000jooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000012ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`00>Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000007oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000@_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
7oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool00000=_ooool003[ooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@023ooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@03Kooooo000gooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0@_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL07?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Kooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Ko
oooo000gooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Ooo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0@?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Kooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo000Koooooooo0000<_l0000Looooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Pooooo`00>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo001Vooooo`Go0000@oooool6o`0004;ooooo1_l00012ooooo`Ko0000
9?ooool002?ooooo0_l0000nooooo`?o00001?ooool3o`0003kooooo0ol00005ooooo`;o0000?ooo
ool2o`0000Gooooo0ol0000nooooo`?o00001?ooool00ol0003oooooooooo`0Rooooo`009Oooool0
0ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`06ooooo`04o`000?oooooo0000o`0003cooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02[ooooo000Vooooo`03o`000?oooooo
oooo03Sooooo00?o0000ooooooooool02_ooool2o`0003Sooooo0_l00009ooooo`05o`000?oooooo
ooooooooool00000>Oooool2o`0000cooooo00?o0000ooooooooool0=oooool2o`0002gooooo000W
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0d
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0]
ooooo`00:?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`09ooooo`;o00001?ooool00ol0003oooooooooo`0coooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0^oooo
o`00:Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool0;oooool002[ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo02oooooo000[ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`0`ooooo`00:oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool0<?ooool002cooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool03Oooool2o`00
00Sooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool0<Oooool002gooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo03;ooooo000]ooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Gooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo03?ooooo000^ooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Gooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Ol0003oooooodA4A007ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0cooooo`00;_ooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05_ooool01Ol@
413ooooooooooooooooo410@00cooooo00?o0000ob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=?ooool002oooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Gooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?ooooooV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8boooo
o`04ooooo`?o00002_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0eooooo`00<?ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool05Oooool01Ol0003ooooooooooooo
oooo000000_ooooo00Go0000ooooooooooooMgMgofIVIP04ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Gooooo000`ooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Eooooo`05oa0@
4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Gooooo000aooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Dooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02_ooool2o`000004okZj^_ooooooV9RHoa0@40Cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03Kooooo000aoooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Doooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02_ooool01_l0003oV9RHoa0@4?l0003o8B4Qolc<c0Cooooo
1?l00006ooooo`;o00003?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`0fooooo`00<Oooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0=_ooool003;ooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03Kooooo000boooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0foooo
o`00<_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool0=oooool003?ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool04oooool2o`0000kooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
=oooool003?ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo03Oooooo000cooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0hooooo`00=?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool0>?ooool003Cooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo03Sooooo000dooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Cooooo
0_l0000?ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo03Wooooo000dooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0iooooo`00=Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0>Oooool003Gooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo03Wooooo000eooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo01Gooooo0_l0000@ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03[ooooo000eooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0jooooo`00=_oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0>_oo
ool003Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo01Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0jooooo`00=_oo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool05ooo
ool01OmgMgOoV9RHo`000?nHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02[ooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0kooooo`00=_ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool05oooool01Ol@413o0000oooo
oooooooo410@013ooooo00?o0000ooooooooool00oooool3o`00017ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
>oooool003Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo01Oooooo0_l00002ooooo`03o`000?oooooooooo00gooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0:ooo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo03_ooooo000gooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Fooooo`;o00000_ooool0
0ol0003oooooooooo`0:ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0:oooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo03_ooooo000gooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`0Fooooo`05o`000?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0??oo
ool003Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo
oooo01Kooooo00Go0000oiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`0looooo`00=oooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool05_ooool01Ol0003o<S8bo`000?lb
<S;ok^k^00cooooo1?l00006ooooo`;o00004oooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0looooo`00=oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0??ooool0
03Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
03gooooo000hooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0mooooo`00>?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Iooooo`;o00005?ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0mooooo`00>?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0?Oooool003Wooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo03gooooo000iooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0nooooo`00>Oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool0?_ooool003Wooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
6_ooool2o`0001Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0?_ooool003Wooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03kooooo000jooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0oooooo`00>_ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0?oooool003[o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03oo
oooo000jooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo01_ooooo0_l0000Fooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03oooooo
000jooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`10ooooo`00>oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03?ooooo00?o0000
ooooooooool02oooool01Oo^k^ko<S8bo`000?lb<S;o000000Gooooo0_lQ8B46ooooo`03o`000?o^
k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0@?ooool003_ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo00[ooooo00GoMgMgoiRHV?ooooooV9RHo`000005ooooo`;o8B4Q
1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`10ooooo`00>oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool02_ooool01Ol@413ooooooooooooooooo000000gooooo
00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o00005_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`10ooooo`00>oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03Gooooo00?o
0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool0
1_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
@Oooool003cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo00[ooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0@Oooool003cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo00Wooooo00Go410@oooooooooooo0000oa0@400>ooooo`03ojVYZOmgMgOooooo00?o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo047o
oooo000looooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`09ooooo`05ogMgMonHV9Soooooo`000?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
047ooooo000mooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`09ooooo`05onk^k_lb<S;o0000o`000?o^k^h02oooool5o`0000Cooooo1?l00006oooo
o`;o00006?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`11ooooo`00?Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0@_ooool003gooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04;ooooo000mooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`12ooooo`00?Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0@_ooool0
03kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool07_ooool2o`0001Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0@_ooool003ko
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04?o
oooo000nooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0>_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`13ooooo`00?_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03[ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0@oooool003oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo04?ooooo000oooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0??ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01oooooo0_l0000Joooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo04Cooooo000oooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0??ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03cooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`14ooooo`00@?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo03cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0mooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0A?ooool0043ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Cooooo0010ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo027ooooo0_l0000Kooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0?_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo04Gooooo0010ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
043ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`15ooooo`00@Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Gooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo04Kooooo0012ooooo`03o`000?oooooooooo00;o0000@oooool01Ol0003ooooo
oooooooooooo000001cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Looooo`05
o`000?ooooooooooooooool00000@oooool2o`0000;ooooo00?o0000ooooooooool0Aoooool004;o
oooo1?l00015ooooo`?o00007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01go
oooo1?l00014ooooo`Co0000BOooool00:_ooooo00?o0000ooooooooool01Oooool3o`000;;ooooo
002[ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/_ooool00:_ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2booooo`00Zoooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0;;ooooo002Yooooo`03oeEEEOmVIVKo000000Oooooo00?o0000oooooooo
ool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool0
0ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?o
oooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o
0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_oo
ool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?o
oooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00TOooool4o`000003oa0@4?oo
oooooooo00;ooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo
00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool01?ooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
/_ooool009?ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oo
oooooooo00?ooooo0ol0002booooo`00Toooool00ol0003oooooooooo`0<ooooo`03oiRHV?lQ8B7o
k^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2booooo`00Toooool00ol0
003oooooooooo`0=ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005
ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03
o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0/_ooool0097ooooo00?oEEEEofIVI_l000003?ooool01OnHV9So
410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000/oooool00;?ooooo00?o0000oooooooo
ool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_oo
ool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooooooo
o`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oo
oooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool009Wo
oooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0/_ooool009_ooooo00?o0000ooooooooool01?ooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2booooo`00Voooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/_ooool009_ooooo00?o
0000ooooooooool03_ooool00omgMgOo<S8booooo`04ooooo`?o0000/_ooool009_ooooo00?o0000
ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/_oo
ool009_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0;;ooooo002Kooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`2booooo`00VOooool00omEEEGoIVIVo`00000=ooooo`Co00001_ooool00ol0003o
ooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o
0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_oo
ool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?o
oooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooooooo
o`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2boooo
o`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002Aooooo`Co000000?o
410@ooooooooool00_ooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool01?oo
ool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00cooooo00?oZJVYoeEEEOooool02?ooool0
0ol0003oooooooooo`03ooooo`?o0000/_ooool009?ooooo00?o0000ooooooooool03Oooool00olQ
8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/_ooool009?o
oooo00?o0000ooooooooool03Oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`0=ooooo`03
ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2booooo`00
Toooool00ol0003oooooooooo`0:ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo0;;ooooo002Aooooo`03oeEEEOmVIVKo000000cooooo
1Ol00004ooooo`Co00001_ooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_oo
ool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?o
oooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooooooo
o`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2boooo
o`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002Xooooo`Go00001_oo
ool00ol0003oooooooooo`2booooo`00Z?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o
0000ooooooooool0/_ooool00:Wooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`2b
ooooo`00Z_ooool00onHV9So8B4Qonk^kP06ooooo`?o0000/_ooool00:_ooooo00?oMgMgofIVI_oo
ool0^_ooool00:cooooo00?o0000ooooooooool0^Oooool00:Sooooo00Go0000okZj^_ooooooV9RH
oa0@402kooooo`00Z?ooool01OnHV9So410@o`000?lQ8B7oc<c<0;_ooooo003oooooofWooooo002^
ooooo`03o`000?nj^[[ooooo0;Oooooo002^ooooo`;o<S8b^?ooool007oooooo0_l000001_l@413o
ooooooooool@413o0000oa0@41Sooooo1?l000001Ol@413oooooooooooooooooA4A400;o000000Oo
<S8bomgMgOooooooooooohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Ioooo
o`Co000000?o410@ooooooooool01Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0NOooool0
083ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00003?ooool00ol0
003oooooooooo`06ooooo`07ogMgMolb<S;oooooooooooo<c<co0000oa0@400<ooooo`05oa0@4?nj
^[[ok^k^ogMgMol@41002Oooool6o`0000cooooo00?o0000ooooooooool00_ooool01OnHV9So8B4Q
onk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1iooooo`00P?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00oooool00onHV9So
8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@4100NOooool0083ooooo00Ko0000oooooom4
A4CoA4A4ooooool00009ooooo`Ko00003?ooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;o
oooo013ooooo00?o0000ooooooooool02oooool6o`0000cooooo00?o0000ooooooooool01?ooool0
0onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool00000NOooool0083ooooo00Ko0000
omgMgOlb<S;oEEEEomgMgOl0000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c00Aooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01Oooool00omgMgOo
IVIVooooo`02ooooo`05o`000?ooooooooooooooool00000NOooool0083ooooo00Ko0000ohN7QonY
ZJWo^[ZjoeEEEOl0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool0
0ol@413o0000o`000003o`0001cooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooo
oooo410@00?ooooo00?o410@ooooooooool0Moooool0083ooooo00Ko0000oc8b<_oooooooooooc8b
<_l0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo00;ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0NOooool007oooooo00?o410@o`000?n7QhL00_ooool00on7QhOo
0000oa0@400Hooooo`03oeEEEOmVIVKo000000Gooooo1?l0000Booooo`03o`000?oooooooooo01_o
oooo00?oEEEEofIVI_l000001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1iooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-44.3769, -0.160437, \
0.309031, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.01333 0 0.309017 [
[.1001 -0.0125 -9 -9 ]
[.1001 -0.0125 9 0 ]
[.2334 -0.0125 -9 -9 ]
[.2334 -0.0125 9 0 ]
[.3667 -0.0125 -9 -9 ]
[.3667 -0.0125 9 0 ]
[.6333 -0.0125 -6 -9 ]
[.6333 -0.0125 6 0 ]
[.7666 -0.0125 -6 -9 ]
[.7666 -0.0125 6 0 ]
[.8999 -0.0125 -6 -9 ]
[.8999 -0.0125 6 0 ]
[.4875 .07725 -24 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -18 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -24 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1001 0 m
.1001 .00625 L
s
[(-30)] .1001 -0.0125 0 1 Mshowa
.2334 0 m
.2334 .00625 L
s
[(-20)] .2334 -0.0125 0 1 Mshowa
.3667 0 m
.3667 .00625 L
s
[(-10)] .3667 -0.0125 0 1 Mshowa
.6333 0 m
.6333 .00625 L
s
[(10)] .6333 -0.0125 0 1 Mshowa
.7666 0 m
.7666 .00625 L
s
[(20)] .7666 -0.0125 0 1 Mshowa
.8999 0 m
.8999 .00625 L
s
[(30)] .8999 -0.0125 0 1 Mshowa
.125 Mabswid
.12676 0 m
.12676 .00375 L
s
.15342 0 m
.15342 .00375 L
s
.18008 0 m
.18008 .00375 L
s
.20674 0 m
.20674 .00375 L
s
.26006 0 m
.26006 .00375 L
s
.28672 0 m
.28672 .00375 L
s
.31338 0 m
.31338 .00375 L
s
.34004 0 m
.34004 .00375 L
s
.39336 0 m
.39336 .00375 L
s
.42002 0 m
.42002 .00375 L
s
.44668 0 m
.44668 .00375 L
s
.47334 0 m
.47334 .00375 L
s
.52666 0 m
.52666 .00375 L
s
.55332 0 m
.55332 .00375 L
s
.57998 0 m
.57998 .00375 L
s
.60664 0 m
.60664 .00375 L
s
.65996 0 m
.65996 .00375 L
s
.68662 0 m
.68662 .00375 L
s
.71328 0 m
.71328 .00375 L
s
.73994 0 m
.73994 .00375 L
s
.79326 0 m
.79326 .00375 L
s
.81992 0 m
.81992 .00375 L
s
.84658 0 m
.84658 .00375 L
s
.87324 0 m
.87324 .00375 L
s
.07344 0 m
.07344 .00375 L
s
.04678 0 m
.04678 .00375 L
s
.02012 0 m
.02012 .00375 L
s
.92656 0 m
.92656 .00375 L
s
.95322 0 m
.95322 .00375 L
s
.97988 0 m
.97988 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .07725 m
.50625 .07725 L
s
[(0.25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(0.75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(1)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(1.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(1.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(1.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(125) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .03387 m
.02605 .03275 L
.02846 .03174 L
.03053 .03101 L
.03279 .0304 L
.03416 .03012 L
.03543 .02992 L
.03665 .02978 L
.03793 .0297 L
.03908 .02968 L
.04016 .02971 L
.04135 .02979 L
.04262 .02994 L
.04393 .03015 L
.04516 .03041 L
.04793 .0312 L
.05037 .03212 L
.05297 .03333 L
.06244 .03955 L
.06791 .04437 L
.07382 .05071 L
.07904 .05748 L
.08454 .06618 L
.08952 .07579 L
.09498 .08867 L
.10458 .11826 L
.12572 .21107 L
.13574 .25686 L
.14014 .27404 L
.145 .28955 L
.14724 .2952 L
.14964 .30015 L
.15097 .30233 L
.15219 .30399 L
.15335 .30525 L
.15457 .30624 L
.15582 .30688 L
.15652 .30708 L
.15715 .30717 L
.15838 .30705 L
.15955 .30661 L
.16021 .30621 L
.1609 .30569 L
.16216 .30445 L
.1635 .30272 L
.16498 .30034 L
.1697 .28962 L
.17476 .27337 L
.18391 .23496 L
.20366 .143 L
Mistroke
.20907 .12174 L
.21483 .10235 L
.22519 .07588 L
.23036 .06615 L
.23594 .05763 L
.24606 .04591 L
.25085 .04155 L
.2559 .03763 L
.26055 .03464 L
.26495 .0324 L
.26733 .03144 L
.26992 .03063 L
.27107 .03034 L
.27228 .0301 L
.27331 .02993 L
.27445 .02979 L
.27577 .02969 L
.27698 .02965 L
.27762 .02966 L
.27831 .02968 L
.27903 .02972 L
.2797 .02978 L
.28095 .02994 L
.28209 .03013 L
.28463 .03073 L
.28699 .03151 L
.28916 .0324 L
.29407 .03498 L
.30297 .04159 L
.31269 .05167 L
.32178 .06472 L
.32699 .07449 L
.33174 .08527 L
.34243 .11736 L
.3631 .20761 L
.3722 .24989 L
.37703 .26961 L
.38224 .28714 L
.38467 .29366 L
.38723 .29923 L
.38942 .30286 L
.39066 .30444 L
.39181 .30559 L
.39298 .30644 L
.39409 .30694 L
.39508 .30715 L
.39616 .30711 L
.39733 .30675 L
.39857 .30601 L
.39964 .30509 L
Mistroke
.4008 .30377 L
.40337 .29979 L
.40572 .29489 L
.411 .27983 L
.42054 .24167 L
.44115 .14559 L
.45118 .10789 L
.46027 .08254 L
.46485 .0727 L
.4698 .0639 L
.47877 .05162 L
.48904 .04147 L
.49848 .03476 L
.50319 .03237 L
.50582 .03134 L
.50823 .03061 L
.51046 .03011 L
.51173 .02991 L
.5129 .02978 L
.51392 .02971 L
.51504 .02967 L
.51622 .02969 L
.51732 .02975 L
.51853 .02987 L
.51985 .03007 L
.52123 .03035 L
.52251 .03067 L
.52481 .0314 L
.52727 .03238 L
.53289 .0354 L
.53799 .039 L
.54798 .0484 L
.55719 .06041 L
.562 .0685 L
.5673 .0793 L
.57799 .10874 L
.58816 .14723 L
.59745 .1896 L
.6083 .24103 L
.61358 .26359 L
.61835 .281 L
.62064 .28801 L
.6231 .29448 L
.62524 .29907 L
.62757 .30296 L
.62886 .30458 L
.63006 .30575 L
.63133 .30661 L
.63204 .30692 L
.63269 .3071 L
Mistroke
.63385 .30718 L
.6351 .3069 L
.63629 .3063 L
.63739 .30544 L
.63858 .30419 L
.63986 .30247 L
.64218 .29844 L
.64493 .29215 L
.64746 .28505 L
.65813 .24391 L
.67871 .14784 L
.68874 .10968 L
.69783 .08384 L
.7024 .07381 L
.70734 .06481 L
.7163 .05226 L
.72656 .04191 L
.73601 .03508 L
.7407 .03262 L
.74334 .03155 L
.74574 .03078 L
.74797 .03024 L
.74923 .03002 L
.7504 .02986 L
.75142 .02977 L
.75255 .02971 L
.75372 .0297 L
.75482 .02974 L
.75603 .02984 L
.75735 .03001 L
.75873 .03025 L
.76001 .03055 L
.76231 .03122 L
.76476 .03215 L
.77038 .03504 L
.77548 .03854 L
.78546 .04769 L
.79466 .05944 L
.79947 .06733 L
.80476 .07788 L
.81545 .1067 L
.82561 .14452 L
.83489 .18648 L
.84573 .23799 L
.851 .26088 L
.85578 .27876 L
.85806 .28603 L
.86052 .29281 L
.86265 .2977 L
.86499 .30194 L
Mistroke
.86627 .30376 L
.86747 .30512 L
.86874 .30619 L
.86945 .30662 L
.8701 .30691 L
.87125 .30718 L
.87251 .30711 L
.8737 .3067 L
.87479 .30602 L
.87598 .30497 L
.87726 .30346 L
.87958 .2998 L
.88233 .29391 L
.88485 .28716 L
.89553 .24703 L
.91609 .15092 L
.9261 .1121 L
.93519 .08562 L
.93975 .07533 L
.94469 .06608 L
.95365 .05319 L
.9639 .04257 L
.97334 .03551 L
.97619 .03387 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^@?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hLooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=_ooool0
03Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Oooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`12ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0=_ooool002oooooo1_l00006ooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41005?ooool6o`0000Gooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@01gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01oo
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03Cooooo000jooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000012ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`00>Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000007oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000@_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
7oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool00000=_ooool003[ooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@023ooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@03Kooooo000gooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0@_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL07?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Kooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Ko
oooo000gooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Ooo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0@?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Kooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo000Koooooooo0000<_l0000Looooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Pooooo`00>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo000Uooooo`Go0000@oooool6o`00043ooooo00?o0000ooooool00000
1Ol00013ooooo`Go0000IOooool002?ooooo0ol00004ooooo`?o0000?_ooool2o`0000Gooooo0ol0
000nooooo`?o00001Oooool2o`0003oooooo0ol00004ooooo`;o0000?_ooool00ol0003ooooooooo
o`0Rooooo`00;Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0>_ooool2o`0000Wooooo0_l0000kooooo`;o00002Oooool2o`0003_ooooo0_l0000T
ooooo`00;_ooool00ol0003oooooooooo`0gooooo`;o00003?ooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooo000000_ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09?ooool002oooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03Kooooo00Co0000oooooooo
oooo00003?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`0Uooooo`00<?ooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0=?ooool01?l0003oooooooooooooool2o`00
00cooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool09_ooool0037ooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo02Oooooo000booooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Xooooo`00<_ooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0;oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0:?ooool003?ooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02Wooooo000doooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo00Gooooo0_l0000?ooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02[ooooo000eooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0[ooooo`00
=Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
4?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool3o`000003
oc8b<_oMgMgooooo00Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0[ooooo`00
=_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
3oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@00oooool01_l0003oooooooooooooooooMgMgoc8b<PGooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`0/ooooo`00=_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool03_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0]ooooo`00=_ooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool03_ooool01Ol0003ooooooooooooo
oooo000000gooooo00?oV9RHob4Q8Oo^k^h00_ooool00ol0003oooooooooo`02ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol0000Aooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02gooooo000gooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0=ooooo`05o`000?oooooo
ooooooooool000003_ooool02omgMgOoIVIVoooooooooooo0000ooooool0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0^ooooo`00=oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool03Oooool01Ol@
413ooooooooooooooooo410@00oooooo00Ko0000oooooooooooo0000ooooool00009ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool0;_ooool003Sooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00gooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`07o`000?nj^[[ooooooiRHV?l@413oooooo`000002ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0^ooooo`00>?ooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool03Oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00OoV9RHoa0@4?l0003o8B4Qolc<c?oooooo000000;ooooo1?l0
0006ooooo`;o00005?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`0_ooooo`00>Oooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0;oooool003Wooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo02oooooo000iooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0`ooooo`00
>_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
<?ooool003[ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool03?ooool2o`0001Kooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0<?oo
ool003[ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo037ooooo000kooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`0aooooo`00>oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool0<Oooool003_ooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo03;ooooo000kooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00gooooo0_l0
000Gooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo03;ooooo000looooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0booooo`00??ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0<_ooool003cooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03?ooooo000looooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo00kooooo0_l0000Hooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03?ooooo000looooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0cooooo`00?Oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0<oooool0
03gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`03o`000?lQ8B7o8B4Q00Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0=?oo
ool003gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03o`000?lQ8B7o8B4Q00Sooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo03Cooooo000m
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0@
ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00?ooooo0ol0000Hooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0:ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03Cooooo000mooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0?ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`09ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02cooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0dooooo`00?_ooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool03oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool01_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02cooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0eooooo`00?_ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool03oooool01Ol@413ooooooooo
oooooooo410@00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0/ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0=Oooool003kooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00oooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo03Gooooo000nooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0_ooool00ol0003oooooooooo`07ooooo`Co00001_ooool2o`0001_ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
=Oooool003oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo03Gooooo000oooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0fooooo`00?oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0=_ooool003oooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0^ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool04Oooool2o`0001_o
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool0=_ooool003oooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo03Kooooo0010ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0fooooo`00@?ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0=oooool0043ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03Oooooo0010ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo01;ooooo0_l0000Mooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03Oooooo0010ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0gooooo`00@Ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0=ooo
ool0047ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo03Sooooo0011ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0hooooo`00@Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Cooooo`;o00007_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0hooooo`00@_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0>?ooool004;ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
00?o0000ooooooooool00oooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Sooooo0012ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@03o`000?oooooooooo00?ooooo00?oEEEEojVYZOoo
ool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0>Oooool004;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4007ooooo`03o`000?oooooooooo00?o
oooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o00007Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0iooooo`00@_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooooooo
ool01?ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0iooooo`00@oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo03Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool01Oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03Wooooo0013ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`05ooooo`03ojVYZOmgMgOooooo
00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
03Wooooo0013ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool0>_ooool004?ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0gooooo`09o`000?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo
00?o0000ooooooooool00_ooool5o`0000Cooooo1?l00006ooooo`;o00007oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0jooooo`00@oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Oooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0>_ooool004Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo03[ooooo0014ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0>Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0kooooo`00A?ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0iooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0>oooool004Gooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
5oooool2o`00023ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0iooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0>oooool004Gooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03_ooooo0015ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0looooo`00A_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0??ooool004Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03co
oooo0016ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0??ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo01Sooooo0_l0000Rooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03cooooo
0017ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0?Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0mooooo`00Aoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0?Oooool004Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0moooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo03gooooo0017ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Wooooo0_l0000Sooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo03kooooo0018ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
?oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0nooooo`00BOooool01Ol0003ooooooooooooooooo000004?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0@ooooo`Co000000?o410@ooooooooool0
0oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
@?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03oooooo0019ooooo`05o`000?oo
ooooooooooooool00000@oooool01Ol0003ooooooooooooooooo000001Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Tooooo`04o`000?ooooooooooo`0004Cooooo00Co0000oooo
oooooooo0000@_ooool004[ooooo0ol00015ooooo`Co00005Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo02Cooooo1?l00015ooooo`?o0000@_ooool00:_ooooo00?o0000oooooooo
ool01Oooool3o`000;;ooooo002[ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
/_ooool00:_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2booooo`00Zoooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;;ooooo002Yooooo`03oeEEEOmVIVKo0000
00Oooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003ooooo
ooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2b
ooooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`00
0?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooo
oooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo
00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000
ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00
TOooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000
o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool0
1?ooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool02oooool00onHV9So8B4Q
onk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0002booooo`00Toooool00ol0003ooooooooo
o`0<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`2booooo`00Toooool00ol0003oooooooooo`0=ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0;;ooooo002Cooooo`03o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@4004
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_ooool0097ooooo00?oEEEEofIV
I_l000003?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000/oooool0
0;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo
00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002c
ooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00
/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooo
oooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;o
oooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000
ooooooooool0/_ooool009Wooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/_ooool009_ooooo00?o0000oooo
ooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2boooo
o`00Voooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0/_ooool009_ooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`04ooooo`?o0000
/_ooool009_ooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool0/_ooool009_ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0;;ooooo002Kooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`2booooo`00VOooool00omEEEGoIVIVo`00000=oooo
o`Co00001_ooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`00
0?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooo
oooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo
00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000
ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00
/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool0
0ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;o
oooo002Aooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Kooooo00?o0000onk^k_ooool0
1?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/_ooool009?ooooo
00?o0000ooooooooool01?ooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00cooooo00?o
ZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000/_ooool009?ooooo00?o0000
ooooooooool03Oooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool0/_ooool009?ooooo00?o0000ooooooooool03Oooool00omEEEGoc<c<ooooo`03oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2booooo`00Toooool00ol0
003oooooooooo`0=ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`0:ooooo`05oa0@4?oooooooooooooo
oolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;;ooooo002Aooooo`03
oeEEEOmVIVKo000000cooooo1Ol00004ooooo`Co00001_ooool2o`000;?ooooo002cooooo`03o`00
0?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooo
oooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo
00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000
ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00
/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool0
0ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;o
oooo002Xooooo`Go00001_ooool00ol0003oooooooooo`2booooo`00Z?ooool01OnHV9So8B4Qonk^
k_ooooooA4A400Kooooo00?o0000ooooooooool0/_ooool00:Wooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00ol0003oooooooooo`2booooo`00Z_ooool00onHV9So8B4Qonk^kP06ooooo`?o0000/_ooool0
0:_ooooo00?oMgMgofIVI_ooool0^_ooool00:cooooo00?o0000ooooooooool0^Oooool00:Sooooo
00Go0000okZj^_ooooooV9RHoa0@402kooooo`00Z?ooool01OnHV9So410@o`000?lQ8B7oc<c<0;_o
oooo003oooooofWooooo002^ooooo`03o`000?nj^[[ooooo0;Oooooo002^ooooo`;o<S8b^?ooool0
07oooooo0_l000001_l@413oooooooooool@413o0000oa0@41Sooooo1?l000001Ol@413ooooooooo
ooooooooA4A400;o000000Oo<S8bomgMgOooooooooooohN7Qol0003o^[Zj00cooooo00GoV9RHo`00
0?l0003oA4A4okZj^P0Iooooo`Co000000?o410@ooooooooool01Ol00004ooooo`05odA4A?l0003o
0000oc8b<_oMgMd0N?ooool0083ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07
ooooo`Ko00003?ooool00ol0003oooooooooo`06ooooo`07ogMgMolb<S;oooooooooooo<c<co0000
oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000cooooo00?o0000oooooooo
ool00_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0Moooool0083o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00?o
oooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`1fooooo`00P?ooool01_l0003ooooo
odA4A?m4A4Coooooo`0000Wooooo1_l0000<ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b
<_ooool04?ooool00ol0003oooooooooo`0;ooooo`Ko00003?ooool00ol0003oooooooooo`04oooo
o`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0Moooool0083ooooo00Ko0000omgMgOlb
<S;oEEEEomgMgOl0000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Aooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01Oooool00omgMgOoIVIVoooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0N?ooool0083ooooo00Ko0000ohN7QonYZJWo^[Zj
oeEEEOl0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol@413o
0000o`000003o`0001cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo07[ooooo0020ooooo`06o`000?lb<S;ooooooooooolb<S;o00006oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`02ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`1j
ooooo`00Ooooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo00?oEEEEofIV
I_l000001Oooool4o`0001;ooooo00?o0000ooooooooool06oooool00omEEEGoIVIVo`000004oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0007Wooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-44.3769, -0.160437, \
0.309031, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.01333 0 0.309017 [
[.1001 -0.0125 -9 -9 ]
[.1001 -0.0125 9 0 ]
[.2334 -0.0125 -9 -9 ]
[.2334 -0.0125 9 0 ]
[.3667 -0.0125 -9 -9 ]
[.3667 -0.0125 9 0 ]
[.6333 -0.0125 -6 -9 ]
[.6333 -0.0125 6 0 ]
[.7666 -0.0125 -6 -9 ]
[.7666 -0.0125 6 0 ]
[.8999 -0.0125 -6 -9 ]
[.8999 -0.0125 6 0 ]
[.4875 .07725 -24 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -18 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -24 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1001 0 m
.1001 .00625 L
s
[(-30)] .1001 -0.0125 0 1 Mshowa
.2334 0 m
.2334 .00625 L
s
[(-20)] .2334 -0.0125 0 1 Mshowa
.3667 0 m
.3667 .00625 L
s
[(-10)] .3667 -0.0125 0 1 Mshowa
.6333 0 m
.6333 .00625 L
s
[(10)] .6333 -0.0125 0 1 Mshowa
.7666 0 m
.7666 .00625 L
s
[(20)] .7666 -0.0125 0 1 Mshowa
.8999 0 m
.8999 .00625 L
s
[(30)] .8999 -0.0125 0 1 Mshowa
.125 Mabswid
.12676 0 m
.12676 .00375 L
s
.15342 0 m
.15342 .00375 L
s
.18008 0 m
.18008 .00375 L
s
.20674 0 m
.20674 .00375 L
s
.26006 0 m
.26006 .00375 L
s
.28672 0 m
.28672 .00375 L
s
.31338 0 m
.31338 .00375 L
s
.34004 0 m
.34004 .00375 L
s
.39336 0 m
.39336 .00375 L
s
.42002 0 m
.42002 .00375 L
s
.44668 0 m
.44668 .00375 L
s
.47334 0 m
.47334 .00375 L
s
.52666 0 m
.52666 .00375 L
s
.55332 0 m
.55332 .00375 L
s
.57998 0 m
.57998 .00375 L
s
.60664 0 m
.60664 .00375 L
s
.65996 0 m
.65996 .00375 L
s
.68662 0 m
.68662 .00375 L
s
.71328 0 m
.71328 .00375 L
s
.73994 0 m
.73994 .00375 L
s
.79326 0 m
.79326 .00375 L
s
.81992 0 m
.81992 .00375 L
s
.84658 0 m
.84658 .00375 L
s
.87324 0 m
.87324 .00375 L
s
.07344 0 m
.07344 .00375 L
s
.04678 0 m
.04678 .00375 L
s
.02012 0 m
.02012 .00375 L
s
.92656 0 m
.92656 .00375 L
s
.95322 0 m
.95322 .00375 L
s
.97988 0 m
.97988 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .07725 m
.50625 .07725 L
s
[(0.25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(0.75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(1)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(1.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(1.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(1.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(130) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .05546 m
.03279 .04532 L
.04262 .03713 L
.04758 .03402 L
.0503 .03261 L
.05288 .0315 L
.05528 .03067 L
.05655 .03031 L
.05789 .02999 L
.05902 .02977 L
.06026 .02958 L
.06139 .02947 L
.06244 .0294 L
.0631 .02938 L
.06379 .02938 L
.06504 .02941 L
.06581 .02947 L
.06653 .02954 L
.06788 .02972 L
.06917 .02997 L
.07036 .03025 L
.07305 .03106 L
.07529 .03195 L
.07776 .03312 L
.08274 .03611 L
.08819 .04027 L
.09404 .04579 L
.09951 .05208 L
.10458 .05909 L
.11475 .07785 L
.12012 .09104 L
.12582 .10804 L
.14594 .19146 L
.15553 .23678 L
.16077 .25945 L
.16563 .27768 L
.1698 .2903 L
.17194 .29551 L
.17426 .30008 L
.17558 .30217 L
.1768 .30375 L
.17797 .30495 L
.1792 .30587 L
.18031 .30639 L
.18134 .30662 L
.18247 .30658 L
.18369 .3062 L
.18498 .30543 L
.18617 .30436 L
.18748 .30281 L
Mistroke
.18888 .30073 L
.19146 .29576 L
.1938 .29007 L
.20304 .25817 L
.22389 .1616 L
.23328 .1229 L
.24318 .09131 L
.24836 .07865 L
.25404 .06741 L
.26401 .05277 L
.26927 .04691 L
.27424 .04222 L
.28356 .03529 L
.28878 .03248 L
.29126 .03143 L
.29359 .03064 L
.29611 .02999 L
.29744 .02974 L
.29813 .02964 L
.29888 .02955 L
.29962 .02947 L
.30031 .02943 L
.30103 .0294 L
.30181 .02939 L
.30253 .0294 L
.30321 .02943 L
.30449 .02953 L
.30565 .02967 L
.30689 .02988 L
.30913 .03041 L
.3118 .03128 L
.31424 .0323 L
.31953 .03521 L
.32454 .0388 L
.33338 .04711 L
.34301 .05961 L
.35239 .07688 L
.35774 .08979 L
.36276 .10435 L
.38376 .1901 L
.39268 .23239 L
.40221 .27236 L
.40503 .28195 L
.40769 .28977 L
.41028 .29607 L
.41267 .30065 L
.41494 .30384 L
.41608 .305 L
.41734 .30593 L
.41861 .30649 L
Mistroke
.41931 .30664 L
.41996 .30667 L
.42122 .30645 L
.42241 .3059 L
.42367 .30495 L
.42482 .30378 L
.42738 .30006 L
.42975 .29534 L
.43199 .28982 L
.437 .27406 L
.44243 .25271 L
.46352 .1548 L
.47384 .11412 L
.48347 .08566 L
.48832 .07468 L
.49352 .06502 L
.49925 .05641 L
.50454 .0499 L
.51473 .04019 L
.5201 .03626 L
.5258 .03298 L
.52818 .03191 L
.53074 .03095 L
.53315 .03025 L
.53422 .03001 L
.53537 .0298 L
.53664 .02961 L
.53783 .0295 L
.53855 .02945 L
.53923 .02943 L
.54051 .02943 L
.54117 .02946 L
.54186 .0295 L
.54311 .02962 L
.5438 .02972 L
.54445 .02982 L
.54592 .03012 L
.54851 .03083 L
.55091 .03171 L
.55634 .03443 L
.56113 .03763 L
.56623 .04184 L
.57596 .05237 L
.58477 .06562 L
.58967 .0751 L
.59483 .08718 L
.60407 .11502 L
.61401 .15415 L
.62491 .20468 L
.63496 .25107 L
Mistroke
.63991 .27086 L
.64447 .28604 L
.64697 .29279 L
.64972 .29879 L
.65106 .30111 L
.65249 .30317 L
.65329 .30411 L
.65401 .30484 L
.6547 .30542 L
.65543 .30592 L
.6567 .30649 L
.65787 .30668 L
.65859 .30663 L
.65927 .30648 L
.66054 .30589 L
.66176 .30498 L
.66288 .30384 L
.6654 .30021 L
.66786 .29534 L
.6701 .28981 L
.67513 .27396 L
.68422 .23635 L
.69495 .18538 L
.70488 .14086 L
.71395 .1074 L
.72396 .08003 L
.72914 .06941 L
.73402 .06122 L
.74471 .04767 L
.75454 .03883 L
.75948 .03541 L
.76489 .03247 L
.76727 .03147 L
.76952 .0307 L
.77076 .03034 L
.77211 .03002 L
.77323 .02981 L
.77447 .02962 L
.77563 .0295 L
.77672 .02943 L
.77787 .02941 L
.77911 .02944 L
.78025 .02952 L
.78134 .02964 L
.78232 .02979 L
.78339 .02999 L
.78595 .03064 L
.78871 .03162 L
.79373 .03405 L
.79861 .03721 L
Mistroke
.80309 .04078 L
.8133 .05142 L
.81844 .05841 L
.82407 .06777 L
.8343 .09076 L
.84361 .12013 L
.86454 .21204 L
.87381 .25428 L
.87889 .27407 L
.88365 .2891 L
.88612 .29526 L
.88878 .30048 L
.89022 .30267 L
.89174 .30446 L
.89303 .30557 L
.89376 .30603 L
.89445 .30635 L
.89575 .30664 L
.89697 .30655 L
.89808 .30617 L
.89927 .30544 L
.90057 .30426 L
.90195 .30258 L
.90442 .29852 L
.90696 .29298 L
.90937 .28653 L
.91388 .27163 L
.92403 .22846 L
.94235 .14345 L
.95086 .11125 L
.95992 .08502 L
.96765 .06865 L
.97619 .05546 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^@?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hLooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=_ooool0
03Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Oooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`12ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0=_ooool002oooooo1_l00006ooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41005?ooool6o`0000Gooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@01gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01oo
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03Cooooo000jooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000012ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`00>Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000007oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000@_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
7oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool00000=_ooool003[ooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@023ooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@03Kooooo000gooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0@_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL07?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Kooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Ko
oooo000gooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Ooo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0@?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Kooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo000Koooooooo0000<_l0000Looooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Pooooo`00>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo000/ooooo`Ko0000@_ooool6o`0003Wooooo00?o0000ooooooooool0
1oooool5o`0004?ooooo1_l0001Mooooo`00:Oooool3o`0000Gooooo0ol0000nooooo`?o00001Ooo
ool2o`0003Oooooo0_l00005ooooo`?o00001Oooool2o`0003oooooo0_l00006ooooo`?o0000F_oo
ool002Sooooo00?o0000ooooooooool02Oooool2o`0003[ooooo0_l0000:ooooo`;o0000=Oooool0
0ol0003oooooooooo`02ooooo`;o00002_ooool2o`0003_ooooo0_l0000;ooooo`03o`000?oooooo
oooo05Oooooo000Wooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo03;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1G
ooooo`009_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0aooooo`04o`000?ooooooooooo`00013ooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo05Kooooo000Uoooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo033ooooo0ol0000Booooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`1Eooooo`009Oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0`ooooo`;o
00005?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0E?ooool002Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool0;oooool2o`0001Gooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05?ooooo000Sooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Rooooo`00>oooool0
0ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02;ooooo000kooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0/ooooo`?o00005oooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`0Sooooo`00??ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool0:_ooool00ol0003oooooo`00000Iooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02?o
oooo000looooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`08ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05
odA4A?l0003o0000oc8b<_oMgMd00oooool00ol0003oooooo`00000Iooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
02Cooooo000mooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`08ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q
8Oo^k^koooooodA4A007ooooo`05ogMgMolb<S;oooooooooool000000_ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo02Cooooo000mooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`07ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0Uooooo`00?_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool01?mgMgOo<S8booooool00003ooooo`?o00006?ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`0Uooooo`00?_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool0
0oooool01_l0003o8B4Qo`000?lb<S;oc<c<o`0000Cooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0Uooooo`00?oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool01_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0Vooooo`00?oooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool01Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Kooooo0010oooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`05oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1Ol0
0005ooooo`;o00006oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0Wooooo`00@?ooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool09oooool0043ooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo02Oooooo0011ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Xooooo`00
@Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
:?ooool0047ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool01?ooool2o`0001gooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0:?oo
ool0047ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo02Wooooo0011ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0Yooooo`00@_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool0:Oooool004;ooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo02[ooooo0012ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Kooooo0_l0
000Oooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo02[ooooo0013ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0Zooooo`00@oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0:oooool004?ooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02_ooooo0013ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo00Oooooo0_l0000Pooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02_ooooo0014ooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0/ooooo`00A?ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0;?ooool0
04Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
00Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool3o`000003oc8b<_oMgMgo
oooo00Cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0/ooooo`00AOooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool02?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`06o`000?oooooooooooooooomgMgOo<S8b
1Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
:_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02cooooo0015ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`08ooooo`05oa0@4?oo
ooooooooooooool@41002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
0ol0000Pooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0:_ooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo02gooooo0015ooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool0:oooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000
2oooool01_l0003oooooooooooooooooMgMgoc8b<PGooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0]ooooo`00AOooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02_o
oooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000000_ooooo0_l000001?lQ
8B7o0000oc8b<_o<c<`5ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0;Oooool0
04Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
00Oooooo00Go410@oooooooooooooooooa0@400:ooooo`03o`000?oooooo000000Wooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`0]ooooo`00A_ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo02cooooo00?o0000ooooooooool01oooool01OmgMgOoV9RHoooooonHV9So
MgMg00[ooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo02gooooo0016ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`07ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02_ooool00ol0003oooooo`000003
o`0000Kooooo0_l0000Rooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02kooooo0016ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0^ooooo`00Aoooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0;_ooool004Oooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02kooooo
0017ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo00[ooooo0_l0000Sooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02kooooo0018
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0_
ooooo`00B?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0;oooool004Sooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo02oooooo0018ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0_ooooo`00B?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0;ooooo`;o00009?oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0_ooooo`00BOooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool0<?ooool004Wooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo033ooooo0019ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0`ooooo`00BOooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0<?ooool004Wooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool03?ooool2o`0002Gooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0<?ooool004Wooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo037ooooo0019oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<_ooool01Oo^k^ko0000o`000?lb<S;o
k^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^ko000000Cooooo00GoA4A4o`000?l0003o<S8bomgM
g@05ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<Oooool004[ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0booooo`05ogMgMonHV9So0000oiRHV?mgMgL01Ooo
ool2ob4Q8@Kooooo00?oEEEEojVYZOl000001oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0<Oooool004[ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0booooo`05oa0@4?oooooo0000ooooool@41003Oooool00onYZJWo0000oooo
o`08ooooo`03o`000?oooooooooo00?ooooo0ol0000Uooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo037ooooo001:
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0<_ooool01Ol0003oooooo`000?oo
oooo000000kooooo00?o0000ooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0<Oooool004[ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0cooooo`05o`000?oooooo0000ooooool000003_ooool00ol0003oc<c<oooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo03;ooooo001:ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0<ooo
ool01Ol@413oooooo`000?oooooo410@00kooooo00?o0000ogMgMoooool00oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0<_ooool004[ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0cooooo`05ogMgMonHV9Soooooo`000?mgMgL0
2oooool01Ol@413oooooooooool0003o<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo03;ooooo001;ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0<oooool01Oo^k^ko<S8bo`000?l0003ok^k^00_ooooo1Ol00004ooooo`Co
00001_ooool2o`0002Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool0<_ooool004_ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
=oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03;ooooo001;ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo03Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0cooooo`00C?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0<oooool0
04cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
03?ooooo001<ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00oooooo0_l0000Xooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03?o
oooo001=ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0>Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0cooooo`00COooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03[ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0=?ooool004gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo03Cooooo001>ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0dooooo`00C_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo03cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Aooooo`;o
0000:Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0eooooo`00C_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo03cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0mooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0=Oooool004oooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Kooooo001?ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo03gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0fooooo`00Coooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Booooo`;o0000:oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
03gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0gooooo`00Coooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0=oooool0053ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`11ooooo`05o`000?ooooooooooooooool0
00002oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0gooooo`00DOooool01?l0003oooooooooool00014ooooo`04o`000?ooooooooooo`00
00kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0[ooooo`;o000000?oooooo`00
0?ooool0@oooool01Ol0003ooooooooooooooooo000003[ooooo001Aooooo`Co0000AOooool3o`00
00kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0/ooooo`?o0000AOooool3o`00
03_ooooo002[ooooo`03o`000?oooooooooo00Gooooo0ol0002booooo`00Zoooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0;;ooooo002[ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0/_ooool00:_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2b
ooooo`00ZOooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o
0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_oo
ool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooooooo
o`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03
o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oo
oooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?o
oooo00?o0000ooooooooool0/_ooool0097ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q
1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;;o
oooo002Cooooo`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000
/_ooool009?ooooo00?o0000ooooooooool03?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool03Oooool0
0omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`2booooo`00Toooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`0:oooo
o`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0;;ooooo002Aooooo`03oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004
ooooo`Co00001_ooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oo
oooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?o
oooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0
002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2boooo
o`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/ooo
ool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002Iooooo`Co000000?o410@oooo
ooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0;;ooooo002Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/_ooool009_ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo0;;ooooo002Kooooo`03o`000?oooooooooo00kooooo
00?oMgMgoc8b<_ooool01?ooool3o`000;;ooooo002Kooooo`03o`000?oooooooooo00_ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;;ooooo002Kooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2booooo`00Voooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_ooool0
09Wooooo00?oEEEEofIVI_l000003Oooool4o`0000Kooooo00?o0000ooooooooool0/_ooool00;?o
oooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooooooo
o`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03
o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oo
oooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?o
oooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o
0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002coooo
o`00/oooool00ol0003oooooooooo`2booooo`00TOooool4o`000003oa0@4?oooooooooo00;ooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00Cooooo0_lQ8B46ooooo`03oeEE
EOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2booooo`00Tooo
ool00ol0003oooooooooo`0<ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00ooo
ool3o`000;;ooooo002Cooooo`03o`000?oooooooooo00gooooo00?o8B4Qooooooooool01_ooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo
00gooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000
ooooooooool0/_ooool009?ooooo00?o0000ooooooooool03Oooool00onYZJWoMgMgooooo`03oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000oooooooo
ool02_ooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`2booooo`00TOooool00omEEEGoIVIVo`00000<ooooo`Go00001?ooool4o`0000Ko
oooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooooooo
o`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2boooo
o`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oo
oooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?o
oooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o
0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002coooo
o`00/oooool00ol0003oooooooooo`2booooo`00Z?ooool5o`0000Kooooo00?o0000ooooooooool0
/_ooool00:Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0;;ooooo
002Yooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/_ooool00:[ooooo00?oV9RH
ob4Q8Oo^k^h01_ooool3o`000;;ooooo002[ooooo`03ogMgMomVIVKooooo0;[ooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002Xooooo`05o`000?nj^[[ooooooiRHV?l@4100^oooool00:Sooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c02kooooo`00oooooomYooooo`00[_ooool00ol0003o^[Zjoooo
o`2gooooo`00[_ooool2oc8b<[Sooooo001oooooo`;o000000Ko410@oooooooooooo410@o`000?l@
410Hooooo`Co000000Go410@ooooooooooooooooodA4A002o`000007oc8b<_oMgMgooooooooooon7
QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06Oooool4o`000008oa0@4?oooooo
oooooiRHV?l@413o0000oc8b<_o<c<`3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0NOooool0083o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00003?ooool00ol0003o
ooooooooo`06ooooo`07ogMgMolb<S;oooooooooooo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[o
k^k^ogMgMol@41002Oooool6o`0000cooooo00?o0000ooooooooool00_ooool01Ol@413o^[Zjoooo
oomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1iooooo`00P?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01_ooool01Ol0003ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool0Moooool0083ooooo00Ko0000oooooom4A4Co
A4A4ooooool00009ooooo`Ko00003?ooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo
013ooooo00?o0000ooooooooool02oooool6o`0000cooooo00?o0000ooooooooool01Oooool00onY
ZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool00000NOooool0083ooooo00Ko0000omgM
gOlb<S;oEEEEomgMgOl0000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00Aooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01?ooool00ol@413o0000
okZj^P03ooooo`05o`000?ooooooooooooooool00000NOooool0083ooooo00Ko0000ohN7QonYZJWo
^[ZjoeEEEOl0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol@
413o0000o`000003o`0001cooooo00?o0000ooooooooool01Oooool00onj^[[o8B4Qooooo`02oooo
o`05oa0@4?ooooooooooooooool@4100NOooool0083ooooo00Ko0000oc8b<_oooooooooooc8b<_l0
000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo00;ooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0NOooool007oooooo00?o410@o`000?n7QhL00_ooool00on7QhOo0000
oa0@400Hooooo`03oeEEEOmVIVKo000000Gooooo1?l0000Booooo`03o`000?oooooooooo01_ooooo
00?oEEEEofIVI_l000001?ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP1iooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-44.3769, -0.160437, \
0.309031, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.01333 0 0.309017 [
[.1001 -0.0125 -9 -9 ]
[.1001 -0.0125 9 0 ]
[.2334 -0.0125 -9 -9 ]
[.2334 -0.0125 9 0 ]
[.3667 -0.0125 -9 -9 ]
[.3667 -0.0125 9 0 ]
[.6333 -0.0125 -6 -9 ]
[.6333 -0.0125 6 0 ]
[.7666 -0.0125 -6 -9 ]
[.7666 -0.0125 6 0 ]
[.8999 -0.0125 -6 -9 ]
[.8999 -0.0125 6 0 ]
[.4875 .07725 -24 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -18 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -24 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1001 0 m
.1001 .00625 L
s
[(-30)] .1001 -0.0125 0 1 Mshowa
.2334 0 m
.2334 .00625 L
s
[(-20)] .2334 -0.0125 0 1 Mshowa
.3667 0 m
.3667 .00625 L
s
[(-10)] .3667 -0.0125 0 1 Mshowa
.6333 0 m
.6333 .00625 L
s
[(10)] .6333 -0.0125 0 1 Mshowa
.7666 0 m
.7666 .00625 L
s
[(20)] .7666 -0.0125 0 1 Mshowa
.8999 0 m
.8999 .00625 L
s
[(30)] .8999 -0.0125 0 1 Mshowa
.125 Mabswid
.12676 0 m
.12676 .00375 L
s
.15342 0 m
.15342 .00375 L
s
.18008 0 m
.18008 .00375 L
s
.20674 0 m
.20674 .00375 L
s
.26006 0 m
.26006 .00375 L
s
.28672 0 m
.28672 .00375 L
s
.31338 0 m
.31338 .00375 L
s
.34004 0 m
.34004 .00375 L
s
.39336 0 m
.39336 .00375 L
s
.42002 0 m
.42002 .00375 L
s
.44668 0 m
.44668 .00375 L
s
.47334 0 m
.47334 .00375 L
s
.52666 0 m
.52666 .00375 L
s
.55332 0 m
.55332 .00375 L
s
.57998 0 m
.57998 .00375 L
s
.60664 0 m
.60664 .00375 L
s
.65996 0 m
.65996 .00375 L
s
.68662 0 m
.68662 .00375 L
s
.71328 0 m
.71328 .00375 L
s
.73994 0 m
.73994 .00375 L
s
.79326 0 m
.79326 .00375 L
s
.81992 0 m
.81992 .00375 L
s
.84658 0 m
.84658 .00375 L
s
.87324 0 m
.87324 .00375 L
s
.07344 0 m
.07344 .00375 L
s
.04678 0 m
.04678 .00375 L
s
.02012 0 m
.02012 .00375 L
s
.92656 0 m
.92656 .00375 L
s
.95322 0 m
.95322 .00375 L
s
.97988 0 m
.97988 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .07725 m
.50625 .07725 L
s
[(0.25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(0.75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(1)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(1.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(1.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(1.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(135) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .10809 m
.02846 .09386 L
.03279 .08255 L
.03793 .07134 L
.04262 .06295 L
.0522 .04993 L
.05746 .04448 L
.06244 .04015 L
.06754 .03645 L
.07295 .03333 L
.07757 .03135 L
.08019 .03053 L
.08147 .03022 L
.08265 .02998 L
.084 .02977 L
.08472 .02968 L
.08548 .02961 L
.0862 .02957 L
.08689 .02954 L
.08817 .02953 L
.08943 .02959 L
.09059 .02969 L
.09187 .02986 L
.09321 .03011 L
.09602 .03083 L
.09863 .03176 L
.10458 .03474 L
.10959 .03814 L
.11503 .04273 L
.12493 .05371 L
.13457 .06884 L
.14349 .08862 L
.15312 .11811 L
.16215 .15387 L
.17219 .20009 L
.18275 .24897 L
.18741 .26791 L
.19239 .28484 L
.19526 .29264 L
.19786 .29832 L
.19911 .30055 L
.20047 .30258 L
.20174 .30411 L
.20294 .3052 L
.20401 .3059 L
.20516 .30635 L
.20644 .30649 L
.20761 .30628 L
.20883 .30572 L
.20952 .30526 L
Mistroke
.21015 .30472 L
.2114 .30342 L
.21257 .30187 L
.21482 .29801 L
.21686 .29359 L
.22144 .28069 L
.23123 .24224 L
.24156 .1935 L
.25124 .14896 L
.26005 .11444 L
.26955 .08587 L
.27478 .07387 L
.27972 .06459 L
.28852 .05197 L
.29807 .04217 L
.30749 .03527 L
.31008 .03382 L
.31285 .03248 L
.31546 .03144 L
.31788 .03067 L
.32044 .03007 L
.32179 .02985 L
.32255 .02975 L
.32323 .02968 L
.32395 .02963 L
.32462 .02959 L
.32535 .02957 L
.32613 .02957 L
.32743 .02962 L
.32817 .02968 L
.32886 .02975 L
.33016 .02993 L
.33139 .03016 L
.3337 .03074 L
.33619 .03158 L
.3389 .03273 L
.34374 .0354 L
.34829 .03859 L
.35369 .04323 L
.35865 .04836 L
.36875 .06202 L
.37406 .07151 L
.37965 .08378 L
.38918 .11118 L
.39937 .15012 L
.41773 .23508 L
.42796 .27669 L
.43076 .28561 L
.43373 .29353 L
.43626 .29889 L
Mistroke
.43769 .30132 L
.43905 .30321 L
.4403 .30457 L
.44096 .30515 L
.44167 .30566 L
.44291 .30626 L
.44406 .3065 L
.44476 .3065 L
.44552 .30636 L
.44623 .30611 L
.44689 .30577 L
.44814 .30485 L
.44945 .30349 L
.45186 .29999 L
.4541 .29559 L
.45919 .28182 L
.46421 .2639 L
.46966 .24076 L
.47956 .19392 L
.48914 .14976 L
.49812 .11449 L
.50753 .08618 L
.51253 .07462 L
.51791 .06447 L
.52325 .05632 L
.52888 .04935 L
.53414 .04398 L
.53893 .03987 L
.54351 .03654 L
.54848 .03362 L
.55121 .03232 L
.55373 .03134 L
.55614 .03059 L
.55747 .03026 L
.55868 .03002 L
.5598 .02984 L
.56086 .02971 L
.56198 .02962 L
.5632 .02957 L
.56427 .02957 L
.5654 .02962 L
.56647 .0297 L
.56743 .02982 L
.56868 .03002 L
.56982 .03025 L
.57239 .03095 L
.57466 .03175 L
.57705 .03279 L
.58203 .03556 L
.58657 .03877 L
Mistroke
.59675 .04836 L
.60618 .06092 L
.6151 .07761 L
.62479 .10315 L
.63506 .14011 L
.6535 .22436 L
.6629 .26519 L
.66809 .2833 L
.67065 .29058 L
.67302 .29621 L
.67523 .30041 L
.67637 .30215 L
.67759 .3037 L
.67829 .30444 L
.67894 .30502 L
.68021 .30588 L
.68136 .30634 L
.68258 .30649 L
.68362 .30633 L
.68473 .30589 L
.68579 .3052 L
.68675 .30435 L
.68787 .30308 L
.6891 .30138 L
.69132 .29743 L
.69617 .28529 L
.70072 .27 L
.71109 .2254 L
.72132 .17653 L
.73209 .12972 L
.74172 .0968 L
.74682 .08319 L
.75226 .07129 L
.76185 .05567 L
.77077 .04542 L
.781 .03697 L
.78678 .03352 L
.78953 .03222 L
.7921 .03122 L
.79435 .03053 L
.7955 .03025 L
.79676 .02999 L
.79748 .02987 L
.79814 .02977 L
.79944 .02962 L
.80063 .02955 L
.80189 .02952 L
.80259 .02953 L
.80324 .02956 L
.80394 .02961 L
Mistroke
.80469 .02968 L
.80595 .02984 L
.80733 .03009 L
.80988 .03072 L
.81225 .03153 L
.81727 .03386 L
.82272 .03733 L
.83264 .04602 L
.84228 .05794 L
.8512 .07338 L
.86085 .09702 L
.86989 .12724 L
.89051 .21928 L
.90036 .26272 L
.90573 .2819 L
.90835 .28954 L
.91072 .29536 L
.91277 .29946 L
.915 .30287 L
.91622 .30427 L
.91735 .30527 L
.91843 .30594 L
.91957 .30636 L
.92072 .30647 L
.92195 .30624 L
.92311 .30571 L
.92417 .30494 L
.92542 .30371 L
.92677 .30197 L
.92923 .29776 L
.93156 .2926 L
.93407 .28583 L
.93861 .27072 L
.94898 .22638 L
.96997 .13059 L
.97619 .10809 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^@?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hLooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=_ooool0
03Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Oooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`12ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0=_ooool002oooooo1_l00006ooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41005?ooool6o`0000Gooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@01gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01oo
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03Cooooo000jooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000012ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`00>Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000007oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000@_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
7oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool00000=_ooool003[ooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@023ooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@03Kooooo000gooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0@_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL07?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Kooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Ko
oooo000gooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Ooo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0@?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Kooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo000Koooooooo0000<_l0000Looooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Pooooo`00>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo000dooooo`Go0000@oooool6o`00037ooooo00?o0000ooooooooool0
3_ooool5o`0004?ooooo1_l0001Fooooo`00<Oooool3o`0000Cooooo0ol0000nooooo`?o00001Ooo
ool3o`0002oooooo0_l0000<ooooo`?o00001Oooool3o`0003gooooo1?l00005ooooo`?o0000Dooo
ool002oooooo0_l0000:ooooo`;o0000>oooool2o`0000[ooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo053ooooo000^ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0;ooooo`;o0000;?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo04oooooo000^ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1>ooooo`00;?ooool2o`00017ooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Wooooo
0_l00008ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo04gooooo000[ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`1=ooooo`00:oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0C?ooool002[ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04_ooooo000Yooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1:ooooo`00
:?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0Uooooo`;o00001?ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1:ooooo`00:?oo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0BOoo
ool002Oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo01Wooooo00Wo0000ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo04Sooooo000Wooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`0Kooooo`08o`000?ooooooooooogMgMonHV9SooooooiRHV?mg
MgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool01Ol0003ooooooooooooooooo000001gooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo04Oooooo000Wooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0Kooooo`04o`000?oooooooooooa0@40?o
oooo00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`17ooooo`009_ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool06oooool01?l0003oooooooooool00003oooo
o`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04oooo
o`?o000000?oooooo`000?ooool07Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool0Aoooool002Gooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo01gooooo00?o0000ooooool000000oooool00ol0003o
ooooooooo`0<ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005oooo
o`04o`000?ooooooooooo`0001oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo04Kooooo000Uooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo410@00?ooooo00?o410@oooo
ooooool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ool000008Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool0A_ooool002Gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo01kooooo00Oo0000oooooomgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000
okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000008Ooo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0A_oo
ool002Cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo023ooooo00Ko0000onk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`01?ooool4o`0000Kooooo0_l0000Sooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`16ooooo`009?ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Qooooo`;o0000
8oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
AOooool002Cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool08Oooool2o`0002?ooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo04Gooooo000Tooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool0AOooool002?ooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`14ooooo`008oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Pooooo`;o00009?ooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`0Rooooo`00BOooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool07_ooool2o`0002Kooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool08_ooool004[ooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01kooooo0_l0
000Vooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo02;ooooo001:ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0Nooooo`;o00009_ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0R
ooooo`00B_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool07Oooool2o`0002Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool08oooool004[ooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01gooooo0ol0000Vooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo02?ooooo001:ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo000002Oooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
8oooool004_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooool000009oooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Sooooo`00Boooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool06oooool0
0ol0003oooooo`00000Wooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo02?ooooo001;ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Kooooo`04o`000?oooooo0000
o`0002Oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool08oooool004_ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo01_ooooo00?o0000ooooool00000:?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Tooooo`00Boooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool06_ooool01?l0003oooooooooool0000Xooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
02Cooooo001<ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:Oooool02Ol0003o
ooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`00
0?lb<S;ogMgM00;ooooo00Co0000oooooooooooo0000:?ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Tooooo`00
C?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Wooooo00Wo0000oooooooooooo
ooooogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00GoMgMgoc8b<_ooooooooooo`00
0002ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool09?ooool004cooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0Yooooo`05o`000?ooooooooooooooool@41000ooo
ool00ol@413oooooooooo`0>ooooo`04o`000?ooooooooooo`0000;ooooo0ol0000Wooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo02Gooooo001<ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0:_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool03Oooool01OmgMgOo<S8b
oooooooooooo000000;ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo02_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Uooooo`00
C?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02_ooooo00Co0000oooooooooooo
00000oooool00ol0003oooooooooo`0:ooooo`07o`000?lQ8B7o0000oc8b<_o<c<coooooo`000003
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool09Oooool004gooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0[ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@
ooooooooool02_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000:_oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0Uooooo`00COooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo02_ooooo00So0000ooooooooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?o0000oooooooo
ool00oooool01Ol0003ooooooooooooooooo000002[ooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool09_ooool004go
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0[ooooo`08o`000?ooooooooooonk^
k_lb<S;o0000oc8b<_o^k^h<ooooo`Co00000_ooool01?l0003oooooooooooooool2o`0002Wooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool09_ooool004kooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo02Kooooo001>ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0Vooooo`00C_ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0]oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool09oooool004kooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool00_ooool2o`0002[ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool09oooool004oooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02Oooooo001?ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Wooooo`00Coooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool09oooool0
053ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
02Sooooo001@ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo0_l0000[ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02So
oooo001@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0:_ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Xooooo`00D?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02_ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool0:?ooool0057ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo02Wooooo001Aooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Yooooo`00DOooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`04ooooo`;o
0000;?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Yooooo`00DOooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo03?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool0:Oooool0057ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Zooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool00ol0003o8B4Q
ob4Q8@06ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0:_ooool005;ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0[ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003o
8B4Qob4Q8@06ooooo`03oeEEEOnYZJWooooo00Kooooo00?o0000ogMgMolb<S801Oooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo02[ooooo001Booooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0:oooool01Ol@413ooooooooooooooooo410@00Cooooo00?o0000oooooooo
ool01_ooool00onYZJWoEEEEooooo`06ooooo`03o`000?oooooo000000Gooooo0ol0000/ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo02[ooooo001Booooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
:oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool01_ooool00olQ8B7o
ooooooooo`05ooooo`03o`000?mgMgOo<S8b00Gooooo00?o0000ooooooooool0;?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0Zooooo`00D_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02_ooooo
00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00Kooooo00?oEEEEolc<c?oo
ool00oooool3o`000003oc8b<_o<c<cooooo00Cooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0[ooooo`00D_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02cooooo
00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo00Kooooo00?oZJVYogMgMooo
ool00oooool2o`0000Sooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0[ooooo`00
Doooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`03o`000?oooooooooo00?ooooo00Go410@oooooooooooooooooc8b<P04oooo
o`;o00002?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02_ooooo001Cooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Kooooo00?o0000ooooooooool00_ooool5o`0000Cooooo1?l00006ooooo`;o0000;_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0[ooooo`00Doooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0;?ooool005?ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo02cooooo001Cooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0>?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Oooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0/ooooo`00E?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0h
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0;?ooool005Cooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02?ooool2o`0002oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0;?ooool005Cooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0>Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02gooooo001Dooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo03[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0]ooooo`00EOoo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0;Ooo
ool005Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0looooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo02gooooo001Eooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo0_l0000`ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
02kooooo001Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0?Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0^ooooo`00E_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0;_ooool005Kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0?Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo02kooooo001Gooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0?oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo0_l0000b
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo02oooooo001Gooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0<_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo043ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0_ooooo`00Eoooool2o`0000?ooooo00?o0000oooooooo
ool0@Oooool01Ol0003ooooooooooooooooo000000Cooooo1?l000000ol@413oooooooooo`03oooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`10oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0<?ooool005Sooooo00?o0000oooooooo
ool00_l00013ooooo`;o00000_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0<oooool01?l0003oooooooooool00014ooooo`03o`000?oooooooooo
00;o0000<_ooool005Wooooo0ol00015ooooo`?o00001oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo03?ooooo1?l00015ooooo`?o0000<oooool00:_ooooo00?o0000ooooooooool0
1Oooool3o`000;;ooooo002[ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/_oo
ool00:_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2booooo`00Zoooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0;;ooooo002Yooooo`03oeEEEOmVIVKo000000Oo
oooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003ooooooooo
o`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2boooo
o`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oo
oooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo
0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o
0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00TOoo
ool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool01?oo
ool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^
kP09ooooo`03o`000?oooooooooo00?ooooo0ol0002booooo`00Toooool00ol0003oooooooooo`0<
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2b
ooooo`00Toooool00ol0003oooooooooo`0=ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
0;;ooooo002Cooooo`03o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@4004oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_ooool0097ooooo00?oEEEEofIVI_l0
00003?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000/oooool00;?o
oooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o
0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002coooo
o`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo
0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000oooo
ooooool0/_ooool009Wooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/_ooool009_ooooo00?o0000oooooooo
ool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2booooo`00
Voooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
/_ooool009_ooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`04ooooo`?o0000/_oo
ool009_ooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool0/_ooool009_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0;;ooooo002Kooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`2booooo`00VOooool00omEEEGoIVIVo`00000=ooooo`Co
00001_ooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oo
oooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo
0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o
0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0
003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002Aooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/_ooool009?ooooo00?o
0000ooooooooool01?ooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00cooooo00?oZJVY
oeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000/_ooool009?ooooo00?o0000oooo
ooooool03Oooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0/_ooool009?ooooo00?o0000ooooooooool03Oooool00omEEEGoc<c<ooooo`03ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2booooo`00Toooool00ol0003o
ooooooooo`0=ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2booooo`00Toooool00ol0003oooooooooo`0:ooooo`05oa0@4?oooooooooooooooolb
<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;;ooooo002Aooooo`03oeEE
EOmVIVKo000000cooooo1Ol00004ooooo`Co00001_ooool2o`000;?ooooo002cooooo`03o`000?oo
oooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo
0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o
0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0
003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002Xooooo`Go00001_ooool00ol0003oooooooooo`2booooo`00Z?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Kooooo00?o0000ooooooooool0/_ooool00:Wooooo00?oV9RHob4Q8Oo^k^h01oooool0
0ol0003oooooooooo`2booooo`00Z_ooool00onHV9So8B4Qonk^kP06ooooo`?o0000/_ooool00:_o
oooo00?oMgMgofIVI_ooool0^_ooool00:cooooo00?o0000ooooooooool0^Oooool00:Sooooo00Go
0000okZj^_ooooooV9RHoa0@402kooooo`00Z?ooool01OnHV9So410@o`000?lQ8B7oc<c<0;_ooooo
003oooooofWooooo002^ooooo`03o`000?nj^[[ooooo0;Oooooo002^ooooo`;o<S8b^?ooool007oo
oooo0_l000001_l@413oooooooooool@413o0000oa0@41Sooooo1?l000001Ol@413ooooooooooooo
ooooA4A400;o000000Oo<S8bomgMgOooooooooooohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0
003oA4A4okZj^P0Iooooo`Co000000So410@ooooooooooooV9RHoa0@4?l0003o<S8bolc<c0Cooooo
00GoA4A4o`000?l0003o<S8bomgMg@1hooooo`00P?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Oooooo1_l0000<ooooo`03o`000?oooooooooo00Kooooo00OoMgMgoc8b<_oooooo
ooooolc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool0
0ol0003oooooooooo`02ooooo`05oa0@4?nj^[[oooooogMgMolb<S801oooool00omgMgOo<S8boooo
o`1gooooo`00P?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo07Kooooo0020oooo
o`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000cooooo00?o0000ooooooooool01_oo
ool00omgMgOo<S8booooo`0@ooooo`03o`000?oooooooooo00_ooooo1_l0000<ooooo`03o`000?oo
oooooooo00Gooooo00?oZJVYoa0@4?ooool01_ooool00omgMgOo<S8booooo`1gooooo`00P?ooool0
1_l0003ogMgMoc8b<_mEEEGogMgMo`0001_ooooo00?o0000ooooooooool00oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<017ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`04ooooo`03
oa0@4?l0003o^[Zj00Cooooo00Go0000ob4Q8Ol0003o<S8bolc<c01hooooo`00P?ooool01_l0003o
QhN7ojVYZOnj^[[oEEEEo`0001_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0A
ooooo`03oa0@4?l0003o000000?o00007?ooool00ol0003oooooooooo`05ooooo`03okZj^_lQ8B7o
oooo00?ooooo00?o0000ooooooooool0N_ooool0083ooooo00Ko0000oc8b<_oooooooooooc8b<_l0
000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo00;ooooo00Go410@oiRHV?oooooo^[Zjo`000004ooooo`03o`00
0?oooooooooo07[ooooo001oooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?oo
ool00omEEEGoIVIVo`000005ooooo`Co00004_ooool00ol0003oooooooooo`0Kooooo`03oeEEEOmV
IVKo000000Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@04ooooo`Co0000NOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-44.3769, -0.160437, \
0.309031, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.01333 0 0.309017 [
[.1001 -0.0125 -9 -9 ]
[.1001 -0.0125 9 0 ]
[.2334 -0.0125 -9 -9 ]
[.2334 -0.0125 9 0 ]
[.3667 -0.0125 -9 -9 ]
[.3667 -0.0125 9 0 ]
[.6333 -0.0125 -6 -9 ]
[.6333 -0.0125 6 0 ]
[.7666 -0.0125 -6 -9 ]
[.7666 -0.0125 6 0 ]
[.8999 -0.0125 -6 -9 ]
[.8999 -0.0125 6 0 ]
[.4875 .07725 -24 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -18 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -24 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1001 0 m
.1001 .00625 L
s
[(-30)] .1001 -0.0125 0 1 Mshowa
.2334 0 m
.2334 .00625 L
s
[(-20)] .2334 -0.0125 0 1 Mshowa
.3667 0 m
.3667 .00625 L
s
[(-10)] .3667 -0.0125 0 1 Mshowa
.6333 0 m
.6333 .00625 L
s
[(10)] .6333 -0.0125 0 1 Mshowa
.7666 0 m
.7666 .00625 L
s
[(20)] .7666 -0.0125 0 1 Mshowa
.8999 0 m
.8999 .00625 L
s
[(30)] .8999 -0.0125 0 1 Mshowa
.125 Mabswid
.12676 0 m
.12676 .00375 L
s
.15342 0 m
.15342 .00375 L
s
.18008 0 m
.18008 .00375 L
s
.20674 0 m
.20674 .00375 L
s
.26006 0 m
.26006 .00375 L
s
.28672 0 m
.28672 .00375 L
s
.31338 0 m
.31338 .00375 L
s
.34004 0 m
.34004 .00375 L
s
.39336 0 m
.39336 .00375 L
s
.42002 0 m
.42002 .00375 L
s
.44668 0 m
.44668 .00375 L
s
.47334 0 m
.47334 .00375 L
s
.52666 0 m
.52666 .00375 L
s
.55332 0 m
.55332 .00375 L
s
.57998 0 m
.57998 .00375 L
s
.60664 0 m
.60664 .00375 L
s
.65996 0 m
.65996 .00375 L
s
.68662 0 m
.68662 .00375 L
s
.71328 0 m
.71328 .00375 L
s
.73994 0 m
.73994 .00375 L
s
.79326 0 m
.79326 .00375 L
s
.81992 0 m
.81992 .00375 L
s
.84658 0 m
.84658 .00375 L
s
.87324 0 m
.87324 .00375 L
s
.07344 0 m
.07344 .00375 L
s
.04678 0 m
.04678 .00375 L
s
.02012 0 m
.02012 .00375 L
s
.92656 0 m
.92656 .00375 L
s
.95322 0 m
.95322 .00375 L
s
.97988 0 m
.97988 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .07725 m
.50625 .07725 L
s
[(0.25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(0.75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(1)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(1.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(1.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(1.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(140) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .21286 m
.03279 .17 L
.04262 .12781 L
.05288 .09341 L
.06244 .07074 L
.06792 .06115 L
.0731 .05385 L
.0828 .04352 L
.08823 .03913 L
.09324 .03583 L
.09875 .03302 L
.10152 .03195 L
.10311 .03144 L
.10458 .03104 L
.10588 .03075 L
.10706 .03054 L
.10838 .03035 L
.1091 .03028 L
.10978 .03022 L
.11101 .03016 L
.11215 .03016 L
.1134 .0302 L
.11472 .03031 L
.11582 .03044 L
.117 .03064 L
.11914 .03111 L
.12167 .03188 L
.12399 .03276 L
.12912 .03534 L
.13471 .03907 L
.13995 .04344 L
.14487 .04836 L
.15427 .06059 L
.15926 .06907 L
.16464 .08026 L
.1756 .11109 L
.18565 .14964 L
.19557 .1951 L
.20618 .24476 L
.21132 .26619 L
.21618 .28321 L
.22054 .29502 L
.22301 .3 L
.22419 .30193 L
.22527 .30342 L
.22632 .30461 L
.22747 .30562 L
.22868 .30635 L
.22983 .30673 L
.2309 .30681 L
Mistroke
.23204 .30659 L
.23311 .3061 L
.23409 .30542 L
.23534 .30423 L
.23649 .30282 L
.23908 .29854 L
.24137 .29356 L
.24378 .28717 L
.25313 .25316 L
.26338 .20572 L
.27427 .15459 L
.28457 .11362 L
.29381 .08583 L
.29903 .07381 L
.30386 .06472 L
.31285 .05184 L
.31797 .04626 L
.32276 .04189 L
.32747 .03828 L
.33242 .03516 L
.33502 .03381 L
.33785 .03256 L
.34044 .03164 L
.34282 .03098 L
.34406 .03071 L
.34537 .03048 L
.34668 .03031 L
.34742 .03024 L
.34812 .0302 L
.34938 .03016 L
.35053 .03016 L
.35117 .03019 L
.35186 .03023 L
.35312 .03036 L
.35424 .03051 L
.35547 .03073 L
.35797 .03134 L
.36029 .0321 L
.36247 .03297 L
.36773 .03569 L
.37255 .03892 L
.37781 .04324 L
.38343 .04888 L
.38856 .0551 L
.39322 .06189 L
.40233 .0793 L
.40744 .09203 L
.41297 .10868 L
.42302 .14661 L
.44249 .23676 L
Mistroke
.44782 .25983 L
.45355 .28088 L
.45633 .28918 L
.45896 .29571 L
.46133 .30036 L
.46267 .30246 L
.46391 .30403 L
.46519 .30529 L
.46587 .30581 L
.46658 .30623 L
.46778 .30668 L
.4691 .30678 L
.47027 .30652 L
.47153 .30589 L
.47272 .30495 L
.4738 .30381 L
.47639 .3 L
.47921 .29419 L
.48433 .27958 L
.49418 .24021 L
.50328 .19702 L
.51304 .1516 L
.52355 .11053 L
.52839 .09536 L
.53347 .08194 L
.54257 .0637 L
.54709 .05684 L
.55192 .05074 L
.56061 .04213 L
.56593 .03805 L
.57095 .03493 L
.57546 .03274 L
.578 .03178 L
.58034 .03109 L
.58159 .03079 L
.58278 .03055 L
.58385 .03038 L
.58502 .03025 L
.58628 .03015 L
.58699 .03012 L
.58763 .03011 L
.58887 .03013 L
.59004 .0302 L
.59115 .0303 L
.59232 .03047 L
.59441 .03088 L
.59665 .03149 L
.59912 .03235 L
.60428 .0348 L
.6098 .03833 L
Mistroke
.61976 .04703 L
.62507 .05309 L
.62997 .05984 L
.63525 .06866 L
.64106 .08072 L
.65083 .10787 L
.66119 .1469 L
.67197 .19615 L
.68222 .24417 L
.69142 .28018 L
.69394 .28787 L
.69663 .29476 L
.69917 .29992 L
.70147 .30338 L
.70263 .30468 L
.7039 .30574 L
.70454 .30614 L
.70522 .30646 L
.70646 .30675 L
.70769 .30668 L
.70886 .30629 L
.70991 .30566 L
.71105 .30468 L
.7123 .30328 L
.71367 .30133 L
.71644 .29611 L
.72142 .28279 L
.72609 .26637 L
.73112 .24538 L
.74023 .2026 L
.74972 .15788 L
.75987 .11672 L
.7657 .09763 L
.771 .08329 L
.77639 .07141 L
.78136 .06253 L
.79113 .04947 L
.79628 .04429 L
.80173 .03975 L
.80615 .03669 L
.81089 .034 L
.81361 .03276 L
.8161 .03182 L
.8186 .03108 L
.82097 .03056 L
.82222 .03036 L
.82287 .03028 L
.82357 .03022 L
.82484 .03013 L
.82601 .03011 L
Mistroke
.82714 .03013 L
.82819 .03019 L
.82934 .0303 L
.83057 .03047 L
.83189 .03072 L
.83333 .03105 L
.83593 .03184 L
.8408 .03392 L
.84544 .0366 L
.85037 .04016 L
.8592 .04846 L
.86859 .06067 L
.87387 .06969 L
.8787 .07973 L
.88762 .1037 L
.89699 .13736 L
.91699 .229 L
.9257 .26658 L
.93029 .28268 L
.93514 .29572 L
.93765 .30061 L
.93907 .30277 L
.9404 .30438 L
.94162 .30551 L
.94274 .30623 L
.94403 .3067 L
.94525 .30678 L
.9464 .30654 L
.94762 .30594 L
.94866 .30515 L
.94981 .30399 L
.95237 .30032 L
.95478 .29557 L
.96004 .28112 L
.96486 .26369 L
.97574 .21502 L
.97619 .21286 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^@?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hLooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=_ooool0
03Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Oooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`12ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0=_ooool002oooooo1_l00006ooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41005?ooool6o`0000Gooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@01gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01oo
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03Cooooo000jooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000012ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`00>Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000007oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000@_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
7oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool00000=_ooool003[ooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@023ooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@03Kooooo000gooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0@_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL07?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Kooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Ko
oooo000gooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Ooo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0@?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Kooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo000Koooooooo0000<_l0000Looooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Pooooo`00>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo000kooooo`Go0000A?ooool4o`0002_ooooo00?o0000ooooooooool0
5_ooool4o`0004Cooooo1Ol0001?ooooo`00>Oooool3o`0000?ooooo0ol0000oooooo`?o00001?oo
ool3o`0002Sooooo0_l0000Eooooo`?o00000oooool3o`0003kooooo1?l00003ooooo`Co0000C?oo
ool003Oooooo0_l00009ooooo`;o0000??ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool04_ooool2o`0000Wooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo04Wooooo000eooooo`;o00003Oooool2o`00
03Sooooo0_l0000<ooooo`;o00009Oooool00ol0003oooooooooo`0@ooooo`;o00003?ooool2o`00
03Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`18ooooo`00=?ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0Aoooool003Cooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool08Oooool2o`00013ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0booooo`;o00004Oooool00ol0003oooooooooo`16ooooo`00<oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0AOooool003;ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`0<ooooo`;o00005Oooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0AOooool0037ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04Cooooo000aooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`13ooooo`00
<?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0Mooooo`;o00002oooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`12ooooo`00<?oo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0@_oo
ool002oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo01Kooooo00Gok^k^oc8b<_l0003o<S8bo`000005ooooo`;o8B4Q1?ooool5o`0000Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
@Oooool002kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo01Oooooo00GoMgMgoiRHV?ooooooV9RHo`000005ooooo`;o8B4Q1?ooool01OnHV9So8B4Q
onk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo047ooooo000^ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`0Gooooo`05oa0@4?ooooooooooooooool000003?ooool00onHV9So
8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`10ooooo`00;Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool05oooool01?l0003oooooooooooooool2o`0000cooooo00?oV9RHob4Q8Oo^
k^h01oooool00omgMgOo<S8booooo`04ooooo`?o00002?ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0oooooo`00
;Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
6?ooool01?l0003oooooooooooooool2o`0000gooooo00?oMgMgofIVI_ooool00oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0ooooo
o`00;?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool06Oooool01ol@413ooooooooooooooooo410@ooooool000003Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0n
ooooo`00;?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool06Oooool01omgMgOoV9RHoooooonHV9SoMgMgooooool000002Oooool01Ol0003o^[Zjoooo
oonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo03kooooo000/ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`0Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool00ol0003ooooo
ooooo`06ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l00007ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo03kooooo000[ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`0mooooo`00:oooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0?Oooool002_ooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03gooooo000Zooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0looooo`00:_ooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`0Gooooo`;o00001_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0looooo`00:_ooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0??ooool002Wooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03_ooooo000Y
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0k
ooooo`00:Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0>oooool002Sooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool05_ooool2o`0000Cooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0>oooool002Sooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo03_ooooo000Xooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0jooooo`00:?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool0>_ooool002Oooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool05Oooool2o`00
00?ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool0>_ooool002Oooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo03[ooooo000Wooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0jooooo`009oooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool09Oooool01Oo^k^ko<S8bo`00
0?lb<S;o000000Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool01Ol0003o
oooooooooooooooo000002cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo03Wooooo000Vooooo`03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`0Vooooo`05ogMgMonHV9SooooooiRHV?l000001Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool01?ooool01Ol0003ooooooooooooooooo000002cooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03Wooooo000Voooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Voooo
o`05oa0@4?ooooooooooooooool000004?ooool00ol0003oooooooooo`03ooooo`?o000000?ooooo
o`000?ooool0:oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool0>Oooool002Kooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo02Kooooo00Co0000oooooooooooooooo0_l0000>ooooo`03ogMgMolb<S;o
oooo00Cooooo00Go0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`0iooooo`009_ooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool09_ooool01?l0003ooooooooooooo
ool2o`0000_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`04o`000?ooooooooooo`0002ko
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03So
oooo000Vooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0Wooooo`06oa0@4?ooooooooooooooool@413o00002oooool00ol0003oooooooooo`07oooo
o`04o`000?ooooooooooo`0002kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo03Sooooo000Uooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0Wooooo`06ogMgMonHV9SooooooiRHV?mgMgOo00002ooo
ool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooo`0002kooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo03Sooooo000Uooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Wooooo`06onk^k_lb
<S;o0000oc8b<_o^k^ko00002oooool4o`0000Kooooo0_l000000ooooooo0000ooooo`0]ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0hooooo`00
9Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0Booooo`04o`000?ooooooooooo`0002oooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo03Oooooo000Uooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooool00000<?ooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo02gooooo00?o0000ooooooooool0=oooool002Gooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool04_oo
ool00ol0003oooooo`00000`ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`0gooooo`009?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Booooo`?o0000<?ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0=oooool0
02Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool04Oooool00ol0003oooooo`00000`ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0fooooo`009?ooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooo0000037ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo03Kooooo000Tooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo017ooooo
0_l0000booooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`0fooooo`009?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`0Aooooo`;o0000<_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0=_ooool002Cooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool04Oooool2o`0003;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo03Gooooo000Tooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo013ooooo0_l0000boooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0eoooo
o`008oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo03Gooooo000Sooooo`03o`00
0?oooooooooo03;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0booooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0=Oooool002?ooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0booooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02;ooooo001Hooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0?ooooo`;o0000<oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Rooooo`00FOooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
03Cooooo00?o0000ooooooooool03_ooool2o`0003Cooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08_ooool005Wo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Sooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Gooooo0_l000000oo^k^koooooooooo`03ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool2o`0003Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0c
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool08oooool005Wooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Gooooo00?o0000oeEEEOnYZJT02?ooool00omgMgOo<S8booooo`03ooooo`;o0000=Oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0Sooooo`00FOooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
02?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?nYZJWoEEEE00Wooooo00?o0000
ooooooooool00_ooool4o`0003?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool08oooool005Wooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0Tooooo`05o`000?ooooooooooooooool000003Oooool0
0ol0003o8B4Qooooo`07ooooo`03ogMgMolb<S;ooooo00?ooooo0_l0000eooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo02?ooooo001Jooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool09?ooool01Ol0
003ooooooooooooooooo000000gooooo00?o0000oeEEEOo<c<`01?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00?ooooo00?o0000ooooool00000=Oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Sooooo`00F_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Cooooo00Go410@oooooooooooooooooa0@
400=ooooo`03o`000?nYZJWoMgMg00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooo`00
000fooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo02Cooooo001Jooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool09?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@ooooool0003ooooo
oc8b<P04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool00000=_ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Tooooo`00F_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Cooooo00Co0000ooooool0003o
0000=Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Oooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Tooooo`00F_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool02_ooool01?l0003oooooooooool0000fooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo02Cooooo001Jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`0003Oooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool09?ooool005_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo00[ooooo00Co0000oooooooooooo0000=oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Uooooo`00
Foooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0
2_ooool01?l0003oooooooooool0000gooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0>Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Gooooo001Kooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`09ooooo`04o`00
0?ooooooooooooooo`;o0000=oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Uooooo`00Foooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02?ooool01Ol0003ooooo
oooooooooooo000003Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0iooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool09Oooool005_ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Sooooo00Go0000oooooooooooo
ooooo`00000hooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo02Gooooo001Looooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool0
0000>?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Vooooo`00G?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo03cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool09_ooool005cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_oo
ool2o`0003Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool09_ooool005gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0?Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Kooooo001Mooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
03gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Wooooo`00GOooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09oooool005kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool2o`0003Wooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0oooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09oooool005kooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0?oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Sooooo001O
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0@?ooool00ol0003oooooo`000003
o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo043ooooo00Go0000ooooooooooooooooo`00000[ooooo`00Goooool2
o`0000;ooooo00?o0000ooooooooool0@_ooool01?l0003oooooooooool00007ooooo`03o`000?oo
oooooooo03[ooooo00?o0000ooooooooool00_l00013ooooo`04o`000?ooooooooooo`0002cooooo
001Pooooo`?o0000AOooool4o`0000Oooooo00?o0000ooooooooool0>_ooool4o`0004Gooooo0ol0
000/ooooo`00Zoooool00ol0003oooooooooo`05ooooo`?o0000/_ooool00:_ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`2booooo`00Zoooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0;;ooooo002[ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
/_ooool00:Wooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2booooo`00/oooool2
o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;o
oooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000
ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooooooo
ool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool0
0ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002Aooooo`Co000000?o410@ooooooooool00_ooool2ob4Q
8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2b
ooooo`00Toooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2booooo`00Toooool00ol0
003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`00
0;;ooooo002Cooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00gooooo
00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool0/_ooool009?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool02_oo
ool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`2booooo`00TOooool00omEEEGoIVIVo`00000<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
1?ooool4o`0000Kooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool0
0ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o
0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_oo
ool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?o
oooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00VOooool4o`000003oa0@4?oo
oooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`2booooo`00Voooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo0;;ooooo002Kooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`2booooo`00Voooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo00Cooooo0ol0002booooo`00Voooool00ol0003oooooooooo`0;ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2booooo`00Voooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_ooool009_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;;ooooo
002Iooooo`03oeEEEOmVIVKo000000gooooo1?l00006ooooo`03o`000?oooooooooo0;;ooooo002c
ooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooooooo
ool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool0
0ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/ooo
ool00;?ooooo00?o0000ooooooooool0/_ooool0097ooooo1?l000000ol@413oooooooooo`02oooo
o`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`04ooooo`;o8B4Q1_ooool00omE
EEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/_ooool009?o
oooo00?o0000ooooooooool03?ooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?o
oooo0ol0002booooo`00Toooool00ol0003oooooooooo`0=ooooo`03ob4Q8Ooooooooooo00Kooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2booooo`00Toooool00ol0003ooooooooo
o`0=ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00gooooo00?oZJVYogMgMoooool00ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooo
oooo00[ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0/_ooool0097ooooo00?oEEEEofIVI_l000003?ooool5o`0000Cooooo1?l00006
ooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooooooo
ool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_oo
ool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/ooo
ool00;?ooooo00?o0000ooooooooool0/_ooool00:Sooooo1Ol00006ooooo`03o`000?oooooooooo
0;;ooooo002Xooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`2boooo
o`00ZOooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0;;ooooo002Zooooo`03oiRH
V?lQ8B7ok^k^00Kooooo0ol0002booooo`00Zoooool00omgMgOoIVIVooooo`2jooooo`00[?ooool0
0ol0003oooooooooo`2iooooo`00Z?ooool01Ol0003o^[ZjoooooonHV9So410@0;_ooooo002Xoooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`0^oooool00?ooooooJOooool00:kooooo00?o0000okZj^_oo
ool0]oooool00:kooooo0_lb<S:hooooo`00Ooooool2o`000006oa0@4?oooooooooooa0@4?l0003o
410@6?ooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000001olb<S;ogMgMoooooooooooo
QhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Wooooo1?l000000ol@413ooooo
ooooo`02ooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h0NOooool0
083ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00003?ooool00ol0
003oooooooooo`06ooooo`07ogMgMolb<S;oooooooooooo<c<co0000oa0@400<ooooo`05oa0@4?nj
^[[ok^k^ogMgMol@41002Oooool6o`0000cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0NOooool0083ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo1Ol00003ooooo`05oa0@
4?ooooooooooooooool@4100NOooool0083ooooo00Ko0000oooooom4A4CoA4A4ooooool00009oooo
o`Ko00003?ooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo013ooooo00?o0000oooo
ooooool02oooool6o`0000cooooo00?o0000ooooooooool00_ooool01?m4A4CogMgMooooool00004
ooooo`05o`000?ooooooooooooooool00000NOooool0083ooooo00Ko0000omgMgOlb<S;oEEEEomgM
gOl0000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Aooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool00_ooool01?oMgMgoEEEEooooool00004oooo
o`05o`000?ooooooooooooooool00000NOooool0083ooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0
000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol@413o0000o`00
0003o`0001cooooo00?o0000ooooooooool00oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oo
ooooooooooooool@4100NOooool0083ooooo00Ko0000oc8b<_oooooooooooc8b<_l0000Kooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo00?ooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
07Wooooo001oooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool00omEEEGo
IVIVo`000005ooooo`Co00004_ooool00ol0003oooooooooo`0Kooooo`03oeEEEOmVIVKo000000Ko
oooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07Wooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-44.3769, -0.160437, \
0.309031, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.01333 0 0.309017 [
[.1001 -0.0125 -9 -9 ]
[.1001 -0.0125 9 0 ]
[.2334 -0.0125 -9 -9 ]
[.2334 -0.0125 9 0 ]
[.3667 -0.0125 -9 -9 ]
[.3667 -0.0125 9 0 ]
[.6333 -0.0125 -6 -9 ]
[.6333 -0.0125 6 0 ]
[.7666 -0.0125 -6 -9 ]
[.7666 -0.0125 6 0 ]
[.8999 -0.0125 -6 -9 ]
[.8999 -0.0125 6 0 ]
[.4875 .07725 -24 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -18 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -24 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1001 0 m
.1001 .00625 L
s
[(-30)] .1001 -0.0125 0 1 Mshowa
.2334 0 m
.2334 .00625 L
s
[(-20)] .2334 -0.0125 0 1 Mshowa
.3667 0 m
.3667 .00625 L
s
[(-10)] .3667 -0.0125 0 1 Mshowa
.6333 0 m
.6333 .00625 L
s
[(10)] .6333 -0.0125 0 1 Mshowa
.7666 0 m
.7666 .00625 L
s
[(20)] .7666 -0.0125 0 1 Mshowa
.8999 0 m
.8999 .00625 L
s
[(30)] .8999 -0.0125 0 1 Mshowa
.125 Mabswid
.12676 0 m
.12676 .00375 L
s
.15342 0 m
.15342 .00375 L
s
.18008 0 m
.18008 .00375 L
s
.20674 0 m
.20674 .00375 L
s
.26006 0 m
.26006 .00375 L
s
.28672 0 m
.28672 .00375 L
s
.31338 0 m
.31338 .00375 L
s
.34004 0 m
.34004 .00375 L
s
.39336 0 m
.39336 .00375 L
s
.42002 0 m
.42002 .00375 L
s
.44668 0 m
.44668 .00375 L
s
.47334 0 m
.47334 .00375 L
s
.52666 0 m
.52666 .00375 L
s
.55332 0 m
.55332 .00375 L
s
.57998 0 m
.57998 .00375 L
s
.60664 0 m
.60664 .00375 L
s
.65996 0 m
.65996 .00375 L
s
.68662 0 m
.68662 .00375 L
s
.71328 0 m
.71328 .00375 L
s
.73994 0 m
.73994 .00375 L
s
.79326 0 m
.79326 .00375 L
s
.81992 0 m
.81992 .00375 L
s
.84658 0 m
.84658 .00375 L
s
.87324 0 m
.87324 .00375 L
s
.07344 0 m
.07344 .00375 L
s
.04678 0 m
.04678 .00375 L
s
.02012 0 m
.02012 .00375 L
s
.92656 0 m
.92656 .00375 L
s
.95322 0 m
.95322 .00375 L
s
.97988 0 m
.97988 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .07725 m
.50625 .07725 L
s
[(0.25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(0.75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(1)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(1.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(1.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(1.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(145) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30107 m
.04262 .23857 L
.06244 .14634 L
.07216 .10939 L
.08255 .08025 L
.08852 .06797 L
.09396 .05907 L
.09911 .05221 L
.10458 .04623 L
.10932 .04192 L
.11454 .03797 L
.11934 .03502 L
.12373 .03292 L
.12638 .03194 L
.1289 .03121 L
.13027 .0309 L
.13155 .03068 L
.13296 .03049 L
.13374 .03041 L
.13446 .03036 L
.13575 .03032 L
.13694 .03033 L
.13825 .03039 L
.13891 .03045 L
.13963 .03052 L
.14085 .0307 L
.14216 .03094 L
.14451 .03151 L
.14707 .03234 L
.14979 .03345 L
.15468 .03602 L
.15994 .03956 L
.16575 .04445 L
.17074 .04958 L
.17613 .05631 L
.18117 .06404 L
.18587 .07279 L
.19544 .09641 L
.20591 .13258 L
.22701 .22914 L
.23206 .25183 L
.23753 .2735 L
.24004 .28201 L
.2427 .28983 L
.245 .2955 L
.24747 .30038 L
.24869 .30231 L
.24986 .30383 L
.25099 .30502 L
.25204 .30585 L
Mistroke
.25303 .3064 L
.25409 .30673 L
.25526 .3068 L
.25632 .30657 L
.25758 .30596 L
.25873 .30508 L
.26 .30376 L
.26134 .30196 L
.26359 .29804 L
.26606 .2925 L
.27131 .2768 L
.27629 .25787 L
.2856 .21571 L
.29576 .16748 L
.30653 .12243 L
.31602 .09188 L
.32142 .07849 L
.32648 .06824 L
.33536 .05456 L
.34491 .04415 L
.35451 .03674 L
.35994 .03373 L
.36237 .03267 L
.36499 .03173 L
.36643 .03131 L
.36775 .03099 L
.36899 .03074 L
.37035 .03052 L
.37157 .03039 L
.37271 .0303 L
.37392 .03027 L
.37521 .03028 L
.37594 .03032 L
.37661 .03037 L
.37735 .03044 L
.37813 .03053 L
.37945 .03074 L
.38091 .03104 L
.38359 .03178 L
.38611 .03269 L
.39079 .0349 L
.39592 .03807 L
.40092 .0419 L
.40626 .04686 L
.41128 .0525 L
.41584 .05864 L
.42476 .07442 L
.4296 .08562 L
.43473 .09992 L
.44392 .13221 L
Mistroke
.46471 .22733 L
.47413 .268 L
.47942 .28596 L
.48193 .29277 L
.48426 .29796 L
.48643 .30177 L
.48755 .30332 L
.48875 .30468 L
.48944 .30531 L
.49007 .30579 L
.49132 .30645 L
.49245 .30675 L
.49365 .30673 L
.49471 .30643 L
.49585 .30581 L
.49692 .30496 L
.4979 .30394 L
.5003 .30055 L
.50257 .29617 L
.50716 .2841 L
.51223 .26647 L
.52249 .2215 L
.54092 .13685 L
.55102 .10082 L
.56028 .07677 L
.56513 .06719 L
.57044 .05865 L
.57595 .05148 L
.58114 .04593 L
.58607 .04152 L
.59142 .03756 L
.59587 .03487 L
.60076 .03259 L
.6035 .03163 L
.60606 .03096 L
.60748 .03068 L
.60877 .03049 L
.60948 .03041 L
.61026 .03034 L
.61099 .03029 L
.61167 .03027 L
.61299 .03026 L
.61423 .03031 L
.61534 .0304 L
.61654 .03055 L
.61785 .03077 L
.61924 .03106 L
.62172 .03175 L
.62428 .03267 L
.6267 .03374 L
Mistroke
.63123 .03621 L
.63652 .03987 L
.64141 .044 L
.65021 .05357 L
.65485 .06005 L
.65976 .06834 L
.66917 .08949 L
.67929 .12173 L
.69759 .20239 L
.70768 .24944 L
.71302 .27099 L
.71595 .28115 L
.71871 .28938 L
.72133 .29586 L
.72271 .2987 L
.72417 .30126 L
.7254 .30305 L
.72675 .30462 L
.72798 .30568 L
.72913 .30636 L
.73038 .30675 L
.73157 .30677 L
.73263 .30651 L
.73379 .30592 L
.73505 .30493 L
.73639 .30347 L
.7388 .29984 L
.74118 .295 L
.74368 .28866 L
.74816 .27445 L
.75826 .23237 L
.77654 .14719 L
.78608 .11062 L
.79132 .09437 L
.79627 .08154 L
.80088 .07157 L
.80589 .06266 L
.81463 .05075 L
.82409 .04155 L
.82947 .03758 L
.8345 .0346 L
.83722 .0333 L
.8398 .03227 L
.84214 .03151 L
.84464 .03091 L
.84606 .03065 L
.84735 .03048 L
.84864 .03037 L
.84985 .03031 L
.85055 .0303 L
Mistroke
.85128 .03031 L
.85259 .03037 L
.85332 .03044 L
.85399 .03051 L
.85554 .03073 L
.8568 .03098 L
.85815 .03129 L
.86056 .03201 L
.86601 .03433 L
.87072 .03707 L
.87592 .04085 L
.8855 .05014 L
.89449 .06247 L
.89919 .0709 L
.90434 .08211 L
.9147 .11221 L
.9243 .14956 L
.93321 .19052 L
.94376 .24044 L
.94893 .26257 L
.9537 .28001 L
.95804 .2926 L
.96023 .29755 L
.96263 .30183 L
.96389 .30356 L
.96504 .30483 L
.96568 .3054 L
.96637 .30591 L
.96763 .30655 L
.9688 .30682 L
.97005 .30674 L
.97112 .30638 L
.9723 .30568 L
.97328 .30485 L
.97417 .30389 L
.97619 .30107 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^@?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hLooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=_ooool0
03Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Oooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`12ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0=_ooool002oooooo1_l00006ooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41005?ooool6o`0000Gooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@01gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01oo
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03Cooooo000jooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000012ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`00>Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000007oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000@_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
7oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool00000=_ooool003[ooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@023ooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@03Kooooo000gooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0@_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL07?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Kooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Ko
oooo000gooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Ooo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0@?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Kooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo000Koooooooo0000<_l0000Looooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Pooooo`00>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo0013ooooo`Co0000A?ooool4o`0002Cooooo00?o0000ooooooooool0
7_ooool3o`0004Gooooo1?l00018ooooo`00@?ooool4o`0000;ooooo1?l0000nooooo`Co00000ooo
ool3o`00027ooooo0_l0000Looooo`?o00000oooool4o`0003kooooo1?l00002ooooo`?o0000A_oo
ool003oooooo00?o0000ooooooooool02?ooool2o`0003_ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0jooooo`;o00002?ooool2o`0004Cooooo000mooooo`;o00003Oooool00ol0
003oooooooooo`0gooooo`03o`000?oooooooooo00[ooooo0_l0000Nooooo`03o`000?oooooooooo
01Sooooo0_l0000<ooooo`03o`000?oooooooooo03Oooooo0_l0000<ooooo`03o`000?oooooooooo
047ooooo000looooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`0=ooooo`;o00007?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0=ooooo`;o0000@Oooool003_ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool06Oooool2o`0001Oooooo00?o0000ooooooooool03oooool2o`0003Cooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0nooooo`00>_ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0?Oooool003Wooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03gooooo000ioooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0loooo
o`00>?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool0>oooool003Sooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool05oooool2o`0001?ooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
>_ooool003Oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo03[ooooo000fooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00olQ8B7o0000oooo
o`03ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0iooooo`00=_ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool03oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
00?o8B4Qo`000?ooool00oooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo03Wooooo000eooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`05oa0@
4?ooooooooooooooool@41001oooool00ol0003oooooooooo`02ooooo`03oiRHV?lQ8B7ok^k^00Wo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo03Wo
oooo000eooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0@ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`03ooooo`03
oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0000oooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool0>?ooool003Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo013ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00?o
oooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0gooooo`00=?ooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@
00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0gooooo`00<oooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool04Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Wooooo00Oo0000ooooool0003o^[ZjoooooonHV9So410@00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03Kooooo000c
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0B
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02Oooool01ol0003ooooooiRHV?l@413o0000ob4Q8Oo<
c<`01?ooool4o`0000Kooooo0_l0000>ooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03Kooooo000cooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0fooooo`00<_oo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08_oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0=Ooo
ool003;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo03Gooooo000booooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`0eooooo`00<Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0@ooooo`;o00003Oooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`0dooooo`00<Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0=?ooool0037ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo03Cooooo000`ooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0dooooo`00<?ooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0<oooool0033ooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool03oooool2o`0000_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool0<oooool0033ooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03?ooooo000_ooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0cooooo`00;oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0<_ooool0
02oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool03_ooool2o`0000[ooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0<_ooool002oo
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03;o
oooo000^ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`0booooo`00;_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool07oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o8B4Qo`000?ooool0
1?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`0aooooo`00;_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool07oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o8B4Qo`000?oo
ool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02[ooooo00?o0000oooooooo
ool0<Oooool002kooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo01oooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool00oooool3o`0000Sooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0<Oooool002gooooo
00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01oooooo
00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo037ooooo000]ooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Oooooo`05o`00
0?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo037ooooo000]ooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Pooooo`05
oa0@4?ooooooooooooooool@41001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0`ooooo`00;Oooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool08?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo02cooooo00?o0000ooooooooool0<?ooool002gooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo023ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP07ooooo`03o`000?oooooooooo00;ooooo1?l00006ooooo`;o00002?ooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`0`ooooo`00;?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool0<?ooool002cooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo033ooooo000/ooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`00;?ooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0;
ooooo`;o00001oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`0_ooooo`00;?ooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;oooool002_ooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02oooooo000[ooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0_ooooo`00:ooo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;ooo
ool002_ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool02_ooool2o`0000Kooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0;_ooool0
02[ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo
02kooooo000Zooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`0^ooooo`00:_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0<_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool0;_ooool002[ooooo00?o0000ooooooooool0<_ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo02gooooo000Zooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Wooooo0_l00005
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0c
ooooo`03o`000?oooooooooo02gooooo000Yooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`0]ooooo`00:Oooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool06oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00?ooooo00Ko0000odA4A?l0003o0000oc8b<_oM
gMd5ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0;?ooool002Wooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`03ooooo`06o`000?oo
oooooooooooooomgMgOo<S8b1Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02co
oooo000Yooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0Looooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool3o`0000?ooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool0;?ooool002Wooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo01cooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00;o
oooo00Ko0000ooooooooooooooooogMgMolb<S85ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03Gooooo00?o0000
ooooooooool0;?ooool002Sooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo01cooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<co
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool0:oooool002Sooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo01gooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmg
MgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo02_ooooo000Xooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0Mooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooo
oooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo03Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0gooooo`03o`00
0?oooooooooo02_ooooo000Xooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0Mooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo
1?l00006ooooo`;o00000oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`0[ooooo`009oooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0=oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0:oooool002Oooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Oooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02[ooooo000Woooo
o`03o`000?oooooooooo03Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Zoooo
o`009oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Wooooo00?o0000oooooooo
ool0:_ooool002Kooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo03Wooooo00?o0000ooooooooool01Oooool2o`0000;ooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0
:_ooool002Kooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000003cooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02[ooooo
000Vooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0jooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`00000looooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Yooooo`009Ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0003gooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Wooooo000Uooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo00Cooooo00Co0000oooooooooooo0000?_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0:Oooool002Gooooo00?o0000ooooooooool0??oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01?oo
ool2o`000003ooooool0003ooooo03gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0looooo`03o`000?oooooooooo02Sooooo000Uooooo`03o`000?oooooooooo03cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooool00000?oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03gooooo00?o0000
ooooooooool0:?ooool002Cooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo03gooooo00?o0000ooooooooool00oooool00ol0003oooooo`00000ooooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Xoooo
o`009?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0?Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000003oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo02Oooooo000Tooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo00;ooooo0_l00010ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`0Wooooo`009?ooool00ol0003oooooooooo`0oooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`02ooooo`;o0000@Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool09_oo
ool002?ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo03_ooooo1?l000000ol@413o0000ooooo`03ooooo`03o`000?oooooooooo047ooooo00Go0000
ooooooooooooooooo`000013ooooo`03o`000?oooooooooo02Kooooo000Sooooo`03o`000?oooooo
oooo047ooooo00?o0000ooooooooool00_l0000oooooo`05o`000?ooooooooooooooool000000_oo
ool2o`0004?ooooo00Go0000ooooooooooooooooo`000013ooooo`;o00000_ooool00ol0003ooooo
ooooo`0Rooooo`00Ioooool4o`00043ooooo00?o0000ooooooooool00_ooool4o`0004Cooooo0ol0
0015ooooo`Co00009?ooool00:_ooooo00?o0000ooooooooool01Oooool3o`000;;ooooo002[oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/_ooool00:_ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2booooo`00Zoooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;;ooooo002Yooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0/_oo
ool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/ooo
ool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?o
oooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0
002cooooo`00/oooool00ol0003oooooooooo`2booooo`00TOooool4o`000003oa0@4?oooooooooo
00;ooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool0/_ooool009?ooooo00?o0000ooooooooool01?ooool2ob4Q8@Cooooo00GoV9RHob4Q
8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/_ooool0
09?ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo
00?ooooo0ol0002booooo`00Toooool00ol0003oooooooooo`0<ooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2booooo`00Toooool00ol0003ooooo
ooooo`0=ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oo
oooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0/_ooool0097ooooo00?oEEEEofIVI_l000003?ooool01OnHV9So410@o`00
0?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_oo
ool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?o
oooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003ooooooooo
o`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2boooo
o`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oo
oooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo
0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool009Wooooo1?l0
00000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo
00?o0000ooooooooool0/_ooool009_ooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2booooo`00Voooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/_ooool009_ooooo00?o0000oooo
ooooool03_ooool00omgMgOo<S8booooo`04ooooo`?o0000/_ooool009_ooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/_ooool009_o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;;o
oooo002Kooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`2booooo`00VOooool00omEEEGoIVIVo`00000=ooooo`Co00001_ooool00ol0003ooooooooo
o`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/ooo
ool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?o
oooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0
002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2boooo
o`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/ooo
ool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002Aooooo`Co000000?o410@oooo
ooooool00_ooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool01?ooool2ob4Q
8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
0;;ooooo002Cooooo`03o`000?oooooooooo00cooooo00?oZJVYoeEEEOooool02?ooool00ol0003o
ooooooooo`03ooooo`?o0000/_ooool009?ooooo00?o0000ooooooooool03Oooool00olQ8B7ooooo
ooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/_ooool009?ooooo00?o
0000ooooooooool03Oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`0=ooooo`03ojVYZOmg
MgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2booooo`00Toooool0
0ol0003oooooooooo`0:ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0;;ooooo002Aooooo`03oeEEEOmVIVKo000000cooooo1Ol00004
ooooo`Co00001_ooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oo
oooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?o
oooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0
002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2boooo
o`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/ooo
ool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002Xooooo`Go00001_ooool00ol0
003oooooooooo`2booooo`00Z?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000oooo
ooooool0/_ooool00:Wooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`2booooo`00
Z_ooool00onHV9So8B4Qonk^kP06ooooo`?o0000/_ooool00:_ooooo00?oMgMgofIVI_ooool0^_oo
ool00:cooooo00?o0000ooooooooool0^Oooool00:Sooooo00Go0000okZj^_ooooooV9RHoa0@402k
ooooo`00Z?ooool01OnHV9So410@o`000?lQ8B7oc<c<0;_ooooo003oooooofWooooo002^ooooo`03
o`000?nj^[[ooooo0;Oooooo002^ooooo`;o<S8b^?ooool007oooooo0_l000001_l@413ooooooooo
ool@413o0000oa0@41Sooooo1?l000001Ol@413oooooooooooooooooA4A400;o000000Oo<S8bomgM
gOooooooooooohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Iooooo`Co0000
00?o410@ooooooooool00_ooool2o`000003oa0@4?oooooooooo00;ooooo00GoA4A4o`000?l0003o
<S8bomgMg@1hooooo`00P?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo
1_l0000<ooooo`03o`000?oooooooooo00Kooooo00OoMgMgoc8b<_ooooooooooolc<c?l0003o410@
00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool0Moooool0083ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo1Ol00008oooo
o`03o`000?oooooooooo07Kooooo0020ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6
o`0000cooooo00?o0000ooooooooool01_ooool00omgMgOo<S8booooo`0@ooooo`03o`000?oooooo
oooo00_ooooo1_l0000<ooooo`03o`000?oooooooooo00;ooooo00CoA4A4omgMgOoooooo00002?oo
ool00omgMgOo<S8booooo`1gooooo`00P?ooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001_ooooo
00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<017ooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`02ooooo`04omgMgOmEEEGoooooo`0000Gooooo00Go0000ob4Q
8Ol0003o<S8bolc<c01hooooo`00P?ooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001_ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03oa0@4?l0003o000000?o00007?oo
ool00ol0003oooooooooo`03ooooo`03ogMgMoo<c<co000000Gooooo00?o0000ooooooooool0N_oo
ool0083ooooo00Ko0000oc8b<_oooooooooooc8b<_l0000Kooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00?ooooo
00?ok^k^odA4A?l000001Oooool00ol0003oooooooooo`1jooooo`00Ooooool00ol@413o0000ohN7
Q`02ooooo`03ohN7Qol0003o410@01Sooooo00?oEEEEofIVI_l000001Oooool4o`0001;ooooo00?o
0000ooooooooool06oooool00omEEEGoIVIVo`000006ooooo`03ogMgMol0003ooooo00Cooooo1?l0
001iooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-44.3769, -0.160437, \
0.309031, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.01333 0 0.309017 [
[.1001 -0.0125 -9 -9 ]
[.1001 -0.0125 9 0 ]
[.2334 -0.0125 -9 -9 ]
[.2334 -0.0125 9 0 ]
[.3667 -0.0125 -9 -9 ]
[.3667 -0.0125 9 0 ]
[.6333 -0.0125 -6 -9 ]
[.6333 -0.0125 6 0 ]
[.7666 -0.0125 -6 -9 ]
[.7666 -0.0125 6 0 ]
[.8999 -0.0125 -6 -9 ]
[.8999 -0.0125 6 0 ]
[.4875 .07725 -24 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -18 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -24 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1001 0 m
.1001 .00625 L
s
[(-30)] .1001 -0.0125 0 1 Mshowa
.2334 0 m
.2334 .00625 L
s
[(-20)] .2334 -0.0125 0 1 Mshowa
.3667 0 m
.3667 .00625 L
s
[(-10)] .3667 -0.0125 0 1 Mshowa
.6333 0 m
.6333 .00625 L
s
[(10)] .6333 -0.0125 0 1 Mshowa
.7666 0 m
.7666 .00625 L
s
[(20)] .7666 -0.0125 0 1 Mshowa
.8999 0 m
.8999 .00625 L
s
[(30)] .8999 -0.0125 0 1 Mshowa
.125 Mabswid
.12676 0 m
.12676 .00375 L
s
.15342 0 m
.15342 .00375 L
s
.18008 0 m
.18008 .00375 L
s
.20674 0 m
.20674 .00375 L
s
.26006 0 m
.26006 .00375 L
s
.28672 0 m
.28672 .00375 L
s
.31338 0 m
.31338 .00375 L
s
.34004 0 m
.34004 .00375 L
s
.39336 0 m
.39336 .00375 L
s
.42002 0 m
.42002 .00375 L
s
.44668 0 m
.44668 .00375 L
s
.47334 0 m
.47334 .00375 L
s
.52666 0 m
.52666 .00375 L
s
.55332 0 m
.55332 .00375 L
s
.57998 0 m
.57998 .00375 L
s
.60664 0 m
.60664 .00375 L
s
.65996 0 m
.65996 .00375 L
s
.68662 0 m
.68662 .00375 L
s
.71328 0 m
.71328 .00375 L
s
.73994 0 m
.73994 .00375 L
s
.79326 0 m
.79326 .00375 L
s
.81992 0 m
.81992 .00375 L
s
.84658 0 m
.84658 .00375 L
s
.87324 0 m
.87324 .00375 L
s
.07344 0 m
.07344 .00375 L
s
.04678 0 m
.04678 .00375 L
s
.02012 0 m
.02012 .00375 L
s
.92656 0 m
.92656 .00375 L
s
.95322 0 m
.95322 .00375 L
s
.97988 0 m
.97988 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .07725 m
.50625 .07725 L
s
[(0.25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(0.75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(1)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(1.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(1.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(1.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(150) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .27348 m
.02846 .28827 L
.03068 .29395 L
.03279 .29841 L
.03398 .30052 L
.03527 .30245 L
.03635 .30378 L
.03754 .30493 L
.03882 .30581 L
.03952 .30613 L
.04018 .30633 L
.04135 .30642 L
.04262 .30617 L
.04393 .3055 L
.04516 .30453 L
.0465 .30306 L
.04793 .30106 L
.05057 .29616 L
.05297 .29047 L
.05785 .27557 L
.06244 .25814 L
.08439 .15736 L
.09401 .11872 L
.09911 .1018 L
.10458 .08652 L
.10965 .0748 L
.11427 .06593 L
.12333 .0525 L
.1282 .04692 L
.1335 .04185 L
.13847 .0379 L
.14313 .03488 L
.14765 .03259 L
.1502 .03159 L
.15253 .03087 L
.15494 .03032 L
.15631 .0301 L
.15758 .02995 L
.15828 .0299 L
.15893 .02986 L
.16016 .02983 L
.16148 .02986 L
.16222 .0299 L
.1629 .02996 L
.16412 .0301 L
.16542 .03031 L
.16776 .03084 L
.17056 .0317 L
.17311 .03271 L
.17865 .03558 L
Mistroke
.18391 .03913 L
.19352 .04779 L
.19889 .05413 L
.20376 .06112 L
.20832 .06901 L
.21324 .07933 L
.22216 .10369 L
.23169 .1385 L
.24214 .18532 L
.25317 .23759 L
.25798 .25846 L
.26321 .27803 L
.26575 .28598 L
.26843 .29314 L
.27092 .29848 L
.27214 .30061 L
.27326 .30228 L
.2743 .30359 L
.27543 .30473 L
.27658 .30559 L
.27778 .30615 L
.27903 .30639 L
.27973 .30636 L
.28036 .30624 L
.2816 .30573 L
.28276 .30492 L
.28397 .30375 L
.2853 .30208 L
.28799 .29751 L
.29048 .29193 L
.29281 .2856 L
.30369 .24476 L
.3223 .15819 L
.33212 .11866 L
.34257 .08675 L
.3478 .07464 L
.35358 .06382 L
.36378 .04969 L
.36877 .04447 L
.37415 .03977 L
.3792 .03617 L
.38389 .0335 L
.38851 .03155 L
.3911 .03076 L
.39224 .03049 L
.39345 .03025 L
.39409 .03014 L
.39479 .03004 L
.39603 .02991 L
.39673 .02986 L
Mistroke
.39748 .02983 L
.39818 .02981 L
.39883 .02981 L
.40008 .02986 L
.40078 .02991 L
.40144 .02997 L
.40263 .03013 L
.40391 .03034 L
.40665 .031 L
.40961 .032 L
.41498 .03451 L
.4202 .03779 L
.425 .0415 L
.42971 .04583 L
.43475 .05136 L
.44384 .06444 L
.4494 .07507 L
.45466 .08752 L
.46451 .1181 L
.48274 .1973 L
.49312 .24591 L
.4982 .2669 L
.50286 .28307 L
.5075 .29542 L
.50983 .29998 L
.51115 .30203 L
.51238 .30361 L
.51303 .3043 L
.51373 .30494 L
.51496 .30578 L
.51565 .3061 L
.51639 .30632 L
.5177 .30639 L
.51892 .3061 L
.52006 .30551 L
.52131 .30452 L
.52265 .30306 L
.52535 .29891 L
.52828 .29263 L
.53363 .27692 L
.54366 .23634 L
.55468 .18444 L
.56503 .13853 L
.57512 .10237 L
.58438 .0779 L
.59355 .06075 L
.59817 .05416 L
.60323 .04813 L
.60832 .04307 L
.61376 .03859 L
Mistroke
.61853 .03541 L
.62358 .03278 L
.62611 .03177 L
.62889 .0309 L
.63011 .03059 L
.63142 .03033 L
.63266 .03013 L
.63379 .03 L
.63447 .02994 L
.6352 .02989 L
.63651 .02986 L
.63731 .02987 L
.63806 .0299 L
.63874 .02994 L
.63947 .03001 L
.64084 .03018 L
.64229 .03043 L
.64488 .03106 L
.64727 .03184 L
.64984 .03289 L
.65447 .03529 L
.65999 .03897 L
.66501 .04313 L
.66982 .04788 L
.67492 .05393 L
.68409 .06829 L
.68918 .07883 L
.69395 .09078 L
.70485 .12647 L
.72331 .20915 L
.73378 .25683 L
.73888 .27628 L
.74352 .29041 L
.74591 .29611 L
.74717 .29863 L
.7485 .30094 L
.74967 .30263 L
.75095 .30414 L
.75211 .30519 L
.75321 .30589 L
.75384 .30617 L
.75454 .30636 L
.75581 .30643 L
.75705 .30612 L
.75819 .30553 L
.75889 .30501 L
.75956 .30442 L
.76079 .30305 L
.76355 .29874 L
.76612 .29327 L
Mistroke
.76884 .28607 L
.77369 .26995 L
.78465 .22294 L
.79487 .1746 L
.80454 .13288 L
.81396 .10014 L
.82266 .07754 L
.83202 .0602 L
.83696 .05327 L
.8422 .04717 L
.85215 .03833 L
.85781 .03467 L
.86057 .03325 L
.86313 .03214 L
.86559 .03127 L
.86783 .03067 L
.86911 .0304 L
.87032 .03019 L
.8716 .03003 L
.87231 .02997 L
.87298 .02992 L
.87422 .02988 L
.87538 .02989 L
.87665 .02996 L
.87736 .03002 L
.87801 .03009 L
.87932 .03028 L
.88075 .03055 L
.88334 .03122 L
.88555 .03197 L
.888 .03297 L
.89295 .03556 L
.90185 .04202 L
.90676 .04664 L
.91192 .05249 L
.92117 .06638 L
.92632 .07665 L
.93112 .08825 L
.94201 .12298 L
.97619 .27348 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^@?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hLooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=_ooool0
03Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Oooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`12ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0=_ooool002oooooo1_l00006ooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41005?ooool6o`0000Gooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@01gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01oo
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03Cooooo000jooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000012ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`00>Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000007oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000@_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
7oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool00000=_ooool003[ooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@023ooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@03Kooooo000gooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0@_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL07?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Kooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Ko
oooo000gooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Ooo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0@?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Kooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo000Koooooooo0000<_l0000Looooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Pooooo`00>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo001:ooooo`Co0000A?ooool5o`0001cooooo00?o0000ooooooooool0
9?ooool5o`0004Cooooo1Ol00010ooooo`00B?ooool3o`0000?ooooo0ol0000nooooo`Co00001?oo
ool2o`0001[ooooo0_l0000Sooooo`?o00001?ooool3o`0003kooooo0ol00004ooooo`?o0000?_oo
ool004Kooooo0_l00009ooooo`;o0000>oooool00ol0003oooooooooo`08ooooo`;o00006?ooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Sooooo0_l0000kooooo`;o00002Oooool2
o`0003cooooo0015ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool07oooool2o`00
00gooooo00?o0000ooooooooool0=_ooool2o`0000gooooo00?o0000ooooooooool0>Oooool004?o
oooo0_l0000?ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03Oooool2o`0001Go
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0hooooo`00@_ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0Booooo`;o00007_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0gooooo`00@_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0=_ooool0047ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03Gooooo0011oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0eoooo
o`00@?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool0=?ooool003oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0/ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool03oooool2o`0001[ooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
<oooool003kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo03;ooooo000nooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0
0004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo03;ooooo000mooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`07ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo
00GoV9RHob4Q8Oo^k^ko0000odA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0aooooo`00?Oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool02?ooool01Ol@413ooooooooooooooooo410@00co
oooo00CoV9RHob4Q8Oo^k^ko00002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool0<Oooool003gooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`00000=oooo
o`03oiRHV?lQ8B7o000000Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0001Oooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool0<Oooool003cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMol0003ooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool0<?ooool003_ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo00[ooooo00Go410@oooooooooooooooooa0@400?ooooo`;o00000oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0<?ooool0
03_ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
00[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`06o`000?nj^[[ooooooiRHV?l@413o0000
0oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
;oooool003[ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo00[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`06oiRHV?l@413o0000ob4Q8Oo<
c<co00000oooool4o`0000Kooooo0_l0000Fooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02oooooo000jooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0_ooooo`00
>_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
;_ooool003Wooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo02kooooo000iooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`0^ooooo`00>Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`09ooooo`;o00005Oooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0]ooooo`00>?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool0;Oooool003Sooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo02gooooo000hooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0/ooooo`00>?ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0;?ooool003Sooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool02?ooool2o`0001?ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0;?ooool003Oooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02cooooo000gooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0[ooooo`00=ooo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0:ooo
ool003Oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool01oooool2o`0001;ooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0:oooool0
03Kooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
02_ooooo000fooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0[ooooo`00=_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool05oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
02[ooooo000fooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0Gooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00Co0000oooo
oomgMgOo<S8b1Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02[ooooo000eoooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Hoooo
o`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooo`000005ooooo`?o00004?ooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`0Zooooo`00=Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000kooooo00?o0000
ogMgMolb<S801Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo02[ooooo000eoooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Hoooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`0Yooooo`00=Oooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooool000001oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo02cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo02Wooooo000dooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool01?l0003ooooooooo
ool00006ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0:Oooool003Cooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Wooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`00013ooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
:Oooool003Cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo02cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo02Wooooo000dooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`0Xooooo`00<oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool0:?ooool003?ooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool00oooool2o`0000oo
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool0:?ooool003?ooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo02Sooooo000cooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`0Xooooo`00<oooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool09oooool003;ooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02Oooooo000booooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo00;ooooo0_l0000>ooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02Oooooo000booooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Wooooo`00<_oo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0<_oo
ool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool09_ooool0037ooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03?ooooo00Go
0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo02Kooooo000aooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0cooooo`05o`000?oo
ooooooooooooool000003_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Vooooo`00<Oooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<oooool01?l0003ooooooooo
ooooool2o`0000gooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo03?ooooo00?o0000ooooooooool09_ooool0037ooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03?ooooo00Go0000oooooooooooooooo
o`00000=ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo02Kooooo000`ooooo`03o`000?oooooooooo03Cooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;o
oooo00Co0000oooooooooooo00003Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Uooooo`00<?ooool00ol0003o
ooooooooo`0dooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool05Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00GoMgMgoc8b
<_ooooooooooo`000002ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool09Oooool0
033ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
01Gooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00Co0000
oooooooooooo00000_ooool3o`0000_ooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool09Oooool0033ooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Gooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00GoMgMgoc8b<_oooooooooo
o`000002ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool09Oooool0033ooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Gooooo00Go
0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c002ooooo`04o`000?ooooooooooo`0000cooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool09?ooool002oo
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Ko
oooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooo`00000<ooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Cooooo000_ooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Fooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooo`00000<ooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Cooooo000_oooo
o`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Foooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00004ooooo`04o`000?oooooo
0000o`0000[ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool09?ooool002oooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooool000002oooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`0Tooooo`00;_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0>?ooool00ol0003oooooo`00000;ooooo`03o`000?oooooooooo
03Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
02?ooooo000^ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooo000000_ooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool08oooool002kooooo
00?o0000ooooooooool0>Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Wooooo
0_l0000:ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0hooooo`03o`000?oooooooooo02?ooooo000^ooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0iooooo`?o00002Oooool00ol0003ooooooooo
o`0iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>?ooool00ol0003ooooooooo
o`0Sooooo`00;_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0>_ooool2o`0000[ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool08oooool002gooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03[ooooo0_l0000:oooo
o`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0joooo
o`03o`000?oooooooooo02;ooooo000Sooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0>_ooool00ol0003oooooooooo`0Rooooo`008oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo05oooooo000Sooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03_ooooo0_l00008ooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Pooooo`009?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0looooo`;o00002?ooool00ol0003oooooooooo`0looooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0H?ooool002Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0??ooool2o`00
00Oooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
063ooooo000Tooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo03cooooo0_l00007ooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Pooooo`009Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0mooooo`?o00001_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0HOooool002Gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0?Oooool00ol0003oooooo`00
0006ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1Qooooo`009Oooool2o`0000Cooooo00?o0000ooooooooool0?oooool2o`0000Cooooo00?o0000
ooooooooool0<oooool4o`000003oa0@4?oooooooooo00?ooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H_oo
ool002Kooooo00?o0000ooooooooool00_l00013ooooo`;o000000?oooooo`000?l00000>?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o00000_ooool00ol0003oooooooooo`12
ooooo`04o`000?ooooooooooo`0006Gooooo000Wooooo`?o0000AOooool3o`0003Wooooo00?o0000
ooooooooool01Oooool01?l0003oooooooooooooool3o`0004Kooooo0ol0001Uooooo`00Zoooool0
0ol0003oooooooooo`05ooooo`?o0000/_ooool00:_ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`2booooo`00Zoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;;o
oooo002[ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/_ooool00:Wooooo00?o
EEEEofIVI_l000001oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002coooo
o`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`00
0?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool0
0;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo
00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2b
ooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00
/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooo
oooo0;;ooooo002Aooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Cooooo1Ol00004oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2booooo`00Toooool00ol0
003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`0;oooo
o`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`000;;ooooo002Cooooo`03
o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool0
0oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/_ooool009?ooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool02_ooool01Ol0003o^[Zjoooo
oonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2booooo`00TOoo
ool00omEEEGoIVIVo`00000<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo
0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2b
ooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00
/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooo
oooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo
00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000
ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00
/oooool00ol0003oooooooooo`2booooo`00VOooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2booooo`00Vooo
ool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0;;ooooo002Kooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`2booooo`00Voooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo
00Cooooo0ol0002booooo`00Voooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`2booooo`00Voooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_ooool009_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;;ooooo002Iooooo`03oeEEEOmV
IVKo000000gooooo1?l00006ooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool0
0;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo
00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2b
ooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00
/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooo
oooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;o
oooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000
ooooooooool0/_ooool0097ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_ooool00ol0
003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2b
ooooo`00Toooool00ol0003oooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000oooooooo
ool03?ooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002booooo`00
Toooool00ol0003oooooooooo`0=ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`0=ooooo`03oeEEEOo<
c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;;ooooo
002Cooooo`03o`000?oooooooooo00gooooo00?oZJVYogMgMoooool00oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00[ooooo00Go410@
oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_oo
ool0097ooooo00?oEEEEofIVI_l000003?ooool5o`0000Cooooo1?l00006ooooo`;o0000/oooool0
0;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo
00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002c
ooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00
/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooo
oooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;o
oooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000
ooooooooool0/_ooool00:Sooooo1Ol00006ooooo`03o`000?oooooooooo0;;ooooo002Xooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`2booooo`00ZOooool00onHV9So
8B4Qonk^kP07ooooo`03o`000?oooooooooo0;;ooooo002Zooooo`03oiRHV?lQ8B7ok^k^00Kooooo
0ol0002booooo`00Zoooool00omgMgOoIVIVooooo`2jooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00Z?ooool01Ol0003o^[ZjoooooonHV9So410@0;_ooooo002Xooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`0^oooool00?ooooooJOooool00:kooooo00?o0000okZj^_ooool0]oooool00:kooooo
0_lb<S:hooooo`00Ooooool2o`000006oa0@4?oooooooooooa0@4?l0003o410@6?ooool4o`000005
oa0@4?oooooooooooooooom4A4@00_l000001olb<S;ogMgMooooooooooooQhN7o`000?nj^[X03?oo
ool01OnHV9So0000o`000?m4A4Co^[Zj01Wooooo1?l000001Ol@413oooooooooooooooooA4A400;o
000000Wo<S8bomgMgOooooooooooonk^k_lb<S;o0000oc8b<_o^k^h0NOooool0083ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00003?ooool00ol0003oooooooooo`06
ooooo`07ogMgMolb<S;oooooooooooo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@
41002Oooool6o`0000cooooo00?o0000ooooooooool01_ooool02OmgMgOo<S8booooooooooooMgMg
oiRHV?ooooooV9RHogMgM`1iooooo`00P?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool01oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oo
oooooooo07Oooooo0020ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000cooooo
00?o0000ooooooooool01_ooool00omgMgOo<S8booooo`0@ooooo`03o`000?oooooooooo00_ooooo
1_l0000<ooooo`03o`000?oooooooooo00Kooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03
o`000?oooooooooo07Oooooo0020ooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo00006oooool00ol0
003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`04Oooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?oo
ooooooooooooool00000NOooool0083ooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Kooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol@413o0000o`000003o`0001co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05oa0@4?oooooooooooooo
ool@4100NOooool0083ooooo00Ko0000oc8b<_oooooooooooc8b<_l0000Kooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg07Wooooo001o
ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool00omEEEGoIVIVo`000005
ooooo`Co00004_ooool00ol0003oooooooooo`0Kooooo`03oeEEEOmVIVKo000000Gooooo1?l00003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0NOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-44.3769, -0.160437, \
0.309031, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.01333 0 0.309017 [
[.1001 -0.0125 -9 -9 ]
[.1001 -0.0125 9 0 ]
[.2334 -0.0125 -9 -9 ]
[.2334 -0.0125 9 0 ]
[.3667 -0.0125 -9 -9 ]
[.3667 -0.0125 9 0 ]
[.6333 -0.0125 -6 -9 ]
[.6333 -0.0125 6 0 ]
[.7666 -0.0125 -6 -9 ]
[.7666 -0.0125 6 0 ]
[.8999 -0.0125 -6 -9 ]
[.8999 -0.0125 6 0 ]
[.4875 .07725 -24 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -18 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -24 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1001 0 m
.1001 .00625 L
s
[(-30)] .1001 -0.0125 0 1 Mshowa
.2334 0 m
.2334 .00625 L
s
[(-20)] .2334 -0.0125 0 1 Mshowa
.3667 0 m
.3667 .00625 L
s
[(-10)] .3667 -0.0125 0 1 Mshowa
.6333 0 m
.6333 .00625 L
s
[(10)] .6333 -0.0125 0 1 Mshowa
.7666 0 m
.7666 .00625 L
s
[(20)] .7666 -0.0125 0 1 Mshowa
.8999 0 m
.8999 .00625 L
s
[(30)] .8999 -0.0125 0 1 Mshowa
.125 Mabswid
.12676 0 m
.12676 .00375 L
s
.15342 0 m
.15342 .00375 L
s
.18008 0 m
.18008 .00375 L
s
.20674 0 m
.20674 .00375 L
s
.26006 0 m
.26006 .00375 L
s
.28672 0 m
.28672 .00375 L
s
.31338 0 m
.31338 .00375 L
s
.34004 0 m
.34004 .00375 L
s
.39336 0 m
.39336 .00375 L
s
.42002 0 m
.42002 .00375 L
s
.44668 0 m
.44668 .00375 L
s
.47334 0 m
.47334 .00375 L
s
.52666 0 m
.52666 .00375 L
s
.55332 0 m
.55332 .00375 L
s
.57998 0 m
.57998 .00375 L
s
.60664 0 m
.60664 .00375 L
s
.65996 0 m
.65996 .00375 L
s
.68662 0 m
.68662 .00375 L
s
.71328 0 m
.71328 .00375 L
s
.73994 0 m
.73994 .00375 L
s
.79326 0 m
.79326 .00375 L
s
.81992 0 m
.81992 .00375 L
s
.84658 0 m
.84658 .00375 L
s
.87324 0 m
.87324 .00375 L
s
.07344 0 m
.07344 .00375 L
s
.04678 0 m
.04678 .00375 L
s
.02012 0 m
.02012 .00375 L
s
.92656 0 m
.92656 .00375 L
s
.95322 0 m
.95322 .00375 L
s
.97988 0 m
.97988 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .07725 m
.50625 .07725 L
s
[(0.25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(0.75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(1)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(1.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(1.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(1.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(155) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .16356 m
.03279 .20583 L
.04262 .25115 L
.04758 .27094 L
.0503 .28036 L
.05288 .28812 L
.05528 .29422 L
.05789 .29953 L
.05904 .3014 L
.06026 .30307 L
.0613 .30423 L
.06244 .30522 L
.06314 .30567 L
.06378 .30599 L
.06505 .30634 L
.0662 .30633 L
.06743 .30597 L
.06813 .30561 L
.06888 .3051 L
.07025 .30384 L
.07157 .3022 L
.0728 .30035 L
.07751 .29022 L
.07989 .28347 L
.0825 .27491 L
.10458 .17674 L
.1146 .13321 L
.12409 .10003 L
.12933 .08551 L
.13503 .07256 L
.14017 .06306 L
.145 .05569 L
.1544 .04461 L
.1594 .04008 L
.16478 .03609 L
.17012 .03302 L
.1728 .03183 L
.17574 .03081 L
.17825 .03017 L
.17966 .02992 L
.18094 .02974 L
.18214 .02964 L
.18343 .02958 L
.18466 .02959 L
.18579 .02964 L
.18704 .02976 L
.18823 .02991 L
.1893 .0301 L
.19046 .03035 L
.19306 .03108 L
Mistroke
.19548 .03195 L
.19987 .03402 L
.20455 .03686 L
.21013 .04104 L
.21538 .04579 L
.22006 .0508 L
.22519 .05734 L
.23498 .074 L
.24032 .08621 L
.24531 .1 L
.26379 .17215 L
.28247 .25852 L
.28758 .27771 L
.29038 .28648 L
.29301 .29341 L
.29543 .29856 L
.29764 .30217 L
.29884 .30368 L
.3001 .3049 L
.30137 .30577 L
.30209 .30609 L
.30275 .30628 L
.30345 .30637 L
.30409 .30636 L
.30479 .30623 L
.30553 .30597 L
.30678 .30524 L
.30749 .30467 L
.30815 .30403 L
.31051 .30094 L
.31305 .29626 L
.316 .28915 L
.31879 .28089 L
.32403 .262 L
.34417 .16988 L
.3538 .12893 L
.36405 .09457 L
.3728 .0732 L
.38246 .05653 L
.38737 .05014 L
.39254 .04453 L
.40179 .03683 L
.40694 .0337 L
.41174 .03156 L
.4145 .03068 L
.4158 .03035 L
.417 .0301 L
.41839 .02988 L
.41912 .02979 L
.4199 .02972 L
Mistroke
.4212 .02965 L
.42194 .02963 L
.42263 .02964 L
.42388 .02969 L
.42458 .02974 L
.42521 .02981 L
.42644 .02997 L
.4276 .03017 L
.43021 .0308 L
.43302 .03174 L
.43817 .0341 L
.4429 .03698 L
.45191 .04423 L
.45689 .04932 L
.46143 .0548 L
.47091 .06978 L
.47614 .08073 L
.48108 .09332 L
.48987 .12166 L
.49942 .16088 L
.51882 .25118 L
.52413 .27229 L
.52692 .28177 L
.52986 .29029 L
.53244 .29642 L
.53381 .2991 L
.53527 .30152 L
.53661 .30333 L
.53783 .30462 L
.53906 .30557 L
.54022 .30615 L
.54139 .30641 L
.54249 .30636 L
.54369 .30598 L
.54499 .3052 L
.54564 .30467 L
.54634 .30397 L
.54762 .30242 L
.55003 .29851 L
.55231 .29369 L
.55473 .28742 L
.55908 .27349 L
.57951 .18264 L
.58983 .1371 L
.60097 .09803 L
.6061 .08413 L
.6115 .07202 L
.61656 .06272 L
.62116 .05569 L
.63067 .04445 L
Mistroke
.63591 .03975 L
.64085 .03612 L
.64543 .03345 L
.64965 .0316 L
.65186 .03087 L
.65429 .03026 L
.65551 .03004 L
.65683 .02985 L
.65807 .02973 L
.6592 .02968 L
.66049 .02967 L
.6617 .02971 L
.66279 .02979 L
.66397 .02993 L
.66525 .03014 L
.66661 .03042 L
.66904 .03108 L
.6734 .03274 L
.67818 .03524 L
.68335 .03867 L
.68889 .0432 L
.6989 .05395 L
.70418 .06142 L
.70907 .06984 L
.71433 .08092 L
.72013 .09603 L
.72988 .12895 L
.74025 .17342 L
.75046 .22192 L
.75603 .24734 L
.76121 .2685 L
.76602 .28482 L
.77039 .29607 L
.77289 .30076 L
.77404 .30245 L
.77525 .30392 L
.77655 .30512 L
.77774 .30588 L
.77903 .30633 L
.77976 .30641 L
.78044 .30638 L
.78168 .30603 L
.78283 .30539 L
.78409 .30433 L
.78544 .30281 L
.78793 .29892 L
.79018 .29424 L
.79477 .28163 L
.79908 .26648 L
.81912 .17554 L
Mistroke
.8289 .13316 L
.83922 .09755 L
.84804 .07527 L
.85771 .05797 L
.86296 .0509 L
.86793 .04533 L
.87725 .03728 L
.88246 .03398 L
.88727 .03173 L
.88979 .03086 L
.89123 .03046 L
.89256 .03017 L
.89395 .02992 L
.89469 .02982 L
.89545 .02974 L
.89675 .02964 L
.89749 .02962 L
.89817 .02961 L
.89945 .02964 L
.9001 .02968 L
.90081 .02974 L
.90206 .02989 L
.90323 .03009 L
.90588 .03069 L
.90871 .03161 L
.91391 .03395 L
.91866 .03677 L
.9282 .04437 L
.93726 .05431 L
.94689 .0693 L
.95175 .07934 L
.95713 .09287 L
.96662 .12376 L
.97554 .16063 L
.97619 .16356 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^@?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hLooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=_ooool0
03Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Oooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`12ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0=_ooool002oooooo1_l00006ooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41005?ooool6o`0000Gooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@01gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01oo
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03Cooooo000jooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000012ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`00>Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000007oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000@_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
7oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool00000=_ooool003[ooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@023ooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@03Kooooo000gooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0@_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL07?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Kooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Ko
oooo000gooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Ooo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0@?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Kooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo000Koooooooo0000<_l0000Looooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Pooooo`00>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo001Aooooo`Go0000@oooool5o`0001Gooooo00?o0000ooooooooool0
;?ooool5o`0004?ooooo1Ol0000iooooo`00C_ooool4o`0000Cooooo0ol0000mooooo`?o00001Ooo
ool2o`0001?ooooo0_l0000Zooooo`?o00001?ooool3o`0003gooooo1?l00005ooooo`?o0000=_oo
ool004gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo00Sooooo0ol0000@ooooo`03o`000?oooooooooo02Oooooo0_l0000:ooooo`;o0000>_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03?ooooo001<ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0booooo`00Boooool00ol0003o
ooooooooo`0=ooooo`;o0000=_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0aooooo`00B_ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool03oooool2o`0000gooooo
0_l0000Vooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo033ooooo0019ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0_ooooo`00B?ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0;_ooool004Oooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02gooooo0017ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0]ooooo`00
A_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`08ooooo`;o00008Oooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0/ooooo`00A_oo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0:ooo
ool004Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Xooooo`08o`000?oooooo
ooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0:_ooool004Co
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Wooooo`09o`000?oooooooooooooo
oomgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool01?l0003oooooogMgMolb<S85ooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0:_ooool004Cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Vooooo`05o`00
0?ooooooooooooooool@41000oooool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo00?o0000ooooool000001Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Wo
oooo0014ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool09_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06ooooo`03
o`000?mgMgOo<S8b00Gooooo0ol0000Nooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Wooooo0013ooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000o`00
0?o<c<`01Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Wooooo0013ooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Xooooo`00@oooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`05o`000?oo
ooooooooooooool000001Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Sooooo
0012ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Co
oooo1Ol00005ooooo`;o00007_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Wooooo`00@_ooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool09oooool004;ooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02Oooooo0011
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0V
ooooo`00@Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool09_ooool0047ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo02?ooooo00Co0000oooooooooooooooo0_l0000Looooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
02Kooooo0010ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`0Sooooo`05o`000?ooooooooooooooool000007Oooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Uoooo
o`00@?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool09?ooool01Ol0003ooooooooooooooooo000001cooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool09Oooool0043o
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Go
oooo00Co0000oooooooooooo00007?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`00?oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09Oooool01?l0003o
ooooooooool0000Looooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo02Cooooo000oooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00;o
00006_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0Tooooo`00?oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool09_ooool01?l0003oooooooooool0000Kooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo02Cooooo000nooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo000001_ooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
9?ooool003kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooool000006_ooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Tooooo`00?_ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0:?ooool0
1?l0003oooooo`000?l0000Iooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02?ooooo000nooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
000001[ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool08oooool003gooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo02Wooooo0_l0000Jooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
02?ooooo000mooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@04ooooo`;o00006Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Sooooo`00?Oooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool04?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo0_l0000I
ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo02?ooooo000mooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0@ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`02ooooo`Co00005oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Rooooo`00??ooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool04?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo02;ooooo000looooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0@ooooo`05o`000?ooooooooooooooool000003?ooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0[ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0:oooool00ol0003ooooooooo
o`0Rooooo`008oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02_ooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`0@ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool08_oo
ool002?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02cooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`1@ooooo`008oooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0A
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0000Gooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Aooooo`008oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0/ooooo`;o00005oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0DOooool002Cooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0;?ooool2o`00
01Oooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
057ooooo000Tooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo02gooooo0_l0000Fooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Aooooo`009?ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0]ooooo`;o00005_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0D_ooool002Cooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0;Oooool00ol0003oooooo`00
000Eooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`1Booooo`009?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo000001Gooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo05;ooooo000Toooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo02gooooo00?o0000ooooool000005?ooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0D_ooool002Cooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooo`00000Dooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`1Booooo`009Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0^ooooo`;o0000
00?oooooo`000?ooool04_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0Doooool002Gooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0;_ooool01?l0003ooooooooo
ool0000Cooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`1Cooooo`009Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0^ooooo`04o`000?ooooooooooo`0001?ooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo05?ooooo
000Uooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0<_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo02kooooo00Co0000oooooooooooo00004_ooool00ol0003ooooo
ooooo`0booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0Doooool002Gooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0;oooool01?l0003oooooooooool0000Booooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Cooooo`009_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0_ooooo`;o00000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`1Dooooo`009_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0_
ooooo`05o`000?ooooooooooooooool000004Oooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0E?ooool002Kooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`05o`000?ooooooooooooooool000004?ooool00ol0003o
ooooooooo`0dooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0E?ooool002Kooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool03Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03
oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool01Ol0003ooooooooooooooooo0000
013ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
05Cooooo000Wooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00Go410@oooooooooooooooooa0@400=oooo
o`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`0000;ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0EOooool002Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool01Ol0003ooooooooooooooooo0000
00kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool0EOooool002Oooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool01Ol0003o
oooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Eooooo`009oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1E
ooooo`009oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0=oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo05Gooooo000Xooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l00004ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo05Kooooo000Xooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`1Fooooo`00:?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0E_ooool002Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo05Kooooo000Yooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Fooooo`00:Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0booooo`;o00001Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`1Gooooo`00:_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0b
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Eoooool002[ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05Oooooo000Zooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo03[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Hooooo`00
:oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
F?ooool002_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0looooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0=?ooool2o`0000Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0F?oo
ool002_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0looooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo05Wooooo000[ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Iooooo`00:oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0F_ooool002cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=Oooool2o`0000Oooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0F_ooool002cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0=_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0?oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo05[ooooo000]ooooo`05o`000?ooooooooooooooool00000@ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02cooooo1?l000000ol@413ooooooooo
o`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`11ooooo`05o`000?ooooooooooooooool00000GOooool002gooooo0_l00002ooooo`03o`000?oo
oooooooo04;ooooo00Co0000oooooooooooo0000<Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Sooooo00Co0000oooooooooooo0000A?ooool2o`0000;ooooo00?o0000oooooooo
ool0Foooool002kooooo0ol00015ooooo`Co0000<Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Sooooo1?l00015ooooo`?o0000G_ooool00:_ooooo00?o0000ooooooooool01Ooo
ool3o`000;;ooooo002[ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/_ooool0
0:_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2booooo`00Zoooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0;;ooooo002Yooooo`03oeEEEOmVIVKo000000Oooooo
00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2b
ooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00
/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooo
oooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;o
oooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000
ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooooooo
ool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00TOooool4
o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool01?ooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP09
ooooo`03o`000?oooooooooo00?ooooo0ol0002booooo`00Toooool00ol0003oooooooooo`0<oooo
o`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2boooo
o`00Toooool00ol0003oooooooooo`0=ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c005ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;;o
oooo002Cooooo`03o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_ooool0097ooooo00?oEEEEofIVI_l00000
3?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000/oooool00;?ooooo
00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000
ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00
/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool0
0ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;o
oooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000oooooooo
ool0/_ooool009Wooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/_ooool009_ooooo00?o0000ooooooooool0
1?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2booooo`00Vooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/_oo
ool009_ooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`04ooooo`?o0000/_ooool0
09_ooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000
ooooooooool0/_ooool009_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo0;;ooooo002Kooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`2booooo`00VOooool00omEEEGoIVIVo`00000=ooooo`Co0000
1_ooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooo
oooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;o
oooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000
ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooooooo
ool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool0
0ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002A
ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000
ooooooooool01?ooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00cooooo00?oZJVYoeEE
EOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000/_ooool009?ooooo00?o0000oooooooo
ool03Oooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0/_ooool009?ooooo00?o0000ooooooooool03Oooool00omEEEGoc<c<ooooo`03ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2booooo`00Toooool00ol0003ooooo
ooooo`0=ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`2booooo`00Toooool00ol0003oooooooooo`0:ooooo`05oa0@4?oooooooooooooooolb<S80
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;;ooooo002Aooooo`03oeEEEOmV
IVKo000000cooooo1Ol00004ooooo`Co00001_ooool2o`000;?ooooo002cooooo`03o`000?oooooo
oooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;o
oooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000
ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooooooo
ool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool0
0ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002X
ooooo`Go00001_ooool00ol0003oooooooooo`2booooo`00Z?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400Kooooo00?o0000ooooooooool0/_ooool00:Wooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0
003oooooooooo`2booooo`00Z_ooool00onHV9So8B4Qonk^kP06ooooo`?o0000/_ooool00:_ooooo
00?oMgMgofIVI_ooool0^_ooool00:cooooo00?o0000ooooooooool0^Oooool00:Sooooo00Go0000
okZj^_ooooooV9RHoa0@402kooooo`00Z?ooool01OnHV9So410@o`000?lQ8B7oc<c<0;_ooooo003o
ooooofWooooo002^ooooo`03o`000?nj^[[ooooo0;Oooooo002^ooooo`;o<S8b^?ooool007oooooo
0_l000001_l@413oooooooooool@413o0000oa0@41Sooooo1?l000001Ol@413ooooooooooooooooo
A4A400;o000000Oo<S8bomgMgOooooooooooohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003o
A4A4okZj^P0Iooooo`Co000000Go410@ooooooooooooooooodA4A002o`000003oc8b<_oMgMgooooo
00;ooooo00GoA4A4o`000?l0003o<S8bomgMg@1hooooo`00P?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Oooooo1_l0000<ooooo`03o`000?oooooooooo00Kooooo00OoMgMgoc8b
<_ooooooooooolc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko0000
3?ooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Gooooo00?oMgMgoc8b<_ooool0
Moooool0083ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1fooooo`00P?ooool0
1_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000<ooooo`03o`000?oooooooooo00Kooooo
00?oMgMgoc8b<_ooool04?ooool00ol0003oooooooooo`0;ooooo`Ko00003?ooool00ol0003ooooo
ooooo`06ooooo`03ogMgMolb<S;ooooo00Gooooo00?oMgMgoc8b<_ooool0Moooool0083ooooo00Ko
0000omgMgOlb<S;oEEEEomgMgOl0000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c00Aooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c01hooooo`00P?ooool0
1_l0003oQhN7ojVYZOnj^[[oEEEEo`0001_ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Aooooo`03oa0@4?l0003o000000?o00007?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0N_ooool0083ooooo00Ko0000oc8b<_oooooooooo
oc8b<_l0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`1jooooo`00Ooooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo
00?oEEEEofIVI_l000001Oooool4o`0001;ooooo00?o0000ooooooooool06oooool00omEEEGoIVIV
o`000005ooooo`Co00001?ooool4o`0007Wooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-44.3769, -0.160437, \
0.309031, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.01333 0 0.309017 [
[.1001 -0.0125 -9 -9 ]
[.1001 -0.0125 9 0 ]
[.2334 -0.0125 -9 -9 ]
[.2334 -0.0125 9 0 ]
[.3667 -0.0125 -9 -9 ]
[.3667 -0.0125 9 0 ]
[.6333 -0.0125 -6 -9 ]
[.6333 -0.0125 6 0 ]
[.7666 -0.0125 -6 -9 ]
[.7666 -0.0125 6 0 ]
[.8999 -0.0125 -6 -9 ]
[.8999 -0.0125 6 0 ]
[.4875 .07725 -24 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -18 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -24 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1001 0 m
.1001 .00625 L
s
[(-30)] .1001 -0.0125 0 1 Mshowa
.2334 0 m
.2334 .00625 L
s
[(-20)] .2334 -0.0125 0 1 Mshowa
.3667 0 m
.3667 .00625 L
s
[(-10)] .3667 -0.0125 0 1 Mshowa
.6333 0 m
.6333 .00625 L
s
[(10)] .6333 -0.0125 0 1 Mshowa
.7666 0 m
.7666 .00625 L
s
[(20)] .7666 -0.0125 0 1 Mshowa
.8999 0 m
.8999 .00625 L
s
[(30)] .8999 -0.0125 0 1 Mshowa
.125 Mabswid
.12676 0 m
.12676 .00375 L
s
.15342 0 m
.15342 .00375 L
s
.18008 0 m
.18008 .00375 L
s
.20674 0 m
.20674 .00375 L
s
.26006 0 m
.26006 .00375 L
s
.28672 0 m
.28672 .00375 L
s
.31338 0 m
.31338 .00375 L
s
.34004 0 m
.34004 .00375 L
s
.39336 0 m
.39336 .00375 L
s
.42002 0 m
.42002 .00375 L
s
.44668 0 m
.44668 .00375 L
s
.47334 0 m
.47334 .00375 L
s
.52666 0 m
.52666 .00375 L
s
.55332 0 m
.55332 .00375 L
s
.57998 0 m
.57998 .00375 L
s
.60664 0 m
.60664 .00375 L
s
.65996 0 m
.65996 .00375 L
s
.68662 0 m
.68662 .00375 L
s
.71328 0 m
.71328 .00375 L
s
.73994 0 m
.73994 .00375 L
s
.79326 0 m
.79326 .00375 L
s
.81992 0 m
.81992 .00375 L
s
.84658 0 m
.84658 .00375 L
s
.87324 0 m
.87324 .00375 L
s
.07344 0 m
.07344 .00375 L
s
.04678 0 m
.04678 .00375 L
s
.02012 0 m
.02012 .00375 L
s
.92656 0 m
.92656 .00375 L
s
.95322 0 m
.95322 .00375 L
s
.97988 0 m
.97988 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .07725 m
.50625 .07725 L
s
[(0.25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(0.75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(1)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(1.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(1.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(1.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(160) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .07931 m
.03279 .10319 L
.04262 .13874 L
.06244 .2305 L
.07298 .27476 L
.07602 .28478 L
.07889 .29272 L
.08146 .29845 L
.08291 .30104 L
.08426 .30305 L
.08553 .30457 L
.0867 .30562 L
.08799 .30642 L
.08871 .3067 L
.08939 .30685 L
.09004 .30689 L
.09074 .30682 L
.09199 .3064 L
.09275 .30597 L
.09348 .30544 L
.09482 .30411 L
.09601 .3026 L
.09727 .30066 L
.09951 .29633 L
.10458 .28281 L
.10954 .26526 L
.11406 .24643 L
.12422 .19892 L
.14255 .11929 L
.15246 .08842 L
.16164 .06804 L
.16642 .05995 L
.1717 .05257 L
.17691 .04657 L
.1824 .04135 L
.18722 .03757 L
.19249 .03425 L
.19481 .03307 L
.19728 .032 L
.1996 .03119 L
.20174 .03061 L
.20305 .03034 L
.20444 .03012 L
.20516 .03003 L
.20583 .02996 L
.20657 .02991 L
.20736 .02987 L
.20805 .02986 L
.20879 .02987 L
.20949 .02989 L
Mistroke
.21014 .02993 L
.21136 .03005 L
.21267 .03023 L
.21396 .03048 L
.21536 .0308 L
.21788 .03156 L
.2226 .03354 L
.22753 .03633 L
.23213 .03955 L
.2376 .04411 L
.24258 .04905 L
.25276 .06222 L
.25836 .07197 L
.26366 .08342 L
.27333 .11118 L
.2836 .15095 L
.30204 .23738 L
.31143 .276 L
.31401 .28445 L
.31671 .29206 L
.31905 .29746 L
.32034 .29994 L
.32155 .30194 L
.32269 .30353 L
.32392 .30491 L
.32505 .30586 L
.32608 .30647 L
.32705 .30681 L
.32813 .30693 L
.32924 .30677 L
.33029 .30635 L
.33153 .30552 L
.3327 .3044 L
.3349 .30146 L
.33726 .29709 L
.33984 .291 L
.34468 .27617 L
.34922 .25886 L
.35959 .21192 L
.36982 .16369 L
.38059 .11953 L
.39021 .0894 L
.39567 .07625 L
.40075 .06623 L
.40969 .05269 L
.41925 .04239 L
.42456 .03804 L
.42947 .03483 L
.43486 .03219 L
.43757 .03122 L
Mistroke
.43911 .03079 L
.44057 .03046 L
.44182 .03024 L
.44248 .03014 L
.44318 .03006 L
.44443 .02996 L
.44558 .02991 L
.44628 .0299 L
.44704 .02992 L
.44775 .02995 L
.44841 .03 L
.44965 .03013 L
.45097 .03033 L
.45213 .03055 L
.45337 .03085 L
.45561 .03151 L
.46071 .03361 L
.466 .03661 L
.47089 .04006 L
.47616 .04452 L
.48197 .05042 L
.49173 .06354 L
.49707 .07315 L
.50209 .08423 L
.51193 .11293 L
.52229 .15357 L
.5408 .24039 L
.55035 .27878 L
.5531 .28738 L
.5557 .29421 L
.55806 .29922 L
.55935 .30145 L
.56056 .30321 L
.5617 .30456 L
.56274 .30553 L
.5639 .30632 L
.56514 .30681 L
.56618 .30693 L
.56731 .30678 L
.56838 .30636 L
.56937 .30573 L
.57063 .3046 L
.5718 .30321 L
.574 .29978 L
.57637 .2949 L
.57893 .28835 L
.58847 .25412 L
.59892 .206 L
.60996 .15453 L
.62 .11482 L
Mistroke
.62482 .09923 L
.63006 .0849 L
.63957 .06501 L
.64485 .05671 L
.65045 .04951 L
.6557 .04395 L
.6605 .0397 L
.665 .03639 L
.6699 .03351 L
.67259 .03227 L
.67509 .03134 L
.67748 .03066 L
.67881 .03037 L
.68002 .03016 L
.68117 .03001 L
.68238 .02991 L
.68341 .02986 L
.68455 .02986 L
.68577 .0299 L
.68708 .03001 L
.68832 .03018 L
.68944 .03037 L
.69163 .03088 L
.694 .03161 L
.69832 .0334 L
.70317 .03608 L
.70772 .03917 L
.71809 .04832 L
.72819 .06099 L
.73388 .0706 L
.73909 .08156 L
.74889 .10905 L
.75801 .14337 L
.76865 .19186 L
.7787 .23957 L
.78851 .279 L
.7912 .28738 L
.79405 .29477 L
.79648 .29978 L
.79785 .30204 L
.79915 .30379 L
.80031 .30503 L
.80157 .30602 L
.80272 .3066 L
.80378 .30686 L
.80504 .30682 L
.80619 .30645 L
.80751 .30565 L
.80875 .30453 L
.80985 .30324 L
Mistroke
.811 .30159 L
.81307 .29789 L
.81774 .28629 L
.82271 .26958 L
.82723 .25129 L
.8374 .20418 L
.85575 .12324 L
.86568 .09128 L
.87486 .07009 L
.87965 .06166 L
.88494 .05399 L
.89015 .04774 L
.89563 .04229 L
.90047 .03831 L
.90575 .03479 L
.90807 .03352 L
.91055 .03236 L
.91287 .03146 L
.91501 .0308 L
.9163 .03049 L
.91771 .03021 L
.91913 .03 L
.91991 .02992 L
.92064 .02986 L
.92133 .02983 L
.92198 .02981 L
.9232 .02983 L
.92451 .0299 L
.92526 .02997 L
.92595 .03005 L
.92713 .03023 L
.92823 .03045 L
.93076 .03111 L
.93322 .03195 L
.93588 .03309 L
.94524 .03874 L
.95056 .04299 L
.9555 .04767 L
.9655 .05988 L
.9711 .06902 L
.97619 .07931 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^@?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hLooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=_ooool0
03Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Oooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`12ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0=_ooool002oooooo1_l00006ooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41005?ooool6o`0000Gooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@01gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01oo
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03Cooooo000jooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000012ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`00>Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000007oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000@_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
7oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool00000=_ooool003[ooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@023ooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@03Kooooo000gooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0@_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL07?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Kooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Ko
oooo000gooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Ooo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0@?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Kooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo000Koooooooo0000<_l0000Looooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Pooooo`00>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo001Hooooo`Go0000A?ooool4o`0000kooooo00?o0000ooooooooool0
<oooool4o`0004Cooooo1Ol0000booooo`00E_ooool3o`0000Cooooo0ol0000oooooo`?o00000ooo
ool4o`0000[ooooo0_l0000aooooo`?o00001?ooool4o`0003kooooo0ol00004ooooo`?o0000;ooo
ool005Gooooo0_l00009ooooo`;o0000>oooool2o`0000[ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo02cooooo001Dooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0=_ooool2o`0000gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0=oooool2o`00
00cooooo0_l0000/ooooo`00D_ooool2o`0000kooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0Yooooo`00DOooool00ol0003oooooooooo`0?ooooo`;o0000=Oooool00ol0003ooooo
ooooo`0?ooooo`;o00001Oooool2o`0002gooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0:Oooool0053ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02Sooooo001?
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0W
ooooo`00Coooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02oooooo00?o0000oooo
ooooool05?ooool01Ol0003ooooooooooooooooo000002_ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool09_ooool0
04kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
01Gooooo00Go0000ooooooooooooooooo`00000[ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02Gooooo001>oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo00;o0000:Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Uooooo`00COooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool06?ooool01?l0003o
ooooooooool0000Yooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo02Cooooo001<ooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool09?ooool01_o^k^ko<S8bo`000?lb<S;ok^k^o`0000Cooooo0_lQ8B44
ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00?ooooo00?o0000ooooool00000:Ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Sooooo`00C?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo02?ooooo00GoMgMgoiRHV?ooooooV9RHo`000005ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^
k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool00oooool2o`0002Sooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
8oooool004_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Sooooo`05oa0@4?oo
ooooooooo`000?l@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00;ooooo
0_l0000Xooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo02;ooooo000Sooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00;o00003Ooo
ool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Uooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo02;ooooo000Sooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00;o00003_ooool00omgMgOoIVIVooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`12ooooo`008oooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool08_ooool0
1Ol@413oooooo`000?oooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`07ooooo`;o00009Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0@_ooool002Cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo027ooooo00GoMgMgoiRHV?l0003oV9RHogMgM`0;ooooo`05o`000?nj
^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`;o00009Oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0@_ooool002Cooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo027ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Ko
oooo0ol0000Tooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`13ooooo`009?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo000002?ooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo04?ooooo
000Uooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo01oooooo00?o0000ooooool000008oooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0@oooool002Gooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool07oooool01?l0003oooooooooool0000Rooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`14ooooo`009Oooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0P
ooooo`04o`000?ooooooooooo`00027ooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo04Cooooo000Uooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo023ooooo0_l00000
0ooooooo0000ooooo`0Pooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`14ooooo`009_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Pooooo`05o`000?oooooooooo
ooooool000008?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool0AOooool002Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool08Oooool01Ol0003ooooooooooooooooo
000001oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo04Gooooo000Vooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`00000O
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`15
ooooo`009oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool0A_ooool002Oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool08Oooool2o`0000?ooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool0A_ooool002Oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo04Kooooo000Wooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`16ooooo`00:?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool0Aoooool002Sooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool08oooool2o`00
00Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0Aoooool002Sooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo04Oooooo000Xooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`17ooooo`00:Oooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`08ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0B?ooool002Wooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool02Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`18ooooo`00
:Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`09ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003o
ooooooooo`03ooooo`?o00001?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02_o
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`18ooooo`00:Oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`09ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool0B?ooool002Wooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
2_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0[oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0BOooool002[ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool02_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo04Wooooo000Zooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00[o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`19ooooo`00:_ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0:ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l00006ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
04Wooooo000Zooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`1:ooooo`00:_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0B_ooool002_ooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo04[ooooo000[ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02Kooooo0_l00007
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo04[ooooo000[ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`1;ooooo`00:oooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool0Boooool002cooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04_ooooo000/ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1;ooooo`00;?ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0Wooooo`;o00002?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1<ooooo`00;?ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0C?ooool002co
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04co
oooo000]ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`1<ooooo`00;Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0COooool002gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0c
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0:?ooool2o`0000Wooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool0COooool002gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0coooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo04gooooo000]ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0<oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04gooooo000^oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool0
0omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`1=ooooo`00;_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
03Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`06ooooo`05oa0@4?oooooooooo
ooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol00008
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo04kooooo000^ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Kooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04kooooo000^ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00Oooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0C_oo
ool002oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool01oooool01Ol@413ooooooooooooooooo410@00kooooo00?o
ZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0C_ooool002oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03Kooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`1>ooooo`00;oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`07ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`;o0000
2_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`1?ooooo`00;oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo03Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0hooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0Coooool002oooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0>?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04oooooo000`ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
03Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1?ooooo`00<?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0[ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Coooool0033ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0:oooool2o`0000cooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0D?ooool0033ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0:oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo053ooooo000`
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1@
ooooo`00<Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0D?ooool0037ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo057ooooo000aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02cooooo0_l0000=ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo057ooooo000booooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`1Aooooo`00<_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo03gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0D_ooool003;ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0?Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo05;ooooo000cooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02ko
oooo0_l0000?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo05;ooooo000cooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0@?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`1Cooooo`00=?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Tooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`0?ooooo`05o`000?oo
ooooooooooooool00000@oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05?ooooo
000dooooo`;o00000_ooool00ol0003oooooooooo`12ooooo`05o`000?ooooooooooooooool00000
:Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00oooooo00Go0000oooooooooooo
ooooo`000013ooooo`;o00000_ooool00ol0003oooooooooo`1Dooooo`00=Oooool4o`0004Gooooo
0ol0000Zooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04?ooool3o`0004Gooooo
1?l0001Fooooo`00Zoooool00ol0003oooooooooo`05ooooo`?o0000/_ooool00:_ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2booooo`00Zoooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0;;ooooo002[ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0/_ooool00:Wooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2booooo`00/ooo
ool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo
0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o
0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0
003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo
002cooooo`03o`000?oooooooooo0;;ooooo002Aooooo`Co000000?o410@ooooooooool00_ooool2
ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooooooo
o`2booooo`00Toooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2booooo`00Toooool0
0ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3
o`000;;ooooo002Cooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h01oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00go
oooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0/_ooool009?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool0
2_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2booooo`00TOooool00omEEEGoIVIVo`00000<ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`01?ooool4o`0000Kooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0
003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002coooo
o`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0
/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool0
0;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00VOooool4o`000003oa0@
4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`2booooo`00Voooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo0;;ooooo002Kooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`2booooo`00Voooool00ol0003oooooooooo`0>
ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002booooo`00Voooool00ol0003oooooooooo`0;oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2booooo`00Voooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_ooool009_o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;;o
oooo002Iooooo`03oeEEEOmVIVKo000000gooooo1?l00006ooooo`03o`000?oooooooooo0;;ooooo
002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0
003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo
002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002coooo
o`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000
/oooool00;?ooooo00?o0000ooooooooool0/_ooool0097ooooo1?l000000ol@413oooooooooo`02
ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`04ooooo`;o8B4Q1_ooool0
0omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/_ooool0
09?ooooo00?o0000ooooooooool03?ooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo
00?ooooo0ol0002booooo`00Toooool00ol0003oooooooooo`0=ooooo`03ob4Q8Ooooooooooo00Ko
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2booooo`00Toooool00ol0003ooooo
ooooo`0=ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00gooooo00?oZJVYogMgMoooool0
0oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oo
oooooooo00[ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0/_ooool0097ooooo00?oEEEEofIVI_l000003?ooool5o`0000Cooooo1?l0
0006ooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0
/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0
003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo
002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002coooo
o`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000
/oooool00;?ooooo00?o0000ooooooooool0/_ooool00:Sooooo1Ol00006ooooo`03o`000?oooooo
oooo0;;ooooo002Xooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`2b
ooooo`00ZOooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0;;ooooo002Zooooo`03
oiRHV?lQ8B7ok^k^00Kooooo0ol0002booooo`00Zoooool00omgMgOoIVIVooooo`2jooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00Z?ooool01Ol0003o^[ZjoooooonHV9So410@0;_ooooo002X
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0^oooool00?ooooooJOooool00:kooooo00?o0000okZj
^_ooool0]oooool00:kooooo0_lb<S:hooooo`00Ooooool2o`000006oa0@4?oooooooooooa0@4?l0
003o410@6?ooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000001olb<S;ogMgMoooooooo
ooooQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Wooooo1?l000002?l@413o
ooooooooooo^k^ko<S8bo`000?l@413oc<c<0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07Wooooo
0020ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`0000cooooo00?o
0000ooooooooool01_ooool01omgMgOo<S8booooooooooooc<c<o`000?l@41003?ooool01Ol@413o
^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<ooooo`03o`000?oooooooooo00;ooooo00GoEEEEogMg
MoooooooV9RHob4Q8@03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0NOooool0083ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05oa0@4?ooooooooooooooool@4100NOooool0083ooooo00Ko
0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00003?ooool00ol0003oooooooooo`06ooooo`03
ogMgMolb<S;ooooo013ooooo00?o0000ooooooooool02oooool6o`0000cooooo00?o0000oooooooo
ool00_ooool01Ol0003oV9RHoooooonHV9So8B4Q00?ooooo00Go0000ooooooooooooooooo`00001i
ooooo`00P?ooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001_ooooo00?o0000ooooooooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<017ooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`02ooooo`05o`000?mEEEGo0000oa0@4?o<c<`00oooool01Ol0003ooooooooooooooooo0000
07Wooooo0020ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo00006oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo017ooooo00?o410@o`000?l000000ol0000Looooo`03o`000?oooooo
oooo00;ooooo00?oEEEEohN7Qoooool01Oooool01Ol@413ooooooooooooooooo410@07Wooooo0020
ooooo`06o`000?lb<S;ooooooooooolb<S;o00006oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02ooooo`03omgM
gOl@413oV9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1iooooo`00Ooooool00ol@413o0000
ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo00?oEEEEofIVI_l000001Oooool4o`0001;ooooo
00?o0000ooooooooool06oooool00omEEEGoIVIVo`000005ooooo`04olc<c?m4A4Co0000oa0@40?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP1iooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-44.3769, -0.160437, \
0.309031, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.01333 0 0.309017 [
[.1001 -0.0125 -9 -9 ]
[.1001 -0.0125 9 0 ]
[.2334 -0.0125 -9 -9 ]
[.2334 -0.0125 9 0 ]
[.3667 -0.0125 -9 -9 ]
[.3667 -0.0125 9 0 ]
[.6333 -0.0125 -6 -9 ]
[.6333 -0.0125 6 0 ]
[.7666 -0.0125 -6 -9 ]
[.7666 -0.0125 6 0 ]
[.8999 -0.0125 -6 -9 ]
[.8999 -0.0125 6 0 ]
[.4875 .07725 -24 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -18 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -24 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1001 0 m
.1001 .00625 L
s
[(-30)] .1001 -0.0125 0 1 Mshowa
.2334 0 m
.2334 .00625 L
s
[(-20)] .2334 -0.0125 0 1 Mshowa
.3667 0 m
.3667 .00625 L
s
[(-10)] .3667 -0.0125 0 1 Mshowa
.6333 0 m
.6333 .00625 L
s
[(10)] .6333 -0.0125 0 1 Mshowa
.7666 0 m
.7666 .00625 L
s
[(20)] .7666 -0.0125 0 1 Mshowa
.8999 0 m
.8999 .00625 L
s
[(30)] .8999 -0.0125 0 1 Mshowa
.125 Mabswid
.12676 0 m
.12676 .00375 L
s
.15342 0 m
.15342 .00375 L
s
.18008 0 m
.18008 .00375 L
s
.20674 0 m
.20674 .00375 L
s
.26006 0 m
.26006 .00375 L
s
.28672 0 m
.28672 .00375 L
s
.31338 0 m
.31338 .00375 L
s
.34004 0 m
.34004 .00375 L
s
.39336 0 m
.39336 .00375 L
s
.42002 0 m
.42002 .00375 L
s
.44668 0 m
.44668 .00375 L
s
.47334 0 m
.47334 .00375 L
s
.52666 0 m
.52666 .00375 L
s
.55332 0 m
.55332 .00375 L
s
.57998 0 m
.57998 .00375 L
s
.60664 0 m
.60664 .00375 L
s
.65996 0 m
.65996 .00375 L
s
.68662 0 m
.68662 .00375 L
s
.71328 0 m
.71328 .00375 L
s
.73994 0 m
.73994 .00375 L
s
.79326 0 m
.79326 .00375 L
s
.81992 0 m
.81992 .00375 L
s
.84658 0 m
.84658 .00375 L
s
.87324 0 m
.87324 .00375 L
s
.07344 0 m
.07344 .00375 L
s
.04678 0 m
.04678 .00375 L
s
.02012 0 m
.02012 .00375 L
s
.92656 0 m
.92656 .00375 L
s
.95322 0 m
.95322 .00375 L
s
.97988 0 m
.97988 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .07725 m
.50625 .07725 L
s
[(0.25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(0.75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(1)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(1.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(1.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(1.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(165) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04378 m
.03279 .05327 L
.04262 .06787 L
.04758 .07768 L
.05288 .09053 L
.06244 .12082 L
.0841 .21775 L
.08927 .24199 L
.09475 .26533 L
.09983 .28342 L
.10231 .29067 L
.10458 .29624 L
.10692 .30084 L
.10914 .30408 L
.11035 .30538 L
.11148 .30627 L
.11272 .30691 L
.11404 .30718 L
.11474 .30716 L
.11539 .30703 L
.1161 .30678 L
.11685 .30638 L
.11811 .30542 L
.1195 .30392 L
.12206 .30001 L
.12445 .29507 L
.1299 .27957 L
.13486 .26114 L
.14603 .21069 L
.15606 .16344 L
.16672 .11995 L
.17582 .0914 L
.18107 .07857 L
.18587 .06884 L
.19538 .05407 L
.20564 .04286 L
.21468 .03587 L
.21923 .0333 L
.22181 .03215 L
.2242 .03128 L
.22674 .03059 L
.22807 .03031 L
.22875 .0302 L
.22949 .03009 L
.23071 .02996 L
.23186 .02989 L
.23256 .02987 L
.23323 .02987 L
.23447 .02991 L
.2356 .03 L
Mistroke
.23679 .03014 L
.23792 .03033 L
.23894 .03053 L
.24145 .03119 L
.24381 .032 L
.24906 .03444 L
.25388 .0374 L
.25914 .04135 L
.26476 .04645 L
.26987 .05199 L
.27452 .05798 L
.28362 .07336 L
.28872 .08473 L
.29425 .09986 L
.3043 .13538 L
.32372 .22502 L
.33403 .26987 L
.33686 .27992 L
.33983 .28904 L
.3424 .29557 L
.34381 .29858 L
.34514 .30102 L
.3464 .30298 L
.34777 .30469 L
.34902 .30586 L
.35016 .30662 L
.35124 .30705 L
.35243 .3072 L
.35367 .307 L
.35483 .30647 L
.35549 .30604 L
.35621 .30545 L
.35751 .30407 L
.35994 .30044 L
.36279 .29455 L
.36543 .28762 L
.37465 .25416 L
.38445 .20907 L
.39403 .16394 L
.40412 .12242 L
.41274 .09464 L
.42217 .07232 L
.42701 .0636 L
.43218 .05587 L
.4415 .04501 L
.44711 .03995 L
.45241 .03605 L
.45718 .03331 L
.45967 .03218 L
.46234 .0312 L
Mistroke
.46365 .03081 L
.46489 .0305 L
.4661 .03026 L
.46722 .03008 L
.46828 .02996 L
.46941 .02987 L
.47066 .02983 L
.47179 .02984 L
.47244 .02987 L
.47313 .02992 L
.47437 .03005 L
.47505 .03015 L
.47569 .03026 L
.47715 .03055 L
.47959 .03121 L
.48219 .03214 L
.48785 .03489 L
.4932 .03833 L
.50323 .04687 L
.51289 .05836 L
.51777 .06596 L
.52315 .07627 L
.53266 .10076 L
.54158 .13211 L
.56007 .21671 L
.57055 .26372 L
.57565 .28219 L
.58029 .29506 L
.58268 .30001 L
.58394 .30212 L
.58528 .30395 L
.58644 .30522 L
.58773 .30625 L
.58889 .30685 L
.58999 .30712 L
.59063 .30714 L
.59132 .30706 L
.5926 .30661 L
.59383 .3058 L
.59498 .30473 L
.59634 .30307 L
.59758 .3012 L
.60034 .29579 L
.60557 .28134 L
.61122 .26055 L
.62145 .21441 L
.64105 .12674 L
.64642 .10789 L
.65216 .09094 L
.66252 .06803 L
Mistroke
.66763 .05965 L
.67317 .05216 L
.67805 .04664 L
.68323 .04168 L
.68789 .03793 L
.69303 .03455 L
.69528 .03333 L
.6977 .03221 L
.7 .03133 L
.70208 .0307 L
.7033 .03041 L
.70462 .03015 L
.70534 .03004 L
.70601 .02995 L
.70732 .02983 L
.70844 .02978 L
.70968 .02978 L
.71097 .02984 L
.71218 .02995 L
.71286 .03004 L
.71361 .03015 L
.71496 .03042 L
.7175 .03109 L
.72046 .03215 L
.72321 .03338 L
.73294 .03955 L
.73786 .04363 L
.74329 .04896 L
.74821 .0547 L
.75338 .06196 L
.76263 .07931 L
.76779 .09215 L
.77259 .10649 L
.78348 .14782 L
.80221 .23586 L
.80734 .25848 L
.81277 .27905 L
.81741 .29277 L
.82005 .29868 L
.82252 .30285 L
.82384 .30451 L
.82453 .30523 L
.82527 .30587 L
.82599 .30636 L
.82663 .3067 L
.82789 .30709 L
.82911 .3071 L
.83042 .30672 L
.83166 .30598 L
.8328 .30498 L
Mistroke
.83413 .30345 L
.83537 .30165 L
.83818 .29632 L
.84092 .28953 L
.84385 .28068 L
.8544 .23851 L
.864 .19305 L
.87328 .15054 L
.88312 .11254 L
.88825 .0965 L
.89391 .08179 L
.90389 .06241 L
.90882 .05522 L
.914 .04891 L
.92326 .04006 L
.92843 .03627 L
.93323 .03347 L
.93595 .03222 L
.93851 .03127 L
.93992 .03084 L
.94145 .03046 L
.94285 .03019 L
.94413 .03001 L
.94515 .0299 L
.94612 .02984 L
.94699 .02982 L
.94794 .02982 L
.94897 .02986 L
.95006 .02995 L
.95099 .03006 L
.95203 .03022 L
.95386 .0306 L
.95583 .03115 L
.95941 .03247 L
.96367 .03458 L
.96816 .03738 L
.97619 .04378 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^@?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hLooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=_ooool0
03Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Oooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`12ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0=_ooool002oooooo1_l00006ooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41005?ooool6o`0000Gooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@01gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01oo
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03Cooooo000jooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000012ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`00>Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000007oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000@_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
7oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool00000=_ooool003[ooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@023ooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@03Kooooo000gooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0@_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL07?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Kooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Ko
oooo000gooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Ooo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0@?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Kooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo000Koooooooo0000<_l0000Looooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Pooooo`00>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo001Pooooo`Go0000@oooool5o`0000Kooooo00?o0000ooooooooool0
>_ooool5o`0004Cooooo1Ol0000Zooooo`00GOooool3o`0000Gooooo0_l0000oooooo`?o00001?oo
ool2o`0000Cooooo0_l0000iooooo`?o00001?ooool4o`0003gooooo0ol00004ooooo`?o0000:?oo
ool005cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0jooooo`;o00002Oooool2
o`0000;ooooo00?o0000ooooooooool0=oooool2o`0000[ooooo00?o0000ooooooooool0>?ooool2
o`0000[ooooo00?o0000ooooooooool09Oooool005_ooooo00?o0000ooooooooool02_ooool2o`00
03Wooooo00?o0000ooooooooool02oooool3o`0003Sooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo00_ooooo0_l0000Uooooo`008oooool00ol0003o
ooooooooo`0dooooo`03o`000?oooooooooo00gooooo0_l0000fooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0=?ooool2o`0000oooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo02;ooooo000Sooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00oooooo
0_l0000dooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`0cooooo`009?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`0@ooooo`;o0000=?ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0=?ooool002Gooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool04Oooool00ol0003oooooo`00000booooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`0eooooo`009Oooool00ol0003oooooooooo`0_oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Boooo
o`04o`000?ooooooooooo`00033ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo03Kooooo000Vooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01;ooooo00Go0000oooo
ooooooooooooo`00000^ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`0fooooo`009oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Cooooo`;o00000_ooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`0gooooo`009oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02_o
oooo00?o0000ooooooooool0=oooool002Sooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q00Co0000oooooooooooooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03Sooooo000Xooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Looooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool00olQ8B7o0000ooooo`03ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0>?oo
ool002Wooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo01cooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00?ooooo00?o
V9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool0>Oooool002[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo01_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo00Cooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o00001?oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0iooooo`00:_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool06oooool01Ol0003ooooooooooooooooo000000Gooooo00?o
0000ooooooooool01_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03[ooooo000Zooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Jooooo`05oa0@4?oo
ooooooooooooool@41001Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03[ooooo
000[ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`03ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool0>oooool002_ooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo01Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`03
o`000?oooooooooo00Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`00
00Oooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool0>oooool002_ooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo03cooooo000/ooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`0looooo`00;?ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0?Oooool002cooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03gooooo000]oooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo01Sooooo0_l00009ooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03gooooo000]ooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0nooooo`00
;Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
?_ooool002kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo03kooooo000^ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0oooooo`00;_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Jooooo`;o00002_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0oooooo`00;_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool0?oooool002oooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo03oooooo000_ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`10ooooo`00;oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0K
ooooo`;o00002oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`10ooooo`00;oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0@?ooool0033ooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo043ooooo000`ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Hooooo`09o`00
0?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo047ooooo000`
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0H
ooooo`09o`000?oooooooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`11ooooo`00
<?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
6?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool03_ooool00ol0003o
ooooooooo`03ooooo`?o00002oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`11ooooo`00<Oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool06?ooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool03Oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool0@Oooool0037ooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0[oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0@_ooool0037ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo04;ooooo000aooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`12ooooo`00<_ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`02ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0000=ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
04;ooooo000booooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`13ooooo`00<_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0@oooool003;ooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`0^ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo04?ooooo000booooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01kooooo0_l0000>
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo04?ooooo000cooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02oooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`13ooooo`00<oooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool0A?ooool003?ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04Cooooo000cooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`14ooooo`00=?ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0Oooooo`;o00003oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`14ooooo`00=?ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0A?ooool003Co
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04Go
oooo000dooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`15ooooo`00=Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0AOooool003Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0b
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool08?ooool2o`00013ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0AOooool003Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo04Gooooo000eooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`0>ooooo`06o`000?o^k^ko<S8bo`000?lb<S;ok^k^1Oooool2
ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Cooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`15ooooo`00=Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool03_ooool01_l0003oMgMgoiRHV?oo
ooooV9RHogMgM`Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Gooooo000eooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0>ooooo`03o`000?l@
413ooooo00;ooooo00?o410@ooooooooool02oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oo
oooooooo00?ooooo0ol0000@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04Kooooo000fooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
000000?ooooo00?o0000ooooooooool03?ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`16ooooo`00=_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03?ooool00ol0
003oooooo`000003ooooo`03o`000?oooooooooo00cooooo00?oEEEEolc<c?ooool00oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`16
ooooo`00=_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool03?ooool00ol0003ooooooa0@4003ooooo`03oa0@4?oooooooooo00cooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool0A_ooool003Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo00cooooo00Oo0000oooooomgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@
oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`16ooooo`00=_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo03Oooooo00?o0000ooooooooool03?ooool01ol0003oooooonk^k_lb<S;o0000oc8b<_o^k^h0
2oooool5o`0000Cooooo1?l00006ooooo`;o00004_ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`17ooooo`00=_oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Aooo
ool003Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0hooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo04Oooooo000gooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`18ooooo`00=oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0B?ooool003Sooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0iooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool09?ooool2o`0001?ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0B?ooool003Sooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo04Wooooo000hooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03[ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`19ooooo`00>Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0joooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0BOooool003Wooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04[ooooo000iooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo02Gooooo0_l0000Eooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04[ooooo000jooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo03cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1:ooooo`00>_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Boooool0
03[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
04_ooooo000jooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0?Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo02Oooooo0_l0000Fooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04_o
oooo000kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1;ooooo`00??ooool01Ol0003ooooooooooooooooo000004?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Mooooo`Co000000?o410@ooooooooool00oooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0@?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo04_ooooo000looooo`05o`000?ooooooooooooooool00000
@oooool01Ol0003ooooooooooooooooo000002;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Fooooo`;o00000_ooool2o`0004?ooooo00?o0000ooooooooool00_l0001>ooooo`00
?Oooool3o`0004Gooooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
5oooool4o`0004Cooooo1?l0001?ooooo`00Zoooool00ol0003oooooooooo`05ooooo`?o0000/_oo
ool00:_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2booooo`00Zoooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0;;ooooo002[ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0/_ooool00:Wooooo00?oEEEEofIVI_l000001oooool00ol0003ooooo
ooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002coooo
o`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000
/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool0
0;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo
0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2b
ooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00
/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002Aooooo`Co000000?o410@
ooooooooool00_ooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`2booooo`00Toooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000
ooooooooool00oooool3o`000;;ooooo002Cooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q
8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03
o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_ooool009?ooooo
00?o0000ooooooooool02_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`2booooo`00TOooool00omEEEGoIVIVo`00000<ooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0002cooooo`00/oooool00ol0003ooooo
ooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2b
ooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`00
0?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooo
oooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo
00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000
ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00
VOooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01Oooool00ol0003oooooooooo`2booooo`00Voooool00ol0003oooooooooo`04ooooo`;o8B4Q
2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;;ooooo002Kooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2booooo`00Voooool0
0ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002booooo`00Voooool00ol0
003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2b
ooooo`00Voooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0/_ooool009_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0;;ooooo002Iooooo`03oeEEEOmVIVKo000000gooooo1?l00006ooooo`03o`00
0?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool0
0;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo
0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2b
ooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00
/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooo
oooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;o
oooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool0097ooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`04
ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool0/_ooool009?ooooo00?o0000ooooooooool03?ooool00onYZJWoEEEEooooo`08oooo
o`03o`000?oooooooooo00?ooooo0ol0002booooo`00Toooool00ol0003oooooooooo`0=ooooo`03
ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2booooo`00
Toooool00ol0003oooooooooo`0=ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00gooooo
00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;;ooooo
002Cooooo`03o`000?oooooooooo00[ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0/_ooool0097ooooo00?oEEEEofIVI_l000003?oo
ool5o`0000Cooooo1?l00006ooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool0
0;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo
00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2b
ooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00
/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooo
oooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;o
oooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00:Sooooo1Ol00006
ooooo`03o`000?oooooooooo0;;ooooo002Xooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool0
0ol0003oooooooooo`2booooo`00ZOooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo
0;;ooooo002Zooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0002booooo`00Zoooool00omgMgOoIVIV
ooooo`2jooooo`00[?ooool00ol0003oooooooooo`2iooooo`00Z?ooool01Ol0003o^[ZjoooooonH
V9So410@0;_ooooo002Xooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0^oooool00?ooooooJOooool0
0:kooooo00?o0000okZj^_ooool0]oooool00:kooooo0_lb<S:hooooo`00Ooooool2o`000006oa0@
4?oooooooooooa0@4?l0003o410@6?ooool4o`000005oa0@4?oooooooooooooooom4A4@00_l00000
1olb<S;ogMgMooooooooooooQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Wo
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?l@413oc<c<1?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM07Sooooo0020ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01ooo
ool6o`0000cooooo00?o0000ooooooooool01_ooool01omgMgOo<S8booooooooooooc<c<o`000?l@
41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<ooooo`03o`000?oooooooooo
00;ooooo00GoEEEEogMgMoooooooV9RHob4Q8@07ooooo`03ogMgMolb<S;ooooo07Oooooo0020oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`1fooooo`00P?ooool01_l0
003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000<ooooo`03o`000?oooooooooo00Kooooo00?o
MgMgoc8b<_ooool04?ooool00ol0003oooooooooo`0;ooooo`Ko00003?ooool00ol0003ooooooooo
o`02ooooo`05o`000?nHV9SooooooiRHV?lQ8B401oooool00omgMgOo<S8booooo`1gooooo`00P?oo
ool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001_ooooo00?o0000ooooooooool00oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<017ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02oooo
o`05o`000?mEEEGo0000oa0@4?o<c<`01?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<07Sooooo0020
ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo00006oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo017ooooo00?o410@o`000?l000000ol0000Looooo`03o`000?oooooooooo00;ooooo
00?oEEEEohN7Qoooool01_ooool00ol0003oooooooooo`1jooooo`00P?ooool01_l0003o<S8boooo
oooooooo<S8bo`0001_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool00_ooool00ooMgMgo410@oiRHV006ooooo`03
o`000?oooooooooo07[ooooo001oooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@4100
6?ooool00omEEEGoIVIVo`000005ooooo`Co00004_ooool00ol0003oooooooooo`0Kooooo`03oeEE
EOmVIVKo000000Gooooo00Coc<c<odA4A?l0003o410@1?ooool4o`0007Wooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-44.3769, -0.160437, \
0.309031, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.01333 0 0.309017 [
[.1001 -0.0125 -9 -9 ]
[.1001 -0.0125 9 0 ]
[.2334 -0.0125 -9 -9 ]
[.2334 -0.0125 9 0 ]
[.3667 -0.0125 -9 -9 ]
[.3667 -0.0125 9 0 ]
[.6333 -0.0125 -6 -9 ]
[.6333 -0.0125 6 0 ]
[.7666 -0.0125 -6 -9 ]
[.7666 -0.0125 6 0 ]
[.8999 -0.0125 -6 -9 ]
[.8999 -0.0125 6 0 ]
[.4875 .07725 -24 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -18 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -24 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1001 0 m
.1001 .00625 L
s
[(-30)] .1001 -0.0125 0 1 Mshowa
.2334 0 m
.2334 .00625 L
s
[(-20)] .2334 -0.0125 0 1 Mshowa
.3667 0 m
.3667 .00625 L
s
[(-10)] .3667 -0.0125 0 1 Mshowa
.6333 0 m
.6333 .00625 L
s
[(10)] .6333 -0.0125 0 1 Mshowa
.7666 0 m
.7666 .00625 L
s
[(20)] .7666 -0.0125 0 1 Mshowa
.8999 0 m
.8999 .00625 L
s
[(30)] .8999 -0.0125 0 1 Mshowa
.125 Mabswid
.12676 0 m
.12676 .00375 L
s
.15342 0 m
.15342 .00375 L
s
.18008 0 m
.18008 .00375 L
s
.20674 0 m
.20674 .00375 L
s
.26006 0 m
.26006 .00375 L
s
.28672 0 m
.28672 .00375 L
s
.31338 0 m
.31338 .00375 L
s
.34004 0 m
.34004 .00375 L
s
.39336 0 m
.39336 .00375 L
s
.42002 0 m
.42002 .00375 L
s
.44668 0 m
.44668 .00375 L
s
.47334 0 m
.47334 .00375 L
s
.52666 0 m
.52666 .00375 L
s
.55332 0 m
.55332 .00375 L
s
.57998 0 m
.57998 .00375 L
s
.60664 0 m
.60664 .00375 L
s
.65996 0 m
.65996 .00375 L
s
.68662 0 m
.68662 .00375 L
s
.71328 0 m
.71328 .00375 L
s
.73994 0 m
.73994 .00375 L
s
.79326 0 m
.79326 .00375 L
s
.81992 0 m
.81992 .00375 L
s
.84658 0 m
.84658 .00375 L
s
.87324 0 m
.87324 .00375 L
s
.07344 0 m
.07344 .00375 L
s
.04678 0 m
.04678 .00375 L
s
.02012 0 m
.02012 .00375 L
s
.92656 0 m
.92656 .00375 L
s
.95322 0 m
.95322 .00375 L
s
.97988 0 m
.97988 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .07725 m
.50625 .07725 L
s
[(0.25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(0.75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(1)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(1.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(1.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(1.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(170) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .02965 m
.02499 .02986 L
.02605 .0301 L
.02846 .03078 L
.03279 .03252 L
.03784 .03532 L
.04262 .03866 L
.05212 .04731 L
.06244 .06044 L
.06751 .06896 L
.07308 .08051 L
.08435 .11257 L
.0948 .15352 L
.10458 .19906 L
.11496 .24778 L
.12008 .26884 L
.12483 .28511 L
.12911 .29631 L
.13151 .30093 L
.13368 .304 L
.13493 .30528 L
.13608 .30614 L
.13733 .30672 L
.13797 .30687 L
.13866 .30692 L
.13983 .30676 L
.14109 .30622 L
.14227 .30537 L
.14335 .30431 L
.14564 .30118 L
.14816 .29639 L
.15326 .28272 L
.158 .266 L
.16244 .24759 L
.1832 .15149 L
.19303 .11357 L
.20338 .08381 L
.21222 .06583 L
.22188 .05177 L
.23216 .04105 L
.23702 .03714 L
.24149 .03418 L
.24667 .03158 L
.24939 .03059 L
.25078 .03019 L
.25227 .02984 L
.25358 .0296 L
.25477 .02945 L
.25598 .02934 L
.25712 .0293 L
Mistroke
.25776 .02929 L
.25844 .02931 L
.25967 .02938 L
.26042 .02945 L
.26112 .02953 L
.26245 .02975 L
.26361 .02999 L
.26486 .0303 L
.26712 .03101 L
.27223 .03326 L
.27764 .03652 L
.28256 .04021 L
.29206 .04934 L
.30105 .06118 L
.30565 .06899 L
.31073 .07942 L
.321 .10769 L
.33051 .14333 L
.33943 .18358 L
.34839 .22649 L
.35794 .26797 L
.36344 .28662 L
.36604 .29357 L
.36843 .29876 L
.37084 .30274 L
.3721 .30431 L
.37275 .30497 L
.37344 .30557 L
.37461 .30632 L
.37569 .30674 L
.37699 .30686 L
.37817 .30663 L
.37941 .30603 L
.38073 .305 L
.38186 .3038 L
.3831 .30213 L
.38587 .29718 L
.38848 .29106 L
.39318 .27674 L
.39825 .25738 L
.41936 .15991 L
.42973 .11833 L
.43938 .08895 L
.44945 .06733 L
.45477 .05878 L
.46047 .05124 L
.4707 .04073 L
.47647 .03622 L
.48179 .03297 L
.48403 .03188 L
Mistroke
.48645 .03091 L
.48783 .03045 L
.48909 .03009 L
.49029 .02981 L
.49157 .02956 L
.49289 .02938 L
.49411 .02927 L
.49486 .02924 L
.49557 .02922 L
.49689 .02925 L
.49815 .02933 L
.49931 .02947 L
.50059 .02968 L
.50193 .02996 L
.50448 .03069 L
.5069 .03159 L
.51142 .03381 L
.51629 .0369 L
.52159 .04102 L
.53112 .0505 L
.53993 .06247 L
.54457 .07056 L
.54956 .08111 L
.55861 .10605 L
.56936 .14645 L
.57921 .19163 L
.58837 .23534 L
.59815 .27577 L
.60104 .28521 L
.60377 .29273 L
.60643 .29861 L
.6076 .30072 L
.60888 .30268 L
.61 .3041 L
.61121 .3053 L
.61248 .30619 L
.61367 .30669 L
.61433 .30682 L
.61506 .30684 L
.61638 .30656 L
.61767 .30589 L
.61886 .30493 L
.62015 .30351 L
.62152 .3016 L
.62396 .29716 L
.62658 .29097 L
.62946 .28266 L
.63943 .24407 L
.65806 .15732 L
.66811 .11734 L
Mistroke
.67762 .08854 L
.68288 .07628 L
.68858 .06545 L
.69856 .0512 L
.70799 .04146 L
.71342 .03709 L
.71838 .03387 L
.72361 .03134 L
.72499 .03083 L
.7265 .03035 L
.72793 .02997 L
.72924 .0297 L
.73055 .02949 L
.73179 .02935 L
.7331 .02927 L
.73383 .02925 L
.73451 .02926 L
.73565 .0293 L
.73689 .02941 L
.73819 .02959 L
.73941 .02981 L
.74201 .03048 L
.74441 .03131 L
.74985 .03393 L
.75465 .03701 L
.75975 .04101 L
.76857 .04975 L
.77831 .06297 L
.78322 .07171 L
.78839 .08291 L
.79764 .10916 L
.8076 .14705 L
.8185 .19729 L
.82858 .24487 L
.83353 .26569 L
.8381 .282 L
.8406 .28946 L
.84336 .29627 L
.84614 .30149 L
.84765 .30363 L
.84907 .30515 L
.85036 .30613 L
.85158 .30669 L
.85268 .3069 L
.85388 .30679 L
.85518 .30629 L
.8559 .30584 L
.85656 .30533 L
.85784 .30403 L
.85905 .30247 L
Mistroke
.86146 .29837 L
.86371 .29341 L
.86883 .2785 L
.87915 .23671 L
.89764 .1509 L
.90811 .11093 L
.91802 .08293 L
.92692 .06505 L
.93658 .05122 L
.94572 .04171 L
.95098 .03742 L
.9558 .03424 L
.96086 .03169 L
.96352 .03071 L
.96488 .03031 L
.96632 .02995 L
.9676 .0297 L
.96877 .02953 L
.96993 .02941 L
.97104 .02934 L
.97232 .02932 L
.97351 .02936 L
.97481 .02947 L
.97547 .02955 L
.97619 .02965 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^@?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hLooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=_ooool0
03Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Oooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`12ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0=_ooool002oooooo1_l00006ooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41005?ooool6o`0000Gooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@01gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01oo
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03Cooooo000jooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000012ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`00>Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000007oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000@_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
7oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool00000=_ooool003[ooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@023ooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@03Kooooo000gooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0@_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL07?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Kooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Ko
oooo000gooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Ooo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0@?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Kooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo000Koooooooo0000<_l0000Looooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Pooooo`00>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo000Sooooo`03o`000?oooooooooo047ooooo1_l00012ooooo`Ko0000
@oooool5o`0004?ooooo1?l0000Tooooo`009?ooool3o`0003oooooo00?o0000ooooooooool00ooo
ool4o`0003gooooo0ol00003ooooo`Go0000?Oooool3o`0000Gooooo0ol0000nooooo`;o0000:?oo
ool002Oooooo00?o0000ooooooooool0>Oooool3o`0000[ooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0:?ooool0
02Sooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0gooooo`;o0000:oooool002Wo
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02_o
oooo000Zooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo00Oooooo0_l00006ooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02cooooo
000[ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`0]ooooo`00:oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool0;_ooool002cooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0_oooo
o`03o`000?oooooooooo02kooooo000]ooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`0_ooooo`00;_ooool00ol0003oooooooooo`0/ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0;ooooo`;o0000
2_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`0_ooooo`00;oooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool0<?ooool0033ooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool0<?ooool0033ooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Gooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo000000Oooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo037ooooo000`ooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Dooooo`05oa0@
4?ooooooooooooooool@41003?ooool00onHV9So8B4Qo`000009ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0booooo`00<Oooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool04oooool01Ol0003ooooo
oooooooooooo000000gooooo00?oV9RHo`000?o^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o
00003?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0booooo`00<Oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool04oooool01Ol0003ooooooooooooooooo000000go
oooo00?o0000ogMgMomVIVH01?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0cooooo`00<Oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool04_ooool01Ol@413ooooooooooooooooo410@
00gooooo00?o0000ooooool000001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool0<oooool003;ooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo01;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`;o000000?ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool0=?ooool003;ooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo01;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05oiRHV?l0003o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0000>ooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo03Cooooo000cooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`0dooooo`00<oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool0=Oooool003?ooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo03Gooooo000dooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`0eooooo`00=?ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0A
ooooo`;o00004?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0fooooo`00=Oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool0=_ooool003Gooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03Kooooo000eooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0fooooo`00=_oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0=ooo
ool003Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool04_ooool2o`00017ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0=oooool0
03Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
03Oooooo000fooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0gooooo`00=oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0>?ooool003Oooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool04oooool2o`0001;ooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool0>?ooool003Oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo03Sooooo000gooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0hooooo`00=oooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool05Oooool01Oo^k^ko<S8bo`000?lb<S;o0000
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo03Wooooo000hooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool0:_ooool00ol0003oooooooooo`0Eooooo`05ogMgMonHV9SooooooiRHV?l000001Oooool2
ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo03Wooooo000hooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`0Eooooo`05oa0@4?ooooooooooooooool000004?ooool00ol0003oooooooooo`03
ooooo`?o00004_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0iooooo`00>?ooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`02o`00
00oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
03Wooooo000hooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0;?ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo00;o00003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0jooooo`00>Oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool05?ooool01Ol@413o
ooooooooool0003o410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo03[ooooo000iooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`0Dooooo`05ogMgMonHV9Soooooo`000?mgMgL03?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0>_ooool003Wo
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`0001Gooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool0>_ooool003Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo03_ooooo000iooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0kooooo`00>_ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0>oooool003[ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05oooool2
o`0001Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool0>oooool003[ooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo03_ooooo000jooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0looooo`00>_ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0??ooool003_ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03cooooo000k
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo01Sooooo0_l0000Gooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03cooooo000koooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0moooo
o`00>oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0?Oooool003cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0booooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo03gooooo000looooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0mooooo`00??ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Iooooo`;o00006?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0nooooo`00??ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0?_ooool003cooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo00Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02oooo
o`03o`000?oooooooooo00;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03kooooo000moooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`08oooo
o`07ogMgMonHV9SooooooiRHV?mgMgOoooooo`000003ooooo`;o8B4Q1_ooool00omEEEGoZJVYoooo
o`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0nooooo`00?Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Cooooo00?o0000
ooooooooool02?ooool01ol@413ooooooooooooooooo410@ooooool000002oooool00onYZJWoEEEE
ooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0000Gooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03kooooo
000mooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`08ooooo`07o`000?ooooooooooooooool0003oooooo`00000<ooooo`03ob4Q8Ooooooooooo00Ko
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03oo
oooo000mooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`07ooooo`07o`000?ooooooooooooooool0003oooooo`00000<ooooo`03oeEEEOo<c<cooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0?oooool003gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo00Oooooo00Ko410@oooooooooooooooooa0@4?l0000=ooooo`03ojVYZOmg
MgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo03oooooo000nooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`07ooooo`06ogMgMonHV9SooooooiRHV?mgMgOo00002_ooool01Ol@413ooooo
oooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo03oooooo000nooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`07ooooo`06onk^k_lb<S;o0000oc8b<_o^k^ko00002_ooool5o`00
00Cooooo1?l00006ooooo`;o00006_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`10ooooo`00?_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0@?ooool003kooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo043ooooo
000oooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`10ooooo`00?oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0@Oooool003oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0joooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07?ooool2o`0001_ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0@Oooool0043ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0jooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo047ooooo0010ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
>_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`11ooooo`00@?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0@Oooool0043ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0looooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo04;ooooo0011ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
01gooooo0_l0000Looooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo04;ooooo0011ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`12ooooo`00@Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0@oooool0047ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04?ooooo0012
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo01oooooo0_l0000Mooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04Cooooo0012oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`14oooo
o`00@oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo043ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Fooooo`Co000000?o410@ooooooooool00oooool00ol0003o
ooooooooo`0Mooooo`;o00001?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0A?ooool004Cooooo00Co0000oooooooooooo0000A?ooool00ol0003o
ooooooooo`02o`0001[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo00;o0000@oooool01Ol0003ooooooooooooooooo000004Oooooo0014ooooo`Co
0000A?ooool4o`0001_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Oooooo`?o
0000AOooool3o`0004Sooooo002[ooooo`03o`000?oooooooooo00Gooooo0ol0002booooo`00Zooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;;ooooo002[ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0/_ooool00:_ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`2booooo`00ZOooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo0;;o
oooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000
ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00
/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool0
0ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?o
oooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o
0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool0097ooooo1?l000000ol@413ooooooooo
o`02ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`00
0?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;;ooooo
002Cooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003ooooooooo
o`03ooooo`?o0000/_ooool009?ooooo00?o0000ooooooooool03?ooool00onHV9So8B4Qonk^kP07
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000oooo
ooooool03Oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2booooo`00Toooool00ol0003o
ooooooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo0;;ooooo002Aooooo`03oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c004ooooo`Co00001_ooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;o
oooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000oooooooo
ool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_oo
ool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooooooo
o`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002Iooooo`Co
000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0;;ooooo002Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/_ooool009_ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;;ooooo002Kooooo`03o`000?oo
oooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool3o`000;;ooooo002Kooooo`03o`000?oooooo
oooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;;ooooo002K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2b
ooooo`00Voooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0/_ooool009Wooooo00?oEEEEofIVI_l000003Oooool4o`0000Kooooo00?o0000oooooooo
ool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool0
0ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?o
oooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o
0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_oo
ool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?o
oooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00TOooool4o`000003oa0@4?oo
oooooooo00;ooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8b
omgMg@05ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00Cooooo0_lQ
8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`2booooo`00Toooool00ol0003oooooooooo`0<ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000
ooooooooool00oooool3o`000;;ooooo002Cooooo`03o`000?oooooooooo00gooooo00?o8B4Qoooo
ooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03
o`000?oooooooooo00gooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool03Oooool00onYZJWo
MgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_ooool009?ooooo
00?o0000ooooooooool02_ooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`2booooo`00TOooool00omEEEGoIVIVo`00000<ooooo`Go0000
1?ooool4o`0000Kooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool0
0ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o
0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_oo
ool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?o
oooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00Z?ooool5o`0000Kooooo00?o
0000ooooooooool0/_ooool00:Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oo
oooooooo0;;ooooo002Yooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/_ooool0
0:[ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;;ooooo002[ooooo`03ogMgMomVIVKooooo0;[o
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002Xooooo`05o`000?nj^[[ooooooiRHV?l@4100
^oooool00:Sooooo00GoV9RHoa0@4?l0003o8B4Qolc<c02kooooo`00oooooomYooooo`00[_ooool0
0ol0003o^[Zjooooo`2gooooo`00[_ooool2oc8b<[Sooooo001oooooo`;o000000Ko410@oooooooo
oooo410@o`000?l@410Hooooo`Co000000Go410@ooooooooooooooooodA4A002o`000007oc8b<_oM
gMgooooooooooon7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06Oooool4o`00
0003oa0@4?oooooooooo00;ooooo00?o0000onk^k_ooool00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^07Wooooo0020ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`00
00cooooo00?o0000ooooooooool01_ooool01omgMgOo<S8booooooooooooc<c<o`000?l@41003?oo
ool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<ooooo`03o`000?oooooooooo00Cooooo
00?oEEEEojVYZOooool00oooool01OmgMgOoV9RHoooooonHV9SoMgMg07Wooooo0020ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`04ooooo`03ojVY
ZOmEEEGooooo00?ooooo00Go410@oooooooooooooooooa0@401iooooo`00P?ooool01_l0003ooooo
odA4A?m4A4Coooooo`0000Wooooo1_l0000<ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b
<_ooool04?ooool00ol0003oooooooooo`0;ooooo`Ko00003?ooool00ol0003oooooooooo`05oooo
o`03ob4Q8Ooooooooooo00;ooooo00Go0000ooooooooooooooooo`00001iooooo`00P?ooool01_l0
003ogMgMoc8b<_mEEEGogMgMo`0001_ooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<017ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`05ooooo`03oeEE
EOo<c<cooooo00;ooooo00Go0000ooooooooooooooooo`00001iooooo`00P?ooool01_l0003oQhN7
ojVYZOnj^[[oEEEEo`0001_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aoooo
o`03oa0@4?l0003o000000?o00007?ooool00ol0003oooooooooo`05ooooo`03ojVYZOmgMgOooooo
00;ooooo00Go410@oooooooooooooooooa0@401iooooo`00P?ooool01_l0003o<S8boooooooooooo
<S8bo`0001_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo<S8b00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`1iooooo`00Ooooool00ol@413o0000ohN7Q`02ooooo`03ohN7
Qol0003o410@01Sooooo00?oEEEEofIVI_l000001Oooool4o`0001;ooooo00?o0000ooooooooool0
6oooool00omEEEGoIVIVo`000004ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07Wo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-44.3769, -0.160437, \
0.309031, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.01333 0 0.309017 [
[.1001 -0.0125 -9 -9 ]
[.1001 -0.0125 9 0 ]
[.2334 -0.0125 -9 -9 ]
[.2334 -0.0125 9 0 ]
[.3667 -0.0125 -9 -9 ]
[.3667 -0.0125 9 0 ]
[.6333 -0.0125 -6 -9 ]
[.6333 -0.0125 6 0 ]
[.7666 -0.0125 -6 -9 ]
[.7666 -0.0125 6 0 ]
[.8999 -0.0125 -6 -9 ]
[.8999 -0.0125 6 0 ]
[.4875 .07725 -24 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -18 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -24 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1001 0 m
.1001 .00625 L
s
[(-30)] .1001 -0.0125 0 1 Mshowa
.2334 0 m
.2334 .00625 L
s
[(-20)] .2334 -0.0125 0 1 Mshowa
.3667 0 m
.3667 .00625 L
s
[(-10)] .3667 -0.0125 0 1 Mshowa
.6333 0 m
.6333 .00625 L
s
[(10)] .6333 -0.0125 0 1 Mshowa
.7666 0 m
.7666 .00625 L
s
[(20)] .7666 -0.0125 0 1 Mshowa
.8999 0 m
.8999 .00625 L
s
[(30)] .8999 -0.0125 0 1 Mshowa
.125 Mabswid
.12676 0 m
.12676 .00375 L
s
.15342 0 m
.15342 .00375 L
s
.18008 0 m
.18008 .00375 L
s
.20674 0 m
.20674 .00375 L
s
.26006 0 m
.26006 .00375 L
s
.28672 0 m
.28672 .00375 L
s
.31338 0 m
.31338 .00375 L
s
.34004 0 m
.34004 .00375 L
s
.39336 0 m
.39336 .00375 L
s
.42002 0 m
.42002 .00375 L
s
.44668 0 m
.44668 .00375 L
s
.47334 0 m
.47334 .00375 L
s
.52666 0 m
.52666 .00375 L
s
.55332 0 m
.55332 .00375 L
s
.57998 0 m
.57998 .00375 L
s
.60664 0 m
.60664 .00375 L
s
.65996 0 m
.65996 .00375 L
s
.68662 0 m
.68662 .00375 L
s
.71328 0 m
.71328 .00375 L
s
.73994 0 m
.73994 .00375 L
s
.79326 0 m
.79326 .00375 L
s
.81992 0 m
.81992 .00375 L
s
.84658 0 m
.84658 .00375 L
s
.87324 0 m
.87324 .00375 L
s
.07344 0 m
.07344 .00375 L
s
.04678 0 m
.04678 .00375 L
s
.02012 0 m
.02012 .00375 L
s
.92656 0 m
.92656 .00375 L
s
.95322 0 m
.95322 .00375 L
s
.97988 0 m
.97988 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .07725 m
.50625 .07725 L
s
[(0.25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(0.75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(1)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(1.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(1.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(1.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(175) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .03653 m
.02846 .03356 L
.03279 .03142 L
.03527 .03049 L
.03754 .02985 L
.03879 .02957 L
.03945 .02945 L
.04015 .02934 L
.04143 .02919 L
.04262 .02911 L
.04384 .02908 L
.04496 .0291 L
.04626 .02919 L
.04749 .02934 L
.04862 .02953 L
.04967 .02974 L
.05205 .03039 L
.05469 .03134 L
.05708 .03241 L
.06244 .0355 L
.07287 .04392 L
.07874 .05013 L
.08414 .057 L
.09408 .07373 L
.09909 .08488 L
.10458 .09972 L
.11478 .13524 L
.12409 .1757 L
.13495 .22727 L
.13973 .24891 L
.145 .27029 L
.14946 .28529 L
.1518 .29178 L
.15426 .29745 L
.15552 .29986 L
.1569 .3021 L
.15817 .30379 L
.15933 .30499 L
.16052 .30592 L
.16179 .30653 L
.16297 .30676 L
.16409 .30668 L
.16529 .30626 L
.16661 .3054 L
.16727 .30482 L
.16798 .30408 L
.16927 .30244 L
.17177 .29821 L
.17405 .29318 L
.17959 .27675 L
Mistroke
.18485 .2566 L
.20492 .16345 L
.21366 .12697 L
.22309 .0957 L
.22839 .08202 L
.23325 .07162 L
.24281 .05599 L
.25302 .04412 L
.25866 .03906 L
.26379 .03527 L
.26868 .03242 L
.27092 .03138 L
.2733 .03047 L
.2745 .03009 L
.27583 .02974 L
.27705 .02947 L
.27817 .02928 L
.27949 .02912 L
.28018 .02906 L
.28091 .02902 L
.28213 .02899 L
.28282 .02901 L
.28347 .02904 L
.28462 .02914 L
.28586 .0293 L
.28704 .02951 L
.28812 .02975 L
.29018 .03032 L
.29235 .0311 L
.29686 .03325 L
.30182 .03637 L
.312 .04502 L
.3213 .05579 L
.32644 .06337 L
.33203 .07346 L
.34221 .09829 L
.35159 .13012 L
.36196 .17463 L
.37291 .22667 L
.37771 .24845 L
.38296 .26982 L
.38751 .2852 L
.39001 .29211 L
.39237 .2975 L
.39366 .29995 L
.39506 .30219 L
.39622 .30372 L
.3975 .30505 L
.39871 .30595 L
.39999 .30654 L
Mistroke
.40117 .30673 L
.40228 .30661 L
.40357 .30611 L
.4043 .30566 L
.40497 .30512 L
.40621 .30387 L
.40753 .30215 L
.41005 .29779 L
.41233 .29267 L
.41789 .27599 L
.42313 .25581 L
.44152 .17034 L
.45196 .12623 L
.4617 .09424 L
.47133 .07157 L
.47673 .06207 L
.48165 .05492 L
.48684 .0486 L
.49248 .04284 L
.49776 .03832 L
.50272 .03481 L
.50725 .03227 L
.50958 .03123 L
.51213 .03031 L
.51477 .02961 L
.51621 .02934 L
.5169 .02923 L
.51755 .02916 L
.51881 .02905 L
.51995 .02901 L
.52118 .02903 L
.52187 .02906 L
.52251 .02911 L
.52372 .02925 L
.52502 .02946 L
.52625 .02972 L
.52737 .03001 L
.53012 .03092 L
.53272 .03203 L
.53789 .03492 L
.54352 .03902 L
.55388 .04901 L
.56325 .0614 L
.56845 .07028 L
.57407 .08205 L
.58424 .11058 L
.59378 .14665 L
.60423 .19431 L
.61527 .24611 L
.62049 .26773 L
Mistroke
.62532 .28439 L
.63014 .29689 L
.63268 .30154 L
.63396 .30335 L
.63537 .30491 L
.63661 .30589 L
.63774 .30647 L
.63904 .30677 L
.64028 .30668 L
.64142 .30628 L
.64248 .30563 L
.64364 .30462 L
.64488 .30319 L
.64759 .29886 L
.65053 .29238 L
.65586 .27639 L
.66581 .23555 L
.68535 .14504 L
.69645 .10423 L
.70176 .08899 L
.7068 .07699 L
.71677 .05905 L
.72585 .04751 L
.73564 .03843 L
.74116 .03457 L
.74383 .03304 L
.74628 .03185 L
.74849 .03094 L
.75091 .03015 L
.75208 .02985 L
.75334 .02957 L
.75467 .02935 L
.7559 .02921 L
.75707 .02913 L
.75834 .0291 L
.75953 .02912 L
.76063 .0292 L
.76163 .02931 L
.76272 .02947 L
.76494 .02995 L
.76631 .03033 L
.76762 .03076 L
.77006 .03174 L
.77558 .03467 L
.78034 .03798 L
.78553 .04235 L
.79587 .05362 L
.80524 .06785 L
.81043 .07816 L
.81605 .09181 L
Mistroke
.82622 .12427 L
.8458 .2109 L
.85616 .258 L
.86187 .27939 L
.86467 .28804 L
.86726 .29471 L
.86975 .29983 L
.87102 .30192 L
.87239 .30377 L
.87311 .30456 L
.87376 .30519 L
.87504 .30612 L
.87572 .30646 L
.87647 .3067 L
.87724 .30682 L
.87797 .30679 L
.87924 .30645 L
.88044 .30578 L
.88152 .30489 L
.88268 .30362 L
.8853 .29964 L
.88772 .29465 L
.89213 .28248 L
.89699 .26523 L
.90679 .22209 L
.91762 .17066 L
.9279 .1272 L
.93712 .09651 L
.94717 .07236 L
.95447 .05971 L
.96224 .04945 L
.96886 .04255 L
.97619 .03653 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^@?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hLooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=_ooool0
03Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Oooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`12ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0=_ooool002oooooo1_l00006ooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41005?ooool6o`0000Gooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@01gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01oo
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03Cooooo000jooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000012ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`00>Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000007oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000@_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
7oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool00000=_ooool003[ooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@023ooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@03Kooooo000gooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0@_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL07?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Kooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Ko
oooo000gooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Ooo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0@?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Kooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo000Koooooooo0000<_l0000Looooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Pooooo`00>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo000Vooooo`Ko0000@_ooool6o`0003oooooo00Co0000oooooooooooo
oooo1Ol00013ooooo`Ko0000Hoooool002Cooooo0_l00006ooooo`;o0000?_ooool2o`0000Kooooo
0ol0000looooo`Co00001Oooool2o`0003oooooo0_l00005ooooo`?o0000HOooool002?ooooo00?o
0000ooooooooool02?ooool2o`0003_ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0iooooo`;o00002Oooool2o`0003cooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0iooooo`03o`000?oooooooooo02;ooooo000`ooooo`03o`000?oooooooooo03Oooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0gooooo`;o00003?ooool00ol0003oooooooooo`0h
ooooo`03o`000?oooooooooo00[ooooo0_l0000hooooo`03o`000?oooooooooo02?ooooo000aoooo
o`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooo000000gooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo03Cooooo00?o0000ooooooooool09?ooool003;ooooo00?o0000oooooooo
ool0<oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03?ooooo00?o0000oooooooo
ool00_l0000=ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0booooo`03o`000?oooooooooo02Gooooo000cooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0aooooo`05o`000?ooooooooooooooool0
00003oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`0Vooooo`00=?ooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool09_ooool003Gooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02Oooooo000eooooo`03o`000?oooooo
oooo02gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Xooooo`00=_ooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`04ooooo`;o00004Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Xooooo`00=_ooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0:Oooool003Oooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:Oooool003Oo
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400Gooooo00Co0000oooooomgMgOo<S8b1Oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo02[ooooo000hooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0=ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^
kP06ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`0Zooooo`00>?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool03?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1?ooool01Ol0003ooooooooooomgMgOo<S8b00Gooooo0ol0000Cooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02_o
oooo000iooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0<ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
02_ooooo000iooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0<ooooo`05oa0@4?ooooooooooooooool@41003oooool01?l0003oooooooooooooool2
o`0000Wooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0/ooooo`00>Oooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool02oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`;o00002Ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02cooooo000jooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0;ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo1Ol00006ooooo`;o0000
5Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0/ooooo`00>_ooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool0;Oooool003_ooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo02gooooo000kooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0]ooooo`00>oooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0;_ooool003cooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool02_ooool2o`0001Oooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0;_ooool003cooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02kooooo000l
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0_
ooooo`00?Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool0;oooool003gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo02oooooo000mooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00cooooo0_l0000Iooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo033ooooo000mooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0`ooooo`00?_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool0<?ooool003kooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo033ooooo000nooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00go
oooo0_l0000Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo037ooooo000nooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0aooooo`00?oooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0<Oooool003oooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`03ob4Q8Ol0003ooooo00Cooooo00GoA4A4o`000?l0003o<S8b
omgMg@05ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0<Oooool003oooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?lQ8B7ooooo00Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
:_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo03;ooooo000oooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0=ooooo`05oa0@4?oo
ooooooooooooool@41001Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo
0ol0000Iooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo03;ooooo0010ooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool0:oooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool00000
1Oooool00ol0003oooooooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0booooo`00@?ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo02cooooo00?o0000ooooooooool03Oooool01Ol0003ooooooooooooooooo000000Gooooo
00?o0000ooooooooool01?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`0booooo`00@?ooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool03Oooool01Ol@413ooooooooooooooooo410@00Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool0<_ooool0043ooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo00gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo03?ooooo0011ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0<ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool00ol0003o
ooooooooo`05ooooo`Co00001_ooool2o`0001cooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0<oooool0047ooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo03?ooooo
0011ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`0cooooo`00@Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0=?ooool0047ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04?ooool2o`0001gooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0=?ooool004;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo03Cooooo0012ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0dooooo`00@_ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0=Oooool004;ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo03Gooooo0012ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
017ooooo0_l0000Nooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo03Gooooo0013ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0eooooo`00@oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0booooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0=_ooool004?ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03Kooooo0013
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0f
ooooo`00@oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03;ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0Booooo`;o00007oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo03?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0foooo
o`00A?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0=oooool004Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0dooooo`09o`00
0?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B42ooooo`06o`000?oooooo
ooooooooool0003ok^k^1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0gooooo`00A?ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo03Cooooo00Wo0000ooooooooooooooooogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@;ooooo00Ko0000oooooooooooooooooeEEEOnYZJT8ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0gooooo`00A?ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo03Cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@
4?oooooooooo00Oooooo00Ko0000ooooooooooooooooojVYZOmEEED9ooooo`03o`000?oooooooooo
00?ooooo0ol0000Oooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo03Oooooo0014ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0=?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`03ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03Sooooo0015ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool0=_ooool01?l0003oooooooooool00003oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00omEEEGoc<c<ooooo`03oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo03Sooooo0015ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0=_ooool01?l0
003oooooooooool@4103ooooo`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool00oooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0hooooo`00AOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
03Kooooo00So0000ooooooooooooMgMgoiRHV?ooooooV9RHogMgM`Sooooo00Co0000oooooooooooo
410@0oooool00olb<S;oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Kooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0hooooo`00A_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo03Oooooo00Oo0000ooooooo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooo
ooooool01Ol00004ooooo`Co00001_ooool2o`00027ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0gooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0>Oooool004Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Wo
oooo0016ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0iooooo`00A_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0>Oooool004Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0h
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo03Wooooo0017ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0>Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Gooooo0_l0000Soooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo03[ooooo0017ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0>Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03[ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0jooooo`00Aoooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo03[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0jooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0>_ooool004Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03[ooooo0018ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0kooooo`00B?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Fooooo`;o00009?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
03cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0kooooo`00B?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0looooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0>oooool004Wooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03_ooooo
0019ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0?Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0kooooo`00BOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03oooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Hooooo`;o00009Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0l
ooooo`00B_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03oooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0??ooool004[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`11ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool4o`000003oa0@4?oooooooooo00?o
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo043o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0mooooo`00Boooool00ol0003ooooo
ooooo`02o`0004?ooooo0_l00002ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Uooooo`;o00000_ooool00ol0003oooooooooo`12ooooo`04o`00
0?ooooooooooo`00043ooooo001<ooooo`?o0000AOooool3o`0001Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Vooooo`Co0000A?ooool4o`00043ooooo002[ooooo`03o`000?oo
oooooooo00Gooooo0ol0002booooo`00Zoooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0;;ooooo002[ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/_ooool00:_o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2booooo`00ZOooool00omEEEGoIVIV
o`000007ooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000
ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooooooo
ool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool0
0ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_oo
ool0097ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooo
oooo00Cooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00_ooooo00?oV9RH
ob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000/_ooool009?ooooo00?o0000oooo
ooooool03?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0/_ooool009?ooooo00?o0000ooooooooool03Oooool00omgMgOoIVIVooooo`03ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2booooo`00Toooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2booooo`00Toooool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@
41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;;ooooo002Aooooo`03oeEE
EOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`000;?o
oooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o
0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_oo
ool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooooooo
o`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03
o`000?oooooooooo0;;ooooo002Iooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;;ooooo002Kooooo`03o`00
0?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
/_ooool009_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo0;;ooooo002Kooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool3
o`000;;ooooo002Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005
ooooo`03o`000?oooooooooo0;;ooooo002Kooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`2booooo`00Voooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_ooool009Wooooo00?oEEEEofIVI_l00000
3Oooool4o`0000Kooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool0
0ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_oo
ool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?o
oooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003ooooooooo
o`2booooo`00TOooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B46ooooo`03o`000?o^k^ko
oooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;;ooooo002C
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`0<oooo
o`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000;;ooooo002Cooooo`03
o`000?oooooooooo00gooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00gooooo00?oEEEEolc<c?ooool0
0oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/_ooool009?ooooo
00?o0000ooooooooool03Oooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool02_ooool01Ol@413ooooooooo
oooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2booooo`00TOoo
ool00omEEEGoIVIVo`00000<ooooo`Go00001?ooool4o`0000Kooooo0_l0002cooooo`00/oooool0
0ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_oo
ool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?o
oooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003ooooooooo
o`2booooo`00Z?ooool5o`0000Kooooo00?o0000ooooooooool0/_ooool00:Sooooo00GoV9RHob4Q
8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0;;ooooo002Yooooo`03oiRHV?lQ8B7ok^k^
00Oooooo00?o0000ooooooooool0/_ooool00:[ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;;o
oooo002[ooooo`03ogMgMomVIVKooooo0;[ooooo002/ooooo`03o`000?oooooooooo0;Wooooo002X
ooooo`05o`000?nj^[[ooooooiRHV?l@4100^oooool00:Sooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c02kooooo`00oooooomYooooo`00[_ooool00ol0003o^[Zjooooo`2gooooo`00[_ooool2oc8b<[So
oooo001oooooo`;o000000Ko410@oooooooooooo410@o`000?l@410Hooooo`Co000000Go410@oooo
ooooooooooooodA4A002o`000007oc8b<_oMgMgooooooooooon7QhOo0000okZj^P0<ooooo`05oiRH
V?l0003o0000odA4A?nj^[X06Oooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000onk^k_oo
ool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM07Sooooo0020ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01oooool6o`0000cooooo00?o0000ooooooooool01_ooool01omgMgOo
<S8booooooooooooc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0
000<ooooo`03o`000?oooooooooo00Cooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8boooo
o`1gooooo`00P?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool01?ooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo07Kooooo0020oooo
o`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000cooooo00?o0000ooooooooool01_oo
ool00omgMgOo<S8booooo`0@ooooo`03o`000?oooooooooo00_ooooo1_l0000<ooooo`03o`000?oo
oooooooo00Gooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`1gooooo`00P?ooool0
1_l0003ogMgMoc8b<_mEEEGogMgMo`0001_ooooo00?o0000ooooooooool00oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<017ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`05ooooo`03
oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c01hooooo`00P?ooool01_l0003o
QhN7ojVYZOnj^[[oEEEEo`0001_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0A
ooooo`03oa0@4?l0003o000000?o00007?ooool00ol0003oooooooooo`05ooooo`03ojVYZOmgMgOo
oooo00?ooooo00?o0000ooooooooool0N_ooool0083ooooo00Ko0000oc8b<_oooooooooooc8b<_l0
000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`00
0?oooooooooo07[ooooo001oooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?oo
ool00omEEEGoIVIVo`000005ooooo`Co00004_ooool00ol0003oooooooooo`0Kooooo`03oeEEEOmV
IVKo000000Cooooo1Ol00004ooooo`Co0000NOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-44.3769, -0.160437, \
0.309031, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.01333 0 0.309017 [
[.1001 -0.0125 -9 -9 ]
[.1001 -0.0125 9 0 ]
[.2334 -0.0125 -9 -9 ]
[.2334 -0.0125 9 0 ]
[.3667 -0.0125 -9 -9 ]
[.3667 -0.0125 9 0 ]
[.6333 -0.0125 -6 -9 ]
[.6333 -0.0125 6 0 ]
[.7666 -0.0125 -6 -9 ]
[.7666 -0.0125 6 0 ]
[.8999 -0.0125 -6 -9 ]
[.8999 -0.0125 6 0 ]
[.4875 .07725 -24 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -18 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -24 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1001 0 m
.1001 .00625 L
s
[(-30)] .1001 -0.0125 0 1 Mshowa
.2334 0 m
.2334 .00625 L
s
[(-20)] .2334 -0.0125 0 1 Mshowa
.3667 0 m
.3667 .00625 L
s
[(-10)] .3667 -0.0125 0 1 Mshowa
.6333 0 m
.6333 .00625 L
s
[(10)] .6333 -0.0125 0 1 Mshowa
.7666 0 m
.7666 .00625 L
s
[(20)] .7666 -0.0125 0 1 Mshowa
.8999 0 m
.8999 .00625 L
s
[(30)] .8999 -0.0125 0 1 Mshowa
.125 Mabswid
.12676 0 m
.12676 .00375 L
s
.15342 0 m
.15342 .00375 L
s
.18008 0 m
.18008 .00375 L
s
.20674 0 m
.20674 .00375 L
s
.26006 0 m
.26006 .00375 L
s
.28672 0 m
.28672 .00375 L
s
.31338 0 m
.31338 .00375 L
s
.34004 0 m
.34004 .00375 L
s
.39336 0 m
.39336 .00375 L
s
.42002 0 m
.42002 .00375 L
s
.44668 0 m
.44668 .00375 L
s
.47334 0 m
.47334 .00375 L
s
.52666 0 m
.52666 .00375 L
s
.55332 0 m
.55332 .00375 L
s
.57998 0 m
.57998 .00375 L
s
.60664 0 m
.60664 .00375 L
s
.65996 0 m
.65996 .00375 L
s
.68662 0 m
.68662 .00375 L
s
.71328 0 m
.71328 .00375 L
s
.73994 0 m
.73994 .00375 L
s
.79326 0 m
.79326 .00375 L
s
.81992 0 m
.81992 .00375 L
s
.84658 0 m
.84658 .00375 L
s
.87324 0 m
.87324 .00375 L
s
.07344 0 m
.07344 .00375 L
s
.04678 0 m
.04678 .00375 L
s
.02012 0 m
.02012 .00375 L
s
.92656 0 m
.92656 .00375 L
s
.95322 0 m
.95322 .00375 L
s
.97988 0 m
.97988 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .07725 m
.50625 .07725 L
s
[(0.25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(0.75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(1)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(1.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(1.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(1.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(180) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .06358 m
.03279 .05115 L
.04262 .04124 L
.04758 .03734 L
.05288 .03394 L
.05546 .03261 L
.05789 .03154 L
.06024 .03071 L
.06244 .03012 L
.06361 .02987 L
.06487 .02967 L
.06559 .02958 L
.06627 .02952 L
.06754 .02944 L
.06819 .02943 L
.06888 .02943 L
.07013 .02949 L
.07089 .02955 L
.07161 .02963 L
.07295 .02983 L
.07413 .03007 L
.07538 .03038 L
.07761 .03107 L
.08265 .03329 L
.08806 .03658 L
.0931 .04044 L
.0986 .04548 L
.10458 .05205 L
.11001 .05925 L
.11503 .06728 L
.12493 .08839 L
.13393 .11538 L
.14349 .1528 L
.15308 .19708 L
.16318 .24455 L
.17181 .27877 L
.17417 .28626 L
.17669 .29312 L
.17906 .2984 L
.18124 .3022 L
.18245 .30386 L
.18374 .30525 L
.18503 .30625 L
.18577 .30665 L
.18645 .30691 L
.18769 .30708 L
.18883 .30692 L
.19013 .30636 L
.19138 .30545 L
.19248 .30434 L
Mistroke
.19366 .30284 L
.19578 .29936 L
.1983 .29394 L
.20059 .28792 L
.21133 .24796 L
.22144 .20043 L
.23986 .1197 L
.2449 .1027 L
.2503 .08741 L
.26005 .06663 L
.26542 .05816 L
.2705 .05157 L
.28002 .04189 L
.28492 .03796 L
.29013 .03452 L
.29284 .03304 L
.29583 .03169 L
.29855 .03071 L
.29978 .03036 L
.3011 .03004 L
.30238 .02979 L
.30354 .02962 L
.30471 .02951 L
.30581 .02944 L
.3071 .02943 L
.30828 .02948 L
.30958 .02959 L
.31024 .02967 L
.31096 .02978 L
.31354 .03034 L
.31499 .03076 L
.31632 .03122 L
.32132 .0335 L
.32587 .0363 L
.33083 .04007 L
.33984 .04879 L
.34922 .06098 L
.35457 .06997 L
.35959 .08023 L
.36969 .10761 L
.38059 .14846 L
.40021 .23976 L
.40559 .26285 L
.41134 .2835 L
.41413 .29151 L
.41676 .29768 L
.41913 .30196 L
.42047 .30383 L
.4217 .30518 L
.42289 .30616 L
Mistroke
.42397 .30676 L
.42523 .3071 L
.42642 .30707 L
.42752 .30675 L
.42854 .3062 L
.42966 .30531 L
.43085 .30404 L
.43357 .29992 L
.43613 .29455 L
.44092 .281 L
.45071 .24218 L
.46129 .19196 L
.47161 .14476 L
.48124 .1084 L
.49129 .08043 L
.49661 .06938 L
.50231 .05985 L
.5125 .04715 L
.51825 .0417 L
.52357 .03752 L
.5286 .0343 L
.53333 .03198 L
.5357 .03108 L
.53826 .03034 L
.53964 .03003 L
.54039 .0299 L
.54109 .02979 L
.54234 .02964 L
.54299 .02959 L
.54369 .02955 L
.54493 .02952 L
.54563 .02953 L
.54629 .02956 L
.54698 .02961 L
.54761 .02967 L
.54903 .02986 L
.55024 .03008 L
.55155 .03039 L
.55395 .03111 L
.55674 .03221 L
.55971 .03367 L
.56505 .03703 L
.57564 .04623 L
.58521 .05783 L
.59011 .06542 L
.59527 .07506 L
.60451 .09772 L
.61445 .13132 L
.62535 .17838 L
.63625 .23019 L
Mistroke
.6416 .25418 L
.64655 .27371 L
.65095 .28801 L
.65329 .29416 L
.6558 .29953 L
.65712 .3018 L
.65832 .30354 L
.65954 .30496 L
.66068 .30597 L
.66194 .30674 L
.66261 .307 L
.66333 .30715 L
.66465 .30711 L
.66585 .30671 L
.66701 .306 L
.66829 .30485 L
.66962 .30324 L
.67087 .30137 L
.67309 .29717 L
.67549 .29148 L
.68094 .27444 L
.68592 .25484 L
.70483 .16623 L
.71408 .12711 L
.7239 .0945 L
.72903 .08134 L
.73468 .06951 L
.74466 .05403 L
.74957 .04823 L
.75475 .04307 L
.764 .03585 L
.76916 .03292 L
.77162 .03181 L
.77396 .03096 L
.77528 .03056 L
.77671 .0302 L
.77791 .02996 L
.77922 .02975 L
.77996 .02967 L
.78064 .0296 L
.78137 .02956 L
.78215 .02953 L
.78287 .02952 L
.78356 .02954 L
.78485 .02961 L
.7861 .02975 L
.7868 .02985 L
.78745 .02996 L
.78989 .03051 L
.79211 .0312 L
Mistroke
.79446 .03213 L
.79934 .03463 L
.80469 .03824 L
.81421 .04673 L
.82308 .05746 L
.8281 .06517 L
.83356 .07537 L
.84347 .1002 L
.85311 .13356 L
.86203 .1719 L
.8718 .21824 L
.88232 .26488 L
.88715 .28221 L
.88979 .29002 L
.89224 .29608 L
.89452 .30059 L
.89659 .30369 L
.89777 .30503 L
.89889 .306 L
.90006 .3067 L
.90134 .30708 L
.90247 .3071 L
.90369 .30678 L
.90484 .30615 L
.90589 .30531 L
.90712 .30399 L
.90846 .30216 L
.9109 .29779 L
.91344 .29187 L
.91615 .28417 L
.92101 .26713 L
.93913 .184 L
.97619 .06358 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^@?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hLooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=_ooool0
03Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Oooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`12ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0=_ooool002oooooo1_l00006ooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41005?ooool6o`0000Gooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@01gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01oo
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03Cooooo000jooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000012ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`00>Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000007oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000@_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
7oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool00000=_ooool003[ooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@023ooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@03Kooooo000gooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0@_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL07?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Kooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Ko
oooo000gooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Ooo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0@?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Kooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo000Koooooooo0000<_l0000Looooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Pooooo`00>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo000^ooooo`Go0000@oooool5o`0003Sooooo00?o0000ooooooooool0
2Oooool5o`0004?ooooo1Ol0001Looooo`00:oooool3o`0000Gooooo0ol0000nooooo`;o00001Ooo
ool3o`0003Gooooo0_l00008ooooo`;o00001?ooool4o`0003gooooo0ol00005ooooo`;o0000F_oo
ool002[ooooo00?o0000ooooooooool02Oooool2o`0003_ooooo00?o0000ooooooooool02?ooool2
o`0003?ooooo00?o0000ooooooooool01Oooool2o`0000[ooooo00?o0000ooooooooool0>?ooool2
o`0000[ooooo00?o0000ooooooooool0Eoooool002Wooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0fooooo`;o00003Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
00_ooooo0_l0001Gooooo`00:?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00;o
oooo0_l0000?ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`1Dooooo`009oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0_ooooo`;o00000_ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`1Cooooo`009_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0^ooooo`05o`000?ooooooooooooooool00000
4_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
Doooool002Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0;_ooool01?l0003oooooooooool0000Dooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Booooo`009Ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooo000001Kooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo057ooooo000Tooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo02cooooo0_l0000Hooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`1@ooooo`008oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0[ooooo`;o00006?ooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`0Rooooo`00?_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02;o
oooo000nooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01?ooool2o`0001[ooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool08_ooool003ko
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400Oooooo00?oMgMgoc8b<_ooool00oooool2o`0001_ooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool08oooool0
03oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
00Kooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00Oo0000
ooooooooooooooooo`000?oooooo000001cooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool08oooool003oooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo00Go
0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0
0_ooool00ol0003oooooo`000002o`0001[ooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool08oooool0043ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo00Go
0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c002ooooo`04o`000?ooooooooooo`0001gooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool09?ooool0043o
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Go
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool01?l0003oooooooooool0000Mooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Cooooo0011oooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`04oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo000001kooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
9?ooool0047ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo00Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`01?ooool4o`0000;ooooo00Co0000oooooooooooooooo0_l0000Mooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
02Gooooo0012ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`0Sooooo`05o`000?ooooooooooooooool000007_ooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Uoooo
o`00@_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool09Oooool004;ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo02Gooooo0013ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0Vooooo`00@oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`03ooooo`;o00007oooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`0Vooooo`00@oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool09_ooool004Cooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo02Oooooo0014ooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Wooooo`00A?ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09oooool004Gooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool01?ooool2o`00023ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0:?ooool004Gooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Sooooo0015ooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Xooooo`00
AOooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
:?ooool004Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool01Oooool2o`00027ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0:Ooo
ool004Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo02Wooooo0016ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Yooooo`00A_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool01_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo02[ooooo0017ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`06ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00Co0000
oooooomgMgOo<S8b1Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02[ooooo0017
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`06
ooooo`05oa0@4?ooooooooooooooool@41003?ooool01Ol0003ooooooooooooooooo000000Gooooo
0ol0000Qooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo02[ooooo0017ooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003ooooooooooomgMgOo<S8b00Gooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0Zooooo`00Aoooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02cooooo
00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0
003o<S8bolc<c005ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0:oooool004So
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Go
oooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0[ooooo`00B?ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool01Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
02_ooooo0018ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`05ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Kooooo0_l0000Soooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo02cooooo0018ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0/ooooo`00BOooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool0;?ooool004Wooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02gooooo0019ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00Sooooo0_l0000Tooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02gooooo0019ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0]ooooo`00BOooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0;Oooool004[ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02kooooo
001:ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0^ooooo`00B_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`09ooooo`;o00009Oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0^
ooooo`00B_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03;ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0;_ooool004_ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo02kooooo001;ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
<oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0_ooooo`00Boooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0;oooool004_ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02_ooool2
o`0002Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0;oooool004_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo02oooooo001<ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0<?ooool01Oo^k^ko<S8bo`000?lb<S;o000000Gooooo0_lQ8B46oooo
o`04o`000?o^k^koooooo`0000?ooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0;oooool004cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0aooooo`05ogMgMonHV9SooooooiRHV?l000001Oooool2ob4Q8@Kooooo00Co
EEEEojVYZOoooooo00001_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0<?ooool004cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0aooooo`05oa0@4?ooooooooooooooool000003Oooool01?nYZJWoEEEEooooool00007ooooo`03
o`000?oooooooooo00?ooooo0ol0000Vooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo033ooooo001<ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool0<Oooool01Ol0003ooooooooooooooooo000000ko
oooo00?o8B4Qooooool000001_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0<?ooool004cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0aooooo`04o`000?ooooooooooooooo`;o00003Oooool00omEEEGo0000ooooo`03ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
033ooooo001=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0<Oooool01_l@413o
oooooooooooooooo410@o`0000gooooo00?oZJVYo`000?ooool00oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0<?ooool004gooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0booooo`06ogMgMonHV9SooooooiRHV?mgMgOo00002_oo
ool01Ol@413ooooooooooooooooo000000Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo037ooooo001=ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0<_ooool01_o^k^ko<S8bo`000?lb<S;ok^k^o`0000[ooooo1Ol00004ooooo`Co
00001_ooool2o`0002Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0<Oooool004gooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo037ooooo001=ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo03Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0aooooo`00C_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0<Oooool0
04kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
03;ooooo001>ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00kooooo0_l0000Yooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03;o
oooo001>ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0booooo`00C_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0<_ooool004oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo03?ooooo001?ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0cooooo`00Coooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo03cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0?ooooo`;o
0000:oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0cooooo`00Coooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo03cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0looooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0=?ooool0053ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0??oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Cooooo001@ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0eooooo`00DOooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0@ooooo`;o0000;Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0eooooo`00DOooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0=Oooool005;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0eooooo`00D_ooool2o`0000;ooooo00?o0000ooooooooool0@Ooo
ool2o`0000;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool00_l00013ooooo`05o`000?ooooooooooooooool00000
>?ooool005?ooooo1?l00014ooooo`Co00003?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo02gooooo1?l00015ooooo`?o0000>Oooool00:_ooooo00?o0000ooooooooool01Oooool3
o`000;;ooooo002[ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/_ooool00:_o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2booooo`00Zoooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0;;ooooo002Yooooo`03oeEEEOmVIVKo000000Oooooo00?o
0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2boooo
o`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/ooo
ool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo
0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0
/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00TOooool4o`00
0003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool01?ooool2ob4Q
8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool0/_ooool009?ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP09oooo
o`03o`000?oooooooooo00?ooooo0ol0002booooo`00Toooool00ol0003oooooooooo`0<ooooo`03
oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2booooo`00
Toooool00ol0003oooooooooo`0=ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;;ooooo
002Cooooo`03o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0/_ooool0097ooooo00?oEEEEofIVI_l000003?oo
ool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000/oooool00;?ooooo00?o
0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0
003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002coooo
o`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0
/_ooool009Wooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/_ooool009_ooooo00?o0000ooooooooool01?oo
ool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2booooo`00Voooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/_ooool0
09_ooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`04ooooo`?o0000/_ooool009_o
oooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0/_ooool009_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0;;ooooo002Kooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`2booooo`00VOooool00omEEEGoIVIVo`00000=ooooo`Co00001_oo
ool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo
0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0
/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0
003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooo
ooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002Aoooo
o`Co000000?o410@ooooooooool00_ooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000oooo
ooooool01?ooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00cooooo00?oZJVYoeEEEOoo
ool02?ooool00ol0003oooooooooo`03ooooo`?o0000/_ooool009?ooooo00?o0000ooooooooool0
3Oooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
/_ooool009?ooooo00?o0000ooooooooool03Oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2booooo`00Toooool00ol0003ooooooooo
o`0=ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`2booooo`00Toooool00ol0003oooooooooo`0:ooooo`05oa0@4?oooooooooooooooolb<S801?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;;ooooo002Aooooo`03oeEEEOmVIVKo
000000cooooo1Ol00004ooooo`Co00001_ooool2o`000;?ooooo002cooooo`03o`000?oooooooooo
0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0
/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0
003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooo
ooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002Xoooo
o`Go00001_ooool00ol0003oooooooooo`2booooo`00Z?ooool01OnHV9So8B4Qonk^k_ooooooA4A4
00Kooooo00?o0000ooooooooool0/_ooool00:Wooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003o
ooooooooo`2booooo`00Z_ooool00onHV9So8B4Qonk^kP06ooooo`?o0000/_ooool00:_ooooo00?o
MgMgofIVI_ooool0^_ooool00:cooooo00?o0000ooooooooool0^Oooool00:Sooooo00Go0000okZj
^_ooooooV9RHoa0@402kooooo`00Z?ooool01OnHV9So410@o`000?lQ8B7oc<c<0;_ooooo003ooooo
ofWooooo002^ooooo`03o`000?nj^[[ooooo0;Oooooo002^ooooo`;o<S8b^?ooool007oooooo0_l0
00001_l@413oooooooooool@413o0000oa0@41Sooooo1?l000001Ol@413oooooooooooooooooA4A4
00;o000000Oo<S8bomgMgOooooooooooohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4
okZj^P0Iooooo`Co000000So410@ooooooooooooc<c<ob4Q8Ol0003o8B4Qolc<c0?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP1iooooo`00P?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Oooooo1_l0000<ooooo`03o`000?oooooooooo00Kooooo00OoMgMgoc8b<_ooooooooooolc<
c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003o
ooooooooo`02ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonHV9So
MgMg07Wooooo0020ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooo
oooo410@07Wooooo0020ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000cooooo
00?o0000ooooooooool01_ooool00omgMgOo<S8booooo`0@ooooo`03o`000?oooooooooo00_ooooo
1_l0000<ooooo`03o`000?oooooooooo00;ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P03ooooo`05
o`000?ooooooooooooooool00000NOooool0083ooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000K
ooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Aooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool00_ooool01Oo<c<co0000o`000?l0003oc<c<00?ooooo
00Go0000ooooooooooooooooo`00001iooooo`00P?ooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`00
01_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03oa0@4?l0003o0000
00?o00007?ooool00ol0003oooooooooo`02ooooo`05oa0@4?nj^[[ooooookZj^_l@41000oooool0
1Ol@413ooooooooooooooooo410@07Wooooo0020ooooo`06o`000?lb<S;ooooooooooolb<S;o0000
6oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`02ooooo`05o`000?nj^[[ooooookZj^_l000000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg07Wooooo001oooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@
41006?ooool00omEEEGoIVIVo`000005ooooo`Co00004_ooool00ol0003oooooooooo`0Kooooo`03
oeEEEOmVIVKo000000Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h0NOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-44.3769, -0.160437, \
0.309031, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.01333 0 0.309017 [
[.1001 -0.0125 -9 -9 ]
[.1001 -0.0125 9 0 ]
[.2334 -0.0125 -9 -9 ]
[.2334 -0.0125 9 0 ]
[.3667 -0.0125 -9 -9 ]
[.3667 -0.0125 9 0 ]
[.6333 -0.0125 -6 -9 ]
[.6333 -0.0125 6 0 ]
[.7666 -0.0125 -6 -9 ]
[.7666 -0.0125 6 0 ]
[.8999 -0.0125 -6 -9 ]
[.8999 -0.0125 6 0 ]
[.4875 .07725 -24 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -18 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -24 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1001 0 m
.1001 .00625 L
s
[(-30)] .1001 -0.0125 0 1 Mshowa
.2334 0 m
.2334 .00625 L
s
[(-20)] .2334 -0.0125 0 1 Mshowa
.3667 0 m
.3667 .00625 L
s
[(-10)] .3667 -0.0125 0 1 Mshowa
.6333 0 m
.6333 .00625 L
s
[(10)] .6333 -0.0125 0 1 Mshowa
.7666 0 m
.7666 .00625 L
s
[(20)] .7666 -0.0125 0 1 Mshowa
.8999 0 m
.8999 .00625 L
s
[(30)] .8999 -0.0125 0 1 Mshowa
.125 Mabswid
.12676 0 m
.12676 .00375 L
s
.15342 0 m
.15342 .00375 L
s
.18008 0 m
.18008 .00375 L
s
.20674 0 m
.20674 .00375 L
s
.26006 0 m
.26006 .00375 L
s
.28672 0 m
.28672 .00375 L
s
.31338 0 m
.31338 .00375 L
s
.34004 0 m
.34004 .00375 L
s
.39336 0 m
.39336 .00375 L
s
.42002 0 m
.42002 .00375 L
s
.44668 0 m
.44668 .00375 L
s
.47334 0 m
.47334 .00375 L
s
.52666 0 m
.52666 .00375 L
s
.55332 0 m
.55332 .00375 L
s
.57998 0 m
.57998 .00375 L
s
.60664 0 m
.60664 .00375 L
s
.65996 0 m
.65996 .00375 L
s
.68662 0 m
.68662 .00375 L
s
.71328 0 m
.71328 .00375 L
s
.73994 0 m
.73994 .00375 L
s
.79326 0 m
.79326 .00375 L
s
.81992 0 m
.81992 .00375 L
s
.84658 0 m
.84658 .00375 L
s
.87324 0 m
.87324 .00375 L
s
.07344 0 m
.07344 .00375 L
s
.04678 0 m
.04678 .00375 L
s
.02012 0 m
.02012 .00375 L
s
.92656 0 m
.92656 .00375 L
s
.95322 0 m
.95322 .00375 L
s
.97988 0 m
.97988 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .07725 m
.50625 .07725 L
s
[(0.25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(0.75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(1)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(1.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(1.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(1.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(185) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12822 m
.03279 .09776 L
.04262 .07372 L
.04758 .06472 L
.05288 .05685 L
.06244 .04596 L
.06788 .04111 L
.07379 .03674 L
.07936 .03347 L
.08202 .03224 L
.08451 .03129 L
.08674 .03062 L
.08789 .03035 L
.08914 .03011 L
.08985 .02999 L
.09051 .02991 L
.09181 .02978 L
.09299 .02972 L
.09425 .02972 L
.09495 .02975 L
.09559 .02978 L
.0963 .02985 L
.09704 .02993 L
.09829 .03012 L
.09967 .0304 L
.10221 .03111 L
.10458 .03198 L
.10959 .03445 L
.11503 .03806 L
.12493 .04696 L
.13457 .059 L
.14349 .0746 L
.14812 .08506 L
.15312 .09854 L
.16215 .12928 L
.18275 .22264 L
.18777 .24579 L
.19314 .26809 L
.1981 .28524 L
.2028 .29736 L
.20533 .302 L
.20676 .30399 L
.20807 .30541 L
.20918 .30629 L
.2104 .30692 L
.21168 .3072 L
.21287 .30711 L
.21355 .30691 L
.2143 .30656 L
.215 .30611 L
Mistroke
.21565 .3056 L
.21688 .30435 L
.21819 .30263 L
.22118 .29726 L
.22389 .29075 L
.22879 .27548 L
.23394 .25532 L
.24318 .21289 L
.25324 .16501 L
.26401 .1204 L
.26931 .10258 L
.27431 .08837 L
.27919 .07688 L
.28369 .06806 L
.29248 .05479 L
.30204 .04446 L
.30669 .04049 L
.31169 .03686 L
.31601 .03426 L
.32074 .03205 L
.32346 .03111 L
.32599 .03045 L
.32738 .03018 L
.32865 .03 L
.32936 .02993 L
.33012 .02987 L
.33084 .02983 L
.3315 .02981 L
.33268 .02983 L
.33378 .02988 L
.33499 .03 L
.33629 .03018 L
.33765 .03045 L
.33894 .03076 L
.34136 .0315 L
.34593 .03348 L
.35099 .03648 L
.36124 .04502 L
.37073 .05619 L
.37965 .07078 L
.38434 .08066 L
.38947 .09365 L
.39981 .12767 L
.41831 .21042 L
.42838 .25656 L
.43333 .27576 L
.4379 .2901 L
.44045 .29641 L
.44316 .3016 L
.44456 .30365 L
Mistroke
.44587 .30517 L
.44661 .30584 L
.44731 .30636 L
.44812 .30682 L
.44886 .3071 L
.45006 .30727 L
.45134 .30709 L
.45254 .30655 L
.45363 .30577 L
.45492 .30448 L
.45631 .30266 L
.45884 .29825 L
.46121 .29283 L
.46376 .28577 L
.46835 .27012 L
.47879 .22472 L
.49986 .12883 L
.51004 .09483 L
.5158 .08025 L
.52112 .06937 L
.53088 .05445 L
.5358 .04872 L
.54124 .04339 L
.54616 .03932 L
.55134 .03576 L
.55577 .03332 L
.55826 .03221 L
.5606 .03135 L
.56192 .03095 L
.56334 .03058 L
.56453 .03033 L
.56583 .03012 L
.56656 .03002 L
.56724 .02995 L
.56796 .0299 L
.56874 .02986 L
.56945 .02984 L
.57013 .02985 L
.57141 .0299 L
.57262 .03 L
.57391 .03017 L
.57512 .03039 L
.57622 .03063 L
.57892 .03142 L
.58146 .03239 L
.58614 .03473 L
.59126 .0381 L
.6016 .04735 L
.61117 .05947 L
.62009 .0754 L
Mistroke
.62512 .08709 L
.63058 .10244 L
.64049 .13791 L
.65907 .22318 L
.664 .24586 L
.6693 .26789 L
.67422 .28491 L
.6789 .2971 L
.68139 .30176 L
.68281 .30378 L
.68412 .30525 L
.68533 .30625 L
.68643 .30686 L
.6877 .3072 L
.6889 .30718 L
.68954 .30702 L
.69024 .30674 L
.69097 .30632 L
.69166 .30581 L
.69288 .30463 L
.69419 .30298 L
.69719 .29775 L
.69992 .29129 L
.70472 .27646 L
.70983 .25668 L
.719 .21466 L
.72899 .16694 L
.73975 .12195 L
.7447 .10503 L
.74991 .08996 L
.75473 .07837 L
.75922 .06939 L
.76794 .05586 L
.77749 .04518 L
.78254 .04073 L
.78801 .03668 L
.79318 .03362 L
.79564 .03245 L
.79794 .03153 L
.80019 .03081 L
.80224 .03031 L
.80341 .03009 L
.80452 .02994 L
.80569 .02982 L
.80697 .02975 L
.80823 .02975 L
.80937 .02979 L
.81069 .02991 L
.81193 .03008 L
.81308 .03029 L
Mistroke
.81414 .03053 L
.81653 .03121 L
.81899 .03213 L
.82124 .03315 L
.82628 .03603 L
.83538 .04317 L
.84047 .04828 L
.846 .05493 L
.85119 .06249 L
.85605 .07107 L
.86547 .09301 L
.87586 .1271 L
.89688 .22189 L
.90673 .26535 L
.91168 .28297 L
.91451 .29119 L
.91709 .2973 L
.91948 .30172 L
.92057 .30332 L
.92173 .30471 L
.92297 .30587 L
.92411 .30661 L
.92534 .30706 L
.92603 .30716 L
.92668 .30715 L
.92784 .30688 L
.92893 .30633 L
.92992 .3056 L
.93099 .30454 L
.93338 .30122 L
.9356 .297 L
.94022 .28495 L
.94521 .26764 L
.95424 .22836 L
.97482 .13357 L
.97619 .12822 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^@?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hLooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=_ooool0
03Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Oooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`12ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0=_ooool002oooooo1_l00006ooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41005?ooool6o`0000Gooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@01gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01oo
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03Cooooo000jooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000012ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`00>Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000007oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000@_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
7oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool00000=_ooool003[ooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@023ooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@03Kooooo000gooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0@_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL07?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Kooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Ko
oooo000gooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Ooo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0@?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Kooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo000Koooooooo0000<_l0000Looooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Pooooo`00>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo000fooooo`Go0000@oooool5o`00033ooooo00?o0000ooooooooool0
4?ooool5o`0004Cooooo1?l0001Eooooo`00<oooool3o`0000Cooooo0ol0000oooooo`;o00001?oo
ool4o`0002gooooo0_l0000?ooooo`?o00001?ooool2o`0003kooooo1?l00004ooooo`?o0000D_oo
ool003;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0iooooo`?o00002_ooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00cooooo0_l00009ooooo`;o0000>oooool0
0ol0003oooooooooo`09ooooo`;o0000D?ooool0037ooooo00?o0000ooooooooool02_ooool2o`00
03Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0COooool002oooooo0_l0000?ooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0eooooo`;o00003oooool00ol0003o
ooooooooo`1<ooooo`00;_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0Wooooo`;o00002_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`1<ooooo`00;Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0Boooool002cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo04[ooooo000[ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`19ooooo`00:oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0B?ooool002[ooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
8oooool2o`0000Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool0Aoooool002[ooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04Oooooo000Zooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Iooooo`08o`000?oooooo
ooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0A_ooool002Wo
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01[o
oooo00Oo0000oooooomgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool0A_ooool002Sooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooool@41000oooool00ol@413oooooooooo`0:
ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo04Kooooo000Xooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0Looooo`;o00000oooool00ol0003oooooooooo`0;oooo
o`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0000;ooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool0AOooool002Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool0AOooool002Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo01kooooo00Go0000oooooooooooooooooa0@400?ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo04Cooooo000Vooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0Nooooo`05o`000?nHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonH
V9So410@00Cooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo0000027ooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo04Cooooo
000Vooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`0Nooooo`05onk^k_l0003o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Co
oooo1?l00006ooooo`;o00000_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`13ooooo`009_ooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`0Oooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo04?ooooo000Uooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01oooooo
00Co0000oooooooooooo00008oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool0@oooool002Gooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool07_ooool01?l0003ooooo
ooooool0000Tooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`12ooooo`009Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo000002Gooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo04;ooooo
000Tooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo01kooooo0ol0000Uooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`12ooooo`009?ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooo000002Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo047ooooo000Tooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01gooooo0_l0000Woooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`11oooo
o`009?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0Looooo`;o00009oooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0@Oooool002Cooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
7?ooool2o`0002Sooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo047ooooo000Sooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01cooooo0_l0000Xooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`10ooooo`008oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool08_ooool0
04cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Rooooo`00C?ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo02;ooooo001=ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Iooooo`?o0000:Oooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Rooooo`00COooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool06Oooool2o`0002[ooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool08_ooool004gooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Wooooo0_l0000Z
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo02?ooooo001=ooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool0:_ooool01ol0003oooooonk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00Go
A4A4o`000?l0003o<S8bomgMg@04ooooo`;o0000:_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Sooooo`00C_oo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02[ooooo00Oo0000oooooomgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo0_l0000[ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo02?ooooo001>ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
:oooool00ol0003o410@ooooo`02ooooo`03oa0@4?oooooooooo00kooooo00Ko0000oooooooooooo
ooooo`000?ooool3o`0002Wooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0[oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool08oooool004kooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`0[ooooo`;o00000oooool00ol0003oooooooooo`0=ooooo`03
ogMgMolb<S;ooooo00;ooooo00?o0000ooooool00000:oooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo02_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Sooooo`00
C_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02cooooo0_l00003ooooo`03o`00
0?oooooooooo00[ooooo00Go0000ob4Q8Ol0003o<S8bolc<c003ooooo`03o`000?oooooo000002_o
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool09?ooool004oooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0/ooooo`03o`000?l@413ooooo00;ooooo00?o410@ooooooooool02_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooo000002_ooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool09?ooool004oooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`0/ooooo`06o`000?mgMgOoV9RHoooooonHV9So
MgMg3?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000002cooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool09?ooool004oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0]ooooo`05o`00
0?lb<S;o0000oc8b<_o^k^h03?ooool4o`0000?ooooo00?o0000ooooooooool00_l0000[ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo02Cooooo001?ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`0Eooooo`04o`000?ooooooooooo`0002cooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool09?ooool0053ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo01Gooooo00Co0000oooooooooooo0000;?ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Uooooo`00
D?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
5Oooool01?l0003oooooooooool0000/ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02Gooooo001@ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo00;o0000;?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02oooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Uooooo`00D?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04oooool01Ol0003ooooooooo
oooooooo000002gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool09Oooool0053ooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01?ooooo00Go0000oooooooooooooooo
o`00000]ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo02Kooooo001Aooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`0Cooooo`05o`000?ooooooooooooooool00000
;Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0Vooooo`00DOooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool04oooool01Ol0003ooooooooooooooooo000002gooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool09_ooool0057ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooooooo0_l0000]ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo02Kooooo001Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Vooooo`00D_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool09oooool005;ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo02Oooooo001Booooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Wooooo`00D_ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`02ooooo`;o0000;_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Wooooo`00Doooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool09oooool005?ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool00olQ8B7o0000ooooo`05ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8b
o`000005ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0:?ooool005?ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0Yooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool00olQ8B7o0000ooooo`05ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgo`000?ooool0
1?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Sooooo001Cooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0:Oooool01Ol@413ooooooooooooooooo410@00Kooooo
00?o0000ooooooooool01?ooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo
0ol0000]ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo02Sooooo001Cooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool0:Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
1Oooool00olQ8B7oooooooooo`06ooooo`03o`000?lb<S;ooooo00Cooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0Xooooo`00E?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo02[ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00Cooooo
00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?l0003oc<c<00Gooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0Yooooo`00E?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo02[ooooo00Go410@oooooooooooooooooa0@4007ooooo`03o`000?oooooooooo00Co
oooo00?oZJVYogMgMoooool00oooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool0:Oooool005Cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Zooooo`05ogMgMonHV9SooooooiRHV?mgMgL01oooool01Ol0003ooooooooooooooooo
410@00?ooooo00?o<S8booooooooool00_ooool00ol0003oooooo`000007ooooo`03o`000?oooooo
oooo02oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0:Oooool005Cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0Zooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01oooool01?l0003ooooooooooooo
ool5o`0000Cooooo1?l00006ooooo`;o0000<?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Yooooo`00E?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0:_ooool0
05Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
02[ooooo001Eooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Zooooo`00EOooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0:_ooool005Gooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0iooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool2o`00037ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0:oooool005Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo02_ooooo001Fooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0[ooooo`00E_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0:oooool005Kooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02_ooooo001Gooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Sooooo0_l0000booooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02cooooo001Gooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0/ooooo`00Eoooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0mooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0;?ooool005Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02co
oooo001Hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Wooooo0_l0000dooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02gooooo
001Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0@?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0^ooooo`00FOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo043ooooo00?o0000
ooooooooool00oooool00ol0003oooooo`000003o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo043ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0^ooooo`00F_ooool01?l0003oooooooooool00014
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo03Cooooo00Go0000ooooooooooooooooo`000013ooooo`;o00000oooool00ol0003ooooo
ooooo`0^ooooo`00F_ooool4o`0004Gooooo0ol00005ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0=Oooool4o`0004Cooooo1?l0000aooooo`00Zoooool00ol0003oooooooooo`05
ooooo`?o0000/_ooool00:_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2boooo
o`00Zoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;;ooooo002[ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0/_ooool00:Wooooo00?oEEEEofIVI_l000001ooo
ool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo
0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0
/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0
003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooo
ooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002Aoooo
o`Co000000?o410@ooooooooool00_ooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool00ol0003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`04oooo
o`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^
00Wooooo00?o0000ooooooooool00oooool3o`000;;ooooo002Cooooo`03o`000?oooooooooo00co
oooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;;o
oooo002Cooooo`03o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
/_ooool009?ooooo00?o0000ooooooooool02_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`2booooo`00TOooool00omEEEGoIVIVo`00
000<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0002cooooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0
003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo
002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002coooo
o`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0
/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool0
0;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003ooooo
ooooo`2booooo`00VOooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2booooo`00Voooool00ol0003ooooooooo
o`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;;ooooo002K
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2b
ooooo`00Voooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002boooo
o`00Voooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0
003oooooooooo`2booooo`00Voooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0/_ooool009_ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;;ooooo002Iooooo`03oeEEEOmVIVKo000000gooooo1?l0
0006ooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0
/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0
003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooo
ooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002coooo
o`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`00
0?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool0
097ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2booooo`00Toooool00ol0
003oooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool03?ooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002booooo`00Toooool00ol0003ooooo
ooooo`0=ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`2booooo`00Toooool00ol0003oooooooooo`0=ooooo`03oeEEEOo<c<cooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oo
oooooooo00gooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00[ooooo00Go410@oooooooooooooooooc8b
<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_ooool0097ooooo00?oEEEE
ofIVI_l000003?ooool5o`0000Cooooo1?l00006ooooo`;o0000/oooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0
/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0
003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooo
ooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002coooo
o`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`00
0?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool0
0:Sooooo1Ol00006ooooo`03o`000?oooooooooo0;;ooooo002Xooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@01_ooool00ol0003oooooooooo`2booooo`00ZOooool00onHV9So8B4Qonk^kP07ooooo`03
o`000?oooooooooo0;;ooooo002Zooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0002booooo`00Zooo
ool00omgMgOoIVIVooooo`2jooooo`00[?ooool00ol0003oooooooooo`2iooooo`00Z?ooool01Ol0
003o^[ZjoooooonHV9So410@0;_ooooo002Xooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0^oooool0
0?ooooooJOooool00:kooooo00?o0000okZj^_ooool0]oooool00:kooooo0_lb<S:hooooo`00Oooo
ool2o`000006oa0@4?oooooooooooa0@4?l0003o410@6?ooool4o`000005oa0@4?oooooooooooooo
oom4A4@00_l000001olb<S;ogMgMooooooooooooQhN7o`000?nj^[X03?ooool01OnHV9So0000o`00
0?m4A4Co^[Zj01Wooooo1?l000002?l@413oooooooooooo<c<co8B4Qo`000?lQ8B7oc<c<1?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM07Sooooo0020ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01oooool6o`0000cooooo00?o0000ooooooooool01_ooool01omgMgOo<S8boooooooo
ooooc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<ooooo`03
o`000?oooooooooo00;ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@07ooooo`03ogMgMolb<S;ooooo
07Oooooo0020ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`1foooo
o`00P?ooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000<ooooo`03o`000?oooooo
oooo00Kooooo00?oMgMgoc8b<_ooool04?ooool00ol0003oooooooooo`0;ooooo`Ko00003?ooool0
0ol0003oooooooooo`02ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801oooool00omgMgOo<S8boooo
o`1gooooo`00P?ooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001_ooooo00?o0000ooooooooool0
0oooool01Ol0003o8B4Qo`000?lb<S;oc<c<017ooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`02ooooo`05olc<c?l0003o0000o`000?o<c<`01?ooool01Ol0003o8B4Qo`000?lb<S;o
c<c<07Sooooo0020ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo00006oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo017ooooo00?o410@o`000?l000000ol0000Looooo`03o`000?oo
oooooooo00;ooooo00Go410@okZj^_oooooo^[Zjoa0@4004ooooo`03o`000?oooooooooo07[ooooo
0020ooooo`06o`000?lb<S;ooooooooooolb<S;o00006oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02ooooo`05
o`000?nj^[[ooooookZj^_l000001?ooool00ol0003oooooooooo`1jooooo`00Ooooool00ol@413o
0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo00?oEEEEofIVI_l000001Oooool4o`0001;o
oooo00?o0000ooooooooool06oooool00omEEEGoIVIVo`000004ooooo`05ojVYZOl@413o0000oa0@
4?nYZJT01?ooool4o`0007Wooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-44.3769, -0.160437, \
0.309031, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.01333 0 0.309017 [
[.1001 -0.0125 -9 -9 ]
[.1001 -0.0125 9 0 ]
[.2334 -0.0125 -9 -9 ]
[.2334 -0.0125 9 0 ]
[.3667 -0.0125 -9 -9 ]
[.3667 -0.0125 9 0 ]
[.6333 -0.0125 -6 -9 ]
[.6333 -0.0125 6 0 ]
[.7666 -0.0125 -6 -9 ]
[.7666 -0.0125 6 0 ]
[.8999 -0.0125 -6 -9 ]
[.8999 -0.0125 6 0 ]
[.4875 .07725 -24 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -18 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -24 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1001 0 m
.1001 .00625 L
s
[(-30)] .1001 -0.0125 0 1 Mshowa
.2334 0 m
.2334 .00625 L
s
[(-20)] .2334 -0.0125 0 1 Mshowa
.3667 0 m
.3667 .00625 L
s
[(-10)] .3667 -0.0125 0 1 Mshowa
.6333 0 m
.6333 .00625 L
s
[(10)] .6333 -0.0125 0 1 Mshowa
.7666 0 m
.7666 .00625 L
s
[(20)] .7666 -0.0125 0 1 Mshowa
.8999 0 m
.8999 .00625 L
s
[(30)] .8999 -0.0125 0 1 Mshowa
.125 Mabswid
.12676 0 m
.12676 .00375 L
s
.15342 0 m
.15342 .00375 L
s
.18008 0 m
.18008 .00375 L
s
.20674 0 m
.20674 .00375 L
s
.26006 0 m
.26006 .00375 L
s
.28672 0 m
.28672 .00375 L
s
.31338 0 m
.31338 .00375 L
s
.34004 0 m
.34004 .00375 L
s
.39336 0 m
.39336 .00375 L
s
.42002 0 m
.42002 .00375 L
s
.44668 0 m
.44668 .00375 L
s
.47334 0 m
.47334 .00375 L
s
.52666 0 m
.52666 .00375 L
s
.55332 0 m
.55332 .00375 L
s
.57998 0 m
.57998 .00375 L
s
.60664 0 m
.60664 .00375 L
s
.65996 0 m
.65996 .00375 L
s
.68662 0 m
.68662 .00375 L
s
.71328 0 m
.71328 .00375 L
s
.73994 0 m
.73994 .00375 L
s
.79326 0 m
.79326 .00375 L
s
.81992 0 m
.81992 .00375 L
s
.84658 0 m
.84658 .00375 L
s
.87324 0 m
.87324 .00375 L
s
.07344 0 m
.07344 .00375 L
s
.04678 0 m
.04678 .00375 L
s
.02012 0 m
.02012 .00375 L
s
.92656 0 m
.92656 .00375 L
s
.95322 0 m
.95322 .00375 L
s
.97988 0 m
.97988 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .07725 m
.50625 .07725 L
s
[(0.25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(0.75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(1)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(1.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(1.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(1.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(190) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .23955 m
.04262 .15168 L
.0522 .11414 L
.06244 .08411 L
.0679 .07219 L
.07286 .06338 L
.08255 .05035 L
.08798 .04478 L
.09388 .03976 L
.0994 .03589 L
.10458 .03303 L
.10913 .03118 L
.11168 .03044 L
.11281 .03018 L
.11402 .02995 L
.11534 .02977 L
.11657 .02965 L
.11732 .02961 L
.11803 .02959 L
.11866 .02958 L
.11935 .02959 L
.12063 .02967 L
.12128 .02972 L
.12199 .02981 L
.12324 .03 L
.12442 .03023 L
.12714 .03097 L
.12973 .03191 L
.13457 .03431 L
.13978 .03776 L
.14545 .04252 L
.15485 .0529 L
.1602 .06057 L
.16522 .06929 L
.17533 .0927 L
.18102 .11 L
.18623 .12867 L
.20676 .22113 L
.21676 .26513 L
.22149 .28196 L
.22585 .29411 L
.22806 .29882 L
.2304 .30266 L
.23161 .30417 L
.23275 .30527 L
.23399 .30614 L
.23469 .30647 L
.23533 .30667 L
.23647 .30679 L
.23753 .30662 L
Mistroke
.23869 .30613 L
.23992 .30526 L
.2411 .30411 L
.24221 .30273 L
.24428 .2994 L
.24668 .29439 L
.24921 .28783 L
.25374 .27317 L
.26396 .23004 L
.27419 .18129 L
.28386 .13838 L
.29328 .10434 L
.30199 .0808 L
.31135 .0628 L
.31629 .05565 L
.32153 .04934 L
.33149 .04003 L
.33715 .036 L
.34246 .03305 L
.34474 .03205 L
.34717 .03116 L
.34857 .03073 L
.34984 .03041 L
.35105 .03015 L
.35232 .02994 L
.35295 .02985 L
.35365 .02977 L
.35488 .02968 L
.35557 .02965 L
.35631 .02964 L
.35701 .02965 L
.35765 .02967 L
.35889 .02976 L
.35959 .02983 L
.36024 .02991 L
.36142 .03011 L
.36268 .03037 L
.36487 .03096 L
.36722 .03178 L
.37148 .03376 L
.37655 .03687 L
.3812 .04045 L
.39099 .05038 L
.4001 .06342 L
.40534 .07321 L
.4101 .08397 L
.42079 .11577 L
.43076 .15528 L
.43995 .19782 L
.45069 .24782 L
Mistroke
.45594 .26922 L
.46074 .28545 L
.46296 .29158 L
.46537 .29718 L
.46766 .30134 L
.46977 .30418 L
.47104 .30538 L
.47224 .30618 L
.47331 .3066 L
.47447 .30676 L
.47574 .30656 L
.47638 .30632 L
.47708 .30594 L
.47832 .305 L
.47948 .30379 L
.48216 .29983 L
.48469 .29463 L
.48944 .28143 L
.49455 .26291 L
.50011 .23905 L
.51951 .14851 L
.53055 .10688 L
.5356 .09195 L
.54092 .07892 L
.54563 .0694 L
.55078 .06083 L
.55983 .04923 L
.56493 .04408 L
.57038 .03943 L
.57515 .03604 L
.5802 .03315 L
.58274 .03199 L
.58554 .03096 L
.58676 .0306 L
.58808 .03026 L
.58931 .03001 L
.59045 .02982 L
.5912 .02972 L
.59188 .02965 L
.59263 .02959 L
.59343 .02955 L
.59413 .02954 L
.59489 .02955 L
.5956 .02957 L
.59626 .02961 L
.59749 .02973 L
.59819 .02982 L
.59884 .02993 L
.60015 .03018 L
.60156 .03052 L
Mistroke
.60418 .03135 L
.60666 .03235 L
.6113 .03478 L
.61672 .03848 L
.62172 .0427 L
.63138 .05333 L
.64044 .06734 L
.64562 .07785 L
.65037 .08945 L
.66106 .12353 L
.68164 .21505 L
.69166 .26001 L
.6964 .2777 L
.70075 .29081 L
.70293 .29602 L
.70532 .30061 L
.70648 .30239 L
.70773 .30396 L
.70904 .30524 L
.71027 .30607 L
.71142 .30653 L
.71267 .30668 L
.71386 .30648 L
.71496 .30599 L
.71594 .30532 L
.71703 .30432 L
.71923 .30145 L
.72178 .29679 L
.72412 .29131 L
.72939 .27515 L
.73893 .23579 L
.74885 .1886 L
.75945 .14078 L
.76861 .10694 L
.77855 .07985 L
.78389 .06902 L
.78881 .06088 L
.7985 .04864 L
.80731 .04046 L
.8121 .03691 L
.81664 .03411 L
.819 .03289 L
.82157 .03175 L
.82393 .0309 L
.82607 .0303 L
.82739 .03001 L
.82862 .02979 L
.82992 .02963 L
.83066 .02956 L
.83133 .02952 L
Mistroke
.83246 .02949 L
.8337 .02951 L
.835 .02959 L
.83621 .02973 L
.83735 .02991 L
.83858 .03016 L
.84083 .03076 L
.84302 .03152 L
.84505 .03238 L
.84964 .03484 L
.85452 .0382 L
.86391 .04681 L
.86884 .05259 L
.87402 .05987 L
.88356 .07758 L
.89231 .10039 L
.90187 .13391 L
.91208 .17853 L
.92165 .22407 L
.93046 .26287 L
.93535 .28061 L
.93794 .28844 L
.94072 .29543 L
.94218 .29847 L
.94351 .30084 L
.94487 .30286 L
.94612 .30435 L
.94752 .30559 L
.94827 .30607 L
.94905 .30643 L
.95037 .3067 L
.95113 .30668 L
.95183 .30653 L
.95301 .30603 L
.95429 .3051 L
.95494 .30449 L
.95564 .30373 L
.95689 .30208 L
.95932 .29789 L
.96153 .29297 L
.96691 .27707 L
.97199 .25777 L
.97619 .23955 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^@?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hLooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=_ooool0
03Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Oooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`12ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0=_ooool002oooooo1_l00006ooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41005?ooool6o`0000Gooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@01gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01oo
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03Cooooo000jooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000012ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`00>Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000007oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000@_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
7oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool00000=_ooool003[ooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@023ooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@03Kooooo000gooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0@_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL07?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Kooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Ko
oooo000gooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Ooo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0@?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Kooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo000Koooooooo0000<_l0000Looooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Pooooo`00>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo000mooooo`Go0000@oooool5o`0002Wooooo00?o0000ooooooooool0
5oooool6o`0004?ooooo1Ol0001=ooooo`00>_ooool3o`0000Gooooo0_l0000oooooo`?o00001?oo
ool4o`0002Gooooo0_l0000Fooooo`?o00001Oooool2o`0003oooooo0_l00004ooooo`?o0000Booo
ool003Wooooo00?o0000ooooooooool02?ooool2o`0003_ooooo0_l0000;ooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool04oooool2o`0000[ooooo00?o0000ooooooooool0>Oooool3
o`0000Wooooo0_l00019ooooo`00>?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool02oooool2o`0003Sooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`16ooooo`00=oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0AOooool003Gooooo0_l0000Aooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Oooooo`;o00004Oooool2o`00017ooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Cooooo
000dooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`13ooooo`00=?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0@_ooool003?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo04;ooooo000booooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`11ooooo`00<Oooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Kooooo`;o0000
3Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`11ooooo`00<Oooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool0@?ooool0033ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Cooooo00Ook^k^oc8b<_l0003o<S8bonk^
k_oooooo000000?ooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Go
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`10ooooo`00<?ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool05?ooool01omgMgOoV9RH
oooooonHV9SoMgMgooooool000000oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0o
ooooo`00<?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool05Oooool01ol@413ooooooooooooooooo410@ooooool000002_ooool00onHV9So8B4Qonk^
kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0oooooo`00;oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool05Oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool02?oo
ool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00009ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo03kooooo000_ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0Fooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooooooo
o`09ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool0?_ooool002kooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01Kooooo00Go410@oooooooooooooooo
oa0@4003ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0?Oooool002kooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`03ooooo`03o`000?oooooooooo00Gooooo00Go0000okZj^_oooooo
V9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0mooooo`00;Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool05oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00?o0000oooooooo
ool01?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o00002Oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0looooo`00;Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool0??ooool002gooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo03cooooo000/ooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`0kooooo`00;?ooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0>oooool002cooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool05_ooool2o`0000Oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0>oooool002_ooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03[ooooo000[ooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0jooooo`00:ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>_oo
ool002_ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo03Wooooo000Zooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo01Cooooo0_l00006ooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
03Wooooo000Zooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0iooooo`00:_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool0>?ooool002Wooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo03Sooooo000Yooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01?ooooo0_l00005
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo03Sooooo000Yooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`0hooooo`00:Oooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0=oooool002Sooooo00?o0000ooooooooool0
:_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02Gooooo00Kok^k^oc8b<_l0003o
<S8bonk^k_l00004ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`0gooooo`00:?ooool00ol0003oooooooooo`0Zoooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool09Oooool01omgMgOoV9RHoooooonHV9So
MgMgooooool000000oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo03Oooooo000Xooooo`03o`000?oooooooooo02_ooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`0Uooooo`07oa0@4?ooooooooooooooool@413ooooo
o`00000>ooooo`03o`000?oooooooooo00?ooooo0ol00003ooooo`03o`000?oooooooooo02[ooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03Oooooo
000Xooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0Uooooo`07o`000?ooooooooooooooool0003oooooo`00000=ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0fooooo`00:?ooool00ol0003ooooo
ooooo`0[ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool09_ooool01ol0003ooooo
oooooooooooo0000ooooool000002_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`0fooooo`009oooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool09_ooool01Ol@413ooooooooooooooooo
410@00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool0=_ooool002Oooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo02Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo03Kooooo000Wooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool0
0ol0003oooooooooo`07ooooo`Co00001_ooool2o`0000?ooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0=_ooool0
02Oooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool04Oooool01Ol0003ooooooooooooooooo000002oooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo03Gooooo000Woooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0_oooo
o`03o`000?oooooooooo013ooooo00Go0000ooooooooooooooooo`00000_ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0eooooo`009_ooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`0@ooooo`05o`000?ooooooooooooooool00000<?ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0=Oooool002Kooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02oooooo00?o0000oooo
ooooool04?ooool2o`0000;ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool0=Oooool002Kooooo00?o0000oooooooo
ool0;oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool04?ooool01Ol0003ooooooooooooooooo0000033ooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo03Cooooo000Vooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo013o
oooo00Co0000oooooooooooo0000<Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool0=?ooool002Kooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool03oooool01?l0003o
ooooooooool0000booooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`0dooooo`009Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooo`00
03;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
03Cooooo000Uooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo00oooooo0_l000000ooooooo0000ooooo`0aooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0dooooo`00
9Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo000003?ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo03?ooooo000Uooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooool00000<oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool0<oooool002Gooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooo`00000dooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`0cooooo`009Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo0000
03Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
03?ooooo000Tooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo00kooooo0ol0000dooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0cooooo`009?ooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`0>ooooo`;o0000=Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool0<_ooool002Cooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo02;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1_ooool2o`0000Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`;o0000=_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0<_ooool002Cooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGo0000ooooo`07ooooo`03
ogMgMolb<S;ooooo00Cooooo0_l0000fooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0<oooool00ol0003oooooooooo`0booooo`009?ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool08_ooool01Ol@413ooooooooooooooooo410@00go
oooo00?oZJVYo`000?ooool02?ooool00ol0003oooooooooo`03ooooo`?o0000=Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0<_ooool002?ooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02;ooooo
00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_oo
ool01?ooool2o`0003Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo037ooooo000Sooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0Rooooo`05o`000?ooooooooooooooool000003_ooool00ol0003o
c<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0aoooo
o`008oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool08oooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYo`000?ooool00oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool08_ooool005_o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Sooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol@413ooooooooooooooooo000000Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0fooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0=Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02;ooooo001Looooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004
ooooo`Co00001_ooool2o`0003Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool08_ooool005cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00_ooooo0_l0000hoooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo02?ooooo001Looooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`0;ooooo`;o0000>?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Sooooo`00
G?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0
2_ooool2o`0003Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0gooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool08oooool005cooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Wooooo00?o0000ooooool00000>Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Sooooo`00GOooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo03Wooooo00?o0000ooooooooool02Oooool01?l0003oooooo`000?l0000hooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo02?ooooo001Mooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooo000003[ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08oooool0
05gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooool00000>_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Tooooo`00GOooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooo`00000jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo02Cooooo001Nooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooo`0003_o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool09?ooool005kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0looooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_l0000jooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo02Cooooo001Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`0003_ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
9Oooool005kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0mooooo`03o`000?oo
oooooooo00Kooooo00Co0000oooooooooooo0000??ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo03gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Uooooo`00Gooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool01Ooo
ool01Ol0003ooooooooooooooooo000003cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09Oooool0063ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Cooooo00Co
0000oooooooooooooooo0_l0000kooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Kooooo001Pooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo043ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Vooooo`00H?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo043ooooo1Ol000000ol@413o0000ooooo`03
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`10
ooooo`;o00000oooool00ol0003oooooooooo`0Wooooo`00HOooool2o`000003ooooool0003o0000
04?ooooo0ol000000ooooooo0000ooooo`04ooooo`03o`000?oooooooooo03cooooo00Go0000oooo
ooooooooooooo`000013ooooo`03o`000?oooooooooo00;o0000:Oooool006;ooooo0ol00015oooo
o`?o00001_ooool00ol0003oooooooooo`0looooo`Co0000A?ooool4o`0002[ooooo002[ooooo`03
o`000?oooooooooo00Gooooo0ol0002booooo`00Zoooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;;ooooo002[ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/_oo
ool00:_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2booooo`00ZOooool00omE
EEGoIVIVo`000007ooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo
00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000
ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00
/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool0
0ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;o
oooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000oooooooo
ool0/_ooool0097ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool5o`0000Cooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`00
0?oooooooooo00Cooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00_ooooo
00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000/_ooool009?ooooo00?o
0000ooooooooool03?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool03Oooool00omgMgOoIVIVooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2booooo`00Toooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;;ooooo002Aoooo
o`03oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2
o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;o
oooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002c
ooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooooooo
ool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool0
0ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002Iooooo`Co000000?o410@ooooooooool00_ooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;;ooooo002Koooo
o`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0/_ooool009_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo0;;ooooo002Kooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool0
1?ooool3o`000;;ooooo002Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`03o`000?oooooooooo0;;ooooo002Kooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2booooo`00Voooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_ooool009Wooooo00?oEEEEofIV
I_l000003Oooool4o`0000Kooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00
/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool0
0ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;o
oooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000oooooooo
ool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_oo
ool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003o
ooooooooo`2booooo`00TOooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B46ooooo`03o`00
0?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;;o
oooo002Cooooo`03o`000?oooooooooo00Cooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2booooo`00Toooool00ol0003ooooooooo
o`0<ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000;;ooooo002C
ooooo`03o`000?oooooooooo00gooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00gooooo00?oEEEEolc<
c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/_ooool0
09?ooooo00?o0000ooooooooool03Oooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool02_ooool01Ol@413o
oooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2boooo
o`00TOooool00omEEEGoIVIVo`00000<ooooo`Go00001?ooool4o`0000Kooooo0_l0002cooooo`00
/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool0
0ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?o
oooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000oooooooo
ool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_oo
ool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003o
ooooooooo`2booooo`00Z?ooool5o`0000Kooooo00?o0000ooooooooool0/_ooool00:Sooooo00Go
V9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0;;ooooo002Yooooo`03oiRHV?lQ
8B7ok^k^00Oooooo00?o0000ooooooooool0/_ooool00:[ooooo00?oV9RHob4Q8Oo^k^h01_ooool3
o`000;;ooooo002[ooooo`03ogMgMomVIVKooooo0;[ooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002Xooooo`05o`000?nj^[[ooooooiRHV?l@4100^oooool00:Sooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c02kooooo`00oooooomYooooo`00[_ooool00ol0003o^[Zjooooo`2gooooo`00[_ooool2
oc8b<[Sooooo001oooooo`;o000000Ko410@oooooooooooo410@o`000?l@410Hooooo`Co000000Go
410@ooooooooooooooooodA4A002o`000007oc8b<_oMgMgooooooooooon7QhOo0000okZj^P0<oooo
o`05oiRHV?l0003o0000odA4A?nj^[X06Oooool4o`000007oa0@4?oooooooooooa0@4?l0003oA4A4
olc<c004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0NOooool0083ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`07ooooo`Ko00003?ooool00ol0003oooooooooo`06ooooo`07ogMg
Molb<S;oooooooooooo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6
o`0000cooooo00?o0000ooooooooool01?ooool00onHV9So410@omgMg@03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL0NOooool0083ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo00Gooooo00?oQhN7oeEEEOooool00_ooool01Ol@413ooooooooooooo
oooo410@07Wooooo0020ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000cooooo
00?o0000ooooooooool01_ooool00omgMgOo<S8booooo`0@ooooo`03o`000?oooooooooo00_ooooo
1_l0000<ooooo`03o`000?oooooooooo00;ooooo00Goc<c<ob4Q8Ol0003oEEEEo`000003ooooo`05
o`000?ooooooooooooooool00000NOooool0083ooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000K
ooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Aooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool00_ooool01OlQ8B7oQhN7oooooonHV9So000000?ooooo
00Go0000ooooooooooooooooo`00001iooooo`00P?ooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`00
01_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03oa0@4?l0003o0000
00?o00007?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol@413ooooooooooooooooo410@07Wooooo0020ooooo`06o`000?lb<S;ooooooooooolb<S;o0000
6oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`02ooooo`05ob4Q8OnHV9SoooooogMgMomEEED00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg07Wooooo001oooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@
41006?ooool00omEEEGoIVIVo`000005ooooo`Co00004_ooool00ol0003oooooooooo`0Kooooo`03
oeEEEOmVIVKo000000Cooooo00Goc<c<oa0@4?l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h0NOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-44.3769, -0.160437, \
0.309031, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.01333 0 0.309017 [
[.1001 -0.0125 -9 -9 ]
[.1001 -0.0125 9 0 ]
[.2334 -0.0125 -9 -9 ]
[.2334 -0.0125 9 0 ]
[.3667 -0.0125 -9 -9 ]
[.3667 -0.0125 9 0 ]
[.6333 -0.0125 -6 -9 ]
[.6333 -0.0125 6 0 ]
[.7666 -0.0125 -6 -9 ]
[.7666 -0.0125 6 0 ]
[.8999 -0.0125 -6 -9 ]
[.8999 -0.0125 6 0 ]
[.4875 .07725 -24 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -18 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -24 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1001 0 m
.1001 .00625 L
s
[(-30)] .1001 -0.0125 0 1 Mshowa
.2334 0 m
.2334 .00625 L
s
[(-20)] .2334 -0.0125 0 1 Mshowa
.3667 0 m
.3667 .00625 L
s
[(-10)] .3667 -0.0125 0 1 Mshowa
.6333 0 m
.6333 .00625 L
s
[(10)] .6333 -0.0125 0 1 Mshowa
.7666 0 m
.7666 .00625 L
s
[(20)] .7666 -0.0125 0 1 Mshowa
.8999 0 m
.8999 .00625 L
s
[(30)] .8999 -0.0125 0 1 Mshowa
.125 Mabswid
.12676 0 m
.12676 .00375 L
s
.15342 0 m
.15342 .00375 L
s
.18008 0 m
.18008 .00375 L
s
.20674 0 m
.20674 .00375 L
s
.26006 0 m
.26006 .00375 L
s
.28672 0 m
.28672 .00375 L
s
.31338 0 m
.31338 .00375 L
s
.34004 0 m
.34004 .00375 L
s
.39336 0 m
.39336 .00375 L
s
.42002 0 m
.42002 .00375 L
s
.44668 0 m
.44668 .00375 L
s
.47334 0 m
.47334 .00375 L
s
.52666 0 m
.52666 .00375 L
s
.55332 0 m
.55332 .00375 L
s
.57998 0 m
.57998 .00375 L
s
.60664 0 m
.60664 .00375 L
s
.65996 0 m
.65996 .00375 L
s
.68662 0 m
.68662 .00375 L
s
.71328 0 m
.71328 .00375 L
s
.73994 0 m
.73994 .00375 L
s
.79326 0 m
.79326 .00375 L
s
.81992 0 m
.81992 .00375 L
s
.84658 0 m
.84658 .00375 L
s
.87324 0 m
.87324 .00375 L
s
.07344 0 m
.07344 .00375 L
s
.04678 0 m
.04678 .00375 L
s
.02012 0 m
.02012 .00375 L
s
.92656 0 m
.92656 .00375 L
s
.95322 0 m
.95322 .00375 L
s
.97988 0 m
.97988 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .07725 m
.50625 .07725 L
s
[(0.25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(0.75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(1)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(1.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(1.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(1.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(195) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30632 m
.06244 .1727 L
.07216 .1308 L
.08255 .09546 L
.08852 .08001 L
.09396 .06871 L
.09948 .05945 L
.10458 .0525 L
.11433 .04233 L
.11947 .03824 L
.12492 .03472 L
.12965 .03237 L
.13192 .03149 L
.13407 .0308 L
.13529 .03048 L
.13661 .03019 L
.13783 .02997 L
.13893 .02982 L
.14024 .0297 L
.14096 .02966 L
.14164 .02964 L
.14285 .02964 L
.14415 .0297 L
.14539 .02981 L
.14652 .02997 L
.14783 .0302 L
.14907 .03047 L
.15127 .03109 L
.15366 .03196 L
.15908 .03462 L
.16409 .03793 L
.1743 .0472 L
.17946 .05336 L
.18515 .06166 L
.19525 .08155 L
.2045 .10739 L
.21466 .14523 L
.22536 .19355 L
.2349 .2383 L
.24015 .26073 L
.2451 .27892 L
.24972 .29231 L
.25232 .29805 L
.25472 .30208 L
.2557 .30335 L
.25675 .30448 L
.25789 .30542 L
.25897 .30603 L
.26018 .30639 L
.26132 .30642 L
Mistroke
.26235 .30618 L
.26347 .30564 L
.26412 .30519 L
.2648 .30461 L
.26603 .3033 L
.26735 .30152 L
.2688 .29911 L
.27381 .28737 L
.27866 .27155 L
.28318 .25366 L
.30416 .15617 L
.31464 .11447 L
.32456 .08497 L
.33346 .06625 L
.33848 .05823 L
.34312 .05207 L
.35278 .04208 L
.36183 .03536 L
.36701 .03259 L
.36947 .03157 L
.37176 .0308 L
.37425 .03016 L
.37556 .02991 L
.37697 .02972 L
.37768 .02964 L
.37844 .02959 L
.37917 .02955 L
.37984 .02954 L
.3811 .02955 L
.38174 .02958 L
.38244 .02964 L
.38374 .02978 L
.38495 .02996 L
.38627 .03023 L
.38767 .03058 L
.39003 .03132 L
.39263 .03236 L
.39743 .03486 L
.40193 .03785 L
.41199 .04685 L
.41764 .05353 L
.42284 .06099 L
.43262 .07977 L
.44174 .10454 L
.45174 .14098 L
.46243 .18877 L
.47265 .23684 L
.47804 .25998 L
.48375 .28074 L
.48874 .29447 L
Mistroke
.4901 .29739 L
.49157 .30009 L
.49284 .30205 L
.49423 .30377 L
.49488 .30443 L
.49557 .30503 L
.49681 .30583 L
.49811 .30627 L
.49928 .30634 L
.50042 .3061 L
.50165 .30549 L
.50282 .30459 L
.50389 .30349 L
.50635 .29998 L
.5086 .29563 L
.51364 .28216 L
.51831 .26572 L
.52273 .24745 L
.5434 .1512 L
.55306 .11328 L
.55836 .09644 L
.56332 .08321 L
.57209 .06525 L
.57674 .05798 L
.58175 .05146 L
.59133 .04179 L
.59676 .03756 L
.60181 .03436 L
.60456 .03292 L
.60715 .03177 L
.60951 .03092 L
.61201 .03022 L
.61331 .02995 L
.614 .02983 L
.61473 .02972 L
.61603 .02957 L
.61724 .02949 L
.61797 .02946 L
.61876 .02946 L
.61951 .02948 L
.6202 .02952 L
.62152 .02963 L
.62225 .02973 L
.62291 .02983 L
.62525 .03032 L
.62657 .03069 L
.62781 .03109 L
.63297 .03333 L
.63743 .03598 L
.64221 .03951 L
Mistroke
.64782 .04457 L
.65312 .05036 L
.65784 .05649 L
.66305 .06459 L
.67274 .08463 L
.67804 .09903 L
.68301 .11502 L
.70145 .1931 L
.71182 .24169 L
.71694 .26324 L
.72169 .28033 L
.72597 .29253 L
.72837 .29781 L
.73054 .30154 L
.7317 .30312 L
.73293 .30445 L
.73357 .305 L
.73428 .30551 L
.73552 .30611 L
.73669 .30636 L
.73794 .30626 L
.73913 .30583 L
.74021 .30516 L
.74139 .30411 L
.74249 .30285 L
.74501 .29893 L
.74747 .29381 L
.75012 .28692 L
.75929 .25399 L
.78004 .15769 L
.79042 .11596 L
.80007 .08656 L
.80494 .07518 L
.81015 .06522 L
.81588 .05639 L
.82117 .04982 L
.83141 .04013 L
.8368 .03628 L
.84251 .03308 L
.8449 .03203 L
.84746 .03109 L
.84989 .0304 L
.85096 .03016 L
.8521 .02995 L
.8528 .02984 L
.85344 .02975 L
.85469 .02963 L
.85539 .02959 L
.85614 .02956 L
.85686 .02955 L
Mistroke
.85751 .02957 L
.85871 .02962 L
.86002 .02975 L
.86068 .02984 L
.86138 .02995 L
.86266 .03019 L
.86523 .03087 L
.86795 .03184 L
.87285 .03424 L
.87812 .03769 L
.88393 .04255 L
.88893 .04764 L
.89431 .05422 L
.89936 .06165 L
.90406 .06992 L
.91365 .09205 L
.92413 .12599 L
.94524 .22006 L
.95359 .25736 L
.95769 .27316 L
.96146 .28551 L
.9649 .29453 L
.96665 .29822 L
.96853 .30145 L
.96952 .30283 L
.97042 .3039 L
.97133 .3048 L
.97218 .30546 L
.97317 .30602 L
.97424 .30637 L
.97518 .30646 L
.97619 .30632 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^@?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hLooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=_ooool0
03Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Oooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`12ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0=_ooool002oooooo1_l00006ooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41005?ooool6o`0000Gooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@01gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01oo
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03Cooooo000jooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000012ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`00>Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000007oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000@_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
7oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool00000=_ooool003[ooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@023ooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@03Kooooo000gooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0@_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL07?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Kooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Ko
oooo000gooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Ooo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0@?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Kooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo000Koooooooo0000<_l0000Looooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Pooooo`00>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo0014ooooo`Ko0000@oooool5o`00027ooooo00?o0000ooooooooool0
7oooool5o`0004?ooooo1Ol00016ooooo`00@_ooool3o`0000Cooooo0ol0000nooooo`?o00001Ooo
ool2o`0001oooooo0_l0000Nooooo`;o00001Oooool3o`0003gooooo0ol00005ooooo`;o0000A?oo
ool0047ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0iooooo`;o00002_ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo0_l0000:ooooo`03o`000?oooooo
oooo03Wooooo00?o0000ooooooooool02?ooool2o`0004;ooooo000oooooo`;o00003?ooool2o`00
03Sooooo00?o0000ooooooooool02oooool2o`0001cooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo03Kooooo0_l0000=ooooo`;o0000@?ooool003ko
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03go
oooo000mooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo01Sooooo0_l0000Iooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03gooooo
000looooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0looooo`00>oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool0>oooool003[ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo03[ooooo000iooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0jooooo`00>Oooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Dooooo`;o0000
5Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0iooooo`00>?ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0>?ooool003Sooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q00Coooooo`000?oooooooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03Oooooo000hooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0>ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@;ooooo00Oo0000oooooonHV9So8B4Qonk^k_oooooo
A4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo03Oooooo000gooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0>ooooo`05oa0@4?ooooooooooooooool@41002Oooool01_l0003ooooooooooonH
V9So8B4Qonk^kPWooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo03Kooooo000fooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0>ooooo`05o`000?ooooooooooooooool000002_ooool01_l0003ooooo
oooooonHV9So8B4Qonk^kPOooooo00?oMgMgoc8b<_ooool01?ooool3o`00017ooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool0=_ooool003Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo00oooooo00Go0000ooooooooooooooooo`00000:ooooo`06o`000?oooooooooo
oooooomgMgOoIVIV1?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0eooooo`00=Oooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool03oooool01Ol@413ooooooooooooooooo410@00[ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0eooooo`00=Oooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool03oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0eooooo`00=Oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool04?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00Go0000oa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`00
013ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool0=?ooool003Cooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo03Cooooo000dooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`0dooooo`00=?ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0<oooool003?ooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03?ooooo000coooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo00oooooo0_l0000?ooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03?ooooo000cooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0booooo`00
<_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
<_ooool003;ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo03;ooooo000booooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0aooooo`00<_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0=ooooo`;o00003Oooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0aooooo`00<Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool0<Oooool0037ooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo037ooooo000aooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`0`ooooo`00<Oooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0<
ooooo`;o00003?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`0`ooooo`00<?ooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0<?ooool0033ooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo033ooooo000`ooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Looooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@03o`000?oooooooooo00;ooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0<?ooool0033o
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01co
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q00?oooooo`000?ooool01Oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0;oooool002oo
oooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01go
oooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooool3o`0000[ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0;oooool002oooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01gooooo00Go0000oooooooo
ooooooooo`000008ooooo`03o`000?oooooooooo00Cooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo02oooooo000_ooooo`03o`000?oooooooooo02_o
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Mooooo`05o`000?oooooooooooooo
ool000002Oooool02?l0003oooooooooool0003o8B4Qo`000?lb<S;oc<c<1Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0[ooooo`03o`000?oooooooooo02oooooo000_ooooo`03o`000?oooooooooo02_ooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0Mooooo`05oa0@4?ooooooooooooooool@4100
2Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool0;oooool002oooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo01kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`09ooooo`04o`000?ooooooooooo`00
00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0^ooooo`00;_ooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool07_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Wooooo00?o0000ooooooooool01?l00006ooooo`;o00002_ooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`0^ooooo`00;_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool0;_ooool002kooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo02kooooo000^ooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`0^ooooo`00;Oooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`08
ooooo`;o00002Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0]ooooo`00;Oooool00ol0003oooooooooo`0_oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;Oooool002gooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02gooooo000/ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0]ooooo`00;?oo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;Ooo
ool002cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool01oooool2o`0000Sooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0;?ooool0
02cooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo
02cooooo000[ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0booooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`0/ooooo`00:oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0<_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool0;?ooool002_ooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo02cooooo000[ooooo`03o`000?oooooooooo03Cooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Kooooo0_l00007
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0c
ooooo`03o`000?oooooooooo02_ooooo000Zooooo`03o`000?oooooooooo03Gooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`0[ooooo`00:_ooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool06_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0:oooool002[ooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01[ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`05ooooo`04o`000?oooooo
MgMgoc8b<PGooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0[ooooo`00:Oooool0
0ol0003oooooooooo`0fooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool06_ooool0
1Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool01_ooool00ol0003oooooo`00
0005ooooo`?o00001Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`0Zooooo`00:Oooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool06_ooool01Ol0003ooooooooooooo
oooo000000kooooo00?o8B4Qooooooooool01Oooool00ol0003oMgMgoc8b<P05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool0:_ooool002Wooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01_ooooo00Go0000ooooooooooooooooo`00
000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo03Gooooo00?o0000ooooooooool0:_ooool002Wooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01_ooooo00Go410@oooooooooooooooo
oa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooool000001oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo02Wooooo000Xooooo`03o`000?oooooooooo03Sooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Kooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooool000001oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo02Wooooo000Xooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Kooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool5o`0000Cooooo1?l00006ooooo`;o00001Oooool00ol0003oooooooooo`0fooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Yooooo`00
:?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
=oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
:Oooool002Sooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo03Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo03Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0hooooo`03o`000?oo
oooooooo02Sooooo000Wooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0>?ooool0
0ol0003oooooooooo`0Xooooo`009oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
03Sooooo00?o0000ooooooooool0:?ooool002Oooooo00?o0000ooooooooool0>_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool01?ooool2o`0000Co
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Wo
oooo00?o0000ooooooooool0:?ooool002Kooooo00?o0000ooooooooool0??ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo02Oooooo000Vooooo`03o`000?oooooooooo03cooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`0Wooooo`009_ooool00ol0003oooooooooo`0l
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool09oooool002Kooooo00?o0000oooo
ooooool0?Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Oooooo000Uooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0looooo`03
o`000?oooooooooo00;ooooo0_l00003ooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Oooooo000Uooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0looooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000nooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Vooooo`009Oooool00ol0003ooooo
ooooo`0nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0?_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool09_ooool002Gooooo00?o0000ooooooooool0
?oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03kooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0mooooo`03o`000?oooooooooo02Kooooo000Tooooo`03o`000?oooooooooo043ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0nooooo`04o`000?ooooooooooooooo`;o
000000?oooooo`000?ooool0@?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03oo
oooo00?o0000ooooooooool09Oooool002Cooooo00?o0000ooooooooool0@?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo043ooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0?oooool00ol0003o
ooooooooo`0Uooooo`009?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0>Oooool4o`000004oa0@4?ooooooooooo`0000;ooooo00?o0000ooooool0
0000@_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo047ooooo00?o0000oooooooo
ool09?ooool002?ooooo00?o0000ooooooooool0@oooool01?l0003oooooooooool0000nooooo`03
o`000?oooooooooo00?ooooo00Co0000ooooool0003o0000A?ooool00ol0003oooooooooo`02o`00
04?ooooo0_l0000Uooooo`008oooool00ol0003oooooooooo`13ooooo`Co0000?_ooool00ol0003o
ooooooooo`03ooooo`Co0000AOooool3o`0004Gooooo0_l0000Tooooo`00Zoooool00ol0003ooooo
ooooo`05ooooo`?o0000/_ooool00:_ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`2booooo`00Zoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;;ooooo002[oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/_ooool00:Wooooo00?oEEEEofIVI_l0
00001oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oo
oooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo
0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o
0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0
003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002Aooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2booooo`00Toooool00ol0003ooooooooo
o`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`000;;ooooo002Cooooo`03o`000?oooooo
oooo00cooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo0;;ooooo002Cooooo`03o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool00oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0/_ooool009?ooooo00?o0000ooooooooool02_ooool01Ol0003o^[ZjoooooonHV9So410@
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2booooo`00TOooool00omEEEGo
IVIVo`00000<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0002coooo
o`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`00
0;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0
/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0
003oooooooooo`2booooo`00VOooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2booooo`00Voooool00ol0003o
ooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;;o
oooo002Kooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2booooo`00Voooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0
002booooo`00Voooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`2booooo`00Voooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0/_ooool009_ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;;ooooo002Iooooo`03oeEEEOmVIVKo000000go
oooo1?l00006ooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o
0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0
003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002coooo
o`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0
/_ooool0097ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_ooool00ol0003ok^k^oooo
o`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2booooo`00Tooo
ool00ol0003oooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool03?ooool0
0onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002booooo`00Toooool00ol0
003oooooooooo`0=ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`0=ooooo`03oeEEEOo<c<cooooo00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03
o`000?oooooooooo00gooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00[ooooo00Go410@oooooooooooo
oooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_ooool0097ooooo
00?oEEEEofIVI_l000003?ooool5o`0000Cooooo1?l00006ooooo`;o0000/oooool00;?ooooo00?o
0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0
003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002coooo
o`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0
/_ooool00:Sooooo1Ol00006ooooo`03o`000?oooooooooo0;;ooooo002Xooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01_ooool00ol0003oooooooooo`2booooo`00ZOooool00onHV9So8B4Qonk^kP07
ooooo`03o`000?oooooooooo0;;ooooo002Zooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0002boooo
o`00Zoooool00omgMgOoIVIVooooo`2jooooo`00[?ooool00ol0003oooooooooo`2iooooo`00Z?oo
ool01Ol0003o^[ZjoooooonHV9So410@0;_ooooo002Xooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
^oooool00?ooooooJOooool00:kooooo00?o0000okZj^_ooool0]oooool00:kooooo0_lb<S:hoooo
o`00Ooooool2o`000006oa0@4?oooooooooooa0@4?l0003o410@6?ooool4o`000005oa0@4?oooooo
oooooooooom4A4@00_l000001olb<S;ogMgMooooooooooooQhN7o`000?nj^[X03?ooool01OnHV9So
0000o`000?m4A4Co^[Zj01Wooooo1?l000001ol@413oooooooooool@413o0000odA4A?o<c<`01Ooo
ool01Om4A4Co0000o`000?lb<S;ogMgM07Sooooo0020ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01oooool6o`0000cooooo00?o0000ooooooooool01_ooool01omgMgOo<S8boooo
ooooooooc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<oooo
o`03o`000?oooooooooo00Cooooo00?oV9RHoa0@4?oMgMd01oooool00omgMgOo<S8booooo`1goooo
o`00P?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool01Oooool00on7QhOoEEEEooooo`07ooooo`03o`000?oooooooooo07Kooooo0020ooooo`06o`00
0?ooooooA4A4odA4A?oooooo00002Oooool6o`0000cooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0@ooooo`03o`000?oooooooooo00_ooooo1_l0000<ooooo`03o`000?oooooooooo
00;ooooo00Goc<c<ob4Q8Ol0003oEEEEo`000007ooooo`03ogMgMolb<S;ooooo07Oooooo0020oooo
o`06o`000?oMgMgo<S8boeEEEOoMgMgo00006oooool00ol0003oooooooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`04Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo
00Go8B4QohN7QoooooooV9RHo`000004ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0N?ooool0083o
oooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool04Oooool00ol@413o0000o`000003o`0001cooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0N_ooool0083ooooo00Ko0000
oc8b<_oooooooooooc8b<_l0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo00Go8B4QoiRHV?oooooo
MgMgoeEEE@04ooooo`03o`000?oooooooooo07[ooooo001oooooo`03oa0@4?l0003oQhN700;ooooo
00?oQhN7o`000?l@41006?ooool00omEEEGoIVIVo`000005ooooo`Co00004_ooool00ol0003ooooo
ooooo`0Kooooo`03oeEEEOmVIVKo000000Cooooo00Goc<c<oa0@4?l0003o<S8bonk^kP04ooooo`Co
0000NOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-44.3769, -0.160437, \
0.309031, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.01333 0 0.309017 [
[.1001 -0.0125 -9 -9 ]
[.1001 -0.0125 9 0 ]
[.2334 -0.0125 -9 -9 ]
[.2334 -0.0125 9 0 ]
[.3667 -0.0125 -9 -9 ]
[.3667 -0.0125 9 0 ]
[.6333 -0.0125 -6 -9 ]
[.6333 -0.0125 6 0 ]
[.7666 -0.0125 -6 -9 ]
[.7666 -0.0125 6 0 ]
[.8999 -0.0125 -6 -9 ]
[.8999 -0.0125 6 0 ]
[.4875 .07725 -24 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -18 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -24 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1001 0 m
.1001 .00625 L
s
[(-30)] .1001 -0.0125 0 1 Mshowa
.2334 0 m
.2334 .00625 L
s
[(-20)] .2334 -0.0125 0 1 Mshowa
.3667 0 m
.3667 .00625 L
s
[(-10)] .3667 -0.0125 0 1 Mshowa
.6333 0 m
.6333 .00625 L
s
[(10)] .6333 -0.0125 0 1 Mshowa
.7666 0 m
.7666 .00625 L
s
[(20)] .7666 -0.0125 0 1 Mshowa
.8999 0 m
.8999 .00625 L
s
[(30)] .8999 -0.0125 0 1 Mshowa
.125 Mabswid
.12676 0 m
.12676 .00375 L
s
.15342 0 m
.15342 .00375 L
s
.18008 0 m
.18008 .00375 L
s
.20674 0 m
.20674 .00375 L
s
.26006 0 m
.26006 .00375 L
s
.28672 0 m
.28672 .00375 L
s
.31338 0 m
.31338 .00375 L
s
.34004 0 m
.34004 .00375 L
s
.39336 0 m
.39336 .00375 L
s
.42002 0 m
.42002 .00375 L
s
.44668 0 m
.44668 .00375 L
s
.47334 0 m
.47334 .00375 L
s
.52666 0 m
.52666 .00375 L
s
.55332 0 m
.55332 .00375 L
s
.57998 0 m
.57998 .00375 L
s
.60664 0 m
.60664 .00375 L
s
.65996 0 m
.65996 .00375 L
s
.68662 0 m
.68662 .00375 L
s
.71328 0 m
.71328 .00375 L
s
.73994 0 m
.73994 .00375 L
s
.79326 0 m
.79326 .00375 L
s
.81992 0 m
.81992 .00375 L
s
.84658 0 m
.84658 .00375 L
s
.87324 0 m
.87324 .00375 L
s
.07344 0 m
.07344 .00375 L
s
.04678 0 m
.04678 .00375 L
s
.02012 0 m
.02012 .00375 L
s
.92656 0 m
.92656 .00375 L
s
.95322 0 m
.95322 .00375 L
s
.97988 0 m
.97988 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .07725 m
.50625 .07725 L
s
[(0.25)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(0.75)] .4875 .23176 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(1)] .4875 .30902 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(1.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(1.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(1.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .2497 m
.02846 .26854 L
.03279 .28344 L
.03754 .296 L
.0402 .30105 L
.04135 .30275 L
.04262 .30428 L
.04385 .30542 L
.04516 .30624 L
.04637 .30664 L
.0475 .3067 L
.04819 .30659 L
.04884 .30638 L
.05006 .30573 L
.05137 .30463 L
.05281 .30298 L
.05523 .29915 L
.05781 .29367 L
.06244 .28049 L
.07382 .23452 L
.08454 .18337 L
.0941 .1404 L
.10458 .10214 L
.11434 .0764 L
.11968 .06592 L
.12466 .05796 L
.13357 .04702 L
.14313 .03865 L
.14841 .03522 L
.1533 .03277 L
.15585 .0318 L
.15867 .03096 L
.16008 .03064 L
.16161 .03038 L
.16231 .03028 L
.16305 .0302 L
.16437 .0301 L
.16563 .03006 L
.16678 .03008 L
.1681 .03015 L
.16935 .03027 L
.1705 .03044 L
.17157 .03063 L
.17398 .03121 L
.17641 .03199 L
.17909 .03307 L
.18449 .03592 L
.1897 .03949 L
.19465 .04362 L
.20394 .05366 L
Mistroke
.20913 .06096 L
.21393 .06919 L
.21917 .0801 L
.22483 .09459 L
.23543 .13016 L
.24539 .17285 L
.26401 .25861 L
.26862 .27602 L
.27354 .29098 L
.27637 .2975 L
.27895 .30197 L
.28019 .30361 L
.28154 .30499 L
.28281 .30591 L
.28399 .30642 L
.2852 .30661 L
.2865 .30643 L
.28773 .3059 L
.28886 .3051 L
.2901 .30388 L
.29147 .30213 L
.29422 .29735 L
.29694 .29104 L
.29984 .28272 L
.30507 .26415 L
.32502 .17221 L
.33552 .12703 L
.34126 .10656 L
.34662 .09051 L
.35655 .06806 L
.36181 .05933 L
.36746 .05178 L
.37261 .04617 L
.3775 .04171 L
.38665 .03524 L
.39123 .0329 L
.39387 .03185 L
.39629 .03108 L
.39883 .03048 L
.40017 .03025 L
.40085 .03016 L
.40157 .03009 L
.4028 .03 L
.40394 .02996 L
.40464 .02997 L
.4053 .02998 L
.40654 .03006 L
.4076 .03017 L
.40877 .03034 L
.40999 .03057 L
Mistroke
.41113 .03083 L
.41537 .03219 L
.41778 .03323 L
.41999 .03434 L
.42495 .0374 L
.43481 .04564 L
.44395 .05632 L
.44921 .0643 L
.45399 .07308 L
.46468 .09965 L
.47471 .13473 L
.48394 .17486 L
.49471 .22596 L
.49997 .24972 L
.50477 .26911 L
.50912 .28397 L
.51386 .29631 L
.51512 .29884 L
.51646 .30115 L
.5177 .30293 L
.51886 .30429 L
.51995 .30528 L
.52112 .30604 L
.52242 .30651 L
.5236 .3066 L
.52481 .30635 L
.5261 .3057 L
.52731 .30474 L
.52842 .30357 L
.53112 .29955 L
.53368 .29429 L
.53876 .27998 L
.54427 .25962 L
.56377 .16925 L
.57411 .12523 L
.57981 .10514 L
.58521 .08916 L
.59031 .07673 L
.59586 .06577 L
.60558 .05164 L
.61037 .04642 L
.61547 .04178 L
.62463 .03539 L
.62725 .03399 L
.63001 .03273 L
.6324 .03183 L
.63496 .03106 L
.6364 .03071 L
.63771 .03046 L
.63903 .03027 L
Mistroke
.64027 .03014 L
.64098 .0301 L
.64173 .03006 L
.64237 .03005 L
.64307 .03006 L
.64382 .03008 L
.64463 .03013 L
.6454 .03019 L
.6461 .03027 L
.64734 .03046 L
.64867 .03071 L
.65105 .03132 L
.65388 .0323 L
.65645 .03342 L
.66151 .03626 L
.66629 .03965 L
.67605 .04885 L
.68096 .05484 L
.68636 .06278 L
.69591 .08152 L
.70483 .1061 L
.71527 .14481 L
.72517 .18951 L
.73399 .23135 L
.73901 .25367 L
.74372 .27227 L
.74876 .28848 L
.75096 .29414 L
.75337 .2992 L
.75577 .30299 L
.75708 .30451 L
.7583 .30557 L
.759 .30602 L
.75965 .30634 L
.76088 .30667 L
.76219 .30664 L
.76294 .30643 L
.76362 .30613 L
.76468 .30545 L
.76582 .30442 L
.76788 .30181 L
.77033 .29748 L
.77257 .29241 L
.77743 .27807 L
.78204 .26089 L
.8021 .16811 L
.81084 .13058 L
.82027 .09788 L
.82556 .08348 L
.83042 .07254 L
Mistroke
.83998 .05637 L
.84485 .05021 L
.85018 .04465 L
.85572 .03994 L
.86096 .03633 L
.86586 .03367 L
.86844 .03255 L
.87118 .03159 L
.87349 .03097 L
.87471 .03071 L
.87602 .03048 L
.87723 .03033 L
.87833 .03023 L
.87939 .03017 L
.8805 .03015 L
.88181 .03019 L
.883 .03027 L
.88367 .03033 L
.88438 .03042 L
.88568 .03063 L
.88819 .03119 L
.8905 .03189 L
.89581 .03415 L
.90142 .0375 L
.91088 .04534 L
.91618 .0511 L
.92103 .05743 L
.93043 .07362 L
.93935 .09536 L
.94862 .12602 L
.95848 .16727 L
.97619 .2497 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00=oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^@?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hLooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=_ooool0
03Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Oooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`12ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0=_ooool002oooooo1_l00006ooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41005?ooool6o`0000Gooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@01gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01oo
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03Cooooo000jooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000012ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`00>Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000007oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000@_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
7oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool00000=_ooool003[ooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@04;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@023ooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@03Kooooo000gooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0@_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL07?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Kooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Ko
oooo000gooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Ooo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0@?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Kooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo000Koooooooo0000<_l0000Looooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Pooooo`00>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo001<ooooo`Co0000A?ooool5o`0001[ooooo00?o0000ooooooooool0
9_ooool5o`0004Cooooo1?l0000oooooo`00BOooool3o`0000Cooooo0ol0000oooooo`?o00000ooo
ool3o`0001Sooooo0_l0000Uooooo`?o00001?ooool3o`0003kooooo0ol00004ooooo`;o0000?Ooo
ool004Sooooo00?o0000ooooooooool02?ooool2o`0003_ooooo0_l00009ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool08_ooool2o`0000[ooooo00?o0000ooooooooool0>Oooool2
o`0000Wooooo0_l0000kooooo`00A_ooool2o`0000gooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0:ooooo`;o00005Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0;ooooo`;o0000>Oooool004Go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0dooooo`;o00003oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo01oooooo0_l0000?ooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0fooooo`00A?ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0Aooooo`;o00007oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0eooooo`00A?ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0=Oooool004?ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03Cooooo0012oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0coooo
o`00@Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02cooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool0<_ooool0047ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool03Oooool2o`0001cooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
<_ooool0043ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo037ooooo0010ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0
0004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo033ooooo000oooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`06ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo
00KoV9RHob4Q8Oo^k^koooooodA4A?l00006ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0`ooooo`00?_ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool01oooool01Ol@413ooooooooooooooooo410@
00cooooo00GoV9RHob4Q8Oo^k^koooooo`000007ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0_ooooo`00?_ooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo
000000gooooo00GoV9RHob4Q8Oo^k^koooooo`000005ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0
000Hooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo02oooooo000mooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool000003_oo
ool01?mgMgOoIVIVooooool00002ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo02kooooo000mooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`08ooooo`05oa0@4?ooooooooooooooool@
41003oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0^ooooo`00?Oooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool02?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4002ooooo`03o`000?oooooo000000Wooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0^ooooo`00??ooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool02Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c002ooooo`03o`000?oooooo000000?o00001_ooool2
o`0001Sooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool0;Oooool003cooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo02gooooo000looooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0]ooooo`00>oooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0;?ooool003_ooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo02cooooo000k
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo00Oooooo0_l0000Fooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02cooooo000joooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0[oooo
o`00>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool0:oooool003[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo02_ooooo000jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0Zooooo`00>Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`06ooooo`;o00005?ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0Zooooo`00>Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool0:_ooool003Wooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo02[ooooo000iooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Yooooo`00>?ooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`05ooooo`;o00004oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`0Yooooo`00>?ooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0:Oooool003Sooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02Wooooo000hooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Eooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o0000omgMg@05
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0:?ooool003Oooooo00?o0000oooo
ooooool0:_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00ol0003o<S8booooo`04ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo02[ooooo00?o0000ooooooooool0:?ooool003Oooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo01Kooooo00Go410@oooooooooooooooooa0@400?
ooooo`;o00001Oooool3o`00017ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0:?ooool003Oooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Kooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03ogMgMol0003ooooo00Cooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`0Xooooo`00=oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool05_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000
ob4Q8Ol0003o<S8bo`000005ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0:ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0:?oo
ool003Kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo01Kooooo00Go410@oooooooooooooooooa0@400<ooooo`05o`000?ooooooooooooooool00000
1Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02Oooooo000fooooo`03o`000?oo
oooooooo02cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Gooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03?ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`0Wooooo`00=_ooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool05oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo1?l000000ooooooo0000ooooo`03ooooo`;o00004Oooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Wooooo`00
=_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
9oooool003Kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo02Kooooo000eooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`0Vooooo`00=Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`02ooooo`;o00004?ooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`0Vooooo`00=Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool0;oooool01Ol0003ooooooooooooooooo0000017ooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool09_ooool003Gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo02oooooo00Go0000ooooooooooooooooo`00000Aooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
02Kooooo000dooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0_ooooo`05o`000?ooooooooooooooool000004Oooool00ol0003oooooooooo`0_oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Uoooo
o`00=?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool0<?ooool01Ol0003ooooooooooooooooo0000013ooooo00?o0000ooooooooool0<?ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool09Oooool003Co
oooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo033o
oooo00Co0000oooooooooooooooo0_l0000?ooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02Gooooo000dooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0aooooo`04
o`000?ooooooooooo`00013ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo033ooooo00?o0000ooooooooool09Oooool003Cooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo037ooooo00Co0000oooooooo
oooo00004?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`0Uooooo`00<oooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool0<Oooool01?l0003oooooooooool0000?oooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0boooo
o`03o`000?oooooooooo02Cooooo000cooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0booooo`04o`000?ooooooooooo`0000oooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03;ooooo00?o0000oooo
ooooool09?ooool003?ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool00_l0000>ooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo02Co
oooo000cooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooo000000oooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool09?ooool003?ooooo00?o
0000ooooooooool0<oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01;ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4
A?l0003o0000oc8b<_oMgMd00oooool00ol0003oooooo`00000?ooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02Co
oooo000booooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0Cooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOoo
ool01oooool00omgMgOo<S8booooo`02ooooo`03o`000?oooooo000000kooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool08oooool003;ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo01?ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00So
oooo00Ko0000ooooooooooooooooo`000?ooool3o`0000cooooo00?o0000ooooooooool0=Oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool08oooool0
03;ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
01?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMg
oc8b<_ooool00_ooool00ol0003oooooo`00000>ooooo`03o`000?oooooooooo03Gooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02?ooooo000boooo
o`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Coooo
o`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01?ooool2o`0000kooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool08oooool003;ooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01?ooooo00Go410@
oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01_oo
ool2o`0000gooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool08oooool0037ooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Cooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`06ooooo`;o0000
3Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`0Rooooo`00<Oooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool05?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
1Ol00004ooooo`Co00001_ooool2o`0000cooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool08_ooool002?ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02;ooooo000S
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0h
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Foooool002?ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`1Looooo`008oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0hooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo05cooooo000Tooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Sooooo0_l0000;ooooo`03o`00
0?oooooooooo03Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Looooo`009?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0hooooo`;o00002oooool00ol0003oooooooooo`0jooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0GOooool002Cooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0>Oooool2
o`0000_ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo05gooooo000Tooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0>_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo03Wooooo0_l0000:ooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Mooooo`009?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo05kooooo000Uooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0??ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03[ooooo
0ol00009ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`1Nooooo`009Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0jooooo`04o`000?ooooooooooo`0000Sooooo
00?o0000ooooooooool0??ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05kooooo
000Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0?Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo03[ooooo00Co0000oooooooooooo00001oooool00ol0003ooooo
ooooo`0mooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0G_ooool002Kooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0>oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo03gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Oooooo`009_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0kooooo`;o00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`1Oooooo`009oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0k
ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0oooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0H?ooool002Oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`10ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0<Oooool4
o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000004?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Pooooo`009oooool2
o`0000;ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`02o`0003Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000A?oo
ool01?l0003oooooooooool0001Sooooo`00:Oooool3o`0004Gooooo0ol0000gooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00oooool3o`0004Gooooo1?l0001Sooooo`00Zoooool0
0ol0003oooooooooo`05ooooo`?o0000/_ooool00:_ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`2booooo`00Zoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;;o
oooo002[ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/_ooool00:Wooooo00?o
EEEEofIVI_l000001oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002coooo
o`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`00
0?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool0
0;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo
00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2b
ooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00
/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooo
oooo0;;ooooo002Aooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Cooooo1Ol00004oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2booooo`00Toooool00ol0
003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`0;oooo
o`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`000;;ooooo002Cooooo`03
o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool0
0oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/_ooool009?ooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool02_ooool01Ol0003o^[Zjoooo
oonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2booooo`00TOoo
ool00omEEEGoIVIVo`00000<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo
0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2b
ooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00
/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooo
oooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo
00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000
ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00
/oooool00ol0003oooooooooo`2booooo`00VOooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2booooo`00Vooo
ool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0;;ooooo002Kooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`2booooo`00Voooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo
00Cooooo0ol0002booooo`00Voooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`2booooo`00Voooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_ooool009_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;;ooooo002Iooooo`03oeEEEOmV
IVKo000000gooooo1?l00006ooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool0
0;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo
00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2b
ooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00
/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooo
oooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;o
oooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000
ooooooooool0/_ooool0097ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_ooool00ol0
003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2b
ooooo`00Toooool00ol0003oooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000oooooooo
ool03?ooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002booooo`00
Toooool00ol0003oooooooooo`0=ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`0=ooooo`03oeEEEOo<
c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;;ooooo
002Cooooo`03o`000?oooooooooo00gooooo00?oZJVYogMgMoooool00oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00[ooooo00Go410@
oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_oo
ool0097ooooo00?oEEEEofIVI_l000003?ooool5o`0000Cooooo1?l00006ooooo`;o0000/oooool0
0;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo
00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002c
ooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00
/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooo
oooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;o
oooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000
ooooooooool0/_ooool00:Sooooo1Ol00006ooooo`03o`000?oooooooooo0;;ooooo002Xooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`2booooo`00ZOooool00onHV9So
8B4Qonk^kP07ooooo`03o`000?oooooooooo0;;ooooo002Zooooo`03oiRHV?lQ8B7ok^k^00Kooooo
0ol0002booooo`00Zoooool00omgMgOoIVIVooooo`2jooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00Z?ooool01Ol0003o^[ZjoooooonHV9So410@0;_ooooo002Xooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`0^oooool00?ooooooJOooool00:kooooo00?o0000okZj^_ooool0]oooool00:kooooo
0_lb<S:hooooo`00Ooooool2o`000006oa0@4?oooooooooooa0@4?l0003o410@6?ooool4o`000005
oa0@4?oooooooooooooooom4A4@00_l000001olb<S;ogMgMooooooooooooQhN7o`000?nj^[X03?oo
ool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07Wooooo0020ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01oooool6o`0000cooooo00?o0000ooooooooool01_ooool01omgMgOo
<S8booooooooooooc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0
0009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`1iooooo`00P?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo01_ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@401iooooo`00P?ooool01_l0003oooooodA4A?m4A4Co
ooooo`0000Wooooo1_l0000<ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool04?oo
ool00ol0003oooooooooo`0;ooooo`Ko00002oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000007Wooooo0020ooooo`06o`00
0?oMgMgo<S8boeEEEOoMgMgo00006oooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`04Oooool00ol0003oooooooooo`0Mooooo`03ogMgMomVIVKooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000NOooool0083ooooo00Ko
0000ohN7QonYZJWo^[ZjoeEEEOl0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool04Oooool00ol@413o0000o`000003o`0001gooooo00Go0000oooooooooooooooooa0@4003oooo
o`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`1gooooo`00P?ooool01_l0
003o<S8boooooooooooo<S8bo`0001_ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo01[ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg07Wooooo001oooooo`03
oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool00omEEEGoIVIVo`000005ooooo`Co
00004_ooool00ol0003oooooooooo`0Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1iooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-44.3769, -0.160437, \
0.309031, 0.0133306}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "The solution appears to be well behaved and stable over the time scale of \
interest. It moves to the right with a speed given by Eq. ",
  ButtonBox["(7.2.16)",
    ButtonData:>{"Chapter7.nb", "(7.2.16)"},
    ButtonStyle->"Hyperlink"],
  " . Other cnoidal waves and solitons can be handled by simply varying the \
parameters.  One can also add small perturbations to these solutions. One \
finds by this sort of empirical approach that steady solutions to the KdV \
equation are stable to small perturbations. This is born out by the \
previously mentioned analytic work on this problem. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 2: Interacting Solitons", "Section",
  CellTags->"c:21"],

Cell["\<\
In this example, for initial conditions we take two soliton \
solutions with different amplitudes:\
\>", "Text"],

Cell[BoxData[{
    \(\(L = \ 60;\)\), "\n", 
    \(\(f0[
          x_]\  = \ \(1/3\)/Cosh[Sqrt[1/36]\ \((x + 30)\)]^2\  + \ \(1/4\)\ /
            Cosh[Sqrt[1/48]\ \((x - 30\ )\)]^2\ ;\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.47"],

Cell["We will again evaluate the solution keeping 15 modes:", "Text"],

Cell[BoxData[{
    \(\(\(M = 15;\)\(\n\)
    \)\), "\n", 
    \(\(\(k[n_]\  := \ n\ Pi/L;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(ics\  = \ 
        Table[\(c[n]\)[0]\  \[Equal] \ 
            NIntegrate[
                Exp[\(-I\)\ k[n]\ x]\ f0[x], {x, \(-L\), L}]/\((2  L)\), {n, 
            0, M}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.48"],

Cell[TextData[{
  "In order to follow the dynamics we must integrate over a longer time, ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 6000\)]],
  ", because our initial conditions are solitons of rather small amplitude. \
This implies their velocities are small. The solution is displayed in Cell ",
  ButtonBox["7.49",
    ButtonData:>"Cell 7.49",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(kdVmod[6000, 100, 0,  .6]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.49"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
147.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03321 0 m
.06244 .0007 L
.07216 .00052 L
.07472 .00046 L
.07607 .00042 L
.0775 .0004 L
.07875 .00038 L
.07942 .00037 L
.08013 .00036 L
.08138 .00035 L
.08255 .00035 L
.08332 .00036 L
.08415 .00036 L
.08494 .00037 L
.08567 .00039 L
.08705 .00042 L
.08852 .00047 L
.08999 .00054 L
.09137 .00061 L
.09396 .00078 L
.09906 .00125 L
.10458 .00191 L
.1146 .0033 L
.12519 .00481 L
.13423 .00634 L
.13936 .00755 L
.14415 .00908 L
.14916 .01121 L
.1546 .0143 L
.15975 .01805 L
.1645 .02231 L
.1735 .0326 L
.18306 .0473 L
.19243 .06682 L
.20253 .09599 L
.21207 .13338 L
.22081 .17616 L
.23074 .23092 L
.24134 .28735 L
.24648 .30998 L
.24901 .31928 L
.25134 .3266 L
.25342 .33202 L
.25571 .33669 L
.25689 .33857 L
.258 .33997 L
.25918 .34108 L
.26044 .34183 L
.26166 .34213 L
.26297 .34198 L
Mistroke
.26421 .34139 L
.26532 .34048 L
.26664 .33895 L
.26807 .33676 L
.27065 .3314 L
.27311 .32471 L
.2757 .3161 L
.28035 .29722 L
.29854 .2003 L
.30877 .14709 L
.31845 .10603 L
.32713 .0779 L
.33657 .05527 L
.34673 .0376 L
.35612 .02561 L
.36627 .01634 L
.37139 .01295 L
.37704 .01011 L
.38198 .00829 L
.38716 .00687 L
.39159 .00595 L
.39643 .00514 L
.40737 .00357 L
.4173 .00218 L
.42216 .00156 L
.42741 .001 L
.42983 .0008 L
.43238 .00063 L
.43456 .00051 L
.43579 .00047 L
.43695 .00043 L
.43825 .0004 L
.43898 .00039 L
.43966 .00038 L
.44091 .00037 L
.44154 .00037 L
.44224 .00037 L
.44343 .00038 L
.44472 .00039 L
.44594 .00041 L
.44706 .00043 L
.45231 .00056 L
.45519 .00064 L
.45661 .00067 L
.45791 .0007 L
.45908 .00072 L
.46037 .00074 L
.46167 .00075 L
.46237 .00075 L
.46304 .00075 L
Mistroke
.46421 .00075 L
.46528 .00075 L
.46652 .00073 L
.4677 .00072 L
.46879 .0007 L
.46996 .00067 L
.47206 .00061 L
.47681 .00043 L
.48206 .00019 L
.48492 7e-05 L
Mfstroke
.48492 7e-05 m
.48693 0 L
s
.50446 0 m
.5078 .00012 L
.51312 .00037 L
.51893 .00063 L
.52139 .00073 L
.52403 .00081 L
.5253 .00084 L
.52651 .00086 L
.52758 .00088 L
.52876 .0009 L
.53002 .00091 L
.5307 .00092 L
.53135 .00092 L
.53249 .00092 L
.53373 .00092 L
.53442 .00092 L
.53517 .00092 L
.53588 .00091 L
.53654 .00091 L
.53911 .00089 L
.54159 .00086 L
.54294 .00085 L
.54421 .00084 L
.54487 .00084 L
.54558 .00084 L
.54636 .00084 L
.54708 .00084 L
.54773 .00084 L
.54843 .00084 L
.54971 .00085 L
.55091 .00087 L
.55223 .00089 L
.55361 .00093 L
.5549 .00097 L
.5572 .00107 L
.55968 .0012 L
.56467 .00159 L
.56941 .00208 L
.57831 .00324 L
.58789 .0047 L
.5981 .00647 L
.60307 .00752 L
.60775 .0087 L
.61649 .0117 L
.62114 .01384 L
.62625 .01673 L
.63656 .02448 L
.64611 .03424 L
.65503 .04601 L
.66547 .06394 L
Mistroke
.67537 .0862 L
.69392 .14329 L
.71213 .20817 L
.71712 .22376 L
.7225 .23794 L
.72498 .24332 L
.72758 .24811 L
.73002 .2517 L
.73224 .25418 L
.73346 .25522 L
.7346 .25598 L
.73582 .25655 L
.73713 .2569 L
.73828 .25697 L
.7395 .25681 L
.74054 .25649 L
.74168 .25592 L
.74302 .25499 L
.74425 .25389 L
.74701 .25056 L
.74957 .24645 L
.75201 .24169 L
.76205 .21466 L
.77301 .17673 L
.78401 .1372 L
.79436 .1039 L
.80443 .07741 L
.8137 .0583 L
.82286 .04355 L
.83252 .03149 L
.84223 .02227 L
.84769 .01819 L
.85287 .015 L
.85777 .01254 L
.86309 .01039 L
.8724 .00769 L
.87768 .00656 L
.88328 .00553 L
.89333 .00391 L
.90272 .00257 L
.90765 .00197 L
.91283 .00146 L
.91739 .00114 L
.91998 .00101 L
.92121 .00096 L
.92238 .00093 L
.92344 .0009 L
.92459 .00087 L
.92564 .00086 L
.92661 .00085 L
Mistroke
.92765 .00084 L
.9288 .00083 L
.93 .00083 L
.93112 .00084 L
.93238 .00084 L
.93371 .00085 L
.93611 .00087 L
.93746 .00089 L
.93891 .0009 L
.93958 .0009 L
.94029 .00091 L
.94155 .00091 L
.94271 .00091 L
.94379 .00091 L
.94498 .00091 L
.94625 .0009 L
.94692 .00089 L
.94764 .00088 L
.94896 .00086 L
.95144 .0008 L
.95367 .00074 L
.95612 .00064 L
.96108 .00041 L
.96537 .00019 L
Mfstroke
.96537 .00019 m
.9695 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00So
oooo2?l00006ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00?ooooo1ol0000;ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`Wo00002Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`07ooooo`[o00001?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo023o
oooo000Tooooo`03o`000?oooooooooo01cooooo1_l0000<ooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool02_ooool5o`0001kooooo00?o0000ooooooooool06?ooool6o`0000oooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0?ooooo`Co00006_ooool00ol0003ooooo
ooooo`0Pooooo`00BOooool00ol0003oooooooooo`13ooooo`?o00008oooool00ol0003ooooooooo
o`0Nooooo`;o0000B_ooool5o`00047ooooo001:ooooo`;o0000@Oooool2o`0002Kooooo00?o0000
ooooooooool08?ooool3o`0004Kooooo00?o0000ooooooooool0A?ooool004cooooo0_l0000noooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`11oooo
o`;o0000Aoooool004kooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Wooooo`;o
00009Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo04Oooooo001?ooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo03gooooo00?o0000ooooooooool0B?ooool0053ooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`19ooooo`00DOooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo04[ooooo001Booooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0Boooool005;o
oooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1<ooooo`00Doooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0:_ooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo04gooooo001Dooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0;?ooool2o`0002cooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`1>ooooo`00E?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo04kooooo001Eoooo
o`03o`000?oooooooooo02cooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool0Coooool005Gooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`1@ooooo`00E_ooool00ol0003oooooooooo`0Zooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo053ooooo001Gooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0DOoo
ool005Oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0`ooooo`;o0000;oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo057ooooo001Hooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool0D_ooool005Sooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`1Booooo`00FOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo05?ooooo
001Iooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Doooool005Wooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1Dooooo`00F_ooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo03;ooooo0_l0000booooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0E?ooool005[ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Eooooo`00
F_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo05Gooooo001Kooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool0EOooool005_ooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`0Hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l0
00000ol@413oooooooooo`03ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`1Fooooo`00Foooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`1Fooooo`00Foooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01Wooooo00Go410@
oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Gooooo0ol0000dooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool0E_ooool005cooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool000003_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`1Gooooo`00G?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01Wooooo00Go0000
ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo05Oooooo001Looooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool06Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool0Eoooool005cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Hooooo`00GOooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01[ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo05Sooooo001Mooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool0F?ooool005gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0eoooo
o`;o0000=oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05Wooooo001Mooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0fooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool0FOooool005kooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`1Iooooo`00G_ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo05[ooooo001Nooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0F_ooool0
05kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
03Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1Jooooo`00G_ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo03Oooooo0_l0000iooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool0F_ooool005oooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0gooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`1Kooooo`00Goooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo03Oooooo00?o
0000ooooooooool0>?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo05_ooooo001O
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Foooool005oooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`1Kooooo`00Goooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo05cooooo001Oooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
>?ooool2o`0003[ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Looooo`00Gooo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0>_oo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05cooooo001Pooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool0G?ooool0063ooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0hooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`1Mooooo`00H?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo03Wo
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05go
oooo001Pooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0>Oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0GOooool0063ooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`0iooooo`;o0000??ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo05kooooo001Pooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool0>Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0G_ooool0067ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0ioooo
o`03o`000?oooooooooo03cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Noooo
o`00HOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03[ooooo00?o0000oooooooo
ool0??ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05oooooo001Qooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool07oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0Goooool0067ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0Oooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A006ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`1Oooooo`00HOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01oo
oooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000oooo
ooooool0?Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo063ooooo001Rooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool07oooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0003gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`1Pooooo`00H_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo023o
oooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000oooo
ooooool0?Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo063ooooo001Rooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool08?ooool01Ol@413ooooooooooooooooo410@
00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0HOooool006;ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Pooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@00Kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo067ooooo001Rooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool08?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oo
oooooooo03kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Rooooo`00Hoooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0?oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo06;ooooo001Sooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0??ooool2o`00043ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`1Rooooo`00Hoooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03co
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06?o
oooo001Sooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0??ooool00ol0003ooooo
ooooo`10ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Hoooool006?ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo043ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1Sooooo`00Hoooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo06Cooooo001Tooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0?Oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0I?ooool006Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0mooooo`;o
0000@oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06Cooooo001Tooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`12ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0IOooool006Cooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo04?ooooo00Go0000oooooooooooooooo
o`00001Xooooo`00I?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03gooooo00?o
0000ooooooooool0A?ooool4o`0006Sooooo001Uooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool0?_ooool00ol0003oooooooooo`2`ooooo`00IOooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo03kooooo00?o0000ooooooooool0/?ooool006Gooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0nooooo`;o0000/Oooool006Gooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo0;3ooooo001Uooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`2`ooooo`00IOooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0/?ooool0
06Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
0;3ooooo001Vooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0?oooool00ol0003o
ooooooooo`2`ooooo`00I_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03oooooo
00?o0000ooooooooool0/?ooool006Kooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0oooooo`;o0000/Oooool006Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`10
ooooo`03o`000?oooooooooo0;3ooooo001Wooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0@?ooool00ol0003oooooooooo`2`ooooo`00Ioooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo02Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01OnH
V9So410@o`000?lb<S;oc<c<00Kooooo00?o0000ooooooooool0/?ooool006Oooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Uooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo0;3ooooo001X
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09Oooool01Ol@413ooooooooooooo
oooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2`ooooo`00J?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ojVYZOl@413ooooo00Gooooo0ol0002`ooooo`00J?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo02Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oa0@4?l0
003o^[Zj00Kooooo00?o0000ooooooooool0/?ooool006Wooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Vooooo`05oa0@4?ooooooooooooooool@41003_ooool00onj^[[o8B4Qoooo
o`05ooooo`03o`000?oooooooooo0;3ooooo001Yooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool09_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oiRHV?oooooo^[Zj
o`000006ooooo`03o`000?oooooooooo0;3ooooo001Yooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool09oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@06ooooo`03o`000?oooooooooo0;3ooooo001Yooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0@_ooool00ol0003oooooooooo`2`ooooo`00JOooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo04;ooooo0_l0002aooooo`00J_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0/?ooool006_ooooo00Co0000oooo
oooooooo0000A_ooool00ol0003oooooooooo`2`ooooo`00Joooool01?l0003oooooooooool00016
ooooo`03o`000?oooooooooo0;3ooooo001/ooooo`;o0000Aoooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003ooooooooo
o`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooa0@
400;ooooo`Go00001_ooool3o`000;3ooooo002Jooooo`05o`000?ooooooooooooooool000002ooo
ool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05o`000?oo
ooooooooooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo0;3o
oooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007ooooo`03
o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^ko
A4A4o`000007ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000
/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002a
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?oo
ool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41004?oo
ool00ol0003oooooooooo`03ooooo`?o0000/?ooool009[ooooo00Go0000ooooooooooooooooo`00
000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00cooooo1?l00006ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aoooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000
/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00;Oooooo00?o0000okZj^_ooool0[_ooool00;Oooooo0_lb<S:_ooooo`00
R?ooool2o`000006oa0@4?oooooooooooa0@4?l0003o410@6?ooool4o`000005oa0@4?oooooooooo
oooooom4A4@00_l000001olb<S;ogMgMooooooooooooQhN7o`000?nj^[X03?ooool01OnHV9So0000
o`000?m4A4Co^[Zj01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP20ooooo`00ROooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l0000<ooooo`03o`000?oooooooooo00Ko
oooo00OoMgMgoc8b<_ooooooooooolc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@
4009ooooo`Ko00002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg083ooooo0029ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool06_ooool01Ol@413ooooooooooooooooo410@083ooooo
0029ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000cooooo00?o0000oooooooo
ool01_ooool00omgMgOo<S8booooo`0@ooooo`03o`000?oooooooooo00_ooooo1_l00009ooooo`05
o`000?ooooooooooooooool00000P?ooool008Wooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000K
ooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Aooooo`03o`000?oo
oooooooo01[ooooo00Go0000ooooooooooooooooo`000020ooooo`00ROooool01_l0003oQhN7ojVY
ZOnj^[[oEEEEo`0001_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03
oa0@4?l0003o000000?o00006Oooool01Ol@413ooooooooooooooooo410@083ooooo0029ooooo`06
o`000?lb<S;ooooooooooolb<S;o00006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool06_ooool01OmgMgOoV9RHoooooonHV9SoMgMg083ooooo0028
ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool00omEEEGoIVIVo`000005
ooooo`Co00004_ooool00ol0003oooooooooo`0Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0P?oo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .00216 m
.03279 .00163 L
.04262 .00108 L
.04758 .00084 L
.0503 .00072 L
.05288 .00063 L
.05528 .00055 L
.05789 .00049 L
.05904 .00047 L
.06026 .00045 L
.0613 .00044 L
.06244 .00043 L
.06368 .00042 L
.06485 .00042 L
.0655 .00042 L
.0662 .00042 L
.06742 .00042 L
.06813 .00042 L
.06889 .00043 L
.07024 .00043 L
.07285 .00046 L
.07532 .00048 L
.07797 .0005 L
.07925 .00052 L
.08047 .00052 L
.08156 .00053 L
.08274 .00053 L
.08339 .00053 L
.08411 .00053 L
.08486 .00053 L
.08557 .00053 L
.08682 .00052 L
.08753 .00052 L
.08818 .00051 L
.08957 .0005 L
.09109 .00047 L
.09415 .00041 L
.09676 .00034 L
.09955 .00025 L
.10458 6e-05 L
s
.10458 6e-05 m
.10639 0 L
s
.13686 0 m
.14035 .00012 L
.14487 .00026 L
.14725 .00032 L
.14851 .00035 L
.14984 .00037 L
.15096 .00039 L
.1522 .0004 L
.15332 .00041 L
.15437 .00042 L
.15562 .00042 L
.15693 .00043 L
.15805 .00042 L
.15927 .00042 L
.15996 .00042 L
.16059 .00041 L
.162 .00041 L
.16454 .00039 L
.16569 .00038 L
.16691 .00038 L
.16794 .00037 L
.16908 .00037 L
.1703 .00038 L
.17162 .00038 L
.17286 .00039 L
.17399 .00041 L
.17512 .00043 L
.17618 .00045 L
.17856 .00053 L
.18066 .00062 L
.18289 .00074 L
.18777 .0011 L
.19225 .00154 L
.20234 .00284 L
.21117 .0042 L
.22061 .00595 L
.22574 .00719 L
.2304 .00861 L
.23508 .01043 L
.23951 .0126 L
.24943 .01945 L
.25503 .02473 L
.2602 .03066 L
.26988 .04493 L
.27894 .06315 L
.28888 .09065 L
.29957 .13143 L
.3193 .23379 L
.32972 .2885 L
.33543 .31288 L
Mistroke
.33824 .32253 L
.34082 .32981 L
.34334 .33534 L
.34462 .33748 L
.34601 .33933 L
.34673 .34008 L
.34741 .34065 L
.3482 .34114 L
.34892 .34144 L
.35021 .34162 L
.35095 .3415 L
.35163 .34126 L
.35279 .34054 L
.35389 .33952 L
.35509 .33802 L
.35638 .33596 L
.35901 .33039 L
.36142 .32375 L
.36587 .30801 L
.37074 .28648 L
.38055 .23464 L
.39149 .17444 L
.40181 .12512 L
.41108 .09052 L
.42113 .06293 L
.431 .04347 L
.44146 .02866 L
.45038 .01958 L
.45545 .01567 L
.46019 .01275 L
.46518 .01035 L
.47061 .00838 L
.47574 .00699 L
.48049 .00597 L
.49904 .00289 L
.50413 .00215 L
.50964 .00145 L
.51217 .00118 L
.51484 .00095 L
.51712 .00078 L
.5184 .00071 L
.51961 .00065 L
.52078 .0006 L
.52205 .00056 L
.5232 .00053 L
.52427 .00052 L
.52542 .0005 L
.52669 .0005 L
.52733 .0005 L
.52801 .00051 L
Mistroke
.52925 .00052 L
.5304 .00054 L
.53166 .00056 L
.53394 .00062 L
.53824 .00074 L
.54079 .00081 L
.54213 .00085 L
.54355 .00088 L
.54479 .0009 L
.54545 .00091 L
.54615 .00092 L
.54739 .00093 L
.54855 .00093 L
.54975 .00093 L
.55106 .00092 L
.5523 .00091 L
.55344 .00089 L
.5556 .00084 L
.5579 .00078 L
.56799 .00036 L
.57075 .00025 L
.57367 .00015 L
.57487 .00012 L
.57615 9e-05 L
.57689 7e-05 L
.57756 6e-05 L
.57887 5e-05 L
.58008 4e-05 L
.58137 4e-05 L
.58247 4e-05 L
.58367 5e-05 L
.58497 7e-05 L
.58636 .0001 L
.58888 .00017 L
.59382 .00036 L
.59833 .00057 L
.61661 .00124 L
.62135 .00134 L
.62582 .00146 L
.62829 .00154 L
.63096 .00165 L
.63562 .00194 L
.63835 .00216 L
.64123 .00244 L
.64638 .00309 L
.65636 .00481 L
.66585 .00693 L
.67603 .00974 L
.68096 .01142 L
.68562 .01331 L
Mistroke
.69437 .01793 L
.69897 .02109 L
.70404 .02527 L
.71431 .03631 L
.72382 .05005 L
.73274 .06651 L
.75295 .11945 L
.77147 .18437 L
.78063 .21584 L
.78567 .23068 L
.79042 .24219 L
.79312 .24743 L
.79605 .25191 L
.79734 .25347 L
.7987 .25483 L
.79987 .25575 L
.80115 .25651 L
.80245 .25699 L
.80364 .25719 L
.8043 .2572 L
.80501 .25713 L
.80631 .25678 L
.80752 .25621 L
.80881 .25533 L
.80991 .25437 L
.81113 .25308 L
.81347 .24996 L
.81603 .24562 L
.8212 .2342 L
.83044 .20685 L
.85129 .13367 L
.87087 .07706 L
.88183 .05451 L
.8918 .03917 L
.90176 .02788 L
.91096 .02025 L
.92105 .01418 L
.93174 .00963 L
.94116 .00678 L
.94644 .00557 L
.95128 .00466 L
.95577 .00398 L
.96067 .00339 L
.96958 .0026 L
.97619 .00216 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool5o`0000Oooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo2ol000000ooooooo0000ooooo`0:ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`So
00001oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo3Ol000000ooooooo
0000ooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00?ooooo1ol0000Rooooo`009?ooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo00Sooooo0ol0000Rooooo`03o`000?oooooooooo02Gooooo
1Ol00003ooooo`03o`000?oooooooooo02cooooo1_l0000[ooooo`03o`000?oooooooooo02;ooooo
1Ol00006ooooo`03o`000?oooooooooo023ooooo001Sooooo`?o0000A?ooool3o`0000Sooooo00?o
0000ooooooooool0<_ooool2o`0004_ooooo0ol0000^ooooo`00I_ooool2o`00043ooooo0_l0000;
ooooo`03o`000?oooooooooo03Cooooo0ol00015ooooo`?o0000<Oooool006Sooooo00?o0000oooo
ooooool0??ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool0@Oooool00ol0003oooooooooo`0booooo`00JOooool00ol0003oooooooooo`0jooooo`03
o`000?oooooooooo00cooooo0_l0000iooooo`03o`000?oooooooooo03oooooo00?o0000oooooooo
ool0<oooool006[ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo03Wooooo0_l0000nooooo`03o`000?oooooooooo03Cooooo001[ooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo03[ooooo00?o0000ooooooooool0=Oooool006cooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0>?ooool0
0ol0003oooooooooo`0fooooo`00K?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
03Oooooo001]ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0nooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0>?ooool006kooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`0iooooo`00K_ooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo01;ooooo0_l00010ooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool0>Oooool006oooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0j
ooooo`00Koooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0@Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo03_ooooo001`ooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`11ooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool0>oooool0077ooooo00?o0000ooooooooool0
:_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`0looooo`00LOooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo03cooooo001booooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool05Oooool2
o`0004Cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0mooooo`00L_ooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0A?ooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo03gooooo001cooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool0?_ooool007?ooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0oooooo`00Loooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool0AOooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03oooooo001d
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`15
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0@?ooool007Cooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0Gooooo`;o0000Aoooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo043ooooo001dooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool0@Oooool007Gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo04Kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`11ooooo`00MOoo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0Aooo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo047ooooo001eooooo`03o`000?oooooo
oooo02;ooooo00Go0000oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo04;ooooo001eooooo`03o`000?oooooooooo02;ooooo00Go0000oiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Sooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`12ooooo`00M_ooool00ol0003oooooooooo`0P
ooooo`03o`000?l@413ooooo00;ooooo00?o410@ooooooooool03?ooool00ol0003oooooooooo`05
ooooo`?o0000B?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo04;ooooo001foooo
o`03o`000?oooooooooo023ooooo0_l00003ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool0@oooool007Kooooo00?o0000ooooooooool08?ooool2o`0000?ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Wooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`13ooooo`00M_ooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooo410@00?ooooo00?o410@ooooooooool03?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo04Wooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`13ooooo`00Mooo
ool00ol0003oooooooooo`0Nooooo`07o`000?ooooooMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo04Cooooo001gooooo`03o`000?oooooooooo01kooooo00Oo0000ooooooo^k^ko
<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`1:oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool0A?ooool007Oooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04[ooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`14ooooo`00Moooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo01_ooooo0_l0001;ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
AOooool007Sooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo04_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`15ooooo`00N?ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0Boooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04Gooooo001hooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool0A_ooool007Sooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`16ooooo`00N?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04Kooooo
001iooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool07?ooool2o`0004gooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`00NOooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo04Oooooo001iooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool0Aoooool007Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo04gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`18ooooo`00
NOooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
COooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04Sooooo001jooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1=ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0B?ooool007[ooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0Mooooo`;o0000C_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo04Sooooo001jooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`1>ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0BOooool007[o
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo04ko
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`19ooooo`00N_ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0C_ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo04Wooooo001kooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool0BOooool007_ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1:
ooooo`00Noooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01kooooo0_l0001@oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0B_ooool007_ooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo04oooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`1:ooooo`00Noooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo04_ooooo001looooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Booo
ool007cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`04ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo053ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`1;ooooo`00O?ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0D?ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo04_ooooo001looooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0
1oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
C?ooool007cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`05ooooo`05o`000?oo
ooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`?o0000DOooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo04cooooo001mooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool0
1Oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
C?ooool007gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`05ooooo`05oa0@4?oo
ooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05;ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`1=ooooo`00OOooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0COooool007gooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`05ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
00Kooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
04gooooo001mooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`1Cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0C_ooool007kooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Qooooo`;o0000E?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo04kooooo001nooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0C_ooool007kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1?
ooooo`00O_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool0E?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04oooooo001nooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1Eooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0Coooool007kooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1@ooooo`00Ooooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo02;ooooo0_l0001Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0D?oo
ool007oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo05Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Aooooo`00Ooooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0Eoooool2o`00
00;ooooo00?o0000ooooooooool0D_ooool007oooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo05Sooooo1?l0001Dooooo`00Ooooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0/?ooool0083ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo0;3ooooo0020
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool08oooool2o`000;7ooooo0020oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`2`oooo
o`00P?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool0/?ooool0083ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo0;3ooooo0020ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`2`ooooo`00POooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0/?ooool0087ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo0;3ooooo0021ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool09?ooool2o`000;7ooooo0021ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`2`ooooo`00POooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0/?ooool008;ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0;3ooooo
0022ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S801_ooool00ol0003o
ooooooooo`2`ooooo`00P_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo
00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0/?ooool008?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`05o`00
0?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`05ooooo`?o0000/?ooool008?ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool0
00003Oooool00ol@413o0000okZj^P06ooooo`03o`000?oooooooooo0;3ooooo0023ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool02oooool01Ol@413ooooooooooooooooo410@00ko
oooo00?o^[Zjob4Q8Oooool01Oooool00ol0003oooooooooo`2`ooooo`00Q?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003oooooooooo`2`ooooo`00Q?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`2`ooooo`00Q?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0/?ooool008Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Xooooo`;o0000/Oooool008Gooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0;3ooooo
0025ooooo`05o`000?ooooooooooooooool00000:oooool00ol0003oooooooooo`2`ooooo`00Q_oo
ool01?l0003oooooooooool0000[ooooo`03o`000?oooooooooo0;3ooooo0027ooooo`;o0000;?oo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000
/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@oooooooo
ool01?ooool00ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool009[ooooo
00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool3o`000;3ooooo002Jooooo`05o`00
0?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo
0;3ooooo002Jooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0;3ooooo002Joooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool009[ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Go
oooo00?o0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`?o0000/?ooool009[ooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0/?ooool009[ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`oooo
o`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:oooooo00?o0000okZj^_ooool0]_oo
ool00:oooooo0_lb<S:gooooo`00P?ooool2o`000006oa0@4?oooooooooooa0@4?l0003o410@6?oo
ool4o`000005oa0@4?oooooooooooooooom4A4@00_l000001olb<S;ogMgMooooooooooooQhN7o`00
0?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Wooooo1?l000002?l@413oooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07Sooooo0021ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`0000cooooo00?o0000oooooooo
ool01_ooool01omgMgOo<S8booooooooooooc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mg
MgOo410@00Wooooo1_l0000<ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0N?ooool0087ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100N?ooool0087ooooo00Ko0000oooooom4
A4CoA4A4ooooool00009ooooo`Ko00003?ooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;o
oooo013ooooo00?o0000ooooooooool02oooool6o`0000cooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00001hooooo`00POoo
ool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001_ooooo00?o0000ooooooooool00oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<017ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000007Sooooo0021
ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo00006oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo017ooooo00?o410@o`000?l000000ol0000Looooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100N?ooool0087o
oooo00Ko0000oc8b<_oooooooooooc8b<_l0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0N?ooool0083ooooo00?o
410@o`000?n7QhL00_ooool00on7QhOo0000oa0@400Hooooo`03oeEEEOmVIVKo000000Gooooo1?l0
000Booooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .02077 m
.02846 .01758 L
.03279 .0151 L
.03793 .01267 L
.04262 .01087 L
.0522 .00798 L
.06244 .00555 L
.07283 .00353 L
.07869 .00263 L
.0841 .00199 L
.08883 .0016 L
.09152 .00144 L
.09404 .00133 L
.0954 .00128 L
.09669 .00125 L
.09912 .00119 L
.10047 .00117 L
.10173 .00116 L
.10458 .00113 L
.10705 .00111 L
.10966 .00108 L
.11102 .00107 L
.11252 .00104 L
.11515 .00099 L
.11763 .00092 L
.1203 .00082 L
.1251 .0006 L
.13477 7e-05 L
s
.13477 7e-05 m
.13628 0 L
s
.16655 0 m
.16738 3e-05 L
.17 .0001 L
.17242 .00016 L
.17362 .00018 L
.17472 .0002 L
.17595 .00022 L
.17661 .00022 L
.1773 .00023 L
.17853 .00023 L
.17965 .00023 L
.18035 .00023 L
.18099 .00023 L
.1817 .00022 L
.18244 .00021 L
.1837 .0002 L
.18507 .00018 L
.18989 7e-05 L
s
.18989 7e-05 m
.19268 0 L
s
.21568 0 m
.22038 .00018 L
.22555 .00039 L
.22816 .00048 L
.23063 .00056 L
.23285 .0006 L
.2341 .00062 L
.23527 .00064 L
.23634 .00065 L
.23736 .00065 L
.23847 .00065 L
.23967 .00064 L
.24086 .00063 L
.24211 .00062 L
.24435 .00058 L
.24911 .00046 L
.25173 .00039 L
.25421 .00033 L
.25561 .00031 L
.25635 .0003 L
.25714 .00029 L
.25779 .00028 L
.25852 .00028 L
.2598 .00028 L
.26109 .00028 L
.26182 .00029 L
.26249 .0003 L
.26378 .00033 L
.265 .00037 L
.26625 .00042 L
.26759 .00048 L
.27004 .00063 L
.2746 .00103 L
.27992 .00166 L
.28482 .00234 L
.30322 .00519 L
.30792 .006 L
.31296 .00706 L
.31772 .00834 L
.32205 .00987 L
.32714 .01222 L
.33267 .01561 L
.34272 .02434 L
.35213 .03594 L
.36251 .05351 L
.37335 .07947 L
.38352 .11382 L
.39337 .15778 L
.40372 .21316 L
.41342 .26667 L
Mistroke
.42223 .30815 L
.42459 .31703 L
.42715 .3253 L
.42936 .33119 L
.43179 .33623 L
.43312 .33832 L
.43437 .33984 L
.43568 .34097 L
.43642 .34139 L
.4371 .34164 L
.4383 .34176 L
.43961 .34142 L
.44084 .34066 L
.44199 .33957 L
.44315 .3381 L
.4444 .33609 L
.44666 .33141 L
.45089 .31922 L
.45583 .30007 L
.46036 .27879 L
.48084 .16794 L
.49083 .12141 L
.49992 .08835 L
.50937 .0628 L
.5183 .04503 L
.52773 .03112 L
.53301 .025 L
.53796 .0202 L
.5474 .01328 L
.5524 .01066 L
.55779 .00851 L
.56342 .00685 L
.56877 .00566 L
.57882 .00401 L
.5884 .00272 L
.59366 .00208 L
.59861 .00154 L
.60324 .00113 L
.60568 .00095 L
.60825 .0008 L
.61043 .00069 L
.61281 .0006 L
.61385 .00057 L
.61498 .00054 L
.61602 .00052 L
.617 .00051 L
.61822 .00049 L
.61886 .00049 L
.61956 .00048 L
.62025 .00048 L
Mistroke
.62098 .00048 L
.62228 .00048 L
.62349 .00048 L
.62461 .00049 L
.62585 .0005 L
.62717 .00051 L
.63286 .00057 L
.63565 .00059 L
.63688 .0006 L
.63823 .00061 L
.6395 .00061 L
.64068 .00061 L
.64194 .00062 L
.64264 .00062 L
.64329 .00062 L
.64398 .00061 L
.64463 .00061 L
.64534 .00061 L
.6461 .00061 L
.64877 .0006 L
.65118 .00058 L
.65343 .00057 L
.65456 .00057 L
.65577 .00057 L
.65647 .00057 L
.65712 .00056 L
.65835 .00057 L
.659 .00057 L
.65968 .00057 L
.66092 .00058 L
.66161 .00058 L
.66225 .00059 L
.66372 .0006 L
.66496 .00062 L
.66609 .00064 L
.66865 .0007 L
.67125 .00078 L
.67408 .00088 L
.67979 .00115 L
.69997 .00242 L
.71008 .00317 L
.71961 .00414 L
.72488 .00491 L
.7306 .00599 L
.73579 .00725 L
.74057 .00869 L
.75028 .01255 L
.75936 .01752 L
.76932 .0249 L
.78001 .03584 L
Mistroke
.79016 .05011 L
.80122 .07121 L
.81166 .09737 L
.82133 .12705 L
.84155 .19827 L
.84637 .21426 L
.85146 .2293 L
.85617 .24091 L
.85846 .24558 L
.86055 .2492 L
.86256 .25208 L
.86473 .25451 L
.86593 .25552 L
.86703 .25626 L
.86809 .25677 L
.86921 .25711 L
.87033 .25725 L
.87154 .25716 L
.87268 .25685 L
.87372 .25638 L
.87494 .2556 L
.87627 .25448 L
.87869 .2517 L
.88126 .24775 L
.8836 .24333 L
.88884 .23081 L
.89826 .20138 L
.91913 .1273 L
.92829 .09931 L
.93833 .07413 L
.94722 .05639 L
.95674 .04132 L
.9668 .02914 L
.97619 .02077 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo000000co
00002_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`02ooooo`Ko000000?oooooo`000?ooool02_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool9o`0000Co
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`ko00001?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Pooooo`009?ooool00ol0003oooooooooo`08ooooo`?o00008oooool00ol0003ooooo
ooooo`0Pooooo`Ko00001oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00oooooo
1Ol0000Iooooo`03o`000?oooooooooo017ooooo1Ol0000Gooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool08?ooool002[ooooo1Ol0001?ooooo`;o0000=Oooool00ol0003ooooooooo
o`0<ooooo`?o0000=oooool3o`0006Oooooo000Xooooo`;o0000E_ooool2o`0003?ooooo00?o0000
ooooooooool02_ooool2o`0003gooooo0ol0001Tooooo`009oooool00ol0003oooooooooo`1Hoooo
o`03o`000?oooooooooo033ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`10oooo
o`03o`000?oooooooooo067ooooo000Tooooo`?o0000G?ooool00ol0003oooooooooo`0_ooooo`;o
00002Oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo03gooooo00?o0000oooooooo
ool08?ooool008Cooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo04?ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Pooooo`00QOoo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0AOoo
ool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo027ooooo0026ooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`17ooooo`03o`000?oooooo
oooo03Sooooo00?o0000ooooooooool08_ooool008Oooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`0Sooooo`00R?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Co
oooo0028ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1;ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool09Oooool008Wooooo00?o
0000ooooooooool0:Oooool2o`0000Cooooo00?o0000ooooooooool0COooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo02Kooooo002:ooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool09_ooool008[ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo053ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Woooo
o`00Roooool00ol0003oooooooooo`0Wooooo`05o`000?ooooooooooooooool00000Doooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo02Oooooo002;ooooo`03o`000?oooooooooo02Oo
oooo00Go0000ooooooooooooooooo`00001Dooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool0:?ooool008cooooo00?o0000ooooooooool09_ooool01Ol0003ooooooooooooooooo0000
05Cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Xooooo`00S?ooool00ol0003o
ooooooooo`0Vooooo`;o000000?oooooo`000?ooool0EOooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo02Wooooo002<ooooo`03o`000?oooooooooo02Kooooo00Co0000oooooooooooo
0000E_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02Wooooo002=ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo02[ooooo002=ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooool00000F?oo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02[ooooo002=ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooool00000F?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo02_ooooo002>ooooo`03o`000?oooooooooo02Cooooo0_l0001Jooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool0:oooool008kooooo00?o0000ooooooooool09?ooool2o`0005[o
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0/ooooo`00Soooool00ol0003ooooo
ooooo`0Sooooo`;o0000F_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02cooooo
002?ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0F_ooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo02gooooo002?ooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool0F_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02gooooo002@oooo
o`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4
o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo02gooooo002@ooooo`03o`000?oooooooooo00Oooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`04ooooo`;o0000GOooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02kooooo002@ooooo`03o`000?oooooooooo
00Oooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Cooooo1?l0001K
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0;_ooool0097ooooo00?o0000oooo
ooooool01_ooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool01?ooool2
o`0005kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0_ooooo`00TOooool00ol0
003oooooooooo`06ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooo000005kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0_
ooooo`00TOooool00ol0003oooooooooo`06ooooo`05oa0@4?ooooooooooooooool@41003_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooo000005kooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0_ooooo`00T_ooool00ol0003oooooooooo`05ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000005oooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0`ooooo`00T_ooool00ol0003oooooooooo`05oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`000004ooooo`04o`000?oooooo
ooooo`0005oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0`ooooo`00T_ooool0
0ol0003oooooooooo`0Mooooo`04o`000?ooooooooooo`0005oooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0`ooooo`00Toooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo00;o0000Goooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo037ooooo002Coooo
o`03o`000?oooooooooo01cooooo00Co0000oooooooooooo0000H?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo037ooooo002Cooooo`03o`000?oooooooooo01_ooooo00Go0000oooo
ooooooooooooo`00001Pooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0<Oooool0
09?ooooo00?o0000ooooooooool06oooool01Ol0003ooooooooooooooooo0000067ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0aooooo`00U?ooool00ol0003oooooooooo`0Joooo
o`05o`000?ooooooooooooooool00000HOooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo03;ooooo002Dooooo`03o`000?oooooooooo01[ooooo00Go0000ooooooooooooooooo`00001Q
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0<_ooool009Cooooo00?o0000oooo
ooooool06_ooool01?l0003oooooooooooooool2o`00067ooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0booooo`00U?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
03?ooooo002Dooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`1Pooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0<oooool009Gooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo067ooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0cooooo`00UOooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0HOooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo03?ooooo002Eooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0=?ooool009Gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`03oooo
o`;o0000Hoooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03Cooooo002Eooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Rooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0=?ooool009Kooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0dooooo`00U_ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo03Gooooo002Fooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1Sooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0=Oooool0
09Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
06?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0eooooo`00U_ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo00Cooooo0_l0001Uooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool0=_ooool009Oooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0fooooo`00Uoooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0I?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03Kooooo002G
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1U
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0=_ooool009Oooooo00So0000oooo
ooooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003ooooo
ooooo`1Uooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0=oooool009Oooooo00So
0000ooooooooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^
o`000?m4A4@01_ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool0=oooool009Oooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`0:
ooooo`03oiRHV?lQ8B7o000000Oooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo03Oooooo002Hooooo`03o`000?oooooo000000?ooooo00?o0000oooo
ooooool02oooool00onHV9So0000onk^kP06ooooo`?o0000I_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo03Sooooo002Hooooo`03o`000?oooooo000000?ooooo00?o0000oooooooo
ool03?ooool00ol0003oIVIVooooo`05ooooo`03o`000?oooooooooo06Kooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0hooooo`00V?ooool00ol0003ooooooa0@4003ooooo`03oa0@
4?oooooooooo00cooooo0_l00006ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0hooooo`00V?ooool01ol0003oooooogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003o^[Zjo`000?nHV9So410@00Kooooo00?o0000ooooooooool0I_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo03Wooooo002Hooooo`07o`000?ooooook^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooooooo
o`1Wooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>Oooool009Sooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06Oooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0iooooo`00VOooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00Kooooo0_l0001Xooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0>_ooool009Wooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo06Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0jooooo`00
VOooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
J?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03[ooooo002Iooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Yooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0>oooool009Wooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0kooooo`00V_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
03cooooo002Jooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01oooool2o`0006_o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0looooo`00V_ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0J_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo03cooooo002Jooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`1[ooooo`;o00000_ooool2o`0003oooooo002J
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1/
ooooo`Co0000@?ooool009_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo0;3ooooo002Kooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`2`ooooo`00Voooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00Sooooo0_l0002aooooo`00Voooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0/?ooool009_ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo0;3ooooo002Kooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2`ooooo`00W?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0/?ooool009cooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0;3ooooo
002Looooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`2`ooooo`00W?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo0_l0002a
ooooo`00W?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0/?ooool009cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@09
ooooool0003ooooooooooonHV9So410@o`000?lb<S;oc<c<00Kooooo00?o0000ooooooooool0/?oo
ool009[ooooo00GoMgMgoiRHV?oooooo0000ogMgM`05ooooo`;o8B4Q00Woooooo`000?oooooooooo
oa0@4?nj^[[oooooogMgMolb<S801_ooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413o
ooooooooool0003o410@00Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo0;3ooooo002Jooooo`03o`000?oooooooooo00;o00002?ooool00ol0003o
ooooooooo`03ooooo`03ojVYZOl@413ooooo00Gooooo0ol0002`ooooo`00V_ooool00ol0003ooooo
ooooo`02o`0000Oooooo00?o0000ooooooooool00oooool00ol@413o0000okZj^P06ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool000001oooool00ol0003ooooo
ooooo`04ooooo`03okZj^_lQ8B7ooooo00Gooooo00?o0000ooooooooool0/?ooool009[ooooo00Go
MgMgoiRHV?ooooooV9RHo`000007ooooo`09o`000?ooooooooooooooool@413oV9RHoooooonj^[[o
000000Kooooo00?o0000ooooooooool0/?ooool009[ooooo00Kok^k^oc8b<_l0003o<S8bonk^k_l0
0006ooooo`09o`000?oooooooooooooooonYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000oooo
ooooool0/?ooool009oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo0;3ooooo002Oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
3Oooool2o`000;7ooooo002Oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`2`ooooo`00X?ooool01Ol0003ooooooooooooooooo0000013ooooo00?o
0000ooooooooool0/?ooool00:7ooooo00Co0000ooooool0003o00004?ooool00ol0003ooooooooo
o`2`ooooo`00XOooool3o`00017ooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0/?ooool009[ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo
0ol0002`ooooo`00V_ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo
00001oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol0003ooooooooooooooooo000000_o
oooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`2`oooo
o`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0
003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`00
0?ooool01_ooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool0
0oooool3o`000;3ooooo002Jooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool009[ooooo
00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co
00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002_
ooooo`03o`000?nj^[[ooooo0;Kooooo002_ooooo`;o<S8b]oooool0083ooooo0_l000001_l@413o
ooooooooool@413o0000oa0@41Sooooo1?l000001Ol@413oooooooooooooooooA4A400;o000000Oo
<S8bomgMgOooooooooooohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Hoooo
o`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP1hooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l0000<
ooooo`03o`000?oooooooooo00Kooooo00OoMgMgoc8b<_ooooooooooolc<c?l0003o410@00cooooo
00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002Oooool01OnHV9So8B4Qonk^k_ooooooA4A4
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0N?oo
ool0087ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Kooooo`03oiRHV?lQ8B7o
k^k^00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100
N?ooool0087ooooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00003?ooool00ol0003o
ooooooooo`06ooooo`03ogMgMolb<S;ooooo013ooooo00?o0000ooooooooool02oooool6o`0000_o
oooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`00001hooooo`00POooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001_ooooo00?o
0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<017ooooo00?o0000ooooooooool0
7Oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000007Sooooo0021ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo00006oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o410@o`000?l000000ol0000M
ooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo
00?o410@ooooooooool0M_ooool0087ooooo00Ko0000oc8b<_oooooooooooc8b<_l0000Kooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Jooooo`05
o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`1hooooo`00P?ooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o
410@01Sooooo00?oEEEEofIVI_l000001Oooool4o`0001;ooooo00?o0000ooooooooool06_ooool0
1OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0N?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(300) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .15956 m
.03279 .12809 L
.04262 .09762 L
.053 .07155 L
.06244 .05319 L
.07298 .03772 L
.08426 .02561 L
.08927 .02141 L
.0947 .01756 L
.0998 .01455 L
.10458 .0122 L
.11402 .00871 L
.11903 .00734 L
.12442 .00614 L
.14545 .00281 L
.15555 .00167 L
.15832 .00142 L
.16127 .00119 L
.16404 .00101 L
.16658 .00088 L
.16919 .00078 L
.17056 .00073 L
.17201 .0007 L
.17327 .00067 L
.17444 .00065 L
.17573 .00064 L
.17646 .00063 L
.17712 .00063 L
.17834 .00063 L
.17947 .00063 L
.18071 .00063 L
.18202 .00063 L
.18316 .00064 L
.18423 .00065 L
.18667 .00066 L
.18894 .00068 L
.19021 .00068 L
.19137 .00069 L
.19202 .00069 L
.19273 .00069 L
.19403 .00069 L
.19531 .00068 L
.1965 .00068 L
.19774 .00067 L
.1989 .00065 L
.20153 .00061 L
.2041 .00056 L
.20685 .00049 L
.21646 .00017 L
.22113 3e-05 L
Mistroke
Mfstroke
.22113 3e-05 m
.22253 0 L
s
.24076 0 m
.24116 1e-05 L
.24653 .00013 L
.24915 .00018 L
.2516 .00022 L
.25294 .00024 L
.25416 .00026 L
.25481 .00026 L
.25552 .00027 L
.25623 .00027 L
.25698 .00028 L
.25825 .00028 L
.2594 .00028 L
.26004 .00027 L
.26073 .00027 L
.26199 .00026 L
.26316 .00024 L
.26441 .00022 L
.26663 .00017 L
s
.26663 .00017 m
.27207 0 L
s
.30544 0 m
.31388 .0004 L
.31857 .00058 L
.31986 .00062 L
.32124 .00065 L
.32253 .00068 L
.32374 .0007 L
.32446 .00071 L
.32512 .00071 L
.32585 .00072 L
.32663 .00072 L
.32731 .00073 L
.32805 .00073 L
.32874 .00073 L
.32938 .00073 L
.33058 .00072 L
.33189 .00071 L
.33327 .00069 L
.33455 .00068 L
.33706 .00064 L
.33973 .0006 L
.34083 .00059 L
.34201 .00058 L
.34331 .00057 L
.34452 .00056 L
.3458 .00056 L
.34644 .00057 L
.34714 .00057 L
.34838 .00058 L
.34954 .0006 L
.35092 .00063 L
.35217 .00067 L
.35499 .00078 L
.35743 .00091 L
.36008 .00109 L
.36489 .00151 L
.38345 .00376 L
.39293 .00516 L
.39831 .00619 L
.40334 .00743 L
.40865 .0092 L
.41349 .01134 L
.41908 .01456 L
.42439 .01847 L
.43401 .02792 L
.44425 .04192 L
.45391 .06017 L
.46266 .08273 L
.47272 .11812 L
.48196 .16036 L
Mistroke
.49274 .21852 L
.50279 .27338 L
.50748 .29601 L
.51191 .31418 L
.51436 .32252 L
.51702 .33001 L
.51944 .33529 L
.52061 .33728 L
.52167 .33879 L
.52286 .34009 L
.52414 .34105 L
.52532 .34154 L
.52645 .34163 L
.52775 .34128 L
.52896 .34053 L
.52966 .33992 L
.53029 .33924 L
.53171 .33732 L
.53434 .33232 L
.53719 .32492 L
.54235 .30674 L
.56189 .20587 L
.57224 .15148 L
.58335 .10421 L
.59402 .0712 L
.60376 .04979 L
.61355 .03412 L
.62282 .0232 L
.63247 .01513 L
.63734 .01218 L
.64272 .00969 L
.64729 .0081 L
.65222 .0068 L
.66114 .00512 L
.68117 .00217 L
.68604 .00156 L
.69124 .00102 L
.69423 .0008 L
.69695 .00065 L
.69826 .00059 L
.69895 .00057 L
.69968 .00055 L
.70032 .00054 L
.70103 .00052 L
.70227 .00051 L
.70356 .00051 L
.70476 .00051 L
.70607 .00053 L
.70681 .00054 L
.70747 .00055 L
Mistroke
.71002 .00062 L
.71242 .00071 L
.71694 .00089 L
.7217 .00108 L
.7242 .00115 L
.72552 .00118 L
.72694 .00121 L
.72824 .00123 L
.72942 .00124 L
.73062 .00125 L
.73174 .00125 L
.73305 .00124 L
.73372 .00123 L
.73445 .00123 L
.73573 .00121 L
.73694 .00119 L
.74259 .00107 L
.74487 .00102 L
.7473 .00097 L
.74802 .00096 L
.7487 .00096 L
.74997 .00095 L
.75116 .00094 L
.75244 .00095 L
.75369 .00096 L
.7544 .00097 L
.75507 .00098 L
.7564 .00102 L
.75784 .00107 L
.76044 .0012 L
.76281 .00136 L
.76735 .00178 L
.77231 .00239 L
.78132 .00381 L
.7915 .00567 L
.80106 .00769 L
.81104 .01052 L
.81634 .01258 L
.82206 .01541 L
.83161 .0218 L
.84206 .0316 L
.85298 .04545 L
.86315 .06258 L
.87365 .08586 L
.88358 .11395 L
.90215 .17886 L
.91185 .21261 L
.91716 .22855 L
.92213 .24084 L
.92636 .2488 L
Mistroke
.92874 .25214 L
.93091 .25444 L
.93214 .25541 L
.93328 .2561 L
.93453 .25661 L
.93523 .25678 L
.93587 .25687 L
.93703 .25686 L
.93829 .2566 L
.93948 .25611 L
.94058 .25547 L
.94171 .25459 L
.94279 .25358 L
.94481 .25119 L
.94936 .24363 L
.95328 .23488 L
.95756 .22336 L
.97619 .15956 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01oooool9o`0000Kooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`04ooooo`So00002Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool01?l0003oooooooooooooool5o`0000?ooooo00?o0000oooo
ooooool01Oooool5o`0000Kooooo2Ol00008ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool08?ooool002Cooooo00?o0000ooooooooool06_ooool5o`0000oooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`0<ooooo`Go00007?ooool00ol0003oooooooooo`0[ooooo`Ko
00009?ooool3o`0000Gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Pooooo`00
?oooool2o`0005Sooooo0_l0000Jooooo`03o`000?oooooooooo02Sooooo0ol0000]ooooo`Go0000
Doooool003cooooo0ol0001Looooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool09_oo
ool2o`0003Gooooo0_l0001Aooooo`00>_ooool2o`00063ooooo0_l0000Gooooo`03o`000?oooooo
oooo02Cooooo0_l0000iooooo`;o0000Coooool003Wooooo00?o0000ooooooooool0H_ooool00ol0
003oooooooooo`0Dooooo`;o00009?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
04cooooo000hooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0Boooool003Oooooo
00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`1:ooooo`00=_ooool00ol0003ooooooooo
o`1Xooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`10ooooo`03o`000?oooooooooo04Wooooo000eooooo`03o`000?oooooooooo06Wooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo04;ooooo00?o0000
ooooooooool0B?ooool003Cooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`18oooo
o`00<oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo04Oooooo000cooooo`03o`00
0?oooooooooo06kooooo00?o0000ooooooooool03_ooool2o`0001oooooo00?o0000ooooooooool0
A_ooool00ol0003oooooooooo`16ooooo`00<_ooool00ol0003oooooooooo`1_ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`18ooooo`03o`000?oo
oooooooo04Gooooo000aooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0AOooool0
033ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`14ooooo`00<?ooool00ol0003o
ooooooooo`1cooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`1<ooooo`03o`000?oooooooooo04?ooooo000_ooooo`03o`000?oooooooooo07Gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04cooooo
00?o0000ooooooooool0@oooool002oooooo00?o0000ooooooooool0MOooool00ol0003ooooooooo
o`0;ooooo`;o00006oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo04;ooooo000^
ooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0@_ooool002kooooo00?o0000oooo
ooooool0Moooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool0Coooool00ol0003oooooooooo`11ooooo`00;Oooool00ol0003oooooooooo`1iooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1@ooooo`03
o`000?oooooooooo047ooooo000]ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0
@?ooool002cooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`10ooooo`00;?ooool0
0ol0003oooooooooo`1kooooo`03o`000?oooooooooo00Sooooo0_l0000Iooooo`03o`000?oooooo
oooo05;ooooo00?o0000ooooooooool0@?ooool002cooooo00?o0000ooooooooool0Noooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0Doooool00ol0
003oooooooooo`0oooooo`00:oooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo03oo
oooo000[ooooo`03o`000?oooooooooo07gooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0?_ooool002_ooooo00?o
0000ooooooooool0K?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo05Gooooo
00?o0000ooooooooool0?_ooool002[ooooo00?o0000ooooooooool0KOooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B45ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo03kooooo000Zooooo`03o`000?oo
oooooooo06gooooo00Go410@oooooooooooooooooa0@400=ooooo`;o00001oooool3o`0001Kooooo
00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0mooooo`00:Oooool00ol0003ooooooooo
o`1^ooooo`05o`000?ooooooooooooooool000003Oooool2o`0000Oooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo03gooooo000Yooooo`03o`000?oo
oooooooo06kooooo00Go0000ooooooooooooooooo`00000=ooooo`;o00001oooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0?Oooool002Wooooo00?o
0000ooooooooool0K_ooool01Ol@413ooooooooooooooooo410@00gooooo0_l00007ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0looooo`00:?oo
ool00ol0003oooooooooo`1_ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0FOooool00ol0003ooooo
ooooo`0looooo`00:?ooool00ol0003oooooooooo`1_ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
FOooool00ol0003oooooooooo`0looooo`00:?ooool00ol0003oooooooooo`22ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Iooooo`03o`000?oo
oooooooo03cooooo000Wooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool01Oooool2
o`0001Kooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0kooooo`009oooool00ol0
003oooooooooo`23ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`1Jooooo`03o`000?oooooooooo03_ooooo000Wooooo`03o`000?oooooooooo08Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05_o
oooo00?o0000ooooooooool0>oooool002Oooooo00?o0000ooooooooool0Q?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0G?ooool00ol0003ooooo
ooooo`0jooooo`009_ooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo03[ooooo000V
ooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0>_ooool002Kooooo00?o0000oooo
ooooool0QOooool00ol0003oooooooooo`04ooooo`;o00005Oooool00ol0003oooooooooo`1Moooo
o`03o`000?oooooooooo03Wooooo000Uooooo`03o`000?oooooooooo08Kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo05kooooo00?o0000oooooooo
ool0>Oooool002Gooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0iooooo`009Ooo
ool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo03Sooooo000Tooooo`03o`000?oooooo
oooo08Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo05oooooo00?o0000ooooooooool0>?ooool002Cooooo00?o0000ooooooooool0R?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Goooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo023ooooo002_ooooo`03o`000?oooooooooo00?o
oooo0_l0000Cooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0Pooooo`00[oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo023ooooo
002`ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`1Qooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool08Oooool00;3ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo06;ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Qooooo`00/?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo027ooooo002`ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool08Oooool00;7ooooo00Co0000oooooooooooooooo0_l0000Booooo`03o`000?oooooooooo06?o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Rooooo`00/Oooool01Ol0003ooooo
oooooooooooo000001?ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo02;ooooo002aooooo`05o`000?ooooooooooooooool000004oooool00ol0003o
ooooooooo`1Tooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool08_ooool00;7ooooo
00Go0000ooooooooooooooooo`00000Cooooo`03o`000?oooooooooo06Cooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Sooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go00000_ooool01Ol0003ooooooooooooooooo000001?ooooo00?o0000oooo
ooooool0IOooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02?ooooo002Jooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003
ooooo`04o`000?ooooooooooo`0001;ooooo00?o0000ooooooooool0I_ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo02?ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00onHV9So8B4Qonk^kP04ooooo`04o`000?ooooooooooo`0001;ooooo00?o0000ooooooooool0
I_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02?ooooo002Jooooo`05o`000?oo
ooooooooooooool000003Oooool00onHV9So8B4Qonk^kP03ooooo`03o`000?oooooooooo00?o0000
4?ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
9?ooool009[ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00;ooooo
00Co0000oooooooooooo00004_ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool09?ooool009[ooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooool000004_ooool00ol0003oooooooooo`1Wooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool09?ooool009[ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooo`00000Aoooo
o`03o`000?oooooooooo06Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Toooo
o`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004
ooooo`03o`000?oooooo0000017ooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo02Gooooo002cooooo`03o`000?oooooo0000017ooooo00?o0000oooo
ooooool0JOooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Gooooo002cooooo`04
o`000?oooooo0000o`00013ooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo02Gooooo002dooooo`;o00004Oooool00ol0003oooooooooo`1Yooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool09_ooool00;Cooooo0_l0000@ooooo`03o`00
0?oooooooooo06[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Wooooo`00]?oo
ool2o`00013ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo02Oooooo002dooooo`;o00004?ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0:?ooool00;Cooooo0_l0000@ooooo`03o`000?oooooooooo
06cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Xooooo`00]Oooool2o`0000oo
oooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02So
oooo002eooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0K_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo02Wooooo002eooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool0Koooool2o`0000;ooooo00?o0000ooooooooool0:_ooool00;Gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`1`ooooo`Co0000;?ooool00;Gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`2Pooooo`00]Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo0:3ooooo002eooooo`;o00003Oooool00ol0003oooooooooo`2Qooooo`00]Ooo
ool2o`0000gooooo00?o0000ooooooooool0XOooool00;Gooooo0_l0000=ooooo`03o`000?oooooo
oooo0:7ooooo002eooooo`;o00003Oooool00ol0003oooooooooo`2Qooooo`00]Oooool2o`0000go
oooo00?o0000ooooooooool0XOooool00;Gooooo0_l0000<ooooo`03o`000?oooooooooo0:;ooooo
002eooooo`03o`000?oooooo000000_ooooo00?o0000ooooooooool0X_ooool00;Gooooo0ol0000;
ooooo`03o`000?oooooooooo0:;ooooo002eooooo`03o`000?oooooo000000_ooooo00?o0000oooo
ooooool0X_ooool00;Gooooo00?o0000ooooool000002oooool00ol0003oooooooooo`2Rooooo`00
V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05oiRHV?l@413o0000oc8b
<_o<c<`01_ooool00ol0003oooooo`00000:ooooo`03o`000?oooooooooo0:?ooooo002Jooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go410@okZj^_ooooooMgMgoc8b<P06
ooooo`03o`000?oooooo000000[ooooo00?o0000ooooooooool0Xoooool009[ooooo00Go410@oooo
oooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool000002_ooool0
0ol0003oooooooooo`2Sooooo`00V_ooool01Ol0003ooooooooooooooooo000000kooooo00?oZJVY
oa0@4?ooool01Oooool4o`0000Wooooo00?o0000ooooooooool0Xoooool009[ooooo00Go0000oooo
ooooooooooooo`00000=ooooo`03oa0@4?l0003o^[Zj00Kooooo00Co0000oooooooooooo00002?oo
ool00ol0003oooooooooo`2Tooooo`00V_ooool01Ol@413ooooooooooooooooo410@00kooooo00?o
^[Zjob4Q8Oooool01Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo0:Cooooo
002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413oV9RHoooooonj^[[o000000Ko
oooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`2Tooooo`00V_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`2Uooooo`00]Oooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool0YOooool00;Gooooo0_l00003ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0YOooool00;Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo0:Kooooo002eooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`00002Xooooo`00]Oooool00ol0003oooooooooo`03ooooo`;o
000000?oooooo`000?ooool0Z?ooool00;Gooooo00?o0000ooooooooool01?ooool2o`000:[ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo
0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@
00_ooooo1Ol00006ooooo`?o0000/?ooool009[ooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0/?oo
ool009[ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o
0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000000Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002a
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`oooo
o`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooa0@400@oooo
o`03o`000?oooooooooo00?ooooo0ol0002`ooooo`00V_ooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol0003o
oooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002a
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00[oooool00ol0003o^[Zjooooo`2fooooo`00[oooool2oc8b<[Oooooo0020
ooooo`;o000000Ko410@oooooooooooo410@o`000?l@410Hooooo`Co000000Go410@oooooooooooo
ooooodA4A002o`000007oc8b<_oMgMgooooooooooon7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o
0000odA4A?nj^[X06?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0N?ooool0087ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`07ooooo`Ko00003?ooool00ol0003oooooooooo`06ooooo`07
ogMgMolb<S;oooooooooooo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Ooo
ool6o`0000Wooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg07Sooooo0021ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool07_ooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooo
oooooooooooooa0@4003ooooo`03oa0@4?oooooooooo07Kooooo0021ooooo`06o`000?ooooooA4A4
odA4A?oooooo00002Oooool6o`0000cooooo00?o0000ooooooooool01_ooool00omgMgOo<S8boooo
o`0@ooooo`03o`000?oooooooooo00_ooooo1_l0000<ooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000N?ooool0087ooooo
00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c00Aooooo`03o`000?oooooooooo01cooooo00?o410@o`000?nj^[X00oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00001hooooo`00POoo
ool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001_ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Aooooo`03oa0@4?l0003o000000?o00007?ooool00onj^[[o8B4Qooooo`02ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@07Sooooo0021oooo
o`06o`000?lb<S;ooooooooooolb<S;o00006oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool06_ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0N?ooool0083o
oooo00?o410@o`000?n7QhL00_ooool00on7QhOo0000oa0@400Hooooo`03oeEEEOmVIVKo000000Go
oooo1?l0000Booooo`03o`000?oooooooooo01[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07Sooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(400) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .20645 m
.02846 .22137 L
.03279 .2336 L
.03754 .24456 L
.04018 .24935 L
.04262 .25284 L
.04384 .25424 L
.04518 .2555 L
.04652 .25647 L
.04726 .25688 L
.04795 .25717 L
.04922 .25751 L
.05038 .25757 L
.05103 .25751 L
.05172 .25737 L
.053 .2569 L
.05424 .25617 L
.05537 .25529 L
.0579 .25258 L
.06024 .24918 L
.06244 .24523 L
.06757 .23355 L
.07299 .21804 L
.08269 .18513 L
.10458 .10982 L
.11406 .08364 L
.12422 .06116 L
.13381 .0448 L
.14255 .03339 L
.15246 .02376 L
.16164 .01729 L
.1717 .01212 L
.1824 .00814 L
.19177 .00557 L
.19704 .00445 L
.20187 .00363 L
.20612 .00306 L
.21077 .00257 L
.21563 .00221 L
.22015 .00196 L
.23888 .00128 L
.24875 .00087 L
.25414 .00065 L
.25919 .00046 L
.26196 .00039 L
.26448 .00033 L
.26582 .00031 L
.26729 .00029 L
.26809 .00028 L
.26883 .00027 L
Mistroke
.26954 .00026 L
.2703 .00026 L
.271 .00026 L
.27164 .00025 L
.2729 .00025 L
.27405 .00025 L
.27526 .00026 L
.27656 .00026 L
.27778 .00027 L
.28054 .00029 L
.28294 .00031 L
.28554 .00033 L
.28673 .00034 L
.288 .00034 L
.28908 .00035 L
.29027 .00035 L
.29098 .00035 L
.29163 .00035 L
.29234 .00035 L
.29309 .00035 L
.29435 .00034 L
.29506 .00033 L
.29572 .00033 L
.29813 .0003 L
.30069 .00026 L
.31096 3e-05 L
Mfstroke
.31096 3e-05 m
.31215 0 L
s
.33899 0 m
.34224 7e-05 L
.34467 .00011 L
.34697 .00015 L
.34824 .00017 L
.34962 .00019 L
.35087 .0002 L
.35203 .00021 L
.35312 .00021 L
.35413 .00021 L
.35525 .00021 L
.35645 .0002 L
.35771 .00019 L
.3589 .00018 L
.36114 .00014 L
s
.36114 .00014 m
.36714 0 L
s
.39761 0 m
.40165 .00014 L
.40633 .0003 L
.40888 .00038 L
.41125 .00044 L
.41328 .00047 L
.41442 .00049 L
.41545 .0005 L
.41659 .00051 L
.41782 .00052 L
.41898 .00052 L
.42005 .00052 L
.4213 .00052 L
.42249 .00051 L
.42356 .00051 L
.42472 .0005 L
.42716 .00048 L
.42849 .00047 L
.42975 .00046 L
.43094 .00046 L
.43222 .00045 L
.43339 .00045 L
.43446 .00046 L
.43547 .00046 L
.43658 .00048 L
.43774 .0005 L
.43882 .00052 L
.44011 .00055 L
.44151 .0006 L
.44404 .00071 L
.44651 .00086 L
.4488 .00103 L
.45398 .00152 L
.45947 .00219 L
.46887 .00355 L
.47899 .00516 L
.48389 .00606 L
.48855 .00706 L
.49305 .00826 L
.49729 .00969 L
.50231 .01188 L
.50687 .01443 L
.51219 .01819 L
.51709 .0225 L
.52592 .03254 L
.53547 .0473 L
.5452 .0679 L
.55429 .09413 L
.56426 .13273 L
.57495 .18546 L
Mistroke
.58455 .23858 L
.59475 .29173 L
.60007 .31409 L
.60289 .32369 L
.60594 .33195 L
.6073 .33488 L
.60872 .33743 L
.60994 .33917 L
.61064 .33998 L
.61128 .3406 L
.61254 .34148 L
.61323 .34178 L
.61388 .34193 L
.61504 .34191 L
.6163 .34145 L
.61749 .3406 L
.61877 .33923 L
.61998 .33752 L
.62109 .33561 L
.62379 .32957 L
.62636 .32213 L
.63146 .30302 L
.63702 .27692 L
.65613 .17251 L
.66628 .12427 L
.67583 .08904 L
.68684 .05983 L
.69681 .04118 L
.7066 .02785 L
.71194 .02221 L
.71692 .01786 L
.72574 .01213 L
.73041 .00997 L
.7354 .00821 L
.7407 .0068 L
.7456 .00579 L
.75668 .00398 L
.76706 .00255 L
.77215 .00196 L
.77437 .00174 L
.77681 .00153 L
.77893 .00138 L
.78119 .00125 L
.78245 .0012 L
.78358 .00116 L
.78473 .00112 L
.78581 .0011 L
.78698 .00109 L
.78823 .00108 L
.78929 .00108 L
Mistroke
.79046 .00109 L
.79172 .0011 L
.79242 .00111 L
.79306 .00113 L
.7955 .00119 L
.8062 .0016 L
.81611 .00189 L
.82516 .00203 L
.82764 .00207 L
.83032 .00214 L
.83284 .00222 L
.83516 .00233 L
.8375 .00246 L
.84006 .00265 L
.84522 .00318 L
.85076 .00397 L
.85591 .00492 L
.86641 .00739 L
.87634 .0104 L
.88524 .01394 L
.89024 .01647 L
.89491 .01933 L
.90436 .0269 L
.91476 .03871 L
.92489 .05439 L
.93579 .07663 L
.9565 .13654 L
.97619 .20645 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;o
oooo3_l00005ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool7o`0000Oo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00Co0000oooooooooooooooo8Ol0000;ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Pooooo`009?ooool00ol0003oooooooooo`0^ooooo`Go
0000:oooool00ol0003oooooooooo`0Vooooo`Go00000_ooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo01Gooooo1?l0000Dooooo`03o`000?oooooooooo00Wooooo1_l0000Nooooo`03
o`000?oooooooooo023ooooo001Cooooo`?o0000GOooool3o`0004Cooooo0ol0000Zooooo`?o0000
?_ooool0053ooooo0ol0001Rooooo`;o0000@_ooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo03_ooooo001=ooooo`?o0000IOooool01?l0003oooooo`000?l0000oooooo`03o`000?oo
oooooooo033ooooo0_l0000kooooo`00C?ooool00ol0003oooooooooo`1Vooooo`;o00000_ooool0
0ol0003oooooooooo`0jooooo`;o0000=Oooool2o`0003Wooooo001;ooooo`03o`000?oooooooooo
06Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool0=_ooool004[ooooo00?o0000ooooooooool0J?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`0eooooo`00BOooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo03Gooooo
0018ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0=?ooool004Sooooo00?o0000
ooooooooool0J_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03?ooooo00?o0000
ooooooooool0??ooool00ol0003oooooooooo`0cooooo`00Aoooool00ol0003oooooooooo`1[oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo03;ooooo0017ooooo`03o`000?oooooooooo06_ooooo0_l00008ooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0booooo`00
A_ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo037ooooo0016ooooo`03o`000?oo
oooooooo06cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo04;ooooo00?o0000ooooooooool0<?ooool004Gooooo00?o0000ooooooooool0KOooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0@oooool0
0ol0003oooooooooo`0`ooooo`00A?ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo
02oooooo0014ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0;oooool004?ooooo
00?o0000ooooooooool0Koooool2o`0000_ooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`16ooooo`03o`000?oooooooooo02kooooo0013ooooo`03o`000?oooooooooo06oooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo04Oooooo00?o
0000ooooooooool0;_ooool004;ooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0]
ooooo`00@_ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo02gooooo0011ooooo`03
o`000?oooooooooo077ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo04[ooooo00?o0000ooooooooool0;?ooool0047ooooo00?o0000ooooooooool0
LOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
B_ooool00ol0003oooooooooo`0/ooooo`00@Oooool00ol0003oooooooooo`1aooooo`;o00003Ooo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0;?oo
ool0043ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0[ooooo`00@?ooool00ol0
003oooooooooo`1booooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`1=ooooo`03o`000?oooooooooo02_ooooo000oooooo`03o`000?oooooooooo07?o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo04go
oooo00?o0000ooooooooool0:oooool003oooooo00?o0000ooooooooool0F?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000?o410@ooooooooool00oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0C_ooool00ol0003o
ooooooooo`0Zooooo`00?_ooool00ol0003oooooooooo`1Iooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Zooooo`00
?_ooool00ol0003oooooooooo`1Iooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003o
ooooooooo`05ooooo`?o00003Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo04oo
oooo00?o0000ooooooooool0:_ooool003kooooo00?o0000ooooooooool0FOooool01Ol0003ooooo
oooooooooooo000000kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Yooooo`00
?Oooool00ol0003oooooooooo`1Jooooo`05o`000?ooooooooooooooool000003_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`1Aooooo`03o`000?oooooooooo02Wooooo000mooooo`03o`000?oooooooooo05[ooooo
00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo057ooooo00?o0000oooooooo
ool0:Oooool003gooooo00?o0000ooooooooool0F_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0Xooooo`00??ooool00ol0003ooooo
ooooo`1Kooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`000007ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Booooo`03
o`000?oooooooooo02Sooooo000looooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0
:?ooool003cooooo00?o0000ooooooooool0M_ooool2o`00013ooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo02Oooooo000kooooo`03o`000?oooooo
oooo07Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo05Cooooo00?o0000ooooooooool09oooool003_ooooo00?o0000ooooooooool0Moooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0E?ooool00ol0
003oooooooooo`0Wooooo`00>oooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo02Ko
oooo000jooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool09_ooool003[ooooo00?o
0000ooooooooool0N?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool0E_ooool00ol0003oooooooooo`0Vooooo`00>_ooool00ol0003oooooooooo`1h
ooooo`;o00004_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05Kooooo00?o0000
ooooooooool09_ooool003Wooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0Uoooo
o`00>Oooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo02Gooooo000iooooo`03o`00
0?oooooooooo07Wooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo05Sooooo00?o0000ooooooooool09Oooool003Wooooo00?o0000ooooooooool0NOoo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0FOoo
ool00ol0003oooooooooo`0Tooooo`00>?ooool00ol0003oooooooooo`1jooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooo
oooo02Cooooo000hooooo`03o`000?oooooooooo07[ooooo0_l0000Cooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Tooooo`00>?ooool00ol0003o
ooooooooo`1jooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`1Jooooo`03o`000?oooooooooo02Cooooo000gooooo`03o`000?oooooooooo07_ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo05_ooooo
00?o0000ooooooooool08oooool003Oooooo00?o0000ooooooooool0Noooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Foooool00ol0003ooooooooo
o`0Sooooo`00=oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo02?ooooo000foooo
o`03o`000?oooooooooo07cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo05cooooo00?o0000ooooooooool08_ooool003Kooooo00?o0000oooooooo
ool0O?ooool2o`0001Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Looooo`03
o`000?oooooooooo02;ooooo000fooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0
8_ooool003Kooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`0Rooooo`00=Oooool0
0ol0003oooooooooo`1mooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`1Nooooo`03o`000?oooooooooo027ooooo000eooooo`03o`000?oooooooooo
06;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo05kooooo00?o0000
ooooooooool08Oooool003Gooooo00?o0000ooooooooool0H_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0G_ooool00ol0003ooooooooo
o`0Qooooo`00=?ooool00ol0003oooooooooo`1Sooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo023ooooo000Tooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0Hoooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01_ooool3o`0001Gooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`1Pooooo`03o`000?oooooooooo023ooooo000Tooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0Hoooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Ooo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Pooo
ool002Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Tooooo`05oa0@4?oooooo
ooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`23ooooo`009Oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo06Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj
^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0Poooool002Kooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`1Tooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Ko
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Co
oooo000Vooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Ooooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Q?ooool002Kooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`20ooooo`;o00005oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo08Cooooo000Wooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0P?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0Q?ooool002Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`20oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`24oooo
o`009oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo083ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo08Gooooo000Xooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0QOooool002Wooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`25ooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo08;ooooo0_l0000Hooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0QOooool0
02Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`25ooooo`00:_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo08Kooooo000[ooooo`Co0000Q_ooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Q_ooool00;Gooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo08Kooooo002e
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`26
ooooo`00]Oooool2o`0001Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`26oooo
o`00]Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0Qoooool00;Gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo08Oooooo002eooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`27ooooo`00]Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0Qoooool00;Gooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo08Oooooo002eooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`27ooooo`00]Oooool2o`0001_ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`27ooooo`00]Oooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0R?ooool00;Gooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo08Sooooo002Joooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<
c006ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`28ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oa0@4?nj
^[[oooooogMgMolb<S801_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0R?ooool009[ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo08Sooooo002Jooooo`05o`000?ooooooooooooooool000003_ooool00onYZJWo410@
ooooo`05ooooo`?o00006oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo08Wooooo
002Jooooo`05o`000?ooooooooooooooool000003Oooool00ol@413o0000okZj^P06ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`29ooooo`00V_oo
ool01Ol@413ooooooooooooooooo410@00kooooo00?o^[Zjob4Q8Oooool01Oooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ROooool009[ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0R_ooool009[ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0R_ooool00;Go
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08[o
oooo002eooooo`;o00007_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo08_ooooo
002eooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`2;ooooo`00]Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0Roooool00;Gooooo00?o0000ooooooooool07_ooool01?l0003oooooooooool0002>
ooooo`00]Oooool00ol0003oooooooooo`0Oooooo`?o0000S_ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0/?ooool009[ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol0
002`ooooo`00V_ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
1oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol0003ooooooooooooooooo000000_ooooo
00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooo
oooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`2`ooooo`00
V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0003o
ooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?oo
ool01_ooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00ooo
ool3o`000;3ooooo002Jooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05o`000?ooooooooooooooool000003?oo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool009[ooooo00Go
410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co0000
1_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002_oooo
o`03o`000?nj^[[ooooo0;Kooooo002_ooooo`;o<S8b]oooool0083ooooo0_l000001_l@413ooooo
ooooool@413o0000oa0@41Sooooo1?l000001Ol@413oooooooooooooooooA4A400;o000000Oo<S8b
omgMgOooooooooooohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Jooooo`;o
000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^07Sooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01ooo
ool6o`0000cooooo00?o0000ooooooooool01_ooool01omgMgOo<S8booooooooooooc<c<o`000?l@
41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0N?oo
ool0087ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Jooooo`Go00000oooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@401hooooo`00POoo
ool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000<ooooo`03o`000?oooooooooo00Ko
oooo00?oMgMgoc8b<_ooool04?ooool00ol0003oooooooooo`0;ooooo`Ko00002Oooool01?m4A4Co
gMgMooooool00004ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000007Sooooo0021ooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo00006oooool00ol0003ooooo
ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`04Oooool00ol0003oooooooooo`0Jooooo`04
omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool00000N?ooool0087ooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Kooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol@413o0000o`000003o`0001[ooooo
00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooooooooa0@401hooooo`00POooool01_l0003o<S8boooooooooooo<S8bo`0001_ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01_ooooo00?ok^k^
odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`1hooooo`00P?ooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo00?o
EEEEofIVI_l000001Oooool4o`0001;ooooo00?o0000ooooooooool07?ooool00omgMgOo0000oooo
o`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07So
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(500) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .03319 m
.03279 .04473 L
.04262 .06147 L
.05288 .08451 L
.06244 .1115 L
.08451 .18789 L
.09413 .21986 L
.0992 .23395 L
.10198 .2405 L
.10458 .24576 L
.10717 .25008 L
.10954 .25318 L
.11089 .25455 L
.11217 .25559 L
.11352 .25641 L
.11429 .25673 L
.115 .25695 L
.11626 .25714 L
.11744 .25707 L
.11851 .25681 L
.11966 .25632 L
.12092 .25554 L
.12225 .25444 L
.12462 .25175 L
.12688 .2484 L
.1293 .24398 L
.13366 .23401 L
.14357 .2039 L
.16338 .13296 L
.17383 .10019 L
.18493 .07236 L
.19477 .05336 L
.20563 .03733 L
.21551 .02639 L
.22478 .01883 L
.22947 .0159 L
.23461 .01328 L
.23962 .01124 L
.24496 .00948 L
.25455 .00706 L
.26347 .00523 L
.27371 .00344 L
.2791 .00266 L
.28481 .002 L
.28981 .00157 L
.29264 .00139 L
.2953 .00125 L
.29773 .00116 L
.29996 .00109 L
.30496 .00098 L
Mistroke
.32399 .00049 L
.3296 .00024 L
.33487 0 L
Mfstroke
.33487 0 m
.33495 0 L
s
.3606 0 m
.36444 .00015 L
.367 .00025 L
.36974 .00034 L
.37228 .00041 L
.37352 .00044 L
.37467 .00046 L
.37596 .00048 L
.37664 .00049 L
.37736 .00049 L
.37853 .0005 L
.37981 .00049 L
.38054 .00049 L
.38121 .00049 L
.38198 .00048 L
.38271 .00047 L
.38401 .00044 L
.38542 .00041 L
.39026 .00026 L
.39481 7e-05 L
s
.39481 7e-05 m
.39673 0 L
s
.42439 0 m
.42617 7e-05 L
.43107 .00025 L
.43376 .00034 L
.43629 .0004 L
.43773 .00042 L
.43854 .00043 L
.43929 .00044 L
.43992 .00045 L
.44061 .00045 L
.44134 .00045 L
.44201 .00045 L
.4427 .00045 L
.44335 .00045 L
.44458 .00044 L
.44589 .00042 L
.44732 .0004 L
.44973 .00035 L
.45239 .00027 L
.45776 .0001 L
s
.45776 .0001 m
.46099 0 L
s
.47925 0 m
.48236 .0001 L
.48678 .00027 L
.4919 .00046 L
.49461 .00055 L
.49609 .00058 L
.49748 .00061 L
.49881 .00063 L
.49956 .00064 L
.50025 .00065 L
.50147 .00066 L
.50275 .00066 L
.50396 .00066 L
.50509 .00065 L
.50632 .00064 L
.50764 .00062 L
.51022 .00057 L
.51295 .00052 L
.51531 .00047 L
.51785 .00042 L
.51927 .00039 L
.52057 .00038 L
.52188 .00037 L
.52312 .00037 L
.52382 .00037 L
.52456 .00037 L
.52527 .00038 L
.5259 .00039 L
.52665 .0004 L
.52746 .00042 L
.52894 .00046 L
.53019 .00051 L
.53137 .00056 L
.53403 .00072 L
.53663 .00091 L
.53942 .00117 L
.54907 .00233 L
.55924 .00376 L
.5646 .00454 L
.5703 .00544 L
.57527 .00639 L
.58075 .00777 L
.58574 .00946 L
.59042 .01157 L
.59511 .01428 L
.60025 .01801 L
.6106 .02826 L
.62018 .0415 L
.6291 .05805 L
.63961 .08509 L
Mistroke
.64954 .12069 L
.66813 .2139 L
.67785 .26739 L
.68316 .29361 L
.68813 .3142 L
.69237 .32772 L
.69475 .33342 L
.69692 .33734 L
.69815 .339 L
.69929 .34016 L
.70054 .34102 L
.70124 .3413 L
.70188 .34144 L
.70304 .3414 L
.7043 .34093 L
.70549 .34007 L
.70658 .33894 L
.70785 .33721 L
.70905 .33518 L
.71129 .33036 L
.71634 .31505 L
.7207 .29751 L
.72544 .27497 L
.74611 .16347 L
.75633 .11692 L
.76592 .08337 L
.77591 .05784 L
.78693 .03801 L
.79678 .02547 L
.80174 .02061 L
.80715 .01626 L
.81179 .01327 L
.81674 .01073 L
.82142 .00888 L
.82566 .00757 L
.83052 .0064 L
.83566 .00544 L
.84487 .0041 L
.85491 .00288 L
.86044 .0023 L
.86316 .00206 L
.86568 .00186 L
.86801 .00171 L
.87059 .00158 L
.87192 .00153 L
.87318 .00149 L
.8745 .00146 L
.87525 .00145 L
.87593 .00144 L
.87706 .00143 L
Mistroke
.87811 .00143 L
.87926 .00144 L
.88049 .00146 L
.88178 .00149 L
.883 .00153 L
.88529 .00162 L
.88986 .00187 L
.89407 .00217 L
.90361 .00299 L
.91263 .00389 L
.92234 .00512 L
.9279 .00607 L
.93299 .00717 L
.93782 .00847 L
.94297 .01019 L
.95121 .01378 L
.95885 .01818 L
.96795 .02505 L
.97619 .03319 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooo`000008o`000003ooooool0003ooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`Oo00001Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`05oooooaSo00001?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo023o
oooo000Tooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool04Oooool6o`0001Kooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0@ooooo`Go00006?ooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooo000000Go00006?ooool5o`0000_ooooo00?o0000ooooooooool0
8?ooool006Oooooo0_l0001<ooooo`03o`000?oooooooooo01Gooooo0ol00014ooooo`?o00008ooo
ool4o`0002[ooooo001Tooooo`?o0000C_ooool00ol0003oooooooooo`0Hooooo`;o0000@Oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Oooooo001Rooooo`;o0000DOooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo03cooooo0_l0000/ooooo`03o`000?oooooooooo
02Kooooo001Qooooo`03o`000?oooooooooo057ooooo0_l0000Looooo`03o`000?oooooooooo03[o
oooo00?o0000ooooooooool0;Oooool2o`0002Kooooo001Pooooo`03o`000?oooooooooo05;ooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02oooooo
00?o0000ooooooooool08oooool005oooooo00?o0000ooooooooool0Doooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`0Rooooo`00G_ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo027ooooo000Toooo
o`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Poooo
o`009?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo05Kooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo05Sooooo000Uooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0FOooool002Kooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`1Gooooo`;o00008_ooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo05Wooooo000Wooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0F?ooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0F_ooool0
02Oooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Jooooo`00:?ooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo05_ooooo000Yooooo`03o`000?oooooooooo02cooooo
00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02cooooo
00?o0000ooooooooool0Foooool002Wooooo00?o0000ooooooooool0:oooool00ol0003ooooooooo
o`1Kooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0:_ooool00ol0003ooooooooo
o`1Looooo`00:_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo05_ooooo0_l0000U
ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0G?ooool002[ooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`1Mooooo`00:oooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo05cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo05gooooo000[ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
GOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
G_ooool002cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1Mooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1Nooooo`00;?ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05kooooo000/ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0G_ooool2o`0002Oooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1Oooooo`00;Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo05ko
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo05oo
oooo000]ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0Goooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0Goooool002kooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`1Pooooo`00;_ooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo04Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Ooo
ool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo063ooooo000^ooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool0AOooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo063ooooo000_ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0AOooool0
1Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01Oooool3o`0002Sooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`1Qooooo`00;oooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo04Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo067ooooo000_ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0AOooool0
1Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0HOooool0033ooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`16ooooo`05oa0@4?ooooooooooooooool@41003_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`1Qooooo`00<?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo04Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo06;ooooo000`
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0A_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool0H_ooool0037ooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`1Rooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`1Rooooo`00<Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
06;ooooo0_l0000[ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0H_ooool0037o
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Sooooo`00<_ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo06?ooooo000booooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool0Hoooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool0Hoooool003;ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1S
ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1S
ooooo`00<oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo06?ooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo06?ooooo000cooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool0I?ooool2o`0002cooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`1Tooooo`00<oooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo06Cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo06Cooooo000dooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0I?oo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0I?oo
ool003Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Tooooo`00=?ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo06Cooooo000dooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool0IOooool003Gooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`1Uooooo`;o0000;_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo06Gooooo
000eooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0I_ooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0IOooool003Gooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`1Uooooo`00=_ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo06Kooooo000fooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool0Ioooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool0I_ooool003Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Wooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1Vooooo`00=ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06Oooooo0_l0000_ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0I_ooool003Oooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`1Wooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`1Vooooo`00=oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
06Sooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
06Oooooo000gooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0J?ooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0Ioooool003Sooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`1=ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`1Wooooo`00>?ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo04kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo06Oooooo000hooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0C_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0Ioooool003Wo
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1>ooooo`05o`000?oooooooooooooo
ool000003Oooool00onHV9So8B4Qonk^kP06ooooo`?o0000;oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo06Sooooo000iooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0Coooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0J?ooool003Wo
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1?ooooo`05oa0@4?oooooooooooooo
ool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`1Xooooo`00>_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo04oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0J?ooool003[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1@oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo06Sooooo000j
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0JOooool003[ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`1[ooooo`;o0000<_ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo06Wooooo000kooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0K?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0JOooool003_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1/ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Yooooo`00>ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo06Wooooo000looooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0J_ooool003cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1^ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`1Zooooo`00?Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06ko
oooo0_l0000cooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0J_ooool003kooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`1Zooooo`00?_ooool2o`0000;ooooo0_l0
001aooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`1Zooooo`00?oooool4o`0007;ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo06_ooooo002eooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`1[ooooo`00]Oooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool0Joooool00;Gooooo0_l0000dooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0Joooool00;Gooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo06_ooooo002eooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1/ooooo`00]Oooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0K?ooool00;Go
oooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo06co
oooo002eooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`1/ooooo`00]Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0K?ooool00;Gooooo0_l0000eooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0KOooool00;Gooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo06gooooo002eooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`1]ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05oiRHV?l@413o0000oc8b<_o<c<`01_ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0KOooool009[ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Kooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06gooooo002Joooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1]ooooo`00V_ooool01Ol0
003ooooooooooooooooo000000kooooo00?oZJVYoa0@4?ooool01Oooool3o`0003Gooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`1^ooooo`00V_ooool01Ol0003ooooooooooooooooo
000000gooooo00?o410@o`000?nj^[X01_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0K_ooool009[ooooo00Go410@oooooooooooooooooa0@400>
ooooo`03okZj^_lQ8B7ooooo00Gooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo06kooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol@413oV9RHoooooonj^[[o000000Kooooo00?o0000ooooooooool0=_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo06kooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo06oooooo002eooooo`03o`000?oooooooooo03Oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`1_ooooo`00]Oooool2o`0003Sooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1`ooooo`00]Oooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0L?ooool00;Gooooo00?o0000oooooooo
ool0>?ooool01Ol0003ooooooooooooooooo000007?ooooo002eooooo`03o`000?oooooooooo03Wo
oooo00Co0000ooooool0003o0000Loooool00;Gooooo00?o0000ooooooooool0>_ooool2o`0007Co
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooo
oooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol00006ooooo`?o0000/?ooool009[ooooo00Go0000ooooooooooooooooo`00000;
ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0
/?ooool009[ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo
00?o0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^
k_m4A4Co000000Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`
ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooa0@400@
ooooo`03o`000?oooooooooo00?ooooo0ol0002`ooooo`00V_ooool01Ol0003ooooooooooooooooo
000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol0
003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oo
oooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00[oooool00ol0003o^[Zjooooo`2fooooo`00[oooool2oc8b<[Oooooo
0020ooooo`;o000000Ko410@oooooooooooo410@o`000?l@410Hooooo`Co000000Go410@oooooooo
ooooooooodA4A002o`000007oc8b<_oMgMgooooooooooon7QhOo0000okZj^P0<ooooo`05oiRHV?l0
003o0000odA4A?nj^[X06Oooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0N?ooool0087ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00003?ooool00ol0003oooooooooo`06oooo
o`07ogMgMolb<S;oooooooooooo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@4100
2Oooool6o`0000gooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg07Sooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool07oooool01?l0003oooooooooool@4103ooooo`05oa0@4?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`1fooooo`00POooool01_l0003oooooodA4A?m4A4Coooooo`0000Wo
oooo1_l0000<ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool04?ooool00ol0003o
ooooooooo`0;ooooo`Ko00003Oooool01OmgMgOo<S8boooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo07Kooooo0021ooooo`06o`000?oMgMgo<S8b
oeEEEOoMgMgo00006oooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
4Oooool00ol0003oooooooooo`0Kooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00001hooooo`00POooool01_l0
003oQhN7ojVYZOnj^[[oEEEEo`0001_ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Aooooo`03oa0@4?l0003o000000?o00006_ooool00ol0003oooooooooo`04ooooo`05oa0@4?oo
ooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@07Sooooo0021ooooo`06o`00
0?lb<S;ooooooooooolb<S;o00006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg07Sooooo0020ooooo`03oa0@4?l0003o
QhN700;ooooo00?oQhN7o`000?l@41006?ooool00omEEEGoIVIVo`000005ooooo`Co00004_ooool0
0ol0003oooooooooo`0Kooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP1hooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(600) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .0036 m
.03279 .00509 L
.04262 .00695 L
.04758 .00799 L
.05288 .00927 L
.05785 .01075 L
.06244 .01245 L
.06788 .01501 L
.07379 .01862 L
.08451 .02771 L
.09425 .03907 L
.10458 .05476 L
.11399 .07307 L
.12411 .09812 L
.14241 .15781 L
.15195 .19246 L
.16212 .22575 L
.16798 .24072 L
.17074 .24631 L
.17328 .25049 L
.17584 .25372 L
.17719 .255 L
.17788 .25554 L
.17861 .25604 L
.17985 .25667 L
.18101 .25703 L
.18172 .25715 L
.18239 .25718 L
.18364 .25704 L
.18481 .25667 L
.18592 .25612 L
.18713 .25529 L
.18843 .25413 L
.19108 .25095 L
.19352 .24711 L
.19797 .23796 L
.20266 .22576 L
.22335 .15502 L
.23362 .11975 L
.24331 .09109 L
.25275 .06851 L
.26146 .05211 L
.27087 .03837 L
.28107 .02713 L
.29124 .01884 L
.29687 .01529 L
.30202 .01261 L
.31145 .00891 L
.31665 .00741 L
.32159 .00628 L
Mistroke
.33035 .00475 L
.3399 .00348 L
.35006 .00236 L
.35962 .0015 L
.36491 .00113 L
.36769 .00098 L
.37063 .00084 L
.37311 .00075 L
.37442 .00072 L
.37583 .00068 L
.37712 .00066 L
.3783 .00064 L
.37949 .00062 L
.3806 .00061 L
.38171 .0006 L
.3829 .00059 L
.38422 .00059 L
.38542 .00059 L
.38662 .00059 L
.38792 .00059 L
.38858 .00059 L
.38928 .0006 L
.39054 .0006 L
.39302 .00061 L
.39424 .00062 L
.39536 .00062 L
.39638 .00062 L
.39745 .00063 L
.39854 .00063 L
.39973 .00063 L
.40039 .00062 L
.40112 .00062 L
.40243 .00062 L
.40372 .00061 L
.40491 .0006 L
.4076 .00057 L
.41047 .00053 L
.4205 .00032 L
.42505 .00023 L
.42754 .00018 L
.42985 .00015 L
.43237 .00012 L
.4337 .00011 L
.43438 .00011 L
.43512 .0001 L
.43642 .0001 L
.43765 .0001 L
.43884 .0001 L
.43995 .0001 L
.441 .00011 L
Mistroke
.44213 .00011 L
.44417 .00012 L
.44882 .00016 L
.45337 .0002 L
.45468 .00021 L
.45591 .00022 L
.45702 .00023 L
.45822 .00023 L
.45885 .00023 L
.45955 .00023 L
.46027 .00023 L
.46095 .00023 L
.46216 .00023 L
.46346 .00022 L
.46477 .00021 L
.46601 .0002 L
.46833 .00017 L
.47108 .00013 L
.47362 8e-05 L
Mfstroke
.47362 8e-05 m
.47717 0 L
s
.51377 0 m
.51597 3e-05 L
.51824 6e-05 L
.51953 7e-05 L
.52026 8e-05 L
.52093 8e-05 L
.52212 8e-05 L
.52337 8e-05 L
.52454 8e-05 L
.52564 8e-05 L
.52684 7e-05 L
.52812 5e-05 L
.53102 1e-05 L
s
.53102 1e-05 m
.53162 0 L
s
.56664 0 m
.56781 5e-05 L
.57729 .00048 L
.57979 .00057 L
.58252 .00065 L
.58377 .00068 L
.5851 .00071 L
.58623 .00072 L
.58749 .00074 L
.58869 .00075 L
.58979 .00075 L
.59101 .00075 L
.59228 .00074 L
.5934 .00073 L
.59443 .00071 L
.59679 .00068 L
.60199 .00056 L
.60454 .00051 L
.6069 .00047 L
.60821 .00045 L
.60888 .00044 L
.60961 .00044 L
.61034 .00043 L
.61113 .00043 L
.61188 .00043 L
.61256 .00044 L
.61382 .00045 L
.61453 .00046 L
.61519 .00047 L
.61641 .0005 L
.6177 .00054 L
.62031 .00065 L
.62307 .00082 L
.628 .00122 L
.63332 .0018 L
.63914 .00254 L
.6497 .00405 L
.65932 .00565 L
.66413 .00667 L
.66936 .0081 L
.6743 .00988 L
.67886 .012 L
.68369 .01484 L
.68901 .01877 L
.69979 .02966 L
.7099 .04416 L
.71916 .0624 L
.72933 .09019 L
.74003 .13084 L
.76003 .23478 L
Mistroke
.76874 .28119 L
.77333 .30235 L
.77818 .32067 L
.78068 .32813 L
.78201 .33147 L
.78344 .33455 L
.78475 .33691 L
.78594 .33866 L
.78714 .34003 L
.78828 .34095 L
.78943 .3415 L
.79065 .34169 L
.7917 .34151 L
.79285 .34095 L
.79408 .33994 L
.79477 .33919 L
.79541 .33838 L
.79782 .33432 L
.80034 .32843 L
.80269 .32153 L
.80802 .30137 L
.81878 .24742 L
.83748 .14703 L
.84804 .10284 L
.85778 .07274 L
.86812 .04986 L
.87909 .03263 L
.88868 .02177 L
.89413 .01707 L
.89923 .01356 L
.9042 .01091 L
.90962 .00876 L
.91473 .0073 L
.91948 .00631 L
.92845 .00495 L
.93801 .00378 L
.9426 .00325 L
.94746 .00277 L
.94999 .00256 L
.95134 .00247 L
.95278 .00238 L
.9541 .00232 L
.95531 .00227 L
.95652 .00224 L
.95767 .00222 L
.95873 .00221 L
.95991 .00222 L
.96113 .00224 L
.96228 .00227 L
.96335 .00231 L
Mistroke
.96433 .00236 L
.96654 .0025 L
.96879 .00269 L
.97124 .00295 L
.97619 .0036 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool3o`0000Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool:o`0000Co
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_l0000;ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`go00008_ooool002Cooooo00?o0000ooooooooool0
1Ol0000Yooooo`03o`000?oooooooooo02Gooooo1_l00002ooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool0;Oooool3o`0002gooooo00?o0000ooooooooool06_ooool7o`0000cooooo
00?o0000ooooooooool08?ooool002cooooo1?l0001;ooooo`;o0000>?ooool00ol0003ooooooooo
o`0`ooooo`?o0000A?ooool3o`0003Kooooo000`ooooo`;o0000A_ooool3o`0003[ooooo00?o0000
ooooooooool0<oooool2o`00043ooooo0_l0000iooooo`00<_ooool2o`0004?ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03cooooo00?o0000oooo
ooooool0>Oooool003Cooooo00?o0000ooooooooool0?_ooool2o`0003kooooo0_l0000gooooo`;o
0000??ooool00ol0003oooooooooo`0iooooo`00=Oooool00ol0003oooooooooo`0kooooo`;o0000
@?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0
>_ooool003Kooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`10ooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0kooooo`00=oooool0
0ol0003oooooooooo`0hooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0dooooo`03o`000?oooooooooo03cooooo000hooooo`03o`000?oooooooooo
03Kooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool0?Oooool003Wooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`12ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`0mooooo`00>_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo04?ooooo
00?o0000ooooooooool0??ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo03kooooo
000jooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0@oooool2o`0003gooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`0oooooo`00>oooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo03oooooo000looooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool0AOooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool0@?ooool003cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`16ooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`10ooooo`00
?Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo047ooooo000mooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool0@Oooool003kooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`17ooooo`;o0000@?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo04;ooooo000oooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0Aoooool00ol0
003oooooooooo`0oooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0@oooool003oo
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo043o
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`13ooooo`00@?ooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0@?ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo04Cooooo0010ooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool0BOooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool0A?ooool0047ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`19
ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`15
ooooo`00@Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04[ooooo0_l00012oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0AOooool0047ooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo047ooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`15ooooo`00@_ooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo04[ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo04Kooooo0012ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0Booo
ool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0A_oo
ool004;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0`ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oo
oooooooo04;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`16ooooo`00@oooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo037ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04?ooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`17ooooo`00@oooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo037ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oo
oooooooo00Gooooo0ol00013ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0Aooo
ool004?ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0aooooo`05o`000?oooooo
ooooooooool000003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04?ooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`17ooooo`00A?ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo03;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo04Oooooo0014ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0<_ooool0
1Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`14ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0B?ooool004Cooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0booooo`05ogMgMonHV9SooooooiRHV?mgMgL03_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`18ooooo`00AOooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo03?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo000000Oooooo00?o
0000ooooooooool0AOooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04Sooooo0015
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`15
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0B?ooool004Gooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`1>ooooo`;o0000A_ooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo04Sooooo0015ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool0C_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool0BOooool004Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1?ooooo`03o`00
0?oooooooooo04Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`19ooooo`00A_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0A_oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04Wooooo0016ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`16ooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool0BOooool004Kooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`1@ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`19ooooo`00Aoooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo053o
oooo0_l00018ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0B_ooool004Oooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo04Oooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`1:ooooo`00Aoooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0Aoooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo04[ooooo0018ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool0DOooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0B_ooool004Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1Aoooo
o`03o`000?oooooooooo04Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1:oooo
o`00B?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo057ooooo00?o0000oooooooo
ool0B?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04_ooooo0018ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool0D_ooool2o`0004Wooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`1;ooooo`00BOooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo05;ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo04_ooooo0019ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0D_ooool0
0ol0003oooooooooo`18ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Boooool0
04Wooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo
04Sooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1;ooooo`00B_ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0BOooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo04_ooooo001:ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0Doooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool0C?ooool004[ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`1Cooooo`;o0000B_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04cooooo001:
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`19
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0C?ooool004_ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo04Wooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`1<ooooo`00Boooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo05Cooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo04cooooo001;ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`1:ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0C?ooool004_ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0jooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo
04[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1=ooooo`00C?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo03[ooooo00Go410@oooooooooooooooooa0@400<oooo
o`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo04gooooo001<ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0>_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`00
04[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1=ooooo`00C?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo03_ooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo04gooooo001=ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0>oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`1;ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0COooool004go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0kooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0Boooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo04gooooo001=ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0>oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`1>ooooo`00C_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo05Oooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo04kooooo001>ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Eoooool2o`00
04gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1>ooooo`00C_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0C?ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo04kooooo001?ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0F?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0C_ooool004oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1Iooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`1>ooooo`00D?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Wooooo00?o0000
ooooooooool0C?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04oooooo001@oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`1<oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Coooool0057ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`1Jooooo`;o0000C_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo04oooooo001Booooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
Foooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
Coooool005?ooooo00Co0000oooooooooooo0000G_ooool00ol0003oooooooooo`1=ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0Coooool005?ooooo1?l0001Nooooo`03o`000?oo
oooooooo04gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1@ooooo`00]Oooool0
0ol0003oooooooooo`1=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0D?ooool0
0;Gooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
053ooooo002eooooo`;o0000C_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo053o
oooo002eooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`1Aooooo`00]Oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0DOooool00;Gooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo057ooooo002eooooo`03o`000?oooooooooo04kooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`1Aooooo`00]Oooool00ol0003oooooooooo`1>ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0DOooool00;Gooooo00?o0000ooooooooool0
C_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05;ooooo002eooooo`;o0000D?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05;ooooo002eooooo`03o`000?oooooo
oooo04oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Booooo`00]Oooool00ol0
003oooooooooo`1?ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0D_ooool009[o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;o
c<c<00Kooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo05?ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go410@
okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`1Cooooo`00V_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0Doooool009[ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ojVYZOl@
413ooooo00Gooooo0ol0001@ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Dooo
ool009[ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oa0@4?l0003o^[Zj00Kooooo00?o
0000ooooooooool0DOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05?ooooo002J
ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onj^[[o8B4Qooooo`05ooooo`03o`000?oo
oooooooo057ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Dooooo`00V_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`00
0?oooooooooo057ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Dooooo`00V_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03
o`000?oooooooooo057ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Dooooo`00
]Oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
E?ooool00;Gooooo0_l0001Cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0EOoo
ool00;Gooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo05Gooooo002eooooo`03o`000?oooooooooo05?ooooo00Go0000ooooooooooooooooo`00001H
ooooo`00]Oooool00ol0003oooooooooo`1Dooooo`04o`000?oooooo0000o`0005Sooooo002eoooo
o`03o`000?oooooooooo05Cooooo0ol0001Iooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o
410@ooooooooool01?ooool00ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool009[ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool3o`000;3ooooo002J
ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00007ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEE
ooooool00007ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@
41003?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0;3o
oooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
09[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`?o0000/?oo
ool009[ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0/?ooool009[ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooo
oooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00V_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:oooooo00?o0000okZj
^_ooool0]_ooool00:oooooo0_lb<S:gooooo`00P?ooool2o`000006oa0@4?oooooooooooa0@4?l0
003o410@6?ooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000001olb<S;ogMgMoooooooo
ooooQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo00Gok^k^oc8b<_l0
003o410@olc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^07Sooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool6
o`0000cooooo00?o0000ooooooooool01_ooool01omgMgOo<S8booooooooooooc<c<o`000?l@4100
3?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00009ooooo`05oeEEEOmgMgOooooooiRH
V?lQ8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`1hooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01[ooooo00Go0000
ooooooooooooooooo`000003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooo
oooooooooooo410@07Sooooo0021ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`00
00cooooo00?o0000ooooooooool01_ooool00omgMgOo<S8booooo`0@ooooo`03o`000?oooooooooo
00_ooooo1_l00009ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`00001hooooo`00POooool01_l0003ogMgMoc8b
<_mEEEGogMgMo`0001_ooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
017ooooo00?o0000ooooooooool06_ooool01Ol0003oEEEEo`000?l@413oc<c<00?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000N?ooool0087ooooo00Ko
0000ohN7QonYZJWo^[ZjoeEEEOl0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool04Oooool00ol@413o0000o`000003o`0001Wooooo00?oEEEEohN7Qoooool01Oooool01Ol@413o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@401hooooo`00POooool01_l0
003o<S8boooooooooooo<S8bo`0001_ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo01[ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1hooooo`00P?ooool00ol@413o0000
ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo00?oEEEEofIVI_l000001Oooool4o`0001;ooooo
00?o0000ooooooooool06oooool01?o<c<coA4A4o`000?l@4103ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07Sooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(700) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .02241 m
.02846 .0184 L
.03279 .01532 L
.03793 .01241 L
.04262 .01037 L
.04754 .00876 L
.0522 .00762 L
.05711 .00671 L
.06244 .00595 L
.06794 .00532 L
.07308 .00485 L
.07588 .00465 L
.07844 .00449 L
.07981 .00443 L
.08129 .00437 L
.08211 .00435 L
.08286 .00433 L
.08358 .00431 L
.08435 .0043 L
.08502 .0043 L
.08572 .00429 L
.08698 .0043 L
.08768 .00431 L
.08833 .00433 L
.08905 .00435 L
.08982 .00437 L
.0912 .00444 L
.09251 .00451 L
.09496 .0047 L
.09735 .00495 L
.09957 .00523 L
.10458 .00604 L
.10921 .00701 L
.11421 .00827 L
.12324 .01113 L
.12848 .01319 L
.13399 .01576 L
.13915 .01866 L
.14385 .02182 L
.15339 .03019 L
.16359 .04269 L
.17304 .05826 L
.18195 .077 L
.20197 .13489 L
.22042 .20064 L
.22947 .22924 L
.23454 .2419 L
.23918 .25052 L
.2418 .25396 L
.24328 .25543 L
Mistroke
.24399 .256 L
.24465 .25646 L
.24597 .25716 L
.24717 .25755 L
.24846 .25768 L
.24918 .25764 L
.24985 .25752 L
.25105 .25711 L
.25216 .25652 L
.25339 .25563 L
.2547 .2544 L
.25738 .25103 L
.25982 .24701 L
.26465 .23662 L
.26976 .22261 L
.27895 .19226 L
.29972 .11986 L
.30912 .09245 L
.31923 .06831 L
.32871 .05042 L
.33752 .03742 L
.34712 .02674 L
.35219 .02237 L
.3576 .01854 L
.3633 .01528 L
.36867 .0128 L
.37872 .00922 L
.38846 .0066 L
.39877 .00445 L
.40757 .00311 L
.41257 .00255 L
.41723 .00214 L
.42223 .00181 L
.42767 .00153 L
.43756 .00111 L
.44713 .0007 L
.45611 .00034 L
.46062 .0002 L
.46316 .00015 L
.46429 .00013 L
.46549 .00011 L
.46674 .0001 L
.4679 9e-05 L
.46862 8e-05 L
.46929 8e-05 L
.47054 8e-05 L
.47119 8e-05 L
.47187 8e-05 L
.47309 9e-05 L
.47441 .0001 L
Mistroke
.47586 .00011 L
.48149 .0002 L
.48426 .00024 L
.48683 .00028 L
.48915 .00031 L
.49045 .00032 L
.49163 .00032 L
.49292 .00033 L
.49365 .00033 L
.49432 .00033 L
.49556 .00033 L
.49686 .00032 L
.49807 .00031 L
.49917 .0003 L
.50165 .00026 L
.50395 .00021 L
.50612 .00016 L
.5114 0 L
Mfstroke
.5114 0 m
.51146 0 L
s
.54209 0 m
.54622 .00013 L
.54883 .0002 L
.55131 .00026 L
.55353 .0003 L
.55478 .00032 L
.55595 .00033 L
.55662 .00033 L
.55734 .00034 L
.55866 .00034 L
.55994 .00034 L
.56111 .00033 L
.56239 .00031 L
.56379 .00029 L
.56661 .00023 L
.57178 8e-05 L
s
.57178 8e-05 m
.57435 0 L
s
.60633 0 m
.60656 1e-05 L
.60898 8e-05 L
.61127 .00014 L
.61351 .00019 L
.61557 .00022 L
.61666 .00023 L
.61782 .00024 L
.61898 .00025 L
.62027 .00025 L
.62152 .00025 L
.62222 .00024 L
.62286 .00024 L
.62405 .00023 L
.6253 .00021 L
.62755 .00017 L
.62964 .00012 L
s
.62964 .00012 m
.63409 0 L
s
.66089 0 m
.66478 .00013 L
.67009 .00035 L
.67505 .00053 L
.67765 .0006 L
.67898 .00063 L
.68042 .00065 L
.68201 .00067 L
.68274 .00068 L
.68351 .00069 L
.6842 .00069 L
.68497 .0007 L
.68566 .0007 L
.68632 .0007 L
.68758 .0007 L
.68822 .0007 L
.68892 .0007 L
.69015 .0007 L
.6913 .0007 L
.69264 .00069 L
.6939 .00069 L
.6946 .00069 L
.69535 .00069 L
.69667 .00069 L
.69787 .00069 L
.69917 .0007 L
.70039 .00071 L
.7015 .00072 L
.70281 .00075 L
.70423 .00078 L
.70682 .00087 L
.70952 .001 L
.71239 .00118 L
.71755 .00162 L
.72668 .00268 L
.73678 .00406 L
.74618 .00552 L
.75131 .00649 L
.75609 .00765 L
.76128 .0093 L
.76696 .01178 L
.77178 .01455 L
.77693 .01831 L
.78715 .02851 L
.79292 .03608 L
.79825 .04445 L
.80802 .06413 L
.81839 .09328 L
.8278 .12932 L
.83793 .1785 L
Mistroke
.85623 .27832 L
.86112 .30129 L
.86634 .32116 L
.86934 .32987 L
.87206 .33582 L
.87337 .338 L
.87406 .33895 L
.87479 .33981 L
.87543 .34044 L
.87614 .341 L
.87737 .34165 L
.87802 .34182 L
.87872 .34187 L
.87999 .34159 L
.88124 .34088 L
.88239 .33983 L
.88363 .33828 L
.88499 .33609 L
.88776 .33012 L
.89017 .32335 L
.89277 .31455 L
.89746 .29517 L
.91712 .19022 L
.92751 .13795 L
.93861 .09423 L
.94881 .06529 L
.95808 .0463 L
.9674 .03221 L
.97619 .02241 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?o
oooo0ol00003ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool<o`0000Go
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00Co0000oooooooooooooooo2ol00009ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Pooooo`009?ooool00ol0003oooooooooo`06ooooo`Wo
00000oooool7o`0001Gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0:ooooo`Ko
00007Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Sooooo1?l0000Aooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool08?ooool002[ooooo0ol0000Cooooo`?o0000
C?ooool3o`0002?ooooo00?o0000ooooooooool0C?ooool2o`0006;ooooo000Xooooo`;o00006Ooo
ool3o`0004Kooooo0ol0000Vooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0Gooo
ool002Oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool0Coooool2o`0005oooooo000Uooooo`;o00008?ooool2o`00
043ooooo0_l0000Zooooo`;o0000D_ooool00ol0003oooooooooo`1Looooo`009?ooool00ol0003o
ooooooooo`0Rooooo`;o0000??ooool2o`0002cooooo00?o0000ooooooooool0D_ooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo023ooooo001;ooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool08?ooool004cooooo00?o0000ooooooooool0=oooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`0Qooooo`00C?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool0EOooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02;ooooo001=oooo
o`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Foooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool08_ooool004kooooo00?o0000oooooooo
ool0<oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo05Kooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`0Sooooo`00Coooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo02oooooo0_l0001Hooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
9?ooool004oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo05Oooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Uooooo`00D?ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0Eoooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02Gooooo001Aooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool09_ooool0057ooooo00?o0000ooooooooool0;?ooool00ol0003o
ooooooooo`0booooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0;?ooool00ol0003o
ooooooooo`0Vooooo`00D_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02Oooooo
001Booooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0<oooool2o`0005[ooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`0Wooooo`00Doooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo02Sooooo001Cooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool0=?ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool0:?ooool005?ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo05_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Yooooo`00
E?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
Foooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Wooooo001Dooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1Kooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool0:Oooool005Cooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0fooooo`;o0000GOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo02[ooooo001Eooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`1Looooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0:_ooool005Go
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo05co
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Zooooo`00EOooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0GOooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo02_ooooo001Fooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool07?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool0:oooool005Kooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`0Mooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
:oooool005Kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Mooooo`05oa0@4?oo
ooooooooooooool@41003_ooool00ol0003oooooooooo`05ooooo`?o0000G_ooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo02_ooooo001Gooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool07Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
;?ooool005Oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Nooooo`05o`000?oo
ooooooooooooool000003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05kooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`0/ooooo`00Eoooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo01kooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo02cooooo001Hooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`1Oooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0;?ooool005Sooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0Oooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0]ooooo`00F?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo03[ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo02gooooo001Iooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0>_ooool2
o`00067ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0]ooooo`00FOooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo02gooooo001Iooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool0;Oooool005[ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0^ooooo`00F_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0HOooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02kooooo001J
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`1Q
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0;_ooool005_ooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0looooo`;o0000H_ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo02kooooo001Kooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool0??ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0;oooool005_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0looooo`03o`00
0?oooooooooo067ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0_ooooo`00G?oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0H_oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02oooooo001Looooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0;oooool005cooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0mooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0`ooooo`00GOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03go
oooo0_l0001Sooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0<?ooool005gooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo06;ooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0`ooooo`00GOooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0Hoooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo033ooooo001Mooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0?_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool0<Oooool005kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0ooooo
o`03o`000?oooooooooo06?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0aoooo
o`00G_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03oooooo00?o0000oooooooo
ool0Hoooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo037ooooo001Nooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0?oooool2o`0006Cooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0aooooo`00Goooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo03oooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo03;ooooo001Oooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0@?ooool0
0ol0003oooooooooo`1Tooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0<_ooool0
05oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo
06Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0booooo`00H?ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo02Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo03;ooooo001Pooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool09_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@01_ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0<_ooool0063ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Voooo
o`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooo
oooo06Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0cooooo`00HOooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo02Kooooo00Go0000ooooooooooooooooo`00000=
ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0001Uooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0<oooool0067ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Woooo
o`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooo
oooo06Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0cooooo`00HOooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo02Oooooo00Go410@oooooooooooooooooa0@400?
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo03?ooooo001Rooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool09oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@
4006ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0cooooo`00H_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Sooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`1Uooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0=?ooool006;ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo06Kooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0dooooo`00Hoooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo04?ooooo0_l0001Wooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0=?ooool006?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`14oooo
o`03o`000?oooooooooo06Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0doooo
o`00Hoooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04Cooooo00?o0000oooooooo
ool0I_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03Cooooo001Sooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`1Vooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0=Oooool006Cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0eooooo`00I?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo04Kooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo03Gooooo001Uooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0A_ooool2o`00
06Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0eooooo`00I_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0Ioooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo03Gooooo001Wooooo`04o`000?ooooooooooo`0004[o
oooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Go
oooo001Wooooo`Co0000B_ooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0=_ooool00;Gooooo00?o0000ooooooooool0J?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo03Kooooo002eooooo`03o`000?oooooooooo06Sooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0fooooo`00]Oooool2o`0006Wooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0fooooo`00]Oooool00ol0003oooooooooo`1Xooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool0=_ooool00;Gooooo00?o0000ooooooooool0
JOooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Oooooo002eooooo`03o`000?oo
oooooooo06Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0gooooo`00]Oooool0
0ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0=oooool0
0;Gooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
03Oooooo002eooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0gooooo`00]Oooool2o`0006[ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0hooooo`00]Oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0>?ooool00;Gooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo03Sooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo06[ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0hooooo`00V_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S801_ooool00ol0003ooooo
ooooo`1Zooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0>?ooool009[ooooo00Go
410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
J_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Sooooo002Jooooo`05o`000?oo
ooooooooooooool000003_ooool00onYZJWo410@ooooo`05ooooo`?o0000Joooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo03Wooooo002Jooooo`05o`000?ooooooooooooooool00000
3Oooool00ol@413o0000okZj^P06ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0iooooo`00V_ooool01Ol@413ooooooooooooooooo410@00kooooo
00?o^[Zjob4Q8Oooool01Oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0>Oooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?nHV9SooooookZj^_l000001_ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0>Oooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0>_ooool00;Gooooo00?o0000ooooooooool0K?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo03[ooooo002eooooo`;o0000K_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo03[ooooo002eooooo`03o`000?oooooooooo06gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0jooooo`00]Oooool00ol0003oooooooooo`1^
ooooo`05o`000?ooooooooooooooool00000?Oooool00;Gooooo00?o0000ooooooooool0K_ooool2
o`000003ooooool0003ooooo03gooooo002eooooo`03o`000?oooooooooo06oooooo0ol0000noooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003ooooooooo
o`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooa0@
400;ooooo`Go00001_ooool3o`000;3ooooo002Jooooo`05o`000?ooooooooooooooool000002ooo
ool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05o`000?oo
ooooooooooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo0;3o
oooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007ooooo`03
o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^ko
A4A4o`000007ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000
/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002a
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?oo
ool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41004?oo
ool00ol0003oooooooooo`03ooooo`?o0000/?ooool009[ooooo00Go0000ooooooooooooooooo`00
000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00cooooo1?l00006ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aoooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000
/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00:oooooo00?o0000okZj^_ooool0]_ooool00:oooooo0_lb<S:gooooo`00
P?ooool2o`000006oa0@4?oooooooooooa0@4?l0003o410@6?ooool4o`000005oa0@4?oooooooooo
oooooom4A4@00_l000001olb<S;ogMgMooooooooooooQhN7o`000?nj^[X03?ooool01OnHV9So0000
o`000?m4A4Co^[Zj01[ooooo00?o0000onk^k_ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1hooooo`00POooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Oooooo1_l0000<ooooo`03o`000?oooooooooo00Kooooo00OoMgMgoc8b
<_ooooooooooolc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko0000
2oooool00omEEEGoZJVYooooo`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg07Sooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool07?ooool00onYZJWoEEEEooooo`03ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@07Sooooo0021ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Ooo
ool6o`0000cooooo00?o0000ooooooooool01_ooool00omgMgOo<S8booooo`0@ooooo`03o`000?oo
oooooooo00_ooooo1_l0000<ooooo`03ob4Q8Ooooooooooo00;ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool00000N?ooool0087ooooo00Ko0000omgMgOlb<S;o
EEEEomgMgOl0000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00A
ooooo`03o`000?oooooooooo01gooooo00?oEEEEolc<c?ooool00_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`00001hooooo`00POooool01_l0003oQhN7ojVY
ZOnj^[[oEEEEo`0001_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03
oa0@4?l0003o000000?o00007?ooool00onYZJWoMgMgooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41000oooool01Ol@413ooooooooooooooooo410@07Sooooo0021ooooo`06o`000?lb<S;ooooo
oooooolb<S;o00006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool06_ooool01Ol@413ooooooooooooooooo<S8b00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0N?ooool0083ooooo00?o410@o`000?n7
QhL00_ooool00on7QhOo0000oa0@400Hooooo`03oeEEEOmVIVKo000000Gooooo1?l0000Booooo`03
o`000?oooooooooo01[ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^07Sooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(800) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .32885 m
.04262 .24703 L
.06244 .1417 L
.07286 .09921 L
.08255 .07001 L
.0932 .0473 L
.09916 .03773 L
.10458 .03053 L
.10941 .02514 L
.11454 .02039 L
.11896 .01701 L
.12373 .01407 L
.12883 .01165 L
.13362 .00999 L
.13653 .00922 L
.1393 .00864 L
.14198 .00819 L
.14451 .00786 L
.14692 .00762 L
.14954 .00741 L
.15191 .00727 L
.1541 .00718 L
.15532 .00714 L
.15646 .00711 L
.15772 .00708 L
.15842 .00707 L
.15907 .00707 L
.16036 .00706 L
.16109 .00706 L
.16176 .00706 L
.163 .00707 L
.16432 .0071 L
.16545 .00713 L
.16648 .00716 L
.16882 .00727 L
.17088 .0074 L
.17306 .00758 L
.17544 .00784 L
.17766 .00814 L
.1827 .00909 L
.18533 .00975 L
.18775 .01046 L
.19323 .01248 L
.19805 .01477 L
.20316 .01772 L
.21201 .02421 L
.22175 .03359 L
.23191 .04656 L
.2412 .06224 L
.25191 .08619 L
Mistroke
.26209 .11534 L
.28216 .18541 L
.29089 .21499 L
.29549 .22848 L
.30033 .2404 L
.30286 .24548 L
.30563 .25005 L
.30814 .25323 L
.30927 .25434 L
.31049 .25531 L
.31173 .25607 L
.3129 .25655 L
.31405 .25681 L
.3151 .25685 L
.31624 .2567 L
.3175 .25629 L
.31881 .25558 L
.32004 .25467 L
.32262 .25198 L
.32532 .24807 L
.33015 .23849 L
.33535 .22495 L
.34103 .2072 L
.36232 .13145 L
.38164 .07609 L
.39131 .05646 L
.40177 .04019 L
.41165 .02859 L
.42074 .02062 L
.42543 .01741 L
.43046 .01456 L
.43954 .01073 L
.44509 .009 L
.45034 .00765 L
.4602 .00552 L
.46983 .00372 L
.47512 .00287 L
.48008 .00219 L
.48429 .00173 L
.48883 .00137 L
.49128 .00123 L
.49262 .00118 L
.49387 .00113 L
.49503 .0011 L
.49608 .00107 L
.49724 .00105 L
.49849 .00104 L
.49968 .00103 L
.5008 .00102 L
.50202 .00102 L
Mistroke
.50333 .00103 L
.50399 .00103 L
.50471 .00103 L
.50601 .00104 L
.50846 .00106 L
.50965 .00107 L
.51077 .00108 L
.51206 .00108 L
.51323 .00108 L
.51434 .00108 L
.51536 .00108 L
.51647 .00107 L
.51765 .00106 L
.51895 .00104 L
.52013 .00102 L
.52278 .00095 L
.52524 .00086 L
.52757 .00076 L
.53844 .00016 L
Mfstroke
.53844 .00016 m
.54145 0 L
s
.57509 0 m
.57679 5e-05 L
.57921 .0001 L
.58178 .00014 L
.58325 .00016 L
.58397 .00017 L
.58463 .00017 L
.58587 .00018 L
.58652 .00018 L
.58721 .00018 L
.58839 .00018 L
.58965 .00018 L
.59084 .00017 L
.59193 .00016 L
.59458 .00013 L
.5971 .0001 L
.60141 4e-05 L
.60377 2e-05 L
.60493 0 L
s
.60493 0 m
.60547 0 L
s
.61388 0 m
.61458 1e-05 L
.61564 2e-05 L
.61796 5e-05 L
.62051 .0001 L
.62565 .00021 L
.62813 .00026 L
.63048 .00031 L
.63276 .00034 L
.63377 .00036 L
.63487 .00037 L
.63608 .00038 L
.63736 .00038 L
.63803 .00039 L
.63876 .00039 L
.64007 .00038 L
.64074 .00038 L
.64148 .00037 L
.64226 .00037 L
.64297 .00036 L
.64564 .00031 L
.64818 .00025 L
.6505 .00019 L
.65569 1e-05 L
s
.65569 1e-05 m
.65608 0 L
s
.68605 0 m
.69085 .00018 L
.69566 .00032 L
.698 .00038 L
.69932 .0004 L
.70054 .00041 L
.70161 .00042 L
.70278 .00042 L
.70401 .00042 L
.70516 .00041 L
.7064 .0004 L
.70771 .00038 L
.71005 .00033 L
.71257 .00027 L
.71533 .00018 L
.71986 1e-05 L
s
.71986 1e-05 m
.72028 0 L
s
.74497 0 m
.75331 .00033 L
.75587 .00042 L
.75727 .00046 L
.75857 .0005 L
.75977 .00052 L
.76087 .00054 L
.76209 .00056 L
.76339 .00057 L
.76407 .00057 L
.76479 .00057 L
.76608 .00057 L
.76679 .00056 L
.76746 .00056 L
.7682 .00055 L
.76899 .00054 L
.77175 .00049 L
.77427 .00042 L
.77904 .00028 L
.78166 .00022 L
.78294 .00019 L
.78412 .00017 L
.78524 .00015 L
.78643 .00014 L
.78761 .00014 L
.78892 .00014 L
.79 .00016 L
.79117 .00018 L
.79226 .0002 L
.79326 .00024 L
.79591 .00035 L
.79836 .00051 L
.80105 .00072 L
.80391 .001 L
.81399 .00231 L
.82336 .00369 L
.83347 .00526 L
.83811 .00611 L
.843 .00724 L
.84718 .00848 L
.85175 .01024 L
.85704 .01291 L
.86203 .01617 L
.87136 .02446 L
.88142 .03699 L
.89232 .05595 L
.90178 .07899 L
.9122 .11418 L
.92307 .16349 L
.93324 .21846 L
Mistroke
.94365 .27511 L
.94878 .29942 L
.95354 .31801 L
.95783 .3306 L
.96023 .33563 L
.96129 .33737 L
.96241 .33887 L
.96365 .34014 L
.9648 .34093 L
.96604 .34136 L
.96674 .34142 L
.96739 .34134 L
.96857 .3409 L
.96965 .34015 L
.9709 .33889 L
.97207 .3373 L
.97421 .33346 L
.97619 .32885 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooool000002?l000000ooooooo0000ooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00So
oooo1_l00007ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo023ooooo000Tooooo`03o`000?oooooooooo02?ooooo
2Ol00002ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool07Oooool6o`0000[ooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00;ooooo
1?l0000Wooooo`03o`000?oooooooooo023ooooo0015ooooo`Go00002?ooool6o`0004[ooooo0ol0
000@ooooo`03o`000?oooooooooo06Kooooo0ol00017ooooo`00@_ooool3o`0001?ooooo00?o0000
ooooooooool0A_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06Wooooo0_l00015
ooooo`00@Oooool00ol0003oooooooooo`0Eooooo`;o0000@oooool3o`0001Cooooo00?o0000oooo
ooooool0Joooool00ol0003oooooooooo`12ooooo`00@?ooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool05Oooool2o`0006gooooo00?o0000oooooooo
ool0@Oooool003oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0mooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`10ooooo`00?_oo
ool00ol0003oooooooooo`0Looooo`;o0000??ooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo06kooooo00?o0000ooooooooool0?oooool003gooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0hooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0Koooool0
0ol0003oooooooooo`0nooooo`00?Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
03Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo
03gooooo000looooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0??ooool003_ooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0LOooool00ol0003oooooooooo`0looooo`00>oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool06oooool2o`0007?ooooo00?o
0000ooooooooool0>oooool003[ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0k
ooooo`00>Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo03[ooooo000iooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo07?ooooo00?o0000ooooooooool0>_ooool003Sooooo00?o0000ooooooooool0
:_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
M?ooool00ol0003oooooooooo`0iooooo`00>?ooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo02cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1dooooo`03o`000?oo
oooooooo03Wooooo000gooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`0Oooooo`;o0000M_ooool00ol0003oooooooooo`0hooooo`00=oooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`1eooooo`03o`000?oooooooooo03Sooooo000fooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo07Ko
oooo00?o0000ooooooooool0=oooool003Kooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0M_ooool00ol0003ooooo
ooooo`0gooooo`00=Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo03Oooooo000e
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool0=_ooool003Gooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02;ooooo0_l0001hoooo
o`03o`000?oooooooooo03Kooooo000dooooo`03o`000?oooooooooo03?ooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo07Oooooo00?o0000oooooooo
ool0=_ooool003Cooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0eooooo`00=?oo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo03Gooooo000cooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`08ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oo
oooooooo07Sooooo00?o0000ooooooooool0=Oooool003?ooooo00?o0000ooooooooool0=Oooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Sooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07Wooooo00?o
0000ooooooooool0=?ooool003?ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo00Wooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oo
oooooooo00Gooooo0ol0001iooooo`03o`000?oooooooooo03Cooooo000cooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`09ooooo`05o`000?oooooo
ooooooooool000003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07Wooooo00?o
0000ooooooooool0=?ooool003;ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`0dooooo`00<_ooool0
0ol0003oooooooooo`0hooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02_ooool0
1Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1jooooo`03o`000?oooooooooo03?ooooo000booooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0:ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0<ooo
ool003;ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo00[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo000000Oooooo00?o
0000ooooooooool0N_ooool00ol0003oooooooooo`0cooooo`00<Oooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1j
ooooo`03o`000?oooooooooo03?ooooo000aooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0Vooooo`;o0000O?ooool00ol0003oooooooooo`0boooo
o`00<Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo03;ooooo000aooooo`03o`00
0?oooooooooo03[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo07_ooooo00?o0000ooooooooool0<_ooool0037ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Nooo
ool00ol0003oooooooooo`0booooo`00<?ooool00ol0003oooooooooo`0looooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1kooooo`03o`000?oooooo
oooo03;ooooo000`ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0<Oooool0033o
oooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02So
oooo0_l0001mooooo`03o`000?oooooooooo037ooooo000`ooooo`03o`000?oooooooooo03gooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo07cooooo
00?o0000ooooooooool0<Oooool0033ooooo00?o0000ooooooooool0?Oooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0O?ooool00ol0003ooooooooo
o`0aooooo`00;oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo037ooooo000_oooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo07gooooo00?o0000ooooooooool0<?ooool002oooooo00?o0000oooooooo
ool0?oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool0OOooool00ol0003oooooooooo`0`ooooo`00;oooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool0:Oooool2o`0007kooooo00?o0000ooooooooool0
<?ooool002oooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`0`ooooo`00;_ooool0
0ol0003oooooooooo`11ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`1mooooo`03o`000?oooooooooo033ooooo000^ooooo`03o`000?oooooooooo
047ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
07gooooo00?o0000ooooooooool0<?ooool002kooooo00?o0000ooooooooool0@Oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0O_ooool00ol0003o
ooooooooo`0_ooooo`00;_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0:oooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo02oooooo
000^ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0[ooooo`;o0000Ooooool00ol0003oooooooooo`0_ooooo`00;Oooool00ol0003oooooooooo`13
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1n
ooooo`03o`000?oooooooooo02oooooo000]ooooo`03o`000?oooooooooo04?ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo07kooooo00?o0000oooo
ooooool0;oooool002gooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`0^ooooo`00
;Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
4Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`1oooooo`03o`000?oooooooooo02kooooo000]ooooo`03o`000?oooooooooo04Cooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo
07oooooo00?o0000ooooooooool0;_ooool002gooooo00?o0000ooooooooool0A?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo01;ooooo00Go410@oooooooooooooooooa0@400<oooo
o`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`0^oooo
o`00;?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool04_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`00
07oooooo00?o0000ooooooooool0;_ooool002cooooo00?o0000ooooooooool0A_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo01;ooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`0]oooo
o`00;?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool04oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`20ooooo`03o`000?oooooooooo02gooooo000/ooooo`03o`000?oooooooooo04Ko
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Cooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0P?ooool0
0ol0003oooooooooo`0]ooooo`00;?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool04oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool0;Ooo
ool002_ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo02oooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`0]ooooo`00:oooool00ol0
003oooooooooo`19ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0;oooool2o`00
087ooooo00?o0000ooooooooool0;Oooool002_ooooo00?o0000ooooooooool0BOooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0POooool00ol0003o
ooooooooo`0/ooooo`00:oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo02cooooo
000[ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool0;?ooool002[ooooo00?o0000
ooooooooool0Boooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool0POooool00ol0003oooooooooo`0/ooooo`00:_ooool00ol0003oooooooooo`1;oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`21oooo
o`03o`000?oooooooooo02cooooo000Zooooo`03o`000?oooooooooo04cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0booooo`;o0000P_ooool00ol0003oooooooooo`0/ooooo`00
:_ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo02_ooooo000Zooooo`03o`000?oo
oooooooo04kooooo00?o0000ooooooooool00_l0000eooooo`03o`000?oooooooooo08;ooooo00?o
0000ooooooooool0:oooool002Wooooo00?o0000ooooooooool0Coooool4o`0003Kooooo00?o0000
ooooooooool0P_ooool00ol0003oooooooooo`0[ooooo`00:Oooool00ol0003oooooooooo`29oooo
o`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0:oooool002Wooooo00?o0000oooooooo
ool0ROooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo02_ooooo000Yooooo`03o`00
0?oooooooooo08Wooooo0_l00023ooooo`03o`000?oooooooooo02_ooooo000Xooooo`03o`000?oo
oooooooo08[ooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`0Zooooo`00:?ooool0
0ol0003oooooooooo`2:ooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool0:_ooool0
02Sooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo
02[ooooo000Xooooo`03o`000?oooooooooo08[ooooo00?o0000ooooooooool0Poooool00ol0003o
ooooooooo`0Zooooo`009oooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo08?ooooo
00?o0000ooooooooool0:_ooool002Oooooo00?o0000ooooooooool0Roooool00ol0003ooooooooo
o`24ooooo`03o`000?oooooooooo02Wooooo000Wooooo`03o`000?oooooooooo08_ooooo0_l00025
ooooo`03o`000?oooooooooo02Wooooo000Wooooo`03o`000?oooooooooo08_ooooo00?o0000oooo
ooooool0Q?ooool00ol0003oooooooooo`0Yooooo`009oooool00ol0003oooooooooo`2;ooooo`03
o`000?oooooooooo08Gooooo00?o0000ooooooooool0:?ooool002Kooooo00?o0000ooooooooool0
LOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05oiRHV?l@413o0000oc8b
<_o<c<`01_ooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo02Sooooo000Vooooo`03
o`000?oooooooooo077ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@
413o^[ZjoooooomgMgOo<S8b00Kooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`0X
ooooo`009_ooool00ol0003oooooooooo`1aooooo`05oa0@4?ooooooooooooooool@41003oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool09oooool0
02Kooooo00?o0000ooooooooool0LOooool01Ol0003ooooooooooooooooo000000kooooo00?oZJVY
oa0@4?ooool01Oooool3o`0008Kooooo00?o0000ooooooooool09oooool002Gooooo00?o0000oooo
ooooool0L_ooool01Ol0003ooooooooooooooooo000000gooooo00?o410@o`000?nj^[X01_ooool0
0ol0003oooooooooo`26ooooo`03o`000?oooooooooo02Oooooo000Uooooo`03o`000?oooooooooo
07;ooooo00Go410@oooooooooooooooooa0@400>ooooo`03okZj^_lQ8B7ooooo00Gooooo00?o0000
ooooooooool0Qoooool00ol0003oooooooooo`0Vooooo`009Oooool00ol0003oooooooooo`1boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413oV9RHoooooonj^[[o000000Kooooo00?o
0000ooooooooool0Qoooool00ol0003oooooooooo`0Vooooo`009Oooool00ol0003oooooooooo`1b
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo
00?o0000ooooooooool0Qoooool00ol0003oooooooooo`0Vooooo`009?ooool00ol0003ooooooooo
o`2>ooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool09Oooool002Cooooo00?o0000
ooooooooool0S_ooool2o`0008Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0P
ooooo`00]Oooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool08?ooool00;Gooooo00?o0000ooooooooool0ROooool01Ol0003ooooooooooooooooo0000
02;ooooo002eooooo`03o`000?oooooooooo08Wooooo1?l0000Sooooo`00]Oooool00ol0003ooooo
ooooo`2:ooooo`;o00009?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002a
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool009[o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo
00Cooooo00?o0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05
oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol0002`ooooo`00V_ooool01Ol0003o
oooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool00ol0003oooooooooo`2`
ooooo`00V_ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001ooo
ool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l000001oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00V_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000;3ooooo002Jooooo`05
o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
0;3ooooo002Jooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool0
09[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo002_ooooo`03o`000?nj^[[ooooo0;Kooooo
002_ooooo`;o<S8b]oooool0083ooooo0_l000001_l@413oooooooooool@413o0000oa0@41Sooooo
1?l000001Ol@413oooooooooooooooooA4A400;o000000Oo<S8bomgMgOooooooooooohN7Qol0003o
^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1hoooo
o`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l0000<ooooo`03
o`000?oooooooooo00Kooooo00OoMgMgoc8b<_ooooooooooolc<c?l0003o410@00cooooo00Go410@
okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002Oooool01OlQ8B7oV9RHoooooonHV9So8B4Q00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0N?ooool0087o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Jooooo`05o`000?oooooooooooooo
ool000000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
401hooooo`00POooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000<ooooo`03o`00
0?oooooooooo00Kooooo00?oMgMgoc8b<_ooool04?ooool00ol0003oooooooooo`0;ooooo`Ko0000
2Oooool01Olb<S;oV9RHoooooonHV9So<S8b00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool00000N?ooool0087ooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0
000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Aooooo`03o`00
0?oooooooooo01[ooooo00Goc<c<o`000?l0003o0000olc<c003ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000007Sooooo0021ooooo`06o`000?n7QhOoZJVY
okZj^_mEEEGo00006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o
410@o`000?l000000ol0000Iooooo`05oa0@4?nj^[[ooooookZj^_l@41000oooool01Ol@413ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@401hooooo`00POooool01_l0003o
<S8boooooooooooo<S8bo`0001_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo01[ooooo00Go0000okZj^_oooooo^[Zjo`000003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg07Sooooo0020ooooo`03oa0@
4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool00omEEEGoIVIVo`000005ooooo`Co0000
4_ooool00ol0003oooooooooo`0Jooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1hooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(900) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04778 m
.06244 .18325 L
.07216 .23678 L
.08255 .29074 L
.08852 .3154 L
.09135 .32458 L
.09396 .33139 L
.09658 .33649 L
.09795 .33843 L
.09866 .33923 L
.09942 .33993 L
.10069 .34074 L
.10187 .34109 L
.1026 .34111 L
.10329 .34099 L
.10458 .3404 L
.10586 .33935 L
.10707 .33794 L
.10933 .33425 L
.11176 .32877 L
.11439 .32119 L
.1235 .2839 L
.14415 .1726 L
.15446 .12402 L
.16409 .08899 L
.17413 .06236 L
.18515 .04174 L
.19016 .03454 L
.19561 .02795 L
.20041 .02313 L
.20551 .01896 L
.21009 .01602 L
.21252 .01475 L
.21515 .0136 L
.21755 .01274 L
.21975 .01209 L
.22197 .01157 L
.22406 .01118 L
.22526 .01101 L
.22655 .01085 L
.22762 .01075 L
.2288 .01066 L
.23008 .01059 L
.23078 .01056 L
.23144 .01054 L
.23261 .01052 L
.23387 .01051 L
.23504 .01053 L
.23631 .01057 L
.23752 .01062 L
Mistroke
.23863 .01068 L
.24074 .01082 L
.24299 .01102 L
.24568 .01132 L
.24858 .01172 L
.25385 .01268 L
.25898 .01399 L
.26369 .01562 L
.2684 .01776 L
.27345 .02071 L
.28255 .02801 L
.29337 .04032 L
.30323 .05533 L
.31317 .07489 L
.32235 .09776 L
.34312 .16637 L
.35213 .19894 L
.36183 .22966 L
.36738 .2431 L
.36981 .24772 L
.37247 .25177 L
.37369 .25327 L
.37499 .25462 L
.37611 .25556 L
.37733 .25634 L
.37805 .2567 L
.37871 .25694 L
.38001 .25722 L
.38119 .25723 L
.38244 .25699 L
.38366 .2565 L
.38435 .25612 L
.38498 .25571 L
.38739 .25354 L
.38958 .25079 L
.39191 .24708 L
.39673 .23706 L
.40206 .22285 L
.42038 .16024 L
.43058 .1248 L
.44133 .09234 L
.45129 .0682 L
.46055 .05077 L
.46947 .03792 L
.47901 .02756 L
.48959 .01912 L
.49921 .01352 L
.50917 .00931 L
.51837 .00656 L
.52317 .00548 L
Mistroke
.52846 .00452 L
.53395 .00373 L
.53916 .00312 L
.5493 .00223 L
.55858 .00162 L
.56857 .00111 L
.57422 .0009 L
.57947 .00074 L
.58455 .00062 L
.59004 .00053 L
.6 .00041 L
.60963 .0003 L
.61862 .00019 L
.62098 .00017 L
.62321 .00016 L
.62444 .00015 L
.62578 .00014 L
.627 .00014 L
.62813 .00014 L
.62937 .00013 L
.63054 .00014 L
.63182 .00014 L
.63253 .00014 L
.63319 .00014 L
.63444 .00015 L
.63581 .00016 L
.63857 .00018 L
.64425 .00026 L
.64961 .00033 L
.65195 .00036 L
.65442 .00038 L
.65572 .00039 L
.6564 .0004 L
.65714 .0004 L
.65843 .0004 L
.65964 .00041 L
.66095 .0004 L
.66216 .0004 L
.66286 .00039 L
.66349 .00039 L
.6649 .00038 L
.66614 .00036 L
.66748 .00034 L
.6699 .0003 L
.67478 .00017 L
.67926 3e-05 L
Mfstroke
.67926 3e-05 m
.6803 0 L
s
.71941 0 m
.72046 3e-05 L
.72268 8e-05 L
.72506 .00012 L
.72642 .00014 L
.72767 .00016 L
.72892 .00017 L
.7301 .00017 L
.73117 .00018 L
.73231 .00018 L
.73328 .00017 L
.73435 .00017 L
.7355 .00016 L
.73674 .00015 L
.73898 .00012 L
.74137 7e-05 L
.74393 2e-05 L
s
.74393 2e-05 m
.74465 0 L
s
.78666 0 m
.78746 1e-05 L
.78862 2e-05 L
.78986 3e-05 L
.79094 3e-05 L
.79213 4e-05 L
.79321 4e-05 L
.79422 4e-05 L
.79541 3e-05 L
.7965 3e-05 L
.7977 2e-05 L
.79896 0 L
s
.79896 0 m
.79923 0 L
s
.83073 0 m
.83941 .00029 L
.8436 .00043 L
.84581 .00049 L
.84814 .00054 L
.84937 .00056 L
.85073 .00058 L
.85196 .00059 L
.85311 .0006 L
.85429 .0006 L
.85537 .0006 L
.85661 .00059 L
.85778 .00059 L
.85893 .00058 L
.86017 .00056 L
.8624 .00053 L
.86748 .00044 L
.8688 .00042 L
.87023 .00039 L
.8715 .00038 L
.8722 .00037 L
.87285 .00037 L
.87349 .00036 L
.87419 .00036 L
.8754 .00036 L
.87663 .00037 L
.87776 .00038 L
.87883 .00039 L
.87997 .00042 L
.88204 .00048 L
.8833 .00052 L
.88449 .00058 L
.88673 .0007 L
.89127 .00104 L
.8962 .00153 L
.91598 .00425 L
.92597 .00606 L
.93166 .00747 L
.93699 .00922 L
.94169 .01124 L
.94683 .01407 L
.95184 .01756 L
.95718 .02218 L
.96677 .03308 L
.97569 .04687 L
.97619 .04778 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`co00000_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo2Ol00003ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool08?ooool002Cooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo02gooooo00Co0000oooooooooooooooo1_l0000Vooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool07_ooool3o`0000cooooo00?o0000oooooooo
ool08?ooool006;ooooo1Ol0001>ooooo`04o`000?oooooo0000o`00083ooooo0_l0000]ooooo`00
G_ooool5o`0000Cooooo1_l00017ooooo`?o0000Q?ooool3o`0002[ooooo001Mooooo`;o00003_oo
ool2o`0004Cooooo00?o0000ooooool00000R?ooool00ol0003oooooooooo`0Wooooo`00Foooool2
o`0001;ooooo0_l00011ooooo`03o`000?oooooooooo00;o0000R?ooool00ol0003oooooooooo`0V
ooooo`00F_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03gooooo00Go0000oooo
ooooooooooooo`00002:ooooo`03o`000?oooooooooo02Gooooo001Jooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
08Wooooo00?o0000ooooooooool09?ooool005Wooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0R_ooool00ol0003o
ooooooooo`0Sooooo`00F?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo02;ooooo
001Gooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo08_ooooo00?o0000ooooooooool08_ooool005Kooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0S?ooool00ol0003oooooooooo`0Qooooo`00EOooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo03?ooooo00?o0000ooooooooool01_ooool2o`0008gooooo00?o0000oooo
ooooool08Oooool005Gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0SOooool00ol0003oooooooooo`0Pooooo`00
9?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool0
8?ooool002Cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2`ooooo`009?ooool0
0ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo0;3ooooo000Uooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0/?ooool002Gooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool02oooool2o`000;7o
oooo000Uooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0/?ooool002Kooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`2`ooooo`009_ooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo0;3ooooo000Vooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool0/?ooool002Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`2`ooooo`00
9oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0>ooooo`;o0000/Oooool002Oooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`2`ooooo`009oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo0;3ooooo000Xooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/?ooool002So
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Wo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`03o`000?lQ8B7o8B4Q00Gooooo1?l000000ol@
413oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo000Xooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01?ooool00ol0003o8B4Qob4Q8@07ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0/?ooool002Wooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo01Sooooo00Go410@oooooooooooooooooa0@4003ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01Oooool3o`000;3ooooo000Yooooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Hooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0/?ooool002Wooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo01Oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2`ooooo`00:Oooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool05oooool01Ol@413o
oooooooooooooooo410@00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0;3ooooo000Zooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`0Gooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool002[o
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01Ko
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`03o`000?oooooooooo00Oooooo00?oEEEEofIV
I_l000001oooool00ol0003oooooooooo`2`ooooo`00:_ooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo0;3ooooo000[ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01;ooooo0_l0002aooooo`00:ooo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0;3ooooo000[ooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool0/?ooool002_ooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`2`ooooo`00;?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo0;3o
oooo000/ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0/?ooool002cooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool05?ooool2o`000;7ooooo000]ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0/?ooool002gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0foooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2`oooo
o`00;Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03Oooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0;3ooooo000^ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool0/?ooool002kooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`2`ooooo`00;_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo03Sooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Eooooo`;o0000/Oooool0
02kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`2`ooooo`00;oooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo0;3ooooo000_ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool0/?ooool002oooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0jooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`2`ooooo`00<?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo03[ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0;3ooooo000`oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo01Oooooo0_l0002aooooo`00<?ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo03cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo0;3ooooo000`ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
/?ooool0033ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0looooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`2`ooooo`00<Oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool03oooool0
1Ol0003o<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00<Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03gooooo00?o0000
ooooooooool03_ooool01_l0003oMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`2`ooooo`00<Oooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool03_ooool00ol0003o410@
ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003ooooo
ooooo`2`ooooo`00<Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool03Oooool2o`0000?ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^
kP06ooooo`?o0000/?ooool0037ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooool000000oooool00ol0003oooooooooo`0<
ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0/?ooool003;ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ool@41000oooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0/?ooool003;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`10ooooo`03
o`000?oooooooooo00_ooooo00Oo0000oooooomgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000
okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0;3ooooo000booooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0:ooooo`08o`000?oooooo
ooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0
003oooooooooo`2`ooooo`00<_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo0;3o
oooo000booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0@_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo01_ooooo0_l0002aooooo`00<oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo0;3ooooo000cooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0@_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool0/?ooool003?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`13oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`2`oooo
o`00<oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo0;3ooooo000cooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool0/?ooool003?ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07_oo
ool2o`000;7ooooo000dooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0AOooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0/?ooool0
03Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`16ooooo`;o00000oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo0;3ooooo000dooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0Aoooool4o`0002;ooooo00?o0000ooooooooool0/?ooool003Cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo0;3ooooo
000dooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0K_ooool00ol0003ooooooooo
o`2`ooooo`00=Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo06kooooo0_l0002a
ooooo`00=Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo06kooooo00?o0000oooo
ooooool0/?ooool003Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1^ooooo`03
o`000?oooooooooo0;3ooooo000eooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
Koooool00ol0003oooooooooo`2`ooooo`00=Oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo06oooooo00?o0000ooooooooool0/?ooool003Kooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`1_ooooo`03o`000?oooooooooo0;3ooooo000fooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`2`ooooo`00=_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo06oooooo0_l0002aooooo`00=_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0/?ooool003Kooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo0;3ooooo000g
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0EOooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05oiRHV?l@413o0000oc8b<_o<c<`01_ooool00ol0003ooooo
ooooo`2`ooooo`00=oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05Gooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Ko
oooo00?o0000ooooooooool0/?ooool003Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`1Fooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo0;3ooooo000gooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
E_ooool01Ol0003ooooooooooooooooo000000kooooo00?oZJVYoa0@4?ooool01Oooool3o`000;3o
oooo000hooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0E_ooool01Ol0003ooooo
oooooooooooo000000gooooo00?o410@o`000?nj^[X01_ooool00ol0003oooooooooo`2`ooooo`00
>?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Kooooo00Go410@oooooooooooo
oooooa0@400>ooooo`03okZj^_lQ8B7ooooo00Gooooo00?o0000ooooooooool0/?ooool003Sooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Gooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol@413oV9RHoooooonj^[[o000000Kooooo00?o0000ooooooooool0/?ooool003Wo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Gooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0/?ooool0
03Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo
0;3ooooo000iooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Loooool2o`000;7o
oooo000jooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Loooool00ol0003ooooo
ooooo`2`ooooo`00>_ooool01Ol0003ooooooooooooooooo000007Kooooo00?o0000ooooooooool0
/?ooool003_ooooo00Co0000ooooool0003o0000M_ooool00ol0003oooooooooo`2`ooooo`00??oo
ool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`?o
0000/?ooool009[ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`00
00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000ooooooooooooooooo`00000;oooo
o`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0/?ooool0
09[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000
ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003o
oooo00Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0/?ooool009[ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?o
oooo0ol0002`ooooo`00V_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol0003ooooooooooooooooo000000co
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00
00Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00[ooo
ool00ol0003o^[Zjooooo`2fooooo`00[oooool2oc8b<[Oooooo0020ooooo`;o000000Ko410@oooo
oooooooo410@o`000?l@410Hooooo`Co000000Go410@ooooooooooooooooodA4A002o`000007oc8b
<_oMgMgooooooooooon7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool0
1?l@413o0000odA4A?o<c<`4ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^07Sooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1oooool6o`0000cooooo00?o0000ooooooooool01_ooool01omgMgOo<S8booooooooooooc<c<o`00
0?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000;ooooo`03oiRHV?l@413o
gMgM00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
N?ooool0087ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Mooooo`03ohN7QomE
EEGooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
4100N?ooool0087ooooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00003?ooool00ol0
003oooooooooo`06ooooo`03ogMgMolb<S;ooooo013ooooo00?o0000ooooooooool02oooool6o`00
00Wooooo00Goc<c<ob4Q8Ol0003oEEEEo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000007Sooooo0021ooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo
00006oooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`04Oooool00ol0
003oooooooooo`0Jooooo`05ob4Q8On7QhOooooooiRHV?l000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`00001hooooo`00POooool01_l0003oQhN7ojVY
ZOnj^[[oEEEEo`0001_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03
oa0@4?l0003o000000?o00006Oooool01Ol0003ooooooooooooooooo000000?ooooo00Go410@oooo
oooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100N?ooool0087ooooo00Ko0000
oc8b<_oooooooooooc8b<_l0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0Jooooo`05ob4Q8OnHV9SoooooogMgMomEEED00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1hooooo`00P?ooool00ol@
413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo00?oEEEEofIVI_l000001Oooool4o`00
01;ooooo00?o0000ooooooooool06_ooool01Oo<c<co410@o`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0N?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1000) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .00105 m
.03279 .00186 L
.04262 .0031 L
.053 .00462 L
.06244 .00633 L
.06786 .00769 L
.07298 .00941 L
.07839 .01185 L
.08426 .01539 L
.08939 .01936 L
.09482 .02456 L
.10458 .03668 L
.11399 .05252 L
.12411 .07591 L
.13367 .1064 L
.14241 .14287 L
.16301 .25229 L
.16817 .27922 L
.17303 .30168 L
.17777 .31954 L
.17984 .32584 L
.18212 .33155 L
.1832 .3338 L
.18436 .33586 L
.18536 .33735 L
.18644 .33866 L
.18767 .33975 L
.18883 .34039 L
.18996 .34064 L
.191 .34056 L
.19215 .34011 L
.19322 .33936 L
.19439 .33817 L
.19566 .33646 L
.19824 .33163 L
.20061 .3257 L
.20519 .3105 L
.21021 .28913 L
.22032 .23669 L
.23125 .1771 L
.24157 .12798 L
.25083 .09334 L
.26088 .06564 L
.27075 .04631 L
.27572 .03882 L
.28119 .03203 L
.28586 .02729 L
.29087 .02321 L
.2956 .02024 L
.29992 .01824 L
Mistroke
.30243 .01737 L
.3047 .01675 L
.30596 .01647 L
.30733 .01622 L
.3085 .01605 L
.30979 .0159 L
.31099 .01581 L
.31211 .01575 L
.3133 .01572 L
.31456 .01572 L
.31574 .01576 L
.31686 .01583 L
.31786 .01591 L
.31895 .01602 L
.32143 .01636 L
.32418 .01689 L
.32704 .01759 L
.32972 .01839 L
.33452 .02019 L
.33968 .02271 L
.34466 .02582 L
.34928 .02939 L
.35478 .03466 L
.35976 .0405 L
.36998 .0561 L
.38088 .07873 L
.4001 .13438 L
.41002 .16913 L
.42091 .20737 L
.42588 .22305 L
.43121 .23748 L
.43379 .24332 L
.43623 .24805 L
.43842 .25154 L
.44082 .25456 L
.44213 .25582 L
.44336 .25674 L
.44466 .25744 L
.44539 .25772 L
.44606 .25789 L
.44719 .258 L
.44842 .25788 L
.44971 .25749 L
.45091 .25686 L
.45159 .2564 L
.45233 .25581 L
.45368 .2545 L
.45621 .25126 L
.45916 .24624 L
.46188 .2405 L
Mistroke
.47156 .21311 L
.48062 .18135 L
.50125 .11001 L
.51164 .08171 L
.52151 .06047 L
.53038 .04549 L
.54004 .03284 L
.55037 .02291 L
.55973 .01651 L
.56492 .0138 L
.57054 .01139 L
.58071 .00801 L
.59022 .00564 L
.60066 .00372 L
.60592 .00303 L
.60882 .00273 L
.61156 .00248 L
.61411 .0023 L
.61688 .00213 L
.62173 .0019 L
.63107 .0016 L
.64113 .00122 L
.65217 .00064 L
.65712 .00037 L
.65974 .00025 L
.66253 .00013 L
.66525 5e-05 L
Mfstroke
.66525 5e-05 m
.66719 0 L
s
.67968 0 m
.6804 1e-05 L
.68303 6e-05 L
.68739 .00016 L
.68978 .00021 L
.69202 .00025 L
.69331 .00027 L
.69398 .00028 L
.69469 .00028 L
.69595 .00029 L
.69711 .0003 L
.69827 .0003 L
.69936 .00029 L
.70055 .00029 L
.70182 .00027 L
.71146 4e-05 L
s
.71146 4e-05 m
.71249 0 L
s
.74954 0 m
.75397 .00016 L
.75653 .00023 L
.75793 .00026 L
.75925 .00029 L
.76046 .00031 L
.76157 .00032 L
.7628 .00033 L
.76345 .00034 L
.76413 .00034 L
.76532 .00034 L
.76641 .00034 L
.76766 .00033 L
.76884 .00032 L
.76993 .00031 L
.77094 .0003 L
.77322 .00026 L
.77802 .00015 L
.78317 2e-05 L
s
.78317 2e-05 m
.78405 0 L
s
.80845 0 m
.80929 1e-05 L
.81177 4e-05 L
.81317 6e-05 L
.81391 6e-05 L
.81469 7e-05 L
.81535 7e-05 L
.81607 8e-05 L
.81735 8e-05 L
.81865 8e-05 L
.81937 8e-05 L
.82004 8e-05 L
.82127 7e-05 L
.82256 5e-05 L
s
.82256 5e-05 m
.82498 0 L
s
.87239 0 m
.87279 1e-05 L
.87549 9e-05 L
.8768 .00012 L
.87803 .00015 L
.87916 .00017 L
.88035 .00018 L
.88165 .00019 L
.88285 .0002 L
.88414 .0002 L
.88488 .00019 L
.88557 .00019 L
.8863 .00018 L
.887 .00018 L
.88832 .00016 L
.88973 .00013 L
.89128 .0001 L
s
.89128 .0001 m
.89459 0 L
s
.92618 0 m
.93108 .00021 L
.93638 .00043 L
.93927 .00053 L
.94196 .00061 L
.94409 .00065 L
.94528 .00067 L
.94636 .00068 L
.94755 .00069 L
.94884 .00069 L
.95005 .00069 L
.95117 .00069 L
.95218 .00069 L
.95313 .00068 L
.95528 .00067 L
.9575 .00065 L
.9586 .00065 L
.95962 .00064 L
.96059 .00064 L
.96162 .00063 L
.96276 .00063 L
.96379 .00064 L
.96474 .00064 L
.96576 .00065 L
.96672 .00067 L
.96761 .00068 L
.9696 .00073 L
.97073 .00077 L
.97178 .00081 L
.97619 .00105 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`06o`0000?ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`02oooooa3o00000oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool08?ooool002Cooooo00?o0000ooooooooool0
1_ooool5o`0002?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo01Oooooo0ol0000Cooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0Pooooo`00<_ooool3o`00083ooooo00?o0000ooooooooool05?oo
ool3o`0009Wooooo000eooooo`;o0000O_ooool00ol0003oooooooooo`0@ooooo`Co0000W?ooool0
03Oooooo00?o0000ooooooooool0?oooool8o`0003Cooooo00?o0000ooooooooool03_ooool2o`00
0:3ooooo000hooooo`03o`000?oooooooooo03_ooooo0ol00007ooooo`Co0000<Oooool2o`0000ko
oooo00?o0000ooooooooool0X?ooool003Wooooo00?o0000ooooooooool0>Oooool00ol0003ooooo
ooooo`0<ooooo`;o0000;oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0:7ooooo
000jooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0X_ooool003_ooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02_ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`2Sooooo`00??ooool00ol0003oooooooooo`0coooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo0:Cooooo000mooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0Y?ooool003gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Uooooo`00?_oo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0:?oo
ool2o`0000Sooooo00?o0000ooooooooool0Y_ooool003oooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`2Wooooo`00?oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
0:Oooooo0010ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Z?ooool0043ooooo
00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Yooooo`00@Oooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo0:Wooooo0011ooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0Tooooo`;o00001?ooool00ol0003oooooooooo`2Z
ooooo`00@_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0:[ooooo0012ooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0Zoooool004;ooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`2[ooooo`00@oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool08_ooool01Ol0003ooooooooooooooooo00000:kooooo
0013ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`0Qooooo`05o`000?ooooooooooooooool00000[_ooool004Cooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo027ooooo0_l000000ooooooo0000oooo
o`2^ooooo`00A?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool08?ooool01?l0003oooooooooool0002_ooooo`00A?ooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool08?ooool00ol0003oooooo`00002`
ooooo`00AOooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool08?ooool00ol0003oooooo`00002`ooooo`00AOooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool01?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooo`00002`oooo
o`00AOooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo
00Gooooo0_l0002aooooo`00A_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000oooo
ooooool01Oooool3o`000;3ooooo0016ooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000003_ooool00ol0
003oooooooooo`05ooooo`;o0000/Oooool004Kooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00000>oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool004Kooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00?ooooo00Go410@oooooooo
oooooooooa0@400>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool004Ko
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0/?ooool004Oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo0000
00Oooooo00?o0000ooooooooool0/?ooool004Oooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0[ooooo`03o`000?oooooooooo01cooooo0_l0002booooo`00Aoooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool06oooool3o`000;7ooooo
0017ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`0Kooooo`;o0000/_ooool004Oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooool00000/_ooool004Oooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ool00000/_ooool004Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooool00000/_ooool004Sooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooool00000
/_ooool004Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool00_l0002aooooo`00B?ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool05oooool01?l0003oooooooooool0
002booooo`00B?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool05oooool01?l0003oooooooooool0002booooo`00BOooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool05Oooool01Ol0003ooooooooooooo
oooo00000;;ooooo0019ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`0Eooooo`05o`000?ooooooooooooooool00000/_ooool004Wooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Gooooo00Go0000
ooooooooooooooooo`00002booooo`00BOooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool05?ooool01?l0003oooooooooooooool2o`000;7ooooo0019
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0/?ooool004[ooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`2`ooooo`00B_ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo03Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo0;3ooooo001:ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
/?ooool004[ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2`ooooo`00B_ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`03ooooo`;o0000/Oooool004_ooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`2`ooooo`00Boooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;3o
oooo001;ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0/?ooool004_ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0;3ooooo001<ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0=Oooool01OmgMgOoV9RHo`000?nHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^o`000?m4A4@01_ooool00ol0003oooooooooo`2`ooooo`00
C?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03Gooooo00Go410@oooooooooooo
0000oa0@400<ooooo`03oiRHV?lQ8B7o000000Oooooo00?o0000ooooooooool0/?ooool004cooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00;o0000
3Oooool00onHV9So0000onk^kP06ooooo`?o0000/?ooool004cooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00;o00003Oooool00ol0003oMgMgofIV
IP06ooooo`03o`000?oooooooooo0;3ooooo001<ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0=_ooool01Ol@413oooooooooool0003o410@00gooooo00?o0000ooooool000001_oo
ool00ol0003oooooooooo`2`ooooo`00COooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo03Kooooo00GoMgMgoiRHV?ooooooV9RHo`00000;ooooo`05o`000?nj^[[o0000oiRHV?l@4100
1_ooool00ol0003oooooooooo`2`ooooo`00COooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo03Kooooo00Gok^k^oc8b<_l0003o<S8bo`00000;ooooo`05oiRHV?l0003o0000ob4Q8Oo<
c<`01_ooool00ol0003oooooooooo`2`ooooo`00COooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo03[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0;3ooooo001=ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0>_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo0_l0002aooooo`00COooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo0;3ooooo001>ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0/?ooool004kooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0mooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`2`ooooo`00C_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0;3ooooo
001>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0?_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0/?ooool004kooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool02_ooool2o`000;7ooooo001?ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool0@?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0/?ooool004oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`11ooooo`05
o`000?ooooooooooooooool000003Oooool00ol0003oooooooooo`2`ooooo`00Coooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo047ooooo1?l0000>ooooo`03o`000?oooooooooo0;3o
oooo001?ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0Doooool00ol0003ooooo
ooooo`2`ooooo`00Coooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo05?ooooo00?o
0000ooooooooool0/?ooool004oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1D
ooooo`;o0000/Oooool0053ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Doooo
o`03o`000?oooooooooo0;3ooooo001@ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0E?ooool00ol0003oooooooooo`2`ooooo`00D?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo05Cooooo00?o0000ooooooooool0/?ooool0053ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo0;3ooooo001@ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`2`ooooo`00D?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0/?ooool0057o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Eooooo`;o0000/Oooool0057ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo0;3ooooo
001Aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0E_ooool00ol0003ooooooooo
o`2`ooooo`00D_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03_ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Kooooo
00?o0000ooooooooool0/?ooool005;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0kooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go410@okZj^_oooooo
MgMgoc8b<P06ooooo`03o`000?oooooooooo0;3ooooo001Booooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0??ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`2`ooooo`00D_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo03cooooo00Go0000ooooooooooooooooo`00000>ooooo`03ojVYZOl@413ooooo00Go
oooo0ol0002`ooooo`00Doooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03cooooo
00Go0000ooooooooooooooooo`00000=ooooo`03oa0@4?l0003o^[Zj00Kooooo00?o0000oooooooo
ool0/?ooool005?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0looooo`05oa0@
4?ooooooooooooooool@41003_ooool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo0;3o
oooo001Cooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0?Oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooooooo
0;3ooooo001Cooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0?Oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooo
oooo0;3ooooo001Dooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0F?ooool00ol0
003oooooooooo`2`ooooo`00E?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05So
oooo0_l0002aooooo`00E?ooool2o`0000?ooooo00?o0000ooooooooool0FOooool00ol0003ooooo
ooooo`2`ooooo`00EOooool01Ol0003ooooooooooooooooo000005_ooooo00?o0000ooooooooool0
/?ooool005Gooooo1?l0001Looooo`03o`000?oooooooooo0;3ooooo001Gooooo`03o`000?oooooo
oooo05_ooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@
4?oooooooooo00Cooooo00?o0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;3ooooo
002Jooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol0002`ooooo`00V_oo
ool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`2`ooooo`00V_ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoo
oooo00001oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@
00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`oooo
o`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0
003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002a
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8b
omgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00V_oo
ool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000;3ooooo
002Jooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aoooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002/ooooo`03o`000?nj^[[o
oooo0;Wooooo002/ooooo`;o<S8b^_ooool007gooooo0_l000001_l@413oooooooooool@413o0000
oa0@41Sooooo1?l000001Ol@413oooooooooooooooooA4A400;o000000Oo<S8bomgMgOoooooooooo
ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Iooooo`Co000000So410@oooo
ooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h0Loooool007kooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`07ooooo`Ko00003?ooool00ol0003oooooooooo`06ooooo`07ogMgMolb<S;ooooooooo
ooo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000cooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Loooool007kooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooo
oooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@07?ooooo001nooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000cooooo
00?o0000ooooooooool01_ooool00omgMgOo<S8booooo`0@ooooo`03o`000?oooooooooo00_ooooo
1_l0000<ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000007?ooooo001noooo
o`06o`000?oMgMgo<S8boeEEEOoMgMgo00006oooool00ol0003oooooooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`04Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000007?ooooo001nooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo00006ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o410@o`000?l000000ol0
000Looooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@
4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@07?ooooo001nooooo`06
o`000?lb<S;ooooooooooolb<S;o00006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`1cooooo`00OOooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo
00?oEEEEofIVI_l000001Oooool4o`0001;ooooo00?o0000ooooooooool06oooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1cooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1100) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .00013 m
.02846 0 L
s
.02846 0 m
.02849 0 L
s
.05407 0 m
.06244 .00033 L
.0653 .00044 L
.06799 .00053 L
.07041 .00058 L
.07177 .00061 L
.07302 .00062 L
.07367 .00063 L
.07437 .00064 L
.07563 .00064 L
.0764 .00064 L
.07713 .00064 L
.07779 .00063 L
.0785 .00063 L
.0792 .00062 L
.07996 .00061 L
.08151 .00059 L
.08429 .00053 L
.08933 .0004 L
.09197 .00034 L
.09342 .00032 L
.09412 .00031 L
.09476 .0003 L
.09594 .00029 L
.0972 .00028 L
.09787 .00028 L
.09858 .00028 L
.09988 .0003 L
.10107 .00032 L
.10233 .00035 L
.1034 .00038 L
.10458 .00043 L
.10707 .00056 L
.10979 .00075 L
.11474 .00123 L
.12403 .00246 L
.13499 .00412 L
.14492 .00569 L
.1498 .00661 L
.15508 .00786 L
.16006 .00944 L
.16463 .01134 L
.1695 .01395 L
.17484 .01762 L
.18038 .0224 L
.18562 .02794 L
.19585 .04198 L
.20517 .05955 L
.2152 .08571 L
.22609 .12537 L
Mistroke
.24552 .22361 L
.25583 .27829 L
.26124 .30266 L
.26419 .31382 L
.26693 .32257 L
.26958 .32939 L
.27199 .33404 L
.27337 .33602 L
.27467 .33742 L
.27538 .33799 L
.27604 .3384 L
.27676 .3387 L
.27752 .33887 L
.27867 .33882 L
.27991 .33835 L
.28108 .33752 L
.28214 .33644 L
.28339 .33479 L
.28475 .33252 L
.28722 .32717 L
.29201 .31267 L
.2971 .29213 L
.30625 .24628 L
.31582 .19399 L
.32592 .14323 L
.33526 .10507 L
.34396 .07812 L
.35319 .05738 L
.35807 .049 L
.36329 .04163 L
.3689 .03525 L
.37421 .03053 L
.37897 .02732 L
.38166 .02592 L
.38414 .02489 L
.38538 .02447 L
.38657 .02413 L
.38765 .02387 L
.3888 .02365 L
.39004 .02346 L
.3912 .02335 L
.3919 .02331 L
.39257 .02329 L
.39381 .02329 L
.39492 .02335 L
.39608 .02346 L
.39708 .0236 L
.39817 .02379 L
.4006 .02439 L
.40288 .02515 L
Mistroke
.40809 .0276 L
.41284 .03067 L
.41801 .03489 L
.42351 .04041 L
.43343 .05339 L
.44261 .06961 L
.45248 .09256 L
.46337 .12487 L
.48436 .19887 L
.49355 .22787 L
.49875 .24089 L
.50124 .24597 L
.50359 .24998 L
.50589 .25312 L
.5071 .25446 L
.50837 .25563 L
.50945 .25641 L
.51063 .25706 L
.51171 .25745 L
.51272 .25764 L
.51398 .25766 L
.51517 .25743 L
.51624 .25703 L
.51741 .25638 L
.51868 .25542 L
.52003 .25412 L
.52246 .25108 L
.52504 .24687 L
.52782 .24127 L
.53287 .22865 L
.5423 .19864 L
.5619 .12849 L
.57228 .09657 L
.58338 .06952 L
.5941 .04973 L
.60385 .03594 L
.61366 .02528 L
.62294 .01779 L
.62755 .01493 L
.63263 .01238 L
.63793 .0103 L
.6429 .00879 L
.65178 .00681 L
.66134 .0052 L
.67144 .00366 L
.67677 .0029 L
.68246 .00218 L
.68793 .00161 L
.69288 .00123 L
.69527 .0011 L
Mistroke
.69786 .00098 L
.7003 .0009 L
.70255 .00084 L
.7124 .00075 L
.715 .00074 L
.71637 .00073 L
.71782 .00072 L
.72049 .00069 L
.72296 .00065 L
.72541 .00061 L
.7277 .00055 L
.73293 .0004 L
.74203 .00012 L
.74443 5e-05 L
.74667 0 L
Mfstroke
.74667 0 m
.74689 0 L
s
.76269 0 m
.76971 .00011 L
.77229 .00015 L
.77371 .00017 L
.77504 .00018 L
.77629 .00019 L
.77699 .00019 L
.77764 .0002 L
.77878 .0002 L
.77999 .0002 L
.78123 .00019 L
.78192 .00019 L
.78255 .00018 L
.78378 .00017 L
.78495 .00015 L
.78755 .0001 L
.79039 4e-05 L
s
.79039 4e-05 m
.79162 0 L
s
.83403 0 m
.83631 5e-05 L
.8387 .0001 L
.83991 .00012 L
.8412 .00013 L
.84249 .00014 L
.84322 .00014 L
.84391 .00014 L
.84515 .00014 L
.84629 .00014 L
.84754 .00013 L
.84886 .00011 L
.85016 9e-05 L
.85155 7e-05 L
.85406 1e-05 L
s
.85406 1e-05 m
.85458 0 L
s
.89415 0 m
.89624 5e-05 L
.8988 .00011 L
.89996 .00013 L
.90121 .00015 L
.90245 .00016 L
.90359 .00017 L
.90487 .00018 L
.90551 .00018 L
.90622 .00018 L
.90693 .00018 L
.90758 .00018 L
.90833 .00017 L
.90904 .00017 L
.9103 .00015 L
.91166 .00014 L
.91417 9e-05 L
.91682 3e-05 L
s
.91682 3e-05 m
.91804 0 L
s
.96413 0 m
.97619 .00013 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00Co0000oooooooooooooooo2_l0000;ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[o00002oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Pooooo`009?ooool00ol0003oooooooooo`0Rooooo`?o00002Oooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0:_ooool6o`0002go
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Pooooo`00C?ooool3o`0006Kooooo
00?o0000ooooooooool09_ooool4o`0008Kooooo001?ooooo`?o0000Hoooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo08Sooooo001Aooooo`03o`000?oooooooooo067ooooo00?o0000
ooooooooool08oooool2o`0008_ooooo001Booooo`;o0000HOooool2o`0002;ooooo0_l0002=oooo
o`00E?ooool00ol0003oooooooooo`0kooooo`Go00007_ooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo08gooooo001Dooooo`03o`000?oooooooooo03Wooooo0ol00004ooooo`;o0000
7?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo08kooooo001Eooooo`03o`000?oo
oooooooo03Oooooo00?o0000ooooooooool01oooool2o`0001[ooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`2?ooooo`00E_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo093ooooo001Gooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool03?ooool2o`00
01Oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`2Aooooo`00F?ooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo097ooooo001Iooooo`03o`000?oooooooooo02oooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Dooooo`;o00007?ooool00ol0003ooooo
ooooo`2Booooo`00FOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo09?ooooo001J
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0U?ooool005[ooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`2Dooooo`00F_ooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo09Gooooo001Kooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
UOooool005_ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo013ooooo0_l0000Hooooo`03o`000?oooooooooo09Kooooo001Looooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool0U_ooool005cooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`2Gooooo`00G?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo09Oo
oooo001Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0V?ooool005gooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`2Hooooo`00GOooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool03Oooool2o`0001Kooooo00?o0000
ooooooooool0V?ooool005kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2Ioooo
o`00G_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo09Wooooo001Oooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0VOooool005oooooo00?o0000ooooooooool08_oo
ool00ol0003oooooooooo`0Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@03o`00
0?oooooooooo00;ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0V_ooool005oooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`0Cooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@03ooooool0003ooooo00Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo09[ooooo
001Pooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool04oooool01Ol@413ooooooooo
oooooooo410@00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`?o0000
4oooool00ol0003oooooooooo`2Jooooo`00H?ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo01Cooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo09_ooooo
001Pooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool05?ooool01Ol0003ooooooooo
oooooooo000000Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0Voooool0067ooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`0Dooooo`05oa0@4?ooooooooooooooool@41002Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`2Kooooo`00HOooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Gooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0:ooooo`05o`000?ooooooooooooooool000001oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo09cooooo001Qooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool05Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00[ooooo00Go0000oooooomE
EEGoIVIVo`000007ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0W?ooool006;o
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`2Looooo`00H_ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool02?ooool2o`00017ooooo
00?o0000ooooooooool0WOooool006;ooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`2Mooooo`00H_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo09gooooo001Soooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0WOooool006?ooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`2Nooooo`00Hoooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo09kooooo001Sooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`07ooooo`;o00004?ooool00ol0003oooooooooo`2Nooooo`00Hoooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo09oooooo001Tooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0Woooool006Cooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`2Oooooo`00I?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02[ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo09oooooo
001Tooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0:oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0X?ooool006Cooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Gooooo0_l0000>
ooooo`03o`000?oooooooooo0:3ooooo001Uooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool0X?ooool006Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`2Qooooo`00
IOooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0:7ooooo001Uooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0XOooool006Gooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`2Qooooo`00I_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool00oooool2o`0000cooooo00?o0000ooooooooool0X_ooool006Ko
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2Rooooo`00I_ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo0:;ooooo001Vooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0Xoooool006Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0J
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol000000ooooooo0000oooo
o`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Xoooool006Oooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Cooooo00OoV9RHob4Q8Oo^k^koooooodA4A?oooooo000000Cooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`2Sooooo`00Ioooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo01[ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0:?o
oooo001Wooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool06oooool01Ol0003ooooo
oooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h00_ooool01?l0003oooooooooooooool3o`00
00Wooooo00?o0000ooooooooool0Y?ooool006Oooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Kooooo`05o`000?ooooooooooooooool000003_ooool01OmgMgOoIVIVoooooooooooo
000000?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Tooooo`00Ioooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo01_ooooo00Go410@oooooooooooooooooa0@400?
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`2Tooooo`00J?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01_ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01?l0003ooooo
ooooool0000:ooooo`03o`000?oooooooooo0:Gooooo001Xooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool06oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c003ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool0YOooool0
06Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0dooooo`04o`000?oooooooooo
o`0000[ooooo00?o0000ooooooooool0YOooool006Sooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0eooooo`04o`000?oooooo0000o`0000Sooooo00?o0000ooooooooool0Y_ooool0
06Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooo0000
00Wooooo00?o0000ooooooooool0Y_ooool006Sooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool0Y_ooool006Wooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0fooooo`;o00002?ooool00ol0003ooooo
ooooo`2Wooooo`00JOooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Oooooo0_l0
0007ooooo`03o`000?oooooooooo0:Sooooo001Yooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool0=oooool2o`0000Oooooo00?o0000ooooooooool0Z?ooool006Wooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0hooooo`;o00001Oooool00ol0003oooooooooo`2Yoooo
o`00JOooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Sooooo0_l00005ooooo`03
o`000?oooooooooo0:Wooooo001Zooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
>?ooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo0:[ooooo001Zooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0>Oooool00ol0003oooooo`000004o`000:cooooo001Z
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`2`
ooooo`00J_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool0/?ooool006[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0iooooo`;o
0000/Oooool006[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0iooooo`03o`00
0?oooooooooo0;3ooooo001[ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>_oo
ool00ol0003oooooooooo`2`ooooo`00Joooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool0/?ooool006_ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0jooooo`03o`000?oooooooooo0;3ooooo001[ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`2`ooooo`00Joooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0/?ooool006_ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0kooooo`;o0000/Oooool006cooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;3ooooo001/oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2`oooo
o`00K?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo023ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Kooooo00?o0000
ooooooooool0/?ooool006cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Poooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go410@okZj^_ooooooMgMgoc8b
<P06ooooo`03o`000?oooooooooo0;3ooooo001/ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool08Oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`2`ooooo`00KOooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo027ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ojVYZOl@413ooooo00Gooooo0ol0
002`ooooo`00KOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo027ooooo00Go0000
ooooooooooooooooo`00000=ooooo`03oa0@4?l0003o^[Zj00Kooooo00?o0000ooooooooool0/?oo
ool006gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Qooooo`05oa0@4?oooooo
ooooooooool@41003_ooool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo0;3ooooo001^
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool08_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0;3ooooo
001^ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool08_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo0;3o
oooo001^ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`2`ooooo`00Koooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03kooooo0_l0
002aooooo`00Koooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03kooooo00?o0000
ooooooooool0/?ooool0073ooooo00Co0000oooooooooooo0000@Oooool00ol0003oooooooooo`2`
ooooo`00LOooool2o`0004;ooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000
ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?oooooooooo
ooooool@41002oooool5o`0000Kooooo0ol0002`ooooo`00V_ooool01Ol0003ooooooooooooooooo
000000_ooooo00CoA4A4omgMgOoooooo00001oooool00ol0003oooooooooo`2`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003ooooo
ooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000
1oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo
00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo
410@013ooooo00?o0000ooooooooool00oooool3o`000;3ooooo002Jooooo`05o`000?oooooooooo
ooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Joooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo002/ooooo`03o`000?nj^[[ooooo0;Wooooo002/ooooo`;o<S8b
^_ooool007gooooo0_l000001_l@413oooooooooool@413o0000oa0@41Sooooo1?l000001Ol@413o
ooooooooooooooooA4A400;o000000Oo<S8bomgMgOooooooooooohN7Qol0003o^[Zj00cooooo00Go
V9RHo`000?l0003oA4A4okZj^P0Iooooo`Co000000Co410@oooooooooooooooo1?l000002?l@413o
ooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07?ooooo
001nooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`0000cooooo00?o
0000ooooooooool01_ooool01omgMgOo<S8booooooooooooc<c<o`000?l@41003?ooool01Ol@413o
^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`1cooooo`00O_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@07?ooooo001nooooo`06o`000?ooooooA4A4odA4A?oooooo
00002Oooool6o`0000cooooo00?o0000ooooooooool01_ooool00omgMgOo<S8booooo`0@ooooo`03
o`000?oooooooooo00_ooooo1_l0000<ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00001c
ooooo`00O_ooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001_ooooo00?o0000ooooooooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<017ooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool00000Loooool007kooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000K
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol@413o0000o`000003
o`0001cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41000oooool01Ol@413ooooooooooooooooo410@07?ooooo001nooooo`06o`000?lb
<S;ooooooooooolb<S;o00006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Loooool0
07gooooo00?o410@o`000?n7QhL00_ooool00on7QhOo0000oa0@400Hooooo`03oeEEEOmVIVKo0000
00Gooooo1?l0000Booooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000001Oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^07?ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1200) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 6e-05 m
.02846 .00016 L
.03068 .00019 L
.03279 .00022 L
.03398 .00023 L
.03527 .00024 L
.03645 .00025 L
.03754 .00026 L
.03871 .00026 L
.04 .00026 L
.04065 .00025 L
.04135 .00025 L
.04262 .00024 L
.04393 .00023 L
.04516 .00021 L
.04793 .00017 L
.05297 6e-05 L
s
.05297 6e-05 m
.0553 0 L
s
.08954 0 m
.09418 .00012 L
.09658 .00017 L
.09915 .00022 L
.10062 .00024 L
.10196 .00026 L
.10261 .00026 L
.10331 .00027 L
.10458 .00028 L
.10578 .00028 L
.10691 .00028 L
.10814 .00028 L
.10884 .00027 L
.10947 .00027 L
.11074 .00026 L
.11212 .00025 L
.11465 .00022 L
.12393 7e-05 L
.12663 3e-05 L
.12795 2e-05 L
.12917 0 L
s
.12917 0 m
.12975 0 L
s
.13681 0 m
.13745 1e-05 L
.14 3e-05 L
.14232 7e-05 L
.14478 .00011 L
.15418 .00031 L
.15675 .00036 L
.15815 .00038 L
.15946 .0004 L
.16067 .00041 L
.16177 .00042 L
.16299 .00043 L
.16429 .00044 L
.16544 .00044 L
.16665 .00044 L
.16768 .00044 L
.16881 .00043 L
.17003 .00043 L
.17134 .00042 L
.17371 .0004 L
.17609 .00038 L
.17726 .00037 L
.17835 .00037 L
.17933 .00036 L
.18038 .00036 L
.18143 .00036 L
.18259 .00036 L
.1838 .00036 L
.18493 .00037 L
.18617 .00039 L
.18749 .00041 L
.18888 .00044 L
.1902 .00048 L
.19266 .00057 L
.19497 .00069 L
.1971 .00082 L
.20191 .00119 L
.21203 .00231 L
.22276 .00381 L
.23218 .0054 L
.23747 .00654 L
.24231 .00787 L
.2468 .00943 L
.25169 .0116 L
.26061 .01714 L
.26593 .02159 L
.27094 .02665 L
.2803 .03869 L
.29038 .05638 L
.30128 .0833 L
Mistroke
.31079 .11574 L
.32123 .16204 L
.33225 .21993 L
.3423 .27269 L
.3471 .29473 L
.35233 .31438 L
.35472 .32151 L
.35726 .32762 L
.35943 .33156 L
.36067 .33325 L
.36182 .33447 L
.36305 .33537 L
.36374 .33569 L
.36438 .33588 L
.36569 .33591 L
.36642 .33572 L
.36708 .33543 L
.36827 .3346 L
.36956 .33327 L
.37077 .3316 L
.37189 .32973 L
.37441 .32437 L
.37717 .31673 L
.38274 .29638 L
.40384 .18926 L
.41384 .14113 L
.4231 .10539 L
.43264 .07805 L
.43768 .06698 L
.44304 .05733 L
.44815 .04989 L
.45296 .04432 L
.45728 .04043 L
.45973 .03869 L
.46195 .03739 L
.46433 .0363 L
.46565 .03584 L
.46689 .03549 L
.46803 .03525 L
.46909 .03509 L
.47026 .03499 L
.47149 .03496 L
.47272 .03502 L
.47342 .03509 L
.47406 .03518 L
.47529 .03542 L
.47646 .03573 L
.47908 .03668 L
.48194 .03815 L
.48723 .042 L
Mistroke
.49287 .04765 L
.50302 .06169 L
.5133 .08119 L
.52443 .10922 L
.54459 .17724 L
.5549 .21379 L
.55993 .22945 L
.56452 .24149 L
.56937 .25125 L
.57203 .25514 L
.57324 .25652 L
.57456 .25777 L
.57589 .25873 L
.57662 .25914 L
.5773 .25943 L
.57852 .25976 L
.57984 .25984 L
.58054 .25976 L
.5813 .25958 L
.5821 .25928 L
.58284 .25891 L
.58416 .25802 L
.58558 .25675 L
.58817 .25361 L
.59091 .24917 L
.59582 .23862 L
.60692 .20542 L
.62707 .13368 L
.6365 .10361 L
.64663 .07671 L
.6562 .0567 L
.66494 .04254 L
.67481 .03051 L
.68396 .0223 L
.694 .01574 L
.69957 .01295 L
.70469 .01081 L
.715 .00748 L
.72042 .00614 L
.72614 .00496 L
.73576 .00343 L
.74632 .0022 L
.75157 .00173 L
.75654 .00135 L
.76106 .00107 L
.76585 .00082 L
.76833 .00072 L
.77107 .00062 L
.77358 .00055 L
.77588 .0005 L
Mistroke
.77859 .00045 L
.78001 .00043 L
.78151 .00041 L
.78281 .0004 L
.78403 .00039 L
.78536 .00039 L
.7861 .00039 L
.78678 .00038 L
.78798 .00038 L
.7891 .00038 L
.79032 .00038 L
.79164 .00038 L
.79428 .00039 L
.79558 .00039 L
.79678 .00039 L
.7979 .00039 L
.79909 .00039 L
.80028 .00039 L
.8016 .00039 L
.80269 .00039 L
.80386 .00038 L
.80497 .00037 L
.80599 .00037 L
.8085 .00034 L
.81083 .00032 L
.81612 .00022 L
Mfstroke
.81612 .00022 m
.82582 0 L
s
.86615 0 m
.86822 3e-05 L
.8705 5e-05 L
.87177 6e-05 L
.87243 6e-05 L
.87314 6e-05 L
.87439 7e-05 L
.87554 7e-05 L
.87661 7e-05 L
.87777 7e-05 L
.87886 7e-05 L
.87986 7e-05 L
.88097 6e-05 L
.88219 5e-05 L
.88463 4e-05 L
s
.88463 4e-05 m
.88824 0 L
s
.97285 0 m
.97619 6e-05 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;o
oooo2_l00009ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`07ooooo`Wo00001Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool08?ooool002Cooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0<ooooo`?o00007_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool03Oooool6o`0001[ooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`0Pooooo`00Ioooool3o`0004_ooooo00?o0000ooooooooool0>_ooool3o`0007?ooooo001Z
ooooo`;o0000BOooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo07Cooooo001/oooo
o`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0=oooool2o`0007Oooooo001]ooooo`03
o`000?oooooooooo04Gooooo0_l0000gooooo`03o`000?oooooooooo07Oooooo001^ooooo`03o`00
0?oooooooooo04Cooooo00?o0000ooooooooool0=?ooool2o`0007[ooooo001_ooooo`03o`000?oo
oooooooo04?ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`1jooooo`00Koooool0
0ol0003oooooooooo`13ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0Noooool0
073ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
07_ooooo001aooooo`03o`000?oooooooooo03Kooooo1_l00005ooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool0O?ooool007;ooooo00?o0000ooooooooool0<oooool2o`0000Gooooo
0_l00004ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0OOooool007;ooooo00?o
0000ooooooooool0<oooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooooooo`;o0000
<?ooool00ol0003oooooooooo`1nooooo`00Loooool00ol0003oooooooooo`0`ooooo`;o00002_oo
ool01?l0003oooooooooool0000aooooo`03o`000?oooooooooo07kooooo001dooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool02oooool00ol0003oooooo`00000`ooooo`03o`000?oo
oooooooo07oooooo001dooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool02oooool0
0ol0003oooooo`00000_ooooo`03o`000?oooooooooo083ooooo001eooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool03Oooool2o`0002kooooo00?o0000ooooooooool0POooool007Go
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02co
oooo00?o0000ooooooooool0POooool007Kooooo00?o0000ooooooooool0:_ooool00ol0003ooooo
ooooo`0?ooooo`;o0000;?ooool00ol0003oooooooooo`22ooooo`00M_ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo013ooooo0_l0000/ooooo`03o`000?oooooooooo08;ooooo001g
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool04?ooool00ol0003oooooo`00000Z
ooooo`03o`000?oooooooooo08?ooooo001gooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool04Oooool00ol0003oooooo`00000Zooooo`03o`000?oooooooooo08?ooooo001hooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool04Oooool01?l0003oooooooooool0000Xoooo
o`03o`000?oooooooooo08Cooooo001hooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool04_ooool01?l0003oooooooooool0000Xooooo`03o`000?oooooooooo08Cooooo001iooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool04_ooool2o`0000;ooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`25ooooo`00NOooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo01;ooooo00Go0000ooooooooooooooooo`00000Vooooo`03o`000?oooooooooo08Go
oooo001iooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0QOooool007[ooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`26ooooo`00N_ooool00ol0003oooooooooo`0M
ooooo`06onk^k_lb<S;o0000oc8b<_o^k^ko00001?ooool2ob4Q8@Gooooo1?l000000ol@413ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`26ooooo`00N_ooool00ol0003oooooooooo`0Mooooo`06ogMgMonHV9SooooooiRHV?mgMgOo
00001?ooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool0Q_ooool007[ooooo00?o0000ooooooooool0
7Oooool01Ol@413ooooooooooooooooo000000kooooo00?o0000ooooooooool01Oooool3o`0000?o
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`27ooooo`00N_ooool00ol0003ooooo
ooooo`0Mooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`27ooooo`00
Noooool00ol0003oooooooooo`0Looooo`05o`000?ooooooooooooooool000003_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`27ooooo`00Noooool00ol0003oooooooooo`0Looooo`05oa0@4?ooooooooooooooool0
00003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`28ooooo`00Noooool00ol0003oooooooooo`0Looooo`05ogMg
MonHV9Soooooo`000?mgMgL03_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`28ooooo`00Noooool00ol0003ooooo
ooooo`0Looooo`05onk^k_lb<S;o0000o`000?o^k^h03?ooool00omEEEGoIVIVo`000007ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`28ooooo`00
Noooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo08Wooooo001looooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool05_ooool2o`0000Kooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`29ooooo`00O?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo08Wooooo001looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0R_ooool007go
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`2:ooooo`00OOooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo08[ooooo001mooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool0R_ooool007gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0G
ooooo`;o00002?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo08_ooooo001noooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0Roooool007kooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`2;ooooo`00O_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo08cooooo001oooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0S?oo
ool007oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`2<ooooo`00Ooooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo01Sooooo0_l0000:ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool0S?ooool007oooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`2=ooooo`00Ooooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo08gooooo
0020ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0SOooool0083ooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`2=ooooo`00P?ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo08kooooo0020ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool06_ooool2o`0000cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`2>ooooo`00
P?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo08kooooo0020ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool0Soooool0087ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`2?ooooo`00POooool00ol0003oooooooooo`0Dooooo`07o`000?ooooook^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo08oooooo0021ooooo`03o`000?oooooo
oooo01?ooooo00So0000ooooooooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0Soooool0087ooooo00?o0000ooooooooool04oooool01?l0003o
ooooooooool@4103ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0T?ooool0087o
oooo00?o0000ooooooooool04oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0000gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`2@ooooo`00POooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`2@ooooo`00P_ooool00ol0003o
ooooooooo`0Booooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool03Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`2@ooooo`00P_ooool00ol0003oooooooooo`0Aooooo`09o`000?oooooooooooooo
oomgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2Aooooo`00P_oo
ool00ol0003oooooooooo`0Aooooo`09o`000?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`2Aooooo`00P_ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo097ooooo0022ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool07?ooool2o`00013ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Booooo`00
P_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo09;ooooo0023ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0T_ooool008?ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`2Cooooo`00Poooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
09?ooooo0023ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Toooool008?ooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Nooooo`;o00004_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo09Cooooo0024ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0UOooool008Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2E
ooooo`00Q?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool04oooool2o`000003ooooool0003o000009Sooooo0024ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Dooooo`?o0000VOooool008Cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo0;3ooooo
0025ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07oooool2o`000;7ooooo0025
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`2`
ooooo`00QOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool0/?ooool008Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo0;3ooooo0025ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`2`ooooo`00QOooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool0/?ooool008Kooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0;3ooooo0026ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool08?ooool2o`000;7ooooo0026ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`2`ooooo`00Q_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0/?ooool008Kooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0;3o
oooo0027ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S801_ooool00ol0
003oooooooooo`2`ooooo`00Qoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Ko
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0/?ooool008Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`05
o`000?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`05ooooo`?o0000/?ooool008So
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`05o`000?oooooooooooooo
ool000003Oooool00ol@413o0000okZj^P06ooooo`03o`000?oooooooooo0;3ooooo0028ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool01Ol@413ooooooooooooooooo410@
00kooooo00?o^[Zjob4Q8Oooool01Oooool00ol0003oooooooooo`2`ooooo`00R?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003oooooooooo`2`ooooo`00ROooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`2`ooooo`00ROooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0/?ooool0
08[ooooo00Go0000ooooooooooooooooo`00000Vooooo`;o0000/Oooool008[ooooo0_l000000ooo
oooo0000o`00000Vooooo`03o`000?oooooooooo0;3ooooo002;ooooo`?o00009oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003o
ooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooo
oooooa0@400;ooooo`Go00001_ooool3o`000;3ooooo002Jooooo`05o`000?ooooooooooooooool0
00002oooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05
o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooo
oooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooooooo
ool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@
41004?ooool00ol0003oooooooooo`03ooooo`?o0000/?ooool009[ooooo00Go0000oooooooooooo
ooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009[ooooo
00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0
003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00:cooooo00?o0000okZj^_ooool0^Oooool00:cooooo0_lb<S:j
ooooo`00OOooool2o`000006oa0@4?oooooooooooa0@4?l0003o410@6?ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000001olb<S;ogMgMooooooooooooQhN7o`000?nj^[X03?ooool01OnH
V9So0000o`000?m4A4Co^[Zj01Wooooo1?l000000ol@413oooooooooo`05o`0000?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0Loooool007kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00003?ooool00ol0003ooooooooo
o`06ooooo`07ogMgMolb<S;oooooooooooo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMg
Mol@41002Oooool6o`0000cooooo00?o0000ooooooooool00_ooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Loooool007kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooooooooa0@401cooooo`00O_ooool01_l0003oooooodA4A?m4A4Coooooo`00
00Wooooo1_l0000<ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool04?ooool00ol0
003oooooooooo`0;ooooo`Ko00003?ooool00ol0003oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000Looo
ool007kooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Kooooo`03o`000?oooooooooo00?ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c00Aooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool01Oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000007?ooooo001nooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo00006ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o410@o`000?l000000ol0
000Looooo`03o`000?oooooooooo00Kooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@
4?ooooooooooooooool@41000oooool00ol@413oooooooooo`1aooooo`00O_ooool01_l0003o<S8b
oooooooooooo<S8bo`0001_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol0003o^[ZjoooooonHV9So
410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Loooool007gooooo00?o410@o`000?n7QhL00_ooool00on7QhOo0000oa0@400Hooooo`03oeEEEOmV
IVKo000000Gooooo1?l0000Booooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000001?oo
ool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h0Loooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1300) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.04752 0 m
.04753 0 L
.0521 .00014 L
.05707 .00029 L
.05968 .00037 L
.06244 .00043 L
.06381 .00045 L
.06454 .00046 L
.06531 .00047 L
.06603 .00048 L
.06668 .00049 L
.06795 .00049 L
.06923 .00049 L
.06995 .00049 L
.07062 .00049 L
.07184 .00048 L
.07314 .00046 L
.07428 .00044 L
.07552 .00042 L
.07775 .00037 L
.08284 .0002 L
s
.08284 .0002 m
.08813 0 L
s
.17552 0 m
.17945 .0001 L
.18184 .00015 L
.1832 .00018 L
.18446 .0002 L
.18564 .00021 L
.1869 .00022 L
.18759 .00023 L
.18825 .00023 L
.18947 .00023 L
.19062 .00023 L
.19168 .00022 L
.19284 .00022 L
.19407 .0002 L
.19629 .00017 L
.19837 .00012 L
s
.19837 .00012 m
.20293 0 L
s
.23096 0 m
.23388 .00013 L
.23959 .00043 L
.24495 .00069 L
.24719 .00078 L
.24955 .00086 L
.25079 .00089 L
.25214 .00092 L
.25337 .00095 L
.25452 .00096 L
.25518 .00097 L
.2559 .00098 L
.25716 .00099 L
.25788 .00099 L
.25863 .00099 L
.25928 .00099 L
.25999 .00099 L
.26126 .00098 L
.26197 .00098 L
.26262 .00097 L
.26507 .00095 L
.26754 .00092 L
.26875 .00091 L
.26986 .00091 L
.27115 .0009 L
.27182 .0009 L
.27254 .0009 L
.27369 .0009 L
.27496 .00091 L
.27615 .00092 L
.27725 .00094 L
.2785 .00097 L
.2797 .001 L
.28181 .00108 L
.28411 .0012 L
.2866 .00137 L
.28935 .00159 L
.2949 .00219 L
.30486 .00362 L
.3148 .00537 L
.32426 .00746 L
.32947 .00897 L
.33515 .01111 L
.34033 .01364 L
.34513 .01661 L
.3502 .02049 L
.35569 .02566 L
.36564 .038 L
.37533 .05455 L
.38425 .07512 L
Mistroke
.39398 .10527 L
.40306 .14184 L
.42372 .24613 L
.42873 .2707 L
.43417 .29419 L
.43666 .30337 L
.43931 .31181 L
.4416 .3179 L
.44407 .32311 L
.44522 .32504 L
.44644 .32671 L
.44748 .32784 L
.44861 .32876 L
.44968 .32932 L
.45082 .32958 L
.4519 .32952 L
.45288 .3292 L
.45413 .32843 L
.45529 .32737 L
.45655 .32581 L
.45789 .32372 L
.46014 .31923 L
.46262 .31295 L
.46783 .29561 L
.47278 .27494 L
.48206 .22956 L
.49217 .17852 L
.50295 .13122 L
.50831 .11198 L
.51335 .09668 L
.51827 .08432 L
.52278 .07499 L
.527 .06789 L
.53162 .06175 L
.53627 .05716 L
.53881 .05529 L
.54118 .05393 L
.54244 .05336 L
.54379 .05287 L
.54493 .05254 L
.5462 .05227 L
.54691 .05217 L
.54755 .0521 L
.54826 .05206 L
.54901 .05205 L
.55027 .05212 L
.55099 .0522 L
.55165 .05231 L
.55294 .0526 L
.55416 .05297 L
Mistroke
.55645 .05393 L
.5589 .05534 L
.56156 .05732 L
.56626 .06196 L
.57123 .06849 L
.58013 .08442 L
.58958 .10731 L
.59973 .13821 L
.61806 .20318 L
.62821 .23561 L
.63099 .24289 L
.63394 .24961 L
.6365 .25444 L
.63926 .25857 L
.64051 .26004 L
.64183 .26131 L
.64295 .26217 L
.64419 .26286 L
.64534 .26327 L
.64658 .26345 L
.64775 .26338 L
.64881 .26311 L
.64947 .26285 L
.65017 .26248 L
.65142 .26162 L
.65276 .2604 L
.65424 .25871 L
.65689 .25479 L
.65937 .25014 L
.66434 .23827 L
.66976 .2221 L
.67962 .18727 L
.69815 .12074 L
.70828 .09072 L
.71783 .06787 L
.72883 .04745 L
.7388 .0336 L
.74857 .02368 L
.75349 .01985 L
.75889 .0164 L
.76844 .01183 L
.77736 .00875 L
.78782 .00598 L
.79772 .00395 L
.80203 .00325 L
.80661 .00264 L
.809 .00238 L
.81163 .00214 L
.81628 .00181 L
.81863 .00169 L
Mistroke
.8212 .00158 L
.82388 .0015 L
.82638 .00143 L
.83563 .00125 L
.84092 .00111 L
.84572 .00093 L
.85649 .00043 L
.86134 .0002 L
.86399 .0001 L
.86647 1e-05 L
Mfstroke
.86647 1e-05 m
.86685 0 L
s
.89129 0 m
.89167 1e-05 L
.89396 4e-05 L
.89526 5e-05 L
.89648 7e-05 L
.89775 8e-05 L
.89892 9e-05 L
.90016 9e-05 L
.90085 .0001 L
.9015 .0001 L
.90216 .0001 L
.90286 .0001 L
.90411 9e-05 L
.90488 9e-05 L
.90561 9e-05 L
.90696 8e-05 L
.90944 5e-05 L
.91172 2e-05 L
s
.91172 2e-05 m
.91298 0 L
s
.94515 0 m
.94989 9e-05 L
.95251 .00013 L
.95395 .00015 L
.95529 .00016 L
.95668 .00018 L
.95742 .00018 L
.95822 .00018 L
.95894 .00019 L
.95963 .00019 L
.96092 .00018 L
.96224 .00018 L
.96346 .00017 L
.96481 .00016 L
.96624 .00014 L
.97146 6e-05 L
s
.97146 6e-05 m
.97427 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`[o00002?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool?o`0000Co
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool08?ooool002Cooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0Uooooo`Co00001?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool08oooool3o`0000Oooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`0Pooooo`00POooool2o`0003;ooooo00?o0000ooooooooool0D?ooool3o`0005gooooo0023
ooooo`?o0000;oooool00ol0003oooooooooo`1=ooooo`?o0000H?ooool008Kooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`1;ooooo`;o0000Hoooool008Oooooo00?o0000oooooooo
ool0:oooool2o`0004[ooooo0_l0001Uooooo`00R?ooool00ol0003oooooooooo`0Zooooo`03o`00
0?oooooooooo04Sooooo00?o0000ooooooooool0IOooool008Wooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo06Kooooo0029ooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`1Wooooo`00R_ooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0J?ooool008_o
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo06So
oooo002<ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0A?ooool00ol0003ooooo
ooooo`1Yooooo`00S?ooool00ol0003oooooooooo`0Vooooo`;o0000A?ooool00ol0003ooooooooo
o`1Zooooo`00SOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo04?ooooo00?o0000
ooooooooool0J_ooool008kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`12oooo
o`03o`000?oooooooooo06_ooooo002>ooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool02_ooool4o`0003Cooooo00?o0000ooooooooool0Joooool008oooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo0_l0000aooooo`03o`00
0?oooooooooo06cooooo002?ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01ooo
ool2o`0000Oooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1/ooooo`00T?ooool0
0ol0003oooooooooo`0Rooooo`;o00001oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool0KOooool0093ooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`1]ooooo`00TOooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo06ko
oooo002Aooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0K_ooool009;ooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`1_ooooo`00T_ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo06oooooo002Cooooo`03o`000?oooooooooo01oooooo0_l00004oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1`oooo
o`00Toooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo073ooooo002Cooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0L?ooool009Cooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`1aooooo`00U?ooool00ol0003oooooooooo`03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l000000ol@413oooooooooo`03ooooo`05o`000?oo
ooooooooooooool000005?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo077ooooo
002Dooooo`03o`000?oooooooooo00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000005Oooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo07;ooooo002Eooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Gooooo0ol000000ooooooo
0000ooooo`0Dooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0L_ooool009Gooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000kooooo00?o0000oooooooo
ool01Oooool01?l0003oooooooooool0000Fooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool0L_ooool009Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00kooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0000Gooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool0Loooool009Gooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01Oooool00ol0003oooooo`00000H
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0Loooool009Gooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooo`00000Iooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0Loooool0
09Kooooo00Wo0000ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIV
o`000007ooooo`03o`000?oooooo000001Wooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`1dooooo`00U_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo000001Wooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`1dooooo`00U_ooool00ol0003oooooooooo`0L
ooooo`;o00006oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo07Cooooo002Foooo
o`03o`000?oooooooooo01cooooo0_l0000Kooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool0M?ooool009Kooooo00?o0000ooooooooool07?ooool2o`0001_ooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`1eooooo`00Uoooool00ol0003oooooooooo`0Kooooo`;o0000
7?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo07Gooooo002Gooooo`03o`000?oo
oooooooo01_ooooo0_l0000Looooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0MOoo
ool009Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0M_ooool009Oooooo00?o0000ooooooooool06oooool2o`00
01cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1fooooo`00Uoooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`1fooooo`00V?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`1gooooo`00V?ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`1gooooo`00V?ooool00ol0003oooooooooo`0Iooooo`;o00007oooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo07Oooooo002Hooooo`03o`000?oooooooooo01Wooooo0_l0000Ooooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Moooool009Sooooo00?o0000oooooooo
ool06Oooool3o`0001kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1hooooo`00
VOooool00ol0003oooooooooo`0Hooooo`;o00008?ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo07Sooooo002Iooooo`03o`000?oooooooooo01Sooooo0_l0000Pooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0N?ooool009Wooooo00?o0000ooooooooool05oooool0
0ol0003oooooo`00000Pooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0NOooool0
09Wooooo00?o0000ooooooooool05oooool00ol0003oooooo`00000Pooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0NOooool009[ooooo00?o0000ooooooooool05_ooool00ol0003o
ooooo`00000Qooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0NOooool009[ooooo
00?o0000ooooooooool05_ooool01?l0003oooooo`000?l0000Pooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool0N_ooool009[ooooo00?o0000ooooooooool05Oooool01?l0003ooooo
ooooool0000Qooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0N_ooool009[ooooo
00?o0000ooooooooool05Oooool01?l0003oooooooooool0000Rooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool0N_ooool009[ooooo00?o0000ooooooooool05Oooool01?l0003ooooo
ooooool0000Rooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0N_ooool009[ooooo
00Gok^k^o`000?l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000?ooooo00Co0000oooooooo
oooo00008_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo07_ooooo002Jooooo`05
ogMgMol0003ooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A002
ooooo`05o`000?ooooooooooooooool000008oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo07_ooooo002Jooooo`05oa0@4?l0003oooooooooool@41003?ooool00onHV9So8B4Qonk^
kP03ooooo`05o`000?ooooooooooooooool000008oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo07_ooooo002Jooooo`;o00000_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ
8B7ok^k^00;ooooo00Co0000oooooooooooooooo0ol0000Qooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0O?ooool009[ooooo0_l00002ooooo`03o`000?oooooooooo00cooooo00Go
MgMgofIVI_ooooooooooo`000003ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`1looooo`00V_ooool01Ol@413oooooo`000?oooooo410@00oooooo
00?o0000ooooool000001?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0O?ooool009[ooooo00GoMgMgoiRHV?l0003oV9RHogMgM`0;ooooo`07o`00
0?nj^[[ooooooiRHV?l@413oooooo`000004ooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`1looooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo00OoV9RHoa0@4?l0003o8B4Qolc<c?oooooo000000Cooooo00?o0000ooooooooool08_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo07gooooo002Looooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0OOooool009gooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`03ooooo`;o00009?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
07gooooo002Mooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0OOooool009gooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`1nooooo`00WOooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo07kooooo002Mooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0O_ooool009kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1ooooo
o`00W_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo0_l0000Vooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0Ooooool009kooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`20ooooo`00W_ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo087ooooo002Nooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0POooool0
09oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
02Oooooo0_l00002ooooo`;o0000Poooool009oooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo02Sooooo1?l00024ooooo`00Woooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00Gooooo0_l0002aooooo`00Woooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool009oooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;3ooooo002Ooooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2`oooo
o`00X?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0/?ooool00:3ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo0;3ooooo002Pooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`2`ooooo`00XOooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Kooooo0_l0002aooooo`00XOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0/?ooool00:7ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01?l0003oooooob4Q8OlQ8B44ooooo`05oiRHV?l0003o0000oc8b<_o<c<`01_ooool0
0ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Co0000
oooooolQ8B7o8B4Q1?ooool01Ol@413o0000oooooomgMgOo<S8b00Kooooo00?o0000ooooooooool0
/?ooool009[ooooo00Go410@oooooooooooooooooa0@4003ooooo`03o`000?oooooooooo00Gooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooojVY
ZOl@41001_ooool3o`000;3ooooo002Jooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`05ooooo`05o`000?oooooo410@o`000?nj^[X01_ooool00ol0003oooooooooo`2`
ooooo`00V_ooool01Ol@413ooooooooooooooooo410@00?ooooo00?o0000ooooooooool01Oooool0
1Ol0003ooooooooooonj^[[o8B4Q00Kooooo00?o0000ooooooooool0/?ooool009[ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`04ooooo`03o`000?oooooooooo00?ooooo00Ko0000oa0@4?nHV9Sooooo
okZj^_l00006ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool02ol0003ooooooooooooooooo0000oooooonYZJWo410@o`000?l@413oZJVY00Kooooo
00?o0000ooooooooool0/?ooool00:Cooooo0_l00002ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0/?ooool00:Gooooo0ol0000=ooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003
oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;3o
oooo002Jooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol0002`ooooo`00
V_ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool00ol0
003oooooooooo`2`ooooo`00V_ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEE
EOoooooo00001oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo
410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`
ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool0
0ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00
V_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000;3o
oooo002Jooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo0;3ooooo002Jooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002a
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002/ooooo`03o`000?nj
^[[ooooo0;Wooooo002/ooooo`;o<S8b^_ooool007gooooo0_l000001_l@413oooooooooool@413o
0000oa0@41Sooooo1?l000001Ol@413oooooooooooooooooA4A400;o000000Oo<S8bomgMgOoooooo
ooooohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Iooooo`Co000000So410@
ooooooooooooV9RHoa0@4?l0003o<S8bolc<c0?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h0Loooool007kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`07ooooo`Ko00003?ooool00ol0003oooooooooo`06ooooo`07ogMgMolb<S;ooooo
ooooooo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000cooooo
00?o0000ooooooooool00_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Loooool007kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Kooooo00Go0000oooo
oooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413ooooooooo
o`1aooooo`00O_ooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000<ooooo`03o`00
0?oooooooooo00Kooooo00?oMgMgoc8b<_ooool04?ooool00ol0003oooooooooo`0;ooooo`Ko0000
3?ooool00ol0003oooooooooo`05ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool00000Loooool007kooooo00Ko0000omgMgOlb
<S;oEEEEomgMgOl0000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Aooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01?ooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000007?o
oooo001nooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo00006oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo017ooooo00?o410@o`000?l000000ol0000Looooo`03o`000?oooooooooo
00Gooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@
oooooooooooooooooa0@401cooooo`00O_ooool01_l0003o<S8boooooooooooo<S8bo`0001_ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool00_ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Loooool007gooooo00?o410@o`00
0?n7QhL00_ooool00on7QhOo0000oa0@400Hooooo`03oeEEEOmVIVKo000000Gooooo1?l0000Boooo
o`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000001?ooool01OnYZJWo410@o`000?l@413o
ZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
Loooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1400) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .00035 m
.04262 9e-05 L
s
.04262 9e-05 m
.04549 0 L
s
.07754 0 m
.07785 1e-05 L
.0803 5e-05 L
.08255 8e-05 L
.08386 9e-05 L
.08453 .0001 L
.08524 .0001 L
.08596 .00011 L
.08662 .00011 L
.08742 .00011 L
.08815 .00011 L
.08939 .00011 L
.0901 .0001 L
.09075 .0001 L
.09194 9e-05 L
.09321 7e-05 L
.096 2e-05 L
s
.096 2e-05 m
.09701 0 L
s
.14559 0 m
.14583 0 L
.14729 2e-05 L
.14864 4e-05 L
.14989 4e-05 L
.15103 5e-05 L
.15234 5e-05 L
.15358 5e-05 L
.15422 5e-05 L
.15493 5e-05 L
.15566 4e-05 L
.15635 4e-05 L
.15892 1e-05 L
s
.15892 1e-05 m
.15966 0 L
s
.18998 0 m
.19018 0 L
.19506 .00014 L
.1978 .00022 L
.20076 .0003 L
.20212 .00033 L
.20355 .00035 L
.20479 .00037 L
.20612 .00039 L
.20735 .0004 L
.20848 .0004 L
.20961 .00041 L
.21068 .0004 L
.21192 .0004 L
.21307 .00039 L
.21434 .00037 L
.21567 .00035 L
.21827 .0003 L
.2207 .00023 L
.22623 5e-05 L
s
.22623 5e-05 m
.22783 0 L
s
.25918 0 m
.26038 4e-05 L
.26502 .00016 L
.26723 .00021 L
.26955 .00025 L
.27077 .00027 L
.2721 .00028 L
.27331 .00029 L
.27443 .0003 L
.27508 .0003 L
.27578 .0003 L
.27706 .0003 L
.27831 .00029 L
.27945 .00029 L
.28069 .00028 L
.28206 .00026 L
.28481 .00022 L
.29005 .00015 L
.29293 .00011 L
.29435 9e-05 L
.29567 8e-05 L
.2969 7e-05 L
.29821 7e-05 L
.29896 7e-05 L
.29966 7e-05 L
.30098 7e-05 L
.30219 8e-05 L
.30331 9e-05 L
.30453 .0001 L
.30582 .00012 L
.31606 .00037 L
.32109 .0005 L
.3233 .00055 L
.32574 .0006 L
.32679 .00061 L
.32792 .00062 L
.32898 .00063 L
.32996 .00064 L
.33106 .00064 L
.33225 .00064 L
.33338 .00064 L
.33443 .00064 L
.33566 .00063 L
.33683 .00062 L
.339 .00059 L
.34387 .00052 L
.34625 .00049 L
.34745 .00048 L
.34876 .00048 L
.34988 .00047 L
Mistroke
.35109 .00047 L
.35223 .00048 L
.35326 .00049 L
.35456 .00051 L
.35576 .00054 L
.35708 .00058 L
.35848 .00063 L
.36084 .00075 L
.36343 .00092 L
.36863 .0014 L
.37423 .00209 L
.38436 .00363 L
.39474 .00531 L
.4044 .00704 L
.40927 .00815 L
.41447 .00969 L
.42024 .01201 L
.42549 .01484 L
.43034 .01818 L
.43547 .02255 L
.44467 .03275 L
.45457 .04758 L
.46546 .0699 L
.47562 .09846 L
.4849 .13261 L
.50579 .23133 L
.515 .27341 L
.52005 .29226 L
.5248 .3059 L
.52752 .31159 L
.52904 .31408 L
.53045 .31588 L
.53163 .31704 L
.53294 .31793 L
.53359 .31822 L
.53429 .31842 L
.53556 .31847 L
.53685 .31813 L
.53757 .31776 L
.53824 .31731 L
.53948 .3162 L
.54078 .31464 L
.54304 .311 L
.54554 .3057 L
.55047 .29159 L
.55565 .27241 L
.56491 .23111 L
.57501 .18357 L
.58578 .1387 L
.59111 .12048 L
Mistroke
.59614 .10606 L
.60104 .09459 L
.60555 .08616 L
.60984 .07994 L
.61437 .07513 L
.61673 .07331 L
.61893 .07201 L
.62019 .07144 L
.62134 .07103 L
.62198 .07085 L
.62267 .07069 L
.62393 .07049 L
.62514 .07041 L
.62625 .07043 L
.62748 .07058 L
.62876 .07085 L
.62989 .07119 L
.63093 .0716 L
.63331 .07285 L
.63593 .07474 L
.63831 .07695 L
.64367 .08363 L
.64885 .09239 L
.65446 .10449 L
.66467 .13294 L
.68412 .20175 L
.69444 .23641 L
.70024 .25193 L
.70299 .25785 L
.70554 .26239 L
.70795 .26577 L
.70919 .26713 L
.71052 .26833 L
.71129 .26888 L
.71199 .26929 L
.71266 .26961 L
.71338 .26987 L
.71461 .2701 L
.71531 .27011 L
.71596 .27005 L
.71724 .2697 L
.71846 .26911 L
.71955 .26837 L
.72074 .26732 L
.7234 .2641 L
.72586 .2601 L
.73025 .25067 L
.73509 .23726 L
.7449 .20322 L
.76588 .12386 L
Mistroke
.77506 .09505 L
.78511 .06987 L
.79488 .05107 L
.80396 .03759 L
.81356 .02668 L
.81889 .02189 L
.82381 .0182 L
.83405 .01245 L
.83945 .01029 L
.84516 .00848 L
.85475 .00614 L
.86531 .00412 L
.87053 .00328 L
.87548 .00258 L
.87998 .00205 L
.88476 .00162 L
.88749 .00143 L
.88995 .0013 L
.89114 .00125 L
.89243 .00121 L
.89364 .00117 L
.89476 .00115 L
.89608 .00112 L
.89684 .00111 L
.89753 .0011 L
.8982 .00109 L
.89893 .00109 L
.89971 .00108 L
.90044 .00108 L
.90176 .00108 L
.90242 .00108 L
.90315 .00108 L
.90445 .00108 L
.90566 .00109 L
.9069 .00109 L
.90758 .00109 L
.90823 .00109 L
.90948 .00109 L
.91061 .00109 L
.91127 .00109 L
.91197 .00109 L
.91321 .00109 L
.91391 .00108 L
.91455 .00108 L
.91603 .00106 L
.9173 .00104 L
.91851 .00102 L
.92078 .00097 L
.92323 .00089 L
.92589 .0008 L
Mistroke
.93469 .00041 L
.93936 .00021 L
.94182 .00012 L
.94441 4e-05 L
Mfstroke
.94441 4e-05 m
.94605 0 L
s
.95917 0 m
.95981 1e-05 L
.97619 .00035 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01Oooool8o`0000Sooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooo000000_o00002_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo023ooooo000Tooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0=ooooo`Co00007?ooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo02gooooo00?o0000ooooooooool02?ooool3o`0002;ooooo00?o0000ooooooooool0
8?ooool009Wooooo1?l0000Hooooo`03o`000?oooooooooo06?ooooo1Ol00018ooooo`00WOooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo067ooooo0_l0001=ooooo`00W_ooool2o`00
01Gooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1=ooooo`00X?ooool00ol0003o
ooooooooo`0Booooo`;o0000H?ooool00ol0003oooooooooo`1>ooooo`00XOooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo05gooooo0_l0001Aooooo`00X_ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0DOooool00:?ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo057ooooo002Toooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`1Boooo
o`00Y?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05[ooooo00?o0000oooooooo
ool0Doooool00:Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Iooooo`03o`00
0?oooooooooo05Cooooo002Vooooo`03o`000?oooooooooo00cooooo0_l0001Jooooo`03o`000?oo
oooooooo05Cooooo002Vooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0F?ooool0
0ol0003oooooooooo`1Eooooo`00Yoooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
05Oooooo00?o0000ooooooooool0E_ooool00:Oooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`1Fooooo`03o`000?oooooooooo05Oooooo002Xooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0E_ooool00ol0003oooooooooo`1Gooooo`00Z?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0F?ooool00:Wooooo00?o0000
ooooooooool02Oooool2o`0005Gooooo00?o0000ooooooooool0FOooool00:Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo05Wooooo002Zooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`1Jooooo`00
Z_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo023ooooo1_l0000]ooooo`03o`00
0?oooooooooo05[ooooo002[ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07ooo
ool2o`0000Gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1Kooooo`00Zoooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo05_ooooo002[ooooo`03o`000?oooooooooo
00Oooooo0_l0000Oooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`1Kooooo`00[?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05co
oooo002/ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0G?ooool00:cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`1Looooo`00V_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000?o410@ooooooooool00oooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`1Mooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool0GOooool009[ooooo00Go410@oooooooooooooooooa0@
400>ooooo`03o`000?oooooooooo00Gooooo0ol0000Kooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`1Mooooo`00V_ooool01Ol0003ooooooooooooo
oooo000000kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1Nooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000kooooo0_l00006ooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo05kooooo002J
ooooo`05oa0@4?ooooooooooooooool@41003_ooool2o`0000Kooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0G_oo
ool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`;o00001_ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`1Nooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00GoEEEEofIVI_l0003ooooo
o`000005ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo05kooooo002_ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool0Goooool00:oooooo00?o0000ooooooooool00oooool2o`0001[ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05oooooo002`oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool0Goooool00;3ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`1Oooooo`00/?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo063ooooo002`ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0H?oo
ool00;7ooooo00Go0000ooooooooooooooooo`00000Iooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`1Pooooo`00/Oooool01?l0003ooooooooooooo
ool2o`0001Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo067ooooo002aooooo`05o`000?ooooooooooooooool000006?ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0HOooool00;7ooooo00Go0000
ooooooooooooooooo`00000Hooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`1Qooooo`00/_ooool01?l0003oooooooooool0000Hooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1Qooooo`00/_ooool0
1?l0003oooooooooool0000Hooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`1Rooooo`00/_ooool01?l0003oooooooooool0000Hooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1Rooooo`00/_ooool0
0ol0003oooooooooo`02o`0001Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo06;ooooo002booooo`04o`000?ooooooooooo`0001Oooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo06?ooooo002coooo
o`03o`000?oooooo000001Oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo06?ooooo002cooooo`03o`000?oooooo000001Oooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo06?ooooo002cooooo`03o`00
0?oooooo000001Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo06Cooooo002cooooo`03o`000?oooooo000001Kooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo06Cooooo002dooooo`?o00005Oooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0I?ooool0
0;Cooooo0_l0000Fooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`1Tooooo`00]?ooool2o`0001Kooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo06Gooooo002dooooo`;o00005Oooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0IOooool009[ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
IOooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Q
onk^k_ooooooA4A400Kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0I_ooool009[ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0I_ooool009[ooooo
00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0000Cooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Vooooo`00
V_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`1Vooooo`00V_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooooooo
ool01?ooool2o`0001?ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo06Oooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o
^[ZjoooooonHV9So410@00Kooooo0_l0000Cooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`1Wooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`;o00004oooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Ioooool00;Gooooo0_l0000Coooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Xoooo
o`00]Oooool3o`00017ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo06Sooooo002eooooo`03o`000?oooooo0000017ooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo06Sooooo002eooooo`03o`000?oo
oooo0000017ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo06Wooooo002eooooo`03o`000?oooooo0000017ooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo06Wooooo002eooooo`03o`000?oooooo0000
013ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
06Wooooo002eooooo`04o`000?ooooooooooo`0000oooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo06Wooooo002eooooo`;o000000?oooooo`000?oo
ool03_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0J_ooool00;Gooooo00Co0000oooooooooooo00003oooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0J_ooool00;Gooooo00Co0000oooooooooooo
00003_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0J_ooool00;Gooooo00Co0000oooooooooooo00003_ooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0Joooool00;Gooooo00Co0000oooooooooooo
00003_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0K?ooool00;Gooooo00Co0000oooooooooooo00003_ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0K?ooool00;Gooooo0_l00002ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0:_ooool01Ol0003ooooooooooooooooo000006oo
oooo002eooooo`05o`000?ooooooooooooooool000003?ooool00ol0003oooooooooo`0/ooooo`?o
0000L?ooool00;Gooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo09oo
oooo002eooooo`05o`000?ooooooooooooooool000003?ooool00ol0003oooooooooo`2Oooooo`00
]Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
X?ooool00;Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo0:3ooooo002eooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`2Pooooo`00]Oooool2o`0000Cooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`2Qooooo`00]Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0XOooool00;Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo0:7ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2Qooooo`00V_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S801_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0X_ooool009[o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0:;ooooo002Jooooo`05
o`000?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`05ooooo`?o00001?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo0:;ooooo002Jooooo`05o`000?oooooooooooooo
ool000003Oooool00ol@413o0000okZj^P06ooooo`03o`000?oooooooooo00Gooooo0_l00003oooo
o`03o`000?oooooooooo0:?ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003_ooool00onj
^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo00Kooooo00Co0000ooooool0003o0000Y_ooool0
09[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l000001_oo
ool00ol0003oooooooooo`07ooooo`;o0000Yoooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413o
ooooooooo`04ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2`ooooo`00
V_ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`?o0000/?ooool009[ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000oooo
ooooool0/?ooool009[ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0000Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0/?ooool0
09[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000
ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00V_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009[ooooo
00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0002`ooooo`00
V_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`2`ooooo`00V_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0
003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool00ol0003o^[Zjoooo
o`2iooooo`00[?ooool2oc8b<[[ooooo001mooooo`;o000000Ko410@oooooooooooo410@o`000?l@
410Hooooo`Co000000Go410@ooooooooooooooooodA4A002o`000007oc8b<_oMgMgooooooooooon7
QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06Oooool4o`000003oa0@4?oooooo
oooo00;ooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h0Loooool007kooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`07ooooo`Ko00003?ooool00ol0003oooooooooo`06ooooo`07ogMgMolb<S;ooooooooo
ooo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg07?ooooo001nooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`02ooooo`Go00000oooool01Ol@413ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@401cooooo`00O_ooool01_l0003o
ooooodA4A?m4A4Coooooo`0000Wooooo1_l0000<ooooo`03o`000?oooooooooo00Kooooo00?oMgMg
oc8b<_ooool04?ooool00ol0003oooooooooo`0;ooooo`Ko00003?ooool00ol0003oooooooooo`02
ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool00000Loooool007kooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Koooo
o`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Aooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool00_ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000007?ooooo001nooooo`06o`00
0?n7QhOoZJVYokZj^_mEEEGo00006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
017ooooo00?o410@o`000?l000000ol0000Looooo`03o`000?oooooooooo00?ooooo00?oMgMgolc<
c?l000001?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
401cooooo`00O_ooool01_l0003o<S8boooooooooooo<S8bo`0001_ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
0oooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg07?ooooo001mooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@
41006?ooool00omEEEGoIVIVo`000005ooooo`Co00004_ooool00ol0003oooooooooo`0Kooooo`03
oeEEEOmVIVKo000000Kooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1cooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1500) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .00073 m
.03279 .00059 L
.03793 .00051 L
.04262 .00042 L
.04758 .00029 L
.05288 .00014 L
.05752 2e-05 L
s
.05752 2e-05 m
.05824 0 L
s
.08561 0 m
.08925 7e-05 L
.09177 .00012 L
.09406 .00015 L
.09522 .00016 L
.09648 .00018 L
.09717 .00018 L
.09781 .00019 L
.09908 .00019 L
.10034 .00019 L
.10107 .00019 L
.10174 .00019 L
.10246 .00019 L
.10311 .00019 L
.10383 .00018 L
.10458 .00018 L
s
.10458 .00018 m
.11484 0 L
s
.15441 0 m
.15703 4e-05 L
.15835 6e-05 L
.15976 8e-05 L
.16109 9e-05 L
.1623 9e-05 L
.16298 .0001 L
.1637 .0001 L
.16499 .0001 L
.16571 .0001 L
.16638 .0001 L
.16712 .0001 L
.16791 .0001 L
.16855 .0001 L
.16926 9e-05 L
.17068 8e-05 L
.17322 6e-05 L
.17803 0 L
s
.17803 0 m
.17818 0 L
s
.20167 0 m
.2029 2e-05 L
.20822 .00012 L
.21113 .00017 L
.21383 .00021 L
.21615 .00024 L
.21744 .00025 L
.21862 .00026 L
.21991 .00027 L
.22064 .00027 L
.22132 .00027 L
.22255 .00027 L
.22386 .00026 L
.22506 .00025 L
.22615 .00025 L
.22861 .00021 L
.23089 .00018 L
.23306 .00013 L
.23831 1e-05 L
s
.23831 1e-05 m
.23878 0 L
s
.269 0 m
.27302 .0001 L
.27549 .00015 L
.27808 .0002 L
.28029 .00024 L
.28155 .00025 L
.28271 .00026 L
.28338 .00026 L
.2841 .00027 L
.28541 .00027 L
.28668 .00027 L
.28785 .00026 L
.28912 .00025 L
.29052 .00024 L
.29198 .00022 L
.29334 .00019 L
s
.29334 .00019 m
.3011 0 L
s
.33032 0 m
.33333 .0001 L
.33758 .00024 L
.34216 .00037 L
.34347 .0004 L
.34471 .00043 L
.34591 .00045 L
.34703 .00046 L
.34809 .00047 L
.34922 .00048 L
.35046 .00048 L
.3516 .00048 L
.35225 .00048 L
.35294 .00048 L
.35417 .00047 L
.35485 .00046 L
.35549 .00045 L
.35695 .00043 L
.35938 .00038 L
.36199 .00032 L
.36729 .00017 L
.37019 9e-05 L
.37291 2e-05 L
s
.37291 2e-05 m
.37401 0 L
s
.39042 0 m
.39048 0 L
.39318 7e-05 L
.40425 .0004 L
.40887 .00052 L
.41383 .00062 L
.41667 .00067 L
.41927 .0007 L
.42437 .00075 L
.42683 .00078 L
.42914 .00081 L
.43181 .00086 L
.43423 .00091 L
.43652 .00098 L
.43863 .00107 L
.44338 .00131 L
.44819 .00166 L
.45347 .00214 L
.46412 .00343 L
.47434 .00505 L
.48365 .00707 L
.48881 .00856 L
.4944 .01064 L
.49966 .01312 L
.50458 .01599 L
.514 .02318 L
.52438 .03413 L
.5345 .04862 L
.5454 .07012 L
.55499 .09596 L
.56547 .13289 L
.58658 .22623 L
.59143 .24702 L
.59669 .26705 L
.60132 .28165 L
.60385 .28814 L
.60622 .29314 L
.60895 .29754 L
.61039 .29925 L
.61113 .29996 L
.61194 .30061 L
.61267 .30107 L
.61335 .3014 L
.614 .30162 L
.61469 .30175 L
.61589 .30175 L
.61721 .30138 L
.6185 .30067 L
.61968 .29971 L
.62098 .29833 L
Mistroke
.62235 .29649 L
.62466 .29257 L
.62718 .28714 L
.63245 .27239 L
.63743 .25498 L
.64676 .21695 L
.65692 .17418 L
.6677 .13497 L
.67721 .10926 L
.68261 .09875 L
.68521 .09474 L
.68768 .09155 L
.6899 .08916 L
.69232 .08709 L
.69452 .08566 L
.6955 .08516 L
.69656 .08472 L
.69781 .08433 L
.69899 .08409 L
.70014 .08397 L
.70119 .08396 L
.70233 .08406 L
.70359 .0843 L
.7049 .08469 L
.70612 .0852 L
.70872 .08672 L
.71113 .08866 L
.71377 .0914 L
.71658 .09502 L
.72128 .10276 L
.72648 .11377 L
.73605 .14064 L
.74504 .17229 L
.76352 .24212 L
.76858 .25796 L
.77136 .26535 L
.77399 .27133 L
.77644 .27593 L
.77773 .27795 L
.77909 .27977 L
.78024 .28105 L
.78151 .28217 L
.78266 .28294 L
.78373 .28344 L
.78497 .28374 L
.78567 .28378 L
.78632 .28373 L
.78751 .28344 L
.78878 .28283 L
.79003 .28194 L
Mistroke
.7912 .28083 L
.7934 .27808 L
.796 .27371 L
.79839 .26869 L
.80378 .25416 L
.81405 .21727 L
.82488 .17247 L
.83511 .13193 L
.84479 .09927 L
.85421 .07399 L
.86291 .05588 L
.87228 .04085 L
.88246 .02853 L
.89262 .01949 L
.89775 .016 L
.90339 .01289 L
.90858 .01063 L
.91352 .00892 L
.92279 .00657 L
.93276 .00477 L
.94366 .00319 L
.95176 .00221 L
.9594 .00149 L
.96363 .0012 L
.96585 .00108 L
.9682 .00097 L
.97018 .00089 L
.97236 .00082 L
.97619 .00073 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Co
oooo2Ol00008ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool:o`0000;o
oooo00?o0000ooooooooool08?ooool002Cooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo02Gooooo1?l00004ooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Looooo`Ko00002oooool00ol0003ooooo
ooooo`0Pooooo`00/Oooool5o`0007[ooooo1?l0000dooooo`00]Oooool00ol0003oooooooooo`1g
ooooo`03o`000?oooooooooo03Kooooo002eooooo`?o0000MOooool2o`0003Wooooo002eooooo`;o
000000?oooooo`000?ooool0L_ooool00ol0003oooooooooo`0iooooo`00]Oooool01Ol0003ooooo
oooooooooooo0000077ooooo00?o0000ooooooooool0>_ooool00;Gooooo00Go0000oooooooooooo
ooooo`00001`ooooo`03o`000?oooooooooo03_ooooo002eooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0looooo`00]Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0??ooool00;Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo03gooooo002eoooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`0noooo
o`00]Oooool2o`0000Kooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0oooooo`00
]Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0
?oooool00;Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Sooooo`03o`000?oo
oooooooo043ooooo002eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0H_ooool0
0ol0003oooooooooo`11ooooo`00]Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
063ooooo00?o0000ooooooooool0@_ooool00;Gooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`1Oooooo`03o`000?oooooooooo04;ooooo002eooooo`;o00002_ooool00ol0003ooooo
ooooo`1Nooooo`03o`000?oooooooooo04?ooooo002eooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0GOooool00ol0003oooooooooo`13ooooo`00]Oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0A?ooool00;Gooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo04Cooooo002eooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`15ooooo`00
]Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0
AOooool00;Gooooo0_l0000=ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0AOoo
ool00;Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Xooooo`Go0000:_ooool0
0ol0003oooooooooo`16ooooo`00]Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
04Kooooo002eooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0A_ooool009[ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000003oa0@4?oooooooooo00?o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`17ooooo`00V_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`17ooooo`00V_ooool01Ol@413ooooooooooooooooo410@00ko
oooo00?o0000ooooooooool01Oooool3o`0000kooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0Aoooool009[ooooo
00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`17ooooo`00V_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo04So
oooo002Jooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool0B?ooool009[ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`18ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l0
00001oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo04Wooooo002eooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool0BOooool00;Gooooo0_l0000Aooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo04Wooooo002eooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0B_ooool0
0;Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1:ooooo`00]Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo04[ooooo002eooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool0B_ooool00;Gooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`1;ooooo`00]Oooool2o`0001?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0Boooool00;Gooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`1;ooooo`00]Oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo04cooooo002eooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
C?ooool00;Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1<ooooo`00]Oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04gooooo002eooooo`;o00005?ooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`1=ooooo`00]Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04go
oooo002eooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0C_ooool00;Gooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`1>ooooo`00]Oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo04kooooo002eooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0C_ooool00;Gooooo0_l0000Eooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04oooooo002eooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool0Coooool00;Gooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`1?ooooo`00]Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo04oooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0D?ooool009[ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`1@ooooo`00V_ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo053ooooo002Jooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^
kP06ooooo`?o00005_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`1@ooooo`00V_ooool01Ol0003ooooooooooooo
oooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo053ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0DOooool009[ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo057ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`1Aooooo`00]Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo057ooooo
002eooooo`;o00006?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`1Booooo`00]Oooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo05;ooooo002eooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool0D_ooool00;Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Cooooo`00
]Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05?ooooo002eooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0Doooool00;Gooooo0_l0000Jooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo05?ooooo002eooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0E?ooool00;Go
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Dooooo`00]Oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo05Cooooo002eooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0EOooool00;Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1E
ooooo`00]Oooool2o`0001_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0EOooool00;Gooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`1Fooooo`00]Oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo05Kooooo002eooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0E_oo
ool00;Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo02[ooooo0_l00002ooooo`;o0000FOooool00;Gooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo02_ooooo1?l0001Jooooo`00]Oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0R_ooool00;Gooooo
0_l0000Mooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0R_ooool00;Gooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08[ooooo002e
ooooo`03o`000?oooooooooo01kooooo00Go0000ooooooooooooooooo`00002=ooooo`00V_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05oiRHV?l@413o0000oc8b<_o<c<`0
1_ooool00ol0003oooooooooo`0Nooooo`;o000000?oooooo`000?l00000SOooool009[ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Ko
oooo00?o0000ooooooooool07oooool2o`0008oooooo002Jooooo`05oa0@4?ooooooooooooooool@
41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05o`00
0?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`05ooooo`?o0000/?ooool009[ooooo
00Go0000ooooooooooooooooo`00000=ooooo`03oa0@4?l0003o^[Zj00Kooooo00?o0000oooooooo
ool0/?ooool009[ooooo00Go410@oooooooooooooooooa0@400>ooooo`03okZj^_lQ8B7ooooo00Go
oooo00?o0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0/?ooool009[ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol0
002`ooooo`00V_ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
1oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol0003ooooooooooooooooo000000_ooooo
00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooo
oooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`2`ooooo`00
V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0003o
ooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?oo
ool01_ooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00ooo
ool3o`000;3ooooo002Jooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05o`000?ooooooooooooooool000003?oo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool009[ooooo00Go
410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co0000
1_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002/oooo
o`03o`000?nj^[[ooooo0;Wooooo002/ooooo`;o<S8b^_ooool007gooooo0_l000001_l@413ooooo
ooooool@413o0000oa0@41Sooooo1?l000001Ol@413oooooooooooooooooA4A400;o000000Oo<S8b
omgMgOooooooooooohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Iooooo`Co
000000Go410@ooooooooooooooooodA4A002o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1cooooo`00O_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l0000<ooooo`03o`000?oooooooooo00Kooooo
00OoMgMgoc8b<_ooooooooooolc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009
ooooo`Ko00003?ooool00ol0003oooooooooo`06ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1cooooo`00O_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01oooool01?l0003o
ooooooooool@4103ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`1a
ooooo`00O_ooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000<ooooo`03o`000?oo
oooooooo00Kooooo00?oMgMgoc8b<_ooool04?ooool00ol0003oooooooooo`0;ooooo`Ko00003?oo
ool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool0LOooool007kooooo00Ko0000omgMgOlb<S;o
EEEEomgMgOl0000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00A
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
0000Loooool007kooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Kooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool04Oooool00ol@413o0000o`000003o`0001cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41000oooool0
1Ol@413ooooooooooooooooo410@07?ooooo001nooooo`06o`000?lb<S;ooooooooooolb<S;o0000
6oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Loooool007gooooo00?o410@o`000?n7
QhL00_ooool00on7QhOo0000oa0@400Hooooo`03oeEEEOmVIVKo000000Gooooo1?l0000Booooo`03
o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000001Oooool4o`0000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0Loooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1600) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01301 m
.02846 .01086 L
.03279 .00923 L
.04262 .00653 L
.0522 .00467 L
.06244 .00306 L
.06788 .00234 L
.07379 .00168 L
.07649 .00143 L
.07936 .00122 L
.08184 .00107 L
.08451 .00094 L
.08583 .00089 L
.08708 .00086 L
.0883 .00083 L
.08944 .00081 L
.09051 .00079 L
.09165 .00078 L
.09291 .00077 L
.09406 .00077 L
.09472 .00077 L
.09541 .00077 L
.09666 .00078 L
.09736 .00078 L
.098 .00079 L
.09948 .0008 L
.10213 .00082 L
.10329 .00083 L
.10458 .00084 L
.10583 .00085 L
.10701 .00085 L
.10825 .00085 L
.10895 .00085 L
.10959 .00085 L
.11085 .00085 L
.11157 .00084 L
.11224 .00084 L
.11359 .00082 L
.11503 .0008 L
.1177 .00075 L
.12022 .00068 L
.12493 .00051 L
.13377 .00015 L
s
.13377 .00015 m
.13801 0 L
s
.16412 0 m
.16811 7e-05 L
.16944 9e-05 L
.1707 .0001 L
.17184 .00011 L
.17305 .00012 L
.17411 .00013 L
.17527 .00013 L
.17633 .00013 L
.17732 .00013 L
.17848 .00013 L
.17955 .00012 L
.18072 .00011 L
.18195 .0001 L
.18454 6e-05 L
.18697 1e-05 L
s
.18697 1e-05 m
.18771 0 L
s
.22057 0 m
.22512 .00013 L
.22788 .0002 L
.23048 .00026 L
.2329 .00031 L
.23418 .00033 L
.23554 .00035 L
.23667 .00036 L
.23793 .00037 L
.23906 .00037 L
.24013 .00037 L
.24143 .00037 L
.24267 .00036 L
.24377 .00035 L
.24498 .00034 L
.24769 .0003 L
.2502 .00025 L
.2555 .00013 L
s
.2555 .00013 m
.26104 0 L
s
.28698 0 m
.2914 7e-05 L
.29382 .00011 L
.2961 .00014 L
.29833 .00016 L
.30037 .00018 L
.30145 .00019 L
.3026 .00019 L
.30374 .0002 L
.30501 .0002 L
.30624 .0002 L
.30693 .0002 L
.30756 .0002 L
.30879 .00019 L
.30995 .00019 L
.31255 .00017 L
.31497 .00015 L
.32043 .0001 L
.32296 8e-05 L
.3257 6e-05 L
.32828 4e-05 L
.32951 4e-05 L
.33065 3e-05 L
.33198 3e-05 L
.33268 3e-05 L
.33343 3e-05 L
.33422 3e-05 L
.33497 3e-05 L
.33564 3e-05 L
.33636 3e-05 L
.33767 3e-05 L
.33833 3e-05 L
.33905 3e-05 L
.34153 3e-05 L
.34401 4e-05 L
.34469 4e-05 L
.34542 4e-05 L
.34672 4e-05 L
.34736 4e-05 L
.34806 4e-05 L
.34931 4e-05 L
.35054 4e-05 L
.35166 3e-05 L
.35277 3e-05 L
.35381 2e-05 L
.35617 1e-05 L
s
.35617 1e-05 m
.35714 0 L
s
.40033 0 m
.40304 7e-05 L
.40547 .00013 L
.40809 .00019 L
.41051 .00024 L
.41281 .00028 L
.41404 .00029 L
.41469 .00029 L
.41538 .0003 L
.4166 .00031 L
.41774 .00031 L
.41844 .00031 L
.4192 .0003 L
.41992 .0003 L
.42058 .0003 L
.42183 .00028 L
.42316 .00027 L
.42571 .00023 L
.42813 .00017 L
.43265 6e-05 L
s
.43265 6e-05 m
.43484 0 L
s
.4598 0 m
.46117 5e-05 L
.47146 .0005 L
.47648 .00071 L
.47868 .00078 L
.48107 .00085 L
.48236 .00088 L
.48356 .0009 L
.48477 .00092 L
.48591 .00094 L
.48711 .00095 L
.48843 .00096 L
.48972 .00096 L
.49044 .00096 L
.4911 .00096 L
.49174 .00096 L
.49243 .00096 L
.49367 .00096 L
.49513 .00095 L
.49647 .00094 L
.49916 .00093 L
.4999 .00093 L
.50069 .00092 L
.50144 .00092 L
.50213 .00092 L
.50331 .00092 L
.50461 .00092 L
.50583 .00093 L
.50696 .00094 L
.50826 .00096 L
.50944 .00098 L
.5108 .00102 L
.51209 .00106 L
.51439 .00115 L
.5165 .00125 L
.52128 .00158 L
.5261 .00204 L
.53139 .00267 L
.54206 .00426 L
.55227 .00617 L
.56158 .00849 L
.56673 .01019 L
.57232 .0125 L
.57757 .01523 L
.5825 .01836 L
.5919 .02616 L
.60228 .03805 L
.61239 .05385 L
.62329 .07708 L
.63286 .10407 L
Mistroke
.64333 .14093 L
.65439 .18573 L
.66443 .22642 L
.66928 .24398 L
.67452 .26024 L
.67693 .26649 L
.67948 .27214 L
.68187 .27648 L
.68405 .27957 L
.68532 .28099 L
.68654 .28205 L
.68781 .28289 L
.68854 .28322 L
.68921 .28344 L
.69043 .28363 L
.69154 .28356 L
.69282 .28319 L
.69403 .28256 L
.69467 .28211 L
.69537 .28154 L
.69678 .28012 L
.6993 .27668 L
.70225 .27131 L
.705 .26506 L
.71548 .23258 L
.7254 .19474 L
.73423 .16107 L
.74397 .12899 L
.74863 .11646 L
.75365 .1053 L
.75896 .09617 L
.76133 .09296 L
.76393 .09006 L
.76648 .08781 L
.76773 .08692 L
.76886 .08624 L
.76995 .08569 L
.77113 .0852 L
.77237 .08483 L
.77355 .08459 L
.77461 .08448 L
.77578 .08448 L
.777 .08459 L
.77814 .08481 L
.7792 .08512 L
.78017 .08549 L
.78236 .08661 L
.78464 .08823 L
.78716 .09056 L
.79226 .09706 L
Mistroke
.79699 .10533 L
.80143 .11514 L
.81141 .14449 L
.82218 .1858 L
.83167 .22613 L
.84181 .2658 L
.84481 .27556 L
.84764 .28359 L
.85039 .29014 L
.85294 .29496 L
.85535 .29837 L
.85657 .29964 L
.85791 .30068 L
.85861 .30108 L
.85925 .30135 L
.85999 .30155 L
.86069 .30163 L
.86194 .30151 L
.86264 .3013 L
.8633 .301 L
.86459 .30015 L
.86579 .29905 L
.86709 .2975 L
.86848 .29548 L
.87335 .28535 L
.8777 .27276 L
.88247 .25577 L
.9029 .16591 L
.91293 .12472 L
.92243 .09272 L
.93337 .0647 L
.94335 .04596 L
.95162 .03412 L
.96041 .02442 L
.96791 .01813 L
.97619 .01301 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`08ooooo`Oo00001_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`04o`000?ooooooooooooooo`co00002?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo023ooooo000Tooooo`03o`000?oooooooooo00;ooooo1_l0000Vooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0=ooooo`?o
00007Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool08?ooool002Gooooo1?l0002<ooooo`03o`000?oooooooooo013ooooo0ol0002Mooooo`009?oo
ool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Mooo
ool00ol0003oooooooooo`0Pooooo`00]Oooool00ol0003oooooooooo`0Dooooo`;o0000M_ooool0
0ol0003oooooooooo`0Qooooo`00]Oooool2o`0001Oooooo0_l0001cooooo`03o`000?oooooooooo
02;ooooo002eooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0Koooool00ol0003o
ooooooooo`0Sooooo`00]Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo06gooooo
00?o0000ooooooooool09?ooool00;Gooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`1/ooooo`03o`000?oooooooooo02Gooooo002eooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool0J_ooool00ol0003oooooooooo`0Vooooo`00]Oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo06Sooooo00?o0000ooooooooool09oooool00;Gooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo02Sooooo002eooooo`;o0000
7Oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo02Wooooo002eooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Zooooo`00]Oooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0:_ooool0
0;Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
02_ooooo002eooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0H?ooool00ol0003o
ooooooooo`0[ooooo`00]Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo05oooooo
00?o0000ooooooooool0;?ooool00;Gooooo0_l0000Qooooo`03o`000?oooooooooo05kooooo00?o
0000ooooooooool0;?ooool00;Gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1M
ooooo`03o`000?oooooooooo02gooooo002eooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool0G?ooool00ol0003oooooooooo`0]ooooo`00]Oooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo05_ooooo00?o0000ooooooooool0;_ooool00;Gooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo02kooooo002eooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0^ooooo`00]Oooool2
o`0002?ooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0_ooooo`00]Oooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo02Sooooo1_l0000Zooooo`03o`000?oooooooooo
02oooooo002eooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool09oooool2o`0000Co
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0_ooooo`00]Oooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo033ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Gooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0<?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
<?ooool009[ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Gooooo
0ol0000Tooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo037ooooo002Jooooo`05o`000?ooooooooooooooool00000
3_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
<Oooool009[ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`0aooooo`00V_ooool01Ol@413ooooooooo
oooooooo410@00kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo03;ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0<_ooool009[ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`0booooo`00]Oooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo03?ooooo002eooooo`;o0000:?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0cooooo`00]Oooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo03?ooooo002eooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool0<oooool00;Gooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0dooooo`00]Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo03Cooooo002e
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0=?ooool00;Gooooo0_l0000Yoooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo03Cooooo002eooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0=Oooool00;Gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0eooooo`00]Ooo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo03Gooooo002eooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0=Oooool00;Gooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0eooooo`00]Oooool2o`0002_ooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0=_ooool00;Gooooo
00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0fooooo`00]Oooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo03Kooooo002eooooo`03o`000?oooooooooo02_ooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool0=_ooool00;Gooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0goooo
o`00]Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03Oooooo002eooooo`;o0000
;Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0gooooo`00]Oooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo03Oooooo002eooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0=oooool0
0;Gooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0hooooo`00V_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`0]oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo03Sooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0>?ooool009[ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7o
k^k^00Oooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0hooooo`00V_ooool01Ol0
003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0002gooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0>Oooool009[ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKo
oooo00Gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0iooooo`00V_ooool01Ol@
413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo03Wooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0iooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c006ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0>Oooool00;Gooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0jooooo`00]Oooool2o`00033ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool0>_ooool00;Gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0joooo
o`00]Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03[ooooo002eooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0>oooool00;Gooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0kooooo`00]Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo03_ooooo002eooooo`;o0000<Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0kooooo`00]Oooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo03_ooooo002eooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0??ooool00;Gooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0looooo`00]Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03cooooo002eoooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0?Oooool00;Gooooo0_l0000dooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo03gooooo002eooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
?Oooool00;Gooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0nooooo`00]Oooool0
0ol0003oooooooooo`0dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo03kooooo002eooooo`03o`000?oooooooooo
03Gooooo00Go0000ooooooooooooooooo`00000/ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0?_ooool00;Gooooo00?o0000ooooooooool0=Oooool4o`0002gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0oooooo`00]Oooool00ol0003oooooooooo`1Vooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0?oooool00;Gooooo0_l0001Xooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0?oooool00;Gooooo00?o0000ooooooooool0Iooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo043ooooo002eooooo`03o`000?oooooo
oooo06Sooooo00Co0000oooooooooooooooo0_l00012ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05oiRHV?l@413o0000oc8b<_o<c<`01_ooool00ol0003ooooo
ooooo`1Yooooo`04o`000?ooooooooooo`0004?ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo
06[ooooo0_l00014ooooo`00V_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol0003ooooooooooooooooo0000
00kooooo00?oZJVYoa0@4?ooool01Oooool3o`000;3ooooo002Jooooo`05o`000?oooooooooooooo
ool000003Oooool00ol@413o0000okZj^P06ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05
oa0@4?ooooooooooooooool@41003_ooool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo
0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413oV9RHoooooonj^[[o
000000Kooooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413ooooo
ooooo`04ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2`ooooo`00V_oo
ool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`?o0000/?ooool009[ooooo00Go
0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000oooooooo
ool0/?ooool009[ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`00
00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooa0@400<oooo
o`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0/?ooool009[o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000oooo
ooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00V_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009[ooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0002`ooooo`00V_oo
ool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00V_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@
41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3o
oooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool00ol0003o^[Zjooooo`2i
ooooo`00[?ooool2oc8b<[[ooooo001mooooo`;o000000Ko410@oooooooooooo410@o`000?l@410H
ooooo`Co000000Go410@ooooooooooooooooodA4A002o`000007oc8b<_oMgMgooooooooooon7QhOo
0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06Oooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oa0@4?o<c<`3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^07?ooooo001nooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01oooool6o`0000cooooo00?o0000ooooooooool01_ooool01omgMgOo<S8booooooooooooc<c<
o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<ooooo`03o`000?oo
oooooooo00;ooooo00GoEEEEogMgMoooooooV9RHob4Q8@03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg07?ooooo001nooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
401cooooo`00O_ooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000<ooooo`03o`00
0?oooooooooo00Kooooo00?oMgMgoc8b<_ooool04?ooool00ol0003oooooooooo`0;ooooo`Ko0000
3?ooool00ol0003oooooooooo`02ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00001cooooo`00O_ooool01_l0
003ogMgMoc8b<_mEEEGogMgMo`0001_ooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<017ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02ooooo`05o`00
0?mEEEGo0000oa0@4?o<c<`00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`00001cooooo`00O_ooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001_ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03oa0@4?l0003o000000?o00007?oo
ool00ol0003oooooooooo`02ooooo`03oeEEEOn7QhOooooo00Gooooo00Go410@oooooooooooooooo
oa0@4003ooooo`05oa0@4?ooooooooooooooool@4100Loooool007kooooo00Ko0000oc8b<_oooooo
oooooc8b<_l0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo00?ogMgMoa0@4?nHV9P01Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1cooooo`00OOooool0
0ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo00?oEEEEofIVI_l000001Oooool4
o`0001;ooooo00?o0000ooooooooool06oooool00omEEEGoIVIVo`000005ooooo`04olc<c?m4A4Co
0000oa0@40?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h0Loooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1700) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .20259 m
.03279 .15925 L
.04262 .11782 L
.05288 .08387 L
.06244 .06029 L
.0731 .04107 L
.0828 .02829 L
.08817 .02277 L
.094 .01787 L
.09946 .01424 L
.10458 .01157 L
.10913 .00972 L
.11402 .00817 L
.11945 .00683 L
.12442 .00584 L
.13532 .00403 L
.14545 .00253 L
.15464 .00143 L
.15728 .00119 L
.15977 .001 L
.16199 .00086 L
.16443 .00074 L
.16695 .00065 L
.16833 .00061 L
.16962 .00058 L
.17082 .00056 L
.17192 .00055 L
.17319 .00054 L
.17439 .00054 L
.17569 .00054 L
.17634 .00054 L
.17707 .00055 L
.17834 .00055 L
.17954 .00056 L
.18245 .00058 L
.18387 .00059 L
.18515 .0006 L
.18632 .00061 L
.18743 .00061 L
.18859 .00061 L
.18985 .00061 L
.19115 .00061 L
.1918 .00061 L
.19252 .0006 L
.1938 .00059 L
.19499 .00058 L
.19759 .00054 L
.19998 .00049 L
.20534 .00037 L
.20988 .00026 L
Mistroke
.21228 .0002 L
.21483 .00016 L
.21609 .00014 L
.21728 .00013 L
.21835 .00012 L
.21951 .00011 L
.22061 .0001 L
.22177 .0001 L
.22276 .0001 L
.22384 .00011 L
.22515 .00011 L
.22636 .00013 L
.2291 .00016 L
.23407 .00025 L
.23888 .00033 L
.24124 .00037 L
.24339 .0004 L
.24452 .00041 L
.24572 .00041 L
.24691 .00042 L
.24822 .00042 L
.24892 .00041 L
.24956 .00041 L
.25029 .00041 L
.25098 .0004 L
.25221 .00039 L
.25355 .00037 L
.25627 .00032 L
.25915 .00024 L
.26432 9e-05 L
Mfstroke
.26432 9e-05 m
.26699 0 L
s
.29689 0 m
.29724 1e-05 L
.29983 8e-05 L
.30226 .00014 L
.30479 .00019 L
.30589 .00021 L
.3071 .00023 L
.30836 .00024 L
.30957 .00025 L
.31023 .00025 L
.31095 .00025 L
.31222 .00025 L
.31342 .00025 L
.31471 .00023 L
.31593 .00022 L
.31705 .0002 L
.31917 .00016 L
.32142 .0001 L
s
.32142 .0001 m
.3247 0 L
s
.36035 0 m
.36186 5e-05 L
.36639 .00019 L
.36894 .00026 L
.37016 .00028 L
.3713 .0003 L
.37237 .00032 L
.37336 .00033 L
.37445 .00034 L
.37562 .00034 L
.37675 .00034 L
.37797 .00034 L
.37913 .00033 L
.3802 .00032 L
.38937 .00011 L
s
.38937 .00011 m
.39334 0 L
s
.41965 0 m
.42437 .00014 L
.42966 .00028 L
.43123 .00031 L
.43271 .00034 L
.43404 .00036 L
.43472 .00036 L
.43547 .00037 L
.43618 .00038 L
.43684 .00038 L
.43754 .00038 L
.43828 .00038 L
.43898 .00038 L
.43964 .00038 L
.44087 .00038 L
.44203 .00037 L
.4433 .00035 L
.44589 .00031 L
.44829 .00026 L
.45054 .0002 L
.45556 6e-05 L
s
.45556 6e-05 m
.45769 0 L
s
.53047 0 m
.5389 .00031 L
.54413 .00052 L
.5467 .00061 L
.54908 .00068 L
.5512 .00074 L
.55353 .00078 L
.55474 .0008 L
.55588 .00081 L
.55708 .00081 L
.55838 .00082 L
.55969 .00082 L
.56091 .00081 L
.56161 .00081 L
.56225 .0008 L
.56368 .00079 L
.56928 .00072 L
.57174 .00069 L
.57242 .00068 L
.57313 .00067 L
.57442 .00067 L
.57561 .00066 L
.57673 .00067 L
.57796 .00068 L
.57928 .00069 L
.57997 .0007 L
.58061 .00072 L
.58182 .00075 L
.58312 .0008 L
.58452 .00086 L
.58706 .001 L
.58939 .00117 L
.59475 .00171 L
.60042 .0025 L
.61012 .00421 L
.62051 .00634 L
.63079 .0088 L
.64016 .01186 L
.64467 .01383 L
.64957 .01646 L
.65849 .02286 L
.66789 .03225 L
.67827 .04623 L
.68911 .06575 L
.69928 .08986 L
.71947 .15662 L
.73798 .22661 L
.74272 .24163 L
.74778 .2548 L
.75024 .25991 L
Mistroke
.75256 .26387 L
.75465 .26668 L
.75574 .26786 L
.75691 .2689 L
.75819 .26976 L
.7594 .27031 L
.76013 .27051 L
.76083 .27062 L
.76214 .27059 L
.76281 .27045 L
.76351 .27023 L
.76479 .2696 L
.76557 .26907 L
.76631 .26848 L
.76768 .26713 L
.77017 .26389 L
.77245 .26004 L
.77761 .2486 L
.78737 .21877 L
.79648 .1858 L
.8071 .14749 L
.81716 .1164 L
.82693 .09358 L
.83245 .08423 L
.83509 .08067 L
.83755 .07784 L
.84184 .07408 L
.84412 .07267 L
.84539 .07206 L
.84656 .0716 L
.84779 .07123 L
.84843 .07108 L
.84912 .07096 L
.8504 .07083 L
.85156 .07081 L
.85268 .0709 L
.85391 .0711 L
.85506 .0714 L
.85612 .07176 L
.85858 .07295 L
.86082 .07445 L
.8634 .0767 L
.86585 .07936 L
.8702 .08543 L
.87493 .09411 L
.88013 .1063 L
.88566 .12245 L
.89559 .15944 L
.91526 .24996 L
.92388 .28528 L
Mistroke
.92876 .30072 L
.9311 .30656 L
.93331 .31104 L
.93446 .31295 L
.9357 .31468 L
.93673 .31585 L
.93786 .31686 L
.93909 .31761 L
.94039 .31801 L
.9416 .31802 L
.94273 .31771 L
.94401 .317 L
.94522 .31596 L
.94631 .31472 L
.9475 .31307 L
.95017 .30819 L
.95264 .3023 L
.95794 .28567 L
.96274 .26668 L
.97349 .21601 L
.97619 .20259 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01_ooool9o`0000Oooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0:o`0000_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo023ooooo000Tooooo`03o`000?oooooooooo01[ooooo1?l0000@ooooo`03o`00
0?oooooooooo02gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Qooooo`?o0000
2Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
8?ooool003kooooo0ol0001dooooo`03o`000?oooooooooo02Cooooo0ol00029ooooo`00>oooool3
o`0007Oooooo00?o0000ooooooooool09oooool3o`0008Kooooo000kooooo`03o`000?oooooooooo
07Oooooo00?o0000ooooooooool0:_ooool2o`0008Cooooo000iooooo`;o0000N_ooool2o`0002go
oooo00?o0000ooooooooool0POooool003Sooooo00?o0000ooooooooool0N_ooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo083ooooo000gooooo`03o`000?oooooooooo07_ooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`1oooooo`00=_ooool00ol0003oooooooooo`1l
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0O_ooool003Kooooo00?o0000oooo
ooooool0O?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo07gooooo000eooooo`03
o`000?oooooooooo07gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1mooooo`00
=?ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
O?ooool003?ooooo00?o0000ooooooooool0Ooooool2o`0003?ooooo00?o0000ooooooooool0Nooo
ool003?ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo07[ooooo000booooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`1jooooo`00<Oooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool0NOooool0037ooooo00?o0000ooooooooool0POooool00ol0003ooooo
ooooo`0dooooo`03o`000?oooooooooo07Wooooo000`ooooo`03o`000?oooooooooo08;ooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`1hooooo`00<?ooool00ol0003oooooooooo`22
ooooo`;o0000=_ooool00ol0003oooooooooo`1hooooo`00;oooool00ol0003oooooooooo`23oooo
o`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0Moooool002oooooo00?o0000oooooooo
ool0Poooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo07Oooooo000_ooooo`03o`00
0?oooooooooo08?ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0[ooooo`Ko0000
AOooool002kooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`0gooooo`03o`000?oo
oooooooo02[ooooo0_l00004ooooo`;o0000A?ooool002kooooo00?o0000ooooooooool0Q?ooool0
0ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`11ooooo`00;_ooool00ol0003oooooooooo`24ooooo`;o0000>Oooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0@Oooool002go
oooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`10ooooo`00;Oooool00ol0003ooooo
ooooo`25ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo043ooooo000]ooooo`03o`000?oooooooooo08Gooooo00?o
0000ooooooooool0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0?oooool002cooooo00?o0000ooooooooool0Joooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000?o410@ooooooooool00oooool00ol0003ooooooooo
o`0iooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0nooooo`00;?ooool00ol0003oooooooooo`1[ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0jooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0nooooo`00;?ooool0
0ol0003oooooooooo`1[ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003ooooooooo
o`05ooooo`?o0000>_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool0?Oooool002_ooooo00?o0000ooooooooool0K?ooool01Ol0003ooooooooooooo
oooo000000kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0jooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0mooooo`00:oooool0
0ol0003oooooooooo`1/ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo03gooooo000[ooooo`03o`000?oooooooooo06cooooo00Go410@
oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0??oo
ool002[ooooo00?o0000ooooooooool0KOooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0looooo`00:_ooool00ol0003oooooooooo`1]
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`000007ooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo03cooooo000Zooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool0??ooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0>oooool0
02[ooooo00?o0000ooooooooool0R?ooool2o`0003gooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo03_ooooo000Yooooo`03o`000?oooooooooo08Wo
oooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool0>oooool002Wooooo00?o0000ooooooooool0ROooool00ol0003ooooo
ooooo`0mooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0jooooo`00:Oooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo03gooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03[ooooo000Y
ooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0>_ooool002Sooooo00?o0000oooo
ooooool0R_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0jooooo`00:?ooool00ol0003oooooooooo`2:ooooo`;o
0000?oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool0>Oooool002Sooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`0nooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0iooooo`00:?oo
ool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03Wooooo000Wooooo`03o`000?oooooo
oooo08_ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool0>Oooool002Oooooo00?o0000ooooooooool0Roooool00ol0
003oooooooooo`0oooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0hooooo`009oooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo03oo
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo03So
oooo000Wooooo`03o`000?oooooooooo08_ooooo0_l00010ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0hooooo`009_ooool00ol0003ooooooooo
o`2<ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo03Sooooo000Vooooo`03o`000?oooooooooo08cooooo00?o0000
ooooooooool0@?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool0=oooool002Kooooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`10oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0goooo
o`009_ooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo047ooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo03Oooooo000Vooooo`03o`00
0?oooooooooo08cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool0=oooool002Gooooo00?o0000ooooooooool0SOoo
ool2o`0004;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo03Oooooo000Uooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool0@Oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0=_ooool0
02Gooooo00?o0000ooooooooool0SOooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0fooooo`009Oooool00ol0003o
ooooooooo`2=ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo03Kooooo000Uooooo`03o`000?oooooooooo07;ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000oooooooo
ool0@_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool0=_ooool002Cooooo00?o0000ooooooooool0Loooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`13oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0eoooo
o`009?ooool00ol0003oooooooooo`1cooooo`05oa0@4?ooooooooooooooool@41003?ooool00onH
V9So8B4Qonk^kP07ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool08?ooool009[o
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol00013oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo023ooooo002Jooooo`05o`000?ooooooooooooooool000003_ooool00omg
MgOoIVIVooooo`05ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool08?ooool009[o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0A?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Pooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo04Cooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool08?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo023ooooo002e
ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool08?ooool00;Gooooo0_l00016oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo027ooooo002eooooo`03o`000?oooooooooo04Gooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool08Oooool00;Gooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Qooooo`00]Ooo
ool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo027ooooo002eooooo`03o`000?oooooo
oooo04Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool08_ooool00;Gooooo00?o0000ooooooooool0Aoooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Rooooo`00]Oooool2o`0004Sooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool08_ooool00;Gooooo
00?o0000ooooooooool0B?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Sooooo`00]Oooool00ol0003ooooooooo
o`18ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo02?ooooo002eooooo`03o`000?oooooooooo04Sooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool08oooool00;Gooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Soooo
o`00]Oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Cooooo002eooooo`;o0000
Boooool01Ol0003ooooooooooooooooo000002gooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0Tooooo`00]Oooool00ol0003oooooooooo`1;ooooo`Co0000;_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo02Cooooo002eooooo`03o`000?oooooooooo07gooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0Tooooo`00]Oooool00ol0003oooooooooo`1m
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool09?ooool00;Gooooo00?o0000oooo
ooooool0OOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Gooooo002eooooo`03
o`000?oooooooooo07kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Uooooo`00
]Oooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
9Oooool00;Gooooo0_l0001oooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09Ooo
ool00;Gooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo02Kooooo002eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Vooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`05oiRHV?l@413o0000oc8b<_o<c<`01_ooool00ol0003oooooooooo`1oooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool09_ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Kooooo00?o0000ooooooooool0Oooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Oooooo002Jooooo`05oa0@4?oooooo
ooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo083ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Wooooo`00V_ooool01Ol0003ooooooooooooo
oooo000000kooooo00?oZJVYoa0@4?ooool01Oooool3o`00083ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0Xooooo`00V_ooool01Ol0003ooooooooooooooooo000000gooooo00?o
410@o`000?nj^[X01_ooool00ol0003oooooooooo`20ooooo`;o00000oooool00ol0003ooooooooo
o`0Xooooo`00V_ooool01Ol@413ooooooooooooooooo410@00kooooo00?o^[Zjob4Q8Oooool01Ooo
ool00ol0003oooooooooo`21ooooo`;o000000?oooooo`000?ooool0:_ooool009[ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003ooooo
ooooo`22ooooo`;o0000;?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04oooo
o`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413o
oooooooooooooooo410@00_ooooo1Ol00006ooooo`?o0000/?ooool009[ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0/?ooool0
09[ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o
0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<
c<co000000Oooooo00?o0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooo
oooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0002`ooooo`00V_ooool01Ol0003o
oooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`oooo
o`00V_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Joooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool00ol0003o^[Zjooooo`2iooooo`00[?oo
ool2oc8b<[[ooooo001mooooo`;o000000Ko410@oooooooooooo410@o`000?l@410Hooooo`Co0000
00Go410@ooooooooooooooooodA4A002o`000007oc8b<_oMgMgooooooooooon7QhOo0000okZj^P0<
ooooo`05oiRHV?l0003o0000odA4A?nj^[X06Oooool4o`000003oa0@4?oooooooooo00;ooooo00?o
0000onk^k_ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP1cooooo`00O_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo
1_l0000<ooooo`03o`000?oooooooooo00Kooooo00OoMgMgoc8b<_ooooooooooolc<c?l0003o410@
00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003oooooooooo`04
ooooo`03oeEEEOnYZJWooooo00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0Loooool007kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo00Cooooo00?oZJVYoeEEEOooool00oooool01Ol@413ooooooooo
oooooooo410@00?ooooo00Go410@oooooooooooooooooa0@401cooooo`00O_ooool01_l0003ooooo
odA4A?m4A4Coooooo`0000Wooooo1_l0000<ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b
<_ooool04?ooool00ol0003oooooooooo`0;ooooo`Ko00003?ooool00ol0003oooooooooo`05oooo
o`03ob4Q8Ooooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool00000Loooool007kooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Kooooo`03o`00
0?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Aooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool01Oooool00omEEEGoc<c<ooooo`02ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000007?ooooo001nooooo`06o`000?n7QhOoZJVY
okZj^_mEEEGo00006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o
410@o`000?l000000ol0000Looooo`03o`000?oooooooooo00Gooooo00?oZJVYogMgMoooool00_oo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@401cooooo`00
O_ooool01_l0003o<S8boooooooooooo<S8bo`0001_ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0Loooool007gooooo00?o410@o`000?n7QhL00_ooool00on7QhOo0000oa0@
400Hooooo`03oeEEEOmVIVKo000000Gooooo1?l0000Booooo`03o`000?oooooooooo01_ooooo00?o
EEEEofIVI_l000001?ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0Loooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1800) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .14355 m
.04262 .23439 L
.0522 .28052 L
.05746 .30148 L
.06244 .31668 L
.06506 .32249 L
.06644 .3249 L
.0679 .32694 L
.06912 .32823 L
.06982 .3288 L
.07047 .32921 L
.07162 .32966 L
.07286 .32977 L
.0741 .32947 L
.0748 .32912 L
.07545 .32868 L
.07665 .32758 L
.07792 .32601 L
.08035 .32188 L
.08255 .31689 L
.088 .29995 L
.0939 .27552 L
.10458 .22181 L
.12413 .12662 L
.13522 .08723 L
.14558 .06068 L
.15555 .04218 L
.16464 .02968 L
.16967 .0242 L
.17513 .01928 L
.18026 .01555 L
.18507 .01275 L
.18997 .01049 L
.19447 .00885 L
.19946 .00739 L
.20484 .00612 L
.21573 .00404 L
.22585 .00241 L
.23056 .0018 L
.235 .00133 L
.23746 .00112 L
.24012 .00095 L
.2413 .00089 L
.24254 .00083 L
.24369 .00079 L
.24478 .00075 L
.24606 .00072 L
.24723 .00071 L
.24849 .00069 L
.24921 .00069 L
Mistroke
.24987 .00069 L
.25108 .00069 L
.25218 .0007 L
.25344 .00071 L
.25463 .00073 L
.25981 .00081 L
.26254 .00086 L
.26408 .00088 L
.26481 .00089 L
.26548 .00089 L
.26672 .0009 L
.26738 .0009 L
.26808 .0009 L
.26925 .0009 L
.27054 .00089 L
.27172 .00088 L
.27298 .00086 L
.27527 .0008 L
.27789 .00072 L
.28066 .00061 L
.28559 .00037 L
.29058 .00011 L
Mfstroke
.29058 .00011 m
.29296 0 L
s
.32095 0 m
.32386 9e-05 L
.32806 .00021 L
.33042 .00026 L
.33259 .00029 L
.33375 .00031 L
.33502 .00032 L
.33634 .00032 L
.33757 .00032 L
.33875 .00032 L
.33983 .00031 L
.34107 .0003 L
.34224 .00029 L
.34463 .00026 L
.34686 .00022 L
.35195 .00012 L
.3547 6e-05 L
.35732 2e-05 L
s
.35732 2e-05 m
.35886 0 L
s
.37249 0 m
.37606 4e-05 L
.38067 .00011 L
.38311 .00014 L
.38569 .00017 L
.38703 .00018 L
.38775 .00018 L
.38852 .00019 L
.38922 .00019 L
.38987 .00019 L
.39114 .00019 L
.39233 .00019 L
.39344 .00019 L
.39466 .00018 L
.39596 .00017 L
.39862 .00014 L
.40104 .0001 L
s
.40104 .0001 m
.40678 0 L
s
.4321 0 m
.4388 .00014 L
.44153 .00019 L
.44408 .00023 L
.44536 .00024 L
.44608 .00024 L
.44674 .00025 L
.44745 .00025 L
.44823 .00025 L
.44897 .00025 L
.44965 .00025 L
.45083 .00025 L
.45195 .00024 L
.45317 .00022 L
.45448 .0002 L
.45716 .00015 L
.4596 8e-05 L
s
.4596 8e-05 m
.46191 0 L
s
.50768 0 m
.50913 3e-05 L
.51027 5e-05 L
.51152 7e-05 L
.51283 9e-05 L
.51407 .0001 L
.51472 .0001 L
.51543 .00011 L
.51618 .00011 L
.51688 .00011 L
.51813 .0001 L
.51883 .0001 L
.51947 9e-05 L
.52061 8e-05 L
.52183 6e-05 L
.52401 2e-05 L
s
.52401 2e-05 m
.52508 0 L
s
.5619 0 m
.56448 9e-05 L
.56726 .00017 L
.56988 .00025 L
.57232 .00031 L
.57361 .00033 L
.57497 .00035 L
.57612 .00037 L
.57738 .00038 L
.57853 .00039 L
.5796 .00039 L
.58077 .00039 L
.58205 .00039 L
.58326 .00038 L
.58438 .00037 L
.58649 .00035 L
.58874 .00032 L
.59346 .00024 L
.59611 .00019 L
.59855 .00016 L
.60102 .00013 L
.60226 .00012 L
.60297 .00011 L
.60362 .00011 L
.60483 .00011 L
.60593 .00011 L
.60719 .00011 L
.60839 .00012 L
.60971 .00013 L
.6111 .00015 L
.6136 .00019 L
.6163 .00025 L
.61926 .00033 L
.63868 .00098 L
.64392 .00115 L
.64951 .00135 L
.65478 .0016 L
.65956 .00192 L
.66476 .00237 L
.66967 .00293 L
.6807 .00461 L
.69035 .00653 L
.70079 .00918 L
.7103 .01257 L
.7157 .01518 L
.72073 .01821 L
.7309 .02654 L
.7366 .03269 L
.7418 .03932 L
.75106 .05378 L
Mistroke
.76089 .07335 L
.77168 .10075 L
.78165 .1321 L
.80135 .20424 L
.80998 .23283 L
.81487 .24585 L
.81941 .2551 L
.8218 .2587 L
.82397 .26115 L
.82517 .26217 L
.82648 .26298 L
.82771 .26348 L
.82884 .26371 L
.83003 .2637 L
.83114 .26347 L
.83235 .26297 L
.83366 .26215 L
.83503 .26098 L
.83633 .25958 L
.83876 .25621 L
.84394 .2461 L
.84874 .23365 L
.85962 .19815 L
.87846 .13228 L
.88837 .10336 L
.89881 .07956 L
.90415 .07021 L
.91 .06217 L
.91256 .05937 L
.91531 .05687 L
.91789 .05498 L
.92027 .05364 L
.92153 .05308 L
.92287 .0526 L
.92422 .05224 L
.92498 .0521 L
.9257 .05199 L
.92699 .05189 L
.92817 .0519 L
.92882 .05194 L
.92954 .05202 L
.93084 .05226 L
.9321 .05259 L
.93325 .05299 L
.93582 .05421 L
.93821 .05574 L
.94045 .05754 L
.94476 .062 L
.9495 .0685 L
.95444 .07723 L
Mistroke
.95906 .08732 L
.96733 .11062 L
.97619 .14355 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Go
oooo2Ol00007ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Gooooo2_l00006ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool08?ooool002Cooooo00?o0000ooooooooool0;_ooool01?l0003ooooo
ooooooooool4o`0002Sooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo00?ooooo1ol0000Sooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool08?ooool005Kooooo0ol0001Looooo`03o`000?oooooooooo03[ooooo0ol0001cooooo`00EOoo
ool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0L?oo
ool005?ooooo0_l0001Pooooo`03o`000?oooooooooo03kooooo0_l0001`ooooo`00D_ooool00ol0
003oooooooooo`1Pooooo`;o0000@Oooool2o`0006kooooo001Booooo`03o`000?oooooooooo063o
oooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`1[ooooo`00D?ooool2o`0006?ooooo
00?o0000ooooooooool0@oooool00ol0003oooooooooo`1Zooooo`00Coooool00ol0003ooooooooo
o`1Sooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0JOooool004oooooo00?o0000
ooooooooool0Hoooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo06Sooooo001>oooo
o`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`1Xoooo
o`00COooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo04Kooooo00?o0000oooooooo
ool0Ioooool004cooooo00?o0000ooooooooool0I_ooool2o`0004Oooooo00?o0000ooooooooool0
Ioooool004cooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`17ooooo`03o`000?oo
oooooooo06Kooooo001;ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0B?ooool0
0ol0003oooooooooo`1Uooooo`00Boooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool0<?ooool5o`0002oooooo001:ooooo`03o`000?oooooooooo06So
oooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0_ooooo`;o00001?ooool2o`0002go
oooo001:ooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0B_ooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0:_ooool004Wooooo00?o
0000ooooooooool0JOooool2o`0004_ooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo02Wooooo0019ooooo`03o`000?oooooooooo06Wooooo00?o0000
ooooooooool0Boooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0:Oooool004Sooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`1;oooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Xoooo
o`00B?ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo04cooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Sooooo0018ooooo`03o`00
0?oooooooooo06[ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool09oooool004Oooooo00?o0000ooooooooool0Jooo
ool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0Vooooo`00Aoooool00ol0003oooooooooo`1[ooooo`;o0000C_ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool09_ooool0
04Oooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Uooooo`00A_ooool00ol0003o
ooooooooo`1/ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo02Gooooo0016ooooo`03o`000?oooooooooo06cooooo
00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool09Oooool004Kooooo00?o0000ooooooooool0DOooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000?o410@ooooooooool00oooool00ol0003ooooo
ooooo`1>ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Tooooo`00AOooool00ol0003oooooooooo`1Booooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1?ooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Tooooo`00AOoo
ool00ol0003oooooooooo`1Booooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003ooooo
ooooo`05ooooo`?o0000Coooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool08oooool004Gooooo00?o0000ooooooooool0D_ooool01Ol0003ooooooooo
oooooooo000000kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1?ooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Sooooo`00AOoo
ool00ol0003oooooooooo`1Booooo`05o`000?ooooooooooooooool000003_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo02?ooooo0014ooooo`03o`000?oooooooooo05?ooooo00Go
410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
D?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
8_ooool004Cooooo00?o0000ooooooooool0Doooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Rooooo`00A?ooool00ol0003ooooooooo
o`1Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`000007ooooo`03o`00
0?oooooooooo057ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo02;ooooo0014ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0DOoo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool08Ooo
ool004?ooooo00?o0000ooooooooool0Koooool2o`0005;ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo027ooooo0013ooooo`03o`000?oooooooooo
06oooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool08Oooool004?ooooo00?o0000ooooooooool0Koooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0Qooooo`00@oooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo05;ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo027ooooo
0012ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0D_ooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool08?ooool004;ooooo00?o0000
ooooooooool0L?ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Pooooo`009?ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo073ooooo0_l0001Dooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0Pooooo`009?ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo073ooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo03kooooo000Tooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
L?ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
?oooool002Gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1aooooo`03o`000?oo
oooooooo05Cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0oooooo`009Oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0E?ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03oooooo000Uooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0@?ooool002Gooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`1aooooo`;o0000E_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo043o
oooo000Uooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0LOooool00ol0003ooooo
ooooo`1Eooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0@?ooool002Kooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo05Gooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`10ooooo`009_ooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo047ooooo000Vooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool0L_ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0@Oooool002Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1booooo`03
o`000?oooooooooo05Kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`11ooooo`00
9oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo07?ooooo0_l0001Gooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0@_ooool002Oooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`12ooooo`009oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo07?ooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo04;ooooo000Wooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0Loooool00ol0
003oooooooooo`1Gooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0@oooool002Oo
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Hooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo05Oooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`13ooooo`00:?ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo05Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnH
V9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo04?ooooo000Xooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0FOooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool0
0ol0003oooooooooo`1Hooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0@oooool0
02Sooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1Iooooo`05o`000?oooooooooo
ooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`?o0000F?ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo04Cooooo000Xooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0FOooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool0
0ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0A?ooool0
02Wooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Iooooo`05oa0@4?oooooooooo
ooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Wooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`14ooooo`00:Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo05[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0AOooool002Wooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1J
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo
00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04Gooooo
000Yooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0MOooool00ol0003ooooooooo
o`1Jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0AOooool002Wooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`1eooooo`;o0000Foooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo04Gooooo000Zooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0MOooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0A_ooool002[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1fooooo`03
o`000?oooooooooo05_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`16ooooo`00
:_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool0
Foooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04Kooooo000Zooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`1Kooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0Aoooool002_ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`1fooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`17ooooo`00:oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
07Kooooo0_l0001Mooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0B?ooool002_o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo05co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`18ooooo`00:oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool0GOooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo04Wooooo000[ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool0Moooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0BOooool002cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1g
ooooo`03o`000?oooooooooo05oooooo00Go0000ooooooooooooooooo`00001<ooooo`00;?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool0H?ooool3
o`0004gooooo000/ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Moooool2o`00
0;7ooooo000/ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0N?ooool00ol0003o
ooooooooo`2`ooooo`00;?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo07Sooooo
00?o0000ooooooooool0/?ooool002gooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`1hooooo`03o`000?oooooooooo0;3ooooo000]ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0N?ooool00ol0003oooooooooo`2`ooooo`00;Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0/?ooool002gooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo0;3ooooo000^ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0NOooool2o`000;7ooooo000^ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`2`ooooo`00;_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0/?ooool0
02oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Oooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oo
oooooooo0;3ooooo000_ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Goooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S80
1_ooool00ol0003oooooooooo`2`ooooo`00;oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo063ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0/?ooool002oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1Pooooo`05o`000?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`05ooooo`?o0000
/?ooool0033ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Pooooo`05o`000?oo
ooooooooooooool000003Oooool00ol@413o0000okZj^P06ooooo`03o`000?oooooooooo0;3ooooo
000`ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0HOooool01Ol@413ooooooooo
oooooooo410@00kooooo00?o^[Zjob4Q8Oooool01Oooool00ol0003oooooooooo`2`ooooo`00<?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo067ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003oooooooooo`2`ooooo`00
<Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo067ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`2`oooo
o`00<Oooool2o`0000;ooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`2`ooooo`00
<_ooool3o`00083ooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool0
0ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooo
oooooooooooooa0@400;ooooo`Go00001_ooool3o`000;3ooooo002Jooooo`05o`000?oooooooooo
ooooool000002oooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`000007ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`03ooooo`?o0000/?ooool009[ooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool0
09[ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00V_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00:cooooo00?o0000okZj^_ooool0^Oooool00:cooooo
0_lb<S:jooooo`00OOooool2o`000006oa0@4?oooooooooooa0@4?l0003o410@6?ooool4o`000005
oa0@4?oooooooooooooooom4A4@00_l000001olb<S;ogMgMooooooooooooQhN7o`000?nj^[X03?oo
ool01OnHV9So0000o`000?m4A4Co^[Zj01Wooooo1?l000002?l@413oooooooooooo<c<co8B4Qo`00
0?lQ8B7oc<c<0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP1cooooo`00O_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l0
000<ooooo`03o`000?oooooooooo00Kooooo00OoMgMgoc8b<_ooooooooooolc<c?l0003o410@00co
oooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003oooooooooo`02oooo
o`05ob4Q8OnHV9SooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`1cooooo`00O_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100Loooool007ko
oooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00003?ooool00ol0003oooooooooo`06
ooooo`03ogMgMolb<S;ooooo013ooooo00?o0000ooooooooool02oooool6o`0000cooooo00?o0000
ooooooooool00_ooool01Olb<S;oV9RHoooooonHV9So<S8b00?ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool00000Loooool007kooooo00Ko0000omgMgOlb<S;o
EEEEomgMgOl0000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00A
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Oo<c<co0000o`000?l0
003oc<c<00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
0000Loooool007kooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Kooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool04Oooool00ol@413o0000o`000003o`0001cooooo00?o0000oooo
ooooool00_ooool01Ol@413o^[Zjoooooonj^[[o410@00?ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100Loooool007kooooo00Ko0000oc8b<_oooooooooo
oc8b<_l0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo00Go0000okZj^_oooooo^[Zjo`000003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg07?ooooo001m
ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool00omEEEGoIVIVo`000005
ooooo`Co00004_ooool00ol0003oooooooooo`0Kooooo`03oeEEEOmVIVKo000000Cooooo00GoZJVY
oa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^07?ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1900) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .05698 m
.02846 .05059 L
.03279 .04562 L
.03754 .04126 L
.04018 .03934 L
.04262 .03789 L
.04518 .03672 L
.04652 .03624 L
.04795 .03585 L
.04919 .0356 L
.05035 .03544 L
.05163 .03535 L
.05234 .03534 L
.053 .03535 L
.0542 .03544 L
.05531 .0356 L
.05654 .03585 L
.05784 .0362 L
.06026 .0371 L
.06244 .03819 L
.06787 .04201 L
.07287 .04692 L
.07835 .05394 L
.08414 .0634 L
.09388 .08508 L
.09942 .1013 L
.10458 .11939 L
.12322 .20687 L
.13305 .2592 L
.13843 .28544 L
.14349 .30645 L
.14873 .32305 L
.15152 .32928 L
.15308 .33193 L
.15452 .33379 L
.15575 .33494 L
.1569 .33565 L
.15815 .33601 L
.15885 .33603 L
.15949 .33592 L
.16079 .33537 L
.16151 .33486 L
.16219 .33426 L
.16342 .33284 L
.16473 .3309 L
.16711 .32623 L
.16968 .31964 L
.17431 .30404 L
.18485 .25529 L
.2046 .15162 L
Mistroke
.21577 .10473 L
.22613 .07269 L
.23623 .0503 L
.24538 .0355 L
.25046 .02899 L
.25595 .02309 L
.26109 .01853 L
.26589 .01505 L
.27088 .01213 L
.27542 .01004 L
.28046 .00823 L
.28586 .00677 L
.29106 .0057 L
.2967 .00475 L
.30694 .00331 L
.31717 .00208 L
.32217 .00158 L
.32676 .00122 L
.33157 .00095 L
.3341 .00084 L
.33675 .00076 L
.33808 .00073 L
.33948 .00071 L
.34081 .00069 L
.34202 .00068 L
.34344 .00067 L
.34425 .00066 L
.34498 .00066 L
.34563 .00066 L
.34634 .00065 L
.34708 .00065 L
.34778 .00065 L
.3502 .00065 L
.35142 .00065 L
.35212 .00065 L
.35277 .00065 L
.35348 .00064 L
.35413 .00064 L
.3556 .00064 L
.35687 .00063 L
.35821 .00062 L
.36066 .00059 L
.36293 .00056 L
.3681 .00045 L
.377 .00022 L
.38169 .0001 L
.38425 5e-05 L
.38665 2e-05 L
.38791 1e-05 L
Mfstroke
.38791 1e-05 m
.38857 0 L
s
.39766 0 m
.39964 2e-05 L
.40193 4e-05 L
.4046 7e-05 L
.40709 9e-05 L
.40917 .00011 L
.41033 .00011 L
.41139 .00012 L
.41256 .00012 L
.41382 .00012 L
.41502 .00012 L
.41612 .00011 L
.41726 .00011 L
.41832 .0001 L
.42075 7e-05 L
.42312 3e-05 L
s
.42312 3e-05 m
.42432 0 L
s
.46974 0 m
.47172 7e-05 L
.4744 .00015 L
.47689 .00021 L
.47902 .00025 L
.48021 .00026 L
.48129 .00028 L
.48249 .00029 L
.48378 .00029 L
.485 .00029 L
.48613 .00029 L
.48732 .00028 L
.48861 .00026 L
.48982 .00025 L
.49094 .00023 L
.49624 .0001 L
s
.49624 .0001 m
.49946 0 L
s
.54456 0 m
.54666 4e-05 L
.54904 8e-05 L
.55157 .00012 L
.55298 .00014 L
.55425 .00015 L
.55555 .00016 L
.55675 .00017 L
.55786 .00017 L
.55903 .00018 L
.56021 .00018 L
.56151 .00018 L
.56262 .00018 L
.56383 .00018 L
.56496 .00017 L
.566 .00017 L
.56865 .00016 L
.57112 .00015 L
.57669 .00011 L
.58685 4e-05 L
s
.58685 4e-05 m
.59129 0 L
s
.64323 0 m
.64746 7e-05 L
.65252 .00015 L
.65535 .00018 L
.65669 .00019 L
.65792 .0002 L
.65907 .00021 L
.66032 .00021 L
.66159 .00022 L
.66228 .00022 L
.66292 .00022 L
.66411 .00022 L
.6652 .00022 L
.66645 .00022 L
.66764 .00022 L
.67003 .00021 L
.67261 .0002 L
.67379 .0002 L
.67504 .0002 L
.67611 .00019 L
.67727 .00019 L
.67849 .00019 L
.67979 .0002 L
.68102 .0002 L
.68214 .00021 L
.68347 .00022 L
.68491 .00024 L
.68752 .00028 L
.68973 .00032 L
.69217 .00039 L
.69709 .00057 L
.70165 .00078 L
.70593 .00103 L
.72447 .00225 L
.73427 .00293 L
.73964 .00337 L
.74471 .00389 L
.75046 .00466 L
.75567 .00559 L
.76056 .00671 L
.76585 .00823 L
.77631 .0124 L
.78594 .01781 L
.79568 .02518 L
.80477 .0343 L
.81474 .04762 L
.82543 .067 L
.83561 .09143 L
.84668 .12494 L
.8668 .1968 L
Mistroke
.87171 .21354 L
.87701 .22972 L
.88167 .2417 L
.88658 .25135 L
.88907 .25492 L
.89039 .25642 L
.89179 .25772 L
.89309 .25863 L
.89427 .25922 L
.89545 .25957 L
.89657 .2597 L
.89721 .25967 L
.89791 .25957 L
.89864 .25937 L
.89932 .2591 L
.90055 .25843 L
.90186 .25743 L
.9034 .2559 L
.90486 .2541 L
.90759 .24984 L
.91264 .23918 L
.91721 .22682 L
.92744 .19287 L
.94585 .12794 L
.96043 .08708 L
.96865 .06969 L
.97619 .05698 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`So00001?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`03ooooo`[o00002?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool08?ooool002Cooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0Kooooo`Ko00003?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool06Oooool5o`0000oooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`0Pooooo`00L?ooool3o`0004;ooooo00?o0000ooooooooool0C_ooool3o`0005oooooo001_
ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0DOooool2o`0005gooooo001]oooo
o`;o0000A_ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo05[ooooo001/ooooo`03
o`000?oooooooooo04Kooooo0_l0001Eooooo`;o0000F_ooool006_ooooo00?o0000ooooooooool0
Aoooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo05Oooooo001Zooooo`03o`000?oo
oooooooo04Sooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`1Fooooo`00JOooool0
0ol0003oooooooooo`19ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0E_ooool0
06Wooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo
05Gooooo000[ooooo`Go0000>?ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo05Wo
oooo00?o0000ooooooooool0E?ooool002Wooooo0_l00005ooooo`;o0000=_ooool00ol0003ooooo
ooooo`1:ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0E?ooool002Sooooo0_l0
0008ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0Boooool2o`0005_ooooo00?o
0000ooooooooool0Doooool002Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`1B
ooooo`009oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02oooooo00?o0000oooo
ooooool0COooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo057ooooo000Uooooo`;o
00003Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04gooooo00?o0000oooooooo
ool0G?ooool00ol0003oooooooooo`1Aooooo`009?ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`1Mooooo`03o`00
0?oooooooooo02gooooo00?o0000ooooooooool08?ooool003Kooooo00?o0000ooooooooool0:ooo
ool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`0Pooooo`00=oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo04oooooo0_l0001Pooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool08Oooool0
03Oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo
063ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Qooooo`00>?ooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0H?ooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo02;ooooo000hooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool0D?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool08_ooool003Wooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`1@ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0Sooooo`00>Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo053ooooo00?o0000
ooooooooool0HOooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02?ooooo000ioooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0DOooool2o`0006?ooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0Sooooo`00>_ooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo057ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo02Cooooo000jooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
DOooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
9?ooool003[ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Booooo`03o`000?oo
oooooooo06?ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Tooooo`00>oooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0Hooo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo02Gooooo000kooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool0=oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Hoooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo02Gooooo000kooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool0>?ooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01Ooo
ool3o`0006Cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Uooooo`00>oooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03Sooooo00Go0000ooooooooooooooooo`00
000>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0I?ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo02Kooooo000looooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool0>?ooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool09_oo
ool003cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0hooooo`05oa0@4?oooooo
ooooooooool@41003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06Gooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0Wooooo`00??ooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo03Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo02Oooooo000mooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0>Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001oooool00ol0003ooooooooo
o`1Uooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0:?ooool003gooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo06Kooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Xooooo`00?Oooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo05Gooooo0_l0001Wooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool0:?ooool003kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Eooooo`03
o`000?oooooooooo06Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Yooooo`00
?_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0
I_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Wooooo000nooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`1Wooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool0:Oooool003kooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`1Fooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Zooooo`00?_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
05Kooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
02[ooooo000oooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0E_ooool2o`0006Wo
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Zooooo`00?oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0J?ooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo02[ooooo000oooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool0Eoooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool0:oooool003oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1G
ooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0[
ooooo`00@?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo05Oooooo00?o0000oooo
ooooool0JOooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02_ooooo0010ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`1Yooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0:oooool0043ooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`1Hooooo`;o0000J_ooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo02cooooo0010ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0F?oo
ool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0;?oo
ool0043ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooo
oooo06[ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0/ooooo`00@Oooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0J_ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo02cooooo0011ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool0;Oooool0047ooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`1Iooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0]ooooo`00@Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo05Wooooo0_l0
001/ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0;Oooool004;ooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo06_ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0]ooooo`00@_ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo02kooooo0012ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0FOooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0;_ooool004;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0oooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo06co
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0^ooooo`00@_ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo03oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0K?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo02oooooo0013ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0?oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q
8Oo^k^h01oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0;oooool004?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0oooooo`05
o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`?o0000KOooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo02oooooo0013ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0?oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool01Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool0<?ooool004?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0oooooo`05
oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
06kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0`ooooo`00@oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo043ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool0<Oooool004Cooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`10ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<00Kooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo037ooooo0014ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Foooool0
0ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0<Oooool0
04Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Kooooo`;o0000L?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo03;ooooo0014ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0<_ooool004Cooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`1Looooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0booooo`00AOooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05cooooo00?o
0000ooooooooool0L?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03?ooooo0015
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`1`
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<oooool004Gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo077ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0cooooo`00AOooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo05cooooo0_l0001booooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0=?ooool004Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Mooooo`03o`00
0?oooooooooo07;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0dooooo`00A_oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0L_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Gooooo0016ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`1cooooo`;o00000_ooool0
0ol0003oooooooooo`0fooooo`00A_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
05gooooo00?o0000ooooooooool0M?ooool3o`0003Wooooo0016ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`2`ooooo`00A_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo05kooooo0_l0002aooooo`00A_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0/?ooool004Kooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo0;3ooooo0017oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`2`oooo
o`00Aoooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05kooooo00?o0000oooooooo
ool0/?ooool004Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Oooooo`03o`00
0?oooooooooo0;3ooooo0017ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Gooo
ool00ol0003oooooooooo`2`ooooo`00Aoooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo05oooooo0_l0002aooooo`00B?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
05oooooo00?o0000ooooooooool0/?ooool004Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`1Oooooo`03o`000?oooooooooo0;3ooooo0018ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00BOooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo04Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Kooooo00?o0000ooooooooool0/?ooool0
04Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`15ooooo`05oa0@4?oooooooooo
ooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;3ooooo0019oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0AOooool01Ol0003ooooooooooooooooo
000000kooooo00?oZJVYoa0@4?ooool01Oooool3o`000;3ooooo0019ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0A_ooool01Ol0003ooooooooooooooooo000000gooooo00?o410@
o`000?nj^[X01_ooool00ol0003oooooooooo`2`ooooo`00B_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo04Kooooo00Go410@oooooooooooooooooa0@400>ooooo`03okZj^_lQ8B7o
oooo00Gooooo00?o0000ooooooooool0/?ooool004[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`16ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413oV9RHoooooonj
^[[o000000Kooooo00?o0000ooooooooool0/?ooool004[ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`16ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`00
0?l@413oZJVY00Kooooo00?o0000ooooooooool0/?ooool004[ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo0;3ooooo001;ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0H_ooool2o`000;7ooooo001<ooooo`04o`000?oooooooooo
o`0006Gooooo00?o0000ooooooooool0/?ooool004cooooo0ol0001Vooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo
0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@
00_ooooo1Ol00006ooooo`?o0000/?ooool009[ooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0/?oo
ool009[ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o
0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000000Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002a
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`oooo
o`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooa0@400@oooo
o`03o`000?oooooooooo00?ooooo0ol0002`ooooo`00V_ooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol0003o
oooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002a
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00[?ooool00ol0003o^[Zjooooo`2iooooo`00[?ooool2oc8b<[[ooooo001m
ooooo`;o000000Ko410@oooooooooooo410@o`000?l@410Hooooo`Co000000Go410@oooooooooooo
ooooodA4A002o`000007oc8b<_oMgMgooooooooooon7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o
0000odA4A?nj^[X06Oooool4o`000007oa0@4?oooooooooooa0@4?l0003oA4A4olc<c004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07?ooooo001noooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`0000cooooo00?o0000oooo
ooooool01_ooool01omgMgOo<S8booooooooooooc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^
k_mgMgOo410@00Wooooo1_l0000<ooooo`03o`000?oooooooooo00Cooooo00?oV9RHoa0@4?oMgMd0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1coooo
o`00O_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool01Oooool00on7QhOoEEEEooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@07?ooooo001nooooo`06o`000?ooooooA4A4odA4A?oooooo00002Ooo
ool6o`0000cooooo00?o0000ooooooooool01_ooool00omgMgOo<S8booooo`0@ooooo`03o`000?oo
oooooooo00_ooooo1_l0000<ooooo`03o`000?oooooooooo00;ooooo00Goc<c<ob4Q8Ol0003oEEEE
o`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
07?ooooo001nooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo00006oooool00ol0003oooooooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`04Oooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00;ooooo00Go8B4QohN7QoooooooV9RHo`000003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000007?ooooo001nooooo`06o`000?n7QhOoZJVYokZj
^_mEEEGo00006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o410@
o`000?l000000ol0000Looooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@07?o
oooo001nooooo`06o`000?lb<S;ooooooooooolb<S;o00006oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02oooo
o`05ob4Q8OnHV9SoooooogMgMomEEED00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`1cooooo`00OOooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0
003o410@01Sooooo00?oEEEEofIVI_l000001Oooool4o`0001;ooooo00?o0000ooooooooool06ooo
ool00omEEEGoIVIVo`000004ooooo`05olc<c?l@413o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1cooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2000) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24418 m
.04262 .18868 L
.06244 .11858 L
.07216 .0902 L
.08255 .06659 L
.08852 .056 L
.09396 .04799 L
.09911 .04163 L
.10458 .03601 L
.10932 .03201 L
.11454 .02846 L
.11682 .02719 L
.11928 .02603 L
.12159 .02513 L
.12373 .02447 L
.12512 .02413 L
.12639 .02388 L
.12779 .02368 L
.12856 .0236 L
.12929 .02354 L
.12993 .02351 L
.13061 .0235 L
.13183 .02352 L
.13314 .0236 L
.13389 .02368 L
.13458 .02378 L
.13587 .02401 L
.13709 .02428 L
.13937 .02497 L
.14183 .02595 L
.14451 .0273 L
.14936 .03052 L
.15391 .03446 L
.15932 .04038 L
.16428 .0471 L
.17439 .06548 L
.1797 .0783 L
.18529 .0947 L
.19484 .13047 L
.20503 .17918 L
.2234 .27714 L
.22838 .29979 L
.23364 .31911 L
.23639 .32683 L
.23785 .33019 L
.23942 .3332 L
.24086 .3354 L
.24217 .33692 L
.24349 .33798 L
.24475 .33854 L
Mistroke
.24602 .33867 L
.24717 .3384 L
.24781 .33809 L
.2485 .33764 L
.24975 .33647 L
.25093 .335 L
.25217 .33304 L
.25439 .32853 L
.25698 .32172 L
.2594 .31397 L
.2649 .29203 L
.28357 .19404 L
.29342 .14414 L
.30386 .10128 L
.30912 .0841 L
.31492 .06827 L
.32514 .04684 L
.33553 .03126 L
.34527 .02077 L
.34998 .0169 L
.35513 .01348 L
.3605 .01071 L
.36549 .00877 L
.37019 .00737 L
.37445 .00637 L
.38401 .00463 L
.39336 .00314 L
.40323 .00166 L
.4084 .00102 L
.41113 .00073 L
.41407 .00049 L
.41545 .0004 L
.41677 .00032 L
.41804 .00026 L
.41923 .00022 L
.42034 .00019 L
.42153 .00016 L
.42273 .00015 L
.42405 .00014 L
.42526 .00014 L
.42639 .00016 L
.42763 .00018 L
.42895 .0002 L
.43166 .00029 L
.43412 .00038 L
.43893 .00056 L
.44104 .00064 L
.44337 .00071 L
.44457 .00073 L
.44587 .00076 L
Mistroke
.44658 .00077 L
.44723 .00078 L
.44851 .00079 L
.44922 .00079 L
.44988 .00079 L
.4506 .00079 L
.45137 .00079 L
.45211 .00078 L
.4528 .00077 L
.45409 .00075 L
.45532 .00072 L
.45662 .00068 L
.45895 .0006 L
.46422 .00037 L
.46909 .00012 L
Mfstroke
.46909 .00012 m
.47166 0 L
s
.50275 0 m
.50472 5e-05 L
.50706 .0001 L
.50951 .00014 L
.51081 .00015 L
.51153 .00016 L
.5122 .00017 L
.51337 .00017 L
.51446 .00017 L
.51565 .00017 L
.51692 .00017 L
.51814 .00016 L
.51928 .00014 L
.52141 .00012 L
s
.52141 .00012 m
.52687 0 L
s
.60314 0 m
.61072 .00017 L
.61339 .00023 L
.6163 .00029 L
.61763 .00031 L
.61905 .00033 L
.61974 .00033 L
.62039 .00034 L
.6216 .00035 L
.62285 .00035 L
.62416 .00035 L
.62529 .00034 L
.62652 .00033 L
.62721 .00032 L
.62784 .00032 L
.62926 .00029 L
.63182 .00023 L
.63413 .00016 L
.63662 8e-05 L
s
.63662 8e-05 m
.63849 0 L
s
.6765 0 m
.67997 .00018 L
.68462 .00037 L
.68589 .00042 L
.68725 .00046 L
.68842 .00049 L
.68969 .00051 L
.69082 .00053 L
.69186 .00053 L
.69286 .00054 L
.6939 .00054 L
.69506 .00053 L
.69613 .00052 L
.6973 .0005 L
.69856 .00047 L
.70114 .0004 L
.70388 .0003 L
.70878 8e-05 L
s
.70878 8e-05 m
.71044 0 L
s
.7405 0 m
.74502 .00025 L
.75047 .00053 L
.75297 .00065 L
.75562 .00075 L
.75791 .00083 L
.76037 .00089 L
.76275 .00094 L
.76492 .00097 L
.76701 .00099 L
.7692 .00101 L
.77182 .00103 L
.7743 .00105 L
.77652 .00108 L
.77778 .00109 L
.77893 .00112 L
.78114 .00117 L
.78357 .00125 L
.78611 .00136 L
.78848 .0015 L
.7934 .00187 L
.79868 .00242 L
.80828 .00375 L
.81705 .00527 L
.82627 .00719 L
.83608 .00993 L
.84173 .01205 L
.84684 .01444 L
.85682 .02073 L
.86687 .02965 L
.87611 .04055 L
.88625 .05622 L
.89694 .07818 L
.90645 .10331 L
.91663 .13601 L
.93497 .20183 L
.94513 .23295 L
.94791 .23974 L
.95086 .24587 L
.95341 .25022 L
.95482 .25221 L
.95616 .25383 L
.95738 .25507 L
.95872 .25615 L
.95994 .25689 L
.96107 .25736 L
.96224 .25763 L
.96331 .25769 L
.96453 .25752 L
.96569 .25714 L
Mistroke
.96696 .25647 L
.96831 .25548 L
.97073 .253 L
.97333 .24933 L
.97619 .24418 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05o`0000Cooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo3Ol0000;ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo023ooooo000Tooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`05ooooo`Oo00008Oooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo02gooooo1_l0000Zooooo`03o`000?oooooooooo023ooooo002:ooooo`?o0000:?oo
ool00ol0003oooooooooo`1Sooooo`;o0000Boooool008Sooooo0_l0000[ooooo`03o`000?oooooo
oooo06Gooooo00?o0000ooooooooool0B?ooool008Oooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`1Vooooo`?o0000Aoooool008Kooooo00?o0000ooooooooool0;?ooool2o`0006[o
oooo00?o0000ooooooooool0A?ooool004?ooooo1?l0000oooooo`03o`000?oooooooooo02cooooo
00?o0000ooooooooool0J_ooool00ol0003oooooooooo`13ooooo`00@Oooool3o`0000?ooooo0ol0
000kooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0Joooool00ol0003ooooooooo
o`12ooooo`00?oooool2o`0000Wooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0@Oooool003kooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02oooooo00?o0000oooo
ooooool0KOooool00ol0003oooooooooo`10ooooo`00?Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo03Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1^ooooo`03
o`000?oooooooooo03oooooo000looooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0
?_ooool003_ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo037ooooo0_l0001`ooooo`03o`000?oooooooooo03kooooo000kooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo073ooooo00?o0000ooooooooool0?Oooool003[ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0LOooool00ol0
003oooooooooo`0looooo`00>Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02co
oooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03co
oooo000hooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0>oooool003Sooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03Cooooo00?o
0000ooooooooool0L_ooool00ol0003oooooooooo`0kooooo`00=oooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0=?ooool2o`0007Cooooo00?o0000
ooooooooool0>_ooool003Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`0joooo
o`00=_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo03Wooooo000eooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo07Cooooo00?o0000ooooooooool0>Oooool003Gooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0M?oo
ool00ol0003oooooooooo`0iooooo`00=Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`1eooooo`03o`000?oooooo
oooo03Sooooo000dooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0fooooo`;o0000M_ooool00ol0003oooooooooo`0hooooo`00=?ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`1fooooo`03o`000?oooooooooo03Oooooo000dooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo07Kooooo
00?o0000ooooooooool0=oooool003?ooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0M_ooool00ol0003ooooooooo
o`0gooooo`00<oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool07Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000?o
410@ooooooooool00oooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo03Kooooo000b
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0M
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo03Kooooo000booooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Nooooo`05oa0@4?oooooo
ooooooooool@41003_ooool00ol0003oooooooooo`05ooooo`?o0000Moooool00ol0003ooooooooo
o`0fooooo`00<_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool07_ooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo03Gooooo000aooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Nooooo`05o`000?oooooo
ooooooooool000003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07Sooooo00?o
0000ooooooooool0=Oooool0037ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo01oooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`0dooooo`00<Oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1iooooo`03o`000?oooooooooo03Cooooo000`ooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0Oooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?oo
ool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0=?oo
ool0033ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0cooooo`00<?ooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0>oooool2o`00
07_ooooo00?o0000ooooooooool0<oooool002oooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0N_ooool00ol0003o
ooooooooo`0cooooo`00;oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo03;ooooo
000_ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0<_ooool002kooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0Noooool00ol0003oooooooooo`0booooo`00;_ooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`1koooo
o`03o`000?oooooooooo03;ooooo000^ooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0looooo`;o0000OOooool00ol0003oooooooooo`0aooooo`00
;_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo037ooooo000]ooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0looooo`03o`000?oo
oooooooo07cooooo00?o0000ooooooooool0<Oooool002gooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0OOooool0
0ol0003oooooooooo`0`ooooo`00;Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo
033ooooo000/ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0mooooo`03o`000?oooooooooo07gooooo00?o0000ooooooooool0<?ooool002cooooo
00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo03gooooo
0_l0001oooooo`03o`000?oooooooooo02oooooo000/ooooo`03o`000?oooooooooo02_ooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo07kooooo00?o
0000ooooooooool0;oooool002cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0_
ooooo`00:oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool0?_ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo02oooooo000[ooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0nooooo`03
o`000?oooooooooo07oooooo00?o0000ooooooooool0;_ooool002_ooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0
Ooooool00ol0003oooooooooo`0^ooooo`00:_ooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0?_ooool2o`00083ooooo00?o0000ooooooooool0;_oo
ool002[ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo03oooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`0]ooooo`00:_ooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0?oooool00ol0
003oooooooooo`20ooooo`03o`000?oooooooooo02gooooo000Yooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo083o
oooo00?o0000ooooooooool0;Oooool002Wooooo00?o0000ooooooooool0<?ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo02Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`0/ooooo`00
:Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@01_ooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo02cooooo000Xooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Tooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo
087ooooo00?o0000ooooooooool0;?ooool002Sooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo02Gooooo00Go0000ooooooooooooooooo`00000=oooo
o`03oiRHV?lQ8B7ok^k^00Kooooo0ol00021ooooo`03o`000?oooooooooo02cooooo000Xooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Uooooo`05
o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo
08;ooooo00?o0000ooooooooool0:oooool002Oooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo02Gooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`0[oooo
o`009oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool09Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006
ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0:oooool002Oooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Gooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooooooo
o`23ooooo`03o`000?oooooooooo02[ooooo000Vooooo`03o`000?oooooooooo03Gooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo08?ooooo00?o0000
ooooooooool0:_ooool002Kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo047ooooo0_l00024ooooo`03o`000?oooooooooo02[ooooo000Vooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`11ooooo`03
o`000?oooooooooo08Cooooo00?o0000ooooooooool0:Oooool002Gooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0
Q?ooool00ol0003oooooooooo`0Yooooo`009Oooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`24ooooo`03o`000?oo
oooooooo02Wooooo000Uooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`11ooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool0:?ooool0
02Cooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
047ooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
023ooooo001Oooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0@_ooool2o`0008Oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`00Goooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0Q_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo023ooooo001Oooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool0@_ooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool08Oooool0063ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`12
ooooo`03o`000?oooooooooo08Sooooo1?l0000Tooooo`00H?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0/?ooool0063ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo0;3ooooo001Pooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0@oooool2o`000;7ooooo001Pooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`2`ooooo`00HOooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0/?ooool0
067ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo
0;3ooooo001Qooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0@oooool00ol0003o
ooooooooo`2`ooooo`00HOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04?ooooo
00?o0000ooooooooool0/?ooool0067ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`14ooooo`03o`000?oooooooooo0;3ooooo001Rooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0A?ooool2o`000;7ooooo001Rooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0A?ooool00ol0003oooooooooo`2`ooooo`00H_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo04Cooooo00?o0000ooooooooool0/?ooool006;ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Zooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0;3ooooo001Rooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0:_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S801_ooool00ol0003oooooooooo`2`
ooooo`00Hoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02[ooooo00Go410@oooo
oooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0/?ooool0
06?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0[ooooo`05o`000?oooooooooo
ooooool000003_ooool00onYZJWo410@ooooo`05ooooo`?o0000/?ooool006?ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0[ooooo`05o`000?ooooooooooooooool000003Oooool0
0ol@413o0000okZj^P06ooooo`03o`000?oooooooooo0;3ooooo001Tooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0:oooool01Ol@413ooooooooooooooooo410@00kooooo00?o^[Zj
ob4Q8Oooool01Oooool00ol0003oooooooooo`2`ooooo`00I?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9So
oooookZj^_l000001_ooool00ol0003oooooooooo`2`ooooo`00I?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@
413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`2`ooooo`00IOooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0/?ooool006Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`18ooooo`;o0000/Oooool006Kooooo00Go0000oooo
ooooooooooooo`00001:ooooo`03o`000?oooooooooo0;3ooooo001Vooooo`;o000000?oooooo`00
0?ooool0B_ooool00ol0003oooooooooo`2`ooooo`00Ioooool3o`0004_ooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`00
0003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol0002`oooo
o`00V_ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool0
0ol0003oooooooooo`2`ooooo`00V_ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgM
oeEEEOoooooo00001oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`2`ooooo`00V_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0003ooooooooo
o`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_oo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`oooo
o`00V_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`00
0;3ooooo002Jooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo0;3ooooo002Jooooo`05o`000?ooooooooooooooool000003?ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool0
09[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002/ooooo`03o`00
0?nj^[[ooooo0;Wooooo002/ooooo`;o<S8b^_ooool007gooooo0_l000001_l@413oooooooooool@
413o0000oa0@41Sooooo1?l000001Ol@413oooooooooooooooooA4A400;o000000Oo<S8bomgMgOoo
ooooooooohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`Go00000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h0Loooool007kooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`07ooooo`Ko00003?ooool00ol0003oooooooooo`06ooooo`07ogMgMolb<S;ooooooooo
ooo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00Go
V9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1cooooo`00O_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo01_ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@
413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oo
ooooooooooooool@4100Loooool007kooooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko
00003?ooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo013ooooo00?o0000oooooooo
ool02oooool6o`0000_ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000Looo
ool007kooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Kooooo`03o`000?oooooooooo00?ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c00Aooooo`03o`000?oooooooooo01gooooo00?oMgMgofIVI_oo
ool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool00000Loooool007kooooo00Ko0000ohN7QonYZJWo^[ZjoeEE
EOl0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol@413o0000
o`000003o`0001gooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0LOooool0
07kooooo00Ko0000oc8b<_oooooooooooc8b<_l0000Kooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Jooooo`05o`000?nj^[[ooooooiRHV?l@4100
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL0Loooool007gooooo00?o410@o`000?n7QhL00_ooool00on7
QhOo0000oa0@400Hooooo`03oeEEEOmVIVKo000000Gooooo1?l0000Booooo`03o`000?oooooooooo
01[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1cooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2100) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .11394 m
.04262 .17911 L
.0522 .21263 L
.05746 .22872 L
.06244 .24133 L
.06506 .2467 L
.0679 .25142 L
.06915 .25311 L
.07047 .25463 L
.07172 .2558 L
.07286 .25664 L
.074 .25728 L
.07524 .25771 L
.07638 .25789 L
.07747 .25785 L
.07873 .25755 L
.0799 .25704 L
.08118 .25621 L
.08255 .25503 L
.08541 .2516 L
.0885 .24649 L
.09411 .23392 L
.10458 .20196 L
.12413 .13318 L
.13448 .1011 L
.14558 .07313 L
.15627 .05257 L
.166 .03874 L
.17069 .03354 L
.1758 .02885 L
.18507 .02248 L
.18992 .02009 L
.19447 .01834 L
.19946 .01693 L
.20227 .01637 L
.20352 .01617 L
.20484 .01599 L
.20617 .01586 L
.20738 .01577 L
.20859 .01571 L
.20973 .01569 L
.21038 .01569 L
.21107 .0157 L
.2123 .01575 L
.21298 .0158 L
.21362 .01585 L
.21508 .01601 L
.21647 .01622 L
.21779 .01647 L
.22027 .01708 L
Mistroke
.22294 .01795 L
.22585 .01916 L
.23118 .02214 L
.2362 .02591 L
.24556 .0357 L
.25082 .04296 L
.25565 .05096 L
.26655 .0748 L
.27631 .10507 L
.28541 .14241 L
.30609 .25137 L
.31111 .27756 L
.31657 .30267 L
.31907 .31252 L
.32172 .32159 L
.32401 .32813 L
.32648 .33372 L
.32764 .33581 L
.32886 .3376 L
.3299 .33882 L
.33104 .3398 L
.33211 .3404 L
.33326 .34067 L
.33434 .34059 L
.33531 .34024 L
.33657 .33939 L
.33772 .33821 L
.33899 .3365 L
.34033 .33422 L
.34258 .32932 L
.34505 .32247 L
.35028 .30346 L
.35524 .28082 L
.36454 .23123 L
.37467 .17565 L
.38544 .12442 L
.39489 .08969 L
.40533 .06175 L
.41482 .04346 L
.42374 .03058 L
.43356 .02003 L
.43849 .01598 L
.4439 .01242 L
.44853 .01004 L
.45348 .00809 L
.45815 .0067 L
.4624 .00573 L
.47236 .00413 L
.48156 .00301 L
.49229 .00188 L
Mistroke
.49754 .00143 L
.50234 .00111 L
.50456 .00099 L
.50698 .00088 L
.51138 .00073 L
.51381 .00067 L
.51641 .00062 L
.52108 .00054 L
.52666 .00045 L
.53191 .00033 L
.54172 3e-05 L
Mfstroke
.54172 3e-05 m
.54252 0 L
s
.57063 0 m
.57081 1e-05 L
.57574 .0002 L
.58029 .00035 L
.58274 .00042 L
.58398 .00044 L
.58534 .00046 L
.58606 .00047 L
.58671 .00048 L
.58746 .00048 L
.58817 .00048 L
.58944 .00048 L
.59016 .00048 L
.59082 .00047 L
.59212 .00045 L
.59335 .00043 L
.59563 .00037 L
.5981 .00029 L
.60076 .00018 L
s
.60076 .00018 m
.60444 0 L
s
.63896 0 m
.63934 2e-05 L
.64187 .00014 L
.6446 .00026 L
.647 .00035 L
.64832 .00039 L
.64955 .00042 L
.65096 .00045 L
.65171 .00046 L
.65252 .00047 L
.65325 .00047 L
.65395 .00047 L
.65525 .00047 L
.65654 .00046 L
.65773 .00044 L
.65904 .00042 L
.66043 .00038 L
s
.66043 .00038 m
.66915 0 L
s
.71169 0 m
.71308 4e-05 L
.71539 .00011 L
.7175 .00015 L
.71863 .00016 L
.71982 .00018 L
.72102 .00019 L
.72233 .00019 L
.72362 .00019 L
.72434 .00019 L
.725 .00019 L
.72627 .00018 L
.72748 .00017 L
.73019 .00013 L
.73269 8e-05 L
s
.73269 8e-05 m
.73685 0 L
s
.76328 0 m
.76699 6e-05 L
.76961 .00011 L
.77247 .00015 L
.77377 .00017 L
.77516 .00018 L
.77647 .00019 L
.77766 .0002 L
.77887 .00021 L
.78017 .00021 L
.78132 .00021 L
.78253 .00021 L
.78317 .00021 L
.78386 .00021 L
.7851 .00021 L
.78586 .00021 L
.78657 .00021 L
.78791 .0002 L
.79009 .00019 L
.79128 .00019 L
.7924 .00019 L
.7936 .00018 L
.79424 .00018 L
.79493 .00018 L
.79615 .00018 L
.79727 .00019 L
.79839 .00019 L
.7996 .0002 L
.80073 .00021 L
.80176 .00022 L
.80428 .00026 L
.80666 .0003 L
.81095 .00042 L
.81559 .00057 L
.82503 .00093 L
.83022 .0011 L
.83514 .00121 L
.83792 .00126 L
.84095 .00129 L
.84624 .00135 L
.84885 .00139 L
.85162 .00144 L
.85399 .00151 L
.8566 .0016 L
.85909 .00173 L
.86172 .0019 L
.86641 .00232 L
.87145 .00294 L
.87697 .00383 L
.88688 .00589 L
Mistroke
.8961 .00828 L
.90662 .0117 L
.91179 .01385 L
.91656 .01622 L
.92548 .02206 L
.93018 .02603 L
.93515 .03104 L
.94459 .04309 L
.95473 .06024 L
.9643 .08105 L
.97304 .10446 L
.97619 .11394 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooool000002ol0000:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooo
oooooooo4Ol00003ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Pooooo`009?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool08?ooool3o`0000[ooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo01;ooooo0ol0000Hooooo`03o`000?oooooooooo023o
oooo002Uooooo`?o00003Oooool00ol0003oooooooooo`1eooooo`?o0000>?ooool00:?ooooo0_l0
000@ooooo`03o`000?oooooooooo07Sooooo0ol0000eooooo`00FOooool8o`00047ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`1kooooo`;o0000<oooool005Kooooo0ol00008oooo
o`;o0000?_ooool00ol0003oooooooooo`0Aooooo`;o0000O_ooool00ol0003oooooooooo`0`oooo
o`00EOooool00ol0003oooooooooo`0;ooooo`;o0000>oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo07kooooo00?o0000ooooooooool0;oooool005Cooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
Ooooool00ol0003oooooooooo`0^ooooo`00D_ooool2o`0001;ooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool0;Ooo
ool0057ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`0/ooooo`00DOooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`22ooooo`03o`000?oooooooooo02_ooooo001@ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo08?o
oooo00?o0000ooooooooool0:_ooool0053ooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo01Oooooo0_l00025ooooo`03o`000?oooooooooo02Wooooo
001?ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0;oooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo08Cooooo00?o0000ooooooooool0:Oooool004kooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool0QOooool00ol0003oooooooooo`0Xooooo`00COooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo02cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`26oooo
o`03o`000?oooooooooo02Oooooo001=ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo08Kooooo00?o0000oooooooo
ool09oooool004cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Zooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`0Vooooo`00Booo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06_oo
ool2o`0008Sooooo00?o0000ooooooooool09_ooool004_ooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0R?ooool0
0ol0003oooooooooo`0Uooooo`00B_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo
02Gooooo0019ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool09?ooool004Wooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0ROooool00ol0003oooooooooo`0Tooooo`00B?ooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`29ooooo`03o`000?oooooooooo02Cooooo0018ooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0Looooo`;o0000Roooool00ol0003oooooooooo`0S
ooooo`00B?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo02?ooooo0017ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo08[ooooo00?o0000ooooooooool08oooool004Oooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
Roooool00ol0003oooooooooo`0Rooooo`00Aoooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B45ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`2;ooooo`03o`00
0?oooooooooo02;ooooo0016ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo02;ooooo
0016ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`03ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05ooooo`?o0000
S?ooool00ol0003oooooooooo`0Qooooo`00A_ooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo027ooooo
0016ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`04ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo08cooooo00?o0000ooooooooool08Oooool004Gooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooo
oa0@400>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0SOooool00ol0003ooooo
ooooo`0Pooooo`009?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool0
8?ooool002Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool01?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`009?ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo0;3ooooo000Uooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo023ooooo0_l0002a
ooooo`009Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0;3ooooo000Uooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0/?ooool002Kooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`2`ooooo`009_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo0;3ooooo000Vooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0/?ooool0
02Oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool08Oooool2o`000;7ooooo000Wooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool0/?ooool002Oooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`2`ooooo`009oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo0;3ooooo000X
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0/?ooool002Sooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`2`ooooo`00:?ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Rooooo`;o
0000/Oooool002Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0booooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`2`ooooo`00:Ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo0;3ooooo000Yooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool0/?ooool002[ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`2`ooooo`00:_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo0;3o
oooo000Zooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo02?ooooo0_l0002aooooo`00:_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo0;3ooooo000[ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool0/?ooool002_ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0foooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`2`oooo
o`00:oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Oooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`09ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0;3ooooo000/ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Wo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400Kooooo00?o0000ooooooooool0/?ooool002cooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0gooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02_ooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`2`
ooooo`00;?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Sooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0:ooooo`05o`000?ooooooooooooooool000003Oooool0
0onHV9So8B4Qonk^kP06ooooo`?o0000/?ooool002gooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02_ooool01Ol0
003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`2`
ooooo`00;Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0:ooooo`05oa0@4?ooooooooooooooool@41003oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;3ooooo000]ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_oo
ool00ol0003oooooooooo`2`ooooo`00;_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0:ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0
/?ooool002kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0jooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`2`ooooo`00;_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0Vooooo`;o0000/Oooool002oooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0looooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`2`ooooo`00;oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03co
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo0;3o
oooo000`ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0??ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0/?ooool0033ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`2`ooooo`00<?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo0;3ooooo000aooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02Oooooo0_l0002aoooo
o`00<_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03oooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo0;3ooooo000booooo`;o0000
0oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`2`ooooo`00<oooool4o`0004?ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0;3ooooo001kooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`2`ooooo`00Noooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0/?ooool007_o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Xooooo`;o0000/Oooool007_ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0;3ooooo
001looooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`2`ooooo`00O?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool0/?ooool007cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo0;3ooooo001looooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`2`ooooo`00O?ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool0/?ooool007cooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Zooooo`;o0000/Oooool007gooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo0;3ooooo001mooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`2`ooooo`00OOooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Kooooo00?o0000ooooooooool0/?ooool0
07gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0@ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oo
oooooooo0;3ooooo001mooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04?ooool0
1Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`2`ooooo`00O_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo013ooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ojVYZOl@413ooooo00Gooooo0ol0002`ooooo`00O_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo013ooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oa0@4?l0003o^[Zj00Kooooo00?o0000ooooooooool0/?ooool007kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41003_oo
ool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo0;3ooooo001oooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0;3ooooo001oooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool04Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo0;3ooooo001oooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`2`ooooo`00Oooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02gooooo0_l0002aooooo`00P?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0/?ooool0
087ooooo00Co0000oooooooooooo0000<?ooool00ol0003oooooooooo`2`ooooo`00POooool4o`00
033ooooo00?o0000ooooooooool0/?ooool008;ooooo0_l0000aooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooo
oooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol00006ooooo`?o0000/?ooool009[ooooo00Go0000ooooooooooooooooo`00000;
ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0
/?ooool009[ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo
00?o0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^
k_m4A4Co000000Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`
ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooa0@400@
ooooo`03o`000?oooooooooo00?ooooo0ol0002`ooooo`00V_ooool01Ol0003ooooooooooooooooo
000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol0
003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oo
oooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00[?ooool00ol0003o^[Zjooooo`2iooooo`00[?ooool2oc8b<[[ooooo
001mooooo`;o000000Ko410@oooooooooooo410@o`000?l@410Hooooo`Co000000Go410@oooooooo
ooooooooodA4A002o`000007oc8b<_oMgMgooooooooooon7QhOo0000okZj^P0<ooooo`05oiRHV?l0
003o0000odA4A?nj^[X06?ooool5o`0000Cooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07?ooooo001nooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01oooool6o`0000cooooo00?o0000ooooooooool01_ooool0
1omgMgOo<S8booooooooooooc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wo
oooo1_l00009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg07?ooooo001n
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06oooool00onHV9So8B4Qonk^kP07
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oo
ooooooooooooool@4100Loooool007kooooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko
00003?ooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo013ooooo00?o0000oooooooo
ool02oooool6o`0000_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000007?ooooo001noooo
o`06o`000?oMgMgo<S8boeEEEOoMgMgo00006oooool00ol0003oooooooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`04Oooool00ol0003oooooooooo`0Mooooo`03ogMgMomVIVKooooo00Gooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`00001cooooo`00O_ooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001_ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03oa0@4?l0003o000000?o00007Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@4100Loooool007kooooo00Ko0000oc8b<_oooooooooo
oc8b<_l0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Jooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg07?ooooo001m
ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool00omEEEGoIVIVo`000005
ooooo`Co00004_ooool00ol0003oooooooooo`0Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?oo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^07?ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2200) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01291 m
.03279 .01786 L
.04262 .02536 L
.05288 .03611 L
.06244 .04956 L
.0731 .06949 L
.0828 .09303 L
.10458 .16367 L
.11466 .19952 L
.12017 .21756 L
.12534 .23233 L
.1301 .24341 L
.13446 .25094 L
.13565 .25251 L
.13694 .25398 L
.13818 .25513 L
.1393 .25597 L
.14061 .25669 L
.14133 .25696 L
.142 .25714 L
.14321 .25728 L
.14451 .25715 L
.14567 .25681 L
.14691 .25619 L
.14808 .25537 L
.14915 .25444 L
.15176 .25137 L
.15424 .2475 L
.15916 .23723 L
.16452 .22272 L
.18292 .15882 L
.20231 .09608 L
.21334 .06952 L
.22371 .05035 L
.23356 .03639 L
.2426 .0268 L
.24734 .02289 L
.25252 .01945 L
.25794 .01667 L
.26297 .01473 L
.26802 .01327 L
.27349 .01212 L
.27601 .01171 L
.27866 .01134 L
.28096 .01107 L
.28343 .01084 L
.28466 .01075 L
.28582 .01067 L
.28695 .01061 L
.288 .01057 L
Mistroke
.28899 .01054 L
.29005 .01052 L
.29122 .01052 L
.29228 .01054 L
.29354 .01058 L
.29469 .01065 L
.29596 .01074 L
.2973 .01087 L
.29955 .01118 L
.30202 .01166 L
.30454 .0123 L
.30727 .01319 L
.31225 .01541 L
.31709 .01834 L
.32157 .02178 L
.33172 .03228 L
.34249 .0481 L
.35189 .06727 L
.362 .09617 L
.37155 .13352 L
.3803 .17635 L
.39025 .2313 L
.40086 .28756 L
.40602 .31 L
.40855 .31916 L
.41088 .32633 L
.41296 .33163 L
.41525 .33616 L
.41643 .33796 L
.41754 .33929 L
.41872 .34033 L
.41997 .34101 L
.42121 .34125 L
.42252 .34103 L
.42364 .34046 L
.42488 .33942 L
.42557 .33866 L
.4262 .33784 L
.42763 .3356 L
.43022 .33018 L
.43247 .32408 L
.43494 .31604 L
.43993 .29606 L
.45813 .20011 L
.46905 .14401 L
.47936 .10125 L
.48862 .07241 L
.49866 .04974 L
.50851 .03396 L
.51348 .02784 L
Mistroke
.51895 .02226 L
.52361 .01835 L
.52862 .01492 L
.53768 .01037 L
.54292 .0085 L
.54779 .0071 L
.55882 .00462 L
.56848 .00285 L
.57356 .00204 L
.57892 .00131 L
.58155 .00102 L
.58443 .00076 L
.58705 .00058 L
.5895 .00045 L
.59079 .0004 L
.59201 .00036 L
.59311 .00034 L
.59431 .00033 L
.5956 .00032 L
.59626 .00032 L
.59698 .00032 L
.59826 .00034 L
.59946 .00036 L
.60055 .00038 L
.60174 .00041 L
.60413 .00048 L
.60842 .00063 L
.61305 .00078 L
.61432 .00081 L
.61566 .00084 L
.61681 .00086 L
.61807 .00088 L
.61939 .00089 L
.62013 .00089 L
.6208 .00089 L
.62212 .00088 L
.62336 .00087 L
.6246 .00084 L
.62575 .00082 L
.62835 .00073 L
.63073 .00064 L
.63288 .00053 L
.63769 .00025 L
Mfstroke
.63769 .00025 m
.64183 0 L
s
.68692 0 m
.68739 1e-05 L
.68875 2e-05 L
.68995 3e-05 L
.69126 4e-05 L
.69246 5e-05 L
.69357 5e-05 L
.69489 5e-05 L
.69609 5e-05 L
.69675 4e-05 L
.69748 4e-05 L
.69879 3e-05 L
s
.69879 3e-05 m
.70193 0 L
s
.73124 0 m
.73419 4e-05 L
.73698 7e-05 L
.73956 .0001 L
.74191 .00011 L
.74323 .00012 L
.74442 .00013 L
.74573 .00013 L
.74647 .00013 L
.74715 .00014 L
.7484 .00014 L
.74971 .00014 L
.75082 .00013 L
.75201 .00013 L
.75312 .00013 L
.75414 .00012 L
.759 9e-05 L
.76149 8e-05 L
.76414 6e-05 L
.76552 6e-05 L
.76625 5e-05 L
.76704 5e-05 L
.76777 5e-05 L
.76843 5e-05 L
.76973 5e-05 L
.77096 5e-05 L
.77209 5e-05 L
.77334 6e-05 L
.77404 6e-05 L
.77468 6e-05 L
.77736 8e-05 L
.77989 .0001 L
.78963 .00022 L
.79199 .00025 L
.79454 .00027 L
.79528 .00027 L
.79599 .00028 L
.79668 .00028 L
.79732 .00028 L
.79857 .00029 L
.79923 .00029 L
.79993 .00028 L
.80106 .00028 L
.8021 .00028 L
.80325 .00027 L
.80445 .00026 L
.80648 .00024 L
.8087 .0002 L
.81372 .00011 L
s
.81372 .00011 m
.81816 0 L
s
.85156 0 m
.85739 .00015 L
.86209 .00025 L
.86473 .00029 L
.86598 .00031 L
.86713 .00032 L
.86822 .00033 L
.86937 .00034 L
.87052 .00034 L
.8718 .00034 L
.8729 .00034 L
.87408 .00034 L
.8752 .00034 L
.87622 .00033 L
.87871 .00032 L
.88103 .0003 L
.88379 .00027 L
.88629 .00026 L
.88756 .00025 L
.88827 .00025 L
.88893 .00024 L
.89014 .00024 L
.89141 .00024 L
.89206 .00025 L
.89276 .00025 L
.89402 .00026 L
.89479 .00027 L
.89552 .00028 L
.89689 .0003 L
.89949 .00036 L
.90193 .00043 L
.90413 .00052 L
.9065 .00063 L
.91184 .00097 L
.91674 .00136 L
.93514 .0033 L
.94425 .00449 L
.95401 .00608 L
.95961 .00727 L
.96471 .00862 L
.97469 .01223 L
.97619 .01291 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Go
oooo1Ol0000;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool9o`0000Wo
oooo00?o0000ooooooooool08?ooool002Cooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool02oooool6o`0001cooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Tooooo`Ko00000oooool00ol0003ooooo
ooooo`0Pooooo`00Loooool5o`0003gooooo00?o0000ooooooooool02?ooool3o`0007oooooo0ol0
000Sooooo`009?ooool2o`0004Sooooo1Ol00005ooooo`Co0000>Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool08?ooool002Kooooo00?o0000oooo
ooooool0@_ooool3o`0000kooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`05oooo
o`;o0000ZOooool002Oooooo0_l00010ooooo`;o00004_ooool2o`0003Kooooo0_l00005ooooo`03
o`000?oooooooooo0:Wooooo000Yooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
Z_ooool002[ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2[ooooo`00:oooool0
0ol0003oooooooooo`0hooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`02o`000:kooooo000/ooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo00000;3ooooo000]ooooo`03
o`000?oooooooooo03Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooo00000;3ooooo000]ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0_ooooo`;o0000/Oooool002kooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02kooooo0_l0002aooooo`00;oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`2`ooooo`00<?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool0;?ooool2o`000;;ooooo000`ooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0/ooooo`;o0000/_ooool0037ooooo
00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02[ooooo
00?o0000ooooool00000/_ooool0037ooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo02[ooooo00?o0000ooooool00000/_ooool003;ooooo00?o0000
ooooooooool0:_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool00_l0002aooooo`00<_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0:?ooool01?l0003oooooooooool0002booooo`00<oooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool09oooool01?l0
003oooooooooool0002booooo`00<oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool09_ooool01Ol0003ooooooooooooooooo00000;;ooooo000doooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Uoooo
o`05o`000?ooooooooooooooool00000/_ooool003Cooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo02Gooooo00Go0000ooooooooooooooooo`00002b
ooooo`00=Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`02ooooo`;o0000/Oooool003Gooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`2`ooooo`00=Oooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0;3ooooo000fooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0:ooo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0/?oo
ool003Kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo00cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000003oa0@4?l0
003ooooo00?ooooo00?o0000ooooooooool0/?ooool003Kooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00cooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo0;3ooooo000g
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0<
ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooo`000005ooooo`?o0000/?oo
ool003Oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo00_ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooo000000Gooooo00?o
0000ooooooooool0/?ooool003Oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oo
oooo000000Gooooo00?o0000ooooooooool0/?ooool003Sooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00_ooooo00Go410@oooooooooooooooooa0@
400>ooooo`;o00001_ooool00ol0003oooooooooo`2`ooooo`00>?ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00kooooo0_l00006ooooo`03o`000?oooooooooo0;3ooooo000hooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0:ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?mEEEGoIVIVo`000?l00006ooooo`03o`000?oooooooooo0;3ooooo
000iooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool003Wooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool01Oooool2o`000;7ooooo000iooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool0<_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0/?ooool003[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2`ooooo`00
>_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0;3ooooo000jooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0/?ooool003_ooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0dooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`2`ooooo`00>oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
03Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`07ooooo`;o0000/Oooool003_o
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00??ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo000looooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0/?ooool003cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0h
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2`
ooooo`00?Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03Sooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0;3ooooo000mooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo00Sooooo0_l0002aooooo`00?Oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo03Wooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo0;3ooooo000mooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0>Ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0/?oo
ool003kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0jooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2`ooooo`00?_ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo0;3ooooo000nooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0/?ooool003oooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02Oooool2o`000;7ooooo
000oooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0??ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0/?ooool003oooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`2`ooooo`00?oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo03gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo0;3ooooo0010ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0?Oooool00ol0003oooooooooo`05ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@;ooooo00?o0000ooooool000001?l00006ooooo`03o`000?oooooooooo0;3ooooo0010ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`05ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@;ooooo00Oo0000oooooonHV9So8B4Qonk^k_oo
ooooA4A400Kooooo00?o0000ooooooooool0/?ooool0043ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Gooooo00Go410@oooooooooooooooooa0@
4009ooooo`06o`000?oooooooooooiRHV?lQ8B7ok^k^1oooool00ol0003oooooooooo`2`ooooo`00
@Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0
1?ooool01Ol0003ooooooooooooooooo000000Wooooo00Oo0000oooooooooooooooooiRHV?lQ8B7o
k^k^00Kooooo0ol0002`ooooo`00@Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
043ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000
ooooooooool00_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0;3ooooo0011oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`04oooo
o`05oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0/?ooool004;ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`10ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08
ooooo`08o`000?ooooooooooo`000?nj^[[ooooooiRHV?l@4106ooooo`03o`000?oooooooooo0;3o
oooo0012ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0@Oooool00ol0003ooooo
ooooo`04ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool02?l0003ooooooooooonHV9So410@
o`000?lQ8B7oc<c<1_ooool00ol0003oooooooooo`2`ooooo`00@_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo0;3ooooo0013ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0@_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo0_l0002aoooo
o`00@oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04?ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0;3ooooo0013ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0/?ooool004?ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`2`ooooo`00A?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo04Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo0;3ooooo0015ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0A_ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0/?ooool004Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03?ooool2o`000;7ooooo0016ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0/?ooool004Kooooo0_l00002ooooo`03o`000?oooooooooo04Sooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0;3ooooo0017
ooooo`Co0000B_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0/?ooool009Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo0;3ooooo002Fooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`2`ooooo`00U_ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00gooooo0_l0002aooooo`00U_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0/?ooool009Kooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo0;3ooooo002Fooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2`ooooo`00Uoooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0/?ooool009Oooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo0;3ooooo
002Gooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`2`ooooo`00Uoooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00oooooo0_l0002a
ooooo`00Uoooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0/?ooool009Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo0;3ooooo002Hooooo`07o`000?ooooook^k^oc8b<_l0003o<S8bonk^kP04oooo
o`03o`000?lQ8B7o8B4Q00Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooo
oooo0;3ooooo002Hooooo`07o`000?ooooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`04o`000?oo
oooo8B4Qob4Q8@Cooooo00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo0;3o
oooo002Hooooo`03o`000?oooooo410@00?ooooo00Go410@ooooooooooooooooo`00000;ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0/?ooool009Sooooo00?o0000ooooool00000
0oooool01Ol0003ooooooooooooooooo000000[ooooo00?oZJVYoa0@4?ooool01Oooool3o`000;3o
oooo002Hooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00002_ooool00ol@413o
0000okZj^P06ooooo`03o`000?oooooooooo0;3ooooo002Iooooo`03o`000?l@413ooooo00;ooooo
00Co410@oooooooooooo00002oooool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo0;3o
oooo002Iooooo`06o`000?mgMgOoV9RHoooooonHV9SoMgMg0_ooool00ol0003oooooooooo`06oooo
o`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003oooooooooo`2`ooooo`00VOooool02?l0
003ok^k^oc8b<_l0003o<S8bonk^k_oooooo00002Oooool01OnYZJWo410@o`000?l@413oZJVY00Ko
oooo00?o0000ooooooooool0/?ooool009[ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo0;3ooooo002Jooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool04_ooool2o`000;7ooooo002Jooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`2`ooooo`00Voooool01Ol0003ooooooooooooooooo
000001Gooooo00?o0000ooooooooool0/?ooool009cooooo00?o0000ooooool000005_ooool00ol0
003oooooooooo`2`ooooo`00WOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooo
oooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol00006ooooo`?o0000/?ooool009[ooooo00Go0000ooooooooooooooooo`00000;
ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0
/?ooool009[ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo
00?o0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^
k_m4A4Co000000Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`
ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooa0@400@
ooooo`03o`000?oooooooooo00?ooooo0ol0002`ooooo`00V_ooool01Ol0003ooooooooooooooooo
000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol0
003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oo
oooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00[?ooool00ol0003o^[Zjooooo`2iooooo`00[?ooool2oc8b<[[ooooo
001mooooo`;o000000Ko410@oooooooooooo410@o`000?l@410Hooooo`Co000000Go410@oooooooo
ooooooooodA4A002o`000007oc8b<_oMgMgooooooooooon7QhOo0000okZj^P0<ooooo`05oiRHV?l0
003o0000odA4A?nj^[X06?ooool5o`0000?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07?ooooo001nooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01oooool6o`0000cooooo00?o0000ooooooooool01_ooool01omgMgOo
<S8booooooooooooc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0
0009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OnHV9So8B4Qonk^k_ooooooA4A400?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Loooool0
07kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Kooooo`03oiRHV?lQ8B7ok^k^
00Gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@
oooooooooooooooooa0@401cooooo`00O_ooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo
1_l0000<ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool04?ooool00ol0003ooooo
ooooo`0;ooooo`Ko00002oooool00onHV9So8B4Qonk^kP05ooooo`03oiRHV?lQ8B7ok^k^00?ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000Loooool007ko
oooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Kooooo`03o`000?oooooooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c00Aooooo`03o`000?oooooooooo01gooooo00?oMgMgofIVI_ooool01Ooo
ool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000007?ooooo001nooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo00006oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o410@o`000?l000000ol0000Moooo
o`03o`000?oooooooooo00Gooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo
ooooooooool@41000oooool00ol@413oooooooooo`1aooooo`00O_ooool01_l0003o<S8boooooooo
oooo<S8bo`0001_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo01[ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05o`000?nj^[[ooooooiRH
V?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`1cooooo`00OOooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo00?oEEEE
ofIVI_l000001Oooool4o`0001;ooooo00?o0000ooooooooool06_ooool01OnHV9So410@o`000?lQ
8B7oc<c<00?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07?ooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2300) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .00127 m
.02605 .0013 L
.02846 .00135 L
.03072 .00141 L
.03279 .00148 L
.03521 .00159 L
.03784 .00175 L
.04262 .00213 L
.04762 .00267 L
.05293 .00339 L
.06244 .00502 L
.0728 .0073 L
.0825 .01014 L
.08805 .01227 L
.09313 .01467 L
.09867 .01786 L
.10458 .02205 L
.11442 .03111 L
.12357 .04224 L
.13443 .05973 L
.14429 .08066 L
.16354 .13779 L
.17346 .17344 L
.18435 .21159 L
.18933 .22672 L
.19467 .2402 L
.19725 .24547 L
.1997 .24961 L
.2019 .25258 L
.20429 .25495 L
.20559 .25587 L
.20682 .25648 L
.20751 .25672 L
.20815 .25687 L
.20886 .25695 L
.2096 .25696 L
.21027 .25689 L
.21099 .25673 L
.21229 .25622 L
.21308 .25578 L
.21383 .25527 L
.21524 .25408 L
.21776 .25116 L
.22009 .24762 L
.22536 .23685 L
.23505 .20896 L
.24412 .17723 L
.25471 .13906 L
.26476 .10626 L
.27447 .08008 L
Mistroke
.28505 .05806 L
.29467 .04299 L
.30359 .03213 L
.31418 .02213 L
.31937 .01823 L
.32415 .01521 L
.32842 .01296 L
.3331 .01099 L
.3378 .00951 L
.34037 .0089 L
.34277 .00844 L
.34538 .00805 L
.34779 .00779 L
.34905 .00768 L
.35044 .00759 L
.35189 .00751 L
.35325 .00745 L
.35446 .00742 L
.35574 .0074 L
.35683 .00738 L
.35802 .00738 L
.35931 .00738 L
.36003 .00738 L
.36068 .00739 L
.36196 .00741 L
.36316 .00743 L
.36542 .00747 L
.3678 .00754 L
.37208 .00769 L
.37445 .00781 L
.37667 .00795 L
.37911 .00814 L
.38173 .00841 L
.38428 .00875 L
.387 .00923 L
.38932 .00974 L
.39189 .01045 L
.39463 .01137 L
.39759 .01261 L
.40294 .01552 L
.40805 .0192 L
.41343 .02411 L
.42306 .03575 L
.43259 .05152 L
.44277 .07475 L
.45239 .10503 L
.46113 .14107 L
.48191 .25104 L
.49104 .29694 L
.49622 .3176 L
Mistroke
.49872 .32554 L
.50108 .33171 L
.50333 .33625 L
.5046 .33822 L
.50578 .33965 L
.50687 .34063 L
.50786 .34123 L
.509 .34158 L
.51008 .34157 L
.51125 .34118 L
.5125 .34035 L
.51356 .33929 L
.51472 .33777 L
.51732 .33304 L
.51974 .32705 L
.52474 .31031 L
.52929 .29071 L
.53952 .23716 L
.54956 .1815 L
.56023 .12938 L
.56934 .09442 L
.57938 .06587 L
.58891 .0463 L
.59917 .03082 L
.60885 .02014 L
.61773 .01324 L
.62248 .01059 L
.62754 .00846 L
.63233 .00699 L
.63667 .00601 L
.64178 .00515 L
.64732 .00443 L
.65738 .00325 L
.66765 .00203 L
.67268 .00149 L
.67727 .00109 L
.67958 .00092 L
.6821 .00077 L
.68476 .00064 L
.68729 .00056 L
.68875 .00052 L
.69006 .0005 L
.69079 .00049 L
.69158 .00048 L
.69233 .00047 L
.69301 .00047 L
.69424 .00047 L
.69494 .00046 L
.69559 .00046 L
.69691 .00047 L
Mistroke
.69764 .00047 L
.69831 .00047 L
.70081 .00048 L
.70203 .00049 L
.70314 .00049 L
.70432 .00049 L
.70558 .0005 L
.70624 .0005 L
.70696 .00049 L
.70826 .00049 L
.70947 .00048 L
.71057 .00047 L
.71183 .00046 L
.71303 .00045 L
.71515 .00041 L
.71745 .00036 L
.72736 .0001 L
.73007 3e-05 L
.73156 0 L
Mfstroke
.73156 0 m
.73168 0 L
s
.74407 0 m
.74531 2e-05 L
.7477 8e-05 L
.75318 .00024 L
.75816 .00038 L
.75946 .00041 L
.76087 .00044 L
.76221 .00046 L
.76343 .00047 L
.76474 .00048 L
.76548 .00048 L
.76617 .00048 L
.7669 .00048 L
.76757 .00047 L
.76834 .00047 L
.76907 .00046 L
.77029 .00043 L
.77159 .00041 L
.77393 .00034 L
.77671 .00023 L
.77922 .00011 L
s
.77922 .00011 m
.7812 0 L
s
.81869 0 m
.81933 4e-05 L
.82187 .00019 L
.82463 .00033 L
.82706 .00044 L
.82838 .00048 L
.82962 .00052 L
.83074 .00054 L
.83194 .00056 L
.83262 .00057 L
.83327 .00058 L
.83449 .00058 L
.8356 .00058 L
.83663 .00057 L
.83777 .00055 L
.83897 .00052 L
.84144 .00045 L
.8441 .00034 L
.84893 8e-05 L
s
.84893 8e-05 m
.85038 0 L
s
.88717 0 m
.8879 3e-05 L
.8908 .00015 L
.89334 .00024 L
.89468 .00027 L
.89612 .00031 L
.89745 .00033 L
.89866 .00034 L
.89987 .00035 L
.90103 .00035 L
.9022 .00035 L
.9035 .00034 L
.90416 .00034 L
.90486 .00033 L
.90613 .00031 L
.9086 .00026 L
.91086 .00021 L
.91597 6e-05 L
s
.91597 6e-05 m
.91841 0 L
s
.93498 0 m
.93522 1e-05 L
.94016 .00019 L
.97619 .00127 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool=o`0000_ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`08ooooo`Ko00001oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`Go00008_ooool002Cooooo
00?o0000ooooooooool02Oooool6o`0001oooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
o`000006o`0002Oooooo00?o0000ooooooooool09Oooool7o`000003ooooool0003ooooo02kooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Pooooo`00=_ooool2o`0004_ooooo1Ol0
0006ooooo`Oo00008?ooool00ol0003oooooooooo`0Rooooo`?o0000Roooool003Sooooo00?o0000
ooooooooool0A_ooool2o`0001;ooooo0_l0000Nooooo`03o`000?oooooooooo023ooooo0_l0002>
ooooo`00>Oooool2o`0004Cooooo0_l0000Fooooo`;o00007?ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo08kooooo000kooooo`;o0000@?ooool2o`0001[ooooo0_l0000Jooooo`;o
00007oooool00ol0003oooooooooo`2?ooooo`00?Oooool00ol0003oooooooooo`0looooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo08oooooo000nooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0T?oo
ool003oooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`2Aooooo`00@?ooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo09;ooooo0011ooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool0T_ooool004;ooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`2Cooooo`00@oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool04oooool2o`0001[ooooo00?o0000ooooooooool0U?ooool004?ooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`2Eooooo`00A?ooool00ol0003oooooooooo`0_oooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo09Gooooo0015ooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool0U_ooool004Gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`2Fooooo`00A_oo
ool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo09Oooooo0016ooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Aooooo`;o00005oooool0
0ol0003oooooooooo`2Gooooo`00Aoooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
09Sooooo0017ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0V?ooool004Sooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`2Iooooo`00B?ooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo09Wooooo0018ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0VOooool004Wooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo00kooooo0_l0000Dooooo`03o`000?oooooooooo09[ooooo0019ooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool0V_ooool004[ooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`2Jooooo`00B_ooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo09_ooooo001:ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0:Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o8B4Qo`000?ooool01?ooool4o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`2Kooooo`00Boooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02Wooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`03ob4Q8Ol0003ooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo09_ooooo001;ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool0:Oooool01Ol@413ooooooooooooooooo410@00Oooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`05ooooo`?o00004_ooool00ol0003oooooooooo`2Kooooo`00Boooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02[ooooo00Go0000ooooooooooooooooo`00
0007ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo09cooooo001<ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool0:_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0W?oo
ool004cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Zooooo`05oa0@4?oooooo
ooooooooool@41001oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`2Looooo`00C?ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo09gooooo001=ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0:oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00Oo0000oooooooooooooooooeEEEOmVIVKo000000Oo
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`2Mooooo`00COooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo09gooooo001=ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`0:ooooo`;o00004?ooool00ol0003ooooooooo
o`2Nooooo`00C_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo09kooooo001>oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0W_ooool004kooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`2Nooooo`00Coooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo03cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo09kooooo001?ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0??oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0Wooo
ool004oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0looooo`03o`000?oooooo
oooo00Wooooo0_l0000?ooooo`03o`000?oooooooooo09oooooo001@ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0Woooool0053ooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`0mooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`2Oooooo`00D?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo09oooooo
001Aooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0?_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0X?ooool0057ooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`2Pooooo`00DOooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool02?ooool2o`0000kooooo00?o0000oooo
ooooool0X?ooool0057ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`2Pooooo`00
D_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0:3ooooo001Booooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0XOooool005;ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`11ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`2Qooooo`00D_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
047ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
0:7ooooo001Cooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0@Oooool00ol0003o
ooooooooo`07ooooo`;o00003Oooool00ol0003oooooooooo`2Qooooo`00Doooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo0:7ooooo001Cooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0@oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0XOooool005Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`13
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2R
ooooo`00E?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`2Rooooo`00E?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
03;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qo`000?oo
ooooA4A400Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2Rooooo`00E?ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03;ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03oiRHV?l0003ok^k^00Oooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`2Rooooo`00EOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03?ooooo00Go0000
ooooooooooooooooo`00000=ooooo`03oiRHV?l0003ok^k^00Kooooo0ol0000;ooooo`03o`000?oo
oooooooo0:;ooooo001Eooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0<oooool0
1Ol0003ooooooooooooooooo000000kooooo00?o0000ofIVI_ooool01Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo0:?ooooo001Eooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool0<oooool01Ol@413ooooooooooooooooo410@00kooooo0_l00006ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0Xoooool005Kooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0cooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooo
ool0003o410@00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`2Sooooo`00E_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Cooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05oiRHV?l@413o0000o`000?o<c<`01_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo0:?ooooo001Fooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
Aoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
Xoooool005Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`18ooooo`03o`000?oo
oooooooo00Cooooo0_l0000;ooooo`03o`000?oooooooooo0:?ooooo001Gooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0Y?ooool005Oooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`19ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`2Tooooo`00F?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Wo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0:Co
oooo001Hooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0BOooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Y?ooool005Sooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`2Tooooo`00FOooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool00oooool2o`0000[ooooo00?o0000
ooooooooool0Y?ooool005[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1=oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Uoooo
o`00F_ooool01Ol0003ooooooooooooooooo0000053ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo0:Gooooo001Kooooo`Co0000D?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0YOooool00;3ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0:Gooooo
002`ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`2Uooooo`00/?ooool00ol0003oooooooooo`02ooooo`;o00002?ooool00ol0003oooooooooo`2V
ooooo`00/?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0Y_ooool00;3ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0:Kooooo002aooooo`05o`000?ooooooooooooooool000002Oooool00ol0003o
ooooooooo`2Vooooo`00/Oooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000oooooooo
ool0Y_ooool00;7ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0:Oo
oooo002aooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`2Wooooo`00
/Oooool01?l0003oooooooooooooool2o`0000Oooooo00?o0000ooooooooool0Yoooool00;;ooooo
00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`2Wooooo`00/_ooool01?l0003ooooo
ooooool00007ooooo`03o`000?oooooooooo0:Sooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`04o`000?oooooooooo
o`0000Oooooo00?o0000ooooooooool0Z?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00Co0000oooooooooooo0000
1oooool00ol0003oooooooooo`2Xooooo`00V_ooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00_ooool00ol0003oooooo`000006ooooo`03o`000?oooooooooo0:Wooooo
002Jooooo`05o`000?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`03ooooo`03o`00
0?oooooo000000;o00001?ooool00ol0003oooooooooo`2Yooooo`00V_ooool01Ol0003ooooooooo
oooooooo000000gooooo00?o410@o`000?nj^[X01?ooool00ol0003oooooo`000006ooooo`03o`00
0?oooooooooo0:Wooooo002Jooooo`05oa0@4?ooooooooooooooool@41003_ooool00onj^[[o8B4Q
ooooo`04ooooo`;o00001_ooool00ol0003oooooooooo`2Yooooo`00V_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go410@oiRHV?oooooo^[Zjo`000005ooooo`;o00001Oooool00ol0003o
ooooooooo`2Zooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@05ooooo`;o00001Oooool00ol0003oooooooooo`2Zooooo`00]?ooool2o`0000Go
oooo00?o0000ooooooooool0Z_ooool00;Cooooo0ol00004ooooo`03o`000?oooooooooo0:[ooooo
002eooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Zoooool00;Gooooo0_l00003
ooooo`03o`000?oooooooooo0:_ooooo002eooooo`?o000000?oooooo`000?ooool0[Oooool00;Go
oooo00Co0000ooooool0003o0000[oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo00Cooooo00?o0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool00ol0003ooooo
ooooo`2`ooooo`00V_ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@00co
oooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003o
ooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aoooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Joooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@05ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00V_ooool0
1Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000;3ooooo002J
ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0;3ooooo002Jooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002/ooooo`03o`000?nj^[[ooooo
0;Wooooo002/ooooo`;o<S8b^_ooool007gooooo0_l000001_l@413oooooooooool@413o0000oa0@
41Sooooo1?l000001Ol@413oooooooooooooooooA4A400;o000000Oo<S8bomgMgOooooooooooohN7
Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`Go00000oooool01OnHV9So
410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h0Loooool007kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07
ooooo`Ko00003?ooool00ol0003oooooooooo`06ooooo`07ogMgMolb<S;oooooooooooo<c<co0000
oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoV9RHob4Q8Oo^
k^koooooodA4A003ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1cooooo`00O_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo01_ooooo00?oV9RHob4Q8Oo^k^h02?ooool01Ol0003ooooooooo
oooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo077o
oooo001nooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000cooooo00?o0000oooo
ooooool01_ooool00omgMgOo<S8booooo`0@ooooo`03o`000?oooooooooo00_ooooo1_l0000;oooo
o`03oiRHV?lQ8B7ok^k^00Kooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`00001cooooo`00O_ooool01_l0003ogMgMoc8b<_mE
EEGogMgMo`0001_ooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<017o
oooo00?o0000ooooooooool07Oooool00omgMgOoIVIVooooo`04ooooo`03oa0@4?l0003o^[Zj00?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000Loooool0
07kooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Kooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool04Oooool00ol@413o0000o`000003o`0001gooooo00?o0000ooooooooool01?oo
ool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooo
oooooooooooo410@07?ooooo001nooooo`06o`000?lb<S;ooooooooooolb<S;o00006oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool06_ooool01Ol0
003o^[ZjoooooonHV9So410@00?ooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg07?ooooo001mooooo`03oa0@
4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool00omEEEGoIVIVo`000005ooooo`Co0000
4_ooool00ol0003oooooooooo`0Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01OnYZJWo
410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h0Loooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2400) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .00028 m
.04262 .00043 L
.04498 .00043 L
.04754 .00044 L
.04996 .00045 L
.0522 .00046 L
.0548 .00048 L
.05756 .0005 L
.06244 .00055 L
.07286 .00072 L
.08255 .00092 L
.08797 .00107 L
.09304 .00125 L
.0986 .00154 L
.10172 .00176 L
.10458 .00199 L
.11442 .00307 L
.12357 .00446 L
.13424 .00645 L
.14429 .00877 L
.15415 .0119 L
.1597 .0143 L
.16481 .0171 L
.17386 .02377 L
.18342 .03366 L
.1929 .04673 L
.20306 .06486 L
.22139 .1107 L
.2412 .17872 L
.25165 .21523 L
.25738 .23228 L
.26018 .23937 L
.26275 .245 L
.26501 .24918 L
.26749 .25287 L
.26997 .25559 L
.27133 .25665 L
.27259 .25735 L
.27327 .25762 L
.274 .25782 L
.2747 .25792 L
.27534 .25794 L
.27655 .25779 L
.27784 .25736 L
.2785 .25702 L
.27922 .25658 L
.28051 .25556 L
.28204 .254 L
.28345 .25224 L
.28815 .24417 L
Mistroke
.29327 .23199 L
.3026 .20323 L
.32395 .12839 L
.34329 .07436 L
.353 .05462 L
.36348 .03838 L
.3683 .03253 L
.37338 .02734 L
.38248 .02022 L
.38745 .01727 L
.39198 .01501 L
.40215 .01098 L
.41158 .00806 L
.4205 .00591 L
.4251 .00508 L
.42775 .00471 L
.43018 .00443 L
.43273 .00421 L
.43407 .00412 L
.43548 .00405 L
.43671 .004 L
.43785 .00397 L
.43911 .00396 L
.43981 .00395 L
.44045 .00396 L
.4416 .00397 L
.44282 .004 L
.44386 .00403 L
.445 .00408 L
.44755 .00422 L
.44994 .00439 L
.45425 .00478 L
.45888 .00532 L
.4638 .00602 L
.46904 .00696 L
.47478 .00833 L
.4801 .01005 L
.48502 .01216 L
.48965 .0147 L
.49469 .01816 L
.50021 .02289 L
.51003 .03404 L
.52037 .05046 L
.52995 .07166 L
.53887 .09864 L
.54937 .14143 L
.5593 .1921 L
.56814 .24146 L
.57788 .29208 L
.58256 .31195 L
Mistroke
.58758 .32833 L
.58901 .33187 L
.59036 .33476 L
.59167 .3371 L
.59289 .33885 L
.59405 .34012 L
.59527 .34107 L
.59597 .34142 L
.59663 .34162 L
.59787 .34167 L
.59894 .34136 L
.60011 .34064 L
.60134 .33948 L
.60248 .33802 L
.60453 .33452 L
.60673 .32954 L
.61174 .31381 L
.61631 .29496 L
.63702 .18488 L
.64613 .13947 L
.65618 .09892 L
.66577 .06994 L
.67478 .04991 L
.68428 .03438 L
.68959 .02768 L
.69453 .02253 L
.70411 .01507 L
.70917 .01227 L
.71458 .00997 L
.72027 .00811 L
.72564 .00671 L
.73569 .00453 L
.74542 .00267 L
.75074 .00179 L
.75572 .00113 L
.75789 .0009 L
.75996 .00072 L
.76109 .00064 L
.76233 .00057 L
.76345 .00051 L
.76451 .00046 L
.76578 .00042 L
.76694 .0004 L
.76818 .00038 L
.76888 .00038 L
.76952 .00038 L
.7706 .00039 L
.77179 .0004 L
.77302 .00043 L
.77417 .00046 L
Mistroke
.7792 .00065 L
.78185 .00077 L
.78466 .00088 L
.78712 .00097 L
.78842 .001 L
.78914 .00102 L
.78982 .00104 L
.7911 .00105 L
.79228 .00106 L
.79338 .00107 L
.79458 .00106 L
.79584 .00104 L
.79702 .00102 L
.79809 .00099 L
.79924 .00095 L
.80183 .00084 L
.80421 .0007 L
.81315 5e-05 L
Mfstroke
.81315 5e-05 m
.81382 0 L
s
.84811 0 m
.85263 .00022 L
.85516 .00032 L
.85651 .00036 L
.85795 .0004 L
.85863 .00041 L
.85928 .00042 L
.86049 .00044 L
.86163 .00044 L
.86287 .00045 L
.86362 .00044 L
.86433 .00044 L
.86497 .00043 L
.86565 .00042 L
.8672 .00039 L
.86862 .00036 L
.87122 .00028 L
.87397 .00018 L
s
.87397 .00018 m
.87837 0 L
s
.91577 0 m
.91806 5e-05 L
.92022 9e-05 L
.92144 .00011 L
.92259 .00012 L
.92383 .00013 L
.92497 .00014 L
.92619 .00015 L
.92688 .00015 L
.92752 .00015 L
.92858 .00015 L
.92975 .00014 L
.93098 .00014 L
.93213 .00013 L
.94194 2e-05 L
s
.94194 2e-05 m
.94361 0 L
s
.95936 0 m
.96108 2e-05 L
.97077 .00019 L
.97619 .00028 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Ko
oooo2_l00006ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01ol00002ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo1_l00006ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Pooooo`009?ooool00ol0003oooooooooo`0Looooo`Ko0000
3?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Cooooo1Ol00006ooooo`Ko0000
2?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo017ooooo1Ol0000Gooooo`03o`00
0?oooooooooo02gooooo00?o0000ooooooooool08?ooool004Wooooo0ol0001:ooooo`Ko00004Ooo
ool3o`0000Gooooo00?o0000ooooooooool0?Oooool4o`0006oooooo001<ooooo`;o0000Aoooool0
0ol0003oooooooooo`0Hooooo`;o00000oooool00ol0003oooooooooo`0looooo`03o`000?oooooo
oooo077ooooo001>ooooo`?o0000@Oooool3o`0001gooooo00Co0000oooooooooooo0000??ooool2
o`0007Cooooo001Aooooo`03o`000?oooooooooo03cooooo0_l0000Qooooo`Co0000>_ooool00ol0
003oooooooooo`1dooooo`00D_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1eooooo`00Doooool00ol0003ooooo
ooooo`0hooooo`03o`000?oooooooooo02Cooooo0_l0000hooooo`03o`000?oooooooooo07Kooooo
001Dooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09?ooool00ol0003oooooo`00
000fooooo`03o`000?oooooooooo07Oooooo001Eooooo`03o`000?oooooooooo03Gooooo00?o0000
ooooooooool09Oooool01?l0003oooooooooool0000eooooo`03o`000?oooooooooo07Oooooo001E
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool09_ooool01?l0003oooooooooool0
000dooooo`03o`000?oooooooooo07Sooooo001Fooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool09oooool01Ol0003ooooooooooooooooo000003?ooooo00?o0000ooooooooool0N?oo
ool005Oooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Wooooo`;o00000oooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo07Wooooo001Hooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool0N_ooool005Sooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;?ooool00ol0003o
ooooooooo`1kooooo`00FOooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo07_ooooo
001Iooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0:_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0O?ooool005[ooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0:_ooool00ol0003oooooooooo`1looooo`00F_ooool00ol0003oooooooooo`0Zoooo
o`03o`000?oooooooooo02_ooooo0_l00006ooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool0OOooool005_ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1mooooo`00
Foooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo07kooooo001Looooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool0O_ooool005cooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1oooooo`00G?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
07oooooo001Mooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0;_ooool2o`0000So
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1oooooo`00GOooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo083ooooo001Mooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool0P?ooool005kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`20
ooooo`00G_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo087ooooo001Noooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool05?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo087ooooo001Oooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool05Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000
ooooooooool01Oooool3o`0000Wooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`21
ooooo`00Goooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01Gooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo087ooooo001Oooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool05_ooool01Ol0003ooooooooooooooooo000000kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool0P_ooool0063ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Foooo
o`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`22ooooo`00H?ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo01Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo08;ooooo001Pooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool05oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0P_ooool0
067ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`23ooooo`00HOooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo03;ooooo0_l0000<ooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool0Poooool0067ooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`23ooooo`00H_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo08?ooooo001R
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0Q?ooool006;ooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`24ooooo`00Hoooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo03Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo08Cooooo001Sooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
=?ooool2o`0000gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`24ooooo`00Hooo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo08Gooooo001Sooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool0QOooool006Cooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`25ooooo`00I?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo08Go
oooo001Tooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0QOooool006Gooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0fooooo`;o00003_ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo08Kooooo001Uooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool0Q_ooool006Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0foooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`26oooo
o`00I_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03Oooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo08Kooooo001Vooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0Q_ooool006Kooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`27ooooo`00Ioooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo03Oooooo0_l0000@ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0Qoooool0
06Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`27ooooo`00Ioooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo08Oooooo001Xooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0Qoooool006Sooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Mooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`28ooooo`00J?oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01kooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo08Sooooo001Yooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool07_ooool01Ol@413ooooooooooooooooo410@00co
oooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0R?ooool006Wooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0Nooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`?o
00004?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo08Sooooo001Yooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool07oooool01Ol0003ooooooooooooooooo000000ko
oooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0R?ooool006[ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Oooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`29ooooo`00
J_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01oooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0ROooool006[ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Pooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnH
V9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo08Wooooo001Zooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0ROooool006_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0kooooo`;o
00004_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Wooooo001[ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool0ROooool006_ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0looooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`2:ooooo`00Joooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo08[ooooo001/ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0?Oooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0R_ooool006co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2:ooooo`00KOooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo03gooooo0_l0000Cooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0R_ooool006kooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`2:ooooo`00K_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03oooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo08_ooooo001_oooo
o`Co0000@_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool0Roooool00;Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo08_ooooo002eooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`2;ooooo`00]Oooool2o`0001Cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`2;ooooo`00]Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0S?ooool00;Gooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo08cooooo002eooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`2<ooooo`00]Oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0S?ooool00;Gooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo08cooooo002e
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2<
ooooo`00]Oooool2o`0001Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2=oooo
o`00]Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0SOooool00;Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo08gooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`2=ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S801_ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0SOooool009[ooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo08kooooo002Jooooo`05o`000?oooooooooooooo
ool000003_ooool00onYZJWo410@ooooo`05ooooo`?o00005_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo08kooooo002Jooooo`05o`000?ooooooooooooooool000003Oooool00ol@
413o0000okZj^P06ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`2>ooooo`00V_ooool01Ol@413ooooooooooooooooo410@00kooooo00?o^[Zjob4Q
8Oooool01Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0S_ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9Sooooo
okZj^_l000001_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0Soooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o
0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0Soooool00;Gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo08oooooo002eooooo`;o00006?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo093ooooo002eooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`2@ooooo`00]Oooool00ol0003oooooooooo`0Hooooo`;o0000
0oooool00ol0003oooooooooo`2@ooooo`00]Oooool00ol0003oooooooooo`0Iooooo`04o`000?oo
ooooooooo`0009?ooooo002eooooo`03o`000?oooooooooo01[ooooo0_l0002Dooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`2`ooooo`00
V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go
00001_ooool3o`000;3ooooo002Jooooo`05o`000?ooooooooooooooool000002oooool01?m4A4Co
gMgMooooool00007ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05o`000?oooooooooooooo
ool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo0;3ooooo002Joooo
o`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooo
oooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool0
0omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009[ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003o
ooooooooo`03ooooo`?o0000/?ooool009[ooooo00Go0000ooooooooooooooooo`00000?ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`oooo
o`00V_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo1?l00006ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00:cooooo00?o0000okZj^_ooool0^Oooool00:cooooo0_lb<S:jooooo`00OOooool2o`00
0006oa0@4?oooooooooooa0@4?l0003o410@6?ooool4o`000005oa0@4?oooooooooooooooom4A4@0
0_l000001olb<S;ogMgMooooooooooooQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co
^[Zj01Sooooo1Ol00005ooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07?ooooo001nooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01oooool6o`0000cooooo00?o0000ooooooooool01_ooool01omgMgOo
<S8booooooooooooc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0
0009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg07?ooooo001nooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool06oooool00onHV9So8B4Qonk^kP04ooooo`Go
00000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@401c
ooooo`00O_ooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000<ooooo`03o`000?oo
oooooooo00Kooooo00?oMgMgoc8b<_ooool04?ooool00ol0003oooooooooo`0;ooooo`Ko00002ooo
ool00onHV9So8B4Qonk^kP03ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool00000Loooool007kooooo00Ko0000omgMgOlb
<S;oEEEEomgMgOl0000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Aooooo`03o`000?oooooooooo01gooooo00?oMgMgofIVI_ooool00_ooool01?oMgMgoEEEEoooo
ool00004ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
07?ooooo001nooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo00006oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo017ooooo00?o410@o`000?l000000ol0000Mooooo`03o`000?oooooo
oooo00;ooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@401cooooo`00O_ooool01_l0003o<S8boooooooooooo<S8bo`0001_o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01[o
oooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Loooool007gooooo00?o410@
o`000?n7QhL00_ooool00on7QhOo0000oa0@400Hooooo`03oeEEEOmVIVKo000000Gooooo1?l0000B
ooooo`03o`000?oooooooooo01[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03ogMgMol0
003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h0Loooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2500) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .00022 m
.02846 7e-05 L
.03068 2e-05 L
s
.03068 2e-05 m
.03164 0 L
s
.04573 0 m
.04793 4e-05 L
.05297 .00016 L
.05752 .00028 L
.06244 .00039 L
.06384 .00041 L
.06531 .00043 L
.06657 .00044 L
.06729 .00045 L
.06795 .00045 L
.06925 .00046 L
.06996 .00046 L
.07064 .00046 L
.07184 .00046 L
.07314 .00046 L
.0743 .00045 L
.07558 .00044 L
.07692 .00043 L
.07818 .00041 L
.08284 .00033 L
.09343 .0001 L
.09622 4e-05 L
s
.09622 4e-05 m
.09839 0 L
s
.12328 0 m
.12476 3e-05 L
.12935 .00013 L
.1343 .00027 L
.14327 .00062 L
.1528 .00111 L
.16324 .00175 L
.17428 .0025 L
.17909 .00286 L
.18432 .00331 L
.18954 .00385 L
.19437 .00448 L
.19898 .00525 L
.20387 .00629 L
.20901 .00768 L
.21383 .0093 L
.2248 .01434 L
.23466 .02068 L
.24502 .02957 L
.25387 .03951 L
.26354 .05376 L
.27384 .07406 L
.28319 .0979 L
.30415 .16784 L
.3135 .20109 L
.32337 .23137 L
.32854 .24339 L
.33147 .24869 L
.33421 .25253 L
.3355 .25395 L
.33673 .25505 L
.33783 .25584 L
.33902 .25647 L
.34032 .2569 L
.34098 .25701 L
.3417 .25705 L
.34298 .25691 L
.34419 .25653 L
.34536 .25593 L
.34661 .25505 L
.34887 .25282 L
.35156 .24914 L
.354 .24487 L
.35932 .23279 L
.36434 .21844 L
.38284 .15345 L
.40114 .09462 L
.41154 .06951 L
.42128 .05117 L
.43084 .03711 L
Mistroke
.44113 .02564 L
.44676 .02083 L
.45211 .01715 L
.45739 .01431 L
.46216 .01229 L
.47176 .00937 L
.48198 .00708 L
.49093 .00521 L
.50037 .00341 L
.50516 .0027 L
.50787 .0024 L
.50918 .00229 L
.51041 .0022 L
.51153 .00214 L
.51274 .00209 L
.51384 .00206 L
.51486 .00204 L
.51596 .00204 L
.51718 .00206 L
.51845 .0021 L
.51964 .00215 L
.52085 .00223 L
.52218 .00233 L
.52487 .00258 L
.52966 .00317 L
.54046 .00478 L
.55056 .00613 L
.55552 .00676 L
.56009 .00745 L
.56536 .00854 L
.56813 .00931 L
.57107 .01032 L
.57582 .01247 L
.58104 .0157 L
.58626 .01995 L
.59121 .02497 L
.6005 .03718 L
.6105 .05494 L
.6214 .08166 L
.63176 .11705 L
.64113 .15896 L
.65207 .21741 L
.66212 .27244 L
.66698 .29615 L
.67151 .31486 L
.67624 .32978 L
.67874 .33545 L
.68014 .33791 L
.68142 .33967 L
.68271 .34099 L
Mistroke
.68337 .34148 L
.68409 .34187 L
.68536 .3422 L
.68655 .34209 L
.68727 .34182 L
.68796 .34143 L
.68924 .34034 L
.68996 .33953 L
.69062 .33865 L
.69213 .33619 L
.6947 .33059 L
.69703 .32406 L
.70226 .30493 L
.72312 .19534 L
.73227 .14814 L
.74231 .1058 L
.752 .07523 L
.76105 .05414 L
.7706 .03748 L
.77593 .03009 L
.78085 .02428 L
.78568 .01948 L
.79102 .01518 L
.79638 .01184 L
.80208 .00925 L
.80707 .00765 L
.81246 .00643 L
.81754 .00558 L
.8222 .00491 L
.83212 .0035 L
.84272 .00187 L
.84786 .00115 L
.85039 .00085 L
.85272 .00062 L
.8548 .00044 L
.85708 .00029 L
.85819 .00023 L
.85938 .00018 L
.86063 .00014 L
.86181 .00011 L
.86304 .0001 L
.86434 9e-05 L
.86558 .0001 L
.86669 .00011 L
.86801 .00014 L
.86944 .00018 L
.87202 .00027 L
.87674 .00048 L
.87931 .00059 L
.88171 .00068 L
Mistroke
.8839 .00075 L
.88512 .00078 L
.88624 .0008 L
.88746 .00081 L
.88815 .00082 L
.88878 .00082 L
.88995 .00082 L
.89119 .00081 L
.89222 .0008 L
.89333 .00077 L
.89534 .00072 L
.89772 .00062 L
.89991 .00052 L
Mfstroke
.89991 .00052 m
.90817 0 L
s
.94119 0 m
.94438 .00018 L
.94887 .00039 L
.95113 .00047 L
.95354 .00054 L
.95492 .00057 L
.95622 .00059 L
.95739 .00061 L
.95866 .00061 L
.95975 .00061 L
.96077 .00061 L
.96189 .0006 L
.96309 .00059 L
.96434 .00057 L
.96554 .00054 L
.96778 .00049 L
.97619 .00022 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<o`0000Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02?ooool>o`0000_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00Co0000oooooooooooooooo1_l00002ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
023ooooo000Tooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool01_l0000Wooooo`03
o`000?oooooooooo02Kooooo1_l000000ooooooo0000ooooo`0:ooooo`So00007?ooool00ol0003o
ooooooooo`0Zooooo`Oo0000;?ooool00ol0003oooooooooo`0Pooooo`00G_ooool2o`0004_ooooo
0ol00007ooooo`03o`000?oooooooooo017ooooo0ol00014ooooo`;o0000E_ooool0063ooooo00?o
0000ooooooooool0A_ooool2o`0000[ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0oooooo`;o0000F?ooool0067ooooo0ol00012ooooo`?o00003?ooool00ol0003oooooooooo`0E
ooooo`;o0000?_ooool00ol0003oooooooooo`1Hooooo`00I?ooool2o`0003oooooo00?o0000oooo
ooooool03Oooool2o`0001Sooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`1Ioooo
o`00I_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo05[ooooo001Wooooo`03o`00
0?oooooooooo03Wooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool0Foooool006Sooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`1Looooo`00J?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo05cooooo001Yooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0GOooool006[o
oooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`1Nooooo`00J_ooool00ol0003ooooo
ooooo`0booooo`03o`000?oooooooooo01?ooooo0_l0000Mooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool0G_ooool006_ooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0;oooool00ol0003ooooooooo
o`1Oooooo`00K?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo063ooooo001]oooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool0H?ooool006gooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`1Qooooo`00K_ooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo067ooooo001^ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool05ooo
ool2o`00023ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1Rooooo`00Koooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo06;ooooo001_ooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool0Hoooool006oooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`1Sooooo`00L?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06Cooooo
001`ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0I?ooool0077ooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0Iooooo`;o00008oooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo06Gooooo001aooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool0IOooool007;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Uooooo`00
L_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo06Kooooo001booooo`03o`000?oo
oooooooo02;ooooo00So0000ooooooooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B45oooo
o`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool0I_ooool007?ooooo00?o0000ooooooooool08Oooool02?l0003o
oooooooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0I_oo
ool007?ooooo00?o0000ooooooooool08?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o
410@ooooooooool03?ooool00ol0003oooooooooo`05ooooo`?o00009?ooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo06Oooooo001cooooo`03o`000?oooooooooo023ooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0Iooo
ool007Cooooo00?o0000ooooooooool07oooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`1Wooooo`00M?ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo06Oooooo001dooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0J?ooool007Gooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?oo
ool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`1Xooooo`00MOooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo06Sooooo001eooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07_ooool2o`00
02Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Xooooo`00MOooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo06Wooooo001fooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0JOooool007Kooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`1Yooooo`00M_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo06Wooooo001goooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0JOooool007Oooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`0Pooooo`;o0000:?ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo06[ooooo001gooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
J_ooool007Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1Zooooo`00N?ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo06[ooooo001hooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool0J_ooool007Sooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`1[ooooo`00NOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02;ooooo
0_l0000Yooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Joooool007Wooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`1[ooooo`00NOooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo06_ooooo001iooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool0Joooool007[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1[ooooo`00
N_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo06_ooooo001jooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool08oooool2o`0002[ooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`1/ooooo`00Noooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo06cooooo001kooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0K?ooool007_o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1/ooooo`00O?ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo06cooooo001looooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
2_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@01_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0K?ooool007cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0:ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1]ooooo`00OOooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00000=oooo
o`03oiRHV?lQ8B7ok^k^00Kooooo0ol0000Zooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0KOooool007gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`05
o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1]ooooo`00OOooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo06gooooo001nooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006
ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1]
ooooo`00O_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooooooo
o`0[ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0K_ooool007kooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02_ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`1^ooooo`00Ooooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo02Oooooo0_l0000/ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0K_ooool007oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1^ooooo`00
Ooooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo06kooooo0020ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0Koooool0083ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`1_ooooo`00POooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
06oooooo0021ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0:Oooool2o`0002ko
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1_ooooo`00P_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo06oooooo0023ooooo`05o`000?ooooooooooooooool00000
;Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
L?ooool008?ooooo1?l0000^ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`1`ooooo`00]Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0L?ooool00;Gooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo073ooooo002eooooo`;o0000;oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo073ooooo002eooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`1aooooo`00]Oooool00ol0003ooooooooo
o`0^ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0LOooool00;Gooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo077ooooo002eoooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1aoooo
o`00]Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0LOooool00;Gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo07;ooooo002eooooo`;o0000<?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo07;ooooo002eooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`1booooo`00]Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0L_ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Kooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo07;ooooo002Jooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1cooooo`00V_ooool0
1Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Loooool009[ooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ojVYZOl@413ooooo00Gooooo0ol0000aooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0Loooool009[ooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oa0@4?l0003o^[Zj00Kooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo07?ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003_oo
ool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`1cooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1dooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`1dooooo`00]Oooool00ol0003oooooooooo`0booooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0M?ooool00;Gooooo0_l0000cooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0MOooool00;Gooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo07Gooooo002eooooo`03o`000?oooooooooo
03?ooooo00Go0000ooooooooooooooooo`00001hooooo`00]Oooool00ol0003oooooooooo`0doooo
o`04o`000?oooooo0000o`0007Sooooo002eooooo`03o`000?oooooooooo03Cooooo0ol0001ioooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003ooooooooo
o`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooa0@
400;ooooo`Go00001_ooool3o`000;3ooooo002Jooooo`05o`000?ooooooooooooooool000002ooo
ool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05o`000?oo
ooooooooooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo0;3o
oooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007ooooo`03
o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^ko
A4A4o`000007ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000
/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002a
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?oo
ool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41004?oo
ool00ol0003oooooooooo`03ooooo`?o0000/?ooool009[ooooo00Go0000ooooooooooooooooo`00
000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00cooooo1?l00006ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aoooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000
/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00:cooooo00?o0000okZj^_ooool0^Oooool00:cooooo0_lb<S:jooooo`00
OOooool2o`000006oa0@4?oooooooooooa0@4?l0003o410@6?ooool4o`000005oa0@4?oooooooooo
oooooom4A4@00_l000001olb<S;ogMgMooooooooooooQhN7o`000?nj^[X03?ooool01OnHV9So0000
o`000?m4A4Co^[Zj01Sooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1cooooo`00O_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l0000<ooooo`03o`000?oooooo
oooo00Kooooo00OoMgMgoc8b<_ooooooooooolc<c?l0003o410@00cooooo00Go410@okZj^_o^k^ko
MgMgoa0@4009ooooo`Ko00002Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00WoMgMgoc8b
<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg07?o
oooo001nooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06oooool00onHV9So8B4Q
onk^kP09ooooo`04o`000?oooooooooooa0@40?ooooo00Go410@oooooooooooooooooa0@4003oooo
o`03oa0@4?oooooooooo077ooooo001nooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6
o`0000cooooo00?o0000ooooooooool01_ooool00omgMgOo<S8booooo`0@ooooo`03o`000?oooooo
oooo00_ooooo1_l0000;ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00GoMgMgoc8b<_ooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`1aooooo`00O_oo
ool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001_ooooo00?o0000ooooooooool00oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<017ooooo00?o0000ooooooooool07Oooool00omgMgOoIVIVooooo`03oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`00001cooooo`00O_ooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001_o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03oa0@4?l0003o000000?o
00007Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooo
oooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100Loooool007kooooo00Ko0000oc8b
<_oooooooooooc8b<_l0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0Jooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooo
ooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
07?ooooo001mooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool00omEEEGo
IVIVo`000005ooooo`Co00004_ooool00ol0003oooooooooo`0Jooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h0Loooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2600) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .00083 m
.02499 .00085 L
.02605 .00087 L
.02729 .00088 L
.02846 .00089 L
.02954 .00089 L
.03053 .00088 L
.03163 .00087 L
.03279 .00085 L
.03395 .00083 L
.0352 .0008 L
.03746 .00073 L
.04262 .00052 L
.0521 9e-05 L
s
.0521 9e-05 m
.05439 0 L
s
.12481 0 m
.12843 9e-05 L
.13111 .00015 L
.13395 .00022 L
.13643 .00026 L
.13784 .00028 L
.13916 .00029 L
.14038 .0003 L
.14148 .00031 L
.1427 .00031 L
.14398 .00031 L
.14526 .0003 L
.14643 .0003 L
.14777 .00028 L
.14903 .00026 L
.15373 .00018 L
.15927 5e-05 L
s
.15927 5e-05 m
.16138 0 L
s
.18056 0 m
.18056 0 L
.18294 7e-05 L
.19285 .00048 L
.1983 .00072 L
.20345 .0009 L
.20824 .00103 L
.21095 .00108 L
.21344 .00112 L
.21814 .00118 L
.22044 .00121 L
.22254 .00125 L
.22678 .00134 L
.22911 .00141 L
.23134 .00149 L
.23597 .00174 L
.23859 .00192 L
.24102 .00212 L
.25051 .00318 L
.26061 .00476 L
.27091 .00691 L
.27671 .00846 L
.28204 .01022 L
.29185 .01459 L
.29679 .01749 L
.30221 .0213 L
.31243 .03054 L
.32174 .04171 L
.33248 .05879 L
.34266 .08036 L
.35232 .10664 L
.36258 .14042 L
.38101 .20643 L
.39039 .23414 L
.39296 .24013 L
.39566 .24553 L
.398 .24938 L
.40049 .2526 L
.40171 .25384 L
.40287 .25479 L
.4039 .25546 L
.40502 .256 L
.40608 .25633 L
.40721 .25648 L
.40817 .25645 L
.40923 .25625 L
.41047 .25578 L
.41161 .25514 L
.41292 .25415 L
.41416 .25296 L
Mistroke
.41637 .25029 L
.41878 .24657 L
.42411 .23558 L
.42913 .22226 L
.4385 .19189 L
.4595 .11767 L
.46929 .08842 L
.47963 .06414 L
.48845 .04861 L
.49812 .03602 L
.50836 .02611 L
.51768 .01902 L
.52844 .01248 L
.53328 .01012 L
.53861 .00797 L
.54362 .00641 L
.5483 .00534 L
.55089 .00489 L
.55325 .00456 L
.55598 .00427 L
.55858 .00405 L
.56079 .00392 L
.56315 .0038 L
.56739 .00364 L
.57702 .00325 L
.58672 .00254 L
.59203 .00206 L
.59698 .00165 L
.59979 .00145 L
.60234 .00132 L
.60304 .00129 L
.6038 .00126 L
.60446 .00124 L
.60519 .00123 L
.60595 .00121 L
.60677 .0012 L
.60752 .0012 L
.60823 .00121 L
.6095 .00122 L
.61013 .00124 L
.61083 .00126 L
.61207 .0013 L
.61321 .00136 L
.61581 .00154 L
.61859 .0018 L
.62376 .00247 L
.62938 .00339 L
.63957 .00545 L
.64949 .00792 L
.65864 .01106 L
Mistroke
.66331 .01321 L
.66833 .01611 L
.6774 .02329 L
.68293 .02915 L
.68818 .03596 L
.69803 .05272 L
.70764 .07556 L
.71787 .10922 L
.72752 .1511 L
.73626 .19639 L
.74564 .24826 L
.75554 .29806 L
.76072 .31845 L
.76365 .32753 L
.76639 .33411 L
.76769 .33655 L
.76892 .33845 L
.77002 .3398 L
.77121 .34089 L
.77251 .34161 L
.77317 .3418 L
.77389 .34186 L
.77517 .3416 L
.77637 .34094 L
.77755 .33989 L
.77881 .33834 L
.78108 .33446 L
.78377 .32807 L
.78622 .32072 L
.79155 .30016 L
.79658 .27624 L
.8151 .17467 L
.82484 .12764 L
.83514 .08914 L
.84394 .06499 L
.8536 .04547 L
.86379 .0304 L
.87308 .02029 L
.87822 .01604 L
.88381 .01242 L
.88909 .00988 L
.89398 .00818 L
.8986 .00703 L
.90359 .00613 L
.91262 .0049 L
.92244 .00355 L
.93321 .0019 L
.93821 .00121 L
.94096 .00089 L
.94356 .00064 L
Mistroke
.94599 .00044 L
.94726 .00036 L
.94862 .00029 L
.94975 .00024 L
.95101 .0002 L
.95215 .00018 L
.95321 .00016 L
.95451 .00015 L
.95525 .00015 L
.95593 .00016 L
.95719 .00017 L
.95788 .00018 L
.95852 .0002 L
.96102 .00027 L
.96337 .00035 L
.96906 .00059 L
.9743 .00078 L
.97619 .00083 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Ko
oooo3_l000000ooooooo0000ooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo6Ol00006ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Cooooo1ol0000:ooooo`03o`000?oooooooooo023ooooo000Tooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool05?ooool5o`0001Cooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0:ooooo`Co00006Oooool3o`0000?ooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0Eooooo`Oo00004Oooool00ol0003oooooooooo`0Pooooo`00LOoo
ool4o`00043ooooo00?o0000ooooooooool01oooool3o`00023ooooo0ol00015ooooo`?o0000>ooo
ool007Gooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`05ooooo`;o00009_ooool3
o`00047ooooo00?o0000ooooooooool0??ooool007Kooooo0_l0000mooooo`03o`000?oooooooooo
00?ooooo0_l0000[ooooo`;o0000?Oooool2o`0003oooooo001hooooo`03o`000?oooooooooo03[o
oooo0_l00002ooooo`;o0000;oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo03oo
oooo001iooooo`;o0000>_ooool01?l0003oooooooooool0000booooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool0@?ooool007_ooooo00?o0000ooooooooool0=oooool00ol0003ooooo
o`00000cooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0@Oooool007cooooo00?o
0000ooooooooool0=_ooool2o`0003Gooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`12ooooo`00O?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo03Gooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`12ooooo`00OOooool00ol0003oooooooooo`0doooo
o`;o0000>?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo04?ooooo001nooooo`03
o`000?oooooooooo03?ooooo0_l0000hooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool0A?ooool007oooooo00?o0000ooooooooool0<Oooool01?l0003oooooo`000?l0000hooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool0A?ooool007oooooo00?o0000ooooooooool0
<?ooool01?l0003oooooooooool0000jooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool0AOooool0083ooooo00?o0000ooooooooool0;_ooool01Ol0003ooooooooooooooooo000003[o
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`15ooooo`00POooool00ol0003ooooo
ooooo`0]ooooo`05o`000?ooooooooooooooool00000>oooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo04Kooooo0021ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
A_ooool008;ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo03[ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`17ooooo`00P_ooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00;ooooo0_l0000kooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool0Aoooool008?ooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`18ooooo`00Poooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo04So
oooo0024ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0B?ooool008Cooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03cooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`19ooooo`00Q?ooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo04Wooooo0025ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool01Oooool2o`0003gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`19oooo
o`00QOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0?Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo04[ooooo0026ooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0mooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool0B_ooool008Kooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`1:ooooo`00Q_ooool00ol0003oooooooooo`0Aooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oo
oooooooo03kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1;ooooo`00Qoooool0
0ol0003oooooooooo`0@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Gooooo00?o
0000ooooool000001oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool0Boooool008Oooooo00?o0000ooooooooool04?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooool000001oooool3o`0003kooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`1;ooooo`00Qoooool00ol0003oooooooooo`0@ooooo`05o`000?oooooo
ooooooooool000002oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo03oooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`1<ooooo`00R?ooool00ol0003ooooooooo
o`0?ooooo`05o`000?ooooooooooooooool000002oooool01?l0003oooooooooool00007ooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1<ooooo`00
R?ooool00ol0003oooooooooo`0?ooooo`05oa0@4?ooooooooooooooool@41002oooool01?l0003o
ooooooooool00007ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`1<ooooo`00R?ooool00ol0003oooooooooo`0?ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool0?oooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo04gooooo0029ooooo`03o`000?oooooooooo
00kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0:ooooo`05o`000?ooooooEEEEofIVI_l000001ooo
ool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0COoo
ool008Wooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo043ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1=ooooo`00ROooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo00Wooooo0_l00011ooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool0C_ooool008[ooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`1>ooooo`00R_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04kooooo
002:ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`11ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0C_ooool008_ooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo047ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`1?ooooo`00Roooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo04oooooo002;ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool02oooool2o`0004;ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1?ooooo`00
Roooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
@_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04oooooo002<ooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`12ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0Coooool008cooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`1@ooooo`00S?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
053ooooo002=ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`13ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0D?ooool008gooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0=ooooo`;o0000A?ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo053ooooo002=ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool0D?ooool008kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1A
ooooo`00S_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0@oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo057ooooo002>ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`14ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool0DOooool008kooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`1Aooooo`00Soooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00oooooo0_l00015ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0DOoo
ool008oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo04Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Booooo`00Soooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0A?ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo05;ooooo002@ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool0D_ooool0093ooooo00?o0000ooooooooool01oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo00Co0000oooooolQ8B7o8B4Q1?ooool5o`0000Kooooo00?o0000oooo
ooooool0AOooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo05;ooooo002@ooooo`03
o`000?oooooooooo00Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`03o`000?oooooooooo
00;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0AOooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo05;ooooo002Aooooo`03o`000?oooooooooo
00Kooooo00Go410@oooooooooooooooooa0@4002ooooo`03o`000?oooooooooo00Oooooo00?oV9RH
ob4Q8Oo^k^h01oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool0D_ooool0097ooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo
000000;ooooo00?o0000ooooooooool02?ooool00onHV9So8B4Qonk^kP06ooooo`?o0000AOooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo05?ooooo002Aooooo`03o`000?oooooooooo
00Kooooo00Oo0000ooooooooooooooooo`000?oooooo000000cooooo00?oMgMgofIVI_ooool01Ooo
ool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Dooo
ool009;ooooo00?o0000ooooooooool01Oooool01ol@413ooooooooooooooooo410@ooooool00000
3Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`1Cooooo`00T_ooool00ol0003oooooooooo`05ooooo`07ogMgMonH
V9SooooooiRHV?mgMgOoooooo`000009ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0
003oooooooooo`16ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0Doooool009;o
oooo00?o0000ooooooooool01Oooool01_o^k^ko<S8bo`000?lb<S;ok^k^o`0000[ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`1Cooooo`00Toooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo05?ooooo002Cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04oooool2o`00
04Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Dooooo`00Toooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0A_ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo05Cooooo002Dooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0E?ooool009Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`1Dooooo`00U?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0Aoooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05Cooooo002Doooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`17oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0E?ooool009Gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Fooooo`;o0000B?ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo05Cooooo002Fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
EOooool009Oooooo00?o0000ooooooooool00_l0000Iooooo`03o`000?oooooooooo04Oooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`1Eooooo`00V?ooool3o`0001[ooooo00?o0000
ooooooooool0Aoooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05Gooooo002eoooo
o`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Eoooo
o`00]Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool0EOooool00;Gooooo0_l00019ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
EOooool00;Gooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo05Kooooo002eooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`1Fooooo`00]Oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0E_ooool00;Gooooo00?o0000ooooooooool0BOooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo05Kooooo002eooooo`03o`000?oooooooooo04Wooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`1Fooooo`00]Oooool00ol0003ooooooooo
o`19ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Eoooool00;Gooooo0_l0001:
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Eoooool00;Gooooo00?o0000oooo
ooooool0B_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05Oooooo002eooooo`03
o`000?oooooooooo04[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Hooooo`00
V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05oiRHV?l@413o0000oc8b
<_o<c<`01_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0F?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@
413o^[ZjoooooomgMgOo<S8b00Kooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo05Sooooo002Jooooo`05oa0@4?ooooooooooooooool@41003oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1Hooooo`00V_ooool01Ol0003ooooooooooooooooo000000kooooo00?oZJVY
oa0@4?ooool01Oooool3o`0004_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1H
ooooo`00V_ooool01Ol0003ooooooooooooooooo000000gooooo00?o410@o`000?nj^[X01_ooool0
0ol0003oooooooooo`1;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0FOooool0
09[ooooo00Go410@oooooooooooooooooa0@400>ooooo`03okZj^_lQ8B7ooooo00Gooooo00?o0000
ooooooooool0C?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Wooooo002Joooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413oV9RHoooooonj^[[o000000Kooooo00?o
0000ooooooooool0C?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Wooooo002J
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo
00?o0000ooooooooool0C?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Wooooo
002eooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1Jooooo`00]Oooool2o`0004kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1J
ooooo`00]Oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0F_ooool00;Gooooo00?o0000ooooooooool0C_ooool01Ol0003ooooooooooooooooo0000
05gooooo002eooooo`03o`000?oooooooooo04kooooo0_l000000ooooooo0000ooooo`1Mooooo`00
]Oooool00ol0003oooooooooo`1?ooooo`?o0000G_ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`00
0003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol0002`oooo
o`00V_ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool0
0ol0003oooooooooo`2`ooooo`00V_ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgM
oeEEEOoooooo00001oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`2`ooooo`00V_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0003ooooooooo
o`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_oo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`oooo
o`00V_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`00
0;3ooooo002Jooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo0;3ooooo002Jooooo`05o`000?ooooooooooooooool000003?ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool0
09[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002/ooooo`03o`00
0?nj^[[ooooo0;Wooooo002/ooooo`;o<S8b^_ooool007gooooo0_l000001_l@413oooooooooool@
413o0000oa0@41Sooooo1?l000001Ol@413oooooooooooooooooA4A400;o000000Oo<S8bomgMgOoo
ooooooooohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`Go00000ooo
ool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h0Loooool007kooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`07ooooo`Ko00003?ooool00ol0003oooooooooo`06ooooo`07ogMgMolb<S;ooooooooo
ooo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00Go
V9RHob4Q8Oo^k^koooooodA4A003ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1cooooo`00O_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo01_ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oo
ooooooooooooool@4100Loooool007kooooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko
00003?ooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo013ooooo00?o0000oooooooo
ool02oooool6o`0000_ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003oV9RHoooooonHV9So8B4Q
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000Looo
ool007kooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Kooooo`03o`000?oooooooooo00?ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c00Aooooo`03o`000?oooooooooo01gooooo00?oMgMgofIVI_oo
ool00_ooool01Ol0003oEEEEo`000?l@413oc<c<00?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool00000Loooool007kooooo00Ko0000ohN7QonYZJWo^[ZjoeEE
EOl0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol@413o0000
o`000003o`0001gooooo00Ko0000oooooooooooooooooeEEEOn7QhL6ooooo`05oa0@4?oooooooooo
ooooool@41000oooool01Ol@413ooooooooooooooooo410@07?ooooo001nooooo`06o`000?lb<S;o
oooooooooolb<S;o00006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00?ogMgMoa0@4?nH
V9P01Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1c
ooooo`00OOooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo00?oEEEEofIV
I_l000001Oooool4o`0001;ooooo00?o0000ooooooooool06_ooool01OnHV9So410@o`000?lQ8B7o
c<c<00Cooooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP1cooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2700) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01025 m
.02846 .0084 L
.03279 .00711 L
.03754 .00604 L
.04262 .00519 L
.06244 .00261 L
.06788 .00192 L
.07379 .00126 L
.07649 .00101 L
.07936 .00079 L
.08181 .00064 L
.08319 .00057 L
.08451 .00052 L
.08575 .00048 L
.08711 .00044 L
.08835 .00042 L
.0895 .00041 L
.0902 .0004 L
.09086 .0004 L
.0921 .0004 L
.09279 .0004 L
.09343 .00041 L
.09413 .00042 L
.09487 .00042 L
.09726 .00046 L
.0995 .00051 L
.10214 .00057 L
.10458 .00062 L
.10701 .00066 L
.10823 .00068 L
.10894 .00068 L
.10959 .00069 L
.11024 .00069 L
.11094 .0007 L
.11163 .0007 L
.11239 .0007 L
.11305 .00069 L
.11376 .00069 L
.11503 .00068 L
.11631 .00066 L
.1177 .00063 L
.12022 .00056 L
.12267 .00047 L
.12493 .00038 L
s
.12493 .00038 m
.13242 0 L
s
.16696 0 m
.16746 2e-05 L
.17298 .00028 L
.17769 .00047 L
.18038 .00055 L
.18158 .00057 L
.18289 .0006 L
.18414 .00061 L
.18546 .00063 L
.18667 .00063 L
.1878 .00063 L
.18849 .00063 L
.18914 .00062 L
.19036 .00061 L
.19167 .00059 L
.19309 .00056 L
.1959 .00049 L
.19886 .00039 L
.20417 .00015 L
s
.20417 .00015 m
.2073 0 L
s
.24427 0 m
.25282 .00061 L
.25769 .00092 L
.26007 .00105 L
.26224 .00115 L
.26453 .00123 L
.26579 .00126 L
.26699 .00129 L
.26828 .0013 L
.26948 .00131 L
.2708 .00131 L
.27154 .00131 L
.27221 .0013 L
.2734 .00128 L
.27449 .00126 L
.27695 .0012 L
.28141 .00103 L
.28664 .0008 L
.28919 .0007 L
.2903 .00067 L
.29152 .00063 L
.29278 .00061 L
.29397 .00059 L
.29464 .00059 L
.29534 .00059 L
.29661 .0006 L
.29727 .0006 L
.29798 .00062 L
.29926 .00066 L
.30001 .00068 L
.30079 .00072 L
.30219 .0008 L
.30477 .001 L
.3072 .00125 L
.31175 .0019 L
.31664 .00284 L
.32195 .00407 L
.34032 .00904 L
.3506 .01205 L
.36021 .01575 L
.36505 .0183 L
.37024 .02177 L
.376 .02672 L
.38126 .03237 L
.39114 .04616 L
.4003 .06282 L
.42104 .11532 L
.43989 .17941 L
.4498 .21368 L
.4552 .23003 L
Mistroke
.46024 .2426 L
.46304 .24817 L
.46558 .25225 L
.46694 .25401 L
.46841 .25559 L
.46922 .2563 L
.46996 .25686 L
.47067 .25731 L
.47143 .25769 L
.47266 .25809 L
.47381 .25823 L
.47451 .2582 L
.47517 .2581 L
.47642 .25769 L
.47773 .25697 L
.47895 .25604 L
.48029 .25473 L
.48171 .25301 L
.48433 .24899 L
.48716 .24347 L
.4923 .23073 L
.5019 .20003 L
.52144 .13073 L
.53179 .0994 L
.54289 .07216 L
.55356 .05148 L
.5633 .03674 L
.56799 .03096 L
.57309 .02562 L
.58236 .01829 L
.58721 .01552 L
.59176 .01343 L
.60213 .00993 L
.61236 .00724 L
.62313 .0047 L
.62779 .00373 L
.63277 .00285 L
.63563 .00244 L
.63823 .00212 L
.64087 .00187 L
.64331 .00169 L
.64552 .00158 L
.64664 .00153 L
.64787 .0015 L
.6491 .00147 L
.6498 .00146 L
.65043 .00145 L
.65166 .00144 L
.65282 .00144 L
.6539 .00144 L
Mistroke
.65505 .00145 L
.65614 .00146 L
.65712 .00147 L
.66181 .00153 L
.66293 .00154 L
.66414 .00155 L
.66546 .00156 L
.6667 .00157 L
.66736 .00157 L
.66808 .00157 L
.66939 .00156 L
.67067 .00156 L
.67185 .00154 L
.67295 .00152 L
.67398 .00151 L
.67633 .00145 L
.68108 .00131 L
.68597 .00116 L
.68843 .0011 L
.6891 .00109 L
.68982 .00108 L
.69111 .00106 L
.69184 .00106 L
.69264 .00105 L
.69338 .00106 L
.69407 .00106 L
.69537 .00107 L
.69603 .00109 L
.69675 .0011 L
.69804 .00114 L
.69942 .00119 L
.70192 .00132 L
.70447 .00151 L
.70719 .00176 L
.71207 .00234 L
.72312 .00416 L
.73267 .00622 L
.73781 .00759 L
.74323 .00937 L
.74804 .01134 L
.7533 .01407 L
.76255 .02071 L
.76776 .02572 L
.77334 .03227 L
.78339 .04781 L
.79361 .0701 L
.79938 .08648 L
.8047 .10453 L
.82484 .19889 L
.83464 .25302 L
Mistroke
.84003 .2811 L
.84517 .30451 L
.84992 .32198 L
.85261 .32966 L
.85511 .33517 L
.8563 .33722 L
.85742 .33881 L
.85842 .33993 L
.85951 .34083 L
.8607 .34144 L
.86195 .34164 L
.86303 .34146 L
.8642 .34088 L
.86542 .33988 L
.86674 .33832 L
.86799 .3364 L
.86914 .33425 L
.87365 .3226 L
.87856 .30459 L
.88377 .28065 L
.90204 .18114 L
.91142 .13487 L
.92152 .09534 L
.93106 .06786 L
.9398 .04926 L
.94881 .03479 L
.95718 .02449 L
.96637 .01613 L
.97152 .01269 L
.97619 .01025 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`06ooooo`So00001oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`Go00001oooool8o`0000Cooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooo`00000Co`0000;ooooo2_l00002ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo023ooooo000Tooooo`03o`00
0?oooooooooo00Ko0000:?ooool00ol0003oooooooooo`0Yooooo`?o000000?oooooo`000?ooool0
;_ooool00ol0003oooooooooo`0Nooooo`Go00002_ooool00ol0003oooooooooo`0Cooooo`Co0000
5_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo023ooooo000Tooooo`?o0000GOoo
ool3o`0002kooooo00?o0000ooooooooool06oooool3o`0002Wooooo00?o0000ooooooooool0@ooo
ool00ol0003oooooooooo`0Pooooo`00Qoooool3o`0002_ooooo00?o0000ooooooooool06?ooool3
o`0002gooooo1?l0000oooooo`;o00008oooool008[ooooo0_l0000Yooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
02?ooooo002<ooooo`;o00009oooool2o`0001Kooooo0_l0000fooooo`03o`000?oooooooooo03[o
oooo00?o0000ooooooooool08oooool008kooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0>Oooool00ol0003ooooo
ooooo`0Tooooo`00Soooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool0>?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Gooooo002@
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool09_ooool0097ooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`0Aooooo`;o0000?Oooool00ol0003oooooooooo`0coooo
o`03o`000?oooooooooo02Oooooo002Aooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool0:?ooool009;ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Xooooo`00Tooo
ool00ol0003oooooooooo`0Oooooo`;o00004?ooool00ol0003oooooooooo`10ooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool0:Oooool009Cooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`0Zooooo`00U?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
02_ooooo002Eooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`13ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0:oooool009Kooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04Cooooo
00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0/ooooo`00U_ooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0AOooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo02cooooo002Gooooo`03o`000?oooooooooo01_ooooo0_l0000=
ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0/
ooooo`00Uoooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0Aoooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02gooooo002Hooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`18ooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0;Oooool009Sooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`0]ooooo`00V?ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo02kooooo002Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`1;ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0;_ooool0
09Wooooo00?o0000ooooooooool06Oooool2o`0000[ooooo00?o0000ooooooooool0Boooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo02kooooo002Iooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool0;oooool009[ooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`0_ooooo`00V_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0COooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02oooooo002J
ooooo`05onk^k_l0003o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l000000ol@413ooooooooo
o`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0COooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo033ooooo002Jooooo`05ogMgMol0003ooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo04oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0`ooooo`00V_ooool0
1Ol@413o0000oooooooooooo410@00kooooo00?o0000ooooooooool01Oooool3o`0000Oooooo00?o
0000ooooooooool0Coooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo033ooooo002J
ooooo`05o`000?oooooo0000ooooool000003_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo037ooooo002Jooooo`05o`000?oooooo0000ooooool000003_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo037ooooo002Jooooo`05oa0@4?oooooo0000ooooool@41003_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0D?oo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo037ooooo002Jooooo`05ogMgMonHV9So
ooooo`000?mgMgL03_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0D_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo037ooooo002J
ooooo`05onk^k_lb<S;o0000o`000?o^k^h03?ooool00omEEEGoIVIVo`000007ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo03;ooooo002Mooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1Cooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0<_ooool0
09kooooo00?o0000ooooooooool05?ooool2o`0000Gooooo00?o0000ooooooooool0Doooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo03;ooooo002Nooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool0<_ooool009kooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0cooooo`00Woooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0EOooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo03?ooooo002O
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1E
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0<oooool009oooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05Kooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0cooooo`00X?ooool00ol0003oooooooooo`0Booooo`;o
00000oooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool0=?ooool00:3ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo05Oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0dooooo`00X?oo
ool00ol0003oooooooooo`0Booooo`05o`000?ooooooooooooooool00000F_ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo03Cooooo002Pooooo`03o`000?oooooooooo01;ooooo00Go
0000ooooooooooooooooo`00001Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
=?ooool00:7ooooo00?o0000ooooooooool04Oooool01Ol0003ooooooooooooooooo000005[ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0dooooo`00XOooool00ol0003ooooooooo
o`0Aooooo`05o`000?ooooooooooooooool00000F_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo03Gooooo002Qooooo`03o`000?oooooooooo017ooooo0_l000000ooooooo0000oooo
o`1Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0=Oooool00:;ooooo00?o0000
ooooooooool04?ooool01?l0003oooooooooool0001Looooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool0=Oooool00:;ooooo00?o0000ooooooooool04?ooool01?l0003oooooooooool0
001Looooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0=Oooool00:;ooooo00?o0000
ooooooooool04?ooool00ol0003oooooo`00001Mooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool0=Oooool00:?ooooo00?o0000ooooooooool03oooool00ol0003oooooo`00001Moooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0=_ooool00:?ooooo00?o0000oooooooo
ool03oooool00ol0003oooooo`00001Nooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool0=_ooool00:?ooooo00?o0000ooooooooool03oooool3o`0005kooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0fooooo`00Xoooool00ol0003oooooooooo`0?ooooo`;o0000Gooo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo03Kooooo002Tooooo`03o`000?oooooo
oooo00kooooo0_l0001Oooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0=oooool0
0:Cooooo00?o0000ooooooooool03_ooool2o`0005oooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0gooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ob4Q
8Oooool00oooool5o`0000Kooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo03Oooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00olQ
8B7o0000ooooo`03ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1O
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0=oooool009[ooooo00Go410@oooo
oooooooooooooa0@4006ooooo`03o`000?oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h01oooool0
0ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0=oooool0
09[ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Cooooo00?oV9RH
ob4Q8Oo^k^h01_ooool3o`0005oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0h
ooooo`00V_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool01?ooool0
0omgMgOoIVIVooooo`04ooooo`;o0000HOooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo03Sooooo002Jooooo`05oa0@4?ooooooooooooooool@41001oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00?ooooo0_l0001Rooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0>?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`09o`000?oooooo
ooooooooool0003o^[ZjoooooonHV9So410@00Gooooo0_l0001Rooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0>?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`09
o`000?oooooooooooooooonHV9So410@o`000?lQ8B7oc<c<00Gooooo0_l0001Rooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0>?ooool00:Oooooo00?o0000ooooooooool02_ooool2
o`0006;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0iooooo`00Yoooool00ol0
003oooooooooo`09ooooo`04o`000?oooooo0000o`00067ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0iooooo`00Yoooool00ol0003oooooooooo`09ooooo`03o`000?oooooo0000
06?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0iooooo`00Yoooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooo000006?ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0iooooo`00Z?ooool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooo`0006?o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0iooooo`00Z?ooool00ol0003ooooo
ooooo`07ooooo`04o`000?ooooooooooo`0006?ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0jooooo`00ZOooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool0
0000Hoooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03[ooooo002Zooooo`03o`00
0?oooooooooo00Cooooo00Co0000oooooooooooooooo0_l0001Sooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0>_ooool00:[ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0jooooo`00Z_ooool2o`0000?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1Rooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0>_ooool00:_ooooo1?l00006
ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0k
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06;ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0kooooo`00]Oooool00ol0003oooooooooo`1Sooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool0>oooool00;Gooooo0_l0001Tooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0>oooool00;Gooooo00?o0000ooooooooool0Hooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03_ooooo002eooooo`03o`000?oooooo
oooo06?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0looooo`00]Oooool00ol0
003oooooooooo`1Tooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0??ooool00;Go
oooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03co
oooo002eooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0looooo`00]Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0??ooool00;Gooooo0_l0001Vooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0??ooool00;Gooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo03cooooo002eooooo`03o`000?oooooooooo06Gooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0mooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05oiRHV?l@413o0000oc8b<_o<c<`01_ooool00ol0003oooooooooo`1Uoooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0?Oooool009[ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Kooooo00?o0000
ooooooooool0I_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03gooooo002Joooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0mooooo`00V_ooool01Ol0
003ooooooooooooooooo000000kooooo00?oZJVYoa0@4?ooool01Oooool3o`0006Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0mooooo`00V_ooool01Ol0003ooooooooooooooooo
000000gooooo00?o410@o`000?nj^[X01_ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0?_ooool009[ooooo00Go410@oooooooooooooooooa0@400>
ooooo`03okZj^_lQ8B7ooooo00Gooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo03kooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol@413oV9RHoooooonj^[[o000000Kooooo00?o0000ooooooooool0Ioooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo03kooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0Ioooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo03oooooo002eooooo`03o`000?oooooooooo06Oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0oooooo`00]Oooool2o`0006Wooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0oooooo`00]Oooool00ol0003oooooooooo`1Xoooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0@?ooool00;Gooooo00?o0000oooooooo
ool0JOooool01Ol0003ooooooooooooooooo000004;ooooo002eooooo`03o`000?oooooooooo06Wo
oooo0_l000000ooooooo0000ooooo`12ooooo`00]Oooool00ol0003oooooooooo`1Zooooo`;o0000
A?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000oooo
ooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?oooooooooooooo
ool@41002oooool5o`0000Kooooo0ol0002`ooooo`00V_ooool01Ol0003ooooooooooooooooo0000
00_ooooo00CoA4A4omgMgOoooooo00001oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol0
003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003ooooooooo
o`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001ooo
ool00ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o
k^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@
013ooooo00?o0000ooooooooool00oooool3o`000;3ooooo002Jooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05
o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000
ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000
/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo002/ooooo`03o`000?nj^[[ooooo0;Wooooo002/ooooo`;o<S8b^_oo
ool007gooooo0_l000001_l@413oooooooooool@413o0000oa0@41Sooooo1?l000001Ol@413ooooo
ooooooooooooA4A400;o000000Oo<S8bomgMgOooooooooooohN7Qol0003o^[Zj00cooooo00GoV9RH
o`000?l0003oA4A4okZj^P0Hooooo`Go00001Oooool00ol0003ok^k^ooooo`03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07?ooooo001nooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`0000cooooo00?o0000ooooooooool0
1_ooool01omgMgOo<S8booooooooooooc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo
410@00Wooooo1_l00009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool00omEEEGoZJVYoooo
o`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg07?o
oooo001nooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06oooool00onHV9So8B4Q
onk^kP06ooooo`03ojVYZOmEEEGooooo00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@4100Loooool007kooooo00Ko0000oooooom4A4CoA4A4ooooool00009
ooooo`Ko00003?ooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo013ooooo00?o0000
ooooooooool02oooool6o`0000_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00olQ8B7oooooooooo`02
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000007?ooooo
001nooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo00006oooool00ol0003oooooooooo`03ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`04Oooool00ol0003oooooooooo`0Mooooo`03ogMgMomVIVKooooo
00Gooooo00?oEEEEolc<c?ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`00001cooooo`00O_ooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001_ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03oa0@4?l0003o000000?o0000
7Oooool00ol0003oooooooooo`04ooooo`03ojVYZOmgMgOooooo00;ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100Loooool007kooooo00Ko0000oc8b<_oo
oooooooooc8b<_l0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0Jooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Ol@413ooooooooo
oooooooo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL0Loooool007gooooo00?o410@o`000?n7QhL00_ooool00on7QhOo0000oa0@400Hooooo`03
oeEEEOmVIVKo000000Gooooo1?l0000Booooo`03o`000?oooooooooo01[ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c003ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP1cooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2800) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .25856 m
.04262 .1557 L
.0522 .1132 L
.06244 .07923 L
.07286 .05483 L
.08255 .03822 L
.08848 .03006 L
.09409 .02348 L
.09908 .01853 L
.10458 .01407 L
.10959 .01092 L
.11428 .00873 L
.11686 .00781 L
.11923 .00712 L
.12199 .00648 L
.12455 .00602 L
.12907 .00545 L
.13146 .00524 L
.13401 .00504 L
.13838 .00471 L
.14299 .00431 L
.14835 .00368 L
.15328 .00296 L
.16441 .00105 L
.16905 .00033 L
.1716 0 L
s
.1716 0 m
.17163 0 L
s
.19697 0 m
.2035 .00052 L
.2062 .0007 L
.20873 .00084 L
.21011 .0009 L
.21137 .00095 L
.21277 .00099 L
.21354 .001 L
.21427 .00102 L
.21546 .00103 L
.21674 .00103 L
.21793 .00102 L
.21902 .001 L
.2203 .00098 L
.22169 .00094 L
.2242 .00083 L
.23366 .00023 L
s
.23366 .00023 m
.23676 0 L
s
.27663 0 m
.2841 .00043 L
.28926 .0007 L
.29215 .00081 L
.29353 .00085 L
.2948 .00088 L
.29599 .00091 L
.29725 .00093 L
.29853 .00094 L
.29925 .00094 L
.29993 .00095 L
.30115 .00094 L
.30227 .00093 L
.3035 .00092 L
.3048 .00089 L
.30717 .00083 L
.30972 .00074 L
.3143 .00053 L
s
.3143 .00053 m
.32409 0 L
s
.34592 0 m
.35043 .00037 L
.35554 .00091 L
.36586 .00221 L
.38434 .00419 L
.38914 .00462 L
.39437 .00515 L
.3993 .00581 L
.40386 .00664 L
.40917 .00797 L
.41481 .00991 L
.41955 .012 L
.42478 .01484 L
.43488 .02194 L
.44414 .03041 L
.45431 .0424 L
.465 .05931 L
.47456 .07951 L
.48476 .1073 L
.50313 .17033 L
.51339 .20638 L
.51878 .22316 L
.52449 .238 L
.52949 .24781 L
.53233 .25185 L
.53369 .25336 L
.53498 .25454 L
.53615 .25538 L
.53742 .25605 L
.53857 .25644 L
.53965 .25661 L
.54092 .25657 L
.54207 .25631 L
.54271 .25607 L
.5434 .25574 L
.54465 .25496 L
.5459 .25393 L
.54704 .25277 L
.54959 .24947 L
.55419 .24113 L
.55956 .22795 L
.56464 .2127 L
.58573 .13752 L
.59542 .10584 L
.60569 .07843 L
.61446 .06017 L
.62413 .04448 L
.63426 .03167 L
.64353 .02246 L
.64864 .01833 L
Mistroke
.65423 .0146 L
.6595 .01182 L
.6644 .00983 L
.66948 .00831 L
.67496 .00713 L
.68015 .00633 L
.68492 .00572 L
.70352 .00316 L
.7126 .00178 L
.71769 .00116 L
.7201 .00093 L
.72234 .00076 L
.72358 .00068 L
.72496 .00061 L
.72635 .00056 L
.72711 .00054 L
.72782 .00053 L
.72913 .00051 L
.73032 .00051 L
.73164 .00052 L
.7323 .00052 L
.73302 .00054 L
.73433 .00057 L
.73552 .00061 L
.73819 .00073 L
.743 .00099 L
.74784 .00126 L
.75049 .00139 L
.75297 .00148 L
.75405 .00151 L
.75508 .00154 L
.75627 .00156 L
.75735 .00157 L
.75855 .00158 L
.75966 .00158 L
.76087 .00158 L
.76217 .00157 L
.76286 .00156 L
.76358 .00154 L
.76487 .00152 L
.76779 .00144 L
.77308 .00126 L
.77536 .00119 L
.77661 .00115 L
.7778 .00113 L
.77847 .00111 L
.7792 .0011 L
.78047 .00109 L
.78177 .00108 L
.78296 .00109 L
Mistroke
.78415 .0011 L
.78539 .00112 L
.78645 .00115 L
.78761 .0012 L
.7902 .00133 L
.79261 .0015 L
.79699 .00193 L
.80166 .00254 L
.81246 .00444 L
.82227 .00668 L
.82713 .00805 L
.83227 .00981 L
.84149 .01412 L
.84661 .01742 L
.8514 .02123 L
.85661 .0263 L
.86229 .03309 L
.87272 .04976 L
.88261 .07218 L
.89224 .10229 L
.90116 .13881 L
.92138 .24525 L
.93128 .29564 L
.93562 .31355 L
.93792 .32153 L
.94038 .32875 L
.94265 .33411 L
.94472 .33782 L
.94572 .3392 L
.9468 .34038 L
.94782 .3412 L
.94876 .34169 L
.94982 .34195 L
.95081 .34189 L
.95189 .34152 L
.95305 .34074 L
.95427 .33952 L
.95543 .33797 L
.9576 .33408 L
.95983 .32877 L
.96221 .32175 L
.96649 .30591 L
.97619 .25856 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool6o`0000Oooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`04ooooo`Oo00002_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`So00001Oooool00ol0003o
ooooooooo`0Co`0000;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Pooooo`00
9?ooool00ol0003oooooooooo`0Jooooo`Oo00003Oooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo00_ooooo1_l0000Looooo`03o`000?oooooooooo02gooooo00Co0000oooooooooooo
oooo1ol0000Sooooo`Go0000;Oooool00ol0003oooooooooo`0Pooooo`00?_ooool4o`0005Oooooo
0ol0000Iooooo`03o`000?oooooooooo02kooooo0ol0000_ooooo`Co0000C?ooool003gooooo00?o
0000ooooooooool0G?ooool2o`0001Oooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`0dooooo`;o0000B_ooool003cooooo00?o0000ooooooooool0Goooool2o`0001Gooooo00?o0000
ooooooooool0:oooool2o`0003Wooooo00?o0000ooooooooool0Aoooool003_ooooo00?o0000oooo
ooooool0H_ooool00ol0003oooooooooo`0Booooo`;o0000:_ooool2o`0003cooooo00?o0000oooo
ooooool0A_ooool003[ooooo00?o0000ooooooooool0I?ooool2o`0001;ooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo04Gooooo000iooooo`03o`00
0?oooooooooo06Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool0A?ooool003Sooooo00?o0000ooooooooool0JOoo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0@?oo
ool00ol0003oooooooooo`13ooooo`00>?ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooo
oooo04;ooooo000gooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0@_ooool003Ko
oooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`11ooooo`00=_ooool00ol0003ooooo
ooooo`1^ooooo`03o`000?oooooooooo00_ooooo0_l0000Uooooo`03o`000?oooooooooo04Kooooo
00?o0000ooooooooool0@?ooool003Gooooo00?o0000ooooooooool0Koooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0Aoooool00ol0003ooooooooo
o`10ooooo`00=?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo03oooooo000doooo
o`03o`000?oooooooooo07;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0?oooool003?ooooo00?o0000oooooooo
ool0Loooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool0Boooool00ol0003oooooooooo`0nooooo`00<oooool00ol0003oooooooooo`1dooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1<ooooo`03o`00
0?oooooooooo03kooooo000booooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool02?oo
ool2o`00027ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0mooooo`00<_ooool0
0ol0003oooooooooo`1fooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`1>ooooo`03o`000?oooooooooo03gooooo000aooooo`03o`000?oooooooooo
07Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
04kooooo00?o0000ooooooooool0?Oooool0037ooooo00?o0000ooooooooool0N?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0D?ooool00ol0003o
ooooooooo`0looooo`00<Oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo03cooooo
000`ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0>oooool0033ooooo00?o0000
ooooooooool0N_ooool00ol0003oooooooooo`05ooooo`;o00007_ooool00ol0003oooooooooo`1B
ooooo`03o`000?oooooooooo03_ooooo000`ooooo`03o`000?oooooooooo07_ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo05?ooooo00?o0000oooo
ooooool0>oooool002oooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0jooooo`00
;oooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo03[ooooo000_ooooo`03o`000?oo
oooooooo06Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool5o`0000Gooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo03[ooooo
000^ooooo`03o`000?oooooooooo06Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
E_ooool00ol0003oooooooooo`0iooooo`00;_ooool00ol0003oooooooooo`1Yooooo`05oa0@4?oo
ooooooooooooool@41003_ooool00ol0003oooooo`000005ooooo`?o00006oooool00ol0003ooooo
ooooo`1Fooooo`03o`000?oooooooooo03Wooooo000^ooooo`03o`000?oooooooooo06Wooooo00Go
0000ooooooooooooooooo`00000>ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo03Wooooo000^ooooo`03o`00
0?oooooooooo06Wooooo00Go0000ooooooooooooooooo`00000>ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo
03Wooooo000]ooooo`03o`000?oooooooooo06[ooooo00Go410@oooooooooooooooooa0@400>oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1H
ooooo`03o`000?oooooooooo03Sooooo000]ooooo`03o`000?oooooooooo06[ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0>ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo03Sooooo000]ooooo`03o`000?oooooo
oooo06[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo000000?ooooo00Go
0000ooooooooooooooooo`00000Kooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0
>?ooool002gooooo00?o0000ooooooooool0POooool01Ol0003ooooooooooooooooo000001_ooooo
00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0gooooo`00;?ooool00ol0003ooooooooo
o`22ooooo`04o`000?ooooooooooooooo`;o00006Oooool00ol0003oooooooooo`1Kooooo`03o`00
0?oooooooooo03Oooooo000/ooooo`03o`000?oooooooooo08?ooooo00Co0000oooooooooooo0000
6_ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo03Oooooo000/ooooo`03o`000?oo
oooooooo08?ooooo00Co0000oooooooooooo00006_ooool00ol0003oooooooooo`1Kooooo`03o`00
0?oooooooooo03Oooooo000/ooooo`03o`000?oooooooooo08?ooooo00Co0000oooooooooooo0000
6Oooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo03Kooooo000[ooooo`03o`000?oo
oooooooo08Gooooo00?o0000ooooool000006Oooool00ol0003oooooooooo`1Mooooo`03o`000?oo
oooooooo03Kooooo000[ooooo`03o`000?oooooooooo08Gooooo00?o0000ooooool000006Oooool0
0ol0003oooooooooo`1Mooooo`03o`000?oooooooooo03Kooooo000[ooooo`03o`000?oooooooooo
08Gooooo00Co0000ooooool0003o00006?ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooo
oooo03Kooooo000[ooooo`03o`000?oooooooooo08Kooooo0_l0000Hooooo`03o`000?oooooooooo
05kooooo00?o0000ooooooooool0=_ooool002[ooooo00?o0000ooooooooool0Qoooool2o`0001So
oooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0eooooo`00:_ooool00ol0003ooooo
ooooo`27ooooo`;o00006?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo03Gooooo
000Zooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`1Pooooo`03o`000?oooooooooo03Gooooo000Zooooo`03o`000?oooooooooo08Sooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo03Gooooo000Zoooo
o`03o`000?oooooooooo08Sooooo0_l0000Fooooo`03o`000?oooooooooo063ooooo00?o0000oooo
ooooool0=Oooool002Wooooo00?o0000ooooooooool0ROooool2o`0001Gooooo00?o0000oooooooo
ool0H_ooool00ol0003oooooooooo`0dooooo`00:Oooool00ol0003oooooooooo`29ooooo`;o0000
5Oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo03Cooooo000Yooooo`03o`000?oo
oooooooo08Wooooo0_l0000Eooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0=?oo
ool002Wooooo00?o0000ooooooooool0ROooool2o`0001Cooooo00?o0000ooooooooool0Hoooool0
0ol0003oooooooooo`0dooooo`00:Oooool00ol0003oooooooooo`29ooooo`03o`000?oooooo0000
01?ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0dooooo`00:?ooool00ol0003o
ooooooooo`2:ooooo`?o00004oooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo03Co
oooo000Xooooo`03o`000?oooooooooo08[ooooo00?o0000ooooool000004oooool00ol0003ooooo
ooooo`1Tooooo`03o`000?oooooooooo03?ooooo000Xooooo`03o`000?oooooooooo08[ooooo00Co
0000oooooooooooo00004Oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo03?ooooo
000Xooooo`03o`000?oooooooooo08[ooooo00Co0000oooooooooooo00004Oooool00ol0003ooooo
ooooo`1Uooooo`03o`000?oooooooooo03?ooooo000Xooooo`03o`000?oooooooooo06oooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00Co0000oooooooooooo
00004Oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo03?ooooo000Wooooo`03o`00
0?oooooooooo073ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00Co0000oooooooooooo00004?ooool00ol0003oooooooooo`1V
ooooo`03o`000?oooooooooo03?ooooo000Wooooo`03o`000?oooooooooo073ooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00Go0000ooooooooooooooooo`00
000?ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0<_ooool002Oooooo00?o0000
ooooooooool0L?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01_oo
ool3o`000003ooooool0003ooooo00kooooo00?o0000ooooooooool0Ioooool00ol0003ooooooooo
o`0booooo`009oooool00ol0003oooooooooo`1`ooooo`05o`000?ooooooooooooooool000003_oo
ool00omgMgOoIVIVooooo`05ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003ooooo
ooooo`1Xooooo`03o`000?oooooooooo03;ooooo000Wooooo`03o`000?oooooooooo073ooooo00Go
410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0
<_ooool002Oooooo00?o0000ooooooooool0L?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo03;ooooo000Vooooo`03o`00
0?oooooooooo077ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0J?ooool00ol0003oooooooooo`0booooo`009_ooool00ol0003oooooooooo`2<ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Zooooo`03
o`000?oooooooooo037ooooo000Vooooo`03o`000?oooooooooo08cooooo0_l00004ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0aooooo`009_oo
ool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo037ooooo000Vooooo`03o`000?oooooo
oooo08cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo06_ooooo00?o0000ooooooooool0<Oooool002Gooooo00?o0000ooooooooool0SOooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Joooool00ol0
003oooooooooo`0aooooo`009Oooool00ol0003oooooooooo`2=ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo033o
oooo000Uooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0<?ooool002Gooooo00?o
0000ooooooooool0SOooool2o`0000Oooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1^ooooo`03o`000?oooooooooo033ooooo000Uooooo`03o`000?oooooooooo08gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06kooooo00?o0000
ooooooooool0<?ooool002Cooooo00?o0000ooooooooool0S_ooool00ol0003oooooooooo`07oooo
o`05o`000?ooooooooooooooool00000LOooool00ol0003oooooooooo`0`ooooo`009?ooool00ol0
003oooooooooo`2>ooooo`03o`000?oooooooooo00Sooooo0ol0001cooooo`03o`000?oooooooooo
02oooooo000Tooooo`03o`000?oooooooooo08kooooo00?o0000ooooooooool0O_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo023ooooo002eooooo`03o`000?oooooooooo07kooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Pooooo`00]Oooool2o`0007oooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Pooooo`00]Oooool00ol0003oooooooooo`1n
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool08Oooool00;Gooooo00?o0000oooo
ooooool0Ooooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo027ooooo002eooooo`03
o`000?oooooooooo07oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Qooooo`00
]Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
8Oooool00;Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo027ooooo002eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Rooooo`00]Oooool2o`00087ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Rooooo`00]Oooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool08_ooool00;Gooooo00?o0000ooooooooool0P?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo02;ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo083o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Rooooo`00V_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S801_ooool00ol0
003oooooooooo`20ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08oooool009[o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0POooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02?ooooo002Jooooo`05
o`000?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`05ooooo`?o0000POooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo02?ooooo002Jooooo`05o`000?oooooooooooooo
ool000003Oooool00ol@413o0000okZj^P06ooooo`03o`000?oooooooooo087ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Sooooo`00V_ooool01Ol@413ooooooooooooooooo410@
00kooooo00?o^[Zjob4Q8Oooool01Oooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool09?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003oooooooooo`22ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool09?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`22ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool09?ooool00;Gooooo00?o0000ooooooooool0P_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Cooooo002eooooo`;o0000Q?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo02Gooooo002eooooo`03o`000?oooooooooo08?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Uooooo`00]Oooool00ol0003ooooo
ooooo`23ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09Oooool00;Gooooo00?o
0000ooooooooool0Q?ooool01?l0003oooooooooool0000Xooooo`00]Oooool00ol0003ooooooooo
o`25ooooo`;o0000:Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aoooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool009[ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Co
oooo00?o0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol0002`ooooo`00V_ooool01Ol0003ooooo
oooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool00ol0003oooooooooo`2`oooo
o`00V_ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool0
0ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMg
olc<c?l000001oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`2`
ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooo
oooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000;3ooooo002Jooooo`05o`00
0?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3o
oooo002Jooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooa0@400<oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo002/ooooo`03o`000?nj^[[ooooo0;Wooooo002/
ooooo`;o<S8b^_ooool007gooooo0_l000001_l@413oooooooooool@413o0000oa0@41Sooooo1?l0
00001Ol@413oooooooooooooooooA4A400;o000000Oo<S8bomgMgOooooooooooohN7Qol0003o^[Zj
00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`Go00000oooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h0Loooool007kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko0000
3?ooool00ol0003oooooooooo`06ooooo`07ogMgMolb<S;oooooooooooo<c<co0000oa0@400<oooo
o`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4
A003ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`1cooooo`00O_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo01_ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100Looo
ool007kooooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00003?ooool00ol0003ooooo
ooooo`06ooooo`03ogMgMolb<S;ooooo013ooooo00?o0000ooooooooool02oooool6o`0000_ooooo
00?oV9RHob4Q8Oo^k^h00oooool01Olb<S;oV9RHoooooonHV9So<S8b00?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool00000Loooool007kooooo00Ko0000omgM
gOlb<S;oEEEEomgMgOl0000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00Aooooo`03o`000?oooooooooo01gooooo00?oMgMgofIVI_ooool00_ooool01Oo<c<co0000
o`000?l0003oc<c<00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool00000Loooool007kooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Kooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool04Oooool00ol@413o0000o`000003o`0001gooooo00Wo
0000oooooooooooooooooa0@4?nj^[[ooooookZj^_l@41000oooool01Ol@413ooooooooooooooooo
410@00?ooooo00Go410@oooooooooooooooooa0@401cooooo`00O_ooool01_l0003o<S8boooooooo
oooo<S8bo`0001_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo01[ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05o`000?nj^[[ooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`1cooooo`00OOooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo00?oEEEE
ofIVI_l000001Oooool4o`0001;ooooo00?o0000ooooooooool06_ooool01OnHV9So410@o`000?lQ
8B7oc<c<00?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07?ooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2900) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .08746 m
.04262 .16696 L
.06244 .27388 L
.06747 .2976 L
.07286 .31841 L
.07547 .32636 L
.07793 .3324 L
.08015 .33651 L
.0814 .33827 L
.08255 .33951 L
.08382 .34046 L
.08453 .3408 L
.08518 .34099 L
.08644 .34102 L
.08764 .34064 L
.08831 .34025 L
.08903 .3397 L
.09032 .33836 L
.09185 .33617 L
.09325 .33364 L
.09605 .32704 L
.09908 .31776 L
.10458 .29598 L
.12413 .19149 L
.13448 .13826 L
.14018 .11353 L
.14558 .09359 L
.1507 .07776 L
.15627 .06358 L
.166 .04477 L
.17591 .03104 L
.18507 .02145 L
.1897 .01748 L
.1947 .01383 L
.19901 .01118 L
.20373 .0088 L
.20897 .00676 L
.21164 .00594 L
.21448 .00522 L
.21716 .00466 L
.21959 .00423 L
.22434 .00361 L
.22665 .00338 L
.22919 .00317 L
.23432 .00282 L
.24352 .00229 L
.26432 .00089 L
.26909 .00058 L
.2743 .00029 L
.27921 7e-05 L
Mistroke
Mfstroke
.27921 7e-05 m
.2814 0 L
s
.31287 0 m
.31366 1e-05 L
.31839 9e-05 L
.32077 .00012 L
.32213 .00013 L
.32336 .00014 L
.32475 .00015 L
.32552 .00015 L
.32624 .00015 L
.32752 .00016 L
.32825 .00016 L
.32892 .00016 L
.33009 .00015 L
.33139 .00015 L
.33204 .00014 L
.33274 .00014 L
.334 .00013 L
.33668 .0001 L
.33922 7e-05 L
s
.33922 7e-05 m
.34386 0 L
s
.36548 0 m
.36839 7e-05 L
.37263 .0002 L
.38227 .00053 L
.38724 .00067 L
.38861 .0007 L
.39006 .00072 L
.39141 .00075 L
.39266 .00076 L
.39395 .00077 L
.39462 .00078 L
.39533 .00078 L
.39653 .00079 L
.39784 .00079 L
.39902 .00079 L
.40027 .00078 L
.40146 .00078 L
.40254 .00077 L
.40475 .00076 L
.40596 .00075 L
.4071 .00075 L
.40832 .00075 L
.40897 .00074 L
.40967 .00074 L
.41092 .00075 L
.41205 .00075 L
.41314 .00076 L
.41415 .00077 L
.41526 .00079 L
.41645 .00081 L
.41887 .00088 L
.42107 .00096 L
.42338 .00108 L
.42592 .00124 L
.43106 .00168 L
.44027 .00273 L
.45114 .00415 L
.46107 .00542 L
.46585 .00609 L
.47105 .00696 L
.47597 .00805 L
.48053 .00939 L
.48584 .01149 L
.49065 .01396 L
.50143 .02174 L
.51149 .03183 L
.52073 .04351 L
.53087 .05953 L
.54157 .08158 L
.55108 .10703 L
Mistroke
.56126 .14053 L
.57961 .20748 L
.58457 .22343 L
.58982 .23769 L
.59256 .24377 L
.59558 .24925 L
.59691 .25122 L
.59833 .25303 L
.59958 .25435 L
.60091 .25548 L
.60161 .25596 L
.60224 .25632 L
.60348 .25685 L
.60418 .25703 L
.60493 .25713 L
.60564 .25715 L
.6063 .25709 L
.60748 .2568 L
.60879 .25622 L
.60944 .25582 L
.61015 .25532 L
.61142 .25422 L
.614 .25122 L
.61645 .24747 L
.62104 .23828 L
.63069 .21159 L
.64094 .17671 L
.65936 .11341 L
.66873 .0863 L
.67882 .06277 L
.68836 .04603 L
.6971 .03474 L
.7069 .02552 L
.71601 .01907 L
.72666 .01307 L
.73671 .00855 L
.74148 .00683 L
.74652 .00536 L
.74916 .00474 L
.75206 .00418 L
.75472 .00377 L
.75716 .00348 L
.75953 .00326 L
.76179 .00311 L
.76302 .00304 L
.76417 .003 L
.76542 .00295 L
.76676 .00292 L
.76793 .0029 L
.76919 .00288 L
Mistroke
.77038 .00287 L
.77147 .00286 L
.77367 .00284 L
.77574 .00282 L
.77693 .00281 L
.77821 .00279 L
.77938 .00276 L
.78045 .00274 L
.7829 .00265 L
.7855 .00252 L
.78773 .00238 L
.78983 .00223 L
.7946 .00178 L
.80467 .00063 L
.80733 .00034 L
.81017 7e-05 L
Mfstroke
.81017 7e-05 m
.81105 0 L
s
.83293 0 m
.83548 .00018 L
.84018 .00056 L
.84514 .00094 L
.84937 .0012 L
.85177 .00132 L
.854 .00141 L
.85521 .00144 L
.85636 .00147 L
.85741 .00149 L
.85852 .00151 L
.85972 .00152 L
.86083 .00153 L
.86203 .00153 L
.86335 .00153 L
.86466 .00153 L
.86586 .00152 L
.86856 .0015 L
.86975 .00149 L
.87106 .00149 L
.87229 .00148 L
.87344 .00148 L
.87458 .00148 L
.87582 .00149 L
.877 .0015 L
.87807 .00152 L
.87905 .00154 L
.88012 .00157 L
.88228 .00166 L
.88463 .00178 L
.88715 .00196 L
.8917 .00242 L
.89427 .00276 L
.89699 .00319 L
.90188 .00414 L
.90714 .00543 L
.91295 .0072 L
.92333 .01143 L
.93307 .01702 L
.94291 .02495 L
.94785 .03011 L
.95326 .03695 L
.96285 .05305 L
.97177 .0742 L
.97619 .08746 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00So
oooo2_l00003ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo3Ol0000;ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`04o`000?oooooooooooooo
o`oo00001Oooool00ol0003oooooooooo`07oooooa7o00002Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo023ooooo000Tooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool01?ooool4o`0002Gooooo00?o0000ooooooooool08Oooool5o`0000Oooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`0Fooooo`?o00005?ooool00ol0003oooooooooo`0Hooooo`Co
00004Oooool00ol0003oooooooooo`0Pooooo`00Foooool00ol0003oooooooooo`1@ooooo`?o0000
1?ooool00ol0003oooooooooo`14ooooo`;o0000=_ooool00ol0003oooooooooo`0aooooo`00F?oo
ool3o`0005Kooooo0_l00002ooooo`03o`000?oooooooooo047ooooo0ol0000iooooo`?o0000<?oo
ool005Oooooo00?o0000ooooooooool0FOooool00ol0003oooooo`000011ooooo`;o0000?oooool0
0ol0003oooooooooo`0]ooooo`00E_ooool00ol0003oooooooooo`1Kooooo`?o0000?oooool00ol0
003oooooooooo`10ooooo`03o`000?oooooooooo02cooooo001Eooooo`03o`000?oooooooooo05go
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo02_o
oooo001Eooooo`03o`000?oooooooooo05gooooo0_l0000mooooo`03o`000?oooooooooo04Cooooo
0_l0000[ooooo`00E?ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooo000003_ooooo00?o
0000ooooooooool0Aoooool00ol0003oooooooooo`0Xooooo`00Doooool00ol0003oooooooooo`1O
ooooo`04o`000?ooooooooooo`0003Wooooo00?o0000ooooooooool0B?ooool00ol0003ooooooooo
o`0Xooooo`00Doooool00ol0003oooooooooo`1Oooooo`05o`000?ooooooooooooooool00000=ooo
ool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo02Oooooo001Booooo`03o`000?oooooo
oooo063ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo04_ooooo00?o0000ooooooooool09oooool0057ooooo00?o0000ooooooooool0HOooool2o`00
00Cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo
02Kooooo001@ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool09Oooool0053ooooo
00?o0000ooooooooool0H_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02oooooo
00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Uooooo`00Coooool00ol0003ooooooooo
o`1Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`1Aooooo`03o`000?oooooooooo02Cooooo001>ooooo`03o`000?oooooooooo06Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo05;ooooo00?o0000
ooooooooool09?ooool004kooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`0Soooo
o`00COooool00ol0003oooooooooo`1Uooooo`;o00001oooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo05Cooooo00?o0000ooooooooool08oooool004gooooo00?o0000ooooooooool0
IOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
EOooool00ol0003oooooooooo`0Rooooo`00C?ooool00ol0003oooooooooo`1Vooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1Fooooo`03o`000?oo
oooooooo02;ooooo001<ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool08_ooool0
04cooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Qooooo`00Boooool00ol0003o
ooooooooo`1Wooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`1Hooooo`03o`000?oooooooooo027ooooo001;ooooo`03o`000?oooooooooo06Oooooo
0_l0000:ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0F?ooool00ol0003ooooo
ooooo`0Qooooo`00B_ooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo023ooooo000T
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0P
ooooo`009?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo06Sooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo07kooooo000Tooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool0C_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0O_ooool002Gooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`1>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool0O_ooool002Gooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`1>ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05oooo
o`?o00002oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo07oooooo000Uooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool0C_ooool01Ol0003ooooooooooooooooo0000
00kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool0Ooooool002Gooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`1?ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1ooooo
o`009_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo04oooooo00Go410@oooooooo
oooooooooa0@400>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo083ooooo000Vooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool0Coooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool0P?ooool002Kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1?ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`20ooooo`009_ooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo083ooooo000Wooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool0Joooool2o`0000kooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`21ooooo`009oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo06_ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo087ooooo000W
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0POooool002Oooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`21ooooo`00:?ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo06cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo08;ooooo000Xooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
K?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
P_ooool002Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1/ooooo`;o00004?oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo08;ooooo000Xooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool0Poooool002Wooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`23ooooo`00:Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo06go
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo08?o
oooo000Yooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Poooool002Wooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`24ooooo`00:_ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo06gooooo0_l0000Booooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0Q?ooool002[ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1^oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`24oooo
o`00:_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo06kooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo08Cooooo000Zooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool0QOooool002[ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`25ooooo`00:oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo06kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo08Gooooo000[ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0Koooool2o`00
01Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`25ooooo`00:oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo08Kooooo000[ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool0Koooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0Q_ooool002_ooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`1_ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`26ooooo`00;?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Cooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo08Oooooo000/ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool0E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0Qoooool002cooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`1Eooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Q
onk^kP07ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`27ooooo`00;?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo05Gooooo00Go
0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0000Eooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool0R?ooool002cooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`1Eooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIV
ooooo`05ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`28ooooo`00;Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05Gooooo00Go
410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo08Sooooo000]ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0EOooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`29ooooo`00;Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo05Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0ROooool002gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1aooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`29ooooo`00
;Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo077ooooo0_l0000Hooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0R_ooool002gooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`2:ooooo`00;_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo077ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo08[ooooo000^ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0L_ooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Roooool002ko
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2;ooooo`00;_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo08cooooo000^ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0L_ooool2o`0001[ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`2=ooooo`00;oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo07;ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo08kooooo000_oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0Koooo
o`05o`000?ooooooooooooooool00000T?ooool002oooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`1cooooo`03o`000?oooooooooo01_ooooo1?l0002Aooooo`00;oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0/?ooool002oooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo0;3ooooo
000`ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Loooool2o`000;7ooooo000`
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`2`
ooooo`00<?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo07Cooooo00?o0000oooo
ooooool0/?ooool0033ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1dooooo`03
o`000?oooooooooo0;3ooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
M?ooool00ol0003oooooooooo`2`ooooo`00<Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo07Cooooo00?o0000ooooooooool0/?ooool0037ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`1dooooo`03o`000?oooooooooo0;3ooooo000aooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0MOooool2o`000;7ooooo000booooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0MOooool00ol0003oooooooooo`2`ooooo`00<_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool0/?ooool003;ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`1Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0;3o
oooo000booooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0F_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S801_ooool00ol0
003oooooooooo`2`ooooo`00<_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05_o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0/?ooool003?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Kooooo`05
o`000?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`05ooooo`?o0000/?ooool003?o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Kooooo`05o`000?oooooooooooooo
ool000003Oooool00ol@413o0000okZj^P06ooooo`03o`000?oooooooooo0;3ooooo000cooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0G?ooool01Ol@413ooooooooooooooooo410@
00kooooo00?o^[Zjob4Q8Oooool01Oooool00ol0003oooooooooo`2`ooooo`00<oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo05cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003oooooooooo`2`ooooo`00<oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo05cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`2`ooooo`00=?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0/?ooool0
03Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1hooooo`;o0000/Oooool003Go
oooo00Go0000ooooooooooooooooo`00001kooooo`03o`000?oooooooooo0;3ooooo000eooooo`05
o`000?ooooooooooooooool00000Noooool00ol0003oooooooooo`2`ooooo`00=_ooool4o`0007_o
oooo00?o0000ooooooooool0/?ooool003Oooooo0_l0001looooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo
0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@
00_ooooo1Ol00006ooooo`?o0000/?ooool009[ooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0/?oo
ool009[ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o
0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000000Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002a
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`oooo
o`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooa0@400@oooo
o`03o`000?oooooooooo00?ooooo0ol0002`ooooo`00V_ooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol0003o
oooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002a
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00[?ooool00ol0003o^[Zjooooo`2iooooo`00[?ooool2oc8b<[[ooooo001m
ooooo`;o000000Ko410@oooooooooooo410@o`000?l@410Hooooo`Co000000Go410@oooooooooooo
ooooodA4A002o`000007oc8b<_oMgMgooooooooooon7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o
0000odA4A?nj^[X06?ooool5o`0000?ooooo00Co410@o`000?m4A4Coc<c<1?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1cooooo`00O_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l0000<ooooo`03o`000?oooooooooo00Ko
oooo00OoMgMgoc8b<_ooooooooooolc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@
4009ooooo`Ko00002Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo00?oV9RHoa0@4?oMgMd0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1coooo
o`00O_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01_ooooo00?oV9RHob4Q8Oo^
k^h01oooool00on7QhOoEEEEooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@07?ooooo001nooooo`06o`000?ooooooA4A4odA4A?oooooo00002Ooo
ool6o`0000cooooo00?o0000ooooooooool01_ooool00omgMgOo<S8booooo`0@ooooo`03o`000?oo
oooooooo00_ooooo1_l0000;ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Goc<c<ob4Q8Ol0003oEEEE
o`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
07?ooooo001nooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo00006oooool00ol0003oooooooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`04Oooool00ol0003oooooooooo`0Mooooo`03ogMgMomV
IVKooooo00;ooooo00Go8B4QohN7QoooooooV9RHo`000003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000007?ooooo001nooooo`06o`000?n7QhOoZJVYokZj
^_mEEEGo00006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o410@
o`000?l000000ol0000Mooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo077o
oooo001nooooo`06o`000?lb<S;ooooooooooolb<S;o00006oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonHV9So
410@00?ooooo00Go8B4QoiRHV?ooooooMgMgoeEEE@03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg07?ooooo001mooooo`03oa0@4?l0003oQhN700;ooooo
00?oQhN7o`000?l@41006?ooool00omEEEGoIVIVo`000005ooooo`Co00004_ooool00ol0003ooooo
ooooo`0Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo<c<co410@o`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0Looo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3000) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .00253 m
.02846 .00288 L
.03279 .00335 L
.03754 .00404 L
.04262 .00504 L
.04795 .00644 L
.053 .00817 L
.06244 .01264 L
.06754 .01584 L
.07295 .01993 L
.08265 .02941 L
.09308 .04368 L
.09902 .05442 L
.10458 .06679 L
.11496 .09746 L
.12483 .13735 L
.14335 .23503 L
.15294 .28561 L
.1582 .3088 L
.16078 .31833 L
.16316 .32583 L
.16537 .3316 L
.16779 .3365 L
.16905 .33844 L
.17023 .33986 L
.17147 .34094 L
.17217 .34136 L
.1728 .34162 L
.17392 .3418 L
.17495 .34165 L
.17609 .34114 L
.17729 .34021 L
.17833 .33907 L
.17931 .33773 L
.18154 .3337 L
.18398 .32782 L
.18624 .32105 L
.19138 .30151 L
.20173 .24961 L
.22023 .14935 L
.23075 .10454 L
.24069 .07354 L
.24961 .05335 L
.25928 .03708 L
.26874 .02498 L
.27915 .01524 L
.28439 .0117 L
.28728 .01013 L
.29002 .00888 L
.29257 .00792 L
Mistroke
.29534 .00707 L
.29787 .00645 L
.3002 .006 L
.30276 .00561 L
.30553 .00529 L
.30797 .00507 L
.31054 .00488 L
.31991 .00424 L
.32509 .00374 L
.32992 .00313 L
.34089 .0014 L
.34592 .00063 L
.34856 .00027 L
Mfstroke
.34856 .00027 m
.3509 0 L
s
.37567 0 m
.37985 .00035 L
.38471 .00073 L
.3871 .00089 L
.38932 .00102 L
.39186 .00113 L
.3932 .00117 L
.39388 .00118 L
.39462 .0012 L
.39583 .00121 L
.39712 .00122 L
.39835 .00121 L
.39947 .0012 L
.40053 .00117 L
.40167 .00114 L
.40373 .00106 L
.40617 .00093 L
.40839 .00079 L
.41779 2e-05 L
s
.41779 2e-05 m
.41805 0 L
s
.45211 0 m
.45774 .00051 L
.46262 .00096 L
.46723 .0013 L
.46978 .00145 L
.47112 .00151 L
.47255 .00156 L
.47375 .00159 L
.47507 .00162 L
.47627 .00163 L
.4774 .00163 L
.47847 .00163 L
.47964 .00162 L
.48086 .0016 L
.482 .00157 L
.48404 .00151 L
.48622 .00143 L
.49085 .00124 L
.49337 .00114 L
.49574 .00106 L
.49696 .00104 L
.49828 .00101 L
.49903 .00101 L
.49974 .001 L
.50038 .001 L
.50107 .00101 L
.50231 .00102 L
.50362 .00106 L
.50486 .00111 L
.50599 .00116 L
.50742 .00126 L
.50874 .00137 L
.51171 .00168 L
.51433 .00206 L
.5171 .00254 L
.52671 .00487 L
.53725 .00823 L
.54731 .01183 L
.55682 .01574 L
.56207 .01838 L
.56778 .02188 L
.57292 .02584 L
.57775 .0304 L
.58718 .04215 L
.59758 .06008 L
.60771 .0829 L
.6186 .11333 L
.6383 .17996 L
.64871 .21519 L
.65443 .23181 L
Mistroke
.65723 .23881 L
.65982 .24442 L
.66229 .24897 L
.665 .25294 L
.66632 .25446 L
.66773 .25579 L
.66851 .25638 L
.66922 .25683 L
.66989 .25717 L
.67061 .25746 L
.67186 .25775 L
.67302 .25778 L
.67426 .25756 L
.67497 .25731 L
.67563 .257 L
.67683 .25625 L
.67793 .25536 L
.6804 .25259 L
.6827 .24913 L
.68484 .24517 L
.68971 .23379 L
.69951 .20314 L
.71824 .13574 L
.73854 .0783 L
.74964 .05595 L
.75988 .03952 L
.76967 .02724 L
.77508 .02194 L
.78003 .01806 L
.78487 .01511 L
.78946 .013 L
.79431 .01137 L
.7996 .01009 L
.81791 .00653 L
.8289 .00378 L
.8343 .00242 L
.83925 .00135 L
.84378 .00062 L
.84605 .00036 L
.84734 .00024 L
.84855 .00016 L
.84985 9e-05 L
.85109 4e-05 L
.85219 2e-05 L
.8534 2e-05 L
.85471 4e-05 L
.85537 5e-05 L
.8561 8e-05 L
.85738 .00013 L
.85859 .0002 L
Mistroke
.86339 .00058 L
.86843 .00107 L
.8728 .00147 L
.87519 .00165 L
.87745 .00178 L
.87872 .00183 L
.87938 .00185 L
.88009 .00187 L
.88133 .0019 L
.88248 .00191 L
.88363 .0019 L
.88471 .00189 L
.88589 .00186 L
.88715 .00181 L
.88852 .00175 L
.89 .00166 L
.8927 .00146 L
.89776 .00098 L
.90265 .00047 L
Mfstroke
.90265 .00047 m
.90756 0 L
s
.93243 0 m
.93279 2e-05 L
.9385 .00048 L
.94774 .00119 L
.95782 .00173 L
.97619 .00253 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool6o`0000Kooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooooooo2Ol0000;oooo
o`03o`000?oooooooooo00Co00001Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo0000
00So000000?oooooo`000?l000001_l00004ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ool000001Ol00004ooooo`03o`000?oooooooooo00;ooooo2?l0000;ooooo`04o`000?oooooooooo
ooooo`Wo00008_ooool002Cooooo00?o0000ooooooooool00oooool3o`0002Sooooo00?o0000oooo
ooooool07oooool6o`0000Sooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`05oooo
o`?o00009Oooool00ol0003oooooooooo`0[ooooo`Co0000;_ooool00ol0003oooooooooo`0Poooo
o`00;Oooool3o`0004Cooooo0ol0000nooooo`03o`000?oooooooooo00Sooooo0ol0001<ooooo`Co
0000EOooool0033ooooo0_l00011ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0
2oooool3o`0004Kooooo0ol0001Iooooo`00<_ooool00ol0003oooooooooo`0mooooo`03o`000?oo
oooooooo043ooooo00?o0000ooooooooool03_ooool2o`0004?ooooo00?o0000ooooooooool0F_oo
ool003?ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`11ooooo`;o00004Oooool0
0ol0003oooooooooo`0nooooo`;o0000GOooool003Cooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`12ooooo`03o`000?oooooooooo017ooooo0_l0000mooooo`03o`000?oooooooooo
05gooooo000eooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0@oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0G_ooool003Kooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Nooooo`00=_ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0gooooo`03o`000?oooooooooo05oooooo000gooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool0A_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03Gooooo00?o0000
ooooooooool0H?ooool003Sooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`16oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`1Qoooo
o`00>Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo04Oooooo0_l0000Hooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool0HOooool003Wooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`1Rooooo`00>_ooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo04Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo06?ooooo000jooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0BOooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0Hoooool0
03_ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Tooooo`00>oooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo06Cooooo000looooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool0B_ooool2o`0001_ooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`1Uooooo`00?Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo04_ooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo06Gooooo000m
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0I_ooool003gooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`1Wooooo`00?_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo04cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo06Oooooo000nooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
C?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
J?ooool003kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1=ooooo`;o00007ooo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo06Sooooo000oooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool0JOooool003oooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`1=ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`1Yooooo`00?oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo04ko
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo06Wo
oooo0010ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0<oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000?o410@ooooooooool00oooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0J_ooool0043ooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`0cooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool0J_ooool0043ooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`0dooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003o
ooooooooo`05ooooo`?o00008?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo06[o
oooo0010ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0=?ooool01Ol0003ooooo
oooooooooooo000000kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool0Joooool0047ooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`0dooooo`05o`000?ooooooooooooooool000003_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`1[ooooo`00@Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03Cooooo
00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo06_ooooo0011ooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool0=Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool0K?ooool0047ooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`0eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`000007ooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1/ooooo`00
@_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo06cooooo0012ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool0D?ooool2o`0002?ooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`1]ooooo`00@_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo057ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo06gooooo0012ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0DOooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0KOooool004?o
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1^ooooo`00@oooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo06kooooo0013ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool0DOooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool0K_ooool004?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1B
ooooo`;o00009Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo06oooooo0014oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Koooool004Cooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`1_ooooo`00A?ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo05;ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo073ooooo0014ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0D_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0L?oo
ool004Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1`ooooo`00AOooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo05?ooooo0_l0000Vooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool0L?ooool004Gooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`1Cooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`1aooooo`00AOooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo05?ooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo077ooooo
0015ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Doooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0LOooool004Gooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`1booooo`00A_ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo05Cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo07;ooooo0016ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0E?ooool2o`0002Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1booooo`00
A_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo07;ooooo0016ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0Loooool004Kooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`1Eooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`1cooooo`00Aoooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
03[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo07?ooooo0017oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0>_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0M?ooool004Oooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0jooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`1dooooo`00Aoooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo03[ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0
000Yooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0M?ooool004Oooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0kooooo`05o`000?ooooooooooooooool000003_oo
ool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`1eooooo`00B?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo03_ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo07Gooooo0018
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0>oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo02[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`1eooooo`00B?ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo03_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0M_ooool004Sooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`1Fooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`1fooooo`00B?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05Oooooo0_l0
000/ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0M_ooool004Wooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`1gooooo`00BOooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo07Oooooo0019ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0Eoooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0Moooool004Wooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Gooooo`03o`00
0?oooooooooo02gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1gooooo`00BOoo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07Sooooo001:ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0F?ooool2o`0002kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1hooooo`00B_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
05Sooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
07Wooooo001:ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0F?ooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0NOooool004[ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo033ooooo
1?l0001looooo`00B_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo05Sooooo00?o
0000ooooooooool0/?ooool004_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1I
ooooo`03o`000?oooooooooo0;3ooooo001;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0FOooool2o`000;7ooooo001;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0FOooool00ol0003oooooooooo`2`ooooo`00Boooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo05Wooooo00?o0000ooooooooool0/?ooool004_ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo0;3ooooo001<ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`2`ooooo`00C?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool0/?ooool004co
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo0;3o
oooo001<ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0F_ooool2o`000;7ooooo
001<ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0F_ooool00ol0003ooooooooo
o`2`ooooo`00C?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05_ooooo00?o0000
ooooooooool0/?ooool004gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`10oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<
c006ooooo`03o`000?oooooooooo0;3ooooo001=ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0@?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oa0@4?nj
^[[oooooogMgMolb<S801_ooool00ol0003oooooooooo`2`ooooo`00COooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo043ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0/?ooool004gooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`10ooooo`05o`000?ooooooooooooooool000003_ooool00onYZJWo410@
ooooo`05ooooo`?o0000/?ooool004gooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`10ooooo`05o`000?ooooooooooooooool000003Oooool00ol@413o0000okZj^P06ooooo`03o`00
0?oooooooooo0;3ooooo001>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0@Ooo
ool01Ol@413ooooooooooooooooo410@00kooooo00?o^[Zjob4Q8Oooool01Oooool00ol0003ooooo
ooooo`2`ooooo`00C_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo047ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003o
ooooooooo`2`ooooo`00C_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo047ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0
003oooooooooo`2`ooooo`00Coooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05co
oooo00?o0000ooooooooool0/?ooool004oooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1Mooooo`;o0000/Oooool004oooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`1Nooooo`03o`000?oooooooooo0;3ooooo001@ooooo`05o`000?ooooooooooooooool00000H?oo
ool00ol0003oooooooooo`2`ooooo`00D?ooool2o`000003ooooool0003o0000063ooooo00?o0000
ooooooooool0/?ooool0057ooooo0ol0001Qooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
0006ooooo`?o0000/?ooool009[ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oM
gMgoooooo`0000Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000oooooooooooooooo
o`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0/?ooool009[ooooo
00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooooooo
ool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oo
oooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03
ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00V_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oo
oooooooo00?ooooo0ol0002`ooooo`00V_ooool01Ol0003ooooooooooooooooo000000oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol0003ooooooooooooo
oooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo
002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00[?ooool00ol0003o^[Zjooooo`2iooooo`00[?ooool2oc8b<[[ooooo001mooooo`;o0000
00Ko410@oooooooooooo410@o`000?l@410Hooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000007oc8b<_oMgMgooooooooooon7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj
^[X06?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07?ooooo
001nooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`0000cooooo00?o
0000ooooooooool01_ooool01omgMgOo<S8booooooooooooc<c<o`000?l@41003?ooool01Ol@413o
^[Zjonk^k_mgMgOo410@00Wooooo1_l00009ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0Loooool007kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0Nooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo077ooooo001noooo
o`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000cooooo00?o0000ooooooooool01_oo
ool00omgMgOo<S8booooo`0@ooooo`03o`000?oooooooooo00_ooooo1_l0000<ooooo`03ojVYZOl@
413ooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000007?ooooo001nooooo`06o`000?oMgMgo<S8boeEE
EOoMgMgo00006oooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`04Ooo
ool00ol0003oooooooooo`0Looooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
07?ooooo001nooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo00006oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo017ooooo00?o410@o`000?l000000ol0000Looooo`03okZj^_lQ8B7o
oooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100
0oooool01Ol@413ooooooooooooooooo410@07?ooooo001nooooo`06o`000?lb<S;ooooooooooolb
<S;o00006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool06_ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg07?o
oooo001mooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool00omEEEGoIVIV
o`000005ooooo`Co00004_ooool00ol0003oooooooooo`0Jooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0Loooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3100) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .00023 m
.06244 .00063 L
.06484 .00082 L
.06744 .001 L
.06973 .00113 L
.07216 .00124 L
.07351 .00129 L
.07499 .00133 L
.07564 .00134 L
.07634 .00135 L
.0776 .00137 L
.07824 .00137 L
.07893 .00137 L
.08019 .00137 L
.08141 .00137 L
.08255 .00135 L
.08404 .00133 L
.08545 .0013 L
.08807 .00124 L
.09114 .00116 L
.09248 .00113 L
.09396 .0011 L
.09515 .00108 L
.09644 .00106 L
.09715 .00106 L
.09779 .00105 L
.09906 .00105 L
.09976 .00105 L
.10042 .00105 L
.10113 .00106 L
.10189 .00107 L
.10317 .0011 L
.1039 .00112 L
.10458 .00115 L
.10689 .00125 L
.1082 .00133 L
.10942 .00141 L
.11209 .00164 L
.11451 .0019 L
.11892 .00251 L
.12362 .00336 L
.12869 .00452 L
.13418 .00606 L
.14415 .00978 L
.15362 .0147 L
.16403 .02233 L
.16927 .02736 L
.1749 .0339 L
.18018 .04139 L
.18507 .04979 L
Mistroke
.1952 .07293 L
.20055 .089 L
.20625 .10948 L
.22635 .20745 L
.23666 .26384 L
.24208 .29056 L
.2478 .31408 L
.25022 .32213 L
.25282 .32929 L
.25431 .33267 L
.25566 .33526 L
.25704 .3374 L
.25832 .33893 L
.25947 .33994 L
.2607 .34061 L
.26193 .34086 L
.26263 .34082 L
.26328 .34066 L
.26446 .34008 L
.26555 .3392 L
.26673 .33788 L
.26798 .33608 L
.27056 .33105 L
.273 .32477 L
.27755 .30939 L
.28776 .26158 L
.30614 .16079 L
.31589 .11569 L
.3262 .07981 L
.33499 .05812 L
.34466 .04128 L
.35485 .02849 L
.36415 .01949 L
.36928 .01535 L
.37488 .01151 L
.38012 .00855 L
.38505 .00635 L
.38957 .00482 L
.39189 .00421 L
.39444 .00366 L
.39707 .00322 L
.39841 .00304 L
.39984 .00288 L
.40119 .00276 L
.40241 .00267 L
.40355 .0026 L
.4048 .00254 L
.40611 .00249 L
.40683 .00247 L
.4075 .00246 L
Mistroke
.40869 .00244 L
.40998 .00244 L
.4107 .00243 L
.41149 .00244 L
.41223 .00244 L
.41292 .00244 L
.41422 .00245 L
.4156 .00246 L
.41693 .00248 L
.41762 .00248 L
.41836 .00249 L
.419 .00249 L
.41971 .00249 L
.42095 .00249 L
.42216 .00249 L
.42346 .00247 L
.42469 .00245 L
.4258 .00243 L
.42698 .0024 L
.42809 .00236 L
.43062 .00224 L
.43308 .00208 L
.43573 .00187 L
.4449 .0009 L
Mfstroke
.4449 .0009 m
.45273 0 L
s
.48505 0 m
.48572 6e-05 L
.49143 .00057 L
.49423 .00078 L
.4968 .00094 L
.49915 .00105 L
.50033 .00109 L
.50162 .00112 L
.50292 .00114 L
.50365 .00114 L
.50432 .00114 L
.50561 .00113 L
.50683 .00111 L
.50898 .00105 L
.5102 .00101 L
.51134 .00095 L
.51563 .0007 L
.52057 .00034 L
.5251 3e-05 L
s
.5251 3e-05 m
.52561 0 L
s
.54216 0 m
.54281 4e-05 L
.54523 .00026 L
.5498 .00077 L
.55484 .00146 L
.56506 .00286 L
.57027 .0034 L
.57321 .00364 L
.5759 .0038 L
.58086 .00403 L
.58608 .00422 L
.58865 .00434 L
.59108 .00448 L
.59326 .00465 L
.59562 .0049 L
.5982 .00525 L
.60092 .00573 L
.60582 .00694 L
.61033 .00849 L
.61456 .01032 L
.62418 .01585 L
.63458 .02366 L
.64446 .03284 L
.65332 .04316 L
.66299 .05804 L
.67333 .07988 L
.68269 .1058 L
.70368 .17893 L
.71305 .21112 L
.71818 .22632 L
.72295 .23818 L
.72813 .24794 L
.73087 .25164 L
.73241 .25323 L
.73381 .25438 L
.73508 .25517 L
.73626 .25567 L
.73756 .25598 L
.73821 .25604 L
.73893 .25602 L
.74014 .25582 L
.74144 .25534 L
.74266 .25465 L
.74378 .25382 L
.74627 .25129 L
.74853 .24819 L
.75361 .23865 L
.7583 .22693 L
.76274 .21378 L
.78345 .13992 L
Mistroke
.79319 .10739 L
.80349 .07934 L
.81229 .06092 L
.82195 .04547 L
.83214 .03291 L
.84143 .0237 L
.84657 .0194 L
.85216 .0154 L
.8574 .01232 L
.86233 .01003 L
.86684 .00842 L
.87171 .00715 L
.87434 .00663 L
.87711 .00617 L
.88207 .00554 L
.90307 .00315 L
.91259 .00177 L
.91783 .00111 L
.9204 .00085 L
.92278 .00066 L
.92502 .00052 L
.92614 .00047 L
.92739 .00042 L
.92863 .00039 L
.92933 .00038 L
.92997 .00037 L
.93121 .00037 L
.93239 .00038 L
.93344 .00039 L
.93456 .00042 L
.93561 .00045 L
.93657 .00049 L
.94113 .00071 L
.94537 .00095 L
.94932 .00116 L
.95132 .00124 L
.95234 .00128 L
.95345 .00131 L
.95467 .00133 L
.95582 .00135 L
.95694 .00135 L
.95798 .00135 L
.9591 .00134 L
.96016 .00132 L
.96132 .00129 L
.96258 .00125 L
.96513 .00112 L
.96746 .00097 L
.97619 .00023 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo000000So
000000?oooooo`000?l000001_l00005ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00oo00001_ooool00ol0003o
ooooooooo`09ooooo`?o00002Oooool00ol0003oooooooooo`02ooooo`_o00002?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`08ooooo`Wo00001?ooool01?l0003oooooooooooooool6o`0000;ooooo00?o0000oooo
ooooool08?ooool002Cooooo00?o0000ooooooooool07Oooool5o`0000cooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`0:ooooo`;o00008Oooool00ol0003oooooooooo`0Iooooo`Go
00003oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00gooooo1ol0000Iooooo`03
o`000?oooooooooo023ooooo0019ooooo`;o0000AOooool2o`0002?ooooo00?o0000ooooooooool0
7_ooool4o`0004Sooooo0ol00013ooooo`00Boooool00ol0003oooooooooo`10ooooo`;o00009Ooo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0A?oo
ool004cooooo0_l0000oooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool08oooool2
o`0004;ooooo0_l00017ooooo`00C_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
02Kooooo0_l0000Vooooo`03o`000?oooooooooo03gooooo0_l00019ooooo`00Coooool2o`0003[o
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0BOooool0057ooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0>_ooool00ol0003ooooo
ooooo`19ooooo`00DOooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo04[ooooo001B
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0Boooool005;ooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`1;ooooo`00Doooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo02_ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo04cooooo001Dooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
;?ooool2o`0002cooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`1=ooooo`00E?oo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0:ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo04kooooo001Eooooo`03o`000?oooooo
oooo02gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool0C_ooool005Gooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`1?ooooo`00E_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo053o
oooo001Fooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0D?ooool005Oooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`0_ooooo`;o0000;oooool00ol0003ooooooooo
o`0[ooooo`03o`000?oooooooooo057ooooo001Gooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool0DOooool005Oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1Boooo
o`00F?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo05?ooooo001Hooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool0Doooool005Wooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0booooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1Dooooo`00FOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo03;ooooo0_l0000booooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0E?ooool0
05Wooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Eooooo`00F_ooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo05Gooooo001Jooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool0EOooool005_ooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`0Hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l000000ol@413ooooo
ooooo`03ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`1Fooooo`00Foooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01Wooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo03?ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1Fooooo`00Fooo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01Wooooo00Go410@oooooooooooooooo
oa0@400>ooooo`03o`000?oooooooooo00Gooooo0ol0000cooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool0E_ooool005cooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0Iooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1Gooooo`00G?oo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01Wooooo00Go0000oooooooooooooooo
o`00000>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo05Oooooo001Looooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool06_ooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
Eoooool005cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Jooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Gooooo`00GOooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo01[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03oeEE
EOmVIVKo000000Oooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo05Sooooo001Mooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0F?oo
ool005gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0fooooo`;o0000=oooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo05Sooooo001Mooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool0FOooool005gooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`1Iooooo`00G_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo03Kooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05Wooooo
001Nooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0=_ooool00ol0003ooooooooo
o`0gooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0F_ooool005kooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo03Oooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`1Jooooo`00G_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo03Oooooo0_l0000iooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool0F_ooool005kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1Jooooo`00
Goooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo05_ooooo001Oooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0Foooool005oooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0hooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`1Kooooo`00Goooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
03Sooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
05cooooo001Oooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0>?ooool2o`0003_o
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Looooo`00H?ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0>_ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo05cooooo001Pooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool0>?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0G?ooool0063ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1M
ooooo`00H?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05gooooo001Pooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool0GOooool0067ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0iooooo`;o0000??ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo05gooooo001Qooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0>Ooo
ool00ol0003oooooooooo`0looooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0G_oo
ool0067ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Nooooo`00HOooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo05kooooo001Qooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool07oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00001_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0Goooool006;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Oooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006
ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1O
ooooo`00H_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0?Oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05oooooo001Rooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool08?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h01_ooool3o`0003kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1O
ooooo`00H_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo023ooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0?_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo063ooooo001Rooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool08?ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool0H?ooool006;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Poooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo063ooooo001S
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool08?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo03oooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Qooooo`00Hoooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0?oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo067ooooo001Sooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0??ooool2o`00043ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1R
ooooo`00Hoooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03cooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo06;ooooo001Sooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`10ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0H_ooool006Cooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`1Sooooo`00I?ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo03gooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo06?ooooo001Tooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0?Oooool0
0ol0003oooooooooo`12ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0I?ooool0
06Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0mooooo`;o0000@oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo06Gooooo001Tooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0IOooool006Cooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0mooooo`03o`000?oooooooooo04?ooooo0_l00002ooooo`03o`000?oooooooooo06Kooooo
001Uooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0?_ooool00ol0003ooooooooo
o`14ooooo`?o0000JOooool006Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo0;3ooooo001Uooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool0?_ooool00ol0003oooooooooo`2`ooooo`00IOooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo03kooooo0_l0002aooooo`00IOooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool0/?ooool006Kooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo0;3ooooo001Vooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`2`ooooo`00I_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0/?ooool006Ko
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo0;3o
oooo001Wooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`2`ooooo`00Ioooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo043ooooo0_l0
002aooooo`00Ioooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo043ooooo00?o0000
ooooooooool0/?ooool006Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`10oooo
o`03o`000?oooooooooo0;3ooooo001Wooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05oiRHV?l@413o0000
oc8b<_o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00J?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo02Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1Ol@413o^[ZjoooooomgMgOo<S8b00Kooooo00?o0000ooooooooool0/?ooool006Sooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Vooooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;3ooooo001Xooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool09_ooool01Ol0003ooooooooooooooooo000000kooooo00?o
ZJVYoa0@4?ooool01Oooool3o`000;3ooooo001Xooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool09_ooool01Ol0003ooooooooooooooooo000000gooooo00?o410@o`000?nj^[X01_oo
ool00ol0003oooooooooo`2`ooooo`00J?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo02Kooooo00Go410@oooooooooooooooooa0@400>ooooo`03okZj^_lQ8B7ooooo00Gooooo00?o
0000ooooooooool0/?ooool006Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0W
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413oV9RHoooooonj^[[o000000Kooooo
00?o0000ooooooooool0/?ooool006Wooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Ko
oooo00?o0000ooooooooool0/?ooool006Wooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`12ooooo`03o`000?oooooooooo0;3ooooo001Zooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0@_ooool2o`000;7ooooo001Zooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0@oooool00ol0003oooooooooo`2`ooooo`00Joooool01?l0003oooooooooool00016
ooooo`03o`000?oooooooooo0;3ooooo001[ooooo`Co0000A_ooool00ol0003oooooooooo`2`oooo
o`00K?ooool2o`0004Oooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2
o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol0002`
ooooo`00V_ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001ooo
ool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol0003ooooooooooooooooo000000_ooooo00Co
gMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooo
oooooooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`2`ooooo`00V_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0003ooooo
ooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool0
1_ooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`
ooooo`00V_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3
o`000;3ooooo002Jooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05o`000?ooooooooooooooool000003?ooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?oo
ool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_oo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002/ooooo`03
o`000?nj^[[ooooo0;Wooooo002/ooooo`;o<S8b^_ooool007gooooo0_l000001_l@413ooooooooo
ool@413o0000oa0@41Sooooo1?l000001Ol@413oooooooooooooooooA4A400;o000000Oo<S8bomgM
gOooooooooooohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`01?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0Loooool007kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`07ooooo`Ko00003?ooool00ol0003oooooooooo`06ooooo`07ogMgMolb
<S;oooooooooooo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`00
00Wooooo00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Loooool007kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@401cooooo`00O_ooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000<oooo
o`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool04?ooool00ol0003oooooooooo`0;oooo
o`Ko00003?ooool00onYZJWo410@ooooo`05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000Loooool007kooooo00Ko0000
omgMgOlb<S;oEEEEomgMgOl0000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c00Aooooo`03o`000?oooooooooo01cooooo00?o410@o`000?nj^[X01_ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000007?ooooo001nooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo00006oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo017ooooo00?o410@o`000?l000000ol0000Looooo`03okZj^_lQ
8B7ooooo00Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooooooooa0@401cooooo`00O_ooool01_l0003o<S8boooooooooooo<S8bo`00
01_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
01[ooooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Loooool007gooooo00?o
410@o`000?n7QhL00_ooool00on7QhOo0000oa0@400Hooooo`03oeEEEOmVIVKo000000Gooooo1?l0
000Booooo`03o`000?oooooooooo01[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@04ooooo`03oeEE
EOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h0Loooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3200) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .00222 m
.02605 .00232 L
.02846 .00243 L
.02962 .00248 L
.03072 .00252 L
.0317 .00254 L
.03279 .00257 L
.03398 .00258 L
.03524 .00259 L
.03641 .00258 L
.0375 .00256 L
.03879 .00252 L
.03997 .00247 L
.04132 .0024 L
.04262 .00231 L
.045 .0021 L
.04753 .00182 L
.0521 .00119 L
s
.0521 .00119 m
.05957 0 L
s
.09331 0 m
.09411 .00011 L
.09956 .00086 L
.10195 .00113 L
.10458 .00138 L
.10576 .00147 L
.10703 .00155 L
.10773 .00159 L
.10837 .00161 L
.10963 .00165 L
.11033 .00167 L
.11097 .00167 L
.11168 .00167 L
.11244 .00167 L
.11316 .00166 L
.11384 .00164 L
.1151 .00159 L
.11631 .00153 L
.11759 .00145 L
.11988 .00126 L
.12504 .00068 L
.13004 0 L
s
.13004 0 m
.13005 0 L
s
.16321 0 m
.1633 1e-05 L
.17204 .00142 L
.17668 .00209 L
.18165 .00265 L
.18428 .00286 L
.18669 .003 L
.18785 .00305 L
.1891 .0031 L
.19029 .00312 L
.1914 .00314 L
.19262 .00315 L
.19377 .00316 L
.19503 .00315 L
.19574 .00315 L
.19639 .00314 L
.19914 .00311 L
.20048 .00309 L
.2017 .00307 L
.20277 .00306 L
.20378 .00306 L
.20484 .00306 L
.20599 .00307 L
.20718 .00309 L
.20844 .00312 L
.20951 .00316 L
.21069 .00322 L
.21193 .00331 L
.21305 .0034 L
.21559 .00368 L
.21794 .00404 L
.22017 .00449 L
.2252 .00587 L
.22976 .00761 L
.23503 .01024 L
.23999 .0133 L
.24883 .02011 L
.25838 .02952 L
.2679 .04177 L
.27833 .06069 L
.2836 .07346 L
.28923 .09021 L
.2994 .12953 L
.31923 .23354 L
.32968 .28843 L
.33496 .311 L
.338 .32159 L
.34078 .32946 L
.34329 .33492 L
.34455 .33706 L
Mistroke
.34593 .3389 L
.34664 .33966 L
.34732 .34024 L
.34809 .34076 L
.3488 .34109 L
.35008 .34133 L
.3508 .34126 L
.35147 .34107 L
.35267 .34041 L
.35379 .33944 L
.35502 .33798 L
.35634 .33596 L
.35904 .33042 L
.3615 .32377 L
.3662 .30726 L
.37132 .28452 L
.38065 .23516 L
.39167 .17418 L
.40202 .12413 L
.41132 .08921 L
.41612 .07498 L
.42137 .06196 L
.43131 .04312 L
.4418 .02893 L
.45152 .01923 L
.46057 .01262 L
.4656 .0099 L
.47106 .00766 L
.47356 .00686 L
.47621 .00614 L
.48098 .00515 L
.48554 .00449 L
.48981 .00402 L
.49955 .00319 L
.51808 .00131 L
.52312 .00078 L
.52787 .00035 L
.5305 .00016 L
Mfstroke
.5305 .00016 m
.53314 0 L
s
.55286 0 m
.55416 5e-05 L
.55943 .00031 L
.5645 .00056 L
.56922 .00076 L
.5716 .00084 L
.57414 .00091 L
.57559 .00094 L
.5763 .00095 L
.57696 .00096 L
.57819 .00097 L
.57884 .00098 L
.57952 .00098 L
.58073 .00098 L
.58205 .00098 L
.58329 .00097 L
.58445 .00095 L
.58559 .00094 L
.58663 .00092 L
.58895 .00087 L
.59382 .00072 L
.59909 .00055 L
.60148 .00048 L
.604 .00041 L
.60504 .00039 L
.60616 .00037 L
.60738 .00035 L
.60852 .00034 L
.60966 .00034 L
.61091 .00034 L
.61208 .00035 L
.61316 .00036 L
.61414 .00038 L
.61522 .00041 L
.6174 .00048 L
.61975 .0006 L
.62233 .00077 L
.62751 .00123 L
.63231 .00179 L
.63677 .00241 L
.65764 .00567 L
.66818 .00742 L
.67336 .00849 L
.67813 .00974 L
.68247 .0112 L
.68706 .01315 L
.69211 .01588 L
.69672 .01897 L
.70618 .02725 L
.71633 .0392 L
Mistroke
.72573 .0534 L
.73465 .07026 L
.75453 .12351 L
.77294 .18912 L
.7819 .21958 L
.78661 .23308 L
.79157 .24452 L
.79421 .24924 L
.79561 .25131 L
.7971 .25319 L
.79848 .25461 L
.79973 .25563 L
.80099 .2564 L
.80218 .25688 L
.80339 .25713 L
.80467 .25713 L
.80576 .25691 L
.80697 .25644 L
.80826 .25568 L
.80965 .25456 L
.81216 .25177 L
.8147 .24798 L
.8174 .24295 L
.82227 .2316 L
.8333 .1978 L
.85339 .12767 L
.86368 .09601 L
.87481 .06809 L
.88531 .04818 L
.89498 .03498 L
.89968 .03006 L
.90472 .02569 L
.91381 .01953 L
.93448 .00957 L
.94465 .00576 L
.9504 .0041 L
.95315 .00347 L
.95572 .00298 L
.95814 .00261 L
.96036 .00235 L
.96156 .00224 L
.96282 .00215 L
.96409 .00208 L
.96481 .00205 L
.96548 .00203 L
.96613 .00201 L
.96683 .002 L
.96811 .00199 L
.96935 .00199 L
.97049 .00201 L
Mistroke
.97173 .00204 L
.97309 .00209 L
.97584 .0022 L
.97619 .00222 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool:o`0000;ooooo00?o0000ooooooooool02Oooool7o`0000Ko
oooo00?o0000ooooooooool01Oooool?o`000003ooooool0003ooooo00[ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo2_l00006ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07o`0000;o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool01?l0003oooooooooooooool9o`0002;ooooo000Tooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool02?ooool4o`00027ooooo00?o0000oooooooo
ool08oooool6o`0000Cooooo00?o0000ooooooooool0:oooool6o`0002cooooo00?o0000oooooooo
ool08oooool2o`0000Sooooo00?o0000ooooooooool08?ooool006Cooooo0_l00014ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0<Oooool3o`0004cooooo0ol0000]ooooo`00I_oo
ool2o`00043ooooo0_l0000;ooooo`03o`000?oooooooooo03Cooooo0ol00016ooooo`?o0000<?oo
ool006Sooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo03Oooooo0_l00012ooooo`;o0000<oooool006Wooooo00?o0000ooooooooool0>_ooool00ol0
003oooooooooo`0<ooooo`;o0000>_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
03?ooooo001Zooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0=?ooool006_ooooo
00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool0>Oooool2o`0003Oooooo001/ooooo`03o`000?oooooooooo03Cooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo03Oooooo00?o
0000ooooooooool0=oooool006cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0g
ooooo`00KOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0?_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Sooooo001]ooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool0>?ooool006kooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`0Booooo`;o0000@?ooool00ol0003oooooooooo`0booooo`03o`00
0?oooooooooo03Wooooo001^ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0>_oo
ool006oooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo043ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0kooooo`00L?ooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0@Oooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo03_ooooo001`ooooo`03o`000?oooooooooo02_o
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool0??ooool0077ooooo00?o0000ooooooooool0:_ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`0looooo`00L_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01Gooooo0_l0
0014ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0?Oooool007;ooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04?ooooo00?o0000
ooooooooool0:_ooool00ol0003oooooooooo`0mooooo`00Loooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo03kooooo001cooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool0?_ooool007?ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo04Gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0oooooo`00M?oo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0AOoo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03oooooo001dooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool05oooool2o`0004Kooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`10ooooo`00M?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
043ooooo001eooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`16ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0@Oooool007Gooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04Kooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`11ooooo`00MOooool00ol0003ooooooooo
o`0Rooooo`05o`000?lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l000000ol@413ooooo
ooooo`03ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`12ooooo`00MOooool00ol0003oooooooooo`0Qooooo`06o`000?mgMgOoV9RHoooooonHV9So
MgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`17ooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool0@_ooool007Kooooo00?o0000ooooooooool0
8?ooool00ol0003o410@ooooo`02ooooo`03oa0@4?oooooooooo00cooooo00?o0000ooooooooool0
1Oooool3o`0004Oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`12ooooo`00M_oo
ool00ol0003oooooooooo`0Pooooo`;o00000oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo04?ooooo001fooooo`03o`000?oooooooooo01oooooo00?o0000ooooool000000oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0B?ooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo04?ooooo001gooooo`03o`000?oooooooooo
01kooooo00?o0000ooooool@41000oooool00ol@413oooooooooo`0<ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
04?ooooo001gooooo`03o`000?oooooooooo01kooooo00Oo0000oooooomgMgOoV9RHoooooonHV9So
MgMg00kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`19ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool0A?ooool007Oooooo00?o0000ooooooooool07_ooool01ol0
003oooooonk^k_lb<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`000007ooooo`03o`000?oo
oooooooo04Wooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`14ooooo`00Moooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0BOooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04Cooooo001hooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool06oooool2o`0004_ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`15ooooo`00N?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04Go
oooo001hooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`1:ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0AOooool007Sooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04_ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`15ooooo`00N?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo04Kooooo001iooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool0A_ooool007Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Looooo`;o
0000COooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04Kooooo001iooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1<ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool0Aoooool007Wooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`17ooooo`00NOooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo04Oooooo001jooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`1=ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Aoooool007[o
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04go
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`18ooooo`00N_ooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo01gooooo0_l0001>ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool0B?ooool007[ooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`18ooooo`00N_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool0C_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04Wooooo001koooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1>oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0BOooool007_ooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo04oooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`19ooooo`00Noooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo04Wooooo001kooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool07_oo
ool2o`00053ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1:ooooo`00Noooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0D?ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04[ooooo001kooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0B_ooool007cooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`1;ooooo`00O?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000oooooooo
ool0D?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04_ooooo001looooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1Aoooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool0Boooool007cooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onH
V9So8B4Qonk^kP07ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`1;ooooo`00O?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0001Aoooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0C?ooool007gooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000003_ooool00omg
MgOoIVIVooooo`05ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`1<ooooo`00OOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Go
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0DOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04cooooo001mooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool01Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo05;ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`1=ooooo`00OOooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0COooool007gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1=
ooooo`00O_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo023ooooo0_l0001Doooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0C_ooool007kooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo05?ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`1>ooooo`00O_ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo04kooooo001nooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Cooo
ool007kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo05Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1?ooooo`00O_ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0EOooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo053ooooo001oooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool08_ooool2o`0005Kooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`1Aooooo`00Ooooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool0E_ooool2o`0000Cooooo00?o0000ooooooooool0DOooool007oooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo05Oooooo00Co
0000oooooooooooooooo0_l0001Cooooo`00Ooooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool0F?ooool3o`0005Gooooo001oooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`2`ooooo`00P?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0/?ooool0083o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Sooooo`;o0000/Oooool0083ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo0;3ooooo
0020ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`2`ooooo`00P?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool0/?ooool0083ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo0;3ooooo0021ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`2`ooooo`00POooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool0/?ooool0087ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Tooooo`;o0000/Oooool0087ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo0;3ooooo0021ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`2`ooooo`00P_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Kooooo00?o0000ooooooooool0/?ooool0
08;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0;ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oo
oooooooo0;3ooooo0022ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02oooool0
1Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`2`ooooo`00Poooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ojVYZOl@413ooooo00Gooooo0ol0002`ooooo`00Poooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oa0@4?l0003o^[Zj00Kooooo00?o0000ooooooooool0/?ooool008?ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`05oa0@4?ooooooooooooooool@41003_oo
ool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo0;3ooooo0024ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool03?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0;3ooooo0024ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool03?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo0;3ooooo0024ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`2`ooooo`00QOoo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Sooooo0_l0002aooooo`00QOooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0/?ooool0
08Gooooo0_l00002ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0/?ooool008Ko
oooo1?l0000[ooooo`03o`000?oooooooooo0;3ooooo0027ooooo`;o0000;?ooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0
003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go00001_ooool3o`000;3ooooo002Jooooo`05o`000?oooooooooooooo
ool000002oooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo0;3ooooo002Joooo
o`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oo
oooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00
0007ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol0003oooooooooo`03ooooo`?o0000/?ooool009[ooooo00Go0000oooooooo
ooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009[o
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00:cooooo00?o0000okZj^_ooool0^Oooool00:cooooo0_lb
<S:jooooo`00OOooool2o`000006oa0@4?oooooooooooa0@4?l0003o410@6?ooool4o`000005oa0@
4?oooooooooooooooom4A4@00_l000001olb<S;ogMgMooooooooooooQhN7o`000?nj^[X03?ooool0
1OnHV9So0000o`000?m4A4Co^[Zj01Sooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`Go0000
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1coooo
o`00O_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l0000<ooooo`03
o`000?oooooooooo00Kooooo00OoMgMgoc8b<_ooooooooooolc<c?l0003o410@00cooooo00Go410@
okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002Oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg07?ooooo001nooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`02ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooo
oooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100Loooool007kooooo00Ko0000
oooooom4A4CoA4A4ooooool00009ooooo`Ko00003?ooool00ol0003oooooooooo`06ooooo`03ogMg
Molb<S;ooooo013ooooo00?o0000ooooooooool02oooool6o`0000cooooo00?oZJVYoa0@4?ooool0
1?ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000007?ooooo001nooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo00006oooool0
0ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`04Oooool00ol0003ooooooooo
o`0Looooo`03oa0@4?l0003o^[Zj00Kooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`00001cooooo`00O_ooool01_l0003oQhN7
ojVYZOnj^[[oEEEEo`0001_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aoooo
o`03oa0@4?l0003o000000?o00007?ooool00onj^[[o8B4Qooooo`06ooooo`05o`000?oooooooooo
ooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0LOoo
ool007kooooo00Ko0000oc8b<_oooooooooooc8b<_l0000Kooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Jooooo`05oa0@4?nHV9SooooookZj^_l0
00000oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Loooool007gooooo00?o410@o`000?n7QhL00_ooool0
0on7QhOo0000oa0@400Hooooo`03oeEEEOmVIVKo000000Gooooo1?l0000Booooo`03o`000?oooooo
oooo01[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1coooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3300) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01934 m
.02846 .01597 L
.03279 .01357 L
.03754 .01164 L
.0402 .01082 L
.04262 .0102 L
.06244 .00665 L
.07225 .00437 L
.08265 .00191 L
.08526 .00141 L
.08808 .00096 L
.08969 .00074 L
.09116 .00058 L
.09266 .00045 L
.09405 .00035 L
.0953 .00029 L
.096 .00026 L
.09663 .00024 L
.09733 .00022 L
.09808 .00021 L
.09879 .00021 L
.09945 .00021 L
.10064 .00023 L
.10194 .00026 L
.1026 .00029 L
.10331 .00032 L
.10458 .00038 L
.10972 .00071 L
.11243 .00091 L
.11531 .0011 L
.11781 .00124 L
.11915 .0013 L
.12058 .00136 L
.1219 .00139 L
.1231 .00141 L
.12425 .00142 L
.12547 .00141 L
.12666 .0014 L
.12774 .00138 L
.129 .00134 L
.13018 .00129 L
.13228 .00118 L
.13456 .00103 L
.1397 .00063 L
.14451 .00023 L
s
.14451 .00023 m
.14786 0 L
s
.16908 0 m
.16957 2e-05 L
.1752 .00032 L
.17778 .00044 L
.17919 .0005 L
.18052 .00054 L
.18174 .00057 L
.18285 .0006 L
.18409 .00062 L
.18474 .00062 L
.18543 .00063 L
.18671 .00063 L
.18787 .00062 L
.18852 .00061 L
.18921 .0006 L
.19048 .00058 L
.19167 .00055 L
.19292 .00051 L
.19517 .00042 L
.20068 .00015 L
s
.20068 .00015 m
.2036 0 L
s
.22915 0 m
.23464 .00027 L
.23968 .00052 L
.24189 .00061 L
.24433 .00069 L
.24538 .00072 L
.24651 .00075 L
.24749 .00076 L
.24855 .00078 L
.24975 .0008 L
.25089 .00081 L
.252 .00081 L
.25303 .00081 L
.25426 .00081 L
.25543 .00081 L
.25647 .00081 L
.2576 .0008 L
.26012 .00079 L
.26134 .00078 L
.26247 .00078 L
.26361 .00077 L
.26483 .00078 L
.26547 .00078 L
.26617 .00078 L
.26743 .0008 L
.26875 .00082 L
.27015 .00085 L
.27135 .00088 L
.27267 .00093 L
.275 .00103 L
.27751 .00118 L
.28205 .00156 L
.28738 .00216 L
.29298 .00297 L
.30299 .00479 L
.31255 .00708 L
.31789 .00875 L
.32275 .01064 L
.32729 .01281 L
.3322 .0157 L
.34112 .0227 L
.3506 .03318 L
.36101 .04954 L
.36626 .06035 L
.37189 .0744 L
.38206 .10765 L
.3922 .15198 L
.40325 .2106 L
.41381 .26849 L
.42336 .31204 L
Mistroke
.42825 .32781 L
.431 .33419 L
.43231 .33654 L
.43352 .33832 L
.4346 .33955 L
.43574 .34052 L
.43702 .34116 L
.43818 .34135 L
.43939 .34116 L
.4407 .34048 L
.44194 .3394 L
.44308 .33802 L
.44559 .3338 L
.44793 .32836 L
.45327 .31113 L
.45848 .28889 L
.46408 .26066 L
.48378 .15383 L
.49493 .10511 L
.50026 .08672 L
.50529 .07217 L
.51536 .0499 L
.5245 .03564 L
.53434 .02442 L
.54498 .01554 L
.55448 .00984 L
.55988 .00744 L
.56491 .00571 L
.56764 .00497 L
.57023 .00438 L
.57258 .00394 L
.57508 .00355 L
.57779 .00323 L
.5803 .003 L
.58299 .00283 L
.58453 .00276 L
.58597 .00271 L
.58715 .00268 L
.5884 .00265 L
.58959 .00263 L
.59067 .00262 L
.59193 .00261 L
.59331 .0026 L
.5958 .00258 L
.59715 .00257 L
.59841 .00255 L
.59973 .00254 L
.60118 .00251 L
.60358 .00245 L
.60492 .0024 L
Mistroke
.60615 .00235 L
.61069 .00209 L
.61326 .00189 L
.61564 .00167 L
.62465 .00066 L
.62974 7e-05 L
Mfstroke
.62974 7e-05 m
.63046 0 L
s
.65623 0 m
.65879 .00029 L
.66382 .00092 L
.66846 .00148 L
.67101 .00174 L
.67341 .00194 L
.67478 .00204 L
.67626 .00212 L
.6776 .00218 L
.67884 .00222 L
.68001 .00225 L
.68129 .00226 L
.68194 .00226 L
.68264 .00225 L
.68389 .00224 L
.68457 .00222 L
.6853 .0022 L
.6866 .00216 L
.68955 .00201 L
.69493 .00169 L
.69723 .00156 L
.69971 .00144 L
.7004 .00141 L
.70113 .00139 L
.70244 .00136 L
.70366 .00135 L
.70435 .00135 L
.705 .00136 L
.70627 .00139 L
.70691 .00141 L
.70762 .00144 L
.70887 .00151 L
.71003 .0016 L
.71267 .00188 L
.7155 .00231 L
.71816 .00283 L
.72068 .00343 L
.72542 .00478 L
.744 .01163 L
.75359 .01541 L
.75885 .01775 L
.76381 .02035 L
.76844 .02333 L
.77346 .02738 L
.7822 .03706 L
.79171 .05197 L
.80214 .07378 L
.82321 .13333 L
.84436 .20543 L
.84922 .22078 L
Mistroke
.85438 .23514 L
.85878 .24516 L
.86132 .24979 L
.86364 .25321 L
.86602 .25583 L
.86727 .25683 L
.86858 .2576 L
.86973 .25803 L
.8708 .25822 L
.87197 .2582 L
.87322 .25791 L
.87392 .25763 L
.87456 .2573 L
.87602 .25626 L
.87731 .25505 L
.87867 .25345 L
.88103 .24994 L
.88363 .24505 L
.88834 .23368 L
.89341 .2185 L
.90256 .18623 L
.92231 .11703 L
.93349 .08679 L
.94384 .06458 L
.95951 .0383 L
.96827 .02705 L
.97619 .01934 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo000000Go
00001?ooool01?l0003oooooooooooooool6o`0000?ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooooooo2Ol0000;
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06
oooooa3o00002oooool00ol0003oooooooooo`0Ao`0000Cooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08?ooool0
02Cooooo00?o0000ooooooooool01_ooool5o`0002?ooooo00?o0000ooooooooool08Oooool5o`00
00Oooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0>ooooo`Co00006oooool00ol0
003oooooooooo`0Aooooo`?o00006Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
023ooooo000Yooooo`Co0000DOooool2o`0003Gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0dooooo`?o0000JOooool002Oooooo0ol0001Fooooo`;o0000<oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo03Sooooo0ol0001Vooooo`009Oooool2o`0005_ooooo0_l0
000aooooo`03o`000?oooooooooo00[ooooo0_l0000nooooo`03o`000?oooooooooo06?ooooo000T
ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0;_ooool2o`0000[ooooo00?o0000
ooooooooool0?oooool3o`0003oooooo00?o0000ooooooooool08?ooool008Gooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04?ooooo0_l0000loooo
o`03o`000?oooooooooo027ooooo0026ooooo`03o`000?oooooooooo02cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool08_ooool008Oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo04Sooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Rooooo`00R?oo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0B_oo
ool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02?ooooo0028ooooo`03o`000?oooooo
oooo02[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool09?ooool008Wooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`0Uooooo`00R_ooool00ol0003oooooooooo`0Xooooo`;o00001?ooool00ol0003o
ooooooooo`1>ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool09Oooool008[ooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04kooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Vooooo`00Roooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Coooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo02Kooooo002;ooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool09oooool008cooooo00?o0000ooooooooool09_ooool01Ol0003ooooooooooooooooo
000005?ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Wooooo`00S?ooool00ol0
003oooooooooo`0Vooooo`05o`000?ooooooooooooooool00000E?ooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo02Sooooo002<ooooo`03o`000?oooooooooo02Kooooo0_l000000ooo
oooo0000ooooo`1Dooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0:?ooool008go
oooo00?o0000ooooooooool09Oooool00ol0003oooooo`00001Gooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool0:Oooool008gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
o`00001Hooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:Oooool008gooooo00?o
0000ooooooooool09Oooool2o`0005Wooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0Zooooo`00S_ooool00ol0003oooooooooo`0Tooooo`;o0000F_ooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo02[ooooo002>ooooo`03o`000?oooooooooo02Cooooo0_l0001Joooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0:oooool008kooooo00?o0000oooooooo
ool09?ooool2o`0005_ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0/ooooo`00
Soooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0/ooooo`00Soooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo05[ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0]ooooo`00Soooool0
0ol0003oooooooooo`0Rooooo`;o0000GOooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo02gooooo002@ooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1Oooool4o`000003oa0@4?oooooooooo00;ooooo0_l0001Mooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool0;_ooool0093ooooo00?o0000ooooooooool01oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo0_l0001M
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0;_ooool0093ooooo00?o0000oooo
ooooool01oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool00oooool0
0ol0003oooooo`000002o`0005cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0^
ooooo`00TOooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooo000005kooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0_ooooo`00TOooool00ol0003oooooooooo`06ooooo`05o`000?oooooooooo
ooooool000003_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000005kooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0_ooooo`00TOooool00ol0003oooooooooo`06oooo
o`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
000005oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0_ooooo`00TOooool00ol0
003oooooooooo`06ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0005oooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0`ooooo`00T_ooool00ol0003oooooooooo`05ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?oo
ool00omEEEGoIVIVo`000004ooooo`04o`000?ooooooooooo`0005oooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0`ooooo`00T_ooool00ol0003oooooooooo`0Mooooo`04o`000?oo
ooooooooo`00063ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0`ooooo`00T_oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00;o0000Goooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo033ooooo002Booooo`03o`000?oooooooooo01gooooo00Co0000
oooooooooooo0000H?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo037ooooo002C
ooooo`03o`000?oooooooooo01_ooooo00Go0000ooooooooooooooooo`00001Qooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool0<Oooool009?ooooo00?o0000ooooooooool06oooool0
1Ol0003ooooooooooooooooo0000067ooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0aooooo`00Toooool00ol0003oooooooooo`0Kooooo`05o`000?ooooooooooooooool00000HOoo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo03;ooooo002Cooooo`03o`000?oooooo
oooo01_ooooo00Go0000ooooooooooooooooo`00001Qooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool0<_ooool009?ooooo00?o0000ooooooooool06oooool01?l0003ooooooooooooo
ool2o`00067ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0booooo`00U?ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H?ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo03;ooooo002Dooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool0<oooool009Cooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`0cooooo`00U?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo03?ooooo
002Eooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`1Qooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0=?ooool009Gooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`02ooooo`;o0000H_ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo03Cooooo002Eooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0=?ooool009Gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo06;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0dooooo`00
UOooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
H_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03Gooooo002Fooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Rooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0=Oooool009Kooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0eooooo`00U_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
00Cooooo0_l0001Tooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0=_ooool009Ko
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06?o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0fooooo`00Uoooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0I?ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo03Kooooo002Gooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0=oooool009Oooooo00So0000ooooooooooook^k^oc8b<_l0003o<S8bonk^kPGo
oooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0=oooool009Oooooo00So0000ooooooooooooMgMgoiRHV?ooooooV9RH
ogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^o`000?m4A4@01_ooool00ol0003ooooooooo
o`1Tooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0=oooool009Oooooo00Co0000
oooooooooooo410@0oooool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7o000000Oooooo00?o
0000ooooooooool0IOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03Sooooo002H
ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool02oooool00onHV9So0000onk^kP06
ooooo`?o0000IOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03Sooooo002Hoooo
o`03o`000?oooooo000000?ooooo00?o0000ooooooooool03?ooool00ol0003oIVIVooooo`05oooo
o`03o`000?oooooooooo06Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0hoooo
o`00V?ooool00ol0003ooooooa0@4003ooooo`03oa0@4?oooooooooo00cooooo0_l00006ooooo`03
o`000?oooooooooo06Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0iooooo`00
V?ooool01ol0003oooooogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjooooool0003o
410@00Kooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo03Wooooo002Hooooo`07o`000?ooooook^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0>Oooool009Wooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0iooooo`00VOooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Kooooo0_l0001X
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>_ooool009Wooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0jooooo`00VOooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo03[ooooo002Iooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
>_ooool009Wooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo06Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0kooooo`00V_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0JOooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo03_ooooo002Jooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool01oooool2o`0006_ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0looooo`00V_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03go
oooo002Jooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`1[ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0?Oooool009[ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06cooooo1?l0
0010ooooo`00V_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0KOooool2o`00047ooooo002Kooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`2`ooooo`00Voooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00Sooooo0_l0002aooooo`00Voooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0/?ooool009_ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0;3ooooo002Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2`ooooo`00W?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0/?ooool009co
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0;3o
oooo002Looooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`2`ooooo`00W?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo0_l0
002aooooo`00WOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0/?ooool009gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000o`000?o^k^h01Oooool2ob4Q
8@;ooooo00Oo0000oooooonHV9So410@o`000?lb<S;oc<c<00Kooooo00?o0000ooooooooool0/?oo
ool009[ooooo00GoMgMgoiRHV?oooooo0000ogMgM`05ooooo`;o8B4Q00Woooooo`000?oooooooooo
oa0@4?nj^[[oooooogMgMolb<S801_ooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413o
ooooooooool0003o410@00Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo0;3ooooo002Jooooo`05o`000?ooooooooooooooool000002?ooool00ol0
003oooooooooo`03ooooo`03ojVYZOl@413ooooo00Gooooo0ol0002`ooooo`00V_ooool01Ol0003o
oooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool00ol@413o0000okZj^P06oooo
o`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool000002?ooool00ol0
003oooooooooo`03ooooo`03okZj^_lQ8B7ooooo00Gooooo00?o0000ooooooooool0/?ooool009[o
oooo00GoMgMgoiRHV?ooooooV9RHo`000007ooooo`09o`000?ooooooooooooooool@413oV9RHoooo
oonj^[[o000000Kooooo00?o0000ooooooooool0/?ooool009[ooooo00Kok^k^oc8b<_l0003o<S8b
onk^k_l00006ooooo`09o`000?oooooooooooooooonYZJWo410@o`000?l@413oZJVY00Kooooo00?o
0000ooooooooool0/?ooool009oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo0;3ooooo002Oooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool03Oooool2o`000;7ooooo002Oooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`2`ooooo`00X?ooool01Ol0003ooooooooooooooooo0000013o
oooo00?o0000ooooooooool0/?ooool00:7ooooo00Co0000ooooool0003o00004?ooool00ol0003o
ooooooooo`2`ooooo`00X_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo
0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@
00_ooooo1Ol00006ooooo`?o0000/?ooool009[ooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0/?oo
ool009[ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o
0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000000Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002a
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`oooo
o`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooa0@400@oooo
o`03o`000?oooooooooo00?ooooo0ol0002`ooooo`00V_ooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol0003o
oooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002a
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00[?ooool00ol0003o^[Zjooooo`2iooooo`00[?ooool2oc8b<[[ooooo001m
ooooo`;o000000Ko410@oooooooooooo410@o`000?l@410Hooooo`Co000000Go410@oooooooooooo
ooooodA4A002o`000007oc8b<_oMgMgooooooooooon7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o
0000odA4A?nj^[X06?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00GoV9RHoa0@4?l0003o
<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^07?ooooo001nooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`00
00cooooo00?o0000ooooooooool01_ooool01omgMgOo<S8booooooooooooc<c<o`000?l@41003?oo
ool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00009ooooo`05oa0@4?nj^[[oooooogMgMolb
<S800oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Loooool007kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`1aooooo`00O_oo
ool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000<ooooo`03o`000?oooooooooo00Ko
oooo00?oMgMgoc8b<_ooool04?ooool00ol0003oooooooooo`0;ooooo`Ko00003?ooool00onYZJWo
410@ooooo`05ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool00000Loooool007kooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0
000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Aooooo`03o`00
0?oooooooooo01cooooo00?o410@o`000?nj^[X01Oooool00ol@413o0000okZj^P03ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000007?ooooo001nooooo`06
o`000?n7QhOoZJVYokZj^_mEEEGo00006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo017ooooo00?o410@o`000?l000000ol0000Looooo`03okZj^_lQ8B7ooooo00Gooooo00?o^[Zj
ob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooo
oa0@401cooooo`00O_ooool01_l0003o<S8boooooooooooo<S8bo`0001_ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01[ooooo00Go410@oiRHV?oo
oooo^[Zjo`000003ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1cooooo`00OOooool00ol@413o0000ohN7
Q`02ooooo`03ohN7Qol0003o410@01Sooooo00?oEEEEofIVI_l000001Oooool4o`0001;ooooo00?o
0000ooooooooool06_ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^07?ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3400) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .16023 m
.03279 .12879 L
.04262 .09824 L
.053 .07202 L
.06244 .05356 L
.07298 .03801 L
.08426 .02584 L
.0947 .01767 L
.0994 .01482 L
.10458 .0122 L
.10925 .01027 L
.11428 .0086 L
.11958 .00723 L
.12455 .00624 L
.13418 .00484 L
.14299 .00379 L
.15296 .00258 L
.16359 .00125 L
.16875 .0007 L
.17128 .00046 L
.17361 .00028 L
.17569 .00015 L
.17798 4e-05 L
s
.17798 4e-05 m
.179 0 L
s
.18901 0 m
.19037 5e-05 L
.19296 .00016 L
.20268 .00075 L
.20731 .001 L
.20964 .0011 L
.21096 .00115 L
.21218 .00118 L
.21332 .0012 L
.21439 .00121 L
.21535 .00122 L
.2164 .00122 L
.21753 .00121 L
.21874 .00118 L
.21976 .00116 L
.2209 .00112 L
.22339 .00101 L
.22611 .00084 L
.23106 .00044 L
s
.23106 .00044 m
.23575 0 L
s
.27197 0 m
.27614 .00043 L
.27893 .0007 L
.28153 .00091 L
.28402 .00108 L
.2851 .00114 L
.28627 .0012 L
.28757 .00124 L
.28878 .00127 L
.28946 .00128 L
.29018 .00129 L
.29146 .00129 L
.29254 .00127 L
.2937 .00125 L
.29479 .00121 L
.29579 .00117 L
.29824 .00104 L
.30055 .00086 L
s
.30055 .00086 m
.30898 0 L
s
.34126 0 m
.34915 .00116 L
.35447 .00193 L
.35706 .00225 L
.35941 .00249 L
.36155 .00267 L
.36387 .00282 L
.36514 .00288 L
.36632 .00293 L
.36744 .00296 L
.36862 .00298 L
.36981 .00299 L
.3711 .00299 L
.37231 .00298 L
.37341 .00296 L
.3747 .00294 L
.37611 .00291 L
.37866 .00285 L
.37982 .00283 L
.38106 .00281 L
.38224 .0028 L
.38331 .00279 L
.38451 .0028 L
.38581 .00283 L
.38647 .00285 L
.38717 .00288 L
.38844 .00294 L
.38978 .00304 L
.39124 .00318 L
.39388 .00354 L
.39645 .00402 L
.39882 .00461 L
.40313 .00604 L
.40787 .00817 L
.41746 .01422 L
.42763 .02284 L
.43692 .03264 L
.44205 .03912 L
.44764 .04749 L
.45782 .06805 L
.46315 .08261 L
.46817 .09921 L
.47754 .13822 L
.49853 .25111 L
.50833 .29959 L
.51326 .31838 L
.51609 .32684 L
.51867 .33289 L
.51981 .33503 L
.52104 .33698 L
Mistroke
.52211 .33834 L
.52329 .33948 L
.52454 .34028 L
.52522 .34054 L
.52586 .34067 L
.52701 .34062 L
.52824 .34017 L
.52938 .33938 L
.53062 .33812 L
.5318 .33655 L
.53289 .33476 L
.53716 .32493 L
.5398 .31669 L
.54223 .3078 L
.54772 .28381 L
.55767 .23134 L
.57627 .13316 L
.586 .09412 L
.59509 .06739 L
.6003 .05573 L
.60506 .04697 L
.61575 .03198 L
.62566 .02179 L
.63482 .01445 L
.64489 .00852 L
.64997 .00639 L
.65265 .0055 L
.65558 .0047 L
.65796 .00418 L
.66049 .00373 L
.66317 .00338 L
.66437 .00325 L
.66567 .00314 L
.66697 .00304 L
.66816 .00297 L
.66928 .00291 L
.67051 .00286 L
.67155 .00283 L
.67265 .0028 L
.67382 .00278 L
.67492 .00276 L
.67759 .00273 L
.68051 .00271 L
.68184 .0027 L
.68326 .00268 L
.6846 .00267 L
.68581 .00264 L
.68828 .00258 L
.68967 .00254 L
.69094 .00249 L
Mistroke
.69577 .00223 L
.70565 .00146 L
.71108 .00099 L
.71622 .00058 L
.71855 .00043 L
.72101 .0003 L
.72229 .00025 L
.72371 .0002 L
.725 .00017 L
.72621 .00014 L
.72732 .00013 L
.72849 .00013 L
.72949 .00013 L
.73059 .00014 L
.73177 .00016 L
.73303 .0002 L
.73422 .00024 L
.7353 .00028 L
.74019 .00056 L
.74469 .00092 L
.75486 .00194 L
.77331 .00363 L
.78238 .0043 L
.78737 .00473 L
.7921 .00525 L
.79768 .0061 L
.80278 .00719 L
.80755 .00856 L
.81275 .01048 L
.82213 .01524 L
.8325 .02259 L
.84332 .03287 L
.85349 .0456 L
.8633 .06187 L
.87364 .08474 L
.89213 .14199 L
.90238 .17944 L
.91207 .2132 L
.92076 .23766 L
.92314 .24288 L
.92567 .24758 L
.92803 .25115 L
.9302 .25368 L
.93139 .25476 L
.93252 .25557 L
.93371 .25622 L
.93501 .25665 L
.93614 .25681 L
.93735 .25675 L
.93848 .25648 L
Mistroke
.93952 .25605 L
.94084 .25526 L
.94205 .25428 L
.9448 .25124 L
.94722 .24762 L
.94978 .24292 L
.95976 .21711 L
.97071 .17999 L
.97619 .16023 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool8o`0000Gooooo00?o0000ooooooooool01Oooool5o`0000_o
oooo00?o0000ooooooooool01?ooool4o`000003ooooool0003ooooo00[ooooo00?o0000ooooool0
00003_l00007ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`oo00002Oooool00ol0003oooooooooo`02ooooo`[o00002Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo023ooooo000Tooooo`03o`000?oooooooooo01[ooooo
1ol0000=ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool03_ooool3o`0001cooooo
00?o0000ooooooooool0:_ooool4o`0002Kooooo1_l00003ooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool08?ooool003kooooo0ol0001Hooooo`?o00006Oooool00ol0003ooooooooo
o`0Xooooo`;o0000<?ooool4o`0005;ooooo000looooo`;o0000G_ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`1?
ooooo`00>oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool09Oooool2o`0003Sooooo0_l0001?ooooo`00>Oooool2o`0006?ooooo00?o0000oooooooo
ool05?ooool2o`0002Gooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`1<ooooo`00
>?ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo04_ooooo000gooooo`03o`000?oo
oooooooo06Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo03kooooo00?o0000ooooooooool0B_ooool003Kooooo00?o0000ooooooooool0J?ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0@?ooool0
0ol0003oooooooooo`19ooooo`00=Oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo
04Sooooo000dooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0B?ooool003?ooooo
00?o0000ooooooooool0KOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool0A?ooool00ol0003oooooooooo`17ooooo`00<oooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo00oooooo0_l0000Oooooo`03o`000?oooooooooo04Kooooo00?o
0000ooooooooool0A_ooool003;ooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`15
ooooo`00<Oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo04Gooooo000`ooooo`03
o`000?oooooooooo07;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo04[ooooo00?o0000ooooooooool0A?ooool0033ooooo00?o0000ooooooooool0
Loooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
C?ooool00ol0003oooooooooo`13ooooo`00;oooool00ol0003oooooooooo`1dooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1<ooooo`03o`000?oo
oooooooo04?ooooo000_ooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool02oooool2
o`0001cooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`12ooooo`00;_ooool00ol0
003oooooooooo`1fooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`1>ooooo`03o`000?oooooooooo04;ooooo000^ooooo`03o`000?oooooooooo07Oo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04oo
oooo00?o0000ooooooooool0@Oooool002gooooo00?o0000ooooooooool0N?ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0Coooool00ol0003ooooo
ooooo`11ooooo`00;Oooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo043ooooo000/
ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0@?ooool002cooooo00?o0000oooo
ooooool0Noooool00ol0003oooooooooo`08ooooo`;o00006_ooool00ol0003oooooooooo`1Aoooo
o`03o`000?oooooooooo043ooooo000/ooooo`03o`000?oooooooooo07_ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo05?ooooo00?o0000oooooooo
ool0?oooool002_ooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`0oooooo`00:ooo
ool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo03kooooo000[ooooo`03o`000?oooooo
oooo06cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1Eooooo`03o`000?oo
oooooooo03kooooo000Zooooo`03o`000?oooooooooo06gooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1Oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool0EOooool00ol0003oooooooooo`0nooooo`00:_ooool00ol0003oooooooooo`1]
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooo`000007ooooo`?o00005ooo
ool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo03gooooo000Yooooo`03o`000?oooooo
oooo06kooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooo000000Oooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo03gooooo000Y
ooooo`03o`000?oooooooooo06kooooo00Go0000ooooooooooooooooo`00000=ooooo`;o00001ooo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0?Ooo
ool002Wooooo00?o0000ooooooooool0K_ooool01Ol@413ooooooooooooooooo410@00gooooo0_l0
0007ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0F?ooool00ol0003ooooooooo
o`0looooo`00:?ooool00ol0003oooooooooo`1_ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03Ooo
ool2o`0000Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1Hooooo`03o`000?oo
oooooooo03cooooo000Xooooo`03o`000?oooooooooo06oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`03oeEEEOl0003o000000Oooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`1Iooooo`03o`000?oooooooooo03cooooo000Xooooo`03o`000?oooooooooo08;ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo05[ooooo00?o0000
ooooooooool0>oooool002Oooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`05oooo
o`;o00005_ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo03_ooooo000Wooooo`03
o`000?oooooooooo08?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo05[ooooo00?o0000ooooooooool0>oooool002Oooooo00?o0000ooooooooool0
Poooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
G?ooool00ol0003oooooooooo`0jooooo`009oooool00ol0003oooooooooo`24ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Looooo`03o`000?oo
oooooooo03[ooooo000Vooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0>_ooool0
02Kooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`0iooooo`009_ooool00ol0003o
ooooooooo`25ooooo`03o`000?oooooooooo00Cooooo0_l0000Dooooo`03o`000?oooooooooo05ko
oooo00?o0000ooooooooool0>Oooool002Gooooo00?o0000ooooooooool0Q_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0G_ooool00ol0003ooooo
ooooo`0iooooo`009Oooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo03Sooooo000U
ooooo`03o`000?oooooooooo08Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0>?ooool002Cooooo00?o0000oooo
ooooool0R?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0Goooool00ol0003oooooooooo`0hooooo`009?ooool00ol0003oooooooooo`28ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Pooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool08?ooool00:oooooo00?o0000ooooooooool0
0oooool2o`0001?ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo023ooooo002`ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool08?oo
ool00;3ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo067ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Pooooo`00/?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0HOooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo027ooooo002`ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool08Oooool00;3ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Qooooo`00/?ooool00ol0003oooooooooo`02ooooo`;o00004_ooool00ol0003ooooooooo
o`1Sooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool08Oooool00;7ooooo00Go0000
ooooooooooooooooo`00000Cooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Rooooo`00/Oooool01Ol0003ooooooooooooooooo000001?ooooo00?o
0000ooooooooool0I?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02;ooooo002a
ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`1Uooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool08_ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000;ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`00
0?oooooooooo06Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Sooooo`00V_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@00_ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool0I_ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo02?ooooo002Jooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000004_ooool0
0ol0003oooooooooo`1Vooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool08oooool0
09[ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00?o0000
ooooooooool00ol0000@ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0Tooooo`00V_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMg
ofIVI_ooool00_ooool01?l0003oooooooooool0000Aooooo`03o`000?oooooooooo06Sooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Tooooo`00V_ooool01Ol@413ooooooooooooo
oooo410@00oooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0J?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Cooooo
002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00?o
oooo00Co0000oooooooooooo00004Oooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool09Oooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01?l0003oooooooooool0000Aooooo`03o`000?oo
oooooooo06Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Uooooo`00/oooool0
0ol0003oooooo`00000Aooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Vooooo`00/oooool01?l0003oooooo`000?l0000?ooooo`03o`000?oooooo
oooo06_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Vooooo`00/oooool00ol0
003oooooo`00000@ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Vooooo`00/oooool00ol0003oooooo`00000@ooooo`03o`000?oooooooooo06_o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Wooooo`00/oooool00ol0003ooooo
o`00000@ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Wooooo`00/oooool00ol0003oooooo`00000@ooooo`03o`000?oooooooooo06cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Wooooo`00]?ooool2o`0000oooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Sooooo002doooo
o`?o00003_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0:?ooool00;Cooooo0_l0000?ooooo`03o`000?oooooooooo06oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Yooooo`00]?ooool2o`0000oooooo00?o0000ooooooooool0
Koooool2o`0000;ooooo00?o0000ooooooooool0:_ooool00;Cooooo0_l0000?ooooo`03o`000?oo
oooooooo073ooooo1?l0000/ooooo`00]Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo0:7ooooo002eooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0XOooool00;Go
oooo0_l0000=ooooo`03o`000?oooooooooo0:7ooooo002eooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0XOooool00;Gooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`2Qooooo`00]Oooool2o`0000cooooo00?o0000ooooooooool0X_ooool00;Gooooo0_l0000<oooo
o`03o`000?oooooooooo0:;ooooo002eooooo`;o00003?ooool00ol0003oooooooooo`2Rooooo`00
]Oooool2o`0000cooooo00?o0000ooooooooool0X_ooool00;Gooooo0_l0000<ooooo`03o`000?oo
oooooooo0:;ooooo002eooooo`03o`000?oooooo000000_ooooo00?o0000ooooooooool0X_ooool0
0;Gooooo00?o0000ooooool000002oooool00ol0003oooooooooo`2Rooooo`00V_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05oiRHV?l@413o0000oc8b<_o<c<`01_ooool0
0ol0003oooooo`00000:ooooo`03o`000?oooooooooo0:?ooooo002Jooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oo
oooo000000[ooooo00?o0000ooooooooool0Xoooool009[ooooo00Go410@oooooooooooooooooa0@
400?ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00002Oooool00ol0003ooooo
ooooo`2Sooooo`00V_ooool01Ol0003ooooooooooooooooo000000kooooo00?oZJVYoa0@4?ooool0
1Oooool4o`0000Wooooo00?o0000ooooooooool0Xoooool009[ooooo00Go0000oooooooooooooooo
o`00000=ooooo`03oa0@4?l0003o^[Zj00Kooooo00Co0000oooooooooooo00002Oooool00ol0003o
ooooooooo`2Sooooo`00V_ooool01Ol@413ooooooooooooooooo410@00kooooo00?o^[Zjob4Q8Ooo
ool01Oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool0Y?ooool009[o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool0
1Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool0Y?ooool009[ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool0YOooool00;Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0:Gooooo002eooooo`;o00000ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0:Gooooo002eooooo`03o`000?oooooo
oooo00?ooooo00Go0000ooooooooooooooooo`00002Xooooo`00]Oooool00ol0003oooooooooo`03
ooooo`05o`000?ooooooooooooooool00000Z?ooool00;Gooooo00?o0000ooooooooool01?ooool3
o`000:Wooooo002eooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Z?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0/?oo
ool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0000Kooooo0ol0002`ooooo`00V_ooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00001oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`2`ooooo`00
V_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003o
ooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l0
00001oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00go
oooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o
0000ooooooooool00oooool3o`000;3ooooo002Jooooo`05o`000?ooooooooooooooool000003ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
/?ooool009[ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo002/ooooo`03o`000?nj^[[ooooo0;Wooooo002/ooooo`;o<S8b^_ooool007gooooo
0_l000001_l@413oooooooooool@413o0000oa0@41Sooooo1?l000001Ol@413ooooooooooooooooo
A4A400;o000000Oo<S8bomgMgOooooooooooohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003o
A4A4okZj^P0Hooooo`05oiRHV?l@413o0000oc8b<_o<c<`01Oooool2o`000009oa0@4?oooooooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1cooooo`00
O_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l0000<ooooo`03o`00
0?oooooooooo00Kooooo00OoMgMgoc8b<_ooooooooooolc<c?l0003o410@00cooooo00Go410@okZj
^_o^k^koMgMgoa0@4009ooooo`Ko00002Oooool01Ol@413o^[ZjoooooomgMgOo<S8b00Kooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`1cooooo`00O_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01kooooo
00Co0000oooooooooooooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@07?ooooo001nooooo`06o`000?ooooooA4A4odA4A?oooooo00002Ooo
ool6o`0000cooooo00?o0000ooooooooool01_ooool00omgMgOo<S8booooo`0@ooooo`03o`000?oo
oooooooo00_ooooo1_l0000<ooooo`03ojVYZOl@413ooooo00;ooooo00CoA4A4omgMgOoooooo0000
1?ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00001coooo
o`00O_ooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001_ooooo00?o0000ooooooooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<017ooooo00?o0000ooooooooool07?ooool00ol@413o0000okZj
^P03ooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool00000Loooool007kooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000K
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol@413o0000o`000003
o`0001cooooo00?o^[Zjob4Q8Oooool00oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooo
ooooooooool@41000oooool01Ol@413ooooooooooooooooo410@07?ooooo001nooooo`06o`000?lb
<S;ooooooooooolb<S;o00006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool06_ooool01Ol@413oV9RHoooooonj^[[o000000Cooooo00?ok^k^odA4
A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`1cooooo`00OOooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo00?oEEEE
ofIVI_l000001Oooool4o`0001;ooooo00?o0000ooooooooool06_ooool01OnYZJWo410@o`000?l@
413oZJVY00Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP1cooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3500) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .20631 m
.02846 .22172 L
.03279 .23426 L
.03754 .24534 L
.0402 .25011 L
.04262 .25348 L
.04385 .25482 L
.04516 .25597 L
.04627 .25672 L
.0475 .25729 L
.04882 .25762 L
.04957 .25767 L
.05024 .25764 L
.05156 .25735 L
.05281 .25681 L
.05397 .25608 L
.0552 .25506 L
.05742 .25262 L
.06005 .24876 L
.06244 .24441 L
.07287 .21788 L
.08414 .18078 L
.10458 .11199 L
.11489 .08247 L
.12452 .05989 L
.13456 .04219 L
.13988 .03521 L
.14558 .02936 L
.15087 .02518 L
.15576 .0221 L
.16682 .01655 L
.1772 .01167 L
.18694 .00708 L
.19132 .00524 L
.19593 .00358 L
.19834 .00288 L
.20098 .00224 L
.20338 .0018 L
.20561 .0015 L
.2069 .00137 L
.20762 .00132 L
.20829 .00128 L
.20952 .00123 L
.21083 .00121 L
.21199 .00122 L
.21309 .00124 L
.21428 .00129 L
.21557 .00137 L
.21842 .00161 L
.22113 .00189 L
Mistroke
.22621 .00245 L
.22881 .0027 L
.23008 .00281 L
.23125 .00289 L
.2323 .00295 L
.23345 .003 L
.2346 .00304 L
.23582 .00305 L
.23651 .00305 L
.23716 .00305 L
.23838 .00302 L
.23969 .00297 L
.24043 .00293 L
.24112 .00288 L
.24351 .00267 L
.24606 .00237 L
.25566 .00073 L
Mfstroke
.25566 .00073 m
.25968 0 L
s
.29243 0 m
.29266 3e-05 L
.29728 .00052 L
.29987 .00074 L
.30226 .0009 L
.30341 .00095 L
.30468 .001 L
.306 .00103 L
.30723 .00105 L
.30841 .00105 L
.30948 .00103 L
.31072 .00101 L
.3119 .00097 L
.31314 .00092 L
.31445 .00085 L
.31681 .00069 L
.32214 .00026 L
s
.32214 .00026 m
.32512 0 L
s
.36022 0 m
.36246 .00013 L
.36502 .00025 L
.36728 .00034 L
.36852 .00039 L
.36968 .00042 L
.37081 .00045 L
.37184 .00047 L
.37298 .00049 L
.37422 .0005 L
.37519 .0005 L
.37626 .0005 L
.37737 .0005 L
.37841 .00049 L
.37969 .00048 L
.38104 .00046 L
.38347 .0004 L
.38894 .00025 L
.39408 8e-05 L
s
.39408 8e-05 m
.39715 0 L
s
.42113 0 m
.42246 4e-05 L
.42699 .00021 L
.43187 .00045 L
.43717 .00077 L
.45552 .00231 L
.46576 .00324 L
.47535 .00414 L
.48017 .0047 L
.48535 .0055 L
.4883 .00611 L
.49111 .00681 L
.49637 .00854 L
.5014 .0108 L
.50595 .01345 L
.51617 .02168 L
.52564 .03238 L
.53455 .04568 L
.54431 .06525 L
.55462 .09438 L
.56343 .12822 L
.57309 .17514 L
.58394 .23532 L
.59423 .28959 L
.5987 .30909 L
.60346 .32547 L
.60594 .33191 L
.60726 .3347 L
.60868 .33718 L
.60998 .33897 L
.61117 .3402 L
.61231 .34101 L
.6135 .34146 L
.61476 .3415 L
.61594 .34113 L
.617 .34047 L
.61816 .33939 L
.61941 .3378 L
.62074 .33564 L
.62313 .33063 L
.62739 .31819 L
.63208 .30002 L
.6524 .19374 L
.66237 .14307 L
.67184 .10354 L
.67706 .0858 L
.68275 .06955 L
.69273 .04774 L
.69805 .03894 L
.70307 .03209 L
Mistroke
.71243 .02229 L
.71769 .01815 L
.72252 .01501 L
.73341 .0097 L
.74317 .00633 L
.75227 .00401 L
.75749 .00302 L
.76225 .00235 L
.76488 .00207 L
.76627 .00195 L
.76774 .00184 L
.76903 .00177 L
.77044 .0017 L
.77173 .00165 L
.77294 .00162 L
.77412 .0016 L
.77538 .00158 L
.77657 .00158 L
.77765 .00159 L
.77892 .0016 L
.77964 .00161 L
.7803 .00162 L
.78279 .00167 L
.78773 .00179 L
.78908 .00181 L
.79053 .00184 L
.79124 .00185 L
.7919 .00186 L
.79315 .00187 L
.79424 .00187 L
.79539 .00187 L
.79637 .00187 L
.79746 .00185 L
.79862 .00184 L
.79988 .00181 L
.80215 .00174 L
.80457 .00164 L
.80711 .00152 L
.81167 .00127 L
.81423 .00114 L
.81666 .00103 L
.81771 .00099 L
.81883 .00096 L
.82006 .00093 L
.82119 .00092 L
.8224 .00091 L
.82369 .00092 L
.82492 .00094 L
.82604 .00097 L
.82735 .00102 L
Mistroke
.82878 .0011 L
.83138 .0013 L
.83379 .00156 L
.83598 .00184 L
.8409 .00262 L
.84973 .00438 L
.85988 .00646 L
.87061 .00853 L
.87502 .0095 L
.87976 .0108 L
.88496 .01272 L
.88981 .01512 L
.89477 .01833 L
.90017 .02276 L
.90998 .03336 L
.92836 .06156 L
.93777 .08093 L
.94814 .10793 L
.96915 .18069 L
.97619 .20631 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01;o
00000oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo2Ol00006ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo01Ko00000oooool9o`0000_ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo023ooooo000Tooooo`03o`000?oooooooooo02kooooo
0ol0000]ooooo`03o`000?oooooooooo02Oooooo1Ol000000ooooooo0000ooooo`0^ooooo`03o`00
0?oooooooooo01Kooooo0_l0000Eooooo`03o`000?oooooooooo00[ooooo0ol0000Pooooo`03o`00
0?oooooooooo023ooooo001Dooooo`03o`000?oooooooooo05gooooo0ol00014ooooo`?o00009ooo
ool5o`0003kooooo001Booooo`;o0000HOooool00ol0003oooooo`000011ooooo`;o0000;oooool0
0ol0003oooooooooo`0kooooo`00Coooool3o`0006?ooooo00Co0000oooooooooooo0000?oooool0
0ol0003oooooooooo`0`ooooo`;o0000>oooool004gooooo0_l0001Vooooo`;o00000_ooool00ol0
003oooooooooo`0jooooo`;o0000=Oooool00ol0003oooooooooo`0hooooo`00C?ooool00ol0003o
ooooooooo`1Vooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo03Oooooo001:ooooo`;o0000JOooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0>?ooool00ol0003ooooo
ooooo`0fooooo`00BOooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Gooooo0019
ooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0b
ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0=?ooool004Sooooo00?o0000oooo
ooooool0J_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03;ooooo00?o0000oooo
ooooool0??ooool00ol0003oooooooooo`0dooooo`00Aoooool00ol0003oooooooooo`1[ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0nooooo`03
o`000?oooooooooo03?ooooo0016ooooo`03o`000?oooooooooo06cooooo0_l00007ooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0booooo`00A_oo
ool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo03;ooooo0015ooooo`03o`000?oooooo
oooo06gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo04;ooooo00?o0000ooooooooool0<Oooool004Cooooo00?o0000ooooooooool0K_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0@oooool00ol0
003oooooooooo`0`ooooo`00A?ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo033o
oooo0013ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0;oooool004?ooooo00?o
0000ooooooooool0Koooool2o`0000[ooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`17ooooo`03o`000?oooooooooo02kooooo0012ooooo`03o`000?oooooooooo073ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo04Oooooo00?o0000
ooooooooool0;_ooool004;ooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0]oooo
o`00@Oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo02gooooo0011ooooo`03o`00
0?oooooooooo077ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo04[ooooo00?o0000ooooooooool0;?ooool0047ooooo00?o0000ooooooooool0LOoo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0Booo
ool00ol0003oooooooooo`0/ooooo`00@?ooool00ol0003oooooooooo`1booooo`;o00003Oooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0:oooool0
043ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0[ooooo`00?oooool00ol0003o
ooooooooo`1cooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`1=ooooo`03o`000?oooooooooo02[ooooo000oooooo`03o`000?oooooooooo07?ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo04kooooo
00?o0000ooooooooool0:_ooool003oooooo00?o0000ooooooooool0F?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000?o410@ooooooooool00oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0C_ooool00ol0003ooooo
ooooo`0Zooooo`00?_ooool00ol0003oooooooooo`1Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Yooooo`00?_oo
ool00ol0003oooooooooo`1Iooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003ooooo
ooooo`05ooooo`?o00003Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo053ooooo
00?o0000ooooooooool0:Oooool003kooooo00?o0000ooooooooool0FOooool01Ol0003ooooooooo
oooooooo000000kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Yooooo`00?Ooo
ool00ol0003oooooooooo`1Jooooo`05o`000?ooooooooooooooool000003_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`1Aooooo`03o`000?oooooooooo02Sooooo000mooooo`03o`000?oooooooooo05[ooooo00Go
410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0
:?ooool003gooooo00?o0000ooooooooool0F_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0Xooooo`00?Oooool00ol0003ooooooooo
o`1Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`000007ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Cooooo`03o`00
0?oooooooooo02Oooooo000looooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool09ooo
ool003cooooo00?o0000ooooooooool0M_ooool2o`00017ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`1Cooooo`03o`000?oooooooooo02Oooooo000looooo`03o`000?oooooooooo
07Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
05Gooooo00?o0000ooooooooool09_ooool003_ooooo00?o0000ooooooooool0Moooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0EOooool00ol0003o
ooooooooo`0Vooooo`00>oooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo02Kooooo
000kooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool09_ooool003_ooooo00?o0000
ooooooooool0Moooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool0Eoooool00ol0003oooooooooo`0Uooooo`00>_ooool00ol0003oooooooooo`1hoooo
o`;o00004_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05Oooooo00?o0000oooo
ooooool09Oooool003[ooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0Uooooo`00
>_ooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo02Gooooo000iooooo`03o`000?oo
oooooooo07Wooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo05Wooooo00?o0000ooooooooool09?ooool003Wooooo00?o0000ooooooooool0NOooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0FOooool0
0ol0003oooooooooo`0Tooooo`00>Oooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo
02Cooooo000iooooo`03o`000?oooooooooo07Wooooo0_l0000Cooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0Sooooo`00>?ooool00ol0003ooooo
ooooo`1jooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`1Jooooo`03o`000?oooooooooo02?ooooo000hooooo`03o`000?oooooooooo07[ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo05_ooooo00?o
0000ooooooooool08oooool003Sooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0S
ooooo`00=oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo02;ooooo000gooooo`03
o`000?oooooooooo07_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo05cooooo00?o0000ooooooooool08_ooool003Oooooo00?o0000ooooooooool0
Noooool2o`0001Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1Looooo`03o`00
0?oooooooooo02;ooooo000fooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool08_oo
ool003Kooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0Qooooo`00=_ooool00ol0
003oooooooooo`1looooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`1Nooooo`03o`000?oooooooooo027ooooo000eooooo`03o`000?oooooooooo06;o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05kooooo00?o0000oooo
ooooool08Oooool003Gooooo00?o0000ooooooooool0H_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0Q
ooooo`00=Oooool00ol0003oooooooooo`1Rooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`1Oooooo`03o`000?oooooooooo023ooooo000Tooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool0Hoooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h01_ooool3o`0001Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1P
ooooo`03o`000?oooooooooo023ooooo000Tooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool0Hoooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Poooool0
02Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Sooooo`05oa0@4?oooooooooo
ooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`23ooooo`009Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo06Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool0Poooool002Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1T
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo08?ooooo
000Vooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0P?ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0Q?ooool002Kooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`20ooooo`;o00005_ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo08Cooooo000Wooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0P?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0Q?ooool002Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`21ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`24ooooo`00
9oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Cooooo000Xooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0QOooool002Sooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`22ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`25ooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
08;ooooo0_l0000Gooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0QOooool002Wo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`25ooooo`00:_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo08Gooooo000[ooooo`Co0000Q_ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0QOooool00;Gooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08Kooooo002eoooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`26oooo
o`00]Oooool2o`0001Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`26ooooo`00
]Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
Q_ooool00;Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo08Kooooo002eooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`27ooooo`00]Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0Qoooool00;Gooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo08Oooooo002eooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`27ooooo`00]Oooool2o`0001[ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`27ooooo`00]Oooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0R?ooool00;Gooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo08Sooooo002Jooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c006
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`28
ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[o
ooooogMgMolb<S801_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0R?ooool009[ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo08Sooooo002Jooooo`05o`000?ooooooooooooooool000003_ooool00onYZJWo410@oooo
o`05ooooo`?o00006oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo08Sooooo002J
ooooo`05o`000?ooooooooooooooool000003Oooool00ol@413o0000okZj^P06ooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`29ooooo`00V_ooool0
1Ol@413ooooooooooooooooo410@00kooooo00?o^[Zjob4Q8Oooool01Oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ROooool009[ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0ROooool009[ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0ROooool00;Gooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08[ooooo
002eooooo`;o00007Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08_ooooo002e
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2;
ooooo`00]Oooool00ol0003oooooooooo`0Mooooo`;o00000oooool00ol0003oooooooooo`2;oooo
o`00]Oooool00ol0003oooooooooo`0Nooooo`Co0000S_ooool00;Gooooo00?o0000ooooooooool0
7oooool2o`0008oooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04oooo
o`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413o
oooooooooooooooo410@00_ooooo1Ol00006ooooo`?o0000/?ooool009[ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0/?ooool0
09[ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o
0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<
c<co000000Oooooo00?o0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooo
oooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0002`ooooo`00V_ooool01Ol0003o
oooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`oooo
o`00V_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Joooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool00ol0003o^[Zjooooo`2iooooo`00[?oo
ool2oc8b<[[ooooo001mooooo`;o000000Ko410@oooooooooooo410@o`000?l@410Hooooo`Co0000
00Go410@ooooooooooooooooodA4A002o`000007oc8b<_oMgMgooooooooooon7QhOo0000okZj^P0<
ooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool01OnHV9So410@o`000?lb<S;oc<c<00Cooooo
00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^07?ooooo001nooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01oooool6o`0000cooooo00?o0000ooooooooool01_ooool01omgMgOo<S8boooooooooooo
c<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00009ooooo`05oa0@
4?nj^[[oooooogMgMolb<S801oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Loooool007kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo410@
0oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0LOooool007kooooo
00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00003?ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo013ooooo00?o0000ooooooooool02oooool6o`0000cooooo00?oZJVYoa0@
4?ooool01_ooool01OmgMgOo<S8boooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo077ooooo001nooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo0000
6oooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`04Oooool00ol0003o
ooooooooo`0Looooo`03oa0@4?l0003o^[Zj00Cooooo00Go0000ob4Q8Ol0003o<S8bolc<c002oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000007?ooooo001n
ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo00006oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo017ooooo00?o410@o`000?l000000ol0000Looooo`03okZj^_lQ8B7ooooo00?ooooo
00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooooooooa0@401cooooo`00O_ooool01_l0003o<S8boooooooooooo<S8bo`0001_ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01[ooooo00Go410@
oiRHV?oooooo^[Zjo`000004ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Loooool007gooooo00?o410@o`000?n7QhL0
0_ooool00on7QhOo0000oa0@400Hooooo`03oeEEEOmVIVKo000000Gooooo1?l0000Booooo`03o`00
0?oooooooooo01[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@04ooooo`Co00000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1cooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3600) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .03198 m
.03279 .04342 L
.04262 .06076 L
.05288 .08458 L
.06244 .11181 L
.08451 .1867 L
.09413 .21822 L
.0992 .23238 L
.10458 .24449 L
.10697 .24871 L
.10954 .25235 L
.11101 .254 L
.11236 .25521 L
.11301 .25569 L
.11371 .25614 L
.115 .25674 L
.11627 .25708 L
.11742 .25715 L
.11805 .25709 L
.11874 .25696 L
.11999 .25651 L
.12117 .25585 L
.1224 .25491 L
.12462 .25259 L
.12688 .24943 L
.1293 .24518 L
.13366 .23541 L
.14357 .20521 L
.16338 .13319 L
.17383 .10035 L
.18493 .07303 L
.19477 .05453 L
.20563 .03855 L
.21496 .02761 L
.22478 .01868 L
.2296 .0153 L
.23487 .01236 L
.23967 .01031 L
.24413 .00888 L
.24941 .00763 L
.25421 .00679 L
.26498 .00529 L
.27509 .00376 L
.28578 .00197 L
.29019 .00131 L
.29492 .00072 L
.29763 .00047 L
.30011 .00029 L
.3013 .00022 L
.3026 .00016 L
Mistroke
.30383 .00012 L
.30496 9e-05 L
.30623 8e-05 L
.30739 7e-05 L
.30866 8e-05 L
.3093 8e-05 L
.31 9e-05 L
.31119 .00012 L
.31245 .00016 L
.31474 .00024 L
.3236 .00068 L
.32615 .0008 L
.3275 .00086 L
.32893 .00091 L
.33018 .00095 L
.33155 .00098 L
.3328 .001 L
.33398 .00102 L
.33514 .00102 L
.33635 .00102 L
.33739 .00101 L
.33853 .00099 L
.33976 .00097 L
.34107 .00093 L
.34343 .00084 L
.34878 .00056 L
.3537 .00025 L
Mfstroke
.3537 .00025 m
.35762 0 L
s
.38653 0 m
.38988 .00018 L
.39451 .00041 L
.39707 .00051 L
.39842 .00056 L
.39985 .0006 L
.40105 .00062 L
.40237 .00064 L
.40357 .00065 L
.4047 .00065 L
.40583 .00065 L
.40707 .00063 L
.40824 .00061 L
.40932 .00059 L
.41136 .00052 L
.41354 .00043 L
.41853 .00014 L
s
.41853 .00014 m
.42065 0 L
s
.45997 0 m
.46314 .00025 L
.46806 .00062 L
.47047 .00077 L
.4727 .00088 L
.47394 .00092 L
.47526 .00096 L
.47595 .00098 L
.47659 .00099 L
.47729 .001 L
.47804 .001 L
.47935 .001 L
.48058 .00099 L
.48169 .00097 L
.4829 .00094 L
.48415 .00089 L
.48532 .00084 L
.48752 .00073 L
.49243 .00038 L
s
.49243 .00038 m
.49735 0 L
s
.52297 0 m
.52594 .00034 L
.53088 .00104 L
.53989 .0024 L
.54516 .00307 L
.54794 .00336 L
.55086 .00361 L
.55625 .00395 L
.5612 .00419 L
.5635 .00431 L
.56597 .00447 L
.56829 .00467 L
.57041 .00489 L
.5729 .00524 L
.57561 .00574 L
.57816 .00635 L
.58053 .00704 L
.58518 .00882 L
.58954 .01103 L
.59949 .01806 L
.60919 .02752 L
.61964 .04092 L
.62921 .05759 L
.63463 .06992 L
.63968 .08385 L
.64987 .12069 L
.66077 .17301 L
.68068 .28144 L
.68613 .30591 L
.68911 .31703 L
.6919 .3257 L
.69428 .33163 L
.69683 .33642 L
.69829 .33837 L
.699 .33913 L
.69967 .3397 L
.70091 .34046 L
.70156 .34069 L
.70226 .3408 L
.70357 .34065 L
.70424 .34039 L
.70496 .33997 L
.70625 .33888 L
.70745 .33746 L
.70887 .33529 L
.71016 .33286 L
.71306 .32589 L
.71829 .3085 L
.72323 .28725 L
.74223 .18539 L
Mistroke
.7519 .13635 L
.76217 .0946 L
.77093 .06835 L
.77592 .05686 L
.7806 .04797 L
.79045 .03375 L
.80081 .02305 L
.80966 .01597 L
.81932 .00992 L
.82462 .00737 L
.82962 .00549 L
.83411 .00424 L
.83663 .00371 L
.83896 .00334 L
.84017 .00318 L
.84147 .00304 L
.8426 .00294 L
.84382 .00285 L
.84456 .00281 L
.84525 .00278 L
.84589 .00275 L
.84661 .00273 L
.84784 .00271 L
.84915 .0027 L
.84983 .0027 L
.85054 .00271 L
.85182 .00273 L
.85253 .00275 L
.8532 .00276 L
.8547 .00281 L
.85993 .00303 L
.86237 .00312 L
.86371 .00316 L
.86496 .0032 L
.86631 .00322 L
.86703 .00323 L
.8678 .00324 L
.8685 .00325 L
.86917 .00325 L
.87042 .00324 L
.87162 .00322 L
.87289 .00319 L
.87408 .00315 L
.87517 .00311 L
.87784 .00296 L
.88035 .00279 L
.88921 .00199 L
.8939 .00159 L
.89525 .0015 L
.89653 .00143 L
Mistroke
.89769 .00137 L
.89893 .00133 L
.90018 .0013 L
.90135 .00129 L
.9026 .0013 L
.90331 .00131 L
.90398 .00133 L
.90516 .00138 L
.90625 .00144 L
.90744 .00153 L
.90869 .00164 L
.91125 .00195 L
.91362 .00233 L
.91901 .00349 L
.92794 .00617 L
.93748 .00966 L
.94704 .01342 L
.9574 .01806 L
.96215 .02067 L
.96718 .02398 L
.97619 .03198 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06o`0000?ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo2?l00004ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00;ooooo7Ol00002ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool08?ooool002Cooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0@ooooo`So0000
5Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo017ooooo1_l0000Fooooo`03o`00
0?oooooooooo02gooooo00?o0000ooooool000000_l0000Mooooo`?o00002oooool00ol0003ooooo
ooooo`0Pooooo`00IOooool3o`0004gooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`13ooooo`;o00008oooool3o`0002_ooooo001Tooooo`03o`000?oooooooooo04kooooo00?o0000
ooooooooool06?ooool2o`0004;ooooo00?o0000ooooooooool09_ooool2o`0002Wooooo001Roooo
o`;o0000DOooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03gooooo0_l0000[oooo
o`03o`000?oooooooooo02Kooooo001Qooooo`03o`000?oooooooooo057ooooo0_l0000Looooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0;?ooool3o`0002Gooooo001Pooooo`03o`00
0?oooooooooo05;ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0iooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool08_ooool005oooooo00?o0000ooooooooool0Dooo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`0Rooooo`00G_ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo027ooooo000Tooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0E?ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`0Pooooo`009Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo05Go
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo05So
oooo000Vooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0E_ooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0FOooool002Oooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`1Fooooo`;o00008_ooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo05[ooooo000Wooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool0Eoooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool0F_ooool002Sooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Hoooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Koooo
o`00:?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo05Wooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo05_ooooo000Yooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool0G?ooool002Wooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`1Looooo`00:_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo05_ooooo0_l0000Uooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0GOooool0
02[ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1Mooooo`00:oooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo05kooooo000[ooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool0GOooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool0G_ooool002cooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`1Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1Oooooo`00;?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05kooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo05oooooo000/oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0G_ooool2o`0002Sooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`1Oooooo`00;Oooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo05kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo063ooooo000]ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
Goooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
H?ooool002kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1Oooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Pooooo`00;_ooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo04Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo067ooooo000^ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool0AOooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo067ooooo000_ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool0AOooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01Ooo
ool3o`0002Sooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1Qooooo`00;oooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo04Gooooo00Go0000ooooooooooooooooo`00
000>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo06;ooooo000_ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool0AOooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0H_oo
ool0033ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`16ooooo`05oa0@4?oooooo
ooooooooool@41003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`1Rooooo`00<?ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo04Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo06;ooooo000`ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0A_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001oooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0Hoooool0037ooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`1Sooooo`00<Oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo06;ooooo0_l0000[ooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool0Hoooool0037ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Rooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Sooooo`00
<_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0
:oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo06?ooooo000booooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool0I?ooool003;ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`1Sooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`1Tooooo`00<oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
06?ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
06Cooooo000cooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0I?ooool2o`0002go
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Tooooo`00<oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo06Gooooo000dooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool0I?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool0IOooool003Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1U
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1U
ooooo`00=?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo06Gooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo06Gooooo000dooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool0IOooool003Gooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`1Uooooo`;o0000;_ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo06Kooooo000eooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0I_oo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0I_oo
ool003Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1Vooooo`00=_ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo06Kooooo000fooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool0I_ooool003Kooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`1Wooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`1Wooooo`00=oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06Oooooo0_l0
000_ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0Ioooool003Oooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`1Wooooo`00=oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo06Oooooo000hooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0J?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0Ioooool003Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1=ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1Xooooo`00>?ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo04kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo06Sooooo000iooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0C_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q
8Oo^k^h01oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool0J?ooool003Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1>ooooo`05
o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`?o0000<?ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo06Sooooo000iooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0C_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool01Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool0J?ooool003[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1?ooooo`05
oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Xooooo`00>_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo04oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool0JOooool003[ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`1?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<00Kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo06Wooooo000jooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Joooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0JOooool0
03_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1[ooooo`;o0000<_ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo06Wooooo000kooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool0JOooool003_ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`1/ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`1Yooooo`00>oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06cooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo06[ooooo000l
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0b
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0J_ooool003gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo03;ooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`1Zooooo`00?Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo06kooooo0_l0000cooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0J_ooool003kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1^ooooo`03o`00
0?oooooooooo03;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1Zooooo`00?_oo
ool2o`0000?ooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0J_ooool003oooooo1?l0001booooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1Zooooo`00]Oooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Joooool00;Go
oooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo06_o
oooo002eooooo`;o0000=?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo06_ooooo
002eooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`1[ooooo`00]Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool0Joooool00;Gooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo06_ooooo002eooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`1/ooooo`00]Oooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0K?ooool00;Gooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo06cooooo002eooooo`;o0000=Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo06cooooo002eooooo`03o`000?oooooooooo
03Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1/ooooo`00]Oooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0KOooool009[ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<
00Kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
06gooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go410@okZj
^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`1]ooooo`00V_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0K_ooool009[ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ojVYZOl@413o
oooo00Gooooo0ol0000eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0K_ooool0
09[ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oa0@4?l0003o^[Zj00Kooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06kooooo002Joooo
o`05oa0@4?ooooooooooooooool@41003_ooool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1^ooooo`00V_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1_ooooo`00V_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1_ooooo`00]Ooo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Kooo
ool00;Gooooo0_l0000hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Koooool0
0;Gooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
073ooooo002eooooo`03o`000?oooooooooo03Wooooo00Co0000oooooooooooo0000Loooool00;Go
oooo00?o0000ooooooooool0>Oooool4o`0007?ooooo002eooooo`03o`000?oooooooooo03[ooooo
0_l0001dooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0
003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go00001_ooool3o`000;3ooooo002Jooooo`05o`000?oooooooooooooo
ool000002oooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo0;3ooooo002Joooo
o`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oo
oooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00
0007ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol0003oooooooooo`03ooooo`?o0000/?ooool009[ooooo00Go0000oooooooo
ooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009[o
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00:cooooo00?o0000okZj^_ooool0^Oooool00:cooooo0_lb
<S:jooooo`00OOooool2o`000006oa0@4?oooooooooooa0@4?l0003o410@6?ooool4o`000005oa0@
4?oooooooooooooooom4A4@00_l000001olb<S;ogMgMooooooooooooQhN7o`000?nj^[X03?ooool0
1OnHV9So0000o`000?m4A4Co^[Zj01Sooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^
k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1cooooo`00O_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Oooooo1_l0000<ooooo`03o`000?oooooooooo00Kooooo00OoMgMgoc8b<_ooooooooooolc<c?l0
003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002Oooool01Ol@413o^[Zj
oooooomgMgOo<S8b00?ooooo00GoEEEEogMgMoooooooV9RHob4Q8@03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg07?ooooo001nooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool07_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`1aooooo`00O_ooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000<oooo
o`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool04?ooool00ol0003oooooooooo`0;oooo
o`Ko00003?ooool00onYZJWo410@ooooo`02ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00001cooooo`00O_oo
ool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001_ooooo00?o0000ooooooooool00oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<017ooooo00?o0000ooooooooool07?ooool00ol@413o0000okZj^P03oooo
o`05o`000?mEEEGo0000oa0@4?o<c<`00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`00001cooooo`00O_ooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001_o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03oa0@4?l0003o000000?o
00007?ooool00onj^[[o8B4Qooooo`02ooooo`03oeEEEOn7QhOooooo00Gooooo00Go410@oooooooo
oooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100Loooool007kooooo00Ko0000oc8b
<_oooooooooooc8b<_l0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0Jooooo`05oa0@4?nHV9SooooookZj^_l000000oooool00ooMgMgo410@
oiRHV005ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
07?ooooo001mooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool00omEEEGo
IVIVo`000005ooooo`Co00004_ooool00ol0003oooooooooo`0Jooooo`05ojVYZOl@413o0000oa0@
4?nYZJT01?ooool01?o<c<coA4A4o`000?l@4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^07?ooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3700) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .00544 m
.02605 .00573 L
.02846 .00598 L
.03053 .00616 L
.03279 .00632 L
.03543 .00646 L
.03793 .00657 L
.04262 .00678 L
.045 .00693 L
.04762 .00716 L
.04894 .00732 L
.05036 .00751 L
.05293 .00797 L
.05547 .00856 L
.0579 .00928 L
.06244 .01108 L
.0675 .01382 L
.07289 .01758 L
.08259 .02632 L
.09315 .03825 L
.10458 .05434 L
.11573 .07537 L
.12599 .10161 L
.14616 .17125 L
.15525 .20414 L
.16499 .23354 L
.16786 .24029 L
.17058 .2457 L
.17322 .24997 L
.17567 .25299 L
.17687 .25414 L
.17799 .25501 L
.17916 .25572 L
.18045 .25624 L
.18176 .25651 L
.18295 .25651 L
.18427 .25626 L
.18493 .25603 L
.18565 .2557 L
.18697 .25489 L
.18819 .25391 L
.19093 .25088 L
.19336 .2473 L
.19592 .24264 L
.20526 .21911 L
.22621 .14601 L
.23637 .11129 L
.24601 .08363 L
.25466 .06416 L
.2641 .04821 L
Mistroke
.27419 .03557 L
.28355 .0263 L
.29431 .01749 L
.29959 .01388 L
.30444 .01105 L
.30915 .00882 L
.31432 .00697 L
.31701 .00625 L
.31952 .00572 L
.32217 .0053 L
.32364 .00511 L
.325 .00497 L
.3274 .00478 L
.32867 .0047 L
.33001 .00464 L
.33226 .00456 L
.33475 .00449 L
.33899 .00438 L
.34139 .00428 L
.34362 .00417 L
.34601 .004 L
.34855 .00377 L
.35374 .00314 L
.363 .0016 L
.36864 .00064 L
.3714 .00023 L
Mfstroke
.3714 .00023 m
.37318 0 L
s
.39629 0 m
.40294 .00061 L
.40527 .00079 L
.40776 .00096 L
.40919 .00103 L
.41049 .00108 L
.4118 .00112 L
.41304 .00114 L
.41433 .00115 L
.41498 .00115 L
.4157 .00114 L
.41696 .00112 L
.41815 .00108 L
.41954 .00103 L
.42082 .00096 L
.42369 .00076 L
s
.42369 .00076 m
.43181 0 L
s
.46767 0 m
.47285 .00042 L
.47514 .00057 L
.47759 .00069 L
.479 .00075 L
.48028 .00079 L
.48157 .00082 L
.48278 .00083 L
.4841 .00084 L
.48476 .00084 L
.4855 .00084 L
.48679 .00083 L
.488 .00081 L
.48943 .00077 L
.49073 .00073 L
.49366 .00061 L
.50364 6e-05 L
s
.50364 6e-05 m
.50475 0 L
s
.53495 0 m
.5386 .00015 L
.54342 .00034 L
.54572 .00042 L
.54824 .00049 L
.55062 .00055 L
.55168 .00057 L
.55283 .00058 L
.55415 .0006 L
.55539 .00061 L
.55661 .00061 L
.55772 .00061 L
.55893 .00061 L
.55962 .0006 L
.56026 .0006 L
.56156 .00059 L
.56295 .00057 L
.5653 .00052 L
.56786 .00046 L
.57252 .00033 L
.58124 2e-05 L
s
.58124 2e-05 m
.58199 0 L
s
.60451 0 m
.60617 9e-05 L
.61101 .00044 L
.61676 .00099 L
.62201 .00158 L
.64264 .00354 L
.64781 .00382 L
.65267 .0041 L
.65704 .00446 L
.6595 .00474 L
.66176 .00507 L
.66606 .00595 L
.6685 .00662 L
.67077 .00738 L
.67536 .00934 L
.68028 .01213 L
.6906 .02042 L
.69999 .03075 L
.70993 .04481 L
.71911 .06196 L
.72918 .08826 L
.73427 .10556 L
.73988 .1282 L
.76088 .23925 L
.77008 .28815 L
.77494 .30956 L
.77761 .31936 L
.78012 .32712 L
.78258 .33319 L
.78388 .33575 L
.78525 .33796 L
.7864 .33942 L
.78767 .3406 L
.78883 .34127 L
.78991 .34156 L
.79108 .3415 L
.7922 .34109 L
.7932 .34042 L
.79429 .33937 L
.79547 .33786 L
.79673 .33585 L
.799 .33118 L
.80386 .31698 L
.80843 .29914 L
.81885 .24758 L
.83729 .15017 L
.84775 .10548 L
.85749 .07361 L
.86716 .05045 L
.87257 .0406 L
Mistroke
.8775 .0333 L
.8827 .02707 L
.88834 .02179 L
.89367 .01795 L
.89859 .01517 L
.90826 .01105 L
.91732 .00798 L
.92789 .00478 L
.93311 .00345 L
.93565 .0029 L
.93795 .00248 L
.94017 .00214 L
.94257 .00187 L
.94389 .00176 L
.94511 .00168 L
.94627 .00163 L
.9475 .00161 L
.94874 .00161 L
.94943 .00162 L
.95007 .00164 L
.9513 .00169 L
.95247 .00177 L
.95382 .00188 L
.95508 .002 L
.95792 .00236 L
.97619 .00544 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00So
oooo2?l00005ooooo`03o`000?oooooooooo00Kooooo1?l0000;ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo3Ol0000;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`08ooooo`co000000?oooooo`000?ooool08Oooool002Cooooo2Ol0000Xooooo`03o`00
0?oooooooooo02Cooooo2?l000000ooooooo0000ooooo`0^ooooo`03o`000?oooooooooo02gooooo
1Ol0000[ooooo`03o`000?oooooooooo01kooooo0_l0000<ooooo`;o00008_ooool002gooooo0ol0
001;ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0<_ooool2o`0004Oooooo0ol0
000booooo`00<?ooool3o`0004Cooooo1?l0000jooooo`03o`000?oooooooooo03Cooooo0_l00012
ooooo`?o0000=Oooool003;ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0loooo
o`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0??ooool3o`0003Sooooo000cooooo`;o
0000@?ooool00ol0003oooooooooo`0mooooo`;o0000>?ooool00ol0003oooooooooo`0jooooo`03
o`000?oooooooooo03Wooooo000eooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo03Oooooo0_l0000looooo`00=_oo
ool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0>Ooo
ool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03cooooo000fooooo`03o`000?oooooo
oooo03Wooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool0?Oooool003Oooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`11ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`0nooooo`00>?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo04;o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo03ko
oooo000iooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0@_ooool00ol0003ooooo
ooooo`0looooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0?oooool003Wooooo00?o
0000ooooooooool0<oooool00ol0003oooooooooo`13ooooo`;o0000?Oooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo03oooooo000jooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool0A?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool0@?ooool003_ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`15oooo
o`03o`000?oooooooooo03gooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`11oooo
o`00??ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04Gooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo047ooooo000mooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0nooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool0@_ooool003gooooo00?o0000ooooooooool0:ooo
ool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`12ooooo`00?_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo04Oooooo0_l00010ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0@_ooool0
03kooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`13ooooo`00?oooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0@?ooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo04?ooooo000oooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool0BOooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool0@oooool0043ooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`19ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`14ooooo`00@?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo04Wooooo00?o0000
ooooooooool0@Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo04Cooooo0011oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0B_ooool2o`0004;ooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`15ooooo`00@Oooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo04[ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo04Gooooo0011ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
B_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
AOooool004;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1;ooooo`03o`000?oo
oooooooo04;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`16ooooo`00@_ooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo033ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0@ooo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo04Kooooo0012ooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool0<?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo04Kooooo0013ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool0<Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01Ooo
ool3o`0004?ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`17ooooo`00@oooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo037ooooo00Go0000ooooooooooooooooo`00
000>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0A?ooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo04Oooooo0014ooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool0<Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0Aooo
ool004Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0booooo`05oa0@4?oooooo
ooooooooool@41003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Cooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`17ooooo`00A?ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo03;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo04Sooooo0015ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0<_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001oooool00ol0003ooooooooo
o`15ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0B?ooool004Gooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo04Gooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`18ooooo`00AOooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo04kooooo0_l00017ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool0B?ooool004Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1>ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`18ooooo`00
A_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0
A_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04Wooooo0016ooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`16ooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool0BOooool004Oooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`1?ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`19ooooo`00Aoooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
053ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
04Wooooo0017ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0D?ooool2o`0004So
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`19ooooo`00B?ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0Aoooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo04[ooooo0018ooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool0B_ooool004Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1A
ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1:
ooooo`00BOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo057ooooo00?o0000oooo
ooooool0B?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04[ooooo0019ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`18ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool0B_ooool004Wooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`1Booooo`;o0000BOooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo04_ooooo001:ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0D_oo
ool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Booo
ool004[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1Booooo`03o`000?oooooo
oooo04Sooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1;ooooo`00B_ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0B?ooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo04_ooooo001:ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool0Boooool004_ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`1Cooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`1;ooooo`00Boooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05Cooooo0_l0
001:ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0C?ooool004_ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo04Wooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`1<ooooo`00Boooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo04cooooo001;ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0E?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0C?ooool004cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0jooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo04[o
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1<ooooo`00C?ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo03[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0B_ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo04gooooo001<ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0>_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q
8Oo^k^h01oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0COooool004cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0kooooo`05
o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`?o0000B_ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo04gooooo001=ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0>oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool01Oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0COooool004gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0kooooo`05
oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
04_ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1=ooooo`00COooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo03cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool0COooool004kooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0looooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<00Kooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo04kooooo001>ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Eoooool0
0ol0003oooooooooo`1;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0C_ooool0
04kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Gooooo`;o0000C?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo04kooooo001?ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool0C_ooool004oooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`1Hooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`1>ooooo`00Coooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05Sooooo00?o
0000ooooooooool0C?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04kooooo001@
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`1<
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Coooool0053ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo04cooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`1?ooooo`00DOooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo05[ooooo0_l0001=ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0Coooool005;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Kooooo`03o`00
0?oooooooooo04gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1?ooooo`00D_oo
ool2o`0000;ooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`1=ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0Coooool005?ooooo1?l0001Nooooo`03o`000?oooooo
oooo04gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1@ooooo`00]Oooool00ol0
003oooooooooo`1=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0D?ooool00;Go
oooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo053o
oooo002eooooo`;o0000Coooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo053ooooo
002eooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`1Aooooo`00]Oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0DOooool00;Gooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo057ooooo002eooooo`03o`000?oooooooooo04kooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`1Aooooo`00]Oooool00ol0003oooooooooo`1?ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0D_ooool00;Gooooo00?o0000ooooooooool0Cooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05;ooooo002eooooo`;o0000D?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo05;ooooo002eooooo`03o`000?oooooooooo
04oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Booooo`00]Oooool00ol0003o
ooooooooo`1?ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Doooool009[ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<
00Kooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
05?ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go410@okZj
^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1Cooooo`00V_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0Doooool009[ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ojVYZOl@413o
oooo00Gooooo0ol0001@ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0E?ooool0
09[ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oa0@4?l0003o^[Zj00Kooooo00?o0000
ooooooooool0D?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Cooooo002Joooo
o`05oa0@4?ooooooooooooooool@41003_ooool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooo
oooo057ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Dooooo`00V_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oo
oooooooo057ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Dooooo`00V_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`00
0?oooooooooo057ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Dooooo`00]Ooo
ool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0EOoo
ool00;Gooooo0_l0001Cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0EOooool0
0;Gooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
05Gooooo002eooooo`03o`000?oooooooooo05?ooooo00Go0000ooooooooooooooooo`00001Hoooo
o`00]Oooool00ol0003oooooooooo`1Cooooo`;o000000?oooooo`000?l00000F?ooool00;Gooooo
00?o0000ooooooooool0E?ooool3o`0005Wooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@
413oooooooooo`04ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2`oooo
o`00V_ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`?o0000/?ooool009[o
oooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000
ooooooooool0/?ooool009[ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0000Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0/?ooool009[ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0/?oo
ool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000
/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009[o
oooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00V_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`2`ooooo`00V_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Joooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool00ol0003o^[Zj
ooooo`2iooooo`00[?ooool2oc8b<[[ooooo001mooooo`;o000000Ko410@oooooooooooo410@o`00
0?l@410Hooooo`Co000000Go410@ooooooooooooooooodA4A002o`000007oc8b<_oMgMgooooooooo
oon7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool01OnHV9So410@o`00
0?lb<S;oc<c<00Gooooo00?o0000onk^k_ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP1cooooo`00O_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Oooooo1_l0000<ooooo`03o`000?oooooooooo00Kooooo00OoMgMgoc8b<_oo
ooooooooolc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002Ooo
ool01Ol@413o^[ZjoooooomgMgOo<S8b00Gooooo00?oEEEEojVYZOooool00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1cooooo`00O_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool00oooool00onYZJWo
EEEEooooo`03ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo
410@07?ooooo001nooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000cooooo00?o
0000ooooooooool01_ooool00omgMgOo<S8booooo`0@ooooo`03o`000?oooooooooo00_ooooo1_l0
000<ooooo`03ojVYZOl@413ooooo00Gooooo00?o8B4Qooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`00001cooooo`00O_ooool01_l0003ogMgM
oc8b<_mEEEGogMgMo`0001_ooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<017ooooo00?o0000ooooooooool07?ooool00ol@413o0000okZj^P06ooooo`03oeEEEOo<c<co
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
Loooool007kooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Kooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool04Oooool00ol@413o0000o`000003o`0001cooooo00?o^[Zjob4Q8Ooo
ool01Oooool00onYZJWoMgMgooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@07?ooooo001nooooo`06o`000?lb<S;ooooooooooolb<S;o00006ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool06_oo
ool01Ol@413oV9RHoooooonj^[[o000000?ooooo00Go410@oooooooooooooooooc8b<P03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg07?ooooo001moooo
o`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool00omEEEGoIVIVo`000005oooo
o`Co00004_ooool00ol0003oooooooooo`0Jooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool5
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
Loooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3800) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .02298 m
.02846 .01913 L
.03279 .01611 L
.03793 .01314 L
.04262 .01092 L
.0522 .00754 L
.05746 .0062 L
.06244 .00524 L
.06754 .00452 L
.07012 .00426 L
.0716 .00414 L
.07295 .00405 L
.07419 .00399 L
.07536 .00395 L
.0766 .00391 L
.07731 .0039 L
.07796 .0039 L
.07915 .0039 L
.08023 .00391 L
.08147 .00394 L
.08265 .00398 L
.08392 .00404 L
.08532 .00412 L
.08814 .00433 L
.09318 .00487 L
.09908 .0057 L
.10458 .00661 L
.11503 .00865 L
.12017 .00988 L
.12493 .01126 L
.13382 .01479 L
.13851 .01736 L
.14349 .02078 L
.15286 .02938 L
.16296 .04216 L
.1725 .05778 L
.18124 .07553 L
.20016 .12755 L
.22086 .20086 L
.2257 .2171 L
.23095 .23261 L
.23591 .24443 L
.23827 .24889 L
.24047 .2523 L
.24301 .25526 L
.24436 .2564 L
.24511 .2569 L
.24581 .25728 L
.24653 .25758 L
.24732 .25781 L
Mistroke
.24801 .25792 L
.24876 .25795 L
.24948 .25789 L
.25017 .25775 L
.25145 .25726 L
.25267 .25655 L
.25395 .25552 L
.25624 .25301 L
.25872 .24938 L
.26142 .24437 L
.26668 .23189 L
.27166 .21739 L
.28097 .18589 L
.3019 .11449 L
.31158 .08723 L
.32185 .06341 L
.33147 .04571 L
.34028 .03325 L
.34968 .0237 L
.35461 .02004 L
.35979 .01701 L
.36853 .01327 L
.37809 .01018 L
.39773 .00442 L
.40339 .00302 L
.40617 .00244 L
.40873 .00198 L
.41101 .00165 L
.41351 .00135 L
.41473 .00124 L
.41603 .00114 L
.41741 .00106 L
.4187 .00101 L
.41991 .00098 L
.4206 .00096 L
.42125 .00096 L
.42256 .00096 L
.4233 .00097 L
.42397 .00098 L
.42511 .00101 L
.42635 .00105 L
.42886 .00116 L
.4342 .00147 L
.43714 .00163 L
.43858 .0017 L
.43991 .00175 L
.44118 .00179 L
.44183 .00181 L
.44253 .00182 L
.44323 .00184 L
Mistroke
.44388 .00184 L
.44466 .00185 L
.44537 .00185 L
.44658 .00184 L
.44727 .00183 L
.44791 .00181 L
.44908 .00177 L
.45033 .00172 L
.45295 .00157 L
.45542 .00137 L
.46003 .0009 L
Mfstroke
.46003 .0009 m
.46757 0 L
s
.49725 0 m
.4986 .00015 L
.50389 .00077 L
.50649 .00105 L
.50888 .00126 L
.51106 .00142 L
.51217 .00148 L
.51337 .00153 L
.51456 .00157 L
.51568 .0016 L
.51636 .0016 L
.51701 .0016 L
.51822 .0016 L
.51891 .00158 L
.51955 .00157 L
.52074 .00152 L
.52204 .00146 L
.52343 .00137 L
.52594 .00117 L
.52825 .00093 L
s
.52825 .00093 m
.53547 0 L
s
.57102 0 m
.57391 .0004 L
.57874 .00102 L
.58116 .00128 L
.58381 .0015 L
.58519 .00158 L
.58648 .00164 L
.58719 .00166 L
.58784 .00168 L
.58859 .00169 L
.5893 .0017 L
.5905 .00169 L
.59177 .00166 L
.59286 .00162 L
.59407 .00157 L
.59535 .00148 L
.59674 .00137 L
.59925 .00112 L
s
.59925 .00112 m
.60726 0 L
s
.64328 0 m
.64888 .00092 L
.6537 .00158 L
.65502 .00172 L
.65643 .00184 L
.65776 .00194 L
.65898 .00201 L
.65963 .00203 L
.66031 .00205 L
.661 .00207 L
.66175 .00208 L
.66241 .00208 L
.66311 .00207 L
.66438 .00204 L
.66563 .00199 L
.66694 .00191 L
.66929 .00171 L
.67205 .0014 L
.67461 .00104 L
.68043 .00011 L
s
.68043 .00011 m
.68117 0 L
s
.70843 0 m
.71021 .00034 L
.71924 .00247 L
.72443 .00362 L
.72926 .00447 L
.7317 .0048 L
.7343 .00506 L
.73579 .00518 L
.7372 .00528 L
.73983 .0054 L
.74484 .00557 L
.74609 .00561 L
.74729 .00565 L
.74953 .00577 L
.75065 .00585 L
.75188 .00596 L
.75442 .00626 L
.75577 .00648 L
.75721 .00676 L
.75981 .00741 L
.7622 .00818 L
.76479 .00924 L
.76948 .01179 L
.77405 .01509 L
.77825 .01883 L
.78799 .03 L
.79708 .04346 L
.80705 .06251 L
.81774 .09077 L
.82792 .12858 L
.83899 .18269 L
.84856 .23607 L
.85364 .26406 L
.85911 .29167 L
.86444 .31412 L
.86677 .32215 L
.86932 .32948 L
.87173 .33492 L
.87398 .33857 L
.87523 .34 L
.87636 .34091 L
.87766 .34152 L
.87889 .34166 L
.88011 .34136 L
.8808 .34101 L
.88144 .34056 L
.88274 .3393 L
.88414 .33743 L
.88667 .33271 L
.88897 .32696 L
Mistroke
.89458 .30791 L
.8999 .28437 L
.91843 .18482 L
.92791 .13764 L
.93816 .0966 L
.94844 .06633 L
.95812 .04614 L
.96754 .03219 L
.97619 .02298 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo000000Ko
00000oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo1Ol000000ooooooo
0000ooooo`09o`000003ooooool0003ooooo00[ooooo00?o0000ooooooooool01_l00003ooooo`03
o`000?oooooooooo00Wooooo1ol00005ooooo`03o`000?oooooooooo00Sooooo1_l00007ooooo`03
o`000?oooooooooo00?ooooo0ol00003ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo023ooooo000Tooooo`03o`00
0?oooooooooo00Gooooo1ol00006ooooo`Oo00005Oooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo00_ooooo1?l0000Nooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
4_ooool;o`00013ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Pooooo`00:_oo
ool2o`0001Cooooo0ol0001<ooooo`Co00008_ooool00ol0003oooooooooo`1<ooooo`?o0000HOoo
ool002Sooooo0_l0000Iooooo`?o0000A_ooool3o`0002Kooooo00?o0000ooooooooool0Coooool0
0ol0003oooooooooo`1Nooooo`009oooool00ol0003oooooooooo`0Looooo`?o0000@Oooool2o`00
02Wooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`1Mooooo`009Oooool2o`0002;o
oooo00?o0000ooooooooool0??ooool2o`0002_ooooo0_l0001Booooo`03o`000?oooooooooo05co
oooo000Tooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0>_ooool00ol0003ooooo
ooooo`0[ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0>?ooool00ol0003ooooo
ooooo`0Pooooo`00Boooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02cooooo00?o
0000ooooooooool0Doooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo023ooooo001<
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1D
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool08Oooool004cooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo05Cooooo00?o0000oooo
ooooool0=?ooool00ol0003oooooooooo`0Rooooo`00COooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo02;ooooo001>ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
8oooool004oooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0_ooooo`;o0000F?oo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02Cooooo001?ooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool09Oooool0053ooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`0Uooooo`00D?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02Ko
oooo001@ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`1Iooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool09_ooool0057ooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo05Wooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`0Wooooo`00DOooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo03?ooooo0_l0001Kooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool09oooool005;ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0coooo
o`03o`000?oooooooooo05[ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Xoooo
o`00Doooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0Foooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Sooooo001Cooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`1Kooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool0:Oooool005Cooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0Yooooo`00E?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo02Wooooo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0=Oooool2o`00
05gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Zooooo`00EOooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0G?ooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo02[ooooo001Eooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0=_ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool0:_ooool005Kooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`0[ooooo`00E_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01cooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o
0000ooooooooool0GOooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo02_ooooo001F
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool07?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0GOoo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo02_ooooo001Gooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool07?ooool01Ol@413ooooooooooooooooo410@00kooooo00?o
0000ooooooooool01Oooool3o`0005kooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`0[ooooo`00Eoooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01gooooo00Go0000
ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0G_oo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02cooooo001Hooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool07Oooool01Ol0003ooooooooooooooooo000000kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool0;?ooool005Sooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0M
ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo05oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0/ooooo`00F?ooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Goooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo02cooooo001Iooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool07_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001ooo
ool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0;Ooo
ool005Wooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo05oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0]ooooo`00FOooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo03[ooooo0_l0001Qooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool0;Oooool005[ooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0]ooooo`00F_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo03[ooooo
00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02gooooo
001Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`1Pooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0;_ooool005_ooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo067ooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0^ooooo`00Foooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo02kooooo001Kooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool0??ooool2o`0006;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0^ooooo`00
G?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0
HOooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02oooooo001Looooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`1Rooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0;oooool005cooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0mooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0_ooooo`00G?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
03gooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
02oooooo001Mooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0?Oooool00ol0003o
ooooooooo`1Rooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0;oooool005gooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0nooooo`;o0000Hoooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo033ooooo001Mooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool0<?ooool005gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0`
ooooo`00G_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03oooooo00?o0000oooo
ooooool0Hoooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo033ooooo001Nooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`1Sooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool0<?ooool005kooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0aooooo`00Goooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo043ooooo0_l0001Uooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0<Ooo
ool005oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooo
oooo06Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0aooooo`00Goooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0I?ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo037ooooo001Oooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0<_ooool0063ooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03
o`000?oooooooooo06Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0booooo`00
H?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02Kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000oooo
ooooool0IOooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03;ooooo001Pooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool09_ooool01Ol@413ooooooooooooooooo410@
00cooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0<_ooool0067ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0Vooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06oooo
o`?o0000IOooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03;ooooo001Qooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool09_ooool01Ol0003ooooooooooooooooo0000
00kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool0<oooool0067ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Wooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo06Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0coooo
o`00H_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`1V
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0<oooool006;ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0I_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo03?ooooo001Rooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0@oooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0<oooool006?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`13oooo
o`;o0000Ioooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03Cooooo001Sooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`1Wooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0=?ooool006?ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0dooooo`00Hoooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo04Cooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo03Cooooo001Tooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0AOooool0
0ol0003oooooooooo`1Wooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0=?ooool0
06Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo
06Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0eooooo`00IOooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo04Kooooo0_l0001Xooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0=Oooool006Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`16ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0eooooo`00I_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04Oooooo00?o
0000ooooooooool0J?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03Gooooo001W
ooooo`Co0000B_ooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0=Oooool00;Gooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo03Kooooo002eooooo`03o`000?oooooooooo06Sooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0fooooo`00]Oooool2o`0006Wooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0fooooo`00]Oooool00ol0003oooooooooo`1Xooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0=_ooool00;Gooooo00?o0000ooooooooool0JOooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Kooooo002eooooo`03o`000?oooooooooo
06Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0gooooo`00]Oooool00ol0003o
ooooooooo`1Yooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0=oooool00;Gooooo
00?o0000ooooooooool0JOooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Oooooo
002eooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0gooooo`00]Oooool2o`0006_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0g
ooooo`00]Oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0=oooool00;Gooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo03Oooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo06[ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0hooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S801_ooool00ol0003oooooooooo`1Z
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0>?ooool009[ooooo00Go410@oooo
oooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Joooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Sooooo002Jooooo`05o`000?oooooooooo
ooooool000003_ooool00onYZJWo410@ooooo`05ooooo`?o0000Joooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo03Sooooo002Jooooo`05o`000?ooooooooooooooool000003Oooool0
0ol@413o0000okZj^P06ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0hooooo`00V_ooool01Ol@413ooooooooooooooooo410@00kooooo00?o^[Zj
ob4Q8Oooool01Oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0>Oooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9So
oooookZj^_l000001_ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0>Oooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@
413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0>Oooool00;Gooooo00?o0000ooooooooool0K?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo03[ooooo002eooooo`;o0000K_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo03[ooooo002eooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0kooooo`00]Oooool00ol0003oooooooooo`1^ooooo`05
o`000?ooooooooooooooool00000?Oooool00;Gooooo00?o0000ooooooooool0K_ooool2o`000003
ooooool0003ooooo03gooooo002eooooo`03o`000?oooooooooo06oooooo0ol0000nooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`2`oooo
o`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooa0@400;oooo
o`Go00001_ooool3o`000;3ooooo002Jooooo`05o`000?ooooooooooooooool000002oooool01?m4
A4CogMgMooooool00007ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05o`000?oooooooooo
ooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oo
oooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00
0007ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Ooo
ool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009[o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`03ooooo`?o0000/?ooool009[ooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000oooooooo
ooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`
ooooo`00V_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo1?l00006ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00:cooooo00?o0000okZj^_ooool0^Oooool00:cooooo0_lb<S:jooooo`00OOooool2
o`000006oa0@4?oooooooooooa0@4?l0003o410@6?ooool4o`000005oa0@4?oooooooooooooooom4
A4@00_l000001olb<S;ogMgMooooooooooooQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4
A4Co^[Zj01Sooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<
c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1c
ooooo`00O_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l0000<oooo
o`03o`000?oooooooooo00Kooooo00OoMgMgoc8b<_ooooooooooolc<c?l0003o410@00cooooo00Go
410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002Oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?o
oooo00Go8B4QoiRHV?ooooooV9RHob4Q8@03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg07?ooooo001nooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool07_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
oa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`1aooooo`00
O_ooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000<ooooo`03o`000?oooooooooo
00Kooooo00?oMgMgoc8b<_ooool04?ooool00ol0003oooooooooo`0;ooooo`Ko00003?ooool00onY
ZJWo410@ooooo`02ooooo`05oc8b<_nHV9SooooooiRHV?lb<S800oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`00001cooooo`00O_ooool01_l0003ogMgMoc8b
<_mEEEGogMgMo`0001_ooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
017ooooo00?o0000ooooooooool07?ooool00ol@413o0000okZj^P03ooooo`05olc<c?l0003o0000
o`000?o<c<`00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`00001cooooo`00O_ooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001_ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Aooooo`03oa0@4?l0003o000000?o00007?ooool00onj^[[o
8B4Qooooo`02ooooo`05oa0@4?nj^[[ooooookZj^_l@41000oooool01Ol@413ooooooooooooooooo
410@00?ooooo00Go410@oooooooooooooooooa0@401cooooo`00O_ooool01_l0003o<S8boooooooo
oooo<S8bo`0001_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo01[ooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05o`000?nj^[[ooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`1cooooo`00OOooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo00?oEEEE
ofIVI_l000001Oooool4o`0001;ooooo00?o0000ooooooooool06_ooool01OnYZJWo410@o`000?l@
413oZJVY00?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07?ooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3900) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .32889 m
.04262 .24734 L
.06244 .14379 L
.07286 .10114 L
.08255 .07081 L
.0932 .04666 L
.09916 .03666 L
.10458 .02947 L
.10941 .02441 L
.11454 .02026 L
.11891 .01753 L
.12373 .01522 L
.1289 .0133 L
.13446 .01164 L
.14451 .00905 L
.15461 .00675 L
.15738 .00625 L
.1589 .00601 L
.16033 .00582 L
.16167 .00567 L
.16238 .00561 L
.16312 .00555 L
.16443 .00547 L
.16564 .00543 L
.16689 .00542 L
.16803 .00544 L
.16935 .00551 L
.1706 .00561 L
.17175 .00573 L
.17281 .00588 L
.17522 .00631 L
.17764 .00688 L
.18032 .00768 L
.18573 .00976 L
.20508 .02033 L
.21596 .02774 L
.22078 .03175 L
.22594 .03688 L
.23107 .04319 L
.23574 .05018 L
.24486 .06785 L
.25551 .09545 L
.26556 .12725 L
.28388 .19098 L
.29429 .22356 L
.29938 .23656 L
.30403 .24604 L
.30638 .24982 L
.30894 .25306 L
.31012 .25423 L
Mistroke
.31136 .25524 L
.31254 .25598 L
.31361 .25646 L
.31426 .25667 L
.31494 .25681 L
.31616 .25688 L
.31747 .25668 L
.31822 .25644 L
.31891 .25614 L
.32017 .25539 L
.32132 .25447 L
.3239 .25164 L
.3266 .24755 L
.32909 .24278 L
.33472 .22883 L
.34495 .19496 L
.36524 .12064 L
.37517 .09157 L
.38426 .07092 L
.40247 .04119 L
.41202 .02914 L
.41729 .02346 L
.42207 .01901 L
.42666 .01545 L
.43164 .01243 L
.43437 .01115 L
.43689 .01018 L
.43946 .00938 L
.44185 .0088 L
.44407 .00838 L
.44611 .00807 L
.44836 .0078 L
.45078 .00756 L
.45527 .0072 L
.46023 .00676 L
.46503 .00616 L
.47013 .00527 L
.47929 .00316 L
.48456 .00189 L
.49011 .00073 L
.4924 .00036 L
.49485 3e-05 L
Mfstroke
.49485 3e-05 m
.49513 0 L
s
.51091 0 m
.51447 .00032 L
.51936 .00084 L
.52187 .00108 L
.52454 .0013 L
.52583 .00139 L
.52705 .00146 L
.52814 .00152 L
.52933 .00157 L
.53002 .00159 L
.53066 .0016 L
.53133 .00162 L
.53206 .00162 L
.53337 .00163 L
.53456 .00161 L
.53528 .0016 L
.53595 .00158 L
.53746 .00153 L
.5388 .00147 L
.54021 .00139 L
.54982 .00056 L
.55505 7e-05 L
s
.55505 7e-05 m
.55585 0 L
s
.59059 0 m
.59251 8e-05 L
.59734 .00024 L
.60008 .00032 L
.60303 .00038 L
.60571 .00042 L
.60698 .00043 L
.60817 .00044 L
.60939 .00045 L
.6105 .00046 L
.61174 .00047 L
.61306 .00047 L
.61432 .00047 L
.61504 .00047 L
.6157 .00047 L
.61692 .00047 L
.61821 .00047 L
.61941 .00046 L
.62072 .00046 L
.62196 .00045 L
.62312 .00044 L
.62529 .00042 L
.62761 .00039 L
.63034 .00034 L
.63292 .00028 L
.63773 .00014 L
s
.63773 .00014 m
.64091 0 L
s
.68356 0 m
.68699 .00024 L
.68952 .00042 L
.69221 .00059 L
.6945 .0007 L
.69571 .00075 L
.69702 .00079 L
.69832 .00082 L
.69952 .00084 L
.70072 .00085 L
.70186 .00085 L
.70316 .00083 L
.70437 .00081 L
.70506 .00079 L
.70569 .00077 L
.7071 .00072 L
.70946 .0006 L
.71201 .00044 L
.71662 9e-05 L
s
.71662 9e-05 m
.71771 0 L
s
.74897 0 m
.75231 .0003 L
.75725 .0007 L
.76005 .00088 L
.76153 .00095 L
.76309 .00101 L
.7644 .00105 L
.76515 .00107 L
.76585 .00108 L
.76707 .0011 L
.76839 .0011 L
.76908 .00109 L
.76972 .00108 L
.77042 .00107 L
.77117 .00106 L
.77242 .00102 L
.77381 .00098 L
.77875 .00075 L
.78354 .00051 L
.78594 .00041 L
.78731 .00037 L
.78858 .00034 L
.7893 .00033 L
.78998 .00032 L
.79126 .00032 L
.79197 .00032 L
.79263 .00033 L
.79335 .00034 L
.79412 .00036 L
.79536 .00041 L
.79653 .00046 L
.79919 .00064 L
.80167 .00087 L
.80403 .00114 L
.80845 .00177 L
.81841 .00347 L
.82873 .00506 L
.83379 .00574 L
.83845 .00639 L
.84269 .00712 L
.84718 .00816 L
.85167 .00963 L
.85661 .0119 L
.86153 .01497 L
.86679 .01925 L
.87629 .02968 L
.88726 .0463 L
.89727 .06686 L
.90718 .09488 L
.91636 .12997 L
Mistroke
.93712 .23893 L
.94606 .28665 L
.95075 .30774 L
.95569 .32525 L
.95833 .33222 L
.95972 .33518 L
.96121 .33775 L
.96258 .33958 L
.96383 .34077 L
.96508 .34153 L
.96627 .34183 L
.96747 .34172 L
.96874 .34116 L
.96983 .34031 L
.97103 .33899 L
.97231 .33714 L
.9737 .33465 L
.97619 .32889 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool00_ooool3o`0000Cooooo00?o0000ooooooooool01?ooool7o`0000[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`00
00Oooooo1ol00009ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo023ooooo000Tooooo`03o`000?oooooooooo02Co
oooo2ol0000_ooooo`03o`000?oooooooooo01kooooo2?l00007ooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`06o`0002Oooooo00?o0000oooooooo
ool08?ooool004Sooooo0ol0000;ooooo`;o0000B_ooool4o`0000oooooo00?o0000ooooooooool0
I_ooool3o`0004Oooooo0014ooooo`Co00004?ooool2o`0004Kooooo0_l0000Cooooo`03o`000?oo
oooooooo06Wooooo0_l00015ooooo`00@Oooool3o`0001Kooooo00?o0000ooooooooool0@Oooool2
o`0001Gooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`12ooooo`00@?ooool00ol0
003oooooooooo`0Hooooo`;o0000@?ooool00ol0003oooooooooo`0Eooooo`;o0000KOooool00ol0
003oooooooooo`11ooooo`00?oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo03co
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo043o
oooo000nooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0>_ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0?oooool003gooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool0Koooool00ol0003oooooooooo`0nooooo`00??ooool00ol0003oooooooooo`0Q
ooooo`;o0000>?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo06oooooo00?o0000
ooooooooool0?_ooool003_ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0moooo
o`00>oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03?ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03cooooo000jooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Kooooo`;o0000
L_ooool00ol0003oooooooooo`0looooo`00>Oooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1booooo`03o`000?oo
oooooooo03_ooooo000iooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0>oooool0
03Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`0jooooo`00>?ooool00ol0003o
ooooooooo`0[ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`1cooooo`03o`000?oooooooooo03[ooooo000hooooo`03o`000?oooooooooo02_ooooo
00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo07Cooooo
00?o0000ooooooooool0>Oooool003Oooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`0[ooooo`03o`000?oooooooooo01kooooo0_l0001eooooo`03o`000?oooooooooo03Wooooo000g
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool0>?ooool003Oooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool0MOooool00ol0003oooooooooo`0hooooo`00=_ooool00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo02Sooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1fooooo`03
o`000?oooooooooo03Oooooo000fooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool0
=oooool003Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`0gooooo`00=Oooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool08Oooool2
o`0007Sooooo00?o0000ooooooooool0=_ooool003Gooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0Moooool00ol0
003oooooooooo`0fooooo`00=?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo03Ko
oooo000dooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0=Oooool003Cooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Sooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000003oa0@4?oooooooooo00?ooooo
00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0eooooo`00<oooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool02Oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
N?ooool00ol0003oooooooooo`0eooooo`00<oooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool02Oooool01Ol@413ooooooooooooooooo410@00kooooo
00?o0000ooooooooool01Oooool3o`0007Sooooo00?o0000ooooooooool0=Oooool003?ooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Wooooo00Go
0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
NOooool00ol0003oooooooooo`0dooooo`00<oooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo03Cooooo
000booooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0:ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo07Wooooo00?o0000ooooooooool0=?ooool003;ooooo00?o0000ooooooooool0>?oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00[ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0N_ooool00ol0003ooooo
ooooo`0cooooo`00<_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l00000
1oooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo03?ooooo000booooo`03o`000?oo
oooooooo03Sooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo07[ooooo00?o0000ooooooooool0<oooool0037ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Kooooo0_l0001kooooo`03o`000?oooooo
oooo03?ooooo000aooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0<_ooool0037o
oooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0booooo`00<Oooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`1kooooo`03o`000?oooooooooo03;ooooo000aooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo07_ooooo00?o
0000ooooooooool0<_ooool0033ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`0a
ooooo`00<?ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool0:?ooool2o`0007gooooo00?o0000ooooooooool0<Oooool0033ooooo00?o0000oooooooo
ool0??ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool0O?ooool00ol0003oooooooooo`0aooooo`00<?ooool00ol0003oooooooooo`0mooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1looooo`03o`00
0?oooooooooo037ooooo000`ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0<Ooo
ool002oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`0`ooooo`00;oooool00ol0
003oooooooooo`0oooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`1mooooo`03o`000?oooooooooo033ooooo000_ooooo`03o`000?oooooooooo03oo
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Yooooo`;o0000O_ooool00ol0003o
ooooooooo`0`ooooo`00;oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo033ooooo
000_ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo07gooooo00?o0000ooooooooool0<?ooool002kooooo00?o0000
ooooooooool0@Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool0O_ooool00ol0003oooooooooo`0_ooooo`00;_ooool00ol0003oooooooooo`11oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1noooo
o`03o`000?oooooooooo02oooooo000^ooooo`03o`000?oooooooooo047ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo07kooooo00?o0000oooooooo
ool0;oooool002kooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo02_ooooo0_l0001oooooo`03o`000?oooooooooo02oooooo000^ooooo`03o`000?oo
oooooooo04;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo07oooooo00?o0000ooooooooool0;_ooool002gooooo00?o0000ooooooooool0@oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0Ooooool0
0ol0003oooooooooo`0^ooooo`00;Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo
02kooooo000]ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006oooo
o`03o`000?oooooooooo07oooooo00?o0000ooooooooool0;_ooool002gooooo00?o0000oooooooo
ool0A?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000
ooooooooool0Ooooool00ol0003oooooooooo`0^ooooo`00;Oooool00ol0003oooooooooo`14oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool04_ooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`20ooooo`03o`000?oooooo
oooo02gooooo000/ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Booooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06
ooooo`?o0000P?ooool00ol0003oooooooooo`0]ooooo`00;?ooool00ol0003oooooooooo`16oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool04_ooool01Ol0003ooooooooooooooooo
000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`20ooooo`03o`000?oooooo
oooo02gooooo000/ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0Cooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool0;Oooool002cooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003ooooooooo
o`20ooooo`03o`000?oooooooooo02gooooo000/ooooo`03o`000?oooooooooo04Oooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0POooool00ol0003ooooo
ooooo`0/ooooo`00:oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo02cooooo000[
ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0_
ooooo`;o0000P_ooool00ol0003oooooooooo`0/ooooo`00:oooool00ol0003oooooooooo`19oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`21oooo
o`03o`000?oooooooooo02cooooo000[ooooo`03o`000?oooooooooo04Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo087ooooo00?o0000oooooooo
ool0;?ooool002_ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`0[ooooo`00:_oo
ool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo02_ooooo000Zooooo`03o`000?oooooo
oooo04cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo08;ooooo00?o0000ooooooooool0:oooool002[ooooo00?o0000ooooooooool0C?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo03;ooooo0_l00023ooooo`03o`000?oooooooooo
02_ooooo000Zooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0booooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0:oooool002[ooooo
00?o0000ooooooooool0C_ooool01Ol0003ooooooooooooooooo000003Gooooo00?o0000oooooooo
ool0Poooool00ol0003oooooooooo`0Zooooo`00:Oooool00ol0003oooooooooo`1@ooooo`?o0000
=_ooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo02[ooooo000Yooooo`03o`000?oo
oooooooo08Wooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`0Zooooo`00:Oooool0
0ol0003oooooooooo`29ooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool0:_ooool0
02Wooooo00?o0000ooooooooool0ROooool2o`0008Cooooo00?o0000ooooooooool0:_ooool002So
oooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo02[o
oooo000Xooooo`03o`000?oooooooooo08[ooooo00?o0000ooooooooool0Poooool00ol0003ooooo
ooooo`0Zooooo`00:?ooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo08Cooooo00?o
0000ooooooooool0:Oooool002Sooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`24
ooooo`03o`000?oooooooooo02Wooooo000Wooooo`03o`000?oooooooooo08_ooooo00?o0000oooo
ooooool0Q?ooool00ol0003oooooooooo`0Yooooo`009oooool00ol0003oooooooooo`2;ooooo`03
o`000?oooooooooo08Cooooo00?o0000ooooooooool0:Oooool002Oooooo00?o0000ooooooooool0
Roooool2o`0008Gooooo00?o0000ooooooooool0:Oooool002Oooooo00?o0000ooooooooool0Rooo
ool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo02Wooooo000Wooooo`03o`000?oooooo
oooo08_ooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`0Xooooo`009_ooool00ol0
003oooooooooo`1aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00GoV9RH
oa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool0:?oo
ool002Kooooo00?o0000ooooooooool0LOooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S801_ooool00ol0003oooooooooo`25ooooo`03o`00
0?oooooooooo02Sooooo000Vooooo`03o`000?oooooooooo077ooooo00Go410@oooooooooooooooo
oa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Q_ooool00ol0003ooooo
ooooo`0Wooooo`009_ooool00ol0003oooooooooo`1aooooo`05o`000?ooooooooooooooool00000
3_ooool00onYZJWo410@ooooo`05ooooo`?o0000Q_ooool00ol0003oooooooooo`0Wooooo`009Ooo
ool00ol0003oooooooooo`1booooo`05o`000?ooooooooooooooool000003Oooool00ol@413o0000
okZj^P06ooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool09oooool002Gooooo00?o
0000ooooooooool0L_ooool01Ol@413ooooooooooooooooo410@00kooooo00?o^[Zjob4Q8Oooool0
1Oooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo02Oooooo000Uooooo`03o`000?oo
oooooooo07;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l0
00001_ooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo02Kooooo000Uooooo`03o`00
0?oooooooooo07;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@
4?nYZJT01_ooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo02Kooooo000Tooooo`03
o`000?oooooooooo08kooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`0Vooooo`00
9?ooool00ol0003oooooooooo`2>ooooo`;o0000R?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo023ooooo002eooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0Pooooo`00]Oooool00ol0003oooooooooo`28ooooo`04o`000?oooooo
ooooooooo`;o00008_ooool00;Gooooo00?o0000ooooooooool0ROooool01?l0003oooooo`000?l0
000Sooooo`00]Oooool00ol0003oooooooooo`2:ooooo`;o00009?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0/?ooool009[ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo
0ol0002`ooooo`00V_ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo
00001oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol0003ooooooooooooooooo000000_o
oooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`2`oooo
o`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0
003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`00
0?ooool01_ooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool0
0oooool3o`000;3ooooo002Jooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool009[ooooo
00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co
00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002/
ooooo`03o`000?nj^[[ooooo0;Wooooo002/ooooo`;o<S8b^_ooool007gooooo0_l000001_l@413o
ooooooooool@413o0000oa0@41Sooooo1?l000001Ol@413oooooooooooooooooA4A400;o000000Oo
<S8bomgMgOooooooooooohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Hoooo
o`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01?l@413o0000odA4A?o<c<`4ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07?ooooo001nooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`0000cooooo00?o0000ooooooooool0
1_ooool01omgMgOo<S8booooooooooooc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo
410@00Wooooo1_l00009ooooo`05oa0@4?nj^[[oooooogMgMolb<S801Oooool00onHV9So410@omgM
g@03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg07?o
oooo001nooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`04ooooo`03ohN7QomEEEGooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@4100Loooool007kooooo00Ko0000oooooom4A4CoA4A4ooooool00009
ooooo`Ko00003?ooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo013ooooo00?o0000
ooooooooool02oooool6o`0000cooooo00?oZJVYoa0@4?ooool00_ooool01Oo<c<co8B4Qo`000?mE
EEGo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
0000Loooool007kooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Kooooo`03o`000?oooooooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Aooooo`03o`000?oooooooooo01cooooo00?o410@
o`000?nj^[X00oooool01OlQ8B7oQhN7oooooonHV9So000000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool00000Loooool007kooooo00Ko0000ohN7QonYZJWo
^[ZjoeEEEOl0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol@
413o0000o`000003o`0001cooooo00?o^[Zjob4Q8Oooool00_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100
Loooool007kooooo00Ko0000oc8b<_oooooooooooc8b<_l0000Kooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Jooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OlQ8B7oV9RHoooooomgMgOoEEEE00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Loooool007gooooo00?o410@o`000?n7QhL00_oo
ool00on7QhOo0000oa0@400Hooooo`03oeEEEOmVIVKo000000Gooooo1?l0000Booooo`03o`000?oo
oooooooo01[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05olc<c?l@413o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1c
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4000) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04866 m
.06244 .18078 L
.07216 .23469 L
.08255 .28979 L
.08852 .31514 L
.09135 .32461 L
.09396 .33164 L
.09658 .33693 L
.09795 .33896 L
.09866 .33979 L
.09942 .34052 L
.10069 .34139 L
.10187 .34178 L
.1026 .34182 L
.10329 .34171 L
.10458 .34115 L
.10586 .34012 L
.10707 .33872 L
.10933 .33503 L
.11176 .32954 L
.11439 .32193 L
.1235 .28459 L
.14415 .174 L
.15446 .12571 L
.16409 .09037 L
.17413 .06284 L
.17941 .05148 L
.18515 .04113 L
.19058 .03305 L
.19561 .02693 L
.20031 .0223 L
.20551 .01837 L
.21015 .01581 L
.2145 .01411 L
.2169 .01343 L
.2191 .01293 L
.22152 .01251 L
.22406 .01218 L
.22664 .01195 L
.22906 .01179 L
.23124 .01169 L
.23361 .0116 L
.23619 .01154 L
.23748 .01151 L
.23891 .01149 L
.24013 .01148 L
.24144 .01147 L
.24268 .01147 L
.2438 .01147 L
.24494 .01148 L
Mistroke
.24614 .0115 L
.24728 .01153 L
.24831 .01157 L
.24953 .01163 L
.25084 .01171 L
.25198 .0118 L
.25323 .01193 L
.2555 .01222 L
.25789 .01265 L
.26011 .01317 L
.26217 .01378 L
.26719 .01581 L
.27003 .01734 L
.27265 .01901 L
.28256 .0276 L
.29157 .0383 L
.30113 .05239 L
.31053 .06931 L
.32064 .09225 L
.33894 .14958 L
.34846 .18497 L
.35862 .22049 L
.36447 .23709 L
.36977 .24839 L
.37233 .25233 L
.37368 .25399 L
.3751 .2554 L
.37635 .25637 L
.37701 .25677 L
.37772 .25712 L
.37896 .25753 L
.38013 .25768 L
.38141 .25757 L
.38206 .25741 L
.38277 .25715 L
.38404 .25649 L
.38523 .25563 L
.38662 .25433 L
.3879 .25288 L
.39078 .2487 L
.39569 .23895 L
.40087 .22567 L
.4198 .16312 L
.43975 .09842 L
.44844 .07547 L
.45788 .0552 L
.46312 .04609 L
.46795 .03899 L
.47747 .02832 L
.48231 .02431 L
Mistroke
.48764 .02071 L
.49841 .01514 L
.51783 .00731 L
.52343 .00546 L
.52874 .004 L
.53351 .003 L
.53621 .00259 L
.53872 .00229 L
.54 .00217 L
.54136 .00207 L
.54253 .002 L
.5438 .00195 L
.54452 .00193 L
.54517 .00191 L
.54593 .0019 L
.54664 .00189 L
.54791 .00189 L
.54863 .00189 L
.54929 .0019 L
.55048 .00192 L
.55159 .00195 L
.55412 .00203 L
.55662 .00212 L
.55925 .00221 L
.56149 .00227 L
.56275 .0023 L
.56393 .00232 L
.56501 .00232 L
.566 .00233 L
.56714 .00232 L
.56821 .0023 L
.56938 .00227 L
.57062 .00223 L
.57285 .00212 L
.57524 .00196 L
.57787 .00174 L
.58785 .00057 L
Mfstroke
.58785 .00057 m
.59262 0 L
s
.62246 0 m
.62316 6e-05 L
.62588 .00028 L
.62846 .00046 L
.63086 .00061 L
.63212 .00067 L
.63347 .00072 L
.63472 .00076 L
.63585 .00079 L
.63698 .0008 L
.63805 .00081 L
.63927 .0008 L
.64056 .00078 L
.64165 .00076 L
.64286 .00072 L
.64555 .00059 L
.64806 .00044 L
.65334 4e-05 L
s
.65334 4e-05 m
.6538 0 L
s
.6866 0 m
.68901 .0002 L
.69369 .00058 L
.69574 .00072 L
.69798 .00085 L
.69919 .0009 L
.70031 .00094 L
.70139 .00096 L
.70254 .00098 L
.70317 .00099 L
.70386 .00099 L
.70511 .00099 L
.70632 .00097 L
.70744 .00094 L
.70868 .00089 L
.70985 .00084 L
.7125 .00069 L
.71784 .00026 L
s
.71784 .00026 m
.72069 0 L
s
.75138 0 m
.75784 .0007 L
.76054 .00097 L
.76308 .00118 L
.76446 .00127 L
.76572 .00134 L
.76711 .0014 L
.76789 .00142 L
.76862 .00144 L
.76981 .00145 L
.77108 .00145 L
.77217 .00143 L
.77337 .00139 L
.77465 .00134 L
.77604 .00125 L
.77855 .00105 L
.78349 .00049 L
s
.78349 .00049 m
.78697 0 L
s
.82324 0 m
.829 .00096 L
.83128 .00129 L
.83372 .00159 L
.83512 .00173 L
.8364 .00184 L
.83768 .00193 L
.83889 .00198 L
.8402 .00202 L
.84086 .00203 L
.84159 .00204 L
.84288 .00202 L
.84409 .00199 L
.84478 .00196 L
.84551 .00192 L
.84681 .00183 L
.84974 .00154 L
.8545 .00088 L
.85972 2e-05 L
s
.85972 2e-05 m
.85984 0 L
s
.88738 0 m
.89033 .00063 L
.90028 .00315 L
.905 .00421 L
.9076 .0047 L
.91005 .00509 L
.91233 .00539 L
.91481 .00565 L
.91915 .00598 L
.92437 .00629 L
.927 .00648 L
.92852 .00662 L
.9299 .00678 L
.93237 .00713 L
.93503 .00766 L
.93749 .00831 L
.93983 .0091 L
.94461 .01132 L
.94895 .01408 L
.95396 .01823 L
.95868 .02307 L
.96709 .03384 L
.97619 .04866 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05oooooa;o00002_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`05ooooo`Go00002oooool01?l0003oooooooooooooool7o`000003ooooool0003ooooo
00[ooooo1?l00008ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08?ooool002Co
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02go
oooo00Co0000oooooooooooooooo1?l0000Xooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool06Oooool9o`0000_ooooo00?o0000ooooooooool08?ooool00;Gooooo00Co0000ooooool0
003o0000POooool2o`0002cooooo001Noooooa3o0000Aoooool2o`0008Gooooo0_l0000Zooooo`00
GOooool00ol0003oooooooooo`0>ooooo`;o0000@oooool3o`0008Sooooo00?o0000ooooooooool0
9oooool005_ooooo0_l0000Cooooo`03o`000?oooooooooo03kooooo0_l00002ooooo`;o0000R?oo
ool00ol0003oooooooooo`0Vooooo`00F_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo03gooooo00Go0000ooooooooooooooooo`00002:ooooo`03o`000?oooooooooo02Gooooo001I
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0>_ooool2o`0000Cooooo00?o0000
ooooooooool0ROooool00ol0003oooooooooo`0Tooooo`00F?ooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo03Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2:oooo
o`03o`000?oooooooooo02?ooooo001Gooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08_ooooo00?o0000oooooooo
ool08_ooool005Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0Roooool00ol0003oooooooooo`0Rooooo`00E_oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo027ooooo001Eooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`07ooooo`;o0000SOooool0
0ol0003oooooooooo`0Qooooo`00EOooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo
027ooooo000Tooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0SOooool00ol0003o
ooooooooo`0Pooooo`009?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0;3ooooo
000Tooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0/?ooool002Gooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02_ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`2`ooooo`009Oooool00ol0003oooooooooo`0Zoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0;oooo
o`;o0000/Oooool002Gooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2`ooooo`00
9_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0;3ooooo000Vooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0/?ooool002Kooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`2`ooooo`009oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
0;3ooooo000Wooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo00gooooo0_l0002aooooo`009oooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo0;3ooooo000Wooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0:oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool0/?ooool002Sooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2`
ooooo`00:?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool06Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00?o0000ob4Q8OlQ8B401Oooool4
o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool002Sooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Sooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`04ooooo`03o`000?lQ8B7o8B4Q00Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`2`ooooo`00:Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool06?ooool01Ol@413ooooooooooooooooo410@00Cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool002Wooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Sooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`2`ooooo`00:Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool05oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;3ooooo000Zoooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Goooo
o`05oa0@4?ooooooooooooooool@41000oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0/?ooool002[ooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo01Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2`
ooooo`00:_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool05_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo00?o0000ooooooooool01oooool0
0omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo0;3ooooo000Zooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0/?ooool002_ooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0booooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool04Oooool2o`000;7o
oooo000[ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0/?ooool002_ooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`2`ooooo`00;?ooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo0;3ooooo000/ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool0/?ooool002cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`2`ooooo`00
;Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0Cooooo`;o0000/Oooool002gooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`2`ooooo`00;Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo03Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo0;3ooooo000]ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0/?ooool002ko
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2`ooooo`00;_ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo0;3ooooo000^ooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool0>?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Gooooo0_l0
002aooooo`00;oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03Wooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0;3ooooo000_oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0/?ooool002oooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`2`ooooo`00<?ooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo03[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo0;3ooooo000`ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0/?oo
ool0033ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool05oooool2o`000;7ooooo000`ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool0/?ooool0033ooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`0looooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`2`ooooo`00<Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03gooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo0;3ooooo
000aooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0?Oooool00ol0003ooooooooo
o`0?ooooo`05o`000?lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`00
0?oooooooooo0;3ooooo000aooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0?ooooo`05o`000?nHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo
00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0;3ooooo000aooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0=ooooo`03o`00
0?l@413ooooo00;ooooo00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`00
0?oooooooooo0;3ooooo000aooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0?ooo
ool00ol0003oooooooooo`0=ooooo`;o00000oooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ
8B7ok^k^00Kooooo0ol0002`ooooo`00<_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo03oooooo00?o0000ooooooooool03Oooool2o`0000?ooooo00?o0000ooooooooool03?ooool0
0omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0;3ooooo000booooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo410@
00?ooooo00?o410@ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
0;3ooooo000booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0@?ooool00ol0003o
ooooooooo`0;ooooo`07o`000?ooooooMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`2`ooooo`00<_ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool02oooool01ol0003oooooonk^k_lb
<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000oooooooo
ool0/?ooool003;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`11ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`2`ooooo`00<ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Kooooo`;o0000/Oooool003?ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`12ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`2`ooooo`00<oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
04;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
0;3ooooo000cooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0@oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0/?ooool003?ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`2`ooooo`00<oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo0;3ooooo000dooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool0AOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01kooooo0_l0002a
ooooo`00=?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo0;3ooooo000dooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool0A_ooool2o`0000;ooooo0_l0000Qooooo`03
o`000?oooooooooo0;3ooooo000dooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
Aoooool4o`0002;ooooo00?o0000ooooooooool0/?ooool003Cooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo0;3ooooo000eooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`2`ooooo`00=Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo06kooooo0_l0002aooooo`00=Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0/?ooool003Gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo0;3ooooo
000eooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0K_ooool00ol0003ooooooooo
o`2`ooooo`00=Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo06oooooo00?o0000
ooooooooool0/?ooool003Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1_oooo
o`03o`000?oooooooooo0;3ooooo000fooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0Koooool00ol0003oooooooooo`2`ooooo`00=_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo06oooooo0_l0002aooooo`00=_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo06oooooo00?o0000ooooooooool0/?ooool003Kooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`1`ooooo`03o`000?oooooooooo0;3ooooo000gooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05oiRHV?l@413o0000oc8b<_o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00=oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo05Gooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Kooooo00?o0000ooooooooool0
/?ooool003Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Fooooo`05oa0@4?oo
ooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;3ooooo
000gooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0E_ooool01Ol0003ooooooooo
oooooooo000000kooooo00?oZJVYoa0@4?ooool01Oooool3o`000;3ooooo000hooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0E_ooool01Ol0003ooooooooooooooooo000000gooooo
00?o410@o`000?nj^[X01_ooool00ol0003oooooooooo`2`ooooo`00>?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo05Kooooo00Go410@oooooooooooooooooa0@400>ooooo`03okZj
^_lQ8B7ooooo00Gooooo00?o0000ooooooooool0/?ooool003Sooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1Gooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413oV9RH
oooooonj^[[o000000Kooooo00?o0000ooooooooool0/?ooool003Wooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1Gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo
410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0/?ooool003Wooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo0;3ooooo000iooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0Loooool2o`000;7ooooo000jooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`2`ooooo`00>_ooool0
1Ol0003ooooooooooooooooo000007Kooooo00?o0000ooooooooool0/?ooool003_ooooo00Co0000
ooooool0003o0000M_ooool00ol0003oooooooooo`2`ooooo`00??ooool2o`0007Oooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool009[ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo
00?o0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?oo
ooooooooooooool@41002oooool5o`0000Kooooo0ol0002`ooooo`00V_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool00ol0003oooooooooo`2`ooooo`00
V_ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0
003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<
c?l000001oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`2`oooo
o`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooo
oooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000;3ooooo002Jooooo`05o`000?oo
ooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo
002Jooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooa0@400<ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo002/ooooo`03o`000?nj^[[ooooo0;Wooooo002/oooo
o`;o<S8b^_ooool007gooooo0_l000001_l@413oooooooooool@413o0000oa0@41Sooooo1?l00000
1Ol@413oooooooooooooooooA4A400;o000000Oo<S8bomgMgOooooooooooohN7Qol0003o^[Zj00co
oooo00GoV9RHo`000?l0003oA4A4okZj^P0Jooooo`;o000000Wo410@ooooooooooooooooonk^k_lb
<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP1cooooo`00O_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oo
oooo1_l0000<ooooo`03o`000?oooooooooo00Kooooo00OoMgMgoc8b<_ooooooooooolc<c?l0003o
410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`1cooooo`00O_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo01[ooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@401cooooo`00O_ooool0
1_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000<ooooo`03o`000?oooooooooo00Kooooo
00?oMgMgoc8b<_ooool04?ooool00ol0003oooooooooo`0;ooooo`Ko00002Oooool01?m4A4CogMgM
ooooool00004ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`00001cooooo`00O_ooool01_l0003ogMgMoc8b<_mE
EEGogMgMo`0001_ooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<017o
oooo00?o0000ooooooooool06_ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`00001cooooo`00O_ooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001_ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Aooooo`03oa0@4?l0003o000000?o00006_ooool00omgMgOo
c<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo
410@00?ooooo00Go410@oooooooooooooooooa0@401cooooo`00O_ooool01_l0003o<S8boooooooo
oooo<S8bo`0001_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo01_ooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Loooool0
07gooooo00?o410@o`000?n7QhL00_ooool00on7QhOo0000oa0@400Hooooo`03oeEEEOmVIVKo0000
00Gooooo1?l0000Booooo`03o`000?oooooooooo01cooooo00?oMgMgo`000?ooool00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h0Loooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4100) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03159 0 m
.03279 .0002 L
.0379 .00136 L
.04262 .00271 L
.06244 .00798 L
.06753 .00894 L
.073 .01007 L
.07565 .01075 L
.07817 .01153 L
.0829 .01348 L
.08546 .01486 L
.08783 .01639 L
.09322 .02083 L
.09872 .02688 L
.10458 .03509 L
.11487 .05403 L
.12599 .08185 L
.1365 .11731 L
.14616 .15961 L
.15602 .21118 L
.16658 .26905 L
.17171 .2944 L
.17656 .3147 L
.18091 .32873 L
.18337 .33458 L
.18456 .33682 L
.18565 .33853 L
.18671 .33986 L
.18782 .34092 L
.18894 .34161 L
.19016 .34195 L
.19122 .34189 L
.19236 .34146 L
.19343 .3407 L
.1944 .33972 L
.19564 .33808 L
.19679 .33618 L
.19937 .33056 L
.20165 .32416 L
.20406 .31602 L
.21338 .27423 L
.22362 .21835 L
.23443 .16127 L
.2447 .11662 L
.25392 .08574 L
.26396 .06029 L
.27372 .04179 L
.27907 .03385 L
.28411 .02779 L
.28882 .02333 L
Mistroke
.2913 .02146 L
.29391 .01982 L
.29612 .01869 L
.29853 .01772 L
.30073 .01705 L
.30279 .0166 L
.30405 .0164 L
.30475 .01631 L
.3054 .01624 L
.30654 .01615 L
.30781 .0161 L
.30848 .01609 L
.30918 .01609 L
.31044 .01612 L
.31114 .01615 L
.31179 .01619 L
.31326 .0163 L
.31578 .01658 L
.31806 .01691 L
.32318 .01783 L
.32777 .01885 L
.33273 .0202 L
.33743 .02181 L
.34175 .02374 L
.34643 .02648 L
.35147 .03039 L
.35621 .03516 L
.36055 .04054 L
.37115 .05797 L
.3812 .07993 L
.40109 .13732 L
.4195 .20102 L
.42847 .22918 L
.43318 .24117 L
.43814 .25078 L
.44078 .25441 L
.44228 .25596 L
.44368 .25708 L
.44496 .25781 L
.44613 .25822 L
.44678 .25835 L
.44748 .2584 L
.44876 .25828 L
.44996 .2579 L
.45128 .2572 L
.45194 .25673 L
.45265 .25614 L
.45395 .25485 L
.45645 .25157 L
.45873 .2477 L
Mistroke
.4635 .23717 L
.46859 .2229 L
.47773 .19209 L
.49846 .12002 L
.50876 .09068 L
.51989 .06485 L
.5304 .04556 L
.54006 .03205 L
.54477 .02695 L
.54981 .0225 L
.55417 .01941 L
.5589 .01673 L
.56446 .01428 L
.56972 .0124 L
.57957 .00929 L
.58978 .00607 L
.59936 .00328 L
.60417 .0022 L
.60687 .00172 L
.60935 .00138 L
.61059 .00124 L
.61192 .00112 L
.61268 .00107 L
.61337 .00102 L
.61403 .00099 L
.61472 .00096 L
.61545 .00094 L
.61612 .00092 L
.61684 .00091 L
.61763 .00091 L
.61831 .00091 L
.61905 .00092 L
.61974 .00094 L
.62037 .00095 L
.62167 .001 L
.62289 .00106 L
.62516 .0012 L
.63025 .00159 L
.63471 .00191 L
.63695 .00204 L
.63823 .00209 L
.63941 .00213 L
.64073 .00217 L
.64192 .00218 L
.64258 .00218 L
.6433 .00218 L
.64461 .00216 L
.64581 .00213 L
.64709 .00207 L
.64818 .00202 L
Mistroke
.64938 .00194 L
.65206 .00173 L
.65494 .00144 L
.66015 .00081 L
.66504 .0002 L
Mfstroke
.66504 .0002 m
.66685 0 L
s
.69731 0 m
.70137 .00032 L
.70618 .00064 L
.70891 .00077 L
.71022 .00082 L
.71145 .00086 L
.71258 .00089 L
.7138 .00091 L
.7149 .00092 L
.71592 .00093 L
.71703 .00093 L
.71825 .00092 L
.71952 .00091 L
.7207 .00089 L
.72199 .00086 L
.7234 .00082 L
.72596 .00073 L
.73075 .00052 L
.74156 1e-05 L
s
.74156 1e-05 m
.74168 0 L
s
.78654 0 m
.79141 .00026 L
.79645 .00052 L
.79892 .00063 L
.80119 .0007 L
.80251 .00073 L
.80317 .00075 L
.8039 .00076 L
.80463 .00076 L
.80541 .00077 L
.80615 .00077 L
.80682 .00077 L
.80808 .00075 L
.80879 .00074 L
.80944 .00072 L
.81065 .00069 L
.81193 .00064 L
.81437 .00051 L
.81667 .00035 L
s
.81667 .00035 m
.82053 0 L
s
.8592 0 m
.86055 .00021 L
.86563 .001 L
.8683 .00137 L
.86976 .00154 L
.87112 .00168 L
.87241 .00179 L
.87359 .00187 L
.8749 .00193 L
.87562 .00196 L
.87631 .00197 L
.87749 .00199 L
.87859 .00198 L
.8798 .00194 L
.88108 .00189 L
.88222 .00181 L
.88327 .00172 L
.88564 .00147 L
.88992 .00085 L
s
.88992 .00085 m
.89459 0 L
s
.9282 0 m
.92852 6e-05 L
.93415 .00121 L
.93661 .00164 L
.93932 .00203 L
.94043 .00216 L
.94162 .00228 L
.94265 .00236 L
.94376 .00243 L
.94502 .00248 L
.94622 .00251 L
.94738 .0025 L
.94845 .00248 L
.94963 .00242 L
.95073 .00236 L
.95194 .00226 L
.95324 .00213 L
.95832 .00143 L
s
.95832 .00143 m
.97044 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`02ooooo`Co00000oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00;ooooo1_l000000ooooooo0000ooooo`0;o`0000_o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool01?l0003oooooooooooooool6o`0000;ooooo00?o0000oooo
ooooool02Oooool9o`0000?ooooo00?o0000ooooooooool08?ooool002Cooooo00?o0000oooooooo
ool01_ooool3o`0002Gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo01Oooooo0ol0000Cooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`0Pooooo`00<?ooool5o`00083ooooo00?o0000ooooooooool0
5?ooool3o`0009Wooooo000eooooo`;o0000O_ooool00ol0003oooooooooo`0Aooooo`?o0000W?oo
ool003Oooooo0_l0000oooooo`Oo0000=_ooool00ol0003oooooooooo`0>ooooo`?o0000Woooool0
03Wooooo00?o0000ooooooooool0>_ooool3o`0000Kooooo1Ol0000aooooo`;o00003_ooool00ol0
003oooooooooo`2Pooooo`00>_ooool00ol0003oooooooooo`0hooooo`;o00003Oooool2o`0002oo
oooo00?o0000ooooooooool02oooool2o`000:?ooooo000kooooo`03o`000?oooooooooo03Kooooo
00?o0000ooooooooool03oooool2o`0002gooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`2Sooooo`00>oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0:?ooooo000l
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Y?ooool003gooooo00?o0000oooo
ooooool0<_ooool00ol0003oooooooooo`0Dooooo`;o0000:_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo0:Cooooo000mooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0YOooool003kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo02Oooooo0_l00008ooooo`03o`000?oooooooooo0:Kooooo000nooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0Yoooool003oooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`2Wooooo`00?oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0:Sooooo0010ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Z?ooool0043ooooo
00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Yooooo`00@Oooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09?ooool2o`0000Gooooo00?o
0000ooooooooool0ZOooool0047ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2Z
ooooo`00@Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0:[ooooo0012ooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0Zoooool004;ooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`2[ooooo`00@_ooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo0:_ooooo0013ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Qooooo`;o00000_ooool00ol0003oooooooooo`2/ooooo`00@oooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool08?ooool01Ol0
003ooooooooooooooooo00000:kooooo0014ooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0Pooooo`05o`000?ooooooooooooooool00000[_ooool0
04Cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
023ooooo00Co0000oooooooooooo0000[oooool004Cooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo00Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1Oooool4o`000003oa0@4?oooooooooo00?ooooo00Co0000oooooooooooo0000[ooo
ool004Gooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooo00000;3ooooo0015ooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41003_oo
ool00ol0003oooooooooo`05ooooo`?o0000/?ooool004Gooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
000>ooooo`03o`000?oooooooooo00Gooooo0_l0002aooooo`00A_ooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooo
oooo000000kooooo00?o0000ooooooooool01Oooool2o`000;7ooooo0016ooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`03ooooo`05oa0@4?oooooo
ooooooooool@41003_ooool00ol0003oooooooooo`05ooooo`;o0000/Oooool004Kooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool004Oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo
oooo00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo000000Oooooo00?o
0000ooooooooool0/?ooool004Oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo01cooooo0_l0002booooo`00Aoooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo02cooooo00?o0000ooooooooool06oooool3o`000;7ooooo0018ooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Kooooo`;o
0000/_ooool004Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooool00000/_ooool004Sooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooool00000/_oo
ool004Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooool00000/_ooool004Wooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo01Sooooo00Co0000oooooooooooo0000/_ooool0
04Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool00_l0002aooooo`00BOooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool05oooool01?l0003oooooooooool0002boooo
o`00BOooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool05oooool01?l0003oooooooooool0002booooo`00BOooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool05_ooool01Ol0003ooooooooooooooooo0000
0;;ooooo001:ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`0Fooooo`05o`000?ooooooooooooooool00000/_ooool004[ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Gooooo00Go0000oooooooo
ooooooooo`00002booooo`00B_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`;o0000/Oooool004[ooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`2`ooooo`00B_ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo0;3ooooo001:ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0/?ooool004_ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2`oooo
o`00Boooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo001;ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo00?ooooo0_l0002aooooo`00Boooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0;3ooooo001;ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0/?ooool0
04_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2`ooooo`00Boooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo03Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0/?ooool004cooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0eooooo`05ogMgMonHV9So0000oiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00GoV9RHob4Q8Oo^k^ko0000odA4A006ooooo`03o`000?oooooooooo0;3ooooo001<oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0=Oooool01Ol@413oooooo`000?oooooo
410@00cooooo00?oV9RHob4Q8Ol000001oooool00ol0003oooooooooo`2`ooooo`00C?ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool00_l0000=oooo
o`03oiRHV?l0003ok^k^00Kooooo0ol0002`ooooo`00C?ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool00_l0000=ooooo`03o`000?mgMgOoIVIV00Ko
oooo00?o0000ooooooooool0/?ooool004cooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0fooooo`05oa0@4?ooooooooooo`000?l@41003Oooool00ol0003oooooo`000006ooooo`03
o`000?oooooooooo0;3ooooo001<ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
=_ooool01OmgMgOoV9RHoooooonHV9So000000_ooooo00Go0000okZj^_l0003oV9RHoa0@4006oooo
o`03o`000?oooooooooo0;3ooooo001=ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0=_ooool01Oo^k^ko<S8bo`000?lb<S;o000000_ooooo00GoV9RHo`000?l0003o8B4Qolc<c006
ooooo`03o`000?oooooooooo0;3ooooo001=ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0/?ooool004gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool2o`000;7ooooo001=ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool004gooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`2`ooooo`00C_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo03gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo0;3ooooo001>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0?_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0/?ooool004ko
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2`ooooo`00C_ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0:ooooo`;o0000/Oooool004oooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`10ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`2`ooooo`00Coooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo047ooooo00Co0000
oooooooooooooooo0_l0000<ooooo`03o`000?oooooooooo0;3ooooo001?ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0@Oooool2o`000003ooooool0003o000000gooooo00?o0000
ooooooooool0/?ooool004oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`13oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0/?ooool004oooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo0;3ooooo001@ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0E?ooool2o`000;7ooooo001@ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`2`ooooo`00D?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0/?ooool0
053ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo
0;3ooooo001@ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0E?ooool00ol0003o
ooooooooo`2`ooooo`00D?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Gooooo
00?o0000ooooooooool0/?ooool0057ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`1Eooooo`03o`000?oooooooooo0;3ooooo001Aooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0EOooool2o`000;7ooooo001Aooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0EOooool00ol0003oooooooooo`2`ooooo`00DOooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo05Kooooo00?o0000ooooooooool0/?ooool0057ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0kooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0;3ooooo001Booooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0>oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S801_ooool00ol0003oooooooooo`2`
ooooo`00D_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03_ooooo00Go410@oooo
oooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0/?ooool0
05;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0kooooo`05o`000?oooooooooo
ooooool000003_ooool00onYZJWo410@ooooo`05ooooo`?o0000/?ooool005?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0looooo`05o`000?ooooooooooooooool000003Oooool0
0ol@413o0000okZj^P06ooooo`03o`000?oooooooooo0;3ooooo001Cooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0??ooool01Ol@413ooooooooooooooooo410@00kooooo00?o^[Zj
ob4Q8Oooool01Oooool00ol0003oooooooooo`2`ooooo`00Doooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo03cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9So
oooookZj^_l000001_ooool00ol0003oooooooooo`2`ooooo`00Doooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo03gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@
413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`2`ooooo`00E?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0/?ooool005Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1Hooooo`;o0000/Oooool005Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo0;3ooooo001Eooooo`05
o`000?ooooooooooooooool00000Foooool00ol0003oooooooooo`2`ooooo`00EOooool2o`000003
ooooool0003o000005_ooooo00?o0000ooooooooool0/?ooool005Kooooo0ol0001Looooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04oooo
o`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413o
oooooooooooooooo410@00_ooooo1Ol00006ooooo`?o0000/?ooool009[ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0/?ooool0
09[ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o
0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<
c<co000000Oooooo00?o0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooo
oooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0002`ooooo`00V_ooool01Ol0003o
oooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`oooo
o`00V_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Joooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool00ol0003o^[Zjooooo`2iooooo`00[?oo
ool2oc8b<[[ooooo001mooooo`;o000000Ko410@oooooooooooo410@o`000?l@410Hooooo`Co0000
00Go410@ooooooooooooooooodA4A002o`000007oc8b<_oMgMgooooooooooon7QhOo0000okZj^P0<
ooooo`05oiRHV?l0003o0000odA4A?nj^[X06_ooool2o`000003oa0@4?oooooooooo00;ooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^07?ooooo001nooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`00
00cooooo00?o0000ooooooooool01_ooool01omgMgOo<S8booooooooooooc<c<o`000?l@41003?oo
ool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`1cooooo`00O_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01[o
oooo1Ol00006ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003oooo
o`05oa0@4?ooooooooooooooool@4100Loooool007kooooo00Ko0000oooooom4A4CoA4A4ooooool0
0009ooooo`Ko00003?ooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo013ooooo00?o
0000ooooooooool02oooool6o`0000Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
07?ooooo001nooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo00006oooool00ol0003oooooooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`04Oooool00ol0003oooooooooo`0Jooooo`04omgMgOmE
EEGoooooo`0000Oooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`00001cooooo`00O_ooool01_l0003oQhN7ojVYZOnj^[[oEEEE
o`0001_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03oa0@4?l0003o
000000?o00006_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100Loooool007kooooo00Ko
0000oc8b<_oooooooooooc8b<_l0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Kooooo`03onk^k_m4A4Co000000Oooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1c
ooooo`00OOooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo00?oEEEEofIV
I_l000001Oooool4o`0001;ooooo00?o0000ooooooooool07?ooool00omgMgOo0000ooooo`04oooo
o`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h0Loooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4200) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .00021 m
0 0 rlineto s
.02381 .00021 m
.02654 0 L
s
.05782 0 m
.06244 .00036 L
.06506 .00056 L
.06789 .00075 L
.07056 .0009 L
.07183 .00095 L
.07302 .00099 L
.07439 .00102 L
.07512 .00104 L
.0759 .00105 L
.07671 .00106 L
.07748 .00106 L
.07818 .00106 L
.07893 .00105 L
.07958 .00104 L
.08028 .00103 L
.08172 .001 L
.08305 .00096 L
.08429 .00092 L
.09418 .00042 L
.09658 .00031 L
.09914 .00021 L
.0999 .00019 L
.10062 .00017 L
.10132 .00016 L
.10196 .00015 L
.10322 .00014 L
.10388 .00014 L
.10458 .00014 L
.10583 .00015 L
.10697 .00018 L
.10829 .00022 L
.10955 .00027 L
.11177 .0004 L
.11419 .00059 L
.11968 .00121 L
.12476 .00195 L
.14327 .00524 L
.14836 .00625 L
.15386 .00753 L
.15906 .00905 L
.16383 .01085 L
.16815 .01292 L
.17289 .01577 L
.18245 .02379 L
.18771 .02968 L
.19268 .03638 L
.202 .05242 L
.21203 .07625 L
.22293 .11237 L
Mistroke
.23235 .1534 L
.24274 .20723 L
.25371 .26624 L
.25851 .28951 L
.26376 .31108 L
.26613 .31911 L
.26866 .32631 L
.27104 .33169 L
.27321 .33532 L
.27449 .33687 L
.27567 .33791 L
.27696 .33862 L
.27761 .3388 L
.27832 .33886 L
.27953 .33864 L
.28082 .33796 L
.28203 .3369 L
.28315 .33558 L
.28444 .33363 L
.28581 .33107 L
.28827 .32526 L
.29386 .30686 L
.30402 .25937 L
.32368 .15453 L
.3323 .11699 L
.34173 .08537 L
.35114 .06253 L
.36106 .04541 L
.36627 .03855 L
.37185 .03262 L
.37712 .0283 L
.3819 .02548 L
.38421 .02451 L
.38674 .02372 L
.38802 .02344 L
.38872 .02331 L
.38939 .02322 L
.39069 .02309 L
.39187 .02304 L
.39297 .02305 L
.39415 .02312 L
.39526 .02324 L
.39627 .02339 L
.39746 .02363 L
.39874 .02395 L
.40107 .02469 L
.40358 .02572 L
.40633 .02709 L
.4119 .03057 L
.42185 .03897 L
Mistroke
.43207 .05079 L
.44138 .06567 L
.45212 .08971 L
.4623 .12001 L
.48053 .18562 L
.49091 .22042 L
.49599 .23431 L
.50065 .24446 L
.50305 .24861 L
.50529 .25173 L
.50762 .25422 L
.50886 .25521 L
.51017 .25602 L
.51086 .25633 L
.5115 .25656 L
.5122 .25674 L
.51294 .25684 L
.51418 .25683 L
.51489 .25672 L
.51555 .25654 L
.51678 .25604 L
.51791 .25537 L
.51921 .25437 L
.52044 .25319 L
.52297 .25007 L
.52566 .24576 L
.53049 .23562 L
.54145 .20343 L
.56148 .13064 L
.572 .09649 L
.5831 .06869 L
.59309 .05096 L
.60403 .03718 L
.62324 .01945 L
.63348 .01205 L
.63833 .00928 L
.64281 .00725 L
.64526 .00637 L
.64796 .0056 L
.65068 .00501 L
.65217 .00477 L
.65357 .00459 L
.65488 .00446 L
.65612 .00436 L
.65724 .00431 L
.65847 .00427 L
.65916 .00426 L
.65979 .00425 L
.66052 .00425 L
.6612 .00426 L
Mistroke
.66242 .00428 L
.66374 .00432 L
.66832 .00453 L
.67085 .00464 L
.67209 .00468 L
.67324 .00471 L
.67389 .00472 L
.67459 .00473 L
.67529 .00474 L
.67606 .00474 L
.6767 .00473 L
.67739 .00472 L
.67863 .00468 L
.67991 .00463 L
.68126 .00454 L
.68367 .00433 L
.68619 .00402 L
.68888 .00359 L
.69373 .00262 L
.69945 .0013 L
.70473 .0001 L
Mfstroke
.70473 .0001 m
.70528 0 L
s
.73433 0 m
.73587 .00025 L
.74125 .00111 L
.74361 .00143 L
.74622 .00171 L
.74739 .00182 L
.74865 .00191 L
.74935 .00195 L
.74998 .00198 L
.75123 .00202 L
.7525 .00205 L
.75322 .00205 L
.75389 .00204 L
.7546 .00203 L
.75524 .00201 L
.75599 .00198 L
.75669 .00194 L
.75789 .00187 L
.75916 .00177 L
.76145 .00154 L
.7666 .00082 L
s
.7666 .00082 m
.77157 0 L
s
.80849 0 m
.81366 .00071 L
.81583 .00094 L
.81815 .00114 L
.81948 .00123 L
.8207 .0013 L
.82193 .00135 L
.82309 .00138 L
.82429 .0014 L
.82556 .00139 L
.82676 .00137 L
.82785 .00134 L
.82914 .00129 L
.83053 .00121 L
.83305 .00102 L
.83784 .00053 L
.84224 1e-05 L
s
.84224 1e-05 m
.8423 0 L
s
.87676 0 m
.87753 8e-05 L
.88278 .00061 L
.88497 .0008 L
.88733 .00096 L
.88868 .00103 L
.88991 .00108 L
.89116 .00112 L
.89233 .00114 L
.89339 .00115 L
.89452 .00114 L
.89559 .00113 L
.89655 .00111 L
.89769 .00107 L
.89892 .00102 L
.90114 .0009 L
.90608 .0005 L
.91068 6e-05 L
s
.91068 6e-05 m
.91125 0 L
s
.94654 0 m
.95061 .00035 L
.95291 .00051 L
.95534 .00066 L
.95742 .00075 L
.9586 .00079 L
.9597 .00082 L
.96072 .00083 L
.96184 .00084 L
.96289 .00084 L
.96386 .00083 L
.96474 .00082 L
.9657 .0008 L
.96671 .00077 L
.96766 .00074 L
.9698 .00064 L
.97176 .00052 L
.97619 .00021 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool00_ooool6o`0000;ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool4o`0000Go
oooo1Ol0000;ooooo`So00001?ooool00ol0003oooooooooo`09ooooo`Go00001oooool00ol0003o
ooooooooo`08ooooo`;o00002oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo023o
oooo000Tooooo`03o`000?oooooooooo023ooooo1_l00008ooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Xooooo`Ko00000_ooool5o`0002Sooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Pooooo`00COooool3o`0006Gooooo00?o
0000ooooooooool09_ooool2o`0008Sooooo001@ooooo`;o0000Hoooool00ol0003oooooooooo`0T
ooooo`;o0000R_ooool005;ooooo0_l0001Qooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool0R_ooool005Cooooo00?o0000ooooooooool0G_ooool2o`0002;ooooo0_l0002=ooooo`00
EOooool00ol0003oooooooooo`0kooooo`Co00007_ooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo08gooooo001Eooooo`03o`000?oooooooooo03Wooooo0_l00004ooooo`?o00006ooo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo08kooooo001Fooooo`03o`000?oooooo
oooo03Kooooo0_l00009ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`2?ooooo`00Eoooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
093ooooo001Hooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0TOooool005Sooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`2Aooooo`00FOooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool05Oooool2o`0001cooooo00?o
0000ooooooooool0T_ooool005Wooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`2C
ooooo`00FOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo09?ooooo001Jooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool0U?ooool005[ooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`2Dooooo`00Foooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo09Gooooo001Kooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0@ooooo`;o00006?ooool00ol0003oooooooooo`2Fooooo`00G?ooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo09Kooooo001Looooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool0Uoooool005cooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`2Gooooo`00GOooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo09Sooooo001M
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0V?ooool005kooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00gooooo0_l0000Foooo
o`03o`000?oooooooooo09Sooooo001Nooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0VOooool005kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2Iooooo`00Gooo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo09Wooooo001Oooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool04oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B400ol0003oooooooooo`02ooooo`Co000000?o410@ooooooooool00oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo09[ooooo001Oooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool04oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B400ooooooo0000oooo
o`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`2Jooooo`00H?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01?ooooo00Go410@
oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Ooo
ool3o`0001?ooooo00?o0000ooooooooool0V_ooool0063ooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0Dooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`2Kooooo`00H?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01Cooooo00Go0000
ooooooooooooooooo`000009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo09_ooooo001Qooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool05?ooool01Ol@413ooooooooooooooooo410@00Wooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool0Voooool0067ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0E
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`2Looooo`00HOooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0:ooooo`05o`000?ooooooEEEEofIVI_l000001oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo09cooooo001Rooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0W?oo
ool006;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo00Wooooo0_l0000Booooo`03o`000?oooooooooo09cooooo001Rooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0WOooool006;ooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`2Mooooo`00Hoooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo09gooooo
001Sooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0WOooool006?ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`2Nooooo`00Hoooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01oooool2o`00013ooooo00?o0000oooo
ooooool0W_ooool006?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2Nooooo`00
I?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo09oooooo001Tooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0Woooool006Cooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`2Oooooo`00I?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
0:3ooooo001Tooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`05ooooo`;o00003_ooool00ol0003oooooooooo`2Pooooo`00IOooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo0:3ooooo001Uooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0XOooool006Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`2Q
ooooo`00IOooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0:7ooooo001Uooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0X_ooool006Kooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00?ooooo0_l0000<ooooo`03o`00
0?oooooooooo0:;ooooo001Vooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0X_oo
ool006Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`2Sooooo`00I_ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo0:?ooooo001Vooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool06_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go000000?oooooo`000?ooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
0:?ooooo001Wooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool06oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`07oiRHV?lQ8B7ok^k^oooooom4A4Coooooo`00
0004ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Y?ooool006Oooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Kooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000002oooool00ol0003ooooo
ooooo`2Tooooo`00Ioooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01_ooooo00Go
0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00;ooooo00Co0000oooooooooooo
oooo0ol00009ooooo`03o`000?oooooooooo0:Cooooo001Wooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool06oooool01Ol0003ooooooooooooooooo000000kooooo00GoMgMgofIVI_oo
ooooooooo`000003ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Y?ooool006Oo
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Kooooo`05oa0@4?oooooooooooooo
ool@41003oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0YOooool006Oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Koooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Co
0000oooooooooooo00002_ooool00ol0003oooooooooo`2Uooooo`00J?ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo01cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`00oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo
0:Gooooo001Xooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0=?ooool01?l0003o
ooooooooool00009ooooo`03o`000?oooooooooo0:Kooooo001Xooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool0=Oooool01?l0003oooooo`000?l00008ooooo`03o`000?oooooooooo
0:Kooooo001Xooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooo`000009ooooo`03o`000?oooooooooo0:Kooooo001Xooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0=_ooool2o`0000Sooooo00?o0000ooooooooool0Yoooool006Sooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0gooooo`;o00002?ooool00ol0003ooooooooo
o`2Wooooo`00JOooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`2Wooooo`00JOooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo03Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Xoooo
o`00JOooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Sooooo0_l00006ooooo`03
o`000?oooooooooo0:Sooooo001Yooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
>?ooool2o`0000Gooooo00?o0000ooooooooool0ZOooool006Wooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0iooooo`?o00000oooool00ol0003oooooooooo`2Zooooo`00JOooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool00ol0002]
ooooo`00J_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool0/?ooool006[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0iooooo`03
o`000?oooooooooo0;3ooooo001Zooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
>Oooool2o`000;7ooooo001Zooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0>_oo
ool00ol0003oooooooooo`2`ooooo`00J_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool0/?ooool006_ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0jooooo`03o`000?oooooooooo0;3ooooo001[ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`2`ooooo`00Joooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0/?ooool006cooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;3ooooo001/
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0>oooool2o`000;7ooooo001/oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2`oooo
o`00K?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool0/?ooool006cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Pooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c006oooo
o`03o`000?oooooooooo0;3ooooo001]ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool08Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S801_ooool00ol0003oooooooooo`2`ooooo`00KOooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo027ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0/?ooool006gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Qooooo`05o`000?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`05
ooooo`?o0000/?ooool006gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Qoooo
o`05o`000?ooooooooooooooool000003Oooool00ol@413o0000okZj^P06ooooo`03o`000?oooooo
oooo0;3ooooo001]ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08Oooool01Ol@
413ooooooooooooooooo410@00kooooo00?o^[Zjob4Q8Oooool01Oooool00ol0003oooooooooo`2`
ooooo`00K_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003ooooooooo
o`2`ooooo`00K_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003ooooo
ooooo`2`ooooo`00Koooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03gooooo00?o
0000ooooooooool0/?ooool006oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0m
ooooo`;o0000/Oooool006oooooo00Co0000oooooooooooooooo0_l00010ooooo`03o`000?oooooo
oooo0;3ooooo001`ooooo`04o`000?ooooooooooo`00047ooooo00?o0000ooooooooool0/?ooool0
077ooooo0_l00012ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooo
oooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol00006ooooo`?o0000/?ooool009[ooooo00Go0000ooooooooooooooooo`00000;
ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0
/?ooool009[ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo
00?o0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^
k_m4A4Co000000Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`
ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooa0@400@
ooooo`03o`000?oooooooooo00?ooooo0ol0002`ooooo`00V_ooool01Ol0003ooooooooooooooooo
000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol0
003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oo
oooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00[?ooool00ol0003o^[Zjooooo`2iooooo`00[?ooool2oc8b<[[ooooo
001mooooo`;o000000Ko410@oooooooooooo410@o`000?l@410Hooooo`Co000000Go410@oooooooo
ooooooooodA4A002o`000007oc8b<_oMgMgooooooooooon7QhOo0000okZj^P0<ooooo`05oiRHV?l0
003o0000odA4A?nj^[X06_ooool2o`000004oa0@4?ooooooooooooooo`Go00000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1cooooo`00O_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l0000<ooooo`03o`000?oooooooooo
00Kooooo00OoMgMgoc8b<_ooooooooooolc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMg
oa0@4009ooooo`Ko00003?ooool00ol0003oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1c
ooooo`00O_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01[ooooo1Ol00004oooo
o`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo
ooooooooool@4100Loooool007kooooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko0000
3?ooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo013ooooo00?o0000ooooooooool0
2oooool6o`0000Wooooo00CoA4A4omgMgOoooooo00001_ooool00onHV9So8B4Qonk^kP03ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000007?ooooo001noooo
o`06o`000?oMgMgo<S8boeEEEOoMgMgo00006oooool00ol0003oooooooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`04Oooool00ol0003oooooooooo`0Jooooo`04omgMgOmEEEGoooooo`0000Oo
oooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`00001cooooo`00O_ooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001_ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03oa0@4?l0003o000000?o00006_oo
ool00omgMgOoc<c<o`000008ooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool0LOooool007kooooo00Ko0000oc8b<_oooooo
oooooc8b<_l0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000000Cooooo00Go0000okZj^_ooooooV9RHoa0@4003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg07?ooooo
001mooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool00omEEEGoIVIVo`00
0005ooooo`Co00004_ooool00ol0003oooooooooo`0Looooo`03ogMgMol0003ooooo00?ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^07?ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4300) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 8e-05 m
.02846 .00068 L
.03068 .00094 L
.03279 .00114 L
.03398 .00124 L
.03527 .00133 L
.03645 .00139 L
.03754 .00143 L
.03871 .00146 L
.04 .00147 L
.04065 .00147 L
.04135 .00146 L
.04262 .00142 L
.04393 .00136 L
.04516 .00128 L
.04793 .00103 L
.05037 .00075 L
.05297 .00039 L
s
.05297 .00039 m
.05547 0 L
s
.0916 0 m
.09492 .00055 L
.09753 .00093 L
.09998 .00123 L
.10219 .00143 L
.10343 .00152 L
.10458 .00158 L
.10572 .00162 L
.10679 .00163 L
.10797 .00163 L
.10923 .0016 L
.11055 .00154 L
.1118 .00146 L
.11415 .00125 L
.11675 .00094 L
.11916 .00058 L
s
.11916 .00058 m
.12263 0 L
s
.15665 0 m
.16058 .00073 L
.16314 .00117 L
.16545 .00153 L
.16746 .00178 L
.16963 .002 L
.17083 .00209 L
.17193 .00215 L
.17298 .00219 L
.17409 .00222 L
.17521 .00223 L
.17641 .00221 L
.17755 .00218 L
.17858 .00214 L
.1798 .00207 L
.18112 .00197 L
.18352 .00175 L
.19292 .00064 L
.1952 .00041 L
.1964 .0003 L
.19766 .00021 L
.19834 .00017 L
.19907 .00014 L
.20037 9e-05 L
.20168 8e-05 L
.20291 9e-05 L
.20358 .0001 L
.20432 .00013 L
.20501 .00017 L
.20565 .00021 L
.20686 .0003 L
.20814 .00044 L
.21081 .00081 L
.21374 .00136 L
.21893 .00264 L
.22378 .00408 L
.24233 .00977 L
.25213 .01282 L
.25761 .0151 L
.26257 .01787 L
.26822 .02217 L
.27354 .02757 L
.27884 .03447 L
.28372 .04225 L
.29337 .06216 L
.30381 .09132 L
.31356 .127 L
.32265 .16809 L
.33327 .22314 L
.34332 .27528 L
Mistroke
.34805 .2968 L
.35308 .31567 L
.3557 .32344 L
.35709 .32692 L
.35859 .33012 L
.35996 .33253 L
.36122 .33431 L
.36242 .3356 L
.36369 .33653 L
.36485 .33699 L
.36591 .33707 L
.36713 .33677 L
.36828 .3361 L
.36935 .33514 L
.37033 .33398 L
.37256 .33037 L
.3748 .32539 L
.37727 .31846 L
.38225 .30027 L
.40334 .19167 L
.41334 .14324 L
.42261 .10788 L
.43215 .08096 L
.44254 .05987 L
.4517 .04642 L
.45682 .04082 L
.46145 .03701 L
.46379 .03559 L
.46635 .03444 L
.46764 .03402 L
.46835 .03384 L
.46902 .0337 L
.47033 .03352 L
.47151 .03345 L
.47263 .03348 L
.47382 .0336 L
.47483 .03379 L
.47594 .03407 L
.47714 .03446 L
.47843 .03499 L
.48075 .03623 L
.48342 .03806 L
.48633 .04054 L
.49163 .04623 L
.50159 .06033 L
.5119 .0791 L
.52126 .10039 L
.54223 .16658 L
.55237 .20373 L
.55791 .22254 L
Mistroke
.56308 .23772 L
.5675 .24808 L
.56977 .25231 L
.57223 .25597 L
.57363 .25759 L
.57493 .25879 L
.57617 .25967 L
.57749 .2603 L
.57866 .26061 L
.57976 .26067 L
.58097 .2605 L
.58228 .26002 L
.58345 .25934 L
.5847 .25835 L
.58695 .25591 L
.58963 .25195 L
.59207 .24741 L
.60238 .22023 L
.62082 .1561 L
.63092 .12206 L
.64161 .09083 L
.65152 .06709 L
.66079 .04934 L
.66961 .03621 L
.6791 .02578 L
.68449 .02132 L
.68962 .0179 L
.69467 .01519 L
.69924 .01316 L
.70885 .00983 L
.71908 .00703 L
.72803 .00491 L
.73747 .00298 L
.74227 .00218 L
.74752 .00148 L
.74983 .00125 L
.7523 .00104 L
.75463 .00088 L
.75675 .00078 L
.75804 .00073 L
.75875 .00071 L
.75942 .0007 L
.76059 .00068 L
.76188 .00067 L
.76256 .00066 L
.76328 .00067 L
.76456 .00068 L
.76528 .00068 L
.76594 .0007 L
.76745 .00073 L
Mistroke
.77002 .0008 L
.77235 .00089 L
.77758 .0011 L
.78009 .00119 L
.78244 .00127 L
.78372 .0013 L
.78489 .00133 L
.78619 .00135 L
.7869 .00136 L
.78758 .00136 L
.78869 .00137 L
.78987 .00136 L
.79088 .00136 L
.79199 .00134 L
.79318 .00132 L
.79447 .00128 L
.79679 .00119 L
.79932 .00106 L
.80208 .00088 L
.80764 .00045 L
.81242 4e-05 L
Mfstroke
.81242 4e-05 m
.81289 0 L
s
.84604 0 m
.84736 9e-05 L
.85005 .00027 L
.85293 .00044 L
.85432 .00051 L
.85564 .00057 L
.85684 .00061 L
.85812 .00065 L
.85925 .00067 L
.8605 .00068 L
.86164 .00069 L
.86271 .00068 L
.86396 .00067 L
.86511 .00064 L
.86637 .0006 L
.86769 .00055 L
.87029 .00042 L
.87271 .00027 L
s
.87271 .00027 m
.87637 0 L
s
.90844 0 m
.91127 .00027 L
.91653 .00075 L
.91874 .00091 L
.9211 .00105 L
.92246 .00111 L
.9237 .00115 L
.92494 .00117 L
.92612 .00118 L
.92718 .00117 L
.92831 .00115 L
.92928 .00113 L
.93034 .00109 L
.93148 .00103 L
.93271 .00096 L
.93493 .0008 L
s
.93493 .0008 m
.94232 0 L
s
.97556 0 m
.97613 7e-05 L
.97619 8e-05 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`05o`0000Cooooo00?o0000oooooooo
ool02?ooool6o`0000Sooooo00?o0000ooooooooool00oooool8o`0000Oooooo1_l00009ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`Ko
00001oooool7o`0000Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Gooooo0ol000000ooooooo0000ooooo`0:ooooo`03o`000?oooooooooo023o
oooo000Tooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool03?ooool3o`0001kooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00kooooo
1_l0000Iooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool08?ooool006Oooooo0ol0
001;ooooo`03o`000?oooooooooo03_ooooo0ol0001booooo`00J_ooool00ol0003oooooooooo`18
ooooo`03o`000?oooooooooo03Wooooo0_l0001eooooo`00Joooool2o`0004Sooooo00?o0000oooo
ooooool0=oooool2o`0007Oooooo001]ooooo`;o0000A_ooool2o`0003Oooooo00?o0000oooooooo
ool0Moooool006oooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0dooooo`;o0000
N_ooool006oooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo07[ooooo001`ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`1kooooo`00LOooool00ol0003oooooooooo`0gooooo`?o00001oooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo07cooooo001booooo`03o`000?oooooooooo03Co
oooo0ol00002ooooo`;o00001Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo07go
oooo001booooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01?ooool2o`0000?ooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1mooooo`00Loooool00ol0003ooooooooo
o`0aooooo`;o00002?ooool01?l0003oooooooooooooool2o`00033ooooo00?o0000ooooooooool0
O_ooool007?ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`09ooooo`04o`000?oo
ooooooooo`00037ooooo00?o0000ooooooooool0O_ooool007Cooooo00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`00033ooooo00?o0000ooooooooool0
Ooooool007Cooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooo0000033ooooo00?o0000ooooooooool0Ooooool007Gooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`0=ooooo`;o0000;oooool00ol0003oooooooooo`20ooooo`00MOooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`20ooooo`00M_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00oo
oooo0_l0000]ooooo`03o`000?oooooooooo087ooooo001fooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool04?ooool2o`0002gooooo00?o0000ooooooooool0POooool007Oooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`0@ooooo`;o0000;?ooool00ol0003ooooooooo
o`22ooooo`00Moooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo017ooooo00?o0000
ooooool00000:oooool00ol0003oooooooooo`22ooooo`00Moooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo017ooooo00?o0000ooooool00000:_ooool00ol0003oooooooooo`23oooo
o`00N?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo017ooooo00Co0000oooooooo
oooo0000:Oooool00ol0003oooooooooo`23ooooo`00N?ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01;ooooo0_l000000ooooooo0000ooooo`0Wooooo`03o`000?oooooooooo08Co
oooo001hooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04_ooool01Ol0003ooooo
oooooooooooo000002Oooooo00?o0000ooooooooool0Q?ooool007Wooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0Cooooo`05o`000?ooooooooooooooool000009oooool00ol0003o
ooooooooo`24ooooo`00NOooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo08Gooooo
001iooooo`03o`000?oooooooooo01kooooo00Kok^k^oc8b<_l0003o<S8bonk^k_l00004ooooo`;o
8B4Q1Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo08Gooooo001iooooo`03o`000?oooooooooo01kooooo
00GoMgMgoiRHV?ooooooV9RHo`000005ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`26ooooo`00
N_ooool00ol0003oooooooooo`0Mooooo`05oa0@4?ooooooooooooooool000003_ooool00ol0003o
ooooooooo`05ooooo`?o00000oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo08Ko
oooo001jooooo`03o`000?oooooooooo01gooooo00Go0000ooooooooooooooooo`00000>ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo08Kooooo001jooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
0_l0000>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo08Oooooo001kooooo`03o`000?oooooooooo01cooooo00Go
410@oooooooooooo0000oa0@400>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo08Oooooo001kooooo`03o`000?oo
oooooooo01cooooo00GoMgMgoiRHV?oooooo0000ogMgM`0>ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo08Oooooo
001kooooo`03o`000?oooooooooo01cooooo00Gok^k^oc8b<_l0003o0000onk^kP0<ooooo`03oeEE
EOmVIVKo000000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo08Sooooo001kooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0R?oo
ool007cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Fooooo`;o00001_ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo08Sooooo001looooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool0R?ooool007cooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`29ooooo`00O?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo08Wooooo
001mooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0ROooool007gooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`2:ooooo`00OOooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo01Oooooo0_l00008ooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool0R_ooool007gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`2:ooooo`00
O_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo08[ooooo001nooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool0Roooool007kooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`2;ooooo`00O_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
08_ooooo001oooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06?ooool2o`0000[o
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`2;ooooo`00Ooooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo08cooooo001oooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0S?ooool007oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2<
ooooo`00Ooooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo08gooooo0020ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool0SOooool0083ooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0Iooooo`;o00003?ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo08gooooo0020ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0S_oo
ool0083ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`2>ooooo`00P?ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo08kooooo0021ooooo`03o`000?oooooooooo01Co
oooo00Oo0000ooooooo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Soooool0
087ooooo00?o0000ooooooooool04oooool02?l0003ooooooooooomgMgOoV9RHoooooonHV9SoMgMg
1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2?ooooo`00POooool00ol0003ooooo
ooooo`0Cooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool02_ooool00onHV9So
8B4Qonk^kP07ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`2?ooooo`00POooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0000?o
oooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06ooooo`?o00003Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo093ooooo0021ooooo`03o`000?oooooooooo01?ooooo
00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo093o
oooo0021ooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo410@0oooool00ol@413o
ooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo093ooooo0022ooooo`03o`000?oooooooooo017ooooo
00Wo0000ooooooooooooooooogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonH
V9So410@00Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo097ooooo0022ooooo`03o`000?oooooooooo017ooooo00Wo0000ooooooooooooooooonk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo097ooooo0022ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0TOooool008;ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Looooo`;o00003oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo09;ooooo0022ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0T_oo
ool008;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Booooo`00Poooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo09?ooooo0023ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0Toooool008?ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`2Cooooo`00Poooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01kooooo0_l0
000Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0U?ooool008?ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2Dooooo`00Q?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo09Gooooo0024ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0Cooooo`05o`000?ooooooooooooooool00000V?ooool008Co
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Co
oooo1?l0002Hooooo`00Q?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool0/?ooool008Cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0Oooooo`;o0000/Oooool008Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo0;3ooooo0025ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`2`ooooo`00QOooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool0/?ooool008Gooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0;3ooooo0026ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`2`ooooo`00Q_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0/?ooool0
08Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Pooooo`;o0000/Oooool008Oo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0;3o
oooo0027ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`2`ooooo`00Qoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Ko
oooo00?o0000ooooooooool0/?ooool008Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`06ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go410@okZj^_oo
ooooMgMgoc8b<P06ooooo`03o`000?oooooooooo0;3ooooo0027ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`2`ooooo`00R?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ojVYZOl@413ooooo
00Gooooo0ol0002`ooooo`00R?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oo
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oa0@4?l0003o^[Zj00Kooooo00?o0000oooo
ooooool0/?ooool008Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`05
oa0@4?ooooooooooooooool@41003_ooool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo
0;3ooooo0028ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooo
oooo0;3ooooo0029ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oo
oooooooo0;3ooooo002:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`2`ooooo`00R_ooool01Ol0003ooooooooooooooooo000002Kooooo0_l0002a
ooooo`00R_ooool01Ol0003ooooooooooooooooo000002Kooooo00?o0000ooooooooool0/?ooool0
08_ooooo1?l0000Vooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@
413oooooooooo`04ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2`oooo
o`00V_ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`?o0000/?ooool009[o
oooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000
ooooooooool0/?ooool009[ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0000Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0/?ooool009[ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0/?oo
ool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000
/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009[o
oooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00V_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`2`ooooo`00V_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Joooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool00ol0003o^[Zj
ooooo`2iooooo`00[?ooool2oc8b<[[ooooo001mooooo`;o000000Ko410@oooooooooooo410@o`00
0?l@410Hooooo`Co000000Go410@ooooooooooooooooodA4A002o`000007oc8b<_oMgMgooooooooo
oon7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06_ooool2o`000009oa0@4?oo
oooooooooooooonHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0Loooool007kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`07ooooo`Ko00003?ooool00ol0003oooooooooo`06ooooo`07ogMgMolb<S;o
ooooooooooo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000co
oooo00?o0000ooooooooool00_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Loooool007kooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0Jooooo`Go00001oooool01Ol0003ooooooooooooo
oooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo077ooooo
001nooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000cooooo00?o0000oooooooo
ool01_ooool00omgMgOo<S8booooo`0@ooooo`03o`000?oooooooooo00_ooooo1_l00009ooooo`04
odA4A?oMgMgoooooo`0000Oooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`00001cooooo`00O_ooool01_l0003ogMgMoc8b<_mE
EEGogMgMo`0001_ooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<017o
oooo00?o0000ooooooooool06_ooool01?oMgMgoEEEEooooool00006ooooo`03oa0@4?l0003o^[Zj
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000Looo
ool007kooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Kooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool04Oooool00ol@413o0000o`000003o`0001[ooooo00?oMgMgolc<c?l00000
1oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@07?ooooo001nooooo`06o`000?lb<S;ooooooooooolb<S;o00006oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool06oooool0
0oo^k^koA4A4o`000004ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1cooooo`00OOooool00ol@413o0000
ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo00?oEEEEofIVI_l000001Oooool4o`0001;ooooo
00?o0000ooooooooool07?ooool00omgMgOo0000ooooo`03ooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1c
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4400) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.0381 0 m
.04262 .0003 L
.04517 .00044 L
.04758 .00053 L
.0489 .00057 L
.05012 .0006 L
.05076 .00061 L
.05146 .00062 L
.05219 .00063 L
.05288 .00063 L
.05412 .00063 L
.05529 .00062 L
.05634 .00061 L
.05749 .00058 L
.05873 .00055 L
.06006 .00051 L
.06244 .00041 L
s
.06244 .00041 m
.06926 0 L
s
.11596 0 m
.11937 .0002 L
.12195 .00032 L
.12432 .00042 L
.12656 .0005 L
.12769 .00052 L
.12894 .00055 L
.13019 .00057 L
.13089 .00057 L
.13152 .00058 L
.13277 .00058 L
.13394 .00057 L
.135 .00056 L
.13612 .00055 L
.13717 .00052 L
.13813 .0005 L
.14048 .00043 L
.14269 .00034 L
s
.14269 .00034 m
.14921 0 L
s
.18335 0 m
.18615 .00019 L
.1914 .00055 L
.19382 .00069 L
.19637 .00081 L
.19855 .00089 L
.19978 .00092 L
.20094 .00094 L
.20162 .00095 L
.20236 .00096 L
.20306 .00096 L
.20371 .00096 L
.20494 .00095 L
.20624 .00092 L
.20691 .00091 L
.20764 .00089 L
.20895 .00084 L
.21193 .0007 L
.21713 .00035 L
s
.21713 .00035 m
.22156 0 L
s
.25069 0 m
.25142 7e-05 L
.2615 .00123 L
.2665 .00175 L
.26903 .00195 L
.27179 .00212 L
.27324 .00219 L
.27404 .00222 L
.27479 .00224 L
.27549 .00226 L
.27626 .00227 L
.27695 .00228 L
.27759 .00229 L
.27882 .00229 L
.27952 .00229 L
.28018 .00228 L
.2815 .00226 L
.28224 .00224 L
.28292 .00223 L
.28798 .00204 L
.29076 .00193 L
.29338 .00183 L
.29457 .00179 L
.29582 .00176 L
.29648 .00175 L
.2972 .00174 L
.29847 .00174 L
.29962 .00175 L
.30086 .00177 L
.30203 .00181 L
.3031 .00186 L
.30427 .00194 L
.30551 .00204 L
.30775 .00227 L
.31041 .00266 L
.31282 .00311 L
.31757 .00431 L
.32204 .0058 L
.33199 .01026 L
.34274 .01657 L
.35228 .02354 L
.36273 .03371 L
.36801 .0405 L
.37365 .04955 L
.38382 .07201 L
.38913 .08752 L
.39403 .10438 L
.40511 .15121 L
.42525 .25291 L
.43427 .29269 L
Mistroke
.43933 .30979 L
.44174 .31617 L
.44397 .32098 L
.44534 .32336 L
.44658 .32515 L
.44795 .32669 L
.44871 .32734 L
.44942 .32783 L
.45072 .32838 L
.45192 .32852 L
.45323 .32827 L
.45389 .32797 L
.45461 .32752 L
.45592 .32639 L
.4571 .32499 L
.45977 .32059 L
.46225 .31502 L
.46459 .3085 L
.47424 .27096 L
.48449 .21956 L
.50291 .13116 L
.51227 .09901 L
.51754 .08547 L
.52237 .07567 L
.52662 .06885 L
.53127 .06304 L
.53362 .06068 L
.53613 .05855 L
.54065 .05561 L
.54323 .05442 L
.54454 .05396 L
.54597 .05355 L
.54719 .05329 L
.54851 .0531 L
.54975 .05301 L
.55088 .053 L
.55157 .05303 L
.55229 .05309 L
.5536 .05328 L
.55441 .05344 L
.55516 .05363 L
.55657 .05409 L
.55917 .05525 L
.56198 .05703 L
.56442 .05902 L
.56709 .06171 L
.57248 .06883 L
.57747 .07751 L
.58213 .08739 L
.60251 .14794 L
Mistroke
.62108 .21293 L
.6259 .22787 L
.63101 .24156 L
.63538 .25097 L
.63772 .255 L
.64019 .25839 L
.64148 .2598 L
.64289 .26104 L
.64417 .26189 L
.64535 .26244 L
.64608 .26266 L
.64676 .26279 L
.64804 .26282 L
.64876 .26272 L
.64942 .26255 L
.65014 .26227 L
.65091 .26189 L
.65211 .26109 L
.65339 .25996 L
.6557 .25725 L
.65845 .25289 L
.66096 .2479 L
.67086 .22023 L
.68002 .18709 L
.69071 .14645 L
.70076 .11214 L
.71048 .08515 L
.7194 .06559 L
.7293 .04827 L
.73999 .03328 L
.74977 .02253 L
.75445 .01846 L
.75888 .01532 L
.76411 .01245 L
.76887 .01057 L
.77154 .00978 L
.774 .00919 L
.77957 .00821 L
.78936 .00696 L
.79989 .00518 L
.80899 .00308 L
.8138 .00194 L
.81892 .00089 L
.82168 .00044 L
.82418 .00011 L
Mfstroke
.82418 .00011 m
.82526 0 L
s
.83876 0 m
.84801 .00096 L
.85024 .0012 L
.85258 .00142 L
.85475 .00159 L
.85677 .00172 L
.85781 .00176 L
.85893 .0018 L
.86017 .00182 L
.86129 .00183 L
.8625 .00182 L
.8638 .00179 L
.86503 .00175 L
.86617 .00169 L
.86857 .00153 L
.87121 .00129 L
.87655 .00066 L
s
.87655 .00066 m
.88161 0 L
s
.91262 0 m
.91701 .00048 L
.91953 .00074 L
.92224 .00097 L
.92356 .00107 L
.9248 .00115 L
.92594 .00121 L
.92715 .00127 L
.92842 .00131 L
.92959 .00133 L
.93032 .00134 L
.931 .00134 L
.93227 .00133 L
.93295 .00132 L
.93368 .00131 L
.93497 .00127 L
.93637 .00121 L
.9379 .00112 L
s
.9379 .00112 m
.95787 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02?oooolCo`0000Kooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Kooooo1?l00009ooooo`So00001_ooool00ol0003o
ooooooooo`06ooooo`Oo00002?ooool00ol0003oooooooooo`0Pooooo`009?ooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo02Oooooo0ol00003ooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Tooooo`Ko00000oooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo023ooooo0022ooooo`;o0000<Oooool00ol0003ooooooooo
o`1>ooooo`Ko0000G?ooool008Cooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1<
ooooo`;o0000H_ooool008Gooooo0_l0000^ooooo`03o`000?oooooooooo04_ooooo00?o0000oooo
ooooool0H_ooool008Oooooo00?o0000ooooooooool0:oooool2o`0004_ooooo00?o0000oooooooo
ool0Hoooool008Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`19ooooo`03o`00
0?oooooooooo06Cooooo0029ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0B?oo
ool00ol0003oooooooooo`1Uooooo`00R_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo04Oooooo00?o0000ooooooooool0I_ooool008_ooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`16ooooo`03o`000?oooooooooo06Oooooo002<ooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`1Wooooo`00SOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0J?ooool008gooooo00?o
0000ooooooooool09Oooool2o`0004Gooooo00?o0000ooooooooool0JOooool008kooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo06[ooooo002?oooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`1[oooo
o`00Soooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00_ooooo1?l0000cooooo`03
o`000?oooooooooo06_ooooo002@ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
2Oooool2o`0000?ooooo0ol0000`ooooo`03o`000?oooooooooo06cooooo002@ooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool0KOooool0097ooooo00?o0000ooooooooool08Oooool2
o`0000Oooooo0_l00009ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0KOooool0
097ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1^ooooo`00TOooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo06kooooo002Booooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool0Koooool009;ooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`1_ooooo`00T_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo06oooooo002Coooo
o`03o`000?oooooooooo01oooooo0_l00004ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`1`ooooo`00Toooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo073ooooo002Cooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
L?ooool009?ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1aooooo`00U?ooool0
0ol0003oooooooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l0
00000ol@413oooooooooo`03ooooo`05o`000?ooooooooooooooool000005Oooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo077ooooo002Dooooo`03o`000?oooooooooo00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`05o`00
0?ooooooooooooooool000005Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo077o
oooo002Dooooo`03o`000?oooooooooo00?ooooo00Go410@oooooooooooooooooa0@400>ooooo`03
o`000?oooooooooo00Gooooo0ol000000ooooooo0000ooooo`0Dooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool0L_ooool009Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000kooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo0000
01Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1booooo`00UOooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`05oooo
o`04o`000?ooooooooooo`0001Oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1b
ooooo`00UOooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41003_ooool0
0ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0001Oooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`1cooooo`00U_ooool02Ol0003oooooooooooooooooMgMgoiRHV?oooooo
V9RHogMgM`0>ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00006?ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo07?ooooo002Fooooo`09o`000?oooooooooooooo
ooo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001oooool00ol0003oooooo`00
000Iooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0Loooool009Kooooo00?o0000
ooooooooool07?ooool00ol0003oooooo`00000Iooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool0M?ooool009Kooooo00?o0000ooooooooool07?ooool3o`0001[ooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`1dooooo`00U_ooool00ol0003oooooooooo`0Looooo`;o
00006oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo07Cooooo002Gooooo`03o`00
0?oooooooooo01_ooooo0_l0000Kooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
MOooool009Oooooo00?o0000ooooooooool06oooool2o`0001cooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`1eooooo`00Uoooool00ol0003oooooooooo`0Kooooo`;o00007?ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo07Gooooo002Gooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
07Gooooo002Gooooo`03o`000?oooooooooo01_ooooo0_l0000Mooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool0M_ooool009Sooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0M_ooool009Sooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool0M_ooool009Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0M_ooool009Sooooo00?o0000oooo
ooooool06Oooool2o`0001oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1goooo
o`00V?ooool00ol0003oooooooooo`0Iooooo`;o00007oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo07Oooooo002Iooooo`03o`000?oooooooooo01Sooooo0ol0000Nooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0Moooool009Wooooo00?o0000ooooooooool06?oo
ool2o`00023ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1gooooo`00VOooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooo0000023ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`1hooooo`00VOooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo0000
023ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1hooooo`00VOooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooo0000027ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`1hooooo`00V_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo0000027ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`1hooooo`00V_ooool00ol0003ooooooooo
o`0Fooooo`04o`000?oooooo0000o`00023ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`1iooooo`00V_ooool00ol0003oooooooooo`0Eooooo`04o`000?ooooooooooo`00027ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`1iooooo`00V_ooool00ol0003ooooooooo
o`0Eooooo`04o`000?ooooooooooo`0002;ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`1iooooo`00V_ooool00ol0003oooooooooo`0Eooooo`04o`000?ooooooooooo`0002;ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`1iooooo`00V_ooool01Oo^k^ko0000o`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00000oooool01?l0003oooooooooool0000Rooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool0N_ooool009[ooooo00GoMgMgo`000?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400;ooooo00Go0000oooo
ooooooooooooo`00000Sooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0N_ooool0
09[ooooo00Go410@o`000?oooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000
ooooooooooooooooo`00000Sooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0N_oo
ool009[ooooo0_l00002ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h00_ooool0
1?l0003oooooooooooooool3o`00027ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`1kooooo`00V_ooool2o`0000;ooooo00?o0000ooooooooool03?ooool01OmgMgOoIVIVoooooooo
oooo000000?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo07_ooooo002Jooooo`05oa0@4?oooooo0000ooooool@41003oooool01?l0003ooooooooo
ool00003ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`1kooooo`00V_ooool01OmgMgOoV9RHo`000?nHV9SoMgMg00_ooooo00Oo0000okZj^_oooooo
V9RHoa0@4?oooooo000000Cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo07cooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01onH
V9So410@o`000?lQ8B7oc<c<ooooool000001?ooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0O?ooool009cooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`1looooo`00W?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
00;ooooo0_l0000Tooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0OOooool009go
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1mooooo`00WOooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo07gooooo002Mooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0O_ooool009gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1n
ooooo`00WOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07kooooo002Nooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool2o`0002Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`1oooooo`00W_ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo07oooooo002Nooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0P?oo
ool009kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`21ooooo`00W_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09oooool2o`00
00;ooooo00?o0000ooooooooool0P_ooool009oooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo02Wooooo0ol00024ooooo`00Woooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00Gooooo0_l0002aooooo`00Woooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool009oooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;3ooooo002Poooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2`oooo
o`00X?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0/?ooool00:3ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo0;3ooooo002Pooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`2`ooooo`00XOooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Kooooo0_l0002aooooo`00XOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0/?ooool00:7ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00_ooool00ol0003oooooooooo`02ob4Q8@Cooooo00GoV9RHo`000?l0003o<S8bolc<c006oooo
o`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01?l0
003oooooob4Q8OlQ8B44ooooo`05oa0@4?l0003oooooogMgMolb<S801_ooool00ol0003ooooooooo
o`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@00?ooooo00?o0000ooooooooool01Ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0/?ooool009[ooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooooooo
ZJVYoa0@4006ooooo`?o0000/?ooool009[ooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo00Gooooo00Go0000ooooool@413o0000okZj^P06ooooo`03o`000?oooooooooo
0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41001?ooool00ol0003oooooooooo`03oooo
o`06o`000?oooooooooooooooonj^[[o8B4Q1_ooool00ol0003oooooooooo`2`ooooo`00V_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000ooooooooool00oooool01_l0003o410@oiRH
V?oooooo^[Zjo`0000Kooooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Ko0000ojVYZOl@413o0000oa0@4?nYZJT6
ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`04o`000?ooooooooooo`0000cooooo00?o0000
ooooooooool0/?ooool00:Kooooo0_l0000=ooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@
4?oooooooooo00Cooooo00?o0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;3ooooo
002Jooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol0002`ooooo`00V_oo
ool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`2`ooooo`00V_ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoo
oooo00001oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@
00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`oooo
o`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0
003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002a
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8b
omgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00V_oo
ool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000;3ooooo
002Jooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aoooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002/ooooo`03o`000?nj^[[o
oooo0;Wooooo002/ooooo`;o<S8b^_ooool007gooooo0_l000001_l@413oooooooooool@413o0000
oa0@41Sooooo1?l000001Ol@413oooooooooooooooooA4A400;o000000Oo<S8bomgMgOoooooooooo
ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Jooooo`;o000000?o410@oooo
ooooool00oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP1cooooo`00O_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Oooooo1_l0000<ooooo`03o`000?oooooooooo00Kooooo00OoMgMgoc8b<_oooooo
ooooolc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Loooool007kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Jooooo`Go00000oooool5o`0000?ooooo00Go410@oooooooooooooooo
oa0@4003ooooo`05oa0@4?ooooooooooooooool@4100Loooool007kooooo00Ko0000oooooom4A4Co
A4A4ooooool00009ooooo`Ko00003?ooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo
013ooooo00?o0000ooooooooool02oooool6o`0000Wooooo00CoA4A4omgMgOoooooo00001?ooool0
1?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000007?ooooo001nooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo00006oooool00ol0
003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`04Oooool00ol0003oooooooooo`0J
ooooo`04omgMgOmEEEGoooooo`0000Cooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00001cooooo`00O_ooool01_l0003o
QhN7ojVYZOnj^[[oEEEEo`0001_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0A
ooooo`03oa0@4?l0003o000000?o00006_ooool00omgMgOoc<c<o`000005ooooo`03ogMgMoo<c<co
000000Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100
Loooool007kooooo00Ko0000oc8b<_oooooooooooc8b<_l0000Kooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Kooooo`03onk^k_m4A4Co000000Go
oooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`1cooooo`00OOooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@
01Sooooo00?oEEEEofIVI_l000001Oooool4o`0001;ooooo00?o0000ooooooooool07?ooool00omg
MgOo0000ooooo`05ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0Loooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4500) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .00162 m
.03279 .00012 L
s
.03279 .00012 m
.03339 0 L
s
.06974 0 m
.07295 .00068 L
.07545 .00115 L
.0781 .00157 L
.08036 .00184 L
.08164 .00196 L
.08284 .00204 L
.08355 .00208 L
.08432 .0021 L
.08504 .00212 L
.08572 .00212 L
.08699 .00211 L
.08763 .00209 L
.08834 .00206 L
.08911 .00202 L
.08981 .00197 L
.09138 .00182 L
.09424 .00145 L
.09928 .00055 L
s
.09928 .00055 m
.10194 0 L
s
.13626 0 m
.14269 .00131 L
.14494 .00168 L
.14736 .00199 L
.14874 .00212 L
.15001 .00222 L
.15128 .00228 L
.15248 .00231 L
.15373 .00232 L
.15436 .00231 L
.15505 .00229 L
.15628 .00223 L
.15743 .00215 L
.15878 .00203 L
.16002 .00189 L
.16281 .0015 L
s
.16281 .0015 m
.17069 0 L
s
.20478 0 m
.2051 6e-05 L
.21022 .0009 L
.21289 .00125 L
.21431 .0014 L
.21582 .00153 L
.21654 .00158 L
.21722 .00162 L
.21849 .00168 L
.21968 .00171 L
.22097 .00172 L
.22217 .00171 L
.2233 .00167 L
.22454 .00161 L
.22588 .00153 L
.2286 .00127 L
.23108 .00097 L
s
.23108 .00097 m
.23754 0 L
s
.27179 0 m
.27734 .00076 L
.27975 .00102 L
.28235 .00126 L
.28383 .00136 L
.2852 .00144 L
.2865 .00149 L
.28716 .00151 L
.28787 .00153 L
.28915 .00154 L
.29031 .00154 L
.29096 .00153 L
.29165 .00152 L
.29292 .00148 L
.29411 .00144 L
.29536 .00137 L
.29761 .00123 L
.30774 .0003 L
s
.30774 .0003 m
.31115 0 L
s
.33692 0 m
.339 .00015 L
.35727 .00145 L
.36766 .00199 L
.37274 .00229 L
.3774 .00261 L
.38695 .00353 L
.39222 .00422 L
.39722 .00504 L
.40728 .00728 L
.41297 .00906 L
.41825 .01118 L
.42332 .01374 L
.42881 .01721 L
.43876 .02574 L
.44845 .03741 L
.45737 .05189 L
.4671 .0731 L
.47618 .09949 L
.48615 .13695 L
.49684 .18595 L
.50701 .23604 L
.51237 .26097 L
.51807 .28422 L
.52304 .30042 L
.52587 .30755 L
.52716 .31024 L
.52852 .31269 L
.52968 .31443 L
.53095 .31599 L
.5321 .31707 L
.53318 .31779 L
.53445 .31829 L
.5356 .31841 L
.53624 .31834 L
.53693 .31815 L
.53819 .3175 L
.53942 .31651 L
.54055 .31529 L
.54308 .31148 L
.54542 .30669 L
.54765 .30107 L
.55263 .28519 L
.55806 .26364 L
.5791 .16642 L
.58925 .12721 L
.5988 .10012 L
.60409 .08927 L
.60688 .08467 L
.60981 .08059 L
Mistroke
.61229 .07774 L
.61501 .07521 L
.61748 .07342 L
.61978 .07218 L
.62105 .07167 L
.62174 .07144 L
.62239 .07126 L
.62354 .07102 L
.6248 .07086 L
.62547 .07083 L
.62617 .07083 L
.62743 .07092 L
.62813 .07102 L
.62878 .07115 L
.63026 .07155 L
.63155 .07204 L
.63277 .07262 L
.63505 .07402 L
.63751 .07597 L
.64017 .07864 L
.64486 .0848 L
.64983 .09339 L
.65873 .11418 L
.66819 .14321 L
.67834 .17974 L
.68785 .21463 L
.69666 .24269 L
.70158 .2549 L
.7041 .25989 L
.70681 .26422 L
.70822 .26601 L
.70952 .26737 L
.71076 .2684 L
.71206 .26922 L
.71276 .26953 L
.7135 .26977 L
.7142 .26992 L
.71483 .26997 L
.71558 .26995 L
.71639 .26982 L
.71716 .26959 L
.71787 .26928 L
.71902 .2686 L
.72026 .26762 L
.72251 .26518 L
.72518 .26122 L
.72763 .25663 L
.73293 .24381 L
.73798 .22856 L
.75801 .15391 L
Mistroke
.77618 .09245 L
.78631 .0669 L
.79586 .04876 L
.80593 .03495 L
.81161 .02911 L
.81683 .02469 L
.83566 .01345 L
.84635 .00869 L
.85633 .00507 L
.86133 .0037 L
.86397 .00313 L
.86678 .00264 L
.86923 .00232 L
.87062 .00218 L
.87192 .00208 L
.87312 .00201 L
.87421 .00196 L
.87542 .00193 L
.87668 .00192 L
.87785 .00192 L
.8789 .00194 L
.88012 .00198 L
.88128 .00202 L
.88333 .00212 L
.88555 .00226 L
.89056 .00258 L
.893 .00272 L
.89417 .00277 L
.89524 .0028 L
.89636 .00283 L
.89758 .00285 L
.89866 .00285 L
.89981 .00284 L
.90044 .00282 L
.90113 .0028 L
.90238 .00275 L
.90359 .00268 L
.90471 .0026 L
.90713 .00238 L
.90978 .00205 L
.91512 .00119 L
.92078 .00013 L
Mfstroke
.92078 .00013 m
.92154 0 L
s
.95249 0 m
.9555 .0005 L
.96033 .00127 L
.96276 .00158 L
.96416 .00173 L
.96544 .00183 L
.96683 .00192 L
.9676 .00195 L
.96833 .00197 L
.96963 .00199 L
.97036 .00199 L
.97104 .00197 L
.97222 .00193 L
.97353 .00186 L
.9749 .00175 L
.97619 .00162 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool2o`0000[ooooo00Co0000oooooooooooooooo1ol000000ooo
oooo0000ooooo`0:ooooo`So00001Oooool00ol0003oooooooooo`06ooooo`Ko00002Oooool00ol0
003oooooooooo`03ooooo`Oo00002oooool00ol0003oooooooooo`0>o`0000Oooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09oooooa?o00001Oooool00ol0003oooooooooo`05oooo
o`Go00008_ooool002Cooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo00kooooo1?l0000Kooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`08ooooo`;o00008oooool00ol0003oooooooooo`0Pooooo`00
V_ooool2o`0001Wooooo00?o0000ooooooooool0IOooool3o`0004Sooooo002Looooo`?o00005_oo
ool00ol0003oooooooooo`1Rooooo`?o0000Boooool009oooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`1Qooooo`03o`000?oooooooooo04cooooo002Pooooo`03o`000?oooooooooo
01;ooooo0_l0001Pooooo`;o0000Coooool00:7ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`1Nooooo`03o`000?oooooooooo04oooooo002Rooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0G?ooool2o`0005;ooooo002Rooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0Foooool00ol0003oooooooooo`1Booooo`00Xoooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0D_ooool00:Cooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo05?ooooo002Uooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`1Cooooo`00
YOooool00ol0003oooooooooo`0=ooooo`;o0000F_ooool00ol0003oooooooooo`1Dooooo`00Y_oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0EOoo
ool00:Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooo
oooo05Kooooo002Xooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Eoooool00ol0
003oooooooooo`1Fooooo`00Z?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Ko
oooo00?o0000ooooooooool0Eoooool00:Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`1Eooooo`03o`000?oooooooooo05Sooooo002Yooooo`03o`000?oooooooooo00Wooooo0_l0
001Fooooo`03o`000?oooooooooo05Sooooo002Zooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0E?ooool00ol0003oooooooooo`1Iooooo`00Z_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0FOooool00:_ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Qooooo`Go0000;Oooool00ol0003oooooooooo`1Jooooo`00
Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
0oooool2o`0002_ooooo00?o0000ooooooooool0F_ooool00:cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`1Jooooo`00[?ooool00ol0003oooooooooo`06ooooo`;o00007oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Foooool0
0:cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1Kooooo`00[Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo05_ooooo002]ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0G?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0G?ooool009[ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool2o`0000Kooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
G?ooool009[ooooo00Go410@oooooooooooooooooa0@400>ooooo`;o00001_ooool3o`0001_ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo05gooooo
002Jooooo`05o`000?ooooooooooooooool000003_ooool2o`0000Kooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
GOooool009[ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooo000000Gooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool0GOooool009[ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`00
0?oooooo000000Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool0G_ooool009[ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0>ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0G_ooool009[ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`05oeEEEOmVIVKo0000ooooool000001Oooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`1Nooooo`00/?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05oooooo
002`ooooo`03o`000?oooooooooo00;ooooo0_l0000Jooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`1Oooooo`00/?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo05oooooo002`ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool0H?ooool00;7ooooo00Go0000ooooooooooooooooo`00000Jooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Pooooo`00/Oooool01Ol0003o
oooooooooooooooo000001Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo063ooooo002aooooo`05o`000?ooooooooooooooool000006Oooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0HOooool00;7o
oooo00Co0000oooooooooooooooo0_l0000Hooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`1Qooooo`00/_ooool01?l0003oooooooooool0000Ioooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1Qoooo
o`00/_ooool01?l0003oooooooooool0000Hooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`1Rooooo`00/_ooool01?l0003oooooooooool0000Hoooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1Roooo
o`00/_ooool01?l0003oooooooooool0000Hooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`1Rooooo`00/_ooool01?l0003oooooooooool0000Hoooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1Roooo
o`00/oooool01?l0003oooooo`000?l0000Fooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`1Sooooo`00/oooool00ol0003oooooo`00000Gooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Sooooo`00
/oooool00ol0003oooooo`00000Gooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`1Sooooo`00/oooool00ol0003oooooo`00000Gooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Sooooo`00/oooool0
0ol0003oooooo`00000Fooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`1Tooooo`00]?ooool2o`0001Kooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo06Cooooo002dooooo`?o00005Oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0I?ooool00;Cooooo
0_l0000Fooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`1Tooooo`00]?ooool2o`0001Gooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo06Gooooo002dooooo`;o00005Oooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0IOooool009[ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0IOooool0
09[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0I_ooool009[ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0I_ooool009[ooooo00Go0000
ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0000Booooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Vooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`1Vooooo`00V_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?oo
ool2o`0001?ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo06Oooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooo
oonHV9So410@00Kooooo0_l0000Booooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`1Wooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`;o00004_ooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool0Ioooool00;Gooooo0_l0000Booooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Wooooo`00]Ooo
ool2o`0001;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo06Sooooo002eooooo`03o`000?oooooo0000017ooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo06Sooooo002eooooo`03o`000?oooooo0000
013ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
06Sooooo002eooooo`03o`000?oooooo0000013ooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo06Sooooo002eooooo`03o`000?oooooo0000013ooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06Wooooo
002eooooo`03o`000?oooooo0000013ooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo06Wooooo002eooooo`;o000000?oooooo`000?ooool03Oooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0JOooool0
0;Gooooo00Co0000oooooooooooo00003_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0J_ooool00;Gooooo00Co0000oooooooooooo00003_ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0J_ooool0
0;Gooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1[ooooo`00]Oooool01Ol0003ooooooooooooooooo
000000cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo06cooooo002eooooo`05o`000?ooooooooooooooool000003?ooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0K?ooool00;Gooooo0_l00002oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0:oooool01Ol0003ooooooooooooooooo
000006oooooo002eooooo`05o`000?ooooooooooooooool000003?ooool00ol0003oooooooooo`0/
ooooo`?o0000L?ooool00;Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo09oooooo002eooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`2Pooooo`00]Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0X?ooool00;Gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0:3ooooo002eooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Pooooo`00]Oooool2o`00
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2Pooooo`00]Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0XOooool00;Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0:7ooooo
002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00GoV9RHoa0@4?l0003o
<S8bolc<c006ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2Qooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
oa0@4?nj^[[oooooogMgMolb<S801_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0X_ooool009[ooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo0:;ooooo002Jooooo`05o`000?ooooooooooooooool000003_ooool00onY
ZJWo410@ooooo`05ooooo`?o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
0:;ooooo002Jooooo`05o`000?ooooooooooooooool000003Oooool00ol@413o0000okZj^P06oooo
o`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`00002Uooooo`00V_ooool01Ol@
413ooooooooooooooooo410@00kooooo00?o^[Zjob4Q8Oooool01Oooool00ol0003oooooooooo`06
ooooo`;o000000?oooooo`000?ooool0YOooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003oooooooooo`07ooooo`;o0000Yooo
ool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0
1_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0;3o
oooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@00_o
oooo1Ol00006ooooo`?o0000/?ooool009[ooooo00Go0000ooooooooooooooooo`00000;ooooo`04
odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0/?ooool0
09[ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000
ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co
000000Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=
ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aoooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002a
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00
V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooa0@400@ooooo`03
o`000?oooooooooo00?ooooo0ol0002`ooooo`00V_ooool01Ol0003ooooooooooooooooo000000oo
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol0003ooooo
oooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo
0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aoooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00[?ooool00ol0003o^[Zjooooo`2iooooo`00[?ooool2oc8b<[[ooooo001moooo
o`;o000000Ko410@oooooooooooo410@o`000?l@410Hooooo`Co000000Go410@oooooooooooooooo
odA4A002o`000007oc8b<_oMgMgooooooooooon7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000
odA4A?nj^[X06_ooool2o`000003oa0@4?oooooooooo00;ooooo00GoA4A4o`000?l0003o<S8bomgM
g@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07?o
oooo001nooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`0000cooooo
00?o0000ooooooooool01_ooool01omgMgOo<S8booooooooooooc<c<o`000?l@41003?ooool01Ol@
413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<ooooo`03o`000?oooooooooo00Kooooo00WoMgMg
oc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
07?ooooo001nooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06_ooool5o`0000So
oooo00Co0000oooooooooooo410@0oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@
ooooooooool0LOooool007kooooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00003?oo
ool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo013ooooo00?o0000ooooooooool02ooo
ool6o`0000Wooooo00CoA4A4omgMgOoooooo00002?ooool01OmgMgOo<S8boooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo077ooooo001nooooo`06
o`000?oMgMgo<S8boeEEEOoMgMgo00006oooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`04Oooool00ol0003oooooooooo`0Jooooo`04omgMgOmEEEGoooooo`0000Gooooo
00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000007?ooooo001nooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo00006ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o410@o`000?l000000ol0
000Jooooo`03ogMgMoo<c<co000000Gooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@00?ooooo00Go410@oooooooooooooooooa0@401cooooo`00O_ooool01_l0003o<S8b
oooooooooooo<S8bo`0001_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo01_ooooo00?ok^k^odA4A?l000001Oooool00ol0003oooooooooo`04oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg07?ooooo001m
ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool00omEEEGoIVIVo`000005
ooooo`Co00004_ooool00ol0003oooooooooo`0Looooo`03ogMgMol0003ooooo00Cooooo1?l00003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07?ooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4600) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .00113 m
.02499 .00117 L
.02605 .0012 L
.02721 .00122 L
.02846 .00125 L
.02961 .00126 L
.03068 .00126 L
.0317 .00126 L
.03279 .00126 L
.03395 .00124 L
.0352 .00122 L
.03638 .00119 L
.03746 .00115 L
.04011 .00104 L
.04262 .0009 L
.05221 .00022 L
s
.05221 .00022 m
.05533 0 L
s
.08834 0 m
.09317 .00022 L
.09607 .00033 L
.09912 .00042 L
.10038 .00045 L
.10173 .00048 L
.1025 .00049 L
.10321 .0005 L
.10386 .0005 L
.10458 .00051 L
.10579 .00052 L
.10708 .00052 L
.10827 .00052 L
.10939 .00051 L
.1107 .0005 L
.1119 .00048 L
.1146 .00043 L
.11692 .00038 L
.11945 .0003 L
.12405 .00014 L
s
.12405 .00014 m
.12784 0 L
s
.17311 0 m
.17781 .00023 L
.18053 .00036 L
.18303 .00046 L
.18539 .00055 L
.18663 .00058 L
.18797 .00061 L
.18868 .00063 L
.18932 .00064 L
.19058 .00065 L
.19125 .00066 L
.19199 .00066 L
.19269 .00066 L
.19333 .00066 L
.19444 .00065 L
.19548 .00064 L
.19663 .00062 L
.19786 .00059 L
.20037 .00051 L
.20268 .00041 L
s
.20268 .00041 m
.20944 0 L
s
.24379 0 m
.24778 .00032 L
.25065 .00054 L
.25332 .00071 L
.2556 .00083 L
.25677 .00088 L
.25805 .00092 L
.25877 .00094 L
.25944 .00095 L
.26076 .00097 L
.26196 .00097 L
.26323 .00096 L
.26445 .00094 L
.26576 .00091 L
.26699 .00086 L
.26813 .00081 L
.27076 .00065 L
.27353 .00044 L
s
.27353 .00044 m
.27844 0 L
s
.31018 0 m
.31544 .00054 L
.31797 .00078 L
.32064 .00098 L
.32292 .00111 L
.32421 .00116 L
.32541 .00119 L
.32657 .00121 L
.32783 .00121 L
.32902 .0012 L
.33012 .00117 L
.33111 .00114 L
.3322 .00109 L
.33441 .00095 L
.3368 .00075 L
.33938 .00049 L
s
.33938 .00049 m
.34364 0 L
s
.37563 0 m
.3802 .00063 L
.38282 .00096 L
.38525 .00123 L
.38762 .00144 L
.38895 .00153 L
.39016 .00159 L
.39144 .00164 L
.39216 .00166 L
.39282 .00167 L
.39404 .00167 L
.39534 .00165 L
.39643 .00162 L
.39761 .00156 L
.39872 .0015 L
.39974 .00143 L
.40459 .00094 L
.40983 .00027 L
s
.40983 .00027 m
.41196 0 L
s
.43342 0 m
.43462 .00017 L
.43939 .00111 L
.44445 .00225 L
.4492 .00328 L
.45432 .00418 L
.45574 .00438 L
.45724 .00455 L
.45863 .00469 L
.45993 .00479 L
.46114 .00487 L
.46244 .00493 L
.46318 .00495 L
.46388 .00497 L
.46519 .00498 L
.46635 .00499 L
.46759 .00498 L
.46876 .00496 L
.46983 .00494 L
.47248 .00488 L
.47364 .00486 L
.47493 .00484 L
.47616 .00483 L
.47746 .00485 L
.47814 .00486 L
.47888 .00489 L
.47958 .00492 L
.48022 .00495 L
.48138 .00504 L
.48266 .00516 L
.48399 .00533 L
.48523 .00553 L
.48763 .00604 L
.4899 .00669 L
.49415 .00837 L
.49873 .01089 L
.50369 .01442 L
.51314 .02305 L
.52354 .03458 L
.53452 .04913 L
.53933 .05687 L
.54457 .06686 L
.55452 .09196 L
.56398 .12481 L
.58486 .21909 L
.58973 .24068 L
.595 .26154 L
.59964 .27689 L
.60454 .28926 L
.60727 .29423 L
Mistroke
.60883 .29641 L
.61027 .29801 L
.61096 .29862 L
.6116 .29911 L
.61282 .2998 L
.61412 .30022 L
.61486 .3003 L
.61554 .30028 L
.61673 .30002 L
.61784 .29952 L
.61906 .29869 L
.62038 .29748 L
.62306 .29401 L
.62552 .28969 L
.63026 .27855 L
.63532 .26313 L
.64445 .22884 L
.66515 .14514 L
.6754 .11335 L
.68117 .10034 L
.68393 .09548 L
.6865 .09171 L
.68894 .08883 L
.69116 .08676 L
.69364 .08509 L
.695 .08443 L
.69629 .08398 L
.69754 .0837 L
.69823 .08362 L
.69886 .08357 L
.70009 .0836 L
.70125 .08375 L
.70191 .08389 L
.7026 .08408 L
.70385 .08453 L
.70519 .08516 L
.70665 .08602 L
.70918 .08793 L
.71191 .09058 L
.71689 .09694 L
.72173 .10502 L
.72621 .11419 L
.73636 .14114 L
.74714 .17819 L
.75725 .21715 L
.76688 .25159 L
.77106 .26386 L
.77551 .27422 L
.77808 .27869 L
.78041 .2817 L
Mistroke
.78153 .28279 L
.78274 .28369 L
.78389 .28427 L
.78495 .28457 L
.78607 .28465 L
.78727 .28445 L
.78841 .284 L
.78944 .28336 L
.79065 .28234 L
.79197 .28091 L
.79437 .27745 L
.79688 .27272 L
.79955 .26653 L
.80434 .25274 L
.82521 .17176 L
.83479 .13484 L
.84489 .10141 L
.86294 .05691 L
.87217 .04079 L
.88227 .02771 L
.88749 .02268 L
.89306 .01847 L
.89833 .01541 L
.90312 .01323 L
.91309 .00987 L
.92228 .00734 L
.93302 .00453 L
.93827 .00329 L
.94307 .00231 L
.94671 .00171 L
.95067 .00121 L
.95284 .00101 L
.95486 .00087 L
.95585 .00082 L
.95679 .00077 L
.95786 .00074 L
.95884 .00071 L
.95985 .0007 L
.96095 .00069 L
.96211 .00069 L
.96318 .0007 L
.96419 .00072 L
.96511 .00074 L
.96718 .0008 L
.97619 .00113 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool6o`0000Kooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool4o`0000;o
oooo00?o0000ooooooooool02Oooool6o`0000Kooooo00?o0000ooooooooool00_ooool6o`000003
ooooool0003ooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`Ko
00001_ooool00ol0003oooooooooo`0Pooooo`009?ooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo02gooooo00?o0000ooooooooool08?ooool;o`0000;ooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01cooooo1Ol0000<ooooo`03o`00
0?oooooooooo023ooooo002cooooo`?o0000Noooool3o`0003Cooooo002eooooo`03o`000?oooooo
oooo07Oooooo0_l0000gooooo`00]Oooool3o`0007Gooooo0_l0000iooooo`00]Oooool2o`000003
ooooool0003ooooo077ooooo0_l0000kooooo`00]Oooool01Ol0003ooooooooooooooooo0000073o
oooo00?o0000ooooooooool0>oooool00;Gooooo00Go0000ooooooooooooooooo`00001`ooooo`03
o`000?oooooooooo03_ooooo002eooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
K?ooool00ol0003oooooooooo`0looooo`00]Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo06_ooooo00?o0000ooooooooool0??ooool00;Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1Yooooo`03o`000?oooooooooo03gooooo002eooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`0nooooo`00]Oooool2o`0000Ko
oooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0oooooo`00]Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0?oooool00;Gooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo043ooooo002e
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`11
ooooo`00]Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05oooooo00?o0000oooo
ooooool0@_ooool00;Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Oooooo`03
o`000?oooooooooo04;ooooo002eooooo`;o00002oooool00ol0003oooooooooo`1Mooooo`03o`00
0?oooooooooo04?ooooo002eooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0GOoo
ool00ol0003oooooooooo`13ooooo`00]Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo05gooooo00?o0000ooooooooool0@oooool00;Gooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`1Kooooo`03o`000?oooooooooo04Cooooo002eooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`14ooooo`00]Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0A?ooool00;Gooooo0_l0
000=ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0AOooool00;Gooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0Xooooo`Ko0000:oooool00ol0003oooooooooo`15
ooooo`00]Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo04Gooooo002eooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0A_ooool009[ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`16ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`16ooooo`00V_ooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000oooooooo
ool01Oooool3o`0000kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0Aoooool009[ooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`17ooooo`00V_ooool01Ol0003ooooooooooooooooo000000kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo04Sooooo002Jooooo`05oa0@
4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool0B?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`18ooooo`00
V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo04Wooooo002eooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool0BOooool00;Gooooo0_l0000Aooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04[ooooo002e
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0B_ooool00;Gooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`1:ooooo`00]Oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo04_ooooo002eooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
Boooool00;Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1;ooooo`00]Oooool2
o`0001;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool0Boooool00;Gooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`1<ooooo`00]Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04co
oooo002eooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0C?ooool00;Gooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`1<ooooo`00]Oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo04cooooo002eooooo`;o00005?ooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1=oooo
o`00]Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04gooooo002eooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0COooool00;Gooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`1=ooooo`00]Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo04gooooo002eooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0C_ooool00;Go
oooo0_l0000Eooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo04kooooo002eooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0C_ooool00;Gooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`1?ooooo`00]Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04oooooo002Joooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool0Coooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`1?ooooo`00V_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo053ooooo002J
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`?o00005_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`1@ooooo`00V_ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool01Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo053ooooo002J
ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0DOooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo057ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@
o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1Aooooo`00
]Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo057ooooo002eooooo`;o00006?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`1Booooo`00]Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo05;ooooo002eooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0D_ooool00;Go
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Booooo`00]Oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo05?ooooo002eooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0Doooool00;Gooooo0_l0000Iooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05?ooooo002eoooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0E?ooool00;Gooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`1Dooooo`00]Oooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo05Cooooo002eooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0E?oo
ool00;Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Eooooo`00]Oooool2o`00
01_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0EOooool00;Gooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`1Eooooo`00]Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Kooooo
002eooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Eoooool00;Gooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02[ooooo00Go0000
ooooooooooooooooo`00001Jooooo`00]Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0:oooool4o`0005[ooooo002eooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0]ooooo`;o0000Foooool00;Go
oooo0_l0000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0R_ooool00;Gooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo08_ooooo
002eooooo`03o`000?oooooooooo01kooooo00Co0000oooooooooooo0000S_ooool009[ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Ko
oooo00?o0000ooooooooool07_ooool4o`0008kooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo
0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo0;3ooooo002Jooooo`05o`000?ooooooooooooooool000003_ooool00onY
ZJWo410@ooooo`05ooooo`?o0000/?ooool009[ooooo00Go0000ooooooooooooooooo`00000=oooo
o`03oa0@4?l0003o^[Zj00Kooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooo
oooooooooa0@400>ooooo`03okZj^_lQ8B7ooooo00Gooooo00?o0000ooooooooool0/?ooool009[o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool0
0ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVY
oa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool009[ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo
00?o0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?oo
ooooooooooooool@41002oooool5o`0000Kooooo0ol0002`ooooo`00V_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool00ol0003oooooooooo`2`ooooo`00
V_ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0
003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<
c?l000001oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`2`oooo
o`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooo
oooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000;3ooooo002Jooooo`05o`000?oo
ooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo
002Jooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooa0@400<ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo002/ooooo`03o`000?nj^[[ooooo0;Wooooo002/oooo
o`;o<S8b^_ooool007gooooo0_l000001_l@413oooooooooool@413o0000oa0@41Sooooo1?l00000
1Ol@413oooooooooooooooooA4A400;o000000Oo<S8bomgMgOooooooooooohN7Qol0003o^[Zj00co
oooo00GoV9RHo`000?l0003oA4A4okZj^P0Jooooo`;o000000Wo410@ooooooooooooooooonk^k_lb
<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP1cooooo`00O_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oo
oooo1_l0000<ooooo`03o`000?oooooooooo00Kooooo00OoMgMgoc8b<_ooooooooooolc<c?l0003o
410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003ooooooooo
o`02ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`1cooooo`00O_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo01[ooooo1Ol00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol@
413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@401cooooo`00O_ooool0
1_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000<ooooo`03o`000?oooooooooo00Kooooo
00?oMgMgoc8b<_ooool04?ooool00ol0003oooooooooo`0;ooooo`Ko00002Oooool01?m4A4CogMgM
ooooool00004ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`00001cooooo`00O_ooool01_l0003ogMgMoc8b<_mE
EEGogMgMo`0001_ooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<017o
oooo00?o0000ooooooooool06_ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?mEEEGo0000
oa0@4?o<c<`00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`00001cooooo`00O_ooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001_ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Aooooo`03oa0@4?l0003o000000?o00006_ooool00omgMgOo
c<c<o`000004ooooo`03oeEEEOn7QhOooooo00Gooooo00Go410@oooooooooooooooooa0@4003oooo
o`05oa0@4?ooooooooooooooool@4100Loooool007kooooo00Ko0000oc8b<_oooooooooooc8b<_l0
000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Kooooo`03onk^k_m4A4Co000000Cooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1cooooo`00OOooool00ol@413o0000
ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo00?oEEEEofIVI_l000001Oooool4o`0001;ooooo
00?o0000ooooooooool07?ooool00omgMgOo0000ooooo`04ooooo`04olc<c?m4A4Co0000oa0@40?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0Loooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4700) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01159 m
.06244 .00501 L
.07216 .0029 L
.0775 .00151 L
.08255 .00029 L
s
.08255 .00029 m
.08405 0 L
s
.10703 0 m
.10938 .00037 L
.11453 .00118 L
.11703 .00152 L
.11939 .00177 L
.12042 .00186 L
.12151 .00194 L
.12271 .002 L
.12382 .00204 L
.12497 .00205 L
.1262 .00205 L
.12736 .00202 L
.12843 .00197 L
.12961 .0019 L
.13091 .0018 L
.13351 .00152 L
.13902 .00067 L
s
.13902 .00067 m
.14278 0 L
s
.1753 0 m
.17863 .00057 L
.1832 .00126 L
.18578 .00155 L
.187 .00166 L
.18813 .00175 L
.18926 .00181 L
.19049 .00186 L
.19158 .00188 L
.19273 .00189 L
.19396 .00187 L
.19466 .00185 L
.19529 .00182 L
.19646 .00176 L
.1977 .00167 L
.20031 .00141 L
.20317 .00105 L
.20886 .00017 L
s
.20886 .00017 m
.20994 0 L
s
.24299 0 m
.2439 .00013 L
.24922 .00083 L
.2519 .00111 L
.25344 .00124 L
.25483 .00133 L
.25612 .00139 L
.25734 .00143 L
.25863 .00146 L
.25936 .00146 L
.26003 .00146 L
.26115 .00144 L
.26238 .0014 L
.26366 .00134 L
.26487 .00127 L
.27385 .00031 L
s
.27385 .00031 m
.27622 0 L
s
.3108 0 m
.31457 .00046 L
.31717 .00075 L
.31991 .00102 L
.32225 .00121 L
.32359 .00129 L
.32481 .00135 L
.32605 .0014 L
.32723 .00143 L
.32847 .00145 L
.32917 .00145 L
.32982 .00145 L
.3309 .00144 L
.33208 .00141 L
.33332 .00137 L
.33448 .00132 L
.33711 .00116 L
.33951 .00097 L
.3449 .00044 L
s
.3449 .00044 m
.34911 0 L
s
.38741 0 m
.38964 .00019 L
.39506 .00062 L
.39753 .00077 L
.40017 .00091 L
.40145 .00096 L
.40266 .001 L
.40375 .00103 L
.40492 .00105 L
.40608 .00107 L
.40716 .00107 L
.40834 .00107 L
.40961 .00106 L
.41025 .00105 L
.41094 .00103 L
.4122 .001 L
.41457 .00092 L
.4168 .00081 L
.41918 .00067 L
.42344 .00036 L
s
.42344 .00036 m
.42785 0 L
s
.46429 0 m
.47039 .00063 L
.47544 .00111 L
.47792 .00131 L
.48019 .00145 L
.48151 .00151 L
.48291 .00156 L
.48363 .00159 L
.48431 .0016 L
.48505 .00161 L
.48584 .00162 L
.4865 .00162 L
.48721 .00162 L
.48851 .00161 L
.48978 .00158 L
.49095 .00154 L
.49325 .00144 L
.49579 .00129 L
.50093 .00089 L
.50586 .00048 L
.50854 .0003 L
.50985 .00022 L
.51104 .00016 L
.51214 .00012 L
.51318 9e-05 L
.51428 7e-05 L
.51547 7e-05 L
.51669 8e-05 L
.51799 .00011 L
.51909 .00016 L
.52031 .00023 L
.5217 .00034 L
.52302 .00046 L
.52551 .00077 L
.52818 .00119 L
.53109 .00176 L
.54117 .00434 L
.56052 .00974 L
.57081 .01261 L
.5766 .01473 L
.58191 .01735 L
.58661 .0204 L
.59175 .02469 L
.60213 .03687 L
.61197 .05313 L
.62113 .07264 L
.64155 .13327 L
.66013 .20654 L
.66943 .24227 L
.67452 .25878 L
Mistroke
.67928 .27115 L
.68176 .27616 L
.68443 .28033 L
.68594 .28211 L
.68669 .28282 L
.68739 .28339 L
.68868 .28419 L
.68936 .28448 L
.69009 .28469 L
.69139 .2848 L
.69212 .28471 L
.69279 .28453 L
.69402 .28398 L
.69533 .28306 L
.6965 .28196 L
.69759 .28069 L
.70007 .27699 L
.70267 .27194 L
.70508 .26627 L
.71052 .25044 L
.72043 .21448 L
.73899 .14544 L
.74862 .11812 L
.75302 .10832 L
.75766 .09983 L
.76283 .09253 L
.76512 .09001 L
.76757 .0878 L
.76896 .08677 L
.77022 .08597 L
.7715 .0853 L
.77268 .08481 L
.77405 .08438 L
.77478 .08422 L
.77555 .0841 L
.77684 .08402 L
.77757 .08404 L
.77826 .0841 L
.77951 .08432 L
.78021 .08451 L
.78084 .08472 L
.78208 .08524 L
.78324 .08586 L
.78585 .08774 L
.78867 .09053 L
.79382 .0978 L
.79855 .10699 L
.80757 .13118 L
.81709 .16503 L
.82732 .20723 L
Mistroke
.837 .24694 L
.84569 .27672 L
.84807 .28321 L
.85059 .28913 L
.85296 .29369 L
.85512 .29696 L
.85623 .29828 L
.85743 .29945 L
.85871 .30036 L
.85992 .30093 L
.86105 .30118 L
.86226 .30115 L
.86339 .30085 L
.86442 .30034 L
.86574 .29936 L
.86696 .29814 L
.8697 .29427 L
.87212 .28961 L
.87468 .28348 L
.88465 .24941 L
.89561 .20041 L
.90645 .15074 L
.91673 .11049 L
.92596 .08262 L
.93601 .06029 L
.94579 .04396 L
.9562 .03 L
.96508 .02027 L
.97489 .01238 L
.97619 .01159 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo000000?o
00001_ooool01?l0003oooooooooooooool7o`0000;ooooo00?o0000ooooooooool02Oooool6o`00
00Kooooo00?o0000ooooooooool01_ooool5o`0000[ooooo00?o0000ooooooooool00oooool5o`00
0003ooooool0003ooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`04o`000?ooooooooooooooo`Wo00001oooool7o`0000Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Pooooo`009?ooool00ol0003oooooooooo`06ooooo`Go00008oooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool03?ooool3o`00
01kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
023ooooo000Wooooo`Ko0000R?ooool00ol0003oooooooooo`0?ooooo`?o0000W_ooool002Cooooo
0ol0002>ooooo`03o`000?oooooooooo01;ooooo0_l0001hooooo`;o00008_ooool00;Gooooo00?o
0000ooooooooool05?ooool3o`0007Cooooo00?o0000ooooooooool08_ooool00;Gooooo0_l0000H
ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool08oooool00;Gooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo02Cooooo002eooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0Uooooo`00
]Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0
9_ooool00;Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Yooooo`03o`000?oo
oooooooo02Kooooo002eooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0Ioooool0
0ol0003oooooooooo`0Wooooo`00]Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
06Kooooo00?o0000ooooooooool0:?ooool00;Gooooo0_l0000Nooooo`03o`000?oooooooooo06Go
oooo00?o0000ooooooooool0:?ooool00;Gooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`1Sooooo`03o`000?oooooooooo02Wooooo002eooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool0Hoooool00ol0003oooooooooo`0Yooooo`00]Oooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0:_ooool00;Gooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo02_ooooo002eooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0/ooooo`00
]Oooool2o`00027ooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0/ooooo`00]Ooo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0;Ooo
ool00;Gooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1Looooo`03o`000?oooooo
oooo02gooooo002eooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0F_ooool00ol0
003oooooooooo`0^ooooo`00]Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo05[o
oooo00?o0000ooooooooool0;_ooool00;Gooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`1Jooooo`03o`000?oooooooooo02kooooo002eooooo`;o00009?ooool00ol0003ooooooooo
o`1Hooooo`03o`000?oooooooooo02oooooo002eooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool0:?ooool6o`0002[ooooo00?o0000ooooooooool0;oooool00;Gooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0Wooooo`;o00001Oooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo033ooooo002eooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool0<?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000003
oa0@4?oooooooooo00?ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0`ooooo`00
V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0aooooo`00V_ooool01Ol@413ooooo
oooooooooooo410@00kooooo00?o0000ooooooooool01Oooool3o`0002Gooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool0<Oooool009[ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0aooooo`00V_ooool01Ol0003ooooo
oooooooooooo000000kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo03;ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0<_ooool009[ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`0booooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03;o
oooo002eooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0<oooool00;Gooooo0_l0
000Xooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo03?ooooo002eooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool0<oooool00;Gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0coooo
o`00]Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo03Cooooo002eooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool0=?ooool00;Gooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0dooooo`00]Oooool2o`0002[ooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0=?ooool0
0;Gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0eooooo`00]Oooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo03Gooooo002eooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool0=Oooool00;Gooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0eooooo`00]Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03Kooooo002eoooo
o`;o0000:oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0fooooo`00]Oooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo03Kooooo002eooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
=_ooool00;Gooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0fooooo`00]Oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03Oooooo002eooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool0=oooool00;Gooooo0_l0000/ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03Oo
oooo002eooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0=oooool00;Gooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0gooooo`00]Oooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo03Sooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0>?ooool0
09[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0hooooo`00V_ooool0
1Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo03Sooooo002Jooooo`05o`000?ooooooooooooooool000003Ooo
ool00onHV9So8B4Qonk^kP06ooooo`?o0000;Oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0hooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo03Wooooo002Jooooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0>Ooo
ool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
1_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03Wooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0iooooo`00]Oooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo03Wooooo002eooooo`;o0000<?ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0jooooo`00]Oooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03[ooooo002eooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0>_ooool00;Gooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0jooooo`00]Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03[ooooo
002eooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0>oooool00;Gooooo0_l0000a
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo03_ooooo002eooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool0>oooool00;Gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0kooooo`00
]Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03_ooooo002eooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0??ooool00;Gooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0looooo`00]Oooool2o`0003Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0??ooool00;Go
oooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0mooooo`00]Oooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo03gooooo002eooooo`03o`000?oooooooooo03Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0?Oooool00;Gooooo00?o0000ooooooooool0=Oooool01Ol0003ooooooooooooo
oooo000002cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0nooooo`00]Oooool0
0ol0003oooooooooo`0eooooo`;o000000?oooooo`000?l00000;?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo03kooooo002eooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03kooooo002eooooo`;o
0000J?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03oooooo002eooooo`03o`00
0?oooooooooo06Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`10ooooo`00]Ooo
ool00ol0003oooooooooo`1Yooooo`05o`000?ooooooooooooooool00000@_ooool009[ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Ko
oooo00?o0000ooooooooool0JOooool4o`0004?ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo
06[ooooo0_l00014ooooo`00V_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol0003ooooooooooooooooo0000
00kooooo00?oZJVYoa0@4?ooool01Oooool3o`000;3ooooo002Jooooo`05o`000?oooooooooooooo
ool000003Oooool00ol@413o0000okZj^P06ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05
oa0@4?ooooooooooooooool@41003_ooool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo
0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413oV9RHoooooonj^[[o
000000Kooooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413ooooo
ooooo`04ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2`ooooo`00V_oo
ool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`?o0000/?ooool009[ooooo00Go
0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000oooooooo
ool0/?ooool009[ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`00
00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooa0@400<oooo
o`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0/?ooool009[o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000oooo
ooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00V_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009[ooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0002`ooooo`00V_oo
ool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00V_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@
41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3o
oooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool00ol0003o^[Zjooooo`2i
ooooo`00[?ooool2oc8b<[[ooooo001mooooo`;o000000Ko410@oooooooooooo410@o`000?l@410H
ooooo`Co000000Go410@ooooooooooooooooodA4A002o`000007oc8b<_oMgMgooooooooooon7QhOo
0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06_ooool2o`000003oa0@4?oooooooooo
00?ooooo00?o0000onk^k_ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP1cooooo`00O_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Oooooo1_l0000<ooooo`03o`000?oooooooooo00Kooooo00OoMgMgoc8b<_ooooooooooolc<
c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003o
ooooooooo`04ooooo`03oeEEEOnYZJWooooo00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL0Loooool007kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Jooooo`Go00001Oooool00onYZJWoEEEEooooo`03ooooo`05oa0@4?oooooooooo
ooooool@41000oooool01Ol@413ooooooooooooooooo410@07?ooooo001nooooo`06o`000?oooooo
A4A4odA4A?oooooo00002Oooool6o`0000cooooo00?o0000ooooooooool01_ooool00omgMgOo<S8b
ooooo`0@ooooo`03o`000?oooooooooo00_ooooo1_l00009ooooo`04odA4A?oMgMgoooooo`0000Oo
oooo00?o8B4Qooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`00001cooooo`00O_ooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001_ooooo00?o
0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<017ooooo00?o0000ooooooooool0
6_ooool01?oMgMgoEEEEooooool00007ooooo`03oeEEEOo<c<cooooo00;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool00000Loooool007kooooo00Ko0000ohN7
QonYZJWo^[ZjoeEEEOl0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Ooo
ool00ol@413o0000o`000003o`0001[ooooo00?oMgMgolc<c?l000001oooool00onYZJWoMgMgoooo
o`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@07?o
oooo001nooooo`06o`000?lb<S;ooooooooooolb<S;o00006oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool06oooool00oo^k^koA4A4o`000004oooo
o`05oa0@4?oooooooooooooooolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`1cooooo`00OOooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0
003o410@01Sooooo00?oEEEEofIVI_l000001Oooool4o`0001;ooooo00?o0000ooooooooool07?oo
ool00omgMgOo0000ooooo`03ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP1cooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4800) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .20411 m
.03279 .16027 L
.04262 .11831 L
.05288 .08412 L
.06244 .06068 L
.0731 .04177 L
.0828 .02913 L
.08817 .02355 L
.094 .01847 L
.09946 .01458 L
.10458 .01163 L
.10951 .00939 L
.11402 .00778 L
.11903 .00641 L
.12442 .00533 L
.12957 .00456 L
.1352 .00392 L
.14545 .00302 L
.16676 .00123 L
.17683 .00035 L
.18125 1e-05 L
s
.18125 1e-05 m
.18147 0 L
s
.20722 0 m
.216 .00073 L
.21833 .00093 L
.2208 .00111 L
.22308 .00126 L
.22522 .00136 L
.22635 .0014 L
.22757 .00143 L
.22826 .00144 L
.22892 .00144 L
.23015 .00144 L
.23079 .00144 L
.23148 .00143 L
.23271 .0014 L
.23346 .00137 L
.23417 .00134 L
.2355 .00127 L
.23783 .0011 L
.23998 .0009 L
.24483 .00033 L
s
.24483 .00033 m
.24718 0 L
s
.28246 0 m
.28464 .00038 L
.28976 .00125 L
.29244 .00162 L
.29391 .0018 L
.29529 .00193 L
.29659 .00203 L
.29778 .0021 L
.2991 .00215 L
.29982 .00217 L
.30051 .00217 L
.30171 .00216 L
.30281 .00213 L
.30403 .00207 L
.30532 .00198 L
.3149 .00057 L
s
.3149 .00057 m
.31772 0 L
s
.35123 0 m
.35228 .00024 L
.35747 .00139 L
.36002 .00187 L
.36236 .00223 L
.36358 .00239 L
.36491 .00252 L
.36625 .00262 L
.36698 .00266 L
.36766 .00269 L
.36887 .00271 L
.36997 .0027 L
.37125 .00266 L
.37246 .00258 L
.37376 .00247 L
.37513 .00231 L
.37761 .00194 L
.38321 .00076 L
s
.38321 .00076 m
.38637 0 L
s
.4214 0 m
.42577 .001 L
.42839 .00152 L
.43086 .00191 L
.43199 .00205 L
.43317 .00217 L
.43447 .00228 L
.43567 .00234 L
.43674 .00237 L
.43775 .00237 L
.43884 .00235 L
.44002 .0023 L
.44069 .00226 L
.44141 .00221 L
.4427 .00208 L
.4456 .00169 L
.44811 .00125 L
.45088 .00067 L
s
.45088 .00067 m
.45385 0 L
s
.48896 0 m
.491 .00041 L
.49577 .00128 L
.49708 .00148 L
.49849 .00166 L
.49971 .00179 L
.50104 .00191 L
.50229 .00199 L
.50361 .00204 L
.50483 .00207 L
.50597 .00206 L
.50665 .00205 L
.50729 .00203 L
.5085 .00198 L
.5098 .00189 L
.51121 .00177 L
.514 .00146 L
.51696 .00104 L
.52227 .00018 L
s
.52227 .00018 m
.52348 0 L
s
.55444 0 m
.5804 .00205 L
.58561 .00168 L
.58836 .00151 L
.58975 .00145 L
.59055 .00142 L
.59128 .00139 L
.59193 .00138 L
.59261 .00136 L
.59329 .00136 L
.59404 .00136 L
.59469 .00136 L
.59538 .00137 L
.59663 .00141 L
.59727 .00144 L
.59796 .00148 L
.59922 .00156 L
.60157 .00179 L
.6039 .0021 L
.60645 .00253 L
.61161 .00368 L
.62086 .00635 L
.63057 .00945 L
.64099 .0129 L
.64604 .01485 L
.65083 .0171 L
.65981 .02293 L
.66439 .02699 L
.66944 .03249 L
.67969 .04718 L
.68918 .0653 L
.6981 .08657 L
.71824 .15095 L
.73674 .22086 L
.74147 .23667 L
.74652 .25107 L
.74897 .25686 L
.75129 .26152 L
.75336 .26495 L
.75563 .2679 L
.75692 .26917 L
.75813 .27009 L
.75941 .27078 L
.76013 .27103 L
.76079 .27118 L
.76196 .27125 L
.76323 .27104 L
.76443 .27057 L
.76555 .26989 L
.76696 .26873 L
Mistroke
.76829 .26732 L
.77076 .26387 L
.77343 .25904 L
.77632 .25263 L
.78583 .22453 L
.79626 .1869 L
.80728 .14754 L
.81733 .11713 L
.82213 .10517 L
.82735 .09418 L
.83186 .08639 L
.83684 .0796 L
.83938 .07687 L
.84211 .07445 L
.84362 .07336 L
.845 .07251 L
.8464 .07179 L
.84771 .07126 L
.84884 .0709 L
.85005 .07063 L
.85074 .07053 L
.85139 .07046 L
.85261 .07043 L
.85389 .07053 L
.85508 .07074 L
.85638 .0711 L
.85776 .07163 L
.85897 .07224 L
.86029 .07304 L
.86269 .07491 L
.8672 .07983 L
.86975 .08349 L
.87246 .0881 L
.87734 .09832 L
.88695 .12594 L
.89566 .15907 L
.90583 .20486 L
.91657 .25461 L
.92574 .29044 L
.92825 .29819 L
.93094 .30521 L
.93329 .31018 L
.93578 .31415 L
.93701 .31561 L
.93767 .31624 L
.93837 .3168 L
.9396 .31752 L
.94076 .31787 L
.94145 .31792 L
.94221 .31785 L
Mistroke
.94292 .31766 L
.94358 .31738 L
.94483 .31655 L
.94553 .31593 L
.94617 .31527 L
.9486 .31187 L
.95123 .3067 L
.95599 .29363 L
.96065 .27687 L
.96557 .25583 L
.97439 .21312 L
.97619 .20411 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01_ooool=o`0000?ooooo00?o0000ooooooooool02?ooool6o`0000Oo
oooo00?o0000ooooooooool01Oooool7o`0000Wooooo00?o0000ooooooooool00_ooool8o`0000_o
oooo00?o0000ooooool000001_l00003ooooo`03o`000?oooooooooo00Sooooo1_l00007ooooo`03
o`000?oooooooooo00Kooooo4?l0000;ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Pooooo`009?ooool00ol0003oooooooooo`0Jooooo`Co0000
4?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
8_ooool2o`0000Wooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo023ooooo000nooooo`?o0000M?ooool00ol0003oooooooooo`0Tooooo`?o0000ROoo
ool003cooooo0_l0001gooooo`03o`000?oooooooooo02Oooooo0_l00027ooooo`00>oooool00ol0
003oooooooooo`1gooooo`03o`000?oooooooooo02Wooooo0ol00024ooooo`00>Oooool2o`0007[o
oooo0_l0000]ooooo`03o`000?oooooooooo087ooooo000hooooo`03o`000?oooooooooo07[ooooo
00?o0000ooooooooool0;Oooool2o`00087ooooo000gooooo`03o`000?oooooooooo07_ooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`1nooooo`00=_ooool00ol0003oooooooooo`1l
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0O_ooool003Kooooo00?o0000oooo
ooooool0O?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo07gooooo000eooooo`03
o`000?oooooooooo07gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1mooooo`00
=?ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
O?ooool003?ooooo00?o0000ooooooooool0Ooooool2o`0003?ooooo00?o0000ooooooooool0Nooo
ool003?ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo07[ooooo000booooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`1jooooo`00<_ooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool0NOooool0037ooooo00?o0000ooooooooool0POooool00ol0003ooooo
ooooo`0dooooo`03o`000?oooooooooo07Wooooo000aooooo`03o`000?oooooooooo087ooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`1hooooo`00<?ooool00ol0003oooooooooo`22
ooooo`;o0000=_ooool00ol0003oooooooooo`1hooooo`00<?ooool00ol0003oooooooooo`22oooo
o`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0Moooool002oooooo00?o0000oooooooo
ool0Poooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo07Oooooo000_ooooo`03o`00
0?oooooooooo08?ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0[ooooo`Ko0000
AOooool002kooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`0gooooo`03o`000?oo
oooooooo02[ooooo0_l00005ooooo`03o`000?oooooooooo04;ooooo000^ooooo`03o`000?oooooo
oooo08Cooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0@Oooool002kooooo00?o0000ooooooooool0Q?ooool2o`00
03Wooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
047ooooo000]ooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool0>Oooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0@?ooool002gooooo
00?o0000ooooooooool0QOooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0oooooo`00;Oooool00ol0003ooooooooo
o`25ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo03oooooo000/ooooo`03o`000?oooooooooo06_ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0?_ooool002cooooo00?o0000ooooooooool0Joooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0?_oo
ool002cooooo00?o0000ooooooooool0Joooool01Ol@413ooooooooooooooooo410@00kooooo00?o
0000ooooooooool01Oooool3o`0003[ooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo03kooooo000[ooooo`03o`000?oooooooooo06cooooo00Go0000
ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0?Ooo
ool002_ooooo00?o0000ooooooooool0K?ooool01Ol0003ooooooooooooooooo000000kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0mooooo`00:oooool00ol0003oooooooooo`1/
ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo03gooooo000Zooooo`03o`000?oooooooooo06gooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0??ooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0??ooool002[ooooo00?o0000
ooooooooool0KOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001ooo
ool00ol0003oooooooooo`0looooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0looooo`00:_ooool00ol0003oooooooooo`28ooooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo03cooooo000Zooooo`03o`000?oooooooooo08Sooooo0_l0000mooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0kooooo`00:Oooool00ol0003o
ooooooooo`29ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo03_ooooo000Yooooo`03o`000?oooooooooo08Wooooo
00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0>oooool002Wooooo00?o0000ooooooooool0ROooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`0jooooo`00:Oooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo03kooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03[ooooo000Xoooo
o`03o`000?oooooooooo08[ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0>_ooool002Sooooo00?o0000oooooooo
ool0R_ooool2o`0003oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo03Wooooo000Xooooo`03o`000?oooooooooo08[ooooo00?o0000ooooooooool0
?oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
>Oooool002Sooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`0oooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0iooooo`00:?ooool0
0ol0003oooooooooo`2:ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo03Sooooo000Wooooo`03o`000?oooooooooo
08_ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool0>?ooool002Oooooo00?o0000ooooooooool0Roooool00ol0003o
ooooooooo`10ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0hooooo`009oooool00ol0003oooooooooo`2;ooooo`;o0000@Oooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0>?ooool002Oooooo00?o
0000ooooooooool0Roooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0gooooo`009_ooool00ol0003oooooooooo`2<
ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo03Oooooo000Vooooo`03o`000?oooooooooo08cooooo00?o0000oooo
ooooool0@Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool0=oooool002Kooooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`11ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0gooooo`00
9_ooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo03Oooooo000Uooooo`03o`000?oo
oooooooo08gooooo0_l00013ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0fooooo`009Oooool00ol0003oooooooooo`2=ooooo`03o`000?oooooo
oooo04;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo03Kooooo000Uooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool0@_ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0=_ooool002Go
oooo00?o0000ooooooooool0SOooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0fooooo`009Oooool00ol0003ooooo
ooooo`1booooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03
o`000?oooooooooo04?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo03Kooooo000Tooooo`03o`000?oooooooooo07?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000oooo
ooooool0@oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool0=Oooool002Cooooo00?o0000ooooooooool0Loooool01Ol@413ooooooooooooooooo410@
00cooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
023ooooo002Jooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06oooo
o`?o0000A?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Pooooo`00V_ooool01Ol0003ooooooooooooooooo0000
00kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
023ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo04Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool08?ooool009[ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`15
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo023ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0AOooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0Pooooo`00]Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo027ooooo002eoooo
o`;o0000A_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0Qooooo`00]Oooool00ol0003oooooooooo`16ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo027ooooo002eooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
8Oooool00;Gooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Rooooo`00]Oooool0
0ol0003oooooooooo`16ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02;ooooo002eooooo`03o`000?oooooooooo
04Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool08_ooool00;Gooooo0_l00018ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02;o
oooo002eooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool08_ooool00;Gooooo00?o
0000ooooooooool0B?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Sooooo`00]Oooool00ol0003oooooooooo`18
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo02?ooooo002eooooo`03o`000?oooooooooo04Sooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool08oooool00;Gooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Sooooo`00
]Oooool2o`0004_ooooo00Go0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool08oooool00;Gooooo00?o0000ooooooooool0Boooool4o`0002gooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Tooooo`00]Oooool00ol0003ooooooooo
o`1mooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool09?ooool00;Gooooo00?o0000
ooooooooool0OOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Cooooo002eoooo
o`03o`000?oooooooooo07gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Toooo
o`00]Oooool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool09Oooool00;Gooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo02Gooooo002eooooo`;o0000Ooooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo02Gooooo002eooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Vooooo`00]Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool09_ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Kooooo00?o0000ooooooooool0Ooooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Kooooo002Jooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oo
oooooooo07oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Wooooo`00V_ooool0
1Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`20ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09oooool009[ooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ojVYZOl@413ooooo00Gooooo0ol00020ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool09oooool009[ooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oa0@4?l0003o^[Zj00Kooooo00?o0000ooooooooool0POooool01Ol0003ooooooooo
oooooooo000002[ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003_ooool00onj^[[o8B4Q
ooooo`05ooooo`03o`000?oooooooooo087ooooo1?l0000[ooooo`00V_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooooooo08;o
oooo0_l0000/ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000
ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?oooooooooo
ooooool@41002oooool5o`0000Kooooo0ol0002`ooooo`00V_ooool01Ol0003ooooooooooooooooo
000000_ooooo00CoA4A4omgMgOoooooo00001oooool00ol0003oooooooooo`2`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003ooooo
ooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000
1oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo
00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo
410@013ooooo00?o0000ooooooooool00oooool3o`000;3ooooo002Jooooo`05o`000?oooooooooo
ooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Joooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo002/ooooo`03o`000?nj^[[ooooo0;Wooooo002/ooooo`;o<S8b
^_ooool007gooooo0_l000001_l@413oooooooooool@413o0000oa0@41Sooooo1?l000001Ol@413o
ooooooooooooooooA4A400;o000000Oo<S8bomgMgOooooooooooohN7Qol0003o^[Zj00cooooo00Go
V9RHo`000?l0003oA4A4okZj^P0Jooooo`;o000000Wo410@ooooooooooooooooolc<c?lQ8B7o0000
ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP1cooooo`00O_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l0
000<ooooo`03o`000?oooooooooo00Kooooo00OoMgMgoc8b<_ooooooooooolc<c?l0003o410@00co
oooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003oooooooooo`02oooo
o`05ob4Q8OnHV9SooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`1cooooo`00O_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo01[ooooo1Ol00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol@413ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@401cooooo`00O_ooool01_l0003o
ooooodA4A?m4A4Coooooo`0000Wooooo1_l0000<ooooo`03o`000?oooooooooo00Kooooo00?oMgMg
oc8b<_ooool04?ooool00ol0003oooooooooo`0;ooooo`Ko00002Oooool01?m4A4CogMgMooooool0
0004ooooo`05oc8b<_nHV9SooooooiRHV?lb<S800oooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`00001cooooo`00O_ooool01_l0003ogMgMoc8b<_mEEEGogMgM
o`0001_ooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<017ooooo00?o
0000ooooooooool06_ooool01?oMgMgoEEEEooooool00004ooooo`05olc<c?l0003o0000o`000?o<
c<`00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00001c
ooooo`00O_ooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001_ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Aooooo`03oa0@4?l0003o000000?o00006_ooool00omgMgOoc<c<o`00
0004ooooo`05oa0@4?nj^[[ooooookZj^_l@41000oooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@401cooooo`00O_ooool01_l0003o<S8boooooooooooo<S8b
o`0001_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo01_ooooo00?ok^k^odA4A?l000001?ooool01Ol0003o^[Zjoooooonj^[[o000000?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Loooool007gooooo
00?o410@o`000?n7QhL00_ooool00on7QhOo0000oa0@400Hooooo`03oeEEEOmVIVKo000000Gooooo
1?l0000Booooo`03o`000?oooooooooo01cooooo00?oMgMgo`000?ooool00oooool01OnYZJWo410@
o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h0Loooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4900) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .14135 m
.04262 .23445 L
.0522 .28053 L
.05746 .30106 L
.06244 .31576 L
.06506 .32134 L
.06653 .32379 L
.0679 .32559 L
.06904 .32676 L
.0703 .32766 L
.07162 .32819 L
.07286 .32829 L
.07411 .32801 L
.0753 .32738 L
.07636 .32653 L
.07753 .32527 L
.08013 .3213 L
.08255 .31621 L
.08815 .29975 L
.09321 .28 L
.10458 .22505 L
.11473 .17244 L
.12545 .12254 L
.1346 .08862 L
.13985 .07317 L
.14465 .06149 L
.15427 .04382 L
.15957 .0366 L
.16458 .03089 L
.1832 .01508 L
.19285 .00911 L
.19773 .00675 L
.20053 .00562 L
.20311 .00474 L
.20768 .00354 L
.21008 .00309 L
.2113 .00291 L
.21261 .00274 L
.21376 .00262 L
.21481 .00253 L
.21588 .00246 L
.21687 .00241 L
.21802 .00237 L
.21926 .00234 L
.22036 .00233 L
.22153 .00234 L
.22274 .00235 L
.22406 .00238 L
.2253 .00242 L
.22646 .00246 L
Mistroke
.23096 .00264 L
.23349 .00273 L
.23473 .00276 L
.23587 .00279 L
.23719 .00281 L
.23789 .00281 L
.23862 .00281 L
.2398 .00281 L
.2411 .00279 L
.24233 .00276 L
.2435 .00272 L
.24568 .00261 L
.24803 .00245 L
.25058 .00223 L
.25941 .00121 L
.26434 .0006 L
.26692 .00031 L
.26964 3e-05 L
Mfstroke
.26964 3e-05 m
.27003 0 L
s
.29588 0 m
.30025 .00025 L
.30505 .00049 L
.30747 .00058 L
.30885 .00061 L
.31015 .00064 L
.31126 .00066 L
.31244 .00068 L
.31345 .00068 L
.31455 .00068 L
.31574 .00068 L
.31702 .00067 L
.31822 .00065 L
.31931 .00063 L
.32197 .00057 L
.32443 .0005 L
.32998 .0003 L
.33484 .00014 L
.33752 6e-05 L
s
.33752 6e-05 m
.33975 0 L
s
.46725 0 m
.47186 .00014 L
.47429 .00021 L
.47685 .00028 L
.47904 .00032 L
.48029 .00034 L
.48143 .00035 L
.48264 .00037 L
.48392 .00037 L
.48511 .00037 L
.48624 .00037 L
.48753 .00036 L
.48872 .00035 L
.49003 .00034 L
.49141 .00031 L
.49666 .0002 L
.50244 4e-05 L
s
.50244 4e-05 m
.50385 0 L
s
.52372 0 m
.52702 9e-05 L
.53261 .00027 L
.53517 .00034 L
.53657 .00038 L
.53789 .00041 L
.5391 .00043 L
.54021 .00044 L
.54144 .00045 L
.54208 .00045 L
.54276 .00046 L
.54404 .00045 L
.54521 .00045 L
.54585 .00044 L
.54655 .00043 L
.54781 .00041 L
.549 .00039 L
.55025 .00035 L
.5525 .00028 L
.55801 5e-05 L
s
.55801 5e-05 m
.55909 0 L
s
.58633 0 m
.5867 2e-05 L
.59124 .00034 L
.59653 .00071 L
.59886 .00085 L
.60009 .00091 L
.60142 .00097 L
.60257 .00101 L
.60363 .00104 L
.60469 .00107 L
.60569 .00108 L
.60682 .00109 L
.60786 .00109 L
.609 .00108 L
.61022 .00106 L
.61146 .00102 L
.6128 .00097 L
.61523 .00086 L
.61978 .00056 L
.62437 .00021 L
.62689 2e-05 L
s
.62689 2e-05 m
.62724 0 L
s
.64331 0 m
.64462 .00012 L
.64743 .00045 L
.64998 .00083 L
.66079 .00287 L
.6656 .00378 L
.67011 .00451 L
.67481 .00507 L
.6773 .00528 L
.67998 .00545 L
.68288 .00559 L
.68563 .0057 L
.68832 .0058 L
.6908 .00593 L
.69311 .0061 L
.6944 .00622 L
.69557 .00635 L
.69826 .00675 L
.70078 .00726 L
.7032 .0079 L
.70545 .00864 L
.71057 .01091 L
.71556 .01394 L
.7209 .01804 L
.73939 .03767 L
.74959 .0516 L
.76067 .07104 L
.77114 .09633 L
.78081 .127 L
.80111 .2042 L
.8062 .22197 L
.81104 .23662 L
.81539 .24733 L
.81788 .25226 L
.82013 .25592 L
.82249 .25887 L
.82356 .25993 L
.8247 .26084 L
.82592 .26158 L
.82704 .26204 L
.82825 .26231 L
.82893 .26236 L
.82957 .26234 L
.83071 .26213 L
.83179 .26174 L
.83275 .26124 L
.83381 .26053 L
.83616 .25832 L
.83834 .25554 L
.84286 .24773 L
Mistroke
.84785 .23624 L
.85795 .20605 L
.8789 .13268 L
.88808 .10407 L
.89293 .09116 L
.89812 .07942 L
.90323 .07009 L
.90787 .06353 L
.91011 .061 L
.91254 .05871 L
.91482 .05697 L
.91695 .05568 L
.91934 .0546 L
.9206 .05417 L
.92196 .05383 L
.92264 .05369 L
.92338 .05358 L
.92408 .0535 L
.92473 .05345 L
.92596 .05343 L
.92727 .05349 L
.9285 .05363 L
.9292 .05374 L
.92984 .05386 L
.931 .05414 L
.93226 .05452 L
.93446 .05537 L
.93679 .05653 L
.93924 .05805 L
.9419 .06007 L
.94674 .06485 L
.95145 .0711 L
.95581 .07856 L
.96051 .08874 L
.9657 .10285 L
.97619 .14135 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Co
oooo4_l0000;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`?o00002Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo023o
oooo000Tooooo`03o`000?oooooooooo02kooooo00Co0000oooooooooooooooo0ol0000Yooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0;o`0002;o
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Pooooo`00Eoooool2o`0005cooooo
00?o0000ooooooooool0>oooool3o`0007;ooooo001Fooooo`03o`000?oooooooooo05cooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`1_ooooo`00E?ooool2o`0005oooooo00?o0000
ooooooooool0?oooool00ol0003oooooooooo`1^ooooo`00Doooool00ol0003oooooooooo`1Ooooo
o`;o0000@Oooool00ol0003oooooooooo`1]ooooo`00D_ooool00ol0003oooooooooo`1Pooooo`03
o`000?oooooooooo047ooooo00?o0000ooooooooool0K?ooool0057ooooo00?o0000ooooooooool0
HOooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo06_ooooo001@ooooo`03o`000?oo
oooooooo06;ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`1Zooooo`00Coooool0
0ol0003oooooooooo`1Sooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0JOooool0
04kooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo
06Sooooo001=ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0A_ooool00ol0003o
ooooooooo`1Wooooo`00C?ooool00ol0003oooooooooo`1Vooooo`;o0000Aoooool00ol0003ooooo
ooooo`1Wooooo`00C?ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo04Oooooo00?o
0000ooooooooool0I_ooool004_ooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`18
ooooo`03o`000?oooooooooo06Gooooo001;ooooo`03o`000?oooooooooo06Oooooo00?o0000oooo
ooooool0BOooool00ol0003oooooooooo`0aooooo`?o0000<?ooool004[ooooo00?o0000oooooooo
ool0J?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo02oooooo0ol000001?oooooo
0000o`000?l0000^ooooo`00B_ooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo04[o
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`05ooooo`;o0000;?ooool004Wooooo
00?o0000ooooooooool0JOooool2o`0004_ooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo02[ooooo0019ooooo`03o`000?oooooooooo06Wooooo00?o
0000ooooooooool0Boooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0:Oooool004Sooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`1;
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0X
ooooo`00B?ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo04cooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Oooooo0018ooooo`03
o`000?oooooooooo06[ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool09oooool004Oooooo00?o0000ooooooooool0
Joooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0Vooooo`00Aoooool00ol0003oooooooooo`1[ooooo`;o0000C_oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool09_oo
ool004Oooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`1>ooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Uooooo`00A_ooool00ol0
003oooooooooo`1/ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo02Cooooo0016ooooo`03o`000?oooooooooo06co
oooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool09?ooool004Kooooo00?o0000ooooooooool0DOooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000?o410@ooooooooool00oooool00ol0003o
ooooooooo`1?ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Tooooo`00AOooool00ol0003oooooooooo`1Booooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1?ooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Sooooo`00
AOooool00ol0003oooooooooo`1Booooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003o
ooooooooo`05ooooo`?o0000Coooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool08oooool004Gooooo00?o0000ooooooooool0D_ooool01Ol0003ooooo
oooooooooooo000000kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1@ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Sooooo`00
A?ooool00ol0003oooooooooo`1Cooooo`05o`000?ooooooooooooooool000003_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo02?ooooo0014ooooo`03o`000?oooooooooo05?ooooo
00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0D?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool08_ooool004Cooooo00?o0000ooooooooool0Doooool01OmgMgOoV9RHoooooonHV9SoMgMg00ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Rooooo`00@oooool00ol0003ooooo
ooooo`1Dooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`000007ooooo`03
o`000?oooooooooo057ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo02;ooooo0013ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0
DOooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
8_ooool004?ooooo00?o0000ooooooooool0Koooool2o`0005?ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo027ooooo0013ooooo`03o`000?oooooo
oooo06oooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool08Oooool004;ooooo00?o0000ooooooooool0L?ooool00ol0
003oooooooooo`1Booooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Qooooo`00@_ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo05;o
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo027o
oooo0012ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0Doooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool08?ooool002Cooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo05?ooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo023ooooo000T
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0L?ooool2o`0005Cooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0nooooo`009?ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo077ooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo03kooooo000Uooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool0LOooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool0?oooool002Gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1aooooo`03o`00
0?oooooooooo05Cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0oooooo`009Ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0E?oo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03oooooo000Uooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1Dooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool0@?ooool002Gooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`1booooo`;o0000E_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
043ooooo000Vooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0L_ooool00ol0003o
ooooooooo`1Eooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0@?ooool002Kooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo05Gooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`11ooooo`009_ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0E_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo047ooooo000Vooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool0L_ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool0@Oooool002Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1boooo
o`03o`000?oooooooooo05Kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`11oooo
o`009oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo07?ooooo0_l0001Gooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool0@_ooool002Oooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`12ooooo`009oooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo07?ooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo04;ooooo000Wooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0Loooool0
0ol0003oooooooooo`1Gooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0@oooool0
02Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Hooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo05Oooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`13ooooo`00:?ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo05Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0F?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo04?ooooo000Xooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool0FOooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0A?oo
ool002Sooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1Iooooo`05o`000?oooooo
ooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`?o0000F?ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo04Cooooo000Xooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool0FOooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Ooo
ool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0A?oo
ool002Wooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Iooooo`05oa0@4?oooooo
ooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Wooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`15ooooo`00:Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo05[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj
^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0AOooool002Wooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`1Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Ko
oooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04Go
oooo000Yooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0MOooool00ol0003ooooo
ooooo`1Jooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0A_ooool002Wooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`1eooooo`;o0000Foooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo04Kooooo000Zooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0MOooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0A_ooool002[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1foooo
o`03o`000?oooooooooo05_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`17oooo
o`00:_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo07Kooooo00?o0000oooooooo
ool0Foooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04Oooooo000Zooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`1Kooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0Aoooool002_ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`18ooooo`00:oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo07Oooooo0_l0001Nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0B?ooool0
02_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo
05gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`18ooooo`00:oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool0GOooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo04Wooooo000[ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0Moooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0BOooool002cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`1gooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool00_l0001<ooooo`00;?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0H?ooool3
o`0004gooooo000/ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0N?ooool2o`00
0;7ooooo000/ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0N?ooool00ol0003o
ooooooooo`2`ooooo`00;?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo07Sooooo
00?o0000ooooooooool0/?ooool002gooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`1iooooo`03o`000?oooooooooo0;3ooooo000]ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0NOooool00ol0003oooooooooo`2`ooooo`00;Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0/?ooool002gooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo0;3ooooo000^ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0NOooool2o`000;7ooooo000^ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`2`ooooo`00;_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0/?ooool0
02oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Oooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oo
oooooooo0;3ooooo000_ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Goooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S80
1_ooool00ol0003oooooooooo`2`ooooo`00;oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo063ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0/?ooool002oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1Pooooo`05o`000?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`05ooooo`?o0000
/?ooool0033ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Pooooo`05o`000?oo
ooooooooooooool000003Oooool00ol@413o0000okZj^P06ooooo`03o`000?oooooooooo0;3ooooo
000`ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0HOooool01Ol@413ooooooooo
oooooooo410@00kooooo00?o^[Zjob4Q8Oooool01Oooool00ol0003oooooooooo`2`ooooo`00<?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo067ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003oooooooooo`2`ooooo`00
<Oooool01Ol0003ooooooooooooooooo000006Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`2`ooooo`00<_ooool01?l0
003oooooo`000?l0001oooooo`03o`000?oooooooooo0;3ooooo000booooo`?o0000P?ooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0;3ooooo
002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@00_ooooo
1Ol00006ooooo`?o0000/?ooool009[ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4
A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000oooooooooooo
ooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0/?ooool009[o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co0000
00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=oooo
o`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aoooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00V_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`00
0?oooooooooo00?ooooo0ol0002`ooooo`00V_ooool01Ol0003ooooooooooooooooo000000oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol0003ooooooooo
oooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3o
oooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00[?ooool00ol0003o^[Zjooooo`2iooooo`00[?ooool2oc8b<[[ooooo001mooooo`;o
000000Ko410@oooooooooooo410@o`000?l@410Hooooo`Co000000Go410@ooooooooooooooooodA4
A002o`000007oc8b<_oMgMgooooooooooon7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4
A?nj^[X06_ooool2o`000008oa0@4?ooooooooooooooool@413o0000odA4A?o<c<`4ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07?ooooo001nooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`0000cooooo00?o0000oooooooo
ool01_ooool01omgMgOo<S8booooooooooooc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mg
MgOo410@00Wooooo1_l0000<ooooo`03o`000?oooooooooo00Cooooo00?oV9RHoa0@4?oMgMd00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1cooooo`00
O_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01[ooooo1Ol00006ooooo`03ohN7
QomEEEGooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@4100Loooool007kooooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00003?ooool0
0ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo013ooooo00?o0000ooooooooool02oooool6
o`0000Wooooo00CoA4A4omgMgOoooooo00001?ooool01Oo<c<co8B4Qo`000?mEEEGo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000Loooool007ko
oooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Kooooo`03o`000?oooooooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c00Aooooo`03o`000?oooooooooo01[ooooo00CogMgMoeEEEOoooooo0000
1?ooool01OlQ8B7oQhN7oooooonHV9So000000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool00000Loooool007kooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0
000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol@413o0000o`00
0003o`0001[ooooo00?oMgMgolc<c?l000001?ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100Loooool007ko
oooo00Ko0000oc8b<_oooooooooooc8b<_l0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0Kooooo`03onk^k_m4A4Co000000Cooooo00Go8B4Q
oiRHV?ooooooMgMgoeEEE@03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg07?ooooo001mooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@4100
6?ooool00omEEEGoIVIVo`000005ooooo`Co00004_ooool00ol0003oooooooooo`0Looooo`03ogMg
Mol0003ooooo00?ooooo00Goc<c<oa0@4?l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07?ooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5000) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .05816 m
.02846 .05141 L
.03279 .04599 L
.03793 .04073 L
.04262 .03719 L
.04498 .03589 L
.04622 .03535 L
.04754 .03488 L
.04869 .03456 L
.04996 .0343 L
.05112 .03416 L
.0522 .03411 L
.05352 .03415 L
.05478 .03429 L
.0559 .0345 L
.05713 .03483 L
.05847 .03529 L
.05989 .0359 L
.06244 .03731 L
.06529 .03934 L
.06791 .04162 L
.07382 .0481 L
.07893 .05517 L
.08454 .06459 L
.09429 .08597 L
.10458 .11793 L
.11478 .16125 L
.12409 .20934 L
.13495 .26784 L
.13973 .29087 L
.145 .31208 L
.1473 .31955 L
.14978 .3262 L
.15211 .33105 L
.15315 .33274 L
.15426 .33421 L
.15544 .33542 L
.15655 .33619 L
.15786 .33667 L
.15905 .33668 L
.16029 .33626 L
.16099 .33584 L
.16164 .33533 L
.16283 .33409 L
.16409 .33236 L
.16655 .32777 L
.1692 .32116 L
.17397 .30525 L
.18485 .25536 L
.2046 .15379 L
Mistroke
.21502 .10996 L
.22613 .07416 L
.2317 .06005 L
.23695 .04886 L
.24206 .03975 L
.24676 .03281 L
.25595 .02271 L
.26079 .01897 L
.26589 .01591 L
.27539 .0118 L
.28556 .00833 L
.2951 .00517 L
.30391 .00256 L
.30886 .00145 L
.31136 .00103 L
.31411 .00069 L
.31555 .00057 L
.31686 .00049 L
.31756 .00045 L
.31831 .00043 L
.3191 .00041 L
.31983 .0004 L
.32053 .0004 L
.32119 .00041 L
.32242 .00044 L
.32312 .00046 L
.32375 .00049 L
.32519 .00057 L
.33021 .00097 L
.3356 .00147 L
.33821 .00168 L
.33949 .00176 L
.34068 .00182 L
.34176 .00186 L
.34291 .00189 L
.34405 .0019 L
.34532 .0019 L
.34651 .00187 L
.34776 .00183 L
.34882 .00177 L
.34999 .00169 L
.35259 .00146 L
.35502 .00116 L
Mfstroke
.35502 .00116 m
.36242 0 L
s
.39345 0 m
.39481 .00023 L
.39964 .00105 L
.40175 .00135 L
.40404 .00163 L
.40543 .00176 L
.40671 .00185 L
.40794 .00191 L
.40924 .00195 L
.4099 .00196 L
.41061 .00196 L
.41189 .00193 L
.41263 .00191 L
.41342 .00187 L
.41481 .00177 L
.41602 .00166 L
.4173 .00151 L
.41962 .00118 L
.42487 .00023 L
s
.42487 .00023 m
.426 0 L
s
.45979 0 m
.4613 .00034 L
.46638 .00145 L
.46877 .00189 L
.47129 .00226 L
.47261 .00241 L
.47331 .00247 L
.47407 .00253 L
.47539 .0026 L
.47663 .00264 L
.47782 .00264 L
.47912 .0026 L
.48035 .00254 L
.48149 .00245 L
.48262 .00233 L
.48365 .00221 L
.48595 .00185 L
s
.48595 .00185 m
.49424 0 L
s
.52862 0 m
.53133 .00064 L
.53419 .00127 L
.5369 .00179 L
.53942 .00217 L
.54084 .00234 L
.54216 .00246 L
.54326 .00254 L
.54448 .00259 L
.54575 .00261 L
.54693 .0026 L
.5481 .00257 L
.54938 .00249 L
.55058 .0024 L
.5517 .00228 L
.55381 .00201 L
.55605 .00164 L
s
.55605 .00164 m
.56392 0 L
s
.59839 0 m
.6014 .00054 L
.60395 .00095 L
.60627 .00127 L
.60842 .00151 L
.61045 .00168 L
.61156 .00174 L
.61259 .00179 L
.61371 .00182 L
.6149 .00182 L
.61602 .00181 L
.61723 .00178 L
.61836 .00173 L
.6194 .00167 L
.62193 .00145 L
.62434 .00119 L
s
.62434 .00119 m
.63244 0 L
s
.66698 0 m
.67399 .00089 L
.67671 .00117 L
.67928 .00137 L
.6816 .00151 L
.6829 .00157 L
.68412 .0016 L
.68527 .00163 L
.68651 .00164 L
.68769 .00164 L
.68877 .00163 L
.68974 .00161 L
.69082 .00158 L
.69193 .00155 L
.69298 .0015 L
.69754 .00126 L
.70242 .00094 L
.70736 .00064 L
.70985 .00052 L
.71127 .00047 L
.7126 .00043 L
.7133 .00042 L
.71404 .00041 L
.71468 .0004 L
.71537 .0004 L
.71611 .0004 L
.71691 .00041 L
.71766 .00042 L
.71835 .00043 L
.71966 .00047 L
.72109 .00053 L
.72243 .0006 L
.72367 .00068 L
.72832 .00111 L
.73097 .00143 L
.73344 .00177 L
.74379 .00364 L
.7542 .00599 L
.76408 .00861 L
.77295 .0115 L
.78262 .01569 L
.78795 .01871 L
.79297 .02216 L
.80234 .03063 L
.81243 .04343 L
.82333 .06248 L
.83286 .08422 L
.84331 .11371 L
.86439 .18643 L
.87444 .22048 L
Mistroke
.87938 .23477 L
.88394 .24568 L
.88644 .25052 L
.8892 .2548 L
.89053 .25646 L
.89196 .25793 L
.89276 .25859 L
.89348 .2591 L
.89417 .25951 L
.8949 .25986 L
.89617 .26024 L
.89734 .26034 L
.89806 .26029 L
.89874 .26015 L
.90001 .25969 L
.90123 .25898 L
.90235 .2581 L
.90487 .25534 L
.90733 .25166 L
.90957 .24748 L
.9146 .23549 L
.92368 .20692 L
.94434 .1331 L
.95959 .09021 L
.96821 .07194 L
.97619 .05816 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`Co00001oooool7o`0000Oo
oooo00?o0000ooooooooool00oooool7o`0000_ooooo00?o0000ooooool000001_l00003ooooo`03
o`000?oooooooooo00Oooooo2?l00006ooooo`03o`000?oooooooooo00Gooooo1ol00009ooooo`03
o`000?oooooooooo00;ooooo2?l00008ooooo`So00001oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool08?ooool002Cooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`0Nooooo`;o00003Oooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo02gooooo00?o0000ooooooooool06_ooool3o`00013ooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0Pooooo`00Loooool3o`0003oooooo00?o0000ooooooooool0COoo
ool3o`00063ooooo001`ooooo`?o0000@_ooool00ol0003oooooooooo`1@ooooo`?o0000GOooool0
06gooooo0ol00015ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0F_ooool006co
oooo00?o0000ooooooooool0A_ooool2o`0005Gooooo0_l0001Jooooo`00Joooool00ol0003ooooo
ooooo`17ooooo`03o`000?oooooooooo05Kooooo0_l0001Hooooo`00J_ooool00ol0003ooooooooo
o`18ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0EOooool006Wooooo00?o0000
ooooooooool0BOooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo05Cooooo001Xoooo
o`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`1Doooo
o`00:_ooool7o`0003Oooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`1Jooooo`03
o`000?oooooooooo05?ooooo000Zooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
<oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0
D_ooool002Sooooo0_l00008ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0Booo
ool2o`0005gooooo00?o0000ooooooooool0DOooool002Oooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0G?ooool0
0ol0003oooooooooo`1Aooooo`009oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo
053ooooo000Vooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooooooo`1=ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0D?ooool002Gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo04kooooo
00?o0000ooooooooool0G_ooool00ol0003oooooooooo`1?ooooo`009?ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0Coooool00ol0003ooooooooo
o`1Nooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool08?ooool003Kooooo00?o0000
ooooooooool0:_ooool00ol0003oooooooooo`1?ooooo`;o0000H?ooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo023ooooo000gooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool0Coooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool08Oooool003Oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1@ooooo`03
o`000?oooooooooo063ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Qooooo`00
>?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02;ooooo000hooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`1Qooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool08_ooool003Wooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`1@ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0Sooooo`00>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
057ooooo0_l0001Rooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool08oooool003[o
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo06;o
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Tooooo`00>_ooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0H_ooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo02Cooooo000jooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool0D_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool09Oooool003_ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0g
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l000000ol@413ooooooooo
o`03ooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`0Uooooo`00>oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03Oooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo06?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Uooooo`00>oooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03Sooooo00Go410@oooooooooooooooooa0@
400>ooooo`03o`000?oooooooooo00Gooooo0ol0001Tooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool09_ooool003cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0h
ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo06Cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Vooooo`00??ooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03Sooooo00Go0000ooooooooooooooooo`00
000>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0I?ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo02Kooooo000looooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool0>Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09ooo
ool003gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0iooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06Gooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0Wooooo`00?Oooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo03Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmV
IVKo000000Oooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo02Oooooo000mooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0EOooool0
0ol0003oooooooooo`1Uooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0:?ooool0
03gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Eooooo`;o0000Ioooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo02Sooooo000nooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool0:?ooool003kooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`1Eooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Yooooo`00?_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05Kooooo00?o
0000ooooooooool0Ioooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Wooooo000n
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`1W
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0:Oooool003oooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo06Oooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Yooooo`00?oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo05Kooooo0_l0001Xooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool0:_ooool003oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Fooooo`03o`00
0?oooooooooo06Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Zooooo`00?ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0J?oo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02[ooooo000oooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`1Xooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool0:oooool0043ooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`1Gooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0[ooooo`00@?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo05Oo
oooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02_o
oooo0010ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0Eoooool2o`0006[ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0/ooooo`00@?ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0JOooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo02cooooo0011ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool0F?ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0;?ooool0047ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1Hoooo
o`03o`000?oooooooooo06[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0]oooo
o`00@Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo05Sooooo00?o0000oooooooo
ool0J_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02gooooo0011ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`1Zooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool0;Oooool0047ooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`1Iooooo`;o0000K?ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo02kooooo0012ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0FOooool0
0ol0003oooooooooo`1[ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0;_ooool0
04;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo
06_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0^ooooo`00@_ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0Joooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo02oooooo0012ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0?_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go
00001_ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0;oooool004;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0oooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006oooo
o`03o`000?oooooooooo06cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0_oooo
o`00@oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03oooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0K?ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo033ooooo0013ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0?oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q
8Oo^k^h01_ooool3o`0006gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0`oooo
o`00@oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03oooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo033ooooo0013ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0?oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool0<?ooool004?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`10ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000
ooooooooool0K_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo037ooooo0013oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0@?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo06kooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0aooooo`00A?ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo037ooooo0014ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0Foooool2o`00073ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0aoooo
o`00A?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05_ooooo00?o0000oooooooo
ool0Koooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo037ooooo0014ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`1`ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0<_ooool004Cooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0booooo`00AOooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo05cooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo03;ooooo0015ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0G?ooool00ol0
003oooooooooo`1aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0<oooool004Go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1Looooo`;o0000L_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo03Cooooo0015ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0GOooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0=?ooool004Gooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`1Mooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0eooooo`00AOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo05gooooo00?o0000
ooooooooool0Loooool2o`0000;ooooo0_l0000gooooo`00A_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo05gooooo00?o0000ooooooooool0M?ooool4o`0003Sooooo0016ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`2`ooooo`00
A_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05kooooo0_l0002aooooo`00A_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0/?oo
ool004Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooo
oooo0;3ooooo0017ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0G_ooool00ol0
003oooooooooo`2`ooooo`00Aoooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05ko
oooo00?o0000ooooooooool0/?ooool004Oooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`1Oooooo`03o`000?oooooooooo0;3ooooo0018ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0Goooool00ol0003oooooooooo`2`ooooo`00B?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo05oooooo0_l0002aooooo`00B?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo05oooooo00?o0000ooooooooool0/?ooool004Sooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo0;3ooooo0018ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05oiRHV?l@413o0000oc8b<_o<c<`01_ooool00ol0003oooooooooo`2`oooo
o`00BOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Kooooo00?o0000
ooooooooool0/?ooool004Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`15oooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo0;3ooooo0019ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0AOooool01Ol0
003ooooooooooooooooo000000kooooo00?oZJVYoa0@4?ooool01Oooool3o`000;3ooooo0019oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0A_ooool01Ol0003ooooooooooooooooo
000000gooooo00?o410@o`000?nj^[X01_ooool00ol0003oooooooooo`2`ooooo`00BOooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo04Kooooo00Go410@oooooooooooooooooa0@400>
ooooo`03okZj^_lQ8B7ooooo00Gooooo00?o0000ooooooooool0/?ooool004[ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`16ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol@413oV9RHoooooonj^[[o000000Kooooo00?o0000ooooooooool0/?ooool004[ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`17ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0/?ooool004_ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo0;3ooooo001;
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H_ooool2o`000;7ooooo001;oooo
o`;o00000_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo0;3ooooo001<ooooo`Co
0000IOooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000
/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@oooooooo
ool01?ooool00ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool009[ooooo
00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool3o`000;3ooooo002Jooooo`05o`00
0?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo
0;3ooooo002Jooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0;3ooooo002Joooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool009[ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Go
oooo00?o0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`?o0000/?ooool009[ooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0/?ooool009[ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`oooo
o`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:cooooo00?o0000okZj^_ooool0^Ooo
ool00:cooooo0_lb<S:jooooo`00OOooool2o`000006oa0@4?oooooooooooa0@4?l0003o410@6?oo
ool4o`000005oa0@4?oooooooooooooooom4A4@00_l000001olb<S;ogMgMooooooooooooQhN7o`00
0?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Wooooo00GoA4A4o`000?l0003o<S8bomgM
g@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP1cooooo`00O_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Oooooo1_l0000<ooooo`03o`000?oooooooooo00Kooooo00OoMgMgoc8b<_oo
ooooooooolc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003Ooo
ool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg07?ooooo001nooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool07oooool01?l0003oooooooooool@4103ooooo`05oa0@4?oo
ooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooooooo
ool0LOooool007kooooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00003?ooool00ol0
003oooooooooo`06ooooo`03ogMgMolb<S;ooooo013ooooo00?o0000ooooooooool02oooool6o`00
00gooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0LOooool007kooooo00Ko
0000omgMgOlb<S;oEEEEomgMgOl0000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c00Aooooo`03o`000?oooooooooo01_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`00001cooooo`00O_ooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`00
01_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03oa0@4?l0003o0000
00?o00006_ooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41000oooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@401cooooo`00O_oo
ool01_l0003o<S8boooooooooooo<S8bo`0001_ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL0Loooool007gooooo00?o410@o`000?n7QhL00_ooool00on7QhOo0000oa0@400H
ooooo`03oeEEEOmVIVKo000000Gooooo1?l0000Booooo`03o`000?oooooooooo01_ooooo1?l00003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP1cooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5100) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .2454 m
.04262 .18972 L
.06244 .11808 L
.07286 .08848 L
.08255 .06777 L
.0932 .05094 L
.10458 .03735 L
.10954 .03258 L
.1148 .02836 L
.11754 .02655 L
.12056 .02492 L
.12189 .02433 L
.12331 .02378 L
.12456 .02338 L
.12589 .02303 L
.12659 .02288 L
.12722 .02277 L
.12846 .0226 L
.12916 .02254 L
.12991 .0225 L
.13062 .02249 L
.13128 .02251 L
.13247 .02259 L
.13377 .02276 L
.13443 .02287 L
.13513 .02302 L
.1364 .02335 L
.13899 .02425 L
.14144 .02539 L
.14603 .02823 L
.15061 .03191 L
.15568 .03687 L
.16593 .04998 L
.17051 .05747 L
.17544 .06711 L
.18435 .08997 L
.19393 .1243 L
.2044 .17387 L
.21545 .23441 L
.22549 .28652 L
.23034 .30712 L
.23288 .3162 L
.23558 .32426 L
.23794 .32989 L
.23919 .33232 L
.24054 .33447 L
.24177 .33603 L
.2429 .33709 L
.24403 .33782 L
.24511 .33819 L
Mistroke
.24643 .33821 L
.24762 .33783 L
.24829 .33744 L
.24901 .3369 L
.25031 .33556 L
.25153 .3339 L
.25282 .33173 L
.25513 .32681 L
.26034 .31119 L
.26606 .28798 L
.28724 .17712 L
.29727 .12862 L
.30653 .09259 L
.31613 .06476 L
.32119 .05351 L
.32655 .04372 L
.33556 .03116 L
.34549 .02134 L
.35561 .01427 L
.36488 .00964 L
.37505 .00604 L
.38016 .00469 L
.38575 .0035 L
.39105 .0026 L
.39605 .00195 L
.40054 .00151 L
.40307 .00133 L
.4054 .00119 L
.40661 .00114 L
.40791 .00109 L
.40903 .00105 L
.41025 .00103 L
.411 .00101 L
.41168 .001 L
.41234 .001 L
.41304 .00099 L
.41425 .00099 L
.41494 .00099 L
.41559 .00099 L
.4169 .00101 L
.41757 .00101 L
.41829 .00103 L
.42077 .00108 L
.42636 .00123 L
.42889 .00131 L
.43022 .00134 L
.43164 .00137 L
.43287 .0014 L
.43352 .00141 L
.43423 .00142 L
Mistroke
.43546 .00143 L
.43662 .00143 L
.43781 .00143 L
.43912 .00142 L
.44035 .0014 L
.44149 .00138 L
.44262 .00134 L
.44365 .00131 L
.44595 .0012 L
.44865 .00104 L
.45113 .00085 L
.45673 .00033 L
Mfstroke
.45673 .00033 m
.45992 0 L
s
.49452 0 m
.49644 .00023 L
.50118 .00083 L
.50388 .00113 L
.5064 .00136 L
.50874 .00153 L
.51005 .0016 L
.51125 .00165 L
.51251 .00169 L
.51323 .0017 L
.51389 .0017 L
.5151 .00169 L
.51639 .00166 L
.51759 .00162 L
.51888 .00155 L
.52122 .00138 L
.5235 .00116 L
.5256 .00091 L
s
.5256 .00091 m
.53183 0 L
s
.56683 0 m
.57051 .00062 L
.57337 .00107 L
.57605 .00144 L
.57833 .00169 L
.5795 .0018 L
.58077 .00189 L
.5815 .00194 L
.58216 .00197 L
.58348 .00201 L
.58468 .00203 L
.58596 .00202 L
.58717 .00199 L
.58848 .00192 L
.58971 .00184 L
.59084 .00175 L
.59347 .00146 L
.59624 .00107 L
.602 6e-05 L
s
.602 6e-05 m
.60233 0 L
s
.63824 0 m
.64297 .00082 L
.64561 .00121 L
.64808 .00149 L
.64923 .0016 L
.65032 .00168 L
.65157 .00175 L
.65271 .0018 L
.65397 .00182 L
.65514 .00182 L
.65642 .00179 L
.65707 .00176 L
.65778 .00173 L
.65894 .00165 L
.66 .00157 L
.66238 .00131 L
.6667 .00068 L
s
.6667 .00068 m
.67058 0 L
s
.70578 0 m
.70636 .00011 L
.71091 .00091 L
.7134 .00128 L
.71571 .00156 L
.71703 .00169 L
.71822 .00179 L
.71955 .00187 L
.72028 .0019 L
.72097 .00192 L
.72218 .00194 L
.72329 .00194 L
.72451 .00192 L
.7258 .00186 L
.72693 .00179 L
.72796 .00171 L
.73029 .00148 L
.73449 .00091 L
s
.73449 .00091 m
.74012 0 L
s
.76807 0 m
.76828 4e-05 L
.77383 .00123 L
.77902 .00235 L
.7813 .00279 L
.78378 .0032 L
.78599 .00351 L
.78835 .00377 L
.78966 .00388 L
.79084 .00396 L
.79203 .00402 L
.79316 .00405 L
.79438 .00407 L
.79568 .00408 L
.79679 .00406 L
.79801 .00403 L
.79932 .00399 L
.80072 .00393 L
.80326 .00379 L
.80561 .00365 L
.80685 .00358 L
.80816 .00352 L
.80943 .00346 L
.81058 .00343 L
.81173 .0034 L
.81282 .0034 L
.81388 .00341 L
.815 .00343 L
.81596 .00348 L
.81701 .00354 L
.81814 .00363 L
.81936 .00376 L
.82154 .00407 L
.82412 .00457 L
.82685 .00528 L
.83175 .00699 L
.83702 .00942 L
.84283 .01267 L
.85334 .01955 L
.86296 .02675 L
.8729 .03585 L
.88236 .04777 L
.88753 .0563 L
.89233 .06576 L
.90323 .09308 L
.92336 .1605 L
.93324 .19558 L
.94233 .22418 L
.95024 .24326 L
.95422 .2501 L
Mistroke
.95648 .25302 L
.95859 .25509 L
.95968 .2559 L
.96087 .25657 L
.96199 .25701 L
.96303 .25723 L
.96396 .25729 L
.965 .2572 L
.96607 .25692 L
.96708 .25649 L
.9682 .25583 L
.96937 .25492 L
.97146 .25275 L
.97372 .24966 L
.97619 .2454 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool9o`0000?ooooo00?o0000ooooool000001Ol00004ooooo`03
o`000?oooooooooo00Wooooo2?l00004ooooo`03o`000?oooooooooo00Sooooo1_l00007ooooo`03
o`000?oooooooooo00Gooooo1_l0000:ooooo`03o`000?oooooooooo00;ooooo1_l000000ooooooo
0000ooooo`09ooooo`oo00002_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Pooooo`009?ooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool01_ooool4o`0002?ooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo000000?o0000
:_ooool00ol0003oooooooooo`0Pooooo`00Roooool3o`0002Oooooo00?o0000ooooooooool0Hooo
ool2o`0004_ooooo0029ooooo`;o0000:_ooool00ol0003oooooooooo`1Uooooo`;o0000BOooool0
08Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo
04Kooooo0027ooooo`03o`000?oooooooooo02_ooooo0_l0001Yooooo`;o0000A_ooool004?ooooo
1Ol0000nooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0J_ooool00ol0003ooooo
ooooo`13ooooo`00@Oooool2o`0000Cooooo0_l0000looooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool0Joooool00ol0003oooooooooo`12ooooo`00?oooool2o`0000Sooooo0_l0000i
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`11
ooooo`00?_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Gooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo043ooooo000nooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo06kooooo00?o0000ooooooooool0?oooool003gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
K_ooool00ol0003oooooooooo`0oooooo`00??ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool0<_ooool2o`00073ooooo00?o0000ooooooooool0?_oo
ool003_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0mooooo`00>_ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`1aooooo`03o`000?oooooooooo03cooooo000iooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo077o
oooo00?o0000ooooooooool0??ooool003Wooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0[ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0L_ooool00ol0003ooooo
ooooo`0kooooo`00>?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo03_ooooo000g
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0d
ooooo`;o0000M?ooool00ol0003oooooooooo`0jooooo`00=oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1doooo
o`03o`000?oooooooooo03Wooooo000fooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo07Cooooo00?o0000oooooooo
ool0>Oooool003Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool0MOooool00ol0003oooooooooo`0hooooo`00=Ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo03Sooooo000eooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo07Gooooo00?o0000ooooooooool0>?ooool003Cooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo03Oooooo0_l0001gooooo`03o`000?oooooooooo
03Oooooo000dooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool0=oooool003?ooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool0M_ooool00ol0003oooooooooo`0gooooo`00<oooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0>?ooool00ol0003ooooooooo
o`1gooooo`03o`000?oooooooooo03Kooooo000booooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`0Mooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Gooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo07Oooooo00?o
0000ooooooooool0=_ooool003;ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo01gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool0=_oo
ool003;ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo01kooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Gooooo0ol0
001hooooo`03o`000?oooooooooo03Gooooo000aooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`0Nooooo`05o`000?ooooooooooooooool000003_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0=Ooo
ool0037ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo01kooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0N?ooool00ol0003oooooooooo`0eooooo`00<Oooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07oooool01Ol@413ooooooooooooo
oooo410@00kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1iooooo`03o`000?oo
oooooooo03Cooooo000`ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Oooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0=?ooool0033ooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0NOoo
ool00ol0003oooooooooo`0dooooo`00<?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`1iooooo`03o`000?oooooo
oooo03Cooooo000`ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0kooooo`;o0000Noooool00ol0003oooooooooo`0cooooo`00;oooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`1jooooo`03o`000?oooooooooo03?ooooo000_ooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo07[ooooo
00?o0000ooooooooool0<oooool002oooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0Noooool00ol0003ooooooooo
o`0booooo`00;_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool0??ooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo03;ooooo000^oooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0loooo
o`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0<_ooool002kooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03cooooo0_l0001looooo`03
o`000?oooooooooo03;ooooo000^ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0
<Oooool002gooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo03cooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`0aooooo`00;Oooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0?Oooool0
0ol0003oooooooooo`1looooo`03o`000?oooooooooo037ooooo000]ooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo
07gooooo00?o0000ooooooooool0<?ooool002gooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0OOooool00ol0003o
ooooooooo`0`ooooo`00;?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool0?Oooool2o`0007kooooo00?o0000ooooooooool0<?ooool002cooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03gooooo00?o
0000ooooooooool0OOooool00ol0003oooooooooo`0`ooooo`00;?ooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`1n
ooooo`03o`000?oooooooooo02oooooo000[ooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo07kooooo00?o0000oooo
ooooool0;oooool002_ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0_ooooo`00
:oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo02kooooo000[ooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0nooooo`;o0000P?oo
ool00ol0003oooooooooo`0^ooooo`00:_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`1oooooo`03o`000?oooooo
oooo02kooooo000Zooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0oooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0;_ooool002[o
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03oo
oooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`0]ooooo`00:Oooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool09?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`20ooooo`03
o`000?oooooooooo02gooooo000Yooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0Tooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo083ooooo00?o0000oooo
ooooool0;Oooool002Wooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo02Cooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^
00Oooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`0/ooooo`00:?ooool00ol0003o
ooooooooo`0booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool09Oooool01Ol0003o
oooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`00087ooooo00?o0000oooo
ooooool0;?ooool002Sooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo02Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo
00Gooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`0/ooooo`00:?ooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool09Oooool01Ol@413o
oooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`22oooo
o`03o`000?oooooooooo02_ooooo000Wooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Uooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`0[
ooooo`009oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c006ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0:oooool002Oooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo043ooooo00?o0000
ooooooooool0Poooool00ol0003oooooooooo`0Zooooo`009_ooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0@Oooool2o`0008Cooooo00?o0000oooo
ooooool0:_ooool002Kooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo047ooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`0Yooooo`00
9_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
@Oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo02Wooooo000Uooooo`03o`000?oo
oooooooo03Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`11ooooo`03o`000?oo
oooooooo08Cooooo00?o0000ooooooooool0:Oooool002Gooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0QOooool0
0ol0003oooooooooo`0Xooooo`009Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo
02Sooooo000Tooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`12ooooo`;o0000Qoooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo023o
oooo001Pooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0@_ooool00ol0003ooooo
ooooo`27ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08?ooool0063ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo08Oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Qooooo`00H?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0R?ooool4o`0002Cooooo001Poooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`2`oooo
o`00HOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04?ooooo00?o0000oooooooo
ool0/?ooool0067ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`13ooooo`;o0000
/Oooool0067ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`13ooooo`03o`000?oo
oooooooo0;3ooooo001Qooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0@oooool0
0ol0003oooooooooo`2`ooooo`00HOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
04?ooooo00?o0000ooooooooool0/?ooool006;ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`13ooooo`03o`000?oooooooooo0;3ooooo001Rooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0A?ooool00ol0003oooooooooo`2`ooooo`00H_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0/?ooool006;ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`14ooooo`;o0000/Oooool006;ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo0;3ooooo001Rooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`2`ooooo`00
Hoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02[ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Kooooo00?o0000oooo
ooooool0/?ooool006?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Zooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go410@okZj^_ooooooMgMgoc8b<P06
ooooo`03o`000?oooooooooo0;3ooooo001Sooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0:_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`2`ooooo`00Hoooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
02_ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ojVYZOl@413ooooo00Gooooo0ol0002`
ooooo`00I?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02_ooooo00Go0000oooo
ooooooooooooo`00000=ooooo`03oa0@4?l0003o^[Zj00Kooooo00?o0000ooooooooool0/?ooool0
06Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0[ooooo`05oa0@4?oooooooooo
ooooool@41003_ooool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo0;3ooooo001Toooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0;3ooooo001U
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo0;3ooooo
001Uooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Aoooool00ol0003ooooooooo
o`2`ooooo`00IOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04Oooooo0_l0002a
ooooo`00I_ooool00ol0003oooooooooo`02o`0004[ooooo00?o0000ooooooooool0/?ooool006Ko
oooo0_l000000ooooooo0000ooooo`1:ooooo`03o`000?oooooooooo0;3ooooo001Wooooo`;o0000
C?ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`2`ooooo`00
V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go
00001_ooool3o`000;3ooooo002Jooooo`05o`000?ooooooooooooooool000002oooool01?m4A4Co
gMgMooooool00007ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05o`000?oooooooooooooo
ool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo0;3ooooo002Joooo
o`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooo
oooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool0
0omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009[ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003o
ooooooooo`03ooooo`?o0000/?ooool009[ooooo00Go0000ooooooooooooooooo`00000?ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`oooo
o`00V_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo1?l00006ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00:cooooo00?o0000okZj^_ooool0^Oooool00:cooooo0_lb<S:jooooo`00OOooool2o`00
0006oa0@4?oooooooooooa0@4?l0003o410@6?ooool4o`000005oa0@4?oooooooooooooooom4A4@0
0_l000001olb<S;ogMgMooooooooooooQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co
^[Zj01Wooooo00GoA4A4o`000?l0003o<S8bomgMg@03ooooo`Co000000So410@ooooooooooook^k^
oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1cooooo`00O_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l0000<ooooo`03o`000?oooooooooo
00Kooooo00OoMgMgoc8b<_ooooooooooolc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMg
oa0@4009ooooo`Ko00003Oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Loooool007ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooo
oooooooooooooa0@401cooooo`00O_ooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0
000<ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool04?ooool00ol0003ooooooooo
o`0;ooooo`Ko00003Oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000Loooool007kooooo
00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c00Aooooo`03o`000?oooooooooo01_ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool00000Loooool007kooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Koooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol@413o0000o`000003o`00
01[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41000oooool01Ol@413ooooooooooooooooo410@07?ooooo001nooooo`06o`000?lb<S;o
oooooooooolb<S;o00006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Loooool007go
oooo00?o410@o`000?n7QhL00_ooool00on7QhOo0000oa0@400Hooooo`03oeEEEOmVIVKo000000Go
oooo1?l0000Booooo`03o`000?oooooooooo01_ooooo1?l00004ooooo`03oeEEEOmVIVKo000000Co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0Loooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5200) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .11284 m
.04262 .17703 L
.0522 .21138 L
.05746 .22811 L
.06244 .2413 L
.06506 .24692 L
.0679 .25185 L
.06915 .25361 L
.07047 .25519 L
.07172 .2564 L
.07286 .25727 L
.074 .25792 L
.07524 .25836 L
.07638 .25852 L
.07747 .25846 L
.07873 .25813 L
.0799 .25758 L
.08118 .2567 L
.08255 .25546 L
.08541 .25189 L
.0885 .24662 L
.09411 .23385 L
.10458 .20214 L
.12413 .13542 L
.13448 .10336 L
.14558 .07387 L
.15627 .05145 L
.166 .03697 L
.17069 .03203 L
.1758 .02799 L
.18061 .0252 L
.18507 .02328 L
.1947 .02025 L
.20373 .01784 L
.20856 .01671 L
.2112 .0162 L
.21248 .016 L
.21365 .01584 L
.21494 .01571 L
.21564 .01566 L
.21631 .01563 L
.21704 .0156 L
.21771 .0156 L
.21845 .01561 L
.21922 .01565 L
.22048 .01575 L
.22166 .01591 L
.22295 .01615 L
.22434 .0165 L
.22688 .01739 L
Mistroke
.22959 .01871 L
.23215 .02034 L
.23447 .02213 L
.24016 .02784 L
.24551 .03484 L
.25517 .05108 L
.26561 .07386 L
.27514 .10103 L
.28559 .1409 L
.30667 .25184 L
.31148 .27781 L
.31671 .30299 L
.32165 .32219 L
.32401 .32935 L
.32622 .33475 L
.32754 .33732 L
.32875 .33924 L
.33009 .34088 L
.33079 .34152 L
.33153 .34203 L
.33221 .34236 L
.33293 .34255 L
.33423 .34251 L
.33502 .34223 L
.33577 .3418 L
.33644 .34126 L
.33717 .34054 L
.33837 .33899 L
.3397 .33682 L
.34236 .33095 L
.34484 .32386 L
.34715 .31593 L
.35758 .26817 L
.36747 .21448 L
.38602 .1251 L
.39566 .09071 L
.40591 .06212 L
.41465 .04306 L
.42432 .02745 L
.42923 .02174 L
.4344 .01727 L
.43881 .01458 L
.44131 .01345 L
.44364 .0126 L
.44636 .01182 L
.44892 .01124 L
.45372 .01038 L
.46449 .00829 L
.48278 .00218 L
.4878 .00065 L
Mistroke
Mfstroke
.4878 .00065 m
.49056 0 L
s
.50823 0 m
.51239 .00074 L
.51779 .00173 L
.52016 .00209 L
.52151 .00227 L
.52278 .00241 L
.52398 .00251 L
.52529 .0026 L
.52596 .00263 L
.52668 .00265 L
.52795 .00267 L
.52863 .00267 L
.52935 .00265 L
.53064 .0026 L
.53143 .00255 L
.53218 .0025 L
.53358 .00236 L
.53614 .00204 L
.53849 .00165 L
.54381 .0006 L
s
.54381 .0006 m
.54673 0 L
s
.57733 0 m
.57765 5e-05 L
.58036 .0005 L
.58323 .00093 L
.58583 .00124 L
.5873 .00138 L
.58869 .00148 L
.58995 .00155 L
.59111 .00158 L
.59175 .0016 L
.59245 .0016 L
.59372 .00159 L
.59503 .00155 L
.59621 .0015 L
.59758 .00141 L
.59887 .00129 L
.60364 .00071 L
s
.60364 .00071 m
.60824 0 L
s
.64293 0 m
.64691 .00048 L
.6495 .00073 L
.65072 .00082 L
.65185 .00089 L
.65292 .00094 L
.65405 .00099 L
.65518 .00101 L
.65643 .00102 L
.6575 .00101 L
.65866 .00099 L
.65975 .00095 L
.66075 .00091 L
.66326 .00075 L
.66553 .00055 L
.67062 2e-05 L
s
.67062 2e-05 m
.67076 0 L
s
.70375 0 m
.70542 .00018 L
.71007 .00063 L
.71263 .00082 L
.71399 .0009 L
.71542 .00096 L
.71662 .001 L
.7173 .00102 L
.71794 .00103 L
.71907 .00105 L
.72027 .00105 L
.7215 .00103 L
.72263 .00101 L
.72388 .00097 L
.7252 .00091 L
.72742 .00079 L
.72988 .00062 L
s
.72988 .00062 m
.7376 0 L
s
.76734 0 m
.76865 7e-05 L
.7712 .00017 L
.7726 .00022 L
.77392 .00026 L
.77515 .00029 L
.7758 .0003 L
.77648 .00031 L
.77769 .00032 L
.77881 .00033 L
.78007 .00032 L
.78122 .00031 L
.78185 .00031 L
.78255 .00029 L
.7838 .00027 L
.78622 .0002 L
.78846 .00013 L
s
.78846 .00013 m
.79178 0 L
s
.81266 0 m
.81759 .00031 L
.82664 .00096 L
.82924 .00111 L
.83172 .00123 L
.83394 .00131 L
.83519 .00134 L
.83636 .00136 L
.83703 .00137 L
.83775 .00137 L
.83907 .00138 L
.84035 .00137 L
.84152 .00136 L
.8428 .00135 L
.8442 .00133 L
.84702 .00127 L
.84952 .00122 L
.85089 .0012 L
.85218 .00118 L
.85339 .00117 L
.8547 .00117 L
.8559 .00118 L
.857 .0012 L
.85824 .00123 L
.85943 .00128 L
.86049 .00133 L
.86165 .0014 L
.86424 .00161 L
.86665 .00187 L
.87103 .00252 L
.87571 .00345 L
.89632 .00888 L
.9066 .01183 L
.912 .01373 L
.91772 .01631 L
.92272 .01929 L
.92822 .02353 L
.93788 .03386 L
.94755 .04796 L
.95636 .06404 L
.97619 .11284 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool00oooool2o`0000Cooooo00?o0000ooooooooool00_ooool8o`0000_o
oooo00?o0000ooooool000001?l00005ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool01?l0003ooooooooooooooolAo`0000?ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo023ooooo000Tooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Tooooo`?o00001_ooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool04_ooool3o`0001So
oooo00?o0000ooooooooool08?ooool00:Kooooo1_l00009ooooo`03o`000?oooooooooo07Gooooo
0ol0000hooooo`00Xoooool3o`0000oooooo00?o0000ooooooooool0N?ooool4o`0003Cooooo001L
ooooo`Oo0000?_ooool2o`0001;ooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`0a
ooooo`00Eoooool5o`0000Oooooo0_l0000kooooo`03o`000?oooooooooo01;ooooo0_l0001noooo
o`;o0000<Oooool005Gooooo0_l0000=ooooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo02kooooo001Dooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo083ooooo00?o0000ooooooooool0;Oooool005;ooooo0_l0000Booooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`21ooooo`03o`000?oo
oooooooo02cooooo001Aooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0:oooool0
053ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`0[ooooo`00D?ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`23ooooo`03o`000?oooooooooo02[ooooo001?ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Gooooo`;o0000QOooool00ol0003ooooo
ooooo`0Yooooo`00C_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo02Wooooo001>
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool0:?ooool004gooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool0QOooool00ol0003oooooooooo`0Xooooo`00COooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo02_ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`26ooooo`03
o`000?oooooooooo02Oooooo001<ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
:_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool0
9oooool004cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo01[ooooo0_l00027ooooo`03o`000?oooooooooo02Oooooo001;ooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo08Oooooo00?o0000ooooooooool09_ooool004[ooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0Qoooool00ol0
003oooooooooo`0Vooooo`00B_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo02Go
oooo0019ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool09Oooool004Wooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool0ROooool00ol0003oooooooooo`0Tooooo`00B?ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07?ooool2o`0008[ooooo00?o0000
ooooooooool09?ooool004Sooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`0Toooo
o`00B?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo02?ooooo0017ooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo08[ooooo00?o0000ooooooooool08oooool004Oooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00;ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0
Roooool00ol0003oooooooooo`0Rooooo`00Aoooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Roooool00ol0003ooooo
ooooo`0Rooooo`00A_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool00oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0
1Oooool3o`0008cooooo00?o0000ooooooooool08Oooool004Kooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0S?ooool00ol0003ooooo
ooooo`0Qooooo`00A_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo027ooooo000Tooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo00Cooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0SOooool00ol0003oooooooooo`0Pooooo`009?ooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo000Tooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Cooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0/?ooool002Gooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`2`ooooo`009Oooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0P
ooooo`;o0000/Oooool002Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`2`oooo
o`009_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0;3ooooo000Vooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool0/?ooool002Kooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`2`ooooo`009oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo0;3ooooo000Wooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo027ooooo0_l0002aooooo`009oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo0;3ooooo000Wooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool0/?ooool002Sooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`2`ooooo`00:?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo0;3ooooo000Xoooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0/?ooool002Wooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool08_ooool2o`000;7ooooo000Yooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
/?ooool002Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`2`ooooo`00:_ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo0;3ooooo000Zooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool0/?ooool002[ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0dooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`2`ooooo`00:_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Sooooo`;o0000/Oooool002_ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`2`ooooo`00:oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo0;3ooooo000[ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool0/?ooool002cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0fooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool02Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`2`ooooo`00;?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`09ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q
8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0;3ooooo000/ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
00Wooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000
ooooooooool0/?ooool002gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo
000000gooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo000]ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00[ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000
ooooooooool0/?ooool002gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0ioooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02_ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2`ooooo`00;_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0:ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonH
V9So410@00Kooooo00?o0000ooooooooool0/?ooool002kooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0jooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`00
0?oooooooooo0;3ooooo000^ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0/?oo
ool002oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool09_ooool2o`000;7ooooo000_ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool0/?ooool002oooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0looooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`2`ooooo`00<?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03cooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo0;3ooooo
000`ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0?Oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0/?ooool0033ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`2`ooooo`00<Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Woooo
o`;o0000/Oooool0037ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`2`ooooo`00
<_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo0;3ooooo000cooooo`Co0000@ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0/?oo
ool003Cooooo0_l00014ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`2`ooooo`00Noooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool0/?ooool007_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Xooooo`;o0000/Oooool007_ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo0;3ooooo001looooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`2`ooooo`00O?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0/?ooool007cooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0;3ooooo001looooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`2`ooooo`00
O?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
/?ooool007cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Zooooo`;o0000/Ooo
ool007gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo0;3ooooo001mooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`2`ooooo`00OOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;o
c<c<00Kooooo00?o0000ooooooooool0/?ooool007gooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go410@
okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo0;3ooooo001mooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool04?ooool01Ol@413ooooooooooooooooo410@00oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`2`ooooo`00O_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo013ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ojVYZOl@
413ooooo00Gooooo0ol0002`ooooo`00O_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo017ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oa0@4?l0003o^[Zj00Kooooo00?o
0000ooooooooool0/?ooool007kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0A
ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onj^[[o8B4Qooooo`05ooooo`03o`000?oo
oooooooo0;3ooooo001oooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`00
0?oooooooooo0;3ooooo001oooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04Ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03
o`000?oooooooooo0;3ooooo001oooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`2`ooooo`00Ooooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo02gooooo0_l0002aooooo`00Ooooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo02gooooo00?o0000ooooooooool0/?ooool0083ooooo00Go0000ooooooooooooooooo`00000`
ooooo`03o`000?oooooooooo0;3ooooo0021ooooo`04o`000?ooooooooooo`00033ooooo00?o0000
ooooooooool0/?ooool0087ooooo0ol0000aooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
0006ooooo`?o0000/?ooool009[ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oM
gMgoooooo`0000Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000oooooooooooooooo
o`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0/?ooool009[ooooo
00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooooooo
ool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oo
oooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03
ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00V_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oo
oooooooo00?ooooo0ol0002`ooooo`00V_ooool01Ol0003ooooooooooooooooo000000oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol0003ooooooooooooo
oooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo
002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00[?ooool00ol0003o^[Zjooooo`2iooooo`00[?ooool2oc8b<[[ooooo001mooooo`;o0000
00Ko410@oooooooooooo410@o`000?l@410Hooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000007oc8b<_oMgMgooooooooooon7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj
^[X06Oooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo1Ol00003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07?ooooo001nooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01oooool6o`0000cooooo00?o0000ooooooooool01_ooool0
1omgMgOo<S8booooooooooooc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wo
oooo1_l0000=ooooo`09ogMgMolb<S;ooooooooooonHV9So8B4Qonk^k_ooooooA4A400?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Loooool007kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0Oooooo`07o`000?oooooooooooooooonH
V9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@07?ooooo001nooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000cooooo
00?o0000ooooooooool01_ooool00omgMgOo<S8booooo`0@ooooo`03o`000?oooooooooo00_ooooo
1_l0000=ooooo`03ogMgMolb<S;ooooo00?ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00001cooooo`00O_ooool01_l0003o
gMgMoc8b<_mEEEGogMgMo`0001_ooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<017ooooo00?o0000ooooooooool06oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`00001cooooo`00O_ooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001_ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03oa0@4?l0003o000000?o00006_ooool0
0ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooo
oooooooo410@00?ooooo00?o410@ooooooooool0LOooool007kooooo00Ko0000oc8b<_oooooooooo
oc8b<_l0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo00Go0000okZj^_ooooooV9RHoa0@4003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg07?ooooo001m
ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool00omEEEGoIVIVo`000005
ooooo`Co00004_ooool00ol0003oooooooooo`0Kooooo`Co00000oooool01OnHV9So410@o`000?lQ
8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h0Loooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5300) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01455 m
.02846 .0162 L
.03279 .01794 L
.03754 .02031 L
.04262 .02362 L
.04795 .02823 L
.053 .03386 L
.06244 .04801 L
.07295 .06924 L
.08265 .09351 L
.10458 .16232 L
.11437 .19625 L
.11977 .21404 L
.1249 .22932 L
.12965 .24127 L
.13216 .24651 L
.13484 .25113 L
.13731 .25445 L
.13955 .25661 L
.14064 .25735 L
.14181 .25793 L
.14291 .25826 L
.14393 .25837 L
.14508 .25828 L
.14612 .258 L
.14732 .25743 L
.14847 .25666 L
.15049 .25473 L
.1527 .25184 L
.15513 .24775 L
.1577 .24241 L
.16233 .23054 L
.18177 .16273 L
.19136 .12901 L
.20146 .09882 L
.21952 .05907 L
.22876 .04392 L
.23886 .0306 L
.24409 .02512 L
.24967 .02041 L
.25493 .01704 L
.25972 .01483 L
.26203 .01403 L
.26457 .01332 L
.26722 .01275 L
.2697 .01235 L
.27202 .01207 L
.27414 .01188 L
.27531 .0118 L
.27658 .01172 L
Mistroke
.2777 .01167 L
.2789 .01162 L
.28032 .01158 L
.28165 .01155 L
.28294 .01153 L
.28413 .01152 L
.28542 .01151 L
.28616 .01151 L
.28684 .01151 L
.28756 .01152 L
.28822 .01152 L
.28898 .01153 L
.2897 .01154 L
.29091 .01157 L
.29219 .0116 L
.29328 .01164 L
.29449 .0117 L
.29579 .01177 L
.29718 .01188 L
.2997 .01212 L
.30211 .01245 L
.30468 .01292 L
.3071 .01351 L
.3093 .01417 L
.31189 .01513 L
.31469 .01641 L
.31978 .01947 L
.32512 .02379 L
.33077 .02972 L
.34089 .04423 L
.35036 .06325 L
.36051 .09141 L
.37009 .12723 L
.37883 .16811 L
.38885 .22177 L
.3995 .27856 L
.40388 .2989 L
.4086 .31728 L
.4113 .32573 L
.41378 .33196 L
.41615 .33647 L
.41734 .33817 L
.41865 .33959 L
.41988 .3405 L
.42058 .34082 L
.42123 .341 L
.42241 .34102 L
.42367 .3406 L
.42479 .33986 L
.42584 .33884 L
Mistroke
.42699 .33738 L
.42823 .33539 L
.43098 .32955 L
.43358 .32223 L
.43848 .30434 L
.44731 .26171 L
.45694 .20811 L
.46708 .15414 L
.47663 .1121 L
.48192 .09331 L
.48764 .07637 L
.49761 .05367 L
.50712 .03765 L
.51756 .02426 L
.52282 .01892 L
.52846 .01427 L
.53378 .01091 L
.53609 .00975 L
.53863 .00867 L
.54344 .00714 L
.54608 .00654 L
.54856 .0061 L
.55297 .00553 L
.55773 .00508 L
.56301 .00459 L
.56857 .00392 L
.57331 .00317 L
.5785 .00219 L
.58334 .00124 L
.58859 .00029 L
Mfstroke
.58859 .00029 m
.59056 0 L
s
.61113 0 m
.61427 .00038 L
.61908 .00102 L
.62145 .0013 L
.62369 .00152 L
.62492 .00162 L
.62627 .00172 L
.62749 .00178 L
.62862 .00182 L
.62986 .00184 L
.63103 .00184 L
.63231 .00182 L
.63303 .0018 L
.63369 .00177 L
.63501 .0017 L
.63645 .00159 L
.63907 .00132 L
.64436 .00055 L
s
.64436 .00055 m
.64753 0 L
s
.68161 0 m
.68664 .00092 L
.68912 .00132 L
.69138 .00162 L
.69377 .00187 L
.69508 .00197 L
.69632 .00203 L
.69697 .00206 L
.69767 .00207 L
.69891 .00208 L
.6996 .00208 L
.70025 .00206 L
.70096 .00204 L
.70172 .002 L
.70306 .00192 L
.70427 .00181 L
.70698 .0015 L
.71185 .00071 L
s
.71185 .00071 m
.71549 0 L
s
.74966 0 m
.75216 .00047 L
.75457 .00092 L
.75719 .00134 L
.75966 .00166 L
.76084 .00179 L
.76194 .00188 L
.76324 .00196 L
.76393 .00199 L
.76468 .00202 L
.76545 .00203 L
.76619 .00203 L
.76685 .00203 L
.76757 .00201 L
.76885 .00196 L
.7695 .00192 L
.77022 .00187 L
.77267 .00162 L
.77515 .00128 L
.77782 .00082 L
s
.77782 .00082 m
.78192 0 L
s
.81714 0 m
.81847 .00029 L
.82375 .00135 L
.82605 .00173 L
.82853 .00204 L
.82995 .00217 L
.83124 .00226 L
.83254 .00231 L
.83377 .00234 L
.83489 .00233 L
.83607 .0023 L
.83708 .00225 L
.83819 .00217 L
.83939 .00206 L
.84067 .00191 L
.843 .00159 L
s
.843 .00159 m
.85114 0 L
s
.88251 0 m
.88387 .0003 L
.88909 .00147 L
.89184 .00202 L
.89474 .00251 L
.89728 .00283 L
.89873 .00297 L
.89942 .00302 L
.90007 .00306 L
.90131 .00312 L
.90244 .00314 L
.90365 .00315 L
.90497 .00312 L
.90619 .00307 L
.90731 .003 L
.90861 .0029 L
.90983 .00278 L
.9144 .00221 L
.91978 .00143 L
.92241 .00108 L
.92479 .00083 L
.92599 .00073 L
.92729 .00064 L
.92852 .00059 L
.92965 .00056 L
.93085 .00057 L
.93217 .0006 L
.93284 .00063 L
.93355 .00068 L
.93484 .00079 L
.93625 .00095 L
.93778 .00118 L
.94057 .00174 L
.94581 .00319 L
.97619 .01455 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Go
oooo1_l0000:ooooo`Oo00001Oooool00ol0003oooooooooo`06ooooo`Oo00002?ooool00ol0003o
ooooooooo`03ooooo`Oo00002oooool00ol0003oooooo`000006o`0000?ooooo00?o0000oooooooo
ool01oooool:o`0000Cooooo1Ol00007ooooo`03o`000?oooooooooo023ooooo000Tooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo00[ooooo1ol0000Looooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
9_ooool2o`0000Gooooo00?o0000ooooooooool08?ooool00;Gooooo00?o0000ooooooooool01ooo
ool3o`0007kooooo0ol0000Uooooo`00KOooool?o`0003Wooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`22ooooo`;o00008oooool002Cooooo0ol00013ooooo`?o00003oooool2o`00
03Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo
023ooooo000Wooooo`?o0000?oooool00ol0003oooooooooo`0Booooo`;o0000=Oooool2o`0000Go
oooo00?o0000ooooooooool0ZOooool002[ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2Zooooo`00:oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0:_ooooo000/
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Zoooool002gooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo033ooooo00Go0000oooo
ooooooooooooo`00002^ooooo`00;Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool0;oooool01?l0003oooooooooool0002_ooooo`00;_ooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0;_ooool00ol0
003oooooo`00002`ooooo`00;oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool0;_ooool3o`000;3ooooo000_ooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0]ooooo`;o0000/Oooool0033ooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool0/?ooool0033ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo02_ooooo0_l0002booooo`00<Oooool00ol0003oooooooooo`0]oooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0:oooool2o`000;;ooooo000aooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooo00000;;ooooo000booooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0Yooooo`04o`000?oooooo0000o`000;7ooooo000booooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Xooooo`04o`00
0?ooooooooooo`000;;ooooo000cooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0Wooooo`04o`000?ooooooooooo`000;;ooooo000cooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Wooooo`04o`00
0?ooooooooooo`000;;ooooo000dooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`0Uooooo`05o`000?ooooooooooooooool00000/_ooool003Cooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02Gooooo
00Go0000ooooooooooooooooo`00002booooo`00=?ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`02ooooo`;o0000
/Oooool003Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2`ooooo`00=Oooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo0;3ooooo000eooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0/?ooool003Kooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo00cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1Oooool5o`0000Gooooo00?o0000ooooooooool0/?ooool003Kooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00cooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo
0;3ooooo000gooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooooooo`0<ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooo`000005oooo
o`?o0000/?ooool003Oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000>ooooo`;o00001_ooool00ol0
003oooooooooo`2`ooooo`00=oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000000kooooo0_l00006oooo
o`03o`000?oooooooooo0;3ooooo000hooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`0;ooooo`05oa0@4?ooooooooooooooool@41003_ooool2o`00
00Kooooo00?o0000ooooooooool0/?ooool003Sooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>oooo
o`;o00001_ooool00ol0003oooooooooo`2`ooooo`00>?ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo00CoEEEEofIVI_l0003o00001_ooool00ol0003oooooooooo`2`ooooo`00>Oooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0;3ooooo000iooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Go
oooo0_l0002aooooo`00>Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;3ooooo
000jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool003[ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`2`ooooo`00>_ooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo03Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo0;3ooooo000kooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0/?ooool003_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool01_ooool2o`000;7ooooo000kooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0/?ooool003cooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`2`ooooo`00??ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
0;3ooooo000looooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool003gooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00?Oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`07ooooo`;o0000/Oooool003gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2`
ooooo`00?_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0;3ooooo000nooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0/?ooool003kooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`2`ooooo`00?oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo0;3ooooo000oooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0??ooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Wooooo0_l0002aooooo`00?oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo0;3ooooo000oooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0/?ooool0043ooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0mooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`2`ooooo`00@?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03kooooo00?o
0000ooooooooool01Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B43ooooo`Ko0000
1_ooool00ol0003oooooooooo`2`ooooo`00@?ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo03kooooo00?o0000ooooooooool01Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B42ooooo`07o`000?ooooooV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo
0;3ooooo0010ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`05ooooo`05oa0@4?ooooooooooooooool@41002Oooool01_l0003ooooooooooonHV9So
8B4Qonk^kPOooooo00?o0000ooooooooool0/?ooool0047ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`00
0009ooooo`07o`000?oooooooooooooooonHV9So8B4Qonk^kP06ooooo`?o0000/?ooool0047ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Gooooo
00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo00;ooooo00?oMgMgofIVI_oo
ool01Oooool00ol0003oooooooooo`2`ooooo`00@Oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo043ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00Wo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;3o
oooo0011ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0@Oooool00ol0003ooooo
ooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02Oooool01ol0003oooooo`000?nj^[[ooooo
oiRHV?l@41001_ooool00ol0003oooooooooo`2`ooooo`00@_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo047ooooo00?o0000ooooooooool01?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Sooooo00So0000ooooooooooooV9RHoa0@4?l0003o8B4Qolc<c0Kooooo00?o0000oooooooo
ool0/?ooool004;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`11ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2`ooooo`00@_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0;ooooo`;o0000/Oooool004?ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`12ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`2`ooooo`00@oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
04?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
0;3ooooo0014ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0@oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0/?ooool004Cooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`2`ooooo`00A?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo0;3ooooo0015ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0AOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00cooooo0_l0002a
ooooo`00A_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04Gooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0;3ooooo0017ooooo`05
o`000?ooooooooooooooool00000BOooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0/?ooool004Sooooo0ol0001:ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`2`ooooo`00BOooool00ol0003ooooo
ooooo`19ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`2`ooooo`00UOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool0/?ooool009Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=
ooooo`;o0000/Oooool009Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo0;3ooooo002Fooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`2`ooooo`00U_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0/?ooool009Kooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo0;3ooooo002Fooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2`ooooo`00Uoooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/?ooool009Oo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0?ooooo`;o0000/Oooool009Oooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;3ooooo
002Hooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`2`ooooo`00V?ooool01ol0003oooooonk^k_lb<S;o0000oc8b<_o^k^h01?ooool00ol0003o8B4Q
ob4Q8@04ooooo`05oiRHV?l@413o0000oc8b<_o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00
V?ooool01ol0003oooooogMgMonHV9SooooooiRHV?mgMgL00oooool01?l0003oooooob4Q8OlQ8B44
ooooo`05oa0@4?nj^[[oooooogMgMolb<S801_ooool00ol0003oooooooooo`2`ooooo`00V?ooool0
0ol0003ooooooa0@4003ooooo`05oa0@4?ooooooooooooooool000002oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo0;3ooooo002Iooooo`;o00000oooool01Ol0003ooooooooooooo
oooo000000[ooooo00?oZJVYoa0@4?ooool01Oooool3o`000;3ooooo002Iooooo`;o00000oooool0
1Ol0003ooooooooooooooooo000000Wooooo00?o410@o`000?nj^[X01_ooool00ol0003ooooooooo
o`2`ooooo`00VOooool00ol0003o410@ooooo`02ooooo`04oa0@4?ooooooooooo`0000_ooooo00?o
^[Zjob4Q8Oooool01Oooool00ol0003oooooooooo`2`ooooo`00VOooool01_l0003oMgMgoiRHV?oo
ooooV9RHogMgM`;ooooo00?o0000ooooooooool01_ooool01Ol@413oV9RHoooooonj^[[o000000Ko
oooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000oc8b<_l0003o<S8bonk^kP02ooooo`03
o`000?oooooooooo00Kooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo
0;3ooooo002Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`2`ooooo`00V_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01;ooooo
0_l0002aooooo`00Voooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool0/?ooool009_ooooo00Go0000ooooooooooooooooo`00000Eooooo`03o`000?oo
oooooooo0;3ooooo002Looooo`Co00005Oooool00ol0003oooooooooo`2`ooooo`00WOooool2o`00
01Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo00Cooooo00?o0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool00ol0003ooooo
ooooo`2`ooooo`00V_ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@00co
oooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003o
ooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aoooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Joooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@05ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00V_ooool0
1Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000;3ooooo002J
ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0;3ooooo002Jooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002/ooooo`03o`000?nj^[[ooooo
0;Wooooo002/ooooo`;o<S8b^_ooool007gooooo0_l000001_l@413oooooooooool@413o0000oa0@
41Sooooo1?l000001Ol@413oooooooooooooooooA4A400;o000000Oo<S8bomgMgOooooooooooohN7
Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Iooooo`05odA4A?l0003o0000oc8b
<_oMgMd00_ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0Loooool007kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`07ooooo`Ko00003?ooool00ol0003oooooooooo`06ooooo`07ogMgMolb
<S;oooooooooooo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`00
00gooooo00WoMgMgoc8b<_oooooooooooa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1cooooo`00O_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooo
oooo077ooooo001nooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000cooooo00?o
0000ooooooooool01_ooool00omgMgOo<S8booooo`0@ooooo`03o`000?oooooooooo00_ooooo1_l0
000=ooooo`03ogMgMolb<S;ooooo00Cooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`00001cooooo`00O_ooool01_l0003ogMgM
oc8b<_mEEEGogMgMo`0001_ooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<017ooooo00?o0000ooooooooool06oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o
410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`00001cooooo`00O_ooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001_ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Aooooo`03oa0@4?l0003o000000?o00006_ooool00ol0
003oooooooooo`07ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@4100Loooool007kooooo00Ko0000oc8b<_oooooooooooc8b
<_l0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo00Cooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg07?ooooo001moooo
o`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool00omEEEGoIVIVo`000005oooo
o`Co00004_ooool00ol0003oooooooooo`0Kooooo`Co00000oooool01OnYZJWo410@o`000?l@413o
ZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
Loooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5400) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02865 0 m
.04262 .00275 L
.0522 .0055 L
.05496 .00612 L
.05756 .0066 L
.0599 .00693 L
.06244 .00719 L
.0637 .00729 L
.06507 .00737 L
.06577 .0074 L
.06651 .00743 L
.06715 .00745 L
.06786 .00747 L
.06855 .00748 L
.0692 .00749 L
.07047 .00751 L
.07161 .00752 L
.07286 .00754 L
.07412 .00756 L
.07532 .00759 L
.07648 .00764 L
.07755 .00769 L
.07871 .00777 L
.07998 .00789 L
.08131 .00805 L
.08255 .00824 L
.08392 .0085 L
.08541 .00884 L
.08811 .00966 L
.09075 .01071 L
.09318 .01194 L
.09871 .01562 L
.10458 .02084 L
.12405 .04475 L
.13278 .05781 L
.14233 .07514 L
.15216 .09873 L
.16251 .13147 L
.18102 .20115 L
.1863 .21923 L
.19129 .23376 L
.19577 .24408 L
.1983 .2486 L
.20063 .2519 L
.20184 .25326 L
.20313 .25446 L
.20436 .25535 L
.20547 .25594 L
.20678 .25638 L
.20752 .25651 L
Mistroke
.20821 .25655 L
.20947 .25642 L
.21017 .25625 L
.2108 .25602 L
.21148 .25571 L
.2122 .2553 L
.21347 .25439 L
.21485 .25314 L
.21636 .25146 L
.22158 .24329 L
.22684 .23183 L
.23181 .21856 L
.24113 .1892 L
.26206 .11674 L
.27173 .08725 L
.282 .06246 L
.29077 .04717 L
.29576 .04059 L
.30044 .03552 L
.32066 .01965 L
.32962 .01387 L
.33454 .01111 L
.33918 .00897 L
.34165 .00804 L
.34433 .00723 L
.34551 .00694 L
.34676 .00668 L
.34901 .00632 L
.35009 .00619 L
.35126 .0061 L
.35235 .00604 L
.35336 .00602 L
.35453 .00602 L
.35581 .00606 L
.35702 .00613 L
.35814 .00622 L
.3606 .00649 L
.36291 .00683 L
.36818 .00775 L
.37885 .00962 L
.38867 .01098 L
.39361 .01183 L
.3964 .01249 L
.39901 .01327 L
.40142 .01418 L
.40369 .01523 L
.40795 .01778 L
.41253 .02148 L
.41751 .02673 L
.42696 .04044 L
Mistroke
.43736 .06139 L
.44822 .09092 L
.45839 .1279 L
.47695 .2206 L
.48675 .27429 L
.49212 .30041 L
.49719 .32055 L
.49995 .32917 L
.50141 .33293 L
.50294 .33629 L
.50424 .33862 L
.50566 .34062 L
.50695 .34193 L
.50816 .34271 L
.50948 .34306 L
.51073 .34292 L
.51185 .34239 L
.51307 .3414 L
.5137 .34071 L
.5144 .33982 L
.51581 .33759 L
.51834 .33218 L
.52094 .32486 L
.52333 .31671 L
.5287 .29403 L
.53843 .24322 L
.54837 .18844 L
.55897 .13681 L
.56898 .09837 L
.57807 .07142 L
.58749 .04964 L
.59245 .04023 L
.59769 .03174 L
.60228 .02553 L
.60733 .02004 L
.61191 .01623 L
.6162 .01359 L
.61879 .01238 L
.62119 .01149 L
.62382 .01071 L
.62662 .01006 L
.63181 .00918 L
.63651 .00849 L
.6411 .00772 L
.64606 .00664 L
.65505 .00405 L
.66005 .00246 L
.6654 .00091 L
.66799 .0003 L
Mfstroke
.66799 .0003 m
.66951 0 L
s
.68967 0 m
.69043 .00011 L
.69612 .00094 L
.69864 .00127 L
.70099 .00152 L
.70228 .00163 L
.70345 .00172 L
.70475 .00179 L
.70546 .00181 L
.70614 .00183 L
.70725 .00185 L
.70843 .00185 L
.70944 .00183 L
.71056 .00179 L
.71175 .00173 L
.71303 .00164 L
.71536 .00143 L
.7253 4e-05 L
s
.7253 4e-05 m
.72555 0 L
s
.75804 0 m
.75895 .0001 L
.76191 .00041 L
.76452 .00064 L
.76595 .00074 L
.76728 .00082 L
.76848 .00087 L
.76977 .00092 L
.7705 .00093 L
.7712 .00094 L
.7725 .00095 L
.7737 .00094 L
.7748 .00092 L
.77602 .00088 L
.7773 .00083 L
.78692 .0001 L
s
.78692 .0001 m
.78812 0 L
s
.82294 0 m
.82448 8e-05 L
.82677 .00018 L
.82923 .00026 L
.83056 .00029 L
.83123 .0003 L
.83196 .00031 L
.83326 .00033 L
.83447 .00033 L
.83515 .00033 L
.83588 .00032 L
.83657 .00032 L
.83721 .00031 L
.83842 .0003 L
.83971 .00027 L
.8453 .00013 L
.84799 6e-05 L
.85054 0 L
s
.85054 0 m
.85068 0 L
s
.86254 0 m
.86475 5e-05 L
.86964 .0002 L
.87233 .00029 L
.87488 .00036 L
.87603 .00038 L
.87725 .0004 L
.87789 .00041 L
.87859 .00042 L
.87983 .00043 L
.88095 .00043 L
.88216 .00042 L
.8833 .00041 L
.88434 .00039 L
.88541 .00037 L
.8864 .00034 L
.88865 .00025 L
.89318 0 L
s
.89318 0 m
.89323 0 L
s
.92429 0 m
.93223 .00098 L
.93462 .00125 L
.93717 .00151 L
.93841 .00161 L
.93958 .00169 L
.94062 .00175 L
.94177 .0018 L
.94303 .00184 L
.94372 .00185 L
.94437 .00185 L
.94553 .00185 L
.94678 .00182 L
.94747 .0018 L
.94823 .00176 L
.94962 .00168 L
.95222 .00146 L
.96242 .00011 L
s
.96242 .00011 m
.96318 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`02ooooo`Co00000oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool3o`0000_o
oooo1ol00005ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool7o`0000Go
oooo00?o0000ooooooooool08?ooool002Cooooo00?o0000ooooooooool01_ooool8o`00023ooooo
00?o0000ooooooooool0;Oooool8o`0002Sooooo00?o0000ooooooooool0:Oooool2o`0000;ooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo023ooooo
000eooooo`Go0000B_ooool2o`0000Oooooo2?l0000Pooooo`03o`000?oooooooooo02;ooooo1ol0
0027ooooo`00>Oooool2o`0004Gooooo1?l0000Aooooo`?o00007Oooool00ol0003oooooooooo`0P
ooooo`?o0000SOooool003_ooooo0_l00012ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Nooooo`;o0000T?ooool003gooooo00?o0000oooooooo
ool0?Oooool2o`0001[ooooo00?o0000ooooooooool06Oooool2o`0001kooooo00?o0000oooooooo
ool0T?ooool003gooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Kooooo`;o0000
6Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo093ooooo000nooooo`03o`000?oo
oooooooo03[ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool0TOooool003oooooo00?o0000ooooooooool0>?ooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`2Aooooo`00@?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
09;ooooo0010ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0Toooool0047ooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`2Dooooo`00@_ooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04oooool2o`0001[ooooo00?o
0000ooooooooool0U?ooool004?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`2E
ooooo`00@oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo09Kooooo0014ooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool0U_ooool004Cooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`2Fooooo`00AOooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo09Oooooo0015ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`0@ooooo`;o00005oooool00ol0003oooooooooo`2Gooooo`00A_ooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo09Oooooo0017ooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool0V?ooool004Oooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`2Hooooo`00B?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo09Sooooo0018
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0VOooool004Wooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00kooooo0_l0000Eoooo
o`03o`000?oooooooooo09Wooooo0019ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0VOooool004[ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0booooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`2Jooooo`00B_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo09[ooooo001:ooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool0:?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o
8B4Qo`000?ooool01?ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`2Jooooo`00Boooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo02Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03ob4Q8Ol0003ooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo09_ooooo001;
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0:?ooool01Ol@413ooooooooooooo
oooo410@00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`?o00004_oo
ool00ol0003oooooooooo`2Kooooo`00Boooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo02Wooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo09_ooooo001<
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0:Oooool01Ol0003ooooooooooooo
oooo000000Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool0W?ooool004cooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0Yooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`2Looooo`00C?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02[ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo09cooooo001=ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00Oo
0000oooooooooooooooooeEEEOmVIVKo000000Oooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`2Looooo`00COooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo09gooooo
001=ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0>?ooool00ol0003ooooooooo
o`0:ooooo`;o00004Oooool00ol0003oooooooooo`2Mooooo`00C_ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo09gooooo001>ooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool0>Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0WOooool004kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0iooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2Nooooo`00
C_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo09kooooo001?ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0W_ooool004oooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Wooooo0_l0000@ooooo`03o`000?oooooo
oooo09kooooo001?ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0Woooool0053o
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2Oooooo`00D?ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo09oooooo001@ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool0Woooool0053ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2O
ooooo`00DOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool02?ooool2o`0000kooooo00?o0000ooooooooool0X?ooool0057ooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`2Pooooo`00DOooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo043ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo0:3ooooo001Booooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0@?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0X?oo
ool005;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`2Pooooo`00D_ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo0:7ooooo001Booooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`06ooooo`;o00003Oooool00ol0003o
ooooooooo`2Qooooo`00Doooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04?ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0:7ooooo
001Cooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0XOooool005?ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`2Qooooo`00E?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo03;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0000Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`2Qooooo`00E?ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo03;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_l0003oA4A400Kooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`2Rooooo`00E?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo03;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7o000000Oooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`2Rooooo`00EOooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo03?ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?l0
003ok^k^00Kooooo0ol0000;ooooo`03o`000?oooooooooo0:;ooooo001Eooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool0<oooool01Ol0003ooooooooooooooooo000000kooooo00?o
0000ofIVI_ooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0:;ooooo001E
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0<oooool01Ol@413ooooooooooooo
oooo410@00kooooo0_l00006ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0X_oo
ool005Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0dooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So000000Kooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`2Sooooo`00E_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo03Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Ol0
00001_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0:?ooooo001Fooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0Xoooool005Kooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Cooooo0_l0000;ooooo`03o`000?oo
oooooooo0:?ooooo001Gooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0BOooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Xoooool0
05Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`2Sooooo`00Eoooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo0:Cooooo001Hooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0Boooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0Y?ooool005Wooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`1<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`2Tooooo`00FOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04cooooo00?o0000
ooooooooool00oooool2o`0000[ooooo00?o0000ooooooooool0Y?ooool005Wooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`2Tooooo`00F_ooool2o`0000;ooooo00?o0000oooooooo
ool0Coooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0YOooool005_ooooo1?l0001Aooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`2Uooooo`00/?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0YOooool00;3ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo0:Gooooo002aooooo`04o`000?oooooooooo
ooooo`;o00002Oooool00ol0003oooooooooo`2Uooooo`00/Oooool01Ol0003ooooooooooooooooo
000000Wooooo00?o0000ooooooooool0Y_ooool00;7ooooo00Go0000ooooooooooooooooo`000009
ooooo`03o`000?oooooooooo0:Kooooo002aooooo`05o`000?ooooooooooooooool000002Oooool0
0ol0003oooooooooo`2Vooooo`00/Oooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000
ooooooooool0Y_ooool00;7ooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooo
oooo0:Kooooo002aooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`2W
ooooo`00/_ooool00ol0003oooooooooo`02o`0000Oooooo00?o0000ooooooooool0Yoooool00;;o
oooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`2Wooooo`00/_ooool01?l0003o
ooooooooool00008ooooo`03o`000?oooooooooo0:Oooooo002Jooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`04o`000?oooooo
ooooo`0000Sooooo00?o0000ooooooooool0Yoooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`2Xooooo`00V_ooool01Ol@413ooooooooooooooooo410@00oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo0:So
oooo002Jooooo`05o`000?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`03ooooo`03
o`000?oooooo000000;o00001Oooool00ol0003oooooooooo`2Xooooo`00V_ooool01Ol0003ooooo
oooooooooooo000000gooooo00?o410@o`000?nj^[X01?ooool00ol0003oooooo`000006ooooo`03
o`000?oooooooooo0:Wooooo002Jooooo`05oa0@4?ooooooooooooooool@41003_ooool00onj^[[o
8B4Qooooo`04ooooo`;o00001_ooool00ol0003oooooooooo`2Yooooo`00V_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go410@oiRHV?oooooo^[Zjo`000005ooooo`;o00001_ooool00ol0
003oooooooooo`2Yooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@
4?l0003o410@ojVYZ@05ooooo`;o00001Oooool00ol0003oooooooooo`2Zooooo`00]Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo0:[ooooo002eooooo`;o00001?ooool00ol0003o
ooooooooo`2Zooooo`00]Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0:_ooooo
002eooooo`;o00000oooool00ol0003oooooooooo`2[ooooo`00]Oooool2o`0000;ooooo0_l0002]
ooooo`00]Oooool00ol0003oooooo`000002o`000:kooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l0
00000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`?o0000/?oo
ool009[ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo
00?o0000ooooooooool0/?ooool009[ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgM
gOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0/?ooool009[ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000oooooooo
ool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Ko
oooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?oo
ool009[ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0
002`ooooo`00V_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol0003ooooooooooooooooo000000cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo
002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002a
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool00ol0
003o^[Zjooooo`2iooooo`00[?ooool2oc8b<[[ooooo001mooooo`;o000000Ko410@oooooooooooo
410@o`000?l@410Hooooo`Co000000Go410@ooooooooooooooooodA4A002o`000007oc8b<_oMgMgo
oooooooooon7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Cooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8b
onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0Loooool007kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`07ooooo`Ko00003?ooool00ol0003oooooooooo`06ooooo`07ogMg
Molb<S;oooooooooooo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6
o`0000gooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg07?ooooo001nooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`05o`0000?ooooo00Go
410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100Loooool007kooooo
00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00003?ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo013ooooo00?o0000ooooooooool02oooool6o`0000gooooo00SoMgMgoc8b
<_ooooooooooodA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool00000Loooool007kooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000K
ooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Aooooo`03o`000?oo
oooooooo01_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`04omgMgOmEEEGoooooo`0000Co
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000Loooool0
07kooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Kooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool04Oooool00ol@413o0000o`000003o`0001[ooooo00?o0000ooooooooool01Ooo
ool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooo
oooooooooooo410@07?ooooo001nooooo`06o`000?lb<S;ooooooooooolb<S;o00006oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`05ooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Loooool007gooooo00?o410@o`000?n7QhL00_ooool0
0on7QhOo0000oa0@400Hooooo`03oeEEEOmVIVKo000000Gooooo1?l0000Booooo`03o`000?oooooo
oooo01_ooooo1?l00005ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0Loooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5500) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.04905 0 m
.05221 .00044 L
.05474 .00078 L
.05748 .00111 L
.0599 .00134 L
.06121 .00145 L
.06244 .00153 L
.06381 .0016 L
.06453 .00162 L
.0653 .00165 L
.066 .00166 L
.06667 .00167 L
.06792 .00168 L
.06916 .00166 L
.0703 .00164 L
.07156 .0016 L
.07289 .00154 L
.07527 .0014 L
.0775 .00123 L
.08259 .00082 L
.08528 .00062 L
.08675 .00053 L
.08811 .00045 L
.08938 .00039 L
.09053 .00035 L
.09181 .00032 L
.09251 .00031 L
.09317 .00031 L
.09383 .00031 L
.09456 .00032 L
.09531 .00033 L
.09602 .00035 L
.09729 .0004 L
.09865 .00048 L
.10024 .0006 L
.10175 .00074 L
.10458 .00107 L
.10962 .00188 L
.11419 .00277 L
.12442 .00493 L
.14282 .00837 L
.14772 .00946 L
.15288 .01097 L
.15728 .01268 L
.16211 .0151 L
.16732 .01845 L
.17289 .02296 L
.18294 .03353 L
.19314 .0475 L
.20422 .067 L
Mistroke
.21469 .0909 L
.22436 .11874 L
.24465 .19053 L
.25458 .22378 L
.25893 .23573 L
.26122 .24115 L
.26368 .24616 L
.26609 .25024 L
.26828 .25317 L
.26933 .25432 L
.27048 .25535 L
.27155 .25613 L
.27255 .25668 L
.27367 .2571 L
.27491 .25732 L
.27611 .25729 L
.27741 .25698 L
.27861 .25645 L
.27975 .25573 L
.28188 .25382 L
.28424 .25087 L
.28675 .24683 L
.29126 .23742 L
.30148 .20812 L
.32115 .1394 L
.3392 .08486 L
.34861 .06322 L
.35852 .04548 L
.36847 .03236 L
.37411 .02673 L
.37937 .02247 L
.38441 .01914 L
.38987 .01619 L
.3998 .01204 L
.4094 .0089 L
.41838 .00646 L
.42332 .00536 L
.42783 .00454 L
.43023 .00419 L
.43284 .00389 L
.43428 .00376 L
.43561 .00366 L
.43688 .00359 L
.43759 .00356 L
.43823 .00354 L
.43955 .00351 L
.44022 .0035 L
.44094 .0035 L
.44223 .00352 L
.44344 .00355 L
Mistroke
.44417 .00358 L
.44486 .00361 L
.44615 .00369 L
.44907 .00395 L
.45161 .00424 L
.45395 .00458 L
.45927 .00551 L
.4689 .00773 L
.47795 .0104 L
.48787 .01438 L
.49344 .01742 L
.49855 .02094 L
.5033 .02502 L
.50837 .03041 L
.51749 .0435 L
.52307 .05415 L
.52834 .06641 L
.5382 .09606 L
.54793 .13486 L
.55823 .18547 L
.57668 .2834 L
.58153 .30495 L
.58613 .32162 L
.58867 .32889 L
.59001 .33211 L
.59143 .33505 L
.59275 .3373 L
.59394 .33894 L
.59514 .34019 L
.59627 .34101 L
.59734 .34145 L
.59851 .34157 L
.59973 .34128 L
.60086 .34064 L
.60193 .3397 L
.6029 .33857 L
.60508 .33508 L
.60742 .32989 L
.60997 .32267 L
.61459 .30569 L
.63403 .20251 L
.64434 .14756 L
.65003 .1219 L
.65544 .10123 L
.66605 .07049 L
.67575 .05066 L
.68573 .03481 L
.69478 .02293 L
.69938 .01784 L
.70436 .01321 L
Mistroke
.7071 .0111 L
.70962 .00945 L
.71219 .00807 L
.71458 .00704 L
.71664 .00635 L
.71884 .0058 L
.7201 .00556 L
.72129 .00539 L
.72236 .00527 L
.72352 .00518 L
.72465 .00513 L
.7259 .0051 L
.7272 .00511 L
.72842 .00514 L
.72956 .00518 L
.73061 .00524 L
.73296 .00538 L
.7354 .00553 L
.7366 .0056 L
.7377 .00565 L
.73897 .00569 L
.73964 .0057 L
.74035 .00571 L
.7415 .0057 L
.74276 .00567 L
.74395 .00562 L
.74503 .00554 L
.74628 .00543 L
.74747 .00529 L
.74958 .00498 L
.75188 .00454 L
.75708 .00321 L
.76262 .0015 L
.76746 3e-05 L
Mfstroke
.76746 3e-05 m
.76758 0 L
s
.79533 0 m
.79908 .0009 L
.80186 .00152 L
.80448 .00204 L
.80692 .00243 L
.8083 .00259 L
.80957 .00271 L
.81064 .00279 L
.81182 .00284 L
.81305 .00286 L
.8142 .00284 L
.81537 .0028 L
.81665 .00271 L
.81786 .00259 L
.81898 .00245 L
.82109 .00213 L
.82334 .00169 L
s
.82334 .00169 m
.83016 0 L
s
.86523 0 m
.86965 .00109 L
.87244 .00168 L
.875 .00212 L
.87746 .00243 L
.8787 .00254 L
.87941 .00259 L
.88007 .00262 L
.88078 .00265 L
.88145 .00267 L
.88271 .00267 L
.88341 .00266 L
.88406 .00263 L
.88478 .0026 L
.88554 .00255 L
.88667 .00245 L
.88788 .00232 L
.89008 .00201 L
.89509 .00105 L
s
.89509 .00105 m
.89968 0 L
s
.93425 0 m
.93624 .00042 L
.94111 .00133 L
.94356 .00169 L
.94497 .00186 L
.94625 .00199 L
.94743 .00208 L
.94855 .00215 L
.94973 .00219 L
.95101 .00221 L
.95213 .00221 L
.95332 .00218 L
.95433 .00214 L
.95545 .00207 L
.95683 .00196 L
.95814 .00183 L
.9606 .00153 L
.96615 .00065 L
s
.96615 .00065 m
.97022 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`08ooooo`Oo00001_ooool00ol0003o
ooooo`000004o`0000Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07o`0000;o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`Co00000oooool00ol0003o
ooooooooo`04ooooo`So00002Oooool00ol0003oooooooooo`02ooooo`Ko000000?oooooo`000?oo
ool02_ooool00ol0003oooooo`000006o`0000?ooooo00?o0000ooooooooool08?ooool002Cooooo
00?o0000ooooooooool07?ooool4o`0000kooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`0Cooooo`Go00001oooool4o`0000[ooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`0>ooooo`co00004oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo023ooooo
0017ooooo`Ko0000Boooool3o`00013ooooo1Ol00005ooooo`03o`000?oooooooooo03cooooo0_l0
001booooo`00COooool00ol0003oooooooooo`15ooooo`?o00006?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo03_ooooo0_l0001cooooo`00C_ooool2o`0004?ooooo0_l0000Loooo
o`?o000000?oooooo`000?ooool0>oooool00ol0003oooooooooo`1cooooo`00D?ooool2o`0003oo
oooo0_l0000Pooooo`04o`000?oooooo0000o`0003[ooooo00?o0000ooooooooool0M?ooool005;o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Qooooo`;o0000>_ooool00ol0003o
ooooooooo`1eooooo`00Doooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02?ooooo
0_l0000iooooo`03o`000?oooooooooo07Gooooo001Dooooo`03o`000?oooooooooo03Oooooo00?o
0000ooooooooool09?ooool00ol0003oooooo`00000gooooo`03o`000?oooooooooo07Kooooo001E
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool09Oooool00ol0003oooooo`00000f
ooooo`03o`000?oooooooooo07Oooooo001Eooooo`03o`000?oooooooooo03Gooooo00?o0000oooo
ooooool09Oooool01?l0003oooooooooool0000dooooo`03o`000?oooooooooo07Sooooo001Foooo
o`03o`000?oooooooooo03?ooooo00?o0000ooooooooool09_ooool01Ol0003ooooooooooooooooo
000003?ooooo00?o0000ooooooooool0N?ooool005Oooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`0Wooooo`;o00000oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
07Wooooo001Gooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0N_ooool005Sooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1jooooo`00F?ooool00ol0003ooooooooo
o`0^ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo07_ooooo001Iooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool0:_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02_ooooo00?o0000
ooooooooool0Noooool005[ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Zoooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1loooo
o`00F_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02_ooooo0_l00006ooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0O?ooool005_ooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`1mooooo`00Foooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo02cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo07gooooo001Looooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0O_ooool0
05cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1nooooo`00G?ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo07oooooo001Mooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0;Oooool2o`0000Sooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`1oooooo`00GOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo07oooooo001M
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0P?ooool005kooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`20ooooo`00G_ooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo01Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`00
0003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo083ooooo001Oooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool05?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
087ooooo001Oooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool05?ooool01Ol@413o
oooooooooooooooo410@00kooooo00?o0000ooooooooool01Oooool3o`0000Sooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`21ooooo`00Goooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo01Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
087ooooo001Pooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool05Oooool01Ol0003o
oooooooooooooooo000000kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool0P_ooool0063ooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0Eooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`22ooooo`00H?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo08;ooooo001Qooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool05_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool0Poooool0067ooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`23ooooo`00HOooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo03;ooooo
0_l0000;ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0Poooool006;ooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`23ooooo`00H_ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo08?ooooo001Rooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool0Poooool006?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`24ooooo`00
Hoooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo08Cooooo001Sooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0<oooool2o`0000gooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`24ooooo`00Hoooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo08Cooooo001Tooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0Q?ooool006Co
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`24ooooo`00I?ooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo08Cooooo001Tooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool0QOooool006Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0e
ooooo`;o00003_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo08Gooooo001Uoooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0QOooool006Gooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`25ooooo`00I_ooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo08Gooooo001Vooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Q_oo
ool006Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`26ooooo`00I_ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo03Oooooo0_l0000@ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool0Q_ooool006Oooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`26ooooo`00Ioooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo08Kooooo
001Wooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0>?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0Q_ooool006Oooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Mooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`27ooooo`00J?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo01gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^
k_ooooooA4A400Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo08Oooooo001Xooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool07_oo
ool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Qoooool006Sooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0Nooooo`05o`000?ooooooooooooooool00000
3Oooool00onHV9So8B4Qonk^kP06ooooo`?o00004?ooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo08Oooooo001Yooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool07_oo
ool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Qoooool006Wooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Oooooo`05oa0@4?ooooooooooooooool@4100
3oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`27ooooo`00JOooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo01oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@
41001_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0R?ooool006[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Oooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo08Sooooo001Zooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool0R?ooool006[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0kooooo`;o00004_ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo08Sooooo001[ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0R?oo
ool006_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0looooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`29ooooo`00K?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo08Wooooo001/ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0ROooool006cooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0mooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`29ooooo`00KOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03kooooo0_l0
000Cooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0ROooool006kooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`2:ooooo`00Koooool01Ol0003ooooooooooooooooo
0000047ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo08[ooooo001_ooooo`Co0000@_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool0R_ooool00;Gooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo08[ooooo002eooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`2:ooooo`00]Oooool2o`0001Cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`2;ooooo`00]Oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Roooool00;Gooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo08_ooooo002eooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2;ooooo`00
]Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
Roooool00;Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo08cooooo002eooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`2<ooooo`00]Oooool2o`0001Gooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`2<ooooo`00]Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0S?ooool00;Gooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo08cooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2=ooooo`00V_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S801_ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0SOooool009[o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo08gooooo002Jooooo`05
o`000?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`05ooooo`?o00005_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo08gooooo002Jooooo`05o`000?oooooooooooooo
ool000003Oooool00ol@413o0000okZj^P06ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`2>ooooo`00V_ooool01Ol@413ooooooooooooooooo410@
00kooooo00?o^[Zjob4Q8Oooool01Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0S_ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0S_ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0Soooool00;Gooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo08oooooo002eooooo`;o00006Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo093ooooo002eooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2@ooooo`00]Oooool00ol0003ooooo
ooooo`0Iooooo`05o`000?ooooooooooooooool00000T_ooool00;Gooooo00?o0000ooooooooool0
6Oooool2o`000003ooooool0003ooooo09;ooooo002eooooo`03o`000?oooooooooo01[ooooo0_l0
002Dooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003o
ooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooo
oooooa0@400;ooooo`Go00001_ooool3o`000;3ooooo002Jooooo`05o`000?ooooooooooooooool0
00002oooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05
o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooo
oooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooooooo
ool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@
41004?ooool00ol0003oooooooooo`03ooooo`?o0000/?ooool009[ooooo00Go0000oooooooooooo
ooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009[ooooo
00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0
003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00:cooooo00?o0000okZj^_ooool0^Oooool00:cooooo0_lb<S:j
ooooo`00OOooool2o`000006oa0@4?oooooooooooa0@4?l0003o410@6?ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000001olb<S;ogMgMooooooooooooQhN7o`000?nj^[X03?ooool01OnH
V9So0000o`000?m4A4Co^[Zj01Wooooo00GoA4A4o`000?l0003o<S8bomgMg@03ooooo`05odA4A?l0
003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP1cooooo`00O_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oo
oooo1_l0000<ooooo`03o`000?oooooooooo00Kooooo00OoMgMgoc8b<_ooooooooooolc<c?l0003o
410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003Oooool00omgMgOo<S8boooo
o`05ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`1cooooo`00O_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool@4103ooooo`05oa0@4?oooooo
ooooooooool@41000oooool00ol@413oooooooooo`1aooooo`00O_ooool01_l0003oooooodA4A?m4
A4Coooooo`0000Wooooo1_l0000<ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool0
4?ooool00ol0003oooooooooo`0;ooooo`Ko00003Oooool00omgMgOo<S8booooo`05ooooo`05ogMg
Molb<S;oooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool0LOooool007kooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Kooooo`03o`000?oooooo
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Aooooo`03o`000?oooooooooo01_ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c003ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00001cooooo`00O_ooool01_l0
003oQhN7ojVYZOnj^[[oEEEEo`0001_ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Aooooo`03oa0@4?l0003o000000?o00006_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
4100Loooool007kooooo00Ko0000oc8b<_oooooooooooc8b<_l0000Kooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`1cooooo`00OOooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o
410@01Sooooo00?oEEEEofIVI_l000001Oooool4o`0001;ooooo00?o0000ooooooooool06oooool4
o`0000Cooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^07?ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5600) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03135 0 m
.03279 .00014 L
.03543 .0004 L
.03793 .00061 L
.04037 .00078 L
.04144 .00084 L
.04262 .0009 L
.04377 .00094 L
.045 .00096 L
.04564 .00097 L
.04633 .00098 L
.04758 .00097 L
.04826 .00096 L
.049 .00095 L
.0497 .00093 L
.05035 .0009 L
.05157 .00085 L
.05288 .00077 L
.05546 .00058 L
.0579 .00036 L
s
.0579 .00036 m
.06134 0 L
s
.09322 0 m
.09917 .00071 L
.10177 .00096 L
.10313 .00108 L
.10458 .00118 L
.1058 .00125 L
.10644 .00128 L
.10713 .00131 L
.10835 .00134 L
.10949 .00136 L
.11073 .00136 L
.11191 .00135 L
.11297 .00132 L
.11412 .00128 L
.11547 .00121 L
.11669 .00113 L
.11942 .00092 L
.12432 .00044 L
s
.12432 .00044 m
.1288 0 L
s
.14608 0 m
.14734 .00014 L
.15234 .00089 L
.16139 .00249 L
.16619 .00321 L
.16891 .00351 L
.17013 .00361 L
.17144 .0037 L
.17216 .00374 L
.17282 .00377 L
.17412 .00382 L
.1753 .00384 L
.17655 .00385 L
.1772 .00385 L
.1779 .00384 L
.17915 .00381 L
.17992 .00379 L
.18064 .00377 L
.18201 .00371 L
.1844 .00359 L
.18698 .00346 L
.18816 .00341 L
.18941 .00336 L
.19048 .00333 L
.19164 .00331 L
.19286 .00331 L
.19417 .00333 L
.1954 .00338 L
.19651 .00345 L
.19784 .00356 L
.19928 .00373 L
.20064 .00393 L
.20189 .00416 L
.20615 .00526 L
.20857 .0061 L
.21083 .00704 L
.2203 .0123 L
.24057 .02697 L
.24954 .03439 L
.2591 .04481 L
.26427 .05239 L
.26895 .06083 L
.2781 .08211 L
.29882 .14985 L
.30898 .18605 L
.31971 .21991 L
.32413 .23142 L
.32886 .24164 L
.33158 .24638 L
.33406 .2499 L
Mistroke
.33525 .25132 L
.33655 .25264 L
.33778 .25368 L
.33891 .25444 L
.34006 .25504 L
.34129 .25546 L
.34238 .25564 L
.34353 .25564 L
.34479 .25542 L
.34597 .25498 L
.34726 .25427 L
.34863 .25322 L
.35141 .2502 L
.35404 .24628 L
.35895 .23623 L
.36358 .22381 L
.36784 .21025 L
.37748 .17475 L
.38731 .1371 L
.39785 .10185 L
.40781 .07671 L
.4169 .06003 L
.43636 .03388 L
.44604 .02268 L
.45481 .01442 L
.4572 .01265 L
.45977 .011 L
.462 .00981 L
.46443 .00875 L
.46703 .0079 L
.46845 .00754 L
.46977 .00728 L
.47101 .00709 L
.47214 .00696 L
.47344 .00686 L
.47467 .0068 L
.47573 .00678 L
.4769 .00679 L
.47812 .00682 L
.47926 .00686 L
.4813 .00697 L
.4835 .00711 L
.48472 .00719 L
.48606 .00727 L
.48724 .00732 L
.4885 .00737 L
.48974 .00739 L
.49087 .0074 L
.49201 .00738 L
.49308 .00734 L
Mistroke
.49424 .00727 L
.49548 .00717 L
.49666 .00705 L
.49773 .00691 L
.50035 .00648 L
.50283 .00596 L
.51315 .00308 L
.51743 .00192 L
.51978 .00138 L
.52199 .00098 L
.52323 .0008 L
.52437 .00067 L
.52563 .00056 L
.52629 .00051 L
.52699 .00048 L
.52813 .00046 L
.5292 .00047 L
.53037 .00052 L
.53162 .00061 L
.53285 .00074 L
.5342 .00093 L
.53694 .00145 L
.54185 .00274 L
.55295 .00655 L
.56348 .00996 L
.5731 .0129 L
.57787 .01472 L
.58307 .01736 L
.58798 .02078 L
.59254 .02494 L
.59785 .03121 L
.60265 .03832 L
.61343 .05974 L
.62347 .08744 L
.6327 .12076 L
.65353 .22365 L
.66264 .27277 L
.66765 .29699 L
.67239 .31633 L
.67507 .32525 L
.67799 .33302 L
.67927 .33575 L
.68064 .33816 L
.6818 .33981 L
.68309 .34119 L
.68438 .3421 L
.68556 .3425 L
.68686 .34248 L
.68752 .34228 L
.68823 .34191 L
Mistroke
.68944 .34096 L
.69074 .33948 L
.69196 .33764 L
.69306 .33562 L
.69538 .3303 L
.69792 .32286 L
.70306 .30331 L
.71228 .25733 L
.72315 .19634 L
.73308 .14528 L
.74241 .10648 L
.75256 .07476 L
.76329 .05054 L
.77346 .0337 L
.78284 .02228 L
.78818 .01738 L
.7932 .01377 L
.79847 .01092 L
.8033 .009 L
.80861 .00746 L
.8142 .00627 L
.82372 .00467 L
.83391 .00306 L
.83854 .00238 L
.84345 .00176 L
.84765 .00134 L
.85003 .00115 L
.85226 .00102 L
.85358 .00095 L
.85484 .0009 L
.85598 .00087 L
.85719 .00083 L
.8585 .00081 L
.85972 .00079 L
.86047 .00079 L
.86117 .00078 L
.86248 .00078 L
.86313 .00078 L
.86383 .00078 L
.86457 .00078 L
.86526 .00078 L
.86781 .00079 L
.86856 .00079 L
.86927 .00079 L
.8699 .00079 L
.87059 .00079 L
.87135 .00079 L
.87214 .00079 L
.87282 .00079 L
.87358 .00078 L
Mistroke
.87485 .00077 L
.87549 .00076 L
.87618 .00075 L
.87858 .0007 L
.87993 .00066 L
.88137 .00061 L
.88397 .00051 L
Mfstroke
.88397 .00051 m
.89356 0 L
s
.91605 0 m
.92011 .00025 L
.9255 .00059 L
.92812 .00073 L
.9294 .00078 L
.93059 .00082 L
.93167 .00085 L
.93281 .00087 L
.93396 .00088 L
.93522 .00088 L
.93648 .00087 L
.93767 .00084 L
.93874 .00081 L
.93991 .00077 L
.94253 .00063 L
.94496 .00046 L
s
.94496 .00046 m
.95012 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo1_l00007ooooo`03o`000?oooooooooo00;ooooo3_l00005ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01?l00004ooooo`Go00002?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool01?l0003oooooooooooooool7o`00
0003ooooool0003ooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo023ooooo000Tooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool01?ooool3o`0002Kooooo00?o0000ooooooooool08oooool=o`0000gooooo0ol0000Mooooo`03
o`000?oooooooooo02[ooooo1ol0000/ooooo`03o`000?oooooooooo023ooooo001Oooooo`03o`00
0?oooooooooo04Oooooo0ol00009ooooo`03o`000?oooooooooo013ooooo0ol00014ooooo`?o0000
E_ooool0063ooooo0_l00016ooooo`;o00002oooool00ol0003oooooooooo`0Cooooo`;o0000@?oo
ool2o`0005Wooooo001Rooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Eooooo`?o0000??ooool00ol0003oooooooooo`1Iooooo`00Hoooool2o`00
047ooooo00?o0000ooooooooool03?ooool2o`0001Wooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`1Iooooo`00IOooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo05[o
oooo001Vooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0Foooool006Oooooo00?o
0000ooooooooool0>Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`1Looooo`00J?ooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0b
ooooo`03o`000?oooooooooo05gooooo001Yooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo03;ooooo00?o0000oooo
ooooool0GOooool006[ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1Nooooo`00
Joooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01;ooooo0_l0000Mooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool0G_ooool006cooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`1Oooooo`00K?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo05oooooo001]ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0H?ooool006go
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1Pooooo`00K_ooool00ol0003ooooo
ooooo`0[ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo067ooooo001_ooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool05_ooool2o`00023ooooo00?o0000ooooooooool0:_ooool00ol0003ooooooooo
o`1Qooooo`00Koooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo06;ooooo001`oooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Poooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0H_ooool0073ooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`1Rooooo`00LOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo06?ooooo001aooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0Hooo
ool007;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Jooooo`;o00008_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06Cooooo001booooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool0I?ooool007;ooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`1Uooooo`00Loooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo06Gooooo
001cooooo`03o`000?oooooooooo027ooooo00So0000ooooooooooook^k^oc8b<_l0003o<S8bonk^
kPGooooo0_lQ8B45ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0IOooool007?ooooo00?o0000oooooooo
ool08Oooool02?l0003ooooooooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool0I_ooool007Cooooo00?o0000ooooooooool07oooool01Ol0003ooooooooooooo
oooo410@00?ooooo00?o410@ooooooooool03?ooool00ol0003oooooooooo`05ooooo`?o00008ooo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo06Kooooo001dooooo`03o`000?oooooo
oooo01oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool0Ioooool007Cooooo00?o0000ooooooooool07oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1Wooooo`00M?ooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
400>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo06Oooooo001eooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0Iooo
ool007Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`1Xooooo`00MOooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo06Sooooo001fooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool07_ooool2o`0002Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Xoooo
o`00M_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo06Sooooo001fooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool0J?ooool007Kooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`1Xooooo`00Moooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo06Wooooo001gooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0JOooool007Oo
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Oooooo`;o00009oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo06Wooooo001hooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0JOooool007Sooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`1Yooooo`00N?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo06Wooooo001hoooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0J_ooool007Wooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`1Zooooo`00NOooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo027ooooo0_l0000Xooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
J_ooool007Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1Zooooo`00N_ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo06[ooooo001jooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool0Joooool007[ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`1[ooooo`00N_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo06_ooooo
001kooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool08oooool2o`0002[ooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`1[ooooo`00Noooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo06_ooooo001kooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0K?ooool007_ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1/ooooo`00
O?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Wooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo06cooooo001looooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool02Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0K?ooool007cooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`09ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP07oooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1/oooo
o`00OOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo00Go0000oooooooo
ooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0000Zooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0KOooool007gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0:ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05oooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1]oooo
o`00OOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo06gooooo001nooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`1]ooooo`00O_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_oo
ool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0KOoo
ool007kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1^ooooo`00Ooooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo02Oooooo0_l0000/ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0K_ooool0083ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`1^ooooo`00P?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo06kooooo
0021ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Koooool0087ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1_ooooo`00POooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo06oooooo0022ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0:Oooool2o`0002gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1_ooooo`00
Poooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo06oooooo0023ooooo`;o00000_oo
ool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`1`ooooo`00Q?ooool3o`0002kooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo073ooooo002eooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1`ooooo`00]Oooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0L?ooool00;Gooooo
0_l0000_ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0LOooool00;Gooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo077ooooo002e
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1a
ooooo`00]Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0LOooool00;Gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo077ooooo002eooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`1booooo`00]Oooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0L_ooool00;Gooooo0_l0000`ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0L_ooool00;Gooooo00?o0000ooooooooool0<?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo07;ooooo002eooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1booooo`00V_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05oiRHV?l@413o0000oc8b<_o<c<`01_ooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Loooool009[o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo
<S8b00Kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo07?ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1c
ooooo`00V_ooool01Ol0003ooooooooooooooooo000000kooooo00?oZJVYoa0@4?ooool01Oooool3
o`00037ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1cooooo`00V_ooool01Ol0
003ooooooooooooooooo000000gooooo00?o410@o`000?nj^[X01_ooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Loooool009[ooooo00Go410@oooo
oooooooooooooa0@400>ooooo`03okZj^_lQ8B7ooooo00Gooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo07Cooooo002Jooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol@413oV9RHoooooonj^[[o000000Kooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07Cooooo002Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07Cooooo002eooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1dooooo`00]Oooool2
o`0003?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1eooooo`00]Oooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0MOooool00;Go
oooo00?o0000ooooooooool0<oooool01Ol0003ooooooooooooooooo000007Sooooo002eooooo`03
o`000?oooooooooo03Cooooo00Co0000oooooooooooo0000N?ooool00;Gooooo00?o0000oooooooo
ool0=?ooool3o`0007Wooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aoooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Joooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@
413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`?o0000/?ooool009[ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0/?oo
ool009[ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo
00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMg
Moo<c<co000000Oooooo00?o0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooo
oooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0002`ooooo`00V_ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`
ooooo`00V_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool00ol0003o^[Zjooooo`2iooooo`00
[?ooool2oc8b<[[ooooo001mooooo`;o000000Ko410@oooooooooooo410@o`000?l@410Hooooo`Co
000000Go410@ooooooooooooooooodA4A002o`000007oc8b<_oMgMgooooooooooon7QhOo0000okZj
^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06Oooool01Om4A4Co0000o`000?lb<S;ogMgM00;o
oooo00Gok^k^oc8b<_l0003o410@olc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^07?ooooo001nooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01oooool6o`0000cooooo00?o0000ooooooooool01_ooool01omgMgOo<S8boooooooo
ooooc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000=ooooo`09
ogMgMolb<S;ooooooooooomEEEGoMgMgoooooonHV9So8B4Q00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Loooool007kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0Oooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooo
oooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`1a
ooooo`00O_ooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000<ooooo`03o`000?oo
oooooooo00Kooooo00?oMgMgoc8b<_ooool04?ooool00ol0003oooooooooo`0;ooooo`Ko00003Ooo
ool02OmgMgOo<S8boooooooooooo0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000007?ooooo001nooooo`06o`000?oMgMgo
<S8boeEEEOoMgMgo00006oooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`04Oooool00ol0003oooooooooo`0Kooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0
003oEEEEo`000?l@413oc<c<00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool00000Loooool007kooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Kooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol@413o0000o`000003o`0001[o
oooo00?o0000ooooooooool01?ooool00omEEEGoQhN7ooooo`05ooooo`05oa0@4?oooooooooooooo
ool@41000oooool01Ol@413ooooooooooooooooo410@07?ooooo001nooooo`06o`000?lb<S;ooooo
oooooolb<S;o00006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`04ooooo`03omgMgOl@413oV9RH00Gooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Loooool007gooooo
00?o410@o`000?n7QhL00_ooool00on7QhOo0000oa0@400Hooooo`03oeEEEOmVIVKo000000Gooooo
1?l0000Booooo`03o`000?oooooooooo01_ooooo1?l00004ooooo`04olc<c?m4A4Co0000oa0@40?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0Loooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5700) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .00046 m
.02846 .00157 L
.03068 .00202 L
.03279 .00239 L
.03398 .00256 L
.03527 .00271 L
.03645 .00281 L
.03754 .00288 L
.03871 .00293 L
.04 .00294 L
.04065 .00293 L
.04135 .0029 L
.04262 .00283 L
.04393 .00272 L
.04516 .00258 L
.04793 .00215 L
.05297 .00104 L
s
.05297 .00104 m
.05698 0 L
s
.0913 0 m
.09343 .00052 L
.09622 .00122 L
.09921 .00189 L
.10202 .00239 L
.10335 .00257 L
.10458 .00271 L
.10574 .00281 L
.10696 .00289 L
.10819 .00293 L
.10888 .00294 L
.10954 .00293 L
.11072 .0029 L
.11179 .00285 L
.11304 .00275 L
.11422 .00263 L
.11684 .00227 L
.11926 .00183 L
.12476 .00059 L
s
.12476 .00059 m
.12723 0 L
s
.16072 0 m
.16383 .00065 L
.16857 .00156 L
.17095 .00192 L
.17231 .00209 L
.17355 .00222 L
.17462 .00231 L
.17578 .00239 L
.17701 .00245 L
.17816 .00247 L
.17925 .00248 L
.18039 .00246 L
.18137 .00243 L
.18245 .00237 L
.19329 .00098 L
.19863 6e-05 L
s
.19863 6e-05 m
.199 0 L
s
.22495 0 m
.26172 .0058 L
.26635 .00619 L
.27075 .00671 L
.27317 .00709 L
.27582 .0076 L
.28046 .0088 L
.28598 .01083 L
.29111 .01336 L
.30109 .02011 L
.31167 .02995 L
.32163 .04193 L
.33057 .05556 L
.34024 .07443 L
.34975 .09825 L
.36019 .13064 L
.37121 .16991 L
.38126 .20577 L
.38607 .22121 L
.39129 .23564 L
.39368 .24122 L
.39622 .24633 L
.3986 .25028 L
.40079 .25315 L
.40197 .25439 L
.40326 .25549 L
.40455 .25633 L
.40526 .25667 L
.40592 .25691 L
.40714 .25717 L
.40825 .25719 L
.40952 .25696 L
.41073 .25649 L
.41137 .25615 L
.41206 .2557 L
.41347 .25455 L
.416 .2517 L
.41895 .24715 L
.42171 .24178 L
.43212 .21354 L
.44201 .1796 L
.46055 .11565 L
.47017 .0881 L
.48041 .06433 L
.49007 .04682 L
.49881 .03465 L
.50371 .0292 L
.50887 .02443 L
.51811 .018 L
.52326 .01534 L
Mistroke
.52806 .01329 L
.53895 .0095 L
.54944 .00632 L
.55936 .00368 L
.56368 .00276 L
.56826 .00201 L
.57066 .00172 L
.57193 .0016 L
.57329 .0015 L
.57454 .00142 L
.57569 .00137 L
.57684 .00134 L
.57793 .00132 L
.57918 .00132 L
.57988 .00133 L
.58052 .00134 L
.5817 .00138 L
.58296 .00143 L
.58513 .00155 L
.58751 .00172 L
.59244 .00216 L
.59773 .00263 L
.60028 .00283 L
.6027 .00298 L
.60487 .00308 L
.6061 .00312 L
.60724 .00315 L
.60829 .00317 L
.60928 .00318 L
.61037 .00318 L
.61154 .00317 L
.6127 .00315 L
.61393 .00312 L
.61611 .00305 L
.62102 .00285 L
.62343 .00275 L
.62449 .00271 L
.62565 .00268 L
.6269 .00265 L
.62821 .00264 L
.62891 .00264 L
.62965 .00265 L
.63035 .00266 L
.63099 .00267 L
.63218 .00271 L
.63348 .00278 L
.63471 .00287 L
.63585 .00298 L
.63825 .00328 L
.64051 .00367 L
Mistroke
.64474 .00468 L
.64929 .00621 L
.65421 .00836 L
.66373 .01386 L
.67418 .02163 L
.67944 .02631 L
.68508 .03216 L
.69525 .04618 L
.70055 .05613 L
.70545 .06748 L
.71652 .10242 L
.72629 .14456 L
.73665 .19851 L
.74627 .25117 L
.75151 .27801 L
.75638 .30011 L
.7609 .31715 L
.76501 .32897 L
.76736 .33396 L
.76957 .3374 L
.77079 .33876 L
.77191 .33965 L
.77314 .34025 L
.77444 .34044 L
.77565 .3402 L
.77675 .33964 L
.77801 .33859 L
.77922 .33719 L
.78135 .33376 L
.78368 .32869 L
.78894 .31239 L
.79382 .29212 L
.81469 .17879 L
.82365 .13347 L
.83332 .09496 L
.83885 .0781 L
.84393 .0655 L
.85391 .04668 L
.86369 .03274 L
.8728 .02197 L
.8828 .01262 L
.88568 .01055 L
.8884 .00889 L
.89103 .00756 L
.89349 .00656 L
.89571 .00585 L
.89811 .0053 L
.89947 .00507 L
.90076 .0049 L
.90192 .00479 L
Mistroke
.90319 .0047 L
.90389 .00467 L
.90454 .00466 L
.90577 .00464 L
.90709 .00466 L
.90784 .00468 L
.90852 .0047 L
.91093 .00481 L
.91347 .00494 L
.91566 .00505 L
.91689 .00509 L
.91802 .00512 L
.91906 .00513 L
.9202 .00513 L
.92127 .00511 L
.92226 .00507 L
.92341 .00501 L
.92449 .00492 L
.92567 .00481 L
.92694 .00465 L
.92953 .00425 L
.93191 .00376 L
.94106 .00125 L
Mfstroke
.94106 .00125 m
.94537 0 L
s
.97429 0 m
.97619 .00046 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooo`000006o`0000?ooooo00?o0000oooooooo
ool01oooool8o`0000Oooooo00?o0000ooooooooool01?ooool7o`0000[ooooo00Co0000oooooooo
oooooooo1_l00002ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_oooolKo`00
00Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01oooool5o`0000Wooooo00?o0000ooooooooool08?ooool002Co
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Cooooo`Oo00004oooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo00_ooooo0ol0000Kooooo`?o000000?oooooo`000?oo
ool0;_ooool00ol0003oooooooooo`0Dooooo`_o00003_ooool00ol0003oooooooooo`0Pooooo`00
L_ooool3o`00043ooooo00?o0000ooooooooool01oooool4o`00027ooooo0ol00013ooooo`;o0000
??ooool007Gooooo0_l0000nooooo`03o`000?oooooooooo00Gooooo0_l0000Xooooo`03o`000?oo
oooooooo03oooooo00?o0000ooooooooool0??ooool007Oooooo0_l0000looooo`03o`000?oooooo
oooo00?ooooo0_l0000[ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Oooool0
07Wooooo00?o0000ooooooooool0>Oooool2o`0000?ooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo03kooooo001jooooo`03o`000?oooooooooo03So
oooo00Go0000ooooooooooooooooo`00000`ooooo`03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool0?oooool007_ooooo00?o0000ooooooooool0=oooool01?l0003oooooo`000?l0000boooo
o`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0@?ooool007cooooo00?o0000oooooooo
ool0=_ooool2o`0003Gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`11ooooo`00
O?ooool00ol0003oooooooooo`0fooooo`;o0000=_ooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooooooo04;ooooo001mooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo04;ooooo001nooooo`03o`000?oooooo
oooo03?ooooo0_l0000hooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0@oooool0
07oooooo00?o0000ooooooooool0<Oooool01?l0003oooooo`000?l0000hooooo`03o`000?oooooo
oooo02oooooo00?o0000ooooooooool0A?ooool007oooooo00?o0000ooooooooool0<?ooool01?l0
003oooooooooool0000jooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0AOooool0
083ooooo00?o0000ooooooooool0;oooool01?l0003oooooooooool0000jooooo`03o`000?oooooo
oooo02gooooo00?o0000ooooooooool0AOooool0083ooooo00?o0000ooooooooool0;_ooool01Ol0
003ooooooooooooooooo000003_ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`16
ooooo`00POooool00ol0003oooooooooo`0]ooooo`05o`000?ooooooooooooooool00000??ooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo04Kooooo0021ooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool0Aoooool008;ooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`02ooooo`;o0000>oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo04Oo
oooo0022ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0B?ooool008?ooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`18ooooo`00Poooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo04Sooooo0024ooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0BOooool008Cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo03cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`19ooooo`00
QOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Gooooo0_l0000mooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0BOooool008Gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`1:ooooo`00Q_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo04[ooooo0026ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0nooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0B_ooool008Ko
oooo00?o0000ooooooooool04Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool0Boooool008Oooooo00?o0000ooooooooool04?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B45ooooo`03o`000?oooooo000000Oooooo00?o0000oooo
ooooool0?_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo04_ooooo0027ooooo`03
o`000?oooooooooo013ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooo0000
00Oooooo0ol0000oooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0Boooool008Oo
oooo00?o0000ooooooooool04?ooool01Ol0003ooooooooooooooooo000000_ooooo00Co0000oooo
oooooooo00001oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool0C?ooool008Sooooo00?o0000ooooooooool03oooool01Ol0003ooooooooooooooooo
000000_ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0oooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool0C?ooool008Sooooo00?o0000ooooooooool03oooool0
1Ol@413ooooooooooooooooo410@00_ooooo00Co0000oooooooooooo00001oooool00ol0003ooooo
ooooo`10ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0C?ooool008Sooooo00?o
0000ooooooooool03oooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo00Go0000oooooooooooo
ooooo`000007ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`1<ooooo`00ROooool00ol0003oooooooooo`0>ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02_ooool01Ol0003ooooooeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0@?ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo04gooooo0029ooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool0COooool008Wooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0:ooooo`;o0000@_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04gooooo
002:ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`11ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0COooool008[ooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo047ooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`1>ooooo`00R_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo04kooooo002;ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool0C_ooool008_ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo04;ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1>ooooo`00Rooo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00cooooo0_l00013ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0Coooool008cooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`1?ooooo`00S?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
04oooooo002<ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`12ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Coooool008gooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04?ooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`1@ooooo`00SOooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo053ooooo002=ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool03Oooool2o`0004Cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1@
ooooo`00S_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0@oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo053ooooo002>ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`13ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool0D?ooool008kooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`1Aooooo`00S_ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo057ooooo002?ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`14ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0DOooool0
08oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0?ooooo`;o0000AOooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo057ooooo002?ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool0DOooool0093ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`1Booooo`00T?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0AOooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo05;ooooo002@
ooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`04o`000?oo
oooo8B4Qob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`1Booooo`00T?ooool00ol0003oooooooooo`07ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00_ooool00ol0003oooooooooo`02ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A006ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`1Booooo`00TOooool00ol0003oooooooooo`06ooooo`05oa0@4?ooooooooooooooool@
41000_ooool00ol0003oooooooooo`07ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000oooooooo
ool0AOooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo05;ooooo002Aooooo`03o`00
0?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00So
oooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0004Gooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`1Booooo`00TOooool00ol0003oooooooooo`06ooooo`07o`000?ooooooooooooooool0
003oooooo`00000<ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0A_ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo05?ooooo002Aooooo`03o`000?oooooooooo00Ko
oooo00Oo410@oooooooooooooooooa0@4?oooooo000000gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`16ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0Doooool0
09;ooooo00?o0000ooooooooool01Oooool01omgMgOoV9RHoooooonHV9SoMgMgooooool000002Ooo
ool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0A_ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo05?ooooo002Booooo`03o`000?oooooooooo00Gooooo00Ko
k^k^oc8b<_l0003o<S8bonk^k_l0000:ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0
003oooooooooo`16ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0Doooool009;o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04Ko
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Cooooo`00Toooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo01?ooooo0_l00018ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0Doooool009?ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`1Dooooo`00Toooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0Aoooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05Cooooo002Doooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`17oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0E?ooool009Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04Oooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`1Dooooo`00UOooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo05Cooooo002Eooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05_oo
ool2o`0004Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Eooooo`00U_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0B?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo05Gooooo002Gooooo`05o`000?oooooooooo
ooooool000006Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0EOooool009Sooooo0ol0000Jooooo`03o`000?oooooooooo04Sooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`1Eooooo`00]Oooool00ol0003oooooooooo`18ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0EOooool00;Gooooo00?o0000ooooooooool0
B?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo05Gooooo002eooooo`;o0000B_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Kooooo002eooooo`03o`000?oooooo
oooo04Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Fooooo`00]Oooool00ol0
003oooooooooo`19ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0E_ooool00;Go
oooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Ko
oooo002eooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`1Fooooo`00]Oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0E_ooool00;Gooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo05Oooooo002eooooo`;o0000Boooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo05Oooooo002eooooo`03o`000?oooooooooo04[ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`1Gooooo`00]Oooool00ol0003oooooooooo`1;ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0Eoooool009[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Kooooo00?o0000oooooooo
ool0Boooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05Oooooo002Jooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go410@okZj^_ooooooMgMgoc8b<P06oooo
o`03o`000?oooooooooo04_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Goooo
o`00V_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`1;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0F?ooool009[o
oooo00Go0000ooooooooooooooooo`00000>ooooo`03ojVYZOl@413ooooo00Gooooo0ol0001<oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0F?ooool009[ooooo00Go0000oooooooo
ooooooooo`00000=ooooo`03oa0@4?l0003o^[Zj00Kooooo00?o0000ooooooooool0C?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo05Sooooo002Jooooo`05oa0@4?oooooooooooooo
ool@41003_ooool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo04cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1Hooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooooooo04cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1Iooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo04cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1Iooooo`00]Oooool00ol0003oooooooooo`1=
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0FOooool00;Gooooo0_l0001>oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0F_ooool00;Gooooo00?o0000oooooooo
ool0COooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05_ooooo002eooooo`03o`00
0?oooooooooo04kooooo00Go0000ooooooooooooooooo`00001Mooooo`00]Oooool00ol0003ooooo
ooooo`1?ooooo`?o0000G_ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0/?ooool009[ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Ko
oooo0ol0002`ooooo`00V_ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoo
oooo00001oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol0003ooooooooooooooooo0000
00_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@
413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`2`
ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool0
0ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMg
o`000?ooool01_ooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooooooo
ool00oooool3o`000;3ooooo002Jooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05o`000?ooooooooooooooool0
00003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool009[o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
002/ooooo`03o`000?nj^[[ooooo0;Wooooo002/ooooo`;o<S8b^_ooool007gooooo0_l000001_l@
413oooooooooool@413o0000oa0@41Sooooo1?l000001Ol@413oooooooooooooooooA4A400;o0000
00Oo<S8bomgMgOooooooooooohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0I
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003ok^k^ooooo`03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07?ooooo001nooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`0000cooooo00?o0000ooooooooool0
1_ooool01omgMgOo<S8booooooooooooc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo
410@00Wooooo1_l0000=ooooo`03ogMgMolb<S;ooooo00?ooooo00?oEEEEojVYZOooool00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1cooooo`00O_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool00_oo
ool00onYZJWoEEEEooooo`03ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooo
oooooooooooo410@07?ooooo001nooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`00
00cooooo00?o0000ooooooooool01_ooool00omgMgOo<S8booooo`0@ooooo`03o`000?oooooooooo
00_ooooo1_l0000=ooooo`03ogMgMolb<S;ooooo00Cooooo00?o8B4Qooooooooool00_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00001cooooo`00O_ooool0
1_l0003ogMgMoc8b<_mEEEGogMgMo`0001_ooooo00?o0000ooooooooool00oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<017ooooo00?o0000ooooooooool06oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?oEEEEolc<c?ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`00001cooooo`00O_ooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001_ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03oa0@4?l0003o000000?o0000
6_ooool00ol0003oooooooooo`07ooooo`03ojVYZOmgMgOooooo00;ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100Loooool007kooooo00Ko0000oc8b<_oo
oooooooooc8b<_l0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooc8b
<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg07?o
oooo001mooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool00omEEEGoIVIV
o`000005ooooo`Co00004_ooool00ol0003oooooooooo`0Kooooo`Co00000oooool5o`0000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0Loooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5800) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01005 m
.02846 .00826 L
.03279 .00704 L
.03754 .00605 L
.04262 .00526 L
.06244 .00297 L
.06788 .00245 L
.07379 .00197 L
.08451 .00131 L
.09406 .00074 L
s
.09406 .00074 m
.10363 0 L
s
.1362 0 m
.13988 .00045 L
.14545 .00111 L
.14771 .00133 L
.15016 .00151 L
.15084 .00155 L
.15156 .00159 L
.15284 .00164 L
.15404 .00167 L
.15536 .00168 L
.15656 .00166 L
.15766 .00163 L
.15892 .00157 L
.16011 .0015 L
.16223 .00132 L
.16453 .00106 L
s
.16453 .00106 m
.1712 0 L
s
.20539 0 m
.21035 .00099 L
.21308 .00147 L
.21458 .00169 L
.21598 .00188 L
.2173 .00202 L
.21851 .00213 L
.21985 .00222 L
.22056 .00225 L
.2213 .00228 L
.22251 .00229 L
.22365 .00228 L
.22489 .00224 L
.22558 .0022 L
.22621 .00216 L
.23634 .00066 L
s
.23634 .00066 m
.23954 0 L
s
.2684 0 m
.27582 .00181 L
.2781 .00233 L
.28052 .00282 L
.28276 .00319 L
.28486 .00345 L
.28601 .00356 L
.28724 .00364 L
.28794 .00368 L
.28861 .0037 L
.28986 .00372 L
.29051 .00371 L
.29121 .0037 L
.29245 .00366 L
.29322 .00361 L
.29394 .00356 L
.29528 .00345 L
.29766 .00318 L
.29984 .00287 L
.30476 .0021 L
.30718 .00174 L
.30947 .00144 L
.31073 .00131 L
.3114 .00125 L
.31211 .0012 L
.31335 .00113 L
.31451 .00109 L
.31558 .00108 L
.31674 .0011 L
.31783 .00115 L
.31883 .00123 L
.31994 .00134 L
.32116 .00151 L
.3236 .00196 L
.32632 .00264 L
.32878 .00343 L
.33431 .00565 L
.34427 .01046 L
.35439 .01514 L
.36509 .0197 L
.36949 .02189 L
.37423 .02482 L
.37942 .02905 L
.38427 .03424 L
.39459 .04991 L
.40439 .0706 L
.42276 .1213 L
.44284 .18809 L
.45159 .21692 L
.45618 .23044 L
Mistroke
.46102 .24258 L
.46355 .24779 L
.46632 .25247 L
.46754 .25415 L
.46884 .25568 L
.47006 .25686 L
.47119 .25773 L
.47242 .25841 L
.47307 .25866 L
.47376 .25885 L
.47492 .25896 L
.4762 .25881 L
.47733 .25841 L
.47855 .25773 L
.4797 .25683 L
.48075 .2558 L
.48342 .25231 L
.48589 .24798 L
.49151 .23466 L
.50174 .20135 L
.52053 .13379 L
.54086 .07877 L
.552 .05589 L
.56226 .03816 L
.57207 .02514 L
.57701 .02038 L
.5796 .01838 L
.58243 .01659 L
.58515 .01521 L
.58767 .01419 L
.59002 .01344 L
.59263 .01278 L
.59714 .01194 L
.60193 .01121 L
.60712 .01029 L
.61271 .0089 L
.618 .00717 L
.62284 .00531 L
.63198 .00189 L
.63462 .00111 L
.6371 .0005 L
.63933 9e-05 L
Mfstroke
.63933 9e-05 m
.64 0 L
s
.65047 0 m
.65109 8e-05 L
.65248 .00028 L
.66245 .00227 L
.66506 .00276 L
.66782 .00319 L
.66896 .00334 L
.67018 .00346 L
.67088 .00352 L
.67151 .00357 L
.67276 .00363 L
.67345 .00365 L
.67418 .00367 L
.6755 .00366 L
.67623 .00364 L
.67692 .00361 L
.67767 .00357 L
.67848 .00351 L
.67986 .00338 L
.68131 .00321 L
.68389 .00282 L
.69366 .00092 L
.69647 .00044 L
.69785 .00024 L
.69912 9e-05 L
s
.69912 9e-05 m
.70002 0 L
s
.70791 0 m
.70906 .00013 L
.71122 .00046 L
.71361 .00096 L
.71889 .00247 L
.72385 .00425 L
.74222 .01104 L
.75203 .01438 L
.75697 .01651 L
.76237 .01964 L
.767 .02327 L
.77195 .02835 L
.78087 .04125 L
.78618 .05149 L
.79109 .0628 L
.80218 .09555 L
.81195 .13368 L
.82232 .18359 L
.83245 .23836 L
.84208 .28835 L
.84627 .30689 L
.85073 .32314 L
.85329 .3305 L
.85562 .33574 L
.85674 .33776 L
.85796 .33956 L
.85911 .34087 L
.86016 .34175 L
.86129 .34234 L
.86249 .34255 L
.86363 .34237 L
.86466 .34187 L
.86588 .34089 L
.8672 .33934 L
.86845 .33742 L
.8696 .33525 L
.8719 .32985 L
.87444 .32231 L
.87958 .30253 L
.90046 .19033 L
.90988 .14221 L
.91981 .10186 L
.93069 .06976 L
.94067 .04863 L
.94957 .03428 L
.95907 .02259 L
.96369 .01817 L
.96804 .01472 L
.97619 .01005 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`06ooooo`co00000oooool00ol0003o
ooooooooo`0:ooooo`Ko00001_ooool00ol0003oooooooooo`06ooooo`Ko00002Oooool01?l0003o
oooooooooooooolBo`0000;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03o`00
00Kooooo2_l00002ooooo`03o`000?oooooooooo00?ooooo1?l00002ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
023ooooo000Tooooo`03o`000?oooooooooo00Ko0000:?ooool00ol0003oooooooooo`0[ooooo`?o
0000;oooool00ol0003oooooooooo`0Pooooo`Co00002Oooool00ol0003oooooooooo`0Cooooo`;o
00006?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo023ooooo000Tooooo`?o0000
Goooool2o`0002gooooo00?o0000ooooooooool07Oooool3o`0002Gooooo00?o0000ooooooooool0
AOooool00ol0003oooooooooo`0Pooooo`00R?ooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo01Oooooo1_l0000Yooooo`?o0000@oooool00ol0003oooooooooo`0Qooooo`00ROooool3
o`0002Wooooo00?o0000ooooooooool05_ooool2o`00037ooooo0ol0000oooooo`03o`000?oooooo
oooo02;ooooo002<ooooo`03o`000?oooooooooo02Kooooo0_l0000Eooooo`;o0000=_ooool2o`00
03_ooooo0_l0000Uooooo`00SOooool2o`0002Kooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09Oooool008oooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Uooooo`00T?ooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0>Oooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo02Kooooo002Aooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Cooooo00?o0000
ooooooooool09oooool009;ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo03cooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Xoooo
o`00T_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02Sooooo002Cooooo`03o`00
0?oooooooooo01oooooo0_l0000Aooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`0Yooooo`00U?ooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo02Wooooo002Eooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`12ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0:_ooool0
09Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
04?ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Zooooo`00U_ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0A?ooool00ol0003o
ooooooooo`0[ooooo`03o`000?oooooooooo02_ooooo002Fooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo02[ooooo
00?o0000ooooooooool0:oooool009Oooooo00?o0000ooooooooool06oooool2o`0000gooooo00?o
0000ooooooooool0A_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02cooooo002G
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`16
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0;?ooool009Oooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04Sooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`0]ooooo`00V?ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo02gooooo002Hooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
;_ooool009Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo04_ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0^ooooo`00VOooool0
0ol0003oooooooooo`0Iooooo`;o00002_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0;_ooool009Wooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`0_ooooo`00V_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02oo
oooo002Jooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`1=ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0<?ooool009[ooooo00Go
0000oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000003oa0@4?oooooooooo00?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool0<?ooool009[ooooo00GoMgMgo`000?ooooooV9RHogMgM`05ooooo`;o8B4Q
1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
Coooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo033ooooo002Jooooo`05oa0@4?l0
003oooooooooool@41003_ooool00ol0003oooooooooo`05ooooo`?o00001oooool00ol0003ooooo
ooooo`1?ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0<Oooool009[ooooo0_l0
0002ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0aooooo`00V_ooool01Ol0003oooooo`000?oooooo000000kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`0aooooo`00V_ooool01Ol@413oooooo`000?oooooo410@00kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo057ooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0booooo`00V_ooool01OmgMgOoV9RHo`000?nH
V9SoMgMg00kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo05;ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0booooo`00V_ooool0
1Oo^k^ko<S8bo`000?l0003ok^k^00cooooo00?oEEEEofIVI_l000001oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0booooo`00WOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0Doooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo03;ooooo002Moooo
o`03o`000?oooooooooo01Gooooo0_l00005ooooo`03o`000?oooooooooo05Cooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0cooooo`00W_ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo03?ooooo002Nooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
<oooool009kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo05Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0cooooo`00Woooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0E_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03Cooooo002Oooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0=?ooool009oooooo00?o0000ooooooooool04oooool2o`0000?o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo03Co
oooo002Pooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`1Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0=?ooool00:3ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05Sooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0eooooo`00X?ooool00ol0003oooooooooo`0B
ooooo`05o`000?ooooooooooooooool00000Foooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo03Gooooo002Qooooo`03o`000?oooooooooo017ooooo00Go0000ooooooooooooooooo`00
001Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0=Oooool00:7ooooo00?o0000
ooooooooool04Oooool01Ol0003ooooooooooooooooo000005cooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0eooooo`00XOooool00ol0003oooooooooo`0Aooooo`;o000000?ooooo
o`000?ooool0G?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03Gooooo002Roooo
o`03o`000?oooooooooo013ooooo00Co0000oooooooooooo0000GOooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo03Kooooo002Rooooo`03o`000?oooooooooo013ooooo00Co0000oooo
oooooooo0000GOooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo03Kooooo002Roooo
o`03o`000?oooooooooo013ooooo00Co0000oooooooooooo0000GOooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo03Kooooo002Sooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ool00000Goooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03Kooooo002Sooooo`03
o`000?oooooooooo00oooooo00?o0000ooooool00000Goooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo03Kooooo002Sooooo`03o`000?oooooooooo00oooooo0ol0001Oooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0=oooool00:Cooooo00?o0000ooooooooool03_oo
ool2o`00063ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0gooooo`00Y?ooool0
0ol0003oooooooooo`0>ooooo`;o0000H?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo03Oooooo002Tooooo`03o`000?oooooooooo00kooooo0_l0001Pooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0=oooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`03ob4Q8Ol0003ooooo00?ooooo1Ol00006ooooo`03o`000?oooooooooo063ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0gooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo00?o8B4Qo`000?ooool00oooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000
ooooooooool0H?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03Oooooo002Joooo
o`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`03ooooo`03oiRHV?lQ8B7o
k^k^00Oooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo03Sooooo002Jooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`04
ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0001Pooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0>?ooool009[ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo00Gooooo00?oMgMgofIVI_ooool01?ooool2o`0006;ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0hooooo`00V_ooool01Ol@413ooooooooooooooooo410@00Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`03ooooo`;o0000Hoooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo03Sooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01oooool0
2Ol0003ooooooooooooooooo0000okZj^_ooooooV9RHoa0@4005ooooo`;o0000Hoooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo03Sooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01oooool02Ol0003oooooooooooooooooV9RHoa0@4?l0003o8B4Qolc<c004ooooo`03o`000?oo
oooo000006?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0iooooo`00Yoooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooo000006?ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0iooooo`00Yoooool00ol0003oooooooooo`09ooooo`04o`000?oooooo0000
o`0006;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0iooooo`00Z?ooool00ol0
003oooooooooo`07ooooo`04o`000?ooooooooooo`0006Cooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0iooooo`00Z?ooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooo
o`0006Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0iooooo`00Z?ooool00ol0
003oooooooooo`07ooooo`04o`000?ooooooooooo`0006Cooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0iooooo`00ZOooool00ol0003oooooooooo`06ooooo`04o`000?oooooooooo
o`0006Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0jooooo`00ZOooool00ol0
003oooooooooo`05ooooo`05o`000?ooooooooooooooool00000I?ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo03[ooooo002Zooooo`03o`000?oooooooooo00Cooooo00Co0000oooo
oooooooooooo0_l0001Sooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0>_ooool0
0:[ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000006Gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0jooooo`00Zoooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo03[ooooo002[ooooo`;o000000?oooooo`000?l000001Oooool00ol0003o
ooooooooo`1Sooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0>_ooool00:gooooo
0_l00006ooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0kooooo`00]Oooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0>oooool00;Gooooo0_l0001Uooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0>oooool00;Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo03_ooooo002eooooo`03o`000?oooooooooo06Cooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0kooooo`00]Oooool00ol0003oooooooooo`1Tooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0??ooool00;Gooooo00?o0000ooooooooool0I?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03cooooo002eooooo`03o`000?oooooo
oooo06Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0looooo`00]Oooool00ol0
003oooooooooo`1Uooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0??ooool00;Go
oooo0_l0001Vooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0??ooool00;Gooooo
00?o0000ooooooooool0IOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03cooooo
002eooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0mooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05oiRHV?l@
413o0000oc8b<_o<c<`01_ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0?Oooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Kooooo00?o0000ooooooooool0I_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo03gooooo002Jooooo`05oa0@4?ooooooooooooooool@
41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06Kooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0mooooo`00V_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oZJVYoa0@4?ooool01Oooool3o`0006Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0nooooo`00V_ooool01Ol0003ooooooooooooooooo000000gooooo00?o410@o`000?nj
^[X01_ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0?_ooool009[ooooo00Go410@oooooooooooooooooa0@400>ooooo`03okZj^_lQ8B7ooooo00Go
oooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03ko
oooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413oV9RHoooooonj^[[o0000
00Kooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
03oooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413o
ZJVY00Kooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo03oooooo002eooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0oooooo`00]Oooool2o`0006Wooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0oooooo`00]Oooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0?oooool00;Gooooo00?o0000ooooooooool0JOooool01Ol0003ooooooooo
oooooooo000004;ooooo002eooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool00_l0
0012ooooo`00]Oooool00ol0003oooooooooo`1Zooooo`?o0000@oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0/?ooool009[ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo
0ol0002`ooooo`00V_ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo
00001oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol0003ooooooooooooooooo000000_o
oooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`2`oooo
o`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0
003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`00
0?ooool01_ooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool0
0oooool3o`000;3ooooo002Jooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool009[ooooo
00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co
00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002/
ooooo`03o`000?nj^[[ooooo0;Wooooo002/ooooo`;o<S8b^_ooool007gooooo0_l000001_l@413o
ooooooooool@413o0000oa0@41Sooooo1?l000001Ol@413oooooooooooooooooA4A400;o000000Oo
<S8bomgMgOooooooooooohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Ioooo
o`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0Loooool007kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00003?ooool00ol0003ooooo
ooooo`06ooooo`07ogMgMolb<S;oooooooooooo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^
ogMgMol@41002Oooool6o`0000gooooo00WoMgMgoc8b<_ooooooooooob4Q8OnHV9SooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1c
ooooo`00O_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01oooooo00Co0000oooo
oooooooo00000oooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooo
oa0@4003ooooo`03oa0@4?oooooooooo077ooooo001nooooo`06o`000?ooooooA4A4odA4A?oooooo
00002Oooool6o`0000cooooo00?o0000ooooooooool01_ooool00omgMgOo<S8booooo`0@ooooo`03
o`000?oooooooooo00_ooooo1_l0000=ooooo`09ogMgMolb<S;ooooooooooolb<S;oV9RHoooooonH
V9So<S8b00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
0000Loooool007kooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Kooooo`03o`000?oooooooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Aooooo`03o`000?oooooooooo01_ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c002ooooo`05olc<c?l0003o0000o`000?o<c<`00oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00001cooooo`00O_ooool01_l0003o
QhN7ojVYZOnj^[[oEEEEo`0001_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0A
ooooo`03oa0@4?l0003o000000?o00006_ooool00ol0003oooooooooo`04ooooo`05oa0@4?nj^[[o
oooookZj^_l@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@401cooooo`00O_ooool01_l0003o<S8boooooooooooo<S8bo`0001_ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool01?ooool01Ol0003o^[Zjoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Loooool007gooooo00?o410@o`000?n7QhL00_oo
ool00on7QhOo0000oa0@400Hooooo`03oeEEEOmVIVKo000000Gooooo1?l0000Booooo`03o`000?oo
oooooooo01_ooooo1?l00003ooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1cooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5900) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26191 m
.04262 .15837 L
.0522 .11339 L
.06244 .07764 L
.0679 .06376 L
.07286 .05369 L
.08255 .03897 L
.09388 .02614 L
.10458 .0159 L
.11428 .00856 L
.11917 .00594 L
.12195 .00482 L
.12455 .00402 L
.12569 .00375 L
.12693 .0035 L
.12803 .00333 L
.12919 .00318 L
.13035 .00307 L
.13139 .003 L
.13245 .00297 L
.13344 .00295 L
.1346 .00297 L
.13583 .00301 L
.13688 .00306 L
.13803 .00314 L
.14299 .00359 L
.1455 .00383 L
.14683 .00394 L
.14823 .00405 L
.14946 .00412 L
.15011 .00415 L
.15081 .00417 L
.15204 .0042 L
.1532 .0042 L
.15433 .00419 L
.15556 .00414 L
.15685 .00406 L
.15805 .00396 L
.1602 .00371 L
.1625 .00335 L
.17339 .00084 L
s
.17339 .00084 m
.1769 0 L
s
.20396 0 m
.20476 .00015 L
.2098 .00116 L
.21257 .00164 L
.21393 .00184 L
.21519 .002 L
.21635 .00212 L
.21763 .00223 L
.21892 .00231 L
.21962 .00234 L
.22028 .00236 L
.22145 .00237 L
.22251 .00236 L
.22368 .00232 L
.22492 .00224 L
.22616 .00214 L
.2275 .00199 L
.22993 .00165 L
.23449 .00078 L
s
.23449 .00078 m
.23803 0 L
s
.2711 0 m
.27344 .00049 L
.2785 .00155 L
.2807 .00192 L
.28309 .00224 L
.28439 .00237 L
.28559 .00247 L
.28674 .00253 L
.28796 .00256 L
.28924 .00257 L
.29044 .00254 L
.29175 .00248 L
.29249 .00243 L
.29316 .00237 L
.29586 .00207 L
.29881 .00162 L
.30418 .00057 L
s
.30418 .00057 m
.307 0 L
s
.3363 0 m
.33952 .00068 L
.34485 .00179 L
.34732 .00224 L
.34995 .00264 L
.35123 .0028 L
.35243 .00293 L
.35351 .00303 L
.35469 .00312 L
.35595 .00319 L
.35664 .00322 L
.35728 .00324 L
.35843 .00326 L
.35966 .00326 L
.36035 .00326 L
.36111 .00324 L
.36182 .00322 L
.36248 .0032 L
.36372 .00314 L
.36505 .00306 L
.36974 .0027 L
.37231 .00249 L
.3747 .00231 L
.37674 .00218 L
.37788 .00213 L
.37892 .00209 L
.38007 .00207 L
.38131 .00206 L
.38248 .00208 L
.38356 .00211 L
.38479 .00217 L
.38594 .00226 L
.38721 .00238 L
.38857 .00254 L
.39134 .00298 L
.39388 .00351 L
.39959 .00511 L
.40502 .00707 L
.41479 .01124 L
.42521 .01621 L
.43559 .02219 L
.44501 .02973 L
.44955 .0345 L
.45447 .04071 L
.46339 .0551 L
.47289 .07523 L
.48332 .10308 L
.50438 .17356 L
.5144 .20815 L
.52388 .23567 L
Mistroke
.52912 .24684 L
.53208 .25151 L
.53349 .25328 L
.53482 .25466 L
.53602 .25567 L
.53712 .25639 L
.53834 .25695 L
.53966 .25729 L
.54085 .25734 L
.54216 .25712 L
.54282 .25691 L
.54352 .25659 L
.54479 .25582 L
.54603 .25481 L
.54738 .25342 L
.55012 .24972 L
.55266 .24527 L
.55503 .24028 L
.56613 .20839 L
.58628 .13612 L
.59668 .10286 L
.60656 .07706 L
.61542 .05871 L
.62509 .04313 L
.63543 .03059 L
.64479 .02213 L
.6556 .01498 L
.66046 .01251 L
.66578 .01022 L
.67556 .00703 L
.6809 .00579 L
.68589 .00492 L
.69056 .00433 L
.69481 .00394 L
.69716 .00378 L
.69972 .00364 L
.70437 .00342 L
.7089 .00321 L
.71379 .00294 L
.71915 .0025 L
.72417 .00196 L
.73421 .00059 L
Mfstroke
.73421 .00059 m
.73875 0 L
s
.7615 0 m
.76526 .00055 L
.77062 .00148 L
.77627 .00243 L
.7786 .00276 L
.78109 .00306 L
.78252 .00319 L
.78382 .00329 L
.78513 .00337 L
.78637 .00342 L
.78748 .00345 L
.78871 .00346 L
.78999 .00346 L
.79119 .00343 L
.7923 .00339 L
.79333 .00334 L
.79563 .00319 L
.80084 .00274 L
.80338 .00251 L
.80568 .00233 L
.80687 .00226 L
.80816 .00219 L
.80886 .00217 L
.80952 .00215 L
.81079 .00214 L
.81209 .00217 L
.81282 .00219 L
.81351 .00223 L
.81423 .00228 L
.81489 .00234 L
.81637 .00251 L
.81767 .0027 L
.81887 .00293 L
.82159 .00359 L
.82398 .00437 L
.82653 .00539 L
.83142 .0079 L
.8359 .01078 L
.846 .01879 L
.85484 .02691 L
.86429 .03699 L
.86942 .0437 L
.87409 .05107 L
.88322 .07064 L
.88833 .08548 L
.89387 .1052 L
.90392 .1505 L
.92341 .25701 L
.92875 .28388 L
.93448 .30834 L
Mistroke
.93726 .31803 L
.9399 .32571 L
.94227 .33125 L
.94351 .33361 L
.94484 .33574 L
.94596 .33715 L
.94698 .33817 L
.94795 .3389 L
.94898 .3394 L
.9499 .33961 L
.95077 .3396 L
.95171 .33937 L
.95272 .33886 L
.95381 .33802 L
.95498 .33676 L
.95711 .33358 L
.95919 .32939 L
.96111 .3246 L
.96843 .299 L
.97619 .26191 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01?ooool=o`0000Gooooo00?o0000ooooooooool01Oooool7o`0000Wo
oooo00?o0000ooooooooool00_ooool8o`0000_ooooo4Ol00007ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Ko
oooo3Ol00002ooooo`03o`000?oooooooooo00Oooooo4Ol00009ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo023o
oooo000Tooooo`03o`000?oooooooooo01[ooooo0_l0000Booooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool03_ooool4o`0001_ooooo00?o0000ooooooooool0;Oooool01?l0003ooooo
ooooooooool5o`0002Oooooo00Co0000oooooooooooo0000;?ooool00ol0003oooooooooo`0Poooo
o`00?oooool2o`0005Wooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0_ooooo`;o
0000<?ooool3o`0004cooooo000nooooo`03o`000?oooooooooo05[ooooo0ol0000Gooooo`03o`00
0?oooooooooo02gooooo0_l0000eooooo`03o`000?oooooooooo04Wooooo000mooooo`03o`000?oo
oooooooo05kooooo0_l0000Eooooo`03o`000?oooooooooo02_ooooo0_l0000hooooo`03o`000?oo
oooooooo04Sooooo000looooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool04_ooool2
o`0002_ooooo00?o0000ooooooooool0>Oooool2o`0004Sooooo000kooooo`03o`000?oooooooooo
06?ooooo0_l0000Booooo`03o`000?oooooooooo02Sooooo0_l0000nooooo`03o`000?oooooooooo
04Gooooo000jooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0A?ooool003Wooooo
00?o0000ooooooooool0J?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool0@?ooool00ol0003oooooooooo`14ooooo`00>?ooool00ol0003ooooooooo
o`1Zooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`11ooooo`03o`000?oooooooooo04?ooooo000gooooo`03o`000?oooooooooo06cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo04?ooooo00?o0000
ooooooooool0@_ooool003Kooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`11oooo
o`00=_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo00_ooooo0_l0000Tooooo`03
o`000?oooooooooo04Oooooo00?o0000ooooooooool0@?ooool003Gooooo00?o0000ooooooooool0
Koooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
Aoooool00ol0003oooooooooo`10ooooo`00=?ooool00ol0003oooooooooo`1aooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`19ooooo`03o`000?oo
oooooooo03oooooo000cooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0?oooool0
03?ooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0oooooo`00<oooool00ol0003o
ooooooooo`1dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`1<ooooo`03o`000?oooooooooo03kooooo000booooo`03o`000?oooooooooo07Kooooo
00?o0000ooooooooool01oooool2o`00027ooooo00?o0000ooooooooool0C?ooool00ol0003ooooo
ooooo`0nooooo`00<_ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo03gooooo000b
ooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0?Oooool0037ooooo00?o0000oooo
ooooool0N?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool0D?ooool00ol0003oooooooooo`0looooo`00<Oooool00ol0003oooooooooo`1iooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1@ooooo`03
o`000?oooooooooo03cooooo000`ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0
>oooool0033ooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`04ooooo`;o00007_oo
ool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo03_ooooo000`ooooo`03o`000?oooooo
oooo07_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo05Cooooo00?o0000ooooooooool0>_ooool002oooooo00?o0000ooooooooool0O?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0E?ooool00ol0
003oooooooooo`0jooooo`00;oooool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo03[o
oooo000_ooooo`03o`000?oooooooooo06Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool5o`0000Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Eooooo`03
o`000?oooooooooo03[ooooo000^ooooo`03o`000?oooooooooo06Wooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0iooooo`00;_ooool00ol0003ooooo
ooooo`1Yooooo`05oa0@4?ooooooooooooooool@41003_ooool01?l0003oooooooooool00004oooo
o`?o00006_ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo03Wooooo000^ooooo`03
o`000?oooooooooo06Wooooo00Go0000ooooooooooooooooo`00000>ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooo
oooo03Wooooo000^ooooo`03o`000?oooooooooo06Wooooo00Go0000ooooooooooooooooo`00000>
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`1Gooooo`03o`000?oooooooooo03Wooooo000]ooooo`03o`000?oooooooooo06[ooooo00Go410@
oooooooooooooooooa0@400>ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0>Oooool002gooooo00?o
0000ooooooooool0J_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0FOooool00ol0003o
ooooooooo`0hooooo`00;Oooool00ol0003oooooooooo`1Zooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03?ooool00omEEEGoIVIVo`000003ooooo`05o`000?ooooooooooooooool000006oooool00ol0
003oooooooooo`1Iooooo`03o`000?oooooooooo03Sooooo000]ooooo`03o`000?oooooooooo08;o
oooo00Co0000oooooooooooo00006_ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo
03Sooooo000/ooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool00_l0000Iooooo`03
o`000?oooooooooo05[ooooo00?o0000ooooooooool0>?ooool002cooooo00?o0000ooooooooool0
Poooool01?l0003oooooooooool0000Jooooo`03o`000?oooooooooo05[ooooo00?o0000oooooooo
ool0>?ooool002cooooo00?o0000ooooooooool0Poooool01?l0003oooooooooool0000Iooooo`03
o`000?oooooooooo05cooooo00?o0000ooooooooool0=oooool002cooooo00?o0000ooooooooool0
Q?ooool00ol0003oooooo`00000Iooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0
=oooool002_ooooo00?o0000ooooooooool0QOooool00ol0003oooooo`00000Iooooo`03o`000?oo
oooooooo05cooooo00?o0000ooooooooool0=oooool002_ooooo00?o0000ooooooooool0QOooool0
0ol0003oooooo`00000Iooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0=oooool0
02_ooooo00?o0000ooooooooool0QOooool01?l0003oooooo`000?l0000Gooooo`03o`000?oooooo
oooo05gooooo00?o0000ooooooooool0=oooool002_ooooo00?o0000ooooooooool0Q_ooool2o`00
01Sooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0fooooo`00:oooool00ol0003o
ooooooooo`26ooooo`;o00006?ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo03Ko
oooo000Zooooo`03o`000?oooooooooo08Oooooo0_l0000Gooooo`03o`000?oooooooooo05oooooo
00?o0000ooooooooool0=_ooool002[ooooo00?o0000ooooooooool0R?ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0=_ooool002[ooooo00?o0000
ooooooooool0R?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo05oooooo00?o0000
ooooooooool0=_ooool002[ooooo00?o0000ooooooooool0R?ooool2o`0001Kooooo00?o0000oooo
ooooool0H?ooool00ol0003oooooooooo`0eooooo`00:_ooool00ol0003oooooooooo`28ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0eooooo`00
:Oooool00ol0003oooooooooo`29ooooo`;o00005Oooool00ol0003oooooooooo`1Qooooo`03o`00
0?oooooooooo03Gooooo000Yooooo`03o`000?oooooooooo08Wooooo0_l0000Eooooo`03o`000?oo
oooooooo067ooooo00?o0000ooooooooool0=Oooool002Wooooo00?o0000ooooooooool0ROooool2
o`0001Gooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0eooooo`00:Oooool00ol0
003oooooooooo`29ooooo`;o00005?ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo
03Cooooo000Yooooo`03o`000?oooooooooo08Wooooo0ol0000Cooooo`03o`000?oooooooooo06?o
oooo00?o0000ooooooooool0=?ooool002Sooooo00?o0000ooooooooool0R_ooool00ol0003ooooo
o`00000Cooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0=?ooool002Sooooo00?o
0000ooooooooool0R_ooool00ol0003oooooo`00000Booooo`03o`000?oooooooooo06Cooooo00?o
0000ooooooooool0=?ooool002Sooooo00?o0000ooooooooool0R_ooool01?l0003oooooooooool0
000Aooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0=?ooool002Sooooo00?o0000
ooooooooool0Koooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_oo
ool01?l0003oooooooooool0000Aooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0
<oooool002Sooooo00?o0000ooooooooool0Koooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool01?l0003oooooooooool0000Aoooo
o`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0<oooool002Oooooo00?o0000oooooooo
ool0L?ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool01Ol0
003ooooooooooooooooo000000oooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0c
ooooo`009oooool00ol0003oooooooooo`1`ooooo`05o`000?ooooooooooooooool000003Oooool0
0onHV9So8B4Qonk^kP06ooooo`?o000000?oooooo`000?ooool03_ooool00ol0003oooooooooo`1V
ooooo`03o`000?oooooooooo03?ooooo000Wooooo`03o`000?oooooooooo073ooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00Go0000ooooooooooooooooo`00
000?ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0<oooool002Oooooo00?o0000
ooooooooool0L?ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0I_oo
ool00ol0003oooooooooo`0cooooo`009oooool00ol0003oooooooooo`1`ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0
<_ooool002Oooooo00?o0000ooooooooool0L?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo03;ooooo000Vooooo`03o`00
0?oooooooooo08cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo06Sooooo00?o0000ooooooooool0<_ooool002Kooooo00?o0000ooooooooool0S?oo
ool2o`0000Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Yooooo`03o`000?oo
oooooooo03;ooooo000Vooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0<_ooool0
02Kooooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0aooooo`009_ooool00ol0003o
ooooooooo`2<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`1[ooooo`03o`000?oooooooooo037ooooo000Uooooo`03o`000?oooooooooo08gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo06_ooooo
00?o0000ooooooooool0<Oooool002Gooooo00?o0000ooooooooool0SOooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Joooool00ol0003ooooooooo
o`0aooooo`009Oooool00ol0003oooooooooo`2=ooooo`;o00001oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0<Oooool002Gooooo00?o0000oooo
ooooool0SOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0K_ooool00ol0003oooooooooo`0`ooooo`009Oooool00ol0003oooooooooo`2=ooooo`03
o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00001aooooo`03o`000?oooooooooo
033ooooo000Tooooo`03o`000?oooooooooo08kooooo00?o0000ooooooooool02?ooool3o`0007;o
oooo00?o0000ooooooooool0<?ooool002Cooooo00?o0000ooooooooool0S_ooool00ol0003ooooo
ooooo`1mooooo`03o`000?oooooooooo033ooooo000Tooooo`03o`000?oooooooooo08kooooo00?o
0000ooooooooool0OOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo023ooooo002e
ooooo`;o0000Ooooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo023ooooo002eoooo
o`03o`000?oooooooooo07kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Poooo
o`00]Oooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool08?ooool00;Gooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo027ooooo002eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Qooooo`00]Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool08Oooool00;Gooooo00?o0000ooooooooool0Ooooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo027ooooo002eooooo`;o0000P?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo027ooooo002eooooo`03o`000?oooooooooo083ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Rooooo`00]Oooool00ol0003ooooooooo
o`20ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08_ooool009[ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Kooooo
00?o0000ooooooooool0P?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02;ooooo
002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go410@okZj^_oooooo
MgMgoc8b<P06ooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Rooooo`00V_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool08_ooool009[ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ojVYZOl@413ooooo00Go
oooo0ol00021ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08oooool009[ooooo
00Go0000ooooooooooooooooo`00000=ooooo`03oa0@4?l0003o^[Zj00Kooooo00?o0000oooooooo
ool0POooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02?ooooo002Jooooo`05oa0@
4?ooooooooooooooool@41003_ooool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo08;o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Sooooo`00V_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooooooo
08;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Sooooo`00V_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooo
oooo08;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Tooooo`00]Oooool00ol0
003oooooooooo`22ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09?ooool00;Go
oooo0_l00023ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09Oooool00;Gooooo
00?o0000ooooooooool0Poooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Gooooo
002eooooo`03o`000?oooooooooo08Cooooo00Co0000oooooooooooo0000:?ooool00;Gooooo00?o
0000ooooooooool0QOooool3o`0002Sooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0;3ooooo
002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@00_ooooo
1Ol00006ooooo`?o0000/?ooool009[ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4
A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000oooooooooooo
ooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0/?ooool009[o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co0000
00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=oooo
o`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aoooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00V_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`00
0?oooooooooo00?ooooo0ol0002`ooooo`00V_ooool01Ol0003ooooooooooooooooo000000oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol0003ooooooooo
oooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3o
oooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00[?ooool00ol0003o^[Zjooooo`2iooooo`00[?ooool2oc8b<[[ooooo001mooooo`;o
000000Ko410@oooooooooooo410@o`000?l@410Hooooo`Co000000Go410@ooooooooooooooooodA4
A002o`000007oc8b<_oMgMgooooooooooon7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4
A?nj^[X06Oooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Co410@o`000?m4A4Coc<c<1?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1cooooo`00
O_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l0000<ooooo`03o`00
0?oooooooooo00Kooooo00OoMgMgoc8b<_ooooooooooolc<c?l0003o410@00cooooo00Go410@okZj
^_o^k^koMgMgoa0@4009ooooo`Ko00003Oooool00omgMgOo<S8booooo`03ooooo`03oiRHV?l@413o
gMgM00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Loooool007kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo00?ooooo00?oQhN7oeEEEOooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooooooooa0@401cooooo`00O_ooool01_l0003oooooodA4A?m4A4Coooooo`00
00Wooooo1_l0000<ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool04?ooool00ol0
003oooooooooo`0;ooooo`Ko00003Oooool02OmgMgOo<S8booooooooooooc<c<ob4Q8Ol0003oEEEE
o`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
07?ooooo001nooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo00006oooool00ol0003oooooooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`04Oooool00ol0003oooooooooo`0Kooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`00_ooool01OlQ8B7oQhN7oooooonHV9So000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool00000Loooool007kooooo00Ko0000ohN7
QonYZJWo^[ZjoeEEEOl0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Ooo
ool00ol@413o0000o`000003o`0001[ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@4100Loooool007kooooo00Ko0000oc8b<_oooooooooooc8b<_l0000Kooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00Cooooo00Go8B4QoiRHV?ooooooMgMgoeEEE@03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg07?ooooo001mooooo`03oa0@4?l0003oQhN700;ooooo
00?oQhN7o`000?l@41006?ooool00omEEEGoIVIVo`000005ooooo`Co00004_ooool00ol0003ooooo
ooooo`0Kooooo`Co00000oooool01Oo<c<co410@o`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0Loooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00793651 0 1.03006 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-60)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-40)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-20)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(40)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(60)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.2)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.3)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.5)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6000) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .08815 m
.04262 .16561 L
.06244 .27106 L
.06747 .29538 L
.07286 .31717 L
.07547 .32566 L
.07793 .33222 L
.08015 .33678 L
.0814 .33878 L
.08255 .34024 L
.08382 .34141 L
.08453 .34186 L
.08518 .34215 L
.08644 .34236 L
.08764 .34213 L
.08831 .34182 L
.08903 .34134 L
.09032 .34011 L
.09111 .33911 L
.09185 .33802 L
.09325 .33555 L
.09608 .32889 L
.09869 .32094 L
.10458 .2974 L
.125 .18675 L
.13497 .13685 L
.14407 .10077 L
.15348 .07266 L
.16239 .05267 L
.1718 .03644 L
.17708 .02909 L
.18204 .02325 L
.18694 .01848 L
.19144 .01496 L
.19643 .01195 L
.19922 .01064 L
.20181 .00962 L
.2067 .00814 L
.21205 .00698 L
.22282 .00517 L
.23334 .00335 L
.23851 .00246 L
.24328 .00175 L
.24761 .00125 L
.24979 .00106 L
.2522 .0009 L
.25346 .00084 L
.25461 .00079 L
.25524 .00077 L
.25593 .00076 L
Mistroke
.25719 .00073 L
.25837 .00072 L
.25962 .00072 L
.2608 .00073 L
.26187 .00074 L
.26307 .00075 L
.2642 .00077 L
.26676 .00082 L
.26814 .00084 L
.26946 .00086 L
.27064 .00088 L
.27192 .00089 L
.27304 .00089 L
.27423 .00089 L
.27525 .00088 L
.27638 .00087 L
.27756 .00084 L
.27884 .0008 L
.28115 .00071 L
.28368 .00057 L
.28645 .00038 L
Mfstroke
.28645 .00038 m
.29132 0 L
s
.31593 0 m
.31682 9e-05 L
.32163 .00065 L
.32683 .00123 L
.32826 .00136 L
.32976 .00148 L
.33106 .00156 L
.33177 .0016 L
.33244 .00163 L
.33376 .00167 L
.33495 .00168 L
.33607 .00168 L
.33729 .00166 L
.33793 .00164 L
.33863 .00161 L
.34005 .00152 L
.34137 .00142 L
.3426 .00131 L
.34757 .00066 L
s
.34757 .00066 m
.35154 0 L
s
.3827 0 m
.39038 .00162 L
.39284 .00205 L
.39419 .00225 L
.39544 .00241 L
.3966 .00253 L
.39765 .00262 L
.39882 .00269 L
.40007 .00274 L
.40073 .00276 L
.40144 .00276 L
.40269 .00274 L
.40339 .00271 L
.40405 .00268 L
.40477 .00263 L
.40554 .00257 L
.40824 .00227 L
.4107 .00189 L
.41553 .00096 L
s
.41553 .00096 m
.42025 0 L
s
.4399 0 m
.44495 .0015 L
.4505 .00359 L
.4557 .00564 L
.46046 .00731 L
.46276 .008 L
.46528 .00865 L
.46768 .00915 L
.46986 .00952 L
.4724 .00986 L
.47511 .01014 L
.47998 .01056 L
.48218 .01079 L
.48451 .0111 L
.48706 .01158 L
.4894 .01218 L
.49159 .01292 L
.49363 .01379 L
.49828 .01647 L
.50088 .01844 L
.50328 .02058 L
.50872 .02649 L
.51862 .04048 L
.53718 .07385 L
.55583 .12003 L
.56645 .15607 L
.57643 .19387 L
.58626 .22813 L
.5912 .2417 L
.59403 .24788 L
.5966 .25235 L
.59775 .25397 L
.59899 .25546 L
.60006 .25652 L
.60124 .25745 L
.60249 .25815 L
.60317 .25841 L
.60381 .25858 L
.60496 .25869 L
.60619 .25854 L
.60733 .25816 L
.60858 .25748 L
.60975 .25659 L
.61085 .25556 L
.61291 .25308 L
.61511 .24972 L
.62048 .23876 L
.62541 .22593 L
.63655 .19132 L
.65673 .1252 L
Mistroke
.6666 .09546 L
.67718 .06746 L
.68231 .05595 L
.68716 .04659 L
.69149 .03961 L
.69625 .03338 L
.70085 .02875 L
.70572 .02505 L
.71024 .02248 L
.71447 .02052 L
.73427 .01157 L
.74412 .00626 L
.74949 .00376 L
.7521 .00276 L
.75448 .00202 L
.75668 .00148 L
.75876 .00111 L
.7599 .00096 L
.76095 .00086 L
.76211 .00078 L
.76333 .00074 L
.76447 .00074 L
.76571 .00078 L
.76687 .00085 L
.76793 .00094 L
.77053 .00125 L
.77299 .00162 L
.77796 .0025 L
.78263 .00323 L
.78497 .0035 L
.78628 .00361 L
.78749 .00369 L
.78874 .00373 L
.78945 .00374 L
.79011 .00374 L
.79081 .00373 L
.79144 .00371 L
.79218 .00368 L
.79287 .00364 L
.79393 .00356 L
.7951 .00344 L
.79746 .00312 L
.8017 .00232 L
.81128 4e-05 L
Mfstroke
.81128 4e-05 m
.81146 0 L
s
.83782 0 m
.84162 .00075 L
.84635 .00161 L
.84904 .002 L
.85028 .00215 L
.85157 .00227 L
.85273 .00237 L
.854 .00244 L
.85515 .00249 L
.85622 .00251 L
.85749 .00251 L
.85864 .00249 L
.85928 .00247 L
.85997 .00244 L
.86123 .00238 L
.86247 .00229 L
.86382 .00217 L
.86657 .00189 L
.87149 .0013 L
.87384 .00104 L
.87608 .00082 L
.87731 .00072 L
.87865 .00064 L
.87988 .00059 L
.88101 .00056 L
.88217 .00055 L
.88327 .00056 L
.88426 .0006 L
.88532 .00065 L
.88648 .00074 L
.88771 .00086 L
.88991 .00115 L
.89247 .00161 L
.89489 .00214 L
.89942 .00339 L
.90959 .00688 L
.91832 .01008 L
.92794 .01388 L
.93261 .01614 L
.93763 .01917 L
.94293 .02334 L
.9479 .02842 L
.95283 .03481 L
.95752 .04229 L
.96633 .06048 L
.97619 .08815 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Vooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h08oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1?ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo000Qooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Coooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo000Iooooo`Ko00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Looooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@4100D?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41008oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Soooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@01gooooo000Q
ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000002Cooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000002Gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000057ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000002?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000002?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooooooo
ooooool000007Oooool0027ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oooooo
ooooooooool000009?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00009_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000D_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000008oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000008oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000ooooooooooooooooo`00000Mooooo`008Oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41009Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41009oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0DOoo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool08_ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41008oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@41007Oooool0027ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Coooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Toooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Sooooo`03omgMgOl@413o
V9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`008_ooool01?o<c<coA4A4o`000?l@
4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09_ooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000Moooo
oooo0000<_l0000Jooooo`009?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooool000001Ol00004ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool01?ooool6o`0000_ooooo00?o0000ooooooooool01ol00002ooooo`03o`000?oooooooooo00Co
oooo0ol00002ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?l00003ooooo`_o
00000oooool00ol0003oooooooooo`06ooooo`Wo00001?ooool6o`0000Sooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Pooooo`009?ooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo00Gooooo1_l0000Rooooo`03o`000?oooooooooo01oooooo0ol0000;ooooo`03o`00
0?oooooooooo02gooooo00?o0000ooooooooool05_ooool2o`0001Gooooo00?o0000ooooooooool0
6Oooool3o`00017ooooo00?o0000ooooooooool08?ooool005[ooooo0ol0001=ooooo`Ko00001Ooo
ool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo03Cooooo0ol0000aooooo`00F?ooool2
o`0005Kooooo1?l000000ooooooo0000ooooo`14ooooo`;o0000>_ooool00ol0003oooooooooo`0^
ooooo`00Eoooool00ol0003oooooooooo`1Jooooo`;o0000@_ooool3o`0003gooooo0_l0000^oooo
o`00EOooool2o`0005kooooo0_l0000oooooo`;o0000@_ooool00ol0003oooooooooo`0[ooooo`00
E?ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooo000003cooooo0_l00015ooooo`03o`00
0?oooooooooo02[ooooo001Dooooo`03o`000?oooooooooo05kooooo00Co0000oooooooooooo0000
>_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo02Wooooo001Cooooo`03o`000?oo
oooooooo05oooooo00Co0000oooooooooooo0000>?ooool2o`0004[ooooo00?o0000ooooooooool0
:?ooool005;ooooo00?o0000ooooooooool0H?ooool01Ol0003ooooooooooooooooo000003Kooooo
00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Xooooo`00DOooool00ol0003ooooooooo
o`1Qooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`1;ooooo`03o`000?oooooooooo02Oooooo001Aooooo`03o`000?oooooooooo067ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo04gooooo00?o0000
ooooooooool09_ooool0053ooooo00?o0000ooooooooool0H_ooool2o`0000Cooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo02Gooooo001?ooooo`03
o`000?oooooooooo06?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo04oooooo00?o0000ooooooooool09Oooool004oooooo00?o0000ooooooooool0
Hoooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
D?ooool00ol0003oooooooooo`0Tooooo`00C_ooool00ol0003oooooooooo`1Tooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Aooooo`03o`000?oo
oooooooo02Cooooo001>ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0/ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool09?ooool0
04gooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`0Sooooo`00COooool00ol0003o
ooooooooo`1Uooooo`;o00001oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo05?o
oooo00?o0000ooooooooool08oooool004gooooo00?o0000ooooooooool0IOooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0E?ooool00ol0003ooooo
ooooo`0Sooooo`00C?ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo02;ooooo001<
ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool08_ooool004cooooo00?o0000oooo
ooooool0I_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool0E_ooool00ol0003oooooooooo`0Rooooo`00Boooool00ol0003oooooooooo`1Wooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1Gooooo`03
o`000?oooooooooo027ooooo001;ooooo`03o`000?oooooooooo06Oooooo0_l0000:ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Qooooo`00Booo
ool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo027ooooo000Tooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0Pooooo`009?ooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo07gooooo000Tooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool0COooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool0O_ooool002Gooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`1>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool0O_ooool002Gooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1>ooooo`05
oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05ooooo`?o00002oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo07oooooo000Uooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool0C_ooool01Ol0003ooooooooooooooooo000000kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool0Ooooool002Gooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1>ooooo`05
o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1oooooo`009_ooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo04oooooo00Go410@oooooooooooooooooa0@400>oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo083ooooo000Vooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool0Coooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0P?ooool002Ko
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1?ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`20ooooo`009_ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo06_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo087ooooo000Wooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
Joooool2o`0000oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`21ooooo`009ooo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo087ooooo000Wooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool0POooool002Sooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`1/ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`22ooooo`00:?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo06co
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo08;o
oooo000Xooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0K?ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0P_ooool002Sooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`1/ooooo`;o00004Oooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo08?ooooo000Yooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool0Poooool002Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`23oooo
o`00:Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo08Cooooo000Yooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool0Q?ooool002[ooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`24ooooo`00:_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo06kooooo0_l0000Booooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0Q?ooool0
02[ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`25ooooo`00:_ooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo08Gooooo000Zooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0QOooool002_ooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`1^ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`26ooooo`00:oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo06oooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo08Kooooo000[oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0Koooool2o`0001Cooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`26ooooo`00:oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo06oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo08Oooooo000[ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
Koooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
Qoooool002cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1_ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`27ooooo`00;?ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo08Oooooo000/ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool0EOooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0R?ooool002cooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`1Eooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`28ooooo`00;?oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo05Gooooo00Go0000oooooooooooooooo
o`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0000Eooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0R?ooool002gooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`1Eooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`29ooooo`00;Ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05Gooooo00Go410@oooooooooooooooo
oa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo08Wooooo000]ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0E_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo
V9RHoa0@4006ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`29ooooo`00;Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo05Kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0ROooool002go
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2:ooooo`00;Oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo077ooooo0_l0000Hooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0R_ooool002kooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`1aooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`2:ooooo`00;_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo077ooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo08_ooooo000^oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Roooool002kooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`2<ooooo`00;_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo07;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo08cooooo000_ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0L_oo
ool2o`0001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2=ooooo`00;oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo08gooooo000_ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`0Jooooo`;o00000oooool00ol0
003oooooooooo`2>ooooo`00;oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo07?o
oooo00?o0000ooooooooool06oooool2o`000003ooooool0003o0000093ooooo000_ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`0Looooo`;o0000
T_ooool0033ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1cooooo`03o`000?oo
oooooooo0;3ooooo000`ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Loooool2
o`000;7ooooo000`ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Loooool00ol0
003oooooooooo`2`ooooo`00<?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo07Co
oooo00?o0000ooooooooool0/?ooool0033ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`1dooooo`03o`000?oooooooooo0;3ooooo000aooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0M?ooool00ol0003oooooooooo`2`ooooo`00<Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0/?ooool0037ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo0;3ooooo000aooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0MOooool2o`000;7ooooo000booooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0MOooool00ol0003oooooooooo`2`ooooo`00<_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool0/?oo
ool003;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`00
0?oooooooooo0;3ooooo000booooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0F_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb
<S801_ooool00ol0003oooooooooo`2`ooooo`00<_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo05_ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0/?ooool003?ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`1Kooooo`05o`000?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`05ooooo`?o
0000/?ooool003?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Kooooo`05o`00
0?ooooooooooooooool000003Oooool00ol@413o0000okZj^P06ooooo`03o`000?oooooooooo0;3o
oooo000cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Foooool01Ol@413ooooo
oooooooooooo410@00kooooo00?o^[Zjob4Q8Oooool01Oooool00ol0003oooooooooo`2`ooooo`00
<oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003oooooooooo`2`oooo
o`00=?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05cooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`2`
ooooo`00=?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07Oooooo00?o0000oooo
ooooool0/?ooool003Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1hooooo`;o
0000/Oooool003Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1hooooo`03o`00
0?oooooooooo0;3ooooo000eooooo`05o`000?ooooooooooooooool00000Noooool00ol0003ooooo
ooooo`2`ooooo`00=_ooool01?l0003oooooooooool0001kooooo`03o`000?oooooooooo0;3ooooo
000gooooo`;o0000O?ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o
000000?o410@ooooooooool01?ooool00ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0/?ooool009[ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool3o`000;3o
oooo002Jooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00007oooo
o`03o`000?oooooooooo0;3ooooo002Jooooo`05o`000?ooooooooooooooool000002oooool01?oM
gMgoEEEEooooool00007ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo0;3ooooo002Joooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooo
oooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3o
oooo002Jooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`?o
0000/?ooool009[ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000ooooooooooooooooo`00000<ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`oooo
o`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006oooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000
/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:cooooo00?o
0000okZj^_ooool0^Oooool00:cooooo0_lb<S:jooooo`00OOooool2o`000006oa0@4?oooooooooo
oa0@4?l0003o410@6?ooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000001olb<S;ogMgM
ooooooooooooQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo00Gok^k^
oc8b<_l0003o410@olc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1cooooo`00O_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l0000<ooooo`03o`000?oooooooooo00Ko
oooo00OoMgMgoc8b<_ooooooooooolc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@
4009ooooo`Ko00002Oooool01OmEEEGoMgMgoooooonHV9So8B4Q00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg07?ooooo001nooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oo
ooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@07?ooooo001nooooo`06o`00
0?ooooooA4A4odA4A?oooooo00002Oooool6o`0000cooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0@ooooo`03o`000?oooooooooo00_ooooo1_l00009ooooo`05o`000?nHV9Sooooo
oiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool00000Loooool007kooooo00Ko0000omgMgOlb<S;o
EEEEomgMgOl0000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00A
ooooo`03o`000?oooooooooo01[ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`00001cooooo`00O_ooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001_ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03oa0@4?l0003o000000?o00006Oooool0
0omEEEGoQhN7ooooo`05ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooo
oooooooo410@00?ooooo00Go410@oooooooooooooooooa0@401cooooo`00O_ooool01_l0003o<S8b
oooooooooooo<S8bo`0001_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo01[ooooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Loooool007gooooo00?o410@o`000?n7QhL00_ooool00on7QhOo0000oa0@400Hooooo`03oeEEEOmV
IVKo000000Gooooo1?l0000Booooo`03o`000?oooooooooo01_ooooo00Coc<c<odA4A?l0003o410@
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h0Loooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-75.3131, -0.0481309, \
0.519043, 0.00399917}}]
}, Closed]]
}, Open  ]],

Cell["\<\
The soliton in back, being of larger amplitude, moves with higher \
speed and catches up to the soliton in the front. It then feeds some of its \
amplitude to the soliton in the front, until they exchange amplitudes, and \
the soliton in the front then moves away from the one in the back. \
Effectively, the two solitons have exchanged places: they have passed through \
one another without change. Thanks to the periodic boundary conditions, this \
interaction then repeats itself ad infinitum. \
\>", "Text"],

Cell["\<\
\tThe fact that solitons effectively retain their shape during \
binary interactions implies that a description of nonlinear processes can \
often be greatly simplified - one can think of the nonlinear system as a gas \
of discrete solitons, which act almost like discrete particles, interacting \
with one another but retaining their identity. \
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 3: Suppression of Wavebreaking", "Section",
  CellTags->{"i:45", "c:22"}],

Cell[TextData[{
  "In this example, we investigate whether wavebreaking occurs in the KdV \
equation. Recall that wavebreaking was observed in the solutions to Eq. ",
  ButtonBox["(7.1.30)",
    ButtonData:>{"Chapter7.nb", "(7.1.30)"},
    ButtonStyle->"Hyperlink"],
  " , where dispersion is neglected. Although we cannot hope to observe \
similar double-valued solutions using the Galerkin method, which expands in a \
set of single-valued modes, we might expect to see some initial conditions \
steepen, and the spectrum of waves should display a cascade to high \
wavenumbers. "
}], "Text"],

Cell[TextData[{
  "For our initial condition, we  take a single finite amplitude sine wave. \
We now keep ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(M\)\(=\)\(20\)\(\ \)\)\)]],
  "modes in order to be certain of capturing the high-wavenumber dynamics \
properly, as shown in Cell ",
  ButtonBox["7.50",
    ButtonData:>"Cell 7.50",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(L = \ 40; \ M = 20;\), "\n", 
    \(\(ics\  = \ Table[\(c[n]\)[0]\  \[Equal] \ 0, {n, 0, M}];\)\), "\n", 
    \(\(\(ics[\([2]\)] = \(c[1]\)[0] \[Equal] 1/8;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(kdVmod[800, 10, \(-1\), 1]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.50"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
147.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .23176 m
.00123 .23177 L
.00236 .23177 L
.00365 .23178 L
.00488 .2318 L
.00706 .23184 L
.00942 .2319 L
.01203 .23198 L
.01479 .2321 L
.01975 .23236 L
.02486 .2327 L
.02966 .2331 L
.04057 .23426 L
.0517 .2358 L
.06188 .23753 L
.08481 .24247 L
.1265 .25491 L
.16661 .27036 L
.20928 .28947 L
.25037 .3092 L
.29403 .33012 L
.3361 .3488 L
.37658 .36418 L
.3971 .37068 L
.41963 .37663 L
.44107 .38104 L
.45066 .38259 L
.46109 .38397 L
.46679 .3846 L
.47207 .38508 L
.47701 .38547 L
.48246 .3858 L
.48481 .38592 L
.48734 .38603 L
.48952 .3861 L
.49191 .38617 L
.49446 .38622 L
.49585 .38625 L
.49715 .38626 L
.49836 .38627 L
.49947 .38627 L
.50074 .38627 L
.50195 .38627 L
.50316 .38626 L
.50446 .38624 L
.50569 .38622 L
.50681 .3862 L
.50955 .38613 L
.51216 .38605 L
.51733 .38581 L
Mistroke
.52296 .38547 L
.53302 .38461 L
.54234 .38355 L
.56393 .38012 L
.58348 .37589 L
.6256 .36344 L
.66614 .34787 L
.70924 .32858 L
.75076 .30865 L
.79069 .28948 L
.83319 .27045 L
.8741 .2547 L
.89494 .24799 L
.91758 .24189 L
.93935 .2373 L
.94974 .23558 L
.95947 .23425 L
.96875 .23325 L
.97875 .23245 L
.98416 .23215 L
.98687 .23203 L
.98984 .23192 L
.99239 .23185 L
.99381 .23182 L
.99511 .2318 L
.99632 .23178 L
.99763 .23177 L
.99886 .23176 L
1 .23176 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`005_ooool@o`0006cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0008kooooo3ol0000Cooooo`009_oo
ool6o`0006Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo08Oooooo1ol0000Rooooo`00
;?ooool4o`0006;ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`24ooooo`?o0000:Oooool0033ooooo
1?l0001Nooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`20ooooo`Co0000;?ooool003Co
oooo0ol0001Kooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7o
c<c<00Cooooo1?l00006ooooo`;o0000O_ooool3o`00033ooooo000gooooo`?o0000Noooool00ol0
003oooooooooo`1iooooo`Co0000<oooool003[ooooo0ol0001hooooo`03o`000?oooooooooo07Ko
oooo0ol0000gooooo`00?Oooool3o`0007Gooooo00?o0000ooooooooool0Loooool3o`0003[ooooo
0010ooooo`?o0000L_ooool00ol0003oooooooooo`1`ooooo`?o0000?Oooool004?ooooo0ol0001_
ooooo`;o0000K_ooool3o`00043ooooo0016ooooo`;o0000KOooool00ol0003oooooooooo`1[oooo
o`;o0000@oooool001Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^
kP0Jooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01_o^k^ko<S8bo`000?lb<S;ok^k^oooo
o`?o00005oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Looooo`Co000000So410@
ooooooooooook^k^oc8b<_l0003o<S8bonk^kQkooooo00?o0000ooooooooool07oooool4o`000008
oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hJooooo`Go00000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^01Kooooo0ol00002ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^01gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8b
onk^kP0>ooooo`005_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
6_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04oooo
o`;o00005Oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01[o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05?ooool2
o`0000Gooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
7_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool000_ooooo
1_l00002ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@01;ooooo1_l00006ooooo`05
o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`04ooooo`;o00002oooool6o`00
00?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01?ooooo1_l00005
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Nooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01_ooooo
00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@017ooooo0ol0000;ooooo`05
o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Iooooo`Go00000oooool01Ol@
413ooooooooooooooooo410@00kooooo000Cooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000
ooooooooooooooooo`00000Mooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oooooooooooooooo
o`000008ooooo`;o00004oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool0
00007_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007_ooool2o`00
02;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001cooooo00?oV9RH
ob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000oooooo0_l0000=ooooo`03ojVYZOl@
413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Kooooo`04odA4A?oMgMgoooooo`0000Co
oooo00Go0000ooooooooooooooooo`00000>ooooo`004oooool01?oMgMgoEEEEooooool00004oooo
o`05o`000?ooooooooooooooool000007?ooool00ol@413o0000okZj^P03ooooo`05o`000?oooooo
ooooooooool000002_ooool3o`00017ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooo
oooooooo000001kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001ko
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000007Oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000003Oooool2
o`0000kooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000001_ooooo00Co
gMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000kooooo000Dooooo`03ogMg
Moo<c<co000000Cooooo00Go410@oooooooooooooooooa0@400Mooooo`03okZj^_lQ8B7ooooo00;o
oooo00Go410@oooooooooooooooooa0@400=ooooo`;o00004?ooool01Ol0003ooooooooooooooooo
410@00?ooooo00?o410@ooooooooool07?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41007_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@400Nooooo`05o`000?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`08ooooo`?o00004Oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41007?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41003_ooool0
01Cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00Go410@
oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03oooool2o`0000[ooooo
00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05o`000?nj
^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo0_l0000Aooooo`05
oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01cooooo00?ok^k^
odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000Eooooo`03ogMgMol0003o
oooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Jooooo`05ojVYZOl@413o0000oa0@4?nYZJT0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^017ooooo0_l00008ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01cooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^01kooooo00?o0000ooooooooool07oooool00omEEEGoIVIVo`00
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06_ooool01OnHV9So410@o`000?lQ8B7oc<c<00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`;o00004oooool01OnYZJWo410@o`000?l@413o
ZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Mooooo`03ogMgMol0003ooooo00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0>ooooo`00F_ooool2o`0005Wooooo0_l0001Gooooo`;o0000F?oo
ool005cooooo0_l0001Gooooo`03o`000?oooooooooo05Cooooo0_l0001Jooooo`00G_ooool3o`00
05Cooooo00?o0000ooooooooool0D_ooool2o`0005cooooo001Qooooo`;o0000D_ooool00ol0003o
ooooooooo`1@ooooo`;o0000G_ooool006?ooooo0_l0001@ooooo`03o`000?oooooooooo04kooooo
0_l0001Pooooo`005_ooooooo`00043o00004oooool001Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
1?l0003oooooo`000?l00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooooooo`Co00001oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Aooooo`005_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Gooooo00Co
0000oooooooooooooooo0_l0000Rooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0Oooooo`;o00000oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool04Oooool006_ooooo0_l00018ooooo`03o`000?oo
oooooooo04Gooooo0_l0001Yooooo`00KOooool2o`0004Kooooo00?o0000ooooooooool0@_ooool3
o`0006_ooooo001_ooooo`;o0000A?ooool2o`00047ooooo0_l0001^ooooo`00LOooool2o`0004;o
oooo00?o0000ooooooooool0?_ooool2o`00073ooooo001cooooo`;o0000@?ooool00ol0003ooooo
ooooo`0looooo`;o0000L_ooool007Gooooo0ol0000mooooo`03o`000?oooooooooo03[ooooo0_l0
001dooooo`00N?ooool2o`0003_ooooo00?o0000ooooooooool0>?ooool2o`0007Kooooo001joooo
o`;o0000>Oooool2o`0003Sooooo00?o0000ooooooooool0M_ooool007cooooo0ol0000fooooo`03
o`000?oooooooooo03Gooooo0_l0001iooooo`00Ooooool2o`0003Cooooo00?o0000ooooooooool0
<oooool2o`0007_ooooo0021ooooo`;o0000<_ooool00ol0003oooooooooo`0`ooooo`?o0000OOoo
ool008?ooooo0ol0000_ooooo`03o`000?oooooooooo02gooooo0ol00020ooooo`00Q_ooool3o`00
02cooooo0_l0000[ooooo`?o0000Poooool008Wooooo0_l0000Zooooo`03o`000?oooooooooo02Oo
oooo0ol00026ooooo`00Roooool3o`0002Oooooo00?o0000ooooooooool08oooool4o`0008Wooooo
002>ooooo`?o00009?ooool00ol0003oooooooooo`0Pooooo`?o0000SOooool0097ooooo0ol0000Q
ooooo`03o`000?oooooooooo01cooooo1?l0002@ooooo`00U?ooool3o`0001kooooo0_l0000Joooo
o`?o0000U?ooool009Oooooo0ol0000Kooooo`03o`000?oooooooooo01Kooooo0ol0002Gooooo`00
T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo1_l00002ooooo`Go00001?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool04oooool3o`0009[ooooo002Booooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@;ooooo1Ol000000oooooooA4A4ooooo`06oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool03_ooool5o`0009gooooo002Booooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qo`00000:o`0000Gooooo00?o0000oooo
ooooool00oooool;o`000:;ooooo002Booooo`05o`000?ooooooooooooooool000003Oooool00onH
V9So8B4Qonk^kP07ooooo`03ogMgMol0003o000000[o0000[Oooool009;ooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005
ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool0
09;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009[ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`03ooooo`?o0000/?ooool009[ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000ooooooooooooooooo`00
000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`ooooo`00V_oo
ool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l00006ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^oooo
o`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00T_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooo
oooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo0;3ooooo002Booooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooo
ooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00T_ooool01Ol0003ooooooooo
oooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool0/?ooool009;ooooo00Go410@oooooooooooooooooa0@400>ooooo`03
ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00
T_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Zooo
ool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool00:gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo0ol0002`ooooo`00
[Oooool00ol0003oooooooooo`2hooooo`00[Oooool00ol0003oooooooooo`2hooooo`00[Oooool0
0ol0003oooooooooo`2hooooo`00Zoooool00omEEEGoIVIVo`00002jooooo`00oooooomYooooo`00
]oooool00ol0003o^[Zjooooo`2^ooooo`00]oooool2oc8b<Zoooooo0028ooooo`;o000000Ko410@
oooooooooooo410@o`000?l@410Gooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP20ooooo`00ROooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Oooooo1_l00009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo
1_l00009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0P?ooool008Wooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooo
oooooa0@400Booooo`03o`000?oooooooooo01[ooooo00Go410@oooooooooooooooooa0@4020oooo
o`00ROooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000;ooooo`03oiRHV?lQ8B7o
k^k^00?ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo00_ooooo1_l0
0009ooooo`05o`000?ooooooooooooooool00000P?ooool008Wooooo00Ko0000omgMgOlb<S;oEEEE
omgMgOl0000Kooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00000Boooo
o`03o`000?oooooooooo01[ooooo00Go0000ooooooooooooooooo`000020ooooo`00ROooool01_l0
003oQhN7ojVYZOnj^[[oEEEEo`0001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@
4?oooooooooo00kooooo00?o410@o`000?l000000ol0000Iooooo`05oa0@4?ooooooooooooooool@
4100P?ooool008Wooooo00Ko0000oc8b<_oooooooooooc8b<_l0000Hooooo`05o`000?nj^[[ooooo
oiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool06_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg083ooooo0028ooooo`03oa0@4?l0003oQhN700;ooooo00?o
QhN7o`000?l@41005oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0Booooo`03o`000?oooooooooo01[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP20oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .23335 m
.00942 .23432 L
.01975 .23565 L
.04057 .23909 L
.08481 .24941 L
.12734 .2624 L
.16829 .27695 L
.2118 .29384 L
.25373 .31077 L
.29406 .327 L
.33697 .34351 L
.37829 .35796 L
.41802 .36983 L
.44011 .37532 L
.46032 .3795 L
.4703 .38124 L
.48119 .38287 L
.49141 .38414 L
.50103 .38509 L
.50624 .3855 L
.51187 .38585 L
.51435 .38598 L
.51698 .3861 L
.51944 .38619 L
.52169 .38626 L
.52431 .38632 L
.52575 .38635 L
.52712 .38636 L
.52838 .38637 L
.52955 .38638 L
.53083 .38638 L
.53219 .38638 L
.53355 .38637 L
.53431 .38636 L
.53501 .38635 L
.53766 .38631 L
.53907 .38627 L
.54061 .38623 L
.54371 .38612 L
.54926 .38584 L
.5545 .38548 L
.5643 .38458 L
.57486 .38323 L
.5863 .38133 L
.60717 .37666 L
.62926 .37 L
.66905 .3537 L
.7114 .33131 L
.75217 .30706 L
.79551 .28168 L
Mistroke
.83726 .26067 L
.87741 .24549 L
.89811 .23987 L
.92015 .23556 L
.93097 .23406 L
.93667 .23343 L
.94267 .23289 L
.94794 .23251 L
.95073 .23234 L
.95371 .23219 L
.95646 .23208 L
.95897 .232 L
.96017 .23197 L
.96148 .23194 L
.96272 .23192 L
.96386 .2319 L
.96487 .23189 L
.96594 .23188 L
.967 .23187 L
.96817 .23187 L
.96918 .23187 L
.97026 .23188 L
.97128 .23189 L
.9722 .2319 L
.97339 .23191 L
.97447 .23193 L
.97693 .23199 L
.9791 .23205 L
.9814 .23213 L
.98598 .23234 L
.99026 .23259 L
1 .23335 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`005_ooool6o`0007Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0008Gooooo6?l0000Cooooo`007?oo
ool5o`00077ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo083ooooo1Ol0000[ooooo`00
8Oooool5o`0006cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1jooooo`Ko0000<?ooool002Kooooo
1Ol0001Wooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1gooooo`?o0000=_ooool002_o
oooo1Ol0001Rooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7o
c<c<00Cooooo1?l00006ooooo`;o0000MOooool3o`0003Wooooo000`ooooo`Co0000POooool00ol0
003oooooooooo`1aooooo`?o0000??ooool003Cooooo0ol0001nooooo`03o`000?oooooooooo06ko
oooo0ol0000oooooo`00=oooool3o`0007_ooooo00?o0000ooooooooool0K?ooool2o`0004;ooooo
000jooooo`?o0000N?ooool00ol0003oooooooooo`1Yooooo`?o0000A?ooool003gooooo0ol0001e
ooooo`;o0000J?ooool2o`0004Oooooo0010ooooo`?o0000L_ooool00ol0003oooooooooo`1Uoooo
o`;o0000BOooool001Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^
kP0Jooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko0000o`000?l0003ok^k^01_o
oooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hNooooo`03o`000?oooooooooo01oooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^6_ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0Aooooo`;o00002?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0Mooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h03_oo
ool001Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00Go
410@okZj^_ooooooMgMgoc8b<P03ooooo`04ogMgMonHV9SooooooiRHV0;o00006_ooool01OnHV9So
8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool3o`0000[ooooo00Go410@okZj
^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool000_ooooo1_l00002ooooo`Go00000ooo
ool01Ol@413ooooooooooooooooo410@01;ooooo1_l00006ooooo`05o`000?ooooooooooooooool@
41000oooool00ol@413oooooo`000002o`0000oooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Co
oooo00Go410@oooooooooooooooooa0@400Cooooo`Ko00001Oooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41007_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@400Kooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go
410@oooooooooooooooooa0@400<ooooo`;o00004Oooool01Ol0003ooooooooooooooooo410@00?o
oooo00?o410@ooooooooool06Oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400>oooo
o`004oooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000007Oooool0
0onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool2o`0001Oooooo00?o
V9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000001kooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000001kooooo0_l0000Rooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`00000Looooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`00000:ooooo`;o00004_ooool00onYZJWo410@ooooo`02ooooo`05o`000?oooooo
ooooooooool000006oooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool0
00003_ooool001?ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo0000
01cooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0000E
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00000Nooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000Nooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001gooooo00?oMgMgofIVI_oo
ool00_ooool01Ol0003ooooooooooooooooo000000Sooooo0_l0000Cooooo`03oa0@4?l0003o^[Zj
00?ooooo00Go0000ooooooooooooooooo`00000Kooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go
0000ooooooooooooooooo`00000>ooooo`005?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oo
ooooooooooooool@41007Oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@
41002Oooool3o`0001?ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo
01cooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01kooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41007_oo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01Oooool00ol0003ooooo
ooooo`0Dooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@400Looooo`03
ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@400>ooooo`005?ooool00oo^k^ko
A4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01Ol@413oV9RHoooooonj^[[o
000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`?o00003?ooool01Ol0003o^[Zjoooo
oonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0001Cooooo00Go410@oiRHV?oooooo
^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07?ooool00oo^k^koA4A4o`000004oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool001Gooooo00?oMgMgo`000?ooool00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^01[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03oooool3o`0000Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h07?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h07_ooool00ol0003oooooooooo`0Oooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Cooooo00?o0000ooooooooool05?ooool01OnYZJWo410@o`000?l@413oZJVY
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Mooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0>ooooo`00FOooool2o`0005[ooooo0_l0001Eooooo`;o0000F_ooool0
05_ooooo0_l0001Hooooo`03o`000?oooooooooo05;ooooo0_l0001Looooo`00GOooool2o`0005Ko
oooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`1Looooo`00Goooool3o`0005?ooooo
00?o0000ooooooooool0Coooool2o`0005oooooo001Rooooo`;o0000DOooool00ol0003ooooooooo
o`1>ooooo`03o`000?oooooooooo05oooooo000Foooooooo0000@?l0000Cooooo`005_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`?o00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`?o00001oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Aooooo`005_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool00ol0000Rooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0Pooooo`;o00000_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool04Oooool006_ooooo0ol00017ooooo`03o`00
0?oooooooooo04Kooooo0_l0001Xooooo`00K_ooool2o`0004Gooooo00?o0000ooooooooool0AOoo
ool00ol0003oooooooooo`1Xooooo`00L?ooool3o`0004;ooooo0_l00014ooooo`;o0000Joooool0
07?ooooo0_l00010ooooo`03o`000?oooooooooo047ooooo0_l0001]ooooo`00MOooool3o`0003go
oooo00?o0000ooooooooool0?oooool2o`0006oooooo001hooooo`?o0000>_ooool00ol0003ooooo
ooooo`0mooooo`;o0000LOooool007_ooooo0ol0000gooooo`03o`000?oooooooooo03_ooooo0_l0
001cooooo`00O_ooool3o`0003Cooooo0_l0000jooooo`;o0000MOooool0087ooooo0_l0000boooo
o`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0MOooool008?ooooo0ol0000_ooooo`03
o`000?oooooooooo03Kooooo0_l0001hooooo`00Q_ooool3o`0002cooooo00?o0000ooooooooool0
=?ooool2o`0007[ooooo0029ooooo`;o0000:_ooool00ol0003oooooooooo`0booooo`;o0000O?oo
ool008_ooooo0ol0000Wooooo`;o0000<Oooool2o`0007kooooo002>ooooo`?o00009?ooool00ol0
003oooooooooo`0^ooooo`;o0000P?ooool0097ooooo1Ol0000Oooooo`03o`000?oooooooooo02_o
oooo0ol00022ooooo`00U_ooool4o`0001_ooooo00?o0000ooooooooool0:Oooool2o`0008Gooooo
002Jooooo`Co00005oooool00ol0003oooooooooo`0Wooooo`;o0000Qoooool009kooooo0ol0000D
ooooo`;o00009Oooool3o`0008Wooooo002Qooooo`Co00004?ooool00ol0003oooooooooo`0Qoooo
o`?o0000S?ooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool6o`00
00?ooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01cooooo1Ol0002?
ooooo`00T_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`06oiRHV?lQ8B7o
k^k^oooooom4A4Cooooo1_l000000omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01Oooooo
1Ol0002Dooooo`00T_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0
2?ooool;o`0000gooooo2Ol0002Iooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo
00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o000000?oooooo`000?l00000
2ol0002Rooooo`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool0
0oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool009;ooooo
00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0/?ooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aoooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooo
oooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0002`ooooo`00V_ooool01Ol0003o
oooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`oooo
o`00V_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Joooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002a
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009;ooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3
o`000;3ooooo002Booooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`ooooo`00T_ooool0
1Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co0000
1_ooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`Co000000?o410@ooooooooool00oooool00ol0
003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;3o
oooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool00:gooooo00?o
0000ooooooooool01Oooool3o`000;3ooooo002]ooooo`03o`000?oooooooooo0;Sooooo002]oooo
o`03o`000?oooooooooo0;Sooooo002]ooooo`03o`000?oooooooooo0;Sooooo002[ooooo`03oeEE
EOmVIVKo00000;[ooooo003oooooofWooooo002cooooo`03o`000?nj^[[ooooo0;;ooooo002coooo
o`;o<S8b/oooool008Cooooo0_l000001_l@413oooooooooool@413o0000oa0@41Oooooo1Ol00003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0
003o0000odA4A?nj^[X06Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^il
ooooo`00QOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l00009oooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?o
c<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<ooooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1looooo`00QOooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo01Oooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooo
oooooooooooo410@01;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@4100O?ooool008Gooooo00Ko0000oooooom4A4CoA4A4ooooool00009
ooooo`Ko00002oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000004_oo
ool00ol0003oooooooooo`0;ooooo`Ko00003?ooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool00000O?ooool008Gooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Kooooo`03
ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000007cooooo0025oooo
o`06o`000?n7QhOoZJVYokZj^_mEEEGo00007?ooool01Ol0003ooooooooooooooooo410@00?ooooo
00?o410@ooooooooool03_ooool00ol@413o0000o`000003o`0001cooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@07cooooo0025ooooo`06o`000?lb<S;ooooooooooolb
<S;o00006?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Booooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg07cooooo0024ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41005ooo
ool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Booooo`03
o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
07cooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .23732 m
.04057 .24492 L
.08481 .25585 L
.12636 .26793 L
.16632 .2807 L
.20885 .29507 L
.2498 .30928 L
.29331 .32438 L
.33524 .33854 L
.37557 .35141 L
.41848 .36383 L
.4598 .37401 L
.49953 .3815 L
.51991 .38422 L
.53136 .38535 L
.53643 .38575 L
.54183 .38611 L
.54725 .38639 L
.55217 .38657 L
.55454 .38663 L
.55579 .38666 L
.55711 .38669 L
.55827 .3867 L
.55953 .38672 L
.56069 .38672 L
.56177 .38673 L
.56312 .38673 L
.56388 .38672 L
.56459 .38672 L
.56588 .38671 L
.56726 .38669 L
.56849 .38667 L
.56964 .38664 L
.57227 .38657 L
.57509 .38647 L
.57769 .38635 L
.58353 .38599 L
.5885 .3856 L
.59382 .38507 L
.6034 .38383 L
.61478 .38185 L
.62513 .37953 L
.64527 .37342 L
.66711 .36413 L
.68798 .35248 L
.71008 .33746 L
.74986 .30653 L
.79221 .2754 L
.81172 .26358 L
.83298 .25297 L
Mistroke
.85521 .24444 L
.86629 .24113 L
.87632 .23862 L
.88627 .23659 L
.89702 .23486 L
.90293 .2341 L
.90837 .23353 L
.91353 .23308 L
.91905 .23271 L
.92181 .23256 L
.92442 .23244 L
.92696 .23235 L
.9293 .23229 L
.93152 .23224 L
.93265 .23222 L
.93388 .23221 L
.93512 .2322 L
.93645 .23219 L
.93771 .23219 L
.93886 .23219 L
.94013 .2322 L
.94148 .23222 L
.94276 .23224 L
.94392 .23226 L
.94676 .23232 L
.94944 .23241 L
.95479 .23264 L
.96057 .23297 L
.9697 .23366 L
.97974 .23466 L
1 .23732 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000O?oooolNo`0001Kooooo000Fooooo`?o0000NOoo
ool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0Moooool5o`0001kooooo0ol0000Cooooo`00
6Oooool5o`0007Cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1cooooo`Co0000>Oooool001kooooo
1?l0001`ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1`ooooo`?o0000?Oooool002;o
oooo1?l0001/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7o
c<c<00Cooooo1?l00006ooooo`;o0000KOooool4o`00043ooooo000Vooooo`Go0000R_ooool00ol0
003oooooooooo`1Yooooo`?o0000A?ooool002_ooooo1Ol00025ooooo`03o`000?oooooooooo06Ko
oooo0ol00017ooooo`00<?ooool4o`00087ooooo00?o0000ooooooooool0I?ooool2o`0004[ooooo
000dooooo`?o0000O_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo04[ooooo000g
ooooo`?o0000Noooool2o`0006;ooooo0_l0001=ooooo`00>_ooool3o`0007Sooooo00?o0000oooo
ooooool0Goooool2o`0004oooooo000Eooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o
0000oc8b<_o^k^h06_ooool00onHV9So410@o`000004o`000006ooooooo^k^ko<S8bo`000?lb<S;o
k^k^6oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Looooo`Co000000So410@oooo
ooooooook^k^oc8b<_l0003o<S8bonk^kQkooooo00?o0000ooooooooool07oooool4o`000008oa0@
4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hJooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo0_l0000>ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^
kP0>ooooo`005_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_oo
ool01Ol@413o^[ZjoooooomgMgOo<S8b00;ooooo0ol000000oooooooV9RHogMgM`0Kooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01OnHV9So8B4Qonk^
k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`09ooooo`;o00004?ooool01Ol@413o
^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`002oooool6o`0000;ooooo1Ol00003
ooooo`05oa0@4?ooooooooooooooool@41004_ooool6o`0000Kooooo00Ko0000oooooooooooooooo
oa0@4?ooool3o`0001?ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooo
oooooooooa0@400Cooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41007_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Kooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooo
oa0@4007ooooo`;o00005_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@oooooooo
ool06Oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`004oooool01?m4A4Co
gMgMooooool00004ooooo`05o`000?ooooooooooooooool000007Oooool00onYZJWo410@ooooo`02
ooooo`04o`000?ooooooooooooooo`Co00006_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oo
ooooooooooooool000007_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00007_ooool2o`0002;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
01cooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool05Oooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000006ooo
ool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool001?ooooo
00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000001cooooo00?o410@o`00
0?nj^[X00oooool01Ol0003ooooooooooooooooo000000?ooooo0ol0000Hooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`00000Nooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`00000Nooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000001gooooo00?oMgMgofIVI_ooool00_ooool01Ol0003o
oooooooooooooooo000000Cooooo0_l0000Gooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000oooo
ooooooooooooo`00000Kooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000oooooooooooooooo
o`00000>ooooo`005?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@4100
7Oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool3o`0001Ko
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@01kooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41007_ooool01Ol0003ooooooooo
oooooooo410@00?ooooo00Go410@ooooooooooooooooo`00000Jooooo`03okZj^_lQ8B7ooooo00;o
oooo00Go410@oooooooooooooooooa0@400Looooo`03ogMgMoo<c<co000000Cooooo00Go410@oooo
oooooooooooooa0@400>ooooo`005?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL06_ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`09ooooo`?o00003oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0N
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg01[ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00_ooool00ol0003oooooooooo`0Fooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00kooooo000Eooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0Jooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo0_l0000=ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01kooooo00?o
0000ooooooooool07oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
6_ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02o`00
01Wooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Ooo
ool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool005Gooooo0ol0
001Mooooo`;o0000D_ooool00ol0003oooooooooo`1Looooo`00F?ooool3o`0005[ooooo00?o0000
ooooooooool0Coooool2o`0005oooooo001Kooooo`?o0000Eoooool00ol0003oooooooooo`1>oooo
o`03o`000?oooooooooo05oooooo001Nooooo`?o0000E?ooool00ol0003oooooooooo`1=ooooo`03
o`000?oooooooooo063ooooo001Qooooo`?o0000DOooool00ol0003oooooooooo`1;ooooo`;o0000
Hoooool001Koooooool00010o`0001?ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooool000000_l00003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo017ooooo000Fooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`02ooooo`?o00008?ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool08?ooool01Ol0003ooooooooooooo
oooo000002Oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Aooooo`00KOooool3
o`0004Gooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1Vooooo`00L?ooool3o`00
04;ooooo00?o0000ooooooooool0AOooool2o`0006Wooooo001cooooo`;o0000@?ooool2o`0004Go
oooo00?o0000ooooooooool0JOooool007Gooooo0ol0000mooooo`03o`000?oooooooooo04?ooooo
00?o0000ooooooooool0J_ooool007Sooooo0ol0000jooooo`03o`000?oooooooooo04;ooooo00?o
0000ooooooooool0Joooool007_ooooo0_l0000hooooo`03o`000?oooooooooo047ooooo00?o0000
ooooooooool0K?ooool007gooooo0ol0000eooooo`03o`000?oooooooooo03oooooo0_l0001_oooo
o`00P?ooool3o`0003;ooooo0_l0000oooooo`03o`000?oooooooooo06oooooo0023ooooo`?o0000
;oooool00ol0003oooooooooo`0looooo`;o0000L_ooool008Kooooo0ol0000/ooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0L_ooool008Wooooo0ol0000Yooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool0Loooool008cooooo1?l0000Uooooo`03o`000?oooooooooo
03Sooooo0_l0001fooooo`00T?ooool3o`0002;ooooo0_l0000gooooo`;o0000N?ooool009?ooooo
1?l0000Nooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0N?ooool009Oooooo0ol0
000Kooooo`03o`000?oooooooooo03?ooooo0_l0001kooooo`00V_ooool4o`0001Oooooo00?o0000
ooooooooool0<Oooool2o`0007gooooo002Nooooo`Go00004_ooool00ol0003oooooooooo`0^oooo
o`?o0000Ooooool00:?ooooo1?l0000>ooooo`;o0000;Oooool2o`0008;ooooo002Wooooo`Go0000
2Oooool00ol0003oooooooooo`0Zooooo`;o0000Q?ooool009;ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00?oA4A4o`000?l000001Ol00002ooooo`03o`00
0?oooooooooo02Oooooo0ol00026ooooo`00T_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`02ooooo`Ko
00007oooool7o`0008Wooooo002Booooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo1ol0000Boooo
o`Ko0000T?ooool009;ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^
00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0000Sooooo4_l0002Fooooo`00T_ooool01Ol0003o
oooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00Go410@oooooooooooooooooa0@400?
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`
ooooo`00T_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@
4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo
00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00V_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oo
oooooooo00?ooooo0ol0002`ooooo`00V_ooool01Ol0003ooooooooooooooooo000000oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol0003ooooooooooooo
oooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo
002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool4o`0000Kooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^
k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo
002Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool0
1oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?oo
ooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0/?ooool009;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q
8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`000;3ooooo002Booooo`05o`000?oo
ooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00ko
oooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3o
oooo002Booooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`2`oooo
o`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002[ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`2`ooooo`00[Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0/?ooool00:gooooo00?o0000ooooooooool01Oooool3o`000;3o
oooo002]ooooo`03o`000?oooooooooo0;Sooooo002]ooooo`03o`000?oooooooooo0;Sooooo002]
ooooo`03o`000?oooooooooo0;Sooooo002[ooooo`03oeEEEOmVIVKo00000;[ooooo003oooooofWo
oooo002cooooo`03o`000?nj^[[ooooo0;;ooooo002cooooo`;o<S8b/oooool008Cooooo0_l00000
1_l@413oooooooooool@413o0000oa0@41Oooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool5o`00
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1looooo`00QOooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Oooooo1_l00009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^
k_mgMgOo410@00Wooooo1_l00009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg07cooooo0025ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool05oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41004_ooool00ol0
003oooooooooo`0Kooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@401l
ooooo`00QOooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000;ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo00_ooooo
1_l0000;ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00001looooo`00
QOooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001_ooooo00?oMgMgofIVI_ooool00_ooool01Ol0
003ooooooooooooooooo000001;ooooo00?o0000ooooooooool07Oooool00omgMgOoIVIVooooo`02
ooooo`05o`000?ooooooooooooooool00000O?ooool008Gooooo00Ko0000ohN7QonYZJWo^[ZjoeEE
EOl0000Looooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0>ooooo`03
oa0@4?l0003o000000?o00007Oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@oooo
ooooool0N_ooool008Gooooo00Ko0000oc8b<_oooooooooooc8b<_l0000Hooooo`05o`000?nj^[[o
oooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool0
6_ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1loooo
o`00Q?ooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Oooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0J
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07cooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .2423 m
.04057 .25063 L
.08481 .2614 L
.12636 .27263 L
.16632 .28413 L
.20885 .29685 L
.2498 .30932 L
.29331 .32257 L
.33524 .33512 L
.37557 .34675 L
.41848 .35839 L
.4598 .36849 L
.49953 .37683 L
.52162 .38073 L
.54183 .38361 L
.55181 .38473 L
.5627 .38568 L
.56768 .38603 L
.57299 .38634 L
.57763 .38656 L
.58254 .38675 L
.58522 .38683 L
.58817 .38691 L
.59087 .38697 L
.59334 .38701 L
.59474 .38703 L
.59626 .38705 L
.59709 .38706 L
.59786 .38706 L
.59865 .38707 L
.59938 .38707 L
.60068 .38708 L
.60137 .38708 L
.60212 .38708 L
.60286 .38708 L
.60363 .38708 L
.6043 .38707 L
.60502 .38707 L
.60571 .38707 L
.60645 .38706 L
.6078 .38705 L
.60912 .38703 L
.61033 .38702 L
.61308 .38696 L
.616 .38689 L
.61851 .38681 L
.62086 .38671 L
.62363 .38657 L
.6262 .38642 L
.63143 .38602 L
Mistroke
.63713 .3854 L
.64216 .38467 L
.6475 .38367 L
.65277 .3824 L
.65772 .38093 L
.66697 .37732 L
.67725 .37187 L
.68809 .36437 L
.7075 .34693 L
.74743 .3038 L
.76967 .28207 L
.78993 .26601 L
.81095 .25333 L
.83084 .24469 L
.841 .24136 L
.85178 .23853 L
.86099 .23663 L
.87114 .23502 L
.87632 .23438 L
.88176 .23383 L
.88647 .23344 L
.89149 .23313 L
.89434 .23299 L
.89692 .23289 L
.89952 .23281 L
.90196 .23276 L
.90335 .23273 L
.90411 .23272 L
.90482 .23272 L
.90608 .23271 L
.90746 .2327 L
.90823 .2327 L
.90896 .2327 L
.91033 .23271 L
.91109 .23272 L
.9118 .23273 L
.9134 .23275 L
.91594 .2328 L
.91826 .23286 L
.9235 .23305 L
.92811 .23328 L
.93298 .23357 L
.9433 .23438 L
.9546 .23552 L
.97517 .2382 L
.99716 .24179 L
1 .2423 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000M?oooolIo`0002?ooooo002Booooo`05o`000?oo
ooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`1_ooooo`Go00006Oooool5o`0001kooooo002Booooo`05oa0@
4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0Joooool4o`0002?ooooo1ol0000Gooooo`005_ooool3o`0007Wooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo06Sooooo0ol0000^ooooo`Co00004oooool001Wo
oooo1Ol0001dooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7o
c<c<00Cooooo1?l00006ooooo`;o0000I_ooool3o`0004Sooooo000Nooooo`Co0000Toooool00ol0
003oooooooooo`1Rooooo`?o0000Boooool002;ooooo1?l0002?ooooo`03o`000?oooooooooo05oo
oooo0ol0001>ooooo`009_ooool5o`0008[ooooo00?o0000ooooooooool0GOooool2o`00057ooooo
000[ooooo`Go0000QOooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo057ooooo000`
ooooo`Co0000POooool2o`0005_ooooo0_l0001Dooooo`00=?ooool3o`0007kooooo00?o0000oooo
ooooool0FOooool00ol0003oooooooooo`1Dooooo`005Oooool2o`000009oa0@4?oooooooooooooo
ooo^k^ko<S8bo`000?lb<S;ok^k^01Oooooo0ol000001OnHV9So410@o`000?lb<S;oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01cooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^7_ooool00ol0003ooooo
ooooo`0Oooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQ[ooooo1Ol00003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`0Booooo`05oiRHV?l@
413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo0_l000002Ol@413o
ooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0>ooooo`005_ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool3o`000003ogMgMolb<S;ooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0Kooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg01kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL06_ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`03o`000?oooooooooo01?ooooo00Go410@okZj^_ooooooMgMgoc8b<P03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03_ooool000_ooooo1_l00002ooooo`Go00000oooool01Ol@413ooooooooooooo
oooo410@01;ooooo1_l00005ooooo`Co000000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@4100
4oooool6o`0000Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01ko
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41006oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41001?ooool0
0ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool@41000oooool00ol@413ooooooooo
o`0Iooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00kooooo000Cooooo`04odA4A?oM
gMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000Mooooo`04ojVYZOl@413ooooooooo
o`Ko00007Oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000007_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007_ooool2o`0002;ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001cooooo00?oV9RHob4Q8Oo^k^h0
0oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool06?ooool00onYZJWo
410@ooooo`02ooooo`05o`000?ooooooooooooooool000006oooool01?m4A4CogMgMooooool00004
ooooo`05o`000?ooooooooooooooool000003_ooool001?ooooo00CogMgMoeEEEOoooooo00001?oo
ool01Ol0003ooooooooooooooooo000001cooooo00?o410@o`000?nj^[X00oooool01?l0003ooooo
ooooooooool4o`0001_ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo0000
01kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001kooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007Ooo
ool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooo
ooooo`0Hooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00000Kooooo`04
omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`005?ooool00omg
MgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41007Oooool00onj^[[o8B4Qooooo`02
ooooo`05oa0@4?ooooooooooooooool@41000oooool4o`0001Sooooo00Go0000oooooooooooooooo
oa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@01kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41007_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@
o`000?l000007?ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41007?oo
ool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41003_ooool001Cooooo00?o
k^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00Go410@oiRHV?oooooo
^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01oooool3o`00017ooooo00Go0000okZj
^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05o`000?nj^[[ooooooiRH
V?l@41000oooool01OmgMgOoV9RHoooooonHV9So000001_ooooo00Go410@oiRHV?oooooo^[Zjo`00
0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07?ooool00oo^k^koA4A4o`000004ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03_ooool001Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02_ooool3o`0000kooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h07?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h07_ooool00ol0003oooooooooo`0Oooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?l0
003ok^k^01_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h07Oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool005Co
oooo0ol0001Nooooo`;o0000D?ooool00ol0003oooooooooo`1Nooooo`00Eoooool4o`0005[ooooo
00?o0000ooooooooool0C_ooool00ol0003oooooooooo`1Oooooo`00Foooool3o`0005Oooooo00?o
0000ooooooooool0COooool00ol0003oooooooooo`1Pooooo`00G_ooool3o`0005Cooooo00?o0000
ooooooooool0C?ooool00ol0003oooooooooo`1Qooooo`00HOooool3o`00057ooooo00?o0000oooo
ooooool0C?ooool00ol0003oooooooooo`1Qooooo`005_ooooooo`00043o00004oooool001Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`03o`0000;ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo000Fooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`03ooooo`Co00007_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool08Ooo
ool01?l0003oooooooooool0000Wooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
4Oooool006oooooo0ol00013ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0IOoo
ool007;ooooo1?l0000oooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0I_ooool0
07Kooooo0ol0000looooo`;o0000Aoooool00ol0003oooooooooo`1Wooooo`00NOooool3o`0003Wo
oooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`1Xooooo`00O?ooool3o`0003Kooooo
00?o0000ooooooooool0A?ooool00ol0003oooooooooo`1Yooooo`00Ooooool4o`0003;ooooo00?o
0000ooooooooool0@oooool00ol0003oooooooooo`1Zooooo`00Poooool3o`0002oooooo00?o0000
ooooooooool0@_ooool00ol0003oooooooooo`1[ooooo`00Q_ooool3o`0002cooooo0_l00012oooo
o`03o`000?oooooooooo06cooooo0029ooooo`?o0000:Oooool00ol0003oooooooooo`10ooooo`03
o`000?oooooooooo06gooooo002<ooooo`Co00009Oooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo06kooooo002@ooooo`?o00008_ooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo06oooooo002Cooooo`Co00007_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo073ooooo002Gooooo`?o00006oooool2o`0003gooooo00?o0000ooooooooool0LOooool009[o
oooo1?l0000Gooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0L_ooool009kooooo
1Ol0000Booooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0Loooool00:?ooooo1?l0
000>ooooo`03o`000?oooooooooo03Sooooo0_l0001fooooo`00Yoooool4o`0000[ooooo00?o0000
ooooooooool0=_ooool2o`0007Sooooo002[ooooo`Go00001Oooool2o`0003Gooooo0_l0001joooo
o`00/?ooool4o`000003ooooool0003ooooo03Cooooo00?o0000ooooooooool0N_ooool009;ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@04ooooo`Ko0000;oooool2o`0007gooooo002Booooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool00_ooool6o`0002Gooooo1?l0001oooooo`00T_ooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Sooooo2?l0000Hooooo`Go0000Poooool009;ooooo00Go0000oooo
ooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3
o`00013ooooo6?l00028ooooo`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMg
ofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?oo
ool009;ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0/?ooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00V_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009[ooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0002`ooooo`00V_oo
ool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00V_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@
41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3o
oooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0002aooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009;ooooo
00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_oo
ool01?ooool3o`000;3ooooo002Booooo`05o`000?ooooooooooooooool000003_ooool00omEEEGo
c<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`oooo
o`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004
ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aoooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002[ooooo`Co000000?o410@ooooooooool0
0oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool0
0:gooooo00?o0000ooooooooool01Oooool3o`000;3ooooo002]ooooo`03o`000?oooooooooo0;So
oooo002]ooooo`03o`000?oooooooooo0;Sooooo002]ooooo`03o`000?oooooooooo0;Sooooo002[
ooooo`03oeEEEOmVIVKo00000;[ooooo003oooooofWooooo002cooooo`03o`000?nj^[[ooooo0;;o
oooo002cooooo`;o<S8b/oooool008Cooooo0_l000001_l@413oooooooooool@413o0000oa0@41Oo
oooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOo0000okZj^P0<oooo
o`05oiRHV?l0003o0000odA4A?nj^[X06?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP1looooo`00QOooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Oooooo1_l00009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@
00Wooooo1_l00009ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonH
V9SoMgMg07cooooo0025ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41004_ooool00ol0003ooooooooo
o`0Nooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`1jooooo`00QOoo
ool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000;ooooo`03oiRHV?lQ8B7ok^k^00?o
oooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo00_ooooo1_l0000<oooo
o`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00001looooo`00QOooool01_l0
003ogMgMoc8b<_mEEEGogMgMo`0001_ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooo
oooooooo000001;ooooo00?o0000ooooooooool07?ooool00ol@413o0000okZj^P03ooooo`05o`00
0?ooooooooooooooool00000O?ooool008Gooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Loooo
o`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0>ooooo`03oa0@4?l0003o
000000?o00007?ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@4100O?oo
ool008Gooooo00Ko0000oc8b<_oooooooooooc8b<_l0000Hooooo`05o`000?nj^[[ooooooiRHV?l@
41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool06_ooool01Ol@
413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1looooo`00Q?ooool0
0ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Oooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Jooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07cooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .24738 m
.04057 .2558 L
.08481 .26607 L
.12636 .27643 L
.16632 .28684 L
.20885 .29822 L
.2498 .30933 L
.29331 .32115 L
.33524 .33236 L
.37557 .34294 L
.41848 .35377 L
.4598 .36308 L
.49953 .37209 L
.52162 .377 L
.5321 .3789 L
.54183 .38025 L
.54666 .38075 L
.55181 .38116 L
.55475 .38135 L
.55752 .38149 L
.56004 .38159 L
.5627 .38168 L
.56767 .3818 L
.57223 .38189 L
.575 .38195 L
.57762 .38201 L
.58018 .38208 L
.58254 .38217 L
.58731 .38241 L
.58982 .38259 L
.59249 .38282 L
.59756 .3834 L
.60316 .38428 L
.60794 .38526 L
.61309 .38653 L
.62241 .38934 L
.63331 .39303 L
.63863 .39473 L
.64345 .39606 L
.64591 .39661 L
.64857 .3971 L
.65003 .39731 L
.65138 .39746 L
.65267 .39757 L
.65404 .39764 L
.65541 .39767 L
.65618 .39766 L
.65688 .39764 L
.65825 .39756 L
.65955 .39743 L
Mistroke
.66028 .39734 L
.66105 .39722 L
.66245 .39696 L
.66561 .39614 L
.66835 .39516 L
.67125 .39383 L
.67644 .39069 L
.68202 .38623 L
.68813 .38012 L
.70932 .35138 L
.73157 .31681 L
.75183 .28915 L
.7619 .27782 L
.77285 .26743 L
.79273 .2532 L
.80263 .24801 L
.81354 .24349 L
.82493 .2399 L
.83561 .2374 L
.84596 .23566 L
.85116 .235 L
.85684 .23442 L
.86172 .23404 L
.8644 .23388 L
.86692 .23374 L
.86928 .23364 L
.87183 .23356 L
.87415 .2335 L
.87517 .23348 L
.87629 .23346 L
.87761 .23344 L
.87886 .23343 L
.88008 .23343 L
.88121 .23343 L
.88243 .23343 L
.88377 .23344 L
.88445 .23344 L
.88517 .23345 L
.88649 .23347 L
.88891 .23352 L
.89146 .23359 L
.89603 .23375 L
.90139 .23401 L
.90638 .23431 L
.91771 .23519 L
.93917 .23751 L
.95868 .24021 L
1 .24738 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000K_oooolCo`0002oooooo002Booooo`05o`000?oo
ooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`1Vooooo`So00004oooool<o`0002?ooooo002Booooo`05oa0@
4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0Hoooool3o`0002Oooooo1Ol0000Nooooo`00T_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0H?ooool3o`0002oooooo1Ol0000Iooooo`00T_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2
o`0005oooooo0_l0000gooooo`Co00005Oooool001Kooooo1?l0002Kooooo`03o`000?oooooooooo
05cooooo0_l0000mooooo`;o00004oooool001[ooooo1ol0002Dooooo`03o`000?oooooooooo05Wo
oooo0ol0001Dooooo`008Oooool5o`0008oooooo00?o0000ooooooooool0F?ooool00ol0003ooooo
ooooo`1Eooooo`009_ooool5o`0008[ooooo00?o0000ooooooooool0Eoooool00ol0003ooooooooo
o`1Fooooo`00:oooool5o`0008Gooooo0_l0001Gooooo`03o`000?oooooooooo05Oooooo000`oooo
o`Co0000POooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo05Sooooo000Eooooo`;o
000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h05?ooool3o`0000?ooooo00Go
V9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool5o`0000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Looooo`Co000000So410@ooooooooooook^k^oc8b<_l0
003o<S8bonk^kQkooooo00?o0000ooooooooool07oooool4o`000008oa0@4?ooooooooooonk^k_lb
<S;o0000oc8b<_o^k^hJooooo`Go00000oooool01_o^k^ko<S8bo`000?lb<S;ok^k^ooooo`;o0000
6?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Moooo
o`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h03_ooool001Kooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Oooooo0ol000001Ol@413o^[Zj
oooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01OnHV9So8B4Qonk^k_ooooooA4A4
00?ooooo00KoMgMgoiRHV?ooooooV9RHogMgMol0000Jooooo`05oa0@4?nj^[[oooooogMgMolb<S80
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko00000_ooool5o`0000?ooooo00Go410@oooooooo
oooooooooa0@400Booooo`Ko00000_ooool3o`000003ooooool0003ooooo00;ooooo00Go410@oooo
oooooooooooooa0@400Cooooo`Ko00000oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?oooooo
ooooooooool@41004oooool6o`0000Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@01kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41006oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?oooooooooooooo
ool000007oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool06Oooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`004oooool01?m4A4CogMgMooooool0
0004ooooo`05o`000?ooooooooooooooool000007Oooool4o`000003ooooool0003ooooo00;ooooo
00?o0000ooooooooool06oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool0
00007_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007_ooool2o`00
02;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001cooooo00?oV9RH
ob4Q8Oo^k^h00oooool00ol0003oooooooooo`02o`0001kooooo00?oZJVYoa0@4?ooool00_ooool0
1Ol0003ooooooooooooooooo000001_ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000000kooooo000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000oooooooo
ooooooooo`00000Looooo`03oa0@4?l0003o^[Zj00;ooooo1_l0000Nooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`00000Nooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`00000Nooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000001gooooo00?oMgMgofIVI_ooool00_ooool00ol0003ooooo
ooooo`02o`0001gooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000001_o
oooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000kooooo000Doooo
o`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@400Mooooo`03okZj^_lQ8B7o
oooo00;ooooo00Co410@oooooooooooooooo1?l0000Looooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Looooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Nooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@01kooooo00Wo0000oooooooooooooooooa0@4?oooooo0000ooooool@4100
7_ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41007?ooool00omgMgOo
c<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41003_ooool001Cooooo00?ok^k^odA4A?l0
00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00Go410@oiRHV?oooooo^[Zjo`000003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool4o`0001Cooooo00Go0000okZj^_ooooooV9RH
oa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05o`000?nj^[[ooooooiRHV?l@41000ooo
ool01OmgMgOo0000oooooonHV9SoMgMg01_ooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL07?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03_ooool001Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1oooool3o`00017ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h07?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07_ooool0
0ol0003oooooooooo`0Oooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Ol0003o<S8bo`000?lb<S;ok^k^01_o
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Oooool0
0omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool0057ooooo0ol0001Q
ooooo`;o0000C_ooool00ol0003oooooooooo`1Pooooo`00E?ooool3o`0005kooooo00?o0000oooo
ooooool0C?ooool00ol0003oooooooooo`1Qooooo`00Eoooool4o`0005[ooooo00?o0000oooooooo
ool0Boooool00ol0003oooooooooo`1Rooooo`00Foooool5o`0005Gooooo00?o0000ooooooooool0
Boooool00ol0003oooooooooo`1Rooooo`00H?ooool4o`00057ooooo00?o0000ooooooooool0B_oo
ool00ol0003oooooooooo`1Sooooo`005_ooooooo`00043o00004oooool001Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`03o`0000;ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000002
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool001Kooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00?ooooo1?l0000Noooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Poooo
o`05o`000?ooooooooooooooool000009oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo017ooooo001_ooooo`?o0000@oooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo
06Kooooo001booooo`Co0000?oooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo06Ko
oooo001fooooo`?o0000??ooool2o`0004Oooooo00?o0000ooooooooool0Ioooool007Wooooo0ol0
000iooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0J?ooool007cooooo0ol0000f
ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0J?ooool007oooooo1?l0000boooo
o`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0JOooool008?ooooo1Ol0000]ooooo`03
o`000?oooooooooo04?ooooo00?o0000ooooooooool0J_ooool008Sooooo1?l0000Yooooo`;o0000
A?ooool00ol0003oooooooooo`1Zooooo`00S?ooool4o`0002Gooooo00?o0000ooooooooool0@_oo
ool00ol0003oooooooooo`1[ooooo`00T?ooool5o`00023ooooo00?o0000ooooooooool0@_ooool0
0ol0003oooooooooo`1[ooooo`00UOooool5o`0001_ooooo00?o0000ooooooooool0@Oooool00ol0
003oooooooooo`1/ooooo`00V_ooool4o`0001Oooooo00?o0000ooooooooool0@?ooool00ol0003o
ooooooooo`1]ooooo`00W_ooool5o`0001;ooooo0_l00011ooooo`03o`000?oooooooooo06gooooo
002Sooooo`Co00003_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo06kooooo002W
ooooo`Co00002_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo06oooooo002[oooo
o`Go00001Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo073ooooo002`ooooo`Co
000000?oooooo`000?ooool0?Oooool00ol0003oooooooooo`1aooooo`00]?ooool4o`0003cooooo
00?o0000ooooooooool0LOooool00;Gooooo00?o0000ooooooooool00ol0000hooooo`03o`000?oo
oooooooo07;ooooo002Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0
0004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`03ooooo`Oo0000
<?ooool00ol0003oooooooooo`1cooooo`00T_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo00[ooooo3ol0000Pooooo`03o`000?oooooooooo07Cooooo002Booooo`05oa0@
4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool06Oooool8o`0001Oooooo00?o0000ooooooooool0MOooool009;ooooo
00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_oo
ool01?ooool3o`00027ooooo0ol0000Booooo`;o0000N?ooool009;ooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005oooo
o`03o`000?oooooooooo02Cooooo0ol0000=ooooo`;o0000N_ooool009;ooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Wooooo`Co00002?ooool00ol0003oooooooooo`1jooooo`00T_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0:oooool8o`0007gooooo002Booooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03
ooooo`?o0000/?ooool009[ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000ooooooooooooooooo`00000<
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`ooooo`00V_ooool0
1Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0
0006ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool0
09;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00T_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooo
oooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo0;3ooooo002Booooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00T_ooool01Ol0003ooooooooooooo
oooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool0/?ooool009;ooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVY
ZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Zoooool4
o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool00:gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo0ol0002`ooooo`00[Ooo
ool00ol0003oooooooooo`2hooooo`00[Oooool00ol0003oooooooooo`2hooooo`00[Oooool00ol0
003oooooooooo`2hooooo`00Zoooool00omEEEGoIVIVo`00002jooooo`00oooooomYooooo`00/ooo
ool00ol0003o^[Zjooooo`2booooo`00/oooool2oc8b<[?ooooo0024ooooo`;o000000Ko410@oooo
oooooooo410@o`000?l@410Gooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01[ooooo0_l000002Ol@413o
ooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP1looooo`00QOooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Oooooo1_l00009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zj
onk^k_mgMgOo410@00Wooooo1_l0000<ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`1looooo`00QOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Oo
oooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01;ooooo00?o0000oooo
ooooool06_ooool5o`0000?ooooo00Go410@oooooooooooooooooa0@401looooo`00QOooool01_l0
003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000;ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go
0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo00_ooooo1_l00009ooooo`04odA4
A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`00001looooo`00QOooool01_l0003o
gMgMoc8b<_mEEEGogMgMo`0001_ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooo
oooo000001;ooooo00?o0000ooooooooool06_ooool01?oMgMgoEEEEooooool00004ooooo`05o`00
0?ooooooooooooooool00000O?ooool008Gooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Loooo
o`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0>ooooo`03oa0@4?l0003o
000000?o00006_ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@4100O?oo
ool008Gooooo00Ko0000oc8b<_oooooooooooc8b<_l0000Hooooo`05o`000?nj^[[ooooooiRHV?l@
41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool06oooool00oo^
k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0O?ooool008Cooooo00?o410@o`00
0?n7QhL00_ooool00on7QhOo0000oa0@400Gooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo00?o0000ooooooooool07?ooool00omgMgOo0000oooo
o`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0O?ooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .25212 m
.04057 .26033 L
.08481 .26999 L
.12636 .27955 L
.16632 .28902 L
.20885 .2993 L
.2498 .30939 L
.29331 .31992 L
.33524 .32995 L
.37557 .34025 L
.41848 .34957 L
.43982 .35315 L
.4598 .35709 L
.47894 .36239 L
.49953 .36954 L
.51014 .37306 L
.51574 .37464 L
.52172 .37601 L
.52467 .37654 L
.52746 .37694 L
.52996 .37722 L
.53136 .37733 L
.53266 .37742 L
.53388 .37748 L
.53501 .37752 L
.53626 .37754 L
.5376 .37754 L
.53827 .37753 L
.539 .37751 L
.54033 .37746 L
.54162 .37739 L
.54281 .37731 L
.54535 .37707 L
.54768 .37679 L
.55292 .37594 L
.56241 .37392 L
.56783 .37268 L
.57362 .37147 L
.57643 .37099 L
.57908 .37061 L
.58146 .37036 L
.58281 .37026 L
.58404 .3702 L
.58519 .37016 L
.58642 .37016 L
.58758 .37018 L
.58864 .37022 L
.58988 .37031 L
.59123 .37044 L
.59251 .37061 L
Mistroke
.5937 .3708 L
.59629 .37135 L
.59865 .37201 L
.60391 .37405 L
.6093 .37699 L
.61511 .3811 L
.62565 .39065 L
.63651 .40201 L
.64663 .41175 L
.65173 .4155 L
.65458 .4171 L
.65718 .41817 L
.65867 .41861 L
.66003 .4189 L
.66075 .41901 L
.66154 .41908 L
.66236 .41912 L
.66313 .41911 L
.66382 .41907 L
.66455 .419 L
.66584 .41877 L
.66656 .41859 L
.66724 .4184 L
.66876 .41783 L
.67153 .41638 L
.67408 .41457 L
.67984 .40881 L
.68491 .40197 L
.69028 .39317 L
.70981 .35319 L
.73064 .31052 L
.74965 .28064 L
.76015 .26839 L
.77011 .25924 L
.78062 .25178 L
.79206 .24572 L
.80191 .24189 L
.8128 .23882 L
.81826 .23767 L
.82416 .23666 L
.82973 .23591 L
.83485 .23537 L
.83981 .23498 L
.84254 .23481 L
.84512 .23468 L
.84753 .23458 L
.84879 .23454 L
.85013 .23451 L
.85126 .23448 L
.8525 .23446 L
Mistroke
.85363 .23444 L
.85469 .23443 L
.85603 .23442 L
.85679 .23442 L
.8575 .23442 L
.85879 .23442 L
.86016 .23443 L
.86151 .23444 L
.86278 .23446 L
.86516 .23451 L
.86798 .23459 L
.87057 .23468 L
.87642 .23495 L
.88665 .2356 L
.8962 .23639 L
.9179 .23874 L
.95877 .24472 L
1 .25212 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000Joooool:o`0003_ooooo002Booooo`05o`000?oo
ooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`1Qooooo`[o00002_ooool;o`00033ooooo002Booooo`05oa0@
4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0Goooool2o`0001oooooo1_l0000Zooooo`00T_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0G?ooool3o`0002Oooooo1ol0000Sooooo`00T_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2
o`0005[ooooo0ol0000aooooo`Ko00007Oooool00;Gooooo00?o0000ooooooooool0Eoooool2o`00
03[ooooo1ol0000Fooooo`005_ooool3o`0009cooooo00?o0000ooooooooool0EOooool2o`0004?o
oooo0ol0000Cooooo`006Oooool5o`0009Oooooo00?o0000ooooooooool0E?ooool00ol0003ooooo
ooooo`1Iooooo`007_ooool4o`0009?ooooo00?o0000ooooooooool0Doooool00ol0003ooooooooo
o`1Jooooo`008_ooool4o`0008oooooo0_l0001Cooooo`03o`000?oooooooooo05_ooooo000Voooo
o`Go0000R_ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo05cooooo000Eooooo`;o
000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000[ooooo00Go
V9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool5o`0000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Looooo`Co000000So410@ooooooooooook^k^oc8b<_l0
003o<S8bonk^kQkooooo00?o0000ooooooooool07oooool4o`000008oa0@4?ooooooooooonk^k_lb
<S;o0000oc8b<_o^k^hJooooo`Go00000oooool01Oo^k^ko<S8bo`000?l0003ok^k^01_ooooo00Go
V9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Oooool2o`000009
oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Fooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0@ooooo`Co00001_ooool01Ol@413o^[Zjoooo
oomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01OnHV9So8B4Qonk^k_ooooooA4A400?o
oooo00GoMgMgoiRHV?l0003oV9RHogMgM`0Kooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00kooooo000;ooooo`Ko00000_ooool5o`0000?ooooo00Go410@oooooooooooooooo
oa0@400Booooo`Oo00001Oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@oooooooo
ool04Oooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@
01?ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400N
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@01_ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o0000oooooooooooo410@01oooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01Wooooo1Ol00003ooooo`05
oa0@4?ooooooooooooooool@41003_ooool001?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0
003ooooooooooooooooo000001Wooooo1?l000000onYZJWo410@ooooo`02ooooo`05o`000?oooooo
ooooooooool000007Oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool00000
7_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007_ooool2o`0002;o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001cooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo000001kooooo00?oZJVYoa0@4?ooool00_ooool0
1Ol0003ooooooooooooooooo000001_ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000000kooooo000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000oooooooo
ooooooooo`00000Looooo`03oa0@4?l0003o000000;o000000?oooooo`000?ooool00_ooool00ol0
003oooooooooo`0Looooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00000N
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Nooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001gooooo
00CoMgMgofIVI_oooooooooo0_l00003ooooo`03o`000?oooooooooo01_ooooo00?o410@o`000?nj
^[X00oooool01Ol0003ooooooooooooooooo000001_ooooo00CogMgMoeEEEOoooooo00001?ooool0
1Ol0003ooooooooooooooooo000000kooooo000Dooooo`03ogMgMoo<c<co000000Cooooo00Go410@
oooooooooooooooooa0@400Mooooo`04okZj^_lQ8B7oooooooooo`Go000000?o410@ooooooooool0
7Oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool07?ooool00ol0003o
ooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41007_ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Nooooo`05o`000?oooooo
ooooo`000?l@41000oooool00ol@413oooooooooo`0Looooo`03okZj^_lQ8B7ooooo00;ooooo00Go
410@oooooooooooooooooa0@400Looooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooo
oooooa0@400>ooooo`005?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL06_ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00CoMgMgoiRHV?ooooooV9RH1?l0000H
ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool03Ol0
003o^[ZjoooooonHV9So410@ooooool0003oooooogMgMonHV9SooooooiRHV?mgMgL06oooool01Ol@
413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`03onk^k_m4
A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`005Oooool00omgMgOo0000oooo
o`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06_ooool01OnYZJWo410@o`000?l@413oZJVY00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`Co00005?ooool01OnHV9So410@o`000?lQ8B7o
c<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Looooo`03oeEEEOmVIVKo000000Cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0Nooooo`03o`000?oooooooooo01oooooo00?oEEEEofIVI_l00000
1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00KoV9RHoa0@4?l0003o8B4Qolc<c?l00002
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Mooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0>ooooo`00C_ooool5o`0006;ooooo0_l0001;ooooo`03o`000?oooooooooo06?o
oooo001Cooooo`Co0000G_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo06Cooooo
001Gooooo`Co0000F_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo06Cooooo001K
ooooo`Go0000EOooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo06Gooooo001Poooo
o`Co0000DOooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo06Kooooo000Foooooooo
0000@?l0000Cooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?o0000
0_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool2o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`005_oo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00ooo
ool4o`0001kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool04Oooool006oooooo0ol00013ooooo`03o`000?oooooo
oooo04Gooooo00?o0000ooooooooool0J?ooool007;ooooo1?l0000oooooo`03o`000?oooooooooo
04Gooooo00?o0000ooooooooool0J?ooool007Kooooo1Ol0000jooooo`;o0000AOooool00ol0003o
ooooooooo`1Yooooo`00Noooool4o`0003Kooooo00?o0000ooooooooool0A?ooool00ol0003ooooo
ooooo`1Yooooo`00Ooooool4o`0003;ooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`1Zooooo`00Poooool5o`0002gooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`1Z
ooooo`00R?ooool4o`0002Wooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`1Zoooo
o`00S?ooool4o`0002Gooooo0_l00013ooooo`03o`000?oooooooooo06_ooooo002@ooooo`Go0000
8?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo06_ooooo002Eooooo`Go00006ooo
ool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo06cooooo002Jooooo`Ko00005Oooool0
0ol0003oooooooooo`11ooooo`03o`000?oooooooooo06cooooo002Pooooo`Ko00003oooool00ol0
003oooooooooo`10ooooo`03o`000?oooooooooo06gooooo002Vooooo`Go00002_ooool2o`00047o
oooo00?o0000ooooooooool0KOooool00:_ooooo0ol00007ooooo`03o`000?oooooooooo03oooooo
00?o0000ooooooooool0K_ooool00:kooooo0ol00004ooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool0K_ooool00;7ooooo0ol000000ooooooo0000ooooo`0oooooo`03o`000?oooooo
oooo06oooooo002dooooo`?o0000?oooool00ol0003oooooooooo`1_ooooo`00]Oooool3o`0001;o
oooo3?l0000Oooooo`03o`000?oooooooooo073ooooo002eooooo`03o`000?oooooooooo00Go0000
2?ooool5o`0000cooooo0_l0000Looooo`03o`000?oooooooooo077ooooo002Booooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01Oooool00ol0003oooooooooo`05ooooo`So00004oooool2o`0001[ooooo00?o0000oooooooo
ool0LOooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0L_ooool009;ooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0L_ooool009;o
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b
<_ooool01?ooool3o`0002Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1coooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo07?ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo07Cooooo002Booooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0M?oo
ool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
1?ooool4o`0000Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo07Gooooo002eooooo`;o0000:Oooool2o`0000kooooo00?o0000ooooooooool0MOoo
ool00;Gooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo07Kooooo002eooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`1gooooo`00]Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0N?ooool00;Gooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`03ooooo`;o0000Noooool00;Gooooo0_l0000_ooooo`Ko0000O?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o
0000ooooooooool00oooool3o`000;3ooooo002Jooooo`05o`000?ooooooooooooooool000003ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
/?ooool009[ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o
0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0
/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVY
ooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009;ooooo00Go
410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000kooooo
00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go
0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@
41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooo
oolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool00:_ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002]
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool00:gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o
0000/?ooool00:gooooo00?o0000ooooooooool0^?ooool00:gooooo00?o0000ooooooooool0^?oo
ool00:gooooo00?o0000ooooooooool0^?ooool00:_ooooo00?oEEEEofIVI_l00000^_ooool00?oo
ooooJOooool00;?ooooo00?o0000okZj^_ooool0/_ooool00;?ooooo0_lb<S:cooooo`00Q?ooool2
o`000006oa0@4?oooooooooooa0@4?l0003o410@5oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Ioooo
o`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07cooooo0025
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`0000Wooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool00oo<c<co0000
oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000gooooo00WoMgMgoc8b<_oo
ooooooooogMgMonHV9SooooooiRHV?mgMgL0O?ooool008Gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
400Booooo`03o`000?oooooooooo01oooooo00Co0000oooooooooooo410@0oooool00ol@413ooooo
ooooo`1jooooo`00QOooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000;ooooo`03
oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo
00_ooooo1_l0000=ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`1j
ooooo`00QOooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001_ooooo00?oMgMgofIVI_ooool00_oo
ool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool06oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00001looooo`00QOooool01_l0003o
QhN7ojVYZOnj^[[oEEEEo`0001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oo
oooooooo00kooooo00?o410@o`000?l000000ol0000Jooooo`03o`000?oooooooooo00Cooooo00Go
410@oooooooooooooooooa0@401looooo`00QOooool01_l0003o<S8boooooooooooo<S8bo`0001So
oooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`1looooo`00Q?ooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Oooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003ooooo
ooooo`0Kooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07cooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .25639 m
.04057 .26424 L
.08481 .27334 L
.12636 .28211 L
.16632 .29072 L
.20885 .30039 L
.2498 .30948 L
.29331 .31825 L
.33524 .32859 L
.35443 .33403 L
.36535 .33687 L
.37557 .33914 L
.38561 .34088 L
.39125 .34163 L
.3964 .34218 L
.40182 .34263 L
.40772 .34301 L
.41848 .34355 L
.42406 .34387 L
.42932 .34428 L
.43404 .34478 L
.43914 .3455 L
.44472 .34657 L
.45061 .34805 L
.46116 .35171 L
.47111 .35633 L
.48178 .36222 L
.49178 .36803 L
.50103 .37291 L
.50611 .37511 L
.51171 .37697 L
.51311 .37732 L
.51462 .37765 L
.51592 .37788 L
.51735 .37809 L
.51887 .37826 L
.5197 .37832 L
.52047 .37836 L
.52186 .3784 L
.52263 .3784 L
.52333 .37838 L
.52465 .37831 L
.52532 .37826 L
.52605 .37819 L
.52734 .37802 L
.52855 .37783 L
.53127 .37725 L
.5342 .3764 L
.53956 .37432 L
.54446 .37187 L
Mistroke
.55495 .36548 L
.56612 .35832 L
.57156 .35532 L
.57422 .35407 L
.57667 .35308 L
.57885 .35234 L
.58125 .35171 L
.5825 .35146 L
.58367 .35128 L
.58489 .35115 L
.58621 .35107 L
.58752 .35107 L
.5889 .35114 L
.59008 .35127 L
.59139 .35149 L
.59278 .3518 L
.59429 .35225 L
.59701 .35334 L
.59961 .35472 L
.60234 .35656 L
.60723 .36081 L
.61638 .3721 L
.62637 .38872 L
.63787 .41071 L
.64352 .42109 L
.64872 .42949 L
.65346 .43563 L
.65584 .43803 L
.65847 .44006 L
.65984 .44085 L
.6611 .44139 L
.66179 .44162 L
.66254 .44182 L
.66392 .442 L
.6652 .44199 L
.66656 .44177 L
.66773 .44141 L
.66901 .44084 L
.67025 .44011 L
.6716 .43912 L
.67432 .43649 L
.67919 .42981 L
.68488 .41915 L
.69018 .40699 L
.71006 .35277 L
.72971 .3049 L
.7408 .28463 L
.75103 .27025 L
.7619 .25887 L
.76784 .25406 L
Mistroke
.77341 .2503 L
.78348 .24504 L
.78882 .2429 L
.79457 .24102 L
.79971 .23965 L
.80519 .23849 L
.8112 .23751 L
.81677 .23684 L
.81951 .23658 L
.82247 .23635 L
.82508 .23619 L
.82784 .23605 L
.83033 .23596 L
.83165 .23592 L
.83307 .23588 L
.83437 .23585 L
.83555 .23584 L
.83674 .23582 L
.83787 .23582 L
.83907 .23582 L
.84036 .23582 L
.84158 .23583 L
.8427 .23584 L
.84394 .23586 L
.84529 .23588 L
.84802 .23595 L
.85072 .23604 L
.8536 .23616 L
.85879 .23643 L
.86893 .23713 L
.87814 .23793 L
.92014 .24302 L
.96055 .24936 L
1 .25639 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo05oooooo5_l0000kooooo`00T_ooool01Ol@413ooooooooooooooooo410@00oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05[o
oooo1Ol0000Fooooo`So0000<oooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
05Sooooo0_l0000Sooooo`[o0000:Oooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0001Gooooo`;o0000;oooool7
o`0002;ooooo002eooooo`03o`000?oooooooooo05Cooooo0_l0000hooooo`Ko00007?ooool00;Go
oooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`0nooooo`Ko00005_ooool001Kooooo
0ol0002Looooo`03o`000?oooooooooo057ooooo0_l00017ooooo`?o00004oooool001Wooooo1Ol0
002Gooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0GOooool001kooooo1?l0002C
ooooo`;o0000DOooool00ol0003oooooooooo`1Mooooo`008_ooool4o`0008oooooo00?o0000oooo
ooooool0Coooool00ol0003oooooooooo`1Nooooo`005Oooool2o`000009oa0@4?oooooooooooooo
ooo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo1Ol0000?ooooo`05oiRHV?l@413o0000oc8b<_o<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h07?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hNooooo`03o`00
0?oooooooooo01oooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^6_ooool5
o`0000?ooooo00Gok^k^o`000?l0003o<S8bonk^kP0Kooooo`05oiRHV?l@413o0000oc8b<_o<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo0_l000002Ol@413oooooooooooooooook^k^
oc8b<_l0003o<S8bonk^kP0>ooooo`005_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool5o`0000[ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL06oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Nooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg01[ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05o`000?nHV9SooooooiRH
V?mgMgL06oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`002ooo
ool6o`0000;ooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41004?ooool8o`0000Kooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo017ooooo1_l00003ooooo`03
oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400Cooooo`Ko00001Oooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41007_ooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Kooooo`03oiRHV?lQ
8B7ok^k^00Cooooo00Go0000oooooooooooooooooa0@400Oooooo`05o`000?ooooooooooooooool@
41000oooool00ol@413oooooooooo`0Iooooo`Go00000oooool01Ol@413ooooooooooooooooo410@
00kooooo000Cooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000D
ooooo`Go00001?ooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000007Ooo
ool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000007_ooool2o`0002;ooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000001cooooo00?oV9RHob4Q8Oo^k^h00_ooool2o`00
00?ooooo00?o0000ooooooooool07?ooool00onYZJWo410@ooooo`02ooooo`05o`000?oooooooooo
ooooool000006oooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool00000
3_ooool001?ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000001Wo
oooo1Ol000001Onj^[[ooooooooooooooooo000000?ooooo00?o0000ooooooooool07?ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`06ogMgMomVIVKoooooo`000?oo
oooo00000oooool00ol0003oooooooooo`0Kooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000oooo
ooooooooooooo`00000Kooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000oooooooooooooooo
o`00000>ooooo`005?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@4100
7Oooool5o`000005oa0@4?ooooooooooooooool@41007oooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool07?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41007_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Nooooo`;o00000_ooool01Ol@413ooooooooooooooooo410@01kooooo
00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@01cooooo00?oMgMgolc<c?l0
00001?ooool01Ol@413ooooooooooooooooo410@00kooooo000Dooooo`03onk^k_m4A4Co000000Co
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05oa0@4?nHV9SooooookZj^_l000000oooool7
o`0001Wooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
7_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Joooo
o`06o`000?nj^[[ooooooiRHV?l@413o00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo
00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07?ooool00oo^
k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool001Gooooo00?oMgMgo`00
0?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00GoZJVYoa0@4?l0003o410@ojVY
Z@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool5o`0001Cooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool00omEEEGoIVIVo`000004oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h07_ooool00ol0003oooooooooo`0Oooooo`03oeEEEOmVIVKo
000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Jooooo`05oiRHV?l@413o0000ob4Q8Ol00000
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h07Oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03_ooool004kooooo1Ol0001Rooooo`;o0000B_ooool00ol0003oooooooooo`1T
ooooo`00Doooool4o`0005kooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`1Uoooo
o`00Eoooool4o`0005[ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1Vooooo`00
Foooool5o`0005Gooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1Vooooo`00H?oo
ool4o`00057ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`1Wooooo`005_oooooo
o`00043o00004oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06o`00
00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`005_ooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01Oooool5o`0001_o
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool04Oooool007;ooooo1?l0000oooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0J?ooool007Kooooo1Ol0000jooooo`03o`000?oooooooooo04Cooooo00?o
0000ooooooooool0JOooool007_ooooo1?l0000fooooo`;o0000AOooool00ol0003oooooooooo`1Y
ooooo`00Ooooool4o`0003;ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`1Zoooo
o`00Poooool3o`0002oooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`1Zooooo`00
Q_ooool4o`0002_ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`1Zooooo`00R_oo
ool3o`0002Sooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`1[ooooo`00SOooool5
o`0002?ooooo0_l00013ooooo`03o`000?oooooooooo06_ooooo002Booooo`ko00005Oooool00ol0
003oooooooooo`11ooooo`03o`000?oooooooooo06cooooo002Pooooo`Go00004?ooool00ol0003o
ooooooooo`11ooooo`03o`000?oooooooooo06cooooo002Uooooo`?o00003Oooool00ol0003ooooo
ooooo`11ooooo`03o`000?oooooooooo06cooooo002Xooooo`Co00002Oooool00ol0003ooooooooo
o`0Eooooo`So00008oooool00ol0003oooooooooo`1]ooooo`00[?ooool2o`0000Oooooo0_l0000D
ooooo`;o00002?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo06gooooo002^oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04Oooool2o`0000_ooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`1^ooooo`00[oooool2o`0000Cooooo00?o0000oooooooo
ool03oooool2o`0000kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1^ooooo`00
/Oooool01Ol0003ooooooooooooooooo000000oooooo0_l0000Aooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool0K_ooool00;;ooooo1?l0000>ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`1_ooooo`00]Oooool2o`0000_ooooo0_l0
000Fooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Koooool00;Gooooo00Co0000
ooooool0003o00002?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool0L?ooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`04o`000?ooooooooooooooo`So
00006_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo073ooooo002Booooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo077ooooo002Booooo`05oa0@4?ooooooooooooooool@41003?ooool00onH
V9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo077ooooo002Booooo`05o`000?oooooooooooooo
ool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Toooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0LOooool009;ooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1b
ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`1booooo`00T_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000
okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo07?ooooo002Booooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1cooooo`00]Ooo
ool2o`0002Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1cooooo`00]Oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0M?ooool0
0;Gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
07Cooooo002eooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`1dooooo`00]Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0MOooool00;Gooooo0_l0000[ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0MOooool00;Gooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo07Gooooo002eooooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`1fooooo`00]Oooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0M_ooool00;Gooooo0_l0000^ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0Moooool00;Gooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07Sooooo002eooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1iooooo`00]Oooool00ol0
003oooooooooo`0_ooooo`Ko0000Noooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?oo
ool009[ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0
002`ooooo`00V_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol0003ooooooooooooooooo000000cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo
002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@4100
3Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
/?ooool009;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo
00?oMgMgoc8b<_ooool01?ooool3o`000;3ooooo002Booooo`05o`000?ooooooooooooooool00000
3_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003o
ooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMooo
ool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002[ooooo`Co000000?o
410@ooooooooool00oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0/?ooool00:gooooo00?o0000ooooooooool01Oooool3o`000;3ooooo002]ooooo`03o`00
0?oooooooooo0;Sooooo002]ooooo`03o`000?oooooooooo0;Sooooo002]ooooo`03o`000?oooooo
oooo0;Sooooo002[ooooo`03oeEEEOmVIVKo00000;[ooooo003oooooofWooooo002cooooo`03o`00
0?nj^[[ooooo0;;ooooo002cooooo`;o<S8b/oooool008Cooooo0_l000001_l@413oooooooooool@
413o0000oa0@41Oooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOo
0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool01Oo^k^ko<S8bo`000?l@413o
c<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1looooo`00QOooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Oooooo1_l00009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zj
onk^k_mgMgOo410@00Wooooo1_l00009ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01Omg
MgOoV9RHoooooonHV9SoMgMg07cooooo0025ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool05oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41004_ooool0
0ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooo
oooooooo410@07cooooo0025ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000_o
oooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000oooo
ooooool02oooool6o`0000Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?oooooo
ooooooooool00000O?ooool008Gooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Kooooo`03ogMg
MomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo01[o
oooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?ooooooooooooooool00000O?ooool0
08Gooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Looooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0>ooooo`03oa0@4?l0003o000000?o00006Oooool00omEEEGoQhN7
ooooo`05ooooo`05oa0@4?ooooooooooooooool@4100O?ooool008Gooooo00Ko0000oc8b<_oooooo
oooooc8b<_l0000Hooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonH
V9SoMgMg01;ooooo00?o0000ooooooooool06_ooool00ooMgMgo410@oiRHV005ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0O?ooool008Cooooo00?o410@o`000?n7QhL00_ooool00on7QhOo0000oa0@
400Gooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;o
oooo00?o0000ooooooooool06oooool01?o<c<coA4A4o`000?l@4103ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h0O?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(70) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .26018 m
.04057 .26775 L
.08481 .27609 L
.12636 .28401 L
.16632 .29254 L
.20885 .30169 L
.2498 .30835 L
.27066 .3117 L
.29331 .3167 L
.31511 .32341 L
.33524 .33019 L
.34471 .33302 L
.34994 .33435 L
.3549 .33541 L
.35769 .33591 L
.36074 .33637 L
.36354 .33672 L
.36608 .33696 L
.36871 .33715 L
.37016 .33722 L
.37151 .33727 L
.37278 .3373 L
.37394 .33731 L
.37521 .33732 L
.37656 .3373 L
.37784 .33727 L
.37856 .33725 L
.37923 .33723 L
.38176 .33711 L
.38406 .33696 L
.38651 .33677 L
.39718 .33563 L
.40207 .33506 L
.40722 .33451 L
.40935 .33432 L
.41162 .33414 L
.41292 .33406 L
.41411 .334 L
.4153 .33395 L
.41643 .33391 L
.41762 .33389 L
.41888 .33389 L
.41996 .3339 L
.42115 .33393 L
.42242 .33398 L
.42379 .33406 L
.42509 .33417 L
.42627 .33429 L
.42887 .33463 L
.43171 .33513 L
Mistroke
.43439 .33575 L
.43687 .33645 L
.44175 .33818 L
.44617 .34018 L
.45607 .3461 L
.47802 .36432 L
.48764 .37252 L
.49274 .37628 L
.49554 .37808 L
.49819 .37957 L
.50075 .38078 L
.50353 .38183 L
.50476 .38219 L
.50606 .38251 L
.50717 .38273 L
.5084 .38291 L
.50963 .38302 L
.51076 .38307 L
.512 .38306 L
.51331 .38297 L
.51445 .38283 L
.51551 .38265 L
.51667 .38239 L
.51791 .38205 L
.52061 .38108 L
.52353 .37968 L
.52882 .37629 L
.53872 .3675 L
.55922 .34518 L
.56484 .33969 L
.57087 .33478 L
.57379 .33288 L
.57655 .3314 L
.57904 .33037 L
.58044 .32992 L
.58174 .32959 L
.58298 .32937 L
.58411 .32923 L
.58535 .32916 L
.58666 .32919 L
.5878 .32929 L
.58887 .32945 L
.59004 .32971 L
.59128 .33008 L
.59264 .33059 L
.59412 .33128 L
.5968 .33289 L
.59941 .33491 L
.60182 .33719 L
.60676 .3431 L
Mistroke
.61219 .35157 L
.62317 .37462 L
.63451 .40442 L
.64528 .43301 L
.64996 .44361 L
.65495 .45265 L
.65782 .45652 L
.66042 .45908 L
.66167 .45997 L
.66303 .46067 L
.66431 .46108 L
.66549 .46123 L
.66673 .46116 L
.66785 .46089 L
.66915 .46033 L
.67038 .45956 L
.67257 .45762 L
.67494 .45471 L
.67755 .45058 L
.68033 .4452 L
.68531 .43329 L
.70623 .36686 L
.71631 .33543 L
.72692 .30757 L
.73598 .28862 L
.74588 .27265 L
.75098 .26614 L
.75642 .2603 L
.76621 .25224 L
.77212 .24861 L
.77769 .24587 L
.78266 .24388 L
.78812 .24211 L
.79305 .24084 L
.79834 .23978 L
.80126 .23931 L
.80392 .23895 L
.80664 .23864 L
.80915 .2384 L
.81165 .23821 L
.81391 .23807 L
.81642 .23795 L
.81781 .2379 L
.81909 .23786 L
.82021 .23783 L
.82143 .23781 L
.82266 .23779 L
.82396 .23778 L
.8251 .23777 L
.82632 .23777 L
Mistroke
.82748 .23778 L
.82853 .23779 L
.82977 .2378 L
.83094 .23782 L
.8336 .23788 L
.83619 .23796 L
.83898 .23806 L
.84401 .2383 L
.84862 .23858 L
.85981 .23948 L
.87044 .24054 L
.91053 .24558 L
.9532 .25212 L
.99427 .25915 L
1 .26018 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo06;ooooo1_l00018ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05[o
oooo2Ol00005ooooo`oo0000>Oooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
05Kooooo1?l0000Mooooo`Oo0000<_ooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0001Fooooo`03o`000?oooooo
oooo02Kooooo1_l0000/ooooo`00]Oooool00ol0003oooooooooo`1Cooooo`;o0000;oooool7o`00
02Gooooo002eooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0=_ooool6o`0001oo
oooo002eooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0?Oooool7o`0001Sooooo
002eooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0AOooool4o`0001Cooooo000F
ooooo`Co0000Voooool2o`0004oooooo0_l0001<ooooo`03o`000?oooooooooo017ooooo000Joooo
o`Oo0000U?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo063ooooo000Eooooo`;o
000000[o410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^kooooo1Ol0000Dooooo`05oiRH
V?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo1Ol00003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000
oc8b<_o^k^hNooooo`03o`000?oooooooooo01oooooo1?l000002?l@413oooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^6_ooool5o`0000?ooooo00Go0000oc8b<_l0003o<S8bonk^kP0Kooooo`05oiRH
V?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo0_l000002Ol@
413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0>ooooo`005_ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool5o`0000oooooo00Go410@okZj^_oooooo
MgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00GoV9RHob4Q8Oo^k^koooooodA4A002oooo
o`06o`000?mgMgOoV9RHoooooonHV9SoMgMg6oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0>ooooo`002oooool6o`0000;ooooo1Ol00003ooooo`05oa0@4?oooooooooooooo
ool@41002oooool5o`0000;ooooo1_l00006ooooo`05o`000?ooooooooooooooool@41000oooool0
0ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?oooooo
ooooooooool@41004oooool6o`0000Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@01kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41006oooool00onHV9So8B4Qonk^kP02ooooo`03o`000?oooooo410@00?o
oooo00?o410@ooooooooool07Oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@oooo
ooooool06Oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`004oooool01?m4
A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000004?ooool5o`0000Sooooo00?o
ZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000001gooooo00?oV9RHob4Q8Oo^k^h0
0oooool01Ol0003ooooooooooooooooo000001kooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000001kooooo0_l0000Rooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00000Looooo`07oiRHV?lQ8B7ok^k^ooooool0003oooooo`000003ooooo`03o`00
0?oooooooooo01cooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000001_o
oooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000000kooooo000Coooo
o`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000Eooooo`Oo000000?o
410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000001kooooo00?oMgMgofIVI_ooool0
0_ooool01Ol0003ooooooooooooooooo000001kooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000001kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000007Oooool00omgMgOoIVIVo`000002ooooo`05o`000?oooooo
ooooooooool000007Oooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool00000
6oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool001Co
oooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@01cooooo1Ol000000ooo
oooo410@ooooo`02ooooo`03oa0@4?oooooooooo01gooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01cooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@01kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41007_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@oooooooo
ool07?ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41007?ooool00omg
MgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41003_ooool001Cooooo00?ok^k^odA4
A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00Go410@oiRHV?oooooo^[Zjo`00
0002ooooo`Go000000?oMgMgooooooooool06Oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0Nooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg01[ooooo00Go0000okZj^_ooooooV9RHo`000003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL06oooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0Looooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>
ooooo`005Oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06_ooool0
1OnYZJWo410@o`000?l@413oZJVY00?ooooo00Cok^k^oc8b<_l0003o<S8b1?l0000Hooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01cooooo00?oEEEEofIV
I_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01kooooo00?o0000ooooooooool07oooool0
0omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06_ooool01OnHV9So410@o`00
0?l0003oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@
4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo00?oMgMgo`000?ooool00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo001:ooooo`Co0000Ioooool2o`0004Wooooo00?o0000
ooooooooool0IOooool004kooooo1Ol0001Rooooo`03o`000?oooooooooo04Oooooo00?o0000oooo
ooooool0I_ooool005?ooooo1?l0001Nooooo`03o`000?oooooooooo04Oooooo00?o0000oooooooo
ool0I_ooool005Oooooo1Ol0001Iooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0
Ioooool005cooooo1ol0001Booooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0Iooo
ool001Koooooool00010o`0001?ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00_ooool5o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aoooo
o`005_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool01oooool3o`0001_ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool04Oooool007;ooooo1?l0000oooooo`03o`00
0?oooooooooo04Cooooo00?o0000ooooooooool0JOooool007Kooooo0ol0000looooo`03o`000?oo
oooooooo04Cooooo00?o0000ooooooooool0JOooool007Wooooo1?l0000hooooo`;o0000A?ooool0
0ol0003oooooooooo`1Zooooo`00OOooool3o`0003Gooooo00?o0000ooooooooool0@oooool00ol0
003oooooooooo`1Zooooo`00P?ooool3o`0003;ooooo00?o0000ooooooooool05Oooool7o`0002Oo
oooo00?o0000ooooooooool0J_ooool008?ooooo1?l0000>ooooo`_o00005Oooool00ol0003ooooo
ooooo`0Cooooo`;o00001oooool2o`0002Cooooo00?o0000ooooooooool0Joooool008Oooooo3_l0
000;ooooo`Co00004Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`1[ooooo`00Y?ooool2o`0000oooooo0_l0000C
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1[
ooooo`00Y_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo06_ooooo002Wooooo`;o
00003?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`1/ooooo`00ZOooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo06cooooo002Zooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0K?oo
ool00:_ooooo00?o0000ooooooooool01oooool2o`0000kooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo06gooooo002/ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool0KOooool00:gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`1]ooooo`00[_ooool2o`0000Gooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0K_ooool00;3ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`1^ooooo`00/Oooool01?l0003ooooooooooooo
ool2o`0000Wooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo06kooooo002booooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo06oooooo002Booooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
0oooool00ol0003oooooo`000007ooooo`;o00007Oooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo06oooooo002Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo
00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00?ooooo0ol00003ooooo`?o
00008?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo06oooooo002Booooo`05oa0@
4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooool000000ol0000Rooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0L?ooool009;ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo00?oMgMgoc8b<_ooool01?ooool3o`0002Gooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`1`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_oo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo073ooooo002Booooo`05oa0@4?oooooooooooooo
ool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo077ooooo002Booooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0LOooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo077ooooo002eooooo`;o0000:?ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo07;ooooo002eooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`1booooo`00]Oooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool0L_ooool00;Gooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo07?ooooo002eooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1cooooo`00]Oooool2
o`0002[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1cooooo`00]Oooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0M?ooool00;Go
oooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo07Co
oooo002eooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`1dooooo`00]Oooool2o`0002cooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`1eooooo`00]Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0MOooool00;Gooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo07Gooooo002eooooo`03o`000?oooooooooo02cooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`1fooooo`00]Oooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0Moooool00;Gooooo0_l0000^ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0Moooool00;Gooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo07Sooooo002eooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1hooooo`00V_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00;ooooo0_l0001jooooo`00V_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool0<?ooool4o`0007cooooo002Jooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`03ooooo`?o0000<Oooool2o`0007gooooo002Jooooo`05o`000?oooooooooo
ooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Joooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_oo
ool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?oo
ool009;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooo
oooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`?o0000/?oo
ool009;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?oo
ooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3o
oooo002Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00:_ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooo
oooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool00:go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003ooooo
ooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000ooooooooool0^?ooool00:gooooo00?o0000
ooooooooool0^?ooool00:gooooo00?o0000ooooooooool0^?ooool00:_ooooo00?oEEEEofIVI_l0
0000^_ooool00?ooooooJOooool00;?ooooo00?o0000okZj^_ooool0/_ooool00;?ooooo0_lb<S:c
ooooo`00Q?ooool2o`000006oa0@4?oooooooooooa0@4?l0003o410@5oooool5o`0000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003o
A4A4okZj^P0Jooooo`03o`000?o^k^kooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1loooo
o`00QOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l00009ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?oc<c<
o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000;ooooo`03oeEEEOnY
ZJWooooo00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1looooo`00QOooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo01Oooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooo
oooooooo410@01;ooooo00?o0000ooooooooool07?ooool00onYZJWoEEEEooooo`03ooooo`05oa0@
4?ooooooooooooooool@4100O?ooool008Gooooo00Ko0000oooooom4A4CoA4A4ooooool00009oooo
o`Ko00002oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000004_ooool0
0ol0003oooooooooo`0;ooooo`Ko00003?ooool00olQ8B7oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000O?ooool008Gooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Kooooo`03ogMg
MomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo01go
oooo00?oEEEEolc<c?ooool00_ooool01Ol0003ooooooooooooooooo000007cooooo0025ooooo`06
o`000?n7QhOoZJVYokZj^_mEEEGo00007?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o
410@ooooooooool03_ooool00ol@413o0000o`000003o`0001cooooo00?oZJVYogMgMoooool00_oo
ool01Ol@413ooooooooooooooooo410@07cooooo0025ooooo`06o`000?lb<S;ooooooooooolb<S;o
00006?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0B
ooooo`03o`000?oooooooooo01[ooooo00Go410@oooooooooooooooooc8b<P03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0O?ooool008Cooooo00?o410@o`000?n7QhL00_ooool00on7QhOo0000oa0@
400Gooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;o
oooo00?o0000ooooooooool06_ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1loooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(80) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .26378 m
.04057 .27065 L
.08481 .27794 L
.12636 .28622 L
.16632 .29512 L
.18687 .29873 L
.19838 .30025 L
.20885 .30137 L
.21943 .30231 L
.23065 .30327 L
.24023 .30426 L
.25078 .30576 L
.26081 .30774 L
.2716 .31057 L
.29111 .31754 L
.31181 .32635 L
.32274 .33048 L
.32875 .33231 L
.33169 .33307 L
.3344 .33366 L
.337 .33415 L
.33985 .33457 L
.34123 .33474 L
.34271 .33489 L
.34428 .33501 L
.34504 .33505 L
.34574 .33508 L
.34706 .33513 L
.34776 .33514 L
.3485 .33515 L
.34974 .33514 L
.35112 .3351 L
.35233 .33504 L
.35365 .33496 L
.35602 .33474 L
.35846 .33443 L
.36112 .33401 L
.36649 .33288 L
.37609 .3302 L
.38669 .32684 L
.39668 .32406 L
.39937 .32347 L
.40221 .32295 L
.4037 .32273 L
.40533 .32253 L
.40682 .32239 L
.40748 .32234 L
.40821 .32229 L
.40956 .32223 L
.41085 .32221 L
Mistroke
.4121 .32222 L
.41326 .32226 L
.41464 .32235 L
.41589 .32246 L
.41733 .32264 L
.41868 .32286 L
.42122 .32339 L
.42359 .32404 L
.42896 .3261 L
.4342 .32892 L
.43981 .33283 L
.44996 .34214 L
.45922 .35259 L
.46978 .36553 L
.48099 .37824 L
.4856 .3825 L
.49056 .38613 L
.4934 .38768 L
.49464 .38822 L
.496 .38872 L
.49729 .38909 L
.49849 .38935 L
.49976 .38953 L
.50111 .38962 L
.50243 .3896 L
.50309 .38955 L
.50383 .38946 L
.50512 .38922 L
.50633 .38891 L
.50776 .38843 L
.50906 .38788 L
.51198 .38627 L
.5145 .38449 L
.51725 .38216 L
.52224 .37698 L
.54141 .35001 L
.5521 .33419 L
.56215 .32152 L
.56719 .31649 L
.57262 .31232 L
.57556 .31068 L
.57716 .30998 L
.57866 .30946 L
.57994 .30911 L
.5813 .30884 L
.58208 .30874 L
.58282 .30868 L
.5842 .30866 L
.5854 .30873 L
.5867 .30892 L
Mistroke
.58793 .30919 L
.58905 .30953 L
.59036 .31003 L
.59178 .3107 L
.59439 .3123 L
.5971 .31447 L
.59999 .31737 L
.60518 .32416 L
.61042 .33309 L
.61534 .34345 L
.62455 .36764 L
.64386 .43022 L
.64915 .44614 L
.65207 .45385 L
.65482 .46025 L
.65739 .46528 L
.66017 .46962 L
.6614 .47113 L
.66271 .47245 L
.66382 .47334 L
.66505 .47407 L
.66637 .47454 L
.66704 .47466 L
.66777 .47469 L
.66905 .47451 L
.67025 .47406 L
.67098 .47366 L
.67167 .47319 L
.67296 .47208 L
.67435 .47054 L
.67586 .4685 L
.68114 .45839 L
.686 .44554 L
.70813 .36732 L
.71763 .33544 L
.72784 .30721 L
.73904 .28376 L
.74952 .26808 L
.75505 .26184 L
.76017 .25711 L
.76626 .25261 L
.77177 .24942 L
.77669 .24714 L
.782 .24517 L
.78761 .24355 L
.79288 .24238 L
.79807 .24153 L
.8029 .24097 L
.80567 .24074 L
.8082 .24057 L
Mistroke
.8096 .2405 L
.81112 .24044 L
.81255 .2404 L
.81387 .24037 L
.81514 .24035 L
.81651 .24034 L
.8178 .24033 L
.81898 .24034 L
.82036 .24035 L
.82115 .24036 L
.82187 .24037 L
.82462 .24043 L
.82751 .24053 L
.83013 .24063 L
.83601 .24092 L
.84653 .24163 L
.85621 .2425 L
.87807 .24498 L
.91952 .25056 L
.95937 .2568 L
1 .26378 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0GOooool>o`0004Go
oooo002Booooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Hooooo`Go00003_ooool8o`00
03gooooo002Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7o
c<c<00Cooooo1?l00006ooooo`;o0000EOooool4o`0001_ooooo1_l0000gooooo`00]Oooool00ol0
003oooooooooo`1Cooooo`03o`000?oooooooooo02?ooooo1ol0000`ooooo`00]Oooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo02_ooooo1_l0000Zooooo`00]Oooool00ol0003ooooo
ooooo`1Aooooo`03o`000?oooooooooo03;ooooo1ol0000Sooooo`00]Oooool00ol0003ooooooooo
o`1?ooooo`;o0000??ooool6o`0001gooooo002eooooo`;o0000Coooool00ol0003oooooooooo`12
ooooo`Oo00005_ooool001Kooooo1?l0002Kooooo`03o`000?oooooooooo04gooooo00?o0000oooo
ooooool0B_ooool3o`0001?ooooo000Eooooo`;o000000?o410@ooooooooool01ol0000Iooooo`05
oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo1Ol00003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o
0000oc8b<_o^k^hNooooo`03o`000?oooooooooo01oooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^6_ooool5o`0000;ooooo00Ko0000onk^k_lb<S;o0000oc8b<_o^k^hKoooo
o`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo0_l0
00002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0>ooooo`005_ooool00ol0003o
ooooooooo`02ooooo`06ogMgMonHV9SooooooiRHV?mgMgOooooo1ol0000Booooo`05oa0@4?nj^[[o
ooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
0_ooool01_l0003oMgMgoiRHV?ooooooV9RHogMgMa_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03_ooool000_ooooo1_l00002ooooo`Go00000oooool01Ol@413ooooooooo
oooooooo410@00Sooooo1ol00003ooooo`Ko00001_ooool01Ol0003ooooooooooooooooo410@00?o
oooo00?o410@ooooooooool04Oooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@01?ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@400Nooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@01_ooooo00?oV9RHob4Q8Oo^k^h00_ooool00ol0003ooooooa0@
4003ooooo`03oa0@4?oooooooooo01gooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@
4?oooooooooo01Wooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41003_ooool001?ooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000000oooooo1Ol00009oooo
o`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRHV?lQ8B7o
k^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`00000Nooooo`;o00008_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000007?ooool01?nHV9So8B4Qonk^k_l00002ooooo`05o`000?oooooooooo
ooooool000007_ooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000006ooo
ool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool001?ooooo
00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000001Cooooo1Ol00003oooo
o`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`00000Nooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`00000Nooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000001gooooo00?oMgMgofIVI_l000000_ooool01Ol0003o
oooooooooooooooo000001gooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo
000001_ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000kooooo
000Dooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@400Iooooo`Co0000
00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooo
oooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@01kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41007_ooool01Ol0003ooooooooooooooooo410@00?ooooo
00?o410@ooooooooool07?ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@
41007?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41003_ooool001Co
oooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00?o410@oiRH
V?ooool01?l000001_ooooooMgMgoiRHV?ooooooV9RHogMgMa_ooooo00Go0000okZj^_ooooooV9RH
oa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05o`000?nj^[[ooooooiRHV?l000000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL07?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03_ooool001Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@02ooooo`Go000000?ok^k^ooooooooool06Ooo
ool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Looooo`03
oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Nooooo`03o`000?oooooooooo
01oooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00GoV9RH
oa0@4?l0003o0000olc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool01OnYZJWo410@
o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Mooooo`03ogMgMol0003ooooo
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`00A_ooool4o`0006_ooooo0_l00019oooo
o`03o`000?oooooooooo06Gooooo001:ooooo`Go0000I_ooool00ol0003oooooooooo`17ooooo`03
o`000?oooooooooo06Kooooo001?ooooo`Wo0000GOooool00ol0003oooooooooo`17ooooo`03o`00
0?oooooooooo06Kooooo001Hooooo`[o0000Doooool00ol0003oooooooooo`16ooooo`03o`000?oo
oooooooo06Oooooo001Rooooo`Oo0000C?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooo
oooo06Oooooo000Foooooooo0000@?l0000Cooooo`005_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo0ol00006ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01?ooool2o`0000Cooooo0_l000000ooooooo0000ooooo`06ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017o
oooo000Fooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`07ooooo`?o00006oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool04Oooool007;ooooo0_l00011ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo06Wooooo001d
ooooo`?o00007oooool6o`0001Wooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0JOooool007Oooooo0_l0000Joooo
o`Co00001?ooool3o`0001Oooooo0_l0000Aooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`1Zooooo`00NOooool3o`0001?ooooo1?l0000;ooooo`?o
00005?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`1Zooooo`00O?ooool2o`0000kooooo0ol0000Booooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool0J_ooool007kooooo3_l0000Fooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool0Joooool00:?ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`1[ooooo`00Y?ooool00ol0003oooooooooo`0>ooooo`;o00003Oooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0Joooool00:Go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1[ooooo`00Y_ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo06cooooo002Wooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool0K?ooool00:Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1/
ooooo`00Z?ooool00ol0003oooooooooo`0:ooooo`;o00002_ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0KOooool00:Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`1]ooooo`00Z_ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo06gooooo002[ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0K_oo
ool00:cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1^ooooo`00[Oooool00ol0
003oooooooooo`05ooooo`;o00001oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool0K_ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`1^ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go
00001?ooool01Om4A4Co0000o`000?lb<S;o000000Gooooo00?o0000ooooooooool00oooool2o`00
027ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1_ooooo`00T_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool0
0omgMgOo0000ooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo06oooooo002Booooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`?o00000oooool01Ol0003ooooooooooooo
oooo000002Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1_ooooo`00T_ooool0
1Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool01?mgMgOo<S8boooo
ooooool2o`000003ooooool0003o000000?o00009Oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo073ooooo002Booooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIV
ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool4o`0002Oooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`1`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1`ooooo`00T_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
073ooooo002Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7o
c<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`1aooooo`00]Oooool2o`0002Wooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1aooooo`00]Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool0LOooool00;Gooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo07;ooooo002eooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`1booooo`00]Oooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0L_ooool00;Gooooo0_l0000[oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool0L_ooool00;Gooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo07?ooooo002eooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1cooooo`00]Ooo
ool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Looo
ool00;Gooooo0_l0000/ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Loooool0
0;Gooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
07Cooooo002eooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`1dooooo`00]Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0M?ooool00;Gooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo07Gooooo002eooooo`;o0000;Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo07Gooooo002eooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`1eooooo`00]Oooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0MOooool009[ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07Kooooo002Jooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0M_ooool009[o
oooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0000^oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0M_ooool009[ooooo00Go0000oooooooo
ooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo07Oooooo002Jooooo`05o`000?oooooooooooooo
ool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo07Sooooo002Jooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo033ooooo0_l00002
ooooo`03o`000?oooooooooo07Wooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo0ol0001looooo`00V_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46
ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`
ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooo
ooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`
ooooo`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00Go410@
oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`2`ooooo`00T_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
/?ooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo
00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00Zoooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooo
ooooool0/?ooool00:gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2`ooooo`00
[Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;3ooooo002]ooooo`03o`000?oo
oooooooo00Gooooo0ol0002`ooooo`00[Oooool00ol0003oooooooooo`2hooooo`00[Oooool00ol0
003oooooooooo`2hooooo`00[Oooool00ol0003oooooooooo`2hooooo`00Zoooool00omEEEGoIVIV
o`00002jooooo`00oooooomYooooo`00/oooool00ol0003o^[Zjooooo`2booooo`00/oooool2oc8b
<[?ooooo0024ooooo`;o000000Ko410@oooooooooooo410@o`000?l@410Gooooo`Go00000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`00
0?m4A4Co^[Zj01Sooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h0O?ooool008Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko
00002Oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`03olc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002Ooo
ool01OlQ8B7oV9RHoooooonHV9So8B4Q00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1looooo`00
QOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Oooooo00?oV9RHob4Q8Oo^k^h0
1?ooool01Ol@413ooooooooooooooooo410@01;ooooo00?o0000ooooooooool06_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@401looooo`00QOooool01_l0
003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000;ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go
0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo00_ooooo1_l00009ooooo`05oc8b
<_nHV9SooooooiRHV?lb<S800oooool01Ol0003ooooooooooooooooo000007cooooo0025ooooo`06
o`000?oMgMgo<S8boeEEEOoMgMgo00006oooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooo
ooooooooool000004_ooool00ol0003oooooooooo`0Jooooo`05olc<c?l0003o0000o`000?o<c<`0
0oooool01Ol0003ooooooooooooooooo000007cooooo0025ooooo`06o`000?n7QhOoZJVYokZj^_mE
EEGo00007?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool03_ooool0
0ol@413o0000o`000003o`0001Wooooo00Go410@okZj^_oooooo^[Zjoa0@4003ooooo`05oa0@4?oo
ooooooooooooool@4100O?ooool008Gooooo00Ko0000oc8b<_oooooooooooc8b<_l0000Hooooo`05
o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000
ooooooooool06_ooool01Ol0003o^[Zjoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`1looooo`00Q?ooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Oooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003o
ooooooooo`0Jooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^07cooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(90) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .26669 m
.04057 .27231 L
.08481 .28015 L
.10632 .2851 L
.12636 .28988 L
.14567 .29373 L
.15648 .29536 L
.16116 .29592 L
.16632 .29643 L
.17139 .29681 L
.17398 .29696 L
.17677 .2971 L
.17937 .29721 L
.18175 .29728 L
.18642 .2974 L
.1919 .29748 L
.19774 .29757 L
.20058 .29762 L
.20325 .29768 L
.20568 .29774 L
.20824 .29783 L
.21062 .29792 L
.21323 .29805 L
.21782 .29835 L
.22318 .29883 L
.22818 .29944 L
.23367 .30033 L
.23868 .30136 L
.24994 .30456 L
.26035 .30859 L
.26998 .3131 L
.29178 .32449 L
.30121 .32899 L
.30616 .33099 L
.31137 .33273 L
.31415 .33347 L
.31719 .33412 L
.31853 .33435 L
.31996 .33456 L
.3213 .33472 L
.32253 .33483 L
.32389 .33492 L
.3246 .33495 L
.32535 .33497 L
.32662 .33498 L
.32734 .33497 L
.32802 .33495 L
.32928 .3349 L
.33042 .33481 L
.33175 .33469 L
Mistroke
.33301 .33453 L
.33574 .3341 L
.3383 .33356 L
.3431 .33223 L
.35384 .32802 L
.37316 .31834 L
.38344 .31375 L
.38862 .312 L
.39155 .31124 L
.39286 .31096 L
.39429 .31069 L
.3956 .3105 L
.39681 .31035 L
.39797 .31025 L
.39919 .31018 L
.40029 .31015 L
.40132 .31016 L
.40245 .3102 L
.40366 .31028 L
.40488 .31041 L
.40621 .31059 L
.40761 .31085 L
.4089 .31114 L
.41122 .3118 L
.4137 .31269 L
.41931 .31549 L
.42448 .31903 L
.43015 .32401 L
.43615 .33049 L
.45732 .36078 L
.46726 .3758 L
.47273 .38307 L
.47792 .3888 L
.48274 .39283 L
.48405 .39368 L
.48546 .39446 L
.48667 .39503 L
.48798 .39552 L
.48915 .39586 L
.49023 .39608 L
.49126 .39622 L
.49234 .39627 L
.49353 .39623 L
.49464 .3961 L
.49586 .39584 L
.49716 .39545 L
.49845 .39493 L
.49987 .39422 L
.50274 .39233 L
.50541 .39007 L
Mistroke
.5079 .38752 L
.51955 .3711 L
.5407 .3331 L
.55161 .31558 L
.55699 .30836 L
.56197 .30268 L
.56686 .29818 L
.57128 .29508 L
.57381 .29376 L
.57619 .29282 L
.5775 .29244 L
.57871 .29218 L
.58003 .29198 L
.5807 .29192 L
.58143 .29189 L
.5828 .29191 L
.58407 .29202 L
.58473 .29213 L
.58546 .29227 L
.58694 .29266 L
.58824 .29312 L
.58963 .29373 L
.59216 .29517 L
.59464 .297 L
.59726 .29938 L
.60193 .30485 L
.60737 .31326 L
.61242 .32313 L
.6239 .35306 L
.64358 .42251 L
.65395 .45715 L
.65917 .47027 L
.66214 .47584 L
.66347 .47782 L
.66492 .47962 L
.6657 .48042 L
.66642 .48106 L
.66718 .48161 L
.66786 .48201 L
.66916 .48252 L
.67054 .48269 L
.67132 .48261 L
.67204 .48243 L
.67283 .48211 L
.67366 .48164 L
.67506 .48054 L
.67659 .47889 L
.67928 .4749 L
.68216 .46919 L
.68734 .45557 L
Mistroke
.70851 .37745 L
.71923 .33936 L
.73087 .30642 L
.74186 .28369 L
.74675 .27588 L
.75201 .26884 L
.75731 .26304 L
.76216 .2587 L
.77167 .25243 L
.77697 .24994 L
.78277 .24784 L
.78824 .24633 L
.79332 .24527 L
.79865 .24445 L
.80165 .24411 L
.80441 .24387 L
.80683 .2437 L
.80949 .24357 L
.81083 .24353 L
.81157 .24351 L
.81226 .24349 L
.81362 .24347 L
.81486 .24346 L
.81598 .24345 L
.81721 .24346 L
.8185 .24347 L
.81972 .24349 L
.82084 .24351 L
.82188 .24353 L
.82421 .2436 L
.82917 .24381 L
.83439 .24408 L
.84441 .24475 L
.85511 .24567 L
.87439 .24785 L
.91795 .25386 L
.95992 .26058 L
1 .26669 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo05gooooo3Ol00016ooooo`00T_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2
o`0005Wooooo1Ol0000=ooooo`So0000?_ooool00;Gooooo00?o0000ooooooooool0E?ooool4o`00
01[ooooo1ol0000gooooo`00]Oooool00ol0003oooooooooo`1Booooo`;o00009Oooool7o`00033o
oooo002eooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0;?ooool6o`0002[ooooo
002eooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0<oooool7o`0002?ooooo002e
ooooo`;o0000D?ooool00ol0003oooooooooo`0kooooo`Ko00007Oooool00;Gooooo00?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`12ooooo`Oo00005_ooool001Gooooo2Ol000000olb<S;o
k^k^ooooo`0Iooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01_ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool4o`000008oa0@4?oo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^hNooooo`03o`000?oooooooooo01oooooo1?l000002?l@
413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^6_ooool5o`0000?ooooo00Go0000oc8b<_l0003o
<S8bonk^kP0Kooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01gooooo0_l000002Ol@413o0000o`000?l0003ok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`00
5_ooool00ol0003oooooooooo`02ooooo`03ogMgMonHV9Sooooo00So00005?ooool01Ol@413o^[Zj
oooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01OnHV9So8B4Qonk^k_ooooooA4A4
00?ooooo00Go0000oiRHV?ooooooV9RHogMgM`0Kooooo`05oa0@4?nj^[[oooooogMgMolb<S800ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00kooooo000;ooooo`Ko00000_ooool5o`0000?ooooo00Go410@oooooooooooo
oooooa0@4006ooooo`Go00001oooool6o`0000Kooooo00Go0000oooooooooooooooooa0@4003oooo
o`03oa0@4?oooooooooo017ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooo
oooooooooooooa0@400Cooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41007_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@400Kooooo`03oiRHV?lQ8B7ok^k^00?ooooo00?o0000oa0@4?ooool0
0_ooool00ol@413oooooooooo`0Mooooo`05o`000?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`0Iooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00kooooo000Cooooo`04
odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000;ooooo`Go00003Oooool0
0onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00onHV9So8B4Qonk^
kP03ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000007_ooool2o`0002;ooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000001cooooo00OoV9RHob4Q8Oo^k^koooooo`000?oooooo000000?ooooo00?o
0000ooooooooool07?ooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool00000
6oooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool001?o
oooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo0000013ooooo1?l00008
ooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03ogMgMomV
IVKooooo00;ooooo00Go0000ooooooooooooooooo`00000Nooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`00000Nooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000001gooooo00KoMgMgofIVI_oooooo0000ooooool0
0003ooooo`03o`000?oooooooooo01_ooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooo
oooooooo000001_ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo0000
00kooooo000Dooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@400Doooo
o`?o00001_ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41007oooool0
1Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool07?ooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41007_ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Nooooo`;o00000_ooool01Ol@413o
oooooooooooooooo410@01kooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo
410@01cooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00kooooo000D
ooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Gooooo`Go000000?o
oooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj^_oooooo
V9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`06o`000?nj^[[ooooooiRHV?l@413o
00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@oiRHV?oooooo^[Zjo`000003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03_ooool001Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^01[ooooo00?oZJVYoa0@4?l000001Ol000001Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool0
0omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07_ooool00ol0003ooooooooo
o`0Oooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Jooooo`05oiRH
V?l@413o0000ob4Q8Ol000000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00GoZJVYoa0@
4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Oooool00omgMgOo0000oooo
o`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool004;ooooo1Ol0001^ooooo`;o00005Ooo
ool6o`0002oooooo00?o0000ooooooooool0I?ooool004Oooooo3ol0001Oooooo`03o`000?oooooo
oooo01?ooooo0_l00005ooooo`;o0000;?ooool00ol0003oooooooooo`1Uooooo`00E_ooool<o`00
05?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool0I_ooool006;ooooo0ol0001@ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo06Ko
oooo001Uooooo`?o0000COooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`1Wooooo`005_ooooooo`00043o00004ooo
ool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`;o00001oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
1?l0003oooooooooooooool:o`0000;ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool2o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Aooooo`005_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool01_ooool2o`0001gooooo1?l0000:ooooo`;o00006?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo017ooooo001`ooooo`03o`000?oooooooooo01Sooooo0ol0000?oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0J?ooool0077ooooo0_l0000Fooooo`;o
00004oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo06Sooooo001cooooo`?o0000
4Oooool2o`0001Kooooo00?o0000ooooooooool04oooool2o`0000gooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo06Wooooo001fooooo`03o`000?oo
oooooooo00cooooo0_l0000Iooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0JOoo
ool007Oooooo0_l0000;ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`1Yooooo`00NOooool;o`0001gooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`1Yooooo`00X_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo06[o
oooo002Sooooo`03o`000?oooooooooo00oooooo0_l0000:ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Zooooo`00Xoooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo06[ooooo002Tooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool0Joooool00:Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1[oooo
o`00YOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo06_ooooo002Vooooo`03o`00
0?oooooooooo00cooooo0_l00007ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`1/ooooo`00Y_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo06cooooo002Wooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0K?ooool0
0:Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1]ooooo`00Z?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo06gooooo002Yooooo`03o`000?oooooooooo00Wooooo
0_l00004ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`1]ooooo`00Z_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo06kooooo002B
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00003ooooo`06o`000?m4
A4Co0000o`000?lb<S;ogMgM1Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1^ooooo`00T_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01?ooool01Ol0
003ooooooooooomgMgOo<S8b00Gooooo00Go0000ooooooooooooooooo`00000Uooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0K_ooool009;ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00Co0000oooooooooooo00001Oooool01?l0003ooooo
ooooool0000Vooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0K_ooool009;ooooo
00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ogMgMolb
<S801Oooool3o`0002Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1_ooooo`00
T_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o
8B4Qo`000?l0003oc<c<00Gooooo00?o0000ooooool00000:?ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo06oooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooooooo`;o00000oooool3o`0002Wooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`1_ooooo`00T_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00?ooooo1Ol0
000Zooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Koooool009;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo073ooooo
002eooooo`;o0000:_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo073ooooo002e
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1`
ooooo`00]Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0L?ooool00;Gooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo077ooooo002eooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`1aooooo`00]Oooool2o`0002cooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`1aooooo`00]Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool0LOooool00;Gooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo077ooooo002eooooo`03o`000?oooooooooo02_o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1booooo`00]Oooool2o`0002gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`1booooo`00]Oooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0L_ooool00;Gooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo07;ooooo002eoooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1coooo
o`00]Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0Loooool00;Gooooo0_l0000^ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
Loooool00;Gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo07?ooooo002eooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`1dooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0M?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`1dooooo`00V_ooool01Ol@413ooooooooooooo
oooo410@013ooooo00?o0000ooooooooool00oooool3o`0002oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`1eooooo`00V_ooool01Ol0003ooooooooooooooooo000000oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0MOooool009[ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0M_ooool009[ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo07Kooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1gooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000
<_ooool01Ol0003ooooooooooooooooo000007[ooooo002eooooo`03o`000?oooooooooo03;ooooo
1?l0001jooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Ko
oooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3o
oooo002Booooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009;ooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`000;3o
oooo002Booooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413o
oooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo0;3ooooo002Booooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@
413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`
ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool0
0ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002[ooooo`Co000000?o410@ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;3ooooo002]
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool00:gooooo00?o0000oooo
ooooool01Oooool3o`000;3ooooo002]ooooo`03o`000?oooooooooo0;Sooooo002]ooooo`03o`00
0?oooooooooo0;Sooooo002]ooooo`03o`000?oooooooooo0;Sooooo002[ooooo`03oeEEEOmVIVKo
00000;[ooooo003oooooofWooooo002cooooo`03o`000?nj^[[ooooo0;;ooooo002cooooo`;o<S8b
/oooool008Cooooo0_l000001_l@413oooooooooool@413o0000oa0@41Oooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000
odA4A?nj^[X06?ooool01?l@413o0000odA4A?o<c<`4ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
O?ooool008Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00002Ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03
olc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002oooool00onH
V9So410@omgMg@03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0O?ooool008Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooo
oooooooooooooa0@400Booooo`03o`000?oooooooooo01gooooo00?oQhN7oeEEEOooool00_ooool0
1Ol@413ooooooooooooooooo410@07cooooo0025ooooo`06o`000?ooooooA4A4odA4A?oooooo0000
2Oooool6o`0000_ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000001;o
oooo00?o0000ooooooooool02oooool6o`0000Wooooo00Goc<c<ob4Q8Ol0003oEEEEo`000003oooo
o`05o`000?ooooooooooooooool00000O?ooool008Gooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0
000Kooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`00
0?oooooooooo01[ooooo00Go8B4QohN7QoooooooV9RHo`000003ooooo`05o`000?oooooooooooooo
ool00000O?ooool008Gooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Looooo`05o`000?oooooo
ooooooooool@41000oooool00ol@413oooooooooo`0>ooooo`03oa0@4?l0003o000000?o00006Ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@401looooo`00
QOooool01_l0003o<S8boooooooooooo<S8bo`0001Sooooo00Go0000okZj^_ooooooV9RHoa0@4003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool00ol0003oooooooooo`0Jooooo`05ob4Q8OnH
V9SoooooogMgMomEEED00oooool01OmgMgOoV9RHoooooonHV9SoMgMg07cooooo0024ooooo`03oa0@
4?l0003oQhN700;ooooo00?oQhN7o`000?l@41005oooool01OnHV9So410@o`000?lQ8B7oc<c<00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Booooo`03o`000?oooooooooo01[ooooo00Goc<c<oa0@
4?l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0O?ooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .26801 m
.01975 .27056 L
.04057 .27401 L
.06168 .27859 L
.08481 .28451 L
.09626 .28735 L
.10708 .28979 L
.11762 .29177 L
.12224 .29247 L
.12734 .29309 L
.12971 .29333 L
.13226 .29354 L
.13447 .2937 L
.13687 .29384 L
.13828 .2939 L
.13958 .29395 L
.14093 .294 L
.14215 .29403 L
.14335 .29405 L
.14448 .29407 L
.14568 .29408 L
.14698 .29408 L
.14831 .29408 L
.14955 .29407 L
.15091 .29405 L
.15237 .29403 L
.1539 .29399 L
.15535 .29395 L
.15807 .29386 L
.16829 .29337 L
.17842 .29281 L
.18089 .29269 L
.18354 .29258 L
.18506 .29253 L
.18645 .29249 L
.18779 .29246 L
.18846 .29245 L
.18919 .29244 L
.1905 .29243 L
.19173 .29243 L
.19284 .29244 L
.19403 .29245 L
.19534 .29249 L
.19673 .29253 L
.19791 .29259 L
.19921 .29266 L
.20153 .29282 L
.20403 .29305 L
.20853 .29362 L
.21405 .2946 L
Mistroke
.21917 .29581 L
.23077 .29965 L
.24099 .30433 L
.25187 .31049 L
.27289 .32388 L
.28393 .33001 L
.28949 .33244 L
.29268 .33359 L
.29559 .33445 L
.29841 .3351 L
.30107 .33556 L
.30254 .33574 L
.30389 .33585 L
.3046 .3359 L
.30537 .33593 L
.30619 .33595 L
.30695 .33595 L
.30825 .33592 L
.30961 .33584 L
.31078 .33574 L
.31205 .33559 L
.31343 .33538 L
.3149 .3351 L
.31754 .33446 L
.32298 .33263 L
.32812 .33031 L
.33771 .32477 L
.35699 .31174 L
.36793 .30516 L
.37328 .30258 L
.37816 .30072 L
.38064 .29999 L
.38194 .29967 L
.38334 .29937 L
.38455 .29916 L
.38588 .29898 L
.3871 .29885 L
.38824 .29878 L
.38957 .29874 L
.39023 .29875 L
.39096 .29877 L
.39225 .29884 L
.39345 .29896 L
.39418 .29906 L
.39487 .29917 L
.39617 .29942 L
.39907 .30019 L
.40175 .30118 L
.40458 .30251 L
.40967 .30567 L
Mistroke
.41515 .31019 L
.42118 .31651 L
.43183 .33096 L
.44157 .34721 L
.45295 .36788 L
.4635 .3855 L
.46847 .3922 L
.47316 .39711 L
.47575 .39916 L
.47712 .40002 L
.47856 .40077 L
.47977 .40127 L
.48111 .40167 L
.48232 .40191 L
.48345 .40202 L
.4848 .402 L
.48557 .40192 L
.48627 .4018 L
.48757 .40147 L
.48895 .40096 L
.49018 .40037 L
.49133 .3997 L
.49396 .39776 L
.49678 .39507 L
.49938 .39207 L
.50521 .38371 L
.52678 .34184 L
.53729 .32131 L
.54684 .3054 L
.55162 .2987 L
.5568 .2925 L
.56128 .28806 L
.5662 .28418 L
.56872 .28261 L
.57143 .28126 L
.57292 .28066 L
.57429 .28021 L
.57566 .27984 L
.57696 .27959 L
.57815 .27943 L
.57942 .27934 L
.58062 .27933 L
.58171 .27939 L
.58299 .27954 L
.58437 .2798 L
.58568 .28015 L
.58688 .28055 L
.58947 .2817 L
.59183 .28309 L
.59714 .28747 L
Mistroke
.60205 .29313 L
.6067 .30001 L
.61711 .32117 L
.62841 .35368 L
.64882 .42985 L
.65441 .44982 L
.66043 .4678 L
.66334 .47466 L
.66611 .47983 L
.6686 .48326 L
.67 .48466 L
.67131 .48559 L
.67266 .48619 L
.6739 .4864 L
.67527 .48627 L
.67595 .48605 L
.67671 .4857 L
.67798 .48484 L
.67934 .48356 L
.68179 .4803 L
.68435 .4757 L
.68676 .47028 L
.6913 .45766 L
.71262 .37747 L
.72275 .34139 L
.73351 .31059 L
.7427 .29068 L
.75285 .27459 L
.75801 .26841 L
.76344 .26314 L
.77315 .25628 L
.77857 .25359 L
.78361 .25163 L
.78914 .24996 L
.79505 .24863 L
.79776 .24815 L
.80064 .24772 L
.80313 .24741 L
.8058 .24714 L
.80866 .24692 L
.81135 .24678 L
.81298 .24672 L
.81379 .24669 L
.81454 .24667 L
.81527 .24666 L
.81593 .24665 L
.81667 .24664 L
.81745 .24664 L
.81878 .24663 L
.81945 .24664 L
Mistroke
.82018 .24664 L
.82148 .24666 L
.82269 .24669 L
.82542 .24677 L
.82835 .24688 L
.83372 .24715 L
.83861 .24746 L
.85868 .24924 L
.87001 .25065 L
.88049 .25211 L
.92176 .25826 L
.96144 .26366 L
1 .26801 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000Goooool;
o`0004Oooooo002eooooo`03o`000?oooooooooo05Sooooo1_l0000;ooooo`Wo0000?_ooool00;Go
oooo00?o0000ooooooooool0EOooool3o`0001[ooooo2?l0000fooooo`00]Oooool00ol0003ooooo
ooooo`1Dooooo`03o`000?oooooooooo02?ooooo1ol0000_ooooo`00]Oooool00ol0003ooooooooo
o`1Cooooo`03o`000?oooooooooo02_ooooo1_l0000Yooooo`00]Oooool2o`0005?ooooo00?o0000
ooooooooool0<_ooool7o`0002;ooooo002eooooo`03o`000?oooooooooo053ooooo0_l0000loooo
o`Wo00006Oooool001Gooooo1Ol000001_ooooook^k^oc8b<_l0003o<S8bonk^kQ[ooooo00GoV9RH
oa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool5o`0000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Looooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o
<S8bonk^kQkooooo00?o0000ooooooooool07oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o
0000oc8b<_o^k^hJooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00GoV9RH
oa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Oooool6o`000005onk^
k_lb<S;o0000oc8b<_o^k^h03_ooool001Kooooo00Co0000oooooooooooooooo1ol0000Iooooo`05
oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOo0000oooooonHV9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMg
oc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03_ooool000_ooooo1_l00002ooooo`Go00000oooool01_l@413o
oooooooooooooooo410@ooooo`Ko00002oooool6o`0000Kooooo00Go0000oooooooooooooooooa0@
4003ooooo`03oa0@4?oooooooooo017ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go
410@oooooooooooooooooa0@400Cooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41007_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@400Kooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go0000oooo
oooooooooooooa0@400Oooooo`05o`000?ooooooooooooooool@41000oooool00ol@413ooooooooo
o`0Iooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00kooooo000Cooooo`04odA4A?oM
gMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`000007ooooo`Go00004Oooool00onYZJWo
410@ooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00onHV9So8B4Qonk^kP03oooo
o`05o`000?ooooooooooooooool000007_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000007_ooool2o`0002;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000001cooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000001ko
oooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000001_ooooo00CoA4A4omgM
gOoooooo00001?ooool01Ol0003ooooooooooooooooo000000kooooo000Cooooo`04omgMgOmEEEGo
ooooo`0000Cooooo00Go0000ooooooooooooooooo`00000<ooooo`Co00003?ooool00ol@413o0000
okZj^P03ooooo`05o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02ooooo`05
o`000?ooooooooooooooool000007_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000007_ooool00ol0003oooooooooo`0Dooooo`Ko00001oooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000007Oooool01?mgMgOoIVIVooooooooool2o`0000?ooooo
00?o0000ooooooooool06oooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool0
00006oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool0
01Cooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@013ooooo1?l00009
ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@400Oooooo`05o`000?oo
ooooooooooooool@41000oooool00ol@413oooooooooo`0Looooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@400Nooooo`03o`000?oooooooooo017ooooo0ol00006ooooo`;o
00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41007_ooool01Ol0
003oooooo`000?oooooo410@00?ooooo00?o410@ooooooooool07?ooool00onj^[[o8B4Qooooo`02
ooooo`05oa0@4?ooooooooooooooool@41007?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oo
ooooooooooooool@41003_ooool001Cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg01Cooooo0ol00003ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL07_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
7_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool03Ol0003o
^[ZjoooooonHV9So410@ooooool0003oooooogMgMonHV9SooooooiRHV?mgMgL06oooool01Ol@413o
V9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`03onk^k_m4A4Co
000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`005Oooool00omgMgOo0000ooooo`03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h05oooool4o`000004oa0@4?l0003o410@ojVYZ@?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^01cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^01kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`09ooooo`06o`000?oo
oooooooooeEEEOmVIVKo00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00KoV9RHoa0@
4?l0003o8B4Qolc<c?l00002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool01OnYZJWo410@
o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Mooooo`03ogMgMol0003ooooo
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`00>ooooolOo`0005_ooooo0_l0000@oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1Soooo
o`00F_ooool4o`0005Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo02Sooooo00?o0000ooooooooool0I?ooool005kooooo0ol0000]ooooo`So0000
7oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`1Tooooo`00HOooool00ol0003oooooooooo`0Xooooo`;o00002?oo
ool2o`0001gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool0IOooool006;ooooo0_l0000Vooooo`;o00003?ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06Gooooo000Foooooooo0000@?l0000Coooo
o`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`?o00001Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool3o`0000Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo000Fooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02o`0001_ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Dooooo`05o`000?ooooooooooooooool000008Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0Aooooo`00J_ooool00ol0003oooooooooo`0Fooooo`;o00005oooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo06Oooooo001[ooooo`;o00005Oooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0Ioooool006gooooo
0_l0000Aooooo`;o00006oooool00ol0003oooooooooo`0Eooooo`;o00002_ooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0Ioooool006oooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool0J?ooool0073ooooo0_l0000<ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`1Xooooo`00L_ooool4o`0000Cooooo1?l0000Qoooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool0J?ooool007Kooooo1?l0000Vooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool0JOooool00:7ooooo00?o0000ooooooooool0
4Oooool2o`0000Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo06Wooooo002Qooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0JOoo
ool00:;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Yooooo`00X_ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo06[ooooo002Sooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool0J_ooool00:?ooooo00?o0000ooooooooool03oooool2o`0000Cooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo06[ooooo
002Tooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0J_ooool00:Gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`1[ooooo`00YOooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo06_ooooo002Vooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool0Joooool00:Kooooo00?o0000ooooooooool03?ooool2o`0000;ooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo06_ooooo002Wooooo`03o`000?oo
oooooooo00_ooooo00Go0000ooooooooooooooooo`00000Vooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool0K?ooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`000005ooooool0003ooooooooooom4A4@00_l000000olb<S;ogMgMooooo`04ooooo`04
o`000?ooooooooooo`0002Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1/oooo
o`00T_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`07oiRHV?lQ8B7ok^k^
oooooom4A4Coooooo`000005ooooo`03ogMgMolb<S;ooooo00Cooooo00Co0000oooooooooooo0000
9oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo06cooooo002Booooo`05oa0@4?oo
ooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooo`00000Xooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool0K?ooool009;ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00;ooooo00?o0000ooooooooool00_ooool00omgMgOo<S8booooo`04ooooo`?o0000
:Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06gooooo002Booooo`05o`000?oo
ooooooooooooool000003_ooool00omgMgOoIVIVooooo`02ooooo`;o000000Co8B4Qo`000?lb<S;o
c<c<1Oooool2o`0002[ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1]ooooo`00
T_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`1]ooooo`00T_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oo
ooooV9RHoa0@4004ooooo`;o00001_ooool3o`0002_ooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`1^ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c004ooooo`Co00000_ooool2o`0000;ooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo06kooooo002^ooooo`Co00000oooool2o`00
02_ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1^ooooo`00]Oooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0K_ooool00;Gooooo
00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06oooooo
002eooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`1_ooooo`00]Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0Koooool00;Gooooo0_l0000/ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0L?ooool00;Gooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo073ooooo002eooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`1`ooooo`00]Oooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0L?ooool00;Gooooo0_l0000]ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0LOooool00;Gooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo077ooooo002eooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1aooooo`00]Oooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0LOooool00;Gooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo07;ooooo002e
ooooo`;o0000;oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo07;ooooo002eoooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1boooo
o`00]Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0Loooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo07?ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0Loooool009[ooooo00Go410@oooooooooooooooooa0@400@oooo
o`03o`000?oooooooooo00?ooooo0ol0000_ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0M?ooool009[ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
07Cooooo002Jooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo07Gooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1e
ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0MOooool0
09[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`0003;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`1eooooo`00]Oooool00ol0003oooooooooo`0boooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0M_ooool00;Gooooo00?o0000oooooooo
ool0<oooool01?l0003oooooo`000?l0001iooooo`00]Oooool00ol0003oooooooooo`0dooooo`;o
0000N_ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`2`ooooo`00T_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooo
ooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0
002`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00Go
410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`2`ooooo`00T_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0/?ooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00Zoooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0/?ooool00:gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2`oooo
o`00[Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;3ooooo002]ooooo`03o`00
0?oooooooooo00Gooooo0ol0002`ooooo`00[Oooool00ol0003oooooooooo`2hooooo`00[Oooool0
0ol0003oooooooooo`2hooooo`00[Oooool00ol0003oooooooooo`2hooooo`00Zoooool00omEEEGo
IVIVo`00002jooooo`00oooooomYooooo`00[oooool00ol0003o^[Zjooooo`2fooooo`00[oooool2
oc8b<[Oooooo0020ooooo`;o000000Ko410@oooooooooooo410@o`000?l@410Gooooo`Go00000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000
o`000?m4A4Co^[Zj01Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^07Sooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01oooool6o`0000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMg
Mol@41002Oooool6o`0000cooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1hooooo`00POooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo01Oooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooo
oooo410@01;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@07Sooooo0021ooooo`06o`00
0?ooooooA4A4odA4A?oooooo00002Oooool6o`0000_ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0
003ooooooooooooooooo000001;ooooo00?o0000ooooooooool02oooool6o`0000cooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`00001hooooo`00POooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001_ooooo00?oMgMgofIVI_oo
ool00_ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000007Sooooo0021ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo00007?ooool01Ol0003ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool03_ooool00ol@413o0000o`000003o`0001co
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooo
oooooooooooooa0@401hooooo`00POooool01_l0003o<S8boooooooooooo<S8bo`0001Sooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL0N?ooool0083ooooo00?o410@o`000?n7QhL00_ooool00on7
QhOo0000oa0@400Gooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^01;ooooo00?o0000ooooooooool06oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07Sooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(110) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .26912 m
.04057 .27824 L
.06168 .28409 L
.07286 .28702 L
.079 .28843 L
.08481 .28958 L
.09021 .29047 L
.09607 .29123 L
.09866 .29149 L
.1014 .29172 L
.10374 .29188 L
.10632 .29201 L
.10765 .29206 L
.10892 .2921 L
.11006 .29212 L
.1113 .29214 L
.11265 .29215 L
.1134 .29215 L
.11408 .29214 L
.11541 .29213 L
.11667 .2921 L
.11785 .29207 L
.11909 .29202 L
.12132 .29192 L
.12372 .29178 L
.12636 .29159 L
.13707 .29047 L
.14684 .2892 L
.15238 .28849 L
.15825 .28783 L
.16327 .28738 L
.16612 .28718 L
.1674 .28711 L
.1688 .28705 L
.17007 .287 L
.17126 .28697 L
.1725 .28695 L
.17384 .28694 L
.17508 .28694 L
.17625 .28696 L
.17731 .28698 L
.17845 .28702 L
.1797 .28708 L
.18108 .28716 L
.18386 .28738 L
.18643 .28766 L
.18884 .28799 L
.19434 .28903 L
.19935 .29033 L
.20514 .29228 L
Mistroke
.21064 .29458 L
.23148 .30685 L
.2508 .32108 L
.26192 .32875 L
.26738 .3319 L
.27239 .33426 L
.27696 .3359 L
.27927 .33651 L
.28179 .33702 L
.28312 .33721 L
.28433 .33734 L
.28499 .3374 L
.28572 .33744 L
.28704 .33748 L
.28828 .33747 L
.28959 .33741 L
.29071 .33732 L
.29194 .33718 L
.29322 .33698 L
.29442 .33676 L
.29712 .3361 L
.29976 .33526 L
.30257 .33416 L
.3123 .3289 L
.32378 .32047 L
.33421 .31182 L
.34402 .30387 L
.35439 .29665 L
.35981 .29363 L
.36269 .29228 L
.36577 .29105 L
.3686 .29013 L
.37118 .28948 L
.37243 .28923 L
.37378 .28901 L
.37506 .28885 L
.37624 .28874 L
.37748 .28868 L
.37878 .28867 L
.37989 .2887 L
.3811 .28877 L
.38241 .28891 L
.38314 .28902 L
.38381 .28913 L
.38634 .28968 L
.38867 .2904 L
.39121 .29141 L
.39582 .29388 L
.40128 .29789 L
.40706 .30349 L
Mistroke
.41744 .31694 L
.43797 .35417 L
.44716 .37265 L
.45719 .39057 L
.46285 .39837 L
.4656 .40133 L
.4681 .40347 L
.46934 .40433 L
.47068 .40511 L
.47195 .40569 L
.47312 .4061 L
.47436 .40638 L
.47572 .40653 L
.4764 .40653 L
.47714 .40649 L
.47846 .40627 L
.47977 .4059 L
.48097 .40541 L
.48229 .40472 L
.48369 .40381 L
.48605 .40188 L
.48864 .39919 L
.49343 .39285 L
.49792 .38549 L
.51734 .34515 L
.52833 .322 L
.53856 .30345 L
.54875 .28893 L
.55445 .28265 L
.55962 .27811 L
.56509 .27447 L
.56818 .27294 L
.57102 .27187 L
.57222 .27152 L
.57351 .27121 L
.57425 .27106 L
.57493 .27095 L
.57625 .27078 L
.57761 .27068 L
.57838 .27066 L
.57909 .27066 L
.58039 .27073 L
.58178 .27088 L
.58309 .27111 L
.58453 .27144 L
.58603 .2719 L
.58743 .27242 L
.58994 .27359 L
.59262 .27521 L
.59875 .28033 L
Mistroke
.60432 .28686 L
.60954 .29473 L
.61522 .30534 L
.62552 .33057 L
.64593 .40182 L
.65676 .44311 L
.66273 .46252 L
.66568 .47046 L
.66841 .47662 L
.67099 .48122 L
.67231 .4831 L
.67374 .48475 L
.67455 .48551 L
.67531 .48609 L
.67601 .48653 L
.67678 .4869 L
.67813 .48724 L
.67886 .48726 L
.67955 .48719 L
.68087 .48676 L
.68212 .48603 L
.68324 .48509 L
.68446 .48379 L
.6872 .47981 L
.68974 .47489 L
.69434 .46324 L
.69942 .44708 L
.70972 .40829 L
.72044 .36713 L
.73173 .32998 L
.74137 .30526 L
.7469 .29391 L
.75192 .2852 L
.76209 .27164 L
.76768 .26618 L
.77295 .26208 L
.77751 .25923 L
.78235 .25682 L
.78764 .25474 L
.79253 .25326 L
.7977 .25206 L
.80243 .25124 L
.80504 .25089 L
.80789 .25059 L
.81058 .25038 L
.81307 .25024 L
.81428 .25019 L
.81559 .25016 L
.81682 .25013 L
.81796 .25012 L
Mistroke
.81898 .25011 L
.82011 .25012 L
.82129 .25013 L
.82238 .25015 L
.82367 .25018 L
.82489 .25022 L
.82717 .25032 L
.8323 .25061 L
.84245 .25142 L
.85323 .25251 L
.87259 .25497 L
.91227 .26004 L
.95452 .264 L
.99518 .26839 L
1 .26912 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0H?ooool7o`0004Wooooo002eooooo`03o`000?oooooooooo05Wo
oooo1ol00007ooooo`_o0000?_ooool00;Gooooo00?o0000ooooooooool0F?ooool00ol0003ooooo
ooooo`0Gooooo`Ko0000>?ooool00;Gooooo00?o0000ooooooooool0EOooool3o`00023ooooo1_l0
000booooo`00]Oooool2o`0005Cooooo0_l0000Yooooo`[o0000:?ooool00;Gooooo00?o0000oooo
ooooool0D_ooool00ol0003oooooooooo`0cooooo`ko00006_ooool001Gooooo1?l00002ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h06_ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01cooooo
1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^7_ooool00ol0003oooooooooo`0O
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQ[ooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_l000006oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0Looooo`Oo000000Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`005_oo
ool00ol0003oooooooooo`05o`000003oiRHV?mgMgOooooo01Wooooo00Go410@okZj^_ooooooMgMg
oc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool01OnHV9So8B4Qonk^k_ooooooA4A4
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo01?ooooo1ol00007ooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@00oooool01OmgMgOoV9RHooooool0003oMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03_ooool000_ooooo1_l00002ooooo`Go00000oooool00ol@413ooooooooo
o`04o`00013ooooo1_l00006ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413ooooo
ooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@
41004oooool6o`0000Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@
01kooooo00?o0000ooooooooool04Oooool3o`0000Kooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41006oooool00onHV9So8B4Qonk^kP04
ooooo`05oa0@4?ooooooooooo`000?l@41007oooool01Ol0003ooooooooooooooooo410@00?ooooo
00?o410@ooooooooool06Oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`00
4oooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000000_ooool4o`00
01Oooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000001gooooo00?oV9RH
ob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000001kooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000001kooooo0_l0000Aooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00007?ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooo0000ooooool000007_ooool00onY
ZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000006oooool01?m4A4CogMgMooooool0
0004ooooo`05o`000?ooooooooooooooool000003_ooool001?ooooo00CogMgMoeEEEOoooooo0000
1?ooool01Ol0003ooooooooooooooooo000000Kooooo0ol0000Cooooo`03oa0@4?l0003o^[Zj00?o
oooo00Go0000ooooooooooooooooo`00000Nooooo`03ogMgMomVIVKooooo00;ooooo00Go0000oooo
ooooooooooooo`00000Nooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
000Nooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03ogMg
MomVIVKooooo00;ooooo0_l00002ooooo`03o`000?oooooooooo01_ooooo00?o410@o`000?nj^[X0
0oooool01Ol0003ooooooooooooooooo000001_ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0
003ooooooooooooooooo000000kooooo000Dooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooo
oooooooooooooa0@4009ooooo`?o00004Oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41007oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0
7?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41007_ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00cooooo00Go0000ooooooooooooooooo`000004oooo
o`05oa0@4?ooooooooooooooool@41007_ooool01_l0003ooooooooooooooooo410@o`0000;ooooo
00?o410@ooooooooool07?ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@
41007?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41003_ooool001Co
oooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo0ol0000;oooo
o`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00go00003_oo
ool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03_ooool01?l0003oooooooooool00004ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL06_ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go0000oiRHV?oooooo
V9RHogMgM`0Kooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9So
MgMg01cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000E
ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0?ooooo`Ko00001Ooo
ool01_nYZJWo410@o`000?l@413oZJVYooooo`Oo00003Oooool3o`0000_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool8o`000005onk^k_lb<S;o
0000oc8b<_o^k^h07_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00oooooo00Co
0000oeEEEOmVIVKo00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c002ooooo`06o`000?o^k^ko<S8bo`000?lb<S;ok^k^6oooool01OnYZJWo410@o`00
0?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Mooooo`03ogMgMol0003ooooo00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`00=Oooool;o`0001Oooooo0_l0000_ooooo`;o
00002?ooool3o`00023ooooo0_l0000=ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`1Rooooo`00FOooool2o`0002_ooooo0_l0000<ooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool0H_ooool005_ooooo0_l0000Wooooo`;o00003ooo
ool2o`0001kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool0H_ooool005gooooo0_l0000Tooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1Sooooo`00Goooool2o`00
027ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
06?ooooo000Foooooooo0000@?l0000Cooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o0000
00?oooooo`000?ooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo000Fooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool09?ooool2o`0001Wooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooo000002?ooooo00Co0000oooooooooooo00009ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo017ooooo001Uooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo06Cooooo001Vooooo`;o00005?ooool2o`0001gooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`1Uooooo`00J?ooool00ol0003oooooooooo`0?ooooo`;o00008?ooool00ol0003o
ooooooooo`0Fooooo`;o00001oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool0IOooool006Wooooo0_l0000=ooooo`;o00008_ooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo06Gooooo001[ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo06Kooooo001/
ooooo`;o00001oooool2o`0002Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1V
ooooo`00K_ooool7o`0002Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Woooo
o`00W_ooool00ol0003oooooooooo`0Dooooo`;o00001?ooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool0Ioooool009oooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`1Wooooo`00Woooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo06Sooooo002Pooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0J?ooool0
0:3ooooo00?o0000ooooooooool04_ooool01Ol0003ooooooooooooooooo000002Gooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`1Xooooo`00XOooool00ol0003oooooooooo`0Aoooo
o`;o00000_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool0JOooool00:7ooooo00?o0000ooooooooool04Oooool01?l0003oooooooooool0000Voooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0JOooool00:;ooooo00?o0000oooooooo
ool04?ooool01?l0003oooooooooool0000Vooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool0JOooool00:?ooooo00?o0000ooooooooool03oooool00ol0003oooooo`00000Xooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool0J_ooool00:?ooooo00?o0000ooooooooool0
3oooool00ol0003oooooo`00000Xooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
J_ooool00:Cooooo00?o0000ooooooooool03_ooool2o`0002Wooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`1Zooooo`00Y?ooool00ol0003oooooooooo`0>ooooo`;o0000:_ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo06[ooooo002Booooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Jooo
ool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^
k_l0003oA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0Joooool009;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`04oiRHV?lQ8B7ok^k^o`0000Sooooo00?o0000ooooooooool00_ooool2o`0002_o
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1[ooooo`00T_ooool01Ol0003ooooo
oooooooooooo000000gooooo00?oV9RHob4Q8Ol000001oooool00omgMgOo<S8booooo`03ooooo`Co
0000:_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo06_ooooo002Booooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVo`000003ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`00oooool00ol0003oooooo`00000/ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0K?ooool009;ooooo00Go410@oooooooooooooooooa0@400?ooooo`;o00000oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooo000002cooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`1/ooooo`00T_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Oo0000okZj
^_ooooooV9RHoa0@4?oooooo000000;ooooo00?o0000ooooooooool01?ooool01?l0003ooooooooo
ool0000/ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0K?ooool009;ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00_ooool00ol0003o
ooooo`000003o`0000;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0K?ooool00:[ooooo0_l00004ooooo`03o`000?oooooooooo00;o
oooo0_l0000/ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0K?ooool00:cooooo
1?l00005ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`1]ooooo`00]Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool0KOooool00;Gooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo06gooooo002eooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`1^ooooo`00]Oooool2o`0002gooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`1^ooooo`00]Oooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0K_ooool00;Gooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo06oooooo002eooooo`03o`000?oooooo
oooo02gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1_ooooo`00]Oooool2o`00
02oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1_ooooo`00]Oooool00ol0003o
ooooooooo`0^ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0L?ooool00;Gooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo073ooooo
002eooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`1`ooooo`00]Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0LOooool00;Gooooo0_l0000`ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0LOooool00;Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo077ooooo002eooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`1aooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0L_ooool009[ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1booooo`00V_ooool01Ol@413ooooo
oooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`00037ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`1booooo`00V_ooool01Ol0003ooooooooooooooooo000000oo
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0L_ooool009[ooooo00Go0000ooooooooooooooooo`00000<ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0Loooool009[ooooo00Go410@oooooooooooooooooa0@400<oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo07?ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`1dooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006oooo
o`;o0000<oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07Cooooo002eooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1eooooo`00
]Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00;o0000Moooool00;Gooooo00?o
0000ooooooooool0=Oooool2o`0007Wooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool009;ooooo00Go410@oooooooooooooooooa0@400=oooo
o`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000ooooooooooooooooo`00000>oooo
o`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002a
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00:_ooooo1?l000000ol@413o
ooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0/?ooool00:gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooo
ooooool0^?ooool00:gooooo00?o0000ooooooooool0^?ooool00:gooooo00?o0000ooooooooool0
^?ooool00:_ooooo00?oEEEEofIVI_l00000^_ooool00?ooooooJOooool00:oooooo00?o0000okZj
^_ooool0]_ooool00:oooooo0_lb<S:gooooo`00P?ooool2o`000006oa0@4?oooooooooooa0@4?l0
003o410@5oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`03ohN7Qol0003o
^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Iooooo`Co000000Co410@oooooooooooooooo
1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^N?ooool0087ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00002Oooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03olc<c?l0003o410@00cooooo00Go
410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1hooooo`00POooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo01Oooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooo
oooooooooooo410@01;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@401hooooo`00POooool01_l0003o
ooooodA4A?m4A4Coooooo`0000Wooooo1_l0000;ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000
ooooooooooooooooo`00000Booooo`03o`000?oooooooooo00_ooooo1_l0000<ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000007Sooooo
0021ooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo00006oooool00omgMgOoIVIVooooo`02ooooo`05
o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000007Sooooo0021oooo
o`06o`000?n7QhOoZJVYokZj^_mEEEGo00007?ooool01Ol0003ooooooooooooooooo410@00?ooooo
00?o410@ooooooooool03_ooool00ol@413o0000o`000003o`0001cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100N?ooool0087ooooo
00Ko0000oc8b<_oooooooooooc8b<_l0000Hooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1hooooo`00P?oo
ool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Oooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Kooooo`03
oeEEEOmVIVKo000000Gooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
07Sooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(120) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .27286 m
.01975 .27861 L
.04057 .28482 L
.05077 .28736 L
.05638 .28852 L
.06168 .28944 L
.06469 .28987 L
.06795 .29026 L
.07067 .29053 L
.07221 .29066 L
.07365 .29076 L
.07512 .29084 L
.07647 .2909 L
.07791 .29095 L
.0787 .29097 L
.07945 .29099 L
.08078 .291 L
.08201 .291 L
.08337 .29098 L
.08412 .29097 L
.08481 .29095 L
.08607 .2909 L
.08725 .29085 L
.08993 .29069 L
.09254 .29048 L
.09533 .2902 L
.10502 .28888 L
.12688 .28484 L
.13756 .28302 L
.14049 .28261 L
.1436 .28224 L
.14628 .28196 L
.14769 .28185 L
.14918 .28174 L
.15047 .28166 L
.15115 .28163 L
.15188 .2816 L
.15317 .28156 L
.15436 .28154 L
.15567 .28153 L
.15691 .28154 L
.15802 .28156 L
.15922 .28161 L
.16056 .28168 L
.16202 .28178 L
.16499 .28207 L
.16774 .28244 L
.17031 .28288 L
.17554 .28408 L
.18124 .28584 L
Mistroke
.19161 .29031 L
.20171 .29624 L
.21107 .30297 L
.23085 .31939 L
.24125 .32764 L
.24692 .33153 L
.25221 .33457 L
.25781 .33703 L
.26078 .33798 L
.2623 .33837 L
.26395 .3387 L
.26468 .33882 L
.26546 .33893 L
.26618 .33901 L
.26685 .33908 L
.26816 .33916 L
.26885 .33918 L
.2696 .33918 L
.27091 .33914 L
.27228 .33904 L
.27346 .3389 L
.27474 .3387 L
.27617 .33841 L
.27752 .33807 L
.28005 .33729 L
.28572 .3348 L
.29062 .33192 L
.29593 .32815 L
.31643 .30992 L
.32729 .29996 L
.33895 .29065 L
.3447 .28691 L
.35015 .28403 L
.35504 .28205 L
.35781 .2812 L
.35904 .2809 L
.36037 .28061 L
.36161 .28039 L
.36274 .28023 L
.36383 .28011 L
.36497 .28002 L
.36623 .27996 L
.3674 .27996 L
.36869 .28 L
.37007 .28011 L
.3714 .28026 L
.37284 .2805 L
.37547 .28111 L
.37802 .28193 L
.38038 .28289 L
Mistroke
.38527 .28552 L
.39054 .28938 L
.40005 .29919 L
.41137 .31573 L
.42172 .33505 L
.43219 .35722 L
.44335 .38068 L
.44878 .3907 L
.45389 .39862 L
.45847 .4041 L
.46106 .40639 L
.4623 .40728 L
.46343 .40796 L
.46455 .40851 L
.46576 .40896 L
.46703 .40928 L
.46825 .40944 L
.46938 .40944 L
.47058 .40931 L
.47161 .40908 L
.47274 .40871 L
.47406 .4081 L
.47527 .4074 L
.47801 .40529 L
.48041 .40285 L
.48295 .39975 L
.49279 .38326 L
.50356 .36019 L
.51504 .33443 L
.52589 .31235 L
.53644 .29457 L
.54617 .28195 L
.55573 .27311 L
.56055 .26993 L
.56585 .26738 L
.56863 .26642 L
.57117 .26576 L
.57257 .2655 L
.57331 .26538 L
.5741 .26528 L
.57485 .2652 L
.57554 .26515 L
.57688 .26508 L
.57821 .26508 L
.57943 .26514 L
.58077 .26526 L
.58145 .26534 L
.58219 .26545 L
.58344 .26569 L
.58477 .266 L
Mistroke
.58718 .26674 L
.58989 .26784 L
.59276 .26934 L
.5979 .27296 L
.60344 .27827 L
.60954 .286 L
.62046 .30539 L
.63069 .33088 L
.65014 .39828 L
.66042 .43758 L
.66607 .45671 L
.67139 .47138 L
.67428 .47757 L
.67581 .48024 L
.67742 .4826 L
.67877 .4842 L
.67949 .4849 L
.68027 .48554 L
.68162 .48637 L
.68289 .4868 L
.68426 .48691 L
.68504 .4868 L
.68575 .48658 L
.68707 .48592 L
.68774 .48545 L
.68847 .48482 L
.6911 .48173 L
.69357 .47765 L
.69886 .46539 L
.70372 .4507 L
.71466 .41055 L
.72507 .371 L
.7362 .33435 L
.7467 .3075 L
.75625 .28939 L
.76612 .27599 L
.77169 .27042 L
.77682 .26635 L
.7817 .26328 L
.78626 .26101 L
.79102 .25914 L
.79625 .25757 L
.80148 .25643 L
.80443 .25593 L
.80717 .25556 L
.80976 .25529 L
.8122 .25508 L
.81354 .255 L
.815 .25492 L
.81633 .25486 L
Mistroke
.81754 .25483 L
.81867 .2548 L
.81988 .25478 L
.82102 .25478 L
.82206 .25478 L
.82328 .25479 L
.8246 .25482 L
.82586 .25485 L
.82701 .25488 L
.82932 .25497 L
.83186 .2551 L
.837 .25543 L
.87926 .259 L
.91992 .2616 L
.94058 .26299 L
.95229 .26402 L
.96316 .2653 L
.9725 .26675 L
.98098 .26836 L
1 .27286 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0G?oooolDo`00043ooooo002eooooo`03o`000?oooooooooo05Wooooo0ol0
000Dooooo`ko0000<_ooool00;Gooooo0_l0001Iooooo`03o`000?oooooooooo02?ooooo3_l0000T
ooooo`00]Oooool00ol0003oooooooooo`0Dooooo`Go0000?Oooool2o`0003Cooooo1ol0000Moooo
o`005Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00Go
V9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool5o`0000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Looooo`Co000000So410@ooooooooooook^k^oc8b<_l0
003o<S8bonk^kQkooooo00?o0000ooooooooool04Oooool3o`0000Gooooo00?o0000ooooooooool0
0oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hJooooo`Go00000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo0_l0000Gooooo`05oiRHV?l@413o0000oc8b<_o<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Wooooo1_l000002Ol@413oooooooooooooooook^k^
oc8b<_l0003o<S8bonk^kP0>ooooo`005_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL06_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Kooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9So
MgMg01kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`07ooooo`;o00001Oooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01OnHV9So8B4Qonk^k_ooooooA4A400?o
oooo00OoMgMgoiRHV?ooooooV9RHogMgMooooooo000001Wooooo00Go410@okZj^_ooooooMgMgoc8b
<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool4o`000006oooooomgMgOoV9RHoooooonH
V9SoMgMg3_ooool000_ooooo1_l00002ooooo`Oo000000?ooooooa0@4?ooool00_ooool00ol@413o
ooooooooo`0@ooooo`Ko00001_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@oooo
ooooool04Oooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo
410@01?ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
400Nooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02_ooool2o`0000?ooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01_ooooo00?oV9RHob4Q8Oo^k^h0
1?ooool01ol@413ooooooooooooooooo410@ooooool000007Oooool01Ol0003ooooooooooooooooo
410@00?ooooo00?o410@ooooooooool06Oooool5o`0000;ooooo00?o0000oa0@4?ooool00_ooool0
0ol@413oooooooooo`0<ooooo`004oooool01?m4A4CogMgMooooool00003ooooo`Ko00007Oooool0
0onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00onHV9So8B4Qonk^
kP03ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000007_ooool2o`0000oooooo00?o0000ooooooooool03Oooool01?l0003o
ooooooooool00004ooooo`05o`000?ooooooooooooooool000007?ooool00onHV9So8B4Qonk^kP03
ooooo`04o`000?ooooooooooooooo`;o00007Oooool00onYZJWo410@ooooo`02ooooo`05o`000?oo
ooooooooooooool000006oooool01?m4A4CogMgMooooool00004ooooo`05o`000?oooooooooooooo
ool000003_ooool001?ooooo00CogMgMoeEEEOoooooo00001?ooool01?l0003oooooooooooooool3
o`0001[ooooo00?o410@o`000?nj^[X00oooool00ol0003oooooooooo`05o`0001_ooooo00?oMgMg
ofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000001Wooooo1_l00004ooooo`05o`000?oo
ooooooooooooool000007_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo
00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo000001gooooo00?oMgMgofIV
I_ooool00_ooool01Ol0003ooooooooooooooooo000001gooooo00?o410@o`000?nj^[X00oooool0
1Ol0003ooooooooooooooooo000001_ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000000kooooo000Dooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooo
oooooa0@4002ooooo`Co00005_ooool9o`000003ooooool@413ooooo00;ooooo1Ol0000Gooooo`05
o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Cooooo`Co00001Oooool3o`00
00;ooooo00Go410@oooooooooooooooooa0@400Nooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool04?ooool00ol0003oooooo`000004ooooo`05oa0@4?ooooooooooooooool@41007_oo
ool01Ol0003ooooooooooooooooo410@00;ooooo00?o0000oa0@4?ooool07Oooool00onj^[[o8B4Q
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41007?ooool00omgMgOoc<c<o`000004ooooo`05
oa0@4?ooooooooooooooool@41003_ooool001Cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Kooooo0_l0000Aooooo`?o000000?ooooookZj^_l000000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Sooooo0ol0000@ooooo`05o`000?nj^[[ooooooiRHV?l@41000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`02o`000005ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo01;ooooo0_l00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01Ol0
003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?l0003oV9RHogMgM`0Kooooo`05oa0@4?nH
V9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01cooooo00?ok^k^odA4A?l0
00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000Eooooo`03ogMgMol0003ooooo00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP08oooooa7o000000KoooooojVYZOl@413o0000oa0@4?nY
ZJT3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool3o`0000gooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool2o`0000Sooooo00?oEEEEofIV
I_l000001?ooool01Ol0003o<S8bo`000?lb<S;ok^k^01kooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Booooo`03oeEEEOl0003o000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko0000o`000?lb<S;ok^k^01_o
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Oooool0
0omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool005Gooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01oooooo0_l0000:
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1O
ooooo`00E_ooool2o`0002Oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo063ooooo001Hooooo`03o`000?oooooooooo02;ooooo0_l0000Fooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo02Sooooo00?o0000ooooooooool0H?ooool005Wooooo0_l0000Qooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1Qooooo`00Fooo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`1Qooooo`005_ooooooo`00043o00004oooool001Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`;o00001ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Aooooo`005_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool07?ooool2o`0002Cooooo00?o0000ooooool000009oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo017ooooo001Oooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
06?ooooo001Pooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo06?ooooo001Qooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Hooooo`;o00001?ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0I?ooool006;ooooo0_l0
000?ooooo`;o00009_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo06Cooooo001T
ooooo`;o00003?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool0I?ooool006Kooooo0_l00008ooooo`;o0000:_ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo06Gooooo001Xooooo`;o00001?ooool2o`0002cooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`1Uooooo`00J_ooool4o`0002oooooo00?o0000ooooooooool0
5Oooool2o`0000;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo06Gooooo002Mooooo`03o`000?oooooooooo01Gooooo00Go0000oooooooooooooooo
o`00000Uooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0I_ooool009kooooo00?o
0000ooooooooool05?ooool01?l0003oooooooooool0000Vooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool0I_ooool009kooooo00?o0000ooooooooool05?ooool01?l0003ooooooooo
ool0000Wooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0I_ooool009kooooo00?o
0000ooooooooool05?ooool00ol0003oooooo`00000Xooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool0I_ooool009oooooo00?o0000ooooooooool04oooool3o`0002Sooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`1Wooooo`00Woooool00ol0003oooooooooo`0Coooo
o`;o0000:_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo06Oooooo002Pooooo`03
o`000?oooooooooo01;ooooo0_l0000Zooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0Ioooool00:3ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool0Ioooool00:7ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0J?oo
ool00:7ooooo00?o0000ooooooooool04Oooool2o`0002_ooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`1Xooooo`00X_ooool00ol0003oooooooooo`0?ooooo`;o0000;?ooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo06Sooooo002Booooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool2
o`0002gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1Yooooo`00T_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?l0003ok^k^oooooom4A4@01ooo
ool00omgMgOo<S8booooo`03ooooo`;o0000;Oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo06Wooooo002Booooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003o8B4Qonk^
kP09ooooo`07o`000?ooooooooooooooool0003oooooo`00000]ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool0JOooool009;ooooo00Go0000ooooooooooooooooo`00000=ooooo`03
o`000?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool00_ooool00ol0003oooooo`000002o`0002co
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Zooooo`00T_ooool01Ol0003ooooo
oooooooooooo000000kooooo00?o0000ofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00;ooooo00Co0000oooooooooooo0000;_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo06[ooooo002Booooo`05oa0@4?ooooooooooooooool@41003_ooool2o`0000Cooooo00?o0000
ooooooooool00oooool01Ol0003ooooooooooooooooo000002kooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`1Zooooo`00T_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
0000okZj^_ooooooV9RHo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
Joooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`04oiRHV?l@413o0000ob4Q8@;o
00000oooool5o`0000Gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo06_ooooo002Xooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool2o`0002kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1[ooooo`00Z?oo
ool2o`0000?ooooo0_l00006ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`1/ooooo`00ZOooool5o`0000Oooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo06cooooo002eooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1/ooooo`00]Oooool00ol0003o
ooooooooo`0^ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0K?ooool00;Gooooo
0_l0000_ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0KOooool00;Gooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo06gooooo002e
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1]
ooooo`00]Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0KOooool00;Gooooo0_l0000`ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool0K_ooool00;Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo06kooooo002eooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`1^ooooo`00]Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool0K_ooool00;Gooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo06kooooo002eooooo`;o0000<_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo06oooooo002eooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`1_ooooo`00]Oooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Koooool009[ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo
00?o0000ooooooooool0<_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo073ooooo
002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
L?ooool009[ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo
0ol0000booooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0L?ooool009[ooooo00Go
0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
<oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo077ooooo002Jooooo`05o`000?oo
ooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool0<oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo077ooooo002Jooooo`05oa0@
4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1aooooo`00V_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0L_ooool009[ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`Co00001_ooool2o`0003Gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`1booooo`00]Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0Loooool00;Gooooo00?o0000ooooooooool0=_ooool01?l0003oooooo`00
0?l0001fooooo`00]Oooool00ol0003oooooooooo`0gooooo`;o0000Moooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003o
k^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`oooo
o`00T_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo
00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413o
oooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?ooooooooooooooool000003_ooool00olQ
8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00T_ooool01Ol0003o
oooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00Go410@oooooooooooooooooa0@400>
ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`
ooooo`00T_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b
<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00Zoooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool00:gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo0ol0002`
ooooo`00[Oooool00ol0003oooooooooo`2hooooo`00[Oooool00ol0003oooooooooo`2hooooo`00
[Oooool00ol0003oooooooooo`2hooooo`00Zoooool00omEEEGoIVIVo`00002jooooo`00oooooomY
ooooo`00[oooool00ol0003o^[Zjooooo`2fooooo`00[oooool2oc8b<[Oooooo0020ooooo`;o0000
00Ko410@oooooooooooo410@o`000?l@410Gooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Wooooo1?l0
00000ol@413oooooooooo`05o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1hooooo`00POoo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l00009ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?oc<c<o`000?l@
41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<ooooo`03o`000?oooooooooo
00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0N?oo
ool0087ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Gooooo`03oiRHV?lQ8B7o
k^k^00Cooooo00Go410@oooooooooooooooooa0@400Booooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool00oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@4100
N?ooool0087ooooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00002oooool00onHV9So
8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0;oooo
o`Ko00003?ooool00ol0003oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`00001hooooo`00POooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001_ooooo00?o
MgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`05ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000oooooooooooo
ooooo`00001hooooo`00POooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001cooooo00Go0000oooo
oooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00kooooo00?o410@o`000?l000000ol0000L
ooooo`03o`000?oooooooooo00Kooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oo
oooooooo07Kooooo0021ooooo`06o`000?lb<S;ooooooooooolb<S;o00006?ooool01Ol0003o^[Zj
oooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Booooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool00_ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`1hooooo`00P?ooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o
410@01Oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
4_ooool00ol0003oooooooooo`0Kooooo`03oeEEEOmVIVKo000000Cooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0N?ooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(130) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .28 m
.00942 .28296 L
.01975 .28586 L
.02496 .28712 L
.03053 .28828 L
.03578 .28915 L
.04057 .28974 L
.04332 .28999 L
.04471 .29008 L
.04624 .29017 L
.04754 .29022 L
.04827 .29024 L
.04894 .29026 L
.05024 .29028 L
.05147 .29029 L
.05222 .29028 L
.05289 .29028 L
.05367 .29026 L
.05441 .29024 L
.05572 .2902 L
.05713 .29013 L
.0587 .29003 L
.06035 .28991 L
.06331 .28963 L
.06861 .28897 L
.07356 .28817 L
.08481 .28586 L
.10438 .28106 L
.1147 .27878 L
.11991 .27787 L
.12291 .27743 L
.12566 .27711 L
.12854 .27684 L
.13005 .27674 L
.13082 .27669 L
.13164 .27665 L
.13303 .2766 L
.13432 .27657 L
.13511 .27656 L
.13585 .27656 L
.13652 .27657 L
.13725 .27658 L
.13854 .27661 L
.13927 .27664 L
.13996 .27668 L
.14134 .27676 L
.14282 .27688 L
.14551 .27717 L
.14796 .27752 L
.15315 .27855 L
Mistroke
.15608 .27932 L
.1588 .28015 L
.16909 .28442 L
.17444 .28734 L
.18022 .29102 L
.19068 .29894 L
.21023 .31649 L
.22109 .32621 L
.23121 .33386 L
.23631 .33683 L
.23892 .33807 L
.24177 .33917 L
.24339 .33968 L
.24488 .34007 L
.24631 .34037 L
.24704 .3405 L
.24783 .34061 L
.24918 .34076 L
.25045 .34084 L
.25118 .34085 L
.25196 .34085 L
.25334 .34079 L
.25464 .34067 L
.25538 .34058 L
.25605 .34047 L
.25861 .33993 L
.26093 .33924 L
.26339 .33831 L
.2685 .33575 L
.27411 .33205 L
.29341 .31448 L
.31559 .29248 L
.32609 .28402 L
.33582 .27806 L
.34068 .27585 L
.34317 .27495 L
.34585 .27414 L
.34853 .27351 L
.34973 .27329 L
.35104 .2731 L
.3525 .27294 L
.35329 .27288 L
.35403 .27283 L
.35536 .2728 L
.3561 .2728 L
.35678 .27281 L
.35801 .27288 L
.35932 .27299 L
.36044 .27314 L
.36167 .27334 L
Mistroke
.36442 .27395 L
.36699 .27475 L
.37164 .27676 L
.37664 .27975 L
.38215 .2841 L
.38726 .28917 L
.39885 .30447 L
.40906 .32233 L
.41995 .34504 L
.43016 .36778 L
.44094 .3898 L
.44657 .39903 L
.44956 .40299 L
.45276 .40641 L
.45427 .4077 L
.4557 .40873 L
.45709 .40954 L
.45838 .41012 L
.4596 .41052 L
.4609 .41077 L
.4622 .41085 L
.46294 .41082 L
.46363 .41075 L
.46491 .41047 L
.46609 .41007 L
.46739 .40947 L
.46878 .40864 L
.47162 .40636 L
.4742 .40364 L
.47919 .39679 L
.48389 .38868 L
.50572 .34093 L
.52497 .30254 L
.53591 .28628 L
.54125 .2799 L
.54613 .27495 L
.55095 .27087 L
.5562 .2673 L
.55908 .2657 L
.56175 .26445 L
.56428 .26346 L
.56702 .26259 L
.56853 .2622 L
.56991 .2619 L
.57121 .26166 L
.57264 .26146 L
.57392 .26132 L
.57511 .26123 L
.57637 .26118 L
.57772 .26118 L
Mistroke
.57849 .2612 L
.57919 .26123 L
.57997 .26128 L
.58079 .26135 L
.58217 .26152 L
.58369 .26177 L
.58649 .2624 L
.58912 .26322 L
.59182 .26431 L
.59432 .26554 L
.60001 .26922 L
.60502 .27359 L
.61037 .27953 L
.62057 .29505 L
.62981 .31455 L
.64033 .34377 L
.65001 .37697 L
.66132 .41987 L
.66684 .44006 L
.67187 .45653 L
.67644 .46895 L
.67885 .47427 L
.6814 .47888 L
.6827 .48076 L
.68413 .48248 L
.68543 .48371 L
.68665 .48456 L
.6879 .48513 L
.68905 .48538 L
.6903 .48535 L
.69163 .48498 L
.69299 .48424 L
.69422 .48325 L
.69565 .48175 L
.69699 .47999 L
.69939 .47604 L
.70199 .47067 L
.70788 .45485 L
.71332 .4369 L
.73469 .35939 L
.74513 .32841 L
.75468 .30652 L
.76451 .28986 L
.77385 .27865 L
.77896 .27408 L
.7837 .27068 L
.78891 .26771 L
.79445 .26528 L
.80009 .26342 L
.80527 .26212 L
Mistroke
.81096 .26107 L
.81386 .26065 L
.81696 .26028 L
.8197 .26001 L
.82219 .25981 L
.82473 .25966 L
.82707 .25954 L
.8298 .25944 L
.83124 .2594 L
.83276 .25937 L
.83409 .25935 L
.83533 .25933 L
.83669 .25932 L
.83745 .25932 L
.83815 .25932 L
.8395 .25931 L
.84077 .25932 L
.84191 .25932 L
.84314 .25932 L
.84449 .25933 L
.84591 .25934 L
.84847 .25936 L
.85805 .25944 L
.86344 .25948 L
.86854 .25952 L
.87443 .25959 L
.8798 .25968 L
.88965 .25991 L
.90038 .26025 L
.90522 .26044 L
.91037 .26069 L
.91962 .2613 L
.92474 .26176 L
.92944 .26228 L
.94003 .26378 L
.95921 .26762 L
.97868 .27303 L
1 .28 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0HooooolIo`0003Cooooo002e
ooooo`;o00004oooool7o`0004Cooooo1ol0000Hooooo`go00009oooool00;Gooooo00?o0000oooo
ooooool04?ooool2o`0000Oooooo1?l0000mooooo`?o0000;?ooool4o`0002?ooooo000Eooooo`;o
000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h06_ooool01OnHV9So410@o`00
0?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^01cooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
7_ooool00ol0003oooooooooo`0>ooooo`;o00003Oooool00ol0003oooooo`000003o`000008oa0@
4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hJooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Kooooo0_l0000Cooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01?ooooo1Ol00005ooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o
0000oc8b<_o^k^h03_ooool001Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg01[ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL06oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0N
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03Oooool01Ol0003ooooooooooooooooo000000Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool04oooool01Ol@413o^[Zjoooooomg
MgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Hooooo`?o00000oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool000_ooooo1_l00002ooooo`Go0000
0oooool01Ol@413ooooooooooooooooo410@01;ooooo1_l00006ooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41004oooool:o`000003ooooool0003ooooo00?ooooo00Go410@
oooooooooooooooooa0@400Nooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03ooo
ool01?l0003oooooooooool00004ooooo`05oa0@4?ooooooooooooooool@41006oooool00onHV9So
8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool2o`0001[ooooo00Go0000oooo
oooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01Wooooo1Ol00003ooooo`05oa0@4?oooooo
ooooooooool@41003_ooool001?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooo
oooooooo000001_ooooo3?l0000Mooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooooooo
ooooo`00000Aooooo`?o00002Oooool2o`0000Cooooo00Go0000ooooooooooooooooo`00000Noooo
o`;o00003?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo000000Cooooo00Go0000oooo
ooooooooooooo`00000Looooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00
0002ooooo`03o`000?oooooooooo01Wooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooo
oooooooo000001_ooooo00?oA4A4omgMgOooool00ol00002ooooo`05o`000?ooooooooooooooool0
00003_ooool001?ooooo00?ogMgMoeEEEOooool00ol00002ooooo`05o`000?ooooooooooooooool0
00005_ooool5o`000004ooooool@413o0000okZj^P?ooooo00Co0000oooooooooooooooo1Ol0000J
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00000@ooooo`03o`000?oo
oooooooo00_ooooo0_l00003ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo01?ooooo0_l00004ooooo`05o`000?ooooooooooooooool0
00007Oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool00ol0
003oooooooooo`0Hooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00000K
ooooo`04omgMgOmEEEGoooooo`0000;ooooo0ol00003ooooo`03o`000?oooooooooo00cooooo000D
ooooo`03ogMgMoo<c<co000000;ooooo0ol00003ooooo`03oa0@4?oooooooooo017ooooo0ol00007
ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4004ooooo`;o00006Ooo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool03?ooool2o`0000kooooo
00?o0000ooooool000000_ooool01Ol@413ooooooooooooooooo410@01kooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Dooooo`;o00001?ooool01Ol@413ooooooooooooooooo410@
01kooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooo000001cooooo00?o^[Zj
ob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@01cooooo00?oMgMgolc<c?l000001?oo
ool01Ol@413ooooooooooooooooo410@00kooooo000Dooooo`03onk^k_m4A4Co000000Cooooo00Go
MgMgo`000?l0003o0000ogMgM`0=ooooo`Ko00001oooool01Ol@413oV9RHoooooonj^[[o000000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`;o00004oooool01Ol0003o^[ZjoooooonHV9So
410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0=ooooo`03o`000?oooooooooo00kooooo00[o
0000oooooooooooo0000oooooomgMgOoV9RHoooooonHV9SoMgMg7_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg01[ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`06ogMgMonHV9SooooooiRHV?mg
MgOo00006_ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Looooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`005Ooo
ool00omgMgOo0000ooooo`03ooooo`04onk^k_lb<S;o0000oc8b<Pko00003Oooool01OnYZJWo410@
o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo
013ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?oo
ool00ol0003oooooooooo`0=ooooo`03oeEEEOmVIVKo000000?ooooo00Ko0000onk^k_lb<S;o0000
oc8b<_o^k^hNooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05?ooool01?mEEEGo
IVIVo`000?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06_ooool01OnHV9So410@o`000?lQ
8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bo`00000Kooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo00?oMgMgo`000?ooool00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00kooooo001@ooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0Qooooo`;o00002?ooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo02cooooo00?o0000ooooooooool0G?ooool0057ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02[ooooo00?o0000oooooooo
ool0GOooool005;ooooo0_l0000Tooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`1Nooooo`00E?ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1Nooooo`00EOooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`1Oooooo`005_ooooooo`00043o00004oooool001Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`;o
00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo000Fooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00[ooooo0_l0000Iooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01oooooo0_l0000Uooooo`;o0000
9_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo017ooooo001Iooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo067ooooo001Jooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo067ooooo001Kooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Jooooo`;o00000oooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0HOooool005co
oooo0_l0000@ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool06Oooool01Ol0003o
oooooooooooooooo000002Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1Roooo
o`00G_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool06Oooool01Ol0003ooooooooooooooooo000002Kooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`1Rooooo`00Goooool2o`0000_ooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`0Iooooo`04o`000?ooooooooooo`0002Oooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`1Rooooo`00HOooool2o`0000Oooooo0_l0000^ooooo`03o`000?oooooooooo01So
oooo00Co0000oooooooooooo0000:?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
06?ooooo001Sooooo`Oo0000<?ooool00ol0003oooooooooo`0Hooooo`?o0000:Oooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo06?ooooo002Jooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooool00000:_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo06?ooooo
002Kooooo`03o`000?oooooooooo01Oooooo0_l0000[ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool0I?ooool009_ooooo00?o0000ooooooooool05oooool2o`0002_ooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`1Tooooo`00W?ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Toooo
o`00W?ooool00ol0003oooooooooo`0Fooooo`;o0000;?ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo06Gooooo002Mooooo`03o`000?oooooooooo01Cooooo0_l0000]ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool0IOooool009kooooo00?o0000ooooooooool04ooo
ool2o`0002kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1Uooooo`00W_ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooo000002kooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`1Uooooo`00Woooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo0000
02kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1Vooooo`00Woooool00ol0003o
ooooooooo`0Aooooo`04o`000?oooooo0000o`0002gooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`1Vooooo`00X?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooo`00
02oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1Vooooo`00T_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B42ooooo`03o`000?oooooo000000Co00001?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00;ooooo00Co0000oooooooooooo0000;oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo06Oooooo002Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@?ooooo00Ko0000oiRHV?lQ8B7ok^k^oooooom4A4@7ooooo`04ogMgMolb<S;oooooo`00
00?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
06Oooooo002Booooo`05oa0@4?ooooooooooooooool@41002_ooool01Ol0003ooooooiRHV?lQ8B7o
k^k^00Wooooo00?o0000ooooool000000oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool0Ioooool009;ooooo00Go0000ooooooooooooooooo`00000:
ooooo`06o`000?oooooooooooiRHV?lQ8B7ok^k^1oooool00omgMgOo<S8bo`000004ooooo`?o0000
;_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo06Oooooo002Booooo`05o`000?oo
ooooooooooooool000002oooool01Ol0003ooooooooooomgMgOoIVIV00Cooooo00Ko0000ob4Q8Ol0
003o<S8bolc<c?l00004ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`1Xooooo`00T_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0J?ooool009;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`;o000000?ooooooiRHV?l@41001?ooool01?l0003ooooo
ooooool00006ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`1Xooooo`00T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool0JOooool00:Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`;o0000<?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo06Wo
oooo002Vooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0JOooool00:Kooooo0ol0
00000ooooooo0000o`000009ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`1Yooooo`00Z?ooool2o`0000_ooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06[ooooo002eooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Zooooo`00]Oooool2o`00037o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Zooooo`00]Oooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0J_ooool00;Gooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo06_ooooo002e
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1[
ooooo`00]Oooool2o`0003;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1[oooo
o`00]Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool0K?ooool00;Gooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo06cooooo002eooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`1/ooooo`00]Oooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool0KOooool00;Gooooo0_l0000dooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0KOooool00;Gooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo06gooooo002eooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`1^ooooo`00V_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`0dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0K_ooool009[ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo03Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1^ooooo`00
V_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`0003Co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1_ooooo`00V_ooool01Ol0003ooooo
oooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0Koooool009[ooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Koooool009[ooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo073ooooo002Jooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`1aooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo1?l00006ooooo`;o0000>?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
077ooooo002eooooo`03o`000?oooooooooo03Oooooo0_l00002ooooo`;o0000Loooool00;Gooooo
00?o0000ooooooooool0>?ooool4o`0007Cooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omE
EEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009;o
oooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo0000
00kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;o
oooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?oooooooooo
ooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooo
oooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002B
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00:_ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0;3o
oooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool00:gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05
ooooo`?o0000/?ooool00:gooooo00?o0000ooooooooool0^?ooool00:gooooo00?o0000oooooooo
ool0^?ooool00:gooooo00?o0000ooooooooool0^?ooool00:_ooooo00?oEEEEofIVI_l00000^_oo
ool00?ooooooJOooool00:oooooo00?o0000okZj^_ooool0]_ooool00:oooooo0_lb<S:gooooo`00
P?ooool2o`000006oa0@4?oooooooooooa0@4?l0003o410@5oooool5o`0000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj
^P0Iooooo`Co000000So410@ooooooooooooV9RHoa0@4?l0003o<S8bolc<c0?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1hooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Oooooo1_l00009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo
1_l0000<ooooo`03o`000?oooooooooo00;ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0N?ooool0087ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400Boooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo
410@00?ooooo00?o410@ooooooooool0M_ooool0087ooooo00Ko0000oooooom4A4CoA4A4ooooool0
0009ooooo`Ko00002oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool00000
4_ooool00ol0003oooooooooo`0;ooooo`Ko00003?ooool00ol0003oooooooooo`05ooooo`03ojVY
ZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00001hooooo`00POooool01_l0003ogMgM
oc8b<_mEEEGogMgMo`0001_ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo
000001;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`04ooooo`03oa0@4?l0003o
^[Zj00?ooooo00Go0000ooooooooooooooooo`00001hooooo`00POooool01_l0003oQhN7ojVYZOnj
^[[oEEEEo`0001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00ko
oooo00?o410@o`000?l000000ol0000Looooo`03o`000?oooooooooo00Gooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@07Sooooo0021ooooo`06o`000?lb<S;ooooooooo
oolb<S;o00006?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0Booooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413oV9RH
oooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1hooooo`00P?ooool00ol@413o
0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Kooooo`03oeEEEOmVIVKo
000000Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
N?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(140) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .28728 m
.00488 .28823 L
.00942 .28893 L
.01199 .28924 L
.01441 .28947 L
.01575 .28957 L
.01721 .28967 L
.01853 .28974 L
.01975 .28978 L
.02094 .28981 L
.02223 .28983 L
.02345 .28984 L
.02456 .28983 L
.02586 .2898 L
.02659 .28978 L
.02727 .28976 L
.02852 .2897 L
.02985 .28962 L
.03275 .2894 L
.03547 .28912 L
.04057 .28843 L
.04595 .28745 L
.05164 .2862 L
.06182 .28348 L
.07291 .2802 L
.08481 .27681 L
.09035 .27541 L
.09559 .27425 L
.1007 .2733 L
.10295 .27295 L
.10543 .27262 L
.10758 .27238 L
.1099 .27217 L
.11118 .27209 L
.11235 .27202 L
.11347 .27198 L
.11465 .27194 L
.11585 .27193 L
.11713 .27193 L
.11834 .27196 L
.11944 .272 L
.12073 .27206 L
.12213 .27216 L
.12468 .27242 L
.12715 .27275 L
.12981 .27322 L
.13462 .27434 L
.14033 .27616 L
.14555 .2783 L
.15688 .28452 L
Mistroke
.16764 .29241 L
.18872 .31214 L
.2078 .33027 L
.21293 .33424 L
.21847 .33777 L
.22101 .33909 L
.22369 .34026 L
.22599 .34106 L
.2285 .34172 L
.22998 .34199 L
.23071 .3421 L
.23138 .34218 L
.23264 .34229 L
.23401 .34233 L
.23537 .3423 L
.23614 .34225 L
.23687 .34219 L
.23763 .3421 L
.23833 .34199 L
.2399 .34169 L
.24238 .34102 L
.24508 .34003 L
.25053 .33724 L
.2561 .3334 L
.26135 .32903 L
.27117 .31944 L
.29318 .29605 L
.30341 .28633 L
.31423 .27787 L
.32347 .27248 L
.32872 .27024 L
.33362 .26872 L
.33635 .26811 L
.33887 .2677 L
.34018 .26755 L
.34094 .26749 L
.34164 .26743 L
.34237 .26739 L
.34315 .26737 L
.34385 .26735 L
.34458 .26735 L
.34582 .26739 L
.34715 .26746 L
.3484 .26758 L
.34954 .26772 L
.35088 .26793 L
.35233 .26821 L
.35497 .26888 L
.35731 .26963 L
.35988 .27066 L
Mistroke
.36509 .27336 L
.36992 .27665 L
.37444 .28047 L
.38535 .29276 L
.39572 .30859 L
.41517 .34798 L
.42601 .37229 L
.43622 .39267 L
.44068 .39981 L
.44539 .40569 L
.44785 .408 L
.44915 .409 L
.45055 .40988 L
.45183 .41052 L
.45301 .41096 L
.45418 .41127 L
.4553 .41143 L
.45648 .41145 L
.45779 .41132 L
.45916 .41099 L
.46044 .41051 L
.46164 .40992 L
.46273 .40925 L
.4652 .40732 L
.46771 .40478 L
.47045 .40138 L
.47597 .39279 L
.498 .34555 L
.50948 .32068 L
.52033 .30071 L
.53006 .28633 L
.54061 .27446 L
.55098 .26622 L
.5562 .26325 L
.55921 .26187 L
.56195 .26082 L
.5643 .26008 L
.56685 .25942 L
.56826 .25912 L
.56955 .25889 L
.57088 .2587 L
.57212 .25856 L
.57328 .25845 L
.57454 .25838 L
.57568 .25834 L
.57672 .25834 L
.57786 .25836 L
.57911 .25842 L
.58041 .25852 L
.58162 .25865 L
Mistroke
.58296 .25883 L
.58437 .25907 L
.5869 .25963 L
.58963 .26041 L
.59264 .26151 L
.59801 .26414 L
.60305 .26745 L
.61245 .27621 L
.61772 .28281 L
.62255 .29007 L
.63288 .30991 L
.64248 .33422 L
.66423 .40791 L
.67532 .4464 L
.68077 .46181 L
.68315 .46742 L
.68577 .47261 L
.68813 .47634 L
.69033 .47897 L
.69155 .48005 L
.69266 .48081 L
.69394 .48139 L
.69516 .48167 L
.69638 .48167 L
.69768 .48137 L
.69879 .48087 L
.70002 .48005 L
.70133 .47887 L
.70275 .47726 L
.70531 .47349 L
.71051 .46272 L
.71535 .44959 L
.72634 .41311 L
.73773 .37366 L
.74849 .34124 L
.75879 .31673 L
.76422 .30637 L
.76996 .29714 L
.7748 .29062 L
.78011 .28462 L
.78948 .27657 L
.79495 .27306 L
.80014 .27037 L
.80989 .26655 L
.81533 .26494 L
.82038 .26369 L
.82588 .26258 L
.83182 .2616 L
.83761 .26086 L
.84294 .26031 L
Mistroke
.84793 .2599 L
.8534 .25954 L
.85799 .25929 L
.86291 .25908 L
.86563 .25899 L
.8681 .25893 L
.8693 .2589 L
.87059 .25888 L
.87182 .25887 L
.87295 .25886 L
.87419 .25885 L
.87549 .25885 L
.87661 .25886 L
.87783 .25887 L
.87914 .25889 L
.88055 .25892 L
.88308 .259 L
.88564 .2591 L
.88806 .25923 L
.89258 .25953 L
.89799 .26 L
.90297 .26054 L
.91422 .26216 L
.92442 .26415 L
.93395 .2665 L
.95563 .27326 L
.99644 .28645 L
1 .28728 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool04_ooool8o`00057ooooo4Ol0
000dooooo`00]Oooool2o`00017ooooo0_l00007ooooo`?o0000B?ooool7o`00017ooooo2?l0000/
ooooo`00]Oooool00ol0003oooooooooo`0>ooooo`;o00003?ooool2o`0004?ooooo0ol0000Poooo
o`?o0000:Oooool001Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^
kP0Jooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04?ooool9o`0000?ooooo1?l000002?l@
413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^7_ooool00ol0003oooooooooo`0<ooooo`;o0000
4?ooool5o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hJooooo`Go00000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo0ol0000<ooooo`05oiRHV?l@413o0000oc8b<_o<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo0ol0000=ooooo`;o000000Wo410@oooooooo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^h03_ooool001Kooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01Sooooo1_l000002Olb<S;oooooooooooooooooMgMgoiRHV?oo
ooooV9RHogMgM`0Kooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00oooooo00?o0000ooooooooool01_ooool3o`0000?ooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooo000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo0_l0000?
ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg013ooooo
0ol0000;ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`00
2oooool6o`0000;ooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41004_ooool6o`0000Ko
oooo1?l000001Ol@413ooooooooooooooooo410@01?ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^
00Cooooo00Go410@oooooooooooooooooa0@400=ooooo`;o00001?ooool6o`0000;ooooo00Co0000
oooooooooooo00001?ooool01Ol@413ooooooooooooooooo410@01kooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Cooooo`;o00001?ooool01Ol@413ooooooooooooooooo410@01_o
oooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00Sooooo0_l0000Eoooo
o`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Aooooo`Co00001?ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`004oooool01?m4A4CogMgMooooool0
0004ooooo`05o`000?ooooooooooooooool000003oooool3o`0000_ooooo00?oZJVYoa0@4?ooool0
0_ooool5o`0001gooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000[o
oooo0ol0000?ooooo`?o00001?ooool01Ol0003ooooooooooooooooo000001kooooo0_l0000:oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000001cooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000Kooooo0_l0
000Fooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Gooooo`?o0000
00GoooooodA4A?oMgMgoooooo`000004ooooo`05o`000?ooooooooooooooool000003_ooool001?o
oooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000_ooooo1?l0000=
ooooo`03oa0@4?l0003o^[Zj00?ooooo00Co0000oooooooooooooooo0_l0000Mooooo`03ogMgMomV
IVKooooo00;ooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001kooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`00000Mooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000005
ooooo`03o`000?oooooooooo01Gooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooo
oooo000001[ooooo0ol000000ooooooo0000ooooo`03ooooo`05o`000?ooooooooooooooool00000
3_ooool001Cooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00Sooooo
0ol0000Booooo`03okZj^_lQ8B7ooooo00;ooooo00Oo410@oooooooooooooooooa0@4?oooooo0000
01gooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Kooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41007_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Oooooo0_l00003ooooo`05oa0@4?oo
ooooooooooooool@41007_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@oooooooo
ool00_ooool00ol0003oooooooooo`0Gooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooo
oooooooooa0@400Looooo`04ogMgMol0003o0000o`0000?ooooo00Go410@oooooooooooooooooa0@
400>ooooo`005?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?oo
ool4o`0001;ooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00_ooool00ol0003oooooooooo`0Fooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Oooooo00?o0000ooooooooool05?ooool2o`0000?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06?oo
ool00ol0003oooooo`000002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01Ol0003o^[Zj
oooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03o`000?oooooooooo
01Gooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07?oo
ool01?o^k^koA4A4o`000?ooool3o`000005ogMgMonHV9SooooooiRHV?mgMgL03_ooool001Gooooo
00?oMgMgo`000?l000003?l0000Fooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo00?o0000ooooooooool05Oooool01OnHV9So410@o`000?lQ8B7o
c<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo01?ooooo00Go
EEEEofIVI_l0003oooooo`000002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01Kooooo00?oEEEEofIVI_l000000_ooool01ol0003o
ooooonk^k_lb<S;o0000oc8b<_o^k^h06_ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP02ooooo`03o`000?oooooooooo01Kooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Oooool00omgMgOo0000ooooo`03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool004_ooooo0_l0000Wooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool08_ooool2o`0000Kooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo05Wooooo001=ooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo05[o
oooo001>ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`0[ooooo`03o`000?oooooooooo05[ooooo001?ooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo05_ooooo001@
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo05cooooo000Foooooooo0000@?l0000Cooooo`005_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Cooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool04Oooool001Kooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07Oooool0
1Ol0003ooooooooooooooooo000002?ooooo00Co0000oooooooooooo00008oooool01Ol0003ooooo
oooooooooooo000002?ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Aooooo`00
E?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
7Oooool01Ol0003ooooooooooooooooo000002Kooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`1Nooooo`00EOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool07?ooool01?l0003oooooooooool0000Wooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool0G_ooool005Kooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo01cooooo0_l000000ooooooo0000ooooo`0Wooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool0Goooool005Oooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01_ooooo00?o0000ooooool00000:Ooo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo05oooooo001Hooooo`03o`000?oooooo
oooo00gooooo0_l0000]ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooool00000:Oooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo063ooooo001Iooooo`;o00002oooool2o`00
02oooooo00?o0000ooooooooool06oooool2o`0002_ooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`1Pooooo`00Foooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool06_ooool2o`0002_ooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`1Pooooo`00G?ooool3o`0000Cooooo0_l0000cooooo`03o`000?oooooooooo01[ooooo
0_l0000[ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0HOooool005kooooo1Ol0
000fooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:oooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo067ooooo002Iooooo`03o`000?oooooooooo01Sooooo0_l0000]
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0HOooool009[ooooo00?o0000oooo
ooooool05oooool2o`0002gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Roooo
o`00V_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo000002kooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`1Rooooo`00Voooool00ol0003oooooooooo`0Eooooo`04o`00
0?oooooo0000o`0002gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Rooooo`00
Voooool00ol0003oooooooooo`0Dooooo`04o`000?ooooooooooo`0002kooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`1Sooooo`00W?ooool00ol0003oooooooooo`0Cooooo`04o`00
0?ooooooooooo`0002kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Sooooo`00
W?ooool00ol0003oooooooooo`0Booooo`05o`000?ooooooooooooooool00000;oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo06?ooooo002Looooo`03o`000?oooooooooo01;ooooo
00Go0000ooooooooooooooooo`00000_ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0Hoooool009gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`;o0000
;_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo06Cooooo002Mooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool0I?ooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q00Co0000oooooooooooooooo1Ol00004ooooo`06odA4A?l0003o0000oc8b<_oM
gMgo00001?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool0I?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q00Wo0000oooo
oooooooooooooiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo0000ooooo`04ooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1Uooooo`00T_oo
ool01Ol@413ooooooooooooooooo410@00Sooooo00Oo0000oooooooooooooooooiRHV?lQ8B7ok^k^
00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0IOooool009;ooooo00Go0000ooooooooooooooooo`000009oooo
o`07o`000?oooooooooooooooonHV9So8B4Qonk^kP07ooooo`03o`000?lb<S;ooooo00Cooooo0ol0
000_ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0IOooool009;ooooo00Go0000
ooooooooooooooooo`000009ooooo`03o`000?oooooooooo00;ooooo00?oMgMgofIVI_ooool00ooo
ool01Ol0003o8B4Qo`000?l0003oc<c<00Gooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo06Kooooo002Booooo`05oa0@4?ooooooooooooooool@4100
2_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000
1oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
I_ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0:ooooo`;o000000Co^[ZjoooooonHV9So
410@1?ooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`1Vooooo`00T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00Go0000oa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Ioooool00:;ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`07ooooo`;o0000<Oooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo06Oooooo002Sooooo`03o`000?oooooooooo00Cooooo0_l00009ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Wooooo`00Y?oo
ool3o`000003ooooool0003o000000_ooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo06Sooooo002Vooooo`?o00003?ooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0J?ooool00;Gooooo00?o0000oooo
ooooool0<_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo06Sooooo002eooooo`;o
0000<oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo06Wooooo002eooooo`03o`00
0?oooooooooo03;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Yooooo`00]Ooo
ool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0JOoo
ool00;Gooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo06[ooooo002eooooo`;o0000=?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
06[ooooo002eooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`1Zooooo`00]Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0Joooool00;Gooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo06_ooooo002eooooo`03o`000?oooooooooo03Gooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`1[ooooo`00]Oooool2o`0003Kooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`1/ooooo`00]Oooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0K?ooool00;Gooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo06cooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1/ooooo`00
V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo06go
oooo002Jooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`?o
0000=_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo06gooooo002Jooooo`05o`00
0?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1]ooooo`00V_ooool01Ol0003ooooo
oooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1^ooooo`00V_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Koooool009[ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo06oooooo002Jooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0000Kooooo0_l0000jooooo`05o`000?ooooooooooooooool00000L_ooool0
0;Gooooo00?o0000ooooooooool0>_ooool4o`0007;ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0/?ooool009;ooooo00Go410@oooooooooooooooooa0@400=
ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2`
ooooo`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool0
0omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oo
oooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgoooo
o`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00:_ooooo1?l000000ol@
413oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0/?ooool00:gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000
ooooooooool0^?ooool00:gooooo00?o0000ooooooooool0^?ooool00:gooooo00?o0000oooooooo
ool0^?ooool00:_ooooo00?oEEEEofIVI_l00000^_ooool00?ooooooJOooool00:oooooo00?o0000
okZj^_ooool0]_ooool00:oooooo0_lb<S:gooooo`00P?ooool2o`000006oa0@4?oooooooooooa0@
4?l0003o410@5oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`03ohN7Qol0
003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Iooooo`Co000000?o410@ooooooooool0
0_ooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^07Sooooo0021oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`0000Wooooo00GoV9RHob4Q
8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool00oo<c<co0000oa0@
400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0N?ooool0087ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400Booooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool00_ooool5o`0000?ooooo00Go410@oooooooooooooooooa0@401hooooo`00POooool01_l0003o
ooooodA4A?m4A4Coooooo`0000Wooooo1_l0000;ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000
ooooooooooooooooo`00000Booooo`03o`000?oooooooooo00_ooooo1_l0000<ooooo`03o`000?oo
oooooooo00;ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000007So
oooo0021ooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo00006oooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo00;ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000007Sooooo
0021ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo00007?ooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool03_ooool00ol@413o0000o`000003o`0001cooooo00?o0000oooo
ooooool00oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@4100N?ooool0
087ooooo00Ko0000oc8b<_oooooooooooc8b<_l0000Hooooo`05o`000?nj^[[ooooooiRHV?l@4100
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`03ooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1hoooo
o`00P?ooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Oooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0K
ooooo`03oeEEEOmVIVKo000000Kooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^07Sooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(150) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .2896 m
.04057 .28075 L
.06168 .2738 L
.06747 .2721 L
.07365 .27051 L
.07945 .2693 L
.08481 .26845 L
.08741 .26815 L
.09017 .26791 L
.0916 .26783 L
.09294 .26777 L
.09371 .26774 L
.09441 .26772 L
.09522 .26771 L
.09599 .26771 L
.09726 .26772 L
.09861 .26776 L
.09989 .26781 L
.10105 .26788 L
.10241 .26799 L
.10389 .26813 L
.10656 .26846 L
.10895 .26885 L
.11158 .26938 L
.11687 .27077 L
.12178 .27248 L
.12636 .27444 L
.13733 .28067 L
.14773 .2885 L
.16721 .30717 L
.18634 .32692 L
.19158 .33166 L
.19723 .33608 L
.20257 .33942 L
.2051 .34067 L
.20746 .34164 L
.20979 .34239 L
.21099 .34269 L
.21229 .34296 L
.21303 .34308 L
.21371 .34318 L
.21506 .34331 L
.21628 .34336 L
.21757 .34336 L
.21884 .34329 L
.22019 .34314 L
.22147 .34294 L
.22264 .34269 L
.22551 .34187 L
.22822 .3408 L
Mistroke
.2337 .33785 L
.23878 .33425 L
.25028 .32369 L
.27006 .30205 L
.29142 .28119 L
.30316 .27272 L
.30831 .2698 L
.31395 .2672 L
.31652 .26622 L
.31928 .26532 L
.32167 .26467 L
.32426 .2641 L
.32578 .26383 L
.32718 .26363 L
.32853 .26347 L
.32921 .26341 L
.32995 .26335 L
.33123 .26328 L
.33242 .26324 L
.33311 .26324 L
.33384 .26324 L
.33514 .26328 L
.33644 .26335 L
.33717 .26341 L
.33785 .26348 L
.33907 .26362 L
.34041 .26382 L
.34273 .26427 L
.34519 .26488 L
.35073 .26682 L
.35591 .26937 L
.36078 .27248 L
.36522 .27596 L
.37521 .2862 L
.3856 .30069 L
.39522 .31764 L
.41701 .36488 L
.42643 .38505 L
.43137 .39424 L
.43658 .40223 L
.43936 .40561 L
.4424 .40854 L
.44373 .40956 L
.44516 .41045 L
.44651 .4111 L
.44773 .41154 L
.44907 .41184 L
.45031 .41195 L
.45168 .4119 L
.45236 .4118 L
Mistroke
.45312 .41163 L
.45438 .41122 L
.45575 .41059 L
.45821 .409 L
.46087 .40661 L
.46371 .40336 L
.46883 .39587 L
.48041 .37313 L
.50151 .32593 L
.51232 .30507 L
.52401 .28712 L
.53505 .2746 L
.54519 .26647 L
.55013 .26354 L
.55543 .26107 L
.55799 .2601 L
.56042 .25933 L
.56259 .25875 L
.56498 .25822 L
.5676 .25778 L
.56903 .2576 L
.57038 .25747 L
.57163 .25738 L
.57278 .25733 L
.57404 .2573 L
.57537 .2573 L
.57673 .25734 L
.57748 .25738 L
.57817 .25742 L
.57951 .25754 L
.58077 .25768 L
.58361 .25811 L
.58668 .25876 L
.59182 .26028 L
.59663 .26224 L
.6019 .26502 L
.60756 .26885 L
.61349 .27394 L
.61911 .27992 L
.62966 .2947 L
.63977 .31395 L
.65052 .34061 L
.66984 .40245 L
.68068 .43822 L
.68638 .4542 L
.68948 .4615 L
.69238 .4672 L
.69493 .47123 L
.69765 .47443 L
.6984 .4751 L
Mistroke
.69921 .47572 L
.69992 .47618 L
.70068 .47657 L
.70136 .47685 L
.70211 .47706 L
.70343 .47719 L
.70475 .47704 L
.70595 .47664 L
.70662 .47631 L
.70735 .47588 L
.70867 .47485 L
.71121 .4721 L
.71358 .46865 L
.7189 .45805 L
.72467 .44298 L
.73512 .41008 L
.75465 .34918 L
.76463 .32468 L
.77558 .3039 L
.7811 .29563 L
.78701 .28818 L
.79256 .28239 L
.79769 .2779 L
.80837 .27075 L
.814 .26791 L
.81998 .26544 L
.83002 .26232 L
.83574 .26103 L
.84111 .26012 L
.84603 .2595 L
.84883 .25924 L
.85142 .25905 L
.85284 .25897 L
.85418 .25891 L
.85539 .25886 L
.85668 .25882 L
.85734 .2588 L
.85808 .25879 L
.85937 .25877 L
.8601 .25877 L
.86088 .25876 L
.86162 .25877 L
.86229 .25877 L
.86349 .25879 L
.86476 .25881 L
.86597 .25884 L
.86706 .25888 L
.86973 .25901 L
.87225 .25916 L
.8768 .25955 L
Mistroke
.88172 .26011 L
.88689 .26088 L
.89172 .26175 L
.90268 .26425 L
.92481 .27101 L
.94582 .27863 L
.95616 .28225 L
.96571 .28517 L
.97368 .28714 L
.97775 .28795 L
.98214 .28866 L
.98443 .28896 L
.98652 .28919 L
.98865 .28938 L
.99063 .28952 L
.99169 .28957 L
.99282 .28962 L
.99407 .28965 L
.9952 .28967 L
.99639 .28968 L
.99767 .28966 L
.99888 .28964 L
1 .2896 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool04?ooool:o`00053ooooo3?l0
000jooooo`00]Oooool2o`0000oooooo0_l0000:ooooo`?o0000B?ooool5o`0000cooooo1ol0000c
ooooo`00Noooool:o`00033ooooo00?o0000ooooooooool03?ooool2o`0000oooooo0_l00013oooo
o`?o00006?ooool3o`00033ooooo000Eooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o
0000oc8b<_o^k^h03_ooool;o`000006oooooonHV9So410@o`000?lb<S;oc<c<0oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^01_ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02_ooool2
o`0000[ooooo0_l00004ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQko
oooo00?o0000ooooooooool02_ooool2o`0001?ooooo1?l000002?l@413oooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^6_ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`;o0000
2oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06oooo
o`?o00005?ooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00kooooo
000Fooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0:ooooo`Co0000
2oooool3o`000003oooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo0_l0000>
ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Cooooo0_l00004ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL06_ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`;o00003Oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`09ooooo`Co00004Oooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03_ooool000_ooooo1_l00002ooooo`Go00000oooool01Ol@413ooooooooo
oooooooo410@00Sooooo0_l00008ooooo`Ko00001?ooool4o`0000;ooooo00Go410@oooooooooooo
oooooa0@400Cooooo`Ko00000oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?oooooooooooooo
ool@41001_ooool2o`0000_ooooo1_l000000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@400Nooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41006ooo
ool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41002oooool00ol0003ooooo
ooooo`0Aooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0;ooooo`?o
00002oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`004oooool01?m4A4Co
gMgMooooool00004ooooo`05o`000?ooooooooooooooool000001Oooool3o`0001Gooooo00KoZJVY
oa0@4?oooooo0000ooooool00003ooooo`03o`000?oooooooooo01_ooooo00?oV9RHob4Q8Oo^k^h0
0oooool01Ol0003ooooooooooooooooo000000Cooooo0_l0000Eooooo`04o`000?ooooooooooo`00
00Cooooo00Go0000ooooooooooooooooo`00000Nooooo`;o00002Oooool00ol0003oooooooooo`0F
ooooo`;o00000oooool01Ol0003ooooooooooooooooo000001cooooo00?oV9RHob4Q8Oo^k^h00ooo
ool01Ol0003ooooooooooooooooo000000[ooooo00?o0000ooooooooool04Oooool00onYZJWo410@
ooooo`02ooooo`05o`000?ooooooooooooooool000004?ooool3o`0000Sooooo00CoA4A4omgMgOoo
oooo00001?ooool01Ol0003ooooooooooooooooo000000kooooo000Cooooo`04omgMgOmEEEGooooo
o`0000Cooooo00Ko0000ooooooooooooooooo`000?ooool4o`0001Oooooo00?o410@o`000?nj^[X0
0_ooool2o`0000?ooooo00?o0000ooooooooool07?ooool00omgMgOoIVIVooooo`02ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo000000Co
oooo00Go0000ooooooooooooooooo`00000Nooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool05oooool00ol0003oooooo`000002ooooo`05o`000?ooooooooooooooool000007Oooool0
0omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000002Oooool00ol0003ooooooooo
o`0Aooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00000Cooooo`03o`00
0?oooooooooo00Gooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo0000
00kooooo000Dooooo`03ogMgMoo<c<co000000Cooooo00?o410@o`000?l000000ol0000Looooo`03
okZj^_lQ8B7ooooo00;ooooo00Go410@o`000?oooooooooooa0@400Oooooo`05o`000?oooooooooo
ooooool@41000oooool01Ol@413ooooooooooooooooo000001Wooooo0_l00004ooooo`05oa0@4?oo
ooooooooooooool@41007_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooool000000_ooool01Ol@413ooooooooooooooooo410@01kooooo00Go0000oooooooo
oooooooooa0@4003ooooo`03oa0@4?oooooooooo00Gooooo0_l0000Eooooo`03okZj^_lQ8B7ooooo
00;ooooo00Go410@oooooooooooooooooa0@400Dooooo`?o00001Oooool00omgMgOoc<c<o`000004
ooooo`05oa0@4?ooooooooooooooool@41003_ooool001Cooooo00Cok^k^odA4A?l0003ooooo1?l0
00001?nHV9SooooooiRHV?mgMgLJooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOo
V9RHo`000?nHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
6Oooool02_l0003oooooooooool0003oooooogMgMonHV9SooooooiRHV?mgMgLJooooo`05o`000?nj
^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000oooooooo
ool04_ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0G
ooooo`Go000000?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000E
ooooo`03ogMgMol0003o000000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Jooooo`05ojVYZOl@
413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?l0003ok^k^01_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c003ooooo`07onk^k_lb<S;o0000oc8b<_o^k^koooooo`00000Jooooo`03oeEEEOmV
IVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Nooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool05oooool00omEEEGoIVIVo`000003ooooo`06o`000?o^k^ko<S8bo`000?lb
<S;ok^k^6_ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP06ooooo`03o`000?oooooooooo01;ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h07?ooool7o`000005onk^k_lb<S;o0000oc8b<_o^k^h03_ooool004Ko
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Co
oooo0_l00005ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`1Fooooo`00Aoooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Gooooo`00B?ooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`1Gooooo`00BOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`1Hooooo`00B_ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08Oooool01Ol0003ooooooooooooooooo
000002Gooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1Hooooo`005_ooooooo`00
043o00004oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
4Oooool001Kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo01Gooooo00Co0000oooooooooooo00009?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo01oooooo00Co0000oooooooooooo00009?ooool01Ol0003ooooooooooooooooo0000
02;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool04Oooool004kooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo01kooooo00?o0000ooooool00000:Oooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo05[ooooo001?ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Nooooo`;o0000:oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo05_ooooo001@ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`0Mooooo`;o0000:oooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo05cooooo001Aooooo`;o00004Oooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo05cooooo001Cooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`1Mooooo`00Doooool00ol0003oooooooooo`0;ooooo`;o
0000<oooool00ol0003oooooooooo`0Kooooo`;o0000;_ooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo05gooooo001Dooooo`;o00002Oooool2o`0003Gooooo00?o0000ooooooooool0
6oooool2o`0002kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1Mooooo`00E_oo
ool2o`0000Kooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Jooooo`?o0000;_oo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo05kooooo001Hooooo`Ko0000>Oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooo000002oooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`1Nooooo`00Uoooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo0000
02oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1Nooooo`00V?ooool00ol0003o
ooooooooo`0Gooooo`04o`000?ooooooooooo`00033ooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`1Oooooo`00V?ooool00ol0003oooooooooo`0Gooooo`04o`000?ooooooooooo`00
033ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Oooooo`00VOooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo00;o0000;oooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo05oooooo002Iooooo`03o`000?oooooooooo01Gooooo00Go0000oooooooooooo
ooooo`00000aooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0H?ooool009Wooooo
00?o0000ooooooooool05Oooool01Ol0003ooooooooooooooooo0000037ooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`1Pooooo`00V_ooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo063ooooo002Jooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0HOoo
ool009_ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`02ooooo`;o0000<Oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo067ooooo002Kooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool0HOooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`03o`000?lQ8B7ooooo00?ooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_l000001Oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0H_ooool0
09;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?lQ8B7ooooo00?ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A007ooooo`03o`000?lb<S;ooooo00Cooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo06;ooooo002Booooo`05oa0@4?oooooo
ooooooooool@41001_ooool00ol0003oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00Sooooo0_l0
0005ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`1Rooooo`00T_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01?oo
ool00onHV9So8B4Qonk^kP06ooooo`03o`000?mgMgOo<S8b00Gooooo0ol0000aooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0Hoooool009;ooooo00Go0000ooooooooooooooooo`00
0007ooooo`03o`000?oooooooooo00Cooooo00?oMgMgofIVI_ooool00oooool3o`000003oc8b<_o<
c<cooooo00Cooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo06?ooooo002Booooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo0_l00008ooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`1Sooooo`00T_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Sooooo00So0000oooooooooooo0000okZj^_ooooooV9RHoa0@40Cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0I?ooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP09ooooo`07o`000?ooooooV9RH
oa0@4?l0003o8B4Qolc<c003ooooo`Go00001_ooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0I?ooool00:7ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`09ooooo`;o0000=?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo06Cooooo002Rooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0IOooool00:?o
oooo00Co0000oooooooooooooooo0_l0000<ooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`1Uooooo`00Y?ooool3o`0000kooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06Gooooo002eooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Vooooo`00]Ooo
ool2o`0003Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Vooooo`00]Oooool0
0ol0003oooooooooo`0eooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0I_ooool0
0;Gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
06Oooooo002eooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`1Wooooo`00]Oooool2o`0003Kooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`1Wooooo`00]Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0J?ooool00;Gooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo06Sooooo002eooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`1Xooooo`00]Oooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool0JOooool00;Gooooo0_l0000hooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0JOooool00;Gooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo06Wooooo002eooooo`03o`000?oooooo
oooo03Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Zooooo`00V_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0J_oo
ool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1Zooooo`00V_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00ooo
ool3o`0003Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Zooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`0jooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Joooool009[ooooo00Go0000
ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0K?ooool009[ooooo00Go
410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06gooooo002Jooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03cooooo
0_l000000ooooooo0000ooooo`1_ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l00006ooooo`;o0000?_ooool2o`00077ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o
0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0
/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVY
ooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009;ooooo00Go
410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000kooooo
00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go
0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@
41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooo
oolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool00:_ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002]
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool00:gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o
0000/?ooool00:gooooo00?o0000ooooooooool0^?ooool00:gooooo00?o0000ooooooooool0^?oo
ool00:gooooo00?o0000ooooooooool0^?ooool00:_ooooo00?oEEEEofIVI_l00000^_ooool00?oo
ooooJOooool00:oooooo00?o0000okZj^_ooool0]_ooool00:oooooo0_lb<S:gooooo`00P?ooool2
o`000006oa0@4?oooooooooooa0@4?l0003o410@5oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Ioooo
o`Co000000Go410@ooooooooooooooooodA4A002o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^07Sooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1oooool6o`0000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6
o`0000cooooo00?o0000ooooooooool01_ooool02OmgMgOo<S8booooooooooooMgMgoiRHV?oooooo
V9RHogMgM`1hooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Oooooo
00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01;ooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@oooo
ooooool0M_ooool0087ooooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00002oooool0
0onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003ooooooooo
o`0;ooooo`Ko00003?ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool00000
0oooool00ol0003oooooooooo`1fooooo`00POooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001_o
oooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool0
1Ol0003ooooooooooooooooo000007Sooooo0021ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo0000
7?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool03_ooool00ol@413o
0000o`000003o`0001cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05
oa0@4?ooooooooooooooool@4100N?ooool0087ooooo00Ko0000oc8b<_oooooooooooc8b<_l0000H
ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`1hooooo`00P?ooool00ol@413o0000ohN7Q`02ooooo`03ohN7
Qol0003o410@01Oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h04_ooool00ol0003oooooooooo`0Kooooo`03oeEEEOmVIVKo000000Gooooo1?l00003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h0N?ooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(160) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .28468 m
.01975 .27789 L
.04057 .27038 L
.0515 .2672 L
.05673 .266 L
.06168 .26508 L
.06449 .26467 L
.06753 .26432 L
.06888 .26419 L
.0703 .26409 L
.07152 .26401 L
.07286 .26395 L
.07365 .26393 L
.07441 .26391 L
.07509 .2639 L
.07583 .2639 L
.07663 .2639 L
.07749 .26391 L
.07829 .26393 L
.07903 .26396 L
.08046 .26403 L
.082 .26414 L
.08346 .26428 L
.08481 .26443 L
.08974 .26521 L
.09251 .26581 L
.09503 .26647 L
.10457 .26988 L
.10991 .27246 L
.11572 .27582 L
.12627 .28342 L
.14662 .3028 L
.15744 .31454 L
.16909 .32673 L
.1745 .33174 L
.18019 .3363 L
.18504 .33946 L
.18783 .34092 L
.19036 .34201 L
.19293 .34287 L
.19411 .34318 L
.19536 .34345 L
.19669 .34367 L
.19792 .34381 L
.19924 .34389 L
.2 .3439 L
.2007 .3439 L
.20194 .34384 L
.20312 .34372 L
.20418 .34357 L
Mistroke
.20534 .34335 L
.20792 .34267 L
.21032 .34181 L
.21567 .33913 L
.22145 .33515 L
.23191 .32572 L
.25146 .30441 L
.27203 .28345 L
.28369 .27409 L
.28928 .27041 L
.29457 .26743 L
.2996 .26505 L
.30507 .26297 L
.31003 .26154 L
.31224 .26104 L
.31462 .2606 L
.31596 .2604 L
.31718 .26024 L
.31842 .26011 L
.31958 .26002 L
.32085 .25994 L
.32152 .25992 L
.32224 .2599 L
.32299 .25988 L
.32371 .25988 L
.32504 .25991 L
.32638 .25997 L
.32706 .26002 L
.3278 .26008 L
.33034 .26036 L
.33178 .26059 L
.33331 .26087 L
.33609 .26152 L
.34162 .26332 L
.34675 .26565 L
.35238 .269 L
.35836 .27356 L
.3684 .28373 L
.37948 .29906 L
.39977 .33826 L
.41022 .36198 L
.42166 .38663 L
.42692 .39615 L
.42981 .40062 L
.43255 .40425 L
.43509 .40706 L
.43785 .40945 L
.43907 .41027 L
.44036 .41097 L
.44147 .41144 L
Mistroke
.44268 .41182 L
.44339 .41197 L
.44416 .41208 L
.44488 .41212 L
.44556 .41211 L
.44683 .41196 L
.44819 .41162 L
.44896 .41135 L
.44979 .41098 L
.4513 .41014 L
.45412 .40798 L
.45683 .40519 L
.45969 .40154 L
.46483 .39345 L
.4857 .34889 L
.50472 .3095 L
.51525 .29258 L
.52522 .28021 L
.53574 .27073 L
.54169 .26679 L
.54718 .26395 L
.55205 .26199 L
.55461 .26115 L
.5573 .26041 L
.55967 .25986 L
.56226 .25937 L
.56461 .25903 L
.5668 .2588 L
.56815 .25869 L
.56886 .25864 L
.56962 .25861 L
.571 .25856 L
.57228 .25854 L
.57351 .25855 L
.57465 .25858 L
.57591 .25864 L
.57726 .25873 L
.57869 .25885 L
.58026 .25902 L
.5831 .25943 L
.58587 .25995 L
.58843 .26053 L
.59379 .26208 L
.59957 .26427 L
.60467 .26669 L
.61004 .2698 L
.62023 .27762 L
.6296 .28758 L
.63958 .30194 L
.65027 .32242 L
Mistroke
.66954 .37416 L
.6904 .44064 L
.69611 .45563 L
.69924 .46239 L
.70217 .46761 L
.70466 .47109 L
.70595 .47252 L
.70735 .47379 L
.70814 .47437 L
.70887 .47482 L
.70963 .4752 L
.71032 .47546 L
.71164 .47573 L
.71236 .47576 L
.71305 .47571 L
.7143 .47542 L
.71548 .47492 L
.71676 .4741 L
.71814 .47294 L
.72096 .46965 L
.72353 .46562 L
.72848 .45539 L
.73318 .44321 L
.75496 .3736 L
.76509 .34381 L
.77585 .31794 L
.78505 .30075 L
.79519 .28645 L
.80035 .28081 L
.80578 .27589 L
.8155 .2693 L
.82091 .26663 L
.82595 .26468 L
.83148 .26306 L
.83458 .26237 L
.83739 .26186 L
.83982 .26151 L
.84248 .26122 L
.84382 .26111 L
.84526 .26101 L
.84662 .26094 L
.84787 .2609 L
.8491 .26088 L
.85024 .26087 L
.85149 .26088 L
.85282 .26091 L
.85409 .26095 L
.85529 .26101 L
.85753 .26116 L
.86019 .26141 L
Mistroke
.863 .26173 L
.86802 .26249 L
.87936 .26489 L
.88933 .26768 L
.90001 .27123 L
.91927 .27838 L
.92998 .2822 L
.94161 .28576 L
.94694 .28708 L
.95259 .28822 L
.95742 .28896 L
.96017 .28927 L
.96141 .28938 L
.96274 .28949 L
.96397 .28957 L
.96509 .28962 L
.96621 .28967 L
.96727 .28969 L
.96851 .28971 L
.96965 .28971 L
.9709 .28969 L
.97222 .28965 L
.97341 .2896 L
.97468 .28953 L
.97697 .28935 L
.9797 .28906 L
.98219 .28873 L
.98657 .288 L
.99133 .28699 L
1 .28468 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool007cooooo0_l0000gooooo`03o`000?oooooooooo013ooooo2?l0
002Hooooo`00M_ooool7o`000003ooooool0003o000000;o0000<oooool2o`0000kooooo0ol00008
ooooo`Go0000B_ooool>o`0003_ooooo000Wooooo`go0000@?ooool2o`0000cooooo1?l0000_oooo
o`03o`000?oooooooooo00_ooooo0_l0000@ooooo`03o`000?oooooooooo04Cooooo0ol0000>oooo
o`Co0000=oooool001Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o00003Oooool3o`0000?ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h06oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hNooooo`03o`000?oooooooooo00Wooooo0_l0000Cooooo`Go0000
00So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQ[ooooo1Ol00003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03oooool3o`0000Wooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`04onk^
k_lb<S;o0000oc8b<P?o00006oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb
<S;ok^k^00kooooo000Fooooo`03o`000?oooooooooo00;ooooo00KoMgMgoiRHV?ooooooV9RHogMg
Moooool4o`0001;ooooo0ol000001Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0Kooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00;ooooo0_l0000Dooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Eooooo`;o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00GoV9RHob4Q8Oo^
k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`0:
ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo
0ol0000Iooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`00
2oooool6o`0000;ooooo1Ol00003ooooo`03oa0@4?oooooooooo00?o00004Oooool6o`0000;ooooo
00Go0000ooooooooooooooooo`000003ooooo`05oa0@4?ooooooooooooooool@41004oooool6o`00
00?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00;o00004Oooool7
o`0000Cooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Gooooo`;o00000oooool01Ol@413ooooooooo
oooooooo410@01_ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00go
oooo00?o0000ooooooooool03oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@oooo
ooooool00oooool3o`0001?ooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41003_ooool0
01?ooooo00CoA4A4omgMgOoooooo00001?ooool3o`000003ooooool0003ooooo01[ooooo0_l00000
0onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00onHV9So8B4Qonk^
kP03ooooo`05o`000?ooooooooooooooool000006_ooool01Ol0003ooooooooooooooooo000000Co
oooo00Go0000ooooooooooooooooo`00000Nooooo`;o00001oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`00000Looooo`03oiRHV?lQ8B7o
k^k^00?ooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo00oooooo00?o
ZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000Sooooo0_l0000Aooooo`04odA4
A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`004oooool01OoMgMgo
EEEEooooool0003ooooo00Co00000oooool00ol0003oooooooooo`0Jooooo`03oa0@4?l0003o^[Zj
00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03ogMgMomVIVKooooo00;ooooo00?o0000
ooooooooool00_l0000Kooooo`04o`000?ooooooooooo`0000Cooooo00Go0000oooooooooooooooo
o`00000Nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06Oooool01_l0003ooooo
ooooool0003oooooo`0000?ooooo00?o0000ooooooooool06oooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`0?ooooo`03oa0@4?l0003o
^[Zj00?ooooo00Go0000ooooooooooooooooo`00000:ooooo`;o00003oooool01?oMgMgoEEEEoooo
ool00004ooooo`05o`000?ooooooooooooooool000003_ooool001Cooooo00CoMgMgolc<c?l0003o
00000oooool01Ol@413ooooooooooooooooo410@01gooooo00?o^[Zjo`000?ooool00_ooool01Ol@
413ooooooooooooooooo410@01oooooo00Wo0000oooooooooooooooooa0@4?oooooo0000ooooool@
41007?ooool00ol0003oooooo`000004ooooo`05oa0@4?ooooooooooooooool@41007_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo01Wooooo00Ko0000ooooooooooooooooo`000?l@
4103ooooo`03oa0@4?oooooooooo01cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@
4?oooooooooo00Sooooo00?o0000ooooooooool04Oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@
4?ooooooooooooooool@41003?ooool3o`0000gooooo00?oMgMgolc<c?l000000_ooool2o`000005
oa0@4?ooooooooooooooool@41003_ooool001Cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg01[ooooo00Co410@oiRHV?oooooo^[Zj0_l00002ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL06oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?l0003o
V9RHogMgM`0Looooo`03o`000?oooooo000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Noooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02oooo
o`05o`000?nHV9SooooooiRHV?mgMgL06_ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`09ooooo`03o`000?oooooooooo00oooooo00Go410@oiRHV?oooooo
^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03oooool4o`0000Wooooo00?ok^k^o`00
0?l000000_l00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool001Gooooo00?oMgMgo`00
0?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00goZJVYoa0@4?l0003o410@ojVY
ZOoooooo0000ooooooo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c003ooooo`05onk^k_l0003o0000oc8b<_o^k^h07?ooool00omEEEGo0000o`000004ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h07_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Wo
oooo00?oEEEEofIVI_l000001?ooool01Ol0003o<S8bo`000?lb<S;ok^k^01[ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02Oooool00ol0003ooooooooo
o`0?ooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01?o
oooo2_l000000omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool0047o
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02Go
oooo0_l00003ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`1Cooooo`00@_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Dooooo`00@oooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool08oooool01Ol0003ooooooooo
oooooooo000002Kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Dooooo`00A?oo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool08ooo
ool01?l0003oooooooooool0000Xooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
EOooool004Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooool00000:Oooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo05Gooooo000Foooooooo0000@?l0000Cooooo`005_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04oooo
o`;o00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
000000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo017ooooo000Fooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooo000002Oooooo00Go0000ooooooooooooooooo`00000S
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo017ooooo0019ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`1Hooooo`00B_ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool07oooool2o`0002oooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1Hooooo`00Boooool00ol0003oooooooooo`0Aooooo`;o0000
<_ooool00ol0003oooooooooo`0Nooooo`?o0000;_ooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo05Wooooo001<ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooo0000033ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`1Iooooo`00COooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool07?ooool00ol0003oooooo`00000`ooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool0F_ooool004kooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000<?ooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo05[ooooo001?ooooo`;o00002_ooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo01[ooooo00Co0000oooooooooooo0000<Oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo05_ooooo001Aooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;o
0000<?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo05_ooooo001Booooo`So0000
??ooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool00000<Oooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo05cooooo002Fooooo`03o`000?oooooooooo01Sooooo
00Go0000ooooooooooooooooo`00000booooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool0G?ooool009Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Looooo`00Uooo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05gooooo002Gooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool00oooool2o`0003;ooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`1Mooooo`00Uoooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
05gooooo002Hooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0G_ooool009Sooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Nooooo`00VOooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo05kooooo002Iooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool01Oooool2o`0003?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1O
ooooo`00V_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo05oooooo002Booooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01?l0003oooooob4Q8OlQ8B44ooooo`Go00001?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo05oooooo002Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01?oo
ool00ol0003o8B4Qob4Q8@04ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool01?l0003ooooo
ogMgMolb<S85ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`1Oooooo`00T_ooool01Ol@413ooooooooooooooooo410@00Cooooo00?o0000oooooooo
ool01Oooool00onHV9So8B4Qonk^kP05ooooo`05o`000?ooooooooooooooool000001Oooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0H?ooool009;o
oooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?oV9RHob4Q
8Oo^k^h01?ooool01Ol0003ooooooooooomgMgOo<S8b00Gooooo0ol0000dooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool0H?ooool009;ooooo00Go0000ooooooooooooooooo`000005
ooooo`03o`000?oooooooooo00Kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Gooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo063ooooo002Booooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooooooo
o`06ooooo`04o`000?ooooooooooooooo`;o00002Oooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0HOooool009;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`07ooooo`09o`000?ooooooooooooooool0003o^[ZjoooooonHV9So410@00?ooooo0_l00009
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Q
ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00So0000ooooooooooooV9RHoa0@
4?l0003o8B4Qolc<c0;ooooo00?o0000ooooool000000ol00006ooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Qooooo`00Woooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00[ooooo0_l0000fooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0H_ooool00:3ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`1Rooooo`00XOooool01?l0003oooooooooooooool2o`0000kooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo06;ooooo002Rooooo`Co00003oooool0
0ol0003oooooooooo`0fooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0Hoooool0
0;Gooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
06?ooooo002eooooo`;o0000>?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo06?o
oooo002eooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`1Tooooo`00]Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0I?ooool00;Gooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo06Cooooo002eooooo`;o0000>Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo06Gooooo002eooooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`1Uooooo`00]Oooool00ol0003oooooooooo`0iooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0IOooool00;Gooooo00?o0000ooooooooool0>Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo06Kooooo002eooooo`03o`000?oooooo
oooo03Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Vooooo`00]Oooool2o`00
03_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Vooooo`00]Oooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0I_ooool00;Gooooo
00?o0000ooooooooool0>_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo06Oooooo
002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`1Wooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo06Oooooo002Jooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003o
ooooooooo`03ooooo`?o0000??ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06So
oooo002Jooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo03cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Yooooo`00
V_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005oooo
o`03o`000?oooooooooo03gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Zoooo
o`00V_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0nooooo`05o`000?ooooooooooooooool00000KOooool009[ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0?oooool4
o`0006gooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0002a
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003Oooool0
0onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool0
09;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMg
oc8b<_ooool01?ooool3o`000;3ooooo002Booooo`05o`000?ooooooooooooooool000003_ooool0
0omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002[ooooo`Co000000?o410@oooo
ooooool00oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
/?ooool00:gooooo00?o0000ooooooooool01Oooool3o`000;3ooooo002]ooooo`03o`000?oooooo
oooo0;Sooooo002]ooooo`03o`000?oooooooooo0;Sooooo002]ooooo`03o`000?oooooooooo0;So
oooo002[ooooo`03oeEEEOmVIVKo00000;[ooooo003oooooofWooooo002_ooooo`03o`000?nj^[[o
oooo0;Kooooo002_ooooo`;o<S8b]oooool0083ooooo0_l000001_l@413oooooooooool@413o0000
oa0@41Oooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOo0000okZj
^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06Oooool4o`000008oa0@4?ooooooooooonk^k_lb
<S;o0000oa0@4?o<c<`3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0N?ooool0087ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00002Oooool01OnHV9So8B4Qonk^k_oo
ooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03olc<c?l0003o410@00cooooo
00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003oooooooooo`02ooooo`05
oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg07Sooooo0021oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41004_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05oa0@4?ooooooooooooooool@4100
N?ooool0087ooooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00002oooool00onHV9So
8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0;oooo
o`Ko00003?ooool00ol0003oooooooooo`02ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool0
1Ol0003ooooooooooooooooo000007Sooooo0021ooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo0000
6oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo00Go0000oeEEEOl0003o410@olc<c003oooo
o`05o`000?ooooooooooooooool00000N?ooool0087ooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0
000Looooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0>ooooo`03oa0@
4?l0003o000000?o00007?ooool00ol0003oooooooooo`02ooooo`03oeEEEOn7QhOooooo00Gooooo
00Go410@oooooooooooooooooa0@401hooooo`00POooool01_l0003o<S8boooooooooooo<S8bo`00
01Sooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo00?ogMgMoa0@4?nHV9P01Ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg07Sooooo0020ooooo`03oa0@4?l0003oQhN700;ooooo00?o
QhN7o`000?l@41005oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0Booooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000001Oooool01?o<c<co
A4A4o`000?l@4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0N?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(170) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .2745 m
.00942 .2708 L
.01975 .26713 L
.03065 .26394 L
.0354 .26283 L
.04057 .26185 L
.04352 .26141 L
.04626 .26108 L
.04887 .26085 L
.05018 .26076 L
.05163 .26069 L
.05242 .26066 L
.05317 .26064 L
.05384 .26063 L
.05458 .26063 L
.05537 .26063 L
.05622 .26063 L
.05702 .26065 L
.05775 .26067 L
.05848 .2607 L
.05916 .26074 L
.06069 .26084 L
.06204 .26095 L
.06347 .2611 L
.06601 .26142 L
.06873 .26187 L
.07364 .26295 L
.07948 .2647 L
.08481 .26674 L
.09522 .27207 L
.10485 .27863 L
.12665 .29874 L
.14791 .32179 L
.15833 .33192 L
.16289 .33565 L
.16788 .33907 L
.1702 .34039 L
.17269 .34159 L
.17484 .34245 L
.17717 .34318 L
.17854 .34351 L
.1798 .34375 L
.18101 .34392 L
.18229 .34403 L
.18344 .34408 L
.18451 .34408 L
.18569 .34402 L
.18695 .3439 L
.18832 .34369 L
.18959 .34343 L
Mistroke
.19246 .34262 L
.195 .34165 L
.1977 .34035 L
.20751 .33365 L
.21834 .32347 L
.23004 .31073 L
.25123 .28802 L
.27221 .27072 L
.28276 .26457 L
.28875 .26187 L
.29434 .25987 L
.29961 .25844 L
.30259 .25784 L
.30534 .2574 L
.30774 .25713 L
.30911 .25701 L
.31039 .25693 L
.31174 .25688 L
.31297 .25685 L
.31433 .25686 L
.31501 .25687 L
.31575 .2569 L
.31707 .25696 L
.31831 .25705 L
.31943 .25715 L
.32064 .25729 L
.32336 .25769 L
.32586 .25819 L
.33042 .25941 L
.33525 .26117 L
.34044 .26367 L
.34518 .26655 L
.35584 .27533 L
.36572 .28668 L
.37508 .30058 L
.39419 .33808 L
.40507 .36274 L
.4153 .38471 L
.42015 .39367 L
.42527 .40146 L
.42795 .40473 L
.43088 .4076 L
.43217 .40861 L
.43355 .40951 L
.43476 .41015 L
.43603 .41067 L
.43674 .41089 L
.43752 .41107 L
.43888 .41125 L
.43965 .41126 L
Mistroke
.44048 .41121 L
.44126 .4111 L
.44197 .41095 L
.44335 .41051 L
.44413 .41017 L
.44485 .40981 L
.44758 .40799 L
.45025 .40555 L
.45267 .4028 L
.45808 .39498 L
.48001 .34993 L
.48963 .32945 L
.50017 .30977 L
.50968 .29525 L
.51987 .28313 L
.5255 .27785 L
.53063 .27385 L
.54067 .26796 L
.54573 .26583 L
.55109 .26408 L
.55567 .26296 L
.56073 .26205 L
.56355 .26168 L
.56614 .26143 L
.5675 .26132 L
.56899 .26123 L
.56973 .2612 L
.57054 .26117 L
.57129 .26114 L
.57198 .26113 L
.57333 .26111 L
.57458 .26111 L
.57596 .26113 L
.57665 .26115 L
.57741 .26117 L
.57868 .26123 L
.58006 .2613 L
.58253 .2615 L
.58521 .26177 L
.58806 .26215 L
.59318 .26305 L
.59927 .26449 L
.60478 .26616 L
.61001 .26812 L
.61566 .27072 L
.62096 .2737 L
.62589 .27706 L
.63591 .28606 L
.64121 .29227 L
.64689 .30021 L
Mistroke
.65847 .32132 L
.66902 .347 L
.69081 .4163 L
.70039 .44643 L
.70547 .4596 L
.70827 .4656 L
.71094 .4703 L
.71346 .47377 L
.71488 .47529 L
.71621 .4764 L
.71744 .47716 L
.71855 .47763 L
.71983 .4779 L
.72104 .4779 L
.72219 .47767 L
.72341 .47717 L
.72444 .47655 L
.72558 .47565 L
.72813 .47286 L
.73051 .46933 L
.73574 .45866 L
.74052 .44602 L
.75126 .41136 L
.76179 .37537 L
.77298 .34129 L
.78335 .31605 L
.79308 .29808 L
.80228 .28567 L
.80746 .28039 L
.8122 .27648 L
.81711 .27328 L
.82249 .27064 L
.8252 .2696 L
.82809 .2687 L
.83058 .26807 L
.83332 .26753 L
.83603 .26713 L
.83752 .26697 L
.83891 .26686 L
.84021 .26678 L
.84139 .26673 L
.84276 .2667 L
.84406 .2667 L
.8448 .26671 L
.84546 .26673 L
.84623 .26676 L
.84696 .26679 L
.84825 .26687 L
.84964 .26698 L
.85281 .26732 L
Mistroke
.85572 .26775 L
.86063 .26868 L
.86601 .26998 L
.87687 .27324 L
.89911 .281 L
.90963 .28446 L
.91936 .28714 L
.92425 .28821 L
.92943 .28908 L
.93212 .28942 L
.93464 .28966 L
.93608 .28977 L
.9374 .28985 L
.93815 .28988 L
.93885 .28991 L
.93958 .28993 L
.94037 .28995 L
.94162 .28996 L
.94297 .28995 L
.94424 .28992 L
.94542 .28988 L
.94648 .28982 L
.94764 .28975 L
.94999 .28956 L
.95255 .28928 L
.9553 .28891 L
.96026 .28803 L
.97002 .28561 L
.98066 .28212 L
1 .2745 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool007?ooooo3Ol0000eooooo`03o`000?oooooooooo0;3ooooo000P
ooooo`oo0000@_ooool2o`0000gooooo0_l0000cooooo`;o00003oooool>o`0009Cooooo000Noooo
o`;o00003oooool2o`0003kooooo0_l0000Aooooo`;o0000<Oooool00ol0003oooooooooo`0;oooo
o`?o00003_ooool4o`00093ooooo000Eooooo`;o000000Co410@oooooooooooooooo0ol000000olb
<S;ok^k^ooooo`0@ooooo`?o00001_ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0Kooooo`Go00000oooool00oo^k^ko<S8bo`000002o`0001Gooooo0_l0
0005ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQkooooo00?o0000oooo
ooooool02Oooool2o`0001Cooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
6_ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Cooooo`co000000Woc<c<oooooooo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^h07Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^00kooooo000Fooooo`03o`000?oooooo000000;o000000GoMgMgoiRHV?oo
ooooV9RHogMgM`0Dooooo`;o00001?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0Kooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOo0000
o`000?nHV9SoMgMg01Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
01Kooooo0_l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Aooooo`;o00002?ooool01?l@413o^[Zj
oooooomgMgL3o`000006oooooomgMgOoV9RHoooooonHV9SoMgMg7_ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool000_ooooo1_l00002ooooo`Go00000oooool0
1Ol@413ooooooooooooooooo410@01;ooooo1_l00006ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04ooooo`05o`00
0?ooooooooooooooool@41004oooool6o`0000Gooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@01kooooo00?o0000ooooooooool01_ooool2o`0001Wooooo00Ko0000oooo
ool0003o0000ooooool@4103ooooo`03oa0@4?oooooooooo01Wooooo00?oV9RHob4Q8Oo^k^h01?oo
ool01Ol@413ooooooooooooooooo410@00oooooo0_l0000>ooooo`03o`000?oooooooooo00Co0000
00?ooooooa0@4?ooool06_ooool5o`000004ooooool0003o0000oa0@40?ooooo00?o410@oooooooo
ool03?ooool001?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo0000
01Oooooo00?o0000ooooooooool00oooool00onYZJWo410@ooooo`02ooooo`05o`000?oooooooooo
ooooool000007Oooool00onHV9So8B4Qonk^kP02ooooo`;o00000oooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000001kooooo0_l00006ooooo`03o`000?oooooooooo01Wooooo00Co0000oooooooooooooooo
0_l00003ooooo`03o`000?oooooooooo01[ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooo
oooooooooooo000000kooooo00?o0000ooooooooool03Oooool00onYZJWo410@ooooo`02ooooo`03
o`000?oooooooooo00?o00006_ooool00om4A4CogMgMooooo`03o`0000;ooooo00Go0000oooooooo
ooooooooo`00000>ooooo`004oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?oooooooooo
ooooool000006?ooool01ol0003ooooooooooooooooo410@o`000?nj^[X00oooool01Ol0003ooooo
oooooooooooo000001kooooo00KoMgMgofIVI_oooooo0000ooooool00003ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001gooooo00?oMgMgofIVI_ooool0
0_ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool03Oooool00ol@413o
0000okZj^P03ooooo`06o`000?ooooooooooooooool0003ooooo1?l0000Fooooo`04omgMgOmEEEGo
0000o`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`005?ooool00omgMgOoc<c<o`00
0004ooooo`05oa0@4?ooooooooooooooool@41006Oooool01_l0003ooooooooooooooooo^[Zjob4Q
8@?ooooo00Go410@oooooooooooooooooa0@400Oooooo`;o00000_ooool01Ol@413ooooooooooooo
oooo410@01[ooooo00Go0000ooooooooooooooooo`000004ooooo`05oa0@4?ooooooooooooooool@
41007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool00_ooool01Ol@413o0000oooooooooooo410@01kooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo00[ooooo00?o0000ooooooooool03oooool00onj^[[o8B4Qooooo`02
ooooo`05oa0@4?ooooooooooooooool@41001Oooool3o`0001?ooooo0_l000000oo<c<co0000oooo
o`03ooooo`05oa0@4?ooooooooooooooool@41003_ooool001Cooooo00?ok^k^odA4A?l000001?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00Go0000oiRHV?oooooo^[Zjo`000003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL06oooool01Ol0003o^[ZjoooooonHV9So000000?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0Kooooo`04o`000?ooooooooooo`0000Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9So0000oiRHV?mgMgL06_ooool01Ol0003o^[ZjoooooonHV9So
410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo00gooooo00Go
410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool2o`0000_o
oooo1_l000001?ooooook^k^odA4A?l00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool0
01Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00GoZJVY
o`000?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool01OnHV9So410@
o`000?lQ8B7o000000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`04o`000?mEEEGoIVIV
o`0000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Nooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool06_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000o`000?o^k^h0
6_ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`03o`000?oooooooooo00gooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02_ooool;o`0000Sooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00kooooo000looooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`0Wooooo`;o00000_ooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool0DOooool003gooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Kooooo00Co0000oooooooooooo0000:_oo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo05;ooooo000nooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Uooooo`04o`000?oooooo
ooooo`0002_ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1Cooooo`00?oooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool09Oooool0
0ol0003oooooo`00000/ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0Doooool0
043ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
02Cooooo0_l0000^ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0E?ooool001Ko
ooooool00010o`0001?ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
017ooooo000Fooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09Oooool00ol0003o
ooooo`00000Tooooo`;o00009oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool04Oooool004Cooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo027ooooo0_l0000`ooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool0E_ooool004Gooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo023ooooo00?o0000ooooool00000<Oooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo05Oooooo0016ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`0Oooooo`04o`000?oooooo0000o`00033ooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`1Gooooo`00Aoooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool07oooool00ol0003oooooo`00000b
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0Eoooool004Sooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01gooooo00Co0000oooo
oooooooo0000<_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo05Sooooo0019oooo
o`03o`000?oooooooooo00_ooooo0_l0000iooooo`03o`000?oooooooooo01gooooo00Co0000oooo
oooooooo0000<oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo05Sooooo001:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Koooo
o`05o`000?ooooooooooooooool00000<oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo05Sooooo001;ooooo`;o00002?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
01_ooooo00Co0000oooooooooooooooo0_l0000cooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool0FOooool004gooooo2?l0000oooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool0FOooool009Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Jooooo`00
UOooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
<oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05[ooooo002Eooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool0F_ooool009Kooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`04ooooo`;o0000=Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo05_ooooo002Fooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0Foooool009Oo
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Kooooo`00Uoooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo05cooooo002Hooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool0G?ooool009Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06
ooooo`;o0000=_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo05cooooo002Ioooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0foooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0GOooool009;ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP02ooooo`03o`000?oooooooooo00;o8B4Q1?ooool5o`0000Cooooo0ol000000olb
<S;ogMgMooooo`04ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`1Mooooo`00T_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo00?o0000oooo
ooooool00_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01?ooool01Ol0003ooooooooooomg
MgOo<S8b00Gooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo05gooooo002Booooo`05oa0@4?ooooooooooooooool@41000oooool00ol0003ooooooooo
o`06ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`1Nooooo`00T_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01ooo
ool00onHV9So8B4Qonk^kP03ooooo`06o`000?oooooooooooooooomgMgOo<S8b1Oooool3o`0003Oo
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Nooooo`00T_ooool01Ol0003ooooo
oooooooooooo000000Cooooo00?o0000ooooooooool01oooool02omgMgOoIVIVoooooooooooo0000
ooooool0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo05kooooo002Booooo`05oa0@4?ooooooooooooooool@4100
1?ooool00ol0003oooooooooo`08ooooo`06o`000?ooooooooooo`000?oooooo00002Oooool00ol0
003oooooooooo`0hooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0G_ooool009;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03o`000?oooooooooo00Cooooo00Oo0000okZj
^_ooooooV9RHoa0@4?oooooo000000;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Goooool009;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo00?ooooo00KoV9RHoa0@4?l0003o8B4Q
olc<c?l00003ooooo`Co00001_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool0Goooool009gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0<ooooo`;o0000>_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05oooooo
002Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0iooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Goooool009oooooo0ol00000
0ooooooo0000o`00000@ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`1Pooooo`00XOooool2o`0001;ooooo00?o0000ooooooooool0>_ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo063ooooo002eooooo`03o`000?oooooooooo03[o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Pooooo`00]Oooool2o`0003_ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`1Qooooo`00]Oooool00ol0003ooooooooo
o`0jooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0HOooool00;Gooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo067ooooo002eoooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Roooo
o`00]Oooool2o`0003cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Rooooo`00
]Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
H_ooool00;Gooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo06?ooooo002eooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`1Sooooo`00]Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0Hoooool00;Gooooo0_l0000nooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0I?ooool00;Gooooo00?o0000ooooooooool0?Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo06Cooooo002eooooo`03o`000?oooooooooo03gooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`1Tooooo`00V_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`0nooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0IOooool009[ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Uooooo`00V_oo
ool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`0003kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`1Uooooo`00V_ooool01Ol0003ooooooooo
oooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0I_ooool009[ooooo00Go0000oooooooooooooooo
o`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`10ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0Ioooool009[ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0@?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo06Oooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo047ooooo0_l000000ooooooo
0000o`00001Zooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o
0000@oooool3o`0006_ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool0
1?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009;ooooo00Go410@oooooooooooo
oooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qoooooooo
ool01_ooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005oooo
o`03o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003_ooool00onY
ZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00:_ooooo
1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002]ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0/?ooool00:gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:go
oooo00?o0000ooooooooool0^?ooool00:gooooo00?o0000ooooooooool0^?ooool00:gooooo00?o
0000ooooooooool0^?ooool00:_ooooo00?oEEEEofIVI_l00000^_ooool00?ooooooJOooool00:oo
oooo00?o0000okZj^_ooool0]_ooool00:oooooo0_lb<S:gooooo`00P?ooool2o`000006oa0@4?oo
oooooooooa0@4?l0003o410@5oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Iooooo`Co000000?o410@
ooooooooool00_ooool00ol0003ok^k^ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0N?oo
ool0087ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00002Oooool0
1OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03olc<
c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003o
ooooooooo`04ooooo`03oeEEEOnYZJWooooo00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1hoooo
o`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Oooooo00?oV9RHob4Q8Oo^
k^h01?ooool01Ol@413ooooooooooooooooo410@01;ooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`04ooooo`03ojVYZOmEEEGooooo00?ooooo00Go410@oooooooooooooooooa0@401h
ooooo`00POooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000;ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo00_ooooo
1_l0000<ooooo`03o`000?oooooooooo00Gooooo00?o8B4Qooooooooool00_ooool01Ol0003ooooo
oooooooooooo000007Sooooo0021ooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo00006oooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo00Gooooo00?oEEEEolc<c?ooool00_ooool01Ol0003ooooooooooooo
oooo000007Sooooo0021ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo00007?ooool01Ol0003ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool03_ooool00ol@413o0000o`000003o`0001co
oooo00?o0000ooooooooool01Oooool00onYZJWoMgMgooooo`02ooooo`05oa0@4?oooooooooooooo
ool@4100N?ooool0087ooooo00Ko0000oc8b<_oooooooooooc8b<_l0000Hooooo`05o`000?nj^[[o
oooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooooolb<S800oooool01OmgMgOo
V9RHoooooonHV9SoMgMg07Sooooo0020ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@
41005oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0B
ooooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000001?ooool5o`0000?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP1hooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(180) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .26389 m
.00488 .26242 L
.00942 .26122 L
.01483 .26002 L
.01975 .25917 L
.02223 .25884 L
.02492 .25854 L
.02746 .25832 L
.02859 .25824 L
.02981 .25818 L
.03109 .25813 L
.03229 .25809 L
.03303 .25808 L
.03372 .25807 L
.03503 .25807 L
.0364 .25809 L
.03768 .25813 L
.03841 .25816 L
.03908 .2582 L
.04057 .25829 L
.04334 .25854 L
.04627 .2589 L
.04877 .25929 L
.05151 .25982 L
.05763 .26138 L
.06335 .26333 L
.07371 .26811 L
.08481 .27509 L
.10711 .29471 L
.12824 .31764 L
.13837 .32807 L
.14393 .33306 L
.14914 .33709 L
.15394 .34009 L
.15834 .34217 L
.16072 .34301 L
.16322 .34366 L
.16452 .3439 L
.16573 .34406 L
.16706 .34418 L
.16781 .34421 L
.16848 .34422 L
.16974 .3442 L
.17091 .34411 L
.17219 .34396 L
.17357 .34372 L
.17502 .34339 L
.17639 .343 L
.17896 .34207 L
.18359 .3398 L
Mistroke
.18863 .33649 L
.19996 .32657 L
.21047 .31543 L
.23024 .29361 L
.25161 .27392 L
.26334 .26595 L
.26849 .26311 L
.27413 .26045 L
.27911 .25849 L
.28444 .25678 L
.28739 .25602 L
.29007 .25543 L
.29257 .25498 L
.29532 .25459 L
.29658 .25445 L
.29794 .25432 L
.29921 .25423 L
.30039 .25417 L
.30164 .25413 L
.303 .25411 L
.3037 .25412 L
.30443 .25413 L
.30576 .25417 L
.30701 .25424 L
.30836 .25434 L
.30964 .25446 L
.31081 .2546 L
.3154 .25535 L
.31801 .25595 L
.32045 .25661 L
.326 .25854 L
.33141 .26103 L
.33721 .26443 L
.34788 .27296 L
.35949 .28611 L
.37046 .30262 L
.38061 .32137 L
.40185 .36713 L
.41226 .38785 L
.41681 .3953 L
.41923 .39869 L
.42181 .40182 L
.42432 .40436 L
.42661 .4062 L
.42771 .40692 L
.42891 .40757 L
.43003 .40806 L
.43108 .40841 L
.43226 .40868 L
.43355 .40883 L
Mistroke
.43481 .40882 L
.43617 .40865 L
.43742 .40833 L
.43862 .40789 L
.43969 .40739 L
.44086 .40672 L
.44356 .40471 L
.44602 .40237 L
.45152 .39545 L
.46141 .37858 L
.48334 .33418 L
.49295 .31673 L
.5035 .30082 L
.51369 .2888 L
.5232 .28026 L
.53324 .2736 L
.53887 .27075 L
.544 .26862 L
.54905 .2669 L
.55442 .26542 L
.55906 .26439 L
.56405 .26351 L
.5694 .26277 L
.57442 .26227 L
.57733 .26206 L
.57891 .26197 L
.58039 .2619 L
.58165 .26186 L
.583 .26182 L
.58377 .26181 L
.5845 .2618 L
.58586 .26179 L
.58707 .26179 L
.58837 .26181 L
.5896 .26184 L
.59073 .26188 L
.59204 .26194 L
.59347 .26202 L
.59608 .26221 L
.59879 .26247 L
.60169 .26283 L
.60689 .26369 L
.61213 .26487 L
.61706 .26632 L
.62627 .27015 L
.63118 .27296 L
.63656 .27682 L
.6418 .28149 L
.64741 .28767 L
.65746 .30233 L
Mistroke
.66682 .32087 L
.67754 .34861 L
.68918 .38596 L
.69924 .42105 L
.70458 .43875 L
.71033 .4555 L
.7132 .46258 L
.71594 .46829 L
.7186 .47279 L
.7199 .47458 L
.72108 .47595 L
.72219 .47704 L
.72341 .47798 L
.72468 .47869 L
.72589 .47909 L
.72722 .47922 L
.72789 .47917 L
.72863 .47902 L
.72993 .47852 L
.73115 .47777 L
.73252 .47663 L
.73401 .47501 L
.73672 .47113 L
.7418 .46085 L
.74773 .44481 L
.75322 .42728 L
.77448 .35618 L
.78489 .32847 L
.79444 .30912 L
.80373 .29549 L
.8084 .29035 L
.81351 .28589 L
.81865 .2825 L
.82148 .28105 L
.82416 .27993 L
.82665 .27909 L
.82935 .27837 L
.8318 .27788 L
.83407 .27756 L
.83538 .27743 L
.83663 .27733 L
.83775 .27727 L
.83897 .27723 L
.84029 .27722 L
.84103 .27723 L
.8417 .27724 L
.84301 .27729 L
.84424 .27736 L
.8454 .27744 L
.84662 .27756 L
Mistroke
.84881 .2778 L
.85376 .27857 L
.85911 .27967 L
.86409 .2809 L
.87543 .28404 L
.88642 .28701 L
.89183 .28824 L
.89683 .28918 L
.90136 .28985 L
.90365 .29011 L
.90617 .29035 L
.9074 .29044 L
.90869 .29051 L
.90937 .29055 L
.91011 .29058 L
.91141 .29062 L
.91264 .29064 L
.91396 .29065 L
.9152 .29064 L
.91632 .29061 L
.91758 .29057 L
.91875 .29051 L
.92004 .29043 L
.92143 .29032 L
.92425 .29004 L
.92682 .2897 L
.93179 .28884 L
.9365 .28778 L
.94696 .28465 L
.95835 .28038 L
1 .26389 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0077ooooo
3?l0000hooooo`03o`000?oooooooooo0;3ooooo000Kooooo`go0000A_ooool3o`0000cooooo0_l0
000fooooo`03o`000?oooooooooo0;3ooooo000Gooooo`Co00003Oooool2o`0004;ooooo0_l0000A
ooooo`;o0000=?ooool2o`0001?ooooo3Ol0002Aooooo`005_ooool00ol0003oooooooooo`0Aoooo
o`?o0000??ooool3o`0001Gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0=oooo
o`Go00003Oooool3o`0007Wooooo0_l0000Cooooo`005Oooool2o`000009oa0@4?oooooooooooooo
ooo^k^ko<S8bo`000?lb<S;ok^k^00gooooo0_l0000;ooooo`05oiRHV?l@413o0000oc8b<_o<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo1Ol000002?oooooo0000ooooooo^k^ko<S8b
o`000?lb<S;ok^k^4oooool00ol0003oooooooooo`06ooooo`Co000000So410@ooooooooooook^k^
oc8b<_l0003o<S8bonk^kQkooooo00?o0000ooooooooool02_ooool3o`0001;ooooo1_l000001_oo
ooook^k^oc8b<_l0003o<S8bonk^kQ[ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
6oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Moooo
o`Co00000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Fooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0?ooooo`;o00002Oooool01Ol@413o^[Zjoooooomg
MgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`06oiRHV?lQ8B7ok^k^oooooom4
A4Co00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003ooooooooo
o`08ooooo`;o00005oooool01?l0003oooooooooooooool2o`000004oiRHV?ooooooV9RHogMgMa[o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool0
1Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`Co0000
1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko00000_ooool5o`0000?ooooo
00Go410@oooooooooooooooooa0@400Aooooo`Oo00001_ooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool04Oooool6o`0000?ooooo00CoV9RHob4Q8Ol0003o00000oooool0
1Ol@413ooooooooooooooooo410@01?ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@400Nooooo`03o`000?oooooooooo00Kooooo0_l0000Iooooo`03o`00
0?oooooooooo00;ooooo00Go410@o`000?oooooooooooa0@400Kooooo`03oiRHV?lQ8B7ok^k^00Co
oooo00Go410@oooooooooooooooooa0@400Oooooo`05o`000?ooooooooooooooool@41000oooool0
0ol@413oooooooooo`0Gooooo`Oo00000oooool01Ol@413ooooooooooooooooo410@00kooooo000C
ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000Booooo`03o`00
0?oooooooooo00Sooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000001go
oooo00?o0000ob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000001Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007_ooool2
o`0000Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
000000;o00007?ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000005?oo
ool9o`000003oooooonYZJWo410@00?ooooo00Go0000ooooooooooooooooo`00000Fooooo`?o0000
0_ooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool001?o
oooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000001?ooooo00?o0000
ooooooooool01_ooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000007?oo
ool01?l0003oooooogMgMomVIVH3ooooo`05o`000?ooooooooooooooool000005oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Noooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000007Oooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooo
ooooooooool000004Oooool3o`0000Wooooo1Ol000000ooooooo0000ooooo`02ooooo`03o`000?oo
oooooooo017ooooo0ol00005ooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`005?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@
41005?ooool00ol0003oooooooooo`06ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooo
oooooooooa0@400Kooooo`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooo
oooo410@01Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool00_ooool01_l@413ooooooooooooooooo410@o`0001gooooo00Go0000oooo
oooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00kooooo00?o0000ooooooooool02oooool0
1?nj^[[o8B4Qooooooooool3o`0000;ooooo00?o410@ooooooooool03_ooool3o`0000Wooooo00?o
MgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00kooooo000Dooooo`03onk^k_m4
A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Eooooo`03o`000?oooooooooo00;ooooo
00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool2o`00
0004okZj^_ooooooV9RHoa0@40?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Iooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00;ooooo
00OoMgMgoiRHV?ooooooV9RHogMgMooooooo000001Sooooo00Go0000okZj^_ooooooV9RHoa0@4003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool2o`0000_ooooo00Go410@oiRHV?oooooo^[Zj
o`000003ooooo`03ogMgMonHV9So000000;o00003Oooool3o`0000cooooo00?ok^k^odA4A?l00000
1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000Eooooo`03ogMgMol0003ooooo00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Fooooo`09o`000?oooooooooooooooonYZJWo410@o`000?l@
413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Iooooo`07o`000?ooooooV9RHoa0@4?l0
003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06Oooool01_l0003ooooooooooomE
EEGoIVIVo`0000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Nooooo`05o`000?oooooooooooooo
ool000007Oooool00omEEEGoIVIVo`000004ooooo`07onk^k_lb<S;o0000oc8b<_o^k^koooooo`00
000Hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00go
oooo00?o0000ooooooooool02oooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0=o`00013ooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00kooooo000gooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`0Yooooo`;o00000_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo02oooooo00?o0000ooooooooool0C_ooool003Sooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo02Sooooo00Co0000oooooooooooo0000;Oooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo04oooooo000iooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo0000
02kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1?ooooo`00>_ooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool09_ooool2o`00033o
oooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1@ooooo`00>oooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool09_ooool2o`00033ooooo
00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1Aooooo`005_ooooooo`00043o00004ooo
ool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`;o00001ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool04Oooool001Kooooo00?o0000ooooooooool09?oo
ool2o`0001[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Uooooo`;o00009Ooo
ool2o`0002Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo017ooooo000oooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooo000003?ooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`1Cooooo`00@?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
03Gooooo00?o0000ooooooooool08Oooool00ol0003oooooo`00000dooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool0E?ooool0047ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool00_l0000cooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0E?ooool004;ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo01kooooo00Go0000oooooooooooo
ooooo`00000eooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0EOooool004?ooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo01kooooo
00Go0000ooooooooooooooooo`00000eooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool0EOooool004Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool0E_ooool004Gooooo0_l0000:ooooo`;o0000?_oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo05Kooooo0017ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo00?ooooo0_l0000eooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0Eoooool0
04Sooooo2?l00012ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0Eoooool009?o
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Gooooo`00Toooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo05Sooooo002Cooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool0F?ooool009Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`05
ooooo`;o0000=oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05Wooooo002Doooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0foooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0FOooool009Gooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Kooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`1Iooooo`00UOooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo05[ooooo002Fooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0F_oo
ool009Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`08ooooo`;o0000>?ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo05[ooooo002Gooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool0Foooool009;ooooo00Kok^k^oc8b<_l0003o<S8bonk^k_l00004
ooooo`;o8B4Q1?ooool5o`0000;ooooo00?o0000oooooom4A4@00_l000000olb<S;ogMgMooooo`04
ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1K
ooooo`00T_ooool01omgMgOoV9RHoooooonHV9SoMgMgooooool000000oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A002ooooo`03o`000?oooooooooo00;ooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
Foooool009;ooooo00Oo410@oooooooooooooooooa0@4?oooooo000000[ooooo00?oV9RHob4Q8Oo^
k^h00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0>Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo05cooooo002Booooo`05o`00
0?ooooooooooooooool000000_ooool00ol0003oooooooooo`08ooooo`04oiRHV?lQ8B7ok^k^o`00
00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`0003Wooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`1Looooo`00T_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000oooo
ooooool02Oooool00omgMgOoIVIVo`000003ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0G?ooool0
09;ooooo00Go410@oooooooooooooooooa0@4003ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Wooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`1Mooooo`00T_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00?o0000ooooooooool01Oooool01Ol0003o^[Zjooooool0003o410@00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool0GOooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`03o`000?oo
oooooooo00Cooooo00GoV9RHoa0@4?l0003o0000olc<c004ooooo`Co00001_ooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0GOooool009cooooo0_l0
0006ooooo`03o`000?oooooooooo00kooooo0_l0000kooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool0GOooool009kooooo00Co0000oooooooooooooooo0_l0000Aooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Nooooo`00W_ooool4
o`0001?ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo05kooooo002eooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1Nooooo`00]Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool0Goooool00;Gooooo0_l0000mooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0Goooool00;Gooooo00?o0000ooooooooool0??ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo05oooooo002eooooo`03o`000?oooooooooo03cooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`1Pooooo`00]Oooool00ol0003oooooooooo`0moooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0H?ooool00;Gooooo0_l0000nooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0H?ooool00;Gooooo00?o0000ooooooooool0
?Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo063ooooo002eooooo`03o`000?oo
oooooooo03kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Qooooo`00]Oooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0HOooool0
0;Gooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
067ooooo002eooooo`;o0000@?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo067o
oooo002eooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`1Rooooo`00]Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0H_ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Ooo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0@?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo06;ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`10ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0Hoooool009[ooooo00Go410@oooooooooooooooo
oa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol00011ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0Hoooool009[ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo06Cooooo002Jooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo06Cooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`1Uooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`13ooooo`05o`000?ooooooooooooooool00000J?ooool009[o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`0004Gooooo0ol0001Yoooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003Oooool00onY
ZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009;o
oooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b
<_ooool01?ooool3o`000;3ooooo002Booooo`05o`000?ooooooooooooooool000003_ooool00omE
EEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`
ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol0
0004ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002a
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002[ooooo`Co000000?o410@oooooooo
ool00oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:gooooo00?o0000ooooooooool01Oooool3o`000;3ooooo002]ooooo`03o`000?oooooooooo
0;Sooooo002]ooooo`03o`000?oooooooooo0;Sooooo002]ooooo`03o`000?oooooooooo0;Sooooo
002[ooooo`03oeEEEOmVIVKo00000;[ooooo003oooooofWooooo002_ooooo`03o`000?nj^[[ooooo
0;Kooooo002_ooooo`;o<S8b]oooool0083ooooo0_l000001_l@413oooooooooool@413o0000oa0@
41Oooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOo0000okZj^P0<
ooooo`05oiRHV?l0003o0000odA4A?nj^[X06Oooool4o`000008oa0@4?ooooooooooolc<c?lQ8B7o
0000ob4Q8Oo<c<`3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0N?ooool0087ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00002Oooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03olc<c?l0003o410@00cooooo00Go
410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003oooooooooo`02ooooo`05ob4Q
8OnHV9SooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg07Sooooo0021ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool05oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41004_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05oa0@4?ooooooooooooooool@4100N?oo
ool0087ooooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00002oooool00onHV9So8B4Q
onk^kP03ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0;ooooo`Ko
00003?ooool00ol0003oooooooooo`02ooooo`05oc8b<_nHV9SooooooiRHV?lb<S800oooool01Ol0
003ooooooooooooooooo000007Sooooo0021ooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo00006ooo
ool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo00;ooooo00Goc<c<o`000?l0003o0000olc<c003ooooo`05
o`000?ooooooooooooooool00000N?ooool0087ooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000L
ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0>ooooo`03oa0@4?l0
003o000000?o00007?ooool00ol0003oooooooooo`02ooooo`05oa0@4?nj^[[ooooookZj^_l@4100
0oooool01Ol@413ooooooooooooooooo410@07Sooooo0021ooooo`06o`000?lb<S;ooooooooooolb
<S;o00006?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Booooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol0003o^[Zjoooo
oonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1hooooo`00P?ooool00ol@413o0000
ohN7Q`02ooooo`03ohN7Qol0003o410@01Oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Kooooo`03oeEEEOmVIVKo0000
00Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0N?oo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(190) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .25696 m
.00236 .25665 L
.00488 .25639 L
.00726 .25619 L
.00831 .25612 L
.00942 .25606 L
.01075 .25601 L
.01197 .25598 L
.01328 .25596 L
.01403 .25595 L
.01473 .25596 L
.01599 .25598 L
.01715 .25601 L
.01848 .25607 L
.01975 .25614 L
.02225 .25633 L
.02491 .25662 L
.0297 .25733 L
.0354 .25853 L
.04057 .25997 L
.05151 .26415 L
.05768 .26725 L
.06335 .27061 L
.08481 .28774 L
.10625 .31028 L
.11672 .32172 L
.12627 .33117 L
.131 .33518 L
.13615 .33886 L
.13851 .34028 L
.14101 .34157 L
.14336 .34258 L
.14551 .34332 L
.14795 .34395 L
.14922 .34419 L
.15057 .34437 L
.15174 .34447 L
.15284 .34451 L
.15404 .34451 L
.15532 .34443 L
.15605 .34436 L
.15672 .34428 L
.15823 .34403 L
.15957 .34373 L
.16099 .34334 L
.16344 .34248 L
.16614 .34128 L
.17161 .33806 L
.17681 .33413 L
.18656 .32497 L
Mistroke
.2085 .30049 L
.22957 .27903 L
.23875 .27148 L
.24866 .26476 L
.25932 .25921 L
.26935 .25551 L
.27494 .25406 L
.27775 .2535 L
.28084 .25299 L
.28347 .25266 L
.28492 .25252 L
.2863 .25242 L
.28757 .25234 L
.28896 .25228 L
.29022 .25225 L
.29139 .25224 L
.29263 .25225 L
.29394 .25229 L
.29505 .25234 L
.29627 .25242 L
.29759 .25252 L
.29899 .25266 L
.30152 .25299 L
.30409 .25343 L
.3065 .25393 L
.31102 .25513 L
.31644 .25702 L
.32142 .25924 L
.33267 .26607 L
.34288 .27479 L
.35241 .28547 L
.3741 .31968 L
.39364 .35912 L
.40396 .3792 L
.40961 .38864 L
.41492 .39592 L
.41779 .39906 L
.42042 .40141 L
.42334 .40338 L
.42487 .40414 L
.42572 .40447 L
.42649 .40472 L
.42777 .40503 L
.42913 .4052 L
.4304 .40521 L
.4316 .4051 L
.43228 .40499 L
.433 .40482 L
.43428 .40442 L
.43567 .40383 L
Mistroke
.4372 .403 L
.43994 .40105 L
.44245 .39878 L
.4481 .39213 L
.45832 .37599 L
.47995 .33568 L
.49049 .31792 L
.50003 .30427 L
.50936 .29332 L
.51946 .28393 L
.53012 .27632 L
.54015 .27087 L
.55014 .26676 L
.56111 .26342 L
.56663 .26212 L
.57255 .26095 L
.57773 .26012 L
.58323 .25943 L
.58587 .25917 L
.58878 .25894 L
.59006 .25887 L
.59143 .25879 L
.59273 .25874 L
.59392 .25871 L
.5946 .25869 L
.59532 .25868 L
.59663 .25867 L
.59742 .25868 L
.59818 .25868 L
.59885 .2587 L
.59959 .25871 L
.6003 .25874 L
.60109 .25877 L
.60269 .25885 L
.60417 .25894 L
.60555 .25906 L
.60828 .25935 L
.61087 .2597 L
.61574 .26059 L
.62097 .26194 L
.62668 .26394 L
.63228 .26656 L
.63755 .26975 L
.64739 .27805 L
.65292 .28433 L
.65799 .29129 L
.66943 .31186 L
.67969 .33669 L
.68925 .36527 L
.70041 .40312 L
Mistroke
.71097 .43812 L
.71596 .4522 L
.72124 .46413 L
.724 .46884 L
.72547 .47087 L
.72704 .47267 L
.72849 .47396 L
.72981 .47484 L
.73113 .47543 L
.7324 .4757 L
.73362 .47571 L
.73474 .47549 L
.73602 .47498 L
.73723 .47424 L
.73835 .47334 L
.73939 .47233 L
.74172 .46943 L
.74408 .46567 L
.74667 .46066 L
.7519 .44811 L
.77409 .37935 L
.7846 .35011 L
.79433 .32886 L
.80437 .31293 L
.80967 .30676 L
.8153 .30167 L
.82017 .29835 L
.82475 .29603 L
.82976 .29423 L
.83258 .29351 L
.83517 .29301 L
.83651 .29281 L
.83778 .29264 L
.84015 .29241 L
.84147 .29231 L
.8427 .29224 L
.84404 .29219 L
.84471 .29217 L
.84546 .29216 L
.84671 .29215 L
.84784 .29215 L
.84916 .29216 L
.85041 .29219 L
.85155 .29222 L
.85262 .29226 L
.85503 .29236 L
.86041 .29267 L
.86623 .29302 L
.8689 .29316 L
.87172 .29329 L
Mistroke
.87413 .29337 L
.87549 .29341 L
.87677 .29343 L
.87811 .29344 L
.87887 .29344 L
.87957 .29343 L
.88085 .29342 L
.88222 .29339 L
.88344 .29335 L
.88458 .2933 L
.88719 .29314 L
.88855 .29303 L
.88999 .2929 L
.89256 .2926 L
.89835 .2917 L
.90319 .29068 L
.90769 .28952 L
.91789 .28628 L
.95893 .26902 L
.96908 .26504 L
.98007 .26138 L
.98511 .25997 L
.99044 .25869 L
1 .25696 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool006kooooo2_l0000mooooo`03o`000?oooooooooo0;3o
oooo000Fooooo`Wo0000Boooool4o`0000Wooooo0ol0000kooooo`03o`000?oooooooooo0;3ooooo
000Fooooo`03o`000?oooooooooo00Kooooo1?l00014ooooo`?o00004?ooool4o`0003Oooooo00?o
0000ooooooooool05oooool;o`0007Kooooo1Ol0000Cooooo`008oooool3o`00043ooooo00?o0000
ooooooooool05Oooool2o`0003Gooooo0_l0000Booooo`Ko00002oooool3o`0006oooooo1?l0000H
ooooo`009_ooool2o`0003cooooo0_l0000Jooooo`03o`000?oooooooooo03;ooooo00?o0000oooo
ooooool03oooool2o`0001Cooooo0_l0001Zooooo`?o00007?ooool001Gooooo0_l000002Ol@413o
ooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP08ooooo`;o00004?ooool01OnHV9So410@o`00
0?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^01;ooooo00?o0000ooooooooool01oooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hNooooo`03o`000?oooooooooo00cooooo0ol0000@ooooo`Co0000
00Co410@ooooooooooook^k^0_l000000olb<S;ok^k^ooooo`0Iooooo`Go00000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^01_ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h05?ooool3o`0000Kooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0
003o<S8bonk^kP0>ooooo`005_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02_ooool2o`0000kooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL06oooool01Ol0003o8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Cooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool02Oooool3o`0001Gooooo00?o0000oooo
ooooool00_ooool00omgMgOoV9RHooooo`02o`0001[ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0Booooo`;o00002_ooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03_ooool000_ooooo1_l00002ooooo`Go00000oooool01Ol@413o
oooooooooooooooo410@00cooooo00?o0000ooooooooool00oooool6o`0000Kooooo00Go0000oooo
oooooooooooooa0@4003ooooo`03oa0@4?oooooooooo017ooooo1_l000001_oooooo0000oooooonH
V9So8B4Qonk^kPCooooo00Go410@oooooooooooooooooa0@400Cooooo`Ko00001Oooool00ol0003o
ooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41007_ooool00ol0003oooooooooo`07oooo
o`;o00006?ooool00ol0003oooooooooo`02ooooo`06oa0@4?ooooooooooooooool@413o00006_oo
ool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41007oooool01Ol0003ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool03_ooool2o`0000Wooooo1Ol00003ooooo`05
oa0@4?ooooooooooooooool@41003_ooool001?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0
003ooooooooooooooooo000000gooooo0_l0000>ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000
ooooooooooooooooo`00000Iooooo`07o`000?oooooooooooooooonHV9So8B4Qonk^kP03ooooo`05
o`000?ooooooooooooooool000005?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`00000Nooooo`;o00001_ooool2o`0001[ooooo00?o0000
ooooooooool00_ooool01ol0003ooooooooooooooooo0000ooooool000006_ooool00onHV9So8B4Q
onk^kP03ooooo`05o`000?ooooooooooooooool000007_ooool00onYZJWo410@ooooo`02ooooo`05
o`000?ooooooooooooooool000003Oooool3o`0000_ooooo00CoA4A4omgMgOoooooo00001?ooool0
1Ol0003ooooooooooooooooo000000kooooo000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go
0000ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo00[ooooo00?o410@o`000?nj^[X0
0oooool01Ol0003ooooooooooooooooo000001Oooooo0_l00005ooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Eooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000001kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0002ooooo`03o`000?oooooooooo01Sooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooo
oooooooo000001gooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000000_o
oooo0_l0000>ooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>
ooooo`005?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`0:ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@
400Fooooo`03o`000?oooooooooo00Kooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@
4?oooooooooo01Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00?o0000oooo
ooooool06?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool07?ooool0
0onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41002Oooool2o`00017ooooo00?o
MgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00kooooo000Dooooo`03onk^k_m4
A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Aooooo`03o`000?oooooooooo00Kooooo
00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05Oooool00ol0
003oooooooooo`03ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonH
V9SoMgMg01Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL07_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?o0000oooooooo
ool05?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0K
ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo
0_l0000Cooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`00
5Oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04Oooool00ol0003o
ooooooooo`06ooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01Cooooo00?o0000ooooooooool01?ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0Gooooo`03o`000?oooooooooo00;ooooo00?oEEEEofIVI_l00000
1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01kooooo00Go0000ooooooooooooooooo`00000Moooo
o`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`03o`000?oooooo
oooo01?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
6oooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`Co00005_ooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool0
03;ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
02_ooooo0_l000000ooooooo0000ooooo`0]ooooo`03o`000?oooooooooo03?ooooo6?l0000coooo
o`00<oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02cooooo00?o0000oooooooo
ool0:_ooool01?l0003oooooooooool0000_ooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool0BOooool003Cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooool00000<?ooool00ol0003oooooooooo`0_ooooo`;o
0000C?ooool003Gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo02Wooooo0_l0000booooo`03o`000?oooooooooo02cooooo0_l0001>ooooo`00=_oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`0booooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0C_oo
ool001Koooooool00010o`0001?ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ool000001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool2o`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aoooo
o`005_ooool00ol0003oooooooooo`0Pooooo`05o`000?ooooooooooooooool000005_ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooool000009Oooool00ol0
003oooooo`00000Wooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0Aooooo`00>_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool08oooool01?l0003oooooooooool0000fooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool0D?ooool003_ooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooooooo0000=_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo057ooooo000looooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Qooooo`04o`000?oooooooooooooo
o`;o0000=Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo057ooooo000mooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo05;ooooo000nooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo05;ooooo000oooooo`03o`000?oo
oooooooo00_ooooo0_l00010ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0Dooo
ool0043ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool0Doooool0047ooooo0ol00007ooooo`03o`000?oooooooooo
04;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`04ooooo`;o0000=oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo05Cooooo0013ooooo`So0000AOooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo05Gooooo002Aooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool0EOooool0097ooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`1Fooooo`00T_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo05Kooooo002Boooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01oooool2o`0003Wooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`1Fooooo`00Toooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo05Oooooo002Cooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
Eoooool009Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Gooooo`00U?ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo05Sooooo002Eooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool02Oooool2o`0003_ooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`1Hooooo`00UOooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo05So
oooo002Booooo`05onk^k_lb<S;o0000oc8b<_l000001Oooool2ob4Q8@Cooooo1Ol000001Ooooooo
0000ooooooooooooA4A400;o000000?o<S8bomgMgOooool01?ooool00ol0003oooooooooo`0joooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0FOooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHo`000005ooooo`;o8B4Q1?ooool01_nHV9So8B4Qonk^k_ooooooA4A4o`0000Kooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool0FOooool009;ooooo00Ko410@oooooooooooooooooa0@4?l0000;ooooo`04oiRH
V?lQ8B7ok^k^o`0000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0FOooool009;ooooo00Oo0000oooooooooooo
ooooo`000?oooooo000000_ooooo00?oV9RHob4Q8Ol000001oooool00omgMgOo<S8booooo`04oooo
o`?o0000>oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo05[ooooo002Booooo`07
o`000?ooooooooooooooool0003oooooo`00000<ooooo`03o`000?mVIVKooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`1Jooooo`00T_ooool01Ol@413ooooooooooooooooo410@00;ooooo00?o
0000ooooooooool02?ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0??ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05[ooooo002B
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool00ol0003oooooooooo`05ooooo`05o`000?nj
^[[o0000oiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03cooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`1Kooooo`00T_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Cooooo00?o0000ooooooooool01?ooool3o`000003ob4Q8Oo<c<cooooo00?ooooo
1?l00006ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`1Kooooo`00W?ooool2o`0000;ooooo0_l0000Cooooo`;o0000?_ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo05_ooooo002Mooooo`Co00005?ooool00ol0003oooooooooo`0m
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0G?ooool00;Gooooo00?o0000oooo
ooooool0?Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo05cooooo002eooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Looooo`00
]Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
GOooool00;Gooooo0_l0000oooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0GOoo
ool00;Gooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo05gooooo002eooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`1Nooooo`00]Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0G_ooool00;Gooooo0_l00010ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0G_ooool00;Gooooo00?o0000ooooooooool0@?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo05oooooo002eooooo`03o`000?oooooooooo043ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`1Oooooo`00]Oooool00ol0003oooooooooo`10oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Goooool00;Gooooo00?o0000oooooooo
ool0@Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo063ooooo002eooooo`;o0000
@_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo063ooooo002eooooo`03o`000?oo
oooooooo047ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Pooooo`00]Oooool0
0ol0003oooooooooo`12ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0HOooool0
09[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo067ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0H_ooool009[ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oo
oooooooo00?ooooo0ol00013ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0H_oo
ool009[ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0@oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06;ooooo002J
ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool0A?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06?ooooo
002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo04Gooooo00Go0000ooooooooooooooooo`00001Vooooo`00V_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`16ooooo`?o
0000Ioooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`000;7o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000
o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0/?ooool009;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03
ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2`ooooo`00
T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo
<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03
oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo
0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5
o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aoooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00:_ooooo1?l000000ol@413ooooo
ooooo`03ooooo`03o`000?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0/?ooool00:gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2`
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool0^?ooool00:gooooo00?o0000ooooooooool0^?ooool00:gooooo00?o0000ooooooooool0^?oo
ool00:_ooooo00?oEEEEofIVI_l00000^_ooool00?ooooooJOooool00:oooooo00?o0000okZj^_oo
ool0]_ooool00:oooooo0_lb<S:gooooo`00P?ooool2o`000006oa0@4?oooooooooooa0@4?l0003o
410@5oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`03ohN7Qol0003o^[Zj
00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Iooooo`Co000000Oo410@oooooooooooo410@o`00
0?m4A4Coc<c<00Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1hooooo`00POooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l00009ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@
413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<ooooo`03o`000?oooooooooo00Cooooo00?oV9RH
oa0@4?oMgMd00oooool01OmgMgOoV9RHoooooonHV9SoMgMg07Sooooo0021ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool05oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?oooooo
ooooooooool@41004_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo00?o
QhN7oeEEEOooool00_ooool01Ol@413ooooooooooooooooo410@07Sooooo0021ooooo`06o`000?oo
ooooA4A4odA4A?oooooo00002Oooool6o`0000_ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003o
oooooooooooooooo000001;ooooo00?o0000ooooooooool02oooool6o`0000cooooo00?o0000oooo
ooooool00_ooool01Oo<c<co8B4Qo`000?mEEEGo000000?ooooo00Go0000ooooooooooooooooo`00
001hooooo`00POooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001_ooooo00?oMgMgofIVI_ooool0
0_ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`02ooooo`05ob4Q8On7QhOooooooiRHV?l000000oooool01Ol0003ooooooooooooooooo
000007Sooooo0021ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo00007?ooool01Ol0003ooooooooo
oooooooo410@00?ooooo00?o410@ooooooooool03_ooool00ol@413o0000o`000003o`0001cooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go410@oooooooo
oooooooooa0@401hooooo`00POooool01_l0003o<S8boooooooooooo<S8bo`0001Sooooo00Go0000
okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo00;ooooo00Go8B4QoiRHV?ooooooMgMgoeEEE@03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0N?ooool0083ooooo00?o410@o`000?n7QhL00_ooool00on7QhOo
0000oa0@400Gooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01;ooooo00?o0000ooooooooool06oooool00omEEEGoIVIVo`000004ooooo`05olc<c?l@413o
0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07Sooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .25448 m
.00236 .25462 L
.00488 .25483 L
.00726 .25509 L
.00942 .25538 L
.01473 .2563 L
.01975 .25747 L
.02973 .2607 L
.04057 .26568 L
.05173 .27254 L
.06357 .28185 L
.08481 .30323 L
.10555 .32604 L
.11463 .33453 L
.11942 .33823 L
.12454 .34139 L
.12738 .34276 L
.12995 .34375 L
.1312 .34413 L
.13254 .34447 L
.13381 .34473 L
.13498 .34491 L
.13617 .34504 L
.13729 .3451 L
.13851 .34511 L
.13981 .34506 L
.14118 .34492 L
.14248 .34473 L
.14365 .34449 L
.14492 .34417 L
.14754 .34331 L
.15044 .34204 L
.1563 .33855 L
.16684 .32965 L
.18886 .30518 L
.20905 .28328 L
.22884 .26704 L
.23879 .26119 L
.24439 .25854 L
.24967 .25646 L
.25485 .25479 L
.26046 .25339 L
.26294 .2529 L
.26556 .25247 L
.26802 .25214 L
.27026 .25191 L
.27151 .25181 L
.27287 .25172 L
.27362 .25168 L
.27431 .25165 L
Mistroke
.27568 .25161 L
.27696 .25159 L
.27813 .25159 L
.27947 .25161 L
.28074 .25165 L
.28141 .25168 L
.28214 .25172 L
.28363 .25181 L
.28628 .25205 L
.28937 .25245 L
.29226 .25292 L
.29754 .25407 L
.30326 .25574 L
.31367 .26 L
.32381 .26586 L
.33317 .27299 L
.34331 .28283 L
.35281 .29432 L
.37445 .32885 L
.39389 .3655 L
.4049 .384 L
.41027 .39121 L
.41513 .39632 L
.41765 .39837 L
.41898 .39926 L
.42038 .40007 L
.42161 .40066 L
.42296 .40118 L
.42419 .40154 L
.42533 .40177 L
.42601 .40185 L
.42674 .40191 L
.42808 .40191 L
.42938 .40177 L
.43058 .40153 L
.43188 .40116 L
.43331 .40059 L
.43622 .399 L
.43908 .39685 L
.44171 .39441 L
.44764 .38745 L
.45838 .371 L
.47991 .33312 L
.49041 .31631 L
.49995 .30311 L
.51928 .28285 L
.5299 .2749 L
.53993 .26899 L
.55013 .26426 L
.56092 .26044 L
Mistroke
.57014 .258 L
.57538 .25692 L
.58029 .25611 L
.58551 .25546 L
.58846 .25519 L
.58987 .25509 L
.5912 .255 L
.59247 .25494 L
.59383 .25489 L
.59508 .25486 L
.59622 .25485 L
.59746 .25484 L
.59882 .25486 L
.59951 .25487 L
.60024 .2549 L
.60157 .25495 L
.60287 .25502 L
.60407 .2551 L
.60679 .25535 L
.6092 .25564 L
.61175 .25602 L
.61616 .2569 L
.62102 .25818 L
.62619 .25997 L
.63163 .26239 L
.64135 .26838 L
.64677 .27285 L
.65182 .27787 L
.66326 .29287 L
.67432 .31293 L
.68475 .33738 L
.70427 .39493 L
.71449 .42575 L
.72008 .4404 L
.7253 .45163 L
.72976 .45878 L
.73225 .46169 L
.73454 .46361 L
.73583 .46438 L
.73703 .46488 L
.73834 .4652 L
.73908 .46527 L
.73974 .46527 L
.74097 .46511 L
.74229 .46469 L
.74354 .46409 L
.74468 .46334 L
.74728 .46103 L
.74964 .4582 L
.75494 .4496 L
Mistroke
.76451 .42827 L
.78622 .37316 L
.79598 .35293 L
.80632 .33636 L
.81171 .32961 L
.81766 .32349 L
.82814 .31546 L
.83359 .31235 L
.83877 .30986 L
.84851 .306 L
.87042 .29825 L
.91051 .28041 L
.93289 .26969 L
.95318 .2617 L
.96334 .25865 L
.96868 .25735 L
.97433 .25622 L
.97927 .25544 L
.98189 .25511 L
.9847 .25483 L
.98729 .25462 L
.98964 .25448 L
.99077 .25444 L
.99201 .2544 L
.99317 .25437 L
.99425 .25436 L
.99493 .25436 L
.99566 .25436 L
.99698 .25438 L
.99775 .2544 L
.99856 .25442 L
1 .25448 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool006Sooooo3?l00011ooooo`03o`000?oooooooooo0;3o
oooo000Fooooo`Ko0000B?ooool4o`0000cooooo1?l0000mooooo`03o`000?oooooooooo01Kooooo
3?l0001aooooo`[o00004oooool001cooooo0ol00014ooooo`03o`000?oooooooooo01;ooooo0_l0
000kooooo`03o`000?oooooooooo01;ooooo1?l0000<ooooo`?o0000J_ooool4o`0001gooooo000O
ooooo`?o0000?oooool2o`0001Oooooo0ol0000hooooo`;o00004?ooool3o`0001?ooooo1?l0001S
ooooo`?o00008Oooool002;ooooo0_l0000looooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`0<ooooo`?o00006_ooool00ol0003oooooooooo`1Noooo
o`;o00009?ooool001Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^
kP04ooooo`03o`000?oooooooooo01?ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h05oooool2o`0000;ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03oooool00ol0003oooooooooo`0:ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0
003o<S8bonk^kQkooooo00?o0000ooooooooool02Oooool3o`0001?ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;o00006_ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0Kooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00ko
oooo0_l0000=ooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h03_oo
ool001Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o
0000ooooooooool04_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Fooooo`03o`000?oooooooooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL04?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00Oooooo0_l0
000Hooooo`03o`000?oooooooooo00;ooooo00KoMgMgoiRHV?ooooooV9RHogMgMol0000Iooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@
okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool2o`00013ooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko0000
0_ooool5o`0000?ooooo00Go410@oooooooooooooooooa0@4006ooooo`;o00002_ooool6o`0000Ko
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo017ooooo1_l00003oooo
o`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400Aooooo`03o`000?oooooo
000000Go00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41007_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00_oo
ool01ol@413ooooooooooooooooo410@ooooool000006Oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41007oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@
ooooooooool01oooool3o`0000oooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41003_oo
ool001?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000000Sooooo
0_l0000Cooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`03
o`000?oooooooooo00Oooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000
01;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000007_ooool2o`0000Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Gooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03ojVYZOl@413ooooo00;ooooo
00Go0000ooooooooooooooooo`000007ooooo`;o00004_ooool01?m4A4CogMgMooooool00004oooo
o`05o`000?ooooooooooooooool000003_ooool001?ooooo00CogMgMoeEEEOoooooo00001?ooool0
1Ol0003ooooooooooooooooo000000[ooooo00?o0000ooooooooool03oooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`09ooooo`03ogMg
MomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001kooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000002ooooo`03o`000?oooooooooo01Sooooo00?oMgMgofIVI_ooool00_ooool0
1Ol0003ooooooooooooooooo000001gooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooo
oooooooo000000Gooooo0_l0000Dooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000oooooooo
ooooooooo`00000>ooooo`005?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooooooo
ool@41002oooool00ol0003oooooooooo`0?ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooo
oooooooooooooa0@400Aooooo`03o`000?oooooooooo00_ooooo00Go0000oooooooooooooooooa0@
4003ooooo`03oa0@4?oooooooooo01;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41007_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@oooo
ooooool07?ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool2
o`0001Oooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00kooooo000D
ooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oo
oooooooo00_ooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL04Oooool00ol0003oooooooooo`07ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo
00?o0000ooooooooool04oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0Kooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01_mgMgOoV9RHoooooonH
V9SoMgMgooooo`;o00006Oooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03_ooool001Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00go
oooo00?o0000ooooooooool02_ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0@ooooo`03o`000?oooooooooo00Sooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h05_ooool00ol0003oooooooooo`03ooooo`03oeEE
EOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Nooooo`05o`000?oooooooooooooo
ool000007Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool0
0ol0003oooooooooo`0Booooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^01_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`03onk^k_lb<S;o000000?o
00007?ooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool002ko
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02co
oooo0_l000000ooooooo0000ooooo`0_ooooo`03o`000?oooooooooo04;ooooo0_l0000hooooo`00
;oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
;?ooool00ol0003oooooo`00000aooooo`03o`000?oooooooooo043ooooo0_l0000jooooo`00<?oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0:ooo
ool2o`0003?ooooo00?o0000ooooooooool0??ooool3o`0003cooooo000aooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool0>Oooool3o`0003oooooo000aooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool0=Oooool3o`0004;ooooo000Foooooooo0000@?l0000Cooooo`00
5_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool0
0ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`04ooooo`;o00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00Co0000ooooool0003o00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`005_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo02;ooooo00Co0000oooooooooooo00009?oo
ool01?l0003oooooooooool0000Wooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0Aooooo`00=?ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool09?ooool01?l0003oooooooooool0000gooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool0BOooool003Gooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02?ooooo00Go0000oooooooooooooooo
o`00000gooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0B_ooool003Kooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool00_ooool2o`0003Oooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`1;ooooo`00=oooool2o`0001?ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo04cooooo000iooooo`03o`000?oooooooooo00kooooo0_l00011oooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0COooool003[ooooo0_l0000=ooooo`03
o`000?oooooooooo04;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1>ooooo`00
??ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`1?ooooo`00?Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo04Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`05ooooo`;o0000>Ooo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo04oooooo000nooooo`?o00000_ooool4
o`0004Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo03Wooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1@ooooo`00@?ooool4o`00
04cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1Aooooo`00T?ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0>Oooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo057ooooo002Aooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool0D_ooool0097ooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`07ooooo`;o0000>oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo05;ooooo002B
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0Doooool009;ooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`1Cooooo`00Toooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo05Cooooo002Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
E?ooool009Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0:ooooo`;o0000?Ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05Cooooo002Eooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0looooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0EOooool009;ooooo00Gok^k^oc8b<_l0003o0000onk^kP05
ooooo`;o8B4Q1?ooool6o`0000?ooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo03cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1Eooooo`00T_ooool0
1OmgMgOoV9RHoooooonHV9So000000Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^ooooool00000
1oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`1Fooooo`00T_ooool01_l@413ooooooooooooooooo410@o`0000_o
oooo00?oV9RHob4Q8Ol000002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03go
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1Fooooo`00T_ooool01?l0003ooooo
ooooooooool2o`0000cooooo00?o0000ob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o
0000?Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo05Kooooo002Booooo`07o`00
0?ooooooooooooooool0003oooooo`00000:ooooo`04o`000?ooooooMgMgofIVIPCooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`1Gooooo`00T_ooool01Ol@413ooooooooooooooooo410@00;ooooo00?o
0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
Eoooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03o`000?oooooooooo00Cooooo
0_l000001?nj^[[ooooooiRHV?l@4104ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Sooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01?ooool2o`0000;ooooo0ol000001OnHV9So410@o`000?lQ8B7oc<c<
00Cooooo1?l00006ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`1Hooooo`00WOooool3o`0001Gooooo0_l00010ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0FOooool00;Gooooo00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo05Wooooo002eooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`1Iooooo`00]Oooool00ol0003oooooooooo`10
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0F_ooool00;Gooooo00?o0000oooo
ooooool0@?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05[ooooo002eooooo`;o
0000@Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05_ooooo002eooooo`03o`00
0?oooooooooo047ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1Kooooo`00]Ooo
ool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0Fooo
ool00;Gooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo05cooooo002eooooo`;o0000@oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
05cooooo002eooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`1Mooooo`00]Oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0GOooool00;Gooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo05kooooo002eooooo`03o`000?oooooooooo04?ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`1Nooooo`00]Oooool2o`0004Gooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`1Nooooo`00]Oooool00ol0003oooooooooo`14ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0Goooool00;Gooooo00?o0000ooooooooool0
AOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05oooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo04Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Pooooo`00
V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo067o
oooo002Jooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`?o
0000Aoooool2o`0000;ooooo0_l0001Sooooo`00V_ooool01Ol0003ooooooooooooooooo000000oo
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`18ooooo`?o0000IOooool009[ooooo
00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0
003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Go
oooo00?o0000ooooooooool0/?ooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`2`ooooo`00T_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46oooo
o`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`oooo
o`00T_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00Go410@oooo
oooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@
oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?oo
ool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00Zoooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooooooo
ool0/?ooool00:gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2`ooooo`00[Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;3ooooo002]ooooo`03o`000?oooooo
oooo00Gooooo0ol0002`ooooo`00[Oooool00ol0003oooooooooo`2hooooo`00[Oooool00ol0003o
ooooooooo`2hooooo`00[Oooool00ol0003oooooooooo`2hooooo`00Zoooool00omEEEGoIVIVo`00
002jooooo`00oooooomYooooo`00[oooool00ol0003o^[Zjooooo`2fooooo`00[oooool2oc8b<[Oo
oooo0020ooooo`;o000000Ko410@oooooooooooo410@o`000?l@410Gooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4
A4Co^[Zj01Sooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^07Sooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1oooool6o`0000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6
o`0000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg07Sooooo0021ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool05oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@
41004_ooool00ol0003oooooooooo`0Kooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooo
oooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100N?ooool0087ooooo00Ko0000oooo
oom4A4CoA4A4ooooool00009ooooo`Ko00002oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oo
ooooooooooooool000004_ooool00ol0003oooooooooo`0;ooooo`Ko00002oooool00onHV9So8B4Q
onk^kP03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
07Sooooo0021ooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo00006oooool00omgMgOoIVIVooooo`02
ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0Mooooo`03ogMgMomV
IVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
0000N?ooool0087ooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Looooo`05o`000?oooooooooo
ooooool@41000oooool00ol@413oooooooooo`0>ooooo`03oa0@4?l0003o000000?o00007Oooool0
1Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@
4?oooooooooo07Kooooo0021ooooo`06o`000?lb<S;ooooooooooolb<S;o00006?ooool01Ol0003o
^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Booooo`03o`000?oooooo
oooo01[ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg07Sooooo0020ooooo`03oa0@4?l0003oQhN700;ooooo
00?oQhN7o`000?l@41005oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0Booooo`03o`000?oooooooooo01[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07Sooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(210) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .25533 m
.00488 .25654 L
.00942 .25791 L
.01975 .26201 L
.02981 .26742 L
.04057 .27486 L
.06373 .29658 L
.08481 .32044 L
.09457 .33073 L
.10491 .33944 L
.11031 .34265 L
.11338 .344 L
.11486 .34451 L
.11626 .34492 L
.11752 .34521 L
.11889 .34546 L
.12015 .34561 L
.12131 .34569 L
.12268 .34572 L
.12393 .34567 L
.12463 .34561 L
.12538 .34553 L
.12674 .34532 L
.12804 .34505 L
.12923 .34473 L
.1319 .34382 L
.13437 .34273 L
.13672 .34147 L
.14767 .33319 L
.15826 .32236 L
.16979 .30906 L
.19014 .28636 L
.20095 .27627 L
.21261 .2675 L
.2237 .26118 L
.22856 .259 L
.23388 .25701 L
.23858 .25556 L
.2436 .25432 L
.24638 .25376 L
.2489 .25334 L
.25145 .25298 L
.25384 .25271 L
.25626 .2525 L
.25755 .25242 L
.25893 .25234 L
.25962 .25232 L
.26038 .25229 L
.26175 .25226 L
.26308 .25224 L
Mistroke
.26432 .25225 L
.26559 .25227 L
.26678 .2523 L
.26785 .25234 L
.269 .2524 L
.2716 .25258 L
.27398 .25281 L
.27905 .25347 L
.28461 .25449 L
.29041 .25589 L
.29582 .25752 L
.30682 .26186 L
.31723 .2674 L
.32658 .27376 L
.33673 .28242 L
.35753 .30698 L
.37961 .34304 L
.38971 .36117 L
.40033 .37888 L
.40939 .39095 L
.41188 .39354 L
.41453 .39589 L
.41701 .39769 L
.4193 .39898 L
.42058 .39955 L
.42194 .40002 L
.4233 .40036 L
.42407 .4005 L
.42479 .40058 L
.4261 .40065 L
.42729 .40059 L
.42866 .4004 L
.42997 .4001 L
.43114 .39972 L
.43238 .39922 L
.43461 .39804 L
.437 .39639 L
.43965 .39415 L
.44509 .38825 L
.45095 .38023 L
.46157 .36279 L
.48217 .32639 L
.49307 .30928 L
.50473 .29387 L
.516 .28191 L
.52626 .27333 L
.53656 .26657 L
.5463 .26163 L
.55649 .25772 L
.56163 .25619 L
Mistroke
.56729 .25483 L
.57211 .25393 L
.57477 .25353 L
.57729 .25322 L
.57963 .25298 L
.58087 .25288 L
.58218 .25279 L
.5834 .25272 L
.5845 .25266 L
.58561 .25262 L
.58666 .2526 L
.58788 .25258 L
.58919 .25257 L
.59042 .25259 L
.59155 .25261 L
.59287 .25265 L
.59431 .25272 L
.59566 .25281 L
.59692 .2529 L
.59942 .25314 L
.60217 .25348 L
.60775 .25444 L
.61257 .25557 L
.61776 .25713 L
.62716 .26094 L
.63722 .26669 L
.64821 .27535 L
.6597 .28764 L
.67037 .30259 L
.69187 .34405 L
.71139 .39158 L
.72119 .41481 L
.73155 .43487 L
.73697 .44239 L
.74004 .44555 L
.74152 .44677 L
.74292 .44773 L
.74418 .44845 L
.74556 .44906 L
.74681 .44946 L
.74797 .4497 L
.74935 .44981 L
.7506 .44977 L
.75129 .44968 L
.75204 .44954 L
.75339 .44915 L
.75471 .44862 L
.7559 .448 L
.75858 .44619 L
.76106 .44401 L
Mistroke
.76341 .44153 L
.77439 .42573 L
.79652 .38515 L
.81571 .35381 L
.83684 .32754 L
.85766 .30763 L
.87974 .29013 L
.90182 .27563 L
.92203 .2653 L
.932 .26133 L
.94289 .25787 L
.94787 .2566 L
.95318 .25545 L
.95815 .25457 L
.96273 .25393 L
.96721 .25346 L
.96947 .25328 L
.97194 .25313 L
.97325 .25308 L
.97443 .25304 L
.9758 .25301 L
.9771 .25299 L
.9783 .25299 L
.97941 .253 L
.98062 .25303 L
.98192 .25307 L
.98303 .25312 L
.98405 .25317 L
.98635 .25333 L
.98838 .25351 L
.99051 .25374 L
.99504 .25438 L
1 .25533 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool006Gooooo2ol00015ooooo`03o`000?oooooooooo01Go
oooo2_l0001booooo`So00005oooool001Kooooo0ol00018ooooo`Co00002oooool4o`00047ooooo
00?o0000ooooooooool04?ooool5o`0000[ooooo0ol0001Yooooo`Ko00002?ooool4o`0001?ooooo
000Iooooo`?o0000@_ooool3o`0001?ooooo0ol0000nooooo`03o`000?oooooooooo00kooooo0_l0
000Booooo`?o0000Hoooool3o`0002Gooooo000Looooo`;o0000?_ooool2o`0001Wooooo0_l0000l
ooooo`;o00003?ooool3o`0001Oooooo0_l0001Nooooo`?o0000:?ooool001kooooo00?o0000oooo
ooooool0>Oooool2o`0001gooooo0_l0000jooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool06_ooool2o`0005Wooooo0ol0000[ooooo`005Oooool2o`000008oa0@4?oooooooooooooo
ooo^k^ko<S8bo`000?lb<S82o`0001Wooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`06ooooo`Go00000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00cooooo0_l0000>ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0
003o<S8bonk^kQkooooo00?o0000ooooooooool02?ooool2o`0001Gooooo1?l000001Ol@413ooooo
ooooooo^k^ko<S8b00?o00006_ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Koooo
o`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00?o
0000ooooooooool04oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
00kooooo000Fooooo`03o`000?oooooooooo00;ooooo00KoMgMgoiRHV?ooooooV9RHogMgMoooool2
o`0001Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
4Oooool00ol0003oooooooooo`07ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003oooooooooo`06ooooo`;o00006Oooool0
0ol0003oooooooooo`02ooooo`06ogMgMonHV9SooooooiRHV?mgMgOo00006Oooool01OnHV9So8B4Q
onk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l0000Gooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`002oooool6o`0000;ooooo1Ol0
0003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol0003oooooooooo`0<ooooo`Ko0000
1_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool03_ooool00ol0003o
ooooooooo`06o`0000?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@
00oooooo00Co0000oooooooooooooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`02ooooo`07oa0@4?ooooooooooooooool@413oooooo`00000Iooooo`03
oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400Oooooo`05o`000?oooooooooo
ooooool@41000oooool00ol@413oooooooooo`02ooooo`03o`000?oooooooooo01Cooooo1Ol00003
ooooo`05oa0@4?ooooooooooooooool@41003_ooool001?ooooo00CoA4A4omgMgOoooooo00001?oo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool05_ooool00onYZJWo410@
ooooo`02ooooo`05o`000?ooooooooooooooool000003_ooool2o`0000gooooo00?oV9RHob4Q8Oo^
k^h00oooool01Ol0003ooooooooooooooooo0000013ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007_ooool2o`0000Gooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000_oo
ool00ol0003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`;o
00005oooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool0
01?ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000Gooooo00?o
0000ooooooooool05?ooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool00000
3Oooool00ol0003oooooooooo`0>ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000oooooooooooo
ooooo`00000Aooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
oooo01Oooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000001gooooo00?o
410@o`000?nj^[X00oooool01?l0003oooooooooooooool3o`0001Wooooo00CogMgMoeEEEOoooooo
00001?ooool01Ol0003ooooooooooooooooo000000kooooo000Dooooo`03ogMgMoo<c<co000000Co
oooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo01Cooooo00?o^[Zjob4Q
8Oooool00_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04?ooool0
1Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool04?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Nooooo`04o`00
0?ooooooooooooooo`;o00007_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41001?ooool00ol0003oooooooooo`0Gooooo`05o`000?ooooooooooooooool@41000oooool0
0ol@413oooooooooo`0Looooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@ooooooooooooooooo`00
000Looooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@400>ooooo`005?oo
ool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01oooool00ol0003ooooo
ooooo`0@ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00?o0000ooooooooool03Oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0Cooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00Co0000oooooooooooo00008?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0Boooo
o`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go
410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9So0000o`000?mgMgL07?ooool00oo^k^ko
A4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool001Gooooo00?oMgMgo`000?oo
ool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool03oooool01OnY
ZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`03o`000?oo
oooooooo00gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h05?ooool00ol0003oooooooooo`05ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0Nooooo`03o`000?oooooo000001oooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool04_ooool01OnHV9So410@o`000?lQ
8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT00oooool3o`000003oc8b<_o^k^kooooo01cooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00kooooo000Yooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`0^ooooo`;o0000<_ooool00ol0003oooooooooo`10ooooo`03
o`000?oooooooooo03Wooooo000Zooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`0]ooooo`;o0000<oooool00ol0003oooooooooo`0nooooo`03o`00
0?oooooooooo03[ooooo000Zooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0kooooo`00:oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool0:_ooool2o`0003Gooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`0looooo`00;?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
03Sooooo00?o0000ooooooooool0:Oooool2o`0003Gooooo00?o0000ooooooooool0>_ooool00ol0
003oooooooooo`0mooooo`005_ooooooo`00043o00004oooool001Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Aooooo`005_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo027ooooo
00Go0000ooooooooooooooooo`00000Tooooo`04o`000?ooooooooooo`0002Oooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo017ooooo000`ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Tooooo`05
o`000?ooooooooooooooool00000=oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
04;ooooo000aooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0@?ooool00ol0003o
ooooooooo`0Sooooo`05o`000?ooooooooooooooool00000>?ooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo04?ooooo000booooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool0@?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00;ooooo0_l0000hooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool0A?ooool003?ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
AOooool003Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`13ooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0hooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool0AOooool003Gooooo00?o0000ooooooooool03?ooool2
o`0004Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo03Sooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`16ooooo`00=_ooool00ol0
003oooooooooo`09ooooo`;o0000B_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
04Oooooo000gooooo`;o00002?ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool01Oooool2o`0003[ooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`18ooooo`00>Oooool2o`0000Gooooo00?o0000ooooooooool0C?ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>_ooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo04Wooooo000kooooo`Go0000Coooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0>_ooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo04[ooooo002@ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool0Boooool0093ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1<oooo
o`00TOooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Sooooo0_l0000looooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool0C?ooool0097ooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`1=ooooo`00T_ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo04kooooo002Booooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0mooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0C_ooool0
09?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
03gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1?ooooo`00U?ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo0_l0000nooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool0Coooool009Cooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`1@ooooo`00T_ooool01Oo^k^ko<S8bo`000?l0003ok^k^00Gooooo0_lQ8B44ooooo`Go0000
1?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo057ooooo002Booooo`05ogMgMonHV9Soooooo`000?mg
MgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^ko0000odA4A007ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
057ooooo002Booooo`05oa0@4?ooooooooooooooool000003?ooool00onHV9So0000onk^kP09oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo05;ooooo002Booooo`04o`000?ooooooooooooooo`;o00002oooool01?l0
003oV9RHob4Q8Oo^k^h7ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000oooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0D_ooool009;ooooo00Oo0000ooooooooooooooooo`000?oo
oooo000000[ooooo00Co0000oooooomgMgOoIVIV1?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo05?o
oooo002Booooo`05oa0@4?ooooooooooooooool@41000_ooool00ol0003oooooooooo`06ooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
043ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1Cooooo`00T_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00?o0000ooooooooool00oooool3o`000004okZj^_ooooooV9RH
oa0@40Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`11ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0E?ooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04
ooooo`Go00000_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oo
oooooooo047ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Dooooo`00]Oooool2
o`0004;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Eooooo`00]Oooool00ol0
003oooooooooo`12ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0E_ooool00;Go
oooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05Ko
oooo002eooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`1Gooooo`00]Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0Eoooool00;Gooooo0_l00014ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0F?ooool00;Gooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo05Sooooo002eooooo`03o`000?oooooooooo04Gooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`1Iooooo`00]Oooool00ol0003oooooooooo`15ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0FOooool00;Gooooo0_l00017ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0F_ooool00;Gooooo00?o0000ooooooooool0Aoooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo05_ooooo002eooooo`03o`000?oooooooooo
04Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Kooooo`00]Oooool00ol0003o
ooooooooo`18ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0G?ooool00;Gooooo
00?o0000ooooooooool0B?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05gooooo
002eooooo`;o0000B_ooool2o`0000?ooooo0_l0001Pooooo`00]Oooool00ol0003oooooooooo`1;
ooooo`Co0000HOooool00;Gooooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`03ooooo`?o0000/?ooool009[ooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool0
09[ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00V_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`2`ooooo`00T_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooo
ooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0
002`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00Go
410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`2`ooooo`00T_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0/?ooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00Zoooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0/?ooool00:gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2`oooo
o`00[Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;3ooooo002]ooooo`03o`00
0?oooooooooo00Gooooo0ol0002`ooooo`00[Oooool00ol0003oooooooooo`2hooooo`00[Oooool0
0ol0003oooooooooo`2hooooo`00[Oooool00ol0003oooooooooo`2hooooo`00Zoooool00omEEEGo
IVIVo`00002jooooo`00oooooomYooooo`00[oooool00ol0003o^[Zjooooo`2fooooo`00[oooool2
oc8b<[Oooooo0020ooooo`;o000000Ko410@oooooooooooo410@o`000?l@410Gooooo`Go00000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000
o`000?m4A4Co^[Zj01Sooooo1Ol00004ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o
<S8bonk^kWSooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool6
o`0000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wo
oooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`1hooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01Oooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01;ooooo00?o0000
ooooooooool06oooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@401hooooo`00POooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo
1_l0000;ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Booooo`03
o`000?oooooooooo00_ooooo1_l0000;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000007Sooooo0021ooooo`06o`000?oMgMgo<S8boeEE
EOoMgMgo00006oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000004_oo
ool00ol0003oooooooooo`0Mooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000007Sooooo0021ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo
00007?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool03_ooool00ol@
413o0000o`000003o`0001gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@4100N?ooool0087ooooo00Ko0000oc8b<_oooooooooooc8b<_l0
000Hooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01;o
oooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg07Sooooo0020ooooo`03oa0@4?l0003oQhN7
00;ooooo00?oQhN7o`000?l@41005oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0Booooo`03o`000?oooooooooo01[ooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c004ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1hooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(220) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .25899 m
.00942 .26355 L
.01975 .27008 L
.04057 .28824 L
.06194 .31226 L
.0737 .32565 L
.07947 .33158 L
.08481 .33639 L
.08989 .3402 L
.09549 .34336 L
.09839 .34452 L
.09979 .34496 L
.10111 .3453 L
.10183 .34545 L
.10262 .3456 L
.10399 .34578 L
.10476 .34585 L
.10559 .34589 L
.10637 .34591 L
.10708 .3459 L
.10835 .34583 L
.10969 .34568 L
.11084 .34549 L
.11209 .34522 L
.1149 .34438 L
.11751 .3433 L
.12226 .34068 L
.12734 .337 L
.13803 .32698 L
.14964 .31398 L
.17077 .29026 L
.19154 .27202 L
.20202 .26541 L
.20766 .26256 L
.21359 .26006 L
.21865 .25831 L
.22419 .25677 L
.22922 .25567 L
.23391 .25489 L
.23676 .25453 L
.23945 .25425 L
.24187 .25406 L
.24323 .25398 L
.2445 .25392 L
.24586 .25386 L
.24658 .25384 L
.24735 .25382 L
.24817 .25381 L
.24894 .2538 L
.24963 .25379 L
Mistroke
.25038 .25379 L
.25174 .25381 L
.25251 .25382 L
.2532 .25384 L
.25454 .25388 L
.25581 .25393 L
.25834 .25407 L
.26071 .25425 L
.26609 .2548 L
.27132 .25554 L
.27693 .25656 L
.28709 .25901 L
.29634 .26196 L
.30678 .2662 L
.31642 .27117 L
.327 .2781 L
.33823 .28756 L
.35872 .31182 L
.37793 .34288 L
.39736 .3769 L
.40269 .38496 L
.40837 .39221 L
.41113 .39511 L
.41374 .39742 L
.41605 .39909 L
.4186 .40051 L
.41993 .40105 L
.42116 .40145 L
.42247 .40174 L
.4232 .40185 L
.42387 .40192 L
.42506 .40194 L
.42636 .40185 L
.42759 .40165 L
.42873 .40135 L
.43003 .4009 L
.43125 .40036 L
.43404 .39871 L
.43675 .39657 L
.43969 .39371 L
.45125 .37773 L
.46185 .35876 L
.48338 .31877 L
.49388 .30203 L
.50342 .28921 L
.51269 .27901 L
.52275 .27026 L
.53337 .26329 L
.53855 .26062 L
.5434 .25851 L
Mistroke
.54859 .25663 L
.55333 .25524 L
.55859 .25403 L
.56149 .25351 L
.56425 .25312 L
.5669 .25283 L
.56838 .2527 L
.56973 .25261 L
.57099 .25254 L
.57235 .25249 L
.57363 .25246 L
.57481 .25246 L
.57619 .25246 L
.57748 .25249 L
.57823 .25252 L
.5789 .25255 L
.58042 .25263 L
.58187 .25273 L
.58346 .25286 L
.58634 .25318 L
.59143 .25394 L
.59621 .25489 L
.60711 .2579 L
.61773 .26198 L
.62918 .26783 L
.65024 .28305 L
.66082 .29304 L
.6724 .30585 L
.71501 .37133 L
.73469 .40711 L
.74506 .42365 L
.75072 .43107 L
.75602 .43659 L
.7587 .43877 L
.76158 .44062 L
.76322 .44143 L
.76478 .44204 L
.76618 .44245 L
.76696 .44262 L
.7677 .44273 L
.76837 .44281 L
.76911 .44286 L
.77043 .44285 L
.77172 .44272 L
.77291 .4425 L
.7742 .44214 L
.77561 .44162 L
.77845 .44016 L
.78122 .43821 L
.78375 .43601 L
Mistroke
.78941 .42967 L
.79962 .41419 L
.82141 .3721 L
.84153 .33429 L
.8611 .30504 L
.8711 .29326 L
.88185 .28272 L
.89256 .27419 L
.90235 .26787 L
.91165 .26303 L
.92157 .25894 L
.9319 .25572 L
.93651 .25459 L
.94149 .25359 L
.94455 .25309 L
.94737 .2527 L
.95 .25239 L
.9529 .25213 L
.95416 .25204 L
.9555 .25195 L
.95667 .25189 L
.95793 .25184 L
.95867 .25182 L
.95936 .2518 L
.96071 .25178 L
.96194 .25177 L
.96325 .25178 L
.96435 .2518 L
.96556 .25183 L
.96683 .25188 L
.968 .25193 L
.97011 .25207 L
.97237 .25226 L
.97502 .25254 L
.97752 .25287 L
.9822 .25366 L
.98664 .25463 L
.99074 .25573 L
1 .25899 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool04?ooool:o`0006oo
oooo3Ol0000Jooooo`00G?oooolEo`0004Cooooo00?o0000ooooooooool03?ooool5o`0000Wooooo
1Ol0001Vooooo`Co00003Oooool6o`0001Cooooo000Fooooo`;o0000@oooool00ol0003ooooooooo
o`0Cooooo`?o0000@Oooool00ol0003oooooooooo`0:ooooo`;o00004oooool3o`00063ooooo0ol0
000Gooooo`03o`000?oooooooooo017ooooo000Hooooo`03o`000?oooooooooo03cooooo1?l0000I
ooooo`;o0000?oooool2o`0000[ooooo00?o0000ooooooooool05_ooool2o`0005_ooooo0ol0000^
ooooo`006Oooool2o`0003[ooooo0_l0000Oooooo`03o`000?oooooooooo03cooooo00?o0000oooo
ooooool01oooool2o`0001_ooooo0_l0001Hooooo`03o`000?oooooooooo02oooooo000Eooooo`;o
000000Wo410@ooooooooooooooooo`000?lb<S;o0000oc8b<_o^k^h06_ooool01OnHV9So410@o`00
0?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03o`000?oooooooooo00_o
oooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool3o`00017ooooo1?l000002?l@
413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^7_ooool00ol0003oooooooooo`05ooooo`;o0000
6?ooool4o`000003oa0@4?oooooooooo00?o000000?o<S8bonk^k_ooool06Oooool5o`0000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00;ooooo0_l0000Iooooo`;o000000Wo410@ooooooooooooooooonk^
k_lb<S;o0000oc8b<_o^k^h03_ooool001Kooooo00?o0000ooooooooool00_ooool01OmgMgOo0000
o`000?nHV9SoMgMg01[ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool2o`0000kooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool2o`00017ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg01kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?l0003oV9RHogMgM`0Jooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMg
oc8b<P03ooooo`07ogMgMonHV9SooooooiRHV?mgMgOoooooo`00000Looooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`002oooool6o`0000;ooooo1Ol00003oooo
o`05oa0@4?ooooooooooo`000?l@41004_ooool6o`0000Kooooo00Go0000oooooooooooooooooa0@
4003ooooo`03oa0@4?oooooooooo00Sooooo00?o0000ooooooooool01_ooool6o`0000?ooooo00?o
V9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00gooooo0_l00004ooooo`Ko0000
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41007_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool00_ooool00ol@413o
ooooooooo`02o`0001_ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@
01oooooo00Go0000oooooooooooooooooa0@4003ooooo`;o00006_ooool5o`0000?ooooo00Go410@
oooooooooooooooooa0@400>ooooo`004oooool01?m4A4CogMgMooooool00004ooooo`05o`000?oo
ooooooooooooool000007Oooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool0
00002Oooool00ol0003oooooooooo`0Aooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00000?ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000001kooooo0_l00003ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooooooool2o`0001_ooooo00?oV9RHob4Q8Oo^k^h00ooo
ool01Ol0003ooooooooooooooooo000001kooooo00?oZJVYoa0@4?ooool00_ooool00ol0003ooooo
ooooo`02o`0001_ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo0000
00kooooo000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo00Co0000oooooooooooooooo0_l0000K
ooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oo
oooooooo01?ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo0000013ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00007_ooool01Ol0003ooooooooooooooooo000001oooooo00?o0000ooooooooool00_ooool01ol0
003ooooooooooooooooo0000ooooool000006oooool00omgMgOoIVIVooooo`02ooooo`05o`000?oo
ooooooooooooool000007Oooool00ol@413o0000okZj^P03ooooo`05o`000?oooooo0000ooooool0
00006oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool0
01Cooooo00?oMgMgolc<c?l000001?ooool01ol@413ooooooooooooooooo410@ooooool000006ooo
ool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41001oooool00ol0003ooooo
ooooo`0Eooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0?ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@
01kooooo00Co0000oooooooooooo00008?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41000_ooool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Looooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@o`000?oooooo
oooooa0@400Looooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@400>oooo
o`005?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool00ol0
003oooooooooo`0Eooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Kooooo00?o0000ooooooooool04_ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0Booooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000ooooool000008Oooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool00ol0003oooooooooo`0D
ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo
00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05o`000?nHV9SooooooiRHV?mgMgL07?ooool00oo^
k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool001Gooooo00?oMgMgo`00
0?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?o0000ooooooooool05?ooool0
1OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`00
0?oooooooooo01?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h04_ooool00ol0003oooooooooo`07ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Nooooo`;o00008?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01?ooool00ol0003oooooooooo`0Cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@02oooo
o`06o`000?o^k^ko<S8bo`000?lb<S;ok^k^7Oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03_ooool002?ooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo033ooooo0_l0000aooooo`03o`000?oooooooooo043ooooo00?o
0000ooooooooool0>_ooool002Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo03[ooooo000Uooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0]ooooo`;o0000=?ooool00ol0003oooooooooo`0moooo
o`03o`000?oooooooooo03_ooooo000Vooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool0>Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo000003Gooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`0looooo`009oooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0:_ooool00ol0003oooooo`00000fooooo`03o`00
0?oooooooooo03Wooooo00?o0000ooooooooool0?Oooool001Koooooool00010o`0001?ooooo000F
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`05ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo000Fooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`00000Wooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Aooooo`00:oooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`0oooooo`00;?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04?ooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`10ooooo`00;Oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`03ooooo`;o0000>?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo047ooooo000^
ooooo`03o`000?oooooooooo013ooooo0_l00018ooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool0@Oooool002oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`18oooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0ioooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool0@_ooool0033ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool0@oooool0037ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1<ooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0jooooo`03o`00
0?oooooooooo02gooooo00?o0000ooooooooool0@oooool003;ooooo0_l00008ooooo`;o0000Cooo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Kooooo0_l0000looooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool0A?ooool003Cooooo0_l00004ooooo`;o0000D_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo04Cooooo000eooooo`Go0000E?ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo04Gooooo002?ooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool0A_ooool008oooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`16ooooo`00T?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Sooooo0_l0
000oooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0Aoooool0093ooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03kooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`17ooooo`00TOooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo04Sooooo002Booooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool0BOooool009;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo043ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`19ooooo`00Tooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00_ooooo0_l00012ooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool0B_ooool009?ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`1:ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0@_oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04_ooooo002Booooo`05ogMgMonHV9So
ooooo`000?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^ko0000odA4A007ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo04_ooooo002Booooo`05oa0@4?ooooooooooooooool000003?ooool00onHV9So0000
onk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0@oooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo04cooooo002Booooo`05o`000?ooooooooooooooool00000
3?ooool01?l0003oV9RHob4Q8Oo^k^h7ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00014ooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool0C?ooool009;ooooo00Co0000oooooooooooo
oooo0_l0000;ooooo`04o`000?ooooooMgMgofIVIPCooooo00Go0000ob4Q8Ol0003o<S8bolc<c005
ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1=
ooooo`00T_ooool01ol@413ooooooooooooooooo410@ooooool000002Oooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`15ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool0COooool009;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`02ooooo`03o`000?oooooooooo00Gooooo0_l000001?nj^[[ooooooiRHV?l@4104ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo04kooooo002Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool2o`0000?o
oooo0_l000001_ooooooV9RHoa0@4?l0003o8B4Qolc<c0Cooooo1?l00006ooooo`03o`000?oooooo
oooo04Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1>ooooo`00W?ooool3o`00
01Kooooo0_l00018ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0Coooool00;Go
oooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04oo
oooo002eooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`1@ooooo`00]Oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0D?ooool00;Gooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo057ooooo002eooooo`;o0000Boooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo057ooooo002eooooo`03o`000?oooooooooo04[ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`1Booooo`00]Oooool00ol0003oooooooooo`1;ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0Doooool00;Gooooo00?o0000ooooooooool0C?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05?ooooo002eooooo`;o0000C_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo05Cooooo002eooooo`03o`000?oooooooooo
04gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Eooooo`00]Oooool00ol0003o
ooooooooo`1>ooooo`;o00001_ooool2o`0005Sooooo002eooooo`03o`000?oooooooooo053ooooo
0_l00003ooooo`;o0000FOooool00;Gooooo00?o0000ooooooooool0D_ooool3o`0005_ooooo002e
ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03oooo
o`?o0000/?ooool009[ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000ooooooooooooooooo`00000<oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@
413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`
ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006
ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool009;o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo
410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo0;3ooooo002Booooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06
ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00T_ooool01Ol0003ooooooooooooooooo
000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool0/?ooool009;ooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmg
MgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Zoooool4o`00
0003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo0ol0002`ooooo`00[Oooool0
0ol0003oooooooooo`2hooooo`00[Oooool00ol0003oooooooooo`2hooooo`00[Oooool00ol0003o
ooooooooo`2hooooo`00Zoooool00omEEEGoIVIVo`00002jooooo`00oooooomYooooo`00[oooool0
0ol0003o^[Zjooooo`2fooooo`00[oooool2oc8b<[Oooooo0020ooooo`;o000000Ko410@oooooooo
oooo410@o`000?l@410Gooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?o
QhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo1Ol00003ooooo`Go0000
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07Sooooo0021ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01oooool6o`0000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^
ogMgMol@41002Oooool6o`0000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg07Sooooo0021ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool05oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41004_ooool00ol0003oooooooooo`0Kooooo`03oiRHV?lQ8B7ok^k^00Go
oooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@07Sooooo0021ooooo`06
o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000_ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool02oooool6o`0000_ooooo00?o
V9RHob4Q8Oo^k^h01Oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool00000
N?ooool0087ooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Kooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo01gooooo00?oMgMgofIV
I_ooool01Oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000N?ooool0
087ooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Looooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0>ooooo`03oa0@4?l0003o000000?o00007Oooool00ol0003ooooo
ooooo`05ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`1fooooo`00
POooool01_l0003o<S8boooooooooooo<S8bo`0001Sooooo00Go0000okZj^_ooooooV9RHoa0@4003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool00ol0003oooooooooo`0Jooooo`05o`000?nj
^[[ooooooiRHV?l@41000oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`1hooooo`00P?ooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Oo
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool0
0ol0003oooooooooo`0Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01OnHV9So410@o`00
0?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(230) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .26671 m
.04057 .30579 L
.06168 .32967 L
.06747 .33507 L
.07365 .33979 L
.07666 .34161 L
.0795 .34303 L
.08204 .34403 L
.08338 .34445 L
.08481 .34482 L
.08615 .34509 L
.08739 .34527 L
.08862 .34538 L
.0898 .34543 L
.09116 .34542 L
.09243 .34533 L
.09382 .34516 L
.09459 .34503 L
.0953 .34489 L
.09805 .34415 L
.0996 .3436 L
.10102 .34301 L
.10641 .34009 L
.11104 .33681 L
.11611 .3325 L
.12636 .32218 L
.14856 .29762 L
.1688 .27875 L
.17885 .27157 L
.18978 .2655 L
.19479 .26331 L
.20011 .26135 L
.20966 .25873 L
.21479 .25773 L
.2195 .25702 L
.22466 .25646 L
.22726 .25626 L
.2301 .25608 L
.2314 .25602 L
.23262 .25597 L
.23373 .25593 L
.23491 .2559 L
.23619 .25587 L
.23737 .25586 L
.23865 .25585 L
.23937 .25585 L
.24005 .25585 L
.24124 .25586 L
.24238 .25588 L
.2434 .2559 L
Mistroke
.24451 .25593 L
.24699 .25602 L
.2493 .25614 L
.25464 .25651 L
.26042 .25709 L
.27089 .25856 L
.28108 .26052 L
.29044 .26281 L
.30069 .26598 L
.31024 .2698 L
.32073 .27529 L
.33195 .28314 L
.34266 .29305 L
.3543 .30707 L
.37544 .34163 L
.39583 .37964 L
.40142 .38855 L
.40744 .39643 L
.4102 .3993 L
.41311 .40174 L
.4156 .40332 L
.41701 .40399 L
.41831 .40448 L
.41966 .40483 L
.4209 .40502 L
.42226 .40508 L
.42295 .40505 L
.4237 .40497 L
.42497 .40473 L
.42633 .40432 L
.42762 .40379 L
.42879 .40319 L
.43112 .40166 L
.43366 .3995 L
.43829 .39435 L
.44365 .38664 L
.44935 .3768 L
.4596 .35657 L
.48025 .31558 L
.4992 .28667 L
.50908 .2758 L
.51949 .26722 L
.5249 .26381 L
.52994 .2612 L
.53547 .2589 L
.54138 .25704 L
.54409 .25637 L
.54697 .25579 L
.54945 .25539 L
.55212 .25505 L
Mistroke
.55362 .2549 L
.55498 .25479 L
.55636 .25471 L
.55767 .25465 L
.5584 .25463 L
.55918 .25462 L
.55992 .25461 L
.56058 .25461 L
.56137 .25461 L
.56223 .25463 L
.56303 .25465 L
.56377 .25468 L
.56499 .25474 L
.56631 .25483 L
.56868 .25503 L
.57149 .25536 L
.57406 .25574 L
.57964 .25679 L
.58492 .25808 L
.59507 .26122 L
.60584 .26543 L
.62519 .27494 L
.66485 .2994 L
.68689 .31506 L
.69653 .32308 L
.70708 .33342 L
.72689 .3597 L
.74772 .39854 L
.75833 .4202 L
.76833 .43821 L
.77387 .44584 L
.77699 .44912 L
.77847 .45038 L
.77986 .45138 L
.78113 .45214 L
.78229 .45268 L
.78357 .45314 L
.78495 .45344 L
.78627 .45354 L
.78702 .45352 L
.78771 .45344 L
.78898 .45318 L
.79033 .4527 L
.79165 .45206 L
.79308 .45115 L
.79598 .44866 L
.79867 .4456 L
.80117 .44214 L
.81288 .41938 L
.83407 .36531 L
Mistroke
.85369 .3205 L
.86477 .30098 L
.875 .28676 L
.88585 .27523 L
.89736 .26621 L
.90742 .26039 L
.9131 .25779 L
.91851 .25573 L
.92359 .25414 L
.92914 .25279 L
.93158 .25231 L
.93419 .25188 L
.93663 .25156 L
.93888 .25131 L
.94172 .25109 L
.94321 .25101 L
.94398 .25097 L
.94479 .25094 L
.94617 .25091 L
.94745 .2509 L
.94824 .2509 L
.94898 .2509 L
.94964 .25091 L
.95037 .25093 L
.95162 .25097 L
.95299 .25103 L
.95443 .25111 L
.95578 .25121 L
.9582 .25143 L
.9608 .25173 L
.96552 .25245 L
.96991 .25335 L
.97474 .25461 L
.97989 .25629 L
.99042 .26095 L
1 .26671 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0QOooool?o`0001co
oooo001Mooooo`co0000C?ooool00ol0003oooooooooo`0;ooooo`_o0000Joooool4o`0000oooooo
1?l0000Hooooo`00Eoooool6o`0000cooooo1_l00016ooooo`03o`000?oooooooooo00Oooooo1?l0
000;ooooo`Go0000IOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Gooooo001E
ooooo`;o00006?ooool6o`00043ooooo0_l00007ooooo`03o`000?oooooooooo01;ooooo0ol0001P
ooooo`;o00006Oooool2o`0001Gooooo001Aooooo`Co00008?ooool2o`0003kooooo00?o0000oooo
ooooool01?ooool2o`0001Sooooo0ol0001Kooooo`;o00007Oooool00ol0003oooooooooo`0Boooo
o`005Oooool3o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Jooooo`05oiRHV?l@413o0000
oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Wooooo00?o0000ooooooooool03ooo
ool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo017ooooo
1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^7_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;o
k^k^6_ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05oiRHV?l@413o0000
oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;o00006oooool2o`000009oa0@4?oo
ooooooooo`000?o^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Fooooo`03o`000?oooooo000000;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo0_l0000Booooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Wooooo0ol0000Booooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool07?ooool02_l0003oooooo`000?l0003oooooogMgMonHV9SooooooiRHV?mgMgLJooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@
okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?l000007_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool000_ooooo1_l00002ooooo`Go0000
00Coooooo`000?oooooo410@0oooool00ol@413oooooooooo`0@ooooo`Ko00001_ooool01Ol0003o
oooooooooooooooo410@00?ooooo00?o410@ooooooooool00oooool2o`0000cooooo1_l00003oooo
o`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400<ooooo`;o00001Oooool6
o`0000Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01kooooo00Go
0000ooooooooooooooooo`00000Oooooo`04o`000?ooooooooooooooo`;o00000oooool00ol@413o
ooooooooo`0Iooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400Ooooo
o`05o`000?ooooooooooooooool@41000_ooool00ol0003o410@ooooo`0Jooooo`Go00000oooool0
1Ol@413ooooooooooooooooo410@00kooooo000Cooooo`04odA4A?oMgMgoooooo`0000?ooooo0_l0
0003ooooo`03o`000?oooooooooo01_ooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooooooool05_ooool00onHV9So8B4Qonk^kP03ooooo`05o`00
0?ooooooooooooooool000003_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`00000Nooooo`;o000000?oooooo`000?ooool07oooool00ol0
003oooooooooo`02ooooo`;o00000_ooool00ol0003oooooooooo`0Jooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03ojVYZOl@413ooooo00;ooooo00Go0000
ooooool0003oooooo`00000Kooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`004oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?oooooooooooooo
ool000007?ooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000001?ooool0
0ol0003oooooooooo`0Gooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00
000?ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000001kooooo00?o0000ooooool000008Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooo000000;o00007Oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool0
00007Oooool00ol@413o0000okZj^P03ooooo`;o00000_ooool00ol0003oooooooooo`0Iooooo`04
omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`005?ooool00omg
MgOoc<c<o`000004ooooo`05oa0@4?l0003oooooooooool@41007Oooool00onj^[[o8B4Qooooo`02
ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol0003oooooooooo`0Iooooo`05o`000?oo
ooooooooooooool@41000oooool00ol@413oooooooooo`0>ooooo`;o00003?ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41007_ooool2o`0002;ooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo000001kooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Oooool00_ooool01Ol0003ooooooooooooo
oooo410@01cooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00kooooo
000Dooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?l0003oV9RHogMgM`0Jooooo`05oa0@
4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo00?o0000oooo
ooooool05_ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Booooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg01kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00_l0000Hooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@oiRHV?oooooo^[Zjo`000002ooooo`06o`000?mg
MgOoV9RHoooooonHV9SoMgMg7?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03_ooool001Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?l0003ok^k^
01[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`07onk^k_lb<S;o0000oc8b<_o^k^kooooo
o`00000Iooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01?ooooo00?o0000ooooooooool01_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h07_ooool00ol0003oooooooooo`0Oooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP02ooooo`03o`000?oooooooooo01Gooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool01OnYZJWo410@o`000?l@413oZJVY
00;ooooo00Ko0000onk^k_lb<S;o0000oc8b<_o^k^hMooooo`03ogMgMol0003ooooo00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0>ooooo`007oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool0;_ooool3o`0002oooooo0_l00013ooooo`03o`000?oo
oooooooo03[ooooo000Pooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooo000003;ooooo00?o0000ooooooooool0?oooool0
0ol0003oooooooooo`0kooooo`008Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
03cooooo00?o0000ooooooooool0;?ooool00ol0003oooooo`00000cooooo`;o0000?oooool00ol0
003oooooooooo`0kooooo`008_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0:_ooool01?l0003oooooooooool0000eooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0??ooool002?ooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0oooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`00000foooo
o`;o0000>oooool00ol0003oooooooooo`0looooo`005_ooooooo`00043o00004oooool001Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool001Kooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0Eooooo`04o`000?ooooooooooo`0002Cooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0Aooooo`009_ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo04Kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0ooooo
o`009_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04Oooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03[ooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`10ooooo`009oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo04Sooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`04ooooo`;o0000
??ooool2o`00033ooooo00?o0000ooooooooool0@?ooool002Sooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0@Ooo
ool002Wooooo0_l0000Aooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`11ooooo`00:oooool00ol0003oooooooooo`0<ooooo`;o0000Coooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0?oooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo04;ooooo000/ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo04;o
oooo000]ooooo`03o`000?oooooooooo00Oooooo0_l0001Cooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool01oooool2o`00047ooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`12ooooo`00;_ooool3o`0000Cooooo0_l0001Fooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool0@oooool0037ooooo1?l0001Hooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0@oooool008kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo04;ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`14oooo
o`00S_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0@oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo04Cooooo002?ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool02_ooool2o`0004Gooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`15ooooo`00T?ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo04Gooooo002@ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`15ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0AOooool0
097ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
04Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`16ooooo`00TOooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0A_ooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo04Kooooo002Booooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool03?ooool2o`0004Sooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`17ooooo`00Toooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0Aoooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04Oooooo002B
ooooo`05onk^k_l0003o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0Aoooool009;ooooo00GoMgMgoiRHV?l0003oV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OnHV9So8B4Qonk^k_l0003oA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`19ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0B?ooool009;ooooo
00Go410@ooooool0003ooooooa0@400<ooooo`03oiRHV?l0003ok^k^00Wooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool0B?ooool009;ooooo00?o0000ooooooooool00_l0000<ooooo`04o`000?nHV9So8B4Qonk^kPOo
oooo00?oMgMgoc8b<_ooool01?ooool3o`0004[ooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`19ooooo`00T_ooool00ol0003oooooooooo`02o`0000_ooooo00Go0000oooooooooooo
MgMgofIVIP04ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`1:oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0BOooool009;ooooo00Go410@oooooooo
ooooooooo`00000:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`1:ooooo`00T_ooool01_mgMgOoV9RHoooooonHV9SoMgMgo`0000Wooooo0_l00000
1?nj^[[ooooooiRHV?l@4104ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Booo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04[ooooo002Booooo`07onk^k_lb<S;o
0000oc8b<_o^k^koooooo`000007ooooo`07o`000?ooooooV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co00001_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0B_ooool009Wooooo0_l00002ooooo`?o00005Oooool2o`0004gooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`1;ooooo`00Voooool3o`0001Oooooo00?o0000ooooooooool0
COooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04_ooooo002eooooo`03o`000?oo
oooooooo04gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1<ooooo`00]Oooool0
0ol0003oooooooooo`1>ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0C?ooool0
0;Gooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
04cooooo002eooooo`;o0000Coooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04go
oooo002eooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`1=ooooo`00]Oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool0C_ooool00;Gooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo04kooooo002eooooo`;o0000D_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo04kooooo002eooooo`03o`000?oooooooooo057ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`1?ooooo`00]Oooool00ol0003oooooooooo`1Booooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0Coooool00;Gooooo00?o0000ooooooooool0D_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04oooooo002eooooo`03o`000?oooooo
oooo05?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1@ooooo`00]Oooool2o`00
05Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Aooooo`00]Oooool00ol0003o
ooooooooo`1Eooooo`;o00000oooool2o`0005Cooooo002eooooo`03o`000?oooooooooo05Kooooo
1Ol0001Eooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0/?ooool009[ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?o
oooo0ol0002`ooooo`00V_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol0003ooooooooooooooooo000000co
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00
00Kooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0/?ooool009;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo
00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`000;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002[ooooo`Co
000000?o410@ooooooooool00oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0/?ooool00:gooooo00?o0000ooooooooool01Oooool3o`000;3ooooo002]oooo
o`03o`000?oooooooooo0;Sooooo002]ooooo`03o`000?oooooooooo0;Sooooo002]ooooo`03o`00
0?oooooooooo0;Sooooo002[ooooo`03oeEEEOmVIVKo00000;[ooooo003oooooofWooooo002_oooo
o`03o`000?nj^[[ooooo0;Kooooo002_ooooo`;o<S8b]oooool0083ooooo0_l000001_l@413ooooo
ooooool@413o0000oa0@41Oooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
0on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool5o`0000?ooooo00Go
V9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0N?ooool0087ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00002Oooool01OnHV9So8B4Q
onk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03olc<c?l0003o410@
00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002Oooool01OnHV9So8B4Qonk^k_oo
ooooA4A400?ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0N?ooool0087ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Gooooo`03oiRH
V?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400Booooo`03o`000?oooooooooo01_o
oooo00?oV9RHob4Q8Oo^k^h02?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@oooo
ooooool0M_ooool0087ooooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00002oooool0
0onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003ooooooooo
o`0;ooooo`Ko00002oooool00onHV9So8B4Qonk^kP06ooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`00001hooooo`00POooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001_o
oooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000oooo
ooooool07Oooool00omgMgOoIVIVooooo`04ooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000oooo
ooooooooooooo`00001hooooo`00POooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001cooooo00Go
0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00kooooo00?o410@o`000?l00000
0ol0000Mooooo`03o`000?oooooooooo00Cooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooo
oooooooooooo410@07Sooooo0021ooooo`06o`000?lb<S;ooooooooooolb<S;o00006?ooool01Ol0
003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Booooo`03o`000?oo
oooooooo01[ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05oa0@4?nHV9SooooookZj^_l0
00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg07Sooooo0020ooooo`03oa0@4?l0003oQhN700;o
oooo00?oQhN7o`000?l@41005oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Booooo`03o`000?oooooooooo01[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c003ooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07So
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(240) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .27959 m
.01975 .30026 L
.04057 .32396 L
.05077 .33377 L
.05648 .33811 L
.06168 .34113 L
.06463 .34241 L
.06619 .34295 L
.06784 .34343 L
.06928 .34375 L
.07004 .34389 L
.07086 .34402 L
.07161 .34411 L
.0723 .34418 L
.07365 .34425 L
.07434 .34426 L
.07507 .34424 L
.07639 .34417 L
.07719 .34409 L
.07795 .34399 L
.07937 .34375 L
.08073 .34344 L
.08198 .3431 L
.08481 .34211 L
.08974 .33969 L
.09503 .3362 L
.10457 .32802 L
.12627 .30525 L
.14707 .2855 L
.15804 .27721 L
.1697 .27019 L
.18003 .26557 L
.18591 .26358 L
.19143 .2621 L
.20111 .2602 L
.20655 .25943 L
.21154 .25886 L
.21651 .25841 L
.21925 .25822 L
.22183 .25806 L
.22424 .25794 L
.22551 .25789 L
.22685 .25785 L
.22798 .25781 L
.22922 .25778 L
.23035 .25776 L
.23141 .25775 L
.23275 .25774 L
.23351 .25774 L
.23422 .25774 L
Mistroke
.23551 .25775 L
.23688 .25776 L
.23824 .25778 L
.23951 .25781 L
.24189 .25788 L
.24471 .25799 L
.2473 .25811 L
.25314 .25844 L
.26339 .25918 L
.27295 .26008 L
.28343 .26146 L
.28931 .26253 L
.29466 .26374 L
.3051 .26691 L
.31474 .27104 L
.32532 .27735 L
.33655 .28677 L
.34642 .29795 L
.35704 .31342 L
.37624 .34949 L
.38625 .37005 L
.39692 .38983 L
.40305 .39874 L
.40595 .40206 L
.40862 .40454 L
.41131 .40643 L
.41272 .40717 L
.41344 .40748 L
.41422 .40776 L
.41552 .4081 L
.41673 .40828 L
.41748 .40832 L
.41818 .40831 L
.4195 .40816 L
.42073 .40788 L
.42188 .40749 L
.42315 .40692 L
.42452 .40614 L
.4273 .40403 L
.42985 .40151 L
.43452 .39558 L
.43944 .38771 L
.46116 .34283 L
.47192 .32067 L
.4821 .30257 L
.492 .28821 L
.50114 .27788 L
.511 .26967 L
.5162 .26644 L
.5217 .26374 L
Mistroke
.52711 .26174 L
.53217 .26038 L
.53507 .25981 L
.53772 .25941 L
.53919 .25923 L
.54078 .25908 L
.54151 .25903 L
.54229 .25897 L
.54302 .25893 L
.54369 .2589 L
.545 .25886 L
.54569 .25885 L
.54643 .25885 L
.54721 .25885 L
.54794 .25886 L
.54932 .2589 L
.55061 .25896 L
.5518 .25904 L
.5545 .25928 L
.5572 .25962 L
.56017 .26009 L
.56619 .26135 L
.57712 .2645 L
.58737 .26815 L
.62802 .2853 L
.67123 .29882 L
.68167 .30142 L
.6874 .30303 L
.6928 .30479 L
.69785 .30676 L
.70331 .3094 L
.71286 .31571 L
.71768 .31996 L
.72298 .32563 L
.7337 .34074 L
.74362 .35958 L
.7529 .3813 L
.77241 .43302 L
.77776 .44554 L
.7807 .45151 L
.78345 .45637 L
.78603 .46018 L
.78739 .46187 L
.78882 .4634 L
.79003 .46448 L
.79136 .46544 L
.79256 .4661 L
.79368 .46654 L
.79507 .46683 L
.79585 .46687 L
Mistroke
.79657 .46684 L
.7979 .46657 L
.79857 .46634 L
.79931 .46601 L
.80058 .46525 L
.80195 .46418 L
.80443 .46159 L
.80751 .45722 L
.81044 .45197 L
.81593 .43961 L
.83704 .37632 L
.84787 .34436 L
.85807 .31873 L
.86799 .29867 L
.87713 .28426 L
.88705 .27245 L
.89216 .26768 L
.89778 .26332 L
.90295 .26003 L
.90848 .25717 L
.91433 .25482 L
.9198 .25319 L
.92249 .25257 L
.92534 .25205 L
.92778 .2517 L
.93047 .25142 L
.93198 .25131 L
.93336 .25123 L
.93408 .25121 L
.93487 .25118 L
.9357 .25117 L
.93646 .25117 L
.9372 .25117 L
.93789 .25118 L
.93918 .25122 L
.93991 .25125 L
.94058 .25128 L
.94209 .25138 L
.94461 .25161 L
.94697 .2519 L
.95235 .25283 L
.95759 .25409 L
.96321 .25586 L
.97224 .25968 L
.98208 .26533 L
1 .27959 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0P_ooool=o`00027o
oooo002eooooo`03o`000?oooooooooo083ooooo0_l0000=ooooo`Co00007Oooool005Oooooo5_l0
0018ooooo`03o`000?oooooooooo00Sooooo2?l0001^ooooo`;o00004oooool2o`0001_ooooo001B
ooooo`Go00005_ooool7o`00047ooooo0_l00006ooooo`?o00002?ooool5o`0006Sooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`0Hooooo`00C_ooool4o`0002;ooooo0ol0000noooo
o`03o`000?oooooooooo00?ooooo0_l0000@ooooo`?o0000Hoooool2o`0001Wooooo0_l0000Hoooo
o`005Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00Go
V9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`0Booooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo0ol0000Aoooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQkooooo00Co0000oooooooooooo
oooo0_l0000Eooooo`?o00001?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^hJooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00GoV9RHoa0@4?l0003o
<S8bolc<c003ooooo`04onk^k_lb<S;o0000oc8b<P;o00007?ooool2o`000009oa0@4?oooooooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Fooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Cooooo0_l0000Eooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo0_l0000Aooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0Nooooo`04o`000?oooooo0000o`0001[ooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMg
oc8b<P03ooooo`05ogMgMonHV9Soooooo`000?mgMgL07_ooool2o`0000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0>ooooo`002oooool6o`0000;ooooo1Ol00003ooooo`05oa0@4?oooooooooooooo
ool@41004_ooool6o`0000Kooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooo
oooo00;o00003oooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooo
oooo410@00gooooo00?o0000ooooooooool00oooool6o`0000Gooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@01kooooo0_l0000Nooooo`;o00000_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41006oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41007oooool01Ol0003ooooooooooooooooo410@00;ooooo00?o0000
oa0@4?ooool06_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400>ooooo`004oooool0
1?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000007Oooool00onYZJWo410@
ooooo`02ooooo`07o`000?ooooooooooooooool0003oooooo`00000Kooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`00000>ooooo`;o00003_ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000007_ooool2o`00023ooooo0ol00004ooooo`05o`000?oo
ooooooooooooool000007?ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool0
00007_ooool00onYZJWo410@ooooo`02ooooo`05o`000?oooooo0000ooooool000006oooool01?m4
A4CogMgMooooool00002ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool03?ooool0
01?ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000001cooooo00?o
410@o`000?nj^[X00oooool01?l0003oooooooooooooool2o`0001gooooo00?oMgMgofIVI_ooool0
0_ooool01Ol0003ooooooooooooooooo0000013ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003oooooooooo`0Qoooo
o`?o00000_ooool01Ol0003ooooooooooooooooo000001gooooo00?oMgMgofIVI_ooool00_ooool0
1Ol0003ooooooooooooooooo000001gooooo00?o410@o`000?nj^[X00oooool2o`0000;ooooo00?o
0000ooooooooool06Oooool01?oMgMgoEEEEooooool00003ooooo`;o00000oooool00ol0003ooooo
ooooo`0<ooooo`005?ooool01?mgMgOoc<c<o`000?l00003ooooo`05oa0@4?ooooooooooooooool@
41007Oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool000007oooool01Ol0
003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool03oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Mooooo`;o00008ooo
ool00ol0003oooooooooo`02o`000005oa0@4?ooooooooooooooool@41007_ooool01Ol0003ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool07?ooool00onj^[[o8B4Qooooo`02ooooo`05
o`000?ooooooooooooooool@41007?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41003_ooool001Cooooo00Gok^k^odA4A?l0003oooooo`000002ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL06_ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?l0003o
0000ogMgM`0Kooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9So
MgMg01;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL07?ooool00ol0003oooooo`00000Sooooo`03o`000?oooooooooo00;ooooo0ol0
00000onHV9SoMgMgooooo`0Iooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RH
oooooonHV9SoMgMg01_ooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05o`000?nHV9Sooooo
oiRHV?mgMgL07?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_oo
ool001Gooooo00_oMgMgo`000?ooooooooooo`000?ooooook^k^oc8b<_l0003o<S8bonk^kP0Joooo
o`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko0000o`000?lb<S;ok^k^01_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003o
ooooooooo`07ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Koooo
o`04o`000?ooooooooooo`00027ooooo00?oEEEEofIVI_l000001?ooool00oo^k^ko<S8bo`000003
o`0001Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
6oooool01OnYZJWo410@o`000?l@413oZJVY00;ooooo00Ko0000onk^k_lb<S;o0000oc8b<_o^k^hM
ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`006_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`02o`0002gooooo0ol00014ooooo`03o`000?oooooooooo03[ooooo000Koooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0[oooo
o`05o`000?ooooooooooooooool00000<Oooool3o`00047ooooo00?o0000ooooooooool0>_ooool0
01cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0booooo`Co0000??ooool00ol0
003oooooooooo`0kooooo`007?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo04;o
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Ko
oooo1?l0000hooooo`03o`000?oooooooooo03_ooooo000Mooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0>_ooool4o`0003?ooooo00?o0000ooooooooool0??ooool001Koooooool0
0010o`0001?ooooo000Fooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`;o00001oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo017ooooo000Fooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool06?ooool00ol0003oooooo`00000Wooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool08Oooool01Ol0003ooooooooooooooooo000002Oooooo00?o0000ooooooooool0
4Oooool0027ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1:ooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`11ooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool0?_ooool002;ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`1<ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`12ooooo`;o0000:oooool00ol0003oooooooooo`0nooooo`008oooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`06ooooo`;o0000AOooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
03oooooo000Tooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Coooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0A?ooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo03oooooo000Uooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03oooooo
000Vooooo`;o00003Oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0@?ooool002Sooooo00?o0000ooooooooool02?ooool2o`0005Kooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04Kooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`10ooooo`00:Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo05Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`08oooo
o`;o0000B?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo043ooooo000Zooooo`So
0000F_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0Aoooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo047ooooo002<ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`18ooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool0@Oooool008gooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`12ooooo`00SOooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo04;ooooo002>ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool2o`00
04[ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`12ooooo`00S_ooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0B_ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo04?ooooo002?ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool0@oooool0093ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`13ooooo`00T?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0Boooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04Cooooo002Aoooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool03Oooool2o`0004gooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`14ooooo`00TOooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo04Cooooo002Booooo`05o`000?lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`1<oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0AOooool009;ooooo00Go0000oiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So0000onk^k_ooooooA4A400Oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool0AOooool009;ooooo00Go410@o`000?oooooooooooa0@400<ooooo`03o`000?lQ8B7o
k^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool0A_ooool009;ooooo0_l00002ooooo`03o`000?oooooooooo
00Wooooo00Go0000oooooonHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0001>
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0A_ooool009;ooooo00Go0000oooo
ool0003oooooo`00000;ooooo`05o`000?ooooooooooogMgMomVIVH01?ooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo04Kooooo002Booooo`05oa0@4?oooooo0000ooooool@41002_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`1>ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0Aoooool009;ooooo00Go
MgMgoiRHV?oooooo0000ogMgM`09ooooo`07o`000?oooooo0000okZj^_ooooooV9RHoa0@4004oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo04Oooooo002Booooo`05onk^k_lb<S;o0000oc8b<_l000002Oooool01ol0
003ooooooiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool0Cooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04Oooooo002Gooooo`03o`000?oooooo
oooo00Cooooo0_l0000Eooooo`;o0000DOooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo04Sooooo002Hooooo`;o00000_ooool2o`0001Oooooo00?o0000ooooooooool0D?ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo04Sooooo002Jooooo`?o00006?ooool00ol0003o
ooooooooo`1Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0B?ooool00;Gooooo
00?o0000ooooooooool0DOooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04Wooooo
002eooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`19ooooo`00]Oooool2o`0005?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`19
ooooo`00]Oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0B_ooool00;Gooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo04[ooooo002eooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`1:ooooo`00]Oooool2o`0005Cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`1;ooooo`00]Oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool0Boooool00;Gooooo00?o0000ooooooooool0E?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo04_ooooo002eooooo`03o`000?oooooooooo05Co
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1<ooooo`00]Oooool00ol0003ooooo
ooooo`1Eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0C?ooool00;Gooooo0_l0
001Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0C?ooool00;Gooooo00?o0000
ooooooooool0EOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04gooooo002eoooo
o`03o`000?oooooooooo05Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1=oooo
o`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0C_ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1>ooooo`00V_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000
ooooooooool00oooool3o`0005Sooooo0_l00004ooooo`03o`000?oooooooooo04oooooo002Joooo
o`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo05Wooooo1Ol0001Booooo`00V_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003Ooo
ool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?oo
ool009;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?o
MgMgoc8b<_ooool01?ooool3o`000;3ooooo002Booooo`05o`000?ooooooooooooooool000003_oo
ool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool0
0oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000
/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002[ooooo`Co000000?o410@
ooooooooool00oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0/?ooool00:gooooo00?o0000ooooooooool01Oooool3o`000;3ooooo002]ooooo`03o`000?oo
oooooooo0;Sooooo002]ooooo`03o`000?oooooooooo0;Sooooo002]ooooo`03o`000?oooooooooo
0;Sooooo002[ooooo`03oeEEEOmVIVKo00000;[ooooo003oooooofWooooo002_ooooo`03o`000?nj
^[[ooooo0;Kooooo002_ooooo`;o<S8b]oooool0083ooooo0_l000001_l@413oooooooooool@413o
0000oa0@41Oooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOo0000
okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool5o`0000Gooooo0_l000002Ol@413o
ooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP1hooooo`00POooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Oooooo1_l00009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zj
onk^k_mgMgOo410@00Wooooo1_l00009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0N?ooool0087ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooo
oooooooooooooa0@400Booooo`03o`000?oooooooooo01_ooooo00?oV9RHob4Q8Oo^k^h01?ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@401hooooo`00POooool01_l0003oooooodA4A?m4
A4Coooooo`0000Wooooo1_l0000;ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooooooo
ooooo`00000Booooo`03o`000?oooooooooo00_ooooo1_l0000;ooooo`03oiRHV?lQ8B7ok^k^00?o
oooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000007Sooooo0021oooo
o`06o`000?oMgMgo<S8boeEEEOoMgMgo00006oooool00omgMgOoIVIVooooo`02ooooo`05o`000?oo
ooooooooooooool000004_ooool00ol0003oooooooooo`0Mooooo`03ogMgMomVIVKooooo00;ooooo
00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000007Sooooo0021ooooo`06
o`000?n7QhOoZJVYokZj^_mEEEGo00007?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o
410@ooooooooool03_ooool00ol@413o0000o`000003o`0001gooooo00?o0000ooooooooool00_oo
ool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@4100N?ooool0087ooooo00Ko
0000oc8b<_oooooooooooc8b<_l0000Hooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@00Cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg07Sooooo
0020ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41005oooool01OnHV9So410@o`00
0?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Booooo`03o`000?oooooooooo01[o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1hooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(250) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .29631 m
.01975 .31811 L
.02981 .32823 L
.03534 .33299 L
.04057 .33676 L
.04331 .33841 L
.04629 .33991 L
.04877 .34092 L
.05018 .3414 L
.0515 .34178 L
.05284 .3421 L
.05407 .34234 L
.05538 .34252 L
.0561 .3426 L
.05679 .34265 L
.05801 .3427 L
.05913 .34269 L
.06037 .34263 L
.06168 .34251 L
.06244 .3424 L
.06324 .34227 L
.06468 .34197 L
.06793 .34104 L
.07073 .33994 L
.07381 .33843 L
.08481 .33093 L
.10701 .3099 L
.12725 .29107 L
.1373 .28339 L
.14823 .27647 L
.15848 .27128 L
.16811 .26752 L
.17798 .2647 L
.18322 .26356 L
.18887 .26255 L
.20038 .26093 L
.21093 .25979 L
.21591 .25936 L
.22122 .25897 L
.22582 .25869 L
.2308 .25846 L
.23666 .25824 L
.24219 .25807 L
.24753 .25793 L
.25253 .25782 L
.25499 .25777 L
.2562 .25775 L
.25733 .25774 L
.25861 .25773 L
.25929 .25772 L
Mistroke
.26002 .25772 L
.2613 .25772 L
.26247 .25772 L
.26316 .25773 L
.26388 .25773 L
.26518 .25775 L
.2659 .25776 L
.26658 .25778 L
.26811 .25782 L
.27066 .25793 L
.2734 .25808 L
.27625 .2583 L
.27935 .25861 L
.28497 .25936 L
.29044 .26035 L
.2955 .26153 L
.30038 .26293 L
.30563 .26479 L
.31514 .26935 L
.32065 .2729 L
.32644 .27752 L
.33678 .28833 L
.34683 .30221 L
.35755 .32068 L
.37685 .36101 L
.38764 .38353 L
.39331 .39367 L
.39641 .39839 L
.39931 .40216 L
.40205 .4051 L
.40456 .40721 L
.40589 .40809 L
.40734 .40885 L
.40814 .40919 L
.40888 .40944 L
.40958 .40963 L
.41033 .40979 L
.41153 .40991 L
.41282 .40989 L
.41404 .40971 L
.41515 .40943 L
.41639 .40896 L
.41775 .40829 L
.42048 .4064 L
.42314 .40392 L
.42602 .40056 L
.43125 .39288 L
.44105 .37441 L
.46304 .32723 L
.4738 .30734 L
Mistroke
.48388 .29248 L
.49439 .281 L
.49997 .27641 L
.50597 .27248 L
.51147 .2697 L
.51659 .26774 L
.51948 .26688 L
.5222 .26623 L
.5237 .26592 L
.52533 .26565 L
.5268 .26544 L
.52817 .26528 L
.52951 .26515 L
.53072 .26507 L
.53207 .265 L
.53282 .26498 L
.53352 .26497 L
.5342 .26496 L
.53492 .26496 L
.53622 .26499 L
.53695 .26501 L
.53762 .26504 L
.53916 .26514 L
.5404 .26524 L
.5417 .26536 L
.54403 .26565 L
.54927 .26653 L
.55453 .2677 L
.5593 .26895 L
.57002 .27225 L
.58931 .27894 L
.59993 .2826 L
.61117 .2861 L
.62076 .28855 L
.62627 .28965 L
.63131 .29044 L
.63378 .29075 L
.63648 .29103 L
.63902 .29124 L
.64138 .29139 L
.6428 .29145 L
.64413 .2915 L
.64533 .29154 L
.64662 .29156 L
.64729 .29157 L
.64803 .29158 L
.6488 .29158 L
.64952 .29158 L
.65081 .29157 L
.65219 .29155 L
Mistroke
.6535 .29152 L
.65471 .29148 L
.65745 .29138 L
.66242 .29112 L
.67172 .29053 L
.67661 .29023 L
.6793 .2901 L
.68063 .29004 L
.68187 .29 L
.68301 .28997 L
.68424 .28994 L
.6856 .28992 L
.68683 .28992 L
.68795 .28993 L
.68917 .28996 L
.69032 .28999 L
.69137 .29004 L
.69262 .29011 L
.69397 .29022 L
.69639 .29047 L
.69787 .29067 L
.69927 .2909 L
.7019 .29143 L
.70467 .29215 L
.70723 .29298 L
.71303 .29557 L
.71789 .29859 L
.72313 .30286 L
.73261 .31376 L
.73811 .32221 L
.7439 .33302 L
.75424 .35755 L
.7752 .42284 L
.78433 .45038 L
.78949 .46285 L
.79194 .46765 L
.79424 .47137 L
.79669 .47444 L
.79799 .47568 L
.79938 .47669 L
.80008 .47707 L
.80084 .47739 L
.80223 .47771 L
.80358 .4777 L
.80483 .4774 L
.80614 .4768 L
.80737 .47596 L
.80847 .47498 L
.80967 .47369 L
.81236 .46992 L
Mistroke
.81482 .46546 L
.81993 .45351 L
.82553 .43702 L
.83682 .39778 L
.84824 .35786 L
.85905 .32552 L
.86876 .30256 L
.87931 .28382 L
.88962 .27082 L
.89482 .26595 L
.90056 .26171 L
.90544 .25894 L
.908 .25776 L
.9107 .25671 L
.91307 .25594 L
.91566 .25525 L
.91801 .25475 L
.9202 .25439 L
.92155 .25422 L
.92297 .25408 L
.92418 .25399 L
.92552 .25393 L
.92627 .25391 L
.92695 .25389 L
.92774 .25389 L
.92849 .2539 L
.92982 .25394 L
.93058 .25397 L
.93127 .25401 L
.93251 .25411 L
.93368 .25422 L
.93633 .25456 L
.93892 .255 L
.94171 .2556 L
.94667 .25697 L
.9519 .25884 L
.96124 .26331 L
.97094 .26947 L
.98131 .27775 L
1 .29631 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0P?ooool;o`0002Gooooo001Goooooa_o0000@oooool00ol0003ooooooooo
o`1mooooo`?o00002oooool4o`00027ooooo001Aooooo`Ko00006oooool5o`0003kooooo0_l0001m
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool07_ooool004gooooo1?l0000Voooo
o`;o0000??ooool00ol0003oooooooooo`04ooooo`Wo0000K_ooool00ol0003oooooooooo`0Boooo
o`;o00007_ooool001Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^
kP0Jooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo0ol0000Eooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00[ooooo00?o0000oooo
ooooool03oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hNooooo`03o`00
0?oooooooooo00;ooooo0ol00008ooooo`Ko00003?ooool4o`000008oa0@4?ooooooooooonk^k_lb
<S;o0000oc8b<_o^k^hJooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00Go
V9RHoa0@4?l0003o<S8bolc<c003ooooo`06onk^k_lb<S;o0000oc8b<_o^k^ko00005oooool00ol0
003oooooooooo`02ooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h0
3_ooool001Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo
00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ol0000Hoooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo0_l0
000Aooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`00
0?oooooooooo00;o00004Oooool2o`0000cooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg01[ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL06oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RH
o`00000Iooooo`;o00000oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03_ooool000_ooooo1_l00002ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@01;o
oooo1_l00006ooooo`05o`000?ooooooooooooooool@41000oooool00ol0003oooooooooo`0Aoooo
o`Ko00000oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41003Oooool2
o`0000Cooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
400Nooooo`?o00005Oooool2o`0000[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@01_ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01oo
oooo00Go0000oooooooooooooooooa0@4003ooooo`03o`000?oooooooooo01Wooooo1Ol00003oooo
o`05oa0@4?ooooooooooooooool@41003_ooool001?ooooo00CoA4A4omgMgOoooooo00001?ooool0
1Ol0003ooooooooooooooooo000001gooooo00?oZJVYoa0@4?ooool00_ooool00ol0003oooooo`00
0002o`0001gooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000oooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00007Oooool3o`0001Sooooo0_l00008ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`00000Looooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000N
ooooo`03ojVYZOl@413ooooo00;ooooo00?o0000ooooooooool00_l0000Kooooo`04odA4A?l0003o
ooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`004oooool01?oMgMgoEEEEoooo
ool00004ooooo`05o`000?ooooooooooooooool000007?ooool00ol@413o0000okZj^P03ooooo`;o
00000_ooool00ol0003oooooooooo`0Looooo`03ogMgMomVIVKooooo00;ooooo00Go0000oooooooo
ooooooooo`00000?ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000001cooooo00?o0000ooooool000006oooool3o`0000Gooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000001gooooo00?oMgMgofIVI_ooool00_oo
ool01Ol0003ooooooooooooooooo000001gooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooo
o`000?oooooo000001_ooooo00CogMgMoeEEEOl0003o00001?ooool01Ol0003ooooooooooooooooo
000000kooooo000Dooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@400M
ooooo`03okZj^_lQ8B7ooooo00;o000000Go410@oooooooooooooooooa0@400Oooooo`05o`000?oo
ooooooooooooool@41000oooool00ol@413oooooooooo`0>ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01cooooo00?o0000ooooool0
00007_ooool4o`000003ooooool0003ooooo00?ooooo00Go410@oooooooooooooooooa0@400Noooo
o`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Looooo`03okZj^_lQ8B7o
oooo00;ooooo00Go410@o`000?oooooooooooa0@400Looooo`03ogMgMoo<c<co000000Cooooo00Go
410@oooooooooooooooooa0@400>ooooo`005?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL06_ooool01?l@413oV9RHoooooonj^[X2o`0000;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0Kooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonH
V9SoMgMg017ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL06oooool01?l0003oooooooooool0000Rooooo`?o00000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg01[ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL06oooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgo`000?oooooo
V9RHogMgM`0Looooo`04onk^k_m4A4Co0000o`0000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>
ooooo`005Oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06_ooool0
1OnYZJWo410@o`000?l@413o000000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo00?o0000oooo
ooooool01oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06_ooool0
1Ol0003ooooooooooooooooo0000027ooooo00CoEEEEofIVI_l0003ooooo1ol000000oo^k^kooooo
ooooo`03ooooo`go00002?ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Ol0003o<S8bo`000?lb
<S;ok^k^01gooooo00CoMgMgo`000?oooooo00000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00ko
oooo000mooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`02ooooo`;o0000:oooool6o`0000gooooo1?l0000cooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool04_ooool001Kooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`13ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`11ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0Aooooo`005_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo04Gooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04;ooooo0_l0000_
ooooo`03o`000?oooooooooo03[ooooo000Gooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool0Aoooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0A?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03_ooooo000Hooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo03_ooooo000Foooooooo0000@?l0000Cooooo`005_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo0_l00005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo0_l00005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool04Oooool001Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo027ooooo00Go0000ooooooooooooooooo`00000Wooooo`03o`000?oooooooooo017o
oooo000Looooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Coooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0B?ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo03gooooo000Mooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0DOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0BOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03gooooo000N
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo00Sooooo0_l0001:ooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool0?_ooool001oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Doooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1:oooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0?_ooool0023ooooo00?o0000oooooooo
ool03Oooool2o`0005Oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo04[ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0nooooo`00
8Oooool2o`0000_ooooo0_l0001Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
?oooool002?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Jooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1;ooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool0?oooool002Cooooo0ol00004ooooo`;o0000G_ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00_ooooo0_l0001=ooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool0?oooool002Kooooo1Ol0001Pooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool0@?ooool008_ooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`10ooooo`00S?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0COooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo043ooooo
002<ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`1=ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@?ooool008gooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`0=ooooo`;o0000C_ooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo047ooooo002=ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool0@Oooool008kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo04kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`11ooooo`00
S_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
C_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04;ooooo002?ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1?ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0@_ooool008oooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0?ooooo`;o0000D?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo04;ooooo002@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`1?ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0@oooool0093o
oooo00Oo0000ooooooo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo04?ooooo002@ooooo`07o`000?ooooooMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q0oooool01_l0003oV9RHob4Q8Oo^k^koooooodA4A0Oooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool0@oooool0097ooooo00?o0000oa0@4?ooool00_ooool00ol@413oooooooooo`08ooooo`05
o`000?ooooooV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
053ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`14ooooo`00TOooool2o`0000?o
oooo00?o0000ooooooooool01oooool01ol0003oooooooooooooooooV9RHob4Q8Oo^k^h01oooool0
0omgMgOo<S8booooo`04ooooo`?o0000DOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo04Cooooo002Booooo`05o`000?ooooooooooooooool000002Oooool00ol0003oooooooooo`02
ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oo
oooooooo057ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`14ooooo`00T_ooool0
1Ol@413o0000oooooooooooo410@00Sooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0DOooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo04Gooooo002Booooo`05ogMgMol0003ooooooiRHV?mgMgL01ooo
ool02Ol0003ooooooooooooooooo0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
04Gooooo002Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`02oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool0D_ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04Gooooo002Eooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool05_ooool2o`0005?ooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`15ooooo`00U_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04Ko
oooo002Gooooo`Go00006Oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0A_ooool00;Gooooo00?o0000ooooooooool0Doooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo04Kooooo002eooooo`03o`000?oooooooooo05?ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`16ooooo`00]Oooool2o`0005Gooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`17ooooo`00]Oooool00ol0003oooooooooo`1Dooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0Aoooool00;Gooooo00?o0000ooooooooool0
E?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Oooooo002eooooo`03o`000?oo
oooooooo05Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`17ooooo`00]Oooool2
o`0005Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`17ooooo`00]Oooool00ol0
003oooooooooo`1Eooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0B?ooool00;Go
oooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04So
oooo002eooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`18ooooo`00]Oooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0BOooool00;Gooooo0_l0001Hooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0BOooool00;Gooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo04Wooooo002eooooo`03o`000?oooooooooo05Oooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`1:ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`1Hoooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0B_ooool009[ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
05Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1;ooooo`00V_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`0005Wooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1;ooooo`00V_ooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0C?ooool009[ooooo00Go0000ooooooooooooooooo`00000<oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0COooool009[ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo04gooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo05_ooooo0_l00002ooooo`03o`000?oooooo
oooo04kooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0001M
ooooo`?o0000DOooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool009;o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo
410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo0;3ooooo002Booooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06
ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00T_ooool01Ol0003ooooooooooooooooo
000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool0/?ooool009;ooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmg
MgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Zoooool4o`00
0003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo0ol0002`ooooo`00[Oooool0
0ol0003oooooooooo`2hooooo`00[Oooool00ol0003oooooooooo`2hooooo`00[Oooool00ol0003o
ooooooooo`2hooooo`00Zoooool00omEEEGoIVIVo`00002jooooo`00oooooomYooooo`00[oooool0
0ol0003o^[Zjooooo`2fooooo`00[oooool2oc8b<[Oooooo0020ooooo`;o000000Ko410@oooooooo
oooo410@o`000?l@410Gooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?o
QhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo1Ol00004ooooo`05odA4
A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07Sooooo0021ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`0000Wooooo00GoV9RHob4Q8Oo^
k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool00oo<c<co0000oa0@400<
ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A007ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg07Sooooo0021oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41004_ooool00ol0003oooooooooo`0Kooooo`03oiRHV?lQ8B7o
k^k^00Wooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`1fooooo`00POooool0
1_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000;ooooo`03oiRHV?lQ8B7ok^k^00?ooooo
00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo00_ooooo1_l0000;ooooo`03
oiRHV?lQ8B7ok^k^00Oooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo
07Kooooo0021ooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo00006oooool00omgMgOoIVIVooooo`02
ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0Mooooo`03ogMgMomV
IVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool0
0000N?ooool0087ooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Looooo`05o`000?oooooooooo
ooooool@41000oooool00ol@413oooooooooo`0>ooooo`03oa0@4?l0003o000000?o00007Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@
401hooooo`00POooool01_l0003o<S8boooooooooooo<S8bo`0001Sooooo00Go0000okZj^_oooooo
V9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool00ol0003oooooooooo`0Joooo
o`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL0N?ooool0083ooooo00?o410@o`000?n7QhL00_ooool00on7QhOo0000oa0@400G
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo
00?o0000ooooooooool06_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h0N?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(260) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .31347 m
.00942 .32286 L
.01975 .33162 L
.02496 .33509 L
.02782 .33666 L
.03053 .33791 L
.03305 .33886 L
.03438 .33928 L
.03578 .33966 L
.03697 .33993 L
.03827 .34016 L
.03946 .34033 L
.04057 .34044 L
.04125 .34049 L
.04198 .34053 L
.0433 .34054 L
.0441 .34053 L
.04486 .34049 L
.04554 .34044 L
.04627 .34037 L
.04765 .34019 L
.0491 .33994 L
.0517 .33932 L
.05421 .33853 L
.05655 .33762 L
.06188 .33499 L
.07295 .32742 L
.08481 .3172 L
.10561 .29864 L
.11658 .2902 L
.12824 .28262 L
.13857 .27702 L
.14997 .27201 L
.16034 .2685 L
.17008 .26597 L
.19127 .26181 L
.2107 .2587 L
.23057 .25629 L
.24196 .25513 L
.24734 .25466 L
.2523 .2543 L
.25477 .25416 L
.25738 .25404 L
.25874 .254 L
.26001 .25397 L
.26074 .25395 L
.2614 .25394 L
.26217 .25394 L
.26289 .25394 L
.2641 .25394 L
Mistroke
.26538 .25396 L
.26658 .25399 L
.26768 .25403 L
.26897 .25408 L
.27037 .25416 L
.27289 .25434 L
.27555 .2546 L
.27847 .25496 L
.28436 .25596 L
.28981 .25724 L
.29489 .25879 L
.30017 .26082 L
.30589 .26361 L
.31094 .26667 L
.3163 .27062 L
.32644 .28036 L
.3358 .29228 L
.35629 .32844 L
.37549 .37029 L
.38584 .3905 L
.39105 .39847 L
.39402 .40214 L
.39673 .40482 L
.39793 .40581 L
.39924 .40673 L
.40036 .40739 L
.4016 .40799 L
.40292 .40846 L
.40364 .40864 L
.40431 .40877 L
.40551 .40889 L
.40681 .40887 L
.40801 .4087 L
.40932 .40836 L
.41056 .40788 L
.4117 .40732 L
.41387 .40592 L
.41617 .40398 L
.42129 .39812 L
.42599 .3911 L
.43659 .37125 L
.45577 .33147 L
.46537 .31418 L
.47562 .29927 L
.48151 .29246 L
.48687 .28731 L
.49196 .28326 L
.49735 .27977 L
.50233 .27723 L
.50497 .27612 L
Mistroke
.50781 .27511 L
.51041 .27434 L
.5128 .27376 L
.51519 .2733 L
.51747 .27297 L
.51884 .27282 L
.52009 .27271 L
.52078 .27266 L
.52153 .27262 L
.52288 .27257 L
.52415 .27255 L
.5255 .27256 L
.52664 .27259 L
.5279 .27265 L
.52867 .27269 L
.52939 .27274 L
.53075 .27286 L
.5338 .2732 L
.53929 .27406 L
.54944 .27622 L
.56021 .27896 L
.57956 .28433 L
.58941 .28686 L
.59458 .28796 L
.60002 .28888 L
.60233 .28919 L
.60481 .28946 L
.60752 .28969 L
.60873 .28977 L
.61004 .28984 L
.61133 .28989 L
.61251 .28993 L
.61365 .28996 L
.61485 .28997 L
.61593 .28998 L
.61693 .28997 L
.61803 .28996 L
.61922 .28993 L
.61994 .28991 L
.62062 .28989 L
.6219 .28984 L
.62475 .28968 L
.62721 .28951 L
.62987 .28927 L
.63591 .28855 L
.64147 .28766 L
.65174 .28543 L
.66258 .28246 L
.67257 .27972 L
.67806 .27843 L
Mistroke
.68326 .27745 L
.6856 .2771 L
.68809 .27678 L
.68939 .27665 L
.69082 .27653 L
.69214 .27644 L
.69335 .27637 L
.69452 .27633 L
.69563 .27631 L
.6968 .2763 L
.69808 .27632 L
.6992 .27636 L
.70039 .27642 L
.70151 .27651 L
.70253 .2766 L
.70496 .27691 L
.70635 .27715 L
.70764 .2774 L
.71025 .27804 L
.71305 .27894 L
.71811 .28119 L
.72273 .28406 L
.7281 .28857 L
.73395 .29511 L
.73947 .30305 L
.74458 .31208 L
.75469 .33513 L
.76417 .36321 L
.77471 .40025 L
.7858 .4405 L
.79069 .45621 L
.79591 .47006 L
.79892 .47623 L
.80165 .48052 L
.80296 .4821 L
.80439 .48345 L
.80574 .48435 L
.80698 .48487 L
.8081 .48508 L
.8093 .48502 L
.81044 .4847 L
.81147 .48418 L
.81269 .4833 L
.81401 .48201 L
.81642 .47881 L
.81893 .47435 L
.8216 .46842 L
.82641 .45511 L
.84741 .37783 L
.85846 .33986 L
Mistroke
.87011 .30847 L
.88058 .28804 L
.88652 .27938 L
.89206 .27301 L
.89715 .26848 L
.90179 .26533 L
.90436 .26396 L
.90715 .26274 L
.9098 .26182 L
.91222 .26117 L
.91468 .26068 L
.91597 .26049 L
.91733 .26033 L
.91851 .26023 L
.91961 .26017 L
.92082 .26013 L
.92211 .26012 L
.92285 .26014 L
.92353 .26016 L
.92427 .2602 L
.92505 .26025 L
.92638 .26036 L
.92783 .26053 L
.93051 .26095 L
.93302 .26147 L
.93858 .26307 L
.94366 .26508 L
.95509 .27149 L
.96547 .27937 L
.97509 .28802 L
.99688 .31022 L
1 .31347 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool005cooooo
5_l00013ooooo`03o`000?oooooooooo0;3ooooo001Fooooo`Ko00005_ooool3o`00043ooooo00?o
0000ooooooooool0/?ooool0053ooooo1_l0000Oooooo`;o0000?_ooool2o`00083ooooo2_l0000W
ooooo`00Boooool5o`0002Oooooo0_l0000looooo`03o`000?oooooooooo07cooooo0ol0000:oooo
o`?o00009?ooool001Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^
kP0Jooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Co
00005oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0:ooooo`03o`000?oooooooooo
00oooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^7_ooool00ol0003ooooo
ooooo`0Oooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQ[ooooo1Ol00003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo
00Ook^k^oc8b<_l0003o<S8bonk^k_oooooo0000013ooooo0_l00009ooooo`;o000000Wo410@oooo
ooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h03_ooool001Kooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`03
ogMgMonHV9So000000;o00006oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`;o00004Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL07_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`07ogMgMonHV9So
oooooiRHV?mgMgOoooooo`00000Booooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko00000_ooool5o`0000?ooooo
00Go410@oooooooooooooooooa0@400Booooo`Ko00001_ooool01_l0003ooooooooooooooooo410@
o`0000;ooooo00?o410@ooooooooool04Oooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h01?ooool0
1Ol@413ooooooooooooooooo410@00gooooo00?o0000ooooooooool00oooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01kooooo00?o0000ooooool00000
3?l0000Eooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Kooooo`03
oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400Oooooo`05o`000?oooooooooo
ooooool@41000oooool00ol@413o0000ooooo`0Cooooo`03o`000?oooooooooo00?ooooo1Ol00003
ooooo`05oa0@4?ooooooooooooooool@41003_ooool001?ooooo00CoA4A4omgMgOoooooo00001?oo
ool01Ol0003ooooooooooooooooo000001gooooo00CoZJVYoa0@4?oooooooooo0_l00003ooooo`03
o`000?oooooooooo01_ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000
00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000007_ooool2o`0000gooooo1?l0000Aooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`00000:ooooo`co00001_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oo
ooooooooooooool000007_ooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool0
00005_ooool00ol0003oooooooooo`02ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000oooo
ooooooooooooo`00000>ooooo`004oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?oooooo
ooooooooool000007?ooool01ol@413o0000okZj^_oooooo0000ooooool000000oooool00ol0003o
ooooooooo`0Looooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00000?oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000001cooooo0ol0000Booooo`Co00003Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000002?ooool2o`0000cooooo0ol00004ooooo`03ogMgMomVIVKooooo00;ooooo00Go
0000ooooooooooooooooo`00000Mooooo`03oa0@4?l0003o^[Zj00?ooooo00?o0000ooooooooool0
0_l0000Gooooo`;o00000_ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?oooooooooooooo
ool000003_ooool001Cooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@
01gooooo00?o^[Zjo`000?l000000_ooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000
oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41006oooool01?l0003ooooo
ooooool0000Fooooo`Go00002?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41001?ooool4o`00017ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
410@00?ooooo00?o410@ooooooooool07?ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?oooooo
0000ooooool@41006Oooool01_l0003ooooooooooomgMgOoc<c<o`0000Cooooo00Go410@oooooooo
oooooooooa0@400>ooooo`005?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL06_ooool00ol@413oV9RHo`000002o`0000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0K
ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg013ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL06_ooool01Ol0003ooooooooooooooooo000001_ooooo1?l00004ooooo`03o`000?oooooooooo
00;ooooo00?oMgMgoiRHV?ooool01_l0000Eooooo`;o000000Co^[ZjoooooonHV9So410@0oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
Mol0003ooooooiRHV?mgMgL06_ooool01Ol0003oooooonk^k_m4A4Co000000Cooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0>ooooo`005Oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h06_ooool3o`000003oa0@4?nYZJWooooo00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0Kooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^017o
oooo00?o0000ooooooooool02?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h06Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01gooooo3?l000000olb
<S;ok^k^ooooo`0Iooooo`05o`000?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^01_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_l0003o0000oc8b<_o^
k^h06_ooool01Ol0003ooooooooooomgMgOo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>
ooooo`00>Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool00oooool2o`0004Oooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo01Sooooo000hooooo`03o`000?oooooooooo04Kooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04Oooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Oooooo000gooooo`03o`00
0?oooooooooo04Sooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo04Sooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo01Kooooo000fooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01Gooooo000eooooo`03o`000?oooooo
oooo04_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo04Wooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo01Cooooo000Foooooooo0000@?l0000Cooooo`005_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ool000001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`03ooooo`;o00001oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04oooo
o`;o00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`04ooooo`;o00004oooool001Kooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02?ooooo0_l0000Uooooo`03
o`000?oooooo000002Oooooo00?o0000ooooooooool04Oooool001Oooooo00?o0000ooooooooool0
5_ooool2o`0005?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo04cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0kooooo`006?oo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`0kooooo`006Oooool2o`0001?ooooo00?o0000ooooooooool0EOooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00[ooooo0_l0001>ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool0??ooool001_ooooo00?o0000ooooooooool03_ooool2o`00
05Wooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
04gooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0looooo`007?ooool2o`0000co
oooo0_l0001Kooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`1=ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0?Oooool001kooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool0?Oooool001oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`1Mooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`1>ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0?Oooool0023ooooo2?l0001Q
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03?ooool2o`00053ooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0nooooo`00ROooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo03kooooo0029ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool0?oooool008[ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo053ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0oooooo`00R_oo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0D?oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo03oooooo002;ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool03_ooool2o`00057ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`10ooooo`00Roooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
043ooooo002<ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`1Aooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0@?ooool008cooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo057ooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`11ooooo`00S?ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0DOooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo047ooooo002=ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool04Oooool2o`0005?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`11
ooooo`00SOooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0D_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04;ooooo002>ooooo`09
o`000?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B42ooooo`03o`000?oo
oooo000000Co00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0
D_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04;ooooo002?ooooo`08o`000?oo
ooooooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q00Woooooo`000?oooooooooooiRHV?lQ
8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo05;ooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`12ooooo`00Soooool01?l0003ooooooooo
ool@4103ooooo`03oa0@4?oooooooooo00Kooooo00Oo0000oooooooooooooooooiRHV?lQ8B7ok^k^
00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool0@_ooool0093ooooo00?o0000ooooool000000oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo
<S8booooo`04ooooo`?o0000Doooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04?o
oooo002Aooooo`;o00000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo
00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool0Doooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04?ooooo002Aooooo`03o`00
0?l@413ooooo00;ooooo00?o410@ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Cooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0@oooool009;ooooo00Go0000oiRHV?ooooooV9RH
ogMgM`05ooooo`03o`000?oooooooooo00?ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo04?ooooo002Booooo`05o`000?lb<S;o0000oc8b<_o^k^h01?ooool2o`0000Go
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`1Doooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0A?ooool009?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Hooooo`;o0000EOooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo04Cooooo002Dooooo`;o00000oooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo05Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`14ooooo`00U_oo
ool3o`0001cooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo04Cooooo002eooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`15ooooo`00]Oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0AOooool00;Gooooo0_l0001Gooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0AOooool00;Gooooo00?o0000ooooooooool0E_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo04Gooooo002eooooo`03o`000?oooooooooo05Kooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`15ooooo`00]Oooool00ol0003oooooooooo`1G
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0A_ooool00;Gooooo0_l0001Hoooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0A_ooool00;Gooooo00?o0000oooooooo
ool0Eoooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04Kooooo002eooooo`03o`00
0?oooooooooo05Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`16ooooo`00]Ooo
ool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Aooo
ool00;Gooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo04Oooooo002eooooo`;o0000FOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
04Oooooo002eooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`17ooooo`00]Oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0B?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0FOooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo04Sooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1Iooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0B?ooool009[ooooo00Go410@oooooooooooo
oooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0001Jooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0BOooool009[ooooo00Go0000ooooooooooooooooo`00000?ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo04Wooooo002Jooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo04[ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1:ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0Boooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`00
05gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1;ooooo`00]Oooool00ol0003o
ooooooooo`1Mooooo`05o`000?ooooooooooooooool00000C_ooool00;Gooooo00?o0000oooooooo
ool0G_ooool3o`0004oooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^
k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool0
09;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009;ooooo00Go410@oooo
oooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Q
ooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003_oo
ool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?oo
ool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S80
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool0
0:_ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002]ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool00:gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?oo
ool00:gooooo00?o0000ooooooooool0^?ooool00:gooooo00?o0000ooooooooool0^?ooool00:go
oooo00?o0000ooooooooool0^?ooool00:_ooooo00?oEEEEofIVI_l00000^_ooool00?ooooooJOoo
ool00:oooooo00?o0000okZj^_ooool0]_ooool00:oooooo0_lb<S:gooooo`00P?ooool2o`000006
oa0@4?oooooooooooa0@4?l0003o410@5oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`Go0000
0oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1hoooo
o`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l00009ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?oc<c<
o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00009ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@00oooool01OmEEEGoMgMgoooooonHV9So8B4Q00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`1hooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Oo
oooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01;ooooo00?o0000oooo
ooooool06oooool00onHV9So8B4Qonk^kP04ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol@413ooooooooooooooooo410@07Sooooo0021ooooo`06o`000?ooooooA4A4odA4A?oooooo0000
2Oooool6o`0000_ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000001;o
oooo00?o0000ooooooooool02oooool6o`0000_ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003o
V9RHoooooonHV9So8B4Q00?ooooo00Go0000ooooooooooooooooo`00001hooooo`00POooool01_l0
003ogMgMoc8b<_mEEEGogMgMo`0001_ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooo
oooooooo000001;ooooo00?o0000ooooooooool07Oooool00omgMgOoIVIVooooo`02ooooo`05o`00
0?mEEEGo0000oa0@4?o<c<`00oooool01Ol0003ooooooooooooooooo000007Sooooo0021ooooo`06
o`000?n7QhOoZJVYokZj^_mEEEGo00007?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o
410@ooooooooool03_ooool00ol@413o0000o`000003o`0001gooooo00Ko0000oooooooooooooooo
oeEEEOn7QhL6ooooo`05oa0@4?ooooooooooooooool@4100N?ooool0087ooooo00Ko0000oc8b<_oo
oooooooooc8b<_l0000Hooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg01;ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonHV9So410@00?o
oooo00?ogMgMoa0@4?nHV9P01Oooool01OmgMgOoV9RHoooooonHV9SoMgMg07Sooooo0020ooooo`03
oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41005oooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Booooo`03o`000?oooooooooo01[ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c004ooooo`04olc<c?m4A4Co0000oa0@40?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP1hooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(270) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .3268 m
.00488 .33025 L
.00942 .33299 L
.01441 .33537 L
.01721 .3364 L
.01975 .33713 L
.02104 .33743 L
.02242 .3377 L
.02359 .33788 L
.02488 .33803 L
.02627 .33813 L
.02704 .33816 L
.02776 .33818 L
.02914 .33817 L
.03045 .3381 L
.03166 .338 L
.03296 .33784 L
.03529 .33745 L
.03806 .33679 L
.04057 .33602 L
.04627 .33373 L
.05151 .33101 L
.06335 .32316 L
.08481 .30592 L
.10625 .29053 L
.12627 .27944 L
.14551 .27121 L
.1563 .26776 L
.16614 .26507 L
.18787 .25947 L
.20798 .2552 L
.22749 .25211 L
.23735 .25082 L
.24005 .25054 L
.24296 .25028 L
.24571 .25009 L
.24691 .25002 L
.24822 .24996 L
.24957 .24992 L
.25083 .24989 L
.25206 .24988 L
.2532 .24988 L
.25443 .24989 L
.25578 .24992 L
.25646 .24994 L
.2572 .24997 L
.25852 .25003 L
.26109 .25019 L
.26352 .25041 L
.26809 .25095 L
Mistroke
.27349 .25184 L
.27849 .25293 L
.28398 .25447 L
.28983 .25657 L
.29547 .25918 L
.30066 .26217 L
.31235 .27137 L
.32267 .2826 L
.33355 .29787 L
.35444 .33687 L
.37347 .37677 L
.37853 .38589 L
.38402 .3942 L
.38653 .39734 L
.3892 .40014 L
.39171 .40225 L
.394 .40372 L
.39526 .40434 L
.39659 .40484 L
.39793 .40518 L
.39869 .40531 L
.39939 .40538 L
.40067 .40539 L
.40184 .40528 L
.40318 .40501 L
.40445 .4046 L
.40585 .404 L
.40733 .40318 L
.40998 .40127 L
.41284 .3986 L
.41597 .395 L
.42667 .37849 L
.43643 .36006 L
.44783 .33821 L
.45838 .32035 L
.46789 .30727 L
.4784 .29629 L
.48384 .29191 L
.48896 .28855 L
.49436 .28573 L
.49718 .28455 L
.50019 .28348 L
.50291 .2827 L
.50538 .28212 L
.50787 .28167 L
.51022 .28135 L
.51155 .28122 L
.51296 .28111 L
.51416 .28104 L
.51549 .28099 L
Mistroke
.51623 .28098 L
.51691 .28097 L
.5177 .28097 L
.51844 .28098 L
.51976 .28102 L
.52051 .28105 L
.5212 .28108 L
.5226 .28116 L
.5241 .28128 L
.52683 .28155 L
.53193 .28221 L
.54335 .2842 L
.56389 .28822 L
.56952 .28918 L
.57261 .28965 L
.57555 .29003 L
.57827 .29033 L
.58124 .29059 L
.58254 .29068 L
.58393 .29076 L
.58512 .29082 L
.58642 .29086 L
.58768 .29089 L
.58904 .2909 L
.58973 .2909 L
.59047 .2909 L
.5918 .29087 L
.59313 .29083 L
.59438 .29078 L
.59673 .29063 L
.5995 .2904 L
.60205 .29012 L
.60783 .28929 L
.61758 .28729 L
.62791 .28445 L
.64871 .27689 L
.66771 .26972 L
.67273 .26815 L
.6782 .26668 L
.68342 .26551 L
.68814 .26468 L
.69099 .2643 L
.69366 .26403 L
.69513 .26392 L
.69649 .26384 L
.69719 .26381 L
.69797 .26379 L
.69878 .26378 L
.69953 .26377 L
.70091 .26379 L
Mistroke
.7022 .26385 L
.70337 .26392 L
.70463 .26403 L
.70601 .26419 L
.70747 .26441 L
.71009 .26493 L
.71273 .26565 L
.71524 .26652 L
.71996 .26872 L
.72504 .272 L
.73059 .27681 L
.73541 .28214 L
.74055 .28915 L
.7498 .30564 L
.76059 .33226 L
.77227 .37063 L
.78237 .40945 L
.79345 .45077 L
.79867 .46666 L
.80155 .47379 L
.80427 .47929 L
.8068 .48318 L
.80823 .48484 L
.80956 .48601 L
.81067 .48671 L
.81189 .4872 L
.81317 .48737 L
.81438 .48723 L
.81567 .48674 L
.8164 .48631 L
.81708 .48582 L
.81846 .48453 L
.81993 .48274 L
.82259 .47844 L
.82502 .47343 L
.83092 .45743 L
.83649 .43853 L
.85571 .36545 L
.86664 .33054 L
.87198 .31671 L
.87687 .30595 L
.88692 .289 L
.89246 .28232 L
.89773 .27751 L
.90038 .27559 L
.90321 .2739 L
.90565 .27271 L
.90829 .2717 L
.90992 .27121 L
.91141 .27085 L
Mistroke
.91284 .27058 L
.91356 .27046 L
.91434 .27036 L
.91569 .27023 L
.91695 .27017 L
.91772 .27015 L
.91845 .27015 L
.91982 .2702 L
.92102 .27029 L
.92231 .27042 L
.92353 .2706 L
.92465 .27079 L
.92725 .27137 L
.92998 .27215 L
.93513 .27411 L
.94076 .27691 L
.95078 .28338 L
.96011 .29079 L
1 .32679 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000/Oooool0
06?ooooo2?l0001:ooooo`03o`000?oooooooooo0;3ooooo001Kooooo`So00002?ooool5o`0004Go
oooo00?o0000ooooooooool0/?ooool005Gooooo1_l0000Eooooo`Co0000@Oooool00ol0003ooooo
ooooo`2`ooooo`00D?ooool5o`0001oooooo00?o0000ooooooooool0?_ooool00ol0003ooooooooo
o`2`ooooo`00COooool3o`0002Gooooo0_l0000nooooo`;o0000/Oooool004Wooooo1?l0000Zoooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0=oooool;o`0006kooooo000Eooooo`;o
000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h06_ooool01OnHV9So410@o`00
0?lb<S;oc<c<00?ooooo00Cok^k^oc8b<_l0003o<S8b0ol0000Iooooo`Go00000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Wooooo00?o0000ooooooooool04?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hNooooo`03o`000?oooooooooo01oooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^2?ooool4o`0000[ooooo2Ol00003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h06oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0Mooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h03_oo
ool001Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00Go
410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMol0003o0000o`000?mgMgL06oooool01OnHV9So
8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0:ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1_ooool2o`0001;ooooo00Go0000ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL06oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`So00004Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3_ooool000_ooooo1_l00002ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@01;ooooo
1_l00006ooooo`03o`000?oooooooooo00;o00000oooool00ol@413oooooooooo`0Aooooo`Ko0000
0oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41002_ooool00ol0003o
ooooooooo`06ooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41007_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@4003ooooo`?o00005?ooool01?l0003oV9RHob4Q8Oo^k^h4ooooo`05oa0@4?oo
ooooooooooooool@41007oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@oooooooo
ool00ol00008ooooo`;o00003?ooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400>oooo
o`004oooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000007Oooool0
1_nYZJWo410@o`000?l0003oooooo`0000?ooooo00?o0000ooooooooool06oooool00onHV9So8B4Q
onk^kP03ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Nooooo`;o00008_ooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooooooo`Co00006?ooool01?l0003oV9RHob4Q8Oo^
k^h3ooooo`05o`000?ooooooooooooooool000007_ooool00onYZJWo410@ooooo`02ooooo`05o`00
0?ooooooooooooooool000000_ooool00ol0003oooooooooo`0:ooooo`;o00002_ooool01?m4A4Co
gMgMooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool001?ooooo00CogMgMoeEE
EOoooooo00001?ooool01Ol0003ooooooooooooooooo000001cooooo00?o410@o`000?l000000ooo
ool01Ol0003ooooooooooooooooo000001kooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooo
oooooooooooo000000cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000007_ooool00ol0003oooooo`000007o`0001[ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooo`000002o`0001cooooo00?o0000ogMgMomVIVH00oooool01Ol0
003ooooooooooooooooo000001gooooo00?o410@o`000?nj^[X00oooool01ol0003ooooooooooooo
oooo0000ooooool000003oooool00ol0003oooooooooo`07ooooo`04omgMgOmEEEGoooooo`0000Co
oooo00Go0000ooooooooooooooooo`00000>ooooo`005?ooool00omgMgOoc<c<o`000004ooooo`05
oa0@4?ooooooooooooooool@41006oooool2o`000003okZj^_lQ8B7ooooo00;ooooo00Go410@oooo
oooooooooooooa0@400Oooooo`05o`000?ooooooooooooooool@41000oooool00ol@413ooooooooo
o`0;ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@01gooooo1?l00007ooooo`Oo00004oooool00ol0003oooooooooo`04o`0000;ooooo
00?o410@ooooooooool06oooool2o`0000?ooooo00Go410@oooooooooooooooooa0@400Nooooo`03
okZj^_lQ8B7ooooo00;ooooo00Ko410@oooooooooooooooooa0@4?l0000Aooooo`;o00002?ooool0
0omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41003_ooool001Cooooo00?ok^k^
odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Wooooo0_l000001?nHV9SooooookZj
^_l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool01Ol0003o^[ZjoooooonHV9So410@
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0=ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo0_l000000ooooooo0000oooo
o`0?ooooo`?o00004?ooool3o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05o`00
0?nj^[[oooooo`000?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@oiRH
V?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?l000005?ooool00ol0003ooooooooo
o`05ooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`005Ooo
ool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h05oooool2o`000006oooo
oonYZJWo410@o`000?l@413oZJVY0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool00ol0003ooooo
ooooo`0;ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Jooooo`05
o`000?ooooooooooooooool000004ooooolAo`0000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0J
ooooo`05oiRHV?l@413o0000ob4Q8Ol000000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo
00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000o`000?o^k^h05Oooool2o`00
00Kooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000foooo
o`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0;_ooool2o`0000Cooooo0_l0001:oooo
o`03o`000?oooooooooo02cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Loooo
o`00=?ooool2o`0004Wooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo04[ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo01_ooooo000cooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0
:oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo000booooo`03o`000?oo
oooooooo04_ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo04_ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo01Wooooo000`ooooo`;o0000Coooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool06?ooool001Koooooool00010o`0001?ooooo000Fooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00007oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04oooo
o`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`0Aooooo`005_ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool09?ooool2o`0002Kooooo00?o0000oooo
ooooool08Oooool01Ol0003ooooooooooooooooo000001?ooooo000/ooooo`03o`000?oooooooooo
05Cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
04kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
01Cooooo000[ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo01?ooooo000Yooooo`;o0000FOooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo00[ooooo0_l0001?ooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Booooo`005_ooool00ol0003ooooooooo
o`0>ooooo`;o0000G?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0Coooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool04Oooool001Oooooo0_l0000<ooooo`;o0000Goooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo03_ooooo000Iooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0Goooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool0D?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03_ooooo000Jooooo`[o
0000Hoooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0D?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03cooooo0027ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool03_ooool2o`0005;ooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0looooo`00R?ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo03cooooo0028ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`1Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0?Oooool0
08Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
05;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0mooooo`00ROooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0D_ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo03gooooo002:ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool04?ooool2o`0005?ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0nooooo`00R_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0Doooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo03kooooo002:
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1C
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0?_ooool008_ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05?ooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0oooooo`00Roooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo03oooooo002<ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
4oooool2o`0005Gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0oooooo`00S?oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0E?oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo043ooooo002=ooooo`03o`000?oooooo
oooo00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q00Co0000oooooooooooooooo
1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`1Dooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0@?ooool008gooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B402Ol0003oooooooooooooooooV9RH
ob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0EOoo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo043ooooo002>ooooo`05o`000?oooooo
ooooooooool@41000oooool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
V9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Gooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`10ooooo`00S_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03oiRHV?lQ
8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0005Gooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`11ooooo`00Soooool01?l0003oooooooooool00003ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0@Oooool0093ooooo00?o0000ooooool@41000oooool00ol@413ooooooooo
o`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`11ooooo`00TOooool01_l0003oMgMgoiRHV?ooooooV9RHogMgM`?ooooo00?o0000ooooooooool0
1Oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`1Fooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0@Oooool009;ooooo
00Go0000oc8b<_l0003o<S8bonk^kP02ooooo`03o`000?oooooooooo00Kooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool0@_ooool009;ooooo0ol00002ooooo`;o00007?ooool2o`0005Oo
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`12ooooo`00U?ooool3o`0001kooooo
00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04;ooooo
002eooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`13ooooo`00]Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0@oooool00;Gooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo04?ooooo002eooooo`;o0000FOooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo04?ooooo002eooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`14ooooo`00]Oooool00ol0003oooooooooo`1Hooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0A?ooool00;Gooooo00?o0000ooooooooool0F?ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04Cooooo002eooooo`;o0000F_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo04Cooooo002eooooo`03o`000?oooooooooo05Wo
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`15ooooo`00]Oooool00ol0003ooooo
ooooo`1Iooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0AOooool00;Gooooo00?o
0000ooooooooool0FOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04Gooooo002e
ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`16
ooooo`00]Oooool2o`0005_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`16oooo
o`00]Oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0A_ooool00;Gooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo04Oooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo05_ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`17ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0Foooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo04Oooooo002Jooooo`05oa0@4?ooooooooooooooool@
41004?ooool00ol0003oooooooooo`03ooooo`?o0000Foooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo04Sooooo002Jooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`18ooooo`00V_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0
003o<S8bolc<c005ooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`18ooooo`00V_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0BOooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
04Wooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0001Ooooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0BOooool00;Gooooo00?o0000oooooooo
ool0G_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04[ooooo002eooooo`03o`00
0?oooooooooo05oooooo00Co0000oooooooooooo0000COooool00;Gooooo00?o0000ooooooooool0
H?ooool3o`0004gooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002a
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool0/?ooool009;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGo
oooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Ol0
003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04
ooooo`?o0000/?ooool009;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<co
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo002B
ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo
1?l00006ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00:_ooooo1?l000000ol@413oooooooooo`03oooo
o`03o`000?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0/?ooool00:gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2`ooooo`00[Ooo
ool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000ooooooooool0^?ooool0
0:gooooo00?o0000ooooooooool0^?ooool00:gooooo00?o0000ooooooooool0^?ooool00:_ooooo
00?oEEEEofIVI_l00000^_ooool00?ooooooJOooool00:oooooo00?o0000okZj^_ooool0]_ooool0
0:oooooo0_lb<S:gooooo`00P?ooool2o`000006oa0@4?oooooooooooa0@4?l0003o410@5oooool5
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`03ohN7Qol0003o^[Zj00cooooo00Go
V9RHo`000?l0003oA4A4okZj^P0Hooooo`Go00001Oooool00ol0003ok^k^ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0N?ooool0087ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`Ko00002Oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`03olc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009
ooooo`Ko00002Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo00?oEEEEojVYZOooool00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg07Sooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool05oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@4100
4_ooool00ol0003oooooooooo`0Kooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?oZJVYoeEEEOooool0
0oooool01Ol@413ooooooooooooooooo410@07Sooooo0021ooooo`06o`000?ooooooA4A4odA4A?oo
oooo00002Oooool6o`0000_ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo
000001;ooooo00?o0000ooooooooool02oooool6o`0000_ooooo00?oV9RHob4Q8Oo^k^h01_ooool0
0olQ8B7oooooooooo`02ooooo`05o`000?ooooooooooooooool00000N?ooool0087ooooo00Ko0000
omgMgOlb<S;oEEEEomgMgOl0000Kooooo`03ogMgMomVIVKooooo00;ooooo00Go0000oooooooooooo
ooooo`00000Booooo`03o`000?oooooooooo01gooooo00?oMgMgofIVI_ooool01Oooool00omEEEGo
c<c<ooooo`02ooooo`05o`000?ooooooooooooooool00000N?ooool0087ooooo00Ko0000ohN7QonY
ZJWo^[ZjoeEEEOl0000Looooo`05o`000?ooooooooooooooool@41000oooool00ol@413ooooooooo
o`0>ooooo`03oa0@4?l0003o000000?o00007Oooool00ol0003oooooooooo`04ooooo`03ojVYZOmg
MgOooooo00;ooooo00Go410@oooooooooooooooooa0@401hooooo`00POooool01_l0003o<S8boooo
oooooooo<S8bo`0001Sooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL04_ooool00ol0003oooooooooo`0Jooooo`05o`000?nj^[[ooooooiRHV?l@41000ooo
ool01Ol@413ooooooooooooooooo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1hooooo`00
P?ooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Oooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Joooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP1hooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(280) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .33313 m
.00236 .33389 L
.00488 .33458 L
.00706 .33506 L
.00942 .33547 L
.01087 .33565 L
.0122 .33578 L
.01348 .33587 L
.01483 .33592 L
.01604 .33593 L
.01717 .33591 L
.01841 .33585 L
.01975 .33574 L
.02113 .33559 L
.02241 .3354 L
.02532 .33484 L
.02789 .33418 L
.03062 .33331 L
.04057 .32883 L
.05251 .32144 L
.06377 .31356 L
.08481 .29888 L
.12529 .27574 L
.14622 .26702 L
.16834 .25942 L
.18896 .25372 L
.20821 .2499 L
.21347 .24906 L
.21918 .24825 L
.22423 .24764 L
.22699 .24737 L
.22958 .24716 L
.2319 .24701 L
.2332 .24695 L
.23439 .2469 L
.23563 .24687 L
.23698 .24684 L
.23766 .24684 L
.23839 .24683 L
.2397 .24684 L
.24091 .24686 L
.24222 .2469 L
.24346 .24696 L
.24461 .24702 L
.24677 .24716 L
.24906 .24736 L
.25424 .24799 L
.25897 .24875 L
.26407 .24978 L
.26962 .25115 L
Mistroke
.27474 .25271 L
.27948 .25446 L
.28885 .25901 L
.29419 .26241 L
.29997 .26682 L
.31044 .27683 L
.32999 .30278 L
.35055 .34046 L
.36144 .36224 L
.36743 .37337 L
.3731 .38267 L
.37849 .38997 L
.38133 .39311 L
.38434 .39584 L
.38687 .39763 L
.38822 .3984 L
.38966 .39907 L
.39099 .39954 L
.3922 .39986 L
.39336 .40006 L
.39458 .40016 L
.39584 .40015 L
.39698 .40003 L
.3983 .39977 L
.39954 .39941 L
.4007 .39897 L
.40176 .39848 L
.40415 .39708 L
.40658 .39527 L
.40924 .39283 L
.41461 .38663 L
.43679 .35067 L
.45702 .32005 L
.46706 .30903 L
.47235 .30433 L
.47798 .30012 L
.48288 .29711 L
.48829 .29447 L
.49066 .29353 L
.49322 .29268 L
.49784 .2915 L
.50035 .29104 L
.50174 .29084 L
.50304 .29069 L
.50425 .29057 L
.50557 .29046 L
.50677 .29039 L
.50788 .29034 L
.50919 .2903 L
.51042 .29028 L
Mistroke
.51176 .29028 L
.51252 .29029 L
.51321 .2903 L
.5146 .29033 L
.51538 .29036 L
.51611 .29038 L
.51886 .29052 L
.52449 .29088 L
.52958 .29128 L
.54101 .29225 L
.55084 .29305 L
.55324 .2932 L
.5558 .29334 L
.55727 .29341 L
.55861 .29345 L
.55996 .29348 L
.56123 .2935 L
.56261 .2935 L
.5633 .2935 L
.56407 .29348 L
.56542 .29345 L
.56669 .2934 L
.56818 .29331 L
.56955 .29322 L
.57262 .29292 L
.57506 .2926 L
.57773 .29218 L
.5831 .29111 L
.5939 .28822 L
.6037 .28503 L
.62571 .27613 L
.64757 .26615 L
.65716 .26247 L
.66771 .2591 L
.6726 .25776 L
.67786 .25649 L
.6824 .25557 L
.68479 .25516 L
.68734 .2548 L
.68886 .25462 L
.69024 .25448 L
.69163 .25437 L
.69292 .25429 L
.69423 .25424 L
.69491 .25422 L
.69564 .25421 L
.69686 .25422 L
.6982 .25425 L
.6995 .25432 L
.70068 .25441 L
Mistroke
.70205 .25454 L
.70334 .2547 L
.70563 .25507 L
.70812 .2556 L
.71323 .25712 L
.71803 .25913 L
.72328 .26207 L
.72894 .26622 L
.73485 .27183 L
.74047 .27861 L
.75102 .296 L
.76108 .3193 L
.7718 .35198 L
.79111 .42427 L
.8019 .46061 L
.80486 .46834 L
.80798 .47506 L
.81065 .47947 L
.81216 .4814 L
.81358 .4828 L
.81489 .48375 L
.81564 .48413 L
.81632 .48439 L
.81758 .48462 L
.81892 .48451 L
.82012 .48411 L
.82124 .48348 L
.82247 .4825 L
.8238 .48111 L
.82658 .47713 L
.82951 .47146 L
.83476 .45806 L
.85571 .3843 L
.86485 .35399 L
.87476 .32746 L
.88026 .31579 L
.88534 .30689 L
.89051 .29957 L
.89534 .29419 L
.90042 .28997 L
.90312 .28828 L
.90602 .28688 L
.90747 .28633 L
.90905 .28583 L
.91054 .28546 L
.91193 .28521 L
.9133 .28502 L
.91455 .28492 L
.91524 .28489 L
.91598 .28488 L
Mistroke
.91733 .2849 L
.91864 .28498 L
.91983 .28509 L
.92121 .28529 L
.92251 .28552 L
.92482 .28604 L
.92733 .28676 L
.93303 .28892 L
.9383 .29148 L
.94903 .29812 L
.96043 .30679 L
1 .33313 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo001Oooooo`Ko0000;Oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2
o`000;7ooooo001Gooooo`So00001_ooool7o`0004Wooooo00?o0000ooooooooool0/?ooool005Co
oooo0ol0000Eooooo`?o0000A_ooool00ol0003oooooooooo`2`ooooo`00Coooool5o`0001_ooooo
0ol00013ooooo`03o`000?oooooooooo03Gooooo3?l0001_ooooo`00B_ooool5o`0002?ooooo00?o
0000ooooooooool0@?ooool00ol0003oooooooooo`0aooooo`Co00003?ooool3o`0006cooooo0017
ooooo`?o0000:Oooool00ol0003oooooooooo`0oooooo`;o0000;oooool3o`0001?ooooo00?o0000
ooooooooool0JOooool004Gooooo0_l0000]ooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool0:oooool3o`0001Oooooo00?o0000ooooooooool0J?ooool001Gooooo0_l000002Ol@413o
ooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0Jooooo`05oiRHV?l@413o0000oc8b<_o<c<`0
0oooool01Oo^k^ko0000o`000?lb<S;ok^k^01_ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01_ooool2o`0001Cooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
7_ooool00ol0003oooooooooo`0Oooooo`Co000000Go410@ooooooooooook^k^oc8b<P03o`0001[o
oooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool01OnHV9So410@o`000?lb<S;o
c<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Mooooo`;o000000Wo410@oooooooooooooooo
onk^k_lb<S;o0000oc8b<_o^k^h03_ooool001Kooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg01[ooooo00Go410@okZj^_ooooooMgMgoc8b<P02ooooo`;o000000CoV9RH
oooooonHV9SoMgMg6oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`08ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9So0000oiRHV?mgMgL06_ooool01OnHV9So8B4Qonk^k_l0003oA4A400?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0Kooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOo
V9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00kooooo000;ooooo`Ko00000_ooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400B
ooooo`Ko00001_ooool3o`000003ooooool@413ooooo00;ooooo00?o410@ooooooooool04Oooool6
o`0000?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00Wooooo00?o
0000ooooooooool01oooool6o`0000Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@01kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`;o0000
0_ooool00ol@413oooooooooo`0Iooooo`03oiRHV?lQ8B7o000000Cooooo00Go410@oooooooooooo
oooooa0@400Oooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Ioooo
o`Go00000oooool01Ol@413ooooooooooooooooo410@00kooooo000Cooooo`04odA4A?oMgMgooooo
o`0000Cooooo00Go0000ooooooooooooooooo`00000Mooooo`;o00000oooool01Ol0003ooooooooo
oooooooo000001gooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000[o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000007_ooool2o`0002;ooooo00?o0000ooooool000000ol00003ooooo`03o`000?oooooooooo
01[ooooo00?oV9RHob4Q8Ol000000oooool01Ol0003ooooooooooooooooo000001kooooo00?oZJVY
oa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000001_ooooo00CoA4A4omgMgOoooooo0000
1?ooool01Ol0003ooooooooooooooooo000000kooooo000Cooooo`04omgMgOmEEEGoooooo`0000Co
oooo00Go0000ooooooooooooooooo`00000Kooooo`?o000000Go^[Zjooooooooooooooooo`000003
ooooo`03o`000?oooooooooo01cooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooo
oooo000000[ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000007_ooool00ol0003oooooooooo`0Pooooo`?o00000oooool01Ol0003ooooo
oooooooooooo000001gooooo00?oMgMgo`000?ooool00_ooool01Ol0003ooooooooooooooooo0000
01gooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000001_ooooo00CogMgM
oeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000kooooo000Dooooo`03ogMgMoo<
c<co000000Cooooo00Go410@oooooooooooooooooa0@400Iooooo`;o00000_ooool00onj^[[o8B4Q
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41007oooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool02Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@400Nooooo`03o`000?oooooooooo01gooooo0ol00000
0ooooooo0000ooooo`03ooooo`05oa0@4?ooooooooooooooool@41007_ooool2o`0000;ooooo00Go
410@oooooooooooooooooa0@400Nooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooo
oooooa0@4006ooooo`?o00004oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooooooo
ool@41003_ooool001Cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
01Oooooo0_l000001_oooooo410@oiRHV?oooooo^[Zjo`0000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0Kooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL07_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00go0000okZj^_ooooooV9RH
oa0@4?oooooo0000oooooomgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@oiRHV?oooooo^[Zj
o`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool3o`0000;ooooo1?l0000?ooooo`03
onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`005Oooool00omgMgOo
0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h05_ooool02Ol0003ooooooooooooooooo
ZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool01OnHV9So
410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03o`000?oooooo
oooo00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01kooooo3?l0
000>ooooo`Go00000oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
6_ooool03OnHV9So410@o`000?lQ8B7oc<c<ooooool0003oooooonk^k_lb<S;o0000oc8b<_o^k^h0
6oooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02oooo
o`;o00002Oooool00ol0003oooooooooo`0=ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0>ooooo`00=?ooool2o`0004Kooooo00?o0000ooooooooool0<oooool5o`00
00[ooooo3_l0000eooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool02_ooool2o`00
02Kooooo000booooo`;o0000BOooool00ol0003oooooooooo`0_ooooo`?o00000oooool00ol0003o
ooooooooo`1=ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool03Oooool2o`0002Co
oooo000`ooooo`;o0000C?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0COooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo013ooooo
0_l0000Rooooo`00;oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo02_ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Oooooo`00;Oooool2o`00053ooooo00?o0000
ooooooooool0:Oooool2o`0000Sooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo01Cooooo0_l0000Oooooo`005_ooooooo`00043o00004oooool001Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00007ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Cooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo0ol00007ooooo`03o`000?oooooooooo017ooooo000Fooooo`03o`00
0?oooooooooo013ooooo0_l0000Booooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Cooooo00Co0000oooooooooooo
00009?ooool00ol0003oooooo`00000Mooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool04Oooool002Oooooo0_l0001Hooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
7?ooool2o`0001Wooooo000Uooooo`;o0000Foooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool05_ooool002Cooooo00?o0000ooooooooool0Foooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00_ooooo0_l0001Aooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Eooooo`008_ooool2o`00
05oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
057ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Rooooo`;o00005Oooool0023o
oooo0_l0001Qooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`1Aooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`0Booooo`005_ooool3o`0000Gooooo0_l0001Tooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Aooooo`006Oooool5o`0006Kooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05;ooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0jooooo`00QOooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00oooooo0_l0001Cooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool0>_ooool008Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo05;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0koooo
o`00Q_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0D_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo03_ooooo0026ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Cooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool0>oooool008Oooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0looooo`00R?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo01;ooooo0_l0001Dooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0??ooool0
08Sooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
05?ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0looooo`00ROooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0E?ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo03gooooo0029ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool0?Oooool008[ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0mooooo`00R_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Gooooo0_l0001F
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0?_ooool008_ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo05Gooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0nooooo`00Roooool00ol0003oooooooooo`04ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003o8B4Qooooo`03ooooo`Go00001?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo03kooooo002<ooooo`03o`000?oooooooooo00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`04ooooo`03o`000?lQ8B7o8B4Q00Cooooo00GoV9RHob4Q8Oo^k^koooooodA4
A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0E_ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo03oooooo002<ooooo`03o`000?oooooooooo00?ooooo00Go410@
oooooooooooooooooa0@4004ooooo`03o`000?oooooooooo00Gooooo00?oV9RHob4Q8Oo^k^h02Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0oooooo`00SOooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`07ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o
MgMgoc8b<_ooool01?ooool3o`0005Kooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`0oooooo`00S_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo0000
2oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003o
ooooooooo`1Gooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0?oooool008oooooo
00Co0000oooooooooooo410@0oooool00ol@413oooooo`00000=ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool0@?ooool0093ooooo0_l000001?mgMgOoV9RHoooooonHV9P2o`0000[o
oooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0Eoooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo043ooooo002Aooooo`Ko
00002oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo
05Oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`10ooooo`00]Oooool2o`0005Wo
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`11ooooo`00]Oooool00ol0003ooooo
ooooo`1Hooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0@Oooool00;Gooooo00?o
0000ooooooooool0F?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo047ooooo002e
ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`11
ooooo`00]Oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0@_ooool00;Gooooo0_l0001Jooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0@_ooool00;Gooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo04;ooooo002eooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`13ooooo`00]Oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0@oooool00;Gooooo0_l0001Kooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool0@oooool00;Gooooo00?o0000ooooooooool0Foooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo04Cooooo002eooooo`03o`000?oooooooooo05_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`14ooooo`00]Oooool00ol0003ooooooooo
o`1Kooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0A?ooool00;Gooooo00?o0000
ooooooooool0G?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04Cooooo002eoooo
o`;o0000GOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04Gooooo002eooooo`03
o`000?oooooooooo05cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`15ooooo`00
]Oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
AOooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo04Kooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0A_ooool009[ooooo00Go410@oooooooooooooooooa0@400@ooooo`03
o`000?oooooooooo00?ooooo0ol0001Mooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0A_ooool009[ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Ko
oooo002Jooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
04Oooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo05kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`17oooo
o`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`1Oooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Aoooool009[o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`00067ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`18ooooo`00]Oooool00ol0003oooooooooo`1Pooooo`;o
00000_ooool00ol0003oooooooooo`19ooooo`00]Oooool00ol0003oooooooooo`1Qooooo`?o0000
C?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool009;ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@
00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
0;3ooooo002Booooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06oooo
o`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00T_ooool01Ol0003ooooooooooooooooo0000
00kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000
ooooooooool0/?ooool009;ooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOo
oooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002a
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Zoooool4o`000003
oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool00:gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo0ol0002`ooooo`00[Oooool00ol0
003oooooooooo`2hooooo`00[Oooool00ol0003oooooooooo`2hooooo`00[Oooool00ol0003ooooo
ooooo`2hooooo`00Zoooool00omEEEGoIVIVo`00002jooooo`00oooooomYooooo`00[oooool00ol0
003o^[Zjooooo`2fooooo`00[oooool2oc8b<[Oooooo0020ooooo`;o000000Ko410@oooooooooooo
410@o`000?l@410Gooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?oQhN7
o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo1Ol00003ooooo`05olc<c?lQ
8B7o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07Sooooo0021ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`0000Wooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool00oo<c<co0000oa0@400<oooo
o`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4
A003ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg07So
oooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05oooool00onHV9So8B4Q
onk^kP04ooooo`05oa0@4?ooooooooooooooool@41004_ooool00ol0003oooooooooo`0Kooooo`03
oiRHV?lQ8B7ok^k^00Cooooo00Go0000ooooooooooooooooo`000003ooooo`05oa0@4?oooooooooo
ooooool@4100N?ooool0087ooooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00002ooo
ool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003ooooo
ooooo`0;ooooo`Ko00002oooool00onHV9So8B4Qonk^kP03ooooo`05oc8b<_nHV9SooooooiRHV?lb
<S800oooool01Ol0003ooooooooooooooooo000007Sooooo0021ooooo`06o`000?oMgMgo<S8boeEE
EOoMgMgo00006oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000004_oo
ool00ol0003oooooooooo`0Mooooo`03ogMgMomVIVKooooo00;ooooo00Goc<c<o`000?l0003o0000
olc<c003ooooo`05o`000?ooooooooooooooool00000N?ooool0087ooooo00Ko0000ohN7QonYZJWo
^[ZjoeEEEOl0000Looooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0>
ooooo`03oa0@4?l0003o000000?o00007Oooool02Ol0003ooooooooooooooooo410@okZj^_oooooo
^[Zjoa0@4003ooooo`05oa0@4?ooooooooooooooool@4100N?ooool0087ooooo00Ko0000oc8b<_oo
oooooooooc8b<_l0000Hooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg01;ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonHV9So410@00?o
oooo00Go0000okZj^_oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0N?ooool0
083ooooo00?o410@o`000?n7QhL00_ooool00on7QhOo0000oa0@400Gooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo00?o0000ooooooooool06_oo
ool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h0N?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(290) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .3347 m
.00123 .33478 L
.00236 .33483 L
.00365 .33486 L
.00488 .33486 L
.00601 .33484 L
.00706 .33479 L
.00821 .33472 L
.00942 .33462 L
.01065 .33448 L
.01196 .33431 L
.01434 .3339 L
.01716 .33327 L
.01975 .33255 L
.02485 .33075 L
.03042 .32825 L
.04057 .32262 L
.08481 .29289 L
.10719 .27888 L
.12749 .26837 L
.14889 .25904 L
.16857 .25289 L
.17821 .25049 L
.18878 .24823 L
.19391 .24733 L
.19941 .24654 L
.20245 .2462 L
.20522 .24593 L
.2078 .24573 L
.21064 .24556 L
.2119 .2455 L
.21325 .24545 L
.21441 .24541 L
.21569 .24538 L
.21705 .24536 L
.2178 .24535 L
.21849 .24534 L
.21973 .24534 L
.22105 .24534 L
.2223 .24536 L
.22365 .24538 L
.22492 .24541 L
.2261 .24544 L
.22832 .24553 L
.23068 .24565 L
.23327 .24582 L
.23604 .24605 L
.24106 .2466 L
.24703 .24751 L
.25248 .24862 L
Mistroke
.26284 .25159 L
.27245 .25547 L
.283 .26119 L
.29423 .26932 L
.30506 .27954 L
.31675 .2936 L
.33795 .32714 L
.35851 .3639 L
.36414 .37281 L
.37018 .38104 L
.37587 .3872 L
.37834 .38931 L
.38105 .39121 L
.38363 .39259 L
.38504 .39316 L
.38637 .39357 L
.3876 .39386 L
.38873 .39403 L
.38997 .39411 L
.39128 .39409 L
.39261 .39396 L
.39335 .39383 L
.39403 .39368 L
.39535 .39331 L
.39659 .39285 L
.39937 .39148 L
.40239 .38946 L
.40749 .38491 L
.41289 .37879 L
.42257 .36563 L
.4434 .33654 L
.4525 .32606 L
.46241 .31672 L
.46786 .31251 L
.47291 .30922 L
.47804 .30648 L
.48287 .30447 L
.48792 .30291 L
.49061 .30228 L
.49351 .30174 L
.49638 .30132 L
.4994 .30098 L
.50482 .30055 L
.51558 .2999 L
.52576 .29918 L
.53566 .29832 L
.5448 .29733 L
.54959 .29663 L
.55466 .29566 L
.55976 .29439 L
Mistroke
.56536 .29262 L
.58735 .28322 L
.60946 .27305 L
.62968 .26293 L
.63966 .25858 L
.65056 .25495 L
.66078 .25232 L
.67041 .25018 L
.67562 .24921 L
.67836 .24878 L
.68125 .24841 L
.68369 .24818 L
.68508 .24809 L
.68637 .24803 L
.68756 .24799 L
.68864 .24798 L
.6899 .24799 L
.69108 .24802 L
.69234 .24808 L
.69306 .24813 L
.69374 .24818 L
.69656 .24847 L
.699 .24884 L
.70163 .24934 L
.70762 .25089 L
.71311 .25281 L
.71809 .25501 L
.72341 .25792 L
.73299 .26518 L
.73885 .27132 L
.74438 .27856 L
.75473 .2964 L
.76495 .31997 L
.77576 .35147 L
.79514 .4192 L
.80506 .45073 L
.80792 .45808 L
.81063 .46405 L
.81309 .46853 L
.81444 .47058 L
.81571 .47224 L
.81692 .47355 L
.81822 .47469 L
.8194 .47546 L
.82049 .47595 L
.82152 .47622 L
.82264 .47629 L
.82382 .47613 L
.82492 .47576 L
.82622 .47505 L
Mistroke
.82745 .4741 L
.82976 .47165 L
.83225 .46807 L
.83495 .46315 L
.84485 .438 L
.85576 .40364 L
.86729 .36843 L
.87784 .34203 L
.88283 .33204 L
.88828 .32303 L
.89349 .31622 L
.89821 .31146 L
.90371 .30746 L
.90673 .3059 L
.90958 .3048 L
.91086 .30441 L
.91222 .30407 L
.91339 .30382 L
.91465 .30362 L
.916 .30346 L
.91726 .30336 L
.91803 .30332 L
.91876 .30331 L
.92013 .30332 L
.92133 .30337 L
.92261 .30347 L
.92383 .30361 L
.92495 .30376 L
.92753 .30424 L
.93026 .30491 L
.9354 .30658 L
.94103 .30897 L
.96036 .31992 L
.97022 .32552 L
.97952 .32983 L
.98467 .33167 L
.98738 .33247 L
.99025 .3332 L
.99267 .33372 L
.99532 .33417 L
.99774 .33449 L
1 .3347 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo001Coooooa7o0000;_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2
o`000;7ooooo001=ooooo`Ko00004Oooool5o`0004cooooo00?o0000ooooooooool0<_ooool=o`00
077ooooo001:ooooo`?o00007?ooool3o`0004Wooooo00?o0000ooooooooool0;oooool3o`0000go
oooo0ol0001^ooooo`00Aoooool3o`0002;ooooo0_l00017ooooo`03o`000?oooooooooo02_ooooo
1?l0000Cooooo`;o0000K?ooool004Cooooo0ol0000Wooooo`;o0000AOooool00ol0003ooooooooo
o`0Xooooo`?o00006Oooool2o`0006[ooooo0011ooooo`?o0000;?ooool2o`0004?ooooo0_l0000V
ooooo`?o00007_ooool00ol0003oooooooooo`1Wooooo`00?oooool2o`00037ooooo00?o0000oooo
ooooool0@?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool0I_ooool001Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^
kP0Jooooo`03oiRHV?l@413o000000;o00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo
1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool00ol0003oooooooooo`0Eooooo`Co
000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQkooooo00?o0000ooooooooool07ooo
ool5o`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Jooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01_ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h07Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00ko
oooo000Fooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05
oa0@4?nj^[[o0000ogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
01[ooooo00GoV9RHob4Q8Oo^k^koooooo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06ooo
ool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`002oooool6o`0000;o
oooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41004_ooool6o`0000;ooooo0_l00002oooo
o`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooooooo
o`0:ooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
7_ooool00ol0003oooooooooo`0Oooooo`?o00001?ooool01Ol@413ooooooooooooooooo410@01_o
oooo00GoV9RHob4Q8Oo^k^koooooo`000002ooooo`05oa0@4?ooooooooooooooool@41007oooool0
1Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool06Oooool5o`0000?ooooo00Go
410@oooooooooooooooooa0@400>ooooo`004oooool01?m4A4CogMgMooooool00004ooooo`05o`00
0?ooooooooooooooool000006Oooool01_l0003oooooooooooooooooZJVYoa0@40?ooooo00Go0000
ooooooooooooooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooooooooooo
o`000007ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000001kooooo0_l0000Mooooo`?o00000_ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000007?ooool01onHV9So8B4Qonk^k_oooooo0000ooooool000000ooo
ool00ol0003oooooooooo`0Looooo`03ojVYZOl@413ooooo00;ooooo00Go0000oooooooooooooooo
o`00000Kooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`004oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000005oooool2
o`0000?ooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000001kooooo00?o
MgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003o
ooooooooo`0Jooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000007Oooool01_mgMgOoIVIVooooool0003oooooo`0000?ooooo00?o0000ooooooooool06ooo
ool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000006oooool01?oMgMgoEEEE
ooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool001Cooooo00?oMgMgolc<c?l0
00001?ooool01Ol@413ooooooooooooooooo410@01Gooooo0_l00006ooooo`03okZj^_lQ8B7ooooo
00;ooooo00Go410@oooooooooooooooooa0@400Oooooo`05o`000?ooooooooooooooool@41000ooo
ool00ol@413oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@01kooooo00?o0000ooooooooool06?ooool2o`0000Oooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01kooooo00Go0000oooooooo
oooo0000oa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@
413ooooooooooooooooo410@01cooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooo
oooo410@00kooooo000Dooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Dooooo`03o`000?oooooooooo00?ooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL06oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0:ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool05Oooool3o`0000Wooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00Go0000okZj^_oooooo
V9RHoa0@4002ooooo`06o`000?mgMgOoV9RHoooooonHV9SoMgMg6oooool01Ol@413oV9RHoooooonj
^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`03onk^k_m4A4Co000000Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`005Oooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h04_ooool2o`0000Kooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`03o`000?oooooooooo00kooooo00?oEEEEofIVI_l00000
1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01kooooo00?o0000ooooooooool04oooool2o`0000[o
oooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c003ooooo`05o`000?lb<S;o0000oc8b<_o^k^h06oooool01OnYZJWo410@o`00
0?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Mooooo`03ogMgMol0003ooooo00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`00<?ooool2o`0004Wooooo00?o0000oooooooo
ool0=oooool2o`00013ooooo1?l0000jooooo`03o`000?oooooooooo063ooooo000_ooooo`03o`00
0?oooooooooo04Wooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0:ooooo`Go0000
?oooool00ol0003oooooooooo`1Oooooo`00;Oooool2o`0004gooooo00?o0000ooooooooool0=_oo
ool=o`0004Cooooo00?o0000ooooooooool0Goooool002cooooo00?o0000ooooooooool0COooool0
0ol0003oooooooooo`0aooooo`Ko0000DOooool00ol0003oooooooooo`0^ooooo`Go0000:oooool0
02[ooooo0_l0001Aooooo`03o`000?oooooooooo02gooooo0ol00005ooooo`03o`000?oooooooooo
04oooooo00?o0000ooooooooool0;?ooool3o`0000Cooooo1?l0000Wooooo`005_ooooooo`00043o
00004oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`;o0000
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Co
oooo0_l00007ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool04Oooool001Kooooo00?o0000ooooooooool03?ooool2o`0001Kooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool09?ooool01Ol0003ooooooooooooooooo000002?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0?ooooo`;o00003_ooool00ol0003oooooooooo`0Aooooo`00
9?ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Oooooo`008_ooool2o`0005cooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0Cooooo`?o00007_ooool0023ooooo0_l0001Nooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool02oooool2o`0005;ooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0Gooooo`?o00006oooool001oooooo00?o0000ooooooooool0Goooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0D_ooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06?ooool001go
oooo0_l0001Rooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool07?ooool2o`0001So
oooo000Fooooo`Oo0000IOooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01kooooo
1Ol0000Cooooo`00P_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0Doooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03Oooooo0023
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool03oooool2o`0005Cooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`0gooooo`00Q?ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo03Sooooo0024ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool0>?ooool008Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo05Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0iooooo`00QOoo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0EOoo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo03Wooooo0026ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool04oooool2o`0005Kooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0iooooo`00Qoooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
03[ooooo0027ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`1Fooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0>_ooool008Sooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo05Kooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0jooooo`00ROooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0E_ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo03_ooooo002:ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool05oooool2o`0005Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0k
ooooo`00R_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool0Eoooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03cooooo002;ooooo`03
o`000?oooooooooo00Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`03o`000?oooooooooo
00;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo05Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0looooo`00S?ooool00ol0
003oooooooooo`03ooooo`07ogMgMonHV9SooooooiRHV?mgMgOoooooo`000003ooooo`;o8B4Q1?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`1Gooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0??ooool008cooooo00?o
0000ooooooooool00oooool01_l@413ooooooooooooooooo410@o`0000_ooooo00?oV9RHob4Q8Oo^
k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Sooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0mooooo`00SOooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooooooo`;o00003?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Co
oooo0ol0001Hooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0?Oooool008kooooo
0_l00002ooooo`03o`000?oooooooooo00;o00003_ooool00omgMgOoIVIVooooo`03ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool0?Oooool0093ooooo1Ol000000ooooooo410@ooooo`0>ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Iooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool0?_ooool009;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo05Wooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0nooooo`00
T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co00001_ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0?_ooool00;Gooooo0_l0001Jooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool0?oooool00;Gooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo03oooooo002eooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0oooooo`00]Oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0@?ooool00;Gooooo00?o0000ooooooooool0Foooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo043ooooo002eooooo`;o0000G?ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo043ooooo002eooooo`03o`000?oooooooooo05_ooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`11ooooo`00]Oooool00ol0003ooooooooo
o`1Kooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0@Oooool00;Gooooo00?o0000
ooooooooool0G?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo047ooooo002eoooo
o`;o0000GOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo047ooooo002eooooo`03
o`000?oooooooooo05cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`12ooooo`00
]Oooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
@_ooool00;Gooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo04;ooooo002eooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`13ooooo`00]Oooool2o`0005oooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`13ooooo`00]Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0@oooool00;Gooooo00?o0000ooooooooool0G_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo04Cooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo05oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`14ooooo`00V_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0Goooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Cooooo002Jooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`?o0000H?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo04Gooooo002Jooooo`05o`000?ooooooooooooooool0
00003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo063ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`15ooooo`00V_ooool01Ol0003ooooooooooooooooo000000co
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo067ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`16ooooo`00V_ooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0Aoooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0H_ooool4o`0004[ooooo002Jooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0002aooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aoooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0;3ooooo002Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009;ooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`00
0;3ooooo002Booooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Ol@
413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_oo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002[ooooo`Co000000?o410@ooooooooool00oooool00ol0003o
ooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;3ooooo
002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool00:gooooo00?o0000
ooooooooool01Oooool3o`000;3ooooo002]ooooo`03o`000?oooooooooo0;Sooooo002]ooooo`03
o`000?oooooooooo0;Sooooo002]ooooo`03o`000?oooooooooo0;Sooooo002[ooooo`03oeEEEOmV
IVKo00000;[ooooo003oooooofWooooo002_ooooo`03o`000?nj^[[ooooo0;Kooooo002_ooooo`;o
<S8b]oooool0083ooooo0_l000001_l@413oooooooooool@413o0000oa0@41Oooooo1Ol00003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o
0000odA4A?nj^[X06?ooool5o`0000?ooooo00Co410@o`000?m4A4Coc<c<1?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^07Sooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1oooool6o`0000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6
o`0000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03oiRHV?l@413ogMgM00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`1hooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo01Oooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01;ooooo
00?o0000ooooooooool06oooool00onHV9So8B4Qonk^kP07ooooo`03ohN7QomEEEGooooo00;ooooo
00Go410@oooooooooooooooooa0@401hooooo`00POooool01_l0003oooooodA4A?m4A4Coooooo`00
00Wooooo1_l0000;ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000B
ooooo`03o`000?oooooooooo00_ooooo1_l0000;ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Goc<c<
ob4Q8Ol0003oEEEEo`000003ooooo`05o`000?ooooooooooooooool00000N?ooool0087ooooo00Ko
0000omgMgOlb<S;oEEEEomgMgOl0000Kooooo`03ogMgMomVIVKooooo00;ooooo00Go0000oooooooo
ooooooooo`00000Booooo`03o`000?oooooooooo01gooooo00?oMgMgofIVI_ooool00_ooool01OlQ
8B7oQhN7oooooonHV9So000000?ooooo00Go0000ooooooooooooooooo`00001hooooo`00POooool0
1_l0003oQhN7ojVYZOnj^[[oEEEEo`0001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo00kooooo00?o410@o`000?l000000ol0000Mooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0M_ooool0
087ooooo00Ko0000oc8b<_oooooooooooc8b<_l0000Hooooo`05o`000?nj^[[ooooooiRHV?l@4100
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool06_ooool01Ol0003o
^[ZjoooooonHV9So410@00?ooooo00Go8B4QoiRHV?ooooooMgMgoeEEE@03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL0N?ooool0083ooooo00?o410@o`000?n7QhL00_ooool00on7QhOo0000oa0@400G
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo
00?o0000ooooooooool06_ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Goc<c<oa0@4?l0
003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0N?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(300) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .3364 m
.00236 .33611 L
.00488 .33567 L
.00726 .33513 L
.00942 .33454 L
.01473 .33269 L
.01975 .33047 L
.04057 .31797 L
.08481 .28447 L
.104 .27223 L
.11492 .26607 L
.12514 .26084 L
.13602 .25625 L
.14597 .25306 L
.15661 .25037 L
.16805 .24786 L
.17306 .24688 L
.17839 .24599 L
.18342 .24533 L
.18564 .2451 L
.18799 .2449 L
.18932 .24481 L
.19079 .24473 L
.19214 .24467 L
.19337 .24462 L
.19407 .2446 L
.19482 .24459 L
.19562 .24457 L
.19638 .24456 L
.19709 .24456 L
.19784 .24455 L
.19919 .24456 L
.20044 .24457 L
.20178 .24459 L
.20305 .24461 L
.20421 .24465 L
.20691 .24473 L
.20975 .24485 L
.215 .24513 L
.21977 .24545 L
.22528 .24594 L
.23048 .24657 L
.23529 .24736 L
.23973 .24828 L
.24976 .25111 L
.25994 .255 L
.26946 .25954 L
.27991 .26577 L
.29113 .2745 L
.30177 .28511 L
Mistroke
.31337 .29929 L
.33447 .3307 L
.34603 .34917 L
.3569 .36522 L
.36666 .37672 L
.36934 .37918 L
.37216 .38141 L
.3748 .38314 L
.37721 .38439 L
.37842 .38491 L
.37973 .38537 L
.38086 .3857 L
.38211 .38598 L
.38344 .38619 L
.38416 .38626 L
.38484 .3863 L
.38606 .38632 L
.38736 .38624 L
.38852 .3861 L
.38977 .38587 L
.39109 .38554 L
.39231 .38516 L
.3945 .3843 L
.39683 .38314 L
.40264 .37926 L
.40811 .37455 L
.41835 .36396 L
.43762 .34307 L
.44857 .33306 L
.45879 .32559 L
.46888 .32002 L
.4797 .31578 L
.49126 .31253 L
.50181 .30997 L
.52352 .30412 L
.54362 .29658 L
.56311 .28632 L
.58383 .27484 L
.60448 .26409 L
.62343 .25531 L
.63331 .25202 L
.64372 .24944 L
.6543 .24725 L
.66012 .24619 L
.66297 .24572 L
.66561 .24535 L
.66809 .24506 L
.67081 .24481 L
.67223 .24472 L
.67355 .24465 L
Mistroke
.67428 .24463 L
.67495 .24461 L
.67572 .2446 L
.67645 .24459 L
.67764 .2446 L
.6789 .24464 L
.68009 .24469 L
.68117 .24475 L
.68244 .24484 L
.68382 .24497 L
.68631 .24526 L
.6912 .24605 L
.69636 .24715 L
.70559 .24968 L
.71555 .25341 L
.72114 .25624 L
.72623 .2595 L
.73612 .26813 L
.74548 .27948 L
.75563 .29547 L
.7664 .31708 L
.78575 .36937 L
.79583 .40112 L
.80644 .43207 L
.81083 .44261 L
.8155 .45171 L
.81819 .45579 L
.82064 .45869 L
.82182 .4598 L
.82309 .4608 L
.8243 .46154 L
.82541 .46205 L
.82658 .4624 L
.82784 .46257 L
.82903 .46254 L
.83011 .46234 L
.83138 .4619 L
.83277 .46119 L
.83408 .46029 L
.83529 .45926 L
.83794 .4564 L
.84035 .45311 L
.84574 .44368 L
.86764 .39016 L
.87751 .3672 L
.88791 .34814 L
.89335 .34051 L
.89931 .33386 L
.90474 .32922 L
.90979 .32596 L
Mistroke
.91235 .32467 L
.91507 .32355 L
.91805 .3226 L
.91938 .32227 L
.9208 .32198 L
.92214 .32176 L
.92336 .32161 L
.92459 .3215 L
.92576 .32144 L
.92711 .32142 L
.92837 .32144 L
.92975 .32151 L
.93052 .32157 L
.93122 .32163 L
.93373 .32196 L
.93604 .32239 L
.94126 .32369 L
.95072 .32679 L
.96106 .33034 L
.97215 .33353 L
.97753 .33474 L
.98262 .33567 L
.98484 .33599 L
.98719 .33627 L
.98842 .33639 L
.98978 .3365 L
.99101 .33658 L
.99217 .33663 L
.99313 .33666 L
.99413 .33668 L
.99499 .33667 L
.99594 .33666 L
.99695 .33662 L
.99804 .33656 L
.99907 .33649 L
1 .3364 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo001<oooooaGo0000<Oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2
o`0002kooooo4Ol0001booooo`00A_ooool6o`0001Gooooo1?l0001@ooooo`03o`000?oooooooooo
02Wooooo1?l0000Aooooo`?o0000Koooool004?ooooo0ol0000Oooooo`?o0000COooool00ol0003o
ooooooooo`0Vooooo`?o00006?ooool2o`0006gooooo0010ooooo`?o00009Oooool3o`0004[ooooo
00?o0000ooooooooool08oooool3o`0001gooooo0_l0001[ooooo`00?oooool00ol0003ooooooooo
o`0Yooooo`;o0000B?ooool00ol0003oooooooooo`0Qooooo`;o00008_ooool00ol0003ooooooooo
o`1Xooooo`00??ooool3o`0002kooooo0_l00016ooooo`;o00008?ooool2o`0002Gooooo00?o0000
ooooooooool0Ioooool003Wooooo0ol0000cooooo`03o`000?oooooooooo04?ooooo00?o0000oooo
ooooool07Oooool2o`0002Sooooo00?o0000ooooooooool0I_ooool001Gooooo0_l000002Ol@413o
ooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0Hooooo`07o`000?ooooooV9RHoa0@4?l0003o
<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool5o`0000?ooooo00Ook^k^oc8b
<_l0003o<S8bonk^k_oooooo000001[ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb
<S;ok^k^7_ooool00ol0003oooooooooo`0Kooooo`;o00000_ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hJooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Oooool2
o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Fooooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Fooooo`;o00000_ooool01Ol@413o
^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003o
ooooooooo`0Iooooo`;o00001_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL06_ooool01OnHV9So8B4Qonk^k_l0003oA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Kooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg01ko
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko
00000_ooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Booooo`Ko00001_ooool01Ol0
003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool04Oooool6o`0000?ooooo00?oV9RH
ob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00?o0000ooooooooool03Ooo
ool6o`0000Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01kooooo
00?o0000ooooooooool05oooool2o`0000Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@01_ooooo00CoV9RHob4Q8Oo^k^ko00000oooool01Ol@413ooooooooooooooooo
410@01oooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01Wooooo1Ol0
0003ooooo`05oa0@4?ooooooooooooooool@41003_ooool001?ooooo00CoA4A4omgMgOoooooo0000
1?ooool01Ol0003ooooooooooooooooo000001?ooooo0_l00008ooooo`03ojVYZOl@413ooooo00;o
oooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000001kooooo0_l0000Fooooo`;o00002_ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000007?ooool01?nHV9So8B4Qonk^k_l00002ooooo`05
o`000?ooooooooooooooool000007_ooool00onYZJWo410@ooooo`02ooooo`05o`000?oooooooooo
ooooool000006oooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool00000
3_ooool001?ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000001;o
oooo00?o0000ooooooooool01oooool00ol@413o0000okZj^P03ooooo`05o`000?oooooooooooooo
ool000007_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
000Nooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000007Oooool01_mgMgOoIVIVooooool0003oooooo`00
00?ooooo00?o0000ooooooooool06oooool00ol@413o0000okZj^P03ooooo`05o`000?oooooooooo
ooooool000006oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool00000
3_ooool001Cooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@013ooooo
0_l0000;ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@400Oooooo`05
o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01kooooo00?o0000
ooooooooool04_ooool2o`0000gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@01kooooo00Go0000ooooool0003ooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo
00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@01cooooo00?oMgMgolc<c?l0
00001?ooool01Ol@413ooooooooooooooooo410@00kooooo000Dooooo`03onk^k_m4A4Co000000Co
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0?ooooo`03o`000?oooooooooo00Sooooo00Go410@oiRH
V?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool01Ol0003o^[Zjoooo
oonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000oooo
ooooool04?ooool2o`0000oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg01[ooooo00Go0000okZj^_ooooooV9RHoa0@4002ooooo`06o`000?mgMgOoV9RHoooooonHV9So
MgMg6oooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0L
ooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`005Oooool0
0omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool00ol0003ooooooooo
o`09ooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01oooool0
0ol0003oooooooooo`0Booooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0Nooooo`03o`000?oooooooooo00kooooo0_l0000?ooooo`03oeEEEOmVIVKo000000Cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Ol0003o
<S8bo`000?lb<S;ok^k^01_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h07Oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3_ooool002gooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0kooooo`;o00003Ooo
ool2o`0003oooooo00?o0000ooooooooool0H?ooool002_ooooo0_l0001;ooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool02_ooool2o`0004;ooooo00?o0000ooooooooool0Goooool0
02[ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo
00Oooooo0ol00014ooooo`03o`000?oooooooooo05oooooo000Yooooo`03o`000?oooooooooo04go
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`05ooooo`;o0000B?ooool00ol0003o
ooooooooo`1Nooooo`009oooool2o`00057ooooo00?o0000ooooooooool0>?ooool01?l0003ooooo
ooooooooool4o`0004[ooooo00?o0000ooooooooool0G_ooool001Koooooool00010o`0001?ooooo
000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04o`000003ooooool0003ooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`005_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool07Oooool3o`0000Gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo017ooooo000R
ooooo`;o0000FOooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0D_ooool00ol0003oooooooooo`1Kooooo`008?ooool2o`0005cooooo00?o0000oooo
ooooool0:Oooool2o`0000Wooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0]oooo
o`Oo00009oooool001oooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0Wooooo`;o
00002oooool2o`0005Cooooo00?o0000ooooooooool0:_ooool2o`0000Oooooo0ol0000Tooooo`00
7Oooool2o`00063ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo05?ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0:ooooo`?o0000
8Oooool001_ooooo0_l0001Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo02Oooooo0_l0000@ooooo`Co00007Ooo
ool001Sooooo0ol0001Uooooo`03o`000?oooooooooo027ooooo0_l0000?ooooo`03o`000?oooooo
oooo05Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Dooooo`Co00006Oooool0
01Kooooo0_l0001Yooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`1Dooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool06Oooool6o`00
01?ooooo0022ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool04?ooool2o`0005Go
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0cooooo`00P_ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0EOooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo03?ooooo0023ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool0=?ooool008Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0e
ooooo`00Q?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0E_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03Gooooo0025ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool05?ooool2o`0005Oooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0fooooo`00Q_ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo03Kooooo0026ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0=ooo
ool008Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo05Oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0gooooo`00Qoooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0F?ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo03Sooooo0028ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool06Oooool2o`0005Wooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0hooooo`00ROooool00ol0003oooooooooo`0;ooooo`;o00007?ooool00ol0003ooooo
ooooo`1Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0>Oooool008[ooooo0_l0
0006ooooo`05onk^k_lb<S;o0000oc8b<_l000001Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool0>Oooool008cooooo00?o0000ooooooooool00oooool01OmgMgOoV9RH
ooooool0003oMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0jooooo`00SOooool3o`0000;ooooo0ol000000ooooooo410@ooooo`0;ooooo`03
oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Iooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool0>_ooool008oooooo1?l00003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000
F_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo03[ooooo002Booooo`05o`000?oo
ooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0>oooool009;ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool0>oooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
05_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0looooo`00T_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool0
0ol0003oooooooooo`1Kooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0??ooool0
0;Gooooo0_l0001Looooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0??ooool00;Go
oooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03go
oooo002eooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0mooooo`00]Oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0?_ooool00;Gooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo03kooooo002eooooo`;o0000G_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo03oooooo002eooooo`03o`000?oooooooooo05gooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0oooooo`00]Oooool00ol0003oooooooooo`1Mooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0?oooool00;Gooooo00?o0000ooooooooool0G_oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo043ooooo002eooooo`;o0000Goooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo043ooooo002eooooo`03o`000?oooooooooo
05kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`11ooooo`00]Oooool00ol0003o
ooooooooo`1Oooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0@Oooool00;Gooooo
00?o0000ooooooooool0Goooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo047ooooo
002eooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`12ooooo`00]Oooool2o`00067ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`12
ooooo`00]Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0@oooool00;Gooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo04Cooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Go
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo06;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`15ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0Hoooool2o`00
00;ooooo0_l00017ooooo`00V_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooo
ooooool00oooool3o`0006Cooooo1?l00018ooooo`00V_ooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol0003o
oooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0;3ooooo002Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEE
ojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0/?ooool009;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`000;3ooooo002Boooo
o`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooo
oooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0;3ooooo002Booooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooo
oooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002[ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`2`oooo
o`00[Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;3ooooo002]ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool00:gooooo00?o0000ooooooooool01Ooo
ool3o`000;3ooooo002]ooooo`03o`000?oooooooooo0;Sooooo002]ooooo`03o`000?oooooooooo
0;Sooooo002]ooooo`03o`000?oooooooooo0;Sooooo002[ooooo`03oeEEEOmVIVKo00000;[ooooo
003oooooofWooooo002_ooooo`03o`000?nj^[[ooooo0;Kooooo002_ooooo`;o<S8b]oooool0083o
oooo0_l000001_l@413oooooooooool@413o0000oa0@41Oooooo1Ol00003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X0
6?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h0N?ooool0087ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`07ooooo`Ko00002Oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`03ooooo`03olc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMg
oa0@4009ooooo`Ko00002Oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0N?ooool0087ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooo
oooooooooooooa0@400Booooo`03o`000?oooooooooo01kooooo00Go0000oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`1fooooo`00POoo
ool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000;ooooo`03oiRHV?lQ8B7ok^k^00?o
oooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo00_ooooo1_l0000<oooo
o`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool00000N?ooool0087ooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Kooooo`03ogMg
MomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo01co
oooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`00001hooooo`00POooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001cooooo00Go
0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00kooooo00?o410@o`000?l00000
0ol0000Looooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@4100N?ooool0087ooooo00Ko0000oc8b<_oooooooooooc8b<_l0000H
ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo
00?o0000ooooooooool06_ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0N?ooool0083ooooo00?o410@o`00
0?n7QhL00_ooool00on7QhOo0000oa0@400Gooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo00?o0000ooooooooool06_ooool01OnYZJWo410@o`00
0?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h0N?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(310) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .33974 m
.04057 .31138 L
.06168 .29205 L
.08481 .27415 L
.10632 .26161 L
.11593 .25688 L
.12636 .25293 L
.13209 .25133 L
.13738 .25011 L
.1478 .24806 L
.15719 .24635 L
.16238 .24551 L
.1673 .24487 L
.16984 .24461 L
.17118 .2445 L
.1726 .2444 L
.17392 .24433 L
.17512 .24428 L
.17632 .24424 L
.17745 .24421 L
.17861 .2442 L
.17983 .24419 L
.18088 .2442 L
.18202 .24422 L
.18326 .24424 L
.18458 .24428 L
.18696 .24438 L
.19278 .2447 L
.19829 .24504 L
.2032 .24536 L
.20862 .24574 L
.21385 .24622 L
.21876 .24685 L
.22394 .24776 L
.22953 .24909 L
.23962 .25229 L
.24887 .25591 L
.25847 .26021 L
.26874 .2658 L
.28 .27383 L
.29047 .28334 L
.33404 .33708 L
.34465 .35112 L
.35589 .3636 L
.36051 .36765 L
.36548 .37118 L
.36832 .37281 L
.37093 .37404 L
.37354 .37503 L
.37603 .37573 L
Mistroke
.37734 .37602 L
.37857 .37623 L
.37968 .37637 L
.38088 .37647 L
.38219 .37653 L
.38358 .37653 L
.38476 .37647 L
.38605 .37636 L
.38727 .3762 L
.38838 .37602 L
.39086 .37546 L
.39317 .37478 L
.39535 .37399 L
.40545 .36883 L
.41642 .36142 L
.45929 .33513 L
.50058 .31604 L
.54027 .291 L
.56233 .276 L
.58254 .26421 L
.60236 .2547 L
.61233 .25105 L
.62321 .24811 L
.63403 .24604 L
.64384 .24462 L
.64929 .24403 L
.65235 .24378 L
.65381 .24369 L
.65517 .24362 L
.65637 .24357 L
.65765 .24353 L
.65838 .24351 L
.65907 .2435 L
.66037 .2435 L
.66173 .24351 L
.663 .24354 L
.66438 .2436 L
.66586 .24367 L
.66835 .24385 L
.67098 .24411 L
.67568 .24472 L
.68628 .24666 L
.69543 .24885 L
.70546 .25205 L
.711 .25438 L
.71623 .25707 L
.72603 .26354 L
.73657 .27258 L
.74802 .28496 L
.75794 .29853 L
Mistroke
.76886 .31752 L
.79095 .36848 L
.80228 .39716 L
.81305 .42176 L
.81773 .43067 L
.82272 .43843 L
.82559 .44196 L
.82819 .44449 L
.82945 .44547 L
.83081 .44636 L
.83209 .44702 L
.83327 .44748 L
.8345 .44781 L
.83563 .44797 L
.83693 .44799 L
.83816 .44784 L
.83929 .44757 L
.84034 .4472 L
.84149 .44667 L
.84272 .44597 L
.84526 .44404 L
.84765 .44171 L
.85308 .43473 L
.874 .39689 L
.89342 .36459 L
.89874 .35768 L
.90442 .35139 L
.90933 .34695 L
.91464 .34321 L
.9176 .34162 L
.92032 .34045 L
.92293 .33958 L
.92425 .33923 L
.92568 .33892 L
.92697 .33868 L
.92815 .33851 L
.92933 .33838 L
.93045 .33829 L
.93176 .33821 L
.93297 .33818 L
.93429 .33817 L
.93503 .33818 L
.9357 .3382 L
.93637 .33822 L
.9371 .33825 L
.93856 .33834 L
.94119 .33855 L
.94712 .3392 L
.95786 .34058 L
.96832 .34194 L
Mistroke
.97347 .34252 L
.97573 .34273 L
.97822 .34291 L
.97959 .34298 L
.98087 .34302 L
.98223 .34304 L
.98299 .34304 L
.98369 .34303 L
.98444 .34301 L
.98514 .34298 L
.98591 .34294 L
.98673 .34288 L
.98825 .34273 L
.98962 .34256 L
.99219 .34211 L
.99496 .34145 L
1 .33974 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool004oooooo
00?o0000ooooooooool0@?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oo
ooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0;?ooool9o`00
07_ooooo0017ooooo`So000000?oooooo`000?l000002ol0000eooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o00009oooool6
o`0000Wooooo1_l0001eooooo`00@Oooool6o`0001Kooooo1Ol0001Cooooo`03o`000?oooooooooo
02?ooooo0ol0000Eooooo`?o0000L_ooool003gooooo1?l0000Qooooo`?o0000D?ooool00ol0003o
ooooooooo`0Oooooo`Co00006oooool2o`00073ooooo000looooo`03o`000?oooooooooo02Kooooo
0_l0001>ooooo`03o`000?oooooooooo01cooooo0ol0000Qooooo`;o0000K_ooool003[ooooo0_l0
000[ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool06_ooool2o`0002Kooooo0_l0
001/ooooo`00=oooool3o`0002kooooo0ol0001:ooooo`;o00006Oooool2o`0002[ooooo00?o0000
ooooooooool0JOooool003Gooooo0_l0000dooooo`;o0000B?ooool00ol0003oooooooooo`0Foooo
o`;o0000;Oooool00ol0003oooooooooo`1Xooooo`005Oooool2o`000009oa0@4?oooooooooooooo
ooo^k^ko<S8bo`000?lb<S;ok^k^01Cooooo00?o0000ooooooooool00oooool01OnHV9So410@o`00
0?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko
<S8bo`000?l0003ok^k^01cooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
7_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Oooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^6_ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0Kooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01go
oooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0>ooooo`005_ooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool2o`0000Kooooo00Go
410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool01OnHV9So
8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHo`00000Nooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo01?ooooo0_l0
000<ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05oiRH
V?lQ8B7o0000oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj
^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool000_ooooo1_l00002ooooo`Go00000ooo
ool01Ol@413ooooooooooooooooo410@013ooooo2?l00006ooooo`05o`000?ooooooooooooooool@
41000oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04ooooo`06
oa0@4?ooooooooooooooool@413o00004_ooool6o`0000Gooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@01kooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Kooooo`04oiRH
V?lQ8B7o0000o`0000?ooooo00Go410@oooooooooooooooooa0@400Oooooo`05o`000?oooooooooo
ooooool@41000oooool00ol@413oooooooooo`0Iooooo`Go00000oooool01Ol@413ooooooooooooo
oooo410@00kooooo000Cooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000oooooooooooooooo
o`00000?ooooo`03o`000?oooooooooo00_ooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooo
oooooooooooo000001gooooo00?oV9RHob4Q8Oo^k^h00oooool01ol0003ooooooooooooooooo0000
ooooool000007?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007_oo
ool2o`00017ooooo0_l0000?ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Looooo`04oiRHV?lQ8B7ok^k^o`0000;ooooo00Go0000ooooooooooooooooo`00000Noooo
o`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Kooooo`04odA4A?oMgMgo
ooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`004oooool01?oMgMgoEEEEoooo
ool00004ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`0;ooooo`03
oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000001kooooo00?o0000ooooooooool03_oo
ool2o`00017ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001gooooo
00KoMgMgofIVI_oooooo0000ooooool00003ooooo`03o`000?oooooooooo01_ooooo00?o410@o`00
0?nj^[X00oooool01Ol0003ooooooooooooooooo000001_ooooo00CogMgMoeEEEOoooooo00001?oo
ool01Ol0003ooooooooooooooooo000000kooooo000Dooooo`03ogMgMoo<c<co000000Cooooo00Go
410@oooooooooooooooooa0@400<ooooo`;o00003oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@
4?ooooooooooooooool@41007oooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooo
ooooooooooooo`00000Jooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
400Nooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41007_ooool01Ol0003oooooooooool0003o410@00?o
oooo00?o410@ooooooooool07?ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41007?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41003_ooool0
01Cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000
ooooooooool03?ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0Kooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL07_ooool00ol0003oooooooooo`0;ooooo`;o00005?ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01Ol0003o^[ZjoooooonHV9So410@00;ooooo
00Ko0000ogMgMonHV9SooooooiRHV?mgMgLKooooo`05oa0@4?nHV9SooooookZj^_l000000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00kooooo000Eooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0:ooooo`03o`000?oooooooooo00gooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h06oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP04ooooo`03o`000?oooooooooo01Gooooo00?oEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^01kooooo00?o0000ooooooooool02Oooool2o`0001Cooooo
00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c003ooooo`05o`000?lb<S;o0000oc8b<_o^k^h06oooool01OnYZJWo410@o`000?l@
413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Mooooo`03ogMgMol0003ooooo00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`00:Oooool00ol0003oooooooooo`18ooooo`03o`00
0?oooooooooo03kooooo0_l00009ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0
Goooool002Sooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0mooooo`03o`000?oo
oooooooo00Kooooo0_l00016ooooo`03o`000?oooooooooo05oooooo000Wooooo`03o`000?oooooo
oooo04cooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`04ooooo`;o0000BOooool0
0ol0003oooooooooo`1Nooooo`009_ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo
05kooooo000Uooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0>oooool01?l0003o
ooooooooooooool2o`0004gooooo00?o0000ooooooooool0GOooool001Koooooool00010o`0001?o
oooo000Fooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooooooo0_l00002ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool0
01Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
02Cooooo0_l0000Wooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04Oooool001oo
oooo0_l0001Jooooo`03o`000?oooooooooo03Cooooo0_l000000ooooooo0000ooooo`1Cooooo`03
o`000?oooooooooo05_ooooo000Nooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool0
<_ooool2o`0000?ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`1Kooooo`007?oo
ool2o`0005kooooo00?o0000ooooooooool0;_ooool3o`0000Gooooo0_l0001Dooooo`03o`000?oo
oooooooo05[ooooo000Kooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0:oooool2
o`0000Sooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`1Jooooo`006_ooool00ol0
003oooooooooo`1Qooooo`03o`000?oooooooooo02Sooooo0_l0000:ooooo`03o`000?oooooooooo
05Cooooo00?o0000ooooooooool0FOooool001Sooooo0_l0001Uooooo`03o`000?oooooooooo02Go
oooo0_l0000<ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0FOooool001Oooooo
00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0EOooool00ol0003oooooooooo`0^ooooo`Co00009_ooool001Kooooo00?o
0000ooooooooool0Ioooool00ol0003oooooooooo`0Qooooo`;o00003oooool2o`0005Kooooo00?o
0000ooooooooool0:oooool3o`0000?ooooo2Ol00008ooooo`?o00004oooool0087ooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05Kooooo00?o0000
ooooooooool09oooool3o`0000oooooo2Ol0000Eooooo`00P_ooool00ol0003oooooooooo`0Loooo
o`;o00004_ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool0;_ooool008;ooooo00?o0000ooooooooool06_ooool2o`0001Cooooo00?o0000oooooooo
ool0Eoooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02kooooo0023ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Gooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool0;oooool008Cooooo00?o0000ooooooooool05Ooo
ool2o`0001Oooooo0_l0001Iooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0<?oo
ool008Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo05Sooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0aooooo`00Q_ooool00ol0
003oooooooooo`0@ooooo`;o00006_ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool0<_ooool008Oooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0cooooo`00R?ooool2o`0000cooooo0_l0000Mooooo`03o`000?oooooooooo05[ooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0cooooo`00R_ooool2o`0000Wooooo00?o
0000ooooooooool07Oooool2o`0005_ooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0dooooo`00S?ooool3o`0000;ooooo1?l0000Pooooo`03o`000?oooooooooo05_ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0eooooo`00S_ooool4o`000005onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0=Ooo
ool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^
k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1Kooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0=_ooool009;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1Looooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0=_ooool009;ooooo00Go
0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0
1?ooool3o`0005cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0gooooo`00T_oo
ool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo03Sooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0GOooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo03Sooooo002Booooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`1Mooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0>Oooool009;o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4
o`0000Kooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo03Wooooo002eooooo`;o0000Goooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
03[ooooo002eooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0jooooo`00]Oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0>oooool00;Gooooo00?o0000ooooooooool0Goooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo03cooooo002eooooo`03o`000?oooooooooo063ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0looooo`00]Oooool2o`00067ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0mooooo`00]Oooool00ol0003oooooooooo`1Qooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool0?Oooool00;Gooooo00?o0000ooooooooool0
HOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03kooooo002eooooo`03o`000?oo
oooooooo06;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0oooooo`00]Oooool2
o`0006?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0oooooo`00]Oooool00ol0
003oooooooooo`1Sooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0@?ooool00;Go
oooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo043o
oooo002eooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`11ooooo`00]Oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0@_ooool00;Gooooo0_l0001Wooooo`Go0000AOooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol0003oooooooooo`03ooooo`?o0000/?ooool009[ooooo00Go0000oooooooo
ooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009[o
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46
ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`
ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooo
ooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`
ooooo`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00Go410@
oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`2`ooooo`00T_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
/?ooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo
00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00Zoooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooo
ooooool0/?ooool00:gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2`ooooo`00
[Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;3ooooo002]ooooo`03o`000?oo
oooooooo00Gooooo0ol0002`ooooo`00[Oooool00ol0003oooooooooo`2hooooo`00[Oooool00ol0
003oooooooooo`2hooooo`00[Oooool00ol0003oooooooooo`2hooooo`00Zoooool00omEEEGoIVIV
o`00002jooooo`00oooooomYooooo`00[oooool00ol0003o^[Zjooooo`2fooooo`00[oooool2oc8b
<[Oooooo0020ooooo`;o000000Ko410@oooooooooooo410@o`000?l@410Gooooo`Go00000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`00
0?m4A4Co^[Zj01Sooooo00GoV9RHoa0@4?l0003o<S8bolc<c004ooooo`Co000000So410@oooooooo
ooook^k^oc8b<_l0003o<S8bonk^kWSooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01oooool6o`0000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@
41002Oooool6o`0000Wooooo00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1hooooo`00POooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01Oooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo
410@01;ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@401hooooo`00POooool01_l0003oooooodA4A?m4
A4Coooooo`0000Wooooo1_l0000;ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooooooo
ooooo`00000Booooo`03o`000?oooooooooo00_ooooo1_l0000<ooooo`03ojVYZOl@413ooooo00Go
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000007Sooooo0021ooooo`06
o`000?oMgMgo<S8boeEEEOoMgMgo00006oooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooo
ooooooooool000004_ooool00ol0003oooooooooo`0Looooo`03oa0@4?l0003o^[Zj00Kooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000007Sooooo0021ooooo`06o`000?n7
QhOoZJVYokZj^_mEEEGo00007?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@oooo
ooooool03_ooool00ol@413o0000o`000003o`0001cooooo00?o^[Zjob4Q8Oooool01Oooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100N?ooool0087ooooo00Ko0000oc8b
<_oooooooooooc8b<_l0000Hooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RH
oooooonHV9SoMgMg01;ooooo00?o0000ooooooooool06_ooool01Ol@413oV9RHoooooonj^[[o0000
00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg07Sooooo0020oooo
o`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41005oooool01OnHV9So410@o`000?lQ8B7o
c<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Booooo`03o`000?oooooooooo01[ooooo00Go
ZJVYoa0@4?l0003o410@ojVYZ@04ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP1hooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(320) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .34121 m
.04057 .30072 L
.06168 .28023 L
.07365 .27167 L
.08481 .26484 L
.09513 .25898 L
.10488 .25433 L
.11028 .25236 L
.11613 .25073 L
.12145 .24963 L
.12636 .24881 L
.13664 .2472 L
.14769 .24532 L
.15025 .24492 L
.15304 .24454 L
.1555 .24426 L
.15686 .24414 L
.15813 .24404 L
.15938 .24396 L
.16073 .2439 L
.16195 .24386 L
.16308 .24384 L
.16415 .24384 L
.16532 .24385 L
.16654 .24388 L
.16768 .24392 L
.16896 .24398 L
.17014 .24406 L
.17283 .24426 L
.17771 .24472 L
.18685 .24564 L
.19745 .24652 L
.20264 .24702 L
.2074 .24766 L
.212 .24852 L
.21684 .24973 L
.227 .25319 L
.24863 .26249 L
.25866 .26778 L
.26936 .27508 L
.28865 .29221 L
.30956 .31336 L
.33222 .33796 L
.34283 .34797 L
.35406 .35618 L
.36365 .36124 L
.3691 .36338 L
.3742 .36491 L
.37691 .36552 L
.37943 .36597 L
Mistroke
.38085 .36617 L
.38219 .36632 L
.38293 .36639 L
.38373 .36645 L
.38446 .3665 L
.38513 .36654 L
.38638 .36658 L
.38776 .36659 L
.3891 .36657 L
.38985 .36655 L
.39054 .36652 L
.39176 .36644 L
.39309 .36633 L
.3955 .36607 L
.40041 .36532 L
.40562 .36429 L
.41497 .36215 L
.42483 .35972 L
.43545 .35666 L
.44548 .35282 L
.45466 .34837 L
.47457 .33628 L
.49632 .31894 L
.51868 .29819 L
.53896 .28094 L
.56034 .26553 L
.58002 .25539 L
.58983 .25168 L
.6002 .24848 L
.61061 .24608 L
.61653 .24511 L
.6194 .24474 L
.62205 .24445 L
.62454 .24423 L
.6273 .24404 L
.63007 .2439 L
.63158 .24384 L
.63301 .24379 L
.63428 .24377 L
.63561 .24375 L
.63676 .24374 L
.63801 .24373 L
.63935 .24374 L
.64011 .24375 L
.6408 .24376 L
.64213 .24379 L
.6434 .24383 L
.64575 .24392 L
.64825 .24406 L
.65274 .2444 L
Mistroke
.65756 .24492 L
.66287 .24567 L
.67353 .24769 L
.68327 .25007 L
.69451 .25348 L
.7052 .25769 L
.71527 .26273 L
.72601 .26928 L
.74532 .2846 L
.75613 .29622 L
.76782 .31203 L
.789 .34892 L
.80954 .39131 L
.82042 .41208 L
.82641 .42132 L
.82935 .42507 L
.83208 .428 L
.83463 .43027 L
.83745 .43219 L
.83892 .43294 L
.84029 .4335 L
.84174 .43393 L
.84256 .43411 L
.8433 .43422 L
.84454 .43432 L
.84568 .43431 L
.84694 .43419 L
.84829 .43394 L
.84897 .43376 L
.8497 .43354 L
.85104 .43304 L
.85353 .43179 L
.85595 .43023 L
.8586 .42814 L
.86395 .42288 L
.87356 .41085 L
.88492 .39466 L
.89571 .38019 L
.90539 .36995 L
.91086 .36566 L
.91594 .36264 L
.91851 .36143 L
.92128 .36033 L
.92373 .35953 L
.92631 .35883 L
.92864 .3583 L
.9312 .35783 L
.93351 .35749 L
.9357 .35723 L
.93845 .35698 L
Mistroke
.94095 .35682 L
.94236 .35675 L
.94365 .3567 L
.94507 .35666 L
.94579 .35664 L
.94658 .35663 L
.9479 .35662 L
.9491 .35661 L
.94977 .35661 L
.95049 .35662 L
.95182 .35663 L
.95305 .35664 L
.95436 .35666 L
.95672 .35669 L
.95801 .35671 L
.95875 .35671 L
.95943 .35672 L
.96081 .35672 L
.96159 .35671 L
.96229 .3567 L
.96356 .35667 L
.96493 .35663 L
.96622 .35656 L
.96742 .35648 L
.9688 .35635 L
.97009 .35621 L
.97163 .35599 L
.97304 .35575 L
.97591 .35511 L
.979 .35418 L
.98389 .35217 L
.98923 .34922 L
1 .34121 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool004Sooooo
1Ol00015ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Uooooo`Wo0000P_ooool0043o
oooo2?l00005ooooo`_o0000>_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`00023ooooo1ol00008ooooo`Ko0000O?ooool0
03cooooo1?l0000Hooooo`Ko0000Eoooool00ol0003oooooooooo`0Kooooo`Co00005Oooool6o`00
07Kooooo000hooooo`Co00008_ooool2o`0005Gooooo00?o0000ooooooooool06?ooool3o`0001oo
oooo0ol0001cooooo`00=_ooool2o`0002Sooooo0ol0001Booooo`03o`000?oooooooooo01Gooooo
0ol0000Uooooo`03o`000?oooooooooo073ooooo000cooooo`?o0000;Oooool2o`00053ooooo00?o
0000ooooooooool04oooool2o`0002Wooooo0ol0001_ooooo`00<_ooool00ol0003oooooooooo`0`
ooooo`;o0000C_ooool2o`0001;ooooo0_l0000^ooooo`;o0000KOooool0033ooooo0_l0000eoooo
o`03o`000?oooooooooo04_ooooo00?o0000ooooooooool03oooool2o`0003;ooooo0_l0001[oooo
o`005Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00kooooo0_l0
000:ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo1Ol000002?oooooo0000o`000?o^k^ko<S8bo`000?lb<S;ok^k^7?ooool4o`000008oa0@4?oo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^hNooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hJooooo`Go0000
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h07Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^00kooooo000Fooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0<ooooo`;o00003?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Kooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01Ol0003oV9RHoooo
oonHV9SoMgMg01kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01ko
oooo00?o0000ooooooooool03?ooool2o`0001?ooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg01[ooooo00GoV9RHob4Q8Ol0003oooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL06oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>oooo
o`002oooool6o`0000;ooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41002oooool00ol0
003oooooooooo`04ooooo`Ko00001_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@
ooooooooool04Oooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o0000o`000?oo
oooo410@01?ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400Nooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41006oooool00onHV9So8B4Qo`000004ooooo`05
oa0@4?ooooooooooooooool@41007oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@
ooooooooool06Oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`004oooool0
1?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003ooooo
ooooo`0@ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03
oiRHV?lQ8B7ok^k^00?ooooo00?o0000ooooooooool00_l0000Nooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`00000Nooooo`;o00002oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Looooo`03oiRHV?lQ8B7o
000000?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`00000Kooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000oooooooo
ooooooooo`00000>ooooo`004oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?oooooooooo
ooooool000002Oooool00ol0003oooooooooo`0@ooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000
ooooooooooooooooo`00000Nooooo`03ogMgMomVIVKooooo00;ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Nooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000007Oooool00omgMgOoIVIVo`000002ooooo`05o`000?oooooooooo
ooooool000007Oooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000006ooo
ool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool001Cooooo
00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000oooooooo
ool04_ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41007oooool01Ol0
003ooooooooooooooooo410@00?ooooo00?o410@o`000?ooool07?ooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41007_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01kooooo
00Go0000ooooool0003ooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@01cooooo00?oMgMgolc<c?l000001?ooool01Ol@
413ooooooooooooooooo410@00kooooo000Dooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`07ooooo`03o`000?oooooooooo013ooooo00Go410@oiRHV?oooooo^[Zjo`00
0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool01Ol0003o^[ZjoooooonHV9So410@00?o
oooo00OoMgMgoiRHV?ooooooV9RHogMgMooooooo000001cooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`0=o`00
0?nj^[[ooooooiRHV?l@413oooooo`000?ooooooMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`05oa0@
4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01cooooo00?ok^k^odA4
A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000Eooooo`03ogMgMol0003ooooo
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo017ooooo00GoZJVY
oa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool01OnHV9So410@
o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`03o`000?oooooooooo
01Oooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Fooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00_ooool01_l0003ok^k^
oc8b<_l0003o<S8bonk^kQ_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h07Oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3_ooool002Gooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`10ooooo`;o00001_oo
ool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo063ooooo000Tooooo`03o`000?oooooo
oooo04_ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo04Oooooo00?o0000ooooooooool0Goooool002?ooooo00?o0000ooooooooool0COooool00ol0
003oooooooooo`0oooooo`03o`000?oooooooooo00;ooooo0_l0001:ooooo`03o`000?oooooooooo
05oooooo000Rooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0?_ooool01Ol0003o
oooooooooooooooo000004gooooo00?o0000ooooooooool0G_ooool0027ooooo00?o0000oooooooo
ool0DOooool00ol0003oooooooooo`0mooooo`04o`000?ooooooooooo`0004oooooo00?o0000oooo
ooooool0GOooool001Koooooool00010o`0001?ooooo000Fooooo`03o`000?oooooooooo00Gooooo
0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo
000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0Aooooo`007Oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo03Oooooo0ol0001E
ooooo`03o`000?oooooooooo05[ooooo000Looooo`03o`000?oooooooooo05_ooooo00?o0000oooo
ooooool0=Oooool01?l0003oooooooooool0001Eooooo`03o`000?oooooooooo05[ooooo000Koooo
o`03o`000?oooooooooo05gooooo00?o0000ooooooooool0<oooool01?l0003oooooooooooooool2
o`0005Gooooo00?o0000ooooooooool0FOooool001[ooooo00?o0000ooooooooool0Goooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0EOooool00ol0
003oooooooooo`1Hooooo`006Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo05So
oooo000Hooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0Eoooool001Oooooo00?o
0000ooooooooool0IOooool00ol0003oooooooooo`0Zooooo`;o00001oooool00ol0003ooooooooo
o`1Fooooo`03o`000?oooooooooo05Oooooo000Fooooo`03o`000?oooooooooo06Oooooo00?o0000
ooooooooool09oooool2o`0000Wooooo0_l0001Hooooo`03o`000?oooooooooo04;ooooo00?o0000
ooooooooool04Oooool0087ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Boooo
o`00P_ooool00ol0003oooooooooo`0Rooooo`;o00003?ooool00ol0003oooooooooo`1Hooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool04oooool008?ooooo0_l0000Pooooo`;o0000
3_ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo03cooooo0_l0000Fooooo`00QOoo
ool00ol0003oooooooooo`0Jooooo`?o00004?ooool00ol0003oooooooooo`1Iooooo`03o`000?oo
oooooooo03[ooooo0_l0000Hooooo`00Q_ooool2o`0001Oooooo0ol0000Cooooo`;o0000Foooool0
0ol0003oooooooooo`0[ooooo`ko00006_ooool008Sooooo00?o0000ooooooooool04Oooool3o`00
01Kooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0Vooooo`Go0000:?ooool008Wo
oooo1?l0000<ooooo`?o00006Oooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo02?o
oooo0_l0000]ooooo`00SOooool<o`0001cooooo00?o0000ooooooooool0Foooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo02gooooo002eooooo`03o`000?oooooooooo05cooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`0^ooooo`00]Oooool2o`0005gooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0_ooooo`00]Oooool00ol0003oooooooooo`1Loooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool0<?ooool009;ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0a
ooooo`00T_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo05gooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0booooo`00T_ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo05kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0cooooo`00T_ooool0
1Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8boooo
o`04ooooo`?o0000G_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo03Cooooo002B
ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool0=Oooool009;ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Oooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool0=_ooool009;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo063ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0fooooo`00
T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co00001_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0=oooool00;Gooooo0_l0001Rooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool0=oooool00;Gooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo03Sooooo002eooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0hooooo`00]Oooool00ol0003oooooooooo`1Sooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool0>Oooool00;Gooooo00?o0000ooooooooool0Hoooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo03[ooooo002eooooo`;o0000IOooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo03_ooooo002eooooo`03o`000?oooooooooo06Gooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0looooo`00]Oooool00ol0003ooooooooo
o`1Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0?Oooool00;Gooooo00?o0000
ooooooooool0Ioooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03kooooo002eoooo
o`;o0000J?ooool2o`0000Cooooo0_l00011ooooo`00]Oooool00ol0003oooooooooo`1Yooooo`Go
0000@_ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooo
oooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0002`ooooo`00V_ooool01Ol0003ooooo
oooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00
V_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005oooo
o`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0002aooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aoooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0;3ooooo002Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009;ooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`00
0;3ooooo002Booooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Ol@
413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_oo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002[ooooo`Co000000?o410@ooooooooool00oooool00ol0003o
ooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;3ooooo
002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool00:gooooo00?o0000
ooooooooool01Oooool3o`000;3ooooo002]ooooo`03o`000?oooooooooo0;Sooooo002]ooooo`03
o`000?oooooooooo0;Sooooo002]ooooo`03o`000?oooooooooo0;Sooooo002[ooooo`03oeEEEOmV
IVKo00000;[ooooo003oooooofWooooo002_ooooo`03o`000?nj^[[ooooo0;Kooooo002_ooooo`;o
<S8b]oooool0083ooooo0_l000001_l@413oooooooooool@413o0000oa0@41Oooooo1Ol00003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o
0000odA4A?nj^[X06?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo1Ol00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0N?ooool0087ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`Ko00002Oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`03olc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009
ooooo`Ko00002Oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0N?ooool0087ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooo
oooooa0@400Booooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool00_ooool00onHV9So
8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@4100N?ooool0087ooooo00Ko0000oooooom4
A4CoA4A4ooooool00009ooooo`Ko00002oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooo
ooooooooool000004_ooool00ol0003oooooooooo`0;ooooo`Ko00003?ooool00onYZJWo410@oooo
o`04ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00001hooooo`00POoo
ool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001_ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003o
oooooooooooooooo000001;ooooo00?o0000ooooooooool07?ooool00ol@413o0000okZj^P06oooo
o`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00001hooooo`00POooool01_l0
003oQhN7ojVYZOnj^[[oEEEEo`0001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@
4?oooooooooo00kooooo00?o410@o`000?l000000ol0000Looooo`03okZj^_lQ8B7ooooo00Kooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo07Kooooo0021ooooo`06o`00
0?lb<S;ooooooooooolb<S;o00006?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0Booooo`03o`000?oooooooooo01[ooooo00Go410@oiRHV?oooooo^[Zj
o`000003ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
07Sooooo0020ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41005oooool01OnHV9So
410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Booooo`03o`000?oooooo
oooo01[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07Sooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(330) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .3403 m
.01975 .31435 L
.04057 .28881 L
.0515 .27846 L
.06168 .27075 L
.07357 .26305 L
.08481 .25673 L
.0898 .2544 L
.09509 .25237 L
.10089 .25066 L
.10625 .24949 L
.12575 .24638 L
.13563 .24482 L
.13848 .24447 L
.14118 .2442 L
.14236 .24411 L
.14361 .24403 L
.14499 .24397 L
.14626 .24393 L
.14756 .24391 L
.14876 .24391 L
.15007 .24394 L
.15145 .24399 L
.15266 .24405 L
.15378 .24412 L
.15634 .24432 L
.16548 .24536 L
.17497 .24641 L
.18505 .24732 L
.1903 .24793 L
.19329 .2484 L
.1961 .24895 L
.20103 .25017 L
.20633 .25188 L
.22863 .26122 L
.23872 .26573 L
.24976 .2717 L
.2708 .28743 L
.29296 .30491 L
.31527 .32301 L
.33555 .33677 L
.35664 .34697 L
.37654 .35595 L
.39756 .36317 L
.4069 .36605 L
.41205 .36748 L
.41693 .36858 L
.41948 .36901 L
.42092 .36919 L
.42225 .36932 L
Mistroke
.42349 .3694 L
.42461 .36944 L
.4259 .36945 L
.42711 .36941 L
.42827 .36934 L
.4295 .36923 L
.43054 .36909 L
.43169 .36891 L
.43425 .36836 L
.43664 .36767 L
.44211 .36546 L
.4471 .36275 L
.45831 .35459 L
.47839 .33413 L
.5002 .30708 L
.52059 .28486 L
.53142 .27506 L
.54308 .26591 L
.5542 .25894 L
.56438 .2542 L
.57412 .25083 L
.58436 .24804 L
.58953 .24688 L
.59441 .24597 L
.59711 .24555 L
.60003 .24519 L
.60269 .24493 L
.60386 .24484 L
.60513 .24476 L
.60634 .2447 L
.60744 .24465 L
.60855 .24462 L
.6096 .2446 L
.61082 .24459 L
.61195 .24459 L
.61319 .2446 L
.61451 .24463 L
.61568 .24466 L
.61694 .24471 L
.61922 .24482 L
.62443 .24515 L
.63446 .24599 L
.64545 .2472 L
.65099 .24803 L
.65691 .24914 L
.66759 .25169 L
.68847 .25769 L
.69948 .26131 L
.71113 .266 L
.73295 .27767 L
Mistroke
.75308 .29297 L
.76297 .30305 L
.77361 .31617 L
.79283 .34567 L
.81354 .38194 L
.82448 .39897 L
.83048 .40656 L
.83613 .41221 L
.83879 .41431 L
.84159 .41612 L
.84305 .4169 L
.84466 .41762 L
.84614 .41816 L
.84748 .41855 L
.8488 .41883 L
.85005 .41902 L
.85137 .41912 L
.85212 .41914 L
.8528 .41913 L
.85395 .41907 L
.85521 .41892 L
.85653 .41868 L
.85777 .41838 L
.86023 .41757 L
.86281 .41645 L
.86743 .41382 L
.87785 .4059 L
.88864 .39694 L
.89394 .393 L
.89883 .38986 L
.90318 .38752 L
.90797 .38545 L
.91279 .38386 L
.91788 .38265 L
.92057 .38218 L
.92302 .38183 L
.92585 .38152 L
.92853 .3813 L
.931 .38114 L
.9333 .38102 L
.93849 .38081 L
.94137 .38068 L
.94408 .38052 L
.94652 .38033 L
.94915 .38004 L
.95203 .3796 L
.95506 .37896 L
.95765 .37823 L
.96049 .37724 L
.96563 .37482 L
Mistroke
.97048 .37176 L
.97958 .36403 L
1 .3403 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool004?ooooo
1Ol0001:ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00>oooool8o`0000Co
oooo2ol00010ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7o
c<c<00Cooooo1?l00006ooooo`;o00006_oooolDo`0008?ooooo000gooooo`Co00005oooool5o`00
05kooooo00?o0000ooooooooool05_ooool3o`0001Cooooo1Ol0001nooooo`00<oooool4o`00023o
oooo0_l0001Looooo`03o`000?oooooooooo01?ooooo0ol0000Looooo`?o0000Noooool0033ooooo
0ol0000Vooooo`?o0000FOooool00ol0003oooooooooo`0@ooooo`?o00008_ooool3o`0007Sooooo
000^ooooo`;o0000;?ooool2o`0005Oooooo00?o0000ooooooooool03Oooool3o`0002Sooooo1?l0
001dooooo`00;?ooool2o`00033ooooo0ol0001Dooooo`;o00003Oooool00ol0003oooooooooo`0]
ooooo`?o0000LOooool002_ooooo00?o0000ooooooooool0<oooool3o`00057ooooo00?o0000oooo
ooooool02_ooool2o`0003?ooooo0ol0001^ooooo`005Oooool2o`000009oa0@4?oooooooooooooo
ooo^k^ko<S8bo`000?lb<S;ok^k^00[ooooo00?o0000ooooooooool03Oooool01OnHV9So410@o`00
0?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^01cooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
7_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01?ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^5oooool2o`000003ooooool0003o000000?o00000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h07Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb
<S;ok^k^00kooooo000Fooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`08ooooo`;o00004?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Kooooo`03oiRHV?lQ8B7ok^k^00;o00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
01kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0Iooooo`06o`000?nHV9So8B4Qonk^k_ooooooA4A40oooool01OmgMgOo
V9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL07_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3_ooool000_ooooo1_l00002ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00Oooooo
00?o0000ooooooooool02?ooool6o`0000Kooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo017ooooo1_l00003ooooo`05oiRHV?lQ8B7ok^k^ooooool000000_ooool01Ol@
413ooooooooooooooooo410@01?ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Nooooo`03o`000?oooooooooo00Kooooo0_l0000Iooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@400Jooooo`;o000000?o8B4Qonk^k_ooool0
0oooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003oooo
o`03oa0@4?oooooooooo01Wooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41003_ooool0
01?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool05?ooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool00000
7Oooool01?nHV9So8B4Qonk^k_ooool3o`0000?ooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000007_ooool2o`0000Kooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007?ooool2
o`000005onk^k_ooooooooooooooool000000oooool00ol0003oooooooooo`0Looooo`03ojVYZOl@
413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Kooooo`04odA4A?oMgMgoooooo`0000Co
oooo00Go0000ooooooooooooooooo`00000>ooooo`004oooool01?oMgMgoEEEEooooool00004oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Cooooo`03oa0@4?l0003o
^[Zj00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03ogMgMomVIVKooooo00;ooooo00Go
0000ooooooooooooooooo`00000Nooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`00000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00omgMgOo0000ooooo`02oooo
o`05o`000?ooooooooooooooool000007Oooool00ol@413o0000okZj^P03ooooo`05o`000?oooooo
ooooooooool000006oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00003_ooool001Cooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00Go
oooo00?o0000ooooooooool05Oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41007oooool01_l0003ooooooooooooooooo410@o`0000;ooooo00?o410@ooooooooool07?oo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41007_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@01kooooo0_l00002ooooo`05oa0@4?ooooooooooooooool@41007_ooool00onj
^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41007?ooool00omgMgOoc<c<o`000004
ooooo`05oa0@4?ooooooooooooooool@41003_ooool001Cooooo00?ok^k^odA4A?l000001?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000ooooooooool04oooool01Ol@413oV9RHoooo
oonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`05o`000?nj^[[ooooooiRH
V?l@41000oooool01OmgMgOoV9RHo`000?l0003oMgMg01kooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`0=o`00
0?nj^[[ooooooiRHV?l@413oooooo`000?ooooooMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`05oa0@
4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01cooooo00?ok^k^odA4
A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000Eooooo`03ogMgMol0003ooooo
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`03o`000?oooooooooo01Cooooo00GoZJVY
oa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool01OnHV9So410@
o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bo`00000Looooo`03oeEEEOmVIVKo0000
00Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Nooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool06_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06_oo
ool01OnHV9So410@o`000?lQ8B7oc<c<00;ooooo00Ko0000onk^k_lb<S;o0000oc8b<_o^k^hKoooo
o`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo00?o
MgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Sooooo`03o`000?oo
oooooooo04Wooooo00?o0000ooooooooool0@oooool2o`0000;ooooo00?o0000ooooooooool0BOoo
ool2o`00067ooooo000Rooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0@_ooool0
1?l0003oooooooooool0001>ooooo`03o`000?oooooooooo05kooooo000Qooooo`03o`000?oooooo
oooo04gooooo00?o0000ooooooooool0@Oooool01?l0003oooooooooool0001?ooooo`03o`000?oo
oooooooo05gooooo000Pooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0@?ooool0
0ol0003oooooo`00001Aooooo`03o`000?oooooooooo05cooooo000Oooooo`03o`000?oooooooooo
057ooooo0_l00010ooooo`;o0000D_ooool00ol0003oooooooooo`1Looooo`005_ooooooo`00043o
00004oooool001Kooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Aooooo`005_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool09?ooool2o`0002Oooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0Aooooo`007?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooo
oooo03Sooooo00?o0000ooooool00000E_ooool00ol0003oooooooooo`1Iooooo`006oooool00ol0
003oooooooooo`1Kooooo`03o`000?oooooooooo03Kooooo00Co0000oooooooooooo0000Eoooool0
0ol0003oooooooooo`1Hooooo`006_ooool00ol0003oooooooooo`1Mooooo`;o0000=Oooool01?l0
003oooooooooooooool2o`0005Oooooo00?o0000ooooooooool0Eoooool001Wooooo00?o0000oooo
ooooool0H?ooool2o`0003;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Foooo
o`03o`000?oooooooooo05Oooooo000Iooooo`03o`000?oooooooooo06;ooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Oooooo00?o0000oooooooo
ool0E_ooool001Sooooo00?o0000ooooooooool0I?ooool2o`0002gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo05Kooooo000Gooooo`03o`000?oo
oooooooo06Oooooo0_l0000[ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0F?oo
ool00ol0003oooooooooo`1Eooooo`005_ooool00ol0003oooooooooo`1Zooooo`;o0000:?ooool0
0ol0003oooooooooo`05ooooo`;o0000F_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooo
oooo017ooooo0025ooooo`;o00009Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
05Wooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Aooooo`00Qoooool2o`0002;o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool04_ooool008Wooooo0ol0000Nooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo01?ooooo
002<ooooo`;o00006oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`0Dooooo`00S_ooool3o`0001Kooooo0_l0000<
ooooo`;o0000GOooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo01Cooooo002Aoooo
o`?o00004Oooool2o`0000kooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0ioooo
o`03o`000?oooooooooo01Gooooo002Dooooo`?o00003?ooool2o`00013ooooo00?o0000oooooooo
ool0GOooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo01Kooooo002Gooooo`;o0000
2Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0
=?ooool2o`0001Wooooo002Iooooo`Wo00004oooool00ol0003oooooooooo`1Nooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool06Oooool00;Gooooo0_l0001Pooooo`03o`000?oooooo
oooo033ooooo0_l0000Looooo`00]Oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo
02kooooo0_l0000Nooooo`00T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0H?ooool0
0ol0003oooooooooo`0[ooooo`;o00008?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo01oooooo2ol0000Rooooo`00T_ooool0
1Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool06_ooool5o`0002gooooo002B
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol0001Rooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0<?oo
ool009;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0
5_ooool2o`0003?ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Hoooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo03?ooooo002Booooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`1Sooooo`03o`000?oooooooooo01;ooooo0_l0000fooooo`00T_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0
003oooooooooo`1Tooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0=_ooool00;Go
oooo0_l0001Vooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0=oooool00;Gooooo
00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Sooooo
002eooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0iooooo`00]Oooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0>_ooool00;Gooooo00?o0000ooooooooool0JOooool2o`0000Gooooo0ol0000moooo
o`00]Oooool2o`0006cooooo1_l0000oooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3o
oooo002Jooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`?o
0000/?ooool009[ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000ooooooooooooooooo`00000<ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`oooo
o`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006oooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool009;ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@
00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
0;3ooooo002Booooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06oooo
o`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00T_ooool01Ol0003ooooooooooooooooo0000
00kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000
ooooooooool0/?ooool009;ooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOo
oooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002a
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Zoooool4o`000003
oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool00:gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo0ol0002`ooooo`00[Oooool00ol0
003oooooooooo`2hooooo`00[Oooool00ol0003oooooooooo`2hooooo`00[Oooool00ol0003ooooo
ooooo`2hooooo`00Zoooool00omEEEGoIVIVo`00002jooooo`00oooooomYooooo`00[oooool00ol0
003o^[Zjooooo`2fooooo`00[oooool2oc8b<[Oooooo0020ooooo`;o000000Ko410@oooooooooooo
410@o`000?l@410Gooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?oQhN7
o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo00GoV9RHoa0@4?l0003o<S8b
olc<c003ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
07Sooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`0000Wo
oooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0
0oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00Go
410@okZj^_ooooooMgMgoc8b<P03ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOo
V9RHoooooonHV9SoMgMg07Sooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool05oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41004_ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo07Kooooo0021ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Ooo
ool6o`0000_ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000001;ooooo
00?o0000ooooooooool02oooool6o`0000cooooo00?oZJVYoa0@4?ooool01Oooool00onYZJWo410@
ooooo`02ooooo`05o`000?ooooooooooooooool00000N?ooool0087ooooo00Ko0000omgMgOlb<S;o
EEEEomgMgOl0000Kooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00000B
ooooo`03o`000?oooooooooo01cooooo00?o410@o`000?nj^[X01Oooool00ol@413o0000okZj^P03
ooooo`05o`000?ooooooooooooooool00000N?ooool0087ooooo00Ko0000ohN7QonYZJWo^[ZjoeEE
EOl0000Looooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0>ooooo`03
oa0@4?l0003o000000?o00007?ooool00onj^[[o8B4Qooooo`05ooooo`03okZj^_lQ8B7ooooo00;o
oooo00Go410@oooooooooooooooooa0@401hooooo`00POooool01_l0003o<S8boooooooooooo<S8b
o`0001Sooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
4_ooool00ol0003oooooooooo`0Jooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01Ol@413o
V9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1hooooo`00P?ooool00ol@
413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Jooooo`05ojVYZOl@
413o0000oa0@4?nYZJT00oooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP1hooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(340) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .33821 m
.01975 .3055 L
.04057 .27984 L
.0515 .27022 L
.06168 .26289 L
.07286 .25643 L
.07911 .25364 L
.08481 .25164 L
.08988 .25024 L
.09526 .24907 L
.10491 .24737 L
.11543 .24571 L
.1182 .24532 L
.12122 .24495 L
.12411 .24465 L
.12674 .24445 L
.12812 .24437 L
.12942 .24432 L
.1308 .24428 L
.13158 .24427 L
.13229 .24427 L
.13349 .24428 L
.1348 .24431 L
.13617 .24436 L
.13745 .24443 L
.13992 .24461 L
.14218 .24482 L
.14725 .24541 L
.16646 .24786 L
.17151 .24851 L
.17687 .24939 L
.18145 .25038 L
.1865 .25179 L
.19774 .25607 L
.2083 .26077 L
.24892 .28256 L
.26955 .29613 L
.29212 .30851 L
.33372 .32543 L
.37631 .34963 L
.39598 .36597 L
.40634 .37445 L
.41157 .37778 L
.41453 .37922 L
.41731 .38025 L
.41882 .38066 L
.41956 .38082 L
.42025 .38095 L
.42153 .38113 L
.42221 .38119 L
Mistroke
.42293 .38124 L
.42372 .38126 L
.42456 .38125 L
.42537 .38121 L
.4261 .38114 L
.42677 .38106 L
.4275 .38095 L
.42897 .38065 L
.43038 .38027 L
.43166 .37985 L
.43454 .37864 L
.43972 .3756 L
.44493 .3715 L
.4506 .36597 L
.46088 .35331 L
.48128 .32189 L
.50376 .29059 L
.51402 .2795 L
.52507 .26923 L
.53542 .26137 L
.54504 .25604 L
.54992 .25405 L
.55512 .25237 L
.56613 .24972 L
.57211 .24854 L
.57775 .24758 L
.58281 .24688 L
.58567 .24659 L
.58702 .24648 L
.58829 .24639 L
.58953 .24633 L
.59087 .24628 L
.59209 .24625 L
.59322 .24624 L
.59443 .24625 L
.59578 .24627 L
.59645 .24629 L
.59718 .24632 L
.5985 .24638 L
.60092 .24654 L
.60347 .24676 L
.60804 .24726 L
.62972 .24982 L
.63973 .25113 L
.64533 .25209 L
.65043 .25313 L
.6697 .25759 L
.6803 .25986 L
.69152 .2625 L
.7011 .26542 L
Mistroke
.71165 .26939 L
.72169 .27375 L
.73249 .2792 L
.75201 .29306 L
.76263 .30339 L
.77421 .31673 L
.79531 .34548 L
.80685 .36207 L
.81771 .37613 L
.82747 .38613 L
.83296 .39039 L
.83801 .3934 L
.84039 .39451 L
.84294 .39549 L
.84535 .39622 L
.84755 .39674 L
.84888 .39698 L
.85012 .39715 L
.85148 .39729 L
.85216 .39735 L
.85292 .39739 L
.85418 .39744 L
.85554 .39744 L
.85683 .3974 L
.85801 .39734 L
.85924 .39724 L
.86055 .3971 L
.86292 .39679 L
.86829 .39582 L
.87393 .39465 L
.87912 .39367 L
.88161 .3933 L
.88304 .39313 L
.88435 .393 L
.88573 .3929 L
.88649 .39286 L
.88721 .39283 L
.88849 .3928 L
.88921 .3928 L
.88988 .39282 L
.89062 .39284 L
.89141 .39288 L
.89216 .39292 L
.89285 .39298 L
.89416 .39311 L
.89553 .3933 L
.8984 .39381 L
.90155 .39458 L
.90684 .39628 L
.9125 .39853 L
Mistroke
.92271 .403 L
.92791 .40506 L
.93076 .40601 L
.93343 .40673 L
.93494 .40706 L
.93631 .40731 L
.93784 .40751 L
.93868 .40759 L
.93948 .40764 L
.94087 .40768 L
.94216 .40765 L
.9429 .4076 L
.94357 .40754 L
.94434 .40744 L
.94507 .40733 L
.9463 .40708 L
.94764 .40674 L
.95036 .40578 L
.95288 .40458 L
.95523 .40317 L
.96053 .39899 L
.96622 .393 L
.98356 .36725 L
1 .33821 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo000ioooooa3o0000BOooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2
o`0001Sooooo3Ol0002<ooooo`00<_ooool7o`00013ooooo2?l0001Tooooo`03o`000?oooooooooo
013ooooo1ol0000=ooooo`Go0000Qoooool0033ooooo0_l0000Oooooo`?o0000HOooool00ol0003o
ooooooooo`0>ooooo`;o00006Oooool7o`00083ooooo000/ooooo`Co00009?ooool3o`0005kooooo
00?o0000ooooooooool02_ooool4o`0002;ooooo0ol0001mooooo`00:_ooool2o`0002_ooooo00?o
0000ooooooooool0Foooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Oooooo1_l0
001gooooo`00:Oooool00ol0003oooooooooo`0/ooooo`;o0000Foooool2o`0000Sooooo0_l0000`
ooooo`Co0000Loooool002Sooooo00?o0000ooooooooool0;oooool2o`0005Wooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0dooooo`;o0000LOooool001Gooooo0_l000002Ol@413o
ooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP07ooooo`03o`000?oooooooooo013ooooo00Go
V9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h05Oooool2o`0000Co
oooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hNooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
5oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hDooooo`03o`000?oooooo
oooo00?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool01OnHV9So410@o`00
0?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Mooooo`;o000000Wo410@oooooooo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^h03_ooool001Kooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool04Oooool01Ol@413o^[Zjoooo
oomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Gooooo`;o00000_ooool01OnHV9So
8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
5Oooool3o`0000;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL06oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`002ooo
ool6o`0000;ooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003ooooo
ooooo`0:ooooo`Ko00001_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@oooooooo
ool04Oooool7o`0000;ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@
01?ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400N
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41006?ooool2o`000004oooooonHV9So8B4Qonk^kPCooooo
00Go410@oooooooooooooooooa0@400Oooooo`05o`000?ooooooooooooooool@41000oooool00ol@
413oooooooooo`0Iooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00kooooo000Coooo
o`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oo
oooooooo01Kooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000001[ooooo
0_l000001?ooooooV9RHob4Q8Oo^k^h3ooooo`05o`000?ooooooooooooooool000007_ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007_ooool2o`0000?ooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000006_oo
ool2o`000003oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03ojVY
ZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Kooooo`04odA4A?oMgMgoooooo`00
00Cooooo00Go0000ooooooooooooooooo`00000>ooooo`004oooool01?oMgMgoEEEEooooool00004
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Fooooo`03oa0@4?l0
003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00000Looooo`;o000000?oMgMgofIVI_ooool0
0_ooool01Ol0003ooooooooooooooooo000001kooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000001kooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`00000Looooo`;o000000GoIVIVoooooooooooooooo
o`000003ooooo`03o`000?oooooooooo01_ooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooo
oooooooooooo000001_ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo
000000kooooo000Dooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@4003
ooooo`03o`000?oooooooooo01Oooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooo
oooo410@01kooooo0_l00003ooooo`05oa0@4?ooooooooooooooool@41007_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41007_ooool01?l0003oooooooooool0000Poooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Nooooo`05o`000?oooooo
ooooooooool@41000oooool00ol@413oooooooooo`0Looooo`03okZj^_lQ8B7ooooo00;ooooo00Go
410@oooooooooooooooooa0@400Looooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooo
oooooa0@400>ooooo`005?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00_ooool00ol0003oooooooooo`0Eooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@4002o`000006oooooomg
MgOoV9RHoooooonHV9SoMgMg7_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL07_ooool00ol0003oooooo`00000Qooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Jooooo`05o`000?nj^[[ooooooiRHV?l@41000_l000001_ooooooMgMgoiRH
V?ooooooV9RHogMgMa_ooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL07?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_oo
ool001Gooooo00?oMgMgo`000?ooool00oooool01oo^k^ko<S8bo`000?lb<S;ok^k^ooooool00000
6?ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Koooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`00_ooool01_l0003ok^k^oc8b<_l0003o<S8bonk^kQcooooo
00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01kooooo0_l0000Pooooo`03
oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Jooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`00_ooool01_l0003ok^k^oc8b<_l0003o<S8bonk^kQ_ooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Oooool00omgMgOo0000ooooo`03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool0023ooooo00?o0000ooooooooool0Aoooool2o`00
04Wooooo0_l0001>ooooo`03o`000?oooooooooo063ooooo000Oooooo`03o`000?oooooooooo04[o
oooo0_l00017ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0Goooool001kooooo
00?o0000ooooooooool0COooool2o`0004Cooooo0_l0001Aooooo`03o`000?oooooooooo05kooooo
000Mooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0@Oooool2o`0005;ooooo00?o
0000ooooooooool0GOooool001cooooo00?o0000ooooooooool0D_ooool2o`00043ooooo00?o0000
ooooool00000D_ooool00ol0003oooooooooo`1Mooooo`005_ooooooo`00043o00004oooool001Ko
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo0ol00005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool001Kooooo00Go0000oooo
ooooooooooooo`00000Rooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04?ooool3
o`0001;ooooo00?o0000ooooooooool08Oooool01Ol0003ooooooooooooooooo000002Oooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0Aooooo`006_ooool00ol0003oooooooooo`1N
ooooo`;o0000<oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05Cooooo00?o0000
ooooooooool0FOooool001Wooooo00?o0000ooooooooool0HOooool3o`0002oooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo05Wooooo000Iooooo`03
o`000?oooooooooo06Cooooo0_l0000]ooooo`03o`000?oooooooooo00?ooooo0_l0001Fooooo`03
o`000?oooooooooo05Sooooo000Hooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0
Eoooool001Oooooo00?o0000ooooooooool0JOooool2o`0002Sooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo05Kooooo000Gooooo`03o`000?oooooo
oooo06_ooooo0_l0000Vooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0F?ooool0
0ol0003oooooooooo`1Eooooo`005_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo
047ooooo00?o0000ooooooooool04Oooool008Sooooo0_l0000Qooooo`03o`000?oooooooooo00Oo
oooo0_l0001Jooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool04Oooool008[ooooo
0_l0000Nooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0F_ooool00ol0003ooooo
ooooo`0nooooo`03o`000?oooooooooo01;ooooo002<ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo03gooooo00?o
0000ooooooooool04_ooool008gooooo0_l0000Jooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0Foooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo01?ooooo002?oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Loooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool04oooool0093ooooo0_l0000Fooooo`03
o`000?oooooooooo00[ooooo0_l0001Nooooo`03o`000?oooooooooo03Wooooo00?o0000oooooooo
ool05?ooool009;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo05kooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Dooooo`00Tooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Gooo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01Gooooo002Dooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool05Oooool009Gooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`0Fooooo`00U_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00oo
oooo0_l0001Rooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool05_ooool009Oooooo
0_l00008ooooo`;o00004_ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool05oooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`;o0000
00?oooooob4Q8OlQ8B400_ooool00ol0003oooooo`000004o`0000Cooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`0Hooooo`00T_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo1Ol00002ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
06?ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Iooooo`00T_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Ioooo
o`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omg
MgOo<S8booooo`04ooooo`?o0000IOooool2o`0002cooooo00?o0000ooooooooool06_ooool009;o
oooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0Kooooo`00T_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo06Sooooo0_l00009
ooooo`_o00004oooool00ol0003oooooooooo`0Looooo`00T_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0J_ooool9o`0000_ooooo0_l0000Aooooo`03o`000?oooooooooo01cooooo002B
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo
1?l00006ooooo`03o`000?oooooooooo083ooooo0ol0000<ooooo`;o00007oooool00;Gooooo0_l0
0024ooooo`;o00002Oooool00ol0003oooooooooo`0Oooooo`00]Oooool00ol0003oooooooooo`25
ooooo`Co000000?oooooo`000?l000000_l0000Rooooo`00]Oooool00ol0003oooooooooo`29oooo
o`;o00009Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000
/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
09[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`?o0000/?oo
ool009[ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0/?ooool009[ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooo
oooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00V_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000
/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool009;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00gooooo
00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo
002Booooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMg
Molb<S;ooooo00Cooooo0ol0002`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000kooooo
00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool0/?ooool009;ooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0/?ooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Zoooool4o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool0/?ooool00:gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo0ol0002`ooooo`00[Oooool00ol0003ooooo
ooooo`2hooooo`00[Oooool00ol0003oooooooooo`2hooooo`00[Oooool00ol0003oooooooooo`2h
ooooo`00Zoooool00omEEEGoIVIVo`00002jooooo`00oooooomYooooo`00[oooool00ol0003o^[Zj
ooooo`2fooooo`00[oooool2oc8b<[Oooooo0020ooooo`;o000000Ko410@oooooooooooo410@o`00
0?l@410Gooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?oQhN7o`000?nj
^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo00GoV9RHoa0@4?l0003o<S8bolc<c005
ooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h0N?ooool0087ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00002Oooool01OnHV9So8B4Q
onk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03olc<c?l0003o410@
00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002Oooool01Ol@413o^[Zjoooooomg
MgOo<S8b00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg07Sooooo
0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@41004_ooool00ol0003oooooooooo`0Nooooo`04o`00
0?ooooooooooooooo`Go00000oooool01Ol@413ooooooooooooooooo410@07Sooooo0021ooooo`06
o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000_ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool02oooool6o`0000cooooo00?o
ZJVYoa0@4?ooool00_ooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool0
0000N?ooool0087ooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Kooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo01cooooo00?o410@
o`000?nj^[X00oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool00000
N?ooool0087ooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Looooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0>ooooo`03oa0@4?l0003o000000?o00007?ooool00onj
^[[o8B4Qooooo`03ooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@401h
ooooo`00POooool01_l0003o<S8boooooooooooo<S8bo`0001Sooooo00Go0000okZj^_ooooooV9RH
oa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool00ol0003oooooooooo`0Jooooo`05
oa0@4?nHV9SooooookZj^_l000001?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0N?ooool0083ooooo00?o410@o`000?n7QhL00_ooool00on7QhOo0000oa0@400Goooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo00?o
0000ooooooooool06_ooool01OnYZJWo410@o`000?l@413oZJVY00Gooooo00?oMgMgo`000?ooool0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07Sooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(350) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .33782 m
.00942 .31815 L
.01975 .29976 L
.03065 .2843 L
.04057 .27343 L
.05163 .26408 L
.05731 .2602 L
.06347 .25663 L
.06917 .2539 L
.07444 .25185 L
.07944 .25028 L
.08481 .24894 L
.09011 .24788 L
.09496 .24708 L
.09989 .2464 L
.10447 .24588 L
.10725 .24562 L
.10978 .24543 L
.11113 .24534 L
.11258 .24527 L
.11339 .24524 L
.11412 .24521 L
.11482 .24519 L
.11557 .24517 L
.11684 .24516 L
.11802 .24515 L
.11874 .24516 L
.11942 .24517 L
.12071 .2452 L
.12205 .24524 L
.1233 .2453 L
.12613 .24549 L
.12866 .24572 L
.13099 .24597 L
.13624 .24666 L
.14572 .24817 L
.15693 .25024 L
.16736 .2528 L
.17696 .25608 L
.18723 .2605 L
.20896 .27075 L
.22987 .28209 L
.24088 .28852 L
.25253 .29429 L
.27438 .30193 L
.29452 .30695 L
.29962 .30761 L
.3025 .30788 L
.30518 .30808 L
.31049 .30843 L
Mistroke
.31281 .30861 L
.3153 .30884 L
.31777 .30914 L
.32004 .30949 L
.3245 .31045 L
.32678 .31109 L
.32927 .31192 L
.3343 .31398 L
.34486 .31989 L
.35472 .32706 L
.36531 .33679 L
.37665 .35019 L
.38677 .36406 L
.3975 .37808 L
.40309 .38395 L
.40607 .38646 L
.40926 .38863 L
.41069 .38941 L
.41219 .39011 L
.41358 .39063 L
.41488 .39102 L
.41609 .39129 L
.41739 .39148 L
.41813 .39154 L
.41883 .39157 L
.42014 .39154 L
.42139 .39143 L
.42256 .39123 L
.42385 .39092 L
.42523 .39048 L
.42804 .38924 L
.43061 .38772 L
.43556 .38372 L
.44025 .37871 L
.45068 .36376 L
.46203 .34336 L
.48236 .30726 L
.49316 .29206 L
.50482 .2785 L
.51589 .26787 L
.52075 .26405 L
.52606 .26057 L
.53109 .25796 L
.53577 .25608 L
.54072 .25458 L
.54601 .25334 L
.55675 .25135 L
.56241 .25041 L
.5655 .24995 L
.5684 .24958 L
Mistroke
.57114 .24929 L
.57233 .24919 L
.57364 .2491 L
.57438 .24905 L
.57506 .24902 L
.57641 .24897 L
.57717 .24895 L
.57786 .24895 L
.57865 .24894 L
.5794 .24895 L
.58064 .24897 L
.58194 .24902 L
.58306 .24908 L
.58428 .24916 L
.58701 .24939 L
.58955 .24967 L
.59905 .25091 L
.60425 .25153 L
.60914 .25198 L
.6144 .25235 L
.6202 .25269 L
.62512 .25306 L
.62789 .25333 L
.63043 .25362 L
.6413 .25539 L
.65275 .25755 L
.66297 .25904 L
.66858 .2597 L
.67388 .26038 L
.6791 .26122 L
.68475 .26241 L
.69462 .26523 L
.71391 .27236 L
.72386 .2769 L
.7348 .2835 L
.74622 .29265 L
.7569 .3029 L
.79768 .34907 L
.80833 .35942 L
.81435 .36397 L
.81993 .36725 L
.8227 .36854 L
.8253 .36956 L
.82767 .37032 L
.83016 .37098 L
.83289 .37153 L
.83539 .37188 L
.83679 .37203 L
.83809 .37213 L
.83884 .37217 L
Mistroke
.83952 .3722 L
.8403 .37223 L
.84105 .37224 L
.84225 .37225 L
.84354 .37223 L
.84477 .37219 L
.84589 .37214 L
.84719 .37207 L
.84862 .37197 L
.85122 .37174 L
.85644 .37122 L
.85931 .37095 L
.86071 .37083 L
.86201 .37075 L
.86324 .37068 L
.86454 .37064 L
.86584 .37062 L
.86658 .37063 L
.86727 .37064 L
.86848 .37069 L
.86958 .37076 L
.87084 .37088 L
.87205 .37103 L
.87436 .37144 L
.87651 .37197 L
.87886 .37272 L
.88137 .37374 L
.8865 .37655 L
.8912 .38001 L
.9018 .39064 L
.92099 .41526 L
.92597 .42122 L
.93128 .42663 L
.93386 .42876 L
.93629 .43041 L
.93848 .43155 L
.93972 .43205 L
.94085 .43241 L
.9421 .43269 L
.94345 .43285 L
.94472 .43287 L
.94588 .43277 L
.94723 .4325 L
.948 .43229 L
.94871 .43204 L
.95002 .43147 L
.95141 .43071 L
.95443 .42847 L
.95727 .42566 L
.96258 .41869 L
Mistroke
.97207 .40159 L
.98208 .37941 L
1 .33782 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo000coooooa7o0000C_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2
o`000;7ooooo000^ooooo`Go00004Oooool7o`0006[ooooo00?o0000ooooooooool04?ooool<o`00
09Cooooo000]ooooo`03o`000?oooooooooo01_ooooo0ol0001Wooooo`03o`000?oooooooooo00_o
oooo1Ol0000<ooooo`go0000Qoooool002[ooooo0ol0000Qooooo`;o0000IOooool00ol0003ooooo
ooooo`08ooooo`?o00007_ooool4o`0008?ooooo000Yooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0H_ooool00ol0003oooooooooo`06ooooo`;o00009Oooool7o`0007cooooo000W
ooooo`;o0000:?ooool2o`0006;ooooo0_l00005ooooo`;o0000;_ooool7o`0007Gooooo000Voooo
o`03o`000?oooooooooo02[ooooo0ol0001Oooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0=Oooool3o`0007;ooooo000Eooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o
0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`0Booooo`05oiRHV?l@413o0000oc8b<_o<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00oooooo0_l0000:ooooo`Go00000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^01cooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
7_ooool01?l0003oooooooooooooool2o`0001cooooo1?l000002?l@413oooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^4oooool3o`0000Cooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
6oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Moooo
o`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h03_ooool001Kooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000ooooooooool0
4oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Aoooo
o`;o00002?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`04o`00
0?ooooooooooo`00023ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
01Kooooo0_l00002ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL07_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool000_o
oooo1_l00002ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00;ooooo0_l0000>oooo
o`Ko00001_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool04Oooool6
o`0000?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01?ooooo1_l0
0005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Nooooo`03o`00
0?oooooo0000027ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01So
oooo00Ko0000ooooooooooooV9RHob4Q8Oo^k^h4ooooo`05oa0@4?ooooooooooooooool@41007ooo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool06Oooool5o`0000?ooooo
00Go410@oooooooooooooooooa0@400>ooooo`004oooool01?m4A4CogMgMooooool00004ooooo`07
o`000?ooooooooooooooool0003oooooo`00000Kooooo`03ojVYZOl@413ooooo00;ooooo00Go0000
ooooooooooooooooo`00000Eooooo`03o`000?oooooooooo00Gooooo00?oV9RHob4Q8Oo^k^h00ooo
ool01Ol0003ooooooooooooooooo000001kooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000001kooooo0_l0000Rooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`00000Iooooo`;o000000CooooooiRHV?lQ8B7ok^k^0oooool01Ol0003ooooooooooooo
oooo000001kooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000001_ooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000000kooooo000Cooooo`04
omgMgOmEEEGoooooo`0000Cooooo00Co0000oooooooooooooooo0_l0000Kooooo`03oa0@4?l0003o
^[Zj00?ooooo00Go0000ooooooooooooooooo`00000Fooooo`;o00001_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000007_ooool2o`0002;ooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000001_ooooo0_l000000omgMgOoIVIVooooo`02ooooo`05o`000?oooooooooo
ooooool000007Oooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000006ooo
ool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool001Cooooo
00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo000001gooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@01Sooooo0_l00005ooooo`05o`000?oooooooooo
ooooool@41000oooool00ol@413oooooooooo`0Looooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Nooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@01gooooo0_l00003ooooo`05oa0@4?ooooooooooooooool@
41007_ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41007?ooool00omg
MgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41003_ooool001Cooooo00?ok^k^odA4
A?l000001?ooool01OmgMgOoV9RHoooooonHV9So000001[ooooo00Go410@oiRHV?oooooo^[Zjo`00
0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool2o`000004okZj^_ooooooV9RHoa0@40?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Mooooo`;o00008oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL06_ooool01Ol0003o^[ZjoooooonHV9So000000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Kooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9So
MgMg01cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000E
ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o0000onk^kP0Jooooo`05ojVYZOl@
413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo0ol000000olQ8B7o
c<c<ooooo`02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool00omEEEGoIVIVo`000004oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h07Oooool2o`00027ooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00KoV9RHoa0@4?l0003o8B4Qolc<c?l00002ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h06oooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0Mooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0>ooooo`007Oooool00ol0003oooooooooo`15ooooo`?o0000Boooool01?l0003oooooo`00
0?l0001<ooooo`;o0000Hoooool001gooooo00?o0000ooooooooool0B?ooool3o`0004Sooooo00?o
0000ooooool00000Coooool00ol0003oooooooooo`1Pooooo`007?ooool00ol0003oooooooooo`1<
ooooo`;o0000AOooool01?l0003oooooooooool0001@ooooo`03o`000?oooooooooo05oooooo000L
ooooo`03o`000?oooooooooo04kooooo1?l00010ooooo`05o`000?ooooooooooooooool00000DOoo
ool00ol0003oooooooooo`1Nooooo`006oooool00ol0003oooooooooo`1Cooooo`Co0000>oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0G_ooool0
01Koooooool00010o`0001?ooooo000Fooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool3o`00
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo0000
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo017ooooo000Fooooo`05o`000?ooooooooooooooool000008_ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01Sooooo0_l0000;ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool04Oooool001Wooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`1Joooo
o`006Oooool00ol0003oooooooooo`1Wooooo`;o0000:?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo05Cooooo00?o0000ooooooooool0FOooool001Sooooo00?o0000ooooooooool0
J_ooool2o`0002Kooooo00?o0000ooooooooool01Oooool2o`0005Kooooo00?o0000ooooooooool0
F?ooool001Sooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`1Gooooo`005oooool0
0ol0003oooooooooo`1^ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1Fooooo`03o`000?oooooooooo05Oooooo000Gooooo`03o`000?oooooooooo
06oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
05Oooooo00?o0000ooooooooool0E_ooool001Kooooo00?o0000ooooooooool0LOooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0F?ooool00ol0003o
ooooooooo`11ooooo`03o`000?oooooooooo017ooooo002;ooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool02?ooool2o`0005[ooooo00?o0000ooooooooool0@?ooool00ol0003ooooo
ooooo`0Aooooo`00S?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0F_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01;ooooo002=
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1K
ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool04_ooool008kooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05cooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`0Cooooo`00S_ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`0jooooo`03
o`000?oooooooooo01?ooooo002?ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
2oooool2o`0005oooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Cooooo`00T?oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Gooo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo01Cooooo002@ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool05?ooool0097ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo067ooooo0_l0000eooooo`03o`000?oooooooooo
01Gooooo002Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`1Sooooo`;o0000<oooool00ol0003oooooooooo`0Eooooo`00T_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00kooooo0_l0001Voooooa7o00008Oooool00ol0003ooooo
ooooo`0Fooooo`00Toooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0M_ooool2o`0001oooooo00?o0000ooooooooool05_ooool009;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8b
omgMg@05ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Fooooo`00T_ooool01OmgMgOoV9RHooooool0003oMgMg00Gooooo0_lQ8B43ooooo`06o`00
0?nHV9So8B4Qonk^k_ooooooA4A41oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
07Wooooo0_l0000Kooooo`03o`000?oooooooooo01Oooooo002Booooo`05oa0@4?oooooooooooooo
ool000002Oooool01_l0003ooooooooooonHV9So8B4Qonk^kPWooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05ooo
ool009;ooooo00Co0000oooooooooooooooo0ol00006ooooo`03o`000?oooooooooo00;ooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000O?ooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo01Sooooo002Booooo`06o`000?ooooooooooooooool0003ooooo
1ol00006ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo07gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Hooooo`00
T_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo07gooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0Iooooo`00T_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oo
ooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0O_ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo01Wooooo002Booooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooo
oooo07oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Iooooo`00]Oooool2o`00
087ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Jooooo`00]Oooool00ol0003o
ooooooooo`20ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool06_ooool00;Gooooo
00?o0000ooooooooool0POooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01_ooooo
002eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0Looooo`00]Oooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool07?ooool00;Gooooo0_l00024ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool07Oooool00;Gooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo01kooooo002eooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Oooooo`00]Oooool00ol0003oooooooooo`26ooooo`;o00001_oo
ool00ol0003oooooooooo`0Oooooo`00]Oooool2o`0008Wooooo0_l000001?oooooo0000o`000?l0
000Rooooo`00]Oooool00ol0003oooooooooo`2:ooooo`;o00009?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00?ooooo0ol0002`ooooo`00V_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol0003ooooooooooooooooo
000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?oo
ool4o`0000Kooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^ko
oooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002B
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0/?ooool009;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooo
oooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`000;3ooooo002Booooo`05o`000?oooooo
ooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo
00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo
002Booooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002[
ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0/?ooool00:gooooo00?o0000ooooooooool01Oooool3o`000;3ooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002]ooooo`03o`000?oooooooooo0;Sooooo002]oooo
o`03o`000?oooooooooo0;Sooooo002[ooooo`03oeEEEOmVIVKo00000;[ooooo003oooooofWooooo
002_ooooo`03o`000?nj^[[ooooo0;Kooooo002_ooooo`;o<S8b]oooool0083ooooo0_l000001_l@
413oooooooooool@413o0000oa0@41Oooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool01OnHV9So
410@o`000?lb<S;oc<c<00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h0N?ooool0087ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07
ooooo`Ko00002Oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`03olc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko
00002Oooool01Ol@413o^[ZjoooooomgMgOo<S8b00Oooooo00WoMgMgoc8b<_ooooooooooogMgMonH
V9SooooooiRHV?mgMgL0N?ooool0087ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Gooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400Booooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool01_ooool01?l0003oooooooooool@4103ooooo`03
oa0@4?oooooooooo07Kooooo0021ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`00
00_ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000
ooooooooool02oooool6o`0000cooooo00?oZJVYoa0@4?ooool01_ooool01OmgMgOo<S8boooooooo
oooo000000?ooooo00?o0000ooooooooool0M_ooool0087ooooo00Ko0000omgMgOlb<S;oEEEEomgM
gOl0000Kooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00000Booooo`03
o`000?oooooooooo01cooooo00?o410@o`000?nj^[X01?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00;ooooo00Go0000ooooooooooooooooo`00001hooooo`00POooool01_l0003oQhN7ojVYZOnj^[[o
EEEEo`0001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00kooooo
00?o410@o`000?l000000ol0000Looooo`03okZj^_lQ8B7ooooo00?ooooo00?o0000ooooooooool0
1?ooool01Ol@413ooooooooooooooooo410@07Sooooo0021ooooo`06o`000?lb<S;ooooooooooolb
<S;o00006?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Booooo`03o`000?oooooooooo01[ooooo00Go410@oiRHV?oooooo^[Zjo`000004ooooo`03o`00
0?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1hooooo`00P?ooool00ol@413o0000
ohN7Q`02ooooo`03ohN7Qol0003o410@01Oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Jooooo`05ojVYZOl@413o0000
oa0@4?nYZJT01?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1hooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(360) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .34157 m
.00942 .31851 L
.01975 .29786 L
.03053 .2814 L
.04057 .26998 L
.04632 .2648 L
.05176 .26068 L
.06194 .25475 L
.06764 .25233 L
.07291 .25059 L
.07868 .24915 L
.08481 .24804 L
.08745 .24767 L
.08997 .24737 L
.09225 .24715 L
.09469 .24695 L
.09607 .24686 L
.09733 .24679 L
.0986 .24673 L
.09977 .24669 L
.10114 .24666 L
.10187 .24664 L
.10263 .24664 L
.10391 .24663 L
.10464 .24664 L
.10532 .24665 L
.10651 .24667 L
.10781 .24671 L
.10904 .24677 L
.11017 .24683 L
.11232 .24698 L
.11459 .24718 L
.11932 .24776 L
.12454 .24861 L
.13513 .25087 L
.14485 .25341 L
.16675 .26123 L
.20835 .28183 L
.21914 .28709 L
.22932 .29153 L
.23846 .29456 L
.24361 .29579 L
.24837 .29662 L
.25313 .2972 L
.25584 .29744 L
.25837 .29762 L
.26104 .29776 L
.26348 .29785 L
.26482 .29789 L
.26553 .2979 L
Mistroke
.26629 .29792 L
.26767 .29793 L
.26896 .29794 L
.26968 .29794 L
.27045 .29793 L
.27182 .29792 L
.27258 .2979 L
.27329 .29788 L
.27491 .29784 L
.27632 .29778 L
.27761 .29772 L
.2805 .29754 L
.28588 .29709 L
.29096 .29656 L
.2962 .29601 L
.29877 .29579 L
.29989 .29571 L
.30112 .29564 L
.30232 .29559 L
.30359 .29555 L
.30497 .29554 L
.30625 .29556 L
.30699 .29558 L
.30768 .29561 L
.30899 .29569 L
.30971 .29575 L
.31039 .29581 L
.3119 .29599 L
.31422 .29636 L
.31639 .29681 L
.32131 .29826 L
.32611 .30023 L
.33126 .30296 L
.34192 .31066 L
.34795 .31639 L
.35353 .32272 L
.37465 .35527 L
.38407 .3715 L
.39423 .38652 L
.39706 .38988 L
.40004 .39293 L
.4028 .39527 L
.40537 .39699 L
.40779 .3982 L
.40914 .3987 L
.41037 .39904 L
.41172 .39928 L
.41249 .39936 L
.41319 .3994 L
.41448 .39936 L
Mistroke
.41585 .39919 L
.41712 .39891 L
.4185 .39846 L
.4198 .3979 L
.42102 .39726 L
.4233 .39577 L
.42574 .39374 L
.43132 .38752 L
.43638 .38015 L
.4556 .34325 L
.47752 .30371 L
.48714 .29023 L
.49769 .27779 L
.50261 .27291 L
.50788 .26844 L
.51243 .26526 L
.51739 .2625 L
.52298 .26018 L
.52827 .25855 L
.53819 .25625 L
.54891 .25404 L
.55416 .2531 L
.55645 .25277 L
.55897 .25247 L
.56016 .25235 L
.56143 .25225 L
.56277 .25217 L
.56401 .25212 L
.56472 .2521 L
.56548 .25209 L
.56687 .25208 L
.56821 .25211 L
.56946 .25215 L
.57084 .25222 L
.57213 .25231 L
.57508 .25256 L
.58103 .2532 L
.58626 .25373 L
.5877 .25385 L
.58922 .25396 L
.59065 .25405 L
.59197 .25412 L
.59332 .25417 L
.59403 .25419 L
.59478 .2542 L
.59604 .25422 L
.59742 .25423 L
.59865 .25423 L
.59997 .25421 L
.60121 .2542 L
Mistroke
.60235 .25418 L
.60467 .25413 L
.60595 .25411 L
.60714 .2541 L
.60843 .25409 L
.60912 .25409 L
.60985 .25409 L
.61116 .2541 L
.61235 .25412 L
.61356 .25416 L
.61467 .2542 L
.6159 .25426 L
.6172 .25435 L
.61962 .25455 L
.62182 .25478 L
.63246 .25634 L
.63828 .25718 L
.64112 .25752 L
.64372 .25777 L
.64835 .2581 L
.6509 .25823 L
.65332 .25834 L
.65577 .25845 L
.65837 .25858 L
.66123 .25877 L
.66387 .25901 L
.66636 .25932 L
.66864 .25967 L
.67379 .26072 L
.67833 .26194 L
.6831 .26345 L
.69337 .26709 L
.70434 .27122 L
.71519 .27628 L
.72506 .28263 L
.74434 .29964 L
.76617 .32169 L
.77576 .33174 L
.78631 .34201 L
.79119 .34602 L
.79644 .34956 L
.79898 .35096 L
.80139 .35209 L
.80376 .35301 L
.80592 .35369 L
.80841 .35429 L
.80978 .35454 L
.81107 .35473 L
.81227 .35486 L
.81337 .35495 L
Mistroke
.81458 .355 L
.81585 .35503 L
.81714 .35501 L
.81852 .35495 L
.81983 .35485 L
.82102 .35474 L
.82393 .35433 L
.82668 .35382 L
.84584 .34772 L
.85109 .34585 L
.85385 .34498 L
.85675 .34421 L
.8593 .34369 L
.86074 .34348 L
.86208 .34334 L
.86332 .34326 L
.86445 .34324 L
.86575 .34327 L
.86697 .34336 L
.86817 .34351 L
.8695 .34375 L
.87088 .34409 L
.87217 .34448 L
.87448 .34539 L
.87695 .34666 L
.88261 .35075 L
.88777 .35596 L
.89909 .37221 L
.90983 .39287 L
.91902 .41287 L
.92893 .43355 L
.9346 .44319 L
.93709 .44659 L
.93981 .44962 L
.94105 .45075 L
.94239 .45176 L
.94354 .45247 L
.94479 .45306 L
.94552 .45331 L
.9462 .45349 L
.94753 .45368 L
.94875 .45365 L
.95003 .45342 L
.95131 .45298 L
.95249 .4524 L
.95384 .45151 L
.95513 .45045 L
.95741 .44807 L
.9599 .44478 L
.96553 .43489 L
Mistroke
.97076 .42315 L
.99281 .36135 L
1 .34157 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo000cooooo`Wo0000E_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2
o`000;7ooooo000^ooooo`Go00002Oooool4o`0007Gooooo00?o0000ooooooooool0/?ooool002[o
oooo1?l0000Booooo`Ko0000Koooool00ol0003oooooooooo`0=ooooo`_o0000V?ooool002Sooooo
0_l0000Looooo`?o0000K?ooool00ol0003oooooooooo`08ooooo`Go00002ooooolAo`0008Oooooo
000Wooooo`03o`000?oooooooooo01oooooo0_l0001Zooooo`03o`000?oooooooooo00Gooooo0ol0
000Qooooo`_o0000O?ooool002Gooooo0_l0000Tooooo`;o0000J?ooool2o`0000?ooooo0ol0000_
ooooo`?o0000NOooool002Cooooo00?o0000ooooooooool09_ooool2o`0006Kooooo00?o0000oooo
ooooool00_l0000eooooo`?o0000M_ooool001Gooooo0_l000002Ol@413oooooooooooooooook^k^
oc8b<_l0003o<S8bonk^kP04ooooo`03o`000?oooooooooo01?ooooo00GoV9RHoa0@4?l0003o<S8b
olc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool2o`00017ooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h07?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b
<_o^k^hNooooo`03o`000?oooooo000001oooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^3oooool3o`0000Sooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06ooo
ool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Mooooo`;o
000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h03_ooool001Kooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo0_l0000Fooooo`05oa0@4?nj
^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo0ol0000>ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000ooooool000008Ooo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool3o`0000Gooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool01Ol@
413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`002oooool6o`0000;ooooo1Ol0
0003ooooo`07oa0@4?ooooooooooooooool@413oooooo`00000@ooooo`Ko00001_ooool01Ol0003o
oooooooooooooooo410@00?ooooo00?o410@ooooooooool02oooool2o`0000Cooooo1_l00003oooo
o`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400Cooooo`Ko00001Oooool0
0ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41007_ooool2o`0002;ooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01Gooooo00?o0000ooooooooool0
0oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41007oooool01Ol0003o
oooooooooooooooo410@00?ooooo00?o410@ooooooooool06Oooool5o`0000?ooooo00Go410@oooo
oooooooooooooa0@400>ooooo`004oooool01?m4A4CogMgMooooool00004ooooo`04o`000?oooooo
ooooooooo`;o00007?ooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool00000
3oooool2o`0000cooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000001ko
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001gooooo0ol0000Roooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Fooooo`;o00001?ooool0
0onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000007_ooool00onYZJWo410@oooo
o`02ooooo`05o`000?ooooooooooooooool000006oooool01?m4A4CogMgMooooool00004ooooo`05
o`000?ooooooooooooooool000003_ooool001?ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0
003ooooooooooooooooo000001cooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooo
oooo0000017ooooo0_l0000;ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`;o
00008oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000006?ooool2o`00
00?ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000001gooooo00?o410@
o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000001_ooooo00CogMgMoeEEEOoooooo0000
1?ooool01Ol0003ooooooooooooooooo000000kooooo000Dooooo`03ogMgMoo<c<co000000Cooooo
00Go410@ooooooooooooooooo`00000Mooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooo
oooooooooa0@400Cooooo`03o`000?oooooooooo00Wooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01cooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@01cooooo00?o0000ooooool000008oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41006_ooool2o`0000;ooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@
01cooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00kooooo000Doooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?oooooo0000ogMgM`0Jooooo`05oa0@4?nHV9So
oooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01Cooooo0_l00005ooooo`05o`00
0?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Co0000oooooooooooo00008ooo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01Ol0003o^[Zj
o`000?nHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`05oa0@4?nHV9Sooooo
okZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01cooooo00?ok^k^odA4A?l000001?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000Eooooo`03ogMgMol0003ooooo00?ooooo00Go
k^k^oc8b<_l0003o0000onk^kP0Jooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^01Kooooo0_l00003ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^01cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^01[ooooo00Go0000ooooooooooooooooo`00000Qooooo`03oeEEEOmVIVKo000000Co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Jooooo`05oiRHV?l@413o0000o`000?o<c<`00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h07Oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03_ooool001gooooo00?o0000ooooooooool0?oooool3o`0004oooooo00Co0000oooooooo
oooooooo0_l0001:ooooo`03o`000?oooooooooo06Cooooo000Mooooo`03o`000?oooooooooo04;o
oooo1_l00007ooooo`go0000=?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04[o
oooo00?o0000ooooooooool0Hoooool001cooooo00?o0000ooooooooool0BOooool7o`0000gooooo
0ol0000`ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Boooool00ol0003ooooo
ooooo`1Rooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o0000;Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0HOooool001_ooooo00?o0000
ooooooooool0Hoooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0COooool00ol0003oooooooooo`1Pooooo`005_ooooooo`00043o00004oooool001Ko
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ool000001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo000Foooo
o`05o`000?ooooooooooooooool000008_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Tooooo`05o`000?oooooo
ooooooooool000008oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo017ooooo000I
ooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0G?ooool001Wooooo00?o0000oooo
ooooool0J_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0D_ooool00ol0003oooooooooo`1Kooooo`006?ooool00ol0003oooooooooo`1[ooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool02?ooool2o`0005Cooooo00?o0000oooooooo
ool0F_ooool001Sooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`1Iooooo`005ooo
ool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo05Sooooo000Gooooo`03o`000?oooooo
oooo06kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo05Gooooo00?o0000ooooooooool0F?ooool001Oooooo00?o0000ooooooooool0Koooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0E_ooool00ol0
003oooooooooo`1Gooooo`005_ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool02_ooool2o`0005Sooooo00?o0000ooooooooool0@_ooool00ol0003o
ooooooooo`0Aooooo`00R_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0F?ooool2o`0001Cooooo1_l0000Xooooo`03o`000?oooooooooo017ooooo
002;ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`1Jooooo`03o`000?oooooooooo00gooooo1Ol00005ooooo`?o00009Oooool00ol0003ooooooooo
o`0Aooooo`00Roooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool0Foooool2o`0000[ooooo0ol0000=ooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool04_ooool008cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo05gooooo0_l00006ooooo`;o00004?ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo01;ooooo002=ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool03Oooool2o`00063ooooo1_l0000Cooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool04_ooool008gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo07Sooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Cooooo`00S_oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0NOoo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01?ooooo002?ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1jooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool04oooool008oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Dooooo`00T?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oo
oooo0_l0001mooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool05?ooool0093ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo07cooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Dooooo`00TOooool01_l0003ok^k^oc8b
<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
01Gooooo002Booooo`05o`000?nHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@?ooooo00Ko0000oiRH
V?lQ8B7ok^k^oooooom4A4@7ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0OOoo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Gooooo002Booooo`05o`000?oooooo
ooooooooool@41002Oooool01_l0003ooooooooooonHV9So8B4Qonk^kPWooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool05Oooool009;ooooo0_l00002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
0_ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0001nooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool05_ooool009;ooooo00Go0000ooooool0003ooooo
o`000007ooooo`03o`000?oooooooooo00Cooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo01Kooooo002Booooo`05oa0@4?ooooooooooo`000?l@41001_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`1oooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05oooool009;ooooo
00CoMgMgoiRHV?ooooooV9RH0_l00003ooooo`;o00001Oooool01Ol0003o^[ZjoooooonHV9So410@
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool05oooool009;ooooo00Kok^k^oc8b<_l0003o<S8bonk^k_ooool4
o`0000Kooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003ooooooooo
o`20ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05oooool00;Gooooo0_l00021
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool06?ooool00;Gooooo00?o0000oooo
ooooool0POooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Sooooo002eooooo`03
o`000?oooooooooo087ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Hooooo`00
]Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
6Oooool00;Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo01Wooooo002eooooo`;o0000Q?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo01Wooooo002eooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0Jooooo`00]Oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool06_ooool00;Gooooo00?o0000ooooooooool0Q?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo01_ooooo002eooooo`;o0000QOooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo01_ooooo002eooooo`03o`000?oooooooooo08Gooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Looooo`00]Oooool00ol0003oooooooooo`25oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07?ooool00;Gooooo00?o0000oooooooo
ool0Q_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01gooooo002eooooo`03o`00
0?oooooooooo08Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Nooooo`00]Ooo
ool2o`0008Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Nooooo`00]Oooool0
0ol0003oooooooooo`29ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07oooool0
0;Gooooo00?o0000ooooooooool0R_ooool4o`0002;ooooo002Jooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo
410@013ooooo00?o0000ooooooooool00oooool3o`000;3ooooo002Jooooo`05o`000?oooooooooo
ooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Joooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_oo
ool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?oo
ool009;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooo
oooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`?o0000/?oo
ool009;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?oo
ooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3o
oooo002Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00:_ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooo
oooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool00:go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003ooooo
ooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000ooooooooool0^?ooool00:gooooo00?o0000
ooooooooool0^?ooool00:gooooo00?o0000ooooooooool0^?ooool00:_ooooo00?oEEEEofIVI_l0
0000^_ooool00?ooooooJOooool00:oooooo00?o0000okZj^_ooool0]_ooool00:oooooo0_lb<S:g
ooooo`00P?ooool2o`000006oa0@4?oooooooooooa0@4?l0003o410@5oooool5o`0000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003o
A4A4okZj^P0Hooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?l@413o
c<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1hooooo`00POooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Oooooo1_l00009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zj
onk^k_mgMgOo410@00Wooooo1_l00009ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmE
EEGoMgMgoooooonHV9So8B4Q00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1hooooo`00POooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Oooooo00?oV9RHob4Q8Oo^k^h01?ooool0
1Ol@413ooooooooooooooooo410@01;ooooo00?o0000ooooooooool07_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo07Ko
oooo0021ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000_ooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool02oooool6
o`0000cooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003oV9RHoooooonHV9So8B4Q00?ooooo00Go
0000ooooooooooooooooo`00001hooooo`00POooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001_o
oooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000oooo
ooooool07?ooool00ol@413o0000okZj^P03ooooo`05o`000?mEEEGo0000oa0@4?o<c<`00oooool0
1Ol0003ooooooooooooooooo000007Sooooo0021ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo0000
7?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool03_ooool00ol@413o
0000o`000003o`0001cooooo00?o^[Zjob4Q8Oooool00_ooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?ooooooooooooooool@4100N?ooool0087ooooo00Ko0000oc8b<_oooooooooooc8b<_l0000H
ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo
00?o0000ooooooooool06_ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00?ogMgMoa0@4?nH
V9P01Oooool01OmgMgOoV9RHoooooonHV9SoMgMg07Sooooo0020ooooo`03oa0@4?l0003oQhN700;o
oooo00?oQhN7o`000?l@41005oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Booooo`03o`000?oooooooooo01[ooooo00GoZJVYoa0@4?l0003o410@ojVY
Z@04ooooo`04olc<c?m4A4Co0000oa0@40?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1hooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(370) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .34992 m
.00942 .32336 L
.01975 .30018 L
.03053 .28208 L
.04057 .26972 L
.04632 .26426 L
.05176 .26009 L
.0567 .25707 L
.06194 .25458 L
.06764 .25258 L
.07291 .25127 L
.07583 .25073 L
.07857 .25031 L
.08158 .24995 L
.08327 .24979 L
.08481 .24967 L
.08609 .24959 L
.08747 .24951 L
.08823 .24948 L
.08893 .24946 L
.09031 .24942 L
.09149 .2494 L
.09279 .2494 L
.09415 .24942 L
.09542 .24945 L
.09614 .24948 L
.09692 .24951 L
.09834 .24959 L
.10101 .24981 L
.10412 .25016 L
.107 .25058 L
.11186 .25151 L
.11723 .25282 L
.12809 .25613 L
.14841 .2639 L
.17031 .27473 L
.19094 .28474 L
.20263 .28918 L
.20822 .29092 L
.2135 .29229 L
.21856 .2933 L
.22141 .29372 L
.22277 .29388 L
.22404 .29401 L
.2252 .29411 L
.22626 .29418 L
.22743 .29424 L
.2287 .29428 L
.2299 .2943 L
.23122 .2943 L
Mistroke
.23247 .29428 L
.23362 .29423 L
.23497 .29417 L
.23643 .29407 L
.23908 .29382 L
.24403 .29318 L
.2498 .29218 L
.25511 .29112 L
.26549 .2888 L
.27659 .28621 L
.28198 .28505 L
.28463 .28455 L
.28708 .28414 L
.28926 .28384 L
.29166 .28359 L
.2929 .28349 L
.29407 .28343 L
.2953 .28338 L
.29663 .28337 L
.29784 .28339 L
.29914 .28345 L
.30037 .28354 L
.30148 .28365 L
.30279 .28381 L
.30421 .28404 L
.30679 .28458 L
.30949 .28533 L
.31235 .28632 L
.31747 .28865 L
.32217 .2914 L
.32656 .29453 L
.33655 .30379 L
.34751 .31785 L
.3579 .33505 L
.37737 .37214 L
.38749 .38882 L
.3926 .39532 L
.39555 .39831 L
.39825 .40051 L
.40059 .40196 L
.40176 .40253 L
.40305 .40303 L
.40434 .40339 L
.40572 .40363 L
.40703 .4037 L
.40822 .40364 L
.40942 .40345 L
.41053 .40317 L
.41175 .40274 L
.41303 .40215 L
Mistroke
.4152 .40084 L
.41758 .39894 L
.42305 .3929 L
.42824 .38524 L
.43798 .36729 L
.45991 .32371 L
.46998 .30676 L
.48072 .29152 L
.49078 .27999 L
.50003 .27205 L
.50529 .26868 L
.51084 .2659 L
.52253 .26172 L
.53263 .25889 L
.53832 .25751 L
.54371 .25642 L
.54621 .25602 L
.54885 .25568 L
.55023 .25554 L
.55175 .25541 L
.55314 .25532 L
.55444 .25526 L
.55563 .25522 L
.55689 .25519 L
.55797 .25518 L
.55914 .25517 L
.56041 .25518 L
.56177 .25521 L
.56305 .25524 L
.56421 .25527 L
.56685 .25535 L
.56964 .25543 L
.57109 .25546 L
.57192 .25548 L
.5727 .25549 L
.57406 .2555 L
.57482 .2555 L
.57552 .25549 L
.57687 .25548 L
.57813 .25545 L
.57952 .25541 L
.58099 .25535 L
.58371 .2552 L
.58618 .25504 L
.59132 .25468 L
.59413 .25451 L
.5955 .25444 L
.59674 .25438 L
.59789 .25435 L
.59898 .25432 L
Mistroke
.60013 .25431 L
.60137 .25431 L
.60265 .25432 L
.60401 .25436 L
.60517 .2544 L
.60644 .25446 L
.60928 .25466 L
.61188 .25489 L
.61774 .25551 L
.62286 .25604 L
.62567 .25627 L
.62832 .25644 L
.63093 .25656 L
.63239 .25661 L
.63374 .25664 L
.63488 .25667 L
.63613 .25668 L
.63866 .25671 L
.63988 .25672 L
.64105 .25673 L
.64239 .25676 L
.64362 .25678 L
.64477 .25682 L
.64584 .25686 L
.64701 .25692 L
.64825 .257 L
.65082 .25722 L
.65226 .25738 L
.65358 .25755 L
.65859 .25846 L
.66415 .25989 L
.67001 .26175 L
.68078 .26554 L
.69096 .26927 L
.7001 .27337 L
.71001 .27959 L
.73059 .29784 L
.75258 .31905 L
.76336 .32972 L
.77344 .33881 L
.77851 .34247 L
.78112 .34402 L
.78396 .34541 L
.78557 .34605 L
.78706 .34656 L
.78861 .347 L
.79001 .34731 L
.79139 .34754 L
.79268 .34769 L
.79405 .34779 L
Mistroke
.79483 .34781 L
.79553 .34782 L
.79686 .34778 L
.79812 .3477 L
.79925 .34758 L
.80048 .34741 L
.80323 .34688 L
.80578 .34622 L
.81041 .34469 L
.81533 .34265 L
.83704 .32987 L
.8469 .32347 L
.8496 .32196 L
.85244 .32059 L
.85489 .3196 L
.85624 .31915 L
.85751 .3188 L
.85871 .31852 L
.86001 .31829 L
.86119 .31815 L
.86227 .31807 L
.86329 .31805 L
.86442 .31808 L
.86559 .31818 L
.86669 .31834 L
.86799 .3186 L
.86922 .31893 L
.87153 .31974 L
.87401 .32093 L
.87672 .32259 L
.88179 .32674 L
.88657 .33191 L
.89224 .33974 L
.89745 .34867 L
.90805 .37217 L
.91949 .40417 L
.92908 .4321 L
.93435 .44573 L
.93933 .45635 L
.94215 .46109 L
.94364 .46317 L
.94522 .46503 L
.94654 .46632 L
.948 .46743 L
.94933 .46816 L
.95058 .46859 L
.95193 .46879 L
.95321 .46871 L
.95436 .46841 L
.95562 .46785 L
Mistroke
.95699 .46697 L
.95844 .46571 L
.96105 .46265 L
.96349 .4589 L
.96607 .45407 L
.97069 .44342 L
.98111 .41244 L
1 .34992 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000/Oooool0
02oooooo2Ol0001mooooo`03o`000?oooooooooo0;3ooooo000Zooooo`Go00002Oooool6o`0007Oo
oooo00?o0000ooooooooool0/?ooool002Wooooo00?o0000ooooooooool04_ooool2o`0007Gooooo
00?o0000ooooooooool02_oooolQo`0008Gooooo000Wooooo`;o00005oooool3o`0007;ooooo00?o
0000ooooooooool01_ooool4o`00027ooooo2?l0001mooooo`009Oooool2o`0001cooooo0_l0001`
ooooo`;o00000oooool4o`0002gooooo0ol0001jooooo`009?ooool00ol0003oooooooooo`0Noooo
o`;o0000K_ooool00ol0003oooooooooo`02o`0003Cooooo0ol0001gooooo`005Oooool2o`000009
oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00?o0000ooooooooool04ooo
ool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03o`0001So
oooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hNooooo`?o00007oooool4o`000008oa0@4?ooooooooooonk^k_lb
<S;o0000oc8b<_o^k^h>ooooo`?o00002Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0Kooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01go
oooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0>ooooo`005_ooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool00ol0003ooooooooo
o`0Dooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo0_l0000Fooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9So
MgMg01kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
4Oooool00ol0003oooooooooo`06ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL07_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3_ooool000_ooooo1_l00002ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00;ooooo
00?o0000ooooooooool03Oooool6o`0000Kooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo00?ooooo0_l0000<ooooo`Ko00000oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41004oooool6o`0000Gooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@01gooooo0_l0000Sooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Booooo`;o00001oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?oo
ooooooooooooool@41007oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@oooooooo
ool06Oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`004oooool01?m4A4Co
gMgMooooool00004ooooo`07o`000?ooooooooooooooool0003oooooo`00000Kooooo`03ojVYZOl@
413ooooo00;ooooo00Go0000ooooooooooooooooo`000007ooooo`;o00005?ooool00onHV9So8B4Q
onk^kP03ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000007?ooool01?l0003oooooo`000?l0000Rooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`00000Dooooo`03o`000?oooooooooo00Gooooo00?o
V9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000001kooooo00?oZJVYoa0@4?ooool0
0_ooool01Ol0003ooooooooooooooooo000001_ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0
003ooooooooooooooooo000000kooooo000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo00Co0000
oooooooooooooooo0_l0000Kooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000oooooooooooooooo
o`000009ooooo`;o00004oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool0
00007_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000006oooool01?l0
003oooooooooool0000Sooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
000Eooooo`03o`000?oooooooooo00Gooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooo
oooooooo000001gooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000001_o
oooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000kooooo000Doooo
o`03ogMgMoo<c<co000000Cooooo00Go410@ooooooooooooooooo`00000Mooooo`03okZj^_lQ8B7o
oooo00;ooooo00Go410@oooooooooooooooooa0@400;ooooo`;o00004_ooool01Ol0003ooooooooo
oooooooo410@00?ooooo00?o410@ooooool000001ol0000Eooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@400Kooooo`04o`000?ooooooooooo`0002?ooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@01Kooooo00?o0000ooooooooool01Oooool0
1Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool07?ooool00onj^[[o8B4Qoooo
o`02ooooo`05oa0@4?ooooooooooooooool@41007?ooool00omgMgOoc<c<o`000004ooooo`05oa0@
4?ooooooooooooooool@41003_ooool001Cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RH
oooooonHV9So000001[ooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03Oooool2o`0000cooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`03ogMgMonH
V9So000000?o00002?ooool3o`0001;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg01[ooooo00Go0000ooooooooooooooooo`00000Sooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Gooooo`08o`000?ooooooooooo`000?nj^[[ooooooiRH
V?l@4103ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool01Ol@413oV9RHoooooonj^[[o0000
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`03onk^k_m4A4Co000000Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0>ooooo`005Oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o
0000o`000?o^k^h06_ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0?ooooo`Co00002?ooool01?nHV9So410@o`000?lQ8B47o`000003oc8b<_o^k^kooooo
00_ooooo00?o0000ooooooooool03Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h06Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01oooooo00?oEEEE
ofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Sooooo00Oo0000oooooonHV9So410@
o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000
oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo00?oMgMgo`000?ooool00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Mooooo`03o`000?oooooooooo03[ooooo3?l0
000Fooooo`;o0000<Oooool00ol0003oooooooooo`03ooooo`;o0000AOooool00ol0003ooooooooo
o`1Yooooo`007Oooool00ol0003oooooooooo`1Nooooo`;o0000;_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0J?ooool001cooooo00?o0000oooo
ooooool0HOooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0A_ooool2o`0006Sooooo000Looooo`03o`000?oooooooooo06;ooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Sooooo00?o0000oooooooo
ool0IOooool001_ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`1Tooooo`005_oo
ooooo`00043o00004oooool001Kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00?ooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo
000Fooooo`05o`000?ooooooooooooooool000008_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Aooooo`006_oo
ool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo01kooooo1Ol0000mooooo`006_ooool0
0ol0003oooooooooo`1Wooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`1>ooooo`03o`000?oooooooooo01_ooooo0ol00004ooooo`?o0000>_ooool0
01Wooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
00[ooooo0_l0001@ooooo`03o`000?oooooooooo01Sooooo0_l00009ooooo`03o`000?oooooooooo
03Sooooo000Iooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`0:ooooo`;o0000>?ooool001Sooooo00?o0000ooooooooool0K?ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0DOooool00ol0003ooooo
ooooo`0Cooooo`;o00003oooool00ol0003oooooooooo`0eooooo`006?ooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`1Booooo`03o`000?oooooooooo013ooooo0_l0000Aooooo`03o`000?oooooooooo03Gooooo000H
ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo03Cooooo000Gooooo`03o`000?oooooooooo06oooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0<ooooo`;o0000EOooool2o`0000cooooo0_l0000Foooo
o`03o`000?oooooooooo03?ooooo000Gooooo`03o`000?oooooooooo06oooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo05Kooooo00?o0000oooooooo
ool01_ooool3o`0001Sooooo00?o0000ooooooooool0<oooool001Oooooo00?o0000ooooooooool0
L?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
Eoooool8o`0001cooooo00?o0000ooooooooool0<_ooool001Kooooo00?o0000ooooooooool0LOoo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0Nooo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo017ooooo002;ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1kooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool04Oooool008_ooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0?ooooo`;o0000OOooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
017ooooo002<ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`1looooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool04_ooool008cooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo07gooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0Booooo`00SOooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0O_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo01;ooooo002=ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool04oooool008kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aoooo
o`;o0000P?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01?ooooo002>ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1oooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool04oooool008oooooo00So0000oooooooooooo
k^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B401?oooooo0000ooooooooool5o`0000Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0Dooooo`00Soooool02?l0003ooooooooooomgMgOoV9RHoooooonH
V9SoMgMg1Oooool2ob4Q8@09ooooool0003ooooooooooonHV9So8B4Qonk^k_ooooooA4A400Oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool05?ooool0093ooooo00?o0000ooooool@41000oooool00ol@413ooooooooo
o`05ooooo`03o`000?oooooooooo00;ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0Dooooo`00T?ooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00020
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool05?ooool0097ooooo0_l00003oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00omgMgOoIVIVooooo`03oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`21ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool05Oooool009;ooooo00Go0000oooooooooooooooooa0@4005
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0E
ooooo`00T_ooool01OmgMgOo0000oooooonHV9SoMgMg00Gooooo00?o0000ooooooooool00oooool0
1Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`21ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05Oooool009;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP03ooooo`;o00001_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo
1?l00006ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Fooooo`00UOooool5o`0001_ooooo0_l00023ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool05_ooool00;Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo01Kooooo002eooooo`03o`000?oooooooooo08?ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0Gooooo`00]Oooool00ol0003oooooooooo`23ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool05oooool00;Gooooo00?o0000ooooooooool0
Poooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Oooooo002eooooo`;o0000QOoo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Oooooo002eooooo`03o`000?oooooo
oooo08Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Hooooo`00]Oooool00ol0
003oooooooooo`24ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool06?ooool00;Go
oooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01So
oooo002eooooo`;o0000Q_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Wooooo
002eooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0Iooooo`00]Oooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool06Oooool00;Gooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo01[ooooo002eooooo`03o`000?oooooooooo08Kooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Jooooo`00]Oooool2o`0008Sooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Jooooo`00]Oooool00ol0003oooooooooo`27ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool06oooool00;Gooooo00?o0000ooooooooool0R?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo01cooooo002Jooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo08Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Looooo`00V_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0ROooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01gooooo002J
ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`?o0000R_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01gooooo002Jooooo`05o`000?oooooo
ooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo08_ooooo00?o
0000ooooooooool00_l0000Pooooo`00V_ooool01Ol0003ooooooooooooooooo000000cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo08cooooo0ol0000Qooooo`00V_oo
ool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l00006ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^oooo
o`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00T_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooo
oooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo0;3ooooo002Booooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooo
ooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00T_ooool01Ol0003ooooooooo
oooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool0/?ooool009;ooooo00Go410@oooooooooooooooooa0@400>ooooo`03
ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00
T_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Zooo
ool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool00:gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo0ol0002`ooooo`00
[Oooool00ol0003oooooooooo`2hooooo`00[Oooool00ol0003oooooooooo`2hooooo`00[Oooool0
0ol0003oooooooooo`2hooooo`00Zoooool00omEEEGoIVIVo`00002jooooo`00oooooomYooooo`00
[oooool00ol0003o^[Zjooooo`2fooooo`00[oooool2oc8b<[Oooooo0020ooooo`;o000000Ko410@
oooooooooooo410@o`000?l@410Gooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo00GoV9RHoa0@
4?l0003o<S8bolc<c005ooooo`03o`000?o^k^kooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP1hooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l00009
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00009ooooo`05
oa0@4?nj^[[oooooogMgMolb<S801Oooool00omEEEGoZJVYooooo`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0N?ooool0087ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Goooo
o`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400Booooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool00oooool00onYZJWoEEEEooooo`03ooooo`05oa0@4?oooooo
ooooooooool@4100N?ooool0087ooooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko0000
2oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003o
ooooooooo`0;ooooo`Ko00003?ooool00onYZJWo410@ooooo`05ooooo`03ob4Q8Ooooooooooo00;o
oooo00Go0000ooooooooooooooooo`00001hooooo`00POooool01_l0003ogMgMoc8b<_mEEEGogMgM
o`0001_ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000001;ooooo00?o
0000ooooooooool07?ooool00ol@413o0000okZj^P06ooooo`03oeEEEOo<c<cooooo00;ooooo00Go
0000ooooooooooooooooo`00001hooooo`00POooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001co
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00kooooo00?o410@o`00
0?l000000ol0000Looooo`03okZj^_lQ8B7ooooo00Gooooo00?oZJVYogMgMoooool00_ooool01Ol@
413ooooooooooooooooo410@07Sooooo0021ooooo`06o`000?lb<S;ooooooooooolb<S;o00006?oo
ool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Booooo`03
o`000?oooooooooo01[ooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05oa0@4?oooooooooo
oooooolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg07Sooooo0020ooooo`03oa0@4?l0003o
QhN700;ooooo00?oQhN7o`000?l@41005oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0Booooo`03o`000?oooooooooo01[ooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@03ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07Sooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(380) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .36262 m
.00942 .33311 L
.01975 .30715 L
.03053 .28646 L
.04057 .27247 L
.04632 .26666 L
.05176 .26255 L
.05664 .25984 L
.06194 .25775 L
.06469 .25695 L
.06771 .25623 L
.07066 .25567 L
.07383 .2552 L
.07679 .25486 L
.0795 .25464 L
.0808 .25456 L
.08149 .25453 L
.08222 .2545 L
.08356 .25447 L
.08481 .25446 L
.08611 .25447 L
.08685 .25448 L
.08754 .25451 L
.08827 .25454 L
.08894 .25458 L
.09043 .25468 L
.09171 .2548 L
.09309 .25497 L
.09561 .25535 L
.09855 .25593 L
.10168 .25671 L
.10729 .25848 L
.12847 .26725 L
.14915 .27661 L
.16811 .28562 L
.178 .2891 L
.18298 .29033 L
.18842 .29131 L
.1913 .29168 L
.19391 .29194 L
.19535 .29205 L
.19692 .29214 L
.19764 .29218 L
.1984 .29221 L
.19977 .29225 L
.20102 .29227 L
.20236 .29228 L
.20363 .29226 L
.20479 .29224 L
.20615 .29218 L
Mistroke
.20692 .29214 L
.20763 .2921 L
.21032 .29188 L
.21168 .29174 L
.21311 .29156 L
.21567 .29118 L
.22145 .29001 L
.22644 .28869 L
.23191 .28698 L
.25146 .28036 L
.26201 .27733 L
.2672 .27606 L
.27199 .27506 L
.27461 .2746 L
.2775 .27419 L
.2789 .27403 L
.28041 .27388 L
.28124 .27382 L
.282 .27377 L
.28273 .27374 L
.28349 .27371 L
.28475 .27369 L
.28608 .2737 L
.28735 .27374 L
.28849 .27381 L
.28985 .27393 L
.29131 .27411 L
.29396 .27456 L
.29645 .27514 L
.29911 .27594 L
.30393 .27785 L
.30965 .28092 L
.31487 .28448 L
.32622 .29484 L
.33698 .30844 L
.35786 .34547 L
.37719 .38246 L
.38205 .38997 L
.38729 .39659 L
.38969 .39903 L
.39223 .40115 L
.3944 .40257 L
.39553 .40317 L
.39677 .4037 L
.39753 .40396 L
.39822 .40416 L
.3996 .40443 L
.40085 .40454 L
.40218 .4045 L
.40286 .40442 L
Mistroke
.4036 .40429 L
.40493 .40394 L
.40574 .40365 L
.40652 .40332 L
.40796 .40256 L
.41055 .40077 L
.41295 .39863 L
.41839 .39217 L
.4295 .37373 L
.43995 .35326 L
.4595 .31714 L
.46976 .30142 L
.4806 .28786 L
.48985 .27907 L
.5 .27219 L
.51072 .26703 L
.5205 .26325 L
.5259 .26143 L
.53178 .25975 L
.53447 .25911 L
.53733 .25853 L
.54246 .25774 L
.54497 .25746 L
.5476 .25723 L
.55231 .25693 L
.55781 .25664 L
.56292 .25631 L
.56736 .25593 L
.57209 .25543 L
.57697 .25487 L
.58212 .25433 L
.58479 .25411 L
.58621 .25402 L
.58772 .25395 L
.58844 .25392 L
.58912 .2539 L
.59039 .25387 L
.59159 .25385 L
.59289 .25385 L
.59368 .25386 L
.59443 .25387 L
.5951 .25389 L
.59582 .25391 L
.59745 .25397 L
.59894 .25404 L
.60455 .2544 L
.60988 .25475 L
.61249 .25489 L
.61485 .25499 L
.61736 .25507 L
Mistroke
.61873 .2551 L
.62004 .25512 L
.62145 .25514 L
.62276 .25515 L
.62427 .25516 L
.62572 .25517 L
.62694 .25519 L
.62827 .25521 L
.62948 .25523 L
.6306 .25527 L
.63194 .25532 L
.63315 .25538 L
.63456 .25547 L
.63586 .25557 L
.63821 .25581 L
.64076 .25616 L
.64537 .25702 L
.65039 .2583 L
.6559 .26001 L
.66702 .26393 L
.67753 .26795 L
.6875 .27277 L
.693 .27621 L
.69898 .28067 L
.70945 .2899 L
.7298 .30946 L
.74061 .3201 L
.75226 .33147 L
.75766 .33616 L
.76335 .34026 L
.7682 .34284 L
.77096 .34389 L
.77352 .34458 L
.77476 .34482 L
.77612 .345 L
.77739 .34511 L
.77857 .34516 L
.77963 .34515 L
.7808 .3451 L
.78202 .34499 L
.78317 .34485 L
.7845 .34462 L
.78576 .34436 L
.78814 .34374 L
.79348 .34181 L
.79877 .33929 L
.80356 .33653 L
.81431 .32882 L
.83362 .31151 L
.83875 .30723 L
Mistroke
.84417 .3034 L
.84879 .30085 L
.85142 .29973 L
.85386 .29891 L
.85522 .29854 L
.8567 .29822 L
.85738 .29811 L
.8581 .298 L
.85939 .29785 L
.86063 .29777 L
.86178 .29774 L
.86306 .29777 L
.86442 .29786 L
.8658 .29802 L
.86658 .29815 L
.8673 .29828 L
.86889 .29865 L
.87033 .29907 L
.87294 .30005 L
.87573 .30143 L
.88084 .30493 L
.88341 .30723 L
.88624 .31023 L
.89591 .32469 L
.90136 .33599 L
.9072 .35065 L
.91776 .38268 L
.92782 .41667 L
.93852 .45025 L
.9441 .46405 L
.94728 .47017 L
.94873 .47247 L
.95027 .47454 L
.95157 .476 L
.95299 .47727 L
.95429 .47811 L
.9555 .47862 L
.95623 .47881 L
.95692 .47889 L
.95822 .4788 L
.95895 .47862 L
.95962 .47836 L
.96036 .47799 L
.96114 .47747 L
.96237 .47644 L
.96354 .4752 L
.96574 .47221 L
.96811 .46807 L
.97069 .46251 L
.97963 .43643 L
Mistroke
1 .36262 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool002_ooooo
3Ol0001mooooo`03o`000?oooooooooo00oooooo7?l00025ooooo`009oooool4o`0000gooooo0_l0
001kooooo`03o`000?oooooooooo00Kooooo2Ol0000Looooo`Co0000POooool002Kooooo00?o0000
ooooooooool04Oooool3o`0007Sooooo0_l00005ooooo`;o0000:Oooool3o`0007kooooo000Uoooo
o`03o`000?oooooooooo01Gooooo0_l0001fooooo`03o`000?oooooooooo00;ooooo0_l0000^oooo
o`?o0000Noooool001Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^
kP04ooooo`03o`000?oooooooooo01?ooooo00GoV9RHoa0@4?l0003o<S8bolc<c002o`000006oooo
ooo^k^ko<S8bo`000?lb<S;ok^k^6oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0L
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQkooooo00?o0000ooooool0
00000_l0000Mooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP[ooooo0_l0
000>ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00GoV9RHoa0@4?l0003o
<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Oooool2o`000009oa0@4?oooooooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Fooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`03ooooo`03o`000?oooooooooo01Cooooo00Go410@okZj^_oooooo
MgMgoc8b<P02ooooo`;o000000CoV9RHoooooonHV9SoMgMg6oooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0Nooooo`;o00008_ooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03?ooool2o`0000cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL06oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0>ooooo`002oooool6o`0000;ooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@
41000oooool00ol0003oooooooooo`0<ooooo`Ko00001_ooool01Ol0003ooooooooooooooooo410@
00;o000000?ooooooa0@4?ooool04_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h01?ooool00ol@
413oooooo`000008o`0000gooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@400Mooooo`;o00008oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41003_ooool00ol0003oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go
410@oooooooooooooooooa0@400Oooooo`05o`000?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`0Iooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00kooooo000Cooooo`04
odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo01Sooooo00?oZJVYoa0@4?ooool00_ooool00ol0003oooooooooo`02o`0001gooooo00CoV9RH
ob4Q8Oo^k^kooooo1?l00002ooooo`03o`000?oooooooooo00Cooooo0ol0000Eooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000Looooo`04o`000?oooooo0000o`0002;o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000oooooo0_l0000;oooo
o`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03ojVYZOl@413o
oooo00;ooooo00Go0000ooooooooooooooooo`00000Kooooo`04odA4A?oMgMgoooooo`0000Cooooo
00Go0000ooooooooooooooooo`00000>ooooo`004oooool01?oMgMgoEEEEooooool00004ooooo`07
o`000?ooooooooooooooool0003oooooo`00000Jooooo`03oa0@4?l0003o^[Zj00?ooooo00Co0000
oooooooooooooooo0ol0000Looooo`?o00000_ooool01Ol0003ooooooooooooooooo000000Wooooo
0_l0000Cooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Jooooo`;o
00000_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`00000Aooooo`;o00002_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooooooo
ooooool000007Oooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000006ooo
ool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool001Cooooo
00?oMgMgolc<c?l000001?ooool01_l@413ooooooooooooooooo410@o`0001cooooo00?o^[Zjob4Q
8Oooool00_ooool01Ol@413ooooooooooooooooo410@00;ooooo0_l0000Gooooo`?o000000?ooooo
o`000?ooool00_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41006Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@01?ooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool07?ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41007?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41003_oo
ool001Cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So000001[ooooo00Go
410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool3o`00017o
oooo1?l000001?nj^[[ooooooiRHV?l@4103ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05?ooool00ol0003oooooooooo`03ooooo`05o`00
0?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@oiRH
V?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07?ooool00oo^k^koA4A4o`00
0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool001Gooooo00?oMgMgo`000?ooool00ooo
ool01Oo^k^ko<S8bo`000?lb<S;o000001[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01oooool5o`0000Oooooo1Ol00003ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?o0000ooooooooool03?oo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo01oooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01Gooooo00?o0000ooooooooool00_ooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00kooooo000Nooooo`03o`000?oooooooooo03;ooooo2?l0000Rooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool01?ooool2o`0004;ooooo00?o0000ooooooooool0
K?ooool001kooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`1[ooooo`007Oooool0
0ol0003oooooooooo`1Nooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`13ooooo`03o`000?oooooooooo02Oooooo2?l0000kooooo`007Oooool00ol0
003oooooooooo`1Oooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`14ooooo`03o`000?oooooooooo02?ooooo0ol00008ooooo`03o`000?oooooooooo
03Sooooo000Mooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo03Oooooo000Foooooooo0000@?l0000Cooooo`005_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`;o
00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool01?l0003oooooo`000?l00004ooooo`03o`000?oooooooooo00Gooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool0
01Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
00cooooo00Go0000ooooooooooooooooo`00000Sooooo`03o`000?oooooooooo017ooooo000Koooo
o`03o`000?oooooooooo06Cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo04Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo03Cooooo000Kooooo`03o`000?oooooooooo06Gooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04Wooooo0_l0000Hooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0<oooool001[ooooo00?o0000ooooooooool0
Ioooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00_ooooo0_l0001<ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0booooo`006_oo
ool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0booooo`006_ooool00ol0003oooooooooo`1Xooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0aooooo`006Oooool00ol0
003oooooooooo`1Yooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`1>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0aooooo`006Oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1?ooooo`;o00003?ooool2o`0001ko
oooo00?o0000ooooooooool0<?ooool001Sooooo00?o0000ooooooooool0K?ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo00kooooo0_l0001Booooo`03o`000?oooooooooo00Oooooo
0_l0000Pooooo`03o`000?oooooooooo033ooooo000Hooooo`03o`000?oooooooooo06cooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05;ooooo0ol0
0002ooooo`Co00008oooool00ol0003oooooooooo`0_ooooo`006?ooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1D
ooooo`Co00009_ooool00ol0003oooooooooo`0_ooooo`005oooool00ol0003oooooooooo`1^oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1ooooo
o`03o`000?oooooooooo02kooooo000Gooooo`03o`000?oooooooooo06oooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo07oooooo00?o0000oooooooo
ool0;_ooool001Oooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo013ooooo0_l00020ooooo`03o`000?oooooooooo02kooooo000Fooooo`03o`000?oo
oooooooo077ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo083ooooo00?o0000ooooooooool0;Oooool001Kooooo00?o0000ooooooooool0LOooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0P?ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo017ooooo002;ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool04Oooool008_ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0Aooooo`00S?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01?ooooo
0_l00022ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool04_ooool008cooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo087ooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0Booooo`00SOooool00ol0003oooooooooo`02
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@04o`000?ooooooooooooooo`Go0000
1?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0POooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo01;ooooo002=ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03ob4Q8Ol0003ooooo00?ooooo00GoV9RHob4Q8Oo^
k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0P_ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo01;ooooo002>ooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?oV9RHob4Q
8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08;ooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0Cooooo`00S_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03oiRHV?lQ8B7ok^k^
00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0008;ooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0Cooooo`00Soooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool04oooool0093ooooo00?o0000ooooool@41000oooool00ol@413oooooooooo`02oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo08?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Coooo
o`00TOooool01_l0003oMgMgoiRHV?ooooooV9RHogMgM`?ooooo00?o0000ooooooooool01Oooool0
1Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`23ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05?ooool009;ooooo0ol00000
0olb<S;ok^k^ooooo`02o`0000Sooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_oo
ool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05?oo
ool009?ooooo0_l000001?oooooo0000o`000?l0000Looooo`;o0000QOooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo01Cooooo002Eooooo`;o00007_ooool00ol0003oooooooooo`24
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool05?ooool00;Gooooo00?o0000oooo
ooooool0Q?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Gooooo002eooooo`03
o`000?oooooooooo08Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Eooooo`00
]Oooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
5Oooool00;Gooooo0_l00026ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05Ooo
ool00;Gooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo01Kooooo002eooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`00]Oooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool05_ooool00;Gooooo0_l00027ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool05_ooool00;Gooooo00?o0000ooooooooool0Qoooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo01Oooooo002eooooo`03o`000?oooooooooo08Oooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0Gooooo`00]Oooool00ol0003oooooooooo`27oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool05oooool00;Gooooo00?o0000oooooooo
ool0Qoooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Sooooo002eooooo`;o0000
ROooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Sooooo002eooooo`03o`000?oo
oooooooo08Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Hooooo`00]Oooool0
0ol0003oooooooooo`28ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06Oooool0
09[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo01Wooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool06Oooool009[ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oo
oooooooo00?ooooo0ol0002:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06_oo
ool009[ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0R_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01[ooooo002J
ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool0Roooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01_ooooo
002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo08cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Looooo`00V_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`2<ooooo`;o00000_ooool00ol0003oooooooooo`0Mooooo`00V_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000S_ooool4o`0001oooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo
00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
/?ooool009;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Ol0003ooooooooo
oooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`?o0000
/?ooool009;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05oa0@
4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006oooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo
00?o0000ooooooooool0/?ooool00:_ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oo
oooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool0
0:gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003o
ooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000ooooooooool0^?ooool00:gooooo00?o
0000ooooooooool0^?ooool00:gooooo00?o0000ooooooooool0^?ooool00:_ooooo00?oEEEEofIV
I_l00000^_ooool00?ooooooJOooool00:oooooo00?o0000okZj^_ooool0]_ooool00:oooooo0_lb
<S:gooooo`00P?ooool2o`000006oa0@4?oooooooooooa0@4?l0003o410@5oooool5o`0000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0
003oA4A4okZj^P0Hooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1hooooo`00POooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Oooooo1_l00009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o
^[Zjonk^k_mgMgOo410@00Wooooo1_l00009ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool0
1OlQ8B7oV9RHoooooonHV9So8B4Q00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1hooooo`00POoo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Oooooo00?oV9RHob4Q8Oo^k^h01?oo
ool01Ol@413ooooooooooooooooo410@01;ooooo00?o0000ooooooooool07_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo
07Kooooo0021ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000_ooooo00?oV9RH
ob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool02ooo
ool6o`0000cooooo00?oZJVYoa0@4?ooool00_ooool01Olb<S;oV9RHoooooonHV9So<S8b00?ooooo
00Go0000ooooooooooooooooo`00001hooooo`00POooool01_l0003ogMgMoc8b<_mEEEGogMgMo`00
01_ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000
ooooooooool07?ooool00ol@413o0000okZj^P03ooooo`05olc<c?l0003o0000o`000?o<c<`00ooo
ool01Ol0003ooooooooooooooooo000007Sooooo0021ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo
00007?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool03_ooool00ol@
413o0000o`000003o`0001cooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413o^[Zjoooooonj^[[o
410@00?ooooo00Go410@oooooooooooooooooa0@401hooooo`00POooool01_l0003o<S8boooooooo
oooo<S8bo`0001Sooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL04_ooool00ol0003oooooooooo`0Jooooo`05oa0@4?nHV9SooooookZj^_l000000oooool0
1Ol0003o^[Zjoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1hooooo`00P?oo
ool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Oooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Jooooo`05
ojVYZOl@413o0000oa0@4?nYZJT00oooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP1hooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(390) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .3798 m
.00942 .34723 L
.01975 .31743 L
.02496 .30516 L
.03053 .29418 L
.03575 .28587 L
.04057 .27977 L
.04628 .27426 L
.05248 .26995 L
.05794 .26723 L
.06073 .26613 L
.06373 .26515 L
.06644 .26441 L
.06891 .26387 L
.0701 .26365 L
.0714 .26345 L
.07261 .26329 L
.07376 .26317 L
.07446 .2631 L
.07522 .26305 L
.07653 .26299 L
.07728 .26297 L
.07807 .26297 L
.07875 .26298 L
.07949 .263 L
.08082 .26307 L
.08156 .26313 L
.08224 .2632 L
.08357 .26336 L
.08481 .26355 L
.08721 .26401 L
.08986 .26468 L
.09522 .26645 L
.10485 .27049 L
.12665 .27926 L
.14605 .28667 L
.15136 .28859 L
.15428 .28951 L
.15704 .29026 L
.15961 .29084 L
.16097 .29109 L
.1624 .29131 L
.16361 .29147 L
.16493 .29161 L
.16614 .2917 L
.16727 .29176 L
.16857 .29179 L
.16931 .2918 L
.16999 .2918 L
.17124 .29177 L
Mistroke
.17257 .29171 L
.17388 .29162 L
.17511 .29152 L
.17741 .29126 L
.18265 .29048 L
.18831 .28942 L
.21047 .2837 L
.23103 .27537 L
.24192 .27149 L
.24802 .26989 L
.25357 .26879 L
.25886 .26801 L
.26185 .26766 L
.26461 .26741 L
.26702 .26725 L
.2684 .26718 L
.26968 .26714 L
.27103 .26711 L
.27227 .26711 L
.27363 .26713 L
.27431 .26715 L
.27506 .26718 L
.27641 .26725 L
.27769 .26736 L
.27884 .26747 L
.28008 .26763 L
.28287 .26809 L
.28544 .26867 L
.29013 .27014 L
.29509 .27229 L
.30028 .27522 L
.30503 .27849 L
.31568 .28785 L
.32556 .29921 L
.33493 .31271 L
.35403 .34761 L
.36491 .36878 L
.37514 .38619 L
.38 .39282 L
.38511 .39828 L
.38779 .40041 L
.38921 .40133 L
.39073 .40213 L
.39212 .40271 L
.39339 .4031 L
.39467 .40336 L
.39588 .40349 L
.39715 .40349 L
.39787 .40343 L
.39855 .40333 L
Mistroke
.39991 .40302 L
.40068 .40278 L
.40138 .40252 L
.40398 .40119 L
.40645 .39943 L
.41194 .39392 L
.41793 .38576 L
.44033 .34558 L
.46062 .31093 L
.4708 .29692 L
.4818 .28509 L
.49218 .27692 L
.50173 .27122 L
.51128 .26652 L
.52151 .2624 L
.52739 .26057 L
.53274 .25928 L
.53812 .2583 L
.54321 .25757 L
.56236 .25499 L
.5676 .25423 L
.57036 .25387 L
.57326 .25354 L
.57581 .25331 L
.57715 .25321 L
.57859 .25312 L
.57992 .25305 L
.58113 .25301 L
.58234 .25298 L
.58348 .25296 L
.58468 .25296 L
.586 .25297 L
.58738 .25299 L
.58867 .25302 L
.59098 .25311 L
.59345 .25322 L
.60426 .25374 L
.60981 .25391 L
.61285 .25399 L
.61571 .25407 L
.61839 .25418 L
.6199 .25426 L
.62128 .25435 L
.62374 .25455 L
.62632 .25484 L
.62895 .25522 L
.6314 .25566 L
.63697 .25697 L
.64857 .2608 L
.65869 .26477 L
Mistroke
.66968 .26979 L
.6807 .27657 L
.69111 .28515 L
.71061 .30422 L
.73102 .32455 L
.74186 .33466 L
.74783 .3392 L
.75078 .34101 L
.75351 .34238 L
.75609 .34339 L
.75753 .34382 L
.75883 .34414 L
.76027 .3444 L
.76108 .3445 L
.76183 .34458 L
.7632 .34465 L
.76389 .34465 L
.76465 .34464 L
.76598 .34455 L
.76719 .34441 L
.76786 .34431 L
.76859 .34418 L
.76991 .3439 L
.77247 .34319 L
.77483 .34235 L
.77944 .34028 L
.78452 .33743 L
.79482 .33009 L
.81683 .30843 L
.82647 .29861 L
.83157 .29414 L
.83702 .29012 L
.84238 .28697 L
.84726 .28475 L
.84961 .28388 L
.85217 .28307 L
.85456 .28244 L
.8568 .28197 L
.85811 .28175 L
.8593 .28158 L
.86063 .28144 L
.86136 .28138 L
.86206 .28134 L
.86344 .2813 L
.86472 .28132 L
.86546 .28136 L
.86613 .28141 L
.86691 .28148 L
.86763 .28158 L
.86885 .28178 L
Mistroke
.87014 .28206 L
.87244 .28275 L
.87491 .28378 L
.87763 .28529 L
.88027 .28718 L
.88314 .28971 L
.88836 .2957 L
.89345 .3033 L
.89814 .31188 L
.9088 .33683 L
.92011 .37134 L
.93021 .40758 L
.94082 .4459 L
.94521 .45963 L
.94989 .47165 L
.95258 .477 L
.95502 .48073 L
.9562 .48212 L
.95748 .48331 L
.95868 .48413 L
.95979 .48463 L
.96091 .48486 L
.96211 .48483 L
.96324 .48453 L
.96428 .48402 L
.96549 .48315 L
.9668 .48186 L
.9692 .47866 L
.97171 .47418 L
.97437 .46826 L
.97915 .45506 L
1 .3798 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool05?ooool:o`0009;o
oooo002eooooo`03o`000?oooooooooo00kooooo1_l0000:ooooo`[o0000R?ooool00;Gooooo00?o
0000ooooooooool01oooool7o`0001[ooooo0ol00025ooooo`00;_ooool2o`0008Gooooo0_l00004
ooooo`Co00009?ooool4o`00087ooooo000Yooooo`Go000000?oooooo`000?l000000ol00021oooo
o`04o`000?ooooooooooooooo`;o0000;?ooool2o`0007oooooo000Eooooo`;o000000Wo410@oooo
ooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h01oooool2o`0000_ooooo0ol00003ooooo`05oiRH
V?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo4?l0000Ioooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQkooooo00Co0000ooooool0003o
00007_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`;o00004_oo
ool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05oiRHV?l@413o0000oc8b<_o<
c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo0_l000002Ol@413ooooooooooooooooo
k^k^oc8b<_l0003o<S8bonk^kP0>ooooo`005_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2o`00013ooooo0_l000001_oooooo410@okZj^_ooooooMgMgoc8b
<P?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`Go000000WoA4A4ooooooooooooooooogMg
MonHV9SooooooiRHV?mgMgL00oooool3o`0001Sooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg01gooooo0ol0000Rooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`08ooooo`;o00004?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0Kooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOo
V9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00kooooo000;ooooo`Ko00000_ooool5o`0000?ooooo00Go410@oooooooooooooooooa0@4004
ooooo`03o`000?oooooooooo00_ooooo1_l000001?oooooo0000o`000?l00002ooooo`05o`000?oo
ooooooooooooool@41000oooool00ol@413oooooooooo`0Aooooo`Oo00000_ooool00onHV9So8B4Q
onk^kP04ooooo`05oa0@4?ooooooooooooooool@41001_ooool2o`0000_ooooo1_l00005ooooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Looooo`03o`000?oooooo0000
02?ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00[ooooo00?o0000
ooooooooool03_ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41007ooo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool06Oooool5o`0000?ooooo
00Go410@oooooooooooooooooa0@400>ooooo`004oooool01?m4A4CogMgMooooool00004ooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Eooooo`;o000000Go410@oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo01?ooooo0_l00006ooooo`03oiRHV?lQ8B7o
k^k^00?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001_ooooo00?o0000ooooooooool0
0_l0000Rooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`;o
00003oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000007_ooool00onY
ZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000006oooool01?m4A4CogMgMooooool0
0004ooooo`05o`000?ooooooooooooooool000003_ooool001?ooooo00CogMgMoeEEEOoooooo0000
1?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool05_ooool00ol@413o
0000o`000002o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool04Oooool2o`0000Wo
oooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000006_ooool0
1Ol0003ooooooooooooooooo000002?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000gooooo00?o0000ooooooooool03Oooool00omgMgOoIVIVooooo`02ooooo`05o`00
0?ooooooooooooooool000007Oooool4o`0000;ooooo00Go0000ooooooooooooooooo`00000Koooo
o`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`005?ooool0
0omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41000_ooool00ol0003ooooooooo
o`0Hooooo`04okZj^_lQ8B7oooooooooo`?o00000_ooool00ol@413oooooooooo`0>ooooo`?o0000
3?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool02?ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Ioooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`0=ooooo`05o`000?oooooo
ooooooooool@41000oooool00ol@413oooooooooo`0Gooooo`Co000000CooooookZj^_lQ8B7ooooo
0_l000001Ol@413ooooooooooooooooo410@01cooooo00?oMgMgolc<c?l000001?ooool01Ol@413o
oooooooooooooooo410@00kooooo000Dooooo`03onk^k_m4A4Co000000Cooooo00OoMgMgoiRHV?oo
ooooV9RHogMgMooooooo000001Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonH
V9So0000o`000?mgMgL03Oooool3o`0000_ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Hooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03ooo
ool00ol0003oooooooooo`08ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RH
oooooonHV9SoMgMg01Oooooo0_l00002ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool2o`00
0003oooooonHV9SoMgMg01cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00kooooo000Eooooo`03ogMgMol0003ooooo00?ooooo00Kok^k^oc8b<_l0003o<S8bonk^k_l0
000Iooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01?o^k^ko<S8bo`000?lb<S84o`0000Co
oooo1_l0000>ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00_ooooo00?o0000ooooooooool03_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h05oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01oooooo00?o
EEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^013ooooo00?o0000ooooooooool0
1oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Eoooo
o`;o00001?ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0Mooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`007ooo
ool00ol0003oooooooooo`0Xooooo`Co0000;Oooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo00Gooooo0_l0000mooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0eooooo`007oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooo
oooo02gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0dooooo`007oooool00ol0
003oooooooooo`1Kooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0nooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0dooooo`007_ooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo02_o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0cooooo`007_ooool00ol0003ooooo
ooooo`1Mooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`10ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0cooooo`005_ooooooo`00043o00004oooool001Kooooo00?o0000ooooooooool01?ooool2
o`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00007oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo017ooooo000Fooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0Aooooo`007?ooool00ol0003oooooooooo`1Rooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`14ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0`ooooo`007?oo
ool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0`ooooo`006oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool03?ooool2o`0004Oooooo0_l0000Eooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool0<?ooool001_ooooo00?o0000ooooooooool0I?ooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0B?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0;oooool001_o
oooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0>ooooo`;o00008_ooool00ol0003o
ooooooooo`0_ooooo`006_ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo00_ooooo
0_l0000Tooooo`03o`000?oooooooooo02oooooo000Jooooo`03o`000?oooooooooo06Oooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04_ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02kooooo000J
ooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0?
ooooo`;o0000COooool2o`0000Oooooo0_l0000Xooooo`03o`000?oooooooooo02kooooo000Ioooo
o`03o`000?oooooooooo06Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo04kooooo1ol0000[ooooo`03o`000?oooooooooo02gooooo000Iooooo`03
o`000?oooooooooo06[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo083ooooo00?o0000ooooooooool0;Oooool001Wooooo00?o0000ooooooooool0
J_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
P?ooool00ol0003oooooooooo`0]ooooo`006Oooool00ol0003oooooooooo`1[ooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`21ooooo`03o`000?oo
oooooooo02cooooo000Hooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0Aooooo`;o0000P_ooool00ol0003oooooooooo`0/ooooo`006?ooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`21ooooo`03o`000?oooooooooo02cooooo000Hooooo`03o`000?oooooooooo06ko
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo08;o
oooo00?o0000ooooooooool0:oooool001Oooooo00?o0000ooooooooool0Koooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0P_ooool00ol0003ooooo
ooooo`0[ooooo`005oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo02_ooooo000G
ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0D
ooooo`;o0000Q?ooool00ol0003oooooooooo`0Zooooo`005oooool00ol0003oooooooooo`1aoooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`23oooo
o`03o`000?oooooooooo02[ooooo000Fooooo`03o`000?oooooooooo07;ooooo00?o0000oooooooo
ool01?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o8B4Qo`000?ooool00oooool5o`00
00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo08?ooooo00?o0000
ooooooooool0:_ooool001Kooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003o8B4Qooooo`03ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo08Cooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`0Aooooo`00S?ooool00ol0003oooooooooo`03
ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`04ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`24ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool04Oooool008gooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool01_ooool00onHV9So8B4Qonk^
kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00024ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool04Oooool008kooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000002_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool04_ooool008oooooo00Co0000oooooooooooo410@0oooool01?l@413oooooooooool0000<oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`25oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool008oooooo00[o0000oooooooo
ooooMgMgoiRHV?ooooooV9RHogMgMooooooo00002Oooool01Ol0003o^[ZjoooooonHV9So410@00Co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool04_ooool0093ooooo0_l000001?o^k^ko<S8bo`000?lb<S82o`0000[o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`25oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool009;ooooo1?l0000Oooooo`;o
0000Q_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo002eooooo`03o`00
0?oooooooooo08Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Cooooo`00]Ooo
ool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04ooo
ool00;Gooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo01Cooooo002eooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Dooooo`00]Oooool2o`0008Sooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0Dooooo`00]Oooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool05Oooool00;Gooooo00?o0000ooooooooool0Qoooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo01Gooooo002eooooo`03o`000?oooooooooo08Oooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0Eooooo`00]Oooool2o`0008Wooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0Fooooo`00]Oooool00ol0003oooooooooo`28ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool05_ooool00;Gooooo00?o0000ooooooooool0
R?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Kooooo002eooooo`03o`000?oo
oooooooo08Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Fooooo`00]Oooool0
0ol0003oooooooooo`29ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05oooool0
0;Gooooo0_l0002:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05oooool00;Go
oooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Oo
oooo002eooooo`03o`000?oooooooooo08[ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Hooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool06?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo08_ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Hooooo`00V_ooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool00oooool3o`0008_ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Hooooo`00V_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool06Oooool009[ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool06Oooool009[ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
01Wooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo08cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Joooo
o`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000S_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo01_ooooo002eooooo`03o`000?oooooooooo08ko
oooo00Co0000oooooooooooo00007_ooool00;Gooooo00?o0000ooooooooool0Soooool3o`0001ko
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0/?ooool009;ooooo00Go410@oooooooooooooooooa0@400=
ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2`
ooooo`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool0
0omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oo
oooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgoooo
o`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00:_ooooo1?l000000ol@
413oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0/?ooool00:gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000
ooooooooool0^?ooool00:gooooo00?o0000ooooooooool0^?ooool00:gooooo00?o0000oooooooo
ool0^?ooool00:_ooooo00?oEEEEofIVI_l00000^_ooool00?ooooooJOooool00:oooooo00?o0000
okZj^_ooool0]_ooool00:oooooo0_lb<S:gooooo`00P?ooool2o`000006oa0@4?oooooooooooa0@
4?l0003o410@5oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`03ohN7Qol0
003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`05oiRHV?l@413o0000oc8b<_o<
c<`00oooool01?l@413o0000odA4A?o<c<`4ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0N?ooool0
087ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00002Oooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03olc<c?l0
003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002Oooool01Ol@413o^[Zj
oooooomgMgOo<S8b00Gooooo00?oV9RHoa0@4?oMgMd00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
07Sooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05oooool00onHV9So
8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41004_ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo00Cooooo00?oQhN7oeEEEOooool00_ooool01Ol@413ooooooooooooooooo
410@07Sooooo0021ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000_ooooo00?o
V9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool0
2oooool6o`0000cooooo00?oZJVYoa0@4?ooool00_ooool01Oo<c<co8B4Qo`000?mEEEGo000000?o
oooo00Go0000ooooooooooooooooo`00001hooooo`00POooool01_l0003ogMgMoc8b<_mEEEGogMgM
o`0001_ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000001;ooooo00?o
0000ooooooooool07?ooool00ol@413o0000okZj^P03ooooo`05ob4Q8On7QhOooooooiRHV?l00000
0oooool01Ol0003ooooooooooooooooo000007Sooooo0021ooooo`06o`000?n7QhOoZJVYokZj^_mE
EEGo00007?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool03_ooool0
0ol@413o0000o`000003o`0001cooooo00?o^[Zjob4Q8Oooool00_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go410@oooooooooooooooooa0@401hooooo`00POooool01_l0003o<S8boooo
oooooooo<S8bo`0001Sooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL04_ooool00ol0003oooooooooo`0Jooooo`05oa0@4?nHV9SooooookZj^_l000000ooo
ool01OlQ8B7oV9RHoooooomgMgOoEEEE00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1hooooo`00
P?ooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Oooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Joooo
o`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo<c<co410@o`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP1hooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(400) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .39813 m
.00942 .36403 L
.01975 .33276 L
.02496 .32021 L
.03053 .30915 L
.04057 .29445 L
.04628 .28845 L
.05248 .28346 L
.05532 .28165 L
.05833 .28006 L
.06093 .27894 L
.06237 .27843 L
.06373 .27801 L
.06503 .27768 L
.06644 .27738 L
.06772 .27717 L
.06891 .27703 L
.07014 .27693 L
.07126 .27689 L
.07255 .27689 L
.07376 .27693 L
.07511 .27703 L
.07578 .27709 L
.07653 .27718 L
.07907 .27758 L
.08204 .27822 L
.08481 .27893 L
.10438 .28445 L
.12566 .28897 L
.13128 .29016 L
.13436 .29075 L
.13725 .29123 L
.1397 .29154 L
.14108 .29168 L
.14234 .29177 L
.14365 .29184 L
.14439 .29187 L
.14508 .29188 L
.14581 .29188 L
.14648 .29187 L
.14724 .29185 L
.14796 .29182 L
.14918 .29174 L
.15053 .29162 L
.15193 .29145 L
.15324 .29126 L
.1581 .29028 L
.1634 .28882 L
.16909 .28702 L
.18983 .2804 L
Mistroke
.21243 .27143 L
.22292 .2674 L
.22595 .2665 L
.22879 .26578 L
.23137 .26523 L
.2341 .26474 L
.2365 .2644 L
.23913 .26408 L
.24375 .26366 L
.24915 .26331 L
.25159 .26318 L
.25418 .26306 L
.25548 .26302 L
.25618 .26299 L
.25692 .26297 L
.25823 .26295 L
.25945 .26294 L
.26015 .26294 L
.26091 .26294 L
.26171 .26295 L
.26245 .26297 L
.26377 .26302 L
.26451 .26305 L
.26518 .26309 L
.26652 .26319 L
.26776 .26331 L
.27054 .26368 L
.273 .26414 L
.27559 .26478 L
.2804 .26638 L
.28488 .26838 L
.29509 .27454 L
.30605 .28324 L
.31643 .29365 L
.32576 .30551 L
.33591 .32156 L
.35624 .35943 L
.36704 .37832 L
.37272 .38674 L
.3787 .39398 L
.38125 .39645 L
.38398 .39864 L
.38555 .39966 L
.38698 .40044 L
.38843 .40108 L
.38977 .40153 L
.39099 .40182 L
.39228 .402 L
.39357 .40205 L
.39431 .40202 L
Mistroke
.395 .40195 L
.39624 .40173 L
.39738 .40143 L
.39869 .40095 L
.39994 .40037 L
.40233 .39893 L
.40489 .39692 L
.40948 .39218 L
.41989 .37718 L
.44088 .33965 L
.45192 .32087 L
.46358 .30362 L
.47403 .29102 L
.4855 .28035 L
.49593 .27294 L
.50567 .26744 L
.51665 .26263 L
.52705 .25936 L
.53639 .25724 L
.54654 .25533 L
.5517 .25445 L
.55726 .25358 L
.56216 .25294 L
.56483 .25266 L
.56732 .25245 L
.56993 .25228 L
.57132 .25221 L
.57279 .25216 L
.57415 .25212 L
.57542 .2521 L
.57657 .25209 L
.57781 .25209 L
.57853 .25209 L
.5792 .2521 L
.57994 .25211 L
.58074 .25212 L
.58235 .25215 L
.58383 .25219 L
.58938 .25238 L
.59441 .25258 L
.59976 .2528 L
.60236 .25293 L
.60481 .25308 L
.60937 .25344 L
.61203 .25373 L
.61483 .25411 L
.61985 .25503 L
.62524 .25638 L
.63115 .25827 L
.65169 .26705 L
Mistroke
.6632 .27365 L
.67367 .2816 L
.69546 .30324 L
.71559 .32387 L
.72569 .33328 L
.73063 .33728 L
.73516 .34037 L
.73991 .34285 L
.74117 .34335 L
.74254 .34383 L
.74382 .3442 L
.74503 .34448 L
.74572 .34461 L
.74646 .34473 L
.74776 .34487 L
.7485 .34492 L
.74928 .34494 L
.74994 .34494 L
.75067 .34492 L
.75198 .34482 L
.75271 .34473 L
.75338 .34463 L
.75468 .34438 L
.75591 .34408 L
.75839 .3433 L
.76072 .34235 L
.76604 .33956 L
.7768 .33178 L
.79614 .31294 L
.81553 .29169 L
.82652 .28204 L
.83188 .27836 L
.83675 .27555 L
.84163 .27318 L
.84692 .27104 L
.84983 .27006 L
.85251 .26931 L
.85507 .26873 L
.85649 .26848 L
.85778 .26829 L
.85913 .26815 L
.86041 .26807 L
.86176 .26804 L
.86252 .26806 L
.86323 .26809 L
.86453 .26819 L
.8657 .26834 L
.86706 .26858 L
.86833 .26888 L
.87124 .26983 L
Mistroke
.87391 .27105 L
.87684 .27278 L
.87994 .27506 L
.88515 .28 L
.88991 .28568 L
.90059 .30276 L
.91048 .32487 L
.91985 .35249 L
.93939 .42556 L
.94455 .44419 L
.9501 .46146 L
.95265 .46805 L
.95534 .47389 L
.95763 .47791 L
.95892 .47975 L
.96014 .4812 L
.96133 .48236 L
.96263 .48331 L
.9638 .48388 L
.96489 .48417 L
.96606 .48423 L
.96735 .48399 L
.9687 .48339 L
.96996 .48251 L
.97114 .48143 L
.97226 .48016 L
.97437 .47717 L
.97909 .46778 L
.98429 .45377 L
.9891 .43818 L
1 .39813 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool03_oooolCo`0008oo
oooo002eooooo`03o`000?oooooooooo00[ooooo1?l0000Cooooo`Ko0000ROooool00;Gooooo00?o
0000ooooooooool01?ooool6o`0001gooooo0_l00027ooooo`00Ioooool4o`0004[ooooo0_l00002
ooooo`?o00009Oooool2o`0008Gooooo001Oooooo`Wo00000_ooool5o`0004Kooooo00Co0000oooo
oooooooo0000:_ooool2o`0008?ooooo000Eooooo`;o000000Wo410@ooooooooooooooooonk^k_lb
<S;o0000oc8b<_o^k^h06_ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0Dooooo`Co00000oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
o`0001Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^7_ooool3o`0001oo
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0_ooool2o`0001Kooooo1Ol0
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool6o`0000;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0Mooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h03_oo
ool001Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00Go
410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04Oooool3o`0000Oo
oooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool2
o`0001Wooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1?ooool2o`0001Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL06Oooool2o`000006oa0@4?nj^[[oooooogMgMolb<S;ooooo0_l000001OmgMgOoV9RHoooo
oonHV9SoMgMg01kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00ko
oooo000;ooooo`Ko00000_ooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Booooo`Ko
00001_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool03?ooool3o`00
00;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4005
ooooo`03o`000?oooooooooo00_ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Looooo`?o00008oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41001_ooool2o`0001?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooo
oooooooooooo410@01Kooooo0ol00006ooooo`04o`000?ooooooooooooooo`;o00000_ooool00ol@
413oooooooooo`0Iooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00kooooo000Coooo
o`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000:ooooo`Oo00003?oo
ool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000003?ooool2o`0000oooooo
00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000006_ooool2o`00
00;ooooo0_l0000Rooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000008
ooooo`03o`000?oooooooooo017ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooo
oooo000001Gooooo00?o0000ooooooooool01_ooool00onYZJWo410@ooooo`02ooooo`05o`000?oo
oooo0000ooooool000006oooool01?m4A4CogMgMooooool00004ooooo`05o`000?oooooooooooooo
ool000003_ooool001?ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo
000000Oooooo0ol00007ooooo`Co00001oooool00ol@413o0000okZj^P03ooooo`05o`000?oooooo
ooooooooool000002_ooool2o`0001;ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooo
oooooooo000000Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000006Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000oooo
ooooool04Oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000005?ooool0
0ol0003oooooooooo`06ooooo`03oa0@4?l0003o^[Zj00?ooooo00?o0000ooooooooool00_l0000K
ooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`005?oo
ool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooo
ooooo`0<ooooo`Go00000oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001oooool3o`0001Gooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo
00Kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41006?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00[ooooo00?o0000ooooooooool04Ooo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool04?ooool2o`0000[ooooo
00?o^[Zjob4Q8Oooool00_ooool01Ol@413oooooooooool0003o410@01cooooo00?oMgMgolc<c?l0
00001?ooool01Ol@413ooooooooooooooooo410@00kooooo000Dooooo`03onk^k_m4A4Co000000Co
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo01;ooooo0ol000000onj
^[[o0000ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool3o`0001Cooooo00Go0000
okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02Oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Gooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0003oooooooooo`0<ooooo`05o`000?nj^[[ooooo
oiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg017ooooo00?o0000ooooooooool01ooo
ool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHo`00000Looooo`03
onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`005Oooool00omgMgOo
0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool00ol0003oooooooooo`0Coooo
o`03ojVYZOl@413o000000Go000000Cok^k^oc8b<_l0003o<S8b1Ol0000Gooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00[ooooo00?o0000ooooooooool0
3oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h05_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01oooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00cooooo00?o0000ooooooooool02oooool01OnHV9So410@o`000?lQ8B7o
c<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0@ooooo`03o`000?oooooooooo00Sooooo00Go
ZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_l000007Oooool00omgMgOo
0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool002?ooooo00?o0000oooooooo
ool07?ooool5o`0003?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`06ooooo`;o
0000>Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool0<oooool002?ooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool0<_ooool002;ooooo00?o0000ooooooooool0E_oo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0>_oo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0<_oo
ool0027ooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool0<Oooool0023ooooo00?o0000ooooooooool0F_ooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0<Oooool001Ko
ooooool00010o`0001?ooooo000Fooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo017ooooo000Fooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Aooooo`007_ooool00ol0003oooooooooo`1Oooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`10ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0^ooooo`007_ooool0
0ol0003oooooooooo`1Pooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`11ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0^ooooo`007_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool03?ooool2o`0004?ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo02gooooo000Mooooo`03o`000?oooooooooo06;o
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04?o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02go
oooo000Mooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo02cooooo000Looooo`03o`000?oooooooooo06Cooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04Gooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02cooooo000L
ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo04Kooooo0_l0000;ooooo`03o`000?oooooooooo02_ooooo00?o0000
ooooooooool0;?ooool001cooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo013ooooo0_l00019ooooo`03o`000?oooooooooo00Kooooo0_l0000_oooo
o`03o`000?oooooooooo02_ooooo000Kooooo`03o`000?oooooooooo06Kooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04Wooooo0ol00002ooooo`?o
0000<Oooool00ol0003oooooooooo`0[ooooo`006oooool00ol0003oooooooooo`1Wooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1;ooooo`?o0000
=?ooool00ol0003oooooooooo`0[ooooo`006oooool00ol0003oooooooooo`1Wooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`23ooooo`03o`000?oo
oooooooo02[ooooo000Jooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool0:_ooool0
01[ooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
01?ooooo0_l00024ooooo`03o`000?oooooooooo02[ooooo000Jooooo`03o`000?oooooooooo06[o
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo08?o
oooo00?o0000ooooooooool0:_ooool001Wooooo00?o0000ooooooooool0Joooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0Q?ooool00ol0003ooooo
ooooo`0Yooooo`006Oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo02Wooooo000I
ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo08Cooooo00?o0000ooooooooool0:Oooool001Wooooo00?o0000oooo
ooooool0KOooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Kooooo0_l00025oooo
o`03o`000?oooooooooo02Wooooo000Hooooo`03o`000?oooooooooo06oooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo08Gooooo00?o0000oooooooo
ool0:?ooool001Sooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`04ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01?ooool00ol0003o8B4Qob4Q8@04ooooo`Go00001?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`0Xoooo
o`006?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`04ooooo`03o`000?lQ8B7o8B4Q00Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`0X
ooooo`005oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00?ooooo00Go410@oooo
oooooooooooooa0@4003ooooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h02Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool0:?ooool0
01Oooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooo
ooooool000000_ooool00ol0003oooooooooo`08ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMg
oc8b<_ooool01?ooool3o`0008Kooooo00?o0000ooooooooool09oooool001Oooooo00?o0000oooo
ooooool0Loooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool0
0ol0003oooooooooo`09ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool09oooool001Oooooo00?o0000
ooooooooool0M?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooool000003Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Q_oo
ool00ol0003oooooooooo`0Wooooo`005_ooool00ol0003oooooooooo`1fooooo`09o`000?oooooo
ooooogMgMonHV9SooooooiRHV?mgMgOo000000[ooooo00Go0000okZj^_ooooooV9RHoa0@4004oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`0Voooo
o`005_ooool00ol0003oooooooooo`1gooooo`;o000000?ok^k^oc8b<_l000000_l0000;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool0Qoooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo002Booooo`?o00008?ooool2o`0008So
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`00]Oooool00ol0003ooooo
ooooo`27ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00;Gooooo00?o
0000ooooooooool0R?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01;ooooo002e
ooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0B
ooooo`00]Oooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool04_ooool00;Gooooo0_l00029ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool04_ooool00;Gooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo01?ooooo002eooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0Cooooo`00]Oooool00ol0003oooooooooo`29ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool04oooool00;Gooooo0_l0002:ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool04oooool00;Gooooo00?o0000ooooooooool0ROooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo01Cooooo002eooooo`03o`000?oooooooooo08[ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Dooooo`00]Oooool00ol0003ooooooooo
o`2:ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05?ooool00;Gooooo00?o0000
ooooooooool0R_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Gooooo002eoooo
o`;o0000Roooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Gooooo002eooooo`03
o`000?oooooooooo08_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Eooooo`00
]Oooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
5_ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0Roooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo01Kooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool05oooool009[ooooo00Go410@oooooooooooooooooa0@400@ooooo`03
o`000?oooooooooo00?ooooo0ol0002<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool05oooool009[ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Oo
oooo002Jooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool0SOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
01Sooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo08gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Hoooo
o`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`2>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06Oooool009[o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`00093ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Iooooo`00]Oooool00ol0003oooooooooo`2?ooooo`;o
00000_ooool00ol0003oooooooooo`0Jooooo`00]Oooool00ol0003oooooooooo`2@ooooo`?o0000
7Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool009;ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@
00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
0;3ooooo002Booooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06oooo
o`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00T_ooool01Ol0003ooooooooooooooooo0000
00kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000
ooooooooool0/?ooool009;ooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOo
oooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002a
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Zoooool4o`000003
oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool00:gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo0ol0002`ooooo`00[Oooool00ol0
003oooooooooo`2hooooo`00[Oooool00ol0003oooooooooo`2hooooo`00[Oooool00ol0003ooooo
ooooo`2hooooo`00Zoooool00omEEEGoIVIVo`00002jooooo`00oooooomYooooo`00[oooool00ol0
003o^[Zjooooo`2fooooo`00[oooool2oc8b<[Oooooo0020ooooo`;o000000Ko410@oooooooooooo
410@o`000?l@410Gooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?oQhN7
o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01[ooooo0_l000002Ol@413ooooooooo
ooooooook^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0N?ooool0
087ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00002Oooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03olc<c?l0
003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
07Sooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05oooool00onHV9So
8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41004_ooool00ol0003oooooooooo`0Joooo
o`Go00000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
401hooooo`00POooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000;ooooo`03oiRH
V?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo00_o
oooo1_l00009ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool00000N?ooool0087ooooo00Ko0000omgMgOlb<S;oEEEEomgM
gOl0000Kooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00000Booooo`03
o`000?oooooooooo01[ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`00001hooooo`00POooool01_l0003oQhN7ojVYZOnj
^[[oEEEEo`0001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00ko
oooo00?o410@o`000?l000000ol0000Jooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooo
oooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100N?ooool0087ooooo00Ko0000oc8b
<_oooooooooooc8b<_l0000Hooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RH
oooooonHV9SoMgMg01;ooooo00?o0000ooooooooool06oooool00oo^k^koA4A4o`000004ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg07Sooooo0020oooo
o`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41005oooool01OnHV9So410@o`000?lQ8B7o
c<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Booooo`03o`000?oooooooooo01cooooo00?o
MgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP1hooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(410) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41613 m
.00942 .38536 L
.01975 .35602 L
.03053 .33234 L
.04057 .31615 L
.04632 .30915 L
.05176 .30399 L
.05664 .30056 L
.0594 .29909 L
.06194 .29801 L
.06467 .29712 L
.06722 .29651 L
.06869 .29625 L
.07003 .29605 L
.07159 .29587 L
.07304 .29574 L
.07444 .29564 L
.07593 .29556 L
.07758 .2955 L
.07907 .29545 L
.08181 .29538 L
.08481 .2953 L
.08746 .29519 L
.08993 .29506 L
.09533 .29468 L
.10502 .29387 L
.11624 .29324 L
.11892 .29311 L
.12177 .29294 L
.1242 .29275 L
.12688 .29246 L
.12942 .29209 L
.13216 .29158 L
.13711 .29031 L
.14292 .2883 L
.14825 .2861 L
.16773 .27828 L
.18929 .27089 L
.19979 .26662 L
.20476 .26479 L
.20934 .2634 L
.21411 .26233 L
.21663 .26193 L
.21929 .26161 L
.2216 .26141 L
.22376 .26128 L
.225 .26122 L
.22614 .26118 L
.22868 .2611 L
.23941 .2608 L
Mistroke
.2421 .2607 L
.24463 .2606 L
.24573 .26057 L
.2469 .26054 L
.24818 .26051 L
.24935 .2605 L
.25051 .2605 L
.25174 .26052 L
.25291 .26055 L
.25397 .2606 L
.25521 .26068 L
.25657 .2608 L
.25785 .26094 L
.25903 .2611 L
.2614 .26151 L
.26402 .26212 L
.26933 .26381 L
.27474 .26612 L
.28056 .26913 L
.2911 .27543 L
.30203 .28326 L
.31218 .29296 L
.32278 .30668 L
.33435 .32531 L
.35406 .3602 L
.36444 .37766 L
.37011 .38611 L
.3754 .39278 L
.37832 .39579 L
.38098 .39805 L
.38393 .39996 L
.38555 .40074 L
.38629 .40101 L
.3871 .40127 L
.38839 .40157 L
.38977 .40174 L
.39105 .40176 L
.39225 .40166 L
.39293 .40154 L
.39366 .40138 L
.39495 .40099 L
.39634 .40042 L
.39786 .39963 L
.40064 .39773 L
.40316 .39554 L
.40882 .3892 L
.41903 .37416 L
.44085 .3358 L
.45043 .31932 L
.46098 .3033 L
Mistroke
.47042 .29163 L
.48057 .28179 L
.4913 .27355 L
.50134 .2672 L
.51196 .26188 L
.51797 .25959 L
.52354 .25789 L
.53376 .25551 L
.54464 .2535 L
.5499 .25266 L
.55545 .25191 L
.55836 .25159 L
.55989 .25146 L
.56154 .25133 L
.56306 .25123 L
.56444 .25116 L
.56583 .2511 L
.56714 .25107 L
.56836 .25104 L
.5697 .25103 L
.57037 .25103 L
.5711 .25104 L
.57241 .25105 L
.57365 .25108 L
.57496 .25111 L
.57729 .25121 L
.58002 .25135 L
.58256 .25151 L
.58832 .25196 L
.59363 .25247 L
.59938 .25318 L
.60481 .25407 L
.60982 .25514 L
.61931 .25796 L
.62934 .26209 L
.63926 .26719 L
.64991 .27394 L
.66914 .29048 L
.6899 .31254 L
.70085 .32406 L
.71251 .33504 L
.71837 .33953 L
.72125 .34135 L
.72389 .34276 L
.72625 .3438 L
.72884 .34466 L
.73019 .345 L
.73144 .34524 L
.73277 .34541 L
.73351 .34547 L
Mistroke
.73419 .34551 L
.73543 .34552 L
.73676 .34546 L
.73789 .34534 L
.73914 .34515 L
.74047 .34486 L
.74191 .34447 L
.74451 .34356 L
.74961 .34103 L
.75428 .33799 L
.7742 .31976 L
.79596 .29482 L
.80659 .28359 L
.8166 .27508 L
.82815 .26771 L
.83314 .26515 L
.83862 .26273 L
.84392 .26083 L
.84646 .2601 L
.84887 .25955 L
.85018 .25931 L
.8516 .2591 L
.85289 .25895 L
.85409 .25886 L
.85538 .25882 L
.85612 .25881 L
.85681 .25882 L
.8582 .25889 L
.85898 .25895 L
.85969 .25903 L
.86082 .25919 L
.86203 .2594 L
.8642 .25992 L
.86679 .26073 L
.86914 .26167 L
.87426 .26436 L
.87909 .26769 L
.88929 .2774 L
.89443 .28391 L
.90009 .29264 L
.9101 .31301 L
.91946 .33843 L
.94037 .41075 L
.95066 .44491 L
.95568 .45838 L
.96022 .46791 L
.9625 .47157 L
.9637 .47316 L
.96496 .47458 L
.96607 .47561 L
Mistroke
.96729 .4765 L
.9684 .47707 L
.96943 .47742 L
.97071 .47759 L
.97191 .47748 L
.973 .47716 L
.97417 .47658 L
.97545 .47567 L
.97681 .4744 L
.97925 .47134 L
.9817 .4673 L
.98434 .46196 L
.98912 .45006 L
1 .41613 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool02_oooolDo`0009;o
oooo002eooooo`03o`000?oooooooooo00Kooooo1?l0000Dooooo`Go0000SOooool00;Gooooo00?o
0000ooooooooool00_ooool4o`0001gooooo0ol00016ooooo`Go0000?oooool005Wooooo4_l0001:
ooooo`;o000000?oooooo`000?l000009?ooool2o`00043ooooo1?l00005ooooo`?o0000??ooool0
05Kooooo0ol0000Booooo`Co0000A_ooool3o`0002Sooooo00?o0000ooooooooool0>oooool2o`00
00cooooo0_l0000jooooo`005Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb
<S;ok^k^01[ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03Oooool2o`0000cooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_l0000Joooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQgooooo0_l0000Qooooo`Co0000
00Go410@ooooooooooook^k^oc8b<P03o`0001[ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h04_ooool2o`0000Oooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_l0003o
0000oc8b<_o^k^h07Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
00kooooo000Fooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Joooo
o`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Wooooo1?l0
000>ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00;o
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL07?ooool00ol0003oooooo`00000Sooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`02o`0001Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL04Oooool00ol0003oooooooooo`07ooooo`05oa0@4?nj^[[oooooogMgMolb
<S800oooool01OmgMgOoV9RHo`000?nHV9SoMgMg01kooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko00000_ooool5o`0000?ooooo00Go410@oooo
oooooooooooooa0@400Booooo`Ko00001_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o
410@ooooooooool01?ooool3o`0000[ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go
410@oooooooooooooooooa0@4003ooooo`;o00003_ooool6o`0000Gooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@01[ooooo0_l00002ooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00;ooooo0_l0000Goooo
o`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400?ooooo`;o00003_ooool0
1Ol0003ooooooooooooooooo410@00;ooooo00?o0000oa0@4?ooool06_ooool5o`0000?ooooo00Go
410@oooooooooooooooooa0@400>ooooo`004oooool01?m4A4CogMgMooooool00004ooooo`05o`00
0?ooooooooooooooool000007Oooool00onYZJWo410@ooooo`02ooooo`05o`000?oooooooooooooo
ool000000oooool3o`0001Oooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo
000000Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000006Oooool00ol0003oooooooooo`02ooooo`;o00008_ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Eooooo`03oiRH
V?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00go
oooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000001_ooooo00CoA4A4omgM
gOoooooo00001?ooool01Ol0003ooooooooooooooooo000000kooooo000Cooooo`04omgMgOmEEEGo
ooooo`0000Cooooo00Go0000ooooooooooooooooo`00000Looooo`03oa0@4?l0003o^[Zj00?ooooo
00Ko0000ooooooooooooooooo`000?ooool2o`0001_ooooo00?oMgMgofIVI_ooool00_ooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000006?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo
00?o0000ooooooooool05Oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool0
00003Oooool00ol0003oooooooooo`0=ooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000oooooooo
ooooooooo`00000Kooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`00
000>ooooo`005?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41007Ooo
ool00onj^[[o8B4Qooooo`02ooooo`04oa0@4?ooooooooooooooo`;o00007_ooool01Ol0003ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool01Oooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Gooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41001_ooool00ol0003oooooooooo`0Eooooo`05o`000?ooooooooooooooool@41000ooo
ool00ol@413oooooooooo`0:ooooo`03o`000?oooooooooo00oooooo00?o^[Zjob4Q8Oooool00_oo
ool01_l@413ooooooooooooooooo410@o`0001_ooooo00?oMgMgolc<c?l000001?ooool01Ol@413o
oooooooooooooooo410@00kooooo000Dooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0Jooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHo`000?l0
003oMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01oooool00ol0003oooooooooo`0@
ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo
00?o0000ooooooooool03?ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00KoMgMgoiRHV?oo
ooooV9RHogMgMol0000Kooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0>ooooo`005Oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06_oo
ool01OnYZJWo410@o`000?l@413oZJVY00;ooooo1?l000000olb<S;ok^k^ooooo`0Jooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Wooooo00?o0000oooo
ooooool04?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h05Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo01oooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool03oooool01OnHV9So410@o`00
0?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`03o`000?oooooooooo00go
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`07onk^k_lb<S;o0000oc8b<_o^k^koooooo`00
000Kooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`00=_oo
ool;o`0003Sooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`07ooooo`;o0000=?oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0<Ooo
ool002[ooooo3?l00013ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0aooooo`00:?ooool2o`00053ooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo033ooooo000Wooooo`03o`000?oooooooooo057o
oooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo033o
oooo000Uooooo`;o0000EOooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool0;oooool001Koooooool00010o`0001?ooooo000Fooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`;o00001_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo017ooooo000Fooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Aooooo`008oooool00ol0003ooooooooo
o`1Hooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0]ooooo`008_ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo01Cooooo0_l0000[
ooooo`03o`000?oooooooooo02gooooo000Qooooo`03o`000?oooooooooo05cooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`0>ooooo`;o0000?_ooool2o`0001?ooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`0]ooooo`008Oooool00ol0003oooooooooo`1Looooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0/ooooo`00
8?ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`0/ooooo`007oooool00ol0003oooooooooo`1Oooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`11ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0/ooooo`007oooool0
0ol0003oooooooooo`1Pooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`11ooooo`03o`000?oooooooooo00Wooooo0_l0000cooooo`03o`000?oooooo
oooo02_ooooo000Nooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0@ooooo`;o0000@oooool2o`0000Sooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`0[ooooo`007_ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`14ooooo`?o00000oooool2o`0003Ko
oooo00?o0000ooooooooool0:oooool001gooooo00?o0000ooooooooool0I?ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0A_ooool4o`0003Wooooo
00?o0000ooooooooool0:_ooool001gooooo00?o0000ooooooooool0I?ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Poooool00ol0003ooooooooo
o`0Zooooo`007Oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo02[ooooo000Loooo
o`03o`000?oooooooooo06Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Coooo
o`;o0000QOooool00ol0003oooooooooo`0Yooooo`007?ooool00ol0003oooooooooo`1Wooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`24ooooo`03
o`000?oooooooooo02Wooooo000Kooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo08Cooooo00?o0000ooooooooool0
:Oooool001_ooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`0Yooooo`006oooool0
0ol0003oooooooooo`1Zooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`25ooooo`03o`000?oooooooooo02Sooooo000Jooooo`03o`000?oooooooooo
06_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Fooooo`;o0000Q_ooool00ol0
003oooooooooo`0Xooooo`006_ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo02So
oooo000Jooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool01Oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Cooooo00?o0000ob4Q8OlQ8B401?ooool5o`0000Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool09oooool001Wo
oooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`05ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01?l0003oooooob4Q8OlQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool09ooo
ool001Wooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`04ooooo`05oa0@4?oooooo
ooooooooool@41000_ooool00ol0003oooooooooo`07ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo02Oooooo000I
ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooo
oooo000000;ooooo00?o0000ooooooooool02?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol00027ooooo`03o`000?oooooooooo02Kooooo000Iooooo`03o`000?oooooo
oooo073ooooo00?o0000ooooooooool00oooool01ol0003ooooooooooooooooo0000ooooool00000
3?ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003o
ooooooooo`27ooooo`03o`000?oooooooooo02Kooooo000Hooooo`03o`000?oooooooooo07;ooooo
00?o0000ooooooooool00_ooool01_l@413ooooooooooooooooo410@o`0000kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo08Oooooo00?o0000oooo
ooooool09_ooool001Sooooo00?o0000ooooooooool0Loooool2o`0000;ooooo00?oMgMgoiRHV?oo
ool00_l0000;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo08Oooooo00?o0000ooooooooool09_ooool001Sooooo00?o0000oooooooo
ool0MOooool2o`000005onk^k_l0003o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7o
c<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool09Oooool0
01Oooooo00?o0000ooooooooool0Moooool3o`00027ooooo0_l00029ooooo`03o`000?oooooooooo
02Gooooo000Gooooo`03o`000?oooooooooo09_ooooo00?o0000ooooooooool0R?ooool00ol0003o
ooooooooo`0Uooooo`005oooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo08Wooooo
00?o0000ooooooooool09?ooool001Kooooo00?o0000ooooooooool0W?ooool00ol0003ooooooooo
o`29ooooo`03o`000?oooooooooo02Cooooo000Fooooo`03o`000?oooooooooo09cooooo00?o0000
ooooooooool0ROooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo002eoooo
o`;o0000R_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo002eooooo`03
o`000?oooooooooo08[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Aooooo`00
]Oooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
4_ooool00;Gooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo01;ooooo002eooooo`;o0000S?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo01;ooooo002eooooo`03o`000?oooooooooo08_ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0Cooooo`00]Oooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool04oooool00;Gooooo00?o0000ooooooooool0S?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo01?ooooo002eooooo`03o`000?oooooooooo08cooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0Cooooo`00]Oooool2o`0008gooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Dooooo`00]Oooool00ol0003oooooooooo`2=oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05?ooool00;Gooooo00?o0000oooooooo
ool0SOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Cooooo002Jooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo08gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Eoooo
o`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0S_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
01Gooooo002Jooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03oooo
o`?o0000S_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Kooooo002Jooooo`05
o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
08oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`00V_ooool01Ol0003o
oooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo08oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Gooooo`00V_ooool01Ol@
413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2@
ooooo`;o00000oooool00ol0003oooooooooo`0Hooooo`00V_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2Aooooo`;o000000?ooooo
o`000?l000006_ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2
o`0009?ooooo0_l0000Looooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo
00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?oooooooooo
ooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0/?ooool009;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooo
oooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`000;3ooooo002Booooo`05o`000?oooooooooo
ooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?o
ZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002B
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002[oooo
o`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0/?ooool00:gooooo00?o0000ooooooooool01Oooool3o`000;3ooooo002]
ooooo`03o`000?oooooooooo0;Sooooo002]ooooo`03o`000?oooooooooo0;Sooooo002]ooooo`03
o`000?oooooooooo0;Sooooo002[ooooo`03oeEEEOmVIVKo00000;[ooooo003oooooofWooooo002_
ooooo`03o`000?nj^[[ooooo0;Kooooo002_ooooo`;o<S8b]oooool0083ooooo0_l000001_l@413o
ooooooooool@413o0000oa0@41Oooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06_ooool2o`000003oa0@
4?oooooooooo00;ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^N?ooool0
087ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00002Oooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03olc<c?l0
003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1hooooo`00
POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Oooooo00?oV9RHob4Q8Oo^k^h0
1?ooool01Ol@413ooooooooooooooooo410@01;ooooo00?o0000ooooooooool06_ooool5o`0000Ko
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@07Sooooo0021ooooo`06
o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000_ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool02oooool6o`0000Wooooo00Co
A4A4omgMgOoooooo00001oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
0000N?ooool0087ooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Kooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo01[ooooo00CogMgM
oeEEEOoooooo00001oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
N?ooool0087ooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Looooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0>ooooo`03oa0@4?l0003o000000?o00006_ooool00omg
MgOoc<c<o`000007ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@401h
ooooo`00POooool01_l0003o<S8boooooooooooo<S8bo`0001Sooooo00Go0000okZj^_ooooooV9RH
oa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool00ol0003oooooooooo`0Kooooo`03
onk^k_m4A4Co000000Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
07Sooooo0020ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41005oooool01OnHV9So
410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Booooo`03o`000?oooooo
oooo01cooooo00?oMgMgo`000?ooool01?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h0N?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(420) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .43269 m
.01975 .38559 L
.02981 .36366 L
.04057 .3444 L
.04629 .3363 L
.0515 .33023 L
.06168 .32127 L
.08481 .30693 L
.12674 .28816 L
.16707 .27052 L
.1879 .2636 L
.19296 .26209 L
.19841 .26083 L
.20153 .26032 L
.20438 .25999 L
.20575 .25988 L
.20725 .25978 L
.20794 .25975 L
.20867 .25972 L
.20998 .25967 L
.21128 .25964 L
.21202 .25963 L
.21271 .25963 L
.21344 .25962 L
.21411 .25962 L
.21488 .25962 L
.2156 .25962 L
.21811 .25963 L
.21938 .25963 L
.2201 .25963 L
.22078 .25963 L
.22151 .25963 L
.22218 .25963 L
.22291 .25962 L
.22369 .25961 L
.22497 .2596 L
.22637 .25957 L
.22953 .25948 L
.23246 .25938 L
.23379 .25934 L
.23522 .25929 L
.23658 .25926 L
.23783 .25924 L
.23895 .25923 L
.24019 .25924 L
.24149 .25926 L
.2427 .25931 L
.24338 .25934 L
.24412 .25938 L
.24546 .25948 L
Mistroke
.24676 .25961 L
.24798 .25976 L
.25072 .26019 L
.25364 .26081 L
.25928 .26247 L
.26447 .26441 L
.27617 .26955 L
.28713 .275 L
.29248 .27823 L
.29736 .28176 L
.30692 .2908 L
.31716 .30359 L
.33887 .3372 L
.34944 .35571 L
.36065 .37567 L
.37022 .39025 L
.37284 .39342 L
.37566 .39633 L
.37831 .39852 L
.3796 .39939 L
.38077 .40006 L
.3819 .40062 L
.38314 .4011 L
.38444 .40148 L
.38567 .40171 L
.38702 .40183 L
.3877 .40183 L
.38845 .40179 L
.38978 .40161 L
.39102 .40133 L
.39169 .40113 L
.39242 .40087 L
.39374 .40031 L
.39622 .39893 L
.39912 .39681 L
.4018 .39441 L
.41114 .38318 L
.42107 .36746 L
.44172 .32899 L
.46067 .2992 L
.47055 .2879 L
.48096 .27798 L
.49154 .26938 L
.49736 .26545 L
.50285 .26239 L
.50805 .2601 L
.51369 .25818 L
.52355 .25573 L
.53351 .25357 L
.54283 .25164 L
Mistroke
.54761 .25085 L
.5503 .25052 L
.55275 .25029 L
.55414 .2502 L
.55543 .25014 L
.55617 .25012 L
.55685 .2501 L
.55762 .25009 L
.55835 .25008 L
.55969 .2501 L
.56091 .25013 L
.56226 .25018 L
.56368 .25026 L
.56631 .25046 L
.56912 .25073 L
.57421 .25131 L
.58576 .2528 L
.59095 .25356 L
.59645 .25457 L
.60249 .25608 L
.60808 .25796 L
.61813 .2626 L
.62921 .26922 L
.64954 .28497 L
.67145 .30837 L
.69209 .33084 L
.69775 .33589 L
.70379 .34042 L
.70672 .34223 L
.70949 .34367 L
.71195 .34471 L
.71326 .34517 L
.71466 .34558 L
.71603 .3459 L
.71727 .34612 L
.71853 .34627 L
.71972 .34635 L
.72104 .34637 L
.72227 .34631 L
.72362 .34616 L
.72438 .34605 L
.72506 .34592 L
.72744 .34531 L
.72877 .34486 L
.73 .34437 L
.73464 .34197 L
.73967 .33846 L
.74518 .33372 L
.75629 .32224 L
.77855 .29609 L
Mistroke
.79881 .27502 L
.8089 .26743 L
.81985 .26121 L
.82487 .25893 L
.83019 .25691 L
.83473 .25556 L
.83732 .25496 L
.83974 .25453 L
.84105 .25435 L
.84176 .25427 L
.84244 .2542 L
.84376 .25411 L
.84495 .25406 L
.84564 .25404 L
.84637 .25404 L
.84768 .25407 L
.84841 .2541 L
.84909 .25415 L
.84983 .25421 L
.85063 .25429 L
.85197 .25446 L
.85341 .25469 L
.85605 .25523 L
.86099 .25668 L
.86589 .25861 L
.87109 .26118 L
.88044 .26731 L
.88557 .27174 L
.89027 .27665 L
.90087 .29137 L
.91022 .30897 L
.92006 .33194 L
.9394 .38709 L
.94931 .417 L
.96006 .44478 L
.96278 .45025 L
.96566 .45512 L
.96812 .45846 L
.96953 .46002 L
.97082 .46121 L
.97203 .46211 L
.97335 .46286 L
.97408 .46317 L
.97475 .46339 L
.97607 .46363 L
.97732 .46363 L
.97845 .46345 L
.97976 .46302 L
.98099 .46241 L
.98209 .46169 L
Mistroke
.9833 .46073 L
.98575 .45823 L
.99012 .45214 L
1 .43269 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool03_ooool5o`0009gooooo002eooooo`03o`000?oooooooooo00Ko
oooo2?l00005ooooo`Wo0000U?ooool00;Gooooo00?o0000ooooooooool00oooool3o`0001Kooooo
0ol00018ooooo`[o0000?oooool005Oooooo3ol0001?ooooo`03o`000?oooooooooo00?o00007?oo
ool3o`0004;ooooo0ol0000:ooooo`;o0000?Oooool005?ooooo1Ol0000>ooooo`Co0000Boooool3
o`0002;ooooo0_l0000nooooo`;o00003oooool2o`0003_ooooo001@ooooo`?o00005oooool2o`00
04Sooooo0_l0000Vooooo`;o0000>_ooool2o`0001?ooooo00?o0000ooooooooool0>?ooool001Go
oooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0Jooooo`05oiRHV?l@
413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo0ol0000Booooo`Go
00000oooool01Oo^k^ko<S8bo`000?l0003ok^k^01cooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^7?ooool00ol0003oooooo`00000Qooooo`Co000000?o410@ooooooooool0
0ol000000olb<S;ok^k^ooooo`0Iooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo0_l0000=ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko0000o`000?lb<S;o
k^k^01gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0>ooooo`00
5_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01Ol@413o
^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`?o00005Oooool0
1OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00CoMgMgoiRHV?ooooooV9RH0ol0000Looooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`;o00000_ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?l0003oV9RHogMgM`0Joooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o
0000ooooooooool03Oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?oooooo
0000ogMgM`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>oooo
o`002oooool6o`0000;ooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41004_ooool6o`00
00Kooooo00Go0000oooooooooooooooooa0@4003ooooo`04oa0@4?l0003o0000o`00013ooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4002ooooo`;o0000
3oooool6o`0000Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01Wo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooo0000oa0@400Kooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooo
oooooooooooooa0@400:ooooo`03o`000?oooooooooo01;ooooo00Go0000oooooooooooooooooa0@
4002ooooo`03o`000?l@413ooooo01[ooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@4100
3_ooool001?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000001go
oooo00?oZJVYoa0@4?ooool00_ooool00ol0003oooooo`000002o`0001gooooo00?oV9RHob4Q8Oo^
k^h00oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000006?ooool00ol0003oooooooooo`03
ooooo`;o00008_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007?oo
ool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003ooooo
ooooo`0Aooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Kooooo`04
odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`004oooool01?oM
gMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000007?ooool00ol@413o0000okZj
^P03ooooo`;o00000_ooool00ol0003oooooooooo`0Looooo`03ogMgMomVIVKooooo00;ooooo00Go
0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0_l0000Loooo
o`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooo
oooo017ooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000001_ooooo00Co
gMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000kooooo000Dooooo`03ogMg
Moo<c<co000000Cooooo00Go410@oooooooooooooooooa0@400Mooooo`03okZj^_lQ8B7o000000;o
000000Go410@oooooooooooooooooa0@400Oooooo`05o`000?ooooooooooooooool@41000oooool0
0ol@413oooooooooo`04ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@01Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo00;ooooo00Oo410@oooooooooooooooooa0@4?oooooo000001co
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Kooooo00?o0000oooo
ooooool04oooool00onj^[[o8B4Qooooo`02ooooo`06oa0@4?ooooooooooooooool@413o00006ooo
ool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41003_ooool001Cooooo00?o
k^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00?o410@oiRHV?ooool0
0_l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool01Ol0003o^[ZjoooooonHV9So410@
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00OoMgMgoiRHV?ooooooV9RH
ogMgMooooooo000001Sooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01oooool00ol0003oooooooooo`0Aooooo`05oa0@4?nHV9SooooookZj^_l000000ooo
ool01omgMgOoV9RHoooooonHV9SoMgMgooooool000006_ooool00oo^k^koA4A4o`000004ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03_ooool001Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^01[ooooo00GoZJVYo`000?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h06oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP08ooooo`03o`000?oooooooooo017ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^01Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Ooooo
o`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`03o`000?oooooo
oooo01Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1_ooool00ol0003oooooooooo`0Booooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00;ooooo00?o0000ooooooooool06?ooool00omgMgOo0000ooooo`03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool003Wooooo0_l0000mooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool02?ooool2o`0002oooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo033ooooo000fooooo`?o0000@?ooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0<?ooool003Cooooo
0_l00014ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0_ooooo`00<_ooool2o`0004Oooooo00?o0000ooooooooool0:_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo02oooooo000`ooooo`;o0000BOooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0;oooool001Koooooool00010o`00
01?ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`;o00001oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool04Oooool001Kooooo00?o0000ooooooooool04_ooool2o`00
013ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Dooooo`05o`000?oooooooooo
ooooool000008oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool04Oooool002[ooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;Oooool002Wooooo00?o0000oooooooo
ool0Doooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool0;?ooool002Sooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo00oooooo0_l0000iooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`0[ooooo`009oooool00ol0003oooooooooo`1Fooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0[ooooo`009_ooool0
0ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0jooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`0Zooooo`009Oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Zooooo`009?ooool00ol0003o
ooooooooo`1Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0looooo`;o00003?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Wo
oooo000Tooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Booooo`;o0000?oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool0:Oooool002?ooooo00?o0000ooooooooool0GOooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0?oooool2o`0000Gooooo0ol0
000kooooo`03o`000?oooooooooo02Wooooo000Sooooo`03o`000?oooooooooo05gooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo047ooooo1_l0000n
ooooo`03o`000?oooooooooo02Sooooo000Rooooo`03o`000?oooooooooo05oooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo08Gooooo00?o0000oooo
ooooool0:?ooool002;ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`0Xooooo`00
8Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
5?ooool2o`0008Oooooo00?o0000ooooooooool09oooool0023ooooo00?o0000ooooooooool0H_oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0Q_oo
ool00ol0003oooooooooo`0Wooooo`008?ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`26ooooo`03o`000?oooooo
oooo02Oooooo000Oooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo08Oooooo00?o0000ooooooooool09_ooool001oo
oooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`0Vooooo`007_ooool00ol0003ooooo
ooooo`1Wooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05_ooool2o`0008Sooooo
00?o0000ooooooooool09_ooool001kooooo00?o0000ooooooooool0J?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0R?ooool00ol0003ooooooooo
o`0Uooooo`007Oooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00Kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP03ooooo`04o`000?oooooo8B4Qob4Q8@Cooooo1Ol00004ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo02Go
oooo000Mooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool01Oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00Co0000oooooolQ8B7o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`28ooooo`03o`000?oooooo
oooo02Gooooo000Mooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool01?ooool01Ol@
413ooooooooooooooooo410@00;ooooo00?o0000ooooooooool01oooool00onHV9So8B4Qonk^kP09
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`0T
ooooo`007?ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo00Cooooo00Oo0000oooo
ooooooooooooo`000?oooooo000000_ooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8boooo
o`04ooooo`?o0000ROooool00ol0003oooooooooo`0Tooooo`007?ooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l0000=ooooo`03ogMgMomV
IVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo08Wooooo
00?o0000ooooooooool09?ooool001_ooooo00?o0000ooooooooool0K_ooool00ol0003ooooooooo
o`03ooooo`05oa0@4?ooooooooooooooool000003oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`0Tooooo`006ooo
ool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo0000
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo08[ooooo00?o0000ooooooooool08oooool001_ooooo00?o0000ooooooooool0
L?ooool3o`000006ooooool0003o0000o`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7o
c<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo08[ooooo00?o0000ooooooooool08oooool0
01[ooooo00?o0000ooooooooool0Loooool3o`0002;ooooo0_l0002;ooooo`03o`000?oooooooooo
02?ooooo000Jooooo`03o`000?oooooooooo09Sooooo00?o0000ooooooooool0Roooool00ol0003o
ooooooooo`0Rooooo`006Oooool00ol0003oooooooooo`2Iooooo`03o`000?oooooooooo08_ooooo
00?o0000ooooooooool08_ooool001Wooooo00?o0000ooooooooool0VOooool00ol0003ooooooooo
o`2;ooooo`03o`000?oooooooooo02;ooooo000Iooooo`03o`000?oooooooooo09Wooooo00?o0000
ooooooooool0S?ooool00ol0003oooooooooo`0Qooooo`006?ooool00ol0003oooooooooo`2Joooo
o`;o0000SOooool00ol0003oooooooooo`0Qooooo`006?ooool00ol0003oooooooooo`2Jooooo`03
o`000?oooooooooo08cooooo00?o0000ooooooooool08Oooool001Oooooo00?o0000ooooooooool0
Voooool00ol0003oooooooooo`2=ooooo`03o`000?oooooooooo023ooooo000Gooooo`03o`000?oo
oooooooo09_ooooo00?o0000ooooooooool0SOooool00ol0003oooooooooo`0Pooooo`005oooool0
0ol0003oooooooooo`2Kooooo`;o0000S_ooool00ol0003oooooooooo`0Pooooo`005_ooool00ol0
003oooooooooo`2Looooo`03o`000?oooooooooo08kooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0Aooooo`00]Oooool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool04Oooool00;Gooooo00?o0000ooooooooool0S_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo01;ooooo002eooooo`03o`000?oooooooooo08oooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0Booooo`00]Oooool2o`00093ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Cooooo`00]Oooool00ol0003oooooooooo`2@oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04oooool00;Gooooo00?o0000oooooooo
ool0T?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Cooooo002Jooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo097ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Doooo
o`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0T_ooool00ol0003oooooooooo`02ooooo`;o00005oooool009[o
oooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0002Coooo
o`Co00006Oooool009[ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000ooooooooooooooooo`00000<oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@
413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`
ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006
ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool009;o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo
410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo0;3ooooo002Booooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06
ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00T_ooool01Ol0003ooooooooooooooooo
000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool0/?ooool009;ooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmg
MgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Zoooool4o`00
0003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo0ol0002`ooooo`00[Oooool0
0ol0003oooooooooo`2hooooo`00[Oooool00ol0003oooooooooo`2hooooo`00[Oooool00ol0003o
ooooooooo`2hooooo`00Zoooool00omEEEGoIVIVo`00002jooooo`00oooooomYooooo`00[oooool0
0ol0003o^[Zjooooo`2fooooo`00[oooool2oc8b<[Oooooo0020ooooo`;o000000Ko410@oooooooo
oooo410@o`000?l@410Gooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?o
QhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01[ooooo0_l000001?l@413ooooo
ooooooooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1hooooo`00POooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l00009ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?oc<c<o`000?l@41003?ooool0
1Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<ooooo`03o`000?oooooooooo00;ooooo00Go
V9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0N?ooool0087ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400Booooo`03o`000?oooooooooo01[ooooo1Ol00004ooooo`03
oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@401hooooo`00POooool01_l0003o
ooooodA4A?m4A4Coooooo`0000Wooooo1_l0000;ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000
ooooooooooooooooo`00000Booooo`03o`000?oooooooooo00_ooooo1_l00009ooooo`04odA4A?oM
gMgoooooo`0000Kooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000007So
oooo0021ooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo00006oooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0Jooooo`04omgMgOmEEEGo
ooooo`0000Oooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000007Sooooo
0021ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo00007?ooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool03_ooool00ol@413o0000o`000003o`0001[ooooo00?oMgMgolc<
c?l000002?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0M_ooool0
087ooooo00Ko0000oc8b<_oooooooooooc8b<_l0000Hooooo`05o`000?nj^[[ooooooiRHV?l@4100
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool06oooool00oo^k^ko
A4A4o`000004ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9So
MgMg07Sooooo0020ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41005oooool01OnH
V9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Booooo`03o`000?oo
oooooooo01cooooo00?oMgMgo`000?ooool00oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP1hooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(430) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .44363 m
.04057 .37728 L
.06168 .34363 L
.07286 .32827 L
.08481 .31429 L
.10632 .29581 L
.12636 .28145 L
.13709 .27539 L
.14314 .27281 L
.14873 .27085 L
.16988 .26414 L
.17935 .26129 L
.18208 .26063 L
.18467 .26012 L
.187 .25974 L
.18954 .25943 L
.19101 .2593 L
.19235 .25921 L
.19309 .25917 L
.19389 .25913 L
.19458 .2591 L
.19534 .25908 L
.1967 .25906 L
.19745 .25905 L
.19814 .25905 L
.19939 .25905 L
.20072 .25907 L
.20334 .25911 L
.2058 .25915 L
.20703 .25916 L
.20836 .25917 L
.20908 .25918 L
.20984 .25917 L
.2112 .25916 L
.21257 .25914 L
.21385 .25911 L
.21525 .25907 L
.21674 .25901 L
.22188 .25876 L
.22338 .25868 L
.22501 .25861 L
.22645 .25855 L
.22723 .25853 L
.22797 .25851 L
.22934 .25849 L
.23006 .25848 L
.23084 .25849 L
.23223 .25851 L
.2335 .25856 L
.2348 .25864 L
Mistroke
.23619 .25875 L
.23868 .25903 L
.24021 .25925 L
.24165 .2595 L
.24434 .26006 L
.25462 .26304 L
.2649 .26649 L
.27575 .2703 L
.28501 .27468 L
.29026 .2781 L
.29516 .28202 L
.31657 .30616 L
.33607 .33576 L
.34663 .35524 L
.35784 .37617 L
.36741 .39086 L
.37003 .39398 L
.37285 .39682 L
.3755 .39898 L
.37796 .40054 L
.37918 .40114 L
.38033 .40161 L
.38166 .40204 L
.38286 .40231 L
.3842 .40249 L
.38543 .40254 L
.38678 .40246 L
.38747 .40238 L
.38821 .40225 L
.38894 .40208 L
.38962 .40189 L
.3909 .40145 L
.39379 .40005 L
.39628 .39838 L
.399 .39611 L
.40384 .3909 L
.409 .38386 L
.41826 .36802 L
.43891 .3276 L
.45786 .29809 L
.47815 .27519 L
.48881 .26654 L
.49417 .26334 L
.50004 .26064 L
.51081 .25706 L
.52061 .25426 L
.52616 .25272 L
.53205 .25126 L
.53447 .25077 L
.53707 .25033 L
Mistroke
.53856 .25013 L
.53992 .24998 L
.5413 .24985 L
.5426 .24977 L
.54387 .24971 L
.54501 .24969 L
.54634 .24968 L
.54759 .24971 L
.54875 .24975 L
.54981 .2498 L
.55222 .24997 L
.55466 .25021 L
.55733 .25051 L
.56272 .25119 L
.57414 .25256 L
.57955 .25325 L
.58455 .2541 L
.58699 .25464 L
.58959 .25532 L
.59508 .25722 L
.59982 .25937 L
.60505 .26224 L
.62701 .27777 L
.64734 .29735 L
.66925 .32389 L
.68016 .33504 L
.68548 .33935 L
.6903 .34253 L
.69542 .34506 L
.69677 .34558 L
.69824 .34606 L
.69961 .34643 L
.70089 .34672 L
.70228 .34695 L
.70302 .34704 L
.70382 .34712 L
.70465 .34716 L
.70544 .34718 L
.70614 .34717 L
.70691 .34713 L
.70765 .34708 L
.70831 .347 L
.70907 .34689 L
.70979 .34676 L
.71108 .34647 L
.71246 .34607 L
.71497 .34512 L
.71765 .34378 L
.72248 .34056 L
.72823 .33553 L
Mistroke
.73346 .33006 L
.75559 .30349 L
.77738 .27944 L
.78696 .27079 L
.79204 .26692 L
.79751 .26337 L
.80278 .26055 L
.80761 .25844 L
.81252 .25669 L
.81708 .25539 L
.82216 .2543 L
.82485 .25386 L
.82622 .25368 L
.82771 .25352 L
.82914 .2534 L
.83044 .25331 L
.8317 .25325 L
.83302 .25322 L
.8342 .25322 L
.83531 .25324 L
.83653 .25329 L
.83783 .25337 L
.83911 .25348 L
.84052 .25363 L
.84337 .25405 L
.84602 .25457 L
.8485 .25517 L
.85409 .25689 L
.86012 .25928 L
.87114 .26509 L
.88124 .27237 L
.89153 .28233 L
.90111 .29423 L
.92284 .33037 L
.94392 .37699 L
.95427 .40146 L
.96382 .42163 L
.97225 .43551 L
.9765 .44068 L
.9789 .443 L
.98118 .44479 L
.98235 .44555 L
.98363 .44626 L
.9848 .44679 L
.98586 .44717 L
.98713 .44751 L
.98848 .44772 L
.98973 .44779 L
.9909 .44774 L
.99201 .44759 L
Mistroke
.99318 .44732 L
.99418 .44701 L
.99527 .44657 L
.99772 .44526 L
1 .44363 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool02Oooool6o`000:7ooooo002eooooo`03o`000?oooooooooo00Co
oooo1Ol00006ooooo`Wo0000COooool5o`0004Kooooo002eooooo`03o`000?oooooooooo00;ooooo
0_l0000Dooooo`?o0000AOooool6o`0000Cooooo1?l00012ooooo`00DOoooolCo`00057ooooo00?o
0000ooooool000000_l0000Iooooo`?o0000@?ooool2o`0000kooooo1?l0000nooooo`00C_ooool3
o`0001;ooooo1_l0001;ooooo`?o00007oooool2o`0003gooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0kooooo`00B_ooool4o`0001_ooooo00?o0000ooooooooool0A_ooool2o`00
0003ooooool0003ooooo027ooooo00?o0000ooooooooool0>?ooool2o`0001Kooooo0_l0000koooo
o`005Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00Go
V9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ol0000Hooooo`Go
00000oooool3o`000003oc8b<_o^k^kooooo01_ooooo1?l000002?l@413oooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^6Oooool2o`0000?ooooo00?o0000ooooooooool07oooool4o`000008oa0@4?oo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^hJooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Oooooo0_l0000Booooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Ol0003o<S8bo`00
0?lb<S;ok^k^01gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0>
ooooo`005_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool0
1Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00?oMgMgoiRHV?l000000_l0000Kooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@00oooool00omgMgOoV9RHooooo`03o`0001gooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Sooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooo000000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Joooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o
0000ooooooooool04_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgo`000?oooooo
V9RHogMgM`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>oooo
o`002oooool6o`0000;ooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41004_ooool6o`00
00Kooooo00?o0000ooooool000000ol00002ooooo`03oa0@4?oooooooooo017ooooo1_l00003oooo
o`03oiRHV?lQ8B7ok^k^00Cooooo00Ko410@oooooooooooooooooa0@4?ooool2o`00013ooooo1_l0
0005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Gooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool08Oooool01_l0003oooooooooool0003ooooooa0@
40?ooooo00?o410@ooooooooool06Oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?oooooooooo
ooooool@41001Oooool00ol0003oooooooooo`0Gooooo`09o`000?ooooooooooooooool@413ooooo
o`000?oooooo410@01_ooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41003_ooool001?o
oooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000001gooooo00?oZJVY
oa0@4?l000000_ooool01Ol0003ooooooooooooooooo000001gooooo00?oV9RHob4Q8Oo^k^h00ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000005oooool00ol0003oooooooooo`04ooooo`;o
00008_ooool01?l0003oooooooooooooool2o`0000?ooooo00?o0000ooooooooool06_ooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0G
ooooo`03ojVYZOl@413ooooo00;ooooo00?o0000ooooooooool00_l0000Kooooo`04odA4A?oMgMgo
ooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`004oooool01?oMgMgoEEEEoooo
ool00004ooooo`05o`000?ooooooooooooooool000007?ooool00ol@413o0000o`000003ooooo`05
o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooooooo
ooooool000001?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`00000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`02ooooo`;o00000_ooool00ol0003oooooooooo`0Kooooo`03ogMgMomV
IVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo01Oooooo
00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000001_ooooo00CogMgMoeEEEOoo
oooo00001?ooool01Ol0003ooooooooooooooooo000000kooooo000Dooooo`03ogMgMoo<c<co0000
00Cooooo00Go410@oooooooooooooooooa0@400Looooo`03o`000?nj^[[o8B4Q00?ooooo00Go410@
oooooooooooooooooa0@400Oooooo`05o`000?ooooooooooooooool@41000oooool00ol@413ooooo
ooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@01Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo00;ooooo00Go410@ooooool0003ooooooa0@400Nooooo`05o`000?oooooooooo
ooooool@41000oooool01?l@413oooooooooool0000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Ko
410@oooooooooooooooooa0@4?l0000Kooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooo
oooooooooa0@400>ooooo`005?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL06_ooool01Ol@413o0000oooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Kooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL05?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHooooool0003oMgMg01[ooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`07ogMgMonHV9SooooooiRHV?mgMgOoooooo`00000Iooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01omgMgOoV9RHoooooonHV9SoMgMgooooool000006_ooool00oo^k^koA4A4o`00
0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool001Gooooo00?oMgMgo`000?ooool00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00Go0000oa0@4?l0003o410@ojVYZ@03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h06oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo01?ooooo00?oEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^01?ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Oooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bo`00000Jooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01_o^k^ko<S8bo`000?lb<S;ok^k^o`0001[ooooo00Go
ZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool00ol0003o
ooooooooo`0Hooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>oooo
o`00>Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool02Oooool2o`0002cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo033ooooo000gooooo`;o0000?_ooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool0<?ooool003Kooooo00?o0000ooooooooool0?ooo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0;ooo
ool003Gooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo02gooooo00?o0000ooooooooool0;oooool003Cooooo00?o0000ooooooooool0@oooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;_ooool001Ko
ooooool00010o`0001?ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo017ooooo000Fooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Sooooo0_l0000Woooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Aoooo
o`00<?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`0/ooooo`00;oooool00ol0003oooooooooo`1;ooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0booooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0[ooooo`00;_oo
ool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool04?oo
ool2o`0003Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0gooooo`03o`000?oo
oooooooo02[ooooo000]ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0hooooo`03o`000?oooooooooo02[ooooo000]ooooo`03o`000?oooooooooo
04oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
03Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo
02Wooooo000/ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo02Wooooo000[ooooo`03o`000?oooooooooo05?ooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool02oooool2o`0003kooooo00?o0000ooooooooool0:?ooool002[ooooo00?o
0000ooooooooool0E?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01?ooooo0_l0
000iooooo`03o`000?oooooooooo00Sooooo0_l00010ooooo`03o`000?oooooooooo02Sooooo000Y
ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo03Wooooo0_l00007ooooo`03o`000?oooooooooo043ooooo00?o0000
ooooooooool0:?ooool002Wooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0>oooool7o`0004Cooooo00?o0000oooo
ooooool09oooool002Sooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`0Wooooo`00
:?ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo02Kooooo000Wooooo`03o`000?oo
oooooooo05[ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Eooooo`;o0000R?oo
ool00ol0003oooooooooo`0Vooooo`009oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`27ooooo`03o`000?oooooo
oooo02Kooooo000Vooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool09Oooool002Go
oooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`0Uooooo`009Oooool00ol0003ooooo
ooooo`1Nooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`29ooooo`03o`000?oooooooooo02Cooooo000Tooooo`03o`000?oooooooooo063ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Gooooo`;o0000R_ooool00ol0003ooooooooo
o`0Tooooo`009?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo02Cooooo000Soooo
o`03o`000?oooooooooo06;ooooo00?o0000ooooooooool01oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00;ooooo00?o0000ooooooooool00_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`0Sooooo`008oooool0
0ol0003oooooooooo`1Rooooo`03o`000?oooooooooo00Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`02ooooo`03o`000?oooooooooo00;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo02?ooooo
000Rooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool01_ooool01ol@413ooooooooo
oooooooo410@ooooool000002_ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0Roooool00ol0003oooooooooo`0Rooooo`008Oooool00ol0003ooooo
ooooo`1Vooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooooooo0_l0000<ooooo`03
oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0008_ooooo00?o0000oooooooo
ool08_ooool0027ooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`04ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo027ooooo000Pooooo`03
o`000?oooooooooo06Sooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo0000
00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
08cooooo00?o0000ooooooooool08Oooool0023ooooo00?o0000ooooooooool0JOooool00ol0003o
ooooooooo`03ooooo`05ogMgMonHV9Soooooo`000?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2=ooooo`03o`000?oooooo
oooo023ooooo000Oooooo`03o`000?oooooooooo06_ooooo0_l00003ooooo`05onk^k_l0003o0000
oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oo
oooooooo08gooooo00?o0000ooooooooool08?ooool001kooooo00?o0000ooooooooool0K_ooool4
o`0002;ooooo0_l0002?ooooo`03o`000?oooooooooo01oooooo000Nooooo`03o`000?oooooooooo
09Cooooo00?o0000ooooooooool0S_ooool00ol0003oooooooooo`0Oooooo`007Oooool00ol0003o
ooooooooo`2Eooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool07_ooool001cooooo
00?o0000ooooooooool0U_ooool00ol0003oooooooooo`2?ooooo`03o`000?oooooooooo01kooooo
000Looooo`03o`000?oooooooooo09Kooooo00?o0000ooooooooool0T?ooool00ol0003ooooooooo
o`0Mooooo`006oooool00ol0003oooooooooo`2Gooooo`;o0000TOooool00ol0003oooooooooo`0M
ooooo`006oooool00ol0003oooooooooo`2Gooooo`03o`000?oooooooooo097ooooo00?o0000oooo
ooooool07?ooool001[ooooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`2Aooooo`03
o`000?oooooooooo01cooooo000Iooooo`03o`000?oooooooooo09Wooooo00?o0000ooooooooool0
T_ooool00ol0003oooooooooo`0Kooooo`006Oooool00ol0003oooooooooo`2Iooooo`;o0000Tooo
ool00ol0003oooooooooo`0Kooooo`006?ooool00ol0003oooooooooo`2Jooooo`03o`000?oooooo
oooo09?ooooo00?o0000ooooooooool06_ooool001Sooooo00?o0000ooooooooool0V_ooool00ol0
003oooooooooo`2Dooooo`03o`000?oooooooooo01Wooooo000Gooooo`03o`000?oooooooooo09_o
oooo00?o0000ooooooooool0UOooool00ol0003oooooooooo`0Hooooo`005_ooool00ol0003ooooo
ooooo`2Looooo`03o`000?oooooooooo09Gooooo0_l00005ooooo`03o`000?oooooooooo017ooooo
002eooooo`;o0000Uoooool6o`0001Cooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Joooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000
ooooooooool00oooool3o`000;3ooooo002Jooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05o`000?oooooooooo
ooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?oo
ool009[ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000
onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?oo
ool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYoooo
o`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009;ooooo00Go410@
oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o
8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000
ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@4100
3_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb
<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo0;3o
oooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002]oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000
/?ooool00:gooooo00?o0000ooooooooool0^?ooool00:gooooo00?o0000ooooooooool0^?ooool0
0:gooooo00?o0000ooooooooool0^?ooool00:_ooooo00?oEEEEofIVI_l00000^_ooool00?oooooo
JOooool00:oooooo00?o0000okZj^_ooool0]_ooool00:oooooo0_lb<S:gooooo`00P?ooool2o`00
0006oa0@4?oooooooooooa0@4?l0003o410@5oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Jooooo`;o
000000Wo410@oooooooooooooooooiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^07Sooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01ooo
ool6o`0000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`00
00cooooo00?o0000ooooooooool00_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`1hooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo01Oooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01;ooooo00?o
0000ooooooooool06_ooool5o`0000Oooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@
4?oooooooooo07Kooooo0021ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000_o
oooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000oooo
ooooool02oooool6o`0000Wooooo00CoA4A4omgMgOoooooo00001oooool00onYZJWo410@ooooo`02
ooooo`05o`000?ooooooooooooooool00000N?ooool0087ooooo00Ko0000omgMgOlb<S;oEEEEomgM
gOl0000Kooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00000Booooo`03
o`000?oooooooooo01[ooooo00CogMgMoeEEEOoooooo00001_ooool00ol@413o0000okZj^P03oooo
o`05o`000?ooooooooooooooool00000N?ooool0087ooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0
000Looooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0>ooooo`03oa0@
4?l0003o000000?o00006_ooool00omgMgOoc<c<o`000007ooooo`03okZj^_lQ8B7ooooo00;ooooo
00Go410@oooooooooooooooooa0@401hooooo`00POooool01_l0003o<S8boooooooooooo<S8bo`00
01Sooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_oo
ool00ol0003oooooooooo`0Kooooo`03onk^k_m4A4Co000000Cooooo00Go410@oiRHV?oooooo^[Zj
o`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0N?ooool0083ooooo00?o410@o`000?n7QhL0
0_ooool00on7QhOo0000oa0@400Gooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^01;ooooo00?o0000ooooooooool07?ooool00omgMgOo0000ooooo`03oooo
o`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07Sooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(440) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .44328 m
.00123 .44408 L
.00236 .44471 L
.00357 .44527 L
.00488 .44574 L
.00609 .44606 L
.00722 .44624 L
.00829 .44632 L
.00942 .44631 L
.01065 .44617 L
.01196 .44588 L
.0132 .44548 L
.01434 .44501 L
.01711 .44342 L
.01975 .44136 L
.02491 .43588 L
.0297 .42928 L
.04057 .41006 L
.06377 .36048 L
.08481 .32201 L
.09497 .3078 L
.10596 .29493 L
.11627 .28508 L
.12589 .27805 L
.13588 .27278 L
.14683 .26837 L
.15819 .26434 L
.16378 .2626 L
.16895 .26128 L
.17391 .26035 L
.17642 .26001 L
.17786 .25986 L
.17918 .25974 L
.1805 .25964 L
.18195 .25956 L
.1834 .25949 L
.18493 .25944 L
.18628 .2594 L
.18772 .25938 L
.19032 .25934 L
.19284 .25931 L
.19426 .25928 L
.19557 .25926 L
.19798 .25918 L
.19919 .25914 L
.20053 .25908 L
.20532 .25879 L
.2098 .25846 L
.21233 .25828 L
.21503 .25812 L
Mistroke
.21583 .25808 L
.21658 .25805 L
.21731 .25802 L
.21799 .258 L
.21931 .25798 L
.22 .25798 L
.22073 .25798 L
.22197 .258 L
.22329 .25805 L
.22454 .25811 L
.22568 .25819 L
.22847 .25846 L
.2311 .25881 L
.23595 .25968 L
.24043 .26065 L
.25057 .26296 L
.26002 .26499 L
.26499 .2662 L
.2702 .26781 L
.27604 .27027 L
.28138 .27327 L
.29185 .28121 L
.3019 .29081 L
.31262 .30293 L
.33192 .33277 L
.35287 .37353 L
.35861 .38329 L
.36468 .39192 L
.36986 .39765 L
.3728 .40016 L
.37555 .40199 L
.37681 .40266 L
.37815 .40324 L
.37885 .4035 L
.37963 .40374 L
.38099 .40406 L
.38227 .40423 L
.38365 .40428 L
.38496 .4042 L
.38615 .40401 L
.38732 .40371 L
.3884 .40334 L
.39086 .40215 L
.39326 .40052 L
.39583 .39829 L
.40169 .39131 L
.40722 .3826 L
.41758 .36261 L
.43679 .32466 L
.45794 .29205 L
Mistroke
.46798 .27963 L
.47878 .26939 L
.48474 .26532 L
.49019 .26244 L
.50087 .25812 L
.51053 .25463 L
.51583 .2528 L
.52082 .2513 L
.52367 .25058 L
.52674 .24997 L
.5281 .24976 L
.52954 .24958 L
.53076 .24945 L
.53211 .24935 L
.53348 .24928 L
.53473 .24925 L
.53542 .24925 L
.53617 .24925 L
.53753 .24928 L
.5388 .24934 L
.54016 .24942 L
.54259 .24963 L
.54772 .25022 L
.55243 .25082 L
.56305 .25213 L
.56789 .2528 L
.5724 .25364 L
.5771 .25487 L
.58224 .25677 L
.58755 .25938 L
.5933 .26291 L
.60374 .27057 L
.62326 .28772 L
.64374 .3122 L
.65459 .32593 L
.66057 .33251 L
.66625 .33775 L
.6716 .3417 L
.67442 .34339 L
.67743 .34488 L
.68021 .34598 L
.68273 .34674 L
.68395 .34702 L
.68526 .34726 L
.6865 .34742 L
.68764 .34752 L
.6888 .34756 L
.69004 .34755 L
.69122 .34747 L
.69229 .34735 L
Mistroke
.69354 .34715 L
.6949 .34685 L
.69738 .34608 L
.69997 .34496 L
.70271 .34344 L
.70764 .33982 L
.71752 .32972 L
.72814 .31648 L
.74736 .29353 L
.75796 .28252 L
.76954 .27182 L
.77483 .26764 L
.78047 .26389 L
.7858 .2611 L
.79063 .25918 L
.79574 .2577 L
.79832 .25713 L
.80115 .25661 L
.80356 .25624 L
.80615 .25591 L
.80858 .25566 L
.81083 .25546 L
.81364 .25527 L
.81512 .25519 L
.81588 .25516 L
.8167 .25513 L
.81806 .2551 L
.81934 .25509 L
.82008 .25509 L
.82086 .2551 L
.82153 .25512 L
.82226 .25514 L
.82363 .2552 L
.82487 .25528 L
.82631 .25539 L
.82766 .25554 L
.83007 .25587 L
.83269 .25634 L
.83782 .25762 L
.84262 .25922 L
.85355 .26396 L
.86488 .2698 L
.87564 .27618 L
.89693 .29316 L
.91639 .31351 L
.93722 .34119 L
.95653 .37401 L
.97772 .41335 L
.98731 .42913 L
.9927 .43635 L
Mistroke
.99766 .44146 L
1 .44328 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool01Oooool9o`000:;ooooo002eooooo`04o`000?oooooooooooooo
o`Co00002Oooool6o`0009cooooo002eooooo`04o`000?oooooo0000o`0001?ooooo1Ol00014oooo
o`_o0000B?ooool004kooooo5?l0001Booooo`?o00006_ooool2o`0003kooooo1?l0000;ooooo`Co
0000A?ooool004Wooooo1_l0000Cooooo`Ko0000BOooool3o`000003ooooool0003o000001cooooo
00?o0000ooooooooool0>Oooool2o`0001?ooooo00?o0000ooooooooool0@Oooool004Kooooo0ol0
000Oooooo`;o0000A_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool0=_ooool2o`0001Kooooo0_l00011ooooo`005Oooool2o`000009oa0@4?oooooo
ooooooooooo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003oooo
o`05onk^k_l0003o0000o`000?o^k^h06oooool5o`0000?ooooo1?l000000oo^k^koooooooooo`0J
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQSooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo000000?o000000So410@oooooooo
ooook^k^oc8b<_l0003o<S8bonk^kQ[ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0_ooool00ol0003oooooooooo`0Fooooo`05oiRHV?l@413o0000o`000?o<c<`00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^01gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8b
onk^kP0>ooooo`005_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
6_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00Go0000oiRHV?ooooooV9RHogMgM`0Koooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9So000001kooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Oooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Nooooo`;o000000?oooooo`000?ooool00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg01[ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`07ogMgMonHV9Sooooo
oiRHV?mgMgOoooooo`00000Iooooo`04oa0@4?nj^[[oooooogMgM`;o00000_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg01kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00kooooo000;ooooo`Ko00000_ooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Boooo
o`Ko00001_ooool01Ol0003oooooo`000?l0003o410@00?ooooo00?o410@ooooooooool04Oooool6
o`0000?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00;o00004Ooo
ool6o`0000Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Pooooo`;o00001?ooool01Ol@413ooooo
oooooooooooo410@01_ooooo00?oV9RHob4Q8Oo^k^h01?ooool01_l@413ooooooooooooooooo410@
o`0001kooooo00Go0000ooooool0003ooooooa0@4003ooooo`03oa0@4?oooooooooo01Wooooo1Ol0
0003ooooo`05oa0@4?ooooooooooooooool@41003_ooool001?ooooo00CoA4A4omgMgOoooooo0000
1?ooool01Ol0003ooooooooooooooooo000001gooooo00?oZJVYo`000?l000000_ooool01Ol0003o
oooooooooooooooo000001gooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo
000000;ooooo0_l0000Jooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
000Eooooo`03o`000?oooooooooo00Kooooo0_l0000Rooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`00000Looooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooooooo
ooooo`00000Nooooo`04ojVYZOl@413oooooooooo`;o00000oooool00ol0003oooooooooo`0Ioooo
o`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`004oooool0
1?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000007?ooool00ol@413o0000
okZj^P03ooooo`05o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02ooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`00000Dooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool08Oooool2o`0000?ooooo00Go0000ooooooooooooooooo`00000Mooooo`03ogMgMomV
IVKooooo00;ooooo00?o0000ooooooooool00_l0000Mooooo`03oa0@4?l0003o^[Zj00?ooooo0_l0
0002ooooo`03o`000?oooooooooo01Wooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000000kooooo000Dooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooo
oooooa0@400Looooo`03o`000?nj^[[o8B4Q00?ooooo00Go410@oooooooooooooooooa0@400Ooooo
o`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01?ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo000000;ooooo00Go
410@oooooooooooooooooa0@400Nooooo`09o`000?ooooooooooooooool@413oooooo`000?oooooo
410@01kooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413oooooo`000?l0003o410@01cooooo00?o
MgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00kooooo000Dooooo`03onk^k_m4
A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`;o000000?ooooookZj^_l00000
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@4003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Booooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool08Oooool02_l0003oooooooooool0003oooooogMgMonHV9SooooooiRHV?mgMgLJ
ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo0000oooooonHV9SoMgMg01_ooooo
00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?l000007?ooool00oo^
k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool001Gooooo00?oMgMgo`00
0?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Wooooo00Ko0000ojVYZOl@413o0000oa0@
4?nYZJT3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`03o`000?oooooooooo01;ooooo00?oEEEE
ofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^017ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Oooooo`03oeEEEOmVIVKo000000;ooooo00Oo0000ooooooo^k^ko<S8b
o`000?lb<S;ok^k^01[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05o`000?lb<S;o0000
oc8b<_o^k^h06oooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Kok^k^oc8b<_l0003o<S8b
onk^k_l0000Looooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>oooo
o`00>?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool02oooool2o`0002Kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo03;ooooo000gooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo03;ooooo000gooooo`03o`000?oo
oooooooo03kooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo037ooooo000fooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo033ooooo000eooooo`03o`000?oooooooooo
047ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
02oooooo000Foooooooo0000@?l0000Cooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooo000000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Aooooo`005_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool04Oooool003;ooooo00?o0000ooooooooool0Aoooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0;?ooool0037ooooo00?o
0000ooooooooool0B?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03[ooooo00?o
0000ooooooooool0:oooool0037ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo017ooooo0_l0000^ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0??ooool00ol0003oooooooooo`0Zooooo`00<?ooool00ol0003oooooooooo`1;oooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Yoooo
o`00<?ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0@?ooool00ol0003oooooooooo`0Xooooo`00;oooool00ol0003oooooooooo`1=ooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0`ooooo`;o0000
3oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo02Oooooo000_ooooo`03o`000?oo
oooooooo04gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`14ooooo`03o`000?oo
oooooooo02Kooooo000^ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Cooooo`;o0000=?ooool00ol0003oooooooooo`08ooooo`;o0000B?ooool0
0ol0003oooooooooo`0Uooooo`00;Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Uooooo`00;Oooool00ol0003o
ooooooooo`1Aooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0eooooo`Wo0000Boooool00ol0003oooooooooo`0Tooooo`00;?ooool00ol0003ooooo
ooooo`1Booooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`29ooooo`03o`000?oooooooooo02Cooooo000/ooooo`03o`000?oooooooooo05?ooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo08[ooooo00?o
0000ooooooooool08oooool002_ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo01Kooooo0_l0002;ooooo`03o`000?oooooooooo02?ooooo000[oooo
o`03o`000?oooooooooo05Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo08_ooooo00?o0000ooooooooool08_ooool002[ooooo00?o0000oooooooo
ool0Eoooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool0S?ooool00ol0003oooooooooo`0Qooooo`00:_ooool00ol0003oooooooooo`1Gooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`2<ooooo`03o`00
0?oooooooooo027ooooo000Yooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool08?oo
ool002Wooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo01Sooooo0_l0002>ooooo`03o`000?oooooooooo023ooooo000Xooooo`03o`000?oooooooooo
05_ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
08kooooo00?o0000ooooooooool07oooool002Sooooo00?o0000ooooooooool0Foooool00ol0003o
ooooooooo`09ooooo`07onk^k_lb<S;o0000oc8b<_o^k^koooooo`000003ooooo`;o8B4Q1?ooool5
o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo08kooooo00?o
0000ooooooooool07oooool002Oooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`08
ooooo`07ogMgMonHV9SooooooiRHV?mgMgOoooooo`000003ooooo`;o8B4Q1?ooool01OnHV9So8B4Q
onk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2?ooooo`03
o`000?oooooooooo01kooooo000Wooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0
1oooool01_l@413ooooooooooooooooo410@o`0000_ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool07_ooool002Ko
oooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooooooo
o`;o00003?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002@oooo
o`03o`000?oooooooooo01gooooo000Vooooo`03o`000?oooooooooo063ooooo00?o0000oooooooo
ool01_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`0L
ooooo`009_ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo00Gooooo00Go410@oooo
ooooooooooooo`00000?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`2Aooooo`03o`000?oooooooooo01cooooo000Uooooo`03o`000?oooooooooo
06?ooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHooooool0003oMgMg00_ooooo00Go0000
okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0T_oo
ool00ol0003oooooooooo`0Kooooo`009Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooo
oooo00?ooooo00Gok^k^o`000?l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
1?ooool4o`0000Kooooo00?o0000ooooooooool0T_ooool00ol0003oooooooooo`0Kooooo`009?oo
ool00ol0003oooooooooo`1Vooooo`Ko00008_ooool2o`0009Cooooo00?o0000ooooooooool06_oo
ool002Cooooo00?o0000ooooooooool0S_ooool00ol0003oooooooooo`2Dooooo`03o`000?oooooo
oooo01Wooooo000Sooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool0U?ooool00ol0
003oooooooooo`0Iooooo`008oooool00ol0003oooooooooo`2?ooooo`03o`000?oooooooooo09Go
oooo00?o0000ooooooooool06?ooool002;ooooo00?o0000ooooooooool0T?ooool00ol0003ooooo
ooooo`2Eooooo`03o`000?oooooooooo01Sooooo000Qooooo`03o`000?oooooooooo097ooooo0_l0
002Gooooo`03o`000?oooooooooo01Oooooo000Qooooo`03o`000?oooooooooo097ooooo00?o0000
ooooooooool0Uoooool00ol0003oooooooooo`0Fooooo`008?ooool00ol0003oooooooooo`2Boooo
o`03o`000?oooooooooo09Oooooo00?o0000ooooooooool05_ooool001oooooo00?o0000oooooooo
ool0Toooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo01Gooooo000Oooooo`03o`00
0?oooooooooo09?ooooo0_l0002Iooooo`03o`000?oooooooooo01Gooooo000Nooooo`03o`000?oo
oooooooo09Cooooo00?o0000ooooooooool0VOooool00ol0003oooooooooo`0Dooooo`007Oooool2
o`0009Kooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0Cooooo`007?ooool00ol0
003oooooooooo`2Fooooo`03o`000?oooooooooo09_ooooo00?o0000ooooooooool04_ooool001Ko
oooo00Co0000oooooooooooooooo0_l0002Iooooo`03o`000?oooooooooo09cooooo00?o0000oooo
ooooool04Oooool001Oooooo1?l0002Jooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0
/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@4100
4?ooool00ol0003oooooooooo`03ooooo`?o0000/?ooool009[ooooo00Go0000oooooooooooooooo
o`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009[ooooo00Go
0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003o
ooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo
00?o0000ooooooooool0/?ooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`2`ooooo`00T_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03
oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00
T_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?ooooooooooooooool0
00003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00
T_ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00Go410@oooooooo
oooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`2`ooooo`00T_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooo
oooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool0
09;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo00?o0000
ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00Zoooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0
/?ooool00:gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo
00Gooooo0ol0002`ooooo`00[Oooool00ol0003oooooooooo`2hooooo`00[Oooool00ol0003ooooo
ooooo`2hooooo`00[Oooool00ol0003oooooooooo`2hooooo`00Zoooool00omEEEGoIVIVo`00002j
ooooo`00oooooomYooooo`00[oooool00ol0003o^[Zjooooo`2fooooo`00[oooool2oc8b<[Oooooo
0020ooooo`;o000000Ko410@oooooooooooo410@o`000?l@410Gooooo`Go00000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co
^[Zj01[ooooo0_l000000ol@413oooooooooo`03ooooo`;o000000Wo410@ooooooooooooooooonk^
k_lb<S;o0000oc8b<_o^k^h0N?ooool0087ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`Ko00002Oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`03olc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009
ooooo`Ko00003?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`1hooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo01Oooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01;ooooo00?o
0000ooooooooool06_ooool5o`0000?ooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@4100
N?ooool0087ooooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00002oooool00onHV9So
8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0;oooo
o`Ko00002Oooool01?m4A4CogMgMooooool00004ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go
0000ooooooooooooooooo`00001hooooo`00POooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001_o
oooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000oooo
ooooool06_ooool01?oMgMgoEEEEooooool00004ooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go
0000ooooooooooooooooo`00001hooooo`00POooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001co
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00kooooo00?o410@o`00
0?l000000ol0000Jooooo`03ogMgMoo<c<co000000Gooooo00?oMgMgolc<c?l000001?ooool01Ol@
413ooooooooooooooooo410@07Sooooo0021ooooo`06o`000?lb<S;ooooooooooolb<S;o00006?oo
ool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Booooo`03
o`000?oooooooooo01_ooooo00?ok^k^odA4A?l000001Oooool00oo^k^koA4A4o`000004ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0N?ooool0083ooooo00?o410@o`000?n7QhL00_ooool00on7QhOo
0000oa0@400Gooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01;ooooo00?o0000ooooooooool07?ooool00omgMgOo0000ooooo`05ooooo`03ogMgMol0003o
oooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1hooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(450) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .43128 m
.00488 .43998 L
.00942 .4466 L
.01199 .4496 L
.01441 .45189 L
.01575 .45292 L
.01721 .45383 L
.01853 .45448 L
.01975 .45492 L
.02094 .45519 L
.02223 .45533 L
.02345 .45529 L
.02456 .45512 L
.02586 .45475 L
.02659 .45446 L
.02727 .45414 L
.02985 .45249 L
.03125 .45129 L
.03257 .44998 L
.03504 .44706 L
.04057 .43843 L
.05164 .41425 L
.06182 .38772 L
.07371 .3572 L
.08481 .33246 L
.09515 .31346 L
.10457 .29943 L
.11505 .28734 L
.12627 .27804 L
.13668 .27188 L
.14631 .26748 L
.15688 .26379 L
.16222 .26243 L
.16503 .26185 L
.16811 .26133 L
.17327 .26065 L
.17871 .26013 L
.18842 .25934 L
.19432 .25882 L
.1999 .25833 L
.20233 .25814 L
.2049 .25798 L
.20624 .2579 L
.20772 .25784 L
.20906 .2578 L
.21032 .25778 L
.21159 .25777 L
.21298 .25778 L
.21429 .2578 L
.21551 .25784 L
Mistroke
.21671 .25789 L
.2178 .25795 L
.22025 .25812 L
.22574 .25865 L
.23091 .25927 L
.24162 .26057 L
.24746 .26129 L
.25291 .26213 L
.25778 .26316 L
.26299 .26469 L
.26877 .26703 L
.27403 .26975 L
.29344 .2838 L
.30388 .29412 L
.31352 .3066 L
.33534 .3461 L
.3456 .3664 L
.35664 .38582 L
.36173 .39322 L
.36707 .39956 L
.36928 .40166 L
.37164 .40354 L
.37299 .40442 L
.37422 .40511 L
.37546 .40567 L
.37662 .40608 L
.3778 .40639 L
.3791 .40658 L
.38037 .40662 L
.38173 .4065 L
.38299 .40623 L
.38419 .40585 L
.38526 .40539 L
.38643 .40477 L
.3891 .40288 L
.39194 .40017 L
.39705 .39366 L
.4062 .37791 L
.41631 .35755 L
.43831 .31539 L
.44794 .2993 L
.45849 .28413 L
.46344 .27827 L
.46873 .273 L
.47826 .26587 L
.48916 .25998 L
.49908 .25527 L
.50416 .25306 L
.50954 .25106 L
.51414 .24978 L
Mistroke
.5154 .24951 L
.51675 .24927 L
.51794 .24909 L
.5192 .24893 L
.51996 .24886 L
.52065 .2488 L
.522 .24872 L
.52275 .24869 L
.52357 .24868 L
.52434 .24868 L
.52505 .24868 L
.52634 .24872 L
.52707 .24876 L
.52775 .24879 L
.5306 .24903 L
.53324 .24932 L
.53563 .24962 L
.54103 .25034 L
.55075 .25162 L
.55566 .25238 L
.55846 .25293 L
.56108 .25358 L
.56654 .2554 L
.5696 .25677 L
.57241 .25826 L
.58289 .26554 L
.60277 .28336 L
.62451 .30813 L
.636 .32339 L
.64164 .33027 L
.64684 .33577 L
.65148 .3398 L
.65658 .34321 L
.65922 .34455 L
.6617 .34556 L
.66432 .34635 L
.66578 .34669 L
.66712 .34692 L
.66845 .34709 L
.66966 .34718 L
.67032 .34721 L
.67104 .34723 L
.67235 .3472 L
.67358 .34712 L
.67488 .34697 L
.67598 .34679 L
.6772 .34654 L
.67994 .34577 L
.68288 .3446 L
.68565 .34316 L
Mistroke
.68817 .34157 L
.69843 .33236 L
.70814 .32061 L
.72733 .29679 L
.74846 .27679 L
.75849 .26903 L
.76402 .26548 L
.76928 .26277 L
.77213 .26161 L
.77523 .2606 L
.77806 .25988 L
.78068 .25938 L
.78207 .25917 L
.78339 .25901 L
.78585 .25877 L
.78723 .25868 L
.7885 .25861 L
.78989 .25855 L
.79065 .25853 L
.79136 .25851 L
.79264 .25848 L
.79331 .25847 L
.79403 .25847 L
.79523 .25846 L
.79656 .25846 L
.79774 .25847 L
.79901 .25848 L
.80021 .2585 L
.80131 .25852 L
.80259 .25855 L
.80379 .25859 L
.80521 .25865 L
.8065 .25871 L
.80914 .25888 L
.8106 .259 L
.81197 .25914 L
.8143 .25943 L
.81677 .25982 L
.8212 .26077 L
.82597 .26215 L
.83122 .26406 L
.87356 .28244 L
.91431 .30451 L
.92494 .31125 L
.93654 .32098 L
.94761 .33286 L
.95764 .34611 L
.97815 .38351 L
1 .43128 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000/Oooool0
0;Gooooo00Co0000oooooooooooooooo3?l0002Sooooo`00]Oooool4o`0000cooooo1Ol0002Noooo
o`00]?ooool2o`0001Cooooo0_l0002Looooo`00DOoooolAo`00053ooooo0_l000000ooooooo0000
ooooo`0Eooooo`;o0000?oooool>o`0004gooooo0019ooooo`So00004Oooool6o`0004Sooooo0_l0
0003ooooo`;o00005oooool00ol0003oooooooooo`0iooooo`Co00003Oooool3o`0004[ooooo0016
ooooo`?o00007oooool3o`0004?ooooo0_l00005ooooo`03o`000?oooooooooo01Oooooo0_l0000g
ooooo`;o00005?ooool2o`0004Sooooo000Eooooo`;o000000Wo410@ooooooooooooooooonk^k_lb
<S;o0000oc8b<_o^k^h06_ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^o`000?l0
003o0000onk^kP0Kooooo`Go00000oooool01Oo^k^ko0000o`000?lb<S;ok^k^01cooooo1?l00000
2?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^5_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool00oooool4o`000008oa0@4?ooooooooooonk^
k_lb<S;o0000oc8b<_o^k^hJooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Kooooo
0ol00002ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0>ooooo`005_oo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01_l@413o^[Zj
oooooomgMgOo<S8booooo`?o000000CoV9RHoooooonHV9SoMgMg6oooool01OnHV9So8B4Qonk^k_oo
ooooA4A400?ooooo00?oMgMgoiRHV?ooool00_l0000Nooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0Eooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOo0000oooooonHV9So
MgMg01Wooooo0_l000001Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`00
2oooool6o`0000;ooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41004_ooool6o`0000Ko
oooo0_l00002ooooo`05oa0@4?ooooooooooooooool@41004oooool6o`0000?ooooo00?oV9RHob4Q
8Oo^k^h01?ooool01_l@413ooooooooooooooooo410@o`0001;ooooo1_l00005ooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@400Cooooo`;o00002Oooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@01_ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol0003ooooooooooooooooo410@
01_ooooo0_l00002ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0I
ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00kooooo000Cooooo`04odA4A?oMgMgo
ooooo`0000Cooooo00Go0000ooooooooooooooooo`00000Mooooo`;o00000oooool01Ol0003ooooo
oooooooooooo000001gooooo00?oV9RHob4Q8Oo^k^h00oooool01_l0003ooooooooooooooooo0000
ooooo`;o00006oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004_oo
ool00ol0003oooooooooo`09ooooo`;o00007Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000Looooo`04oiRHV?lQ8B7ok^k^ooooo`?o
00000oooool00ol0003oooooooooo`0Kooooo`?o00000oooool01Ol0003ooooooooooooooooo0000
01_ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000000kooooo000C
ooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000Looooo`;o0000
00Go^[Zjooooooooooooooooo`000003ooooo`03o`000?oooooooooo01cooooo00?oMgMgofIVI_oo
ool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01gooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oo
ooooooooooooool000007Oooool00omgMgOoIVIVo`000002ooooo`05o`000?ooooooooooooooool0
00007Oooool00ol@413o0000okZj^P02o`000003ooooool0003ooooo00;ooooo00?o0000oooooooo
ool06Oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool0
01Cooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@01_ooooo00Co0000
oooooonj^[[o8B4Q0oooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooo
oooooa0@4003ooooo`03oa0@4?oooooooooo00;ooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41004Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo01kooooo00Co0000oooooooooooo00001?ooool01Ol@413ooooooooooooo
oooo410@01kooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo
00Co^[Zjob4Q8Ooooooooooo0_l00003ooooo`03oa0@4?oooooooooo01[ooooo00?oMgMgolc<c?l0
00001?ooool01Ol@413ooooooooooooooooo410@00kooooo000Dooooo`03onk^k_m4A4Co000000Co
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05o`000?nHV9SooooookZj^_l000000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Aooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool07_ooool01?l0003oooooooooool00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_oo
ool01Ol0003o^[Zjooooool0003o410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`05
oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOo0000o`000?nHV9SoMgMg01cooooo00?ok^k^
odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000Eooooo`03ogMgMol0003o
oooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Jooooo`05o`000?l@413o0000oa0@4?nYZJT0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`0Cooooo`03oeEEEOmVIVKo
000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0@ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool07oooool00ol0003oIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
6_ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Koooo
o`05ojVYZOl@413o0000oa0@4?nYZJT00oooool00oo^k^ko<S8bo`000002o`0001gooooo00?oMgMg
o`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000iooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0<ooooo`;o00008Oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo037ooooo0_l0000dooooo`00>?ooool00ol0
003oooooooooo`0looooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`0aooooo`00=oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool0=Oooool2o`00037ooooo000gooooo`03o`000?oooooooooo03oooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0hooooo`;o0000;oooool003Kooooo00?o
0000ooooooooool0@Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo03_ooooo0_l0
000]ooooo`005_ooooooo`00043o00004oooool001Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`00
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo0000
00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`;o00001_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Ooo
ool001Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Uooooo`;o00006_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo017ooooo000dooooo`03o`000?oooooooooo
04Gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo
02Kooooo000cooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`16ooooo`03o`000?oooooooooo02Gooooo000cooooo`03o`000?oooooooooo04Oooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Booooo`;o0000:Oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool09Oooool003;ooooo00?o
0000ooooooooool0B?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04Sooooo00?o
0000ooooooooool09?ooool003;ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool08oooool0037ooooo00?o0000oooo
ooooool0B_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`0=ooooo`;o0000C_ooool00ol0003oooooooooo`0Roooo
o`00<Oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0Coooool00ol0003oooooooooo`0Qooooo`00<?ooool00ol0003oooooooooo`1<ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool05Oooool2o`0002kooooo0_l0000:ooooo`03o`00
0?oooooooooo057ooooo00?o0000ooooooooool08?ooool0033ooooo00?o0000ooooooooool0C?oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0;ooo
ool2o`0000Kooooo0_l0001Eooooo`03o`000?oooooooooo01oooooo000_ooooo`03o`000?oooooo
oooo04kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo033ooooo1ol0001Hooooo`03o`000?oooooooooo01kooooo000^ooooo`03o`000?oooooooooo
04oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
08oooooo00?o0000ooooooooool07_ooool002kooooo00?o0000ooooooooool0D?ooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0T?ooool00ol0003o
ooooooooo`0Mooooo`00;Oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool05oooool2o`00097ooooo00?o0000ooooooooool07Oooool002gooooo00?o
0000ooooooooool0D_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool0TOooool00ol0003oooooooooo`0Looooo`00;?ooool00ol0003oooooooooo`1D
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`2A
ooooo`03o`000?oooooooooo01cooooo000/ooooo`03o`000?oooooooooo05Gooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo09;ooooo00?o0000oooo
ooooool06oooool002cooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool0T_ooool00ol0003oooooooooo`0Kooooo`00
:oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
6_ooool2o`0009Cooooo00?o0000ooooooooool06_ooool002_ooooo00?o0000ooooooooool0Eooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0Tooo
ool00ol0003oooooooooo`0Jooooo`00:_ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooo
oooo00Wooooo00Kok^k^oc8b<_l0003o<S8bonk^k_l00004ooooo`;o8B4Q1?ooool5o`0000Cooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo09Cooooo00?o0000oooooooo
ool06Oooool002[ooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`09ooooo`06ogMg
MonHV9SooooooiRHV?mgMgOo00001?ooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0U?ooool00ol0003oooooooooo`0I
ooooo`00:_ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00Wooooo00Go410@oooo
ooooooooooooo`00000<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`2Eooooo`03o`000?oooooooooo01Sooooo000Yooooo`03o`000?oooooooooo
05_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02o`0000gooooo00?oV9RHob4Q
8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000UOooool00ol0003oooooooooo`0Hoooo
o`00:Oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool00_l0000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005oooo
o`03o`000?oooooooooo09Kooooo00?o0000ooooooooool05oooool002Sooooo00?o0000oooooooo
ool0G_ooool00ol0003oooooooooo`06ooooo`05oa0@4?oooooo0000ooooool@41003oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0U_ooool00ol0
003oooooooooo`0Gooooo`00:?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo00Go
oooo00GoMgMgo`000?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo09Oooooo00?o0000ooooooooool05_ooool0
02Sooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`04ooooo`05o`000?lb<S;o0000
oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oo
oooooooo09Oooooo00?o0000ooooooooool05_ooool002Oooooo00?o0000ooooooooool0HOooool2
o`0000Gooooo00?o0000ooooooooool08?ooool2o`0009Wooooo00?o0000ooooooooool05Oooool0
02Oooooo00?o0000ooooooooool0H_ooool6o`0002?ooooo00?o0000ooooooooool0V?ooool00ol0
003oooooooooo`0Eooooo`009oooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo09Wo
oooo00?o0000ooooooooool05?ooool002Kooooo00?o0000ooooooooool0S?ooool00ol0003ooooo
ooooo`2Iooooo`03o`000?oooooooooo01Cooooo000Vooooo`03o`000?oooooooooo08cooooo00?o
0000ooooooooool0VOooool00ol0003oooooooooo`0Dooooo`009_ooool00ol0003oooooooooo`2<
ooooo`;o0000Voooool00ol0003oooooooooo`0Cooooo`009Oooool00ol0003oooooooooo`2=oooo
o`03o`000?oooooooooo09[ooooo00?o0000ooooooooool04oooool002Gooooo00?o0000oooooooo
ool0SOooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo01;ooooo000Tooooo`03o`00
0?oooooooooo08kooooo00?o0000ooooooooool0Voooool00ol0003oooooooooo`0Booooo`005_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo08kooooo0_l0002Mooooo`03o`000?oo
oooooooo017ooooo000Fooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0S_ooool0
0ol0003oooooooooo`2`ooooo`005oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
08oooooo00?o0000ooooooooool0/?ooool001Oooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`2?ooooo`03o`000?oooooooooo0;3ooooo000Hooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0T?ooool00ol0003oooooooooo`2`ooooo`006Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo097ooooo0_l0002aooooo`006_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo09;ooooo00?o0000ooooooooool0/?ooool001[ooooo0ol000000ooo
oooo0000o`00002Eooooo`03o`000?oooooooooo0;3ooooo000Looooo`?o0000Noooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooo
oooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0002`ooooo`00V_ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`
ooooo`00V_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgM
g@05ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEoooo
o`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009;ooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?oo
ool3o`000;3ooooo002Booooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<oooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`ooooo`00T_oo
ool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co
00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002[ooooo`Co000000?o410@ooooooooool00oooool0
0ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool00:gooooo
00?o0000ooooooooool01Oooool3o`000;3ooooo002]ooooo`03o`000?oooooooooo0;Sooooo002]
ooooo`03o`000?oooooooooo0;Sooooo002]ooooo`03o`000?oooooooooo0;Sooooo002[ooooo`03
oeEEEOmVIVKo00000;[ooooo003oooooofWooooo002_ooooo`03o`000?nj^[[ooooo0;Kooooo002_
ooooo`;o<S8b]oooool0083ooooo0_l000001_l@413oooooooooool@413o0000oa0@41Oooooo1Ol0
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOo0000okZj^P0<ooooo`05oiRH
V?l0003o0000odA4A?nj^[X06_ooool2o`000003oa0@4?oooooooooo00;ooooo00GoA4A4o`000?l0
003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0N?ooool0087ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00002Oooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03olc<c?l0003o410@00cooooo00Go
410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003oooooooooo`06ooooo`09ogMg
Molb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg07Sooooo0021ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool05oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?oooooooooo
ooooool@41004_ooool00ol0003oooooooooo`0Jooooo`Go00002?ooool01?l0003oooooooooool@
4103ooooo`03oa0@4?oooooooooo07Kooooo0021ooooo`06o`000?ooooooA4A4odA4A?oooooo0000
2Oooool6o`0000_ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000001;o
oooo00?o0000ooooooooool02oooool6o`0000Wooooo00CoA4A4omgMgOoooooo00002?ooool01Omg
MgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool0M_ooool0087ooooo00Ko0000omgM
gOlb<S;oEEEEomgMgOl0000Kooooo`03ogMgMomVIVKooooo00;ooooo00Go0000oooooooooooooooo
o`00000Booooo`03o`000?oooooooooo01[ooooo00CogMgMoeEEEOoooooo00001Oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00001hooooo`00POooool01_l0
003oQhN7ojVYZOnj^[[oEEEEo`0001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@
4?oooooooooo00kooooo00?o410@o`000?l000000ol0000Jooooo`03ogMgMoo<c<co000000Gooooo
00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@07Sooooo0021ooooo`06o`00
0?lb<S;ooooooooooolb<S;o00006?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0Booooo`03o`000?oooooooooo01_ooooo00?ok^k^odA4A?l000001Ooo
ool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0N?ooool0083ooooo00?o
410@o`000?n7QhL00_ooool00on7QhOo0000oa0@400Gooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo00?o0000ooooooooool07?ooool00omgMgOo
0000ooooo`04ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07Sooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(460) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .4102 m
.00942 .43389 L
.01483 .44568 L
.01975 .45443 L
.02243 .45817 L
.02496 .46095 L
.02634 .46214 L
.02763 .46301 L
.02903 .46372 L
.02974 .46397 L
.03053 .46417 L
.03183 .46432 L
.03302 .46424 L
.0344 .4639 L
.03571 .46334 L
.03691 .46261 L
.03803 .46175 L
.04057 .45918 L
.04334 .45542 L
.04635 .45033 L
.0518 .43876 L
.06198 .4118 L
.08481 .34838 L
.09564 .3237 L
.10574 .30535 L
.11629 .29112 L
.12187 .28535 L
.12786 .2802 L
.13854 .2729 L
.14418 .26978 L
.15016 .26696 L
.15538 .26495 L
.16114 .26321 L
.16637 .26201 L
.17129 .26115 L
.18161 .25971 L
.19248 .25829 L
.19697 .25776 L
.20176 .2573 L
.20318 .25719 L
.20452 .25711 L
.20582 .25704 L
.20702 .25699 L
.20816 .25696 L
.20937 .25693 L
.21058 .25692 L
.21191 .25693 L
.21327 .25694 L
.21453 .25697 L
.21591 .25702 L
Mistroke
.21739 .25709 L
.22011 .25724 L
.22258 .25741 L
.23233 .25826 L
.23777 .2588 L
.24364 .25952 L
.24918 .26045 L
.25427 .26163 L
.25922 .26315 L
.26452 .26524 L
.27408 .27019 L
.28544 .27801 L
.29579 .28746 L
.30622 .30024 L
.31587 .31536 L
.33768 .35742 L
.34714 .37602 L
.35732 .39349 L
.36016 .39751 L
.36315 .40117 L
.36592 .40398 L
.36849 .40603 L
.36974 .40682 L
.37091 .40744 L
.37227 .40799 L
.37349 .40833 L
.37486 .40855 L
.37612 .40858 L
.3775 .40845 L
.3782 .40831 L
.37896 .4081 L
.38033 .40758 L
.38159 .40695 L
.38445 .40495 L
.38698 .40259 L
.38966 .3995 L
.39942 .38422 L
.42138 .33977 L
.43143 .31943 L
.44203 .29996 L
.45184 .28512 L
.46098 .27467 L
.47067 .26653 L
.48127 .25948 L
.49185 .25357 L
.49489 .25217 L
.49777 .25102 L
.50055 .25009 L
.50316 .24941 L
.5055 .24895 L
Mistroke
.50681 .24875 L
.50801 .24861 L
.50932 .2485 L
.51006 .24846 L
.51075 .24843 L
.51201 .2484 L
.51335 .24841 L
.51408 .24843 L
.51475 .24846 L
.51549 .2485 L
.51627 .24855 L
.51901 .2488 L
.52146 .24909 L
.52415 .24946 L
.5341 .25099 L
.53899 .25182 L
.54351 .25277 L
.54865 .25423 L
.55136 .25525 L
.55424 .25655 L
.56402 .26277 L
.57446 .27193 L
.58598 .28336 L
.60802 .30832 L
.61767 .32105 L
.62277 .32757 L
.62822 .33384 L
.63359 .33893 L
.63848 .34242 L
.64083 .34369 L
.64339 .34477 L
.64456 .34516 L
.6458 .34552 L
.64694 .34578 L
.64802 .34598 L
.64931 .34616 L
.65049 .34626 L
.65176 .34631 L
.65315 .3463 L
.65435 .34624 L
.65564 .34611 L
.65685 .34594 L
.65794 .34575 L
.66065 .3451 L
.66357 .34414 L
.66886 .34167 L
.67404 .33831 L
.67887 .3343 L
.68985 .32232 L
.70123 .30781 L
Mistroke
.71199 .2953 L
.73341 .27734 L
.74269 .27105 L
.74797 .26792 L
.75292 .26547 L
.75782 .26366 L
.76057 .26293 L
.76309 .26244 L
.76446 .26225 L
.76573 .26211 L
.76645 .26205 L
.76713 .26201 L
.76791 .26196 L
.76862 .26194 L
.76994 .26191 L
.77115 .26191 L
.77248 .26194 L
.77314 .26196 L
.77388 .26199 L
.77641 .26214 L
.77871 .2623 L
.78389 .26272 L
.79324 .26344 L
.79828 .26389 L
.80083 .26419 L
.80364 .26462 L
.80861 .26565 L
.81327 .26699 L
.83506 .27567 L
.87567 .28797 L
.8967 .29257 L
.90221 .29325 L
.90741 .294 L
.91341 .29522 L
.91886 .29674 L
.9288 .30056 L
.93957 .30607 L
.94445 .30918 L
.94961 .31315 L
.95886 .32269 L
.96403 .32975 L
.96876 .33739 L
.9794 .3586 L
.99863 .4066 L
1 .4102 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000/Oooool0
0;Gooooo2ol0002Xooooo`00/Oooool5o`0000[ooooo1?l0002Tooooo`00/?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00cooooo1?l0002Pooooo`00C_oooolGo`0004[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo09gooooo001:
ooooo`Co00005oooool3o`0004Kooooo00?o0000ooooooooool01?ooool2o`0001;ooooo0_l0000m
ooooo`[o0000E_ooool004Kooooo1?l0000Nooooo`Co0000@Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0=oooool3o`0000[ooooo1ol0001?oooo
o`005Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00Go
V9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000o`000?o^k^h06oooool5o`0000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Looooo`Co000000So410@ooooooooooook^k^oc8b<_l0
003o<S8bonk^kQCooooo0_l00008ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
2?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hJooooo`Go000000Sooooo
o`000?l0003ok^k^oc8b<_l0003o<S8bonk^kPoooooo0_l0000:ooooo`05oiRHV?l@413o0000oc8b
<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo0_l000002Ol@413ooooooooooooo
ooook^k^oc8b<_l0003o<S8bonk^kP0>ooooo`005_ooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL06_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgo`00
0?l0003oV9RHogMgM`0Kooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool00omgMgOoV9RHoooo
o`02o`0001kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo
0_l0000:ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01?nHV9So8B4Qonk^k_ooool2o`00
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Aooooo`?o00001oooool01Ol@413o^[Zjoooooomg
MgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`002oooool6o`0000;ooooo1Ol00003ooooo`05oa0@
4?ooooooooooooooool@41004_ooool6o`0000Kooooo00?o0000ooooooooool00_l00003ooooo`03
oa0@4?oooooooooo017ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooo
oooooooooa0@4002o`00017ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@400Aooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
400Kooooo`03oiRHV?lQ8B7o000000Cooooo00Go410@oooooooooooooooooa0@400Dooooo`;o0000
2Oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool06Oooool5o`0000?o
oooo00Go410@oooooooooooooooooa0@400>ooooo`004oooool01?m4A4CogMgMooooool00004oooo
o`05o`000?ooooooooooooooool000007Oooool01_nYZJWo410@o`000?l0003oooooo`0000?ooooo
00?o0000ooooooooool06oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool0
00000_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`00000Aooooo`03o`000?oooooooooo00[ooooo0_l0000Gooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001_ooooo0_l00000
0olQ8B7ok^k^ooooo`02ooooo`05o`000?ooooooooooooooool000005_ooool3o`0000Gooooo00?o
ZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000001_ooooo00CoA4A4omgMgOoooooo
00001?ooool01Ol0003ooooooooooooooooo000000kooooo000Cooooo`04omgMgOmEEEGoooooo`00
00Cooooo00Go0000ooooooooooooooooo`00000Looooo`03oa0@4?l0003o000000?ooooo00Go0000
ooooooooooooooooo`00000Nooooo`03ogMgMomVIVKooooo00;ooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo0000013ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
01[ooooo00Go0000ooooooooooooMgMgofIVIP03ooooo`05o`000?ooooooooooooooool000006Ooo
ool4o`000003oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00000Kooooo`04omgM
gOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`005?ooool00omgMgOo
c<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41007Oooool00ol0003o8B4Qooooo`02oooo
o`05oa0@4?ooooooooooooooool@41007oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o
410@ooooooooool00_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Iooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooooa0@4003oooo
o`03oa0@4?oooooooooo01_ooooo1?l00002ooooo`05oa0@4?ooooooooooooooool@41007?ooool0
0omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41003_ooool001Cooooo00?ok^k^
odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00Go410@oiRHV?l0003o^[Zj
o`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool01Ol0003o^[ZjoooooonHV9So410@
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00oooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01Sooooo00Oo0000ooooool0003o^[ZjoooooonHV9So410@
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`06oa0@4?nHV9SooooookZj^_l0003ooooo
1?l000000oooooooV9RHogMgM`0Looooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0>ooooo`005Oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h06_ooool01OnYZJWo0000o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0K
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
00?o0000ooooooooool05?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool00oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h05oooool02?l0
003ooooooooooonHV9So410@o`000?lQ8B7oc<c<0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`03onk^k_lb<S;o000000;o00007Oooool00omg
MgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool003_ooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00kooooo0_l0000Koooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0=_ooool6o`00033ooooo000jooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0mooooo`Go
0000:oooool003Wooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo04;ooooo0_l0000Yooooo`00>?ooool00ol0003oooooooooo`0looooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool0AOooool2o`0002Oooooo000gooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooo
oooo02Cooooo000Foooooooo0000@?l0000Cooooo`005_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
000000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Aooooo`005_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool04Oooool003Gooooo00?o0000ooooooooool0@_ooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool07oooool003Gooooo
00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05?ooooo
00?o0000ooooooooool07_ooool003Cooooo00?o0000ooooooooool0A?ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo01Cooooo0_l0000Tooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool0Doooool00ol0003oooooooooo`0Nooooo`00=?ooool00ol0003oooooooooo`15
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0M
ooooo`00<oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0Eoooool00ol0003oooooooooo`0Looooo`00<oooool00ol0003oooooooooo`17ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo00cooooo0_l0001Jooooo`03o`000?oooooooooo01cooooo000cooooo`03o`00
0?oooooooooo04Oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`03o`00
0?oooooooooo01_ooooo000booooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0Fooooo`;o0000:?ooool2o`0000_ooooo00?o0000ooooooooool0Fooo
ool00ol0003oooooooooo`0Kooooo`00<_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Yooooo`;o00001_ooool3
o`0005oooooo00?o0000ooooooooool06_ooool003;ooooo00?o0000ooooooooool0B_ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0:oooool6o`00
06;ooooo00?o0000ooooooooool06_ooool0037ooooo00?o0000ooooooooool0Boooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0U?ooool00ol0003o
ooooooooo`0Iooooo`00<Oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`2Eooooo`03o`000?oooooooooo01Sooooo
000`ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0Hooooo`;o0000U_ooool00ol0003oooooooooo`0Hooooo`00<?ooool00ol0003oooooooooo`1>
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`2F
ooooo`03o`000?oooooooooo01Oooooo000`ooooo`03o`000?oooooooooo04kooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo09Kooooo00?o0000oooo
ooooool05oooool002oooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool0Uoooool00ol0003oooooooooo`0Fooooo`00
;oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`2Gooooo`03o`000?oooooooooo01Kooooo000^ooooo`03o`000?oo
oooooooo05;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Kooooo`;o0000V?oo
ool00ol0003oooooooooo`0Fooooo`00;_ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`2Hooooo`03o`000?oooooo
oooo01Gooooo000^ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool02oooool01Oo^
k^ko<S8bo`000?lb<S;o000000Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`0Eooooo`00;Oooool0
0ol0003oooooooooo`1Eooooo`03o`000?oooooooooo00[ooooo00GoMgMgoiRHV?ooooooV9RHo`00
0005ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2Iooooo`03o`000?oooooooooo01Cooooo000]ooooo`03o`000?oo
oooooooo05Gooooo00?o0000ooooooooool02_ooool01Ol@413oooooooooool0003o410@00cooooo
00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09Wooooo
00?o0000ooooooooool05?ooool002cooooo00?o0000ooooooooool0Eoooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00;o00003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol0002Iooooo`03o`000?oooooooooo01Cooooo000/ooooo`03o`000?oooooo
oooo05Oooooo00?o0000ooooooooool02Oooool01Ol0003oooooo`000?oooooo000000kooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
V_ooool00ol0003oooooooooo`0Cooooo`00;?ooool00ol0003oooooooooo`1Hooooo`03o`000?oo
oooooooo00Sooooo00Go410@o`000?oooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo01?ooooo
000[ooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool01oooool01OmgMgOo0000oooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0Voooool00ol0003oooooooooo`0Booooo`00:oooool00ol0003ooooo
ooooo`1Kooooo`03o`000?oooooooooo00Kooooo00Go0000oc8b<_l0003o<S8bonk^kP0;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool0Voooool00ol0
003oooooooooo`0Booooo`00:_ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool08Oooool2o`0009cooooo00?o0000ooooooooool04_ooool002[ooooo
00?o0000ooooooooool0G_ooool2o`0000;ooooo0_l0000Tooooo`03o`000?oooooooooo09cooooo
00?o0000ooooooooool04Oooool001Kooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`1Oooooo`Co00009Oooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo017ooooo000F
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`2`
ooooo`005oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo08Wooooo00?o0000oooo
ooooool0/?ooool001Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2:ooooo`;o
0000/Oooool001Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2:ooooo`03o`00
0?oooooooooo0;3ooooo000Hooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0R_oo
ool00ol0003oooooooooo`2`ooooo`006?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo08_ooooo00?o0000ooooooooool0/?ooool001Sooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`2;ooooo`;o0000/Oooool001Wooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`2;ooooo`03o`000?oooooooooo0;3ooooo000Iooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0S?ooool00ol0003oooooooooo`2`ooooo`006Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool0/?ooool001[ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`2=ooooo`03o`000?oooooooooo0;3ooooo000Joooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0SOooool2o`000;7ooooo000Kooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0S_ooool00ol0003oooooooooo`2`ooooo`00
7?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08kooooo00?o0000ooooooooool0
/?ooool001cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1dooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0;3ooooo000Mooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
M?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0/?ooool001kooooo0_l000000ooooooo0000o`00001gooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`?o0000/?ooool001oooooo
0_l0001iooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo0;3ooooo002Jooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool009;ooooo00Go410@oooooooooooooooooa0@400=oooo
o`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000ooooooooooooooooo`00000>oooo
o`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002a
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00:_ooooo1?l000000ol@413o
ooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0/?ooool00:gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooo
ooooool0^?ooool00:gooooo00?o0000ooooooooool0^?ooool00:gooooo00?o0000ooooooooool0
^?ooool00:_ooooo00?oEEEEofIVI_l00000^_ooool00?ooooooJOooool00:oooooo00?o0000okZj
^_ooool0]_ooool00:oooooo0_lb<S:gooooo`00P?ooool2o`000006oa0@4?oooooooooooa0@4?l0
003o410@5oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`03ohN7Qol0003o
^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Jooooo`;o000000Wo410@oooooooooooooooo
onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07Sooooo0021oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`0000Wooooo00GoV9RHob4Q
8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool00oo<c<co0000oa0@
400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000cooooo00?o0000ooooooooool0
0_ooool01OmEEEGoMgMgoooooonHV9So8B4Q00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1hoooo
o`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Oooooo00?oV9RHob4Q8Oo^
k^h01?ooool01Ol@413ooooooooooooooooo410@01;ooooo00?o0000ooooooooool06_ooool5o`00
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05oa0@4?ooooooooooooooool@4100N?oo
ool0087ooooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00002oooool00onHV9So8B4Q
onk^kP03ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0;ooooo`Ko
00002Oooool01?m4A4CogMgMooooool00004ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool0
1Ol0003ooooooooooooooooo000007Sooooo0021ooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo0000
6oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003o
ooooooooo`0Jooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000oeEEEOl0003o410@olc<c003
ooooo`05o`000?ooooooooooooooool00000N?ooool0087ooooo00Ko0000ohN7QonYZJWo^[ZjoeEE
EOl0000Looooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0>ooooo`03
oa0@4?l0003o000000?o00006_ooool00omgMgOoc<c<o`000004ooooo`03oeEEEOn7QhOooooo00Go
oooo00Go410@oooooooooooooooooa0@401hooooo`00POooool01_l0003o<S8boooooooooooo<S8b
o`0001Sooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
4_ooool00ol0003oooooooooo`0Kooooo`03onk^k_m4A4Co000000Cooooo00?ogMgMoa0@4?nHV9P0
1Oooool01OmgMgOoV9RHoooooonHV9SoMgMg07Sooooo0020ooooo`03oa0@4?l0003oQhN700;ooooo
00?oQhN7o`000?l@41005oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0Booooo`03o`000?oooooooooo01cooooo00?oMgMgo`000?ooool01?ooool01?o<
c<coA4A4o`000?l@4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0N?ooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(470) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .38487 m
.00942 .41264 L
.01975 .44151 L
.02496 .4533 L
.02782 .45856 L
.03053 .4626 L
.03305 .46548 L
.03447 .46671 L
.03578 .46759 L
.03689 .46814 L
.03811 .46853 L
.03938 .46871 L
.04057 .46867 L
.04125 .46855 L
.04198 .46835 L
.0433 .46779 L
.0441 .46734 L
.04486 .46682 L
.04627 .46564 L
.04888 .46279 L
.0517 .45873 L
.057 .44868 L
.06188 .43711 L
.08481 .36944 L
.09435 .3431 L
.10457 .31998 L
.1158 .30089 L
.12627 .28756 L
.13695 .27718 L
.14259 .27288 L
.14857 .2692 L
.15379 .2667 L
.15955 .26456 L
.1697 .26176 L
.1796 .25947 L
.19001 .25737 L
.19265 .25695 L
.19547 .25658 L
.19709 .25641 L
.19856 .25627 L
.20006 .25616 L
.20144 .25608 L
.20269 .25602 L
.20402 .25598 L
.20536 .25596 L
.20612 .25595 L
.20683 .25595 L
.20811 .25596 L
.20928 .25598 L
.21063 .25601 L
Mistroke
.21191 .25605 L
.21721 .25629 L
.22201 .25655 L
.22717 .25684 L
.23275 .2572 L
.23527 .25741 L
.23794 .25767 L
.24041 .25797 L
.24271 .25831 L
.24717 .25917 L
.25207 .26047 L
.25734 .2623 L
.26307 .26477 L
.27348 .27045 L
.28362 .27765 L
.29298 .28651 L
.30311 .29942 L
.31262 .31483 L
.33426 .35807 L
.34461 .37944 L
.35026 .39 L
.3555 .39844 L
.35999 .40423 L
.36251 .40676 L
.36479 .40856 L
.36601 .40933 L
.3673 .40998 L
.36797 .41025 L
.36871 .4105 L
.37001 .4108 L
.37124 .41093 L
.37256 .4109 L
.3738 .41071 L
.37494 .41039 L
.37617 .4099 L
.37733 .40931 L
.37998 .40746 L
.38255 .40504 L
.38533 .40178 L
.39495 .3863 L
.41674 .33939 L
.43735 .29772 L
.44903 .28046 L
.45991 .26886 L
.47043 .26051 L
.48 .25468 L
.4853 .25223 L
.48809 .25121 L
.49104 .25033 L
.49363 .24975 L
Mistroke
.49509 .2495 L
.49647 .24931 L
.49773 .24918 L
.49888 .24909 L
.50021 .24903 L
.50148 .24901 L
.50279 .24902 L
.50352 .24904 L
.5042 .24907 L
.50545 .24914 L
.50676 .24925 L
.50905 .24949 L
.51155 .24983 L
.51711 .25081 L
.52229 .25194 L
.53161 .25465 L
.53684 .25679 L
.5416 .25929 L
.55202 .26685 L
.56166 .27595 L
.58346 .29955 L
.60474 .32548 L
.60982 .33129 L
.61516 .33657 L
.61972 .34016 L
.62234 .34177 L
.62471 .34294 L
.62589 .34342 L
.62717 .34387 L
.62828 .34419 L
.62949 .34447 L
.63079 .3447 L
.63215 .34485 L
.63342 .34493 L
.6346 .34494 L
.63579 .34489 L
.63692 .3448 L
.63793 .34467 L
.63904 .3445 L
.64151 .34395 L
.6438 .34328 L
.64903 .34118 L
.65377 .33865 L
.66437 .33072 L
.68634 .30595 L
.69597 .29533 L
.70652 .28635 L
.72625 .27428 L
.73146 .27149 L
.73703 .26889 L
Mistroke
.73973 .26783 L
.74229 .267 L
.74458 .2664 L
.74588 .26612 L
.74707 .26591 L
.74825 .26575 L
.74953 .26561 L
.75089 .26551 L
.75218 .26546 L
.75339 .26545 L
.75467 .26547 L
.75588 .26553 L
.75698 .2656 L
.75838 .26572 L
.75967 .26586 L
.76259 .26624 L
.76789 .26703 L
.77931 .26841 L
.78488 .26892 L
.78732 .26917 L
.78997 .2695 L
.79251 .26989 L
.79486 .27034 L
.7995 .27148 L
.80446 .27309 L
.80972 .2751 L
.82016 .27903 L
.82302 .27991 L
.82603 .28069 L
.82863 .28125 L
.83142 .28174 L
.83647 .28241 L
.84117 .28292 L
.85185 .28438 L
.86183 .2863 L
.86622 .28707 L
.86871 .28742 L
.87104 .28766 L
.87236 .28776 L
.87356 .28783 L
.87494 .28788 L
.87626 .28789 L
.87763 .28787 L
.87891 .28783 L
.87964 .28779 L
.8803 .28775 L
.88179 .28765 L
.88467 .28737 L
.88779 .287 L
.89049 .28667 L
Mistroke
.89344 .28634 L
.89478 .28621 L
.89622 .28608 L
.89746 .28599 L
.89881 .28592 L
.8996 .28589 L
.90033 .28586 L
.90103 .28585 L
.90177 .28584 L
.90305 .28584 L
.90378 .28586 L
.90447 .28587 L
.90571 .28592 L
.90701 .286 L
.90935 .28618 L
.91186 .28644 L
.9146 .28678 L
.92521 .28834 L
.93042 .28921 L
.93522 .29018 L
.93791 .29088 L
.94076 .29178 L
.94386 .29302 L
.94676 .29447 L
.95175 .29774 L
.95723 .30258 L
.96818 .31622 L
.97857 .33374 L
.99804 .37934 L
1 .38487 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000/Oooool0
0;;ooooo2?l0002^ooooo`00/?ooool2o`0000?ooooo00?o0000ooooooooool00_ooool5o`000:Wo
oooo001Dooooo`[o0000D?ooool2o`0000Gooooo00?o0000ooooooooool01oooool2o`000:Oooooo
001>ooooo`Ko00002_ooool8o`0004Kooooo0_l00007ooooo`03o`000?oooooooooo00Wooooo0_l0
002Uooooo`00B_ooool4o`0001Sooooo0ol00011ooooo`;o00002Oooool2o`0000cooooo00?o0000
ooooooooool0X_ooool004Sooooo0_l0000Oooooo`;o0000?_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool0??ooool6o`0005oooooo000Eooooo`;o
000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h06_ooool01OnHV9So410@o`00
0?lb<S;oc<c<00?ooooo00?ok^k^oc8b<_l000000ol0000Jooooo`Go00000oooool01Oo^k^ko0000
o`000?lb<S;ok^k^01cooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^4Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00gooooo0_l0000@ooooo`Co000000So
410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQ[ooooo1ol000000oooooook^k^oc8b<P0:o`00
01Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Ooo
ool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Fooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S800oooool01OmgMgOoV9RHo`000?nHV9SoMgMg01_ooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A003ooooo`03ogMgMonHV9Sooooo00;o00007_ooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL04Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL06_ooool01OnHV9So0000o`000?ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`07ooooo`Go00003oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>oooo
o`002oooool6o`0000;ooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41004_ooool6o`00
00Kooooo00Co0000oooooooooooooooo0_l00002ooooo`03oa0@4?oooooooooo017ooooo1_l00003
ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Ko410@oooooooooooooooooa0@4?l0000Booooo`Ko0000
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41006Oooool2o`000003oiRHV?lQ8B7ok^k^
00Cooooo00Go410@oooooooooooooooooa0@400<ooooo`?o00004?ooool01Ol0003ooooooooooooo
oooo410@00?ooooo00?o410@ooooooooool06Oooool5o`0000?ooooo00Go410@oooooooooooooooo
oa0@400>ooooo`004oooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool0
00007Oooool01?nYZJWo410@ooooooooool2o`0000?ooooo00?o0000ooooooooool06oooool00onH
V9So8B4Qonk^kP03ooooo`07o`000?ooooooooooooooool0003oooooo`00000Looooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo00cooooo
0_l0000Booooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000001Sooooo00Oo0000oooooooooooooooooiRHV?lQ8B7ok^k^00?ooooo00Go0000
ooooooooooooooooo`00000?ooooo`;o00003Oooool00onYZJWo410@ooooo`02ooooo`05o`000?oo
ooooooooooooool000006oooool01?m4A4CogMgMooooool00004ooooo`05o`000?oooooooooooooo
ool000003_ooool001?ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo
000001cooooo00Oo410@o`000?nj^[[oooooo`000?oooooo000000?ooooo00?o0000ooooooooool0
7?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000>oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Fooooo`;o00001Oooool0
0omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000004Oooool5o`0000Oooooo00?o
410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000001_ooooo00CogMgMoeEEEOoooooo
00001?ooool01Ol0003ooooooooooooooooo000000kooooo000Dooooo`03ogMgMoo<c<co000000Co
oooo00Go410@oooooooooooooooooa0@400Mooooo`03okZj^_lQ8B7o000000;ooooo00Go410@oooo
oooooooooooooa0@400Oooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooo
oooooooo000001[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01Gooooo00?o0000oooo
ooooool01_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool05?ooool8
o`000003okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@400Looooo`03ogMgMoo<
c<co000000Cooooo00Go410@oooooooooooooooooa0@400>ooooo`005?ooool00oo^k^koA4A4o`00
0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01Ol@413oV9RHoooooonj^[[o000000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03Oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL04oooool2o`0000Gooooo00Go0000okZj^_ooooooV9RHoa0@4003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL06oooool00ol@413oV9RHooooo`0Do`0001;ooooo00?ok^k^
odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000Eooooo`03ogMgMol0003o
oooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Jooooo`05ojVYZOl@413o0000oa0@4?l00000
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool00ol0003oooooooooo`0Eooooo`03oeEEEOmVIVKo
000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`08ooooo`03oeEEEOmVIVKo000000Cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0Booooo`03o`000?oooooooooo00Gooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool01OnYZJWo410@o`000?l@413o
ZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0:ooooo`Go00003_ooool00omgMgOo0000oooo
o`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool003gooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00oooooo0_l0000Fooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool0B_ooool2o`0002Gooooo000looooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1=ooooo`;o00008oooool0
03cooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
053ooooo00?o0000ooooooooool08?ooool003_ooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool07oooool003_ooooo
00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05Cooooo
00?o0000ooooooooool07_ooool001Koooooool00010o`0001?ooooo000Fooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooo000000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool04Oooool001Kooooo00?o0000oooooooo
ool08?ooool01Ol0003ooooooooooooooooo000002Oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo017ooooo000hooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo01_o
oooo000gooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`1Looooo`03o`000?oooooooooo01[ooooo000gooooo`03o`000?oooooooooo043ooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`0Eooooo`;o00007oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool06_ooool003Kooooo00?o0000
ooooooooool0@_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05oooooo00?o0000
ooooooooool06Oooool003Kooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo063ooooo00?o0000ooooooooool06Oooool003Gooooo00?o0000oooooooo
ool0A?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo06;ooooo00?o0000oooooooo
ool06?ooool003Gooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo06?ooooo00?o0000ooooooooool06?ooool003Gooooo00?o0000ooooooooool0AOoo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Sooooo0_l0000Tooooo`03o`000?oo
oooooooo00Kooooo0ol0001Wooooo`03o`000?oooooooooo01Oooooo000dooooo`03o`000?oooooo
oooo04Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo02Cooooo1?l000001?oooooo0000o`000?l0001Zooooo`03o`000?oooooooooo01Oooooo000d
ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo02Oooooo0_l0001]ooooo`03o`000?oooooooooo01Oooooo000coooo
o`03o`000?oooooooooo04Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo09Oooooo00?o0000ooooooooool05_ooool003?ooooo00?o0000oooooooo
ool0BOooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0Uoooool00ol0003oooooooooo`0Fooooo`00<oooool00ol0003oooooooooo`19ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool06_ooool2o`0009Wooooo00?o0000ooooooooool0
5Oooool003;ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`0Eooooo`00<_ooool0
0ol0003oooooooooo`1;ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`2Hooooo`03o`000?oooooooooo01Gooooo000booooo`03o`000?oooooooooo
04cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
09Wooooo00?o0000ooooooooool05?ooool0037ooooo00?o0000ooooooooool0COooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0VOooool00ol0003o
ooooooooo`0Dooooo`00<Oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool07?ooool2o`0009_ooooo00?o0000ooooooooool04oooool0033ooooo00?o
0000ooooooooool0Coooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool0V_ooool00ol0003oooooooooo`0Cooooo`00<?ooool00ol0003oooooooooo`1?
ooooo`03o`000?oooooooooo00gooooo00Gok^k^oc8b<_l0003o0000onk^kP05ooooo`;o8B4Q1?oo
ool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo09[ooooo
00?o0000ooooooooool04oooool0033ooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0<ooooo`05ogMgMonHV9So0000oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0Voooool00ol0003o
ooooooooo`0Booooo`005_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo057ooooo
00?o0000ooooooooool03?ooool01Ol@413oooooo`000?oooooo410@00cooooo00?oV9RHob4Q8Oo^
k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09cooooo00?o0000oooooooo
ool04Oooool001Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1Booooo`03o`00
0?oooooooooo00_ooooo0_l00002ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool001Oooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo00[ooooo0_l00002ooooo`03o`000?oo
oooooooo00cooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool0/?ooool001Oooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`1Dooooo`03o`000?oooooooooo00[ooooo00Go0000oooooooooooooooooa0@400?ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`005ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool02?oo
ool01_l0003oMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4004oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool001Sooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo00Oooooo00Ko0000onk^k_lb
<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o
0000ooooooooool0/?ooool001Sooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1H
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08_ooool2o`000;7ooooo000Hoooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0/?ooool001Wooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`1Kooooo`;o000000?oooooo`000?l000009_ooool00ol0003o
ooooooooo`2`ooooo`006Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05cooooo
0ol0000Wooooo`03o`000?oooooooooo0;3ooooo000Iooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0Q_ooool00ol0003oooooooooo`2`ooooo`006_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo08Oooooo0_l0002aooooo`006_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo08Oooooo00?o0000ooooooooool0/?ooool001[ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo0;3ooooo000Kooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`2`ooooo`006ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo08Sooooo0_l0002aooooo`006oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool0/?ooool0
01cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo
0;3ooooo000Looooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0ROooool00ol0003o
ooooooooo`2`ooooo`007?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo08Wooooo
00?o0000ooooooooool0/?ooool001gooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`2:ooooo`;o0000/Oooool001gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2:
ooooo`03o`000?oooooooooo0;3ooooo000Nooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0R_ooool00ol0003oooooooooo`2`ooooo`007_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo073ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool001oooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`1aooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`007oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00Go410@oooooooooooooooooa0@400@
ooooo`03o`000?oooooooooo00?ooooo0ol0002`ooooo`008?ooool2o`0000;ooooo00?o0000oooo
ooooool0Loooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`2`ooooo`008Oooool4o`0007Gooooo00Go0000ooooooooooooooooo`00000<
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`ooooo`00V_ooool0
1Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0
0006ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool0
09;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00T_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooo
oooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo0;3ooooo002Booooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00T_ooool01Ol0003ooooooooooooo
oooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool0/?ooool009;ooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVY
ZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Zoooool4
o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool00:gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo0ol0002`ooooo`00[Ooo
ool00ol0003oooooooooo`2hooooo`00[Oooool00ol0003oooooooooo`2hooooo`00[Oooool00ol0
003oooooooooo`2hooooo`00Zoooool00omEEEGoIVIVo`00002jooooo`00oooooomYooooo`00[ooo
ool00ol0003o^[Zjooooo`2fooooo`00[oooool2oc8b<[Oooooo0020ooooo`;o000000Ko410@oooo
oooooooo410@o`000?l@410Gooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01[ooooo0_l000000ol@413o
ooooooooo`03ooooo`03o`000?o^k^kooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1hoooo
o`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l00009ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?oc<c<
o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<ooooo`03o`000?oo
oooooooo00Cooooo00?oEEEEojVYZOooool00oooool01OmgMgOoV9RHoooooonHV9SoMgMg07Sooooo
0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@41004_ooool00ol0003oooooooooo`0Jooooo`Go0000
1Oooool00onYZJWoEEEEooooo`03ooooo`05oa0@4?ooooooooooooooool@4100N?ooool0087ooooo
00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00002oooool00onHV9So8B4Qonk^kP03oooo
o`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0;ooooo`Ko00002Oooool0
1?m4A4CogMgMooooool00007ooooo`03ob4Q8Ooooooooooo00;ooooo00Go0000oooooooooooooooo
o`00001hooooo`00POooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001_ooooo00?oMgMgofIVI_oo
ool00_ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool06_ooool01?oM
gMgoEEEEooooool00007ooooo`03oeEEEOo<c<cooooo00;ooooo00Go0000ooooooooooooooooo`00
001hooooo`00POooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001cooooo00Go0000oooooooooooo
oooooa0@4003ooooo`03oa0@4?oooooooooo00kooooo00?o410@o`000?l000000ol0000Jooooo`03
ogMgMoo<c<co000000Oooooo00?oZJVYogMgMoooool00_ooool01Ol@413ooooooooooooooooo410@
07Sooooo0021ooooo`06o`000?lb<S;ooooooooooolb<S;o00006?ooool01Ol0003o^[ZjoooooonH
V9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Booooo`03o`000?oooooooooo01_ooooo
00?ok^k^odA4A?l000001?ooool01Ol@413ooooooooooooooooo<S8b00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`1hooooo`00P?ooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Oo
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool0
0ol0003oooooooooo`0Looooo`03ogMgMol0003ooooo00?ooooo1Ol00003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h0N?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(480) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .3598 m
.01975 .41937 L
.02981 .44666 L
.03544 .45855 L
.03811 .46301 L
.04057 .46636 L
.04326 .46913 L
.04468 .47019 L
.04541 .47062 L
.04619 .471 L
.04749 .47143 L
.04871 .4716 L
.04946 .4716 L
.05017 .47151 L
.0515 .47115 L
.05272 .47058 L
.05402 .46972 L
.05637 .46753 L
.05915 .46387 L
.06168 .4596 L
.0674 .44698 L
.07359 .42971 L
.08481 .39394 L
.10533 .33544 L
.11698 .31079 L
.12786 .29279 L
.13324 .28572 L
.13833 .28018 L
.14787 .27253 L
.15321 .26946 L
.15815 .26709 L
.16932 .26247 L
.17876 .25909 L
.18406 .25759 L
.18658 .25703 L
.18892 .2566 L
.19152 .25622 L
.19301 .25606 L
.19436 .25594 L
.19578 .25583 L
.19712 .25576 L
.19854 .25571 L
.19934 .25568 L
.20008 .25567 L
.20133 .25565 L
.2025 .25565 L
.20379 .25565 L
.20517 .25565 L
.20586 .25566 L
.20661 .25567 L
Mistroke
.20798 .25568 L
.20923 .25569 L
.21055 .2557 L
.21122 .2557 L
.21196 .2557 L
.21324 .2557 L
.21397 .2557 L
.21475 .25569 L
.21548 .25569 L
.21615 .25568 L
.21886 .25564 L
.22142 .25559 L
.2237 .25555 L
.22486 .25553 L
.22613 .25552 L
.2275 .25552 L
.22879 .25553 L
.22998 .25555 L
.23125 .25559 L
.23192 .25562 L
.23264 .25565 L
.23393 .25574 L
.23547 .25587 L
.23686 .25602 L
.23989 .25646 L
.24275 .25702 L
.24781 .25835 L
.25329 .26025 L
.26325 .26464 L
.2742 .27087 L
.27971 .27491 L
.28563 .28025 L
.29631 .29319 L
.30697 .31047 L
.31858 .33325 L
.3397 .37975 L
.34484 .39028 L
.35039 .40017 L
.35294 .404 L
.35563 .40744 L
.35795 .40988 L
.36044 .4119 L
.3618 .41272 L
.36303 .4133 L
.36427 .41372 L
.36544 .41396 L
.36681 .41404 L
.36807 .41393 L
.36945 .41362 L
.37015 .41338 L
Mistroke
.37092 .41305 L
.37242 .41223 L
.3738 .41128 L
.37689 .40843 L
.37976 .40499 L
.38249 .40107 L
.39256 .38229 L
.4033 .35785 L
.42261 .31339 L
.43342 .29296 L
.44511 .27643 L
.45615 .26544 L
.46629 .25814 L
.47123 .25542 L
.47395 .25417 L
.47653 .25317 L
.47892 .25239 L
.48152 .25172 L
.48267 .25148 L
.48389 .25127 L
.48495 .25112 L
.48608 .25099 L
.48741 .25089 L
.48864 .25083 L
.48996 .25082 L
.4907 .25083 L
.4914 .25085 L
.49266 .25092 L
.49381 .25101 L
.49514 .25115 L
.49639 .25132 L
.49924 .2518 L
.50186 .25237 L
.50778 .25398 L
.51797 .2577 L
.52749 .26258 L
.53296 .26625 L
.53795 .27023 L
.54917 .28112 L
.57085 .30534 L
.5814 .31727 L
.59094 .32767 L
.59576 .3324 L
.60097 .33676 L
.60337 .33843 L
.60589 .33993 L
.60825 .34108 L
.61041 .3419 L
.61159 .34226 L
.61288 .34257 L
Mistroke
.61424 .34282 L
.61552 .34297 L
.61673 .34305 L
.618 .34306 L
.61909 .34301 L
.62029 .3429 L
.62101 .34281 L
.6217 .3427 L
.62298 .34245 L
.62588 .34167 L
.62838 .34077 L
.63112 .33959 L
.64195 .33318 L
.65177 .32531 L
.67378 .30254 L
.6836 .29314 L
.69398 .28562 L
.70537 .27957 L
.71584 .27485 L
.72095 .27285 L
.72579 .27129 L
.72846 .27063 L
.72987 .27034 L
.73136 .27009 L
.73262 .26992 L
.73401 .26978 L
.73527 .26969 L
.73645 .26964 L
.73757 .26962 L
.7388 .26963 L
.74009 .26968 L
.74128 .26975 L
.7424 .26984 L
.74342 .26994 L
.74571 .27022 L
.7557 .2718 L
.7663 .27311 L
.7721 .27363 L
.77494 .27391 L
.77753 .27422 L
.78215 .27497 L
.78712 .2761 L
.79767 .2794 L
.80246 .28094 L
.80757 .28232 L
.81051 .28292 L
.81318 .28333 L
.81446 .28348 L
.81586 .28361 L
.81717 .28371 L
Mistroke
.81838 .28378 L
.81952 .28383 L
.82074 .28386 L
.82189 .28388 L
.82294 .28389 L
.82417 .28389 L
.82551 .28389 L
.82678 .28388 L
.82794 .28388 L
.82915 .28388 L
.83027 .28388 L
.83151 .28389 L
.83284 .28392 L
.83417 .28395 L
.83556 .284 L
.83674 .28406 L
.83804 .28414 L
.84314 .28456 L
.84866 .2851 L
.85119 .28531 L
.85257 .28541 L
.85387 .28548 L
.85497 .28552 L
.85615 .28554 L
.85747 .28554 L
.85866 .28552 L
.85938 .28549 L
.86014 .28545 L
.8615 .28536 L
.86297 .28522 L
.86459 .28502 L
.86748 .28456 L
.8702 .28402 L
.8752 .28287 L
.88067 .28161 L
.88325 .28109 L
.88601 .28063 L
.88861 .2803 L
.89097 .28008 L
.89237 .27999 L
.89365 .27993 L
.89432 .27991 L
.89506 .27989 L
.89583 .27987 L
.89655 .27987 L
.89788 .27986 L
.8991 .27986 L
.89977 .27987 L
.9005 .27988 L
.90183 .2799 L
Mistroke
.90304 .27992 L
.90434 .27994 L
.90557 .27995 L
.9067 .27996 L
.90803 .27996 L
.9087 .27995 L
.90943 .27995 L
.91071 .27992 L
.9119 .27989 L
.91311 .27985 L
.91426 .2798 L
.91641 .27969 L
.92125 .27938 L
.92357 .27924 L
.92487 .27918 L
.92607 .27914 L
.92741 .27912 L
.92808 .27912 L
.92881 .27912 L
.93015 .27916 L
.93139 .27923 L
.93206 .27928 L
.93279 .27935 L
.93412 .27951 L
.93541 .27972 L
.9366 .27995 L
.9393 .28063 L
.94216 .28161 L
.94692 .28383 L
.95137 .28653 L
.9615 .29456 L
.97182 .30526 L
.98162 .31899 L
.99042 .33585 L
1 .3598 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00:gooooo2_l0002aooooo`00D_oooolAo`0004Sooooo
0ol00007ooooo`03o`000?oooooo000000;o0000[_ooool004kooooo1?l0000Aooooo`?o0000@ooo
ool2o`0000[ooooo00?o0000ooooooooool00_ooool4o`000:[ooooo001;ooooo`?o00006?ooool3
o`0003oooooo00?o0000ooooooooool02_ooool2o`0000Oooooo00?o0000ooooooooool0Yoooool0
04Wooooo0_l0000Nooooo`?o0000>oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0Yoooool001Gooooo0_l000002Ol@413oooooooooooooooook^k^
oc8b<_l0003o<S8bonk^kP0Jooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00;o00006Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Loooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPoooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`07ooooo`;o00005_ooool4o`000008oa0@4?ooooooooooonk^k_lb
<S;o0000oc8b<_o^k^hJooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00Go
V9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Oooool2o`000009
oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Fooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05oa0@4?nj^[[oooooogMgMolb<S80
0oooool01OmgMgOoV9RHoooooonHV9So000001_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003oooo
o`03ogMgMonHV9Sooooo00;o00007_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo0_l0000F
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Iooooo`go000000?o
MgMgooooooooool06Oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>oooo
o`002oooool6o`0000;ooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41004_ooool6o`00
00Kooooo00Ko0000oooooooooooooooooa0@4?ooool2o`000003oa0@4?oooooooooo017ooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Ko410@oooooooooooooooooa0@4?l0000Booooo`Ko
00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41003Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41005_ooool3o`0000;ooooo00?oV9RH
ob4Q8Oo^k^h01?ooool01?l@413oooooooooooooool7o`0001Wooooo00Go0000oooooooooooooooo
oa0@4003ooooo`03oa0@4?oooooooooo01Wooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@
41003_ooool001?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo0000
01gooooo00?oZJVYoa0@4?ooool00_ooool2o`0000;ooooo00?o0000ooooooooool06oooool00onH
V9So8B4Qonk^kP03ooooo`07o`000?ooooooooooooooool0003oooooo`00000Looooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo00oooooo
0_l0000=ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000001Cooooo0_l00006ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`000006ooooo`?o00005Oooool00onYZJWo410@ooooo`02ooooo`05o`000?oooooooooo
ooooool000006oooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool00000
3_ooool001?ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000001co
oooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000001kooooo00?oMgMgofIV
I_ooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000004_ooool2o`0000Wooooo00?oMgMgofIVI_ooool0
0_ooool01Ol0003ooooooooooooooooo000000Wooooo1?l0000@ooooo`03oa0@4?l0003o^[Zj00?o
oooo5_l0000:ooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>
ooooo`005?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41007Oooool0
1_nj^[[o8B4Qoooooooooooo0000oa0@40?ooooo00?o410@ooooooooool07Oooool01Ol0003ooooo
oooooooooooo410@00?ooooo00Co410@oooooooooooo00006oooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41002oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41004Oooool00ol0003oooooooooo`0:ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0;ooooo`go00001?ooool00onj^[[o0000o`000002o`000005oa0@
4?ooooooooooooooool@41004Oooool2o`0000Wooooo00?oMgMgolc<c?l000001?ooool01Ol@413o
oooooooooooooooo410@00kooooo000Dooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0Jooooo`0=oa0@4?nHV9SooooookZj^_l0003oooooo`000?ooooooMgMgoiRHV?oo
ooooV9RHogMgM`0Kooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03oooool2o`0000Wooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL06_ooool6o`0000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Cooooo`03o`000?oo
oooooooo00Kooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo
000Eooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Jooooo`06ojVY
ZOl@413o0000oa0@4?nYZJWo00000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool00ol0003ooooo
ooooo`0Eooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0:ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0=ooooo`03
oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`;o00002oooool01OnH
V9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@
413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Cooooo00?o0000oooooooo
ool01_ooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool003ko
oooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01;o
oooo0_l0000Aooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0EOooool00ol0003o
ooooooooo`0Nooooo`00?_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0Mooooo`00?Oooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0FOooool00ol0003ooooooooo
o`0Looooo`00?Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool0Foooool00ol0003oooooooooo`0Kooooo`00??ooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`0Joooo
o`005_ooooooo`00043o00004oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo017ooooo000Fooooo`03o`000?oooooooooo02;ooooo00?o0000ooooool00000
9oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
4Oooool003[ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo06Cooooo00?o0000ooooooooool05oooool003[ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool05oooool0
03Wooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
01Oooooo0_l0000Jooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0Ioooool00ol0
003oooooooooo`0Fooooo`00>Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`0Fooooo`00>?ooool00ol0003ooooo
ooooo`0oooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0J_ooool00ol0003ooooo
ooooo`0Eooooo`00>?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0Kooooo`;o00003?ooool2o`0006gooooo00?o
0000ooooooooool05Oooool003Oooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool07Oooool2o`0000Wooooo00?o0000
ooooooooool0K_ooool00ol0003oooooooooo`0Dooooo`00=oooool00ol0003oooooooooo`12oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool2o`00023ooooo00?o0000oooo
ooooool01?ooool2o`00077ooooo00?o0000ooooooooool05?ooool003Kooooo00?o0000oooooooo
ool0@oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool08?ooool6o`0007Cooooo00?o0000ooooooooool04oooool003Kooooo00?o0000ooooooooool0
A?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
V_ooool00ol0003oooooooooo`0Cooooo`00=_ooool00ol0003oooooooooo`14ooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`2Kooooo`03o`000?oo
oooooooo01;ooooo000eooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo09_ooooo00?o0000ooooooooool04_ooool0
03Gooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
01_ooooo0_l0002Looooo`03o`000?oooooooooo01;ooooo000Fooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0Aooooo`005_ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo0;3ooooo000Fooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool0B?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool0/?ooool001Oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`19
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`2`
ooooo`005oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04[ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Nooooo`;o0000/Oooool001Oooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`2`ooooo`006?ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo04_ooooo00?o0000ooooooooool03_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0/?ooool001Sooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1=ooooo`03
o`000?oooooooooo00gooooo00GoMgMgo`000?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnH
V9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`
ooooo`006?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04gooooo00?o0000oooo
ooooool03Oooool01Ol@413o0000oooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo000Iooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0<ooooo`05o`000?oooooooooo
ooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`
ooooo`006Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04oooooo00?o0000oooo
ooooool02oooool2o`0000?ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`03oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`ooooo`006Oooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool02oooool00ol0
003o410@ooooo`02ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo000Jooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`09ooooo`07o`000?ooooooMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0;3ooooo000Jooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool0D_ooool00ol0003oooooooooo`07ooooo`08o`000?ooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000oooo
ooooool0/?ooool001[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1Cooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool08oooool2o`000;7ooooo000Kooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool0/?ooool001_ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`2`ooooo`006oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo05Kooooo1_l0000Wooooo`03o`000?oooooooooo0;3ooooo000Looooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0F?ooool2o`0002Wooooo00?o0000ooooooooool0/?ooool001co
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`24ooooo`;o0000/Oooool001cooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo0;3ooooo
000Mooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0Q?ooool00ol0003ooooooooo
o`2`ooooo`007Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08Gooooo00?o0000
ooooooooool0/?ooool001gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`25oooo
o`;o0000/Oooool001kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`25ooooo`03
o`000?oooooooooo0;3ooooo000Nooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
Q_ooool00ol0003oooooooooo`2`ooooo`007_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo08Kooooo00?o0000ooooooooool0/?ooool001oooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`26ooooo`03o`000?oooooooooo0;3ooooo000Oooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0Qoooool2o`000;7ooooo000Oooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`2`ooooo`008?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool0/?ooool0023ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3o
oooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0K_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0/?ooool002;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1^ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`?o0000/?ooool002?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`1^ooooo`05o`000?ooooooooooooooool0
00003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo000Sooooo`;o0000
0_ooool2o`00077ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`2`ooooo`009?ooool3o`0007?ooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool009;ooooo00Go410@oooooooooooooooooa0@400=oooo
o`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000ooooooooooooooooo`00000>oooo
o`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002a
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00:_ooooo1?l000000ol@413o
ooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0/?ooool00:gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooo
ooooool0^?ooool00:gooooo00?o0000ooooooooool0^?ooool00:gooooo00?o0000ooooooooool0
^?ooool00:_ooooo00?oEEEEofIVI_l00000^_ooool00?ooooooJOooool00:oooooo00?o0000okZj
^_ooool0]_ooool00:oooooo0_lb<S:gooooo`00P?ooool2o`000006oa0@4?oooooooooooa0@4?l0
003o410@5oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`03ohN7Qol0003o
^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Jooooo`;o000000Wo410@oooooooooooooooo
olc<c?lQ8B7o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07Sooooo0021oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`0000Wooooo00GoV9RHob4Q
8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool00oo<c<co0000oa0@
400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000cooooo00?o0000ooooooooool0
0_ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1hoooo
o`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Oooooo00?oV9RHob4Q8Oo^
k^h01?ooool01Ol@413ooooooooooooooooo410@01;ooooo00?o0000ooooooooool06_ooool5o`00
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05oa0@4?ooooooooooooooool@4100N?oo
ool0087ooooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00002oooool00onHV9So8B4Q
onk^kP03ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0;ooooo`Ko
00002Oooool01?m4A4CogMgMooooool00004ooooo`05oc8b<_nHV9SooooooiRHV?lb<S800oooool0
1Ol0003ooooooooooooooooo000007Sooooo0021ooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo0000
6oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003o
ooooooooo`0Jooooo`04omgMgOmEEEGoooooo`0000Cooooo00Goc<c<o`000?l0003o0000olc<c003
ooooo`05o`000?ooooooooooooooool00000N?ooool0087ooooo00Ko0000ohN7QonYZJWo^[ZjoeEE
EOl0000Looooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0>ooooo`03
oa0@4?l0003o000000?o00006_ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?nj^[[ooooookZj
^_l@41000oooool01Ol@413ooooooooooooooooo410@07Sooooo0021ooooo`06o`000?lb<S;ooooo
oooooolb<S;o00006?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Booooo`03o`000?oooooooooo01_ooooo00?ok^k^odA4A?l000001?ooool01Ol0003o
^[Zjoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1hooooo`00P?ooool00ol@
413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Looooo`03ogMgMol0
003ooooo00?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h0N?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(490) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .33769 m
.01975 .39221 L
.02981 .424 L
.04057 .45467 L
.04351 .46128 L
.04629 .46651 L
.04879 .47024 L
.05008 .47178 L
.0515 .47317 L
.05283 .47415 L
.05407 .4748 L
.05538 .4752 L
.05612 .47529 L
.05679 .4753 L
.05799 .4751 L
.0593 .47462 L
.06053 .47389 L
.06168 .47298 L
.06313 .47154 L
.0647 .4696 L
.06755 .46516 L
.07288 .45408 L
.08481 .42042 L
.10533 .356 L
.11621 .32655 L
.12219 .31307 L
.12786 .30236 L
.13323 .29404 L
.13908 .28673 L
.14931 .27694 L
.15963 .26905 L
.16932 .2629 L
.17407 .26053 L
.17919 .25859 L
.18196 .2578 L
.18488 .25716 L
.18736 .25674 L
.19009 .25638 L
.20164 .25537 L
.21215 .25408 L
.21723 .25339 L
.2199 .25309 L
.22137 .25295 L
.22274 .25285 L
.22393 .25279 L
.22521 .25275 L
.22594 .25274 L
.22664 .25274 L
.22794 .25277 L
.22913 .25282 L
Mistroke
.23023 .2529 L
.23145 .25301 L
.23274 .25316 L
.2356 .25362 L
.23868 .25429 L
.24428 .25589 L
.25473 .25973 L
.26474 .2643 L
.27042 .26769 L
.27571 .27172 L
.2864 .28331 L
.29239 .29196 L
.29784 .30107 L
.31962 .34629 L
.32919 .36902 L
.33973 .39285 L
.34459 .40204 L
.34715 .40614 L
.34983 .4098 L
.35219 .41241 L
.35344 .41355 L
.35477 .41458 L
.356 .41534 L
.35711 .41588 L
.35823 .41628 L
.35929 .41651 L
.36049 .41662 L
.36181 .41654 L
.36319 .41624 L
.36448 .41575 L
.36568 .41513 L
.36678 .41442 L
.36925 .41234 L
.3719 .40942 L
.37479 .40548 L
.38004 .39658 L
.40037 .34996 L
.41117 .32386 L
.42282 .29945 L
.4339 .28191 L
.44406 .27057 L
.45378 .26288 L
.45867 .25993 L
.46402 .25737 L
.46668 .25638 L
.46956 .25552 L
.47088 .25521 L
.47228 .25493 L
.47349 .25474 L
.47479 .25459 L
Mistroke
.47605 .25448 L
.4772 .25443 L
.47835 .25441 L
.47945 .25443 L
.48073 .2545 L
.48191 .2546 L
.4832 .25475 L
.48458 .25496 L
.48744 .25555 L
.49053 .25638 L
.49612 .25832 L
.50657 .26309 L
.51656 .26902 L
.52753 .27768 L
.54965 .30108 L
.56106 .31339 L
.57187 .32404 L
.57697 .32859 L
.58239 .33291 L
.58741 .33624 L
.58986 .33758 L
.59211 .33861 L
.5943 .33941 L
.5966 .34004 L
.59779 .34028 L
.5989 .34045 L
.60012 .34057 L
.60143 .34062 L
.60276 .3406 L
.6035 .34056 L
.6042 .3405 L
.60547 .34033 L
.60681 .34009 L
.60914 .3395 L
.6117 .33862 L
.617 .33617 L
.6227 .33279 L
.63299 .32545 L
.65374 .30738 L
.66469 .29735 L
.6707 .29252 L
.67635 .28868 L
.68773 .283 L
.69803 .27932 L
.70769 .27642 L
.71034 .27575 L
.71313 .27512 L
.71552 .27467 L
.71812 .2743 L
.71952 .27415 L
Mistroke
.72081 .27404 L
.72204 .27397 L
.72335 .27393 L
.72452 .27392 L
.72561 .27393 L
.72682 .27398 L
.72811 .27405 L
.72948 .27416 L
.73097 .27431 L
.73369 .27466 L
.7388 .27549 L
.75807 .27806 L
.78044 .28111 L
.78558 .28231 L
.79101 .28349 L
.79324 .2839 L
.79564 .28426 L
.79702 .28443 L
.79827 .28455 L
.79954 .28465 L
.80073 .28473 L
.80196 .28478 L
.80326 .2848 L
.80437 .28481 L
.8056 .28479 L
.80691 .28475 L
.80765 .28472 L
.80832 .28468 L
.81089 .28452 L
.81614 .28411 L
.81891 .2839 L
.82044 .2838 L
.82188 .28373 L
.82314 .28367 L
.82451 .28362 L
.82576 .28359 L
.8269 .28358 L
.82799 .28357 L
.82918 .28357 L
.83042 .28358 L
.83158 .28359 L
.83411 .28364 L
.83536 .28366 L
.83651 .28368 L
.83783 .28369 L
.83853 .28369 L
.83928 .28369 L
.8406 .28368 L
.8418 .28365 L
.84307 .28361 L
Mistroke
.84425 .28355 L
.84555 .28346 L
.84694 .28333 L
.84977 .28299 L
.85235 .28256 L
.85733 .28149 L
.86204 .28028 L
.86713 .27895 L
.87253 .27777 L
.87534 .27729 L
.87845 .27689 L
.8798 .27676 L
.88127 .27664 L
.88392 .27647 L
.90499 .27473 L
.91051 .27374 L
.91571 .27286 L
.91859 .27249 L
.91938 .27242 L
.92022 .27235 L
.92094 .2723 L
.92171 .27226 L
.92305 .27222 L
.9243 .27222 L
.92507 .27224 L
.9258 .27227 L
.92716 .27236 L
.92834 .27247 L
.92966 .27263 L
.93231 .27308 L
.93478 .27362 L
.93709 .27423 L
.94792 .27783 L
.9572 .2815 L
.96238 .28402 L
.96721 .287 L
.97483 .29366 L
.97886 .2984 L
.98317 .30449 L
1 .33769 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool005[ooooo2?l0001Cooooo`03o`000?oooooooooo0;3o
oooo001Aooooo`Wo00002?ooool4o`0004Cooooo2_l000000ooooooo0000ooooo`2aooooo`00C_oo
ool4o`0001Cooooo0ol00010ooooo`03o`000?oooooooooo00Sooooo0_l0002booooo`00Boooool3
o`0001_ooooo00?o0000ooooooooool0>_ooool3o`0000cooooo0_l0002aooooo`00B_ooool00ol0
003oooooooooo`0Mooooo`;o0000>Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo0000
00;o0000[_ooool001Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^
kP0Jooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01_o^k^ko<S8bo`000?lb<S;ok^k^oooo
o`;o00006?ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Looooo`Co000000So410@
ooooooooooook^k^oc8b<_l0003o<S8bonk^kPgooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`02ooooo`;o00006oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^hJooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00GoV9RHoa0@4?l0003o
<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Oooool2o`000009oa0@4?oooooooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Fooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01_mgMgOo
V9RHoooooonHV9SoMgMgo`0001[ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonH
V9Soooooo`000?mgMgL07_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`05oa0@4?nj
^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo1?l0000Booooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`002oooool6o`0000;o
oooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41004_ooool6o`0000Kooooo00Go0000oooo
oooooooooooooa0@4003ooooo`03o`000?oooooooooo017ooooo1_l00003ooooo`03oiRHV?lQ8B7o
k^k^00Cooooo00Go410@ooooooooooooooooo`00000Cooooo`Ko00001Oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41005_ooool<o`000005oa0@4?ooooooooooooooool@41007oooool01Ol0
003ooooooooooooooooo410@00?ooooo00?o410@ooooool000001ol00003ooooo`Go00002_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`004oooool01?m4A4CogMgMooooool0
0004ooooo`05o`000?ooooooooooooooool000007Oooool00onYZJWo410@ooooo`02ooooo`03o`00
0?oooooooooo00;o00007Oooool00onHV9So8B4Qonk^kP03ooooo`04o`000?ooooooooooooooo`;o
00007Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000002oooool00ol0
003oooooooooo`0@ooooo`;o00001oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`?o00001_ooool00onHV9So8B4Qonk^kP03
ooooo`Oo00007?ooool00onYZJWo410@ooooo`08o`00013ooooo0ol00007ooooo`04odA4A?oMgMgo
ooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`004oooool01?oMgMgoEEEEoooo
ool00004ooooo`05o`000?ooooooooooooooool000007?ooool00ol@413o0000okZj^P03ooooo`05
o`000?oooooo0000ooooool000007_ooool00omgMgOoIVIVooooo`02ooooo`07o`000?oooooooooo
ooooool0003oooooo`00000Looooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000:ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000@ooooo`?o
00002_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool4o`00
01Kooooo1Ol00002ooooo`05o`000?ooooooooooooooool000005?ooool2o`0000Gooooo00CogMgM
oeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000kooooo000Dooooo`03ogMgMoo<
c<co000000Cooooo00Go410@oooooooooooooooooa0@400Mooooo`03okZj^_lQ8B7ooooo00;ooooo
00Go410@o`000?oooooooooooa0@400Oooooo`05o`000?ooooooooooooooool@41000oooool01?l@
413oooooooooool0000Kooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4009ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400=ooooo`?o0000
3_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01?oooolFo`0000;o
oooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@01Kooooo0_l00004oooo
o`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@400>ooooo`005?ooool00oo^
k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01Ol@413oV9RHoooooonj
^[[o000000?ooooo00Go0000oiRHV?ooooooV9RHogMgM`0Kooooo`05o`000?nj^[[ooooooiRHV?l@
41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02Oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool2o`0000gooooo00Go0000okZj^_ooooooV9RH
oa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool01Ol@413oV9RHoooooonj^[[o0000
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Hooooo`07o`000?ooooooooooooooooo^k^koA4A4
o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool001Gooooo00?oMgMgo`000?ooool0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@02oooo
o`06o`000?o^k^ko<S8bo`000?lb<S;ok^k^6oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`03o`000?oooooooooo01Kooooo00?oEEEEofIVI_l0
00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo01?ooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Wooooo0_l0000?ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h06Oooool01_l0003oooooooooooooooooMgMgo`0000Cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0>ooooo`00@?ooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool05?ooool2o`0000_ooooo00?o0000ooooooooool09Ooo
ool2o`00063ooooo00?o0000ooooooooool06Oooool0043ooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool06Oooool0
03oooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
067ooooo00?o0000ooooooooool06?ooool003kooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool05oooool003kooooo
00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo06Gooooo
00?o0000ooooooooool05_ooool001Koooooool00010o`0001?ooooo000Fooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`;o00001_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`04ooooo`;o00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool04Oooool001Kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool04?ooool2o`0001?ooooo00?o0000
ooooooooool00_ooool2o`00023ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Q
ooooo`05o`000?ooooooooooooooool000004oooool003cooooo00?o0000ooooooooool0>?ooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool05?ooool0
03cooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
06kooooo00?o0000ooooooooool05?ooool003cooooo00?o0000ooooooooool0>Oooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo01Wooooo0_l0000Eooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0Cooooo`00>oooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0LOooool00ol0003ooooo
ooooo`0Cooooo`00>oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0Loooool00ol0003oooooooooo`0Booooo`00>_ooool00ol0003oooooooooo`0l
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0G
ooooo`;o00002_ooool2o`0007Kooooo00?o0000ooooooooool04_ooool001Kooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Gooooo0_l0001ioooo
o`03o`000?oooooooooo017ooooo000Fooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo0_l0000Kooooo`Oo
0000Soooool001Oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0nooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`2`ooooo`005ooo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo0;3ooooo000Gooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool0/?ooool001Sooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`11ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`2`ooooo`006?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04;o
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Nooooo`;o0000/Oooool001Sooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`2`ooooo`006Oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo0;3ooooo000Iooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool0A?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool0/?ooool001Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`15oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`2`oooo
o`006_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04Gooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Pooooo`;o0000/Oooool001[ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`2`ooooo`006_ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo04Oooooo00?o0000ooooooooool04?ooool01Ol0003o<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooooooo
ool0/?ooool001_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`18ooooo`03o`00
0?oooooooooo00kooooo00Ko0000ogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnH
V9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`
ooooo`006oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Sooooo00?o0000oooo
ooooool03_ooool00ol0003o410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q
8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo000Kooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooo000000?ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP07ooooo`03
ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`007?ooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo04[ooooo00?o0000ooooooooool03?ooool00ol0003oooooo`000003ooooo`03o`00
0?oooooooooo00cooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool0/?ooool001cooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`1;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool@41000oooool00ol@413ooooo
ooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`2`ooooo`007?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04cooooo00?o
0000ooooooooool02_ooool02?l0003ooooooooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0
003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`
ooooo`007?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04gooooo00?o0000oooo
ooooool02Oooool02?l0003oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@
o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo0;3ooooo000Mooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo02Cooooo0_l0002aooooo`007Oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo04kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo0;3ooooo000Mooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0D?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0/?ooool0
01kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`2`ooooo`007_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo05;ooooo1?l0000Zooooo`03o`000?oooooooooo0;3o
oooo000Nooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0POooool2o`000;7ooooo
000Oooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0POooool00ol0003ooooooooo
o`2`ooooo`007oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo087ooooo00?o0000
ooooooooool0/?ooool001oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`22oooo
o`03o`000?oooooooooo0;3ooooo000Pooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool0P_ooool2o`000;7ooooo000Pooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
P_ooool00ol0003oooooooooo`2`ooooo`008?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo08?ooooo00?o0000ooooooooool0/?ooool0027ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`23ooooo`03o`000?oooooooooo0;3ooooo000Qooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`2`ooooo`008_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo08Cooooo0_l0002aooooo`008_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo08Cooooo00?o0000ooooooooool0/?ooool002;ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo0;3ooooo000S
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0J_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`2`ooooo`008oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0;3ooooo000Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Jooo
ool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000;3ooooo
000Tooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0K?ooool01Ol0003ooooooooo
oooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`009Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06gooooo00Go0000oooooooooooooooo
o`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`ooooo`00
9_ooool00ol0003oooooooooo`02o`0006oooooo00Go410@oooooooooooooooooa0@400<ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool002Oooooo0ol0001`ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3o
oooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0002aooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009;ooooo
00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_oo
ool01?ooool3o`000;3ooooo002Booooo`05o`000?ooooooooooooooool000003_ooool00omEEEGo
c<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`oooo
o`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004
ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aoooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002[ooooo`Co000000?o410@ooooooooool0
0oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool0
0:gooooo00?o0000ooooooooool01Oooool3o`000;3ooooo002]ooooo`03o`000?oooooooooo0;So
oooo002]ooooo`03o`000?oooooooooo0;Sooooo002]ooooo`03o`000?oooooooooo0;Sooooo002[
ooooo`03oeEEEOmVIVKo00000;[ooooo003oooooofWooooo002_ooooo`03o`000?nj^[[ooooo0;Ko
oooo002_ooooo`;o<S8b]oooool0083ooooo0_l000001_l@413oooooooooool@413o0000oa0@41Oo
oooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOo0000okZj^P0<oooo
o`05oiRHV?l0003o0000odA4A?nj^[X06_ooool2o`000008oa0@4?ooooooooooooooool@413o0000
odA4A?o<c<`4ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0N?ooool0087ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`07ooooo`Ko00002Oooool01OnHV9So8B4Qonk^k_ooooooA4A4
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03olc<c?l0003o410@00cooooo00Go410@
okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003oooooooooo`04ooooo`03oiRHV?l@
413ogMgM00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1hooooo`00POooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo01Oooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooo
oooooooo410@01;ooooo00?o0000ooooooooool06_ooool5o`0000Kooooo00?oQhN7oeEEEOooool0
0_ooool01Ol@413ooooooooooooooooo410@07Sooooo0021ooooo`06o`000?ooooooA4A4odA4A?oo
oooo00002Oooool6o`0000_ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo
000001;ooooo00?o0000ooooooooool02oooool6o`0000Wooooo00CoA4A4omgMgOoooooo00001?oo
ool01Oo<c<co8B4Qo`000?mEEEGo000000?ooooo00Go0000ooooooooooooooooo`00001hooooo`00
POooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001_ooooo00?oMgMgofIVI_ooool00_ooool01Ol0
003ooooooooooooooooo000001;ooooo00?o0000ooooooooool06_ooool01?oMgMgoEEEEooooool0
0004ooooo`05ob4Q8On7QhOooooooiRHV?l000000oooool01Ol0003ooooooooooooooooo000007So
oooo0021ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo00007?ooool01Ol0003ooooooooooooooooo
410@00?ooooo00?o410@ooooooooool03_ooool00ol@413o0000o`000003o`0001[ooooo00?oMgMg
olc<c?l000001?ooool01Ol0003ooooooooooooooooo000000?ooooo00Go410@oooooooooooooooo
oa0@401hooooo`00POooool01_l0003o<S8boooooooooooo<S8bo`0001Sooooo00Go0000okZj^_oo
ooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool00ol0003oooooooooo`0K
ooooo`03onk^k_m4A4Co000000Cooooo00Go8B4QoiRHV?ooooooMgMgoeEEE@03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0N?ooool0083ooooo00?o410@o`000?n7QhL00_ooool00on7QhOo0000oa0@
400Gooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;o
oooo00?o0000ooooooooool07?ooool00omgMgOo0000ooooo`03ooooo`05olc<c?l@413o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07Sooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(500) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .31765 m
.01975 .36618 L
.04057 .43457 L
.04585 .44958 L
.04875 .45669 L
.0515 .46252 L
.05405 .46708 L
.05683 .471 L
.05805 .47238 L
.05935 .4736 L
.06055 .4745 L
.06168 .47515 L
.06237 .47544 L
.06311 .47568 L
.06442 .4759 L
.06516 .4759 L
.06595 .47581 L
.06669 .47563 L
.06736 .4754 L
.06868 .47474 L
.06942 .47425 L
.0701 .47372 L
.07269 .4711 L
.0755 .46713 L
.07858 .46149 L
.08481 .44653 L
.10701 .37333 L
.11753 .34159 L
.12725 .31848 L
.1373 .29991 L
.14823 .28369 L
.15787 .27246 L
.16274 .26807 L
.16811 .2643 L
.17327 .26161 L
.17871 .25952 L
.18842 .25656 L
.19901 .2532 L
.20483 .25137 L
.20769 .2506 L
.21032 .25001 L
.21285 .24958 L
.21413 .24942 L
.21553 .24929 L
.21627 .24924 L
.21694 .24921 L
.21772 .24919 L
.21845 .24918 L
.21976 .2492 L
.2205 .24923 L
Mistroke
.22118 .24927 L
.22247 .24938 L
.22369 .24951 L
.22596 .24984 L
.23105 .25088 L
.24025 .25329 L
.25034 .25625 L
.25565 .25825 L
.26061 .26074 L
.26585 .26434 L
.27146 .26952 L
.28162 .28253 L
.29087 .29778 L
.31264 .34351 L
.32221 .36736 L
.33276 .3927 L
.33762 .40243 L
.34017 .40673 L
.34285 .41055 L
.34521 .41326 L
.34646 .41443 L
.34779 .41548 L
.34902 .41625 L
.35014 .41679 L
.35126 .41718 L
.35232 .41741 L
.35352 .41751 L
.35484 .41741 L
.35621 .41708 L
.3575 .41658 L
.35871 .41593 L
.35981 .4152 L
.36228 .41309 L
.36493 .41014 L
.36781 .40619 L
.37306 .39732 L
.39339 .35078 L
.40419 .3245 L
.41585 .30024 L
.42124 .29125 L
.42693 .2834 L
.43219 .27747 L
.43709 .27291 L
.44662 .26614 L
.45166 .26351 L
.45704 .26141 L
.45976 .26066 L
.46112 .26037 L
.46263 .26012 L
.46391 .25995 L
Mistroke
.46529 .25984 L
.46659 .25978 L
.46778 .25978 L
.4685 .2598 L
.46926 .25984 L
.47064 .25996 L
.47148 .26006 L
.47227 .26017 L
.47376 .26044 L
.47648 .26108 L
.47943 .262 L
.48479 .26414 L
.49045 .26691 L
.50058 .27284 L
.52122 .28934 L
.54047 .3094 L
.55146 .31988 L
.56186 .32803 L
.5712 .3336 L
.57376 .33477 L
.57647 .33581 L
.57879 .33652 L
.58012 .33685 L
.58135 .33711 L
.58254 .3373 L
.58382 .33745 L
.58455 .33751 L
.58523 .33754 L
.58652 .33757 L
.58788 .33752 L
.58913 .33742 L
.5905 .33725 L
.59196 .33698 L
.59435 .33638 L
.59659 .33564 L
.60168 .33338 L
.61224 .32689 L
.62358 .31872 L
.64434 .30278 L
.65529 .29465 L
.6613 .29087 L
.66695 .28796 L
.67242 .28575 L
.67833 .28392 L
.68862 .28151 L
.69372 .2805 L
.6991 .27955 L
.70369 .27891 L
.70494 .27877 L
.70629 .27864 L
Mistroke
.70754 .27855 L
.70872 .27847 L
.71 .27842 L
.71069 .27839 L
.71142 .27838 L
.71219 .27837 L
.71292 .27837 L
.71429 .2784 L
.71556 .27844 L
.71675 .2785 L
.71805 .27859 L
.71944 .27871 L
.72554 .27944 L
.73108 .28024 L
.7363 .28094 L
.73905 .28124 L
.74196 .28149 L
.74451 .28167 L
.7473 .28182 L
.75222 .28202 L
.75485 .28213 L
.75772 .28227 L
.76042 .28245 L
.76293 .28265 L
.76766 .28314 L
.7727 .28379 L
.77772 .28443 L
.78035 .28472 L
.78313 .28496 L
.78461 .28506 L
.78545 .2851 L
.78623 .28513 L
.7876 .28516 L
.78837 .28517 L
.78907 .28517 L
.79045 .28515 L
.79123 .28513 L
.79194 .28511 L
.79326 .28504 L
.79465 .28495 L
.80531 .28378 L
.81056 .28317 L
.81312 .28292 L
.81543 .28274 L
.81983 .28247 L
.82451 .28226 L
.82697 .28215 L
.82962 .282 L
.83212 .28181 L
.83442 .28159 L
Mistroke
.83916 .28093 L
.84185 .28044 L
.84435 .27991 L
.85483 .27731 L
.86027 .27606 L
.86542 .27514 L
.86827 .27475 L
.87136 .27442 L
.87677 .27397 L
.88153 .27358 L
.88665 .273 L
.88959 .27255 L
.89228 .27207 L
.89756 .27096 L
.90313 .26972 L
.90832 .26873 L
.91093 .26835 L
.91239 .26819 L
.91372 .26808 L
.91443 .26803 L
.91518 .26798 L
.916 .26795 L
.91676 .26793 L
.91813 .26791 L
.9189 .26792 L
.91963 .26793 L
.92095 .26798 L
.92161 .26801 L
.92235 .26806 L
.92487 .26826 L
.92781 .26858 L
.93058 .26892 L
.94096 .27025 L
.94552 .27078 L
.95033 .27142 L
.95284 .27186 L
.9556 .27246 L
.9581 .27315 L
.96044 .27396 L
.96554 .27636 L
.96843 .27814 L
.97109 .28007 L
.98115 .28981 L
.9903 .3017 L
1 .31765 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000/Oooool0
05Wooooo1_l0001Fooooo`03o`000?oooooooooo0;3ooooo001Dooooo`Go00001_ooool6o`00053o
oooo00?o0000ooooooooool0/?ooool0057ooooo0ol0000Aooooo`;o0000C_ooool00ol0003ooooo
ooooo`2`ooooo`00C_ooool3o`0001Kooooo0_l00011ooooo`;o00002Oooool00ol0003ooooooooo
o`2`ooooo`00C?ooool2o`0001_ooooo00?o0000ooooooooool0>_ooool4o`0000;ooooo1?l00005
ooooo`;o0000/Oooool004_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0goooo
o`;o00002_ooool2o`0000?ooooo00?o0000ooooooooool0/?ooool001Gooooo0_l000002Ol@413o
ooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0Jooooo`05oiRHV?l@413o0000oc8b<_o<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo0_l0000Gooooo`Go00000oooool01Oo^k^ko
0000o`000?lb<S;ok^k^01cooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
3?ooool00ol0003oooooooooo`0<ooooo`;o000000?oooooo`000?ooool08?ooool4o`000008oa0@
4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hJooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^01_ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01?ooool;o`0000kooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^
kP0>ooooo`005_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_oo
ool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00OoMgMgoiRHV?ooooooV9RHogMgMooooooo0000
01Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So0000oiRHV?mgMgL07_oo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0003ooooo
ooooo`0?ooooo`;o00008oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL06_ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0K
ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Co0000
2oooool6o`0000Wooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00ko
oooo000;ooooo`Ko00000_ooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Booooo`Ko
00001_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooool000004Oooool6o`00
00?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413oooooo`000?oooooo410@01?ooooo1_l00005
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4009ooooo`;o00004ooo
ool2o`0002;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01_ooooo
00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01oooooo2Ol0000Eooooo`;o
00001?ooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`004oooool01?m4A4Co
gMgMooooool00004ooooo`05o`000?ooooooooooooooool000007Oooool00onYZJWo410@ooooo`02
ooooo`04o`000?ooooooooooooooo`;o00007?ooool00onHV9So8B4Qonk^kP03ooooo`03o`000?oo
oooooooo00;o00007_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
2?ooool00ol0003oooooooooo`0Cooooo`?o00008Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000005?ooool6o`0000;ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003o
oooooooooooooooo000001_ooooo1?l000001Ol@413ooooooooooooooooo000000?ooooo00?o0000
ooooooooool05Oooool2o`0000;ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooo
oooooooo000000kooooo000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000oooooooooooo
ooooo`00000Looooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00000Noooo
o`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00000Nooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool00_l0000Oooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000=ooooo`Oo00001_ooool9o`0000?ooooo00?o0000ooooooooool04oooool6o`0000;ooooo
00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000001Wooooo00Ko0000oooooooM
gMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool001Cooooo00?oMgMg
olc<c?l000001?ooool01Ol@413ooooooooooooooooo410@01gooooo00?o^[Zjob4Q8Oooool00_oo
ool01Ol@413oooooooooool0003o410@01oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?l0003ooooo01cooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@
00Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00[ooooo0ol0000A
ooooo`04o`000?ooooooooooooooo`_o00000oooool<o`0000Wooooo00?o^[Zjob4Q8Oooool00_oo
ool01Ol@413ooooooooooooooooo410@01[ooooo00Go0000oooooomgMgOoc<c<o`000004ooooo`05
oa0@4?ooooooooooooooool@41003_ooool001Cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg01[ooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9So
ooooo`000?mgMgL06oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00KoMgMgoiRHV?oooooo
V9RHogMgMol0000Mooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`Co00004?oo
ool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`Co
00004_ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0K
ooooo`04o`000?o^k^koA4A4o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`005Ooo
ool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06_ooool01OnYZJWo410@
o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`00oooool01oo^k^ko<S8bo`000?lb<S;ok^k^ooooool000006_ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool06?ooool00omEEEGoIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`0Booooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool00ol0003oMgMgo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03_ooool004?ooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo01Kooooo0_l00006ooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Gooooo`00@_ooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo02Cooooo0_l0001Xooooo`03o`000?oooooooooo01Kooooo
0011ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`1Yooooo`03o`000?oooooooooo01Gooooo0011ooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool07oooool2o`0006gooooo00?o0000ooooooooool05?ooool0043ooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool05?ooool001Koooooool00010o`0001?ooooo000Fooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`00
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`;o00004oooool001Ko
oooo00?o0000ooooooooool09?ooool00ol0003oooooo`00000Uooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Tooooo`;o00004oooool001Kooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool0MOooool00ol0003oooooooooo`0Aooooo`005_ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00gooooo0_l0000Dooooo`03o`000?oooooooooo08[ooooo000G
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo01cooooo0_l0000@ooooo`;o00004Oooool00ol0003oooooooooo`2;
ooooo`005oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo017ooooo0_l0000=oooo
o`;o0000S_ooool001Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo00Sooooo0_l0002@ooooo`006?ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2@ooooo`006?oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Gooooo2?l0002Cooooo`006Oooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Nooooo`;o0000/Oooool001Wooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`2`ooooo`006Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo0;3o
oooo000Jooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0??ooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0/?ooool001[ooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`2`ooooo`006oooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0P
ooooo`;o0000/Oooool001_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`2`oooo
o`006oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo03oooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo0;3ooooo000Looooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool0/?ooool001cooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool08_oo
ool00ol0003oooooooooo`2`ooooo`007?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo047ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Rooooo`;o0000/Oooool0
01gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`2`ooooo`007Oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool03oooool02?l0003o
ooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`007Oooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool03_ooool02?l0003ooooooooo
oomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool001kooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo00gooooo00Go0000oooo
oooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h02Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo000Nooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0<ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMg
oc8b<_ooool01?ooool3o`000;3ooooo000Nooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool0AOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo0;3ooooo000Oooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0Aoooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`2`ooooo`007oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo04Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`2`ooooo`007oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo04Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03
o`000?oooooooooo0;3ooooo000Pooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
BOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Oooooo0_l0002aooooo`008?oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo0;3ooooo000Pooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool0/?ooool0027ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`1=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`2`ooooo`008Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04go
oooo0_l00002ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0/?ooool0027ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`1?ooooo`;o0000;Oooool2o`000;7ooooo
000Rooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0O_ooool00ol0003ooooooooo
o`2`ooooo`008_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo07oooooo00?o0000
ooooooooool0/?ooool002;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1ooooo
o`03o`000?oooooooooo0;3ooooo000Sooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool0Ooooool2o`000;7ooooo000Sooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
P?ooool00ol0003oooooooooo`2`ooooo`008oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo083ooooo00?o0000ooooooooool0/?ooool002?ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`20ooooo`03o`000?oooooooooo0;3ooooo000Tooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`2`ooooo`009?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo087ooooo0_l0002aooooo`009?ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool0/?ooool002Cooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo0;3ooooo000U
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Ioooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`2`ooooo`009Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0;3ooooo000Vooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0J?oo
ool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000;3ooooo
000Wooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0JOooool01Ol0003ooooooooo
oooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`009ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06Wooooo00Go0000oooooooooooooooo
o`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`ooooo`00
:?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06[ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool002Wooooo
1?l0001]ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Ko
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@
41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0/?ooool009;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Ko
oooo00?oMgMgoc8b<_ooool01?ooool3o`000;3ooooo002Booooo`05o`000?ooooooooooooooool0
00003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0
003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00_ooooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002[ooooo`Co0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0/?ooool00:gooooo00?o0000ooooooooool01Oooool3o`000;3ooooo002]ooooo`03
o`000?oooooooooo0;Sooooo002]ooooo`03o`000?oooooooooo0;Sooooo002]ooooo`03o`000?oo
oooooooo0;Sooooo002[ooooo`03oeEEEOmVIVKo00000;[ooooo003oooooofWooooo002_ooooo`03
o`000?nj^[[ooooo0;Kooooo002_ooooo`;o<S8b]oooool0083ooooo0_l000001_l@413ooooooooo
ool@413o0000oa0@41Oooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7
QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06Oooool01Om4A4Co0000o`000?lb
<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h0N?ooool0087ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko0000
2Oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`03olc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003Oooool0
2OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL0N?ooool0087ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Gooooo`03
oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400Booooo`03o`000?oooooooooo
01oooooo00Co0000oooooooooooo410@0oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o
410@ooooooooool0M_ooool0087ooooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko0000
2oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003o
ooooooooo`0;ooooo`Ko00003Oooool01OmgMgOo<S8boooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo07Kooooo0021ooooo`06o`000?oMgMgo<S8b
oeEEEOoMgMgo00006oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000
4_ooool00ol0003oooooooooo`0Kooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00001hooooo`00POooool01_l0
003oQhN7ojVYZOnj^[[oEEEEo`0001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@
4?oooooooooo00kooooo00?o410@o`000?l000000ol0000Jooooo`03o`000?oooooooooo00Cooooo
00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100N?ooool0087o
oooo00Ko0000oc8b<_oooooooooooc8b<_l0000Hooooo`05o`000?nj^[[ooooooiRHV?l@41000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
07Sooooo0020ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41005oooool01OnHV9So
410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Booooo`03o`000?oooooo
oooo01_ooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^07Sooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(510) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30103 m
.00942 .318 L
.01975 .343 L
.04057 .40776 L
.05163 .44294 L
.05772 .45932 L
.06071 .46599 L
.06347 .47111 L
.06607 .47492 L
.06738 .47643 L
.06883 .47776 L
.06957 .4783 L
.07027 .47872 L
.07109 .4791 L
.07183 .47935 L
.07318 .47953 L
.07394 .47949 L
.07464 .47935 L
.07597 .47885 L
.07722 .47808 L
.07835 .47715 L
.07956 .47588 L
.0823 .4721 L
.08481 .46754 L
.08974 .45594 L
.09503 .44045 L
.10457 .40831 L
.12627 .33888 L
.13695 .31164 L
.14259 .29949 L
.14857 .28847 L
.15379 .28056 L
.15955 .27357 L
.1697 .26476 L
.1803 .25797 L
.19001 .2525 L
.19554 .24988 L
.19823 .24883 L
.20068 .24804 L
.20328 .24739 L
.2047 .24711 L
.20605 .24691 L
.20676 .24682 L
.20751 .24675 L
.20886 .24666 L
.20961 .24663 L
.21031 .24661 L
.21109 .24661 L
.21191 .24663 L
.21264 .24665 L
Mistroke
.21332 .24669 L
.21459 .24678 L
.21595 .24692 L
.21743 .2471 L
.22255 .24792 L
.23415 .25016 L
.2395 .25136 L
.24242 .25216 L
.24515 .25308 L
.24997 .25523 L
.25252 .25672 L
.25525 .25861 L
.26082 .26352 L
.26596 .26928 L
.2776 .28586 L
.29874 .32588 L
.309 .35076 L
.32004 .37918 L
.32513 .39109 L
.33047 .40168 L
.33504 .40862 L
.33762 .41155 L
.34002 .4136 L
.34132 .41443 L
.34251 .41502 L
.34382 .41549 L
.3452 .41576 L
.34641 .41583 L
.34753 .41574 L
.34877 .41549 L
.35009 .41503 L
.35126 .41448 L
.35254 .41371 L
.35487 .41192 L
.35923 .40721 L
.36438 .39965 L
.36986 .38959 L
.37971 .36767 L
.38977 .34285 L
.40037 .31823 L
.40941 .30125 L
.41932 .28776 L
.4244 .28254 L
.42983 .27787 L
.43961 .27126 L
.44244 .26978 L
.4455 .26842 L
.4484 .26741 L
.44978 .26703 L
.45107 .26674 L
Mistroke
.45223 .26653 L
.45348 .26637 L
.45487 .26625 L
.45614 .26622 L
.45745 .26624 L
.45819 .26629 L
.45889 .26635 L
.46015 .26651 L
.4615 .26674 L
.46424 .26741 L
.46713 .26838 L
.47231 .27064 L
.484 .27712 L
.50518 .29155 L
.52605 .31149 L
.53516 .31953 L
.54507 .32616 L
.55054 .32888 L
.5556 .3309 L
.56044 .33242 L
.56288 .33302 L
.56557 .33354 L
.56696 .33374 L
.56772 .33384 L
.56842 .33391 L
.56967 .33401 L
.57103 .33407 L
.57179 .33408 L
.57252 .33408 L
.57387 .33403 L
.57463 .33397 L
.57533 .33391 L
.5769 .33371 L
.57818 .33349 L
.57937 .33324 L
.58207 .3325 L
.58471 .33155 L
.58754 .33031 L
.59819 .32404 L
.60979 .31614 L
.6309 .30289 L
.64157 .29648 L
.65161 .29126 L
.65718 .28903 L
.66318 .28723 L
.66864 .28606 L
.67365 .28523 L
.68323 .28394 L
.68849 .28329 L
.69347 .28277 L
Mistroke
.6963 .28254 L
.69789 .28244 L
.69936 .28237 L
.7006 .28233 L
.70196 .2823 L
.70264 .2823 L
.70338 .2823 L
.70472 .28231 L
.70606 .28234 L
.70681 .28237 L
.70752 .2824 L
.71019 .28256 L
.71261 .28275 L
.71519 .28299 L
.72044 .28352 L
.72598 .28401 L
.72888 .2842 L
.73053 .28428 L
.73207 .28433 L
.73279 .28435 L
.73348 .28437 L
.73477 .28439 L
.73615 .2844 L
.73694 .28441 L
.73766 .28441 L
.73887 .2844 L
.74018 .28439 L
.74254 .28437 L
.74391 .28436 L
.74466 .28435 L
.74535 .28434 L
.74658 .28434 L
.74793 .28434 L
.74861 .28434 L
.74935 .28435 L
.75069 .28436 L
.752 .28439 L
.7532 .28442 L
.75594 .28452 L
.75884 .28467 L
.76392 .28498 L
.76642 .28513 L
.76874 .28524 L
.77003 .28529 L
.7714 .28533 L
.77218 .28534 L
.77292 .28535 L
.7743 .28535 L
.77557 .28534 L
.77674 .28531 L
Mistroke
.77803 .28525 L
.77938 .28518 L
.78167 .285 L
.78413 .28475 L
.78855 .28418 L
.79861 .28266 L
.84208 .27619 L
.86384 .27223 L
.88396 .26926 L
.89404 .2669 L
.89645 .2664 L
.89898 .26594 L
.90132 .26558 L
.9035 .26532 L
.90577 .26512 L
.90697 .26504 L
.90825 .26498 L
.90963 .26494 L
.91093 .26491 L
.9121 .26491 L
.91337 .26492 L
.91468 .26494 L
.91542 .26496 L
.91612 .26497 L
.91903 .26506 L
.92156 .26514 L
.92294 .26518 L
.92425 .26521 L
.92554 .26523 L
.92623 .26524 L
.92697 .26524 L
.92828 .26524 L
.92949 .26524 L
.93081 .26523 L
.93157 .26522 L
.93227 .2652 L
.9352 .26514 L
.93643 .26511 L
.93778 .26509 L
.93904 .26507 L
.94021 .26506 L
.94158 .26506 L
.94227 .26507 L
.94302 .26508 L
.94434 .26513 L
.94558 .26519 L
.94678 .26528 L
.94809 .2654 L
.95048 .26571 L
.9528 .26614 L
Mistroke
.95496 .26664 L
.95985 .26822 L
.96505 .2705 L
.9737 .27546 L
.98305 .28222 L
.99188 .29054 L
1 .30103 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo001Gooooo`Ko0000=Oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2
o`000;7ooooo001Cooooo`Co00001_ooool5o`0005?ooooo00?o0000ooooooooool0/?ooool0057o
oooo0_l0000?ooooo`?o0000D?ooool00ol0003oooooooooo`2`ooooo`00D?ooool00ol0003ooooo
ooooo`0Booooo`;o0000C_ooool00ol0003oooooooooo`2`ooooo`00C_ooool2o`0001Oooooo00?o
0000ooooooooool0Boooool00ol0003oooooooooo`2`ooooo`00COooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo04[ooooo0_l0002aooooo`00Boooool2o`0001cooooo00?o0000oooo
ooooool0BOooool00ol0003oooooooooo`1loooooa;o00008_ooool001Gooooo0_l000002Ol@413o
ooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0Jooooo`05oiRHV?l@413o0000oc8b<_o<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?o0000ooooooooool05Oooool5o`0000?o
oooo00Go0000oc8b<_l0003o<S8bonk^kP0Looooo`Co000000So410@ooooooooooook^k^oc8b<_l0
003o<S8bonk^kPgooooo2?l00009ooooo`03o`000?oooooooooo01oooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^6_ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0Kooooo`05oiRHV?l@413o0000oc8b<_o<c<`00_ooool8o`0001;ooooo0ol00006ooooo`;o0000
00Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h03_ooool001Kooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00Go410@okZj^_ooooooMgMgoc8b
<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool00ol0003oooooooooo`0Fooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@00oooool01Ol0003oV9RHoooooonHV9SoMgMg01kooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo0ol00008ooooo`;o00001oooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_o
oooo00?o410@okZj^_l000001?l000001_ooooooMgMgoiRHV?ooooooV9RHogMgMaOooooo0ol00004
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`002oooool6
o`0000;ooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41004_ooool6o`0000Kooooo00Go
0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooo0000017ooooo1_l00003ooooo`03oiRH
V?lQ8B7ok^k^00Cooooo00Go410@o`000?oooooooooooa0@400Cooooo`Ko00001Oooool00ol0003o
ooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002Oooool00ol0003oooooooooo`0;oooo
o`;o00001Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@400Kooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
400Jooooo`?o00000_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0
6?ooool6o`0000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`004oooool01?m4A4CogMgM
ooooool00004ooooo`05o`000?ooooooooooooooool000007Oooool00onYZJWo410@ooooo`02oooo
o`07o`000?ooooooooooooooool0003oooooo`00000Kooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go
0000ooooool0003oooooo`00000Nooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000008ooooo`03o`000?oooooooooo00kooooo0_l00003ooooo`;o00008_ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000007?ooool00onHV9So8B4Qonk^kP03oooo
o`05o`000?ooooooooooooooool000005Oooool5o`0000Cooooo00?oZJVYoa0@4?ooool00_ooool0
1Ol0003ooooooooooooooooo000001_ooooo00Co0000omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000000kooooo000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000oooooooo
ooooooooo`00000Looooo`03oa0@4?l0003o^[Zj00?ooooo00Co0000oooooooooooooooo0_l0000M
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooool0003oooooo`00000Nooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo017ooooo
00Co0000oooooooooooo00008oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000007Oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000003_ooool7
o`0000Sooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000001_ooooo00Co
gMgMo`000?oooooo00001?ooool01Ol0003ooooooooooooooooo000000kooooo000Dooooo`03ogMg
Moo<c<co000000Cooooo00Go410@oooooooooooooooooa0@400Mooooo`03okZj^_lQ8B7ooooo00;o
oooo00Ko410@oooooooooooooooooa0@4?l0000Nooooo`05o`000?ooooooooooooooool@41000_oo
ool00ol0003o410@ooooo`0Mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@4005ooooo`;o00005Oooool3o`0002?ooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@00_ooooo7?l00005ooooo`Wo00004?ooool00onj^[[o8B4Qooooo`02ooooo`05
oa0@4?ooooooooooooooool@41007?ooool00omgMgOo0000o`000004ooooo`05oa0@4?oooooooooo
ooooool@41003_ooool001Cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg01[ooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?l00000
6oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHo`00000Noooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool6o`0000oooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Ol0000Fooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00kooooo000Eooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0Jooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?l0003ok^k^01_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_l000007?ooool0
0omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool00ol0003ooooooooo
o`0Gooooo`;o00008?ooool00omEEEGoIVIVo`000004ooooo`06onk^k_lb<S;o0000oc8b<_o^k^ko
oooo1?l0000Eooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
7Oooool00omgMgOo0000o`000003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool004Gooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01Sooooo
0ol0000[ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool05?ooool004Cooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01Wooooo00Co
0000oooooooooooo0000:?ooool2o`0006oooooo00?o0000ooooooooool04oooool004?ooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01Wooooo00Go
0000ooooooooooooooooo`00000Vooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0
4_ooool001Kooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo027ooooo0_l0001dooooo`03o`000?oooooooooo017ooooo000Fooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Nooooo`;o0000R_ooool0
01Koooooool00010o`0001?ooooo000Fooooo`03o`000?oooooo000000Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2
o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`04o`000?ooooooooooooooo`;o00000_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Aooooo`005_ooool00ol0003oooooo`00000Tooooo`05o`000?ooooooooooooooool000008ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05Ooo
ool2o`0000Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool04Oooool001Wooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Soooool0
01Wooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0T?ooool001[ooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07_ooool2o`0000_o
oooo00?o0000ooooooooool03_ooool2o`0009?ooooo000Jooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool02oooool4o`0000_ooooo00?o0000ooooooooool0Toooool001[ooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Kooooo0_l0
002Fooooo`006oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03Cooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo013ooooo2?l0002H
ooooo`006oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03Gooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo0;3ooooo000Kooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo01oooooo0_l0002aooooo`007?ooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo0;3ooooo000Looooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0/?oo
ool001gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`2`ooooo`007Oooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo0;3ooooo000Mooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo027o
oooo0_l0002aooooo`007_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo03[ooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo0;3ooooo
000Nooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0/?ooool001kooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`2`ooooo`007oooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo03cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo0;3ooooo000Oooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool0?Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02?ooooo0_l0002aooooo`00
7oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo0;3ooooo000Pooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0?ooooo`09o`000?oo
ooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool0023ooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo000P
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2`ooooo`008Oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^
kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`008Oooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`04
ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`ooooo`008Oooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`04ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool002;ooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool002;ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
1Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co00001_ooool00ol0003oooooooooo`2`ooooo`008_ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo04Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Yooooo`;o
0000/Oooool002?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`15ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`2`ooooo`008ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo0;3ooooo000Sooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool0Aoooool2o`0000?ooooo0_l0000]ooooo`03o`000?oooooo
oooo0;3ooooo000Sooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0B?ooool5o`00
02kooooo00?o0000ooooooooool0/?ooool002Cooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`1looooo`;o0000/Oooool002Cooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`1looooo`03o`000?oooooooooo0;3ooooo000Tooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0O?ooool00ol0003oooooooooo`2`ooooo`009Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo07gooooo00?o0000ooooooooool0/?ooool002Gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`1mooooo`;o0000/Oooool002Gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo0;3ooooo000Uooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`2`ooooo`009_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool0/?oo
ool002Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1nooooo`03o`000?oooooo
oooo0;3ooooo000Vooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Ooooool2o`00
0;7ooooo000Wooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Ooooool00ol0003o
ooooooooo`2`ooooo`009oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo07oooooo
00?o0000ooooooooool0/?ooool002Oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`1Uooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo000Xooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0IOooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool002Sooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`1Uooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003o
ooooooooo`03ooooo`?o0000/?ooool002Wooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`1Vooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo0;3ooooo000Yooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
I_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005oooo
o`03o`000?oooooooooo0;3ooooo000Zooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0Ioooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`2`ooooo`00:oooool01Ol0003ooooooooooooooooo000006[ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool0
02cooooo1?l0001Zooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0002a
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003Oooool0
0onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool0
09;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMg
oc8b<_ooool01?ooool3o`000;3ooooo002Booooo`05o`000?ooooooooooooooool000003_ooool0
0omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002[ooooo`Co000000?o410@oooo
ooooool00oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
/?ooool00:gooooo00?o0000ooooooooool01Oooool3o`000;3ooooo002]ooooo`03o`000?oooooo
oooo0;Sooooo002]ooooo`03o`000?oooooooooo0;Sooooo002]ooooo`03o`000?oooooooooo0;So
oooo002[ooooo`03oeEEEOmVIVKo00000;[ooooo003oooooofWooooo002_ooooo`03o`000?nj^[[o
oooo0;Kooooo002_ooooo`;o<S8b]oooool0083ooooo0_l000001_l@413oooooooooool@413o0000
oa0@41Oooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOo0000okZj
^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06Oooool01Om4A4Co0000o`000?lb<S;ogMgM00?o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^N?ooool0087ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00002Oooool01OnHV9So8B4Qonk^k_oo
ooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03olc<c?l0003o410@00cooooo
00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003Oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1hooooo`00POooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo01Oooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@01;ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@401hooooo`00POooool01_l0
003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000;ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go
0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo00_ooooo1_l0000=ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000007So
oooo0021ooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo00006oooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0Kooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
N?ooool0087ooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Looooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0>ooooo`03oa0@4?l0003o000000?o00006_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@401h
ooooo`00POooool01_l0003o<S8boooooooooooo<S8bo`0001Sooooo00Go0000okZj^_ooooooV9RH
oa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
07Sooooo0020ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41005oooool01OnHV9So
410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Booooo`03o`000?oooooo
oooo01_ooooo1?l00004ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP1hooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(520) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .28756 m
.04057 .37903 L
.05077 .41551 L
.06168 .45306 L
.0649 .46227 L
.06795 .46973 L
.07092 .47561 L
.07222 .47772 L
.07365 .47971 L
.07491 .48113 L
.07625 .48233 L
.07699 .48285 L
.07767 .48323 L
.079 .48372 L
.07974 .48385 L
.08043 .48387 L
.08118 .4838 L
.08198 .4836 L
.08274 .4833 L
.08346 .48291 L
.08481 .48194 L
.08606 .48075 L
.08722 .47939 L
.08986 .47543 L
.0952 .46417 L
.10477 .43553 L
.12636 .35649 L
.13733 .32173 L
.14773 .29678 L
.15706 .28063 L
.16721 .26766 L
.17708 .25792 L
.18277 .25347 L
.18798 .25027 L
.19064 .249 L
.19345 .24792 L
.19627 .24712 L
.19787 .24678 L
.19935 .24653 L
.20075 .24636 L
.20206 .24624 L
.20324 .24617 L
.20452 .24613 L
.20518 .24612 L
.20591 .24612 L
.20667 .24613 L
.20739 .24615 L
.20866 .2462 L
.21003 .24627 L
.21271 .24647 L
Mistroke
.21555 .24674 L
.22067 .24733 L
.22381 .24776 L
.22676 .24824 L
.22944 .24878 L
.23227 .24949 L
.23479 .25029 L
.23756 .25138 L
.24241 .25394 L
.24809 .25813 L
.25337 .26321 L
.26438 .27685 L
.27479 .29271 L
.29428 .3317 L
.31345 .37946 L
.31871 .39085 L
.32436 .4008 L
.32696 .40442 L
.3297 .40751 L
.33203 .40955 L
.33326 .4104 L
.33458 .41115 L
.33532 .41148 L
.33599 .41174 L
.33732 .41212 L
.33853 .41231 L
.3398 .41236 L
.34117 .41223 L
.34245 .41195 L
.34319 .41171 L
.34386 .41145 L
.34537 .41072 L
.34783 .40908 L
.35051 .40669 L
.35539 .40081 L
.36094 .39192 L
.36685 .38031 L
.37746 .35592 L
.38752 .33252 L
.39811 .31193 L
.40716 .29894 L
.41706 .28857 L
.42214 .28432 L
.42757 .28044 L
.4327 .27751 L
.43496 .27648 L
.43735 .27559 L
.43869 .27519 L
.44016 .27484 L
.4415 .27459 L
Mistroke
.44275 .27443 L
.44351 .27437 L
.44423 .27433 L
.44558 .27431 L
.44633 .27434 L
.44703 .27438 L
.44779 .27445 L
.44861 .27455 L
.44999 .27479 L
.45148 .27511 L
.45419 .2759 L
.45924 .27792 L
.4802 .28901 L
.50232 .30465 L
.51304 .31412 L
.51831 .31831 L
.52319 .32159 L
.52752 .32394 L
.5323 .32596 L
.53711 .32748 L
.54221 .32869 L
.5473 .32961 L
.54997 .32999 L
.55143 .33017 L
.55279 .33031 L
.55408 .33042 L
.55526 .3305 L
.55657 .33056 L
.55729 .33058 L
.55796 .33059 L
.55915 .33059 L
.56024 .33056 L
.56144 .33049 L
.56271 .33039 L
.56407 .33022 L
.56532 .33003 L
.56812 .32943 L
.57071 .32867 L
.57317 .32776 L
.57868 .32513 L
.58468 .3216 L
.60712 .30871 L
.62743 .29911 L
.63763 .29406 L
.64299 .29185 L
.64592 .29087 L
.64864 .29012 L
.65124 .28953 L
.65361 .28911 L
.65623 .28875 L
Mistroke
.65904 .28846 L
.66395 .2881 L
.66859 .28778 L
.67783 .28687 L
.68293 .28621 L
.68778 .28562 L
.6905 .28535 L
.69194 .28524 L
.69347 .28514 L
.6942 .2851 L
.69489 .28508 L
.69618 .28504 L
.69738 .28503 L
.69869 .28503 L
.69992 .28506 L
.70128 .2851 L
.70196 .28513 L
.70269 .28517 L
.70401 .28526 L
.70891 .28567 L
.71159 .28593 L
.7145 .28619 L
.71707 .28639 L
.71848 .28647 L
.7198 .28654 L
.72098 .28658 L
.72225 .28661 L
.72294 .28662 L
.72366 .28663 L
.72496 .28662 L
.72614 .2866 L
.72724 .28657 L
.72844 .28653 L
.72973 .28646 L
.73531 .28609 L
.73836 .28586 L
.74122 .28567 L
.74385 .28552 L
.74626 .28542 L
.74763 .28538 L
.74894 .28535 L
.75031 .28533 L
.75109 .28533 L
.75181 .28532 L
.75249 .28533 L
.75322 .28533 L
.75454 .28534 L
.75583 .28535 L
.75702 .28536 L
.75841 .28538 L
Mistroke
.75971 .28539 L
.76107 .2854 L
.76179 .2854 L
.76256 .28539 L
.76334 .28538 L
.76406 .28537 L
.76485 .28536 L
.76569 .28533 L
.7671 .28528 L
.76866 .2852 L
.77004 .2851 L
.77152 .28497 L
.77421 .28468 L
.7796 .28388 L
.78526 .28282 L
.79537 .28095 L
.83543 .27363 L
.85777 .2697 L
.87806 .26622 L
.88298 .26516 L
.8882 .26418 L
.89092 .26377 L
.89236 .26359 L
.89391 .26343 L
.89534 .26331 L
.89663 .26321 L
.89794 .26314 L
.89918 .26309 L
.90032 .26305 L
.90158 .26303 L
.90289 .26301 L
.90413 .26301 L
.90528 .26301 L
.90633 .26302 L
.90871 .26303 L
.90996 .26304 L
.91113 .26304 L
.9124 .26304 L
.91377 .26302 L
.91446 .26301 L
.9152 .263 L
.91656 .26296 L
.91788 .26291 L
.9191 .26285 L
.92857 .26215 L
.9313 .26193 L
.93265 .26184 L
.93389 .26176 L
.93512 .2617 L
.93622 .26166 L
Mistroke
.93745 .26164 L
.93876 .26163 L
.93946 .26164 L
.9402 .26166 L
.94153 .26171 L
.94227 .26175 L
.94296 .2618 L
.94452 .26193 L
.94714 .26225 L
.94995 .26272 L
.95543 .26395 L
.96042 .26532 L
.96962 .26809 L
.97938 .27157 L
.98447 .27404 L
.99009 .27773 L
.9952 .28223 L
1 .28756 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo001Dooooo`Wo0000=Oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2
o`000;7ooooo001Aooooo`?o00002Oooool4o`0005Cooooo00?o0000ooooooooool0/?ooool0053o
oooo00?o0000ooooooooool03_ooool2o`0005;ooooo00?o0000ooooooooool0/?ooool004oooooo
00?o0000ooooooooool04Oooool2o`00053ooooo00?o0000ooooooooool0/?ooool004kooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo0;3ooooo001=
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0COooool2o`0007gooooo4_l0000R
ooooo`00C?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04cooooo00?o0000oooo
ooooool0M_ooool7o`00017ooooo1?l0000Nooooo`005Oooool2o`000009oa0@4?oooooooooooooo
ooo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01?ooool00ol0003oooooooooo`0Dooooo`Ko00000_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^01cooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
7_ooool00ol0003oooooooooo`0Oooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kQ[ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool01OnHV9So410@o`00
0?lb<S;oc<c<00Co000000Co<S8bo`000?lb<S;ok^k^6?ooool3o`0000;ooooo0_l000002Ol@413o
ooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0>ooooo`005_ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03o`000?oooooooooo01Cooooo00goV9RHob4Q8Oo^
k^koooooodA4A?oooooo0000oooooomgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`Ko00000oooool01OmgMgOoV9RH
oooooonHV9SoMgMg01_ooooo0_l000000ooooooo0000ooooo`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03_ooool000_ooooo1_l00002ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@
01;ooooo1_l00006ooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo000000oooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00?o0000oa0@4?ooool00_oo
ool00ol@413oooooooooo`0Aooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41002_ooool5o`0000oooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41006oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41004oooool7o`0000Gooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01Wooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41003_oo
ool001?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000001gooooo
00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000oooooooo
ool06?ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000007_ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000002?ooool2o`0000Gooooo1?l0000;
ooooo`;o00008_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007?oo
ool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000003?ooool7o`0000_ooooo
00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000001_ooooo00?oA4A4omgMgOoo
ool00_l00003ooooo`05o`000?ooooooooooooooool000003_ooool001?ooooo00CogMgMoeEEEOoo
oooo00001?ooool01Ol0003ooooooooooooooooo000001cooooo00?o410@o`000?nj^[X00oooool0
1ol0003ooooooooooooooooo0000ooooool000007?ooool00omgMgOoIVIVooooo`02ooooo`05o`00
0?ooooooooooooooool000007_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000001_ooool2o`0000_ooooo0_l00009ooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000001gooooo00?oMgMgofIVI_ooool00_ooool0
1Ol0003ooooooooooooooooo000000Sooooo1?l0000Aooooo`03oa0@4?l0003o^[Zj00?ooooo00Go
0000ooooooooooooooooo`00000Kooooo`06omgMgOmEEEGoooooo`000?oooooo00000_ooool01Ol0
003ooooooooooooooooo000000kooooo000Dooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooo
oooooooooooooa0@400Mooooo`03okZj^_lQ8B7ooooo00;ooooo00Oo410@oooooooooooooooooa0@
4?oooooo000001gooooo00Ko0000oooooooooooooooooa0@4?l00002ooooo`03oa0@4?oooooooooo
01cooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@017ooooo00?o0000ooooooooool02_oo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooool000001_l0000Fooooo`03okZj
^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@400Looooo`03ogMgMoo<c<co000000;o
oooo00?o0000ooooool@41000oooool00ol@413oooooooooo`0<ooooo`005?ooool00oo^k^koA4A4
o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01Ol@413oV9RHoooooonj^[[o0000
00?ooooo00KoMgMgoiRHV?ooooooV9RHogMgMol0000Jooooo`05o`000?nj^[[ooooooiRHV?l@4100
0oooool01OmgMgOoV9RHo`000?nHV9SoMgMg01kooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Cooooo00?o0000ooooooooool03oooool2o`0000Kooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool;
o`000003ooooool0003o000001Go00006Oooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0Looooo`03onk^k_m4A4Co000000?ooooo00Ko0000ogMgMonHV9So
oooooiRHV?mgMgL>ooooo`005Oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h06_ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bo`00
000Kooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01co
oooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?o0000oooo
ooooool04_ooool2o`0000Cooooo00?o0000ooooooooool07oooool00omEEEGoIVIVo`000004oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01_l0000Dooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h07Oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03_ooool001Oooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool05Oooool01?l0003oooooooooooooool2
o`0002Wooooo0ol00025ooooo`005oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Gooooo`;o000000?oooooo`00
0?ooool09oooool2o`0008Sooooo000Hooooo`03o`000?oooooooooo02[ooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01[ooooo0_l0000Vooooo`;o
0000R_ooool001Sooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Rooooo`;o0000
S?ooool001Sooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool07?ooool2o`00027ooooo0_l0002>ooooo`005_oooooo
o`00043o00004oooool001Kooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool001Kooooo00Go
0000ooooooooooooooooo`00000Rooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Nooooo`04o`000?ooooooooooooooo`;o00006?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo017ooooo000Jooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`;o0000UOooool001_ooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`04ooooo`;o00004Oooool2o`0009Oooooo000K
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo023ooooo0_l00007ooooo`03o`000?oooooooooo00cooooo0_l0002I
ooooo`007?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Oooooo1Ol00007oooo
o`;o0000Voooool001cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0<ooooo`So
0000W?ooool001gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`2`ooooo`007Ooo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo0;3ooooo000Mooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo02;ooooo0_l0002aooooo`007_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
0;3ooooo000Nooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0/?ooool001oooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`2`ooooo`007oooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo0;3ooooo000Pooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02Cooooo0_l0002a
ooooo`008?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo03Gooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo0;3ooooo000Qooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0/?ooool0027ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`2`ooooo`008Oooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo03Oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo0;3ooooo000Rooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0>?ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02Kooooo0_l0002aooooo`008_ooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo0;3ooooo000Sooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo000Sooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`008oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`05ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^
kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool002Cooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool01Oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool002Cooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0mooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool002Cooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_oo
ool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo000Tooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool0?oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo000Uooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0@?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`00
00Kooooo00?o0000ooooooooool0/?ooool002Gooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`10ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0;?ooool2o`000;7o
oooo000Uooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0@Oooool2o`0000Gooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`2`ooooo`009Oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo04?ooooo0_l00003ooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool0/?ooool002Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`14
ooooo`Go0000<?ooool00ol0003oooooooooo`2`ooooo`009_ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0/?ooool002Kooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`1iooooo`;o0000/Oooool002Kooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo0;3ooooo000Wooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`2`ooooo`009oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0/?ooool0
02Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1kooooo`;o0000/Oooool002Oo
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo0;3o
oooo000Xooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Noooool00ol0003ooooo
ooooo`2`ooooo`00:?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo07_ooooo00?o
0000ooooooooool0/?ooool002Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1l
ooooo`03o`000?oooooooooo0;3ooooo000Xooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0O?ooool2o`000;7ooooo000Yooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0O?ooool00ol0003oooooooooo`2`ooooo`00:Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo07gooooo00?o0000ooooooooool0/?ooool002Wooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`1Rooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo000Zooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0H_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool002[ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`1Sooooo`05oa0@4?ooooooooooooooool@
41004?ooool00ol0003oooooooooo`03ooooo`?o0000/?ooool002[ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`1Sooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo000[ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0Hoooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0
003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo000[ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0I?ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`2`ooooo`00;?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo06Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0/?ooool002gooooo00Go0000ooooooooooooooooo`00001Xoooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0002aooooo`00;_ooool01?l0
003oooooo`000?l00023ooooo`03o`000?oooooooooo0;3ooooo000^ooooo`?o0000Q?ooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^ko
oooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002B
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0/?ooool009;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooo
oooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`000;3ooooo002Booooo`05o`000?oooooo
ooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo
00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo
002Booooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002[
ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0/?ooool00:gooooo00?o0000ooooooooool01Oooool3o`000;3ooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002]ooooo`03o`000?oooooooooo0;Sooooo002]oooo
o`03o`000?oooooooooo0;Sooooo002[ooooo`03oeEEEOmVIVKo00000;[ooooo003oooooofWooooo
002_ooooo`03o`000?nj^[[ooooo0;Kooooo002_ooooo`;o<S8b]oooool0083ooooo0_l000001_l@
413oooooooooool@413o0000oa0@41Oooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00;ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0N?ooool0
087ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00002Oooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03olc<c?l0
003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003Oooool02OmgMgOo<S8b
ooooooooooooV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0N?oo
ool0087ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Gooooo`03oiRHV?lQ8B7o
k^k^00Cooooo00Go410@oooooooooooooooooa0@400Booooo`03o`000?oooooooooo01oooooo00Oo
0000oooooooooooooooooiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@401hoooo
o`00POooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000;ooooo`03oiRHV?lQ8B7o
k^k^00?ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo00_ooooo1_l0
000=ooooo`03ogMgMolb<S;ooooo00?ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooo
oooooooo000007Sooooo0021ooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo00006oooool00omgMgOo
IVIVooooo`02ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0Koooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooo
ooooooooool00000N?ooool0087ooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Looooo`05o`00
0?ooooooooooooooool@41000oooool00ol@413oooooooooo`0>ooooo`03oa0@4?l0003o000000?o
00006_ooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool@41000oooool00ol@
413oooooooooo`1fooooo`00POooool01_l0003o<S8boooooooooooo<S8bo`0001Sooooo00Go0000
okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo00Cooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0N?ooool0083ooooo00?o410@o`000?n7QhL00_ooool00on7QhOo
0000oa0@400Gooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01;ooooo00?o0000ooooooooool06oooool4o`0000?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0N?ooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(530) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .27523 m
.00942 .28522 L
.01975 .30055 L
.02496 .31066 L
.03053 .32367 L
.04057 .35344 L
.05147 .39356 L
.06331 .43934 L
.06874 .45792 L
.07449 .47399 L
.07685 .4792 L
.0794 .48373 L
.08086 .4858 L
.08219 .48734 L
.08353 .48854 L
.08481 .48934 L
.08549 .48964 L
.08622 .48985 L
.08755 .48995 L
.08884 .48969 L
.09003 .48915 L
.09132 .48823 L
.09274 .48682 L
.09422 .48492 L
.0956 .48275 L
.10043 .4723 L
.10562 .45679 L
.12833 .36632 L
.13901 .32932 L
.15063 .29892 L
.1616 .27763 L
.16649 .27003 L
.17176 .26314 L
.17703 .25766 L
.17934 .25572 L
.18186 .2539 L
.18649 .25138 L
.18901 .25039 L
.19135 .24967 L
.19271 .24934 L
.19417 .24904 L
.19546 .24882 L
.19683 .24863 L
.19807 .24848 L
.19942 .24835 L
.20181 .24818 L
.20327 .2481 L
.2046 .24805 L
.20533 .24803 L
.20613 .24801 L
Mistroke
.20688 .248 L
.20758 .24799 L
.20896 .24798 L
.2102 .24799 L
.21089 .248 L
.21164 .24801 L
.21299 .24806 L
.21429 .24812 L
.21549 .2482 L
.21686 .24832 L
.21816 .24846 L
.22048 .24881 L
.22299 .24934 L
.22576 .25016 L
.22869 .25131 L
.23396 .25422 L
.23939 .25839 L
.24449 .26327 L
.25609 .27705 L
.26644 .29182 L
.27733 .31089 L
.29677 .35544 L
.30682 .37854 L
.31234 .38911 L
.31754 .39709 L
.3224 .40256 L
.32514 .40475 L
.32644 .40557 L
.32766 .40621 L
.32877 .40667 L
.32978 .40701 L
.33091 .40727 L
.33212 .40743 L
.33328 .40747 L
.33454 .40737 L
.33573 .40716 L
.33684 .40685 L
.33807 .40639 L
.33937 .40576 L
.34169 .40427 L
.34419 .40217 L
.34693 .39928 L
.35184 .39263 L
.35641 .38493 L
.37803 .33963 L
.38907 .31988 L
.39949 .30607 L
.40885 .29664 L
.41409 .29228 L
.419 .28885 L
Mistroke
.42378 .28625 L
.42646 .28517 L
.42892 .28444 L
.43031 .28414 L
.4316 .28393 L
.43234 .28385 L
.43301 .28379 L
.43379 .28375 L
.43452 .28373 L
.43585 .28376 L
.43708 .28384 L
.43842 .284 L
.43984 .28424 L
.44247 .28485 L
.44529 .28572 L
.45037 .28767 L
.46193 .29275 L
.48275 .30335 L
.49372 .31121 L
.49974 .31562 L
.50538 .31928 L
.51036 .32187 L
.51572 .32392 L
.51862 .32472 L
.52167 .32539 L
.52713 .32625 L
.5321 .32683 L
.53673 .32728 L
.53935 .32749 L
.54063 .32758 L
.54181 .32764 L
.54318 .3277 L
.5439 .32772 L
.54466 .32774 L
.54589 .32775 L
.54724 .32773 L
.5486 .32767 L
.54986 .32758 L
.55124 .32745 L
.55272 .32725 L
.55545 .32673 L
.55792 .32608 L
.56295 .32425 L
.56767 .32198 L
.58962 .31052 L
.60897 .30345 L
.61994 .29852 L
.6253 .2961 L
.63017 .2942 L
.63267 .29339 L
Mistroke
.63538 .29266 L
.63794 .29212 L
.64031 .29174 L
.64282 .29145 L
.64424 .29133 L
.64558 .29123 L
.64827 .2911 L
.65116 .29098 L
.65399 .29087 L
.65549 .2908 L
.65709 .2907 L
.66001 .29047 L
.66272 .29018 L
.66827 .28938 L
.6733 .28854 L
.67841 .28778 L
.68099 .2875 L
.68245 .28738 L
.68382 .2873 L
.68507 .28725 L
.68626 .28722 L
.68733 .28722 L
.68849 .28723 L
.68975 .28727 L
.69109 .28733 L
.69223 .2874 L
.6935 .2875 L
.69892 .28802 L
.70177 .28829 L
.70332 .28843 L
.70477 .28854 L
.70604 .28861 L
.70741 .28867 L
.70818 .28869 L
.70892 .28871 L
.71029 .28872 L
.71156 .2887 L
.71272 .28866 L
.714 .28859 L
.71536 .2885 L
.72601 .28716 L
.73126 .28644 L
.73382 .28616 L
.73613 .28596 L
.73722 .28588 L
.7384 .28581 L
.73942 .28576 L
.74053 .28572 L
.74172 .28569 L
.74297 .28566 L
Mistroke
.74413 .28565 L
.74522 .28564 L
.7465 .28564 L
.74772 .28563 L
.74881 .28563 L
.75 .28562 L
.75129 .2856 L
.75266 .28558 L
.75383 .28554 L
.75512 .28548 L
.75641 .28541 L
.75777 .28531 L
.7602 .28506 L
.7628 .28471 L
.76566 .2842 L
.77553 .2818 L
.79747 .27738 L
.81981 .27326 L
.83037 .27043 L
.83501 .2694 L
.8401 .26854 L
.84503 .26794 L
.85024 .26747 L
.85553 .26701 L
.86122 .26636 L
.8666 .26554 L
.87152 .26467 L
.87609 .26384 L
.88114 .26304 L
.88356 .26273 L
.88617 .26246 L
.88761 .26234 L
.88893 .26225 L
.89027 .26217 L
.89152 .26212 L
.8926 .26208 L
.89376 .26205 L
.89504 .26202 L
.89621 .262 L
.89742 .26199 L
.89874 .26198 L
.90114 .26197 L
.90249 .26196 L
.90376 .26195 L
.90515 .26192 L
.90593 .26191 L
.90664 .26189 L
.90807 .26184 L
.90963 .26178 L
.91247 .26161 L
Mistroke
.9151 .26141 L
.9179 .26116 L
.92293 .26063 L
.92818 .26011 L
.93083 .2599 L
.93235 .25981 L
.93373 .25974 L
.93446 .25971 L
.93525 .25969 L
.93609 .25967 L
.93688 .25965 L
.93762 .25965 L
.93841 .25965 L
.93908 .25965 L
.93982 .25966 L
.94054 .25967 L
.94121 .25969 L
.94271 .25974 L
.94403 .2598 L
.94542 .25987 L
.95553 .26062 L
.96123 .26107 L
.9666 .26152 L
.97066 .26195 L
.97295 .26226 L
.97506 .26261 L
.9788 .26342 L
.98275 .26463 L
.98699 .26638 L
.99096 .26851 L
1 .27523 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000/Oooool0
05;ooooo3Ol0001Fooooo`03o`000?oooooooooo0;3ooooo001Aooooo`03o`000?oooooooooo00[o
oooo0_l0001Eooooo`03o`000?oooooooooo0;3ooooo001?ooooo`;o00003oooool2o`0005?ooooo
00?o0000ooooooooool0/?ooool004kooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`1@ooooo`03o`000?oooooooooo08Kooooo2?l0000Rooooo`00COooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo04oooooo0_l0001goooooa3o00002?ooool7o`0001_ooooo001<oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`1aoooo
o`Go00007oooool3o`0001Sooooo000Eooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o
0000oc8b<_o^k^h06_ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`03o`000?oooooooooo01?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h07?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hNooooo`03o`00
0?oooooooooo01oooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^6_ooool5
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Gooooo`So000000Woc<c<oooooooooooooooo
onk^k_lb<S;o0000oc8b<_o^k^h07Oooool4o`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>
ooooo`005_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool0
1Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03o`00
0?oooooooooo01Cooooo00GoV9RHob4Q8Oo^k^ko0000odA4A003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL07_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01?o
oooo1?l00004ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9So
MgMg01kooooo00[o0000oooooooooooo0000oooooomgMgOoV9RHoooooonHV9SoMgMg3_ooool000_o
oooo1_l00002ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@01;ooooo1_l00006oooo
o`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo000000oooooo1_l0
0003ooooo`04oiRHV?lQ8B7ok^k^o`0000?ooooo00Go410@oooooooooooooooooa0@400Cooooo`Ko
00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41007_ooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400K
ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400>ooooo`Go00003?oo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool06Oooool5o`0000;ooooo
00?o0000oa0@4?ooool00_ooool00ol@413oooooooooo`0<ooooo`004oooool01?m4A4CogMgMoooo
ool00004ooooo`05o`000?ooooooooooooooool000007Oooool00onYZJWo410@ooooo`02ooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Hooooo`04oiRHV?lQ8B7ok^k^
o`0000;ooooo00Go0000ooooooooooooooooo`00000Nooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`00000Nooooo`;o00008_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000007?ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooooooooooo
ool000001oooool7o`00013ooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo
000001_ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000000kooooo
000Cooooo`03omgMgOmEEEGooooo00;o00000oooool01Ol0003ooooooooooooooooo000001cooooo
00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000oooooooo
ool06Oooool00omgMgOoIVIVo`000002ooooo`05o`000?ooooooooooooooool000007_ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03ogMgMomV
IVKooooo00;ooooo00Ko0000ooooooooooooooooo`000?ooool6o`0001Kooooo00?o410@o`000?nj
^[X00oooool01Ol0003ooooooooooooooooo000001_ooooo00CogMgMoeEEEOoooooo00001?ooool0
1Ol0003ooooooooooooooooo000000kooooo000Dooooo`05ogMgMoo<c<co0000ooooool000000_oo
ool01Ol@413ooooooooooooooooo410@01gooooo00?o^[Zjob4Q8Oooool00_ooool01ol@413ooooo
oooooooooooo410@ooooool000007Oooool01Ol0003oooooo`000?oooooo410@00?ooooo00?o410@
ooooooooool07?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001ooo
ool6o`00017ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41007_ooool01Ol0003ooooooooooooooooo410@00?ooooo0_l0000Mooooo`03
okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@400Looooo`03ogMgMoo<c<co0000
00Cooooo00Go410@oooooooooooooooooa0@400>ooooo`005?ooool00oo^k^koA4A4o`000002oooo
o`07o`000?ooooooMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05oa0@4?nHV9SooooookZj^_l00000
0oooool01omgMgOoV9RHoooooonHV9SoMgMgooooool000006Oooool01Ol0003o^[ZjoooooonHV9So
410@00;ooooo00Ko0000ogMgMonHV9SooooooiRHV?mgMgLNooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o00001Oooool4o`0000kooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02_ooool8o`00
00Kooooo3_l000000omgMgOoooooooooo`0Iooooo`05oa0@4?nHV9SooooookZj^_l000000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00kooooo000Eooooo`0;ogMgMol0003oooooooooool0003oooooonk^k_lb<S;o0000
oc8b<_o^k^h06_ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Kok^k^oc8b<_l0003o<S8b
onk^k_l0000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Ol0003o<S8bo`000?lb<S;o
k^k^01cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00?o
0000ooooooooool02Oooool2o`0000cooooo00?o0000ooooooooool07oooool00omEEEGoIVIVo`00
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02_l00008ooooo`Ko00000_ooool01OnHV9So410@
o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000
oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo00?oMgMgo`000?ooool00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Jooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`0[ooooo`;o00003_ooool2o`0000[ooooo0_l0
000Wooooo`Ko0000Q?ooool001_ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool04?ooool2o`0000Sooooo00?o0000
ooooooooool09?ooool2o`0008[ooooo000Looooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01?ooooo0_l00006oooo
o`03o`000?oooooooooo02;ooooo0_l0002<ooooo`007?ooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Fooooo`;o
00001?ooool00ol0003oooooooooo`0Oooooo`?o0000S_ooool001gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
6Oooool01Ol0003ooooooooooooooooo000001kooooo0ol0002Aooooo`005_ooooooo`00043o0000
4oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`;o00001_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00oooool3o`0000Oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o00000oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo017ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool07oooool2o`0001Kooooo0ol0000=ooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo017ooooo000Noooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo01oooooo00?o0000ooooool000004oooool2o`0009_ooooo000Oooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool00_l0000@ooooo`03o`000?oooooooooo09_o
oooo000Oooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0:_ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo023ooooo0_l00003ooooo`Co00002_ooool2o`0009kooooo
000Oooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0:_ooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01_ooool:o`000:3ooooo000P
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0/?ooool0023ooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`2`ooooo`008Oooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo0;3ooooo000Qooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Cooooo0_l0002aooooo`008Ooo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo0;3ooooo000Rooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0/?ooool002;ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`2`ooooo`008oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo0;3o
oooo000Sooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo02Kooooo0_l0002aooooo`008oooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo0;3ooooo000Tooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool0/?ooool002Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0coooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`2`oooo
o`009?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0;3ooooo000Tooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo02Wooooo0_l0002aooooo`009Oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo0;3ooooo000Uooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`00
0?oooooooooo0;3ooooo000Uooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`2`ooooo`009Oooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`08ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0/?ooool002Gooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0hooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02?ooool01Ol0003ooooo
oooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o
0000/?ooool002Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0iooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo000000ko
oooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0/?ooool002Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0jooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool01Ol@413ooooooooooooooooo410@
00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
0;3ooooo000Vooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0??ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0;3ooooo000Vooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool0/?oo
ool002Oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00?ooooo0_l0000aooooo`;o0000/Oooool002Oooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0nooooo`Ko0000<_ooool00ol0003oooooooooo`2`ooooo`009oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool0/?ooool002Oooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo0;3ooooo
000Xooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Moooool00ol0003ooooooooo
o`2`ooooo`00:?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo07Sooooo0_l0002a
ooooo`00:?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo07Sooooo00?o0000oooo
ooooool0/?ooool002Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1hooooo`03
o`000?oooooooooo0;3ooooo000Yooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
N?ooool00ol0003oooooooooo`2`ooooo`00:Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo07Wooooo0_l0002aooooo`00:Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo07Wooooo00?o0000ooooooooool0/?ooool002[ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`1iooooo`03o`000?oooooooooo0;3ooooo000Zooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`2`ooooo`00:_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0/?ooool002_ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1jooooo`;o0000/Oooool002_ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo0;3ooooo000[oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`2`oooo
o`00;?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo063ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool0/?ooool002cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Poooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`2`ooooo`00;?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
063ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0002`
ooooo`00;?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo067ooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool0
02gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Qooooo`05o`000?oooooooooo
ooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?oo
ool002gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Qooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo000]
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0HOooool01OmgMgOoV9RHoooooonH
V9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00;_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo06;ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`Co00001_ooool2o`000;7ooooo000^ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0O_ooool00ol0003oooooooooo`2`ooooo`00;oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo07kooooo00?o0000ooooooooool0/?ooool0033ooooo00Co0000ooooool0
003o0000POooool00ol0003oooooooooo`2`ooooo`00<Oooool2o`0008;ooooo00?o0000oooooooo
ool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^oooo
o`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00T_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooo
oooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo0;3ooooo002Booooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooo
ooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00T_ooool01Ol0003ooooooooo
oooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool0/?ooool009;ooooo00Go410@oooooooooooooooooa0@400>ooooo`03
ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00
T_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Zooo
ool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool00:gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo0ol0002`ooooo`00
[Oooool00ol0003oooooooooo`2hooooo`00[Oooool00ol0003oooooooooo`2hooooo`00[Oooool0
0ol0003oooooooooo`2hooooo`00Zoooool00omEEEGoIVIVo`00002jooooo`00oooooomYooooo`00
[oooool00ol0003o^[Zjooooo`2fooooo`00[oooool2oc8b<[Oooooo0020ooooo`;o000000Ko410@
oooooooooooo410@o`000?l@410Gooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Wooooo00GoA4A4o`00
0?l0003o<S8bomgMg@02ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^07Sooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01ooo
ool6o`0000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`00
00gooooo00WoMgMgoc8b<_oooooooooooa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RH
oooooonHV9SoMgMg07Sooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
5oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41004_ooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooooa0@4003oooo
o`03oa0@4?oooooooooo07Kooooo0021ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6
o`0000_ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000001;ooooo00?o
0000ooooooooool02oooool6o`0000gooooo00?oMgMgoc8b<_ooool01?ooool00onYZJWo410@oooo
o`02ooooo`05o`000?ooooooooooooooool00000N?ooool0087ooooo00Ko0000omgMgOlb<S;oEEEE
omgMgOl0000Kooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00000Boooo
o`03o`000?oooooooooo01_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03oa0@4?l0003o
^[Zj00?ooooo00Go0000ooooooooooooooooo`00001hooooo`00POooool01_l0003oQhN7ojVYZOnj
^[[oEEEEo`0001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00ko
oooo00?o410@o`000?l000000ol0000Jooooo`03o`000?oooooooooo00Oooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@07Sooooo0021ooooo`06o`000?lb<S;ooooooooo
oolb<S;o00006?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0Booooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01?ooool01Ol@413oV9RH
oooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1hooooo`00P?ooool00ol@413o
0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Kooooo`Co00000oooool0
1OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1hooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(540) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .26356 m
.00488 .26707 L
.00942 .27109 L
.01483 .27707 L
.01975 .28393 L
.02981 .30313 L
.03534 .31702 L
.04057 .33239 L
.06357 .42026 L
.07368 .45961 L
.07645 .4688 L
.07942 .47748 L
.082 .48377 L
.08336 .4866 L
.08481 .4892 L
.08623 .49132 L
.08753 .49286 L
.08883 .49403 L
.09005 .49478 L
.0913 .49518 L
.09244 .49522 L
.0937 .49491 L
.09503 .49417 L
.09615 .49324 L
.09734 .49192 L
.09949 .48872 L
.10205 .48361 L
.10439 .47782 L
.11505 .44076 L
.12514 .39806 L
.14427 .32609 L
.15516 .29639 L
.1605 .28496 L
.16539 .27626 L
.17016 .26936 L
.17538 .26351 L
.18063 .25919 L
.18349 .25739 L
.18615 .25601 L
.18903 .25478 L
.19174 .25384 L
.19421 .25313 L
.19682 .25252 L
.19966 .252 L
.20093 .25182 L
.20228 .25166 L
.20305 .25159 L
.20374 .25154 L
.20511 .25146 L
.20587 .25143 L
Mistroke
.2067 .25142 L
.20748 .25143 L
.20821 .25144 L
.20957 .25152 L
.21025 .25157 L
.211 .25165 L
.21232 .25183 L
.21356 .25205 L
.21635 .25273 L
.21791 .25324 L
.21934 .25378 L
.22471 .25652 L
.2298 .2601 L
.23917 .26879 L
.24935 .28045 L
.27016 .31264 L
.29223 .36028 L
.30209 .37928 L
.30727 .3872 L
.31271 .39372 L
.31503 .3959 L
.31751 .39782 L
.31893 .39873 L
.32022 .39944 L
.32153 .40003 L
.32274 .40047 L
.32384 .40078 L
.32501 .40101 L
.32618 .40114 L
.32747 .40115 L
.32858 .40107 L
.32977 .40087 L
.33089 .40058 L
.33192 .40023 L
.33431 .39908 L
.33696 .39728 L
.33972 .39482 L
.34231 .39197 L
.35194 .37758 L
.36255 .35774 L
.37372 .33779 L
.38383 .32339 L
.39489 .31113 L
.40495 .30217 L
.40982 .2987 L
.41431 .29622 L
.41688 .29515 L
.4196 .29433 L
.42101 .29403 L
.42234 .29382 L
Mistroke
.42309 .29374 L
.42379 .29368 L
.42458 .29364 L
.42534 .29362 L
.4266 .29365 L
.42793 .29373 L
.42919 .29387 L
.43033 .29404 L
.43313 .2946 L
.43577 .29529 L
.45528 .30156 L
.47637 .3105 L
.48574 .31619 L
.49089 .31911 L
.49578 .32139 L
.49834 .32234 L
.50113 .32317 L
.50366 .32375 L
.50601 .32416 L
.50821 .32444 L
.51064 .32466 L
.51186 .32474 L
.51318 .32482 L
.51556 .32492 L
.52107 .32512 L
.52688 .32535 L
.52928 .32544 L
.53059 .32548 L
.53184 .32551 L
.53254 .32552 L
.53331 .32553 L
.53465 .32552 L
.53601 .32549 L
.53726 .32543 L
.53858 .32535 L
.53983 .32523 L
.54095 .32509 L
.54217 .32491 L
.54491 .32438 L
.54745 .3237 L
.55206 .32206 L
.55697 .31982 L
.57865 .30997 L
.59968 .30353 L
.61073 .29886 L
.61677 .29652 L
.61971 .2956 L
.62239 .29492 L
.62499 .29442 L
.62745 .29407 L
Mistroke
.6288 .29394 L
.63005 .29384 L
.63142 .29376 L
.63211 .29373 L
.63287 .29371 L
.63364 .29368 L
.63436 .29367 L
.63573 .29365 L
.63649 .29364 L
.6372 .29363 L
.63802 .29363 L
.6388 .29362 L
.63948 .29361 L
.64021 .2936 L
.64149 .29358 L
.64222 .29356 L
.64298 .29353 L
.64436 .29347 L
.64561 .2934 L
.64676 .29332 L
.64933 .29307 L
.65172 .29276 L
.65398 .29241 L
.65899 .29148 L
.66453 .29046 L
.66705 .29008 L
.66837 .28992 L
.66976 .28977 L
.67098 .28967 L
.67232 .28958 L
.67353 .28954 L
.67466 .28952 L
.67534 .28952 L
.67607 .28952 L
.67739 .28956 L
.67868 .28961 L
.67987 .28969 L
.68257 .2899 L
.68543 .29018 L
.68771 .29041 L
.68987 .2906 L
.69106 .29068 L
.69236 .29076 L
.69354 .29081 L
.69464 .29083 L
.69597 .29084 L
.69717 .29082 L
.69784 .29079 L
.69856 .29076 L
.69987 .29067 L
Mistroke
.70111 .29055 L
.70242 .2904 L
.70477 .29006 L
.7155 .28784 L
.71806 .28732 L
.72078 .28683 L
.72329 .28647 L
.72565 .2862 L
.72774 .28603 L
.72892 .28595 L
.72999 .2859 L
.73232 .28581 L
.73349 .28578 L
.73477 .28574 L
.73726 .28568 L
.73865 .28564 L
.73991 .28559 L
.74109 .28553 L
.74236 .28544 L
.74468 .28523 L
.74596 .28508 L
.74715 .28491 L
.74987 .28443 L
.75536 .28307 L
.7652 .27987 L
.77064 .27821 L
.77579 .27699 L
.77864 .27649 L
.78174 .27608 L
.78717 .27556 L
.7919 .27513 L
.79701 .27449 L
.79994 .27397 L
.80262 .2734 L
.8079 .27204 L
.81341 .27045 L
.81931 .26887 L
.82217 .26825 L
.82488 .26778 L
.82731 .26746 L
.82868 .26732 L
.82994 .26722 L
.83108 .26714 L
.83231 .26708 L
.83347 .26703 L
.83452 .267 L
.83576 .26698 L
.83711 .26696 L
.83957 .26693 L
.84089 .26691 L
Mistroke
.84213 .26689 L
.84282 .26688 L
.84357 .26686 L
.84486 .26681 L
.84611 .26675 L
.84742 .26667 L
.84978 .26647 L
.85236 .26618 L
.85513 .26578 L
.86013 .26486 L
.86604 .26368 L
.86864 .2632 L
.8715 .26273 L
.87399 .2624 L
.87668 .26213 L
.87816 .26202 L
.87952 .26194 L
.88082 .26188 L
.88219 .26184 L
.88292 .26183 L
.88358 .26182 L
.88434 .26181 L
.88506 .2618 L
.88635 .2618 L
.88707 .2618 L
.88774 .2618 L
.88846 .2618 L
.88914 .26179 L
.88989 .26179 L
.89069 .26179 L
.89152 .26178 L
.89232 .26177 L
.89303 .26176 L
.89381 .26174 L
.8945 .26172 L
.89524 .2617 L
.8966 .26164 L
.89791 .26156 L
.89912 .26147 L
.90187 .2612 L
.90477 .26081 L
.91494 .25889 L
.92007 .25788 L
.92492 .25709 L
.9276 .25675 L
.93051 .25646 L
.93316 .25627 L
.9356 .25613 L
.94488 .25575 L
.9501 .25545 L
Mistroke
.95487 .25507 L
.96007 .2546 L
.96263 .25439 L
.96388 .2543 L
.96501 .25423 L
.96606 .25418 L
.96721 .25414 L
.96841 .25411 L
.96955 .25411 L
.97081 .25412 L
.97214 .25417 L
.97327 .25424 L
.97451 .25434 L
.97596 .25449 L
.97734 .25468 L
.97991 .25513 L
.98269 .25578 L
.98571 .25667 L
.99114 .25877 L
.99616 .26126 L
1 .26356 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool005Cooooo2?l0001Iooooo`03o`000?oooooooooo0;3o
oooo001Aooooo`?o00002?ooool2o`0005Oooooo00?o0000ooooooooool0QOoooolDo`0001Oooooo
001?ooooo`;o00003Oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo083ooooo1Ol0
000Dooooo`;o00005Oooool004oooooo00?o0000ooooooooool03Oooool2o`0005Cooooo0_l0001d
ooooo`go00006oooool00ol0003oooooooooo`0Booooo`005_ooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`1]oooo
o`Ko0000:Oooool00ol0003oooooooooo`0Aooooo`005Oooool4o`0000;ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0Jooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Kooooo00?o0000ooooooooool04_ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0Looooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQkooooo00?o0000
ooooooooool07oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hJooooo`Go
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^013ooooo2ol000001OnHV9So410@o`000?lb<S;o
c<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Mooooo`;o000000Wo410@oooooooooooooooo
onk^k_lb<S;o0000oc8b<_o^k^h03_ooool001Kooooo00[o0000oooooooooooo0000oooooomgMgOo
V9RHoooooonHV9SoMgMg6_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`03o`000?oooooooooo01?ooooo00Go0000ob4Q8Oo^k^koooooodA4A003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL07_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo1?l0000;ooooo`05oa0@4?nj^[[oooooogMgMolb<S800ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00kooooo000;ooooo`Ko00000_ooool5o`000004ooooool0003ooooooa0@40?o
oooo00?o410@ooooooooool04?ooool6o`0000Kooooo00Go0000oooooooooooooooooa0@4003oooo
o`03oa0@4?oooooooooo00;ooooo00?o0000ooooooooool03?ooool6o`0000?ooooo00?o0000ob4Q
8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01?ooooo1_l00005ooooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@400Nooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01_ooooo00?oV9RHob4Q8Oo^k^h0
1?ooool01Ol@413ooooooooooooooooo410@00Kooooo1_l0000Cooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0Iooooo`Go00000oooool01Ol@413ooooooooooooooooo
410@00kooooo000Cooooo`04odA4A?oMgMgoooooo`0000?ooooo0_l00003ooooo`03o`000?oooooo
oooo01_ooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool05oooool00ol0003o8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool00000
7_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007_ooool2o`0002;o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001cooooo00?oV9RHob4Q
8Oo^k^h00oooool01?l0003oooooooooooooool7o`0001Sooooo00?oZJVYoa0@4?ooool00_ooool0
1Ol0003ooooooooooooooooo000001_ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000000kooooo000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000oooooooo
ooooooooo`00000Looooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo01Sooooo00?o0000ofIVI_ooool00_ooool01Ol0003ooooooooooooo
oooo000001kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001kooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00007Oooool00omgMgOoIVIVooooo`02ooooo`03o`000?oooooooooo00;o00007Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool000006oooool01?oMgMgoEEEEooooool00004
ooooo`05o`000?ooooooooooooooool000003_ooool001Cooooo00?oMgMgolc<c?l000001?ooool0
1Ol@413o0000oooooooooooo410@01gooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooo
oooooooo410@00;ooooo00?o0000ooooooooool06Oooool2o`0000?ooooo00Go410@oooooooooooo
oooooa0@400Nooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Noooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@01kooooo00?o0000ooooooooool01?l000000ooooooo410@ooooo`0Mooooo`03okZj^_lQ8B7o
oooo00;ooooo00Go410@oooooooooooooooooa0@400Looooo`03ogMgMoo<c<co000000Cooooo00Go
410@oooooooooooooooooa0@400>ooooo`005?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMol0
003ooooooiRHV?mgMgL06_ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`02ooooo`03o`000?oooooooooo01Kooooo00Go0000okZj^_ooooooV9RHo`000003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL07_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0Eooooo`co000000KoooooogMgMonHV9SooooooiRHV?mgMgLK
ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01cooooo
00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000Eooooo`03ogMg
Mol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Jooooo`05ojVYZOl@413o0000oa0@
4?nYZJT00oooool01oo^k^ko<S8bo`000?lb<S;ok^k^ooooool000006Oooool01_nHV9So410@o`00
0?lQ8B7oc<c<o`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Looooo`03oeEEEOmVIVKo0000
00Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Nooooo`03o`000?oooooooooo01oooooo00?oEEEE
ofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo4?l00005ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Oooool00omgMgOo0000ooooo`03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool001gooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo037ooooo1Ol0000Eooooo`;o00009_ooool;
o`00083ooooo000Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`0^ooooo`;o00001Oooool3o`0001;ooooo00?o0000ooooooooool08Oooool4o`00
08_ooooo000Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo00Sooooo0ol0000?ooooo`03o`000?oooooooooo01oo
oooo0_l0002?ooooo`007oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool0:Oooool2o`0000kooooo0ol0000<ooooo`03o`000?oooooooooo01_ooooo
1?l0002Aooooo`007oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`0Aooooo`;o00002_ooool00ol0003ooooooooo
o`0Hooooo`?o0000UOooool001Koooooool00010o`0001?ooooo000Fooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`;o00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo0000
00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`?o00001Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool3o`00
00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`005_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01[ooooo0_l00003ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Aooooo`008Oooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`0Mooooo`;o000000?oooooo`000?ooool04Oooool2o`0009kooooo000Qooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo023ooooo0_l0000?ooooo`?o0000X?ooool002;ooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool08_ooool@
o`000:?ooooo000Rooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0/?ooool002;o
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`2`ooooo`008oooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo0;3ooooo000Sooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0/?ooool002?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool09Oooool2o`000;7ooooo000Toooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0/?ooool002Cooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`2`ooooo`009?ooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo0;3ooooo000Tooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0/?oo
ool002Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0:?ooool2o`000;7ooooo000Uooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool0/?ooool002Gooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`2`ooooo`009Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo0;3ooooo
000Vooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0/?ooool002Kooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0:oooool2o`000;7ooooo000Vooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool0<_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool0/?ooool002Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool02Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool0/?ooool002Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool02Oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo0;3ooooo000Wooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`2`ooooo`009oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;ooooo`05o`000?oooooo
ooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0
002`ooooo`009oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000003_oo
ool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`2`ooooo`00:?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03Sooooo00?o
0000ooooooooool01_ooool2o`0000kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00:?oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03Wooooo0_l00005ooooo`03o`000?oo
oooooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@
41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo000Xooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool0>_ooool6o`00017ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000oooo
ooooool0/?ooool002Sooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1dooooo`;o
0000/Oooool002Wooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1eooooo`03o`00
0?oooooooooo0;3ooooo000Yooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0MOoo
ool00ol0003oooooooooo`2`ooooo`00:Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo07Gooooo00?o0000ooooooooool0/?ooool002Wooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`1fooooo`03o`000?oooooooooo0;3ooooo000Zooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0M_ooool2o`000;7ooooo000Zooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0M_ooool00ol0003oooooooooo`2`ooooo`00:_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool0/?ooool002[ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo0;3ooooo000[oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0Moooool2o`000;7ooooo000[ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`2`ooooo`00
:oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0
/?ooool002_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1hooooo`03o`000?oo
oooooooo0;3ooooo000/ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0N?ooool0
0ol0003oooooooooo`2`ooooo`00;?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
07Sooooo0_l0002aooooo`00;?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo07Wo
oooo00?o0000ooooooooool0/?ooool002cooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`1iooooo`03o`000?oooooooooo0;3ooooo000]ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0G_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00;Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo05kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo000]ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0Goooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool00oooool3o`000;3ooooo000^ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0Goooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`2`ooooo`00;_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo05oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`2`ooooo`00;_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo05oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0/?ooool002oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`1Pooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo0;3ooooo000_ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0H?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000/Oooool002oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo0;3o
oooo000`ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0O?ooool00ol0003ooooo
ooooo`2`ooooo`00<?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07gooooo00?o
0000ooooooooool0/?ooool0037ooooo00Go0000ooooooooooooooooo`00001oooooo`03o`000?oo
oooooooo0;3ooooo000booooo`?o0000P?ooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0;3ooooo002Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEE
ojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0/?ooool009;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`000;3ooooo002Boooo
o`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooo
oooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0;3ooooo002Booooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooo
oooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002[ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`2`oooo
o`00[Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;3ooooo002]ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool00:gooooo00?o0000ooooooooool01Ooo
ool3o`000;3ooooo002]ooooo`03o`000?oooooooooo0;Sooooo002]ooooo`03o`000?oooooooooo
0;Sooooo002]ooooo`03o`000?oooooooooo0;Sooooo002[ooooo`03oeEEEOmVIVKo00000;[ooooo
003oooooofWooooo002_ooooo`03o`000?nj^[[ooooo0;Kooooo002_ooooo`;o<S8b]oooool0083o
oooo0_l000001_l@413oooooooooool@413o0000oa0@41Oooooo1Ol00003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X0
6Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo0_l000002Ol@413oooooooooooooooook^k^
oc8b<_l0003o<S8bonk^kP1hooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Oooooo1_l00009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wo
oooo1_l0000=ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg07Sooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool05oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41004_ooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo00Go00000oooool01Ol@413ooooooooooooooooo
410@07Sooooo0021ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000_ooooo00?o
V9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool0
2oooool6o`0000gooooo00SoMgMgoc8b<_ooooooooooodA4A?oMgMgoooooo`0000Cooooo00Go0000
ooooooooooooooooo`00001hooooo`00POooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001_ooooo
00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000oooooooo
ool06oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00CogMgMoeEEEOoooooo00001?ooool0
1Ol0003ooooooooooooooooo000007Sooooo0021ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo0000
7?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool03_ooool00ol@413o
0000o`000003o`0001[ooooo00?o0000ooooooooool01Oooool00omgMgOoc<c<o`000004ooooo`05
oa0@4?ooooooooooooooool@4100N?ooool0087ooooo00Ko0000oc8b<_oooooooooooc8b<_l0000H
ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`05ooooo`03onk^k_m4A4Co000000Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`1hooooo`00P?ooool00ol@413o0000ohN7Q`02ooooo`03ohN7
Qol0003o410@01Oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h04_ooool00ol0003oooooooooo`0Kooooo`Co00001Oooool00omgMgOo0000ooooo`03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h0N?ooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(550) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .25427 m
.00488 .25692 L
.00942 .26021 L
.01441 .265 L
.01975 .27176 L
.03065 .29135 L
.04057 .3162 L
.05147 .35175 L
.06331 .39956 L
.07354 .44341 L
.07897 .46419 L
.08196 .47404 L
.08481 .48201 L
.08749 .48808 L
.08891 .49067 L
.09042 .49294 L
.09182 .49456 L
.09309 .49563 L
.09436 .49632 L
.09556 .49661 L
.09679 .49654 L
.09808 .49608 L
.09919 .49537 L
.1004 .49426 L
.10171 .49268 L
.10311 .49057 L
.10564 .48569 L
.11157 .46949 L
.11719 .44941 L
.12772 .40554 L
.14685 .33107 L
.15209 .31517 L
.15774 .30067 L
.16796 .28112 L
.17324 .274 L
.1788 .26828 L
.18354 .26461 L
.18873 .26166 L
.19162 .26044 L
.19425 .2596 L
.19571 .25923 L
.19729 .25892 L
.19801 .2588 L
.19878 .2587 L
.20015 .25857 L
.20142 .25851 L
.20277 .25851 L
.20405 .25856 L
.20522 .25867 L
.20658 .25886 L
Mistroke
.20807 .25914 L
.21079 .25986 L
.21348 .26083 L
.21638 .26217 L
.22165 .2653 L
.23148 .27324 L
.24297 .28538 L
.25352 .29951 L
.275 .33797 L
.28549 .35796 L
.29504 .37368 L
.29978 .38012 L
.30494 .38589 L
.30731 .38806 L
.30982 .39003 L
.31217 .39154 L
.31432 .39263 L
.31548 .39309 L
.31676 .3935 L
.31804 .3938 L
.31938 .39399 L
.32058 .39406 L
.32185 .39402 L
.32305 .39388 L
.32414 .39367 L
.32481 .39349 L
.32553 .39327 L
.32681 .39277 L
.32971 .39123 L
.33221 .38943 L
.33496 .38697 L
.34566 .37363 L
.35542 .35883 L
.36682 .34243 L
.37737 .32962 L
.38688 .31978 L
.39739 .31087 L
.40001 .30911 L
.40283 .30747 L
.40527 .30628 L
.40795 .30524 L
.4108 .30443 L
.41235 .30412 L
.4131 .304 L
.4138 .30391 L
.41516 .30377 L
.4164 .3037 L
.41773 .30368 L
.41848 .30368 L
.41918 .3037 L
Mistroke
.42049 .30377 L
.42173 .30387 L
.42407 .30413 L
.42934 .30496 L
.43885 .3067 L
.46051 .31221 L
.47136 .31718 L
.47667 .31965 L
.48156 .32157 L
.48602 .32287 L
.48827 .32334 L
.49073 .32373 L
.49202 .32388 L
.4932 .32399 L
.49457 .32409 L
.49586 .32415 L
.49705 .32419 L
.49815 .32421 L
.49936 .32422 L
.50064 .32422 L
.50191 .32422 L
.50308 .32421 L
.50434 .32419 L
.50571 .32418 L
.50691 .32417 L
.50803 .32417 L
.50921 .32417 L
.51047 .32418 L
.5112 .32418 L
.51187 .32419 L
.51339 .32422 L
.51615 .32427 L
.51745 .3243 L
.51866 .32432 L
.51992 .32433 L
.52059 .32434 L
.52131 .32434 L
.52202 .32433 L
.52278 .32432 L
.52414 .32428 L
.52497 .32425 L
.52575 .3242 L
.52722 .32409 L
.52862 .32395 L
.52991 .32378 L
.53282 .32324 L
.53527 .32264 L
.53794 .3218 L
.54334 .31965 L
.55478 .31421 L
Mistroke
.5604 .31189 L
.5656 .31022 L
.57531 .30801 L
.58586 .30542 L
.59604 .30171 L
.60165 .29953 L
.60442 .29858 L
.60699 .29781 L
.60958 .29718 L
.61193 .29674 L
.61327 .29654 L
.61454 .2964 L
.61588 .29628 L
.61663 .29623 L
.61733 .29619 L
.61846 .29615 L
.61952 .29613 L
.62068 .29613 L
.62193 .29614 L
.62323 .29616 L
.62447 .2962 L
.62679 .29626 L
.62801 .29629 L
.62916 .29632 L
.63035 .29633 L
.63168 .29632 L
.63281 .2963 L
.63385 .29626 L
.635 .29621 L
.6362 .29613 L
.63742 .29602 L
.63873 .29588 L
.64109 .29556 L
.64644 .29457 L
.65227 .29336 L
.65514 .29283 L
.65778 .29243 L
.66019 .29216 L
.6614 .29206 L
.66273 .29198 L
.66407 .29194 L
.66482 .29193 L
.6655 .29192 L
.66683 .29194 L
.66809 .29197 L
.6694 .29203 L
.67082 .29211 L
.67339 .29228 L
.67567 .29244 L
.67688 .29251 L
Mistroke
.67818 .29258 L
.67892 .29261 L
.67959 .29263 L
.6809 .29266 L
.68161 .29266 L
.68238 .29265 L
.68311 .29263 L
.68378 .29261 L
.68496 .29254 L
.68627 .29244 L
.68764 .29229 L
.68892 .29211 L
.69129 .29169 L
.69378 .29114 L
.69822 .28992 L
.70824 .287 L
.71095 .28637 L
.7135 .28589 L
.7158 .28554 L
.71828 .28525 L
.72099 .28502 L
.72386 .28484 L
.72634 .28469 L
.729 .28451 L
.73148 .28428 L
.73375 .284 L
.73603 .28364 L
.73819 .2832 L
.74303 .28192 L
.74829 .28015 L
.75343 .27831 L
.75898 .27653 L
.76153 .27587 L
.76422 .27531 L
.76651 .27494 L
.76902 .27464 L
.77039 .27452 L
.77164 .27443 L
.77444 .27428 L
.77707 .27417 L
.77949 .27407 L
.78235 .2739 L
.78385 .27378 L
.78544 .27361 L
.78812 .27326 L
.79107 .27274 L
.80152 .27012 L
.80667 .26881 L
.80918 .26828 L
.81145 .26789 L
Mistroke
.81273 .26771 L
.8141 .26755 L
.81556 .26743 L
.81693 .26734 L
.81765 .26731 L
.81844 .26728 L
.81927 .26726 L
.82004 .26726 L
.82142 .26726 L
.8222 .26727 L
.8229 .26729 L
.82798 .26746 L
.82922 .26749 L
.83055 .26752 L
.83131 .26753 L
.83201 .26753 L
.83338 .26752 L
.83463 .26748 L
.8358 .26743 L
.83708 .26734 L
.83845 .26722 L
.84125 .26686 L
.84379 .26641 L
.85342 .26408 L
.8588 .26277 L
.86164 .26222 L
.86464 .26176 L
.86726 .26148 L
.86875 .26137 L
.87015 .26128 L
.87143 .26123 L
.87259 .26119 L
.87394 .26116 L
.87522 .26114 L
.87654 .26113 L
.87795 .2611 L
.87929 .26108 L
.88052 .26104 L
.88164 .261 L
.88286 .26093 L
.88413 .26084 L
.88532 .26074 L
.88804 .26041 L
.89051 .26 L
.89607 .25868 L
.90544 .25575 L
.91058 .25423 L
.91539 .25312 L
.91778 .25271 L
.92036 .25236 L
Mistroke
.92321 .25208 L
.92583 .25188 L
.93083 .25156 L
.93547 .25117 L
.93806 .25087 L
.94082 .25046 L
.94665 .24931 L
.95219 .24802 L
.95729 .24694 L
.95974 .24653 L
.96114 .24634 L
.96242 .2462 L
.96378 .24609 L
.96452 .24605 L
.96523 .24602 L
.96648 .24599 L
.96785 .24601 L
.96921 .24606 L
.96999 .24611 L
.97072 .24617 L
.97219 .24632 L
.97378 .24652 L
.97665 .24701 L
.97928 .24756 L
.98937 .25031 L
1 .25427 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000Soooool8
o`0001[ooooo002eooooo`03o`000?oooooooooo08Wooooo1Ol00007ooooo`Ko00005Oooool00;Go
oooo00?o0000ooooooooool0POooool8o`0001;ooooo00?o0000ooooooooool04_ooool001Kooooo
00?o0000ooooooooool0W?ooool00ol0003oooooooooo`1mooooo`Co00006oooool00ol0003ooooo
ooooo`0Aooooo`005oooool2o`0003_ooooo1_l0001Kooooo`03o`000?oooooooooo07[ooooo0ol0
000cooooo`006Oooool00ol0003oooooooooo`0eooooo`?o00001_ooool2o`0005Wooooo0_l0001_
ooooo`co0000=_ooool001[ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0K?ooool2o`0004;ooooo000Eooooo`;o
000000Wo410@ooooooooooooooooo`000?lb<S;o0000oc8b<_o^k^h06_ooool01OnHV9So410@o`00
0?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool00_ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Loooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQkooooo00?o0000ooooooooool0
7oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hJooooo`Go00000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo3_l000001_ooooooV9RHoa0@4?l0003o<S8bolc<c0?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Mooooo`;o000000Wo410@ooooooooooooooooonk^k_lb
<S;o0000oc8b<_o^k^h03_ooool001Kooooo00?o0000ooooooooool00_ooool01OmgMgOo0000oooo
oonHV9SoMgMg01[ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01oooool00ol0003oooooooooo`0=ooooo`09o`000?oooooooooooooooonHV9So8B4Qonk^
k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00GoV9RHob4Q8Oo^k^koooooodA4
A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02_ooool2o`0000oooooo00Go410@okZj^_oooooo
MgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool000_ooooo1_l00002ooooo`Go00000oooool01Ol@
413o0000oooooooooooo410@01;ooooo1_l00006ooooo`05o`000?ooooooooooooooool@41000ooo
ool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo1_l00003ooooo`03oiRHV?lQ
8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400Cooooo`Ko00001Oooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41007_ooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Kooooo`03oiRHV?lQ8B7ok^k^
00Cooooo00Co410@oooooooooooooooo2ol0000Eooooo`05o`000?ooooooooooooooool@41000ooo
ool00ol@413oooooooooo`0Iooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00kooooo
000Cooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooool0003oooooo`00000Mooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo
017ooooo00Oo0000oooooooooooooooooiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Nooooo`;o
00008_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007?ooool00onH
V9So8B4Qonk^kP03ooooo`Go00007_ooool00onYZJWo410@ooooo`02ooooo`05o`000?oooooooooo
ooooool000006oooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool00000
3_ooool001?ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003oooooo`000?oooooo000001co
oooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool04oooool01_l0003oooooooooooooooooMgMgofIVIP?ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Nooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
01gooooo00?oMgMgofIVI_ooool00ol00003ooooo`03o`000?oooooooooo01_ooooo00?o410@o`00
0?nj^[X00oooool01Ol0003ooooooooooooooooo000001_ooooo00CogMgMoeEEEOoooooo00001?oo
ool01Ol0003ooooooooooooooooo000000kooooo000Dooooo`03ogMgMoo<c<co000000Cooooo00Go
410@oooooooooooo0000oa0@400Mooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooo
oooooa0@4004ooooo`03o`000?oooooooooo01Cooooo00Go0000ooooooooooooooooo`000003oooo
o`05oa0@4?ooooooooooooooool@41007_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41007_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@400Hooooo`So00000_ooool01Ol@413ooooooooooooooooo410@01ko
oooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@01cooooo00?oMgMgolc<
c?l000001?ooool01Ol@413ooooooooooooooooo410@00kooooo000Dooooo`03onk^k_m4A4Co0000
00Cooooo00GoMgMgoiRHV?oooooo0000ogMgM`0Jooooo`05oa0@4?nHV9SooooookZj^_l000000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?o0000ooooooooool05Oooool2o`000003oooo
oonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo1Ol00002ooooo`05o`000?nj^[[o
oooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@oiRHV?oooooo
^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07?ooool00oo^k^koA4A4o`000004oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool001Gooooo00?oMgMgo`000?ooool00oooool01Oo^
k^ko<S8bo`000?l0003ok^k^01[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool00ol0003oooooooooo`0Eooooo`05oiRHV?l0003o0000ob4Q8Oo<
c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01cooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^01kooooo00?o0000ooooooooool07oooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04?ooool3o`0000Oooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool01OnYZJWo410@o`000?l@413oZJVY
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Mooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0>ooooo`007oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool0C_ooool2o`0002kooooo3_l0001eooooo`007oooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0COooool00ol0
003oooooooooo`0Pooooo`go0000Poooool0023ooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool07?ooool4o`00093o
oooo000Pooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0aooooo`?o00006?ooool00ol0003oooooooooo`0Jooooo`;o0000U?ooool0027ooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02gooooo0ol0
0003ooooo`Oo00004Oooool00ol0003oooooooooo`0Gooooo`?o0000U_ooool001Koooooool00010
o`0001?ooooo000Fooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooo`000002o`0000?ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001?l0
00000ooooooo0000ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Ooo
ool001Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool07?ooool01Ol0003ooooooooooooooooo000002?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Dooooo`;o00002Oooool00ol0003ooooooooo
o`0=ooooo`;o00005_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0Aooooo`008oooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`2Q
ooooo`008oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0Iooooo`?o00001Oooool00ol0003oooooooooo`08oooo
o`Co0000Y?ooool002Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool07Oooool@o`000:Sooooo000Tooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool0/?ooool002Cooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`2`ooooo`009?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo0;3ooooo000Uooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0/?ooool002Go
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool09oooool2o`000;7ooooo000Uooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool0/?ooool002Gooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`2`ooooo`009_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0;3ooooo000Voooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0/?ooool002Kooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0:_ooool2o`000;7ooooo000Vooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
/?ooool002Oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`2`ooooo`009oooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0/ooooo`03o`000?oooooooooo0;3ooooo000Wooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool0/?ooool002Oooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0;Oooool2o`000;7o
oooo000Xooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0<?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0/?ooool002Sooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000
1?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool002Sooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool03Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
0;3ooooo000Yooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00kooooo00Go410@oooooooooooooooooa0@400<oooo
o`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2`oooo
o`00:Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03Cooooo0_l00007ooooo`03
o`000?oooooooooo00oooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^
00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`000;3ooooo000Yooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool0=_ooool2o`0000Gooooo00?o0000ooooooooool04?ooool01Ol0003o
oooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool0/?ooool002Wooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0hooooo`Go00004oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo000Zoooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0D?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0/?ooool002[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1@
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo
1?l00006ooooo`03o`000?oooooooooo0;3ooooo000Zooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0M?ooool2o`000;7ooooo000Zooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0M?ooool00ol0003oooooooooo`2`ooooo`00:oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0/?ooool002_ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo0;3ooooo000[ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0MOooool00ol0003oooooooooo`2`ooooo`00:ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo07Gooooo0_l0002aooooo`00:oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool0/?ooool0
02cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo
0;3ooooo000/ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0MOooool00ol0003o
ooooooooo`2`ooooo`00;?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo07Kooooo
0_l0002aooooo`00;?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo07Kooooo00?o
0000ooooooooool0/?ooool002cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1f
ooooo`03o`000?oooooooooo0;3ooooo000]ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool0M_ooool00ol0003oooooooooo`2`ooooo`00;Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo07Kooooo00?o0000ooooooooool0/?ooool002gooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`1gooooo`;o0000/Oooool002gooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo0;3ooooo000^ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`2`ooooo`00;_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo05gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?oo
ool002kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Mooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`2`ooooo`00;oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05gooooo00Go410@
oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0002`ooooo`00;oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo05kooooo00Go0000ooooooooooooooooo`00
000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool002oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`1Nooooo`05o`000?ooooooooooooooool000003?oo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool0033ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`1Nooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo000`ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0Goooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00<?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo05oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co0000
1_ooool2o`000;7ooooo000aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0N_oo
ool00ol0003oooooooooo`2`ooooo`00<Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo07_ooooo00?o0000ooooooooool0/?ooool003;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`1kooooo`03o`000?oooooooooo0;3ooooo000booooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`2`ooooo`00<_ooool2o`000003oooo
ool0003o000007kooooo0_l0002aooooo`00<oooool3o`0007oooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o
0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0
/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVY
ooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009;ooooo00Go
410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000kooooo
00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go
0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@
41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooo
oolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool00:_ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002]
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool00:gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o
0000/?ooool00:gooooo00?o0000ooooooooool0^?ooool00:gooooo00?o0000ooooooooool0^?oo
ool00:gooooo00?o0000ooooooooool0^?ooool00:_ooooo00?oEEEEofIVI_l00000^_ooool00?oo
ooooJOooool00:oooooo00?o0000okZj^_ooool0]_ooool00:oooooo0_lb<S:gooooo`00P?ooool2
o`000006oa0@4?oooooooooooa0@4?l0003o410@5oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Ioooo
o`05odA4A?l0003o0000oc8b<_oMgMd00oooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP1hooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Oooooo1_l00009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@
00Wooooo1_l0000=ooooo`03ogMgMolb<S;ooooo00Gooooo00WoMgMgoc8b<_ooooooooooogMgMonH
V9SooooooiRHV?mgMgL0N?ooool0087ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Gooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400Booooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool@4103ooooo`03
oa0@4?oooooooooo07Kooooo0021ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`00
00_ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000
ooooooooool02oooool6o`0000gooooo00?oMgMgoc8b<_ooool01Oooool01OmgMgOo<S8boooooooo
oooo000000?ooooo00?o0000ooooooooool0M_ooool0087ooooo00Ko0000omgMgOlb<S;oEEEEomgM
gOl0000Kooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00000Booooo`03
o`000?oooooooooo01_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c003ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000007Sooooo0021ooooo`06o`000?n7QhOo
ZJVYokZj^_mEEEGo00007?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@oooooooo
ool03_ooool00ol@413o0000o`000003o`0001[ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100N?ooool0087ooooo00Ko0000oc8b<_oo
oooooooooc8b<_l0000Hooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg01;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1hooooo`00P?ooool00ol@413o0000
ohN7Q`02ooooo`03ohN7Qol0003o410@01Oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Kooooo`Co00001?ooool4o`00
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1hooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(560) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .24705 m
.00488 .24972 L
.00942 .25318 L
.01441 .25813 L
.01975 .26476 L
.03065 .28241 L
.04057 .30392 L
.05147 .33596 L
.06331 .382 L
.07354 .42664 L
.07897 .44889 L
.08481 .4693 L
.08769 .47745 L
.09042 .48379 L
.09288 .48821 L
.09427 .49014 L
.09556 .49157 L
.09688 .49264 L
.09812 .4933 L
.09923 .4936 L
.10044 .49361 L
.10176 .49325 L
.10242 .49293 L
.10315 .49246 L
.10443 .49135 L
.10564 .48999 L
.1085 .48556 L
.11121 .47988 L
.11629 .46583 L
.12772 .42297 L
.14685 .34669 L
.15209 .32991 L
.15774 .31465 L
.16796 .294 L
.17324 .28627 L
.1788 .27986 L
.18354 .27562 L
.18873 .27221 L
.19162 .27086 L
.19425 .26997 L
.19571 .26962 L
.19648 .26947 L
.19729 .26935 L
.198 .26927 L
.19878 .2692 L
.20015 .26916 L
.20154 .2692 L
.2028 .26931 L
.2035 .2694 L
.20426 .26953 L
Mistroke
.20565 .26982 L
.20831 .27059 L
.21079 .27156 L
.21613 .27434 L
.22191 .27826 L
.23238 .28727 L
.25193 .31116 L
.27249 .34456 L
.28338 .36123 L
.28937 .36911 L
.29504 .37548 L
.30043 .38038 L
.30327 .38244 L
.30628 .3842 L
.30881 .38531 L
.31025 .38578 L
.3116 .38611 L
.31284 .38632 L
.31397 .38643 L
.31521 .38646 L
.31652 .3864 L
.31778 .38623 L
.31892 .386 L
.32024 .38564 L
.32148 .3852 L
.3237 .38419 L
.32609 .3828 L
.33154 .37856 L
.33655 .37362 L
.35797 .349 L
.36843 .33785 L
.37798 .32864 L
.3827 .32458 L
.38784 .32071 L
.39229 .31796 L
.3972 .31564 L
.39987 .31471 L
.40239 .31403 L
.40504 .3135 L
.40653 .31329 L
.4079 .31313 L
.4091 .31303 L
.41021 .31296 L
.41143 .3129 L
.41273 .31287 L
.4141 .31286 L
.41539 .31286 L
.41656 .31288 L
.41782 .31291 L
.41911 .31295 L
Mistroke
.42029 .313 L
.42294 .31311 L
.42774 .31338 L
.43042 .31357 L
.43334 .31382 L
.4361 .31412 L
.43866 .31447 L
.44427 .31554 L
.44935 .3169 L
.46075 .32077 L
.46587 .3224 L
.46867 .32314 L
.47128 .3237 L
.47351 .32407 L
.4759 .32436 L
.47727 .32448 L
.47855 .32456 L
.47971 .32461 L
.48097 .32464 L
.48232 .32464 L
.48359 .32463 L
.48432 .32462 L
.48498 .3246 L
.48648 .32455 L
.49233 .32428 L
.49498 .32416 L
.49745 .32407 L
.50002 .324 L
.50284 .32395 L
.50542 .3239 L
.50672 .32386 L
.50815 .32382 L
.50969 .32375 L
.51114 .32367 L
.51247 .32357 L
.5139 .32344 L
.5167 .32308 L
.51935 .3226 L
.52174 .32205 L
.52433 .32131 L
.54386 .31349 L
.54946 .31166 L
.55473 .31039 L
.56457 .30869 L
.57517 .30634 L
.58113 .30448 L
.58661 .30265 L
.59157 .30118 L
.59429 .30052 L
.59687 .30003 L
Mistroke
.59927 .2997 L
.60062 .29956 L
.60187 .29947 L
.60293 .29941 L
.60409 .29937 L
.6053 .29935 L
.60643 .29936 L
.60777 .29938 L
.60853 .29939 L
.60923 .29941 L
.61189 .29951 L
.61313 .29956 L
.61447 .2996 L
.61573 .29963 L
.61689 .29964 L
.61828 .29964 L
.61898 .29963 L
.61975 .29961 L
.62109 .29955 L
.62234 .29947 L
.6238 .29934 L
.62514 .29919 L
.62815 .29874 L
.63868 .29636 L
.64145 .29571 L
.64445 .2951 L
.64728 .29463 L
.64862 .29446 L
.64987 .29432 L
.65103 .29421 L
.65209 .29414 L
.65327 .29407 L
.65452 .29402 L
.65573 .29399 L
.65704 .29397 L
.65828 .29397 L
.65942 .29397 L
.66068 .29398 L
.66186 .29399 L
.66316 .29399 L
.66388 .29399 L
.66455 .29398 L
.66588 .29395 L
.66663 .29393 L
.66733 .2939 L
.66861 .29383 L
.66997 .29372 L
.6713 .29358 L
.6727 .2934 L
.6752 .29296 L
Mistroke
.67789 .29234 L
.68085 .2915 L
.69108 .28788 L
.69586 .28631 L
.69849 .28559 L
.70098 .28503 L
.70329 .2846 L
.70581 .28425 L
.70809 .28401 L
.71021 .28384 L
.71508 .28351 L
.71764 .28331 L
.72033 .28302 L
.7227 .28268 L
.72529 .2822 L
.72983 .28107 L
.74118 .27728 L
.74378 .27645 L
.74654 .27569 L
.74909 .2751 L
.75148 .27468 L
.75275 .27451 L
.7539 .27438 L
.75519 .27426 L
.75657 .27418 L
.75793 .27413 L
.75869 .27411 L
.7594 .2741 L
.76071 .2741 L
.76209 .27411 L
.76327 .27413 L
.76454 .27415 L
.76564 .27417 L
.76684 .27419 L
.76818 .2742 L
.76891 .2742 L
.76958 .27419 L
.7708 .27417 L
.7721 .27411 L
.77282 .27408 L
.77358 .27402 L
.77494 .27391 L
.77641 .27374 L
.77802 .27352 L
.78092 .27299 L
.78362 .27238 L
.79411 .26959 L
.79663 .26901 L
.79932 .2685 L
.80087 .26827 L
Mistroke
.80227 .2681 L
.80368 .26796 L
.80501 .26787 L
.80627 .26781 L
.8076 .26778 L
.80874 .26777 L
.80999 .26777 L
.81133 .2678 L
.81209 .26782 L
.81277 .26784 L
.81537 .26792 L
.81658 .26795 L
.81786 .26798 L
.81895 .26799 L
.82016 .26799 L
.82145 .26796 L
.82218 .26794 L
.82284 .2679 L
.82407 .26782 L
.82536 .2677 L
.82771 .2674 L
.82988 .26702 L
.83483 .26579 L
.87583 .25796 L
.89675 .25119 L
.90247 .2494 L
.90536 .24871 L
.90854 .24813 L
.91125 .24776 L
.91416 .24747 L
.91941 .24706 L
.92202 .24684 L
.9248 .24655 L
.92785 .24612 L
.93067 .24562 L
.94136 .2429 L
.94678 .24148 L
.94943 .24091 L
.95188 .24049 L
.9541 .24021 L
.95523 .24012 L
.95646 .24004 L
.95769 .24 L
.95901 .23999 L
.96026 .24001 L
.9614 .24006 L
.96255 .24013 L
.96362 .24021 L
.96607 .24047 L
.97102 .24117 L
Mistroke
.9799 .24254 L
.98486 .24326 L
.98958 .24401 L
.99218 .24453 L
.99502 .24524 L
.9976 .24608 L
1 .24705 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0S?ooool7o`0001go
oooo002Booooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`28ooooo`Co00001oooool7o`00
01Kooooo000Fooooo`03o`000?oooooooooo07Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l00023ooooo`Ko00004_ooool3
o`0001?ooooo000Gooooo`;o0000W?ooool00ol0003oooooooooo`1looooo`Ko0000;_ooool001Wo
oooo00?o0000ooooooooool0VOooool00ol0003oooooooooo`1jooooo`;o0000=?ooool001Wooooo
00?o0000ooooooooool0VOooool00ol0003oooooooooo`1gooooo`?o0000=_ooool001[ooooo00?o
0000ooooooooool0V?ooool00ol0003oooooooooo`1booooo`Go0000>Oooool001_ooooo00?o0000
ooooooooool0Uoooool2o`0006cooooo1ol0000nooooo`007?ooool00ol0003oooooooooo`2Foooo
o`03o`000?oooooooooo06Oooooo1?l00015ooooo`005Oooool2o`000005oa0@4?oooooooooooooo
ooo^k^h00_l000000olb<S;ok^k^ooooo`0Iooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo0_l0000;ooooo`Go00000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^01cooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^7_ooool0
0ol0003oooooooooo`0Oooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQ[o
oooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02Oooool<o`0000Kooooo00GoV9RHoa0@
4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Oooool2o`000009oa0@4?oo
ooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Fooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?l0003oV9RHogMgM`0Jooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo2?l00008ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`Go00004Oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0>ooooo`002oooool6o`0000;ooooo1Ol00003ooooo`05oa0@4?oooooo0000
ooooool@41004_ooool6o`0000Kooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oo
oooooooo00Sooooo00?o0000ooooooooool01_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h01?oo
ool01Ol@413ooooooooooooooooo410@01?ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@400Nooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@01_ooooo00?oV9RHob4Q8Oo^k^h00oooool;o`00
01[ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01Wooooo1Ol00003
ooooo`05oa0@4?ooooooooooooooool@41003_ooool001?ooooo00CoA4A4omgMgOoooooo00001?oo
ool00ol0003oooooooooo`02o`0001gooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooo
oooooooo000000Wooooo00?o0000ooooooooool02Oooool2o`0000Kooooo00?oV9RHob4Q8Oo^k^h0
0oooool01Ol0003ooooooooooooooooo000001kooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000001kooooo0_l0000Rooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00000Looooo`03oiRHV?l0003o000000;o000000?oooooo`000?ooool00_ooool0
0ol0003oooooooooo`0Looooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00
000Kooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`00
4oooool01?oMgMgoEEEEooooool00004ooooo`03o`000?oooooooooo00;o00007?ooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00Cooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo
000001kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001kooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
6oooool2o`000003ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03
oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00000Kooooo`04omgMgOmEEEGooooo
o`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`005?ooool00omgMgOoc<c<o`000004
ooooo`05oa0@4?ooooooooooooooool000007Oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41001oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@01kooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41004_ooool9o`0000?ooooo00Go0000
oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Oooool00_oo
ool01Ol@413ooooooooooooooooo410@01cooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooo
oooooooooooo410@00kooooo000Dooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?oooooo
V9RHo`00000Jooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Kooooo00?o0000ooooooooool04?ooool01ol0003oooooo`000?nj^[[ooooooiRHV?l@4100
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool4o`0000Sooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool01Ol@413oV9RHoooooonj^[[o000000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0>ooooo`005Oooool00omgMgOo0000ooooo`03ooooo`06onk^k_lb<S;o0000
oc8b<_o^k^ko00006Oooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`03o`000?oooooooooo017ooooo00Oo0000oooooonHV9So410@o`000?lQ8B7o
c<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Looooo`03oeEEEOmVIVKo000000Cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0Nooooo`03o`000?oooooooooo01oooooo00?oEEEEofIVI_l00000
1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo0_l0000<ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00GoZJVYoa0@4?l0003o410@ojVY
Z@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Oooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03_ooool0023ooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo057ooooo0_l0000]ooooo`_o0000NOooool0027ooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo053ooooo00?o
0000ooooooooool0:?ooool5o`0008?ooooo000Rooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo01_ooooo3Ol00028
ooooo`008_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool0Coooool00ol0003oooooooooo`0Hooooo`?o0000UOooool002?ooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04kooooo00?o0000oooooooo
ool04oooool5o`0009Sooooo000Foooooooo0000@?l0000Cooooo`005_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooo`000006o`0000Oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool4o`0000Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017o
oooo000Fooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo01[ooooo0_l0000Vooooo`03o`000?oooooooooo00Cooooo
1?l00006ooooo`Oo00004?ooool00ol0003oooooooooo`0:ooooo`;o00006Oooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0Aooooo`009?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool0:?ooool2o`00017ooooo0ol0000=ooooo`03o`000?oooooooooo00Oooooo0ol0
002Vooooo`009?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0Dooooo`?o00002_ooool00ol0003oooooooooo`03
ooooo`Co0000ZOooool002Gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo02Cooooo0_l0000Joooooa3o0000[Oooool002Gooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`2`ooooo`009Oooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo0;3ooooo000Vooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0/?oo
ool002Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`2`ooooo`009_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0Wooooo`;o0000/Oooool002Kooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`2`ooooo`009oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0;3ooooo
000Wooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0/?ooool002Oooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool0:_ooool00ol0003oooooooooo`2`ooooo`00:?ooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0[oooo
o`;o0000/Oooool002Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`2`ooooo`00
:?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo0;3ooooo000Xooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool0/?ooool002Wooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`2`ooooo`00:Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0`ooooo`;o0000/Oooool002Wo
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Wo
oooo0_l0000cooooo`03o`000?oooooooooo0;3ooooo000Zooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo013ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo000Zooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo013o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00:_ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo03;ooooo0ol00003ooooo`?o00004oooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo0;3ooooo000Zooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0=?ooool5o`0001Gooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`000;3ooooo000[ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0C_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMg
ofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?oo
ool002_ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1?ooooo`05oa0@4?oooooo
ooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0/?ooool002_ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1?
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00:oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo04oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool002_ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`1booooo`;o0000/Oooool002cooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo0;3ooooo000/
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`2`
ooooo`00;?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo07?ooooo00?o0000oooo
ooooool0/?ooool002cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1cooooo`03
o`000?oooooooooo0;3ooooo000/ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
M?ooool2o`000;7ooooo000]ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0M?oo
ool00ol0003oooooooooo`2`ooooo`00;Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo07Cooooo00?o0000ooooooooool0/?ooool002gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`1dooooo`03o`000?oooooooooo0;3ooooo000]ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0MOooool2o`000;7ooooo000]ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0MOooool00ol0003oooooooooo`2`ooooo`00;_ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool0/?ooool002kooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo0;3ooooo000^oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool0MOooool00ol0003oooooooooo`2`oooo
o`00;oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo07Kooooo0_l0002aooooo`00
;oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool0
/?ooool002oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1fooooo`03o`000?oo
oooooooo0;3ooooo000`ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1Oooool00ol0003oooooooooo`2`ooooo`00<?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo05_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo0;3ooooo000`ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0G?ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool0
0oooool3o`000;3ooooo000aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0G?oo
ool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05cooooo00Go
0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003o
ooooooooo`2`ooooo`00<Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05gooooo
00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0/?ooool003;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Mooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3o
oooo000booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0GOooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000/Oooool003;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo0;3ooooo000booooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`2`ooooo`00<oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0/?ooool0
03Cooooo00Co0000oooooooooooo0000OOooool00ol0003oooooooooo`2`ooooo`00=Oooool3o`00
07gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool009;ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@
00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
0;3ooooo002Booooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06oooo
o`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00T_ooool01Ol0003ooooooooooooooooo0000
00kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000
ooooooooool0/?ooool009;ooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOo
oooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002a
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Zoooool4o`000003
oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool00:gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo0ol0002`ooooo`00[Oooool00ol0
003oooooooooo`2hooooo`00[Oooool00ol0003oooooooooo`2hooooo`00[Oooool00ol0003ooooo
ooooo`2hooooo`00Zoooool00omEEEGoIVIVo`00002jooooo`00oooooomYooooo`00[oooool00ol0
003o^[Zjooooo`2fooooo`00[oooool2oc8b<[Oooooo0020ooooo`;o000000Ko410@oooooooooooo
410@o`000?l@410Gooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?oQhN7
o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Wooooo00GoA4A4o`000?l0003o<S8b
omgMg@02ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
07Sooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`0000Wo
oooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0
0oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000gooooo00Wo
MgMgoc8b<_oooooooooooeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonHV9So
MgMg07Sooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05oooool00onH
V9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41004_ooool00ol0003oooooooooo`0O
ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@
4?oooooooooo07Kooooo0021ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000_o
oooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000oooo
ooooool02oooool6o`0000gooooo00WoMgMgoc8b<_ooooooooooo`000?nHV9SooooooiRHV?lQ8B40
0oooool01Ol0003ooooooooooooooooo000007Sooooo0021ooooo`06o`000?oMgMgo<S8boeEEEOoM
gMgo00006oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000004_ooool0
0ol0003oooooooooo`0Kooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003oEEEEo`00
0?l@413oc<c<00?ooooo00Go0000ooooooooooooooooo`00001hooooo`00POooool01_l0003oQhN7
ojVYZOnj^[[oEEEEo`0001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooo
oooo00kooooo00?o410@o`000?l000000ol0000Jooooo`03o`000?oooooooooo00Cooooo00?oEEEE
ohN7Qoooool01Oooool01Ol@413ooooooooooooooooo410@07Sooooo0021ooooo`06o`000?lb<S;o
oooooooooolb<S;o00006?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0Booooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01?ooool00ooM
gMgo410@oiRHV005ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0N?ooool0083ooooo00?o410@o`00
0?n7QhL00_ooool00on7QhOo0000oa0@400Gooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo00?o0000ooooooooool06oooool4o`0000Cooooo00Co
c<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07Sooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(570) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .24399 m
.00942 .25106 L
.01975 .26158 L
.03053 .27609 L
.04057 .29518 L
.04632 .30957 L
.05176 .32575 L
.06194 .36209 L
.07304 .40685 L
.08481 .45144 L
.08962 .46614 L
.09227 .47288 L
.09479 .47825 L
.09621 .48078 L
.09775 .48312 L
.09917 .48486 L
.10046 .4861 L
.1018 .48702 L
.10253 .48737 L
.10322 .4876 L
.10445 .48776 L
.10578 .48758 L
.10699 .48709 L
.10812 .48636 L
.10936 .48525 L
.11068 .4837 L
.11339 .47947 L
.11587 .4744 L
.12063 .46174 L
.12514 .44693 L
.14427 .37445 L
.15516 .34004 L
.16539 .3159 L
.17538 .29902 L
.181 .29219 L
.18367 .28962 L
.18615 .28762 L
.18884 .28588 L
.19128 .28468 L
.19268 .28415 L
.194 .28374 L
.19539 .28343 L
.19617 .28329 L
.1969 .2832 L
.19825 .28309 L
.19951 .28308 L
.2009 .28314 L
.20168 .28322 L
.20239 .28331 L
.20382 .28355 L
Mistroke
.20538 .28391 L
.20821 .28477 L
.21381 .28716 L
.21907 .29007 L
.22891 .29707 L
.2395 .30735 L
.25094 .32186 L
.27151 .35024 L
.2824 .36273 L
.28839 .36847 L
.29405 .37302 L
.29944 .37635 L
.30248 .37773 L
.30394 .37824 L
.3053 .37862 L
.30643 .37888 L
.30766 .37908 L
.30902 .37922 L
.31027 .37926 L
.31149 .37922 L
.31283 .37909 L
.31351 .37899 L
.31424 .37885 L
.31554 .37854 L
.31813 .37768 L
.32094 .37639 L
.32604 .37326 L
.33557 .36555 L
.35607 .34736 L
.36693 .33822 L
.37292 .33352 L
.37859 .32955 L
.38395 .32644 L
.38678 .3251 L
.38979 .32391 L
.39231 .32311 L
.39509 .32241 L
.39762 .32192 L
.4 .32158 L
.40245 .32132 L
.40368 .32123 L
.40502 .32114 L
.40618 .32107 L
.40741 .32102 L
.40963 .32094 L
.41097 .32091 L
.41243 .32088 L
.41371 .32086 L
.41507 .32084 L
.41629 .32083 L
Mistroke
.41764 .32082 L
.41887 .32082 L
.42002 .32082 L
.42133 .32083 L
.42206 .32084 L
.42272 .32085 L
.42402 .32087 L
.42523 .32091 L
.42666 .32096 L
.42797 .32103 L
.43093 .32123 L
.43333 .32147 L
.43597 .3218 L
.44129 .32269 L
.44608 .32366 L
.45128 .32472 L
.45367 .32516 L
.4562 .32556 L
.45836 .32583 L
.45952 .32595 L
.46075 .32605 L
.46141 .32609 L
.46214 .32613 L
.46341 .32619 L
.46413 .3262 L
.4649 .32621 L
.46628 .32621 L
.46695 .32619 L
.46768 .32617 L
.469 .32611 L
.47029 .32603 L
.47147 .32595 L
.47622 .32548 L
.48125 .32489 L
.49184 .32378 L
.49768 .32322 L
.50055 .32289 L
.50321 .32251 L
.50836 .32153 L
.51396 .32004 L
.52378 .31662 L
.54302 .31144 L
.55265 .31027 L
.55791 .30953 L
.56281 .3086 L
.56812 .30732 L
.57395 .30578 L
.57921 .30452 L
.58179 .30402 L
.58418 .30364 L
Mistroke
.58691 .30332 L
.58835 .3032 L
.58909 .30315 L
.58988 .30311 L
.59115 .30305 L
.59235 .30302 L
.59308 .303 L
.59377 .303 L
.59507 .30299 L
.5958 .30299 L
.59646 .30299 L
.59723 .303 L
.59796 .303 L
.59924 .30301 L
.59997 .30301 L
.60064 .303 L
.60137 .303 L
.60205 .30299 L
.60279 .30298 L
.60359 .30296 L
.60443 .30293 L
.60523 .30289 L
.60672 .3028 L
.60793 .30269 L
.60927 .30255 L
.61199 .30217 L
.61451 .30169 L
.61687 .30115 L
.62792 .29801 L
.63326 .29664 L
.63586 .29611 L
.63823 .29571 L
.64074 .29539 L
.64342 .29512 L
.6491 .29472 L
.65142 .29455 L
.65389 .29431 L
.65659 .29397 L
.65909 .29354 L
.66358 .29248 L
.66852 .29088 L
.67899 .28688 L
.68415 .28521 L
.68666 .28458 L
.68893 .28412 L
.69159 .28372 L
.69305 .28356 L
.69442 .28343 L
.69729 .28325 L
.69891 .28317 L
Mistroke
.70039 .28311 L
.70303 .283 L
.70549 .28285 L
.70673 .28275 L
.70805 .28262 L
.71087 .28226 L
.75434 .27529 L
.79622 .26801 L
.83651 .25898 L
.87937 .24914 L
.88437 .24709 L
.88962 .24532 L
.89238 .24462 L
.89383 .24431 L
.89539 .24404 L
.89682 .24383 L
.89812 .24367 L
.90067 .24344 L
.92064 .24129 L
.9299 .23872 L
.93496 .23734 L
.93743 .23678 L
.93969 .23637 L
.94087 .2362 L
.94216 .23605 L
.94352 .23593 L
.94481 .23586 L
.94548 .23583 L
.94622 .23582 L
.947 .23581 L
.94773 .23582 L
.94903 .23586 L
.94976 .2359 L
.95043 .23594 L
.95273 .23613 L
.95525 .23641 L
.96032 .23707 L
1 .24399 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo08Oooooo3?l0000Mooooo`00T_ooool01Ol@413ooooooooooooooooo410@00oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo08Go
oooo0_l0000<ooooo`Oo00005_ooool001Kooooo00?o0000ooooooooool0NOooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0Noooool:o`0001Gooooo0ol0000Cooooo`005oooool00ol0003o
ooooooooo`1hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7o
c<c<00Cooooo1?l00006ooooo`;o0000N?ooool4o`0003Gooooo000Hooooo`03o`000?oooooooooo
09[ooooo00?o0000ooooooooool0M?ooool3o`0003Wooooo000Iooooo`03o`000?oooooooooo09Wo
oooo00?o0000ooooooooool0Koooool5o`0003cooooo000Jooooo`03o`000?oooooooooo09Sooooo
00?o0000ooooooooool0J_ooool5o`00047ooooo000Kooooo`03o`000?oooooooooo09Oooooo00?o
0000ooooooooool0I_ooool4o`0004Kooooo000Looooo`03o`000?oooooooooo09Kooooo0_l0001R
ooooo`Go0000B_ooool001cooooo00?o0000ooooooooool0U_ooool00ol0003oooooooooo`1Moooo
o`Co0000Coooool001Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^
kP0Jooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hNooooo`03o`000?oooooooooo01oooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^6_ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP06ooooo`Go00004?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0Mooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h03_oo
ool001Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHooooool0003oMgMg01[ooooo00Go
410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool01OnHV9So
8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A003ooooo`04ogMgMonHV9SooooooiRHV0Oo00005Oooool01Ol@413o^[ZjoooooomgMgOo
<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0>ooooo`002oooool6o`0000;ooooo1Ol00003ooooo`05oa0@4?oo
ooooooooo`000?l@41004_ooool6o`0000Kooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo017ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooo
oooooooooa0@400Cooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41007_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Kooooo`03oiRHV?lQ8B7ok^k^00?ooooo1Ol000000ol@413ooooooooo
o`0Mooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Iooooo`Go0000
0oooool01Ol@413ooooooooooooooooo410@00kooooo000Cooooo`04odA4A?oMgMgoooooo`0000Co
oooo00Go0000ooooooooooooooooo`00000Mooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oooo
ooooooooooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00
000Nooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Nooooo`;o0000
8_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007?ooool5o`000003
ooooool0003ooooo00;ooooo00?o0000ooooooooool07?ooool00onYZJWo410@ooooo`02ooooo`05
o`000?ooooooooooooooool000006oooool01?m4A4CogMgMooooool00004ooooo`05o`000?oooooo
ooooooooool000003_ooool001?ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooo
oooooooo000001cooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000001ko
oooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000001kooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000001kooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000005oooool5o`000003oooooomg
MgOoIVIV00?ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oa0@4?l0003o^[Zj00?ooooo
00Go0000ooooooooooooooooo`00000Kooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000oooo
ooooooooooooo`00000>ooooo`005?ooool00omgMgOoc<c<o`000004ooooo`06oa0@4?oooooooooo
ooooool@413o00007?ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool7o`0000cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01co
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01kooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41003Oooool:
o`0000Oooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o
^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@01cooooo00?oMgMgolc<c?l00000
1?ooool01Ol@413ooooooooooooooooo410@00kooooo000Dooooo`03onk^k_m4A4Co000000Cooooo
00OoMgMgoiRHV?ooooooV9RHogMgMooooooo000001Sooooo00Go410@oiRHV?oooooo^[Zjo`000003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02_ooool2o`0000Oooooo00?o0000ooooooooool01Ooo
ool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo1?l0000<
ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo
00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07?ooool00oo^
k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool001Gooooo00?oMgMgo`00
0?ooool00oooool01oo^k^ko<S8bo`000?lb<S;ok^k^ooooool000006?ooool01OnYZJWo410@o`00
0?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP09ooooo`03o`000?oooooooooo00So
oooo0_l00005ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01kooooo00?o
0000ooooooooool07oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1oooool3o`00013ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h06oooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0Mooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`008_oo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00_ooooo0_l0001Fooooo`;o0000;ooo
ool4o`0007kooooo000Sooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`1Cooooo`03o`000?oooooooooo02Oooooo1ol00022ooooo`008oooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0Doooool00ol0
003oooooooooo`0Tooooo`?o0000ROooool002?ooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool06?ooool<o`0008co
oooo000Tooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`1Aooooo`03o`000?oooooooooo01Cooooo1?l0002Hooooo`005_ooooooo`00043o00004ooo
ool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
000000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00Co0000oooooooooooooooo1_l00006ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`005_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0G
ooooo`;o00009oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Kooooo0ol0000L
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo017ooooo000Uooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo00?ooooo0ol0002Zoooo
o`009Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0:_oooolAo`00017ooooo1_l0002]ooooo`009_ooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool0:?ooool3o`00013ooooo1Ol00004ooooo`[o0000
/Oooool002Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo02Gooooo0_l0000Gooooo`Go00002?ooool00ol0003oooooooooo`2`ooooo`009_ooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool08_ooool2
o`0002Kooooo00?o0000ooooooooool0/?ooool002Oooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`2`ooooo`009oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool07_ooool2o`0002Wooooo00?o0000ooooooooool0/?ooool002Oooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool0:Oooool2o`000;7ooooo000Wooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool0/?ooool002Sooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`2`
ooooo`00:?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo0;3ooooo000Xooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool0/?ooool002Sooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
;_ooool2o`000;7ooooo000Yooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0/?oo
ool002Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`2`ooooo`00:Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool03?ooool2o`00
03?ooooo00?o0000ooooooooool0/?ooool002Wooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`2`ooooo`00:_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02_ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0dooooo`;o0000/Oooool002[ooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0/ooooo`;o00002?ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo0;3ooooo000Zooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool0;_ooool8o`0001Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo
000[ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Boooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo000[ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool0C?ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^
k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo000[ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool0C?ooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool002_ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`1<ooooo`05o`000?ooooooooooooooool0
00003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0
003oooooooooo`2`ooooo`00;?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04co
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`2`ooooo`00;?ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo04gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo000/oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0COooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003ooooooooo
o`2`ooooo`00;Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo073ooooo0_l0002a
ooooo`00;Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo073ooooo00?o0000oooo
ooooool0/?ooool002gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1aooooo`03
o`000?oooooooooo0;3ooooo000]ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
LOooool00ol0003oooooooooo`2`ooooo`00;_ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo077ooooo00?o0000ooooooooool0/?ooool002kooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`1booooo`;o0000/Oooool002kooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`1booooo`03o`000?oooooooooo0;3ooooo000_ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`2`ooooo`00;oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0/?ooool002oooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`1cooooo`;o0000/Oooool002oooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo0;3ooooo000`oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`2`oooo
o`00<?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo07?ooooo00?o0000oooooooo
ool0/?ooool0033ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1dooooo`03o`00
0?oooooooooo0;3ooooo000aooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0M?oo
ool2o`000;7ooooo000aooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0M?ooool0
0ol0003oooooooooo`2`ooooo`00<Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
07Gooooo00?o0000ooooooooool0/?ooool0037ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`1Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo000booooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0F_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool003;ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`1Kooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`03ooooo`?o0000/?ooool003;ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`1Kooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo0;3ooooo000booooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0Foooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo0;3ooooo000cooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0G?ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`2`ooooo`00<oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo05cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0/?ooool003Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1M
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0002aooooo`00=?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0/?ooool0
03Gooooo00Go0000ooooooooooooooooo`00001kooooo`03o`000?oooooooooo0;3ooooo000foooo
o`?o0000O?ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@4100
3Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
/?ooool009;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo
00?oMgMgoc8b<_ooool01?ooool3o`000;3ooooo002Booooo`05o`000?ooooooooooooooool00000
3_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003o
ooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMooo
ool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002[ooooo`Co000000?o
410@ooooooooool00oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0/?ooool00:gooooo00?o0000ooooooooool01Oooool3o`000;3ooooo002]ooooo`03o`00
0?oooooooooo0;Sooooo002]ooooo`03o`000?oooooooooo0;Sooooo002]ooooo`03o`000?oooooo
oooo0;Sooooo002[ooooo`03oeEEEOmVIVKo00000;[ooooo003oooooofWooooo002_ooooo`03o`00
0?nj^[[ooooo0;Kooooo002_ooooo`;o<S8b]oooool0083ooooo0_l000001_l@413oooooooooool@
413o0000oa0@41Oooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOo
0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06Oooool01Om4A4Co0000o`000?lb<S;o
gMgM00Cooooo00?o0000onk^k_ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07Sooooo0021
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`0000Wooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool00oo<c<co0000
oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000gooooo00?oMgMgoc8b<_oo
ool00oooool00omEEEGoZJVYooooo`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0N?ooool0087o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^00Co
oooo00Go410@oooooooooooooooooa0@400Booooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool00_ooool00onYZJWoEEEEooooo`03ooooo`05oa0@4?ooooooooooooooool@4100N?ooool0
087ooooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00002oooool00onHV9So8B4Qonk^
kP03ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0;ooooo`Ko0000
3Oooool00omgMgOo<S8booooo`04ooooo`03ob4Q8Ooooooooooo00;ooooo00Go0000oooooooooooo
ooooo`00001hooooo`00POooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001_ooooo00?oMgMgofIV
I_ooool00_ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool06oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?oEEEEolc<c?ooool00_ooool01Ol0003ooooooooo
oooooooo000007Sooooo0021ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo00007?ooool01Ol0003o
oooooooooooooooo410@00?ooooo00?o410@ooooooooool03_ooool00ol@413o0000o`000003o`00
01[ooooo00?o0000ooooooooool01oooool00onYZJWoMgMgooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100N?ooool0087ooooo00Ko0000oc8b<_oooooooooooc8b<_l0000Hooooo`05o`000?nj
^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`04ooooo`05oa0@4?oooooooooooooooolb<S800oooool01Omg
MgOoV9RHoooooonHV9SoMgMg07Sooooo0020ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`00
0?l@41005oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0Booooo`03o`000?oooooooooo01_ooooo1?l00003ooooo`Go00000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^07Sooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(580) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .24574 m
.00942 .25209 L
.01975 .26019 L
.02496 .26552 L
.03053 .27277 L
.04057 .29087 L
.05248 .32071 L
.06373 .3557 L
.07396 .39167 L
.08481 .43077 L
.08962 .44655 L
.09479 .46102 L
.09775 .4677 L
.10046 .47258 L
.10177 .47447 L
.10319 .47617 L
.10453 .47743 L
.10578 .47829 L
.107 .47883 L
.10831 .4791 L
.10955 .47903 L
.1107 .47871 L
.11173 .47819 L
.11286 .4774 L
.11405 .47631 L
.11515 .47507 L
.11768 .47143 L
.11997 .46722 L
.12514 .45511 L
.14688 .38647 L
.15643 .35809 L
.16698 .33235 L
.17182 .32291 L
.17705 .31458 L
.18198 .30849 L
.1865 .3044 L
.18899 .3027 L
.19132 .30146 L
.19387 .30043 L
.1953 .3 L
.19659 .29969 L
.19796 .29945 L
.19922 .29929 L
.2006 .29919 L
.2013 .29917 L
.20206 .29916 L
.20335 .29919 L
.20473 .29928 L
.20604 .29942 L
.20723 .29959 L
Mistroke
.20986 .30011 L
.21225 .30074 L
.21759 .30269 L
.22254 .3052 L
.2272 .30823 L
.23767 .31738 L
.24898 .32984 L
.26954 .35204 L
.28043 .36159 L
.28642 .36595 L
.28936 .36778 L
.29208 .36924 L
.29465 .3704 L
.29747 .37139 L
.29894 .37178 L
.30032 .37207 L
.30102 .37218 L
.30177 .37228 L
.30258 .37237 L
.30333 .37242 L
.30456 .37245 L
.30587 .37242 L
.3071 .37232 L
.30822 .37218 L
.30954 .37195 L
.31097 .37163 L
.31357 .37086 L
.31864 .36877 L
.324 .36593 L
.3336 .36006 L
.35443 .34653 L
.36353 .34062 L
.37344 .33516 L
.37889 .33294 L
.38129 .33217 L
.38394 .33146 L
.38877 .33048 L
.39141 .3301 L
.3939 .3298 L
.40446 .32887 L
.41036 .3284 L
.41323 .32819 L
.41585 .32802 L
.41704 .32795 L
.41834 .32789 L
.41946 .32784 L
.4207 .3278 L
.42201 .32777 L
.42339 .32775 L
.42468 .32775 L
Mistroke
.42588 .32776 L
.42656 .32777 L
.4273 .32779 L
.42865 .32783 L
.42996 .32788 L
.43118 .32794 L
.43687 .32827 L
.43976 .32844 L
.44118 .32851 L
.44249 .32856 L
.44368 .3286 L
.44494 .32862 L
.4462 .32862 L
.44759 .32861 L
.44835 .32859 L
.44908 .32857 L
.45044 .3285 L
.45191 .3284 L
.4535 .32826 L
.45636 .32793 L
.45901 .32753 L
.50026 .32072 L
.53992 .31288 L
.58216 .30613 L
.6228 .29714 L
.64344 .29355 L
.65514 .29072 L
.66602 .28703 L
.67144 .28544 L
.67411 .28483 L
.67657 .28438 L
.6788 .28406 L
.68116 .28382 L
.68239 .28372 L
.68354 .28365 L
.68615 .28352 L
.68869 .28343 L
.69004 .28338 L
.69147 .28332 L
.69284 .28325 L
.69409 .28317 L
.69651 .28296 L
.69795 .2828 L
.69951 .2826 L
.70233 .28213 L
.70764 .28094 L
.71289 .27953 L
.71851 .27809 L
.72123 .27751 L
.72381 .27708 L
Mistroke
.72612 .27679 L
.72743 .27667 L
.72863 .27659 L
.72989 .27652 L
.73107 .27649 L
.73237 .27647 L
.7331 .27646 L
.73376 .27646 L
.73509 .27648 L
.73585 .27649 L
.73655 .2765 L
.73782 .27652 L
.7392 .27655 L
.73999 .27655 L
.74071 .27656 L
.7414 .27656 L
.74214 .27655 L
.74341 .27653 L
.74413 .2765 L
.7448 .27647 L
.74557 .27643 L
.74631 .27638 L
.74768 .27625 L
.74916 .27607 L
.75077 .27583 L
.76056 .2732 L
.77112 .2696 L
.77406 .2688 L
.77716 .26812 L
.77981 .26768 L
.7827 .26734 L
.78543 .26711 L
.78834 .26692 L
.79088 .26674 L
.79358 .26649 L
.7949 .26634 L
.79635 .26613 L
.79891 .26566 L
.80189 .26492 L
.80469 .26404 L
.81517 .25947 L
.8348 .25297 L
.83966 .25243 L
.84424 .25198 L
.84677 .25165 L
.84951 .25118 L
.852 .25062 L
.85429 .24998 L
.85966 .24807 L
.86532 .24561 L
Mistroke
.87026 .24346 L
.87555 .24155 L
.87842 .24078 L
.88103 .24026 L
.88229 .24008 L
.88366 .23992 L
.88495 .23981 L
.88615 .23973 L
.88753 .23968 L
.88883 .23965 L
.88957 .23964 L
.89025 .23964 L
.891 .23964 L
.89179 .23964 L
.89317 .23965 L
.89395 .23965 L
.89465 .23965 L
.89548 .23965 L
.89627 .23964 L
.89699 .23963 L
.89777 .23961 L
.89909 .23955 L
.90032 .23948 L
.90166 .23937 L
.90311 .23921 L
.90606 .23875 L
.90876 .23818 L
.91888 .2353 L
.92391 .234 L
.92645 .23351 L
.9279 .2333 L
.92926 .23316 L
.93044 .23307 L
.93167 .23302 L
.93273 .23301 L
.93389 .23303 L
.93514 .23308 L
.93647 .23318 L
.93773 .23331 L
.93888 .23345 L
.94438 .23432 L
.94739 .23484 L
.95021 .23527 L
.95261 .23557 L
.95396 .23569 L
.95519 .23579 L
.95653 .23586 L
.95729 .23589 L
.958 .2359 L
.95929 .23592 L
Mistroke
.96067 .23591 L
.96194 .23588 L
.96312 .23584 L
.96576 .23572 L
.96805 .23562 L
.96935 .23557 L
.97056 .23554 L
.97166 .23553 L
.97267 .23554 L
.97383 .23557 L
.97492 .23563 L
.97607 .23572 L
.97713 .23583 L
.97829 .23599 L
.97953 .2362 L
.98195 .23675 L
.98455 .23755 L
.98926 .23951 L
1 .24574 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000Poooool8o`0002Gooooo002Booooo`05o`000?oo
ooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`21ooooo`;o00002?ooool>o`0001Oooooo002Booooo`05oa0@
4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0MOooool<o`0001Sooooo0_l0000Eooooo`00T_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0L_ooool3o`0002Kooooo00?o0000ooooooooool04_ooool001Ko
oooo0_l0001jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7o
c<c<00Cooooo1?l00006ooooo`;o0000LOooool2o`0002[ooooo00?o0000ooooooooool04Oooool0
01Sooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`1^ooooo`;o0000@?ooool001Wo
oooo00?o0000ooooooooool0VOooool00ol0003oooooooooo`1Vooooo`So0000@_ooool001[ooooo
00?o0000ooooooooool0V?ooool00ol0003oooooooooo`1Sooooo`?o0000B_ooool001_ooooo00?o
0000ooooooooool0Uoooool00ol0003oooooooooo`1Pooooo`?o0000COooool001cooooo0_l0002G
ooooo`;o0000H?ooool00ol0003oooooooooo`1>ooooo`007_ooool00ol0003oooooooooo`2Doooo
o`03o`000?oooooooooo05_ooooo1?l0001Aooooo`005Oooool2o`000006oa0@4?oooooooooooooo
ooo^k^ko<S8b0_l000000oo^k^koooooooooo`0Hooooo`05oiRHV?l@413o0000oc8b<_o<c<`00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h07?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hNooooo`03o`000?oo
oooooooo01oooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^6_ooool5o`00
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`So00004Oooool01OnHV9So410@o`000?lb
<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Mooooo`;o000000Wo410@oooooooooooo
ooooonk^k_lb<S;o0000oc8b<_o^k^h03_ooool001Kooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9So000001[ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL06oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0N
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg01[ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00_l0000Iooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9So
MgMg01kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;
ooooo`Ko00000_ooool5o`0000?ooooo00Go410@ooooooooooooooooo`00000Booooo`Ko00001_oo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool04Oooool6o`0000?ooooo
00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01?ooooo1_l00005ooooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Nooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01_ooooo00?oV9RH
ob4Q8Oo^k^h01?ooool00ol@413oooooo`000002o`0001oooooo00Go0000oooooooooooooooooa0@
4003ooooo`03oa0@4?oooooooooo01Wooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@4100
3_ooool001?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000001go
oooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000001gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo000001kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000001kooooo0_l0000Rooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`00000Gooooo`go00000_ooool00ol0003oooooooooo`0Looooo`03ojVY
ZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Kooooo`04odA4A?oMgMgoooooo`00
00Cooooo00Go0000ooooooooooooooooo`00000>ooooo`004oooool01?oMgMgoEEEEooooool00004
ooooo`04o`000?ooooooooooooooo`;o00006oooool00ol@413o0000okZj^P03ooooo`05o`000?oo
ooooooooooooool000007_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool0
00007_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007_ooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000C
ooooo`Co00001_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Ooo
ool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000006oooool01?oMgMgoEEEE
ooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool001Cooooo00?oMgMgolc<c?l0
00001?ooool01ol@413ooooooooooooooooo410@ooooool000006oooool00onj^[[o8B4Qooooo`02
ooooo`05oa0@4?ooooooooooooooool@41007oooool01Ol0003ooooooooooooooooo410@00?ooooo
00?o410@ooooooooool07?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41007_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooo
oooooooooa0@4009ooooo`[o00002oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@
ooooooooool07?ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41007?oo
ool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41003_ooool001Cooooo00?o
k^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo00?o0000ooooooooool0
5Oooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Koooo
o`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool4o`00017o
oooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool0
1Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`03onk^
k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`005Oooool00omgMgOo0000
ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00ol0003oooooooooo`0Dooooo`05
ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07_ooool00ol0003oooooooooo`0Oooooo`03
oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`?o00005Oooool01OnH
V9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@
413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo00?oMgMgo`000?oo
ool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Sooooo`03o`000?oooooooooo08oo
oooo0_l0000Yooooo`Go0000Poooool002?ooooo00?o0000ooooooooool0Soooool00ol0003ooooo
ooooo`0Rooooo`Ko0000R?ooool002Cooooo00?o0000ooooooooool0;?ooool8o`0005[ooooo00?o
0000ooooooooool07Oooool5o`0008kooooo000Tooooo`03o`000?oooooooooo02_ooooo0_l00007
ooooo`;o0000F?ooool00ol0003oooooooooo`0Iooooo`Co0000Toooool002Cooooo00?o0000oooo
ooooool0:_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05Gooooo00?o0000oooo
ooooool05?ooool5o`0009Oooooo000Foooooooo0000@?l0000Cooooo`005_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko0000
1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
4Oooool001Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`03ooooo`Go00007Ooo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0Aooooo`009_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0DOooool00ol0003oooooo`000003o`000:gooooo000Voooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1=oooo
o`Go0000/Oooool002Kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo04Gooooo1ol00003ooooo`;o0000/Oooool002Oooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02kooooo5_l0000:ooooo`03o`00
0?oooooooooo0;3ooooo000Wooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0Xooooo`Go00008?ooool00ol0003oooooooooo`2`ooooo`009oooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool08oooool4
o`0002Gooooo00?o0000ooooooooool0/?ooool002Sooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo023ooooo0_l0000Yooooo`03o`000?oooooooooo
0;3ooooo000Xooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo02Wooooo0_l0002aooooo`00:?ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo0;3ooooo000Yooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0Iooooo`;o0000;Oooool00ol0003ooooooooo
o`2`ooooo`00:Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool05_ooool2o`0002oooooo00?o0000ooooooooool0/?ooool002Wooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`2`ooooo`00:_ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool04Oooool2o`0003;ooooo0_l0002aooooo`00
:_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
3_ooool2o`0003Cooooo00?o0000ooooooooool0/?ooool002[ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Uooooo`;o00003Oooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo0;3ooooo000[ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`08ooooo`;o0000=oooool00ol0003oooooooooo`2`ooooo`00:oooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo02Wooooo0_l00007ooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool0/?ooool002_ooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0Zooooo`So0000>_ooool2o`000;7ooooo000/ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool0KOooool00ol0003oooooooooo`2`ooooo`00;?ooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo04[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3o
oooo000/ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0B_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo000/ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool0Boooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q
8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo000]ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0Boooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool002go
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1;ooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00;Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
04_ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00;Oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo04cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo000^
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0C?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003ooooo
ooooo`2`ooooo`00;_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo06oooooo0_l0
002aooooo`00;_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo073ooooo00?o0000
ooooooooool0/?ooool002oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1`oooo
o`03o`000?oooooooooo0;3ooooo000_ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0L?ooool00ol0003oooooooooo`2`ooooo`00;oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo073ooooo00?o0000ooooooooool0/?ooool0033ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`1aooooo`;o0000/Oooool0033ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`1aooooo`03o`000?oooooooooo0;3ooooo000`ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`2`ooooo`00<Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0/?ooool0037ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`1booooo`;o0000/Oooool0037ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo0;3ooooo000a
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`2`
ooooo`00<_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo07?ooooo00?o0000oooo
ooooool0/?ooool003;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1cooooo`03
o`000?oooooooooo0;3ooooo000booooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
Loooool2o`000;7ooooo000booooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Looo
ool00ol0003oooooooooo`2`ooooo`00<oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo07Cooooo00?o0000ooooooooool0/?ooool003?ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`1Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo000cooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0FOooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool003Cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`1Jooooo`05oa0@4?ooooooooooooooool@41004?oo
ool00ol0003oooooooooo`03ooooo`?o0000/?ooool003Cooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`1Jooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo0;3ooooo000eooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0Foooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`03o`000?oooooooooo0;3ooooo000fooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0G?ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`2`ooooo`00=_ooool2o`0000;ooooo00?o0000ooooooooool0GOoo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`2`ooooo`00=oooool4o`0005oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co0000
1_ooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002B
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009;ooooo00Go410@oooooooooooooooo
oa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool0
1_ooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWo
MgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00:_ooooo1?l0
00000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002]ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0/?ooool00:gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo
00?o0000ooooooooool0^?ooool00:gooooo00?o0000ooooooooool0^?ooool00:gooooo00?o0000
ooooooooool0^?ooool00:_ooooo00?oEEEEofIVI_l00000^_ooool00?ooooooJOooool00:oooooo
00?o0000okZj^_ooool0]_ooool00:oooooo0_lb<S:gooooo`00P?ooool2o`000006oa0@4?oooooo
oooooa0@4?l0003o410@5oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`03
ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Iooooo`05odA4A?l0003o0000
oc8b<_oMgMd00_ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP1hooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l0
0009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000=oooo
o`09ogMgMolb<S;ooooooooooolQ8B7oV9RHoooooonHV9So8B4Q00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`1hooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Oooooo
00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01;ooooo00?o0000oooooooo
ool07oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool@41000oooool0
0ol@413oooooooooo`1fooooo`00POooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0
000;ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`00
0?oooooooooo00_ooooo1_l0000=ooooo`09ogMgMolb<S;ooooooooooolb<S;oV9RHoooooonHV9So
<S8b00?ooooo00Go0000ooooooooooooooooo`00001hooooo`00POooool01_l0003ogMgMoc8b<_mE
EEGogMgMo`0001_ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000001;o
oooo00?o0000ooooooooool06oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Goc<c<o`00
0?l0003o0000olc<c003ooooo`05o`000?ooooooooooooooool00000N?ooool0087ooooo00Ko0000
ohN7QonYZJWo^[ZjoeEEEOl0000Looooo`05o`000?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`0>ooooo`03oa0@4?l0003o000000?o00006_ooool00ol0003oooooooooo`04ooooo`05
oa0@4?nj^[[ooooookZj^_l@41000oooool01Ol@413ooooooooooooooooo410@07Sooooo0021oooo
o`06o`000?lb<S;ooooooooooolb<S;o00006?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0Booooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool01?ooool01Ol0003o^[Zjoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1h
ooooo`00P?ooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Oooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003ooooooooo
o`0Kooooo`Co00000oooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP1hooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(590) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .24888 m
.00488 .25094 L
.00942 .25312 L
.01441 .25617 L
.01975 .26056 L
.02535 .26667 L
.03065 .27387 L
.04057 .29042 L
.06178 .33719 L
.07375 .37323 L
.08481 .41065 L
.09428 .43955 L
.0996 .45206 L
.10213 .45673 L
.10447 .46026 L
.10721 .46338 L
.10866 .46457 L
.1094 .46506 L
.1102 .4655 L
.11097 .46583 L
.11167 .46605 L
.11306 .46628 L
.11432 .46625 L
.11565 .46597 L
.1169 .46548 L
.11823 .46472 L
.1195 .46378 L
.12065 .46275 L
.12346 .45953 L
.12613 .45562 L
.13626 .43455 L
.14703 .40527 L
.15712 .37677 L
.16637 .35401 L
.17621 .33602 L
.18138 .32926 L
.18682 .32388 L
.19157 .32039 L
.19598 .31798 L
.19852 .31692 L
.20083 .31616 L
.20211 .31582 L
.2035 .31552 L
.2048 .3153 L
.20601 .31514 L
.20733 .31504 L
.20858 .315 L
.2097 .31502 L
.21092 .31509 L
.21224 .31523 L
Mistroke
.21298 .31534 L
.21365 .31546 L
.21619 .31607 L
.21855 .31686 L
.2211 .31796 L
.22571 .32051 L
.23701 .329 L
.24738 .33766 L
.26887 .35365 L
.27426 .35719 L
.27935 .36021 L
.28432 .36267 L
.2865 .36355 L
.2889 .36436 L
.29122 .36497 L
.29339 .36538 L
.29458 .36554 L
.29568 .36564 L
.29688 .36571 L
.29814 .36573 L
.29935 .36571 L
.30063 .36564 L
.30184 .36553 L
.30294 .36539 L
.30564 .36494 L
.30818 .36437 L
.3181 .36132 L
.32883 .35746 L
.34933 .34883 L
.36019 .34402 L
.36617 .34187 L
.37185 .34031 L
.37721 .33923 L
.38304 .33832 L
.39326 .33684 L
.41327 .33347 L
.45606 .32719 L
.49726 .32062 L
.50731 .31857 L
.51237 .31775 L
.51524 .3174 L
.51791 .31713 L
.52301 .31677 L
.52784 .31649 L
.53216 .31618 L
.53461 .31594 L
.53686 .31566 L
.54162 .31487 L
.54667 .31378 L
.55715 .31113 L
Mistroke
.5677 .30894 L
.57352 .30804 L
.57904 .30717 L
.58417 .30616 L
.58976 .3047 L
.59957 .30132 L
.61879 .29553 L
.63033 .29374 L
.64119 .29151 L
.65176 .2884 L
.6564 .2871 L
.65886 .28652 L
.66149 .28598 L
.66409 .28557 L
.66646 .28529 L
.6676 .28518 L
.66884 .28509 L
.67 .28502 L
.67109 .28496 L
.67231 .28492 L
.67365 .28488 L
.67636 .28482 L
.67869 .28476 L
.68001 .28472 L
.68124 .28467 L
.6825 .2846 L
.68385 .28451 L
.6866 .28424 L
.68918 .2839 L
.69152 .28349 L
.70259 .2808 L
.70769 .27953 L
.71048 .27894 L
.71309 .27849 L
.71549 .27816 L
.71769 .27793 L
.72013 .27773 L
.72275 .27758 L
.72535 .27744 L
.72812 .27728 L
.72971 .27717 L
.73115 .27704 L
.73396 .2767 L
.7366 .27625 L
.73944 .27561 L
.7446 .27405 L
.78773 .26199 L
.82926 .24797 L
.85018 .24267 L
.8593 .23913 L
Mistroke
.8618 .23835 L
.86445 .23768 L
.86672 .23724 L
.868 .23705 L
.86921 .23691 L
.87057 .23679 L
.87186 .23672 L
.87303 .23668 L
.87429 .23666 L
.87567 .23666 L
.87644 .23668 L
.87713 .23669 L
.87977 .23678 L
.88097 .23682 L
.88224 .23685 L
.8829 .23687 L
.88363 .23688 L
.88491 .23689 L
.88612 .23688 L
.88741 .23684 L
.88863 .23678 L
.88975 .2367 L
.89111 .23657 L
.89256 .2364 L
.89515 .23598 L
.90104 .23466 L
.90661 .23324 L
.90906 .2327 L
.91035 .23244 L
.91173 .23221 L
.91303 .23203 L
.91421 .2319 L
.9154 .2318 L
.91652 .23174 L
.91778 .23172 L
.91894 .23174 L
.92021 .23179 L
.92156 .2319 L
.92282 .23203 L
.92417 .23221 L
.92661 .23262 L
.93217 .23376 L
.93463 .23426 L
.93731 .23474 L
.93853 .23493 L
.93984 .2351 L
.94107 .23523 L
.94219 .23533 L
.94338 .2354 L
.94467 .23545 L
Mistroke
.9458 .23547 L
.947 .23547 L
.94808 .23544 L
.94908 .23541 L
.95018 .23535 L
.95136 .23528 L
.95655 .23491 L
.95781 .23484 L
.95917 .23478 L
.95995 .23476 L
.96066 .23475 L
.96134 .23475 L
.96206 .23476 L
.96278 .23478 L
.96356 .23481 L
.96429 .23486 L
.96495 .23492 L
.96657 .23511 L
.9681 .23536 L
.97079 .23596 L
.97369 .23685 L
.97904 .23903 L
.98469 .24179 L
.99483 .24668 L
1 .24888 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000O?ooool=o`0000Kooooo0_l0000Oooooo`00T_oo
ool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0LOooool;o`0000cooooo3Ol0000Kooooo`00
T_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo06kooooo0ol0000Tooooo`;o00006Oooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo06_ooooo0ol0000Yooooo`?o00005_ooool009;o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4
o`0000Kooooo0_l0001Yooooo`?o0000;oooool2o`0001Cooooo000Fooooo`03o`000?oooooooooo
09cooooo00?o0000ooooooooool0I?ooool4o`0003Cooooo00?o0000ooooooooool04Oooool001Oo
oooo0ol0002Kooooo`03o`000?oooooooooo067ooooo0ol0001<ooooo`006_ooool00ol0003ooooo
ooooo`2Hooooo`03o`000?oooooooooo05gooooo1?l0001?ooooo`006oooool00ol0003ooooooooo
o`2Gooooo`03o`000?oooooooooo05[ooooo0ol0001Cooooo`007?ooool00ol0003oooooooooo`2F
ooooo`;o0000Eoooool4o`0005Kooooo000Mooooo`03o`000?oooooooooo09Gooooo00?o0000oooo
ooooool0Doooool3o`0005[ooooo000Eooooo`;o000000Ko410@ooooooooooooooooonk^k_lb<S82
o`000003onk^k_oooooooooo01Sooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h06oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Looooo`Co
000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQkooooo00?o0000ooooooooool07ooo
ool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hJooooo`Go00000oooool00oo^
k^ko<S8bo`000003o`0001[ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h07Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
00kooooo000Fooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo0000ogMgM`0Joooo
o`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go
V9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@00oooool3o`000003oiRHV?mgMgOooooo01[ooooo00Go410@okZj^_ooooooMgMg
oc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03_ooool000_ooooo1_l00002ooooo`Go00000oooool01Ol@413o
oooooooooooooooo000001;ooooo1_l00006ooooo`05o`000?ooooooooooooooool@41000oooool0
0ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?oooooo
ooooooooool@41004oooool6o`0000Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@01kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41006oooool00onHV9So8B4Qonk^kP04o`000005oa0@4?oooooooooooooo
ool@41007oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool06Oooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`004oooool01?m4A4CogMgMooooool0
0004ooooo`05o`000?ooooooooooooooool000007Oooool00onYZJWo410@ooooo`02ooooo`05o`00
0?ooooooooooooooool000007Oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooooooooooo
ool000007_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007_ooool2
o`0002;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001Kooooo2?l0
00001Oo^k^kooooooooooooooooo000000?ooooo00?o0000ooooooooool07?ooool00onYZJWo410@
ooooo`02ooooo`05o`000?ooooooooooooooool000006oooool01?m4A4CogMgMooooool00004oooo
o`05o`000?ooooooooooooooool000003_ooool001?ooooo00CogMgMoeEEEOoooooo00001?ooool0
1?l0003oooooooooooooool2o`0001_ooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooo
oooooooo000001kooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000001ko
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001kooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004Oooool5
o`0000Oooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000001gooooo00?o
410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000001_ooooo00CogMgMoeEEEOoooooo
00001?ooool01Ol0003ooooooooooooooooo000000kooooo000Dooooo`03ogMgMoo<c<co000000Co
oooo00Oo410@oooooooooooooooooa0@4?oooooo000001_ooooo00?o^[Zjob4Q8Oooool00_ooool0
1Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@
4?oooooooooo01cooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01ko
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41002?ooool9o`0000gooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooo
oooo01cooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@01cooooo00?o
MgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00kooooo000Dooooo`03onk^k_m4
A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`03o`000?oooooooooo01Gooooo
00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool01Ol0
003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo1_l0000Aooooo`05
o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@
oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07?ooool00oo^k^koA4A4
o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool001Gooooo00?oMgMgo`000?ooool0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?o0000ooooooooool05?ooool01OnYZJWo
410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01cooooo00?oEEEEofIVI_l00000
1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01kooooo00?o0000ooooooooool07oooool00omEEEGo
IVIVo`000004ooooo`06onk^k_lb<S;o0000oc8b<_o^k^kooooo0_l0000Gooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Oooool00omgMgOo0000ooooo`03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool002?ooooo00?o0000ooooooooool0Soooool2o`00
02Kooooo1ol00024ooooo`009?ooool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo02;o
oooo0ol0002;ooooo`009?ooool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo01oooooo
0ol0002>ooooo`009?ooool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo01_ooooo1?l0
002Aooooo`009Oooool00ol0003oooooooooo`2=ooooo`03o`000?oooooooooo01Oooooo1?l0002E
ooooo`005_ooooooo`00043o00004oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool4o`0000Co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017o
oooo000Fooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0Fooooo`Ko00002Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool01oooool7o`0001Oooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04Oooool002Kooooo00?o
0000ooooooooool0:oooool2o`0000Gooooo0ol0001Gooooo`[o0000ZOooool002Oooooo00?o0000
ooooooooool0:?ooool2o`0000[ooooo0_l0001Aooooo`Go0000/_ooool002Oooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04Oooooo1ol00004oooo
o`;o0000/Oooool002Sooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo043ooooo1_l0000;ooooo`03o`000?oooooooooo0;3ooooo000Xooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0hooooo`Oo0000
4Oooool00ol0003oooooooooo`2`ooooo`00:?ooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool0<?ooool7o`0001Sooooo00?o0000ooooooooool0/?oo
ool002Wooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Cooooo`;o0000:Oooool7
o`0001oooooo00?o0000ooooooooool0/?ooool002Wooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo02;ooooo1?l0000Vooooo`;o0000/Oooool002[o
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Gooooo`;o00007_ooool4o`0002[o
oooo00?o0000ooooooooool0/?ooool002[ooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`2`ooooo`00:_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool05oooool2o`0002oooooo00?o0000ooooooooool0/?ooool002_ooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0Mooooo`;o00005?ooool3o`00037ooooo00?o0000
ooooooooool0/?ooool002_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Ooooo
o`;o00004?ooool2o`0003Cooooo0_l0002aooooo`00:oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool02oooool2o`0003Kooooo00?o0000oooooooo
ool0/?ooool002cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Sooooo`;o0000
2?ooool3o`0003Sooooo00?o0000ooooooooool0/?ooool002cooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0Uooooo`So0000>oooool00ol0003oooooooooo`2`ooooo`00;?ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0/?ooool0
02gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1Yooooo`;o0000/Oooool002go
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo0;3o
oooo000]ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0Aoooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0/?ooool002kooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`17ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q
8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool0
02kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`18ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0/?ooool002kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`18oooo
o`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;o
oooo00Cooooo0ol0002`ooooo`00;oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
04Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo000_ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool0BOooool01Ol@413ooooooooooooooooo410@00oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo000_
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0BOooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0/?ooool0033ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`1:ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Co
oooo1?l00006ooooo`03o`000?oooooooooo0;3ooooo000`ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0KOooool2o`000;7ooooo000`ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0K_ooool00ol0003oooooooooo`2`ooooo`00<Oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0/?ooool0037ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo0;3ooooo000aooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`2`ooooo`00
<_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo06oooooo0_l0002aooooo`00<_oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0/?oo
ool003;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooo
oooo0;3ooooo000cooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0L?ooool00ol0
003oooooooooo`2`ooooo`00<oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo077o
oooo0_l0002aooooo`00<oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo077ooooo
00?o0000ooooooooool0/?ooool003Cooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`1aooooo`03o`000?oooooooooo0;3ooooo000dooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0L_ooool00ol0003oooooooooo`2`ooooo`00=?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0/?ooool003Cooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`1cooooo`;o0000/Oooool003Gooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo0;3ooooo000eooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`2`ooooo`00=_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0
/?ooool003Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Jooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00>?ooool01Ol0003ooooooooooooooooo000005gooooo00Go410@oooooooooooo
oooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0002`ooooo`00>?ooool4o`0005kooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0/?ooool009[ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`oooo
o`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000/Oooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aoooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool009;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEE
EOooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05
o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo
00Cooooo0ol0002`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<
c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool0
09;ooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0/?ooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?oo
ool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002a
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Zoooool4o`000003oa0@4?oooooooooo00?o
oooo00?o0000ooooooooool0/?ooool00:gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;3ooooo002]
ooooo`03o`000?oooooooooo00Gooooo0ol0002`ooooo`00[Oooool00ol0003oooooooooo`2hoooo
o`00[Oooool00ol0003oooooooooo`2hooooo`00[Oooool00ol0003oooooooooo`2hooooo`00Zooo
ool00omEEEGoIVIVo`00002jooooo`00oooooomYooooo`00[oooool00ol0003o^[Zjooooo`2foooo
o`00[oooool2oc8b<[Oooooo0020ooooo`;o000000Ko410@oooooooooooo410@o`000?l@410Goooo
o`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?oQhN7o`000?nj^[X03?ooool0
1OnHV9So0000o`000?m4A4Co^[Zj01Wooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`04oa0@
4?l0003oA4A4olc<c0Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1hooooo`00POooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l00009ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?oc<c<o`000?l@41003?ooool0
1Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000=ooooo`03ogMgMolb<S;ooooo00?ooooo00?o
V9RHoa0@4?oMgMd00oooool01OmgMgOoV9RHoooooonHV9SoMgMg07Sooooo0021ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool05oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?oo
ooooooooooooool@41004_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00?ooooo
00?oQhN7oeEEEOooool00_ooool01Ol@413ooooooooooooooooo410@07Sooooo0021ooooo`06o`00
0?ooooooA4A4odA4A?oooooo00002Oooool6o`0000_ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0
003ooooooooooooooooo000001;ooooo00?o0000ooooooooool02oooool6o`0000gooooo00WoMgMg
oc8b<_ooooooooooolc<c?lQ8B7o0000oeEEEOl000000oooool01Ol0003ooooooooooooooooo0000
07Sooooo0021ooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo00006oooool00omgMgOoIVIVooooo`02
ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0Kooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`00_ooool01OlQ8B7oQhN7oooooonHV9So000000?ooooo00Go0000oooooooo
ooooooooo`00001hooooo`00POooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001cooooo00Go0000
oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00kooooo00?o410@o`000?l000000ol0
000Jooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000003ooooo`05oa0@
4?ooooooooooooooool@4100N?ooool0087ooooo00Ko0000oc8b<_oooooooooooc8b<_l0000Hoooo
o`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`04ooooo`05ob4Q8OnHV9SoooooogMgMomEEED0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg07Sooooo0020ooooo`03oa0@4?l0003oQhN700;ooooo
00?oQhN7o`000?l@41005oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0Booooo`03o`000?oooooooooo01_ooooo1?l00003ooooo`05olc<c?l@413o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07Sooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(600) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .25075 m
.00488 .253 L
.00942 .25584 L
.01975 .26493 L
.04057 .2894 L
.05176 .30686 L
.06194 .32856 L
.08481 .39224 L
.09457 .41784 L
.09991 .42979 L
.10491 .43922 L
.11031 .44706 L
.11318 .45008 L
.11479 .4514 L
.11626 .45235 L
.11759 .45299 L
.11883 .4534 L
.12018 .45364 L
.12094 .45368 L
.12163 .45365 L
.12289 .45345 L
.12426 .453 L
.12555 .45237 L
.12674 .45161 L
.12932 .44937 L
.13167 .44666 L
.13696 .43845 L
.1465 .41838 L
.15777 .39229 L
.1682 .37137 L
.17791 .35603 L
.18824 .34359 L
.19358 .33869 L
.1986 .3352 L
.20147 .33375 L
.2041 .33278 L
.20548 .33241 L
.20699 .33211 L
.20775 .332 L
.20857 .33192 L
.20934 .33187 L
.21003 .33184 L
.21129 .33186 L
.21246 .33193 L
.21374 .33207 L
.21513 .3323 L
.21657 .3326 L
.21794 .33295 L
.22052 .33374 L
.23018 .33757 L
Mistroke
.25202 .34636 L
.26287 .35138 L
.2682 .35396 L
.27309 .35612 L
.27755 .35774 L
.2798 .35838 L
.28226 .35894 L
.28354 .35916 L
.28474 .35933 L
.28613 .35949 L
.28739 .35959 L
.28858 .35965 L
.28968 .35967 L
.29089 .35967 L
.29217 .35964 L
.29345 .35959 L
.29462 .35951 L
.29725 .35929 L
.30202 .35876 L
.31287 .3576 L
.3184 .35711 L
.32143 .35683 L
.32429 .3565 L
.32986 .35565 L
.33491 .35454 L
.34527 .35152 L
.35482 .34875 L
.35989 .34759 L
.36526 .34663 L
.37657 .34489 L
.3865 .34277 L
.39716 .3398 L
.4164 .33554 L
.43718 .33142 L
.44814 .32876 L
.45368 .32771 L
.45683 .32725 L
.4598 .3269 L
.47024 .32609 L
.47572 .32563 L
.47848 .32533 L
.4815 .32494 L
.49198 .32321 L
.5016 .3217 L
.51306 .32057 L
.5158 .32033 L
.51869 .32004 L
.52389 .31935 L
.52852 .31847 L
.53361 .3172 L
Mistroke
.54416 .31401 L
.58512 .30277 L
.59054 .30074 L
.59646 .29872 L
.60204 .2972 L
.60723 .29618 L
.62744 .29321 L
.66817 .28696 L
.70928 .27812 L
.71454 .2774 L
.72009 .27642 L
.72299 .27572 L
.72618 .27478 L
.73178 .27263 L
.75296 .26333 L
.76438 .26054 L
.76999 .25928 L
.77518 .25777 L
.77989 .25599 L
.78488 .25371 L
.78996 .25119 L
.79543 .24861 L
.80066 .2466 L
.80295 .24591 L
.80546 .2453 L
.80767 .24486 L
.81004 .2445 L
.81254 .2442 L
.81486 .24397 L
.81764 .24371 L
.82065 .24339 L
.82348 .24299 L
.8261 .24251 L
.83106 .24128 L
.8363 .23958 L
.84139 .23776 L
.84622 .23619 L
.84889 .23549 L
.85029 .23519 L
.85179 .23491 L
.85317 .23471 L
.85443 .23457 L
.85569 .23446 L
.85687 .2344 L
.85799 .23437 L
.85922 .23437 L
.8605 .23439 L
.86169 .23444 L
.86281 .2345 L
.86383 .23457 L
Mistroke
.86612 .23475 L
.86858 .23495 L
.86988 .23505 L
.87125 .23514 L
.87245 .2352 L
.87378 .23524 L
.87498 .23525 L
.87611 .23524 L
.87741 .2352 L
.87814 .23516 L
.87881 .23512 L
.8801 .23501 L
.88131 .23488 L
.88404 .2345 L
.887 .23396 L
.89204 .23293 L
.89479 .2324 L
.89736 .23199 L
.89855 .23184 L
.89969 .23172 L
.90099 .23163 L
.90218 .23157 L
.9035 .23156 L
.90472 .23158 L
.90606 .23165 L
.90674 .2317 L
.90748 .23178 L
.9098 .23208 L
.91229 .23252 L
.9168 .23353 L
.92166 .23467 L
.92433 .23522 L
.92685 .23564 L
.92828 .23583 L
.92983 .23598 L
.93051 .23604 L
.93124 .23609 L
.93254 .23614 L
.93384 .23617 L
.93506 .23618 L
.9364 .23615 L
.93715 .23613 L
.93784 .2361 L
.94327 .23582 L
.94476 .23575 L
.94559 .23572 L
.94635 .2357 L
.94705 .23569 L
.94782 .23569 L
.9492 .23571 L
Mistroke
.9505 .23577 L
.95124 .23581 L
.95193 .23587 L
.95333 .23602 L
.95482 .23624 L
.95753 .23678 L
.95999 .23744 L
1 .25075 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1mooooo`;o0000<Oooool009;ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0006gooooo1Ol00005ooooo`Ko0000
00?oooooo`000?l000001?l0000/ooooo`00T_ooool01Ol0003ooooooooooooooooo000000kooooo
00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool0JOooool5o`0000Cooooo1Ol0000=ooooo`go00007oooool009;ooooo00Go410@oooooooooooo
oooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`1Wooooo`;o0000:?ooool3o`0001cooooo002Booooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`1Pooooo`Oo0000;Oooool3o`0001Wooooo002Booooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000GOooool5
o`0003Kooooo0_l0000Gooooo`00]Oooool00ol0003oooooooooo`1Jooooo`;o0000?Oooool3o`00
01Cooooo000Fooooo`?o0000W?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo043o
oooo00?o0000ooooooooool04Oooool001Wooooo00?o0000ooooooooool0VOooool00ol0003ooooo
ooooo`1Eooooo`Co0000Eoooool001[ooooo00?o0000ooooooooool0V?ooool00ol0003ooooooooo
o`1Booooo`?o0000Foooool001_ooooo00?o0000ooooooooool0Uoooool2o`00053ooooo0ol0001N
ooooo`007?ooool00ol0003oooooooooo`2Fooooo`03o`000?oooooooooo04cooooo0ol0001Qoooo
o`005Oooool2o`000005oa0@4?ooooooooooooooooo^k^h00_l000000olb<S;ok^k^ooooo`0Ioooo
o`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo1Ol0
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool4o`000008oa0@4?ooooooooooonk^k_lb
<S;o0000oc8b<_o^k^hNooooo`03o`000?oooooooooo01oooooo1?l000002?l@413oooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^6_ooool7o`000006ooooooo^k^ko<S8bo`000?lb<S;ok^k^6oooool0
1OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Mooooo`;o0000
00Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h03_ooool001Kooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHo`000?nHV9SoMgMg01[ooooo00Go410@okZj^_ooooooMgMgoc8b
<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool01OnHV9So8B4Qonk^k_ooooooA4A400?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00?oV9RHob4Q8Oo^k^h00_l00003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL06oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>
ooooo`002oooool6o`0000;ooooo1Ol00003ooooo`05oa0@4?ooooooooooo`000?l@41004_ooool6
o`0000Kooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo017ooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400Cooooo`Ko0000
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41007_ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Joooo
o`?o000000?ok^k^ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000
oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01Wooooo1Ol00003ooooo`05oa0@4?oo
ooooooooooooool@41003_ooool001?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000001gooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo0000
01gooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000001kooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000001kooooo0_l0000Rooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`Oo00000_ooool00onHV9So8B4Q
onk^kP03ooooo`05o`000?ooooooooooooooool000007_ooool00onYZJWo410@ooooo`02ooooo`05
o`000?ooooooooooooooool000006oooool01?m4A4CogMgMooooool00004ooooo`05o`000?oooooo
ooooooooool000003_ooool001?ooooo00CogMgMoeEEEOoooooo00001?ooool01?l0003ooooooooo
ooooool2o`0001_ooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000001ko
oooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000001kooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000001kooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003_ooool5o`0000[ooooo00?o
MgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000001gooooo00?o410@o`000?nj^[X0
0oooool01Ol0003ooooooooooooooooo000001_ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0
003ooooooooooooooooo000000kooooo000Dooooo`03ogMgMoo<c<co000000Cooooo00Oo410@oooo
oooooooooooooa0@4?oooooo000001_ooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooo
oooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01co
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01kooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002Oooool5
o`00013ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o
^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@01cooooo00?oMgMgolc<c?l00000
1?ooool01Ol@413ooooooooooooooooo410@00kooooo000Dooooo`03onk^k_m4A4Co000000Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`03o`000?oooooooooo01Gooooo00Go410@oiRHV?oo
oooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool01Ol0003o^[ZjoooooonH
V9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo1Ol0000Aooooo`05o`000?nj^[[ooooo
oiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@oiRHV?oooooo^[Zj
o`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07?ooool00oo^k^koA4A4o`000004ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03_ooool001Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo00?o0000ooooooooool05?ooool01OnYZJWo410@o`000?l@413o
ZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^01kooooo00?o0000ooooooooool07oooool00omEEEGoIVIVo`000004oooo
o`03onk^k_lb<S;o000000Ko00005_ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00kooooo000Sooooo`03o`000?oooooooooo08oooooo0_l0000Sooooo`Ko0000R?ooool002Cooooo
00?o0000ooooooooool0S_ooool00ol0003oooooooooo`0Mooooo`Go0000S_ooool002Gooooo00?o
0000ooooooooool0SOooool00ol0003oooooooooo`0Iooooo`Co0000Toooool002Gooooo00?o0000
ooooooooool0SOooool00ol0003oooooooooo`0Fooooo`?o0000Uoooool002Kooooo00?o0000oooo
ooooool0S?ooool00ol0003oooooooooo`0Cooooo`?o0000V_ooool001Koooooool00010o`0001?o
oooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`0000Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool3o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo017ooooo000Fooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0:ooooo`?o00006?ooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0Aooooo`00:?ooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo00Cooooo1_l0002V
ooooo`00:?ooool00ol0003oooooooooo`29ooooo`So0000[?ooool002Sooooo00?o0000oooooooo
ool0POooool8o`000003ooooool0003o00000;7ooooo000Yooooo`03o`000?oooooooooo07Oooooo
2Ol00009ooooo`03o`000?oooooooooo0;3ooooo000Yooooo`03o`000?oooooooooo02cooooo0ol0
0014ooooo`Co00004_ooool00ol0003oooooooooo`2`ooooo`00:_ooool00ol0003oooooooooo`0X
ooooo`?o00000_ooool5o`0003gooooo0ol0000Fooooo`03o`000?oooooooooo0;3ooooo000Zoooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool02?ooool2o`0003Kooooo1Ol0000Ioooo
o`03o`000?oooooooooo0;3ooooo000Zooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool02oooool3o`0002oooooo1?l0000Nooooo`;o0000/Oooool002_ooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0?ooooo`;o0000:_ooool3o`0002;ooooo00?o0000ooooooooool0
/?ooool002_ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Booooo`;o00008?oo
ool8o`0002Gooooo00?o0000ooooooooool0/?ooool002_ooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01_ooooo0_l0000]ooooo`03o`000?oooooo
oooo0;3ooooo000/ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool05oooool4o`00
01Gooooo1?l0000_ooooo`03o`000?oooooooooo0;3ooooo000/ooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0:ooooo`So0000<oooool2o`000;7o
oooo000]ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07Oooool<o`0003_ooooo
00?o0000ooooooooool0/?ooool002gooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`1Uooooo`03o`000?oooooooooo0;3ooooo000]ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool0I_ooool00ol0003oooooooooo`2`ooooo`00;_ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0/?ooool002kooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`1Wooooo`;o0000/Oooool002oooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo0;3ooooo000_ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool0AOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooooooo
ool0/?ooool002oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`15ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool0033ooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`16ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onH
V9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool0033o
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`16ooooo`05o`000?oooooooooooooo
ool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`oooo
o`00<?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Kooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005
ooooo`03o`000?oooooooooo0;3ooooo000aooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0Aoooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo000aooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0Aoooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000
okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?oo
ool003;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`18ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`00
0?oooooooooo0;3ooooo000booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Jooo
ool2o`000;7ooooo000booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0K?ooool0
0ol0003oooooooooo`2`ooooo`00<oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
06cooooo00?o0000ooooooooool0/?ooool003?ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo0;3ooooo000cooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0KOooool00ol0003oooooooooo`2`ooooo`00=?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo06kooooo0_l0002aooooo`00=?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0/?ooool003Cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo0;3ooooo000eooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`2`ooooo`00
=Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo073ooooo0_l0002aooooo`00=Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0/?oo
ool003Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooo
oooo0;3ooooo000gooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0LOooool00ol0
003oooooooooo`2`ooooo`00>?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07;o
oooo00?o0000ooooooooool0/?ooool003Wooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1booooo`;o0000/Oooool003[ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`1cooooo`03o`000?oooooooooo0;3ooooo000kooooo`Co0000M_ooool00ol0003oooooooooo`2`
ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?oo
ool009[ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0
002`ooooo`00V_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol0003ooooooooooooooooo000000cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo
002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@4100
3Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
/?ooool009;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo
00?oMgMgoc8b<_ooool01?ooool3o`000;3ooooo002Booooo`05o`000?ooooooooooooooool00000
3_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003o
ooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMooo
ool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002[ooooo`Co000000?o
410@ooooooooool00oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0/?ooool00:gooooo00?o0000ooooooooool01Oooool3o`000;3ooooo002]ooooo`03o`00
0?oooooooooo0;Sooooo002]ooooo`03o`000?oooooooooo0;Sooooo002]ooooo`03o`000?oooooo
oooo0;Sooooo002[ooooo`03oeEEEOmVIVKo00000;[ooooo003oooooofWooooo002_ooooo`03o`00
0?nj^[[ooooo0;Kooooo002_ooooo`;o<S8b]oooool0083ooooo0_l000001_l@413oooooooooool@
413o0000oa0@41Oooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOo
0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool01Oo^k^ko<S8bo`000?l@413o
c<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
N?ooool0087ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00002Ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03
olc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002Oooool01OmE
EEGoMgMgoooooonHV9So8B4Q00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0N?ooool0087ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Gooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400Booooo`03o`00
0?oooooooooo01[ooooo00Go0000ooooooooooooooooo`000003ooooo`05oa0@4?oooooooooooooo
ool@41000oooool01Ol@413ooooooooooooooooo410@07Sooooo0021ooooo`06o`000?ooooooA4A4
odA4A?oooooo00002Oooool6o`0000_ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooo
oooooooo000001;ooooo00?o0000ooooooooool02oooool6o`0000Wooooo00Go0000oiRHV?oooooo
V9RHob4Q8@03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000007Sooooo0021ooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo00006oooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0Jooooo`05o`00
0?mEEEGo0000oa0@4?o<c<`00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`00001hooooo`00POooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001cooooo00Go
0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00kooooo00?o410@o`000?l00000
0ol0000Iooooo`03oeEEEOn7QhOooooo00Gooooo00Go410@oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@4100N?ooool0087ooooo00Ko0000oc8b<_oooooooooooc8b<_l0000H
ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo
00?o0000ooooooooool06_ooool00ooMgMgo410@oiRHV005ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg07Sooooo0020ooooo`03oa0@4?l0003oQhN700;o
oooo00?oQhN7o`000?l@41005oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Booooo`03o`000?oooooooooo01_ooooo00Coc<c<odA4A?l0003o410@0ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1hooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(610) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .25503 m
.01975 .26986 L
.02981 .27785 L
.04057 .28876 L
.04629 .29656 L
.0515 .30503 L
.06168 .32464 L
.08481 .3747 L
.09457 .3964 L
.10491 .41776 L
.11031 .42682 L
.11318 .43071 L
.11626 .43407 L
.11771 .43533 L
.11908 .43633 L
.12042 .43712 L
.12167 .43769 L
.12284 .43808 L
.12409 .43835 L
.12548 .43846 L
.12674 .4384 L
.128 .43819 L
.12918 .43786 L
.13047 .43736 L
.13185 .43667 L
.13468 .4348 L
.13726 .43264 L
.14694 .42163 L
.1688 .38992 L
.17852 .37573 L
.18884 .36323 L
.19423 .35846 L
.19708 .35648 L
.20017 .35473 L
.20299 .35347 L
.20557 .35254 L
.20823 .35177 L
.21064 .35121 L
.21562 .35031 L
.22094 .34954 L
.22592 .34891 L
.22811 .34867 L
.23051 .34845 L
.23177 .34836 L
.23312 .34828 L
.23386 .34825 L
.23454 .34823 L
.23588 .34821 L
.23662 .34821 L
.2373 .34821 L
Mistroke
.23806 .34823 L
.23886 .34826 L
.23963 .34831 L
.24035 .34836 L
.24169 .34848 L
.24298 .34862 L
.24434 .34882 L
.24677 .34924 L
.25225 .35054 L
.26223 .3533 L
.2651 .35397 L
.26782 .35449 L
.27026 .35486 L
.27163 .35502 L
.27291 .35514 L
.27412 .35524 L
.27522 .3553 L
.27645 .35536 L
.27777 .3554 L
.27897 .35543 L
.28028 .35544 L
.28165 .35544 L
.28292 .35544 L
.28413 .35544 L
.28527 .35543 L
.28629 .35543 L
.2874 .35544 L
.28861 .35545 L
.28988 .35548 L
.29097 .35551 L
.29217 .35556 L
.29354 .35563 L
.2948 .35571 L
.29766 .35595 L
.30287 .35653 L
.3079 .35714 L
.31037 .35739 L
.31145 .35747 L
.31263 .35756 L
.31382 .35762 L
.31506 .35766 L
.31642 .35768 L
.31769 .35767 L
.31841 .35765 L
.3191 .35763 L
.32039 .35756 L
.32177 .35745 L
.32327 .35729 L
.32613 .35691 L
.32916 .35639 L
Mistroke
.33458 .35531 L
.35535 .35216 L
.35974 .35162 L
.36443 .35086 L
.36956 .34968 L
.37433 .34825 L
.38479 .34448 L
.39473 .34133 L
.40065 .34 L
.40623 .33904 L
.41666 .33727 L
.45715 .33057 L
.45959 .33051 L
.46097 .33047 L
.46225 .33042 L
.46459 .33029 L
.46577 .33021 L
.46707 .3301 L
.46994 .3298 L
.47263 .32943 L
.47769 .32855 L
.48935 .32624 L
.50023 .32453 L
.50996 .32303 L
.51485 .32198 L
.5202 .32048 L
.53142 .31647 L
.54171 .31283 L
.56404 .30682 L
.5746 .30344 L
.58432 .30036 L
.58924 .29914 L
.59445 .29819 L
.59715 .29782 L
.59968 .29753 L
.60543 .29695 L
.61035 .2964 L
.61503 .29572 L
.62042 .29472 L
.62534 .29366 L
.64643 .29033 L
.6509 .28997 L
.65561 .28949 L
.65807 .28915 L
.66077 .28867 L
.66552 .28755 L
.67104 .28582 L
.67619 .28392 L
.68623 .28027 L
.69756 .27714 L
Mistroke
.70313 .27575 L
.70827 .27422 L
.71854 .2699 L
.7297 .26391 L
.73916 .25958 L
.74394 .25799 L
.7492 .25662 L
.77128 .24943 L
.77635 .24702 L
.78176 .24457 L
.78439 .24353 L
.78686 .24269 L
.78911 .24204 L
.79149 .24149 L
.79398 .24106 L
.79628 .24077 L
.79756 .24064 L
.79875 .24055 L
.80146 .24038 L
.80439 .24024 L
.80716 .24007 L
.80964 .23986 L
.81105 .23971 L
.81235 .23954 L
.81699 .2387 L
.82192 .23743 L
.82728 .23582 L
.83219 .23444 L
.83467 .23387 L
.83698 .23345 L
.83814 .23329 L
.83939 .23315 L
.84077 .23305 L
.84202 .23299 L
.84338 .23297 L
.84464 .233 L
.84601 .23306 L
.84671 .2331 L
.84747 .23316 L
.85013 .23343 L
.85262 .23375 L
.85489 .23405 L
.85737 .23436 L
.8585 .23449 L
.8597 .2346 L
.86075 .23468 L
.86187 .23475 L
.8626 .23479 L
.86328 .23481 L
.8646 .23482 L
Mistroke
.8658 .23481 L
.86707 .23477 L
.86824 .2347 L
.86933 .23461 L
.87181 .23434 L
.87708 .23354 L
.87986 .23309 L
.88281 .23268 L
.88405 .23255 L
.88538 .23243 L
.88614 .23238 L
.88684 .23234 L
.88822 .23231 L
.88938 .23231 L
.89065 .23235 L
.89198 .23244 L
.89322 .23256 L
.89444 .23272 L
.89576 .23292 L
.89816 .23339 L
.90265 .23449 L
.90785 .23587 L
.91039 .23647 L
.91271 .23694 L
.91389 .23714 L
.91517 .23732 L
.91628 .23746 L
.91751 .23757 L
.91881 .23766 L
.92019 .23772 L
.92147 .23774 L
.92267 .23773 L
.924 .2377 L
.92468 .23768 L
.92541 .23765 L
.92793 .23751 L
.92946 .23742 L
.9309 .23735 L
.9322 .23729 L
.93293 .23726 L
.93361 .23724 L
.93489 .23723 L
.93561 .23723 L
.93629 .23725 L
.93767 .2373 L
.93844 .23735 L
.93914 .2374 L
.94059 .23756 L
.94217 .23778 L
.94506 .23836 L
Mistroke
.94773 .23908 L
.95058 .24001 L
.95572 .24192 L
.9767 .24765 L
.98244 .24847 L
.98534 .249 L
.98851 .24979 L
.99123 .25067 L
.99414 .25185 L
.99938 .25465 L
1 .25503 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000I_ooool;o`000003ooooool0003o000000_o0000
<Oooool009;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo06?ooooo0ol0000:ooooo`;o
00003Oooool<o`0002Gooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0F_ooool9o`0002So
oooo0ol0000Rooooo`00T_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oo
ooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Eoooool4o`00
03?ooooo0ol0000Oooooo`00T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`0005Gooooo1?l0000iooooo`?o00007?ooool0
0;Gooooo00?o0000ooooooooool0DOooool3o`00043ooooo1Ol0000Gooooo`00]Oooool00ol0003o
ooooooooo`1>ooooo`?o0000B?ooool3o`0001Cooooo000Fooooo`;o0000WOooool00ol0003ooooo
ooooo`1<ooooo`;o0000C_ooool00ol0003oooooooooo`0Aooooo`006?ooool00ol0003ooooooooo
o`2Jooooo`03o`000?oooooooooo04Sooooo1?l0001Tooooo`006Oooool00ol0003oooooooooo`2I
ooooo`;o0000B?ooool00ol0003oooooooooo`1Vooooo`006_ooool00ol0003oooooooooo`2Hoooo
o`03o`000?oooooooooo04Gooooo0_l0001Yooooo`005Oooool2o`000009oa0@4?oooooooooooooo
ool0003o<S8bo`000?lb<S;ok^k^01[ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h06oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Loooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQkooooo00?o0000ooooooooool0
7oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hHooooo`Oo00000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h07Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb
<S;ok^k^00kooooo000Fooooo`03o`000?oooooooooo00;ooooo00GoMgMgo`000?l0003oV9RHogMg
M`0Jooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Fooooo`;o0000
0_ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Koooo
o`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko00000_oo
ool5o`0000?ooooo00Go410@oooooooooooo0000oa0@400Booooo`Ko00001_ooool01Ol0003ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool04Oooool6o`0000?ooooo00?oV9RHob4Q8Oo^
k^h01?ooool01Ol@413ooooooooooooooooo410@01?ooooo1_l00005ooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@400Nooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01Cooooo0_l00005ooooo`03oiRHV?lQ
8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400Oooooo`05o`000?ooooooooooooooool@
41000oooool00ol@413oooooooooo`0Iooooo`Go00000oooool01Ol@413ooooooooooooooooo410@
00kooooo000Cooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000M
ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`00000Nooooo`;o00008_ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000003oooool5o`0000Sooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0
003ooooooooooooooooo000001kooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooo
oooo000001_ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000000ko
oooo000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo00Co0000oooooooooooooooo0_l0000Koooo
o`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`00000Nooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`00000Nooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000cooooo0ol0000>ooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Mooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000oooo
ooooooooooooo`00000Kooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000oooooooooooooooo
o`00000>ooooo`005?ooool00omgMgOoc<c<o`000004ooooo`07oa0@4?ooooooooooooooool@413o
ooooo`00000Kooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@400Ooooo
o`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Looooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@400Nooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Wooooo0ol0000Booooo`05o`00
0?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Looooo`03okZj^_lQ8B7ooooo00;o
oooo00Go410@oooooooooooooooooa0@400Looooo`03ogMgMoo<c<co000000Cooooo00Go410@oooo
oooooooooooooa0@400>ooooo`005?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00_ooool00ol0003oooooooooo`0Eooooo`05oa0@4?nHV9SooooookZj^_l000000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL07_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`06ooooo`?o00004Oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00kooooo000Eooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`03o`000?oooooooooo01Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h06oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Looooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0Nooooo`03o`000?oooooooooo01oooooo00?oEEEEofIVI_l000001?ooool00oo^k^ko<S8bo`00
0008o`0001Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h06oooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0M
ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`008oooool0
0ol0003oooooooooo`2?ooooo`;o00009Oooool4o`0008Sooooo000Tooooo`03o`000?oooooooooo
08kooooo00?o0000ooooooooool07Oooool7o`0008cooooo000Tooooo`03o`000?oooooooooo08ko
oooo00?o0000ooooooooool05oooool6o`0009?ooooo000Uooooo`03o`000?oooooooooo08gooooo
00?o0000ooooooooool04oooool4o`0009Wooooo000Vooooo`03o`000?oooooooooo08cooooo00?o
0000ooooooooool03oooool4o`0009gooooo000Foooooooo0000@?l0000Cooooo`005_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`04o`000?oooooooooo
ooooo`?o000000?oooooo`000?ooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool04Oooool001Kooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0Aooooo`00:?ooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo00Go
oooo0ol0002Xooooo`00:?ooool00ol0003oooooooooo`2:ooooo`04o`000?ooooooooooooooo`Co
0000Zoooool002Wooooo00?o0000ooooooooool0Qoooool6o`000:oooooo000Yooooo`03o`000?oo
oooooooo087ooooo1_l00002ooooo`03o`000?oooooooooo0;3ooooo000Zooooo`03o`000?oooooo
oooo07Oooooo2Ol00008ooooo`03o`000?oooooooooo0;3ooooo000Zooooo`03o`000?oooooooooo
073ooooo1ol0000Aooooo`03o`000?oooooooooo0;3ooooo000[ooooo`03o`000?oooooooooo06_o
oooo1?l0000Hooooo`03o`000?oooooooooo0;3ooooo000[ooooo`03o`000?oooooooooo06Cooooo
1ol0000Looooo`;o0000/Oooool002cooooo00?o0000ooooooooool0H?ooool3o`0002?ooooo00?o
0000ooooooooool0/?ooool002cooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo0;3ooooo000]ooooo`03o`000?oooooooooo02[ooooo3ol0000Poooo
o`Go00009oooool00ol0003oooooooooo`2`ooooo`00;Oooool00ol0003oooooooooo`0Vooooo`Co
00003oooool2o`0001Wooooo1Ol0000/ooooo`03o`000?oooooooooo0;3ooooo000^ooooo`03o`00
0?oooooooooo02?ooooo0_l0000Eooooo`ko00001Oooool6o`00037ooooo0_l0002aooooo`00;_oo
ool00ol0003oooooooooo`0Rooooo`;o00009?ooool5o`0003Oooooo00?o0000ooooooooool0/?oo
ool002oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo0;3ooooo000_ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`2`ooooo`00<?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo067o
oooo00?o0000ooooooooool0/?ooool0033ooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`1Rooooo`;o0000/Oooool0037ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`1Sooooo`03o`000?oooooooooo0;3ooooo000aooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool0@?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool003;ooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`11ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0/?ooool003;ooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`12ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool003?ooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`13ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So
8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00<oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo04Cooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo
0;3ooooo000cooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0A?ooool01Ol@413o
oooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo0;3ooooo000dooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool0AOooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool003Cooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`16ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo0;3ooooo000e
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0JOooool2o`000;7ooooo000eoooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`2`oooo
o`00=_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo06_ooooo00?o0000oooooooo
ool0/?ooool003Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1/ooooo`03o`00
0?oooooooooo0;3ooooo000fooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0K?oo
ool00ol0003oooooooooo`2`ooooo`00=oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo06gooooo0_l0002aooooo`00=oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
06kooooo00?o0000ooooooooool0/?ooool003Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`1_ooooo`03o`000?oooooooooo0;3ooooo000iooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0L?ooool00ol0003oooooooooo`2`ooooo`00>_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo077ooooo0_l0002aooooo`00>oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0/?ooool003cooooo1Ol0001doooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool0
09[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`03ooooo`?o0000/?ooool009[ooooo00Go0000ooooooooooooooooo`00000?
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l00006ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool0
0ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooooooo
o`2`ooooo`00T_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnY
ZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00T_ooool0
1Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?ooooooooooooooool000003_oo
ool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00T_ooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00Go410@oooooooooooooooo
oa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooo
oooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo00?o0000oooooooo
ool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00Zoooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool0
0:gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo
0ol0002`ooooo`00[Oooool00ol0003oooooooooo`2hooooo`00[Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`2hooooo`00Zoooool00omEEEGoIVIVo`00002jooooo`00
oooooomYooooo`00[oooool00ol0003o^[Zjooooo`2fooooo`00[oooool2oc8b<[Oooooo0020oooo
o`;o000000Ko410@oooooooooooo410@o`000?l@410Gooooo`Go00000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01So
oooo00Gok^k^oc8b<_l0003o410@olc<c004ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0
003o<S8bonk^kWSooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01ooo
ool6o`0000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`00
00Wooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`1hooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo01Oooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01;ooooo00?o
0000ooooooooool06_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@07Sooooo0021ooooo`06o`000?ooooooA4A4odA4A?oo
oooo00002Oooool6o`0000_ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo
000001;ooooo00?o0000ooooooooool02oooool6o`0000Wooooo00Go0000oiRHV?ooooooV9RHob4Q
8@06ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001hooooo`00POoo
ool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001_ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003o
oooooooooooooooo000001;ooooo00?o0000ooooooooool06_ooool01Ol0003oEEEEo`000?l@413o
c<c<00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000007Sooooo0021
ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo00007?ooool01Ol0003ooooooooooooooooo410@00?o
oooo00?o410@ooooooooool03_ooool00ol@413o0000o`000003o`0001Wooooo00?oEEEEohN7Qooo
ool02?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100N?ooool0087o
oooo00Ko0000oc8b<_oooooooooooc8b<_l0000Hooooo`05o`000?nj^[[ooooooiRHV?l@41000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool06_ooool00ooMgMgo410@
oiRHV008ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1hooooo`00
P?ooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Oooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Koooo
o`04olc<c?m4A4Co0000oa0@40Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^07Sooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(620) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .26236 m
.00942 .26793 L
.01975 .27363 L
.02496 .27707 L
.03053 .28169 L
.04057 .29287 L
.08481 .3601 L
.09494 .37928 L
.10568 .3977 L
.11128 .40535 L
.11745 .4119 L
.12016 .41417 L
.12307 .41623 L
.12833 .41905 L
.13111 .4201 L
.13369 .42081 L
.13518 .4211 L
.13653 .42129 L
.13728 .42137 L
.13808 .42142 L
.13885 .42145 L
.13955 .42145 L
.14083 .42141 L
.14202 .4213 L
.14333 .4211 L
.14407 .42096 L
.14474 .42081 L
.14609 .42044 L
.14755 .41994 L
.15022 .41876 L
.15527 .41562 L
.16063 .41108 L
.17025 .40099 L
.19093 .38108 L
.20989 .36807 L
.21959 .36209 L
.22509 .35939 L
.22772 .35837 L
.23021 .35758 L
.23291 .35692 L
.23536 .3565 L
.23674 .35632 L
.23801 .3562 L
.2394 .3561 L
.2401 .35606 L
.24087 .35603 L
.24162 .35601 L
.24233 .35599 L
.24367 .35598 L
.24442 .35598 L
Mistroke
.24511 .35598 L
.24587 .35599 L
.24668 .356 L
.24927 .35604 L
.24997 .35605 L
.25073 .35606 L
.2521 .35607 L
.25284 .35607 L
.25354 .35607 L
.25485 .35605 L
.25624 .35603 L
.25702 .35601 L
.25775 .35598 L
.26026 .35587 L
.26293 .35572 L
.26584 .35553 L
.26736 .35543 L
.26897 .35534 L
.27038 .35528 L
.27113 .35525 L
.27192 .35522 L
.27266 .3552 L
.27333 .35519 L
.27463 .35519 L
.27593 .35521 L
.27712 .35525 L
.27843 .35532 L
.27982 .35543 L
.28215 .35567 L
.28471 .35603 L
.29041 .35709 L
.29582 .35818 L
.2983 .35863 L
.30094 .35902 L
.30232 .35918 L
.30384 .35933 L
.30522 .35942 L
.30652 .35948 L
.30771 .3595 L
.30897 .3595 L
.31004 .35948 L
.31121 .35943 L
.31248 .35935 L
.31384 .35925 L
.31628 .359 L
.33823 .35654 L
.34345 .35614 L
.34607 .35587 L
.34897 .35549 L
.3521 .35494 L
Mistroke
.35503 .35428 L
.36062 .35264 L
.37073 .34891 L
.37646 .34692 L
.38177 .34544 L
.38705 .34436 L
.39268 .34353 L
.39802 .34283 L
.40305 .34206 L
.41325 .33991 L
.4225 .33782 L
.42486 .3374 L
.4274 .33702 L
.42885 .33685 L
.43017 .33672 L
.43143 .33662 L
.43276 .33653 L
.43415 .33647 L
.43543 .33643 L
.43681 .33641 L
.43759 .3364 L
.43833 .3364 L
.43965 .3364 L
.44087 .33641 L
.44219 .33642 L
.44291 .33643 L
.4436 .33643 L
.44483 .33643 L
.44594 .33643 L
.44698 .33641 L
.44812 .33639 L
.44936 .33634 L
.45069 .33628 L
.45181 .3362 L
.45305 .33609 L
.45553 .33581 L
.45819 .33541 L
.463 .33442 L
.50636 .32379 L
.51687 .31941 L
.52263 .31692 L
.52804 .31484 L
.53859 .31184 L
.54813 .30975 L
.58831 .3009 L
.62886 .29404 L
.63973 .29208 L
.64503 .29096 L
.64986 .28962 L
.65496 .2878 L
Mistroke
.66042 .28542 L
.67199 .27986 L
.71391 .26103 L
.75423 .24665 L
.76498 .24228 L
.77024 .24037 L
.77254 .23968 L
.77505 .23906 L
.77764 .23857 L
.78011 .23823 L
.78147 .2381 L
.78293 .23799 L
.78431 .23792 L
.78555 .23787 L
.79118 .23778 L
.79255 .23776 L
.79331 .23774 L
.79401 .23772 L
.79484 .23769 L
.79562 .23765 L
.79713 .23756 L
.79839 .23746 L
.79974 .23733 L
.80216 .23702 L
.80477 .23658 L
.80764 .236 L
.81269 .23482 L
.81733 .23377 L
.81997 .23328 L
.82131 .23308 L
.82275 .23291 L
.82351 .23284 L
.8242 .23278 L
.82554 .23271 L
.8263 .23268 L
.82711 .23267 L
.82789 .23268 L
.8286 .2327 L
.82986 .23275 L
.83105 .23284 L
.83234 .23297 L
.83374 .23313 L
.83918 .23401 L
.84433 .23486 L
.84581 .23507 L
.84721 .23523 L
.84846 .23534 L
.84981 .23543 L
.85054 .23547 L
.85134 .23549 L
Mistroke
.85217 .23551 L
.85295 .23551 L
.85368 .23549 L
.85434 .23547 L
.8551 .23544 L
.85583 .2354 L
.85722 .23529 L
.8585 .23517 L
.86141 .23481 L
.86669 .23408 L
.86795 .23393 L
.86928 .23379 L
.8705 .23368 L
.87164 .2336 L
.87283 .23354 L
.87413 .23352 L
.87543 .23353 L
.87681 .2336 L
.87755 .23365 L
.87835 .23372 L
.8798 .23389 L
.88251 .23434 L
.89331 .23716 L
.89602 .23786 L
.89859 .23842 L
.9009 .23883 L
.9022 .239 L
.90341 .23913 L
.90458 .23923 L
.90587 .2393 L
.90722 .23933 L
.90849 .23934 L
.90986 .23931 L
.91111 .23926 L
.91249 .23918 L
.91394 .23909 L
.91661 .2389 L
.91808 .23881 L
.91947 .23873 L
.92025 .2387 L
.92111 .23868 L
.92188 .23867 L
.9226 .23867 L
.92327 .23868 L
.92402 .2387 L
.92479 .23873 L
.92552 .23877 L
.92683 .23889 L
.92822 .23905 L
.93073 .23948 L
Mistroke
.93371 .2402 L
.93642 .24101 L
.94678 .24474 L
.9516 .24625 L
.95413 .24688 L
.9568 .24741 L
.95914 .24776 L
.96171 .24806 L
.96624 .24846 L
.96833 .24865 L
.97061 .2489 L
.97277 .24921 L
.97476 .24958 L
.97853 .25056 L
.98043 .25121 L
.98253 .25205 L
.99154 .25692 L
1 .26236 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000HOooool:o`0000Kooooo2Ol0000fooooo`00T_oo
ool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0Eoooool:o`0000[ooooo1_l00009ooooo`;o
0000=?ooool009;ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Booooo`Ko00009?ooool>o`0002Ko
oooo002Booooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1@ooooo`;o0000>?ooool00ol0
003oooooooooo`0Sooooo`00T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`0004kooooo0ol0000kooooo`?o00008_ooool0
0;Gooooo00?o0000ooooooooool0B_ooool3o`00047ooooo1ol0000Kooooo`00]Oooool00ol0003o
ooooooooo`17ooooo`?o0000Boooool3o`0001Sooooo002eooooo`03o`000?oooooooooo04Gooooo
0_l0001Aooooo`03o`000?oooooooooo01Gooooo002eooooo`03o`000?oooooooooo04;ooooo0ol0
001Dooooo`?o00005?ooool001Kooooo0_l0002Mooooo`;o0000@Oooool2o`0005[ooooo00?o0000
ooooooooool04Oooool001Sooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0noooo
o`;o0000L?ooool001Gooooo0_l000002Ol@413oooooo`000?l0003ok^k^oc8b<_l0003o<S8bonk^
kP0Jooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hNooooo`03o`000?oooooooooo01oooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^4Oooool2o`0000Oooooo1Ol00003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h06oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0Mooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h03_oo
ool001Kooooo00?o0000ooooooooool00_ooool01Ol0003oV9RHoooooonHV9SoMgMg01[ooooo00Go
410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool01OnHV9So
8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo0ol00009ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj
^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool000_ooooo1_l00002ooooo`Go00000ooo
ool01Ol@413o0000o`000?oooooo410@01;ooooo1_l00006ooooo`05o`000?ooooooooooooooool@
41000oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41004oooool6o`0000Gooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@01kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41003?ooool2o`0000gooooo00?oV9RHob4Q8Oo^k^h01?oo
ool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo01Wooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41003_ooool001?o
oooo00CoA4A4omgMgOoooooo00001?ooool00ol0003oooooooooo`02o`0001gooooo00?oZJVYoa0@
4?ooool00_ooool01Ol0003ooooooooooooooooo000001gooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000001kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000001kooooo0_l0000Rooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`00000:ooooo`;o00004?ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooooooooooo
ool000007_ooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000006oooool0
1?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool001?ooooo00Co
gMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000001cooooo00?o410@o`000?nj
^[X00oooool01Ol0003ooooooooooooooooo000001kooooo00?oMgMgofIVI_ooool00_ooool01Ol0
003ooooooooooooooooo000001kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000001kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000002?ooool2o`0001?ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooo
oooooooooooo000001gooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo0000
01_ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000kooooo000D
ooooo`03ogMgMoo<c<co000000Cooooo00Ko410@oooooooooooooooooa0@4?l0000Looooo`03okZj
^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@400Oooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0Looooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@400Nooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@00Kooooo0_l0000Fooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Looooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Looooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@400>oooo
o`005?ooool00oo^k^koA4A4o`000004ooooo`07ogMgMonHV9SooooooiRHV?mgMgOoooooo`00000H
ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo
00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`?o00005?oo
ool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`05
oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01cooooo00?ok^k^
odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000Eooooo`03ogMgMol0003o
oooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`03o`000?oooooooooo01Gooooo00Go
ZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool01OnHV9So
410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Looooo`03oeEEEOmVIVKo
000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Nooooo`03o`000?oooooooooo01oooooo00?o
EEEEofIVI_l000001?ooool01?o^k^ko<S8bo`000?lb<S84o`0001Oooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool01OnYZJWo410@o`000?l@413o
ZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Mooooo`03ogMgMol0003ooooo00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0>ooooo`008oooool00ol0003oooooooooo`2?ooooo`;o00009Ooo
ool6o`0008Kooooo000Sooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool07oooool5
o`0008cooooo000Tooooo`03o`000?oooooooooo08kooooo00?o0000ooooooooool06oooool4o`00
097ooooo000Uooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool05_ooool5o`0009Go
oooo000Uooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool03oooool7o`0009[ooooo
000Foooooooo0000@?l0000Cooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?o00000_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0A
ooooo`005_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool01Oooool3o`0001gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04Oooool002Sooooo00?o0000oooooooo
ool0R_ooool01?l0003oooooooooooooool4o`000:_ooooo000Yooooo`03o`000?oooooooooo08Wo
oooo00Co0000oooooooooooo0000[oooool002Wooooo00?o0000ooooooooool0ROooool3o`000;3o
oooo000Zooooo`03o`000?oooooooooo08?ooooo1_l0002booooo`00:oooool00ol0003ooooooooo
o`1mooooo`Go00001Oooool00ol0003oooooooooo`2`ooooo`00:oooool00ol0003oooooooooo`1k
ooooo`;o00002_ooool00ol0003oooooooooo`2`ooooo`00;?ooool00ol0003oooooooooo`1/oooo
o`ko00003?ooool00ol0003oooooooooo`2`ooooo`00;Oooool00ol0003oooooooooo`1Xooooo`?o
00006_ooool2o`000;7ooooo000]ooooo`03o`000?oooooooooo063ooooo2?l0000Mooooo`03o`00
0?oooooooooo0;3ooooo000^ooooo`03o`000?oooooooooo05cooooo0ol0000Uooooo`03o`000?oo
oooooooo0;3ooooo000_ooooo`03o`000?oooooooooo05Wooooo0_l0000Xooooo`03o`000?oooooo
oooo0;3ooooo000_ooooo`03o`000?oooooooooo05Kooooo0ol0000Zooooo`03o`000?oooooooooo
0;3ooooo000`ooooo`03o`000?oooooooooo02gooooo5?l0000:ooooo`[o0000;Oooool2o`000;7o
oooo000aooooo`03o`000?oooooooooo02Wooooo0ol0000Dooooo`[o0000=oooool00ol0003ooooo
ooooo`2`ooooo`00<Oooool00ol0003oooooooooo`0Wooooo`;o0000F?ooool00ol0003ooooooooo
o`2`ooooo`00<_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05Sooooo00?o0000
ooooooooool0/?ooool003;ooooo00?o0000ooooooooool08oooool2o`0005_ooooo00?o0000oooo
ooooool0/?ooool003?ooooo00?o0000ooooooooool08?ooool2o`0005gooooo0_l0002aooooo`00
<oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0
/?ooool003?ooooo00?o0000ooooooooool07Oooool2o`0003gooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0;3ooooo000dooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
?Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo000dooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool0?_ooool01Ol@413ooooooooooooooooo410@
00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
0;3ooooo000eooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0?oooool01Ol0003o
oooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04oooo
o`?o0000/?ooool003Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`10ooooo`05
o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`ooooo`00=_ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo047ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00=oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo04;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0;3ooooo000gooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0@oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co0000
1_ooool00ol0003oooooooooo`2`ooooo`00>?ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo06Kooooo0_l0002aooooo`00>Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo06Oooooo00?o0000ooooooooool0/?ooool003[ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`1Xooooo`03o`000?oooooooooo0;3ooooo000kooooo`03o`000?oooooooooo00[o
oooo0_l0001[ooooo`03o`000?oooooooooo0;3ooooo000looooo`?o00002?ooool00ol0003ooooo
ooooo`1[ooooo`03o`000?oooooooooo0;3ooooo000oooooo`03o`000?oooooooooo00?ooooo0_l0
001^ooooo`;o0000/Oooool003oooooo1_l0001`ooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000
/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?oo
ool009[ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0
002`ooooo`00V_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol0003ooooooooooooooooo000000cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo
002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@4100
3Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
/?ooool009;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo
00?oMgMgoc8b<_ooool01?ooool3o`000;3ooooo002Booooo`05o`000?ooooooooooooooool00000
3_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003o
ooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMooo
ool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002[ooooo`Co000000?o
410@ooooooooool00oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0/?ooool00:gooooo00?o0000ooooooooool01Oooool3o`000;3ooooo002]ooooo`03o`00
0?oooooooooo0;Sooooo002]ooooo`03o`000?oooooooooo0;Sooooo002]ooooo`03o`000?oooooo
oooo0;Sooooo002[ooooo`03oeEEEOmVIVKo00000;[ooooo003oooooofWooooo002_ooooo`03o`00
0?nj^[[ooooo0;Kooooo002_ooooo`;o<S8b]oooool0083ooooo0_l000001_l@413oooooooooool@
413o0000oa0@41Oooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOo
0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool01Oo^k^ko<S8bo`000?l@413o
c<c<00?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0N?ooool0087ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00002Oooool01OnHV9So8B4Qonk^k_oo
ooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03olc<c?l0003o410@00cooooo
00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002Oooool01OmEEEGoMgMgoooooonHV9So8B4Q
00?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0N?oo
ool0087ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Gooooo`03oiRHV?lQ8B7o
k^k^00Cooooo00Go410@oooooooooooooooooa0@400Booooo`03o`000?oooooooooo01[ooooo00Go
0000ooooooooooooooooo`000004ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooo
oooooa0@401hooooo`00POooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000;oooo
o`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooo
oooo00_ooooo1_l00009ooooo`05o`000?nHV9SooooooiRHV?lQ8B401Oooool00onHV9So8B4Qonk^
kP03ooooo`05o`000?ooooooooooooooool00000N?ooool0087ooooo00Ko0000omgMgOlb<S;oEEEE
omgMgOl0000Kooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00000Boooo
o`03o`000?oooooooooo01[ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`00001hooooo`00POooool01_l0003oQhN7ojVYZOnj
^[[oEEEEo`0001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00ko
oooo00?o410@o`000?l000000ol0000Iooooo`03oeEEEOn7QhOooooo00Wooooo00Go0000oooooooo
oooooooooa0@4003ooooo`03oa0@4?oooooooooo07Kooooo0021ooooo`06o`000?lb<S;ooooooooo
oolb<S;o00006?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0Booooo`03o`000?oooooooooo01[ooooo00?ogMgMoa0@4?nHV9P01Oooool01Ol0003o^[Zj
oooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1hooooo`00P?ooool00ol@413o
0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Kooooo`04olc<c?m4A4Co
0000oa0@40?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h0N?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(630) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .26886 m
.00488 .27074 L
.00942 .27271 L
.01441 .27541 L
.01975 .27912 L
.04057 .29891 L
.08481 .3489 L
.10568 .37604 L
.11667 .38833 L
.12833 .40077 L
.13332 .40531 L
.1387 .40913 L
.14028 .40999 L
.14178 .4107 L
.14324 .41127 L
.1446 .41171 L
.14588 .41203 L
.14724 .41229 L
.14802 .41239 L
.14875 .41246 L
.15013 .41253 L
.15129 .41252 L
.15258 .41244 L
.15391 .41229 L
.15516 .4121 L
.1574 .41162 L
.15979 .41095 L
.17025 .40692 L
.18093 .40168 L
.19255 .39403 L
.2026 .38562 L
.20793 .38105 L
.21368 .37658 L
.21927 .37301 L
.22439 .37049 L
.22929 .36865 L
.23445 .36712 L
.24511 .36432 L
.25097 .36278 L
.2565 .36148 L
.25903 .361 L
.26171 .36061 L
.26311 .36046 L
.26386 .36039 L
.26465 .36034 L
.26539 .3603 L
.26605 .36027 L
.26736 .36025 L
.26862 .36025 L
.26979 .36029 L
Mistroke
.27106 .36036 L
.27243 .36046 L
.27495 .36072 L
.27723 .36102 L
.28201 .36172 L
.28452 .36207 L
.28717 .36238 L
.28829 .36249 L
.28949 .36258 L
.29081 .36266 L
.29204 .36271 L
.29324 .36273 L
.29438 .36273 L
.29541 .36271 L
.29652 .36267 L
.2978 .3626 L
.29898 .36251 L
.30162 .36225 L
.30641 .36163 L
.31732 .3602 L
.32286 .35972 L
.32876 .35929 L
.33163 .35903 L
.33434 .35872 L
.33676 .35836 L
.33939 .35788 L
.34443 .35663 L
.34976 .35494 L
.3593 .35161 L
.3643 .35014 L
.36706 .3495 L
.36967 .34901 L
.37275 .34856 L
.37555 .34826 L
.37819 .34805 L
.38105 .34785 L
.38579 .34752 L
.38846 .34728 L
.39091 .34701 L
.39652 .34618 L
.40179 .3452 L
.40735 .34418 L
.41006 .34376 L
.41253 .34344 L
.41514 .34318 L
.41657 .34308 L
.41793 .34301 L
.41864 .34298 L
.4194 .34296 L
.42076 .34293 L
Mistroke
.42152 .34292 L
.42223 .34292 L
.42301 .34292 L
.42384 .34292 L
.42456 .34293 L
.42524 .34294 L
.42651 .34296 L
.42799 .34298 L
.42935 .34299 L
.43054 .343 L
.43181 .34299 L
.43307 .34297 L
.43379 .34295 L
.43446 .34292 L
.43518 .34289 L
.43596 .34284 L
.43739 .34274 L
.43877 .3426 L
.44005 .34244 L
.44296 .34196 L
.44605 .34129 L
.45608 .33822 L
.46715 .33463 L
.47789 .33181 L
.48919 .32842 L
.49883 .32431 L
.50938 .31942 L
.51462 .31742 L
.51957 .31596 L
.52526 .31475 L
.53044 .31392 L
.55002 .30997 L
.5553 .30865 L
.56024 .30757 L
.56293 .3071 L
.56539 .30676 L
.56812 .30647 L
.56963 .30635 L
.57105 .30626 L
.5763 .30604 L
.57887 .30595 L
.58123 .30584 L
.58338 .3057 L
.58565 .30549 L
.58794 .30521 L
.59043 .3048 L
.59566 .30361 L
.60054 .30215 L
.61129 .29847 L
.63061 .29241 L
Mistroke
.64163 .28758 L
.65204 .28141 L
.67154 .27071 L
.69073 .26193 L
.70164 .25577 L
.70698 .25292 L
.71186 .25068 L
.717 .24884 L
.72189 .24752 L
.73268 .24526 L
.74324 .2424 L
.74917 .2404 L
.75476 .2386 L
.75729 .2379 L
.75996 .23729 L
.76136 .23702 L
.76289 .23677 L
.7643 .23659 L
.76559 .23645 L
.76685 .23636 L
.76804 .23629 L
.7693 .23625 L
.77067 .23623 L
.77186 .23623 L
.77313 .23625 L
.77421 .23627 L
.77541 .23631 L
.77807 .2364 L
.77952 .23645 L
.78087 .23648 L
.78158 .23649 L
.78234 .23649 L
.78318 .23649 L
.78394 .23648 L
.78464 .23647 L
.78539 .23645 L
.78676 .23639 L
.78805 .23631 L
.78946 .23619 L
.79231 .23587 L
.79743 .23508 L
.8029 .23414 L
.80559 .23374 L
.8069 .23359 L
.80809 .23347 L
.80925 .23338 L
.81035 .23332 L
.8115 .23328 L
.81275 .23327 L
.81404 .23329 L
Mistroke
.8154 .23335 L
.81656 .23343 L
.81784 .23355 L
.82373 .23441 L
.82931 .2354 L
.83175 .23578 L
.83433 .2361 L
.83567 .23622 L
.83639 .23627 L
.83715 .23632 L
.8385 .23637 L
.83977 .23639 L
.84106 .23638 L
.84226 .23635 L
.84358 .23628 L
.84499 .23618 L
.84787 .23591 L
.85048 .23562 L
.8529 .23535 L
.85418 .23522 L
.85553 .23511 L
.85671 .23503 L
.858 .23496 L
.85918 .23493 L
.86029 .23492 L
.86165 .23495 L
.86242 .23499 L
.86313 .23503 L
.86444 .23514 L
.86583 .2353 L
.86823 .23567 L
.87088 .2362 L
.87642 .23759 L
.88226 .23906 L
.8847 .23956 L
.8873 .23997 L
.8888 .24015 L
.89017 .24027 L
.89154 .24035 L
.89283 .24039 L
.89401 .2404 L
.89525 .24038 L
.89631 .24035 L
.89749 .2403 L
.90009 .24015 L
.90254 .23999 L
.90389 .23992 L
.9046 .23988 L
.90536 .23985 L
.90609 .23982 L
Mistroke
.90675 .2398 L
.90804 .23979 L
.90929 .23981 L
.91064 .23986 L
.91191 .23995 L
.91308 .24007 L
.91444 .24025 L
.91571 .24046 L
.9186 .24108 L
.92442 .24287 L
.92968 .24479 L
.9354 .24675 L
.93802 .24749 L
.9408 .24813 L
.94318 .24856 L
.9458 .24891 L
.95075 .24935 L
.95345 .24955 L
.95597 .24978 L
.95812 .25004 L
.96042 .25042 L
.96297 .25098 L
.96529 .25165 L
.96941 .25321 L
.97388 .2554 L
.98199 .2601 L
1 .26886 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000GOooool9o`0004[ooooo002Booooo`05o`000?oo
ooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`1?ooooo`ko00002OoooolAo`0003Wooooo002Booooo`05oa0@
4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0Boooool4o`0002Sooooo2ol0000^ooooo`00T_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0BOooool2o`0003Oooooo1?l0000Zooooo`00T_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2
o`0004Oooooo0ol0000mooooo`;o0000:?ooool00;Gooooo00?o0000ooooooooool0@Oooool5o`00
04;ooooo2?l0000Pooooo`00]Oooool00ol0003oooooooooo`0nooooo`?o0000Coooool4o`0001co
oooo002eooooo`03o`000?oooooooooo03cooooo0_l0001Fooooo`03o`000?oooooooooo01Wooooo
002eooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0Eoooool00ol0003ooooooooo
o`0Hooooo`00]Oooool2o`0003[ooooo0_l0001Kooooo`?o00005oooool00;Gooooo00?o0000oooo
ooooool0=_ooool3o`00063ooooo0ol0000Dooooo`005Oooool2o`000009oa0@4?oooooooooooooo
ooo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h06oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Loooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQkooooo00?o0000ooooooooool0
7oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h9ooooo`;o00003oooool5
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05oiRHV?l@413o0000oc8b<_o<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo0_l000002Ol@413oooooooooool0003ok^k^
oc8b<_l0003o<S8bonk^kP0>ooooo`005_ooool3o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Jooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`;o0000
4Oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Koooo
o`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko00000_oo
ool5o`000004ooooool0003o0000oa0@40?ooooo00?o410@ooooooooool04?ooool6o`0000Kooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo017ooooo1_l00003ooooo`03
oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400Cooooo`Ko00001Oooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41007_ooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4005ooooo`;o00005?oo
ool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41007oooool01Ol0003ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool06Oooool5o`0000?ooooo00Go410@oooooooo
oooooooooa0@400>ooooo`004oooool01?m4A4CogMgMooooool00004ooooo`05o`000?oooooooooo
ooooool000007Oooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000007Ooo
ool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000007_ooool2o`0002;ooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000?ooooo0_l0000Gooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03ojVYZOl@413ooooo00;ooooo00Go0000
ooooooooooooooooo`00000Kooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`004oooool01?oMgMgoEEEEooooool00004ooooo`?o000000?oooooo`000?oo
ool06oooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000007_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo00;ooooo00Ko0000ooooooooooooooooo`000?ooool2o`0001[ooooo00?oMgMgofIVI_oo
ool00_ooool01Ol0003ooooooooooooooooo000001gooooo00?o410@o`000?nj^[X00oooool01Ol0
003ooooooooooooooooo000001_ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooo
oooooooo000000kooooo000Dooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooo0000
oa0@400Mooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@400Oooooo`05
o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Looooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@400Nooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool00_ooool01_l@413ooooooooooooooooo410@o`0001gooooo00Go0000oooooooooooo
oooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413o
oooooooooooooooo410@01cooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo
410@00kooooo000Dooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHo`00000J
ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo
00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo00;ooooo00?oMgMgoiRHV?ooool00_l0000Jooooo`05o`000?nj^[[o
oooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@oiRHV?oooooo
^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07?ooool00oo^k^koA4A4o`000004oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool001Gooooo00?oMgMgo`000?ooool00oooool01_o^
k^ko<S8bo`000?lb<S;ok^k^o`0001Wooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h06oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Looooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0Nooooo`03o`000?oooooooooo01oooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko0000o`00
0?lb<S;ok^k^01[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h06oooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0Mooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`008Ooo
ool00ol0003oooooooooo`2Aooooo`;o00009_ooool2o`0008Wooooo000Rooooo`03o`000?oooooo
oooo093ooooo00?o0000ooooooooool08_ooool3o`0008_ooooo000Sooooo`03o`000?oooooooooo
08oooooo00?o0000ooooooooool07oooool3o`0008kooooo000Sooooo`03o`000?oooooooooo08oo
oooo00?o0000ooooooooool06oooool4o`00097ooooo000Tooooo`03o`000?oooooooooo08kooooo
00?o0000ooooooooool04_ooool9o`0009Gooooo000Foooooooo0000@?l0000Cooooo`005_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
1?l0003oooooooooooooool3o`000003ooooool0003ooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo000Fooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`03ooooo`Ko00007?ooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0Aooooo`00:?ooool00ol0003oooooooooo`2:ooooo`03o`000?oooooo0000
00?o0000[Oooool002Wooooo00?o0000ooooooooool0ROooool2o`000;7ooooo000Zooooo`03o`00
0?oooooooooo08Kooooo1?l0002aooooo`00:_ooool00ol0003oooooooooo`23ooooo`?o00000_oo
ool00ol0003oooooooooo`2`ooooo`00:oooool00ol0003oooooooooo`1nooooo`Co00001Oooool0
0ol0003oooooooooo`2`ooooo`00;?ooool00ol0003oooooooooo`1jooooo`?o00002Oooool00ol0
003oooooooooo`2`ooooo`00;Oooool00ol0003oooooooooo`1fooooo`?o00003?ooool00ol0003o
ooooooooo`2`ooooo`00;_ooool00ol0003oooooooooo`1cooooo`;o00003oooool2o`000;7ooooo
000_ooooo`03o`000?oooooooooo06Gooooo3Ol0000Aooooo`03o`000?oooooooooo0;3ooooo000`
ooooo`03o`000?oooooooooo05cooooo2?l0000Nooooo`03o`000?oooooooooo0;3ooooo000aoooo
o`03o`000?oooooooooo05Gooooo1_l0000Vooooo`03o`000?oooooooooo0;3ooooo000aooooo`03
o`000?oooooooooo05?ooooo0_l0000/ooooo`03o`000?oooooooooo0;3ooooo000booooo`03o`00
0?oooooooooo04kooooo1?l0000^ooooo`;o0000/Oooool003?ooooo00?o0000ooooooooool0=?oo
ool3o`0000cooooo2_l0000booooo`03o`000?oooooooooo0;3ooooo000dooooo`03o`000?oooooo
oooo02kooooo1Ol00002ooooo`go0000??ooool00ol0003oooooooooo`2`ooooo`00=?ooool00ol0
003oooooooooo`0[ooooo`?o0000D?ooool00ol0003oooooooooo`2`ooooo`00=Oooool00ol0003o
ooooooooo`0Vooooo`Co0000Doooool00ol0003oooooooooo`2`ooooo`00=_ooool00ol0003ooooo
ooooo`0Sooooo`;o0000Eoooool2o`000;7ooooo000gooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool0Eoooool00ol0003oooooooooo`2`ooooo`00>?ooool00ol0003oooooooooo`0N
ooooo`;o0000=oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool003Wooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0gooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0/?ooool003[ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0hooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool003_ooooo00?o0000ooooooooool0
5oooool2o`0003_ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo00?oMgMgoc8b<_ooool01?ooool3o`000;3ooooo000looooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool0>oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_oo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool003go
oooo00?o0000ooooooooool04_ooool2o`0003kooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`oooo
o`00?_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03kooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0;3ooooo000oooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0?oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c004ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00?oooool00ol0003oooooooooo`0<
ooooo`;o0000IOooool2o`000;7ooooo0010ooooo`;o00002Oooool3o`0006Oooooo00?o0000oooo
ooooool0/?ooool004;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Xooooo`03
o`000?oooooooooo0;3ooooo0013ooooo`Oo0000Joooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00?ooooo0ol0002`ooooo`00V_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol0003ooooooooooooooooo
000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?oo
ool4o`0000Kooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^ko
oooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002B
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0/?ooool009;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooo
oooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`000;3ooooo002Booooo`05o`000?oooooo
ooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo
00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo
002Booooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002[
ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0/?ooool00:gooooo00?o0000ooooooooool01Oooool3o`000;3ooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002]ooooo`03o`000?oooooooooo0;Sooooo002]oooo
o`03o`000?oooooooooo0;Sooooo002[ooooo`03oeEEEOmVIVKo00000;[ooooo003oooooofWooooo
002_ooooo`03o`000?nj^[[ooooo0;Kooooo002_ooooo`;o<S8b]oooool0083ooooo0_l000001_l@
413oooooooooool@413o0000oa0@41Oooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool01Oo^k^ko
<S8bo`000?l@413oc<c<00?ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h0N?ooool0087ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07
ooooo`Ko00002Oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`03olc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko
00002Oooool01OmEEEGoMgMgoooooonHV9So8B4Q00?ooooo00Go410@okZj^_ooooooMgMgoc8b<P03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0N?ooool0087ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
400Booooo`03o`000?oooooooooo01[ooooo00Go0000ooooooooooooooooo`000007ooooo`05o`00
0?ooooooooooooooool@41000oooool00ol@413oooooooooo`1fooooo`00POooool01_l0003ooooo
odA4A?m4A4Coooooo`0000Wooooo1_l0000;ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`00000Booooo`03o`000?oooooooooo00_ooooo1_l00009ooooo`05o`000?nHV9So
oooooiRHV?lQ8B401_ooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool00000
N?ooool0087ooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Kooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo01[ooooo00Go0000oeEE
EOl0003o410@olc<c005ooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00
001hooooo`00POooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001cooooo00Go0000oooooooooooo
oooooa0@4003ooooo`03oa0@4?oooooooooo00kooooo00?o410@o`000?l000000ol0000Iooooo`03
oeEEEOn7QhOooooo00Sooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@
07Sooooo0021ooooo`06o`000?lb<S;ooooooooooolb<S;o00006?ooool01Ol0003o^[ZjoooooonH
V9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Booooo`03o`000?oooooooooo01[ooooo
00?ogMgMoa0@4?nHV9P01Oooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`1hooooo`00P?ooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Oo
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool0
0ol0003oooooooooo`0Kooooo`04olc<c?m4A4Co0000oa0@40?ooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0N?ooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(640) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .2741 m
.04057 .29986 L
.08481 .3382 L
.10632 .35949 L
.11681 .37257 L
.12636 .38383 L
.13112 .3885 L
.13628 .3927 L
.14567 .39837 L
.15088 .40081 L
.1564 .40304 L
.15906 .40398 L
.16158 .40477 L
.16404 .40541 L
.16632 .40587 L
.16752 .40605 L
.16861 .40617 L
.16986 .40627 L
.17104 .4063 L
.17233 .40629 L
.17352 .40621 L
.17482 .40606 L
.1762 .40583 L
.17746 .40555 L
.17882 .40517 L
.18127 .40431 L
.18683 .40158 L
.20605 .38949 L
.21673 .3846 L
.22835 .38006 L
.23839 .37574 L
.24372 .37357 L
.24653 .37258 L
.24947 .37171 L
.25214 .37109 L
.25355 .37082 L
.25506 .37059 L
.25645 .37043 L
.25771 .37031 L
.25898 .37023 L
.26018 .37018 L
.2614 .37015 L
.26269 .37014 L
.2638 .37014 L
.26501 .37016 L
.26631 .37018 L
.26771 .37021 L
.26893 .37023 L
.27024 .37025 L
.27101 .37026 L
Mistroke
.27171 .37026 L
.27307 .37024 L
.27383 .37023 L
.27466 .3702 L
.27543 .37017 L
.27615 .37012 L
.27745 .37003 L
.27888 .36989 L
.28176 .36951 L
.2844 .36903 L
.28721 .36841 L
.2923 .36711 L
.31314 .36293 L
.33578 .35827 L
.34634 .35475 L
.34891 .35405 L
.35168 .35342 L
.35326 .35313 L
.35471 .35291 L
.35609 .35273 L
.35755 .35259 L
.35883 .3525 L
.35998 .35243 L
.36114 .35239 L
.36224 .35237 L
.36352 .35236 L
.3647 .35237 L
.36599 .35239 L
.36736 .35241 L
.36973 .35247 L
.37104 .35249 L
.37227 .35251 L
.37297 .35252 L
.37373 .35252 L
.37506 .35252 L
.37642 .35249 L
.37767 .35245 L
.3789 .3524 L
.3802 .35232 L
.38253 .35214 L
.38503 .35189 L
.38776 .35156 L
.39273 .3509 L
.39725 .35036 L
.39858 .35023 L
.40003 .35011 L
.40128 .35002 L
.40266 .34994 L
.40412 .34988 L
.40492 .34985 L
Mistroke
.40567 .34984 L
.407 .34982 L
.40775 .34981 L
.40844 .34981 L
.40969 .34981 L
.41104 .34982 L
.41223 .34983 L
.41349 .34984 L
.41419 .34985 L
.41496 .34985 L
.41631 .34984 L
.41763 .34982 L
.41887 .34979 L
.42021 .34973 L
.42148 .34964 L
.42262 .34954 L
.42386 .34941 L
.42664 .34899 L
.42922 .34846 L
.43387 .34714 L
.43882 .34533 L
.46058 .33691 L
.48128 .32954 L
.49034 .3254 L
.49513 .32335 L
.50024 .32154 L
.50293 .32078 L
.50537 .32022 L
.50786 .31976 L
.51015 .31943 L
.51272 .31914 L
.51551 .31888 L
.52057 .31847 L
.52564 .31795 L
.52852 .31757 L
.53121 .31714 L
.54248 .31496 L
.562 .31283 L
.56475 .31265 L
.56734 .31242 L
.56878 .31226 L
.57033 .31205 L
.57303 .31157 L
.57563 .31097 L
.57837 .31018 L
.58326 .30837 L
.60551 .29761 L
.62662 .28681 L
.66657 .26226 L
.68883 .25105 L
Mistroke
.69394 .2485 L
.69936 .24629 L
.70399 .2449 L
.70662 .24431 L
.70909 .24385 L
.71918 .24247 L
.72445 .2416 L
.73013 .24032 L
.73512 .23898 L
.74044 .23755 L
.74303 .23693 L
.74546 .23644 L
.74765 .23608 L
.74888 .23592 L
.75002 .2358 L
.7513 .23569 L
.75198 .23565 L
.75271 .23562 L
.75347 .23559 L
.75419 .23557 L
.75554 .23557 L
.75681 .23559 L
.75798 .23563 L
.75926 .23569 L
.76062 .23577 L
.7635 .23598 L
.76659 .2362 L
.76802 .23628 L
.7688 .23632 L
.76952 .23636 L
.7708 .2364 L
.77148 .23641 L
.7722 .23642 L
.7735 .23642 L
.77423 .2364 L
.7749 .23638 L
.77614 .23633 L
.77745 .23625 L
.77973 .23606 L
.78223 .23577 L
.7879 .23498 L
.7907 .2346 L
.79206 .23444 L
.79329 .23432 L
.79448 .23421 L
.79576 .23413 L
.79712 .23407 L
.79839 .23405 L
.79907 .23405 L
.7998 .23406 L
Mistroke
.80057 .23408 L
.80129 .23411 L
.80258 .23419 L
.80396 .23431 L
.80658 .23462 L
.80906 .235 L
.8137 .23583 L
.8188 .23666 L
.82138 .23698 L
.82284 .23711 L
.82421 .23719 L
.82494 .23723 L
.82571 .23725 L
.82707 .23727 L
.82784 .23726 L
.82854 .23725 L
.82932 .23722 L
.83015 .23719 L
.83163 .2371 L
.83303 .23699 L
.83564 .23675 L
.83819 .23649 L
.84092 .23623 L
.84225 .23613 L
.84351 .23605 L
.84464 .23601 L
.84587 .23598 L
.84716 .23598 L
.84854 .23602 L
.84972 .23608 L
.85102 .23619 L
.85242 .23634 L
.85394 .23655 L
.85668 .23705 L
.86672 .23949 L
.86924 .24007 L
.87162 .24054 L
.87375 .24088 L
.87607 .24115 L
.87729 .24125 L
.87859 .24132 L
.87969 .24137 L
.88091 .24139 L
.8822 .24139 L
.88359 .24137 L
.8849 .24133 L
.8861 .24129 L
.88879 .24118 L
.88953 .24115 L
.89031 .24113 L
Mistroke
.89105 .24111 L
.89173 .2411 L
.89305 .24109 L
.8938 .24109 L
.89448 .24111 L
.89574 .24116 L
.89708 .24124 L
.89845 .24137 L
.89971 .24152 L
.90254 .24201 L
.90515 .24263 L
.90763 .24335 L
.91922 .24752 L
.92445 .24914 L
.92936 .25022 L
.93182 .2506 L
.93448 .25092 L
.94013 .25147 L
.94268 .25177 L
.94505 .25212 L
.94752 .25261 L
.95022 .2533 L
.95469 .25486 L
.95947 .25706 L
1 .2741 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000FOooool6o`00057ooooo002Booooo`05o`000?oo
ooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`19oooooa7o00001OoooolBo`0003oooooo002Booooo`05oa0@
4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0AOooool4o`0002Sooooo1?l0000kooooo`00T_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0?oooool6o`00033ooooo3?l0000_ooooo`00T_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2
o`0003gooooo1?l00011ooooo`03o`000?oooooooooo02cooooo002eooooo`03o`000?oooooooooo
03[ooooo0_l00016ooooo`Go0000:Oooool00;Gooooo00?o0000ooooooooool0>?ooool2o`0004co
oooo2?l0000Rooooo`00]Oooool00ol0003oooooooooo`0eooooo`?o0000E_ooool00ol0003ooooo
ooooo`0Oooooo`00]Oooool00ol0003oooooooooo`0cooooo`;o0000F_ooool2o`0001oooooo002e
ooooo`;o0000<_ooool2o`0005kooooo0ol0000Looooo`00]Oooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo067ooooo0ol0000Iooooo`005Oooool2o`000009oa0@4?oooooooooooooo
ooo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h06oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Loooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQkooooo00?o0000ooooooooool0
7oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`;o00005Oooool5
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05oiRHV?l@413o0000oc8b<_o<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo0_l000002Ol@413oooooooooooooooook^k^
oc8b<_l0003o<S8bonk^kP0>ooooo`005_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL06_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Kooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9So
MgMg01kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`06ogMgMonHV9SooooooiRHV?mgMgOo
oooo0_l0000Gooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9So
MgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
7_ooool4o`000006oooooomgMgOoV9RHoooooonHV9SoMgMg3_ooool000_ooooo1_l00002ooooo`Go
00000oooool01Ol@413ooooooooooooooooo410@01;ooooo1_l00006ooooo`05o`000?oooooooooo
ooooool@41000oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04
ooooo`05oa0@4?ooooooooooooooool@41004oooool6o`0000Gooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@01kooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`02ooooo`06oa0@4?ooooooooooooooool@413o00006_ooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41007oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o
410@ooooooooool06Oooool5o`0000;ooooo00?o0000oa0@4?ooool00_ooool00ol@413ooooooooo
o`0<ooooo`004oooool01_m4A4CogMgMooooool0003oooooo`0000;ooooo00Go0000oooooooooooo
ooooo`00000Mooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Moooo
o`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`00000Nooooo`;o00008_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;o00007?ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oo
ooooooooooooool000007_ooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool0
00006oooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool0
01?ooooo00CogMgMoeEEEOoooooo00000_ooool3o`0000?ooooo00?o0000ooooooooool06_ooool0
0ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000007_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;o
oooo0ol000000ooooooo0000ooooo`0Looooo`03ogMgMomVIVKooooo00;ooooo00Go0000oooooooo
ooooooooo`00000Mooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00000K
ooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`005?oo
ool00omgMgOoc<c<o`000004ooooo`;o00000_ooool00ol@413oooooooooo`0Kooooo`03okZj^_lQ
8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@400Oooooo`05o`000?ooooooooooooooool@
41000oooool00ol@413oooooooooo`0Looooo`03o`000?oooooooooo00;ooooo00Go410@oooooooo
oooooooooa0@400Nooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo410@01kooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oo
oooooooo01cooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@01cooooo
00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00kooooo000Dooooo`03onk^
k_m4A4Co000000Cooooo00GoMgMgoiRHV?l0003oV9RHogMgM`0Jooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL07_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;o
000000GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL07?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03_ooool001Gooooo00?oMgMgo`000?ooool00oooool00oo^k^ko<S8bo`000002o`0001[o
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Looooo`03oeEE
EOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Nooooo`03o`000?oooooooooo01oo
oooo00?oEEEEofIVI_l000000_l00002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06_ooool01OnH
V9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@
413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo00?oMgMgo`000?oo
ool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Pooooo`;o0000Toooool2o`0002;o
oooo00?o0000ooooooooool0S?ooool002;ooooo00?o0000ooooooooool0T?ooool00ol0003ooooo
ooooo`0Oooooo`;o0000Soooool002?ooooo0_l0002@ooooo`03o`000?oooooooooo01gooooo0_l0
002Aooooo`009Oooool00ol0003oooooooooo`2=ooooo`03o`000?oooooooooo01[ooooo0ol0002C
ooooo`009_ooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo01Sooooo0_l0002Foooo
o`005_ooooooo`00043o00004oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool:o`0000Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`005_ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool02Oooool5o`0001Oooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool04Oooool002[ooooo0_l00029ooooo`03o`000?oooooooooo00Wo0000Yoooool0
02cooooo00?o0000ooooooooool0QOooool4o`000;3ooooo000]ooooo`03o`000?oooooooooo087o
oooo0ol000000ooooooo0000o`00002aooooo`00;_ooool00ol0003oooooooooo`1oooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0/?ooool002oooooo00?o0000ooooooooool0Nooo
ool3o`0000Gooooo00?o0000ooooooooool0/?ooool0033ooooo00?o0000ooooooooool0Moooool3
o`0000Sooooo00?o0000ooooooooool0/?ooool0037ooooo00?o0000ooooooooool0Loooool3o`00
00_ooooo00?o0000ooooooooool0/?ooool003;ooooo00?o0000ooooooooool0Koooool3o`0000ko
oooo0_l0002aooooo`00<oooool00ol0003oooooooooo`1/ooooo`;o00004Oooool00ol0003ooooo
ooooo`2`ooooo`00=?ooool00ol0003oooooooooo`1Xooooo`?o00004oooool00ol0003ooooooooo
o`2`ooooo`00=Oooool00ol0003oooooooooo`1Jooooo`go00005_ooool00ol0003oooooooooo`2`
ooooo`00=_ooool00ol0003oooooooooo`1<ooooo`go00008oooool00ol0003oooooooooo`2`oooo
o`00=oooool00ol0003oooooooooo`19ooooo`;o0000<?ooool2o`000;7ooooo000hooooo`03o`00
0?oooooooooo04;ooooo1_l0000booooo`03o`000?oooooooooo0;3ooooo000hooooo`03o`000?oo
oooooooo03gooooo1Ol0000hooooo`03o`000?oooooooooo0;3ooooo000iooooo`03o`000?oooooo
oooo03Wooooo0ol0000mooooo`03o`000?oooooooooo0;3ooooo000jooooo`03o`000?oooooooooo
03;ooooo1_l00010ooooo`03o`000?oooooooooo0;3ooooo000kooooo`03o`000?oooooooooo02Ko
oooo2ol00016ooooo`;o0000/Oooool003_ooooo00?o0000ooooooooool08oooool3o`00057ooooo
00?o0000ooooooooool0/?ooool003cooooo00?o0000ooooooooool08?ooool2o`00037ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo000mooooo`03o`000?oooooooooo01gooooo
0_l0000cooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool003ko
oooo00?o0000ooooooooool06Oooool3o`0003Gooooo00Go410@oooooooooooooooooa0@400<oooo
o`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2`oooo
o`00?oooool00ol0003oooooooooo`0Fooooo`;o0000>?ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool0043o
oooo00?o0000ooooooooool04oooool2o`0003[ooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo0;3ooooo0011ooooo`;o00004_ooool00ol0003oooooooooo`0jooooo`05oa0@4?oooooooooo
ooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0/?ooool004?ooooo00?o0000ooooooooool03Oooool2o`0003gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0;3ooooo0014ooooo`?o00002oooool00ol0003oooooooooo`0m
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo
1?l00006ooooo`03o`000?oooooooooo0;3ooooo0017ooooo`;o00001_ooool3o`0006?ooooo0_l0
002aooooo`00BOooool7o`0006Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000
/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
09[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`?o0000/?oo
ool009[ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0/?ooool009[ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooo
oooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00V_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000
/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool009;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00gooooo
00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo
002Booooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMg
Molb<S;ooooo00Cooooo0ol0002`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000kooooo
00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool0/?ooool009;ooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0/?ooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Zoooool4o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool0/?ooool00:gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo0ol0002`ooooo`00[Oooool00ol0003ooooo
ooooo`2hooooo`00[Oooool00ol0003oooooooooo`2hooooo`00[Oooool00ol0003oooooooooo`2h
ooooo`00Zoooool00omEEEGoIVIVo`00002jooooo`00oooooomYooooo`00[oooool00ol0003o^[Zj
ooooo`2fooooo`00[oooool2oc8b<[Oooooo0020ooooo`;o000000Ko410@oooooooooooo410@o`00
0?l@410Gooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?oQhN7o`000?nj
^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo00Gok^k^oc8b<_l0003o410@olc<c005
ooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h0N?ooool0087ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00002Oooool01OnHV9So8B4Q
onk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03olc<c?l0003o410@
00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002Oooool01OmEEEGoMgMgoooooonH
V9So8B4Q00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg07Sooooo
0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@41004_ooool00ol0003oooooooooo`0Jooooo`05o`00
0?ooooooooooooooool000000oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@401hoooo
o`00POooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000;ooooo`03oiRHV?lQ8B7o
k^k^00?ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo00_ooooo1_l0
0009ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01?m4A4CogMgMooooool00004ooooo`05
o`000?ooooooooooooooool00000N?ooool0087ooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000K
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oo
oooooooo01[ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`04omgMgOmEEEGoooooo`0000Co
oooo00Go0000ooooooooooooooooo`00001hooooo`00POooool01_l0003oQhN7ojVYZOnj^[[oEEEE
o`0001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00kooooo00?o
410@o`000?l000000ol0000Iooooo`03oeEEEOn7QhOooooo00Kooooo00?oMgMgolc<c?l000001?oo
ool01Ol@413ooooooooooooooooo410@07Sooooo0021ooooo`06o`000?lb<S;ooooooooooolb<S;o
00006?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0B
ooooo`03o`000?oooooooooo01[ooooo00?ogMgMoa0@4?nHV9P01_ooool00oo^k^koA4A4o`000004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0N?ooool0083ooooo00?o410@o`000?n7QhL00_ooool0
0on7QhOo0000oa0@400Gooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^01;ooooo00?o0000ooooooooool06oooool01?o<c<coA4A4o`000?l@4105ooooo`03
ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1hooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(650) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .28093 m
.01975 .29066 L
.02981 .29381 L
.03534 .29589 L
.04057 .29848 L
.04629 .30208 L
.0515 .30586 L
.06168 .31347 L
.07291 .32078 L
.08481 .32873 L
.09479 .33783 L
.10578 .35008 L
.12514 .36905 L
.14552 .38497 L
.15139 .3894 L
.15697 .393 L
.1594 .39428 L
.16198 .3954 L
.16347 .39593 L
.16481 .39633 L
.16617 .39666 L
.16745 .39691 L
.16862 .39708 L
.16989 .39721 L
.1706 .39726 L
.17129 .39729 L
.17256 .39731 L
.17391 .39728 L
.17515 .39721 L
.17652 .39709 L
.17797 .39693 L
.18765 .39542 L
.19817 .39419 L
.2037 .39372 L
.20648 .39342 L
.20952 .39301 L
.21219 .39253 L
.21504 .3919 L
.22018 .39043 L
.22996 .38707 L
.23513 .38548 L
.23767 .38485 L
.24002 .38436 L
.2421 .384 L
.2444 .38369 L
.24671 .38345 L
.24915 .38324 L
.25177 .38305 L
.25463 .38282 L
.25732 .38254 L
Mistroke
.25982 .3822 L
.2623 .38175 L
.26455 .38123 L
.26957 .37971 L
.29151 .37107 L
.31346 .36557 L
.32309 .36216 L
.32818 .36026 L
.33098 .35932 L
.33363 .35856 L
.3362 .35796 L
.33755 .35771 L
.33898 .3575 L
.34018 .35735 L
.34151 .35724 L
.34271 .35717 L
.34384 .35714 L
.34501 .35713 L
.34623 .35716 L
.34728 .3572 L
.34842 .35727 L
.35098 .35748 L
.35336 .35772 L
.35585 .358 L
.35854 .35827 L
.35978 .35838 L
.36108 .35847 L
.36221 .35854 L
.36343 .3586 L
.36481 .35864 L
.36611 .35865 L
.3669 .35865 L
.36765 .35864 L
.36832 .35862 L
.36906 .35859 L
.37034 .35853 L
.37171 .35844 L
.37417 .35825 L
.39482 .35693 L
.39707 .35694 L
.39817 .35695 L
.39919 .35696 L
.40037 .35696 L
.40164 .35694 L
.40272 .35692 L
.40387 .35688 L
.40513 .35681 L
.40631 .35673 L
.4076 .3566 L
.409 .35643 L
Mistroke
.41149 .356 L
.41377 .35547 L
.41884 .35381 L
.42365 .35172 L
.43406 .34642 L
.45595 .33799 L
.46679 .33407 L
.477 .32981 L
.48146 .32814 L
.48617 .32677 L
.48863 .32624 L
.48993 .32602 L
.49133 .32583 L
.49261 .32569 L
.49378 .3256 L
.49496 .32553 L
.49608 .32548 L
.49726 .32546 L
.49857 .32546 L
.49994 .32548 L
.50122 .32551 L
.50598 .32569 L
.5073 .32573 L
.50868 .32576 L
.50987 .32578 L
.51116 .32577 L
.5119 .32577 L
.51256 .32575 L
.51333 .32573 L
.51406 .3257 L
.51535 .32563 L
.51675 .32552 L
.5194 .32526 L
.52232 .32486 L
.52821 .32383 L
.53877 .32194 L
.54379 .32119 L
.54926 .32037 L
.55176 .31992 L
.55442 .31935 L
.55921 .31799 L
.56231 .31682 L
.56523 .3155 L
.57068 .31247 L
.58115 .30535 L
.62171 .27699 L
.63165 .26919 L
.64229 .26263 L
.65396 .25753 L
.66483 .25283 L
Mistroke
.67601 .24741 L
.68151 .24507 L
.68392 .24421 L
.68658 .2434 L
.6888 .24284 L
.69119 .24236 L
.69371 .24197 L
.69607 .2417 L
.69883 .24145 L
.70145 .24126 L
.70637 .24086 L
.70909 .24057 L
.71165 .24022 L
.71643 .23936 L
.72202 .2381 L
.72716 .23692 L
.73167 .23609 L
.73394 .23579 L
.73523 .23567 L
.73643 .23558 L
.73773 .23551 L
.73896 .23549 L
.74007 .23548 L
.74127 .2355 L
.74258 .23556 L
.74324 .23559 L
.74397 .23564 L
.74646 .23584 L
.75162 .23635 L
.75443 .23661 L
.75581 .23671 L
.75705 .23678 L
.75821 .23683 L
.7593 .23685 L
.76044 .23686 L
.76169 .23684 L
.76297 .2368 L
.76433 .23672 L
.76549 .23664 L
.76677 .23652 L
.77263 .23577 L
.77553 .23535 L
.77821 .235 L
.78063 .23476 L
.78198 .23465 L
.78321 .23459 L
.78456 .23455 L
.78532 .23454 L
.78602 .23455 L
.7873 .23458 L
Mistroke
.78866 .23465 L
.78994 .23475 L
.79109 .23487 L
.7937 .23521 L
.7984 .23602 L
.80395 .23704 L
.80638 .23742 L
.80777 .2376 L
.80907 .23773 L
.81033 .23784 L
.81169 .23792 L
.8124 .23795 L
.81314 .23797 L
.81447 .23799 L
.81518 .23798 L
.81593 .23796 L
.81728 .23792 L
.8181 .23787 L
.81888 .23782 L
.82034 .23772 L
.82542 .23725 L
.82812 .23702 L
.82889 .23697 L
.82963 .23693 L
.83101 .23687 L
.83232 .23684 L
.83354 .23684 L
.83487 .23687 L
.83555 .2369 L
.83629 .23695 L
.83752 .23705 L
.83884 .2372 L
.84123 .23755 L
.84398 .23809 L
.84687 .23878 L
.85205 .24015 L
.85652 .24125 L
.85898 .24176 L
.8613 .24214 L
.86262 .24232 L
.86405 .24247 L
.86535 .24258 L
.86655 .24265 L
.86768 .2427 L
.86892 .24274 L
.87022 .24275 L
.87144 .24276 L
.87275 .24275 L
.87348 .24275 L
.87414 .24274 L
Mistroke
.87543 .24273 L
.87665 .24273 L
.87734 .24273 L
.87807 .24274 L
.87938 .24276 L
.88011 .24279 L
.88079 .24282 L
.88153 .24286 L
.88234 .24292 L
.88368 .24304 L
.88496 .24319 L
.88734 .24358 L
.89013 .24419 L
.8927 .24491 L
.91216 .25174 L
.95339 .26348 L
.97247 .2706 L
.9777 .27176 L
.9832 .27316 L
.9879 .27478 L
.99304 .27708 L
1 .28093 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000E_ooool4o`0005Kooooo002Booooo`05o`000?oo
ooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`15oooooa7o00001?ooool7o`000003ooooool0003o000000Oo
0000AOooool009;ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0nooooo`Oo00006oooool2o`0000So
oooo1?l00012ooooo`00T_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oo
ooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>?ooool6o`00
033ooooo3?l0000fooooo`00T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`0003Oooooo0_l00012ooooo`?o0000<oooool0
0;Gooooo00?o0000ooooooooool0<oooool3o`0004Oooooo0ol0000`ooooo`00]Oooool00ol0003o
ooooooooo`0`ooooo`?o0000COooool3o`0002gooooo002eooooo`03o`000?oooooooooo02oooooo
00?o0000ooooooooool0DOooool3o`0002[ooooo002eooooo`03o`000?oooooooooo02cooooo0ol0
001Gooooo`?o00009oooool00;Gooooo0_l0000Zooooo`?o0000GOooool3o`0002Cooooo002eoooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0HOooool4o`00023ooooo000Eooooo`;o
000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h06_ooool01OnHV9So410@o`00
0?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^01cooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
7_ooool00ol0003oooooooooo`0Oooooo`Co000000Co410@ooooooooooook^k^0_l000000olb<S;o
k^k^ooooo`0Iooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00GoV9RHoa0@
4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h05_ooool3o`0000Cooooo0_l0
00002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0>ooooo`005_ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01Ol@413o^[ZjoooooomgMgOo
<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02oooo
o`05o`000?nHV9SooooooiRHV?mgMgL06_ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0Kooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOo
V9RHoooooonHV9SoMgMg01Wooooo1?l000000ooooooo0000ooooo`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03_ooool000_ooooo1_l00002ooooo`Go00000oooool01Ol@413ooooooooooooooooo
410@01;ooooo1_l00006ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413ooooooooo
o`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@4100
4oooool6o`0000Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01ko
oooo00?o0000ooooooooool08Oooool01_l0003ooooooooooooooooo0000oa0@40?ooooo00?o410@
ooooooooool06Oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41007ooo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool06Oooool5o`0000?ooooo
00Go410@oooooooooooooooooa0@400>ooooo`004oooool01?m4A4CogMgMooooool00004ooooo`05
o`000?ooooooooooooooool000007Oooool00onYZJWo410@ooooo`02ooooo`05o`000?oooooooooo
ooooool000007Oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000007_oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007_ooool2o`0002;ooooo
00Ko0000ooooool0003o0000ooooool00003ooooo`03o`000?oooooooooo01[ooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo000001kooooo00?oZJVYoa0@4?ooool00_ooool0
1Ol0003ooooooooooooooooo000001_ooooo00GoA4A4omgMgOoooooo0000ooooo`02o`000003oooo
ool0003ooooo00;ooooo00?o0000ooooooooool03?ooool001?ooooo00?ogMgMoeEEEOooool00_l0
0003ooooo`05o`000?ooooooooooooooool000007?ooool00ol@413o0000okZj^P03ooooo`05o`00
0?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooooooooooo
ool000007_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007_ooool0
0ol0003oooooooooo`0Qooooo`;o00000oooool01Ol0003ooooooooooooooooo000001gooooo00?o
MgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000001gooooo00?o410@o`000?nj^[X0
0oooool01Ol0003ooooooooooooooooo000001_ooooo00CogMgMoeEEEOoooooo00000oooool2o`00
00?ooooo00?o0000ooooooooool03?ooool001Cooooo00CoMgMgolc<c?l0003ooooo0_l000000ooo
oooo410@ooooo`02ooooo`03oa0@4?oooooooooo01_ooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@
413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oo
oooooooo01cooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01kooooo
00?o0000ooooooooool08?ooool2o`0000Cooooo00Go410@oooooooooooooooooa0@400Nooooo`05
o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Looooo`03okZj^_lQ8B7ooooo
00;ooooo00Go410@oooooooooooooooooa0@400Looooo`03ogMgMoo<c<co000000Cooooo00Go410@
oooooooooooooooooa0@400>ooooo`005?ooool00oo^k^koA4A4o`000003ooooo`;o000000CoV9RH
oooooonHV9SoMgMg6_ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Kooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9So
MgMg01kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o
0000ooooooooool07oooool00ol0003oooooo`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
6_ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Koooo
o`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01cooooo00?o
k^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000Eooooo`03ogMgMol0
003ooooo00?ooooo00Gok^k^o`000?l0003o0000onk^kP0Jooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h07_ooool00ol0003oooooooooo`0Mooooo`;o000000?oEEEEofIVI_l00000
1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0Mooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0>ooooo`007oooool2o`0009Cooooo0_l0000Mooooo`03o`000?oooooooooo097ooooo
000Qooooo`;o0000T_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo09;ooooo000S
ooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool06Oooool2o`0009Gooooo000Toooo
o`;o0000Soooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo09Gooooo000Vooooo`03
o`000?oooooooooo08cooooo00?o0000ooooooooool05_ooool2o`0009Sooooo000Foooooooo0000
@?l0000Cooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooool000001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo000F
ooooo`03o`000?oooooooooo013ooooo0_l0000Booooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0Aooooo`00:oooool2o`0008Sooooo00?o0000oooo
ooooool03_ooool4o`0009kooooo000]ooooo`;o0000Q_ooool00ol0003oooooooooo`08ooooo`Ko
0000X_ooool002oooooo0_l00021ooooo`ko0000Z?ooool0037ooooo00?o0000ooooooooool0Nooo
ool4o`0000;ooooo00?o0000ooooooooool0/?ooool003;ooooo00?o0000ooooooooool0Moooool3
o`0000Kooooo00?o0000ooooooooool0/?ooool003?ooooo00?o0000ooooooooool0Loooool3o`00
00Wooooo00?o0000ooooooooool0/?ooool003Cooooo00?o0000ooooooooool0Koooool3o`0000co
oooo00?o0000ooooooooool0/?ooool003Cooooo00?o0000ooooooooool0K?ooool3o`0000oooooo
0_l0002aooooo`00=Oooool00ol0003oooooooooo`1Yooooo`;o00004_ooool00ol0003ooooooooo
o`2`ooooo`00=_ooool00ol0003oooooooooo`1Vooooo`;o00005?ooool00ol0003oooooooooo`2`
ooooo`00=oooool2o`0006Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2`oooo
o`00>Oooool00ol0003oooooooooo`1Nooooo`Co00005oooool00ol0003oooooooooo`2`ooooo`00
>_ooool00ol0003oooooooooo`15ooooo`Co00002_ooool:o`0001_ooooo0_l0002aooooo`00>ooo
ool00ol0003oooooooooo`10ooooo`Go00000_ooool;o`0002Gooooo00?o0000ooooooooool0/?oo
ool003cooooo00?o0000ooooooooool0??ooool3o`0003Oooooo00?o0000ooooooooool0/?ooool0
03gooooo00?o0000ooooooooool0=oooool4o`0003[ooooo00?o0000ooooooooool0/?ooool003ko
oooo0_l0000dooooo`?o0000?_ooool00ol0003oooooooooo`2`ooooo`00@?ooool00ol0003ooooo
ooooo`0^ooooo`?o0000@Oooool2o`000;7ooooo0011ooooo`03o`000?oooooooooo02_ooooo0_l0
0014ooooo`03o`000?oooooooooo0;3ooooo0012ooooo`03o`000?oooooooooo02Sooooo0_l0000S
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00@oooool00ol0003ooooooooo
o`0Rooooo`Go00009Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3o
oooo0014ooooo`03o`000?oooooooooo01Wooooo2Ol0000Yooooo`05oa0@4?ooooooooooooooool@
41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0/?ooool004Gooooo00?o0000ooooooooool05_ooool2o`0003;ooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`000;3o
oooo0016ooooo`;o00004oooool3o`0003Cooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo
0;3ooooo0018ooooo`03o`000?oooooooooo00Sooooo2?l0000gooooo`05oa0@4?oooooooooooooo
ool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0/?ooool004Wooooo2_l0000oooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`
ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c004ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo
410@013ooooo00?o0000ooooooooool00oooool3o`000;3ooooo002Jooooo`05o`000?oooooooooo
ooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Joooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_oo
ool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?oo
ool009;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooo
oooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`?o0000/?oo
ool009;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?oo
ooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3o
oooo002Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00:_ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooo
oooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool00:go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003ooooo
ooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000ooooooooool0^?ooool00:gooooo00?o0000
ooooooooool0^?ooool00:gooooo00?o0000ooooooooool0^?ooool00:_ooooo00?oEEEEofIVI_l0
0000^_ooool00?ooooooJOooool00:oooooo00?o0000okZj^_ooool0]_ooool00:oooooo0_lb<S:g
ooooo`00P?ooool2o`000006oa0@4?oooooooooooa0@4?l0003o410@5oooool5o`0000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003o
A4A4okZj^P0Hooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01?ooool01Om4A4Co0000o`000?lb<S;o
gMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1hooooo`00POooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Oooooo1_l00009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zj
onk^k_mgMgOo410@00Wooooo1_l00009ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401oooool02Omg
MgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`1hooooo`00POooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo01Oooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooo
oooooooo410@01;ooooo00?o0000ooooooooool06_ooool01Ol0003ooooooooooooooooo000000So
oooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`1fooooo`00POooool01_l0003o
ooooodA4A?m4A4Coooooo`0000Wooooo1_l0000;ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000
ooooooooooooooooo`00000Booooo`03o`000?oooooooooo00_ooooo1_l00009ooooo`05o`000?nH
V9SooooooiRHV?lQ8B401oooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000oooooooo
ool0M_ooool0087ooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Kooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo01[ooooo00Go0000
oeEEEOl0003o410@olc<c004ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooo
oooooooooooo000007Sooooo0021ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo00007?ooool01Ol0
003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool03_ooool00ol@413o0000o`000003
o`0001Wooooo00?oEEEEohN7Qoooool01_ooool00ol0003oooooooooo`04ooooo`05oa0@4?oooooo
ooooooooool@4100N?ooool0087ooooo00Ko0000oc8b<_oooooooooooc8b<_l0000Hooooo`05o`00
0?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000oooo
ooooool06_ooool00ooMgMgo410@oiRHV006ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`1hooooo`00P?ooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@
01Oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_oo
ool00ol0003oooooooooo`0Kooooo`04olc<c?m4A4Co0000oa0@40Cooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0N?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(660) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .28513 m
.00942 .28741 L
.01483 .2884 L
.01975 .2895 L
.02243 .29028 L
.02496 .29116 L
.03053 .29364 L
.04057 .29947 L
.08481 .32599 L
.12514 .35765 L
.13498 .36526 L
.14556 .37307 L
.15163 .37646 L
.15717 .37869 L
.16275 .38029 L
.16805 .38152 L
.17842 .38432 L
.18948 .3883 L
.19485 .39009 L
.19749 .39081 L
.19991 .39136 L
.20212 .39176 L
.20446 .39207 L
.20567 .3922 L
.2068 .39229 L
.20804 .39237 L
.20937 .39244 L
.21066 .39248 L
.21187 .39251 L
.21314 .39252 L
.21381 .39253 L
.21453 .39254 L
.21605 .39255 L
.21672 .39255 L
.21745 .39256 L
.21876 .39257 L
.22014 .3926 L
.22148 .39263 L
.2227 .39268 L
.2241 .39275 L
.22543 .39282 L
.23035 .39322 L
.23481 .39364 L
.23705 .39382 L
.23833 .3939 L
.23953 .39395 L
.24083 .39398 L
.24202 .39398 L
.2434 .39394 L
.2447 .39385 L
Mistroke
.24589 .39374 L
.24699 .3936 L
.24947 .39316 L
.25083 .39284 L
.25226 .39244 L
.25482 .39159 L
.2606 .38909 L
.27107 .38369 L
.29062 .376 L
.30135 .37204 L
.31151 .36764 L
.31594 .36591 L
.31836 .36511 L
.32063 .36449 L
.32308 .36399 L
.32438 .36379 L
.32505 .36371 L
.32578 .36363 L
.32699 .36354 L
.32827 .36349 L
.32945 .36348 L
.33054 .36351 L
.33183 .36358 L
.33255 .36363 L
.33322 .36369 L
.33575 .36398 L
.34047 .36471 L
.34311 .36514 L
.34595 .36556 L
.34732 .36573 L
.34862 .36587 L
.34989 .36598 L
.35107 .36606 L
.35225 .36612 L
.3535 .36616 L
.35476 .36618 L
.35548 .36618 L
.35616 .36617 L
.35684 .36615 L
.35756 .36613 L
.35885 .36607 L
.36023 .36598 L
.36175 .36587 L
.37304 .36493 L
.3755 .36479 L
.37811 .36469 L
.38097 .36461 L
.38225 .36457 L
.38362 .36453 L
.3849 .36448 L
Mistroke
.38607 .36442 L
.38837 .36427 L
.38966 .36415 L
.39106 .36399 L
.39361 .36359 L
.39512 .36327 L
.3965 .36294 L
.39958 .36199 L
.40512 .35962 L
.4156 .35359 L
.42543 .34808 L
.43039 .34592 L
.43582 .34402 L
.44721 .34072 L
.45769 .33734 L
.4632 .33558 L
.46591 .33483 L
.46841 .33426 L
.47068 .33386 L
.47183 .33371 L
.4731 .33357 L
.47436 .33348 L
.47572 .33343 L
.47701 .33342 L
.47819 .33345 L
.47947 .33351 L
.48084 .33362 L
.48213 .33375 L
.4833 .3339 L
.48889 .33477 L
.49172 .33522 L
.49436 .3356 L
.4958 .33576 L
.49712 .33588 L
.49782 .33593 L
.49858 .33598 L
.49939 .33601 L
.50015 .33603 L
.50154 .33604 L
.50279 .33601 L
.50349 .33598 L
.50424 .33593 L
.5056 .33582 L
.50688 .33568 L
.50823 .33549 L
.51064 .33509 L
.52031 .33282 L
.53086 .33003 L
.53667 .32828 L
.54216 .32615 L
Mistroke
.54734 .32345 L
.55298 .31963 L
.56283 .31111 L
.5821 .29407 L
.60251 .2783 L
.61334 .26912 L
.61932 .2645 L
.625 .26081 L
.63613 .25571 L
.64632 .25213 L
.6568 .24789 L
.6663 .24394 L
.66879 .24307 L
.67148 .24226 L
.67381 .24168 L
.67636 .24117 L
.67908 .24078 L
.68056 .24062 L
.68195 .2405 L
.68443 .24035 L
.68582 .24029 L
.68709 .24024 L
.68939 .24016 L
.69184 .24007 L
.69311 .24001 L
.69452 .23992 L
.697 .23972 L
.69933 .23946 L
.70184 .23911 L
.70639 .23831 L
.71166 .23725 L
.71455 .2367 L
.71729 .23624 L
.71984 .23591 L
.72127 .23578 L
.7226 .23568 L
.72371 .23562 L
.72494 .23559 L
.72623 .23558 L
.72743 .23559 L
.72879 .23564 L
.73009 .23571 L
.73252 .23589 L
.738 .23642 L
.74068 .23667 L
.74216 .23678 L
.74354 .23686 L
.74433 .2369 L
.74518 .23693 L
.74596 .23695 L
Mistroke
.74667 .23696 L
.74735 .23696 L
.74809 .23696 L
.74886 .23694 L
.74958 .23692 L
.75091 .23686 L
.75158 .23682 L
.75232 .23677 L
.75485 .23654 L
.76057 .23585 L
.76316 .23554 L
.76452 .23539 L
.76594 .23526 L
.7672 .23516 L
.76857 .23508 L
.76982 .23504 L
.77098 .23502 L
.7722 .23503 L
.77352 .23508 L
.77477 .23515 L
.77592 .23524 L
.7781 .23547 L
.78041 .2358 L
.78567 .23674 L
.79047 .23762 L
.79291 .23799 L
.7942 .23815 L
.79557 .2383 L
.79676 .2384 L
.79808 .23849 L
.79928 .23854 L
.8004 .23857 L
.8017 .23857 L
.80307 .23854 L
.80424 .2385 L
.80553 .23844 L
.80839 .23825 L
.81106 .23805 L
.81226 .23796 L
.81356 .23788 L
.81471 .23782 L
.81593 .23777 L
.81702 .23774 L
.81823 .23774 L
.81933 .23776 L
.82035 .2378 L
.82164 .23788 L
.82286 .23798 L
.82395 .23811 L
.82514 .23827 L
Mistroke
.82782 .23875 L
.8303 .23931 L
.83563 .24078 L
.8414 .24242 L
.84404 .24307 L
.84684 .24364 L
.84923 .24402 L
.85058 .24419 L
.85185 .24432 L
.85307 .24442 L
.8544 .2445 L
.85561 .24456 L
.85673 .24459 L
.85793 .24462 L
.85926 .24464 L
.86067 .24466 L
.86196 .24468 L
.8631 .24471 L
.8643 .24475 L
.8655 .2448 L
.86682 .24488 L
.86797 .24497 L
.86919 .2451 L
.87139 .2454 L
.87411 .24593 L
.87699 .24667 L
.88215 .24843 L
.88817 .25087 L
.89381 .25307 L
.89867 .2546 L
.9014 .25526 L
.90389 .25574 L
.90957 .25652 L
.91236 .25683 L
.91497 .25714 L
.91752 .25751 L
.92027 .25802 L
.92507 .25929 L
.92779 .26024 L
.93067 .2614 L
.93581 .26378 L
.95514 .2711 L
.99507 .28332 L
1 .28513 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo043ooooo6_l00007ooooo`?o0000C?ooool009;ooooo00Go410@oooooooooooo
oooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0fooooo`[o00006_ooool7o`0000?ooooo1_l00016ooooo`00T_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0<Oooool5o`0003Cooooo0ol00013ooooo`00T_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2
o`00037ooooo00?o0000ooooooooool0>_ooool:o`0003Wooooo002eooooo`03o`000?oooooooooo
02gooooo0ol00017ooooo`03o`000?oooooooooo03Kooooo002eooooo`03o`000?oooooooooo02[o
oooo0ol0001;ooooo`Co0000=?ooool00;Gooooo00?o0000ooooooooool09oooool3o`0005;ooooo
1?l0000`ooooo`00]Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05Oooooo1Ol0
000[ooooo`00]Oooool2o`0002Gooooo0_l0001Oooooo`?o0000:?ooool00;Gooooo00?o0000oooo
ooooool08_ooool2o`0006Cooooo0ol0000Uooooo`005Oooool2o`000009oa0@4?oooooooooooooo
ooo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h06oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Loooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQkooooo00?o0000ooooooooool0
7oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hJooooo`Go00000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h04Oooool3o`0000Wooooo0_l000002Ol@413oooooooooooooooook^k^
oc8b<_l0003o<S8bonk^kP0>ooooo`005_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL06_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Kooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9So
MgMg01kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o
0000ooooooooool08?ooool2o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj
^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05?ooool3o`0000Oooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko00000_oo
ool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Booooo`Ko00001_ooool01Ol0003ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool04Oooool6o`0000?ooooo00?oV9RHob4Q8Oo^
k^h01?ooool01Ol@413ooooooooooooooooo410@01?ooooo1_l00005ooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@400Nooooo`03o`000?oooooooooo01oooooo00?o0000
ooooool000001?ooool01Ol@413ooooooooooooooooo410@01_ooooo00?oV9RHob4Q8Oo^k^h01?oo
ool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo01Gooooo0ol000000ooooooo0000o`000003o`0000?ooooo00Go410@oooooooo
oooooooooa0@400>ooooo`004oooool01?m4A4CogMgMooooool00004ooooo`05o`000?oooooooooo
ooooool000007Oooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000007Ooo
ool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000007_ooool2o`0001kooooo0_l00002ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Looooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03ojVYZOl@413ooooo00;ooooo00Go0000
ooooooooooooooooo`00000Jooooo`?o000000?oooooo`000?ooool00oooool01Ol0003ooooooooo
oooooooo000000kooooo000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000oooooooooooo
ooooo`00000Looooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00000Noooo
o`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00000Nooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`00000Nooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
7Oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool000006oooool00ooMgMgoEEEEo`000002o`00
00?ooooo00Go0000ooooooooooooooooo`00000>ooooo`005?ooool00omgMgOoc<c<o`000004oooo
o`05oa0@4?ooooooooooooooool@41007Oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41007oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0
7?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41007_ooool00ol0003o
ooooooooo`0Jooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41007_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool07?ooool0
0onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41007?ooool01?mgMgOoc<c<o`00
0?ooool2o`000003ooooool@413ooooo00;ooooo00?o410@ooooooooool03?ooool001Cooooo00?o
k^k^odA4A?l000000ol000001_ooooooMgMgoiRHV?ooooooV9RHogMgMa[ooooo00Go410@oiRHV?oo
oooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool01Ol0003o^[ZjoooooonH
V9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01Ol0
003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`05oa0@4?nH
V9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01cooooo00?ok^k^odA4A?l0
00000oooool01_l0003oMgMgoiRHV?ooooooV9RHogMgM`kooooo000Eooooo`03ogMgMol0003ooooo
00;ooooo1Ol000000oo^k^koooooooooo`0Hooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h07?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h07_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Cooooo00?oEEEEofIV
I_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool01OnYZJWo410@o`000?l@413oZJVY00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Mooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0>ooooo`007oooool2o`0009Cooooo0_l0000Hooooo`03o`000?oooooooooo
09Kooooo000Qooooo`;o0000T_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo09Oo
oooo000Sooooo`;o0000T?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo09Sooooo
000Uooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`2Iooooo`009_ooool2o`0008gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`2J
ooooo`005_ooooooo`00043o00004oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00;o00000oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool04Oooool001Kooooo00?o0000ooooooooool04_ooool2o`00013o
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo017o
oooo000]ooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`2Nooooo`00;_ooool2o`0008Gooooo00?o0000ooooooooool03Oooool2o`000:7ooooo000`
ooooo`03o`000?oooooooooo08;ooooo0_l0000<ooooo`;o0000Xoooool0037ooooo0_l00022oooo
o`03o`000?oooooooooo00Sooooo0ol0002Uooooo`00<oooool00ol0003oooooooooo`1oooooo`03
o`000?oooooooooo00Gooooo0ol0002Xooooo`00=?ooool00ol0003oooooooooo`1cooooo`Wo0000
0_ooool00ol0003oooooooooo`05o`000:_ooooo000eooooo`;o0000Koooool4o`0000Wooooo1Ol0
002`ooooo`00=oooool00ol0003oooooooooo`1Xooooo`Co00003oooool2o`000;7ooooo000hoooo
o`03o`000?oooooooooo06Gooooo0_l0000Cooooo`03o`000?oooooooooo0;3ooooo000iooooo`03
o`000?oooooooooo06;ooooo0_l0000Eooooo`03o`000?oooooooooo0;3ooooo000jooooo`;o0000
H?ooool2o`0001Oooooo00?o0000ooooooooool0/?ooool003cooooo00?o0000ooooooooool0F_oo
ool3o`0001Wooooo00?o0000ooooooooool0/?ooool003gooooo00?o0000ooooooooool0F?ooool0
0ol0003oooooooooo`0Jooooo`;o0000/Oooool003kooooo0_l0001Fooooo`;o00007Oooool00ol0
003oooooooooo`2`ooooo`00@?ooool00ol0003oooooooooo`0kooooo`;o00004oooool3o`0001oo
oooo00?o0000ooooooooool0/?ooool0047ooooo00?o0000ooooooooool0=_ooool4o`000003oooo
ool0003o000001?o00008Oooool00ol0003oooooooooo`2`ooooo`00@_ooool00ol0003ooooooooo
o`0cooooo`;o0000>oooool00ol0003oooooooooo`2`ooooo`00@oooool00ol0003oooooooooo`0^
ooooo`Co0000?Oooool2o`000;7ooooo0014ooooo`;o0000:oooool3o`00047ooooo00?o0000oooo
ooooool0/?ooool004Kooooo1?l0000Uooooo`;o00008Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool0/?ooool004[ooooo1?l0000Oooooo`;o00008oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo0;3ooooo001>ooooo`?o00006_ooool2o`0002Gooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`2`ooooo`00DOooool3o`0001Kooooo00?o0000ooooooooool09Oooool0
1Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8boooo
o`04ooooo`?o0000/?ooool005Cooooo0ol0000@ooooo`?o0000:?ooool01Ol0003ooooooooooooo
oooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool0/?ooool005Oooooo4?l0000[ooooo`05oa0@4?ooooooooooooooool@4100
3oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@
41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006oooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009[ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003o
ooooooooo`03ooooo`?o0000/?ooool009[ooooo00Go0000ooooooooooooooooo`00000?ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`oooo
o`00V_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo1?l00006ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003o
k^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`oooo
o`00T_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo
00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413o
oooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?ooooooooooooooool000003_ooool00olQ
8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00T_ooool01Ol0003o
oooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00Go410@oooooooooooooooooa0@400>
ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`
ooooo`00T_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b
<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00Zoooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool00:gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo0ol0002`
ooooo`00[Oooool00ol0003oooooooooo`2hooooo`00[Oooool00ol0003oooooooooo`2hooooo`00
[Oooool00ol0003oooooooooo`2hooooo`00Zoooool00omEEEGoIVIVo`00002jooooo`00oooooomY
ooooo`00[oooool00ol0003o^[Zjooooo`2fooooo`00[oooool2oc8b<[Oooooo0020ooooo`;o0000
00Ko410@oooooooooooo410@o`000?l@410Gooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo00Go
k^k^oc8b<_l0003o410@olc<c003ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^07Sooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01oooool6o`0000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Ooo
ool6o`0000Wooooo00GoEEEEogMgMoooooooV9RHob4Q8@03ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg07Sooooo0021ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool05oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?oooooooooooooo
ool@41004_ooool00ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@401hooooo`00POoo
ool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000;ooooo`03oiRHV?lQ8B7ok^k^00?o
oooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo00_ooooo1_l00009oooo
o`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003oV9RHoooooonHV9So8B4Q00?ooooo00Go
0000ooooooooooooooooo`00001hooooo`00POooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001_o
oooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000oooo
ooooool06_ooool01Ol0003oEEEEo`000?l@413oc<c<00?ooooo00Go0000oeEEEOl0003o410@olc<
c003ooooo`05o`000?ooooooooooooooool00000N?ooool0087ooooo00Ko0000ohN7QonYZJWo^[Zj
oeEEEOl0000Looooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0>oooo
o`03oa0@4?l0003o000000?o00006Oooool00omEEEGoQhN7ooooo`05ooooo`03oeEEEOn7QhOooooo
00Gooooo00Go410@oooooooooooooooooa0@401hooooo`00POooool01_l0003o<S8boooooooooooo
<S8bo`0001Sooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL04_ooool00ol0003oooooooooo`0Jooooo`03omgMgOl@413oV9RH00Gooooo00?ogMgMoa0@4?nH
V9P01Oooool01OmgMgOoV9RHoooooonHV9SoMgMg07Sooooo0020ooooo`03oa0@4?l0003oQhN700;o
oooo00?oQhN7o`000?l@41005oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Booooo`03o`000?oooooooooo01_ooooo00Coc<c<odA4A?l0003o410@1?oo
ool01?o<c<coA4A4o`000?l@4103ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0N?ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(670) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .28436 m
.00236 .28466 L
.00488 .28506 L
.00726 .28554 L
.00942 .2861 L
.01473 .28797 L
.01975 .29035 L
.04057 .30118 L
.08481 .32733 L
.12514 .34916 L
.16805 .3673 L
.18939 .38036 L
.20937 .38901 L
.21918 .39332 L
.22402 .39529 L
.22638 .3961 L
.22851 .39672 L
.231 .39728 L
.23236 .3975 L
.23365 .39764 L
.23433 .39769 L
.23505 .39773 L
.23635 .39775 L
.23707 .39773 L
.23774 .3977 L
.23847 .39764 L
.23926 .39756 L
.24053 .39738 L
.2419 .39712 L
.24441 .39649 L
.2491 .39487 L
.26945 .3863 L
.29192 .37766 L
.2969 .37555 L
.30215 .37362 L
.3049 .37284 L
.30636 .3725 L
.30791 .37221 L
.30934 .37201 L
.31064 .37187 L
.31195 .37179 L
.31319 .37176 L
.31434 .37178 L
.31561 .37183 L
.31693 .37194 L
.31817 .37207 L
.32038 .37239 L
.32276 .37281 L
.32779 .37385 L
.33315 .37484 L
Mistroke
.33464 .37506 L
.33605 .37523 L
.33731 .37535 L
.33867 .37545 L
.33997 .37551 L
.34134 .37554 L
.34251 .37554 L
.34379 .37552 L
.34457 .37549 L
.3453 .37546 L
.34669 .37537 L
.34979 .37511 L
.35538 .37449 L
.36562 .37334 L
.36832 .37303 L
.37123 .37264 L
.3738 .37222 L
.37649 .37165 L
.37898 .37098 L
.38169 .37007 L
.38645 .36799 L
.39744 .36114 L
.4074 .35446 L
.41229 .35179 L
.41679 .34985 L
.42198 .34818 L
.42761 .34682 L
.43742 .34476 L
.44295 .34358 L
.44812 .34262 L
.45072 .34226 L
.45147 .34218 L
.45218 .34211 L
.45351 .34202 L
.45423 .34199 L
.45498 .34196 L
.45635 .34196 L
.4571 .34198 L
.45781 .34201 L
.45859 .34206 L
.45943 .34213 L
.46939 .34423 L
.47487 .34591 L
.48004 .34733 L
.48146 .34764 L
.48297 .34791 L
.48376 .34802 L
.48463 .34813 L
.48543 .34821 L
.48616 .34827 L
Mistroke
.48754 .34834 L
.48831 .34835 L
.48903 .34834 L
.49032 .34829 L
.49105 .34823 L
.49172 .34817 L
.49314 .34799 L
.49448 .34778 L
.49699 .34724 L
.5026 .34558 L
.513 .34157 L
.52257 .33712 L
.52758 .33417 L
.53308 .33013 L
.54417 .31919 L
.56639 .29492 L
.58664 .27793 L
.59694 .26884 L
.60258 .26411 L
.60787 .26024 L
.61274 .25735 L
.61721 .25528 L
.62217 .2535 L
.62751 .25192 L
.64756 .24484 L
.65307 .24274 L
.65819 .24117 L
.66077 .24058 L
.66353 .24011 L
.6651 .23991 L
.66659 .23977 L
.66792 .23968 L
.66937 .23961 L
.67065 .23956 L
.67137 .23955 L
.67204 .23954 L
.67327 .23952 L
.67457 .23952 L
.67536 .23951 L
.67611 .23951 L
.67749 .2395 L
.67878 .23949 L
.68016 .23946 L
.68138 .23942 L
.68272 .23935 L
.68412 .23926 L
.68542 .23916 L
.68776 .23891 L
.69025 .23857 L
.70078 .23665 L
Mistroke
.7039 .23614 L
.70543 .23593 L
.70684 .23577 L
.70812 .23566 L
.70948 .23557 L
.71085 .23551 L
.71163 .23549 L
.71235 .23548 L
.71366 .23549 L
.71439 .23551 L
.71505 .23554 L
.71635 .2356 L
.71756 .23569 L
.72029 .23593 L
.72325 .23626 L
.72828 .23679 L
.72951 .23689 L
.73082 .23698 L
.73157 .23702 L
.73226 .23705 L
.7336 .2371 L
.7349 .23711 L
.73609 .23711 L
.73741 .23707 L
.73807 .23705 L
.7388 .23701 L
.74003 .23694 L
.74135 .23683 L
.74373 .23661 L
.74824 .2361 L
.75071 .23584 L
.75305 .23564 L
.75436 .23556 L
.7551 .23553 L
.75578 .2355 L
.75698 .23547 L
.75825 .23548 L
.75944 .2355 L
.76056 .23555 L
.76178 .23563 L
.7631 .23575 L
.76604 .23612 L
.76884 .23659 L
.77409 .23762 L
.77922 .23857 L
.78208 .23898 L
.78344 .23914 L
.78468 .23925 L
.78617 .23936 L
.78695 .2394 L
Mistroke
.78777 .23944 L
.78916 .23947 L
.78994 .23948 L
.79068 .23948 L
.7914 .23948 L
.79208 .23947 L
.79336 .23944 L
.79474 .23939 L
.79624 .23934 L
.79869 .23925 L
.80007 .23921 L
.80134 .23919 L
.80245 .23919 L
.80367 .2392 L
.80494 .23924 L
.80613 .2393 L
.80681 .23935 L
.80755 .23941 L
.80889 .23954 L
.8114 .23989 L
.81433 .24046 L
.81703 .24112 L
.8391 .24652 L
.88051 .25607 L
.92034 .26496 L
.96274 .27425 L
1 .28436 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo03_ooooo6ol0001Jooooo`00T_ooool01Ol@413ooooooooooooooooo410@00oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo033o
oooo2ol0000Kooooo`co0000C_ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
02gooooo0ol0000booooo`Go0000BOooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0000[ooooo`?o0000>_ooool5
o`0004Cooooo002eooooo`03o`000?oooooooooo02Oooooo0ol00012ooooo`Go0000?oooool00;Go
oooo00?o0000ooooooooool08oooool4o`0004[ooooo1?l0000kooooo`00]Oooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo053ooooo1?l0000gooooo`00]Oooool00ol0003ooooooooo
o`0Pooooo`;o0000Eoooool5o`0003;ooooo002eooooo`;o00008?ooool00ol0003oooooooooo`1L
ooooo`Co0000;_ooool00;Gooooo00?o0000ooooooooool07Oooool2o`0006?ooooo1?l0000Zoooo
o`005Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00Go
V9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool5o`0000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Looooo`Co000000So410@ooooooooooook^k^oc8b<_l0
003o<S8bonk^kQkooooo00?o0000ooooooooool06oooool2o`0000;ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^6_ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0Kooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo1Ol0000<ooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h03_oo
ool001Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00Go
410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool01OnHV9So
8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
6_ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Koooo
o`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg017ooooo1?l0
0009ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`002ooo
ool6o`0000;ooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41004_ooool6o`0000Kooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo017ooooo1_l00003ooooo`03
oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400Cooooo`Ko00001Oooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41007_ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@01_ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01oooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01?ooooo1?l00002ooooo`Go
00000oooool01Ol@413ooooooooooooooooo410@00kooooo000Cooooo`04odA4A?oMgMgoooooo`00
00Cooooo00Go0000ooooooooooooooooo`00000Mooooo`03ojVYZOl@413ooooo00;ooooo00Go0000
ooooooooooooooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Nooooo`;o
00006Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`00000Looooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000N
ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Iooooo`Co000000?o
ooooo`000?ooool00oooool01Ol0003ooooooooooooooooo000000kooooo000Cooooo`04omgMgOmE
EEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000Looooo`03oa0@4?l0003o^[Zj00?o
oooo00Go0000ooooooooooooooooo`00000Nooooo`03ogMgMomVIVKooooo00;ooooo00Go0000oooo
ooooooooooooo`00000Nooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
000Nooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000007Oooool00omgMgOoIVIVooooo`02ooooo`05o`00
0?ooooooooooooooool000007Oooool00ol@413o0000okZj^P03ooooo`05o`000?oooooooooooooo
ool000006oooool00ooMgMgoEEEEo`000003o`0000;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`005?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41007Oooool0
0onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41007oooool01Ol0003ooooooooo
oooooooo410@00?ooooo00?o410@ooooooooool07?ooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41007_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01kooooo00Go0000oooo
oooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Oooool00_ooool0
1Ol@413ooooooooooooooooo410@01cooooo00?oMgMgolc<c?l000000_ooool2o`000005oa0@4?oo
ooooooooooooool@41003_ooool001Cooooo00?ok^k^odA4A?l000001Ol000001?nHV9SooooooiRH
V?mgMgLJooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
01_ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_oo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg01[ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL06oooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0Looooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`00
5Oooool00omgMgOo0000ooooo`03ooooo`05onk^k_l0003o0000oc8b<_o^k^h06_ooool01OnYZJWo
410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01cooooo00?oEEEEofIVI_l00000
1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01kooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`08ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Joooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00Go
ZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Oooool00omgMgOo
0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool001kooooo0_l0002Eooooo`;o
00005?ooool00ol0003oooooooooo`2Jooooo`008?ooool00ol0003oooooooooo`2Booooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0Voooool0027ooooo0_l0002Booooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool0W?ooool002?ooooo0_l0002@ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0WOooool002Gooooo0_l0002>ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0W_ooool001Koooooool00010o`0001?ooooo000Fooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01?l0003oooooo`000?l00004ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool001Kooooo00?o0000ooooooooool0
4Oooool2o`00017ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo017ooooo000/ooooo`;o0000Qoooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo0:;ooooo000^ooooo`03o`000?oooooooooo08Cooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`2Sooooo`00;oooool2o`0008Cooooo0_l0000:ooooo`03o`000?oooooooooo
0:Cooooo000aooooo`;o0000P_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0:Go
oooo000cooooo`;o0000P?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0:Kooooo
000eooooo`;o0000O_ooool00ol0003oooooooooo`05ooooo`;o0000ZOooool003Oooooo0_l0001l
ooooo`03o`000?oooooooooo00?ooooo0_l0002[ooooo`00>Oooool00ol0003oooooooooo`1ioooo
o`;o000000Coooooo`000?l0003o0000[Oooool003[ooooo0_l0001Vooooo`_o00002?ooool00ol0
003oooooo`00002`ooooo`00??ooool2o`0005oooooo1Ol0000;ooooo`?o00000oooool4o`000;7o
oooo000nooooo`;o0000F_ooool3o`0001;ooooo1Ol000000ooooooo0000ooooo`2aooooo`00@?oo
ool2o`0005Kooooo0_l0000Kooooo`03o`000?oooooooooo0;3ooooo0012ooooo`;o0000D_ooool2
o`0001gooooo0_l0002aooooo`00A?ooool3o`0004kooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`2`ooooo`00Aoooool2o`0004[ooooo0_l0000Pooooo`03o`000?oooooooooo0;3o
oooo0019ooooo`;o0000Aoooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0;3ooooo
001;ooooo`;o0000@oooool2o`0002?ooooo00?o0000ooooooooool0/?ooool004gooooo0_l0000X
ooooo`Oo00003_ooool4o`0002Gooooo0_l0002aooooo`00Coooool00ol0003oooooooooo`0Roooo
o`?o00001oooool>o`0002Wooooo00?o0000ooooooooool0/?ooool0053ooooo0_l0000Pooooo`;o
00007_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool005;ooooo0_l0000Koooo
o`?o00008?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo001D
ooooo`;o00005_ooool3o`0002?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2`ooooo`00E_ooool2
o`0001;ooooo0_l0000Vooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^
kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00F?ooool3o`0000cooooo0ol0000X
ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`ooooo`00Foooool2o`0000Sooooo0_l0
000[ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool005gooooo2?l0000]ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`2`oooo
o`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aoooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00
V_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000;3o
oooo002Jooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo0;3ooooo002Jooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool009;ooooo00Go410@oooooooooooooooooa0@400=oooo
o`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000ooooooooooooooooo`00000>oooo
o`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002a
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00:_ooooo1?l000000ol@413o
ooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0/?ooool00:gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooo
ooooool0^?ooool00:gooooo00?o0000ooooooooool0^?ooool00:gooooo00?o0000ooooooooool0
^?ooool00:_ooooo00?oEEEEofIVI_l00000^_ooool00?ooooooJOooool00:oooooo00?o0000okZj
^_ooool0]_ooool00:oooooo0_lb<S:gooooo`00P?ooool2o`000006oa0@4?oooooooooooa0@4?l0
003o410@5oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`03ohN7Qol0003o
^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0
1Oooool00ol0003ok^k^ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0N?ooool0087ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00002Oooool01OnHV9So8B4Q
onk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03olc<c?l0003o410@
00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002Oooool01OmEEEGoMgMgoooooonH
V9So8B4Q00Gooooo00?oEEEEojVYZOooool00oooool01OmgMgOoV9RHoooooonHV9SoMgMg07Sooooo
0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@41004_ooool00ol0003oooooooooo`0Jooooo`05o`00
0?ooooooooooooooool000001Oooool00onYZJWoEEEEooooo`03ooooo`05oa0@4?oooooooooooooo
ool@4100N?ooool0087ooooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00002oooool0
0onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003ooooooooo
o`0;ooooo`Ko00002Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o8B4Qooooooooool0
0_ooool01Ol0003ooooooooooooooooo000007Sooooo0021ooooo`06o`000?oMgMgo<S8boeEEEOoM
gMgo00006oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000004_ooool0
0ol0003oooooooooo`0Jooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00omEEEGoc<c<oooo
o`02ooooo`05o`000?ooooooooooooooool00000N?ooool0087ooooo00Ko0000ohN7QonYZJWo^[Zj
oeEEEOl0000Looooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0>oooo
o`03oa0@4?l0003o000000?o00006Oooool00omEEEGoQhN7ooooo`08ooooo`03ojVYZOmgMgOooooo
00;ooooo00Go410@oooooooooooooooooa0@401hooooo`00POooool01_l0003o<S8boooooooooooo
<S8bo`0001Sooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL04_ooool00ol0003oooooooooo`0Jooooo`03omgMgOl@413oV9RH00Gooooo00Go410@oooooooo
oooooooooc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0N?ooool0083ooooo00?o410@o`00
0?n7QhL00_ooool00on7QhOo0000oa0@400Gooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo00?o0000ooooooooool06oooool01?o<c<coA4A4o`00
0?l@4103ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07Sooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(680) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .28471 m
.04057 .30273 L
.06168 .31485 L
.08481 .32554 L
.12636 .33984 L
.13185 .34101 L
.13781 .34219 L
.14054 .34285 L
.14344 .34371 L
.14863 .3458 L
.15361 .34853 L
.15827 .35164 L
.16889 .35966 L
.19027 .37368 L
.20984 .38689 L
.21467 .38975 L
.21732 .39103 L
.21981 .392 L
.22124 .39244 L
.22278 .39282 L
.22346 .39296 L
.22418 .39308 L
.22546 .39325 L
.22676 .39335 L
.22796 .39339 L
.22929 .39336 L
.23003 .39332 L
.23071 .39327 L
.23194 .39313 L
.23324 .39293 L
.23559 .39247 L
.2409 .39108 L
.25055 .38834 L
.27123 .38383 L
.28028 .38135 L
.28541 .38 L
.28787 .37947 L
.29018 .37909 L
.29139 .37895 L
.29269 .37883 L
.29388 .37877 L
.29497 .37875 L
.29615 .37877 L
.29745 .37883 L
.29881 .37896 L
.30008 .37913 L
.30271 .37962 L
.3051 .38021 L
.3105 .38189 L
.31587 .38368 L
Mistroke
.31871 .38452 L
.32173 .38526 L
.32323 .38555 L
.32464 .38578 L
.3259 .38594 L
.32727 .38607 L
.32857 .38615 L
.32994 .38619 L
.33111 .3862 L
.3324 .38616 L
.33377 .38609 L
.33504 .38599 L
.33644 .38586 L
.33792 .38568 L
.34314 .38487 L
.35292 .38291 L
.35832 .38152 L
.36338 .37979 L
.36892 .37719 L
.3749 .37345 L
.3849 .36564 L
.39557 .35772 L
.39873 .35591 L
.40171 .35448 L
.4046 .35336 L
.40727 .35254 L
.40981 .35192 L
.4125 .35141 L
.41519 .35101 L
.41815 .35067 L
.42094 .3504 L
.42358 .35018 L
.42599 .35001 L
.42854 .34987 L
.42986 .34982 L
.43061 .3498 L
.43131 .34979 L
.43255 .34978 L
.43388 .34979 L
.43458 .34981 L
.43535 .34984 L
.43616 .34988 L
.43691 .34994 L
.43825 .35006 L
.43969 .35024 L
.44229 .35068 L
.44511 .35136 L
.45023 .3531 L
.45981 .35743 L
.46459 .35948 L
Mistroke
.46723 .36041 L
.46973 .36111 L
.47114 .3614 L
.47189 .36153 L
.47268 .36164 L
.47341 .36172 L
.47408 .36178 L
.47537 .36184 L
.47668 .36183 L
.47742 .3618 L
.47809 .36175 L
.47934 .36162 L
.48065 .36142 L
.48203 .36114 L
.48328 .36083 L
.4861 .35997 L
.49119 .35791 L
.50274 .35159 L
.51316 .34386 L
.5228 .33391 L
.5446 .30502 L
.56588 .28348 L
.5763 .27397 L
.58585 .26517 L
.59515 .25808 L
.59983 .25548 L
.60494 .25338 L
.62551 .24732 L
.63611 .24309 L
.64132 .24121 L
.6436 .24054 L
.64612 .23993 L
.6488 .23945 L
.65028 .23927 L
.65165 .23913 L
.65243 .23908 L
.65316 .23903 L
.65454 .23898 L
.65531 .23897 L
.65603 .23896 L
.65681 .23896 L
.65765 .23897 L
.65901 .239 L
.65978 .23902 L
.66048 .23904 L
.66314 .23912 L
.6644 .23916 L
.66557 .23918 L
.66678 .23919 L
.66812 .23918 L
Mistroke
.66945 .23915 L
.67012 .23912 L
.67086 .23908 L
.67217 .239 L
.6734 .23889 L
.67616 .23856 L
.67913 .23809 L
.68447 .23705 L
.6871 .23652 L
.68955 .23607 L
.6921 .23568 L
.69321 .23554 L
.69441 .23541 L
.69574 .23531 L
.69699 .23524 L
.69768 .23521 L
.69842 .2352 L
.69973 .2352 L
.70084 .23523 L
.70203 .23528 L
.70315 .23536 L
.70417 .23545 L
.70905 .23603 L
.71409 .23673 L
.71686 .23706 L
.71821 .23719 L
.71945 .23729 L
.72052 .23736 L
.72165 .23741 L
.72279 .23744 L
.72403 .23745 L
.72529 .23743 L
.72664 .23739 L
.72792 .23733 L
.72908 .23725 L
.73446 .23677 L
.73729 .2365 L
.73884 .23637 L
.74029 .23627 L
.74155 .23621 L
.74291 .23617 L
.74368 .23616 L
.74442 .23616 L
.74579 .23619 L
.74706 .23624 L
.74822 .23632 L
.74951 .23644 L
.75087 .2366 L
.76109 .23858 L
.76667 .23977 L
Mistroke
.7694 .24024 L
.77188 .24057 L
.77318 .24071 L
.7746 .24083 L
.77538 .24089 L
.7761 .24093 L
.77752 .24099 L
.77826 .24102 L
.77895 .24104 L
.7797 .24105 L
.78052 .24106 L
.78133 .24107 L
.78218 .24107 L
.78291 .24107 L
.78371 .24107 L
.78444 .24107 L
.78513 .24107 L
.78643 .24108 L
.78716 .24108 L
.78783 .24109 L
.78856 .24111 L
.78934 .24113 L
.79063 .24119 L
.79184 .24126 L
.79316 .24136 L
.79458 .24151 L
.79738 .24191 L
.79999 .24242 L
.80588 .24397 L
.81097 .24558 L
.81659 .24729 L
.81901 .24792 L
.82161 .24851 L
.82386 .24893 L
.82633 .2493 L
.82896 .24961 L
.83173 .24986 L
.83669 .25028 L
.83934 .25055 L
.84222 .25094 L
.84494 .25143 L
.84745 .252 L
.85221 .25339 L
.85725 .2552 L
.87923 .26117 L
.88432 .26161 L
.88701 .26182 L
.88987 .2621 L
.89262 .26246 L
.89511 .26289 L
Mistroke
.89998 .26404 L
.9091 .26705 L
.9139 .26868 L
.91897 .27008 L
.92157 .27061 L
.92295 .27083 L
.92443 .27103 L
.92579 .27118 L
.92704 .27128 L
.92828 .27136 L
.92946 .27141 L
.93066 .27145 L
.93192 .27147 L
.93301 .27149 L
.9342 .2715 L
.93548 .27152 L
.93686 .27154 L
.93816 .27157 L
.93935 .27162 L
.94063 .27168 L
.94199 .27178 L
.94328 .2719 L
.94445 .27204 L
.94732 .27249 L
.95003 .27308 L
.95543 .27463 L
.96128 .27664 L
.96559 .27807 L
.97023 .27936 L
.97289 .27993 L
.97533 .28035 L
.98009 .28092 L
.98498 .28136 L
.98756 .28164 L
.9903 .28202 L
.99294 .28253 L
.99534 .28312 L
1 .28471 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo03Oooooo6Ol0001Pooooo`00T_ooool01Ol@413ooooooooooooooooo410@00oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02_o
oooo3?l0000Iooooo`Oo0000FOooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
02Oooooo1?l0000[ooooo`[o0000D?ooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0000Tooooo`Co0000>Oooool3
o`0004gooooo002eooooo`03o`000?oooooooooo023ooooo0ol0000oooooo`Oo0000Aoooool00;Go
oooo00?o0000ooooooooool07_ooool2o`0004Wooooo1_l00011ooooo`00]Oooool00ol0003ooooo
ooooo`0Looooo`;o0000DOooool3o`0003kooooo002eooooo`03o`000?oooooooooo01[ooooo0_l0
001Fooooo`?o0000>oooool00;Gooooo0_l0000Jooooo`03o`000?oooooooooo05Wooooo1ol0000d
ooooo`00]Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo067ooooo0ol0000aoooo
o`005Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00Go
V9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool5o`0000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Looooo`Co000000So410@ooooooooooook^k^oc8b<_l0
003o<S8bonk^kQkooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`05ooooo`Co0000
00So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQ[ooooo1Ol00003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h06oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`?o00005Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb
<S;ok^k^00kooooo000Fooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Jooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg01[ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL06oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`08ooooo`Wo00003Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3_ooool000_ooooo1_l00002ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@01;ooooo
1_l00006ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Aooooo`Ko
00000oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41004oooool6o`00
00Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01kooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Kooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooo
oa0@400Oooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0?ooooo`Go
00001Oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`004oooool01?m4A4Co
gMgMooooool00004ooooo`05o`000?ooooooooooooooool000007Oooool00onYZJWo410@ooooo`02
ooooo`05o`000?ooooooooooooooool000007Oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oo
ooooooooooooool000007_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00007_ooool2o`0001Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000007?ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooooooo
ooooool000007_ooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000005_oo
ool3o`0000;ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000000ko
oooo000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000Loooo
o`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`00000Nooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`00000Nooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00omgMgOo
IVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00ol@413o0000okZj^P03oooo
o`05o`000?ooooooooooooooool000006Oooool6o`0000Cooooo00Go0000ooooooooooooooooo`00
000>ooooo`005?ooool01?mgMgOoc<c<o`000?l00003ooooo`05oa0@4?ooooooooooooooool@4100
7Oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41007oooool01Ol0003o
oooooooooooooooo410@00?ooooo00?o410@ooooooooool07?ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41007_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01kooooo00Go
0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Oooool0
0_ooool01Ol@413ooooooooooooooooo410@01cooooo00?oMgMgolc<c?l000001?l000001Ol@413o
oooooooooooooooo410@00kooooo000Dooooo`04onk^k_m4A4Co0000ooooo`;o000000KoooooogMg
MonHV9SooooooiRHV?mgMgLJooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RH
oooooonHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL07_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL06oooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0Looooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0>ooooo`005Oooool00omgMgOo0000ooooo`02ooooo`;o000000Co<S8bo`000?lb<S;ok^k^
6_ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Koooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01cooooo00?o
EEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01kooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
7Oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool001cooooo
0ol0002Fooooo`;o00004?ooool00ol0003oooooooooo`2Nooooo`007oooool2o`0009Cooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`2Oooooo`008Oooool2o`0009;ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`2Pooooo`008oooool2o`00093ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`2Qooooo`009Oooool00ol0003oooooooooo`2=ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0X_ooool001Koooooool00010o`0001?ooooo
000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooo`00
0005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool001Kooooo00?o
0000ooooooooool04?ooool2o`0001;ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo017ooooo000[ooooo`?o0000Qoooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo0:Gooooo000^ooooo`?o0000Q?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo0:Kooooo000aooooo`;o0000P_ooool2o`0000Sooooo00?o0000oooooooo
ool0Y_ooool003?ooooo0ol0001oooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
Yoooool003Kooooo0ol0001looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Z?oo
ool003Wooooo0_l0001jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0ZOooool0
03_ooooo0ol0001gooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Z_ooool003ko
oooo1?l0001cooooo`;o00000oooool00ol0003oooooooooo`2[ooooo`00@_ooool3o`00073ooooo
00Go0000ooooooooooooooooo`00002^ooooo`00AOooool2o`0006kooooo00Co0000oooooooooooo
0000[oooool004Oooooo00?o0000ooooooooool0DOooool9o`00017ooooo00?o0000ooooool00000
/?ooool004Sooooo0_l0001=ooooo`Co00002?ooool4o`0000kooooo0_l0002aooooo`00B_ooool0
0ol0003oooooooooo`18ooooo`;o00004?ooool00ol0003oooooooooo`09ooooo`Co0000/Oooool0
04_ooooo0_l00016ooooo`;o00004oooool3o`0000Gooooo0ol00002ooooo`03o`000?oooooooooo
0;3ooooo001=ooooo`03o`000?oooooooooo047ooooo0_l0000Hooooo`Ko00001?ooool00ol0003o
ooooooooo`2`ooooo`00C_ooool2o`00043ooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`2`ooooo`00D?ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool0/?ooool0057ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0T
ooooo`;o0000/Oooool005;ooooo0_l0000hooooo`;o00009oooool00ol0003oooooooooo`2`oooo
o`00E?ooool00ol0003oooooooooo`0Kooooo`Co00005?ooool2o`0000Kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo0;3ooooo001Eooooo`;o00005oooool4o`0000Cooooo1?l0000=oooo
o`?o00002?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo001G
ooooo`03o`000?oooooooooo00oooooo1Ol0000<ooooo`?o00001Oooool5o`0000_ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`2`ooooo`00F?ooool2o`0000[ooooo1Ol0000Dooooo`Go00004?ooool0
1Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8boooo
o`04ooooo`?o0000/?ooool005[ooooo0_l00006ooooo`;o0000;_ooool01Ol0003ooooooooooooo
oooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool0/?ooool005cooooo1_l0000`ooooo`05oa0@4?ooooooooooooooool@4100
3oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@
41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006oooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009[ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003o
ooooooooo`03ooooo`?o0000/?ooool009[ooooo00Go0000ooooooooooooooooo`00000?ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`oooo
o`00V_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo1?l00006ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003o
k^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`oooo
o`00T_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo
00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413o
oooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?ooooooooooooooool000003_ooool00olQ
8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00T_ooool01Ol0003o
oooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00Go410@oooooooooooooooooa0@400>
ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`
ooooo`00T_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b
<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00Zoooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool00:gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo0ol0002`
ooooo`00[Oooool00ol0003oooooooooo`2hooooo`00[Oooool00ol0003oooooooooo`2hooooo`00
[Oooool00ol0003oooooooooo`2hooooo`00Zoooool00omEEEGoIVIVo`00002jooooo`00oooooomY
ooooo`00[oooool00ol0003o^[Zjooooo`2fooooo`00[oooool2oc8b<[Oooooo0020ooooo`;o0000
00Ko410@oooooooooooo410@o`000?l@410Gooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo00Go
k^k^oc8b<_l0003o410@olc<c003ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^07Sooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01oooool6o`0000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Ooo
ool6o`0000Wooooo00GoEEEEogMgMoooooooV9RHob4Q8@03ooooo`05ob4Q8OnHV9SooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg07Sooooo0021ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool05oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?oooooooooooooo
ool@41004_ooool00ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@401hooooo`00POoo
ool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000;ooooo`03oiRHV?lQ8B7ok^k^00?o
oooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo00_ooooo1_l00009oooo
o`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Olb<S;oV9RHoooooonHV9So<S8b00?ooooo00Go
0000ooooooooooooooooo`00001hooooo`00POooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001_o
oooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000oooo
ooooool06_ooool01Ol0003oEEEEo`000?l@413oc<c<00?ooooo00Goc<c<o`000?l0003o0000olc<
c003ooooo`05o`000?ooooooooooooooool00000N?ooool0087ooooo00Ko0000ohN7QonYZJWo^[Zj
oeEEEOl0000Looooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0>oooo
o`03oa0@4?l0003o000000?o00006Oooool00omEEEGoQhN7ooooo`05ooooo`05oa0@4?nj^[[ooooo
okZj^_l@41000oooool01Ol@413ooooooooooooooooo410@07Sooooo0021ooooo`06o`000?lb<S;o
oooooooooolb<S;o00006?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0Booooo`03o`000?oooooooooo01[ooooo00?ogMgMoa0@4?nHV9P01Oooool01Ol0
003o^[Zjoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1hooooo`00P?ooool0
0ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Oooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Kooooo`04olc<
c?m4A4Co0000oa0@40?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h0N?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(690) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .2909 m
.01975 .29928 L
.04057 .30765 L
.05077 .31316 L
.05371 .31453 L
.05648 .31563 L
.05901 .31646 L
.06168 .31714 L
.0631 .31743 L
.06467 .31769 L
.06742 .31803 L
.06897 .31817 L
.07064 .31828 L
.07365 .31844 L
.07664 .31861 L
.07811 .31871 L
.07948 .31882 L
.08203 .3191 L
.08481 .31953 L
.09441 .3219 L
.10455 .32483 L
.10985 .32595 L
.11286 .32642 L
.11566 .32679 L
.12092 .32742 L
.1235 .32781 L
.12589 .32826 L
.12861 .32894 L
.13157 .32991 L
.13675 .33229 L
.14239 .33584 L
.14838 .34038 L
.16956 .35606 L
.19023 .37043 L
.19929 .37693 L
.20177 .37842 L
.20442 .37979 L
.20671 .38076 L
.20919 .38157 L
.21058 .38192 L
.21186 .38216 L
.21308 .38234 L
.21438 .38246 L
.21554 .38252 L
.21662 .38253 L
.21781 .3825 L
.21909 .38242 L
.22043 .3823 L
.22188 .38212 L
.22453 .3817 L
Mistroke
.22951 .38079 L
.23501 .37989 L
.2366 .37969 L
.23809 .37953 L
.23944 .3794 L
.24087 .3793 L
.24213 .37922 L
.24351 .37916 L
.24477 .37911 L
.24594 .37908 L
.24732 .37905 L
.24858 .37903 L
.25141 .37899 L
.25382 .37894 L
.25519 .3789 L
.25647 .37885 L
.25906 .37873 L
.26184 .37856 L
.26645 .37826 L
.26772 .37819 L
.26906 .37813 L
.27033 .3781 L
.27149 .37808 L
.27286 .3781 L
.27363 .37812 L
.27434 .37816 L
.27565 .37825 L
.27704 .3784 L
.27848 .37861 L
.27982 .37887 L
.28287 .37967 L
.2855 .3806 L
.2879 .38163 L
.2933 .38448 L
.303 .39019 L
.30556 .39153 L
.30832 .39279 L
.31075 .39372 L
.31331 .39449 L
.31465 .39481 L
.31612 .39509 L
.31745 .39528 L
.31869 .39542 L
.31946 .39548 L
.32019 .39552 L
.32156 .39557 L
.32233 .39557 L
.32303 .39556 L
.32381 .39553 L
.32463 .3955 L
Mistroke
.32587 .39541 L
.3272 .39529 L
.32961 .39499 L
.33248 .39454 L
.3351 .39403 L
.34011 .39281 L
.34545 .39105 L
.35049 .38878 L
.35505 .38606 L
.36626 .37676 L
.37682 .36673 L
.38213 .36244 L
.38708 .35931 L
.38958 .3581 L
.39225 .35706 L
.39521 .35619 L
.39652 .35589 L
.39792 .35562 L
.3991 .35543 L
.4004 .35526 L
.40159 .35514 L
.40269 .35504 L
.40398 .35496 L
.40466 .35492 L
.40537 .35489 L
.40657 .35486 L
.40788 .35484 L
.40912 .35484 L
.41025 .35486 L
.41155 .35489 L
.41277 .35495 L
.41391 .35501 L
.41495 .35509 L
.41732 .35532 L
.41864 .3555 L
.41989 .35569 L
.42223 .35615 L
.42476 .3568 L
.42751 .35771 L
.43245 .35992 L
.43703 .36259 L
.44821 .37029 L
.45087 .37199 L
.45368 .37357 L
.45629 .37477 L
.45756 .37526 L
.45871 .37564 L
.45986 .37595 L
.46111 .37622 L
.46242 .37642 L
Mistroke
.46367 .37653 L
.46504 .37656 L
.46573 .37655 L
.46649 .3765 L
.46784 .37635 L
.4691 .37614 L
.47055 .37582 L
.47192 .37543 L
.4745 .3745 L
.48032 .37163 L
.48967 .36524 L
.49987 .35568 L
.5107 .34167 L
.52052 .32616 L
.54254 .295 L
.56274 .27448 L
.57316 .26433 L
.57868 .25974 L
.5846 .25585 L
.59025 .25321 L
.59542 .2515 L
.60552 .24879 L
.61701 .24472 L
.62206 .24268 L
.62764 .24067 L
.63005 .23997 L
.63264 .23936 L
.63384 .23914 L
.6351 .23895 L
.63628 .2388 L
.63735 .23869 L
.63858 .2386 L
.6399 .23854 L
.64112 .23852 L
.64227 .23851 L
.64362 .23853 L
.64486 .23856 L
.64622 .23862 L
.64767 .23868 L
.65025 .23879 L
.65099 .23881 L
.6517 .23883 L
.65303 .23886 L
.65427 .23886 L
.65543 .23885 L
.65669 .23881 L
.65804 .23874 L
.65882 .23869 L
.65953 .23864 L
.66113 .23848 L
Mistroke
.66403 .23808 L
.66946 .2371 L
.67441 .23614 L
.67713 .23569 L
.67847 .23552 L
.6797 .23538 L
.68087 .23528 L
.6821 .2352 L
.68334 .23516 L
.6847 .23515 L
.68583 .23517 L
.68705 .23523 L
.6882 .23531 L
.68926 .23541 L
.6947 .23617 L
.70051 .23718 L
.70333 .2376 L
.70471 .23777 L
.70599 .23791 L
.70713 .23801 L
.70838 .23809 L
.70963 .23814 L
.71096 .23816 L
.7123 .23816 L
.71356 .23813 L
.71469 .23808 L
.71593 .23801 L
.71869 .2378 L
.72125 .23756 L
.72365 .23735 L
.72591 .23719 L
.72704 .23713 L
.72826 .23708 L
.72962 .23706 L
.73086 .23707 L
.73213 .23712 L
.73348 .2372 L
.73476 .23732 L
.73592 .23745 L
.73876 .2379 L
.74145 .23846 L
.74676 .23983 L
.75261 .24138 L
.75515 .24196 L
.75787 .24248 L
.76044 .24285 L
.7628 .24309 L
.76417 .2432 L
.76544 .24327 L
.76684 .24333 L
Mistroke
.76762 .24335 L
.76833 .24337 L
.76963 .24339 L
.77104 .24341 L
.77236 .24343 L
.77359 .24345 L
.77472 .24348 L
.77593 .24352 L
.77727 .24359 L
.7785 .24367 L
.77977 .24378 L
.78116 .24393 L
.78368 .2443 L
.78601 .24475 L
.7885 .24535 L
.79295 .24667 L
.8028 .24997 L
.80549 .25076 L
.80833 .25147 L
.81078 .25197 L
.81341 .2524 L
.81589 .25271 L
.81816 .25293 L
.82257 .25328 L
.82505 .25349 L
.82773 .25376 L
.83027 .25411 L
.8326 .25451 L
.87398 .26342 L
.91377 .2702 L
.91513 .27023 L
.9164 .27025 L
.91711 .27025 L
.91787 .27025 L
.91921 .27024 L
.91999 .27023 L
.92081 .27023 L
.92157 .27022 L
.92228 .27021 L
.92364 .27021 L
.92436 .27021 L
.92513 .27022 L
.92585 .27023 L
.92652 .27025 L
.92725 .27027 L
.92803 .27031 L
.92934 .27039 L
.93077 .27052 L
.93205 .27066 L
.93343 .27085 L
Mistroke
.93591 .27129 L
.94132 .27263 L
.94647 .27422 L
.95614 .27708 L
.96636 .27893 L
.97198 .27967 L
.97474 .28012 L
.97727 .28062 L
.98222 .282 L
.98482 .28296 L
.98757 .28415 L
.99691 .28914 L
1 .2909 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo03;ooooo3Ol00004ooooo`Oo0000I_ooool009;ooooo00Go410@oooooooooooo
oooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Uooooo`go00003Oooool4o`0000Oooooo0ol0001Sooooo`00T_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool08oooool2o`0002Sooooo2_l0001Iooooo`00T_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2
o`00027ooooo0ol0000dooooo`Ko0000Doooool00;Gooooo00?o0000ooooooooool07Oooool3o`00
03gooooo00?o0000ooooooooool0D?ooool00;Gooooo00?o0000ooooooooool06Oooool4o`00047o
oooo1ol0001;ooooo`00]Oooool00ol0003oooooooooo`0Gooooo`;o0000C?ooool5o`0004Kooooo
002eooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0DOooool5o`00047ooooo002e
ooooo`;o00005_ooool00ol0003oooooooooo`1Gooooo`Co0000?Oooool00;Gooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`1Looooo`Go0000>?ooool001Gooooo0_l000002Ol@413o
ooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0Jooooo`05oiRHV?l@413o0000oc8b<_o<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h07?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hNooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool02Oooool4o`000008oa0@4?ooooooooooonk^k_lb
<S;o0000oc8b<_o^k^hJooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00Go
V9RHoa0@4?l0003o<S8bolc<c003ooooo`03onk^k_lb<S;o000000Oo00006?ooool2o`000009oa0@
4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Fooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05oa0@4?nj^[[oooooogMgMolb<S800ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL07_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool01Ol@413o^[ZjoooooomgMgOo<S8b
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`[o00003oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool000_ooooo1_l00002ooooo`Go00000oooool0
1Ol@413ooooooooooooooooo410@01;ooooo1_l00006ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41004oooool6o`0000Gooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@01kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Kooooo`03oiRHV?lQ8B7o
k^k^00Cooooo00Go410@oooooooooooooooooa0@400Oooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0=ooooo`Go00001oooool5o`0000?ooooo00Go410@oooooooooooo
oooooa0@400>ooooo`004oooool01?m4A4CogMgMooooool00004ooooo`05o`000?oooooooooooooo
ool000007Oooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool0
0onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000007_ooool2o`00017ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007?ooool00onHV9So
8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000007_ooool00onYZJWo410@ooooo`02oooo
o`05o`000?ooooooooooooooool000005?ooool3o`0000Cooooo00CoA4A4omgMgOoooooo00001?oo
ool01Ol0003ooooooooooooooooo000000kooooo000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo
00Go0000ooooooooooooooooo`00000Looooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000oooooooo
ooooooooo`00000Nooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00000N
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Nooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000007Oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool0
00007Oooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000005oooool5o`00
0003oeEEEOoooooo000000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`005?ooool00omg
MgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41007Oooool00onj^[[o8B4Qooooo`02
ooooo`05oa0@4?ooooooooooooooool@41007oooool01Ol0003ooooooooooooooooo410@00?ooooo
00?o410@ooooooooool07?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41007_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@01kooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooo
oooo410@01cooooo1?l00003ooooo`05oa0@4?ooooooooooooooool@41003_ooool001Cooooo00?o
k^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00Go410@oiRHV?oooooo
^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool01Ol0003o^[ZjoooooonHV9So
410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01Ol0003o
^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`05oa0@4?nHV9So
oooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01cooooo00Gok^k^odA4A?l0003o
ooooo`000002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool001Gooooo00?oMgMgo`000?l0
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Looooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0Nooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04?ooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06_ooool01OnHV9So410@o`000?lQ
8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo00CoMgMgo`000?oooooooooo0_l00000
1Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Hooooo`;o0000Voooool2o`0000cooooo00?o0000
ooooooooool0X_ooool001[ooooo0_l0002Iooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0Xoooool001cooooo0_l0002Gooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0Xoooool001kooooo0ol0002Dooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
Y?ooool0027ooooo0_l0002Booooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0YOoo
ool001Koooooool00010o`0001?ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool04Oooool001Kooooo00?o0000ooooooooool03_ooool2o`0001Cooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo017ooooo000Xooooo`co0000
POooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:Sooooo000dooooo`?o0000O_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:Sooooo000gooooo`;o0000O?ooool2
o`0000Gooooo00?o0000ooooooooool0ZOooool003Wooooo1ol0001eooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0Z_ooool0043ooooo00?o0000ooooooooool0L_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo0:[ooooo0011ooooo`;o0000L_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0:_ooooo0013ooooo`;o0000L?ooool01Ol0003ooooooooo
oooooooo00000:kooooo0015ooooo`;o0000K_ooool2o`0000;ooooo00?o0000ooooooooool0[?oo
ool004Oooooo00?o0000ooooooooool0Joooool01?l0003oooooooooool0002_ooooo`00B?ooool2
o`0006_ooooo00Co0000oooooooooooo0000[oooool004[ooooo00?o0000ooooooooool0J?ooool0
0ol0003oooooo`00002`ooooo`00Boooool00ol0003oooooooooo`1Wooooo`;o0000/Oooool004co
oooo0_l00015ooooo`_o00005oooool2o`000;7ooooo001>ooooo`03o`000?oooooooooo03oooooo
0ol0000;ooooo`?o00004oooool2o`000;;ooooo001?ooooo`03o`000?oooooooooo03gooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo00000;;ooooo001@
ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0<
ooooo`;o00000_ooool00ol0003oooooooooo`2`ooooo`00DOooool00ol0003oooooooooo`0ioooo
o`;o00005?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0/?ooool005;ooooo0_l0000hooooo`03o`000?oooooooooo01Gooooo0_l00008ooooo`;o
00001Oooool2o`000;7ooooo001Dooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0
6?ooool3o`0000?ooooo0_l00007ooooo`03o`000?oooooooooo0;3ooooo001Eooooo`;o00003?oo
ool=o`0001[ooooo00?o0000ooooooooool01Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`Go000000?oooooo`000?l000001?l000000olb<S;ogMgMooooo`04ooooo`03o`00
0?oooooooooo0;3ooooo001Gooooo`Co000000?oooooo`000?l000001Ol0000=ooooo`?o00005_oo
ool00ol0003oooooooooo`06ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo
00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0/?ooool005[ooooo0_l0000Gooooo`;o00004oooool00ol0003oooooooooo`07ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0/?ooool007Gooooo00?o0000ooooooooool03_ooool2o`0000[ooooo
00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_oo
ool01?ooool3o`000;3ooooo001fooooo`;o00002oooool3o`0000cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005oooo
o`03o`000?oooooooooo0;3ooooo001hooooo`?o00001Oooool3o`0000oooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`2`ooooo`00N_ooool6o`0001;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002a
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`03ooooo`?o0000/?ooool009[ooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool0
09[ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00V_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`2`ooooo`00T_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooo
ooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0
002`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00Go
410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`2`ooooo`00T_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0/?ooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00Zoooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0/?ooool00:gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2`oooo
o`00[Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;3ooooo002]ooooo`03o`00
0?oooooooooo00Gooooo0ol0002`ooooo`00[Oooool00ol0003oooooooooo`2hooooo`00[Oooool0
0ol0003oooooooooo`2hooooo`00[Oooool00ol0003oooooooooo`2hooooo`00Zoooool00omEEEGo
IVIVo`00002jooooo`00oooooomYooooo`00[oooool00ol0003o^[Zjooooo`2fooooo`00[oooool2
oc8b<[Oooooo0020ooooo`;o000000Ko410@oooooooooooo410@o`000?l@410Gooooo`Go00000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000
o`000?m4A4Co^[Zj01Sooooo00Gok^k^oc8b<_l0003o410@olc<c003ooooo`04oa0@4?l0003oA4A4
olc<c0Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1hooooo`00POooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Oooooo1_l00009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zj
onk^k_mgMgOo410@00Wooooo1_l00009ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401Oooool00onH
V9So410@omgMg@03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0N?ooool0087ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooo
oooooooooooooa0@400Booooo`03o`000?oooooooooo01[ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03ohN7QomEEEGooooo00;ooooo00Go410@oooooooooooooooooa0@401hooooo`00POoo
ool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000;ooooo`03oiRHV?lQ8B7ok^k^00?o
oooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo00_ooooo1_l00009oooo
o`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Oo<c<co8B4Qo`000?mEEEGo000000?ooooo00Go
0000ooooooooooooooooo`00001hooooo`00POooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001_o
oooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000oooo
ooooool06_ooool01Ol0003oEEEEo`000?l@413oc<c<00?ooooo00Go8B4QohN7QoooooooV9RHo`00
0003ooooo`05o`000?ooooooooooooooool00000N?ooool0087ooooo00Ko0000ohN7QonYZJWo^[Zj
oeEEEOl0000Looooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0>oooo
o`03oa0@4?l0003o000000?o00006Oooool00omEEEGoQhN7ooooo`05ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol@413ooooooooooooooooo410@07Sooooo0021ooooo`06o`000?lb<S;o
oooooooooolb<S;o00006?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0Booooo`03o`000?oooooooooo01[ooooo00?ogMgMoa0@4?nHV9P01Oooool01OlQ
8B7oV9RHoooooomgMgOoEEEE00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1hooooo`00P?ooool0
0ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Oooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Kooooo`04olc<
c?m4A4Co0000oa0@40?ooooo00Goc<c<oa0@4?l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h0N?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(700) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .29799 m
.01975 .30343 L
.02981 .30709 L
.03534 .30914 L
.04057 .31071 L
.04331 .31129 L
.04486 .31154 L
.04629 .31172 L
.04749 .31182 L
.04882 .3119 L
.0502 .31194 L
.0515 .31195 L
.05281 .31192 L
.05406 .31187 L
.05518 .3118 L
.0564 .31172 L
.06168 .31129 L
.06325 .31117 L
.06402 .31113 L
.06473 .31109 L
.06605 .31104 L
.06675 .31102 L
.06749 .31101 L
.06822 .31101 L
.06901 .31102 L
.06976 .31104 L
.07044 .31106 L
.07123 .3111 L
.0721 .31116 L
.07367 .3113 L
.07501 .31145 L
.07648 .31165 L
.07946 .31216 L
.08481 .31327 L
.09554 .31538 L
.10139 .3162 L
.10683 .31695 L
.11149 .31786 L
.1141 .31857 L
.11647 .31938 L
.1219 .3219 L
.12702 .32511 L
.14816 .34145 L
.16764 .3539 L
.17778 .36081 L
.18273 .36403 L
.18726 .36654 L
.18954 .36757 L
.19203 .36848 L
.19339 .36887 L
Mistroke
.19466 .36917 L
.19587 .3694 L
.19715 .36958 L
.19789 .36965 L
.19857 .3697 L
.19931 .36973 L
.2001 .36975 L
.20142 .36972 L
.20216 .36969 L
.20286 .36963 L
.20417 .3695 L
.20536 .36935 L
.20803 .3689 L
.21306 .36785 L
.21778 .3669 L
.22014 .36652 L
.22269 .36621 L
.22407 .36609 L
.22482 .36604 L
.22552 .366 L
.22676 .36595 L
.22811 .36592 L
.22882 .36592 L
.22959 .36592 L
.23032 .36593 L
.23099 .36595 L
.23226 .36599 L
.2336 .36605 L
.23945 .36642 L
.24493 .36679 L
.24993 .36713 L
.25237 .36734 L
.25503 .36763 L
.25754 .36803 L
.25986 .36852 L
.26232 .3692 L
.26503 .3702 L
.27052 .37305 L
.27529 .37645 L
.28044 .38084 L
.28976 .38936 L
.29461 .3933 L
.2998 .39671 L
.30277 .39824 L
.30548 .39937 L
.30821 .40025 L
.31078 .40089 L
.31346 .40136 L
.31481 .40153 L
.31559 .40161 L
Mistroke
.3163 .40167 L
.31757 .40175 L
.31894 .40181 L
.3202 .40182 L
.3214 .4018 L
.32279 .40173 L
.32356 .40168 L
.32426 .40162 L
.32563 .40146 L
.32691 .40127 L
.3298 .40067 L
.33143 .40022 L
.33293 .39972 L
.33787 .39744 L
.34063 .3957 L
.34316 .39383 L
.35271 .38457 L
.36398 .37197 L
.36894 .36718 L
.37441 .36301 L
.37682 .36158 L
.37943 .36032 L
.38168 .35944 L
.38413 .35869 L
.38676 .35809 L
.38819 .35784 L
.38952 .35766 L
.39078 .35752 L
.39191 .35743 L
.39322 .35735 L
.39446 .35731 L
.39572 .35729 L
.39711 .35732 L
.39781 .35734 L
.39856 .35738 L
.39991 .35747 L
.40125 .35761 L
.40253 .35777 L
.40493 .3582 L
.40629 .35852 L
.40774 .35892 L
.41035 .35982 L
.41346 .36124 L
.41627 .36285 L
.42696 .37174 L
.43824 .38301 L
.44289 .38688 L
.44544 .3886 L
.44786 .38992 L
.44923 .39052 L
Mistroke
.45072 .39105 L
.45207 .39143 L
.45332 .39168 L
.4545 .39184 L
.45579 .39193 L
.45715 .39192 L
.45841 .39183 L
.45971 .39165 L
.46091 .39142 L
.46223 .39108 L
.46364 .39064 L
.46861 .38842 L
.47351 .38532 L
.47795 .38175 L
.48314 .37655 L
.48877 .36956 L
.49897 .3532 L
.51948 .31519 L
.54201 .28536 L
.55235 .27358 L
.55804 .26738 L
.56344 .26211 L
.56845 .25806 L
.57391 .2547 L
.57887 .25253 L
.58346 .25104 L
.60471 .24393 L
.60978 .24183 L
.61255 .24078 L
.61512 .23993 L
.61751 .23927 L
.61968 .2388 L
.62084 .2386 L
.62209 .23842 L
.62342 .23828 L
.62467 .23818 L
.62586 .23813 L
.62697 .2381 L
.62818 .23811 L
.62949 .23813 L
.63086 .23819 L
.63215 .23826 L
.63459 .23842 L
.63671 .23856 L
.63787 .23863 L
.63897 .23869 L
.64027 .23874 L
.64144 .23876 L
.64255 .23877 L
.64374 .23875 L
Mistroke
.64502 .23871 L
.64622 .23864 L
.64754 .23854 L
.64895 .2384 L
.65183 .23801 L
.65445 .23756 L
.65913 .23668 L
.6618 .23621 L
.6643 .23585 L
.66548 .23571 L
.66673 .23559 L
.6681 .2355 L
.66936 .23545 L
.67069 .23544 L
.67192 .23547 L
.67328 .23554 L
.67404 .2356 L
.67473 .23566 L
.67711 .23595 L
.67969 .23638 L
.68437 .23731 L
.68988 .2384 L
.69266 .23882 L
.69424 .23901 L
.69572 .23914 L
.69707 .23923 L
.69836 .23928 L
.69951 .2393 L
.70076 .2393 L
.70213 .23927 L
.70281 .23925 L
.70357 .23922 L
.70618 .23907 L
.70884 .2389 L
.71132 .23875 L
.71258 .23869 L
.71391 .23865 L
.71468 .23864 L
.7154 .23864 L
.71675 .23866 L
.71793 .2387 L
.71917 .23878 L
.72023 .23888 L
.72141 .23901 L
.72401 .23941 L
.72646 .23991 L
.74834 .24542 L
.78906 .25284 L
.80976 .2561 L
.83236 .26017 L
Mistroke
.83775 .26174 L
.84039 .26241 L
.84282 .26293 L
.84564 .26339 L
.84712 .26356 L
.84868 .26371 L
.84999 .26379 L
.85121 .26384 L
.85255 .26387 L
.8533 .26388 L
.85398 .26388 L
.85523 .26386 L
.85655 .26383 L
.85892 .26376 L
.86025 .26372 L
.86096 .2637 L
.86169 .26368 L
.86305 .26365 L
.86429 .26364 L
.86544 .26365 L
.86651 .26367 L
.86768 .26371 L
.86893 .26378 L
.87032 .26389 L
.87162 .26402 L
.87406 .26433 L
.88333 .26619 L
.88844 .26729 L
.89096 .26775 L
.8933 .26809 L
.89473 .26826 L
.89603 .26838 L
.89747 .26848 L
.89827 .26853 L
.89901 .26856 L
.90032 .2686 L
.90152 .26861 L
.90284 .26861 L
.9035 .2686 L
.90423 .26859 L
.90557 .26856 L
.90679 .26854 L
.9081 .2685 L
.90879 .26849 L
.90952 .26848 L
.91084 .26846 L
.91206 .26847 L
.9132 .26849 L
.91446 .26853 L
.91584 .26861 L
Mistroke
.91716 .26871 L
.91835 .26884 L
.91964 .26901 L
.92254 .26953 L
.92523 .27017 L
.93533 .27352 L
.95743 .27951 L
.97896 .28737 L
.98834 .29272 L
.99849 .29745 L
1 .29799 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo02kooooo2ol0001gooooo`00T_ooool01Ol@413ooooooooooooooooo410@00oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo027o
oooo3Ol0000;ooooo`oo0000J?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
01gooooo1?l0000Wooooo`?o0000IOooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0000Kooooo`?o0000;_ooool5
o`00063ooooo002eooooo`03o`000?oooooooooo01Sooooo0_l0000fooooo`Oo0000FOooool00;Go
oooo00?o0000ooooooooool05Oooool3o`0003oooooo1_l0001Cooooo`00]Oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo04Kooooo1Ol0001>ooooo`00]Oooool00ol0003ooooooooo
o`0Booooo`;o0000C_ooool4o`0004[ooooo002eooooo`;o00004_ooool00ol0003oooooooooo`1B
ooooo`Go0000AOooool00;Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Hoooo
o`ko0000=oooool001Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^
kP0Jooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hNooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
3Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hJooooo`Go00000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`04onk^
k_lb<S;o0000oc8b<P[o00005?ooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb
<S;ok^k^00kooooo000Fooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Jooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg01[ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL06oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`09ooooo`Co00004Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3_ooool000_ooooo1_l00002ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@01;ooooo
1_l00006ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Aooooo`Ko
00000oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41004oooool6o`00
00Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01kooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Kooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooo
oa0@400Oooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0;ooooo`?o
00002oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`004oooool01?m4A4Co
gMgMooooool00004ooooo`05o`000?ooooooooooooooool000007Oooool00onYZJWo410@ooooo`02
ooooo`05o`000?ooooooooooooooool000007Oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oo
ooooooooooooool000007_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00007_ooool2o`0000kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000007?ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooooooo
ooooool000007_ooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000004?oo
ool4o`0000Oooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000000ko
oooo000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000Loooo
o`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`00000Nooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`00000Nooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00omgMgOo
IVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00ol@413o0000okZj^P03oooo
o`05o`000?ooooooooooooooool000005?ooool4o`0000?ooooo00CogMgMoeEEEOoooooo00001?oo
ool01Ol0003ooooooooooooooooo000000kooooo000Dooooo`03ogMgMoo<c<co000000Cooooo00Go
410@oooooooooooooooooa0@400Mooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Oooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Loooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Nooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41007_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0
7?ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41006?ooool3o`000004
oooooomgMgOoc<c<o`0000Cooooo00Go410@oooooooooooooooooa0@400>ooooo`005?ooool00oo^
k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01Ol@413oV9RHoooooonj
^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`05o`000?nj^[[ooooooiRHV?l@
41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05o`000?nj
^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@oiRHV?oo
oooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool2o`000003odA4A?l0003o
oooo00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`005Oooool00omgMgOo0000ooooo`03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06_ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^01cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^01kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Booooo`03oeEEEOmV
IVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Jooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Oooool2o`0000Cooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0>ooooo`00]Oooool2o`0000[ooooo00?o0000ooooooooool0S?ooool3o`0001Gooooo002e
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0T?ooool2o`0001?ooooo000Foooo
o`Co0000Voooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo09;ooooo00?o0000oooo
ooooool04Oooool001[ooooo1?l0002Gooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0Yoooool001kooooo00?o0000ooooooooool0U?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo0:Oooooo000Foooooooo0000@?l0000Cooooo`005_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00;ooooo4Ol00002ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool001Kooooo00?o0000oooo
ooooool06oooool4o`0000Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo017ooooo000hooooo`Co0000NOooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo0:[ooooo000looooo`;o0000Moooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0:_ooooo000nooooo`;o0000MOooool2o`0000?ooooo00?o0000ooooooooool0Zooo
ool0043ooooo00?o0000ooooooooool0L_ooool01Ol0003ooooooooooooooooo00000:kooooo0011
ooooo`;o0000L_ooool01Ol0003ooooooooooooooooo00000:kooooo0013ooooo`03o`000?oooooo
oooo06oooooo00Co0000oooooooooooo0000[oooool004Cooooo00?o0000ooooooooool0K_ooool0
1?l0003oooooooooool0002_ooooo`00AOooool2o`0006kooooo0ol0002`ooooo`00Aoooool00ol0
003oooooooooo`1[ooooo`03o`000?oooooo00000;3ooooo0018ooooo`;o0000Joooool2o`000;7o
oooo001:ooooo`03o`000?oooooooooo06Sooooo0_l0002aooooo`00Boooool00ol0003ooooooooo
o`1Wooooo`03o`000?oooooooooo0;3ooooo001<ooooo`03o`000?oooooooooo06Kooooo0_l0002a
ooooo`00COooool00ol0003oooooooooo`0nooooo`_o00006oooool2o`000;;ooooo001>ooooo`;o
0000?Oooool2o`0000[ooooo0ol0000Gooooo`03o`000?oooooo00000;;ooooo001@ooooo`;o0000
2_ooool8o`0002Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Cooooo`04o`00
0?ooooooooooo`000;;ooooo001Booooo`[o00002?ooool6o`00027ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0Aooooo`05o`000?ooooooooooooooool00000/_ooool006[ooooo
0_l0000Nooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool01?l0003ooooo
ooooooooool2o`000;7ooooo001/ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
/?ooool006gooooo0_l0000Iooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q00Coooooo`000?oooooooooo1Ol00004ooooo`04odA4A?l0003o0000oc8b
<P;o00001?ooool00ol0003oooooooooo`2`ooooo`00Koooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo00Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q0_ooool01ol0
003ooooooiRHV?lQ8B7ok^k^oooooom4A4@01_ooool2o`000003oc8b<_oooooooooo00?ooooo00?o
0000ooooooooool0/?ooool0073ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`09
ooooo`05oa0@4?ooooooooooooooool@41002_ooool2o`000003oiRHV?lQ8B7ok^k^00Kooooo00Co
0000oooooooooooo00001Oooool00ol0003oooooooooo`2`ooooo`00LOooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00000<ooooo`;o0000
00?o8B4Qonk^k_ooool00_ooool2o`0000;ooooo00?oMgMgoc8b<_ooool01?ooool3o`000;3ooooo
001booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02oooool01Ol0003ooooooooo
oooooooo000000gooooo0ol000002Ooooooo0000o`000?oooooo0000ob4Q8Ol0003o<S8bolc<c005
ooooo`03o`000?oooooooooo0;3ooooo001cooooo`;o00003_ooool00ol0003oooooooooo`0<oooo
o`05oa0@4?ooooooooooooooool@41003oooool2o`0000?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`2`ooooo`00MOooool00ol0003oooooooooo`09ooooo`;o00003oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0/?ooool007Kooooo1?l00005ooooo`;o00004Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co0000
1_ooool00ol0003oooooooooo`2`ooooo`00NOooool6o`0003Kooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooooooo
o`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo0ol0002`ooooo`00V_ooool01Ol0003ooooooooooooo
oooo000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0002aooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`00
0?oooooooooo0;3ooooo002Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo
00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo
002Booooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`000;3ooooo
002Booooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooo
oooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413o
oooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`oooo
o`00T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool00ol0
003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002[ooooo`Co000000?o410@ooooooooool00oooool00ol0003ooooooooo
o`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;3ooooo002]oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool00:gooooo00?o0000oooooooo
ool01Oooool3o`000;3ooooo002]ooooo`03o`000?oooooooooo0;Sooooo002]ooooo`03o`000?oo
oooooooo0;Sooooo002]ooooo`03o`000?oooooooooo0;Sooooo002[ooooo`03oeEEEOmVIVKo0000
0;[ooooo003oooooofWooooo002_ooooo`03o`000?nj^[[ooooo0;Kooooo002_ooooo`;o<S8b]ooo
ool0083ooooo0_l000001_l@413oooooooooool@413o0000oa0@41Oooooo1Ol00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4
A?nj^[X06_ooool00ol0003ok^k^ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^07Sooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01oooool6o`0000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@
41002Oooool6o`0000_ooooo00?oEEEEojVYZOooool00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1hooooo`00POooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01Oooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo
410@01;ooooo00?o0000ooooooooool07?ooool00onYZJWoEEEEooooo`03ooooo`05oa0@4?oooooo
ooooooooool@41000oooool01Ol@413ooooooooooooooooo410@07Sooooo0021ooooo`06o`000?oo
ooooA4A4odA4A?oooooo00002Oooool6o`0000_ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003o
oooooooooooooooo000001;ooooo00?o0000ooooooooool02oooool6o`0000cooooo00?o8B4Qoooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
001hooooo`00POooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001_ooooo00?oMgMgofIVI_ooool0
0_ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool07Oooool00omEEEGo
c<c<ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000007Sooooo0021ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo00007?ooool01Ol0003ooooooooo
oooooooo410@00?ooooo00?o410@ooooooooool03_ooool00ol@413o0000o`000003o`0001cooooo
00?oZJVYogMgMoooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooooooooa0@401hooooo`00POooool01_l0003o<S8boooooooooooo<S8bo`0001Sooooo00Go0000
okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool00ol0003ooooo
ooooo`0Jooooo`05oa0@4?oooooooooooooooolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1hooooo`00P?ooool00ol@413o0000ohN7Q`02oooo
o`03ohN7Qol0003o410@01Oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Jooooo`Go00000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(710) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30124 m
.00488 .30187 L
.00942 .30263 L
.01483 .30374 L
.01975 .3048 L
.02223 .30528 L
.02492 .30571 L
.02615 .30587 L
.02746 .30601 L
.02858 .3061 L
.02981 .30616 L
.03052 .30619 L
.0312 .3062 L
.03248 .3062 L
.03386 .30615 L
.03464 .30611 L
.03536 .30606 L
.03668 .30594 L
.03788 .3058 L
.04057 .30542 L
.04589 .30451 L
.0488 .30402 L
.05151 .30365 L
.05293 .3035 L
.05366 .30343 L
.05445 .30338 L
.05532 .30333 L
.05614 .3033 L
.05694 .30328 L
.05768 .30328 L
.05898 .3033 L
.05973 .30333 L
.06043 .30337 L
.06183 .30349 L
.06335 .30365 L
.06595 .30404 L
.0688 .30458 L
.07454 .30587 L
.08481 .30811 L
.08989 .3091 L
.0954 .31032 L
.09793 .31102 L
.1006 .31192 L
.1054 .31403 L
.11089 .3173 L
.11693 .3218 L
.1274 .33053 L
.14953 .34501 L
.16002 .3508 L
.16975 .35581 L
Mistroke
.17225 .35683 L
.1746 .35764 L
.1759 .358 L
.17731 .35833 L
.17859 .35857 L
.17976 .35873 L
.18107 .35885 L
.18229 .35891 L
.18363 .3589 L
.18438 .35887 L
.18507 .35882 L
.18645 .35868 L
.18723 .35857 L
.18794 .35845 L
.19067 .35788 L
.20091 .35472 L
.20593 .35325 L
.20831 .35269 L
.21052 .35227 L
.21272 .35194 L
.21398 .35179 L
.21513 .35169 L
.21634 .3516 L
.21747 .35154 L
.21868 .35149 L
.21998 .35146 L
.2212 .35145 L
.22255 .35146 L
.22323 .35147 L
.22396 .35149 L
.22528 .35152 L
.22783 .35162 L
.23016 .35174 L
.23292 .35191 L
.23548 .35212 L
.23828 .35243 L
.24127 .35289 L
.24385 .35344 L
.24627 .35413 L
.24893 .35512 L
.2518 .35651 L
.257 .35992 L
.26184 .36414 L
.27282 .37633 L
.28421 .38905 L
.2898 .39419 L
.29497 .39808 L
.29987 .40107 L
.30526 .4036 L
.30806 .40458 L
Mistroke
.31068 .40529 L
.31212 .40557 L
.31345 .40576 L
.31418 .40584 L
.31497 .4059 L
.31572 .40592 L
.31642 .40593 L
.31765 .40588 L
.31897 .40575 L
.32023 .40554 L
.32138 .40527 L
.32356 .40456 L
.32587 .40352 L
.32835 .40205 L
.33067 .40037 L
.33593 .39548 L
.35551 .37212 L
.36088 .36689 L
.36658 .36256 L
.37144 .35982 L
.37681 .35766 L
.3797 .35683 L
.38235 .35626 L
.38374 .35604 L
.38453 .35593 L
.38526 .35586 L
.38603 .3558 L
.38684 .35575 L
.3876 .35573 L
.38832 .35573 L
.38963 .35577 L
.39102 .35589 L
.3922 .35606 L
.39351 .35632 L
.39491 .35669 L
.39641 .35719 L
.39912 .35841 L
.40184 .36005 L
.40479 .36232 L
.41017 .36771 L
.42026 .3809 L
.42539 .38801 L
.43093 .39502 L
.43582 .40014 L
.44097 .40417 L
.44385 .40578 L
.44548 .40648 L
.447 .407 L
.4484 .40737 L
.44968 .40761 L
Mistroke
.45038 .40771 L
.45115 .40778 L
.45187 .40783 L
.45254 .40784 L
.45379 .4078 L
.45496 .40769 L
.45624 .40749 L
.45762 .40717 L
.45906 .40672 L
.46043 .40619 L
.46301 .40489 L
.46573 .40308 L
.46828 .40093 L
.47307 .3957 L
.47822 .38824 L
.4838 .37817 L
.5031 .33576 L
.52402 .29922 L
.5347 .28419 L
.54614 .26922 L
.55167 .26319 L
.55692 .25864 L
.56163 .25558 L
.56675 .2532 L
.586 .24658 L
.5967 .24181 L
.59925 .24077 L
.60194 .23982 L
.60443 .23911 L
.60675 .2386 L
.60791 .2384 L
.60916 .23824 L
.61054 .23811 L
.61179 .23804 L
.61314 .23801 L
.61389 .23801 L
.61459 .23803 L
.61587 .23808 L
.61723 .23816 L
.62328 .23872 L
.62592 .23896 L
.62665 .23901 L
.62742 .23906 L
.62881 .23912 L
.63018 .23916 L
.63147 .23916 L
.63263 .23913 L
.63388 .23907 L
.63511 .23898 L
.6364 .23886 L
Mistroke
.63871 .23856 L
.64421 .23763 L
.6469 .23714 L
.64935 .23673 L
.65044 .23658 L
.65162 .23643 L
.65265 .23632 L
.65378 .23623 L
.65497 .23617 L
.65624 .23613 L
.65742 .23614 L
.65852 .23618 L
.65975 .23625 L
.66105 .23638 L
.66215 .23651 L
.66336 .23669 L
.66857 .23776 L
.67367 .23902 L
.67635 .23964 L
.67919 .24021 L
.68167 .2406 L
.68308 .24077 L
.6844 .24089 L
.68561 .24097 L
.68671 .24102 L
.68799 .24105 L
.6892 .24106 L
.68986 .24106 L
.69059 .24104 L
.69135 .24102 L
.69206 .241 L
.69472 .24089 L
.69625 .24082 L
.69785 .24075 L
.69923 .24071 L
.70001 .24069 L
.70073 .24068 L
.70201 .24069 L
.70317 .24072 L
.7045 .24078 L
.70577 .24088 L
.70712 .24101 L
.70838 .24118 L
.7112 .24169 L
.75253 .24964 L
.77328 .25484 L
.77768 .25617 L
.78009 .25679 L
.78236 .25727 L
.78365 .25749 L
Mistroke
.78505 .2577 L
.78622 .25784 L
.7875 .25797 L
.78871 .25807 L
.78998 .25814 L
.79116 .25819 L
.79227 .25822 L
.79362 .25824 L
.7949 .25825 L
.79606 .25825 L
.79731 .25825 L
.79867 .25825 L
.79936 .25826 L
.80012 .25827 L
.80146 .25829 L
.80272 .25833 L
.80393 .25839 L
.80521 .25848 L
.8075 .25868 L
.80996 .259 L
.81265 .25945 L
.81856 .26073 L
.82414 .26201 L
.82657 .26249 L
.82915 .26291 L
.83049 .26309 L
.83197 .26324 L
.83332 .26334 L
.83458 .2634 L
.83585 .26343 L
.83724 .26344 L
.83855 .26341 L
.83977 .26336 L
.84097 .2633 L
.84206 .26322 L
.84451 .26303 L
.84721 .2628 L
.84869 .26268 L
.85007 .26258 L
.85134 .26251 L
.8525 .26246 L
.85379 .26243 L
.85517 .26242 L
.85652 .26245 L
.85727 .26247 L
.85797 .26251 L
.85926 .2626 L
.86062 .26272 L
.86342 .26308 L
.86651 .26361 L
Mistroke
.87717 .26575 L
.87979 .26618 L
.88258 .26654 L
.88418 .2667 L
.88564 .26681 L
.8871 .2669 L
.88848 .26697 L
.88979 .26701 L
.89117 .26705 L
.89365 .2671 L
.89494 .26713 L
.89632 .26717 L
.89783 .26723 L
.89924 .26731 L
.90059 .26741 L
.90184 .26753 L
.90467 .26791 L
.90716 .26839 L
.90981 .26905 L
.91439 .27054 L
.91945 .27256 L
.96013 .28673 L
1 .30124 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo02[ooooo2_l0001looooo`00T_ooool01Ol@413ooooooooooooooooo410@00oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01co
oooo3_l0000:ooooo`co0000L?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
01[ooooo0ol0000Rooooo`Go0000K?ooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0000Hooooo`?o0000:_ooool7
o`0006Gooooo002eooooo`03o`000?oooooooooo01Cooooo0ol0000dooooo`Go0000H?ooool00;Go
oooo00?o0000ooooooooool04Oooool3o`0003cooooo0ol0001Mooooo`00]Oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo043ooooo0ol0001Jooooo`00]Oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo04Cooooo3?l0001>ooooo`00]Oooool2o`0000oooooo00?o0000
ooooooooool0DOooool5o`0000Cooooo1_l0000oooooo`00]Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo05Kooooo1Ol00006ooooo`Ko0000>Oooool001Gooooo0_l000002Ol@413o
ooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0Jooooo`05oiRHV?l@413o0000oc8b<_o<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h07?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hNooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool04?ooool4o`000008oa0@4?ooooooooooonk^k_lb
<S;o0000oc8b<_o^k^hJooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00Go
V9RHoa0@4?l0003o<S8bolc<c003ooooo`03onk^k_lb<S;o000000Wo00005_ooool2o`000009oa0@
4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Fooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05oa0@4?nj^[[oooooogMgMolb<S800ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL07_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool01Ol@413o^[ZjoooooomgMgOo<S8b
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Booooo`Ko00001_ooool01Ol0003ooooooooo
oooooooo410@00?ooooo00?o410@ooooooooool04Oooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h0
1?ooool01Ol@413ooooooooooooooooo410@01?ooooo1_l00005ooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@400Nooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41006oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41007oooool01Ol0003ooooooooo
oooooooo410@00?ooooo00?o410@ooooooooool01_ooool3o`00013ooooo1Ol00003ooooo`05oa0@
4?ooooooooooooooool@41003_ooool001?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003o
oooooooooooooooo000001gooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo
000001gooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000001kooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001kooooo0_l0000;ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001co
oooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000001kooooo00?oZJVYoa0@
4?ooool00_ooool01Ol0003ooooooooooooooooo000000_ooooo0ol0000=ooooo`04odA4A?oMgMgo
ooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`004oooool01?oMgMgoEEEEoooo
ool00004ooooo`05o`000?ooooooooooooooool000007?ooool00ol@413o0000okZj^P03ooooo`05
o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooooooo
ooooool000007_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000001gooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooo
oooooooooooo000001gooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo0000
00kooooo0ol0000:ooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`00
000>ooooo`005?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41007Ooo
ool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41007oooool01Ol0003ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool07?ooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41007_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01kooooo00Go0000
oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Oooool00_oo
ool01Ol@413ooooooooooooooooo410@017ooooo0ol00008ooooo`03ogMgMoo<c<co000000Cooooo
00Go410@oooooooooooooooooa0@400>ooooo`005?ooool00oo^k^koA4A4o`000004ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL06_ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Kooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg01kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01ko
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL05?ooool3o`0000Gooooo00?ok^k^odA4A?l000001?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00kooooo000Eooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0Jooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h07?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo01Gooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^01[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h06oooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0Gooooo`?o00000oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03_ooool00;Gooooo0_l00007ooooo`03o`000?oooooooooo08_ooooo0ol0000Ioooo
o`00]Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo08kooooo0_l0000Gooooo`00
]Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo097ooooo0ol0000Dooooo`005_oo
ool6o`0000[ooooo1Ol0002:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0U?oo
ool00ol0003oooooooooo`0Aooooo`007?ooool:o`0000Gooooo1Ol00025ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0ZOooool001Koooooool00010o`0001?ooooo000Fooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo0ol00006ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool0
00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Aooooo`005_ooool00ol0003oooooooooo`0Nooooo`;o0000
1?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
4Oooool003Wooooo0_l0001jooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Zooo
ool003_ooooo00?o0000ooooooooool0Moooool01Ol0003ooooooooooooooooo00000:kooooo000l
ooooo`03o`000?oooooooooo07Kooooo0_l00002ooooo`03o`000?oooooooooo0:cooooo000moooo
o`03o`000?oooooooooo07Gooooo00Co0000oooooooooooo0000[oooool003kooooo0_l0001eoooo
o`03o`000?oooooo00000;3ooooo0010ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooool0
0000/?ooool0047ooooo0_l0001booooo`;o0000/Oooool004?ooooo00?o0000ooooooooool0Kooo
ool2o`000;7ooooo0014ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0/?ooool0
04Gooooo0ol0001]ooooo`03o`000?oooooooooo0;3ooooo0018ooooo`?o0000JOooool2o`000;;o
oooo001;ooooo`03o`000?oooooooooo00Wooooo3_l0001?ooooo`;o0000/_ooool004cooooo0_l0
0006ooooo`?o00003_ooool3o`0002Oooooo1_l0000Nooooo`04o`000?oooooo0000o`000;7ooooo
001=ooooo`Oo00005?ooool00ol0003oooooooooo`0Pooooo`Co00001_ooool2o`0001cooooo00?o
0000ooooool00000/_ooool006Sooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooool00000/_ooool006Wooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Sooooo00Co0000oooo
oooooooo0000/_ooool006[ooooo00?o0000ooooooooool06oooool2o`0000kooooo00?o0000oooo
ooooool05oooool01?l0003oooooooooool0002booooo`00Joooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool05_ooool01?l0003oooooooooooooool2
o`000;7ooooo001/ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Eooooo`05o`000?ooooooooooooooool00000/_ooool006gooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`09ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1?l0003oooooob4Q8OlQ8B44ooooo`Go00001?ooool01_m4A4Co0000o`000?lb<S;ogMgMo`0000Co
oooo00?o0000ooooooooool0/?ooool006gooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0:ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003o8B4Qob4Q8@04ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8bo`000004ooooo`03o`000?oooooooooo
0;3ooooo001^ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02oooool01Ol@413o
oooooooooooooooo410@00Gooooo00?o0000ooooooooool01?ooool00onHV9So8B4Qonk^kP09oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool006oooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000oc8b<_ooool01?ooool3o`00
0;3ooooo001`ooooo`;o00004Oooool00ol0003oooooooooo`0<ooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooooooo`05ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q
8Ol0003o0000olc<c005ooooo`03o`000?oooooooooo0;3ooooo001booooo`;o00003_ooool00ol0
003oooooooooo`0=ooooo`05oa0@4?ooooooooooooooool@41001oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`2`
ooooo`00M?ooool00ol0003oooooooooo`09ooooo`;o00004?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Sooooo00So0000oooooooooooo0000okZj^_ooooooV9RHoa0@40Cooooo0_l00008ooooo`03
o`000?oooooooooo0;3ooooo001eooooo`;o00002?ooool00ol0003oooooooooo`0@ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02Oooool2o`000005oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`00
00Kooooo00?o0000ooooooooool0/?ooool007Oooooo00?o0000ooooooooool00oooool2o`0002?o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`;o0000/Oooool007Sooooo
1_l0000Uooooo`;o00000_ooool3o`0000_ooooo00?o0000ooooooooool0/?ooool00:Gooooo0ol0
000=ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooooooo
ool00oooool3o`000;3ooooo002Jooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05o`000?ooooooooooooooool0
00003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool009[o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_oo
ool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009;ooooo00Go410@oooooooo
oooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qoooo
ooooool01_ooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005
ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003_ooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool0
09;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00:_o
oooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002]ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool00:gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool0
0:gooooo00?o0000ooooooooool0^?ooool00:gooooo00?o0000ooooooooool0^?ooool00:gooooo
00?o0000ooooooooool0^?ooool00:_ooooo00?oEEEEofIVI_l00000^_ooool00?ooooooJOooool0
0:oooooo00?o0000okZj^_ooool0]_ooool00:oooooo0_lb<S:gooooo`00P?ooool2o`000006oa0@
4?oooooooooooa0@4?l0003o410@5oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Jooooo`03o`000?o^
k^kooooo00Cooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^N?ooool0087o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00002Oooool01OnHV9So
8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03olc<c?l0003o
410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002oooool00omEEEGoZJVYoooo
o`06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1hooooo`00POoo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Oooooo00?oV9RHob4Q8Oo^k^h01?oo
ool01Ol@413ooooooooooooooooo410@01;ooooo00?o0000ooooooooool07?ooool00onYZJWoEEEE
ooooo`06ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@401hooooo`00
POooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000;ooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo00_ooooo1_l0000<
ooooo`03ob4Q8Ooooooooooo00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000007Sooooo0021ooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo00006oooool00omgMgOoIVIV
ooooo`02ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0Mooooo`03
oeEEEOo<c<cooooo00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
07Sooooo0021ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo00007?ooool01Ol0003ooooooooooooo
oooo410@00?ooooo00?o410@ooooooooool03_ooool00ol@413o0000o`000003o`0001cooooo00?o
ZJVYogMgMoooool01Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
N?ooool0087ooooo00Ko0000oc8b<_oooooooooooc8b<_l0000Hooooo`05o`000?nj^[[ooooooiRH
V?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool06_ooool0
1Ol@413ooooooooooooooooo<S8b00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg07Sooooo0020ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41005ooo
ool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Booooo`03
o`000?oooooooooo01[ooooo1Ol00004ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP1hooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(720) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .29967 m
.00488 .30002 L
.00722 .30019 L
.00942 .30032 L
.01068 .30037 L
.01204 .30041 L
.01327 .30042 L
.01441 .30041 L
.01565 .30037 L
.017 .30031 L
.01769 .30026 L
.01842 .3002 L
.01975 .30007 L
.02241 .29972 L
.02532 .29922 L
.03062 .29813 L
.03308 .29763 L
.03574 .29713 L
.03696 .29694 L
.03825 .29676 L
.03937 .29663 L
.04057 .29652 L
.04132 .29647 L
.042 .29644 L
.04334 .2964 L
.04409 .2964 L
.04491 .29641 L
.04568 .29644 L
.04639 .29649 L
.04761 .29659 L
.04895 .29674 L
.05167 .29718 L
.05461 .29782 L
.05778 .29865 L
.06351 .30036 L
.07368 .30334 L
.07906 .30491 L
.08481 .3069 L
.09052 .30954 L
.09571 .31271 L
.10585 .32077 L
.11738 .33053 L
.12801 .33756 L
.13779 .34237 L
.14815 .34685 L
.15316 .34877 L
.15593 .34966 L
.15855 .35034 L
.16003 .35065 L
.16081 .35078 L
Mistroke
.16164 .3509 L
.1624 .35098 L
.1631 .35105 L
.16446 .35112 L
.16583 .35112 L
.1666 .3511 L
.16731 .35105 L
.16861 .35092 L
.16999 .3507 L
.17127 .35045 L
.17267 .3501 L
.17521 .34931 L
.17997 .3474 L
.19065 .34245 L
.19551 .34059 L
.19817 .33977 L
.20066 .33914 L
.20296 .33868 L
.20506 .33834 L
.2074 .33804 L
.20991 .33781 L
.21126 .33771 L
.21253 .33763 L
.21368 .33757 L
.21491 .33752 L
.21624 .33748 L
.21746 .33745 L
.21878 .33743 L
.21953 .33743 L
.22023 .33743 L
.22147 .33745 L
.22265 .33748 L
.22371 .33752 L
.22486 .33758 L
.22611 .33768 L
.22744 .33782 L
.22857 .33797 L
.22982 .33817 L
.23119 .33845 L
.23263 .33881 L
.23522 .33964 L
.23799 .34085 L
.24104 .34258 L
.24649 .34683 L
.25157 .35204 L
.27122 .37747 L
.28157 .38961 L
.29254 .39994 L
.29808 .40391 L
.30123 .40564 L
Mistroke
.30274 .4063 L
.30418 .40682 L
.30547 .40719 L
.30616 .40734 L
.30688 .40747 L
.30817 .40762 L
.30936 .40766 L
.31008 .40764 L
.31086 .40758 L
.3116 .40748 L
.31228 .40735 L
.31356 .40702 L
.31492 .40654 L
.31744 .4053 L
.32014 .40347 L
.32501 .39898 L
.33607 .3851 L
.34677 .37124 L
.35241 .36506 L
.35839 .35958 L
.36361 .35566 L
.36638 .35389 L
.36937 .35223 L
.3721 .35097 L
.37461 .35006 L
.37585 .3497 L
.377 .34943 L
.37821 .34922 L
.37952 .34908 L
.38087 .34903 L
.38154 .34905 L
.38229 .3491 L
.3836 .34927 L
.38483 .34953 L
.38558 .34974 L
.38628 .34998 L
.38761 .35051 L
.39058 .35218 L
.39318 .35416 L
.39558 .35644 L
.40102 .36305 L
.42054 .39538 L
.4259 .4039 L
.43168 .41196 L
.43678 .41785 L
.43956 .4205 L
.44215 .42256 L
.4445 .42405 L
.4457 .42467 L
.44701 .42522 L
Mistroke
.44776 .42547 L
.44845 .42567 L
.4498 .42593 L
.45104 .42604 L
.45234 .426 L
.45345 .42584 L
.45464 .42553 L
.45577 .42512 L
.4568 .42462 L
.45931 .42295 L
.4617 .42073 L
.46442 .41747 L
.46698 .41369 L
.47176 .40493 L
.48249 .37956 L
.50179 .33244 L
.52287 .29234 L
.53222 .27713 L
.53738 .27008 L
.54226 .26459 L
.5476 .25999 L
.55248 .25692 L
.56202 .25267 L
.57253 .24802 L
.5783 .24507 L
.58371 .24239 L
.58849 .24046 L
.59117 .23965 L
.59364 .23911 L
.59496 .23891 L
.59619 .23878 L
.59754 .23869 L
.59829 .23866 L
.59898 .23865 L
.60037 .23867 L
.60115 .2387 L
.60187 .23874 L
.6032 .23884 L
.6046 .23898 L
.60904 .23953 L
.61149 .23982 L
.61381 .24004 L
.61512 .24013 L
.61586 .24017 L
.61655 .24019 L
.61776 .24021 L
.61904 .2402 L
.62037 .24015 L
.62161 .24006 L
.62273 .23996 L
Mistroke
.62394 .23981 L
.62918 .23894 L
.63206 .23838 L
.63479 .23788 L
.63733 .23749 L
.63876 .23732 L
.64009 .23721 L
.6412 .23715 L
.64243 .23712 L
.64371 .23714 L
.64491 .2372 L
.6462 .23731 L
.64756 .23748 L
.64999 .23791 L
.65261 .23852 L
.65546 .23933 L
.66142 .24118 L
.66434 .24201 L
.66704 .24264 L
.66956 .2431 L
.67083 .24328 L
.67223 .24343 L
.67295 .24349 L
.67363 .24354 L
.67441 .24358 L
.67513 .2436 L
.67643 .24363 L
.67717 .24363 L
.67785 .24362 L
.67901 .2436 L
.68011 .24356 L
.6826 .24345 L
.68502 .24335 L
.68638 .2433 L
.68766 .24328 L
.68896 .24329 L
.69035 .24333 L
.69111 .24336 L
.69183 .24341 L
.69318 .24353 L
.69444 .24368 L
.69561 .24386 L
.69824 .24439 L
.70088 .24508 L
.70379 .24601 L
.70967 .24817 L
.71513 .2501 L
.71782 .2509 L
.72031 .2515 L
.72257 .25192 L
Mistroke
.72497 .25224 L
.72634 .25237 L
.72764 .25246 L
.7288 .25252 L
.73005 .25256 L
.73142 .25259 L
.7327 .2526 L
.73343 .25261 L
.7341 .25261 L
.73488 .25261 L
.73561 .25262 L
.73631 .25262 L
.73705 .25263 L
.7378 .25265 L
.73862 .25267 L
.73933 .25269 L
.74009 .25272 L
.74147 .2528 L
.74275 .25291 L
.74414 .25305 L
.74695 .25345 L
.74956 .25396 L
.75198 .25453 L
.75728 .25604 L
.76303 .25771 L
.76567 .25836 L
.76846 .25892 L
.77084 .25927 L
.7722 .25942 L
.77346 .25951 L
.77467 .25957 L
.77599 .2596 L
.77723 .2596 L
.77838 .25958 L
.77952 .25954 L
.78056 .25948 L
.78288 .25933 L
.7877 .25896 L
.78902 .25887 L
.78975 .25883 L
.79043 .2588 L
.79177 .25875 L
.79298 .25873 L
.79426 .25873 L
.79545 .25876 L
.79674 .25881 L
.79812 .2589 L
.79945 .25901 L
.8007 .25914 L
.80354 .25952 L
Mistroke
.80851 .26033 L
.81324 .2611 L
.81587 .26144 L
.81736 .26159 L
.81874 .2617 L
.82002 .26178 L
.82118 .26182 L
.82251 .26184 L
.82377 .26184 L
.82515 .2618 L
.82585 .26177 L
.82661 .26173 L
.82922 .26155 L
.83204 .26131 L
.83512 .26103 L
.8365 .26092 L
.83797 .26081 L
.83922 .26075 L
.84061 .2607 L
.8419 .26068 L
.84263 .26069 L
.8433 .2607 L
.84452 .26074 L
.84582 .26082 L
.84698 .26091 L
.84823 .26105 L
.85048 .26136 L
.85558 .26236 L
.87754 .26663 L
.88275 .26719 L
.88561 .26754 L
.88828 .26797 L
.89116 .26856 L
.89434 .2694 L
.89993 .27139 L
.92108 .2811 L
.94198 .28761 L
.95227 .29192 L
.95728 .29425 L
.96182 .2962 L
.96638 .2978 L
.96846 .29838 L
.97066 .29887 L
.97179 .29907 L
.97302 .29926 L
.97416 .2994 L
.97519 .2995 L
.97641 .29959 L
.97772 .29966 L
.97893 .29969 L
Mistroke
.98008 .2997 L
.98123 .2997 L
.98249 .29968 L
.9838 .29965 L
.98504 .29961 L
.98728 .29954 L
.98849 .2995 L
.98963 .29947 L
.99087 .29945 L
.99223 .29943 L
.99339 .29944 L
.99462 .29945 L
.99532 .29947 L
.99607 .29949 L
.99744 .29954 L
.99877 .2996 L
1 .29967 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo02Sooooo1_l00022ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Wo
oooo3ol00005ooooo`?o0000P?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
01Oooooo0_l0000Gooooo`co0000M?ooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0000Fooooo`;o00009Oooool4
o`00073ooooo002eooooo`03o`000?oooooooooo01?ooooo0_l0000[ooooo`;o0000K_ooool00;Go
oooo00?o0000ooooooooool04?ooool3o`0002oooooo2ol0001Sooooo`00]Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo03[ooooo1Ol0001Oooooo`00]Oooool00ol0003ooooooooo
o`0=ooooo`;o0000@_ooool>o`00057ooooo002eooooo`;o00003?ooool2o`0005;ooooo4_l0000o
ooooo`00]Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo06Cooooo0ol0000loooo
o`005Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00Go
V9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool5o`0000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Looooo`Co000000So410@ooooooooooook^k^oc8b<_l0
003o<S8bonk^kQkooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Booooo`Co0000
00So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQ[ooooo1Ol00003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h06oooool01OnHV9So410@o`000?lb<S;oc<c<00;ooooo1_l0000Mooooo`;o0000
00Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h03_ooool001Kooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00Go410@okZj^_ooooooMgMgoc8b
<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool01OnHV9So8B4Qonk^k_ooooooA4A400?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01OnHV9So8B4Qonk^
k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`05oa0@4?nj^[[oooooogMg
Molb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Co00006_ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool000_ooooo1_l00002ooooo`Go00000oooool0
1Ol@413ooooooooooooooooo410@01;ooooo1_l00006ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41004oooool6o`0000Gooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@01kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Kooooo`03oiRHV?lQ8B7o
k^k^00Cooooo00Go410@oooooooooooooooooa0@400Oooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`02ooooo`?o00005?ooool5o`0000?ooooo00Go410@oooooooooooo
oooooa0@400>ooooo`004oooool01?m4A4CogMgMooooool00004ooooo`05o`000?oooooooooooooo
ool000007Oooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool0
0onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000007_ooool2o`0000Sooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007?ooool00onHV9So
8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000007_ooool00onYZJWo410@ooooo`02oooo
o`05o`000?ooooooooooooooool000001oooool2o`0001;ooooo00CoA4A4omgMgOoooooo00001?oo
ool01Ol0003ooooooooooooooooo000000kooooo000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo
00Go0000ooooooooooooooooo`00000Looooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000oooooooo
ooooooooo`00000Nooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00000N
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Nooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000007Oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool0
00007Oooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000002Oooool3o`00
00oooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000kooooo000D
ooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@400Mooooo`03okZj^_lQ
8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@400Oooooo`05o`000?ooooooooooooooool@
41000oooool00ol@413oooooooooo`0Looooo`03o`000?oooooooooo00;ooooo00Go410@oooooooo
oooooooooa0@400Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41007_ooool01Ol0003ooooooooooooo
oooo410@00?ooooo00?o410@ooooooooool07?ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41003?ooool3o`0000gooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooo
oooooooooooo410@00kooooo000Dooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Jooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9So
MgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
7_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg01[ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL06oooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0?ooooo`?o00002_ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03_ooool001Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06ooo
ool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Looooo`03
oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Nooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool05oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h06_ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01;ooooo00?o0000ooooooooool02?ooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03_ooool00;Gooooo0_l00005ooooo`03o`000?oooooooooo08Kooooo0ol0000Poooo
o`008Oooool6o`0008kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`29ooooo`03
o`000?oooooooooo01gooooo000Fooooo`_o00001_ooool6o`0008Sooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`2;ooooo`co00004oooool002gooooo0_l00026ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0Z_ooool002oooooo1?l00022ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0Zoooool001Koooooool00010o`0001?ooooo000Fooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooool000001_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`005_ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo02Gooooo00Co0000oooooooooooo00009?ooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0Aooooo`00=_ooool00ol0003oooooooooo`1looooo`04o`000?ooooooooooo`00
0:oooooo000gooooo`;o0000O?ooool00ol0003oooooo`00002`ooooo`00>Oooool00ol0003ooooo
ooooo`1iooooo`?o0000/?ooool003[ooooo00?o0000ooooooooool0N?ooool2o`000;7ooooo000k
ooooo`;o0000N?ooool2o`000;7ooooo000mooooo`03o`000?oooooooooo07Gooooo00?o0000oooo
ooooool0/?ooool003kooooo0_l0000Gooooo`Wo0000EOooool00ol0003oooooooooo`2`ooooo`00
@?ooool2o`00017ooooo1?l00008ooooo`?o0000D_ooool3o`000;7ooooo0012ooooo`?o00003?oo
ool2o`0000oooooo0_l0001@ooooo`;o0000/_ooool004Gooooo00?o0000ooooooooool01_ooool3
o`0001?ooooo00?o0000ooooooooool0COooool2o`000;;ooooo0016ooooo`Co000000Coooooo`00
0?l0003o00005oooool00ol0003oooooooooo`0Tooooo`Ko00008Oooool00ol0003oooooo`00002b
ooooo`00B_ooool2o`0001[ooooo00?o0000ooooooooool08Oooool2o`0000Kooooo00?o0000oooo
ooooool07_ooool00ol0003oooooo`00002booooo`00I_ooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo00Oooooo0_l0000Mooooo`03o`000?oooooooooo00;o0000/Oooool006Oooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01_ooooo
00Co0000oooooooooooo0000/_ooool006Sooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo01[ooooo00Co0000oooooooooooo0000/_ooool006Wooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Wooooo
00Go0000ooooooooooooooooo`00002booooo`00JOooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo00000;;o
oooo001Zooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo00;ooooo0_l0002aooooo`00Joooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo0;3ooooo001/ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool03?ooool01oo^k^ko<S8bo`000?lb<S;ok^k^ooooool000000oooool2ob4Q8@Cooooo
1Ol00004ooooo`06odA4A?l0003o0000oc8b<_oMgMgo00001?ooool00ol0003oooooooooo`2`oooo
o`00K?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`02ooooo`03o`000?oooooooooo00;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400Oooooo00?oMgMgo`000?ooool01?ooool00ol0003oooooooooo`2`ooooo`00KOooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo00kooooo00Go410@oooooooooooooooooa0@4002
ooooo`03o`000?oooooooooo00Oooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo0;3ooooo001^ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool03_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01oooool0
0onHV9So8B4Qonk^kP07ooooo`03o`000?lb<S;ooooo00Cooooo0ol0002`ooooo`00Koooool2o`00
00oooooo00?o0000ooooooooool03oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool02?ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000o`000?o<c<`01Ooo
ool00ol0003oooooooooo`2`ooooo`00LOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo013ooooo00Go410@oooooooooooooooooa0@4004ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo0;3ooooo
001booooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo00?o0000ooooooooool00oooool01Ol0003o^[ZjoooooonHV9So410@00Co
oooo00?o0000ooooool000001oooool00ol0003oooooooooo`2`ooooo`00Loooool2o`0000Sooooo
00?o0000ooooooooool04_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000oooooooo
ool00oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo
0;3ooooo001eooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo0_l0002aooooo`00M_ooool2o`000004oooo
ool0003o0000o`00027ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo0;3ooooo001hooooo`;o00009?ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0;3ooooo002Pooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2`ooooo`00XOooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo0_l0002aooooo`00X_ooool00ol0003o
ooooooooo`03ooooo`;o00002oooool00ol0003oooooooooo`2`ooooo`00Xoooool5o`0000gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002a
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`oooo
o`00V_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`00
0;3ooooo002Jooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo0;3ooooo002Jooooo`05o`000?ooooooooooooooool000003?ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool0
09[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0/?ooool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0/?ooool009;ooooo00Go410@oooooooooooooooooa0@400=
ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2`
ooooo`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool0
0omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oo
oooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgoooo
o`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00:_ooooo1?l000000ol@
413oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0/?ooool00:gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000
ooooooooool0^?ooool00:gooooo00?o0000ooooooooool0^?ooool00:gooooo00?o0000oooooooo
ool0^?ooool00:_ooooo00?oEEEEofIVI_l00000^_ooool00?ooooooJOooool00:oooooo00?o0000
okZj^_ooool0]_ooool00:oooooo0_lb<S:gooooo`00P?ooool2o`000006oa0@4?oooooooooooa0@
4?l0003o410@5oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`03ohN7Qol0
003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Jooooo`03o`000?o^k^kooooo00?ooooo
1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0N?ooool0087ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`07ooooo`Ko00002Oooool01OnHV9So8B4Qonk^k_ooooooA4A400?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03olc<c?l0003o410@00cooooo00Go410@okZj
^_o^k^koMgMgoa0@4009ooooo`Ko00002oooool00omEEEGoZJVYooooo`03ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg07Sooooo0021ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool05oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?oo
ooooooooooooool@41004_ooool00ol0003oooooooooo`0Looooo`03ojVYZOmEEEGooooo00Cooooo
00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@07Sooooo0021ooooo`06o`00
0?ooooooA4A4odA4A?oooooo00002Oooool6o`0000_ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0
003ooooooooooooooooo000001;ooooo00?o0000ooooooooool02oooool6o`0000cooooo00?o8B4Q
ooooooooool01?ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool00000N?oo
ool0087ooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Kooooo`03ogMgMomVIVKooooo00;ooooo
00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo01gooooo00?oEEEEolc<c?oo
ool01Oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000N?ooool0087o
oooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Looooo`05o`000?ooooooooooooooool@41000ooo
ool00ol@413oooooooooo`0>ooooo`03oa0@4?l0003o000000?o00007?ooool00onYZJWoMgMgoooo
o`06ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`1fooooo`00POoo
ool01_l0003o<S8boooooooooooo<S8bo`0001Sooooo00Go0000okZj^_ooooooV9RHoa0@4003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool00ol0003oooooooooo`0Jooooo`05oa0@4?oooooo
oooooooooolb<S800oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`1hooooo`00P?ooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0
003oooooooooo`0Jooooo`Go00000oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP1hooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(730) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .29434 m
.00236 .29418 L
.00488 .29394 L
.00942 .29334 L
.01438 .2925 L
.01975 .29156 L
.02116 .29135 L
.02266 .29116 L
.02405 .29101 L
.02535 .2909 L
.02657 .29083 L
.02787 .29079 L
.02862 .29079 L
.02932 .2908 L
.03065 .29085 L
.03184 .29093 L
.03311 .29106 L
.03431 .29123 L
.03539 .2914 L
.03806 .29196 L
.04057 .29263 L
.06182 .30042 L
.06764 .30275 L
.07379 .30567 L
.08481 .31304 L
.09552 .3224 L
.10566 .33081 L
.11477 .33639 L
.11992 .33872 L
.12468 .34052 L
.13461 .3437 L
.13963 .34496 L
.141 .34524 L
.14248 .34549 L
.14388 .34568 L
.14516 .34581 L
.14644 .3459 L
.14781 .34593 L
.1491 .3459 L
.15027 .34583 L
.15165 .34568 L
.15243 .34556 L
.15315 .34543 L
.15586 .34477 L
.15847 .34389 L
.16133 .34265 L
.16712 .3395 L
.1776 .33317 L
.18276 .33052 L
.18754 .32859 L
Mistroke
.19303 .32697 L
.19592 .32632 L
.19901 .32574 L
.2045 .32491 L
.20708 .3246 L
.20948 .32438 L
.21066 .3243 L
.21193 .32423 L
.21265 .32421 L
.21334 .32419 L
.21462 .3242 L
.21597 .32424 L
.21721 .32433 L
.21858 .32448 L
.21927 .32458 L
.22003 .32471 L
.22244 .32528 L
.2238 .32571 L
.22504 .32618 L
.22973 .32866 L
.23237 .33057 L
.23483 .33268 L
.24039 .33855 L
.25161 .35354 L
.27132 .38141 L
.28169 .39456 L
.28736 .40067 L
.29266 .40508 L
.29535 .40667 L
.29685 .40734 L
.29823 .40779 L
.29901 .40798 L
.29973 .40812 L
.30053 .40822 L
.30137 .40826 L
.3021 .40825 L
.30279 .4082 L
.30354 .4081 L
.30435 .40794 L
.30565 .40756 L
.30708 .40698 L
.30857 .40619 L
.30996 .4053 L
.31511 .40076 L
.32047 .3944 L
.32535 .38772 L
.33629 .37212 L
.34605 .35946 L
.35641 .34808 L
.36181 .34329 L
Mistroke
.36468 .34122 L
.36626 .34025 L
.36776 .33946 L
.36911 .33887 L
.37058 .33836 L
.37192 .33802 L
.37317 .33783 L
.37445 .33776 L
.37562 .3378 L
.37697 .33799 L
.37823 .3383 L
.37945 .33873 L
.38076 .33933 L
.38313 .34078 L
.38594 .3431 L
.38849 .34577 L
.39406 .35319 L
.39933 .36186 L
.41873 .40067 L
.42888 .4213 L
.43444 .43115 L
.43716 .43524 L
.43965 .43844 L
.44177 .44067 L
.44408 .44252 L
.44529 .44322 L
.44641 .44371 L
.44759 .44404 L
.44885 .44418 L
.45016 .44408 L
.45091 .44392 L
.45159 .4437 L
.45284 .44312 L
.45417 .44226 L
.45647 .44017 L
.459 .43702 L
.46448 .42741 L
.46968 .41547 L
.47943 .38909 L
.50138 .3306 L
.51148 .3068 L
.52223 .28506 L
.52746 .27665 L
.53237 .27028 L
.53679 .26576 L
.54156 .26192 L
.56255 .24919 L
.56765 .24613 L
.57311 .24327 L
.57625 .24198 L
Mistroke
.5791 .24111 L
.58048 .24079 L
.58197 .24052 L
.58266 .24043 L
.58338 .24035 L
.58468 .24024 L
.58595 .2402 L
.58733 .2402 L
.58863 .24025 L
.58984 .24033 L
.59104 .24044 L
.59212 .24055 L
.59456 .24085 L
.59704 .24117 L
.59966 .24148 L
.60103 .2416 L
.60176 .24166 L
.60254 .2417 L
.60391 .24176 L
.60519 .24178 L
.60646 .24176 L
.60784 .2417 L
.60915 .24161 L
.61036 .2415 L
.61265 .24121 L
.61508 .24082 L
.61962 .24001 L
.62209 .23962 L
.6244 .23933 L
.62558 .23922 L
.62685 .23915 L
.62757 .23912 L
.62825 .23911 L
.62953 .23913 L
.6307 .23919 L
.63178 .23928 L
.63297 .23943 L
.63423 .23963 L
.63684 .24018 L
.63928 .24085 L
.64483 .24273 L
.64958 .24437 L
.65408 .24563 L
.65657 .24614 L
.65797 .24636 L
.65928 .24651 L
.66048 .24662 L
.66158 .24669 L
.66284 .24674 L
.66402 .24675 L
Mistroke
.66525 .24674 L
.66656 .24671 L
.6678 .24667 L
.66892 .24662 L
.67028 .24656 L
.67172 .2465 L
.67294 .24646 L
.6743 .24644 L
.67567 .24644 L
.67697 .24648 L
.67769 .24651 L
.67836 .24655 L
.67987 .24669 L
.68109 .24684 L
.68244 .24705 L
.68514 .24762 L
.68769 .24833 L
.69 .24908 L
.6952 .25103 L
.69965 .2527 L
.70454 .2542 L
.70582 .2545 L
.70718 .25477 L
.70836 .25497 L
.70965 .25513 L
.7104 .25521 L
.7111 .25527 L
.71247 .25535 L
.71372 .25538 L
.71505 .25538 L
.71618 .25535 L
.71741 .2553 L
.71857 .25523 L
.71964 .25516 L
.72227 .25496 L
.72472 .25479 L
.726 .25473 L
.72717 .25468 L
.72852 .25466 L
.7298 .25466 L
.73118 .25471 L
.73246 .25478 L
.73313 .25484 L
.73387 .25491 L
.73536 .25509 L
.73814 .25555 L
.74114 .25619 L
.74657 .25757 L
.7517 .25877 L
.75318 .25904 L
Mistroke
.75458 .25926 L
.75583 .25941 L
.75718 .25954 L
.75791 .25959 L
.7587 .25962 L
.75953 .25964 L
.76031 .25965 L
.76104 .25964 L
.7617 .25962 L
.76246 .25958 L
.76319 .25954 L
.76458 .25942 L
.76586 .25927 L
.76876 .25886 L
.77404 .25796 L
.77662 .25756 L
.77899 .25728 L
.78021 .25716 L
.78148 .25708 L
.78276 .25703 L
.78348 .25701 L
.78416 .25701 L
.7849 .25702 L
.7856 .25704 L
.78692 .25711 L
.78765 .25716 L
.78833 .25722 L
.78986 .25738 L
.79936 .25899 L
.80187 .25942 L
.8046 .2598 L
.80585 .25994 L
.80718 .26006 L
.80843 .26015 L
.80957 .2602 L
.81032 .26022 L
.81102 .26024 L
.81178 .26024 L
.81258 .26023 L
.81394 .2602 L
.8147 .26016 L
.81542 .26013 L
.818 .25996 L
.82077 .25973 L
.82212 .25962 L
.82358 .25952 L
.82488 .25944 L
.82625 .25937 L
.82748 .25934 L
.82884 .25933 L
Mistroke
.83008 .25936 L
.83124 .25941 L
.83255 .25951 L
.83328 .25958 L
.83394 .25965 L
.83644 .26004 L
.83937 .26066 L
.84213 .26141 L
.85248 .2649 L
.87193 .26969 L
.87722 .27086 L
.88216 .27234 L
.88732 .27437 L
.89299 .27712 L
.90227 .28196 L
.90717 .28422 L
.91238 .28619 L
.91807 .28785 L
.92334 .28912 L
.93373 .29176 L
.94389 .29494 L
.94834 .29623 L
.95086 .29684 L
.95321 .2973 L
.95552 .29764 L
.95681 .29777 L
.95799 .29786 L
.95923 .29792 L
.96058 .29794 L
.96186 .29792 L
.96303 .29787 L
.9643 .29779 L
.96548 .29768 L
.96818 .29737 L
.97363 .29653 L
.97837 .29579 L
.98288 .29522 L
.98536 .295 L
.98807 .29482 L
.99053 .2947 L
.99282 .29462 L
1 .29434 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05oooool5o`0000Ko
oooo2Ol00025ooooo`00T_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oo
ooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04oooool4o`00
00Gooooo1_l00009ooooo`;o0000Poooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0000Cooooo`03o`000?oooooo
oooo01Sooooo2ol0001hooooo`00]Oooool00ol0003oooooooooo`0@ooooo`;o00009_ooool3o`00
07Gooooo002eooooo`03o`000?oooooooooo00kooooo0_l0000[ooooo`?o0000L_ooool00;Gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0^ooooo`go0000IOooool00;Gooooo00?o
0000ooooooooool02oooool2o`0003kooooo5?l00004ooooo`Go0000B?ooool00;Gooooo0_l0000;
ooooo`03o`000?oooooooooo057ooooo1Ol00005ooooo`Go0000@oooool00;Gooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`1Qooooo`?o0000@?ooool001Gooooo0_l000002Ol@413o
ooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0Jooooo`05oiRHV?l@413o0000oc8b<_o<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h07?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hNooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool05?ooool4o`000008oa0@4?ooooooooooonk^k_lb
<S;o0000oc8b<_o^k^hJooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00?o
V9RHoa0@4?l000000ol00002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Oooool2o`000009oa0@
4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Fooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05oa0@4?nj^[[oooooogMgMolb<S800ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL07_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool01_l@413o^[ZjoooooomgMgOo<S8b
ooooo`Go000000?oV9RHogMgMoooool07Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03_ooool000_ooooo1_l00002ooooo`Go00000oooool01Ol@413ooooooooooooo
oooo410@01;ooooo1_l00006ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413ooooo
ooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@
41004oooool6o`0000Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@
01kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@400Kooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@
oooooooooooooooooa0@400Oooooo`05o`000?ooooooooooooooool@41000_ooool2o`0001_ooooo
1Ol00003ooooo`05oa0@4?ooooooooooooooool@41003_ooool001?ooooo00CoA4A4omgMgOoooooo
00001?ooool01Ol0003ooooooooooooooooo000001gooooo00?oZJVYoa0@4?ooool00_ooool01Ol0
003ooooooooooooooooo000001gooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooo
oooo000001kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001kooooo
0_l00007ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000001cooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000
01kooooo00?oZJVYoa0@4?ooool00_ooool01?l0003oooooooooooooool3o`0001Wooooo00CoA4A4
omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000000kooooo000Cooooo`04omgMgOmE
EEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000Looooo`03oa0@4?l0003o^[Zj00?o
oooo00Go0000ooooooooooooooooo`00000Nooooo`03ogMgMomVIVKooooo00;ooooo00Go0000oooo
ooooooooooooo`00000Nooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000007Oooool00omgMgOoIVIVooooo`02ooooo`05o`00
0?ooooooooooooooool000007Oooool00ol@413o0000okZj^P03ooooo`05o`000?oooooooooooooo
ool000000_ooool00ol0003oooooooooo`0Fooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000
ooooooooooooooooo`00000>ooooo`005?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooo
ooooooooool@41007Oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
7oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool07?ooool00ol0003o
ooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41007_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@01kooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o
^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo0ol0000Fooooo`03ogMg
Moo<c<co000000Cooooo00Go410@oooooooooooooooooa0@400>ooooo`005?ooool00oo^k^koA4A4
o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01Ol@413oV9RHoooooonj^[[o0000
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`05o`000?nj^[[ooooooiRHV?l@41000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg01kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05o`000?nj^[[ooooo
oiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@oiRHV?oooooo^[Zj
o`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool4o`0001;ooooo00?ok^k^odA4A?l0
00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000Eooooo`03ogMgMol0003ooooo00?o
oooo00?ok^k^oc8b<_l000001?l0000Hooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h07?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h07_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Sooooo00?oEEEEofIVI_l0
00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0:ooooo`?o00004?ooool00omgMgOo0000ooooo`03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03_ooool001Kooooo1ol00004ooooo`Go0000Soooool2o`0000Co
oooo00?o0000ooooooooool0POooool3o`00017ooooo0_l0000Cooooo`009_ooool3o`0008cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`24ooooo`Co00001?ooool9o`0001Gooooo
000Yooooo`;o0000R_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo08Wooooo1?l0
000Nooooo`00:oooool2o`0008Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2[
ooooo`00;Oooool2o`0008Kooooo00Go0000ooooooooooooooooo`00002^ooooo`005_ooooooo`00
043o00004oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0A
ooooo`005_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Gooooo00Co0000oooo
oooooooo00009?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0Aooooo`00<oooool00ol0003oooooooooo`1ooooo
o`03o`000?oooooo00000;3ooooo000dooooo`03o`000?oooooooooo07kooooo00?o0000ooooool0
0000/?ooool003Gooooo00?o0000ooooooooool07Oooool9o`0005Oooooo0_l0002aooooo`00=_oo
ool00ol0003oooooooooo`0Hooooo`Co00002?ooool3o`0005Gooooo0_l0002aooooo`00=oooool2
o`0001Kooooo0_l0000?ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0/?ooool0
03Wooooo00?o0000ooooooooool04Oooool2o`00017ooooo00?o0000ooooooooool0D_ooool00ol0
003oooooooooo`2`ooooo`00>_ooool2o`00013ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Xooooo`?o00009Oooool2o`000;;ooooo000looooo`Co00002_ooool2o`0001Kooooo
00?o0000ooooooooool09Oooool2o`0000;ooooo0ol0000Sooooo`?o0000/Oooool0043ooooo0_l0
0006ooooo`;o00006Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool08?ooool2o`000;;ooooo0012ooooo`Ko00007?ooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07oooool00ol0003oooooo`00002b
ooooo`00IOooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool07_ooool00ol0003oooooo`00002booooo`00I_ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool07Oooool00ol0003oooooo`00002booooo`00
I_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`02o`000;7ooooo001Wooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`000;;ooooo
001Xooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0Iooooo`05o`000?ooooooooooooooool00000/_ooool006Sooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Wooooo00Go0000oooooooooooooooo
o`00002booooo`00JOooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool06?ooool01Ol0003ooooooooooooooooo00000;;ooooo001Zooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo00;ooooo0_l0002aooooo`00J_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo0;3ooooo001[ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03oooool01_o^
k^ko<S8bo`000?lb<S;ok^k^o`0000Cooooo0_lQ8B44ooooo`Go00001?ooool01_m4A4Co0000o`00
0?lb<S;ogMgMo`0000Cooooo00?o0000ooooooooool0/?ooool006cooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0@ooooo`07ogMgMonHV9SooooooiRHV?mgMgOoooooo`000003oooo
o`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgo`000?ooool01?ooool0
0ol0003oooooooooo`2`ooooo`00K?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
017ooooo00Oo410@oooooooooooooooooa0@4?oooooo000000[ooooo00?oV9RHob4Q8Oo^k^h02Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo001]ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool04_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o
0000ooooooooool02?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMol0003ooooo00Cooooo0ol0
002`ooooo`00K_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01;ooooo00Go0000
ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Wooooo00?oMgMgofIVI_ooool00ooo
ool01Ol0003o8B4Qo`000?l0003oc<c<00Gooooo00?o0000ooooooooool0/?ooool006oooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Cooooo`05oa0@4?ooooooooooooooool@4100
0oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00001_ooool00ol0003oooooooooo`2`ooooo`00L?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo01Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03o`000?oooooooooo00Go
oooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooo000000Oooooo00?o0000oooo
ooooool0/?ooool0077ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Eooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01?ooool00ol0003oooooooooo`04ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool007;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool01Oooool2o`000;7ooooo001cooooo`;o00000_ooool2o`0002?ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0;3ooooo001eooooo`?o0000
9?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
/?ooool009gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0;3ooooo002Mooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`2`ooooo`00WOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Oooooo0_l0002aooooo`00W_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0/?ooool009kooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo0;3ooooo002Oooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`2`ooooo`00X?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Sooooo0_l0002aooooo`00XOooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0/?ooool00:;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0;3ooooo002Rooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2`ooooo`00Xooo
ool4o`0000kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooo
oooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0002`ooooo`00V_ooool01Ol0003o
oooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`oooo
o`00V_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Joooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002a
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009;ooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3
o`000;3ooooo002Booooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`ooooo`00T_ooool0
1Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co0000
1_ooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`Co000000?o410@ooooooooool00oooool00ol0
003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;3o
oooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool00:gooooo00?o
0000ooooooooool01Oooool3o`000;3ooooo002]ooooo`03o`000?oooooooooo0;Sooooo002]oooo
o`03o`000?oooooooooo0;Sooooo002]ooooo`03o`000?oooooooooo0;Sooooo002[ooooo`03oeEE
EOmVIVKo00000;[ooooo003oooooofWooooo002_ooooo`03o`000?nj^[[ooooo0;Kooooo002_oooo
o`;o<S8b]oooool0083ooooo0_l000001_l@413oooooooooool@413o0000oa0@41Oooooo1Ol00003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0
003o0000odA4A?nj^[X06_ooool00ol0003ok^k^ooooo`03ooooo`05oiRHV?l@413o0000oc8b<_o<
c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07Sooooo0021ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01oooool6o`0000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[o
k^k^ogMgMol@41002Oooool6o`0000_ooooo00?oEEEEojVYZOooool00oooool01Ol@413o^[Zjoooo
oomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1hooooo`00POooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo01Oooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooo
oooooooooooo410@01;ooooo00?o0000ooooooooool07?ooool00onYZJWoEEEEooooo`07ooooo`05
o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`1fooooo`00POooool01_l0003o
ooooodA4A?m4A4Coooooo`0000Wooooo1_l0000;ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000
ooooooooooooooooo`00000Booooo`03o`000?oooooooooo00_ooooo1_l0000<ooooo`03ob4Q8Ooo
oooooooo00Gooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000007Sooooo
0021ooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo00006oooool00omgMgOoIVIVooooo`02ooooo`05
o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0Mooooo`03oeEEEOo<c<cooooo
00Cooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000007Sooooo0021oooo
o`06o`000?n7QhOoZJVYokZj^_mEEEGo00007?ooool01Ol0003ooooooooooooooooo410@00?ooooo
00?o410@ooooooooool03_ooool00ol@413o0000o`000003o`0001cooooo00?oZJVYogMgMoooool0
1Oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@4100N?ooool0087ooooo
00Ko0000oc8b<_oooooooooooc8b<_l0000Hooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool06_ooool01Ol@413ooooooooo
oooooooo<S8b00?ooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL0N?ooool0083ooooo00?o410@o`000?n7QhL00_ooool00on7QhOo0000oa0@400Gooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo00?o0000
ooooooooool06_ooool5o`0000?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h0N?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(740) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .28744 m
.00488 .2869 L
.00722 .28665 L
.00942 .28647 L
.01068 .28639 L
.01204 .28633 L
.01327 .28631 L
.01441 .28631 L
.01565 .28635 L
.017 .28643 L
.01769 .28649 L
.01842 .28657 L
.01975 .28674 L
.02241 .28723 L
.02532 .28797 L
.03062 .28985 L
.04057 .2945 L
.05167 .30015 L
.06351 .30692 L
.07468 .31546 L
.08481 .32447 L
.09464 .33225 L
.09959 .33527 L
.10502 .33783 L
.11091 .33985 L
.1164 .34121 L
.119 .34172 L
.12146 .34211 L
.12282 .34229 L
.12429 .34246 L
.12564 .34258 L
.12688 .34265 L
.12811 .3427 L
.12942 .34271 L
.13053 .34269 L
.13174 .34263 L
.13306 .34252 L
.13379 .34243 L
.13446 .34234 L
.13577 .34212 L
.13699 .34186 L
.13933 .34123 L
.14187 .34032 L
.14648 .33813 L
.15698 .33114 L
.16811 .32338 L
.17802 .3183 L
.18358 .31625 L
.18866 .31472 L
.19338 .31352 L
Mistroke
.19587 .31297 L
.19853 .31248 L
.19984 .31229 L
.20108 .31213 L
.20219 .31203 L
.20338 .31195 L
.20453 .31192 L
.20573 .31193 L
.20676 .31197 L
.20789 .31207 L
.20927 .31227 L
.21054 .31252 L
.21193 .31288 L
.21341 .31337 L
.21589 .31445 L
.21863 .31602 L
.22368 .31998 L
.22842 .32485 L
.25039 .35565 L
.26983 .38631 L
.27516 .3942 L
.28084 .40136 L
.2836 .40412 L
.2862 .4062 L
.28854 .40757 L
.28985 .40812 L
.29107 .40849 L
.29228 .40872 L
.29359 .4088 L
.29482 .40873 L
.29595 .40855 L
.29727 .40817 L
.29801 .40789 L
.2987 .40759 L
.30131 .40606 L
.30381 .40408 L
.30657 .40139 L
.31215 .39461 L
.33432 .36123 L
.3442 .34636 L
.35461 .33286 L
.35724 .33019 L
.36006 .32783 L
.36168 .32672 L
.36315 .32589 L
.36463 .32523 L
.36529 .32499 L
.36602 .32477 L
.36729 .32449 L
.36864 .32435 L
Mistroke
.36988 .32436 L
.37105 .32448 L
.37242 .32478 L
.37367 .32519 L
.37512 .32583 L
.3765 .32659 L
.37922 .32854 L
.38178 .33087 L
.38657 .33639 L
.39731 .35344 L
.40659 .37296 L
.41662 .39876 L
.42746 .42859 L
.43275 .44135 L
.43757 .4505 L
.44019 .45417 L
.44139 .4555 L
.44267 .45668 L
.44402 .45763 L
.44528 .45824 L
.44663 .45861 L
.4474 .45868 L
.44812 .45866 L
.4488 .45855 L
.44954 .45836 L
.45031 .45805 L
.45103 .45768 L
.45232 .45681 L
.45369 .4556 L
.45684 .45175 L
.4597 .4471 L
.47019 .42277 L
.47986 .39452 L
.5017 .32746 L
.51121 .30277 L
.52141 .28312 L
.52727 .27511 L
.53262 .26931 L
.54309 .26006 L
.55278 .2524 L
.55809 .24875 L
.56308 .24605 L
.56593 .24492 L
.56754 .24443 L
.56902 .24406 L
.57026 .24382 L
.57163 .24363 L
.57232 .24356 L
.57306 .2435 L
.57439 .24343 L
Mistroke
.57574 .24342 L
.5765 .24343 L
.5772 .24346 L
.5785 .24353 L
.57987 .24364 L
.58486 .24415 L
.58613 .24428 L
.5875 .2444 L
.58872 .24449 L
.59002 .24455 L
.5913 .24459 L
.59246 .2446 L
.59363 .24459 L
.59474 .24455 L
.59603 .24447 L
.59739 .24436 L
.59984 .24407 L
.60536 .24322 L
.60765 .24287 L
.60891 .2427 L
.6101 .24255 L
.61121 .24244 L
.61241 .24235 L
.61351 .2423 L
.61452 .24228 L
.61572 .24229 L
.61684 .24234 L
.61807 .24244 L
.6194 .2426 L
.62071 .24281 L
.6221 .24309 L
.62458 .24371 L
.63459 .24722 L
.63723 .24814 L
.6401 .249 L
.6428 .24963 L
.64409 .24987 L
.64529 .25005 L
.64642 .25018 L
.64763 .25028 L
.64897 .25035 L
.6502 .25038 L
.65147 .25038 L
.6522 .25037 L
.65286 .25035 L
.65409 .25029 L
.6554 .25022 L
.65771 .25007 L
.65986 .24994 L
.66095 .24989 L
Mistroke
.66211 .24985 L
.6634 .24983 L
.66458 .24984 L
.66596 .24989 L
.66675 .24993 L
.66747 .24999 L
.6688 .25013 L
.67022 .25033 L
.67268 .25079 L
.6754 .25148 L
.68103 .25327 L
.68709 .25528 L
.68987 .25603 L
.69139 .25636 L
.6928 .25662 L
.69401 .25679 L
.6953 .25693 L
.69603 .25699 L
.69673 .25702 L
.69803 .25706 L
.69927 .25705 L
.70059 .25699 L
.70171 .25691 L
.70295 .25679 L
.7057 .25642 L
.70828 .25602 L
.71082 .25561 L
.71352 .25523 L
.71493 .25506 L
.71568 .25499 L
.71648 .25493 L
.71722 .25488 L
.7179 .25485 L
.71923 .25482 L
.72048 .25482 L
.72164 .25487 L
.72292 .25495 L
.72428 .25508 L
.72572 .25526 L
.72708 .25547 L
.72961 .25593 L
.73415 .25689 L
.73663 .2574 L
.73895 .2578 L
.74026 .25799 L
.74146 .25814 L
.74279 .25825 L
.74352 .2583 L
.74422 .25833 L
.74543 .25836 L
Mistroke
.74655 .25835 L
.74778 .2583 L
.74909 .2582 L
.75039 .25807 L
.75182 .25787 L
.75471 .25737 L
.75989 .25627 L
.76281 .25568 L
.76441 .2554 L
.76593 .25518 L
.76735 .25501 L
.76815 .25494 L
.76889 .25488 L
.77019 .25482 L
.77158 .25481 L
.77288 .25485 L
.77407 .25492 L
.77539 .25504 L
.77677 .25521 L
.7791 .2556 L
.78164 .25613 L
.78736 .25749 L
.79017 .25812 L
.79276 .25862 L
.79527 .25899 L
.79654 .25914 L
.79794 .25926 L
.79867 .25931 L
.79933 .25935 L
.8001 .25938 L
.80084 .2594 L
.80213 .25942 L
.80287 .25942 L
.80355 .25942 L
.80483 .25939 L
.80604 .25936 L
.8083 .25928 L
.80948 .25925 L
.81073 .25921 L
.8121 .25919 L
.81335 .2592 L
.81473 .25923 L
.81598 .25929 L
.81667 .25934 L
.81742 .2594 L
.81879 .25956 L
.82006 .25974 L
.82142 .25999 L
.82385 .26055 L
.82667 .26141 L
Mistroke
.82932 .26238 L
.83535 .26501 L
.87604 .27869 L
.88604 .28392 L
.89154 .28668 L
.89671 .28878 L
.89966 .28969 L
.90285 .29044 L
.90575 .29094 L
.90842 .29129 L
.91404 .2918 L
.9193 .29229 L
.92395 .29288 L
.92895 .29368 L
.93403 .29452 L
.93671 .2949 L
.93817 .29508 L
.93955 .29521 L
.94029 .29526 L
.94097 .2953 L
.94173 .29534 L
.94254 .29536 L
.94388 .29537 L
.94456 .29536 L
.9453 .29534 L
.94667 .29526 L
.94743 .2952 L
.94812 .29513 L
.95075 .29478 L
.95327 .29431 L
.956 .29367 L
.96097 .29234 L
.96568 .29106 L
.96828 .29043 L
.97076 .28991 L
.97305 .2895 L
.97554 .28914 L
.97781 .28889 L
.97992 .28872 L
.98235 .28857 L
.98455 .28847 L
.98948 .28826 L
.99208 .28812 L
.9949 .28793 L
1 .28744 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo01?ooooo1_l00004ooooo`_o0000R?ooool009;o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4
o`0000Kooooo0_l0000Aooooo`?o00001Oooool5o`0000_ooooo00?o0000ooooooooool0QOooool0
0;Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Gooooo`_o0000O?ooool00;Go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Sooooo`Co0000N?ooool00;Gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Xooooo`?o00000oooool9o`0000Sooooo
2Ol0001Hooooo`00]Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02cooooo0ol0
0009ooooo`So00002Oooool<o`0004cooooo002eooooo`;o00002oooool2o`0005Oooooo1Ol00018
ooooo`00]Oooool00ol0003oooooooooo`08ooooo`;o0000G_ooool3o`0004Gooooo000Eooooo`;o
000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h06_ooool01OnHV9So410@o`00
0?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^01cooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
7_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Gooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^6_ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0Iooooo`?o000000Co410@o`000?lb<S;oc<c<0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01go
oooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0>ooooo`005_ooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01Ol@413o^[Zjoooo
oomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@o`00
0?l0003o0000oc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool000_ooooo1_l00002ooooo`Go00000ooo
ool01Ol@413ooooooooooooooooo410@01;ooooo1_l00006ooooo`05o`000?ooooooooooooooool@
41000oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41004oooool6o`0000Gooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@01kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Kooooo`03oiRHV?lQ
8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400Oooooo`?o000000?ooooooa0@4?ooool0
0_ooool00ol@413oooooooooo`0Iooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00ko
oooo000Cooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000Moooo
o`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRHV?lQ8B7o
k^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`00000Nooooo`;o00001oooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Looooo`03oiRHV?lQ8B7ok^k^00?o
oooo00Go0000ooooooooooooooooo`00000Nooooo`04ojVYZOl@413oooooooooo`?o00000_ooool0
0ol0003oooooooooo`0Iooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000oooooooooooooooo
o`00000>ooooo`004oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00007?ooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000007_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001gooooo
00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000001gooooo00?o410@o`000?nj
^[X00oooool01Ol0003oooooo`000?oooooo000001_ooooo00CogMgMoeEEEOoooooo00001?ooool0
1Ol0003ooooooooooooooooo000000kooooo000Dooooo`03ogMgMoo<c<co000000Cooooo00Go410@
oooooooooooooooooa0@400Mooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooo
oa0@400Oooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Looooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Nooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41007_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool07?oo
ool00onj^[[o8B4Qooooo`02ooooo`03oa0@4?oooooooooo00;o00007?ooool00omgMgOoc<c<o`00
0004ooooo`05oa0@4?ooooooooooooooool@41003_ooool001Cooooo00?ok^k^odA4A?l000002?l0
00000omgMgOoooooooooo`0Hooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RH
oooooonHV9SoMgMg01_ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL07_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL06oooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00KoMgMg
oiRHV?ooooooV9RHogMgMol0000Kooooo`04onk^k_m4A4Co0000ooooo`?o000000GoMgMgoiRHV?oo
ooooV9RHogMgM`0>ooooo`005Oooool00omgMgOo0000ooooo`03ooooo`04onk^k_lb<S;o0000oc8b
<P;o00006Oooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0Kooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01co
oooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Iooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^01_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`06onk^k_lb<S;o0000oc8b
<_o^k^kooooo1_l0000@ooooo`Wo00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Q
ooooo`;o0000T_ooool2o`0000?ooooo00?o0000ooooooooool0O?ooool6o`0000Kooooo1?l0000O
ooooo`008oooool3o`0008oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`22oooo
o`Ko00008oooool002Kooooo0_l0002=ooooo`05o`000?ooooooooooooooool00000[_ooool002So
oooo0_l0002;ooooo`04o`000?ooooooooooo`000:oooooo000Zooooo`03o`000?oooooooooo08So
oooo00Co0000oooooooooooo0000[oooool001Koooooool00010o`0001?ooooo000Fooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooo000000Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool6o`0000?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Aooooo`005_ooool00ol0003oooooooooo`0Dooooo`;o00003_oo
ool00ol0003oooooooooo`0?ooooo`Go00001_ooool2o`0000Wooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooo000002Gooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04Ooo
ool002oooooo00?o0000ooooooooool06oooool2o`0000gooooo00?o0000ooooooooool0E_ooool2
o`000;7ooooo000`ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`1Eooooo`;o0000/Oooool0037ooooo00?o0000ooooooooool05_ooool2o`0001;o
oooo00?o0000ooooooooool0:Oooool4o`0002Oooooo0_l0002aooooo`00<_ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool09oooool2o`0000Cooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`2`ooooo`00<oooool00ol0003ooooooooo
o`0Aooooo`;o00005_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`2`ooooo`00=?ooool3o`0000kooooo0_l0000I
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Q
ooooo`;o0000/_ooool003Oooooo0_l0000;ooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo023ooooo0_l0002boooo
o`00>Oooool3o`0000Kooooo0_l0000Mooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Pooooo`?o0000/Oooool003cooooo1_l0000Pooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooo00000;;ooooo001Sooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooo00000;;ooooo001Sooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
00000;;ooooo001Tooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Kooooo`04o`000?ooooooooooo`000;;ooooo001Uooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
00;o0000/Oooool006Gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo01[ooooo00Co0000oooooooooooo0000/_ooool006Kooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Wooooo00Go0000oooooooo
ooooooooo`00002booooo`00Ioooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo00000;;ooooo001Wooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Hooooo`05
o`000?ooooooooooooooool00000/_ooool006Sooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool2o`000;7o
oooo001Yooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0/?ooool006[ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0Booooo`07onk^k_lb<S;o0000oc8b<_o^k^ko
ooooo`000003ooooo`;o8B4Q1?ooool5o`0000Cooooo00KoA4A4o`000?l0003o<S8bomgMgOl00004
ooooo`03o`000?oooooooooo0;3ooooo001Zooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool04oooool01omgMgOoV9RHoooooonHV9SoMgMgooooool000000oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMol0003ooooo00Cooooo00?o0000ooooooooool0
/?ooool006_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Dooooo`07oa0@4?oo
ooooooooooooool@413oooooo`00000:ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`2`ooooo`00K?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo01Cooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00So
oooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo0000ooooo`04ooooo`?o0000/?ooool006cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Eooooo`05o`000?ooooooooooooooool0
00000_ooool00ol0003oooooooooo`09ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0
003o0000olc<c005ooooo`03o`000?oooooooooo0;3ooooo001]ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool05_ooool01Ol@413ooooooooooooooooo410@00;ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000
ooooooooool0/?ooool006gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Foooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool00ol0003oooooooooo`05ooooo`05o`000?nj^[[o
oooooiRHV?l@41001?ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo0;3ooooo
001^ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00?o0000ooooooooool01Oooool01OnHV9So410@o`000?lQ8B7oc<c<00Co
oooo1?l00006ooooo`03o`000?oooooooooo0;3ooooo001_ooooo`;o00001Oooool2o`0002;ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`05ooooo`;o0000/Oooool0077ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`2`ooooo`00L_ooool4o`0002Gooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0;3ooooo002Loooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2`oooo
o`00W?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0/?ooool009cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`;o0000
/Oooool009gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0;3ooooo002Mooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`2`ooooo`00W_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0/?ooool009kooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`08ooooo`;o0000/Oooool009kooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo0;3ooooo002Oooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`2`ooooo`00Woooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0/?ooool009oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0;3ooooo002Pooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool2o`000;7ooooo002Qooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`2`ooooo`00X_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0/?oo
ool009[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`;o000000?o8B4Qo`000?l000001?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009[ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`04ooooo`?o00002?ooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooo
ooooo`03ooooo`?o0000/?ooool009[ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000oooooooooooooooo
o`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`ooooo`00
V_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo1?l00006ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^
ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00
T_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oo
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooo
oooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7o
ooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00T_ooool01Ol0003ooooo
oooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00Go410@oooooooooooooooooa0@400>oooo
o`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`oooo
o`00T_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
Zoooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool00:gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo0ol0002`oooo
o`00[Oooool00ol0003oooooooooo`2hooooo`00[Oooool00ol0003oooooooooo`2hooooo`00[Ooo
ool00ol0003oooooooooo`2hooooo`00Zoooool00omEEEGoIVIVo`00002jooooo`00oooooomYoooo
o`00[oooool00ol0003o^[Zjooooo`2fooooo`00[oooool2oc8b<[Oooooo0020ooooo`;o000000Ko
410@oooooooooooo410@o`000?l@410Gooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01[ooooo00?o0000
onk^k_ooool01Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^07So
oooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`0000Wooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool00oo<
c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000_ooooo00?oEEEE
ojVYZOooool01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0N?oo
ool0087ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Gooooo`03oiRHV?lQ8B7o
k^k^00Cooooo00Go410@oooooooooooooooooa0@400Booooo`03o`000?oooooooooo01cooooo00?o
ZJVYoeEEEOooool00oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@401hooooo`00POoo
ool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000;ooooo`03oiRHV?lQ8B7ok^k^00?o
oooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo00_ooooo1_l0000<oooo
o`03ob4Q8Ooooooooooo00;ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooo
oooo000007Sooooo0021ooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo00006oooool00omgMgOoIVIV
ooooo`02ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0Mooooo`03
oeEEEOo<c<cooooo00;ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo
000007Sooooo0021ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo00007?ooool01Ol0003ooooooooo
oooooooo410@00?ooooo00?o410@ooooooooool03_ooool00ol@413o0000o`000003o`0001cooooo
00?oZJVYogMgMoooool00oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@
4100N?ooool0087ooooo00Ko0000oc8b<_oooooooooooc8b<_l0000Hooooo`05o`000?nj^[[ooooo
oiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool06_oo
ool01Ol@413ooooooooooooooooo<S8b00Cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg07Sooooo0020ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@4100
5oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Boooo
o`03o`000?oooooooooo01[ooooo1Ol00005ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP1hooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(750) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .28272 m
.00123 .28277 L
.00236 .28284 L
.00365 .28296 L
.00488 .28311 L
.00706 .28346 L
.00942 .28399 L
.01203 .28477 L
.01479 .2858 L
.01975 .28814 L
.04057 .30089 L
.06341 .31765 L
.07458 .32772 L
.07947 .33169 L
.08481 .33532 L
.08727 .33668 L
.0899 .33791 L
.09217 .3388 L
.09462 .33957 L
.09714 .34019 L
.09829 .34041 L
.09951 .34061 L
.10061 .34077 L
.10182 .34091 L
.10284 .341 L
.10395 .34108 L
.10533 .34115 L
.10664 .34118 L
.10791 .34118 L
.10909 .34116 L
.11036 .34111 L
.11108 .34107 L
.11176 .34103 L
.11312 .34091 L
.1146 .34075 L
.11712 .34036 L
.11978 .33981 L
.12205 .33919 L
.12454 .33836 L
.13009 .33584 L
.13532 .33261 L
.14513 .32491 L
.15581 .31616 L
.16166 .31214 L
.16712 .30904 L
.17713 .30482 L
.18244 .30315 L
.18517 .30244 L
.18814 .30181 L
.18944 .30159 L
Mistroke
.19083 .3014 L
.19215 .30127 L
.19333 .3012 L
.19455 .30117 L
.19587 .3012 L
.19712 .30128 L
.19826 .30141 L
.19937 .30159 L
.20041 .30181 L
.20276 .3025 L
.20506 .30342 L
.20751 .30471 L
.21308 .30879 L
.21822 .31388 L
.22986 .32896 L
.251 .36376 L
.26045 .38109 L
.27064 .39777 L
.27348 .40144 L
.27647 .40463 L
.27902 .40674 L
.28046 .40767 L
.28181 .40835 L
.28318 .40886 L
.28446 .40918 L
.28562 .40932 L
.28688 .40933 L
.28824 .40916 L
.28893 .40901 L
.28969 .4088 L
.29103 .40829 L
.29228 .40767 L
.29501 .40587 L
.29753 .40369 L
.30324 .39725 L
.31363 .3818 L
.3331 .34685 L
.34252 .33057 L
.34746 .32341 L
.35268 .31748 L
.35545 .31511 L
.35692 .31409 L
.35849 .31319 L
.35994 .31252 L
.36125 .31206 L
.36257 .31172 L
.36382 .31152 L
.36509 .31143 L
.36644 .31146 L
.36758 .31159 L
Mistroke
.36885 .31182 L
.3702 .31219 L
.37166 .31272 L
.3743 .314 L
.37697 .3157 L
.37981 .31795 L
.38492 .32317 L
.391 .33155 L
.39651 .34152 L
.40737 .36871 L
.41761 .40159 L
.42787 .43474 L
.43347 .44963 L
.43621 .45554 L
.4387 .46002 L
.44084 .46313 L
.44317 .46569 L
.44445 .46674 L
.44563 .46747 L
.44676 .46796 L
.44795 .46825 L
.44915 .46831 L
.45044 .46813 L
.45166 .4677 L
.45278 .46711 L
.45402 .46623 L
.45537 .465 L
.4581 .46169 L
.46077 .45743 L
.46366 .45174 L
.4689 .43883 L
.47871 .4077 L
.48919 .36963 L
.50071 .33094 L
.50592 .31657 L
.51151 .30365 L
.5216 .28583 L
.53315 .2704 L
.53826 .2645 L
.5437 .25897 L
.54915 .25452 L
.55172 .25289 L
.55407 .25167 L
.55646 .25071 L
.55769 .25032 L
.55903 .24997 L
.56013 .24975 L
.5613 .24956 L
.56254 .24941 L
.56369 .24932 L
Mistroke
.5644 .24929 L
.56515 .24926 L
.5665 .24925 L
.56725 .24926 L
.56795 .24927 L
.56872 .2493 L
.56955 .24933 L
.57239 .24947 L
.57379 .24954 L
.57509 .24958 L
.57635 .24961 L
.57768 .24962 L
.57845 .24961 L
.57917 .24959 L
.58051 .24954 L
.58175 .24946 L
.58289 .24936 L
.58547 .24905 L
.595 .24737 L
.59632 .24716 L
.59775 .24696 L
.59901 .24681 L
.60035 .2467 L
.60155 .24663 L
.60288 .24661 L
.60409 .24663 L
.60523 .24669 L
.6066 .24682 L
.60729 .2469 L
.60804 .24701 L
.61062 .24752 L
.61364 .24832 L
.61644 .24921 L
.62189 .25109 L
.62692 .25258 L
.62949 .25314 L
.63079 .25335 L
.63222 .25353 L
.63296 .2536 L
.63365 .25364 L
.63443 .25369 L
.63518 .25371 L
.63651 .25371 L
.63726 .2537 L
.63796 .25367 L
.63933 .25359 L
.64061 .25348 L
.64301 .25322 L
.64563 .2529 L
.64839 .25258 L
Mistroke
.64951 .25247 L
.65072 .25238 L
.65204 .2523 L
.65328 .25226 L
.65448 .25226 L
.65563 .25229 L
.65665 .25234 L
.65777 .25243 L
.65898 .25256 L
.66032 .25275 L
.66303 .25326 L
.6679 .25447 L
.67308 .25585 L
.6759 .25649 L
.67727 .25674 L
.67852 .25693 L
.67968 .25707 L
.68077 .25717 L
.68192 .25723 L
.68317 .25726 L
.68445 .25723 L
.68581 .25716 L
.68697 .25705 L
.68825 .25689 L
.69413 .25577 L
.6997 .2545 L
.70213 .25404 L
.70346 .25384 L
.70471 .25368 L
.70605 .25355 L
.70677 .2535 L
.70754 .25346 L
.7089 .25343 L
.71016 .25344 L
.71135 .2535 L
.71262 .25359 L
.71382 .25371 L
.71491 .25385 L
.72011 .25473 L
.72276 .25524 L
.72557 .25572 L
.72797 .25605 L
.72933 .25619 L
.73061 .25629 L
.73197 .25634 L
.73322 .25636 L
.7339 .25635 L
.73465 .25632 L
.73602 .25624 L
.73679 .25618 L
Mistroke
.73749 .25611 L
.73907 .25591 L
.74189 .25545 L
.74708 .25443 L
.74991 .25391 L
.7513 .25369 L
.75256 .25353 L
.7538 .25339 L
.75498 .25331 L
.75622 .25325 L
.75758 .25324 L
.75896 .25329 L
.75967 .25333 L
.76044 .2534 L
.7618 .25356 L
.76309 .25376 L
.76552 .25425 L
.76775 .25482 L
.77277 .25634 L
.77829 .25802 L
.78098 .25872 L
.78342 .25924 L
.78601 .25967 L
.78744 .25984 L
.78878 .25998 L
.79024 .2601 L
.79159 .26018 L
.79307 .26025 L
.79463 .26031 L
.79591 .26035 L
.79729 .26041 L
.79851 .26046 L
.79981 .26054 L
.8011 .26064 L
.80227 .26076 L
.80455 .26106 L
.80592 .26131 L
.80718 .26158 L
.81003 .26235 L
.81519 .26433 L
.82448 .26913 L
.82959 .27179 L
.83442 .27395 L
.83979 .27578 L
.84468 .27701 L
.85424 .27919 L
.85965 .28089 L
.86464 .28293 L
.87009 .28552 L
.87595 .28833 L
Mistroke
.87866 .28948 L
.88124 .29043 L
.88375 .29118 L
.88609 .29171 L
.88722 .29191 L
.88829 .29207 L
.88952 .29221 L
.89063 .2923 L
.89187 .29236 L
.89301 .29239 L
.89427 .29239 L
.89559 .29236 L
.91724 .29161 L
.91968 .29174 L
.92234 .29188 L
.92356 .29193 L
.92486 .29198 L
.92596 .292 L
.92718 .29201 L
.92856 .29199 L
.92934 .29196 L
.93006 .29193 L
.93137 .29184 L
.93276 .29171 L
.93401 .29155 L
.93518 .29137 L
.93784 .29084 L
.94271 .2895 L
.94714 .288 L
.95188 .28634 L
.95709 .28475 L
.95954 .28415 L
.96217 .28365 L
.96362 .28343 L
.96495 .28327 L
.96629 .28315 L
.96755 .28306 L
.96871 .283 L
.96995 .28296 L
.97112 .28294 L
.97217 .28293 L
.97342 .28293 L
.97477 .28295 L
.97604 .28297 L
.97721 .28299 L
.97847 .28302 L
.97966 .28304 L
.98103 .28306 L
.98228 .28306 L
.98365 .28306 L
Mistroke
.98443 .28306 L
.98515 .28305 L
.98645 .28303 L
.98783 .28299 L
.99061 .28289 L
.99361 .28278 L
.99499 .28274 L
.99575 .28272 L
.99645 .2827 L
.99769 .28269 L
.99904 .2827 L
1 .28272 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o00007Oooool4
o`00093ooooo002eooooo`03o`000?oooooooooo00oooooo3Ol00004ooooo`Co0000S?ooool00;Go
oooo00?o0000ooooooooool03Oooool3o`0001Cooooo1?l000000ooooooo0000o`000007o`0000co
oooo1?l0000;ooooo`Co0000Goooool00;Gooooo00?o0000ooooooooool03?ooool2o`0001Wooooo
0ol00008ooooo`Co00001?ooool5o`0000;ooooo3Ol00003ooooo`Co0000Foooool00;Gooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0Xooooo`Co00006oooool4o`0005Oooooo002e
ooooo`;o00002oooool00ol0003oooooooooo`1<ooooo`So0000Coooool00;Gooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`1Eooooo`?o0000C?ooool001Gooooo0_l000002Ol@413o
ooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0Jooooo`05oiRHV?l@413o0000oc8b<_o<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h07?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hNooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool05?ooool4o`000008oa0@4?ooooooooooonk^k_lb
<S;o0000oc8b<_o^k^hJooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo0_l0
0007ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01go
oooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0>ooooo`005_ooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01Ol@413o^[Zjoooo
oomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01Cooooo00?o0000oooo
ooooool01?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`002ooo
ool6o`0000;ooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41004_ooool6o`0000Kooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo017ooooo1_l00003ooooo`03
oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400Cooooo`Ko00001Oooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41007_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@01_ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01Gooooo
0_l00008ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Iooooo`Go
00000oooool01Ol@413ooooooooooooooooo410@00kooooo000Cooooo`04odA4A?oMgMgoooooo`00
00Cooooo00Go0000ooooooooooooooooo`00000Mooooo`03ojVYZOl@413ooooo00;ooooo00Go0000
ooooooooooooooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Nooooo`;o
00001oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`00000Looooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000G
ooooo`Go00000_ooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000006ooo
ool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool001?ooooo
00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000001cooooo00?o410@o`00
0?nj^[X00oooool01Ol0003ooooooooooooooooo000001kooooo00?oMgMgofIVI_ooool00_ooool0
1Ol0003ooooooooooooooooo000001kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000001kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Looooo`?o000000Go^[Zjooooooooooooooooo`000003
ooooo`03o`000?oooooooooo01Wooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooo
oooooooo000000kooooo000Dooooo`03ogMgMoo<c<co000000Co000000Go410@oooooooooooooooo
oa0@400Mooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@400Oooooo`05
o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Looooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@400Nooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41007_oo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool07?ooool00onj^[[o0000
o`000002ooooo`05oa0@4?ooooooooooooooool@41005?ooool?o`000005oa0@4?oooooooooooooo
ool@41003_ooool001Cooooo00?ok^k^odA4A?l000000oooool4o`000003oiRHV?mgMgOooooo01Wo
oooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool0
1Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL06_ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Kooooo`06oa0@4?nHV9SooooookZj^_l0003ooooo0_l000001OmgMgOoV9RHoooooonHV9SoMgMg
017ooooo0ol00008ooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>
ooooo`005Oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000o`000?o^k^h06_ooool0
1OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01cooooo00?oEEEEofIV
I_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Hooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_o
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`?o000000?o<S8bonk^k_ooool03Oooool3o`00
00cooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Ooooo
o`;o0000U?ooool2o`0000Cooooo00?o0000ooooooooool0L_ooool@o`0002Sooooo000Qooooo`03
o`000?oooooooooo097ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2[ooooo`00
8_ooool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
Zoooool002?ooooo0_l0000Zooooo`Wo0000GOooool01Ol0003ooooooooooooooooo00000:kooooo
000Uooooo`03o`000?oooooooooo02Gooooo0_l00009ooooo`;o0000Foooool01Ol0003ooooooooo
oooooooo00000:kooooo000Foooooooo0000@?l0000Cooooo`005_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02
o`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06o`0000Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool04Oooool001Kooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool00oooool2o`0002Kooooo00Co
0000oooooooooooo00009?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Aooooo`00:_ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooool00000/?ooool002_ooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo00000;3ooooo000/oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08_ooool2o`000;7ooooo000]ooooo`;o
00005?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Qooooo`;o0000/Oooool002oooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0;3ooooo000`ooooo`03o`000?oo
oooooooo00gooooo0_l0000Nooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0;3ooooo000aooooo`;o00002_ooool3
o`00023ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo01kooooo0_l0002booooo`00<oooool;o`0002?ooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo01gooooo0ol0002aooooo`00H_ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool07Oooool2o`000;;o
oooo001Rooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooo00000;;ooooo001Sooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo00000;;ooooo001S
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooo00000;;ooooo001Tooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00;o0000/Oooool006Go
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Wo
oooo00Co0000oooooooooooo0000/_ooool006Gooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo01Wooooo00Co0000oooooooooooo0000/_ooool006Ko
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Oo
oooo00Go0000ooooooooooooooooo`00002booooo`00I_ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool05oooool01Ol0003ooooooooooooooooo0000
0;;ooooo001Wooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0Gooooo`04o`000?ooooooooooooooo`;o0000/Oooool006Sooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Kooooo00Go0000oooooooo
ooooooooo`00002booooo`00J?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Co
oooo00Ook^k^oc8b<_l0003o<S8bonk^k_oooooo000000?ooooo0_lQ8B44ooooo`Go00001?ooool0
1_m4A4Co0000o`000?lb<S;ogMgMo`0000Cooooo00?o0000ooooooooool0/?ooool006Wooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0Eooooo`07ogMgMonHV9SooooooiRHV?mgMgOo
ooooo`000003ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b
<_l000001?ooool00ol0003oooooooooo`2`ooooo`00JOooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo01Gooooo00Go410@oooooooooooooooooa0@4002ooooo`03o`000?oooooooooo
00Oooooo00?oV9RHob4Q8Oo^k^h02Oooool2o`0000Cooooo00?o0000ooooooooool0/?ooool006[o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Fooooo`05o`000?oooooooooooooo
ool000000_ooool00ol0003oooooooooo`08ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b
<_l000001?ooool3o`000;3ooooo001[ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool05oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool02Oooool00omg
MgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_l000001Oooool00ol0003oooooooooo`2`
ooooo`00Joooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Sooooo00Go410@oooo
oooooooooooooa0@4003ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0/?ooool006cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool00ol0003oooooooooo`05ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool01Ol0003ooooo
oooooooooooo000000Gooooo00?o0000ooooooooool0/?ooool006cooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00ol0003o
ooooooooo`05ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool5o`0000Gooooo00?o0000oooo
ooooool0/?ooool006gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool00oooool2o`000;7ooooo001^ooooo`;o0000
1?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`2`ooooo`00Koooool5o`0002Oooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;3ooooo002Looooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2`ooooo`00W?ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool009co
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`05ooooo`;o0000/Oooool009gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;3ooooo
002Mooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`2`ooooo`00WOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0/?ooool009kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06oooo
o`;o0000/Oooool009kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0;3ooooo002Nooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`2`ooooo`00Woooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0/?ooool009oooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo0;3ooooo002Oooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool2o`000;7ooooo002Pooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2`ooooo`00X?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0/?ooool009[ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP02ooooo`03o`000?oooooooooo00;o8B4Q0_ooool01?l0003ooooo
oooooom4A4@2o`000003oc8b<_oMgMgooooo00Cooooo00?o0000ooooooooool0/?ooool009[ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`03o`000?oooooooooo00;o8B4Q0_ooool00ol0003o
ooooooooo`03ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool009[ooooo
00Go410@oooooooooooooooooa0@4003ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`?o0000/?ooool009[ooooo00Go0000oooooooooooo
ooooo`000004ooooo`03o`000?oooooooooo00;o00001_ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo0;3ooooo002Jooooo`05o`000?ooooooooooooooool000001Oooool2o`0000Go
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00
00Kooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0/?ooool009;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo
00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`000;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002[ooooo`Co
000000?o410@ooooooooool00oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0/?ooool00:gooooo00?o0000ooooooooool01Oooool3o`000;3ooooo002]oooo
o`03o`000?oooooooooo0;Sooooo002]ooooo`03o`000?oooooooooo0;Sooooo002]ooooo`03o`00
0?oooooooooo0;Sooooo002[ooooo`03oeEEEOmVIVKo00000;[ooooo003oooooofWooooo002_oooo
o`03o`000?nj^[[ooooo0;Kooooo002_ooooo`;o<S8b]oooool0083ooooo0_l000001_l@413ooooo
ooooool@413o0000oa0@41Oooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
0on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06_ooool00ol0003ok^k^oooo
o`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07So
oooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`0000Wooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool00oo<
c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000_ooooo00?oEEEE
ojVYZOooool01oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`1hooooo`00
POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Oooooo00?oV9RHob4Q8Oo^k^h0
1?ooool01Ol@413ooooooooooooooooo410@01;ooooo00?o0000ooooooooool07?ooool00onYZJWo
EEEEooooo`08ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool0M_ooool0087o
oooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00002oooool00onHV9So8B4Qonk^kP03
ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0;ooooo`Ko00003?oo
ool00olQ8B7oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003ooooo
ooooo`1fooooo`00POooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001_ooooo00?oMgMgofIVI_oo
ool00_ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool07Oooool00omE
EEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooo
oooo000007Sooooo0021ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo00007?ooool01Ol0003ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool03_ooool00ol@413o0000o`000003o`0001co
oooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`04ooooo`05oa0@4?oooooooooooooo
ool@4100N?ooool0087ooooo00Ko0000oc8b<_oooooooooooc8b<_l0000Hooooo`05o`000?nj^[[o
oooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool0
6_ooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg07Sooooo0020ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@
41005oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0B
ooooo`03o`000?oooooooooo01[ooooo1Ol00004ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^07Sooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(760) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .28275 m
.04057 .31081 L
.06168 .32929 L
.06747 .33402 L
.07065 .33621 L
.07365 .33794 L
.07646 .33923 L
.07793 .33978 L
.0795 .34027 L
.08081 .3406 L
.08226 .3409 L
.08357 .3411 L
.08481 .34123 L
.08614 .34132 L
.08737 .34136 L
.08872 .34134 L
.08948 .34131 L
.09017 .34128 L
.09143 .34117 L
.09279 .34103 L
.09526 .34066 L
.09768 .34019 L
.10024 .33959 L
.10483 .33823 L
.11014 .33616 L
.11509 .33363 L
.12053 .3301 L
.12636 .32545 L
.13645 .31605 L
.14716 .30654 L
.15275 .30255 L
.15891 .29904 L
.16459 .2965 L
.16979 .29462 L
.17485 .29316 L
.17739 .29258 L
.18017 .2921 L
.18093 .292 L
.18164 .29192 L
.18298 .29181 L
.18372 .29177 L
.18441 .29175 L
.18517 .29174 L
.18597 .29176 L
.1873 .29184 L
.18854 .29198 L
.1899 .2922 L
.19137 .29253 L
.19397 .29335 L
.1968 .29462 L
Mistroke
.19947 .29619 L
.20195 .29797 L
.21163 .3076 L
.22275 .32288 L
.23322 .34032 L
.25277 .37884 L
.26305 .39733 L
.26822 .40418 L
.27115 .40704 L
.27247 .40805 L
.27389 .40897 L
.2752 .40963 L
.27641 .41009 L
.27757 .41039 L
.2788 .41057 L
.27989 .4106 L
.28092 .41052 L
.28205 .41032 L
.28326 .40997 L
.28449 .40948 L
.28582 .4088 L
.2885 .40695 L
.29099 .40473 L
.2933 .40227 L
.30438 .38602 L
.31482 .36602 L
.33435 .32631 L
.33964 .31749 L
.34459 .31073 L
.34974 .30535 L
.35248 .30319 L
.35541 .3014 L
.3579 .30028 L
.35931 .2998 L
.36061 .29946 L
.36175 .29923 L
.363 .29906 L
.36431 .29897 L
.36555 .29896 L
.36668 .29902 L
.36787 .29916 L
.36888 .29933 L
.37 .29959 L
.3712 .29994 L
.37248 .3004 L
.3748 .30147 L
.37751 .30314 L
.38038 .30546 L
.38553 .31118 L
.39108 .31991 L
Mistroke
.39718 .33283 L
.40811 .36401 L
.41834 .399 L
.42925 .43564 L
.43462 .45107 L
.43961 .46274 L
.44193 .46708 L
.44412 .47046 L
.44533 .47202 L
.44663 .47343 L
.44781 .47446 L
.44892 .4752 L
.45014 .47578 L
.45149 .47611 L
.4528 .4761 L
.45353 .47596 L
.4542 .47575 L
.4554 .47515 L
.4567 .4742 L
.45793 .47301 L
.45907 .47166 L
.46161 .46779 L
.46394 .46324 L
.46919 .44982 L
.47868 .41743 L
.48989 .37516 L
.50032 .34085 L
.5202 .2945 L
.53072 .27709 L
.5366 .26969 L
.53915 .26711 L
.54194 .26473 L
.5444 .26302 L
.54704 .26156 L
.54983 .26039 L
.55244 .25959 L
.55503 .259 L
.55749 .25857 L
.5621 .25791 L
.56717 .25709 L
.57256 .25586 L
.57847 .25416 L
.58395 .25266 L
.5867 .25208 L
.58808 .25186 L
.58887 .25176 L
.5896 .25168 L
.59089 .25158 L
.59228 .25153 L
.59357 .25155 L
Mistroke
.59478 .25161 L
.59546 .25166 L
.5962 .25173 L
.5977 .25193 L
.60039 .25244 L
.60649 .25401 L
.61176 .25535 L
.61328 .25566 L
.61472 .25591 L
.61601 .25608 L
.61674 .25616 L
.61743 .25622 L
.61878 .25629 L
.62 .25631 L
.62132 .25628 L
.62206 .25624 L
.62275 .25619 L
.62389 .25608 L
.62515 .25592 L
.62768 .2555 L
.63272 .25442 L
.63537 .25386 L
.6382 .25335 L
.63938 .25318 L
.64066 .25303 L
.64139 .25296 L
.64206 .25291 L
.64337 .25285 L
.64448 .25284 L
.6457 .25286 L
.64697 .25293 L
.64816 .25304 L
.64965 .25322 L
.65107 .25344 L
.65371 .25393 L
.65964 .25522 L
.66208 .25568 L
.66342 .25589 L
.66467 .25606 L
.66602 .25619 L
.66673 .25623 L
.6675 .25627 L
.66887 .25629 L
.67012 .25626 L
.67147 .25617 L
.67275 .25603 L
.67389 .25587 L
.67513 .25566 L
.68047 .25437 L
.68506 .25306 L
Mistroke
.68748 .25242 L
.69008 .25185 L
.69158 .25159 L
.69294 .25141 L
.6943 .25128 L
.6956 .25122 L
.6963 .2512 L
.69705 .2512 L
.69839 .25125 L
.69914 .2513 L
.69983 .25135 L
.70142 .25154 L
.70404 .25197 L
.70644 .25247 L
.71185 .2537 L
.71442 .25422 L
.71684 .2546 L
.71818 .25476 L
.71894 .25482 L
.71963 .25487 L
.72086 .25493 L
.72217 .25495 L
.7233 .25493 L
.72453 .25487 L
.72568 .25478 L
.72673 .25467 L
.72931 .25433 L
.73175 .25394 L
.7368 .2531 L
.73802 .25294 L
.73935 .25279 L
.7401 .25272 L
.7408 .25268 L
.74216 .25262 L
.74353 .25261 L
.74431 .25264 L
.74503 .25268 L
.74579 .25274 L
.74649 .25281 L
.74805 .25303 L
.74939 .25328 L
.75085 .25363 L
.7535 .2544 L
.76334 .25831 L
.76877 .26036 L
.77144 .26117 L
.77392 .26178 L
.77682 .26233 L
.77999 .26275 L
.78554 .26328 L
Mistroke
.78825 .26358 L
.7908 .26395 L
.79375 .26456 L
.79642 .26531 L
.80145 .26729 L
.80676 .27006 L
.81627 .27556 L
.82121 .27798 L
.82651 .27992 L
.82955 .28072 L
.83232 .2813 L
.83774 .28221 L
.84279 .28312 L
.84816 .28445 L
.85273 .28597 L
.85779 .28794 L
.8632 .29004 L
.86604 .29098 L
.86759 .29142 L
.86903 .29177 L
.87041 .29205 L
.87166 .29225 L
.87305 .29242 L
.87382 .29248 L
.87454 .29252 L
.8758 .29256 L
.87696 .29255 L
.87824 .2925 L
.87959 .29239 L
.88086 .29224 L
.88225 .29204 L
.88477 .29159 L
.8895 .29058 L
.89466 .2895 L
.89749 .28902 L
.90015 .28868 L
.90267 .28845 L
.90408 .28835 L
.90539 .28828 L
.90769 .28819 L
.91013 .28812 L
.91226 .28805 L
.91345 .288 L
.91454 .28794 L
.91583 .28785 L
.91704 .28774 L
.91938 .28746 L
.92187 .28704 L
.92421 .28653 L
.92955 .28495 L
Mistroke
.93518 .28286 L
.94033 .28093 L
.94261 .28017 L
.94511 .27945 L
.94749 .27889 L
.94965 .2785 L
.95095 .27832 L
.95217 .2782 L
.95346 .2781 L
.95419 .27806 L
.95485 .27804 L
.95597 .27802 L
.9572 .27803 L
.95849 .27806 L
.95969 .27812 L
.96487 .27851 L
.9676 .27875 L
.97051 .27898 L
.97304 .27914 L
.97439 .27921 L
.97584 .27927 L
.97838 .27935 L
.98077 .27941 L
.9831 .27948 L
.98442 .27953 L
.98565 .27959 L
.98695 .27968 L
.98814 .27979 L
.98951 .27994 L
.9908 .28012 L
.99309 .28054 L
.99521 .28106 L
.99754 .28179 L
1 .28275 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool05oooool8o`0000[o
oooo1Ol00009ooooo`Wo00002?ooool6o`0006;ooooo002eooooo`03o`000?oooooooooo01?ooooo
1?l00008ooooo`[o00001Oooool9o`0000Wooooo2?l00006ooooo`?o0000Goooool00;Gooooo00?o
0000ooooooooool03_ooool5o`0003kooooo00?o0000ooooooooool0G?ooool00;Gooooo0_l0000<
ooooo`?o0000A?ooool6o`0005Sooooo002eooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0Boooool5o`0005?ooooo000Eooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o
0000oc8b<_o^k^h06_ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01cooooo1?l000002?l@
413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^7_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo01?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^6_ooool5
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`;o00003_ooool01OnHV9So410@o`00
0?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Mooooo`;o000000Wo410@oooooooo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^h03_ooool001Kooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL06oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Nooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01OnHV9So8B4Qonk^k_ooooooA4A400?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0=ooooo`?o00002oooool01Ol@413o^[ZjoooooomgMgOo
<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0>ooooo`002oooool6o`0000;ooooo1Ol00003ooooo`05oa0@4?oo
ooooooooooooool@41004_ooool6o`0000Kooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo017ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooo
oooooooooa0@400Cooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41007_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01_ooooo00?oV9RHob4Q8Oo^k^h01?oo
ool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool03?ooool01Ol0003ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool06Oooool5o`0000?ooooo00Go410@oooooooo
oooooooooa0@400>ooooo`004oooool01?m4A4CogMgMooooool00004ooooo`05o`000?oooooooooo
ooooool000007Oooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000007Ooo
ool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000007_ooool2o`0000Sooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007?ooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000004Oooool2o`0000_ooooo00?oZJVY
oa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000001;ooooo1ol00002ooooo`04odA4A?oM
gMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`004oooool01?oMgMgoEEEE
ooooool00004ooooo`05o`000?ooooooooooooooool000007?ooool00ol@413o0000okZj^P03oooo
o`05o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooo
ooooooooool000007_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
7_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000001gooooo00?oMgMgofIVI_ooool00_ooool01Ol0003o
oooooooooooooooo000001?ooooo0ol00007ooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000oooo
ooooooooooooo`00000>ooooo`Co00001oooool9o`000003ooooool0003ooooo00;ooooo00?o0000
ooooooooool03?ooool001Cooooo00CoMgMgolc<c?l0003o00000oooool01Ol@413ooooooooooooo
oooo410@01gooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@01oooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@01kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400N
ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Dooooo`Go00000ooo
ool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41002oooool3o`0000kooooo
00?oMgMgolc<c?l000000oooool00ol0003o410@ooooo`02ooooo`03oa0@4?oooooooooo00cooooo
000Dooooo`05onk^k_m4A4Co0000ooooool000000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01[o
oooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool0
1Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL06_ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Kooooo`Go00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo1_l0000Aooooo`03onk^
k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`005Oooool01?mgMgOo0000
ooooooooool2o`000005onk^k_lb<S;o0000oc8b<_o^k^h06_ooool01OnYZJWo410@o`000?l@413o
ZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^01kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Goooo
o`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Jooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00GoZJVYoa0@4?l0003o
410@o`000003ooooo`03onk^k_lb<S;o000000So00005oooool00omgMgOo0000ooooo`03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03_ooool001_ooooo00?o0000ooooooooool0;oooool7o`00067o
oooo0_l00005ooooo`03o`000?oooooooooo06_ooooo1_l0000hooooo`007?ooool2o`0002_ooooo
1?l00007ooooo`;o0000Goooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0:[ooooo
000Nooooo`03o`000?oooooooooo02Kooooo0_l0000=ooooo`03o`000?oooooooooo02oooooo1Ol0
000Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Z_ooool001oooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02cooooo0_l00005
ooooo`;o00009_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0:_ooooo000Poooo
o`;o00008_ooool2o`0001;ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2[oooo
o`005_ooooooo`00043o00004oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool00ol0
003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool04Oooool001Kooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Fooooo`05o`000?ooooooooooooooool000006?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01oooool01?l0003ooooo
ooooool0000Tooooo`05o`000?ooooooooooooooool000008oooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Aoooo
o`009Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo027ooooo00Co0000oooooooo
oooo0000[oooool002Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Pooooo`04
o`000?ooooooooooo`000:oooooo000Wooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool08?ooool3o`000;3ooooo000Xooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
7oooool00ol0003oooooo`00002`ooooo`00:Oooool2o`00013ooooo0_l0000Qooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Oooooo`;o0000/Ooo
ool002_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Nooooo`;o0000/Oooool0
02cooooo0_l00009ooooo`?o00009Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool07_ooool2o`000;7ooooo000^ooooo`Wo0000:Oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool07Oooool2o`000;7o
oooo001Pooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo0;3ooooo001Qooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo0;3ooooo001Q
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0K
ooooo`;o0000/_ooool006;ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo01_ooooo0_l0002booooo`00H_ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool06_ooool3o`000;7ooooo001Sooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooo00000;;ooooo001Sooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooo00000;;ooooo001Tooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
00000;;ooooo001Tooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooo00000;;ooooo001Uooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00;o
0000/Oooool006Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo01Kooooo00Co0000oooooooooooo0000/_ooool006Kooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0Gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool00ol0003o
ooooooooo`02ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01?l0
003oooooooooool0002booooo`00I_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
01Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`03o`000?oooooooooo00;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00GoMgMgoc8b<_ooooooooooo`000002ooooo`03o`00
0?oooooooooo0;3ooooo001Wooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool05ooo
ool01Ol@413ooooooooooooooooo410@00?ooooo00?o0000ooooooooool01_ooool00onHV9So8B4Q
onk^kP09ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool0/?ooool006Oooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`07ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00CoMgMgoc8b<_oooooo
00000oooool3o`000;3ooooo001Xooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
6?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool02?ooool00omgMgOo
IVIVooooo`03ooooo`07o`000?lQ8B7o0000oc8b<_o<c<coooooo`000003ooooo`03o`000?oooooo
oooo0;3ooooo001Xooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06Oooool01Ol@
413ooooooooooooooooo410@00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2`
ooooo`00JOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01[ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`04ooooo`03o`000?oooooooooo00Cooooo00Go0000okZj^_ooooooV9RHoa0@
4004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`2`ooooo`00J_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01_ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP04ooooo`03o`000?oooooooooo00Cooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c004ooooo`Co000000?oooooo`000?ooool00oooool00ol0003oooooooooo`2`ooooo`00Jooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`02ooooo`;o0000/Oooool006cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`2`ooooo`00K?ooool6o`0002[ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002Looooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2`ooooo`00W?ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0/?ooool009gooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`04ooooo`;o0000/Oooool009gooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;3ooooo002Moooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2`oooo
o`00WOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0/?ooool009kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`;o0000
/Oooool009kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0;3ooooo002Nooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`2`ooooo`00Woooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0/?ooool009oooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo0;3ooooo002Oooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool01oooool2o`000;7ooooo002Pooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00X?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP02ooooo`03o`000?oooooooooo00;o8B4Q1?ooool01_l0003oA4A4o`000?l0
003o<S8bomgMg@Gooooo00?o0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`02ooooo`03o`000?oooooooooo00;o8B4Q1?ooool01_l0003oooooooooooooooooMgMgoc8b
<PGooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@oooooooooooooooooa0@4003oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`?o0000/?ooool009[ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
0;3ooooo002Jooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`04oooo
o`07o`000?oooooo0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05oa0@4?ooooooooooooooool@41001?ooool2o`0000;ooooo0_l00002ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`Co00000oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgM
g@05ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEoooo
o`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009;ooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?oo
ool3o`000;3ooooo002Booooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<oooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`ooooo`00T_oo
ool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co
00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002[ooooo`Co000000?o410@ooooooooool00oooool0
0ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool00:gooooo
00?o0000ooooooooool01Oooool3o`000;3ooooo002]ooooo`03o`000?oooooooooo0;Sooooo002]
ooooo`03o`000?oooooooooo0;Sooooo002]ooooo`03o`000?oooooooooo0;Sooooo002[ooooo`03
oeEEEOmVIVKo00000;[ooooo003oooooofWooooo002_ooooo`03o`000?nj^[[ooooo0;Kooooo002_
ooooo`;o<S8b]oooool0083ooooo0_l000001_l@413oooooooooool@413o0000oa0@41Oooooo1Ol0
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOo0000okZj^P0<ooooo`05oiRH
V?l0003o0000odA4A?nj^[X06_ooool00ol0003ok^k^ooooo`03ooooo`05onk^k_lb<S;o0000oa0@
4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07Sooooo0021ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01oooool6o`0000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj
^[[ok^k^ogMgMol@41002Oooool6o`0000_ooooo00?oEEEEojVYZOooool00oooool01OmEEEGoMgMg
oooooonHV9So8B4Q00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1hooooo`00POooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo01Oooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@01;ooooo00?o0000ooooooooool07?ooool00onYZJWoEEEEooooo`03oooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@07Sooooo0021
ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000_ooooo00?oV9RHob4Q8Oo^k^h0
0oooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool02oooool6o`0000co
oooo00?o8B4Qooooooooool00_ooool01Ol0003oV9RHoooooonHV9So8B4Q00?ooooo00Go0000oooo
ooooooooooooo`00001hooooo`00POooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001_ooooo00?o
MgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool0
7Oooool00omEEEGoc<c<ooooo`02ooooo`05o`000?mEEEGo0000oa0@4?o<c<`00oooool01Ol0003o
oooooooooooooooo000007Sooooo0021ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo00007?ooool0
1Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool03_ooool00ol@413o0000o`00
0003o`0001cooooo00?oZJVYogMgMoooool00_ooool00omEEEGoQhN7ooooo`05ooooo`05oa0@4?oo
ooooooooooooool@4100N?ooool0087ooooo00Ko0000oc8b<_oooooooooooc8b<_l0000Hooooo`05
o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000
ooooooooool06_ooool01Ol@413ooooooooooooooooo<S8b00?ooooo00?ogMgMoa0@4?nHV9P01Ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg07Sooooo0020ooooo`03oa0@4?l0003oQhN700;ooooo00?o
QhN7o`000?l@41005oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0Booooo`03o`000?oooooooooo01[ooooo1Ol00004ooooo`04olc<c?m4A4Co0000oa0@
40?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1hooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(770) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .28997 m
.01975 .30663 L
.04057 .32377 L
.05077 .33296 L
.05638 .33722 L
.05914 .33891 L
.06168 .34018 L
.06469 .34129 L
.06627 .3417 L
.06708 .34187 L
.06795 .34201 L
.06868 .34211 L
.06935 .34218 L
.07067 .34225 L
.0714 .34226 L
.0722 .34225 L
.07295 .34222 L
.07365 .34216 L
.07436 .3421 L
.07511 .342 L
.07649 .34178 L
.07905 .34123 L
.08205 .34037 L
.08481 .33942 L
.09503 .33489 L
.10457 .32904 L
.11505 .32008 L
.12627 .30846 L
.13695 .29841 L
.14299 .29404 L
.14857 .29088 L
.15882 .28659 L
.16399 .28493 L
.16672 .2842 L
.16816 .28386 L
.1697 .28355 L
.1711 .28331 L
.17237 .28314 L
.17365 .28302 L
.17486 .28295 L
.17622 .28293 L
.17747 .28298 L
.17884 .2831 L
.17954 .28319 L
.1803 .28332 L
.18156 .28359 L
.18272 .2839 L
.18532 .28484 L
.18773 .28601 L
.19001 .2874 L
Mistroke
.19545 .29175 L
.20049 .29697 L
.21191 .31212 L
.2335 .3513 L
.24302 .37229 L
.25305 .39308 L
.25809 .4014 L
.26075 .40496 L
.26361 .40803 L
.26496 .4092 L
.26623 .41014 L
.26748 .41089 L
.26862 .41144 L
.26971 .41183 L
.27087 .41212 L
.27203 .41227 L
.2733 .41227 L
.27469 .4121 L
.27538 .41194 L
.27614 .41171 L
.27749 .41117 L
.27874 .41052 L
.28157 .40853 L
.28459 .40567 L
.29014 .39864 L
.29518 .39053 L
.31706 .34392 L
.32667 .32349 L
.33175 .31424 L
.33721 .30595 L
.34253 .29954 L
.34738 .29506 L
.34971 .29331 L
.35225 .29171 L
.35463 .29046 L
.35687 .28951 L
.35936 .2887 L
.36068 .28839 L
.36136 .28825 L
.3621 .28813 L
.36284 .28804 L
.36352 .28798 L
.36424 .28794 L
.365 .28792 L
.36572 .28793 L
.3664 .28797 L
.36767 .28811 L
.36888 .28833 L
.37016 .28865 L
.37125 .28901 L
Mistroke
.37246 .2895 L
.37514 .29094 L
.37766 .29277 L
.38288 .29816 L
.38583 .30221 L
.38857 .30661 L
.39893 .32869 L
.40835 .35509 L
.41839 .38798 L
.4292 .42564 L
.43489 .44427 L
.44089 .46107 L
.44343 .46684 L
.44615 .47193 L
.44771 .47429 L
.44914 .47605 L
.45057 .47743 L
.45192 .47838 L
.45315 .47892 L
.45445 .47916 L
.45556 .47909 L
.45679 .47873 L
.4581 .47801 L
.45884 .47745 L
.45951 .47685 L
.46207 .47377 L
.46468 .46939 L
.46706 .46443 L
.47238 .45045 L
.48196 .41899 L
.5037 .34659 L
.51349 .31991 L
.52386 .29751 L
.52927 .28869 L
.53523 .28133 L
.54064 .27648 L
.5457 .2731 L
.55664 .26739 L
.56702 .26214 L
.57153 .26006 L
.57634 .2583 L
.57776 .25789 L
.5791 .25757 L
.58041 .25731 L
.5816 .25711 L
.58275 .25697 L
.58395 .25686 L
.58516 .2568 L
.58649 .25677 L
.58786 .25679 L
Mistroke
.58914 .25684 L
.5898 .25688 L
.59053 .25694 L
.59201 .25706 L
.59453 .25732 L
.59724 .2576 L
.59859 .25772 L
.59988 .25782 L
.60103 .25788 L
.60229 .25792 L
.60348 .25792 L
.60475 .25789 L
.60594 .25783 L
.60703 .25774 L
.6084 .25759 L
.60986 .25737 L
.61246 .25686 L
.61834 .25529 L
.62392 .25371 L
.62656 .25309 L
.62901 .25265 L
.63019 .25249 L
.63145 .25237 L
.63272 .25228 L
.63344 .25226 L
.63411 .25225 L
.63533 .25226 L
.63644 .2523 L
.63767 .25238 L
.63895 .2525 L
.64159 .25284 L
.64405 .25322 L
.64691 .25369 L
.64962 .25409 L
.65075 .25422 L
.65196 .25434 L
.65328 .25443 L
.65449 .25447 L
.65558 .25448 L
.6566 .25446 L
.65772 .2544 L
.65892 .2543 L
.6602 .25415 L
.66159 .25394 L
.66412 .25343 L
.66887 .25219 L
.67155 .25143 L
.67446 .25067 L
.67702 .25011 L
.67842 .24987 L
Mistroke
.67972 .24969 L
.6809 .24957 L
.68216 .2495 L
.68289 .24948 L
.68357 .24948 L
.68484 .24951 L
.68602 .24959 L
.6871 .2497 L
.68829 .24987 L
.68955 .25008 L
.71159 .25454 L
.72168 .25377 L
.72413 .25353 L
.72551 .25342 L
.72675 .25336 L
.72746 .25334 L
.72823 .25333 L
.72896 .25334 L
.72963 .25336 L
.73092 .25344 L
.7323 .25358 L
.73347 .25376 L
.73455 .25396 L
.73697 .25456 L
.73921 .25529 L
.74133 .25612 L
.75127 .26092 L
.75598 .26306 L
.761 .26481 L
.76362 .26546 L
.76651 .266 L
.76914 .26638 L
.77161 .26667 L
.77429 .26699 L
.7771 .2674 L
.77951 .26786 L
.78215 .26853 L
.78499 .26948 L
.78804 .27077 L
.79352 .2737 L
.80425 .28015 L
.80719 .28162 L
.81031 .28291 L
.81297 .28376 L
.81447 .28414 L
.8159 .28444 L
.81721 .28467 L
.81865 .28486 L
.81996 .285 L
.82116 .2851 L
Mistroke
.82258 .2852 L
.82409 .28528 L
.82682 .28541 L
.82935 .28556 L
.83077 .28568 L
.83209 .28582 L
.8345 .28614 L
.83705 .28661 L
.847 .28942 L
.84963 .29023 L
.85248 .29101 L
.85379 .29131 L
.85518 .29158 L
.85638 .29178 L
.85767 .29193 L
.85896 .29203 L
.86014 .29207 L
.86127 .29206 L
.86246 .292 L
.86377 .29187 L
.86498 .2917 L
.86632 .29145 L
.86774 .29113 L
.87255 .28967 L
.87692 .28807 L
.88202 .28627 L
.8848 .28544 L
.88741 .28481 L
.88963 .28438 L
.89201 .28404 L
.89337 .28388 L
.89466 .28377 L
.89707 .2836 L
.89968 .28345 L
.90214 .28331 L
.9035 .28321 L
.90496 .28307 L
.90752 .28276 L
.90902 .28251 L
.9106 .2822 L
.91343 .2815 L
.91891 .27967 L
.9289 .27571 L
.93177 .27476 L
.93449 .27404 L
.93567 .27379 L
.93693 .27358 L
.93831 .2734 L
.93958 .27329 L
.94077 .27323 L
Mistroke
.94186 .27321 L
.94312 .27323 L
.94431 .27329 L
.94541 .27338 L
.94643 .27348 L
.94875 .27379 L
.95885 .27565 L
.96993 .27714 L
.97257 .27743 L
.97537 .2778 L
.97775 .2782 L
.98038 .27878 L
.98272 .27946 L
.98522 .28038 L
.98975 .2826 L
.99506 .28607 L
.99991 .28989 L
1 .28997 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0=Oooool7o`0007Cooooo002eooooo`03o`000?oooooooooo02Go
oooo1ol00005ooooo`Co00001oooool3o`0000Gooooo1?l0001Xooooo`00]Oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo00Oooooo0ol00007ooooo`Go00003_ooool5o`0000?ooooo
1Ol0001Tooooo`00]Oooool00ol0003oooooooooo`0Eooooo`go0000:_ooool00ol0003ooooooooo
o`1Qooooo`00]Oooool2o`0001;ooooo1?l0000hooooo`03o`000?oooooooooo063ooooo002eoooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0>oooool5o`0005gooooo000Eooooo`;o
000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h06_ooool01OnHV9So410@o`00
0?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^01cooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
7_ooool00ol0003oooooooooo`0>ooooo`;o00003oooool4o`000008oa0@4?ooooooooooonk^k_lb
<S;o0000oc8b<_o^k^hJooooo`Go00000oooool01_o^k^ko<S8bo`000?lb<S;ok^k^ooooo`Go0000
5Oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Moooo
o`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h03_ooool001Kooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00Go410@okZj^_oooooo
MgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00cooooo0_l0000Cooooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo0_l0000Cooooo`05oa0@4?nj^[[o
ooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko00000_ooool5o`0000?ooooo
00Go410@oooooooooooooooooa0@400Booooo`Ko00001_ooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool04Oooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@
413ooooooooooooooooo410@01?ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Nooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41006oooool00onHV9So8B4Q
onk^kP04ooooo`05oa0@4?ooooooooooooooool@41002?ooool2o`0001Gooooo00Go0000oooooooo
oooooooooa0@4003ooooo`03oa0@4?oooooooooo00[ooooo2Ol00006ooooo`Go00000oooool01Ol@
413ooooooooooooooooo410@00kooooo000Cooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000
ooooooooooooooooo`00000Mooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oooooooooooooooo
o`00000Mooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Nooooo`;o00002_ooool2o`00
01Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001cooooo00?oV9RH
ob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000[ooooo0_l0000Booooo`03ojVYZOl@
413ooooo00;ooooo00Go0000ooooooooooooooooo`00000:ooooo`;o00002Oooool7o`000003omgM
gOoooooo000000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`004oooool01?oMgMgoEEEE
ooooool00004ooooo`05o`000?ooooooooooooooool000007?ooool00ol@413o0000okZj^P03oooo
o`05o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooo
ooooooooool000007_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
7_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000001gooooo00?oMgMgofIVI_ooool00_ooool01Ol0003o
oooooooooooooooo000000cooooo0_l0000?ooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000oooo
ooooooooooooo`000007ooooo`?o00004Oooool01?oMgMgo0000o`000?l00004ooooo`05o`000?oo
ooooooooooooool000003_ooool001Cooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooo
oooooooo410@01gooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00;o
oooo2Ol0000Dooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Loooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Nooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41007_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0
3?ooool4o`0000cooooo00?o^[Zjob4Q8Oooool00_ooool00ol@413oooooooooo`09o`0001Gooooo
00CoMgMgolc<c?l0003o00000oooool01Ol@413ooooooooooooooooo410@00kooooo000Dooooo`03
onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05oa0@4?nHV9Sooooo
okZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00;o00002?ooool2o`0000oooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool3o`000003
ooooool0003ooooo00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL06_ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0Aooooo`So00000_ooool01Ol@413oV9RHoooooonj^[[o000000;ooooo1?l000000onHV9So
MgMgooooo`0Kooooo`04onk^k_m4A4Co0000ooooo`;o000000KoooooogMgMonHV9SooooooiRHV?mg
MgL>ooooo`005Oooool00omgMgOo0000o`000003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06_oo
ool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00?ok^k^oc8b<_l000000_l0000<ooooo`03o`00
0?oooooooooo00cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h06?ooool3o`000004ooooool0003o0000o`0000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05_ooool00omEEEGoIVIVo`00
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06_ooool01OnHV9So410@o`000?lQ8B7oc<c<00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Iooooo`Go000000[o410@ojVYZOl0003o0000ooooooo^
k^ko<S8bo`000?lb<S;ok^k^7Oooool00omgMgOo0000ooooo`02ooooo`06o`000?o^k^ko<S8bo`00
0?lb<S;ok^k^3_ooool001Sooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0>oooo
o`;o0000;oooool2o`0000Oooooo00?o0000ooooooooool09?ooool2o`0000Kooooo00?o0000oooo
ooooool0I_ooool5o`0003gooooo000Iooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0:Wooooo000Jooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Zooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo0:Wooooo000Kooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0:[ooooo000Looooo`;o00008Oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Z_ooool0
01Koooooool00010o`0001?ooooo000Fooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00007ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo017ooooo000Fooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06Ooo
ool2o`0001_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Aooooo`008Oooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`2[ooooo`008_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
01kooooo00Go0000ooooooooooooooooo`00002^ooooo`008oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo01kooooo0_l00002ooooo`03o`000?oooooooooo0:cooooo000Tooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool07Oooool01?l0003oooooooooool0002_oooo
o`009Oooool00ol0003oooooooooo`0>ooooo`;o00009?ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool07Oooool01?l0003oooooooooool0002_oooo
o`009_ooool2o`0000_ooooo0ol0000Wooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`0Looooo`04o`000?ooooooooooo`000:oooooo000Xooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool07?ooool00ol0003oooooo`00002`ooooo`00
:Oooool2o`0000Cooooo0ol0000/ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0Looooo`?o0000/?ooool002_ooooo1?l0000_ooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooo00000;3ooooo001Oooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Kooooo`;o0000/Oooool005oooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo0_l0002aooooo`00H?ooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06_ooool2o`000;7o
oooo001Pooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Jooooo`;o0000/Oooool0067ooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0/?ooool0067ooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool0/?ooool006;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo01Sooooo0_l0002booooo`00H_ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool06?ooool2o`000;;ooooo001Sooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Hooooo`?o0000
/Oooool006?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooool00000/_ooool006Cooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01?l0003oooooob4Q
8OlQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00?ooooo00?o0000ooooool0
0000/_ooool006Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Iooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01?l0003oooooob4Q8OlQ8B44ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@01oooool00omgMgOo<S8booooo`02ooooo`03o`000?oooooo00000;;ooooo001Uoooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool06_ooool01Ol@413ooooooooooooooooo
410@00Cooooo00?o0000ooooooooool01Oooool00onHV9So8B4Qonk^kP09ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooooooool0/?ooool006Gooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooooooo
o`06ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00GoMgMgoc8b<_ooooooooooo`000002ooooo`?o0000
/?ooool006Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Kooooo`05o`000?oo
ooooooooooooool000001?ooool00ol0003oooooooooo`07ooooo`03ogMgMomVIVKooooo00?ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`04o`000?ooooooooooo`000;;ooooo001Vooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool06oooool01Ol@413ooooooooooooooooo410@
00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00Co0000oooooooooooo0000/_ooool006Kooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Looooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`03
ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`03ooooo`05o`000?oo
ooooooooooooool00000/_ooool006Oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Mooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`03ooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000;ooooo00Go0000ooooooooooooooooo`00002boooo
o`00J?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool04_ooool01?l0003oooooooooooooool2o`000;7ooooo001Yooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0/?ooool006[ooooo00Co0000oooooooooooooooo0_l0000]ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2`ooooo`00
Joooool4o`0002kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0;3ooooo002Mooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`2`ooooo`00WOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00?ooooo0_l0002aooooo`00W_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0/?ooool009kooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002Nooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`2`ooooo`00Woooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00Cooooo0_l0002aooooo`00Woooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0/?ooool009oooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;3ooooo002Pooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2`ooooo`00
X?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
/?ooool00:3ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`;o0000/Ooo
ool00:7ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo0;3ooooo002Qooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo00?o0000oooo
ooooool00_lQ8B45ooooo`?o000000?o<S8bomgMgOooool01?ooool00ol0003oooooooooo`2`oooo
o`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Co0000oooooolQ8B7o8B4Q1Oooool0
1Ol0003ooooooooooomgMgOo<S8b00Gooooo00?o0000ooooooooool0/?ooool009[ooooo00Go410@
oooooooooooooooooa0@4003ooooo`03o`000?oooooooooo00Kooooo00Go0000oooooooooooooooo
o`000005ooooo`?o0000/?ooool009[ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo00Cooooo00Ko0000ooooooooooooooooogMgMolb<S85ooooo`03o`000?oooooooooo
0;3ooooo002Jooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`04oooo
o`;o000000Co8B4Qo`000?lb<S;oc<c<1Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol@
413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool00oooool2o`0000Wooooo00?o0000
ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o00000oooool0
0ol0003oooooo`000009ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01_ooool4o`0000;ooooo1?l00006ooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46
ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`
ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooo
ooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`
ooooo`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00Go410@
oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`2`ooooo`00T_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
/?ooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo
00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00Zoooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooo
ooooool0/?ooool00:gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2`ooooo`00
[Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;3ooooo002]ooooo`03o`000?oo
oooooooo00Gooooo0ol0002`ooooo`00[Oooool00ol0003oooooooooo`2hooooo`00[Oooool00ol0
003oooooooooo`2hooooo`00[Oooool00ol0003oooooooooo`2hooooo`00Zoooool00omEEEGoIVIV
o`00002jooooo`00oooooomYooooo`00[oooool00ol0003o^[Zjooooo`2fooooo`00[oooool2oc8b
<[Oooooo0020ooooo`;o000000Ko410@oooooooooooo410@o`000?l@410Gooooo`Go00000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`00
0?m4A4Co^[Zj01[ooooo00?o0000onk^k_ooool01Oooool00ol0003ok^k^ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0N?ooool0087ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`Ko00002Oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`03olc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009
ooooo`Ko00002oooool00omEEEGoZJVYooooo`05ooooo`03oeEEEOnYZJWooooo00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`1hooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo01Oooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01;ooooo00?o
0000ooooooooool07?ooool00onYZJWoEEEEooooo`05ooooo`03ojVYZOmEEEGooooo00?ooooo00Go
410@oooooooooooooooooa0@401hooooo`00POooool01_l0003oooooodA4A?m4A4Coooooo`0000Wo
oooo1_l0000;ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Boooo
o`03o`000?oooooooooo00_ooooo1_l0000<ooooo`03ob4Q8Ooooooooooo00Gooooo00?o8B4Qoooo
ooooool00_ooool01Ol0003ooooooooooooooooo000007Sooooo0021ooooo`06o`000?oMgMgo<S8b
oeEEEOoMgMgo00006oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000
4_ooool00ol0003oooooooooo`0Mooooo`03oeEEEOo<c<cooooo00Gooooo00?oEEEEolc<c?ooool0
0_ooool01Ol0003ooooooooooooooooo000007Sooooo0021ooooo`06o`000?n7QhOoZJVYokZj^_mE
EEGo00007?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool03_ooool0
0ol@413o0000o`000003o`0001cooooo00?oZJVYogMgMoooool01Oooool00onYZJWoMgMgooooo`02
ooooo`05oa0@4?ooooooooooooooool@4100N?ooool0087ooooo00Ko0000oc8b<_oooooooooooc8b
<_l0000Hooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
01;ooooo00?o0000ooooooooool06_ooool01Ol@413ooooooooooooooooo<S8b00?ooooo00Go410@
oooooooooooooooooc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0N?ooool0083ooooo00?o
410@o`000?n7QhL00_ooool00on7QhOo0000oa0@400Gooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo00?o0000ooooooooool06_ooool5o`0000?o
oooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0N?ooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(780) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30265 m
.01975 .3191 L
.02981 .32775 L
.04057 .33713 L
.04351 .33927 L
.04629 .34098 L
.04879 .3422 L
.05008 .3427 L
.0515 .34315 L
.05283 .34347 L
.05407 .34368 L
.05538 .3438 L
.05612 .34384 L
.05679 .34384 L
.05799 .34378 L
.0593 .34364 L
.06053 .34343 L
.06168 .34317 L
.0647 .34223 L
.06755 .34105 L
.07288 .33831 L
.08481 .33087 L
.10589 .3124 L
.11525 .30179 L
.12529 .29152 L
.13063 .28728 L
.13551 .28425 L
.14505 .28002 L
.15039 .27823 L
.15619 .27659 L
.15885 .27598 L
.16031 .2757 L
.16168 .27547 L
.16284 .27532 L
.16409 .27519 L
.16548 .27511 L
.16675 .2751 L
.16809 .27515 L
.16936 .27526 L
.17049 .27542 L
.17173 .27566 L
.17307 .276 L
.17449 .27646 L
.17704 .27754 L
.1794 .27884 L
.1816 .28031 L
.18662 .28457 L
.1971 .29682 L
.20835 .31377 L
.22909 .3557 L
Mistroke
.24004 .38117 L
.24604 .39358 L
.24899 .3988 L
.25169 .40297 L
.2543 .40634 L
.25716 .40928 L
.25855 .4104 L
.26003 .41138 L
.26085 .41183 L
.2616 .41217 L
.26231 .41245 L
.26306 .41268 L
.26438 .41295 L
.2656 .41304 L
.26691 .41297 L
.26765 .41286 L
.26835 .4127 L
.26961 .4123 L
.27076 .4118 L
.27336 .41024 L
.27578 .40824 L
.27804 .40595 L
.28315 .3993 L
.29344 .38069 L
.31316 .33538 L
.32353 .31433 L
.3345 .29826 L
.34007 .2924 L
.34619 .28736 L
.34887 .28555 L
.35175 .28388 L
.35445 .28258 L
.35695 .28163 L
.35827 .28124 L
.35967 .2809 L
.36035 .28078 L
.36108 .28066 L
.36188 .28057 L
.36263 .28052 L
.364 .2805 L
.36469 .28053 L
.36544 .2806 L
.36678 .2808 L
.36802 .28108 L
.36934 .28149 L
.37058 .28199 L
.3729 .28318 L
.37541 .28489 L
.37812 .28722 L
.38325 .29297 L
Mistroke
.38805 .29983 L
.39897 .32017 L
.40961 .34614 L
.42105 .38141 L
.43167 .41858 L
.43728 .43745 L
.44326 .45482 L
.44622 .46183 L
.449 .46726 L
.4515 .47108 L
.45279 .47263 L
.45421 .47401 L
.45554 .47498 L
.45678 .47561 L
.45809 .47598 L
.45883 .47605 L
.4595 .47603 L
.46069 .47581 L
.46199 .4753 L
.46322 .47455 L
.46436 .47364 L
.4669 .47087 L
.46923 .46749 L
.47448 .45725 L
.48397 .43165 L
.50561 .36044 L
.51523 .33275 L
.5255 .31032 L
.5314 .30067 L
.53676 .29344 L
.54724 .28175 L
.55703 .27255 L
.56239 .26839 L
.5674 .26531 L
.57023 .26395 L
.57281 .26294 L
.57568 .26207 L
.57876 .26138 L
.58134 .26094 L
.58414 .26055 L
.58924 .25986 L
.5948 .25884 L
.59793 .25806 L
.60081 .25721 L
.606 .25546 L
.61168 .25356 L
.61415 .25285 L
.6168 .25222 L
.61808 .25198 L
.6193 .25178 L
Mistroke
.62038 .25164 L
.62157 .25153 L
.62283 .25144 L
.62417 .25139 L
.62541 .25139 L
.62657 .25141 L
.62793 .25148 L
.62918 .25156 L
.63199 .25182 L
.63687 .25232 L
.63828 .25244 L
.6396 .25254 L
.64079 .2526 L
.64208 .25263 L
.64277 .25264 L
.64352 .25264 L
.64431 .25262 L
.64505 .25259 L
.64637 .25252 L
.64711 .25246 L
.64779 .25239 L
.65051 .25203 L
.65309 .25158 L
.65775 .2506 L
.6627 .2496 L
.66394 .24941 L
.66528 .24923 L
.66605 .24915 L
.66675 .24909 L
.66813 .249 L
.6693 .24897 L
.67058 .24898 L
.67191 .24905 L
.67316 .24916 L
.67449 .24933 L
.67591 .24956 L
.67845 .25011 L
.6842 .25174 L
.68958 .25336 L
.69222 .25403 L
.69463 .25453 L
.69572 .25472 L
.69692 .25489 L
.69807 .25502 L
.6991 .25512 L
.70031 .2552 L
.7016 .25526 L
.70279 .25528 L
.70392 .25529 L
.70516 .25527 L
Mistroke
.70648 .25525 L
.70883 .25518 L
.71014 .25515 L
.71136 .25514 L
.7127 .25514 L
.71345 .25515 L
.71414 .25518 L
.71538 .25524 L
.71655 .25534 L
.71782 .25548 L
.7192 .25569 L
.72057 .25596 L
.722 .25631 L
.72457 .2571 L
.72918 .25901 L
.73421 .2616 L
.75602 .2702 L
.76154 .27104 L
.76445 .27152 L
.76752 .27217 L
.77021 .27291 L
.77317 .27394 L
.77837 .27634 L
.78897 .28241 L
.7936 .28474 L
.79605 .28573 L
.79865 .28656 L
.79994 .28688 L
.80138 .28716 L
.80268 .28736 L
.8039 .2875 L
.80515 .28759 L
.8063 .28764 L
.80756 .28766 L
.80888 .28764 L
.81019 .2876 L
.81093 .28756 L
.8116 .28753 L
.81412 .28738 L
.81554 .2873 L
.81628 .28727 L
.81707 .28723 L
.81776 .28721 L
.81852 .28719 L
.81986 .28718 L
.82118 .2872 L
.82244 .28725 L
.82357 .28732 L
.8248 .28742 L
.82613 .28757 L
Mistroke
.82755 .28776 L
.8301 .2882 L
.83476 .28914 L
.83731 .28965 L
.83969 .29005 L
.84098 .29023 L
.84237 .29037 L
.84316 .29043 L
.84391 .29046 L
.84459 .29048 L
.84532 .29048 L
.84662 .29044 L
.84801 .29032 L
.84919 .29017 L
.85049 .28994 L
.85201 .28959 L
.85339 .2892 L
.85652 .28811 L
.86218 .28558 L
.88336 .27885 L
.88872 .27852 L
.89 .27846 L
.89136 .27837 L
.89378 .27816 L
.89512 .27801 L
.89658 .27779 L
.89962 .2772 L
.90236 .27648 L
.90492 .27565 L
.91029 .27358 L
.9154 .27154 L
.91762 .27075 L
.91998 .27004 L
.92134 .2697 L
.92257 .26945 L
.92381 .26925 L
.92497 .26911 L
.92609 .26902 L
.92732 .26897 L
.92861 .26899 L
.92981 .26905 L
.93093 .26916 L
.93195 .26929 L
.93425 .26969 L
.93672 .27027 L
.9394 .27101 L
.94427 .27247 L
.95413 .27493 L
.95936 .27584 L
.96225 .27635 L
Mistroke
.96499 .27691 L
.96718 .27746 L
.96957 .2782 L
.97376 .27996 L
.97802 .28244 L
.98198 .28538 L
1 .30265 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0<?ooool8o`0007Sooooo002eooooo`03o`000?oooooooooo023o
oooo4?l00008ooooo`;o0000M_ooool00;Gooooo00?o0000ooooooooool07_ooool2o`0001[ooooo
2ol0001[ooooo`00]Oooool00ol0003oooooooooo`0Iooooo`Go00009_ooool3o`0006Wooooo002e
ooooo`;o00005Oooool5o`0002kooooo0_l0001Wooooo`00]Oooool00ol0003oooooooooo`0Boooo
o`;o0000=Oooool3o`0006Cooooo000Eooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o
0000oc8b<_o^k^h06_ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01cooooo1?l000002?l@
413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^7_ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo00_ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^6_ooool5
o`0000;ooooo0_l000001?lb<S;o0000oc8b<_o^k^hKooooo`05oiRHV?l@413o0000oc8b<_o<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00[ooooo0ol0000@ooooo`;o000000Wo410@oooooooo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^h03_ooool001Kooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL06oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Nooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01OnHV9So8B4Qonk^k_ooooooA4A400?o
oooo00?oMgMgo`000?l000000ol0000Jooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Oooooo0ol00003ooooo`Ko00002oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool000_ooooo1_l00002ooooo`Go00000oooool0
1Ol@413ooooooooooooooooo410@01;ooooo1_l00006ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`04o`0000gooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400Cooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41007_ooool00ol0003oooooooooo`0>ooooo`;o00004Oooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41006oooool00onHV9So8B4Qonk^kP04
ooooo`06oa0@4?ooooooooooooooool@413ooooo0ol0000Kooooo`05o`000?ooooooooooooooool@
41000oooool00ol@413oooooooooo`03ooooo`;o00003?ooool2o`0000Kooooo1Ol00003ooooo`05
oa0@4?ooooooooooooooool@41003_ooool001?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0
003ooooooooooooooooo000001gooooo00?oZJVYoa0@4?ooool00_ooool00ol0003oooooooooo`05
o`0000;ooooo0ol0000Eooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00
000Nooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Nooooo`;o0000
3_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`00000Looooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000004oooo
o`;o00006?ooool00onYZJWo410@ooooo`02ooooo`03o`000?oooooooooo00Oo00004?ooool5o`00
0005oooooom4A4CogMgMooooool000001?ooool01Ol0003ooooooooooooooooo000000kooooo000C
ooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000Looooo`03oa0@
4?l0003o^[Zj00?ooooo0ol000000ooooooo0000ooooo`07ooooo`;o00005?ooool00omgMgOoIVIV
ooooo`02ooooo`05o`000?ooooooooooooooool000006?ooool5o`000003ooooool0003ooooo00?o
oooo00Go0000ooooooooooooooooo`00000Nooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool0
0omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`0Dooooo`03oa0@4?l0003o^[Zj00?ooooo0ol000000ooooooo0000ooooo`0Iooooo`05o`000?oM
gMgoEEEEooooool000001?ooool01Ol0003ooooooooooooooooo000000kooooo000Dooooo`03ogMg
Moo<c<co000000Cooooo00Go410@oooooooooooooooooa0@400Mooooo`03okZj^_lQ8B7ooooo00?o
00000oooool00ol@413oooooooooo`08ooooo`03o`000?oooooooooo01;ooooo00Go0000oooooooo
oooooooooa0@4003ooooo`03oa0@4?oooooooooo01Gooooo0_l00004ooooo`;o00001?ooool01Ol@
413ooooooooooooooooo410@01kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Nooooo`05o`000?oo
ooooooooooooool@41000oooool00ol@413oooooooooo`05ooooo`;o00005Oooool00onj^[[o8B4Q
o`000002o`000005oa0@4?ooooooooooooooool@41006oooool01?l0003oMgMgolc<c?l00004oooo
o`05oa0@4?ooooooooooooooool@41003_ooool001Cooooo00?ok^k^odA4A?l000001?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg01[ooooo00Co410@oiRHV?oooooo^[Zj0_l00002ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02_ooool00ol0003oooooooooo`0>ooooo`05o`000?nj^[[ooooooiRHV?l@
41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01Gooooo0_l00007ooooo`;o00000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05o`000?nj
^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Wooooo2ol00007ooooo`03
oa0@4?l0003o000000;o00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01cooooo0ol00004oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool001Gooooo00?oMgMgo`000?ooool00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^01[ooooo00KoZJVYoa0@4?l0003o410@ojVYZOl00002ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool00ol0003oooooooooo`0=ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Cooooo00?o0000ooooooooool01Oooool0
1OmEEEGoIVIVo`000?oooooo000000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Nooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool04_ooool00omEEEGoIVIVo`000004ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h06_ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Dooooo`So000000Co410@o`000?l@413oZJVY0oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^01gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00ko
oooo000mooooo`;o00005?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool08_ooool2o`0000[ooooo00?o0000ooooooooool0SOooool00ol0003ooooo
ooooo`0Dooooo`00??ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0Soooool00ol0003oooooooooo`0Cooooo`00>oooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`0B
ooooo`005_ooool2o`0002;ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo09;ooooo00?o0000ooooooooool04Oooool001Sooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0Yoooool001Koooooool00010o`0001?ooooo000Fooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool2o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`;o0000
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool00000
1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
4Oooool001Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo017ooooo000Looooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0:Wooooo000Mooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
0:Wooooo000Nooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool07Oooool2o`0000Co
oooo00?o0000ooooooooool0Z_ooool001oooooo0_l0000Aooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`2Zooooo`008Oooool00ol0003ooooooooo
o`0<ooooo`;o0000:?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0:[ooooo000R
ooooo`03o`000?oooooooooo00Wooooo0_l0000[ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0Zoooool002?ooooo00?o0000ooooooooool01_ooool2o`0002kooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`2[ooooo`009?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo01_ooooo0_l00002ooooo`03o`000?oooooooooo0:cooooo000Uooooo`Ko0000
<_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
6oooool01Ol0003ooooooooooooooooo00000:kooooo001Mooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool0
0000[_ooool005kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo01[ooooo00Co0000oooooooooooo0000[oooool005kooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01Wooooo00Co0000oooooooooooo
0000[oooool005oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo01Wooooo0_l000000ooooooo0000ooooo`2^ooooo`00Goooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool06Oooool00ol0003oooooo`00
002`ooooo`00H?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool06?ooool00ol0003oooooo`00002`ooooo`00H?ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool06?ooool00ol0003oooooo`00002`oooo
o`00H?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool06?ooool00ol0003oooooo`00002`ooooo`00HOooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool05oooool2o`000;7ooooo001Qooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Gooooo`;o0000/Ooo
ool0067ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Kooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01?ooool00ol0003o8B4Qob4Q8@04ooooo`Go00001?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Gooooo0_l0002aooooo`00H_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo01cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?lQ8B7ooooo00?ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0/?ooool006;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Looooo`05oa0@
4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00Wo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2`ooooo`00Hoooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo01gooooo00Go0000ooooooooooooooooo`000005ooooo`03
o`000?oooooooooo00Gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o
0000/?ooool006?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Mooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`05ooooo`03ogMgMomVIVKooooo00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`;o0000/_ooool006Cooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Nooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool2o`00
0;;ooooo001Tooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool00_ooool01Ol0003o^[ZjoooooonHV9So
410@00Cooooo00?o0000ooooooooool01_ooool2o`000;;ooooo001Uooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool07oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000
ooooooooool00_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00004ooooo`03o`000?oo
oooo00000;;ooooo001Vooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`0Booooo`04o`000?oooooo0000o`000;7ooooo001Wooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
00000;;ooooo001Xooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`0Aooooo`04o`000?ooooooooooo`000;;ooooo001Xooooo`Go0000<Oooool00ol0
003oooooooooo`0Aooooo`04o`000?ooooooooooo`000;;ooooo002Oooooo`03o`000?oooooooooo
013ooooo00Co0000oooooooooooo0000/_ooool009oooooo00?o0000ooooooooool03oooool01?l0
003oooooooooooooool2o`000;7ooooo002Oooooo`03o`000?oooooooooo00oooooo00Go0000oooo
ooooooooooooo`00002booooo`00X?ooool00ol0003oooooooooo`0>ooooo`05o`000?oooooooooo
ooooool00000/_ooool00:3ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo0;3ooooo002Pooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool00_ooool2o`000;7ooooo002Qooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`2`ooooo`00XOooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0/?ooool00:7ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002Rooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2`ooooo`00X_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Cooooo0_l0002aooooo`00X_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0/?ooool00:?ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool00ol0003o8B4Qob4Q8@05ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Cooooo00?o0000ob4Q8OlQ8B401oooool00ol0003oMgMgoc8b<P05ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003ooooo
ooooo`05ooooo`04o`000?ooooooooooo`0000Gooooo0ol0002`ooooo`00V_ooool01Ol0003ooooo
oooooooooooo000000Gooooo00?o0000ooooooooool01Oooool01?l0003oooooogMgMolb<S85oooo
o`03o`000?oooooooooo0;3ooooo002Jooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2`
ooooo`00V_ooool01Ol@413ooooooooooooooooo410@00Kooooo0_l00003ooooo`;o00002Oooool0
0ol0003oooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo1_l00009
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00T_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo
00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?oooooooooo
ooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0/?ooool009;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooo
oooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`000;3ooooo002Booooo`05o`000?oooooooooo
ooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?o
ZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002B
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002[oooo
o`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0/?ooool00:gooooo00?o0000ooooooooool01Oooool3o`000;3ooooo002]
ooooo`03o`000?oooooooooo0;Sooooo002]ooooo`03o`000?oooooooooo0;Sooooo002]ooooo`03
o`000?oooooooooo0;Sooooo002[ooooo`03oeEEEOmVIVKo00000;[ooooo003oooooofWooooo002_
ooooo`03o`000?nj^[[ooooo0;Kooooo002_ooooo`;o<S8b]oooool0083ooooo0_l000001_l@413o
ooooooooool@413o0000oa0@41Oooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06_ooool00ol0003ok^k^
ooooo`03ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
07Sooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`0000Wo
oooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0
0oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000_ooooo00?o
EEEEojVYZOooool00oooool01OlQ8B7oV9RHoooooonHV9So8B4Q00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`1hooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Oooooo
00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01;ooooo00?o0000oooooooo
ool07?ooool00onYZJWoEEEEooooo`03ooooo`05o`000?ooooooooooooooool000000oooool01Ol@
413ooooooooooooooooo410@07Sooooo0021ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Ooo
ool6o`0000_ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000001;ooooo
00?o0000ooooooooool02oooool6o`0000cooooo00?o8B4Qooooooooool00_ooool01Olb<S;oV9RH
oooooonHV9So<S8b00?ooooo00Go0000ooooooooooooooooo`00001hooooo`00POooool01_l0003o
gMgMoc8b<_mEEEGogMgMo`0001_ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooo
oooo000001;ooooo00?o0000ooooooooool07Oooool00omEEEGoc<c<ooooo`02ooooo`05olc<c?l0
003o0000o`000?o<c<`00oooool01Ol0003ooooooooooooooooo000007Sooooo0021ooooo`06o`00
0?n7QhOoZJVYokZj^_mEEEGo00007?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@
ooooooooool03_ooool00ol@413o0000o`000003o`0001cooooo00?oZJVYogMgMoooool00_ooool0
1Ol@413o^[Zjoooooonj^[[o410@00?ooooo00Go410@oooooooooooooooooa0@401hooooo`00POoo
ool01_l0003o<S8boooooooooooo<S8bo`0001Sooooo00Go0000okZj^_ooooooV9RHoa0@4003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool00ol0003oooooooooo`0Jooooo`05oa0@4?oooooo
oooooooooolb<S800oooool01Ol0003o^[Zjoooooonj^[[o000000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`1hooooo`00P?ooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0
003oooooooooo`0Jooooo`Go00000oooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP1hooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(790) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .31628 m
.01975 .33293 L
.02492 .33746 L
.02981 .34122 L
.03251 .34291 L
.03393 .34365 L
.03544 .34432 L
.03671 .34478 L
.03738 .34498 L
.03811 .34517 L
.03938 .34542 L
.04057 .34557 L
.04129 .34561 L
.04197 .34562 L
.04271 .34559 L
.04349 .34553 L
.04424 .34544 L
.04495 .34532 L
.04628 .34501 L
.04758 .34461 L
.04878 .34417 L
.0515 .3429 L
.05645 .33988 L
.06168 .33608 L
.08481 .31697 L
.10566 .29293 L
.11477 .28353 L
.11992 .27959 L
.12468 .27685 L
.12978 .27467 L
.1352 .27288 L
.14516 .2701 L
.14776 .26948 L
.15055 .26891 L
.15183 .2687 L
.15319 .26853 L
.15434 .26842 L
.1556 .26835 L
.15638 .26833 L
.15711 .26833 L
.15849 .2684 L
.15926 .26847 L
.15997 .26856 L
.16075 .26869 L
.16157 .26885 L
.16294 .2692 L
.16422 .26961 L
.16712 .27087 L
.16984 .27245 L
.17235 .27426 L
Mistroke
.17805 .27949 L
.18843 .29206 L
.20789 .3234 L
.22767 .36819 L
.23806 .39127 L
.24329 .40034 L
.2463 .40447 L
.24903 .40748 L
.25196 .40989 L
.25358 .41084 L
.25432 .41119 L
.25511 .41151 L
.25578 .41173 L
.25652 .41192 L
.25782 .41212 L
.25855 .41217 L
.25934 .41216 L
.26009 .41209 L
.26077 .41199 L
.26207 .41167 L
.26328 .41124 L
.26461 .41062 L
.26603 .40978 L
.26893 .40754 L
.27156 .40492 L
.27679 .39812 L
.28246 .38863 L
.29275 .36708 L
.31325 .32154 L
.31886 .31166 L
.32489 .30282 L
.33577 .29069 L
.34109 .2861 L
.34689 .28202 L
.34954 .2805 L
.35236 .27917 L
.35477 .2783 L
.35614 .27791 L
.35743 .27763 L
.35858 .27745 L
.35984 .27732 L
.36116 .27728 L
.36239 .27732 L
.36354 .27742 L
.36459 .27758 L
.36579 .27784 L
.36694 .27815 L
.3695 .2791 L
.37186 .28026 L
.37719 .28385 L
Mistroke
.38209 .28819 L
.38736 .29384 L
.39687 .30676 L
.40819 .32816 L
.41853 .35514 L
.42901 .38845 L
.44017 .42506 L
.4456 .44097 L
.4507 .45377 L
.45529 .46292 L
.45787 .46695 L
.46025 .46986 L
.46144 .47102 L
.46257 .47194 L
.46388 .47275 L
.46506 .47328 L
.46618 .47357 L
.46722 .47367 L
.46835 .47359 L
.46955 .47328 L
.47076 .47275 L
.47206 .47191 L
.47329 .47088 L
.47441 .46973 L
.47702 .46631 L
.47976 .46162 L
.48487 .45022 L
.48961 .43701 L
.50037 .4018 L
.52006 .34195 L
.53116 .31692 L
.54139 .29797 L
.55229 .2819 L
.55778 .27584 L
.56382 .27084 L
.56909 .2677 L
.57476 .26513 L
.58498 .26101 L
.59563 .25616 L
.60125 .25378 L
.60434 .25273 L
.60585 .25229 L
.60723 .25195 L
.60855 .25168 L
.61 .25143 L
.61145 .25125 L
.61225 .25117 L
.61299 .25112 L
.6143 .25106 L
.6155 .25104 L
Mistroke
.61688 .25105 L
.61819 .2511 L
.61942 .25117 L
.62072 .25126 L
.62306 .25146 L
.62577 .2517 L
.62711 .25181 L
.62835 .25189 L
.62954 .25196 L
.63081 .25201 L
.63154 .25202 L
.63222 .25203 L
.6335 .25202 L
.63468 .25198 L
.63577 .25193 L
.63696 .25184 L
.63822 .25172 L
.64084 .2514 L
.64329 .25102 L
.64885 .25009 L
.65134 .24974 L
.65256 .24961 L
.6537 .24951 L
.65472 .24944 L
.65581 .2494 L
.65691 .24939 L
.65812 .24942 L
.6594 .24949 L
.66058 .24961 L
.66188 .24977 L
.66324 .25 L
.66554 .2505 L
.66806 .25118 L
.67356 .25301 L
.67953 .25502 L
.68227 .25581 L
.68517 .25649 L
.68764 .25694 L
.69036 .2573 L
.6958 .25773 L
.69847 .25789 L
.70095 .25808 L
.7032 .25832 L
.70445 .2585 L
.70559 .25869 L
.70819 .25925 L
.71064 .25995 L
.71554 .26187 L
.72084 .26457 L
.72618 .26755 L
Mistroke
.73181 .27047 L
.73673 .27251 L
.73953 .2734 L
.74213 .27408 L
.75162 .27588 L
.75689 .27705 L
.75987 .27794 L
.76262 .27894 L
.77302 .28386 L
.7779 .28619 L
.78248 .28792 L
.78478 .28855 L
.78607 .28882 L
.78725 .28901 L
.78848 .28916 L
.78982 .28927 L
.79049 .2893 L
.79122 .28931 L
.79252 .2893 L
.79381 .28924 L
.79455 .28918 L
.79524 .28912 L
.79813 .28877 L
.80329 .28795 L
.80618 .28753 L
.8076 .28736 L
.80892 .28723 L
.81043 .28711 L
.81123 .28707 L
.81208 .28703 L
.81345 .28701 L
.81423 .28701 L
.81496 .28702 L
.8162 .28706 L
.81755 .28712 L
.81896 .28721 L
.82027 .28731 L
.82278 .28752 L
.82514 .28769 L
.82648 .28776 L
.82723 .28779 L
.82792 .28781 L
.82915 .28782 L
.83045 .28778 L
.83112 .28775 L
.83185 .2877 L
.83315 .28757 L
.83395 .28746 L
.83471 .28734 L
.83613 .28705 L
Mistroke
.83885 .28633 L
.84141 .28542 L
.8462 .28325 L
.85179 .28034 L
.85693 .2778 L
.86144 .27603 L
.86372 .27536 L
.86621 .27479 L
.86871 .27439 L
.87012 .27423 L
.8714 .27411 L
.87389 .27395 L
.87624 .27384 L
.87856 .27372 L
.88106 .27354 L
.88249 .2734 L
.88381 .27324 L
.88638 .27281 L
.88889 .27225 L
.89163 .27148 L
.89715 .26954 L
.902 .26775 L
.90466 .26688 L
.90717 .26621 L
.90831 .26597 L
.90952 .26577 L
.91084 .2656 L
.91206 .2655 L
.91315 .26546 L
.91417 .26547 L
.91529 .26553 L
.9165 .26564 L
.91722 .26573 L
.9179 .26584 L
.91917 .26608 L
.92202 .2668 L
.92714 .26853 L
.93873 .27265 L
.94901 .27511 L
.95172 .27577 L
.95462 .27662 L
.9573 .27761 L
.95984 .27878 L
.96507 .28202 L
.96983 .28597 L
.98077 .29753 L
1 .31628 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0:oooool7o`0007kooooo002eooooo`03o`000?oooooooooo01ko
oooo3Ol00007ooooo`Co0000N_ooool00;Gooooo00?o0000ooooooooool06_ooool4o`0001Sooooo
0ol0001gooooo`00]Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01gooooo1ol0
001`ooooo`00]Oooool2o`0001Sooooo0_l0000Wooooo`?o0000KOooool00;Gooooo00?o0000oooo
ooooool05?ooool3o`0002cooooo0_l0000jooooo`Co0000;Oooool001Gooooo0_l000002Ol@413o
ooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0Jooooo`05oiRHV?l@413o0000oc8b<_o<c<`0
0oooool01?o^k^ko<S8bo`000?lb<S85o`0001Oooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h07?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hNooooo`03o`00
0?oooooooooo01;ooooo0_l0000;ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kQ[ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool01OnHV9So410@o`00
0?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`Co00000oooool4o`00013o
oooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0>ooooo`005_ooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01Ol@413o^[Zjoooo
oomgMgOo<S8b00?ooooo00GoMgMgo`000?l0003o0000ogMgM`03ooooo`?o00005Oooool01OnHV9So
8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
6_ooool01OnHV9So8B4Qo`000?ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Koooo
o`05oa0@4?nj^[[oooooogMgMolb<S800oooool01?mgMgOoV9RHoooooonHV9P3o`0000_ooooo0_l0
000?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`002ooo
ool6o`0000;ooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41004_ooool6o`0000Kooooo
1Ol00003ooooo`03oa0@4?oooooooooo00Cooooo00?o0000ooooooooool02_ooool6o`0000?ooooo
00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01?ooooo1_l00005ooooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Nooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41006oooool00onHV9So8B4Qo`000004o`000005oa0@4?ooooooooooooooool@41007ooo
ool8o`000003oa0@4?oooooooooo00gooooo1?l00008ooooo`Go00000oooool01Ol@413ooooooooo
oooooooo410@00kooooo000Cooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000oooooooooooo
ooooo`00000Mooooo`03o`000?l@413ooooo00;ooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo01Cooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo
000001Sooooo1Ol000000ooooooo0000ooooo`03ooooo`05o`000?ooooooooooooooool000007_oo
ool2o`00013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000007?ooool00onHV9So8B4Qonk^kP03ooooo`Go00007?ooool3o`000005oa0@
4?ooooooooooooooool000000oooool00ol0003oooooooooo`0Aooooo`;o00001_ooool01?m4A4Co
gMgMooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool001?ooooo00CogMgMoeEE
EOoooooo00001?ooool01Ol0003ooooooooooooooooo000001_ooooo0ol000001Onj^[[ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Dooooo`03ogMg
MomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00000Fooooo`;o00001?ooool3o`0000Co
oooo00Go0000ooooooooooooooooo`00000Nooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool0
0omgMgOoIVIVooooo`02ooooo`03o`000?oooooooooo00?o00006Oooool2o`000004ooooool@413o
0000okZj^P?ooooo00Go0000ooooooooooooooooo`00000Eooooo`;o00001?ooool01?oMgMgoEEEE
ooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool001Cooooo00?oMgMgolc<c?l0
00001?ooool01Ol@413ooooooooooooooooo410@01[ooooo00Go0000oooooooooooo^[Zjob4Q8@03
ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`0Dooooo`05o`000?oo
ooooooooooooool@41000oooool00ol@413oooooooooo`0Booooo`;o00002?ooool2o`0000?ooooo
00Go410@oooooooooooooooooa0@400Nooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41007_ooool01Ol0
003ooooooooooooooooo410@00?ooooo00Co410@ooooool0003o00005_ooool00ol0003ooooooooo
o`02ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@400Gooooo`03o`00
0?oooooooooo00;ooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00ko
oooo000Dooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Iooooo`06
o`000?l@413oV9RHoooooonj^[[o00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Wooooo00?o
0000ooooooooool03oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Cooooo`03o`000?oooooooooo00Sooooo0_l00003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL07_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool3o`0000Gooooo3_l00002ooooo`05oa0@
4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01Sooooo0_l00002oooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`005Oooool00omg
MgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06?ooool01ol0003oooooojVYZOl@
413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00[ooooo00?o0000oooooooo
ool03_ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0B
ooooo`03o`000?oooooooooo00Oooooo00CoEEEEofIVI_l0003ooooo0_l000001_ooooook^k^oc8b
<_l0003o<S8bonk^kQkooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03
oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Jooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo1Ol0000@ooooo`05ojVYZOl@
413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00Go0000oooooooo
ooooMgMgo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool003Oooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool08Oooool2o`0000gooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`0Hoooo
o`00=oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02[ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0R?ooool00ol0003oooooooooo`0Gooooo`00=_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`0Fooooo`00=Ooo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Rooo
ool00ol0003oooooooooo`0Eooooo`00=?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0SOooool00ol0003oooooooooo`0Dooooo`005_ooooooo`00
043o00004oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00006oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooo`000007oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0001?ooooo000Foooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04Oooool001Oooooo00?o0000oooooooo
ool05_ooool2o`0002Gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2Vooooo`00
6?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`2Vooooo`006Oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo01_ooooo0_l00007ooooo`03o`000?oooooooooo0:Oooooo000Jooooo`03o`000?oooooo
oooo00oooooo0_l0000Zooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Yoooool0
01_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0Z?ooool001cooooo0_l0000<ooooo`03o`000?oooooooooo02co
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Xooooo`007_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2Yooooo`007oooool00ol0003oooooooooo`05ooooo`;o0000<Oooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool06Oooool2o`0000Gooooo00?o
0000ooooooooool0ZOooool0023ooooo0_l00003ooooo`;o0000<oooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo0:[ooooo000Qooooo`Co0000=_ooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo0:[ooooo001Kooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0Z_ooool005cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2[ooooo`00G?oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool05ooo
ool2o`0000?ooooo00?o0000ooooooooool0Zoooool005gooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`2[ooooo`00GOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool05oooool01Ol0003ooooooooooooooooo00000:kooooo001Moooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Foooo
o`05o`000?ooooooooooooooool00000[_ooool005kooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo01Kooooo00Go0000ooooooooooooooooo`00002^
ooooo`00G_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool05_ooool2o`000003ooooool0003ooooo0:kooooo001Oooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Eooooo`04o`000?ooooooooooo`00
0:oooooo001Oooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool07Oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo00?o8B4Qo`000?ooool00oooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`04o`000?ooooooooooo`000:oooooo001Pooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool07_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o
8B4Qo`000?ooool00oooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooo`00002`ooooo`00H?ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo01kooooo00Go410@oooooooooooooooooa0@4007ooooo`03o`000?oooooooooo00;ooooo
00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo00000;3ooooo
001Pooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool07oooool01Ol0003ooooooooo
oooooooo000000Oooooo00?o0000ooooooooool00oooool00onHV9So8B4Qonk^kP07ooooo`03ogMg
Molb<S;ooooo00Cooooo0ol0002`ooooo`00HOooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo01oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00Cooooo
00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo0_l0002aooooo`00
HOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo023ooooo00Go410@oooooooooooo
oooooa0@4008ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`07ooooo`;o0000/Oooool006;ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Pooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool02?l0003oooooooooool0003o^[Zj
oooooonHV9So410@1?ooool00ol0003oooooooooo`07ooooo`;o0000/Oooool006?ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Qooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?oo
ool02?l0003ooooooooooonHV9So410@o`000?lQ8B7oc<c<1?ooool4o`0000Kooooo00?o0000oooo
ooooool0/?ooool006?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo01;ooooo0_l0002aooooo`00I?ooool2o`0000Kooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0;3ooooo001Vooooo`04o`000?oo
ooooooooooooo`;o0000=?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0;3ooooo
001Vooooo`Go0000=_ooool00ol0003oooooooooo`0@ooooo`;o0000/_ooool00:7ooooo00?o0000
ooooooooool04?ooool2o`000;;ooooo002Qooooo`03o`000?oooooooooo013ooooo0ol0002aoooo
o`00X_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo00000;;ooooo002Rooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooool00000/_ooool00:;ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooo`00002booooo`00Xoooool00ol0003oooooooooo`0=ooooo`04o`000?oooooo
0000o`000;7ooooo002Sooooo`03o`000?oooooooooo00cooooo00Co0000oooooooooooo0000/_oo
ool00:?ooooo00?o0000ooooooooool03?ooool01?l0003oooooooooool0002booooo`00Y?ooool0
0ol0003oooooooooo`0;ooooo`04o`000?ooooooooooo`000;;ooooo002Tooooo`03o`000?oooooo
oooo00[ooooo00Go0000ooooooooooooooooo`00002booooo`00Y?ooool00ol0003oooooooooo`0:
ooooo`04o`000?ooooooooooooooo`;o0000/Oooool00:Gooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo0;3ooooo002Uooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo00?o8B4Qo`000?ooool01?ooool01Om4A4Co0000o`000?lb<S;o
000000Gooooo00?o0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q00?o0000ooooooooool01Oooool00omgMgOo0000ooooo`04ooooo`03o`000?oooooo
oooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`04
ooooo`;o00001Oooool3o`000;3ooooo002Jooooo`05o`000?ooooooooooooooool000002?ooool0
0ol0003oooooooooo`04ooooo`03o`000?lb<S;ooooo00Cooooo00?o0000ooooooooool0/?ooool0
09[ooooo00Go0000ooooooooooooooooo`000009ooooo`08o`000?ooooooooooo`000?lQ8B7o0000
oc8b<_o<c<`5ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@
41002_ooool4o`0000Sooooo00?o0000ooooooooool0/?ooool009[ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`;o00002Oooool00ol0003oooooooooo`2`ooooo`00V_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo
00?o0000ooooooooool0/?ooool009;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`2`ooooo`00T_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03
oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2`ooooo`00
T_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?ooooooooooooooool0
00003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00
T_ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00Go410@oooooooo
oooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`2`ooooo`00T_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooo
oooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool0
09;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo00?o0000
ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00Zoooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0
/?ooool00:gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo
00Gooooo0ol0002`ooooo`00[Oooool00ol0003oooooooooo`2hooooo`00[Oooool00ol0003ooooo
ooooo`2hooooo`00[Oooool00ol0003oooooooooo`2hooooo`00Zoooool00omEEEGoIVIVo`00002j
ooooo`00oooooomYooooo`00[oooool00ol0003o^[Zjooooo`2fooooo`00[oooool2oc8b<[Oooooo
0020ooooo`;o000000Ko410@oooooooooooo410@o`000?l@410Gooooo`Go00000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co
^[Zj01[ooooo00?o0000onk^k_ooool00oooool01?l@413o0000odA4A?o<c<`4ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h0N?ooool0087ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`07ooooo`Ko00002Oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`03olc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009oooo
o`Ko00002oooool00omEEEGoZJVYooooo`05ooooo`03oiRHV?l@413ogMgM00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`1hooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01Oooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01;ooooo00?o0000
ooooooooool07?ooool00onYZJWoEEEEooooo`06ooooo`03ohN7QomEEEGooooo00;ooooo00Go410@
oooooooooooooooooa0@401hooooo`00POooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo
1_l0000;ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Booooo`03
o`000?oooooooooo00_ooooo1_l0000<ooooo`03ob4Q8Ooooooooooo00;ooooo00Goc<c<ob4Q8Ol0
003oEEEEo`000003ooooo`05o`000?ooooooooooooooool00000N?ooool0087ooooo00Ko0000omgM
gOlb<S;oEEEEomgMgOl0000Kooooo`03ogMgMomVIVKooooo00;ooooo00Go0000oooooooooooooooo
o`00000Booooo`03o`000?oooooooooo01gooooo00?oEEEEolc<c?ooool00_ooool01OlQ8B7oQhN7
oooooonHV9So000000?ooooo00Go0000ooooooooooooooooo`00001hooooo`00POooool01_l0003o
QhN7ojVYZOnj^[[oEEEEo`0001cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oo
oooooooo00kooooo00?o410@o`000?l000000ol0000Looooo`03ojVYZOmgMgOooooo00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`05oa0@4?ooooooooooooooool@4100N?ooool0087ooooo
00Ko0000oc8b<_oooooooooooc8b<_l0000Hooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool06_ooool01Ol@413ooooooooo
oooooooo<S8b00?ooooo00Go8B4QoiRHV?ooooooMgMgoeEEE@03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL0N?ooool0083ooooo00?o410@o`000?n7QhL00_ooool00on7QhOo0000oa0@400Gooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo00?o0000
ooooooooool06_ooool5o`0000?ooooo00Goc<c<oa0@4?l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h0N?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.309017 0.309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -9 -9 ]
[.125 .29652 9 0 ]
[.25 .29652 -9 -9 ]
[.25 .29652 9 0 ]
[.375 .29652 -9 -9 ]
[.375 .29652 9 0 ]
[.625 .29652 -6 -9 ]
[.625 .29652 6 0 ]
[.75 .29652 -6 -9 ]
[.75 .29652 6 0 ]
[.875 .29652 -6 -9 ]
[.875 .29652 6 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-40)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-30)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-20)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-10)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(10)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(20)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(30)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(40)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(800) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .33033 m
.00942 .3384 L
.01483 .34257 L
.01719 .3441 L
.01975 .34546 L
.02114 .34605 L
.02243 .3465 L
.02365 .34683 L
.02496 .34707 L
.02632 .34719 L
.02761 .3472 L
.02834 .34715 L
.02901 .34707 L
.02979 .34694 L
.03053 .34678 L
.03173 .34644 L
.03302 .34597 L
.03533 .34488 L
.04057 .34139 L
.06377 .3204 L
.08481 .29757 L
.09464 .28532 L
.10001 .2796 L
.10502 .27537 L
.11045 .27208 L
.11332 .27081 L
.1164 .26971 L
.12688 .26695 L
.13206 .2656 L
.13756 .2642 L
.14043 .2636 L
.14206 .26333 L
.14281 .26323 L
.1436 .26315 L
.14427 .2631 L
.145 .26306 L
.14628 .26303 L
.14701 .26305 L
.14778 .2631 L
.14852 .26317 L
.14918 .26325 L
.1505 .26349 L
.15189 .26383 L
.15308 .26421 L
.1544 .26472 L
.15732 .26619 L
.16005 .26799 L
.16499 .27218 L
.17031 .27773 L
.18095 .29072 L
Mistroke
.19254 .30709 L
.20349 .32691 L
.21365 .34993 L
.22477 .37623 L
.23023 .38742 L
.23524 .39588 L
.23981 .40181 L
.24211 .40412 L
.24464 .40613 L
.24717 .40761 L
.2486 .4082 L
.24989 .4086 L
.2511 .40885 L
.25241 .40899 L
.25365 .409 L
.25479 .40889 L
.25603 .40867 L
.25734 .4083 L
.25845 .40788 L
.25967 .40731 L
.26239 .40562 L
.26492 .40353 L
.26952 .39847 L
.27443 .39131 L
.28578 .3691 L
.29607 .34602 L
.30588 .32617 L
.31626 .30982 L
.32763 .29624 L
.33811 .28611 L
.34321 .28214 L
.34804 .27922 L
.35071 .27803 L
.35212 .27753 L
.35362 .2771 L
.35487 .27682 L
.35626 .27659 L
.35752 .27646 L
.3587 .2764 L
.35983 .2764 L
.36105 .27645 L
.36234 .27657 L
.36353 .27674 L
.36567 .27716 L
.36796 .27777 L
.37319 .27964 L
.37795 .28183 L
.38303 .28464 L
.38841 .2883 L
.39301 .29222 L
Mistroke
.39807 .29771 L
.4035 .30526 L
.40934 .31553 L
.41989 .33951 L
.4406 .40052 L
.45154 .43484 L
.45755 .45166 L
.46049 .4588 L
.4632 .4645 L
.4658 .46904 L
.46865 .47286 L
.47014 .47433 L
.47152 .47535 L
.47229 .47578 L
.47298 .47607 L
.47379 .4763 L
.47455 .47641 L
.47579 .47637 L
.47711 .47602 L
.47824 .47548 L
.47948 .47461 L
.48081 .47339 L
.48224 .47172 L
.48484 .46787 L
.48994 .4574 L
.49531 .44313 L
.50491 .41294 L
.5259 .34655 L
.53504 .32201 L
.54495 .30038 L
.55047 .29099 L
.55555 .284 L
.56556 .27387 L
.57625 .2658 L
.58216 .2618 L
.58756 .25848 L
.59231 .25602 L
.59481 .25495 L
.59748 .25402 L
.59897 .2536 L
.60031 .25328 L
.60168 .25301 L
.60294 .25281 L
.60423 .25265 L
.60562 .25252 L
.60684 .25245 L
.60813 .25241 L
.60933 .25239 L
.61042 .2524 L
.61169 .25242 L
Mistroke
.61288 .25246 L
.61503 .25254 L
.61731 .25263 L
.6185 .25267 L
.61981 .2527 L
.62101 .25272 L
.62213 .25271 L
.62344 .25269 L
.62465 .25266 L
.62531 .25263 L
.62604 .25259 L
.62736 .25251 L
.63247 .25202 L
.63515 .25171 L
.63799 .2514 L
.63919 .2513 L
.64048 .2512 L
.64122 .25116 L
.64189 .25113 L
.64321 .25109 L
.64439 .2511 L
.64567 .25113 L
.64689 .25121 L
.64801 .25131 L
.64938 .25148 L
.65067 .25169 L
.65361 .25233 L
.65647 .25314 L
.65955 .25419 L
.67003 .25805 L
.71321 .27127 L
.71857 .27421 L
.72362 .27653 L
.72642 .27754 L
.72945 .27842 L
.73221 .27905 L
.73475 .2795 L
.73936 .28019 L
.7443 .28099 L
.74713 .28158 L
.74973 .28224 L
.7548 .28388 L
.7641 .28747 L
.76664 .28834 L
.76935 .28911 L
.77067 .28941 L
.77191 .28965 L
.77303 .28981 L
.77423 .28994 L
.77551 .29003 L
Mistroke
.77623 .29005 L
.77691 .29005 L
.77827 .29001 L
.77903 .28996 L
.77973 .28989 L
.78097 .28974 L
.78233 .28953 L
.78478 .28903 L
.7948 .28638 L
.83767 .27707 L
.84266 .27437 L
.84792 .27196 L
.85068 .27098 L
.85213 .27056 L
.85369 .27018 L
.85512 .26989 L
.85642 .26968 L
.85896 .26938 L
.86402 .26911 L
.86535 .26907 L
.86678 .26903 L
.86811 .26897 L
.86936 .26891 L
.8705 .26883 L
.87175 .26872 L
.87392 .26847 L
.87653 .26804 L
.87894 .26752 L
.88874 .26458 L
.89139 .2638 L
.89389 .26318 L
.89524 .26291 L
.89649 .26271 L
.89787 .26255 L
.89859 .26249 L
.89936 .26245 L
.90056 .26243 L
.90166 .26247 L
.90292 .26256 L
.90412 .26271 L
.90522 .26289 L
.90624 .2631 L
.90855 .26371 L
.91344 .26547 L
.91862 .26773 L
.92926 .27203 L
.9345 .27373 L
.93937 .27532 L
.94376 .27709 L
.94845 .27964 L
Mistroke
.95364 .28353 L
.95835 .28803 L
.97842 .31122 L
1 .33033 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Zoooool4o`000003oa0@4?oooooooooo0;Kooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00001Oooool00ol0003oooooooooo`2h
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`?o0000/?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?oo
ool00:_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0/?ooool008[ooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0002`oooo
o`00T_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Boooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2`ooooo`00T_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/?ooool009[ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002`ooooo`00V_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0;3ooooo002Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0/?ooool009;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`2`ooooo`00R_ooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2`ooooo`00T_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`?o0000/?ooool009;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/?ooool009;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool07?oooolDo`00083o
oooo002eooooo`03o`000?oooooooooo01[ooooo0ol0000Cooooo`?o0000OOooool00;Gooooo00?o
0000ooooooooool06?ooool2o`0001Wooooo0ol0001jooooo`00A?ooool00ol0003oooooooooo`1^
ooooo`;o00005oooool2o`0001kooooo0ol00012ooooo`Co0000<Oooool003oooooo2_l0001/oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool08Oooool4o`0003_ooooo0ol00003oooo
o`Co0000;_ooool001Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^
kP0Jooooo`03oiRHV?l@413o000000;o00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo
00?o0000ooooooooool05_ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Looooo`Co
000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQkooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`08ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^
kQ;ooooo0ol00005ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00?oV9RH
oa0@4?l000002?l000000olb<S;ok^k^ooooo`07ooooo`?o00004_ooool2o`000009oa0@4?oooooo
ooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Fooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0Hooooo`Go000000?oMgMgoc8b<_ooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00?o0000ooooooooool05Oooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05Oooool2o`0000?o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06Oooool5
o`000003ogMgMolb<S;ooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`;o00004Ooo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool000_ooooo1_l0
0002ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@01;ooooo1_l00006ooooo`05o`00
0?ooooooooooooooool@41000oooool00ol@413oooooooooo`02ooooo`03o`000?oooooooooo00co
oooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400Coooo
o`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41007_ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@01Oooooo0_l00002ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go
410@oooooooooooooooooa0@400Gooooo`;o00001_ooool01Ol0003ooooooooooooooooo410@00?o
oooo00?o410@ooooooooool02oooool3o`0000_ooooo1Ol00003ooooo`05oa0@4?oooooooooooooo
ool@41003_ooool001?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo
000001Oooooo00?o0000ooooooooool00oooool00onYZJWo410@ooooo`02ooooo`05o`000?oooooo
ooooooooool000001Oooool00ol0003oooooooooo`0Eooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go
0000ooooooooooooooooo`00000Fooooo`Wo00001?ooool01Ol0003ooooooooooooooooo000001ko
oooo0_l0000Booooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000001Wooooo0ol000000onHV9So8B4Qonk^kP03ooooo`05o`000?oooooooooo
ooooool000005?ooool3o`0000Oooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooo
oooo0000013ooooo0_l00009ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`004oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?oooooooooooooo
ool000005_ooool00ol0003oooooooooo`03ooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000oooo
ooooooooooooo`000005ooooo`03o`000?oooooooooo01Kooooo00?oMgMgofIVI_ooool00_ooool0
1Ol0003ooooooooooooooooo000001Gooooo00?o0000ooooooooool01_ooool3o`0000;ooooo00Go
0000ooooooooooooooooo`00000Nooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007?ooool7o`0000?o
oooo00?o0000ooooooooool03Oooool5o`0000Wooooo00?o410@o`000?nj^[X00oooool01Ol0003o
oooooooooooooooo000001;ooooo00?o0000ooooooooool01_ooool01?oMgMgoEEEEooooool00004
ooooo`05o`000?ooooooooooooooool000003_ooool001Cooooo00?oMgMgolc<c?l000001?ooool0
1Ol@413ooooooooooooooooo410@01Gooooo00?o0000ooooooooool01Oooool00onj^[[o8B4Qoooo
o`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`0Fooooo`05o`00
0?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Aooooo`;o00002Oooool01_l0003o
ooooooooool0003ooooooa0@40?ooooo00?o410@ooooooooool07?ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@01kooooo00?o0000ooooooooool01Ol000000ol@413oooooooooo`09ooooo`Co00003ooo
ool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41004oooool2o`0000Oooooo
00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00kooooo000Dooooo`03onk^
k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Dooooo`03o`000?oooooooooo00?o
oooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01oooool0
0ol0003oooooooooo`0Aooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg01;ooooo00?o0000ooooooooool02Oooool02_l0003oooooooooool0003oooooogMg
MonHV9SooooooiRHV?mgMgLNooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01Ol0003o^[Zj
oooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHo`000008ooooo`?o00004?ooool01Ol@
413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Eooooo`03o`000?oo
oooooooo00Cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo
000Eooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Cooooo`03o`00
0?oooooooooo00Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02?ooool00ol0003oooooooooo`0@ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^017ooooo00?o0000ooooooooool02?ooool00omEEEGoIVIVo`00
0003ooooo`;o000000Co<S8bo`000?lb<S;ok^k^7_ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00oooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?l0000C
ooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Gooooo
00?o0000ooooooooool01Oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03_ooool003;ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool07oooool2o`0000kooooo00?o0000ooooooooool0
P?ooool00ol0003oooooooooo`0Mooooo`00<Oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`0Looooo`00<Oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Q?ooool0
0ol0003oooooooooo`0Kooooo`00<?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`0Kooooo`00;oooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Q_ooool00ol0003o
ooooooooo`0Jooooo`005_ooooooo`00043o00004oooool001Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooo000000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`?o00001Oooool00ol0003o
ooooooooo`0Aooooo`005_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool04Oooool002_ooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool05Oooool002Wooooo0_l0000Z
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0S_ooool00ol0003oooooooooo`0D
ooooo`00:?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0Iooooo`;o00002Oooool00ol0003oooooooooo`2?oooo
o`03o`000?oooooooooo01?ooooo000Wooooo`03o`000?oooooooooo02cooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`2Aooooo`03o`000?oooooooooo01;ooooo000Fooooo`;o0000
3_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
T_ooool00ol0003oooooooooo`0Aooooo`006?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2Vooooo`006Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`2Wooooo`006Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
01Oooooo0_l00007ooooo`03o`000?oooooooooo0:Oooooo000Jooooo`;o00001_ooool00ol0003o
ooooooooo`0dooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Yoooool001cooooo
1_l0000gooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Z?ooool005[ooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`2Xooooo`00F_ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0:Wooooo001Kooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`0Eooooo`;o00001Oooool00ol0003oooooooooo`2Yoooo
o`00Foooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0:Wooooo001Kooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0Z_ooool005cooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`2Zooooo`00G?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo02[ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo0:[ooooo001Looooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`0Cooooo`;o00000oooool00ol0003oooooooooo`2[ooooo`00GOooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo0:_ooooo001Mooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool07oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B401?oooooo
0000ooooooooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0Zoooool005gooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Pooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@;ooooo00Oo0000
oooooonHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool01Ol0003ooooo
oooooooooooo00000:kooooo001Nooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
8Oooool01Ol@413ooooooooooooooooo410@00Wooooo00Ko0000ooooooooooooV9RHob4Q8Oo^k^h9
ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00002^ooooo`00Goooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`00
0009ooooo`07o`000?oooooooooooooooonHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Co
oooo0ol000000ooooooo0000ooooo`2]ooooo`00Goooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo02;ooooo00Go0000ooooooooooooooooo`00000:ooooo`06o`000?oooooooooooooo
oomgMgOoIVIV1?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00Co0000oooooooooooo0000
[oooool0063ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Rooooo`05oa0@4?oo
ooooooooooooool@41002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01oooool01?l0003oooooooooool0002_ooooo`00HOooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo02?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0:ooooo`;o
000000Co^[ZjoooooonHV9So410@1?ooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooo
o`000:oooooo001Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go0000oa0@4?l0003o8B4Qolc<c004ooooo`Co00001_oo
ool00ol0003oooooo`00002`ooooo`00H_ooool2o`0000Kooooo00?o0000ooooooooool0=Oooool0
0ol0003oooooooooo`0@ooooo`?o0000/?ooool006Cooooo00Co0000oooooooooooooooo0_l0000h
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooool00000/?ooool006Cooooo1Ol0000joooo
o`03o`000?oooooooooo00oooooo0_l0002aooooo`00Xoooool00ol0003oooooooooo`0?ooooo`;o
0000/Oooool00:?ooooo00?o0000ooooooooool03oooool2o`000;7ooooo002Tooooo`03o`000?oo
oooooooo00kooooo0_l0002aooooo`00Y?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo0;3ooooo002Tooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0/?ooool00:Co
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2`ooooo`00YOooool00ol0003ooooo
ooooo`0<ooooo`?o0000/Oooool00:Gooooo00?o0000ooooooooool03?ooool2o`000;;ooooo002U
ooooo`03o`000?oooooooooo00cooooo0_l0002booooo`00Y_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooo00000;;ooooo002Vooooo`03o`000?oooooooooo00[ooooo00?o0000ooooool0
0000/_ooool00:Kooooo00?o0000ooooooooool02_ooool01?l0003oooooo`000?l0002aooooo`00
Yoooool00ol0003oooooooooo`09ooooo`03o`000?oooooo00000;;ooooo002Wooooo`03o`000?oo
oooooooo00Sooooo00Co0000oooooooooooo0000/_ooool009[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q00?oooooo`000?ooool00_ooool01Om4A4Co0000o`000?lb<S;ogMgM00;o
oooo00Co0000oooooooooooo0000/_ooool009[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q0_ooool00ol0003oooooooooo`03ooooo`05ogMgMolb<S;oooooooooool000000_ooool0
0ol0003oooooooooo`2`ooooo`00V_ooool01Ol@413ooooooooooooooooo410@00Wooooo00?o0000
ooooooooool01?ooool00ol0003oooooo`000003ooooo`?o0000/?ooool009[ooooo00Go0000oooo
ooooooooooooo`00000:ooooo`03o`000?oooooooooo00;ooooo00CoMgMgoc8b<_oooooo00000ooo
ool00ol0003oooooooooo`2`ooooo`00V_ooool01Ol0003ooooooooooooooooo000000_ooooo0_l0
00001OlQ8B7o0000oc8b<_o<c<co000000Cooooo00?o0000ooooooooool0/?ooool009[ooooo00Go
410@oooooooooooooooooa0@400<ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003o
ooooooooo`2`ooooo`00V_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo1?l00006ooooo`03
o`000?oooooooooo0;3ooooo002Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Ko
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00T_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05oa0@4?ooooooooooooooool@
41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0/?ooool009;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Ko
oooo00?oMgMgoc8b<_ooool01?ooool3o`000;3ooooo002Booooo`05o`000?ooooooooooooooool0
00003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0
003oooooooooo`2`ooooo`00T_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo002Booooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00T_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00_ooooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002[ooooo`Co0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0/?ooool00:gooooo00?o0000ooooooooool01Oooool3o`000;3ooooo002]ooooo`03
o`000?oooooooooo0;Sooooo002]ooooo`03o`000?oooooooooo0;Sooooo002]ooooo`03o`000?oo
oooooooo0;Sooooo002[ooooo`03oeEEEOmVIVKo00000;[ooooo003oooooofWooooo002_ooooo`03
o`000?nj^[[ooooo0;Kooooo002_ooooo`;o<S8b]oooool0083ooooo0_l000001_l@413ooooooooo
ool@413o0000oa0@41Oooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7
QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h0N?ooool0087ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko0000
2Oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`03olc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002Oooool0
1OlQ8B7oV9RHoooooonHV9So8B4Q00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0N?ooool0087ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Gooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400Booooo`03
o`000?oooooooooo01[ooooo00Go0000ooooooooooooooooo`000003ooooo`05oa0@4?oooooooooo
ooooool@41000oooool01Ol@413ooooooooooooooooo410@07Sooooo0021ooooo`06o`000?oooooo
A4A4odA4A?oooooo00002Oooool6o`0000_ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooo
oooooooooooo000001;ooooo00?o0000ooooooooool02oooool6o`0000Wooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000007Sooooo0021ooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo00006oooool00omgMgOoIVIV
ooooo`02ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0Jooooo`05
olc<c?l0003o0000o`000?o<c<`00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`00001hooooo`00POooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001cooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00kooooo00?o410@o`000?l0
00000ol0000Iooooo`05oa0@4?nj^[[ooooookZj^_l@41000oooool01Ol@413ooooooooooooooooo
410@00?ooooo00Go410@oooooooooooooooooa0@401hooooo`00POooool01_l0003o<S8boooooooo
oooo<S8bo`0001Sooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL04_ooool00ol0003oooooooooo`0Jooooo`05o`000?nj^[[ooooookZj^_l000000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1hooooo`00P?oo
ool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Oooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Jooooo`05
ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP1hooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -1.05718, 0.31409, \
0.0127052}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "\tInitially the wave steepens, just as when dispersion is neglected. \
However, instead of breaking, the wave dissociates into several solitons that \
proceed to interact with one another in a complex manner.   The spectrum of \
the solution is peaked at low wavenumbers, as can be seen in the  plot of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(\(c\_n\)(t)\)\(|\)\)\)]],
  " shown in Cell ",
  ButtonBox["7.51",
    ButtonData:>"Cell 7.51",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(spectrum = \ Abs[vars /. sol[\([1]\)]];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(Table[
        ParametricPlot3D[{k[n], t, spectrum[\([n + 1]\)]}, {t, 0, 800}, 
          DisplayFunction \[Rule] Identity], {n, 0, M}];\)\), "\n", 
    \(\(Show[%, DisplayFunction \[Rule] $DisplayFunction, 
        BoxRatios \[Rule] {1, 1, 1}, 
        AxesLabel \[Rule] {"\<k\>", "\<t\>", "\<|\!\(c\_n\)(t)|  \>"}, 
        PlotLabel -> "\<wave spectrum\n \>"];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.51"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[.5 1.098 -41.125 0 ]
[.5 1.098 41.125 24.5 ]
[.09072 .22988 -5.91576 -9 ]
[.09072 .22988 .08424 0 ]
[.25533 .16034 -16.7461 -9 ]
[.25533 .16034 1.25388 0 ]
[.43173 .08588 -5.24832 -9 ]
[.43173 .08588 .75168 0 ]
[.62122 .00596 -14.7438 -9 ]
[.62122 .00596 3.25621 0 ]
[.30907 .06148 -8.98592 -12 ]
[.30907 .06148 1.01408 0 ]
[.00955 .82643 -3.46362 0 ]
[.00955 .82643 2.53638 9 ]
[.12079 .90442 -10.0666 0 ]
[.12079 .90442 7.93341 9 ]
[.22056 .97437 -9.78807 0 ]
[.22056 .97437 8.21193 9 ]
[.31055 1.03745 -9.54626 0 ]
[.31055 1.03745 8.45374 9 ]
[.39213 1.09464 -9.33435 0 ]
[.39213 1.09464 8.66565 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12 ]
[.07325 .26228 -6 -2.6177 ]
[.07325 .26228 0 6.3823 ]
[.05358 .38541 -24 -2.72708 ]
[.05358 .38541 0 6.27292 ]
[.03208 .51999 -24 -2.84769 ]
[.03208 .51999 0 6.15231 ]
[.00848 .66771 -24 -2.98134 ]
[.00848 .66771 0 6.01866 ]
[-0.03373 .52941 -57.25 -3.77786 ]
[-0.03373 .52941 0 8.22214 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.098 -102.125 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(wave) show
93.125 13.000 moveto
(spectrum) show
69.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.10087 .24033 m
.10595 .24556 L
s
[(0)] .09072 .22988 .97192 1 Mshowa
.26484 .17139 m
.2696 .17691 L
s
[(0.5)] .25533 .16034 .86068 1 Mshowa
.44047 .09754 m
.44484 .10337 L
s
[(1)] .43173 .08588 .74944 1 Mshowa
.62906 .01825 m
.63298 .02439 L
s
[(1.5)] .62122 .00596 .6382 1 Mshowa
.125 Mabswid
.13279 .22691 m
.1358 .23008 L
s
.16514 .21331 m
.16811 .21652 L
s
.19792 .19953 m
.20086 .20277 L
s
.23115 .18555 m
.23405 .18883 L
s
.299 .15703 m
.30181 .16038 L
s
.33363 .14247 m
.33639 .14585 L
s
.36874 .1277 m
.37146 .13113 L
s
.40435 .11273 m
.40703 .11619 L
s
.47711 .08214 m
.47968 .08567 L
s
.51427 .06651 m
.51679 .07008 L
s
.55198 .05066 m
.55444 .05427 L
s
.59024 .03457 m
.59265 .03822 L
s
.66846 .00168 m
.67075 .0054 L
s
gsave
.30907 .06148 -69.9859 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.01178 .81203 m
.01289 .80482 L
s
[(0)] .00955 .82643 .15454 -1 Mshowa
.1225 .88995 m
.12336 .88271 L
s
[(200)] .12079 .90442 .11851 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(400)] .22056 .97437 .08756 -1 Mshowa
.31143 1.0229 m
.31187 1.01563 L
s
[(600)] .31055 1.03745 .0607 -1 Mshowa
.39267 1.08007 m
.39294 1.07279 L
s
[(800)] .39213 1.09464 .03715 -1 Mshowa
.125 Mabswid
.04063 .83233 m
.04126 .82801 L
s
.06868 .85207 m
.06927 .84774 L
s
.09596 .87127 m
.09651 .86693 L
s
.14833 .90812 m
.14881 .90378 L
s
.17348 .92582 m
.17392 .92147 L
s
.19797 .94306 m
.19838 .9387 L
s
.24508 .97621 m
.24543 .97185 L
s
.26775 .99217 m
.26808 .9878 L
s
.28986 1.00772 m
.29016 1.00336 L
s
.33248 1.03771 m
.33271 1.03335 L
s
.35302 1.05217 m
.35323 1.0478 L
s
.37308 1.06628 m
.37326 1.06192 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.0867 .25665 m
.09342 .25384 L
s
[(0)] .07325 .26228 1 -0.41829 Mshowa
.06714 .38007 m
.07392 .37739 L
s
[(0.02)] .05358 .38541 1 -0.39398 Mshowa
.04576 .51497 m
.0526 .51246 L
s
[(0.04)] .03208 .51999 1 -0.36718 Mshowa
.02229 .66305 m
.0292 .66072 L
s
[(0.06)] .00848 .66771 1 -0.33748 Mshowa
.125 Mabswid
.08197 .28651 m
.08601 .28484 L
s
.07713 .31702 m
.08118 .31537 L
s
.07219 .34819 m
.07625 .34657 L
s
.06198 .41265 m
.06605 .41107 L
s
.05669 .44598 m
.06078 .44443 L
s
.05129 .48008 m
.05539 .47855 L
s
.0401 .55068 m
.04422 .5492 L
s
.03431 .58725 m
.03843 .58579 L
s
.02837 .62469 m
.03251 .62326 L
s
.01607 .70236 m
.02022 .70099 L
s
.00968 .74265 m
.01384 .74131 L
s
.00313 .78396 m
.00731 .78266 L
s
gsave
-0.03373 .52941 -118.25 -7.77786 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(\\310) show
69.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
75.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
80.250 13.000 moveto
(H) show
86.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
92.250 13.000 moveto
(L) show
98.250 13.000 moveto
(\\310) show
116.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.4186 .578 m
.42216 .58164 L
s
.41502 .57434 m
.4186 .578 L
s
.41143 .57067 m
.41502 .57434 L
s
.40782 .56698 m
.41143 .57067 L
s
.40419 .56327 m
.40782 .56698 L
s
.40055 .55955 m
.40419 .56327 L
s
.39689 .55581 m
.40055 .55955 L
s
.39322 .55206 m
.39689 .55581 L
s
.38953 .54829 m
.39322 .55206 L
s
.38583 .5445 m
.38953 .54829 L
s
.3821 .54069 m
.38583 .5445 L
s
.37836 .53687 m
.3821 .54069 L
s
.37461 .53303 m
.37836 .53687 L
s
.37084 .52917 m
.37461 .53303 L
s
.36705 .5253 m
.37084 .52917 L
s
.36324 .52141 m
.36705 .5253 L
s
.35941 .5175 m
.36324 .52141 L
s
.35557 .51357 m
.35941 .5175 L
s
.35171 .50962 m
.35557 .51357 L
s
.34784 .50566 m
.35171 .50962 L
s
.34394 .50168 m
.34784 .50566 L
s
.42317 .54966 m
.4247 .6207 L
s
.41891 .56099 m
.42317 .54966 L
s
.34003 .49768 m
.34394 .50168 L
s
.5805 .57328 m
.58395 .58182 L
s
.57752 .59388 m
.5805 .57328 L
s
.3361 .49366 m
.34003 .49768 L
s
.60442 .55335 m
.60857 .58906 L
s
.60101 .54598 m
.60442 .55335 L
s
.59803 .55766 m
.60101 .54598 L
s
.33215 .48963 m
.3361 .49366 L
s
.41257 .62852 m
.41891 .56099 L
s
.46678 .51773 m
.46995 .54716 L
s
.46282 .52881 m
.46678 .51773 L
s
.5573 .6634 m
.56024 .61677 L
s
.67721 .51067 m
.6801 .50932 L
s
.32819 .48557 m
.33215 .48963 L
s
.65358 .54322 m
.65627 .53455 L
s
.62192 .52912 m
.62567 .54748 L
s
.61863 .52592 m
.62192 .52912 L
s
.3242 .4815 m
.32819 .48557 L
s
.70147 .49206 m
.70475 .49884 L
s
.67452 .51679 m
.67721 .51067 L
s
.49404 .52473 m
.49749 .54331 L
s
.4903 .53163 m
.49404 .52473 L
s
.59485 .56199 m
.59803 .55766 L
s
.46995 .54716 m
.47328 .56947 L
s
.3202 .4774 m
.3242 .4815 L
s
.69868 .49392 m
.70147 .49206 L
s
.62567 .54748 m
.6296 .57033 L
s
.61535 .52321 m
.61863 .52592 L
s
.57456 .61954 m
.57752 .59388 L
s
.45816 .56854 m
.46282 .52881 L
s
.51105 .48506 m
.51454 .50753 L
s
.50733 .50398 m
.51105 .48506 L
s
.45279 .59615 m
.45617 .61424 L
s
.44889 .59999 m
.45279 .59615 L
s
.49749 .54331 m
.50098 .56057 L
s
.31617 .47329 m
.3202 .4774 L
s
.65048 .54296 m
.65358 .54322 L
s
.61191 .51572 m
.61535 .52321 L
s
.50454 .56795 m
.50807 .58057 L
s
.50098 .56057 m
.50454 .56795 L
s
.47328 .56947 m
.47672 .58646 L
s
.50807 .58057 m
.51147 .62238 L
s
.63959 .50301 m
.64321 .51633 L
s
.63616 .49494 m
.63959 .50301 L
s
.72646 .48352 m
.72982 .49188 L
s
.45617 .61424 m
.4593 .64446 L
s
.6296 .57033 m
.63315 .58187 L
s
.60843 .50679 m
.61191 .51572 L
s
.69583 .49518 m
.69868 .49392 L
s
.64321 .51633 m
.64694 .53208 L
s
.67149 .51656 m
.67452 .51679 L
s
.72331 .47838 m
.72646 .48352 L
s
.63275 .48767 m
.63616 .49494 L
s
.31213 .46916 m
.31617 .47329 L
s
.59149 .55972 m
.59485 .56199 L
s
.60493 .49764 m
.60843 .50679 L
s
.52163 .52913 m
.52517 .55261 L
s
.51808 .5193 m
.52163 .52913 L
s
.51454 .50753 m
.51808 .5193 L
s
.47672 .58646 m
.48018 .60364 L
s
.60146 .48933 m
.60493 .49764 L
s
.48407 .73474 m
.48795 .72004 L
s
.48655 .53653 m
.4903 .53163 L
s
.49799 .65378 m
.50115 .71444 L
s
.49434 .65294 m
.49799 .65378 L
s
.4247 .6207 m
.42657 .68547 L
s
.64694 .53208 m
.65048 .54296 L
s
.62929 .47916 m
.63275 .48767 L
s
.44473 .61225 m
.44889 .59999 L
s
.59801 .48237 m
.60146 .48933 L
s
.72046 .47799 m
.72331 .47838 L
s
.62585 .47152 m
.62929 .47916 L
s
.75175 .47575 m
.75476 .47959 L
s
.30807 .46501 m
.31213 .46916 L
s
.48018 .60364 m
.48358 .62571 L
s
.58806 .55459 m
.59149 .55972 L
s
.59457 .47636 m
.59801 .48237 L
s
.62245 .46532 m
.62585 .47152 L
s
.6681 .50897 m
.67149 .51656 L
s
.69272 .49212 m
.69583 .49518 L
s
.6609 .4849 m
.66451 .49703 L
s
.65742 .47563 m
.6609 .4849 L
s
.52517 .55261 m
.52875 .59032 L
s
.49058 .65994 m
.49434 .65294 L
s
.66451 .49703 m
.6681 .50897 L
s
.48305 .52037 m
.48655 .53653 L
s
.4792 .52808 m
.48305 .52037 L
s
.304 .46084 m
.30807 .46501 L
s
.65406 .46901 m
.65742 .47563 L
s
.74856 .46954 m
.75175 .47575 L
s
.59111 .46988 m
.59457 .47636 L
s
.61912 .4615 m
.62245 .46532 L
s
.58453 .5452 m
.58806 .55459 L
s
.4593 .64446 m
.46255 .67143 L
s
.71744 .47549 m
.72046 .47799 L
s
.58097 .53413 m
.58453 .5452 L
s
.57741 .52361 m
.58097 .53413 L
s
.77703 .46483 m
.77988 .46748 L
s
.57387 .51351 m
.57741 .52361 L
s
.53882 .50159 m
.54241 .51816 L
s
.53527 .49572 m
.53882 .50159 L
s
.57032 .50383 m
.57387 .51351 L
s
.65072 .46343 m
.65406 .46901 L
s
.48358 .62571 m
.487 .64869 L
s
.74548 .46501 m
.74856 .46954 L
s
.58765 .46379 m
.59111 .46988 L
s
.68938 .48524 m
.69272 .49212 L
s
.56676 .49318 m
.57032 .50383 L
s
.50355 .52116 m
.50733 .50398 L
s
.5632 .48257 m
.56676 .49318 L
s
.5597 .47761 m
.5632 .48257 L
s
.2999 .45665 m
.304 .46084 L
s
.61578 .45787 m
.61912 .4615 L
s
.53172 .49613 m
.53527 .49572 L
s
.54241 .51816 m
.546 .53315 L
s
.5543 .71876 m
.5573 .6634 L
s
.68594 .47642 m
.68938 .48524 L
s
.57133 .63254 m
.57456 .61954 L
s
.64741 .45848 m
.65072 .46343 L
s
.58422 .46006 m
.58765 .46379 L
s
.71427 .47074 m
.71744 .47549 L
s
.77407 .46111 m
.77703 .46483 L
s
.74249 .46197 m
.74548 .46501 L
s
.68249 .4677 m
.68594 .47642 L
s
.51147 .62238 m
.51482 .69565 L
s
.546 .53315 m
.54963 .55126 L
s
.55617 .47078 m
.5597 .47761 L
s
.48029 .73824 m
.48407 .73474 L
s
.4407 .61786 m
.44473 .61225 L
s
.29578 .45244 m
.2999 .45665 L
s
.67911 .46029 m
.68249 .4677 L
s
.6124 .45355 m
.61578 .45787 L
s
.80251 .45404 m
.80541 .45789 L
s
.487 .64869 m
.49058 .65994 L
s
.64409 .45384 m
.64741 .45848 L
s
.46255 .67143 m
.46601 .68898 L
s
.55262 .46243 m
.55617 .47078 L
s
.71101 .4646 m
.71427 .47074 L
s
.58077 .45618 m
.58422 .46006 L
s
.6758 .45446 m
.67911 .46029 L
s
.52813 .48305 m
.53172 .49613 L
s
.52454 .48961 m
.52813 .48305 L
s
.47465 .57489 m
.4792 .52808 L
s
.77098 .45591 m
.77407 .46111 L
s
.54963 .55126 m
.55331 .57288 L
s
.7394 .45769 m
.74249 .46197 L
s
.54921 .47425 m
.55262 .46243 L
s
.29165 .44822 m
.29578 .45244 L
s
.4696 .69995 m
.47317 .71187 L
s
.46601 .68898 m
.4696 .69995 L
s
.7077 .45794 m
.71101 .4646 L
s
.60902 .44987 m
.6124 .45355 L
s
.47317 .71187 m
.47669 .72731 L
s
.64075 .44913 m
.64409 .45384 L
s
.79968 .45107 m
.80251 .45404 L
s
.67252 .44949 m
.6758 .45446 L
s
.52875 .59032 m
.5324 .63552 L
s
.45353 .60184 m
.45816 .56854 L
s
.57731 .45229 m
.58077 .45618 L
s
.7679 .451 m
.77098 .45591 L
s
.47669 .72731 m
.48029 .73824 L
s
.73625 .45262 m
.7394 .45769 L
s
.70439 .45153 m
.7077 .45794 L
s
.45886 .79607 m
.46292 .78431 L
s
.28749 .44397 m
.29165 .44822 L
s
.40617 .69223 m
.41257 .62852 L
s
.43692 .61315 m
.4407 .61786 L
s
.6374 .44434 m
.64075 .44913 L
s
.55331 .57288 m
.55699 .59353 L
s
.66923 .44463 m
.67252 .44949 L
s
.82833 .44448 m
.83128 .44936 L
s
.60561 .44562 m
.60902 .44987 L
s
.76485 .44653 m
.7679 .451 L
s
.79674 .44696 m
.79968 .45107 L
s
.70111 .44567 m
.70439 .45153 L
s
.57396 .457 m
.57731 .45229 L
s
.5679 .63394 m
.57133 .63254 L
s
.73305 .4472 m
.73625 .45262 L
s
.49977 .53052 m
.50355 .52116 L
s
.28331 .4397 m
.28749 .44397 L
s
.43318 .60646 m
.43692 .61315 L
s
.50115 .71444 m
.50409 .82619 L
s
.63405 .44013 m
.6374 .44434 L
s
.52087 .51932 m
.52454 .48961 L
s
.66592 .43973 m
.66923 .44463 L
s
.82552 .44102 m
.82833 .44448 L
s
.60221 .44219 m
.60561 .44562 L
s
.69785 .44038 m
.70111 .44567 L
s
.76177 .44182 m
.76485 .44653 L
s
.55699 .59353 m
.56068 .61175 L
s
.79369 .44191 m
.79674 .44696 L
s
.72985 .44178 m
.73305 .4472 L
s
.42899 .61397 m
.43318 .60646 L
s
.42657 .68547 m
.42893 .73873 L
s
.27912 .43541 m
.28331 .4397 L
s
.66263 .43537 m
.66592 .43973 L
s
.6307 .43634 m
.63405 .44013 L
s
.54575 .48704 m
.54921 .47425 L
s
.69461 .43552 m
.69785 .44038 L
s
.8545 .43587 m
.85737 .44048 L
s
.82267 .43732 m
.82552 .44102 L
s
.56433 .62611 m
.5679 .63394 L
s
.72665 .43658 m
.72985 .44178 L
s
.75865 .4369 m
.76177 .44182 L
s
.59888 .44268 m
.60221 .44219 L
s
.79063 .4368 m
.79369 .44191 L
s
.56068 .61175 m
.56433 .62611 L
s
.45485 .80281 m
.45886 .79607 L
s
.5706 .46263 m
.57396 .457 L
s
.2749 .4311 m
.27912 .43541 L
s
.65934 .43137 m
.66263 .43537 L
s
.69137 .43109 m
.69461 .43552 L
s
.85164 .43151 m
.8545 .43587 L
s
.62733 .43224 m
.6307 .43634 L
s
.72345 .43159 m
.72665 .43658 L
s
.78759 .43201 m
.79063 .4368 L
s
.75553 .43201 m
.75865 .4369 L
s
.81972 .43281 m
.82267 .43732 L
s
.49584 .55032 m
.49977 .53052 L
s
.27067 .42677 m
.2749 .4311 L
s
.68813 .42678 m
.69137 .43109 L
s
.5324 .63552 m
.53613 .68104 L
s
.59558 .44535 m
.59888 .44268 L
s
.65603 .42712 m
.65934 .43137 L
s
.8809 .42711 m
.88367 .43132 L
s
.72026 .42689 m
.72345 .43159 L
s
.84884 .42771 m
.85164 .43151 L
s
.75241 .42724 m
.75553 .43201 L
s
.4241 .6417 m
.42899 .61397 L
s
.62403 .43089 m
.62733 .43224 L
s
.78454 .4273 m
.78759 .43201 L
s
.81672 .42781 m
.81972 .43281 L
s
.26641 .42242 m
.27067 .42677 L
s
.68487 .42239 m
.68813 .42678 L
s
.71707 .42242 m
.72026 .42689 L
s
.6527 .42294 m
.65603 .42712 L
s
.74928 .42259 m
.75241 .42724 L
s
.45088 .80632 m
.45485 .80281 L
s
.87808 .42258 m
.8809 .42711 L
s
.78148 .42261 m
.78454 .4273 L
s
.84597 .42344 m
.84884 .42771 L
s
.81371 .42286 m
.81672 .42781 L
s
.56716 .4662 m
.5706 .46263 L
s
.54219 .49115 m
.54575 .48704 L
s
.44915 .62056 m
.45353 .60184 L
s
.62077 .43136 m
.62403 .43089 L
s
.4347 .44295 m
.43584 .53877 L
s
.42743 .54382 m
.4347 .44295 L
s
.26214 .41805 m
.26641 .42242 L
s
.51482 .69565 m
.51828 .78335 L
s
.55102 .75518 m
.5543 .71876 L
s
.6816 .41808 m
.68487 .42239 L
s
.59225 .44828 m
.59558 .44535 L
s
.71386 .41792 m
.71707 .42242 L
s
.90754 .41808 m
.91025 .42232 L
s
.74614 .41804 m
.74928 .42259 L
s
.77842 .41803 m
.78148 .42261 L
s
.87529 .41835 m
.87808 .42258 L
s
.64942 .42025 m
.6527 .42294 L
s
.81071 .41815 m
.81371 .42286 L
s
.84305 .41875 m
.84597 .42344 L
s
.47001 .61865 m
.47465 .57489 L
s
.51713 .53698 m
.52087 .51932 L
s
.25784 .41366 m
.26214 .41805 L
s
.44687 .80948 m
.45088 .80632 L
s
.71064 .41344 m
.71386 .41792 L
s
.67831 .41377 m
.6816 .41808 L
s
.743 .41354 m
.74614 .41804 L
s
.77535 .41353 m
.77842 .41803 L
s
.8077 .41354 m
.81071 .41815 L
s
.90479 .41374 m
.90754 .41808 L
s
.42893 .73873 m
.4318 .77736 L
s
.87248 .41409 m
.87529 .41835 L
s
.8401 .41393 m
.84305 .41875 L
s
.6175 .43249 m
.62077 .43136 L
s
.64618 .4192 m
.64942 .42025 L
s
.56373 .47255 m
.56716 .4662 L
s
.53859 .49352 m
.54219 .49115 L
s
.49164 .58716 m
.49584 .55032 L
s
.25352 .40924 m
.25784 .41366 L
s
.70742 .40917 m
.71064 .41344 L
s
.73984 .40902 m
.743 .41354 L
s
.77227 .40905 m
.77535 .41353 L
s
.8047 .409 m
.8077 .41354 L
s
.67506 .41042 m
.67831 .41377 L
s
.58892 .45261 m
.59225 .44828 L
s
.90203 .40927 m
.90479 .41374 L
s
.83715 .4092 m
.8401 .41393 L
s
.86962 .40956 m
.87248 .41409 L
s
.53613 .68104 m
.53992 .72086 L
s
.64294 .41848 m
.64618 .4192 L
s
.44285 .81219 m
.44687 .80948 L
s
.24919 .40481 m
.25352 .40924 L
s
.73668 .40459 m
.73984 .40902 L
s
.80168 .40452 m
.8047 .409 L
s
.76918 .40457 m
.77227 .40905 L
s
.70418 .40471 m
.70742 .40917 L
s
.8342 .4046 m
.83715 .4092 L
s
.61421 .43388 m
.6175 .43249 L
s
.89926 .40487 m
.90203 .40927 L
s
.86675 .4049 m
.86962 .40956 L
s
.67184 .40813 m
.67506 .41042 L
s
.41878 .67912 m
.4241 .6417 L
s
.53497 .50199 m
.53859 .49352 L
s
.44475 .63727 m
.44915 .62056 L
s
.56027 .48065 m
.56373 .47255 L
s
.24483 .40035 m
.24919 .40481 L
s
.4 .74515 m
.40617 .69223 L
s
.7335 .40016 m
.73668 .40459 L
s
.79866 .40005 m
.80168 .40452 L
s
.76608 .40007 m
.76918 .40457 L
s
.70096 .40091 m
.70418 .40471 L
s
.83125 .40007 m
.8342 .4046 L
s
.86385 .40023 m
.86675 .4049 L
s
.89646 .40037 m
.89926 .40487 L
s
.58556 .45723 m
.58892 .45261 L
s
.63966 .41746 m
.64294 .41848 L
s
.66862 .40604 m
.67184 .40813 L
s
.4318 .77736 m
.43516 .80073 L
s
.43889 .81093 m
.44285 .81219 L
s
.51339 .5359 m
.51713 .53698 L
s
.61087 .43437 m
.61421 .43388 L
s
.24045 .39588 m
.24483 .40035 L
s
.76296 .3956 m
.76608 .40007 L
s
.79562 .39557 m
.79866 .40005 L
s
.7303 .39568 m
.7335 .40016 L
s
.82829 .39556 m
.83125 .40007 L
s
.86096 .39562 m
.86385 .40023 L
s
.89365 .39577 m
.89646 .40037 L
s
.69776 .39778 m
.70096 .40091 L
s
.63633 .41578 m
.63966 .41746 L
s
.66536 .40374 m
.66862 .40604 L
s
.43516 .80073 m
.43889 .81093 L
s
.46966 .49931 m
.47277 .54413 L
s
.46552 .50981 m
.46966 .49931 L
s
.23604 .39138 m
.24045 .39588 L
s
.75983 .39111 m
.76296 .3956 L
s
.79257 .39106 m
.79562 .39557 L
s
.72712 .39155 m
.7303 .39568 L
s
.82531 .39105 m
.82829 .39556 L
s
.85806 .39106 m
.86096 .39562 L
s
.89082 .39116 m
.89365 .39577 L
s
.54745 .76479 m
.55102 .75518 L
s
.53992 .72086 m
.54372 .75069 L
s
.50966 .53039 m
.51339 .5359 L
s
.5313 .50905 m
.53497 .50199 L
s
.69456 .39482 m
.69776 .39778 L
s
.58212 .45936 m
.58556 .45723 L
s
.55676 .48805 m
.56027 .48065 L
s
.60741 .43199 m
.61087 .43437 L
s
.53806 .41242 m
.54188 .44676 L
s
.53443 .43011 m
.53806 .41242 L
s
.23162 .38685 m
.23604 .39138 L
s
.50589 .52862 m
.50966 .53039 L
s
.7895 .38655 m
.79257 .39106 L
s
.75668 .3866 m
.75983 .39111 L
s
.82232 .38652 m
.82531 .39105 L
s
.85515 .38652 m
.85806 .39106 L
s
.88798 .38655 m
.89082 .39116 L
s
.72395 .38789 m
.72712 .39155 L
s
.66209 .40165 m
.66536 .40374 L
s
.63295 .41305 m
.63633 .41578 L
s
.50532 .41607 m
.50882 .46286 L
s
.5014 .42943 m
.50532 .41607 L
s
.43975 .67325 m
.44475 .63727 L
s
.69134 .39193 m
.69456 .39482 L
s
.50409 .82619 m
.50716 .95377 L
s
.60383 .42546 m
.60741 .43199 L
s
.46541 .65289 m
.47001 .61865 L
s
.22718 .38231 m
.23162 .38685 L
s
.78642 .38201 m
.7895 .38655 L
s
.75353 .38227 m
.75668 .3866 L
s
.81932 .38197 m
.82232 .38652 L
s
.85222 .38196 m
.85515 .38652 L
s
.88513 .38196 m
.88798 .38655 L
s
.72077 .38436 m
.72395 .38789 L
s
.50212 .52292 m
.50589 .52862 L
s
.57095 .42404 m
.57479 .4432 L
s
.56729 .41686 m
.57095 .42404 L
s
.48734 .62157 m
.49164 .58716 L
s
.57854 .45566 m
.58212 .45936 L
s
.62952 .40975 m
.63295 .41305 L
s
.6588 .3995 m
.66209 .40165 L
s
.54372 .75069 m
.54745 .76479 L
s
.60021 .41775 m
.60383 .42546 L
s
.68813 .38947 m
.69134 .39193 L
s
.52758 .51737 m
.5313 .50905 L
s
.43201 .4048 m
.43347 .48947 L
s
.42652 .44537 m
.43201 .4048 L
s
.46045 .56084 m
.46552 .50981 L
s
.22271 .37774 m
.22718 .38231 L
s
.56386 .42789 m
.56729 .41686 L
s
.78332 .37744 m
.78642 .38201 L
s
.8163 .37741 m
.81932 .38197 L
s
.84929 .37739 m
.85222 .38196 L
s
.88227 .37738 m
.88513 .38196 L
s
.7504 .37824 m
.75353 .38227 L
s
.59671 .41556 m
.60021 .41775 L
s
.49826 .52603 m
.50212 .52292 L
s
.55318 .49297 m
.55676 .48805 L
s
.46857 .41895 m
.47149 .47454 L
s
.46442 .42732 m
.46857 .41895 L
s
.71759 .38104 m
.72077 .38436 L
s
.57479 .4432 m
.57854 .45566 L
s
.62611 .40744 m
.62952 .40975 L
s
.51828 .78335 m
.52192 .86346 L
s
.41346 .71273 m
.41878 .67912 L
s
.65547 .39695 m
.6588 .3995 L
s
.54188 .44676 m
.54573 .47591 L
s
.21822 .37316 m
.22271 .37774 L
s
.78022 .37298 m
.78332 .37744 L
s
.81327 .37282 m
.8163 .37741 L
s
.84633 .37279 m
.84929 .37739 L
s
.8794 .37278 m
.88227 .37738 L
s
.68488 .38677 m
.68813 .38947 L
s
.74726 .37434 m
.7504 .37824 L
s
.47277 .54413 m
.47601 .58657 L
s
.59325 .4159 m
.59671 .41556 L
s
.71441 .3779 m
.71759 .38104 L
s
.49726 .45771 m
.5014 .42943 L
s
.53074 .44847 m
.53443 .43011 L
s
.62265 .40446 m
.62611 .40744 L
s
.21371 .36855 m
.21822 .37316 L
s
.81022 .36821 m
.81327 .37282 L
s
.84337 .36818 m
.84633 .37279 L
s
.87651 .36816 m
.8794 .37278 L
s
.77712 .3687 m
.78022 .37298 L
s
.65207 .39325 m
.65547 .39695 L
s
.49422 .54264 m
.49826 .52603 L
s
.53338 .9131 m
.53698 .8543 L
s
.74411 .37058 m
.74726 .37434 L
s
.43584 .53877 m
.43671 .65226 L
s
.68157 .38312 m
.68488 .38677 L
s
.54951 .49059 m
.55318 .49297 L
s
.52382 .52681 m
.52758 .51737 L
s
.71118 .37438 m
.71441 .3779 L
s
.20918 .36391 m
.21371 .36855 L
s
.45952 .46687 m
.46442 .42732 L
s
.80717 .36365 m
.81022 .36821 L
s
.84039 .36355 m
.84337 .36818 L
s
.87362 .36353 m
.87651 .36816 L
s
.50882 .46286 m
.51246 .49864 L
s
.77401 .36452 m
.77712 .3687 L
s
.58964 .411 m
.59325 .4159 L
s
.56027 .43073 m
.56386 .42789 L
s
.61903 .39686 m
.62265 .40446 L
s
.39434 .78108 m
.4 .74515 L
s
.64852 .38632 m
.65207 .39325 L
s
.54573 .47591 m
.54951 .49059 L
s
.74095 .36686 m
.74411 .37058 L
s
.67813 .3775 m
.68157 .38312 L
s
.39107 .51395 m
.39002 .63701 L
s
.38682 .51276 m
.39107 .51395 L
s
.61526 .38475 m
.61903 .39686 L
s
.61151 .37332 m
.61526 .38475 L
s
.60813 .37511 m
.61151 .37332 L
s
.58207 .38519 m
.58589 .39974 L
s
.57835 .3753 m
.58207 .38519 L
s
.54511 .37363 m
.54893 .3929 L
s
.54143 .37643 m
.54511 .37363 L
s
.70787 .36984 m
.71118 .37438 L
s
.64481 .37574 m
.64852 .38632 L
s
.20463 .35926 m
.20918 .36391 L
s
.57485 .37922 m
.57835 .3753 L
s
.5119 .37569 m
.51561 .40145 L
s
.50794 .39612 m
.5119 .37569 L
s
.83739 .35889 m
.84039 .36355 L
s
.8707 .35887 m
.87362 .36353 L
s
.80411 .35919 m
.80717 .36365 L
s
.58589 .39974 m
.58964 .411 L
s
.64123 .36872 m
.64481 .37574 L
s
.7709 .36042 m
.77401 .36452 L
s
.32373 .41296 m
.32746 .42525 L
s
.31606 .45645 m
.32373 .41296 L
s
.67457 .36978 m
.67813 .3775 L
s
.32746 .42525 m
.3302 .45245 L
s
.43413 .72661 m
.43975 .67325 L
s
.73775 .36281 m
.74095 .36686 L
s
.63795 .3696 m
.64123 .36872 L
s
.54893 .3929 m
.55271 .40569 L
s
.6711 .36401 m
.67457 .36978 L
s
.46066 .68925 m
.46541 .65289 L
s
.70448 .36418 m
.70787 .36984 L
s
.55271 .40569 m
.55651 .41999 L
s
.20005 .35458 m
.20463 .35926 L
s
.37867 .59321 m
.38682 .51276 L
s
.83439 .35425 m
.83739 .35889 L
s
.86778 .35419 m
.8707 .35887 L
s
.80105 .35481 m
.80411 .35919 L
s
.429 1.00478 m
.43398 .97299 L
s
.55651 .41999 m
.56027 .43073 L
s
.76777 .35632 m
.7709 .36042 L
s
.52001 .52939 m
.52382 .52681 L
s
.48325 .63321 m
.48734 .62157 L
s
.47601 .58657 m
.47949 .61828 L
s
.73449 .3582 m
.73775 .36281 L
s
.60467 .37512 m
.60813 .37511 L
s
.37278 .68262 m
.37611 .70407 L
s
.36869 .67714 m
.37278 .68262 L
s
.48604 .41142 m
.48971 .43154 L
s
.48185 .42696 m
.48604 .41142 L
s
.6678 .36188 m
.6711 .36401 L
s
.70111 .35907 m
.70448 .36418 L
s
.53771 .38008 m
.54143 .37643 L
s
.49016 .55463 m
.49422 .54264 L
s
.52696 .44563 m
.53074 .44847 L
s
.19545 .34987 m
.20005 .35458 L
s
.51561 .40145 m
.51939 .41672 L
s
.42087 .61441 m
.42743 .54382 L
s
.86483 .34948 m
.86778 .35419 L
s
.83138 .34967 m
.83439 .35425 L
s
.79797 .35046 m
.80105 .35481 L
s
.57123 .37832 m
.57485 .37922 L
s
.47149 .47454 m
.47474 .51759 L
s
.76462 .35208 m
.76777 .35632 L
s
.51246 .49864 m
.51621 .51994 L
s
.3302 .45245 m
.3328 .48269 L
s
.36396 .68406 m
.36869 .67714 L
s
.51939 .41672 m
.52317 .42925 L
s
.40849 .73359 m
.41346 .71273 L
s
.63447 .36585 m
.63795 .3696 L
s
.52317 .42925 m
.52696 .44563 L
s
.73122 .35351 m
.73449 .3582 L
s
.69778 .355 m
.70111 .35907 L
s
.48971 .43154 m
.49334 .45764 L
s
.37611 .70407 m
.37898 .73604 L
s
.19082 .34515 m
.19545 .34987 L
s
.86188 .34478 m
.86483 .34948 L
s
.82836 .34513 m
.83138 .34967 L
s
.66434 .35693 m
.6678 .36188 L
s
.42089 .48601 m
.42652 .44537 L
s
.79489 .34615 m
.79797 .35046 L
s
.49334 .45764 m
.49726 .45771 L
s
.60101 .36816 m
.60467 .37512 L
s
.51621 .51994 m
.52001 .52939 L
s
.76143 .34763 m
.76462 .35208 L
s
.56363 .35353 m
.56745 .36722 L
s
.55996 .35303 m
.56363 .35353 L
s
.72793 .34895 m
.73122 .35351 L
s
.32334 .65071 m
.32711 .66298 L
s
.31908 .64594 m
.32334 .65071 L
s
.63079 .35712 m
.63447 .36585 L
s
.32711 .66298 m
.33025 .68552 L
s
.56745 .36722 m
.57123 .37832 L
s
.69436 .34945 m
.69778 .355 L
s
.53394 .37866 m
.53771 .38008 L
s
.59725 .35796 m
.60101 .36816 L
s
.18618 .3404 m
.19082 .34515 L
s
.47949 .61828 m
.48325 .63321 L
s
.66072 .34889 m
.66434 .35693 L
s
.85892 .3401 m
.86188 .34478 L
s
.62714 .34946 m
.63079 .35712 L
s
.82532 .34062 m
.82836 .34513 L
s
.59351 .34859 m
.59725 .35796 L
s
.79178 .34178 m
.79489 .34615 L
s
.45565 .59294 m
.46045 .56084 L
s
.75822 .34303 m
.76143 .34763 L
s
.31452 .64537 m
.31908 .64594 L
s
.5039 .4149 m
.50794 .39612 L
s
.58987 .34408 m
.59351 .34859 L
s
.65718 .3427 m
.66072 .34889 L
s
.72456 .34336 m
.72793 .34895 L
s
.62349 .34238 m
.62714 .34946 L
s
.69082 .3423 m
.69436 .34945 L
s
.35898 .69453 m
.36396 .68406 L
s
.3328 .48269 m
.33337 .54596 L
s
.52192 .86346 m
.52572 .91787 L
s
.18151 .33562 m
.18618 .3404 L
s
.33025 .68552 m
.33274 .71954 L
s
.48613 .55973 m
.49016 .55463 L
s
.38941 .79623 m
.39434 .78108 L
s
.85594 .33545 m
.85892 .3401 L
s
.82228 .33615 m
.82532 .34062 L
s
.5563 .35527 m
.55996 .35303 L
s
.78865 .33724 m
.79178 .34178 L
s
.61996 .33898 m
.62349 .34238 L
s
.68742 .33766 m
.69082 .3423 L
s
.37898 .73604 m
.38191 .76821 L
s
.65373 .33907 m
.65718 .3427 L
s
.53015 .38098 m
.53394 .37866 L
s
.75494 .33782 m
.75822 .34303 L
s
.47773 .43351 m
.48185 .42696 L
s
.72111 .33676 m
.72456 .34336 L
s
.58637 .34733 m
.58987 .34408 L
s
.43347 .48947 m
.43559 .55906 L
s
.30983 .64607 m
.31452 .64537 L
s
.17682 .33083 m
.18151 .33562 L
s
.45483 .49175 m
.45952 .46687 L
s
.47033 .39543 m
.47395 .41835 L
s
.46631 .3928 m
.47033 .39543 L
s
.85296 .33081 m
.85594 .33545 L
s
.42379 1.04143 m
.429 1.00478 L
s
.81923 .33162 m
.82228 .33615 L
s
.71781 .33249 m
.72111 .33676 L
s
.78546 .33234 m
.78865 .33724 L
s
.68407 .3342 m
.68742 .33766 L
s
.75159 .33181 m
.75494 .33782 L
s
.47474 .51759 m
.4783 .54665 L
s
.61637 .33443 m
.61996 .33898 L
s
.40392 .7416 m
.40849 .73359 L
s
.65026 .33515 m
.65373 .33907 L
s
.52958 .93587 m
.53338 .9131 L
s
.1721 .32601 m
.17682 .33083 L
s
.45555 .73606 m
.46066 .68925 L
s
.84997 .32619 m
.85296 .33081 L
s
.5526 .35783 m
.5563 .35527 L
s
.81613 .3269 m
.81923 .33162 L
s
.74832 .32703 m
.75159 .33181 L
s
.48212 .55997 m
.48613 .55973 L
s
.78222 .32693 m
.78546 .33234 L
s
.71451 .32856 m
.71781 .33249 L
s
.46203 .40148 m
.46631 .3928 L
s
.52632 .38193 m
.53015 .38098 L
s
.30518 .64585 m
.30983 .64607 L
s
.47395 .41835 m
.47773 .43351 L
s
.68062 .32924 m
.68407 .3342 L
s
.61275 .32931 m
.61637 .33443 L
s
.35413 .7016 m
.35898 .69453 L
s
.64664 .32843 m
.65026 .33515 L
s
.58278 .34748 m
.58637 .34733 L
s
.33274 .71954 m
.33463 .76467 L
s
.30729 .5127 m
.31606 .45645 L
s
.38191 .76821 m
.3853 .79066 L
s
.41061 .54139 m
.41295 .59444 L
s
.40592 .5512 m
.41061 .54139 L
s
.16736 .32116 m
.1721 .32601 L
s
.84695 .32151 m
.84997 .32619 L
s
.34209 .4352 m
.34503 .46194 L
s
.33251 .5129 m
.34209 .4352 L
s
.779 .32182 m
.78222 .32693 L
s
.813 .32187 m
.81613 .3269 L
s
.74508 .32281 m
.74832 .32703 L
s
.3853 .79066 m
.38941 .79623 L
s
.643 .3212 m
.64664 .32843 L
s
.71108 .32297 m
.71451 .32856 L
s
.51007 1.05246 m
.50716 .95377 L
s
.60923 .32842 m
.61275 .32931 L
s
.67706 .32266 m
.68062 .32924 L
s
.4283 .7815 m
.43413 .72661 L
s
.4783 .54665 m
.48212 .55997 L
s
.37197 .4267 m
.37568 .44131 L
s
.36689 .43757 m
.37197 .4267 L
s
.49989 .421 m
.5039 .4149 L
s
.51478 .34363 m
.51862 .35643 L
s
.51088 .34179 m
.51478 .34363 L
s
.51862 .35643 m
.52246 .37397 L
s
.1626 .31629 m
.16736 .32116 L
s
.39943 .74602 m
.40392 .7416 L
s
.37568 .44131 m
.37658 .51299 L
s
.30065 .64336 m
.30518 .64585 L
s
.63955 .31917 m
.643 .3212 L
s
.54885 .35777 m
.5526 .35783 L
s
.52246 .37397 m
.52632 .38193 L
s
.84391 .31668 m
.84695 .32151 L
s
.7758 .31722 m
.779 .32182 L
s
.80984 .3168 m
.813 .32187 L
s
.6735 .31629 m
.67706 .32266 L
s
.74172 .31727 m
.74508 .32281 L
s
.70762 .317 m
.71108 .32297 L
s
.57908 .34396 m
.58278 .34748 L
s
.4807 .35148 m
.48446 .3698 L
s
.47682 .34062 m
.4807 .35148 L
s
.52572 .91787 m
.52958 .93587 L
s
.45148 .59387 m
.45565 .59294 L
s
.34948 .70408 m
.35413 .7016 L
s
.15781 .31139 m
.1626 .31629 L
s
.47286 .33391 m
.47682 .34062 L
s
.60562 .32518 m
.60923 .32842 L
s
.67005 .31227 m
.6735 .31629 L
s
.4241 .38937 m
.42775 .40749 L
s
.42003 .38326 m
.4241 .38937 L
s
.45787 .40205 m
.46203 .40148 L
s
.34503 .46194 m
.34472 .54428 L
s
.41595 .50346 m
.42089 .48601 L
s
.39774 .41378 m
.40002 .4629 L
s
.39253 .4315 m
.39774 .41378 L
s
.84084 .31172 m
.84391 .31668 L
s
.8067 .31192 m
.80984 .3168 L
s
.7042 .31186 m
.70762 .317 L
s
.29628 .63831 m
.30065 .64336 L
s
.77253 .31189 m
.7758 .31722 L
s
.73835 .31174 m
.74172 .31727 L
s
.50698 .33536 m
.51088 .34179 L
s
.6361 .31772 m
.63955 .31917 L
s
.57532 .33762 m
.57908 .34396 L
s
.48446 .3698 m
.48822 .38972 L
s
.39851 .62628 m
.40592 .5512 L
s
.54504 .35405 m
.54885 .35777 L
s
.4687 .33656 m
.47286 .33391 L
s
.45031 .37086 m
.45407 .38721 L
s
.44615 .36914 m
.45031 .37086 L
s
.45033 .50491 m
.45483 .49175 L
s
.41542 .39049 m
.42003 .38326 L
s
.42775 .40749 m
.4307 .44815 L
s
.15299 .30647 m
.15781 .31139 L
s
.3946 .75793 m
.39943 .74602 L
s
.50308 .32696 m
.50698 .33536 L
s
.29201 .6317 m
.29628 .63831 L
s
.73503 .30711 m
.73835 .31174 L
s
.70078 .30702 m
.7042 .31186 L
s
.49593 .41767 m
.49989 .421 L
s
.83776 .30678 m
.84084 .31172 L
s
.76924 .30662 m
.77253 .31189 L
s
.8035 .3067 m
.8067 .31192 L
s
.6666 .30856 m
.67005 .31227 L
s
.60194 .32038 m
.60562 .32518 L
s
.43671 .65226 m
.43846 .74301 L
s
.5715 .32906 m
.57532 .33762 L
s
.45407 .38721 m
.45787 .40205 L
s
.49915 .32115 m
.50308 .32696 L
s
.42087 1.06352 m
.42379 1.04143 L
s
.44758 .58304 m
.45148 .59387 L
s
.33337 .54596 m
.33164 .64926 L
s
.36036 .47328 m
.36689 .43757 L
s
.34483 .70566 m
.34948 .70408 L
s
.33463 .76467 m
.33608 .81942 L
s
.44332 .58531 m
.44758 .58304 L
s
.28771 .62522 m
.29201 .6317 L
s
.53341 .31657 m
.53729 .32983 L
s
.52954 .30848 m
.53341 .31657 L
s
.48822 .38972 m
.49204 .40665 L
s
.56765 .31833 m
.5715 .32906 L
s
.53729 .32983 m
.54118 .3445 L
s
.54118 .3445 m
.54504 .35405 L
s
.63257 .3148 m
.6361 .31772 L
s
.14816 .30153 m
.15299 .30647 L
s
.56383 .31038 m
.56765 .31833 L
s
.766 .302 m
.76924 .30662 L
s
.80029 .3015 m
.8035 .3067 L
s
.83464 .30164 m
.83776 .30678 L
s
.69731 .30167 m
.70078 .30702 L
s
.73168 .3022 m
.73503 .30711 L
s
.59827 .31647 m
.60194 .32038 L
s
.44212 .36225 m
.44615 .36914 L
s
.52566 .30484 m
.52954 .30848 L
s
.49204 .40665 m
.49593 .41767 L
s
.66312 .3047 m
.6666 .30856 L
s
.4952 .31589 m
.49915 .32115 L
s
.28328 .6202 m
.28771 .62522 L
s
.56002 .30451 m
.56383 .31038 L
s
.41598 .63115 m
.42087 .61441 L
s
.46425 .35033 m
.4687 .33656 L
s
.1433 .29656 m
.14816 .30153 L
s
.43814 .35313 m
.44212 .36225 L
s
.37115 .65545 m
.37867 .59321 L
s
.79712 .29681 m
.80029 .3015 L
s
.69388 .29724 m
.69731 .30167 L
s
.8315 .29638 m
.83464 .30164 L
s
.76271 .297 m
.766 .302 L
s
.30475 .36344 m
.30269 .45469 L
s
.29825 .38454 m
.30475 .36344 L
s
.72827 .29669 m
.73168 .3022 L
s
.41295 .59444 m
.41598 .63115 L
s
.62893 .30958 m
.63257 .3148 L
s
.43559 .55906 m
.43899 .58869 L
s
.49115 .31659 m
.4952 .31589 L
s
.27868 .61703 m
.28328 .6202 L
s
.33992 .71122 m
.34483 .70566 L
s
.43377 .35595 m
.43814 .35313 L
s
.59454 .31106 m
.59827 .31647 L
s
.55619 .29822 m
.56002 .30451 L
s
.52175 .30483 m
.52566 .30484 L
s
.65961 .30053 m
.66312 .3047 L
s
.40965 .42589 m
.41542 .39049 L
s
.43899 .58869 m
.44332 .58531 L
s
.38923 .78139 m
.3946 .75793 L
s
.39002 .63701 m
.38872 .77326 L
s
.13841 .29156 m
.1433 .29656 L
s
.41107 .5173 m
.41595 .50346 L
s
.8284 .29159 m
.8315 .29638 L
s
.72486 .29148 m
.72827 .29669 L
s
.7939 .29171 m
.79712 .29681 L
s
.38671 .46029 m
.39253 .4315 L
s
.75938 .29156 m
.76271 .297 L
s
.45027 .78395 m
.45555 .73606 L
s
.69048 .29364 m
.69388 .29724 L
s
.62521 .30259 m
.62893 .30958 L
s
.44608 .50573 m
.45033 .50491 L
s
.55236 .29377 m
.55619 .29822 L
s
.59072 .30259 m
.59454 .31106 L
s
.27394 .6152 m
.27868 .61703 L
s
.65603 .29532 m
.65961 .30053 L
s
.4307 .44815 m
.43375 .48812 L
s
.58689 .29355 m
.59072 .30259 L
s
.62146 .29488 m
.62521 .30259 L
s
.1335 .28654 m
.13841 .29156 L
s
.7215 .28711 m
.72486 .29148 L
s
.40002 .4629 m
.40235 .51372 L
s
.75603 .28627 m
.75938 .29156 L
s
.82525 .2865 m
.8284 .29159 L
s
.79064 .2864 m
.7939 .29171 L
s
.487 .32168 m
.49115 .31659 L
s
.51779 .30704 m
.52175 .30483 L
s
.58309 .28677 m
.58689 .29355 L
s
.54852 .29051 m
.55236 .29377 L
s
.68703 .28952 m
.69048 .29364 L
s
.42921 .36295 m
.43377 .35595 L
s
.61772 .28793 m
.62146 .29488 L
s
.33458 .72314 m
.33992 .71122 L
s
.65242 .28983 m
.65603 .29532 L
s
.26914 .61374 m
.27394 .6152 L
s
.44186 .50461 m
.44608 .50573 L
s
.12856 .28149 m
.1335 .28654 L
s
.75271 .28134 m
.75603 .28627 L
s
.78739 .28132 m
.79064 .2864 L
s
.57933 .28288 m
.58309 .28677 L
s
.82207 .28124 m
.82525 .2865 L
s
.71813 .28288 m
.7215 .28711 L
s
.614 .28198 m
.61772 .28793 L
s
.45983 .35996 m
.46425 .35033 L
s
.68353 .28476 m
.68703 .28952 L
s
.6488 .28466 m
.65242 .28983 L
s
.54467 .28851 m
.54852 .29051 L
s
.42249 .83 m
.4283 .7815 L
s
.29834 .56846 m
.30729 .5127 L
s
.33608 .81942 m
.33722 .88168 L
s
.37658 .51299 m
.37611 .61692 L
s
.1236 .27642 m
.12856 .28149 L
s
.74937 .27638 m
.75271 .28134 L
s
.81891 .27625 m
.82207 .28124 L
s
.78413 .27621 m
.78739 .28132 L
s
.26436 .61165 m
.26914 .61374 L
s
.61027 .27625 m
.614 .28198 L
s
.51381 .30776 m
.51779 .30704 L
s
.57555 .27936 m
.57933 .28288 L
s
.71471 .27812 m
.71813 .28288 L
s
.43755 .50514 m
.44186 .50461 L
s
.36784 .38212 m
.37152 .39914 L
s
.36128 .41674 m
.36784 .38212 L
s
.40619 .52912 m
.41107 .5173 L
s
.48277 .32919 m
.487 .32168 L
s
.64513 .27855 m
.6488 .28466 L
s
.67997 .27913 m
.68353 .28476 L
s
.28391 .50185 m
.29825 .38454 L
s
.11861 .27132 m
.1236 .27642 L
s
.37152 .39914 m
.37465 .42706 L
s
.35208 .5372 m
.36036 .47328 L
s
.5408 .28963 m
.54467 .28851 L
s
.60656 .27206 m
.61027 .27625 L
s
.78083 .27095 m
.78413 .27621 L
s
.42429 .37867 m
.42921 .36295 L
s
.81571 .27111 m
.81891 .27625 L
s
.38341 .8128 m
.38923 .78139 L
s
.74604 .27185 m
.74937 .27638 L
s
.71123 .27279 m
.71471 .27812 L
s
.43375 .48812 m
.43755 .50514 L
s
.64143 .27202 m
.64513 .27855 L
s
.25965 .60836 m
.26436 .61165 L
s
.67634 .27269 m
.67997 .27913 L
s
.57177 .27678 m
.57555 .27936 L
s
.32889 .73974 m
.33458 .72314 L
s
.38242 .33026 m
.38478 .37488 L
s
.37816 .32403 m
.38242 .33026 L
s
.32455 .36805 m
.32499 .43175 L
s
.31668 .41054 m
.32455 .36805 L
s
.44414 .30682 m
.44764 .33532 L
s
.44001 .30026 m
.44414 .30682 L
s
.11359 .2662 m
.11861 .27132 L
s
.50981 .30382 m
.51381 .30776 L
s
.77756 .26612 m
.78083 .27095 L
s
.81249 .26584 m
.81571 .27111 L
s
.40526 .29682 m
.40818 .33377 L
s
.40032 .30663 m
.40526 .29682 L
s
.74268 .26713 m
.74604 .27185 L
s
.60283 .26744 m
.60656 .27206 L
s
.63775 .26633 m
.64143 .27202 L
s
.34472 .54428 m
.3451 .61829 L
s
.67271 .26649 m
.67634 .27269 L
s
.70772 .26727 m
.71123 .27279 L
s
.45553 .36169 m
.45983 .35996 L
s
.37036 .38326 m
.37816 .32403 L
s
.25502 .60381 m
.25965 .60836 L
s
.38208 .46188 m
.38671 .46029 L
s
.43543 .30748 m
.44001 .30026 L
s
.56795 .27369 m
.57177 .27678 L
s
.53689 .2901 m
.5408 .28963 L
s
.40376 .46051 m
.40965 .42589 L
s
.32258 .59181 m
.33251 .5129 L
s
.10855 .26104 m
.11359 .2662 L
s
.37465 .42706 m
.37827 .44618 L
s
.40235 .51372 m
.40619 .52912 L
s
.80927 .26069 m
.81249 .26584 L
s
.77428 .26134 m
.77756 .26612 L
s
.63408 .26136 m
.63775 .26633 L
s
.50583 .29461 m
.50981 .30382 L
s
.66911 .261 m
.67271 .26649 L
s
.47852 .33387 m
.48277 .32919 L
s
.73928 .26205 m
.74268 .26713 L
s
.70421 .26189 m
.70772 .26727 L
s
.5991 .26394 m
.60283 .26744 L
s
.25045 .59835 m
.25502 .60381 L
s
.50183 .28683 m
.50583 .29461 L
s
.43846 .74301 m
.44132 .79861 L
s
.37827 .44618 m
.38208 .46188 L
s
.44764 .33532 m
.45142 .35474 L
s
.80604 .25561 m
.80927 .26069 L
s
.6655 .25569 m
.66911 .261 L
s
.56409 .26939 m
.56795 .27369 L
s
.6304 .25661 m
.63408 .26136 L
s
.77097 .25639 m
.77428 .26134 L
s
.49773 .28678 m
.50183 .28683 L
s
.70067 .25634 m
.70421 .26189 L
s
.45142 .35474 m
.45553 .36169 L
s
.73585 .25676 m
.73928 .26205 L
s
.44534 .81096 m
.45027 .78395 L
s
.24589 .59247 m
.25045 .59835 L
s
.59538 .26172 m
.5991 .26394 L
s
.53294 .28715 m
.53689 .2901 L
s
.46272 .27815 m
.46657 .29677 L
s
.45865 .26979 m
.46272 .27815 L
s
.39057 .70813 m
.39851 .62628 L
s
.41913 .39829 m
.42429 .37867 L
s
.32307 .75693 m
.32889 .73974 L
s
.66188 .25067 m
.6655 .25569 L
s
.8028 .2506 m
.80604 .25561 L
s
.24128 .58694 m
.24589 .59247 L
s
.69711 .25064 m
.70067 .25634 L
s
.3959 .30361 m
.40032 .30663 L
s
.76761 .2511 m
.77097 .25639 L
s
.62671 .25236 m
.6304 .25661 L
s
.56022 .26536 m
.56409 .26939 L
s
.73237 .25108 m
.73585 .25676 L
s
.36458 .69439 m
.37115 .65545 L
s
.45401 .28296 m
.45865 .26979 L
s
.43127 .30044 m
.43543 .30748 L
s
.40818 .33377 m
.41091 .37764 L
s
.33722 .88168 m
.33822 .94917 L
s
.47439 .32945 m
.47852 .33387 L
s
.46657 .29677 m
.47044 .31496 L
s
.59161 .25865 m
.59538 .26172 L
s
.49366 .28186 m
.49773 .28678 L
s
.52896 .28006 m
.53294 .28715 L
s
.23652 .58274 m
.24128 .58694 L
s
.38478 .37488 m
.3878 .4077 L
s
.33164 .64926 m
.32854 .77994 L
s
.42694 .29767 m
.43127 .30044 L
s
.65824 .2456 m
.66188 .25067 L
s
.69354 .24522 m
.69711 .25064 L
s
.79954 .24551 m
.8028 .2506 L
s
.72887 .24528 m
.73237 .25108 L
s
.76422 .24561 m
.76761 .2511 L
s
.37736 .84698 m
.38341 .8128 L
s
.62301 .24819 m
.62671 .25236 L
s
.47044 .31496 m
.47439 .32945 L
s
.55633 .26223 m
.56022 .26536 L
s
.39136 .30266 m
.3959 .30361 L
s
.52097 .25422 m
.52496 .26824 L
s
.51695 .24989 m
.52097 .25422 L
s
.35419 .4577 m
.36128 .41674 L
s
.4857 .25433 m
.48968 .26811 L
s
.48156 .25121 m
.4857 .25433 L
s
.30269 .45469 m
.30222 .5278 L
s
.52496 .26824 m
.52896 .28006 L
s
.41666 .87419 m
.42249 .83 L
s
.48968 .26811 m
.49366 .28186 L
s
.23154 .58056 m
.23652 .58274 L
s
.68998 .23997 m
.69354 .24522 L
s
.72538 .23986 m
.72887 .24528 L
s
.65462 .24116 m
.65824 .2456 L
s
.79625 .24027 m
.79954 .24551 L
s
.76082 .24017 m
.76422 .24561 L
s
.58778 .25362 m
.59161 .25865 L
s
.42226 .30344 m
.42694 .29767 L
s
.61929 .24413 m
.62301 .24819 L
s
.55238 .25648 m
.55633 .26223 L
s
.51291 .24523 m
.51695 .24989 L
s
.4773 .25249 m
.48156 .25121 L
s
.15892 .24012 m
.15345 .32493 L
s
.38534 .33077 m
.39136 .30266 L
s
.72188 .23454 m
.72538 .23986 L
s
.6864 .23486 m
.68998 .23997 L
s
.75741 .23474 m
.76082 .24017 L
s
.79293 .23493 m
.79625 .24027 L
s
.58387 .24597 m
.58778 .25362 L
s
.65099 .23708 m
.65462 .24116 L
s
.22633 .58044 m
.23154 .58056 L
s
.28905 .62582 m
.29834 .56846 L
s
.31728 .77233 m
.32307 .75693 L
s
.30092 .35631 m
.30491 .36915 L
s
.28805 .45417 m
.30092 .35631 L
s
.32499 .43175 m
.32133 .55938 L
s
.30491 .36915 m
.30605 .42001 L
s
.5484 .24761 m
.55238 .25648 L
s
.61555 .24001 m
.61929 .24413 L
s
.3878 .4077 m
.39111 .43568 L
s
.44948 .28909 m
.45401 .28296 L
s
.50883 .24199 m
.51291 .24523 L
s
.44132 .79861 m
.44534 .81096 L
s
.57994 .23815 m
.58387 .24597 L
s
.39878 .47028 m
.40376 .46051 L
s
.30991 .43548 m
.31668 .41054 L
s
.41452 .40116 m
.41913 .39829 L
s
.71837 .22926 m
.72188 .23454 L
s
.75397 .22924 m
.75741 .23474 L
s
.5444 .23805 m
.5484 .24761 L
s
.68281 .22992 m
.6864 .23486 L
s
.78959 .22945 m
.79293 .23493 L
s
.41033 .26203 m
.41401 .28305 L
s
.40494 .28095 m
.41033 .26203 L
s
.64732 .23248 m
.65099 .23708 L
s
.5404 .23124 m
.5444 .23805 L
s
.57606 .23334 m
.57994 .23815 L
s
.41091 .37764 m
.41452 .40116 L
s
.47295 .25673 m
.4773 .25249 L
s
.61176 .235 m
.61555 .24001 L
s
.22093 .58179 m
.22633 .58044 L
s
.41788 .30002 m
.42226 .30344 L
s
.3451 .61829 m
.34648 .67803 L
s
.1845 .22949 m
.18792 .24706 L
s
.50471 .24095 m
.50883 .24199 L
s
.71485 .224 m
.71837 .22926 L
s
.75053 .22382 m
.75397 .22924 L
s
.78623 .22388 m
.78959 .22945 L
s
.67922 .22518 m
.68281 .22992 L
s
.53641 .23025 m
.5404 .23124 L
s
.41401 .28305 m
.41788 .30002 L
s
.64358 .22687 m
.64732 .23248 L
s
.57212 .22663 m
.57606 .23334 L
s
.39111 .43568 m
.39471 .4581 L
s
.18792 .24706 m
.1888 .28597 L
s
.34257 .61797 m
.35208 .5372 L
s
.6079 .22834 m
.61176 .235 L
s
.74707 .21846 m
.75053 .22382 L
s
.78285 .21841 m
.78623 .22388 L
s
.71132 .21896 m
.71485 .224 L
s
.37611 .61692 m
.37625 .71347 L
s
.67561 .22054 m
.67922 .22518 L
s
.44512 .28749 m
.44948 .28909 L
s
.21498 .2264 m
.21826 .24584 L
s
.21036 .21875 m
.21498 .2264 L
s
.35857 .71962 m
.36458 .69439 L
s
.56816 .21937 m
.57212 .22663 L
s
.63981 .22096 m
.64358 .22687 L
s
.37108 .88321 m
.37736 .84698 L
s
.21542 .58367 m
.22093 .58179 L
s
.33899 1.00406 m
.33822 .94917 L
s
.31132 .78909 m
.31728 .77233 L
s
.5006 .23442 m
.50471 .24095 L
s
.60398 .22044 m
.6079 .22834 L
s
.38872 .77326 m
.38861 .88887 L
s
.39471 .4581 m
.39878 .47028 L
s
.53238 .22805 m
.53641 .23025 L
s
.36313 .42789 m
.37036 .38326 L
s
.46862 .25773 m
.47295 .25673 L
s
.77947 .213 m
.78285 .21841 L
s
.7436 .21313 m
.74707 .21846 L
s
.70778 .21402 m
.71132 .21896 L
s
.56422 .21477 m
.56816 .21937 L
s
.21826 .24584 m
.21984 .28117 L
s
.60008 .21359 m
.60398 .22044 L
s
.67197 .2156 m
.67561 .22054 L
s
.63605 .21562 m
.63981 .22096 L
s
.43302 .24712 m
.437 .26204 L
s
.42866 .24304 m
.43302 .24712 L
s
.32218 .34873 m
.32561 .37046 L
s
.31804 .33716 m
.32218 .34873 L
s
.49649 .22663 m
.5006 .23442 L
s
.31259 .34321 m
.31804 .33716 L
s
.437 .26204 m
.44097 .27777 L
s
.44097 .27777 m
.44512 .28749 L
s
.24548 .22514 m
.24834 .24973 L
s
.24128 .21379 m
.24548 .22514 L
s
.23649 .20789 m
.24128 .21379 L
s
.77608 .20758 m
.77947 .213 L
s
.74012 .20785 m
.7436 .21313 L
s
.59622 .2086 m
.60008 .21359 L
s
.41065 .91949 m
.41666 .87419 L
s
.49226 .22728 m
.49649 .22663 L
s
.7042 .20884 m
.70778 .21402 L
s
.20991 .58519 m
.21542 .58367 L
s
.56028 .21252 m
.56422 .21477 L
s
.52832 .22401 m
.53238 .22805 L
s
.63224 .20959 m
.63605 .21562 L
s
.66826 .20993 m
.67197 .2156 L
s
.34861 .47038 m
.35419 .4577 L
s
.37935 .35566 m
.38534 .33077 L
s
.30605 .42001 m
.30991 .43548 L
s
.39924 .3045 m
.40494 .28095 L
s
.42367 .255 m
.42866 .24304 L
s
.32561 .37046 m
.32787 .40976 L
s
.46441 .25111 m
.46862 .25773 L
s
.77267 .20216 m
.77608 .20758 L
s
.73663 .2027 m
.74012 .20785 L
s
.59234 .20392 m
.59622 .2086 L
s
.1888 .28597 m
.18828 .33744 L
s
.30222 .5278 m
.30325 .58283 L
s
.70059 .20341 m
.7042 .20884 L
s
.3145 .63868 m
.32258 .59181 L
s
.6284 .20305 m
.63224 .20959 L
s
.27221 .21051 m
.27585 .22807 L
s
.26769 .20251 m
.27221 .21051 L
s
.6645 .2034 m
.66826 .20993 L
s
.24834 .24973 m
.24979 .28915 L
s
.52424 .21671 m
.52832 .22401 L
s
.55631 .20938 m
.56028 .21252 L
s
.46029 .2401 m
.46441 .25111 L
s
.48802 .22608 m
.49226 .22728 L
s
.4561 .23144 m
.46029 .2401 L
s
.30461 .81588 m
.31132 .78909 L
s
.20443 .58588 m
.20991 .58519 L
s
.26291 .19692 m
.26769 .20251 L
s
.27585 .22807 m
.2781 .26138 L
s
.30373 .39287 m
.31259 .34321 L
s
.76924 .19679 m
.77267 .20216 L
s
.73312 .19754 m
.73663 .2027 L
s
.62456 .19707 m
.6284 .20305 L
s
.66075 .19733 m
.6645 .2034 L
s
.69697 .19799 m
.70059 .20341 L
s
.52015 .2067 m
.52424 .21671 L
s
.58844 .19947 m
.59234 .20392 L
s
.21984 .28117 m
.22039 .32678 L
s
.34648 .67803 m
.34909 .71769 L
s
.45189 .22318 m
.4561 .23144 L
s
.51602 .20422 m
.52015 .2067 L
s
.35321 .73062 m
.35857 .71962 L
s
.33603 .3104 m
.33985 .32738 L
s
.33119 .30843 m
.33603 .3104 L
s
.34079 .43878 m
.34471 .45439 L
s
.33556 .44362 m
.34079 .43878 L
s
.38351 .76342 m
.39057 .70813 L
s
.55228 .20434 m
.55631 .20938 L
s
.76581 .19145 m
.76924 .19679 L
s
.62075 .19252 m
.62456 .19707 L
s
.44745 .22226 m
.45189 .22318 L
s
.657 .19167 m
.66075 .19733 L
s
.29897 .19801 m
.30306 .21093 L
s
.29435 .1914 m
.29897 .19801 L
s
.30306 .21093 m
.30605 .23756 L
s
.72958 .19214 m
.73312 .19754 L
s
.34471 .45439 m
.34861 .47038 L
s
.69331 .19232 m
.69697 .19799 L
s
.33985 .32738 m
.3439 .34089 L
s
.5845 .19402 m
.58844 .19947 L
s
.3439 .34089 m
.34758 .36052 L
s
.48381 .2204 m
.48802 .22608 L
s
.19895 .58611 m
.20443 .58588 L
s
.27882 .6925 m
.28905 .62582 L
s
.36432 .92681 m
.37108 .88321 L
s
.41872 .26411 m
.42367 .255 L
s
.28961 .18582 m
.29435 .1914 L
s
.32787 .40976 m
.33078 .44071 L
s
.51184 .20403 m
.51602 .20422 L
s
.54822 .1971 m
.55228 .20434 L
s
.76235 .18603 m
.76581 .19145 L
s
.65321 .18576 m
.657 .19167 L
s
.72599 .18632 m
.72958 .19214 L
s
.68961 .1862 m
.69331 .19232 L
s
.32462 .33035 m
.33119 .30843 L
s
.61692 .18798 m
.62075 .19252 L
s
.26764 .63742 m
.28391 .50185 L
s
.34758 .36052 m
.35016 .39864 L
s
.58056 .18948 m
.5845 .19402 L
s
.47961 .21282 m
.48381 .2204 L
s
.33026 .19611 m
.33391 .21559 L
s
.32593 .18627 m
.33026 .19611 L
s
.15345 .32493 m
.14867 .4066 L
s
.44279 .22711 m
.44745 .22226 L
s
.2781 .26138 m
.279 .31101 L
s
.54414 .18922 m
.54822 .1971 L
s
.35894 .28803 m
.36272 .30675 L
s
.3547 .27716 m
.35894 .28803 L
s
.30605 .23756 m
.30788 .27972 L
s
.24979 .28915 m
.25039 .33847 L
s
.64944 .18052 m
.65321 .18576 L
s
.33078 .44071 m
.33556 .44362 L
s
.32129 .18023 m
.32593 .18627 L
s
.75886 .18055 m
.76235 .18603 L
s
.68588 .18002 m
.68961 .1862 L
s
.19333 .58727 m
.19895 .58611 L
s
.72238 .18047 m
.72599 .18632 L
s
.34986 .27566 m
.3547 .27716 L
s
.47541 .20385 m
.47961 .21282 L
s
.37428 .36073 m
.37935 .35566 L
s
.61304 .18275 m
.61692 .18798 L
s
.39425 .31033 m
.39924 .3045 L
s
.34909 .71769 m
.35321 .73062 L
s
.54006 .18509 m
.54414 .18922 L
s
.33391 .21559 m
.33698 .2438 L
s
.57658 .18458 m
.58056 .18948 L
s
.36272 .30675 m
.36635 .32835 L
s
.47112 .19905 m
.47541 .20385 L
s
.50766 .19969 m
.51184 .20403 L
s
.3166 .17461 m
.32129 .18023 L
s
.68218 .17454 m
.68588 .18002 L
s
.64568 .1758 m
.64944 .18052 L
s
.71877 .17477 m
.72238 .18047 L
s
.75535 .17496 m
.75886 .18055 L
s
.18828 .33744 m
.18788 .38926 L
s
.30325 .58283 m
.30542 .62367 L
s
.35731 .44457 m
.36313 .42789 L
s
.35759 .18265 m
.3617 .196 L
s
.35314 .17478 m
.35759 .18265 L
s
.29652 .86108 m
.30461 .81588 L
s
.3617 .196 m
.36557 .21334 L
s
.60911 .17622 m
.61304 .18275 L
s
.40445 .96566 m
.41065 .91949 L
s
.37821 .24796 m
.3823 .26186 L
s
.3739 .23829 m
.37821 .24796 L
s
.3823 .26186 m
.38619 .27955 L
s
.22039 .32678 m
.22105 .37261 L
s
.57256 .17839 m
.57658 .18458 L
s
.34478 .27729 m
.34986 .27566 L
s
.32854 .77994 m
.32532 .91863 L
s
.53596 .18306 m
.54006 .18509 L
s
.36635 .32835 m
.37012 .34799 L
s
.23815 .61304 m
.2416 .63355 L
s
.23326 .60806 m
.23815 .61304 L
s
.18736 .59112 m
.19333 .58727 L
s
.46671 .19868 m
.47112 .19905 L
s
.3696 .22827 m
.3739 .23829 L
s
.4142 .2606 m
.41872 .26411 L
s
.50347 .19219 m
.50766 .19969 L
s
.36557 .21334 m
.3696 .22827 L
s
.2173 .54998 m
.22093 .56805 L
s
.21301 .53848 m
.2173 .54998 L
s
.34853 .16895 m
.35314 .17478 L
s
.67847 .1691 m
.68218 .17454 L
s
.71512 .1689 m
.71877 .17477 L
s
.43831 .22495 m
.44279 .22711 L
s
.75181 .16911 m
.75535 .17496 L
s
.20812 .53276 m
.21301 .53848 L
s
.38619 .27955 m
.39003 .29869 L
s
.64187 .1707 m
.64568 .1758 L
s
.60518 .17067 m
.60911 .17622 L
s
.35016 .39864 m
.35305 .43306 L
s
.40194 .21733 m
.40603 .23152 L
s
.39778 .20478 m
.40194 .21733 L
s
.56852 .17209 m
.57256 .17839 L
s
.39362 .19201 m
.39778 .20478 L
s
.33698 .2438 m
.34038 .26801 L
s
.38945 .17967 m
.39362 .19201 L
s
.22093 .56805 m
.22441 .58785 L
s
.37012 .34799 m
.37428 .36073 L
s
.49928 .18403 m
.50347 .19219 L
s
.38512 .17007 m
.38945 .17967 L
s
.2416 .63355 m
.24228 .68561 L
s
.40603 .23152 m
.41006 .24738 L
s
.22845 .60209 m
.23326 .60806 L
s
.39003 .29869 m
.39425 .31033 L
s
.37625 .71347 m
.37853 .76803 L
s
.34388 .16327 m
.34853 .16895 L
s
.20297 .52922 m
.20812 .53276 L
s
.71147 .16311 m
.71512 .1689 L
s
.67474 .16374 m
.67847 .1691 L
s
.41006 .24738 m
.4142 .2606 L
s
.74824 .16315 m
.75181 .16911 L
s
.38063 .16333 m
.38512 .17007 L
s
.53183 .17847 m
.53596 .18306 L
s
.60126 .16602 m
.60518 .17067 L
s
.63802 .16494 m
.64187 .1707 L
s
.30892 .64644 m
.3145 .63868 L
s
.49504 .1784 m
.49928 .18403 L
s
.22441 .58785 m
.22845 .60209 L
s
.56447 .1668 m
.56852 .17209 L
s
.46235 .19417 m
.46671 .19868 L
s
.43407 .21434 m
.43831 .22495 L
s
.34038 .26801 m
.34478 .27729 L
s
.31773 .35504 m
.32462 .33035 L
s
.42577 .18765 m
.42993 .20066 L
s
.42157 .1759 m
.42577 .18765 L
s
.42993 .20066 m
.43407 .21434 L
s
.18087 .59921 m
.18736 .59112 L
s
.30788 .27972 m
.30942 .32708 L
s
.33278 .6984 m
.34257 .61797 L
s
.41728 .16582 m
.42157 .1759 L
s
.37606 .15755 m
.38063 .16333 L
s
.70781 .15762 m
.71147 .16311 L
s
.74467 .1574 m
.74824 .16315 L
s
.67098 .1583 m
.67474 .16374 L
s
.19775 .52595 m
.20297 .52922 L
s
.63411 .15841 m
.63802 .16494 L
s
.49076 .17435 m
.49504 .1784 L
s
.52766 .17151 m
.53183 .17847 L
s
.4129 .15803 m
.41728 .16582 L
s
.59729 .16049 m
.60126 .16602 L
s
.56042 .16305 m
.56447 .1668 L
s
.27284 .57597 m
.28805 .45417 L
s
.279 .31101 m
.27886 .37431 L
s
.30542 .62367 m
.30892 .64644 L
s
.45811 .18423 m
.46235 .19417 L
s
.32133 .55938 m
.31874 .67647 L
s
.25039 .33847 m
.25053 .39408 L
s
.35922 .96448 m
.36432 .92681 L
s
.37146 .15181 m
.37606 .15755 L
s
.35305 .43306 m
.35731 .44457 L
s
.74107 .15161 m
.74467 .1574 L
s
.29326 .46024 m
.30373 .39287 L
s
.40842 .15182 m
.4129 .15803 L
s
.70415 .15217 m
.70781 .15762 L
s
.45389 .17258 m
.45811 .18423 L
s
.39002 .95939 m
.38861 .88887 L
s
.52348 .16424 m
.52766 .17151 L
s
.66721 .15281 m
.67098 .1583 L
s
.63023 .15289 m
.63411 .15841 L
s
.44965 .16193 m
.45389 .17258 L
s
.19239 .52371 m
.19775 .52595 L
s
.59329 .15437 m
.59729 .16049 L
s
.48648 .16762 m
.49076 .17435 L
s
.44534 .15316 m
.44965 .16193 L
s
.37853 .76803 m
.38351 .76342 L
s
.22105 .37261 m
.22242 .41275 L
s
.55633 .158 m
.56042 .16305 L
s
.51928 .15803 m
.52348 .16424 L
s
.4039 .14602 m
.40842 .15182 L
s
.73748 .14594 m
.74107 .15161 L
s
.70044 .14645 m
.70415 .15217 L
s
.66339 .14691 m
.66721 .15281 L
s
.44095 .14622 m
.44534 .15316 L
s
.62635 .14804 m
.63023 .15289 L
s
.18788 .38926 m
.18886 .4304 L
s
.17368 .61272 m
.18087 .59921 L
s
.48223 .15821 m
.48648 .16762 L
s
.58927 .14855 m
.59329 .15437 L
s
.18669 .52408 m
.19239 .52371 L
s
.51506 .15194 m
.51928 .15803 L
s
.5522 .15137 m
.55633 .158 L
s
.47797 .14883 m
.48223 .15821 L
s
.39935 .14023 m
.4039 .14602 L
s
.43652 .14021 m
.44095 .14622 L
s
.73387 .14037 m
.73748 .14594 L
s
.6967 .14054 m
.70044 .14645 L
s
.65954 .14072 m
.66339 .14691 L
s
.24228 .68561 m
.24008 .77229 L
s
.62242 .14241 m
.62635 .14804 L
s
.58525 .14386 m
.58927 .14855 L
s
.47366 .14096 m
.47797 .14883 L
s
.4037 .97 m
.40445 .96566 L
s
.28684 .92681 m
.29652 .86108 L
s
.54804 .14441 m
.5522 .15137 L
s
.51082 .14428 m
.51506 .15194 L
s
.2672 .77352 m
.27882 .6925 L
s
.43205 .13437 m
.43652 .14021 L
s
.73023 .13467 m
.73387 .14037 L
s
.69296 .13487 m
.6967 .14054 L
s
.46931 .13445 m
.47366 .14096 L
s
.6557 .13526 m
.65954 .14072 L
s
.1805 .52837 m
.18669 .52408 L
s
.30942 .32708 m
.31237 .35722 L
s
.61845 .13615 m
.62242 .14241 L
s
.14867 .4066 m
.14558 .47721 L
s
.5812 .13824 m
.58525 .14386 L
s
.31237 .35722 m
.31773 .35504 L
s
.50657 .13613 m
.51082 .14428 L
s
.54387 .13783 m
.54804 .14441 L
s
.42755 .12851 m
.43205 .13437 L
s
.46492 .12849 m
.46931 .13445 L
s
.72656 .12871 m
.73023 .13467 L
s
.68919 .12899 m
.69296 .13487 L
s
.22242 .41275 m
.22428 .4492 L
s
.65185 .12994 m
.6557 .13526 L
s
.50229 .12891 m
.50657 .13613 L
s
.61447 .13034 m
.61845 .13615 L
s
.16567 .63263 m
.17368 .61272 L
s
.53967 .13091 m
.54387 .13783 L
s
.57709 .13158 m
.5812 .13824 L
s
.18886 .4304 m
.19164 .45645 L
s
.46051 .12259 m
.46492 .12849 L
s
.49798 .12261 m
.50229 .12891 L
s
.72286 .12268 m
.72656 .12871 L
s
.25053 .39408 m
.25003 .45821 L
s
.68539 .12301 m
.68919 .12899 L
s
.64796 .12404 m
.65185 .12994 L
s
.61048 .12495 m
.61447 .13034 L
s
.17368 .53749 m
.1805 .52837 L
s
.53546 .12364 m
.53967 .13091 L
s
.57297 .12479 m
.57709 .13158 L
s
.20477 .49258 m
.2089 .50687 L
s
.20031 .48134 m
.20477 .49258 L
s
.2089 .50687 m
.21262 .52521 L
s
.27886 .37431 m
.27845 .44317 L
s
.45607 .11666 m
.46051 .12259 L
s
.49365 .11664 m
.49798 .12261 L
s
.19574 .47105 m
.20031 .48134 L
s
.71916 .11693 m
.72286 .12268 L
s
.6816 .11733 m
.68539 .12301 L
s
.53123 .11686 m
.53546 .12364 L
s
.64402 .11783 m
.64796 .12404 L
s
.19164 .45645 m
.19574 .47105 L
s
.56883 .11805 m
.57297 .12479 L
s
.60645 .11881 m
.61048 .12495 L
s
.21262 .52521 m
.21574 .54967 L
s
.22428 .4492 m
.22599 .48796 L
s
.48929 .11068 m
.49365 .11664 L
s
.52697 .11068 m
.53123 .11686 L
s
.71544 .11102 m
.71916 .11693 L
s
.67778 .11163 m
.6816 .11733 L
s
.64009 .11197 m
.64402 .11783 L
s
.56467 .11126 m
.56883 .11805 L
s
.60239 .11216 m
.60645 .11881 L
s
.21574 .54967 m
.21817 .58146 L
s
.16631 .55065 m
.17368 .53749 L
s
.48491 .10468 m
.48929 .11068 L
s
.52269 .10466 m
.52697 .11068 L
s
.71169 .10499 m
.71544 .11102 L
s
.56049 .10477 m
.56467 .11126 L
s
.15667 .6599 m
.16567 .63263 L
s
.67392 .10556 m
.67778 .11163 L
s
.63613 .10603 m
.64009 .11197 L
s
.5983 .10551 m
.60239 .11216 L
s
.51839 .09863 m
.52269 .10466 L
s
.55629 .09862 m
.56049 .10477 L
s
.70793 .0991 m
.71169 .10499 L
s
.5942 .09894 m
.5983 .10551 L
s
.67003 .0994 m
.67392 .10556 L
s
.63213 .09962 m
.63613 .10603 L
s
.32448 .75003 m
.33278 .6984 L
s
.28445 .50327 m
.29326 .46024 L
s
.21817 .58146 m
.21992 .62086 L
s
.22599 .48796 m
.22697 .53514 L
s
.51407 .09257 m
.51839 .09863 L
s
.55207 .09254 m
.55629 .09862 L
s
.59008 .09259 m
.5942 .09894 L
s
.70414 .09314 m
.70793 .0991 L
s
.66613 .09333 m
.67003 .0994 L
s
.6281 .09306 m
.63213 .09962 L
s
.325 .93854 m
.32532 .91863 L
s
.24008 .77229 m
.23597 .88416 L
s
.14558 .47721 m
.14498 .52978 L
s
.54783 .08645 m
.55207 .09254 L
s
.2854 .93745 m
.28684 .92681 L
s
.58594 .08643 m
.59008 .09259 L
s
.15884 .56378 m
.16631 .55065 L
s
.62406 .0866 m
.6281 .09306 L
s
.70032 .08696 m
.70414 .09314 L
s
.6622 .08706 m
.66613 .09333 L
s
.25003 .45821 m
.2486 .53469 L
s
.31874 .67647 m
.31953 .74545 L
s
.25061 .77587 m
.26764 .63742 L
s
.54356 .08032 m
.54783 .08645 L
s
.58178 .08029 m
.58594 .08643 L
s
.62 .0803 m
.62406 .0866 L
s
.69648 .08074 m
.70032 .08696 L
s
.65824 .0806 m
.6622 .08706 L
s
.27845 .44317 m
.27959 .49554 L
s
.14658 .69523 m
.15667 .6599 L
s
.21992 .62086 m
.22043 .67419 L
s
.5776 .07412 m
.58178 .08029 L
s
.61593 .0741 m
.62 .0803 L
s
.65426 .07419 m
.65824 .0806 L
s
.69262 .07447 m
.69648 .08074 L
s
.25415 .86841 m
.2672 .77352 L
s
.22697 .53514 m
.22673 .59621 L
s
.57339 .06792 m
.5776 .07412 L
s
.61183 .0679 m
.61593 .0741 L
s
.65027 .06789 m
.65426 .07419 L
s
.68872 .06807 m
.69262 .07447 L
s
.15213 .56973 m
.15884 .56378 L
s
.14498 .52978 m
.14724 .56032 L
s
.60771 .06166 m
.61183 .0679 L
s
.64626 .06163 m
.65027 .06789 L
s
.68481 .06168 m
.68872 .06807 L
s
.259 .67555 m
.27284 .57597 L
s
.60357 .05539 m
.60771 .06166 L
s
.64223 .05536 m
.64626 .06163 L
s
.68089 .05534 m
.68481 .06168 L
s
.14724 .56032 m
.15213 .56973 L
s
.27959 .49554 m
.28445 .50327 L
s
.31953 .74545 m
.32448 .75003 L
s
.63817 .04905 m
.64223 .05536 L
s
.67694 .04902 m
.68089 .05534 L
s
.22043 .67419 m
.21862 .75375 L
s
.63409 .0427 m
.63817 .04905 L
s
.67297 .04268 m
.67694 .04902 L
s
.13531 .73874 m
.14658 .69523 L
s
.2486 .53469 m
.24665 .61968 L
s
.66898 .0363 m
.67297 .04268 L
s
.22673 .59621 m
.22491 .67601 L
s
.66497 .02988 m
.66898 .0363 L
s
.23535 .90033 m
.23597 .88416 L
s
.1229 .78993 m
.13531 .73874 L
s
.21464 .85488 m
.21862 .75375 L
s
.25211 .88329 m
.25415 .86841 L
s
.24665 .61968 m
.24605 .6921 L
s
.22491 .67601 m
.2216 .77444 L
s
.24966 .71787 m
.259 .67555 L
s
.24137 .84415 m
.25061 .77587 L
s
.11148 .83888 m
.1229 .78993 L
s
.24605 .6921 m
.24966 .71787 L
s
.2199 .82751 m
.2216 .77444 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.10087 .24033 m
.10595 .24556 L
s
[(0)] .09072 .22988 .97192 1 Mshowa
.26484 .17139 m
.2696 .17691 L
s
[(0.5)] .25533 .16034 .86068 1 Mshowa
.44047 .09754 m
.44484 .10337 L
s
[(1)] .43173 .08588 .74944 1 Mshowa
.62906 .01825 m
.63298 .02439 L
s
[(1.5)] .62122 .00596 .6382 1 Mshowa
.125 Mabswid
.13279 .22691 m
.1358 .23008 L
s
.16514 .21331 m
.16811 .21652 L
s
.19792 .19953 m
.20086 .20277 L
s
.23115 .18555 m
.23405 .18883 L
s
.299 .15703 m
.30181 .16038 L
s
.33363 .14247 m
.33639 .14585 L
s
.36874 .1277 m
.37146 .13113 L
s
.40435 .11273 m
.40703 .11619 L
s
.47711 .08214 m
.47968 .08567 L
s
.51427 .06651 m
.51679 .07008 L
s
.55198 .05066 m
.55444 .05427 L
s
.59024 .03457 m
.59265 .03822 L
s
.66846 .00168 m
.67075 .0054 L
s
gsave
.30907 .06148 -69.9859 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.01178 .81203 m
.01289 .80482 L
s
[(0)] .00955 .82643 .15454 -1 Mshowa
.1225 .88995 m
.12336 .88271 L
s
[(200)] .12079 .90442 .11851 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(400)] .22056 .97437 .08756 -1 Mshowa
.31143 1.0229 m
.31187 1.01563 L
s
[(600)] .31055 1.03745 .0607 -1 Mshowa
.39267 1.08007 m
.39294 1.07279 L
s
[(800)] .39213 1.09464 .03715 -1 Mshowa
.125 Mabswid
.04063 .83233 m
.04126 .82801 L
s
.06868 .85207 m
.06927 .84774 L
s
.09596 .87127 m
.09651 .86693 L
s
.14833 .90812 m
.14881 .90378 L
s
.17348 .92582 m
.17392 .92147 L
s
.19797 .94306 m
.19838 .9387 L
s
.24508 .97621 m
.24543 .97185 L
s
.26775 .99217 m
.26808 .9878 L
s
.28986 1.00772 m
.29016 1.00336 L
s
.33248 1.03771 m
.33271 1.03335 L
s
.35302 1.05217 m
.35323 1.0478 L
s
.37308 1.06628 m
.37326 1.06192 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.312, 287.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005;0001Ib000`400?l00000o`00003ooooooom<
ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<
ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<
ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<
ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<
ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00f_ooool4o`000003oa0@4?oo
oooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0G?ooool00=cooooo00?o
0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0Foooool00=cooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Jooooo`00g?ooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo05_ooooo003Looooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c01Looooo`00g?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05ko
oooo003Looooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0G_ooool00=[ooooo00?o
EEEEofIVI_l000003Oooool4o`0000Wooooo0_l0001Booooo`00m?ooool3o`000003ooooool0003o
oooo057ooooo003booooo`;o00001?ooool2o`00057ooooo003`ooooo`;o00001_ooool00ol0003o
ooooo`00001@ooooo`00kOooool3o`0000Sooooo00?o0000ooooool00000D?ooool009Gooooo0_l0
0002ooooo`03oa0@4?l0003o000004oooooo0ol0000:ooooo`04o`000?ooooooooooo`0004oooooo
002Fooooo`05o`000?ooooook^k^oc8b<_o<c<`0C_ooool2o`0000?ooooo00?o0000ooooooooool0
1oooool01?l0003oooooooooool0001?ooooo`00U_ooool01?l0003oV9RHoc8b<_o<c<a<ooooo`?o
00003oooool01Ol0003ooooooooooooooooo000004kooooo002Fooooo`03o`000?l@413oV9RH04_o
oooo0_l0000@ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool0Boooool009Kooooo
00Co0000onk^k_mEEEGoQhN7B?ooool2o`0001?ooooo00?o0000ooooool000000oooool00ol0003o
ooooooooo`1;ooooo`00U_ooool01Ol0003oooooodA4A?l0003o410@04Cooooo0ol00002ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooool000001?ooool00ol0003oooooooooo`1:ooooo`00
U_ooool00ol0003oooooooooo`14ooooo`;o00003oooool00ol0003oooooooooo`07ooooo`;o0000
1?ooool00ol0003oooooooooo`1:ooooo`00U_ooool00ol0003oooooooooo`12ooooo`;o00004_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0BOoo
ool009Gooooo0_l0000Pooooo`Co000000?o410@ooooooooool06_ooool3o`0001Cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04Sooooo002ioooo
o`03o`000?oooooooooo01[ooooo0_l00002ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`06ooooo`;o00001Oooool00ol0003oooooooooo`18oooo
o`00^Oooool00ol0003oooooooooo`0Gooooo`?o00004_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo04Oooooo002iooooo`03o`00
0?oooooooooo01Gooooo0_l0000Eooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooo`000006ooooo`03o`000?oooooooooo04Kooooo002iooooo`03o`000?oo
oooooooo01?ooooo0_l0000>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0
A_ooool00;Wooooo00?o0000ooooooooool04?ooool3o`0000;ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo04Gooooo002iooooo`03o`000?oo
oooooooo00kooooo0_l0000Dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003ooooo
ooooo`15ooooo`00]oooool00omEEEGoIVIVo`00000>ooooo`;o00003_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`14ooooo`00aOooool3o`00013ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0@oooool00<?ooooo0_l00003oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0@oooool00<7ooooo0_l0000=ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Kooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo04;ooooo002nooooo`?o00003oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`04o`000?oooooooooo
o`0000Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`12ooooo`00_?ooool3o`00
01;ooooo0_l00008ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`06ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`11ooooo`00^_ooool2o`0000?ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000001oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo043ooooo002gooooo`?o00003oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool000001oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo043ooooo002eooooo`;o00004oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Kooooo0_l00008ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0?oooool00;?ooooo0_l000000ooooooo0000ooooo`0:ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0nooooo`00/?ooool3
o`0000oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01_ooool2o`0000Sooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0?_ooool0
07[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM01kooooo0_l0000Cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`05ooooo`;o00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo03gooooo001jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?o
MgMgoc8b<_ooool06_ooool3o`0000gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooo`00
0009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0?Oooool007[ooooo00Go410@
oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo01Oooooo0_l00002ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000009ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0??ooool007[ooooo00Go0000ooooooooooooooooo`00
000?ooooo`03ogMgMolb<S;ooooo01Kooooo0_l0000Cooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00Co
0000oooooooooooo00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03_ooooo
001jooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Co
oooo0ol0000=ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0koooo
o`00N_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool05?ooool2o`00
013ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000002?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03[ooooo001joooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Booooo`;o00000_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0jooooo`00N_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000>ooooo`?o00003Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo0000
1Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
>Oooool009[ooooo0ol0000@ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0hooooo`00VOooool3o`0001;ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooo000000Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Sooooo002Fooooo`?o00003Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool2
o`0000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo03Oooooo002Dooooo`;o00004Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool02?ooool2o`0000Oooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo03Kooooo002Booooo`;o00004oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool2o`0000Oo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Ko
oooo002?ooooo`?o000000?oooooo`000?ooool02_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`;o0000
2?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
=Oooool008gooooo0_l0000Aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=Ooo
ool008[ooooo0ol0000Cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`06ooooo`;o00002?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0dooooo`00R?ooool3o`00
00gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`;o00002?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0<oooool008Ko
oooo0_l0000Aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003o
ooooo`000008ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0cooooo`00Goooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01oooooo0ol0000;ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooo000000Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo03;ooooo001Oooooo`05ogMgMonHV9SooooooiRHV?mgMgL07Oooool2o`0000oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo0ol00008ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool01?l0003o
ooooooooool00008ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0booooo`00Goooool01Ol@413ooooooooooooooooo410@01_ooooo0_l000000ooo
oooo0000ooooo`0?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo0_l00008ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0aooooo`00Goooool01Ol0003ooooooooooooooooo
000001Sooooo0ol0000<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0`ooooo`00Goooool01Ol0003ooooooooooooooooo000001Gooooo0ol0000?
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`;o00002?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo033ooooo001Oooooo`05oa0@4?oooooo
ooooooooool@41005?ooool3o`00017ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo00001Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0_ooooo`00Goooool01OmgMgOoV9RHoooooonHV9SoMgMg017ooooo0ol0000<ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooool000001_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0^ooooo`00Gooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00oooooo0_l0000?ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooool000000_l00007ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1oooool2o`0000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0;_ooool0077ooooo0_l0000Booooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Kooooo00Co0000oooooooooooo00002?ooool3o`0000Sooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1_ooool2o`0000Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0;Oooool006kooooo0ol000000ooooooo0000oooo
o`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo0_l00007ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`;o00001oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0]ooooo`00K?ooool2o`00013ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;?ooool006Wooooo0ol0000;oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:oooool006Oooooo0ol0000=ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool2o`0000Oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool2o`0000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0:oooool006Kooooo00Go0000oooooooooooo
ooooo`00000<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`02ooooo`;o00001oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool2o`0000Sooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:_ooool006Kooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo
00Oo0000ooooooooooooooooo`000?oooooo000000Oooooo00?o0000ooooooooool00_l00008oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000008oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo02[ooooo001Uooooo`?o00003oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Kooooo00Ko0000oooooooooooo0000ooooool00007ooooo`03o`000?oooooo
000000;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00?ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Yooooo`00I_ooool0
0ol0003oooooo`000002ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool01Oooool0
1Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool005_ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`07o`000?ooooooooooooooool0003oooooo`00000;oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000004oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Oooooo0_l00007ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool0
05_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooool000002_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Wooooo`00Foooool01Ol@413ooooooooooooooooo410@00Gooooo00?o
0000ooooooooool00oooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00Co
0000oooooooooooo00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Kooooo
001Kooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooo000000Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo0_l00008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000
1_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`;o00002?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
02Kooooo001Kooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooo000000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooool000001oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooo000000Kooooo00Ko0000oooooooooooo0000ooooool00007ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooo`000006ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool09Oooool005_ooooo00Go410@oooooooooooooooooa0@
4005ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool000001Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000001_ooool01_l0003ooooooooo
ool0003oooooo`0000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`;o
00001_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Gooooo001Kooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo000000Co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Oo
oooo0_l00002ooooo`03o`000?oooooooooo00Kooooo0_l00007ooooo`04o`000?ooooooooooo`00
00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo0_l00007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09?ooool005_o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ool000000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`05ooooo`07o`000?ooooooooooooooool0003oooooo`00
000<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool2o`000003ooooool0
003ooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo02?ooooo001Tooooo`03o`000?oooooooooo00[ooooo00?o0000ooooool000000_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o00000_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0S
ooooo`00I?ooool00ol0003oooooooooo`0;ooooo`05o`000?oooooo0000ooooool000002?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02o`0000;ooooo00?o0000ooooool000000_l000000ooooooo0000ooooo`04
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0R
ooooo`00I?ooool00ol0003oooooooooo`0<ooooo`04o`000?oooooo0000o`0000Sooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo1Ol00003
ooooo`06o`000?ooooooooooo`000?oooooo00001Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00;o00002?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`;o00002?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo02;ooooo001Tooooo`03o`000?oooooooooo00gooooo00?o
0000ooooool000002?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`Co00001oooool00ol0003oooooo`00
0005ooooo`03o`000?oooooooooo00Sooooo0_l00002ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool00oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool08Oooool006Cooooo00?o0000ooooooooool03_ooool3o`0000Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`03ooooo`;o00001Oooool00ol0003oooooooooo`05
ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool01?l0003ooooooooo
ool00008ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08?ooool006?ooooo0_l0
000Aooooo`03o`000?oooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`;o0000
2?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08?ooool006?ooooo
00?o0000ooooooooool04?ooool3o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooo000000Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`;o00002?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool2o`0000Oooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Oooooo`00
Hoooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo000000;o00001?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001Oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool07_ooool006?ooooo00?o0000
ooooooooool04?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00oooool01_l0003o
ooooooooool0003oooooo`0000Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool2o`0000Wooooo00?o0000ooooooooool01?oo
ool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo01kooooo001Sooooo`03o`000?oooooooooo013ooooo00Oo
0000ooooooooooooooooo`000?oooooo000000;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03o`00
00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`04o`000?oooooo0000
o`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`04o`000?oooooo
ooooo`0000Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo01gooooo001Sooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool0
1Ol0003oooooo`000?oooooo000000Oooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00ol00005ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool00_ooool3o`0000Oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo01gooooo001Rooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool00oooool01?l0003oooooo`000?l00007ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`04o`000?oooooo0000o`0000Go
oooo00?o0000ooooooooool00oooool00ol0003oooooo`000002o`0000Gooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`;o00001_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool07?ooool006;ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`04ooooo`?o00001oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01Oooool4o`0000Gooooo00?o0000ooooooooool0
0oooool2o`000003ooooool0003o000000Gooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooo000000Sooooo0_l00005ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooool000002?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool06oooool006;ooooo0_l0000Booooo`03o`000?oooooooooo00Gooooo0_l0
0007ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool00oooool2o`000003ooooool0
003ooooo00Gooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooo000000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01_ooooo001Rooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_oo
ool3o`0000Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Kooooo0ol00006ooooo`03o`000?oooooooooo00;ooooo0_l000000ooooooo0000oooo
o`05ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`0000Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01[ooooo
001Rooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool2o`000003ooooool0
003ooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00ol00006ooooo`03o`000?oooooooooo00?ooooo1?l0
0005ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o0000
1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1?ooool2o`0000Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01[ooooo001Rooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_oo
ool01Ol0003oooooo`000?oooooo000000?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00Ko0000ooooool0003o0000ooooool00006oooo
o`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`03
ooooo`;o00000oooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool2o`0000;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000008
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0I
ooooo`00HOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Kooooo00Ko0000oooo
oooooooo0000ooooool00002ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`?o00000oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Kooooo0_l00005ooooo`03o`000?oooooo000000Oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Sooooo001Qooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool01oooool02Ol0003ooooooooooooooooo0000oooo
ool0003oooooo`000006ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool3
o`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`04o`000?oooooo
ooooo`0000Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000:ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo0_l00007ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool00000
2?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
6?ooool0067ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00;ooooo0_l000000ooooooo0000ooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool3o`0000?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooooooo`;o00002?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`;o00002?ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo01Oooooo001Qooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`?o00001_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo1?l00003ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000oooo
ooooooooooooo`000005ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooo`000004ooooo`;o00001_ooool2o`0000Kooooo0ol00007ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo001P
ooooo`?o00004_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo0_l00006
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool4o`0000?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001Ooo
ool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooo000000;ooooo0_l000000ooooooo0000ooooo`05ooooo`;o0000
2?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Kooooo001Qooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`?o00001?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000000ooo
ool2o`0000Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo
00?o0000ooooooooool00_l00006ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02o`0000?ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000000Cooooo0_l00007ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Eooooo`00?_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool5o`0000Kooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo0_l000000ooo
oooo0000ooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooo`000003ooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000001Oooool00ol0003oooooooooo`02o`0000Kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`02ooooo`;o00002?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`04o`000?oooooo
ooooo`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool05Oooool003kooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A005ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`05ooooo`05o`000?oooooo0000ooooool000000_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooool000000oooool2o`0000Gooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooool000000_l00006
ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00
0007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Oooooo0ol00007ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Cooooo000n
ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Cooooo
00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01Oooool02?l0003oooooooooool0003oooooo`000?oooooo00001_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooo000000?ooooo0ol00004ooooo`04o`000?oooooo
ooooooooo`?o00000oooool00ol0003oooooooooo`03ooooo`Co00001_ooool00ol0003ooooooooo
o`02o`0000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000007ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`00?_ooool0
1Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000005ooooo`03oiRH
V?lQ8B7ok^k^00Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Gooooo00Ko0000ooooooooooooooooo`000?ooool2o`0000Kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooo`000003ooooo`?o00001?ooool01?l0003oooooooooooooool3
o`0000?ooooo00?o0000ooooooooool00oooool4o`0000Oooooo0_l000000ooooooo0000ooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool2o`0000Sooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Cooooo`00?_ooool01Ol0003ooooooooooooooooo
000000_ooooo00Go0000ooooooooooooooooo`000006ooooo`03ogMgMomVIVKooooo00Cooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00_ooool00ol0003oooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooool000000_ooool01?l0003oooooo`000?l00004ooooo`04o`000?ooooooooooooooo`?o
00000oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00001Oooool2o`00
0003ooooool0003ooooo00Cooooo00Oo0000ooooooooooooooooo`000?oooooo000000Sooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo0_l0
0007ooooo`?o00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Booooo`00?_ooool01Ol@413ooooooooooooo
oooo410@00_ooooo00Go410@oooooooooooooooooa0@4007ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00oooool2o`0000Kooooo00Ko0000ooooooooooooooooo`000?ooool2o`00
00;ooooo00Co0000ooooool0003o00001?ooool01ol0003ooooooooooooooooo0000ooooool00000
0oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00002?ooool00ol0003o
ooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool2o`00
00Gooooo00?o0000ooooool000001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Booooo`00?_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05o`000?nj^[[o
oooooiRHV?l@41001?ooool2o`0001Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo0_l00005ooooo`06o`000?ooooooooooooooool0003o
oooo0_l00002ooooo`04o`000?oooooo0000o`0000Cooooo00?o0000ooooooooool00_l000000ooo
oooo0000ooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l00009
ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool04Oooool003kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1?ooool3o`0000Cooooo00Ko0000ooooooooooooooooo`000?ooool2o`0000;ooooo00Co0000oooo
ool0003o00001?ooool00ol0003oooooooooo`02o`000003ooooool0003ooooo00;ooooo00?o0000
ooooool000000oooool01?l0003oooooooooooooool2o`0000Wooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooo`000003ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`06ooooo`;o00002?ooool2o`0000[ooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`04o`000?ooooooooooooooo`?o00004_ooool005oooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`00
0003ooooool0003ooooo00;ooooo00Ko0000ooooooooooooooooo`000?ooool2o`000004ooooool0
003oooooooooo`;o00001Oooool01_l0003oooooo`000?l0003oooooo`0000?ooooo00?o0000oooo
ool000000oooool01?l0003oooooooooooooool2o`0000Sooooo0_l00002ooooo`06o`000?oooooo
ooooo`000?oooooo00000oooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooo
oooo00001oooool00ol0003oooooooooo`07ooooo`?o00001oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo0ol00002ooooo`03o`000?oooooooooo013ooooo001Oooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooool0003oooooo`000002ooooo`06o`000?ooooooooooooooool0003ooooo
0_l000001?oooooo0000ooooooooool2o`0000Gooooo00Ko0000ooooool0003o0000ooooool00004
ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`;o00002?ooool2o`000004ooooool0003o
ooooo`0000;ooooo0_l00003ooooo`03o`000?oooooooooo00;o00001?ooool00ol0003ooooooooo
o`02o`0000Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`04o`00
0?ooooooooooooooo`?o000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0@ooooo`00
Goooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`04ooooo`08o`000?ooooooooooo`000?oooooo0000ooooool00003
ooooo`Co000000?oooooo`000?ooool00ol00005ooooo`06o`000?oooooo0000o`000?oooooo0000
1?ooool2o`0000;ooooo00?o0000ooooooooool00_ooool2o`0000Oooooo0ol000001?oooooo0000
ooooool00002ooooo`;o00001?ooool01?l0003oooooo`000?l00005ooooo`;o000000?oooooo`00
0?ooool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo1?l00008
ooooo`03o`000?oooooooooo013ooooo001Oooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00Ko0000oooo
ooooooooooooo`000?ooool2o`0000?ooooo0ol000001?oooooo0000ooooooooool3o`0000Gooooo
0_l000001?oooooo0000ooooool00004ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`;o
00001oooool2o`000005ooooool0003o0000ooooool000000_ooool2o`0000Cooooo00Go0000oooo
ool0003oooooo`000004ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool000000ol0
0007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00;ooooo1?l0000:ooooo`03o`000?oooooooooo013ooooo001O
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01?l0003oooooo`000?l0
0002ooooo`?o000000Coooooo`000?oooooooooo0ol00002ooooo`03o`000?oooooooooo00?o0000
00?oooooo`000?l000001?ooool2o`0000;ooooo00?o0000ooooooooool00_ooool2o`0000Oooooo
0_l000001Ooooooo0000oooooooooooo000000;ooooo0_l00004ooooo`05o`000?oooooo0000oooo
ool000002?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`Co00003oooool00ol0003oooooooooo`0?ooooo`00G_ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo0_l000000ooooooo0000ooooo`03o`0000Cooooo1?l000001?oooooo
0000ooooooooool4o`0000;ooooo00Co0000oooooooooooooooo0_l00002ooooo`04o`000?oooooo
ooooooooo`?o00001oooool2o`0000Cooooo00?o0000ooooooooool00_l00004ooooo`05o`000?oo
oooo0000ooooool000002?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool3o`0001;ooooo
00?o0000ooooooooool03oooool005kooooo0_l0000Eooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?l00004ooooo`?o000000?oooooo`000?l000000oooool00ol0003oooooo`00
0002ooooo`03o`000?oooooooooo00;o000000Coooooo`000?oooooo00000oooool3o`0000Oooooo
0_l00004ooooo`06o`000?ooooooooooo`000?oooooo00001?ooool2o`000003ooooool0003ooooo
00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01?ooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l000001?oooooo0000o`000?l0000E
ooooo`03o`000?oooooooooo00oooooo001Nooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool2o`000003ooooool0003o000000;o00000oooool01?l0003oooooo`000?l00002
ooooo`07o`000?ooooooooooooooool0003oooooo`000002ooooo`03o`000?oooooooooo00;o0000
00?oooooo`000?l000001?ooool3o`0000Oooooo0_l00005ooooo`;o00000_ooool00ol0003ooooo
ooooo`02ooooo`;o000000?oooooo`000?ooool01oooool01?l0003oooooooooooooool2o`000003
ooooool0003ooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo0ol0000Hooooo`03o`000?oooooooooo00oooooo001Nooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000004o`0000?ooooo
00Co0000ooooool0003o00000_ooool2o`000005ooooool0003oooooooooool000000_ooool00ol0
003oooooooooo`02o`000003ooooool0003o000000Cooooo0ol00006ooooo`04o`000?oooooooooo
o`0000Cooooo0_l00002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool2
o`000003ooooool0003ooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`03o`0000;ooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0?ooooo`00G_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_l000000ooooooo0000ooooo`02ooooo`04o`000?oooooo0000
o`0000;ooooo0_l000001Ooooooo0000oooooooooooo000000;ooooo00Ko0000ooooool0003ooooo
o`000?ooool2o`0000Cooooo0ol00006ooooo`04o`000?ooooooooooo`0000Cooooo0_l00002oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool2o`000003ooooool0003ooooo
00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00?ooooo0_l00007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool3o`00
01kooooo00?o0000ooooooooool03oooool005kooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;o000000?oooooo`000?ooool00_ooool03?l0003o
ooooo`000?l0003oooooo`000?oooooo0000ooooool0003oooooo`0000?ooooo0ol000000ooooooo
0000ooooo`02o`0000Cooooo0ol00006ooooo`04o`000?ooooooooooo`0000Cooooo0_l00002oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01?l0003oooooo`000?l00007
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool01Oooool01?l0003ooooooooooooo
ool3o`000003ooooool0003ooooo01kooooo00?o0000ooooooooool03oooool005kooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Go00000_ooool0
3?l0003oooooo`000?l0003oooooo`000?oooooo0000ooooool0003oooooo`0000?ooooo0_l00002
ooooo`04o`000?oooooo0000o`0000Cooooo0ol00006ooooo`04o`000?ooooooooooo`0000Sooooo
00?o0000ooooooooool01_ooool00ol0003oooooo`000004ooooo`05o`000?ooooooooooooooool0
00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Gooooo0ol0000Uoooo
o`03o`000?oooooooooo00kooooo001Mooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02o`000007ooooool0003oooooo`000?oooooo0000ooooo`02
o`000003ooooool0003ooooo00;o00000_ooool01Ol0003ooooooooooooooooo000000Cooooo0_l0
0005ooooo`?o00001_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool0
00000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo1Ol0000Vooooo`03
o`000?oooooooooo00kooooo001Mooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1Oooool01Ol0003oooooo`000?l0003ooooo00;o000000Koooooo`000?l0003oooooo`000?ooool2
o`000003ooooool0003o000000;ooooo00Go0000ooooooooooooooooo`000004ooooo`;o00001?oo
ool01?l0003oooooooooool00006ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooooooo
ool01_ooool2o`000004ooooool0003oooooo`0000Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo00Gooooo1?l0000[ooooo`03o`000?oooooooooo00kooooo001Moooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool3o`0000;ooooo00?o0000oooo
ool000000_l000000ooooooo0000ooooo`02o`000003ooooool0003ooooo00;ooooo00Go0000oooo
ooooooooooooo`000005ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001_oo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00Kooooo0_l000001?oooooo0000
ooooool00007ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`03oooo
o`Co0000;Oooool00ol0003oooooooooo`0>ooooo`00G?ooool2o`0001Kooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01Oooool3o`0000;ooooo00Go0000oooooooooooo0000ooooo`02o`000005ooooool0003o0000
ooooool000000oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00006ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooooooo
ool01_ooool2o`0000;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00Cooooo1Ol00004ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool03_ooool005go
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`?o00000_ooool00ol0003o
ooooooooo`02o`000003ooooool0003ooooo00;o000000?oooooo`000?ooool00_ooool01Ol0003o
oooooooooooooooo000000Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00005
ooooo`05o`000?ooooooooooooooool000002Oooool01Ol0003ooooooooooooooooo000000?ooooo
00Co0000oooooooooooooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000?ooooo1?l0000coooo
o`03o`000?oooooooooo00kooooo001Mooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01Oooool3o`0000;ooooo00Go0000oooooooooooo0000ooooo`05o`000003ooooool0003ooooo
00;ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00001Oooool01Ol0003ooooooooooooooooo000000Wooooo00Go0000oooooooooooo
ooooo`000003ooooo`;o000000Coooooo`000?oooooo00001oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04o`00
00?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0>ooooo`00G?ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Gooooo0ol00002ooooo`04o`000?ooooooooooo`00
00;ooooo00Ko0000ooooool0003o0000ooooool00003ooooo`05o`000?ooooooooooooooool00000
1Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Gooooo00Go0000oooooooo
ooooooooo`000009ooooo`0<o`000?ooooooooooo`000?oooooo0000ooooool0003oooooo`000?oo
oooo00000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`05ooooo`Co00001Oooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo00kooooo001Looooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01Oooool2o`0000?ooooo00Co0000oooooooooooo00000_ooool4o`000005ooooool0003ooooo
ooooool000001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooool000000_l00004ooooo`05o`000?ooooooooooooooool000002Oooool01Ol0003ooooooooo
ool0003ooooo00;o00000oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooooooo`?o000000Coooooo`00
0?l0003o0000>_ooool00ol0003oooooooooo`0=ooooo`00G?ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Gooooo0_l00003ooooo`06o`000?ooooooooooo`000?oooooo00000_oo
ool01?l0003oooooo`000?l00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool01Ol0003ooooooooooooooooo000000;ooooo0ol00003ooooo`04o`000?oooooooooooooo
o`;o00002?ooool2o`0000;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool4o`0000Kooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`0=ooooo`00G?ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00gooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooo
oooo00Gooooo0_l00003ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00_l00000
1Ooooooo0000oooooooooooo000000Cooooo00?o0000ooooooooool00oooool01Ol0003ooooooooo
oooooooo000000;ooooo0ol00003ooooo`04o`000?ooooooooooooooo`;o00002?ooool2o`0000;o
oooo00?o0000ooooooooool00_l00006ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`04o`0000Wooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`0=ooooo`00G?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00gooooo
00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00Gooooo0_l00003ooooo`03
o`000?oooooo000000;ooooo00Go0000oooooooooooo0000ooooo`03o`000003ooooool0003ooooo
00?ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo1_l00003
ooooo`?o00002?ooool2o`000003ooooool0003ooooo00;ooooo0_l00006ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01Oooool3o`0000Cooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0hooooo`03o`000?oooooooooo00gooooo001Looooo`;o00005_ooool00ol0
003oooooooooo`0=ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`05
ooooo`;o00000oooool00ol0003oooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000ooooool0003o00001?ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool0
00000_ooool3o`0000Kooooo0ol00008ooooo`Co00000_ooool00ol0003oooooo`000007ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool3o`000003ooooool0003ooooo00Co
oooo00Co0000ooooool0003o00001Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
00gooooo001Kooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03Oooool01Ol0003o
oooooooooooooooo000000Gooooo00?o0000ooooooooool01Oooool2o`0000?ooooo00?o0000oooo
ool000000_ooool01?l0003oooooooooool00002ooooo`;o000000?oooooo`000?ooool00oooool0
0ol0003oooooo`000002o`000005ooooool0003oooooooooool000000oooool3o`0000Kooooo0ol0
0007ooooo`03o`000?oooooooooo00;o00000_ooool00ol0003oooooo`000007ooooo`03o`000?oo
oooooooo00Oooooo1?l00004ooooo`03o`000?oooooooooo00Cooooo0_l00006ooooo`03o`000?oo
oooooooo03Sooooo00?o0000ooooooooool03Oooool003Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_l000000ol@413ooooo
ooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03_ooool01?l0003ooooo
ooooool00005ooooo`03o`000?oooooooooo00Gooooo0_l00003ooooo`03o`000?oooooo000000;o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000002o`0000?ooooo00Oo0000oooo
ool0003oooooo`000?oooooo000000;ooooo00Co0000oooooooooooooooo0ol00006ooooo`?o0000
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o000000Goooooo`000?oooooo
ooooo`000007ooooo`03o`000?oooooooooo00Gooooo0ol00007ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00go
oooo0006ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00002?ooool00omgMgOo
IVIVooooo`08ooooo`03ofIVI_mgMgOooooo00Oooooo00?o0000ooooooooool01?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01oooool3
o`0000Cooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00002ooooo`06o`00
0?ooooooooooo`000?oooooo00000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_oo
ool01?l0003oooooooooooooool3o`0000Kooooo00?o0000ooooool000000_ooool01?l0003ooooo
ooooooooool2o`0000;ooooo0_l000001Ooooooo0000oooooooooooo000000Sooooo00Co0000oooo
oooooooooooo0ol00003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo00cooooo0006ooooo`03o`000?oooooooooo
00Sooooo00Co0000oooooooooooo00001oooool00ooMgMgo410@onk^kP09ooooo`03onk^k_l@413o
gMgM00Oooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
410@oooooooooooooooooa0@4003ooooo`Go00001Oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`00
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o00000oooool01?l0
003oooooooooool00002ooooo`0=o`000?oooooo0000ooooool0003oooooo`000?oooooo0000oooo
ool0003oooooo`000002ooooo`;o00001?ooool00ol0003oooooo`000006ooooo`04o`000?oooooo
0000ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o00000oooool00ol0003ooooooooo
o`06ooooo`Co00001oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0>Oooool00ol0003oooooooooo`0<ooooo`001_ooool00ol0003oooooooooo`03
ooooo`06ofIVI_l0003o0000odA4A?o<c<co00000_ooool00ol0003oooooooooo`05ooooo`03oeEE
EOnHV9Sooooo00;ooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`03ohN7QomVIVKooooo00Ko
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oooo
ooooooooooooo`000003ooooo`04odA4A?oMgMgoooooo`0000Kooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo0_l000001Ooooooo0000oooo
oooooooo000000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o0000
0oooool01?l0003oooooo`000?l00002ooooo`03o`000?oooooo000000;ooooo0_l000001_oooooo
0000ooooool0003oooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003oooooo`000006
ooooo`04o`000?oooooo0000ooooo`So000000?oooooo`000?l000001Oooool00ol0003ooooooooo
o`03ooooo`Co00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0>Oooool00ol0003oooooooooo`0<ooooo`001_ooool00ol0003oooooooooo`02
ooooo`06ofIVI_mgMgOooooooooooon7QhOo410@0ol00008ooooo`03o`000?oooooooooo00;ooooo
00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`03onk^k_l0003ooooo00Kooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000003
ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo0_l00002ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool2o`0000Cooooo0_l00003ooooo`04o`000?oooooo0000o`0000;ooooo
00?o0000ooooool000000oooool3o`000004ooooool0003oooooo`0000Sooooo00?o0000ooooool0
00001_ooool:o`0000;ooooo0ol00005ooooo`03o`000?oooooooooo00?o00000oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool000002oooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo00cooooo0006ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool03_ooool00olb<S;oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
41002oooool01Ol@413ooooooooooooooooo410@00Cooooo00?oMgMgolc<c?l000001_ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool01?l0
003oooooooooool00005ooooo`03o`000?oooooooooo00Cooooo0_l00004ooooo`;o00000oooool0
1?l0003oooooo`000?l00002ooooo`03o`000?oooooo000000Cooooo0ol00002ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooool000001Oooool7o`000004ooooool0003o0000o`0000?ooooo
0_l00005ooooo`?o00001_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo
0_l0000;ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool03?ooool000Kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`03oc8b<_oooooooooo00;ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00oo^k^ko
A4A4o`000005ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`07ooooo`;o000000?oooooo`000?ooool01?ooool00ol0003oooooooooo`04ooooo`;o
00001?ooool2o`0000?ooooo00Co0000ooooool0003o00000_ooool00ol0003oooooo`000005oooo
o`?o000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo0000
00Gooooo00?o0000ooooool000000_l00003ooooo`;o00001Oooool00ol0003oooooooooo`04o`00
00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0<ooooo`001_ooool00ol0003o
ooooooooo`02ooooo`06ofIVI_mgMgOooooooooooon7QhOo00002oooool00ol0003ok^k^ooooo`02
ooooo`03o`000?oooooooooo00Gooooo00?ok^k^o`000?ooool01_ooool00ol0003oooooooooo`04
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
00?oMgMgo`000?ooool01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Cooooo
0_l00004ooooo`03o`000?oooooooooo00;ooooo00Co0000ooooool0003o00000_ooool00ol0003o
ooooo`000005ooooo`;o000000?oooooo`000?l000000oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooo000000Gooooo00?o0000ooooool000000_l00003ooooo`;o00001Oooool3o`0000Co
oooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00cooooo0006ooooo`03
o`000?oooooooooo00;ooooo00Kok^k^ofIVI_l0003o0000odA4A?l0000;ooooo`04oeEEEOmgMgOo
oooooa0@40Go00001?ooool00omgMgOoEEEEooooo`06ooooo`03o`000?oooooooooo02Gooooo0_l0
000Hooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ol0003oooooo`00
0005ooooo`03o`000?oooooooooo00Cooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00Co
0000ooooool0003o00000_ooool00ol0003oooooo`000005ooooo`?o000000Coooooo`000?oooooo
oooo0_l00003ooooo`;o000000?oooooo`000?ooool01?ooool00ol0003oooooo`000002o`0000;o
oooo00?o0000ooooool000000_ooool3o`000003ooooool0003ooooo00Cooooo00?o0000oooooooo
ool01_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0jooooo`03o`000?oooooooooo00_ooooo0006ooooo`03o`000?oooooooooo01?o
oooo00?ogMgMoa0@4?o^k^h00_ooool00ol0003oooooooooo`04ooooo`03onk^k_l@413ogMgM00Oo
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool02_ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Co
oooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0_l000001?oooooo0000ooooooooool2o`00
00Kooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00000oooool2o`000003ooooool0003o
oooo00Cooooo00?o0000ooooool000000ol000000ooooooo0000ooooo`03o`0000Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`07ooooo`05o`000?oooooo0000ooooool000001?oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02ooo
ool000Kooooo00?o0000ooooooooool05?ooool01OmgMgOoIVIVoooooooooooo000000Kooooo00?o
IVIVogMgMoooool01oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01Oooooo00Go
0000ooooooooooooooooo`00000=ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`;o00000oooool2o`000004ooooool0003oooooooooo`;o
00001_ooool2o`0000;ooooo00?o0000ooooool000000_l00002ooooo`?o000000?oooooo`000?oo
ool01?ooool00ol0003oooooo`000008o`0000Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`08ooooo`;o000000?oooooo`000?ooool00oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool02oooool005[ooooo00?o0000ooooooooool0
5oooool01?l0003oooooooooool0000>ooooo`?o00001Oooool00ol0003oooooooooo`03ooooo`;o
00001Oooool2o`0000?ooooo0_l000001?oooooo0000ooooooooool2o`0000Kooooo0_l00002oooo
o`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo00?o0000ooooooooool00_ooool2o`00
00;ooooo0ol00003ooooo`;o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool02oooool005Wooooo00?o0000ooooooooool06Oooool00ol0003o
ooooo`00000>ooooo`?o00001Oooool00ol0003oooooooooo`03ooooo`;o00001?ooool00ol0003o
ooooo`000003ooooo`;o000000Coooooo`000?oooooooooo0_l00006ooooo`;o00000_ooool00ol0
003oooooo`000002o`0000;ooooo0_l00002ooooo`03o`000?oooooooooo00;ooooo1_l00004oooo
o`03o`000?oooooo000000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0ioooo
o`03o`000?oooooooooo00_ooooo001Iooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool03Oooool3o`0000Gooooo00?o0000ooooooooool00oooool2o`0000Cooooo00?o0000ooooool0
00000oooool2o`000004ooooool0003oooooooooo`;o00001_ooool2o`0000;ooooo00Oo0000oooo
oooooooo0000ooooool0003ooooo00;o00000_ooool00ol0003oooooooooo`04o`0000;ooooo0_l0
0003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0iooooo`03o`000?oooooooooo00_ooooo001Iooooo`03o`000?oooooooooo02[ooooo0ol0
0005ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03o`000?oooooo000000?ooooo0_l0
00001?oooooo0000ooooooooool2o`0000Kooooo0_l00002ooooo`04o`000?oooooo0000ooooo`Go
00000_ooool3o`0000;ooooo0_l00002ooooo`;o00000oooool01?l0003oooooooooool00005oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0ioooo
o`03o`000?oooooooooo00_ooooo001Iooooo`03o`000?oooooooooo02[ooooo00?o0000ooooool0
00001?ooool00ol0003oooooooooo`04ooooo`;o00001?ooool00ol0003oooooo`000003ooooo`;o
000000Coooooo`000?oooooooooo0_l00006ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool02?l00003ooooo`;o00000_ooool2o`0000?ooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0iooooo`03o`000?oooooooooo00_ooooo001Iooooo`03o`000?oooooooooo02Wooooo1ol00000
0ooooooo0000ooooo`05ooooo`;o00001?ooool00ol0003oooooo`000003ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00Co00000_ooool2o`000004ooooool0003oooooo`0000?ooooo0_l00003ooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo0_l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0jooooo`03o`000?oooooooooo00[ooooo001Hooooo`;o00009Oooool6o`000004
ooooool0003oooooo`0000?ooooo0_l00006ooooo`;o00000oooool01?l0003oooooooooool00003
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01Oooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00;o000000Coooooo`000?oooooooooo1?l000000ooooooo
0000ooooo`02ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool05?ooool3o`0003cooooo00?o0000ooooooooool02_ooool005Sooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000?ooooo0_l00005ooooo`;o
00001?ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool01Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;o000000Co
ooooo`000?oooooooooo0_l00002ooooo`;o00000oooool2o`0000?ooooo00Go0000oooooooooooo
ooooo`000004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo017ooooo0ol00002ooooo`03o`000?oooooooooo03[o
oooo00?o0000ooooooooool02_ooool005Sooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool00oooool2o`0000Cooooo
00Co0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02o`000005ooooool0003o
ooooooooool000000oooool2o`0000?ooooo0_l00003ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
5_ooool3o`0000Kooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0:ooooo`00F?oo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Kooooo00Co0000ooooool0003o0000
0oooool2o`0000Cooooo0_l00004ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool01?l00002ooooo`03o`000?oooooooooo00;o00000oooool01?l0003oooooo`000?l0
0002ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool04oooool3o`0000[ooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`0:ooooo`00F?ooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo00Kooooo00Co0000ooooool0003o00000oooool00ol0003oooooo`000003ooooo`;o0000
1?ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool01Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Co00000_ooool0
0ol0003oooooooooo`02o`0000?ooooo00Co0000ooooool0003o00000_ooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00oooooo1?l0000>ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
2_ooool005Sooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`08ooooo`;o000000Go
ooooo`000?ooooooooooo`000002ooooo`03o`000?oooooooooo00;o00001?ooool01?l0003ooooo
ooooool00002ooooo`;o00000_ooool01?l0003oooooooooool00007ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool01?l000001_oooooo0000o`000?oooooo0000ooooo`;o0000
0_ooool01_l0003oooooooooool0003oooooo`0000Gooooo00Go0000ooooooooooooooooo`000007
ooooo`05o`000?ooooooooooooooool000003_ooool3o`0001?ooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`0:ooooo`00F?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo00Sooooo0_l000001Ooooooo0000oooooooooooo000000?ooooo1?l00004ooooo`04o`000?oo
ooooooooo`0000;ooooo0_l00002ooooo`04o`000?oooooo0000o`0000Oooooo00Ko0000oooooooo
oooo0000ooooool00003ooooo`Co000000Koooooo`000?l0003oooooo`000?ooool2o`0000;ooooo
00Ko0000oooooooooooo0000ooooool00005ooooo`05o`000?ooooooooooooooool000001oooool0
1Ol0003ooooooooooooooooo000000_ooooo0ol0000Fooooo`03o`000?oooooooooo03Oooooo00?o
0000ooooooooool02Oooool005Sooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`09
ooooo`;o00000_ooool00ol0003oooooo`000004ooooo`?o00000oooool01Ol0003ooooooooooooo
oooo000000;ooooo0_l00002ooooo`04o`000?oooooo0000o`0000Oooooo00Ko0000oooooooooooo
0000ooooool00004ooooo`Co000000?oooooo`000?ooool00_l000001Ooooooo0000oooooooooooo
000000;ooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`Co00006_ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo00Wooooo001Gooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool02Oooool2o`0000;ooooo00?o0000ooooool000001?ooool00ol0003oooooo`000004
o`0000?ooooo00?o0000ooooooooool00_l00002ooooo`04o`000?oooooo0000o`0000Oooooo00Ko
0000oooooooooooo0000ooooool00003ooooo`Go000000Ooooooo`000?l0003oooooo`000?oooooo
000000;ooooo00?o0000ooooooooool00ol00005ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Cooooo0ol0000Oooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool02Oooool005Oooooo0_l0000Qooooo`03o`000?oooooo
oooo00[ooooo0_l00002ooooo`03o`000?oooooo000000Cooooo00?o0000ooooool000000_ooool2
o`0000?ooooo00Co0000oooooooooooo00000oooool01?l0003oooooo`000?l00007ooooo`06o`00
0?ooooooooooo`000?oooooo00000oooool5o`000007ooooool0003oooooooooool0003oooooo`00
0002ooooo`03o`000?oooooooooo00?o00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo0_l00002ooooo`03o`000?oooooo000000;o00008oooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo00Wooooo001Gooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool02_ooool2o`0000?ooooo0_l00004ooooo`;o00001?ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Ko0000ooooooooooooooooo`000?ooool2o`0000Kooooo0_l00002ooooo`03
o`000?oooooo000000?ooooo0_l000001Ooooooo0000o`000?oooooo000000;ooooo00?o0000oooo
ool000000_ooool00ol0003oooooooooo`03o`0000Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`;o000000Coooooo`000?l0003o00009oooool00ol0003oooooooooo`0c
ooooo`03o`000?oooooooooo00Wooooo001Gooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool02_ooool2o`0000?ooooo0_l00004ooooo`;o00001?ooool2o`0000;ooooo00Co0000oooo
ool0003o00000oooool01?l0003oooooo`000?l00006ooooo`;o00000_ooool00ol0003oooooo`00
0003ooooo`;o000000Goooooo`000?ooooooooooo`000002ooooo`03o`000?oooooo000000;ooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool5o`0002Wooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`09ooooo`00
Eoooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00_ooooo0_l00003ooooo`;o0000
1?ooool2o`0000Cooooo0_l00002ooooo`04o`000?oooooo0000o`0000?ooooo00Co0000ooooool0
003o00001_ooool2o`0000;ooooo00?o0000ooooool000000oooool2o`000007ooooool0003ooooo
ooooool0003oooooo`000003ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o000000?oooooo`000?ooool00_l0
000Zooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool02Oooool005Oooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0;ooooo`;o00000oooool2o`0000Cooooo0_l00004
ooooo`03o`000?oooooo000000;ooooo0ol00003ooooo`04o`000?oooooo0000o`0000Kooooo0_l0
0002ooooo`03o`000?oooooo000000?ooooo0_l000001ooooooo0000oooooooooooo0000ooooool0
00000oooool2o`0000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`?o
00001?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool02Oooool005Kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0<ooooo`;o0000
0oooool2o`0000?ooooo00?o0000ooooool000000oooool01_l0003ooooooooooooooooo0000oooo
o`?o00000oooool2o`000003ooooool0003ooooo00Gooooo0_l00002ooooo`03o`000?oooooo0000
00?ooooo0_l000001ooooooo0000oooooooooooo0000ooooool000000oooool2o`0000Gooooo00?o
0000ooooooooool00oooool6o`0000Gooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo00Sooooo001Fooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool03?ooool2o`0000?ooooo0_l00003ooooo`03o`000?oooooo000000?ooooo00?o0000
ooooooooool00_ooool5o`0000;ooooo0_l000000ooooooo0000ooooo`05ooooo`;o00000_ooool0
0ol0003oooooo`000003ooooo`;o000000Ooooooo`000?ooooooooooo`000?oooooo000000?ooooo
0_l00005ooooo`04o`000?ooooooooooooooo`?o00001?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`00
E_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00cooooo0_l00003ooooo`;o0000
0oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Gooooo00Co0000ooooool0003o
oooo0_l000000ooooooo0000ooooo`05ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`06
o`000?ooooooooooo`000?oooooo00000oooool2o`0000Gooooo1?l00002ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool02?ooool005Kooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`0=ooooo`;o00000oooool2o`0000?ooooo0_l00004ooooo`03o`000?oooooooooo
00Gooooo00Co0000ooooool0003ooooo0_l000000ooooooo0000ooooo`05ooooo`;o00000_ooool2
o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`03o`000?oooooo000000?ooooo0_l00003
ooooo`Go00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Sooooo001Foooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool03Oooool2o`0000?ooooo0_l00003oooo
o`;o00001?ooool00ol0003oooooooooo`05ooooo`04o`000?oooooo0000ooooo`;o000000?ooooo
o`000?ooool01Oooool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2
o`0000Cooooo1Ol00002ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`08ooooo`00EOooool3o`0001oooooo00?o0000ooooooooool03Oooool2o`00
00?ooooo0_l00003ooooo`;o00000oooool00ol0003oooooooooo`06ooooo`04o`000?oooooo0000
ooooo`;o000000?oooooo`000?ooool01Oooool2o`0000;ooooo0_l00003ooooo`;o000000?ooooo
o`000?l000000_ooool2o`0000;ooooo1?l00007ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`08ooooo`00<oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?l@413oc<c<00Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0>ooooo`;o0000
0oooool2o`0000;ooooo00?o0000ooooool000000oooool00ol0003oooooooooo`06ooooo`04o`00
0?oooooo0000ooooo`;o000000?oooooo`000?ooool01?ooool00ol0003oooooo`000002ooooo`;o
00000oooool2o`000003ooooool0003o000000;ooooo1?l00002ooooo`;o00001oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool02?ooool003?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoEEEEogMgMoooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool03_ooool2o`0000?ooooo0_l00002ooooo`03o`000?oooooo000000?ooooo00?o0000
ooooooooool01_ooool01?l0003oooooo`000?ooool2o`000003ooooool0003ooooo00Cooooo00?o
0000ooooool000000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000004o`0000Cooooo0_l0
0007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`07ooooo`00<oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooooooo
oa0@4003ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo00kooooo0_l00003ooooo`;o00000_ooool00ol0003oooooo`000003ooooo`03
o`000?oooooooooo00Kooooo00Co0000ooooool0003ooooo0_l000000ooooooo0000ooooo`04oooo
o`03o`000?oooooo000000;ooooo0_l00003ooooo`Go00000_ooool2o`0000Cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool01oooool003?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003oV9RHoooooonHV9So8B4Q00Gooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0?ooooo`;o00000oooool2o`0000;ooooo00?o0000ooooool000000ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?o000000?oooooo`000?ooool01?oo
ool00ol0003oooooo`000002ooooo`;o000000?oooooo`000?l000000ol000001?oooooo0000oooo
ooooool2o`0000Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool01oooool003?ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003oEEEEo`000?l@413oc<c<
00Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0?ooooo`;o00000oooool2o`00
00;ooooo0_l00004ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_l00002oooo
o`03o`000?oooooooooo00;ooooo1?l00002ooooo`?o000000?oooooo`000?ooool00_l000001?oo
oooo0000ooooooooool2o`0000Cooooo0_l00007ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool0:_ooool00ol0003oooooooooo`07ooooo`00<oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oeEEEOn7QhOooooo00Oooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0?ooooo`;o00000oooool2o`0000;ooooo0_l0
0003ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_l00002ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooool000001Ol00002ooooo`06o`000?oooooo0000o`000?oooooo
00000_ooool2o`0000Cooooo0_l00008ooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`07ooooo`00<oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`03omgMgOl@413oV9RH00Oooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0@ooooo`;o00000oooool2o`000004ooooool0003oooooo`0000?ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`02o`0000;ooooo00Co0000oooooooooooooooo
1Ol00002ooooo`;o00000_ooool01_l0003oooooo`000?l0003oooooo`0000;ooooo00?o0000oooo
ooooool00oooool2o`0000Sooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo00Oooooo000cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Cooooo00Coc<c<odA4A?l0003o410@1?ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo013ooooo0_l00003ooooo`;o000000Coooooo`000?oooooo00000oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00;o00000_ooool4o`000005ooooool0003ooooooooo
ool000000_ooool01_l0003ooooooooooooooooo0000ooooo`;o000000Goooooo`000?oooooooooo
o`000005ooooo`;o00002?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooo
ooooooooo`00000kooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01oooool005Co
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0@ooooo`;o00000oooool2o`000004
ooooool0003oooooo`0000?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05o`00
00;ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooo
000000;ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`000007ooooo`05o`000?oo
ooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`07ooooo`00E?ooool2o`0001kooooo00?o0000ooooooooool0
4?ooool2o`0000?ooooo0_l000001?oooooo0000ooooool00003ooooo`03o`000?oooooooooo00Oo
oooo1Ol00003ooooo`;o000000?oooooo`000?ooool00_ooool01?l0003oooooooooool00003oooo
o`03o`000?oooooo000000;ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`000007
ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000003gooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`06ooooo`00E?ooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo017ooooo0_l00003ooooo`06o`000?oooooo0000o`000?oooooo
00000oooool00ol0003oooooooooo`05ooooo`?o00000oooool00ol0003oooooooooo`02o`0000;o
oooo00Go0000ooooooooooooooooo`000002ooooo`07o`000?ooooooooooooooool0003oooooo`00
0002ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001_ooool01Ol0003o
oooooooooooooooo000000Gooooo00Co0000oooooooooooo0000?_ooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo00Kooooo001Dooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool04Oooool2o`0000?ooooo00Go0000ooooool0003oooooo`000003ooooo`03o`000?oooooo
oooo00?ooooo0ol00002ooooo`09o`000?ooooooooooooooool0003oooooo`000?oooooo000000;o
oooo00Go0000ooooooooooooooooo`000002ooooo`07o`000?ooooooooooooooool0003oooooo`00
0002ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001_ooool01Ol0003o
oooooooooooooooo000000Gooooo00Co0000oooooooooooo0000?_ooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo00Kooooo001Dooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool04Oooool2o`0000?ooooo00Go0000ooooool0003oooooo`000003ooooo`03o`000?oooooo
000000?o00001_ooool02_l0003oooooo`000?l0003oooooo`000?oooooo0000ooooool00004oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooool000000oooool00ol0003oooooo`000005
ooooo`04o`000?ooooooooooo`0000Kooooo00Go0000ooooooooooooooooo`000005ooooo`04o`00
0?ooooooooooo`0003oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`06ooooo`00
Doooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo017ooooo00?o0000ooooool00000
0oooool01Ol0003oooooo`000?oooooo000000;ooooo0ol0000:ooooo`03o`000?oooooo000000;o
00000_ooool00ol0003oooooo`000004ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ool000000oooool3o`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00010ooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool01_ooool005?ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooooooo
0ol000000ooooooo0000ooooo`0:ooooo`04o`000?oooooo0000o`0000?ooooo00?o0000ooooool0
00001?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo0ol00004
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooo
oooooooo000000Gooooo00Co0000oooooooooooo0000@Oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00Kooooo001Cooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
4Oooool2o`0000Cooooo1Ol00003ooooo`03o`000?oooooooooo00Wooooo00Co0000ooooool0003o
00001?ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
ool0003o00000oooool3o`0000Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003oooooooooool00012ooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool01_ooool005?ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Aooooo`;o000000?oooooo`000?l000000_l00003ooooo`05o`00
0?ooooooooooooooool000002oooool01?l0003oooooo`000?l00004ooooo`03o`000?oooooooooo
00?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooo`000?l00003ooooo`?o00001?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000?ooooo00Go0000oooooooooooooooo
o`000005ooooo`04o`000?ooooooooooo`0004;ooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`05ooooo`00Doooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01;ooooo
0ol00003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`09ooooo`04
o`000?oooooo0000o`0000[ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooo`000?l0
0003ooooo`?o00001?ooool00ol0003oooooooooo`03ooooo`;o00000oooool01Ol0003ooooooooo
oooooooo000000Gooooo00Co0000oooooooooooo0000@oooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo00Gooooo001Cooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
3oooool5o`0000Cooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0:ooooo`04
o`000?oooooo0000o`0000[ooooo00Co0000ooooool0003o00000_ooool01?l0003oooooo`000?l0
0003ooooo`?o00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooo000004Cooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`05ooooo`00D_ooool2o`0001gooooo00?o0000ooooooooool03?oo
ool3o`0000?ooooo0_l00004ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
2_ooool4o`0000[ooooo00Co0000ooooool0003o00000_ooool2o`000003ooooool0003ooooo00;o
oooo0ol00004ooooo`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooo000004Gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`05oooo
o`00D_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Sooooo1?l00006ooooo`;o
00001?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00[ooooo1?l0000:oooo
o`04o`000?oooooo0000o`0000;ooooo00Co0000oooooooooooo00000oooool3o`0000Cooooo00?o
0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool00000
A_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Gooooo001Booooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool01_ooool3o`0000[ooooo0_l00004ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool02oooool3o`0000[ooooo00Co0000ooooool0003o
00000_ooool01?l0003oooooooooool00003ooooo`?o00001?ooool00ol0003oooooooooo`08oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`000016ooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool01Oooool005;ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`03ooooo`?o00003Oooool2o`0000Cooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooooooo`0;ooooo`?o00002_ooool4o`000003ooooool0003o000000;ooooo00Co0000
oooooooooooooooo0ol00003ooooo`03o`000?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooo000004Oooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`05ooooo`00D_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo000000?o00004?oo
ool2o`0000Cooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0:ooooo`04o`00
0?oooooo0000o`0000[ooooo1_l00003ooooo`07o`000?ooooooooooooooool0003oooooo`000003
ooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooo000004Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`05ooooo`00D_ooool0
0ol0003oooooooooo`0Jooooo`?o00005?ooool2o`0000Cooooo00Co0000oooooooooooo00000ooo
ool00ol0003oooooooooo`0:ooooo`04o`000?oooooo0000o`0000[ooooo1_l00003ooooo`04o`00
0?ooooooooooooooo`?o00000oooool00ol0003oooooooooo`09ooooo`05o`000?oooooooooooooo
ool000001oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool01?ooool005;ooooo00?o0000ooooooooool05oooool4o`0001Kooooo0_l00004ooooo`03
o`000?oooooo000000?ooooo00?o0000ooooooooool02oooool01?l0003oooooo`000?l0000:oooo
o`;o000000Coooooo`000?l0003o00000oooool01?l0003oooooooooooooool3o`0000?ooooo00?o
0000ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool0
BOooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Cooooo001Aooooo`03o`000?oo
oooooooo01Gooooo0ol00003ooooo`03o`000?oooooooooo01Cooooo0_l00004ooooo`03o`000?oo
oooo000000?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02o`0000[ooooo0_l0
00001?oooooo0000o`000?l00003ooooo`04o`000?ooooooooooooooo`?o00000oooool00ol0003o
ooooooooo`09ooooo`05o`000?ooooooooooooooool00000E?ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo00Cooooo001Aooooo`03o`000?oooooooooo017ooooo1?l00006ooooo`03
o`000?oooooooooo01Cooooo0_l00004ooooo`03o`000?oooooo000000?ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`02o`0000_ooooo00Go0000ooooool0003oooooo`000002oooo
o`03o`000?oooooooooo00;ooooo0_l000001Ooooooo0000oooooooooooo000000cooooo00Co0000
oooooooooooo0000E?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo001A
ooooo`03o`000?oooooooooo00kooooo0ol0000:ooooo`03o`000?oooooooooo01Cooooo0_l00004
ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02
o`0000_ooooo00Co0000ooooool0003o00000oooool00ol0003oooooooooo`02ooooo`;o000000Co
ooooo`000?oooooo00003Oooool01?l0003oooooooooool0001Eooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool01?ooool0057ooooo00?o0000ooooooooool02oooool3o`0000gooooo
00?o0000ooooooooool05?ooool2o`0000Cooooo00?o0000ooooool000000oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00;o00003?ooool3o`0000?ooooo00?o0000ooooooooool0
0_ooool2o`000004ooooool0003oooooo`0000gooooo00Co0000oooooooooooo0000E_ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo00Cooooo001@ooooo`;o00002Oooool4o`0000oo
oooo00?o0000ooooooooool05Oooool2o`0000Cooooo00?o0000ooooool000000oooool00ol0003o
ooooooooo`09ooooo`04o`000?ooooooooooooooo`;o00003?ooool3o`0000?ooooo00?o0000oooo
ooooool00_ooool2o`000004ooooool0003oooooo`0000?ooooo00?o0000ooooooooool01oooool0
1?l0003oooooooooool0001Gooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01?oo
ool0057ooooo00?o0000ooooooooool01?ooool3o`0001?ooooo00?o0000ooooooooool05Oooool2
o`0000Cooooo00?o0000ooooool000000oooool00ol0003oooooooooo`09ooooo`04o`000?oooooo
ooooooooo`;o00003?ooool3o`0000?ooooo00?o0000ooooooooool00_ooool2o`000004ooooool0
003oooooo`0000?ooooo00?o0000ooooooooool01oooool01?l0003oooooooooool0001Hooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool00oooool0053ooooo00?o0000ooooooooool0
0_ooool3o`0001Kooooo00?o0000ooooooooool05Oooool2o`0000Cooooo0_l00003ooooo`03o`00
0?oooooooooo00[ooooo00Oo0000ooooooooooooooooo`000?oooooo000000_ooooo0_l00004oooo
o`03o`000?oooooooooo00;ooooo00Ko0000ooooool0003o0000ooooool00002ooooo`03o`000?oo
oooooooo00Sooooo00Co0000oooooooooooo0000F?ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo00?ooooo001@ooooo`03o`000?oooooo000000;o00006Oooool00ol0003ooooooooo
o`0Eooooo`;o00001?ooool2o`0000?ooooo00?o0000ooooooooool02_ooool01ol0003ooooooooo
oooooooo0000ooooool000003?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000000_ooool2o`000005ooooool0003oooooooooool000002_ooool01?l0003oooooooooool0
001Iooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00oooool0053ooooo0_l0000K
ooooo`03o`000?oooooooooo01Kooooo0_l00004ooooo`;o00000oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000002oooool2o`0000Cooooo00Go0000
ooooooooooooooooo`000002ooooo`?o00000_ooool00ol0003oooooooooo`09ooooo`04o`000?oo
ooooooooo`0005[ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`03ooooo`00D_oo
ool2o`0001Wooooo00?o0000ooooooooool05Oooool00ol0003oooooo`000004ooooo`;o00000ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000002ooo
ool2o`0000Cooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooo0000ooooool0
00003?ooool01?l0003oooooooooool0001Kooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool00oooool005?ooooo0_l0000Hooooo`03o`000?oooooooooo01Gooooo00?o0000ooooool0
00001?ooool2o`0000?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooo000000_ooooo0_l00004ooooo`05o`000?ooooooooooooooool000000oooool3o`00
00gooooo00Co0000oooooooooooo0000G?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00?ooooo001Booooo`04o`000?ooooooooooo`0001Oooooo00?o0000ooooooooool05Oooool0
0ol0003oooooo`000004ooooo`;o00000oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooool000002oooool2o`0000Cooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo00cooooo00Co0000oooooooooooo0000G?ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo00?ooooo001Fooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool05_ooool00ol0003oooooo`000004ooooo`;o00000oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000002oooool2o`0000Cooooo00Go
0000ooooooooooooooooo`00000Cooooo`04o`000?ooooooooooo`0005gooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`02ooooo`00Eoooool2o`0001?ooooo00?o0000ooooooooool0
5_ooool00ol0003oooooo`000004ooooo`;o00000oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooool000002oooool2o`0000Cooooo00Co0000oooooooooooo
00005?ooool01?l0003oooooooooool0001Nooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool00_ooool005Wooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooo000000Cooooo0_l00002ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool00oooool00ol0003oooooo`00000:ooooo`03o`000?oooooo000000Cooooo00Co0000oooooooo
oooo00005?ooool01Ol0003ooooooooooooooooo000005kooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`02ooooo`00F_ooool2o`00013ooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooo000000[ooooo00?o0000ooooool000001?ooool01?l0003oooooooooool0
000Dooooo`05o`000?ooooooooooooooool00000Goooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo00;ooooo001Jooooo`03o`000?oooooo000000kooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`03ooooo`;o00000oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooool000002_ooool00ol0003oooooo`000004ooooo`04o`000?oo
ooooooooo`0001Cooooo00Go0000ooooooooooooooooo`00001Oooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool00_ooool005gooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01?ooool00ol0003oooooo`00000:ooooo`03o`000?oooooo000000Cooooo
00Co0000oooooooooooo00005?ooool01Ol0003ooooooooooooooooo0000063ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`02ooooo`00C_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo0_l0000Uooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000009ooooo`04o`000?oooooooooo
o`0000Cooooo00Co0000oooooooooooo00005?ooool01Ol0003ooooooooooooooooo0000067ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`00C_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00gooooo0_l0000Sooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000009ooooo`04o`00
0?ooooooooooo`0000Cooooo00Co0000oooooooooooo00005?ooool01Ol0003ooooooooooooooooo
000006;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`00C_ooool01Ol@
413ooooooooooooooooo410@00kooooo0_l0000Rooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooool000002Oooool01?l0003oooooooooool00004ooooo`04o`000?ooooooooooo`0001Cooooo
00Go0000ooooooooooooooooo`00001Sooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool00Oooool004kooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooo0000027o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00009ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooool000005Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool0GOooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo007ooooo001>
ooooo`05o`000?ooooooooooooooool000004Oooool00ol0003oooooooooo`0Tooooo`05o`000?oo
ooooooooooooool000002_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Wo
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooo`00000Eooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool00Oooool004kooooo00Go410@oooooooooooooooooa0@400Booooo`;o00009?ooool0
1Ol0003ooooooooooooooooo000000[ooooo00?o0000ooooooooool01?ooool01?l0003ooooooooo
ool00009ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooool000005Oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo007ooooo001>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05?ooool2o`00
02;ooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo00Cooooo00Co0000
oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooool00000
5Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0H?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo007ooooo001>ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h05Oooool2o`00027ooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo
00Cooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o
0000ooooool000005Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
HOooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo007ooooo001Zooooo`03o`000?oo
oooooooo01kooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo00Cooooo
00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ool000005Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0HOooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo007ooooo001[ooooo`03o`000?oooooooooo
01gooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooool00000
5Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0H_ooool00ol0003o
ooooooooo`0:ooooo`7o00000Oooool1ooooo`00K?ooool3o`0001cooooo00Go0000oooooooooooo
ooooo`000009ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00002?ooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ooooool000005Oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`09ooooo`7o00000Ooo
ool1ooooo`00K_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool01Oooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooo`00000Eooooo`05o`000?ooooooooooooooool000000_ooool00ol0003o
ooooooooo`1Uooooo`03o`000?oooooooooo00Sooooo0Ol00001ooooo`7ooooo001^ooooo`?o0000
6_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00002?ooool01Ol0003ooooooooooooooooo000000Cooooo0_l0000Fooooo`05o`000?oooooooooo
ooooool000000_ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo00Oooooo0Ol00001
ooooo`7ooooo001aooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`00
0004ooooo`;o00005oooool01ol0003ooooooooooooooooo0000ooooool00000J?ooool00ol0003o
ooooooooo`07ooooo`7o00000Oooool1ooooo`00L_ooool2o`0001Kooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`;o00005oooool01ol0003ooooooooooooooooo0000
ooooool00000JOooool00ol0003oooooooooo`06ooooo`7o00000Oooool1ooooo`00M?ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool01?l0
003oooooooooool00007ooooo`03o`000?oooooooooo00;ooooo00Oo0000ooooooooooooooooo`00
0?oooooo000001Oooooo00Oo0000ooooooooooooooooo`000?oooooo000006[ooooo00?o0000oooo
ooooool01Oooool1o`00007ooooo0Oooool007Gooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`06ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool00_ooool01ol0
003ooooooooooooooooo0000ooooool000005oooool01ol0003ooooooooooooooooo0000ooooool0
0000Joooool00ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`00MOooool3o`00023ooooo
00?o0000ooooooooool01_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooooooo0_l0000Hooooo`07o`000?ooooooooooooooool0003oooooo`00
001/ooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`00N?ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo00001oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooooooo`;o00006?ooool01ol0003ooooooooooooooooo0000oooo
ool00000K?ooool00ol0003oooooooooo`04ooooo`7o00000Oooool007Wooooo0_l0000Looooo`03
o`000?oooooooooo00Oooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`03oooo
o`04o`000?ooooooooooooooo`;o00006?ooool01ol0003ooooooooooooooooo0000ooooool00000
KOooool00ol0003oooooooooo`03ooooo`7o00000Oooool0067ooooo1Ol00003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooo
ooooool00oooool01?l0003oooooooooooooool2o`0001Sooooo00Oo0000ooooooooooooooooo`00
0?oooooo000006kooooo00?o0000ooooooooool00_ooool1o`00007ooooo001Qooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o00006_ooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooo
o`0000Kooooo00?o0000ooooooooool00oooool01?l0003oooooooooooooool2o`0001Sooooo00Oo
0000ooooooooooooooooo`000?oooooo000006oooooo00Go0000ooooooooooooooooo`000001oooo
o`00H_ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@00Oooooo0_l0000Hooooo`03o`000?oooooooooo00Oooooo00Co0000
oooooooooooo00001_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o0000
6?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06oooooo00Co0000oooooooooooo
00000Oooool006?ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool01oooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00?ooooo00Co0000
oooooooooooooooo0_l0000Hooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Kooo
ool01?l0003oooooooooool00001ooooo`00I?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000[ooooo0_l0000Eooooo`03
o`000?oooooooooo00Oooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`03oooo
o`04o`000?ooooooooooooooo`;o00006?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo073ooooo00?o0000ooooooooool00Ol0000006Gooooo00Go0000oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`09ooooo`;o00008Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo
0_l0000Hooooo`03o`000?oooooooooo07Kooooo0Ol00001ooooo`7o0000001Qooooo`05o`000?nj
^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0=ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`05o`000?ooooooooooooooool000006Oooool00ol0003oooooooooo`1g
ooooo`;o0000001Qooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`;o00007_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000Iooooo`03
o`000?oooooooooo07Kooooo0ol0000008Kooooo0_l0000Looooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000001Wooooo00?o0000oooooooo
ool0LOooool5o`0000?ooooo0027ooooo`;o00006oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000Iooooo`03o`000?oooooooooo06go
oooo1?l00008ooooo`00Qoooool00ol0003oooooo`00000Jooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo06Wooooo
1?l0000<ooooo`00R_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo06Cooooo1Ol0
000@ooooo`00Roooool2o`0001Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo063ooooo1?l0000Eooooo`00SOooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo05_ooooo1Ol0000Iooooo`00SOooool3o`0001Cooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0Eoooool4o`0001kooooo002@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
D_ooool5o`0002;ooooo002Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0C_oo
ool4o`0002Oooooo001mooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo0_l0000@ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
04[ooooo1?l0000[ooooo`00O_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0_l0000?ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo04Gooooo1Ol0000_ooooo`00Noooool5o`0000?ooooo00Go410@oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@41001Oooool2o`0000gooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0@Ooo
ool4o`0003Cooooo001kooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000001oooool2o`0000_ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0??ooool5o`0003Sooooo001kooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool2o`0000[ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0>?ooool4o`0003gooooo001looooo`03ogMgMoo<c<co000000Cooooo00Go410@oooo
oooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooo`00
000Jooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0dooooo`Co0000@Oooool007cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02oooooo
1Ol00015ooooo`00OOooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo0ol0000Fooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0[ooooo`Co0000B_ooool009kooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool09_ooool5o`0004kooooo002Oooooo`;o00004oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool08_ooool4o`0005?ooooo002Q
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo01kooooo1?l0001Gooooo`00X_ooool2o`00013ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Wooooo1Ol0001Koooo
o`00Xoooool2o`0000oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo01Gooooo1?l0001Pooooo`00YOooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0@ooooo`Go0000
I?ooool00:Kooooo0_l0000<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0<ooooo`Co0000JOooool00:Sooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01oooool5
o`0006gooooo002Booooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Kok^k^oc8b<_l0003o<S8bonk^k_ooool2o`0000[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00?ooooo1?l0001booooo`00
T_ooool01OmEEEGoMgMgoooooonHV9So8B4Q00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool2o`0000Sooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Eooooo`Co0000M_ooool009;ooooo00Go0000ooooooooooooooooo`000003
ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo
0_l00006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool5o`0007[ooooo
0023ooooo`05oiRHV?l0003o0000odA4A?nj^[X02_ooool01Ol0003oV9RHoooooonHV9So8B4Q00?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool2
o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`Co0000Ooooool0
08?ooooo00Go410@okZj^_o^k^koMgMgoa0@400:ooooo`05o`000?mEEEGo0000oa0@4?o<c<`00ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool5o`0008?ooooo0023ooooo`03o`00
0?oooooooooo00cooooo00?oEEEEohN7Qoooool01Oooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@4009ooooo`05o`000?oooooo0000ooooool000002_ooool4
o`0008Sooooo0023ooooo`03o`000?oooooooooo00cooooo00?ogMgMoa0@4?nHV9P01Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0:ooooo`;o000000?o
ooooo`000?ooool01Oooool4o`0008cooooo0023ooooo`03o`000?oooooooooo00gooooo00Coc<c<
odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`?o000000?oooooo`000?l000000ol0002@ooooo`00POooool00ol@413o0000
o`000003o`0002gooooo0_l0002Eooooo`00Poooool00ol0003oooooooooo`35ooooo`00Poooool0
0ol0003oooooooooo`35ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00Y_oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h0T?ooool00:Kooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg093ooooo002V
ooooo`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooooooooa0@402@ooooo`00Y_ooool01Olb<S;oV9RHoooooonHV9So<S8b00?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000T?ooool0
0:Kooooo00Goc<c<o`000?l0003o0000olc<c003ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo0000093ooooo002Vooooo`05oa0@4?nj^[[ooooookZj^_l@4100
0oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@402@oooo
o`00Y_ooool01Ol0003o^[Zjoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0T?ooool00:Kooooo00GoZJVYoa0@4?l0003o410@ojVY
Z@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^093o
oooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodco
oooo003oooooodcooooo003oooooodcooooo003;ooooo`04oa0@4?l0003o0000o`0007cooooo003<
ooooo`03o`000?oooooooooo07cooooo003<ooooo`03o`000?oooooooooo07cooooo002Nooooo`05
o`000?o<c<cogMgMo`000?o^k^h00_ooool01_nHV9So0000o`000?mgMgOo410@o`0000Cooooo00?o
8B4Qoc8b<_ooool00oooool01_o^k^koEEEEo`000?l0003oA4A4okZj^PSooooo00Ko410@oc8b<_l0
003o0000oa0@4?nYZJT3ooooo`09o`000?mgMgOo0000o`000?mEEEGok^k^ooooooo^k^koEEEE00;o
000000?oA4A4okZj^_ooool00_ooool01OmVIVKo0000o`000?m4A4Coc<c<00?ooooo00OoV9RHo`00
0?l0003oA4A4okZj^_oooooo410@00Go00001?ooool01_nHV9So0000o`000?mgMgOo0000oa0@40;o
00000_ooool01Ol0003oooooooooool0003o410@04Sooooo002Mooooo`06ojVYZOl0003oQhN7oiRH
V?l0003oV9RH0_ooool01Ol0003oc<c<onk^k_n7QhOo000000Cooooo00CoV9RHoc8b<_l@413o^[Zj
0oooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40Sooooo00Ko0000ojVYZOoooooooooookZj^_l0
0003ooooo`0=o`000?mEEEGok^k^oooooomgMgOoEEEEoooooomEEEGoMgMgooooooo^k^koMgMgoa0@
4002ooooo`06ofIVI_mgMgOooooooooooon7QhOo410@0oooool01Ol@413o^[Zjonk^k_mgMgOo410@
00?ooooo00?o0000ooooooooool01Oooool01Ol0003oZJVYoooooon7QhOo000000;ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`17ooooo`00WOooool01_mEEEGoQhN7odA4A?mE
EEGoMgMgoeEEE@;ooooo00Go410@ohN7Qoooooook^k^o`000004ooooo`04oa0@4?nj^[[oV9RHoc8b
<P?ooooo00?o0000ooooooooool03?ooool01Onj^[[oQhN7ofIVI_mVIVKo410@00?ooooo00?o0000
onk^k_ooool00_ooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo04Oooooo002Mooooo`06o`000?oM
gMgoA4A4ob4Q8Oo^k^ko00000_ooool00onj^[[o410@o`000002o`0000?ooooo00KoV9RHoc8b<_oo
oooooooooa0@4?nj^[X2ooooo`Ko00002?ooool01_lb<S;o8B4QogMgMomgMgOoQhN7onk^kP?ooooo
00?o0000onk^k_ooool00_ooool00ol0003oooooo`000005o`0000;ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooooooo
ooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0Aoooool009co
oooo00SoZJVYob4Q8OooooooQhN7oeEEEOoooooo<S8bojVYZ@Cooooo00Ooc<c<o`000?oooooooooo
onk^k_l0003ogMgM00;ooooo00[oV9RHoc8b<_oooooooooooeEEEOn7QhOok^k^oooooon7QhOo<S8b
2?ooool01_l0003o^[Zjooooooo^k^koMgMgo`0000?ooooo00go0000oeEEEOo^k^koooooogMgMomV
IVKooooooeEEEOn7QhOok^k^oooooon7QhOo<S8b00;ooooo00KoIVIVogMgMoooooooooooohN7Qol0
0003ooooo`03o`000?oooooooooo00Gooooo00?o0000oc8b<_oMgMd01Oooool01Ol0003ooooooooo
oooooooo000000;ooooo00Oo0000olc<c?o<c<co0000ojVYZOoMgMgo8B4Q04Wooooo002Looooo`?o
00000_ooool3o`0000;ooooo00Co<S8bo`000?l0003oV9RH0_ooool00ol@413o0000o`000002oooo
o`?o000000?oooooonk^k_mEEED00_l000000om4A4Cok^k^ooooo`07ooooo`06ojVYZOlQ8B7o0000
o`000?lb<S;o00000_ooool00ol@413o0000ogMgM`02o`000005ofIVI_o^k^koooooonk^k_mEEED0
0_l000001_m4A4Cok^k^ooooooooooook^k^ofIVIP;o000000CoA4A4o`000?oooooo410@1Ol00003
ooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q0_ooool01?l@413o0000ooooooooool2o`000009oooo
ool@413o0000ob4Q8Ol0003oMgMgoa0@4?l0003oZJVY04Wooooo003Tooooo`03o`000?oooooooooo
06Cooooo003Tooooo`03o`000?oooooooooo06Cooooo003oooooodcooooo003oooooodcooooo003o
ooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003o
ooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003o
ooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003o
ooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003o
ooooodcooooo003oooooodcooooo0000\
\>"],
  ImageRangeCache->{{{0, 330.625}, {358.875, 0}} -> {-0.225172, -0.107519, \
0.00427749, 0.00427749}}]
}, Open  ]],

Cell[TextData[{
  "Evidently the cascade to large wavenumbers has been suppressed by the \
dispersive term in the ",
  "KdV",
  " equation. Modes in the upper half of the spectral range have negligible \
amplitude. This implies that our cutoff of the spectrum at ",
  Cell[BoxData[
      \(TraditionalForm\`n = \(\[PlusMinus]M\)\)]],
  " does not affect the result. This can be verified by taking larger (or \
somewhat smaller) values of ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  ": the answer does not change. "
}], "Text"],

Cell[TextData[{
  "\tThus, when dispersion is added in the KdV equation, wavebreaking no \
longer occurs.  Is this due to the relatively small amplitude of the  wave \
chosen in the above example? The answer is no - even for large amplitudes, \
the wavebreaking is suppressed. However, it is harder to see this \
numerically, because more  modes must be kept, making the problem somewhat \
harder to integrate.  In Fig. ",
  ButtonBox["7.7",
    ButtonData:>"Fig. 7.7",
    ButtonStyle->"Hyperlink"],
  ", we show an example of a sinusoidal initial condition with eight times \
the previous amplitude. The solution still breaks up into solitons, and the \
spectrum (Fig. ",
  ButtonBox["7.8",
    ButtonData:>"Fig. 7.8",
    ButtonStyle->"Hyperlink"],
  ") still remains peaked in the lower half of the spectral range."
}], "Text"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
147.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .10301 m
.00123 .10301 L
.00236 .10302 L
.00365 .10303 L
.00488 .10305 L
.00706 .10311 L
.00942 .10319 L
.01203 .1033 L
.01479 .10345 L
.01975 .1038 L
.02486 .10426 L
.02966 .10479 L
.04057 .10633 L
.0517 .10839 L
.06188 .11069 L
.08481 .11729 L
.1265 .13387 L
.16661 .15447 L
.20928 .17995 L
.25037 .20625 L
.29403 .23415 L
.3361 .25906 L
.37658 .27957 L
.3971 .28823 L
.41963 .29616 L
.44107 .30204 L
.45066 .30411 L
.46109 .30595 L
.46679 .30678 L
.47207 .30743 L
.47701 .30794 L
.48246 .30839 L
.48481 .30855 L
.48734 .30869 L
.48952 .30879 L
.49191 .30888 L
.49446 .30895 L
.49585 .30898 L
.49715 .309 L
.49836 .30901 L
.49947 .30902 L
.50074 .30902 L
.50195 .30901 L
.50316 .309 L
.50446 .30898 L
.50569 .30895 L
.50681 .30892 L
.50955 .30883 L
.51216 .30872 L
.51733 .30841 L
Mistroke
.52296 .30795 L
.53302 .30681 L
.54234 .30539 L
.56393 .30082 L
.58348 .29517 L
.6256 .27857 L
.66614 .25781 L
.70924 .2321 L
.75076 .20552 L
.79069 .17996 L
.83319 .15459 L
.8741 .13359 L
.89494 .12465 L
.91758 .11651 L
.93935 .11039 L
.94974 .1081 L
.95947 .10633 L
.96875 .10498 L
.97875 .10392 L
.98416 .10352 L
.98687 .10336 L
.98984 .10322 L
.99239 .10312 L
.99381 .10308 L
.99511 .10305 L
.99632 .10303 L
.99763 .10302 L
.99886 .10301 L
1 .10301 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
01Kooooo3?l0002:ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0002Aooooo`co00004oooool002;o
oooo1ol00024ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0Roooool6o`0001oo
oooo000Yooooo`?o0000P_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08Oooooo
1?l0000Uooooo`00;?ooool4o`0007[ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`00
0?oooooooooo08Cooooo0ol0000Yooooo`00<?ooool3o`0007Oooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c006ooooo`03o`000?oooooooooo083ooooo1?l0000/ooooo`00<oooool3o`0007oooooo00?o
0000ooooooooool0OOooool3o`00033ooooo000fooooo`?o0000O?ooool00ol0003oooooooooo`1j
ooooo`?o0000<oooool003Wooooo0_l0001jooooo`03o`000?oooooooooo07Oooooo0ol0000foooo
o`00>oooool3o`0007Oooooo0_l0001fooooo`;o0000>Oooool003kooooo0_l0001eooooo`03o`00
0?oooooooooo07?ooooo0_l0000kooooo`00@?ooool2o`0007?ooooo00?o0000ooooooooool0LOoo
ool2o`0003gooooo0012ooooo`;o0000LOooool00ol0003oooooooooo`1_ooooo`;o0000?oooool0
04Cooooo0_l0001_ooooo`03o`000?oooooooooo06gooooo0_l00011ooooo`00A_ooool00ol0003o
ooooooooo`1/ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0@Oooool004Oooooo
0_l0001/ooooo`03o`000?oooooooooo06[ooooo0_l00014ooooo`00BOooool2o`0006[ooooo00?o
0000ooooooooool0J?ooool2o`0004Kooooo001;ooooo`;o0000J?ooool2o`0006Oooooo0_l00018
ooooo`00COooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo0_l0001:oooo
o`00C_ooool2o`0006Gooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`1:ooooo`00
5Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00GoV9RH
oa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02Oooool2o`00013ooooo
1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool4o`000008oa0@4?ooooooooooonk^
k_lb<S;o0000oc8b<_o^k^hNooooo`03o`000?oooooooooo01oooooo1?l000002?l@413ooooooooo
ooo^k^ko<S8bo`000?lb<S;ok^k^6_ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0?
ooooo`;o00002_ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0Mooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h03_ooool0
01Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00Go410@
okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0003ooooo
ooooo`0=ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
01kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0=ooooo`;o
00003?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0N
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`002oooool6
o`0000;ooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41004_ooool6o`0000Kooooo00Go
0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00[ooooo0_l00005ooooo`Ko0000
0oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41004oooool6o`0000Go
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01kooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41006oooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41002oooool2o`0001;ooooo00Go
0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01Wooooo1Ol00003ooooo`05oa0@
4?ooooooooooooooool@41003_ooool001?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003o
oooooooooooooooo000001gooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo
000000kooooo0_l0000=ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00
000Nooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Nooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001co
oooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000oooo
ooooool04Oooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000006oooool0
1?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool001?ooooo00Co
gMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000001cooooo00?o410@o`000?nj
^[X00oooool01Ol0003ooooooooooooooooo0000013ooooo00?o0000ooooooooool02oooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03ogMgMomVIVKooooo00;ooooo
00Go0000ooooooooooooooooo`000008ooooo`;o00004oooool00ol@413o0000okZj^P03ooooo`05
o`000?ooooooooooooooool000006oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?oooooo
ooooooooool000003_ooool001Cooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooo
oooo410@01gooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@017ooooo
0_l0000<ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Looooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Nooooo`;o00008_ooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41007_ooool01Ol0003ooooooooooooo
oooo410@00?ooooo00?o410@ooooooooool01?ooool2o`0001Kooooo00?o^[Zjob4Q8Oooool00_oo
ool01Ol@413ooooooooooooooooo410@01cooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooo
oooooooooooo410@00kooooo000Dooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Jooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9So
MgMg01?ooooo00?o0000ooooooooool01Oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Nooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg01[ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0Cooooo`05oa0@4?nHV9SooooookZj^_l00000
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg01cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00kooooo000Eooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0Jooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^01Cooooo0_l00005ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01kooooo00?o0000ooooooooool07oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h06_ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`;o00005_ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0Mooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>
ooooo`00GOooool2o`0005Kooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`1Ioooo
o`00Goooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo05;ooooo0_l0001Looooo`00
H?ooool2o`0005?ooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`1Looooo`00H_oo
ool2o`00057ooooo00?o0000ooooooooool0Coooool2o`0005oooooo001Tooooo`03o`000?oooooo
oooo04kooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`1Oooooo`005_ooooooo`00
043o00004oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo000Fooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00_l00003ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooooooo`;o
000000?oooooo`000?ooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`00J_ooool00ol0003ooooo
ooooo`18ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0IOooool006_ooooo0_l0
0018ooooo`03o`000?oooooooooo04Kooooo0_l0001Xooooo`00KOooool2o`0004Kooooo00?o0000
ooooooooool0A?ooool2o`0006[ooooo001_ooooo`03o`000?oooooooooo04?ooooo00?o0000oooo
ooooool0@oooool00ol0003oooooooooo`1Zooooo`00L?ooool2o`0004?ooooo00?o0000oooooooo
ool0@Oooool2o`0006gooooo001booooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0
@?ooool00ol0003oooooooooo`1]ooooo`00Loooool2o`00043ooooo0_l0000oooooo`;o0000L?oo
ool007Gooooo0_l0000nooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0L?ooool0
07Oooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0kooooo`;o0000Loooool007So
oooo0_l0000kooooo`03o`000?oooooooooo03Wooooo0_l0001eooooo`00N_ooool2o`0003Wooooo
00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1eooooo`00O?ooool2o`0003Oooooo00?o
0000ooooooooool0=_ooool2o`0007Sooooo001nooooo`03o`000?oooooooooo03Cooooo00?o0000
ooooooooool0=?ooool2o`0007[ooooo001oooooo`;o0000=?ooool00ol0003oooooooooo`0coooo
o`03o`000?oooooooooo07[ooooo0021ooooo`;o0000<_ooool2o`0003;ooooo0_l0001mooooo`00
Poooool2o`00033ooooo00?o0000ooooooooool0;oooool2o`0007oooooo0025ooooo`;o0000;_oo
ool00ol0003oooooooooo`0]ooooo`;o0000POooool008Oooooo0_l0000/ooooo`03o`000?oooooo
oooo02[ooooo0ol00023ooooo`00ROooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
02Sooooo0_l00026ooooo`00R_ooool2o`0002Wooooo00?o0000ooooooooool09_ooool2o`0008So
oooo002<ooooo`;o00009oooool00ol0003oooooooooo`0Tooooo`;o0000R_ooool008kooooo0_l0
000Uooooo`03o`000?oooooooooo027ooooo0ol0002<ooooo`00T?ooool2o`0002?ooooo0_l0000P
ooooo`;o0000Soooool009;ooooo0_l0000Qooooo`03o`000?oooooooooo01gooooo0_l0002Aoooo
o`00U?ooool3o`0001kooooo00?o0000ooooooooool06_ooool3o`0009?ooooo002Gooooo`?o0000
6oooool00ol0003oooooooooo`0Hooooo`;o0000U_ooool009[ooooo1?l0000Gooooo`03o`000?oo
oooooooo01Kooooo0_l0002Hooooo`00W_ooool3o`0001Cooooo00?o0000ooooooooool04oooool3
o`0009[ooooo002Qooooo`Co00001Oooool5o`0000Kooooo00?o0000ooooooooool03_ooool5o`00
09gooooo002Uooooo`Oo000000?ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`06ooooo`So
0000X_ooool00:_ooooo00?oV9RHo`000?l000004?l0002Zooooo`00[?ooool00onHV9So8B4Qonk^
kP06ooooo`03o`000?oooooooooo0;3ooooo002]ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000
ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2`oooo
o`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0/?ooool00:[o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002/ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`2`oooo
o`00[Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go0000
1_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01?m4A4CogMgMooooool00007ooooo`?o0000
/?ooool00:[ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`2`ooooo`00Zooo
ool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03onk^k_m4A4Co
000000Oooooo00?o0000ooooooooool0/?ooool00:cooooo00?oMgMgo`000?ooool01_ooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00Z_ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[o
oooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003o
V9RHoooooonHV9So8B4Q00Kooooo0ol0002`ooooo`00Z_ooool01Ol0003oEEEEo`000?l@413oc<c<
00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00?oEEEEohN7Qoooool02?ooool00ol0003o
ooooooooo`2`ooooo`00Z_ooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo0;3ooooo
002[ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo00Goc<c<ob4Q8Ol0003o8B4Q
olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40
1_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0/?ooool00:[ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000
/?ooool00:[ooooo00Goc<c<o`000?l0003o0000olc<c02iooooo`00Z_ooool01Ol@413o^[Zjoooo
oonj^[[o410@0;Wooooo002Zooooo`05o`000?nj^[[ooooookZj^_l00000^Oooool00:[ooooo00Go
ZJVYoa0@4?l0003o410@ojVYZ@2iooooo`00oooooomYooooo`00]oooool00ol0003o^[Zjooooo`2^
ooooo`00]oooool2oc8b<Zoooooo0028ooooo`;o000000Ko410@oooooooooooo410@o`000?l@410H
ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP20ooooo`00ROooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oo
oooo1_l0000=ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?o
c<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00009ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0P?ooool008Wooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Kooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool04?ooool00ol0003o
ooooooooo`0Jooooo`05oa0@4?ooooooooooooooool@4100P?ooool008Wooooo00Ko0000oooooom4
A4CoA4A4ooooool00009ooooo`Ko00003Oooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`Ko00002Oooool01Ol0003ooooooooo
oooooooo0000083ooooo0029ooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo00006Oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooo
oooo01[ooooo00Go0000ooooooooooooooooo`000020ooooo`00ROooool01_l0003oQhN7ojVYZOnj
^[[oEEEEo`0001Wooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@013o
oooo00?o410@o`000?l000000ol0000Iooooo`05oa0@4?ooooooooooooooool@4100P?ooool008Wo
oooo00Ko0000oc8b<_oooooooooooc8b<_l0000Iooooo`03o`000?oooooooooo00Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0Booooo`03o`000?oooooooooo01[ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`20ooooo`00R?ooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo1?l0
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Jooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0P?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
147.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .10766 m
.04057 .11701 L
.08481 .13144 L
.12636 .14794 L
.16632 .1657 L
.20885 .1859 L
.2498 .20596 L
.29331 .22728 L
.33524 .24715 L
.37557 .26501 L
.41848 .28189 L
.4598 .29523 L
.48055 .30052 L
.49953 .30438 L
.50927 .30596 L
.51991 .30734 L
.52574 .30793 L
.53115 .30837 L
.53632 .3087 L
.53921 .30884 L
.54183 .30893 L
.54427 .309 L
.54566 .30903 L
.54695 .30905 L
.54831 .30906 L
.54956 .30906 L
.55025 .30906 L
.551 .30906 L
.55236 .30905 L
.55352 .30904 L
.5548 .30902 L
.55613 .30898 L
.55739 .30895 L
.55963 .30887 L
.56204 .30876 L
.5676 .30841 L
.57344 .30788 L
.57844 .30731 L
.5839 .30655 L
.59469 .30461 L
.60449 .30233 L
.62649 .29526 L
.64663 .2863 L
.66847 .27378 L
.71144 .24113 L
.75281 .2031 L
.79259 .16705 L
.81472 .14956 L
.83495 .13592 L
.8561 .12428 L
Mistroke
.87571 .11591 L
.89569 .10968 L
.90623 .10727 L
.91208 .10618 L
.91746 .10533 L
.92263 .10465 L
.92829 .10404 L
.93398 .10359 L
.93709 .1034 L
.93999 .10326 L
.94131 .10321 L
.94274 .10316 L
.944 .10312 L
.94534 .1031 L
.94655 .10308 L
.94788 .10306 L
.94909 .10305 L
.95022 .10305 L
.95156 .10306 L
.95224 .10306 L
.95298 .10307 L
.95428 .10309 L
.9555 .10311 L
.95825 .10319 L
.96118 .1033 L
.96617 .10357 L
.97077 .1039 L
.98116 .10491 L
.99032 .10611 L
1 .10766 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`00087ooooo6?l0000Gooooo`005_ooool3o`0009Co
oooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`1mooooo`Co00006?ooool4o`0001?o
oooo000Iooooo`Go0000T?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07Wooooo
1?l0000cooooo`007_ooool4o`0008Sooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`00
0?oooooooooo07Kooooo0ol0000gooooo`008_ooool3o`0008Gooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c006ooooo`03o`000?oooooooooo07?ooooo0ol0000jooooo`009Oooool3o`0008gooooo00?o
0000ooooooooool0L?ooool3o`0003gooooo000Xooooo`?o0000R_ooool00ol0003oooooooooo`1]
ooooo`?o0000@?ooool002_ooooo0ol00027ooooo`03o`000?oooooooooo06cooooo00?o0000oooo
ooooool0@Oooool002kooooo0ol00024ooooo`;o0000Joooool2o`0004Cooooo000aooooo`;o0000
P_ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo04Cooooo000cooooo`?o0000Oooo
ool00ol0003oooooooooo`1Wooooo`;o0000Aoooool003Kooooo0ol0001looooo`03o`000?oooooo
oooo06Gooooo0_l00019ooooo`00>Oooool2o`0007[ooooo00?o0000ooooooooool0I?ooool00ol0
003oooooooooo`19ooooo`00>oooool3o`0007Oooooo00?o0000ooooooooool0H_ooool2o`0004co
oooo000nooooo`;o0000MOooool00ol0003oooooooooo`1Pooooo`;o0000C_ooool0043ooooo0_l0
001cooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0C_ooool004;ooooo0_l0001a
ooooo`;o0000Goooool00ol0003oooooooooo`1?ooooo`00A?ooool3o`0006kooooo00?o0000oooo
ooooool0GOooool00ol0003oooooooooo`1@ooooo`00Aoooool2o`0006cooooo00?o0000oooooooo
ool0G?ooool00ol0003oooooooooo`1Aooooo`005Oooool2o`000009oa0@4?ooooooooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^01[ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00_ooool2o`0001Oooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h07?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hNooooo`03o`000?oo
oooooooo01oooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^6_ooool5o`00
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP09ooooo`03o`000?oooooooooo00oooooo00GoV9RH
oa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Oooool2o`000009oa0@
4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Fooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05oa0@4?nj^[[oooooogMgMolb<S800ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo0_l0000Eooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`;o00004_ooool01Ol@413o^[ZjoooooomgMgOo<S8b
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0>ooooo`002oooool6o`0000;ooooo1Ol00003ooooo`05oa0@4?oooooo
ooooooooool@41004_ooool6o`0000Kooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@
4?oooooooooo00Cooooo0_l0000;ooooo`Ko00000oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41004oooool6o`0000Gooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@01kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41006oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?oooooo
ooooooooool@41001_ooool00ol0003oooooooooo`0Fooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Iooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00ko
oooo000Cooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000Moooo
o`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000008ooooo`;o00004oooool0
0onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Looooo`03oiRHV?lQ8B7ok^k^00?o
oooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo01Kooooo00?oZJVYoa0@
4?ooool00_ooool01Ol0003ooooooooooooooooo000001_ooooo00CoA4A4omgMgOoooooo00001?oo
ool01Ol0003ooooooooooooooooo000000kooooo000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo
00Go0000ooooooooooooooooo`00000Looooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000oooooooo
ooooooooo`00000:ooooo`?o00004Oooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooooooo
ooooool000007_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007_oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Mooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo01Kooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo0000
01_ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000kooooo000D
ooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@400Mooooo`03okZj^_lQ
8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@400=ooooo`;o00004?ooool01Ol0003ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool07?ooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41007_ooool2o`0002;ooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@01kooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?oo
ooooooooooooool000006_ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@
41007?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41003_ooool001Co
oooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00Go410@oiRH
V?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03oooool2o`0000[ooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05o`000?nj^[[o
oooooiRHV?l@41000oooool01_mgMgOoV9RHoooooonHV9SoMgMgooooo`;o00006?ooool01Ol@413o
V9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`03onk^k_m4A4Co
000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`005Oooool00omgMgOo0000ooooo`03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06_ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Aooooo`;o00002?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Looooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0Nooooo`03o`000?oooooooooo01oooooo00?oEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`06
onk^k_lb<S;o0000oc8b<_o^k^ko00006_ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0Mooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0>ooooo`00F_ooool2o`0005Wooooo00?o0000ooooooooool0DOooool00ol0003ooooo
ooooo`1Looooo`00G?ooool2o`0005Oooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`1Mooooo`00G_ooool3o`0005Cooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`1N
ooooo`00HOooool2o`0005;ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`1Ooooo
o`00Hoooool2o`00053ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`1Pooooo`00
5_ooooooo`00043o00004oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01?l0003oooooo`00
0?l00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00?ooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo
000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooooooo0_l00002ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`00Jooo
ool2o`0004Sooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`1Tooooo`00KOooool2
o`0004Kooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`1Uooooo`00Koooool2o`00
04Cooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1Vooooo`00LOooool2o`0004;o
oooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`1Wooooo`00Loooool2o`00043ooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`1Xooooo`00MOooool2o`0003kooooo00?o
0000ooooooooool0A?ooool00ol0003oooooooooo`1Yooooo`00Moooool2o`0003cooooo0_l00014
ooooo`03o`000?oooooooooo06[ooooo001iooooo`?o0000>Oooool00ol0003oooooooooo`12oooo
o`03o`000?oooooooooo06_ooooo001looooo`;o0000=oooool00ol0003oooooooooo`11ooooo`03
o`000?oooooooooo06cooooo001nooooo`;o0000=Oooool00ol0003oooooooooo`0oooooo`;o0000
Koooool0083ooooo0_l0000cooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0Kooo
ool008;ooooo0_l0000aooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0L?ooool0
08Cooooo0_l0000_ooooo`03o`000?oooooooooo03_ooooo0_l0001cooooo`00Q_ooool3o`0002co
oooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`1cooooo`00ROooool2o`0002[ooooo
0_l0000jooooo`03o`000?oooooooooo07Cooooo002;ooooo`;o0000:?ooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo07Gooooo002=ooooo`;o00009_ooool00ol0003oooooooooo`0f
ooooo`;o0000N?ooool008oooooo0ol0000Sooooo`03o`000?oooooooooo03Gooooo00?o0000oooo
ooooool0N?ooool009;ooooo0ol0000Pooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0NOooool009Gooooo0ol0000Mooooo`03o`000?oooooooooo03;ooooo0_l0001looooo`00V?oo
ool3o`0001[ooooo00?o0000ooooooooool0<?ooool2o`0007kooooo002Kooooo`;o00006?ooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo07kooooo002Mooooo`?o00005Oooool2o`00
02kooooo0_l00021ooooo`00X?ooool3o`0001;ooooo00?o0000ooooooooool0:oooool2o`0008?o
oooo002Sooooo`;o00004?ooool00ol0003oooooooooo`0Xooooo`?o0000QOooool00:Gooooo0ol0
000=ooooo`03o`000?oooooooooo02Kooooo0_l00028ooooo`00Z?ooool5o`0000Sooooo00?o0000
ooooooooool08oooool3o`0008[ooooo002]ooooo`Go00000oooool00ol0003oooooooooo`0Poooo
o`?o0000SOooool00:[ooooo1Ol00003ooooo`Co00007oooool3o`00093ooooo002Zooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01_ooool6o`0001Cooooo1_l0002Cooooo`00Zoooool00onHV9So8B4Q
onk^kP07ooooo`?o00000ooooolDo`0009Wooooo002/ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o
0000ooooooooool0/?ooool00:gooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`2`
ooooo`00[_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05
o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OnHV9So
410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0:cooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0;3ooooo002]ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool00:[ooooo1Ol00006ooooo`03o`00
0?oooooooooo0;3ooooo002Zooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_oo
ool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<
c<co000000Oooooo00?o0000ooooooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool0
0ol0003oooooooooo`2`ooooo`00[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05
onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OmEEEGo
MgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?nHV9SooooooiRH
V?lQ8B401_ooool3o`000;3ooooo002Zooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0
003oooooooooo`2`ooooo`00Z_ooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo0;3o
oooo002Zooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0/?ooool00:_ooooo00Co
c<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo
00?o0000ooooooooool0/?ooool00:[ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`00
0?oooooooooo0;3ooooo002Zooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0002`ooooo`00Z_oo
ool01Oo<c<co0000o`000?l0003oc<c<0;Wooooo002Zooooo`05oa0@4?nj^[[ooooookZj^_l@4100
^Oooool00:[ooooo00Go0000okZj^_oooooo^[Zjo`00002iooooo`00Z_ooool01OnYZJWo410@o`00
0?l@413oZJVY0;Wooooo003oooooofWooooo002gooooo`03o`000?nj^[[ooooo0:kooooo002goooo
o`;o<S8b[oooool008Sooooo0_l000001_l@413oooooooooool@413o0000oa0@41Sooooo00GoA4A4
o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOo0000
okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool5o`00083ooooo0029ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`0000gooooo00WoMgMgoc8b<_oooooo
ooooogMgMonHV9SooooooiRHV?mgMgL00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[o
k^k^ogMgMol@41002Oooool6o`0000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A020ooooo`00ROoo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo410@
0oooool00ol@413oooooooooo`0@ooooo`03o`000?oooooooooo01_ooooo00?oV9RHob4Q8Oo^k^h0
POooool008Wooooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00003Oooool01OmgMgOo
<S8boooooooooooo000000?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;oooo
o`Ko00002oooool00onHV9So8B4Qonk^kP20ooooo`00ROooool01_l0003ogMgMoc8b<_mEEEGogMgM
o`0001Wooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool00000
4_ooool00ol0003oooooooooo`0Mooooo`03ogMgMomVIVKooooo07oooooo0029ooooo`06o`000?n7
QhOoZJVYokZj^_mEEEGo00006Oooool00ol0003oooooooooo`04ooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol@413o0000o`000003o`0001gooooo00?o0000ooooooooool0O_ooool008Wo
oooo00Ko0000oc8b<_oooooooooooc8b<_l0000Iooooo`03o`000?oooooooooo00Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0Booooo`03o`000?oooooooooo01[ooooo00Go0000okZj^_ooooooV9RH
oa0@4020ooooo`00R?ooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo1?l0
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Jooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`0P?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
147.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .11772 m
.04057 .12901 L
.08481 .14333 L
.12636 .15812 L
.16632 .17317 L
.20885 .18976 L
.2498 .20599 L
.29331 .22324 L
.33524 .23957 L
.37557 .25475 L
.41848 .26997 L
.4598 .2833 L
.49953 .29439 L
.52162 .29957 L
.54183 .30354 L
.55181 .30518 L
.5627 .30669 L
.57299 .30783 L
.57796 .30827 L
.58254 .3086 L
.58787 .3089 L
.59068 .30902 L
.5921 .30907 L
.59364 .30912 L
.59499 .30915 L
.59621 .30917 L
.59745 .30919 L
.59862 .3092 L
.59998 .30921 L
.60124 .3092 L
.60262 .3092 L
.60332 .30919 L
.60409 .30918 L
.60532 .30916 L
.60662 .30912 L
.60894 .30905 L
.61144 .30895 L
.61417 .3088 L
.61907 .30844 L
.62363 .30799 L
.62893 .30734 L
.63468 .30643 L
.64511 .30425 L
.65526 .30135 L
.66463 .29789 L
.68433 .28754 L
.69552 .27931 L
.706 .26949 L
.7273 .24164 L
.74676 .20909 L
Mistroke
.76843 .1739 L
.78851 .14822 L
.80796 .13047 L
.81883 .12311 L
.82867 .11777 L
.83852 .11348 L
.84892 .10994 L
.85436 .10845 L
.86032 .10706 L
.87079 .1052 L
.87631 .10449 L
.88154 .10397 L
.88623 .10362 L
.88887 .10347 L
.89132 .10336 L
.89258 .10332 L
.89394 .10328 L
.89511 .10325 L
.89639 .10323 L
.89713 .10321 L
.89781 .10321 L
.89854 .1032 L
.89931 .10319 L
.90003 .10319 L
.90071 .10319 L
.90198 .1032 L
.90336 .10321 L
.90405 .10322 L
.90481 .10323 L
.90741 .10329 L
.90888 .10334 L
.91045 .10339 L
.91329 .10352 L
.91883 .10384 L
.92396 .10423 L
.93557 .10541 L
.94581 .10676 L
.95669 .10848 L
.99629 .1168 L
1 .11772 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0007;ooooo6Ol0000Uooooo`00[Oooool00omgMgOo
IVIVooooo`05ooooo`03o`000?oooooooooo06gooooo1Ol0000Iooooo`Ko00007oooool00:kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1[ooooo`;o00009?ooool5o`0001[ooooo
002Zooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`1Xooooo`?o0000
:oooool4o`0001Kooooo000Fooooo`?o0000TOooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo
00?o0000ooooooooool0IOooool3o`0003;ooooo0ol0000Cooooo`006Oooool3o`0009Wooooo00?o
0000ooooooooool0Hoooool2o`0004_ooooo000Looooo`?o0000U_ooool00ol0003oooooooooo`1Q
ooooo`;o0000COooool001oooooo0ol0002Cooooo`03o`000?oooooooooo063ooooo00?o0000oooo
ooooool0COooool002;ooooo1?l0002?ooooo`;o0000H?ooool00ol0003oooooooooo`1>ooooo`00
9_ooool3o`0008cooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`1?ooooo`00:Ooo
ool4o`0008Sooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`1@ooooo`00;Oooool3
o`0008Gooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`1Aooooo`00<?ooool3o`00
08;ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`1Booooo`00<oooool3o`0007oo
oooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`1Cooooo`00=_ooool3o`0007cooooo
00?o0000ooooooooool0FOooool00ol0003oooooooooo`1Dooooo`00>Oooool2o`0007[ooooo00?o
0000ooooooooool0FOooool00ol0003oooooooooo`1Dooooo`00>oooool3o`0007Oooooo0_l0001I
ooooo`03o`000?oooooooooo05Gooooo000nooooo`;o0000MOooool00ol0003oooooooooo`1Goooo
o`03o`000?oooooooooo05Kooooo0010ooooo`?o0000L_ooool00ol0003oooooooooo`1Fooooo`03
o`000?oooooooooo05Oooooo000Eooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h06_ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^o`000?l0003o0000
onk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01cooooo1?l000002?l@413o
ooooooooooo^k^ko<S8bo`000?lb<S;ok^k^7_ooool00ol0003oooooooooo`0Oooooo`Co000000So
410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQ[ooooo1Ol00003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool00ol0003oooooooooo`0Eooooo`05oiRHV?l@413o0000oc8b<_o<c<`00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b
<_l0003o<S8bonk^kP0>ooooo`005_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL06_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00CoMgMgoiRHV?ooooooV9RH
0_l0000Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
01kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`03
o`000?oooooooooo01Kooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL07_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_oo
ool000_ooooo1_l00002ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@01;ooooo1_l0
0006ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooo`000002o`0000oooooo
1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400Cooooo`Ko
00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41007_ooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400K
ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Oo410@oooooooooooooooooa0@4?oooooo000001gooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01Wooooo1Ol00003ooooo`05
oa0@4?ooooooooooooooool@41003_ooool001?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0
003ooooooooooooooooo000001gooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooo
oooo000000Cooooo0_l0000Gooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Nooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
01cooooo00?oV9RHob4Q8Oo^k^h00oooool01?l0003oooooooooooooool2o`0001gooooo00?oZJVY
oa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000001_ooooo00CoA4A4omgMgOoooooo0000
1?ooool01Ol0003ooooooooooooooooo000000kooooo000Cooooo`04omgMgOmEEEGoooooo`0000Co
oooo00Go0000ooooooooooooooooo`00000Looooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000oooo
ooooooooooooo`000006ooooo`?o00005Oooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooo
ooooooooool000007_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
7_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`00000Mooooo`03ogMgMomVIVKooooo00;ooooo00Co0000oooooooooooooooo0_l0000Loooo
o`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00000Kooooo`04omgMgOmEEEGo
ooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`005?ooool00omgMgOoc<c<o`00
0004ooooo`05oa0@4?ooooooooooooooool@41007Oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@
4?ooooooooooooooool@41002Oooool3o`0001?ooooo00Go0000oooooooooooooooooa0@4003oooo
o`03oa0@4?oooooooooo01cooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@01kooooo0_l0000Rooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
400Nooooo`05o`000?ooooooooooooooool@41000oooool00ol0003oooooooooo`0Looooo`03okZj
^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@400Looooo`03ogMgMoo<c<co000000Co
oooo00Go410@oooooooooooooooooa0@400>ooooo`005?ooool00oo^k^koA4A4o`000004ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL06_ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0<ooooo`;o00003Oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0Nooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg01[ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonH
V9Soooooo`000?mgMgL06oooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0Looooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>
ooooo`005Oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06_ooool0
1OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`?o0000
2_ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Loooo
o`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Nooooo`03o`000?oooooo
oooo01oooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000o`000?o^k^h06oooool01OnYZJWo
410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Mooooo`03ogMgMol0003o
oooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`00F?ooool2o`0005_ooooo00?o0000
ooooooooool0Coooool00ol0003oooooooooo`1Nooooo`00F_ooool3o`0005Sooooo00?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`1Oooooo`00GOooool3o`0005Gooooo00?o0000oooooooo
ool0C_ooool00ol0003oooooooooo`1Oooooo`00H?ooool2o`0005?ooooo00?o0000ooooooooool0
COooool00ol0003oooooooooo`1Pooooo`00H_ooool3o`00053ooooo00?o0000ooooooooool0COoo
ool00ol0003oooooooooo`1Pooooo`005_ooooooo`00043o00004oooool001Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooo`000002o`0000?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool2o`00
00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool04Oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`02ooooo`;o000000?oooooo`000?ooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool2o`0000Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool04Oooool006cooooo0_l00017ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0
Hoooool006kooooo0ol00014ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0Hooo
ool0077ooooo0_l00012ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0I?ooool0
07?ooooo0_l00010ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0I?ooool007Go
oooo0ol0000mooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0IOooool007Sooooo
0ol0000jooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0I_ooool007_ooooo0_l0
000hooooo`;o0000B?ooool00ol0003oooooooooo`1Vooooo`00OOooool3o`0003Gooooo00?o0000
ooooooooool0A_ooool00ol0003oooooooooo`1Wooooo`00P?ooool2o`0003?ooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`1Wooooo`00P_ooool3o`00033ooooo00?o0000oooooooo
ool0AOooool00ol0003oooooooooo`1Xooooo`00QOooool3o`0002gooooo00?o0000ooooooooool0
AOooool00ol0003oooooooooo`1Xooooo`00R?ooool2o`0002_ooooo00?o0000ooooooooool0A?oo
ool00ol0003oooooooooo`1Yooooo`00R_ooool3o`0002Sooooo00?o0000ooooooooool0@oooool0
0ol0003oooooooooo`1Zooooo`00SOooool2o`0002Kooooo00?o0000ooooooooool0@_ooool00ol0
003oooooooooo`1[ooooo`00Soooool3o`0002?ooooo0_l00012ooooo`03o`000?oooooooooo06co
oooo002Booooo`?o00008?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo06cooooo
002Eooooo`?o00007Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo06gooooo002H
ooooo`?o00006_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo06kooooo002Koooo
o`?o00005oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo06oooooo002Nooooo`?o
00005?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo073ooooo002Qooooo`?o0000
4Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo077ooooo002Tooooo`?o00003_oo
ool00ol0003oooooooooo`0jooooo`;o0000M?ooool00:Oooooo1?l0000:ooooo`;o0000>_ooool0
0ol0003oooooooooo`1dooooo`00Zoooool5o`0000Gooooo00?o0000ooooooooool0=oooool2o`00
07Oooooo002`ooooo`Co000000?oooooo`000?ooool0=_ooool2o`0007Wooooo002dooooo`Co0000
=?ooool00ol0003oooooooooo`1iooooo`00]Oooool00ol0003oooooooooo`03o`0002oooooo0_l0
001looooo`00]Oooool00ol0003oooooooooo`03ooooo`Go0000:?ooool2o`0007kooooo002Zoooo
o`Go00001_ooool00ol0003oooooooooo`08ooooo`Go00008?ooool3o`00083ooooo002Zooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`0=ooooo`Oo00004oooool6o`00
08?ooooo002[ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0000Doooooa?o0000ROooool00:cooooo
00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`2`ooooo`00[Oooool00omgMgOoIVIVoooo
o`05ooooo`03o`000?oooooooooo0;3ooooo002^ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0/?ooool00:[ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooo
oooo0;3ooooo002Zooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00[?ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000
ooooooooool0/?ooool00:gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2`oooo
o`00Z_ooool5o`0000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00CoA4A4omgMgOoooooo
00001oooool3o`000;3ooooo002Zooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000oooooooo
ool0/?ooool00:_ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`2`ooooo`00Zooo
ool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0;3ooooo002/ooooo`03ogMgMol0003o
oooo00Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00:[ooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooo
oooo0;3ooooo002Zooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2`
ooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0/?ooool0
0:[ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000/?ooool00:[ooooo00Go0000oeEE
EOl0003o410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03oeEEEOn7QhOooooo
00Sooooo00?o0000ooooooooool0/?ooool00:[ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003o
ooooooooo`2`ooooo`00Zoooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05olc<
c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OlQ8B7oV9RH
oooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05oc8b<_nHV9SooooooiRHV?lb
<S801_ooool3o`000;3ooooo002Zooooo`05olc<c?l0003o0000o`000?o<c<`0^Oooool00:[ooooo
00Go410@okZj^_oooooo^[Zjoa0@402iooooo`00Z_ooool01Ol0003o^[Zjoooooonj^[[o00000;Wo
oooo002Zooooo`05ojVYZOl@413o0000oa0@4?nYZJT0^Oooool00?ooooooJOooool00;Oooooo00?o
0000okZj^_ooool0[_ooool00;Oooooo0_lb<S:_ooooo`00R?ooool2o`000006oa0@4?oooooooooo
oa0@4?l0003o410@6?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Joooo
o`;o000000?o410@ooooooooool0O_ooool008Wooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`07ooooo`Ko00003Oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`03olc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko0000
3?ooool00ol0003oooooooooo`1oooooo`00ROooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo01_ooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`0@ooooo`03o`00
0?oooooooooo01[ooooo1Ol00020ooooo`00ROooool01_l0003oooooodA4A?m4A4Coooooo`0000Wo
oooo1_l0000=ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00_ooooo1_l00009ooooo`04odA4A?oMgMgoooooo`00087ooooo0029oooo
o`06o`000?oMgMgo<S8boeEEEOoMgMgo00006Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo
00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo01[ooooo00CogMgMoeEEEOoo
oooo0000POooool008Wooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Iooooo`03o`000?oooooo
oooo00Cooooo00Go410@oooooooooooooooooa0@400@ooooo`03oa0@4?l0003o000000?o00006_oo
ool00omgMgOoc<c<o`000021ooooo`00ROooool01_l0003o<S8boooooooooooo<S8bo`0001Wooooo
00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000oooooooo
ool06oooool00oo^k^koA4A4o`000021ooooo`00R?ooool00ol@413o0000ohN7Q`02ooooo`03ohN7
Qol0003o410@01Sooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003o
ooooooooo`0Looooo`03ogMgMol0003ooooo083ooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
147.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .1282 m
.04057 .13934 L
.08481 .15247 L
.12636 .16547 L
.16632 .17837 L
.20885 .19238 L
.2498 .206 L
.29331 .22048 L
.33524 .23429 L
.37557 .24731 L
.41848 .2607 L
.4598 .27296 L
.49953 .28391 L
.54183 .29428 L
.58254 .30234 L
.59315 .30421 L
.59876 .30525 L
.60473 .3063 L
.60769 .30674 L
.61047 .30709 L
.61297 .30733 L
.61438 .30744 L
.61567 .30751 L
.61689 .30757 L
.61803 .30761 L
.61927 .30764 L
.62061 .30765 L
.62128 .30765 L
.62201 .30765 L
.62334 .30765 L
.62463 .30763 L
.62583 .30762 L
.62706 .30761 L
.62836 .3076 L
.62948 .30761 L
.63069 .30762 L
.632 .30766 L
.63274 .30769 L
.63341 .30772 L
.63471 .3078 L
.63594 .30791 L
.6383 .30819 L
.64049 .30854 L
.64542 .30963 L
.65085 .31103 L
.65351 .31163 L
.65467 .31183 L
.65593 .31201 L
.65724 .31214 L
.65849 .31219 L
Mistroke
.65918 .31218 L
.65991 .31215 L
.66123 .31203 L
.66199 .31191 L
.66281 .31175 L
.66429 .31136 L
.66573 .31086 L
.66706 .31029 L
.67662 .30408 L
.67914 .30229 L
.68188 .30061 L
.68314 .29999 L
.68447 .29946 L
.68561 .29912 L
.68686 .2989 L
.68763 .29884 L
.68832 .29884 L
.68909 .29891 L
.6899 .29905 L
.69126 .29946 L
.69203 .29978 L
.69274 .30015 L
.69533 .30195 L
.6981 .30459 L
.70319 .31056 L
.70597 .31369 L
.70733 .31498 L
.70857 .31594 L
.70986 .31668 L
.71125 .31712 L
.71197 .31718 L
.71276 .3171 L
.7135 .31688 L
.71419 .31655 L
.71538 .31566 L
.71669 .3142 L
.71807 .31212 L
.71936 .30964 L
.72228 .30215 L
.72497 .2932 L
.73103 .26756 L
.74199 .21583 L
.74734 .19374 L
.7522 .17673 L
.76179 .15154 L
.76706 .14159 L
.77205 .1341 L
.78247 .12283 L
.78835 .11834 L
.79377 .11503 L
Mistroke
.79867 .11259 L
.80393 .11044 L
.81345 .10752 L
.81925 .10623 L
.82476 .10528 L
.82971 .10462 L
.83511 .10408 L
.8378 .10388 L
.8407 .10371 L
.84344 .10359 L
.84474 .10354 L
.84596 .10351 L
.84715 .10348 L
.84824 .10346 L
.84944 .10345 L
.85074 .10344 L
.85198 .10343 L
.85333 .10344 L
.8546 .10345 L
.85578 .10346 L
.85705 .10349 L
.8584 .10352 L
.86086 .10359 L
.86379 .10371 L
.86647 .10384 L
.87199 .10418 L
.87781 .10464 L
.88784 .10565 L
.89855 .10698 L
.91785 .10995 L
.96144 .11873 L
1 .1282 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0006Cooooo5ol0000eooooo`00[Oooool00omgMgOo
IVIVooooo`05ooooo`03o`000?oooooooooo063ooooo1?l0000Gooooo`Go0000<?ooool00:kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Mooooo`?o00008?ooool5o`0002_ooooo
002Zooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`1Jooooo`?o0000
:?ooool5o`0002Kooooo002Zooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`1Iooooo`03o`000?oooooooooo02kooooo1Ol0000Qooooo`00]Oooool00ol0003ooooooooo
o`1Hooooo`03o`000?oooooooooo03Cooooo1?l0000Mooooo`00]Oooool00ol0003oooooooooo`1F
ooooo`;o0000>oooool4o`0001Wooooo002eooooo`03o`000?oooooooooo05Gooooo00?o0000oooo
ooooool0?oooool4o`0001Gooooo000Fooooo`?o0000W?ooool2o`0005Gooooo00?o0000oooooooo
ool0A?ooool2o`0001?ooooo000Iooooo`Go0000Uoooool00ol0003oooooooooo`1Cooooo`03o`00
0?oooooooooo05[ooooo000Nooooo`Co0000Toooool00ol0003oooooooooo`1Cooooo`03o`000?oo
oooooooo05[ooooo000Rooooo`Co0000Soooool00ol0003oooooooooo`1Booooo`03o`000?oooooo
oooo05_ooooo000Vooooo`?o0000S?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo
05_ooooo000Yooooo`Co0000R?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo05_o
oooo000]ooooo`?o0000QOooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo05cooooo
000`ooooo`Co0000POooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo05gooooo000d
ooooo`?o0000O_ooool2o`00057ooooo00?o0000ooooooooool0GOooool003Oooooo0ol0001koooo
o`03o`000?oooooooooo04oooooo00?o0000ooooooooool0G_ooool003[ooooo0ol0001hooooo`03
o`000?oooooooooo04oooooo00?o0000ooooooooool0G_ooool001Gooooo0_l000002Ol@413ooooo
ooooooooooook^k^oc8b<_l0003o<S8bonk^kP0Jooooo`03oiRHV?l@413o000000?o00000_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
7?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hNooooo`03o`000?oooooo
oooo01oooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^6_ooool5o`0000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0
003o<S8bonk^kP0>ooooo`005_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL06_ooool01_l@413o^[ZjoooooomgMgOo<S8booooo`?o000000CoV9RHoooooonHV9SoMgMg
6oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Noooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00Go
V9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMol0003ooooooiRHV?mgMgL06oooool01Ol@413o
^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`002oooool6o`0000;ooooo1Ol00003
ooooo`05oa0@4?ooooooooooooooool@41004_ooool6o`0000Kooooo00Go0000oooooooooooooooo
oa0@4003o`000003oa0@4?oooooooooo017ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400Cooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41007_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@400Kooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@
o`000?oooooooooooa0@400Oooooo`05o`000?ooooooooooooooool@41000oooool00ol@413ooooo
ooooo`0Iooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00kooooo000Cooooo`04odA4
A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000Mooooo`03ojVYZOl@413ooooo
00;ooooo00Co0000oooooooooooooooo0_l0000Looooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000
ooooooooooooooooo`00000Nooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000001cooooo00?oV9RHob4Q8Oo^k^h00oooool2o`0000;ooooo00?o0000oooooooo
ool07?ooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000006oooool01?m4
A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool001?ooooo00CogMgM
oeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000001cooooo00?o410@o`000?nj^[X0
0oooool01_l0003ooooooooooooooooo0000ooooo`?o00006_ooool00omgMgOoIVIVooooo`02oooo
o`05o`000?ooooooooooooooool000007_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000007_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`00000Mooooo`03ogMgMomVIVKooooo00;ooooo00Go0000oooooooooooo
ooooo`00000Mooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00000Koooo
o`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`005?ooool0
0omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41007Oooool00onj^[[o8B4Qoooo
o`02ooooo`05oa0@4?ooooooooooooooool@41001?ooool3o`0001Sooooo00Go0000oooooooooooo
oooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@01kooooo0_l0000Rooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@400Nooooo`05o`000?ooooooooooooooool000000oooool00ol@413ooooooooo
o`0Looooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@400Looooo`03ogMg
Moo<c<co000000Cooooo00Go410@oooooooooooooooooa0@400>ooooo`005?ooool00oo^k^koA4A4
o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01Ol@413oV9RHoooooonj^[[o0000
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`?o00004Oooool01Ol0003o^[ZjoooooonH
V9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00Go0000okZj^_ooooooV9RHoa0@4003
ooooo`05o`000?nHV9SooooooiRHV?mgMgL06oooool01Ol@413oV9RHoooooonj^[[o000000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0>ooooo`005Oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h06_ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0:ooooo`?o00003_ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0Looooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Noooo
o`03o`000?oooooooooo01oooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c002ooooo`06o`000?o^k^ko<S8bo`000?lb<S;o
k^k^6oooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0M
ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`00E?ooool3
o`0005kooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1Qooooo`00Eoooool4o`00
05[ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1Qooooo`00Foooool3o`0005Oo
oooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1Qooooo`00G_ooool3o`0005Cooooo
00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1Qooooo`00HOooool3o`00057ooooo00?o
0000ooooooooool0Boooool00ol0003oooooooooo`1Rooooo`005_ooooooo`00043o00004oooool0
01Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000002o`0000?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooool2o`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool001Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`02ooooo`Co00001oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000007ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo017ooooo001]ooooo`?o0000AOooool00ol0003oooooooooo`1:ooooo`03o`00
0?oooooooooo06?ooooo001`ooooo`?o0000@_ooool00ol0003oooooooooo`1:ooooo`03o`000?oo
oooooooo06?ooooo001cooooo`?o0000?oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooo
oooo06?ooooo001fooooo`?o0000??ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo
06Cooooo001iooooo`?o0000>Oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo06Co
oooo001looooo`?o0000=_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo06Cooooo
001oooooo`Co0000<_ooool2o`0004[ooooo00?o0000ooooooooool0I?ooool008?ooooo0ol0000_
ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0IOooool008Kooooo0ol0000/oooo
o`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0IOooool008Wooooo0ol0000Yooooo`03
o`000?oooooooooo04Sooooo00?o0000ooooooooool0IOooool008cooooo0ol0000Vooooo`03o`00
0?oooooooooo04Sooooo00?o0000ooooooooool0IOooool008oooooo0ol0000Sooooo`03o`000?oo
oooooooo04Sooooo00?o0000ooooooooool0IOooool009;ooooo0ol0000Pooooo`03o`000?oooooo
oooo04Oooooo00?o0000ooooooooool0I_ooool009Gooooo0ol0000Mooooo`03o`000?oooooooooo
04Oooooo00?o0000ooooooooool0I_ooool009Sooooo0ol0000Jooooo`;o0000B?ooool00ol0003o
ooooooooo`1Vooooo`00Voooool3o`0001Oooooo00?o0000ooooooooool0Aoooool00ol0003ooooo
ooooo`1Vooooo`00W_ooool3o`0001Cooooo00?o0000ooooooooool0A_ooool00ol0003ooooooooo
o`1Wooooo`00XOooool3o`00017ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`1W
ooooo`00Y?ooool3o`0000kooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`1Woooo
o`00Yoooool4o`0000[ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`1Wooooo`00
Zoooool5o`0000Gooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`1Wooooo`00/?oo
ool4o`000003ooooool0003ooooo04Oooooo00?o0000ooooooooool0Ioooool00;Cooooo1?l00015
ooooo`03o`000?oooooooooo06Sooooo002eooooo`03o`000?oooooooooo00Go0000@?ooool00ol0
003oooooooooo`1Xooooo`00]Oooool00ol0003oooooooooo`05ooooo`Co0000??ooool00ol0003o
ooooooooo`1Xooooo`00]Oooool00ol0003oooooooooo`09ooooo`Co0000>?ooool00ol0003ooooo
ooooo`1Xooooo`00]Oooool00ol0003oooooooooo`0=ooooo`Go0000<oooool00ol0003ooooooooo
o`1Xooooo`00]Oooool00ol0003oooooooooo`0Booooo`Co00008Oooool4o`0000Wooooo00?o0000
ooooooooool0JOooool00:[ooooo1Ol00006ooooo`03o`000?oooooooooo01Kooooo1?l0000Loooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Yoooo
o`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool06_ooool6o`00
01Cooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0JOooool00:_o
oooo00?oV9RHob4Q8Oo^k^h01oooool3o`00023ooooo3Ol00006ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Zooooo`00[?ooool00onHV9So8B4Q
onk^kP06ooooo`03o`000?oooooooooo02gooooo1_l0000;ooooo`05o`000?ooooooooooooooool0
0000KOooool00:gooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`0nooooo`;o0000
00?oooooo`000?l00000KOooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`10ooooo`;o0000K_ooool00:[ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oo
oooooooo0;3ooooo002Zooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00[?ooool2o`000003oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool0/?ooool00:gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2`
ooooo`00Z_ooool5o`0000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00CoA4A4omgMgOoo
oooo00001oooool3o`000;3ooooo002Zooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`2`ooooo`00
Zoooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0;3ooooo002/ooooo`03ogMgMol0
003ooooo00Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00:[ooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oo
oooooooo0;3ooooo002Zooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0/?oo
ool00:[ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000/?ooool00:[ooooo00Go0000
oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03oeEEEOn7QhOo
oooo00Sooooo00?o0000ooooooooool0/?ooool00:[ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0
003oooooooooo`2`ooooo`00Zoooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OlQ8B7o
V9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05oc8b<_nHV9SooooooiRH
V?lb<S801_ooool3o`000;3ooooo002Zooooo`05olc<c?l0003o0000o`000?o<c<`0^Oooool00:[o
oooo00Go410@okZj^_oooooo^[Zjoa0@402iooooo`00Z_ooool01Ol0003o^[Zjoooooonj^[[o0000
0;Wooooo002Zooooo`05ojVYZOl@413o0000oa0@4?nYZJT0^Oooool00?ooooooJOooool00;Oooooo
00?o0000okZj^_ooool0[_ooool00;Oooooo0_lb<S:_ooooo`00R?ooool2o`000006oa0@4?oooooo
oooooa0@4?l0003o410@6?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0H
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0P?ooool008Wooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`07ooooo`Ko00003Oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`03olc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009oooo
o`Ko00002Oooool01OmEEEGoMgMgoooooonHV9So8B4Q083ooooo0029ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool06oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooo
oooo013ooooo00?o0000ooooooooool06_ooool01Ol0003ooooooooooooooooo0000083ooooo0029
ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000gooooo00GoMgMgoc8b<_oooooo
ooooo`000003ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02oooool6o`0000Wo
oooo00Go0000oiRHV?ooooooV9RHob4Q8@20ooooo`00ROooool01_l0003ogMgMoc8b<_mEEEGogMgM
o`0001Wooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool00000
4_ooool00ol0003oooooooooo`0Jooooo`05o`000?mEEEGo0000oa0@4?o<c<`0P?ooool008Wooooo
00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Iooooo`03o`000?oooooooooo00Cooooo00Go410@oooo
oooooooooooooa0@400@ooooo`03oa0@4?l0003o000000?o00006Oooool00omEEEGoQhN7ooooo`22
ooooo`00ROooool01_l0003o<S8boooooooooooo<S8bo`0001Wooooo00?o0000ooooooooool01?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool06_ooool00ooMgMgo410@
oiRHV022ooooo`00R?ooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo1?l0
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Kooooo`04olc<
c?m4A4Co0000oa0@483ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
147.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .13732 m
.04057 .14768 L
.08481 .1595 L
.12636 .17094 L
.16632 .18217 L
.20885 .19426 L
.2498 .20599 L
.29331 .21847 L
.33524 .23042 L
.37557 .24175 L
.41848 .25353 L
.4598 .26465 L
.49953 .2757 L
.50494 .27692 L
.50801 .27743 L
.51085 .27781 L
.51606 .27831 L
.51873 .27851 L
.52014 .27861 L
.52162 .27874 L
.52298 .27888 L
.52446 .27908 L
.52708 .27955 L
.52836 .27986 L
.52974 .28025 L
.53222 .28111 L
.53725 .28341 L
.54183 .28593 L
.54669 .28866 L
.54935 .29001 L
.55184 .29105 L
.55314 .29148 L
.55453 .29183 L
.55529 .29197 L
.55608 .29208 L
.55676 .29214 L
.5575 .29217 L
.55881 .29212 L
.55955 .29205 L
.56021 .29195 L
.56151 .29167 L
.56274 .29132 L
.56728 .28948 L
.57217 .28723 L
.5736 .28666 L
.57497 .2862 L
.57619 .28588 L
.57753 .28565 L
.57879 .28555 L
.58013 .28561 L
Mistroke
.5814 .28584 L
.58254 .28619 L
.58386 .28679 L
.58507 .28752 L
.5878 .28985 L
.59021 .29261 L
.59275 .2961 L
.59834 .30462 L
.60107 .3084 L
.60226 .30981 L
.60356 .31114 L
.60475 .31214 L
.60585 .31285 L
.6069 .31331 L
.60802 .31355 L
.60919 .31352 L
.61029 .31322 L
.6115 .31258 L
.6128 .31153 L
.61403 .31018 L
.61538 .30836 L
.61809 .30369 L
.62293 .29334 L
.6256 .28757 L
.6285 .28218 L
.62983 .2802 L
.63123 .27853 L
.63243 .27751 L
.63375 .27684 L
.63503 .27669 L
.6362 .27701 L
.63754 .27794 L
.63882 .27941 L
.64 .28127 L
.64109 .28344 L
.64356 .28989 L
.64902 .31049 L
.65189 .32313 L
.65491 .33579 L
.65757 .3448 L
.65829 .34675 L
.65907 .34853 L
.65974 .34981 L
.66047 .3509 L
.66185 .35206 L
.66314 .35205 L
.66441 .35096 L
.66557 .34902 L
.6667 .34631 L
.66791 .34253 L
Mistroke
.6701 .33361 L
.67508 .30611 L
.67989 .27655 L
.68244 .26251 L
.68515 .25016 L
.68672 .24456 L
.68815 .24064 L
.68884 .23916 L
.68959 .23788 L
.69094 .23641 L
.6916 .23611 L
.69233 .23611 L
.6931 .23649 L
.69381 .23719 L
.69508 .23932 L
.69644 .24288 L
.69777 .24766 L
.69922 .25438 L
.70185 .27068 L
.70677 .31399 L
.71153 .3636 L
.71402 .38713 L
.71538 .39781 L
.71665 .40587 L
.71738 .4096 L
.71805 .41232 L
.71879 .41457 L
.71958 .41602 L
.72097 .41613 L
.72227 .41338 L
.72359 .40783 L
.72481 .40039 L
.72755 .37651 L
.73305 .31103 L
.73895 .2406 L
.74181 .21257 L
.74452 .19039 L
.74699 .1737 L
.74961 .15912 L
.75218 .14756 L
.75451 .1391 L
.75905 .12706 L
.7616 .1223 L
.76435 .1183 L
.76933 .11304 L
.77195 .11098 L
.77483 .1092 L
.77783 .10782 L
.78063 .10689 L
.78325 .10622 L
Mistroke
.78564 .10572 L
.78819 .10523 L
.79101 .10476 L
.79227 .10458 L
.79362 .10441 L
.7948 .10429 L
.79608 .10418 L
.79682 .10413 L
.79752 .10409 L
.79888 .10403 L
.80013 .104 L
.80145 .10399 L
.8027 .10398 L
.80406 .10397 L
.80534 .10397 L
.80651 .10396 L
.80873 .10394 L
.80995 .10393 L
.8111 .10392 L
.81247 .10393 L
.81372 .10394 L
.81489 .10397 L
.81616 .10401 L
.81756 .10408 L
.81904 .10417 L
.82171 .10437 L
.82756 .10479 L
.83012 .10495 L
.83292 .10514 L
.83771 .1056 L
.84275 .1062 L
.85336 .10741 L
.87255 .1102 L
.91512 .11793 L
.95611 .12679 L
.99967 .13723 L
1 .13732 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0005Sooooo4_l00016ooooo`00[Oooool00omgMgOo
IVIVooooo`05ooooo`03o`000?oooooooooo05Gooooo0ol0000Booooo`Oo0000?oooool00:kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Cooooo`;o00007?ooool7o`0003Sooooo
002Zooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`1Booooo`;o0000
9?ooool7o`00037ooooo002Zooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`1Aooooo`03o`000?oooooooooo02_ooooo1Ol0000/ooooo`00]Oooool00ol0003ooooooooo
o`1Aooooo`03o`000?oooooooooo033ooooo1Ol0000Wooooo`00]Oooool00ol0003oooooooooo`1@
ooooo`03o`000?oooooooooo03Kooooo1?l0000Sooooo`00]Oooool00ol0003oooooooooo`1?oooo
o`03o`000?oooooooooo03_ooooo1?l0000Oooooo`00]Oooool2o`00053ooooo00?o0000oooooooo
ool0?oooool5o`0001[ooooo002eooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0
A?ooool5o`0001Gooooo000Fooooo`?o0000W?ooool00ol0003oooooooooo`1>ooooo`03o`000?oo
oooooooo04[ooooo0_l0000Cooooo`006Oooool3o`0009Wooooo00?o0000ooooooooool0C_ooool0
0ol0003oooooooooo`1Oooooo`007?ooool3o`0009Kooooo00?o0000ooooooooool0C_ooool00ol0
003oooooooooo`1Oooooo`007oooool3o`0009?ooooo00?o0000ooooooooool0COooool00ol0003o
ooooooooo`1Pooooo`008_ooool4o`0008oooooo00?o0000ooooooooool0COooool00ol0003ooooo
ooooo`1Pooooo`009_ooool3o`0008cooooo00?o0000ooooooooool0COooool00ol0003ooooooooo
o`1Pooooo`00:Oooool4o`0008Sooooo0_l0001=ooooo`03o`000?oooooooooo067ooooo000]oooo
o`?o0000QOooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo067ooooo000`ooooo`Co
0000POooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo067ooooo000Eooooo`;o0000
00Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h05?ooool5o`000006oooooonHV9So
410@o`000?lb<S;oc<c<0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h07?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b
<_o^k^hNooooo`03o`000?oooooooooo01oooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^6_ooool5o`0000;ooooo00Ko0000onk^k_lb<S;o0000oc8b<_o^k^hKooooo`05oiRH
V?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01gooooo0_l000002Ol@
413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0>ooooo`005_ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06Oooool4o`000003ogMgMolb<S;ooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg01kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL06_ooool01OnHV9So8B4Qonk^k_ooooooA4A400;ooooo00Ko0000ogMgMonH
V9SooooooiRHV?mgMgLKooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg01kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00ko
oooo000;ooooo`Ko00000_ooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Booooo`Ko
00001Oooool4o`000003ooooool@413ooooo00;ooooo00?o410@ooooooooool04Oooool6o`0000?o
oooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01?ooooo1_l00005oooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Nooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01_ooooo00?o
V9RHob4Q8Oo^k^h00oooool00ol0003o410@ooooo`02ooooo`03oa0@4?oooooooooo01gooooo00Go
0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01Wooooo1Ol00003ooooo`05oa0@
4?ooooooooooooooool@41003_ooool001?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003o
oooooooooooooooo000001gooooo00CoZJVYoa0@4?oooooooooo0ol00002ooooo`03o`000?oooooo
oooo01_ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000001kooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001kooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007?ooool00onHV9So
8B4Qonk^kP02ooooo`;o00000oooool00ol0003oooooooooo`0Looooo`03ojVYZOl@413ooooo00;o
oooo00Go0000ooooooooooooooooo`00000Kooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000
ooooooooooooooooo`00000>ooooo`004oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?oo
ooooooooooooool000007?ooool00ol@413o0000okZj^P03ooooo`03o`000?oooooo000000;o0000
7_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`04ogMgMomVIVKo
ooooooooo`;o00000oooool00ol0003oooooooooo`0Kooooo`03oa0@4?l0003o^[Zj00?ooooo00Go
0000ooooooooooooooooo`00000Kooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000oooooooo
ooooooooo`00000>ooooo`005?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooooooo
ool@41007Oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41000ol0000L
ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Looooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@400Nooooo`;o00008_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41007_ooool01Ol0003oooooooooool0003o410@
00?ooooo00?o410@ooooooooool07?ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41007?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41003_oo
ool001Cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00Go
410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool4o`0001Co
oooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`0=o`00
0?nj^[[ooooooiRHV?l@413oooooo`000?ooooooMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`05oa0@
4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01cooooo00?ok^k^odA4
A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000Eooooo`03ogMgMol0003ooooo
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Jooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo0ol0000Aooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01cooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^01kooooo00?o0000ooooooooool07oooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06_ooool03OnHV9So410@o`000?lQ8B7oc<c<ooooool0
003oooooonk^k_lb<S;o0000oc8b<_o^k^h06oooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Mooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0>ooooo`00DOooool3o`00067ooooo00?o0000ooooooooool0Boooool00ol0003o
ooooooooo`1Rooooo`00E?ooool3o`0005kooooo00?o0000ooooooooool0Boooool00ol0003ooooo
ooooo`1Rooooo`00Eoooool4o`0005[ooooo00?o0000ooooooooool0Boooool00ol0003ooooooooo
o`1Rooooo`00Foooool5o`0005Gooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`1R
ooooo`00H?ooool4o`00057ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`1Soooo
o`005_ooooooo`00043o00004oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`03o`0000;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000007ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo017ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00ooo
ool4o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`00Koooool3
o`0004?ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`1Sooooo`00L_ooool4o`00
03oooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`1Sooooo`00M_ooool3o`0003co
oooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`1Sooooo`00NOooool3o`0003Wooooo
00?o0000ooooooooool0B_ooool00ol0003oooooooooo`1Sooooo`00O?ooool3o`0003Kooooo00?o
0000ooooooooool0BOooool00ol0003oooooooooo`1Tooooo`00Ooooool4o`0003;ooooo00?o0000
ooooooooool0BOooool00ol0003oooooooooo`1Tooooo`00Poooool3o`0002oooooo0_l0001:oooo
o`03o`000?oooooooooo06Cooooo0026ooooo`?o0000;?ooool00ol0003oooooooooo`0iooooo`?o
00003Oooool00ol0003oooooooooo`1Tooooo`00ROooool3o`0002Wooooo00?o0000ooooooooool0
>Oooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo06Cooooo002<ooooo`Co00009Ooo
ool00ol0003oooooooooo`0iooooo`03o`000?oooooo000000gooooo00?o0000ooooooooool0I?oo
ool0093ooooo1Ol0000Pooooo`03o`000?oooooooooo03Sooooo00Co0000oooooooooooo00003Ooo
ool00ol0003oooooooooo`1Tooooo`00UOooool5o`0001_ooooo00?o0000ooooooooool0>?ooool0
1Ol0003ooooooooooooooooo000000cooooo00?o0000ooooooooool0I?ooool009[ooooo1?l0000G
ooooo`03o`000?oooooooooo03Sooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oo
oooooooo06Cooooo002Nooooo`?o00005?ooool00ol0003oooooooooo`0hooooo`05o`000?oooooo
ooooooooool000003?ooool00ol0003oooooooooo`1Tooooo`00XOooool3o`00017ooooo0_l0000h
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1T
ooooo`00Y?ooool3o`0000kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0IOooool00:Oooooo1?l0000:ooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo06Gooooo002[ooooo`?o00001oooool00ol0003oooooooooo`0gooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Uooooo`00[_oo
ool3o`0000Cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0IOooool00;7ooooo0ol000000ooooooo0000ooooo`0g
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1U
ooooo`00]?ooool9o`0002;ooooo0ol0000<ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`1Uooooo`00]Oooool00ol0003oooooooooo`04ooooo`Go
00007Oooool01?l0003oooooooooool0000<ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`1Uooooo`00]Oooool2o`0000[ooooo00?o0000oooooooo
ool06_ooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo06Gooooo002eooooo`03o`000?oooooooooo00[o
oooo0_l00007ooooo`Ko00003?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo06Go
oooo002eooooo`03o`000?oooooooooo00cooooo0_l00003ooooo`;o00001_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0IOooool00;Gooooo00?o
0000ooooooooool03_ooool3o`0000Wooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo06Gooooo002eooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06Kooooo002eoooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo06Kooooo002Zooooo`Go00001_ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Vooooo`00
Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0I_ooool00:_ooooo
00?oV9RHob4Q8Oo^k^h01oooool3o`0001gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo06Kooooo002/ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o
0000ooooooooool07_ooool4o`0000[ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0I_ooool00:gooooo00?oMgMg
ofIVI_ooool01Oooool00ol0003oooooooooo`0Oooooo`;o00002oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1V
ooooo`00[_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0I_ooool00:[ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0I_ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006oooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0I_ooool00;Gooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`1Vooooo`00]Oooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo06Oooooo002eooooo`;o0000;oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Wooooo`00]Oooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo06Oooooo002eooooo`03o`000?oooooooooo
02kooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0Ioooool00;Gooooo00?o0000ooooooooool0;oooool01?l0003oooooooooool0000=
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Ioooool00;Gooooo00?o0000oooo
ooooool0;oooool01?l0003oooooooooool0000=ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0Ioooool00;Gooooo00?o0000ooooooooool0<?ooool3o`0000gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`1Wooooo`00]Oooool00ol0003oooooooooo`0`ooooo`;o
00003_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06Oooooo002eooooo`03o`00
0?oooooooooo043ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Wooooo`00]Ooo
ool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Iooo
ool00;Gooooo0_l00011ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Ioooool0
0;Gooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
06Sooooo002eooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`1Xooooo`00]Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0J?ooool00;Gooooo00?o0000ooooooooool0@?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo06Sooooo002eooooo`03o`000?oooooooooo047ooooo00Go0000
ooooooooooooooooo`00001Zooooo`00]Oooool00ol0003oooooooooo`11ooooo`05o`000?oooooo
ooooooooool00000J_ooool00;Gooooo00?o0000ooooooooool0@Oooool01Ol0003ooooooooooooo
oooo000006[ooooo002eooooo`;o0000@_ooool01Ol0003ooooooooooooooooo000006[ooooo002e
ooooo`03o`000?oooooooooo047ooooo00Co0000oooooooooooo0000Joooool00;Gooooo00?o0000
ooooooooool0@Oooool01?l0003oooooooooool0001[ooooo`00]Oooool00ol0003oooooooooo`11
ooooo`04o`000?ooooooooooo`0006_ooooo002eooooo`03o`000?oooooooooo047ooooo00Co0000
oooooooooooo0000Joooool00:cooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooo
oooo04;ooooo00?o0000ooooool00000Joooool00:gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`12ooooo`03o`000?oooooo000006_ooooo002Zooooo`Go00001_ooool00ol0003o
ooooooooo`12ooooo`03o`000?oooooo000006_ooooo002Zooooo`04odA4A?oMgMgoooooo`0000Oo
oooo0ol00012ooooo`03o`000?oooooo000006_ooooo002Zooooo`04omgMgOmEEEGoooooo`0000Oo
oooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`1Zooooo`00Zoooool00omgMgOoc<c<
o`000007ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03onk^k_m4A4Co000000Oooooo00?o
0000ooooooooool0/?ooool00:cooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aoooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Oo^
k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00GoEEEEogMg
MoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003oV9RHoooooonHV9So
8B4Q00Kooooo0ol0002`ooooo`00Z_ooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000
ooooooooool0/?ooool00:[ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`2`oooo
o`00Z_ooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`04olc<
c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00:[ooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03
o`000?oooooooooo0;3ooooo002Zooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003o
ooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool0/?ooool00:[ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000/?ooool00:[ooooo
00Goc<c<o`000?l0003o0000olc<c02iooooo`00Z_ooool01Ol@413o^[Zjoooooonj^[[o410@0;Wo
oooo002Zooooo`05o`000?nj^[[ooooookZj^_l00000^Oooool00:[ooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@2iooooo`00oooooomYooooo`00]oooool00ol0003o^[Zjooooo`2^ooooo`00]oooool2
oc8b<Zoooooo0028ooooo`;o000000Ko410@oooooooooooo410@o`000?l@410Hooooo`05odA4A?l0
003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?oQhN7o`000?nj
^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c020
ooooo`00ROooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l0000=oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?oc<c<o`000?l@4100
3?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00009ooooo`05ob4Q8OnHV9SooooooiRH
V?lQ8B40P?ooool008Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Kooooo`04
o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool04?ooool00ol0003oooooooooo`0Joooo
o`05o`000?ooooooooooooooool00000P?ooool008Wooooo00Ko0000oooooom4A4CoA4A4ooooool0
0009ooooo`Ko00003Oooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0;ooooo`Ko00002Oooool01Olb<S;oV9RHoooooonHV9So<S8b083o
oooo0029ooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo00006Oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00;ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo01[ooooo00Go
c<c<o`000?l0003o0000olc<c020ooooo`00ROooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001Wo
oooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@013ooooo00?o410@o`00
0?l000000ol0000Iooooo`05oa0@4?nj^[[ooooookZj^_l@4100P?ooool008Wooooo00Ko0000oc8b
<_oooooooooooc8b<_l0000Iooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0Booooo`03o`000?oooooooooo01[ooooo00Go0000okZj^_oooooo^[Zjo`000020ooooo`00
R?ooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Jooooo`05ojVYZOl@413o0000oa0@
4?nYZJT0P?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .14477 m
.04057 .15425 L
.08481 .16497 L
.12636 .17518 L
.16632 .18511 L
.20885 .19577 L
.2498 .20607 L
.29331 .21687 L
.33524 .22718 L
.37557 .23811 L
.38062 .23915 L
.38541 .23991 L
.38805 .24021 L
.39094 .2405 L
.39359 .2408 L
.39599 .24115 L
.39891 .24173 L
.40201 .24251 L
.40761 .24428 L
.41848 .24915 L
.42345 .2516 L
.42617 .2527 L
.4287 .25349 L
.43003 .25381 L
.43145 .25408 L
.43226 .2542 L
.43303 .25429 L
.43371 .25436 L
.43446 .25441 L
.4358 .25447 L
.43647 .25447 L
.43721 .25446 L
.43853 .25439 L
.43976 .25428 L
.4409 .25414 L
.44214 .25394 L
.44439 .25346 L
.44698 .25281 L
.44933 .25221 L
.4507 .25191 L
.45145 .25176 L
.45215 .25165 L
.45339 .2515 L
.45476 .25143 L
.45603 .25147 L
.45719 .2516 L
.45853 .25186 L
.4598 .25222 L
.46104 .25268 L
.46237 .25329 L
Mistroke
.46474 .25469 L
.47013 .25916 L
.47573 .26527 L
.47847 .26838 L
.48099 .27098 L
.48338 .27299 L
.48458 .27377 L
.4859 .27443 L
.48722 .27487 L
.48796 .27501 L
.48864 .27508 L
.48995 .27503 L
.49119 .27476 L
.49231 .27435 L
.49349 .27375 L
.49562 .27224 L
.4979 .2701 L
.50042 .26723 L
.5056 .26053 L
.50843 .2571 L
.5098 .25568 L
.51105 .25459 L
.51221 .25377 L
.5133 .25321 L
.51445 .25285 L
.5157 .25276 L
.51698 .25299 L
.51834 .25362 L
.5195 .25448 L
.52078 .25575 L
.52225 .25764 L
.52364 .25984 L
.52624 .26498 L
.53211 .28027 L
.53714 .29451 L
.53851 .29795 L
.54 .3012 L
.54129 .30353 L
.54197 .30456 L
.54269 .30548 L
.54402 .30669 L
.54526 .3072 L
.54599 .30722 L
.54668 .30704 L
.54797 .3062 L
.54918 .30482 L
.55029 .30305 L
.55281 .29749 L
.5553 .29022 L
.55804 .2808 L
Mistroke
.56357 .26042 L
.56604 .25221 L
.56838 .24571 L
.56967 .24284 L
.57036 .24155 L
.57108 .24038 L
.57237 .23883 L
.57356 .238 L
.57477 .23781 L
.57608 .23836 L
.57732 .23962 L
.57846 .24143 L
.57949 .24361 L
.58062 .24658 L
.5829 .25441 L
.58554 .26636 L
.58841 .28238 L
.59363 .31583 L
.59609 .33094 L
.59744 .33825 L
.59871 .3442 L
.59987 .34873 L
.60094 .35197 L
.60213 .35444 L
.60341 .35567 L
.60469 .35537 L
.60605 .35333 L
.60735 .34982 L
.60852 .34539 L
.61139 .33017 L
.61411 .31162 L
.61947 .27059 L
.62232 .25012 L
.62537 .23134 L
.62679 .22412 L
.62813 .21827 L
.62944 .21358 L
.63065 .21016 L
.6318 .2078 L
.63301 .20624 L
.63437 .20567 L
.63559 .20625 L
.63627 .20702 L
.63699 .20819 L
.63827 .21122 L
.63965 .21583 L
.64116 .22251 L
.64387 .23888 L
.6464 .25919 L
.65569 .36124 L
Mistroke
.65824 .38691 L
.65963 .39819 L
.66094 .4064 L
.66205 .41131 L
.66324 .41429 L
.66457 .41466 L
.66578 .41226 L
.66646 .40981 L
.66718 .40633 L
.66848 .39799 L
.67003 .38496 L
.67143 .37073 L
.67679 .30515 L
.6818 .24631 L
.68443 .22097 L
.68721 .19934 L
.6897 .18455 L
.69112 .17809 L
.69244 .17333 L
.69365 .17003 L
.69476 .16794 L
.69604 .16659 L
.69725 .16639 L
.69839 .16715 L
.6996 .16897 L
.70064 .17136 L
.70178 .17492 L
.703 .17982 L
.70432 .18643 L
.70671 .20217 L
.70923 .22458 L
.71191 .25576 L
.71675 .32908 L
.72203 .4155 L
.72347 .43512 L
.725 .45198 L
.72631 .46247 L
.72705 .46663 L
.72774 .46926 L
.72851 .47073 L
.72925 .47067 L
.73062 .46676 L
.73139 .46247 L
.7321 .45721 L
.73371 .4411 L
.73644 .40315 L
.73935 .35417 L
.74448 .26823 L
.74989 .20019 L
.75258 .17641 L
Mistroke
.75553 .15638 L
.75822 .1425 L
.76072 .13257 L
.76223 .12776 L
.76367 .12397 L
.76636 .11859 L
.76787 .11637 L
.76926 .11471 L
.77241 .1119 L
.77493 .11024 L
.7773 .10895 L
.77989 .10783 L
.78135 .10736 L
.78269 .10705 L
.78401 .10684 L
.78523 .10673 L
.78657 .10669 L
.78732 .1067 L
.78801 .10673 L
.78939 .1068 L
.79088 .10689 L
.79161 .10694 L
.7923 .10697 L
.7936 .10702 L
.79479 .10704 L
.79608 .10705 L
.79746 .10704 L
.79875 .10704 L
.79985 .10705 L
.80108 .10709 L
.80235 .10716 L
.80356 .10727 L
.80489 .10744 L
.8063 .10765 L
.80882 .10809 L
.8145 .10889 L
.8366 .11192 L
.87657 .11876 L
.91911 .12704 L
.96006 .13577 L
1 .14477 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0EOoooolAo`0004[ooooo002^ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0?ooooo`Go0000AOooool00:[ooooo00Go
0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0
5Oooool5o`00043ooooo002Zooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`1Booooo`03o`000?oooooooooo01_ooooo1?l0000looooo`00]Oooool00ol0003ooooooooo
o`1Booooo`03o`000?oooooooooo01oooooo1Ol0000gooooo`00]Oooool00ol0003oooooooooo`1A
ooooo`03o`000?oooooooooo02Gooooo1ol0000`ooooo`00]Oooool00ol0003oooooooooo`1@oooo
o`03o`000?oooooooooo02gooooo1Ol0000[ooooo`00]Oooool2o`00057ooooo00?o0000oooooooo
ool0<_ooool5o`0002Kooooo002eooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0
=oooool4o`0002;ooooo002eooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0>ooo
ool4o`0001kooooo002eooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0@?ooool5
o`0001Wooooo002eooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0AOooool4o`00
01Gooooo000Fooooo`?o0000W?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo04Wo
oooo0_l0000Cooooo`006Oooool5o`0009Oooooo00?o0000ooooooooool0Coooool00ol0003ooooo
ooooo`1Nooooo`007_ooool4o`0009?ooooo00?o0000ooooooooool0C_ooool00ol0003ooooooooo
o`1Oooooo`008_ooool4o`0008oooooo0_l0001?ooooo`03o`000?oooooooooo05oooooo000Voooo
o`Go0000R_ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo05oooooo000[ooooo`Go
0000QOooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo05oooooo000Eooooo`;o0000
00Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h04?ooool4o`0000Kooooo00GoV9RH
oa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool5o`0000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Looooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o
<S8bonk^kQkooooo00?o0000ooooooooool07oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o
0000oc8b<_o^k^hJooooo`Go00000oooool01Oo^k^ko0000o`000?lb<S;ok^k^01_ooooo00GoV9RH
oa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Oooool2o`000009oa0@
4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Fooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Dooooo`?o00000oooool01Ol@413o^[Zjoooooomg
MgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04?ooool2o`0000Sooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A003ooooo`05ogMgMol0003ooooooiRHV?mgMgL06oooool01Ol@413o^[ZjoooooomgMgOo<S8b
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0>ooooo`002oooool6o`0000;ooooo1Ol00003ooooo`05oa0@4?oooooo
ooooooooool@41004_ooool8o`0000Cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@
4?oooooooooo017ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooo
oooooa0@400Cooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41007_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@400@ooooo`?o00002?ooool00onHV9So8B4Qonk^kP04ooooo`05o`000?oooooo
ooooooooool@41007oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0
6Oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`004oooool01?m4A4CogMgM
ooooool00004ooooo`05o`000?ooooooooooooooool000006_ooool3o`000003ojVYZOl@413ooooo
00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000
ooooooooooooooooo`00000Nooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000oooooo00Co0000oooooooooooo00002Oooool00onHV9So8B4Qonk^kP03oooo
o`05o`000?ooooooooooooooool000007_ooool00onYZJWo410@ooooo`02ooooo`05o`000?oooooo
ooooooooool000006oooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool0
00003_ooool001?ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo0000
01cooooo00?o410@o`000?l000000_l000000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
01cooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000001kooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000001kooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003oooool01?l0003ooooo
ooooool0000:ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00000Moooo
o`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00000Kooooo`04omgMgOmEEEGo
ooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`005?ooool00omgMgOoc<c<o`00
0004ooooo`05oa0@4?ooooooooooooooool@41007Oooool01?nj^[[o8B4Qooooooooool5o`000003
oa0@4?oooooooooo01gooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo
01cooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01kooooo0_l0000R
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400?ooooo`05o`000?oo
ooooooooooooool000002_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o410@oooooooo
ool07?ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41007?ooool00omg
MgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41003_ooool001Cooooo00?ok^k^odA4
A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00Go410@oiRHV?oooooo^[Zjo`00
0003ooooo`04ogMgMonHV9SooooooiRHV0Co00006?ooool01Ol0003o^[ZjoooooonHV9So410@00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Ol0003oV9RHoooooonHV9SoMgMg01_o
oooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07?ooool0
0oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool001Gooooo00?oMgMg
o`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool4o`0001Cooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07_ooool00ol0003oooooooooo`0Oooooo`03oeEEEOmV
IVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Go0000oc8b<_l0
003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^01gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo
001>ooooo`Go0000H_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`1Qooooo`00Doooool4o`0005kooooo00?o0000
ooooooooool0>Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0HOooool005Oooooo1?l0001Jooooo`03o`000?oooooooooo03Sooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo067ooooo001Kooooo`Go
0000EOooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`1Qooooo`00H?ooool4o`00057ooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
HOooool001Koooooool00010o`0001?ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00ol00002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
1?l0003oooooo`000?l00004ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Aooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00?ooooo1?l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l00002ooooo`05o`000?oo
ooooooooooooool000001oooool01?l0003oooooooooool00004ooooo`03o`000?oooooo000000Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017o
oooo001_ooooo`?o0000@oooool00ol0003oooooooooo`0Vooooo`04o`000?ooooooooooo`0000ko
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo067o
oooo001booooo`Co0000?oooool00ol0003oooooooooo`0Vooooo`04o`000?ooooooooooo`0000ko
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo067o
oooo001fooooo`Go0000>_ooool00ol0003oooooooooo`0Vooooo`05o`000?ooooooooooooooool0
00003Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0HOooool007_ooooo1?l0000fooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`1Qooooo`00Ooooool4o`0003;ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo067ooooo0023ooooo`?o0000;oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0HOooool0
08Kooooo0ol0000/ooooo`;o00009_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
067ooooo0029ooooo`?o0000:Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Rooooo`00S?ooool8o`00027ooooo
00?o0000ooooooooool05?ooool2o`0000oooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`1Rooooo`00U?ooool3o`0001kooooo00?o0000ooooooooool04oooool01?l0003ooooooooo
ool0000=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0H_ooool009Oooooo0ol0
000Kooooo`03o`000?oooooooooo01?ooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0H_ooool009[ooooo0ol0000Hooooo`03o`000?oo
oooooooo01?ooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0H_ooool009gooooo0_l00004ooooo`Oo00002oooool01?l0003ooooooooo
ooooool3o`0000kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0H_ooool009oooooo1?l00007ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool00_l000000ooooooo0000ooooo`0=ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo06;ooooo002[ooooo`03o`000?oooooooooo00Oooooo0_l000000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0H_ooool00:cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0H_ooool00:gooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`1Rooooo`00[_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Rooooo`00[ooo
ool01?l0003oooooooooooooool3o`0000Sooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`1Rooooo`00/?ooool4o`000003ooooool0003ooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`1Rooooo`00]Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0H_ooool00;Gooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo06;ooooo002eooooo`;o00002?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo06;ooooo002eooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`1Rooooo`00]Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0H_ooool00;Gooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06?ooooo002eoooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Soooo
o`00]Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0Hoooool00:[ooooo1Ol00006ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooo
00003?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0Hoooool00:[ooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo00[o
oooo1?l0000<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1Sooooo`00Zoooool00onHV9So8B4Qonk^kP07ooooo`?o00002oooool2o`0000kooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06?ooooo
002/ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Hoooool00:gooooo00?oMgMg
ofIVI_ooool01Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1Sooooo`00[_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo06?ooooo002Zooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Sooooo`00Z_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0Hoooool00;Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0Hoooool00;Gooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
Hoooool00;Gooooo0_l0000Looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1Sooooo`00]Oooool00ol0003oooooooooo`0Looooo`05o`000?oooooo
ooooooooool000003?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`1Tooooo`00]Oooool00ol0003oooooooooo`0L
ooooo`04o`000?ooooooooooo`0000gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0I?ooool00;Gooooo00?o0000
ooooooooool07?ooool01?l0003oooooooooool0000=ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06Cooooo002e
ooooo`03o`000?oooooooooo01cooooo00Co0000oooooooooooo00003_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`1Tooooo`00]Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo000000kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0I?ooool00;Gooooo00?o0000ooooooooool07Oooool00ol0003oooooo`00000>oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo06Cooooo002eooooo`03o`000?oooooooooo01gooooo0_l0000?ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo06Cooooo002eooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
I?ooool00;Gooooo0_l0000_ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06Cooooo002eooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0I?ooool00;Gooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Tooooo`00]Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06Co
oooo002eooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0I?ooool00;Gooooo00?o
0000ooooooooool0;oooool01Ol0003ooooooooooooooooo000000oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`1Tooooo`00]Oooool00ol0003oooooooooo`0_ooooo`05o`000?oo
ooooooooooooool000003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06Gooooo
002eooooo`03o`000?oooooooooo02oooooo00Go0000ooooooooooooooooo`00000?ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0IOooool00;Gooooo0_l0000`ooooo`05o`000?oo
ooooooooooooool000003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06Gooooo
002eooooo`03o`000?oooooooooo02oooooo00Go0000ooooooooooooooooo`00000?ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0IOooool00;Gooooo00?o0000ooooooooool0;ooo
ool01Ol0003ooooooooooooooooo000000oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`1Uooooo`00]Oooool00ol0003oooooooooo`0`ooooo`04o`000?ooooooooooo`00013ooooo
00Go0000ooooooooooooooooo`00001Wooooo`00]Oooool00ol0003oooooooooo`0`ooooo`04o`00
0?ooooooooooo`00013ooooo00Go0000ooooooooooooooooo`00001Wooooo`00[?ooool2o`000003
oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0<?ooool00ol0003oooooo`00000Aooooo`05
o`000?ooooooooooooooool00000Ioooool00:gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooo0000017ooooo00Go0000ooooooooooooooooo`00001Woooo
o`00Z_ooool5o`0000Kooooo00?o0000ooooooooool0<?ooool00ol0003oooooo`00000Aooooo`05
o`000?ooooooooooooooool00000Ioooool00:[ooooo00CoA4A4omgMgOoooooo00001oooool3o`00
033ooooo00?o0000ooooool000004Oooool01Ol0003ooooooooooooooooo000006Oooooo002Zoooo
o`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0@
ooooo`05o`000?ooooooooooooooool00000Ioooool00:_ooooo00?oMgMgolc<c?l000001oooool0
0ol0003oooooooooo`14ooooo`05o`000?ooooooooooooooool00000Ioooool00:_ooooo00?ok^k^
odA4A?l000001oooool00ol0003oooooooooo`14ooooo`05o`000?ooooooooooooooool00000Iooo
ool00:cooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`14ooooo`04o`000?oooooo
ooooo`0006Sooooo002eooooo`03o`000?oooooooooo04Cooooo00Co0000oooooooooooo0000J?oo
ool00;Gooooo00?o0000ooooooooool0A?ooool01?l0003oooooooooool0001Xooooo`00]Oooool0
0ol0003oooooooooo`14ooooo`04o`000?ooooooooooo`0006Sooooo002eooooo`;o0000AOooool0
1?l0003oooooooooool0001Xooooo`00]Oooool00ol0003oooooooooo`14ooooo`04o`000?oooooo
ooooo`0006Sooooo002eooooo`03o`000?oooooooooo04Cooooo00Co0000oooooooooooo0000J?oo
ool00;Gooooo00?o0000ooooooooool0AOooool00ol0003oooooo`00001Xooooo`00]Oooool00ol0
003oooooooooo`15ooooo`03o`000?oooooo000006Sooooo002eooooo`03o`000?oooooooooo04Go
oooo00?o0000ooooool00000J?ooool00;Gooooo00?o0000ooooooooool0AOooool00ol0003ooooo
o`00001Xooooo`00]Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooo000006Sooooo002e
ooooo`;o0000A_ooool00ol0003oooooo`00001Xooooo`00]Oooool00ol0003oooooooooo`15oooo
o`;o0000JOooool00;Gooooo00?o0000ooooooooool0AOooool2o`0006Wooooo002eooooo`03o`00
0?oooooooooo04Kooooo00?o0000ooooooooool0Ioooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_oo
ool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go
EEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003oV9RHoooo
oonHV9So8B4Q00Kooooo0ol0002`ooooo`00Z_ooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo
00?o0000ooooooooool0/?ooool00:[ooooo00?oEEEEohN7Qoooool02?ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo0;3ooooo002[oooo
o`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006
ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool0
0ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool0/?ooool00:[ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000/?ooool0
0:[ooooo00Goc<c<o`000?l0003o0000olc<c02iooooo`00Z_ooool01Ol@413o^[Zjoooooonj^[[o
410@0;Wooooo002Zooooo`05o`000?nj^[[ooooookZj^_l00000^Oooool00:[ooooo00GoZJVYoa0@
4?l0003o410@ojVYZ@2iooooo`00oooooomYooooo`00/oooool00ol0003o^[Zjooooo`2booooo`00
/oooool2oc8b<[?ooooo0024ooooo`;o000000Ko410@oooooooooooo410@o`000?l@410Hooooo`05
odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?oQhN7
o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Wooooo1?l000002?l@413ooooooooo
ooo^k^ko<S8bo`000?lb<S;ok^k^O?ooool008Gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`07ooooo`Ko00003Oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`03olc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko0000
3?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0O?ooool008Gooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooooooooa0@40?o
oooo00?o410@ooooooooool04?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@401looooo`00QOooool01_l0003oooooodA4A?m4A4Cooooo
o`0000Wooooo1_l0000=ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo00_ooooo1_l0000<ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`00001looooo`00QOooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001Wo
oooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000004_ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
001looooo`00QOooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001Wooooo00?o0000ooooooooool0
1?ooool01Ol@413ooooooooooooooooo410@013ooooo00?o410@o`000?l000000ol0000Looooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@401looooo`00QOooool01_l0003o
<S8boooooooooooo<S8bo`0001Wooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg01;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0O?ooool008Cooooo00?o410@o`000?n7QhL00_ooool00on7QhOo0000oa0@
400Hooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo00?o0000ooooooooool0
6oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0O?ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .15107 m
.04057 .15973 L
.08481 .16935 L
.12636 .17844 L
.16632 .18738 L
.20885 .19691 L
.2498 .20536 L
.29331 .21655 L
.29595 .21682 L
.29742 .21693 L
.29878 .21702 L
.30003 .21707 L
.3014 .21711 L
.30269 .21714 L
.30389 .21715 L
.30523 .21717 L
.30648 .21719 L
.30717 .21721 L
.30792 .21724 L
.30923 .21731 L
.30994 .21736 L
.31072 .21742 L
.3123 .2176 L
.31375 .21782 L
.31511 .21808 L
.31772 .2187 L
.32019 .21944 L
.32483 .22121 L
.32981 .22372 L
.33524 .227 L
.34048 .23005 L
.34305 .23127 L
.3454 .23215 L
.34658 .2325 L
.34787 .2328 L
.34916 .23303 L
.35053 .23319 L
.35127 .23324 L
.35195 .23325 L
.35273 .23325 L
.35346 .23321 L
.35477 .23308 L
.35551 .23297 L
.35619 .23284 L
.35851 .23223 L
.36067 .23144 L
.36561 .22916 L
.36811 .22798 L
.37078 .22691 L
.37208 .22649 L
Mistroke
.3733 .22619 L
.37439 .22599 L
.37557 .22586 L
.3769 .22584 L
.37757 .22587 L
.3783 .22595 L
.37959 .2262 L
.3808 .22655 L
.38224 .22714 L
.38355 .22784 L
.3865 .22999 L
.38906 .23252 L
.39183 .23589 L
.39688 .24305 L
.40178 .24992 L
.40447 .25303 L
.40579 .25428 L
.40699 .25524 L
.40802 .25591 L
.40913 .25647 L
.41026 .25683 L
.41144 .25701 L
.41267 .25694 L
.41398 .2566 L
.41522 .256 L
.41634 .25524 L
.41877 .25289 L
.42145 .24935 L
.42685 .24031 L
.43191 .23182 L
.43412 .22876 L
.43652 .22615 L
.43723 .22556 L
.43798 .22503 L
.43932 .22432 L
.44058 .22399 L
.4413 .22394 L
.44197 .224 L
.44269 .22418 L
.44344 .22449 L
.44479 .22539 L
.44554 .22608 L
.44623 .22685 L
.44782 .22905 L
.45049 .23416 L
.45292 .24022 L
.45838 .25746 L
.46346 .27466 L
.46624 .28277 L
.4676 .28606 L
Mistroke
.46884 .28858 L
.46997 .29041 L
.47105 .2917 L
.47219 .29254 L
.47343 .29282 L
.47471 .29241 L
.47606 .29118 L
.47734 .28927 L
.47849 .28695 L
.48131 .2792 L
.4839 .26997 L
.48974 .24576 L
.49485 .22616 L
.49771 .21761 L
.49907 .2144 L
.50032 .21197 L
.50154 .21015 L
.50284 .20883 L
.50414 .20818 L
.50488 .20813 L
.50558 .2083 L
.50683 .20915 L
.50797 .21054 L
.50923 .21278 L
.51056 .21593 L
.51292 .22359 L
.51512 .233 L
.5201 .26134 L
.5255 .29788 L
.52816 .31476 L
.5306 .3277 L
.53197 .33331 L
.53267 .33564 L
.53342 .33769 L
.53417 .33926 L
.53487 .34026 L
.53571 .34087 L
.53647 .34085 L
.53778 .33952 L
.53852 .33805 L
.53921 .33625 L
.54047 .33186 L
.54181 .32578 L
.55264 .24901 L
.55834 .21231 L
.56121 .19881 L
.56283 .19292 L
.56435 .18866 L
.56503 .18712 L
.56578 .18575 L
Mistroke
.56714 .18406 L
.56846 .18343 L
.56968 .18375 L
.571 .1851 L
.57175 .18633 L
.57246 .1878 L
.57387 .1917 L
.5754 .19729 L
.57811 .21097 L
.58069 .22844 L
.58554 .27233 L
.59072 .32856 L
.59326 .35452 L
.5956 .37412 L
.59692 .38246 L
.5983 .38875 L
.59902 .39089 L
.5997 .39217 L
.60043 .39275 L
.60123 .3924 L
.6026 .38944 L
.60389 .38399 L
.60506 .37705 L
.60633 .36754 L
.61628 .2602 L
.62116 .21383 L
.6233 .19788 L
.62563 .18364 L
.62794 .17285 L
.6292 .16834 L
.63038 .16501 L
.63167 .1623 L
.63285 .16072 L
.63421 .15994 L
.6355 .16022 L
.63682 .16154 L
.63748 .16261 L
.63821 .16409 L
.63951 .16753 L
.64072 .17171 L
.64345 .18477 L
.64498 .19449 L
.64639 .20503 L
.65193 .26322 L
.65783 .3474 L
.6607 .38744 L
.6621 .4044 L
.6634 .4176 L
.66458 .42723 L
.66582 .43454 L
Mistroke
.66707 .43866 L
.66844 .43929 L
.66978 .43594 L
.67105 .42926 L
.67219 .42055 L
.67343 .40849 L
.67877 .33595 L
.68335 .26849 L
.68841 .20974 L
.69124 .1861 L
.69389 .16918 L
.6967 .15588 L
.69828 .15024 L
.69972 .14618 L
.70098 .14351 L
.70215 .14177 L
.70344 .1407 L
.70482 .14054 L
.70551 .14085 L
.70626 .14148 L
.70763 .14341 L
.70895 .14624 L
.71018 .14969 L
.71275 .15961 L
.7151 .17208 L
.71781 .19134 L
.72038 .21557 L
.72494 .2756 L
.72991 .36121 L
.73272 .41016 L
.73536 .44854 L
.73669 .46304 L
.73737 .46897 L
.73812 .47416 L
.73889 .47801 L
.73971 .48033 L
.74046 .48087 L
.74116 .47997 L
.74252 .47446 L
.7438 .46491 L
.74495 .45306 L
.7462 .43716 L
.75159 .347 L
.75637 .26635 L
.759 .23017 L
.76151 .20241 L
.76445 .17719 L
.76715 .15974 L
.76967 .14713 L
.77243 .13663 L
Mistroke
.77392 .13216 L
.77533 .12865 L
.77797 .12371 L
.77945 .12171 L
.78081 .12026 L
.7824 .11893 L
.78388 .11795 L
.78634 .11668 L
.78905 .11556 L
.79168 .11469 L
.79316 .11433 L
.79451 .11409 L
.79575 .11396 L
.79691 .11391 L
.79818 .11394 L
.79956 .11405 L
.80092 .11421 L
.80236 .11442 L
.80492 .11478 L
.80607 .11491 L
.80731 .11502 L
.80847 .11511 L
.80952 .11517 L
.81197 .1153 L
.8132 .11538 L
.81455 .1155 L
.816 .11568 L
.81735 .1159 L
.81994 .11641 L
.82298 .11708 L
.82577 .1176 L
.82839 .11797 L
.83087 .11824 L
.83635 .11898 L
.87652 .12621 L
.91926 .13451 L
.96041 .14284 L
1 .15107 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
F_ooool8o`0004kooooo002Zooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`1Gooooo`?o00001oooool7o`0004Sooooo002eooooo`03o`000?oooooooooo05Kooooo0_l0
000@ooooo`Co0000A?ooool00;Gooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0D
ooooo`Oo0000?Oooool00;Gooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Koooo
o`Go0000>?ooool00;Gooooo0_l0001Fooooo`03o`000?oooooooooo023ooooo1Ol0000cooooo`00
]Oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo02Kooooo1?l0000_ooooo`00]Ooo
ool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo02[ooooo1Ol0000Zooooo`00]Oooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0;oooool7
o`0002?ooooo002eooooo`03o`000?oooooooooo03gooooo0ol0000Dooooo`03o`000?oooooooooo
03Kooooo1Ol0000Nooooo`00]Oooool00ol0003oooooooooo`0looooo`04o`000?ooooooooooo`00
01?ooooo00?o0000ooooooooool0??ooool5o`0001Wooooo002eooooo`03o`000?oooooooooo03co
oooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo047ooooo1?l0000Eoooo
o`005_ooool3o`0009cooooo00?o0000ooooooooool0??ooool01Ol0003ooooooooooooooooo0000
01;ooooo00?o0000ooooooooool0AOooool2o`0001?ooooo000Iooooo`Go0000Uoooool2o`0003go
oooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo05[ooooo000Nooooo`Co
0000Toooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`1Kooooo`008_ooool4o`0008oooooo00?o0000ooooooooool0
9oooool2o`0001?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo05_ooooo000Eooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b
<_o^k^h01_ooool5o`0000oooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h06oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Looooo`Co0000
00So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQkooooo00?o0000ooooooooool07oooool4
o`000005oa0@4?ooooooooooo`000?lb<S800_l000000oo^k^koooooooooo`0>ooooo`03o`000?oo
oooooooo00?ooooo00Co0000oooooooooooooooo1Ol00003ooooo`06onk^k_lb<S;o0000oc8b<_o^
k^ko00006_ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0Mooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h03_ooool001Ko
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo1Ol0000:oooo
o`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go
V9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo00;ooooo00Go0000oiRHV?oooooo0000ogMgM`0@ooooo`03o`000?oooooo
oooo00?ooooo00Wo0000oooooooooooooooooiRHV?lQ8B7ok^k^oooooom4A4@00oooool01_mgMgOo
V9RHoooooonHV9SoMgMgo`0001[ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL07_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03_ooool000_ooooo1_l00002ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@013o
oooo2?l00006ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Aoooo
o`Ko00000oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41004oooool6
o`0000Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01kooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
4?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?oV9RHob4Q8Oo^k^h0
1?ooool01Ol@413ooooooooooooooooo000001oooooo00Go0000oooooooooooooooooa0@4003oooo
o`03oa0@4?oooooooooo01Wooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41003_ooool0
01?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000001Cooooo1Ol0
0004ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRH
V?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`00000Nooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo0000013ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00
000Nooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Kooooo`04odA4
A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`004oooool01?oMgMgo
EEEEooooool00004ooooo`05o`000?ooooooooooooooool000006Oooool5o`000005okZj^_oooooo
ooooooooool000000oooool00ol0003oooooooooo`0Looooo`03ogMgMomVIVKooooo00;ooooo00Go
0000ooooooooooooooooo`00000Nooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`00000Nooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo0000013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oa0@4?l0003o
^[Zj00?ooooo00Go0000ooooooooooooooooo`00000Kooooo`04omgMgOmEEEGoooooo`0000Cooooo
00Go0000ooooooooooooooooo`00000>ooooo`005?ooool00omgMgOoc<c<o`000004ooooo`05oa0@
4?ooooooooooooooool@41007Oooool5o`000005oa0@4?ooooooooooooooool@41007oooool01Ol0
003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool07?ooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41007_ooool2o`0002;ooooo00Ko0000oooooooooooooooo
o`000?l@4103ooooo`03oa0@4?l0003ooooo00gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`05ooooo`05o`000?ooooooooooooooool@41000oooool00ol0003oooooooooo`0Loooo
o`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@400Looooo`03ogMgMoo<c<co
000000Cooooo00Go410@oooooooooooooooooa0@400>ooooo`005?ooool00oo^k^koA4A4o`000004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo
1ol0000Iooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
01kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000
ooooooooool04_ooool2o`0000gooooo00_o0000ooooooooooooooooo`000?mgMgOoV9RHoooooonH
V9SoMgMgo`00000>ooooo`03o`000?oooooooooo00Cooooo00Wo0000ooooooooooooooooo`000?nj
^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9So000001_ooooo00Go410@oiRHV?oo
oooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07?ooool00oo^k^koA4A4o`000004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool001Gooooo00?oMgMgo`000?ooool00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00_ooool5o`0001Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h07_ooool00ol0003oooooooooo`0Booooo`?o00002_ooool00omEEEGoIVIVo`00
0003ooooo`07o`000?o^k^ko<S8bo`000?lb<S;ok^k^o`00000>ooooo`03o`000?oooooooooo00Go
oooo00So0000ooooooooooooV9RHoa0@4?l0003o8B4Qolc<c0?ooooo00Gok^k^oc8b<_l0003o<S8b
o`00000Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo001>oooo
o`Go0000H_ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`00013ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`1Looooo`00Doooool4o`0005kooooo00?o0000oooo
ooooool04Oooool01?l0003oooooooooool0000?ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0GOooool005Oooooo1?l0001Jooooo`03o`000?oooooooooo017ooooo00Co0000oooo
oooooooo00003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05gooooo001Koooo
o`Go0000EOooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05gooooo001Pooooo`Co
0000DOooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05gooooo000Foooooooo0000
@?l0000Cooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?o00000_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool3o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005ooooo`;o00001_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Gooooo00?o0000ooooool000001ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
o`000006ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`00
5_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo1?l00006ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01?l0003oooooo`000?l00004ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool2o`0000Kooooo00?o0000oooooooo
ool00oooool00ol0003oooooo`000005ooooo`03o`000?oooooo000000Oooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001_ooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool006oooooo0ol00013oooo
o`04o`000?ooooooooooo`0000kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0GOooool007;ooooo2_l0000hoooo
o`;o00000_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05kooooo001looooo`?o
0000=Oooool2o`0000?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Nooooo`00
Ooooool00ol0003oooooooooo`0Oooooo`?o00003oooool00ol0003oooooo`000003ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0G_ooool0083ooooo0_l00009ooooo`Ko00004?oo
ool01?l0003oooooo`000?l0000>ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`1Nooooo`00P_ooool2o`0000Gooooo0_l00006ooooo`03o`000?oo
oooooooo00cooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooo000000Cooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Nooooo`00Q?ooool5o`0000Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00Co
0000ooooool0003o00000oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05kooooo
002Booooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`1Nooooo`00Toooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0G_ooool009Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo05kooooo002Eooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`1Nooooo`00U_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool0
0005ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G_ooool009Kooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00Co0000
oooooooooooo00001Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo002G
ooooo`Co00003Oooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000001Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo002Hooooo`;o00003_ooool0
0ol0003oooooooooo`06ooooo`04o`000?ooooooooooooooo`;o00001?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo05oooooo002Xooooo`03o`000?oooooooooo00Kooooo00Go0000
ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Gooo
ool00:Sooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1Oooooo`00ZOooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo05oooooo002Yooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0Goooool00:Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Oooooo`00
ZOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo002Zooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0Goooool00:[ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`;o00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo05oooooo002[ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo002[ooooo`04o`000?oooooo0000
o`0000Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo05oooooo002/ooooo`;o00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0Goooool00;Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo05oooooo002eooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Oooooo`00Z_ooool5o`0000Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05oooooo002Z
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0Goooool00:_ooooo00?oV9RHob4Q8Oo^k^h01oooool3
o`0000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Pooooo`00[?ooool00onH
V9So8B4Qonk^kP06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Pooooo`00[Oooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Pooooo`00[_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`00000?ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Pooooo`00
Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool01_ooool01Ol0003o
oooooooooooooooo000000oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo063ooooo002Zooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0
003oooooooooo`07ooooo`04o`000?ooooooooooo`0000oooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo063ooooo002eooooo`03o`000?oooooooooo
00Oooooo00Co0000oooooooooooo00003oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0H?ooool00;Gooooo00?o0000ooooooooool01oooool01?l0
003oooooooooool0000?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1Pooooo`00]Oooool2o`0000Sooooo00Co0000oooooooooooo00003oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0H?ooool0
0;Gooooo00?o0000ooooooooool01oooool3o`00013ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo063ooooo002eooooo`03o`000?oooooooooo00So
oooo0_l0000@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`1Pooooo`00]Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Pooooo`00]Oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`1Pooooo`00]Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`1Pooooo`00]Oooool00ol0003oooooooooo`0Koooo
o`05o`000?ooooooooooooooool000003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Pooooo`00]Oooool00ol0
003oooooooooo`0Kooooo`05o`000?ooooooooooooooool000003oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1P
ooooo`00]Oooool00ol0003oooooooooo`0Kooooo`05o`000?ooooooooooooooool000003oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1Pooooo`00]Oooool2o`0001cooooo00Go0000ooooooooooooooooo`00000?
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo063ooooo002eooooo`03o`000?oooooooooo01_ooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo063ooooo002eooooo`03o`000?oooooooooo
01_ooooo00Go0000ooooooooooooooooo`00000@ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo063ooooo002eoooo
o`03o`000?oooooooooo01_ooooo00Go0000ooooooooooooooooo`00000@ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo067ooooo002eooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo00004Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1Qooooo`00]Oooool00ol0003oooooooooo`0Kooooo`04o`000?oooooooooo
o`00017ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0HOooool00;Gooooo00?o0000ooooooooool07?ooool00ol0
003oooooo`00000Aooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo067ooooo002eooooo`03o`000?oooooooooo01co
oooo00?o0000ooooool000004Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00]Oooool2o`0001gooooo
00?o0000ooooool000004Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Qooooo`00]Oooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooo0000017ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0HOooool00;Gooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0@ooooo`05o`000?ooooooooooooooool000004_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo067ooooo002eooooo`03o`000?oooooo
oooo033ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0HOooool00;Gooooo00?o0000ooooooooool0<?ooool01Ol0003ooooooooooooo
oooo000001;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Qooooo`00[?ooool2
o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0<?ooool01Ol0003ooooooooooooo
oooo000001;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Qooooo`00[Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo033ooooo00Go0000ooooooooooooooooo`00
000Booooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0HOooool00:[ooooo1Ol00006
ooooo`03o`000?oooooooooo033ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0HOooool00:[ooooo00CoA4A4omgMgOoooooo00001ooo
ool3o`00033ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0HOooool00:[ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003ooooo
ooooo`0aooooo`04o`000?ooooooooooo`0001;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`1Qooooo`00Zoooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo037ooooo
00Co0000oooooooooooo00004_ooool01Ol0003ooooooooooooooooo000006Cooooo002[ooooo`03
onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0<Oooool01?l0003oooooooooool0000Boooo
o`05o`000?ooooooooooooooool00000I?ooool00:cooooo00?oMgMgo`000?ooool01_ooool00ol0
003oooooooooo`0aooooo`04o`000?ooooooooooo`0001;ooooo00Go0000ooooooooooooooooo`00
001Tooooo`00]Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooo000001?ooooo00Go0000
ooooooooooooooooo`00001Tooooo`00]Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
000001Cooooo00Co0000oooooooooooo0000I?ooool00;Gooooo00?o0000ooooooooool0<_ooool2
o`0001Cooooo00Co0000oooooooooooo0000I?ooool00;Gooooo0_l0000cooooo`;o00005?ooool0
1?l0003oooooooooool0001Tooooo`00]Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo01;ooooo00Co0000oooooooooooo0000I?ooool00;Gooooo00?o0000ooooooooool0B?ooool0
1?l0003oooooooooool0001Tooooo`00]Oooool00ol0003oooooooooo`18ooooo`04o`000?oooooo
ooooo`0006Cooooo002eooooo`03o`000?oooooooooo04Sooooo00Co0000oooooooooooo0000I?oo
ool00;Gooooo00?o0000ooooooooool0B?ooool01?l0003oooooooooool0001Tooooo`00]Oooool0
0ol0003oooooooooo`18ooooo`04o`000?ooooooooooo`0006Cooooo002eooooo`03o`000?oooooo
oooo04Sooooo00Co0000oooooooooooo0000I?ooool00;Gooooo0_l00019ooooo`03o`000?oooooo
000006Gooooo002eooooo`03o`000?oooooooooo04Sooooo00?o0000ooooool00000IOooool00;Go
oooo00?o0000ooooooooool0B?ooool00ol0003oooooo`00001Uooooo`00]Oooool00ol0003ooooo
ooooo`18ooooo`03o`000?oooooo000006Gooooo002eooooo`03o`000?oooooooooo04Wooooo0_l0
001Uooooo`00]Oooool00ol0003oooooooooo`19ooooo`;o0000IOooool00;Gooooo00?o0000oooo
ooooool0BOooool2o`0006Gooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00:[ooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`00
0?oooooooooo0;3ooooo002Zooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000/?ooool00:[ooooo00Go
0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03oeEEEOn7
QhOooooo00Sooooo00?o0000ooooooooool0/?ooool00:[ooooo00?ogMgMoa0@4?nHV9P02?ooool0
0ol0003oooooooooo`2`ooooo`00Zoooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Zoooo
o`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OlQ
8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05oc8b<_nHV9Sooooo
oiRHV?lb<S801_ooool3o`000;3ooooo002Zooooo`05olc<c?l0003o0000o`000?o<c<`0^Oooool0
0:[ooooo00Go410@okZj^_oooooo^[Zjoa0@402iooooo`00Z_ooool01Ol0003o^[Zjoooooonj^[[o
00000;Wooooo002Zooooo`05ojVYZOl@413o0000oa0@4?nYZJT0^Oooool00?ooooooJOooool00;?o
oooo00?o0000okZj^_ooool0/_ooool00;?ooooo0_lb<S:cooooo`00Q?ooool2o`000006oa0@4?oo
oooooooooa0@4?l0003o410@6?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj
^P0Iooooo`Co000000?o410@ooooooooool01Ol0001looooo`00QOooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Oooooo1_l0000=ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@
00Wooooo1_l0000<ooooo`03o`000?oooooooooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A01l
ooooo`00QOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01_ooooo00Co0000oooo
oooooooo410@0oooool00ol@413oooooooooo`0@ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool00oooool00onHV9So8B4Qonk^kP1mooooo`00QOooool01_l0003oooooodA4A?m4A4Co
ooooo`0000Wooooo1_l0000=ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00_ooooo1_l0000<ooooo`03o`000?oooooooooo00Cooooo
00?oV9RHob4Q8Oo^k^h0O?ooool008Gooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Iooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`05ooooo`03ogMgMomVIVKooooo07_ooooo0025oooo
o`06o`000?n7QhOoZJVYokZj^_mEEEGo00006Oooool00ol0003oooooooooo`04ooooo`05oa0@4?oo
ooooooooooooool@41004?ooool00ol@413o0000o`000003o`0001cooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`1jooooo`00QOooool01_l0003o<S8boooooooooooo<S8bo`0001Wo
oooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`02ooooo`05o`000?nj^[[ooooooiRHV?l@4100O?ooool0
08Cooooo00?o410@o`000?n7QhL00_ooool00on7QhOo0000oa0@400Hooooo`Co00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^01;ooooo00?o0000ooooooooool06oooool00omEEEGoIVIVo`000004
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0O?ooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(14) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .15624 m
.04057 .16417 L
.08481 .17258 L
.12636 .18126 L
.16632 .18896 L
.17777 .1925 L
.18339 .19386 L
.18859 .19502 L
.19102 .19549 L
.19331 .19585 L
.19445 .19598 L
.19569 .1961 L
.19705 .19619 L
.19831 .19624 L
.19965 .19626 L
.20089 .19627 L
.20226 .19627 L
.20302 .19627 L
.20371 .19627 L
.20498 .19628 L
.20636 .1963 L
.20766 .19633 L
.20885 .19637 L
.21122 .19648 L
.21376 .19663 L
.21596 .19678 L
.21834 .197 L
.2198 .19717 L
.22114 .19738 L
.22379 .19794 L
.2262 .19866 L
.22876 .19964 L
.23888 .20475 L
.2442 .20769 L
.2471 .20927 L
.2498 .2106 L
.25226 .21161 L
.25364 .21205 L
.25489 .21236 L
.25626 .21261 L
.25704 .2127 L
.25776 .21275 L
.25907 .21278 L
.25973 .21276 L
.26046 .21272 L
.26173 .21258 L
.2629 .21239 L
.26424 .21212 L
.26551 .2118 L
.27024 .21019 L
Mistroke
.27543 .20785 L
.27797 .20665 L
.28031 .20567 L
.28245 .20495 L
.28352 .20469 L
.2847 .20449 L
.28588 .20438 L
.28715 .20438 L
.28834 .20449 L
.28943 .20469 L
.29073 .20504 L
.29192 .20548 L
.29462 .20688 L
.297 .20857 L
.29953 .21083 L
.30464 .21681 L
.31027 .2247 L
.31507 .23091 L
.31777 .2336 L
.31905 .2346 L
.32024 .23536 L
.3213 .23588 L
.32242 .23627 L
.32367 .23651 L
.3248 .23653 L
.32598 .23636 L
.32727 .23594 L
.32848 .23533 L
.32959 .23458 L
.33217 .23217 L
.33451 .22924 L
.3398 .22095 L
.34475 .21284 L
.34693 .2097 L
.34933 .20677 L
.35057 .20551 L
.35192 .20439 L
.35265 .20387 L
.35333 .20347 L
.35466 .2029 L
.35601 .20262 L
.35678 .20261 L
.35749 .20269 L
.35824 .20289 L
.35893 .20317 L
.35972 .20361 L
.36046 .20415 L
.36174 .20535 L
.3631 .20701 L
.36553 .21099 L
Mistroke
.36814 .21662 L
.37102 .22419 L
.37602 .23953 L
.38148 .25633 L
.38397 .26278 L
.38534 .26573 L
.38663 .26803 L
.38784 .2697 L
.38914 .27095 L
.39032 .27153 L
.39141 .27159 L
.39279 .27099 L
.39407 .26976 L
.39481 .26877 L
.39548 .26769 L
.39698 .26468 L
.40001 .25655 L
.40287 .24694 L
.40785 .22831 L
.41334 .20892 L
.41586 .20156 L
.41718 .19825 L
.41858 .19525 L
.4198 .19306 L
.42114 .19118 L
.42236 .18996 L
.42349 .18927 L
.42416 .18907 L
.42489 .18903 L
.42622 .18945 L
.42751 .19046 L
.4287 .19192 L
.42999 .1941 L
.4314 .19718 L
.43426 .20565 L
.43678 .21553 L
.43908 .22644 L
.44426 .25607 L
.44917 .2858 L
.4513 .29709 L
.45361 .3069 L
.45496 .31116 L
.4562 .31398 L
.45738 .3156 L
.45864 .31614 L
.45996 .31539 L
.46119 .31347 L
.46254 .31007 L
.46398 .30504 L
.46657 .2929 L
Mistroke
.46902 .27861 L
.4736 .24823 L
.47867 .21575 L
.48144 .20073 L
.48404 .18914 L
.48684 .1796 L
.48833 .17584 L
.4891 .17426 L
.48993 .17281 L
.49069 .17175 L
.49139 .17099 L
.49278 .17009 L
.49404 .17 L
.49538 .17068 L
.49668 .17214 L
.49742 .17332 L
.49811 .17466 L
.4995 .17808 L
.501 .18285 L
.5037 .19449 L
.50617 .20854 L
.51217 .25529 L
.51785 .30837 L
.5204 .33027 L
.5218 .34062 L
.52312 .34886 L
.52433 .35494 L
.52543 .35909 L
.52666 .36197 L
.52799 .36292 L
.52932 .36158 L
.53056 .3583 L
.53192 .35255 L
.53337 .34411 L
.53633 .32098 L
.53903 .29557 L
.54408 .24628 L
.54881 .20714 L
.55138 .19019 L
.55374 .17748 L
.55635 .16644 L
.55779 .16173 L
.55916 .15819 L
.56053 .15557 L
.56129 .15451 L
.56198 .15379 L
.56333 .15308 L
.56459 .15323 L
.56532 .15368 L
.56608 .15443 L
Mistroke
.56744 .15648 L
.5682 .15802 L
.56891 .15971 L
.57052 .16448 L
.57317 .17525 L
.57558 .18851 L
.57836 .20846 L
.581 .23229 L
.59115 .35288 L
.59362 .37806 L
.59501 .38917 L
.59628 .39694 L
.59696 .40005 L
.5977 .40259 L
.59848 .40423 L
.5992 .40482 L
.60052 .40354 L
.60126 .40151 L
.60193 .39886 L
.60314 .39227 L
.60442 .38294 L
.60671 .36112 L
.61189 .2982 L
.61671 .24031 L
.62128 .19774 L
.62377 .18053 L
.62647 .16599 L
.62893 .15599 L
.63121 .14915 L
.63248 .14631 L
.63366 .14426 L
.63497 .14271 L
.6357 .14218 L
.63638 .1419 L
.63765 .14194 L
.63838 .14231 L
.63905 .14287 L
.64041 .14468 L
.64117 .14607 L
.64187 .14759 L
.64433 .15489 L
.64661 .16435 L
.64911 .17802 L
.65176 .19688 L
.65621 .2408 L
.66111 .30722 L
.66372 .34678 L
.66657 .38779 L
.66787 .40418 L
.66926 .41911 L
Mistroke
.67057 .43025 L
.67175 .4375 L
.67301 .44195 L
.67416 .44301 L
.67543 .44078 L
.67677 .43468 L
.67793 .42646 L
.67902 .41657 L
.68149 .38763 L
.68689 .309 L
.68973 .26849 L
.69275 .23116 L
.69539 .20457 L
.69829 .18155 L
.70094 .16568 L
.70342 .15441 L
.70603 .14569 L
.70735 .14235 L
.70878 .13942 L
.71002 .13748 L
.71133 .13596 L
.71258 .13505 L
.7137 .13465 L
.7144 .13461 L
.71513 .13474 L
.71644 .13543 L
.71717 .13606 L
.71785 .13682 L
.71941 .13918 L
.72076 .14198 L
.722 .14516 L
.72479 .15473 L
.72727 .16644 L
.72958 .18054 L
.7321 .20039 L
.73479 .22757 L
.73977 .29604 L
.74428 .37216 L
.74694 .41556 L
.74942 .44888 L
.75066 .46157 L
.752 .47137 L
.75276 .47503 L
.75348 .47715 L
.75484 .47749 L
.75601 .47396 L
.75725 .46646 L
.75831 .4572 L
.75948 .44426 L
.76453 .36667 L
Mistroke
.76997 .27697 L
.77297 .23688 L
.77583 .20682 L
.77847 .18523 L
.78135 .16709 L
.78397 .15444 L
.78641 .14539 L
.78776 .14137 L
.78918 .13782 L
.79173 .13304 L
.79315 .13111 L
.79448 .12968 L
.79749 .12735 L
.80013 .1259 L
.80253 .1248 L
.80386 .12428 L
.80531 .12378 L
.80667 .12341 L
.80794 .12316 L
.80906 .12303 L
.81026 .12298 L
.8114 .12301 L
.81244 .12309 L
.81359 .12324 L
.81486 .12343 L
.81741 .12384 L
.8187 .12402 L
.81993 .12414 L
.8206 .1242 L
.82134 .12425 L
.82262 .1243 L
.82392 .12435 L
.82515 .12439 L
.82626 .12445 L
.82747 .12454 L
.82875 .12469 L
.82994 .12487 L
.8326 .12542 L
.8374 .12655 L
.83883 .12682 L
.84017 .12703 L
.84269 .1273 L
.84543 .12755 L
.84692 .12772 L
.84832 .12792 L
.85096 .12842 L
.85385 .12911 L
.85646 .12973 L
.85894 .13021 L
.86183 .13062 L
Mistroke
.86448 .1309 L
.86732 .13127 L
.86893 .13154 L
.87041 .13183 L
.91167 .1394 L
.95134 .14681 L
.99358 .155 L
1 .15624 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo05gooooo2_l00019
ooooo`00]Oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo00Oooooo1ol00013oooo
o`00]Oooool2o`0005_ooooo0_l0000Aooooo`Go0000?_ooool00;Gooooo00?o0000ooooooooool0
F_ooool00ol0003oooooooooo`0Eooooo`Go0000>Oooool00;Gooooo00?o0000ooooooooool0@?oo
ool3o`0001Oooooo00?o0000ooooooooool06_ooool7o`0003;ooooo002eooooo`03o`000?oooooo
oooo03oooooo0_l00002ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool08_ooool6
o`0002cooooo002eooooo`03o`000?oooooooooo02Sooooo0_l0000Eooooo`05o`000?oooooooooo
ooooool000005?ooool00ol0003oooooooooo`0Yooooo`Oo00009Oooool00;Gooooo00?o0000oooo
ooooool09oooool01?l0003oooooooooool0000Cooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0`ooooo`Go00008?ooool00;Gooooo00?o0000oooo
ooooool09oooool01?l0003oooooooooool0000Cooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0eooooo`Go00006oooool00;Gooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0001?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03_ooooo1?l0000G
ooooo`005_ooool3o`0009cooooo0_l0000Aooooo`?o00004oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo03oooooo1?l0000Cooooo`006Oooool5o`0009Oooooo00?o0000oooooooo
ool04?ooool01?l0003oooooo`000?l0000Booooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0E_ooool001kooooo1?l0002Cooooo`03o`000?oooooooooo00oooooo00Go0000oooooooo
ooooooooo`00000Booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0E_ooool001Go
oooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP02ooooo`Co00005?oo
ool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`Go
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01cooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^7_ooool00ol0003oooooooooo`0?ooooo`05o`000?ooooooooooooooool0
00002oooool4o`00000:oa0@4?oooooo0000onk^k_lb<S;o0000oc8b<_o^k^koooooo`00013ooooo
00?o0000ooooooooool01Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`03
o`000?oooooooooo01Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h07Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00ko
oooo000Fooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`Go
00003oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0K
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000oooooooo
ool03oooool01Ol0003ooooooooooooooooo000000gooooo00co0000ooooooooooooooooo`000?mg
MgOoV9RHoooooonHV9SoMgMgooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Go0000ob4Q
8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003ooooooooo
o`0Dooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg01ko
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko
00000_ooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00000_ooool6o`00
00Kooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo017ooooo1_l00003
ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400Cooooo`Ko00001Ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41006oooool2o`000003oooo
ool0003ooooo013ooooo00Go0000ooooooooooooooooo`00000=ooooo`06o`000?oooooooooooooo
ool0003o410@0oooool00ol@413oooooo`00000@ooooo`03o`000?oooooooooo00Gooooo00Co0000
oiRHV?lQ8B7ok^k^1?ooool01Ol@413ooooooooooooooooo410@00Cooooo00?o0000ooooooooool0
6?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool06Oooool5o`0000?o
oooo00Go410@oooooooooooooooooa0@400>ooooo`004oooool01?m4A4CogMgMooooool00004oooo
o`05o`000?ooooooooooooooool000004?ooool5o`0000Sooooo00?oZJVYoa0@4?ooool00_ooool0
1Ol0003ooooooooooooooooo000001gooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooo
oooooooo000001kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001[o
oooo0_l000000ooooooo0000o`00000@ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02_ooool01?l0003oooooooooooooool2o`0000?ooooo00?o0000ooooool000004?ooool00ol0
003oooooooooo`05ooooo`05o`000?ooooooV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooo
oooo000000Cooooo00?o0000ooooooooool05oooool00onYZJWo410@ooooo`02ooooo`05o`000?oo
ooooooooooooool000006oooool01?m4A4CogMgMooooool00004ooooo`05o`000?oooooooooooooo
ool000003_ooool001?ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo
000001Gooooo1ol000000ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000007_oo
ool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000006_ooool01Ol0003ooooooooooooooooo0000
013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`06o`000?oooooooooo
o`000?oooooo00000oooool00ol0003oooooo`00000?ooooo`03o`000?oooooooooo00Oooooo00Co
0000oooooomgMgOoIVIV0oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooooooo
ool05_ooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000006oooool01?oM
gMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool001Cooooo00?oMgMg
olc<c?l000001?ooool01Ol@413ooooooooooooooooo410@01cooooo1Ol000000ooooooo410@oooo
o`02ooooo`03oa0@4?oooooooooo01gooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@
4?oooooooooo01cooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01[o
oooo00Co0000oooooooooooooooo0_l0000?ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02_ooool01_l0003oooooooooool0003ooooooa0@40?ooooo00?o410@ooooool000003ooo
ool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooo`0000?ooooo00Go410@oooooooooooo
oooooa0@4004ooooo`03o`000?oooooooooo01Oooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413o
oooooooooooooooo410@01cooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo
410@00kooooo000Dooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0J
ooooo`05oa0@4?nHV9SooooookZj^_l000000_ooool5o`000003ogMgMooooooooooo01Wooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01Ol0003ooooooooooooooooo
0000013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`0<o`000?oooooo
ooooo`000?ooooooMgMgoiRHV?ooooooV9RHogMgMooooooo00003oooool00ol0003oooooooooo`06
ooooo`;o000000?ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o
0000ooooooooool05?ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Looooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>oooo
o`005Oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06_ooool01OnY
ZJWo410@o`000?l@413oZJVY00?ooooo00Cok^k^oc8b<_l0003o<S8b1?l0000Hooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01cooooo00?oEEEEofIVI_l0
00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Wooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00omE
EEGoIVIVo`000002ooooo`09o`000?ooooook^k^oc8b<_l0003o<S8bonk^k_oooooo000000oooooo
00?o0000ooooooooool01_ooool01OnHV9So0000o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP04ooooo`03o`000?oooooooooo01Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03_ooool004[ooooo1?l0001>ooooo`?o00004Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0Eoooool004kooooo1?l00019
ooooo`;o000000?oooooo`000?ooool04?ooool00ol0003oooooooooo`02ooooo`;o00003_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`1Gooooo`00D_ooool:o`0003oooooo00Go0000ooooooooooooooooo`00000@
ooooo`03o`000?oooooooooo00;ooooo0_l0000>ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Oooooo001Loooo
o`Go0000>_ooool01Ol0003ooooooooooooooooo000000oooooo00?o0000ooooooooool00oooool2
o`0000kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool0F?ooool0067ooooo00?o0000ooooooooool08oooool2o`00
017ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00?ooooo0_l0000=ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo05Sooooo000Foooooooo0000@?l0000Cooooo`00
5_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`?o00001oooool2o`0000Cooooo0ol00007ooooo`03o`00
0?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Go
oooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooo000000Gooooo00?o0000
ooooooooool01?ooool2o`0000Oooooo0_l00006ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooool000001oooool2o`0000Kooooo00?o0000ooooooooool00oooool00ol0003oooooo`000007
ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo000Foooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo2Ol00007ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool2o`0000Cooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo
0_l00006ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo
0_l00006ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool2o`0000Kooooo
00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooo000000Cooooo
00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo017ooooo001fooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000000cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0F?ooool007Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool000003?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1H
ooooo`00Moooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooo`00000<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Sooooo001hooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`04
o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0FOooool007Wooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooo
oooo00002oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`1Iooooo`00N_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0000:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo05Wooooo001kooooo`05o`000?ooooooooooooooool000003Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`05ooooo`;o000000?oooooo`000?ooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Ioooo
o`00O?ooool3o`0000kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0000:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo05Wooooo002=ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooo
oooo00002_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`1Iooooo`00SOooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`04
o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0FOooool008kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01_ooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0FOooool008ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0FOooool008kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo0000
00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0FOooool008oooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool01Ol0003o
oooooooooooooooo000000Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0FOooool008oooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01_ooool2o`0000;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Jooooo`00
T?ooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`06ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Joooo
o`00T?ooool01Ol0003ooooooooooooooooo000000oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`07ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1J
ooooo`00TOooool01?l0003oooooo`000?l0000?ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0F_oo
ool0097ooooo0ol0000@ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0F_ooool0
0:Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Jooooo`00Y?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo05[ooooo002Uooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0F_ooool00:Gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`07ooooo`;o00000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05[ooooo002U
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0F_ooool00:Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`1Jooooo`00YOooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo05[ooooo002Uooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
F_ooool00:Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Jooooo`00Y_ooool0
0ol0003oooooooooo`06o`0000Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo05_ooooo002Vooooo`09o`000?ooooooooooo`000?nHV9So8B4Qonk^
k_ooooooA4A400Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo05_ooooo002Vooooo`08o`000?ooooooooooo`000?ooooooV9RHob4Q8Oo^k^h7oooo
o`?o00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05_ooooo002Wooooo`03
o`000?oooooo000000;ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0Foooool00:Oooooo0ol00003ooooo`03ogMg
MomVIVKooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo05_ooooo002^ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05_ooooo002Zooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0Foooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Kooooo`00]Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Foooool0
0;Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
05_ooooo002eooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05_o
oooo002eooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000Aooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Kooooo`00
]Oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000004Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Foooool00;Gooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000017ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05_ooooo002eooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000Aooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Looooo`00]Oooool00ol0003ooooo
ooooo`04ooooo`04o`000?ooooooooooo`0001;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo05cooooo002eooooo`03o`000?oooooooooo00Cooooo
00Co0000oooooooooooo00004_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0G?ooool00;Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
o`00000Booooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1Looooo`00]Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000001;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05cooooo002e
ooooo`;o00001_ooool2o`0001?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo05cooooo002eooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05cooooo002eooooo`03
o`000?oooooooooo01_ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
05cooooo002eooooo`03o`000?oooooooooo01_ooooo00Go0000ooooooooooooooooo`00000Boooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo05cooooo002eooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooo
oooo00004oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`1Looooo`00]Oooool00ol0003oooooooooo`0Kooooo`04
o`000?ooooooooooo`0001?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0G?ooool00;Gooooo00?o0000oooooooo
ool06oooool01?l0003oooooooooool0000Cooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05cooooo002eooooo`03
o`000?oooooooooo01_ooooo00Co0000oooooooooooo00004oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Loooo
o`00]Oooool2o`0001cooooo00Co0000oooooooooooo00004oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Moooo
o`00]Oooool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0GOooool00;Gooooo00?o0000ooooooooool06oooool01?l0003oooooooooool0000Coooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo05gooooo002eooooo`03o`000?oooooooooo01cooooo00?o0000ooooool0
00004oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`1Mooooo`00]Oooool00ol0003oooooooooo`0Looooo`;o0000
5?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`1Mooooo`00[?ooool2o`000003oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool07?ooool2o`0001Cooooo00Go0000ooooooooooooooooo`00000Dooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0GOooool00:gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01?ooooo00Go0000oooooooooooooooo
o`00000Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0GOooool00:[ooooo1Ol0
0006ooooo`03o`000?oooooooooo03;ooooo00Go0000ooooooooooooooooo`00000Dooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0GOooool00:[ooooo00CoA4A4omgMgOoooooo0000
1oooool3o`0003?ooooo00Co0000oooooooooooo00005?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo05gooooo002Zooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000oooooooo
ool0<oooool01?l0003oooooooooool0000Dooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0GOooool00:_ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0cooooo`04
o`000?ooooooooooo`0001Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Moooo
o`00Zoooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo03?ooooo00Co0000oooooooo
oooo00005?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05gooooo002/ooooo`03
ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0<oooool01?l0003oooooooooool0000Doooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0GOooool00;Gooooo00?o0000oooooooo
ool0<oooool01?l0003oooooooooool0000Dooooo`05o`000?ooooooooooooooool00000H?ooool0
0;Gooooo00?o0000ooooooooool0<oooool01?l0003oooooooooool0000Dooooo`05o`000?oooooo
ooooooooool00000H?ooool00;Gooooo00?o0000ooooooooool0<oooool00ol0003oooooo`00000F
ooooo`04o`000?ooooooooooo`00063ooooo002eooooo`;o0000=Oooool2o`0001Kooooo00Co0000
oooooooooooo0000H?ooool00;Gooooo00?o0000ooooooooool0=?ooool2o`0001Kooooo00Co0000
oooooooooooo0000H?ooool00;Gooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0E
ooooo`04o`000?ooooooooooo`00063ooooo002eooooo`03o`000?oooooooooo04cooooo00Co0000
oooooooooooo0000H?ooool00;Gooooo00?o0000ooooooooool0C?ooool01?l0003oooooooooool0
001Pooooo`00]Oooool00ol0003oooooooooo`1<ooooo`04o`000?ooooooooooo`00063ooooo002e
ooooo`03o`000?oooooooooo04cooooo00Co0000oooooooooooo0000H?ooool00;Gooooo00?o0000
ooooooooool0COooool00ol0003oooooo`00001Pooooo`00]Oooool2o`0004kooooo00?o0000oooo
ool00000H?ooool00;Gooooo00?o0000ooooooooool0COooool00ol0003oooooo`00001Pooooo`00
]Oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooo0000063ooooo002eooooo`03o`000?oo
oooooooo04gooooo0_l0001Qooooo`00]Oooool00ol0003oooooooooo`1=ooooo`;o0000HOooool0
0;Gooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`1Oooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?oo
ool00:[ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Z
ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`000;3ooooo002Zooooo`05o`000?mEEEGo
0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool00omEEEGoQhN7ooooo`08
ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03omgMgOl@413oV9RH00Sooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000
/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Oo<c<co
8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go8B4QoiRHV?oo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Olb<S;oV9RHoooooonHV9So<S8b
00Kooooo0ol0002`ooooo`00Z_ooool01Oo<c<co0000o`000?l0003oc<c<0;Wooooo002Zooooo`05
oa0@4?nj^[[ooooookZj^_l@4100^Oooool00:[ooooo00Go0000okZj^_oooooo^[Zjo`00002ioooo
o`00Z_ooool01OnYZJWo410@o`000?l@413oZJVY0;Wooooo003oooooofWooooo002cooooo`03o`00
0?nj^[[ooooo0;;ooooo002cooooo`;o<S8b/oooool008Cooooo0_l000001_l@413oooooooooool@
413o0000oa0@41Sooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06Oooool4
o`000003oa0@4?oooooooooo00;ooooo0_l000000ol@413oooooooooo`1jooooo`00QOooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l0000=ooooo`09ogMgMolb<S;ooooo
oooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zj
onk^k_mgMgOo410@00Wooooo1_l0000<ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0Noooool008Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Kooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool04?ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo00;ooooo1Ol0001looooo`00QOooool01_l0003oooooodA4A?m4A4Coooooo`00
00Wooooo1_l0000=ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00_ooooo1_l0000<ooooo`03o`000?oooooooooo00;ooooo00CoA4A4
omgMgOoooooo0000OOooool008Gooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Iooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`02ooooo`04omgMgOmEEEGoooooo`0007gooooo0025oooo
o`06o`000?n7QhOoZJVYokZj^_mEEEGo00006Oooool00ol0003oooooooooo`04ooooo`05oa0@4?oo
ooooooooooooool@41004?ooool00ol@413o0000o`000003o`0001cooooo00?o0000ooooooooool0
0oooool00omgMgOoc<c<o`00001mooooo`00QOooool01_l0003o<S8boooooooooooo<S8bo`0001Wo
oooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`03ooooo`03onk^k_m4A4Co000007gooooo0024ooooo`03
oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool4o`0000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0Booooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000001_ooool00omg
MgOo0000ooooo`1looooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .16072 m
.04057 .16722 L
.06168 .17185 L
.07286 .17456 L
.079 .17583 L
.08202 .17633 L
.08481 .17672 L
.09021 .17726 L
.09306 .17746 L
.09607 .17763 L
.10136 .17786 L
.10395 .17797 L
.10632 .17809 L
.10867 .17825 L
.11091 .17846 L
.11328 .17876 L
.11586 .17918 L
.1213 .18045 L
.12636 .18207 L
.16745 .19143 L
.17764 .18829 L
.18012 .18766 L
.18149 .18738 L
.18278 .18717 L
.18351 .18707 L
.18431 .187 L
.18503 .18695 L
.1857 .18692 L
.18702 .18694 L
.18768 .18698 L
.18842 .18705 L
.18916 .18716 L
.18995 .1873 L
.19135 .18765 L
.19286 .18816 L
.19451 .18888 L
.19748 .19058 L
.20024 .19262 L
.21111 .20353 L
.21659 .20923 L
.21928 .21153 L
.22046 .21238 L
.22176 .21318 L
.22285 .21373 L
.22402 .21419 L
.22526 .21453 L
.22641 .2147 L
.22776 .21472 L
.22904 .21455 L
.23019 .21426 L
Mistroke
.23145 .21378 L
.23292 .21301 L
.23431 .21209 L
.23691 .20991 L
.24272 .20338 L
.24771 .19711 L
.25035 .19402 L
.25318 .19118 L
.25461 .18998 L
.25596 .18902 L
.25728 .18827 L
.2585 .18775 L
.25965 .18742 L
.26087 .18725 L
.2621 .18728 L
.26346 .18755 L
.26414 .18779 L
.26486 .18812 L
.26615 .18889 L
.26754 .19001 L
.26905 .19157 L
.27177 .19526 L
.2743 .19965 L
.28362 .22142 L
.28852 .23338 L
.29121 .2389 L
.29371 .24292 L
.29504 .24449 L
.29572 .24513 L
.29646 .24569 L
.29727 .24613 L
.29804 .24639 L
.29878 .24647 L
.29948 .24641 L
.3007 .24597 L
.30205 .24498 L
.30273 .2443 L
.30346 .24342 L
.30479 .24148 L
.30744 .23636 L
.31023 .22953 L
.31523 .21517 L
.31974 .20189 L
.32456 .18952 L
.32732 .18398 L
.32984 .18026 L
.33105 .17895 L
.33237 .17793 L
.33361 .17734 L
.33476 .17715 L
Mistroke
.33607 .17733 L
.33732 .17792 L
.33844 .1788 L
.33966 .18014 L
.34098 .18206 L
.34239 .18463 L
.34492 .19067 L
.34749 .19861 L
.34992 .20769 L
.35444 .22801 L
.3595 .25298 L
.36227 .26564 L
.36485 .27559 L
.36631 .28008 L
.36764 .28332 L
.3684 .28476 L
.36912 .28583 L
.36988 .28665 L
.37071 .28717 L
.37207 .28716 L
.37275 .28674 L
.37351 .28596 L
.37485 .28378 L
.3761 .28082 L
.38549 .23901 L
.39065 .21141 L
.39552 .18909 L
.39828 .17897 L
.39974 .17449 L
.40128 .17042 L
.40258 .16756 L
.40401 .16502 L
.4053 .16328 L
.40652 .16217 L
.40784 .16152 L
.40909 .16147 L
.41022 .1619 L
.41145 .16289 L
.41278 .16459 L
.4142 .16711 L
.41674 .17355 L
.41948 .18327 L
.42244 .19712 L
.4278 .23079 L
.43257 .26723 L
.4378 .30515 L
.43921 .31331 L
.44071 .32052 L
.44144 .32337 L
.44213 .32564 L
Mistroke
.44342 .32874 L
.44414 .32977 L
.4449 .33032 L
.44627 .32989 L
.44703 .32886 L
.44774 .3274 L
.44851 .32525 L
.44935 .32233 L
.45071 .31634 L
.45219 .30822 L
.45489 .29005 L
.45996 .24997 L
.46554 .20807 L
.46827 .19108 L
.47079 .17801 L
.47304 .16843 L
.47551 .1601 L
.47799 .15396 L
.47934 .15153 L
.48061 .14985 L
.48198 .1487 L
.48275 .14835 L
.48346 .14823 L
.48477 .1485 L
.48543 .14889 L
.48617 .14952 L
.48742 .15109 L
.48878 .1535 L
.49006 .15647 L
.49123 .15979 L
.49388 .16949 L
.49678 .18383 L
.49981 .20327 L
.50263 .22561 L
.50792 .27686 L
.51071 .30575 L
.51367 .33394 L
.51625 .35361 L
.51696 .35785 L
.51772 .36175 L
.51909 .36699 L
.52043 .36969 L
.52171 .36996 L
.52285 .36829 L
.5241 .36446 L
.52542 .35823 L
.52667 .35052 L
.529 .33211 L
.53422 .2801 L
.53908 .23163 L
Mistroke
.54361 .19494 L
.54618 .17879 L
.54851 .16689 L
.55111 .15653 L
.55255 .15196 L
.55388 .14845 L
.55515 .14572 L
.55655 .14337 L
.55723 .14248 L
.55796 .14169 L
.55873 .14106 L
.55945 .14066 L
.56079 .14039 L
.56147 .14049 L
.5622 .14078 L
.56351 .14177 L
.56473 .14325 L
.56594 .14528 L
.56726 .14813 L
.56965 .1551 L
.57197 .16431 L
.57411 .17513 L
.57898 .20941 L
.58144 .23232 L
.58413 .26169 L
.58962 .32928 L
.59232 .3608 L
.59351 .37296 L
.59482 .38463 L
.59591 .39262 L
.59709 .39929 L
.59833 .40392 L
.59949 .40588 L
.60079 .40526 L
.60215 .40147 L
.60331 .3958 L
.60458 .38722 L
.60746 .36031 L
.61007 .3298 L
.61595 .25795 L
.61856 .2301 L
.62139 .20454 L
.62386 .18624 L
.62653 .17043 L
.6292 .15815 L
.63165 .14967 L
.63283 .14645 L
.63411 .14351 L
.63531 .14128 L
.63645 .13961 L
Mistroke
.63714 .1388 L
.63788 .13809 L
.63919 .13723 L
.63993 .13697 L
.64071 .13685 L
.64138 .13689 L
.64211 .13707 L
.64342 .13778 L
.64416 .13839 L
.64483 .13908 L
.64613 .14082 L
.64736 .14296 L
.65003 .14941 L
.65138 .15373 L
.65286 .15942 L
.65548 .17213 L
.65794 .18763 L
.66083 .2109 L
.66348 .23754 L
.66945 .31472 L
.67443 .38433 L
.67586 .40159 L
.67721 .41556 L
.67843 .42573 L
.67975 .4338 L
.6809 .43809 L
.68217 .43965 L
.68349 .43765 L
.68473 .43251 L
.68589 .42499 L
.68694 .41604 L
.68932 .38986 L
.69479 .3136 L
.69779 .27263 L
.7006 .23915 L
.70324 .21314 L
.70609 .19051 L
.70866 .17429 L
.71106 .16225 L
.71348 .1528 L
.71487 .1485 L
.71613 .14525 L
.71737 .14264 L
.71871 .14038 L
.72013 .13859 L
.72147 .13736 L
.72262 .13663 L
.72389 .1361 L
.72521 .13583 L
.72645 .13582 L
Mistroke
.7276 .13601 L
.72866 .13638 L
.72988 .13706 L
.73104 .13801 L
.73241 .13955 L
.73365 .14141 L
.73509 .14417 L
.73644 .14745 L
.73884 .15508 L
.74145 .16613 L
.74433 .18217 L
.74737 .2044 L
.74997 .22873 L
.75282 .26212 L
.75785 .33682 L
.7605 .37989 L
.76332 .42203 L
.76451 .43702 L
.76578 .45066 L
.76651 .45708 L
.76718 .462 L
.7685 .46876 L
.76961 .47132 L
.77083 .47071 L
.7721 .4663 L
.77328 .45889 L
.774 .45296 L
.77478 .44541 L
.77619 .42906 L
.77883 .39163 L
.78476 .2985 L
.78741 .26201 L
.79021 .22977 L
.79262 .20746 L
.79524 .18811 L
.79789 .17292 L
.80041 .16177 L
.80286 .15344 L
.80513 .14756 L
.80653 .14471 L
.80784 .14247 L
.81028 .13925 L
.81166 .13789 L
.81292 .13684 L
.81577 .13505 L
.81808 .13399 L
.82023 .13325 L
.82147 .13292 L
.82259 .13268 L
.82389 .13247 L
Mistroke
.82512 .13234 L
.82631 .13227 L
.82758 .13226 L
.82866 .13228 L
.82985 .13235 L
.83113 .13244 L
.8325 .13256 L
.83499 .13281 L
.85606 .13569 L
.87822 .13929 L
.91826 .14616 L
.96088 .15344 L
1 .16072 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
H_ooool:o`0004Cooooo002eooooo`03o`000?oooooooooo02Wooooo0_l0000Hooooo`Co00006_oo
ool00ol0003oooooooooo`08ooooo`Oo0000?Oooool00;Gooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0Eooooo`;o000000?oooooo`000?ooool05_ooool00ol0003oooooooooo`02
o`0001Sooooo00?o0000ooooooooool04?ooool6o`0003Oooooo002eooooo`03o`000?oooooooooo
00oooooo0ol0000Fooooo`03o`000?oooooooooo00;o00005Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05oooool7o`00033ooooo002eooooo`03
o`000?oooooooooo00kooooo00Go0000ooooooooooooooooo`00000Dooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool07oooool5o`0002_ooooo002_ooooo`;o00001?ooool00ol0003o
ooooooooo`0>ooooo`05o`000?ooooooooooooooool000005?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo02Cooooo1Ol0000Vooooo`00[_ooool01?l0003oooooooooool00003oooo
o`03o`000?oooooooooo00kooooo00Go0000ooooooooooooooooo`00000Dooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool0:Oooool5o`00027ooooo002^ooooo`04o`000?oooooooooo
o`0000?ooooo0_l0000?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02oooooo1Ol0000Looooo`00[_ooool01Ol0
003ooooooooooooooooo000000;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0d
ooooo`Ko00005_ooool001Kooooo1?l0001mooooo`;o00005?ooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0>_ooool3o`0001?ooooo000Eoooo
o`;o000000?o410@ooooooooool01ol0000Iooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
7?ooool4o`000007oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<P02o`000003ooooool0003ooooo
01;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000>ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02?ooool4o`000008oa0@4?ooooooooooo`000?lb<S;o0000
oc8b<_o^k^h3ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool6o`0000;o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`03o`000?oooooooooo00gooooo00GoV9RHoa0@
4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Oooool2o`000009oa0@4?oo
ooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Fooooo`03o`000?oooooooooo00;o
oooo00KoMgMgoiRHV?ooooooV9RHogMgMoooool6o`0001?ooooo00Go410@okZj^_ooooooMgMgoc8b
<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool01OnHV9So8B4Qonk^k_ooooooA4A400?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHo`000003ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooo`00000>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool0
2_l0003ooooooooooooooooo0000ogMgMonHV9SooooooiRHV?mgMgL3ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool00_ooool01_nHV9So8B4Qonk^k_ooooooA4A4o`0000;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo00gooooo00Go410@okZj^_oooooo
MgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool000_ooooo1_l00002ooooo`Go00000oooool01Ol@
413ooooooooooooooooo410@00Oooooo1Ol00006ooooo`Ko00001_ooool01Ol0003ooooooooooooo
oooo410@00?ooooo00?o410@ooooooooool04Oooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h01?oo
ool01Ol@413ooooooooooooooooo410@01?ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooo0000oa0@4003ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooo`00000>ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool02_ooool01_l0003ooooooooooooooooo0000oa0@40?ooooo00Go410@ooooooooooooooooo`00
000@ooooo`03o`000?oooooooooo00Cooooo00GoV9RHob4Q8Oo^k^koooooo`000002ooooo`05oa0@
4?ooooooooooooooool@41002_ooool00ol0003oooooooooo`0Booooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0Iooooo`Go00000oooool01Ol@413ooooooooooooooooo
410@00kooooo000Cooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`00
000<ooooo`?o00003_ooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool00000
7Oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;o00000oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooool000003_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00[ooooo00Co0000oooooooooooooooo0_l00003ooooo`05o`000?oooooooooo
ooooool000004?ooool00ol0003oooooooooo`05ooooo`04oiRHV?lQ8B7ok^k^o`0000;ooooo00Go
0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo017ooooo00?oZJVYoa0@4?ooool0
0_ooool01Ol0003ooooooooooooooooo000001_ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0
003ooooooooooooooooo000000kooooo000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000
ooooooooooooooooo`00000?ooooo`[o00000oooool00ol@413o0000okZj^P03ooooo`05o`000?oo
ooooooooooooool000007_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool0
00004Oooool2o`0000_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02o`0000?o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000000ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`04o`000?oooooooooooooo
o`;o00000oooool01Ol0003ooooooooooooooooo0000013ooooo00?o0000ooooooooool01_ooool0
1_mgMgOoIVIVooooool0003oooooo`0000?ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0@ooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00000Kooooo`04
omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`005?ooool00omg
MgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41006?ooool6o`000005ob4Q8Ooooooo
ooooooooool@41000oooool00ol@413oooooooooo`0Mooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0>ooooo`04o`000?oooooo0000o`0000[ooooo00?o0000oooooooo
ool00_ooool01Ol@413oooooo`000?oooooo410@00Cooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`05ooooo`?o00003Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00[ooooo00Ko0000oooooooooooo0000ooooool@4103ooooo`05oa0@4?ooooooooooooooool00000
4?ooool00ol0003oooooooooo`07ooooo`05o`000?oooooo0000ooooool@41000oooool00ol@413o
ooooooooo`08ooooo`03o`000?oooooooooo017ooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413o
oooooooooooooooo410@01cooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo
410@00kooooo000Dooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0J
ooooo`04oa0@4?nHV9SooooookZj^P?o000000KoooooogMgMonHV9SooooooiRHV?mgMgLKooooo`05
o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00oooooo00Go0000
ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?l0003oV9RH
ogMgM`04ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01Oooool2o`0000kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`0:o`000?ooooooooooo`000?oo
ooooMgMgoiRHV?ooooooV9RHogMgM`Cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`04ooooo`0=o`000?nj^[[ooooooiRHV?l@413oooooo`000?ooooooMgMgoiRHV?ooooooV9RHogMg
M`09ooooo`03o`000?oooooooooo00oooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL07?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03_ooool001Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@02ooooo`Go000000?ok^k^ooooooooool01_ooool5
o`0000kooooo00KoV9RHoa0@4?l0003o8B4Qolc<c?ooool3o`000004oc8b<_l0003o<S8bonk^kPoo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03oeEEEOmVIVKo000000Co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool01_ooool2o`0000kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07oooo
o`03oeEEEOmVIVKo000000;ooooo00Oo0000ooooooo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`0=oiRHV?l@413o0000ob4Q8Oo<c<co
ooooo`000?ooooook^k^oc8b<_l0003o<S8bonk^kP09ooooo`03o`000?oooooooooo00oooooo00Go
ZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Oooool00omgMgOo
0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool004Kooooo1?l00003ooooo`;o
00001?ooool3o`00017ooooo0_l000000ooooooo0000o`00000Aooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool01_ooool2o`0000gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0D_ooool004[ooooo
0ol00008ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01_ooool2o`0000gooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0D_ooool005Kooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0D_ooool005Oooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool0D_ooool005Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Doooool001Koooooool00010o`0001?o
oooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooo000000Cooooo00Co0000oooooooooooo00001oooool2o`0000Ko
oooo00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00007ooooo`;o00001_oo
ool00ol0003oooooooooo`04ooooo`;o00001oooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Aooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0000;ooooo0_l00003ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000Oooooo0_l00006ooooo`03o`000?oooooooooo00Cooooo0_l00007
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooool000001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo001L
ooooo`Go00003_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05?ooooo001_oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08oooo
o`;o00002oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`1Cooooo`00L?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool2o`0000_ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0E?ooool0073ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Wooooo0_l0000:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Cooooo001aooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`;o00002_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`1Dooooo`00LOooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02Oooool2o`0000[ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0E?ooool0
07;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Wooooo0_l0000:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo05Cooooo001booooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`;o00002_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`1Dooooo`00L_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02Oooool2o`0000[ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0E?ooool007?ooooo00?o
0000ooooooooool00_l0000@ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo0_l0000:ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo05Cooooo001dooooo`?o00004Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`;o00002_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`1Dooooo`00R?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`;o00002_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`1Eooooo`00R?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`;o00002_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`1Eooooo`00R?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo000000Wooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0EOooool008Sooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool3o`0000Sooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0EOooool008Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooo`000008
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo05Gooooo0029ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ool000002?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`1Eooooo`00ROooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooo000000Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0EOooool008[ooooo00Go0000oooooooooooo
ooooo`00000@ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003o
ooooo`000008ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo05Gooooo002:ooooo`05o`000?ooooooooooooooool0
00004?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool0
00002?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`1Eooooo`00R_ooool01?l0003oooooooooool0000Aooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooo`000008ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo05Gooooo002:ooooo`04o`000?ooooooooooo`0001;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000000Sooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0EOooool008_ooooo00?o0000ooooool000004_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00_ooooo0ol00008ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Gooooo002;ooooo`?o00004_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000002?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`1Eooooo`00X?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Eooooo`00X?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooo00001oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1Eooooo`00X?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00_ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Eooooo`00XOooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooo00001_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1Eooooo`00XOooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
ooooo`Go00001_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Gooooo002Q
ooooo`03o`000?oooooooooo00;ooooo00Wo0000oooooooooooooooooiRHV?lQ8B7ok^k^oooooom4
A4@01_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Gooooo002Qooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00onHV9So8B4Qonk^kP07ooooo`Co
00001_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`1Eooooo`00X_ooool01Ol0003ooooooooooooooooo000000Go
oooo00?oV9RHob4Q8Oo^k^h01_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
05Gooooo002Rooooo`04o`000?ooooooooooo`0000Oooooo00?oMgMgofIVI_ooool01Oooool01?l0
003oooooooooool00006ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Gooooo002Rooooo`04o`000?oooooooooo
o`0000Sooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00006ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo05Gooooo002Rooooo`04o`000?ooooooooooo`0000Cooooo00Go0000okZj^_ooooooV9RH
oa0@4006ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Eooooo`00
X_ooool00ol0003oooooo`000005ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0E_ooool00:?ooooo0_l0000@ooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Fooooo`00Xoooool2o`00013o
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Kooooo002eooooo`;o
00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Kooooo002eooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Fooooo`00]Oooool01Ol0003ooooo
oooooooooooo000000Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0E_ooool00;Gooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo05Kooooo002eooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00004oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0E_ooool00;Gooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`1Fooooo`00]Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Ko
oooo002eooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00005?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0E_ooool00;Gooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Dooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Fooooo`00]Oooool2o`0000Cooooo
00?o0000ooooool000005?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0E_ooool00;Gooooo00?o0000ooooooooool00oooool00ol0003oooooo`00
000Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`1Fooooo`00]Oooool00ol0003oooooooooo`03ooooo`;o00005_ooool01Ol0003ooooooooooooo
oooo000001Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0E_ooool00;Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Dooooo`05o`000?ooooooooooooooool000005?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1Gooooo`00]Oooool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0001Gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0Eoooool00;Gooooo00?o0000ooooooooool06oooool01?l0003oooooooooool0
000Eooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo05Oooooo002eooooo`03o`000?oooooooooo01_ooooo00Co0000
oooooooooooo00005Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`1Gooooo`00]Oooool00ol0003oooooooooo`0K
ooooo`04o`000?ooooooooooo`0001Gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Eoooool00;Gooooo0_l0000L
ooooo`04o`000?ooooooooooo`0001Gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Eoooool00;Gooooo00?o0000
ooooooooool06oooool01?l0003oooooooooool0000Eooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Oooooo002e
ooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo00005Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1Gooooo`00]Oooool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0001Kooooo00Go
0000ooooooooooooooooo`00000Fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
Eoooool00;Gooooo00?o0000ooooooooool07?ooool00ol0003oooooo`00000Fooooo`05o`000?oo
ooooooooooooool000005_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Oooooo
002/ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0Looooo`;o00005ooo
ool01Ol0003ooooooooooooooooo000001Oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`1Gooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool05Oooool01?l0003oooooooooool0000Hooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0Eoooool00:[ooooo1Ol00006ooooo`03o`000?oooooooooo03Gooooo00Co
0000oooooooooooo00006?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05Oooooo
002Zooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0000eooooo`04o`000?ooooooooooo`0001So
oooo00Go0000ooooooooooooooooo`00001Jooooo`00Z_ooool01?oMgMgoEEEEooooool00007oooo
o`03o`000?oooooooooo03Gooooo00Co0000oooooooooooo00006?ooool01Ol0003ooooooooooooo
oooo000005[ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0=Oooool0
1?l0003oooooooooool0000Hooooo`05o`000?ooooooooooooooool00000F_ooool00:_ooooo00?o
k^k^odA4A?l000001oooool00ol0003oooooooooo`0fooooo`03o`000?oooooo000001Sooooo00Go
0000ooooooooooooooooo`00001Jooooo`00[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooool000006?ooool01Ol0003ooooooooooooooooo000005[ooooo
002eooooo`03o`000?oooooooooo03Kooooo00?o0000ooooool000006?ooool01Ol0003ooooooooo
oooooooo000005[ooooo002eooooo`03o`000?oooooooooo03Kooooo00?o0000ooooool000006?oo
ool01Ol0003ooooooooooooooooo000005[ooooo002eooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooool000006?ooool01Ol0003ooooooooooooooooo000005[ooooo002eooooo`;o0000=ooo
ool2o`0001Wooooo00Go0000ooooooooooooooooo`00001Jooooo`00]Oooool00ol0003ooooooooo
o`0gooooo`03o`000?oooooooooo01Oooooo00Co0000oooooooooooo0000Foooool00;Gooooo00?o
0000ooooooooool0DOooool01?l0003oooooooooool0001Kooooo`00]Oooool00ol0003ooooooooo
o`1Aooooo`04o`000?ooooooooooo`0005_ooooo002eooooo`03o`000?oooooooooo057ooooo00Co
0000oooooooooooo0000Foooool00;Gooooo00?o0000ooooooooool0DOooool01?l0003ooooooooo
ool0001Kooooo`00]Oooool00ol0003oooooooooo`1Booooo`03o`000?oooooo000005_ooooo002e
ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooool00000Foooool00;Gooooo0_l0001Coooo
o`03o`000?oooooo000005_ooooo002eooooo`03o`000?oooooooooo05;ooooo00?o0000ooooool0
0000Foooool00;Gooooo00?o0000ooooooooool0D_ooool00ol0003oooooo`00001Kooooo`00]Ooo
ool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo05[ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00:[ooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Z
ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000
oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000/?ooool00:[ooooo00Go0000oeEEEOl0003o410@olc<
c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000
ooooooooool0/?ooool00:[ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`2`oooo
o`00Zoooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05olc<c?lQ8B7o0000ob4Q
8Oo<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OlQ8B7oV9RHoooooonHV9So8B4Q
00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo0;3ooooo002Zooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`00
0;3ooooo002Zooooo`05olc<c?l0003o0000o`000?o<c<`0^Oooool00:[ooooo00Go410@okZj^_oo
oooo^[Zjoa0@402iooooo`00Z_ooool01Ol0003o^[Zjoooooonj^[[o00000;Wooooo002Zooooo`05
ojVYZOl@413o0000oa0@4?nYZJT0^Oooool00?ooooooJOooool00;?ooooo00?o0000okZj^_ooool0
/_ooool00;?ooooo0_lb<S:cooooo`00Q?ooool2o`000006oa0@4?oooooooooooa0@4?l0003o410@
6?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Iooooo`Co000000So410@
ooooooooooook^k^oc8b<_l0003o410@olc<c7cooooo0025ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01oooool6o`0000gooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9Sooooo
oiRHV?mgMgL00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Ooo
ool6o`0000cooooo00?o0000ooooooooool00_ooool01OmEEEGoMgMgoooooonHV9So8B4Q07cooooo
0025ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06oooool01?l0003ooooooooo
ool@4103ooooo`03oa0@4?oooooooooo013ooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool00000O?ooool008Gooooo00Ko0000oooooom4A4Co
A4A4ooooool00009ooooo`Ko00003Oooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`Ko00003?ooool00ol0003oooooooooo`02
ooooo`05o`000?nHV9SooooooiRHV?lQ8B40O?ooool008Gooooo00Ko0000omgMgOlb<S;oEEEEomgM
gOl0000Iooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo0000
01;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02ooooo`05o`000?mEEEGo0000
oa0@4?o<c<`0O?ooool008Gooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Iooooo`03o`000?oo
oooooooo00Cooooo00Go410@oooooooooooooooooa0@400@ooooo`03oa0@4?l0003o000000?o0000
7?ooool00ol0003oooooooooo`02ooooo`03oeEEEOn7QhOooooo07kooooo0025ooooo`06o`000?lb
<S;ooooooooooolb<S;o00006Oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL04_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo00?ogMgMoa0@
4?nHV9P0O_ooool008Cooooo00?o410@o`000?n7QhL00_ooool00on7QhOo0000oa0@400Hooooo`Co
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo00?o0000ooooooooool06oooool00omE
EEGoIVIVo`000005ooooo`04olc<c?m4A4Co0000oa0@47cooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(18) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .16266 m
.01975 .16769 L
.02981 .17108 L
.0327 .17192 L
.03544 .17258 L
.04057 .1735 L
.04329 .17385 L
.04459 .17398 L
.04581 .17408 L
.04712 .17415 L
.04782 .17418 L
.04857 .17419 L
.04935 .17419 L
.0501 .17418 L
.05077 .17416 L
.0515 .17413 L
.05284 .17403 L
.05405 .17391 L
.05678 .17356 L
.06168 .17281 L
.06446 .17243 L
.0674 .17211 L
.06894 .17197 L
.07063 .17185 L
.07137 .17181 L
.07216 .17177 L
.07291 .17175 L
.07359 .17173 L
.07429 .17173 L
.07502 .17173 L
.07635 .17178 L
.07709 .17183 L
.07778 .17189 L
.07853 .17198 L
.07935 .17209 L
.08074 .17235 L
.0822 .17271 L
.08481 .17355 L
.08751 .1747 L
.09006 .176 L
.09483 .17888 L
.10554 .18667 L
.11003 .1897 L
.11249 .19102 L
.11479 .19196 L
.11599 .19234 L
.11728 .19265 L
.11801 .19279 L
.11871 .19288 L
.12001 .19299 L
Mistroke
.12121 .193 L
.12231 .19293 L
.12353 .19277 L
.12482 .1925 L
.13505 .18703 L
.14063 .18263 L
.14584 .17889 L
.14856 .17732 L
.14996 .17665 L
.15148 .17605 L
.15235 .17577 L
.15314 .17556 L
.15391 .1754 L
.15472 .17528 L
.15544 .17522 L
.15612 .1752 L
.15687 .17523 L
.15767 .17531 L
.15899 .17558 L
.15974 .17581 L
.16043 .17608 L
.16184 .17676 L
.16334 .17771 L
.16607 .18002 L
.16854 .18271 L
.17895 .19878 L
.18443 .20841 L
.18742 .21309 L
.19022 .21664 L
.19148 .21789 L
.19267 .21886 L
.19404 .21969 L
.19529 .22017 L
.19668 .22038 L
.19796 .22028 L
.19863 .22012 L
.19937 .21984 L
.20014 .21945 L
.20086 .219 L
.20332 .2168 L
.20558 .21397 L
.21066 .20528 L
.22025 .18553 L
.22302 .18051 L
.22562 .17643 L
.228 .17341 L
.23051 .17103 L
.23184 .17013 L
.2326 .16975 L
.23332 .16947 L
Mistroke
.23456 .16919 L
.2359 .1692 L
.23665 .16934 L
.23747 .16962 L
.23825 .17001 L
.23896 .17047 L
.24032 .17161 L
.24176 .17324 L
.24459 .17764 L
.24725 .18322 L
.25223 .19701 L
.2625 .23329 L
.26499 .24151 L
.26766 .24888 L
.2692 .25219 L
.2706 .25452 L
.27127 .25539 L
.272 .25614 L
.27333 .25696 L
.27453 .25709 L
.27566 .25668 L
.27689 .25565 L
.27822 .25388 L
.27954 .25148 L
.28093 .24831 L
.28341 .24121 L
.29273 .20538 L
.2979 .18577 L
.30277 .17106 L
.30546 .16498 L
.30688 .16241 L
.30838 .16018 L
.30964 .1587 L
.31031 .15806 L
.31103 .1575 L
.3123 .15681 L
.31348 .15653 L
.31476 .15662 L
.31595 .1571 L
.31726 .15806 L
.31799 .15881 L
.31865 .15961 L
.31987 .16142 L
.32118 .16386 L
.32356 .16958 L
.3259 .17684 L
.32836 .18624 L
.33277 .20727 L
.34276 .26573 L
.34563 .28035 L
Mistroke
.34705 .28624 L
.34835 .2907 L
.34954 .29386 L
.35079 .29618 L
.35206 .29739 L
.35277 .29758 L
.35345 .29741 L
.35463 .29632 L
.35593 .294 L
.35715 .29078 L
.35829 .28695 L
.36273 .26582 L
.37271 .20486 L
.37804 .17778 L
.38104 .16604 L
.3838 .15759 L
.38623 .15199 L
.3876 .14954 L
.38888 .14773 L
.39024 .1463 L
.39148 .14543 L
.39216 .14513 L
.3929 .14496 L
.39425 .14504 L
.39546 .14556 L
.39659 .14644 L
.39783 .14786 L
.39917 .14994 L
.4005 .15258 L
.4019 .156 L
.4044 .16382 L
.40888 .18363 L
.41379 .21414 L
.41887 .25391 L
.42437 .29863 L
.4269 .31565 L
.42828 .32314 L
.42957 .32871 L
.43067 .33222 L
.43186 .33466 L
.43317 .33565 L
.43437 .33497 L
.43508 .33386 L
.43584 .33211 L
.4372 .32754 L
.43881 .31995 L
.44028 .31129 L
.44589 .26823 L
.45089 .22703 L
.45636 .18902 L
Mistroke
.4615 .16354 L
.4643 .15369 L
.46691 .14686 L
.46817 .14431 L
.46936 .14233 L
.47044 .14088 L
.47159 .13969 L
.47284 .13881 L
.47399 .13836 L
.47524 .13829 L
.4766 .13869 L
.47799 .13963 L
.47868 .14031 L
.47944 .14122 L
.48079 .14326 L
.48204 .14567 L
.48487 .15308 L
.48789 .16424 L
.49075 .17826 L
.49344 .19491 L
.49848 .23539 L
.50376 .28794 L
.5087 .33572 L
.51119 .35413 L
.51259 .36173 L
.51386 .36664 L
.51458 .3685 L
.51525 .3696 L
.51598 .37012 L
.51677 .36986 L
.51807 .36756 L
.51882 .36524 L
.51952 .36242 L
.52065 .35663 L
.52189 .34868 L
.52438 .32847 L
.52885 .2844 L
.53367 .23672 L
.53891 .19487 L
.54179 .17734 L
.54444 .16438 L
.54698 .15462 L
.54967 .1468 L
.55083 .14417 L
.55208 .14179 L
.55316 .14009 L
.55433 .1386 L
.55571 .13732 L
.55701 .13653 L
.55828 .13615 L
Mistroke
.55946 .13613 L
.56084 .13651 L
.56162 .13692 L
.56234 .13743 L
.56366 .13869 L
.56505 .1405 L
.56746 .14496 L
.56883 .1483 L
.57011 .152 L
.57297 .16258 L
.57558 .17532 L
.5786 .19422 L
.58145 .21673 L
.59159 .32782 L
.59405 .35551 L
.59671 .38034 L
.59823 .39098 L
.5989 .39463 L
.59962 .39788 L
.60096 .40166 L
.60168 .40249 L
.60236 .40249 L
.60357 .40058 L
.60488 .39583 L
.60612 .38894 L
.60726 .38072 L
.61171 .33601 L
.61693 .27438 L
.6217 .22532 L
.62661 .18784 L
.62932 .17249 L
.63189 .16095 L
.63425 .15267 L
.63644 .14682 L
.63885 .14218 L
.64019 .14029 L
.64141 .13896 L
.64277 .13785 L
.64346 .13743 L
.64421 .13706 L
.64554 .13664 L
.64678 .13651 L
.64753 .13655 L
.64825 .13667 L
.64958 .13714 L
.65033 .13755 L
.65102 .13803 L
.65258 .1395 L
.65383 .14112 L
.655 .14302 L
Mistroke
.65768 .14892 L
.66028 .15702 L
.66308 .16862 L
.66574 .1828 L
.66858 .20198 L
.67368 .24952 L
.67964 .32536 L
.68256 .36485 L
.68526 .39701 L
.68659 .41008 L
.68784 .42001 L
.68914 .42765 L
.68983 .43048 L
.69057 .43253 L
.6913 .43355 L
.69211 .43346 L
.69287 .43224 L
.69357 .43014 L
.6949 .42372 L
.69557 .41932 L
.69631 .41362 L
.6988 .38902 L
.70149 .35579 L
.70634 .29084 L
.7112 .23505 L
.71386 .21117 L
.71638 .19295 L
.71936 .17606 L
.72207 .16426 L
.72461 .1557 L
.72604 .15183 L
.72737 .14875 L
.73003 .14406 L
.73144 .14227 L
.73296 .14082 L
.73372 .14027 L
.73455 .13978 L
.73533 .13941 L
.73606 .13915 L
.73743 .13885 L
.73819 .13878 L
.73889 .13878 L
.74026 .13891 L
.74152 .1392 L
.7429 .13971 L
.7436 .14005 L
.74436 .1405 L
.74565 .14145 L
.74703 .14277 L
.74952 .14614 L
Mistroke
.7508 .14846 L
.75221 .15155 L
.75507 .15969 L
.75772 .1698 L
.76021 .18193 L
.76313 .20016 L
.76581 .22157 L
.77184 .28987 L
.77718 .36844 L
.77978 .40576 L
.78214 .43426 L
.78343 .44643 L
.78464 .45519 L
.78593 .46126 L
.78665 .46314 L
.78731 .46388 L
.78862 .46248 L
.78937 .46004 L
.79006 .45671 L
.7908 .45214 L
.79147 .44706 L
.79297 .4328 L
.80348 .2865 L
.80651 .25012 L
.80935 .22253 L
.81193 .20262 L
.81466 .1861 L
.81706 .17462 L
.8197 .1648 L
.82209 .158 L
.82432 .15323 L
.82568 .15096 L
.82696 .14918 L
.82936 .14662 L
.83195 .14466 L
.83475 .1431 L
.83724 .14204 L
.83958 .14128 L
.84091 .14096 L
.84214 .14075 L
.84281 .14067 L
.84355 .1406 L
.84489 .14055 L
.84562 .14056 L
.84631 .14058 L
.84759 .14066 L
.84897 .14079 L
.85047 .14096 L
.85565 .14145 L
.85817 .14161 L
Mistroke
.86053 .14179 L
.86172 .14191 L
.86299 .14207 L
.86569 .1425 L
.87494 .14417 L
.91836 .15046 L
.94009 .15435 L
.94965 .15639 L
.96019 .15818 L
.97949 .16052 L
1 .16266 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool03oooool2o`0001[ooooo0ol00022ooooo`00[?ooool3
o`0000Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02o`0001Oooooo0_l00000
0ooooooo0000ooooo`0Hooooo`Go00007oooool00ol0003oooooooooo`12ooooo`00Zoooool00ol0
003oooooooooo`02o`0000Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Foooo
o`04o`000?ooooooooooooooo`;o00006_ooool=o`0003cooooo002Booooo`?o00005_ooool01Ol0
003ooooooooooooooooo000000Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05oooool2o`0000cooooo1Ol0000g
ooooo`00TOooool00ol0003oooooooooo`02o`0001Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool04Oooool7o`00
033ooooo002Aooooo`05o`000?ooooooooooooooool000005?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Hoooo
o`Oo0000:Oooool0097ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool2o`0000gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool08?ooool5o`0002Cooooo001hooooo`Co00005?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool09_ooool8o`0001cooooo001gooooo`;o00000_oo
ool2o`0001?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00Gooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02kooooo
1_l0000Fooooo`005Oooool5o`000006ooooooo^k^ko<S8bo`000?lb<S;ok^k^6_ooool01OnHV9So
410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`Go00000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0<ooooo`Go00000_ooool01Oo^k^ko<S8bo`000?lb<S;o000001;ooooo00?o0000ooooooooool0
1Oooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`08ooooo`Co000000Co410@ooooooooooook^k^0_l000000olb<S;ok^k^ooooo`05oooo
o`03o`000?oooooooooo013ooooo1_l00003ooooo`05onk^k_l0003o0000oc8b<_o^k^h04Oooool0
0ol0003oooooooooo`07ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^01gooooo0_l000002Ol@413o0000o`000?l0003ok^k^oc8b<_l0003o<S8bonk^kP0>
ooooo`005_ooool01?l0003oooooooooooooool5o`000003ogMgMooooooooooo01Sooooo00Go410@
okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool01OnHV9So8B4Q
onk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool03_ooool00ol0003oooooo`000002ooooo`05ogMgMonHV9Sooooo
oiRHV?l000004_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000003Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_oo
ool01OmgMgOo0000oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool04?ooool01_l0003oV9RH
ob4Q8Oo^k^koooooodA4A0?ooooo00GoMgMgoiRHV?l0003oV9RHogMgM`0Aooooo`03o`000?oooooo
oooo00Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
7_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool000_ooooo
1_l00002ooooo`Go00000oooool01?l@413oooooooooooooool2o`0000_ooooo0ol00003ooooo`Ko
00001_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool04Oooool9o`00
0003oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4007ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool6o`0000Gooooo00?o0000ooooool000000_ooool0
1_l@413ooooooooooooooooo410@o`00017ooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000000gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00;ooooo00Go0000oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo
013ooooo00Go0000oooooonHV9So8B4Qonk^kP04ooooo`05oa0@4?oooooo0000ooooool@41004?oo
ool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413ooooo
ooooo`0Iooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00kooooo000Cooooo`04odA4
A?oMgMgoooooo`0000Cooooo00Ko0000ooooooooooooooooo`000?ooool<o`0000;ooooo1?l0000:
ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Gooooo`03o`000?oo
oooooooo00;ooooo00Co0000oiRHV?lQ8B7ok^k^0oooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`;o00000oooool01?l0003o
ooooooooooooool2o`00013ooooo00?o0000ooooooooool01oooool01?l0003oooooooooool0000<
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0?ooooo`07o`000?oo
oooooooooooooonHV9So8B4Qonk^kP03ooooo`05o`000?oooooo0000ooooool000004?ooool00ol0
003oooooooooo`0;ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000K
ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`004ooo
ool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000004_ooool2o`0000So
oooo00?o410@o`000?nj^[X00oooool00ol0003oooooooooo`06o`0001?ooooo00?o0000oooooooo
ool00oooool00ol0003oMgMgofIVIP03ooooo`05o`000?ooooooooooooooool000001oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo0_l00003ooooo`04o`000?oooooooooo
ooooo`;o00004?ooool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooo`0000cooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
0_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooo0000ooooool000004?ooool00ol0003o
ooooooooo`0:ooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00000Koooo
o`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`005?ooool0
0omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41005?ooool2o`0000Oooooo00?o
^[Zjob4Q8Oooool00_ooool01Ol@413o0000o`000?oooooo410@00Cooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000000?ooooo00Go410@oooooooooooo
oooooa0@4006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03Oooool2o`0000?o
oooo00Oo410@oooooooooooooooooa0@4?oooooo000000oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`02o`0000_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooooa0@4007ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo410@00;ooooo
00?o0000oa0@4?ooool03oooool00ol0003oooooooooo`0;ooooo`03okZj^_lQ8B7ooooo00;ooooo
00Go410@oooooooooooooooooa0@400Looooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooo
oooooooooa0@400>ooooo`005?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL05_ooool02Ol0003ooooooooooooooooo410@oiRHV?oooooo^[Zjo`000003ooooo`05o`00
0?nHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;o
oooo00Go0000okZj^_l0003oV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00cooooo0_l00003ooooo`07ogMgMonHV9So
oooooiRHV?mgMgOoooooo`00000?ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo
00003?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00[o0000oooooooo
ooooooooo`000?mgMgOoV9RHoooooonHV9SoMgMg1oooool00ol0003oooooooooo`0>ooooo`07o`00
0?oooooo0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9Soooooo`000?mgMgL03oooool0
0ol0003oooooooooo`09ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg01cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00ko
oooo000Eooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Gooooo`;o
000000OoooooojVYZOl@413o0000oa0@4?nYZJWooooo00;o000000Gok^k^oc8b<_l0003o<S8bonk^
kP04ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00oooool01OnHV9So410@o`00
0?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool02_ooool00omEEEGoIVIVo`000004ooooo`07onk^k_lb<S;o0000oc8b
<_o^k^koooooo`00000>ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00003?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?oEEEEofIVI_l000000ooo
ool01_l0003ok^k^oc8b<_l0003o<S8bonk^kPOooooo00?o0000ooooooooool03Oooool02?l0003o
oooooooooonHV9So410@o`000?lQ8B7oc<c<0oooool01Oo^k^ko<S8bo`000?l0003ok^k^00oooooo
00?o0000ooooooooool02Oooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0Mooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>
ooooo`00>Oooool00ol0003oooooooooo`02ooooo`;o00003?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooool000002oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1<oooo
o`00>_ooool4o`0000oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooo000000_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0C?ooool004kooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo000000_ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
COooool004oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooo000000_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0COooool004oooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooo000000_ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0COooool0
01Koooooool00010o`0001?ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooo
oooo00001?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooo`000005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooo000000Oooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`04ooooo`;o
00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo017ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00001?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooool000001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`;o00001oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000oooo
ooooool00oooool00ol0003oooooo`000007ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01?ooool2
o`0000Oooooo00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooool000001oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Aooooo`00DOooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooool000002oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1>ooooo`00D_ooool2
o`0000;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02oooool2o`0000[ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0C_ooool0
05?ooooo0ol0000Booooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0<ooooo`;o00002_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1>ooooo`00J?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03?ooool2o`0000[o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0C_ooool006Sooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00cooooo0_l0000:ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04kooooo
001Yooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0<ooooo`;o00002_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1>ooooo`00JOooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03?ooool3o`0000Wooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0C_ooool006Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00cooooo0_l0000:ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04kooooo001Zooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0<ooooo`;o
00002_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`1?ooooo`00J_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool03?ooool2o`0000[ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
Coooool006[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00cooooo0_l0000:ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04oooooo001[ooooo`05o`000?oooooo
ooooooooool000004_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0=ooooo`;o00002_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`1?ooooo`00Joooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04oooooo001/ooooo`?o00004oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Coooool0
06gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0>ooooo`;o00002?ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`1?ooooo`00Poooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0Coooool008?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo04oooooo0023ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`1?ooooo`00Poooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0D?ooool008Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo053ooooo0024ooooo`05
o`000?ooooooooooooooool000004oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00kooooo0_l00007ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo053ooooo0024ooooo`05o`000?oooooooooooooo
ool000004oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00oooooo0_l00007oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo053ooooo0024ooooo`05o`000?ooooooooooooooool000004oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00oooooo0_l00007ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
053ooooo0024ooooo`05o`000?ooooooooooooooool000004oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00oooooo0_l00007ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo053ooooo0025ooooo`03
o`000?oooooo000001Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0?ooooo`;o
00001oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`1@ooooo`00QOooool00ol0003oooooo`00000Eooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool03oooool2o`0000Oooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
D?ooool008Gooooo0ol0000Eooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03ooo
ool2o`0000Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0D?ooool009gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0?ooooo`;o00001oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1@ooooo`00WOooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo1Ol00006ooooo`03o`000?oooooo0000
00Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0D?ooool009gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`05ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooo`000006oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo053ooooo002Nooooo`05o`000?ooooooooooooooool000002?ooool00onH
V9So8B4Qonk^kP07ooooo`?o00001Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1@ooooo`00W_ooool01Ol0003o
oooooooooooooooo000000Wooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooo`000005oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo053ooooo002Nooooo`05o`000?ooooooooooooooool000002_ooool00omg
MgOoIVIVooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0DOooool009ko
oooo00Co0000oooooooooooo00003?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo0000
00Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0DOooool009kooooo00Co0000oooooooooooo00002?ooool01Ol0
003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1A
ooooo`00W_ooool01?l0003oooooooooool00008ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_oo
ool00ol0003oooooo`000005ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo057ooooo002Nooooo`04o`000?oooooo
ooooo`0001?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Aooooo`00W_oo
ool00ol0003oooooo`00000Dooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
DOooool009oooooo0_l0000Dooooo`;o000000?oooooo`000?ooool00oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1Aooooo`00X?ooool00ol0003oooooooooo`0Booooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0DOooool00;Gooooo00Co0000oooooooooooo00000oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1Aooooo`00]Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo057ooooo002e
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0DOooool00;Gooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1Aooooo`00]Oooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo057ooooo002eooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0DOooool00;Gooooo00Oo0000ooooooooooooooooo`000?oooooo000001Oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo057ooooo
002eooooo`;o00000_ooool00ol0003oooooo`00000Gooooo`05o`000?ooooooooooooooool00000
5oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`1Booooo`00]Oooool01ol0003ooooooooooooooooo0000ooooool0
00005oooool01Ol0003ooooooooooooooooo000001Oooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0D_ooool00;Go
oooo00?o0000ooooooooool00_ooool2o`0001Oooooo00Go0000ooooooooooooooooo`00000Goooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo05;ooooo002eooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool05oooool01?l0003oooooooooool0000Gooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05;ooooo002eooooo`03
o`000?oooooooooo01cooooo00Co0000oooooooooooo00005oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Boooo
o`00]Oooool00ol0003oooooooooo`0Looooo`04o`000?ooooooooooo`0001Oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0D_ooool00;Gooooo00?o0000ooooooooool07?ooool01?l0003oooooooooool0000Goooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo05;ooooo002eooooo`03o`000?oooooooooo01cooooo00Co0000oooooooo
oooo00006?ooool01Ol0003ooooooooooooooooo000001Sooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1Booooo`00]Oooool2o`0001gooooo00Co0000oooooooooooo00006?ooool0
1Ol0003ooooooooooooooooo000001Sooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1Booooo`00]Oooool00ol0003oooooooooo`0Looooo`04o`000?ooooooooooo`0001Sooooo00Go
0000ooooooooooooooooo`00000Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
D_ooool00;Gooooo00?o0000ooooooooool07?ooool01?l0003oooooooooool0000Hooooo`05o`00
0?ooooooooooooooool000006Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05;o
oooo002eooooo`03o`000?oooooooooo01gooooo0_l0000Iooooo`05o`000?ooooooooooooooool0
00006Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05;ooooo002eooooo`03o`00
0?oooooooooo01gooooo0_l0000Iooooo`05o`000?ooooooooooooooool000006Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo05;ooooo002/ooooo`;o000000?o410@ooooooooool0
1?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Sooooo00Co0000oooooooooooo
00006_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05;ooooo002]ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0>?ooool01?l0003oooooooooool0000Jooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0D_ooool00:[ooooo1Ol00006ooooo`03o`00
0?oooooooooo03Sooooo00Co0000oooooooooooo00006_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo05;ooooo002Zooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0000hooooo`04
o`000?ooooooooooo`0001[ooooo00Go0000ooooooooooooooooo`00001Eooooo`00Z_ooool01?oM
gMgoEEEEooooool00007ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooool000006_ooool0
1Ol0003ooooooooooooooooo000005Gooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000
ooooooooool0>Oooool00ol0003oooooo`00000Jooooo`05o`000?ooooooooooooooool00000EOoo
ool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
000001_ooooo00Co0000oooooooooooo0000EOooool00:cooooo00?oMgMgo`000?ooool01_ooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooo000001_ooooo00Co0000oooooooooooo0000EOoo
ool00;Gooooo00?o0000ooooooooool0>Oooool00ol0003oooooo`00000Kooooo`04o`000?oooooo
ooooo`0005Gooooo002eooooo`03o`000?oooooooooo03Wooooo0ol0000Kooooo`04o`000?oooooo
ooooo`0005Gooooo002eooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool06_ooool0
1?l0003oooooooooool0001Eooooo`00]Oooool2o`0005Sooooo00Co0000oooooooooooo0000EOoo
ool00;Gooooo00?o0000ooooooooool0Eoooool01?l0003oooooooooool0001Eooooo`00]Oooool0
0ol0003oooooooooo`1Gooooo`04o`000?ooooooooooo`0005Gooooo002eooooo`03o`000?oooooo
oooo05Oooooo00Co0000oooooooooooo0000EOooool00;Gooooo00?o0000ooooooooool0Eoooool0
1?l0003oooooooooool0001Eooooo`00]Oooool00ol0003oooooooooo`1Hooooo`;o0000E_ooool0
0;Gooooo00?o0000ooooooooool0F?ooool2o`0005Kooooo002eooooo`03o`000?oooooooooo05So
oooo0_l0001Fooooo`00]Oooool2o`0005Wooooo0_l0001Fooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0
003oooooooooo`2`ooooo`00Z_ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000oooo
ooooool0/?ooool00:[ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
0;3ooooo002Zooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`000;3ooooo002Zooooo`05
o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool00omEEEGo
QhN7ooooo`08ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03omgMgOl@413oV9RH00Sooooo
00?o0000ooooooooool0/?ooool00:_ooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go
8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Olb<S;oV9RHoooo
oonHV9So<S8b00Kooooo0ol0002`ooooo`00Z_ooool01Oo<c<co0000o`000?l0003oc<c<0;Wooooo
002Zooooo`05oa0@4?nj^[[ooooookZj^_l@4100^Oooool00:[ooooo00Go0000okZj^_oooooo^[Zj
o`00002iooooo`00Z_ooool01OnYZJWo410@o`000?l@413oZJVY0;Wooooo003oooooofWooooo002c
ooooo`03o`000?nj^[[ooooo0;;ooooo002cooooo`;o<S8b/oooool008Cooooo0_l000001_l@413o
ooooooooool@413o0000oa0@41Sooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj
^[X06Oooool4o`000008oa0@4?ooooooooooolc<c?lQ8B7o0000ob4Q8Oo<c<alooooo`00QOooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l0000=ooooo`09ogMgMolb<S;o
oooooooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o
^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<ooooo`03o`000?oooooooooo00;ooooo00Go8B4QoiRH
V?ooooooV9RHob4Q8@1looooo`00QOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01_ooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`0@ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000007cooooo0025
ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000gooooo00GoMgMgoc8b<_oooooo
ooooo`000003ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02oooool6o`0000co
oooo00?o0000ooooooooool00_ooool01Olb<S;oV9RHoooooonHV9So<S8b07cooooo0025ooooo`06
o`000?oMgMgo<S8boeEEEOoMgMgo00006Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go
0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
0_ooool01Oo<c<co0000o`000?l0003oc<c<07cooooo0025ooooo`06o`000?n7QhOoZJVYokZj^_mE
EEGo00006Oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol@413o0000o`000003o`0001cooooo00?o0000ooooooooool00_ooool01Ol@413o^[Zjoooooonj
^[[o410@07cooooo0025ooooo`06o`000?lb<S;ooooooooooolb<S;o00006Oooool00ol0003ooooo
ooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo00;ooooo00Go0000okZj^_oooooo^[Zjo`00001looooo`00Q?ooool00ol@413o
0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h04_ooool00ol0003oooooooooo`0Kooooo`03oeEEEOmVIVKo000000Cooooo00GoZJVYoa0@
4?l0003o410@ojVYZ@1looooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .17246 m
.00123 .17267 L
.00236 .17282 L
.00365 .17295 L
.00488 .17302 L
.00601 .17303 L
.00706 .173 L
.00821 .17291 L
.00942 .17276 L
.01065 .17255 L
.01196 .17227 L
.01434 .17164 L
.01975 .16984 L
.0297 .16622 L
.03243 .16534 L
.03393 .16494 L
.03534 .16463 L
.03665 .16442 L
.0374 .16433 L
.03808 .16427 L
.03929 .16422 L
.04057 .16425 L
.0413 .16431 L
.04198 .16438 L
.04275 .16449 L
.04349 .16463 L
.04479 .16493 L
.04621 .16536 L
.04943 .16667 L
.05241 .16835 L
.05787 .17262 L
.06367 .17861 L
.07384 .18942 L
.07663 .1918 L
.07815 .1929 L
.07956 .19378 L
.08088 .19447 L
.08207 .19496 L
.08339 .19535 L
.08412 .19549 L
.08481 .19557 L
.08599 .1956 L
.08729 .19546 L
.08864 .19512 L
.08991 .19464 L
.0911 .19403 L
.09218 .19337 L
.09462 .1915 L
.10007 .18591 L
.10525 .17954 L
Mistroke
.1097 .17393 L
.11444 .16862 L
.11716 .1662 L
.11963 .16454 L
.12082 .16395 L
.12211 .16346 L
.12333 .16315 L
.12445 .16301 L
.12578 .163 L
.12704 .16318 L
.12817 .16348 L
.1294 .16399 L
.13073 .16474 L
.13215 .16577 L
.1347 .16828 L
.13704 .17134 L
.13924 .17485 L
.14425 .18483 L
.15484 .21019 L
.15741 .21582 L
.16015 .22093 L
.16173 .2233 L
.16317 .22501 L
.16386 .22568 L
.16461 .22627 L
.16596 .22701 L
.16729 .22728 L
.16852 .22714 L
.16988 .22653 L
.17064 .22599 L
.17134 .22538 L
.17273 .2238 L
.17425 .2216 L
.17702 .21644 L
.1872 .19001 L
.19202 .17706 L
.19455 .171 L
.19722 .16544 L
.19957 .16136 L
.20213 .15783 L
.20326 .15661 L
.20447 .15552 L
.20561 .15471 L
.20664 .15417 L
.2079 .15375 L
.20907 .15361 L
.21035 .15375 L
.21171 .15424 L
.21288 .15495 L
.21398 .15587 L
Mistroke
.21519 .15717 L
.21649 .15891 L
.21941 .16413 L
.22218 .17078 L
.22738 .18746 L
.23805 .23291 L
.24113 .24543 L
.24402 .25513 L
.24528 .25847 L
.24662 .26129 L
.24732 .26245 L
.24808 .26348 L
.24943 .2646 L
.2501 .26483 L
.25082 .26483 L
.25215 .26418 L
.25343 .26273 L
.25462 .26071 L
.25591 .25784 L
.25733 .25391 L
.26019 .24384 L
.27024 .1983 L
.27504 .17812 L
.27755 .16912 L
.2802 .16105 L
.28253 .15517 L
.28508 .15004 L
.2862 .14821 L
.2874 .14655 L
.28851 .14528 L
.28955 .14433 L
.29085 .14347 L
.29153 .14316 L
.29227 .14294 L
.29305 .14284 L
.29378 .14288 L
.29515 .14327 L
.29644 .14403 L
.29762 .14508 L
.29893 .14663 L
.30032 .14874 L
.30347 .15538 L
.30644 .16406 L
.31198 .18703 L
.32228 .24926 L
.325 .26635 L
.3279 .28235 L
.32931 .28877 L
.33065 .2938 L
.33184 .29736 L
Mistroke
.33314 .3001 L
.33436 .30153 L
.33569 .30183 L
.33636 .30146 L
.33708 .30068 L
.33839 .29829 L
.33969 .29472 L
.34092 .29028 L
.34323 .27959 L
.35428 .21004 L
.35878 .18476 L
.36357 .16369 L
.36632 .15442 L
.36882 .14776 L
.37133 .14267 L
.3737 .13927 L
.37492 .13803 L
.37622 .13708 L
.37746 .13652 L
.37858 .1363 L
.3799 .1364 L
.38065 .13662 L
.38133 .13693 L
.3826 .13777 L
.38394 .13906 L
.38522 .14068 L
.3866 .14289 L
.38909 .14817 L
.39205 .15683 L
.39477 .16731 L
.39928 .19052 L
.40422 .22423 L
.40899 .26276 L
.41416 .3036 L
.41556 .31291 L
.41705 .32136 L
.41832 .32721 L
.41904 .32994 L
.41971 .332 L
.42101 .33476 L
.42173 .33555 L
.42241 .33579 L
.42363 .33503 L
.42495 .33248 L
.42624 .32833 L
.42741 .32325 L
.43003 .30798 L
.43475 .27188 L
.44032 .22671 L
.44621 .18716 L
Mistroke
.45123 .16287 L
.45408 .15287 L
.45674 .14578 L
.458 .1431 L
.45937 .14065 L
.46057 .13886 L
.46185 .13731 L
.46301 .13621 L
.46428 .1353 L
.46543 .13473 L
.46651 .13443 L
.4678 .13436 L
.46914 .13462 L
.47029 .13513 L
.47155 .13601 L
.47291 .13734 L
.47437 .13925 L
.47698 .14404 L
.47981 .15139 L
.48288 .16216 L
.48578 .17539 L
.48844 .19054 L
.4935 .22794 L
.49885 .27813 L
.50129 .30223 L
.50395 .32679 L
.50629 .34509 L
.50757 .35316 L
.50878 .35922 L
.51015 .3641 L
.51088 .36576 L
.51167 .3668 L
.51235 .36707 L
.51307 .36671 L
.51435 .36445 L
.51561 .36028 L
.51678 .35475 L
.51944 .33713 L
.52866 .25066 L
.53352 .20992 L
.53868 .17797 L
.5414 .16541 L
.54441 .15454 L
.54714 .14705 L
.5497 .14192 L
.55104 .13988 L
.55232 .13832 L
.55347 .13723 L
.55472 .13632 L
.55608 .13566 L
Mistroke
.55683 .13542 L
.55752 .13528 L
.55886 .13522 L
.56012 .1354 L
.56125 .13576 L
.56249 .13638 L
.56379 .1373 L
.565 .13844 L
.56717 .14124 L
.56949 .1455 L
.57221 .15243 L
.57479 .1612 L
.57729 .17196 L
.57963 .18434 L
.58445 .21799 L
.58977 .26905 L
.59539 .33238 L
.59785 .35799 L
.59915 .36975 L
.60054 .38044 L
.60177 .38798 L
.60289 .39306 L
.60401 .39635 L
.60507 .3977 L
.60626 .39716 L
.60736 .39475 L
.60857 .39007 L
.60985 .38295 L
.61232 .3638 L
.61462 .34109 L
.61988 .28274 L
.62511 .23021 L
.62787 .20795 L
.63081 .18871 L
.63364 .1741 L
.6362 .1637 L
.63877 .1555 L
.64119 .14954 L
.64356 .14512 L
.64486 .14323 L
.64606 .14177 L
.64718 .14067 L
.6482 .13986 L
.64933 .13915 L
.65055 .13861 L
.65184 .13826 L
.65304 .13813 L
.65435 .13819 L
.65501 .13831 L
.65574 .13849 L
Mistroke
.65696 .13894 L
.65828 .13964 L
.65952 .14051 L
.66065 .1415 L
.662 .14295 L
.66327 .14461 L
.66565 .14863 L
.66821 .15452 L
.67098 .1631 L
.67341 .17283 L
.67597 .18575 L
.68057 .21711 L
.69106 .33279 L
.69383 .36727 L
.69529 .38387 L
.69684 .39941 L
.69819 .41063 L
.69891 .41556 L
.69969 .41999 L
.70105 .42539 L
.70232 .42754 L
.70363 .42675 L
.70437 .42496 L
.70506 .42245 L
.70579 .41892 L
.70645 .41498 L
.70794 .40379 L
.71059 .37731 L
.71309 .34737 L
.71821 .28392 L
.72292 .23465 L
.7274 .20018 L
.72966 .18699 L
.73215 .17523 L
.73465 .16597 L
.73732 .15839 L
.73985 .15311 L
.74217 .14954 L
.74352 .1479 L
.7448 .1466 L
.74718 .14474 L
.74851 .14396 L
.74974 .14342 L
.75109 .14299 L
.75177 .14285 L
.75252 .14274 L
.75377 .14269 L
.75492 .14277 L
.75624 .14303 L
.75749 .14344 L
Mistroke
.75864 .14395 L
.75971 .14454 L
.76212 .14629 L
.76471 .14888 L
.76714 .15215 L
.76981 .15699 L
.77268 .16416 L
.77553 .17386 L
.77853 .1875 L
.78109 .20248 L
.78389 .22309 L
.78945 .27947 L
.79469 .3494 L
.79946 .41259 L
.80186 .43686 L
.80323 .4468 L
.8045 .45308 L
.80589 .45634 L
.80715 .45596 L
.80785 .45438 L
.80861 .45156 L
.81 .44365 L
.81127 .43347 L
.81263 .42 L
.81506 .39064 L
.82103 .30924 L
.82364 .27684 L
.82651 .24655 L
.82906 .2244 L
.83178 .20528 L
.83467 .18947 L
.83735 .1781 L
.83886 .17294 L
.8405 .16821 L
.84194 .16473 L
.84348 .16165 L
.84638 .15723 L
.84905 .15434 L
.85156 .15231 L
.85426 .15062 L
.85681 .14941 L
.85794 .14899 L
.85914 .14862 L
.85988 .14843 L
.86055 .14829 L
.86186 .14808 L
.8626 .14799 L
.86339 .14793 L
.86415 .14789 L
.86484 .14788 L
Mistroke
.86609 .14788 L
.86747 .14791 L
.86816 .14793 L
.86891 .14796 L
.87025 .14801 L
.87294 .14811 L
.87441 .14816 L
.8758 .14822 L
.87697 .1483 L
.87824 .1484 L
.87964 .14856 L
.88093 .14874 L
.88659 .14988 L
.89255 .15111 L
.90276 .15324 L
.90838 .15463 L
.91368 .15557 L
.91889 .15623 L
.92163 .15658 L
.92453 .15694 L
.92571 .15706 L
.92698 .15717 L
.9277 .15723 L
.92837 .15727 L
.92967 .15732 L
.93083 .15734 L
.9321 .15734 L
.93329 .15733 L
.9344 .1573 L
.93561 .15727 L
.93693 .15723 L
.93816 .15721 L
.9393 .15719 L
.94033 .15719 L
.94146 .15719 L
.94264 .15721 L
.94374 .15723 L
.94891 .15736 L
.95118 .15741 L
.95247 .15745 L
.95368 .1575 L
.95492 .15756 L
.95624 .15767 L
.95766 .15782 L
.95896 .158 L
.96175 .15852 L
.96468 .15926 L
.97509 .16273 L
.9852 .16739 L
.98974 .16942 L
Mistroke
.99459 .17113 L
.99743 .1719 L
1 .17246 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool008gooooo0ol0000Iooooo`Co00002?ooool00ol0003oooooooooo`0>ooooo`Co0000W_oo
ool008gooooo00Co0000ooooool0003o00005oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool03Oooool2o`0000?ooooo00?o0000ooooooooool05ooo
ool5o`0007oooooo001booooo`?o00005oooool01?l0003oooooooooooooool2o`0001Kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Fooooo`;o00000oooool00ol0003ooooooooo
o`0Iooooo`Co0000H?ooool0077ooooo0_l000000ooooooo0000o`00000Fooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Gooooo`;o00000_ooool2
o`0005oooooo001aooooo`05o`000?ooooooooooooooool000005Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo01[ooooo3?l0000fooooo`00L?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Hoooo
o`;o00002oooool3o`0003?ooooo001Gooooo`Co00005Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0000cooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool03_ooool6o`0002gooooo001Fooooo`04o`000?ooooooooooooooo`;o00005?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo01Gooooo4?l0000Mooooo`00EOooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo01[ooooo000Eooooo`;o000000Wo410@oooooooooooooooo
onk^k_lb<S;o0000oc8b<_o^k^h01Ol0000Eooooo`03oiRHV?l@413o000000?o00000_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03
ooooo`Go00000oooool01_o^k^ko<S8bo`000?lb<S;ok^k^o`0000Oooooo00?o0000ooooooooool0
3oooool00ol0003oooooo`000003o`000004oa0@4?ooooooooooonk^kP;o000000?o<S8bonk^k_oo
ool03Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo1?l000002?l@413o
ooooooooooo^k^ko<S8bo`000?lb<S;ok^k^2?ooool00ol0003oooooooooo`0?ooooo`Go00000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo00?o0000ooooooooool04oooool02?l0003ooooo
oooooonHV9So410@o`000?lb<S;oc<c<0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo1Ol0
00002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0>ooooo`005_ooool00ol0003o
ooooooooo`02ooooo`03ogMgMonHV9Sooooo00;o00001Oooool2o`0001?ooooo0_l000001?oooooo
MgMgoc8b<_ooool2o`000005ogMgMonHV9SooooooiRHV?mgMgL03Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonH
V9SooooooiRHV?l000002?ooool00ol0003oooooooooo`0?ooooo`05o`000?ooooooooooooooool0
00001?ooool01OmgMgOo0000oooooonHV9SoMgMg00kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?l0003oV9RHogMgM`08
ooooo`03o`000?oooooooooo00oooooo00GoV9RHob4Q8Oo^k^ko0000odA4A003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00_ooool00ol0003oooooooooo`0Booooo`09o`000?ooooooooooooooool@
413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`;o00001?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko00000_ooool5o`0000;ooooo1?l0
00000ooooooo410@ooooo`06ooooo`03o`000?oooooooooo00Sooooo1_l00002ooooo`05o`000?oo
ooooooooooooool000000_ooool00ol0003o410@ooooo`02ooooo`03oa0@4?oooooooooo00_ooooo
00?o0000ooooooooool00oooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooo
oooooooooooo000000Sooooo00?o0000ooooooooool02?ooool6o`000003ooooool0003ooooo00;o
oooo00?o0000ooooooooool00_ooool01Ol@413o0000oooooooooooo410@00kooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00Go410@o`00
0?oooooooooooa0@4009ooooo`03o`000?oooooooooo00oooooo00?oV9RHob4Q8Ol000001?ooool0
1Ol@413ooooooooooooooooo410@00?ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`05ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Iooooo`Oo0000
00?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0<ooooo`004oooool00om4A4CogMgMoooo
o`04o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0>ooooo`06o`000?oooooooooooooooonYZJWo410@0oooool01Ol0003ooooooooooooooooo0000
00gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo00kooooo00Go0000
ooooooooooooooooo`000004ooooo`;o00000_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`;o00000_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo013ooooo00?o0000ob4Q8Oo^k^h00ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`04ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Kooooo`04
odA4A?oMgMgoooooo`0000?ooooo0_l00003ooooo`03o`000?oooooooooo00cooooo000Cooooo`04
omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooo
oooo00cooooo00Oo0000oooooooooooooooooa0@4?l0003o^[Zj00?ooooo00Go0000oooooooooooo
ooooo`00000<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00omgMgOo
IVIVooooo`02ooooo`03o`000?oooooooooo00;o00002Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003oooooo`000?oooooo0000
00gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00;ooooo0_l00002ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04?ooool00ol0
003oMgMgofIVIP03ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00Cooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooo
oooo000001_ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000ko
oooo000Dooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@400:ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool00onj^[[o8B4Qooooo`02ooooo`05
oa0@4?l0003oooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Kooooo00Go0000oooooooooooooooooa0@4002ooooo`03o`000?l@413ooooo00Sooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go410@
ooooool0003ooooooa0@400=ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_oo
ool2o`0000[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00;ooooo00Go410@o`000?oooooooooooa0@4009ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooool000000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`05ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooo
oooooooooa0@400Looooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@400>
ooooo`005?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
0ol0003oooooooooo`09ooooo`08o`000?oooooooooooa0@4?nHV9SooooookZj^_l00003ooooo`05
ogMgMol0003ooooooiRHV?mgMgL02oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00;ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9Soooooo`000?mgMgL02_oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHo`000?nHV9SoMgMg00gooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00;ooooo00GoMgMgo`000?ooooooV9RHogMgM`0:ooooo`03
o`000?oooooooooo00gooooo0_l000000oooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Go410@oiRH
V?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07?ooool00oo^k^koA4A4o`00
0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool001Gooooo00?oMgMgo`000?ooool00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?o0000ooooooooool01oooool02Ol0003ooooo
ooooooooooooZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool00ol0003oooooooooo`09ooooo`09o`000?oooooooooooooooonHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o0000onk^kP0:ooooo`03o`000?oooooooooo00cooooo00Ko0000
ooooooooooooEEEEofIVI_l00004ooooo`05onk^k_lb<S;o0000o`000?o^k^h03Oooool00ol0003o
ooooooooo`0:ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Kooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko0000o`000?lb<S;o
k^k^00[ooooo00?o0000ooooooooool03Oooool01OnHV9So0000o`000?lQ8B7oc<c<00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP04ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
0oooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Moooo
o`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`00;Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0:ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`16
ooooo`00;_ooool2o`0000?ooooo0_l0000@ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02_ooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0A_ooool0
02oooooo1Ol0000Aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02_ooool01Ol0
003ooooooooooooooooo000000[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0A_ooool004Gooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000002_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`16ooooo`00A_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00cooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`16ooooo`005_ooooooo`00
043o00004oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooo000000Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool0
00001oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo0_l00006oooo
o`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ool000001oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o
0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool04Oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003oooooo`00
0005ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00007ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00007ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oo
oooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Ooo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo0018ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool03?ooool01?l0003oooooooooool0000:ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo04Kooooo0018ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03?oo
ool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04Oooooo0019ooooo`05o`000?oo
ooooooooooooool000004_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool03_ooool00ol0003oooooo`00000:ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04Oooooo
0019ooooo`;o00000_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo000000Wooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0Aoooool004[ooooo0ol0000Dooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo000000Wooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool0Aoooool0067ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`17oooo
o`00HOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool03_ooool01?l0003oooooo`000?l00008ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04Oooooo001Qooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooo000000Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0B?ooool0067ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000ooooool00000
2Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`18ooooo`00H_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool04?ooool2o`0000Wooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0B?oo
ool006;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo013ooooo0_l00008ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04Sooooo001Rooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0@ooooo`;o00002?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`18ooooo`00Hoooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool04?ooool2o`0000Sooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0B?ooool006?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo013ooooo
0_l00008ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo04Sooooo001Tooooo`04o`000?ooooooooooo`0001Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool04?ooool3o`0000Oooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0B?ooool006Cooooo00Co
0000ooooool0003o00005Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`;o00002?ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`18ooooo`00IOooool2o`0001Kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool2o`0000Sooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0BOooool007gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo04Wooooo001mooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`19ooooo`00OOooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0BOooool007kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04Wooooo001nooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`19ooooo`00O_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Booooo`;o00001_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`19ooooo`00O_ooool01Ol0
003ooooooooooooooooo000001Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0BOooool007oooooo00Co0000oooo
oooooooo00005_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`19ooooo`00Ooooool01?l0003oooooooooool0000F
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo04Wooooo001oooooo`04o`000?ooooooooooo`0001Oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0B_ooool0083ooooo0_l0000Hooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04[ooooo0020ooooo`;o
00006?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo1Ol00006ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0B_ooool009[ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`08ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo04[ooooo002Jooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool02Oooool00onHV9So8B4Qonk^kP07ooooo`?o00001?ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`1:ooooo`00V_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o
V9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04[ooooo002J
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02oooool00omgMgOoIVIVooooo`05
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0B_ooool009[ooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03o`000?oooooooooo00Cooooo0_l00005ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo04[ooooo002Jooooo`05o`000?ooooooooooooooool000002oooool01Ol0003o^[ZjoooooonH
V9So410@00Kooooo0_l00005ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04[ooooo002Jooooo`05o`000?oooooo
ooooooooool000002oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo0_l00004ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo04[ooooo002Kooooo`03o`000?oooooo000001Oooooo0_l00004ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo04[ooooo002Kooooo`03o`000?oooooo000001Oooooo0_l00004ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo04_ooooo002Looooo`;o00005oooool2o`0000Cooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Boooool009co
oooo00?o0000ooooooooool05_ooool2o`0000Cooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Boooool00;Gooooo
00?o0000ooooool000000oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1;ooooo`00]Oooool00ol0003oooooo`00
0003ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo04_ooooo002eooooo`03o`000?oooooo000000?ooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0Boooool00;Gooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1;oooo
o`00]Oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04_ooooo002eooooo`03o`00
0?oooooo000000;ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0Boooool00;Gooooo00Ko0000oooooooooooo0000
ooooool0000Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`1;ooooo`00]Oooool2o`000004ooooool0003oooooo`0001Wooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04_ooooo002eooooo`03o`00
0?oooooooooo00;o00006_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0Boooool00;Gooooo00Go0000ooooooooooooooooo`00000Jooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1;ooooo`00]Ooo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1<ooooo`00]Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1<ooooo`00]Oooool00ol0
003oooooooooo`0Mooooo`04o`000?ooooooooooo`0001[ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0C?ooool0
0;Gooooo00?o0000ooooooooool07Oooool01?l0003oooooooooool0000Jooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo04cooooo002eooooo`03o`000?oooooooooo01gooooo00Co0000oooooooooooo00006_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1<ooooo`00]Oooool2o`0001kooooo00Co0000oooooooooooo00006_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1<ooooo`00]Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo0000
01_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0C?ooool00;Gooooo00?o0000ooooooooool07_ooool2o`0001co
oooo00Co0000oooooooooooo00007?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
04cooooo002eooooo`03o`000?oooooooooo01kooooo0_l0000Looooo`04o`000?ooooooooooo`00
01cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1<ooooo`00]Oooool00ol0003o
ooooooooo`0looooo`04o`000?ooooooooooo`0001cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`1<ooooo`00[?ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000oooooooo
ool0??ooool01?l0003oooooooooool0000Looooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0C?ooool00:gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0looooo`04
o`000?ooooooooooo`0001cooooo00Go0000ooooooooooooooooo`00001?ooooo`00Z_ooool5o`00
00Kooooo00?o0000ooooooooool0??ooool01?l0003oooooooooool0000Looooo`05o`000?oooooo
ooooooooool00000Coooool00:[ooooo00CoA4A4omgMgOoooooo00001oooool3o`0003cooooo00Co
0000oooooooooooo00007?ooool01Ol0003ooooooooooooooooo000004oooooo002Zooooo`04omgM
gOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0??ooool01?l0003oooooooooool0000Loooo
o`05o`000?ooooooooooooooool00000Coooool00:_ooooo00?oMgMgolc<c?l000001oooool00ol0
003oooooooooo`0looooo`03o`000?oooooo000001gooooo00Go0000ooooooooooooooooo`00001?
ooooo`00Zoooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo03cooooo00?o0000oooo
ool000007Oooool01Ol0003ooooooooooooooooo000004oooooo002/ooooo`03ogMgMol0003ooooo
00Kooooo00?o0000ooooooooool0?Oooool2o`0001gooooo00Go0000ooooooooooooooooo`00001?
ooooo`00]Oooool00ol0003oooooooooo`0mooooo`;o00007_ooool01?l0003oooooooooool0001?
ooooo`00]Oooool00ol0003oooooooooo`1Mooooo`04o`000?ooooooooooo`0004oooooo002eoooo
o`03o`000?oooooooooo05gooooo00Co0000oooooooooooo0000Coooool00;Gooooo0_l0001Noooo
o`04o`000?ooooooooooo`0004oooooo002eooooo`03o`000?oooooooooo05gooooo00Co0000oooo
oooooooo0000Coooool00;Gooooo00?o0000ooooooooool0GOooool01?l0003oooooooooool0001?
ooooo`00]Oooool00ol0003oooooooooo`1Mooooo`04o`000?ooooooooooo`0004oooooo002eoooo
o`03o`000?oooooooooo05gooooo00?o0000ooooool00000D?ooool00;Gooooo00?o0000oooooooo
ool0G_ooool2o`00053ooooo002eooooo`03o`000?oooooooooo05kooooo0_l0001@ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00:[ooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`00
0?oooooooooo0;3ooooo002Zooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000/?ooool00:[ooooo00Go
0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03oeEEEOn7
QhOooooo00Sooooo00?o0000ooooooooool0/?ooool00:[ooooo00?ogMgMoa0@4?nHV9P02?ooool0
0ol0003oooooooooo`2`ooooo`00Zoooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Zoooo
o`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OlQ
8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05oc8b<_nHV9Sooooo
oiRHV?lb<S801_ooool3o`000;3ooooo002Zooooo`05olc<c?l0003o0000o`000?o<c<`0^Oooool0
0:[ooooo00Go410@okZj^_oooooo^[Zjoa0@402iooooo`00Z_ooool01Ol0003o^[Zjoooooonj^[[o
00000;Wooooo002Zooooo`05ojVYZOl@413o0000oa0@4?nYZJT0^Oooool00?ooooooJOooool00;?o
oooo00?o0000okZj^_ooool0/_ooool00;?ooooo0_lb<S:cooooo`00Q?ooool2o`000006oa0@4?oo
oooooooooa0@4?l0003o410@6?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj
^P0Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07cooooo0025ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01oooool6o`0000gooooo00WoMgMgoc8b<_oooooooooo
ogMgMonHV9SooooooiRHV?mgMgL00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^
ogMgMol@41002Oooool6o`0000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0O?ooool008Gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Kooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool04?ooool00ol0003ooooo
ooooo`0Kooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@401looooo`00
QOooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000=ooooo`05ogMgMolb<S;ooooo
ooooool000000oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo1_l0000;
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00001looooo`00QOooool0
1_l0003ogMgMoc8b<_mEEEGogMgMo`0001Wooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05
o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0Mooooo`03ogMgMomVIVKooooo
00;ooooo00Go0000ooooooooooooooooo`00001looooo`00QOooool01_l0003oQhN7ojVYZOnj^[[o
EEEEo`0001Wooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@013ooooo
00?o410@o`000?l000000ol0000Mooooo`05o`000?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`1jooooo`00QOooool01_l0003o<S8boooooooooooo<S8bo`0001Wooooo00?o0000oooo
ooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool06_ooool0
1Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1looooo`00Q?oo
ool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo1?l00003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Jooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07cooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(22) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .1571 m
.00123 .1568 L
.00236 .1566 L
.00365 .15647 L
.00488 .15645 L
.00601 .15651 L
.00706 .15664 L
.00821 .15686 L
.00942 .15719 L
.01065 .15762 L
.01196 .15818 L
.01434 .15949 L
.01716 .16154 L
.01975 .16392 L
.02485 .16994 L
.03042 .17791 L
.03565 .18565 L
.04057 .1922 L
.04336 .19525 L
.04484 .19656 L
.04639 .1977 L
.0477 .19844 L
.04845 .19876 L
.04914 .19899 L
.05036 .19924 L
.05167 .19927 L
.05246 .19918 L
.05319 .19901 L
.054 .19874 L
.05485 .19836 L
.05628 .1975 L
.05786 .19625 L
.06078 .19321 L
.06351 .18964 L
.07388 .17258 L
.07954 .16346 L
.0823 .1597 L
.08481 .15684 L
.08733 .15454 L
.0897 .15293 L
.09101 .1523 L
.09221 .15189 L
.09353 .15162 L
.0942 .15156 L
.09493 .15156 L
.09567 .15162 L
.09637 .15175 L
.09769 .15216 L
.09842 .1525 L
.0991 .15287 L
Mistroke
.10065 .15396 L
.10324 .15656 L
.106 .16038 L
.11125 .17052 L
.1162 .18308 L
.12543 .21059 L
.13033 .22333 L
.13168 .22609 L
.13312 .22859 L
.13447 .23046 L
.13571 .23173 L
.1371 .23264 L
.13838 .23298 L
.13905 .23296 L
.13979 .23278 L
.14056 .23242 L
.14128 .23192 L
.14261 .23061 L
.14382 .22899 L
.14655 .22392 L
.15108 .21209 L
.15602 .19634 L
.16596 .16589 L
.16864 .15936 L
.17153 .15335 L
.17408 .14905 L
.17548 .14711 L
.17678 .14558 L
.17805 .14434 L
.17922 .14344 L
.18051 .1427 L
.18189 .14222 L
.18305 .14206 L
.18431 .14215 L
.18549 .14248 L
.1866 .14301 L
.18785 .14387 L
.18921 .14511 L
.19166 .14823 L
.19458 .15345 L
.19726 .15978 L
.20279 .17766 L
.20861 .20276 L
.21375 .22766 L
.21861 .24945 L
.2213 .25897 L
.22282 .26313 L
.22354 .26476 L
.22422 .26606 L
.22539 .26779 L
Mistroke
.22669 .26886 L
.22795 .26905 L
.22931 .2683 L
.23059 .2667 L
.23178 .26447 L
.23308 .26125 L
.23447 .257 L
.23938 .23689 L
.24859 .19201 L
.25385 .16994 L
.2594 .15238 L
.2623 .14573 L
.26384 .14289 L
.26549 .14035 L
.267 .13845 L
.26838 .13707 L
.26977 .13602 L
.27109 .13533 L
.2723 .13496 L
.27364 .13484 L
.27432 .1349 L
.27504 .13506 L
.27636 .1356 L
.2776 .1364 L
.2789 .13757 L
.28123 .14055 L
.28256 .14275 L
.28397 .14553 L
.28651 .15171 L
.28953 .16114 L
.29227 .17176 L
.29737 .19695 L
.30276 .23023 L
.30742 .2607 L
.30999 .27594 L
.31243 .28803 L
.31377 .29336 L
.31448 .29572 L
.31524 .29788 L
.31657 .3007 L
.31781 .30216 L
.31917 .30244 L
.32044 .30142 L
.32159 .29948 L
.32283 .29632 L
.32422 .29158 L
.32574 .28507 L
.3288 .26859 L
.33427 .23337 L
.3398 .199 L
Mistroke
.34503 .17278 L
.34972 .1553 L
.35237 .14782 L
.35481 .14236 L
.35607 .14005 L
.35743 .13793 L
.35861 .1364 L
.35989 .13503 L
.36066 .13435 L
.36138 .13381 L
.36213 .13335 L
.36281 .13301 L
.3641 .13257 L
.36548 .13239 L
.36619 .13242 L
.36694 .13253 L
.36828 .13295 L
.36902 .13331 L
.36972 .13373 L
.3713 .13499 L
.37269 .13648 L
.37395 .13816 L
.37679 .14321 L
.37919 .14899 L
.38184 .15715 L
.3872 .18007 L
.39216 .20966 L
.39682 .24423 L
.40193 .28503 L
.40472 .30508 L
.40731 .32003 L
.40867 .3259 L
.40937 .3283 L
.41013 .3304 L
.41096 .33209 L
.41174 .33308 L
.4125 .33347 L
.41321 .33331 L
.41446 .33185 L
.41584 .32852 L
.41653 .3262 L
.41727 .32325 L
.41862 .31681 L
.42865 .24361 L
.43416 .20394 L
.43934 .17534 L
.4423 .16301 L
.4455 .15256 L
.4484 .14531 L
.45107 .1403 L
Mistroke
.45359 .13687 L
.45503 .13544 L
.45636 .13442 L
.45709 .13398 L
.45777 .13365 L
.45906 .13322 L
.46044 .13302 L
.46122 .13303 L
.46195 .13311 L
.46319 .13342 L
.46434 .1339 L
.46559 .13463 L
.46691 .13566 L
.46914 .13804 L
.47157 .1417 L
.47424 .14716 L
.47708 .155 L
.47976 .16457 L
.48219 .17533 L
.4875 .20653 L
.49325 .25282 L
.49864 .30313 L
.50128 .32613 L
.50368 .34373 L
.50486 .35065 L
.50615 .35662 L
.50736 .36063 L
.50848 .36281 L
.50967 .36348 L
.51098 .36224 L
.51235 .35879 L
.51364 .35363 L
.51497 .3465 L
.51638 .33728 L
.5189 .31738 L
.52458 .26542 L
.52968 .22213 L
.53513 .18665 L
.53827 .17162 L
.54112 .16093 L
.54398 .15263 L
.54669 .14668 L
.54919 .14255 L
.55153 .13971 L
.55288 .13848 L
.55411 .13758 L
.55478 .13718 L
.55552 .13681 L
.55687 .13631 L
.5576 .13614 L
Mistroke
.55829 .13604 L
.55958 .136 L
.56097 .13618 L
.56175 .13639 L
.56247 .13663 L
.56367 .13719 L
.565 .13801 L
.56638 .1391 L
.56767 .14037 L
.57018 .14358 L
.57256 .14768 L
.57469 .15242 L
.57701 .15891 L
.57954 .1678 L
.58222 .17967 L
.58703 .20842 L
.59217 .25105 L
.59687 .29928 L
.60194 .35138 L
.60333 .36349 L
.60481 .37456 L
.60621 .38285 L
.60748 .38829 L
.60868 .39145 L
.60979 .39258 L
.61101 .3918 L
.61229 .38872 L
.61341 .38424 L
.61445 .37863 L
.61683 .36145 L
.62668 .26253 L
.63191 .2176 L
.63487 .1979 L
.63761 .18316 L
.6402 .17199 L
.64263 .16363 L
.64544 .15619 L
.64798 .15114 L
.65036 .14759 L
.65286 .14482 L
.655 .1431 L
.65621 .14235 L
.65734 .1418 L
.65866 .14132 L
.6599 .14103 L
.66101 .1409 L
.66222 .1409 L
.66354 .14106 L
.66421 .1412 L
.66494 .14141 L
Mistroke
.66624 .14191 L
.66745 .14252 L
.67015 .14442 L
.67265 .14692 L
.6754 .15069 L
.67834 .15625 L
.68113 .16344 L
.68376 .17233 L
.68616 .18252 L
.68869 .19585 L
.69355 .23024 L
.69803 .27333 L
.70331 .33473 L
.70813 .38764 L
.70932 .39797 L
.71058 .40716 L
.71196 .41478 L
.71324 .41931 L
.71442 .42118 L
.71553 .42086 L
.71676 .41819 L
.71807 .4127 L
.71937 .40487 L
.72078 .39384 L
.72363 .36561 L
.72873 .30633 L
.73355 .25485 L
.7362 .23164 L
.7387 .21329 L
.74103 .19909 L
.74356 .18646 L
.74587 .17712 L
.74798 .17021 L
.75045 .16384 L
.75311 .15873 L
.75557 .15528 L
.7579 .15284 L
.76061 .15072 L
.76313 .14926 L
.76458 .1486 L
.76589 .14813 L
.76662 .14791 L
.7674 .14773 L
.76815 .14759 L
.76883 .14751 L
.77011 .14745 L
.77148 .14753 L
.77277 .14773 L
.77395 .14803 L
.77534 .14849 L
Mistroke
.77684 .14914 L
.77957 .15066 L
.78243 .1528 L
.78547 .15598 L
.78806 .15983 L
.79092 .16576 L
.79339 .17268 L
.79609 .18252 L
.79891 .19577 L
.80153 .21134 L
.80623 .24907 L
.81125 .30498 L
.81716 .38233 L
.82006 .41586 L
.82134 .42783 L
.82273 .43838 L
.82399 .4452 L
.82517 .44907 L
.82641 .45043 L
.82774 .4487 L
.82843 .44652 L
.82919 .44316 L
.83057 .4346 L
.83192 .42353 L
.83316 .41122 L
.83852 .34527 L
.8443 .27512 L
.84696 .24917 L
.84976 .22683 L
.85218 .21129 L
.85477 .19796 L
.8573 .18771 L
.8596 .18038 L
.86192 .17464 L
.86411 .1705 L
.86665 .16692 L
.86901 .1645 L
.87159 .1625 L
.87433 .16084 L
.87697 .15952 L
.87949 .1585 L
.88177 .15775 L
.88421 .15713 L
.88684 .15661 L
.88929 .15619 L
.89484 .15512 L
.89733 .15458 L
.90003 .15403 L
.90126 .15382 L
.90257 .15362 L
Mistroke
.9037 .15348 L
.90491 .15336 L
.90609 .15327 L
.90717 .15321 L
.90825 .15317 L
.90927 .15314 L
.91046 .15312 L
.91156 .15312 L
.91277 .15313 L
.91405 .15315 L
.91525 .15319 L
.91655 .15327 L
.91791 .15339 L
.91918 .15354 L
.92037 .15374 L
.92146 .15395 L
.92389 .15459 L
.9265 .1555 L
.92934 .1567 L
.93449 .15922 L
.94441 .16508 L
.94926 .16814 L
.95368 .17048 L
.95614 .17149 L
.95847 .17224 L
.95967 .17254 L
.96094 .17281 L
.96167 .17293 L
.96233 .17303 L
.96362 .17316 L
.96431 .1732 L
.96503 .17323 L
.96633 .17321 L
.96705 .17317 L
.96772 .1731 L
.96846 .173 L
.96925 .17287 L
.97068 .17254 L
.97203 .17214 L
.97455 .17114 L
.98005 .16816 L
.98514 .16498 L
.99061 .16158 L
.99373 .15979 L
.99664 .15834 L
1 .1571 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool008Wooooo0ol0000Kooooo`Co0000
2_ooool00ol0003oooooooooo`2`ooooo`00Joooool4o`0001Wooooo0_l00002ooooo`03o`000?oo
oooooooo01Oooooo0_l00002ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03_oo
ool4o`0009kooooo001Zooooo`;o00000_ooool2o`0001Oooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0=ooooo`;o00000oooool00ol0003oooooooooo`2Kooooo`00Coooool3o`00
01Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01Sooooo1Ol0001mooooo`00C_ooool00ol0003oooooooooo`02o`0001Kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`1jooooo`00COooool2o`0000Cooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01[ooooo1Ol0001Jooooo`00<_oo
ool4o`0001Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool05oooool2o`0000Gooooo0_l0000Xooooo`03o`000?oo
oooooooo02gooooo000aooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo0_l0000<ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Nooooo`go0000:_ooool0
01Kooooo1?l0000Gooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06oooool3o`00
00gooooo0ol0000Booooo`;o00004oooool001[ooooo0_l0000Dooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool05oooool3o`0001?ooooo00?o0000ooooooooool03?ooool3o`0001Go
oooo000Eooooo`;o000000Go410@ooooooooooooooooonk^kP02o`000003oc8b<_o^k^kooooo00ko
oooo00?o0000ooooooooool01Oooool02?l0003ooooooooooonHV9So410@o`000?lb<S;oc<c<0ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0;ooooo`Ko00000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`03ooooo`Go00000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`Co000000So410@oooo
ooooooook^k^oc8b<_l0003o<S8bo`0000cooooo00?o0000ooooooooool02oooool5o`0000?ooooo
00Go0000oc8b<_l0003o<S8bonk^kP07ooooo`03o`000?oooooooooo017ooooo00KoV9RHoa0@4?l0
003o<S8bolc<c?l00002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04?ooool2o`0000_ooooo0_l0
00002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0>ooooo`005_ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9So0000oiRHV?mgMgL03oooool00ol0003oooooooooo`06oooo
o`07o`000?oooooo410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo00KoV9RHob4Q8Oo^k^ko
ooooodA4A?l00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00Kooooo00[o0000oooooooooooo0000oooooomgMgOoV9RHoooooonH
V9SoMgMg3?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9So000000cooooo00?o0000ooooooooool02oooool0
1OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Go0000oiRHV?ooooooV9RHogMgM`08ooooo`03o`00
0?oooooooooo013ooooo00Ko410@okZj^_ooooooMgMgoc8b<_l00002ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL04_ooool00ol0003oooooooooo`06ooooo`;o000000?oooooo`000?ooool00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko00000_ooool5o`0000?ooooo00Go410@
oooooooooooo0000oa0@400>ooooo`04o`000?ooooooooooooooo`Ko000000?oooooo`000?ooool0
0oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool00_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00;ooooo1_l00003ooooo`05oiRHV?lQ8B7ok^k^oooo
ool000000_ooool01Ol@413ooooooooooooooooo410@00Cooooo00?o0000ooooooooool03?ooool6
o`0000Gooooo00Ko0000oooooooooooo0000ooooool@4103ooooo`03oa0@4?oooooooooo00[ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo
00Go410@ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^
k^h00oooool00ol0003o410@ooooo`02ooooo`03oa0@4?oooooooooo00Kooooo00?o0000oooooooo
ool05?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool04Oooool2o`00
00Gooooo1_l00003ooooo`05oa0@4?ooooooooooooooool@41003_ooool001?ooooo00CoA4A4omgM
gOoooooo00001?ooool00ol0003oooooooooo`02o`0000gooooo00?o0000ooooooooool02Oooool0
1_l0003oooooooooooooooooZJVYoa0@40?ooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool03?ooool01?nHV9So8B4Qonk^k_l00002oooo
o`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00Kooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo00gooooo00?oV9RHob4Q8Oo^
k^h00_ooool2o`0000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Cooooo`03
o`000?l@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Eooooo`Go000000GoooooodA4
A?oMgMgoooooo`000004ooooo`05o`000?ooooooooooooooool000003_ooool001?ooooo00CogMgM
oeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool0
2_ooool01Ol0003ooooooa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVo`000002oooo
o`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00Kooooo00Co0000oooooooooooooooo0_l00003ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo00kooooo00KoMgMgofIVI_oooooo
0000ooooool00003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol@
413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000006oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000003_ooool001Cooooo00?oMgMgolc<c?l000001?oo
ool01Ol@413ooooooooooooooooo000000cooooo00?o0000ooooooooool02oooool01Ol0003ooooo
oooooonj^[[o8B4Q00?ooooo00Go410@oooooooooooooooooa0@4002ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool03Oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@
ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Kooooo00Ko0000
ooooooooooooooooo`000?l@4103ooooo`03oa0@4?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`03ooooo`;o00002Oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool00_ooool01Ol@413oooooooooool0003o410@00go
oooo00?o0000ooooooooool03_ooool01Ol0003oooooo`000?oooooo410@00?ooooo00?o410@oooo
ooooool01oooool00ol0003oooooooooo`0Aooooo`03o`000?nj^[[o8B4Q00?ooooo00Go410@oooo
oooooooooooooa0@400Looooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@
400>ooooo`005?ooool00oo^k^koA4A4o`000004ooooo`06ogMgMonHV9SooooooiRHV?mgMgOo0000
2_ooool00ol0003oooooooooo`0<ooooo`05oa0@4?l0003ooooookZj^_l000000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09oooo
o`05o`000?nj^[[ooooooiRHV?l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`0:o`000?ooooooooooooooool0003o
MgMgoiRHV?ooooooV9RHogMgM`_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo0000ogMgM`0=ooooo`03o`000?oo
oooooooo00[ooooo00Ko0000okZj^_ooooooV9RHoa0@4?l00002ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02Oooool00ol0003oooooooooo`0?ooooo`05oa0@4?nHV9So0000okZj^_l000000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00kooooo000Eooooo`03ogMgMol0003ooooo00?ooooo00Ook^k^oc8b<_l0003o<S8b
onk^k_oooooo000000Wooooo00?o0000ooooooooool03?ooool01OnYZJWo0000o`000?l@413oZJVY
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02?ooool01OnHV9So410@o`000?lQ8B7o000000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool00omEEEGoIVIV
o`000003ooooo`06o`000?o^k^ko<S8bo`000?lb<S;ok^k^2_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00Gooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?l0003o
k^k^00gooooo00?o0000ooooooooool02_ooool01_nHV9So410@o`000?lQ8B7oc<c<o`0000;ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP09ooooo`03o`000?oooooooooo00oooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Oooool00omgMgOo0000ooooo`03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool002;ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0?_ooool0
02?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0?_ooool002?ooooo0_l00003ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0oooooo`009?ooool5o`0001Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0oooooo`00?Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00kooooo00Go0000ooooooooooooooooo`000009ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo03oooooo000Foooooooo0000@?l0000Cooooo`005_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Cooooo0_l00006ooooo`;o00001_ooool00ol0003oooooooooo`05
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000oooo
ooooool01Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000002ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000oooooooo
ool01Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo017ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1?ooool2o`0000Kooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
o`000005ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool2o`00
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
017ooooo000nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03_ooool01Ol0003o
oooooooooooooooo000000Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0@?ooool003kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0?ooooo`05o`000?ooooooooooooooool000002?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`10ooooo`00?oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo013o
oooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`11ooooo`00?oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo013ooooo00Co0000oooooooooooo00002?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`11ooooo`00@?ooool01Ol0003ooooooooooooooooo000001Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo013ooooo00Co0000oooo
oooooooo00002?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`11ooooo`00@?ooool01?l0003oooooooooool0000F
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0@
ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0@Oooool0047ooooo0ol0000F
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00;o00001oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`11ooooo`00F_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04Oooool01?l0
003oooooooooool00008ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo047ooooo001Kooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Aooooo`04o`000?oooooooooo
o`0000Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0@_ooool005_ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooool000002?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`12ooooo`00Foooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool04_ooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04;o
oooo001Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0@_ooool005_ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooool000001oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`12ooooo`00G?ooool01Ol0003ooooooooooooo
oooo000001Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool04_ooool00ol0003oooooo`000007ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo04;ooooo001Looooo`05o`000?ooooooooooooooool000005oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Cooooo`04o`000?oooooo0000o`0000Kooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0@_ooool005cooooo00Go
0000ooooooooooooooooo`00000Gooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooool00000
1oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`12ooooo`00GOooool00ol0003oooooo`00000Hooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`13ooooo`00GOooool3
o`0001Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool04oooool00ol0003oooooo`000007ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo04?ooooo001hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooool000001oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`13ooooo`00N?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo000000Oo
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0@oooool007Sooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04oooool00ol0003ooooo
o`000007ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo04?ooooo001hooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Cooooo0_l0
0006ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo04?ooooo001iooooo`05o`000?ooooooooooooooool000006?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Gooooo0ol00005ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo04?ooooo001iooooo`05o`000?ooooooooooooooool000006?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo01Gooooo0_l00006ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04?ooooo001i
ooooo`05o`000?ooooooooooooooool000006?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo01Gooooo0_l00006ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04?ooooo001jooooo`04o`000?oooooo
ooooo`0001Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Eooooo`;o00001_oo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`13ooooo`00N_ooool00ol0003oooooo`00000Jooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool05Oooool2o`0000Kooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0@oooool0
07[ooooo00?o0000ooooool000006_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01Gooooo0_l00006ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo04?ooooo001kooooo`;o00006_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00_ooooo1Ol00005ooooo`;o00001_ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`13ooooo`00Uoooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o00001_ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`13ooooo`00
Uoooool01Ol0003ooooooooooooooooo000000oooooo00?oV9RHob4Q8Oo^k^h01_ooool4o`0000?o
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0@oooool009Oooooo00Go0000ooooooooooooooooo`00000@ooooo`03
oiRHV?lQ8B7ok^k^00Gooooo0_l00005ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Cooooo002Gooooo`05o`00
0?ooooooooooooooool000004Oooool00omgMgOoIVIVooooo`04ooooo`;o00001Oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`14ooooo`00Uoooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Cooooo002Gooooo`05o`00
0?ooooooooooooooool000003_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`14ooooo`00Uoooool01Ol0003ooooooooooooooooo0000
00kooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0A?ooool009Sooooo00?o0000ooooool000006_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo04Cooooo002Hooooo`?o00006_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo04Cooooo002Iooooo`03o`000?oooooooooo01Wooooo0_l00003ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo04Cooooo002eooooo`;o00000oooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`14ooooo`00]Oooool2
o`0000?ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0A?ooool00;Gooooo0_l00003ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
04Cooooo002eooooo`;o00000oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`14ooooo`00]Oooool2o`0000?ooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0A?ooool00;Gooooo0_l00002ooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Cooooo002e
ooooo`05o`000?oooooo0000ooooool000006oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0A?ooool00;Gooooo00Go0000ooooool0003oooooo`00
000Looooo`05o`000?ooooooooooooooool000006oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`14ooooo`00]Ooo
ool4o`0001gooooo00Go0000ooooooooooooooooo`00000Looooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Cooooo
002eooooo`03o`000?oooooooooo01kooooo00Go0000ooooooooooooooooo`00000Looooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo04Gooooo002eooooo`03o`000?oooooooooo01kooooo00Go0000oooooooooooooooo
o`00000Looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo04Gooooo002eooooo`03o`000?oooooooooo01kooooo00Co
0000oooooooooooo00007Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`15ooooo`00]Oooool00ol0003ooooooooo
o`0Nooooo`04o`000?ooooooooooo`0001gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0AOooool00;Gooooo00?o
0000ooooooooool07_ooool01?l0003oooooooooool0000Mooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04Gooooo
002eooooo`03o`000?oooooooooo01oooooo00?o0000ooooool000007Oooool01Ol0003ooooooooo
oooooooo000001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`15ooooo`00]Ooo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooo000001gooooo00Go0000oooooooooooooooo
o`00000Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0AOooool00;Gooooo0_l0
000Pooooo`03o`000?oooooo000001gooooo00Go0000ooooooooooooooooo`00000Nooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0AOooool00;Gooooo00?o0000ooooooooool07ooo
ool3o`0001gooooo00Go0000ooooooooooooooooo`00000Nooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0AOooool00;Gooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`0Mooooo`04o`000?ooooooooooo`0001kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`15ooooo`00]Oooool00ol0003oooooooooo`10ooooo`04o`000?ooooooooooo`0001kooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`15ooooo`00]Oooool00ol0003ooooooooo
o`10ooooo`04o`000?ooooooooooo`0001oooooo00Go0000ooooooooooooooooo`000018ooooo`00
[?ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0@?ooool01?l0003ooooo
ooooool0000Oooooo`05o`000?ooooooooooooooool00000B?ooool00:gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`10ooooo`04o`000?ooooooooooo`0001oooooo00Go0000oooo
ooooooooooooo`000018ooooo`00Z_ooool5o`0000Kooooo00?o0000ooooooooool0@?ooool01?l0
003oooooooooool0000Oooooo`05o`000?ooooooooooooooool00000B?ooool00:[ooooo00CoA4A4
omgMgOoooooo00001oooool3o`00043ooooo00?o0000ooooool000008?ooool01Ol0003ooooooooo
oooooooo000004Sooooo002Zooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0
@?ooool00ol0003oooooo`00000Pooooo`05o`000?ooooooooooooooool00000B?ooool00:_ooooo
00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`11ooooo`;o00008?ooool01Ol0003ooooo
oooooooooooo000004Sooooo002[ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0
@Oooool00ol0003oooooooooo`0Oooooo`05o`000?ooooooooooooooool00000B?ooool00:cooooo
00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`1Sooooo`05o`000?ooooooooooooooool0
0000B?ooool00;Gooooo00?o0000ooooooooool0Hoooool01Ol0003ooooooooooooooooo000004So
oooo002eooooo`03o`000?oooooooooo06?ooooo00Co0000oooooooooooo0000BOooool00;Gooooo
00?o0000ooooooooool0I?ooool00ol0003oooooo`000019ooooo`00]Oooool2o`0006Gooooo00?o
0000ooooool00000BOooool00;Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooo`000019
ooooo`00]Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooo000004Wooooo002eooooo`03
o`000?oooooooooo06Cooooo0_l0001:ooooo`00]Oooool00ol0003oooooooooo`1Tooooo`;o0000
B_ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool0
0ol0003oooooooooo`2`ooooo`00Z_ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000
ooooooooool0/?ooool00:[ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo0;3ooooo002Zooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`000;3ooooo002Zoooo
o`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool00omE
EEGoQhN7ooooo`08ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03omgMgOl@413oV9RH00So
oooo00?o0000ooooooooool0/?ooool00:_ooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
Z_ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo
00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Olb<S;oV9RH
oooooonHV9So<S8b00Kooooo0ol0002`ooooo`00Z_ooool01Oo<c<co0000o`000?l0003oc<c<0;Wo
oooo002Zooooo`05oa0@4?nj^[[ooooookZj^_l@4100^Oooool00:[ooooo00Go0000okZj^_oooooo
^[Zjo`00002iooooo`00Z_ooool01OnYZJWo410@o`000?l@413oZJVY0;Wooooo003oooooofWooooo
002cooooo`03o`000?nj^[[ooooo0;;ooooo002cooooo`;o<S8b/oooool008Cooooo0_l000001_l@
413oooooooooool@413o0000oa0@41Sooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4
A?nj^[X06?ooool5o`0000?ooooo1Ol0001looooo`00QOooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Oooooo1_l0000=ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo
1_l00009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OnHV9So8B4Qonk^k_ooooooA4A4
07cooooo0025ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06oooool01?l0003o
ooooooooool@4103ooooo`03oa0@4?oooooooooo013ooooo00?o0000ooooooooool06oooool00onH
V9So8B4Qonk^kP05ooooo`03oiRHV?lQ8B7ok^k^07gooooo0025ooooo`06o`000?ooooooA4A4odA4
A?oooooo00002Oooool6o`0000gooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool02oooool6o`0000_ooooo00?oV9RHob4Q8Oo^k^h01Ooo
ool00onHV9So8B4Qonk^kP1looooo`00QOooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001Wooooo
00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000004_ooool00ol0
003oooooooooo`0Mooooo`03ogMgMomVIVKooooo00Gooooo00?oMgMgofIVI_ooool0Noooool008Go
oooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Iooooo`03o`000?oooooooooo00Cooooo00Go410@
oooooooooooooooooa0@400@ooooo`03oa0@4?l0003o000000?o00007Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo07[ooooo0025ooooo`06o`000?lb<S;ooooooooooolb<S;o0000
6Oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool00ol0003o
ooooooooo`0Jooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Ol0003o^[ZjoooooonHV9So
410@07cooooo0024ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool4o`00
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Booooo`03o`000?oooooooooo01[ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c003ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0O?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(24) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .18273 m
.00488 .19137 L
.00942 .198 L
.01077 .19951 L
.01204 .20071 L
.01319 .20159 L
.01441 .2023 L
.01574 .20279 L
.01697 .20299 L
.01829 .20292 L
.01904 .20275 L
.01975 .20251 L
.02103 .20187 L
.02243 .20088 L
.02499 .19834 L
.02747 .19502 L
.02978 .1913 L
.04057 .1697 L
.04635 .15869 L
.0518 .15037 L
.05418 .14751 L
.05669 .14509 L
.058 .14409 L
.05945 .14322 L
.06076 .14263 L
.06198 .14227 L
.06272 .14214 L
.0634 .14208 L
.06415 .14208 L
.06494 .14215 L
.06627 .14245 L
.06703 .14273 L
.06774 .14305 L
.06906 .14381 L
.07027 .14471 L
.073 .14745 L
.07575 .15124 L
.07875 .15662 L
.08481 .1714 L
.0954 .20584 L
.1006 .22206 L
.10289 .22786 L
.1054 .23281 L
.10679 .23478 L
.10809 .23607 L
.10946 .23684 L
.11023 .23698 L
.11093 .23694 L
.11169 .23671 L
.1124 .23631 L
Mistroke
.11318 .23568 L
.11401 .23479 L
.11554 .23258 L
.11693 .22997 L
.11952 .22376 L
.12232 .21549 L
.1274 .19814 L
.13264 .17973 L
.13825 .16224 L
.14355 .14937 L
.14606 .14467 L
.14837 .14112 L
.15097 .13801 L
.15235 .13675 L
.1538 .13569 L
.15506 .13502 L
.15624 .13458 L
.15754 .13434 L
.15827 .13431 L
.15893 .13434 L
.15961 .13445 L
.16033 .13464 L
.16163 .13518 L
.16242 .13564 L
.16317 .13616 L
.16457 .13737 L
.16742 .14083 L
.17051 .14614 L
.17299 .15169 L
.17566 .15897 L
.18047 .17577 L
.19142 .22737 L
.19426 .24105 L
.19735 .25411 L
.19877 .25909 L
.20027 .26353 L
.20156 .26652 L
.20225 .2678 L
.20298 .26889 L
.20434 .27019 L
.20559 .27049 L
.20694 .26988 L
.2077 .2691 L
.20842 .26809 L
.20971 .26561 L
.21089 .26265 L
.21353 .25388 L
.22412 .20351 L
.22991 .1771 L
.23534 .15759 L
Mistroke
.23996 .14547 L
.24255 .14039 L
.24492 .13675 L
.24751 .13378 L
.24897 .13254 L
.25033 .13167 L
.25164 .13107 L
.25282 .13072 L
.25419 .13057 L
.25547 .13066 L
.25668 .13096 L
.25782 .13143 L
.25906 .13217 L
.26039 .13322 L
.2631 .13626 L
.26557 .14013 L
.26786 .14474 L
.27035 .15096 L
.27486 .1659 L
.28015 .18989 L
.28576 .22252 L
.29101 .25605 L
.29331 .26981 L
.29583 .28294 L
.29703 .28822 L
.29832 .29298 L
.29953 .29656 L
.30063 .29896 L
.30187 .30066 L
.30323 .30122 L
.3045 .30052 L
.30568 .29883 L
.30695 .29593 L
.30813 .29225 L
.31083 .28087 L
.31629 .24936 L
.32548 .19382 L
.33067 .16966 L
.33549 .15319 L
.33827 .1461 L
.34079 .14103 L
.34369 .1366 L
.34502 .13503 L
.34643 .13365 L
.34767 .13266 L
.34903 .1318 L
.35026 .13123 L
.35142 .13087 L
.35278 .13065 L
.35402 .13066 L
Mistroke
.35471 .13075 L
.35545 .13091 L
.35681 .13139 L
.35801 .13202 L
.35914 .1328 L
.36172 .13525 L
.36423 .13865 L
.36693 .14353 L
.36943 .14936 L
.37181 .15623 L
.37627 .1732 L
.38155 .20109 L
.38633 .2336 L
.39148 .27287 L
.3942 .2927 L
.39706 .31072 L
.39825 .31685 L
.39953 .32231 L
.40026 .32487 L
.40093 .32682 L
.40224 .3295 L
.40341 .33058 L
.40468 .33031 L
.40588 .32867 L
.407 .32599 L
.40811 .32226 L
.40916 .31786 L
.41154 .30503 L
.41636 .27123 L
.42668 .1988 L
.43187 .17289 L
.43481 .16177 L
.43755 .15352 L
.44008 .14749 L
.44246 .14302 L
.44461 .13987 L
.44694 .13723 L
.44947 .13515 L
.45075 .13439 L
.45149 .13403 L
.45216 .13376 L
.45336 .13341 L
.45464 .1332 L
.45584 .13318 L
.45697 .1333 L
.45828 .13363 L
.45902 .1339 L
.4597 .1342 L
.46095 .1349 L
.46226 .13584 L
Mistroke
.46455 .13798 L
.46706 .14114 L
.46974 .14562 L
.47262 .15195 L
.47533 .15972 L
.4778 .16859 L
.48256 .19128 L
.48772 .22527 L
.49712 .3053 L
.49957 .3252 L
.50086 .33442 L
.50222 .34286 L
.50341 .34902 L
.50472 .35421 L
.5059 .3574 L
.50701 .35899 L
.50769 .35929 L
.50843 .35902 L
.50977 .35697 L
.51108 .3531 L
.51228 .34801 L
.51502 .33177 L
.51791 .30943 L
.52856 .22115 L
.53162 .20122 L
.53453 .18554 L
.53717 .17388 L
.53998 .16395 L
.54241 .15715 L
.5451 .15127 L
.54754 .14714 L
.54983 .14412 L
.55252 .14144 L
.55499 .13971 L
.55629 .13905 L
.55771 .13853 L
.55842 .13835 L
.55919 .1382 L
.56056 .13808 L
.56186 .13812 L
.56305 .1383 L
.56436 .13863 L
.56574 .13914 L
.56695 .13972 L
.56807 .14037 L
.57064 .14229 L
.57294 .14463 L
.57505 .1474 L
.57749 .15154 L
.5798 .1566 L
Mistroke
.58252 .16422 L
.58508 .1733 L
.58987 .19622 L
.59256 .21307 L
.59503 .23142 L
.60061 .28217 L
.60546 .33097 L
.60783 .35251 L
.61 .36878 L
.61109 .37537 L
.61228 .38104 L
.61353 .38521 L
.61472 .38732 L
.61603 .3875 L
.61742 .38525 L
.61861 .3814 L
.61991 .37522 L
.63065 .28047 L
.6365 .22931 L
.63935 .20973 L
.64194 .19504 L
.64661 .17503 L
.64917 .16698 L
.65159 .16102 L
.65422 .15607 L
.65665 .15269 L
.65931 .15001 L
.66066 .14896 L
.66214 .14801 L
.66343 .14731 L
.66485 .14667 L
.6661 .14621 L
.66742 .14583 L
.66874 .14556 L
.66993 .14542 L
.67113 .14537 L
.67226 .14542 L
.67358 .1456 L
.67425 .14574 L
.67498 .14593 L
.67628 .14637 L
.67748 .14688 L
.68021 .14841 L
.68313 .15062 L
.68566 .15312 L
.68841 .15671 L
.69101 .16127 L
.69341 .16682 L
.69557 .17316 L
.69795 .18184 L
Mistroke
.70276 .20587 L
.70537 .22315 L
.70821 .246 L
.71339 .29818 L
.7185 .35599 L
.72072 .3789 L
.72313 .39911 L
.72384 .40389 L
.7246 .40823 L
.72596 .41401 L
.72723 .41695 L
.72795 .41751 L
.72862 .4173 L
.72938 .41623 L
.7301 .4144 L
.73145 .40891 L
.73221 .40475 L
.7329 .40024 L
.73449 .38795 L
.74504 .27514 L
.7499 .23143 L
.75245 .21353 L
.75514 .19822 L
.7575 .18744 L
.76008 .17808 L
.76243 .17146 L
.76462 .16665 L
.76597 .16424 L
.76744 .16205 L
.76873 .16044 L
.77009 .15903 L
.77133 .15798 L
.77268 .15705 L
.77391 .15638 L
.77507 .15588 L
.77577 .15563 L
.77652 .15541 L
.77785 .15511 L
.7786 .15499 L
.7794 .1549 L
.78016 .15485 L
.78084 .15482 L
.78218 .15483 L
.78293 .15486 L
.78363 .15491 L
.7849 .15505 L
.78624 .15526 L
.78892 .15583 L
.79146 .15658 L
.79374 .15744 L
Mistroke
.79621 .15858 L
.7989 .16009 L
.80176 .16203 L
.80423 .16409 L
.80689 .16688 L
.80935 .17026 L
.81161 .17426 L
.81377 .17914 L
.81604 .18562 L
.81854 .19468 L
.82087 .20525 L
.82614 .23895 L
.82891 .26315 L
.83145 .28972 L
.83721 .3605 L
.83983 .39276 L
.84228 .4188 L
.84362 .43022 L
.84484 .43847 L
.84619 .44485 L
.84694 .44702 L
.84765 .44816 L
.84888 .44797 L
.85 .44542 L
.85129 .43975 L
.8525 .43193 L
.85466 .4128 L
.85699 .3865 L
.86226 .31871 L
.86717 .26204 L
.87201 .2208 L
.87472 .20387 L
.87719 .19171 L
.8799 .18141 L
.88132 .17712 L
.88283 .17334 L
.88415 .17062 L
.88561 .16821 L
.88683 .16659 L
.88817 .16521 L
.88893 .16458 L
.88964 .16408 L
.89038 .16366 L
.89104 .16334 L
.89232 .16289 L
.89367 .16262 L
.89444 .16255 L
.89514 .16252 L
.89591 .16255 L
.89672 .16262 L
Mistroke
.89809 .16285 L
.89887 .16304 L
.8996 .16325 L
.9023 .16433 L
.90477 .16566 L
.91031 .16925 L
.91535 .17216 L
.9179 .17324 L
.91937 .17372 L
.92071 .17408 L
.92188 .17433 L
.9231 .17453 L
.92433 .17466 L
.92568 .17471 L
.92685 .17468 L
.9281 .17455 L
.92927 .17435 L
.93034 .17408 L
.9317 .17363 L
.93314 .17302 L
.93572 .17158 L
.94155 .16717 L
.95214 .15791 L
.95722 .15376 L
.95972 .15202 L
.96205 .15071 L
.96344 .15008 L
.96471 .14962 L
.96611 .14923 L
.96688 .14907 L
.96761 .14897 L
.96888 .14886 L
.97005 .14886 L
.97133 .14896 L
.97269 .14919 L
.97389 .1495 L
.97498 .14988 L
.97744 .15106 L
.97971 .1526 L
.98186 .15447 L
.98668 .16014 L
.99192 .16821 L
1 .18273 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo001Vooooo`;o00007_ooool2o`0002gooooo0_l0002aooooo`00
I?ooool2o`0000;ooooo0_l0000Jooooo`;o000000?oooooo`000?l000007?ooool4o`0000cooooo
00?o0000ooooooooool0/?ooool004Kooooo1Ol0000Iooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool05oooool2o`0000Cooooo00?o0000ooooooooool06?ooool2o`0000;ooooo0_l0
000;ooooo`03o`000?oooooooooo0;3ooooo0016ooooo`05o`000?ooooooooooooooool000006?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0>ooooo`Ko0000W?ooool002Wooooo0ol0000Iooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0V_ooool002Sooooo00Go0000ooooooooooooooooo`00000G
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06_ooool5o`0007[ooooo000Woooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01Sooooo0_l00003ooooo`;o0000F_ooool4o`0001_ooooo000Vooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo01Kooooo0_l00006ooooo`;o0000E_ooool2o`0000Cooooo0_l0000Iooooo`00
9Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`06ooooo`;o00003?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Iooooo`Ko0000
=?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Oooooo000Tooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Gooooo`;o00001Ooo
ool2o`00033ooooo0_l00009ooooo`03o`000?oooooooooo01Kooooo000Tooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo00Oooooo0_l0000Mooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Eooooo`005Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^00Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`05oiRH
V?l@413o0000oc8b<_o<c<`00oooool01Ol0003o<S8bo`000?lb<S;ok^k^00Oooooo00?o0000oooo
ooooool03oooool00ol0003oooooo`000004o`0000?ooooo00Gok^k^oc8b<_l0003o0000onk^kP0A
ooooo`03o`000?oooooooooo00Sooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;o
k^k^2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo1?l000002?l@413o
ooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Sooooo1Ol00003ooooo`06onk^k_lb<S;o0000oc8b<_o^k^ko00002oooool00ol0003o
ooooooooo`0<ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool00oo^k^ko<S8bo`000007o`00
00_ooooo00?o0000ooooooooool02_ooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^00kooooo000Fooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool01Ol@413o^[Zj
oooooomgMgOo<S8b00;ooooo00Ko0000ogMgMonHV9SooooooiRHV?mgMgL7ooooo`03o`000?oooooo
oooo00oooooo00Oo0000oooooonHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?oooooo
0000ogMgM`0Aooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00;ooooo00OoMgMgoiRHV?ooooooV9RHogMgMooooooo000000gooooo00?o
0000ooooooooool02?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?oooooo
V9RHo`00000=ooooo`03o`000?oooooooooo00_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03oooo
o`05ogMgMonHV9Soooooo`000?mgMgL01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00cooooo0_l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool000_ooooo1_l00002
ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o0000ooooooooool02ooo
ool7o`0000Kooooo00Go0000oooooooooooo0000oa0@4003ooooo`03oa0@4?oooooooooo00Kooooo
00?o0000ooooooooool02?ooool7o`0000;ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooo
ooooool0003o410@013ooooo00?o0000ooooooooool01_l00005ooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`02ooooo`07oa0@4?ooooooooooooooool@413oooooo`00
000=ooooo`03o`000?oooooooooo00Wooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooo
ool0003o410@00gooooo00?o0000ooooooooool03oooool02Ol0003ooooooooooooooooo410@oooo
ool0003ooooooa0@4006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`004oooool01?m4A4CogMgMooooool0
0004ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Wooooo00CoZJVYoa0@4?oooooooooo0_l00003ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03oiRHV?lQ8B7ok^k^00?o
oooo00?o0000ooooooooool00_l0000@ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Oo0000ooooooooooooooooo`000?oo
oooo000000kooooo00?o0000ooooooooool02Oooool00onHV9So8B4Qonk^kP03ooooo`03o`000?oo
oooooooo00;o00003_ooool00ol0003oooooooooo`0=ooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooool0003oooooo`000007ooooo`Oo00003Oooool01_m4A4CogMgMooooool0003oooooo`00
00;ooooo00Go0000ooooooooooooooooo`00000>ooooo`004oooool01?oMgMgoEEEEooooool00004
ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00Sooooo00Oo410@o`000?nj^[[oooooo`000?oooooo000000?ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?oMgMgofIVI_oo
ool00_ooool01Ol0003ooooooooooooooooo0000013ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01ol0003ooooooooooooo
oooo0000ooooool000003_ooool00ol0003oooooooooo`0:ooooo`03ogMgMomVIVKooooo00;ooooo
00?o0000ooooooooool00_l0000>ooooo`03o`000?oooooooooo00cooooo00?o410@o`000?nj^[X0
0oooool2o`0000;ooooo00?o0000ooooooooool06Oooool01?oMgMgoEEEEooooool00002ooooo`03
o`000?oooooo000000?ooooo00?o0000ooooooooool03?ooool001Cooooo00?oMgMgolc<c?l00000
1?ooool01Ol@413ooooooooooooooooo410@00;ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`08ooooo`06okZj^_lQ8B7oooooo`000?oooooo410@0oooool00ol@413oooooooooo`06
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo410@00?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool01?ooool2o`0000[ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00;ooooo00Oo410@oooooooooooooooooa0@4?oooooo0000
00oooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo410@00;ooooo00?o0000
oa0@4?ooool03_ooool00ol0003oooooooooo`0<ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@
o`000?oooooooooooa0@400Looooo`03ogMgMoo<c<co000000;ooooo00?o0000ooooool@41000ooo
ool00ol@413oooooooooo`0<ooooo`005?ooool00oo^k^koA4A4o`000004ooooo`07ogMgMonHV9So
oooooiRHV?mgMgOoooooo`00000@ooooo`03o`000?oooooooooo00Gooooo00go410@oiRHV?oooooo
^[Zjo`000?oooooo0000oooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0
3Oooool02?l0003oooooooooool0003o^[ZjoooooonHV9So410@0oooool01OmgMgOoV9RHoooooonH
V9So000000oooooo00?o0000ooooooooool03?ooool2o`0000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`08ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`02ooooo`06ogMgMonHV9SooooooiRHV?mgMgOo00004?ooool00ol0003oooooooooo`06oooo
o`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHo`000?nHV9SoMgMg00oooooo00?o
0000ooooooooool02Oooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgo`000?oooooo
V9RHogMgM`0Looooo`03onk^k_m4A4Co000000?ooooo00Ko0000ogMgMonHV9SooooooiRHV?mgMgL>
ooooo`005Oooool00omgMgOo0000ooooo`03ooooo`06onk^k_lb<S;o0000oc8b<_o^k^ko00004Ooo
ool00ol0003oooooooooo`05ooooo`06ojVYZOl@413o0000oa0@4?nYZJWo00000_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Wooooo00?o0000ooooooooool02oooool02Ol0003ooooooooooooooooo
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`06onk^k_lb<S;o0000oc8b<_o^k^ko00003_ooool00ol0
003oooooooooo`0:ooooo`04oeEEEOmVIVKo0000o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP08ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00oooool00omEEEGoIVIVo`00
0004ooooo`06onk^k_lb<S;o0000oc8b<_o^k^ko00004?ooool00ol0003oooooooooo`06ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00oooooo00?o0000
ooooooooool02Oooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^o`000?l0003o<S8b
onk^kP0Mooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`00
5oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0hooooo`005oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0hooooo`006?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0hooooo`006Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0hooooo`006_ooool4o`0001Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0iooooo`005_ooooooo`00043o0000
4oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooo`000006ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Oooool2o`0000Ko
oooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01?ooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`04ooooo`;o00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`005_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04
ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo
0_l00007ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Aooooo`00=Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03[ooooo000eoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04Oooool01Ol0003ooooooooooooooooo
000000Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool0>_ooool003Kooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Aooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0j
ooooo`00=_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo017ooooo00Go0000oooo
ooooooooooooo`000008ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03[ooooo000fooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool04Oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool0>_ooool003Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Boooo
o`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0jooooo`00=oooool2o`00
0003ooooool0003ooooo01Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo01;ooooo00Co0000oooooooooooooooo0_l00007ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo03[ooooo000hooooo`?o00006Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool04_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0>_ooool005Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0j
ooooo`00E?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool04oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03_ooooo001Doooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Doooo
o`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>oooool005Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Cooooo00Co0000oooo
oooooooo00001oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0kooooo`00EOooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05?ooool01?l0003oooooooooool00007
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo03_ooooo001Eooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Dooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0>oooool005Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00_l00006ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
03_ooooo001Eooooo`05o`000?ooooooooooooooool000006?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Doooo
o`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>oooool005Gooooo00Co0000oooo
oooooooo00006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Eooooo`04o`000?ooooooooooo`0000Oooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0>oooool005Kooooo00?o0000ooooool000006_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooo000000Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>oooool005Oooooo0_l0000Joooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooool000001_ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0koooo
o`00Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo000000Kooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0>oooool007?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool05_ooool00ol0003oooooo`000006ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo03cooooo001dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooool000001_oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0looooo`00M?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`04o`000?oooooo
0000o`0000Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0??ooool007Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05_ooool0
0ol0003oooooo`000006ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo03cooooo001dooooo`05o`000?oooooooooo
ooooool000006_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooool000001_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0looooo`00MOooool01?l0003oooooooooool0000J
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05oooool00ol0003oooooo`000006
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo03cooooo001eooooo`03o`000?oooooo000001_ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Hooooo`;o00001Oooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0loooo
o`00MOooool3o`0001_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Hooooo`;o
00001Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0looooo`00M_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool03_ooool5o`0000Gooooo0_l00005ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo03cooooo002Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_l00005ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03gooooo
002Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03oooool00onHV9So8B4Qonk^
kP06ooooo`Co00000oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0mooooo`00U?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo013ooooo00?oV9RHob4Q8Oo^k^h01Oooool2o`0000Gooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0?Oooool009Cooooo00Go0000ooooooooooooooooo`00000Dooooo`03ogMgMomVIVKo
oooo00Cooooo0_l00005ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo03gooooo002Dooooo`05o`000?oooooooooo
ooooool000005Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0?Oooool009Gooooo00Co0000oooooooooooo00004Oooool01Ol0003o^[ZjoooooonH
V9So410@00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0mooooo`00UOooool0
1?l0003oooooooooool0000Aooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo03gooooo002Eooooo`03o`000?oooooo000001gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0mooooo`00U_ooool2o`0001gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0mooooo`00]Oooool2o`0000?ooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0?Oooool00;Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0mooooo`00
]Oooool2o`0000?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0?Oooool00;Gooooo0_l00002ooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo03gooooo002eooooo`;o00000_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0mooooo`00]Oooool2o`00
00;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0?Oooool00;Gooooo0_l000000ooooooo0000ooooo`0Mooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0mooooo`00
]Oooool2o`000003ooooool0003ooooo01gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo03kooooo002eooooo`04o`000?oooooo0000o`0001kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03kooooo
002eooooo`;o00008Oooool01?l0003oooooooooool0000Nooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03kooooo
002eooooo`03o`000?oooooooooo023ooooo00Co0000oooooooooooo00007_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0nooooo`00]Oooool00ol0003oooooooooo`0Pooooo`04o`000?ooooooooooo`0001oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0?_ooool00;Gooooo00?o0000ooooooooool08?ooool01?l0003ooooooooo
ool0000Oooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo03kooooo002eooooo`03o`000?oooooooooo023ooooo00Co
0000oooooooooooo00007oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0nooooo`00]Oooool00ol0003ooooooooo
o`0Pooooo`04o`000?ooooooooooo`0001oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0?_ooool00;Gooooo00?o
0000ooooooooool08Oooool00ol0003oooooo`00000Oooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03kooooo002e
ooooo`03o`000?oooooooooo027ooooo0_l0000Pooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03kooooo002eoooo
o`;o00008_ooool2o`00023ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0?_ooool00;Gooooo00?o0000oooooooo
ool0A?ooool01Ol0003ooooooooooooooooo0000023ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0nooooo`00]Oooool00ol0003oooooooooo`14ooooo`05o`000?oooooooooooooo
ool000008?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03kooooo002eooooo`03
o`000?oooooooooo04Cooooo00Co0000oooooooooooo00008Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo03kooooo002eooooo`03o`000?oooooooooo04Cooooo00Co0000oooooooo
oooo00008Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03kooooo002/ooooo`;o
000000?o410@ooooooooool01?ooool00ol0003oooooooooo`14ooooo`04o`000?ooooooooooo`00
027ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0oooooo`00[Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo04Cooooo00Co0000oooooooooooo00008Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo03oooooo002Zooooo`Go00001_ooool00ol0003o
ooooooooo`14ooooo`04o`000?ooooooooooo`0002;ooooo00Go0000ooooooooooooooooo`000011
ooooo`00Z_ooool01?m4A4CogMgMooooool00007ooooo`?o0000A?ooool01?l0003oooooooooool0
000Rooooo`05o`000?ooooooooooooooool00000@Oooool00:[ooooo00CogMgMoeEEEOoooooo0000
1oooool00ol0003oooooooooo`15ooooo`;o00008oooool01Ol0003ooooooooooooooooo0000047o
oooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0AOooool2o`0002?ooooo
00Go0000ooooooooooooooooo`000011ooooo`00Zoooool00oo^k^koA4A4o`000007ooooo`03o`00
0?oooooooooo06[ooooo00Go0000ooooooooooooooooo`000011ooooo`00[?ooool00omgMgOo0000
ooooo`06ooooo`03o`000?oooooooooo06[ooooo00Co0000oooooooooooo0000@_ooool00;Gooooo
00?o0000ooooooooool0J_ooool01?l0003oooooooooool00012ooooo`00]Oooool00ol0003ooooo
ooooo`1Zooooo`04o`000?ooooooooooo`0004;ooooo002eooooo`03o`000?oooooooooo06[ooooo
00Co0000oooooooooooo0000@_ooool00;Gooooo0_l0001/ooooo`03o`000?oooooo000004;ooooo
002eooooo`03o`000?oooooooooo06_ooooo00?o0000ooooool00000@_ooool00;Gooooo00?o0000
ooooooooool0Joooool00ol0003oooooo`000012ooooo`00]Oooool00ol0003oooooooooo`1[oooo
o`;o0000@oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Z
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?nHV9So
oooooiRHV?lQ8B401_ooool3o`000;3ooooo002Zooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_oo
ool00ol0003oooooooooo`2`ooooo`00Z_ooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooo
oooo0;3ooooo002Zooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0/?ooool00:_o
oooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<
00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06oooo
o`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`2`ooooo`00Z_ooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0002`oooo
o`00Z_ooool01Oo<c<co0000o`000?l0003oc<c<0;Wooooo002Zooooo`05oa0@4?nj^[[ooooookZj
^_l@4100^Oooool00:[ooooo00Go0000okZj^_oooooo^[Zjo`00002iooooo`00Z_ooool01OnYZJWo
410@o`000?l@413oZJVY0;Wooooo003oooooofWooooo002cooooo`03o`000?nj^[[ooooo0;;ooooo
002cooooo`;o<S8b/oooool008Cooooo0_l000001_l@413oooooooooool@413o0000oa0@41Sooooo
00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7
QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool5o`0000Gooooo0_l00000
0ol@413oooooooooo`1jooooo`00QOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Oooooo1_l0000=ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00009ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1kooooo`00QOooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo410@0oooool00ol@
413oooooooooo`0@ooooo`03o`000?oooooooooo01_ooooo00?oV9RHob4Q8Oo^k^h01?ooool5o`00
07cooooo0025ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000gooooo00GoMgMg
oc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02ooo
ool6o`0000_ooooo00?oV9RHob4Q8Oo^k^h00oooool01?m4A4CogMgMooooool0001mooooo`00QOoo
ool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001Wooooo00Go0000ob4Q8Ol0003o<S8bolc<c002oooo
o`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0Mooooo`03ogMgMomVIVKo
oooo00;ooooo00CogMgMoeEEEOoooooo0000OOooool008Gooooo00Ko0000ohN7QonYZJWo^[ZjoeEE
EOl0000Iooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400@ooooo`03
oa0@4?l0003o000000?o00007Oooool00ol0003oooooooooo`02ooooo`03ogMgMoo<c<co000007go
oooo0025ooooo`06o`000?lb<S;ooooooooooolb<S;o00006Oooool00ol0003oooooooooo`04oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool00ol0003oooooooooo`0Jooooo`05o`000?nj^[[o
oooooiRHV?l@41001?ooool00oo^k^koA4A4o`00001mooooo`00Q?ooool00ol@413o0000ohN7Q`02
ooooo`03ohN7Qol0003o410@01Sooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_oo
ool00ol0003oooooooooo`0Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Oooool00omgMgOo0000
ooooo`1looooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(26) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .18537 m
.00942 .16389 L
.01483 .15295 L
.01975 .14495 L
.02225 .14173 L
.02496 .13891 L
.02644 .13767 L
.02782 .13672 L
.02913 .136 L
.02986 .13567 L
.03053 .13542 L
.03171 .1351 L
.03299 .13492 L
.03418 .13491 L
.0353 .13505 L
.03661 .1354 L
.03782 .13589 L
.03915 .13664 L
.04057 .13767 L
.04356 .14067 L
.04631 .14446 L
.04933 .1498 L
.05251 .15684 L
.06377 .19186 L
.06898 .21057 L
.07392 .22615 L
.07665 .23268 L
.07819 .23546 L
.07893 .23653 L
.07962 .23737 L
.08081 .23845 L
.08213 .23907 L
.08342 .23907 L
.08481 .23841 L
.08611 .23718 L
.08731 .23553 L
.08863 .23319 L
.09005 .23012 L
.09557 .21376 L
.10543 .17815 L
.11062 .16157 L
.11551 .14898 L
.11991 .14046 L
.12239 .13678 L
.12468 .13408 L
.12599 .13281 L
.12724 .1318 L
.12838 .13105 L
.12959 .13041 L
.13089 .12991 L
Mistroke
.13211 .12963 L
.13285 .12954 L
.13355 .12952 L
.13486 .12964 L
.13602 .12991 L
.13724 .13038 L
.13829 .13093 L
.13944 .13169 L
.14199 .13402 L
.14438 .13701 L
.1472 .14163 L
.14986 .1472 L
.15485 .16105 L
.16022 .18118 L
.16605 .20823 L
.17082 .23184 L
.17595 .25422 L
.17738 .25916 L
.17889 .26347 L
.18017 .26637 L
.18091 .26767 L
.18158 .26862 L
.1829 .26982 L
.18363 .27008 L
.18431 .27008 L
.18553 .26946 L
.18686 .26791 L
.18823 .26537 L
.18952 .2622 L
.19244 .25248 L
.19835 .22589 L
.20893 .17656 L
.21417 .15809 L
.21694 .15039 L
.21988 .14368 L
.22245 .13897 L
.22528 .13488 L
.22785 .13208 L
.22901 .13109 L
.23027 .13019 L
.2315 .1295 L
.23265 .129 L
.23386 .12864 L
.23516 .12844 L
.23636 .12842 L
.23751 .12854 L
.23853 .12878 L
.23964 .12917 L
.24086 .12975 L
.24219 .1306 L
Mistroke
.2449 .13297 L
.2474 .13604 L
.24975 .13976 L
.25497 .15149 L
.25792 .16058 L
.26066 .17078 L
.27102 .22464 L
.27557 .25269 L
.28037 .27918 L
.28288 .28956 L
.28431 .29392 L
.28564 .29686 L
.28686 .29852 L
.28798 .29913 L
.28926 .29876 L
.29048 .29736 L
.29182 .29467 L
.2925 .29287 L
.29324 .29057 L
.2958 .28042 L
.30159 .2486 L
.30662 .21806 L
.31204 .18876 L
.31731 .16659 L
.31961 .15892 L
.32213 .15185 L
.32674 .14204 L
.32925 .13816 L
.33159 .13535 L
.33293 .13405 L
.33435 .1329 L
.33558 .13209 L
.3369 .13139 L
.33764 .13108 L
.33831 .13084 L
.33963 .13051 L
.34037 .13039 L
.34118 .13033 L
.34194 .13033 L
.34265 .13037 L
.34401 .13059 L
.3453 .13096 L
.34646 .13144 L
.3477 .1321 L
.34907 .13301 L
.35051 .13419 L
.35308 .13693 L
.35541 .14019 L
.35791 .14463 L
.3624 .15558 L
Mistroke
.36515 .1645 L
.36774 .17471 L
.37261 .19901 L
.38278 .26853 L
.38546 .28754 L
.38835 .30548 L
.38975 .31268 L
.39107 .31836 L
.39227 .32237 L
.39357 .32546 L
.39478 .32707 L
.39588 .32743 L
.39715 .32653 L
.39834 .32443 L
.39945 .32143 L
.40047 .31783 L
.40278 .30706 L
.40771 .27541 L
.41293 .23792 L
.41803 .20511 L
.42287 .18058 L
.42554 .16988 L
.42845 .16037 L
.43087 .15398 L
.43354 .14835 L
.43604 .14424 L
.43838 .14122 L
.44086 .13878 L
.44214 .13778 L
.44353 .13686 L
.44467 .13625 L
.44588 .13571 L
.44717 .13528 L
.44836 .13501 L
.44955 .13486 L
.45068 .13482 L
.45169 .13488 L
.45278 .13504 L
.45408 .13535 L
.45526 .13575 L
.45662 .13636 L
.45791 .13708 L
.46021 .13872 L
.46272 .14107 L
.46546 .14448 L
.46839 .14932 L
.47115 .1553 L
.47364 .16215 L
.47911 .18288 L
.48219 .19862 L
Mistroke
.48503 .21596 L
.4902 .25448 L
.49574 .30093 L
.49849 .32229 L
.5011 .33893 L
.50223 .34463 L
.50344 .34945 L
.50476 .35317 L
.50598 .35504 L
.50711 .35539 L
.50832 .35428 L
.50947 .35184 L
.51052 .34848 L
.51169 .34356 L
.51296 .33688 L
.51553 .32003 L
.52139 .27261 L
.52691 .2292 L
.53187 .19823 L
.53443 .18562 L
.53724 .17421 L
.53976 .16593 L
.54246 .15882 L
.54531 .15303 L
.54797 .14897 L
.55063 .14599 L
.55314 .14395 L
.5554 .14263 L
.55668 .14208 L
.55786 .14167 L
.55912 .14134 L
.56047 .14111 L
.56175 .141 L
.56293 .14099 L
.56423 .14109 L
.56497 .1412 L
.56565 .14133 L
.56704 .14169 L
.56853 .14223 L
.56999 .1429 L
.57158 .14379 L
.57447 .14588 L
.57728 .14855 L
.57987 .15171 L
.58476 .16017 L
.58751 .16686 L
.59003 .17455 L
.5949 .19467 L
.59954 .22148 L
.61002 .31005 L
Mistroke
.61279 .33517 L
.61578 .35862 L
.61715 .36724 L
.6186 .37443 L
.61984 .37883 L
.6212 .38164 L
.62193 .38225 L
.62262 .38224 L
.62392 .38066 L
.62465 .37891 L
.62532 .37675 L
.62684 .37007 L
.62805 .3631 L
.6294 .35395 L
.63211 .33183 L
.642 .24298 L
.64679 .20977 L
.64931 .19599 L
.65196 .18399 L
.65429 .17533 L
.65684 .16763 L
.65916 .16201 L
.66131 .15785 L
.66397 .15381 L
.66686 .1506 L
.66941 .14857 L
.67069 .14778 L
.6721 .14708 L
.67338 .14658 L
.67454 .14624 L
.67589 .14596 L
.67717 .14581 L
.67834 .14577 L
.67943 .1458 L
.68063 .14593 L
.6819 .14616 L
.68263 .14633 L
.6834 .14655 L
.68477 .14702 L
.68785 .14849 L
.69052 .15023 L
.69345 .1527 L
.69606 .15546 L
.69886 .15914 L
.7039 .16824 L
.70661 .17484 L
.70947 .18357 L
.71462 .20486 L
.71748 .22054 L
.72015 .23814 L
Mistroke
.72626 .28895 L
.73147 .33965 L
.73405 .36337 L
.73644 .38222 L
.73787 .39132 L
.73917 .39781 L
.73992 .40067 L
.74062 .40278 L
.74136 .40436 L
.74216 .40529 L
.74348 .40505 L
.74415 .40409 L
.74489 .40239 L
.74618 .3978 L
.7474 .39179 L
.75687 .30988 L
.76207 .26193 L
.76695 .22575 L
.7722 .19718 L
.77499 .18579 L
.778 .17598 L
.78059 .16926 L
.78333 .16361 L
.78822 .1562 L
.79089 .15325 L
.79373 .15081 L
.79512 .14988 L
.79642 .14915 L
.79758 .14862 L
.79886 .14817 L
.79959 .14797 L
.80027 .14782 L
.80099 .14769 L
.80177 .1476 L
.80249 .14755 L
.80317 .14754 L
.80445 .14759 L
.80518 .14767 L
.80595 .14779 L
.80668 .14793 L
.80735 .14808 L
.80897 .14858 L
.81051 .1492 L
.81308 .15062 L
.81579 .15271 L
.81811 .15503 L
.82066 .15819 L
.82633 .1677 L
.83163 .1803 L
.83689 .19801 L
Mistroke
.84262 .22533 L
.84802 .2606 L
.85302 .30191 L
.85759 .34466 L
.8624 .3873 L
.86492 .40484 L
.86635 .41241 L
.86768 .41763 L
.8689 .42075 L
.87002 .4221 L
.8713 .42187 L
.87251 .4199 L
.87374 .41622 L
.87504 .4106 L
.87737 .39658 L
.88263 .35235 L
.89213 .26721 L
.89746 .23043 L
.90244 .20426 L
.9079 .183 L
.91075 .17439 L
.91377 .16671 L
.91667 .16056 L
.9193 .1559 L
.92197 .15196 L
.92442 .14899 L
.9273 .14628 L
.92881 .14517 L
.9304 .14424 L
.93179 .14361 L
.93309 .14319 L
.93383 .14302 L
.93451 .14291 L
.93529 .14283 L
.93603 .1428 L
.93724 .14287 L
.93858 .14311 L
.93925 .14329 L
.93998 .14353 L
.94129 .14409 L
.94383 .14562 L
.94615 .14756 L
.94884 .15043 L
.95178 .15431 L
.95714 .16323 L
.96777 .18524 L
.97299 .19546 L
.97528 .19919 L
.97779 .2025 L
.97919 .20392 L
Mistroke
.98049 .20495 L
.98186 .20571 L
.98264 .20598 L
.98334 .20613 L
.98411 .20619 L
.98481 .20614 L
.98559 .20598 L
.98642 .20568 L
.98781 .20488 L
.9886 .20427 L
.98934 .2036 L
.99197 .20046 L
.99438 .19666 L
.99981 .18579 L
1 .18537 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo000oooooo`Co00007?ooool5o`0001gooooo1?l0000`ooooo`;o
0000/Oooool003gooooo0_l00003ooooo`;o00006_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo01Wooooo0_l00002ooooo`;o0000;oooool00ol0003oooooooooo`2`ooooo`007ooo
ool4o`0001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01[ooooo1Ol0000=ooooo`03o`000?oooooooooo0;3ooooo000Nooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0/?ooool001gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0?ooooo`Go0000L_ooool4o`0002Kooooo000Looooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool03Oooool2o`0000Gooooo0_l0000Nooooo`Co0000COooool2o`0000;o
oooo0_l0000Uooooo`006oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Kooooo`;o00000oooool2o`00027ooooo
1_l0000Sooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool08_ooool001[ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool08Oooool001[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool2o`0000cooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Pooooo`006_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Poooo
o`006Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Oooooo`005Oooool2o`000009oa0@4?oooooo0000ooooooo^
k^ko<S8bo`000?lb<S;ok^k^00Oooooo00?o0000ooooooooool03oooool01_l0003oV9RHoa0@4?l0
003o<S8bolc<c0?ooooo00Kok^k^oc8b<_l0003o<S8bonk^k_l0000Aooooo`03o`000?oooooooooo
00Kooooo1Ol000002?oooooo0000ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool00ol0003ooooo
ooooo`0<ooooo`Go000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPOooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`04ooooo`Co000000So410@ooooooooooook^k^oc8b
<_l0003o<S8bonk^kPGooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`Go
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`06ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`;o000000Wo
410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h03_ooool001Kooooo00[o0000oooooooo
oooo0000oooooomgMgOoV9RHoooooonHV9SoMgMg1oooool00ol0003oooooooooo`0>ooooo`07o`00
0?oooooo410@okZj^_ooooooMgMgoc8b<P03ooooo`07ogMgMonHV9SooooooiRHV?mgMgOoooooo`00
000@ooooo`03o`000?oooooooooo00Kooooo00GoV9RHob4Q8Oo^k^koooooodA4A002ooooo`06o`00
0?mgMgOoV9RHoooooonHV9SoMgMg3?ooool00ol0003oooooooooo`0<ooooo`04o`000?oooooooooo
o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Gooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko00000_oo
ool6o`0000;ooooo00Go410@oooooooooooooooooa0@4007ooooo`03o`000?oooooooooo00Sooooo
1ol00005ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooo`00000@ooooo`Oo
00000oooool00onHV9So8B4Qonk^kP03ooooo`03o`000?l@413ooooo00;ooooo00?o410@oooooooo
ool02_ooool00ol0003oooooooooo`04ooooo`Ko00000oooool00ol0003oooooo`000004ooooo`05
oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`05ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@
oooooooooooooooooa0@4004ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Ooo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00?ooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@
41003_ooool001?ooooo00KoA4A4omgMgOoooooo0000ooooool00002ooooo`05o`000?oooooooooo
ooooool000002?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?oZJVY
oa0@4?ooool00_ooool01ol0003ooooooooooooooooo0000ooooool000003oooool00ol0003ooooo
ooooo`09ooooo`03oiRHV?lQ8B7ok^k^00;ooooo0_l00003ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool03Oooool00ol0003oooooo`000004ooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`05ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000004
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02?ooool00onYZJWo410@ooooo`02
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000000ko
oooo000Cooooo`03omgMgOmEEEGooooo00;o00000oooool01Ol0003ooooooooooooooooo000000So
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`03oa0@4?l0003o^[Zj00?o
oooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02_ooool01?mgMgOoIVIVooooooooool2o`0000?ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooo000000Cooooo00Go0000ooooooooooooooooo`00
0005ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00Kooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`06ooooo`03oa0@4?l0003o^[Zj00?o
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool00_ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000003_oo
ool001Cooooo00CoMgMgolc<c?l0003o00000oooool01Ol@413ooooooooooooooooo410@00Sooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`03okZj^_lQ8B7ooooo00;ooooo
00Go410@oooooooooooooooooa0@4002ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02oooool01Ol0003oooooooooool0003o410@00?ooooo00?o410@ooooooooool02Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooo000000Cooooo00Go410@oooooooooooooooooa0@4005
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool2o`0000[ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@4003ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01_oo
ool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@ooooooooooooooooo`00000@ooooo`03
o`000?oooooooooo00Oooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@
00Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`03ogMgMoo<c<co0000
00Cooooo00Go410@oooooooooooooooooa0@400>ooooo`005?ooool01?o^k^koA4A4o`000?l00003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02Oooool00ol0003oooooooooo`0;ooooo`08o`000?oo
oooooooooa0@4?nHV9SooooookZj^_l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo00Go0000okZj^_ooooooV9RHoa0@
4003ooooo`05o`000?nHV9SooooooiRHV?mgMgL02oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooo000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00Go0000okZj
^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00Cooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;o
oooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000Eooooo`03
ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP09ooooo`03o`000?oooooooooo
00[ooooo00Wo0000ooooooooooooooooojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Ol0003o<S8bo`000?lb<S;ok^k^00[ooooo00?o0000
ooooooooool03oooool00ol0003oIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0@ooooo`07o`000?oooooooooooooooomEEEGoIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00;ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00?ooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00;ooooo00?oMgMgo`000?ooool00_ooool01_l0003ok^k^oc8b<_l0003o<S8b
onk^kPkooooo000Yooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo017ooooo000Zooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01;o
oooo000Zooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo01?ooooo000[ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo000[
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo01?ooooo000Foooooooo0000@?l0000Cooooo`005_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooo`000006ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooool000001oooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooo000000Oooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo0000
00Gooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`;o00001oooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0
003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Gooooo0_l0
0006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo017ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Gooooo00?o0000
ooooool000001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooool000001oooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooo000000Oooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool01Oooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool01?ooool2o`0000Oooooo
00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`05oooo
o`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Aooooo`00;?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo037ooooo000/ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
<Oooool002gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0aooooo`00;Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo037ooooo000]ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0<_ooool002gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Eooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0boooo
o`00;_ooool01Ol0003ooooooooooooooooo000001Wooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo01Gooooo00Co0000oooooooooooooooo0_l00006
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo03;ooooo000_ooooo`03o`000?oooooo000001[ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Gooooo00Go0000oooo
ooooooooooooo`000007ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03;ooooo000_ooooo`?o00006_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05Oooool01Ol0
003ooooooooooooooooo000000Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0<_ooool004gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Gooooo00Go0000oooo
ooooooooooooo`000007ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03;ooooo001=ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Eooooo`05o`000?oooooooooo
ooooool000001oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0booooo`00COooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05oooool01?l0003oooooooooool00007
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo03;ooooo001>ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Gooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool0<oooool004kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01Oooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0c
ooooo`00C_ooool01Ol0003ooooooooooooooooo000001[ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`02o`0000Gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0<oooool004kooooo00Go0000oooo
ooooooooooooo`00000Kooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Oooooo00Co0000oooooooooooo00001_oo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0cooooo`00Coooool01?l0003oooooooooool0000Kooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01Oooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0cooooo`00Cooo
ool00ol0003oooooo`00000Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Sooooo00Co0000oooooooooooo0000
1_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0cooooo`00D?ooool2o`0001cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooo`000006ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03?ooooo001^ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooool000001_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0cooooo`00Koooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooo000000Kooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0<oooool006oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool06Oooool00ol0003oooooo`000006ooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03?o
oooo001_ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo01Wooooo00Co0000ooooool0003o00001Oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0dooooo`00L?ooool01?l0003oooooooooool0000Looooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool06Oooool00ol0003oooooo`000006ooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Co
oooo001`ooooo`04o`000?ooooooooooo`0001cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0=?ooool0073ooooo
00Co0000oooooooooooo00007?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_o
oooo0_l00005ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo03Cooooo001aooooo`?o00007?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo01_ooooo0_l00005ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Cooooo
001aooooo`;o00007_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01_ooooo0_l0
0005ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo03Cooooo002Aooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool04Oooool5o`0000Gooooo0_l00005ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Cooooo002Aoooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04Oooool01OnHV9So8B4Qonk^k_oooooo
A4A400Gooooo0_l00005ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Cooooo002Aooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool04_ooool00onHV9So8B4Qonk^kP06ooooo`Co00000oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0dooooo`00T_ooool01Ol0003ooooooooooooooooo000001Gooooo00?oV9RHob4Q
8Oo^k^h01Oooool2o`0000Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0=Oooool009;ooooo00Co0000oooooooo
oooo00005oooool00omgMgOoIVIVooooo`04ooooo`;o00001?ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0eoooo
o`00T_ooool01?l0003oooooooooool0000Hooooo`03o`000?oooooooooo00?ooooo0_l00004oooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo03Gooooo002Cooooo`03o`000?oooooo000001Cooooo00Go0000okZj^_oo
ooooV9RHoa0@4005ooooo`;o00001?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0eooooo`00Toooool00ol0003o
ooooo`00000Dooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Oooool2o`0000Cooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0=Oooool009?ooooo0_l0000Oooooo`;o00001?ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0eooooo`00
]?ooool2o`0000?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0=Oooool00;Gooooo0_l00002ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo03Gooooo002eooooo`05o`000?ooooooooooooooool000007oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=Oooool00;Gooooo00Go0000
ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0fooooo`00]Oooool2o`0000;ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=_ooool0
0;Gooooo0_l00002ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo03Kooooo002eooooo`;o000000?oooooo`000?oo
ool08?ooool01Ol0003ooooooooooooooooo0000023ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=_ooool00;Go
oooo0_l000000ooooooo0000ooooo`0Pooooo`05o`000?ooooooooooooooool000008?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0fooooo`00]Oooool01?l0003oooooo`000?l0000Qooooo`05o`000?oooooooooo
ooooool000008?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0fooooo`00]Oooool00ol0003oooooooooo`0Roooo
o`05o`000?ooooooooooooooool000008?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0fooooo`00]Oooool2o`00
02?ooooo00Go0000ooooooooooooooooo`00000Pooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Kooooo002eoooo
o`03o`000?oooooooooo02;ooooo00Go0000ooooooooooooooooo`00000Pooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo03Oooooo002eooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooooooo00008Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0gooooo`00]Oooool00ol0003oooooooooo`0Rooooo`04o`000?oooooooooo
o`00027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0=oooool00;Gooooo00?o0000ooooooooool08oooool00ol0
003oooooo`00000Rooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo03Oooooo002eooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooool000008_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0gooooo`00]Oooool00ol0003ooooo
ooooo`0Sooooo`;o00008oooool01Ol0003ooooooooooooooooo000002?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0gooooo`00]Oooool00ol0003oooooooooo`18ooooo`05o`00
0?ooooooooooooooool000008oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Oo
oooo002eooooo`;o0000B_ooool01?l0003oooooooooool0000Sooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0>?ooool00;Gooooo00?o0000ooooooooool0BOooool01?l0003ooooo
ooooool0000Sooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>?ooool00;Gooooo
00?o0000ooooooooool0BOooool01?l0003oooooooooool0000Sooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0>?ooool00;Gooooo00?o0000ooooooooool0BOooool00ol0003ooooo
o`00000Tooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>?ooool00;Gooooo00?o
0000ooooooooool0BOooool00ol0003oooooo`00000Uooooo`05o`000?ooooooooooooooool00000
>_ooool00:cooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo04Wooooo0ol0
000Uooooo`05o`000?ooooooooooooooool00000>_ooool00:gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo02Cooooo00Co0000oooooooooooo0000
>oooool00:[ooooo1Ol00006ooooo`03o`000?oooooooooo077ooooo00Co0000oooooooooooo0000
>oooool00:[ooooo00CoA4A4omgMgOoooooo00001oooool3o`0007;ooooo00?o0000ooooool00000
>oooool00:[ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`1booooo`03o`00
0?oooooo000003_ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0L_oo
ool2o`0003cooooo002[ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0L_ooool2
o`0003cooooo002/ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo00Gok^k^oc8b<_l0
003o410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05oeEEEOmgMgOooooooiRH
V?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06oooo
o`?o0000/?ooool00:[ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo
0;3ooooo002Zooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0/?ooool00:[ooooo
00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`2`ooooo`00Zoooool01?o<c<coA4A4o`00
0?l@4106ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002Zooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo
002Zooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`000;3ooooo002Zooooo`05olc<c?l0
003o0000o`000?o<c<`0^Oooool00:[ooooo00Go410@okZj^_oooooo^[Zjoa0@402iooooo`00Z_oo
ool01Ol0003o^[Zjoooooonj^[[o00000;Wooooo002Zooooo`05ojVYZOl@413o0000oa0@4?nYZJT0
^Oooool00?ooooooJOooool00;?ooooo00?o0000okZj^_ooool0/_ooool00;?ooooo0_lb<S:coooo
o`00Q?ooool2o`000006oa0@4?oooooooooooa0@4?l0003o410@6?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`03ohN7Qol0003o^[Zj00cooooo
00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`Go00000oooool01Oo^k^ko<S8bo`000?l@413oc<c<
07cooooo0025ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`0000go
oooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL00oooool00oo<c<co0000oa0@
400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A003ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40O?ooool008Gooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooooooooa0@40?ooooo00?o410@oooo
ooooool04?ooool00ol0003oooooooooo`0Kooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go0000oooo
ooooooooooooo`00001looooo`00QOooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0
000=ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo00_ooooo1_l0000;ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@1looooo`00QOooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001Wooooo00Go0000ob4Q
8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003ooooooooo
o`0Mooooo`03ogMgMomVIVKooooo00;ooooo00Go0000oeEEEOl0003o410@olc<c01looooo`00QOoo
ool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001Wooooo00?o0000ooooooooool01?ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o410@o`000?l000000ol0000Mooooo`06o`000?oooooooooo
oooooomEEEGoQhN7Ooooool008Gooooo00Ko0000oc8b<_oooooooooooc8b<_l0000Iooooo`03o`00
0?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Booooo`03o`000?oooooooooo01[o
oooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`03omgMgOl@413oV9RH07kooooo0024ooooo`03
oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool4o`0000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0Booooo`03o`000?oooooooooo01[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004
ooooo`04olc<c?m4A4Co0000oa0@47cooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(28) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .13035 m
.00123 .12995 L
.00236 .12972 L
.00365 .12961 L
.00488 .12966 L
.00601 .12986 L
.00706 .13016 L
.00821 .13063 L
.00942 .13129 L
.01196 .13319 L
.01434 .1356 L
.01694 .13895 L
.01975 .14345 L
.02532 .15547 L
.03062 .17087 L
.04057 .20621 L
.04588 .22392 L
.04884 .23173 L
.05025 .23464 L
.05154 .23678 L
.05276 .23832 L
.05405 .23937 L
.05535 .23983 L
.05609 .23981 L
.05678 .23962 L
.05803 .23883 L
.05916 .23764 L
.06048 .23573 L
.06172 .23342 L
.06451 .22669 L
.06746 .21772 L
.07278 .19892 L
.07905 .17627 L
.08481 .15836 L
.0896 .14668 L
.09465 .13756 L
.09727 .13397 L
.09971 .13129 L
.10239 .12908 L
.10389 .12817 L
.10525 .12754 L
.10645 .12714 L
.10772 .12688 L
.1088 .12677 L
.10999 .12679 L
.11127 .12696 L
.11264 .12732 L
.11394 .12782 L
.11513 .12842 L
.11741 .12997 L
Mistroke
.11991 .13231 L
.12226 .13521 L
.12445 .13858 L
.12979 .14988 L
.13281 .15831 L
.13557 .16743 L
.14604 .21268 L
.15096 .23635 L
.15555 .25507 L
.15786 .26198 L
.15916 .26489 L
.16034 .26687 L
.16163 .26827 L
.16236 .26869 L
.16304 .26885 L
.16427 .26853 L
.16559 .26737 L
.16679 .26557 L
.1681 .26285 L
.17074 .2552 L
.17545 .23609 L
.18607 .18658 L
.19089 .16803 L
.19603 .15257 L
.19853 .14664 L
.20088 .14193 L
.20528 .13522 L
.2078 .13246 L
.21016 .1305 L
.21148 .12963 L
.21274 .12895 L
.21419 .12835 L
.21552 .12795 L
.21682 .1277 L
.21821 .12759 L
.21939 .12763 L
.2207 .12781 L
.22143 .12798 L
.2221 .12818 L
.2236 .12878 L
.22494 .12949 L
.22634 .13042 L
.22865 .1324 L
.23113 .13517 L
.23559 .1421 L
.23832 .14781 L
.2409 .15442 L
.24573 .17045 L
.25058 .19173 L
.25592 .22056 L
Mistroke
.26112 .25129 L
.26399 .26728 L
.26671 .28034 L
.26921 .28949 L
.2699 .29141 L
.27063 .29316 L
.27194 .29548 L
.27323 .29668 L
.27444 .2968 L
.27554 .29607 L
.27672 .29442 L
.27785 .29202 L
.27909 .28852 L
.28159 .27902 L
.28608 .25614 L
.29113 .22678 L
.29661 .1969 L
.30145 .17535 L
.30658 .15814 L
.30942 .15093 L
.31255 .1446 L
.3154 .14013 L
.31807 .13688 L
.3207 .13447 L
.32312 .13286 L
.32438 .13222 L
.32576 .13168 L
.32646 .13147 L
.32721 .13128 L
.32855 .13104 L
.32984 .13094 L
.33058 .13094 L
.33127 .13097 L
.332 .13104 L
.33266 .13114 L
.33342 .13129 L
.33415 .13147 L
.33543 .13189 L
.33662 .13239 L
.33931 .13394 L
.34084 .1351 L
.34228 .1364 L
.34496 .13941 L
.34785 .14363 L
.35098 .14953 L
.35635 .1638 L
.35905 .17335 L
.36201 .18594 L
.37214 .24576 L
.37767 .28343 L
Mistroke
.38039 .29976 L
.38158 .30595 L
.38289 .31187 L
.38399 .31598 L
.38517 .31948 L
.38642 .32206 L
.38759 .32338 L
.38895 .32353 L
.39025 .3223 L
.39141 .32007 L
.39268 .31648 L
.39417 .31086 L
.39557 .30432 L
.3982 .28955 L
.40408 .25038 L
.40912 .21779 L
.41466 .18851 L
.41722 .17772 L
.41996 .16799 L
.42491 .15474 L
.42781 .14912 L
.43057 .14497 L
.43304 .14205 L
.43573 .13961 L
.43805 .13802 L
.44062 .13677 L
.4419 .13632 L
.44329 .13597 L
.4446 .13576 L
.44581 .13567 L
.44693 .13566 L
.44797 .13573 L
.44912 .13587 L
.45035 .13612 L
.45163 .13647 L
.45285 .13691 L
.45513 .13798 L
.45764 .13961 L
.45998 .14162 L
.46256 .14447 L
.46533 .14843 L
.46822 .15375 L
.47097 .16016 L
.47347 .16731 L
.47613 .17657 L
.48094 .1983 L
.4854 .22488 L
.4955 .301 L
.49825 .32031 L
.49975 .3294 L
Mistroke
.50114 .33662 L
.50244 .34203 L
.50361 .34578 L
.50492 .34851 L
.50564 .34935 L
.50633 .34969 L
.507 .3496 L
.50774 .34901 L
.50851 .34784 L
.50924 .34626 L
.51053 .34229 L
.51193 .33648 L
.51511 .31839 L
.51802 .29781 L
.52333 .25755 L
.529 .21952 L
.53435 .19218 L
.53921 .17445 L
.54177 .16745 L
.54412 .16219 L
.54666 .15759 L
.54945 .15357 L
.55414 .14857 L
.55671 .14658 L
.55911 .14512 L
.56046 .14446 L
.56192 .14386 L
.56322 .14342 L
.56459 .14305 L
.56583 .1428 L
.56719 .14259 L
.56843 .14247 L
.5696 .14241 L
.57097 .14241 L
.57166 .14244 L
.57242 .1425 L
.57376 .14268 L
.57501 .14293 L
.57649 .14335 L
.57783 .14386 L
.57939 .14462 L
.58085 .14553 L
.58336 .14755 L
.5857 .15008 L
.58827 .15366 L
.59104 .15868 L
.59393 .16553 L
.59668 .17392 L
.59917 .18345 L
.60183 .19592 L
Mistroke
.60664 .2252 L
.61109 .26022 L
.61601 .30471 L
.6212 .34904 L
.62249 .35798 L
.62388 .36606 L
.62468 .3699 L
.6254 .37284 L
.62614 .37527 L
.62682 .37698 L
.6281 .37876 L
.62948 .37856 L
.6307 .37656 L
.632 .37263 L
.63338 .36656 L
.63487 .35808 L
.63756 .33874 L
.64369 .28616 L
.64907 .24377 L
.65201 .22489 L
.65474 .21025 L
.65957 .19071 L
.66213 .18328 L
.66487 .17715 L
.66759 .17251 L
.67046 .16875 L
.67563 .16387 L
.67849 .16186 L
.68118 .16033 L
.68729 .1577 L
.69252 .15561 L
.69749 .15364 L
.69882 .1532 L
.70023 .15281 L
.70104 .15262 L
.70178 .15248 L
.70253 .15236 L
.70322 .15228 L
.70451 .1522 L
.70519 .15219 L
.70591 .15221 L
.70712 .15231 L
.70845 .15251 L
.70982 .15285 L
.71109 .15329 L
.71249 .15393 L
.71397 .15486 L
.71525 .1559 L
.71646 .15711 L
.71786 .15888 L
Mistroke
.71919 .16095 L
.72165 .16596 L
.72391 .17209 L
.72633 .18059 L
.72898 .19242 L
.73449 .22742 L
.73757 .2541 L
.74037 .28264 L
.74552 .34119 L
.74833 .3715 L
.7497 .38442 L
.75096 .39464 L
.75211 .40247 L
.75337 .40901 L
.7547 .41346 L
.75597 .41522 L
.75735 .41435 L
.75805 .41281 L
.75882 .41026 L
.76019 .40374 L
.76147 .39545 L
.7639 .37504 L
.76612 .35253 L
.77115 .29805 L
.77381 .2715 L
.77666 .2471 L
.7793 .22863 L
.78179 .21471 L
.78459 .20267 L
.78714 .19455 L
.78995 .1882 L
.79154 .18564 L
.793 .18384 L
.79431 .18264 L
.79556 .18181 L
.79668 .18129 L
.7979 .18094 L
.79922 .18075 L
.79996 .18072 L
.80063 .18072 L
.80194 .18081 L
.80317 .18094 L
.80539 .18123 L
.8066 .18136 L
.80774 .18145 L
.80897 .18151 L
.81031 .18151 L
.81146 .18145 L
.81268 .18133 L
.81339 .18123 L
Mistroke
.81413 .18111 L
.81547 .18082 L
.81691 .18041 L
.81851 .17983 L
.82135 .17841 L
.82402 .17656 L
.82899 .17182 L
.83435 .16577 L
.83921 .16078 L
.84189 .15852 L
.84441 .15678 L
.84584 .15599 L
.8466 .15565 L
.8474 .15536 L
.84807 .15517 L
.84881 .15503 L
.85011 .15498 L
.85143 .15524 L
.85217 .15555 L
.85285 .15593 L
.85416 .15702 L
.85541 .1585 L
.85681 .16075 L
.85808 .16336 L
.86092 .17144 L
.86355 .18206 L
.86602 .19531 L
.86891 .21566 L
.87157 .23978 L
.87757 .31419 L
.88253 .38649 L
.88526 .42132 L
.8866 .43513 L
.88784 .44532 L
.889 .45233 L
.89024 .4568 L
.89148 .45807 L
.89284 .45571 L
.89398 .45083 L
.8952 .44283 L
.89635 .43291 L
.8974 .42207 L
.90285 .35016 L
.90584 .30903 L
.90866 .27482 L
.9113 .24854 L
.91415 .22658 L
.91674 .21189 L
.91912 .20215 L
.92027 .19857 L
Mistroke
.92151 .19548 L
.92267 .19321 L
.92374 .19165 L
.92499 .19041 L
.92634 .18971 L
.92762 .18962 L
.92881 .18997 L
.93003 .1907 L
.93117 .19167 L
.93377 .19466 L
.93905 .20192 L
.94171 .20528 L
.94451 .20816 L
.94567 .20909 L
.9469 .2099 L
.94826 .21054 L
.94952 .21088 L
.95028 .21095 L
.95098 .21093 L
.95175 .2108 L
.95256 .21053 L
.95393 .2098 L
.95471 .20922 L
.95543 .20856 L
.95802 .20538 L
.96081 .20064 L
1 .13035 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo000goooo
o`Co00007oooool3o`0005Sooooo00?o0000ooooooooool0/?ooool001Kooooo0ol0000Mooooo`;o
00000_ooool2o`0001gooooo0_l000001?oooooo0000o`000?l0000Oooooo`;o0000=Oooool2o`00
09gooooo00?o0000ooooooooool04Oooool001Wooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Looooo`;o000000Coooooo`000?l0003o0000<_ooool00ol0003oooooooooo`2Loooo
o`03o`000?oooooooooo017ooooo000Jooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool06Oooool2o`0000Gooooo0_l0000Nooooo`Go00003_ooool00ol0003oooooooooo`2Kooooo`03
o`000?oooooooooo01;ooooo000Kooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Wooooo0_l00005ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0Voooool00ol0003oooooooooo`0Booooo`007?oo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Aooooo`Go0000Q?ooool00ol0003oooooooooo`0Cooooo`007?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0?ooooo`?o00001?ooool2o`0008;ooooo00?o0000ooooooooool04oooool0
01gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
07oooooo00?o0000ooooooooool05?ooool001gooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo02;ooooo1?l0001Hooooo`03o`000?oooooooooo01Co
oooo000Nooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`07ooooo`;o00003_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01kooooo
0ol00003ooooo`;o0000:Oooool3o`0002[ooooo00?o0000ooooooooool05Oooool001kooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01_ooooo0_l0
0008ooooo`03o`000?oooooooooo02Gooooo0_l00002ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool05Oooool001kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo01Wooooo0_l0000;ooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01Kooooo000Eoooo
o`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_l000004?ooool00ol0003ooooo
ooooo`07ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00_ooool01_l0003ok^k^oc8b<_l0003o<S8b
onk^kPcooooo00?o0000ooooooooool03?ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP08ooooo`03o`000?oooooooooo00gooooo00Co0000oooooooooooooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0=ooooo`04o`000?oooooo
ooooooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPWooooo0_l0000=oooo
o`03o`000?oooooo000000Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Kooooo00?o0000
ooooooooool00_ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0Mooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h03_ooool0
01Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So0000013ooooo00?o0000
ooooooooool01oooool01Ol@413o^[ZjoooooomgMgOo<S8b00;ooooo00Ko0000ogMgMonHV9Sooooo
oiRHV?mgMgL;ooooo`03o`000?oooooooooo00gooooo00GoV9RHo`000?o^k^koooooodA4A003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo00gooooo00Oo0000oooooonHV9So
8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Eooooo`03o`000?oooooo
oooo00?ooooo00Go410@okZj^_l0003oMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
7?ooool00ol0003oooooo`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool000_ooooo
1_l00002ooooo`Go00000oooool01Ol@413ooooooooooooooooo0000013ooooo00?o0000ooooool0
00001Ol00006ooooo`05o`000?ooooooooooo`000?l@41000oooool00ol@413oooooooooo`09oooo
o`03o`000?oooooooooo00Gooooo1_l00003ooooo`03oiRHV?l0003ok^k^00Cooooo00Go410@oooo
oooooooooooooa0@4007ooooo`03o`000?oooooooooo00Wooooo1ol00004ooooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@4004ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
2?ooool00ol0003oooooooooo`0=ooooo`06o`000?oooooooooooiRHV?lQ8B7ok^k^1?ooool01Ol@
413ooooooooooooooooo410@01Cooooo00?o0000ooooooooool01oooool2o`0000?ooooo00Go410@
oooooooooooooooooa0@400Kooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00kooooo
000Cooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000?ooooo`03
o`000?oooooooooo00_ooooo00CoZJVYoa0@4?oooooooooo0_l00003ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool03oooool00ol0003o8B4Qonk^kP03ooooo`05o`000?oooooooooo
ooooool000001oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`000007ooooo`03o`000?oooooooooo00oooooo00Ko0000ooooooooooooV9RHob4Q8Oo^k^h3oooo
o`05o`000?ooooooooooooooool000004oooool00ol0003oooooooooo`08ooooo`03o`000?l@413o
oooo00;ooooo00Go0000ooooooooooooooooo`00000Kooooo`04o`000?oMgMgoooooo`0000Cooooo
00Go0000ooooooooooooooooo`00000>ooooo`004oooool01?oMgMgoEEEEooooool00004ooooo`04
o`000?ooooooooooooooo`;o00003_ooool00ol0003oooooooooo`0:ooooo`03oa0@4?l0003o^[Zj
00?ooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo00oooooo00?o0000
ogMgMomVIVH00oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`000004ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0@ooooo`06
o`000?oooooooooooooooomgMgOoIVIV0oooool01Ol0003ooooooooooooooooo000001;ooooo00?o
0000ooooooooool02?ooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool00000
6_ooool01Ol0003ogMgMoeEEEOoooooo000000Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`005?ooool00omgMgOoc<c<o`000004ooooo`06oa0@4?ooooooooooooooool@413o00003_ooool0
0ol0003oooooooooo`0;ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go0000oooooooooooooooooa0@
400:ooooo`03o`000?oooooooooo013ooooo00?o0000ooooool000000oooool01Ol@413ooooooooo
oooooooo410@00Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4004ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool01Oooool2o`0000[ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006oooo
o`03o`000?oooooooooo017ooooo00Go0000ooooooooooooooooo`000003ooooo`05oa0@4?oooooo
ooooooooool@41002Oooool4o`000003ooooool0003o000000;o00003?ooool00onj^[[o0000oooo
o`02ooooo`05oa0@4?ooooooooooooooool@41006_ooool01Ol0003oooooogMgMoo<c<co000000Co
oooo00Go410@oooooooooooooooooa0@400>ooooo`005?ooool00oo^k^koA4A4o`000004ooooo`06
ogMgMonHV9SooooooiRHV?mgMgOo00003_ooool00ol0003oooooooooo`08ooooo`05oa0@4?nHV9So
oooookZj^_l000000oooool01Ol0003oV9RHoooooonHV9SoMgMg00[ooooo00?o0000ooooooooool0
3_ooool01Ol0003o^[Zjooooool0003o410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06oooo
o`03o`000?oooooooooo017ooooo00Go0000ooooooooooooooooo`000004ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0
4_ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08oooo
o`;o00000oooool2o`0000cooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL06Oooool01_l0003oooooooooooo^k^koA4A4o`0000Cooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0>ooooo`005Oooool00omgMgOo0000ooooo`03ooooo`07onk^k_lb<S;o0000oc8b
<_o^k^koooooo`00000<ooooo`03o`000?oooooooooo00Wooooo00GoZJVYoa0@4?l0003o410@ojVY
Z@03ooooo`05o`000?lb<S;o0000oc8b<_o^k^h02_ooool00ol0003oooooooooo`0>ooooo`05oiRH
V?l@413o0000o`000?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool04Oooool01Ol0003ooooooeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo017ooooo00Ko0000ooooooooooooEEEEofIVI_l00004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`0Booooo`05o`000?l@413o0000
ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool04?oo
ool01OnYZJWo410@o`000?l@413o000000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Iooooo`06
o`000?oooooooooooooooomgMgOo00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Q
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo013ooooo0ol0000;ooooo`03o`000?oooooooooo01_ooooo000Qoooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00oooooo0_l000000ooooooo0000ooooo`0:ooooo`03o`000?oooooooooo
01_ooooo000Rooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo00oooooo00Go0000ooooooooooooooooo`000009oooo
o`03o`000?oooooooooo01cooooo000Rooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01cooooo000Rooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo01gooooo000Foooooooo0000@?l0000Cooooo`005_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`00
0007ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
0_l00006ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000oooo
ooooool01Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooo000000Cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool00oooool00ol0003oooooo`000005
ooooo`?o000000?oooooo`000?ooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo017ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00005ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`;o00001oooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001?ooool00ol0003o
ooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooo000000Kooooo0ol00006ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool04Oooool002?ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0[ooooo`009?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02_ooooo
000Tooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0;?ooool002Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0/ooooo`009?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo02cooooo000Uooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0;?ooool002Gooooo0_l00002ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
0_ooool2o`0000Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0;?ooool002Kooooo00Co0000oooooooooooo0000
7?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
;?ooool002Kooooo0ol0000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Gooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0]ooooo`00A_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
;Oooool004Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo01Sooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02gooooo
0017ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Hooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0]ooooo`00Aooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06?oo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0;Oooool004Oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Sooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02gooooo0017ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Hooooo`04o`000?oo
ooooooooooooo`;o00001Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0]ooooo`00B?ooool01?l0003ooooooooo
ool0000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo01Wooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo02gooooo0018ooooo`04o`000?ooooooooooo`0001kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool06_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02kooooo0019ooooo`;o
00007oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Jooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0;_ooool006[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool06_ooool01?l0003oooooooooool00006oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo02kooooo001Zooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01[ooooo00Co0000oooooooo
oooo00001_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0^ooooo`00Joooool01Ol0003ooooooooooooooooo0000
01kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Jooooo`04o`000?oooooooooo
o`0000Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0;_ooool006_ooooo00Go0000ooooooooooooooooo`00000N
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06_ooool01?l0003oooooooooool0
0005ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo02kooooo001[ooooo`05o`000?ooooooooooooooool000007_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool00_l0
0004ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo02kooooo001[ooooo`05o`000?ooooooooooooooool000007_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo0000
1Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0^ooooo`00Joooool01Ol0003ooooooooooooooooo000001kooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0000Go
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0;_ooool006cooooo00?o0000ooooool000008?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo01cooooo00?o0000ooooool000001Oooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0_ooooo`00K?ooool2o`00027ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0;oooool008oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo000000Gooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0;oooool008oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Coooo
o`Go00001?ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02oooooo002?ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool04oooool01OnHV9So8B4Qonk^k_ooooooA4A4
00Cooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0_ooooo`00Soooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo01Cooooo00?oV9RHob4Q8Oo^k^h01Oooool00ol0003o
ooooo`000002o`0000?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0;oooool0093ooooo00Co0000oooooooooooo
00006?ooool00onHV9So8B4Qonk^kP04ooooo`03o`000?oooooo000000Cooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0;oooool0093ooooo00Co0000oooooooooooo00006Oooool00omgMgOoIVIVooooo`04ooooo`;o
00001?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0_ooooo`00T?ooool01?l0003oooooooooool0000Jooooo`03
o`000?oooooooooo00?ooooo0_l00004ooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02oooooo002Aooooo`;o0000
5oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo0_l00004ooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02oo
oooo002Aooooo`;o00005oooool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo0_l00004ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo02oooooo002eooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
;oooool00;Gooooo00Go0000ooooooooooooooooo`00000Qooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0`ooooo`00]Oooool2o`0000;ooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0<?ooool00;Gooooo00Go0000ooooooooooooooooo`00000Qooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0`ooooo`00]Oooool0
1Ol0003ooooooooooooooooo0000027ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo033ooooo002eooooo`;o000000?oooooo`000?ooool08Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<?ooool0
0;Gooooo0_l000000ooooooo0000ooooo`0Qooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0`ooooo`00]Oooool3o`0002?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo033ooooo002eooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo033ooooo002eooooo`03o`000?oooooooooo02Cooooo00Go0000oooooooooooooooo
o`00000Rooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo033ooooo002eooooo`03o`000?oooooooooo02Cooooo00Go
0000ooooooooooooooooo`00000Sooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo033ooooo002eooooo`;o00009Ooo
ool01Ol0003ooooooooooooooooo000002?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<?ooool00;Gooooo00?o
0000ooooooooool09?ooool01?l0003oooooooooool0000Tooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo033ooooo
002eooooo`03o`000?oooooooooo02Cooooo00Co0000oooooooooooo00009?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0`ooooo`00]Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo000002Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0<Oooool00;Gooooo00?o0000ooooooooool09Oooool00ol0003oooooo`00000T
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo037ooooo002eooooo`03o`000?oooooooooo02Gooooo0_l0000Uoooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo037ooooo002eooooo`03o`000?oooooooooo04cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0<Oooool00;Gooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0aooooo`00]Ooo
ool2o`0004gooooo00Go0000ooooooooooooooooo`00000Vooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0<Oooool00;Gooooo00?o0000ooooooooool0COooool01?l0003ooooooooo
ool0000Vooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0<Oooool00;Gooooo00?o
0000ooooooooool0COooool01?l0003oooooooooool0000Vooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0<Oooool00;Gooooo00?o0000ooooooooool0COooool01?l0003ooooooooo
ool0000Vooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0<Oooool00;Gooooo00?o
0000ooooooooool0COooool01?l0003oooooooooool0000Vooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0<Oooool00:cooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oo
oooooooo04gooooo00Co0000oooooooooooo00009_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo037ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0COoo
ool01?l0003oooooooooool0000Wooooo`04o`000?ooooooooooo`0003Cooooo002Zooooo`Go0000
1_ooool00ol0003oooooooooo`1>ooooo`;o0000:?ooool01?l0003oooooooooool0000dooooo`00
Z_ooool01?m4A4CogMgMooooool00007ooooo`?o0000C_ooool2o`0002Sooooo00Co0000oooooooo
oooo0000=?ooool00:[ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`1>oooo
o`;o0000:?ooool01?l0003oooooooooool0000dooooo`00Zoooool00omgMgOoc<c<o`000007oooo
o`03o`000?oooooooooo07Sooooo00Co0000oooooooooooo0000=?ooool00:_ooooo00?ok^k^odA4
A?l000001oooool00ol0003oooooooooo`1hooooo`04o`000?ooooooooooo`0003Cooooo002/oooo
o`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0N?ooool01?l0003oooooooooool0000d
ooooo`00]Oooool00ol0003oooooooooo`1hooooo`04o`000?ooooooooooo`0003Cooooo002eoooo
o`03o`000?oooooooooo07Sooooo00Co0000oooooooooooo0000=?ooool00;Gooooo00?o0000oooo
ooooool0N?ooool01?l0003oooooooooool0000dooooo`00]Oooool2o`0007Wooooo00Co0000oooo
oooooooo0000=?ooool00;Gooooo00?o0000ooooooooool0N?ooool01?l0003oooooooooool0000d
ooooo`00]Oooool00ol0003oooooooooo`1hooooo`04o`000?ooooooooooo`0003Cooooo002eoooo
o`03o`000?oooooooooo07Sooooo00Co0000oooooooooooo0000=?ooool00;Gooooo00?o0000oooo
ooooool0N?ooool00ol0003oooooo`00000eooooo`00]Oooool00ol0003oooooooooo`1iooooo`;o
0000=Oooool00;Gooooo00?o0000ooooooooool0NOooool2o`0003Gooooo002eooooo`03o`000?oo
oooooooo07[ooooo00?o0000ooooooooool0<oooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0
1_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo
00?o0000ooooooooool0/?ooool00:[ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo0;3ooooo002Zooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`000;3ooooo
002Zooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_oo
ool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03omgMgOl@413o
V9RH00Sooooo00?o0000ooooooooool0/?ooool00:_ooooo00Coc<c<odA4A?l0003o410@1_ooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00Z_ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0/?ooool0
0:[ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Zoooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Olb
<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0002`ooooo`00Z_ooool01Oo<c<co0000o`000?l0003o
c<c<0;Wooooo002Zooooo`05oa0@4?nj^[[ooooookZj^_l@4100^Oooool00:[ooooo00Go0000okZj
^_oooooo^[Zjo`00002iooooo`00Z_ooool01OnYZJWo410@o`000?l@413oZJVY0;Wooooo003ooooo
ofWooooo002cooooo`03o`000?nj^[[ooooo0;;ooooo002cooooo`;o<S8b/oooool008Cooooo0_l0
00001_l@413oooooooooool@413o0000oa0@41Sooooo00GoA4A4o`000?l0003o<S8bomgMg@02oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o
0000odA4A?nj^[X06?ooool5o`0000?ooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c01looooo`00QOoo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l0000=ooooo`09ogMgMolb
<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@
413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OlQ8B7oV9RHoooooonHV9So8B4Q07cooooo0025ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool06oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo013ooooo
00?o0000ooooooooool06oooool00onHV9So8B4Qonk^kP04ooooo`05o`000?ooooooooooooooool0
0000O?ooool008Gooooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00003Oooool01Omg
MgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;
ooooo`Ko00002oooool00onHV9So8B4Qonk^kP03ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80O?oo
ool008Gooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Iooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`00_ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool07Oooool00omg
MgOoIVIVooooo`02ooooo`05olc<c?l0003o0000o`000?o<c<`0O?ooool008Gooooo00Ko0000ohN7
QonYZJWo^[ZjoeEEEOl0000Iooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooo
oa0@400@ooooo`03oa0@4?l0003o000000?o00007Oooool02Ol0003ooooooooooooooooo410@okZj
^_oooooo^[Zjoa0@401looooo`00QOooool01_l0003o<S8boooooooooooo<S8bo`0001Wooooo00?o
0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool0
6_ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go0000okZj^_oooooo^[Zjo`00001loooo
o`00Q?ooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo1?l00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Jooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`00oooool01OnYZJWo410@o`000?l@413oZJVY07cooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .15903 m
.00942 .18972 L
.01483 .20929 L
.01975 .22519 L
.02243 .23193 L
.02365 .2344 L
.02496 .23653 L
.02634 .23819 L
.02763 .23914 L
.02901 .23953 L
.02979 .23945 L
.03053 .23918 L
.03182 .23826 L
.03305 .23685 L
.03416 .23518 L
.03536 .23293 L
.03806 .22649 L
.04057 .21909 L
.05251 .17704 L
.05838 .15905 L
.06377 .14612 L
.06868 .13734 L
.07116 .13393 L
.07388 .1309 L
.07661 .12857 L
.07811 .12756 L
.07953 .12679 L
.08085 .12622 L
.08155 .12597 L
.08229 .12575 L
.0836 .12546 L
.08481 .12531 L
.08604 .12527 L
.08734 .12535 L
.08844 .12552 L
.08966 .12582 L
.09096 .12627 L
.09236 .12691 L
.09488 .1285 L
.09743 .13072 L
.09984 .13341 L
.10434 .14023 L
.10695 .14539 L
.10972 .15195 L
.11468 .16677 L
.12589 .21377 L
.13098 .23715 L
.13348 .24742 L
.1358 .25551 L
.1372 .25951 L
Mistroke
.13846 .26247 L
.13987 .26496 L
.14064 .26594 L
.14137 .26662 L
.14264 .26719 L
.14381 .26702 L
.14509 .26608 L
.14645 .26425 L
.14765 .26195 L
.14874 .25933 L
.15119 .25183 L
.15562 .23415 L
.16568 .18892 L
.17074 .16975 L
.17611 .15393 L
.1807 .14397 L
.18576 .1362 L
.18859 .13308 L
.19118 .13089 L
.19402 .12913 L
.19545 .12849 L
.19626 .12819 L
.19701 .12796 L
.1984 .12763 L
.19966 .12744 L
.20102 .12736 L
.20178 .12736 L
.20249 .1274 L
.20366 .12754 L
.20496 .12781 L
.20631 .1282 L
.20757 .12869 L
.21029 .13016 L
.21281 .13207 L
.21558 .13485 L
.21853 .13871 L
.22346 .14769 L
.22627 .15448 L
.22891 .16216 L
.23828 .20082 L
.24352 .22922 L
.24839 .25663 L
.25088 .26937 L
.25324 .27965 L
.25454 .28435 L
.25595 .28851 L
.25724 .29134 L
.25842 .29311 L
.25973 .29406 L
.26096 .29399 L
Mistroke
.26231 .29285 L
.26306 .29172 L
.26376 .2904 L
.26514 .28695 L
.26665 .28206 L
.26941 .27061 L
.28102 .20861 L
.28651 .1834 L
.29155 .16561 L
.29667 .1526 L
.29936 .14749 L
.3022 .14316 L
.30451 .14034 L
.30698 .1379 L
.30969 .13584 L
.31222 .13443 L
.3137 .13381 L
.31506 .13335 L
.31656 .13298 L
.31731 .13284 L
.31814 .13272 L
.31887 .13264 L
.31954 .1326 L
.32027 .13257 L
.32104 .13258 L
.32233 .13265 L
.32307 .13273 L
.32375 .13283 L
.32512 .1331 L
.32641 .13346 L
.32883 .13438 L
.33018 .13507 L
.33143 .13581 L
.33425 .13794 L
.33682 .14048 L
.33916 .1434 L
.34169 .14729 L
.34444 .15257 L
.34933 .1653 L
.35397 .18226 L
.35942 .20921 L
.36522 .2454 L
.37029 .27926 L
.37306 .29594 L
.37564 .30867 L
.37695 .31368 L
.37834 .3178 L
.37914 .31953 L
.37989 .32073 L
.38056 .32144 L
Mistroke
.38129 .32182 L
.3826 .32144 L
.38399 .31959 L
.38518 .31687 L
.38648 .31274 L
.38939 .29982 L
.39252 .2817 L
.39819 .24457 L
.40386 .21015 L
.40925 .18448 L
.4141 .16781 L
.41684 .16076 L
.41938 .15551 L
.42216 .15101 L
.42471 .14779 L
.42751 .14511 L
.42894 .14403 L
.43047 .14307 L
.43182 .14238 L
.43305 .14186 L
.4343 .14143 L
.43545 .14112 L
.4368 .14085 L
.43751 .14075 L
.43826 .14066 L
.43952 .14058 L
.44024 .14056 L
.44092 .14056 L
.44206 .14059 L
.44331 .14069 L
.44461 .14084 L
.44582 .14103 L
.448 .1415 L
.45032 .1422 L
.45305 .14331 L
.45563 .14468 L
.46046 .14826 L
.46296 .15078 L
.46531 .15365 L
.4681 .15791 L
.47066 .16279 L
.47586 .17663 L
.47873 .18698 L
.48146 .19894 L
.49073 .25627 L
.49558 .2933 L
.49814 .31196 L
.50083 .32905 L
.50222 .33624 L
.50375 .34253 L
Mistroke
.50513 .3466 L
.50642 .34886 L
.50775 .34957 L
.50897 .34876 L
.50964 .34773 L
.51036 .34614 L
.51169 .34205 L
.51287 .33719 L
.51417 .33063 L
.5168 .31421 L
.52152 .27859 L
.52712 .23618 L
.53302 .20012 L
.53805 .17798 L
.5409 .16867 L
.54355 .16181 L
.54621 .15647 L
.54871 .15261 L
.55096 .14998 L
.55339 .14787 L
.55466 .14703 L
.55605 .14628 L
.5575 .14569 L
.55886 .1453 L
.56013 .14505 L
.56129 .14493 L
.56263 .14491 L
.5639 .14499 L
.56515 .14517 L
.56654 .14547 L
.56798 .1459 L
.56934 .14638 L
.57438 .1488 L
.57988 .15234 L
.58581 .15728 L
.591 .16282 L
.59583 .16932 L
.60114 .17887 L
.60411 .18592 L
.60681 .1938 L
.61227 .21507 L
.61535 .23086 L
.6182 .24812 L
.62338 .28564 L
.62896 .32945 L
.63168 .34832 L
.63302 .35616 L
.63426 .36232 L
.63538 .3668 L
.63658 .37033 L
Mistroke
.63791 .37263 L
.63911 .37319 L
.64034 .37223 L
.64147 .36999 L
.6427 .3661 L
.64401 .36045 L
.64621 .34779 L
.64862 .33032 L
.65444 .28092 L
.65995 .23633 L
.6649 .20423 L
.66746 .19093 L
.67028 .1787 L
.67544 .16211 L
.67827 .15567 L
.68093 .15102 L
.6834 .14771 L
.68567 .14543 L
.68815 .14364 L
.68941 .14301 L
.69077 .14249 L
.69149 .1423 L
.69226 .14215 L
.69299 .14206 L
.69366 .14201 L
.69493 .14204 L
.69628 .14223 L
.69697 .14239 L
.69772 .14261 L
.69907 .14311 L
.70068 .14389 L
.70215 .14478 L
.70758 .14937 L
.71274 .15551 L
.72283 .17187 L
.73358 .19422 L
.73881 .20713 L
.74372 .22157 L
.74847 .239 L
.7529 .25969 L
.75781 .28877 L
.76318 .32698 L
.7661 .34832 L
.76886 .36671 L
.77134 .38006 L
.77274 .3857 L
.77403 .38946 L
.77515 .39146 L
.7762 .39223 L
.77734 .39179 L
Mistroke
.77858 .3898 L
.77987 .38606 L
.7811 .381 L
.78341 .3679 L
.7882 .32955 L
.79344 .28111 L
.79901 .23418 L
.80426 .19933 L
.80898 .17606 L
.81408 .15826 L
.81674 .1515 L
.81965 .14568 L
.8227 .14108 L
.82416 .13934 L
.82554 .13796 L
.82682 .1369 L
.8282 .13597 L
.82947 .13533 L
.83063 .13491 L
.83189 .13462 L
.83261 .13454 L
.83328 .13452 L
.83463 .13462 L
.8354 .13476 L
.83609 .13495 L
.83743 .13544 L
.8387 .13606 L
.84106 .13765 L
.84361 .13998 L
.84638 .14325 L
.85135 .15124 L
.85595 .16102 L
.87767 .22489 L
.88716 .24921 L
.89239 .26266 L
.89736 .27927 L
.90015 .29163 L
.9032 .3084 L
.90855 .34611 L
.91358 .38558 L
.91623 .40327 L
.91756 .41031 L
.91902 .41612 L
.91975 .41816 L
.92053 .41968 L
.92126 .42044 L
.92193 .42054 L
.92331 .41896 L
.92461 .41522 L
.92592 .40931 L
Mistroke
.92713 .40204 L
.92987 .38005 L
.9397 .27347 L
.94521 .22159 L
.95038 .18573 L
.95298 .17206 L
.95578 .16012 L
.95888 .14981 L
.96173 .14264 L
.96413 .13799 L
.96631 .13471 L
.96752 .13322 L
.96883 .13185 L
.96996 .13086 L
.9712 .12995 L
.97235 .12929 L
.97343 .12882 L
.97457 .12847 L
.97579 .12826 L
.97692 .12822 L
.978 .12832 L
.97896 .12852 L
.98001 .12885 L
.98137 .12946 L
.98265 .13022 L
.98504 .1321 L
.98761 .13482 L
.99039 .13858 L
.9954 .14773 L
1 .15903 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo000_oooo
o`Go00008?ooool4o`0005gooooo00?o0000ooooooooool0/?ooool002gooooo0_l00005ooooo`;o
00007Oooool2o`0000;ooooo0ol0001Kooooo`;o0000U?ooool5o`0001Sooooo000/ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo01kooooo1Ol0000fooooo`03o`000?oooooooooo09;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Fooooo`00;?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Kooooo`;o00001?oo
ool2o`0003Gooooo00?o0000ooooooooool0IOooool5o`0002Oooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Eooooo`00;?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo00Kooooo0_l0000cooooo`03o`000?oooooooooo06Cooooo0_l00003ooooo`;o00009_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Cooooo000[ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Jooooo`So00003_ooool00ol0
003oooooooooo`0iooooo`Co00009oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`00:_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03oooool6o`0002?o
oooo00?o0000ooooooooool00_ooool2o`0002Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04oooool002[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00gooooo
0_l00006ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool04_ooool002Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`08
ooooo`;o00003Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo017ooooo000Foooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Aoooo
o`005_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01oooooo000Eooooo`;o0000
00Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h01oooool00ol0003oooooooooo`0@
ooooo`05o`000?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`05o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP04ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool4o`000008
oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool00_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h:oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooool000001?l00003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03_ooool00ol0003oooooooooo`0:ooooo`05oiRHV?l0003o0000oc8b<_o<c<`00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Cooooo00?o0000ooooooooool01_ooool2o`000009oa0@
4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Fooooo`;o00000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Oooooo00?o0000ooooooooool04?ooool01Ol0003o^[Zjoooooomg
MgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00oooooo
00So0000ooooooooooooV9RHob4Q8Oo^k^koooooodA4A0?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`04ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Wo
oooo00?o0000ooooooooool03?ooool01ol0003ooooooiRHV?lQ8B7ok^k^oooooom4A4@00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool02_ooool01Ol@413o^[Zjo`00
0?mgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Dooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko
00000_ooool5o`0000?ooooo00Go410@oooooooooooooooooa0@4007ooooo`03o`000?oooooooooo
00Sooooo1_l00002ooooo`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooo
oooo410@00Gooooo00?o0000ooooooooool02oooool7o`0000;ooooo00?oV9RHob4Q8Oo^k^h01?oo
ool01Ol@413ooooooooooooooooo410@00?ooooo00?o0000ooooooooool03Oooool6o`0000Gooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooo
oooooooooa0@4009ooooo`03o`000?oooooooooo00gooooo00Go0000oooooonHV9So8B4Qonk^kP04
ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooo000000?ooooo00Go410@oooooooooooooooooa0@400Cooooo`03o`000?oooooooooo00Gooooo
1Ol00003ooooo`05oa0@4?ooooooooooooooool@41003_ooool001?ooooo00?oA4A4omgMgOooool0
0_l00003ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Aooooo`05
o`000?ooooooooooojVYZOl@41000oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000
ooooooooool04Oooool01ol0003oooooooooooooooooV9RHob4Q8Oo^k^h00oooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000002Oooool00ol0003oooooooooo`0=ooooo`06o`000?oooooooooooiRHV?lQ8B7ok^k^
0oooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool03Oooool00ol0003o
ZJVYoa0@4003ooooo`05o`000?ooooooooooooooool000004oooool00ol0003oooooooooo`05oooo
o`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`004oooool0
1_oMgMgoEEEEooooool0003oooooo`0000;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo01;ooooo00Co0000oa0@4?l0003o^[Zj0oooool01Ol0003ooooooooooooooooo
000000Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`02ooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
0_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool03oooool01Ol0003o
oooooooooomgMgOoIVIV00?ooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooo
oooo00gooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000001?ooooo00?o
0000ooooooooool01Oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00003_ooool001Cooooo00GoMgMgolc<c?l0003oooooo`000002ooooo`05oa0@4?oooooooooooooo
ool@41001_ooool00ol0003oooooooooo`0Booooo`04o`000?oooooo^[Zjob4Q8@?ooooo00Go410@
oooooooooooooooooa0@4004ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00ooo
ool01Ol0003ooooooooooooooooo410@00?ooooo00Co410@oooooooooooo00005?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4002oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool01Oooool2o`0000[ooooo00?o0000oooo
ooooool04Oooool01Ol0003ooooooooooooooooo000000Cooooo00Go410@oooooooooooooooooa0@
4008ooooo`03o`000?oooooooooo00oooooo00Go0000ooooooooooooooooo`000003ooooo`05oa0@
4?ooooooooooooooool@41003Oooool00ol0003oooooooooo`0>ooooo`03o`000?lQ8B7ooooo00;o
oooo00Go410@oooooooooooooooooa0@400Cooooo`03o`000?oooooooooo00Kooooo00?oMgMgolc<
c?l000001?ooool01Ol@413ooooooooooooooooo410@00kooooo000Dooooo`05onk^k_m4A4Co0000
ooooool000000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool04Ooo
ool01Ol@413o0000oooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03
o`000?oooooooooo01?ooooo0_l000001?nj^[[ooooooiRHV?l@4103ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool01omgMgOoV9RHoooooonHV9SoMgMgooooool000005Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04Oooool01Ol0003ooooo
oooooooooooo000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo
00oooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03Ooo
ool00ol0003oooooooooo`0;ooooo`03oa0@4?nHV9Sooooo00;o00000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg01;ooooo00?o0000ooooooooool01oooool00oo^k^koA4A4o`000004ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03_ooool001Gooooo00_oMgMgo`000?ooooooooooo`000?ooooook^k^
oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo01;ooooo00GoZJVYo`000?l0003o410@
ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00ol0003oooooooooo`0Dooooo`06
o`000?nHV9So410@o`000?lQ8B7oc<c<0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`02ooooo`03oeEEEOmVIVKo000000Cooooo00Oo
k^k^oc8b<_l0003o<S8bonk^k_oooooo000001Gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo01?ooooo00Co0000oeEEEOmVIVKo00001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool03oooool01OnHV9So0000o`000?lQ
8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03o`000?oooooooooo00_ooooo
00GoZJVYoa0@4?l0003o410@o`000003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0
003oooooooooo`08ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>
ooooo`006Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo027ooooo000Iooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool08Oooool001Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0Qooooo`006Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo027ooooo000Jooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool08Oooool0
01Koooooool00010o`0001?ooooo000Fooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool000001Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Aooooo`005_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?ooool2o`0000Kooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`;o
00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000002ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
4Oooool001_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Rooooo`006oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02;ooooo000Kooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool08_ooool001cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Rooooo`007?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02;ooooo
000Mooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06Oooool01Ol0003ooooooooo
oooooooo000000Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool08_ooool001gooooo00Go0000oooooooooooooooo
o`00000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Iooooo`04o`000?ooooooooooooooo`;o00001oooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Rooooo`00
7_ooool01?l0003oooooo`000?l0000Mooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool000002?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Sooooo`007_ooool3o`0001kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo01[ooooo00Go0000ooooooooooooooooo`000008oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo02?ooooo000oooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool000002?ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Sooooo`00@?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool06_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool08oooool0043ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo01_ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Soooo
o`00@?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool06oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02?ooooo0011ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Kooooo`04
o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool08oooool0047ooooo00Go0000oooooooo
ooooooooo`00000Oooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool00_l00006oooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo02?ooooo0012ooooo`04o`000?ooooooooooo`0001oooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool06oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02?ooooo0012oooo
o`03o`000?oooooo0000027ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07?ooool01?l0003oooooooooool00007
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo02Cooooo0013ooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool07?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Cooooo001Voooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01cooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0T
ooooo`00I_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Looooo`04o`000?ooooooooooo`0000Kooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool09?ooool006Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07Oooool00ol0003oooooo`000006oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo02Cooooo001Vooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01gooooo00?o0000ooooool0
00001_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Tooooo`00Ioooool01Ol0003ooooooooooooooooo0000023o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Mooooo`04o`000?oooooo0000o`00
00Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool09?ooool006Oooooo00Co0000oooooooooooo00008Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo01gooooo00?o0000ooooool000001_ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0Tooooo`00Ioooool01?l0003oooooooooool0000Qooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool07Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
02Cooooo001Xooooo`;o00008_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooool000001Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Tooooo`00S?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo01kooooo00?o0000ooooool000001Oooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Uooooo`00S?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01kooooo00?o
0000ooooool000001Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0Uooooo`00S?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01Gooooo1Ol00004ooooo`03o`000?oooooo000000Gooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool09Oooool008gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Eoooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2o`0000Gooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool09Oooool0
08gooooo00Go0000ooooooooooooooooo`00000Iooooo`03oiRHV?lQ8B7ok^k^00Kooooo1?l00002
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo02Gooooo002=ooooo`05o`000?ooooooooooooooool000006_ooool0
0onHV9So8B4Qonk^kP05ooooo`;o00001?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Uooooo`00S_ooool01?l0
003oooooooooool0000Kooooo`03ogMgMomVIVKooooo00Cooooo0_l00004ooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo02Gooooo002>ooooo`03o`000?oooooo000001gooooo00?o0000ooooooooool00oooool2o`00
00Cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool09Oooool008oooooo0_l0000Iooooo`05o`000?nj^[[ooooooiRH
V?l@41001Oooool2o`0000Cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09Oooool00:[ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c006ooooo`05o`000?ooooooooooooooool000009?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09Oooool00;Gooooo00Go0000oooo
ooooooooooooo`00000Tooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Uooooo`00]Oooool01Ol0003ooooooooooooooooo000002Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Kooooo002eoooo
o`;o00000_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Vooooo`00]Oooool2o`0000;ooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool09_ooool00;Gooooo0_l00002ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Kooooo002eooooo`;o00000_oo
ool00ol0003oooooooooo`0Sooooo`05o`000?ooooooooooooooool000009_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Vooooo`00]Oooool01?l0003oooooo`000?l0000Vooooo`05o`000?ooooooooooooooool0
00009_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Vooooo`00]Oooool01?l0003oooooo`000?l0000Vooooo`05
o`000?ooooooooooooooool000009_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Vooooo`00]Oooool00ol0003o
ooooooooo`0Wooooo`05o`000?ooooooooooooooool000009_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Voooo
o`00]Oooool00ol0003oooooooooo`0Wooooo`05o`000?ooooooooooooooool000009_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Vooooo`00]Oooool00ol0003oooooooooo`0Wooooo`05o`000?oooooooooooooo
ool000009_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Vooooo`00]Oooool2o`0002Wooooo00Co0000oooooooo
oooo00009_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Vooooo`00]Oooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooo000002Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool09oooool00;Gooooo00?o0000ooooooooool0
:?ooool00ol0003oooooo`00000Wooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Oooooo002eooooo`03o`000?oo
oooooooo02Sooooo0ol0000Wooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Oooooo002eooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Wooooo`00]Oooool00ol0
003oooooooooo`1Cooooo`04o`000?ooooooooooo`0002Wooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Wooooo`00]Oooool00ol0003oooooooooo`1Cooooo`04o`000?oooooooooo
o`0002[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Wooooo`00]Oooool00ol0
003oooooooooo`1Cooooo`04o`000?ooooooooooo`0002[ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Wooooo`00]Oooool2o`0005Gooooo00?o0000ooooool00000:_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo02Oooooo002eooooo`03o`000?oooooooooo05Co
oooo0ol0000Zooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09oooool00;Gooooo
00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Yooooo`05o`000?ooooooooooooooool0
0000:_ooool00;Gooooo00?o0000ooooooooool0POooool01Ol0003ooooooooooooooooo000002[o
oooo002eooooo`03o`000?oooooooooo087ooooo00Go0000ooooooooooooooooo`00000Zooooo`00
[?ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0POooool01Ol0003ooooo
oooooooooooo000002[ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
POooool01Ol0003ooooooooooooooooo000002[ooooo002Zooooo`Go00001_ooool00ol0003ooooo
ooooo`22ooooo`03o`000?oooooo000002_ooooo002Zooooo`04odA4A?oMgMgoooooo`0000Oooooo
0ol00022ooooo`03o`000?oooooo000002_ooooo002Zooooo`04omgMgOmEEEGoooooo`0000Oooooo
00?o0000ooooooooool0P_ooool00ol0003oooooo`00000[ooooo`00Zoooool00omgMgOoc<c<o`00
0007ooooo`03o`000?oooooooooo08?ooooo0_l0000[ooooo`00Zoooool00oo^k^koA4A4o`000007
ooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool0:_ooool00:cooooo00?oMgMgo`00
0?ooool01_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00Z_ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000oooo
ooooool0/?ooool00:[ooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo
0;3ooooo002Zooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`2`oooo
o`00Z_ooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0002`ooooo`00Z_ooool01Ol0003o
EEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00?oEEEEohN7Qooo
ool02?ooool00ol0003oooooooooo`2`ooooo`00Z_ooool00ooMgMgo410@oiRHV008ooooo`03o`00
0?oooooooooo0;3ooooo002[ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go
c<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go<S8boiRHV?ooooooV9RH
oc8b<P06ooooo`?o0000/?ooool00:[ooooo00Goc<c<o`000?l0003o0000olc<c02iooooo`00Z_oo
ool01Ol@413o^[Zjoooooonj^[[o410@0;Wooooo002Zooooo`05o`000?nj^[[ooooookZj^_l00000
^Oooool00:[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2iooooo`00oooooomYooooo`00/oooool0
0ol0003o^[Zjooooo`2booooo`00/oooool2oc8b<[?ooooo0024ooooo`;o000000Ko410@oooooooo
oooo410@o`000?l@410Hooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01So
oooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0O?ooool0
08Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00003Oooool02Omg
MgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03olc<c?l0003o410@00cooooo
00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002Oooool01Ol@413o^[ZjoooooomgMgOo<S8b
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1looooo`00QOooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`0@
ooooo`03o`000?oooooooooo01kooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oo
oooooooo07[ooooo0025ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000gooooo
00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool02oooool6o`0000cooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo0000
07cooooo0025ooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo00006Oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo01cooooo
00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000007cooooo0025ooooo`06o`00
0?n7QhOoZJVYokZj^_mEEEGo00006Oooool00ol0003oooooooooo`04ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol@413o0000o`000003o`0001cooooo00?o^[Zjob4Q8Oooool00_ooool0
1Ol@413ooooooooooooooooo410@07cooooo0025ooooo`06o`000?lb<S;ooooooooooolb<S;o0000
6Oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool00ol0003o
ooooooooo`0Jooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9So
MgMg07cooooo0024ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool4o`00
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Booooo`03o`000?oooooooooo01[ooooo00GoZJVY
oa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0O?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(32) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .23908 m
.00123 .23999 L
.00236 .24037 L
.00365 .24025 L
.00488 .2396 L
.00601 .23854 L
.00706 .23718 L
.00942 .23292 L
.01181 .22717 L
.01444 .21956 L
.01975 .20171 L
.02532 .18204 L
.03062 .16502 L
.03578 .15163 L
.04057 .14211 L
.04583 .13429 L
.04861 .13115 L
.05157 .12856 L
.05311 .12752 L
.05477 .12661 L
.05634 .12594 L
.05778 .12547 L
.05909 .12516 L
.05983 .12502 L
.06052 .12492 L
.06125 .12485 L
.06191 .1248 L
.06268 .12478 L
.06341 .12478 L
.06464 .12486 L
.06599 .12503 L
.06667 .12516 L
.06741 .12534 L
.06873 .12574 L
.06999 .12624 L
.0713 .12689 L
.07366 .12841 L
.07642 .13079 L
.07898 .13361 L
.08201 .13774 L
.08481 .14239 L
.09011 .15399 L
.09586 .17147 L
.10629 .21472 L
.11119 .23639 L
.11577 .25344 L
.11807 .2597 L
.11937 .26231 L
.12055 .26407 L
.12184 .26528 L
Mistroke
.12257 .26562 L
.12325 .26572 L
.12449 .26534 L
.12581 .26415 L
.12712 .26221 L
.12855 .25925 L
.13145 .25101 L
.13663 .23083 L
.14228 .20575 L
.14833 .18076 L
.15407 .1618 L
.1593 .14906 L
.16182 .14427 L
.16455 .13993 L
.16952 .13405 L
.17198 .132 L
.17463 .13034 L
.17585 .12976 L
.17713 .12924 L
.17833 .12886 L
.17942 .12857 L
.18073 .12832 L
.18144 .12821 L
.18212 .12814 L
.18333 .12806 L
.18463 .12806 L
.18532 .12809 L
.18607 .12815 L
.18686 .12825 L
.1876 .12837 L
.18891 .12866 L
.19033 .12909 L
.1918 .12966 L
.19316 .13031 L
.19625 .13224 L
.19897 .1345 L
.20187 .13752 L
.20687 .14459 L
.20972 .14995 L
.2124 .15607 L
.23177 .23661 L
.23708 .26389 L
.24 .27634 L
.24144 .28131 L
.24276 .28508 L
.24401 .28783 L
.24533 .28984 L
.24665 .29088 L
.24741 .29103 L
.24812 .29087 L
Mistroke
.24934 .28993 L
.25046 .28834 L
.25176 .28568 L
.25299 .28238 L
.25551 .27353 L
.2582 .26169 L
.26304 .23691 L
.26831 .20962 L
.274 .18434 L
.27712 .17306 L
.27999 .16429 L
.28267 .15735 L
.28562 .15104 L
.29074 .14285 L
.29354 .13964 L
.29615 .13729 L
.29888 .13539 L
.30141 .13406 L
.30419 .13303 L
.30559 .13266 L
.30634 .1325 L
.30713 .13237 L
.30848 .13221 L
.30972 .13215 L
.31105 .13217 L
.3118 .13222 L
.3125 .13229 L
.31378 .13249 L
.31494 .13274 L
.31627 .1331 L
.31754 .13354 L
.3199 .13456 L
.3224 .13599 L
.32689 .13958 L
.32938 .14229 L
.33172 .14538 L
.33447 .14983 L
.33702 .15486 L
.34226 .16838 L
.34796 .1891 L
.35299 .21326 L
.35834 .24412 L
.36361 .27581 L
.36619 .28979 L
.36856 .30061 L
.37073 .30818 L
.37182 .311 L
.37301 .31326 L
.37421 .31462 L
.37549 .31502 L
Mistroke
.37671 .31439 L
.37781 .31298 L
.37906 .31047 L
.38022 .30727 L
.38288 .29732 L
.38826 .26937 L
.3979 .21547 L
.40339 .19138 L
.40841 .17475 L
.41119 .16762 L
.41421 .16126 L
.41972 .15261 L
.4224 .14943 L
.4253 .14655 L
.42785 .14445 L
.43055 .14263 L
.43299 .14129 L
.43566 .14013 L
.43808 .13929 L
.44037 .13867 L
.44175 .13837 L
.44324 .13812 L
.44461 .13795 L
.44586 .13786 L
.44722 .13784 L
.448 .13787 L
.44872 .13792 L
.44948 .13801 L
.45018 .13812 L
.45095 .13827 L
.45176 .13847 L
.45303 .13887 L
.45439 .13941 L
.45683 .14071 L
.45974 .14285 L
.46239 .14546 L
.46481 .14855 L
.46748 .15289 L
.47026 .15872 L
.47286 .16559 L
.47752 .18187 L
.48252 .20588 L
.49385 .28337 L
.49669 .30378 L
.49936 .3206 L
.50176 .33246 L
.50311 .33741 L
.50436 .34072 L
.50555 .34271 L
.50686 .34352 L
Mistroke
.50823 .34281 L
.5095 .34076 L
.51089 .33708 L
.51215 .33253 L
.51499 .31876 L
.52054 .28324 L
.52658 .2438 L
.53221 .21441 L
.53469 .20434 L
.53742 .19511 L
.5424 .18253 L
.54513 .17753 L
.54768 .17378 L
.55263 .16842 L
.55803 .16413 L
.56891 .15675 L
.57891 .15035 L
.58382 .1474 L
.58598 .14631 L
.58835 .14534 L
.58965 .14493 L
.59087 .14464 L
.59216 .14445 L
.59354 .14436 L
.59426 .14437 L
.59505 .14443 L
.59579 .14453 L
.59648 .14467 L
.59778 .14505 L
.59916 .14565 L
.60031 .14632 L
.60156 .14723 L
.60382 .1495 L
.60513 .15124 L
.6065 .15345 L
.60897 .15852 L
.6116 .16575 L
.61441 .17591 L
.61947 .20166 L
.62257 .2228 L
.6255 .24671 L
.63098 .29917 L
.63351 .32413 L
.63624 .34853 L
.63756 .35866 L
.63881 .3669 L
.63995 .37303 L
.64116 .37798 L
.64244 .38128 L
.64362 .38254 L
Mistroke
.64434 .38244 L
.64503 .38174 L
.6463 .3789 L
.64699 .37656 L
.64772 .37352 L
.64902 .3667 L
.65196 .34594 L
.65716 .29958 L
.66209 .25702 L
.66651 .22684 L
.66901 .2138 L
.67132 .2042 L
.67362 .19678 L
.67615 .19074 L
.67742 .18846 L
.67879 .1865 L
.68009 .18507 L
.68128 .18408 L
.68256 .18332 L
.68376 .18286 L
.68507 .18259 L
.68581 .18253 L
.68648 .18252 L
.68783 .18262 L
.68859 .18274 L
.68929 .18287 L
.69195 .18354 L
.69409 .18413 L
.6964 .18469 L
.69772 .18492 L
.69893 .18506 L
.70015 .18512 L
.7013 .18508 L
.70249 .18493 L
.70376 .18466 L
.70495 .18427 L
.70604 .18382 L
.7087 .18229 L
.7112 .18031 L
.72054 .16932 L
.73054 .1553 L
.73349 .15179 L
.73628 .14902 L
.73879 .1471 L
.74021 .14629 L
.74151 .14574 L
.74273 .14542 L
.74387 .14531 L
.74513 .14543 L
.74648 .14588 L
Mistroke
.74715 .14624 L
.74788 .14674 L
.74922 .14798 L
.75053 .14964 L
.75174 .15161 L
.75306 .15426 L
.75448 .15779 L
.75706 .16615 L
.75958 .17706 L
.76189 .18994 L
.76716 .23142 L
.76981 .25937 L
.77272 .29485 L
.77824 .36663 L
.77983 .38514 L
.78134 .40042 L
.78271 .4118 L
.78346 .41686 L
.78417 .42078 L
.78543 .42567 L
.7861 .42709 L
.78682 .42771 L
.78811 .42641 L
.78929 .42259 L
.79058 .41563 L
.792 .40501 L
.79486 .37606 L
.79993 .31294 L
.8026 .28082 L
.80544 .25122 L
.80791 .22996 L
.81063 .21154 L
.81311 .19888 L
.81543 .19013 L
.81692 .18593 L
.81833 .18289 L
.8196 .18089 L
.82098 .17945 L
.82177 .17897 L
.82248 .17871 L
.8233 .17864 L
.82408 .17877 L
.82546 .17944 L
.82623 .18003 L
.82695 .1807 L
.82938 .1837 L
.83204 .18786 L
.83742 .19722 L
.84006 .20173 L
.84293 .20621 L
Mistroke
.84546 .20951 L
.84674 .21083 L
.84748 .21147 L
.84815 .21196 L
.84941 .21263 L
.85077 .21295 L
.85197 .21288 L
.85323 .21243 L
.85439 .21169 L
.85547 .21073 L
.85793 .20767 L
.86079 .20284 L
.8635 .19741 L
.86855 .18579 L
.87396 .17215 L
.87989 .15788 L
.88244 .15284 L
.88518 .14839 L
.88776 .14508 L
.89012 .14274 L
.8914 .14172 L
.89277 .14087 L
.89356 .14049 L
.89427 .14023 L
.89499 .14005 L
.89567 .13997 L
.89699 .14009 L
.8982 .14056 L
.89953 .14153 L
.9002 .14222 L
.90093 .14315 L
.90224 .14525 L
.90347 .14782 L
.90578 .15427 L
.90827 .16382 L
.91096 .17773 L
.91332 .19349 L
.91583 .21469 L
.92031 .26653 L
.92538 .34423 L
.93019 .41929 L
.93148 .43565 L
.93285 .45009 L
.93363 .45677 L
.93435 .46169 L
.93507 .46548 L
.93574 .46796 L
.93701 .46966 L
.93818 .4678 L
.93946 .46205 L
Mistroke
.94082 .45205 L
.94202 .44024 L
.94311 .42739 L
.94556 .39311 L
.94998 .32411 L
.95486 .25793 L
.95732 .23261 L
.96003 .21119 L
.9625 .19697 L
.96389 .19086 L
.96516 .18631 L
.96638 .18285 L
.96751 .18033 L
.96869 .17841 L
.96998 .17706 L
.97118 .1765 L
.97231 .17653 L
.97332 .177 L
.97442 .17794 L
.97563 .17945 L
.9769 .18154 L
.97918 .18632 L
1 .23908 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo000Yooooo`;o0000R_ooool00ol0003oooooooooo`2`
ooooo`009oooool6o`0008Sooooo00?o0000ooooooooool0/?ooool002Kooooo00?o0000oooooooo
ool01?ooool2o`0001kooooo1ol0001Qooooo`;o0000/Oooool002Gooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
7oooool6o`0003Wooooo00?o0000ooooooooool0/?ooool002Cooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07?oo
ool2o`0000Kooooo0_l0000gooooo`03o`000?oooooooooo0;3ooooo000Tooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Oooooo`Oo00003_ooool0
0ol0003oooooooooo`1jooooo`;o0000=?ooool002?ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo01gooooo0_l00006ooooo`;o00003?ooool00ol0
003oooooooooo`1iooooo`;o000000?oooooo`000?l00000<_ooool002?ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01_ooooo0_l0000:ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool06?ooool6o`0002_ooooo1?l0000[ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0<?ooool002;ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Oooooo0_l00004ooooo`;o0000
:Oooool2o`0000;ooooo0_l0000Zooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
<?ooool0027ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo01Gooooo0_l00007ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0<?oo
ool0027ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`;o00005Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;oooool0
023ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
01;ooooo0_l0000<ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;oooool0023o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo013o
oooo0_l0000>ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0;_ooool001Gooooo
0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bo`00000Cooooo`03o`000?oooooo
oooo00Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`06onk^k_lb<S;o0000oc8b<_o^k^ko
00004_ooool00ol0003oooooooooo`05ooooo`Go00000oooool01_o^k^ko<S8bo`000?lb<S;ok^k^
o`0001;ooooo00?o0000ooooooooool01_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h3ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00gooooo1?l000002?l@413oooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^6Oooool6o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05oiRH
V?l@413o0000oc8b<_o<c<`00oooool01Ol0003o<S8bo`000?lb<S;ok^k^00Gooooo00?o0000oooo
ooooool05Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00kooooo
000Fooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHo`00000Cooooo`03o`00
0?oooooooooo00Cooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRH
V?l000004oooool00ol0003oooooooooo`05ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool0
1_mgMgOoV9RHoooooonHV9SoMgMgo`0001?ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`;o
00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Wooooo00Ko0000oiRHV?lQ8B7ok^k^oooooom4
A4@3ooooo`05ogMgMonHV9So0000oiRHV?mgMgL06oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?o
oooo00Go0000oiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko00000_ooool5o`00
00?ooooo00Go410@ooooooooooooooooo`00000Booooo`Ko00001_ooool01Ol0003ooooooooooooo
oooo410@00?ooooo00?o0000ooooooooool04Oooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h01?oo
ool01Ol@413ooooooooooooooooo000001?ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@4002ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo013ooooo0_l00004ooooo`05
oa0@4?ooooooooooooooool@41006?ooool01_l0003ooooooooooonHV9So8B4Qonk^kPCooooo00Go
410@ooooool0003ooooooa0@400Oooooo`05o`000?ooooooooooooooool000000oooool00ol@413o
ooooooooo`03ooooo`03o`000?oooooooooo01?ooooo1Ol00003ooooo`05oa0@4?oooooooooooooo
ool@41003_ooool001?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo
000001Cooooo00?o0000ooooooooool01_ooool00onYZJWo410@ooooo`02ooooo`05o`000?oooooo
ooooooooool000004oooool00ol0003oooooooooo`07ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go
0000ooooooooooooooooo`00000Dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
0_ooool01ol0003ooooooooooooooooo0000ooooool000005?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000005oooool00ol0003oooooooooo`02ooooo`03oiRHV?lQ8B7o
k^k^00?ooooo00?o0000ooooooooool00_l0000Nooooo`04ojVYZOl@413oooooooooo`;o00000ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo00CoA4A4omgMgOoooooo0000
1?ooool01Ol0003ooooooooooooooooo000000kooooo000Cooooo`04omgMgOmEEEGoooooo`0000Co
oooo00?o0000ooooooooool00_l0000Dooooo`03o`000?oooooooooo00Gooooo00?o410@o`000?nj
^[X00oooool00ol0003oooooooooo`02o`0001Cooooo00?o0000ooooooooool01oooool00omgMgOo
IVIVooooo`02ooooo`05o`000?ooooooooooooooool000005?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00;ooooo00Oo0000ooooooooooooooooo`000?oooooo000001Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001Kooooo00?o0000ooooooooool0
1?ooool00omgMgOoIVIVooooo`02ooooo`03o`000?oooooooooo00;o00007Oooool00ol@413o0000
okZj^P02ooooo`;o00000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo013ooooo
0_l000001?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool001Co
oooo00?oMgMgolc<c?l000001?ooool01Ol@413oooooooooool0003o410@01Gooooo00?o0000oooo
ooooool01Oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooo`000?l@41005?ooool0
0ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool@41000_ooool00ol0003o410@oooo
o`0Dooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01_l@413ooooooooo
oooooooo410@o`0001Kooooo00?o0000ooooooooool01?ooool2o`0000cooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41005Oooool00ol0
003oooooooooo`06ooooo`05o`000?ooooooooooooooool@41000_ooool00ol0003o410@ooooo`0@
ooooo`?o00002_ooool01_nj^[[o8B4Qooooool0003ooooooa0@40?ooooo00?o410@ooooooooool0
1?ooool00ol0003oooooooooo`0?ooooo`07o`000?oooooo0000oooooomgMgOoc<c<o`000004oooo
o`05oa0@4?ooooooooooooooool@41003_ooool001Cooooo00?ok^k^odA4A?l000001?ooool01Omg
MgOoV9RHooooool0003oMgMg01Gooooo00?o0000ooooooooool00_ooool01Ol@413oV9RHoooooonj
^[[o000000?ooooo00GoMgMgoiRHV?oooooo0000ogMgM`0Dooooo`03o`000?oooooooooo00Cooooo
00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9Soooooo`000?mgMgL05Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00KoMgMgoiRHV?ooooooV9RHogMgMol0
000Fooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`Go0000
0_ooool2o`0000Gooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9Soooooo`00
0?mgMgL04?ooool01Ol0003ooooooooooooooooo000000Kooooo00go410@oiRHV?oooooo^[Zjo`00
0?oooooo0000oooooomgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool03_ooool0
2?l0003ooooooooooooooooo0000onk^k_m4A4Co00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00kooooo000Eooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o0000onk^kP0Eoooo
o`03o`000?oooooooooo00;ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o
0000o`000?o^k^h05?ooool00ol0003oooooooooo`04ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?l0003ok^k^01Gooooo00?o0000ooooooooool01?ooool00omEEEGo
IVIVo`000004ooooo`06onk^k_lb<S;o0000oc8b<_o^k^ko00005_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04_ooool01?mEEEGoIVIVo`000?l0
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool00ol0003oooooooooo`02ooooo`Co0000
1_ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o0000onk^kP0@oooo
o`05o`000?ooooooooooooooool000001_ooool01_nYZJWo410@o`000?l@413oZJVYo`0000;ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00kooooo00So0000oooooooo
ooooooooo`000?ooooooMgMgo`0000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`007Ooo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00Go0000oooooooooooooooo
o`00000Jooooo`007Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Gooooo`007Oooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0G
ooooo`007?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Gooooo`007?ooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Fooooo`00
5_ooooooo`00043o00004oooool001Kooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`0000Gooooo
00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooool000001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo
00?o0000ooooooooool01Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oo
oooo00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Cooooo0_l00002
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool04Oooool001Kooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool0
00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`04ooooo`;o
00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool0
00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool0
00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00001oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01?ooool4
o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000Oooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool04Oooool001_ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo01Cooooo000Jooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool05?ooool001[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0D
ooooo`006_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01?ooooo000Iooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool04oooool001Wooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Booooo`006Oooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo00;ooooo0_l00007ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04_oo
ool001Sooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool06oooool01Ol0003ooooooooooooooooo000000Sooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Booooo`005_ooool3o`00023ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01_ooooo00Go0000
ooooooooooooooooo`000007ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04Ooo
ool003[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo01_ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01oooooo000j
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0L
ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Oooooo`00>_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07?ooool0
1Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07oooool003_ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01cooooo00Go0000
ooooooooooooooooo`000007ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01oooooo000kooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Looooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0Oooooo`00>oooool01Ol0003ooooooooooooo
oooo0000023ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02o`0000Gooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool07oooool003cooooo00?o0000ooooool000008_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0M
ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07oooool003cooooo0ol0000R
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01kooooo00Co0000oooooooooooo00001_ooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Oooooo`00HOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Nooooo`04o`000?ooooooooooo`0000Kooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool07oooool0067ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07_ooool01?l0003oooooooooool0
0006ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo01oooooo001Rooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01kooooo00Co0000
oooooooooooo00001_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Oooooo`00H_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08?ooool006?ooooo00Co0000oooo
oooooooo00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01oooooo00?o0000
ooooool000001Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Pooooo`00Hoooool01?l0003oooooooooool0000R
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07oooool01?l0003oooooo`000?l0
0004ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo023ooooo001Sooooo`04o`000?ooooooooooo`0002?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo000000Gooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool08?ooool006Cooooo0_l0000Tooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool08?ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo023ooooo002:oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08?ooool00ol0003oooooo`000005oooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo023ooooo002;ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool08Oooool2o`0000Gooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool08?ooool008_ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Qooooo`;o00001Oooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Pooooo`00Rooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Oooooo1Ol00005ooooo`;o00001?oo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Pooooo`00S?ooool01?l0003oooooooooool0000Jooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01Oooool2o`0000Cooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08?ooool008cooooo00Co
0000oooooooooooo00006oooool00onHV9So8B4Qonk^kP06ooooo`Co00000_ooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Pooooo`00S?ooool00ol0003oooooo`00000Mooooo`03oiRHV?lQ8B7ok^k^00Gooooo0_l0
0004ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo027ooooo002=ooooo`;o00007_ooool00omgMgOoIVIVooooo`05
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08Oooool00:kooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo027ooooo002Zooooo`05
o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
027ooooo002Zooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo027ooooo002eooooo`05o`000?ooooooooooooooool000009Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08Oooool00;Go
oooo00Go0000ooooooooooooooooo`00000Uooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Qooooo`00]Oooool2o`0000;ooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool08Oooool00;Gooooo0_l000000ooooooo0000ooooo`0Uooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Qooooo`00]Oooool2o`000003ooooool0
003ooooo02Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo027ooooo002eooooo`03o`000?oooooo000002Sooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo027ooooo002eooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
027ooooo002eooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo027ooooo002eooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo027ooooo
002eooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`00000Wooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo027ooooo002eooooo`03o`000?oooooooooo02Wooooo00Co0000oooooooooooo0000
:?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Qooooo`00]Oooool2o`0002[ooooo00Co0000oooooooooooo0000
:?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Rooooo`00]Oooool00ol0003oooooooooo`0Yooooo`04o`000?oo
ooooooooo`0002Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool08_ooool00;Gooooo00?o0000ooooooooool0:Ooo
ool01?l0003oooooooooool0000Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02;ooooo002eooooo`03o`000?oo
oooooooo02Wooooo00Co0000oooooooooooo0000:?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Rooooo`00]Ooo
ool00ol0003oooooooooo`0Yooooo`04o`000?ooooooooooo`0002Sooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
8_ooool00;Gooooo00?o0000ooooooooool0:_ooool3o`0002Wooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08_oo
ool00;Gooooo00?o0000ooooooooool0:_ooool2o`0002[ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08_ooool0
0;Gooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
02;ooooo002eooooo`;o0000Eoooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Rooooo`00]Oooool00ol0003ooooo
ooooo`1Fooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo02;ooooo002eooooo`03o`000?oooooooooo05Kooooo00Go
0000ooooooooooooooooo`00000Zooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
8_ooool00;Gooooo00?o0000ooooooooool0E_ooool01Ol0003ooooooooooooooooo000002[ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Rooooo`00]Oooool00ol0003ooooooooo
o`1Fooooo`05o`000?ooooooooooooooool00000:_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo02;ooooo002/ooooo`;o000000?o410@ooooooooool01?ooool00ol0003ooooooooo
o`1Fooooo`05o`000?ooooooooooooooool00000:oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo02;ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0E_oo
ool01Ol0003ooooooooooooooooo000002_ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Rooooo`00Z_ooool5o`0000Kooooo00?o0000ooooooooool0Eoooool01?l0003ooooooooo
ool0000[ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08_ooool00:[ooooo00Co
A4A4omgMgOoooooo00001oooool3o`0005Oooooo00?o0000ooooool00000;?ooool01Ol0003ooooo
oooooooooooo000002Gooooo002Zooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000oooooooo
ool0Eoooool00ol0003oooooo`00000/ooooo`05o`000?ooooooooooooooool000009Oooool00:_o
oooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooo000002co
oooo00Go0000ooooooooooooooooo`00000Uooooo`00Zoooool00oo^k^koA4A4o`000007ooooo`03
o`000?oooooooooo05Oooooo00?o0000ooooool00000;?ooool01Ol0003ooooooooooooooooo0000
02Gooooo002/ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0F?ooool2o`0002co
oooo00Go0000ooooooooooooooooo`00000Uooooo`00]Oooool00ol0003oooooooooo`1Hooooo`;o
0000;?ooool01Ol0003ooooooooooooooooo000002Gooooo002eooooo`03o`000?oooooooooo08Ko
oooo00Go0000ooooooooooooooooo`00000Uooooo`00]Oooool00ol0003oooooooooo`26ooooo`05
o`000?ooooooooooooooool000009Oooool00;Gooooo0_l00027ooooo`05o`000?oooooooooooooo
ool000009Oooool00;Gooooo00?o0000ooooooooool0Q_ooool01Ol0003ooooooooooooooooo0000
02Gooooo002eooooo`03o`000?oooooooooo08Oooooo00Co0000oooooooooooo00009Oooool00;Go
oooo00?o0000ooooooooool0Qoooool01?l0003oooooooooool0000Uooooo`00]Oooool00ol0003o
ooooooooo`27ooooo`03o`000?oooooo000002Kooooo002eooooo`03o`000?oooooooooo08Oooooo
00?o0000ooooool000009_ooool00;Gooooo00?o0000ooooooooool0Qoooool00ol0003oooooo`00
000Vooooo`00]Oooool00ol0003oooooooooo`27ooooo`03o`000?oooooo000002Kooooo002eoooo
o`;o0000R?ooool00ol0003oooooo`00000Vooooo`00]Oooool00ol0003oooooooooo`27ooooo`03
o`000?oooooo000002Kooooo002eooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool0
9Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002a
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool0
1Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00GoEEEE
ogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003oV9RHoooooonH
V9So8B4Q00Kooooo0ol0002`ooooo`00Z_ooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o
0000ooooooooool0/?ooool00:[ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`2`
ooooo`00Z_ooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`04
olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006oooo
o`03o`000?oooooooooo0;3ooooo002Zooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0
003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool0/?ooool00:[ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000/?ooool00:[o
oooo00Goc<c<o`000?l0003o0000olc<c02iooooo`00Z_ooool01Ol@413o^[Zjoooooonj^[[o410@
0;Wooooo002Zooooo`05o`000?nj^[[ooooookZj^_l00000^Oooool00:[ooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@2iooooo`00oooooomYooooo`00/oooool00ol0003o^[Zjooooo`2booooo`00/ooo
ool2oc8b<[?ooooo0024ooooo`;o000000Ko410@oooooooooooo410@o`000?l@410Hooooo`05odA4
A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?oQhN7o`00
0?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo00GoV9RHoa0@4?l0003o<S8bolc<
c003ooooo`Go0000O?ooool008Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07
ooooo`Ko00003Oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03
olc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002Oooool01Ol@
413o^[ZjoooooomgMgOo<S8b00?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A01looooo`00QOooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo410@0ooo
ool00ol@413oooooooooo`0@ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool00_oo
ool00onHV9So8B4Qonk^kP1mooooo`00QOooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo
1_l0000=ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00_ooooo1_l0000<ooooo`03ojVYZOl@413ooooo00Cooooo00?oV9RHob4Q8Oo^
k^h0O?ooool008Gooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Iooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool07?oo
ool00ol@413o0000okZj^P06ooooo`03ogMgMomVIVKooooo07_ooooo0025ooooo`06o`000?n7QhOo
ZJVYokZj^_mEEEGo00006Oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
41004?ooool00ol@413o0000o`000003o`0001cooooo00?o^[Zjob4Q8Oooool01_ooool00ol0003o
ooooooooo`1jooooo`00QOooool01_l0003o<S8boooooooooooo<S8bo`0001Wooooo00?o0000oooo
ooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool06_ooool0
1Ol@413oV9RHoooooonj^[[o000000?ooooo00Go0000okZj^_ooooooV9RHoa0@401looooo`00Q?oo
ool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo1?l00003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Jooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT00oooool01OnHV9So410@o`000?lQ8B7oc<c<07cooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(34) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .21416 m
.00488 .187 L
.00942 .16755 L
.01441 .15186 L
.01721 .14521 L
.01975 .14028 L
.02488 .1329 L
.02778 .12997 L
.03045 .12791 L
.03279 .12655 L
.03536 .12549 L
.03666 .12511 L
.03737 .12495 L
.03805 .12482 L
.03936 .12464 L
.04057 .12456 L
.04126 .12455 L
.042 .12457 L
.04335 .12468 L
.04467 .12488 L
.04588 .12515 L
.04719 .12553 L
.04863 .12607 L
.05154 .12755 L
.05408 .12931 L
.0568 .13174 L
.06172 .13776 L
.06469 .14259 L
.06792 .14905 L
.0738 .16447 L
.07952 .18433 L
.08481 .20626 L
.0894 .22632 L
.09424 .2455 L
.09677 .25351 L
.09811 .25693 L
.09954 .25986 L
.10086 .26186 L
.10206 .26303 L
.10327 .26359 L
.10441 .26354 L
.10576 .26274 L
.10644 .26204 L
.10719 .26105 L
.10852 .25875 L
.10976 .25599 L
.11256 .24791 L
.11556 .23701 L
.12604 .19353 L
.13119 .17492 L
Mistroke
.13668 .15927 L
.13983 .1522 L
.14269 .14693 L
.1456 .14254 L
.14827 .13925 L
.15077 .13675 L
.1535 .13454 L
.15625 .13282 L
.15915 .13147 L
.1617 .13063 L
.16314 .13029 L
.16444 .13005 L
.16566 .12988 L
.16698 .12977 L
.16823 .12973 L
.16938 .12973 L
.17062 .12979 L
.17193 .12992 L
.17304 .13008 L
.17426 .13031 L
.17558 .13062 L
.17698 .13104 L
.17951 .13202 L
.18208 .13335 L
.1845 .13495 L
.18902 .13903 L
.19165 .14221 L
.19443 .14636 L
.19941 .1563 L
.20477 .17144 L
.21066 .19423 L
.22117 .24747 L
.22367 .26017 L
.22634 .27219 L
.22861 .28056 L
.22992 .28438 L
.23112 .28714 L
.23249 .28935 L
.2332 .2901 L
.23396 .29058 L
.23523 .29065 L
.23595 .29027 L
.23662 .28966 L
.2374 .28863 L
.23813 .28736 L
.23951 .28422 L
.24099 .27981 L
.2426 .27397 L
.25307 .22205 L
.25786 .19877 L
Mistroke
.263 .17814 L
.26594 .16864 L
.26864 .16137 L
.27392 .15066 L
.27673 .14658 L
.27934 .14362 L
.2822 .14115 L
.28366 .14015 L
.28525 .13926 L
.28676 .13855 L
.28815 .13804 L
.28948 .13764 L
.29089 .13732 L
.29215 .13712 L
.29333 .137 L
.29462 .13692 L
.29601 .13692 L
.29729 .13697 L
.29802 .13703 L
.2987 .1371 L
.30008 .13727 L
.30156 .13753 L
.30424 .13813 L
.3067 .13884 L
.31236 .14109 L
.31521 .1426 L
.31832 .1446 L
.32362 .14911 L
.32658 .15243 L
.32927 .15611 L
.33179 .16025 L
.33451 .16568 L
.33946 .17859 L
.34933 .21926 L
.35993 .28019 L
.36305 .29626 L
.36459 .30286 L
.36601 .30795 L
.3673 .31159 L
.36867 .31434 L
.36945 .31536 L
.37019 .31595 L
.37156 .31606 L
.37289 .31493 L
.37356 .31391 L
.37429 .31246 L
.37559 .30905 L
.37679 .30498 L
.37952 .29302 L
.38244 .27704 L
Mistroke
.38778 .24412 L
.39358 .21027 L
.39869 .18599 L
.40149 .17527 L
.40411 .16682 L
.40899 .15476 L
.41158 .15003 L
.41437 .14603 L
.4169 .14323 L
.41931 .14121 L
.42147 .13986 L
.4227 .13927 L
.42384 .13884 L
.42518 .13844 L
.42586 .13829 L
.42661 .13817 L
.42793 .13803 L
.42916 .13801 L
.42991 .13803 L
.43062 .13809 L
.43194 .13827 L
.43268 .13841 L
.43337 .13857 L
.43492 .13901 L
.43733 .13991 L
.43999 .14119 L
.44537 .14465 L
.45022 .14867 L
.45545 .1539 L
.46491 .16596 L
.47011 .17456 L
.47495 .18451 L
.48026 .19861 L
.48594 .21871 L
.49746 .27738 L
.50253 .30563 L
.5054 .31921 L
.50681 .32465 L
.50809 .32875 L
.50938 .33193 L
.51061 .33399 L
.5119 .3351 L
.51263 .33523 L
.51331 .33501 L
.51404 .33443 L
.51472 .33356 L
.51599 .33109 L
.51736 .32724 L
.51884 .32181 L
.5218 .30758 L
Mistroke
.52491 .28902 L
.5305 .25226 L
.53537 .22186 L
.54059 .19452 L
.54631 .17168 L
.55165 .1565 L
.55435 .1507 L
.55721 .14568 L
.55969 .14217 L
.56236 .13915 L
.56521 .1367 L
.56789 .13507 L
.56944 .13441 L
.57022 .13415 L
.57107 .13392 L
.5718 .13376 L
.57258 .13364 L
.57332 .13357 L
.57399 .13354 L
.57531 .13358 L
.57597 .13364 L
.57671 .13374 L
.578 .13402 L
.57921 .13439 L
.58064 .13495 L
.58194 .13558 L
.58486 .13744 L
.58739 .13955 L
.59013 .14239 L
.59512 .14899 L
.60497 .16749 L
.61585 .19591 L
.6379 .27475 L
.64777 .31825 L
.65017 .32776 L
.65274 .3364 L
.65421 .34038 L
.65555 .34323 L
.6569 .34527 L
.65818 .34636 L
.65956 .34657 L
.66026 .34627 L
.66102 .34563 L
.66238 .34368 L
.66365 .34092 L
.66514 .33654 L
.66651 .33153 L
.66959 .31715 L
.68006 .25145 L
.68972 .19619 L
Mistroke
.69511 .17339 L
.7 .15766 L
.7028 .15053 L
.70582 .14415 L
.70848 .13953 L
.71129 .13556 L
.71389 .13263 L
.71675 .13016 L
.718 .1293 L
.71934 .12854 L
.72059 .12796 L
.72177 .12754 L
.72305 .1272 L
.72373 .12708 L
.72446 .12698 L
.72519 .12693 L
.72595 .12693 L
.72732 .12703 L
.72859 .12726 L
.72977 .12759 L
.73107 .12808 L
.73245 .12875 L
.73559 .13089 L
.73854 .13372 L
.7412 .137 L
.74407 .14141 L
.74942 .15222 L
.75507 .16775 L
.7652 .20636 L
.77587 .25599 L
.786 .29798 L
.79509 .32605 L
.80029 .33937 L
.80499 .34944 L
.80627 .35157 L
.80764 .35347 L
.80894 .3548 L
.81013 .35556 L
.8114 .35581 L
.81212 .35567 L
.81279 .35535 L
.81414 .35411 L
.8149 .35305 L
.81559 .35185 L
.81685 .34909 L
.81801 .34585 L
.82064 .3362 L
.82542 .31136 L
.83674 .23631 L
.84228 .20339 L
Mistroke
.84736 .179 L
.85221 .16097 L
.85682 .14804 L
.86169 .13811 L
.86444 .13389 L
.867 .13073 L
.86983 .12801 L
.87249 .12609 L
.87489 .12486 L
.87623 .12436 L
.87748 .12401 L
.87881 .12376 L
.88007 .12364 L
.88144 .12364 L
.88221 .12369 L
.88291 .12378 L
.88364 .12391 L
.88432 .12406 L
.88586 .12454 L
.88721 .1251 L
.88865 .12585 L
.89115 .12755 L
.89377 .12992 L
.89848 .13587 L
.9011 .14028 L
.90354 .14522 L
.90908 .15982 L
.91393 .17706 L
.91835 .19661 L
.92826 .25143 L
.93331 .2806 L
.93804 .30444 L
.94296 .32324 L
.94558 .33052 L
.94839 .33663 L
.95974 .3559 L
.96237 .36117 L
.96518 .36679 L
.96654 .36926 L
.96782 .37127 L
.96897 .37272 L
.97022 .3738 L
.9711 .37421 L
.97207 .37425 L
.97308 .37382 L
.97402 .37293 L
.97491 .37164 L
.97571 .37007 L
.97752 .36513 L
.97948 .35756 L
Mistroke
.98162 .34684 L
.98549 .32185 L
1 .21416 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo000Rooooo`;o0000TOooool00ol0003oooooooooo`1e
ooooo`Co0000=oooool001oooooo1?l000001?oooooo0000o`000?l0002>ooooo`03o`000?oooooo
oooo04?ooooo1?l0000/ooooo`;o00000oooool2o`0003Kooooo000Oooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool07oooool6o`0006Kooooo0_l00013ooooo`;o00000_ooool3o`00
02Wooooo0_l00006ooooo`03o`000?oooooooooo03?ooooo000Nooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool07?ooool2o`0000Kooooo0_l0001Tooooo`03o`000?oooooooooo01?o
oooo1?l0000Zooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo03;ooooo000Mooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool06oooool2o`0000Sooooo0_l0000Pooooo`Co0000?oooool00ol0003ooooo
ooooo`0Booooo`;o00000_ooool2o`0002Sooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0<Oooool001cooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool06oooool3o`0000?ooooo0ol0000Sooooo`Ko00004oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00Cooooo0_l0000Uooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo033ooooo000L
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo01Wooooo0_l00008ooooo`;o00007oooool2o`0000Kooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0`ooooo`006oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo00[ooooo0_l0000Mooooo`03o`000?oooooooooo00Kooooo0_l0000@oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo033ooooo000Kooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0`ooooo`006_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool0;oooool001[ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0;ooooo`;o00003oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool0;oooool001[ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02oooooo000Iooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0^ooooo`005Oooool2o`000009
oa0@4?oooooo0000ooooooo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?o0000ooooooooool02_oo
ool03OnHV9So410@o`000?lb<S;oc<c<ooooool0003oooooonk^k_lb<S;o0000oc8b<_o^k^h03ooo
ool00ol0003oooooooooo`09ooooo`Go00000oooool01Oo^k^ko0000o`000?lb<S;ok^k^017ooooo
00?o0000ooooooooool02?ooool4o`000009oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^ko
0000017ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooool000000ol000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;o
k^k^4Oooool00ol0003oooooooooo`06ooooo`Go00000oooool01Ol0003o<S8bo`000?lb<S;ok^k^
01_ooooo00Go0000oa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool00ol0003oooooooooo`0Eooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b
<_o^k^h03_ooool001Kooooo00[o0000oooooooooooo0000oooooomgMgOoV9RHoooooonHV9SoMgMg
3Oooool00ol0003oooooooooo`0:ooooo`0=oa0@4?nj^[[oooooogMgMolb<S;oooooo`000?oooooo
MgMgoiRHV?ooooooV9RHogMgM`0?ooooo`03o`000?oooooooooo00Wooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A003ooooo`05o`000?nHV9SooooooiRHV?mgMgL04Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHo`00000Cooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
ooooo`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Aooooo`03o`000?oooooooooo00Kooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMol0003ooooooiRHV?mgMgL06_ooool01_l0
003o410@okZj^_ooooooMgMgoc8b<P?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00ko
oooo000;ooooo`Ko00000_ooool5o`000004ooooool0003ooooooa0@40?ooooo00?o410@oooooooo
ool03?ooool01?l0003oooooooooooooool6o`0000Kooooo00Go0000ooooool0003ooooooa0@4003
ooooo`03oa0@4?oooooooooo00kooooo00?o0000ooooooooool01_l00003ooooo`03oiRHV?lQ8B7o
k^k^00Cooooo00Go0000oooooooooooooooooa0@400Booooo`Oo00001Oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool000004oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03oooool01?l0003oooooooooool00004ooooo`05
oa0@4?ooooooooooooooool@41004Oooool00ol0003oooooooooo`07ooooo`03oiRHV?lQ8B7ok^k^
00Cooooo00Go410@o`000?oooooooooooa0@400Jooooo`03o`000?oooooooooo00;ooooo00Go0000
oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o0000ooooooooool04_oo
ool5o`0000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`004oooool01_m4A4CogMgMoooo
ool0003oooooo`0000;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo
00cooooo00?oZJVYoa0@4?l000000_ooool01Ol0003ooooooooooooooooo0000013ooooo00?o0000
ooooooooool02_ooool00onHV9So8B4Qonk^kP02ooooo`;o00000oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000001Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooool000001?ooool01Ol0003ooooooooooooooooo0000013ooooo
00?o0000ooooooooool02Oooool00onHV9So8B4Qonk^kP03ooooo`;o00000_ooool00ol0003ooooo
ooooo`0Hooooo`06o`000?oooooooooooooooonYZJWo410@0oooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool04_ooool01?m4A4CogMgMooooool00004ooooo`05o`000?oo
ooooooooooooool000003_ooool001?ooooo00KogMgMoeEEEOoooooo0000ooooool00002ooooo`05
o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`0;ooooo`04oa0@4?l0003o^[Zj
o`0000;ooooo00Go0000ooooooooooooooooo`00000@ooooo`03o`000?oooooooooo00_ooooo00Co
MgMgofIVI_oooooooooo0_l00003ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000005?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04?ooool00ol0003o
ooooo`000004ooooo`05o`000?ooooooooooooooool000004?ooool00ol0003oooooooooo`0:oooo
o`03ogMgMomVIVKooooo00;ooooo00Go0000ooooool0003oooooo`00000Iooooo`07o`000?oooooo
ooooooooool@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000001oooool00ol0003o
ooooooooo`0Aooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>
ooooo`005?ooool01OmgMgOoc<c<o`000?oooooo000000;ooooo00Go410@oooooooooooooooooa0@
400?ooooo`03o`000?oooooooooo00_ooooo00?o^[Zjob4Q8Ol000000_ooool01Ol@413ooooooooo
oooooooo410@017ooooo00?o0000ooooooooool02oooool01Ol0003oooooooooool0003o410@00?o
oooo00?o410@ooooooooool04Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;o
oooo00Go410@ooooooooooooooooo`00000Eooooo`03o`000?oooooooooo00Kooooo0_l0000<oooo
o`03o`000?oooooooooo01;ooooo0_l00004ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`0;ooooo`09o`000?ooooooooooooooool@413oooooo`000?oooooo410@01Wo
oooo00?o0000ooooooooool00_ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41001oooool00ol0003oooooooooo`0Booooo`03ogMgMoo<c<co000000Cooooo00Go410@oooo
oooooooooooooa0@400>ooooo`005?ooool01?o^k^koA4A4o`000?l00003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03oooool00ol0003oooooooooo`08ooooo`04oa0@4?nHV9SooooookZj^P;o0000
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg017ooooo00?o0000ooooooooool01oooool01Ol0003o
^[ZjoooooonHV9So410@00;ooooo00Ko0000ogMgMonHV9SooooooiRHV?mgMgLCooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHooooool0003oMgMg01Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01;ooooo
0_l00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03oooool00ol0003oooooooooo`08ooooo`05
o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHo`000?nHV9SoMgMg01Wooooo00Oo0000
ooooool@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`03
o`000?oooooooooo01;ooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00kooooo000Eooooo`03ogMgMol0003o000000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0?oooo
o`03o`000?oooooooooo00Sooooo00GoZJVYoa0@4?l0003o410@o`000003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h04Oooool00ol0003oooooooooo`07ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0_ooool01_l0003ok^k^oc8b<_l0003o<S8bonk^kQ?ooooo00?o0000ooooooooool01_ooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000o`000?o^k^h05_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04Oooool00omEEEGo0000o`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03oooool00ol0003oooooooooo`08ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Wooooo00Oo0000oooooonY
ZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`03o`000?oo
oooooooo01?ooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo
000Gooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0[ooooo`005oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0:oooool001Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo02_ooooo000Gooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0[ooooo`005_ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool0:oooool001Koooooool00010o`0001?ooooo000F
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool000001Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo
00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000oooooooo
ool01Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool001Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`03ooooo`;o00001oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0007ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooool000001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo017ooooo000Fooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo017ooooo000booooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Aooooo`00
<_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
4Oooool003;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo017ooooo000booooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Looooo`05o`000?ooooooooooooooool000002_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0Booooo`00<_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool07?ooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04_oo
ool003?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo01cooooo00Co0000oooooooooooooooo0_l00009ooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01;ooooo000c
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0M
ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Booooo`00<oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07Oooool0
1Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04_ooool003Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01kooooo00Co0000
oooooooooooo00002Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0Booooo`00=?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07_ooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo01;ooooo000dooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Nooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool04oooool003Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo01kooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Cooooo`00=?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool07oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo000e
ooooo`04o`000?ooooooooooo`0002Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08?ooool01?l0003oooooo`00
0?l00008ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01?ooooo000fooooo`?o00009?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04oooool003Oooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo000000Sooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool04oooool005kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08?ooool00ol0003oooooo`000008oooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo01?ooooo001Nooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo027ooooo00?o0000ooooool0
00002?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Dooooo`00G_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Rooooo`;o0000
2?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Dooooo`00G_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Rooooo`;o00002?oo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Dooooo`00G_ooool01Ol0003ooooooooooooooooo000002Gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Rooooo`;o00002?ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Dooooo`00Goooool01?l0003oooooooooool0000Uooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool08_ooool3o`0000Kooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05?ooool005oooooo00Co0000
oooooooooooo00009Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Dooooo`00H?ooool2o`0002Oooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool05?ooool008Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool05Oooool008Wooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool05Oooool008Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool05Oooool008[ooooo00Go0000oooooooooooooooo
o`00000Kooooo`Go00001_ooool2o`0000Gooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05Oooool008[ooooo00Go
0000ooooooooooooooooo`00000Kooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool2o`0000Go
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool05Oooool008[ooooo00Co0000oooooooooooo00007Oooool00onHV9So
8B4Qonk^kP07ooooo`?o00001?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Eooooo`00Roooool00ol0003ooooo
o`00000Nooooo`03oiRHV?lQ8B7ok^k^00Kooooo0_l00005ooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Gooooo
002;ooooo`?o00007oooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooo000000Cooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool05_ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000003
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo01Kooooo002Zooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool0
0ol0003oooooo`000003ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Kooooo002Zooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01_ooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Kooooo002eoooo
o`03o`000?oooooo000000;ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05_ooool00;Gooooo00Ko0000oooooooo
oooo0000ooooool0000Zooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Fooooo`00]Oooool2o`000004ooooool0003o0000o`0002_ooooo00Go0000
ooooooooooooooooo`00000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Kooooo002eooooo`03o`000?oooooo
oooo02kooooo00Co0000oooooooooooo0000:_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Gooooo`00]Oooool0
0ol0003oooooooooo`0^ooooo`04o`000?ooooooooooo`0002[ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05ooo
ool00;Gooooo00?o0000ooooooooool0;_ooool01?l0003oooooooooool0000Zooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo01Oooooo002eooooo`03o`000?oooooooooo02oooooo0_l0000/ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo01Oooooo002eooooo`03o`000?oooooooooo05kooooo00Go0000ooooooooooooooooo`00000[
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05oooool00;Gooooo00?o0000oooo
ooooool0G_ooool2o`000003ooooool0003ooooo02_ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Gooooo`00]Oooool00ol0003oooooooooo`1Oooooo`;o0000;_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo01Oooooo002eooooo`03o`000?oooooooooo08oooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Gooooo`00]Oooool2o`00097ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Gooooo`00]Oooool00ol0003oooooooooo`2@
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06?ooool00;Gooooo00?o0000oooo
ooooool0TOooool01Ol0003ooooooooooooooooo000001[ooooo002eooooo`03o`000?oooooooooo
09;ooooo00?o0000ooooool000006oooool00;Gooooo00?o0000ooooooooool0Toooool00ol0003o
ooooooooo`0Jooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002/ooooo`;o000000?o410@oooo
ooooool01?ooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003oooooooooo`2`ooooo`00Z_oo
ool01?m4A4CogMgMooooool00007ooooo`?o0000/?ooool00:[ooooo00CogMgMoeEEEOoooooo0000
1oooool00ol0003oooooooooo`2`ooooo`00Zoooool00omgMgOoc<c<o`000007ooooo`03o`000?oo
oooooooo0;3ooooo002[ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Oo^k^ko<S8bo`000?l@413oc<c<
00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00GoEEEEogMgMoooooooV9RHob4Q8@06oooo
o`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`2`ooooo`00Z_ooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0002`oooo
o`00Z_ooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[o
oooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`2`ooooo`00Z_ooool00ooMgMgo410@
oiRHV008ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`04olc<c?m4A4Co0000oa0@40Kooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00:[ooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002Zooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00Z_oo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go
<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000/?ooool00:[ooooo00Goc<c<o`000?l0003o0000
olc<c02iooooo`00Z_ooool01Ol@413o^[Zjoooooonj^[[o410@0;Wooooo002Zooooo`05o`000?nj
^[[ooooookZj^_l00000^Oooool00:[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2iooooo`00oooo
oomYooooo`00/oooool00ol0003o^[Zjooooo`2booooo`00/oooool2oc8b<[?ooooo0024ooooo`;o
000000Ko410@oooooooooooo410@o`000?l@410Hooooo`05odA4A?l0003o0000oc8b<_oMgMd00_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000
o`000?m4A4Co^[Zj01Sooooo00GoV9RHoa0@4?l0003o<S8bolc<c005ooooo`;o000000?o410@oooo
ooooool0N_ooool008Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko
00003Oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03olc<c?l0
003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002Oooool01Ol@413o^[Zj
oooooomgMgOo<S8b00Kooooo00?o0000ooooooooool0Noooool008Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooooooooa0@40?ooooo00?o410@oooooooo
ool04?ooool00ol0003oooooooooo`0Nooooo`04o`000?ooooooooooooooo`Go0000O?ooool008Go
oooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00003Oooool01OmgMgOo<S8boooooooo
oooo000000?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`Ko00003?oo
ool00onYZJWo410@ooooo`02ooooo`04odA4A?oMgMgoooooo`0007gooooo0025ooooo`06o`000?oM
gMgo<S8boeEEEOoMgMgo00006Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooo
ooooooooooooo`00000Booooo`03o`000?oooooooooo01cooooo00?o410@o`000?nj^[X00oooool0
1?oMgMgoEEEEooooool0001mooooo`00QOooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001Wooooo
00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@013ooooo00?o410@o`000?l0
00000ol0000Looooo`03okZj^_lQ8B7ooooo00?ooooo00?oMgMgolc<c?l00000OOooool008Gooooo
00Ko0000oc8b<_oooooooooooc8b<_l0000Iooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Booooo`03o`000?oooooooooo01[ooooo00Go410@oiRHV?oooooo^[Zjo`00
0004ooooo`03onk^k_m4A4Co000007gooooo0024ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7
o`000?l@41006?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Booooo`03o`000?oo
oooooooo01[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@05ooooo`03ogMgMol0003ooooo07cooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(36) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .33996 m
.00488 .26606 L
.00942 .2142 L
.01204 .19233 L
.01441 .17663 L
.01716 .1626 L
.01975 .15267 L
.02227 .14568 L
.02354 .14302 L
.02494 .14068 L
.02613 .13914 L
.02741 .13788 L
.02862 .13703 L
.02973 .13649 L
.03111 .13611 L
.03239 .13599 L
.03312 .13602 L
.03379 .1361 L
.03456 .13625 L
.03529 .13646 L
.03661 .13699 L
.03782 .13766 L
.03916 .1386 L
.04057 .13985 L
.04332 .14309 L
.04583 .14699 L
.05147 .15887 L
.0567 .17337 L
.06166 .19035 L
.07288 .23508 L
.07561 .24442 L
.07855 .25251 L
.08024 .25599 L
.08097 .25722 L
.08178 .25835 L
.08249 .25916 L
.08325 .25981 L
.08406 .26026 L
.08481 .26046 L
.08549 .26044 L
.08622 .26023 L
.08751 .25935 L
.08823 .25857 L
.08891 .25767 L
.09044 .255 L
.09301 .2488 L
.09576 .24013 L
.10571 .2018 L
.11057 .18414 L
.11575 .1681 L
Mistroke
.12063 .15609 L
.12505 .14784 L
.13054 .14035 L
.13569 .13528 L
.1386 .13314 L
.14127 .13162 L
.1442 .13039 L
.14567 .12992 L
.14729 .12949 L
.14871 .12919 L
.15005 .12896 L
.15125 .12879 L
.15256 .12866 L
.15324 .12861 L
.15399 .12857 L
.15477 .12855 L
.1555 .12855 L
.15681 .1286 L
.15754 .12866 L
.15821 .12873 L
.15944 .12892 L
.16058 .12916 L
.16184 .1295 L
.16318 .12994 L
.16591 .13113 L
.1684 .13253 L
.1735 .13653 L
.17608 .13926 L
.1789 .143 L
.18391 .15195 L
.18858 .16344 L
.19409 .18142 L
.19912 .2023 L
.2046 .22889 L
.21043 .25726 L
.21281 .26724 L
.21537 .27605 L
.21684 .27997 L
.21818 .28274 L
.21947 .28459 L
.22082 .28566 L
.22197 .28585 L
.2232 .28532 L
.22436 .28413 L
.22542 .28249 L
.22666 .2799 L
.228 .27636 L
.23045 .26821 L
.24082 .22198 L
.24632 .19891 L
Mistroke
.25223 .17917 L
.25512 .17159 L
.25786 .16558 L
.26052 .16073 L
.263 .157 L
.26782 .15138 L
.27308 .14697 L
.27597 .14512 L
.27869 .14368 L
.28377 .14159 L
.28921 .13982 L
.29208 .13901 L
.29517 .13826 L
.29659 .13798 L
.29794 .13776 L
.29916 .1376 L
.30047 .13747 L
.30172 .13738 L
.30305 .13734 L
.30418 .13735 L
.30543 .1374 L
.30611 .13745 L
.30683 .13752 L
.30812 .13769 L
.3095 .13795 L
.31102 .13834 L
.31233 .13878 L
.31374 .13938 L
.31626 .14085 L
.31877 .14289 L
.32149 .14589 L
.32406 .14959 L
.32643 .15387 L
.33092 .16474 L
.33318 .17184 L
.33566 .18108 L
.34115 .20719 L
.34635 .23851 L
.35107 .26943 L
.3561 .29871 L
.35757 .30544 L
.35896 .31065 L
.36021 .31431 L
.36155 .31705 L
.36283 .31845 L
.36418 .31859 L
.36534 .31763 L
.3666 .31545 L
.36737 .31358 L
.3681 .31144 L
Mistroke
.36946 .30656 L
.37252 .29206 L
.37804 .25901 L
.38329 .22737 L
.38822 .20253 L
.39335 .18323 L
.39607 .17573 L
.39901 .16956 L
.40148 .16569 L
.40279 .16407 L
.40419 .16261 L
.40553 .16146 L
.40674 .16058 L
.40798 .15985 L
.40911 .1593 L
.4102 .15888 L
.4114 .15851 L
.4126 .15824 L
.41388 .15806 L
.415 .15797 L
.4162 .15795 L
.41733 .15798 L
.41836 .15804 L
.4196 .15816 L
.42076 .1583 L
.42341 .15863 L
.42466 .15878 L
.42599 .1589 L
.42668 .15895 L
.42744 .15899 L
.42877 .15903 L
.43003 .15902 L
.43118 .15897 L
.4325 .15888 L
.43375 .15875 L
.43598 .15843 L
.43839 .15797 L
.44102 .1573 L
.4439 .15634 L
.44973 .15374 L
.45473 .15137 L
.4561 .15081 L
.45756 .1503 L
.45883 .14992 L
.46019 .14961 L
.46096 .14947 L
.46167 .14938 L
.46234 .14931 L
.46306 .14928 L
.4643 .1493 L
Mistroke
.46566 .14945 L
.46696 .14975 L
.46768 .14999 L
.46835 .15027 L
.46963 .15095 L
.47085 .15181 L
.47203 .15287 L
.47328 .15427 L
.47552 .15757 L
.47794 .16245 L
.4806 .16967 L
.48344 .17978 L
.48605 .19148 L
.49192 .22744 L
.49705 .26906 L
.50253 .31621 L
.50532 .33627 L
.50668 .34414 L
.50794 .34993 L
.50908 .35386 L
.5103 .35651 L
.51151 .35754 L
.51285 .35678 L
.5141 .35428 L
.51524 .35056 L
.51655 .34466 L
.5178 .33765 L
.52243 .30278 L
.52787 .25541 L
.53297 .2163 L
.5383 .18645 L
.54113 .17513 L
.54418 .166 L
.54671 .16059 L
.54814 .15829 L
.54948 .15662 L
.5502 .15589 L
.55089 .15531 L
.55218 .15449 L
.55356 .15397 L
.55434 .15383 L
.55506 .15379 L
.55625 .15391 L
.55737 .1542 L
.55859 .15471 L
.55991 .15544 L
.56259 .15743 L
.56505 .15975 L
.57441 .17118 L
.57954 .17743 L
Mistroke
.58206 .17992 L
.58438 .18173 L
.58565 .1825 L
.58699 .18316 L
.58833 .18363 L
.58909 .18382 L
.5898 .18395 L
.59105 .18405 L
.59218 .18401 L
.59348 .1838 L
.59472 .18345 L
.59588 .18297 L
.59711 .18232 L
.59932 .18077 L
.6017 .1786 L
.60432 .17572 L
.60985 .16889 L
.61287 .16531 L
.61567 .16237 L
.61828 .16012 L
.61941 .15933 L
.62064 .15861 L
.622 .15804 L
.62327 .15773 L
.62398 .15767 L
.62473 .15771 L
.62608 .15805 L
.62734 .15874 L
.62849 .15972 L
.62982 .1613 L
.63108 .1633 L
.63332 .16817 L
.63576 .17563 L
.63843 .18671 L
.64128 .2023 L
.6464 .24154 L
.65196 .29924 L
.65499 .33324 L
.65782 .36209 L
.66023 .38155 L
.66159 .38945 L
.66282 .39443 L
.66417 .39727 L
.66493 .39762 L
.66564 .39712 L
.66693 .3942 L
.6683 .38836 L
.66958 .38055 L
.67096 .3699 L
.67346 .34599 L
Mistroke
.67913 .28164 L
.682 .25055 L
.68513 .221 L
.68812 .19788 L
.69083 .18116 L
.69361 .16783 L
.69503 .16233 L
.69657 .15729 L
.698 .15339 L
.69931 .15043 L
.70065 .14797 L
.7019 .14615 L
.70303 .14487 L
.70424 .14384 L
.70559 .1431 L
.70682 .14277 L
.7081 .14273 L
.70882 .14284 L
.70949 .14302 L
.71072 .14355 L
.71203 .14437 L
.71322 .14533 L
.71452 .14662 L
.71715 .1499 L
.72185 .15783 L
.73245 .18212 L
.73725 .19361 L
.73989 .19927 L
.74239 .20388 L
.74471 .20733 L
.74594 .20878 L
.74723 .21 L
.74832 .21078 L
.74953 .21135 L
.75062 .21162 L
.75164 .21165 L
.75295 .21136 L
.75368 .21105 L
.75435 .21067 L
.75564 .20969 L
.75686 .20847 L
.7596 .2048 L
.76255 .1996 L
.7676 .18905 L
.77292 .17777 L
.77776 .16926 L
.77908 .16742 L
.7805 .16574 L
.78184 .1645 L
.78306 .16368 L
Mistroke
.78425 .16322 L
.78535 .16312 L
.78656 .16342 L
.78785 .16423 L
.78896 .16539 L
.79 .1669 L
.79115 .16905 L
.79238 .17197 L
.81303 .35331 L
.81594 .39003 L
.81737 .40535 L
.81869 .41711 L
.81941 .42243 L
.82021 .42726 L
.82101 .43096 L
.82185 .43355 L
.82257 .43464 L
.82334 .43467 L
.82407 .43361 L
.82473 .43173 L
.82611 .42507 L
.8274 .41581 L
.82881 .40264 L
.83031 .38578 L
.8356 .3141 L
.84102 .24472 L
.84387 .21586 L
.84687 .1916 L
.8495 .17493 L
.85239 .16088 L
.85502 .15139 L
.85746 .145 L
.85869 .14258 L
.86003 .14048 L
.8613 .13897 L
.86246 .13792 L
.86352 .13724 L
.86467 .13673 L
.86588 .13645 L
.86702 .13639 L
.86833 .13655 L
.86959 .13692 L
.87071 .13742 L
.87194 .13817 L
.87327 .13921 L
.87469 .1406 L
.87724 .14388 L
.87997 .14849 L
.88286 .15448 L
.88804 .16747 L
Mistroke
.89972 .20467 L
.90459 .22016 L
.90727 .22709 L
.90981 .23212 L
.91125 .23422 L
.91201 .2351 L
.91281 .23587 L
.91348 .23637 L
.91423 .23678 L
.91554 .23711 L
.91687 .23695 L
.91762 .23664 L
.9183 .23621 L
.91957 .23508 L
.9209 .23341 L
.93084 .20846 L
.94024 .18123 L
.94276 .17552 L
.94543 .17051 L
.94683 .16842 L
.94757 .16749 L
.94836 .16663 L
.94909 .16599 L
.94976 .16555 L
.95106 .16507 L
.95232 .16517 L
.95348 .16579 L
.95475 .16712 L
.95611 .16931 L
.95741 .1722 L
.95863 .17568 L
.9609 .18428 L
1 .33996 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo0014ooooo`So0000JOooool2o`000;7ooooo0012ooooo`;o0000
1oooool2o`0006Sooooo00?o0000ooooooooool0/?ooool001oooooo0ol0000Nooooo`;o00002ooo
ool00ol0003oooooooooo`0Vooooo`;o0000?Oooool00ol0003oooooooooo`1aooooo`?o0000??oo
ool001kooooo00Co0000oooooooooooooooo0_l0000Kooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool08?ooool5o`000003ooooool0003o000000;o0000>_ooool00ol0003ooooooooo
o`1`ooooo`03o`000?oooooooooo00;o0000>oooool001gooooo0_l00004ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Looooo`?o00002Oooool2
o`0003Wooooo00?o0000ooooooooool0?_ooool3o`0002kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0iooooo`007Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0mooooo`;o000000?oooooo`00
0?l00000;Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Sooooo000Mooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo01Wooooo0_l0000?ooooo`03o`000?oooooooooo02Sooooo0ol0000:ooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0=oooool001cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Kooooo0_l00003ooooo`;o0000
2?ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Oooooo000Looooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Sooooo`;o00001_oo
ool00ol0003oooooooooo`06ooooo`;o00003_ooool4o`0002_ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=_oo
ool001cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo01Oooooo3?l00009ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03?ooool2
o`0000?ooooo00?o0000ooooooooool03oooool3o`0001Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0=_ooool0
01_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
01Gooooo0_l0000Eooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo0_l00002ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0=_ooool001Gooooo0_l000002Ol@413ooooooooooooooooo0000
oc8b<_l0003o<S8bonk^kP07ooooo`03o`000?oooooooooo013ooooo00GoV9RHo`000?l0003o<S8b
olc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool00ol0003oooooooooo`0=ooooo`Go
000000Soooooo`000?ooooook^k^oc8b<_l0003o<S8bonk^kQ3ooooo00?o0000ooooooooool02Ooo
ool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_l0000Gooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Wooooo1?l000001?l@413oooooooooooo^k^h2o`000003oc8b<_o^k^kooooo00oooooo00?o0000
ooooooooool01oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`?o00004ooo
ool01Ol0003o410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o0000onk^kP0Booooo`;o
00002Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000F
ooooo`03o`000?oooooooooo00;ooooo00Go0000oiRHV?ooooooV9RHogMgM`07ooooo`03o`000?oo
oooooooo013ooooo00Go410@o`000?ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool00ol0003oooooooooo`0=ooooo`0=oiRHV?lQ8B7ok^k^oooooom4A4Coooooo`000?oo
ooooMgMgoiRHV?ooooooV9RHogMgM`0@ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9So000001Sooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`02ooooo`05ogMgMol0003ooooooiRHV?mgMgL04?ooool00ol0003oooooooooo`07
ooooo`05o`000?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo
00Co0000oooooooooooo00004oooool01Ol0003o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRH
V?oooooo0000ogMgM`0Aooooo`Co00002Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03_ooool000_ooooo1_l00002ooooo`Go00000oooool01Ol0003ooooooooooooo
oooo410@00Oooooo00?o0000ooooooooool02?ooool6o`0000?ooooo00Co0000oooooooooooo0000
0oooool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000ooooooooool01Oooool6o`0000?o
oooo00GoV9RHob4Q8Oo^k^koooooo`000002ooooo`05oa0@4?ooooooooooooooool@41004Oooool0
0ol0003oooooo`000005o`0000Gooooo00?o0000ooooooooool00_ooool01Ol@413oooooooooool0
003o410@01Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool2o`0000Cooooo00Go410@o`000?oooooooooo
oa0@400@ooooo`03o`000?oooooooooo00Oooooo00Co0000oiRHV?lQ8B7ok^k^1?ooool01Ol@413o
oooooooooooooooo410@00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooooa0@4002ooooo`03o`000?l@413o
oooo013ooooo00Co0000oooooooooooo00001_ooool5o`0000?ooooo00Go410@oooooooooooooooo
oa0@400>ooooo`004oooool01?m4A4CogMgMooooool00003ooooo`;o00000oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00oooooo00Go0000ooooooooooooZJVYoa0@4003ooooo`05
o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`0?ooooo`04oiRHV?lQ8B7ok^k^
o`0000;ooooo00Go0000ooooooooooooooooo`00000Aooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02o`0001Sooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooo`000004ooooo`05o`000?oooooo0000ooooool000004?ooool00ol0003ooooo
ooooo`08ooooo`04o`000?nHV9So8B4Qonk^kP?ooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03oooool01_l0003ooooooooooooooooo
ZJVYoa0@40?ooooo00Go0000ooooooooooooooooo`00000Aooooo`05o`000?ooooooooooooooool0
00001Oooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool0
01?ooooo00CogMgMoeEEEOoooooo00000oooool2o`0000?ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0?ooooo`05o`000?oooooo410@o`000?nj^[X00oooool01Ol0003ooooooooo
oooooooo000000cooooo00?o0000ooooooooool03oooool00omgMgOo0000ooooo`02ooooo`05o`00
0?ooooooooooooooool000004_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooool0003oooooo`00000Iooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00Co0000oooo
oooooooo00001?ooool01Ol0003oooooo`000?oooooo000000oooooo00?o0000ooooooooool02Ooo
ool01?l0003oooooogMgMomVIVH3ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00oooooo00Ko0000oooooooooooo410@o`000?nj^[X3
ooooo`05o`000?ooooooooooooooool000004?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000ko
oooo000Dooooo`03ogMgMoo<c<co000000?ooooo00?o0000oa0@4?ooool00_ooool00ol@413ooooo
ooooo`06ooooo`03o`000?oooooooooo00oooooo00Go0000oooooooooooo^[Zjob4Q8@03ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0@ooooo`05o`000?oooooooooo
ooooool@41000oooool00ol@413oooooooooo`0@ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool00_ooool01Ol@413oooooo`000?oooooo410@01Wooooo00?o0000ooooooooool00_oo
ool2o`0000_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`;o00000ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo0000ooooool@41003oooool00ol0003ooooo
ooooo`09ooooo`04o`000?ooooooooooo`0000?ooooo00Go410@oooooooooooooooooa0@4002oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03oooool01_l0003ooooooooooooooooo
^[Zjob4Q8@?ooooo00Go410@ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@
41003_ooool001Cooooo00?ok^k^odA4A?l000000oooool01_l0003oMgMgoiRHV?ooooooV9RHogMg
M`Wooooo00?o0000ooooooooool03Oooool01_l0003o410@oiRHV?oooooo^[Zjo`0000?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00cooooo00Go0000okZj^_oooooo
V9RHo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00;ooooo00GoMgMgo`000?ooooooV9RHogMgM`0Iooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0<ooooo`Go00001?ooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9Soooooo`000?mgMgL03oooool00ol0003ooooooooo
o`08ooooo`05o`000?nj^[[o0000oiRHV?l@41000oooool01omgMgOoV9RHoooooonHV9SoMgMgoooo
ool000001_ooool00ol0003oooooooooo`0?ooooo`06o`000?l@413oV9RHoooooonj^[[o00000ooo
ool01_mgMgOoV9RHoooooonHV9SoMgMgo`0000kooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`03ooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>oooo
o`005Oooool00omgMgOo0000ooooo`02ooooo`06o`000?o^k^ko<S8bo`000?lb<S;ok^k^2Oooool0
0ol0003oooooooooo`0=ooooo`06o`000?nYZJWo410@o`000?l@413oZJVY0oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo00?o0000ooooooooool03?ooool01OnHV9So410@o`000?l0003oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Booooo`03o`000?oooooooooo00Oooooo00?oEEEE
ofIVI_l000001?ooool01Oo^k^ko0000o`000?lb<S;ok^k^01Wooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01?ooooo00?oEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?l0003ok^k^00oooooo00?o0000ooooooooool02?ooool01OnHV9So410@
o`000?lQ8B7oc<c<00?ooooo00Ook^k^oc8b<_l0003o<S8bonk^k_oooooo000000Kooooo00?o0000
ooooooooool03_ooool01ol0003oooooojVYZOl@413o0000oa0@4?nYZJT00oooool01_o^k^ko<S8b
o`000?lb<S;ok^k^o`0000gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04oooo
o`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`006_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Mooooo`006_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Looooo`006_ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Looooo`006_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Looooo`006_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0L
ooooo`005_ooooooo`00043o00004oooool001Kooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05
ooooo`;o00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooool000001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`03ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo0_l0
0007ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool04Oooool001Kooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00001oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000Oooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo0ol00005ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`05ooooo`;o0000
1_ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool00000
1oooool00ol0003oooooooooo`0Aooooo`006Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Mooooo`05o`000?oo
ooooooooooooool000002Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01_ooooo
000Iooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo01kooooo00Go0000ooooooooooooooooo`000009ooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool06_ooool001Wooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07ooo
ool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
6_ooool001Wooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool07oooool01?l0003oooooooooool00009ooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool06_ooool001Wooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07ooo
ool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
6_ooool001Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool07oooool01?l0003oooooooooool00009ooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool06_ooool001Sooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`02o`0000Sooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Cooooo`;o00000_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Wooooo000H
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo023ooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo01Cooooo0ol0000Aooooo`03o`000?oooooooooo01Wooooo000H
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool06Oooool001Sooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool08Oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`0Iooooo`006?ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooo000000Sooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo01Sooooo000Hooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo027ooooo00?o0000ooooool00000
2?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
6?ooool001Sooooo00?o0000ooooooooool05?ooool01Ol0003ooooooooooooooooo000002Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool08_ooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Hooooo`005oooool00ol0003ooooooooo
o`0Eooooo`04o`000?ooooooooooo`0002Kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08_ooool00ol0003ooooo
o`000008ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`0Hooooo`005oooool00ol0003oooooooooo`0Eooooo`;o000000?oooooo`000?ooool09Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Rooooo`04o`000?oooooo0000o`0000Oooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Oooooo000Gooooo`03o`000?oo
oooooooo01Kooooo0_l0000Wooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02?ooooo0_l00008ooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Gooooo`005oooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo02?ooooo0_l00008ooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Gooooo`005oooool00ol0
003oooooooooo`0oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo02?ooooo0_l00008ooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Gooooo`005oooool00ol0003o
ooooooooo`0oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo02Cooooo0_l00007ooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Fooooo`005oooool00ol0003ooooo
ooooo`10ooooo`05o`000?ooooooooooooooool000009_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo02Cooooo0_l00007ooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`0Fooooo`005oooool00ol0003oooooooooo`10ooooo`05o`00
0?ooooooooooooooool000009_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Co
oooo0_l00007ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`0Fooooo`005oooool00ol0003oooooooooo`11ooooo`04o`000?ooooooooooo`0002Oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Tooooo`;o00001oooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool05_ooool001Oooooo
00?o0000ooooooooool0@Oooool3o`0002Sooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Uooooo`;o00001_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool05Oooool001Oooooo00?o0000ooooooooool0@_ooool2o`0002Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Gooooo000G
ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo01Gooooo000Gooooo`03o`000?oooooooooo06cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Gooooo000Gooooo`03
o`000?oooooooooo06gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo01Cooooo000Gooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Cooooo000Gooooo`03o`000?oo
oooooooo06gooooo00Go0000ooooooooooooooooo`00000Nooooo`Go00001_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0Dooooo`005_ooool00ol0003oooooooooo`1_ooooo`04o`000?ooooooooooo`0001kooooo
00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`;o00001Oooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool05?ooool001Kooooo00?o0000ooooooooool0
Koooool01?l0003oooooooooool0000Oooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol00004ooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Dooooo`00
5_ooool00ol0003oooooooooo`1_ooooo`04o`000?ooooooooooo`00023ooooo00?oV9RHob4Q8Oo^
k^h01_ooool2o`0000Gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo01?ooooo000Fooooo`03o`000?oooooooooo06oooooo00Co0000ooooool0003o
00008Oooool00omgMgOoIVIVooooo`05ooooo`;o00001Oooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool04oooool001Kooooo00?o0000ooooooooool0
L?ooool2o`0002?ooooo00?o0000ooooooooool01?ooool2o`0000Gooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01?ooooo000Fooooo`03o`000?oo
oooooooo097ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`;o00001?ooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04oooool001Kooooo00?o
0000ooooooooool0TOooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo0_l00004ooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Booooo`005_oo
ool00ol0003oooooooooo`2Looooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01;ooooo000Fooooo`03o`000?oooooo
oooo09cooooo00?o0000ooooool000000oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool04_ooool001Kooooo00?o0000ooooooooool0W?ooool3o`00
00?ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
01;ooooo000Fooooo`03o`000?oooooooooo09cooooo00?o0000ooooool000000oooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04Oooool001Kooooo
00?o0000ooooooooool0W?ooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Aooooo`00]Oooool00ol0003oooooo`00
0002ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0A_ooool00;Gooooo00?o0000
ooooool000000_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0:_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04Kooooo002eoooo
o`03o`000?oooooo000000;ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`16oooo
o`00]Oooool01_l0003oooooooooool0003oooooo`0002cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0A_ooool0
0;Gooooo00?o0000ooooooooool00_l0000]ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0:_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04Kooooo002eooooo`05
o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`16ooooo`00]Oooool2o`00033o
oooo00Go0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0A_ooool00;Gooooo00?o0000ooooooooool0;oooool01Ol0003ooooooooooooooooo0000
02gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`16ooooo`00]Oooool00ol0003o
ooooooooo`0_ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo04Kooooo002eooooo`03o`000?oooooooooo02oooooo00Go0000oooooooo
ooooooooo`00000]ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Aoooool00;Go
oooo00?o0000ooooooooool0<?ooool01?l0003oooooooooool0000]ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0Aoooool00;Gooooo00?o0000ooooooooool0<?ooool01?l0003o
ooooooooool0000]ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Aoooool00;Go
oooo00?o0000ooooooooool0<?ooool01?l0003oooooooooool0000]ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0Aoooool00;Gooooo00?o0000ooooooooool0<?ooool01?l0003o
ooooooooool0000]ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Aoooool00;Go
oooo0_l0000aooooo`03o`000?oooooo000002kooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`17ooooo`00]Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo000002kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`17ooooo`00]Oooool00ol0003ooooooooo
o`0aooooo`;o0000;_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04Oooooo002e
ooooo`03o`000?oooooooooo037ooooo0_l0000^ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0Aoooool00;Gooooo00?o0000ooooooooool0H_ooool01Ol0003ooooooooooooooooo
000004Wooooo002/ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`1Roooo
o`05o`000?ooooooooooooooool00000BOooool00:gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Rooooo`05o`000?ooooooooooooooool00000BOooool00:[ooooo1Ol00006oooo
o`03o`000?oooooooooo06;ooooo00Go0000ooooooooooooooooo`000019ooooo`00Z_ooool01?m4
A4CogMgMooooool00007ooooo`?o0000H_ooool01?l0003oooooooooool0001:ooooo`00Z_ooool0
1?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo06;ooooo00Co0000oooooooooooo0000
B_ooool00:_ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`1Rooooo`04o`000?oo
ooooooooo`0004[ooooo002[ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0Hooo
ool00ol0003oooooo`00001:ooooo`00[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooo
oooo06?ooooo00?o0000ooooool00000B_ooool00;Gooooo00?o0000ooooooooool0Hoooool00ol0
003oooooo`00001:ooooo`00]Oooool00ol0003oooooooooo`1Sooooo`;o0000Boooool00;Gooooo
00?o0000ooooooooool0Hoooool2o`0004_ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Zoooo
o`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OmE
EEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?nHV9Sooooo
oiRHV?lQ8B401_ooool3o`000;3ooooo002Zooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool0
0ol0003oooooooooo`2`ooooo`00Z_ooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo
0;3ooooo002Zooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0/?ooool00:_ooooo
00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Ko
oooo00?o0000ooooooooool0/?ooool00:[ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03
o`000?oooooooooo0;3ooooo002Zooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`2`ooooo`00Z_ooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0002`ooooo`00
Z_ooool01Oo<c<co0000o`000?l0003oc<c<0;Wooooo002Zooooo`05oa0@4?nj^[[ooooookZj^_l@
4100^Oooool00:[ooooo00Go0000okZj^_oooooo^[Zjo`00002iooooo`00Z_ooool01OnYZJWo410@
o`000?l@413oZJVY0;Wooooo003oooooofWooooo002cooooo`03o`000?nj^[[ooooo0;;ooooo002c
ooooo`;o<S8b/oooool008Cooooo0_l000001_l@413oooooooooool@413o0000oa0@41Sooooo00Go
A4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOo
0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool01OnHV9So410@o`000?lb<S;o
c<c<00?ooooo00Gok^k^oc8b<_l0003o410@olc<c01looooo`00QOooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Oooooo1_l0000=ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@
00Wooooo1_l00009ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmEEEGoMgMgoooooonH
V9So8B4Q07cooooo0025ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06oooool0
1?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo013ooooo00?o0000ooooooooool07_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0N_ooool008Gooooo00Ko
0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00003Oooool01OmgMgOo<S8boooooooooooo0000
00?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`Ko00003?ooool00onY
ZJWo410@ooooo`02ooooo`05o`000?nHV9SooooooiRHV?lQ8B40O?ooool008Gooooo00Ko0000omgM
gOlb<S;oEEEEomgMgOl0000Iooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooo
oooooooooooo000001;ooooo00?o0000ooooooooool07?ooool00ol@413o0000okZj^P03ooooo`05
o`000?mEEEGo0000oa0@4?o<c<`0O?ooool008Gooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000I
ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400@ooooo`03oa0@4?l0
003o000000?o00007?ooool00onj^[[o8B4Qooooo`02ooooo`03oeEEEOn7QhOooooo07kooooo0025
ooooo`06o`000?lb<S;ooooooooooolb<S;o00006Oooool00ol0003oooooooooo`04ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL04_ooool00ol0003oooooooooo`0Jooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool00ooMgMgo410@oiRHV01nooooo`00Q?ooool00ol@413o0000ohN7Q`02ooooo`03
ohN7Qol0003o410@01Sooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0
003oooooooooo`0Jooooo`05ojVYZOl@413o0000oa0@4?nYZJT01?ooool01?o<c<coA4A4o`000?l@
411looooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(38) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .44169 m
.00123 .44954 L
.00236 .4541 L
.00365 .45617 L
.00488 .45492 L
.00601 .45104 L
.00706 .44525 L
.00821 .43666 L
.00942 .42528 L
.01475 .35823 L
.01975 .29279 L
.02219 .26624 L
.02452 .24556 L
.0272 .22717 L
.02966 .21498 L
.03096 .21009 L
.03236 .20601 L
.03368 .20315 L
.03487 .20134 L
.03561 .20058 L
.03628 .20011 L
.03702 .19984 L
.0378 .19983 L
.03912 .2004 L
.03987 .20103 L
.04057 .20182 L
.04199 .20397 L
.04331 .20654 L
.0463 .21402 L
.05174 .23093 L
.05699 .24727 L
.05956 .25398 L
.06192 .25879 L
.06316 .26067 L
.06446 .2621 L
.06576 .26291 L
.06651 .26308 L
.06719 .26305 L
.06795 .2628 L
.06867 .26235 L
.07001 .26097 L
.07076 .2599 L
.07145 .25872 L
.07302 .25544 L
.07575 .24791 L
.07875 .23763 L
.08481 .21374 L
.08982 .1939 L
.09528 .17463 L
.1001 .1609 L
Mistroke
.10523 .14986 L
.10835 .14464 L
.11118 .1407 L
.11383 .13761 L
.11669 .13491 L
.1195 .13288 L
.12209 .1315 L
.12456 .13055 L
.1258 .13018 L
.12717 .12985 L
.12845 .1296 L
.12981 .12939 L
.13052 .1293 L
.13131 .12923 L
.13269 .12914 L
.13398 .12912 L
.13471 .12913 L
.13538 .12916 L
.13661 .12927 L
.13791 .12944 L
.13908 .12966 L
.14033 .12996 L
.14258 .13065 L
.14769 .13284 L
.15054 .13438 L
.15362 .13636 L
.15921 .14111 L
.16465 .14759 L
.16967 .15537 L
.17459 .16513 L
.17987 .17871 L
.18941 .21197 L
.19486 .23441 L
.20067 .25744 L
.20305 .26545 L
.20562 .27241 L
.20709 .27542 L
.20844 .27749 L
.20973 .2788 L
.21109 .27944 L
.21237 .27936 L
.21373 .27854 L
.21502 .27709 L
.21619 .27522 L
.21756 .27241 L
.21905 .26865 L
.22176 .26023 L
.23337 .21314 L
.24342 .17744 L
.24914 .16271 L
Mistroke
.25449 .15216 L
.25974 .14446 L
.26453 .13927 L
.26718 .13698 L
.27007 .13488 L
.27278 .13325 L
.27533 .13203 L
.27673 .13149 L
.27824 .13101 L
.2795 .13068 L
.28088 .13041 L
.28165 .13029 L
.28238 .1302 L
.28314 .13013 L
.28396 .13008 L
.28472 .13006 L
.28544 .13005 L
.28679 .1301 L
.28807 .1302 L
.28944 .13039 L
.2906 .1306 L
.29188 .13091 L
.29326 .13132 L
.29474 .13187 L
.29742 .13318 L
.29994 .13481 L
.30263 .13699 L
.30748 .14214 L
.31324 .15071 L
.31848 .16149 L
.32395 .17646 L
.32988 .19719 L
.34064 .24466 L
.34543 .26615 L
.34808 .27651 L
.35059 .28474 L
.352 .28853 L
.35354 .29188 L
.35422 .29308 L
.35494 .29417 L
.35624 .29562 L
.35693 .29612 L
.35767 .29645 L
.35901 .2965 L
.36032 .29588 L
.36152 .29474 L
.36281 .29295 L
.36418 .29042 L
.36666 .28446 L
.37228 .26614 L
Mistroke
.38362 .2248 L
.39434 .19325 L
.40598 .16847 L
.41698 .15083 L
.42187 .14461 L
.42713 .1389 L
.43243 .13422 L
.43727 .13105 L
.4396 .12994 L
.44083 .12946 L
.44215 .12904 L
.44341 .12871 L
.44455 .12847 L
.4457 .12831 L
.44678 .12821 L
.44804 .12819 L
.44941 .12827 L
.45011 .12836 L
.45085 .12849 L
.4522 .12882 L
.45353 .1293 L
.4548 .12988 L
.45718 .13136 L
.45998 .13381 L
.46257 .13682 L
.46541 .14106 L
.46843 .14681 L
.47356 .16022 L
.47827 .17747 L
.48343 .20252 L
.48887 .23527 L
.49404 .26969 L
.49892 .29982 L
.50105 .31051 L
.50331 .31935 L
.50448 .32279 L
.50578 .32557 L
.50696 .32715 L
.50806 .3278 L
.50935 .32757 L
.51058 .32638 L
.51168 .32457 L
.51289 .32184 L
.51558 .31334 L
.51807 .30327 L
.52369 .27753 L
.52878 .25583 L
.53359 .23969 L
.53812 .22867 L
.54289 .22034 L
Mistroke
.54806 .21326 L
.56862 .17988 L
.5795 .158 L
.58549 .14739 L
.59116 .13894 L
.59654 .13274 L
.59958 .13006 L
.60239 .12808 L
.60476 .12677 L
.60611 .12617 L
.60736 .12573 L
.60867 .12538 L
.60936 .12524 L
.61008 .12513 L
.6113 .12505 L
.61263 .1251 L
.61398 .12531 L
.61526 .12566 L
.61641 .12611 L
.61765 .12674 L
.61901 .12762 L
.62044 .12876 L
.62301 .13144 L
.62539 .13474 L
.62761 .13869 L
.63004 .14418 L
.63266 .15168 L
.63534 .1614 L
.63819 .17432 L
.64332 .2052 L
.64883 .24993 L
.65492 .30789 L
.65747 .33085 L
.66016 .35128 L
.66157 .3597 L
.66231 .3634 L
.66311 .36672 L
.66384 .36919 L
.66451 .37091 L
.66581 .37282 L
.66712 .37279 L
.66833 .37105 L
.66966 .36734 L
.67033 .36481 L
.67107 .36154 L
.67364 .34689 L
.67604 .32982 L
.68125 .28961 L
.68401 .2702 L
.68694 .25267 L
Mistroke
.68976 .23941 L
.69232 .23044 L
.69355 .2271 L
.69489 .22415 L
.69615 .22197 L
.69731 .22043 L
.69843 .21934 L
.69964 .21855 L
.70078 .21814 L
.70182 .218 L
.70303 .21809 L
.70436 .21842 L
.70561 .2189 L
.70677 .21944 L
.70927 .22072 L
.71161 .22178 L
.71279 .22217 L
.71406 .22245 L
.71475 .22252 L
.71547 .22254 L
.71676 .22239 L
.71806 .22201 L
.71879 .22167 L
.71946 .22129 L
.7207 .22038 L
.72201 .21914 L
.72429 .21628 L
.72679 .21215 L
.73232 .19996 L
.73749 .18643 L
.74672 .16263 L
.7516 .15179 L
.75678 .14237 L
.76245 .13475 L
.76771 .12974 L
.77052 .12779 L
.7719 .12704 L
.77316 .12648 L
.77431 .12607 L
.77553 .12577 L
.77675 .12558 L
.77809 .12553 L
.7794 .12562 L
.78064 .12584 L
.78175 .12614 L
.78296 .1266 L
.78427 .12723 L
.78566 .12809 L
.78816 .13016 L
.79047 .13283 L
Mistroke
.79263 .13619 L
.795 .14107 L
.79755 .148 L
.80021 .1574 L
.80305 .17032 L
.80815 .20285 L
.81128 .2299 L
.81422 .26068 L
.81973 .32787 L
.82465 .38425 L
.82585 .39496 L
.82713 .40447 L
.82787 .40888 L
.82854 .4122 L
.82985 .41662 L
.83058 .41785 L
.83126 .4182 L
.832 .41771 L
.83278 .41621 L
.8341 .41149 L
.83485 .40763 L
.83556 .40329 L
.83809 .38288 L
.84081 .35483 L
.84567 .30092 L
.85085 .25299 L
.85383 .23335 L
.85654 .22051 L
.85785 .21588 L
.85926 .21192 L
.8606 .20911 L
.86184 .20728 L
.86311 .2061 L
.86448 .20557 L
.86578 .20574 L
.86696 .2064 L
.86834 .20773 L
.86985 .20978 L
.87259 .21473 L
.87846 .2275 L
.88134 .23319 L
.8826 .23533 L
.88399 .23735 L
.88521 .23881 L
.88652 .24001 L
.88791 .24084 L
.8892 .24116 L
.88992 .24115 L
.89071 .24097 L
.89146 .24064 L
Mistroke
.89215 .2402 L
.89345 .23899 L
.89483 .23719 L
.89725 .2328 L
.89951 .22739 L
.90466 .21172 L
.9154 .17633 L
.92125 .16003 L
.92669 .148 L
.93159 .14017 L
.93434 .13687 L
.93683 .13439 L
.93956 .13211 L
.941 .13109 L
.94253 .13015 L
.94386 .12946 L
.94533 .12885 L
.94666 .12845 L
.94791 .12822 L
.94911 .12812 L
.95042 .12816 L
.95166 .12832 L
.95281 .12859 L
.95394 .12894 L
.95497 .12935 L
.95728 .13053 L
.95977 .13229 L
.96247 .13496 L
.96501 .13854 L
.96734 .14306 L
.96938 .14822 L
.97124 .15405 L
.97324 .16171 L
.97541 .17183 L
.97927 .1955 L
.98293 .22627 L
.98724 .27517 L
.9918 .3396 L
1 .44169 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo01kooooo1_l0000_ooooo`Go0000F?ooool003gooooo2?l0000Yooooo`Ko
0000;?ooool7o`0000kooooo0_l0000Nooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`03ooooo`;o0000;oooool6o`00027ooooo000looooo`;o0000
1oooool00ol0003oooooooooo`0Uooooo`;o00001?ooool2o`0002[ooooo00?o0000ooooooooool0
1Oooool2o`0000cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool07_ooool003_ooooo00?o0000ooooooooool02?oo
ool2o`0002?ooooo0_l00008ooooo`;o0000:?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Zooooo`;o00001ooo
ool00ol0003oooooooooo`0Mooooo`00>_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Looooo`00>Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Kooooo`00>?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Kooooo`00=oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Kooooo`00=oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Kooooo`00=oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01_ooool2o`0001Sooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01[ooooo000foooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo01[ooooo000fooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Wooooo000Eooooo`;o0000
00Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h05_ooool02Ol0003ooooooooooooo
ooooV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0
003oooooooooo`0Booooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?o0000
ooooooooool03Oooool4o`00000:oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^koooooo`00
01?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
00Oooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^6_ooool5o`000008oooo
ool0003oooooonk^k_lb<S;o0000oc8b<_o^k^h:ooooo`03o`000?oooooooooo00kooooo00GoV9RH
oa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h03_ooool001Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg01Gooooo00?o0000ooooooooool00_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo01;ooooo00GoV9RHob4Q8Oo^k^ko
0000odA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00;ooooo00KoMgMgoiRHV?ooooooV9RHogMgMol0000Eooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?l0003oV9RHogMgM`0Jooooo`0=oiRHV?lQ8B7ok^k^oooooom4
A4Coooooo`000?ooooooMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo00gooooo
00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0
003oooooooooo`0?ooooo`05o`000?ooooooooooooooool000001?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00kooooo000;ooooo`Ko00000_ooool5o`0000?ooooo00Go410@oooooooooooooooooa0@
400Booooo`Ko00001_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0
1Oooool00ol0003oooooooooo`09ooooo`Ko00000oooool00onHV9So0000onk^kP04ooooo`05oa0@
4?ooooooooooooooool@41003Oooool00ol0003oooooooooo`03ooooo`Ko00001Oooool00ol0003o
ooooooooo`02ooooo`06oa0@4?ooooooooooooooool@413o00005Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooo`000?l@41006oooool01OnHV9So8B4Qonk^k_oooooo000000;ooooo
00Go410@oooooooooooooooooa0@400;ooooo`03o`000?oooooooooo017ooooo00Go0000oooooooo
oooooooooa0@4003ooooo`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool03oooool6o`00
00?ooooo00Go410@oooooooooooooooooa0@400>ooooo`004oooool01?m4A4CogMgMooooool00004
ooooo`05o`000?ooooooooooooooool000005?ooool00ol0003oooooooooo`06ooooo`03ojVYZOl@
413ooooo00;ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo01?ooooo
00?o0000ob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000gooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000005_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;o00007?ooool01?nHV9So8B4Qonk^k_l00002
ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`0@ooooo`03ojVYZOl@
413ooooo00;ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00oooooo
00Go0000odA4A?oMgMgoooooo`000004ooooo`05o`000?ooooooooooooooool000003_ooool001?o
oooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000001Cooooo00?o0000
ooooooooool01Oooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000001ooo
ool00ol0003oooooooooo`0Booooo`04o`000?ooooooMgMgofIVIP?ooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000001Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02o`00
01gooooo00?oMgMgo`000?ooool00_ooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000
ooooooooool03oooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000001ooo
ool00ol0003oooooooooo`0@ooooo`05o`000?oMgMgoEEEEooooool000001?ooool01Ol0003ooooo
oooooooooooo000000kooooo000Dooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooo
oooooa0@400Cooooo`03o`000?oooooooooo00Oooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413o
oooooooooooooooo410@00Sooooo00?o0000ooooooooool04Oooool01?l0003oooooooooool00003
ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooo0000oa0@400Gooooo`03o`000?oooooooooo00Cooooo
0_l0000Dooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
ooooool0003o410@01kooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo
00[ooooo00?o0000ooooooooool03oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41001oooool00ol0003oooooooooo`0@ooooo`05o`000?ooooooMgMgolc<c?l000001?oo
ool01Ol@413ooooooooooooooooo410@00kooooo000Dooooo`03onk^k_m4A4Co000000Cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0Cooooo`03o`000?oooooooooo00Cooooo00Go410@oiRHV?oooooo
^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`0@oooo
o`;o000000?ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Soooooo`000?mgMgL05ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?l000006_ooool01Ol0003o^[Zj
oooooonHV9So000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo
00cooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01ooo
ool00ol0003oooooooooo`0@ooooo`05o`000?ooooook^k^odA4A?l000001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00kooooo000Eooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0Cooooo`03o`000?oooooooooo00Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`0@ooooo`05o`000?l@413o
0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00oooooo00?o0000ooooooooool0
2_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02_ooool00omEEEGo
IVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_l000006_ooool01OnHV9So410@o`000?l0003o
c<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03o`000?oooooooooo00cooooo00Go
ZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`0Booooo`04o`000?ooooooMgMgo`0000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>
ooooo`00<_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Hooooo`00<_ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Hooooo`00
<_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0Hooooo`008Oooool2o`0000oooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool06?oo
ool0023ooooo1?l0000>ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Sooooo000Foooooooo0000@?l0000Coooo
o`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooo
oooo00001oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l00006
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`;o00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`09o`000?ooooooooooooooool0003o
ooooo`000?oooooo000000Oooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`0Aoooo
o`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooo
oooo00001oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00001oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00Co
0000oooooooooooo00000oooool2o`0000Oooooo00?o0000ooooool000001Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003ooooo
ooooo`0Aooooo`007oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Oooooo000O
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool03_ooool3o`0000Gooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Oooooo000Ooooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo01kooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool03Oooool2o`0000;ooooo1_l0000Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool05_ooool001kooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool07_ooool01Ol0
003ooooooooooooooooo000000gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00?ooooo0_l0000Mooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool05_ooool001kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool07_ooool01Ol0003ooooooooooooooooo
000000cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Fooooo`007_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0Nooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo01Kooooo000Nooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01oooooo00Co0000oooo
oooooooooooo0_l0000:ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05_ooool0
01kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool07oooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000006ooo
ool00ol0003oooooooooo`0Fooooo`007Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Oooooo`05o`000?oooooo
ooooooooool000002_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo0ol0
000Looooo`03o`000?oooooooooo01Kooooo000Mooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo023ooooo00Go0000
ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Kooooo000Mooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo023ooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0Fooooo`007Oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Q
ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo01Kooooo000Mooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02;ooooo00Co0000
oooooooooooo00002Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool05Oooool001gooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooo
oooo000002Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool08_ooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Eooooo`007Ooo
ool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0002Wooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`02o`0000Oooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo01Gooooo000Mooooo`03o`000?oooooooooo00[ooooo0ol0
000Yooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo02?ooooo00Co0000oooooooooooo00002?ooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool05Oooool001gooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooool000001oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool05Oooool001gooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo01Gooooo000Mooooo`03o`000?oooooooooo03Oooooo00Go0000oooo
ooooooooooooo`00000Xooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09Oooool0
0ol0003oooooo`000007ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`0Eooooo`007Oooool00ol0003oooooooooo`0hooooo`04o`000?oooooooooo
o`0002Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
000000Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo01Gooooo000Mooooo`03o`000?oooooooooo03Sooooo00?o0000ooooool00000:_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooool000001_ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool05Oooool001go
oooo00?o0000ooooooooool0>?ooool2o`0002_ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Wooooo`;o00001_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool05Oooool001cooooo00?o0000ooooooooool0I_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo02Oooooo0ol00005ooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Eooooo`007?ooool00ol0003ooooooooo
o`1Vooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09oooool2o`0000Kooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Gooooo000L
ooooo`03o`000?oooooooooo06Oooooo00Go0000ooooooooooooooooo`00000Yooooo`;o00001_oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool05Ooo
ool001cooooo00?o0000ooooooooool0Ioooool2o`000003ooooool0003ooooo02Wooooo0_l00005
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0E
ooooo`007?ooool00ol0003oooooooooo`1Xooooo`?o0000:oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Eoooo
o`007?ooool00ol0003oooooooooo`2Fooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Gooooo000Looooo`03o`00
0?oooooooooo08_ooooo1Ol00006ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Gooooo000Looooo`03o`000?oo
oooooooo08_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Gooooo
000Looooo`03o`000?oooooooooo08cooooo00?oV9RHob4Q8Oo^k^h01oooool3o`0000?ooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Cooooo000K
ooooo`03o`000?oooooooooo08kooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0D
ooooo`006oooool00ol0003oooooooooo`2?ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0:_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool05?ooool001_ooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`04ooooo`;o
00000oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02cooooo00?o0000oooooooo
ool05?ooool001_ooooo00?o0000ooooooooool0S?ooool01Ol0003o^[ZjoooooonHV9So410@00Ko
oooo0_l00002ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;?ooool00ol0003o
ooooooooo`0Dooooo`006oooool00ol0003oooooooooo`2<ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`01_ooool3o`000003ooooool0003ooooo02cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0[ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;?ooool00ol0003o
ooooooooo`0Dooooo`006oooool00ol0003oooooooooo`2Gooooo`04o`000?oooooo0000o`0002ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Dooooo`006oooool00ol0003ooooo
ooooo`2Gooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0[ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`0Dooooo`006oooool00ol0003oooooooooo`2Gooooo`;o0000<?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo01Cooooo000Kooooo`03o`000?oooooooooo09Oooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02_ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Cooooo000Koooo
o`03o`000?oooooooooo09Oooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo02cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo01Cooooo000Kooooo`03o`000?oooooooooo09Oooooo00?o0000oooooooo
ool0<?ooool01Ol0003ooooooooooooooooo000002kooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo01Cooooo000Jooooo`03o`000?oooooooooo09So
oooo00?o0000ooooooooool0<?ooool01Ol0003ooooooooooooooooo000002kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Cooooo000Jooooo`03
o`000?oooooooooo09Sooooo00?o0000ooooooooool0<?ooool01Ol0003ooooooooooooooooo0000
02kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
01Cooooo000Jooooo`03o`000?oooooooooo09Sooooo00?o0000ooooooooool0<?ooool01Ol0003o
oooooooooooooooo000002kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0]oooo
o`03o`000?oooooooooo01Cooooo000Jooooo`03o`000?oooooooooo09Sooooo00?o0000oooooooo
ool0<?ooool01?l0003oooooooooool0000_ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`0Dooooo`006_ooool00ol0003oooooooooo`2Hooooo`03
o`000?oooooooooo033ooooo00Co0000oooooooooooo0000<?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool04oooool001[ooooo00?o0000oooooooo
ool0V?ooool2o`0003;ooooo00?o0000ooooool00000<?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool04oooool001[ooooo00?o0000ooooooooool0
V?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooo0000033ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01?ooooo000Jooooo`03o`000?oo
oooooooo09Sooooo00?o0000ooooooooool0<Oooool00ol0003oooooo`00000`ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Cooooo`006_ooool0
0ol0003oooooooooo`2Hooooo`03o`000?oooooooooo037ooooo0_l0000aooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Cooooo`006_ooool00ol0
003oooooooooo`2Hooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo01?ooooo000Jooooo`03o`000?oooooooooo09So
oooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool04oooool001[ooooo00?o0000ooooooooool0V?ooool00ol0003ooooo
ooooo`1Tooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0Cooooo`006_ooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo06Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01?ooooo000J
ooooo`03o`000?oooooooooo09Sooooo0_l0001Uooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`0Cooooo`006_ooool00ol0003oooooooooo`2Hoooo
o`03o`000?oooooooooo06Gooooo00Go0000ooooooooooooooooo`00000`ooooo`03o`000?oooooo
oooo01?ooooo000Iooooo`03o`000?oooooooooo09Wooooo00?o0000ooooooooool0IOooool01Ol0
003ooooooooooooooooo0000037ooooo00?o0000ooooooooool04_ooool001Wooooo00?o0000oooo
ooooool0VOooool00ol0003oooooooooo`1Uooooo`04o`000?ooooooooooo`0003;ooooo00?o0000
ooooooooool04_ooool001Wooooo00?o0000ooooooooool0VOooool00ol0003oooooooooo`1Uoooo
o`04o`000?ooooooooooo`0003;ooooo00?o0000ooooooooool04_ooool001Wooooo00?o0000oooo
ooooool0T?ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0IOooool01?l0
003oooooooooool0000booooo`03o`000?oooooooooo01;ooooo000Iooooo`03o`000?oooooooooo
097ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Uooooo`04o`000?oooooooooo
o`0003;ooooo00?o0000ooooooooool04_ooool001Wooooo00?o0000ooooooooool0S_ooool5o`00
00Kooooo00?o0000ooooooooool0IOooool00ol0003oooooo`00000cooooo`03o`000?oooooooooo
01;ooooo000Iooooo`03o`000?oooooooooo08kooooo00CoA4A4omgMgOoooooo00001oooool3o`00
06Gooooo00?o0000ooooool00000<oooool00ol0003oooooooooo`0Booooo`006Oooool00ol0003o
ooooooooo`2>ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0I_ooool2o`00
03?ooooo00?o0000ooooooooool04_ooool001Wooooo00?o0000ooooooooool0Soooool00omgMgOo
c<c<o`000007ooooo`03o`000?oooooooooo06Kooooo0_l0000cooooo`03o`000?oooooooooo01;o
oooo000Iooooo`03o`000?oooooooooo08oooooo00?ok^k^odA4A?l000001oooool00ol0003ooooo
ooooo`2Kooooo`03o`000?oooooooooo01;ooooo000Iooooo`03o`000?oooooooooo093ooooo00?o
MgMgo`000?ooool01_ooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo01;ooooo000I
ooooo`03o`000?oooooooooo09Wooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0A
ooooo`006Oooool00ol0003oooooooooo`2Iooooo`03o`000?oooooooooo09cooooo00?o0000oooo
ooooool04Oooool001Sooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`2Looooo`03
o`000?oooooooooo017ooooo000Hooooo`03o`000?oooooooooo09[ooooo0_l0002Mooooo`03o`00
0?oooooooooo017ooooo000Fooooo`03o`000?oooooo000009cooooo00?o0000ooooooooool0W?oo
ool00ol0003oooooooooo`0Aooooo`005_ooool00ol0003oooooo`00002Looooo`03o`000?oooooo
oooo0;3ooooo000Fooooo`03o`000?oooooo000009cooooo00?o0000ooooooooool0/?ooool001Ko
oooo00?o0000ooooool00000W?ooool00ol0003oooooooooo`2`ooooo`005_ooool00ol0003ooooo
o`00002Looooo`03o`000?oooooooooo0;3ooooo000Gooooo`03o`000?oooooooooo09_ooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aoooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05onk^k_lb<S;o
0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OmEEEGoMgMgoooooonH
V9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?nHV9SooooooiRHV?lQ8B401_oo
ool3o`000;3ooooo002Zooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo0;3ooooo002Zoooo
o`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0/?ooool00:_ooooo00Coc<c<odA4A?l0
003o410@1_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aoooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00Z_ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000oooo
ooooool0/?ooool00:[ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo
0;3ooooo002Zooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`2`oooo
o`00Z_ooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0002`ooooo`00Z_ooool01Oo<c<co
0000o`000?l0003oc<c<0;Wooooo002Zooooo`05oa0@4?nj^[[ooooookZj^_l@4100^Oooool00:[o
oooo00Go0000okZj^_oooooo^[Zjo`00002iooooo`00Z_ooool01OnYZJWo410@o`000?l@413oZJVY
0;Wooooo003oooooofWooooo002cooooo`03o`000?nj^[[ooooo0;;ooooo002cooooo`;o<S8b/ooo
ool008Cooooo0_l000001_l@413oooooooooool@413o0000oa0@41Sooooo00GoA4A4o`000?l0003o
<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOo0000okZj^P0<oooo
o`05oiRHV?l0003o0000odA4A?nj^[X06?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Go
c<c<ob4Q8Ol0003o8B4Qolc<c01looooo`00QOooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Oooooo1_l0000=ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00009
ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OlQ8B7oV9RHoooooonHV9So8B4Q07cooooo
0025ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06oooool01?l0003ooooooooo
ool@4103ooooo`03oa0@4?oooooooooo013ooooo00?o0000ooooooooool07_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool0N_ooool008Gooooo00Ko0000oooooom4A4Co
A4A4ooooool00009ooooo`Ko00003Oooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`Ko00003?ooool00onYZJWo410@ooooo`02
ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80O?ooool008Gooooo00Ko0000omgMgOlb<S;oEEEEomgM
gOl0000Iooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo0000
01;ooooo00?o0000ooooooooool07?ooool00ol@413o0000okZj^P03ooooo`05olc<c?l0003o0000
o`000?o<c<`0O?ooool008Gooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Iooooo`03o`000?oo
oooooooo00Cooooo00Go410@oooooooooooooooooa0@400@ooooo`03oa0@4?l0003o000000?o0000
7?ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?nj^[[ooooookZj^_l@4100O?ooool008Gooooo
00Ko0000oc8b<_oooooooooooc8b<_l0000Iooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Booooo`03o`000?oooooooooo01[ooooo00Go410@oiRHV?oooooo^[Zjo`00
0003ooooo`05o`000?nj^[[ooooookZj^_l00000O?ooool008Cooooo00?o410@o`000?n7QhL00_oo
ool00on7QhOo0000oa0@400Hooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo
00?o0000ooooooooool06_ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@1looooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .28517 m
.00236 .29813 L
.00488 .31016 L
.00706 .31862 L
.00942 .32549 L
.01087 .32848 L
.0122 .33045 L
.01348 .33169 L
.01483 .33237 L
.01604 .33252 L
.01717 .33234 L
.01841 .33187 L
.01975 .33118 L
.02104 .33045 L
.02241 .32974 L
.0232 .32941 L
.02392 .3292 L
.02464 .32908 L
.02532 .32907 L
.02665 .32938 L
.02787 .3301 L
.02921 .33143 L
.02988 .33232 L
.03062 .33347 L
.0331 .33861 L
.03576 .34597 L
.04057 .36105 L
.042 .36506 L
.04352 .36859 L
.04482 .37081 L
.04556 .37168 L
.04626 .37221 L
.04702 .37244 L
.04781 .37227 L
.04849 .37178 L
.04924 .37087 L
.05004 .36942 L
.0509 .36735 L
.05245 .36224 L
.05391 .35588 L
.05548 .3474 L
.05835 .32848 L
.06371 .28603 L
.06855 .24733 L
.07376 .21174 L
.07674 .1951 L
.07947 .1823 L
.08224 .17151 L
.08481 .1633 L
.0875 .15635 L
Mistroke
.08993 .15131 L
.09264 .14688 L
.09551 .14327 L
.09803 .14088 L
.10075 .13896 L
.102 .13827 L
.10332 .13767 L
.10453 .13722 L
.10568 .13687 L
.10706 .13655 L
.10831 .13634 L
.10966 .13619 L
.11043 .13613 L
.11113 .1361 L
.11231 .13609 L
.1136 .13611 L
.11495 .13619 L
.11622 .13629 L
.11763 .13644 L
.11912 .13663 L
.12178 .13706 L
.12777 .13833 L
.13782 .14112 L
.14344 .14311 L
.14854 .14559 L
.15331 .14885 L
.156 .15126 L
.15848 .15396 L
.16303 .1605 L
.16784 .1703 L
.17853 .20574 L
.18867 .25328 L
.19308 .27198 L
.19531 .27925 L
.19658 .28249 L
.19777 .28487 L
.19906 .28665 L
.20025 .28753 L
.20155 .28763 L
.20292 .28676 L
.20409 .28522 L
.20519 .28315 L
.20639 .28021 L
.20768 .27634 L
.21319 .25324 L
.21839 .22652 L
.22814 .18117 L
.23361 .16284 L
.23867 .15069 L
.24131 .14595 L
Mistroke
.24421 .14184 L
.24725 .13864 L
.24862 .13751 L
.25009 .13651 L
.25151 .13572 L
.2528 .13515 L
.25409 .13471 L
.25531 .13441 L
.256 .13429 L
.25673 .13419 L
.25804 .1341 L
.25877 .1341 L
.25945 .13413 L
.2602 .13419 L
.261 .1343 L
.26233 .13455 L
.26379 .13492 L
.26642 .13587 L
.26899 .13709 L
.27137 .13843 L
.2808 .14539 L
.29082 .15429 L
.30091 .16288 L
.31152 .17109 L
.3159 .17489 L
.32058 .18003 L
.32327 .18385 L
.32571 .18808 L
.33048 .19901 L
.3355 .21513 L
.34094 .23836 L
.34564 .26199 L
.35081 .28763 L
.35348 .29857 L
.35495 .30341 L
.35635 .30703 L
.35711 .30855 L
.35793 .30985 L
.35868 .31067 L
.35938 .31112 L
.36075 .31113 L
.36152 .31061 L
.36221 .30982 L
.36357 .30741 L
.36481 .30422 L
.36618 .2997 L
.36762 .29389 L
.37271 .26699 L
.3827 .20679 L
.3882 .17981 L
Mistroke
.39339 .16042 L
.39823 .14734 L
.40096 .14176 L
.40348 .13761 L
.40578 .13455 L
.40794 .13224 L
.41018 .13035 L
.41266 .12882 L
.41397 .12823 L
.41468 .12796 L
.41536 .12775 L
.41668 .12745 L
.41787 .12728 L
.41856 .12723 L
.41929 .12722 L
.4206 .12729 L
.42133 .12738 L
.42201 .1275 L
.42275 .12767 L
.42355 .12788 L
.42489 .12834 L
.42633 .12896 L
.42897 .13042 L
.43154 .13226 L
.43391 .13433 L
.44334 .14591 L
.45336 .16316 L
.49298 .22149 L
.49567 .22702 L
.49854 .23454 L
.5037 .25295 L
.5091 .27827 L
.515 .308 L
.51761 .31909 L
.51898 .32384 L
.52043 .32781 L
.52171 .33026 L
.52243 .3312 L
.52311 .33175 L
.52429 .33197 L
.52557 .33107 L
.5268 .32911 L
.52815 .32575 L
.52942 .32146 L
.53059 .31657 L
.53518 .29087 L
.54524 .22152 L
.55053 .19049 L
.5561 .16541 L
.561 .14956 L
Mistroke
.56377 .14273 L
.56636 .13754 L
.57092 .13068 L
.57347 .12788 L
.57579 .12589 L
.57713 .12496 L
.57855 .12414 L
.57978 .12356 L
.58111 .12306 L
.58185 .12283 L
.58252 .12266 L
.58385 .12242 L
.58456 .12233 L
.58533 .12228 L
.58613 .12226 L
.58688 .12227 L
.58825 .12239 L
.58954 .1226 L
.5907 .12288 L
.59196 .12326 L
.59478 .12447 L
.59737 .12603 L
.6019 .12986 L
.60687 .13581 L
.61207 .14413 L
.61692 .15406 L
.65773 .25074 L
.66289 .25678 L
.6655 .26102 L
.66839 .26722 L
.67149 .27607 L
.67441 .28655 L
.67999 .31106 L
.68494 .33274 L
.68743 .34109 L
.68811 .34287 L
.68884 .3445 L
.69015 .34664 L
.69089 .34735 L
.69169 .34771 L
.69244 .34763 L
.69314 .3472 L
.69446 .34541 L
.69513 .34402 L
.69586 .34213 L
.69717 .33782 L
.69857 .33193 L
.70111 .31836 L
.71113 .2465 L
.71663 .2094 L
Mistroke
.72181 .18159 L
.72476 .16899 L
.72796 .15776 L
.73353 .14327 L
.73628 .13805 L
.73919 .13364 L
.74192 .13036 L
.7444 .12797 L
.74678 .12613 L
.74937 .12458 L
.75079 .12391 L
.7521 .12339 L
.75343 .12296 L
.75469 .12265 L
.75575 .12244 L
.7569 .12228 L
.75817 .12218 L
.75934 .12215 L
.76049 .12218 L
.76175 .12228 L
.76306 .12246 L
.76429 .12269 L
.76565 .12304 L
.76713 .12351 L
.76981 .12466 L
.77243 .12616 L
.77484 .12793 L
.78031 .13351 L
.78307 .13726 L
.78611 .14226 L
.79158 .15399 L
.79678 .16888 L
.80653 .20684 L
.81716 .25468 L
.82022 .26654 L
.8231 .27589 L
.82568 .28254 L
.82712 .28552 L
.82847 .28785 L
.83099 .29117 L
.83233 .29248 L
.83376 .29364 L
.83662 .29555 L
.83933 .29747 L
.84184 .29993 L
.84325 .30179 L
.84456 .30389 L
.84687 .30858 L
.84931 .31498 L
.85448 .33227 L
Mistroke
.85703 .34136 L
.8594 .34897 L
.86154 .35435 L
.86273 .35649 L
.86382 .35778 L
.86501 .3584 L
.8663 .35805 L
.86751 .3567 L
.86864 .35455 L
.86982 .35134 L
.87092 .34749 L
.87343 .33588 L
.87851 .3031 L
.88913 .22518 L
.89389 .19717 L
.8984 .17644 L
.90089 .16728 L
.90359 .15893 L
.90834 .14776 L
.91078 .14342 L
.91342 .13959 L
.91819 .13448 L
.92096 .13236 L
.92387 .13066 L
.92636 .12955 L
.92908 .12866 L
.93057 .12829 L
.93197 .12801 L
.93323 .12781 L
.9346 .12765 L
.93531 .12759 L
.93609 .12754 L
.93691 .12751 L
.93767 .1275 L
.93903 .12751 L
.9398 .12754 L
.9405 .12758 L
.94185 .1277 L
.94311 .12786 L
.94449 .12809 L
.94595 .12839 L
.94867 .12912 L
.95113 .13002 L
.95358 .13115 L
.95626 .13274 L
.95906 .13483 L
.96167 .13728 L
.96635 .14312 L
.96897 .14741 L
.97136 .15209 L
Mistroke
.97675 .16595 L
.9826 .18729 L
.98812 .21411 L
.99323 .24383 L
1 .28517 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo01Kooooo1_l0000`
ooooo`So0000G?ooool009[ooooo1?l0000Gooooo`03o`000?oooooooooo01Cooooo0_l00006oooo
o`03o`000?oooooooooo02cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0`oooo
o`Co00009Oooool009Sooooo0_l00003ooooo`;o00005_ooool2o`0001Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0;?ooool3o`0000?ooooo1?l0000Rooooo`00Ioooool3o`0002kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
:_ooool00ol0003oooooooooo`07ooooo`;o00008Oooool003Oooooo1ol0000Wooooo`?o000000Co
ooooo`000?l0003o0000:oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00[ooooo
0_l0000Oooooo`00=_ooool2o`0000Kooooo0ol0000Sooooo`;o00001_ooool2o`0002Sooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01gooooo000d
ooooo`;o00002oooool4o`0001kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0L
ooooo`00=?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0Looooo`00<oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Kooooo`00
<_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Jooooo`00<_ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03_ooool2o`00017ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01[ooooo000booooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo01Wooooo000booooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo01Wooooo000Eooooo`;o000000Wo410@oooooooo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^h04Oooool00ol0003oooooooooo`06ooooo`05oiRHV?l@
413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?o0000oooooooo
ool04oooool00ol0003oooooo`000004o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06oooo
o`;o00005?ooool4o`000004oa0@4?ooooooooooonk^kP;o000000?o<S8bonk^k_ooool03_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03Oooool5
o`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Jooooo`Go00000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Wooooo00?o0000ooooooooool03oooool01OnHV9So410@o`000?lb<S;oc<c<00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool00_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0>ooooo`005_oo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04Oooool00ol0003ooooo
ooooo`06ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Cooooo00?o0000ooooooooool04_ooool01ol0003ooooooiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo0_l0000Dooooo`03o`000?oooooooooo00;ooooo
00Go0000oiRHV?ooooooV9RHogMgM`0?ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo000000;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0Iooooo`06o`000?nHV9So8B4Qonk^k_ooooooA4A40oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Wooooo00?o0000ooooooooool03oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03o`000?oooooooooo01Gooooo00Co0000oooo
oooooooo00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo000000Go00001_oo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool00_ooool00ol0003ooooo
ooooo`0<ooooo`Ko00000oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@
41002_ooool00ol0003oooooooooo`06ooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool03oooool01_l0003oooooooooool0003ooooooa0@40?ooooo00?o
410@ooooooooool05oooool01Ol0003ooooooiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooo
oooooa0@4009ooooo`03o`000?oooooooooo01?ooooo00Go0000oooooooooooooooooa0@4003oooo
o`05oa0@4?ooooooooooooooool000005oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@
400>ooooo`004oooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool00000
4?ooool00ol0003oooooooooo`0:ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oooooooooooo
ooooo`000004ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00_ooool00onHV9So
8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Aooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0@ooooo`06o`000?oooooo
ooooo`000?oooooo00000oooool00ol0003oooooooooo`0Gooooo`06o`000?oooooooooooiRHV?lQ
8B7ok^k^0oooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool04_ooool0
0onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooooooo
o`0Fooooo`04odA4A?l0003oooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`00
4oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000004?ooool00ol0
003oooooooooo`09ooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`000005
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00oooool00omgMgOoIVIVooooo`02
ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003oooooooooo`0?ooooo`04o`000?oo
ooooooooooooo`;o00000oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0@ooooo`04o`000?ooooooooooooooo`;o
00000oooool00ol0003oooooooooo`0Gooooo`06o`000?oooooooooooooooomgMgOoIVIV0oooool0
1Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool04Oooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Fooooo`04omgM
gOl0003oooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`005?ooool00omgMgOo
c<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`0;oooo
o`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o
410@ooooooooool02oooool00ol0003oooooooooo`0>ooooo`06o`000?ooooooooooooooool0003o
410@0oooool00ol@413oooooooooo`0@ooooo`03o`000?oooooooooo00Wooooo0_l0000?ooooo`03
o`000?oooooooooo013ooooo00Ko0000ooooooooooooooooo`000?l@4103ooooo`03oa0@4?oooooo
oooo01Kooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o
410@ooooooooool02?ooool00ol0003oooooooooo`0Aooooo`03okZj^_lQ8B7ooooo00;ooooo00Go
410@oooooooooooooooooa0@4002ooooo`03o`000?oooooooooo01Oooooo00?o0000olc<c?l00000
1?ooool01Ol@413ooooooooooooooooo410@00kooooo000Dooooo`03onk^k_m4A4Co000000Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0?ooooo`03o`000?oooooooooo00Sooooo00Go410@oiRHV?oo
oooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0?
ooooo`09o`000?ooooooooooooooool0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00gooooo00[o0000ooooooooooooooooo`000?mg
MgOoV9RHoooooonHV9SoMgMg4oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`05o`000?nHV9SooooooiRH
V?mgMgL06?ooool01ol0003oooooo`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00[ooooo00?o0000ooooooooool03_ooool01Ol@413oV9RHoooooonj^[[o000000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`03o`000?oooooooooo01Oooooo00?ok^k^o`00
0?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000Eooooo`03ogMgMol0003ooooo
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0?ooooo`03o`000?oooooooooo00Sooooo00GoZJVY
oa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003ooooo
ooooo`0>ooooo`09o`000?oooooooooooooooonHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0>ooooo`03o`000?oooooooooo00_ooooo00?oEEEEofIVI_l000000ooo
ool01_l0003ok^k^oc8b<_l0003o<S8bonk^kQCooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00oooooo00?oEEEEofIVI_l000001?ooool01Ol0003o
<S8bo`000?lb<S;ok^k^01Sooooo00Oo0000oooooonHV9So410@o`000?lQ8B7oc<c<00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0:ooooo`03o`000?oooooooooo00kooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@03ooooo`07onk^k_lb<S;o0000oc8b<_o^k^koooooo`00000Kooooo`;o00001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000_ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Kooooo000^oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo01Kooooo000^ooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Kooooo000^ooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01Kooooo000^ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Gooooo000Foooooooo0000@?l0000C
ooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool2o`0000Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`04oooo
o`;o00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00006oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooo000000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Aooooo`005_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`00
00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1?ooool2o`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo0000
00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`0Aooooo`00;Oooool00ol0003oooooooooo`0Poooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo01kooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Eooooo`00;Oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo023ooooo00Co0000oooooooooooo00003Oooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05Oooool0
02gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo0000
00gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
01Gooooo000]ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool08Oooool00ol0003o
ooooo`00000=ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0Dooooo`00;Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo027ooooo
00?o0000ooooool000003Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool05?ooool002cooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooo000000gooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo01Cooooo000/ooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool08oooool3o`0000cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo01Cooooo000/ooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool08oooool2o`0000cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo01Cooooo000/ooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0Cooooo`00;?ooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool04oooool002cooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01?ooooo000/ooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool09Oooool2o`0000_ooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01?ooooo000/ooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool09Oooool2o`0000_ooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo01?ooooo000/ooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool09Oooool2o`0000_ooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo01;ooooo000[ooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool09Oooool2o`0000[ooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo01;ooooo000[ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool09Oooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`0Booooo`00:oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool04_ooool002_ooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo000000Wooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01;ooooo000[ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool09_ooool00ol0003oooooo`000009ooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Booooo`00
:oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Kooooo00Co0000oooooooooooo
00002?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool04_ooool002_ooooo00?o0000ooooooooool09_ooool01Ol0003ooooooooooooooooo000002co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Vooooo`04o`000?ooooooooooo`00
00Sooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
017ooooo000Zooooo`03o`000?oooooooooo02Oooooo00Co0000oooooooooooo0000;Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo02Kooooo00Co0000oooooooooooo00001oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool04Oooool0
02[ooooo00?o0000ooooooooool09oooool2o`000003ooooool0003ooooo02cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Wooooo`;o000000?oooooo`000?ooool01_ooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool04Oooool001Ko
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Xooooo`?o0000;Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo02Oooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Aoooo
o`005_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo05Sooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Wooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo03Oooooo000Fooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Oo
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool0=oooool001Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Iooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool09oooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
02Oooooo0_l0000;ooooo`03o`000?oooooooooo03Sooooo000Fooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool0F_ooool01Ol0003ooooooooooooooooo000002[ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0>?ooool0
01Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Kooooo`04o`000?oooooooooo
o`0001oooooo1Ol00006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Sooooo000Gooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0Foooool01?l0003oooooooooool0000Oooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0:oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0hooooo`005oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo05_ooooo0ol0000Qooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol00002
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0h
ooooo`005oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05cooooo0_l0000Roooo
o`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo02cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0[oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>?ooool001Sooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`21ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0>?ooool001Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`22ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0/ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0>?ooool001Sooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`1oooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool00000<?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0iooooo`00
6Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo07oooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c006ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000<?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0iooooo`006Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo08[o
oooo00?o0000ooooooooool00oooool01?l0003oooooooooool0000`ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
03Wooooo000Jooooo`03o`000?oooooo000000?o00002?ooool00ol0003oooooooooo`2:ooooo`03
o`000?oooooooooo00Cooooo0_l0000booooo`05o`000?ooooooooooooooool00000<Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo03Wooooo000Jooooo`;o00000oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo08[ooooo0_l0000iooooo`05o`000?oooooooooooooo
ool00000<Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Wooooo000Oooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`0hooooo`05
o`000?ooooooooooooooool00000<Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
03Wooooo000Pooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Roooool00ol0003o
ooooooooo`0iooooo`04o`000?ooooooooooo`0003;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0iooooo`008?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08_o
oooo00?o0000ooooooooool0>Oooool00ol0003oooooo`00000cooooo`05o`000?oooooooooooooo
ool00000??ooool0027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2;ooooo`03
o`000?oooooooooo03Wooooo0ol0000cooooo`05o`000?ooooooooooooooool00000??ooool0027o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo06oo
oooo00Go0000ooooooooooooooooo`00000looooo`008_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo08_ooooo00?o0000ooooooooool0Koooool01Ol0003ooooooooooooooooo0000
03cooooo000Rooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Roooool00ol0003o
ooooooooo`1`ooooo`03o`000?oooooo000003gooooo000Rooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0Roooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03cooooo
000Sooooo`04o`000?ooooooooooo`0008kooooo0_l0002aooooo`008oooool01?l0003ooooooooo
ool0002>ooooo`03o`000?oooooooooo0;3ooooo000Tooooo`03o`000?oooooo000008kooooo00?o
0000ooooooooool0/?ooool002Cooooo0_l0002?ooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:cooooo0_l00000
0ol@413oooooooooo`04ooooo`03o`000?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0/?ooool00:[ooooo1Ol00006ooooo`03o`000?oooooooooo0;3o
oooo002Zooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEE
ooooool00007ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo
00?o0000ooooooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003ooooooooo
o`2`ooooo`00[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05onk^k_lb<S;o0000
oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OmEEEGoMgMgoooooonHV9So
8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3
o`000;3ooooo002Zooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`
ooooo`00Z_ooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03
omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0/?ooool00:_ooooo00Coc<c<odA4A?l0003o
410@1_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00Z_ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000oooooooo
ool0/?ooool00:[ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3o
oooo002Zooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`2`ooooo`00
Z_ooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0002`ooooo`00Z_ooool01Oo<c<co0000
o`000?l0003oc<c<0;Wooooo002Zooooo`05oa0@4?nj^[[ooooookZj^_l@4100^Oooool00:[ooooo
00Go0000okZj^_oooooo^[Zjo`00002iooooo`00Z_ooool01OnYZJWo410@o`000?l@413oZJVY0;Wo
oooo003oooooofWooooo002cooooo`03o`000?nj^[[ooooo0;;ooooo002cooooo`;o<S8b/oooool0
08Cooooo0_l000001_l@413oooooooooool@413o0000oa0@41Sooooo00GoA4A4o`000?l0003o<S8b
omgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOo0000okZj^P0<ooooo`05
oiRHV?l0003o0000odA4A?nj^[X06_ooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^07cooooo0025ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01ooo
ool6o`0000gooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL00oooool00oo<
c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000cooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg07cooooo0025ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool06oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oo
oooooooo013ooooo00?o0000ooooooooool06_ooool5o`0000?ooooo00Go410@oooooooooooooooo
oa0@401looooo`00QOooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000=ooooo`05
ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00_ooooo1_l00009ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`00
001looooo`00QOooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001Wooooo00Go0000ob4Q8Ol0003o
<S8bolc<c002ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0Joooo
o`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`00001looooo`00QOooool0
1_l0003oQhN7ojVYZOnj^[[oEEEEo`0001Wooooo00?o0000ooooooooool01?ooool01Ol@413ooooo
oooooooooooo410@013ooooo00?o410@o`000?l000000ol0000Jooooo`03ogMgMoo<c<co000000Co
oooo00Go410@oooooooooooooooooa0@401looooo`00QOooool01_l0003o<S8boooooooooooo<S8b
o`0001Wooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o
0000ooooooooool06oooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
O?ooool008Cooooo00?o410@o`000?n7QhL00_ooool00on7QhOo0000oa0@400Hooooo`Co00000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo00?o0000ooooooooool07?ooool00omgMgOo0000
ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0O?ooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(42) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .24435 m
.00942 .21311 L
.0122 .20459 L
.01483 .19752 L
.01739 .19174 L
.01975 .18755 L
.02096 .18591 L
.02225 .18459 L
.02353 .18377 L
.02427 .18354 L
.02496 .18349 L
.02567 .18362 L
.02636 .18392 L
.02764 .18498 L
.02902 .18688 L
.0298 .18832 L
.03053 .18991 L
.03308 .19742 L
.03539 .20708 L
.03805 .22198 L
.04057 .24021 L
.0509 .35843 L
.05363 .3938 L
.05513 .41132 L
.05655 .42577 L
.05787 .43677 L
.05857 .44148 L
.05931 .44559 L
.06061 .45044 L
.06182 .45205 L
.06249 .45173 L
.06322 .45041 L
.06453 .44549 L
.06529 .44121 L
.06609 .43565 L
.06753 .42326 L
.07052 .38944 L
.07379 .34581 L
.07946 .27306 L
.08224 .24383 L
.08481 .22148 L
.08999 .18826 L
.09271 .17586 L
.0956 .16569 L
.09801 .15911 L
.10027 .15425 L
.10274 .15002 L
.1054 .14645 L
.10822 .14341 L
.1113 .14072 L
Mistroke
.11401 .13878 L
.11689 .13714 L
.11975 .13593 L
.12234 .13515 L
.1236 .13487 L
.12495 .13462 L
.12622 .13445 L
.1274 .13435 L
.12873 .13428 L
.12999 .13429 L
.13112 .13436 L
.13235 .13451 L
.13368 .13478 L
.13436 .13496 L
.1351 .13519 L
.13643 .13571 L
.13765 .13631 L
.14002 .13785 L
.14258 .14011 L
.14483 .14268 L
.1472 .14604 L
.14981 .15061 L
.15258 .15667 L
.15758 .17122 L
.16352 .19522 L
.16891 .22247 L
.17402 .25011 L
.17681 .26416 L
.17942 .27542 L
.18165 .2829 L
.18289 .28606 L
.18403 .28821 L
.18528 .28973 L
.18663 .29035 L
.18791 .28994 L
.1891 .28871 L
.19035 .28657 L
.19169 .28333 L
.19413 .27531 L
.19969 .24982 L
.20552 .21976 L
.21095 .19499 L
.2158 .17784 L
.21851 .17045 L
.22098 .16504 L
.22369 .16041 L
.22512 .15846 L
.22663 .15675 L
.22795 .15551 L
.22941 .15441 L
Mistroke
.23073 .15364 L
.23197 .15308 L
.23333 .15265 L
.23411 .15248 L
.23483 .15237 L
.23614 .15228 L
.23688 .15229 L
.23754 .15232 L
.2388 .15246 L
.24017 .15271 L
.24146 .15303 L
.24264 .15338 L
.24818 .15546 L
.25411 .15777 L
.25686 .15864 L
.25822 .15899 L
.25947 .15926 L
.2606 .15945 L
.2618 .1596 L
.26301 .15969 L
.26435 .15971 L
.26558 .15966 L
.26672 .15955 L
.26796 .15936 L
.26927 .15909 L
.27148 .15845 L
.27389 .15751 L
.27933 .15466 L
.28514 .15088 L
.29022 .14745 L
.293 .14575 L
.2956 .14439 L
.29699 .14378 L
.29826 .14332 L
.29968 .14293 L
.30046 .14277 L
.3012 .14266 L
.30248 .14257 L
.30367 .14262 L
.30497 .14282 L
.30636 .14324 L
.30715 .14358 L
.30788 .14395 L
.30952 .14507 L
.31096 .14639 L
.31248 .14815 L
.31513 .15224 L
.31803 .15847 L
.3208 .16639 L
.32332 .1755 L
Mistroke
.32898 .20325 L
.33423 .23776 L
.33919 .2746 L
.34403 .30693 L
.34536 .31388 L
.34678 .32004 L
.34813 .32442 L
.34936 .32708 L
.35073 .32846 L
.35201 .32819 L
.35274 .32737 L
.3534 .32621 L
.35417 .32438 L
.35489 .3222 L
.35742 .3114 L
.36015 .29514 L
.37016 .22237 L
.37505 .19273 L
.37951 .17237 L
.38198 .16377 L
.38432 .15727 L
.3868 .15198 L
.38949 .14787 L
.3908 .14642 L
.39224 .14519 L
.39297 .14471 L
.39375 .1443 L
.39449 .14399 L
.39517 .14378 L
.3964 .14357 L
.39774 .14356 L
.39841 .14364 L
.39914 .14379 L
.40044 .14421 L
.40116 .14452 L
.40192 .14492 L
.4033 .14578 L
.4064 .14838 L
.41202 .155 L
.42255 .17014 L
.42763 .17689 L
.43013 .17968 L
.43245 .1818 L
.43385 .18282 L
.43511 .18355 L
.43579 .18387 L
.43652 .18415 L
.43729 .18438 L
.43801 .18454 L
.4393 .18465 L
Mistroke
.44066 .18456 L
.44182 .18431 L
.4431 .18387 L
.44439 .18325 L
.44561 .1825 L
.4479 .18074 L
.45304 .17524 L
.46232 .16244 L
.46756 .15591 L
.47013 .15339 L
.47248 .15159 L
.47368 .15088 L
.47495 .15032 L
.47622 .14995 L
.4776 .14981 L
.47835 .14985 L
.47902 .14997 L
.4798 .15021 L
.48053 .15055 L
.48184 .15141 L
.48258 .15206 L
.48326 .15278 L
.48437 .1542 L
.48557 .1561 L
.48774 .16056 L
.49031 .16781 L
.49266 .17646 L
.49511 .18776 L
.49777 .20296 L
.50261 .23875 L
.50775 .28576 L
.51045 .31113 L
.51329 .33517 L
.51579 .35164 L
.51648 .35514 L
.51721 .35832 L
.51853 .36251 L
.51982 .36458 L
.52105 .36462 L
.52215 .36305 L
.52334 .35969 L
.5246 .35435 L
.52598 .34653 L
.52878 .3256 L
.53381 .27849 L
.53974 .22408 L
.54267 .20193 L
.54538 .18478 L
.55047 .16081 L
.55316 .15189 L
Mistroke
.55603 .14479 L
.55729 .14235 L
.55866 .14015 L
.55987 .13856 L
.56114 .1372 L
.56229 .13623 L
.56355 .13544 L
.5647 .13494 L
.56577 .13464 L
.56713 .13449 L
.5679 .13451 L
.56861 .13459 L
.56992 .13488 L
.5713 .1354 L
.57254 .13604 L
.5737 .13679 L
.57635 .13901 L
.5792 .14221 L
.58181 .14585 L
.58769 .15615 L
.5973 .17721 L
.60258 .18941 L
.60757 .19951 L
.6104 .20396 L
.612 .20592 L
.61347 .20735 L
.61471 .20825 L
.61607 .20892 L
.61676 .20914 L
.6175 .20927 L
.61883 .20925 L
.62017 .20892 L
.62093 .20859 L
.62164 .20819 L
.62293 .20724 L
.62431 .20593 L
.62693 .20262 L
.62931 .19884 L
.63916 .17922 L
.64455 .16949 L
.64717 .16569 L
.64956 .16295 L
.65091 .16175 L
.65219 .1609 L
.65354 .16031 L
.6543 .16015 L
.655 .16011 L
.65638 .16037 L
.65716 .16073 L
.65789 .16123 L
Mistroke
.65867 .16191 L
.65937 .1627 L
.66096 .16505 L
.66229 .16768 L
.66353 .1707 L
.66633 .1798 L
.6688 .19071 L
.67144 .20571 L
.67706 .25059 L
.68223 .30538 L
.68491 .3352 L
.68779 .36407 L
.68944 .37763 L
.69095 .38731 L
.69167 .39092 L
.69246 .394 L
.69321 .39607 L
.6939 .39722 L
.69512 .39745 L
.69627 .39555 L
.69753 .39115 L
.69889 .38386 L
.70024 .37428 L
.70166 .36202 L
.70419 .33598 L
.70989 .27073 L
.71507 .21897 L
.71754 .19928 L
.72022 .18159 L
.72254 .16908 L
.72508 .15794 L
.72779 .14872 L
.73065 .14146 L
.73193 .13893 L
.7333 .13664 L
.73459 .13486 L
.73578 .13349 L
.73708 .13228 L
.73825 .13139 L
.73956 .13063 L
.74028 .1303 L
.74095 .13005 L
.74216 .12972 L
.74348 .12953 L
.74463 .12951 L
.74585 .12962 L
.74695 .12985 L
.74813 .13022 L
.74924 .13069 L
.75025 .13122 L
Mistroke
.75272 .13292 L
.75506 .13504 L
.75989 .14093 L
.76521 .14978 L
.77077 .16193 L
.77599 .17592 L
.78523 .20392 L
.79012 .21757 L
.7928 .22377 L
.79534 .22837 L
.79669 .23024 L
.79739 .23105 L
.79815 .23177 L
.79947 .2327 L
.80069 .23315 L
.80192 .23321 L
.80307 .23291 L
.80432 .2322 L
.80568 .231 L
.80707 .22931 L
.80859 .227 L
.81136 .2217 L
.81655 .20925 L
.82137 .1969 L
.82657 .18512 L
.82896 .18078 L
.83026 .17879 L
.83148 .17721 L
.83261 .17601 L
.83363 .17515 L
.83477 .17449 L
.83599 .17415 L
.83666 .17414 L
.83738 .17427 L
.83867 .17491 L
.84005 .1762 L
.84084 .17724 L
.84158 .17841 L
.84413 .18415 L
.84556 .1886 L
.84686 .19352 L
.84928 .20491 L
.85191 .22119 L
.85671 .26227 L
.86266 .33086 L
.86558 .3661 L
.86827 .3945 L
.86953 .40541 L
.87072 .41373 L
.87195 .42018 L
Mistroke
.8733 .4244 L
.87468 .42544 L
.87593 .42347 L
.87662 .42121 L
.87738 .41783 L
.87875 .40934 L
.88002 .399 L
.88122 .38745 L
.88395 .35622 L
.88948 .2861 L
.89431 .23304 L
.8994 .19228 L
.90204 .17667 L
.90493 .16315 L
.90756 .15361 L
.91 .14676 L
.91289 .14077 L
.91552 .13686 L
.91856 .13363 L
.92142 .13145 L
.92263 .13072 L
.92393 .13007 L
.92506 .12962 L
.92628 .12924 L
.92702 .12908 L
.92771 .12896 L
.92907 .12886 L
.93031 .12891 L
.93163 .12911 L
.93236 .12927 L
.93303 .12946 L
.93455 .13001 L
.9373 .13134 L
.9398 .1329 L
.94243 .13493 L
.94474 .13713 L
.94722 .14005 L
.95167 .14712 L
.95698 .15874 L
.96181 .17218 L
.97069 .20415 L
.97555 .22389 L
.98011 .24059 L
.98268 .24817 L
.98503 .25355 L
.9863 .25575 L
.98764 .25749 L
.98898 .25861 L
.98974 .25897 L
.99045 .25912 L
Mistroke
.9917 .25893 L
.99287 .25825 L
.99393 .25721 L
.99507 .25565 L
.99632 .25345 L
.99764 .25061 L
1 .24435 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000B_ooool4o`0003Kooooo1Ol0000Xooooo`00
]Oooool00ol0003oooooooooo`18ooooo`;o00000oooool00ol0003oooooooooo`0booooo`;o0000
1?ooool2o`0002Kooooo000kooooo`So0000L_ooool00ol0003oooooooooo`0@ooooo`Go0000<_oo
ool2o`0000Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo02?ooooo000jooooo`03o`000?oooooooooo00Gooooo0_l0001aooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo02;ooooo000hooooo`;o00002_ooool00ol0003oooooooooo`0^ooooo`?o00007?ooool2o`00
01oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool08_ooool003Oooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0[ooooo`;o00000oooool2o`0001Sooooo1Ol0000Nooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo027o
oooo000gooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0:Oooool2o`0000Kooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01?ooooo
0_l00006ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0[ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo023ooooo000fooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool06?ooool4o`0000cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04Oooool5o`0000Cooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool08?ooool003Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0F
ooooo`;o00000oooool4o`0000Oooooo0_l0000:ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool2o`0000oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo01oooooo000eooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool05?ooool2o`0000Sooooo0_l00002ooooo`?o00003Oooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Zoooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool07oooool003Gooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Wooooo0ol0000?ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool04?ooool3o`0001Gooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool07oooool001Go
oooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0Dooooo`03o`000?oo
oooooooo00?ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`06onk^k_lb<S;o0000oc8b<_o^
k^ko00005?ooool00ol0003oooooooooo`03ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00gooooo00?o0000ooooooooool03?ooool5o`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP04ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooo
oooooooo000000oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`Co0000
00[o410@ooooooooooook^k^oc8b<_l0003o<S8bonk^k_oooooo00000oooool00ol0003ooooooooo
o`0Booooo`Go00000oooool01oo^k^ko<S8bo`000?lb<S;ok^k^ooooool000006Oooool01OnHV9So
410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool01Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^00kooooo000Fooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Dooooo`03o`000?oooooooooo00?ooooo00Go410@okZj^_ooooooMgMgoc8b<P03oooo
o`06ogMgMonHV9SooooooiRHV?mgMgOo00005?ooool00ol0003oooooooooo`03ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00gooooo00?o0000oooooooo
ool03_ooool00ol0003oooooo`000002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo00003oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
1omgMgOoV9RHoooooonHV9SoMgMgooooool000001?ooool00ol0003oooooooooo`0@ooooo`06o`00
0?nHV9So8B4Qonk^k_ooooooA4A40oooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo00?o0000
ooooooooool05_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`04ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool000_ooooo1_l00002ooooo`Go0000
0oooool01Ol@413ooooooooooooooooo410@01;ooooo1_l00006ooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooo`00000Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41003Oooool00ol0003oooooooooo`03ooooo`Ko00001Oooool0
0ol0003oooooo`000002ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00003_ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01_l@413ooooo
oooooooooooo410@o`0000Gooooo00?o0000ooooooooool04?ooool01Ol0003ooooooiRHV?lQ8B7o
k^k^00Cooooo00Go410@oooooooooooooooooa0@4002ooooo`03o`000?oooooooooo01[ooooo00Go
0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`03ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00ko
oooo000Cooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000Coooo
o`03o`000?oooooooooo00Oooooo00?oZJVYoa0@4?ooool00_ooool01ol0003ooooooooooooooooo
0000ooooool000004_ooool00ol0003oooooooooo`06ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go
0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooool00000
0_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooo000000kooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0_l00005oooo
o`03o`000?oooooooooo013ooooo00Ko0000ooooooooooooV9RHob4Q8Oo^k^h3ooooo`05o`000?oo
ooooooooooooool000000_ooool00ol0003oooooooooo`0@ooooo`?o00001_ooool00onYZJWo410@
ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00;ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo
000000kooooo000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`00
000Cooooo`03o`000?oooooooooo00Kooooo00?o410@o`000?nj^[X00oooool01ol0003ooooooooo
oooooooo0000ooooool000004Oooool00ol0003oooooooooo`08ooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ool000000_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool01?ooool2
o`0000cooooo00?o0000ooooool000003_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o
0000ooooooooool03oooool01_l0003oooooooooooooooooMgMgofIVIP?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo00kooooo0_l000000ooooooo0000ooooo`04oooo
o`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool00_ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?oo
ooooooooooooool000003_ooool001Cooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooo
oooooooo410@01?ooooo00?o0000ooooooooool01oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@
4?ooooooooooooooool@41000_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Wo
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00cooooo00?o0000oooo
ooooool03Oooool2o`0000?ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool03?ooool01?l0003oooooo`000?l0000=ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooo`000?l@41001oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo
00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool000004?ooool01Ol0
003ooooooooooooooooo000000Gooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooo
oooo410@00?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`03ooooo`03ogMgMoo<
c<co000000Cooooo00Go410@oooooooooooooooooa0@400>ooooo`005?ooool00oo^k^koA4A4o`00
0004ooooo`05ogMgMonHV9So0000o`000?mgMgL04oooool00ol0003oooooooooo`04ooooo`05oa0@
4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`05ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool03Oooool2o`0000?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`08ooooo`Ko00003_ooool00ol0003oooooo`00000=ooooo`03o`00
0?oooooooooo00oooooo00Go0000ooooooooooooooooo`000004ooooo`05ogMgMonHV9Soooooo`00
0?mgMgL01oooool00ol0003oooooooooo`0>ooooo`07o`000?oooooo0000okZj^_ooooooV9RHoa0@
4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`0=ooooo`05o`00
0?ooooooooooooooool000000_ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00_ooool0
0oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool001Gooooo00?oMgMg
o`000?ooool00oooool00oo^k^ko0000o`000002o`0001;ooooo00?o0000ooooooooool01Oooool0
1OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool01Oooool01OnHV9So410@o`000?lQ8B7oc<c<00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`03o`000?oooooooooo00_ooooo00CoEEEEofIV
I_l0003o00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00[ooooo0_l0000@ooooo`03o`000?oo
oooo000000gooooo00?o0000ooooooooool03oooool01Ol0003ooooooeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo00gooooo00Oo0000oooooonH
V9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool00_ooool02?l0003ooooooooooonYZJWo410@o`000?l@
413oZJVY0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`03ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0>ooooo`007?ooool01?l0003oooooooooool0000Booooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool08oooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01cooooo000K
ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooool000003Oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Kooooo`006oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooo000000cooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool06oooool0
01[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool09?ooool2o`0000cooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool06oooool001[o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool09?ooool2o`0000cooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool06_ooool001Kooooo
ool00010o`0001?ooooo000Fooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
1oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooooooo`Go00001oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00006ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool04Oooool001Kooooo00Co0000oooo
oooooooo00001?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool01?ooool2o`0000Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooo000000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`;o00001ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oo
oooooooo017ooooo000Iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01[ooooo000Iooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
01Wooooo000Iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo01Wooooo000Hooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Wooooo
000Hooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05oooool01Ol0003ooooooooo
oooooooo000000gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo01Wooooo000Hooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05ooo
ool2o`000003ooooool0003o000000gooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo01Sooooo000Gooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Kooooo0_l0000;
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0H
ooooo`?o00003_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool06?ooool001Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool09oooool2o`0000_ooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Sooooo000Gooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo02Oooooo0_l0000:ooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Gooooo`005_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Wooooo`;o0000
2_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
:_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
5oooool001Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool09oooool2o`0000[ooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04Ooo
ool002?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo02Oooooo0_l0000:ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo000Sooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Wooooo`;o00002_ooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo01[ooooo00Go0000ooooooooooooooooo`00000D
ooooo`008oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0:?ooool2o`0000[ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooo000001Gooooo000Sooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02[ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Xooooo`;o00002_ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo01_ooooo0ol0000Eooooo`009?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Zooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0:?ooool2o`0000[ooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0dooooo`009?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0:?ooool00ol0003oooooo`000009ooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0=?ooool002Cooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooool000002?ooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Cooooo000Tooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool07Oooool01Ol0003ooooooooooooooooo000002kooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo000000Sooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02_ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0dooooo`009?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo01gooooo00Go0000ooooooooooooooooo`00000^ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooo`000008ooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0=?ooool002Cooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Mooooo`05o`000?ooooooooooooooool00000;_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo03Cooooo000Tooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool07_ooool01?l0003oooooooooool0000^ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0:Oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo02_ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0=?ooool002Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Noooo
o`04o`000?ooooooooooo`0002kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Y
ooooo`?o00002?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Cooooo000Toooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07_ooool00ol0003oooooo`00000_oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooo`000008oooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0=?ooool002Cooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Nooooo`?o0000;oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo03Cooooo000Tooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
DOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooool00000
1oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Cooooo000Tooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo03Cooooo000Tooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0D_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooool000001oooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Cooooo000Uooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01oooooo1Ol00006ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0dooooo`009Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
05;ooooo00Go0000ooooooooooooooooo`00000Rooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_oo
ool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
=Oooool002Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Booooo`05o`000?oo
ooooooooooooool000008oooool00onHV9So8B4Qonk^kP07ooooo`Co00001_ooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo03Gooooo000Uooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0Doooool01?l0003oooooooooool0000Tooooo`03oiRHV?lQ8B7ok^k^00Kooooo
00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Go
oooo000Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Doooool01?l0003ooooo
ooooool0000Uooooo`03ogMgMomVIVKooooo00Gooooo00Co0000oooooooooooo00001Oooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo03Gooooo000Uooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0Doooool01?l0003oooooooooool0000Vooooo`03o`000?oooooooooo
00Cooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo03Gooooo000Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Doooool01?l0
003oooooooooool0000Rooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool01?l0003ooooooooo
ool00005ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=Oooool002Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`1Dooooo`;o00008oooool01OnHV9So410@o`00
0?lQ8B7oc<c<00Kooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0=Oooool002Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`1Dooooo`;o0000;_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooooooo
ool0;oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0eooooo`009Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo08Gooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0=Oooool002Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`25ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0=Oooool002Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`25ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo03Gooooo000Uooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0QOoo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0<?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0fooooo`009_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08Gooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
=_ooool002Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`25ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000<_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0fooooo`009_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool0000booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Kooooo000Vooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0003?ooooo00Go0000ooooooooooooooooo`00000cooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0=_ooool002Kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`25ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000<oooool01Ol0003o
oooooooooooooooo000003?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0foooo
o`009_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08Gooooo00?o0000oooooooo
ool00_ooool00ol0003oooooo`00000dooooo`05o`000?ooooooooooooooool00000<oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo03Kooooo000Vooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0QOooool2o`0000Cooooo0_l0000dooooo`05o`000?oooooooooooooo
ool00000<oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Kooooo000Vooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`03ooooo`;o
0000=?ooool01Ol0003ooooooooooooooooo000003?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0fooooo`009_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08Go
oooo00?o0000ooooooooool0>Oooool01Ol0003ooooooooooooooooo000003?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0fooooo`009_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo08Kooooo00?o0000ooooooooool0>Oooool01Ol0003ooooooooooooooooo0000
03?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0fooooo`009_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool0>Oooool01Ol0003o
oooooooooooooooo000003?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0goooo
o`009oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo08Kooooo00?o0000oooooooo
ool0>Oooool01Ol0003ooooooooooooooooo000003?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0gooooo`009oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo08Ko
oooo00?o0000ooooooooool0>Oooool01?l0003oooooooooool0000eooooo`05o`000?oooooooooo
ooooool00000>Oooool002Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`26oooo
o`03o`000?oooooooooo03[ooooo00?o0000ooooool00000=Oooool01Ol0003ooooooooooooooooo
000003Wooooo000Wooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Q_ooool2o`00
03_ooooo00?o0000ooooool00000=Oooool01Ol0003ooooooooooooooooo000003Wooooo000Woooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`0joooo
o`03o`000?oooooo000003Gooooo00Go0000ooooooooooooooooo`00000iooooo`009oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool0>_ooool00ol0
003oooooo`00000eooooo`05o`000?ooooooooooooooool00000>Oooool002Oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo03[ooooo0_l0000foooo
o`05o`000?ooooooooooooooool00000>Oooool002Oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`26ooooo`03o`000?oooooooooo07;ooooo00Go0000ooooooooooooooooo`00000i
ooooo`009oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07gooooo0_l000000ol@
413oooooooooo`04ooooo`03o`000?oooooooooo07?ooooo00Co0000oooooooooooo0000>Oooool0
02Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0Loooool00ol0003oooooo`00000jooooo`009oooool01Ol0003o
oooooooooooooooo000007kooooo1Ol00006ooooo`03o`000?oooooooooo07?ooooo00?o0000oooo
ool00000>_ooool002Oooooo00Go0000ooooooooooooooooo`00001nooooo`04odA4A?oMgMgooooo
o`0000Oooooo0ol0001cooooo`03o`000?oooooo000003[ooooo000Wooooo`05o`000?oooooooooo
ooooool00000O_ooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo07?ooooo00?o
0000ooooool00000>_ooool002Oooooo00Go0000ooooooooooooooooo`00001oooooo`03ogMgMoo<
c<co000000Oooooo00?o0000ooooooooool0Loooool00ol0003oooooo`00000jooooo`00:?ooool0
1?l0003oooooooooool0001oooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0Looo
ool00ol0003oooooo`00000jooooo`00:?ooool01?l0003oooooooooool00020ooooo`03ogMgMol0
003ooooo00Kooooo00?o0000ooooooooool0M?ooool2o`0003[ooooo000Xooooo`04o`000?oooooo
ooooo`0008Wooooo00?o0000ooooooooool0/?ooool002Sooooo00Co0000oooooooooooo0000ROoo
ool00ol0003oooooooooo`2`ooooo`00:?ooool01?l0003oooooooooool00029ooooo`03o`000?oo
oooooooo0;3ooooo000Xooooo`04o`000?ooooooooooo`0008Wooooo0_l0002aooooo`00:?ooool0
0ol0003oooooo`00002:ooooo`03o`000?oooooooooo0;3ooooo000Xooooo`03o`000?oooooo0000
08[ooooo00?o0000ooooooooool0/?ooool002Wooooo0_l0002:ooooo`03o`000?oooooooooo0;3o
oooo000Yooooo`;o0000R_ooool00ol0003oooooooooo`2`ooooo`00:Oooool2o`0008[ooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`
ooooo`00Z_ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool0
0:[ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zoooo
o`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`000;3ooooo002Zooooo`05o`000?mEEEGo0000
oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool00omEEEGoQhN7ooooo`08oooo
o`03o`000?oooooooooo0;3ooooo002Zooooo`03omgMgOl@413oV9RH00Sooooo00?o0000oooooooo
ool0/?ooool00:_ooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Oo<c<co8B4Q
o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go8B4QoiRHV?oooooo
V9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Olb<S;oV9RHoooooonHV9So<S8b00Ko
oooo0ol0002`ooooo`00Z_ooool01Oo<c<co0000o`000?l0003oc<c<0;Wooooo002Zooooo`05oa0@
4?nj^[[ooooookZj^_l@4100^Oooool00:[ooooo00Go0000okZj^_oooooo^[Zjo`00002iooooo`00
Z_ooool01OnYZJWo410@o`000?l@413oZJVY0;Wooooo003oooooofWooooo002cooooo`03o`000?nj
^[[ooooo0;;ooooo002cooooo`;o<S8b/oooool008Cooooo0_l000001_l@413oooooooooool@413o
0000oa0@41Sooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06_ooool2o`00
0004oa0@4?ooooooooooooooo`Go0000O?ooool008Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`07ooooo`Ko00003Oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`03olc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko
00003?ooool00ol0003oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0O?ooool008Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooooooooa0@
40?ooooo00?o410@ooooooooool04?ooool00ol0003oooooooooo`0Jooooo`Go00001?ooool00onH
V9So8B4Qonk^kP1mooooo`00QOooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000=
ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00_ooooo1_l00009ooooo`04odA4A?oMgMgoooooo`0000Kooooo00?oV9RHob4Q8Oo^k^h0
O?ooool008Gooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Iooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`00_ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool06_ooool0
1?oMgMgoEEEEooooool00007ooooo`03ogMgMomVIVKooooo07_ooooo0025ooooo`06o`000?n7QhOo
ZJVYokZj^_mEEEGo00006Oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
41004?ooool00ol@413o0000o`000003o`0001[ooooo00?oMgMgolc<c?l000002?ooool00ol0003o
ooooooooo`1jooooo`00QOooool01_l0003o<S8boooooooooooo<S8bo`0001Wooooo00?o0000oooo
ooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool06oooool0
0oo^k^koA4A4o`000004ooooo`05o`000?nj^[[ooooooiRHV?l@4100O?ooool008Cooooo00?o410@
o`000?n7QhL00_ooool00on7QhOo0000oa0@400Hooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^01;ooooo00?o0000ooooooooool07?ooool00omgMgOo0000ooooo`03ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`0O?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(44) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .19084 m
.00488 .17932 L
.00942 .17053 L
.01483 .16209 L
.01975 .15573 L
.02223 .15304 L
.02492 .15065 L
.02746 .14893 L
.02981 .1478 L
.03109 .14735 L
.03229 .14702 L
.03361 .14677 L
.03435 .14668 L
.03503 .14663 L
.03639 .14664 L
.03716 .14673 L
.03787 .14686 L
.03917 .14728 L
.0399 .14762 L
.04057 .14801 L
.04189 .14905 L
.04334 .15064 L
.04485 .1529 L
.04627 .15563 L
.0488 .16224 L
.05151 .17212 L
.05469 .18817 L
.0577 .209 L
.06041 .23358 L
.06335 .2676 L
.06826 .33965 L
.07355 .42095 L
.07502 .43937 L
.07658 .45491 L
.07791 .46441 L
.07866 .46807 L
.07936 .47031 L
.08074 .47129 L
.08199 .46821 L
.08269 .46491 L
.08344 .46011 L
.08481 .44834 L
.08731 .41828 L
.09006 .37677 L
.09561 .2888 L
.09809 .2551 L
.10076 .22499 L
.10326 .2024 L
.10557 .18572 L
.1084 .16996 L
Mistroke
.11002 .16286 L
.11148 .15749 L
.1142 .14993 L
.1157 .14699 L
.1171 .14493 L
.11838 .14359 L
.11974 .14268 L
.12089 .14227 L
.12216 .14216 L
.12353 .14239 L
.12429 .14266 L
.12499 .14298 L
.12635 .14381 L
.12763 .14483 L
.13013 .14749 L
.13246 .15083 L
.13503 .15557 L
.13779 .16201 L
.14342 .17909 L
.14858 .19831 L
.15794 .23785 L
.16041 .24782 L
.16308 .25737 L
.16561 .26464 L
.16681 .26738 L
.16793 .26947 L
.16918 .27127 L
.17056 .27257 L
.1719 .27316 L
.17265 .2732 L
.17334 .27307 L
.17455 .27244 L
.17586 .2712 L
.1771 .26955 L
.17825 .26762 L
.1829 .25664 L
.18784 .24145 L
.1983 .21059 L
.20419 .1982 L
.20959 .1896 L
.21434 .18373 L
.21953 .17852 L
.23001 .16826 L
.2492 .1467 L
.25977 .1358 L
.26497 .13152 L
.26976 .12824 L
.27244 .12678 L
.27529 .1256 L
.27676 .12515 L
Mistroke
.27814 .12483 L
.27893 .12469 L
.27965 .12458 L
.28049 .12449 L
.28128 .12444 L
.28254 .12442 L
.28388 .12449 L
.28514 .12465 L
.28629 .12487 L
.28764 .12525 L
.2891 .1258 L
.29048 .12648 L
.29175 .12725 L
.29433 .12932 L
.29669 .13186 L
.29941 .13566 L
.30198 .14023 L
.30656 .15109 L
.31153 .16786 L
.317 .19344 L
.32281 .22838 L
.32825 .26448 L
.33063 .27939 L
.33323 .29369 L
.33444 .2993 L
.33572 .30441 L
.33683 .30804 L
.33803 .31106 L
.33939 .31327 L
.34068 .31414 L
.34193 .31385 L
.34308 .3126 L
.34435 .31018 L
.34554 .307 L
.34824 .2969 L
.35369 .26881 L
.35814 .24426 L
.36288 .2215 L
.36561 .21092 L
.36808 .20311 L
.37056 .19695 L
.37289 .19263 L
.37423 .19075 L
.37563 .1892 L
.37684 .1882 L
.37815 .1874 L
.3789 .18708 L
.37957 .18687 L
.38035 .18669 L
.38109 .1866 L
Mistroke
.3824 .1866 L
.38315 .18667 L
.38383 .18678 L
.38507 .18706 L
.38623 .18741 L
.38887 .1884 L
.39161 .18951 L
.39421 .19047 L
.39534 .19081 L
.39655 .19109 L
.39788 .19128 L
.39911 .19135 L
.40032 .19128 L
.40146 .19109 L
.40248 .19081 L
.40359 .19039 L
.40481 .18978 L
.40614 .18892 L
.40884 .18665 L
.41368 .18095 L
.42507 .16251 L
.43587 .14476 L
.44057 .13847 L
.44556 .13296 L
.44817 .13059 L
.45104 .12841 L
.45366 .12685 L
.45493 .12624 L
.45611 .12576 L
.45736 .12535 L
.45849 .12506 L
.45976 .12483 L
.4611 .12471 L
.4624 .1247 L
.46313 .12475 L
.46381 .12483 L
.46505 .12506 L
.46636 .12545 L
.46748 .12589 L
.46867 .1265 L
.47084 .12797 L
.47341 .13044 L
.47576 .13352 L
.47846 .13818 L
.48096 .1438 L
.48371 .15167 L
.48663 .16234 L
.49205 .1897 L
.49695 .22415 L
.5068 .31071 L
Mistroke
.50919 .32931 L
.51051 .33797 L
.51176 .34487 L
.51246 .34814 L
.51323 .35114 L
.51457 .35491 L
.51593 .35673 L
.51719 .35655 L
.51855 .35437 L
.51982 .35054 L
.52055 .34761 L
.52122 .3445 L
.52272 .33608 L
.52859 .29114 L
.53366 .24947 L
.53644 .2295 L
.53906 .2135 L
.54166 .20053 L
.54447 .1896 L
.54571 .18575 L
.54702 .18231 L
.54938 .17765 L
.55052 .17605 L
.55174 .17478 L
.55289 .17397 L
.55395 .17355 L
.55518 .17341 L
.55652 .17365 L
.55779 .17423 L
.55896 .17502 L
.56021 .1761 L
.56155 .17753 L
.56397 .18065 L
.5695 .18963 L
.57531 .19982 L
.57814 .20417 L
.57937 .20579 L
.58071 .20733 L
.58201 .20856 L
.5832 .20945 L
.58434 .21008 L
.58556 .2105 L
.58683 .21066 L
.58802 .21054 L
.58933 .21012 L
.59007 .20975 L
.59074 .20933 L
.59213 .20822 L
.59343 .20689 L
.59637 .20292 L
Mistroke
.60172 .19281 L
.61312 .16638 L
.61872 .1546 L
.62386 .14538 L
.6289 .13819 L
.63422 .13268 L
.63698 .13061 L
.63956 .12915 L
.64104 .12851 L
.64238 .12807 L
.64313 .12788 L
.64394 .12773 L
.64471 .12764 L
.64542 .1276 L
.64653 .12762 L
.64774 .12777 L
.64888 .12804 L
.64992 .12841 L
.65108 .12895 L
.65234 .12972 L
.65368 .13075 L
.65489 .13189 L
.65741 .13497 L
.66011 .13954 L
.6626 .14523 L
.66496 .15216 L
.66747 .16156 L
.66982 .17253 L
.67261 .18875 L
.67517 .20694 L
.68038 .25456 L
.68598 .31682 L
.68828 .34208 L
.69073 .36575 L
.69214 .37695 L
.69342 .38512 L
.69471 .39117 L
.69592 .3947 L
.69707 .39602 L
.69828 .39522 L
.69932 .39277 L
.70045 .38829 L
.70168 .3815 L
.70299 .3722 L
.70535 .35122 L
.71055 .29559 L
.71607 .24055 L
.71894 .21769 L
.72212 .19768 L
.725 .18384 L
Mistroke
.7277 .17426 L
.72901 .17073 L
.73043 .16761 L
.73177 .16533 L
.73302 .16375 L
.73425 .16267 L
.73537 .16206 L
.73667 .16177 L
.73789 .16184 L
.73922 .16229 L
.73989 .16264 L
.74063 .16311 L
.74315 .16543 L
.74457 .16716 L
.74609 .16934 L
.74884 .17411 L
.75951 .20004 L
.76514 .21405 L
.76823 .22053 L
.77113 .22544 L
.77235 .2271 L
.77363 .22853 L
.77431 .22914 L
.77504 .2297 L
.77634 .23038 L
.77709 .23058 L
.77778 .23065 L
.77857 .23058 L
.77932 .23036 L
.78065 .22963 L
.7814 .22902 L
.78209 .22834 L
.78444 .22522 L
.78702 .22056 L
.79225 .20848 L
.80359 .17798 L
.80918 .16429 L
.81436 .1542 L
.81943 .14643 L
.82403 .14073 L
.82666 .13816 L
.82914 .13634 L
.8305 .13561 L
.83175 .1351 L
.83313 .13473 L
.83382 .1346 L
.83458 .13452 L
.83589 .13448 L
.83663 .13452 L
.83731 .1346 L
Mistroke
.83857 .13485 L
.8399 .13526 L
.84109 .13579 L
.84221 .13644 L
.84344 .13737 L
.84475 .13865 L
.84608 .1403 L
.84753 .14258 L
.84894 .14535 L
.85044 .14898 L
.85314 .15744 L
.85566 .16782 L
.8582 .18121 L
.86096 .19956 L
.86596 .24542 L
.87532 .36724 L
.8778 .39704 L
.87917 .41059 L
.88046 .42094 L
.88166 .42803 L
.88298 .43274 L
.88417 .43416 L
.88527 .43299 L
.88596 .43106 L
.8867 .42798 L
.88805 .41989 L
.88937 .40919 L
.89057 .39724 L
.89621 .32569 L
.90178 .25537 L
.90697 .20736 L
.90958 .19017 L
.91238 .17616 L
.91398 .16992 L
.91549 .16504 L
.91685 .16141 L
.91831 .15827 L
.91962 .15608 L
.92081 .15456 L
.92201 .15344 L
.92315 .15275 L
.92448 .15236 L
.92571 .15235 L
.92705 .15271 L
.92781 .15306 L
.92849 .15347 L
.92988 .15454 L
.93116 .15579 L
.93405 .15947 L
.93659 .16364 L
Mistroke
.93928 .16896 L
.94851 .19374 L
.95864 .22568 L
.96121 .23283 L
.964 .23955 L
.96528 .24216 L
.96664 .24457 L
.96781 .2463 L
.96908 .24779 L
.9703 .24883 L
.97141 .24944 L
.97248 .24969 L
.97361 .24961 L
.97484 .24912 L
.97599 .2483 L
.97725 .24699 L
.9786 .24517 L
.98137 .24023 L
.98437 .23344 L
.98981 .21896 L
1 .19084 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo001^ooooo`?o0000=oooool2o`0000_ooooo00?o0000
ooooooooool0/?ooool006cooooo0ol00002ooooo`?o0000<_ooool3o`000004ooooool0003o0000
o`0000Sooooo00?o0000ooooooooool0:_ooool3o`0008?ooooo001[ooooo`;o00001_ooool00ol0
003oooooooooo`0^ooooo`;o00001_ooool00ol0003oooooooooo`06ooooo`;o0000:Oooool3o`00
0004ooooool0003o0000o`00087ooooo001Yooooo`;o00002Oooool00ol0003oooooooooo`0]oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Ooooool006Sooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0=?ooool5o`0004Gooooo001Wooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`12ooooo`00>oooool3o`0002Sooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo047ooooo000Pooooo`?o00006?ooool0
1?l0003oooooooooool0000Vooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`11ooooo`007_ooool3o`000003ooooool0003o000001Kooooo0_l00003
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo047ooooo000Mooooo`;o00001?ooool2o`0001Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Eooooo`;o0000:_ooool001cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`02ooooo`;o00009?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Booooo`;o
000000?oooooo`000?l00000:Oooool001_ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool04?ooool01Ol0003ooooo
oooooooooooo000002Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool04_ooool01Ol0003ooooooooooooooooo0000
02Wooooo000Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo017ooooo00Go0000ooooooooooooooooo`00000Toooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool04oooool2o`0001Kooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool09_ooool001Gooooo0_l000002Ol@413oooooooooool0003ok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`03o`000?oooooooooo017ooooo00Ko0000oiRHV?l@413o0000oc8b<_o<c<`3ooooo`05
o`000?lb<S;o0000oc8b<_o^k^h06Oooool00ol0003oooooo`000004o`0000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP09ooooo`03o`000?oooooooooo013ooooo1?l000002?l@413oooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^1_ooool00ol0003oooooooooo`0Aooooo`05o`000?oooooooooooooo
ool000008Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h7ooooo`03o`00
0?oooooooooo013ooooo1_l00002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00ol0003o
ooooooooo`0;ooooo`05oiRHV?l0003o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`;o000000Wo410@
ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h03_ooool001Kooooo00[o0000oooooooooooo
0000oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool00ol0003oooooooooo`0Aooooo`06o`000?l@
413o^[ZjoooooomgMgOo<S8b0oooool01Ol0003oV9RHoooooonHV9SoMgMg01Sooooo00So0000oooo
ooooooooV9RHob4Q8Oo^k^koooooodA4A0?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0:ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo00?o0000ooooooooool04_ooool01Ol0003ooooooooooooooooo000002?ooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo00?o0000ooooooooool04?oo
ool03OnHV9So0000onk^k_ooooooA4A4ooooool0003oooooogMgMonHV9SooooooiRHV?mgMgL03Ooo
ool00ol0003oooooooooo`0;ooooo`05oa0@4?l0003oooooogMgMolb<S800oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`002oooool6o`0000;o
oooo1Ol000001?oooooo0000ooooool@4103ooooo`03oa0@4?oooooooooo00Cooooo00?o0000oooo
ooooool02Oooool7o`0000Gooooo00Go0000ooooooooooooooooo`000003ooooo`03oa0@4?oooooo
oooo017ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
400:ooooo`03o`000?oooooooooo00Kooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@4004ooooo`03o`000?oooooooooo01?ooooo00Go0000oooooooooooo
ooooo`00000Sooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4008oooo
o`03o`000?oooooooooo013ooooo00?o0000ob4Q8Oo^k^h00_ooool00ol0003ooooooa0@4003oooo
o`03oa0@4?oooooooooo00_ooooo00?o0000ooooooooool03?ooool01?l0003oooooooooool00003
ooooo`05oa0@4?ooooooooooooooool@41001oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Wooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41003_ooool001?ooooo00Co
A4A4omgMgOoooooo00000_ooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`03ojVYZOl@413ooooo00;ooooo
0_l00002ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00oooool00onHV9So8B4Q
onk^kP03ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo
01?ooooo00Go0000ooooooooooooooooo`00000?ooooo`Co00003oooool2o`0000Cooooo00Go0000
ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00oooooo00Go0000oooooonHV9So8B4Q
onk^kP02ooooo`;o00000oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00gooooo
00Co0000oooooonYZJWo410@0oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000
ooooooooooooooooo`00000>ooooo`004oooool01_oMgMgoEEEEooooool0003oooooo`0000;ooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00oooooo00Oo0000oooooooo
oooooooooa0@4?l0003o^[Zj00?ooooo0_l00002ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool01Oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000002ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo01Gooooo00Co0000oooooooooooo00003oooool01?l0003o
ooooooooool0000?ooooo`;o00001?ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000
ooooooooool03oooool01Ol0003ooooooooooomgMgOoIVIV00;ooooo0_l00003ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool03_ooool2o`000005okZj^_ooooooooooooooool00000
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool001Co
oooo00CoMgMgolc<c?l0003o00000oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@
o`000?oooooooooooa0@400Dooooo`;o00002Oooool01Ol0003ooooooooooooooooo410@00?ooooo
00?o410@ooooooooool02Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@4002ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool00_l0000>ooooo`05o`000?ooooooooooooooool000003Oooool00ol0003oooooo`000004oooo
o`05oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`0?ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo410@00cooooo00?o0000ooooooooool0
3_ooool00ol0003o^[Zjob4Q8@03ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?oMgMgolc<c?l000001?ooool01Ol@413o
oooooooooooooooo410@00kooooo000Dooooo`04onk^k_m4A4Co0000o`0000?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`07ooooo`03o`000?oooooooooo00gooooo00So0000oooooooooooo410@oiRH
V?oooooo^[Zjo`0000?ooooo00GoMgMgo`000?ooooooV9RHogMgM`0Cooooo`03o`000?oooooooooo
00Gooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`02ooooo`03o`000?oooooooooo01Kooooo00Co0000oooooooooooo00003_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000001?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Wooooo00?o0000ooooooooool03_ooool01Ol0003o^[ZjoooooonHV9So
410@00?ooooo00Go0000oiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo00gooooo00Go
410@oiRHV?l0003o^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?ok^k^odA4A?l000001?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00kooooo000Eooooo`03ogMgMol0003o000000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP07ooooo`03o`000?oooooooooo00gooooo00So0000ooooooooooooZJVYoa0@4?l0
003o410@ojVYZ@?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Booooo`03o`000?oooooooooo00Ko
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
0ol0003oooooooooo`0>ooooo`03oeEEEOmVIVKo000000Co000000Ook^k^oc8b<_l0003o<S8bonk^
k_oooooo000001Wooooo00Co0000oooooooooooo00003Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Wooooo00Co0000oeEEEOmVIVKo00001?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Wooooo00?o0000ooooooooool03_ooool01Ol0003o410@o`000?lQ8B7oc<c<00?ooooo00Go
0000oc8b<_l0003o<S8bonk^kP0;ooooo`03o`000?oooooooooo00gooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00kooooo000Fooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0?ooooo`;o00000_ooool4o`000003ooooool0003o000001[ooooo00Co0000oooo
oooooooo00003Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Rooooo`005_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`05oooo
o`?o00006oooool01?l0003oooooooooool0000=ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool04Oooool002Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo02?ooooo00Co0000oooooooooooo00003Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo017ooooo000Wooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0Sooooo`04o`000?ooooooooooo`0000cooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0Booooo`00:?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool09Oooool00ol0003oooooo`00000<oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04_ooool001Koooooool00010o`0001?o
oooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
o`000005ooooo`03o`000?oooooooooo00Gooooo0_l00005ooooo`03o`000?oooooooooo00Gooooo
0_l00006ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooool000001oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00001oooool00ol0003oooooo`000002ooooo`;o000000?oooooo`00
0?ooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`04ooooo`;o00001_ooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooo
oooo00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooo000001?ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo0_l00005
ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooo`00
0007ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?o00000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooool000001_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool00oooool00ol0
003oooooo`00000Cooooo`00:?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool09_ooool00ol0003oooooo`00000;ooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Cooooo`00:?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0:?ooool2o`0000_ooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Cooooo
000Xooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Xooooo`;o00002oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool05?ooool002Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo02Sooooo0_l0000:ooooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Eooooo`00:Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0:?ooool2o`0000[ooooo00?o0000oooo
ooooool0:_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00gooooo0_l00002oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05Oooool002Wooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Sooooo0_l0000:ooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0?ooooo`?o
00006_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Eooooo`00:Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0:?ooool3o`0000Wooooo00?o0000ooooooooool0
:oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
5_ooool002Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo02Wooooo0_l0000:ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Kooooo000Yooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Yooooo`;o00002_ooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Gooooo`00:Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01Oooooo000Yooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Aooooo`;o00000_ooool00ol0003oooooooooo`0Hooooo`00:Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0:_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04_ooool3o`0001_ooooo
000Zooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0:oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0`ooooo`00:_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02_ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0<?ooool002[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo02_ooooo0_l00009ooooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0<?ooool002[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo02_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo033ooooo000Zooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0`ooooo`00:_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo01?ooooo00Co0000oooooooooooo0000;oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0/ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo033ooooo000Zooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04ooo
ool4o`0002oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0/ooooo`;o00002?oo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo033ooooo000Zooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool05Oooool2o`00037ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0/ooooo`;o00002?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo037ooooo000Zooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0B?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo02cooooo0_l00008ooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0<Oooool002[ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`18ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;?ooool2o`0000So
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0aooooo`00:_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0]ooooo`;o00001oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo
000Zooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0B?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo02gooooo0_l00007ooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0<Oooool002[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`19
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;Oooool2o`0000Oooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0aooooo`00:_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo04Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0]oooo
o`;o00001oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo000Zooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo02gooooo0_l00007ooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0<Oooool002[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`19ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0;Oooool00ol0003oooooo`000006ooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0<Oooool002[ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`19ooooo`05o`000?ooooooooooooooool000009Oooool5o`0000Kooooo
00?o0000ooooool000001_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo
000[ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0B_ooool01?l0003ooooooooo
ool0000Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooo`000005ooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0<Oooool002_ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`1:ooooo`04o`000?ooooooooooo`0002Kooooo00?oV9RHob4Q8Oo^
k^h01oooool3o`0000Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0booooo`00
:oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04[ooooo0ol0000Xooooo`03oiRH
V?lQ8B7ok^k^00Kooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo03;ooooo000[ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0C?oo
ool2o`0002Wooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0<_ooool002_ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool000001Oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo03;ooooo000[ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0M?ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000
ooooool000001Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03;ooooo000[oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0M?ooool01OnHV9So410@o`000?lQ8B7o
c<c<00Kooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo03;ooooo000[ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Ooooool0
1?l0003oooooooooool00003ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<_oo
ool002_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1oooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0booooo`00:oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo07oooooo0_l000000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<_ooool002_ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`1oooooo`04o`000?ooooooooooo`0000?ooooo00?o0000
ooooooooool0<_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0booooo`00:oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo07oooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0b
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo03;ooooo000[ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0Ooooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0booooo`00:oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
07oooooo00Oo0000ooooooooooooooooo`000?oooooo000003Gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<ooo
ool002_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1oooooo`07o`000?oooooo
ooooooooool0003oooooo`00000eooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
<oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03?ooooo000[ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0Ooooool01ol0003ooooooooooooooooo0000ooooool0
0000=Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0cooooo`00:oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo07oooooo00?o0000ooooooooool00_ooool2o`0003Kooooo00Go0000oooooooooooo
ooooo`00000eooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0<oooool002_ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo03[ooooo
00Go0000ooooooooooooooooo`00000eooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0<oooool002cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`20ooooo`;o0000
>oooool01Ol0003ooooooooooooooooo000003Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0cooooo`00;?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo083ooooo
00?o0000ooooooooool0>_ooool01Ol0003ooooooooooooooooo000003Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0cooooo`00;?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo083ooooo00?o0000ooooooooool0>_ooool01Ol0003ooooooooooooooooo000003Go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0cooooo`00;?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool0>_ooool01Ol0003ooooo
oooooooooooo000003Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0cooooo`00
;?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool0
>_ooool01Ol0003ooooooooooooooooo000003Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0cooooo`00;?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo083ooooo
00?o0000ooooooooool0>_ooool01?l0003oooooooooool0000fooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0<oooool002cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`20ooooo`03o`000?oooooooooo03[ooooo00Co0000oooooooooooo0000=_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo03Cooooo000/ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0P?ooool00ol0003oooooooooo`0jooooo`04o`000?ooooooooooo`0003Oo
oooo00Go0000ooooooooooooooooo`00000fooooo`00;?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo083ooooo0_l0000kooooo`04o`000?ooooooooooo`0003Oooooo00Go0000oooo
ooooooooooooo`00000fooooo`00;?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
083ooooo00?o0000ooooooooool0>oooool00ol0003oooooo`00000gooooo`05o`000?oooooooooo
ooooool00000=_ooool002cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`20oooo
o`03o`000?oooooooooo03_ooooo0_l0000hooooo`05o`000?ooooooooooooooool00000=_ooool0
02cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo
03cooooo00?o0000ooooooooool0=_ooool01Ol0003ooooooooooooooooo000003Kooooo000/oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`1eoooo
o`05o`000?ooooooooooooooool00000=_ooool002gooooo00Go0000ooooooooooooooooo`00001j
ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`1eooooo`05o`000?oooooo
ooooooooool00000=_ooool002gooooo00Go0000ooooooooooooooooo`00001kooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0M_ooool01?l0003oooooooooool0000fooooo`00;Ooo
ool01Ol0003ooooooooooooooooo000007Sooooo1Ol00006ooooo`03o`000?oooooooooo07Kooooo
00Co0000oooooooooooo0000=_ooool002gooooo00Go0000ooooooooooooooooo`00001hooooo`04
odA4A?oMgMgoooooo`0000Oooooo0ol0001fooooo`04o`000?ooooooooooo`0003Kooooo000]oooo
o`05o`000?ooooooooooooooool00000N?ooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oo
oooooooo07Kooooo00?o0000ooooool00000=oooool002gooooo00Go0000ooooooooooooooooo`00
001iooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0M_ooool00ol0003oooooo`00
000gooooo`00;Oooool01Ol0003ooooooooooooooooo000007Wooooo00?ok^k^odA4A?l000001ooo
ool00ol0003oooooooooo`1fooooo`03o`000?oooooo000003Oooooo000]ooooo`05o`000?oooooo
ooooooooool00000N_ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo07Kooooo00?o
0000ooooool00000=oooool002gooooo00Go0000ooooooooooooooooo`000023ooooo`03o`000?oo
oooooooo07Kooooo00?o0000ooooool00000=oooool002gooooo00Go0000ooooooooooooooooo`00
0023ooooo`03o`000?oooooooooo07Kooooo00?o0000ooooool00000=oooool002kooooo00Co0000
oooooooooooo0000Poooool00ol0003oooooooooo`1gooooo`;o0000=oooool002kooooo00Co0000
oooooooooooo0000Poooool2o`000;7ooooo000^ooooo`04o`000?ooooooooooo`0008?ooooo00?o
0000ooooooooool0/?ooool002kooooo00Co0000oooooooooooo0000Poooool00ol0003ooooooooo
o`2`ooooo`00;_ooool01?l0003oooooooooool00023ooooo`03o`000?oooooooooo0;3ooooo000^
ooooo`04o`000?ooooooooooo`0008?ooooo00?o0000ooooooooool0/?ooool002kooooo00Co0000
oooooooooooo0000Poooool00ol0003oooooooooo`2`ooooo`00;_ooool00ol0003oooooo`000024
ooooo`03o`000?oooooooooo0;3ooooo000^ooooo`03o`000?oooooo000008Cooooo00?o0000oooo
ooooool0/?ooool002kooooo00?o0000ooooool00000Q?ooool2o`000;7ooooo000^ooooo`03o`00
0?oooooo000008Cooooo00?o0000ooooooooool0/?ooool002oooooo0_l00024ooooo`03o`000?oo
oooooooo0;3ooooo000_ooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00Z_ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000
ooooooooool0/?ooool00:[ooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooo
oooo0;3ooooo002Zooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`2`
ooooo`00Z_ooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0002`ooooo`00Z_ooool01Ol0
003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00?oEEEEohN7
Qoooool02?ooool00ol0003oooooooooo`2`ooooo`00Z_ooool00ooMgMgo410@oiRHV008ooooo`03
o`000?oooooooooo0;3ooooo002[ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo
00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05ob4Q
8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go<S8boiRHV?oooooo
V9RHoc8b<P06ooooo`?o0000/?ooool00:[ooooo00Goc<c<o`000?l0003o0000olc<c02iooooo`00
Z_ooool01Ol@413o^[Zjoooooonj^[[o410@0;Wooooo002Zooooo`05o`000?nj^[[ooooookZj^_l0
0000^Oooool00:[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2iooooo`00oooooomYooooo`00/ooo
ool00ol0003o^[Zjooooo`2booooo`00/oooool2oc8b<[?ooooo0024ooooo`;o000000Ko410@oooo
oooooooo410@o`000?l@410Hooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj
01[ooooo0_l000000ol@413oooooooooo`03ooooo`;o000000?o410@ooooooooool0N_ooool008Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00003Oooool02OmgMgOo
<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03olc<c?l0003o410@00cooooo00Go
410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo07_ooooo0025ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06ooo
ool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo013ooooo00?o0000ooooooooool0
6_ooool5o`0000?ooooo1Ol0001looooo`00QOooool01_l0003oooooodA4A?m4A4Coooooo`0000Wo
oooo1_l0000=ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00_ooooo1_l00009ooooo`04odA4A?oMgMgoooooo`0000Cooooo00CoA4A4
omgMgOoooooo0000OOooool008Gooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Iooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000oooo
ooooool06_ooool01?oMgMgoEEEEooooool00004ooooo`04omgMgOmEEEGoooooo`0007gooooo0025
ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo00006Oooool00ol0003oooooooooo`04ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol@413o0000o`000003o`0001[ooooo00?oMgMgolc<c?l0
00001Oooool00omgMgOoc<c<o`00001mooooo`00QOooool01_l0003o<S8boooooooooooo<S8bo`00
01Wooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000
ooooooooool06oooool00oo^k^koA4A4o`000005ooooo`03onk^k_m4A4Co000007gooooo0024oooo
o`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool4o`0000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Booooo`03o`000?oooooooooo01cooooo00?oMgMgo`000?ooool01Oooool0
0omgMgOo0000ooooo`1looooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(46) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .15261 m
.00488 .14419 L
.00942 .13803 L
.01441 .13277 L
.01975 .1286 L
.02244 .12705 L
.02385 .12639 L
.02535 .1258 L
.02666 .12536 L
.02811 .12497 L
.02942 .12469 L
.03065 .12449 L
.03193 .12434 L
.03314 .12426 L
.03424 .12424 L
.03543 .12427 L
.03672 .12438 L
.03809 .12459 L
.03939 .12489 L
.04057 .12525 L
.04189 .12577 L
.04334 .12648 L
.04627 .12841 L
.04898 .13083 L
.05151 .13371 L
.0545 .13806 L
.05722 .14323 L
.06037 .15107 L
.06335 .16091 L
.06594 .17176 L
.06869 .18608 L
.07363 .22054 L
.07894 .27236 L
.08481 .34383 L
.08748 .3764 L
.08997 .40294 L
.09133 .41491 L
.09257 .42379 L
.09394 .43114 L
.09469 .43397 L
.09541 .4358 L
.09658 .43705 L
.09783 .43594 L
.0989 .43306 L
.10007 .42796 L
.10133 .42041 L
.10268 .41023 L
.10512 .38769 L
.11063 .32928 L
.11365 .29966 L
Mistroke
.11649 .27606 L
.11914 .25823 L
.12202 .24336 L
.12462 .23337 L
.12702 .22675 L
.1283 .22411 L
.12949 .22216 L
.1308 .22053 L
.13153 .21984 L
.1322 .21934 L
.13354 .21868 L
.1343 .2185 L
.135 .21845 L
.13629 .21861 L
.13766 .2191 L
.13903 .21989 L
.14051 .22101 L
.14318 .22365 L
.14926 .23194 L
.15934 .24968 L
.16211 .25422 L
.16505 .25832 L
.16649 .25995 L
.16784 .26122 L
.16905 .26212 L
.17036 .26282 L
.17168 .26322 L
.1729 .26329 L
.17425 .26302 L
.17501 .26269 L
.1757 .26229 L
.17708 .26116 L
.17859 .25944 L
.18134 .25501 L
.18388 .24949 L
.18659 .24237 L
.19145 .22726 L
.20211 .19103 L
.20771 .17368 L
.21361 .15835 L
.2187 .14771 L
.22426 .1384 L
.22932 .1319 L
.23403 .12738 L
.23889 .12399 L
.24331 .12181 L
.24575 .12094 L
.24713 .12057 L
.2484 .1203 L
.24952 .12012 L
Mistroke
.25074 .11999 L
.25202 .11992 L
.25322 .11993 L
.25453 .12 L
.25526 .12007 L
.25592 .12015 L
.25722 .12036 L
.25844 .12061 L
.26117 .12139 L
.26271 .12197 L
.26413 .1226 L
.26917 .12568 L
.27171 .12781 L
.27449 .13062 L
.27935 .13677 L
.28456 .14533 L
.29395 .16693 L
.30405 .19807 L
.31477 .23319 L
.32036 .24795 L
.32354 .25437 L
.32653 .259 L
.32926 .26212 L
.33176 .26416 L
.33307 .26496 L
.33451 .26564 L
.33601 .26616 L
.33668 .26635 L
.3374 .26651 L
.33876 .26673 L
.34002 .26686 L
.34137 .26692 L
.34214 .26693 L
.34286 .26692 L
.34416 .26687 L
.34534 .26679 L
.34671 .26665 L
.34801 .26647 L
.34917 .26626 L
.3504 .26598 L
.35262 .26528 L
.35398 .26469 L
.35526 .264 L
.35764 .26227 L
.36028 .25958 L
.36306 .25572 L
.36804 .24608 L
.37339 .2321 L
.37926 .21379 L
.38982 .17989 L
Mistroke
.3998 .15413 L
.40532 .14348 L
.41131 .13475 L
.41675 .12896 L
.41938 .12677 L
.42178 .12506 L
.42412 .12365 L
.42667 .1224 L
.42936 .12137 L
.43071 .12097 L
.43192 .12066 L
.43307 .12042 L
.43431 .12021 L
.43562 .12004 L
.43685 .11993 L
.43801 .11987 L
.43924 .11986 L
.44028 .11988 L
.44143 .11995 L
.44213 .12001 L
.44288 .1201 L
.44426 .12031 L
.4456 .12059 L
.44684 .12092 L
.44964 .12191 L
.45263 .12338 L
.45519 .12501 L
.4576 .1269 L
.46044 .12962 L
.46309 .13274 L
.46801 .14041 L
.4734 .15235 L
.47865 .16837 L
.48427 .19105 L
.49437 .24468 L
.49881 .2692 L
.50369 .2916 L
.50499 .2962 L
.50639 .30036 L
.50771 .30348 L
.50891 .30563 L
.51027 .30723 L
.51104 .30774 L
.51175 .30798 L
.51305 .30781 L
.51444 .30684 L
.51523 .30594 L
.51596 .30492 L
.51759 .30198 L
.52056 .29496 L
Mistroke
.5261 .27943 L
.52867 .27265 L
.53142 .26637 L
.53398 .26168 L
.53639 .25828 L
.53769 .25684 L
.5391 .25557 L
.54157 .25393 L
.543 .25324 L
.54452 .25265 L
.54725 .25173 L
.54976 .25073 L
.55102 .25007 L
.5524 .24916 L
.55484 .24695 L
.55711 .2441 L
.5598 .23962 L
.56225 .23455 L
.56773 .22024 L
.57706 .19109 L
.58693 .16275 L
.59194 .15154 L
.59744 .14179 L
.60244 .13504 L
.60711 .1304 L
.60994 .12828 L
.61262 .12665 L
.61505 .12545 L
.61765 .12443 L
.61898 .124 L
.62046 .1236 L
.62181 .12331 L
.62306 .1231 L
.62377 .12301 L
.62452 .12293 L
.62528 .12287 L
.6261 .12283 L
.62681 .12281 L
.62758 .12281 L
.62896 .12286 L
.63025 .12296 L
.63098 .12304 L
.63167 .12313 L
.63317 .12337 L
.63454 .12363 L
.63702 .12425 L
.63969 .12514 L
.64254 .1264 L
.64566 .12825 L
.6486 .13053 L
Mistroke
.65133 .13316 L
.6541 .13643 L
.6567 .14018 L
.66157 .14956 L
.6643 .15659 L
.66681 .16448 L
.67248 .18826 L
.67742 .21676 L
.68271 .2554 L
.68728 .2927 L
.69225 .32996 L
.69372 .33883 L
.69528 .34666 L
.69661 .35185 L
.69737 .35414 L
.69808 .35584 L
.69947 .35784 L
.70074 .35815 L
.70141 .35774 L
.70214 .35684 L
.7029 .35543 L
.7036 .35369 L
.70495 .34933 L
.70623 .34408 L
.70861 .3319 L
.71395 .29889 L
.71923 .2683 L
.72181 .25645 L
.72416 .24786 L
.72665 .24115 L
.72801 .23844 L
.72931 .23649 L
.72999 .23568 L
.73072 .23499 L
.73202 .23415 L
.73282 .23387 L
.73357 .23375 L
.73424 .23377 L
.73497 .2339 L
.73619 .23436 L
.73732 .23502 L
.73856 .23596 L
.73989 .23716 L
.74255 .2399 L
.74507 .24249 L
.7474 .24449 L
.74871 .24533 L
.74993 .24587 L
.75095 .24612 L
.75207 .24615 L
Mistroke
.75325 .24591 L
.75435 .24541 L
.75565 .24446 L
.75638 .24376 L
.75705 .24302 L
.75955 .23933 L
.76248 .23338 L
.76524 .22638 L
.77559 .19379 L
.78486 .16628 L
.78977 .15473 L
.79503 .14484 L
.80033 .13734 L
.80527 .1323 L
.80818 .13007 L
.81093 .12837 L
.81344 .12713 L
.8161 .12611 L
.81839 .12548 L
.81969 .12522 L
.82092 .12504 L
.82204 .12494 L
.82306 .12489 L
.82419 .12488 L
.82538 .12492 L
.82659 .12501 L
.82788 .12516 L
.8291 .12536 L
.83021 .12557 L
.83292 .12628 L
.83549 .12721 L
.83799 .12841 L
.84034 .12984 L
.84313 .132 L
.84568 .13446 L
.85089 .14119 L
.85376 .1462 L
.85648 .15214 L
.85881 .15837 L
.86129 .16643 L
.86575 .18541 L
.87105 .21722 L
.87585 .25608 L
.88569 .35335 L
.88808 .37344 L
.8894 .38254 L
.89065 .38957 L
.89135 .3928 L
.89212 .39566 L
.89346 .39893 L
Mistroke
.89482 .39996 L
.89608 .39884 L
.89744 .39547 L
.89871 .39041 L
.9001 .38296 L
.90161 .37304 L
.90747 .32365 L
.9129 .27829 L
.91555 .26017 L
.91795 .24661 L
.92045 .23541 L
.92282 .22748 L
.92411 .22415 L
.92531 .22168 L
.92662 .2196 L
.92729 .21879 L
.92801 .21807 L
.92875 .21753 L
.92945 .21718 L
.93075 .21692 L
.93149 .21699 L
.93216 .21718 L
.93291 .21753 L
.9337 .21804 L
.93514 .21933 L
.93649 .2209 L
.93901 .22461 L
.9446 .23497 L
.9498 .24474 L
.95242 .24874 L
.95377 .25037 L
.95523 .25176 L
.95606 .25236 L
.95683 .25277 L
.95756 .25304 L
.95834 .25318 L
.95969 .25308 L
.96046 .25282 L
.96118 .25244 L
.96242 .25149 L
.96379 .25 L
.96627 .24619 L
.96868 .24122 L
.97093 .23565 L
.98142 .20278 L
1 .15261 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
001Tooooo`Ko0000=?ooool7o`00013ooooo00?o0000ooooooooool0/?ooool001oooooo1?l0000n
ooooo`?o00001Oooool2o`0003;ooooo0_l00006ooooo`;o00003_ooool00ol0003oooooooooo`0R
ooooo`So0000Q_ooool001gooooo0ol00002ooooo`;o0000??ooool00ol0003oooooooooo`08oooo
o`;o0000;_ooool2o`0000[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Qoooo
o`;o00001_ooool2o`0003Kooooo2?l00017ooooo`006oooool2o`0000Oooooo0_l0000jooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00[ooooo0_l0000Pooooo`;o00002_ooool2o`0003;ooooo0_l00007ooooo`;o
0000A_ooool001[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo02gooooo0_l0000;ooooo`03o`000?oooooooooo04?ooooo000Jooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0@_ooool001Wooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`11ooooo`006?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
043ooooo000Gooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0?oooool001Oooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0oooooo`005_ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool04Oooool002Wooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`06ooooo`;o00006oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo017ooooo000Zooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool04_ooool002[ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Booooo`00
5Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00[ooooo00?o0000
ooooooooool03Oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0Booooo`03o`000?oooooooooo00Kooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool00ol0003oooooooooo`0Fooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o
<S8bonk^kQKooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1oooool00ol0
003oooooooooo`0@ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000
ooooooooool04_ooool01OnHV9So410@o`000?l0003oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0Mooooo`;o000000Wo410@ooooool0003oooooonk^k_lb<S;o0000oc8b<_o^k^h03_ooool0
01Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000
ooooooooool03?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0Booooo`03o`000?oooooooooo00Kooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?l0003oV9RHogMgM`0Gooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`07ooooo`03o`000?oooooooooo013ooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0Booooo`05
oa0@4?nj^[[oooooo`000?lb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000
ooooool000000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03o`000?oooooooooo00Cooooo1_l0
0006ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0@ooooo`Oo0000
0oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41001?ooool00ol0003o
ooooooooo`0<ooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?l0003ooooooooo
ool@41005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001oooool0
0ol0003oooooooooo`0Aooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
4006ooooo`03o`000?oooooooooo01Gooooo0_l00003ooooo`05oa0@4?ooooooooooooooool@4100
6oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400>ooooo`004oooool01?m4A4CogMgM
ooooool00004ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`0?oooo
o`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Aooooo`03o`000?oooooo
oooo00Wooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000Cooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`02ooooo`;o00000_ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`00
0?oooooooooo017ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000Go
oooo00?o0000ooooooooool05_ooool00ol0003o410@ooooo`02ooooo`05o`000?oooooooooooooo
ool000006oooool01_m4A4CogMgMooooool0003oooooo`0000;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`004oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00002oooool00ol0003oooooooooo`0>ooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000oooooooo
ooooooooo`00000Aooooo`03o`000?oooooooooo00[ooooo00?oMgMgofIVI_ooool00_ooool01Ol0
003ooooooooooooooooo000000Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`02
ooooo`;o00000_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000008ooooo`03o`000?oooooooooo01;ooooo00?oMgMgofIVI_ooool00_oo
ool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool05Oooool00ol@413o0000
okZj^P03ooooo`05o`000?ooooooooooooooool000006oooool00ooMgMgoEEEEooooo`02o`0000?o
oooo00Go0000ooooooooooooooooo`00000>ooooo`005?ooool00omgMgOoc<c<o`000004ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0>ooooo`03okZj^_lQ8B7ooooo
00;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00cooooo00Go0000
oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00?ooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool@41006?ooool00ol0003ooooo
ooooo`03ooooo`;o00006?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo01?ooooo00Go0000oooooooo
oooooooooa0@4003ooooo`03oa0@4?oooooooooo00?ooooo00?o0000ooooooooool05_ooool00onj
^[[o0000ooooo`02ooooo`05oa0@4?ooooooooooooooool@41007?ooool01?mgMgOoc<c<o`000?l0
0003ooooo`05oa0@4?ooooooooooooooool@41003_ooool001Cooooo00?ok^k^odA4A?l000001?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool02oooool01Ol@413oV9RH
oooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0@ooooo`03o`000?oooooooooo
00Sooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo00Go0000oiRHV?ooooooV9RH
ogMgM`0Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03
o`000?oooooooooo00oooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01?ooool00ol0003oooooooooo`0Dooooo`05oa0@4?nHV9SooooookZj^_l000000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00kooooo000Eooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`03o`000?oooooooooo00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h04?ooool00ol0003oooooooooo`08ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0
4oooool00omEEEGoIVIVo`000003ooooo`06o`000?o^k^ko<S8bo`000?lb<S;ok^k^6?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01_ooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02Oooool00ol0003oooooooooo`0>
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo
00?o0000ooooooooool05?ooool01OnYZJWo410@o`000?l@413o000000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0Mooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>
ooooo`00;?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01Gooooo000/ooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool05_ooool002cooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`0Fooooo`00;?ooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo01Kooooo000/ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool05oooool0
01Koooooool00010o`0001?ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0
003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool04Oooool001Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Co
oooo0_l00007ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool2o`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`0Aoooo
o`00;Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Pooooo`05o`000?ooooooooooooooool000005Oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo01Sooooo000]ooooo`03o`000?oooooooooo013o
oooo0_l0000Booooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Pooooo`05o`000?ooooooooooooooool000005?ooool00ol0003oooooooooo`0Poooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0?oooo
o`?o00003Oooool00ol0003oooooooooo`0Hooooo`00;Oooool00ol0003oooooooooo`0?ooooo`;o
000000?oooooo`000?ooool04?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool08Oooool01?l0003oooooooooool0000Dooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
00kooooo0_l000000ooooooo0000o`00000;ooooo`03o`000?oooooooooo01Wooooo000]ooooo`03
o`000?oooooooooo00oooooo00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Qooooo`04o`000?oooooooooo
o`0001Cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool06Oooool002gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooooooo00005?ooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Iooooo`00;Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool08_ooool01?l0003oooooooooool0000Cooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo01Wooooo000]ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo00;o00004_ooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo00kooooo0_l00007ooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool06_ooool002kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo02;ooooo00Co0000oooooooooooo00004oooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo00gooooo00Co0000ooooool0003o00001_ooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo01[ooooo000^ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo000001;ooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01[ooooo000^ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooo0000017ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00000Tooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01_ooooo000^ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooo0000013ooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo0ol0000Uooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01co
oooo000^ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooo000000oooooo0_l0000Xooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo
00Go0000ooooooooooooooooo`00000Nooooo`00;_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool09_ooool00ol0003oooooo`00000=ooooo`?o0000
:Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`?o00007oooool002kooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooool000002ooo
ool2o`0002cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0;?ooool002kooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Wooooo0ol00009ooooo`;o0000;Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0/ooooo`00;oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00cooooo1?l0000`ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0:Oooool2o`00
00[ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0/ooooo`00;oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00gooooo0_l0000aooooo`?o00000oooool3o`0002co
oooo0_l0000:ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0;?ooool002oooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`12ooooo`Go0000;_ooool2o`0000Wooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02oooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0/ooooo`00;oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo07Kooooo0_l00009ooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0;Oooool002oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1f
ooooo`;o00002?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02gooooo000_oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0;Oooool002oooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0]ooooo`00;oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo07Oooooo0_l00006ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
;Oooool002oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1gooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0]ooooo`00;oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo07Sooooo0_l00005ooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0;Oooool0033ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`1hooooo`;o00001Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
02gooooo000`ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0N?ooool2o`0000Co
oooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0]ooooo`00<?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooool000000oooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo02gooooo000`ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0KOooool5o`0000Kooooo00?o0000ooooool000000_ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo02kooooo000`ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0KOooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool00ol0
000fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo02kooooo000`ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0K_ooool00onHV9So8B4Qonk^kP07ooooo`Go0000=oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0^
ooooo`00<?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo06oooooo00?oV9RHob4Q
8Oo^k^h01_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0=?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02kooooo000`ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0L?ooool00omgMgOoIVIVooooo`05ooooo`03
o`000?oooooooooo03[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0;_ooool0033ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
>_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0^ooooo`00<?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo06kooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo03[ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0;_ooool0033ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`1^ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0jooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo02kooooo000aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0NOoo
ool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02kooooo000aooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`0jooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo02kooooo000aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0NOooool2o`00
03_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0;_ooool0037ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`1iooooo`03o`000?oooooooooo03_ooooo00Go0000ooooooooooooooooo`00000goooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;_ooool0037ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo03_ooooo00Go0000oooooooo
ooooooooo`00000hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;oooool0037o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo03_o
oooo00Go0000ooooooooooooooooo`00000hooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0;oooool0037ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1jooooo`03
o`000?oooooooooo03_ooooo00Go0000ooooooooooooooooo`00000hooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0;oooool0037ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`1jooooo`03o`000?oooooooooo03_ooooo00Co0000oooooooooooo0000>Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo02oooooo000aooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0kooooo`04o`000?ooooooooooo`00
03Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0_ooooo`00<Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0??ooool2o`0003[o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0_ooooo`00<Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0??ooool2o`0003[ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0_ooooo`00<_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo07[ooooo0_l0001iooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0;oooool003;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1j
ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0`
ooooo`00<_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07[ooooo00?o0000oooo
ooooool0N?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo033ooooo000booooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`1hooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0<?ooool003;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0`ooooo`00<_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo07_ooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo033ooooo000booooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Noooool0
0ol0003oooooooooo`1iooooo`04o`000?ooooooooooo`0003?ooooo000booooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`1iooooo`04o`000?oooooo
ooooo`0003?ooooo000booooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Noooool2
o`0007[ooooo00Co0000oooooooooooo0000<oooool003;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1kooooo`03o`000?oooooooooo07Wooooo00Co0000oooooooooooo0000<ooo
ool003;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1kooooo`03o`000?oooooo
oooo07Wooooo00Co0000oooooooooooo0000<oooool003;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1kooooo`03o`000?oooooooooo07[ooooo0_l0000dooooo`00<_ooool01Ol0
003ooooooooooooooooo000007kooooo00?o0000ooooooooool0N_ooool2o`0003Cooooo000boooo
o`05o`000?ooooooooooooooool00000MOooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000
ooooooooool0/?ooool003;ooooo00Go0000ooooooooooooooooo`00001fooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0/?ooool003;ooooo00Go0000ooooooooooooooooo`00001c
ooooo`Go00001_ooool00ol0003oooooooooo`2`ooooo`00<oooool01?l0003oooooooooool0001c
ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00<oooool01?l0003oooooooooool0
001cooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0/?ooool003?ooooo00Co
0000oooooooooooo0000M?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo0;3ooooo
000cooooo`04o`000?ooooooooooo`0007Cooooo00?ok^k^odA4A?l000001oooool00ol0003ooooo
ooooo`2`ooooo`00<oooool01?l0003oooooooooool0001eooooo`03ogMgMol0003ooooo00Kooooo
00?o0000ooooooooool0/?ooool003?ooooo00Co0000oooooooooooo0000O_ooool00ol0003ooooo
ooooo`2`ooooo`00=?ooool00ol0003oooooo`00001nooooo`03o`000?oooooooooo0;3ooooo000d
ooooo`;o0000Ooooool00ol0003oooooooooo`2`ooooo`00=?ooool2o`0007oooooo0_l0002aoooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00:[ooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0;3o
oooo002Zooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00
Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo
00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000/?ooool00:[ooooo00Go0000oeEEEOl0003o
410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03oeEEEOn7QhOooooo00Sooooo
00?o0000ooooooooool0/?ooool00:[ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003ooooooooo
o`2`ooooo`00Zoooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aoooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05olc<c?lQ8B7o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OlQ8B7oV9RHoooooonH
V9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_oo
ool3o`000;3ooooo002Zooooo`05olc<c?l0003o0000o`000?o<c<`0^Oooool00:[ooooo00Go410@
okZj^_oooooo^[Zjoa0@402iooooo`00Z_ooool01Ol0003o^[Zjoooooonj^[[o00000;Wooooo002Z
ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0^Oooool00?ooooooJOooool00;?ooooo00?o0000okZj
^_ooool0/_ooool00;?ooooo0_lb<S:cooooo`00Q?ooool2o`000006oa0@4?oooooooooooa0@4?l0
003o410@6?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Jooooo`;o0000
00Wo410@ooooooooooooooooonk^k_lb<S;o0000oa0@4?o<c<`0O?ooool008Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00003Oooool02OmgMgOo<S8boooooooooooo
MgMgoiRHV?ooooooV9RHogMgM`03ooooo`03olc<c?l0003o410@00cooooo00Go410@okZj^_o^k^ko
MgMgoa0@4009ooooo`Ko00003?ooool00ol0003oooooooooo`02ooooo`05oeEEEOmgMgOooooooiRH
V?lQ8B40O?ooool008Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Kooooo`04
o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool04?ooool00ol0003oooooooooo`0Joooo
o`Go00000oooool01Ol0003ooooooooooooooooo000007cooooo0025ooooo`06o`000?ooooooA4A4
odA4A?oooooo00002Oooool6o`0000gooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool02oooool6o`0000Wooooo00CoA4A4omgMgOoooooo
00001?ooool01Ol0003oV9RHoooooonHV9So8B4Q07cooooo0025ooooo`06o`000?oMgMgo<S8boeEE
EOoMgMgo00006Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooooooooooooooo
o`00000Booooo`03o`000?oooooooooo01[ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003o
EEEEo`000?l@413oc<c<07cooooo0025ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo00006Oooool0
0ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol@413o0000o`00
0003o`0001[ooooo00?oMgMgolc<c?l000001?ooool00omEEEGoQhN7ooooo`1nooooo`00QOooool0
1_l0003o<S8boooooooooooo<S8bo`0001Wooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg01;ooooo00?o0000ooooooooool06oooool00oo^k^koA4A4o`000004ooooo`03
omgMgOl@413oV9RH07kooooo0024ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@4100
6?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Booooo`03o`000?oooooooooo01co
oooo00?oMgMgo`000?ooool01?ooool01?o<c<coA4A4o`000?l@411looooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(48) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .12761 m
.00123 .12729 L
.00236 .12709 L
.00365 .12694 L
.00488 .1269 L
.00601 .12694 L
.00706 .12703 L
.00821 .1272 L
.00942 .12744 L
.01196 .12817 L
.01434 .12909 L
.01975 .132 L
.02499 .13579 L
.02978 .13993 L
.04057 .15048 L
.06172 .16876 L
.06751 .17285 L
.0707 .1754 L
.07369 .17831 L
.07649 .18175 L
.07952 .18664 L
.08228 .19252 L
.08481 .19946 L
.10469 .32301 L
.10748 .34547 L
.11013 .36388 L
.11159 .37219 L
.11318 .37935 L
.11389 .38182 L
.11463 .38395 L
.11597 .38648 L
.11721 .38731 L
.11855 .38658 L
.11982 .38442 L
.12098 .38127 L
.12226 .37663 L
.12367 .37037 L
.1265 .35519 L
.13184 .32471 L
.13447 .31234 L
.13689 .30376 L
.13824 .30032 L
.13893 .29897 L
.13968 .29779 L
.14043 .29691 L
.14124 .29632 L
.142 .29607 L
.1427 .29611 L
.144 .29681 L
.14473 .29754 L
Mistroke
.14541 .29843 L
.14666 .3005 L
.14798 .30326 L
.15338 .31735 L
.15467 .32056 L
.15603 .32353 L
.1572 .32558 L
.15847 .32719 L
.15961 .32797 L
.16083 .32804 L
.16198 .32732 L
.16303 .32595 L
.16425 .32353 L
.16557 .31987 L
.16796 .31064 L
.17779 .25023 L
.18294 .21598 L
.18836 .1854 L
.19125 .17205 L
.19442 .15985 L
.19996 .14383 L
.20269 .13806 L
.2056 .13315 L
.20835 .12954 L
.21084 .127 L
.21342 .12501 L
.21472 .12423 L
.21615 .12353 L
.21737 .12306 L
.21868 .12267 L
.21992 .1224 L
.22104 .12224 L
.22173 .12218 L
.22245 .12215 L
.22376 .12216 L
.22448 .12221 L
.22516 .12229 L
.22591 .12239 L
.22671 .12254 L
.22808 .12288 L
.22952 .12333 L
.23209 .12442 L
.23448 .12574 L
.23704 .12748 L
.24165 .13143 L
.25213 .14417 L
.26226 .1606 L
.27301 .17815 L
.27862 .18517 L
.28015 .18665 L
Mistroke
.28181 .18801 L
.28323 .18897 L
.28479 .18981 L
.28552 .19012 L
.2863 .1904 L
.28698 .19059 L
.2877 .19076 L
.28845 .19089 L
.28915 .19097 L
.29047 .19102 L
.29179 .19095 L
.29245 .19087 L
.29318 .19076 L
.29446 .19051 L
.29566 .19022 L
.29827 .18947 L
.29965 .18907 L
.30111 .18867 L
.30238 .18839 L
.3031 .18826 L
.30378 .18817 L
.30497 .18809 L
.30626 .18814 L
.30743 .18834 L
.30871 .18875 L
.31005 .18943 L
.3113 .19031 L
.31247 .19139 L
.31353 .19259 L
.31591 .19614 L
.3187 .20195 L
.32127 .20901 L
.32708 .23123 L
.33216 .25656 L
.33761 .285 L
.34034 .29709 L
.34169 .30199 L
.34294 .30573 L
.34406 .30838 L
.34526 .31037 L
.3466 .31149 L
.3478 .3115 L
.34903 .3105 L
.35016 .30869 L
.3514 .30574 L
.35271 .30161 L
.35491 .29252 L
.35733 .28004 L
.36868 .20971 L
.37405 .18167 L
Mistroke
.37901 .1617 L
.38407 .14676 L
.38673 .14078 L
.38956 .13563 L
.39431 .1292 L
.39701 .12654 L
.39955 .12456 L
.40238 .12287 L
.40378 .12222 L
.40507 .12171 L
.40634 .1213 L
.40749 .121 L
.40877 .12073 L
.41013 .12053 L
.41085 .12046 L
.4116 .1204 L
.41295 .12036 L
.4137 .12036 L
.4144 .12039 L
.41517 .12044 L
.416 .12051 L
.41671 .1206 L
.41748 .12072 L
.41889 .12098 L
.42153 .12169 L
.42397 .1226 L
.42661 .12387 L
.43139 .127 L
.43707 .13228 L
.44228 .13885 L
.44741 .14721 L
.45302 .15858 L
.46433 .18676 L
.46988 .20085 L
.4726 .20704 L
.47512 .21204 L
.47736 .21578 L
.47982 .21903 L
.4811 .22034 L
.48229 .22132 L
.48356 .22212 L
.48492 .2227 L
.48562 .2229 L
.48638 .22303 L
.48774 .22308 L
.48857 .223 L
.48935 .22286 L
.49005 .22269 L
.49081 .22245 L
.49373 .2212 L
Mistroke
.49641 .21989 L
.49758 .21938 L
.49885 .21893 L
.50023 .2186 L
.50152 .21851 L
.50221 .21856 L
.50297 .21871 L
.50434 .21926 L
.50568 .22016 L
.50691 .22137 L
.50815 .22297 L
.50946 .22511 L
.51179 .23016 L
.5143 .23746 L
.51704 .24767 L
.52654 .29579 L
.52933 .30993 L
.53197 .32094 L
.53342 .32557 L
.53419 .32751 L
.535 .32914 L
.53568 .33017 L
.53644 .33093 L
.53776 .33126 L
.53912 .33024 L
.54036 .3281 L
.54104 .32644 L
.54179 .32425 L
.54315 .31931 L
.54576 .30666 L
.54818 .29209 L
.55759 .22709 L
.56254 .19746 L
.56775 .17317 L
.57052 .16309 L
.57356 .15407 L
.57889 .1425 L
.58151 .13841 L
.58431 .13493 L
.58672 .13255 L
.58937 .13048 L
.59207 .12884 L
.59495 .12756 L
.59761 .12669 L
.6001 .12613 L
.6016 .12588 L
.60303 .1257 L
.60431 .12558 L
.60503 .12553 L
.60571 .1255 L
Mistroke
.6065 .12547 L
.60724 .12545 L
.60791 .12545 L
.60863 .12546 L
.60942 .12547 L
.61025 .12551 L
.61096 .12555 L
.61174 .1256 L
.61316 .12573 L
.6145 .12589 L
.61702 .12627 L
.61973 .12683 L
.62268 .12762 L
.62525 .12847 L
.62798 .12959 L
.63289 .13225 L
.63539 .134 L
.63803 .1362 L
.64273 .14122 L
.6478 .14857 L
.65334 .15949 L
.65815 .17179 L
.66329 .18791 L
.67254 .22222 L
.67776 .24108 L
.68062 .24989 L
.6833 .25666 L
.68481 .25975 L
.68619 .26207 L
.68772 .26408 L
.68856 .26494 L
.68936 .26559 L
.69075 .26636 L
.69204 .26669 L
.69278 .26674 L
.69345 .26669 L
.69423 .26655 L
.69496 .26634 L
.69991 .26382 L
.70111 .2632 L
.7024 .26266 L
.70314 .26244 L
.70381 .2623 L
.70513 .26226 L
.70586 .26239 L
.70654 .26261 L
.70728 .26298 L
.70807 .26353 L
.7094 .26483 L
.71086 .26687 L
Mistroke
.71216 .26925 L
.71357 .27243 L
.71612 .27977 L
.72125 .2997 L
.72671 .32331 L
.72833 .32932 L
.72986 .33408 L
.73123 .33741 L
.732 .33882 L
.73271 .33981 L
.73401 .34077 L
.73474 .34081 L
.73542 .34052 L
.73681 .3389 L
.73758 .3374 L
.73829 .33566 L
.73959 .33155 L
.74098 .32596 L
.74347 .31315 L
.74912 .27543 L
.75447 .23702 L
.75938 .20583 L
.76416 .18148 L
.7692 .1624 L
.77182 .15486 L
.77426 .14909 L
.77711 .14367 L
.7798 .13966 L
.78213 .13691 L
.78466 .13458 L
.78696 .13296 L
.78908 .13183 L
.79137 .13096 L
.79267 .13061 L
.79389 .13036 L
.79517 .13018 L
.79635 .13008 L
.7977 .13003 L
.79899 .13004 L
.8003 .13012 L
.80104 .13018 L
.80171 .13025 L
.80428 .13063 L
.80661 .13112 L
.80907 .13175 L
.81981 .13549 L
.82991 .13967 L
.83912 .14407 L
.8439 .14683 L
.84909 .15065 L
Mistroke
.85194 .15332 L
.85457 .15629 L
.85976 .16397 L
.8642 .17315 L
.8691 .18701 L
.87422 .2065 L
.87902 .22958 L
.88936 .28765 L
.89187 .30043 L
.89455 .31195 L
.8961 .31728 L
.8975 .32121 L
.89817 .32277 L
.89891 .32421 L
.90023 .32617 L
.90144 .32721 L
.90258 .32758 L
.90382 .32735 L
.90515 .32642 L
.90582 .32572 L
.90654 .32481 L
.90787 .32278 L
.91035 .31811 L
.91967 .303 L
.93124 .31571 L
.934 .32214 L
.93551 .32539 L
.93691 .32801 L
.93811 .3298 L
.9394 .33115 L
.94013 .33162 L
.94082 .33184 L
.94212 .33162 L
.9433 .33066 L
.94455 .32881 L
.94562 .32654 L
.9468 .32331 L
.94943 .31346 L
.95189 .3013 L
.96243 .23399 L
.96687 .2071 L
.97171 .18258 L
.97628 .1645 L
.98053 .1518 L
.98545 .14124 L
.9882 .13694 L
.9907 .13385 L
.993 .1316 L
.99549 .12973 L
.99663 .12904 L
Mistroke
.99784 .12843 L
1 .12761 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002Gooooo`Ko00006?ooool00ol0003oooooooooo`2`ooooo`00F_ooool7o`0003Cooooo0_l00006
ooooo`;o00005_ooool00ol0003oooooooooo`2`ooooo`005_ooool4o`0003oooooo0_l00005oooo
o`;o0000<_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool06oooool:o`0007Oooooo00?o0000ooooooooool04Oooool001Wooooo0ol0000looooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo01;ooooo0_l0000Jooooo`;o00002_ooool2o`0003?ooooo1Ol0000looooo`03
o`000?oooooooooo01;ooooo000Looooo`;o0000>Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo02gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool03?ooool2o`0002oooooo0_l00005ooooo`?o0000
=oooool2o`0001Gooooo000Nooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0:ooo
ool2o`0000Wooooo1?l0000booooo`03o`000?oooooooooo01Gooooo000Oooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0=ooooo`;o0000<?ooool0
0ol0003oooooooooo`0Eooooo`008?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
01Kooooo000Qooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`0Aooooo`;o0000;?ooool00ol0003oooooooooo`0Fooooo`008_ooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo01Oooooo000Sooooo`;o0000<?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`0Gooooo`009Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00gooooo0_l0000E
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool05oooool002Kooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0Gooooo`009oooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo01Sooooo000Eooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h02?ooool00ol0003oooooooooo`0?ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?o0000ooooooooool02oooool5o`0000;ooooo
00Ko0000onk^k_lb<S;o0000oc8b<_o^k^hLooooo`Co000000So410@ooooooooooook^k^oc8b<_l0
003o<S8bonk^kQ3ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo00Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool0
0ol0003oooooooooo`0Dooooo`Go00000oooool01oo^k^ko<S8bo`000?lb<S;ok^k^ooooool00000
6Oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Koooo
o`05o`000?oooooo0000o`000?l@41000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000F
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`09ooooo`03o`000?oo
oooooooo00kooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03Oooool00ol0003oooooooooo`0;ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01Ol0
003oV9RHoooooonHV9SoMgMg01kooooo0_l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003ooooo
ooooo`0Cooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01omgMgOoV9RHoooooonHV9SoMgMg
ooooool000006Oooool01Ol@413o^[Zjo`000?mgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0Kooooo`04o`000?ooooooooooo`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>oooo
o`002oooool6o`0000;ooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41002_ooool00ol0
003oooooooooo`05ooooo`Ko00001_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@
ooooooooool02_ooool00ol0003oooooooooo`04ooooo`Ko00000oooool00onHV9So8B4Qonk^kP04
ooooo`05oa0@4?l0003oooooooooool@41004oooool6o`0000Gooooo0_l00003ooooo`05oa0@4?oo
ooooooooooooool@41004Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001?ooool00ol0003oooooooooo`0Dooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Ko410@oooooooo
oooooooooa0@4?l0000Mooooo`;o00000oooool01Ol@413ooooooooooooooooo410@01[ooooo1_l0
0003ooooo`05oa0@4?ooooooooooooooool@41003_ooool001?ooooo00CoA4A4omgMgOoooooo0000
1?ooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000ooooooooool03oooool00onYZJWo
410@ooooo`02ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003oooooooooo`0>oooo
o`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooool0003oooooo`00000Nooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`00000Aooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo01Gooooo00?oV9RHob4Q8Oo^k^h0
0oooool01?l0003oooooooooooooool2o`0001gooooo00?oZJVYo`000?ooool00_ooool01Ol0003o
oooooooooooooooo000001[ooooo00Go0000odA4A?oMgMgoooooo`000004ooooo`05o`000?oooooo
ooooooooool000003_ooool001?ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooo
oooooooo000000cooooo00?o0000ooooooooool03Oooool00ol@413o0000okZj^P03ooooo`05o`00
0?ooooooooooooooool000003?ooool00ol0003oooooooooo`0?ooooo`03ogMgMomVIVKooooo00;o
oooo00?o0000ooooooooool00_l0000Nooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`00000Aooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000005
ooooo`03o`000?oooooooooo01Gooooo00?oMgMgofIVI_ooool00_ooool01?l0003ooooooooooooo
ool2o`0001cooooo00?o410@o`000?l000000oooool01Ol0003ooooooooooooooooo000001[ooooo
00Go0000omgMgOmEEEGoooooo`000004ooooo`05o`000?ooooooooooooooool000003_ooool001Co
oooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00gooooo00?o0000oooo
ooooool03Oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`0@ooooo`05o`000?ooooooooooooooool@41000_ooool00ol0003o410@oooo
o`0Mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Booooo`03o`00
0?oooooooooo00Wooooo0_l0000Cooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool05_ooool01Ol0003o
oooooooooooooooo410@00?ooooo00?o0000ooooooooool07?ooool00onj^[[o0000ooooo`02oooo
o`05oa0@4?ooooooooooooooool@41006Oooool01_l0003ooooooooooomgMgOoc<c<o`0000Cooooo
00Go410@oooooooooooooooooa0@400>ooooo`005?ooool00oo^k^koA4A4o`000004ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`09ooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000ooooooooool03Oooool0
1Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHo`00000Nooooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Booooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo01;ooooo00Go0000okZj
^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?l000006oooool01?l@413oV9RHoooo
oonj^[X2o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Iooooo`06o`000?ooooooooooonk^
k_m4A4Co00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000Eooooo`03ogMgMol0003o
oooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0?ooooo`03o`000?oooooooooo00Sooooo00Go
ZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool00ol0003o
ooooooooo`0=ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01?o^k^ko<S8bo`000?lb<S82
o`0001_ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01?ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00[ooooo00?o
EEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0
4Oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bo`00000Koooo
o`06ojVYZOl@413o0000oa0@4?nYZJWo00000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Wooooo
00Ko0000ooooooooooooooooogMgMol00004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool0
02oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Jooooo`?o000000?oooooo`00
0?l000001Ol0000Cooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool06_ooool0033o
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Mooooo`;o00001Oooool2o`00017o
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Jooooo`00<?ooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo01[ooooo000aooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool06oooool0037ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0K
ooooo`005_ooooooo`00043o00004oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04
ooooo`;o00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l00007
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0003ooooo
ooooo`0Aooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`0A
ooooo`00<_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo000booooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool01?ooool2o`00017ooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Looooo`00<_ooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Qooooo`;o0000
0_ooool5o`00013ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Looooo`00<_oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Sooooo`?o00000_ooool01?l0003oooooo`000?l0000>ooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool07?ooool003;ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0:?oo
ool01?l0003oooooooooool0000>ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
7?ooool003;ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0:?ooool01Ol0003ooooooooooooooooo000000gooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0Mooooo`00<oooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Xooooo`;o00000_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool07Oooool003?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0:?ooool01Ol0003ooooooooooooo
oooo000000gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Mooooo`00<oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Yooooo`05o`000?ooooooooooooooool000003?ooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo01gooooo000cooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Wooooo00Go0000
ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool07Ooo
ool003?ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Mooooo`00<oooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo01kooooo000cooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool07_ooool003Cooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0Nooooo`00=?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Zooooo`;o00001?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool07_ooool003Cooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0:_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`02ooooo`?o00003Oooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool07_ooool003Cooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0:_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`02o`000003ooooool0003o000000cooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01kooooo000dooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo02[ooooo0_l00004ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01kooooo000dooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool07oooool003Gooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0:ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0Oooooo`00=Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo01oooooo000eooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool07oooool003Go
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0:oooool2o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo01oooooo000eooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0<_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02_ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool07oooool003Gooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Oooooo`00=Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo023ooooo000foooo
o`03o`000?oooooooooo00Wooooo0ol00007ooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo023ooooo000fooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooool000001oooool00ol0003oooooooooo`0cooooo`05
o`000?ooooooooooooooool00000;_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Pooooo`00=_ooool00ol0003o
ooooooooo`08ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0coooo
o`05o`000?ooooooooooooooool000008oooool5o`0000Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Pooooo`00=_ooool00ol0003oooooooooo`08ooooo`05o`000?oooooooooo
ooooool000001Oooool00ol0003oooooooooo`0eooooo`04o`000?ooooooooooo`0002?ooooo00Go
V9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`05ooooo`;o00002Oooool00ol0003oooooooooo`0Pooooo`00=_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0eooooo`03o`000?oooooo000002Gooooo00?oV9RHob4Q8Oo^k^h01ooo
ool3o`0000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`04ooooo`04o`000?oo
ooooooooo`0000Sooooo00?o0000ooooooooool08?ooool003Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=_oo
ool2o`0002Kooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool08Oooool003Kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Goooool00omgMgOoIVIVoooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Qooooo`00=oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00Co0000
oooooooooooo0000Hoooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00Go
0000ooooooooooooooooo`00000hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Qooooo`00=oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Cooooo00Co0000oooooooooooo0000Goooool01Ol0003o^[ZjoooooonHV9So410@00Ko
oooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo000003Wooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool01Ol0003ooooooooooooooooo000002Cooooo000gooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01?ooool2o`000003ooooool0003ooooo05kooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooool00000>_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo02oooooo00Co0000ooooool0003o00002?oo
ool01?l0003oooooooooool0000Tooooo`00=oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Gooooo0ol0001Zooooo`03o`000?oooooooooo00Sooooo00?o0000ooooool00000>_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02oooooo0ol00009ooooo`04o`000?oo
oooo0000o`0002Cooooo000gooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0L_oo
ool00ol0003oooooooooo`08ooooo`;o0000??ooool01?l0003oooooooooool0000nooooo`?o0000
9Oooool003Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1cooooo`;o0000Aooo
ool01?l0003oooooooooool0001Vooooo`00>?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo07?ooooo00?o0000ooooooooool0A_ooool01?l0003oooooooooool0001Vooooo`00>?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0Aooo
ool2o`0006Oooooo000hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Loooool0
0ol0003oooooooooo`2`ooooo`00>?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
07?ooooo00?o0000ooooooooool0/?ooool003Sooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`1dooooo`03o`000?oooooooooo0;3ooooo000hooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0M?ooool00ol0003oooooooooo`2`ooooo`00>?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0/?ooool003Wooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo0;3ooooo000ioooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0M?ooool2o`000;7ooooo000iooooo`05
o`000?ooooooooooooooool00000Moooool00ol0003oooooooooo`2`ooooo`00>Oooool01Ol0003o
oooooooooooooooo000007Oooooo00?o0000ooooooooool0/?ooool003Wooooo00Go0000oooooooo
ooooooooo`00001gooooo`03o`000?oooooooooo0;3ooooo000iooooo`05o`000?oooooooooooooo
ool00000Moooool00ol0003oooooooooo`2`ooooo`00>_ooool01?l0003oooooooooool0001goooo
o`03o`000?oooooooooo0;3ooooo000jooooo`03o`000?oooooo000007Sooooo00?o0000oooooooo
ool0/?ooool003[ooooo00?o0000ooooool00000N?ooool00ol0003oooooooooo`2`ooooo`00>ooo
ool00ol0003oooooooooo`1gooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00:cooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oo
oooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool0
0:[ooooo1Ol00006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`04odA4A?oMgMgoooooo`00
00Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo
0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0/?ooool00:_ooooo
00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00[?ooool00omgMgOo0000oooo
o`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000
/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?oo
ool00:[ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Z
ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`000;3ooooo002Zooooo`05o`000?mEEEGo
0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool00omEEEGoQhN7ooooo`08
ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03omgMgOl@413oV9RH00Sooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000
/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Oo<c<co
8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go8B4QoiRHV?oo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Olb<S;oV9RHoooooonHV9So<S8b
00Kooooo0ol0002`ooooo`00Z_ooool01Oo<c<co0000o`000?l0003oc<c<0;Wooooo002Zooooo`05
oa0@4?nj^[[ooooookZj^_l@4100^Oooool00:[ooooo00Go0000okZj^_oooooo^[Zjo`00002ioooo
o`00Z_ooool01OnYZJWo410@o`000?l@413oZJVY0;Wooooo003oooooofWooooo002cooooo`03o`00
0?nj^[[ooooo0;;ooooo002cooooo`;o<S8b/oooool008Cooooo0_l000001_l@413oooooooooool@
413o0000oa0@41Sooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06_ooool2
o`000009oa0@4?ooooooooooooooooo<c<co8B4Qo`000?lQ8B7oc<c<07cooooo0025ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`0000gooooo00WoMgMgoc8b<_oooooo
ooooogMgMonHV9SooooooiRHV?mgMgL00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[o
k^k^ogMgMol@41002Oooool6o`0000cooooo00?o0000ooooooooool00_ooool01OlQ8B7oV9RHoooo
oonHV9So8B4Q07cooooo0025ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06ooo
ool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo013ooooo00?o0000ooooooooool0
6_ooool5o`0000?ooooo00Go0000ooooooooooooooooo`00001looooo`00QOooool01_l0003ooooo
odA4A?m4A4Coooooo`0000Wooooo1_l0000=ooooo`05ogMgMolb<S;oooooooooool000000oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo1_l00009ooooo`04odA4A?oMgMgo
ooooo`0000Cooooo00Go<S8boiRHV?ooooooV9RHoc8b<P1looooo`00QOooool01_l0003ogMgMoc8b
<_mEEEGogMgMo`0001Wooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?oooooooooo
ooooool000004_ooool00ol0003oooooooooo`0Jooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go
c<c<o`000?l0003o0000olc<c01looooo`00QOooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001Wo
oooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@013ooooo00?o410@o`00
0?l000000ol0000Jooooo`03ogMgMoo<c<co000000Cooooo00Go410@okZj^_oooooo^[Zjoa0@401l
ooooo`00QOooool01_l0003o<S8boooooooooooo<S8bo`0001Wooooo00?o0000ooooooooool01?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool06oooool00oo^k^koA4A4
o`000004ooooo`05o`000?nj^[[ooooookZj^_l00000O?ooool008Cooooo00?o410@o`000?n7QhL0
0_ooool00on7QhOo0000oa0@400Hooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;o
oooo00?o0000ooooooooool07?ooool00omgMgOo0000ooooo`03ooooo`05ojVYZOl@413o0000oa0@
4?nYZJT0O?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .15283 m
.00488 .15535 L
.00942 .1576 L
.01199 .15865 L
.01441 .15942 L
.01575 .15974 L
.01646 .15987 L
.01721 .15999 L
.01853 .16013 L
.01975 .16018 L
.02104 .16015 L
.02221 .16006 L
.02357 .15986 L
.02486 .15959 L
.02715 .15892 L
.02966 .15795 L
.03531 .15499 L
.04057 .15162 L
.04635 .14784 L
.04919 .14627 L
.05043 .14569 L
.0518 .14515 L
.05295 .14477 L
.05418 .14446 L
.05548 .14424 L
.05669 .14414 L
.05737 .14414 L
.05811 .14418 L
.05946 .14436 L
.06077 .1447 L
.06198 .14517 L
.06329 .14587 L
.06469 .14687 L
.06724 .14941 L
.06872 .15138 L
.07027 .15389 L
.07305 .15961 L
.07596 .16743 L
.07867 .1765 L
.08481 .20378 L
.09011 .23414 L
.09586 .2692 L
.09849 .28327 L
.09994 .28979 L
.10128 .29495 L
.10253 .29879 L
.10367 .30145 L
.10493 .30342 L
.10629 .30435 L
.10749 .30413 L
Mistroke
.10877 .30283 L
.10998 .30066 L
.11108 .29793 L
.11377 .28855 L
.1163 .27701 L
.12122 .25103 L
.12581 .22867 L
.12817 .21986 L
.1295 .21606 L
.13071 .21341 L
.13203 .21144 L
.13278 .21078 L
.13347 .21047 L
.13474 .2107 L
.13609 .21209 L
.13737 .21459 L
.13875 .21862 L
.14005 .22378 L
.14124 .22974 L
.14402 .24845 L
.14693 .27583 L
.15217 .34211 L
.15474 .37811 L
.15711 .40901 L
.15926 .43225 L
.16035 .44137 L
.16154 .44898 L
.16274 .45381 L
.16402 .45565 L
.16523 .45412 L
.16634 .45 L
.16762 .44209 L
.16881 .43202 L
.1715 .40116 L
.17639 .32974 L
.18148 .25881 L
.18419 .22862 L
.18711 .20266 L
.18962 .18523 L
.19193 .17262 L
.19414 .16311 L
.19646 .15543 L
.19765 .15234 L
.19892 .14961 L
.20002 .14769 L
.20121 .14604 L
.20194 .14523 L
.20261 .14461 L
.20393 .14372 L
.20513 .14323 L
Mistroke
.20641 .14301 L
.20768 .14303 L
.20906 .1433 L
.21036 .14374 L
.21157 .1443 L
.21386 .14569 L
.2163 .14764 L
.22188 .15395 L
.22694 .16115 L
.23628 .17361 L
.24099 .17849 L
.24366 .18064 L
.24486 .18141 L
.24616 .18209 L
.24752 .1826 L
.24882 .18288 L
.25008 .18295 L
.25124 .18286 L
.2525 .18257 L
.25389 .18206 L
.25533 .18131 L
.25669 .18044 L
.26136 .17647 L
.26638 .17093 L
.27683 .15734 L
.27969 .15405 L
.28274 .15112 L
.28423 .14996 L
.28563 .14901 L
.28687 .1483 L
.28825 .14766 L
.28957 .14721 L
.2908 .14694 L
.29211 .14683 L
.29284 .14685 L
.29351 .14694 L
.2947 .14724 L
.29599 .14781 L
.29722 .14861 L
.29835 .14959 L
.29979 .1512 L
.30114 .1531 L
.30366 .15777 L
.30637 .16455 L
.3093 .17411 L
.31493 .19981 L
.32086 .23786 L
.32641 .2793 L
.32904 .29769 L
.33146 .3121 L
Mistroke
.33264 .31779 L
.33393 .32291 L
.33522 .32671 L
.3366 .32916 L
.33781 .32989 L
.3391 .32918 L
.34033 .3271 L
.34145 .32403 L
.34281 .31892 L
.34407 .31293 L
.34693 .29564 L
.35214 .2566 L
.35664 .22249 L
.3614 .1917 L
.36661 .16608 L
.37141 .14938 L
.37414 .14239 L
.3767 .13728 L
.3795 .13305 L
.38093 .13136 L
.3825 .12984 L
.38396 .12869 L
.38531 .12783 L
.38657 .12718 L
.38796 .12662 L
.38921 .12625 L
.39038 .12602 L
.39162 .12589 L
.39295 .12588 L
.39418 .12599 L
.39532 .1262 L
.39657 .12654 L
.39791 .12705 L
.40065 .12848 L
.40314 .13023 L
.40794 .13469 L
.41248 .14018 L
.43171 .17736 L
.43697 .18875 L
.43988 .19444 L
.44263 .19914 L
.44519 .20263 L
.44664 .20417 L
.44798 .20529 L
.44922 .20605 L
.45034 .20651 L
.45164 .20676 L
.45286 .20673 L
.45407 .20646 L
.4554 .20588 L
Mistroke
.45679 .20498 L
.45808 .2039 L
.4604 .20139 L
.46289 .19802 L
.47372 .17861 L
.47657 .17354 L
.47966 .16866 L
.48239 .16506 L
.48388 .16341 L
.48528 .16209 L
.48664 .16102 L
.48788 .16026 L
.48927 .15966 L
.48999 .15946 L
.49075 .15933 L
.49201 .15935 L
.49317 .15961 L
.49445 .16021 L
.49581 .16124 L
.49711 .16261 L
.49854 .1646 L
.50142 .17029 L
.50409 .17775 L
.50659 .18683 L
.51222 .21563 L
.51537 .23711 L
.51826 .25962 L
.52346 .30322 L
.5262 .32442 L
.52771 .33446 L
.52912 .34245 L
.53034 .34803 L
.53166 .35249 L
.53238 .35417 L
.53313 .35538 L
.53447 .35604 L
.5357 .35495 L
.53684 .35251 L
.53809 .34831 L
.53943 .34219 L
.54956 .26352 L
.55511 .21921 L
.5603 .18704 L
.563 .17408 L
.56591 .16268 L
.56913 .15269 L
.57208 .14564 L
.57474 .1407 L
.57765 .13654 L
.5804 .13355 L
Mistroke
.58295 .1314 L
.58559 .12967 L
.58697 .12893 L
.58844 .12827 L
.58972 .1278 L
.59113 .12737 L
.5924 .12708 L
.5936 .12688 L
.59485 .12674 L
.59604 .12668 L
.5971 .12669 L
.59826 .12674 L
.59952 .12687 L
.60085 .12707 L
.60199 .12729 L
.60325 .1276 L
.60605 .12851 L
.60862 .12967 L
.61144 .13134 L
.61441 .13366 L
.61941 .13901 L
.62489 .1472 L
.63637 .17362 L
.64721 .20701 L
.65193 .22025 L
.65452 .22611 L
.65694 .23036 L
.6582 .23203 L
.65955 .23336 L
.66032 .23389 L
.66105 .23425 L
.66242 .23452 L
.66368 .2343 L
.66485 .2337 L
.66612 .23263 L
.66748 .23103 L
.67708 .21014 L
.68231 .19613 L
.6872 .18461 L
.68975 .1798 L
.69107 .17775 L
.69249 .17591 L
.6933 .17506 L
.69405 .17439 L
.69477 .17388 L
.69553 .17348 L
.69684 .17313 L
.69759 .17313 L
.69829 .17328 L
.69961 .17395 L
Mistroke
.70086 .17507 L
.70198 .17651 L
.7032 .17857 L
.70453 .18141 L
.70594 .18517 L
.70849 .19399 L
.71141 .20767 L
.71457 .22714 L
.7203 .27447 L
.72541 .32393 L
.72831 .34993 L
.72973 .36082 L
.73102 .36928 L
.73235 .37625 L
.73361 .38102 L
.73494 .38394 L
.73569 .3846 L
.73638 .38456 L
.73769 .38278 L
.73843 .38079 L
.73913 .37831 L
.74054 .37158 L
.74205 .36199 L
.74735 .31549 L
.75221 .26777 L
.75718 .22585 L
.75991 .20739 L
.76249 .19291 L
.7649 .18175 L
.76751 .17192 L
.76986 .16484 L
.77206 .15957 L
.77468 .15474 L
.77755 .15084 L
.78035 .14804 L
.78337 .14575 L
.78616 .14408 L
.78881 .14282 L
.79119 .14194 L
.79379 .14121 L
.80444 .139 L
.80699 .13839 L
.80967 .1378 L
.81196 .13738 L
.81327 .1372 L
.81447 .13707 L
.81586 .13695 L
.81657 .1369 L
.81734 .13685 L
.81872 .1368 L
Mistroke
.82002 .13676 L
.82074 .13676 L
.82154 .13676 L
.82237 .13677 L
.82314 .13679 L
.82453 .13687 L
.82531 .13694 L
.82603 .13703 L
.82729 .13724 L
.82847 .13751 L
.82975 .13792 L
.83113 .13849 L
.83394 .14012 L
.8365 .14221 L
.83893 .14474 L
.8416 .14818 L
.8442 .15229 L
.84699 .1577 L
.85199 .17052 L
.85666 .1864 L
.868 .23408 L
.87085 .2455 L
.87352 .25479 L
.87592 .26133 L
.87727 .26407 L
.87851 .26592 L
.87971 .26705 L
.88102 .26753 L
.88239 .26718 L
.88367 .2661 L
.88438 .26518 L
.88506 .26413 L
.88632 .26167 L
.88916 .25422 L
.89519 .23296 L
.90077 .21243 L
.9033 .20438 L
.90568 .19823 L
.90687 .19578 L
.90816 .19371 L
.90889 .19282 L
.90958 .19216 L
.91089 .19149 L
.91221 .19159 L
.91294 .192 L
.91361 .1926 L
.91492 .19441 L
.91614 .19691 L
.91758 .20086 L
.9189 .20552 L
Mistroke
.92188 .21993 L
.92446 .23709 L
.92681 .25674 L
.9321 .31318 L
.93705 .37097 L
.93923 .39249 L
.94039 .4019 L
.94164 .41008 L
.94298 .41627 L
.94423 .41946 L
.94493 .42009 L
.94566 .41984 L
.94698 .41711 L
.94767 .41451 L
.94841 .41087 L
.94975 .40225 L
.95134 .38892 L
.95278 .37442 L
.95791 .31331 L
.96334 .25102 L
.96769 .21266 L
.97017 .19603 L
.97249 .18351 L
.97457 .17446 L
.97656 .16756 L
.97884 .16138 L
.98093 .15718 L
.98322 .15391 L
.9845 .15261 L
.98566 .1517 L
.98675 .15107 L
.98792 .15059 L
.98903 .1503 L
.99005 .15016 L
.99125 .15014 L
.99236 .15023 L
.99358 .15044 L
.99489 .15077 L
.99757 .15173 L
1 .15283 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002@oooo
o`Go00008?ooool00ol0003oooooooooo`0Iooooo`Ko0000TOooool008oooooo0_l00004ooooo`;o
00007_ooool2o`0001Wooooo0_l00005ooooo`03o`000?oooooooooo08kooooo002?ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Fooooo`;o0000
2?ooool2o`0008kooooo002>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>ooo
ool6o`0004[ooooo002>ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0=_ooool4
o`0000Gooooo0ol00018ooooo`00Eoooool2o`0003Cooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0cooooo`?o00003?ooool00ol0003oooooooooo`15ooooo`009Oooool6o`0002_o
oooo0_l000000ooooooo0000o`00000Hooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0`ooooo`;o00004?ooool00ol0003oooooooooo`14ooooo`00
9?ooool00ol0003oooooooooo`03ooooo`;o0000:Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo01;ooooo1_l0000Fooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04?ooooo000Fooooo`03o`000?oo
oooooooo00Wooooo0_l00008ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo0_l0000Eooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo02[ooooo1_l0000Cooooo`005oooool2o`0000Oooooo0_l0000:ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo01Oooooo0_l0000Dooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool05_ooool0
01Wooooo0_l00003ooooo`;o00003?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Cooooo`04o`000?oooooooooo
o`0001Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Gooooo`006_ooool5o`00
00kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool04Oooool6o`0001Cooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0Hooooo`005Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb
<S;ok^k^00gooooo00?o0000ooooooooool02_ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooo
oooooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`0@
ooooo`Go000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000oooooooo
ool03oooool2o`0000?ooooo0_l0000Dooooo`03o`000?oooooooooo00[ooooo1?l000001?l@413o
ooooooooooo^k^h2o`000003oc8b<_o^k^kooooo01Wooooo1Ol00003ooooo`07onk^k_lb<S;o0000
oc8b<_o^k^koooooo`00000Hooooo`06o`000?nHV9So410@o`000?lb<S;oc<c<0oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^01_ooooo00Go0000ooooool0003o0000oa0@4003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03_ooool001Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00kooooo00?o0000ooooooooool02Oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Wooooo00So0000oooooooo
ooooV9RHob4Q8Oo^k^koooooodA4A0?ooooo00GoMgMgo`000?ooooooV9RHogMgM`08ooooo`03o`00
0?oooooooooo013ooooo00Co0000oooooooooooo00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`;o00005?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00GoMgMgo`000?ooooooV9RHogMgM`0J
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01omgMgOoV9RHoooooonHV9SoMgMgooooool0
00006?ooool01_l0003o410@okZj^_ooooooMgMgoc8b<P?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Kooooo`04o`000?ooooooooooo`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`00
2oooool6o`0000;ooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41003_ooool01?l0003o
ooooooooooooool6o`0000Kooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooo
oooo00[ooooo00?o0000ooooooooool01?ooool7o`0000;ooooo00?oV9RHob4Q8Oo^k^h01?ooool0
1Ol0003ooooooooooooooooo410@00Wooooo00?o0000ooooooooool01oooool6o`0000;ooooo00Co
0000oooooooooooo00001?ooool01Ol@413ooooooooooooooooo410@00Oooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`02ooooo`05oa0@4?l0003oooooooooool@41006oooool00onH
V9So8B4Qonk^kP04ooooo`06oa0@4?ooooooooooooooool@413o00006_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go410@oooooooooooooooooa0@400Kooooo`Go00000oooool01Ol@413o
oooooooooooooooo410@00kooooo000Cooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03o`000?oooooooooo00_ooooo00?oZJVYoa0@4?ooool00_ooool0
1Ol0003ooooooooooooooooo000000cooooo00?o0000ooooooooool02oooool01_l0003ooooooooo
oonHV9So8B4Qonk^kP?ooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo
00oooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo0000ooooool00000
3oooool4o`0000Wooooo00?oV9RHob4Q8Oo^k^h00oooool01?l0003oooooooooooooool2o`0001[o
oooo00Go0000ooooooooooooZJVYoa0@4003ooooo`05o`000?ooooooooooooooool000006_ooool0
1Ol0003oA4A4omgMgOoooooo000000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`004ooo
ool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000003oooool00ol0003o
ooooooooo`0:ooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00000<oooo
o`03o`000?oooooooooo00_ooooo00Oo0000ooooooooooooooooogMgMomVIVKooooo00?o00000ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo0000
1?ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`05ooooo`;o00004_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooool0003oooooo`00000?ooooo`04o`000?ooooooooooo`0000[ooooo00?oMgMg
ofIVI_ooool00_ooool01?l0003oooooooooooooool2o`0001[ooooo00Go0000ooooool@413o0000
okZj^P03ooooo`05o`000?ooooooooooooooool000006_ooool01Ol0003ogMgMoeEEEOoooooo0000
00Cooooo00Go0000ooooooooooooooooo`00000>ooooo`005?ooool00omgMgOoc<c<o`000004oooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`0;ooooo`03okZj^_lQ8B7o
oooo00;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00cooooo0_l0
0002ooooo`;o00000_ooool01Ol@413ooooooooooooooooo410@00Wooooo00?o0000ooooooooool0
3oooool01?l0003oooooooooool00004ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo0_l0000Booooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool00_ooool01Ol@413oooooooooool0003o410@00kooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool@41000ooo
ool00ol0003oooooooooo`0Jooooo`04o`000?oooooo^[Zjob4Q8@?ooooo00Go410@oooooooooooo
oooooa0@400Iooooo`06o`000?ooooooooooogMgMoo<c<co00001?ooool01Ol@413ooooooooooooo
oooo410@00kooooo000Dooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0?ooooo`03o`000?oooooooooo00Sooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool00ol0003oooooooooo`0=ooooo`03o`000?nj^[[o000000?o
00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo00?o0000ooooooooool03Oooool01Ol0
003ooooooooooooooooo000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`09ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool01Oooool00ol0003oooooo`00000@ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHooooool0003oMgMg00kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?nj^[[ooooooiRHV?l@
41000oooool01OmgMgOoV9RHoooooonHV9So000001_ooooo00Go410@o`000?oooooo^[Zjo`000003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06Oooool01_l0003oooooooooooo^k^koA4A4o`0000Co
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`005Oooool00omgMgOo0000ooooo`03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h04?ooool00ol0003oooooooooo`07ooooo`05ojVYZOl@413o0000
oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00?o0000ooooooooool03Ooo
ool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0:ooooo`03
o`000?oooooooooo00gooooo00Go0000oooooomEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooool000004?ooool00ol0003oooooooooo`0<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^
oc8b<_l0003o0000onk^kP0=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bo`00000Kooooo`05
ojVYZOl0003o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Wooooo00Ko0000
ooooooooooooooooogMgMol00004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool0033ooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooool000004?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Jooooo`00<?ooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooo`00
000@ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0>ooooo`?o00004Oooool00ol0003oooooooooo`0Jooooo`00<?ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool0
000?ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0<ooooo`04o`000?ooooooooooo`00017ooooo00?o0000ooooooooool06_ooool0033ooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00Co
0000oooooooooooo00003_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool03?ooool01?l0003oooooooooool0000Aooooo`03o`000?oooooooooo01[o
oooo000aooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0:ooooo`04o`000?ooooooooooo`0000kooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo00cooooo00Go0000ooooooooooooooooo`00000@oooo
o`03o`000?oooooooooo01[ooooo000Foooooooo0000@?l0000Cooooo`005_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`;o00001oooool2o`0000Kooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool2
o`0000Cooooo00?o0000ooooool000001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
000000Oooooo00?o0000ooooooooool04Oooool001Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o00000oooool00ol0003oooooooooo`05
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooool000001oooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003o
ooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`0Aooooo`00<Oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooo000000oooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02[ooooo00Go0000ooooooooooooooooo`00
000<ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0Kooooo`00<Oooool00ol0003oooooooooo`0;ooooo`04o`000?ooooooooooo`0000gooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02_ooooo00Go
0000ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0Kooooo`00<_ooool00ol0003oooooooooo`09ooooo`05o`000?oo
ooooooooooooool000003Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0:oooool01Ol0003ooooooooooooooooo000000cooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01_ooooo000booooo`03o`00
0?oooooooooo00Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0[ooooo`05o`000?oooooooooooooo
ool000003?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool07?ooool003;ooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo0000
00gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Looooo`00<_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07_ooool01?l0003o
ooooooooool0000>ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Looooo`00<_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0:oooool2o`0000?ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Nooooo`Co00003_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool07?ooool003;ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo01cooooo000booooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Looooo`00<_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07?ooool003?ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0:_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03;ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01gooooo000cooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo02_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Mooooo`00
<oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
7Oooool003?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo02cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo01gooooo000cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0/ooooo`;o00001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo01gooooo000dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool09Oooool01?l0
003oooooooooool0000<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07Oooool0
03Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo0000
00gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Mooooo`00=?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0[ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo02Kooooo0_l0000=ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool07Oooool003Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07Oooool003Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool07Oooool003Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07Oooool003Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool07Oooool003Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo02gooooo0_l00005ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Mooooo`00=Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0/ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Nooooo`00=_oo
ool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Nooooo`00=_ooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Nooooo`00=_ooool01?l0003oooooooooool0000;ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0gooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool07_ooool003Kooooo00Co0000oooooooooooo0000
2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
=oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01kooooo000gooooo`;o00003?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Sooooo`Go00001_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo03Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Nooooo`00>?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Cooooo00GoV9RHob4Q8Oo^k^koooooodA4
A006ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo01kooooo0015ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0;_ooool01Ol0003ooooooooooooooooo000002Oooooo00?oV9RHob4Q8Oo^k^h01ooo
ool3o`0000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo01kooooo0015ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0;_ooool0
1Ol0003ooooooooooooooooo000002Sooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Nooooo`00AOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02kooooo00Go0000
ooooooooooooooooo`00000Yooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07_oo
ool004Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0_ooooo`04o`000?oooooo
ooooo`0002[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo03Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Nooooo`00AOooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo02oooooo00Co0000oooooooooooo00009_oo
ool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0gooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07_ooool004Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo000002Oooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
=oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01kooooo0015ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0;oooool00ol0003oooooo`00000booooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0hooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo01kooooo0016ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<?ooool2
o`0003;ooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000003[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool07_ooool004Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1T
ooooo`;o00001oooool01Ol0003ooooooooooooooooo000003[ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07ooo
ool004Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooo
oooo00Kooooo00Co0000oooooooooooo0000>oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Oooooo`00A_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool01_ooool0
1?l0003oooooooooool0000looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01oooooo0016ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`06ooooo`04o`000?oooooo
ooooo`0003cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool07oooool004Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo0000??oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Oooooo`00A_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06Gooooo00?o0000ooooooooool01oooool00ol0003oooooo`00000looooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01oooooo0016ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0IOooool00ol0
003oooooooooo`07ooooo`03o`000?oooooo000003cooooo00Go0000ooooooooooooooooo`00000l
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07oooool004Kooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00Oooooo0_l0000moooo
o`05o`000?ooooooooooooooool00000??ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01oooooo0016ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0IOooool00ol0
003oooooooooo`16ooooo`05o`000?ooooooooooooooool00000?Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01oooooo0017ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0IOooool2o`0004Oooooo00Go0000ooooooooooooooooo`00000mooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool08?ooool004Oooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Uooooo`03o`000?oooooooooo04Kooooo00Go0000ooooooooooooooooo`00000m
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08?ooool004Oooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo04Kooooo00Co0000oooo
oooooooo0000?_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo023ooooo0017oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`16oooo
o`04o`000?ooooooooooo`0003kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0P
ooooo`00Aoooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06Gooooo00?o0000oooo
ooooool0Aoooool00ol0003oooooo`00000nooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool08?ooool004Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Uooooo`03
o`000?oooooooooo04Oooooo00?o0000ooooool00000?_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo023ooooo0017ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
IOooool00ol0003oooooooooo`17ooooo`03o`000?oooooo000003kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Pooooo`00Aoooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo06Kooooo00?o0000ooooooooool0B?ooool2o`0003oooooo00Go0000oooooooooooooooo
o`00000Rooooo`00Aoooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06Kooooo0_l0
002:ooooo`05o`000?ooooooooooooooool000008_ooool004Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo08Wooooo00Go0000oooooooooooooooo
o`00000Rooooo`00Aoooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06Kooooo00?o
0000ooooooooool0ROooool01Ol0003ooooooooooooooooo000002;ooooo0018ooooo`05o`000?oo
ooooooooooooool00000J?ooool00ol0003oooooooooo`29ooooo`05o`000?ooooooooooooooool0
00008_ooool004Sooooo00Go0000ooooooooooooooooo`00001Xooooo`03o`000?oooooooooo08Wo
oooo00Co0000oooooooooooo00008oooool004Sooooo00Go0000ooooooooooooooooo`00001Ooooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`29ooooo`04o`000?oooooooooo
o`0002?ooooo0018ooooo`05o`000?ooooooooooooooool00000H?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo08Wooooo00Co0000oooooooooooo00008oooool004Sooooo00Go0000
ooooooooooooooooo`00001Mooooo`Go00001_ooool00ol0003oooooooooo`29ooooo`04o`000?oo
ooooooooo`0002?ooooo0018ooooo`05o`000?ooooooooooooooool00000GOooool01?m4A4CogMgM
ooooool00007ooooo`?o0000ROooool01?l0003oooooooooool0000Sooooo`00B?ooool01Ol0003o
oooooooooooooooo000005gooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`2:
ooooo`;o00009?ooool004Sooooo00Co0000oooooooooooo0000Goooool00omgMgOoc<c<o`000007
ooooo`03o`000?oooooooooo08[ooooo0_l0000Tooooo`00B?ooool01?l0003oooooooooool0001O
ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0/?ooool004Sooooo00Co0000oooo
oooooooo0000H?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo0018oooo
o`04o`000?ooooooooooo`0006Wooooo00?o0000ooooooooool0/?ooool004Sooooo00Co0000oooo
oooooooo0000JOooool00ol0003oooooooooo`2`ooooo`00B?ooool01?l0003oooooooooool0001Y
ooooo`03o`000?oooooooooo0;3ooooo0019ooooo`03o`000?oooooo000006Wooooo0_l0002aoooo
o`00BOooool00ol0003oooooo`00001Yooooo`03o`000?oooooooooo0;3ooooo0019ooooo`03o`00
0?oooooo000006Wooooo00?o0000ooooooooool0/?ooool004Wooooo00?o0000ooooool00000JOoo
ool00ol0003oooooooooo`2`ooooo`00BOooool00ol0003oooooo`00001Yooooo`03o`000?oooooo
oooo0;3ooooo001:ooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0/?ooool004[o
oooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00:[ooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0;3o
oooo002Zooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00
Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo
00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000/?ooool00:[ooooo00Go0000oeEEEOl0003o
410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03oeEEEOn7QhOooooo00Sooooo
00?o0000ooooooooool0/?ooool00:[ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003ooooooooo
o`2`ooooo`00Zoooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aoooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05olc<c?lQ8B7o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OlQ8B7oV9RHoooooonH
V9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_oo
ool3o`000;3ooooo002Zooooo`05olc<c?l0003o0000o`000?o<c<`0^Oooool00:[ooooo00Go410@
okZj^_oooooo^[Zjoa0@402iooooo`00Z_ooool01Ol0003o^[Zjoooooonj^[[o00000;Wooooo002Z
ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0^Oooool00?ooooooJOooool00;?ooooo00?o0000okZj
^_ooool0/_ooool00;?ooooo0_lb<S:cooooo`00Q?ooool2o`000006oa0@4?oooooooooooa0@4?l0
003o410@6?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Iooooo`05odA4
A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07cooooo0025ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`0000gooooo00WoMgMgoc8b<_oo
ooooooooogMgMonHV9SooooooiRHV?mgMgL00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj
^[[ok^k^ogMgMol@41002Oooool6o`0000gooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9Sooooo
oiRHV?mgMgL0O?ooool008Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Koooo
o`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool04?ooool00ol0003oooooooooo`0O
ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool0N_ooool008Gooooo00Ko0000
oooooom4A4CoA4A4ooooool00009ooooo`Ko00003Oooool01OmgMgOo<S8boooooooooooo000000?o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`Ko00003Oooool01OmgMgOo
<S8boooooooooooo000000?ooooo00?o0000ooooooooool0N_ooool008Gooooo00Ko0000omgMgOlb
<S;oEEEEomgMgOl0000Iooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooo
oooooooo000001;ooooo00?o0000ooooooooool06oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;o
oooo00Go0000ooooooooooooooooo`00001looooo`00QOooool01_l0003oQhN7ojVYZOnj^[[oEEEE
o`0001Wooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@013ooooo00?o
410@o`000?l000000ol0000Jooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooo
oa0@401looooo`00QOooool01_l0003o<S8boooooooooooo<S8bo`0001Wooooo00?o0000oooooooo
ool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0O?ooool008Cooooo00?o410@o`00
0?n7QhL00_ooool00on7QhOo0000oa0@400Hooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01;ooooo00?o0000ooooooooool06oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP1looooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(52) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .16291 m
.00488 .15285 L
.00942 .14531 L
.01441 .13869 L
.01975 .13327 L
.02244 .13111 L
.02535 .12916 L
.02811 .12772 L
.02942 .12718 L
.03065 .12676 L
.03175 .12646 L
.03294 .12623 L
.03426 .12608 L
.03546 .12604 L
.03671 .12611 L
.03808 .12631 L
.03937 .12664 L
.04057 .12706 L
.04201 .12773 L
.04334 .12851 L
.04635 .13094 L
.049 .13395 L
.0518 .13819 L
.05431 .14306 L
.05665 .14864 L
.06198 .16558 L
.06774 .19128 L
.073 .22092 L
.07872 .2559 L
.08186 .27321 L
.0834 .28047 L
.08481 .28617 L
.08595 .29001 L
.08719 .29334 L
.08844 .2957 L
.08976 .29706 L
.09112 .29723 L
.09189 .29676 L
.09259 .296 L
.09394 .29359 L
.09522 .29027 L
.09762 .28155 L
.09984 .27118 L
.10485 .24307 L
.11028 .21203 L
.11327 .19692 L
.11611 .18452 L
.11874 .17486 L
.12162 .16638 L
.12423 .16051 L
Mistroke
.12665 .15656 L
.12789 .15508 L
.12923 .15387 L
.13049 .1531 L
.13165 .15269 L
.13271 .15257 L
.13386 .1527 L
.13507 .15314 L
.13619 .15382 L
.13751 .15497 L
.13876 .15641 L
.1411 .16011 L
.14361 .16566 L
.14635 .17379 L
.14895 .18376 L
.15181 .19761 L
.15761 .23619 L
.16298 .28555 L
.16802 .3402 L
.17062 .36804 L
.17338 .39427 L
.17473 .40485 L
.176 .41317 L
.17714 .41909 L
.17837 .4237 L
.17969 .42644 L
.18035 .42695 L
.18108 .42684 L
.18237 .42495 L
.18357 .42131 L
.18431 .41825 L
.185 .4148 L
.18631 .40703 L
.18925 .38465 L
.19849 .30226 L
.20375 .2651 L
.2087 .23932 L
.21356 .2205 L
.21882 .20503 L
.22958 .1802 L
.23959 .16069 L
.24891 .14586 L
.25416 .13914 L
.25894 .13432 L
.26425 .13032 L
.26717 .12869 L
.26848 .1281 L
.26993 .12756 L
.27131 .12716 L
.27261 .12691 L
Mistroke
.27398 .12677 L
.27475 .12675 L
.27545 .12678 L
.2767 .12692 L
.27806 .12722 L
.27935 .12765 L
.28055 .12819 L
.28205 .12905 L
.28347 .13008 L
.28613 .13261 L
.28898 .13643 L
.29207 .14214 L
.29457 .14821 L
.29724 .15642 L
.30206 .17634 L
.3078 .20961 L
.31302 .24817 L
.31847 .29055 L
.32134 .30967 L
.32291 .31813 L
.32439 .3244 L
.32567 .32836 L
.32704 .33095 L
.32779 .3316 L
.32857 .33171 L
.32924 .33134 L
.32998 .33044 L
.33127 .32762 L
.33265 .32298 L
.33396 .31718 L
.33515 .31085 L
.34577 .23357 L
.35157 .19582 L
.35441 .18138 L
.357 .17057 L
.35922 .16302 L
.36163 .15641 L
.36418 .15109 L
.3666 .14742 L
.36799 .14586 L
.36925 .14477 L
.36995 .14428 L
.37071 .14385 L
.37207 .1433 L
.37336 .14304 L
.37472 .14302 L
.37588 .14319 L
.37715 .14357 L
.37845 .14417 L
.37987 .14503 L
Mistroke
.38244 .14713 L
.38494 .14979 L
.38725 .15273 L
.39807 .17108 L
.40745 .18899 L
.41016 .19346 L
.41273 .19713 L
.41504 .19981 L
.41634 .20102 L
.41756 .20196 L
.41889 .20275 L
.4201 .20324 L
.42141 .20353 L
.42214 .20358 L
.42282 .20355 L
.42395 .20336 L
.42519 .20292 L
.42649 .20223 L
.4277 .20137 L
.4301 .19911 L
.43229 .19647 L
.43721 .18898 L
.44846 .16864 L
.4534 .16023 L
.45886 .15226 L
.46354 .14674 L
.46857 .1421 L
.47135 .14014 L
.4739 .13874 L
.47516 .13819 L
.47633 .13778 L
.47755 .13745 L
.47889 .13721 L
.48026 .1371 L
.48102 .1371 L
.48173 .13714 L
.48303 .13732 L
.48441 .13767 L
.48565 .13812 L
.4868 .13868 L
.48807 .13946 L
.48943 .14051 L
.49087 .14189 L
.49245 .14375 L
.49531 .14826 L
.4981 .15431 L
.50069 .16169 L
.52046 .29441 L
.52326 .31943 L
.52587 .3396 L
Mistroke
.5273 .34852 L
.5286 .35501 L
.52929 .35776 L
.53004 .36015 L
.53083 .36198 L
.53159 .36302 L
.53281 .36327 L
.53417 .36145 L
.53485 .35972 L
.53558 .35726 L
.5369 .35134 L
.53947 .33513 L
.54182 .31611 L
.55279 .21808 L
.5583 .18238 L
.56143 .16747 L
.56433 .15663 L
.5671 .14868 L
.5697 .14302 L
.57205 .13925 L
.57458 .13632 L
.5759 .13521 L
.57735 .13426 L
.57808 .13389 L
.57886 .13356 L
.5796 .13332 L
.58027 .13315 L
.58156 .13297 L
.58229 .13295 L
.58297 .13297 L
.5842 .13315 L
.58552 .13352 L
.58671 .13401 L
.58801 .13471 L
.59064 .13667 L
.59307 .13911 L
.59534 .14189 L
.60045 .14993 L
.60593 .16124 L
.6159 .18833 L
.62511 .21393 L
.6278 .21986 L
.63032 .22429 L
.63159 .22603 L
.63295 .2275 L
.63372 .22814 L
.63446 .22861 L
.63584 .22913 L
.63658 .22921 L
.63724 .22916 L
Mistroke
.63801 .22897 L
.63873 .22865 L
.64002 .22778 L
.64074 .22711 L
.64141 .22639 L
.64437 .22212 L
.64749 .21601 L
.6577 .19072 L
.66331 .17717 L
.66864 .16661 L
.67381 .15902 L
.67673 .15581 L
.67943 .15348 L
.68169 .15198 L
.68298 .15132 L
.6842 .15082 L
.68547 .15044 L
.68663 .15021 L
.68791 .1501 L
.68926 .15014 L
.69047 .15032 L
.69157 .15059 L
.69283 .15103 L
.69403 .15157 L
.69615 .15286 L
.69846 .15476 L
.701 .15757 L
.70369 .16155 L
.70599 .16597 L
.70851 .17215 L
.71114 .18026 L
.71399 .19139 L
.71919 .21891 L
.72425 .25595 L
.72894 .29805 L
.73157 .32273 L
.73442 .34757 L
.73572 .35758 L
.7371 .36677 L
.73829 .37334 L
.73957 .37876 L
.74034 .38115 L
.74103 .38273 L
.7424 .38412 L
.74317 .38389 L
.744 .38283 L
.74478 .38105 L
.7455 .37877 L
.74675 .37348 L
.74811 .36579 L
Mistroke
.75088 .34527 L
.76131 .24733 L
.76646 .20792 L
.77124 .1808 L
.77389 .16925 L
.77671 .15923 L
.77978 .15061 L
.78268 .1443 L
.78532 .1398 L
.78817 .13598 L
.79077 .13327 L
.79316 .13132 L
.79448 .13045 L
.79573 .12974 L
.79687 .1292 L
.79808 .12874 L
.7994 .12836 L
.80061 .12813 L
.80192 .128 L
.80267 .12798 L
.80337 .128 L
.80453 .12811 L
.80576 .12834 L
.80681 .12862 L
.80795 .12902 L
.81052 .13028 L
.8129 .13193 L
.81573 .13456 L
.81839 .13781 L
.82339 .14626 L
.82618 .15251 L
.82876 .15931 L
.83459 .17842 L
.84408 .21823 L
.84931 .24005 L
.85188 .24897 L
.85427 .25547 L
.85563 .25823 L
.85632 .25937 L
.85707 .26038 L
.85789 .26122 L
.85867 .26174 L
.85943 .262 L
.86012 .26202 L
.86136 .26153 L
.86272 .26025 L
.86341 .25932 L
.86414 .25811 L
.86546 .25543 L
.86828 .24778 L
Mistroke
.87095 .23863 L
.87594 .21879 L
.88118 .19793 L
.88609 .18116 L
.89121 .16785 L
.89393 .16262 L
.89545 .16025 L
.89687 .15839 L
.89922 .15602 L
.90046 .15513 L
.90179 .15445 L
.90246 .15421 L
.90318 .15402 L
.9045 .1539 L
.90578 .15402 L
.90696 .15435 L
.90807 .15484 L
.9091 .15546 L
.91146 .15746 L
.91375 .16021 L
.91621 .16412 L
.91889 .16962 L
.92174 .17711 L
.92687 .19562 L
.93001 .2107 L
.93296 .22784 L
.93847 .268 L
.94875 .35837 L
.95125 .37649 L
.95262 .38454 L
.95392 .39062 L
.95465 .39334 L
.95545 .39566 L
.95618 .39718 L
.95685 .39807 L
.95818 .39838 L
.95885 .39779 L
.95958 .39658 L
.96025 .39497 L
.96099 .39269 L
.96232 .38716 L
.96482 .37261 L
.97046 .32705 L
.97539 .28391 L
.98065 .24382 L
.98591 .21252 L
.99069 .19106 L
.99548 .17472 L
1 .16291 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo000Ooooo
o`Go0000B?ooool4o`0004Gooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`1@oooo
o`007Oooool2o`0000Cooooo0_l00015ooooo`;o00000oooool2o`0004Cooooo0_l0001Looooo`Ko
0000Coooool001cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`11ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Fooooo`?o0000
@?ooool2o`0000Gooooo00?o0000ooooooooool0COooool001_ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>Ooo
ool2o`0000Gooooo00?o0000ooooooooool05Oooool01?l0003oooooooooooooool2o`0003kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1<ooooo`006_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0gooooo`?o000000Coooooo`000?l0003o00000_ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo04_ooooo000Jooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0??oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Kooooo0ol0000Kooooo`;o00001_oo
ool01?l0003oooooooooool0000Eooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
>_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04[ooooo000Iooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo01Gooooo0_l000000ooooooo0000o`00000Iooooo`03o`000?oooooooooo00Kooooo00Co
0000oooooooooooo00005Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`19ooooo`006?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo00;ooooo0_l0000Hooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooool000005?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Oooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`19ooooo`005oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo01Cooooo0_l0000Sooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool02?ooool00ol0003oooooo`00000Dooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool05oooool5o`0001[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`18
ooooo`005oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01?ooooo0_l000000ooo
oooo0000ooooo`0Pooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02Oooool3o`00
01;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Dooooo`;o00001Oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05?ooool4o`00
033ooooo000Gooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04_ooool01Ol0003o
oooooooooooooooo0000023ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0:oooo
o`;o00004oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02gooooo000Fooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0/ooooo`00
5Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Wooooo00?o0000
ooooooooool03_ooool01OnHV9So410@o`000?l0003oc<c<00?ooooo00Gok^k^o`000?l0003o<S8b
onk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`04o`000004oa0@4?ooooooooooonk^kP;o000000?o<S8bonk^
k_ooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool03?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h8ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool01?ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01?ooool01OnHV9So
410@o`000?lb<S;oc<c<00?ooooo00Kok^k^oc8b<_l0003o<S8bonk^k_l00006ooooo`03o`000?oo
oooooooo01?ooooo0_l000002Ol@413oooooooooool0003ok^k^oc8b<_l0003o<S8bonk^kP0>oooo
o`005_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02Oooool00ol0
003oooooooooo`0>ooooo`05oa0@4?nj^[[o0000ogMgMolb<S800oooool01OmgMgOo0000oooooonH
V9SoMgMg01[ooooo00Ko0000oiRHV?lQ8B7ok^k^oooooom4A4@3ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool01OmgMgOo0000oooooonHV9SoMgMg00gooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00gooooo0_l00004ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo00Go410@okZj^_ooooooMgMgoc8b<P03oooo
o`05ogMgMonHV9SooooooiRHV?l000001oooool00ol0003oooooooooo`0Dooooo`0:o`000?oooooo
ooooooooool0003oMgMgoiRHV?ooooooV9RHogMgM`kooooo000;ooooo`Ko00000_ooool5o`0000?o
oooo00Go410@oooooooooooooooooa0@4009ooooo`03o`000?oooooooooo00Kooooo1_l00004oooo
o`03o`000?oooooo000000?ooooo00Go410@ooooool0003ooooooa0@400Cooooo`Ko000000Kooooo
o`000?ooooooV9RHob4Q8Oo^k^h4ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003o
ooooooooo`0:ooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo0000oooo
ool@41003Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool03Oooool2o`0000Cooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01Oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?oooooo
ooooooooool@41000_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00Go
0000oooooooooooooooooa0@4003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
4?ooool5o`000004ooooool0003ooooooa0@40?ooooo00?o410@ooooooooool03?ooool001?ooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000oooo
ooooool03_ooool01?l0003oooooojVYZOl@4103ooooo`05o`000?oooooo0000ooooool000006Ooo
ool01ol0003oooooooooooooooooV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000
00Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooool0003oooooo`00000<ooooo`03o`000?oooooooooo00oooooo0_l0000A
ooooo`03o`000?oooooooooo00gooooo0_l00004ooooo`05o`000?ooooooooooooooool000001ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo00?oV9RHob4Q8Oo^k^h00ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`06ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000008ooooo`03
o`000?oooooooooo013ooooo00CoA4A4omgMgOoooooo00000_ooool00ol0003oooooo`000003oooo
o`03o`000?oooooooooo00cooooo000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000oooo
ooooooooooooo`00000:ooooo`03o`000?oooooooooo00kooooo00Co0000oa0@4?l0003o^[Zj0ooo
ool01Ol0003oooooo`000?oooooo000001Wooooo00?o0000ooooooooool00_ooool00omgMgOoIVIV
ooooo`02ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02o`0000co
oooo00?o0000ooooooooool03oooool2o`00013ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Kooooo00?oMgMgofIVI_ooool00_ooool01ol0003ooooooooooooooooo
0000ooooool000004oooool00ol0003oooooooooo`05ooooo`03oa0@4?l0003o^[Zj00?ooooo00?o
0000ooooooooool00_l00009ooooo`03o`000?oooooooooo00oooooo00CogMgMoeEEEOoooooo0000
0_ooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00cooooo000Dooooo`03ogMgMoo<
c<co000000Cooooo00Go410@oooooooooooooooooa0@400:ooooo`03o`000?oooooooooo00kooooo
00Co0000oooooonj^[[o8B4Q0oooool01Ol@413oooooooooool0003o410@01Sooooo00?o0000oooo
ooooool01?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01Oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
1Ol@413oooooooooool0003o410@00_ooooo00?o0000ooooooooool04?ooool2o`00013ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
1_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo00Go0000oooooooooooo
oooooa0@4003ooooo`03oa0@4?oooooo000001?ooooo00?o0000ooooooooool01_ooool00onj^[[o
8B4Qooooo`02ooooo`05oa0@4?ooooooooooo`000?l@41002Oooool00ol0003oooooooooo`0@oooo
o`05ogMgMoo<c<co0000ooooool000000_ooool01Ol@413ooooooooooooooooo410@00kooooo000D
ooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0:ooooo`03o`000?oo
oooooooo00gooooo00Go410@o`000?oooooo^[Zjo`000003ooooo`05ogMgMonHV9Soooooo`000?mg
MgL06?ooool02?l0003oooooooooool0003o^[ZjoooooonHV9So410@0oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHo`00000;ooooo`03o`000?oooooooooo013o
oooo0_l0000@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02oooo
o`05o`000?nj^[[ooooooiRHV?l@41000oooool01omgMgOoV9RHoooooonHV9SoMgMgooooool00000
4oooool00ol0003oooooooooo`03ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOo
V9RHooooool0003oMgMg00[ooooo00?o0000ooooooooool03oooool01Oo^k^koA4A4o`000?oooooo
000000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`005Oooool00omgMgOo0000ooooo`03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02_ooool00ol0003oooooooooo`0=ooooo`05ojVYZOl0
003o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?l0003ok^k^01Oooooo00Wo0000oooooooo
oooooooooiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo
00?o0000ooooooooool03Oooool01ol0003oooooooooooooooooEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;o000000_ooooo00?o0000ooooooooool04?ooool2o`00013ooooo00?o0000
ooooooooool03Oooool01?mEEEGoIVIVo`000?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c003ooooo`07onk^k_lb<S;o0000oc8b<_o^k^koooooo`00000Cooooo`03o`000?oooooo
oooo00?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2_ooool00ol0003oooooooooo`0@ooooo`04ogMgMol0003oooooo`0000;ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0>ooooo`00:oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo017o
oooo0_l0000@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Dooooo`00:oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01;ooooo
0_l0000@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Dooooo`00:oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooool000003oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool05?ooool002_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo013ooooo0_l00004ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooool000003oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool05?ooool002cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo017ooooo0_l000000ooooooo0000o`00000Fooooo`03o`000?oooooo0000
00kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
01Cooooo000Foooooooo0000@?l0000Cooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo0_l00006oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o
0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o
0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
4Oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooool000001oooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooo000000Gooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00006oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool2o`0000Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo017ooooo000/ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
000000kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo01Gooooo000]ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0]ooooo`04o`000?ooooooooooo`0000gooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Gooooo000]ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0]ooooo`04o`000?oooooooooo
o`0000gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo01Kooooo000]ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0]ooooo`04o`000?ooooooooooo`0000gooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Kooooo000]ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0^ooooo`04o`000?oooooooooo
o`0000gooooo00?o0000ooooooooool05_ooool01?l0003oooooo`000?l0000Hooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Fooooo`00;Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0;_ooool0
1?l0003oooooooooool0000=ooooo`03o`000?oooooooooo01Oooooo0_l0000Iooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Fooooo`00;_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0;_ooool2
o`000003ooooool0003ooooo00_ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05_ooool002kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02kooooo00Co0000oooo
oooooooo00003?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0Gooooo`00;_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0;_ooool01Ol0003ooooooooooooooooo
000000_ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool05oooool002kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo02kooooo00Go0000ooooooooooooooooo`00000;
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo01Oooooo000^ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0_ooooo`05o`000?ooooooooooooooool000002oooool0
0ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0Gooooo`00;oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0;oooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool05oooool002oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo02oooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo01Oooooo000_ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0_ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`0d
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06oooool01?l0003oooooooooool0
000Fooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06?ooool002oooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02oooooo0_l00002
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo00005_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo01Sooooo000_ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool07?ooool2o`0001Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0H
ooooo`00;oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Hooooo`00<?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Hooooo`00
<?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Hooooo`00<?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Hooooo`00<?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Iooooo`00<?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
03Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Iooooo`00<?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<?ooool2o`0000Co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Wo
oooo000aooooo`04o`000?ooooooooooo`0001Gooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Iooooo`00<Oooool01?l0003oooooooooool0000Eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03So
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool06Oooool0037ooooo00Co0000oooooooooooo00005Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo01Wooooo000booooo`;o00005_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0hooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo01Wooooo001:ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Sooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool06Oooool004[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09_ooool5o`0000Kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool06Oooool004[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Toooo
o`05o`000?ooooooooooooooool00000:Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool06Oooool004[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0T
ooooo`05o`000?ooooooooooooooool00000:_ooool00onHV9So8B4Qonk^kP07ooooo`?o00001?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06_oo
ool004[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Tooooo`05o`000?oooooo
ooooooooool00000:oooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0>Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01[ooooo001;
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09?ooool01Ol0003ooooooooooooo
oooo000002cooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Jooooo`00Boooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Gooooo00Go0000ooooooooooooooooo`00
000]ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06_ooool004_ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Uooooo`05o`000?ooooooooooooooool00000:Ooo
ool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06_ooool004_ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Vooooo`04o`000?ooooooooooo`0002Wooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0>Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01[ooooo001;ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool09_ooool00ol0003oooooo`00000eooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01[ooooo001;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09ooo
ool2o`0003Gooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000003gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool06_ooool004_ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`1Nooooo`;o00001_ooool01Ol0003ooooooooooooooooo000003gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
6_ooool004_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Nooooo`03o`000?oo
oooooooo00Gooooo00Go0000ooooooooooooooooo`00000nooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01[ooooo
001;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0G_ooool00ol0003ooooooooo
o`05ooooo`05o`000?ooooooooooooooool00000?_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Kooooo`00Booo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool01Ooo
ool01Ol0003ooooooooooooooooo000003kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06oooool004_ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo00Kooooo00Co
0000oooooooooooo0000?_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Kooooo`00Boooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool01_ooool01?l0003ooooooooo
ool0000nooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0??ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo01_ooooo001;ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0Goooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`0003kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool06oooool004cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`1Oooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool00000?oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Kooooo`00C?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05oooooo00?o0000
ooooooooool01_ooool00ol0003oooooo`00000oooooo`05o`000?ooooooooooooooool00000?ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo001<ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0Goooool2o`0000Sooooo0_l0000oooooo`05o`000?oooooo
ooooooooool00000?oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01cooooo001<
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`18
ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo01cooooo001<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Goooool0
0ol0003oooooooooo`18ooooo`05o`000?ooooooooooooooool00000?oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo01cooooo001<ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0Goooool00ol0003oooooooooo`18ooooo`04o`000?ooooooooooo`00047ooooo00Go
0000ooooooooooooooooo`00000Nooooo`00C?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo063ooooo00?o0000ooooooooool0BOooool00ol0003oooooo`000011ooooo`05o`000?oo
ooooooooooooool000007_ooool004cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1Pooooo`03o`000?oooooooooo04Wooooo00?o0000ooooool00000@Oooool01Ol0003ooooooooo
oooooooo000001kooooo001<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0H?oo
ool00ol0003oooooooooo`19ooooo`03o`000?oooooo0000047ooooo00Co0000oooooooooooo0000
7oooool004gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo04[ooooo0_l00011ooooo`04o`000?ooooooooooo`0001oooooo001=ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0H?ooool2o`0008kooooo00Co0000oooooooooooo0000
7oooool004gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo08gooooo00Co0000oooooooooooo00007oooool004gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo08kooooo0ol0000Oooooo`00COooool0
1Ol0003ooooooooooooooooo000006?ooooo00?o0000ooooooooool0S_ooool2o`00023ooooo001=
ooooo`05o`000?ooooooooooooooool00000Hoooool00ol0003oooooooooo`2?ooooo`03o`000?oo
oooooooo01kooooo001=ooooo`05o`000?ooooooooooooooool00000F_ooool2o`000003oa0@4?oo
oooooooo00Cooooo00?o0000ooooooooool0/?ooool004gooooo00Go0000ooooooooooooooooo`00
001Kooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool004gooooo00Go0000
ooooooooooooooooo`00001Hooooo`Go00001_ooool00ol0003oooooooooo`2`ooooo`00C_ooool0
1?l0003oooooooooool0001Hooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00C_oo
ool01?l0003oooooooooool0001Hooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000oooooooo
ool0/?ooool004kooooo00?o0000ooooool00000F_ooool00omgMgOoc<c<o`000007ooooo`03o`00
0?oooooooooo0;3ooooo001>ooooo`03o`000?oooooo000005[ooooo00?ok^k^odA4A?l000001ooo
ool00ol0003oooooooooo`2`ooooo`00C_ooool00ol0003oooooo`00001Kooooo`03ogMgMol0003o
oooo00Kooooo00?o0000ooooooooool0/?ooool004oooooo00?o0000ooooooooool0Hoooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Oo^k^ko<S8bo`000?l@413o
c<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00GoEEEEogMgMoooooooV9RHob4Q8@06
ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0002`
ooooo`00Z_ooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0/?ooool0
0:[ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`2`ooooo`00Z_ooool00ooMgMgo
410@oiRHV008ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`04olc<c?m4A4Co0000oa0@40Ko
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aoooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00:[ooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3o
oooo002Zooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00
Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo
00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000/?ooool00:[ooooo00Goc<c<o`000?l0003o
0000olc<c02iooooo`00Z_ooool01Ol@413o^[Zjoooooonj^[[o410@0;Wooooo002Zooooo`05o`00
0?nj^[[ooooookZj^_l00000^Oooool00:[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2iooooo`00
oooooomYooooo`00/oooool00ol0003o^[Zjooooo`2booooo`00/oooool2oc8b<[?ooooo0024oooo
o`;o000000Ko410@oooooooooooo410@o`000?l@410Hooooo`05odA4A?l0003o0000oc8b<_oMgMd0
0_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So
0000o`000?m4A4Co^[Zj01Wooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`Go0000O?ooool0
08Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00003Oooool02Omg
MgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03olc<c?l0003o410@00cooooo
00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003Oooool02OmgMgOo<S8booooooooooooV9RH
ob4Q8Oo^k^koooooodA4A01looooo`00QOooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo01_ooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`0@ooooo`03o`000?oo
oooooooo01oooooo00Oo0000oooooooooooooooooiRHV?lQ8B7ok^k^07gooooo0025ooooo`06o`00
0?ooooooA4A4odA4A?oooooo00002Oooool6o`0000gooooo00GoMgMgoc8b<_ooooooooooo`000003
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02oooool6o`0000gooooo00?oMgMg
oc8b<_ooool00oooool00onHV9So8B4Qonk^kP1looooo`00QOooool01_l0003ogMgMoc8b<_mEEEGo
gMgMo`0001Wooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool0
00004_ooool00ol0003oooooooooo`0Kooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00omg
MgOoIVIVooooo`1kooooo`00QOooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001Wooooo00?o0000
ooooooooool01?ooool01Ol@413ooooooooooooooooo410@013ooooo00?o410@o`000?l000000ol0
000Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0N_ooool008Gooooo00Ko0000
oc8b<_oooooooooooc8b<_l0000Iooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Booooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01?ooool01Ol0003o
^[ZjoooooonHV9So410@07cooooo0024ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@
41006?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Booooo`03o`000?oooooooooo
01_ooooo1?l00003ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0O?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(54) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .16655 m
.00236 .15551 L
.00488 .14624 L
.00726 .13957 L
.00942 .135 L
.01197 .13119 L
.01341 .12966 L
.01473 .12859 L
.01589 .12788 L
.01717 .12731 L
.0185 .12695 L
.01975 .12679 L
.02103 .1268 L
.02176 .12689 L
.02243 .12702 L
.02367 .12739 L
.02499 .12796 L
.02628 .12873 L
.0275 .12963 L
.02978 .13183 L
.03248 .13533 L
.03496 .13944 L
.04057 .15194 L
.06166 .24346 L
.06463 .25763 L
.06744 .269 L
.06899 .27409 L
.07068 .27847 L
.07142 .27999 L
.07221 .28131 L
.07289 .28219 L
.07363 .28289 L
.07434 .2833 L
.07508 .28344 L
.07641 .28299 L
.07715 .28235 L
.07783 .28151 L
.07859 .28032 L
.0794 .27876 L
.08223 .2711 L
.08481 .2618 L
.09504 .21813 L
.09785 .20763 L
.10081 .19806 L
.10338 .19117 L
.10614 .18525 L
.10746 .18294 L
.10872 .18108 L
.10995 .17957 L
.11109 .17842 L
Mistroke
.11216 .17755 L
.11331 .17685 L
.11458 .17631 L
.11572 .17603 L
.11709 .17591 L
.11834 .176 L
.11971 .17626 L
.1204 .17646 L
.12116 .17671 L
.1238 .17789 L
.12627 .1793 L
.13154 .1829 L
.13432 .18488 L
.13727 .18673 L
.13851 .18737 L
.13985 .18793 L
.14061 .18819 L
.14131 .18838 L
.14268 .18864 L
.14385 .18872 L
.14512 .18868 L
.14645 .1885 L
.14768 .18822 L
.1489 .18785 L
.15023 .18735 L
.15263 .18628 L
.15712 .1838 L
.15963 .18225 L
.16232 .18061 L
.16362 .17991 L
.16486 .17936 L
.16597 .179 L
.16718 .17881 L
.16837 .17886 L
.16969 .17927 L
.17106 .18015 L
.17235 .18147 L
.17355 .18318 L
.17466 .18519 L
.17714 .19148 L
.17846 .19591 L
.17969 .2008 L
.18247 .21508 L
.18519 .23401 L
.18809 .26073 L
.19367 .33116 L
.19673 .3758 L
.19959 .41518 L
.20202 .44215 L
.20339 .45321 L
Mistroke
.20464 .46018 L
.206 .46401 L
.20677 .46436 L
.20749 .46349 L
.2088 .45895 L
.20953 .45479 L
.2102 .45008 L
.21158 .43756 L
.21286 .42321 L
.21573 .38353 L
.22094 .30283 L
.2266 .22937 L
.22946 .20207 L
.23259 .1788 L
.23535 .16296 L
.23787 .15165 L
.24078 .1417 L
.24353 .13489 L
.24607 .13043 L
.24842 .12749 L
.251 .12519 L
.25231 .12428 L
.25374 .12345 L
.25495 .12287 L
.25624 .12237 L
.25761 .12198 L
.25888 .12176 L
.26015 .12168 L
.26134 .12175 L
.26242 .12193 L
.26359 .12226 L
.26486 .12277 L
.26627 .1235 L
.26911 .12549 L
.27174 .12787 L
.2742 .1306 L
.27668 .13398 L
.27904 .13794 L
.28346 .14798 L
.28593 .15535 L
.28821 .16339 L
.2934 .1861 L
.30453 .25498 L
.30719 .27289 L
.30999 .29006 L
.31238 .30218 L
.31375 .3077 L
.315 .31168 L
.31621 .31451 L
.31735 .31621 L
Mistroke
.31856 .31697 L
.31987 .31657 L
.32102 .3152 L
.32223 .31277 L
.32326 .30992 L
.32441 .30604 L
.32693 .29506 L
.32965 .2805 L
.33456 .25115 L
.33969 .22258 L
.34516 .19946 L
.34831 .19007 L
.35116 .18383 L
.35254 .18154 L
.35404 .17955 L
.35544 .17812 L
.35674 .17717 L
.35796 .17659 L
.35927 .17627 L
.3605 .17626 L
.36163 .17646 L
.36295 .17695 L
.36369 .17733 L
.36438 .17774 L
.36699 .17978 L
.37225 .18542 L
.37783 .19235 L
.38262 .19802 L
.38523 .20061 L
.38766 .20247 L
.38894 .20319 L
.3903 .20375 L
.39108 .20397 L
.39182 .2041 L
.39319 .20416 L
.39446 .20401 L
.39563 .20369 L
.39691 .20315 L
.39827 .20237 L
.40054 .20062 L
.40299 .19815 L
.4074 .19233 L
.41746 .17492 L
.42809 .15683 L
.4337 .14862 L
.43968 .14133 L
.44543 .13584 L
.45063 .1318 L
.45586 .12852 L
.45841 .12726 L
Mistroke
.46078 .12631 L
.46315 .12555 L
.46568 .12492 L
.46713 .12464 L
.4685 .12444 L
.46972 .1243 L
.47106 .12422 L
.47236 .1242 L
.4731 .12423 L
.47379 .12428 L
.47452 .12436 L
.47519 .12447 L
.47592 .12461 L
.47669 .1248 L
.47798 .12521 L
.47918 .12571 L
.4819 .12726 L
.48443 .12932 L
.48682 .13188 L
.48896 .13482 L
.49129 .13881 L
.49382 .14439 L
.4965 .15196 L
.5013 .17088 L
.51199 .24353 L
.51725 .29193 L
.51957 .3128 L
.52212 .33325 L
.52322 .34066 L
.5244 .34753 L
.52542 .35239 L
.52653 .35647 L
.52772 .35928 L
.52898 .36046 L
.53014 .35989 L
.53122 .35794 L
.53251 .3539 L
.53373 .34849 L
.53601 .33476 L
.54113 .29299 L
.54629 .24813 L
.54912 .22649 L
.55176 .2091 L
.55643 .18565 L
.55891 .1768 L
.56158 .16978 L
.56293 .16712 L
.5644 .16485 L
.56507 .16402 L
.56579 .16326 L
Mistroke
.56708 .16223 L
.56843 .16156 L
.56971 .1613 L
.57086 .16135 L
.5721 .16168 L
.57348 .16236 L
.57427 .16289 L
.575 .16346 L
.57805 .16672 L
.5807 .17053 L
.58353 .17544 L
.59421 .19804 L
.59985 .2094 L
.60294 .21452 L
.60445 .21661 L
.60583 .21824 L
.60703 .21941 L
.60835 .22042 L
.60966 .22115 L
.61105 .22159 L
.61181 .22169 L
.61249 .2217 L
.61329 .22161 L
.61404 .22143 L
.61537 .22089 L
.61612 .22047 L
.61681 .22001 L
.61916 .21794 L
.62174 .2149 L
.62696 .20685 L
.63832 .18615 L
.6491 .16973 L
.65878 .15895 L
.66933 .15033 L
.67958 .14352 L
.6852 .14045 L
.68796 .13912 L
.69049 .13805 L
.6929 .13726 L
.69411 .13697 L
.69544 .13675 L
.69677 .13663 L
.69752 .13662 L
.6982 .13664 L
.69953 .13679 L
.70078 .13706 L
.70191 .13741 L
.7031 .13793 L
.70412 .13849 L
.70525 .13925 L
Mistroke
.70646 .14026 L
.70775 .1416 L
.7101 .14483 L
.71276 .15002 L
.7156 .15781 L
.71827 .16773 L
.7207 .17928 L
.72356 .19651 L
.72666 .22012 L
.73227 .27636 L
.73761 .33837 L
.74053 .36859 L
.74195 .38067 L
.74325 .38958 L
.74445 .39572 L
.74558 .39955 L
.74677 .40138 L
.74807 .40073 L
.7494 .39722 L
.75007 .39438 L
.75082 .39047 L
.75336 .37151 L
.76408 .25208 L
.76946 .20349 L
.77252 .18321 L
.77536 .16859 L
.77799 .15829 L
.78047 .15106 L
.7827 .14639 L
.78396 .14444 L
.78512 .14302 L
.78636 .14187 L
.78753 .14113 L
.78881 .14063 L
.79018 .14044 L
.79087 .14048 L
.79162 .1406 L
.79299 .14106 L
.79432 .14178 L
.79555 .1427 L
.7981 .14537 L
.80086 .14942 L
.80586 .15983 L
.81073 .1732 L
.8152 .1877 L
.82044 .20647 L
.82604 .22646 L
.82875 .23484 L
.83133 .24133 L
.83363 .24568 L
Mistroke
.83494 .24746 L
.83614 .24865 L
.83728 .24937 L
.8385 .24971 L
.83965 .24962 L
.84071 .2492 L
.84188 .24837 L
.84316 .24702 L
.8445 .24517 L
.84574 .24306 L
.85067 .23174 L
.85593 .21692 L
.86178 .20125 L
.86731 .1895 L
.87226 .18169 L
.87506 .17844 L
.87764 .17618 L
.87895 .17529 L
.8802 .17459 L
.88255 .17361 L
.88386 .17321 L
.88508 .1729 L
.88783 .17234 L
.89736 .17048 L
.9002 .16985 L
.90287 .16914 L
.90527 .1683 L
.90786 .16709 L
.91365 .16338 L
.91904 .15977 L
.92153 .15839 L
.92388 .1573 L
.92518 .1568 L
.92659 .15634 L
.92787 .15603 L
.92906 .15586 L
.93037 .15583 L
.93159 .156 L
.93294 .15645 L
.93369 .15686 L
.93439 .15733 L
.93577 .15862 L
.93728 .16062 L
.93871 .16314 L
.94004 .16609 L
.94293 .17484 L
.94565 .18638 L
.9481 .19999 L
.95075 .21881 L
.95364 .24499 L
Mistroke
.9567 .27921 L
.96217 .35163 L
.96471 .38421 L
.96711 .41003 L
.96816 .41892 L
.96927 .42645 L
.97049 .4322 L
.97161 .435 L
.97281 .43524 L
.9741 .43233 L
.97531 .42666 L
.97643 .41912 L
.97766 .40839 L
.97901 .3942 L
.98174 .35991 L
1 .16655 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
001Yooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0/?ooool006Kooooo1Ol0000o
ooooo`Co00001oooool00ol0003oooooooooo`2`ooooo`006oooool4o`0004Kooooo0_l00004oooo
o`;o0000>oooool3o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo0;3ooooo000Jooooo`05
o`000?ooooooooooooooool00000AOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
03Kooooo0_l00008ooooo`03o`000?oooooooooo00;ooooo0_l0002aooooo`006Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0dooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`00002boooo
o`006Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo043ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00[ooooo00Go0000oooooooo
ooooooooo`00000looooo`Co0000L_ooool001Sooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0oooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`0<ooooo`04o`000?ooooooooooo`0003Wooooo1?l00003ooooo`;o00006Oooool00ol0
003oooooooooo`1Dooooo`006?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00go
oooo00Co0000oooooooooooo0000>?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01Kooooo1?l0001Dooooo`005oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03go
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooool00000=oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Aooooo`005oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo013ooooo00?o0000ooooool00000=_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1@ooooo`005_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo017ooooo0_l0
000dooooo`;o00003Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0D?ooool001Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0B
ooooo`?o0000<Oooool2o`0000oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo02Gooooo0_l0000Yooooo`005_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Zoooo
o`03o`000?oooooooooo01?ooooo0_l0000aooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02;ooooo0ol000000ooo
oooo0000o`00000Wooooo`005_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03[o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01?o
oooo0_l0000Dooooo`?o00006_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool09Oooool001Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b
<_l0003o<S8bonk^kP04ooooo`03o`000?oooooooooo01?ooooo00GoV9RHoa0@4?l0003o<S8bolc<
c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06_ooool6o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP02ooooo`03o`000?oooooooooo01Oooooo1?l000002?l@413oooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^1_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo017ooooo0_l0
0002ooooo`03o`000?oooooooooo00Oooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb
<S;ok^k^0oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0<
ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo
0_l00007ooooo`03o`000?oooooooooo00_ooooo0_l000002Ol@413oooooooooooooooook^k^oc8b
<_l0003o<S8bonk^kP0>ooooo`005_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01?ooool00ol0003oooooooooo`0Cooooo`05oa0@4?nj^[[oooooogMgMolb<S800ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00Ko0000oiRHV?lQ8B7ok^k^oooooom4A4@3oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo00?o0000ooooooooool0
4_ooool02?l0003ooooooooooonHV9So8B4Qonk^k_ooooooA4A40oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0;ooooo`05oa0@4?nj
^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo0_l00009ooooo`03
o`000?oooooooooo00cooooo00[o0000ooooooooooooooooo`000?mgMgOoV9RHoooooonHV9SoMgMg
3_ooool000_ooooo1_l00002ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00Cooooo
00?o0000ooooooooool02oooool6o`0000Kooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo017ooooo1_l000001_oooooo0000oooooonHV9So8B4Qonk^kPCooooo00Go410@
oooooooooooooooooa0@4002ooooo`03o`000?oooooooooo00kooooo1_l00005ooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool00_ooool01ol@413ooooooooooooooooo410@ooooool000005Oooool01ol0
003oooooooooooooooooV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`05o`000?ooooooooooooooool@
41000oooool00ol@413o0000o`000002o`0000_ooooo00?o0000ooooooooool02Oooool5o`0000;o
oooo00?o0000oa0@4?ooool00_ooool00ol@413oooooooooo`0<ooooo`004oooool01?m4A4CogMgM
ooooool00004ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Foooo
o`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Iooooo`07o`000?oooooo
oooooooooonHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool01ol0003ooooooooooooooooo
0000ooooool000005Oooool00ol0003oooooooooo`02ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
3Oooool00onYZJWo410@ooooo`02ooooo`Go00004?ooool00ol0003oooooooooo`08ooooo`04odA4
A?oMgMgoooooo`0000?ooooo0_l00003ooooo`03o`000?oooooooooo00cooooo000Cooooo`04omgM
gOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo
017ooooo1Ol000001Onj^[[ooooooooooooooooo000000?ooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`02ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo01;ooooo1?l00002ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooooooool2o`0001Oooooo00?o0000ooooooooool00_ooool00omgMgOo
IVIVooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00cooooo00?o410@o`000?nj^[X00oooool2o`0000;ooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`08ooooo`04omgMgOmEEEGoooooo`0000?ooooo0_l00003
ooooo`03o`000?oooooooooo00cooooo000Dooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooo
oooooooooooooa0@4005ooooo`03o`000?oooooooooo013ooooo0_l00003ooooo`03okZj^_l0003o
000000;ooooo00Go410@oooooooooooooooooa0@4002ooooo`Co00004oooool00ol0003ooooooooo
o`03ooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo000001?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooo`000004ooooo`05oa0@4?oooooooooooooo
ool@41000oooool00ol0003oooooooooo`0Hooooo`;o00004Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
000001Sooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo410@00?ooooo00Co
410@oooooooooooo00002oooool00ol0003oooooooooo`0=ooooo`06okZj^_lQ8B7oooooooooool0
003o410@0oooool00ol@413oooooooooo`0>ooooo`03o`000?oooooooooo00Wooooo00?oMgMgolc<
c?l000000oooool00ol0003o410@ooooo`02ooooo`03oa0@4?oooooooooo00cooooo000Dooooo`03
onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo
013ooooo00oo0000ooooool@413oV9RHoooooonj^[[o0000ooooool0003oooooogMgMonHV9Sooooo
oiRHV?mgMgL00ol00003ooooo`03o`000?oooooooooo013ooooo00Oo0000ooooool0003o^[Zjoooo
oonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03o`000?oooooooooo00oo
oooo0_l00004ooooo`03o`000?oooooo000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02oooo
o`03o`000?oooooooooo01Wooooo0_l0000@ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?l000006?ooool0
1ol0003oooooo`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00;o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`0=oa0@4?nHV9SooooookZj
^_l0003oooooo`000?ooooooMgMgoiRHV?ooooooV9RHogMgM`0Aooooo`03o`000?oooooooooo00So
oooo00?ok^k^odA4A?l000000oooool01_l0003oMgMgoiRHV?ooooooV9RHogMgM`kooooo000Eoooo
o`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooo
oooo00oooooo00Wo0000ooooooooooooZJVYoa0@4?l0003o410@ojVYZOooool00ol000001?lb<S;o
0000oc8b<_l00006ooooo`03o`000?oooooooooo013ooooo00Oo0000oooooonHV9So410@o`000?lQ
8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool00oooool00omEEEGo0000o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00_ooool00ol0003oooooooooo`0Iooooo`;o00004?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?l0003ok^k^
01Sooooo00Oo0000oooooonHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP02ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool03OnYZJWo410@
o`000?l@413oZJVYooooool0003oooooonk^k_lb<S;o0000oc8b<_o^k^h04Oooool00ol0003ooooo
ooooo`09ooooo`0;ogMgMol0003oooooooooool0003oooooonk^k_lb<S;o0000oc8b<_o^k^h03_oo
ool002Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`08ooooo`Co00001oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06_ooool2
o`00013ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo01;ooooo000Vooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06oooool2o`00
013ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
01;ooooo000Vooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06oooool2o`0000oo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01;o
oooo000Vooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool07?ooool2o`0000oooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01;ooooo
000Vooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`09ooooo`?o000000?oooooo`000?l000007oooool00ol0003oooooo`00000>ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Booooo`005_oooooo
o`00043o00004oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`;o00001_ooool00ol0003oooooooooo`04ooooo`;o00001_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04oooo
o`;o00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`04ooooo`;o00001_ooool00ol0003oooooooooo`04oooo
o`;o00001oooool00ol0003oooooooooo`04ooooo`;o00001oooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0001?ooooo000Foooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000oooo
ooooool01?ooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000
ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo0_l00007
ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`;o00004oooool002Oooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02oooooo00?o0000
ooooool000003Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool04_ooool002Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo02oooooo00Co0000oooooooooooo00003?ooool00ol0003oooooooooo`0>
ooooo`;o00000oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0Cooooo`009oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0<?ooool01?l0003oooooooooool0000<
ooooo`03o`000?oooooooooo00oooooo1?l0000Rooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0Cooooo`00:?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0<?ooool01?l0003oooooooooool0000<
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo01?ooooo000Xooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0`ooooo`04o`000?ooooooooooo`0000cooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool04oooool002Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo033ooooo00Co0000oooooooooooo00003?ooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0C
ooooo`00:?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0<Oooool2o`000003ooooool0003ooooo00_ooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04oooool002So
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo037o
oooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01?ooooo000Yooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0aooooo`05
o`000?ooooooooooooooool000002_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Cooooo`00:Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0<Oooool01Ol0003o
oooooooooooooooo000000[ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04oooool002Wooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo037ooooo00Go0000oooooooo
ooooooooo`00000:ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00;o00008Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo01?ooooo000Yooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0booooo`05o`000?ooooooooooooooool000002_ooool00ol0
003oooooooooo`0gooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05?ooool3o`00
02;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Dooooo`00:_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0<_ooool01Ol0003o
oooooooooooooooo000000[ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Doooo
o`00:_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0<_ooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Dooooo`00:_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0<_ooool2o`0000;ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0>Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo01Cooooo000Zooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0booooo`05o`000?ooooooooooooooool0
00002Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0>Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Cooooo000[ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0booooo`05o`00
0?ooooooooooooooool000002Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Co
oooo000[ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0cooooo`05o`000?ooooooooooooooool000002Oooool00ol0003oooooooooo`0iooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo01Cooooo000[ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
>_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Cooooo000/ooooo`05o`000?oo
ooooooooooooool000008Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Cooooo
000/ooooo`04o`000?ooooooooooo`0002;ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0>Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Dooooo`00;?ooool4o`0002;ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0>Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Dooooo`00;Oooool2o`0002?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<oooool2o`0000?ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Gooooo001Boooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo03?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo03[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05Oooool005;ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0>_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Eooooo`00D_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0jooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01Gooooo001Booooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05Ooo
ool005?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Eooooo`00Doooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo01[ooooo00Go0000ooooooooooooooooo`00000/
ooooo`Go00001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Eooooo`00Doooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01[ooooo00Go0000ooooooooooooooooo`00000/ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0??ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Eooooo`00Doooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo0000;Oooool00onHV9So8B4Qonk^
kP07ooooo`?o00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool05Oooool005?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooo000002oooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0E
ooooo`00Doooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01_ooooo0ol0000`oooo
o`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo03cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0moooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool005?ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Looooo`;o0000<Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0looooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01Kooooo001Cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
Boooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool005?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1<ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0?Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Fooooo`00Doooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo05Oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000043o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool05_ooool005?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`1Gooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000010ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01Kooooo001Cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
Eoooool2o`0000Gooooo00Go0000ooooooooooooooooo`000010ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Ko
oooo001Cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Eoooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool00000@?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Fooooo`00
Doooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0
1?ooool01Ol0003ooooooooooooooooo0000043ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05_ooool005?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00Cooooo
00Go0000ooooooooooooooooo`000010ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Kooooo001Cooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`05ooooo`04o`00
0?ooooooooooo`00043ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0nooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool05oooool005?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
0000@?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Gooooo`00Doooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo05Oooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000011ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo01Oooooo001Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Eooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooo0000047ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05ooo
ool005Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooo
oooo00Kooooo0_l00011ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0?oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Oooooo001Dooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0Eoooool2o`0000Oooooo00?o0000ooooooooool0@?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Gooooo`00E?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05So
oooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Gooooo`00E?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0BOooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Gooooo`00E?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Sooooo00?o
0000ooooooooool0BOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo043ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Gooooo`00E?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0G
ooooo`00E?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Sooooo00?o0000oooo
ooooool0B_ooool01Ol0003ooooooooooooooooo000004;ooooo00Go0000ooooooooooooooooo`00
000Jooooo`00E?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Sooooo00?o0000
ooooooooool0B_ooool01Ol0003ooooooooooooooooo000004;ooooo00Go0000oooooooooooooooo
o`00000Jooooo`00E?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Sooooo00?o
0000ooooooooool0B_ooool01?l0003oooooooooool00013ooooo`05o`000?ooooooooooooooool0
00006_ooool005Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Hooooo`;o0000
Boooool01?l0003oooooooooool00013ooooo`05o`000?ooooooooooooooool000006_ooool005Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo04[o
oooo00Co0000oooooooooooo0000@oooool01Ol0003ooooooooooooooooo000001[ooooo001Doooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`1:oooo
o`03o`000?oooooo000004Cooooo00Go0000ooooooooooooooooo`00000Jooooo`00EOooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0Boooool2o`00
04Cooooo00Go0000ooooooooooooooooo`00000Jooooo`00EOooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0Boooool2o`0004Gooooo00Co0000oooo
oooooooo00006_ooool005Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1?oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo
04Cooooo00Co0000oooooooooooo00006_ooool005Gooooo00Go0000ooooooooooooooooo`00001C
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0T_ooool01?l0003oooooooooool0
000Jooooo`00EOooool01Ol0003ooooooooooooooooo0000053ooooo1Ol00006ooooo`03o`000?oo
oooooooo09;ooooo00Co0000oooooooooooo00006_ooool005Gooooo00Go0000oooooooooooooooo
o`00001@ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0002Booooo`04o`000?ooooooooooo`00
01[ooooo001Eooooo`05o`000?ooooooooooooooool00000D?ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo09;ooooo00Co0000oooooooooooo00006_ooool005Gooooo00Go0000
ooooooooooooooooo`00001Aooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0T_oo
ool01?l0003oooooooooool0000Jooooo`00EOooool01Ol0003ooooooooooooooooo0000057ooooo
00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2Booooo`04o`000?ooooooooooo`0001[o
oooo001Eooooo`05o`000?ooooooooooooooool00000D_ooool00omgMgOo0000ooooo`06ooooo`03
o`000?oooooooooo09;ooooo00?o0000ooooool000006oooool005Gooooo00Go0000oooooooooooo
ooooo`00001Kooooo`03o`000?oooooooooo09;ooooo00?o0000ooooool000006oooool005Kooooo
00Co0000oooooooooooo0000Foooool00ol0003oooooooooo`2Cooooo`;o00006oooool005Kooooo
00Co0000oooooooooooo0000Foooool00ol0003oooooooooo`2Cooooo`03o`000?oooooooooo01[o
oooo001Fooooo`04o`000?ooooooooooo`0005_ooooo0_l0002aooooo`00E_ooool01?l0003ooooo
ooooool0001Kooooo`03o`000?oooooooooo0;3ooooo001Fooooo`04o`000?ooooooooooo`0005_o
oooo00?o0000ooooooooool0/?ooool005Kooooo00Co0000oooooooooooo0000Foooool00ol0003o
ooooooooo`2`ooooo`00E_ooool01?l0003oooooooooool0001Kooooo`03o`000?oooooooooo0;3o
oooo001Fooooo`04o`000?ooooooooooo`0005_ooooo00?o0000ooooooooool0/?ooool005Kooooo
00?o0000ooooool00000G?ooool00ol0003oooooooooo`2`ooooo`00Eoooool2o`0005cooooo00?o
0000ooooooooool0/?ooool005Oooooo0_l0001Looooo`;o0000/Oooool005Sooooo00?o0000oooo
ooooool0F_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OmEEEGoMgMgoooo
oonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?nHV9SooooooiRHV?lQ8B40
1_ooool3o`000;3ooooo002Zooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo0;3ooooo002Z
ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0/?ooool00:_ooooo00Coc<c<odA4
A?l0003o410@1_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002a
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00Z_ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000
ooooooooool0/?ooool00:[ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooo
oooo0;3ooooo002Zooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`2`
ooooo`00Z_ooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0002`ooooo`00Z_ooool01Oo<
c<co0000o`000?l0003oc<c<0;Wooooo002Zooooo`05oa0@4?nj^[[ooooookZj^_l@4100^Oooool0
0:[ooooo00Go0000okZj^_oooooo^[Zjo`00002iooooo`00Z_ooool01OnYZJWo410@o`000?l@413o
ZJVY0;Wooooo003oooooofWooooo002cooooo`03o`000?nj^[[ooooo0;;ooooo002cooooo`;o<S8b
/oooool008Cooooo0_l000001_l@413oooooooooool@413o0000oa0@41Sooooo00GoA4A4o`000?l0
003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOo0000okZj^P0<
ooooo`05oiRHV?l0003o0000odA4A?nj^[X06Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo
0_l000000ol@413oooooooooo`1jooooo`00QOooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Oooooo1_l0000=ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000=
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0Noooool008Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooooooooa0@40?ooooo00?o410@
ooooooooool04?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Go0000O?ooool0
08Gooooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00003Oooool01OmgMgOo<S8boooo
oooooooo000000?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`Ko0000
3Oooool02?mgMgOo<S8booooooooooooA4A4omgMgOoooooo0000OOooool008Gooooo00Ko0000omgM
gOlb<S;oEEEEomgMgOl0000Iooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooo
oooooooooooo000001;ooooo00?o0000ooooooooool06oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00;ooooo00CogMgMoeEEEOoooooo0000OOooool008Gooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0
000Iooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400@ooooo`03oa0@
4?l0003o000000?o00006_ooool00ol0003oooooooooo`05ooooo`03ogMgMoo<c<co000007gooooo
0025ooooo`06o`000?lb<S;ooooooooooolb<S;o00006Oooool00ol0003oooooooooo`04ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL04_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
00Gooooo00?ok^k^odA4A?l00000OOooool008Cooooo00?o410@o`000?n7QhL00_ooool00on7QhOo
0000oa0@400Hooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo00?o0000oooo
ooooool06oooool4o`0000Gooooo00?oMgMgo`000?ooool0O?ooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(56) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .24027 m
.00236 .21983 L
.00488 .20237 L
.00726 .18967 L
.00942 .18093 L
.01066 .17703 L
.01197 .17369 L
.01341 .1709 L
.01473 .16908 L
.01596 .168 L
.01712 .16748 L
.01839 .16743 L
.01975 .16792 L
.02113 .16895 L
.02241 .17033 L
.02382 .17227 L
.02532 .17478 L
.03062 .18672 L
.04057 .21783 L
.04631 .23575 L
.04933 .24349 L
.05097 .24701 L
.05251 .24978 L
.05398 .25193 L
.05531 .25346 L
.05602 .2541 L
.05679 .25465 L
.0576 .25508 L
.05838 .25535 L
.05974 .25546 L
.06042 .25536 L
.06118 .25512 L
.06252 .2544 L
.06377 .2534 L
.06634 .25051 L
.06905 .24659 L
.07389 .23861 L
.07961 .22981 L
.08211 .22661 L
.08481 .22372 L
.08749 .22148 L
.08996 .21996 L
.09233 .21894 L
.09352 .21854 L
.09483 .21817 L
.09748 .21753 L
.09999 .21687 L
.10138 .21642 L
.10289 .21583 L
.10554 .21446 L
Mistroke
.10804 .21274 L
.11071 .21038 L
.1155 .20462 L
.12039 .19661 L
.12482 .18785 L
.13551 .16547 L
.14134 .15406 L
.14678 .14469 L
.1564 .13283 L
.16149 .12832 L
.16435 .12636 L
.16558 .12569 L
.16695 .12509 L
.16825 .12467 L
.16946 .12441 L
.17075 .12427 L
.17214 .12427 L
.17336 .12438 L
.17464 .12461 L
.17573 .12491 L
.17693 .12533 L
.17836 .12599 L
.17965 .12677 L
.18114 .12795 L
.18255 .12939 L
.18506 .13301 L
.18647 .13578 L
.18778 .13888 L
.19013 .146 L
.19234 .15466 L
.19476 .16675 L
.19735 .18332 L
.20007 .20566 L
.20265 .23256 L
.20748 .29944 L
.2127 .38666 L
.21525 .42607 L
.2176 .45451 L
.2188 .46495 L
.22006 .47244 L
.22133 .47604 L
.22271 .47532 L
.22345 .47294 L
.22413 .46962 L
.2249 .46444 L
.22564 .45831 L
.22836 .42655 L
.23756 .28096 L
.24008 .2479 L
.24279 .21914 L
Mistroke
.24535 .198 L
.24769 .183 L
.25019 .17073 L
.25151 .16558 L
.25292 .16102 L
.25427 .15747 L
.25549 .15492 L
.25672 .15295 L
.25788 .15161 L
.2592 .15065 L
.26059 .15021 L
.26177 .15025 L
.26307 .15068 L
.2638 .15108 L
.26447 .15154 L
.26597 .15285 L
.26868 .15612 L
.27116 .16009 L
.27345 .16466 L
.27863 .17868 L
.2832 .19512 L
.28805 .21542 L
.2979 .25864 L
.30059 .26887 L
.30207 .27369 L
.30343 .27756 L
.3047 .28058 L
.30586 .28278 L
.30714 .28461 L
.30851 .28583 L
.30971 .28628 L
.31098 .28613 L
.31206 .28554 L
.31325 .28442 L
.31453 .28271 L
.3159 .28037 L
.31839 .27504 L
.32771 .24908 L
.33287 .23596 L
.33575 .23038 L
.33836 .22662 L
.33985 .225 L
.34146 .22365 L
.34298 .22271 L
.3437 .22237 L
.34438 .2221 L
.34567 .22171 L
.34636 .22157 L
.34709 .22146 L
.34786 .22139 L
Mistroke
.34859 .22136 L
.34996 .22139 L
.35117 .22149 L
.35251 .22167 L
.35522 .22215 L
.35643 .22237 L
.35773 .22257 L
.35896 .2227 L
.36008 .22275 L
.36075 .22273 L
.36147 .22267 L
.36277 .22244 L
.36357 .22222 L
.36431 .22193 L
.36571 .22123 L
.36705 .22032 L
.36828 .21928 L
.37107 .21624 L
.376 .20883 L
.38128 .19873 L
.39083 .17729 L
.40209 .1543 L
.41252 .13846 L
.41769 .13281 L
.42319 .12823 L
.42871 .12456 L
.43189 .12285 L
.43481 .12161 L
.43736 .12079 L
.44005 .12015 L
.44275 .11966 L
.4443 .11943 L
.4457 .11926 L
.44693 .11913 L
.44826 .11903 L
.449 .11898 L
.44967 .11896 L
.451 .11894 L
.45214 .11898 L
.4534 .11907 L
.45471 .11922 L
.45593 .11942 L
.45725 .1197 L
.45864 .12006 L
.46116 .12086 L
.46409 .12202 L
.46685 .12336 L
.46947 .12492 L
.4723 .12704 L
.47723 .13215 L
Mistroke
.47958 .13533 L
.48216 .13943 L
.48737 .15001 L
.49219 .16355 L
.49669 .18046 L
.50619 .23101 L
.51628 .29543 L
.51882 .30875 L
.52015 .31459 L
.52155 .3197 L
.5223 .32195 L
.52311 .32401 L
.52386 .32553 L
.52454 .32658 L
.52525 .32734 L
.526 .32778 L
.52735 .32763 L
.52867 .32635 L
.52988 .32422 L
.53121 .32094 L
.53262 .3165 L
.53758 .29515 L
.54271 .2694 L
.54822 .24449 L
.55138 .23315 L
.55427 .22504 L
.55566 .22188 L
.55717 .21898 L
.55858 .21674 L
.55992 .21501 L
.56123 .21365 L
.56244 .21267 L
.56378 .21186 L
.56449 .21155 L
.56523 .2113 L
.56591 .21113 L
.56663 .21102 L
.56793 .21098 L
.56873 .21104 L
.56948 .21116 L
.57016 .21132 L
.57089 .21154 L
.57211 .212 L
.57345 .21263 L
.57617 .21421 L
.58105 .21741 L
.58366 .21896 L
.58504 .21966 L
.58651 .22028 L
.58792 .22076 L
Mistroke
.5892 .22108 L
.59049 .22128 L
.5917 .22137 L
.59288 .22134 L
.59414 .22119 L
.59521 .22097 L
.59638 .2206 L
.59764 .22007 L
.599 .21934 L
.60144 .21757 L
.60426 .21481 L
.60733 .211 L
.61291 .2025 L
.62336 .18381 L
.64372 .14966 L
.6493 .14239 L
.65531 .13591 L
.66051 .13137 L
.66619 .12714 L
.66882 .12545 L
.67162 .1239 L
.67667 .12181 L
.67965 .12094 L
.68245 .12031 L
.68368 .12008 L
.68498 .11988 L
.68565 .11979 L
.6864 .11971 L
.68771 .11962 L
.68902 .1196 L
.69027 .11965 L
.6914 .11977 L
.69262 .11999 L
.69395 .12032 L
.69536 .1208 L
.6979 .12198 L
.70048 .12362 L
.7029 .12563 L
.70508 .12789 L
.70743 .13098 L
.70993 .13521 L
.71261 .1411 L
.71514 .14821 L
.71744 .15621 L
.72014 .16771 L
.72308 .18314 L
.72841 .22033 L
.73894 .32225 L
.74183 .34832 L
.74342 .36022 L
Mistroke
.74493 .36935 L
.74633 .37558 L
.74713 .37809 L
.74786 .37972 L
.74916 .38095 L
.75055 .37994 L
.75123 .37857 L
.75195 .37653 L
.75324 .3714 L
.75463 .36398 L
.75616 .35389 L
.76146 .3095 L
.76663 .26525 L
.77136 .2337 L
.77418 .21999 L
.77686 .21039 L
.77833 .20639 L
.77969 .20343 L
.78118 .20094 L
.78194 .19996 L
.78277 .19909 L
.78415 .1981 L
.78541 .19765 L
.78608 .19758 L
.7868 .19763 L
.78756 .19781 L
.78827 .19809 L
.78957 .19886 L
.79076 .19982 L
.79343 .20267 L
.8032 .2164 L
.80855 .22317 L
.81116 .22581 L
.81356 .2277 L
.81489 .22851 L
.81616 .22911 L
.8175 .22955 L
.81826 .22972 L
.81896 .22983 L
.81974 .22989 L
.82047 .22989 L
.82184 .22977 L
.82261 .22964 L
.82332 .22948 L
.82491 .22901 L
.82734 .22805 L
.83001 .22675 L
.83539 .22359 L
.84592 .21564 L
.85589 .20647 L
Mistroke
.8614 .19962 L
.86739 .19062 L
.87786 .17285 L
.88858 .15409 L
.89864 .13985 L
.90412 .13343 L
.90914 .12885 L
.91471 .1252 L
.91785 .12355 L
.92071 .1223 L
.92194 .12186 L
.92328 .12148 L
.92453 .12121 L
.9257 .12106 L
.92693 .121 L
.92828 .12107 L
.92896 .12116 L
.9297 .1213 L
.93102 .12164 L
.93225 .12208 L
.93359 .12268 L
.93603 .12412 L
.9384 .12606 L
.9406 .12849 L
.94197 .13041 L
.94345 .13292 L
.94613 .13888 L
.94874 .14679 L
.95114 .15624 L
.95374 .16927 L
.95659 .18744 L
.95957 .2116 L
.96234 .23957 L
.9672 .30073 L
.97248 .37348 L
.9749 .40176 L
.97622 .41421 L
.97746 .4234 L
.97851 .4291 L
.97965 .43289 L
.98091 .43414 L
.98206 .43254 L
.98316 .42859 L
.98434 .42192 L
.98545 .4135 L
.98646 .40428 L
.99126 .34643 L
1 .24028 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002Pooooo`[o00002oooool00ol0003oooooooooo`0fooooo`Ko0000B?ooool3o`0002Wooooo001;
ooooo`?o0000D?ooool2o`0000Wooooo0_l0000:ooooo`03o`000?oooooooooo03Cooooo0_l00006
ooooo`;o0000A?ooool2o`0000;ooooo0ol0000Wooooo`00B_ooool2o`0000;ooooo0_l0001=oooo
o`03o`000?oooooooooo00_ooooo0_l00008ooooo`03o`000?oooooooooo03;ooooo0_l00009oooo
o`;o0000@Oooool2o`0000Kooooo00?o0000ooooooooool09Oooool004Sooooo0_l00006ooooo`03
o`000?oooooooooo04Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`05ooooo`;o
0000<_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03gooooo00?o0000oooooooo
ool01oooool2o`0002Gooooo0017ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
Aoooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
;oooool2o`0000kooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo02?ooooo0017ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0A_oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Sooooo`00A_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo04Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo02gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool08_ooool004Gooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`15ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0>?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo02;ooooo0014ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Qooooo`00A?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08Oooool004?ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Aooooo`Co0000;?ooool00ol0003ooooooooo
o`0Gooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Pooooo`00@ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo017ooooo00Go0000oooooooooooooooo
o`00000Zooooo`03o`000?oooooooooo01Sooooo00Co0000oooooooooooooooo0_l0000[ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo023ooooo0013ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
4Oooool01Ol0003ooooooooooooooooo000002[ooooo00?o0000ooooooooool06?ooool01Ol0003o
oooooooooooooooo000002_ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool08?ooool004;ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0Jooooo`04o`000?ooooooooooo`0002_ooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool08?ooool001Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^
kP0Jooooo`05oiRHV?l@413o0000oc8b<_o<c<`00_ooool01_l0003ok^k^oc8b<_l0003o<S8bonk^
kPgooooo00?o0000ooooooooool02oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o0000onk^kP0L
ooooo`Co000000Go410@ooooooooooook^k^oc8b<P02o`000003onk^k_oooooooooo01Wooooo00Co
0000oooooooooooo00008Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hH
ooooo`03o`000?oooooo000000Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00Go
V9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04oooool00ol0003o
ooooooooo`07ooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h03_oo
ool001Kooooo00?o0000ooooooooool00_ooool2o`000003oooooonHV9SoMgMg01[ooooo00Go410@
okZj^_ooooooMgMgoc8b<P02ooooo`06o`000?mgMgOoV9RHoooooonHV9SoMgMg3Oooool00ol0003o
ooooooooo`0;ooooo`05oiRHV?lQ8B7ok^k^ooooool000000oooool01OmgMgOoV9RHooooool0003o
MgMg01kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHo`000?nHV9SoMgMg01_ooooo00Co
0000oooooooooooo00008oooool00ol0003oooooooooo`02ooooo`05ogMgMol0003ooooooiRHV?mg
MgL06?ooool01ol0003ooooooiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9So0000oiRHV?mg
MgL04oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0>ooooo`002oooool6o`0000;ooooo1Ol00002ooooo`06o`000?l@413o0000o`00
0?oooooo410@4_ooool6o`0000Kooooo00Go0000ooooool0003ooooooa0@4003ooooo`03oa0@4?oo
oooooooo00_ooooo00?o0000ooooooooool00oooool6o`0000?ooooo00?oV9RHob4Q8Ol000001?oo
ool01Ol@413oooooooooool0003o410@01?ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo
00Go410@o`000?oooooooooooa0@400Looooo`03o`000?oooooo000002?ooooo00?o0000oooooooo
ool00_ooool01Ol@413o0000oooooooooooo410@01Sooooo00Ko0000ooooooooooooV9RHob4Q8Oo^
k^h4ooooo`05oa0@4?ooooooooooooooool@41007oooool01_l0003ooooooooooooooooo410@o`00
00;ooooo00?o410@ooooooooool04Oooool00ol0003oooooooooo`05ooooo`Go00000oooool01Ol@
413ooooooooooooooooo410@00kooooo000Cooooo`04odA4A?oMgMgoooooo`0000;ooooo00Co0000
ooooool0003ooooo0ol0000Mooooo`06ojVYZOl@413oooooo`000?oooooo00000oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00gooooo00?oV9RHo`000?o^k^h00oooool01Ol0003o
oooooooooooooooo000001kooooo00?o0000ooooooooool00_ooool2o`0000;ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooo`00000Sooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00000Hooooo`07o`000?oooooooooooooooonHV9So8B4Qonk^kP03ooooo`05o`00
0?ooooooooooooooool000007_ooool00onYZJWo410@ooooo`02ooooo`05o`000?oooooooooooooo
ool000004oooool00ol0003oooooooooo`05ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000
ooooooooooooooooo`00000>ooooo`004oooool01?oMgMgoEEEEooooool00002ooooo`03o`000?oo
oooo000000;ooooo0_l0000Looooo`04oa0@4?l0003o^[Zjo`0000;ooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03o`000?oooooooooo00gooooo00?o0000ofIVI_ooool00_ooool01Ol0003o
oooooooooooooooo000001kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000001cooooo00?o0000ooooool000008oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000006Oooool01_l0003oooooooooooooooooMgMgofIVIP?ooooo00Go0000oooooooo
ooooooooo`00000Mooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00000C
ooooo`03o`000?oooooooooo00Gooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooo
oooooooo000000kooooo000Dooooo`03ogMgMoo<c<co000000;ooooo00?o0000ooooool@41000_oo
ool00ol0003o410@ooooo`0Looooo`03okZj^_lQ8B7o000000;ooooo00Go410@oooooooooooooooo
oa0@400>ooooo`03o`000?oooooooooo00gooooo0_l00003ooooo`05oa0@4?ooooooooooooooool0
00007_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool@41007Oooool3o`00
02;ooooo00Ko0000ooooooooooooooooo`000?l@4103ooooo`03oa0@4?oooooooooo01Oooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0
7?ooool01_nj^[[o8B4Qoooooooooooo0000oa0@40?ooooo00?o410@ooooooooool04_ooool00ol0
003oooooooooo`05ooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@400>
ooooo`005?ooool00oo^k^koA4A4o`000002ooooo`07o`000?ooooooMgMgoiRHV?ooooooV9RHo`00
000Jooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00ko
oooo00?o0000ooooooooool02_ooool01Ol0003o^[Zjooooool0003o410@00?ooooo00GoMgMgoiRH
V?ooooooV9RHo`00000Nooooo`0:o`000?ooooooooooooooool0003oMgMgoiRHV?ooooooV9RHogMg
Magooooo0_l0000Sooooo`0:o`000?ooooooooooo`000?ooooooMgMgoiRHV?ooooooV9RHogMgMaWo
oooo0_l000001?nj^[[ooooooiRHV?l@4103ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool0
3Ol@413oV9RHoooooonj^[[o0000ooooool0003oooooogMgMonHV9SooooooiRHV?mgMgL05?ooool0
0ol0003oooooooooo`05ooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0>ooooo`005Oooool01?mgMgOo0000ooooool00002ooooo`05onk^k_lb<S;o0000oc8b<_l00000
6_ooool01OnYZJWo410@o`000?l@413o000000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>oooo
o`03o`000?oooooooooo00[ooooo00GoV9RHoa0@4?l0003o0000olc<c003ooooo`06onk^k_lb<S;o
0000oc8b<_o^k^ko00006oooool00omEEEGoIVIVo`000003ooooo`06o`000?o^k^ko<S8bo`000?lb
<S;ok^k^7Oooool2o`00027ooooo00?oEEEEofIVI_l000000_ooool01ol0003oooooonk^k_lb<S;o
0000oc8b<_o^k^h06Oooool01_l0003oV9RHoa0@4?l0003o8B4Qolc<c0?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0Kooooo`0=ojVYZOl@413o0000oa0@4?nYZJWoooooo`000?ooooook^k^oc8b<_l0
003o<S8bonk^kP0Dooooo`03o`000?oooooooooo00Kooooo00?oMgMgo`000?ooool00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00kooooo000Hooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo027ooooo0_l0000Uoooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo01oooooo000Hooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Oooooo`006?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool07oooool001Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool03ooo
ool3o`0001Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Oooooo`005oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`0>ooooo`05o`000?ooooooooooooooool000005?ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo01kooooo000Foooooooo0000@?l0000Cooooo`005_ooool2o`00
00Kooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`;o00001oooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`05ooooo`;o00001Oooool2o`0000Oooooo00?o0000ooooooooool01Oooool2o`0000Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
017ooooo000Fooooo`;o00001_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`04o`000?oooooo0000o`0000?ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool2o`0000Kooooo00?o0000ooooooooool01Oooool01?l0003oooooooooooooool5o`0000Oooooo
00?o0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo017ooooo000Fooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool04Oooool2o`0001gooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool09_ooool2o`00017ooooo
00?o0000ooooooooool00_ooool2o`0000Oooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo01kooooo000Fooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool03Oooool4o`0001kooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool09_ooool2o`00013ooooo0_l0
0006ooooo`;o00001?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool07_ooool001Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00oooooo1Ol000001?oooooo0000o`000?l0000Yooooo`;o00004?oo
ool00ol0003oooooooooo`06ooooo`Go0000:Oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo01kooooo000Fooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0=ooooo`;o00000oooool3o`0002_ooooo00?o0000ooooool000003_ooool0
0ol0003oooooooooo`0eooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`05ooooo`;o00009_ooool00ol0003oooooooooo`0Nooooo`005_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0aooooo`03o`000?oooooo000000kooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo0_l00003ooooo`;o0000:Oooool00ol0
003oooooooooo`0Mooooo`005_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooo000000go
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_o
oooo1?l0000[ooooo`03o`000?oooooooooo01gooooo000Fooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo037ooooo
0ol0000=ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo01gooooo000Fooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooool000003Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`0Mooooo`005_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0b
ooooo`03o`000?oooooo000000gooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0A
ooooo`009Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0<oooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool04Oooool002Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo03?ooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`0h
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo017ooooo000Vooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0dooooo`04o`000?ooooooooooo`0000_ooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Aooooo`009oooool00ol0003oooooooooo`02o`00
02_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0=?ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooo
oooo03Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool04Oooool002Sooooo0ol0000/ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
03Gooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo017ooooo001Gooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo03Gooooo0_l000000ooooooo0000ooooo`09oooo
o`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0loooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04Oooool005Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0=Oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool04_ooool005Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0=_ooool01Ol0003ooooooooooooooooo0000
00Wooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
03cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`00Eoooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0fooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`0joooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo01;ooooo001Gooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Kooooo00Go0000oooooooo
ooooooooo`000008ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0looooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool005Oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0=oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Booooo`00Eoooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0gooooo`05
o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
01;ooooo001Gooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04oooool01?l0003o
ooooooooool0000jooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo01;ooooo001Gooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool04oooool01?l0003oooooo`000?l0000jooooo`;o00000_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0m
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool005Sooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Dooooo`;o0000>oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo03kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Boooo
o`00F?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo057ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03cooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool04_ooool005Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Aooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0looooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo01;ooooo001Hooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0DOoo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0??oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Cooooo`00F?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo057ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool04oooool005Sooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`16ooooo`Go00001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`00F?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo04Kooooo00GoV9RHob4Q8Oo^k^koooooodA4A006oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0moooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01?ooooo001Hooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0B?ooool00onHV9So8B4Qonk^kP07ooooo`?o00000oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool005Sooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`19ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
4oooool005Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1:ooooo`03ogMgMomV
IVKooooo00Gooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000047ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool04oooool005Sooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool01Ol0003ooooooooo
oooooooo0000047ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool04oooool005Sooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`17ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003ooooo
ooooo`04ooooo`04o`000?ooooooooooo`00047ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`10ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool005Sooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`17ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000004;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool04oooool005Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Booooo`03o`00
0?oooooooooo00Gooooo0_l00012ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
@?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo001Hooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`19ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01Cooooo001Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0D_ooool2
o`0004[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`10ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool05?ooool005Sooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Booooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`10ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05?ooool005So
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo04[o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool05?ooool005Sooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`1Booooo`03o`000?oooooooooo04[ooooo00Go0000ooooooooooooooooo`000014ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool05?ooool005Wooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo04[ooooo00Go0000oooooooooooo
ooooo`000014ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05?ooool005Wooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo04[ooooo
00Go0000ooooooooooooooooo`000014ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool05?ooool005Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Booooo`03o`00
0?oooooooooo04[ooooo00Go0000ooooooooooooooooo`000014ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool05?ooool005Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1Cooooo`03o`000?oooooooooo04[ooooo00Go0000ooooooooooooooooo`000014ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool05?ooool005Wooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo04[ooooo00Go0000oooooooooooo
ooooo`000014ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05?ooool005Wooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`1Cooooo`;o0000Boooool01Ol0003ooooo
oooooooooooo000004Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Dooooo`00
FOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0
Boooool01?l0003oooooooooool00014ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool05?ooool005Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Cooooo`03o`00
0?oooooooooo04_ooooo00Co0000oooooooooooo0000A?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo01Cooooo001Iooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
Doooool00ol0003oooooooooo`1;ooooo`04o`000?ooooooooooo`0004Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Dooooo`00FOooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo05?ooooo00?o0000ooooooooool0Boooool01?l0003oooooooooool00014ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool05?ooool005Wooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo04cooooo0_l00015ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool05Oooool005Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo04cooooo0_l00015ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool05Oooool005Wooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1Cooooo`03o`000?oooooooooo09?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Eooooo`00FOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
05?ooooo0_l0002Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05Oooool005Wo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo09Co
oooo00Go0000ooooooooooooooooo`00000Gooooo`00FOooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo05?ooooo00?o0000ooooooooool0U?ooool01Ol0003ooooooooooooooooo0000
01Oooooo001Iooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Doooool00ol0003o
ooooooooo`2Dooooo`05o`000?ooooooooooooooool000005oooool005Wooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo09Cooooo00Go0000oooooooo
ooooooooo`00000Gooooo`00FOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04[o
oooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo09Cooooo00Go0000oooooooo
ooooooooo`00000Gooooo`00FOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Dooooo`05o`000?oooooooooooooo
ool000005oooool005[ooooo00Go0000ooooooooooooooooo`00001;ooooo`Go00001_ooool00ol0
003oooooooooo`2Dooooo`04o`000?ooooooooooo`0001Sooooo001Jooooo`05o`000?oooooooooo
ooooool00000Boooool01?m4A4CogMgMooooool00007ooooo`?o0000U?ooool01?l0003ooooooooo
ool0000Hooooo`00F_ooool01Ol0003ooooooooooooooooo000004_ooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`2Dooooo`04o`000?ooooooooooo`0001Sooooo001Jooooo`05
o`000?ooooooooooooooool00000C?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo
09Cooooo00Co0000oooooooooooo00006?ooool005[ooooo00Go0000ooooooooooooooooo`00001<
ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0UOooool00ol0003oooooo`00000H
ooooo`00F_ooool01Ol0003ooooooooooooooooo000004gooooo00?oMgMgo`000?ooool01_ooool0
0ol0003oooooooooo`2Eooooo`03o`000?oooooo000001Sooooo001Jooooo`05o`000?oooooooooo
ooooool00000E_ooool00ol0003oooooooooo`2Eooooo`03o`000?oooooo000001Sooooo001Joooo
o`05o`000?ooooooooooooooool00000E_ooool00ol0003oooooooooo`2Eooooo`;o00006Oooool0
05[ooooo00Go0000ooooooooooooooooo`00001Fooooo`03o`000?oooooooooo09Kooooo00?o0000
ooooooooool05oooool005[ooooo00Go0000ooooooooooooooooo`00001Fooooo`;o0000/Oooool0
05_ooooo00Co0000oooooooooooo0000E_ooool00ol0003oooooooooo`2`ooooo`00Foooool01?l0
003oooooooooool0001Fooooo`03o`000?oooooooooo0;3ooooo001Kooooo`04o`000?oooooooooo
o`0005Kooooo00?o0000ooooooooool0/?ooool005_ooooo00Co0000oooooooooooo0000E_ooool0
0ol0003oooooooooo`2`ooooo`00Foooool01?l0003oooooooooool0001Fooooo`03o`000?oooooo
oooo0;3ooooo001Kooooo`04o`000?ooooooooooo`0005Kooooo00?o0000ooooooooool0/?ooool0
05_ooooo00Co0000oooooooooooo0000E_ooool00ol0003oooooooooo`2`ooooo`00Foooool01?l0
003oooooooooool0001Fooooo`;o0000/Oooool005_ooooo00?o0000ooooool00000Eoooool00ol0
003oooooooooo`2`ooooo`00Foooool00ol0003oooooo`00001Gooooo`03o`000?oooooooooo0;3o
oooo001Looooo`;o0000Eoooool00ol0003oooooooooo`2`ooooo`00G?ooool2o`0005Oooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo
002Zooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_oo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0002`ooooo`00Z_ooool01Ol0003oEEEEo`00
0?l@413oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00?oEEEEohN7Qoooool02?oo
ool00ol0003oooooooooo`2`ooooo`00Z_ooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooo
oooo0;3ooooo002[ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo00Goc<c<ob4Q
8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06
ooooo`?o0000/?ooool00:[ooooo00Goc<c<o`000?l0003o0000olc<c02iooooo`00Z_ooool01Ol@
413o^[Zjoooooonj^[[o410@0;Wooooo002Zooooo`05o`000?nj^[[ooooookZj^_l00000^Oooool0
0:[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2iooooo`00oooooomYooooo`00/oooool00ol0003o
^[Zjooooo`2booooo`00/oooool2oc8b<[?ooooo0024ooooo`;o000000Ko410@oooooooooooo410@
o`000?l@410Hooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Wooooo00Go
A4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0O?ooool008Gooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00003Oooool02OmgMgOo<S8b
ooooooooooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03olc<c?l0003o410@00cooooo00Go410@
okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003Oooool02OmgMgOo<S8booooooooooooEEEEogMgMooo
ooooV9RHob4Q8@1looooo`00QOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01_o
oooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`0@ooooo`03o`000?oooooooooo
01oooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`1jooooo`00QOooool01_l0
003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000=ooooo`05ogMgMolb<S;oooooooooool00000
0oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo1_l0000=ooooo`09ogMg
Molb<S;oooooooooool0003oV9RHoooooonHV9So8B4Q07cooooo0025ooooo`06o`000?oMgMgo<S8b
oeEEEOoMgMgo00006Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooooooooooo
ooooo`00000Booooo`03o`000?oooooooooo01_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002oooo
o`05o`000?mEEEGo0000oa0@4?o<c<`0O?ooool008Gooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0
000Iooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400@ooooo`03oa0@
4?l0003o000000?o00006_ooool00ol0003oooooooooo`04ooooo`03oeEEEOn7QhOooooo07kooooo
0025ooooo`06o`000?lb<S;ooooooooooolb<S;o00006Oooool00ol0003oooooooooo`04ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL04_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
00Cooooo00?ogMgMoa0@4?nHV9P0O_ooool008Cooooo00?o410@o`000?n7QhL00_ooool00on7QhOo
0000oa0@400Hooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo00?o0000oooo
ooooool06oooool4o`0000Cooooo00Coc<c<odA4A?l0003o410@O?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(58) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .3493 m
.00942 .30865 L
.01975 .27141 L
.02496 .25741 L
.03053 .24511 L
.03575 .23578 L
.03804 .23241 L
.04057 .22934 L
.0419 .22802 L
.04334 .22687 L
.04413 .22636 L
.04486 .22597 L
.04558 .22565 L
.04628 .22543 L
.04702 .22527 L
.04781 .2252 L
.04856 .22523 L
.04924 .22533 L
.05004 .22554 L
.05091 .22589 L
.05172 .22633 L
.05248 .22683 L
.05508 .22922 L
.05657 .23102 L
.05795 .23296 L
.06373 .24317 L
.06896 .25323 L
.07153 .25742 L
.07266 .25893 L
.0739 .26032 L
.07523 .26141 L
.07595 .26183 L
.07664 .26209 L
.07738 .26224 L
.07807 .26224 L
.07882 .26209 L
.07961 .26175 L
.08089 .26081 L
.08209 .25949 L
.08341 .25756 L
.08481 .25496 L
.08753 .24846 L
.0904 .23976 L
.09556 .22097 L
.10722 .17703 L
.11208 .16222 L
.1173 .14935 L
.12302 .13869 L
.12838 .13161 L
.13105 .12893 L
Mistroke
.1339 .12655 L
.13636 .12485 L
.13902 .12332 L
.14215 .12194 L
.14359 .12144 L
.1451 .12101 L
.14647 .12069 L
.14798 .12041 L
.14934 .12021 L
.15061 .12007 L
.15193 .11996 L
.15262 .11991 L
.15336 .11987 L
.1547 .11982 L
.15595 .1198 L
.15714 .11981 L
.15826 .11984 L
.15949 .1199 L
.16081 .12 L
.16214 .12015 L
.16359 .12036 L
.16651 .12093 L
.17172 .12237 L
.1744 .12326 L
.17729 .12439 L
.17984 .12558 L
.18254 .12712 L
.18765 .13111 L
.19235 .13629 L
.19497 .14 L
.19778 .14494 L
.20284 .15753 L
.20594 .16842 L
.20887 .18163 L
.21437 .21581 L
.21917 .25793 L
.22449 .31699 L
.22966 .37691 L
.23108 .3912 L
.23257 .40432 L
.23386 .4137 L
.23524 .42138 L
.23654 .42617 L
.23771 .42842 L
.23889 .42861 L
.24 .42692 L
.2413 .42275 L
.2425 .41696 L
.24382 .40871 L
.24521 .39816 L
Mistroke
.25458 .31106 L
.25723 .29034 L
.25974 .27432 L
.262 .26301 L
.26447 .25377 L
.26587 .24981 L
.26714 .24695 L
.26861 .24443 L
.26999 .24274 L
.27127 .24171 L
.27245 .24115 L
.27374 .24093 L
.27511 .24105 L
.2763 .24141 L
.27739 .24189 L
.27985 .2433 L
.28427 .24601 L
.28547 .24659 L
.28674 .2471 L
.28741 .24731 L
.28814 .2475 L
.28944 .24772 L
.29065 .24779 L
.29196 .24772 L
.29319 .24753 L
.29433 .24726 L
.29927 .24523 L
.30394 .2428 L
.3052 .24223 L
.30653 .24173 L
.30722 .24152 L
.30798 .24134 L
.30932 .24116 L
.31054 .24118 L
.31185 .24141 L
.31308 .24185 L
.31421 .24245 L
.31565 .24348 L
.31698 .24471 L
.31999 .2484 L
.32548 .25755 L
.32813 .26246 L
.33094 .26736 L
.33219 .26932 L
.33353 .27117 L
.33478 .27261 L
.33595 .27367 L
.33729 .27448 L
.33851 .27481 L
.33985 .27468 L
Mistroke
.34061 .27436 L
.34131 .27391 L
.34264 .27261 L
.3434 .27162 L
.34411 .27052 L
.34709 .26425 L
.34972 .25663 L
.35213 .24829 L
.35756 .2265 L
.36702 .18751 L
.37222 .16948 L
.37711 .15571 L
.38253 .14391 L
.38744 .13585 L
.39205 .13023 L
.39704 .12589 L
.39966 .12419 L
.40255 .12269 L
.40556 .1215 L
.407 .12105 L
.40837 .12069 L
.40963 .12042 L
.411 .12018 L
.41225 .12003 L
.4134 .11993 L
.41464 .11986 L
.41602 .11985 L
.41671 .11986 L
.41745 .11989 L
.41879 .11997 L
.42011 .12009 L
.42131 .12023 L
.424 .12067 L
.42649 .1212 L
.42884 .12183 L
.43411 .12369 L
.43983 .12636 L
.45135 .13352 L
.46198 .14249 L
.47215 .1536 L
.48167 .16784 L
.48713 .17853 L
.49212 .19053 L
.50334 .22622 L
.51301 .26181 L
.51579 .27093 L
.51841 .27831 L
.52076 .28364 L
.52208 .286 L
.5233 .28779 L
Mistroke
.52467 .28927 L
.52539 .28985 L
.52617 .2903 L
.52698 .29059 L
.52775 .2907 L
.52844 .29067 L
.52919 .29049 L
.53055 .28981 L
.53124 .2893 L
.532 .28862 L
.5346 .28546 L
.54001 .27626 L
.54508 .26713 L
.54747 .26344 L
.55002 .26025 L
.55149 .25882 L
.55282 .25778 L
.55416 .25698 L
.55542 .25646 L
.55674 .25613 L
.55741 .25604 L
.55814 .256 L
.55943 .25606 L
.56064 .25624 L
.56137 .25641 L
.56207 .25659 L
.56337 .25699 L
.5663 .25797 L
.56751 .25834 L
.56864 .25861 L
.56982 .2588 L
.57113 .25886 L
.57225 .25876 L
.57328 .25852 L
.57441 .25808 L
.5756 .2574 L
.57681 .25645 L
.57811 .25515 L
.58044 .252 L
.58322 .24691 L
.58574 .2411 L
.59632 .2086 L
.60754 .17271 L
.61712 .14946 L
.62257 .13977 L
.62767 .13273 L
.63288 .12728 L
.63782 .12344 L
.64226 .12089 L
.64478 .11978 L
Mistroke
.64711 .11894 L
.64842 .11855 L
.64984 .1182 L
.6511 .11794 L
.65242 .11771 L
.65361 .11756 L
.65492 .11743 L
.65612 .11736 L
.65723 .11733 L
.6579 .11733 L
.65863 .11734 L
.65995 .1174 L
.66124 .1175 L
.66244 .11763 L
.66372 .11781 L
.66514 .11807 L
.66802 .11878 L
.67048 .11959 L
.67318 .12069 L
.67862 .12364 L
.68365 .12729 L
.68834 .13159 L
.69893 .14515 L
.70485 .15532 L
.71024 .16643 L
.72072 .19383 L
.73039 .22688 L
.74167 .2746 L
.74719 .29831 L
.7496 .30762 L
.75223 .31641 L
.75345 .31988 L
.75476 .32308 L
.75588 .32538 L
.7571 .32735 L
.75835 .32879 L
.75953 .32958 L
.76068 .32981 L
.76173 .32956 L
.76295 .32871 L
.7641 .32739 L
.76535 .32539 L
.76669 .32263 L
.76944 .31528 L
.77193 .307 L
.7774 .28604 L
.7832 .26414 L
.78815 .24904 L
.79097 .24259 L
.79223 .24025 L
Mistroke
.79361 .2381 L
.79495 .2364 L
.7962 .23517 L
.79739 .2343 L
.79866 .23369 L
.79991 .23339 L
.80108 .23338 L
.80214 .23358 L
.80328 .23399 L
.80454 .23468 L
.80592 .23567 L
.8087 .23828 L
.81369 .24395 L
.81649 .2469 L
.81786 .24811 L
.81913 .24902 L
.81983 .24943 L
.8206 .24979 L
.82137 .25005 L
.82219 .2502 L
.82288 .25024 L
.82362 .25017 L
.82497 .24975 L
.82625 .249 L
.82697 .24841 L
.82765 .24775 L
.83047 .24393 L
.8329 .23925 L
.83551 .23299 L
.84565 .20105 L
.8564 .16723 L
.86201 .15322 L
.86818 .1412 L
.8738 .1331 L
.87905 .12749 L
.88165 .12531 L
.88447 .12331 L
.88696 .12185 L
.88962 .12056 L
.89225 .11953 L
.89463 .11879 L
.89702 .1182 L
.89927 .11778 L
.90054 .11759 L
.90192 .11743 L
.90262 .11737 L
.90337 .11732 L
.90472 .11725 L
.90606 .11723 L
.90733 .11725 L
Mistroke
.90848 .11729 L
.90972 .11738 L
.91107 .11752 L
.91256 .11771 L
.91559 .11828 L
.91838 .119 L
.92101 .11987 L
.92595 .12211 L
.92875 .1238 L
.93135 .12571 L
.93661 .13074 L
.94222 .13838 L
.94747 .14845 L
.95241 .16153 L
.95685 .17708 L
.96166 .19883 L
1 .3493 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo02cooooo
1_l00019ooooo`Oo0000;_ooool004?ooooo2Ol0001;ooooo`Oo00005oooool00ol0003ooooooooo
o`0Zooooo`?o00001Oooool4o`0004?ooooo0ol00006ooooo`;o0000;?ooool0047ooooo0ol00008
ooooo`?o0000A_ooool2o`0000Oooooo1?l0000Cooooo`03o`000?oooooooooo02Sooooo0_l0000<
ooooo`03o`000?oooooooooo03kooooo0_l0000;ooooo`;o0000:_ooool0043ooooo00?o0000oooo
ooooool03?ooool2o`0004?ooooo00?o0000ooooooooool02oooool2o`00017ooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03cooooo00?o0000oooo
ooooool03Oooool2o`0002Sooooo000oooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0?oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo0_l0000Xooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo02Gooooo000oooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
?Oooool00ol0003oooooooooo`0@ooooo`;o00003_ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo02Gooooo000nooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Tooooo`00?Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool08oooool003gooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo02?ooooo000looooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Rooooo`00>oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0booooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool08_ooool003_ooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02;ooooo000j
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00Kooooo0_l0000Rooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo027ooooo000joooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Qoooo
o`00>Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool08?ooool001Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0I
ooooo`06o`000?nHV9So410@o`000?lb<S;oc<c<0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^013o
oooo00?o0000ooooooooool02?ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Loooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQOooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Oooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kQCooooo00?o0000ooooooooool00oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0Kooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01?o
oooo00?o0000ooooooooool01oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb
<S;ok^k^00kooooo000Fooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Iooooo`06o`000?l@413o^[ZjoooooomgMgOo<S8b0oooool01OmgMgOoV9RHoooooonHV9SoMgMg
013ooooo00?o0000ooooooooool02?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08?ooool2o`0000Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0Eooooo`03o`000?oooooooooo00;ooooo00GoV9RHob4Q8Oo^
k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool01Ol@413o0000oooooomg
MgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Cooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko0000
0_ooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Booooo`Oo00001Oooool01Ol0003o
oooooooooooooooo410@00?ooooo00?o410@ooooooooool03_ooool00ol0003oooooooooo`06o`00
00?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01?ooooo1_l00004
ooooo`;o00001?ooool01Ol@413ooooooooooooooooo410@01Sooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Pooooo`;o00001?ooool01Ol@413ooooooooooooooooo410@01Gooooo
00?o0000ooooooooool00oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@
41007?ooool01?l0003oooooooooool00003ooooo`05oa0@4?ooooooooooooooool@41005?ooool0
0ol0003oooooooooo`04ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00kooooo000C
ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000Hooooo`03o`00
0?oooooooooo00;ooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo0000013o
oooo00?o0000ooooooooool02_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooooooooooo
ool000007Oooool2o`0000Cooooo00Go0000ooooooooooooooooo`00000Iooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool07oooool00ol0003oooooo`000004ooooo`05o`000?oooooo
ooooooooool000005_ooool00ol0003oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go
0000ooooooooooooooooo`00000Looooo`04o`000?ooooooZJVYoa0@40?ooooo00Go0000oooooooo
ooooooooo`00000Dooooo`03o`000?oooooooooo00Cooooo00CoA4A4omgMgOoooooo00001?ooool0
1Ol0003ooooooooooooooooo000000kooooo000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go
0000ooooooooooooooooo`00000Hooooo`07o`000?ooooooooooooooool@413o0000okZj^P03oooo
o`05o`000?ooooooooooooooool000004Oooool00ol0003oooooooooo`0:ooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`;o00001?ooool01Ol0003ooooooooo
oooooooo000001Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooo000000Cooooo00Go0000ooooooooooooooooo`00000Fooooo`03o`000?oooooooooo00Co
oooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000001_ooooo00Go0000oooo
ool@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000005?ooool00ol0003ooooooooo
o`04ooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`00
5?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41006?ooool00ol0003o
ooooooooo`02ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@400Aoooo
o`03o`000?oooooooooo00_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooo
oooo01[ooooo00?o0000ooooool000001?ooool01Ol@413ooooooooooooooooo410@01[ooooo00Co
0000oooooooooooooooo0_l0000Pooooo`03o`000?oooooo000000Cooooo00Go410@oooooooooooo
oooooa0@400Fooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooooooooooooa0@4003oooo
o`03oa0@4?oooooooooo01Wooooo00Go0000oooooooooooo^[Zjob4Q8@03ooooo`05oa0@4?oooooo
ooooooooool@41005?ooool00ol0003oooooooooo`05ooooo`03ogMgMoo<c<co000000Cooooo00Go
410@oooooooooooooooooa0@400>ooooo`005?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL06?ooool01ol0003ooooooa0@4?nHV9SooooookZj^_l000000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg017ooooo00?o0000ooooooooool01oooool01Ol0003o^[ZjoooooonH
V9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`03o`000?oooooo000000Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05o`000?ooooooooooooooool000008?ooool01?l0
003oooooooooool00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05oooool02?l0003ooooooooo
ool0003o^[ZjoooooonHV9So410@0oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000
oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05?ooool00ol0003ooooo
ooooo`05ooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`00
5Oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h05oooool02?l0003o
oooooooooonYZJWo410@o`000?l@413oZJVY0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^017ooooo
00?o0000ooooooooool01oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0Looooo`03o`000?mVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0K
ooooo`04o`000?ooooooooooo`00023ooooo00Co0000oeEEEOmVIVKo00001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01Oooooo00So0000ooooooooooooV9RHoa0@4?l0003o8B4Qolc<c0?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0Jooooo`06o`000?nYZJWo410@o`000?l@413oZJVY0oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^01Gooooo00?o0000ooooooooool01Oooool00omgMgOo0000ooooo`03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool003Oooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02Cooooo00Co0000oooooooooooo00008?oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`0Nooooo`00=oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo02oooooo00?o0000ooooooooool09?ooool01?l0003oooooooooool0000Oooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo01kooooo000fooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooo000001oooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool07Oooool0
03Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooool000007oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Mooooo`00=_ooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool09_ooool00ol0003o
ooooo`00000Oooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo01gooooo000Foooooooo0000@?l0000Cooooo`005_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01?ooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo
017ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l00006ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l00007
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04
ooooo`;o00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00001oooool00ol0003oooooooooo`0Aooooo`00=Oooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo01cooooo000dooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool07?ooool003Cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Kooooo`00
9Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
:oooool00ol0003oooooooooo`0Zooooo`;o00006oooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Kooooo`008ooo
ool2o`000003ooooool0003ooooo00_ooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0[ooooo`03o`000?oooooooooo02[ooooo0_l0000Kooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01_ooooo000S
ooooo`04o`000?ooooooooooooooo`;o00002_ooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool0:_ooool2o`0001_ooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool06ooo
ool002;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Zooooo`;o00006_ooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01?ooooo0ol00009ooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool06_ooool0027ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooo000001Wooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0Jooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool0:oooool00ol0003oooooo`00000Iooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`;o00001_ooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo01[ooooo000Pooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00ko
oooo00Co0000ooooool0003o00001_ooool5o`0000cooooo00?o0000ooooooooool0:oooool00ol0
003oooooo`00000Hooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`0Jooooo`007oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;o
oooo0_l000001?oooooo0000o`000?l00005ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0;?ooool01?l0003oooooooooool0000Fooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool00000;Ooo
ool00ol0003oooooooooo`0Iooooo`007oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00Cooooo0ol00008ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0;?ooool0
1?l0003oooooooooool0000Fooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`06ooooo`Co0000;_ooool00ol0003oooooooooo`0Iooooo`007oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0/ooooo`04o`000?ooooooooooo`0001Gooooo00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool06Ooo
ool001kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0;Oooool01?l0003oooooooooool0000>ooooo`?o00000ooo
ool2o`00037ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo01Wooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l00002ooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0;Oooool2o`0000;ooooo00?o0000ooooooooool02Oooool2
o`0000;ooooo1Ol0000cooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0Hooooo`007_ooool00ol0003oooooooooo`0<ooooo`?o0000:oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0^ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0H
ooooo`007Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02kooooo00Go0000oooo
ooooooooooooo`00000:ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Sooooo000Mooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool06?ooool001cooooo00?o0000ooooooooool0??ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo01Gooooo00Co0000oooooooooooo0000<Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool05oooool001co
oooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Go
oooo1?l0000aooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0mooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0?Oooool00ol0003o
ooooooooo`0Gooooo`007?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0B_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0?Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03gooooo
00?o0000ooooooooool05oooool001_ooooo00?o0000ooooooooool0?_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo01Oooooo000Kooooo`03o`000?oooooooooo03kooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`1:ooooo`;o00001?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo01Kooooo000Kooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`000012ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0?oooool0
0ol0003oooooooooo`0Fooooo`006oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`05ooooo`?o0000@oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool05_ooool001[o
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04[o
oooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo043o
oooo00?o0000ooooooooool05_ooool001[ooooo00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0C?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool05Oooool001[ooooo00?o
0000ooooooooool0?oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04[ooooo00?o
0000ooooooooool0C?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo047ooooo00?o
0000ooooooooool05Oooool001[ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo043ooooo1Ol00006ooooo`03o`000?oooooooooo04cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01Gooooo000Ioooo
o`03o`000?oooooooooo047ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`10oooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Eooooo`006Oooool00ol0
003oooooooooo`11ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0@Oooool00onH
V9So8B4Qonk^kP07ooooo`?o0000C?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
04?ooooo00?o0000ooooooooool05?ooool001Wooooo00?o0000ooooooooool0@Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo04;ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003o
ooooooooo`1<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0@oooool00ol0003o
ooooooooo`0Dooooo`006Oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0@oooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo04gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01Cooooo
000Hooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`14ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0COooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool05?ooool001Sooooo00?o0000
ooooooooool0@_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo043ooooo00Go0000
okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo04kooooo00Go0000oooooooooooooooo
o`000017ooooo`03o`000?oooooooooo01?ooooo000Hooooo`03o`000?oooooooooo04;ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`10ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
1_ooool00ol0003oooooooooo`1>ooooo`04o`000?ooooooooooo`0004Sooooo00?o0000oooooooo
ool04oooool001Sooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo04_ooooo00?o0000ooooooooool0Coooool00ol0003oooooo`000018ooooo`03o`00
0?oooooooooo01?ooooo000Gooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0Aooo
ool00ol0003oooooooooo`0Cooooo`005oooool00ol0003oooooooooo`13ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0C?ooool2o`0009cooooo00?o0000ooooooooool04_ooool0
01Oooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
04cooooo00?o0000ooooooooool0Voooool00ol0003oooooooooo`0Booooo`005oooool00ol0003o
ooooooooo`14ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0C?ooool00ol0003o
ooooooooo`2Kooooo`03o`000?oooooooooo01;ooooo000Gooooo`03o`000?oooooooooo04Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo09_ooooo
00?o0000ooooooooool04_ooool001Kooooo00?o0000ooooooooool0AOooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0W?ooool00ol0003ooooooooo
o`0Aooooo`005_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0C?ooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo017ooooo001Noooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`2`oooo
o`00G_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04cooooo00?o0000oooooooo
ool0/?ooool005kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1=ooooo`03o`00
0?oooooooooo0;3ooooo001Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0COoo
ool2o`000;7ooooo001Oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0COooool0
0ol0003oooooooooo`2`ooooo`00Goooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
04gooooo00?o0000ooooooooool0/?ooool005oooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`1=ooooo`03o`000?oooooooooo0;3ooooo001Oooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0COooool00ol0003oooooooooo`2`ooooo`00Goooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0/?ooool005oooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo0;3ooooo001Ooooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`2`oooo
o`00Goooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04kooooo0_l0002aooooo`00
Goooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0
/?ooool005oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1>ooooo`03o`000?oo
oooooooo0;3ooooo001Oooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0C_ooool0
0ol0003oooooooooo`2`ooooo`00H?ooool01Ol0003ooooooooooooooooo0000053ooooo00?o0000
ooooooooool0/?ooool0063ooooo00Go0000ooooooooooooooooo`000017ooooo`;o000000?o410@
ooooooooool01?ooool00ol0003oooooooooo`2`ooooo`00H?ooool01?l0003oooooooooool00019
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool0063ooooo00Co0000oooo
oooooooo0000A_ooool5o`0000Kooooo00?o0000ooooooooool0/?ooool0063ooooo00Co0000oooo
oooooooo0000A_ooool01?m4A4CogMgMooooool00007ooooo`?o0000/?ooool0063ooooo00Co0000
oooooooooooo0000A_ooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo0;3ooooo
001Qooooo`03o`000?oooooo000004Oooooo00?oMgMgolc<c?l000001oooool00ol0003ooooooooo
o`2`ooooo`00HOooool00ol0003oooooo`000017ooooo`03onk^k_m4A4Co000000Oooooo00?o0000
ooooooooool0/?ooool0067ooooo00?o0000ooooool00000B?ooool00omgMgOo0000ooooo`06oooo
o`03o`000?oooooooooo0;3ooooo001Qooooo`;o0000D_ooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00Z_ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000oooo
ooooool0/?ooool00:[ooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo
0;3ooooo002Zooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`2`oooo
o`00Z_ooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0002`ooooo`00Z_ooool01Ol0003o
EEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00?oEEEEohN7Qooo
ool02?ooool00ol0003oooooooooo`2`ooooo`00Z_ooool00ooMgMgo410@oiRHV008ooooo`03o`00
0?oooooooooo0;3ooooo002[ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go
c<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go<S8boiRHV?ooooooV9RH
oc8b<P06ooooo`?o0000/?ooool00:[ooooo00Goc<c<o`000?l0003o0000olc<c02iooooo`00Z_oo
ool01Ol@413o^[Zjoooooonj^[[o410@0;Wooooo002Zooooo`05o`000?nj^[[ooooookZj^_l00000
^Oooool00:[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2iooooo`00oooooomYooooo`00/oooool0
0ol0003o^[Zjooooo`2booooo`00/oooool2oc8b<[?ooooo0024ooooo`;o000000Ko410@oooooooo
oooo410@o`000?l@410Hooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Wo
oooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0O?ooool0
08Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00003Oooool02Omg
MgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03olc<c?l0003o410@00cooooo
00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003Oooool02OmgMgOo<S8boooooooooooo8B4Q
oiRHV?ooooooV9RHob4Q8@1looooo`00QOooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo01_ooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`0@ooooo`03o`000?oo
oooooooo01oooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`1jooooo`00QOoo
ool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000=ooooo`05ogMgMolb<S;ooooooooo
ool000000oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo1_l0000=oooo
o`09ogMgMolb<S;ooooooooooolb<S;oV9RHoooooonHV9So<S8b07cooooo0025ooooo`06o`000?oM
gMgo<S8boeEEEOoMgMgo00006Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooo
ooooooooooooo`00000Booooo`03o`000?oooooooooo01_ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c002ooooo`05olc<c?l0003o0000o`000?o<c<`0O?ooool008Gooooo00Ko0000ohN7QonYZJWo^[Zj
oeEEEOl0000Iooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400@oooo
o`03oa0@4?l0003o000000?o00006_ooool00ol0003oooooooooo`04ooooo`05oa0@4?nj^[[ooooo
okZj^_l@4100O?ooool008Gooooo00Ko0000oc8b<_oooooooooooc8b<_l0000Iooooo`03o`000?oo
oooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Booooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool01?ooool01Ol0003o^[Zjoooooonj^[[o000007cooooo0024ooooo`03oa0@
4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0Booooo`03o`000?oooooooooo01_ooooo1?l00003ooooo`05ojVYZOl@413o0000oa0@
4?nYZJT0O?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .316 m
.04057 .26122 L
.05077 .28816 L
.05346 .29776 L
.05488 .30237 L
.05638 .30664 L
.05769 .30969 L
.05839 .31101 L
.05914 .31216 L
.06045 .31348 L
.06168 .31384 L
.06248 .3136 L
.06336 .31289 L
.06419 .31179 L
.06496 .31041 L
.06641 .30683 L
.06795 .30171 L
.07094 .28845 L
.07365 .2735 L
.08481 .20546 L
.08981 .18071 L
.09509 .16078 L
.09785 .15275 L
.10088 .14558 L
.10366 .14029 L
.1062 .1364 L
.11123 .13076 L
.114 .12857 L
.11663 .12698 L
.11905 .12586 L
.12129 .12507 L
.12375 .12444 L
.12499 .12419 L
.12636 .12398 L
.12755 .12383 L
.12882 .1237 L
.12956 .12364 L
.13022 .1236 L
.13152 .12354 L
.13286 .12351 L
.13362 .12351 L
.13432 .12352 L
.1356 .12355 L
.13696 .12361 L
.13811 .12369 L
.13935 .1238 L
.14158 .12404 L
.14667 .12482 L
.15254 .12603 L
.15812 .12765 L
Mistroke
.16312 .12965 L
.16857 .1325 L
.17417 .13641 L
.17943 .1414 L
.18416 .14716 L
.18927 .15488 L
.20075 .17822 L
.21131 .20351 L
.21664 .215 L
.22168 .22384 L
.2275 .23113 L
.23279 .23635 L
.23521 .23907 L
.23778 .24272 L
.23997 .24679 L
.24239 .25265 L
.24498 .26093 L
.24777 .27259 L
.25282 .3018 L
.25809 .34145 L
.26298 .3783 L
.26545 .39275 L
.26683 .39872 L
.26809 .40256 L
.26946 .4049 L
.27024 .40529 L
.27096 .40506 L
.27227 .40314 L
.27294 .40144 L
.27366 .39904 L
.27494 .39351 L
.27615 .38686 L
.27842 .37127 L
.28353 .32778 L
.28828 .28786 L
.29061 .27149 L
.29275 .25904 L
.29506 .24862 L
.29627 .24445 L
.29756 .24103 L
.29887 .23856 L
.30009 .23718 L
.30143 .23668 L
.30218 .23686 L
.30287 .2373 L
.30425 .23897 L
.30552 .24141 L
.30692 .24503 L
.3084 .24987 L
.31363 .27329 L
Mistroke
.31806 .29642 L
.32051 .30798 L
.32283 .31686 L
.32414 .3206 L
.32487 .32225 L
.32556 .32345 L
.32677 .32477 L
.32806 .325 L
.32938 .32393 L
.33063 .32171 L
.33175 .31875 L
.33296 .31455 L
.34287 .25414 L
.34833 .21651 L
.3535 .18671 L
.35642 .17308 L
.3596 .16084 L
.36224 .15255 L
.36516 .1452 L
.3679 .13979 L
.37081 .13537 L
.3735 .13228 L
.37603 .13009 L
.37846 .12852 L
.37983 .12784 L
.38111 .12732 L
.38246 .12689 L
.38369 .1266 L
.38438 .12647 L
.38511 .12636 L
.38645 .12624 L
.3876 .12621 L
.38887 .12624 L
.39019 .12634 L
.39142 .12648 L
.39258 .12666 L
.39363 .12685 L
.396 .12738 L
.40128 .12893 L
.40704 .13111 L
.41752 .13562 L
.43996 .14411 L
.44511 .14594 L
.45055 .14826 L
.45519 .15082 L
.46027 .15456 L
.46555 .16003 L
.47047 .16704 L
.47579 .177 L
.48148 .19039 L
Mistroke
.49185 .21918 L
.49641 .23081 L
.49883 .23593 L
.50143 .2403 L
.50283 .24211 L
.50412 .24339 L
.50541 .24433 L
.50663 .24488 L
.508 .24511 L
.50927 .24496 L
.51 .24473 L
.51067 .24444 L
.51143 .24399 L
.51215 .24348 L
.51506 .24061 L
.51774 .23717 L
.52087 .23281 L
.52379 .22907 L
.52501 .22778 L
.52616 .22675 L
.52748 .22586 L
.52869 .22535 L
.53003 .22518 L
.53127 .22542 L
.53263 .22618 L
.53331 .22676 L
.53407 .22758 L
.53548 .22956 L
.53677 .23195 L
.53968 .23939 L
.54224 .24829 L
.54494 .25981 L
.55009 .28584 L
.55495 .30978 L
.55626 .31506 L
.55764 .31979 L
.55836 .32185 L
.55916 .32376 L
.55989 .32516 L
.56056 .32613 L
.56183 .32712 L
.56319 .32688 L
.56446 .32542 L
.56566 .32296 L
.56687 .31941 L
.56797 .31533 L
.57044 .30353 L
.57488 .27555 L
.58494 .20637 L
.59007 .1785 L
Mistroke
.59548 .15658 L
.60011 .14327 L
.60273 .13757 L
.60518 .13325 L
.60802 .12926 L
.6107 .12631 L
.61312 .12425 L
.61574 .12255 L
.61709 .12187 L
.61859 .12126 L
.62015 .12077 L
.62087 .12059 L
.62162 .12044 L
.62298 .12024 L
.62423 .12014 L
.62558 .12012 L
.62634 .12014 L
.62705 .12018 L
.62839 .12032 L
.62907 .12041 L
.62982 .12053 L
.63236 .1211 L
.6338 .12152 L
.63534 .12205 L
.63812 .12321 L
.64358 .12624 L
.64856 .1298 L
.66809 .1485 L
.67778 .15783 L
.6831 .16195 L
.68809 .16486 L
.69068 .16596 L
.69347 .16686 L
.69656 .16758 L
.6994 .16806 L
.70447 .16883 L
.70592 .1691 L
.7073 .16941 L
.70855 .16975 L
.70988 .17019 L
.71244 .17132 L
.7148 .17281 L
.71735 .17501 L
.72015 .17834 L
.72253 .18202 L
.72509 .187 L
.72972 .19891 L
.73553 .21944 L
.74106 .24365 L
.7465 .26854 L
Mistroke
.75144 .2874 L
.75393 .29417 L
.75533 .29695 L
.75662 .2988 L
.75776 .29985 L
.759 .30039 L
.7603 .30029 L
.76151 .29962 L
.76217 .29902 L
.7629 .2982 L
.76422 .29629 L
.76669 .29156 L
.77224 .27845 L
.77475 .27306 L
.7771 .26913 L
.77829 .26771 L
.77956 .26666 L
.78025 .26632 L
.78097 .26613 L
.78227 .26625 L
.78338 .26684 L
.78457 .26796 L
.78569 .26948 L
.7867 .27124 L
.78919 .27698 L
.79155 .28396 L
.79682 .30236 L
.7994 .31082 L
.80176 .31701 L
.80303 .31944 L
.80424 .32104 L
.80552 .32187 L
.80624 .32193 L
.80691 .32171 L
.80765 .32115 L
.80835 .32032 L
.80965 .31796 L
.81038 .31618 L
.81105 .31427 L
.81257 .30901 L
.81707 .28687 L
.822 .25579 L
.83195 .19479 L
.83747 .16945 L
.84269 .15187 L
.84738 .14055 L
.85003 .13565 L
.85248 .13191 L
.85755 .12609 L
.86044 .12373 L
Mistroke
.86314 .12201 L
.86599 .12065 L
.86859 .11972 L
.87003 .11932 L
.8716 .11897 L
.87308 .11871 L
.87445 .11853 L
.8758 .11842 L
.87648 .11839 L
.87723 .11837 L
.87854 .11837 L
.87978 .11842 L
.88052 .11847 L
.88123 .11854 L
.88256 .1187 L
.88398 .11893 L
.88554 .11924 L
.88817 .11991 L
.89096 .12082 L
.89598 .12306 L
.90077 .126 L
.90526 .12956 L
.91551 .14073 L
.9349 .17166 L
.94021 .18002 L
.94313 .18404 L
.94588 .18729 L
.94845 .18976 L
.94981 .19084 L
.95124 .19181 L
.95245 .19249 L
.95377 .19311 L
.95611 .1939 L
.95731 .19418 L
.9586 .19439 L
.95933 .19447 L
.96 .19454 L
.96131 .19462 L
.96368 .19472 L
.96501 .19478 L
.96624 .19488 L
.96692 .19496 L
.96767 .19508 L
.96845 .19524 L
.96917 .19544 L
.9705 .19593 L
.97125 .19629 L
.97193 .19668 L
.97321 .19759 L
.9746 .1989 L
Mistroke
.97713 .20226 L
.9785 .2047 L
.98002 .20796 L
.98308 .2166 L
.98591 .2273 L
.98857 .23988 L
.99928 .31085 L
1 .316 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo07Cooooo
0ol0000iooooo`00]Oooool00ol0003oooooooooo`0Sooooo`Go0000BOooool4o`0000;ooooo1?l0
000eooooo`00?Oooool9o`0006oooooo00?o0000ooooooooool08Oooool2o`0000Gooooo0ol00015
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0<_ooool003_ooooo0_l00009oooo
o`Co0000AOooool6o`00023ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo047ooooo00?o0000ooooooooool02_ooool2o`0003;ooooo000iooooo`;o
00003oooool00ol0003oooooooooo`10ooooo`;o00001_ooool4o`0001cooooo0_l0000Pooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo02oooooo000hooooo`03o`000?oooooooooo013ooooo0_l00010ooooo`03o`00
0?oooooooooo00Wooooo0_l0000Jooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
;oooool003Oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0looooo`03o`000?oo
oooooooo00cooooo0_l0000Hooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0;_oo
ool003Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooo
oooo00oooooo0ol0000Eooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0;Oooool0
03Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo
01;ooooo0_l0000Cooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0hooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0;?ooool003Ko
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo01Go
oooo0ol0000@ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0;?ooool003Kooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo01Sooooo
0_l0000>ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0:oooool003Gooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02[ooooo000e
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo00[ooooo0_l0000Mooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02[ooooo000doooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Goooo
o`;o0000<_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02Wooooo000dooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Iooooo`;o
0000<?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Sooooo000Eooooo`;o0000
00Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h05?ooool00ol0003oooooooooo`03
ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
00?o0000ooooooooool03?ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Iooooo`03
o`000?oooooooooo00Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQ?ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooooooo`Co0000
00So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPkooooo00?o0000ooooooooool02Oooool5
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Gooooo`09o`000?oooooooooooooooonHV9So
410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`03o`000?oooooo
oooo00oooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0>ooooo`00
5_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool00ol0003o
ooooooooo`04ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9So
MgMg00gooooo00?o0000ooooooooool02oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00oooooo1?l00007ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01Kooooo00?o0000ooooooooool00_ooool01Ol@413o^[Zjoooo
oomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko
00000_ooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Booooo`Ko00001_ooool01Ol0
003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool03?ooool00ol0003oooooooooo`02
ooooo`Ko00000oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41004ooo
ool6o`0000Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01?ooooo1?l00004ooooo`03
oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400Fooooo`03o`000?oooooooooo
00Kooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00_ooooo00?o0000
ooooooooool02oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`004oooool0
1?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000004oooool00ol0003ooooo
ooooo`07ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03
o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000
01Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000005Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000005_oo
ool2o`0000Cooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000001Kooooo
00?o0000ooooooooool01Oooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool0
00003Oooool00ol0003oooooooooo`0;ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000oooo
ooooooooooooo`00000>ooooo`004oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?oooooo
ooooooooool000004_ooool00ol0003oooooooooo`07ooooo`03oa0@4?l0003o^[Zj00?ooooo00Go
0000ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool0
0_ooool01Ol0003ooooooooooooooooo000001Sooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000005_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000005oooool00ol0003oooooooooo`03ooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`00000Fooooo`03o`000?oooooooooo00Cooooo00?o
410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool0
2_ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool001Co
oooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@01;ooooo00?o0000oooo
ooooool02?ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41003oooool0
0ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413ooooooooo
o`0Fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@01Kooooo00?o0000ooooooooool01Oooool2o`0001_ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41006?ooool00ol0003o
ooooooooo`03ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Doooo
o`03o`000?oooooooooo00Gooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool02_ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooo
ooooooooool@41003_ooool001Cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg01;ooooo00?o0000ooooooooool01Oooool01Ol@413oV9RHoooooonj^[[o000000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0@ooooo`03o`000?oooooooooo00Sooooo00Go0000okZj^_oo
ooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Gooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Iooooo`;o000000Co^[ZjoooooonHV9So
410@0oooool01OmgMgOoV9RHoooooonHV9SoMgMg01Kooooo00?o0000ooooooooool00_ooool01Ol@
413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0@ooooo`03o`000?oo
oooooooo00Wooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo
000Eooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Booooo`03o`00
0?oooooooooo00Gooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h04?ooool00ol0003oooooooooo`08ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^01Oooooo00?o0000ooooooooool00_ooool00omEEEGoIVIVo`00
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h05oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool00_ooool00omEEEGoIVIVo`000004ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h06_ooool01Ol0003o410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Eooooo`03o`000?oooooooooo00?ooooo00GoZJVYoa0@4?l0003o410@ojVY
Z@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04Oooool00ol0003oooooooooo`09ooooo`03ogMg
Mol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`00<_ooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08Oooool003;ooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`0Rooooo`?o00008Oooool0037ooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0Tooooo`Ko00007?ooool0037ooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Wooooo000aooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Hooooo`00
5_ooooooo`00043o00004oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000004ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
000000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
000000Gooooo00?o0000ooooooooool04Oooool001Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooo`000005ooooo`03o`000?oooooooooo017ooooo000aooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0Yooooo`05o`000?ooooooooooooooool0
00006_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`0Fooooo`00<?ooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool0:_ooool01?l0003oooooooooool0000Jooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo01Kooooo000`ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0Zooooo`04o`000?ooooooooooo`0001Wooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool05_ooool0033ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo02[ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo01Gooooo000`ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo000000Oooooo1?l0000>ooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo01Gooooo000`ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`0]ooooo`;o00001_ooool01Ol0003ooooooooooooooooo000000kooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool05Oooool002oooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo02gooooo0ol00005ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`0Eooooo`00;oooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo01;ooooo0_l0000=ooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool05Oooool002oooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0@oooo
o`;o000000?oooooo`000?ooool02oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo
01Gooooo000_ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04?ooool01?l0003o
ooooooooool0000<ooooo`03o`000?oooooooooo02kooooo0_l00002ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Eooooo`00;oooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo00003?ooool00ol0
003oooooooooo`0^ooooo`04o`000?oooooo0000o`0000Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`0Eooooo`00;oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
00oooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01Gooooo000^oooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool03_ooool01Ol0003ooooooooooooooooo
000000[ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool05?ooool002kooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`0Dooooo`00;_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02oo
oooo0_l0000<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool05?ooool002?ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02oooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo01Cooooo
000Sooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo01Cooooo000Rooooo`03o`000?oooooo000000Sooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Oooooo0ol0000;
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool05?ooool0027ooooo00Co0000oooo
oooooooo00002?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03?ooooo00?o0000
ooooooooool01oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo03Cooooo00?o
0000ooooooooool04oooool0023ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`05ooooo`05o`000?oo
ooooooooooooool000002Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo01?ooooo
000Pooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`0Cooooo`007oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Gooooo00?o0000
ooooooooool04oooool001kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<?ooool2o`0000kooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Gooooo00?o0000oooo
ooooool04oooool001gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0fooooo`03
o`000?oooooooooo01;ooooo000Looooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`0Booooo`007?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0gooooo`05o`000?oo
ooooooooooooool000001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Kooooo
00?o0000ooooooooool04_ooool001_ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=oooool01?l0003ooooooooo
ool00009ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`0Booooo`006_ooool00ol0003oooooooooo`0:ooooo`05o`000?ooooooooooooooool00000
>_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0iooooo`?o00002Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool04_ooool001Wooooo00?o0000ooooooooool02ooo
ool01Ol0003ooooooooooooooooo000003[ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09_ooool5o`0000Kooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo01;ooooo
000Iooooo`03o`000?oooooooooo00cooooo00Co0000oooooooooooo0000>_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Vooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool04Oooool001Sooooo00?o0000ooooooooool0
3Oooool01?l0003oooooooooool0000jooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02Oooool01Ol0003ooooooooooooooooo000002[ooooo00?oV9RHob4Q8Oo^k^h01oooool3o`00
00kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`16ooooo`05o`000?oooooooooo
ooooool00000>oooool00ol0003oooooooooo`0Aooooo`005oooool00ol0003oooooooooo`0>oooo
o`?o0000>oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00Go0000oooo
ooooooooooooo`00000[ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo04Kooooo00Go0000ooooooooooooooooo`00
000kooooo`03o`000?oooooooooo017ooooo000Fooooo`03o`000?oooooooooo013ooooo0_l0000l
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooo
oooo000002cooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`0?ooooo`05o`000?oo
ooooooooooooool00000B?ooool01Ol0003ooooooooooooooooo000003_ooooo00?o0000oooooooo
ool04Oooool006Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`04o`00
0?ooooooooooo`0002kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0?ooooo`04
o`000?ooooooooooo`0004[ooooo00?o0000ooooool00000D?ooool006Oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo000002[ooooo00Go0000okZj^_oo
ooooV9RHoa0@4006ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo0000Boooool2
o`00053ooooo001Wooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool3o`00
02[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo013ooooo0ol0002M
ooooo`00Ioooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04;ooooo00?o0000oooo
ooooool04?ooool2o`0009kooooo001Wooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0@_ooool00ol0003oooooooooo`2`ooooo`00J?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo04;ooooo0_l0002aooooo`00J?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo04;ooooo00?o0000ooooooooool0/?ooool006Sooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`13ooooo`03o`000?oooooooooo0;3ooooo001Xooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`2`ooooo`00J?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0/?ooool006Sooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo0;3ooooo
001Xooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`2`ooooo`00J?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04?ooooo00?o0000
ooooooooool0/?ooool006Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`13oooo
o`03o`000?oooooooooo0;3ooooo001Yooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0A?ooool2o`000;7ooooo001Yooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
A?ooool00ol0003oooooooooo`2`ooooo`00JOooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo04Cooooo00?o0000ooooooooool0/?ooool006Wooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`14ooooo`03o`000?oooooooooo0;3ooooo001Yooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`2`ooooo`00JOooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0/?ooool006Wooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo0;3ooooo
001Yooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0A?ooool00ol0003ooooooooo
o`2`ooooo`00J_ooool01Ol0003ooooooooooooooooo000004Kooooo0_l0002aooooo`00J_ooool0
1Ol0003ooooooooooooooooo000004Kooooo00?o0000ooooooooool0/?ooool006[ooooo00Co0000
oooooooooooo0000Aoooool00ol0003oooooooooo`2`ooooo`00J_ooool01?l0003oooooooooool0
0017ooooo`03o`000?oooooooooo0;3ooooo001[ooooo`03o`000?oooooo000004Oooooo00?o0000
ooooooooool0/?ooool006_ooooo0ol0000nooooo`;o000000?o410@ooooooooool01?ooool00ol0
003oooooooooo`2`ooooo`00Joooool2o`00043ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2`ooooo`00Z_ooool5o`0000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Co
A4A4omgMgOoooooo00001oooool3o`000;3ooooo002Zooooo`04omgMgOmEEEGoooooo`0000Oooooo
00?o0000ooooooooool0/?ooool00:_ooooo00?oMgMgolc<c?l000001oooool00ol0003ooooooooo
o`2`ooooo`00Zoooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0;3ooooo002/oooo
o`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo00Gok^k^oc8b<_l0003o410@olc<c006oooo
o`03o`000?oooooooooo0;3ooooo002Zooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0
003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool0/?ooool00:[ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000/?ooool00:[o
oooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03
oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0/?ooool00:[ooooo00?ogMgMoa0@4?nHV9P0
2?ooool00ol0003oooooooooo`2`ooooo`00Zoooool01?o<c<coA4A4o`000?l@4106ooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002Zooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_oo
ool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05oc8b<_nH
V9SooooooiRHV?lb<S801_ooool3o`000;3ooooo002Zooooo`05olc<c?l0003o0000o`000?o<c<`0
^Oooool00:[ooooo00Go410@okZj^_oooooo^[Zjoa0@402iooooo`00Z_ooool01Ol0003o^[Zjoooo
oonj^[[o00000;Wooooo002Zooooo`05ojVYZOl@413o0000oa0@4?nYZJT0^Oooool00?ooooooJOoo
ool00;?ooooo00?o0000okZj^_ooool0/_ooool00;?ooooo0_lb<S:cooooo`00Q?ooool2o`000006
oa0@4?oooooooooooa0@4?l0003o410@6?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003o
A4A4okZj^P0Hooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^07cooooo0025ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`00
00gooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL00oooool00oo<c<co0000
oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoEEEEogMgMooo
ooooV9RHob4Q8@03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0O?ooool008Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooooooooa0@40?ooooo00?o410@
ooooooooool04?ooool00ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol@413ooooooooooooooooo410@07cooooo0025ooooo`06o`000?ooooooA4A4odA4A?oooooo
00002Oooool6o`0000gooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool02oooool6o`0000Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@03
ooooo`05o`000?ooooooooooooooool00000O?ooool008Gooooo00Ko0000omgMgOlb<S;oEEEEomgM
gOl0000Iooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo0000
01;ooooo00?o0000ooooooooool06_ooool01Ol0003oEEEEo`000?l@413oc<c<00?ooooo00Go0000
ooooooooooooooooo`00001looooo`00QOooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001Wooooo
00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@013ooooo00?o410@o`000?l0
00000ol0000Iooooo`03oeEEEOn7QhOooooo00Gooooo00Go410@oooooooooooooooooa0@401loooo
o`00QOooool01_l0003o<S8boooooooooooo<S8bo`0001Wooooo00?o0000ooooooooool01?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool06_ooool00ooMgMgo410@oiRH
V005ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0O?ooool008Cooooo00?o410@o`000?n7QhL00_oo
ool00on7QhOo0000oa0@400Hooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo
00?o0000ooooooooool06oooool01?o<c<coA4A4o`000?l@4103ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h0O?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(62) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30417 m
.00123 .30592 L
.00236 .30669 L
.00365 .30663 L
.00488 .30563 L
.00601 .30394 L
.00706 .30175 L
.00942 .29487 L
.01444 .27428 L
.017 .26266 L
.01975 .25096 L
.02242 .24148 L
.02369 .23789 L
.02486 .23518 L
.02604 .23311 L
.02732 .23164 L
.02845 .23106 L
.02966 .23123 L
.03039 .23174 L
.03107 .23249 L
.03182 .23364 L
.0326 .23522 L
.03393 .23876 L
.03538 .24395 L
.03806 .25717 L
.04057 .27368 L
.04582 .31866 L
.04859 .34467 L
.05153 .36996 L
.05277 .37892 L
.0541 .38701 L
.05486 .39081 L
.05556 .39369 L
.05693 .39755 L
.05809 .39887 L
.05936 .39818 L
.06069 .39507 L
.06192 .39006 L
.06267 .38607 L
.06348 .381 L
.06495 .36999 L
.06771 .34444 L
.07389 .27767 L
.07953 .22391 L
.08229 .20308 L
.08481 .1872 L
.0896 .16426 L
.09224 .15504 L
.09475 .14813 L
.09746 .14233 L
Mistroke
.09998 .13821 L
.10274 .13473 L
.10568 .13189 L
.10855 .12978 L
.11006 .12889 L
.11165 .1281 L
.11305 .12753 L
.11458 .12703 L
.11598 .12667 L
.11727 .12642 L
.11864 .12623 L
.11993 .12611 L
.12109 .12604 L
.12234 .126 L
.12371 .12601 L
.1244 .12602 L
.12517 .12605 L
.12651 .12613 L
.12777 .12625 L
.12901 .1264 L
.13034 .12661 L
.13272 .12715 L
.13418 .12759 L
.13555 .12808 L
.13812 .1292 L
.14335 .13229 L
.14901 .13695 L
.15393 .1425 L
.15913 .15017 L
.16845 .16793 L
.17839 .18971 L
.181 .19497 L
.18386 .19997 L
.18655 .20375 L
.18784 .20518 L
.18904 .20629 L
.19016 .20709 L
.19136 .20772 L
.1927 .20812 L
.19392 .20821 L
.19513 .20805 L
.19645 .20757 L
.19782 .20676 L
.19911 .20571 L
.20143 .20315 L
.20354 .20017 L
.20829 .19177 L
.21806 .17272 L
.22298 .16502 L
.22433 .16334 L
Mistroke
.22578 .16179 L
.22714 .1606 L
.22841 .15975 L
.22911 .1594 L
.22986 .15911 L
.23069 .15891 L
.23145 .15885 L
.23216 .15889 L
.23293 .15906 L
.23366 .15934 L
.23434 .1597 L
.23559 .16065 L
.23697 .16215 L
.23841 .16423 L
.23976 .16669 L
.2424 .17309 L
.24482 .18091 L
.2476 .19253 L
.25023 .20632 L
.26038 .28225 L
.26306 .30475 L
.26594 .3269 L
.26727 .33572 L
.26866 .34374 L
.26987 .34946 L
.27115 .35417 L
.27235 .35716 L
.27343 .35867 L
.27452 .35903 L
.27555 .35831 L
.27675 .35621 L
.27785 .35314 L
.27907 .34865 L
.28035 .34277 L
.28566 .31129 L
.2905 .28318 L
.29294 .27287 L
.29431 .26865 L
.29559 .2659 L
.29682 .26438 L
.29793 .26397 L
.29921 .2647 L
.30042 .26657 L
.30172 .26989 L
.30309 .27487 L
.30554 .28745 L
.30818 .30582 L
.31107 .33026 L
.31588 .37324 L
.31726 .3841 L
Mistroke
.31857 .393 L
.31976 .39962 L
.32103 .40486 L
.32213 .40777 L
.32334 .40906 L
.32444 .40842 L
.32547 .40625 L
.32669 .40179 L
.3278 .396 L
.3303 .37765 L
.34076 .26663 L
.34377 .23796 L
.34661 .21518 L
.34919 .19809 L
.35191 .18347 L
.35431 .17318 L
.35693 .16425 L
.35932 .15795 L
.36155 .15339 L
.36419 .14933 L
.36659 .14662 L
.36936 .14436 L
.37198 .14285 L
.37428 .1419 L
.37559 .14148 L
.37682 .14116 L
.37802 .1409 L
.37929 .14069 L
.38068 .1405 L
.38196 .14038 L
.38306 .14029 L
.38424 .14022 L
.38636 .14011 L
.38887 .14 L
.39118 .13986 L
.39388 .13967 L
.39681 .1394 L
.40213 .13885 L
.40732 .13825 L
.41207 .13769 L
.41328 .13756 L
.41459 .13745 L
.41583 .13736 L
.41698 .1373 L
.41832 .13727 L
.41953 .13728 L
.4202 .1373 L
.42093 .13734 L
.42225 .13745 L
.4234 .1376 L
Mistroke
.42466 .13781 L
.42598 .1381 L
.42721 .13844 L
.42941 .13922 L
.43177 .14035 L
.43456 .14213 L
.43759 .14471 L
.44046 .14789 L
.44311 .15152 L
.44812 .16039 L
.45343 .17275 L
.46329 .20198 L
.46847 .21757 L
.47129 .22485 L
.47391 .23029 L
.4751 .23225 L
.47623 .23376 L
.47752 .23508 L
.4787 .23586 L
.48001 .23626 L
.48121 .23617 L
.48253 .23559 L
.4832 .2351 L
.48393 .23442 L
.48513 .23299 L
.48622 .23134 L
.48868 .2266 L
.49311 .21513 L
.50281 .18587 L
.50771 .17353 L
.5105 .16812 L
.51312 .16436 L
.5145 .16296 L
.51519 .16242 L
.51596 .16196 L
.5173 .1615 L
.51856 .1615 L
.51932 .16171 L
.52004 .16207 L
.5214 .16316 L
.52215 .16403 L
.52285 .16499 L
.52443 .16777 L
.52685 .17377 L
.52951 .18303 L
.5323 .19591 L
.53491 .21116 L
.54012 .25062 L
.54581 .30193 L
.54841 .32419 L
Mistroke
.54984 .33498 L
.55118 .34381 L
.55244 .35062 L
.5538 .35621 L
.55503 .35952 L
.55617 .36098 L
.5573 .3609 L
.5585 .35911 L
.55964 .35584 L
.56068 .3516 L
.5619 .3452 L
.56322 .33668 L
.56563 .31787 L
.57079 .27033 L
.57562 .2274 L
.58038 .1935 L
.5855 .16739 L
.58827 .15728 L
.59118 .14924 L
.59367 .14419 L
.59639 .14028 L
.59788 .13873 L
.59929 .1376 L
.60055 .13682 L
.60192 .1362 L
.60263 .13595 L
.60341 .13575 L
.60423 .1356 L
.60499 .13552 L
.60636 .1355 L
.60712 .13555 L
.60782 .13565 L
.60918 .13593 L
.61043 .13632 L
.61181 .13686 L
.61328 .13757 L
.61845 .14088 L
.62928 .14929 L
.63498 .15358 L
.63809 .15562 L
.64098 .15719 L
.64353 .15823 L
.64496 .15866 L
.64625 .15898 L
.64768 .15923 L
.64848 .15933 L
.64922 .15939 L
.65058 .15945 L
.65127 .15945 L
.65203 .15943 L
Mistroke
.65335 .15934 L
.65455 .15918 L
.65522 .15907 L
.65594 .15893 L
.65727 .15861 L
.65981 .15779 L
.66218 .15679 L
.67326 .1508 L
.6759 .14948 L
.6787 .14825 L
.68129 .14732 L
.68255 .14695 L
.68371 .14668 L
.68481 .14649 L
.68586 .14637 L
.68697 .14633 L
.68818 .14639 L
.68941 .14657 L
.69072 .14691 L
.69185 .14733 L
.69308 .14794 L
.6956 .14967 L
.69702 .15096 L
.69832 .15234 L
.70324 .15953 L
.70584 .16477 L
.70821 .1705 L
.71352 .18687 L
.72309 .22555 L
.72845 .24719 L
.73127 .25656 L
.73282 .26071 L
.73426 .26383 L
.73552 .26589 L
.73688 .26736 L
.73765 .26784 L
.73838 .26805 L
.73975 .2678 L
.74101 .26685 L
.74217 .26537 L
.74345 .26312 L
.74482 .26006 L
.75563 .22248 L
.76132 .20324 L
.76418 .1961 L
.76581 .19312 L
.76653 .19208 L
.76732 .19116 L
.76807 .19051 L
.76875 .1901 L
Mistroke
.77011 .18985 L
.77134 .1903 L
.77265 .19152 L
.77332 .19245 L
.77405 .1937 L
.77536 .1966 L
.77693 .20117 L
.77836 .20648 L
.78072 .21771 L
.7833 .23362 L
.78851 .27675 L
.79407 .33188 L
.7968 .35654 L
.79799 .36574 L
.79931 .37426 L
.80049 .38026 L
.8016 .3843 L
.80277 .38678 L
.80402 .38731 L
.80539 .38535 L
.80668 .38108 L
.80785 .37536 L
.80912 .36727 L
.82067 .25115 L
.82612 .20301 L
.83112 .17151 L
.83362 .15984 L
.83626 .15 L
.83891 .14232 L
.8418 .13601 L
.84431 .13202 L
.8457 .13031 L
.847 .12896 L
.84822 .1279 L
.84954 .12696 L
.85065 .12631 L
.85184 .12575 L
.85321 .12527 L
.85449 .12496 L
.85527 .12484 L
.85601 .12476 L
.85668 .12473 L
.85741 .12474 L
.85818 .12479 L
.85889 .12487 L
.8597 .12501 L
.86046 .12518 L
.86183 .12559 L
.8633 .12616 L
.86598 .12752 L
Mistroke
.86882 .12937 L
.87389 .13361 L
.88384 .14532 L
.8945 .16127 L
.89935 .16847 L
.9045 .17519 L
.90662 .17748 L
.9089 .17956 L
.9102 .18054 L
.9114 .18128 L
.91254 .18186 L
.91375 .18233 L
.91504 .18266 L
.91624 .1828 L
.91697 .18282 L
.91766 .18278 L
.91895 .18258 L
.92032 .18219 L
.92158 .18167 L
.92297 .18093 L
.92443 .17997 L
.92996 .17499 L
.93605 .16795 L
.94131 .16176 L
.94421 .15871 L
.94696 .15626 L
.94952 .15446 L
.95096 .15368 L
.9523 .15312 L
.95354 .15277 L
.95466 .15258 L
.95596 .15255 L
.95718 .1527 L
.9584 .15305 L
.95971 .15366 L
.96095 .15447 L
.96208 .15543 L
.9634 .15683 L
.96484 .1587 L
.96745 .16315 L
.97019 .16934 L
.97309 .17776 L
.9783 .19797 L
.98831 .25248 L
.99283 .27795 L
.99538 .28996 L
.99651 .29447 L
.9977 .29854 L
1 .30417 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo06kooooo0_l00010
ooooo`00>_ooool7o`0007Cooooo00?o0000ooooooooool0K?ooool6o`0003kooooo000hooooo`;o
00001oooool2o`0007;ooooo0_l0001/ooooo`03o`000?oooooooooo00Cooooo0_l0000looooo`00
=oooool00ol0003oooooooooo`09ooooo`;o0000L?ooool00ol0003oooooooooo`1Zooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0>Oooool003Kooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`1Booooo`?o00006?ooool00ol0003oooooooooo`0Mooooo`Co0000BOoo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Wooooo000fooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0A_ooool<o`000003ooooool0003o000000;o00005Oooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo00;ooooo0_l00017ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0>?ooool003Gooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`12ooooo`?o00004Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool01?ooool2o`0004Cooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0gooooo`00=Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo043o
oooo0_l0000Eooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00oooooo0ol0000_ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0=_ooool003Cooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0oooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03?ooool3o`0000;ooooo
0_l0000/ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0=_ooool003Cooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02Oooool2o`0000Oooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo01;ooooo0ol0000Pooooo`00<oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0?
ooooo`;o00006_ooool00ol0003oooooooooo`0<ooooo`;o00002?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?
ooooo`;o00000_ooool2o`0001oooooo000cooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool04oooool2o`0002Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool03_ooool3o`000003ooooool0003o0000
00;o00002oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`03ooooo`;o00007_ooool003;ooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0Aooooo`04o`000?oooooo0000o`0002Kooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo0_l0000Eoooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01cooooo000Eooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o
0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`05ooooo`05oiRHV?l@413o0000oc8b<_o<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Sooooo00Co0000oooo
oooooooooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00ol0003o
ooooooooo`0>ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00Cooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
4oooool00ol0003oooooooooo`04ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Go
oooo00?o0000ooooooooool00oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Ook^k^oc8b
<_l0003o<S8bonk^k_oooooo000000gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`02ooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h03_ooool001Ko
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000oooo
ooooool01Oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`04ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool01Ol0003o8B4Qonk^
k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Hooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000oooo
ooooool03Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04ooo
ool00ol0003oooooooooo`04ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg01Cooooo00?o0000ooooooooool01?ooool01Ol@413o^[ZjoooooomgMgOo<S8b
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0>ooooo`002oooool6o`0000;ooooo1Ol00003ooooo`05oa0@4?oooooo
ooooooooool@41004_ooool6o`0000Kooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@
4?oooooooooo00;ooooo00?o0000ooooooooool03?ooool6o`0000;ooooo00Co0000oiRHV?lQ8B7o
k^k^1?ooool01Ol@413ooooooooooooooooo410@01?ooooo1_l00005ooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00gooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01Cooooo00?o0000ooooooooool0
1?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41005?ooool00ol0003o
ooooooooo`08ooooo`05o`000?ooooooooooooooool@41000oooool01?l@413oooooooooool0000:
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooool000001?l00003ooooo`05oa0@4?oooooo
ooooooooool@41003_ooool001?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooo
oooooooo000001;ooooo00?o0000ooooooooool02?ooool00onYZJWo410@ooooo`02ooooo`05o`00
0?ooooooooooooooool000001Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Go
oooo00Co0000oiRHV?lQ8B7ok^k^0oooool01Ol0003ooooooooooooooooo000001Oooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Dooooo`03o`000?oooooooooo00Gooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooo
oooooooooooo000001Cooooo00?o0000ooooooooool01oooool00onYZJWo410@ooooo`02ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00[ooooo00Ko0000oooooom4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool00000
3_ooool001?ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo0000017o
oooo00?o0000ooooooooool02?ooool00ol@413o0000okZj^P03ooooo`05o`000?oooooooooooooo
ool000001Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo00Co0000oooo
oomgMgOoIVIV0oooool01Ol0003ooooooooooooooooo000001Oooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Eooooo`03
o`000?oooooooooo00Gooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo0000
01Cooooo00?o0000ooooooooool01_ooool00ol@413o0000okZj^P03ooooo`05o`000?oooooooooo
ooooool000001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00Ko0000
oooooooMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool001Cooooo
00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@017ooooo00?o0000oooooooo
ool02Oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000000oooool01Ol@
413ooooooooooooooooo410@01Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0;ooooo`?o00001_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@01Gooooo00?o0000ooooooooool01_ooool01Ol0003ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool04_ooool00ol0003oooooooooo`07ooooo`03
okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4005ooooo`;o00000oooool00ol0
003oooooooooo`0<ooooo`06o`000?ooooooooooogMgMoo<c<co00001?ooool01Ol@413ooooooooo
oooooooo410@00kooooo000Dooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0Aooooo`03o`000?oooooooooo00Kooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Gooooo00Go0000okZj^_l0003oV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0@ooooo`03o`000?oooooooooo00_ooooo0_l00007ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL05Oooool00ol0003oooooooooo`02ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg01Cooooo00?o0000ooooooooool01?ooool01Ol@413oV9RHoooooonj
^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`Co00003oooool01_l0003ooooo
ooooooo^k^koA4A4o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`005Oooool00omg
MgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04Oooool00ol0003oooooooooo`06
ooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Oooooo00?o0000ooooooooool00_ooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04?ooool00ol0003oooooooooo`0;
ooooo`;o00001oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo00?oEEEE
ofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Kooooo00Wo0000oooooooooooooooo
oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Cooooo00?o0000
ooooooooool01?ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0Jooooo`05o`000?ooooooooooogMgMol000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00kooooo000aooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`0:ooooo`;o00001oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool03_ooool2o`00017ooooo00?o0000ooooooooool0;?ooool00ol0003o
ooooooooo`0Iooooo`00<Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo0000013ooooo
00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Iooooo`00<?ooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0<ooooo`05o`000?ooooooooooooooool000003oooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo01Sooooo000`ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00cooooo00Go0000oooooooooooooooo
o`00000?ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool06?ooool0033ooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Sooooo0_l0
0009ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo01Sooooo000Foooooooo0000@?l0000Cooooo`005_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooo`000005ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo1?l00007ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00006ooooo`;o00001oooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooo`000006ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
o`000005ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool04Oooool001Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooool000001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooool000001oooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001_ooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Oooool2o`00
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo0000
00Gooooo00?o0000ooooooooool04Oooool002oooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooo`00000:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0^ooooo`03o`000?oooooooooo01Oooooo000_ooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooool000002_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02_ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Gooooo`00;oooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0[ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool05oooool002oooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool00oooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0;?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Oooooo
000_ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo01Kooooo000Nooooo`;o00003oooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool09oooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0/ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool05_ooool001kooooo0ol0000>ooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Wooooo`04o`000?oo
ooooooooo`0000Cooooo0_l0000:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01Kooooo000Mooooo`;o000000?o
ooooo`000?ooool03Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool0:?ooool3o`0000Cooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`0Fooooo`007Oooool01?l0003oooooooooool0000=ooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool05_ooool001gooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool05_ooool001gooooo00Go0000ooooooooooooooooo`00
000<ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool05Oooool001cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool05Oooool001cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo03Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0_oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool05Oooool001cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Kooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool05Oooool001_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0`ooooo`;o0000
2oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo033ooooo00Go0000oooooooooooo
ooooo`00000<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`0Eooooo`006oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo037ooooo
00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0<oooool00ol0003oooooooooo`0Dooooo`006oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`09ooooo`;o0000
3?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0aooooo`;o000000?oooooo`000?ooool03?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool05?ooool001_ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Sooooo00?o
0000ooooooooool02?ooool00ol0003oooooo`00000<ooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03;ooooo0ol0
000>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`0Dooooo`006_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000_ooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0@oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Cooooo00?o
0000ooooooooool05?ooool001[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool0
000;ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo01?ooooo000Jooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Oooooo00Co0000
oooooooooooo00002oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`0Cooooo`006_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`06
ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`13ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Cooooo`006_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0`ooooo`;o00003?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo04?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo01?ooooo000Iooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo01;ooooo000Iooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04?o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01;o
oooo000Iooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo01;ooooo000Iooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01;ooooo000I
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo01;ooooo000Hooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Kooooo1Ol00006oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`15oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Boooo
o`005_ooool3o`0000_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0jooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo02Kooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Aooooo`009?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09oooool00onHV9So
8B4Qonk^kP07ooooo`?o00002oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1<ooooo`009?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0:?ooool00onHV9So8B4Q
onk^kP06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`15ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0C?ooool002Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Wooooo00?o
MgMgofIVI_ooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0AOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04cooooo000T
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1<
ooooo`009?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool09_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1<ooooo`009?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool09oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04Kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1<ooooo`009?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo04gooooo000Tooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0??ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00gooooo00Go0000oooooooo
ooooooooo`000019ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0COooool002Go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03;o
oooo0_l0000>ooooo`05o`000?ooooooooooooooool00000BOooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo04gooooo000Uooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0?Oooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo00gooooo00Go0000ooooooooooooooooo`000019
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0COooool002Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0mooooo`05o`000?ooooooooooooooool000002Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool03Oooool0
1Ol0003ooooooooooooooooo000004Wooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`1=ooooo`009Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03gooooo00Go0000
ooooooooooooooooo`000009ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool00000BOooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo04gooooo000Uooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0?Oooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00gooooo00Go0000oooooooooooo
ooooo`000019ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0COooool002Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0nooooo`04o`000?ooooooooooo`0000Wo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00ko
oooo00Co0000oooooooooooo0000BOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
04gooooo000Uooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooo`00000:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooo000004[ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`1=ooooo`009Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03kooooo
00?o0000ooooool000002oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool03_ooool00ol0003oooooo`00001:ooooo`05o`000?ooooooooooooooool0
0000D?ooool002Kooooo00Go0000ooooooooooooooooo`000012ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00ko
oooo00?o0000ooooool00000B_ooool01Ol0003ooooooooooooooooo0000053ooooo000Vooooo`05
o`000?ooooooooooooooool00000Coooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
03?ooooo0_l0000@ooooo`03o`000?oooooooooo04[ooooo00Co0000oooooooooooo0000D?ooool0
02Kooooo00Go0000ooooooooooooooooo`00001?ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`1Looooo`04o`000?ooooooooooo`00053ooooo000V
ooooo`05o`000?ooooooooooooooool00000Coooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool0G?ooool01?l0003oooooooooool0001@ooooo`009_oo
ool01Ol0003ooooooooooooooooo000004oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo05cooooo00Co0000oooooooooooo0000D?ooool002Kooooo
00Go0000ooooooooooooooooo`00001?ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0<oooool00ol0003oooooooooo`1Looooo`04o`000?ooooooooooo`00053ooooo000Vooooo`05
o`000?ooooooooooooooool00000Coooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool0G?ooool01?l0003oooooooooool0001@ooooo`009_ooool01Ol0
003ooooooooooooooooo0000053ooooo00Go0000ooooooooooooooooo`00000eooooo`03o`000?oo
oooooooo05gooooo00?o0000ooooool00000D?ooool002Oooooo00Co0000oooooooooooo0000D?oo
ool01Ol0003ooooooooooooooooo000003Gooooo00?o0000ooooooooool0GOooool2o`00057ooooo
000Wooooo`04o`000?ooooooooooo`00053ooooo00Go0000ooooooooooooooooo`00000eooooo`;o
0000G_ooool2o`00057ooooo000Wooooo`03o`000?oooooo0000057ooooo00Co0000oooooooooooo
0000=_ooool00ol0003oooooooooo`2`ooooo`009oooool00ol0003oooooo`00001Aooooo`04o`00
0?ooooooooooo`0003Kooooo00?o0000ooooooooool0/?ooool002Sooooo0_l0001Aooooo`04o`00
0?ooooooooooo`0003Kooooo00?o0000ooooooooool0/?ooool002Sooooo0_l0001Aooooo`04o`00
0?ooooooooooo`0003Kooooo00?o0000ooooooooool0/?ooool007_ooooo00Co0000oooooooooooo
0000;Oooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0/?ooool007cooooo
0_l0000_ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool007cooooo0_l0
000/ooooo`Go00001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01?m4A4CogMgMooooool0
0007ooooo`?o0000/?ooool00:[ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003ooooooooo
o`2`ooooo`00Zoooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo0;3ooooo002[oooo
o`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0/?ooool00:cooooo00?oMgMgo`000?oo
ool01_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00Z_ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000oooooooo
ool0/?ooool00:[ooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3o
oooo002Zooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`2`ooooo`00
Z_ooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0002`ooooo`00Z_ooool01Ol0003oEEEE
o`000?l@413oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00?oEEEEohN7Qoooool0
2?ooool00ol0003oooooooooo`2`ooooo`00Z_ooool00ooMgMgo410@oiRHV008ooooo`03o`000?oo
oooooooo0;3ooooo002[ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo00Goc<c<
ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05ob4Q8OnHV9So
oooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`?o0000/?ooool00:[ooooo00Goc<c<o`000?l0003o0000olc<c02iooooo`00Z_ooool0
1Ol@413o^[Zjoooooonj^[[o410@0;Wooooo002Zooooo`05o`000?nj^[[ooooookZj^_l00000^Ooo
ool00:[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2iooooo`00oooooomYooooo`00/oooool00ol0
003o^[Zjooooo`2booooo`00/oooool2oc8b<[?ooooo0024ooooo`;o000000Ko410@oooooooooooo
410@o`000?l@410Hooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo
00Gok^k^oc8b<_l0003o410@olc<c003ooooo`Go0000O?ooool008Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`07ooooo`Ko00003Oooool02OmgMgOo<S8booooooooooooMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`03olc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@
4009ooooo`Ko00002Oooool01OmEEEGoMgMgoooooonHV9So8B4Q00?ooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A01looooo`00QOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01_ooooo
00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`0@ooooo`03o`000?oooooooooo01[o
oooo00Go0000ooooooooooooooooo`000004ooooo`03oiRHV?lQ8B7ok^k^07gooooo0025ooooo`06
o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000gooooo00GoMgMgoc8b<_ooooooooooo`00
0003ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02oooool6o`0000Wooooo00Go
0000oiRHV?ooooooV9RHob4Q8@05ooooo`03oiRHV?lQ8B7ok^k^07cooooo0025ooooo`06o`000?oM
gMgo<S8boeEEEOoMgMgo00006Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooo
ooooooooooooo`00000Booooo`03o`000?oooooooooo01[ooooo00Go0000oeEEEOl0003o410@olc<
c006ooooo`03ogMgMomVIVKooooo07_ooooo0025ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo0000
6Oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol@413o
0000o`000003o`0001Wooooo00?oEEEEohN7Qoooool02Oooool00ol0003oooooooooo`1jooooo`00
QOooool01_l0003o<S8boooooooooooo<S8bo`0001Wooooo00?o0000ooooooooool01?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool06_ooool00ooMgMgo410@oiRHV005
ooooo`05o`000?nj^[[ooooooiRHV?l@4100O?ooool008Cooooo00?o410@o`000?n7QhL00_ooool0
0on7QhOo0000oa0@400Hooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo00?o
0000ooooooooool06oooool01?o<c<coA4A4o`000?l@4103ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`0O?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .26231 m
.00942 .21309 L
.01483 .18955 L
.01719 .18142 L
.01975 .17414 L
.02114 .17086 L
.02243 .16826 L
.02373 .16606 L
.02496 .16442 L
.02624 .16315 L
.02693 .16267 L
.02766 .16232 L
.02843 .16214 L
.02916 .16215 L
.03053 .16267 L
.03173 .16368 L
.03302 .16538 L
.03423 .16758 L
.03533 .17012 L
.03803 .17864 L
.04057 .18996 L
.04313 .20511 L
.04595 .22666 L
.05164 .28704 L
.05696 .35667 L
.05929 .38524 L
.06182 .41062 L
.06256 .41646 L
.06335 .42172 L
.06408 .42566 L
.06477 .4285 L
.06609 .43152 L
.0668 .43176 L
.06756 .43094 L
.0683 .42907 L
.06912 .42584 L
.06997 .42118 L
.07077 .41574 L
.07371 .38758 L
.07904 .31835 L
.08481 .24588 L
.0876 .21807 L
.09056 .19441 L
.09308 .1784 L
.09586 .16458 L
.09846 .1547 L
.09989 .15035 L
.10125 .14689 L
.10251 .1442 L
.10388 .14181 L
Mistroke
.10504 .14018 L
.10629 .13879 L
.10762 .13767 L
.10886 .13692 L
.11008 .13643 L
.11119 .13616 L
.11241 .13606 L
.11374 .13613 L
.11512 .13642 L
.11642 .13687 L
.11764 .13745 L
.11879 .13815 L
.12095 .13987 L
.12328 .14231 L
.12581 .14563 L
.1462 .1867 L
.15179 .19788 L
.15332 .20033 L
.15493 .20253 L
.15632 .2041 L
.1578 .20542 L
.15853 .20593 L
.15922 .20632 L
.1605 .20684 L
.1617 .20707 L
.163 .20702 L
.16369 .20688 L
.16444 .20663 L
.16523 .20626 L
.16596 .20582 L
.16727 .2048 L
.16868 .20338 L
.17144 .1997 L
.17399 .19535 L
.17976 .18338 L
.19027 .16116 L
.19519 .15247 L
.19982 .14589 L
.20214 .14332 L
.20464 .14112 L
.20599 .14018 L
.20742 .13938 L
.20863 .13883 L
.20997 .13839 L
.21135 .13808 L
.21262 .13794 L
.21329 .13793 L
.21402 .13795 L
.21479 .13804 L
.21551 .13817 L
Mistroke
.21682 .13854 L
.21803 .13904 L
.21942 .13983 L
.22074 .1408 L
.22317 .14321 L
.22542 .14622 L
.2279 .15045 L
.23053 .15609 L
.23339 .16364 L
.23647 .17371 L
.24207 .1978 L
.25252 .26079 L
.25734 .29019 L
.26 .30338 L
.2613 .30865 L
.26251 .31267 L
.26393 .31625 L
.26468 .31761 L
.26548 .31863 L
.26676 .31934 L
.2675 .31923 L
.26818 .31878 L
.26951 .31699 L
.27073 .31431 L
.27207 .31031 L
.27347 .30502 L
.28417 .24716 L
.28699 .2324 L
.29005 .21849 L
.29269 .20851 L
.29419 .20377 L
.2956 .19997 L
.29703 .19677 L
.29835 .19449 L
.29902 .19356 L
.29975 .19275 L
.30052 .19212 L
.30125 .19175 L
.30256 .19163 L
.3033 .19188 L
.30396 .19231 L
.30525 .19371 L
.30647 .19571 L
.30767 .19837 L
.30894 .20194 L
.31121 .21039 L
.31366 .22268 L
.31634 .24046 L
.32116 .28515 L
.32633 .34841 L
Mistroke
.33084 .40464 L
.33312 .42728 L
.33442 .43713 L
.33563 .44396 L
.33635 .4468 L
.33703 .44864 L
.33832 .44973 L
.3397 .44744 L
.34048 .44458 L
.3412 .44093 L
.34251 .43214 L
.3437 .42189 L
.34635 .39263 L
.35194 .31783 L
.35488 .28 L
.35799 .24536 L
.36069 .22046 L
.36366 .19835 L
.36888 .17021 L
.37144 .16034 L
.37418 .15206 L
.37677 .14608 L
.37914 .14186 L
.38153 .13852 L
.38418 .13561 L
.38694 .13322 L
.38954 .13148 L
.39072 .13086 L
.39195 .13032 L
.39301 .12995 L
.39417 .12965 L
.39542 .12946 L
.39676 .12939 L
.39802 .12945 L
.39917 .12961 L
.40052 .12992 L
.40196 .13038 L
.40454 .13151 L
.40732 .13321 L
.41037 .13576 L
.41301 .13867 L
.41584 .14268 L
.42096 .15238 L
.431 .17985 L
.44169 .21613 L
.44486 .22531 L
.44641 .22906 L
.44784 .23198 L
.44912 .23411 L
.45052 .23589 L
Mistroke
.45125 .23658 L
.45193 .23707 L
.45264 .23743 L
.45341 .23763 L
.45414 .23764 L
.45481 .2375 L
.45555 .23718 L
.45634 .23665 L
.45765 .23532 L
.4591 .23325 L
.46178 .2279 L
.46429 .22131 L
.4749 .18556 L
.48069 .16739 L
.48607 .15377 L
.49068 .14496 L
.49326 .14127 L
.49561 .13872 L
.49695 .1376 L
.49818 .13678 L
.49953 .1361 L
.50022 .13585 L
.50097 .13564 L
.50223 .13545 L
.50358 .13547 L
.50486 .13569 L
.50602 .13608 L
.50722 .13667 L
.50854 .13756 L
.50992 .13878 L
.51121 .14021 L
.51352 .14352 L
.51601 .14831 L
.51878 .15528 L
.52169 .16472 L
.52689 .1877 L
.53179 .21729 L
.53634 .25148 L
.54172 .29541 L
.54408 .31326 L
.54669 .32989 L
.54792 .33625 L
.54925 .34175 L
.54999 .34415 L
.55066 .34592 L
.55197 .34819 L
.5527 .34875 L
.55338 .34881 L
.55412 .34839 L
.55492 .34737 L
Mistroke
.55567 .34587 L
.55638 .344 L
.55771 .33937 L
.56032 .32658 L
.56272 .31151 L
.56813 .27244 L
.57304 .23915 L
.57762 .21437 L
.5824 .19564 L
.58493 .1883 L
.58764 .1821 L
.59033 .17741 L
.59319 .17372 L
.59563 .17137 L
.59832 .1694 L
.60432 .16614 L
.60995 .16341 L
.63108 .14935 L
.6414 .14136 L
.64703 .13747 L
.64978 .13586 L
.65227 .13464 L
.65458 .13375 L
.65676 .13312 L
.65796 .13286 L
.65906 .13268 L
.66027 .13254 L
.66155 .13247 L
.66276 .13248 L
.66405 .13257 L
.66527 .13275 L
.66639 .133 L
.66769 .1334 L
.66912 .13399 L
.67046 .13471 L
.67171 .13553 L
.67449 .13793 L
.67706 .1409 L
.67987 .14505 L
.68283 .15055 L
.68783 .16279 L
.6933 .18113 L
.70335 .22524 L
.70829 .24649 L
.71046 .25429 L
.71285 .26114 L
.71414 .26391 L
.71535 .26586 L
.71663 .26718 L
.71801 .26772 L
Mistroke
.71872 .26764 L
.7195 .26725 L
.72024 .26661 L
.72093 .26578 L
.72222 .26361 L
.7236 .26048 L
.72624 .25239 L
.72873 .24278 L
.73339 .22193 L
.74407 .17558 L
.74945 .15858 L
.75251 .15154 L
.75387 .14901 L
.75536 .14668 L
.75678 .14486 L
.75809 .14352 L
.75934 .14254 L
.76068 .14182 L
.76186 .14146 L
.76298 .14139 L
.7642 .14161 L
.76552 .14224 L
.76685 .14329 L
.7676 .14409 L
.76829 .14498 L
.7697 .14721 L
.77121 .15029 L
.77394 .15788 L
.77642 .16727 L
.77891 .17932 L
.78121 .19306 L
.7864 .23449 L
.79581 .33755 L
.79833 .36289 L
.80071 .38171 L
.80203 .38913 L
.80277 .39227 L
.80347 .39445 L
.80468 .39652 L
.80598 .39621 L
.80722 .3935 L
.80855 .38805 L
.80981 .38068 L
.81097 .37222 L
.8155 .32831 L
.82091 .26919 L
.82389 .24039 L
.82671 .21745 L
.82933 .20011 L
.83218 .18534 L
Mistroke
.83477 .17521 L
.83716 .16827 L
.8383 .16571 L
.83952 .16342 L
.84057 .16181 L
.84173 .16041 L
.84301 .15925 L
.84435 .15844 L
.8456 .15803 L
.84676 .1579 L
.84809 .15801 L
.84934 .15835 L
.85047 .15881 L
.85169 .15947 L
.85443 .16142 L
.85695 .16368 L
.86236 .16937 L
.86817 .17538 L
.87098 .17775 L
.87236 .17872 L
.87365 .17949 L
.87491 .18012 L
.87604 .18057 L
.87731 .18095 L
.87865 .18119 L
.87989 .18127 L
.8812 .1812 L
.88232 .18101 L
.88354 .18067 L
.88486 .18015 L
.88627 .17941 L
.88882 .17765 L
.89382 .17282 L
.89838 .16739 L
.90965 .1529 L
.9146 .14727 L
.92005 .14229 L
.92248 .14053 L
.92509 .13897 L
.92636 .13834 L
.92756 .13783 L
.92874 .1374 L
.92981 .13709 L
.93105 .13683 L
.93238 .13666 L
.9336 .13663 L
.93476 .13669 L
.93611 .13691 L
.93735 .13723 L
.93871 .13774 L
Mistroke
.94016 .13844 L
.94275 .14018 L
.94553 .14279 L
.94816 .14607 L
.95056 .14988 L
.95337 .15548 L
.95642 .16315 L
.96198 .18169 L
.97074 .22274 L
.97578 .2502 L
.98041 .27309 L
.98278 .28228 L
.98399 .28601 L
.98527 .28918 L
.98657 .29147 L
.98778 .29275 L
.98851 .29311 L
.98921 .29316 L
.99051 .2925 L
.99166 .29111 L
.99288 .28884 L
.99392 .28629 L
.99507 .28288 L
1 .26231 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002Booooo`Go00007_ooool2o`000;7ooooo002Aooooo`;o0000
0oooool2o`0001gooooo00?o0000ooooooooool0;_ooool6o`0007cooooo000hooooo`Co0000E?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Wooooo1?l0000]ooooo`03o`000?oo
oooooooo00?ooooo0_l0001@ooooo`Co00009oooool003Oooooo0_l00002ooooo`;o00006_ooool6
o`0003;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Gooooo`?o00000_ooool0
0ol0003oooooooooo`0Xooooo`;o00001oooool00ol0003oooooooooo`1<ooooo`?o00000oooool2
o`0002Gooooo000gooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05_ooool2o`00
00Cooooo0_l0000`ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05_ooool00ol0
003oooooo`000003ooooo`03o`000?oooooooooo02Gooooo0_l0000:ooooo`03o`000?oooooooooo
01Oooooo1?l0000`ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08_ooool003Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Go
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool05Oooool2o`0000;ooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo027ooooo000fooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Dooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool08Oooool2o`0000kooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo02[ooooo0_l0000:ooooo`03o`000?oooooooooo
027ooooo000eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Booooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Poooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Qoooo
o`00=Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`02ooooo`;o00001?ooool00ol0003oooooooooo`0Mooooo`;o
00004_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo023ooooo000eooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01?ooooo0ol0000Aooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
8?ooool001kooooo0_l0000Dooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01;ooooo0_l00002ooooo`;o00003_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01oooooo000Eooooo`;o000000Ko410@
ooooooooooooooooonk^k_lb<S84o`0001?ooooo00?o0000ooooooooool00oooool01OnHV9So410@
o`000?lb<S;oc<c<00;ooooo00Ko0000onk^k_lb<S;o0000oc8b<_o^k^h;ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooool000001?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?oo
ool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01Sooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^3_ooool00ol0003ooooo
ooooo`09ooooo`Go00000_ooool01_l0003ok^k^oc8b<_l0003o<S8bonk^kP?ooooo00?o0000oooo
ooooool04Oooool02Ol0003oooooooooooooooooV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Ko
oooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0>ooooo`005_ooool0
0ol0003oooooooooo`02ooooo`07ogMgMonHV9So0000oiRHV?mgMgOoooooo`00000Booooo`03o`00
0?oooooooooo00?ooooo00Go410@okZj^_ooooooMgMgoc8b<P02ooooo`06o`000?mgMgOoV9RHoooo
oonHV9SoMgMg2_ooool00ol0003oooooooooo`0<ooooo`07o`000?ooooooV9RHob4Q8Oo^k^kooooo
odA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07?ooool00ol0003oooooo`000004ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Fooooo`;o00000_ooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`09
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00_ooool01_l0003oMgMgoiRHV?ooooooV9RHogMgM`?o
oooo00?o0000ooooooooool04?ooool2o`0000?ooooo00Go410@okZj^_l0003oMgMgoc8b<P03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;
ooooo`Ko00000_ooool5o`0000?ooooo00Oo410@o`000?oooooooooooa0@4?oooooo0000013ooooo
1_l00006ooooo`05o`000?ooooooooooo`000?l@41000oooool00ol@413oooooooooo`08ooooo`03
o`000?oooooooooo00Kooooo1_l000001_oooooo0000oooooonHV9So8B4Qonk^kPCooooo00Go410@
oooooooooooooooooa0@400Cooooo`Ko00000oooool00ol0003oooooo`000004ooooo`05oa0@4?oo
ooooooooooooool@41001oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Dooooo`;o00001?ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`0:ooooo`03
oiRHV?lQ8B7ok^k^00;ooooo00?o0000ooooool@41000oooool01Ol@413ooooooooooooooooo0000
01;ooooo00?o0000ooooooooool01Oooool2o`0000?ooooo00Oo410@oooooooooooooooooa0@4?oo
oooo000001?ooooo00?o0000ooooooooool00oooool5o`0000?ooooo00Go410@oooooooooooooooo
oa0@400>ooooo`004oooool01?m4A4CogMgMooooool00004ooooo`;o00000_ooool00ol0003ooooo
o`00000Aooooo`03o`000?oooooooooo00Oooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooo
oooooooooooo000000Wooooo00?o0000ooooooooool03_ooool01_l0003ooooooooooonHV9So8B4Q
onk^kP?ooooo00Go0000ooooooooooooooooo`00000Looooo`03o`000?oooooo000000Cooooo00Go
0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003oooool00ol0003o
ooooooooo`0:ooooo`07oiRHV?lQ8B7ok^k^ooooool0003oooooo`000003ooooo`05o`000?oooooo
ooooooooool000004Oooool00ol0003oooooooooo`06ooooo`03ojVYZOl0003ooooo00;ooooo00Co
0000oooooooooooooooo0_l0000Dooooo`03o`000?oooooooooo00?ooooo00CoA4A4omgMgOoooooo
00001?ooool01Ol0003ooooooooooooooooo000000kooooo000Cooooo`04omgMgOmEEEGoooooo`00
00Cooooo0_l00002ooooo`04o`000?ooooooooooo`00013ooooo00?o0000ooooooooool01_ooool0
0ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000002Oooool00ol0003ooooooooo
o`0>ooooo`06o`000?oooooooooooooooomgMgOoIVIV0oooool01Ol0003ooooooooooooooooo0000
01cooooo00?o0000ooooool000001?ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo00_ooooo00KoMgMgofIVI_oooooo0000
ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`05ooooo`03oa0@4?l0003o^[Zj00;o000000?oooooo`000?ooool00_ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0
003ooooooooooooooooo000000kooooo000Dooooo`03ogMgMoo<c<co000000Cooooo00Go0000oooo
oooooooooooooa0@4002ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01oooool0
0onj^[[o8B4Qooooo`02ooooo`05oa0@4?l0003oooooooooool@41002Oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@
4?oooooooooo01Wooooo00Co0000oooooooooooo00001?ooool01Ol@413ooooooooooooooooo410@
00Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`;o00001_ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@00oooooo00?o0000ooooooooool03?ooool01Ol0003oooooo`000?oo
oooo410@00?ooooo00?o410@ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00Kooooo00?o^[Zjob4Q8Oooool01_l000000ol@413oooooooooo`0Dooooo`03o`000?oo
oooooooo00?ooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00kooooo
000Dooooo`03onk^k_m4A4Co000000Cooooo00Go0000oiRHV?ooooooV9RHogMgM`02ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool01?ooool01Ol@413oV9RHoooooonj^[[o000000?o
oooo00GoMgMgo`000?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo013ooooo00Go0000okZj
^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool01?l0003ooooooooo
ool00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00oooooo00?o0000ooooooooool02?ooool03Ol0003o^[ZjoooooonHV9So410@ooooool0003ooooo
ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00?ooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05_oo
ool00ol0003oooooooooo`03ooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0>ooooo`005Oooool00omgMgOo0000ooooo`03ooooo`05o`000?lb<S;o0000oc8b<_o^k^h0
0oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`0@oooo
o`05o`000?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00Co
0000oeEEEOmVIVKo00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`03ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0?ooooo`03o`000?oooooooooo00Sooooo00KoV9RHoa0@4?l0003o8B4Qolc<c?l0
0002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h05_ooool00ol0003oooooooooo`04ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0>ooooo`006_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
01gooooo000Jooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0@ooooo`?o00004_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01co
oooo000Jooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0>ooooo`;o000000?oooooo`000?ooool04?ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo01cooooo000Jooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0>ooooo`05o`000?ooooooooooooooool000004?ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo01cooooo000Jooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0>ooooo`05o`000?ooooooooooooooool00000
4?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01cooooo000Foooooooo0000@?l0
000Cooooo`005_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooooooo`;o00000_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0
003oooooo`000007ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000000oooool01Ol0
003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo
0_l00006ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
0_l00007ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01Oooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0
003oooooooooo`0Aooooo`005_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l0
0007ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000000oooool01Ol0003ooooooooo
oooooooo000000Oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo0_l00006oooo
o`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0003ooooooooo
o`0Aooooo`006Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01_ooooo000Ioooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0_oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool06oooool001Wooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`0Jooooo`006?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo01[ooooo000Hooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool06_oo
ool001Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo02oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Jooooo`006?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0Hooooo`;o00000_ooool00ol0003oooooooooo`0:ooooo`;o00002?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`0Jooooo`006?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Jooooo`?o00003Oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo01[ooooo000Gooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02[ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Iooooo`005oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool06Oooool001Oooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0:_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Wooooo000Goooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Ioooo
o`005oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool06Oooool001Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo03;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo01Wooooo000Fooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02[ooooo0_l00009ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0:_ooool01Ol0003ooooooooooooooooo000001Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Sooooo
000Fooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo02_ooooo00Co0000oooooooooooo00005?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Aooooo`009Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0:oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0:oooool01?l0003oooooo`000?l0000Dooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo017ooooo
000Uooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0[ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0/ooooo`;o00005Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Aooooo`009Oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0B
ooooo`009_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0@oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Booooo`009_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo03Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Booooo`00
9_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
:oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
@oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo00Co0000oooooooooooo
00005Oooool002Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo02_ooooo0_l0000:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
A?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo00Co0000oooooooooooo
00005Oooool002Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo04Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0booooo`04o`00
0?ooooooooooo`0001Gooooo000Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
<_ooool01?l0003oooooo`000?l0000Eooooo`009_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo03Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo03?ooooo0_l0000Fooooo`009_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo04_ooooo000Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0=Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`15ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Boooool0
02Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
027ooooo1Ol00006ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`15ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Boooool002Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo027o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0Boooool002Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0gooooo`05
o`000?ooooooooooooooool000003oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
02;ooooo00?oV9RHob4Q8Oo^k^h01oooool3o`0000_ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`16ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Boooool002Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0gooooo`04o`000?ooooooooooo`00
013ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Sooooo`03oiRHV?lQ8B7ok^k^
00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
04Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1;ooooo`009oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooool000004?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo02Cooooo00?oMgMgofIVI_ooool01Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0A_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo04cooooo000Wooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0>?ooool2o`00017ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1<ooooo`009oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Qooooo`05o`000?nj^[[ooooooiRHV?l@4100
1_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
B?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04cooooo000Wooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo027ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo00cooooo
00Go0000ooooooooooooooooo`00001:ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0C?ooool002Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1;ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0<ooooo`05o`00
0?ooooooooooooooool00000B_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04co
oooo000Wooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Boooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool03?ooool01Ol0003ooooo
oooooooooooo000004[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1<ooooo`00
9oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0/ooooo`;o00003Oooool01Ol0003ooooooooooooooooo000004[o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1<ooooo`009oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo00cooooo00Co0000oooooooooooo0000Boooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo04cooooo000Xooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0COooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool03?ooool01?l0003oooooooooool0001;ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0C?ooool002Sooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooo000004_ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1<ooooo`00:?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00gooooo0ol0
001;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0C?ooool002Sooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`0=ooooo`;o0000C?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo04cooooo000Xooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0COooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool0G?ooool01Ol0003ooooooooooooooooo000004oooooo000Xooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool0G?ooool01Ol0003ooooooooooooooooo000004oooooo000Xoooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool0G?ooool01Ol0003ooooooooooooooooo
000004oooooo000Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0COooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo02gooooo0_l0001Mooooo`05o`000?oooooooooo
ooooool00000Coooool002Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1=oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Loooo
o`05o`000?ooooooooooooooool00000Coooool002Sooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`1Looooo`05o`000?ooooooooooooooool00000Coooool002Wooooo00Go0000oooo
ooooooooooooo`00001@ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`1Looooo`05o`000?ooooooooooooooool00000Coooool002Wooooo00Go0000
ooooooooooooooooo`00001@ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`1Mooooo`04o`000?ooooooooooo`0004oooooo000Yooooo`05o`000?oo
ooooooooooooool00000D?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool0GOooool01?l0003oooooooooool0001?ooooo`00:Oooool01Ol0003ooooo
oooooooooooo0000057ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo05gooooo00Co0000oooooooooooo0000Coooool002Wooooo00Go0000oooooooo
ooooooooo`00001Aooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`1Mooooo`04o`000?ooooooooooo`0004oooooo000Yooooo`05o`000?oooooooooo
ooooool00000DOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02kooooo0_l0001N
ooooo`03o`000?oooooo0000053ooooo000Yooooo`05o`000?ooooooooooooooool00000DOooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0GOooool0
0ol0003oooooo`00001@ooooo`00:Oooool01Ol0003ooooooooooooooooo0000057ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo05gooooo00?o0000
ooooool00000D?ooool002Wooooo00Go0000ooooooooooooooooo`00001Aooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooo
oooo04oooooo000Yooooo`05o`000?ooooooooooooooool00000DOooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0/?ooool002Wooooo00Co0000oooo
oooooooo0000D_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Gooooo0_l00000
0ol@413oooooooooo`04ooooo`03o`000?oooooooooo0;3ooooo000Yooooo`04o`000?oooooooooo
o`0005;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0/?ooool002Wooooo00Co0000oooooooooooo0000D_ooool0
1Ol0003ooooooooooooooooo000002Kooooo1Ol00006ooooo`03o`000?oooooooooo0;3ooooo000Y
ooooo`04o`000?ooooooooooo`0005;ooooo00Go0000ooooooooooooooooo`00000Vooooo`04odA4
A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00:_ooool00ol0003oooooo`00001Booooo`05o`00
0?ooooooooooooooool000009_ooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo
0;3ooooo000Zooooo`03o`000?oooooo000005?ooooo00Co0000oooooooooooo00009oooool00omg
MgOoc<c<o`000007ooooo`03o`000?oooooooooo0;3ooooo000Zooooo`03o`000?oooooo000005?o
oooo00Co0000oooooooooooo00009oooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo
0;3ooooo000Zooooo`03o`000?oooooo000005?ooooo00Co0000oooooooooooo0000:?ooool00omg
MgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo000Zooooo`;o0000E?ooool01?l0003o
ooooooooool0000aooooo`03o`000?oooooooooo0;3ooooo000[ooooo`03o`000?oooooooooo05;o
oooo00Co0000oooooooooooo0000<Oooool00ol0003oooooooooo`2`ooooo`00P?ooool01?l0003o
ooooooooool0000aooooo`03o`000?oooooooooo0;3ooooo0020ooooo`03o`000?oooooo000003;o
oooo0_l0002aooooo`00P?ooool00ol0003oooooo`00000booooo`03o`000?oooooooooo0;3ooooo
0021ooooo`;o0000<_ooool00ol0003oooooooooo`2`ooooo`00POooool2o`0003;ooooo00?o0000
ooooooooool0/?ooool0087ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00:[ooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`00
0?oooooooooo0;3ooooo002Zooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000/?ooool00:[ooooo00Go
0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03oeEEEOn7
QhOooooo00Sooooo00?o0000ooooooooool0/?ooool00:[ooooo00?ogMgMoa0@4?nHV9P02?ooool0
0ol0003oooooooooo`2`ooooo`00Zoooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Zoooo
o`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OlQ
8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05oc8b<_nHV9Sooooo
oiRHV?lb<S801_ooool3o`000;3ooooo002Zooooo`05olc<c?l0003o0000o`000?o<c<`0^Oooool0
0:[ooooo00Go410@okZj^_oooooo^[Zjoa0@402iooooo`00Z_ooool01Ol0003o^[Zjoooooonj^[[o
00000;Wooooo002Zooooo`05ojVYZOl@413o0000oa0@4?nYZJT0^Oooool00?ooooooJOooool00;?o
oooo00?o0000okZj^_ooool0/_ooool00;?ooooo0_lb<S:cooooo`00Q?ooool2o`000006oa0@4?oo
oooooooooa0@4?l0003o410@6?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj
^P0Hooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01Oooool2o`000003oa0@4?oooooooooo07[ooooo
0025ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`0000gooooo00Wo
MgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL00oooool00oo<c<co0000oa0@400<oooo
o`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoEEEEogMgMoooooooV9RHob4Q
8@06ooooo`03o`000?oooooooooo07_ooooo0025ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool06oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo013ooooo00?o
0000ooooooooool06_ooool01Ol0003ooooooooooooooooo000000?ooooo1Ol0001looooo`00QOoo
ool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000=ooooo`05ogMgMolb<S;ooooooooo
ool000000oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo1_l00009oooo
o`05o`000?nHV9SooooooiRHV?lQ8B400oooool01?m4A4CogMgMooooool0001mooooo`00QOooool0
1_l0003ogMgMoc8b<_mEEEGogMgMo`0001Wooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05
o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0Jooooo`05o`000?mEEEGo0000
oa0@4?o<c<`00oooool01?oMgMgoEEEEooooool0001mooooo`00QOooool01_l0003oQhN7ojVYZOnj
^[[oEEEEo`0001Wooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@013o
oooo00?o410@o`000?l000000ol0000Iooooo`03oeEEEOn7QhOooooo00Kooooo00?oMgMgolc<c?l0
0000OOooool008Gooooo00Ko0000oc8b<_oooooooooooc8b<_l0000Iooooo`03o`000?oooooooooo
00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Booooo`03o`000?oooooooooo01[ooooo00?ogMgM
oa0@4?nHV9P01_ooool00oo^k^koA4A4o`00001mooooo`00Q?ooool00ol@413o0000ohN7Q`02oooo
o`03ohN7Qol0003o410@01Sooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool0
0ol0003oooooooooo`0Kooooo`04olc<c?m4A4Co0000oa0@40Gooooo00?oMgMgo`000?ooool0O?oo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(66) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .18954 m
.00488 .16898 L
.00942 .15456 L
.01441 .14325 L
.01721 .13873 L
.01975 .13569 L
.02104 .13454 L
.02242 .13359 L
.02359 .133 L
.02488 .13257 L
.02627 .13238 L
.02704 .13238 L
.02776 .13246 L
.02914 .1328 L
.03045 .13336 L
.03166 .13411 L
.03296 .13515 L
.03529 .13778 L
.03671 .13993 L
.03806 .14239 L
.04057 .1483 L
.04313 .15636 L
.04595 .16794 L
.04889 .18355 L
.05164 .20185 L
.05655 .24484 L
.06182 .30435 L
.06478 .34015 L
.06799 .37568 L
.06947 .38923 L
.07103 .40093 L
.07237 .40834 L
.07313 .41139 L
.07384 .41344 L
.07519 .41513 L
.07586 .41491 L
.0766 .41385 L
.0779 .40995 L
.07912 .40413 L
.08056 .39481 L
.08187 .38439 L
.08481 .3563 L
.08986 .30335 L
.09459 .26115 L
.09697 .24476 L
.09953 .23089 L
.10098 .22461 L
.10236 .21966 L
.10372 .21566 L
.10495 .21273 L
Mistroke
.10632 .21019 L
.10702 .20915 L
.10777 .20821 L
.10912 .20698 L
.11039 .20628 L
.11111 .20606 L
.11189 .20595 L
.11271 .20595 L
.11348 .20606 L
.11485 .20646 L
.11562 .20677 L
.11631 .2071 L
.1214 .20992 L
.12263 .21052 L
.12396 .21105 L
.12472 .2113 L
.12542 .21147 L
.12679 .21167 L
.12805 .21166 L
.12922 .21148 L
.13051 .21108 L
.13188 .21041 L
.13332 .20941 L
.13468 .20821 L
.13723 .20526 L
.14186 .1979 L
.14687 .18797 L
.15726 .16636 L
.16277 .15652 L
.16868 .14829 L
.17158 .14516 L
.17433 .14271 L
.17701 .14075 L
.17949 .13932 L
.18184 .1383 L
.18302 .13791 L
.18433 .13756 L
.18563 .13731 L
.18637 .13721 L
.18704 .13714 L
.18828 .13707 L
.18959 .13706 L
.19098 .13713 L
.19223 .13725 L
.19293 .13734 L
.19369 .13746 L
.19506 .13772 L
.1977 .13839 L
.20015 .13925 L
.20282 .14047 L
Mistroke
.20576 .14218 L
.2117 .14679 L
.21716 .15256 L
.22235 .16023 L
.22701 .16977 L
.2321 .18379 L
.2376 .20414 L
.24347 .23246 L
.2486 .26121 L
.25402 .29012 L
.25671 .30151 L
.25823 .30659 L
.25896 .3086 L
.25966 .31025 L
.26096 .31261 L
.26216 .31387 L
.26344 .31423 L
.26416 .31398 L
.26484 .31344 L
.2655 .31262 L
.26623 .31142 L
.26753 .30844 L
.26908 .30361 L
.2705 .29806 L
.27652 .26614 L
.28183 .23403 L
.2875 .2031 L
.2924 .18119 L
.29771 .16303 L
.3005 .15593 L
.30307 .15082 L
.30553 .1471 L
.30678 .14558 L
.30813 .14421 L
.30935 .14321 L
.31046 .14248 L
.31158 .14194 L
.31264 .14162 L
.31387 .14152 L
.31501 .14172 L
.31626 .14229 L
.31759 .14337 L
.31831 .14418 L
.31907 .1452 L
.32042 .14754 L
.32188 .15081 L
.32347 .15537 L
.32634 .1664 L
.329 .18049 L
.33162 .19865 L
Mistroke
.33399 .21977 L
.33933 .28591 L
.3444 .36754 L
.34718 .41155 L
.34854 .43047 L
.34978 .44542 L
.35084 .45593 L
.35199 .46477 L
.35321 .47079 L
.35437 .47317 L
.35564 .47194 L
.35699 .46629 L
.35827 .45707 L
.35943 .44576 L
.36495 .3662 L
.37079 .27541 L
.37319 .24526 L
.37577 .21912 L
.3786 .19728 L
.38125 .18235 L
.38384 .17192 L
.38531 .16764 L
.38667 .16463 L
.38786 .16272 L
.38916 .16133 L
.39053 .16063 L
.39181 .16065 L
.39299 .16117 L
.39423 .16221 L
.39529 .16344 L
.39645 .16512 L
.40145 .17538 L
.4129 .20987 L
.41553 .21812 L
.41831 .22578 L
.42069 .23097 L
.42204 .23324 L
.4233 .23487 L
.42458 .23603 L
.42575 .23665 L
.4271 .23684 L
.42838 .23651 L
.42975 .23562 L
.43102 .23432 L
.43241 .23239 L
.43389 .22978 L
.43659 .22367 L
.43913 .21659 L
.44389 .2012 L
.45459 .168 L
Mistroke
.45997 .15557 L
.46306 .14986 L
.46588 .14562 L
.46859 .14244 L
.47115 .14023 L
.47256 .13932 L
.47386 .13865 L
.47529 .13808 L
.47608 .13783 L
.4768 .13764 L
.47801 .1374 L
.4793 .13725 L
.48045 .1372 L
.48165 .13723 L
.48297 .13737 L
.4842 .1376 L
.48555 .13797 L
.48699 .1385 L
.48951 .13977 L
.49223 .14162 L
.49717 .14595 L
.5064 .15686 L
.51155 .16516 L
.51636 .17465 L
.52208 .18838 L
.5273 .20424 L
.53796 .2496 L
.54351 .2783 L
.54655 .29394 L
.54941 .30739 L
.55198 .31754 L
.55311 .32118 L
.55434 .32449 L
.55562 .3271 L
.55696 .32889 L
.55767 .32941 L
.55843 .32964 L
.55979 .32919 L
.56103 .32783 L
.56238 .32534 L
.56365 .32207 L
.56483 .31832 L
.56941 .2982 L
.58066 .23385 L
.58616 .20578 L
.5912 .18504 L
.59573 .17025 L
.60067 .1575 L
.6059 .14717 L
.61086 .13984 L
Mistroke
.6163 .13385 L
.61929 .13122 L
.6221 .1291 L
.62472 .12745 L
.62757 .12604 L
.62882 .12555 L
.63015 .1251 L
.63252 .12449 L
.6338 .12426 L
.63448 .12416 L
.6352 .12408 L
.63651 .12398 L
.63773 .12394 L
.6389 .12397 L
.63999 .12405 L
.64119 .12421 L
.64248 .12447 L
.64377 .12483 L
.64519 .12536 L
.64667 .12606 L
.64805 .12687 L
.65051 .12871 L
.65315 .13129 L
.65564 .13433 L
.65834 .13841 L
.66324 .14826 L
.66801 .16158 L
.6724 .17743 L
.6819 .22065 L
.68714 .24473 L
.68972 .25465 L
.69211 .26187 L
.69347 .26491 L
.69416 .26613 L
.69491 .2672 L
.69573 .26805 L
.69651 .26853 L
.69727 .2687 L
.69796 .2686 L
.6992 .26781 L
.70056 .26606 L
.70125 .26484 L
.70198 .26329 L
.70331 .25992 L
.70613 .25055 L
.70879 .23958 L
.71378 .21626 L
.72395 .17203 L
.72908 .15604 L
.732 .14908 L
Mistroke
.73474 .14385 L
.73723 .14005 L
.7396 .13722 L
.74173 .13531 L
.74294 .13448 L
.74406 .13387 L
.74537 .13333 L
.7466 .13301 L
.74771 .13287 L
.74891 .13286 L
.75022 .13302 L
.75161 .13339 L
.75279 .13384 L
.75409 .1345 L
.75672 .13633 L
.75959 .1391 L
.76229 .14255 L
.76479 .14655 L
.76953 .15655 L
.77456 .17116 L
.77994 .19213 L
.78499 .21764 L
.79651 .29237 L
.79909 .30902 L
.80185 .32487 L
.80441 .33683 L
.80566 .3415 L
.80682 .34501 L
.80812 .34799 L
.80881 .34913 L
.80954 .35001 L
.81071 .35073 L
.81201 .3505 L
.81275 .3499 L
.81342 .34907 L
.8142 .34778 L
.81494 .34625 L
.81768 .33818 L
.82002 .32895 L
.8225 .31751 L
.82697 .29521 L
.83711 .24887 L
.84792 .21286 L
.85961 .18412 L
.87065 .16297 L
.8808 .14841 L
.88574 .14312 L
.89103 .13875 L
.89603 .13553 L
.90058 .13329 L
Mistroke
.90193 .13278 L
.90336 .13231 L
.9046 .13197 L
.90593 .13167 L
.90735 .13142 L
.90869 .13125 L
.90946 .13118 L
.91028 .13112 L
.91097 .13108 L
.91173 .13105 L
.91312 .13104 L
.91438 .13108 L
.91508 .13112 L
.91583 .13118 L
.9172 .13134 L
.91849 .13156 L
.91985 .13187 L
.92101 .13222 L
.92229 .13269 L
.92491 .13397 L
.92777 .13592 L
.93047 .13832 L
.93297 .14108 L
.9377 .14812 L
.94034 .15338 L
.94273 .15917 L
.94817 .17654 L
.95404 .20212 L
.96467 .26016 L
.96864 .27926 L
.96978 .2837 L
.97086 .28733 L
.97184 .29009 L
.97288 .29243 L
.97404 .29426 L
.97511 .29521 L
.97626 .29542 L
.97753 .29466 L
.97861 .29323 L
.97977 .2909 L
.98087 .28799 L
.98187 .28477 L
.98631 .26524 L
.99116 .23806 L
1 .18954 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo02Oooooo1Ol00024
ooooo`00]Oooool00ol0003oooooooooo`0Uooooo`;o00001?ooool2o`0008?ooooo002eooooo`;o
00009Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo053ooooo0_l0000^ooooo`00
7Oooool4o`0009Cooooo00?o0000ooooooooool08_ooool2o`0000[ooooo00?o0000ooooooooool0
6_ooool3o`0002kooooo1?l000000ooooooo0000o`000002o`0002_ooooo000Looooo`05o`000?oo
ooooooooooooool00000<?ooool3o`0005[ooooo0_l00005ooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Hooooo`;o00000oooool2o`0002[ooooo
0_l00009ooooo`03o`000?oooooooooo02Sooooo000Kooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0:oooool2o`0000;ooooo1?l0001Eooooo`;o00000_ooool3o`0000;ooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool09oooool001[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0X
ooooo`;o00002?ooool2o`0001oooooo1?l0000_ooooo`03o`000?oooooooooo00Cooooo0_l00000
0ooooooo0000ooooo`0Qooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0Vooooo`006_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Kooooo`;o00000_ooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo00Oooooo0_l0000Qooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Vooooo`006_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`08ooooo`;o00008Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool09Oooool001Wooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0Uooooo`006Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`0:ooooo`;o00007oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool09?ooool001Wooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool02_ooool00ol0003oooooo`00000Mooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0Sooooo`006?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool2o`0001?ooooo00?o0000oooo
ooooool02oooool01?l0003oooooooooool0000Looooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0Sooooo`005Oooool2o`000009oa0@4?l0003ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00?o0000ooooooooool04oooool01OnHV9So410@
o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool00oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool4o`000008oa0@4?oooooo
0000onk^k_lb<S;o0000oc8b<_o^k^h@ooooo`03o`000?oooooooooo00_ooooo00Go0000oooooooo
ooooooooo`00000Jooooo`03o`000?oooooooooo00Co000000So410@ooooooooooook^k^oc8b<_l0
003o<S8bonk^kPOooooo00?o0000ooooooooool04?ooool5o`0000?ooooo00Ook^k^oc8b<_l0003o
<S8bonk^k_oooooo000001Wooooo00goV9RHoa0@4?l0003o<S8bolc<c?oooooo0000ooooooo^k^ko
<S8bo`000?lb<S;ok^k^017ooooo00?o0000ooooooooool02Oooool2o`000009oa0@4?oooooooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Fooooo`03o`000?oooooo000000;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`04ooooo`03o`000?oooooooooo01?ooooo00Go410@okZj^_oooooo
MgMgoc8b<P03ooooo`07ogMgMonHV9SooooooiRHV?mgMgOoooooo`00000Dooooo`03o`000?oooooo
oooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo00[o0000oooooooooooo
0000oooooomgMgOoV9RHo`000?nHV9SoMgMg3oooool00ol0003oooooooooo`0<ooooo`05o`000?oo
ooooooooooooool000006_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo00oooooo00Go0000ob4Q8Oo^
k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool00ol0003oooooooooo`0F
ooooo`0=oa0@4?nj^[[oooooogMgMolb<S;oooooo`000?ooooooMgMgoiRHV?ooooooV9RHogMgM`0A
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00kooooo000;ooooo`Ko00000_ooool5o`0000?ooooo00Go410@oooooooooooooooooa0@
4004ooooo`03o`000?oooooooooo00_ooooo1_l00006ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooo`00000Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooooooo
o`Ko00001Oooool01_l0003oooooooooool0003ooooooa0@40;ooooo00?o0000oa0@4?ooool03_oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@4008ooooo`03o`000?oooooooooo00kooooo00Go0000oooooonHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000_ooool00ol0003oooooooooo`0Jooooo`;o00000_ooool01Ol@
413ooooooooooooooooo410@017ooooo00?o0000ooooooooool01oooool5o`0000?ooooo00Go410@
oooooooooooooooooa0@400>ooooo`004oooool00om4A4CogMgMooooo`02o`0000?ooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo01Kooooo00?oZJVYoa0@4?ooool00_oo
ool01?l0003oooooooooooooool2o`0001Kooooo00?o0000ooooooooool00oooool00onHV9So8B4Q
onk^kP03ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00cooooo00Ko0000oooooooooooo0000ooooool00002ooooo`;o00003oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0008ooooo`03o`000?oooooooooo00kooooo00Ko0000ooooooooooooV9RHob4Q8Oo^k^h3ooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Iooooo`03ojVYZOl0003ooooo
00;ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo00Kooooo00CoA4A4
omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000000kooooo000Cooooo`03omgMgOmE
EEGooooo00;o00000oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0
5?ooool00ol@413o0000okZj^P03ooooo`04o`000?ooooooooooooooo`;o00005oooool00ol0003o
ooooooooo`03ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03?ooool01_l0003oooooooooool0003o
ooooo`0000?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo00gooooo
00Ko0000ooooooooooooooooogMgMomVIVH3ooooo`05o`000?ooooooooooooooool000000_ooool0
0ol0003oooooooooo`0Hooooo`03oa0@4?l0003o000000?ooooo00Go0000ooooooooooooooooo`00
000Booooo`03o`000?oooooooooo00Kooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000000kooooo000Dooooo`04ogMgMoo<c<co0000o`0000?ooooo00Go410@oooooooo
oooooooooa0@4005ooooo`03o`000?oooooooooo01Gooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@
413ooooooooooooooooo000001Sooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo410@00?ooooo00?o410@ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooool000000_ooool01Ol@413ooooooooooooooooo000000kooooo
00?o0000ooooooooool03Oooool2o`0000Cooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4009ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo410@
00?ooooo00Go410@ooooooooooooooooo`00000Jooooo`03o`000?lQ8B7ooooo00;ooooo00Go410@
oooooooooooooooooa0@400Booooo`03o`000?oooooooooo00Oooooo00?oMgMgolc<c?l000001?oo
ool01Ol@413ooooooooooooooooo410@00kooooo000Dooooo`03onk^k_m4A4Co000000Cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo01;ooooo00Go410@oiRHV?oooooo
^[Zjo`000003ooooo`05ogMgMonHV9Soooooo`000?mgMgL06Oooool01ol0003oooooo`000?nj^[[o
oooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo000000;ooooo00GoMgMgoiRHV?oooooo
V9RHo`00000>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Wooooo00?o0000ooooooooool03?ooool01ol0003oooooo`000?nj^[[o
oooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?o0000ooooooooool0
5Oooool01Ol@413oV9RHo`000?nj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Boooo
o`03o`000?oooooooooo00Oooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00kooooo000Eooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`03o`000?oooooooooo01;ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb
<S;o0000o`000?o^k^h06Oooool01ol0003ooooooiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:
ooooo`05oeEEEOmVIVKo0000ooooool000000_ooool01_o^k^ko<S8bo`000?lb<S;ok^k^o`0000co
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool00_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02_ooool00ol0003oooooooooo`0;ooooo`07o`000?ooooooV9RHoa0@4?l0003o8B4Qolc<
c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00ol0003oooooooooo`0Eooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo00?o0000oooo
ooooool02?ooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool0
01Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
017ooooo000Uooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04Oooool002Kooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Aooooo`009_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo017ooooo000Vooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool04_ooool001Koooooool00010o`0001?ooooo000Fooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00Co0000ooooool0003ooooo0_l000001?oooooo0000ooooooooool2o`0000?ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003ooooo
ooooo`05ooooo`;o00001_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`;o00001_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Kooooo00?o
0000ooooooooool01Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Cooooo
0_l0000Cooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`?o00000oooool5o`0000Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00001_ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ool000001Oooool00ol0003oooooooooo`04ooooo`;o00004oooool002Oooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Booooo`009oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo01?ooooo000Wooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04ooo
ool002Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Cooooo`009oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo01?ooooo000Wooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<ooooo`05o`000?oooooooooooooo
ool000005?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool04oooool002Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00cooooo00Co0000oooooooooooo00005Oooool2o`0000Wooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Dooooo`00:?ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo02_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool03?ooool4o`0001Gooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Cooooo000Xooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Dooooo`00:?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05?oo
ool002Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo01Cooooo000Xooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Dooooo`00:?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool05?ooool002Sooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo01Gooooo000Xooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0Uooooo`;o00002oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo01Gooooo000Xooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Rooooo`05o`000?ooooooooooooooool000006ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Eooooo`00:?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool08_ooool2o`000003ooooool0003ooooo01_ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool05Oooool002Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo02?ooooo0_l0000Mooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Gooooo000Xooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`12ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo01Kooooo000Xooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Kooooo000Yooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`13ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo01Kooooo000Yooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`13ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0:Oooool0
1Ol0003ooooooooooooooooo000001Wooooo000Yooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Vooooo`;o00003?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Y
ooooo`05o`000?ooooooooooooooool000006Oooool002Wooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Zooooo`04o`000?ooooooooooo`0001Wooooo000Yooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0:oooool01?l0003oooooooooool0000Iooooo`00:Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0AOooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo02_ooooo0ol0000Jooooo`00:Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0AOooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo02cooooo0_l0000Jooooo`00:Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0AOooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo04Sooooo000Yooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0<_ooool01Ol0003ooooooooooooooooo000001Kooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Looooo`Go00001_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo04Sooooo000Yooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
<oooool01?l0003oooooooooool0000Fooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool07?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`18ooooo`00:Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03?o
oooo00Co0000oooooooooooo00005_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01gooooo00?oV9RHob4Q8Oo^k^h01oooool3o`0000gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`16ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0BOooool002Wo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0cooooo`?o00005oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01kooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Aoooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo04Wooooo000Yooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0=?ooool2o`0001Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Oooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`19ooooo`00:Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04Sooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`19ooooo`00:Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0L
ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`0>ooooo`04o`000?oo
ooooooooo`0004_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`19ooooo`00:_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Looooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`0>ooooo`04o`000?ooooooooooo`0004_ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`1:ooooo`00:_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00oooooo
0_l0001<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0B_ooool002[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0?ooooo`;o0000C?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo04[ooooo000Zooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0Coooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Oooooo0_l0001O
ooooo`05o`000?ooooooooooooooool00000COooool002[ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`1Nooooo`05o`000?ooooooooooooooool00000COooool002[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`1Nooooo`05o`000?ooooooooooooooool00000COoo
ool002[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1Nooooo`04o`000?oooooo
ooooo`0004kooooo000Zooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Coooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0Goooool0
0ol0003oooooo`00001>ooooo`00:_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
04oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
05oooooo0ol0001>ooooo`00:_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0;3o
oooo000Zooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Coooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0/?ooool002_ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`2`ooooo`00:oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0X
ooooo`;o0000/Oooool002_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1?oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`2`oooo
o`00:oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0;3ooooo000[ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool0/?ooool002_ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`2`ooooo`00:oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo053ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo0;3ooooo000[ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0D?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0/?ooool002co
oooo00Go0000ooooooooooooooooo`00001Booooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`2`ooooo`00;?ooool01Ol0003ooooooooooooooooo0000
05;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Yooooo`;o0000/Oooool002co
oooo00Co0000oooooooooooo0000Doooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool0/?ooool002cooooo00Co0000oooooooooooo0000E?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0/?ooool002co
oooo00Co0000oooooooooooo0000E?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool0/?ooool002cooooo00Co0000oooooooooooo0000E?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0/?ooool002co
oooo00Co0000oooooooooooo0000E?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
023ooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0;3ooooo000]ooooo`03
o`000?oooooo000005Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool002gooooo0_l0001Eooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool07_ooool5o`0000Kooooo00?o0000ooooooooool0
/?ooool002gooooo0_l0001Eooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07_oo
ool01?m4A4CogMgMooooool00007ooooo`?o0000/?ooool002kooooo00?o0000ooooooooool0Dooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01kooooo00CogMgMoeEEEOoooooo0000
1oooool00ol0003oooooooooo`2`ooooo`00Q?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo01oooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`2`ooooo`00Q?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01oooooo00?ok^k^odA4A?l000001oooool0
0ol0003oooooooooo`2`ooooo`00QOooool01Ol0003ooooooooooooooooo000002;ooooo00?oMgMg
o`000?ooool01_ooool00ol0003oooooooooo`2`ooooo`00QOooool01?l0003oooooooooool0000/
ooooo`03o`000?oooooooooo0;3ooooo0025ooooo`04o`000?ooooooooooo`0002cooooo00?o0000
ooooooooool0/?ooool008Gooooo00Co0000oooooooooooo0000;?ooool00ol0003oooooooooo`2`
ooooo`00QOooool01?l0003oooooooooool0000/ooooo`;o0000/Oooool008Gooooo00Co0000oooo
oooooooo0000;?ooool00ol0003oooooooooo`2`ooooo`00QOooool01?l0003oooooooooool0000/
ooooo`03o`000?oooooooooo0;3ooooo0025ooooo`04o`000?ooooooooooo`0002cooooo00?o0000
ooooooooool0/?ooool008Gooooo00Co0000oooooooooooo0000;?ooool00ol0003oooooooooo`2`
ooooo`00QOooool01?l0003oooooooooool0000/ooooo`03o`000?oooooooooo0;3ooooo0025oooo
o`04o`000?ooooooooooo`0002cooooo00?o0000ooooooooool0/?ooool008Gooooo00Co0000oooo
oooooooo0000;?ooool00ol0003oooooooooo`2`ooooo`00Q_ooool2o`0002gooooo0_l0002aoooo
o`00Q_ooool2o`0002gooooo00?o0000ooooooooool0/?ooool008Kooooo0_l0000]ooooo`03o`00
0?oooooooooo0;3ooooo0026ooooo`;o0000;Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?oo
ool00:[ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Z
ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`000;3ooooo002Zooooo`05o`000?mEEEGo
0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool00omEEEGoQhN7ooooo`08
ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03omgMgOl@413oV9RH00Sooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000
/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Oo<c<co
8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go8B4QoiRHV?oo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Olb<S;oV9RHoooooonHV9So<S8b
00Kooooo0ol0002`ooooo`00Z_ooool01Oo<c<co0000o`000?l0003oc<c<0;Wooooo002Zooooo`05
oa0@4?nj^[[ooooookZj^_l@4100^Oooool00:[ooooo00Go0000okZj^_oooooo^[Zjo`00002ioooo
o`00Z_ooool01OnYZJWo410@o`000?l@413oZJVY0;Wooooo003oooooofWooooo002cooooo`03o`00
0?nj^[[ooooo0;;ooooo002cooooo`;o<S8b/oooool008Cooooo0_l000001_l@413oooooooooool@
413o0000oa0@41Sooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool0
1Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b<_l0003o410@olc<c01looooo`00QOoo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l0000=ooooo`09ogMgMolb
<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@
413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00009ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400ooo
ool01OmEEEGoMgMgoooooonHV9So8B4Q07cooooo0025ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool06oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo013ooooo
00?o0000ooooooooool06_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`00001looooo`00QOooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000=
ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00_ooooo1_l00009ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003oV9RH
oooooonHV9So8B4Q07cooooo0025ooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo00006Oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oo
oooooooo01[ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0O?ooool008Gooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Iooooo`03o`000?oooooooooo
00Cooooo00Go410@oooooooooooooooooa0@400@ooooo`03oa0@4?l0003o000000?o00006Oooool0
0omEEEGoQhN7ooooo`05ooooo`03oeEEEOn7QhOooooo07kooooo0025ooooo`06o`000?lb<S;ooooo
oooooolb<S;o00006Oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
4_ooool00ol0003oooooooooo`0Jooooo`03omgMgOl@413oV9RH00Gooooo00?ogMgMoa0@4?nHV9P0
O_ooool008Cooooo00?o410@o`000?n7QhL00_ooool00on7QhOo0000oa0@400Hooooo`Co00000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo00?o0000ooooooooool06oooool01?o<c<coA4A4
o`000?l@4104ooooo`04olc<c?m4A4Co0000oa0@47cooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(68) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .14335 m
.00123 .14166 L
.00236 .14034 L
.00357 .13915 L
.00488 .1381 L
.00609 .13735 L
.00722 .13684 L
.00829 .1365 L
.00942 .13629 L
.01065 .13625 L
.01196 .13639 L
.0132 .13669 L
.01434 .13712 L
.01566 .13778 L
.01711 .13871 L
.01975 .14092 L
.02249 .14391 L
.02497 .14723 L
.03054 .15663 L
.04057 .17926 L
.06182 .23245 L
.08481 .30842 L
.09032 .34029 L
.09301 .35518 L
.09546 .3667 L
.0967 .37137 L
.09805 .37536 L
.09879 .377 L
.09948 .37815 L
.10083 .37932 L
.10219 .37896 L
.10296 .37805 L
.10369 .37673 L
.10445 .37486 L
.10515 .37272 L
.10672 .36645 L
.10915 .35323 L
.11141 .33783 L
.11654 .29677 L
.12192 .25367 L
.12688 .22018 L
.13218 .19296 L
.13497 .18199 L
.13793 .1726 L
.14289 .16111 L
.14572 .15648 L
.14836 .15312 L
.15088 .15061 L
.15328 .14874 L
.15542 .14741 L
Mistroke
.15777 .14629 L
.16031 .14538 L
.16301 .1447 L
.16557 .14424 L
.16788 .14393 L
.18813 .14184 L
.19367 .14112 L
.19502 .14096 L
.19646 .14082 L
.19729 .14075 L
.19805 .1407 L
.19881 .14066 L
.19953 .14064 L
.20079 .14064 L
.20214 .14069 L
.20328 .14079 L
.20455 .14096 L
.2059 .14123 L
.20736 .14164 L
.20874 .14215 L
.21 .14273 L
.21262 .14437 L
.21499 .14648 L
.21774 .14987 L
.22032 .15419 L
.22272 .15939 L
.22493 .16533 L
.22991 .18357 L
.23495 .20969 L
.24048 .24692 L
.24622 .28905 L
.24905 .3072 L
.25029 .31393 L
.25166 .3202 L
.25294 .32477 L
.25414 .32784 L
.25541 .3297 L
.25678 .33005 L
.25746 .32958 L
.2582 .32859 L
.25897 .32702 L
.25969 .32509 L
.26098 .32053 L
.26236 .31422 L
.26747 .28118 L
.27212 .2452 L
.27753 .2061 L
.28039 .1887 L
.28341 .17307 L
.28605 .16173 L
Mistroke
.28895 .15155 L
.29161 .14417 L
.29407 .13876 L
.29668 .13434 L
.29818 .13235 L
.29954 .13085 L
.30074 .12974 L
.30205 .12876 L
.30343 .12795 L
.30473 .12741 L
.3059 .12708 L
.30719 .1269 L
.30854 .12692 L
.3098 .12712 L
.31098 .12746 L
.31205 .12791 L
.31329 .12859 L
.31447 .1294 L
.31711 .13182 L
.31993 .13533 L
.32233 .13916 L
.32497 .14438 L
.32781 .15128 L
.33087 .16048 L
.3364 .18253 L
.34638 .24194 L
.35704 .32147 L
.36019 .34172 L
.36317 .35696 L
.36447 .3622 L
.36584 .36676 L
.36656 .36874 L
.36735 .37059 L
.36874 .37306 L
.36946 .37396 L
.37015 .37459 L
.37145 .37517 L
.37217 .37519 L
.37284 .37504 L
.37358 .37468 L
.37436 .37411 L
.37504 .37346 L
.37578 .37263 L
.37712 .37082 L
.37961 .36667 L
.39017 .34486 L
.39549 .33062 L
.40131 .30914 L
.41155 .25775 L
.42124 .20912 L
Mistroke
.4264 .18872 L
.42911 .17991 L
.43199 .17203 L
.43441 .16651 L
.43708 .1615 L
.43949 .15786 L
.44178 .1551 L
.44314 .15375 L
.44463 .15252 L
.446 .15158 L
.44725 .1509 L
.44872 .15026 L
.44953 .14999 L
.4503 .14979 L
.45166 .14953 L
.45242 .14944 L
.45313 .14939 L
.4544 .14938 L
.45559 .14946 L
.4569 .14963 L
.45763 .14976 L
.4583 .14989 L
.4611 .15066 L
.46376 .1516 L
.47389 .15616 L
.47656 .15731 L
.47944 .1584 L
.48198 .1592 L
.48466 .15986 L
.48576 .16008 L
.48694 .16026 L
.48824 .16042 L
.48945 .16053 L
.49063 .16058 L
.49175 .1606 L
.49276 .16058 L
.49385 .16053 L
.49507 .16043 L
.49641 .16028 L
.49913 .15984 L
.50399 .15888 L
.50661 .15842 L
.50733 .15832 L
.50809 .15823 L
.50946 .15811 L
.51014 .15809 L
.51087 .15808 L
.51219 .15814 L
.51348 .1583 L
.51466 .15855 L
Mistroke
.51583 .15891 L
.51692 .15936 L
.51812 .16001 L
.5194 .1609 L
.52075 .16208 L
.52202 .16347 L
.5244 .16688 L
.52705 .17214 L
.52987 .17975 L
.53227 .18816 L
.53492 .19974 L
.54081 .23507 L
.54634 .2788 L
.5517 .3227 L
.55431 .34014 L
.55545 .34621 L
.55668 .35151 L
.55798 .35548 L
.5592 .35761 L
.55988 .35809 L
.56059 .35804 L
.56188 .35651 L
.56256 .35499 L
.56328 .35281 L
.56459 .34751 L
.56614 .33912 L
.56756 .32973 L
.57698 .24833 L
.58215 .20733 L
.587 .17759 L
.59194 .15583 L
.59456 .14723 L
.59739 .13987 L
.59983 .13488 L
.6024 .13074 L
.6046 .12795 L
.60701 .12554 L
.60847 .12437 L
.60986 .12344 L
.61112 .12275 L
.61246 .12217 L
.61315 .12192 L
.61391 .1217 L
.61525 .12142 L
.61601 .12132 L
.61682 .12127 L
.61759 .12126 L
.61829 .1213 L
.61962 .12146 L
.62086 .12173 L
Mistroke
.62222 .12215 L
.62367 .12274 L
.62636 .12424 L
.62879 .12609 L
.63123 .12848 L
.63391 .1318 L
.63652 .13583 L
.63932 .14114 L
.64433 .15344 L
.64901 .16845 L
.66036 .21744 L
.66536 .23977 L
.6682 .25043 L
.66959 .25478 L
.67087 .25815 L
.67206 .26072 L
.67336 .26284 L
.67467 .26421 L
.67605 .26479 L
.67743 .26449 L
.6782 .26393 L
.6789 .2632 L
.68027 .26113 L
.68156 .25847 L
.68446 .25023 L
.68713 .24046 L
.69318 .21467 L
.69848 .19255 L
.70344 .17514 L
.70862 .16138 L
.71136 .15597 L
.71431 .15153 L
.71698 .14864 L
.71848 .14746 L
.71983 .14662 L
.7211 .14604 L
.72247 .1456 L
.72376 .14537 L
.72495 .1453 L
.72562 .14532 L
.72634 .14538 L
.72764 .14562 L
.72844 .14583 L
.72919 .14608 L
.73059 .14667 L
.73345 .14831 L
.73655 .15071 L
.75766 .1738 L
.77806 .18623 L
.78092 .18721 L
Mistroke
.78364 .18836 L
.78515 .18918 L
.78679 .1903 L
.78829 .1916 L
.78966 .19305 L
.79239 .19693 L
.79389 .19972 L
.7953 .20285 L
.79782 .20977 L
.80054 .21945 L
.80552 .24392 L
.81099 .28112 L
.81632 .32322 L
.81926 .34472 L
.8207 .35381 L
.82204 .36097 L
.82328 .36633 L
.8246 .37049 L
.82593 .37293 L
.82668 .3735 L
.82739 .37348 L
.82862 .37219 L
.82974 .36962 L
.83097 .36532 L
.83227 .35922 L
.83464 .34455 L
.83684 .32768 L
.84183 .28382 L
.84713 .23898 L
.85287 .20031 L
.8555 .18652 L
.85829 .17435 L
.8607 .16563 L
.86329 .15788 L
.8658 .15175 L
.86809 .14713 L
.87258 .1402 L
.87509 .13725 L
.87782 .13459 L
.8828 .13091 L
.88549 .12943 L
.88839 .12817 L
.89113 .12725 L
.89365 .12659 L
.89593 .12615 L
.89723 .12596 L
.89843 .12583 L
.89971 .12574 L
.90087 .1257 L
.90221 .12573 L
Mistroke
.90348 .12582 L
.90475 .12598 L
.90547 .12611 L
.90614 .12625 L
.9075 .1266 L
.90897 .1271 L
.91161 .12834 L
.91404 .1299 L
.91671 .13218 L
.91963 .13549 L
.92268 .14008 L
.92551 .14562 L
.93082 .16001 L
.93382 .1708 L
.93657 .1826 L
.94701 .24123 L
.95192 .27016 L
.95431 .28197 L
.9565 .29046 L
.95768 .29392 L
.95881 .29639 L
.95999 .29808 L
.96128 .29883 L
.9626 .29838 L
.96334 .2976 L
.96401 .29657 L
.96531 .29372 L
.96654 .29007 L
.96863 .28187 L
.97059 .2724 L
.97503 .24677 L
.98398 .19452 L
.98796 .17614 L
.99172 .16237 L
.9938 .15622 L
.99606 .15064 L
1 .14335 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo027ooooo0ol0002<ooooo`00]Oooool00ol0003oooooooooo`0O
ooooo`?o000000Coooooo`000?l0003o0000R_ooool007Kooooo1?l0000kooooo`03o`000?oooooo
oooo01kooooo0_l00006ooooo`03o`000?oooooooooo053ooooo1ol0000`ooooo`00MOooool2o`00
00;ooooo0_l0000jooooo`;o00007_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
04gooooo0ol00006ooooo`;o0000;_ooool007Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`1;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0:oooool001Sooooo
0ol0001Iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0BOooool2o`0000cooooo
00?o0000ooooooooool0:oooool001Kooooo0_l00003ooooo`03o`000?oooooooooo05Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool0:_ooool001Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0`
ooooo`_o00006Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04Oooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo017ooooo000Moooo
o`03o`000?oooooooooo02Sooooo1ol0000:ooooo`;o00006?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo03Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo01Oooooo1?l0000[ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0Aooooo`007_ooool00ol0003oooooooooo`0Uooooo`;o
00004oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool09Oooool4o`0000cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Booooo`00
7_ooool00ol0003oooooooooo`0Tooooo`;o00005?ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool08_ooool3o`0000;ooooo1?l00009ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool04_ooool001oooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Qooooo`;o00002?ooool2o`0000Oooooo0_l0000Kooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo01?ooooo000Oooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`08ooooo`?o00001Oooool6o`0001Oooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool0
01oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
00cooooo1_l00005ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05?ooool001Go
oooo0_l000002_l@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^k_l0000Iooooo`05oiRH
V?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko0000o`000?lb<S;ok^k^01Kooooo00?o0000oooo
ooooool00_ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h:ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo1?l000002_l@413oooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^ooooool0000Booooo`03o`000?oooooooooo00?ooooo1Ol00002ooooo`06o`00
0?o^k^ko<S8bo`000?lb<S;ok^k^6oooool01OnHV9So410@o`000?l0003oc<c<00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`03o`000?oooooooooo00kooooo0ol00003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03_ooool001Kooooo00?o0000ooooooooool00_ooool01_mgMgOoV9RHoooo
oonHV9SoMgMgo`0001Wooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMol0003ooooo
oiRHV?mgMgL05_ooool00ol0003oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`09ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01omgMgOoV9RHoooooonHV9SoMgMg
ooooool000004_ooool00ol0003oooooooooo`03ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01Ol0003oV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_oooooo0000oc8b<P03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03Oooool00ol0003oooooooooo`0>ooooo`;o00000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko00000_ooool5o`0000?ooooo00Oo410@oooo
oooooooooooooa0@4?oooooo0000013ooooo1_l00006ooooo`05o`000?ooooooooooooooool00000
0oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04ooooo`07oa0@
4?ooooooooooooooool@413oooooo`00000?ooooo`03o`000?oooooo000000Go00001Oooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002Oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00;ooooo00Oo410@oooooooooooooooooa0@4?oooooo0000017ooooo
00?o0000ooooooooool01Oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?l0003oooooooooool@
41007Oooool00ol0003oooooo`000003ooooo`05oa0@4?ooooooooooooooool@41003Oooool00ol0
003oooooooooo`0;ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00kooooo000Coooo
o`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oo
oooooooo01Sooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000001Oooooo
00?o0000ooooooooool00oooool00onHV9So8B4Qonk^kP03ooooo`07o`000?ooooooooooooooool0
003oooooo`00000?ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000Sooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02
ooooo`07o`000?ooooooooooooooool0003oooooo`00000Aooooo`03o`000?oooooooooo00Kooooo
00?oV9RHob4Q8Oo^k^h00oooool00ol0003oooooo`000002o`0001gooooo00?o0000ojVYZOl@4100
0oooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool02oooool01?m4A4Co
gMgMooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool001?ooooo00CogMgMoeEE
EOoooooo00001?ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool05ooo
ool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000005oooool00ol0003ooooo
ooooo`04ooooo`03ogMgMomVIVKooooo00;ooooo00Oo0000ooooooooooooooooo`000?oooooo0000
00oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000002?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01ooo
ool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool2o`000005okZj
^_ooooooooooooooool000000oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_o
oooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000kooooo000Doooo
o`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@4003ooooo`03o`000?oooooo
oooo01Oooooo00Ko^[Zjob4Q8Oooooooooooo`000?l@4103ooooo`03oa0@4?oooooooooo01Kooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooool0
00004?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooo
oooooooooa0@4007ooooo`03o`000?oooooooooo01Cooooo0_l00007ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41000_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Sooooo00Go0000
oooooooooooooooooa0@4003ooooo`03oa0@4?l0003o000001_ooooo00?o0000okZj^_lQ8B400ooo
ool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool02oooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41003_ooool001Cooooo00?ok^k^odA4A?l00000
1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?o0000ooooooooool05?ooool01Ol@413o
V9RHoooooonj^[[o000000;ooooo00Ko0000ogMgMonHV9SooooooiRHV?mgMgLHooooo`08o`000?oo
ooooooooo`000?nj^[[ooooooiRHV?l@4103ooooo`06ogMgMonHV9SooooooiRHV?mgMgOo00004Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`07ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`05
o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo00?o0000
ooooooooool05_ooool01Ol@413o0000oooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0>ooooo`03o`000?oooooooooo00_ooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00kooooo000Eooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP04ooooo`03o`000?oooooooooo01?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@02oooo
o`06o`000?o^k^ko<S8bo`000?lb<S;ok^k^6?ooool02?l0003ooooooooooonHV9So410@o`000?lQ
8B7oc<c<0oooool01_o^k^ko<S8bo`000?lb<S;ok^k^o`00017ooooo00?o0000ooooooooool01ooo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`04ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`;o00005_ooool01OnYZJWo0000o`000?l@
413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`03o`000?oooooooooo00cooooo
00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Tooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool05oooool2o`0001Gooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Kooooo000Tooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Fooooo`009Oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05_ooool0
02Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
01Kooooo000Uooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Fooooo`005_ooooooo`00043o00004oooool001Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ool000001oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l00006oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`0A
ooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ool000001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo0_l00006
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool00000
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool00000
1Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00007oooo
o`03o`000?oooooo000000Gooooo00?o0000ooooooooool04Oooool002Oooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Oooooo000Wooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Gooooo`009ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05ooo
ool002Sooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo01Sooooo000Xooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Hooooo`00:?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool06?ooool002Wooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo01Oooooo0_l0000;ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool06?ooool002Wooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo01Sooooo000Zooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`00:_ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06Oooool002[ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Wooooo000[ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`00:ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06Ooo
ool002_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01_ooooo00Go0000ooooooooooooooooo`00000Wooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Wooooo000/
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0I
ooooo`;o00003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01_ooooo00Go0000
ooooooooooooooooo`00000Wooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Wooooo000/ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
000002Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool06_ooool002cooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo01gooooo0ol0000Xooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01[ooooo000]ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`18ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01[ooooo000]ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01[ooooo
000]ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`19ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo01[ooooo000^ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01_ooooo000^oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`19oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08Oooool01Ol0003ooooooooooooooooo
000001gooooo000^ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Kooooo`;o00003Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Qooooo`05o`000?oooooooooo
ooooool000007Oooool002oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo04Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Qoooo
o`04o`000?ooooooooooo`0001kooooo000_ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool08Oooool01?l0003oooooooooool0000Nooooo`00;oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooool000007_ooool0033ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04_ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Sooooo`?o00007_ooool0033ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Sooooo`;o00007oooool0033ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo017ooooo1Ol00006ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1;ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0A?ooool0037ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01;ooooo00GoV9RHob4Q8Oo^k^koooooodA4
A006ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0A?ooool0037ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Xooooo`05o`000?ooooooooooooooool000007?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01?ooooo00?oV9RHob4Q8Oo^k^h01ooo
ool3o`0000gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1;ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0A?ooool0037ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Xooooo`05o`000?ooooooooooooooool000007Oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo01Cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Boooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo04Cooooo000aooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0:?ooool01Ol0003ooooooooooooooooo000001gooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Eooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`14ooooo`00<Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo02Sooooo00Go0000ooooooooooooooooo`00000Mooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0AOooool0037ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Y
ooooo`04o`000?ooooooooooo`0001gooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Cooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo04Gooooo000aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooo`00000Nooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04ooo
ool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`15ooooo`00<_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02[ooooo0_l0
000Nooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0COooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo04Gooooo000booooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0:oooool2o`0001kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1=
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0AOooool003;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool07_ooool2o`0000oooooo00Go0000ooooooooooooooooo`00001?ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0AOooool003;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`1<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0>ooooo`05o`000?ooooooooooooooool00000D?ooool01Ol0003ooooooooooooo
oooo000004Sooooo000booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0C?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool03_ooool0
1Ol0003ooooooooooooooooo0000053ooooo00Go0000ooooooooooooooooo`000018ooooo`00<_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00kooooo00Go0000oooooooooooooooo
o`00001@ooooo`05o`000?ooooooooooooooool00000B?ooool003;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo0000057ooooo00Go0000oooooooooooo
ooooo`000018ooooo`00<oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04gooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00oooooo
00?o0000ooooool00000DOooool01Ol0003ooooooooooooooooo000004Sooooo000cooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool03oooool00ol0003oooooo`00001Aooooo`05o`00
0?ooooooooooooooool00000B?ooool003?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`1>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooo0000057ooooo00Go0000ooooooooooooooooo`000018ooooo`00
<oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
D?ooool01Ol0003ooooooooooooooooo000004Sooooo000dooooo`05o`000?ooooooooooooooool0
0000DOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02;ooooo0_l0001Tooooo`05
o`000?ooooooooooooooool00000B?ooool003Cooooo00Go0000ooooooooooooooooo`00001Aoooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Toooo
o`03o`000?oooooo000004Wooooo000dooooo`05o`000?ooooooooooooooool00000DOooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0I?ooool00ol0
003oooooo`000019ooooo`00=?ooool01?l0003oooooooooool0001Cooooo`04o`000?oooooo0000
o`0002Kooooo00?o0000ooooooooool0I?ooool3o`0004Wooooo000eooooo`03o`000?oooooo0000
05?ooooo0ol0000Wooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0B?ooool003Go
oooo0ol0001mooooo`03o`000?oooooooooo0;3ooooo000fooooo`03o`000?oooooooooo07cooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002a
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00[?ooool2
o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0/?ooool00:gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool5o`0000Kooooo00?o0000oooooooo
ool0/?ooool00:[ooooo00CoA4A4omgMgOoooooo00001oooool3o`000;3ooooo002Zooooo`04omgM
gOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0/?ooool00:_ooooo00?oMgMgolc<c?l00000
1oooool00ol0003oooooooooo`2`ooooo`00Zoooool00oo^k^koA4A4o`000007ooooo`03o`000?oo
oooooooo0;3ooooo002/ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo00Gok^k^oc8b
<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06
ooooo`?o0000/?ooool00:[ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooo
oooo0;3ooooo002Zooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0/?ooool00:[o
oooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`2`ooooo`00Zoooool01?o<c<coA4A4
o`000?l@4106ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002Zooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003o
ooooooooo`2`ooooo`00Z_ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000oooooooo
ool0/?ooool00:[ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;3o
oooo002Zooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`000;3ooooo002Zooooo`05olc<
c?l0003o0000o`000?o<c<`0^Oooool00:[ooooo00Go410@okZj^_oooooo^[Zjoa0@402iooooo`00
Z_ooool01Ol0003o^[Zjoooooonj^[[o00000;Wooooo002Zooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT0^Oooool00?ooooooJOooool00;?ooooo00?o0000okZj^_ooool0/_ooool00;?ooooo0_lb<S:c
ooooo`00Q?ooool2o`000006oa0@4?oooooooooooa0@4?l0003o410@6?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`03ohN7Qol0003o^[Zj00co
oooo00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool0
1Oo<c<co8B4Qo`000?lQ8B7oc<c<07cooooo0025ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01oooool6o`0000gooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mg
MgL00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`00
00Wooooo00GoEEEEogMgMoooooooV9RHob4Q8@03ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40O?oo
ool008Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooo
oooooa0@40?ooooo00?o410@ooooooooool04?ooool00ol0003oooooooooo`0Jooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000007cooooo0025ooooo`06o`00
0?ooooooA4A4odA4A?oooooo00002Oooool6o`0000gooooo00GoMgMgoc8b<_ooooooooooo`000003
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02oooool6o`0000Wooooo00Go0000
oiRHV?ooooooV9RHob4Q8@03ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80O?ooool008Gooooo00Ko
0000omgMgOlb<S;oEEEEomgMgOl0000Iooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0
003ooooooooooooooooo000001;ooooo00?o0000ooooooooool06_ooool01Ol0003oEEEEo`000?l@
413oc<c<00?ooooo00Goc<c<o`000?l0003o0000olc<c01looooo`00QOooool01_l0003oQhN7ojVY
ZOnj^[[oEEEEo`0001Wooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@
013ooooo00?o410@o`000?l000000ol0000Iooooo`03oeEEEOn7QhOooooo00Gooooo00Go410@okZj
^_oooooo^[Zjoa0@401looooo`00QOooool01_l0003o<S8boooooooooooo<S8bo`0001Wooooo00?o
0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool0
6_ooool00ooMgMgo410@oiRHV005ooooo`05o`000?nj^[[ooooookZj^_l00000O?ooool008Cooooo
00?o410@o`000?n7QhL00_ooool00on7QhOo0000oa0@400Hooooo`Co00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01;ooooo00?o0000ooooooooool06oooool01?o<c<coA4A4o`000?l@4103oooo
o`05ojVYZOl@413o0000oa0@4?nYZJT0O?ooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(70) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .16383 m
.00942 .17705 L
.01483 .18521 L
.01975 .19163 L
.02225 .19426 L
.02496 .19647 L
.02644 .19737 L
.02782 .19798 L
.02913 .19837 L
.0298 .19848 L
.03053 .19856 L
.03183 .19853 L
.03302 .19834 L
.0344 .19793 L
.03571 .19735 L
.03803 .19593 L
.04057 .19389 L
.05167 .18162 L
.0546 .17828 L
.05777 .17504 L
.0605 .17273 L
.06206 .17168 L
.06351 .17089 L
.06487 .17033 L
.06564 .1701 L
.06634 .16994 L
.06707 .16983 L
.06787 .16978 L
.06863 .1698 L
.06933 .16988 L
.07056 .17018 L
.07192 .17076 L
.07261 .17117 L
.07335 .17169 L
.07468 .17288 L
.07591 .17429 L
.07725 .1762 L
.07996 .18139 L
.08247 .18805 L
.08481 .19607 L
.08719 .2063 L
.08975 .21989 L
.09436 .25209 L
.09918 .29611 L
.10448 .35069 L
.10746 .37836 L
.10892 .38971 L
.11028 .39836 L
.11151 .40437 L
.11281 .40868 L
Mistroke
.11356 .41012 L
.11426 .41077 L
.11558 .41013 L
.11682 .40732 L
.11814 .4021 L
.11926 .39595 L
.12049 .38758 L
.12581 .33795 L
.13141 .27903 L
.13741 .22692 L
.14031 .20745 L
.14307 .19222 L
.14822 .17069 L
.15078 .16277 L
.15349 .15593 L
.15836 .14665 L
.1636 .13931 L
.16938 .13328 L
.17456 .12939 L
.18 .12641 L
.18225 .12542 L
.18465 .12453 L
.18603 .12411 L
.18729 .12381 L
.18855 .12358 L
.18973 .12345 L
.191 .1234 L
.19172 .12342 L
.1924 .12346 L
.19375 .12364 L
.19452 .1238 L
.19521 .12397 L
.19645 .12437 L
.1978 .12493 L
.20026 .12632 L
.20162 .12732 L
.20312 .12866 L
.20617 .13224 L
.20899 .13689 L
.21165 .14269 L
.21657 .15794 L
.21936 .16961 L
.22195 .1827 L
.23281 .25999 L
.23764 .29783 L
.24001 .31327 L
.2422 .32418 L
.24342 .32856 L
.24472 .3317 L
.24602 .33322 L
Mistroke
.24676 .33333 L
.24746 .33294 L
.24866 .33115 L
.24976 .32831 L
.25103 .32368 L
.25223 .31805 L
.26308 .23923 L
.26839 .2022 L
.27073 .18892 L
.27328 .1766 L
.27774 .16043 L
.28018 .15415 L
.28245 .14973 L
.28373 .1478 L
.28495 .14632 L
.28604 .14527 L
.28723 .14441 L
.28852 .14379 L
.2899 .14346 L
.29107 .14345 L
.29236 .1437 L
.29366 .14421 L
.29504 .14501 L
.29621 .14591 L
.29749 .14709 L
.30036 .1505 L
.30302 .15455 L
.30786 .16395 L
.31303 .17642 L
.3186 .19141 L
.32449 .2068 L
.32953 .21754 L
.3309 .21985 L
.33238 .22196 L
.33377 .22356 L
.33506 .22469 L
.33644 .22551 L
.33717 .22578 L
.33794 .22595 L
.33869 .22598 L
.33938 .22591 L
.34068 .2255 L
.34197 .22477 L
.34315 .22382 L
.34582 .22088 L
.3515 .21208 L
.35749 .20199 L
.36001 .19831 L
.3614 .19659 L
.36271 .19522 L
Mistroke
.36394 .1942 L
.36526 .19343 L
.36647 .19307 L
.36759 .19306 L
.3689 .19349 L
.37014 .19435 L
.3715 .19588 L
.37226 .19701 L
.37296 .19823 L
.37435 .20123 L
.37587 .2054 L
.37865 .21564 L
.38133 .22913 L
.38422 .24826 L
.38948 .29564 L
.39416 .34824 L
.3993 .40348 L
.40069 .41521 L
.40218 .42531 L
.4029 .42916 L
.40359 .43211 L
.40487 .43576 L
.40558 .43668 L
.40634 .43678 L
.40769 .43471 L
.40845 .43233 L
.40915 .42934 L
.41076 .41991 L
.41205 .41005 L
.41341 .39781 L
.41584 .37252 L
.42132 .31072 L
.42647 .26101 L
.43133 .22701 L
.43402 .21306 L
.43694 .2011 L
.43959 .1926 L
.44203 .18643 L
.44649 .17829 L
.44903 .17485 L
.4514 .17204 L
.46132 .16188 L
.48081 .14361 L
.49111 .13542 L
.49407 .13339 L
.49686 .13169 L
.49936 .13044 L
.50077 .12989 L
.50207 .1295 L
.50345 .12921 L
Mistroke
.50474 .12907 L
.50549 .12904 L
.50616 .12905 L
.50694 .1291 L
.50768 .12919 L
.50839 .12932 L
.50915 .1295 L
.51052 .12993 L
.51198 .13059 L
.5136 .13156 L
.51499 .13265 L
.51626 .13389 L
.51762 .13553 L
.51912 .13772 L
.52164 .14256 L
.52429 .14947 L
.52707 .15898 L
.52958 .16994 L
.53523 .20398 L
.54046 .24844 L
.5454 .29817 L
.54775 .32137 L
.55027 .34321 L
.55172 .35345 L
.55304 .36093 L
.55436 .36638 L
.55562 .36949 L
.55693 .37047 L
.55831 .369 L
.5595 .36573 L
.5608 .36009 L
.5622 .35188 L
.56371 .34085 L
.56644 .31655 L
.57129 .26743 L
.57648 .21892 L
.58137 .18385 L
.58583 .16138 L
.5883 .15223 L
.59098 .14457 L
.59352 .13923 L
.59585 .1357 L
.59716 .13426 L
.59839 .13321 L
.59974 .13238 L
.60049 .13205 L
.60119 .13182 L
.60257 .1316 L
.60335 .1316 L
.60408 .13167 L
Mistroke
.60541 .13199 L
.60616 .13227 L
.60684 .13258 L
.60822 .13341 L
.60969 .13455 L
.61231 .13727 L
.61514 .14121 L
.61824 .14679 L
.62379 .16015 L
.62898 .17633 L
.63996 .21856 L
.64257 .22849 L
.64536 .23795 L
.64793 .24518 L
.6492 .24805 L
.65035 .25024 L
.65137 .2518 L
.65249 .25309 L
.65361 .25395 L
.65479 .25436 L
.65602 .25426 L
.65733 .25357 L
.65856 .25238 L
.65969 .25086 L
.66219 .24615 L
.66491 .23929 L
.66984 .22387 L
.67504 .20653 L
.68063 .19005 L
.68333 .18348 L
.6859 .1782 L
.68823 .17421 L
.69072 .17078 L
.69209 .16923 L
.69333 .16805 L
.69459 .16704 L
.69575 .16628 L
.69711 .16559 L
.69782 .16531 L
.69858 .16507 L
.69985 .1648 L
.70057 .16472 L
.70124 .16468 L
.70196 .16469 L
.70274 .16474 L
.70348 .16483 L
.70416 .16495 L
.70546 .16525 L
.70683 .16568 L
.70968 .16686 L
Mistroke
.71281 .16848 L
.7178 .17146 L
.72325 .17474 L
.72574 .17602 L
.7271 .17661 L
.72839 .1771 L
.7296 .17748 L
.7309 .1778 L
.73208 .17802 L
.73317 .17816 L
.73454 .17824 L
.73582 .17824 L
.73656 .17819 L
.73723 .17813 L
.738 .17803 L
.73873 .17791 L
.7402 .17759 L
.74155 .1772 L
.74461 .17596 L
.74703 .17465 L
.74969 .17288 L
.75509 .16855 L
.76497 .15991 L
.77036 .15539 L
.77538 .1518 L
.77802 .15038 L
.77949 .14977 L
.78083 .14934 L
.7816 .14915 L
.78231 .14902 L
.78308 .14891 L
.7839 .14884 L
.78528 .14884 L
.78607 .14892 L
.7868 .14904 L
.78815 .1494 L
.78944 .14994 L
.79059 .15059 L
.79185 .15153 L
.79321 .15285 L
.79466 .15464 L
.79728 .15907 L
.79858 .16196 L
.80002 .1657 L
.80291 .17531 L
.80559 .18703 L
.80809 .20077 L
.81373 .24334 L
.81978 .30527 L
.82251 .33494 L
Mistroke
.82547 .36397 L
.82683 .37502 L
.82828 .3846 L
.82951 .39073 L
.83087 .39506 L
.83217 .39667 L
.83337 .39588 L
.83469 .39252 L
.83608 .38631 L
.83729 .37881 L
.83841 .37029 L
.84097 .34654 L
.84628 .28745 L
.85203 .22793 L
.85467 .20581 L
.85746 .1863 L
.85988 .1724 L
.86247 .16016 L
.86498 .15061 L
.86727 .1436 L
.86961 .13792 L
.87177 .13375 L
.87428 .12999 L
.87702 .12692 L
.87943 .12491 L
.88199 .12337 L
.88331 .12279 L
.88474 .12232 L
.88547 .12215 L
.88625 .12201 L
.88698 .12193 L
.88764 .12189 L
.88892 .12192 L
.89031 .1221 L
.89162 .12241 L
.89283 .12282 L
.89423 .12342 L
.89554 .12413 L
.89852 .12627 L
.90142 .12911 L
.90454 .13321 L
.90725 .13785 L
.91021 .14424 L
.91561 .16007 L
.92086 .18127 L
.92574 .20614 L
.93107 .2372 L
.93387 .25353 L
.93683 .2692 L
.93943 .28046 L
Mistroke
.9409 .28547 L
.94227 .28907 L
.94354 .2914 L
.94469 .29266 L
.94602 .29308 L
.94728 .29243 L
.9484 .29102 L
.94964 .2886 L
.95093 .28515 L
.95214 .28114 L
.95664 .26114 L
.96682 .20734 L
.97119 .18863 L
.97525 .1753 L
.9773 .17008 L
.97949 .16556 L
.98074 .16346 L
.98192 .16178 L
.98297 .16052 L
.98413 .15938 L
.98506 .15865 L
.98605 .15804 L
.9871 .15757 L
.98809 .1573 L
.98907 .15718 L
.99 .1572 L
.99083 .15731 L
.99174 .15754 L
.99283 .15795 L
.99382 .15845 L
.99603 .15995 L
.99807 .16177 L
1 .16383 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo001@ooooo`Go0000H?ooool00ol0003oooooooooo`1f
ooooo`Ko0000=?ooool004kooooo0ol00004ooooo`;o0000G_ooool00ol0003oooooooooo`1eoooo
o`;o00001Oooool00ol0003oooooooooo`0aooooo`00COooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo05cooooo1Ol0001booooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0<?ooool004cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Iooooo`?o0000
0oooool2o`0001Wooooo1?l0001Cooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
;oooool004_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Fooooo`;o00000_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_oo
ool2o`00057ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0_ooooo`00B_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0;_ooool0
04Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
03[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0;_ooool004Sooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0Dooooo`Go0000>Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04co
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0^ooooo`00B?ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo01?ooooo00Go0000ooooooooooooooooo`00000hooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0<?ooool4o`0001Oooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0^ooooo`00Aoooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0;_ooool2o`0000?ooooo0_l0000Fooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0;Oooool004Oooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`07ooooo`;o00001_ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0]ooooo`00Aoooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0Dooooo`Co00005Oooool004Kooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo02Wooooo0_l0000:ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Booooo`;o00000oooool00ol0
003oooooooooo`0Booooo`005Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb
<S;ok^k^01[ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_l0
00005?ooool00ol0003oooooooooo`04ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o0000
00Wooooo00?o0000ooooooooool04?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b
<_o^k^hAooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00Cooooo1?l000002?l@413o0000ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^4Oooool4o`0000Gooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02_oo
ool00ol0003oooooooooo`0>ooooo`05oiRHV?l@413o0000o`000?o<c<`00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Oooooo00?o0000ooooooooool04_ooool3o`000009oa0@4?ooooooooooo`00
0?o^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Fooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0Jooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RH
oooooonHV9So000001Gooooo00?o0000ooooooooool00oooool01OnHV9So8B4Qonk^k_ooooooA4A4
00?ooooo00GoMgMgoiRHV?ooooooV9RHo`000009ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg013ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01_oo
ool02_l0003ooooooooooooooooo0000ogMgMonHV9SooooooiRHV?mgMgL?ooooo`;o00001?ooool2
o`0000?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMol0003ooooooiRHV?mgMgL0
2_ooool00ol0003oooooooooo`0>ooooo`05oa0@4?nj^[[oooooo`000?lb<S800oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool04Oooool00ol0003oooooo`000004oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool000_ooooo1_l00002ooooo`Go00000oooool01Ol@
413ooooooooooooooooo410@00Wooooo1Ol00004ooooo`Ko00001_ooool01Ol0003ooooooooooooo
oooo410@00;ooooo00?o0000oa0@4?ooool04_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h01?oo
ool01Ol@413oooooooooool0003o410@00Wooooo00?o0000ooooooooool01oooool6o`0000Gooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool01_ooool01_l0003ooooooooooooooooo0000oa0@40?ooooo00?o410@ooooooooool03Oooool0
0ol0003oooooooooo`05ooooo`;o00000_ooool00onHV9So8B4Qonk^kP04ooooo`05o`000?oooooo
ooooooooool@41002_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo000000?ooooo00Go
410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo013ooooo1Ol00003ooooo`05oa0@
4?ooooooooooooooool@41003_ooool001?ooooo00KoA4A4omgMgOoooooo0000ooooool00002oooo
o`05o`000?ooooooooooooooool000002?ooool2o`0000?ooooo0_l0000>ooooo`03ojVYZOl@413o
oooo00;ooooo00?o0000ooooooooool00_l0000Eooooo`03o`000?oooooooooo00Gooooo00?oV9RH
ob4Q8Oo^k^h00oooool00ol0003oooooooooo`02o`0000[ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`07ooooo`04o`000?ooooooooooooooo`;o00000oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00Sooooo00Ko0000ooooooooooooV9RHob4Q8Oo^k^h2ooooo`;o00000oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00oooooo00?o0000ojVYZOl@41000oooool01Ol0
003ooooooooooooooooo000000Sooooo00?o0000ooooooooool04?ooool01?l0003ogMgMooooool0
0004ooooo`05o`000?ooooooooooooooool000003_ooool001?ooooo00CogMgMoeEEEOoooooo0000
0_ooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0;ooooo`03oa0@4?l0003o^[Zj00?ooooo00?o0000ooooooooool0
0_l0000Eooooo`03o`000?oooooooooo00Kooooo00?oMgMgofIVI_ooool00_ooool00ol0003ooooo
ooooo`02o`0000[ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000003_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo00[ooooo1ol000000ooo
oooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03oooool2o`00
0005okZj^_ooooooooooooooool000000oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00kooooo00Go0000omgMgOmEEEGoooooo`000004ooooo`05o`000?ooooooooooooooool00000
3_ooool001Cooooo00?oMgMgolc<c?l000000_ooool00ol0003ooooooa0@4003ooooo`03oa0@4?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03okZj^_lQ
8B7ooooo00;ooooo00Go410@ooooool0003ooooooa0@400Eooooo`03o`000?oooooooooo00Oooooo
00Go0000oooooooooooooooooa0@4002ooooo`03o`000?l@413ooooo00Wooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41003Oooool00ol0
003oooooooooo`0>ooooo`;o00001oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo410@00gooooo00?o0000
ooooooooool03_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool02Ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?nj^[[o8B4Q00?ooooo00Go410@oooooooooooooooo
oa0@4009ooooo`03o`000?oooooooooo00kooooo00Go0000oooooomgMgOoc<c<o`000004ooooo`05
oa0@4?ooooooooooooooool@41003_ooool001Cooooo00?ok^k^odA4A?l000000oooool01_l0003o
MgMgoiRHV?ooooooV9RHogMgM`Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08
ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHo`000?nHV9SoMgMg01Gooooo
00?o0000ooooooooool00oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oo
oooo0000ogMgM`0;ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02
ooooo`05o`000?nHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0;ooooo`05o`000?nj
^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooooooo
ool03?ooool01Ol@413oV9RHo`000?nj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`09
ooooo`03o`000?oooooooooo00kooooo00Go0000ooooooo^k^koA4A4o`000004ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03_ooool001Gooooo00?oMgMgo`000?ooool00_ooool01_l0003ok^k^oc8b
<_l0003o<S8bonk^kPGooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`05
ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Gooooo00?o0000
ooooooooool00oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`03o`000?oooooooooo00kooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool00omEEEGoIVIVo`000004ooooo`05
onk^k_l0003o0000oc8b<_o^k^h03?ooool00ol0003oooooooooo`0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?o0000ooooooooool03?oo
ool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP09ooooo`03
o`000?oooooooooo00gooooo00Ko0000ooooooooooooooooogMgMol00004ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03_ooool001_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0J
ooooo`007?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`;o00005_ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Joooo
o`007Oooool2o`0000?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00_ooooo0_l000000ooooooo0000ooooo`0Dooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01[o
oooo000Nooooo`Co00003oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Wooooo
00Go0000ooooooooooooooooo`00000Dooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01[ooooo000aooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool06oooool001Koooooool00010o`0001?ooooo000F
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
o`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
o`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05oooo
o`;o00001_ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo017ooooo000F
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
o`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`0000Kooooo
0_l00006ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooo`000007ooooo`03o`000?oooooooooo017ooooo000booooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool06oooool003;ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Looooo`00<_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Booooo`;o00000oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07?ooool003;ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool04oooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool07?ooool003;ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05?ooool2o`0000cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Looooo`00<oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07Oooool003?ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01?ooooo0_l0000:
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07Oooool003?ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01gooooo000cooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Mooooo`00
<oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
7Oooool003Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01kooooo000dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Eooooo`;o00000oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo01kooooo000dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Fooooo`04o`000?oooooo0000o`00033ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07_ooool0
03Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
01Oooooo0_l0000aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo01kooooo000dooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Eooooo`;o00002oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07oooool003Cooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04_ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool07oooool003Cooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool07oooool003Cooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04_ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool07oooool003Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo04_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool07oooool003Cooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04_ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool08?ooool003Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo04_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Kooooo`05o`00
0?ooooooooooooooool000008_ooool003Gooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Kooooo`05o`000?ooooooooooooooool000008_ooool003Gooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Gooooo0_l0000<ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo01_ooooo00Go0000ooooooooooooooooo`00000Rooooo`00=Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0C?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo00008oooool003Gooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04cooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo000002?ooooo
000eooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07?ooool2o`0002Cooooo000e
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1=
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0@_ooool003Gooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`12ooooo`00=Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02oooool5o`0000Kooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`12ooooo`00=Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02oooool01OnHV9So8B4Qonk^k_ooooooA4A400Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`13ooooo`00=Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo023ooooo00Go0000ooooooooooooooooo`00000[ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool00onHV9So8B4Qonk^kP07ooooo`?o
00002oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`13ooooo`00=_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo023ooooo00Go0000ooooooooooooooooo`00000[ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool03Oooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0@oooool003Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Pooooo`05o`000?ooooooooooooooool00000:oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo04?ooooo000fooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
8?ooool01Ol0003ooooooooooooooooo000002_ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`13ooooo`00=_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo027ooooo
00Co0000oooooooooooo0000:oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0@oooool003Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Rooooo`04
o`000?ooooooooooo`0002cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo04?ooooo000fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08_ooool00ol0
003oooooo`00000]ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Coooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo04?ooooo000fooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool08oooool2o`0002gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`1@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0@oooool003Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Gooooo`;o00003_ooool01Ol0003ooooo
oooooooooooo000005;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`14ooooo`00
=_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00gooooo00Go0000oooooooooooo
ooooo`00001Booooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0A?ooool003Oooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool0
0000D_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04Cooooo000gooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool03Oooool01Ol0003ooooooooooooooooo000005;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`14ooooo`00=oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo00gooooo00Go0000ooooooooooooooooo`00001Booooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0A?ooool003Oooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool00000D_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo04Cooooo000gooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0Doooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool03Oooool01Ol0003ooooooooooooooooo000005?ooooo00Go0000oooooooo
ooooooooo`000016ooooo`00=oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05?o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00go
oooo00Go0000ooooooooooooooooo`00001Cooooo`05o`000?ooooooooooooooool00000A_ooool0
03Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo0000
05Cooooo00Go0000ooooooooooooooooo`000016ooooo`00=oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo05?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Hoooo
o`;o00003oooool00ol0003oooooo`00001Dooooo`05o`000?ooooooooooooooool00000A_ooool0
03Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo0000
05Cooooo00Go0000ooooooooooooooooo`000016ooooo`00>?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo05Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Doooool01Ol0003ooooooooooooooooo
000004Kooooo000hooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0E?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`1Cooooo`05o`000?ooooooooooooooool00000A_ooool003Sooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`1Uooooo`05o`000?ooooooooooooooool00000A_ooool0
03Sooooo00Go0000ooooooooooooooooo`00001Gooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`1Uooooo`04o`000?ooooooooooo`0004Oooooo000h
ooooo`05o`000?ooooooooooooooool00000Eoooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool0IOooool01?l0003oooooooooool00017ooooo`00>?oo
ool01Ol0003ooooooooooooooooo000005Oooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo06Gooooo00Co0000oooooooooooo0000Aoooool003Sooooo
00Go0000ooooooooooooooooo`00001Gooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool06Oooool2o`0006Kooooo00Co0000oooooooooooo0000Aoooool003Sooooo00Go0000oooooooo
ooooooooo`00001Gooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`1Vooooo`03o`000?oooooo000004Oooooo000hooooo`05o`000?oooooooooooooo
ool00000F?ooool01Ol0003ooooooooooooooooo000001_ooooo00?o0000ooooooooool0I_ooool2
o`0004Sooooo000iooooo`04o`000?ooooooooooo`0005Sooooo00Go0000ooooooooooooooooo`00
000Kooooo`03o`000?oooooooooo06Kooooo0_l00018ooooo`00>Oooool01?l0003oooooooooool0
001Hooooo`05o`000?ooooooooooooooool000006oooool00ol0003oooooooooo`2`ooooo`00>Ooo
ool00ol0003oooooo`00001Iooooo`05o`000?ooooooooooooooool000004_ooool2o`000003oa0@
4?oooooooooo00Cooooo00?o0000ooooooooool0/?ooool003Wooooo00?o0000ooooool00000FOoo
ool01Ol0003ooooooooooooooooo000001?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`2`ooooo`00>_ooool00ol0003oooooooooo`1Hooooo`05o`000?ooooooooooooooool00000
4?ooool5o`0000Kooooo00?o0000ooooooooool0/?ooool003[ooooo00?o0000ooooooooool0F?oo
ool01Ol0003ooooooooooooooooo0000013ooooo00CoA4A4omgMgOoooooo00001oooool3o`000;3o
oooo002Eooooo`04o`000?ooooooooooo`00017ooooo00CogMgMoeEEEOoooooo00001oooool00ol0
003oooooooooo`2`ooooo`00UOooool01?l0003oooooooooool0000Booooo`03ogMgMoo<c<co0000
00Oooooo00?o0000ooooooooool0/?ooool009Kooooo00?o0000ooooool000004_ooool00oo^k^ko
A4A4o`000007ooooo`03o`000?oooooooooo0;3ooooo002Fooooo`03o`000?oooooo000001?ooooo
00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`2`ooooo`00U_ooool00ol0003oooooo`00
000Looooo`03o`000?oooooooooo0;3ooooo002Fooooo`03o`000?oooooo000001cooooo00?o0000
ooooooooool0/?ooool009Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`2`oooo
o`00Uoooool00ol0003oooooooooo`0Kooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002a
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OmEEEGoMgMgoooo
oonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?nHV9SooooooiRHV?lQ8B40
1_ooool3o`000;3ooooo002Zooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo0;3ooooo002Z
ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0/?ooool00:_ooooo00Coc<c<odA4
A?l0003o410@1_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002a
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00Z_ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000
ooooooooool0/?ooool00:[ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooo
oooo0;3ooooo002Zooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`2`
ooooo`00Z_ooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0002`ooooo`00Z_ooool01Oo<
c<co0000o`000?l0003oc<c<0;Wooooo002Zooooo`05oa0@4?nj^[[ooooookZj^_l@4100^Oooool0
0:[ooooo00Go0000okZj^_oooooo^[Zjo`00002iooooo`00Z_ooool01OnYZJWo410@o`000?l@413o
ZJVY0;Wooooo003oooooofWooooo002cooooo`03o`000?nj^[[ooooo0;;ooooo002cooooo`;o<S8b
/oooool008Cooooo0_l000001_l@413oooooooooool@413o0000oa0@41Sooooo00GoA4A4o`000?l0
003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOo0000okZj^P0<
ooooo`05oiRHV?l0003o0000odA4A?nj^[X06_ooool00ol0003ok^k^ooooo`03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h0O?ooool008Gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`07ooooo`Ko00003Oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`03olc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002oooool0
0omEEEGoZJVYooooo`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0O?ooool008Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooooooooa0@40?ooooo00?o
410@ooooooooool04?ooool00ol0003oooooooooo`0Looooo`03ojVYZOmEEEGooooo00?ooooo00Go
410@oooooooooooooooooa0@401looooo`00QOooool01_l0003oooooodA4A?m4A4Coooooo`0000Wo
oooo1_l0000=ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00_ooooo1_l0000<ooooo`03ob4Q8Ooooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00001looooo`00QOooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001Wooooo00Go
0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003o
ooooooooo`0Mooooo`03oeEEEOo<c<cooooo00;ooooo00Go0000ooooooooooooooooo`00001loooo
o`00QOooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001Wooooo00?o0000ooooooooool01?ooool0
1Ol@413ooooooooooooooooo410@013ooooo00?o410@o`000?l000000ol0000Looooo`03ojVYZOmg
MgOooooo00;ooooo00Go410@oooooooooooooooooa0@401looooo`00QOooool01_l0003o<S8boooo
oooooooo<S8bo`0001Wooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
01;ooooo00?o0000ooooooooool06_ooool01Ol@413ooooooooooooooooo<S8b00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`1looooo`00Q?ooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o
410@01Sooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003ooooooooo
o`0Jooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07cooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(72) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .19653 m
.04057 .16941 L
.06168 .15562 L
.06747 .15181 L
.07065 .14988 L
.07365 .1484 L
.07501 .14786 L
.07646 .1474 L
.07721 .1472 L
.07804 .14701 L
.0788 .14688 L
.0795 .14678 L
.08082 .14667 L
.08155 .14666 L
.08224 .14668 L
.08347 .14682 L
.08481 .14715 L
.08616 .14771 L
.08692 .14814 L
.08763 .14862 L
.08892 .14975 L
.09028 .15135 L
.09264 .15525 L
.09398 .15821 L
.09524 .16153 L
.09804 .17113 L
.1006 .1829 L
.10356 .20083 L
.10636 .22297 L
.11586 .33754 L
.11847 .37316 L
.11984 .39037 L
.12128 .40652 L
.12254 .41849 L
.12393 .42869 L
.12519 .43496 L
.12636 .43802 L
.12768 .43811 L
.12893 .43493 L
.13005 .42944 L
.13126 .42087 L
.13258 .40873 L
.13398 .39319 L
.1365 .36037 L
.14206 .28135 L
.14726 .21981 L
.1517 .18251 L
.1542 .16691 L
.15647 .15539 L
.15896 .14535 L
Mistroke
.16167 .137 L
.16423 .13123 L
.16661 .12736 L
.16796 .12566 L
.16939 .12419 L
.17195 .12221 L
.17338 .1214 L
.17471 .1208 L
.17546 .12054 L
.17617 .12033 L
.17699 .12014 L
.17773 .12002 L
.179 .11993 L
.18034 .12001 L
.18148 .12022 L
.18275 .1206 L
.1841 .1212 L
.18556 .12205 L
.1882 .1241 L
.19057 .12649 L
.19317 .12973 L
.1957 .13363 L
.1984 .13882 L
.20325 .15165 L
.20775 .16844 L
.21336 .19652 L
.21853 .22903 L
.22409 .26771 L
.22704 .28683 L
.22866 .29605 L
.2302 .30357 L
.23153 .30893 L
.23224 .31128 L
.23298 .3134 L
.2343 .31613 L
.23552 .31748 L
.23674 .31767 L
.23788 .31682 L
.23914 .31477 L
.24049 .31132 L
.24181 .30684 L
.24326 .30082 L
.24617 .28589 L
.25137 .25457 L
.25691 .22293 L
.25963 .21009 L
.26214 .20024 L
.26438 .19313 L
.26684 .18703 L
.26932 .18258 L
Mistroke
.27067 .18082 L
.27194 .17956 L
.2733 .17862 L
.27407 .17827 L
.27478 .17805 L
.27608 .17792 L
.27681 .178 L
.27747 .17815 L
.27873 .17865 L
.28008 .1795 L
.28136 .18055 L
.28254 .18171 L
.28808 .18907 L
.29393 .19845 L
.29905 .2064 L
.30156 .20979 L
.30389 .21243 L
.30516 .21362 L
.30657 .21469 L
.30798 .21549 L
.30875 .21582 L
.30948 .21604 L
.31075 .21626 L
.31193 .21627 L
.31321 .21605 L
.31456 .2156 L
.31577 .21502 L
.31687 .21435 L
.31933 .21242 L
.32376 .20774 L
.33382 .19418 L
.33892 .18794 L
.34431 .1829 L
.34892 .17975 L
.35153 .17839 L
.35398 .17742 L
.35533 .17701 L
.3568 .17667 L
.35748 .17655 L
.3582 .17644 L
.35948 .1763 L
.36085 .1762 L
.36212 .17614 L
.36327 .17611 L
.36451 .17608 L
.36597 .17605 L
.36734 .17601 L
.36892 .17595 L
.37037 .17588 L
.37164 .17583 L
Mistroke
.37298 .17578 L
.37368 .17577 L
.37446 .17576 L
.37582 .17578 L
.37712 .17583 L
.37831 .17592 L
.37969 .17605 L
.38099 .17623 L
.38331 .17664 L
.38462 .17694 L
.38584 .17729 L
.38727 .17782 L
.38862 .17847 L
.38984 .17922 L
.39115 .18027 L
.39258 .18176 L
.3941 .18381 L
.39552 .18626 L
.39681 .18901 L
.39945 .19633 L
.40227 .20725 L
.40489 .2208 L
.40737 .23731 L
.41291 .28976 L
.41895 .3677 L
.4214 .39977 L
.42268 .41508 L
.42404 .42935 L
.42523 .43986 L
.42653 .44877 L
.42771 .45423 L
.42881 .45686 L
.4295 .45726 L
.43023 .45662 L
.43157 .45263 L
.43288 .44537 L
.43408 .43594 L
.43681 .40639 L
.4397 .36689 L
.44516 .28846 L
.45034 .22763 L
.45319 .20218 L
.4563 .18023 L
.45913 .16464 L
.46176 .15325 L
.46445 .14417 L
.46698 .13761 L
.46925 .13302 L
.47171 .12909 L
.47439 .12568 L
Mistroke
.47723 .1228 L
.47968 .12078 L
.4823 .11911 L
.48358 .11848 L
.48479 .11799 L
.48596 .1176 L
.48705 .11732 L
.48808 .11711 L
.48917 .11695 L
.49026 .11683 L
.49147 .11676 L
.49278 .11674 L
.49397 .11676 L
.49528 .11685 L
.49666 .11701 L
.49787 .11722 L
.49899 .11749 L
.50022 .11788 L
.50153 .11841 L
.50425 .11997 L
.50563 .12102 L
.50714 .12239 L
.50984 .12545 L
.5123 .12903 L
.51521 .13444 L
.51834 .1421 L
.52123 .15141 L
.52397 .16265 L
.52923 .19194 L
.53411 .22892 L
.53941 .27779 L
.5422 .30422 L
.54514 .32948 L
.54765 .3466 L
.54908 .35374 L
.5504 .35843 L
.55162 .36094 L
.55273 .36166 L
.55402 .36062 L
.55523 .35784 L
.55638 .35367 L
.55759 .34776 L
.55977 .33384 L
.56471 .2926 L
.56966 .24906 L
.575 .21054 L
.57805 .19394 L
.58085 .18226 L
.58219 .17778 L
.58366 .17367 L
Mistroke
.58495 .17069 L
.58633 .16817 L
.58772 .16622 L
.58901 .16494 L
.59039 .16406 L
.59117 .16378 L
.59191 .16365 L
.59323 .16372 L
.59444 .16412 L
.59511 .16446 L
.59584 .16493 L
.59716 .16603 L
.59964 .16892 L
.60227 .17306 L
.60699 .18292 L
.61759 .211 L
.62315 .22485 L
.62619 .231 L
.62767 .23348 L
.62901 .23537 L
.63019 .23675 L
.63148 .2379 L
.63283 .23873 L
.63411 .23914 L
.63478 .23921 L
.63552 .23918 L
.63629 .23902 L
.63701 .23876 L
.6383 .23804 L
.63968 .23692 L
.6423 .23396 L
.64479 .23031 L
.64946 .22202 L
.65465 .21186 L
.65954 .20286 L
.66429 .19571 L
.66866 .19088 L
.67102 .18891 L
.67351 .18725 L
.67601 .186 L
.67743 .18545 L
.67875 .18505 L
.67942 .18489 L
.68015 .18474 L
.68147 .18454 L
.68276 .18443 L
.68394 .1844 L
.68523 .18441 L
.68596 .18444 L
.68664 .18448 L
Mistroke
.6895 .18469 L
.69069 .18479 L
.69199 .18487 L
.69322 .18493 L
.69436 .18496 L
.69549 .18496 L
.69651 .18494 L
.69769 .18488 L
.69881 .1848 L
.70002 .18469 L
.70131 .18452 L
.70362 .18412 L
.7049 .18382 L
.7061 .18348 L
.70882 .1825 L
.71155 .18114 L
.71407 .17954 L
.71978 .17495 L
.73017 .16473 L
.74965 .14403 L
.75907 .13566 L
.76923 .12926 L
.77206 .12784 L
.77505 .12651 L
.77759 .12562 L
.77829 .12543 L
.77904 .12526 L
.78038 .12503 L
.78173 .12491 L
.7825 .12489 L
.7832 .12491 L
.7845 .12503 L
.78587 .12527 L
.78709 .12559 L
.78824 .12598 L
.79085 .12726 L
.79217 .12813 L
.79356 .12929 L
.79607 .13209 L
.79761 .13439 L
.79906 .13704 L
.80177 .14348 L
.80436 .15181 L
.80675 .16163 L
.80937 .17518 L
.81214 .19317 L
.81694 .23495 L
.82142 .28573 L
.8267 .35052 L
.82903 .37497 L
Mistroke
.83035 .38639 L
.83159 .39503 L
.83282 .40131 L
.83415 .40531 L
.83484 .40622 L
.83556 .40628 L
.83686 .40411 L
.83754 .40182 L
.83828 .39852 L
.83959 .3905 L
.84116 .37785 L
.84258 .36391 L
.84758 .3047 L
.85299 .24141 L
.85552 .21681 L
.85821 .19513 L
.86069 .17885 L
.86302 .16656 L
.86537 .15664 L
.86752 .14952 L
.86991 .14354 L
.87123 .14103 L
.87248 .13911 L
.87379 .13753 L
.87448 .13688 L
.87521 .1363 L
.87655 .13555 L
.87778 .13518 L
.87897 .13508 L
.88007 .1352 L
.88129 .13556 L
.88258 .13618 L
.88397 .13711 L
.88548 .13844 L
.88821 .1417 L
.89088 .146 L
.89334 .15101 L
.8978 .16269 L
.90272 .17923 L
.91266 .222 L
.91812 .2464 L
.92081 .25673 L
.9233 .26451 L
.92446 .2674 L
.92556 .26966 L
.92682 .27168 L
.92796 .27294 L
.92923 .27371 L
.9304 .27383 L
.93168 .27332 L
Mistroke
.93304 .27208 L
.9344 .27014 L
.93565 .26783 L
.93844 .26098 L
.94349 .24474 L
.94905 .22538 L
.95496 .20798 L
.95734 .20253 L
.95991 .19773 L
.96272 .1937 L
.96399 .19229 L
.96537 .19101 L
.96655 .19012 L
.96781 .18939 L
.96915 .18883 L
.97039 .1885 L
.97163 .18833 L
.9728 .18833 L
.97386 .18843 L
.975 .18864 L
.97635 .18901 L
.97762 .18945 L
.9805 .1907 L
.98634 .19351 L
.98892 .19461 L
.99138 .19548 L
.99273 .19587 L
.99421 .19621 L
.99555 .19644 L
.99679 .19658 L
.99766 .19662 L
.99848 .19663 L
.99921 .1966 L
1 .19653 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00KoV9RHoa0@4?l0003o8B4Qolc<c?ooool6o`000;;ooooo001=ooooo`Co0000
GOooool2o`0000Gooooo0ol0002`ooooo`00C?ooool00ol0003oooooooooo`02ooooo`;o0000Fooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooo00000;3ooooo001;ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`05ooooo`04o`000?oooooo
ooooo`0005;ooooo1ol0001Fooooo`00Boooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo05Kooooo00?o0000ooooooooool01_ooool2o`0000;ooooo00?o0000ooooooooool0C_ooool2
o`0000Kooooo00?o0000ooooooooool0Doooool004[ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`1Dooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00001>
ooooo`;o00002Oooool00ol0003oooooooooo`1Booooo`00BOooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo05Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo04[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Eoooo
o`Co0000>?ooool004Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Booooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool05?ooool2o`0000?ooooo00?o0000oooooooo
ool0=Oooool004Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Booooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`17ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo03Gooooo000_ooooo`;o00005oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo05;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo04Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0=?ooool002cooooo1?l000000ooooooo0000o`00000E
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0d
ooooo`00:_ooool2o`0000Kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo053ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo04?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<oooool002Sooooo0_l00009ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1@ooooo`03
o`000?oooooooooo00Wooooo0_l00005ooooo`03o`000?oooooooooo04;ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0<oooool002Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0booooo`009_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03;ooooo000Eooooo`;o000000Wo410@
ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00?ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`06onk^k_lb<S;o0000
oc8b<_o^k^ko00003oooool00ol0003oooooooooo`08ooooo`Go00000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^01cooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^4Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool3
o`0000?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^6_ooool5o`0000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03o`000?oooooooooo00_ooooo00GoV9RHoa0@
4?l0003o0000olc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool00ol0003ooooooooo
o`0Hooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h03_ooool001Ko
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool0
1_mgMgOoV9RHoooooonHV9SoMgMgo`00013ooooo00?o0000ooooooooool01oooool01OnHV9So8B4Q
onk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Aooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0@ooooo`;o00000_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05o`000?lQ
8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00gooooo00?o0000oooooooo
ool02oooool01Ol@413o^[Zjooooool0003o<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00kooooo000;ooooo`Ko00000_ooool5o`0000?ooooo00Go410@oooooooooooooooooa0@
4002ooooo`;o00003_ooool6o`0000Kooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@
4?l0003ooooo00oooooo00?o0000ooooool000001Ol00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400Cooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41004Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000001?ooool01Ol@413ooooooooooooooooo410@01Wooooo00Go0000oooooonHV9So8B4Q
onk^kP04ooooo`05oa0@4?ooooooooooooooool@41003Oooool00ol0003oooooooooo`0>ooooo`;o
00000oooool01Ol@413ooooooooooooooooo410@00;ooooo00?o0000ooooooooool05_ooool5o`00
00?ooooo00Go410@oooooooooooooooooa0@400>ooooo`004oooool01?m4A4CogMgMooooool00004
ooooo`07o`000?ooooooooooooooool0003oooooo`00000Cooooo`03o`000?oooooooooo00Gooooo
00?oZJVYoa0@4?ooool00_ooool01?l0003oooooooooooooool2o`00013ooooo00?o0000oooooooo
ool02Oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000007_ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000001Sooooo
00Oo0000oooooooooooooooooiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000=
ooooo`03o`000?oooooooooo00kooooo00?o0000oa0@4?ooool00_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool05Oooool01?m4A4CogMgMooooool00004ooooo`05o`00
0?ooooooooooooooool000003_ooool001?ooooo00CogMgMoeEEEOoooooo00001?ooool01?l0003o
ooooooooooooool2o`0001Cooooo00?o0000ooooooooool01?ooool00ol@413o0000okZj^P03oooo
o`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`09ooooo`03ogMgMomVIVKo
oooo00;ooooo00?o0000ooooooooool00_l0000Gooooo`go00000oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oo
ooooooooooooool000005oooool00ol0003oooooooooo`03ooooo`03ogMgMomVIVKooooo00;ooooo
00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo00gooooo00?o410@o`000?nj
^[X00oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool05Oooool01?oM
gMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool001Cooooo00?oMgMg
olc<c?l000001?ooool01Ol@413oooooo`000?l0003o410@01Kooooo00?o0000ooooooooool01?oo
ool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool000004_ooool00ol0003ooooo
ooooo`0:ooooo`06o`000?ooooooooooooooool@413ooooo1?l0000Dooooo`?o00001_ooool01?l0
003oooooooooooooool2o`0000?ooooo00?o410@ooooooooool03_ooool00ol0003oooooooooo`0;
ooooo`;o00001oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo00Co0000
oooooooooooo00001?ooool01Ol@413ooooooooooooooooo410@01Gooooo0_l00007ooooo`05o`00
0?ooooooooooooooool@41000oooool00ol@413oooooooooo`0;ooooo`03o`000?oooooooooo00ko
oooo00?o0000ob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00?o0000oooo
ooooool05_ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41003_ooool0
01Cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOo0000oooooonHV9SoMgMg01Kooooo00Wo0000
oooooooooooooooooa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9So0000
01;ooooo00?o0000ooooooooool01_ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00OoMgMg
o`000?ooooooV9RHogMgMooooooo000001;ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMol0003ooooooiRHV?mgMgL04?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooo000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`;o00001?ooool3o`00
00Gooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03Ooo
ool00ol0003oooooooooo`0;ooooo`03oa0@4?nHV9Sooooo00;o00000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00?o0000ooooooooool05_ooool00oo^k^koA4A4o`000004ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03_ooool001Gooooo00?oMgMgo`000?ooool00_ooool2o`000004oc8b
<_l0003o<S8bonk^kQKooooo00Wo0000ooooooooooooooooojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;o000001;ooooo00?o0000ooooooooool01_ooool01OnHV9So410@
o`000?lQ8B7oc<c<00?ooooo00Ook^k^o`000?l0003o<S8bonk^k_oooooo000001;ooooo00?o0000
ooooooooool01Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`05ooooo`03o`000?mVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP09ooooo`Co000000?oooooo`000?l000000ol00007ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo00?o0000ooooooooool02_ooool01OnY
ZJWo410@o`000?l0003oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`03o`000?oo
oooooooo01Oooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo
000Hooooo`;o00007?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0@ooooo`Oo00006?ooool001Oooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool03oooool2o`0002cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00oooooo0_l00006ooooo`03o`000?oooooooooo01Gooooo000Foooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`06oooo
o`Co00004oooool003Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Nooooo`00
=oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01oooooo000Foooooooo0000@?l0
000Cooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`;o00001Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool2o`0000Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00001oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00Oooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool04Oooool001Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`00
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00007ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool01Oooool2o`0000Cooooo00?o0000ooooool000001ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oo
oooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo0_l00006ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool003Sooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool03?ooool2o`000003ooooool0003o000001[ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Pooooo`00>?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=ooooo`;o00007Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo023ooooo000hooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Pooooo`00>?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08Oooool003Sooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027ooooo000hooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Qooooo`00
>?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
3Oooool2o`0000Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0?ooooo`05o`00
0?ooooooooooooooool00000=oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Rooooo`00>?ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03oooool2o`000003oooo
ool0003ooooo03Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool08_ooool003Sooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo013ooooo0ol0000hooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo02;ooooo000hooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`1<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo02?ooooo000iooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
02?ooooo000iooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`1<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo02?ooooo000iooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02oooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Cooooo
000iooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo02Cooooo000iooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`;o00002_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09?ooool003Wooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04gooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Dooooo`05o`000?ooooooooooooooool000009oooool0
03Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
04kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Dooooo`05o`000?oooooooooo
ooooool000009oooool003Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo04kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Doooo
o`05o`000?ooooooooooooooool000009oooool003Wooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Dooooo`;o000000?oooooo`000?ooool09oooool003Wooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04kooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Eooooo`;o0000:Oooool003Wooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`11ooooo`00>Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo047ooooo000jooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0?ooooo`;o00002_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo04oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`11ooooo`00>_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Coooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo047ooooo000jooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0@Oooool003[ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`11ooooo`00>_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0Coooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo047ooooo000j
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1?
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0@Oooool003[ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool00000=Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo1Ol00006ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0@Oooool003[ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Jooooo`05o`000?ooooooooooooooool00000=Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1@ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0@Oooool003[ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool00000=Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Gooooo00?oV9RHob4Q8Oo^k^h01oooool3o`0000[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0@Oooool003[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooo000003Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`11
ooooo`00>_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ool00000=oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?oMgMgofIV
I_ooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0DOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo047ooooo000jooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0fooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Aooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0@Oooool003_ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1?ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`11ooooo`00>oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0DOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04;ooooo000kooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo057ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`12ooooo`00>ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0@_oo
ool003_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool04?ooool2o`0000cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1Aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0@_ooool0
03_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
04;ooooo000kooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0EOooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03?ooool01Ol0003o
oooooooooooooooo000005Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`12oooo
o`00>oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo00Co0000oooooooo
oooo0000EOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04;ooooo000kooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool03?ooool01?l0003oooooooooool0001Eoooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0@_ooool003_ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0<ooooo`04o`000?ooooooooooo`0005Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`12ooooo`00>oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo05Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooool00000EOooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo04?ooooo000kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
Eoooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooo`00001Eooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
@oooool003_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Gooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0=ooooo`;o0000E_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04?ooooo000kooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo013ooooo0_l0000>ooooo`;o0000E_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo04?ooooo000kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Eoooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0I_ooool01Ol0
003ooooooooooooooooo000004Gooooo000kooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0Eoooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0I_ooool01Ol0003ooooooooooooooooo000004Gooooo000kooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0I_ooool01Ol0003ooooooooooooooooo000004Gooooo000koooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0I_ooool01?l0003oooooooooool00016
ooooo`00>oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05Sooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo06Kooooo00Co0000oooo
oooooooo0000A_ooool003_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Hoooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Voooo
o`04o`000?ooooooooooo`0004Kooooo000looooo`05o`000?ooooooooooooooool00000F_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0I_ooool0
1?l0003oooooooooool00016ooooo`00??ooool01Ol0003ooooooooooooooooo000005_ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0@ooooo`;o0000Ioooool01?l0003ooooooooo
ool00016ooooo`00??ooool01Ol0003ooooooooooooooooo000005_ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06Kooooo00Co0000oooooooooooo
0000A_ooool003cooooo00Go0000ooooooooooooooooo`00001Kooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Vooooo`04o`000?ooooooooooo`00
04Kooooo000looooo`05o`000?ooooooooooooooool00000Foooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0I_ooool01?l0003oooooooooool00016
ooooo`00??ooool01Ol0003ooooooooooooooooo000005_ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06Kooooo00Co0000oooooooooooo0000A_oo
ool003cooooo00Go0000ooooooooooooooooo`00001Kooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool02?ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0Iooo
ool2o`0004Oooooo000looooo`05o`000?ooooooooooooooool00000Foooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1Wooooo`;o0000Aoooool003cooooo00Go0000ooooooooooooooooo`00001Kooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01_ooool5o`0000Kooooo00?o0000ooooooooool0/?oo
ool003cooooo00Go0000ooooooooooooooooo`00001Kooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01_ooool01?m4A4CogMgMooooool00007ooooo`?o0000/?ooool003gooooo00Co
0000oooooooooooo0000Foooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo
00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`2`ooooo`00?Oooool00ol0003ooooo
o`00001Looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00omgMgOoc<c<
o`000007ooooo`03o`000?oooooooooo0;3ooooo000mooooo`03o`000?oooooo000005cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03onk^k_m4A4Co000000Oooooo00?o
0000ooooooooool0/?ooool003gooooo00?o0000ooooool00000GOooool01?l0003oooooooooool0
000;ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0/?ooool003gooooo00?o0000
ooooool00000GOooool01?l0003oooooooooool0000Dooooo`03o`000?oooooooooo0;3ooooo000m
ooooo`03o`000?oooooo000005gooooo00Co0000oooooooooooo00005?ooool00ol0003ooooooooo
o`2`ooooo`00?_ooool2o`0005gooooo00Co0000oooooooooooo00005?ooool00ol0003ooooooooo
o`2`ooooo`00?_ooool00ol0003oooooooooo`1Looooo`04o`000?ooooooooooo`0001Cooooo0_l0
002aooooo`00WOooool01?l0003oooooooooool0000Dooooo`03o`000?oooooooooo0;3ooooo002M
ooooo`04o`000?ooooooooooo`0001Cooooo00?o0000ooooooooool0/?ooool009gooooo00Co0000
oooooooooooo00005?ooool00ol0003oooooooooo`2`ooooo`00WOooool01?l0003oooooooooool0
000Dooooo`03o`000?oooooooooo0;3ooooo002Nooooo`;o00005Oooool00ol0003oooooooooo`2`
ooooo`00W_ooool2o`0001Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`oooo
o`00Z_ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[o
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05
o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`000;3ooooo002Zooooo`05o`000?mEEEGo0000oa0@
4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool00omEEEGoQhN7ooooo`08ooooo`03
o`000?oooooooooo0;3ooooo002Zooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0
/?ooool00:_ooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Oo<c<co8B4Qo`00
0?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go8B4QoiRHV?ooooooV9RH
ob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo
0ol0002`ooooo`00Z_ooool01Oo<c<co0000o`000?l0003oc<c<0;Wooooo002Zooooo`05oa0@4?nj
^[[ooooookZj^_l@4100^Oooool00:[ooooo00Go0000okZj^_oooooo^[Zjo`00002iooooo`00Z_oo
ool01OnYZJWo410@o`000?l@413oZJVY0;Wooooo003oooooofWooooo002cooooo`03o`000?nj^[[o
oooo0;;ooooo002cooooo`;o<S8b/oooool008Cooooo0_l000001_l@413oooooooooool@413o0000
oa0@41Sooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06_ooool00ol0003o
k^k^ooooo`03ooooo`Go0000O?ooool008Gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`Ko00003Oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`03olc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002ooo
ool00omEEEGoZJVYooooo`03ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0O?ooool008Gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooooooooa0@40?ooooo
00?o410@ooooooooool04?ooool00ol0003oooooooooo`0Looooo`03ojVYZOmEEEGooooo00Cooooo
00?oV9RHob4Q8Oo^k^h0OOooool008Gooooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko
00003Oooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0;ooooo`Ko00003?ooool00olQ8B7oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^
07cooooo0025ooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo00006Oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo01gooooo
00?oEEEEolc<c?ooool01Oooool00omgMgOoIVIVooooo`1kooooo`00QOooool01_l0003oQhN7ojVY
ZOnj^[[oEEEEo`0001Wooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@
013ooooo00?o410@o`000?l000000ol0000Looooo`03ojVYZOmgMgOooooo00Kooooo00?o0000oooo
ooooool0N_ooool008Gooooo00Ko0000oc8b<_oooooooooooc8b<_l0000Iooooo`03o`000?oooooo
oooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Booooo`03o`000?oooooooooo01[ooooo00Go
410@oooooooooooooooooc8b<P03ooooo`05o`000?nj^[[ooooooiRHV?l@4100O?ooool008Cooooo
00?o410@o`000?n7QhL00_ooool00on7QhOo0000oa0@400Hooooo`Co00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01;ooooo00?o0000ooooooooool06_ooool5o`0000?ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c01looooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(74) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .19161 m
.01975 .17197 L
.04057 .14496 L
.05077 .13409 L
.05638 .12902 L
.06168 .12518 L
.06795 .1218 L
.07092 .12048 L
.07365 .11942 L
.07625 .11863 L
.07756 .11834 L
.07831 .11822 L
.079 .11814 L
.07975 .11807 L
.08046 .11804 L
.0818 .11807 L
.08255 .11813 L
.08324 .11822 L
.084 .11834 L
.08481 .11851 L
.08611 .11886 L
.08754 .11936 L
.08894 .11997 L
.09043 .12078 L
.09183 .12171 L
.09311 .12274 L
.09561 .12541 L
.0971 .12753 L
.09848 .12993 L
.10161 .13721 L
.10436 .14618 L
.10729 .1589 L
.10979 .17292 L
.11248 .19206 L
.11736 .2398 L
.12311 .31779 L
.12592 .35929 L
.12847 .39393 L
.12967 .408 L
.13097 .42097 L
.1322 .43065 L
.13333 .43705 L
.13453 .441 L
.13585 .44182 L
.13723 .4387 L
.13852 .43222 L
.1392 .42752 L
.13994 .42144 L
.14129 .40808 L
.14382 .37679 L
Mistroke
.14951 .2951 L
.15508 .22771 L
.15819 .20049 L
.16101 .18176 L
.16365 .16844 L
.16504 .16285 L
.1665 .15788 L
.16778 .15427 L
.16919 .15106 L
.17047 .14878 L
.17167 .14717 L
.173 .14592 L
.17367 .1455 L
.17441 .14517 L
.17572 .14495 L
.17694 .1451 L
.17764 .14532 L
.17838 .14566 L
.1797 .14651 L
.18112 .14773 L
.18267 .1494 L
.18528 .15301 L
.18807 .15802 L
.19308 .17056 L
.19834 .18838 L
.2033 .20826 L
.21258 .24843 L
.21513 .25867 L
.21787 .2682 L
.21919 .27209 L
.22045 .27525 L
.22159 .27764 L
.22281 .27967 L
.22409 .28122 L
.22528 .28211 L
.22656 .28252 L
.22728 .28249 L
.22797 .28231 L
.22866 .28198 L
.22939 .28148 L
.23069 .2802 L
.2321 .27834 L
.23363 .2758 L
.2436 .25219 L
.2485 .2406 L
.25302 .23253 L
.25553 .22931 L
.25819 .22673 L
.26085 .2248 L
.26379 .22323 L
Mistroke
.26623 .22226 L
.26885 .2215 L
.27132 .221 L
.27359 .22064 L
.2762 .22018 L
.27766 .21984 L
.27898 .21946 L
.28203 .2182 L
.28486 .21659 L
.29558 .20902 L
.30541 .20228 L
.3078 .2009 L
.31037 .19972 L
.31184 .1992 L
.31318 .19882 L
.3158 .19829 L
.3186 .19785 L
.32165 .19733 L
.32453 .19669 L
.32719 .19596 L
.33227 .19435 L
.33484 .19334 L
.33767 .19185 L
.34014 .1901 L
.34283 .18764 L
.34827 .18131 L
.358 .1682 L
.36948 .15054 L
.3799 .13795 L
.38499 .13258 L
.38767 .13018 L
.38913 .1291 L
.3905 .12826 L
.3918 .12762 L
.39298 .12717 L
.3943 .1268 L
.39502 .12665 L
.39571 .12654 L
.3969 .12641 L
.39801 .12636 L
.39922 .12637 L
.40051 .12648 L
.40123 .12659 L
.402 .12676 L
.40337 .12722 L
.40413 .12758 L
.40484 .12799 L
.40567 .1286 L
.40646 .1293 L
.40788 .13094 L
Mistroke
.40916 .13292 L
.41055 .13562 L
.41206 .13932 L
.41469 .14788 L
.41749 .16028 L
.41988 .1741 L
.42251 .19371 L
.42512 .21886 L
.42796 .25406 L
.43315 .33779 L
.43577 .38475 L
.43825 .42591 L
.44047 .45602 L
.44173 .46876 L
.44288 .47724 L
.44415 .48263 L
.44488 .48375 L
.44555 .4835 L
.44692 .47923 L
.44768 .4747 L
.44838 .46928 L
.44982 .45453 L
.45139 .4338 L
.45424 .38746 L
.45969 .29227 L
.46235 .25219 L
.4648 .22175 L
.46707 .19893 L
.46954 .17912 L
.47204 .16364 L
.47466 .15113 L
.47739 .14148 L
.47892 .13738 L
.4803 .13437 L
.4816 .13213 L
.483 .13027 L
.48433 .12897 L
.48555 .12812 L
.48682 .12753 L
.48819 .12717 L
.48948 .12702 L
.49065 .12704 L
.49203 .1272 L
.49281 .12736 L
.49353 .12755 L
.49485 .12801 L
.49626 .12868 L
.49774 .1296 L
.49933 .13088 L
.50222 .13405 L
Mistroke
.50503 .13823 L
.50761 .14299 L
.51255 .15449 L
.51785 .17126 L
.52285 .19298 L
.5274 .21809 L
.53288 .25293 L
.53868 .29005 L
.54107 .30328 L
.54364 .31491 L
.54512 .31999 L
.54646 .32348 L
.54775 .3257 L
.54911 .32682 L
.55037 .32673 L
.55152 .32572 L
.55284 .32351 L
.55408 .32047 L
.5563 .31311 L
.5587 .30295 L
.56918 .25234 L
.5747 .23216 L
.57748 .22496 L
.57906 .22179 L
.58053 .21942 L
.58189 .21773 L
.58317 .21653 L
.58432 .21576 L
.58558 .21522 L
.58694 .21495 L
.58763 .21493 L
.58839 .21499 L
.58973 .21527 L
.59099 .21572 L
.59222 .2163 L
.59354 .21706 L
.59591 .2187 L
.60129 .22313 L
.60397 .22533 L
.60687 .22738 L
.6082 .22813 L
.60961 .22877 L
.61082 .22916 L
.61215 .22944 L
.61347 .22954 L
.61468 .22948 L
.61534 .22939 L
.61607 .22925 L
.6174 .22888 L
.61863 .22841 L
Mistroke
.61995 .22779 L
.62232 .22641 L
.62717 .22275 L
.63157 .21874 L
.63665 .21396 L
.6414 .21016 L
.64635 .20735 L
.64897 .20628 L
.65178 .20538 L
.65484 .20461 L
.65774 .20406 L
.66317 .20331 L
.6656 .20294 L
.66683 .2027 L
.66819 .20237 L
.66965 .20193 L
.67102 .20142 L
.67364 .20015 L
.6762 .19853 L
.67858 .19671 L
.68397 .19156 L
.69484 .17709 L
.71427 .14815 L
.72533 .13525 L
.73076 .13036 L
.73576 .12641 L
.74022 .12344 L
.74513 .12088 L
.75006 .11883 L
.75528 .11698 L
.7579 .11622 L
.75928 .11588 L
.76076 .11557 L
.76217 .11533 L
.76345 .11516 L
.76474 .11503 L
.76595 .11494 L
.76714 .11487 L
.7684 .11482 L
.76947 .1148 L
.77064 .11479 L
.77191 .1148 L
.77326 .11483 L
.77454 .1149 L
.7757 .11499 L
.77707 .11515 L
.77776 .11526 L
.77851 .11541 L
.78111 .1161 L
.78257 .11664 L
Mistroke
.78414 .11736 L
.78698 .11902 L
.78983 .1212 L
.79255 .12385 L
.79498 .12686 L
.79764 .13108 L
.80032 .13662 L
.80321 .14447 L
.80595 .15402 L
.80846 .16494 L
.81324 .19236 L
.81828 .2327 L
.82373 .28848 L
.8289 .34304 L
.83175 .36723 L
.83254 .37252 L
.83337 .37738 L
.83409 .38092 L
.83486 .384 L
.83619 .38741 L
.83744 .3884 L
.83817 .38798 L
.83893 .38675 L
.8403 .38263 L
.84158 .37661 L
.84276 .36951 L
.84539 .34904 L
.85013 .30353 L
.85529 .25544 L
.85801 .23457 L
.8609 .21668 L
.86335 .20481 L
.86465 .19969 L
.86604 .19501 L
.86732 .19144 L
.8685 .18874 L
.86969 .18652 L
.87079 .18491 L
.8719 .18369 L
.87308 .18283 L
.8744 .18235 L
.87559 .18232 L
.87671 .18262 L
.87793 .18328 L
.87908 .18419 L
.88014 .18526 L
.88273 .18865 L
.88508 .19253 L
.89038 .20322 L
.89993 .22519 L
Mistroke
.90527 .23589 L
.90829 .24055 L
.90973 .24236 L
.91108 .24379 L
.91235 .2449 L
.91351 .24573 L
.9148 .24643 L
.91548 .2467 L
.9162 .24693 L
.91754 .24717 L
.91879 .24719 L
.92016 .24699 L
.92093 .24678 L
.92163 .24653 L
.92289 .24596 L
.92406 .24528 L
.92673 .24329 L
.93213 .2379 L
.9418 .22713 L
.95301 .21647 L
.96364 .20915 L
.97274 .20442 L
.98265 .20028 L
1 .19161 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
D?ooool7o`0005Wooooo000^ooooo`Co0000N?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo
00?o0000ooooooooool0COooool4o`0000Gooooo0_l0001Hooooo`00;?ooool3o`0000;ooooo0ol0
0021ooooo`03o`000?oooooooooo04[ooooo0ol0000;ooooo`;o0000E_ooool002[ooooo0_l00007
ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo05?ooooo000Yooooo`03o`000?oooooooooo00Sooooo0_l0001Loooo
o`Ko00006Oooool3o`000003ooooool0003ooooo04Sooooo0_l0000Booooo`03o`000?oooooooooo
05;ooooo000Wooooo`;o00003?ooool00ol0003oooooooooo`1Iooooo`;o00001?ooool2o`0001Ko
oooo0_l00002ooooo`Co0000Aoooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo057o
oooo000Vooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0F?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00oooool2o`0004Oooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`1Aooooo`009_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Cooooo`;o00001Oooool2o`0004Kooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`1Aooooo`009Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Cooooo0_l00015
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0DOooool002Cooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000004?ooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`1@ooooo`008oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo01?ooooo0ol0000mooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000004;ooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`1@ooooo`008oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool00_l0000kooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`00043o
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1@ooooo`008_ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0gooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`05ooooo`04o`000?ooooooooooo`00043ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`1?ooooo`008Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`05ooooo`;o00000_ooool00ol0003ooooo
ooooo`0looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0Coooool0023ooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000003gooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`1?ooooo`007oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo04kooooo000Eooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_l0
00006?ooool01ol0003ooooooiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0=ooooo`Go00000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00?o0000ooooool000000ol000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^1?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Jooooo`Co000000So410@
ooooooooooook^k^oc8b<_l0003o<S8bonk^kQ?ooooo00?o0000ooooooooool01?ooool5o`0000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03o`000?oooooooooo00_ooooo00GoV9RHoa0@
4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07Oooool2o`000009oa0@4?oo
ooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Fooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?oooooo0000ogMgM`0Iooooo`06o`000?l@413o^[ZjoooooomgMgOo<S8b0ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0<ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
01Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0Booooo`03o`000?oooooooooo00Gooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03Oooool00ol0003oooooooooo`0;ooooo`05
oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko00000_ooool5
o`0000?ooooo00Go410@ooooool0003ooooooa0@400Booooo`Ko000000?oooooo`000?ooool00ooo
ool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@ooooooooooooooooo`000008ooooo`03
o`000?oooooooooo00Cooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooo
oooooooooa0@400Cooooo`Oo00001?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41001?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Booooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h01?oo
ool01Ol@413ooooooooooooooooo410@00gooooo00?o0000ooooooooool03oooool01Ol0003ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool06Oooool5o`0000?ooooo00Go410@oooooooo
oooooooooa0@400>ooooo`004oooool01?m4A4CogMgMooooool00004ooooo`;o00000_ooool00ol0
003oooooooooo`0Gooooo`06o`000?oooooooooooooooonYZJWo410@0oooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0>ooooo`03oiRH
V?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Hooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004Oooool0
0ol0003oooooooooo`08ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00
000>ooooo`03o`000?oooooooooo00gooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooo
oooooooo000001_ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo0000
00kooooo000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000I
ooooo`06o`000?oooooooooooa0@4?l0003o^[Zj0oooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0>ooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Gooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004?ooool00ol0003ooooooooo
o`0:ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`00
0?oooooooooo00cooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000001_o
oooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000kooooo000Doooo
o`03ogMgMoo<c<co000000?ooooo00?o0000oa0@4?ooool00_ooool00ol@413oooooooooo`0Goooo
o`06o`000?oooooooooooooooonj^[[o8B4Q0oooool01Ol@413ooooooooooooooooo410@00;ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0?ooooo`05o`000?ooooooooooooooool@
41000oooool00ol@413oooooooooo`0Dooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@00Cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`07ooooo`;o00001?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00_ooooo00Go0000
oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00cooooo00?o0000ooooooooool03Ooo
ool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41007?ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41003_ooool001Cooooo00?ok^k^odA4A?l00000
0_ooool01ol0003oooooogMgMonHV9SooooooiRHV?mgMgL06Oooool01_l0003o410@oiRHV?oooooo
^[Zjo`0000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0Eooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03oooool00ol0003oooooooooo`08ooooo`05o`000?nj
^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000oooooooo
ool02_ooool01_l@413oV9RHoooooonj^[[o0000ooooo`Co000000?ooooooiRHV?mgMgL07?ooool0
0oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool001Gooooo00CoMgMg
o`000?oooooo00000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Wooooo00Ko0000ojVYZOl@413o
0000oa0@4?nYZJT3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h05?ooool00ol0003oooooooooo`05ooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Sooooo00?oEEEEofIVI_l0
00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo00?o0000ooooooooool02Oooool01OnH
V9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`03o`000?oo
oooooooo00[ooooo00WoZJVYoa0@4?l0003o410@ojVYZOoooooo0000ooooooo^k^h00_l000000olb
<S;ok^k^ooooo`0Looooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>
ooooo`005oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0fooooo`005_ooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Xooooo`;o
00006_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo027ooooo0_l0000Cooooo`00
>Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
9Oooool3o`0001cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Oooooo`;o0000
5Oooool003Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo027ooooo1?l0000Oooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02gooooo0_l0000[ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo01Gooooo000iooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Mooooo`?o00008oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Xooooo`Co0000;Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06Oooool3
o`0001Sooooo000Foooooooo0000@?l0000Cooooo`005_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`05ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo0ol00007ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00007ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`000007ooooo`03
o`000?oooooooooo00Gooooo00Co0000oooooooooooooooo0_l00002ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool04Oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01Ol0003o
oooooooooooooooo000000;ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooooooo0_l00002ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00001oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000
ooooool000001oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`00>_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00oooooo0ol0000=ooooo`03o`000?oooooooooo03Oooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool07oooool003[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo01Gooooo0_l0000/ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool00_l0000;ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08?ooool003[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo017o
oooo1Ol0000]ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00gooooo0_l00004ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Qooooo`00>_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03oooool2o`0003;ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`04ooooo`;o00001_ooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo02;ooooo000jooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooooooo`;o0000
?Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool2o`0002Gooooo000kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`08ooooo`?o0000?oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Uooooo`00>oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool2
o`0000Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo02Kooooo000kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`1:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo02Oooooo000kooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Oo
oooo000kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`1;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03Oooool2o`0000Cooooo
00?o0000ooooooooool0:?ooool003_ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0=oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0?ooooo`Go0000:oooool003_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0o
ooooo`00>oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0COooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03oooooo000kooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1=ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0?oooool003_ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo0_l00008ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo03oooooo000looooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0?ooo
ool003cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo04kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0oooooo`00??ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0C_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo03oooooo000looooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03[o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0@?ooool003cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`10ooooo`00??ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01?ooooo00Go
0000ooooooooooooooooo`00000nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
Coooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo043ooooo000looooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool05Oooool00ol0003oooooo`00000oooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo043ooooo000looooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05Oooool2
o`00043ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`;o00002_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`10ooooo`00??ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
05Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0@?ooool003cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1Gooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0D?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo043ooooo000looooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0Eoooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo053ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`11ooooo`00??ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`1Aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0@Oooool003cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0DOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo047ooooo000moooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`06oooo
o`03o`000?oooooo000000Co00001_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
047ooooo000mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Eoooool00ol0003o
ooooooooo`06ooooo`07o`000?ooooooV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Booooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0@Oooool003gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Gooooo`03o`000?oooooooooo00Kooooo00Ko0000ooooooooooooV9RHob4Q8Oo^
k^h7ooooo`?o00002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`11ooooo`00?Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool01_ooool01ol0003ooooooooooooo
ooooV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool0
0000EOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo047ooooo000mooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00;ooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`0;ooooo`05o`00
0?ooooooooooooooool00000EOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo047o
oooo000mooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0FOooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0;ooooo`04o`000?ooooooooooo`0005Kooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`11ooooo`00?Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Wooooo
00?o0000ooooooooool01?ooool02?l0003oooooooooool0003o^[ZjoooooonHV9So410@1_ooool0
0ol0003oooooooooo`0;ooooo`04o`000?ooooooooooo`0005Kooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`11ooooo`00?Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo05Wooooo00?o0000ooooooooool01?ooool02?l0003ooooooooooonHV9So410@o`000?lQ8B7o
c<c<1_ooool00ol0003oooooooooo`0<ooooo`?o0000E_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo047ooooo000mooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
FOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
@_ooool003gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Iooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Uooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0@_ooool003gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool2
o`0006Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`12ooooo`00?Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`12ooooo`00?_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Wo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo06Ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`12ooooo`00?_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`12ooooo`00?_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Wooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo06Kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`12ooooo`00?_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`12
ooooo`00?_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Wooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo06Kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`12ooooo`00?_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo05Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo06Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`12ooooo`00
?_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`12ooooo`00?_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo05[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`;o0000Iooo
ool01Ol0003ooooooooooooooooo000004Gooooo000nooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0F_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0I_ooool01Ol0003ooooooooooooooooo000004Gooooo000nooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0I_ooool01Ol0003ooooooooooooooooo000004Gooooo
000nooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0F_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Ioooool01?l0003ooooooooo
ool00015ooooo`00?_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo06Oooooo00Co
0000oooooooooooo0000AOooool003oooooo00Go0000ooooooooooooooooo`00001Looooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Wooooo`04o`00
0?ooooooooooo`0004Gooooo000oooooo`05o`000?ooooooooooooooool00000G?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Ioooool01?l0003o
ooooooooool00015ooooo`00?oooool01Ol0003ooooooooooooooooo000005cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo06Oooooo00?o0000oooo
ool00000A_ooool003oooooo00Go0000ooooooooooooooooo`00001Looooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool03?ooool2o`0006Wooooo0_l00016ooooo`00?oooool01Ol0003o
oooooooooooooooo000005cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo0;3ooooo000oooooo`05o`000?ooooooooooooooool00000G?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0/?ooool003oo
oooo00Go0000ooooooooooooooooo`00001Looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`2`ooooo`00?oooool01Ol0003ooooooooooooooooo0000
05cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
0;3ooooo000oooooo`05o`000?ooooooooooooooool00000G?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo
0;3ooooo000oooooo`05o`000?ooooooooooooooool00000GOooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2`oooo
o`00?oooool01Ol0003ooooooooooooooooo000005gooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooooooool5o`0000Kooooo00?o0000ooooooooool0/?ooool003oooooo00Go0000oooo
ooooooooooooo`00001Mooooo`05o`000?ooooooooooooooool000001?ooool01?m4A4CogMgMoooo
ool00007ooooo`?o0000/?ooool003oooooo00Go0000ooooooooooooooooo`00001Mooooo`05o`00
0?ooooooooooooooool000001?ooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo
0;3ooooo000oooooo`04o`000?ooooooooooo`0005kooooo00Go0000ooooooooooooooooo`000005
ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0/?ooool003oooooo00Co0000oooo
oooooooo0000G_ooool01Ol0003ooooooooooooooooo000000Gooooo00?ok^k^odA4A?l000001ooo
ool00ol0003oooooooooo`2`ooooo`00?oooool01?l0003oooooooooool0001Nooooo`05o`000?oo
ooooooooooooool000001_ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo
0010ooooo`03o`000?oooooo000005kooooo00Go0000ooooooooooooooooo`00000?ooooo`03o`00
0?oooooooooo0;3ooooo0010ooooo`03o`000?oooooo000005kooooo00Go0000oooooooooooooooo
o`00000?ooooo`03o`000?oooooooooo0;3ooooo0010ooooo`03o`000?oooooo000005kooooo00Go
0000ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo0;3ooooo0010ooooo`;o0000Gooo
ool01Ol0003ooooooooooooooooo000000oooooo0_l0002aooooo`00@Oooool00ol0003ooooooooo
o`1Mooooo`05o`000?ooooooooooooooool000003oooool00ol0003oooooooooo`2`ooooo`00X_oo
ool01?l0003oooooooooool0000?ooooo`03o`000?oooooooooo0;3ooooo002Rooooo`04o`000?oo
ooooooooo`0000oooooo00?o0000ooooooooool0/?ooool00:;ooooo00Co0000oooooooooooo0000
3oooool00ol0003oooooooooo`2`ooooo`00X_ooool01?l0003oooooooooool0000?ooooo`03o`00
0?oooooooooo0;3ooooo002Rooooo`04o`000?ooooooooooo`0000oooooo00?o0000ooooooooool0
/?ooool00:;ooooo00Co0000oooooooooooo00003oooool00ol0003oooooooooo`2`ooooo`00X_oo
ool00ol0003oooooo`00000@ooooo`;o0000/Oooool00:;ooooo00?o0000ooooool000004?ooool0
0ol0003oooooooooo`2`ooooo`00X_ooool00ol0003oooooo`00000@ooooo`03o`000?oooooooooo
0;3ooooo002Rooooo`03o`000?oooooo0000013ooooo00?o0000ooooooooool0/?ooool00:?ooooo
0_l0000@ooooo`03o`000?oooooooooo0;3ooooo002Sooooo`;o00004?ooool00ol0003ooooooooo
o`2`ooooo`00Xoooool2o`00013ooooo00?o0000ooooooooool0/?ooool00:?ooooo0_l0000@oooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000
/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo
00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05oeEE
EOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@06ooooo`?o0000/?ooool00:[ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03
o`000?oooooooooo0;3ooooo002Zooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0
/?ooool00:[ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`2`ooooo`00Zoooool0
1?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_oo
ool00ol0003oooooooooo`2`ooooo`00Z_ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o
0000ooooooooool0/?ooool00:[ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo0;3ooooo002Zooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`000;3ooooo002Z
ooooo`05olc<c?l0003o0000o`000?o<c<`0^Oooool00:[ooooo00Go410@okZj^_oooooo^[Zjoa0@
402iooooo`00Z_ooool01Ol0003o^[Zjoooooonj^[[o00000;Wooooo002Zooooo`05ojVYZOl@413o
0000oa0@4?nYZJT0^Oooool00?ooooooJOooool00;?ooooo00?o0000okZj^_ooool0/_ooool00;?o
oooo0_lb<S:cooooo`00Q?ooool2o`000006oa0@4?oooooooooooa0@4?l0003o410@6?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`03ohN7Qol0
003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Jooooo`03o`000?o^k^kooooo00Gooooo
0_l000000ol@413oooooooooo`1jooooo`00QOooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Oooooo1_l0000=ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000;
ooooo`03oeEEEOnYZJWooooo00Kooooo00?o0000ooooooooool0Noooool008Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooooooooa0@40?ooooo00?o410@
ooooooooool04?ooool00ol0003oooooooooo`0Looooo`03ojVYZOmEEEGooooo00?ooooo1Ol0001l
ooooo`00QOooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000=ooooo`05ogMgMolb
<S;oooooooooool000000oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo
1_l0000<ooooo`03ob4Q8Ooooooooooo00;ooooo00CoA4A4omgMgOoooooo0000OOooool008Gooooo
00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Iooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool0
1Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool07Oooool00omEEEGoc<c<oooo
o`02ooooo`04omgMgOmEEEGoooooo`0007gooooo0025ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo
00006Oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol@
413o0000o`000003o`0001cooooo00?oZJVYogMgMoooool00oooool00omgMgOoc<c<o`00001moooo
o`00QOooool01_l0003o<S8boooooooooooo<S8bo`0001Wooooo00?o0000ooooooooool01?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool06_ooool01Ol@413ooooooooo
oooooooo<S8b00Cooooo00?ok^k^odA4A?l00000OOooool008Cooooo00?o410@o`000?n7QhL00_oo
ool00on7QhOo0000oa0@400Hooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo
00?o0000ooooooooool06_ooool5o`0000Gooooo00?oMgMgo`000?ooool0O?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(76) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .1618 m
.00942 .14435 L
.01975 .13089 L
.02496 .12593 L
.03053 .12182 L
.03578 .11905 L
.04057 .11716 L
.04332 .11626 L
.04624 .11545 L
.04873 .11491 L
.05014 .11468 L
.05147 .11449 L
.05301 .11433 L
.05442 .11423 L
.0552 .11418 L
.05593 .11415 L
.05678 .11412 L
.05758 .11409 L
.05828 .11407 L
.05904 .11406 L
.06036 .11404 L
.0611 .11404 L
.06189 .11404 L
.06257 .11404 L
.06331 .11405 L
.064 .11406 L
.06475 .11409 L
.06612 .11415 L
.06745 .11424 L
.06868 .11436 L
.07 .11453 L
.07147 .11476 L
.07443 .11538 L
.07978 .11685 L
.08239 .11773 L
.08481 .11868 L
.08974 .12135 L
.09235 .1233 L
.09513 .12587 L
.09806 .12916 L
.10083 .13295 L
.10334 .13714 L
.106 .14263 L
.10831 .14852 L
.11085 .15648 L
.11532 .17508 L
.11784 .18859 L
.12055 .20595 L
.12543 .24556 L
.13058 .2978 L
Mistroke
.13607 .35552 L
.13769 .37026 L
.13923 .38216 L
.1406 .39085 L
.14131 .3945 L
.14209 .3978 L
.14282 .40022 L
.1435 .40185 L
.14422 .40291 L
.14499 .40328 L
.14571 .40292 L
.14639 .40196 L
.14766 .39861 L
.14888 .39364 L
.15022 .38635 L
.15292 .36695 L
.15778 .32398 L
.16314 .27868 L
.16606 .25882 L
.16877 .24408 L
.17123 .23369 L
.17385 .2254 L
.17535 .22181 L
.17676 .2191 L
.17802 .21719 L
.1794 .21562 L
.18057 .21465 L
.18186 .21393 L
.1832 .21354 L
.18446 .21347 L
.18564 .21362 L
.18671 .21392 L
.18795 .21442 L
.18913 .21505 L
.19457 .21914 L
.19962 .22392 L
.21104 .23661 L
.22045 .24833 L
.2254 .25439 L
.23061 .25977 L
.23195 .26083 L
.23339 .26179 L
.23421 .26223 L
.23496 .26257 L
.23572 .26285 L
.23643 .26304 L
.23774 .26323 L
.23843 .26324 L
.23917 .26318 L
.2404 .26291 L
Mistroke
.24176 .26237 L
.24312 .26159 L
.24437 .26066 L
.24717 .25789 L
.25223 .25089 L
.26189 .23451 L
.26444 .23056 L
.26719 .22683 L
.26962 .22412 L
.27218 .2219 L
.27366 .22094 L
.27527 .22013 L
.27598 .21985 L
.27674 .2196 L
.27811 .2193 L
.2788 .2192 L
.27955 .21915 L
.28092 .21916 L
.28224 .21931 L
.28347 .21954 L
.28472 .21987 L
.28589 .22024 L
.28855 .22123 L
.29135 .22231 L
.29271 .22276 L
.29395 .2231 L
.29518 .22334 L
.29634 .22346 L
.29756 .22346 L
.29889 .2233 L
.30025 .22293 L
.30094 .22266 L
.3017 .22231 L
.30303 .22151 L
.30428 .22056 L
.30702 .21782 L
.30953 .21453 L
.31516 .20457 L
.33459 .15944 L
.33962 .14934 L
.34497 .14018 L
.35458 .12827 L
.36047 .12309 L
.36336 .12104 L
.36602 .11948 L
.37099 .11734 L
.37361 .1165 L
.37636 .11575 L
.37905 .1151 L
.38037 .11483 L
Mistroke
.38159 .1146 L
.38268 .11444 L
.38387 .11429 L
.38508 .11419 L
.38635 .11414 L
.38774 .11414 L
.38901 .11419 L
.38971 .11424 L
.39047 .1143 L
.39187 .11444 L
.39458 .11476 L
.39704 .11509 L
.39936 .11546 L
.40187 .11599 L
.40326 .11638 L
.40453 .11682 L
.40703 .11795 L
.40918 .1192 L
.41154 .12087 L
.41631 .12519 L
.41894 .12835 L
.42181 .13288 L
.42451 .1387 L
.42702 .14585 L
.42927 .15403 L
.43175 .16533 L
.43678 .19738 L
.43963 .22253 L
.44223 .25106 L
.44811 .33335 L
.45325 .40992 L
.45473 .42825 L
.45613 .44266 L
.45738 .45268 L
.45874 .46003 L
.45998 .46327 L
.46134 .46294 L
.46203 .46123 L
.46276 .45827 L
.46409 .45011 L
.46542 .43873 L
.46667 .42534 L
.46903 .3951 L
.47366 .3278 L
.4786 .26433 L
.48143 .23654 L
.484 .21691 L
.48657 .20181 L
.489 .19118 L
.49038 .18647 L
Mistroke
.49184 .18245 L
.49308 .17975 L
.49445 .1775 L
.49522 .17654 L
.49592 .17586 L
.49673 .17528 L
.49749 .17493 L
.49885 .17475 L
.49962 .17487 L
.50033 .17512 L
.50157 .17584 L
.50288 .17694 L
.50521 .17965 L
.50772 .18344 L
.51046 .18849 L
.51996 .21277 L
.53131 .24712 L
.53667 .2611 L
.54161 .27126 L
.54408 .27501 L
.5467 .2779 L
.54806 .27896 L
.54933 .27972 L
.55004 .28005 L
.55072 .28031 L
.5515 .28054 L
.55222 .28069 L
.55342 .28084 L
.55471 .28086 L
.5558 .28079 L
.55701 .28062 L
.5583 .28034 L
.5597 .27995 L
.56223 .27899 L
.56489 .27766 L
.56781 .27585 L
.5737 .27137 L
.58424 .26058 L
.62678 .22329 L
.6317 .22594 L
.63411 .22721 L
.63631 .22819 L
.6375 .22861 L
.63863 .22891 L
.63982 .22909 L
.64112 .22913 L
.64245 .22896 L
.64319 .22876 L
.64387 .22852 L
.64518 .22788 L
Mistroke
.64642 .22705 L
.64776 .22589 L
.64919 .22439 L
.65174 .22102 L
.6575 .21065 L
.66773 .18623 L
.6784 .16077 L
.68405 .14962 L
.69011 .13965 L
.69583 .13226 L
.70104 .12707 L
.7059 .12319 L
.71125 .1198 L
.7163 .11748 L
.71907 .11652 L
.72167 .11577 L
.7263 .11468 L
.72891 .11421 L
.7313 .11389 L
.73257 .11377 L
.73393 .11368 L
.73521 .11363 L
.73637 .11361 L
.73774 .11363 L
.73851 .11365 L
.73923 .11367 L
.74054 .11374 L
.74192 .11383 L
.74467 .11406 L
.74724 .11435 L
.75007 .11479 L
.7531 .11543 L
.75578 .11617 L
.75862 .11713 L
.76374 .11918 L
.76983 .12225 L
.77534 .12597 L
.78057 .13048 L
.78622 .13649 L
.79155 .14366 L
.79645 .15207 L
.8014 .16276 L
.8067 .17724 L
.81626 .2143 L
.82755 .27628 L
.83251 .30437 L
.83533 .31813 L
.83671 .32388 L
.83797 .32843 L
.83917 .33206 L
Mistroke
.84048 .33519 L
.84186 .33751 L
.84317 .33874 L
.84456 .339 L
.84533 .33869 L
.84603 .33813 L
.8474 .33632 L
.84869 .33379 L
.8501 .33019 L
.8516 .32557 L
.85428 .31565 L
.86032 .2896 L
.86518 .26951 L
.8704 .25223 L
.87339 .24488 L
.87612 .23983 L
.87743 .23792 L
.87886 .23622 L
.88022 .23493 L
.88147 .23402 L
.88266 .23336 L
.88391 .23288 L
.88517 .23261 L
.88655 .23253 L
.88774 .23263 L
.88902 .23289 L
.89023 .23327 L
.89132 .23371 L
.89692 .23693 L
.90221 .24016 L
.90488 .2414 L
.90623 .24186 L
.907 .24208 L
.90771 .24224 L
.90897 .24244 L
.91033 .24253 L
.91159 .24249 L
.91279 .24235 L
.91417 .24206 L
.91494 .24184 L
.91563 .24161 L
.91827 .24041 L
.92136 .23846 L
.92426 .23622 L
.92957 .23173 L
.93453 .22803 L
.93702 .22656 L
.9397 .22534 L
.94122 .22481 L
.94266 .22441 L
Mistroke
.94396 .22414 L
.94469 .22403 L
.94536 .22395 L
.94648 .22386 L
.94767 .22382 L
.9488 .22383 L
.94984 .22389 L
.95099 .22399 L
.95225 .22413 L
.95478 .22446 L
.95606 .22461 L
.95728 .22472 L
.95795 .22475 L
.95868 .22477 L
.95995 .22474 L
.96117 .22461 L
.96246 .22437 L
.96356 .22406 L
.96477 .22359 L
.96695 .22242 L
.96933 .22062 L
.97157 .2184 L
.97365 .2159 L
.98176 .20219 L
1 .1618 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`009Oooool:o`0005oooooo1ol0000Eooooo`05o`000?nj^[[ooooooiRHV?l@4100
1_ooool00ol0003oooooooooo`14ooooo`[o0000H_ooool002;ooooo0ol0000:ooooo`;o0000F_oo
ool4o`0000Kooooo0ol0000Booooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`11ooooo`?o00002_ooool3o`0005oooooo000Pooooo`;o00003oooool2o`0005Kooooo0_l0
000=ooooo`;o00006oooool00ol0003oooooooooo`0oooooo`;o00004?ooool2o`0005gooooo000O
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0B
ooooo`;o0000Foooool001gooooo0_l0000Eooooo`03o`000?oooooooooo057ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo03gooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`1Hooooo`007?ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo04oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Gooooo`;o
0000?Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo05Oooooo000Looooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo05Kooooo000Kooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Booo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0>_oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05Gooooo000Jooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo05Cooooo000Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0B_ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo05?ooooo000Iooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo05?o
oooo000Iooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0Aoooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo05;ooooo000Hooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool0Aoooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo05;ooooo000G
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo01Cooooo0_l0000hooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool0D_ooool001Oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`15oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0foooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0DOooool001Kooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool0?Oooool00ol0003oooooooooo`0Aooooo`005Oooool2o`000009oa0@4?ooooooooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^01Wooooo00Ko0000oiRHV?l@413o0000oc8b<_o<c<`3ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h06oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Aoooo
o`03o`000?oooooooooo00Sooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
2?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01oooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool00ol0003oooooooooo`0<ooooo`Go00000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00?o0000ooooooooool03Oooool01OnHV9So410@o`00
0?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Mooooo`;o000000Wo410@oooooooo
oooo0000onk^k_lb<S;o0000oc8b<_o^k^h03_ooool001Kooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00Go0000okZj^_ooooooMgMgoc8b<P03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL06oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0@ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0:ooooo`03o`00
0?oooooooooo00gooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool00ol0003oooooooooo`0=ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00[o0000oooooooooooo0000oooooomgMgOoV9RHoooo
oonHV9SoMgMg3_ooool000_ooooo1_l00002ooooo`Go00000oooool01Ol@413ooooooooooooooooo
410@01;ooooo1_l00002ooooo`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooo
oooooooo410@01?ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooo
oooooa0@400@ooooo`03o`000?oooooooooo00Ko00001Oooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00[ooooo00?o0000
ooooooooool03_ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`0@ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413ooooo
ooooo`0Iooooo`Go000000Coooooo`000?oooooo410@0oooool00ol@413oooooooooo`0<ooooo`00
4oooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000006_ooool01Ol0
003ooooooooooonYZJWo410@00?ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooooooo
ool04_ooool2o`0002?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00Wooooo00?o0000ooooooooool04?ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooooooo
ooooool000003?ooool00ol0003oooooooooo`0?ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000
ooooooooooooooooo`00000Kooooo`06odA4A?oMgMgoooooo`000?oooooo00000_ooool01Ol0003o
oooooooooooooooo000000kooooo000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000oooo
ooooooooooooo`00000Jooooo`05o`000?oooooo410@o`000?nj^[X00oooool01Ol0003ooooooooo
oooooooo000001kooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000oo
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000002Oooool00ol0003oooooooooo`0@ooooo`Co00008_ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000002Oooool00ol0003oooooooooo`0Aooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo00gooooo00?o
410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000001_ooooo00KogMgMoeEEEOoooooo
0000ooooool00002ooooo`05o`000?ooooooooooooooool000003_ooool001Cooooo00?oMgMgolc<
c?l000001?ooool01Ol@413ooooooooooooooooo410@01[ooooo00Go0000oooooooooooo^[Zjob4Q
8@03ooooo`05oa0@4?ooooooooooooooool@41007oooool01Ol0003ooooooooooooooooo410@00?o
oooo00?o410@ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@4009ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ool000000_l0000Qooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4008
ooooo`03o`000?oooooooooo01?ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oo
oooooooo00_ooooo00?o0000ooooooooool03_ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41007?ooool01?mgMgOoc<c<o`000?l00003ooooo`05oa0@4?oooooooooooooo
ool@41003_ooool001Cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
01[ooooo00Go410@o`000?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06ooo
ool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Wooooo00?o0000ooooooooool03oooool01_l0003oooooooooool0003oooooo`00027ooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0
3oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0=oooo
o`03o`000?oooooooooo00_ooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL07?ooool01?o^k^koA4A4o`000?l00003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03_ooool001Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[o
oooo00GoZJVYo`000?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`03o`00
0?oooooooooo00_ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Wo
oooo00?o0000ooooooooool03oooool01_l0003oooooooooool0003oooooo`0001oooooo00?oEEEE
ofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00?o0000ooooooooool04?oo
ool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`03
o`000?oooooooooo00[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h07Oooool00omgMgOo0000o`000003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_oo
ool003_ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Eooooo`00>oooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool03Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool05Oooool003_ooooo00?o0000
ooooooooool0?Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00gooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo01Kooooo000looooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0=ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool0<oooool00ol0003oooooooooo`0Fooooo`00??ooool00ol0003oooooooooo`0l
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool03Oooool01Ol0003ooooooooooooo
oooo000000Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool05oooool001Koooooool00010o`0001?ooooo000Foooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool2o`0000Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`0Aooooo`005_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo0_l00007ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool00000
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool2o`0000Kooooo00?o0000ooooooooool04Oooool003cooooo00?o0000ooooooooool04?oo
ool4o`0002Gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Iooooo`00?Oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01[ooooo000mooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Eooooo`Oo00000oooool2o`00
02[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool06oooool003gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00oooool5o`0002_o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool07Oooool3o`0000Gooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`0Tooooo`[o00007Oooool003gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Kooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0003Kooooo00?o0000oooooooo
ool08Oooool2o`0002Oooooo000mooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`04ooooo`?o0000=oooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo02Kooooo000mooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`03ooooo`;o00001_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo03oooooo00?o0000ooooooooool04?ooool5o`0000[ooooo0_l0000Yooooo`00?Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0fooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0@?ooool0
0ol0003oooooooooo`0?ooooo`;o00001?ooool2o`0000Oooooo00?o0000ooooooooool0:Oooool0
03kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
047ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo0_l0000/ooooo`00?_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Ko
oooo1?l0000^ooooo`00?_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0@oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Wooooo
000nooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`15ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0>Oooool003kooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0>Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04Kooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0jooooo`00?_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00oooooo0_l00006ooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool0>_ooool003kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Cooooo0_l00009ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0B?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03_ooooo000nooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool04_ooool4o`0003kooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2oooool2o`0004_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0kooooo`00?_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01?ooooo0_l0000oooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo03_ooooo000nooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0E?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0looooo`00?_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
05Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0??ooool003oooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`1Fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Coooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo03cooooo000oooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0E_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo053ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0looooo`00?oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00cooooo1_l0001Cooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0??ooool003oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1F
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool2o`0006Kooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0mooooo`00?oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo05Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo06Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0moooo
o`00?oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05Kooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06Kooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0mooooo`00?oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo05Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo06Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0mooooo`00?ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0mooooo`00?oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo05Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo06Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0nooooo`00?oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool01?ooool5o`00
00Kooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
03kooooo000oooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Eoooool00ol0003o
ooooooooo`04ooooo`05oiRHV?lQ8B7ok^k^o`000?m4A4@01_ooool00ol0003oooooooooo`1Woooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0?_ooool003oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00Gooooo00?oV9RHob4Q8Ol0
00001oooool3o`0006Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0nooooo`00
?oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0
1_ooool00onHV9So0000onk^kP06ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0oooooo`00@?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo05Wooooo00?o0000ooooooooool01Oooool00ol0003oMgMgofIVIP06ooooo`03o`000?oo
oooooooo06Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0oooooo`00@?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool01Oooool0
0ol0003oooooo`000006ooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0oooooo`00@?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
05Wooooo00?o0000ooooooooool00oooool01Ol0003o^[Zjo`000?nHV9So410@00Kooooo00?o0000
ooooooooool0J?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo043ooooo0010oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`03oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Xooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0@?ooool0043ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`1Xooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0@?ooool0043o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Yooooo`04o`000?ooooooooooo`00
04?ooooo0010ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0FOooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Kooooo0_l0001Zooooo`04o`000?ooooooooooo`00
04?ooooo0010ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0F_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0J_ooool2o`0004Co
oooo0010ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0F_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0J_ooool2o`0004Cooooo
0011ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0F_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0/?ooool0047ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`2`ooooo`00@Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo05[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo0;3ooooo0011ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0F_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0/?ooool0047ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Kooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2`ooooo`00@Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0;3ooooo0011ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Kooooo0_l0002aooooo`00@_ooool01Ol0003ooooooooooooooooo000005kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo0012oooo
o`05o`000?ooooooooooooooool00000G_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0/?ooool004;ooooo00Go0000ooooooooooooooooo`00001N
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`
ooooo`00@_ooool01Ol0003ooooooooooooooooo000005kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo0012ooooo`05o`000?oooooooooo
ooooool00000G_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0/?ooool004;ooooo00Go0000ooooooooooooooooo`00001Nooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2`ooooo`00@_ooool01Ol0
003ooooooooooooooooo000005kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0;3ooooo0012ooooo`05o`000?ooooooooooooooool00000G_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo0_l0002aooooo`00@_ooool01Ol0
003ooooooooooooooooo000005kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0;3ooooo0013ooooo`03o`000?oooooo0000063ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo0013ooooo`03
o`000?oooooo0000063ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0;3ooooo0013ooooo`03o`000?oooooo0000063ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;3ooooo0013ooooo`;o0000HOoo
ool00ol0003oooooooooo`02ooooo`?o000000?o410@ooooooooool01?ooool00ol0003ooooooooo
o`2`ooooo`00Y_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Oooooo00?o0000
ooooooooool0/?ooool00:Kooooo00Co0000oooooooooooooooo1Ol00006ooooo`03o`000?oooooo
oooo0;3ooooo002Vooooo`08o`000?ooooooooooooooool0003ogMgMooooool00007ooooo`?o0000
/?ooool00:Kooooo00So0000ooooooooooooooooo`000?mEEEGoooooo`0000Oooooo00?o0000oooo
ooooool0/?ooool00:Kooooo00So0000ooooooooooooooooo`000?mgMgOoc<c<o`0000Oooooo00?o
0000ooooooooool0/?ooool00:Kooooo00So0000ooooooooooooooooo`000?o^k^koA4A4o`0000Oo
oooo00?o0000ooooooooool0/?ooool00:Kooooo00So0000ooooooooooooooooo`000?ooooooMgMg
o`0000Oooooo00?o0000ooooooooool0/?ooool00:Kooooo00Go0000ooooooooooooooooo`00000:
ooooo`03o`000?oooooooooo0;3ooooo002Vooooo`05o`000?ooooooooooooooool000002_ooool0
0ol0003oooooooooo`2`ooooo`00Y_ooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000
ooooooooool0/?ooool00:Oooooo00Co0000oooooooooooo00002_ooool2o`000;7ooooo002Woooo
o`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool0/?ooool00:Oooooo00Co0000oooo
oooooooo00002_ooool00ol0003oooooooooo`2`ooooo`00Yoooool00ol0003oooooo`00000;oooo
o`03o`000?oooooooooo0;3ooooo002Wooooo`03o`000?oooooo000000_ooooo00?o0000oooooooo
ool0/?ooool00:Oooooo00?o0000ooooool000002oooool00ol0003oooooooooo`2`ooooo`00Yooo
ool00ol0003oooooo`00000;ooooo`03o`000?oooooooooo0;3ooooo002Xooooo`;o00002oooool0
0ol0003oooooooooo`2`ooooo`00Z?ooool2o`0000_ooooo0_l0002aooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_oo
ool00ol0003oooooooooo`2`ooooo`00Z_ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o
0000ooooooooool0/?ooool00:[ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo0;3ooooo002Zooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`000;3ooooo002Z
ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool0
0omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03omgMgOl@413oV9RH
00Sooooo00?o0000ooooooooool0/?ooool00:_ooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00Z_ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[o
oooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Olb<S;o
V9RHoooooonHV9So<S8b00Kooooo0ol0002`ooooo`00Z_ooool01Oo<c<co0000o`000?l0003oc<c<
0;Wooooo002Zooooo`05oa0@4?nj^[[ooooookZj^_l@4100^Oooool00:[ooooo00Go0000okZj^_oo
oooo^[Zjo`00002iooooo`00Z_ooool01OnYZJWo410@o`000?l@413oZJVY0;Wooooo003oooooofWo
oooo002cooooo`03o`000?nj^[[ooooo0;;ooooo002cooooo`;o<S8b/oooool008Cooooo0_l00000
1_l@413oooooooooool@413o0000oa0@41Sooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000
odA4A?nj^[X06_ooool00ol0003ok^k^ooooo`03ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0O?oo
ool008Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00003Oooool0
2OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03olc<c?l0003o410@00co
oooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002oooool00omEEEGoZJVYooooo`03oooo
o`05oeEEEOmgMgOooooooiRHV?lQ8B40O?ooool008Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Kooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool04?ooool0
0ol0003oooooooooo`0Looooo`03ojVYZOmEEEGooooo00?ooooo00Go0000ooooooooooooooooo`00
001looooo`00QOooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000=ooooo`05ogMg
Molb<S;oooooooooool000000oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_o
oooo1_l0000<ooooo`03ob4Q8Ooooooooooo00;ooooo00Go0000oiRHV?ooooooV9RHob4Q8@1loooo
o`00QOooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001Wooooo00Go0000ob4Q8Ol0003o<S8bolc<
c002ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0Mooooo`03oeEE
EOo<c<cooooo00;ooooo00Go0000oeEEEOl0003o410@olc<c01looooo`00QOooool01_l0003oQhN7
ojVYZOnj^[[oEEEEo`0001Wooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo
410@013ooooo00?o410@o`000?l000000ol0000Looooo`03ojVYZOmgMgOooooo00;ooooo00?oEEEE
ohN7Qoooool0O_ooool008Gooooo00Ko0000oc8b<_oooooooooooc8b<_l0000Iooooo`03o`000?oo
oooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Booooo`03o`000?oooooooooo01[ooooo
00Go410@oooooooooooooooooc8b<P03ooooo`03omgMgOl@413oV9RH07kooooo0024ooooo`03oa0@
4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0Booooo`03o`000?oooooooooo01[ooooo1Ol00004ooooo`04olc<c?m4A4Co0000oa0@
47cooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(78) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .12237 m
.00488 .11947 L
.00942 .11756 L
.01204 .11674 L
.01441 .11615 L
.01716 .11563 L
.01839 .11544 L
.01975 .11526 L
.02096 .11513 L
.02227 .11501 L
.02365 .11492 L
.02494 .11486 L
.02622 .11482 L
.02744 .11481 L
.02854 .11481 L
.02973 .11484 L
.03047 .11486 L
.03116 .11489 L
.03245 .11497 L
.03384 .11508 L
.03535 .11522 L
.03807 .11555 L
.04057 .11593 L
.04587 .11701 L
.05082 .1184 L
.05626 .12041 L
.06208 .12316 L
.06819 .12682 L
.07397 .13114 L
.08481 .14156 L
.10571 .16891 L
.11502 .18302 L
.12505 .20147 L
.13033 .2148 L
.13516 .23099 L
.13979 .25103 L
.14465 .27726 L
.15003 .31043 L
.15511 .34034 L
.15792 .35336 L
.1595 .35891 L
.16026 .36102 L
.16097 .36266 L
.1622 .36472 L
.16355 .36576 L
.16487 .36553 L
.16561 .36486 L
.16628 .36393 L
.16756 .36132 L
.16892 .35743 L
Mistroke
.17137 .34793 L
.17692 .31888 L
.18177 .29211 L
.1845 .2789 L
.18701 .26868 L
.18955 .26045 L
.19094 .25688 L
.19223 .25414 L
.19345 .25205 L
.19457 .25056 L
.19581 .24936 L
.19713 .24856 L
.19831 .24825 L
.19939 .24827 L
.20058 .2486 L
.20184 .24926 L
.20294 .25006 L
.20396 .25097 L
.2063 .2535 L
.21166 .26013 L
.21428 .26289 L
.21542 .26387 L
.21665 .26472 L
.21794 .26536 L
.21917 .2657 L
.21984 .26578 L
.22056 .26576 L
.22185 .2655 L
.22253 .26524 L
.22325 .26487 L
.22456 .26396 L
.22611 .26249 L
.22753 .26082 L
.23696 .24525 L
.23925 .24149 L
.24172 .238 L
.24313 .23637 L
.24443 .23514 L
.24567 .23425 L
.24697 .2336 L
.24822 .2333 L
.24954 .23331 L
.2508 .23364 L
.25194 .23422 L
.25328 .23523 L
.25473 .2367 L
.25737 .2403 L
.26699 .25865 L
.26836 .26106 L
.26983 .26333 L
Mistroke
.2712 .26507 L
.27249 .26633 L
.27318 .26683 L
.27394 .26722 L
.27527 .26751 L
.27603 .26743 L
.27685 .26714 L
.27762 .26667 L
.27832 .26607 L
.27967 .26446 L
.28091 .26245 L
.28371 .25616 L
.28617 .24879 L
.28878 .23954 L
.2995 .19503 L
.30477 .17488 L
.30965 .15926 L
.31398 .14802 L
.31876 .13831 L
.32357 .13099 L
.32623 .12781 L
.32867 .12537 L
.33376 .12149 L
.33643 .12 L
.33925 .11876 L
.3417 .11793 L
.34399 .11732 L
.34649 .11684 L
.3479 .11664 L
.34917 .11649 L
.35054 .11638 L
.35123 .11634 L
.35199 .1163 L
.35334 .11627 L
.35459 .11626 L
.35536 .11627 L
.35608 .11629 L
.35743 .11634 L
.35818 .11638 L
.35889 .11643 L
.36047 .11656 L
.36318 .11685 L
.36564 .11718 L
.37114 .11816 L
.3817 .12073 L
.3914 .12381 L
.40205 .1281 L
.40793 .13108 L
.41328 .13439 L
.41807 .13799 L
Mistroke
.42327 .14287 L
.42876 .14959 L
.43396 .15804 L
.43882 .16848 L
.44398 .18329 L
.44838 .2 L
.45323 .22385 L
.45868 .25843 L
.46386 .2984 L
.46857 .33744 L
.4736 .37468 L
.47506 .38334 L
.47645 .3902 L
.47769 .39515 L
.47903 .39911 L
.48031 .40146 L
.48166 .40242 L
.48281 .40199 L
.48408 .40024 L
.48484 .39855 L
.48557 .39654 L
.48693 .39176 L
.48999 .37702 L
.49552 .34228 L
.50565 .28139 L
.51076 .25925 L
.51371 .24933 L
.51641 .2419 L
.5187 .23679 L
.52121 .23238 L
.52373 .22912 L
.52511 .22783 L
.52638 .22693 L
.5276 .22635 L
.52876 .22604 L
.52979 .22598 L
.53091 .22612 L
.53213 .22655 L
.53343 .2273 L
.53453 .22819 L
.53575 .22944 L
.5471 .2528 L
.55269 .26877 L
.55541 .27613 L
.55787 .28196 L
.55903 .2843 L
.56029 .28649 L
.56137 .28806 L
.56256 .28941 L
.56382 .2904 L
Mistroke
.56516 .29091 L
.56639 .29089 L
.56755 .29045 L
.56892 .28941 L
.57021 .28793 L
.57264 .28399 L
.57525 .27837 L
.57809 .27121 L
.5834 .25724 L
.58599 .25114 L
.58837 .24646 L
.59086 .24274 L
.59218 .24134 L
.59355 .24031 L
.59424 .23997 L
.59497 .23972 L
.59629 .23962 L
.59709 .23976 L
.59785 .24003 L
.59853 .24039 L
.59927 .2409 L
.60049 .24199 L
.60163 .24328 L
.60422 .24705 L
.60946 .25691 L
.61182 .2615 L
.61433 .26583 L
.61648 .26872 L
.6177 .26991 L
.61885 .27067 L
.62016 .27108 L
.62137 .27099 L
.62269 .27034 L
.62336 .26979 L
.62409 .26901 L
.62552 .26698 L
.62704 .26405 L
.6298 .25694 L
.63523 .23744 L
.64018 .21634 L
.64963 .17753 L
.65481 .16044 L
.65965 .14769 L
.66463 .1376 L
.67011 .1294 L
.67476 .12435 L
.67976 .12047 L
.68256 .11884 L
.68561 .11744 L
.68849 .11642 L
Mistroke
.69116 .11571 L
.69252 .11542 L
.69381 .1152 L
.69498 .11503 L
.69621 .1149 L
.69755 .11479 L
.69879 .11473 L
.70013 .11469 L
.70088 .11469 L
.70159 .1147 L
.70291 .11475 L
.70358 .11478 L
.70432 .11483 L
.70562 .11493 L
.70685 .11506 L
.7096 .11545 L
.71257 .11601 L
.71799 .11743 L
.72296 .11916 L
.73246 .12346 L
.74245 .12929 L
.76342 .14376 L
.78247 .15699 L
.78756 .16092 L
.79307 .16595 L
.79783 .17133 L
.80307 .17881 L
.80863 .18903 L
.81452 .20282 L
.82507 .23431 L
.83008 .25049 L
.83555 .26683 L
.84071 .2794 L
.84318 .2841 L
.84549 .28773 L
.84841 .29125 L
.85105 .29358 L
.85389 .29537 L
.85549 .29614 L
.85696 .29673 L
.86206 .29829 L
.86462 .29889 L
.86608 .29917 L
.86743 .29938 L
.86872 .29952 L
.87008 .29959 L
.87145 .29954 L
.87223 .29945 L
.87296 .29932 L
.87427 .29897 L
Mistroke
.87547 .29848 L
.87686 .2977 L
.87818 .29673 L
.88061 .29429 L
.88286 .29121 L
.88796 .28141 L
.89928 .25196 L
.90198 .24531 L
.90483 .23919 L
.90727 .23494 L
.90867 .23297 L
.90994 .2315 L
.91127 .23032 L
.91252 .22954 L
.91385 .22907 L
.91459 .22898 L
.91529 .22899 L
.91644 .22924 L
.91771 .22983 L
.91903 .23078 L
.92028 .23199 L
.92309 .23568 L
.92566 .24003 L
.93147 .25147 L
.93366 .25562 L
.93601 .25942 L
.93736 .26118 L
.93859 .26245 L
.93982 .26335 L
.94098 .26383 L
.9422 .26392 L
.94348 .26353 L
.94458 .26279 L
.94579 .26154 L
.94709 .25969 L
.94848 .25714 L
.951 .25111 L
.97172 .17405 L
.97739 .15695 L
.98344 .14303 L
.98915 .13346 L
.99432 .12722 L
1 .12237 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`007?ooool6o`0008Sooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`00
0?oooooooooo03[ooooo1_l0001`ooooo`006?ooool5o`0000Gooooo1_l0001Jooooo`go00006ooo
ool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0>?ooool3o`0000Gooooo
1?l0001/ooooo`005oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05Gooooo0ol0
000<ooooo`?o00008oooool00ol0003oooooooooo`0fooooo`;o00003?ooool3o`0006Wooooo000F
ooooo`03o`000?oooooooooo013ooooo0_l0001Dooooo`03o`000?oooooooooo013ooooo0_l0000Q
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03oooool2o`0005;ooooo0_l0000C
ooooo`00:oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo01?ooooo0_l0000Ooooo
o`03o`000?oooooooooo03Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1>oooo
o`03o`000?oooooooooo01?ooooo000/ooooo`03o`000?oooooooooo04kooooo00?o0000oooooooo
ool05_ooool3o`0001cooooo0_l0000dooooo`03o`000?oooooooooo01Cooooo0_l0001>ooooo`03
o`000?oooooooooo01?ooooo000]ooooo`;o0000C_ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo04[ooooo00?o0000ooooooooool05?ooool002oooooo00?o0000ooooooooool0B_oo
ool00ol0003oooooooooo`0Jooooo`;o00006_ooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo01Sooooo0_l0001:ooooo`03o`000?oooooooooo01Cooooo000`ooooo`03o`000?oooooo
oooo04Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`16ooooo`03o`000?oooooo
oooo01Gooooo000aooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`14ooooo`03o`000?oooooooooo01Kooooo000aooooo`03o`000?oooooooooo04Ko
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool07_ooool2o`0004Cooooo00?o0000ooooooooool05_ooool003;ooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo043ooooo
00?o0000ooooooooool05oooool003?ooooo00?o0000ooooooooool0A?ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`0Qooooo`;o0000@?ooool00ol0003oooooooooo`0Gooooo`00<oooool00ol0003oooooooooo`13
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool04oooool2o`00033ooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo01Oooooo000doooo
o`03o`000?oooooooooo047ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo01Sooooo000eooooo`03o`000?oooooooooo043ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo01Sooooo000Eooooo`;o0000
00Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h05Oooool00ol0003oooooooooo`02
ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo
1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02Oooool00ol0003oooooooooo`0@ooooo`Co
000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP[ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Oooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^
kP?ooooo00?o0000ooooooooool05?ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07
ooooo`03o`000?oooooooooo017ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h06_ooool00ol0003oooooooooo`02o`000009oa0@4?ooooooooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^00kooooo000Fooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Fooooo`09o`000?ooooooooooooooool@413o^[ZjoooooomgMgOo<S8b00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02_ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00?o0000ooooooooool05?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`08ooooo`;o00004Oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05o`000?ooooooooooooooool000001?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko00000_ooool5o`0000?ooooo00Go410@oooooooo
oooooooooa0@400Booooo`Ko00001_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@
ooooooooool04Oooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooo
oooo410@00Sooooo00?o0000ooooooooool02?ooool6o`0000Gooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00[ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4002ooooo`03
o`000?oooooooooo01Kooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@
00[ooooo00?o0000ooooooooool04_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@
ooooooooool06?ooool6o`0000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`004oooool0
1?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000005oooool00ol0003ooooo
ooooo`03ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03
oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000002ooooo`03o`000?oooooooooo01Oooooo00?oV9RHob4Q8Oo^k^h00ooo
ool01Ol0003ooooooooooooooooo000000[ooooo00?o0000ooooooooool04Oooool00onYZJWo410@
ooooo`02ooooo`05o`000?ooooooooooooooool000006Oooool01_l0003oooooodA4A?oMgMgooooo
o`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`004oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000006?ooool01ol0003ooooooooooooooooo410@o`00
0?nj^[X00oooool01Ol0003ooooooooooooooooo000001kooooo00?oMgMgofIVI_ooool00_ooool0
1Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool06?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooooooooooo
ool000002oooool00ol0003oooooooooo`0?ooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000oooo
ooooooooooooo`00000Iooooo`06o`000?oooooogMgMoeEEEOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000000kooooo000Dooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooo
oooooa0@400Iooooo`06o`000?oooooooooooooooonj^[[o8B4Q0oooool01Ol@413ooooooooooooo
oooo410@01oooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Kooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41002oooool00ol0003oooooooooo`0@ooooo`;o00008_ooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41000_ooool00ol0003oooooooooo`0Iooooo`05o`000?oooooooooo
ooooool@41000oooool00ol@413oooooooooo`09ooooo`03o`000?oooooooooo013ooooo00?o^[Zj
ob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@01Wooooo00Ko0000ooooooooooooMgMg
olc<c?l00004ooooo`05oa0@4?ooooooooooooooool@41003_ooool001Cooooo00?ok^k^odA4A?l0
00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00Go0000oiRHV?oooooo^[Zjo`000003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02
ooooo`03o`000?oooooooooo01Gooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool00ol0003oooooooooo`0=ooooo`05oa0@4?nHV9SooooookZj^_l0
00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01Sooooo00Oo0000ooooooooooooooooonk^k_m4
A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`005Oooool00omgMgOo0000oooo
o`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06_ooool01Ol0003o410@o`000?l@413oZJVY00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00?o0000ooooooooool04_ooool00omEEEGoIVIVo`00
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo01oooooo00?oEEEEofIVI_l000001?ooool01oo^k^ko<S8bo`000?lb<S;ok^k^oooo
ool000006?ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`03o`000?oooooooooo00cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h06?ooool00ol0003oooooooooo`02ooooo`03ogMgMol0003ooooo00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`00>oooool00ol0003oooooooooo`0hooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Kooooo`00
??ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`0Looooo`00??ooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo02cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Looooo`00?Oooool0
0ol0003oooooooooo`0eooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`0Looooo`00?_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Looooo`005_ooooooo`00043o
00004oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`;o0000
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1?ooool2o`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`005_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool000001Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Aooooo`00?oooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Nooooo`00
?oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
:_ooool00ol0003oooooooooo`0Nooooo`00@?ooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Nooooo`00@?ooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`0Nooooo`00@?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`Co00008?ooool00ol0
003oooooooooo`0gooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool07oooool0047o
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000023ooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`0Hooooo`Co00002oooool00ol0003oooooooooo`0Ooooo
o`00@Oooool00ol0003oooooooooo`0Pooooo`?o00003?ooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo00cooooo0_l00005ooooo`05o`000?ooooooooooooooool000007oooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000:
ooooo`03o`000?oooooooooo01oooooo0011ooooo`03o`000?oooooooooo01oooooo0_l000000ooo
oooo0000o`00000:ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo01oooooo0011ooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool03oooool2o`0000_ooooo00?o0000ooooooooool0>_ooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Pooooo`00@_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00gooooo
00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo023o
oooo0012ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Pooooo`00@_ooool00ol0003oooooooooo`0?ooooo`?o00002_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`0;ooooo`05o`000?ooooooooooooooool000002Oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0looooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo027ooooo0012ooooo`03o`000?oooooooooo00kooooo0_l00002ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000[ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Qooooo`00@_ooool00ol0003ooooooooo
o`0>ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0:ooooo`04o`00
0?ooooooooooo`0000_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Qooooo`00
@_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`0:ooooo`;o000000?oooooo`000?ooool02oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0nooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`02o`0002?ooooo0013ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01?oo
ool2o`0000?ooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000003Sooooo
00?o0000ooooooooool02_ooool01?l0003oooooooooool0000<ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0:ooooo`Co00009?ooool004?ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`Co00003_ooool01?l0003ooooo
o`000?l0000hooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooo00003?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000012
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03?ooool2o`0002Gooooo0013oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06?ooool3o`0003Wooooo00?o0000oooo
ooooool02_ooool01?l0003oooooooooool0000=ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02Oooool01?l0003oooooo`000?l00012ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0<oooool004?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1D
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooool000003_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Wooooo0ol00013ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0<oooool004Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Doooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooool000003oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo04oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0doooo
o`00A?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05Gooooo00?o0000oooooooo
ool02_ooool00ol0003oooooo`00000?ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0DOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03Cooooo0014ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooo000000oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Aooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0=Oooool004Cooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo00Wooooo0ol0000?ooooo`;o00000ooo
ool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0=Ooo
ool004Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Fooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooool000004?ooool01?l0003oooooooooool0001Gooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0=_ooool004Cooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`1Fooooo`03o`000?oooooooooo00Wooooo0_l0000Booooo`?o0000F?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Kooooo0014ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`09ooooo`;o0000K_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo03Oooooo0015ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`09ooooo`;o0000Koooool2o`0000Go
oooo00?o0000ooooooooool0>?ooool004Gooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`1Fooooo`03o`000?oooooooooo00Wooooo0_l0001aooooo`Ko0000>_ooool004Gooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1Gooooo`Ko00001_ooool2o`000;7ooooo0015
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Eoooool01_l0003oV9RHob4Q8Oo^
k^koooooodA4A0Kooooo00?o0000ooooooooool0/?ooool004Gooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`1Gooooo`05o`000?ooooooV9RHob4Q8Oo^k^h01oooool3o`000;3ooooo
0015ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0F?ooool01Ol0003ooooooiRH
V?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0/?ooool004Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`1Iooooo`05o`000?ooooooooooogMgMomVIVH01_ooool00ol0003ooooo
ooooo`2`ooooo`00AOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Wooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo0016ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0FOooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo
0_l0002booooo`00A_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Wooooo00Go
0000oa0@4?l0003o8B4Qolc<c005ooooo`;o0000/_ooool004Kooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00Oooooo0_l0002booooo`00A_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool01_ooool2
o`000;;ooooo0016ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Foooool00ol0
003oooooooooo`06ooooo`?o0000/Oooool004Oooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`1Kooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool00000/_ooool004Oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooool00000/_ooool004Oooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`1Looooo`03o`000?oooooooooo00Gooooo00?o0000ooooool00000/_ooool004Oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo00Gooooo00?o0000
ooooool00000/_ooool004Sooooo00Go0000ooooooooooooooooo`00001Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooool00000/_ooool004Sooooo00Go0000ooooooooooooooooo`00001N
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool00000/_ooool004Sooooo00Co0000oooo
oooooooo0000Goooool00ol0003oooooooooo`05ooooo`03o`000?oooooo00000;;ooooo0018oooo
o`04o`000?ooooooooooo`00063ooooo00?o0000ooooooooool01?ooool00ol0003oooooo`00002b
ooooo`00BOooool00ol0003oooooo`00001Pooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_l0002aooooo`00BOooool3o`00063ooooo00?o0000ooooooooool00oooool01?l0003o
ooooooooool0002booooo`00[?ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`00
0;;ooooo002/ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000/_ooool00:co
oooo00?o0000ooooooooool00oooool01?l0003oooooooooool0002booooo`00[?ooool00ol0003o
ooooooooo`03ooooo`04o`000?ooooooooooo`000;;ooooo002]ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo0000/_ooool00:gooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool0002booooo`00[Oooool01Ol0003ooooooooooooooooo000000?ooooo0_l0002aoooo
o`00[Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0/?ooool00:go
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo0;3ooooo002^ooooo`03
o`000?oooooo000000Cooooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooool00000
1?ooool00ol0003oooooooooo`2`ooooo`00[?ooool2o`000003oa0@4?l0003ooooo00Cooooo00?o
0000ooooooooool0/?ooool00:gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2`
ooooo`00Z_ooool5o`0000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00CoA4A4omgMgOoo
oooo00001oooool3o`000;3ooooo002Zooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`2`ooooo`00
Zoooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0;3ooooo002/ooooo`03ogMgMol0
003ooooo00Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00:[ooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oo
oooooooo0;3ooooo002Zooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0/?oo
ool00:[ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000/?ooool00:[ooooo00Go0000
oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03oeEEEOn7QhOo
oooo00Sooooo00?o0000ooooooooool0/?ooool00:[ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0
003oooooooooo`2`ooooo`00Zoooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OlQ8B7o
V9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05oc8b<_nHV9SooooooiRH
V?lb<S801_ooool3o`000;3ooooo002Zooooo`05olc<c?l0003o0000o`000?o<c<`0^Oooool00:[o
oooo00Go410@okZj^_oooooo^[Zjoa0@402iooooo`00Z_ooool01Ol0003o^[Zjoooooonj^[[o0000
0;Wooooo002Zooooo`05ojVYZOl@413o0000oa0@4?nYZJT0^Oooool00?ooooooJOooool00;?ooooo
00?o0000okZj^_ooool0/_ooool00;?ooooo0_lb<S:cooooo`00Q?ooool2o`000006oa0@4?oooooo
oooooa0@4?l0003o410@6?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0J
ooooo`03o`000?o^k^kooooo00?ooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c01looooo`00QOooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l0000=ooooo`09ogMgMolb<S;o
oooooooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o
^[Zjonk^k_mgMgOo410@00Wooooo1_l0000;ooooo`03oeEEEOnYZJWooooo00?ooooo00Go8B4QoiRH
V?ooooooV9RHob4Q8@1looooo`00QOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01_ooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`0@ooooo`03o`000?oooooo
oooo01cooooo00?oZJVYoeEEEOooool00oooool01Ol0003ooooooooooooooooo000007cooooo0025
ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000gooooo00GoMgMgoc8b<_oooooo
ooooo`000003ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02oooool6o`0000co
oooo00?o8B4Qooooooooool00_ooool01Olb<S;oV9RHoooooonHV9So<S8b07cooooo0025ooooo`06
o`000?oMgMgo<S8boeEEEOoMgMgo00006Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go
0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo01gooooo00?oEEEEolc<c?ooool0
0_ooool01Oo<c<co0000o`000?l0003oc<c<07cooooo0025ooooo`06o`000?n7QhOoZJVYokZj^_mE
EEGo00006Oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol@413o0000o`000003o`0001cooooo00?oZJVYogMgMoooool00_ooool01Ol@413o^[Zjoooooonj
^[[o410@07cooooo0025ooooo`06o`000?lb<S;ooooooooooolb<S;o00006Oooool00ol0003ooooo
ooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool00ol0003oooooooooo`0Jooooo`05
oa0@4?oooooooooooooooolb<S800oooool01Ol0003o^[Zjoooooonj^[[o000007cooooo0024oooo
o`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool4o`0000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Booooo`03o`000?oooooooooo01[ooooo1Ol00003ooooo`05ojVYZOl@413o
0000oa0@4?nYZJT0O?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(80) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .11662 m
.00123 .11668 L
.00236 .11677 L
.00365 .11689 L
.00488 .11705 L
.00706 .11739 L
.00942 .11786 L
.01479 .11931 L
.01975 .12112 L
.02985 .12632 L
.04057 .13416 L
.05157 .14425 L
.06341 .15541 L
.06914 .1599 L
.07196 .1617 L
.07458 .16308 L
.07695 .16407 L
.07947 .16485 L
.08091 .16517 L
.08227 .16539 L
.08349 .16552 L
.08481 .1656 L
.08601 .16562 L
.08729 .16559 L
.0885 .16551 L
.08961 .16541 L
.0909 .16526 L
.09231 .16506 L
.09487 .16464 L
.09755 .16419 L
.09901 .16397 L
.10039 .16381 L
.10156 .16371 L
.10282 .16365 L
.1035 .16364 L
.10422 .16366 L
.1055 .16376 L
.10669 .16393 L
.10778 .16416 L
.10903 .16453 L
.11021 .16499 L
.11231 .1661 L
.11459 .16776 L
.1171 .17023 L
.11976 .17366 L
.12454 .18211 L
.1352 .2121 L
.14532 .24799 L
.14972 .26145 L
.15214 .26738 L
Mistroke
.15441 .27182 L
.15571 .27384 L
.15711 .2756 L
.15838 .27685 L
.15955 .27772 L
.16066 .27833 L
.16187 .27879 L
.16314 .27909 L
.16432 .27925 L
.16559 .27934 L
.16697 .27944 L
.16827 .27959 L
.16948 .27985 L
.17056 .28022 L
.17176 .28084 L
.17301 .28176 L
.17418 .28292 L
.17547 .28457 L
.17683 .28678 L
.17926 .29198 L
.18188 .29939 L
.18474 .30934 L
.19024 .33094 L
.19169 .33627 L
.19326 .34143 L
.19462 .34519 L
.19539 .34697 L
.19611 .34837 L
.19684 .34952 L
.19751 .35031 L
.19823 .35086 L
.19899 .35111 L
.20036 .35063 L
.20165 .34908 L
.2029 .34656 L
.20405 .34336 L
.20667 .33329 L
.21609 .27881 L
.22104 .25144 L
.22352 .24058 L
.22625 .23157 L
.2277 .2281 L
.2285 .22661 L
.22926 .22547 L
.22996 .22464 L
.23073 .22401 L
.23206 .22357 L
.23341 .22396 L
.23409 .22448 L
.23484 .2253 L
Mistroke
.23616 .22737 L
.2374 .23001 L
.24003 .23775 L
.24244 .24709 L
.24787 .27335 L
.25288 .29786 L
.25432 .3037 L
.25568 .30836 L
.2569 .31172 L
.25822 .31435 L
.25938 .31572 L
.26065 .31616 L
.26198 .31539 L
.26322 .31353 L
.26438 .31081 L
.26544 .30755 L
.26782 .2977 L
.27913 .22637 L
.2841 .19623 L
.28958 .16985 L
.292 .16065 L
.2946 .15227 L
.29931 .14068 L
.30194 .13589 L
.3047 .13187 L
.30729 .1289 L
.30964 .12674 L
.31225 .12486 L
.31504 .12336 L
.31762 .12235 L
.32006 .12168 L
.32144 .1214 L
.3229 .12117 L
.32415 .12102 L
.32552 .12089 L
.32629 .12084 L
.327 .12081 L
.32781 .12077 L
.32858 .12076 L
.32995 .12075 L
.33073 .12076 L
.33144 .12078 L
.3328 .12083 L
.33349 .12087 L
.33423 .12091 L
.3368 .12113 L
.33979 .12148 L
.34258 .12186 L
.35305 .1236 L
.3625 .12572 L
Mistroke
.37261 .12868 L
.37818 .13088 L
.38333 .13339 L
.38886 .13672 L
.39497 .14133 L
.40523 .1516 L
.41611 .16522 L
.4211 .17173 L
.42655 .17821 L
.4317 .18322 L
.43416 .1851 L
.43648 .18652 L
.43788 .18721 L
.43938 .1878 L
.44076 .18821 L
.44202 .18849 L
.44339 .18868 L
.44416 .18874 L
.44489 .18878 L
.44566 .18878 L
.44635 .18877 L
.44716 .18874 L
.44792 .18869 L
.44919 .18857 L
.45053 .18843 L
.45169 .1883 L
.45294 .18818 L
.45428 .18808 L
.45554 .18804 L
.45626 .18805 L
.45703 .1881 L
.4584 .18827 L
.45969 .18857 L
.46042 .18882 L
.4611 .18909 L
.46234 .18974 L
.46365 .19066 L
.46592 .19291 L
.46721 .19464 L
.46841 .19658 L
.47111 .20223 L
.47357 .20918 L
.47642 .21964 L
.47912 .23221 L
.4839 .26106 L
.48834 .29428 L
.49358 .33616 L
.49588 .35279 L
.4984 .36799 L
.49975 .37436 L
Mistroke
.501 .37903 L
.50232 .38251 L
.50307 .38379 L
.50374 .38453 L
.50448 .38488 L
.50517 .38478 L
.50591 .38421 L
.50671 .3831 L
.50805 .38014 L
.50881 .37789 L
.50952 .37545 L
.51456 .35182 L
.51998 .32399 L
.52256 .31342 L
.52495 .30603 L
.52616 .30328 L
.52745 .30105 L
.52819 .30011 L
.52888 .29943 L
.53018 .29867 L
.53132 .29853 L
.53252 .29884 L
.53354 .29943 L
.53467 .30036 L
.53718 .30321 L
.53953 .30622 L
.54085 .30779 L
.54225 .3092 L
.54345 .31009 L
.54477 .31065 L
.54551 .31073 L
.54618 .31065 L
.54693 .31038 L
.54771 .30988 L
.54903 .30852 L
.54978 .30745 L
.55048 .30627 L
.55311 .30018 L
.5555 .29265 L
.56086 .2712 L
.56566 .2509 L
.56819 .2414 L
.57087 .23306 L
.57321 .22764 L
.57455 .22545 L
.57579 .22403 L
.57694 .22329 L
.57798 .22309 L
.57919 .22346 L
.58034 .2244 L
Mistroke
.58164 .22619 L
.58287 .22855 L
.58414 .23171 L
.58554 .23598 L
.58847 .24752 L
.59117 .26077 L
.59651 .29103 L
.59884 .3039 L
.60137 .31595 L
.60256 .32054 L
.60383 .32448 L
.60491 .32698 L
.6061 .32874 L
.60721 .32937 L
.60841 .32892 L
.60954 .32742 L
.61058 .32513 L
.61177 .32146 L
.61288 .31711 L
.61539 .30428 L
.62045 .26986 L
.62602 .2284 L
.63127 .194 L
.63599 .16972 L
.64111 .15047 L
.6438 .14291 L
.64665 .13651 L
.64911 .13211 L
.65176 .12834 L
.65456 .12527 L
.65717 .12309 L
.65877 .12205 L
.66029 .12124 L
.66165 .12064 L
.66313 .12013 L
.66455 .11975 L
.66586 .11949 L
.66711 .11931 L
.66843 .1192 L
.66962 .11916 L
.67072 .11916 L
.67193 .11921 L
.67323 .11932 L
.67461 .11949 L
.67612 .11973 L
.67885 .12031 L
.68398 .12187 L
.69402 .12612 L
.7033 .13084 L
.71276 .13571 L
Mistroke
.72294 .14014 L
.72877 .14208 L
.73411 .1434 L
.74459 .14525 L
.74959 .14612 L
.75233 .1467 L
.75491 .14738 L
.75733 .14816 L
.75994 .14922 L
.76451 .15171 L
.76713 .15357 L
.77001 .15602 L
.77583 .16244 L
.78122 .17023 L
.78626 .17886 L
.79151 .18866 L
.79722 .19914 L
.80225 .20699 L
.8048 .21008 L
.80626 .21153 L
.80761 .21263 L
.80881 .21342 L
.81012 .21407 L
.81143 .21451 L
.81282 .21475 L
.81405 .21477 L
.81536 .21461 L
.8166 .2143 L
.81772 .21389 L
.82003 .21277 L
.82254 .21124 L
.82709 .20832 L
.82835 .20763 L
.82956 .20708 L
.83094 .20662 L
.83221 .20639 L
.8334 .20638 L
.83451 .20657 L
.83572 .20702 L
.83701 .20781 L
.83775 .20842 L
.83843 .20908 L
.83996 .21097 L
.84132 .21311 L
.84274 .21588 L
.84522 .22199 L
.84794 .23063 L
.85949 .28517 L
.86215 .2984 L
.86497 .31049 L
Mistroke
.86737 .31828 L
.86874 .32141 L
.87002 .32339 L
.87129 .32438 L
.87245 .32444 L
.87373 .32357 L
.87507 .32163 L
.87643 .31866 L
.87769 .31508 L
.88056 .30455 L
.88569 .28118 L
.89053 .26019 L
.8932 .2512 L
.89471 .24727 L
.8961 .24447 L
.89727 .24275 L
.89856 .24155 L
.8999 .2411 L
.90116 .24142 L
.90186 .2419 L
.90262 .24268 L
.90335 .24366 L
.90402 .24476 L
.90663 .25085 L
.90812 .2555 L
.90947 .26034 L
.9125 .27285 L
.91764 .29577 L
.92045 .30648 L
.92182 .31062 L
.92307 .31359 L
.92422 .31557 L
.9253 .3167 L
.92645 .31707 L
.9277 .31647 L
.92898 .31477 L
.93033 .31177 L
.93149 .30828 L
.93277 .30349 L
.93561 .28976 L
.93821 .27438 L
.94407 .23561 L
.94919 .20347 L
.95465 .17542 L
.96007 .15474 L
.96499 .14141 L
.96736 .1365 L
.96993 .13211 L
.97458 .12612 L
.97721 .12362 L
Mistroke
.98009 .12146 L
.9831 .11974 L
.98591 .11855 L
.98855 .11774 L
.99095 .11722 L
.99227 .117 L
.99372 .11682 L
.99508 .1167 L
.99634 .11663 L
.99724 .1166 L
.99808 .11659 L
.999 .1166 L
1 .11662 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool001Kooooo1?l0002@ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`2Hooooo`Go00004oooool001[ooooo1?l0001Nooooo`Oo0000<_ooool00ol0003ooooooooo
o`0`ooooo`Oo0000Goooool2o`0001Sooooo000Nooooo`03o`000?oooooooooo05Wooooo0_l00007
ooooo`Ko0000;?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Gooooo0ol0001K
ooooo`03o`000?oooooooooo01Sooooo000Oooooo`;o0000Eoooool2o`0000oooooo0ol0000Yoooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool02Oooool4o`0005Kooooo00?o0000oooo
ooooool06Oooool0027ooooo0_l0001Eooooo`03o`000?oooooooooo017ooooo1?l0000Uooooo`;o
0000;_ooool00ol0003oooooooooo`0>ooooo`;o0000Doooool00ol0003oooooooooo`0Jooooo`00
8oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
Coooool00ol0003oooooooooo`0Kooooo`008oooool00ol0003oooooooooo`1@ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo01;ooooo0ol0001>ooooo`03o`000?oooooooooo01_ooooo000Tooooo`03o`000?oooooo
oooo04oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool05Oooool2o`0004cooooo00?o0000ooooooooool06oooool0
02Gooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Kooooo`;o00008?ooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo01Sooooo1?l00017ooooo`03o`000?oooooooooo
01cooooo000Vooooo`;o0000COooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Looooo`Co0000@oooool00ol0003o
ooooooooo`0Looooo`00:?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo027ooooo
0ol0000oooooo`03o`000?oooooooooo01gooooo000Yooooo`03o`000?oooooooooo04Oooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo01gooooo000Z
ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0K
ooooo`;o0000:oooool00ol0003oooooooooo`0Uooooo`;o0000>oooool00ol0003oooooooooo`0N
ooooo`00:oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`0Nooooo`00;?ooool2o`0004Gooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo01kooooo000Eooooo`;o0000
00Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h03Oooool=o`000005oiRHV?l@413o
0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo1Ol00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01?ooool00ol0003oooooooooo`0Eooooo`Co000000So410@oooooooo
ooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0Oooooo`Co000000Go410@ooooooooooook^k^oc8b<P02o`000003onk^k_oooooooooo01Sooooo
1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00ol0003oooooooooo`0Eooooo`05
oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Gooooo00?o0000
ooooooooool01Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00ko
oooo000Fooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Iooooo`;o
000000Co^[ZjoooooomgMgOo<S8b0oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9So0000oiRHV?mgMgL06_ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`04ooooo`03o`000?oooooooooo01Cooooo00Go410@okZj^_ooooooMgMg
oc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`002oooool6o`0000;o
oooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41004_ooool6o`0000?ooooo00Co0000oooo
oooooooo00000oooool01Ol@413ooooooooooooooooo410@01?ooooo1_l00003ooooo`03oiRHV?lQ
8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`03o`000?oooooooooo00gooooo
1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4005ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05
oa0@4?oooooo0000ooooool@41006oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?oooooooooo
ooooool@41001?ooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool@41000ooo
ool00ol@413oooooooooo`0Booooo`03o`000?oooooooooo00Cooooo1Ol00003ooooo`05oa0@4?oo
ooooooooooooool@41003_ooool001?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000001cooooo00?o0000ojVYZOl@41000oooool01Ol0003ooooooooooooooooo0000
01gooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001Ooo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00_oo
ool01Ol0003oooooo`000?oooooo000001cooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooo
oooooooooooo000000Cooooo00?o0000ooooooooool05oooool00onYZJWo410@ooooo`02ooooo`05
o`000?ooooooooooooooool000005?ooool00ol0003oooooooooo`04ooooo`04odA4A?oMgMgooooo
o`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`004oooool01?oMgMgoEEEEooooool0
0004ooooo`05o`000?ooooooooooooooool000007?ooool2o`000005okZj^_ooooooooooooooool0
00000oooool00ol0003oooooooooo`0Looooo`03ogMgMomVIVKooooo00;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooool0003oooooo`00000Mooooo`03ogMgMomV
IVKooooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo01Gooooo
00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000001Cooooo00?o0000oooooooo
ool01?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool0
01Cooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@01gooooo00?o0000
ob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooo
oa0@4003ooooo`04oa0@4?ooooooooooo`0001_ooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@00Oooooo00?o0000ooooooooool05?ooool2o`0002;ooooo00?o0000oooo
ooooool00_ooool01Ol@413oooooo`000?oooooo410@01kooooo00Go0000oooooooooooooooooa0@
4003ooooo`03oa0@4?oooooooooo00Cooooo00?o0000ooooooooool05Oooool00onj^[[o8B4Qoooo
o`02ooooo`05oa0@4?ooooooooooooooool@41005?ooool00ol0003oooooooooo`05ooooo`03ogMg
Moo<c<co000000Cooooo00Go410@oooooooooooooooooa0@400>ooooo`005?ooool00oo^k^koA4A4
o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool00ol@413oV9RHooooo`02o`0000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHo`000?nHV9SoMgMg01[o
oooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool0
0ol0003oooooooooo`0Booooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg01Cooooo00?o0000ooooooooool01Oooool00oo^k^koA4A4o`000004ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03_ooool001Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01[ooooo00GoZJVYoa0@4?l0003o0000ojVYZ@03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h06oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP02ooooo`03o`000?oooooooooo01Oooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Wooooo0_l0000Cooooo`03o`000?oooooooooo01oooooo00?oEEEEofIVI_l0
00001?ooool01Oo^k^ko0000o`000?lb<S;ok^k^01[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01oooool00ol0003oooooooooo`0Aooooo`05ojVYZOl@
413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01?ooooo00?o0000oooooooo
ool01oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool003ko
oooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0^ooooo`So00002oooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`0Pooooo`00?_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Pooooo`00?oooool00ol0003ooooooooo
o`0^ooooo`03o`000?oooooooooo03Oooooo0_l00009ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo023ooooo000o
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo023ooooo000oooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool0>Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool0<_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo027ooooo000Foooooooo
0000@?l0000Cooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`;o00001_ooool6o`00
00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool04Oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04
ooooo`;o00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l00006
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`04o`000?oooooo0000o`0000?ooooo0_l00004ooooo`04o`000?ooooooooooo`0000Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo
0011ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0>_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=_ooool4o`0000Oooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0Rooooo`00@Oooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0R
ooooo`00@_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo04?ooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Rooooo`00@_ooool00ol0003oooooooooo`0Jooooo`;o
00003_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool05Oooool2o`0000kooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo02;ooooo0012ooooo`03o`000?oooooooooo01Wooooo0_l000000ooooooo0000
ooooo`0<ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Dooooo`;o000000?oooooo`000?ooool03?ooool00ol0003oooooooooo`14ooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool08_ooool004;ooooo00?o0000ooooooooool06Ooo
ool01?l0003oooooooooool0000=ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Dooooo`04o`000?ooooooooooo`0000gooooo00?o0000oooooooo
ool0A?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02?ooooo0013ooooo`03o`00
0?oooooooooo01Sooooo00Co0000oooooooooooo00003Oooool00ol0003oooooooooo`0looooo`03
o`000?oooooooooo00Cooooo0_l0000Dooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool08oooool004?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo04Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Sooooo`00@ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0AOoo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02?ooooo0013ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`16ooooo`03o`000?oooooo
oooo00_ooooo0ol0000<ooooo`03o`000?oooooooooo02?ooooo0014ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo
00_ooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`0Sooooo`00A?ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0A_ooool00ol0
003oooooooooo`0;ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool09?ooool0
04Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
04Kooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000
ooooooooool09?ooool004Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo04Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09?ooool004Gooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0@?ooool00ol0003oooooooooo`02ooooo`;o00004_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`00
AOooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
B?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Tooooo`00AOooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`10ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`00A_ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`10ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0B?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Uooooo`00Aoooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Uooooo`00Aoooool2o`0001;o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Go
oooo0018ooooo`;o00004?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0@Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool09Oooool004Wooooo1Ol0000<ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`12ooooo`05o`000?ooooooooooooooool00000
4_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
BOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Uooooo`00COooool2o`0000_ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04;ooooo00Co0000oooooooooooooooo
0_l0000@ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`19ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo02Gooooo001>ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04;ooooo00Go
0000ooooooooooooooooo`00000Aooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Gooooo001>ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo04;ooooo00Go0000ooooooooooooooooo`00000Aooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Gooooo
001?ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo04?ooooo00Go0000ooooooooooooooooo`00000Aooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1:ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo02Gooooo001?ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04?ooooo00Go0000oooooooooooooooo
o`00000Aooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo02Gooooo001@ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04?ooooo00Go
0000ooooooooooooooooo`000008ooooo`?o00001Oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Vooooo`00D?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00Go0000oooooooooooooooo
o`00000nooooo`Go00000_ooool01Ol0003ooooooooooooooooo000000Oooooo0_l00002ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo04_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`05
o`000?ooooooooooooooool00000:?ooool0057ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0;ooooo`04o`000?ooooooooooo`0003oooooo00GoV9RHob4Q8Oo^k^koooooodA4A003
ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1;ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000002So
oooo001Aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool01?l0003ooooo
ooooool00010ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00?o0000ooooooooool00ol00005ooooo`03
o`000?oooooooooo00;ooooo1?l0000>ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0C?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooo
oooo0000:Oooool0057ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`04
o`000?ooooooooooo`00047ooooo00?oV9RHob4Q8Oo^k^h00oooool01?l0003oooooooooool00006
ooooo`03o`000?oooooooooo00Cooooo0_l0000@ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0C?ooool01Ol0003ooooooooooooooooo000000gooooo00Co0000oooooooooooo0000
:Oooool0057ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`;o0000@ooo
ool00omgMgOoIVIVooooo`02ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0
5_ooool01Ol0003ooooooooooooooooo000004oooooo00Go0000ooooooooooooooooo`00000>oooo
o`;o0000:_ooool0057ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Cooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01Kooooo00Go0000ooooooooooooooooo`00001@ooooo`04o`000?ooooooooooo`0000kooooo0_l0
000Zooooo`00D_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04oooooo00Go0000
okZj^_ooooooV9RHoa0@4003ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0
6?ooool00ol0003oooooo`00001Aooooo`03o`000?oooooo000003_ooooo001Booooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0Coooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo000005;o
oooo0_l0000kooooo`00D_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05Wooooo
00?o0000ooooool000001Oooool00ol0003oooooooooo`0Hooooo`?o0000Soooool005;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooo000000Gooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`2>ooooo`00D_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo05Wooooo00Co0000ooooool0003o00001?ooool00ol0003ooooooooo
o`2Zooooo`00Doooool01Ol0003ooooooooooooooooo000005_ooooo00?o0000ooooool000001Ooo
ool00ol0003oooooooooo`2Zooooo`00Doooool01Ol0003ooooooooooooooooo000005_ooooo00?o
0000ooooool000001?ooool00ol0003oooooooooo`2[ooooo`00Doooool01Ol0003ooooooooooooo
oooo000005_ooooo00?o0000ooooool000001?ooool00ol0003oooooooooo`2[ooooo`00E?ooool0
0ol0003oooooo`00001Mooooo`;o00001?ooool00ol0003oooooooooo`2[ooooo`00E?ooool3o`00
05gooooo0_l00004ooooo`03o`000?oooooooooo0:_ooooo001Eooooo`03o`000?oooooooooo05co
oooo0_l00004ooooo`03o`000?oooooooooo0:_ooooo002dooooo`;o00001?ooool00ol0003ooooo
ooooo`2[ooooo`00]?ooool2o`0000Cooooo00?o0000ooooooooool0Zoooool00;Cooooo0ol00002
ooooo`03o`000?oooooooooo0:cooooo002dooooo`;o00000oooool00ol0003oooooooooo`2/oooo
o`00]?ooool2o`0000?ooooo00?o0000ooooooooool0[?ooool00;Cooooo0_l00002ooooo`03o`00
0?oooooooooo0:gooooo002eooooo`04o`000?ooooooooooo`000:oooooo002eooooo`04o`000?oo
ooooooooo`000:oooooo002eooooo`03o`000?oooooo00000;3ooooo002eooooo`?o0000/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00[?ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0/?ooool00:go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool5o`0000Kooooo
00?o0000ooooooooool0/?ooool00:[ooooo00CoA4A4omgMgOoooooo00001oooool3o`000;3ooooo
002Zooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0/?ooool00:_ooooo00?o
MgMgolc<c?l000001oooool00ol0003oooooooooo`2`ooooo`00Zoooool00oo^k^koA4A4o`000007
ooooo`03o`000?oooooooooo0;3ooooo002/ooooo`03ogMgMol0003ooooo00Kooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:[o
oooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05
oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000oiRHV?oo
ooooV9RHob4Q8@06ooooo`?o0000/?ooool00:[ooooo00Go0000oeEEEOl0003o410@olc<c006oooo
o`03o`000?oooooooooo0;3ooooo002Zooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000oooooooo
ool0/?ooool00:[ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`2`ooooo`00Zooo
ool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0
1_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo
00?o0000ooooooooool0/?ooool00:[ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo0;3ooooo002Zooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`000;3ooooo
002Zooooo`05olc<c?l0003o0000o`000?o<c<`0^Oooool00:[ooooo00Go410@okZj^_oooooo^[Zj
oa0@402iooooo`00Z_ooool01Ol0003o^[Zjoooooonj^[[o00000;Wooooo002Zooooo`05ojVYZOl@
413o0000oa0@4?nYZJT0^Oooool00?ooooooJOooool00;?ooooo00?o0000okZj^_ooool0/_ooool0
0;?ooooo0_lb<S:cooooo`00Q?ooool2o`000006oa0@4?oooooooooooa0@4?l0003o410@6?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`03ohN7
Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`05olc<c?lQ8B7o0000ob4Q
8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07cooooo0025ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01oooool6o`0000gooooo00WoMgMgoc8b<_ooooooooooogMgMonH
V9SooooooiRHV?mgMgL00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@
41002Oooool6o`0000Wooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0O?ooool008Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Koooo
o`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool04?ooool00ol0003oooooooooo`0J
ooooo`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@07cooooo
0025ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000gooooo00GoMgMgoc8b<_oo
ooooooooo`000003ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02oooool6o`00
00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P03ooooo`05o`000?ooooooooooooooool00000O?oo
ool008Gooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Iooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`00_ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool06_ooool01Oo<
c<co0000o`000?l0003oc<c<00?ooooo00Go0000ooooooooooooooooo`00001looooo`00QOooool0
1_l0003oQhN7ojVYZOnj^[[oEEEEo`0001Wooooo00?o0000ooooooooool01?ooool01Ol@413ooooo
oooooooooooo410@013ooooo00?o410@o`000?l000000ol0000Iooooo`05oa0@4?nj^[[ooooookZj
^_l@41000oooool01Ol@413ooooooooooooooooo410@07cooooo0025ooooo`06o`000?lb<S;ooooo
oooooolb<S;o00006Oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
4_ooool00ol0003oooooooooo`0Jooooo`05o`000?nj^[[ooooookZj^_l000000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg07cooooo0024ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@
41006?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Booooo`03o`000?oooooooooo
01[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0O?oo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(82) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .13307 m
.00942 .14117 L
.01975 .15048 L
.02496 .15467 L
.02782 .15656 L
.03053 .15803 L
.03305 .1591 L
.03438 .15955 L
.03578 .15993 L
.03697 .16018 L
.03827 .16038 L
.03946 .16048 L
.04057 .16052 L
.04125 .1605 L
.04198 .16046 L
.0433 .16032 L
.0441 .16019 L
.04486 .16003 L
.04627 .15966 L
.04888 .15875 L
.0517 .15747 L
.06188 .15167 L
.06769 .1485 L
.07061 .14722 L
.07227 .14665 L
.07301 .14644 L
.07382 .14624 L
.07456 .14609 L
.07525 .14598 L
.0766 .14586 L
.07782 .14585 L
.07912 .14596 L
.0798 .14607 L
.08052 .14622 L
.08183 .1466 L
.08338 .14723 L
.08481 .148 L
.08742 .14989 L
.08979 .15219 L
.09252 .15561 L
.0951 .15966 L
.0997 .16886 L
.10468 .18153 L
.11503 .2127 L
.11786 .22074 L
.12091 .22815 L
.12239 .23111 L
.12379 .23346 L
.12504 .23516 L
.12641 .23653 L
Mistroke
.1271 .23701 L
.12783 .23739 L
.12917 .23767 L
.13047 .23746 L
.13166 .23685 L
.13296 .23575 L
.13438 .23404 L
.13724 .22921 L
.14244 .21705 L
.14728 .20422 L
.14991 .19762 L
.15277 .19132 L
.15408 .18885 L
.15546 .18659 L
.15666 .18496 L
.15795 .18358 L
.15872 .18296 L
.15942 .18252 L
.1608 .18206 L
.16153 .18204 L
.16233 .1822 L
.16316 .18257 L
.16393 .18312 L
.16532 .18461 L
.16657 .18653 L
.16801 .18947 L
.16938 .19298 L
.17166 .20055 L
.17415 .21132 L
.17868 .23786 L
.18389 .27785 L
.18865 .31705 L
.19141 .33697 L
.19292 .34601 L
.19433 .35291 L
.19554 .35738 L
.19683 .36065 L
.19754 .36171 L
.19827 .36229 L
.1996 .36192 L
.20082 .36 L
.20212 .35636 L
.20336 .35153 L
.20448 .34609 L
.20982 .31104 L
.21498 .27476 L
.2177 .25919 L
.21918 .25231 L
.22058 .24704 L
.22179 .24345 L
Mistroke
.22309 .24063 L
.22383 .23952 L
.22454 .23881 L
.22586 .23837 L
.22707 .239 L
.22819 .24047 L
.22942 .24306 L
.23073 .24693 L
.23223 .25272 L
.2336 .25927 L
.23671 .27793 L
.24233 .3199 L
.24498 .33914 L
.24744 .35405 L
.24869 .35988 L
.25002 .36457 L
.25078 .36647 L
.2515 .3677 L
.25284 .36849 L
.25404 .3675 L
.25533 .36464 L
.25655 .36029 L
.25767 .35497 L
.26026 .33836 L
.26299 .31598 L
.26857 .26417 L
.27376 .22026 L
.27823 .19061 L
.28301 .16734 L
.28573 .15736 L
.2883 .14982 L
.29062 .14437 L
.29311 .13973 L
.29562 .1361 L
.29798 .13343 L
.30077 .13096 L
.30333 .12919 L
.30598 .12774 L
.30738 .12712 L
.30888 .12658 L
.31031 .12615 L
.31161 .12583 L
.31291 .12559 L
.31414 .12541 L
.31527 .12529 L
.3165 .12518 L
.31779 .12511 L
.319 .12506 L
.32013 .12502 L
.32115 .125 L
Mistroke
.32234 .12498 L
.32346 .12498 L
.32468 .12498 L
.32597 .12501 L
.32707 .12506 L
.32828 .12514 L
.32958 .12525 L
.33099 .12542 L
.33352 .12584 L
.33618 .12643 L
.33902 .12716 L
.34412 .12873 L
.34725 .12993 L
.35019 .13133 L
.3557 .13475 L
.36583 .14338 L
.37679 .15639 L
.38761 .17029 L
.3929 .17606 L
.39521 .17814 L
.39772 .17997 L
.39908 .18073 L
.40033 .18128 L
.40153 .18167 L
.40281 .18192 L
.40414 .18203 L
.4054 .18197 L
.40677 .18175 L
.40755 .18156 L
.40826 .18134 L
.41095 .18016 L
.41248 .17926 L
.4139 .1783 L
.41983 .173 L
.42513 .16717 L
.43088 .16113 L
.43351 .15885 L
.4363 .1569 L
.43868 .15566 L
.44004 .15515 L
.4413 .15481 L
.44251 .15464 L
.44382 .15462 L
.44507 .15479 L
.44622 .15512 L
.44736 .15563 L
.44839 .15626 L
.44959 .15719 L
.45071 .15828 L
.45324 .16152 L
Mistroke
.45557 .16548 L
.46082 .17799 L
.47119 .217 L
.47689 .24292 L
.4797 .25454 L
.48229 .26361 L
.48473 .27011 L
.48596 .27253 L
.48732 .27448 L
.48867 .27564 L
.48943 .27594 L
.49013 .276 L
.49142 .27556 L
.49277 .27436 L
.49392 .27278 L
.49514 .27057 L
.49734 .26539 L
.50232 .25003 L
.50483 .24195 L
.50749 .23442 L
.50888 .23121 L
.50961 .22977 L
.5104 .22844 L
.51179 .22671 L
.51309 .22587 L
.51439 .22582 L
.51513 .22618 L
.51581 .22676 L
.51707 .22851 L
.5184 .23138 L
.51958 .23485 L
.5207 .23894 L
.52324 .25146 L
.52556 .26688 L
.52801 .28717 L
.53238 .33137 L
.53481 .35753 L
.53744 .38381 L
.53865 .39424 L
.53993 .40369 L
.54103 .41021 L
.54223 .41553 L
.54354 .4189 L
.54427 .41965 L
.54494 .4196 L
.54624 .41753 L
.54747 .41318 L
.54865 .40697 L
.54975 .39958 L
.55223 .37805 L
Mistroke
.55784 .31718 L
.56028 .29129 L
.56293 .26686 L
.56543 .24832 L
.56653 .24175 L
.56773 .23567 L
.56879 .23128 L
.56993 .22759 L
.57113 .22482 L
.57226 .22326 L
.57354 .22268 L
.57426 .2229 L
.57493 .22346 L
.57616 .22537 L
.57746 .22863 L
.57862 .2326 L
.57971 .23721 L
.5822 .25078 L
.59253 .33443 L
.59504 .35276 L
.59642 .36082 L
.59772 .36675 L
.59846 .36931 L
.59926 .37138 L
.59999 .3726 L
.60066 .37315 L
.60199 .37259 L
.60266 .37147 L
.6034 .3696 L
.6047 .36475 L
.60593 .35841 L
.60824 .34254 L
.61344 .29477 L
.61828 .24771 L
.62283 .21016 L
.62538 .19317 L
.62813 .17799 L
.63293 .15843 L
.63565 .15061 L
.63853 .14447 L
.64098 .14068 L
.64237 .13903 L
.64367 .13774 L
.64489 .13675 L
.6462 .13587 L
.6473 .13528 L
.6485 .13474 L
.64981 .13429 L
.65119 .13394 L
.65247 .13372 L
Mistroke
.65367 .1336 L
.65488 .13354 L
.65602 .13356 L
.65704 .13362 L
.65816 .13374 L
.65938 .13392 L
.66067 .13416 L
.663 .1347 L
.67378 .13742 L
.67674 .13803 L
.67986 .1386 L
.68256 .13901 L
.68405 .13918 L
.68546 .13932 L
.68676 .13941 L
.6875 .13944 L
.68819 .13947 L
.68939 .13949 L
.69068 .13947 L
.69187 .13944 L
.69299 .13938 L
.69422 .13931 L
.69555 .1392 L
.70129 .13864 L
.70663 .13806 L
.70913 .1378 L
.71148 .13759 L
.71279 .1375 L
.71352 .13746 L
.7142 .13743 L
.7154 .13741 L
.71667 .13742 L
.71797 .13747 L
.7187 .13752 L
.71937 .13759 L
.72067 .13774 L
.7219 .13795 L
.72333 .13825 L
.72465 .1386 L
.72765 .13964 L
.73055 .14103 L
.73328 .14272 L
.73838 .14703 L
.74387 .15354 L
.7498 .16274 L
.76064 .18348 L
.76594 .19351 L
.77076 .20094 L
.77201 .20245 L
.77338 .20386 L
Mistroke
.77455 .20487 L
.77585 .20574 L
.77723 .20637 L
.77798 .20659 L
.77869 .20672 L
.77995 .20674 L
.78131 .20648 L
.78204 .20621 L
.78272 .2059 L
.78425 .20492 L
.78575 .20364 L
.78735 .20195 L
.79288 .19397 L
.80365 .17508 L
.8066 .17064 L
.80973 .16681 L
.81101 .16554 L
.81239 .16441 L
.81318 .16388 L
.81391 .16347 L
.81465 .16313 L
.81532 .16289 L
.81663 .16264 L
.81734 .16262 L
.81802 .16268 L
.81922 .163 L
.82052 .16365 L
.8212 .16413 L
.82196 .16476 L
.82347 .16641 L
.82487 .1684 L
.82618 .17068 L
.82879 .17647 L
.83116 .18326 L
.83649 .20395 L
.84624 .25717 L
.84882 .27173 L
.85158 .28569 L
.85292 .29144 L
.8542 .29612 L
.85535 .29962 L
.85659 .30249 L
.85793 .30453 L
.85917 .30538 L
.85993 .30539 L
.86065 .30506 L
.86199 .30356 L
.86271 .30228 L
.86347 .30058 L
.86484 .29674 L
Mistroke
.86793 .28479 L
.87341 .25715 L
.87841 .23207 L
.88085 .22189 L
.88215 .21734 L
.88352 .21324 L
.88471 .21032 L
.88603 .20785 L
.88723 .20632 L
.88836 .20553 L
.88966 .20543 L
.89103 .20629 L
.89221 .20784 L
.89349 .21041 L
.89488 .21423 L
.89636 .21954 L
.89902 .23236 L
.90151 .24801 L
.90421 .26857 L
.90911 .31175 L
.91353 .34856 L
.9148 .35709 L
.91601 .36388 L
.91709 .3687 L
.91827 .37246 L
.91956 .37462 L
.92094 .37461 L
.92223 .37239 L
.92341 .36856 L
.9246 .36301 L
.92588 .35529 L
.92821 .33742 L
.93914 .23138 L
.94474 .18894 L
.94756 .17278 L
.95065 .15861 L
.9533 .14909 L
.95613 .14117 L
.9588 .13551 L
.96123 .1316 L
.96346 .12886 L
.96592 .12657 L
.96715 .12566 L
.96848 .12483 L
.96963 .12423 L
.97089 .1237 L
.97207 .1233 L
.97316 .12302 L
.97431 .12282 L
.97555 .1227 L
Mistroke
.9767 .12267 L
.97778 .12271 L
.97876 .12281 L
.97981 .12297 L
.98107 .12322 L
.98225 .12352 L
.98492 .12437 L
.99032 .12671 L
.99499 .12942 L
1 .13307 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo09;ooooo1ol0000G
ooooo`00Moooool<o`0003;ooooo00?o0000ooooooooool0TOooool2o`0000Kooooo00?o0000oooo
ooooool05?ooool007Gooooo0_l0000<ooooo`;o0000<?ooool2o`00097ooooo00?o0000oooooooo
ool01oooool2o`0001Cooooo000Fooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0
3Oooool2o`0002kooooo00?o0000ooooooooool0;Oooool4o`0005oooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Aooooo`005oooool00ol0003oooooooooo`1Jooooo`03o`000?oo
oooooooo013ooooo0_l0000/ooooo`03o`000?oooooooooo02_ooooo0ol00003ooooo`?o00003Ooo
ool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo01kooooo000Hooooo`03o`000?oooooo
oooo05Sooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo02[ooooo0_l00008oooooa;o0000BOooool00ol0003oooooooooo`0Nooooo`006Oooool00ol0
003oooooooooo`1Gooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo01Wooooo0_l00016ooooo`03o`000?oooooooooo
01oooooo000Jooooo`03o`000?oooooooooo013ooooo1?l00011ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Oooooo`006oooool00ol0003ooooo
ooooo`0<ooooo`?o00000oooool3o`0003kooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`11ooooo`03o`000?oooooooooo023ooooo000Looooo`;o00002_ooool2o`0000Sooooo00?o
0000ooooooooool0??ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo043ooooo00?o
0000ooooooooool08?ooool001kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0A
ooooo`Co00004?ooool2o`0002Wooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo027ooooo000Oooooo`;o00001?ooool2o`0000cooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00oooooo0_l00003oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo03kooooo00?o0000ooooooooool08Oooool0027ooooo1?l0000?ooooo`03
o`000?oooooooooo03[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Qooooo`00
5Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^01Cooooo00?o0000
ooooooooool00oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0Kooooo`Go00000oooool01oo^k^ko<S8bo`000?lb<S;ok^k^ooooool000006_ooool5o`00
00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0Oooooo`Co000000Co410@ooooooooooook^k^0_l0
00000olb<S;ok^k^ooooo`0Iooooo`Go00000_ooool01_l0003ok^k^oc8b<_l0003o<S8bonk^kPko
oooo1?l00009ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01;ooooo00?o0000ooooooooool02?ooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^00kooooo000Fooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Eooooo`03o`000?oooooooooo00;ooooo00Go410@okZj^_ooooooMgMgoc8b<P03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL06oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Oo
MgMgoiRHV?ooooooV9RHogMgMooooooo000001cooooo00[o0000oooooooooooo0000oooooomgMgOo
V9RHoooooonHV9SoMgMg1_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05ogMgMol0003ooooooiRHV?mg
MgL06_ooool01OnHV9So8B4Qonk^k_ooooooA4A400;ooooo00Ko0000ogMgMonHV9SooooooiRHV?mg
MgL=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool01Ol@413o^[Zjoooo
oomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Aooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko
00000_ooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Booooo`Ko00001_ooool01Ol0
003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool04Oooool6o`0000?ooooo00?oV9RH
ob4Q8Oo^k^h01?ooool01ol@413ooooooooooooooooo410@ooooool000004Oooool6o`0000Gooooo
00Ko0000ooooooooooooooooo`000?l@4103ooooo`03oa0@4?oooooooooo00?ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo410@01_ooooo00?oV9RHob4Q8Oo^k^h01?ooool0
1Ol0003ooooooooooooooooo410@00cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`09ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0?ooooo`03o`00
0?oooooooooo00Oooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41003_ooool001?ooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000001Gooooo00?o0000oooo
ooooool01Oooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool0
0onHV9So8B4Qonk^kP03ooooo`07o`000?ooooooooooooooool0003oooooo`00000Looooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`00000Looooo`03oiRHV?lQ8B7ok^k^00?ooooo0_l00002oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08oooo
o`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Aooooo`03o`000?oooooo
oooo00Oooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000000kooooo
000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000Fooooo`03
o`000?oooooooooo00?ooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo0000
01kooooo00?oMgMgofIVI_ooool00_ooool01?l0003oooooooooooooool2o`0001gooooo00?o0000
ooooooooool00_ooool3o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000001gooooo00?oMgMgofIVI_ooool00_ooool2o`0000;ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo0000017ooooo00?o0000ooooooooool0
1oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool001Co
oooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@01Kooooo00?o0000oooo
ooooool01?ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41007oooool0
1Ol0003ooooooooooooooooo410@00?ooooo00?o410@o`000?ooool07?ooool00ol0003ooooooooo
o`02ooooo`06oa0@4?oooooo0000o`000?l@413ooooo0_l0000>ooooo`03o`000?oooooooooo00[o
oooo0_l0000Rooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooooa0@400Noooo
o`09o`000?ooooooooooooooool@413oooooo`000?oooooo410@00_ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`07ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Aooooo`03o`000?oooooooooo00Sooooo00?oMgMgolc<c?l000001?ooool01Ol@413o
oooooooooooooooo410@00kooooo000Dooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0Gooooo`08o`000?oooooooooooa0@4?nHV9SooooookZj^_l00003ooooo`06ogMg
MonHV9SooooooiRHV?mgMgOooooo0ol0000Gooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool0
1_mgMgOoV9RHoooooonHV9SoMgMgo`0001gooooo00?o0000ooooooooool00_ooool01?mgMgOoV9RH
oooooonHV9P2o`00013ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo00;ooooo00Go0000oiRHV?ooooooV9RHogMgM`0Jooooo`05o`000?nj^[[ooooo
oiRHV?l@41000oooool01OmgMgOoV9RHooooool0003oMgMg00_ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`04ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RH
oooooonHV9SoMgMg013ooooo00?o0000ooooooooool02Oooool00oo^k^koA4A4o`000004ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03_ooool001Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^01Oooooo00So0000ooooooooooooZJVYoa0@4?l0003o410@ojVYZ@?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP02o`000003ooooool0003o000001Kooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_l000007?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo01oooooo00?oEEEEofIVI_l000000oooool01_l0003ok^k^oc8b<_l0003o<S8bonk^kQ[o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000o`000?o^k^h02_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00GoZJVYoa0@4?l0003o410@ojVY
Z@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04?ooool00ol0003oooooooooo`0:ooooo`03ogMg
Mol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`00>?ooool00ol0003ooooo
ooooo`0<ooooo`05o`000?ooooooooooooooool000008_ooool00ol0003oooooooooo`0hooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo02?ooooo000hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
8oooool003Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Sooooo`00>Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02?ooooo000iooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool08oooool001Koooooool00010o`0001?ooooo000Fooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`05ooooo`?o00001Oooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`05ooooo`09o`000?ooooooooooooooool0003oooooo`00
0?oooooo000000Oooooo00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool04Oooool001Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool01?ooool2o`0000Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooool000001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo00Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000007oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo017ooooo000jooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo03cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo047ooooo00?o0000oooo
ooooool03?ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool09?ooool0
03_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0;ooooo`05o`000?oooooooooo
ooooool000003Oooool00ol0003oooooooooo`0Tooooo`00>oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0loooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`12oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo02Cooooo000kooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo03cooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Dooooo`;o00003_ooool00ol0003oooooooooo`12ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo02Cooooo000looooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03o`00013ooooo00?o0000ooooool000003_ooool00ol0003ooooo
ooooo`12ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo02Cooooo000mooooo`05o`000?ooooooooooooooool00000
3?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0
1Oooool01Ol0003oooooooooool0003ooooo00;o00003oooool01?l0003oooooooooool0000=oooo
o`03o`000?oooooooooo04;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09?ooool003gooooo00Co0000oooooooo
oooo00003_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool01Oooool3o`0000?ooooo00?o0000ooooooooool03Oooool01?l0003oooooooooool0000<
ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09?ooool003gooooo1?l0000>oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooo000000?ooooo00?o0000ooooooooool03?ooool01Ol0003ooooooooooooooooo
000000cooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Tooooo`00Coooool00ol0
003oooooooooo`0;ooooo`;o00003Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
00Cooooo0_l00004ooooo`03o`000?oooooooooo00cooooo00Go0000ooooooooooooooooo`00000<
ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09?ooool004oooooo00?o0000oooo
ooooool02_ooool01?l0003oooooooooool0000<ooooo`03o`000?oooooooooo03oooooo00?o0000
ooooooooool01?ooool2o`0000Cooooo00?o0000ooooooooool03?ooool01Ol0003ooooooooooooo
oooo000000cooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Tooooo`00Coooool0
0ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`0000cooooo00?o0000ooooooooool0?ooo
ool00ol0003oooooooooo`04ooooo`;o00001?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`14ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo02Gooooo001?ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooo00003?oo
ool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Cooooo0_l00005ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo04Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool09Oooool004oooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0?oooool0
0ol0003oooooooooo`04ooooo`;o00001Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo02Gooooo001?ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool09Oooool0053o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`04ooooo`;o00001Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`15ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo02Gooooo001@ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo047ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool09Oooool0053ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0@Oooool00ol0003ooooooooo
o`02ooooo`;o00001oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Gooooo001@
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool00_ooool2o`0000Oooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0Aoooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Uooooo`00D?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`12oooo
o`06o`000?ooooooooooo`000?oooooo00001oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`17ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo02Gooooo001@ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo04;ooooo1?l000000ooooooo0000ooooo`06
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09_ooool0053ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0@oooool2o`0000;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`17oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo02Kooooo001@ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Sooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Kooooo001@ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo04Sooooo0_l00007ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
9_ooool0053ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo04Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool09_ooool0057ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0B?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09_ooool0
057ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
04Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool09_ooool0057ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo04[ooooo00Co0000oooooooooooo00003Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo02Kooooo001Aooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Sooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`1:ooooo`04o`000?ooooooooooo`0000gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Wooooo`00DOooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0moooo
o`Go00001_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04[ooooo00?o0000oooo
ool000003_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Oooooo001Aooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo03kooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0Boooool2o`0000kooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Wooooo`00DOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0oooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo0ol00006ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Wooooo`00D_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`10ooooo`03oiRHV?lQ8B7ok^k^00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool09oooool005;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0@Oooool00omgMgOoIVIVoooo
o`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0G?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo02Oooooo001Booooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Wooooo`00D_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0noooo
o`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo05cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Wooooo`00D_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0nooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0W
ooooo`00D_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0GOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Sooooo001Cooooo`05
o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0:?ooool005?ooooo00Go0000ooooooooooooooooo`00000<oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0BOooool2o`0000Sooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0G_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Sooooo001Cooooo`05
o`000?ooooooooooooooool000003?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0:?ooool005?ooooo00Go0000ooooooooooooooooo`00000<oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo05kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Xoooo
o`00Doooool01Ol0003ooooooooooooooooo000000cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`19ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Goooool01Ol0
003ooooooooooooooooo000002[ooooo001Cooooo`05o`000?ooooooooooooooool000003?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`00
001Qooooo`05o`000?ooooooooooooooool00000:_ooool005?ooooo00Go0000oooooooooooooooo
o`00000<ooooo`05o`000?ooooooooooooooool00000C?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo0000
067ooooo00Co0000oooooooooooo0000:oooool005Cooooo00?o0000ooooool000003Oooool01Ol0
003ooooooooooooooooo000004cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00001Qooooo`04o`000?oo
ooooooooo`0002_ooooo001Dooooo`03o`000?oooooo000000gooooo00Go0000oooooooooooooooo
o`00001<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0:ooooo`05o`000?ooooooooooooooool00000HOooool01?l0003oooooooooool0000[oooo
o`00E?ooool00ol0003oooooo`00000>ooooo`03o`000?oooooo000004gooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooo
oooo0000HOooool01?l0003oooooooooool0000[ooooo`00E?ooool2o`0000oooooo00?o0000oooo
ool00000COooool2o`0000Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;oooo
o`04o`000?ooooooooooo`00067ooooo00Co0000oooooooooooo0000:oooool006Gooooo0ol0001=
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooo000006;ooooo00Co0000oooooooooooo0000:oooool006Kooooo0_l0001=
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooo000006?ooooo00?o0000ooooool00000:oooool00;Gooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo0ol0001Soooo
o`;o0000;?ooool00;Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool0H_ooool2o`0002cooooo002eooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Oooooo`00]Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Wooo
ool00;Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo09oooooo002eooooo`;o00002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
09oooooo002eooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`00002Roooo
o`00]Oooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool00000X_ooool00;Go
oooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo00000:;ooooo002eooooo`03
o`000?oooooooooo00[ooooo00Co0000oooooooooooo0000X_ooool00:cooooo0_l000000ol@413o
ooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooo0000X_ooool00:go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo00000:?o
oooo002Zooooo`Go00001_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo00000:?ooooo
002Zooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0000:ooooo`03o`000?oooooo00000:?ooooo
002Zooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool02_ooool00ol0003ooooo
o`00002Sooooo`00Zoooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo00_ooooo0_l0
002Sooooo`00Zoooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0;3ooooo002/oooo
o`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo00Gok^k^oc8b<_l0003o410@olc<c006oooo
o`03o`000?oooooooooo0;3ooooo002Zooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0
003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool0/?ooool00:[ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000/?ooool00:[o
oooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03
oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0/?ooool00:[ooooo00?ogMgMoa0@4?nHV9P0
2?ooool00ol0003oooooooooo`2`ooooo`00Zoooool01?o<c<coA4A4o`000?l@4106ooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002Zooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_oo
ool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05oc8b<_nH
V9SooooooiRHV?lb<S801_ooool3o`000;3ooooo002Zooooo`05olc<c?l0003o0000o`000?o<c<`0
^Oooool00:[ooooo00Go410@okZj^_oooooo^[Zjoa0@402iooooo`00Z_ooool01Ol0003o^[Zjoooo
oonj^[[o00000;Wooooo002Zooooo`05ojVYZOl@413o0000oa0@4?nYZJT0^Oooool00?ooooooJOoo
ool00;?ooooo00?o0000okZj^_ooool0/_ooool00;?ooooo0_lb<S:cooooo`00Q?ooool2o`000006
oa0@4?oooooooooooa0@4?l0003o410@6?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003o
A4A4okZj^P0Hooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`00oooool5o`0007cooooo0025ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`0000gooooo00WoMgMgoc8b<_oo
ooooooooogMgMonHV9SooooooiRHV?mgMgL00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj
^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@03ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@0O?ooool008Gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Kooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool04?ooool00ol0
003oooooooooo`0Jooooo`05o`000?ooooooooooooooool000001?ooool00onHV9So8B4Qonk^kP1m
ooooo`00QOooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000=ooooo`05ogMgMolb
<S;oooooooooool000000oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo
1_l00009ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801Oooool00onHV9So8B4Qonk^kP1looooo`00
QOooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001Wooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0Jooooo`05olc<c?l0
003o0000o`000?o<c<`01_ooool00omgMgOoIVIVooooo`1kooooo`00QOooool01_l0003oQhN7ojVY
ZOnj^[[oEEEEo`0001Wooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@
013ooooo00?o410@o`000?l000000ol0000Iooooo`05oa0@4?nj^[[ooooookZj^_l@41001oooool0
0ol0003oooooooooo`1jooooo`00QOooool01_l0003o<S8boooooooooooo<S8bo`0001Wooooo00?o
0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool0
6_ooool01Ol0003o^[Zjoooooonj^[[o000000?ooooo00Go0000okZj^_ooooooV9RHoa0@401loooo
o`00Q?ooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo1?l00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Jooooo`05ojVYZOl@413o0000
oa0@4?nYZJT00oooool01OnHV9So410@o`000?lQ8B7oc<c<07cooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(84) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .15932 m
.01975 .1486 L
.02981 .14093 L
.0327 .13896 L
.03544 .13734 L
.03793 .13613 L
.04057 .13517 L
.04186 .13482 L
.04255 .13466 L
.04329 .13453 L
.04459 .13436 L
.04581 .13428 L
.04654 .13427 L
.04733 .1343 L
.04808 .13435 L
.04878 .13443 L
.0501 .13467 L
.05083 .13485 L
.0515 .13505 L
.05402 .13609 L
.05544 .13691 L
.05674 .13781 L
.05914 .13988 L
.06168 .14268 L
.06738 .15135 L
.07271 .16258 L
.08481 .19802 L
.09007 .21427 L
.09284 .2217 L
.09578 .22812 L
.09702 .23025 L
.09835 .23212 L
.09911 .23298 L
.09981 .23363 L
.10118 .23451 L
.10234 .23482 L
.10362 .23472 L
.10494 .2341 L
.10618 .23307 L
.1074 .23163 L
.10872 .22963 L
.11111 .22495 L
.1156 .21338 L
.12566 .18311 L
.13045 .17038 L
.1356 .1596 L
.13855 .15507 L
.14125 .15207 L
.14255 .15102 L
.14323 .15058 L
Mistroke
.14396 .15018 L
.14529 .14967 L
.14653 .14945 L
.14726 .14944 L
.14803 .14952 L
.1494 .14991 L
.15017 .15027 L
.15088 .1507 L
.15251 .15205 L
.15393 .15366 L
.15522 .15551 L
.15813 .1611 L
.16071 .16791 L
.16352 .17747 L
.16863 .201 L
.17936 .27323 L
.18193 .29166 L
.18462 .309 L
.18692 .32093 L
.18822 .32611 L
.18943 .32977 L
.19071 .33232 L
.19188 .3334 L
.19322 .33317 L
.19449 .33152 L
.19585 .32827 L
.1971 .32402 L
.19993 .31062 L
.20551 .27493 L
.2115 .23609 L
.21424 .22153 L
.21684 .21055 L
.21917 .20336 L
.22049 .2005 L
.22171 .19865 L
.22284 .19765 L
.2239 .19734 L
.22507 .19773 L
.22633 .19901 L
.22758 .20119 L
.22889 .20448 L
.23002 .20814 L
.23124 .21305 L
.23409 .22824 L
.23667 .24686 L
.24247 .30396 L
.24745 .36039 L
.25028 .38807 L
.25167 .39881 L
.25293 .4065 L
Mistroke
.25419 .41184 L
.25538 .41463 L
.25664 .41505 L
.25801 .41251 L
.25936 .40704 L
.26012 .40276 L
.2608 .39818 L
.2634 .37559 L
.27305 .26227 L
.27845 .21084 L
.2815 .18922 L
.28429 .17345 L
.28696 .16156 L
.28944 .15283 L
.29203 .14581 L
.29488 .14017 L
.29761 .13635 L
.30014 .13386 L
.30146 .13286 L
.30292 .13195 L
.30445 .13119 L
.30586 .13065 L
.30712 .1303 L
.30845 .13006 L
.30978 .12996 L
.31053 .12996 L
.31123 .13 L
.31251 .13016 L
.31366 .13041 L
.315 .13082 L
.31626 .1313 L
.32113 .13389 L
.32562 .13706 L
.33054 .14149 L
.33575 .1475 L
.34567 .16097 L
.35114 .16839 L
.35632 .1748 L
.35865 .17721 L
.36113 .17928 L
.36256 .1802 L
.36385 .18086 L
.36515 .18134 L
.36638 .18163 L
.3675 .18176 L
.36868 .18176 L
.36968 .18166 L
.37079 .18143 L
.37198 .18105 L
.37326 .18051 L
Mistroke
.37556 .17916 L
.37826 .17699 L
.38113 .17403 L
.38628 .16739 L
.39792 .15117 L
.40276 .14539 L
.40798 .14039 L
.40951 .13926 L
.41096 .13836 L
.41238 .13767 L
.4137 .13718 L
.41494 .13686 L
.41626 .13668 L
.41702 .13665 L
.41773 .13667 L
.41906 .13683 L
.42028 .13712 L
.42159 .1376 L
.42282 .13821 L
.42394 .13891 L
.42526 .13993 L
.4267 .14129 L
.42931 .14451 L
.43203 .14902 L
.43493 .15524 L
.44013 .17016 L
.44935 .20741 L
.45421 .23021 L
.45696 .24249 L
.45953 .25252 L
.46202 .2603 L
.46342 .26358 L
.46468 .26582 L
.46603 .26737 L
.46678 .26786 L
.46748 .26807 L
.46876 .26783 L
.47012 .26672 L
.47127 .26511 L
.47251 .26272 L
.47474 .25685 L
.4774 .24767 L
.47983 .23771 L
.48533 .21274 L
.49119 .18791 L
.49404 .17799 L
.49672 .17023 L
.49916 .16455 L
.50049 .16201 L
.50173 .16001 L
Mistroke
.50297 .15834 L
.50411 .15715 L
.50537 .1562 L
.50673 .15563 L
.50786 .15554 L
.50909 .15584 L
.51025 .15654 L
.51132 .15755 L
.51256 .15915 L
.51371 .16111 L
.51635 .16729 L
.51892 .17571 L
.52169 .18769 L
.52434 .2022 L
.52723 .22178 L
.53305 .27244 L
.53805 .32179 L
.54068 .34548 L
.54346 .36553 L
.54484 .37281 L
.54563 .37603 L
.54636 .3784 L
.54765 .38102 L
.54903 .38161 L
.5497 .38105 L
.55043 .37984 L
.55177 .37606 L
.55307 .37055 L
.55427 .36403 L
.55903 .32897 L
.56408 .28744 L
.56668 .26924 L
.56804 .26116 L
.56947 .25393 L
.57074 .24873 L
.57212 .24433 L
.57337 .24151 L
.57454 .23992 L
.57526 .23943 L
.57604 .23933 L
.57678 .23965 L
.57746 .24031 L
.57875 .24249 L
.58012 .24615 L
.58159 .25164 L
.58296 .25825 L
.58609 .27842 L
.59131 .32498 L
.59406 .35255 L
.597 .37998 L
Mistroke
.59845 .39156 L
.59982 .40068 L
.60104 .40709 L
.60237 .41189 L
.60363 .41422 L
.60497 .41422 L
.60611 .4122 L
.60736 .40788 L
.60866 .40117 L
.6099 .39293 L
.61222 .37335 L
.61742 .31819 L
.62226 .26692 L
.62681 .22765 L
.63163 .19708 L
.63419 .18483 L
.63695 .17415 L
.63969 .16573 L
.64257 .15879 L
.64506 .15409 L
.64772 .15006 L
.65251 .14457 L
.65696 .1407 L
.66226 .1372 L
.66707 .1349 L
.67216 .13308 L
.67495 .13226 L
.67755 .13164 L
.67977 .13124 L
.68102 .13108 L
.68215 .13099 L
.6834 .13093 L
.68475 .13093 L
.68603 .131 L
.68722 .13111 L
.68859 .13131 L
.69008 .13159 L
.69277 .13231 L
.69539 .13328 L
.69779 .13443 L
.70041 .13603 L
.70327 .13825 L
.70906 .14435 L
.72049 .16262 L
.73131 .1853 L
.73602 .19452 L
.7386 .19879 L
.74102 .20208 L
.74238 .20358 L
.74362 .20471 L
Mistroke
.74501 .20568 L
.74577 .20607 L
.7465 .20636 L
.74775 .20664 L
.74892 .20666 L
.7502 .20639 L
.75156 .20579 L
.75291 .20487 L
.75432 .20358 L
.75687 .20048 L
.76261 .19058 L
.77302 .1686 L
.77749 .15974 L
.78229 .15162 L
.78505 .14783 L
.78756 .145 L
.79009 .1428 L
.79133 .14195 L
.79248 .14132 L
.79367 .14081 L
.79496 .14043 L
.7961 .14025 L
.79729 .14023 L
.7986 .1404 L
.79983 .14077 L
.80117 .14142 L
.80192 .1419 L
.8026 .14242 L
.80526 .14514 L
.80676 .14724 L
.80814 .14954 L
.81084 .15518 L
.81337 .16188 L
.81783 .17742 L
.82275 .20029 L
.8327 .25932 L
.83523 .27358 L
.83792 .28635 L
.83947 .29213 L
.84087 .29617 L
.84155 .29768 L
.84229 .29897 L
.84361 .30038 L
.84487 .30059 L
.84624 .29956 L
.84693 .29855 L
.84768 .29711 L
.84902 .29362 L
.85035 .28907 L
.85161 .28388 L
Mistroke
.85398 .27224 L
.86323 .21727 L
.8685 .19036 L
.87108 .17993 L
.87344 .17209 L
.87582 .16589 L
.87703 .1634 L
.87833 .16125 L
.87963 .15964 L
.88084 .15864 L
.88158 .15828 L
.88228 .15812 L
.88359 .15828 L
.8849 .15908 L
.88628 .16064 L
.88746 .16257 L
.88876 .16535 L
.89016 .16913 L
.89166 .17414 L
.89437 .18587 L
.89685 .19993 L
.89956 .21913 L
.90448 .26449 L
.90892 .31321 L
.91125 .33857 L
.91371 .36235 L
.91511 .37356 L
.91664 .38336 L
.91731 .38673 L
.91803 .38965 L
.91932 .39304 L
.92 .39382 L
.92074 .39387 L
.92208 .39188 L
.92339 .3874 L
.92459 .38118 L
.92686 .36471 L
.92937 .34109 L
.93443 .28589 L
.93992 .23157 L
.94294 .20803 L
.94581 .19017 L
.94848 .17718 L
.95138 .16636 L
.95402 .15913 L
.95648 .15432 L
.95783 .15236 L
.95925 .15074 L
.96047 .14969 L
.9618 .14885 L
Mistroke
.96256 .1485 L
.96324 .14825 L
.96404 .14803 L
.96479 .1479 L
.96612 .14781 L
.96687 .14783 L
.96757 .14788 L
.96881 .14808 L
.96998 .14835 L
.97126 .14874 L
.97264 .14925 L
.97802 .15196 L
.98295 .15491 L
.98754 .15729 L
.98985 .15819 L
.99104 .15855 L
.99232 .15888 L
.99306 .15904 L
.99373 .15916 L
.99507 .15934 L
.99628 .15943 L
.99756 .15946 L
.99872 .15943 L
1 .15932 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo001gooooo`Co0000>_ooool2o`0003Sooooo0_l0001gooooo`00
9Oooool00ol0003oooooooooo`1=ooooo`?o00000_ooool3o`0003Sooooo00?o0000ooooooooool0
<oooool4o`0000;ooooo0ol0001dooooo`008Oooool7o`0004cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Iooooo`?o00006Oooool00ol0003oooooooooo`0aooooo`;o00002Ooo
ool2o`0007;ooooo000Pooooo`03o`000?oooooooooo00Gooooo0_l0001:ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool05oooool2o`0000;ooooo0_l0000Gooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Jooooo`;o0000Doooool0
01kooooo0_l00009ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0^ooooo`;o00003_ooool00ol0003oooooooooo`0Hooooo`;o000000?oooooo`00
0?l00000D_ooool001gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`17ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1?ooooo`00
6oooool2o`0000gooooo00?o0000ooooooooool05oooool2o`0002gooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02gooooo1_l0000Kooooo`006Ooo
ool2o`00013ooooo00?o0000ooooooooool05Oooool4o`0002_ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool00ooo
ool2o`0001Wooooo000Gooooo`;o00004_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Booooo`Co0000:_ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05_ooool0
01Kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Booooo`;o000000?oooooo`00
0?l00000:?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Cooooo`;o00005Oooool00ol0003oooooooooo`08oooo
o`?o000000?oooooo`000?ooool04_ooool002cooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04Oooool01Ol0003o
oooooooooooooooo000002Sooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04Oooool2o`000003ooooool0003ooooo
01?ooooo00?o0000ooooooooool02oooool2o`0001?ooooo000Eooooo`;o000000Wo410@oooooooo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^h03Oooool00ol0003oooooooooo`0:ooooo`05oiRHV?l@
413o0000oc8b<_o<c<`00_ooool02?l0003ok^k^oc8b<_l0003o<S8bonk^k_oooooo00006Oooool5
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool01?ooool4o`000008oa0@4?ooooooooooo`000?lb<S;o0000oc8b<_o^k^h:oooo
o`03o`000?oooooooooo017ooooo00Go0000ooooooooooooooooo`00000Mooooo`Co000000Go410@
ooooooooooook^k^oc8b<P02o`000003onk^k_oooooooooo01Kooooo00?o0000ooooool000001?l0
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`03o`000?lb<S;o000000;o
00004oooool00ol0003oooooooooo`07ooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o
0000oc8b<_o^k^h03_ooool001Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00gooooo00?o0000ooooooooool02_ooool03Ol@413o^[ZjoooooomgMgOo<S8booooool0
003oooooogMgMonHV9SooooooiRHV?mgMgL00_ooool00ol0003oooooooooo`0Fooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`05ooooo`0:o`000?ooooooooooooooool0003oMgMgoiRHV?oo
ooooV9RHogMgM`[ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHooooool0003oMgMg01So
oooo00Oo0000oooooonHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`02ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool01Ol@413o^[Zjoooo
oomgMgOo<S8b00?ooooo00Go0000oiRHV?ooooooV9RHo`00000Cooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko
00000_ooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`04o`000?oooooooooo
ooooo`Ko00001_ooool2o`0000;ooooo00Go410@oooooooooooooooooa0@4002ooooo`03o`000?oo
oooooooo00kooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Oo410@oooooooooooooooo
oa0@4?oooooo0000017ooooo1_l00005ooooo`06o`000?ooooooooooo`000?oooooo410@0oooool0
0ol@413oooooooooo`09ooooo`03o`000?oooooooooo00oooooo0_l00004ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool00_ooool01Ol@413oooooooooool0003o410@01Wooooo00Go
0000oooooonHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool01Oooool5o`0000?ooooo00Go410@oooo
oooooooooooooa0@400>ooooo`004oooool01?m4A4CogMgMooooool00004ooooo`05o`000?oooooo
ooooooooool000003_ooool00ol0003oooooooooo`0<ooooo`03ojVYZOl@413o000000;ooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo01Oooooo00?oV9RHob4Q8Oo^k^h0
0oooool01ol0003ooooooooooooooooo0000ooooool000005_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooo
oooo00oooooo0_l00005ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool00_ooool0
1Ol0003oooooo`000?oooooo000001Wooooo00Ko0000ooooooooooooV9RHob4Q8Oo^k^h3ooooo`07
o`000?ooooooooooooooool0003oooooo`00000>ooooo`03o`000?oooooooooo00_ooooo00CoZJVY
oa0@4?oooooooooo0_l00003ooooo`;o00004Oooool00ol0003oooooooooo`06ooooo`04odA4A?oM
gMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`004oooool01?oMgMgoEEEE
ooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`0;oooo
o`04oa0@4?l0003o^[Zjo`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo01Sooooo00?oMgMgofIVI_ooool00_ooool01ol0003ooooooooooooooooo0000ooooool0
00005oooool00ol0003oooooooooo`02ooooo`;o00000oooool01Ol0003ooooooooooooooooo0000
00_ooooo00?o0000ooooooooool03_ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool00_ooool01Ol0003oooooo`000?oooooo000001[ooooo00Go0000
ooooooooooooMgMgofIVIP03ooooo`07o`000?ooooooooooooooool0003oooooo`00000>ooooo`03
o`000?oooooooooo00[ooooo00?o410@o`000?nj^[X00_ooool2o`0000?ooooo0_l0000Aooooo`03
o`000?oooooooooo00Kooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo
000000kooooo000Dooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@400?
ooooo`03o`000?oooooooooo00_ooooo00?o^[Zjo`000?ooool00_ooool01Ol@413ooooooooooooo
oooo410@00?ooooo00?o0000ooooooooool06Oooool01Ol0003ooooooooooooooooo410@00?ooooo
00?o410@ooooool000006?ooool2o`000003ooooool0003o000000Cooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03o`000?oooooooooo00gooooo00Co0000ooooool0003o00001?ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo00;ooooo00Go410@ooooool0003ooooooa0@400K
ooooo`04o`000?ooooooooooo`0000?ooooo00Ko410@oooooooooooooooooa0@4?l0000?ooooo`03
o`000?oooooooooo00_ooooo00Ko^[Zjob4Q8Ooooooo0000ooooool@4103ooooo`03oa0@4?l0003o
oooo013ooooo00?o0000ooooooooool01oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooo
ooooooooool@41003_ooool001Cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00oooooo00?o0000ooooooooool02?ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03o`000?oooooooooo01Gooooo00Go0000okZj^_oo
ooooV9RHoa0@4003ooooo`06ogMgMonHV9SooooooiRHV?mgMgOo00006_ooool4o`0000Cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooool00000
1Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?l0003o
V9RHogMgM`0Jooooo`;o000000?ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9So0000
013ooooo00?o0000ooooooooool02?ooool03_l@413oV9RHoooooonj^[[o0000ooooool0003ooooo
ogMgMonHV9SooooooiRHV?mgMgOo00004Oooool00ol0003oooooooooo`07ooooo`03onk^k_m4A4Co
000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`005Oooool00omgMgOo0000ooooo`03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03oooool00ol0003oooooooooo`08ooooo`05ojVYZOl@
413o0000oa0@4?l000000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?o0000oooooooo
ool05Oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Kok^k^oc8b<_l0003o<S8bonk^k_l0
000Kooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03o`00
0?oooooooooo00cooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0Hooooo`03
oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Jooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o0000017ooooo00?o0000ooooooooool01ooo
ool01_nYZJWo410@o`000?l@413oZJVYo`0000;ooooo00Kok^k^oc8b<_l0003o<S8bonk^k_l0000@
ooooo`03o`000?oooooooooo00Wooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00kooooo000`ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool03?ooool0
1?l0003oooooooooool00006ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool08_oo
ool0033ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0;ooooo`04o`000?oooooo
ooooo`0000Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Rooooo`00<?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooo00001_oo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02;ooooo000aooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0>ooooo`?o00004?ooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00
0007ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool08_ooool0037ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo0_l00000
0ooooooo0000ooooo`0>ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02_ooool0
1Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0Sooooo`005_ooooooo`00043o00004oooool001Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool00oooool01Ol0003oooooo`000?oo
oooo000000Gooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00001_ooool2o`0000Oooooo00?o0000oooooooo
ool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool04Oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooool000001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oo
oooo00?o0000ooooooooool00oooool01Ol0003oooooo`000?oooooo000000Gooooo00?o0000oooo
ooooool01Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooool000001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo000b
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0<
ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Sooooo`00<_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool08oooool0
03?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
03Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
02Cooooo000cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0?Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0Tooooo`00=?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo03gooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool09?ooool003Gooooo00Co0000oooooooooooo00004oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0?Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Tooooo`00=Oooool3o`0001Gooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0Tooooo`00=_ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo02Cooooo001=ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool03?ooool2o`0000kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Toooo
o`00COooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool0
00003_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Cooooo001=ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooo`00000>ooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool09Oooool004kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0000gooooo00?o0000ooooooooool0
?oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Uooooo`00C_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0hooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Wooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo043ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool09Oooool004kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`09ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003oooooooooo`10ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo02Gooooo001>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Wooooo00Go0000oooooooooooooooo
o`000007ooooo`;o00002?ooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool0
00003?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Gooooo001>ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo03Wooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo
043ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool09Oooool004kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0>Oooool2o`000003
ooooool0003ooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`05
o`000?ooooooooooooooool000003?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
02Gooooo001?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo03[ooooo0_l00009ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Uooooo`00Coooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`15ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0@Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Uooooo`00Coooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0@Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Vooooo`00Coooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`15
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0V
ooooo`00Coooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0@Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Vooooo`00Coooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`16ooooo`;o
00002?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Kooooo001@ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo04Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`12ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo02Kooooo001@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`12ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo02Kooooo001@ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Kooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`13ooooo`04o`000?ooooooooooo`0001;ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Vooooo`00D?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`16ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0@oooool01?l0003ooooooooo
ool0000Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09_ooool0053ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0A_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Cooooo0_l0
000Cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09_ooool0053ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0>oooool5o`0000Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1I
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09_ooool0053ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0>oooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09_ooool0
053ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0??ooool00onHV9So8B4Qonk^kP07ooooo`?o00002?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`1Jooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09_ooool0053o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0?Oooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Ko
oooo001@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo03kooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Wooooo`00DOooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
9oooool0057ooooo00Co0000oooooooooooo00003_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo03cooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Oo
oooo001Aooooo`04o`000?ooooooooooo`0000kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0looooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo05[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Woooo
o`00D_ooool00ol0003oooooo`00000>ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0Aoooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05_ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Wooooo`00D_ooool00ol0003oooooo`00000>ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo05_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Wooooo`00D_oo
ool2o`00013ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`17ooooo`;o00002_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09ooo
ool006Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo02Oooooo001Tooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Aoooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Wooooo`00I?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04Oo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool09oooool006Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`17ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Foooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo02Oooooo001Tooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0Aoooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Wooooo`00I?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1M
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09oooool006Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0GOooool01Ol0003ooooooooooooooooo000002[ooooo001Tooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0;ooooo`04o`000?oooooooooo
o`0000cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Mooooo`05o`000?oooooo
ooooooooool00000:_ooool006Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`18
ooooo`;o00003?ooool01?l0003oooooooooool0000<ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0GOooool01Ol0003ooooooooooooooooo000002[ooooo001Tooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0;ooooo`04o`000?oo
ooooooooo`0000cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Mooooo`05o`00
0?ooooooooooooooool00000:_ooool006Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`18ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooo00003Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo05gooooo00Go0000ooooooooooooooooo`00000Zoooo
o`00I?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04Sooooo00?o0000oooooooo
ool02oooool01?l0003oooooooooool0000=ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0GOooool01Ol0003ooooooooooooooooo000002[ooooo001Uooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo0000
00kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Mooooo`04o`000?oooooooooo
o`0002_ooooo001Uooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0B?ooool00ol0
003oooooooooo`0<ooooo`;o00003_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
05gooooo00Co0000oooooooooooo0000:oooool006Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`18ooooo`03o`000?oooooooooo00cooooo0_l0000>ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0G_ooool00ol0003oooooo`00000[ooooo`00IOooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo05kooooo00?o0000ooooool00000:oooool006Gooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`18ooooo`;o00007Oooool01Ol0003ooooo
oooooooooooo0000067ooooo00?o0000ooooool00000:oooool006Gooooo00Go0000oooooooooooo
ooooo`00001;ooooo`03o`000?oooooooooo01cooooo00Go0000ooooooooooooooooo`00001Qoooo
o`03o`000?oooooo000002_ooooo001Uooooo`05o`000?ooooooooooooooool00000Boooool00ol0
003oooooooooo`0Looooo`05o`000?ooooooooooooooool00000HOooool2o`0002cooooo001Voooo
o`04o`000?ooooooooooo`0004_ooooo00?o0000ooooooooool07Oooool01?l0003oooooooooool0
002?ooooo`00I_ooool01?l0003oooooooooool0001;ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooool00000T?ooool006Kooooo00Co0000oooooooooooo0000@_ooool2o`000003oa0@4?oo
oooooooo00Cooooo00?o0000ooooooooool07Oooool00ol0003oooooo`00002@ooooo`00I_ooool0
0ol0003oooooo`000014ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07Oooool0
0ol0003oooooo`00002@ooooo`00I_ooool00ol0003oooooo`000011ooooo`Go00001_ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooo0000093ooooo001Wooooo`;o0000@Oooool01?m4A4Co
gMgMooooool00007ooooo`?o00007Oooool00ol0003oooooo`00002@ooooo`00Ioooool00ol0003o
ooooooooo`10ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`2?ooooo`00Zoooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo0;3o
oooo002[ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0/?ooool00:cooooo00?o
MgMgo`000?ooool01_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00Z_ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o
0000ooooooooool0/?ooool00:[ooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oo
oooooooo0;3ooooo002Zooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0002`ooooo`00Z_ooool0
1Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00?oEEEE
ohN7Qoooool02?ooool00ol0003oooooooooo`2`ooooo`00Z_ooool00ooMgMgo410@oiRHV008oooo
o`03o`000?oooooooooo0;3ooooo002[ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:[o
oooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P06ooooo`?o0000/?ooool00:[ooooo00Goc<c<o`000?l0003o0000olc<c02ioooo
o`00Z_ooool01Ol@413o^[Zjoooooonj^[[o410@0;Wooooo002Zooooo`05o`000?nj^[[ooooookZj
^_l00000^Oooool00:[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2iooooo`00oooooomYooooo`00
/oooool00ol0003o^[Zjooooo`2booooo`00/oooool2oc8b<[?ooooo0024ooooo`;o000000Ko410@
oooooooooooo410@o`000?l@410Hooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co
^[Zj01Sooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c005ooooo`;o000000?o410@ooooooooool0N_oo
ool008Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00003Oooool0
2OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03olc<c?l0003o410@00co
oooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002Oooool01OlQ8B7oV9RHoooooonHV9So
8B4Q00Kooooo00?o0000ooooooooool0Noooool008Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Kooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool04?ooool0
0ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool000000oooool5o`0007cooooo0025
ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000gooooo00GoMgMgoc8b<_oooooo
ooooo`000003ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02oooool6o`0000Wo
oooo00Go<S8boiRHV?ooooooV9RHoc8b<P03ooooo`04odA4A?oMgMgoooooo`0007gooooo0025oooo
o`06o`000?oMgMgo<S8boeEEEOoMgMgo00006Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo
00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo01[ooooo00Goc<c<o`000?l0
003o0000olc<c003ooooo`04omgMgOmEEEGoooooo`0007gooooo0025ooooo`06o`000?n7QhOoZJVY
okZj^_mEEEGo00006Oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100
4?ooool00ol@413o0000o`000003o`0001Wooooo00Go410@okZj^_oooooo^[Zjoa0@4004ooooo`03
ogMgMoo<c<co000007gooooo0025ooooo`06o`000?lb<S;ooooooooooolb<S;o00006Oooool00ol0
003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool00ol0003oooooooooo`0J
ooooo`05o`000?nj^[[ooooookZj^_l000001?ooool00oo^k^koA4A4o`00001mooooo`00Q?ooool0
0ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo1?l00003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Jooooo`05ojVYZOl@413o0000oa0@4?nYZJT0
1Oooool00omgMgOo0000ooooo`1looooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(86) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .13231 m
.00236 .13097 L
.00488 .12976 L
.00706 .1289 L
.00821 .12853 L
.00942 .1282 L
.01011 .12804 L
.01087 .1279 L
.0122 .12771 L
.01356 .12762 L
.01483 .12761 L
.01607 .12768 L
.0172 .12782 L
.01851 .12805 L
.01975 .12834 L
.02225 .12916 L
.02491 .1304 L
.02742 .13197 L
.0297 .13376 L
.03239 .13641 L
.0353 .13996 L
.04057 .14829 L
.06208 .20558 L
.06731 .21961 L
.07024 .22571 L
.07163 .228 L
.07292 .22973 L
.07443 .23125 L
.07523 .23181 L
.07607 .23223 L
.07681 .23243 L
.0775 .23249 L
.07825 .2324 L
.07907 .23213 L
.07976 .23175 L
.08053 .23119 L
.08206 .2296 L
.08348 .2276 L
.08481 .22533 L
.09641 .19525 L
.10211 .17899 L
.10737 .16565 L
.11205 .15596 L
.1172 .14789 L
.12238 .14213 L
.12521 .13989 L
.12659 .13904 L
.12786 .1384 L
.12909 .13793 L
.1304 .13759 L
Mistroke
.13114 .13747 L
.13185 .1374 L
.13316 .1374 L
.13442 .13756 L
.13558 .13784 L
.13685 .13829 L
.13819 .13895 L
.14052 .14052 L
.14269 .14255 L
.14508 .14551 L
.14763 .14972 L
.15036 .15567 L
.15334 .16408 L
.15874 .1853 L
.164 .21392 L
.16886 .24682 L
.17374 .28237 L
.1763 .29949 L
.1777 .30769 L
.17899 .31434 L
.18024 .31967 L
.18137 .32351 L
.18262 .32658 L
.18395 .32839 L
.18508 .3287 L
.18629 .32779 L
.18744 .32577 L
.1885 .32294 L
.18975 .31849 L
.19109 .31249 L
.19351 .29897 L
.19902 .26062 L
.2048 .21987 L
.20734 .20435 L
.21014 .18964 L
.21263 .17888 L
.21531 .16958 L
.21679 .16543 L
.21815 .1622 L
.21943 .15964 L
.22081 .15743 L
.22154 .15648 L
.22221 .15575 L
.22351 .15472 L
.22424 .15437 L
.22503 .15418 L
.22577 .15419 L
.22646 .15437 L
.22784 .15521 L
.22862 .15599 L
Mistroke
.22936 .15693 L
.23083 .15945 L
.23242 .16313 L
.23513 .1719 L
.23808 .18541 L
.24086 .2025 L
.24345 .22265 L
.24834 .27272 L
.25354 .33849 L
.25628 .37244 L
.25777 .38888 L
.25917 .40212 L
.26046 .41209 L
.26164 .41899 L
.26295 .42394 L
.26367 .42538 L
.26435 .42589 L
.26502 .42557 L
.26576 .42429 L
.26653 .42191 L
.26726 .41876 L
.26855 .41103 L
.26995 .39997 L
.27313 .36678 L
.27604 .33105 L
.28139 .26746 L
.28636 .22245 L
.28887 .2059 L
.29155 .19226 L
.29308 .18612 L
.29452 .18131 L
.29582 .17771 L
.29722 .17458 L
.29854 .17226 L
.29974 .17063 L
.30094 .16943 L
.30209 .16866 L
.30342 .16815 L
.30465 .16801 L
.306 .16817 L
.30676 .16838 L
.30744 .16864 L
.30884 .16932 L
.31012 .1701 L
.31301 .17225 L
.31825 .17675 L
.32061 .17877 L
.32313 .18075 L
.32547 .18227 L
.32662 .18286 L
Mistroke
.32768 .18331 L
.32888 .18367 L
.33017 .1839 L
.33127 .18394 L
.33243 .18385 L
.33371 .18357 L
.33491 .18314 L
.33622 .1825 L
.33763 .18163 L
.34029 .17948 L
.34313 .17656 L
.34824 .16996 L
.35981 .15189 L
.36551 .14372 L
.37087 .1372 L
.37569 .13247 L
.37821 .1305 L
.3809 .12881 L
.38229 .12812 L
.3836 .12758 L
.38488 .12715 L
.38606 .12685 L
.38718 .12665 L
.38837 .12652 L
.38956 .12648 L
.39088 .12655 L
.39157 .12663 L
.3923 .12675 L
.3936 .12707 L
.39432 .12729 L
.395 .12755 L
.39653 .12825 L
.39909 .1299 L
.40183 .13237 L
.40469 .13581 L
.40779 .14063 L
.41342 .15265 L
.41889 .1689 L
.42395 .18794 L
.43344 .22941 L
.43617 .24048 L
.43877 .24952 L
.4411 .25595 L
.44241 .25873 L
.44364 .2607 L
.44434 .26155 L
.4451 .26223 L
.44648 .26284 L
.44782 .26263 L
.44906 .26175 L
Mistroke
.4504 .26008 L
.45116 .25881 L
.45187 .25743 L
.45483 .24979 L
.45989 .23173 L
.46531 .20975 L
.4705 .19011 L
.47601 .17312 L
.47888 .16614 L
.48205 .15993 L
.48494 .15559 L
.48623 .15403 L
.48764 .15257 L
.49023 .15054 L
.49164 .14975 L
.49295 .14921 L
.49419 .14887 L
.49531 .1487 L
.4966 .14865 L
.49782 .14876 L
.49915 .14904 L
.49982 .14926 L
.50056 .14955 L
.50186 .1502 L
.50308 .15098 L
.50583 .15336 L
.50878 .15697 L
.51146 .16131 L
.51431 .1672 L
.51943 .18179 L
.52228 .19261 L
.52495 .20486 L
.53104 .2408 L
.54112 .314 L
.54388 .33106 L
.5454 .33868 L
.54684 .34442 L
.54817 .34831 L
.54893 .34985 L
.54962 .35081 L
.55085 .35146 L
.55216 .35063 L
.55338 .34846 L
.55469 .34469 L
.55593 .33985 L
.55706 .33444 L
.56246 .29956 L
.56765 .26134 L
.57331 .22533 L
.57581 .21278 L
Mistroke
.57848 .20203 L
.57977 .19787 L
.58099 .19463 L
.58209 .19229 L
.58327 .1904 L
.58441 .18923 L
.58567 .1887 L
.58698 .18901 L
.5882 .19012 L
.58934 .19189 L
.59039 .19415 L
.59159 .19754 L
.59273 .20155 L
.59506 .21231 L
.59722 .22575 L
.59948 .2437 L
.60194 .26823 L
.60712 .33465 L
.61187 .40121 L
.61329 .41863 L
.61463 .43284 L
.61585 .44339 L
.61714 .45168 L
.61781 .4547 L
.61854 .45695 L
.61984 .45813 L
.62057 .4572 L
.62135 .45494 L
.62209 .45162 L
.62276 .44762 L
.62407 .43746 L
.62527 .42545 L
.62801 .39106 L
.63299 .31722 L
.63817 .24822 L
.64305 .20162 L
.64575 .183 L
.64867 .16747 L
.65132 .15678 L
.65376 .1494 L
.65504 .14635 L
.65641 .14366 L
.65759 .14176 L
.65888 .14011 L
.66039 .13862 L
.66108 .13809 L
.66182 .13761 L
.66248 .13726 L
.66321 .13693 L
.66449 .13653 L
Mistroke
.66525 .13638 L
.66596 .1363 L
.66731 .13627 L
.66806 .13634 L
.66876 .13645 L
.66952 .13662 L
.67034 .13687 L
.67182 .1375 L
.67321 .13831 L
.67582 .1404 L
.67834 .14313 L
.6807 .14623 L
.68606 .15473 L
.69688 .1766 L
.70138 .18671 L
.70616 .19629 L
.70866 .20033 L
.70998 .20214 L
.71141 .20382 L
.71272 .20509 L
.71392 .20602 L
.71506 .2067 L
.71627 .20718 L
.71758 .20742 L
.71831 .20741 L
.71898 .20733 L
.72028 .20692 L
.7215 .20626 L
.7222 .20575 L
.72293 .20512 L
.72425 .20375 L
.72723 .19958 L
.73218 .19019 L
.73762 .17816 L
.74761 .15627 L
.75253 .14703 L
.7571 .14015 L
.76219 .13435 L
.76489 .13196 L
.76775 .12991 L
.76902 .12918 L
.77039 .12853 L
.77168 .12806 L
.77287 .12774 L
.77394 .12757 L
.77512 .12749 L
.77635 .12755 L
.7775 .12773 L
.77886 .12809 L
.77963 .12837 L
Mistroke
.78034 .12868 L
.78163 .12935 L
.78304 .13028 L
.78549 .13236 L
.78809 .13534 L
.7909 .13968 L
.79394 .14591 L
.7968 .1535 L
.79943 .16202 L
.80986 .21143 L
.8156 .24654 L
.81841 .26344 L
.821 .27728 L
.82346 .2878 L
.82469 .29189 L
.82605 .2953 L
.82741 .2975 L
.82818 .29818 L
.82888 .29845 L
.83023 .29801 L
.83152 .29643 L
.83267 .29411 L
.83389 .29074 L
.83609 .28261 L
.84106 .257 L
.84627 .22595 L
.8519 .19541 L
.85448 .18378 L
.85721 .1734 L
.85956 .16596 L
.86208 .15948 L
.86454 .15453 L
.86678 .15113 L
.86786 .14985 L
.86903 .14872 L
.87014 .1479 L
.87116 .14734 L
.87235 .14694 L
.87346 .14679 L
.87468 .14688 L
.87599 .14725 L
.87736 .14795 L
.87866 .1489 L
.88111 .15142 L
.88382 .15538 L
.88638 .16032 L
.89117 .17325 L
.89385 .18293 L
.89632 .19355 L
.9019 .22395 L
Mistroke
.91121 .29207 L
.91634 .33063 L
.91887 .34618 L
.9212 .35703 L
.92244 .36113 L
.92376 .36407 L
.92509 .36551 L
.92584 .36564 L
.92655 .36531 L
.92777 .36372 L
.92889 .36118 L
.93013 .35726 L
.93142 .35198 L
.93598 .32622 L
.94097 .29175 L
.94681 .25294 L
.95233 .22316 L
.95729 .20268 L
.96266 .1858 L
.96722 .17454 L
.97205 .16482 L
.98071 .15126 L
.9899 .14037 L
.99512 .13569 L
1 .13231 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo000Ioooo
o`?o0000M?ooool4o`00027ooooo00?o0000ooooooooool0E?ooool2o`0005[ooooo000Fooooo`Co
00000_ooool3o`0006oooooo0_l00004ooooo`;o00007oooool2o`0005?ooooo0_l00002ooooo`;o
0000F?ooool001Kooooo00?o0000ooooooooool01Oooool2o`0006gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo017ooooo000Pooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool0<Oooool3o`0001cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0nooooo`;o00005?ooool0027ooooo00?o0000ooooooooool06_ooool5
o`0004Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo02oooooo0_l00003ooooo`;o00006Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo03gooooo00?o0000ooooooooool05?ooool0027ooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0?Oooool00ol0
003oooooooooo`0Dooooo`008_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool05Oooool002?ooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0Fooooo`Co0000<?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Eooooo`Co00008Oooool00ol0003ooooo
ooooo`0Fooooo`008oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0@?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Gooooo0_l0
0002ooooo`;o0000;oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0Dooooo`05o`000?ooooooooooooooool00000
7oooool00ol0003oooooooooo`0Gooooo`009?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool04oooool3o`0002Wooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo0ol0000]ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo01Oooooo000Tooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0002Oooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
;?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Hooooo`009?ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool04Oooool2o`0000;ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00ooo
ool01Ol0003ooooooooooooooooo000002_ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool001Gooooo0_l0
00002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo
013ooooo00Oo0000oooooonHV9So410@o`000?lb<S;oc<c<00?ooooo00Kok^k^oc8b<_l0003o<S8b
onk^k_l0000Cooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000001?l00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h05oooool00ol0003oooooooooo`02ooooo`Co000000So410@oooo
ooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`03ooooo`05o`000?ooooooooooooooool000007Oooool4o`00000:oa0@4?ooooooooooonk^
k_lb<S;o0000oc8b<_o^k^koooooo`0000cooooo00?o0000ooooooooool02Oooool5o`000008oooo
ool0003oooooonk^k_lb<S;o0000oc8b<_o^k^h:ooooo`03o`000?oooooooooo00kooooo00GoV9RH
oa0@4?l0003o0000olc<c003ooooo`05onk^k_lb<S;o0000o`000?o^k^h06Oooool01?l0003ooooo
ooooooooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000F
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oo
oooooooo013ooooo00Oo0000ooooool@413o^[ZjoooooomgMgOo<S8b00?ooooo00KoMgMgoiRHV?oo
ooooV9RHogMgMol0000Cooooo`03o`000?oooooooooo00;ooooo00Oo0000oooooonHV9So8B4Qonk^
k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`?o00003Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
000001oooooo00?o0000ooooooooool00_ooool01omgMgOoV9RHoooooonHV9SoMgMgooooool00000
3Oooool00ol0003oooooooooo`08ooooo`0=oiRHV?lQ8B7ok^k^oooooom4A4Coooooo`000?oooooo
MgMgoiRHV?ooooooV9RHogMgM`0:ooooo`03o`000?oooooooooo00kooooo00Go410@okZj^_l0003o
MgMgoc8b<P03ooooo`05ogMgMonHV9Soooooo`000?mgMgL06Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`002oooool6o`00
00;ooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`0:
ooooo`Ko00001_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@o`000?ooool04Ooo
ool6o`000006ooooool0003ooooooiRHV?lQ8B7ok^k^1?ooool01Ol@413ooooooooooooooooo410@
00Kooooo0_l000000ooooooo0000ooooo`08ooooo`Ko00001Oooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41001?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00Cooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00;ooooo00Oo
410@oooooooooooooooooa0@4?oooooo000000kooooo00?o0000ooooooooool02?ooool01OnHV9So
8B4Qonk^k_oooooo000000;ooooo00Go410@oooooooooooooooooa0@400;ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooool000000oooool01Ol@413ooooooooooooooooo000001Sooooo00?o
0000ooooooooool01Ol00003ooooo`05oa0@4?ooooooooooooooool@41003_ooool001?ooooo00Co
A4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`03ooooo`03ojVYZOl@413ooooo00;ooooo00Co0000oooooooo
oooooooo0_l0000Booooo`03o`000?oooooooooo00Cooooo00Ko0000ooooooooooooV9RHob4Q8Oo^
k^h3ooooo`05o`000?ooooooooooooooool000001Oooool2o`0000?ooooo0_l00009ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Co
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`02ooooo`07o`000?oooooooooooooo
ool0003oooooo`00000>ooooo`03o`000?oooooooooo00Wooooo00CoV9RHob4Q8Oo^k^ko00000_oo
ool01Ol0003ooooooooooooooooo000000_ooooo00?o0000ooooooooool03oooool00ol0003oZJVY
oa0@4003ooooo`05o`000?ooooooooooooooool000006?ooool01ol0003ooooooooooom4A4CogMgM
ooooool000001?ooool01Ol0003ooooooooooooooooo000000kooooo000Cooooo`04omgMgOmEEEGo
ooooo`0000Cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool00_ooool00ol@413o0000okZj^P03ooooo`07o`000?ooooooooooooooool0
003oooooo`00000@ooooo`03o`000?oooooooooo00Gooooo00Ko0000ooooooooooooooooogMgMomV
IVH3ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000001Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooooooo0_l0000@ooooo`03o`000?oooooooooo00Wooooo00?oMgMgo`00
0?ooool00_ooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000ooooooooool03oooool2
o`000005okZj^_ooooooooooooooool000000oooool00ol0003oooooooooo`0Fooooo`07o`000?oo
ooooooooomgMgOmEEEGoooooo`000004ooooo`05o`000?ooooooooooooooool000003_ooool001Co
oooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`04ooooo`03okZj^_lQ8B7ooooo00;ooooo00Oo410@oooo
oooooooooooooa0@4?oooooo0000013ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`02ooooo`03o`00
0?oooooooooo00Kooooo0_l00004ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`06ooooo`;o00000oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00;o
oooo00Ko410@oooooooooooooooooa0@4?l0000@ooooo`03o`000?oooooooooo00[ooooo00Go0000
oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Wooooo00?o0000ooooooooool03_oo
ool01?l0003ooooookZj^_lQ8B43ooooo`06oa0@4?ooooooooooooooool@413o00005_ooool00ol0
003oooooooooo`02ooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@400>
ooooo`005?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01oooool0
0ol0003oooooooooo`0<ooooo`09o`000?ooooooooooooooool@413oV9RHoooooonj^[[o000000?o
oooo00OoMgMgoiRHV?ooooooV9RHogMgMooooooo0000013ooooo00?o0000ooooooooool01Oooool2
o`000004okZj^_ooooooV9RHoa0@40?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03o`00
0?oooooooooo00Oooooo1Ol0000;ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool00_ooool01_mgMgOo
V9RHoooooonHV9SoMgMgo`00017ooooo00?o0000ooooooooool01Oooool01Ol0003o^[Zjooooool0
003o410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00cooooo
00Go410@o`000?oooooo^[Zjo`000003ooooo`06ogMgMonHV9SooooooiRHV?mgMgOo00005_ooool0
0ol0003oooooooooo`02ooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0>ooooo`005Oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@03ooooo`07onk^k_lb<S;o0000oc8b<_o^k^koooooo`00000@ooooo`03o`000?oooooooooo
00Gooooo00Ko0000oiRHV?l@413o0000ob4Q8Oo<c<`3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1?ooool00ol0003oooooooooo`0Eooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP06ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01Wooooo00?oEEEEofIVI_l000001?ooool01_o^k^ko
<S8bo`000?lb<S;ok^k^o`00017ooooo00?o0000ooooooooool01Oooool01OnHV9So410@o`000?l0
003oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03o`000?oooooooooo00cooooo
00GoZJVYo`000?l0003o410@ojVYZ@03ooooo`06onk^k_lb<S;o0000oc8b<_o^k^ko00005Oooool0
0ol0003oooooooooo`04ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0>ooooo`009oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0@ooooo`?o00004Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0M
ooooo`00:?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo0000017ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool07_ooool002Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool04?ooool01?l0003oooooooooool0000?oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo01kooooo000Xooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00oooooo00Go0000oooooooo
ooooooooo`00000?ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo01kooooo000Yooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00ko
oooo00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo01;ooooo0_l00004oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool07oooool001Koooooool00010o`0001?o
oooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001_ooool00ol0
003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00007ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`05ooooo`04o`000?oooooo
ooooooooo`?o000000?oooooo`000?ooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool04Oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooo000000Oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00007oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
000000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`00:_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo023ooooo000Zooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool08?ooool002_ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0Pooooo`00:oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0:oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo023ooooo000/
ooooo`05o`000?ooooooooooooooool000006Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool08?ooool002gooooo00Co0000ooooool0003o00006Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool08?oo
ool002kooooo0_l0000Kooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0:ooooo`;o00002?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo027ooooo001;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0Qooooo`00Boooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool08Oooool004_ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo027ooooo001;ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0Qooooo`00Boooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08_ooool004_ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02;ooooo001;ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo02oooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Rooooo`00C?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0aooooo`04o`000?oooooo0000o`0000kooooo0_l00009ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
03Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool08_ooool004cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0<Oooool3o`0000oo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;o
oooo001<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo02?ooooo001<ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04?ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02?ooooo001<
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo02?ooooo001<ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04?ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02?ooooo001=ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo04?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0hooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo02?ooooo001=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02?ooooo001=ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo04?ooooo0_l0000:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Wooooo00Go0000oooooooooooooooo
o`00000Gooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08oooool004gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0@oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Wooooo00Go
0000ooooooooooooooooo`00000Gooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
9?ooool004gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo03Wooooo00Co0000oooooooooooo00006?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo02Cooooo001>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0iooooo`04o`000?ooooooooooo`0001Sooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Tooooo`00C_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`13ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0>_ooool2o`0001Wooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Tooooo`00C_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`13ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0>_ooool2o`0001Wooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Tooooo`00C_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0iooooo`Go00001_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Tooooo`00C_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0iooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Tooooo`00C_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0jooooo`03
oiRHV?lQ8B7ok^k^00Oooooo0ol0000:ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Kooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Tooooo`00C_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0kooooo`03oiRH
V?lQ8B7ok^k^00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Fooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool09Oooool004oooooo00Go0000oooooooooooooooo
o`00000Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0??ooool00omgMgOoIVIV
ooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Eoooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo02Gooooo001?ooooo`04o`000?ooooooooooo`0001?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool09Oooool004oooooo00Co0000oooooooooooo00004oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo03Wooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo02Gooooo001?ooooo`04o`000?oooooo0000o`0001?ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0iooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Uooooo`00D?ooool2o`0001Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`14ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000?oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo02Gooooo001Vooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0A?ooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000003oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Uooooo`00I_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Co
oooo0_l0000<ooooo`05o`000?ooooooooooooooool000003oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo05Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Uoooo
o`00I_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Cooooo00?o0000oooooooo
ool02oooool01Ol0003ooooooooooooooooo000000oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Gooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09_ooool006Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo00_o
oooo00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0F?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Kooooo001Vooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooo0000013ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Hooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool09_ooool006Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo00cooooo00?o0000ooooool00000
4?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Vooooo`00I_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo04Cooooo00?o0000ooooooooool03?ooool3o`00013ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1Hooooo`05o`000?ooooooooooooooool00000:Oooool006Kooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Wooooo00Co
0000oooooooooooo0000:Oooool006Kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`15ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`1Jooooo`04o`000?ooooooooooo`0002Wooooo001Wooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0AOooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0F_ooool01?l0003oooooooooool0000Yooooo`00Ioooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo04Gooooo0_l0000Pooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0F_ooool00ol0003oooooo`00000Zooooo`00Ioooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo05_ooooo0_l0000Zooooo`00Ioooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo04Gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo08Oooooo001Wooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0AOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0Qoooool006Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`15ooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`27ooooo`00Iooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08Oooooo001Wooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0Qoooool006Sooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`15ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`27ooooo`00J?ooool01Ol0003ooooooooooooooooo000004Sooooo0_l0000Qoooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Qoooool006Sooooo00Go0000oooooooo
ooooooooo`000018ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`27ooooo`00J?ooool01Ol0003ooooooooooooooooo000004Sooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08Oooooo001Xooooo`05
o`000?ooooooooooooooool00000B?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0Qoooool006Sooooo00Go0000ooooooooooooooooo`000018oooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`27oooo
o`00J?ooool01Ol0003ooooooooooooooooo000003oooooo0_l000000ol@413oooooooooo`04oooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`27oooo
o`00J?ooool01Ol0003ooooooooooooooooo0000043ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Qoooool006Wo
oooo00?o0000ooooool00000?_ooool5o`0000Kooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo08Sooooo001Yooooo`03o`000?oooooo000003kooooo
00CoA4A4omgMgOoooooo00001oooool3o`00027ooooo00Go0000ooooooooooooooooo`00002:oooo
o`00JOooool00ol0003oooooo`00000nooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000oooo
ooooool08Oooool01Ol0003ooooooooooooooooo000008[ooooo001Yooooo`03o`000?oooooo0000
03oooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0Qooooo`05o`000?oooooooooo
ooooool00000R_ooool006Wooooo00?o0000ooooool00000?oooool00oo^k^koA4A4o`000007oooo
o`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`00002:ooooo`00JOooool2o`00
047ooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`0Qooooo`05o`000?oooooooooo
ooooool00000R_ooool00;Gooooo00?o0000ooooooooool08Oooool01Ol0003ooooooooooooooooo
000008[ooooo002eooooo`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`00002:
ooooo`00]Oooool00ol0003oooooooooo`0Qooooo`04o`000?ooooooooooo`0008_ooooo002eoooo
o`;o00008_ooool01?l0003oooooooooool0002;ooooo`00]Oooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooo000008_ooooo002eooooo`03o`000?oooooooooo02;ooooo00?o0000ooooool0
0000Roooool00;Gooooo00?o0000ooooooooool08_ooool00ol0003oooooo`00002;ooooo`00]Ooo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooo000008_ooooo002eooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooool00000Roooool00;Gooooo00?o0000ooooooooool08_ooool3o`00
08_ooooo002eooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0R_ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05
onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OmEEEGo
MgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?nHV9SooooooiRH
V?lQ8B401_ooool3o`000;3ooooo002Zooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0
003oooooooooo`2`ooooo`00Z_ooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo0;3o
oooo002Zooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0/?ooool00:_ooooo00Co
c<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo
00?o0000ooooooooool0/?ooool00:[ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`00
0?oooooooooo0;3ooooo002Zooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0002`ooooo`00Z_oo
ool01Oo<c<co0000o`000?l0003oc<c<0;Wooooo002Zooooo`05oa0@4?nj^[[ooooookZj^_l@4100
^Oooool00:[ooooo00Go0000okZj^_oooooo^[Zjo`00002iooooo`00Z_ooool01OnYZJWo410@o`00
0?l@413oZJVY0;Wooooo003oooooofWooooo002cooooo`03o`000?nj^[[ooooo0;;ooooo002coooo
o`;o<S8b/oooool008Cooooo0_l000001_l@413oooooooooool@413o0000oa0@41Sooooo00GoA4A4
o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOo0000
okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o410@olc<c01looooo`00QOooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Oooooo1_l0000=ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wo
oooo1_l00009ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B400oooool01OmEEEGoMgMgoooooonHV9So
8B4Q07cooooo0025ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06oooool01?l0
003oooooooooool@4103ooooo`03oa0@4?oooooooooo013ooooo00?o0000ooooooooool06_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00001looooo`00QOoo
ool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000=ooooo`05ogMgMolb<S;ooooooooo
ool000000oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo1_l00009oooo
o`05oc8b<_nHV9SooooooiRHV?lb<S800oooool01Ol0003oV9RHoooooonHV9So8B4Q07cooooo0025
ooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo00006Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;o
oooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo01[ooooo00Goc<c<o`00
0?l0003o0000olc<c003ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0O?ooool008Gooooo00Ko0000
ohN7QonYZJWo^[ZjoeEEEOl0000Iooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooo
oooooa0@400@ooooo`03oa0@4?l0003o000000?o00006Oooool01Ol@413o^[Zjoooooonj^[[o410@
00?ooooo00?oEEEEohN7Qoooool0O_ooool008Gooooo00Ko0000oc8b<_oooooooooooc8b<_l0000I
ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Booooo`03o`000?oo
oooooooo01[ooooo00Go0000okZj^_oooooo^[Zjo`000003ooooo`03omgMgOl@413oV9RH07kooooo
0024ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool4o`0000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0Booooo`03o`000?oooooooooo01[ooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@04ooooo`04olc<c?m4A4Co0000oa0@47cooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(88) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .13178 m
.00236 .13331 L
.00488 .13534 L
.00942 .14013 L
.01483 .14793 L
.01975 .15711 L
.03057 .18396 L
.04057 .21191 L
.0433 .21836 L
.04586 .2234 L
.04726 .22564 L
.04853 .22735 L
.04995 .22882 L
.05073 .22944 L
.05147 .22989 L
.05222 .2302 L
.05289 .23037 L
.05367 .23042 L
.05441 .23033 L
.05572 .22984 L
.05645 .22938 L
.05713 .22884 L
.05856 .22735 L
.06014 .22519 L
.06331 .21937 L
.07456 .19002 L
.08481 .16367 L
.08985 .1535 L
.09533 .14476 L
.1005 .13843 L
.10529 .13409 L
.1079 .13228 L
.11036 .13092 L
.11304 .12976 L
.11456 .12926 L
.11594 .12889 L
.11731 .12863 L
.11857 .12846 L
.1193 .12841 L
.11997 .12839 L
.12073 .12839 L
.12145 .12843 L
.12216 .1285 L
.1229 .12861 L
.12424 .1289 L
.12498 .12912 L
.12567 .12936 L
.12725 .13006 L
.12857 .13081 L
.12997 .13177 L
Mistroke
.13248 .13402 L
.13547 .13766 L
.13818 .14209 L
.14075 .14749 L
.14353 .1549 L
.14856 .17332 L
.15349 .19862 L
.1587 .23301 L
.16349 .26881 L
.16802 .30049 L
.17052 .31424 L
.17194 .32018 L
.17324 .3243 L
.17434 .32665 L
.17555 .328 L
.17681 .328 L
.178 .3267 L
.17931 .32383 L
.18068 .31929 L
.18314 .30777 L
.18868 .27127 L
.19388 .23376 L
.19878 .20317 L
.20318 .1821 L
.20566 .17301 L
.20794 .16633 L
.21027 .16106 L
.21283 .1569 L
.21412 .1554 L
.2155 .1542 L
.2168 .15342 L
.21799 .15301 L
.21936 .15286 L
.22063 .15301 L
.22129 .1532 L
.22202 .1535 L
.22278 .1539 L
.2235 .15436 L
.22601 .15661 L
.22742 .1583 L
.22871 .16011 L
.2332 .16823 L
.23811 .18033 L
.24324 .19656 L
.24801 .21518 L
.26766 .32372 L
.27304 .35335 L
.27576 .36478 L
.2773 .36972 L
.27799 .37151 L
Mistroke
.27875 .37315 L
.28007 .37519 L
.28132 .3761 L
.28254 .376 L
.28368 .37502 L
.28502 .37277 L
.28624 .36973 L
.28765 .36508 L
.28898 .35968 L
.29458 .32814 L
.29973 .29237 L
.30528 .25403 L
.31136 .21743 L
.31633 .19312 L
.32165 .17248 L
.32727 .15601 L
.33252 .14461 L
.33521 .13995 L
.33807 .13577 L
.34321 .13003 L
.34606 .12771 L
.34874 .12602 L
.35167 .12465 L
.35332 .12407 L
.35483 .12367 L
.35607 .12342 L
.35738 .12325 L
.35862 .12316 L
.35975 .12315 L
.36108 .12322 L
.36183 .1233 L
.36252 .1234 L
.36379 .12366 L
.36513 .12401 L
.3678 .12501 L
.37029 .12628 L
.37303 .12805 L
.37597 .13044 L
.38149 .13655 L
.38661 .14444 L
.39223 .15592 L
.39822 .17161 L
.40922 .2086 L
.41404 .22533 L
.41678 .23384 L
.41933 .24067 L
.42188 .2461 L
.4233 .24843 L
.4246 .25006 L
.42597 .25124 L
Mistroke
.42675 .25166 L
.42746 .25189 L
.42877 .25191 L
.42944 .25172 L
.43017 .25135 L
.43094 .2508 L
.43168 .2501 L
.43308 .2484 L
.43457 .24601 L
.43621 .24282 L
.44187 .22835 L
.45298 .1956 L
.46306 .17229 L
.46817 .16396 L
.47369 .15697 L
.47891 .15194 L
.48371 .14848 L
.48881 .14577 L
.49171 .14461 L
.49301 .14418 L
.49442 .1438 L
.49518 .14364 L
.49588 .14351 L
.49656 .14341 L
.49727 .14333 L
.49851 .14328 L
.49988 .14334 L
.50063 .14343 L
.50133 .14355 L
.50209 .14373 L
.50289 .14397 L
.50425 .1445 L
.50573 .14528 L
.50711 .14622 L
.50839 .14728 L
.51127 .15049 L
.51382 .15448 L
.51651 .1602 L
.51892 .1669 L
.52118 .17475 L
.52631 .19925 L
.52915 .21717 L
.53185 .23709 L
.53691 .28036 L
.53999 .30774 L
.54289 .33115 L
.54549 .3478 L
.54621 .35136 L
.54696 .35458 L
.5483 .35886 L
Mistroke
.54951 .36096 L
.55079 .36135 L
.55201 .35994 L
.55312 .35717 L
.55441 .35222 L
.55583 .34492 L
.55839 .3274 L
.5636 .28207 L
.56913 .23353 L
.57391 .19933 L
.57644 .18491 L
.57917 .17229 L
.58167 .16325 L
.58396 .15689 L
.58615 .15238 L
.58725 .15064 L
.58845 .14912 L
.58913 .14843 L
.58984 .14783 L
.59112 .14708 L
.5925 .14675 L
.59328 .14678 L
.59401 .14695 L
.59534 .14764 L
.59654 .14871 L
.59721 .14949 L
.59794 .1505 L
.59926 .1528 L
.60173 .15876 L
.60435 .16777 L
.60659 .17791 L
.60907 .19207 L
.61453 .23636 L
.6176 .27018 L
.62042 .30632 L
.62557 .37714 L
.6284 .41133 L
.6298 .42493 L
.63108 .43498 L
.63233 .44215 L
.63366 .44666 L
.63499 .44787 L
.63575 .44705 L
.63646 .44532 L
.63769 .44019 L
.63882 .43327 L
.64135 .4112 L
.65092 .29935 L
.65349 .27455 L
.65624 .25341 L
Mistroke
.65782 .24366 L
.65926 .23625 L
.66071 .22997 L
.66205 .22522 L
.6633 .2216 L
.66467 .21844 L
.66605 .21603 L
.66681 .21501 L
.6675 .21424 L
.66879 .21322 L
.67016 .21262 L
.67143 .21246 L
.67264 .21257 L
.67384 .21289 L
.67513 .21338 L
.67746 .21443 L
.67881 .21501 L
.67955 .21529 L
.68023 .21551 L
.68145 .2158 L
.68278 .21594 L
.68345 .21594 L
.68418 .21587 L
.68551 .21557 L
.6868 .21504 L
.68799 .21436 L
.68927 .2134 L
.69069 .21207 L
.69355 .20852 L
.69607 .20445 L
.69837 .20002 L
.70354 .18813 L
.71289 .16511 L
.71792 .15404 L
.72326 .14381 L
.72788 .1366 L
.73287 .13065 L
.73594 .12782 L
.73876 .12566 L
.74141 .124 L
.7428 .12327 L
.7443 .1226 L
.74567 .12211 L
.74691 .12175 L
.74816 .12149 L
.74934 .12133 L
.75066 .12124 L
.75188 .12126 L
.75323 .12137 L
.7539 .12146 L
Mistroke
.75465 .12159 L
.756 .1219 L
.75725 .12227 L
.75874 .12284 L
.7601 .12346 L
.7626 .12495 L
.76528 .1271 L
.76768 .1296 L
.77029 .13301 L
.77501 .14126 L
.78056 .15493 L
.78642 .17512 L
.79693 .22571 L
.80203 .25206 L
.80454 .26354 L
.80686 .27251 L
.80813 .27655 L
.80953 .28019 L
.81094 .2829 L
.81171 .28397 L
.81244 .28469 L
.81372 .28528 L
.81489 .28506 L
.81617 .28401 L
.81753 .282 L
.81873 .2795 L
.81983 .27669 L
.82228 .2688 L
.82671 .25083 L
.83677 .20842 L
.84185 .19215 L
.84442 .1858 L
.84724 .18023 L
.84964 .17655 L
.85223 .17352 L
.85467 .17139 L
.8569 .16994 L
.85824 .16927 L
.85967 .16869 L
.86103 .16827 L
.86225 .16798 L
.8637 .16773 L
.86451 .16762 L
.86526 .16755 L
.86664 .16747 L
.86733 .16744 L
.86809 .16743 L
.87056 .16742 L
.87192 .16742 L
.87319 .16741 L
Mistroke
.87456 .16739 L
.87528 .16737 L
.87606 .16734 L
.87873 .1672 L
.88013 .16712 L
.88089 .16709 L
.8816 .16705 L
.88286 .16701 L
.88424 .167 L
.88556 .16702 L
.88676 .16709 L
.88815 .16723 L
.88946 .16744 L
.89064 .1677 L
.8919 .16807 L
.89297 .16847 L
.89415 .16902 L
.89542 .16977 L
.89678 .17079 L
.89923 .17335 L
.9007 .17542 L
.90205 .17776 L
.90512 .18488 L
.90783 .19362 L
.91072 .2059 L
.91355 .22141 L
.91622 .23937 L
.9212 .28133 L
.92653 .33257 L
.92913 .35542 L
.93149 .37222 L
.93278 .37909 L
.934 .38385 L
.93528 .38687 L
.936 .38762 L
.93667 .38769 L
.93798 .38608 L
.93873 .38415 L
.93943 .3817 L
.94083 .37493 L
.94235 .36518 L
.95241 .2674 L
.95732 .22244 L
.96176 .19085 L
.9663 .16743 L
.96879 .15781 L
.97113 .15051 L
.97352 .14461 L
.97605 .13976 L
.97882 .13578 L
Mistroke
.98136 .1331 L
.98358 .13139 L
.98482 .13066 L
.98596 .13011 L
.98701 .12972 L
.98816 .12939 L
.98924 .12919 L
.99025 .12909 L
.99141 .12907 L
.9925 .12914 L
.99369 .12932 L
.99498 .12962 L
.99625 .13002 L
.9976 .13055 L
1 .13178 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo04cooooo0ol0001Qooooo`00Q_ooool5o`0002[ooooo00?o0000
ooooooooool0B_ooool2o`0000;ooooo0ol0001Oooooo`00Q?ooool2o`0000Gooooo0_l0000Xoooo
o`03o`000?oooooooooo04Sooooo0_l00006ooooo`;o0000G_ooool003Wooooo1ol00013ooooo`03
o`000?oooooooooo00Kooooo0_l0000Wooooo`;o0000B?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo04;ooooo1Ol0000Dooooo`005_ooool00ol0003oooooooooo`0Nooooo`;o0000
1_ooool2o`00047ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo04Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`10ooooo`;o0000
1?ooool00ol0003oooooooooo`0Aooooo`005oooool2o`0001kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0?ooo
ool00ol0003oooooooooo`0Hooooo`006Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo03gooooo00?o0000ooooooooool06Oooool001Wooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0Pooooo`?o0000A_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
03gooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0Mooooo`?o000000Coooooo`000?l0003o00006_ooool2o`0002Sooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo01Wooooo000Jooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool06oooool2o`0000Cooooo00Co0000oooooooo
oooo00006?ooool4o`0002Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0loooo
o`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0Fooooo`;o00008_ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0000Goooo
o`;o00000_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`0Jooooo`006oooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool05?ooool4o`00023ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Cooooo0_l00002ooooo`03
o`000?oooooooooo01Cooooo00Go0000ooooooooooooooooo`00000Uooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Jooooo`007?ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`00000Foooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo03Wooooo00?o0000ooooooooool06oooool001cooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo01_ooooo000Eooooo`;o0000
00Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h04Oooool00ol0003oooooooooo`06
ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`05o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0>ooooo`03o`000?oooooooooo00_ooooo1?l000002?l@413oooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^5?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`04ooooo`Go000000So410@ooooooooooook^k^
oc8b<_l0003o<S8bonk^kQKooooo00Co0000oooooooooooooooo1Ol00003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`0Cooooo`05oiRHV?l@413o0000oc8b<_o<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Oooooo00?o0000ooooooooool00oooool2o`000009
oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Fooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?l0003oV9RHogMgM`0Aooooo`03o`000?oooooooooo00Kooooo00Go
410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9So0000oiRHV?mgMgL04Oooool00ol0003o
ooooooooo`05ooooo`07o`000?ooooooV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?l0003oV9RHogMgM`0Dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo
00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Kooooo00Wo0000oooooooooooooooooiRHV?lQ
8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000oooooooo
ool04oooool00ol@413o^[Zjo`00000;o`0001Kooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool000_ooooo1_l00002ooooo`Go
00000oooool01Ol@413oooooo`000?oooooo410@013ooooo00?o0000ooooool000001Ol00006oooo
o`05o`000?ooooooooooooooool@41000_ooool00ol0003o410@ooooo`0@ooooo`03o`000?oooooo
000000Ko00000_ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41003Ooo
ool00ol0003oooooooooo`03ooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
oooo0000ooooool@41004oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Co
oooo00Go410@oooooooooooooooooa0@400Eooooo`03o`000?oooooooooo00?ooooo00?oV9RHob4Q
8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool05?ooool2
o`000003ooooool0003ooooo00;ooooo00Go410@oooooooooooooooooa0@4002o`0001Gooooo00Co
0000oooooooooooooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41003_ooool001?ooooo
00CoA4A4omgMgOoooooo00001?ooool00ol0003oooooooooo`02o`00013ooooo00?o0000oooooooo
ool02_ooool00onYZJWo410@ooooo`02ooooo`03o`000?oooooooooo00;o00004?ooool00ol0003o
ooooooooo`06ooooo`07o`000?oooooooooooooooonHV9So8B4Qonk^kP03ooooo`05o`000?oooooo
ooooooooool000003Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooool0003oooooo`00000Booooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool00000
1?ooool01Ol0003ooooooooooooooooo000001Gooooo00?o0000ooooooooool01?ooool00onHV9So
8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Boooo
o`05o`000?ooooooooooojVYZOl@41000oooool01Ol0003ooooooooooooooooo000000;ooooo00?o
0000ooooooooool04_ooool02?l0003oooooooooooooooooA4A4omgMgOoooooo00001?ooool01Ol0
003ooooooooooooooooo000000kooooo000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo00?o0000
ooooooooool00_l0000?ooooo`03o`000?oooooooooo00[ooooo00?o410@o`000?nj^[X00oooool0
0ol0003oooooooooo`02o`00013ooooo00?o0000ooooooooool01oooool01_l0003ooooooooooooo
ooooMgMgofIVIP?ooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02o`0001;ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooo`000004ooooo`05o`000?ooooooooooooooool000005Oooool00ol0
003oooooooooo`05ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo017ooooo00Ko0000oooooooooooo410@o`000?nj^[X3ooooo`05o`00
0?ooooooooooooooool000000_ooool2o`0001?ooooo00So0000ooooooooooooooooomgMgOmEEEGo
ooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`005?ooool00omgMgOoc<c<o`00
0004ooooo`05oa0@4?ooooooooooo`000?l@41003oooool00ol0003oooooooooo`0;ooooo`03okZj
^_lQ8B7ooooo00;ooooo00Go410@oooooooooooo0000oa0@400?ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@oooo
ooooool02_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooo0000oa0@400Aooooo`03o`000?oooooooooo00[ooooo0_l00005ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool01_ooool00ol0003oooooo`000004ooooo`05oa0@4?oooooo
ooooooooool@41005?ooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
0_ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00?oMgMgolc<c?l000001?ooool01Ol@413o
oooooooooooooooo410@00kooooo000Dooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?oo
ooooV9RHo`00000>ooooo`03o`000?oooooooooo00Wooooo00Go410@oiRHV?oooooo^[Zjo`000003
ooooo`05ogMgMonHV9SooooooiRHV?l000003oooool00ol0003oooooooooo`08ooooo`;o000000Co
^[ZjoooooonHV9So410@0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Soooooo`000?mgMgL04Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooo000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0D
ooooo`03o`000?oooooooooo00?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0@ooooo`07o`000?oooooo410@oiRHV?oo
oooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00?ooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00kooooo000Eooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bo`00
000>ooooo`03o`000?oooooooooo00Wooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^
k_lb<S;o0000oc8b<_l000003oooool00ol0003oooooooooo`09ooooo`05o`000?l@413o0000ob4Q
8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?o0000ooooooooool03Oooool0
0omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_l000004?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`07ooooo`03oeEEEOl0003o000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Dooooo`03o`00
0?oooooooooo00?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01_ooool00ol0003oooooooooo`0@ooooo`07o`000?ooooooZJVYoa0@4?l0003o410@ojVY
Z@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00Cooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00ko
oooo000Pooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07Oooool0023ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0Mooooo`008Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo01gooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool07Oooool0027ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Nooooo`00
5_ooooooo`00043o00004oooool001Kooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00007ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`;o
00001oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`04ooooo`;o00001oooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooool000001oooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`005_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool01?l0003oooooooooool0
0007ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooo`00
0005ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000oooooooo
ool01?ooool2o`0000Oooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00?ooooo0ol00004ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooool000001oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Aooooo`008oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool03oooool8o`00023ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07_ooool002?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00gooooo0_l0
000Wooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo01oooooo000Sooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool07oooool002Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Ooooo
o`009Oooool01?l0003oooooooooool0000Oooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Oooooo`009_ooool3o`0001oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01oooooo0018ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0@ooooo`;o0000
2?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01oooooo0018ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Oooooo`00B?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07oooool0
04Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
01oooooo0019ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`00000Doooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Ooooo
o`00BOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0Rooooo`;o000000?oooooo`000?l000005?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08?ooool004Wooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool08oooool3o`0001Gooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0[ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo023ooooo0019ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo023ooooo0019
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo03_ooooo0_l00009ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02_ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool08?ooool004[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo02cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08?ooool004[ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool08?ooool004[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo02gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool08?ooool004[ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0??oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02kooooo00Go0000oooooooooooooooo
o`00000Nooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08?ooool004[ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0??ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02kooooo00Go
0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
8?ooool004[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo02kooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool08?ooool004[ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0??ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo02kooooo00Co0000oooooooooooo00008?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo023ooooo001:ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03cooooo0_l0
000:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo02oooooo00?o0000ooooool000008?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo023ooooo001;ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03gooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Qooooo`00Boooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0moooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo027ooooo001;ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03gooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool08Oooool004_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo05Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Qooooo`00Booo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0E?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo027ooooo001;ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo03;ooooo1Ol00006ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0E?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo027ooooo001;ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
03?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0E?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo027ooooo001<oooo
o`05o`000?ooooooooooooooool000006Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo03Cooooo00?oV9RHob4Q8Oo^k^h01oooool3o`0000[ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0E?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo027ooooo001<ooooo`05o`000?oooooooooo
ooooool000006Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Gooooo00?oV9RH
ob4Q8Oo^k^h01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Qooooo`00C?ooool01?l0003oooooooooool0000J
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0=_ooool00omgMgOoIVIVooooo`05
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo027ooooo001<ooooo`04o`000?ooooooooooo`0001_ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool08_ooool004cooooo00Co0000oooooooooooo00006oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo03Cooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oo
oooooooo00_ooooo00Go0000ooooooooooooooooo`00000Cooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0EOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02;ooooo
001=ooooo`03o`000?oooooo000001_ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0dooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0;ooooo`05o`00
0?ooooooooooooooool000004oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Rooooo`00COooool2o`0001cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo
00Go0000ooooooooooooooooo`00000Dooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0E_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02;ooooo001[ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`05o`00
0?ooooooooooooooool000005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Rooooo`00K?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo03oooooo0_l0000<ooooo`05o`000?ooooooooooooooool0
00005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Rooooo`00K?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000001Co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool08_ooool006cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0oooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000Dooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo02;ooooo001/ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
?oooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000005?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Rooooo`00K?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo043ooooo
00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000001Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool08_ooool006gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`10ooooo`03o`00
0?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000Dooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02;o
oooo001]ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0@?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooo000001Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`1Gooooo`05o`000?ooooooooooooooool000009Oooool006gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00cooooo00?o0000ooooool00000
5Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Oooooo00Go0000oooooooooooo
ooooo`00000Uooooo`00KOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo043ooooo
00?o0000ooooooooool03?ooool2o`0001Kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1Hooooo`05o`000?ooooooooooooooool000009Oooool006gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`10ooooo`;o00003_ooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0F?ooool01Ol0003ooooooooooooooooo000002Go
oooo001]ooooo`05o`000?ooooooooooooooool00000@oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0F?ooool01Ol0003ooooooooooooooooo0000
02Gooooo001^ooooo`04o`000?ooooooooooo`0004?ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo05Sooooo00Go0000ooooooooooooooooo`00000U
ooooo`00K_ooool00ol0003oooooo`000014ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`1Hooooo`04o`000?ooooooooooo`0002Kooooo001^oooo
o`?o0000A?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0F?ooool01?l0003oooooooooool0000Vooooo`00]Oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0FOooool00ol0003oooooo`00000Voooo
o`00]Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0FOooool00ol0003oooooo`00000Vooooo`00]Oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0FOooool00ol0003oooooo`00000Vooooo`00]Ooo
ool2o`0002Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Iooooo`;o00009ooo
ool00;Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo08;ooooo002eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`22ooooo`00]Oooool00ol0003oooooooooo`0Vooooo`05o`000?oooooooooooooo
ool00000QOooool00;Gooooo00?o0000ooooooooool09_ooool01Ol0003ooooooooooooooooo0000
08Gooooo002/ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0Vooooo`05
o`000?ooooooooooooooool00000QOooool00:gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Vooooo`05o`000?ooooooooooooooool00000QOooool00:[ooooo1Ol00006ooooo`03
o`000?oooooooooo02Kooooo00Go0000ooooooooooooooooo`000025ooooo`00Z_ooool01?m4A4Co
gMgMooooool00007ooooo`?o00009_ooool01Ol0003ooooooooooooooooo000008Gooooo002Zoooo
o`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool09_ooool01Ol0003ooooooooooooo
oooo000008Gooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool09_ooool0
1Ol0003ooooooooooooooooo000008Gooooo002[ooooo`03onk^k_m4A4Co000000Oooooo00?o0000
ooooooooool09_ooool01Ol0003ooooooooooooooooo000008Gooooo002/ooooo`03ogMgMol0003o
oooo00Kooooo00?o0000ooooooooool09_ooool01?l0003oooooooooool00026ooooo`00]Oooool0
0ol0003oooooooooo`0Vooooo`04o`000?ooooooooooo`0008Kooooo002eooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooool00000Q_ooool00;Gooooo00?o0000ooooooooool09oooool00ol0
003oooooo`000026ooooo`00]Oooool2o`0002Sooooo00?o0000ooooool00000Q_ooool00;Gooooo
00?o0000ooooooooool09oooool00ol0003oooooo`000026ooooo`00]Oooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooo000008Kooooo002eooooo`03o`000?oooooooooo02Oooooo0_l00027
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go
k^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000oiRHV?ooooooV9RH
ob4Q8@06ooooo`?o0000/?ooool00:[ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`00
0?oooooooooo0;3ooooo002Zooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0/?oo
ool00:[ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`2`ooooo`00Zoooool01?o<
c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`2`ooooo`00Z_ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000
ooooooooool0/?ooool00:[ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo0;3ooooo002Zooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`000;3ooooo002Zoooo
o`05olc<c?l0003o0000o`000?o<c<`0^Oooool00:[ooooo00Go410@okZj^_oooooo^[Zjoa0@402i
ooooo`00Z_ooool01Ol0003o^[Zjoooooonj^[[o00000;Wooooo002Zooooo`05ojVYZOl@413o0000
oa0@4?nYZJT0^Oooool00?ooooooJOooool00;?ooooo00?o0000okZj^_ooool0/_ooool00;?ooooo
0_lb<S:cooooo`00Q?ooool2o`000006oa0@4?oooooooooooa0@4?l0003o410@6?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`03ohN7Qol0003o
^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0
0oooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<07cooooo0025ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01oooool6o`0000gooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9Sooooo
oiRHV?mgMgL00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Ooo
ool6o`0000Wooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@03ooooo`05ob4Q8OnHV9SooooooiRHV?lQ
8B40O?ooool008Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Kooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool04?ooool00ol0003oooooooooo`0Jooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000007cooooo0025oooo
o`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000gooooo00GoMgMgoc8b<_oooooooooo
o`000003ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02oooool6o`0000Wooooo
00Go<S8boiRHV?ooooooV9RHoc8b<P03ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80O?ooool008Go
oooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Iooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_oo
ool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool06_ooool01Oo<c<co0000
o`000?l0003oc<c<00?ooooo00Goc<c<o`000?l0003o0000olc<c01looooo`00QOooool01_l0003o
QhN7ojVYZOnj^[[oEEEEo`0001Wooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooo
oooo410@013ooooo00?o410@o`000?l000000ol0000Iooooo`05oa0@4?nj^[[ooooookZj^_l@4100
0oooool01Ol@413o^[Zjoooooonj^[[o410@07cooooo0025ooooo`06o`000?lb<S;ooooooooooolb
<S;o00006Oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool0
0ol0003oooooooooo`0Jooooo`05o`000?nj^[[ooooookZj^_l000000oooool01Ol0003o^[Zjoooo
oonj^[[o000007cooooo0024ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?oo
ool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Booooo`03o`000?oooooooooo01[ooooo
00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0O?ooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(90) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .16802 m
.00942 .19128 L
.01483 .20595 L
.01975 .21812 L
.02225 .22321 L
.02496 .22747 L
.02568 .22835 L
.02644 .22915 L
.02782 .23024 L
.02911 .23084 L
.02984 .231 L
.03053 .23103 L
.03182 .23075 L
.03305 .2301 L
.03416 .22921 L
.03536 .22791 L
.03806 .22386 L
.04057 .21886 L
.05251 .18612 L
.05838 .1698 L
.06377 .15689 L
.06859 .14735 L
.07388 .13895 L
.07919 .13252 L
.08208 .1298 L
.08481 .12764 L
.08738 .12594 L
.09017 .12441 L
.0925 .12338 L
.09506 .12249 L
.09649 .12211 L
.09783 .12184 L
.09852 .12173 L
.09925 .12163 L
.10004 .12155 L
.10077 .1215 L
.10208 .12148 L
.1033 .12152 L
.10463 .12165 L
.10538 .12175 L
.10606 .12187 L
.10729 .12215 L
.1086 .12252 L
.11095 .12341 L
.11348 .12474 L
.11626 .12672 L
.11866 .12896 L
.12124 .13199 L
.12589 .13946 L
.12857 .14513 L
Mistroke
.13141 .15246 L
.13653 .1696 L
.14262 .19748 L
.14813 .2291 L
.15336 .26113 L
.1561 .27669 L
.159 .2906 L
.16023 .29542 L
.16155 .29973 L
.1623 .30178 L
.16299 .30335 L
.16434 .30562 L
.16554 .30671 L
.16685 .30686 L
.16809 .30604 L
.16924 .30448 L
.17048 .30197 L
.17178 .29848 L
.17412 .29041 L
.17937 .26699 L
.18397 .24554 L
.18887 .22606 L
.19168 .21726 L
.19424 .21088 L
.1968 .20595 L
.19922 .20258 L
.20059 .20117 L
.20204 .20003 L
.20328 .1993 L
.20464 .19873 L
.20541 .1985 L
.20611 .19833 L
.20692 .19819 L
.20768 .1981 L
.20904 .198 L
.20981 .19797 L
.21052 .19795 L
.21175 .19793 L
.21305 .19789 L
.21416 .19783 L
.21537 .19773 L
.21668 .19756 L
.21742 .19742 L
.21809 .19728 L
.2194 .19693 L
.22061 .19651 L
.22295 .19543 L
.22549 .19379 L
.22772 .19189 L
.23009 .18938 L
Mistroke
.24051 .17445 L
.24626 .16648 L
.24909 .16324 L
.25047 .1619 L
.25172 .16085 L
.25291 .16003 L
.2542 .15936 L
.25556 .15895 L
.25684 .15891 L
.25752 .15903 L
.25826 .1593 L
.25904 .15972 L
.25976 .16028 L
.26105 .16165 L
.26244 .16373 L
.2637 .16621 L
.26507 .1696 L
.26757 .17777 L
.27 .18856 L
.27224 .20142 L
.27668 .23651 L
.28156 .2913 L
.28629 .35405 L
.28897 .38748 L
.29146 .41257 L
.29277 .4223 L
.29396 .42866 L
.29534 .43276 L
.29663 .43331 L
.29799 .43038 L
.29924 .42459 L
.30062 .41509 L
.30207 .40185 L
.31179 .27635 L
.31682 .22109 L
.31965 .19778 L
.32223 .18088 L
.32527 .16544 L
.32815 .15453 L
.33081 .14719 L
.33231 .14404 L
.3337 .14167 L
.33506 .13983 L
.33649 .13831 L
.33771 .13732 L
.33905 .13649 L
.3405 .13585 L
.34131 .13559 L
.34204 .13541 L
.34273 .13529 L
Mistroke
.34348 .13519 L
.34483 .13512 L
.34609 .13518 L
.34748 .13538 L
.34817 .13553 L
.34892 .13573 L
.35028 .13621 L
.35162 .13683 L
.3529 .13755 L
.3553 .13921 L
.36015 .14358 L
.36465 .14846 L
.37486 .16351 L
.39459 .21092 L
.39999 .2257 L
.40294 .23282 L
.4057 .2384 L
.40806 .24215 L
.40926 .24367 L
.41058 .245 L
.41133 .24559 L
.41202 .24603 L
.41338 .2466 L
.41462 .24675 L
.41593 .24652 L
.41732 .24585 L
.41858 .24483 L
.41997 .24329 L
.42144 .2412 L
.42391 .23668 L
.42661 .23053 L
.4384 .19741 L
.44411 .18165 L
.4495 .16844 L
.45474 .15784 L
.45958 .14992 L
.46428 .14349 L
.46946 .13771 L
.47466 .1334 L
.4775 .13161 L
.48016 .13021 L
.483 .12894 L
.4844 .1284 L
.4857 .12797 L
.48697 .12761 L
.48812 .12736 L
.4894 .12716 L
.49076 .12705 L
.49148 .12705 L
.49223 .12708 L
Mistroke
.49359 .12723 L
.49434 .12736 L
.49504 .12753 L
.49663 .12804 L
.49803 .12863 L
.4993 .1293 L
.50216 .13128 L
.50456 .13358 L
.50722 .13699 L
.50999 .14184 L
.51259 .1479 L
.51723 .16313 L
.51984 .17458 L
.52223 .18715 L
.52731 .22111 L
.53286 .26852 L
.53562 .29388 L
.53861 .31972 L
.53998 .33019 L
.54143 .33985 L
.5428 .3473 L
.54404 .35254 L
.54532 .35625 L
.5467 .3582 L
.54798 .35807 L
.54919 .35624 L
.54987 .3545 L
.55059 .35212 L
.5519 .34652 L
.55485 .32851 L
.56466 .24704 L
.56725 .22771 L
.57005 .20991 L
.57247 .19729 L
.57511 .18634 L
.57805 .17742 L
.57965 .17385 L
.58114 .17127 L
.58186 .17027 L
.58254 .16946 L
.58381 .16831 L
.58518 .16756 L
.58595 .16735 L
.58667 .16729 L
.58798 .16749 L
.58922 .16804 L
.59034 .16881 L
.59156 .16993 L
.59429 .17339 L
.59682 .17757 L
Mistroke
.60634 .198 L
.61169 .21017 L
.61451 .21597 L
.61749 .22126 L
.6201 .22502 L
.62296 .22821 L
.62799 .23223 L
.63076 .23445 L
.63337 .23724 L
.63482 .23928 L
.63639 .24205 L
.6377 .24487 L
.63914 .24863 L
.64176 .2576 L
.64455 .27076 L
.64713 .28692 L
.64955 .30576 L
.65406 .34885 L
.65888 .39742 L
.66031 .40976 L
.66165 .41971 L
.66286 .42689 L
.66417 .43248 L
.66541 .43545 L
.66673 .43595 L
.66785 .43416 L
.66909 .42984 L
.67043 .42246 L
.67166 .41345 L
.67442 .38656 L
.67942 .32469 L
.68462 .26076 L
.68736 .23221 L
.69029 .20675 L
.693 .18741 L
.69546 .17303 L
.70026 .15208 L
.7026 .14468 L
.70513 .1384 L
.70752 .13384 L
.70972 .13058 L
.71231 .12762 L
.71467 .12555 L
.71598 .12463 L
.71739 .12377 L
.71862 .12317 L
.71997 .12263 L
.72122 .12226 L
.72238 .12203 L
.72361 .12189 L
Mistroke
.72494 .12187 L
.72617 .12195 L
.72734 .12212 L
.72838 .12234 L
.72953 .12265 L
.73238 .12368 L
.73498 .1249 L
.73777 .12651 L
.74079 .12868 L
.74617 .13395 L
.75124 .14062 L
.76121 .15836 L
.76687 .17178 L
.77216 .18643 L
.78351 .22109 L
.7891 .2373 L
.79156 .24352 L
.79427 .24941 L
.79683 .25384 L
.79923 .25693 L
.80055 .25817 L
.80176 .25903 L
.80309 .25966 L
.80376 .25986 L
.80449 .25998 L
.80524 .26001 L
.80595 .25994 L
.80728 .25959 L
.80802 .25926 L
.80871 .25887 L
.81026 .25772 L
.8115 .25653 L
.81286 .25495 L
.81562 .25101 L
.82568 .23106 L
.8351 .20961 L
.85458 .16859 L
.85992 .15937 L
.86561 .15099 L
.87052 .14511 L
.87584 .13994 L
.87897 .13745 L
.88034 .13652 L
.88184 .13564 L
.88317 .13499 L
.88459 .13444 L
.88538 .1342 L
.88609 .13402 L
.88681 .13389 L
.88749 .13379 L
Mistroke
.88877 .13372 L
.89012 .13378 L
.89128 .13395 L
.89255 .13427 L
.89392 .13477 L
.89539 .13551 L
.89678 .13644 L
.89805 .13751 L
.9006 .14043 L
.90296 .14428 L
.90556 .15007 L
.90833 .1584 L
.91125 .16996 L
.914 .18394 L
.91915 .21969 L
.92937 .32578 L
.93186 .35203 L
.93453 .37538 L
.93606 .3854 L
.93678 .38911 L
.93745 .3919 L
.93812 .39405 L
.93886 .39563 L
.94019 .39643 L
.94141 .39481 L
.94273 .39058 L
.94397 .38437 L
.94512 .37694 L
.94958 .33609 L
.95441 .28302 L
.95957 .23217 L
.96226 .211 L
.9648 .19455 L
.96727 .18159 L
.96956 .17201 L
.97172 .1648 L
.97402 .15894 L
.97633 .15468 L
.97764 .1529 L
.97886 .15163 L
.98017 .15065 L
.98091 .15026 L
.98159 .14999 L
.98284 .14972 L
.98418 .14974 L
.98549 .15002 L
.98673 .15052 L
.98784 .15114 L
.98905 .152 L
.99182 .15467 L
Mistroke
.99475 .15853 L
1 .16802 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
000eooooo`?o0000OOooool00ol0003oooooooooo`2`ooooo`00<_ooool4o`000003ooooool0003o
000000;o0000N_ooool00ol0003oooooooooo`12ooooo`Ko0000J?ooool0037ooooo0_l00008oooo
o`03o`000?oooooooooo07;ooooo1?l000000ooooooo0000ooooo`11ooooo`;o00001_ooool2o`00
06Kooooo000`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0LOooool2o`0000?o
oooo0ol00011ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Hoooool002oooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`1^ooooo`;o00001_ooool2o`00043ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Zooooo`?o0000=Oooool002kooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`11ooooo`Ko00009Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooo000003oooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Xooooo`;o00000_ooool2o`0003Cooooo000]ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool0?oooool2o`0000Cooooo0_l0000Sooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooool00000?_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Kooooo0_l00005
ooooo`03o`000?oooooooooo037ooooo000]ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool02?ooool01?l0003oooooooooool0000mooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo037ooooo000/oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool0000l
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo033ooooo000/ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0?Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool02_ooool01Ol0003ooooooooooooooooo000003_ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0Fooooo`00;?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
03cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
00[ooooo00Go0000ooooooooooooooooo`00000kooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Cooooo1Ol0000F
ooooo`00:oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00_ooooo0_l00002oooo
o`03o`000?oooooooooo03Wooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05?ooool01Ol0003ooooooooooooooooo
000001Kooooo000Zooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool09?ooool2o`00
01Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`00:_ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo02;ooooo0_l000000ooooooo0000o`00000Cooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool001Gooooo0_l000002Ol@413ooooo
ooooooooooook^k^oc8b<_l0003o<S8bonk^kP09ooooo`03o`000?oooooooooo00kooooo00GoV9RH
oa0@4?l0003o<S8bolc<c002ooooo`06o`000?o^k^ko<S8bo`000?lb<S;ok^k^6oooool5o`0000;o
oooo00Ko0000onk^k_lb<S;o0000oc8b<_o^k^h>ooooo`03o`000?oooooooooo00_ooooo1?l00000
2?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^3_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool06_ooool4o`000008oa0@4?ooooooooooonk^
k_lb<S;o0000oc8b<_o^k^hAooooo`03o`000?oooooooooo00Kooooo1Ol00003ooooo`05onk^k_lb
<S;o0000oc8b<_l000006oooool01OnHV9So0000o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`03o`000?oooooooooo017ooooo00Co0000oooooooooooooooo0_l00000
2Ol@413oooooo`000?ooooook^k^oc8b<_l0003o<S8bonk^kP0>ooooo`005_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02Oooool00ol0003oooooooooo`0>ooooo`05
oa0@4?nj^[[oooooogMgMolb<S800_ooool01_l0003oMgMgoiRHV?ooooooV9RHogMgMa_ooooo00Go
V9RHob4Q8Ol0003oooooodA4A003ooooo`05o`000?nHV9SooooooiRHV?mgMgL03_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Coooo
o`?o00001_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04Oooool0
0ol0003oooooooooo`06ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooo
oonHV9So000001_ooooo00Go410@o`000?ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00[o0000oooo
ooooooooooooo`000?mgMgOoV9RHoooooonHV9SoMgMg3_ooool000_ooooo1_l00002ooooo`Go0000
0oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool01oooool6o`0000Ko
oooo00Go0000oooooooooooo0000oa0@4003ooooo`03oa0@4?oooooooooo017ooooo1_l00003oooo
o`03o`000?lQ8B7ok^k^00Cooooo00Go0000oooooooooooooooooa0@400>ooooo`03o`000?oooooo
oooo00;ooooo1_l00005ooooo`;o00000oooool01Ol@413ooooooooooooooooo410@00kooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00Co
0000oooooooooooo00001_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41004?ooool00ol0003oooooooooo`08ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Ko410@oooooooo
oooooooooa0@4?l0000Kooooo`04o`000?ooooooooooo`0000?ooooo00Go410@oooooooooooooooo
oa0@4006ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01Ol00003ooooo`05oa0@
4?ooooooooooooooool@41003_ooool001?ooooo00?oA4A4omgMgOooool00_l00003ooooo`05o`00
0?ooooooooooooooool000002?ooool00ol0003oooooooooo`0Booooo`04ojVYZOl@413ooooooooo
o`;o00000oooool00ol0003oooooooooo`0Iooooo`05o`000?ooooooV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool03_ooool2o`0000?ooooo00Go
0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004?ooool00ol0003o
ooooooooo`09ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Co0000oooooooooooooooo0_l0000Joooo
o`05o`000?ooooooooooojVYZOl@41000oooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool03oooool01ol0003ooooooooooom4A4CogMgMooooool000001?ooool01Ol0003o
oooooooooooooooo000000kooooo000Cooooo`03omgMgOmEEEGooooo00;o00000oooool01Ol0003o
oooooooooooooooo000000Oooooo00?o0000ooooooooool04_ooool00ol@413o0000okZj^P02oooo
o`;o00000oooool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooogMgMomVIVH00oooool2
o`0000;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0>ooooo`;o00000oooool0
1Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000@ooooo`03o`00
0?oooooooooo00[ooooo00?oMgMgofIVI_ooool00_ooool01ol0003ooooooooooooooooo0000oooo
ool000006Oooool01Ol0003ooooooa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo00oooooo00Oo0000oooooooooooogMgMoeEEEOoooooo000000Co
oooo00Go0000ooooooooooooooooo`00000>ooooo`005?ooool01?mgMgOoc<c<o`000?l00003oooo
o`05oa0@4?ooooooooooooooool@41001oooool00ol0003oooooooooo`0Cooooo`03okZj^_lQ8B7o
oooo00;ooooo00Go0000oooooooooooooooooa0@400Jooooo`03o`000?oooooooooo00;ooooo00Ko
0000oooooooooooooooooa0@4?l00002ooooo`03oa0@4?oooooooooo00_ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooo`000002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00ol0
003oooooooooo`0>ooooo`;o00001?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool@41000ooo
ool00ol@413oooooo`00000Hooooo`06o`000?oooooooooooooooonj^[[o8B4Q0oooool01Ol@413o
oooooooooooooooo410@00Oooooo00?o0000ooooooooool03_ooool01ol0003ooooooooooooooooo
MgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00kooooo000Dooooo`05onk^k_m4
A4Co0000ooooool000000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo00?o0000oooooooo
ool04?ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00Go0000oiRHV?ooooooV9RHogMgM`0I
ooooo`07o`000?oooooo0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMol0003ooooooiRHV?mg
MgL03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo000000;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03oooool00ol0003oooooooooo`08ooooo`05o`000?nj
^[[ooooooiRHV?l@41000oooool01omgMgOoV9RHoooooonHV9SoMgMgooooool000006?ooool01_l0
003o410@oiRHV?oooooo^[Zjo`0000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`03o`00
0?oooooooooo00kooooo00Oo0000ooooooooooooooooonk^k_m4A4Co000000Cooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0>ooooo`005Oooool01?mgMgOo0000ooooool00002ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`0Aooooo`05ojVYZOl@413o0000oa0@4?nYZJT0
0oooool01Ol0003o<S8bo`000?lb<S;ok^k^01Wooooo00Oo0000oooooonHV9So410@o`000?lQ8B7o
c<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03o`000?oooooooooo00cooooo00?o
EEEEofIVI_l000000_ooool01ol0003oooooonk^k_lb<S;o0000oc8b<_o^k^h03?ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`05ooooo`05o`000?ooooooEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00oooooo00?o0000ooooooooool02?ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP02ooooo`03o`000?oooooooooo01Cooooo00Oo0000oooooonYZJWo
410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool00_ooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03_ooool001Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0K
ooooo`006Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool06?ooool2o`0000gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool07?ooool001Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Kooooo0_l0000>ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo01cooooo000Iooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0@ooooo`Ko00004?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Looooo`006_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03ooo
ool2o`0001Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool07?ooool001Koooooool00010o`0001?ooooo000Foooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
000000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool00oooool0
0ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Oooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`005_ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooool000001ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool2o`0000Oooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooo000000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooo000000Oooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooool000001oooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooo`000007ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo000Kooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07Oooool001cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0Mooooo`007?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01go
oooo000Mooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07_ooool001kooooo00Co
0000oooooooooooo00008oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool07_ooool001kooooo1?l0000Sooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Nooooo`00AOooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05?ooool2o`0000Oooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Aooooo`;o00004Oooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo01kooooo0015ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Nooooo`00A_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool07_ooool004Kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`02o`0001Sooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo01kooooo0016ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01_ooooo1?l0
000Iooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Nooooo`00A_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Nooooo`00A_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Noooo
o`00Aoooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Nooooo`00Aoooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0hooooo`;o0000
2?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Qooooo`Go00008_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo01kooooo0017ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Oooooo`00Aoooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01oooooo0017ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`19ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07oooool004Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04Wo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Oooooo`00Aoooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0iooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0BOooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo01oooooo0017ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool07oooool004Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0O
ooooo`00Aoooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0iooooo`;o00002Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1:oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07oooool004Sooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0>Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04[ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Oooooo`00B?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0iooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo01oooooo0018ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07ooo
ool004Wooooo00Co0000oooooooooooo00008_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1;ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool07oooool004Wooooo00Co0000oooooooooooo00008_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08?oo
ool004Wooooo0_l000000ooooooo0000ooooo`0Qooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0;oooool5o`0000Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1;
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08?ooool004[ooooo0ol0000Roooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0;oooool01OnHV9So8B4Qonk^k_oooooo
A4A400Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool08?ooool0073ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0`ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol00009ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
04_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Pooooo`00L?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo037ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Pooooo`00L?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03;ooooo
00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`00L?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Pooooo`00L?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02oooooo00Go0000
okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0COoo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo023ooooo001`ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0;oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool08?ooool0073ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00000Nooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo027ooooo001`ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0:ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Qooooo`00L?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03[ooooo0_l0000;
ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo04gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Qooooo`00L?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02_ooool0
1Ol0003ooooooooooooooooo000001kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`1=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08Oooool0077ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00[ooooo00Co0000
oooooooooooo00008?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Qooooo`00LOooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02_ooool01?l0003oooooooooool0
000Pooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0C_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo027ooooo001aooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo0000023ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool08Oooool0077ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooool000008?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo04kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Qoooo
o`00LOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool02oooool00ol0003oooooo`00000Pooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0C_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo027ooooo001aooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooo0000023ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1>ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool08Oooool0077ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0Rooooo`00LOooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo03_ooooo0_l0000_ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0C_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo02;ooooo001aooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0Coooool01Ol0003ooooooooooooooooo000002Cooooo001aoooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Coooool01Ol0003ooooooooooooooooo
000002Cooooo001booooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Coooool01Ol0
003ooooooooooooooooo000002Cooooo001booooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0D?ooool01Ol0003ooooooooooooooooo000002Cooooo001booooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0D?ooool01Ol0003ooooooooooooooooo000002Cooooo001boooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0_oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0DOooool01?l0003oooooooooool0000T
ooooo`00L_ooool01Ol0003ooooooooooooooooo000003kooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo057ooooo00?o0000ooooool000009Oooool0
07;ooooo00Go0000ooooooooooooooooo`00000nooooo`;o0000<?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo057ooooo00?o0000ooooool000009Oooool007;ooooo00Go0000oooo
ooooooooooooo`00000nooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1Aooooo`03o`000?oooooo000002Gooooo001booooo`05o`000?oooooooooo
ooooool00000?_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0DOooool2o`0002Kooooo001booooo`05o`000?ooooooooooooooool00000?_ooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0D_ooool0
0ol0003oooooooooo`0Tooooo`00L_ooool01Ol0003ooooooooooooooooo000003kooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07Wooooo001boooo
o`05o`000?ooooooooooooooool00000=Oooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07Wooooo001boooo
o`05o`000?ooooooooooooooool00000=_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo033ooooo00Go0000ooooooooooooooooo`00001kooooo`00L_ooool01Ol0003ooooooooooooo
oooo000003?ooooo1Ol00006ooooo`03o`000?oooooooooo033ooooo00Go0000oooooooooooooooo
o`00001kooooo`00L_ooool01?l0003oooooooooool0000dooooo`04odA4A?oMgMgoooooo`0000Oo
oooo0ol0000`ooooo`05o`000?ooooooooooooooool00000Noooool007;ooooo00Co0000oooooooo
oooo0000=?ooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo033ooooo00Go0000
ooooooooooooooooo`00001kooooo`00Loooool00ol0003oooooo`00000eooooo`03ogMgMoo<c<co
000000Oooooo00?o0000ooooooooool0<?ooool01?l0003oooooooooool0001looooo`00Loooool0
0ol0003oooooo`00000eooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0<?ooool0
1?l0003oooooooooool0001looooo`00Loooool00ol0003oooooo`00000fooooo`03ogMgMol0003o
oooo00Kooooo00?o0000ooooooooool0<Oooool00ol0003oooooo`00001looooo`00Loooool00ol0
003oooooo`00000oooooo`03o`000?oooooooooo037ooooo00?o0000ooooool00000O?ooool007?o
oooo00?o0000ooooool00000?oooool00ol0003oooooooooo`0aooooo`03o`000?oooooo000007co
oooo001dooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`1kooooo`00]Oooool2o`0003?ooooo00?o0000ooooooooool0Noooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Zoooo
o`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OmE
EEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?nHV9Sooooo
oiRHV?lQ8B401_ooool3o`000;3ooooo002Zooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool0
0ol0003oooooooooo`2`ooooo`00Z_ooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo
0;3ooooo002Zooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0/?ooool00:_ooooo
00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Ko
oooo00?o0000ooooooooool0/?ooool00:[ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03
o`000?oooooooooo0;3ooooo002Zooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`2`ooooo`00Z_ooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0002`ooooo`00
Z_ooool01Oo<c<co0000o`000?l0003oc<c<0;Wooooo002Zooooo`05oa0@4?nj^[[ooooookZj^_l@
4100^Oooool00:[ooooo00Go0000okZj^_oooooo^[Zjo`00002iooooo`00Z_ooool01OnYZJWo410@
o`000?l@413oZJVY0;Wooooo003oooooofWooooo002cooooo`03o`000?nj^[[ooooo0;;ooooo002c
ooooo`;o<S8b/oooool008Cooooo0_l000001_l@413oooooooooool@413o0000oa0@41Sooooo00Go
A4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOo
0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool01?l@413o0000odA4A?o<c<`4
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0O?ooool008Gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`07ooooo`Ko00003Oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`03olc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009oooo
o`Ko00002oooool00onHV9So410@omgMg@03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0O?ooool0
08Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooooooo
oa0@40?ooooo00?o410@ooooooooool04?ooool00ol0003oooooooooo`0Mooooo`03ohN7QomEEEGo
oooo00;ooooo00Go410@oooooooooooooooooa0@401looooo`00QOooool01_l0003oooooodA4A?m4
A4Coooooo`0000Wooooo1_l0000=ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo1_l00009ooooo`05olc<c?lQ8B7o0000oeEE
EOl000000oooool01Ol0003ooooooooooooooooo000007cooooo0025ooooo`06o`000?oMgMgo<S8b
oeEEEOoMgMgo00006Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooooooooooo
ooooo`00000Booooo`03o`000?oooooooooo01[ooooo00Go8B4QohN7QoooooooV9RHo`000003oooo
o`05o`000?ooooooooooooooool00000O?ooool008Gooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0
000Iooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400@ooooo`03oa0@
4?l0003o000000?o00006Oooool01Ol0003ooooooooooooooooo000000?ooooo00Go410@oooooooo
oooooooooa0@401looooo`00QOooool01_l0003o<S8boooooooooooo<S8bo`0001Wooooo00?o0000
ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool06_oo
ool01OlQ8B7oV9RHoooooomgMgOoEEEE00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1looooo`00
Q?ooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Jooooo`05olc<c?l@413o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07cooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(92) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .23543 m
.00123 .23697 L
.00236 .23808 L
.00365 .23899 L
.00488 .23945 L
.00601 .23951 L
.00706 .23925 L
.00821 .23861 L
.00942 .23753 L
.01065 .23605 L
.01196 .23403 L
.01434 .22935 L
.01975 .21484 L
.0297 .18212 L
.03496 .16602 L
.04057 .15182 L
.04671 .13977 L
.05241 .13151 L
.05545 .12821 L
.05832 .12573 L
.06092 .12394 L
.06367 .12242 L
.06619 .12132 L
.06753 .12085 L
.06896 .12043 L
.07028 .12012 L
.07148 .11992 L
.07268 .11979 L
.07382 .11973 L
.07515 .11974 L
.07582 .11978 L
.07656 .11986 L
.07786 .12005 L
.07909 .1203 L
.08184 .12109 L
.08481 .12227 L
.08733 .12356 L
.09001 .12527 L
.09486 .12943 L
.10062 .1364 L
.10585 .14456 L
.11725 .16877 L
.12801 .19726 L
.13821 .22254 L
.14336 .23264 L
.14902 .24127 L
.1684 .26672 L
.17101 .2701 L
.17387 .27333 L
.17518 .27453 L
Mistroke
.17589 .2751 L
.17657 .27557 L
.17788 .27625 L
.17907 .27659 L
.18025 .27662 L
.18151 .2763 L
.18258 .27572 L
.18375 .27475 L
.18502 .27329 L
.18637 .27125 L
.18882 .26639 L
.19164 .25902 L
.19472 .24925 L
.2003 .22837 L
.21075 .18765 L
.21552 .17216 L
.22065 .15859 L
.22628 .14701 L
.23156 .13916 L
.23424 .13626 L
.23717 .13383 L
.24023 .13195 L
.2417 .13124 L
.24308 .13068 L
.24436 .13024 L
.24504 .13005 L
.24575 .12988 L
.24702 .12965 L
.24818 .12953 L
.24952 .12952 L
.25078 .12963 L
.25215 .1299 L
.25292 .13012 L
.25363 .13036 L
.25602 .13148 L
.25738 .13232 L
.25866 .13325 L
.26146 .13573 L
.26402 .13868 L
.26627 .14198 L
.26865 .1464 L
.27103 .15208 L
.27364 .16004 L
.2765 .17122 L
.2791 .18399 L
.28189 .20098 L
.28493 .22382 L
.29033 .27699 L
.29543 .33778 L
.2979 .36655 L
Mistroke
.30056 .39314 L
.30184 .40344 L
.30306 .41126 L
.30416 .41644 L
.30535 .41998 L
.30609 .42102 L
.30679 .42118 L
.3081 .41936 L
.30883 .41715 L
.3095 .41439 L
.31102 .40577 L
.31224 .39668 L
.31358 .38482 L
.31628 .35654 L
.32221 .28845 L
.32513 .25853 L
.32783 .23495 L
.33288 .20177 L
.33554 .1893 L
.33836 .17918 L
.34078 .17269 L
.34205 .17 L
.34339 .16764 L
.34457 .16594 L
.34585 .16444 L
.34702 .16339 L
.34811 .16265 L
.34878 .1623 L
.34951 .162 L
.35084 .16169 L
.35212 .16163 L
.35331 .16179 L
.3546 .16216 L
.35533 .16247 L
.35601 .16282 L
.35738 .16371 L
.35886 .16493 L
.36168 .16803 L
.36475 .17261 L
.37034 .18412 L
.38083 .21453 L
.38643 .23235 L
.38918 .24018 L
.3917 .24624 L
.394 .2505 L
.39516 .2521 L
.39643 .25339 L
.39771 .25417 L
.39908 .25442 L
.40037 .25409 L
Mistroke
.40154 .25332 L
.40291 .25186 L
.40437 .24968 L
.40697 .24426 L
.40978 .2366 L
.41287 .22654 L
.42358 .18757 L
.42903 .1701 L
.43422 .15649 L
.43893 .14664 L
.44395 .13844 L
.44939 .1319 L
.45443 .12758 L
.45752 .12556 L
.46043 .124 L
.46324 .1228 L
.46587 .12194 L
.46708 .12163 L
.46823 .12139 L
.46955 .12118 L
.47075 .12104 L
.47209 .12094 L
.47332 .12091 L
.47468 .12093 L
.47536 .12096 L
.47612 .12102 L
.4768 .12108 L
.47752 .12117 L
.4788 .12136 L
.48019 .12164 L
.4817 .12204 L
.48442 .12302 L
.48694 .1243 L
.48947 .12602 L
.49185 .1281 L
.49632 .1333 L
.49882 .13711 L
.50112 .1413 L
.50634 .15381 L
.51124 .17037 L
.51651 .19408 L
.52603 .25008 L
.53184 .2852 L
.5347 .2993 L
.53609 .30488 L
.53735 .30907 L
.53858 .31231 L
.53975 .31455 L
.54097 .31605 L
.5423 .31667 L
Mistroke
.54367 .31625 L
.54436 .31566 L
.54511 .31473 L
.54645 .3124 L
.5477 .30954 L
.58859 .24091 L
.60943 .1897 L
.62041 .15856 L
.62595 .14704 L
.62911 .14238 L
.63052 .14075 L
.63206 .13928 L
.63335 .13828 L
.63473 .13744 L
.63549 .13707 L
.63618 .1368 L
.63753 .13646 L
.63877 .13637 L
.64011 .13656 L
.64138 .13706 L
.64254 .13782 L
.64389 .13914 L
.64516 .14084 L
.64654 .14328 L
.64803 .14664 L
.65106 .15615 L
.65383 .16841 L
.65639 .18341 L
.65877 .20111 L
.66138 .22561 L
.66415 .25824 L
.66892 .32898 L
.67394 .40924 L
.67639 .4411 L
.67777 .45487 L
.67906 .46421 L
.68025 .46951 L
.68133 .47142 L
.68258 .47012 L
.68376 .46549 L
.68504 .4569 L
.6864 .44415 L
.68884 .4137 L
.69435 .32827 L
.69875 .2659 L
.70118 .23842 L
.70348 .21718 L
.70619 .19762 L
.70867 .184 L
.711 .17425 L
Mistroke
.71353 .1664 L
.71493 .16318 L
.71622 .16082 L
.71763 .15885 L
.71834 .15808 L
.71912 .15739 L
.72043 .15656 L
.72116 .15625 L
.72183 .15605 L
.72314 .15587 L
.72437 .15589 L
.72556 .15606 L
.72682 .15634 L
.72908 .15706 L
.73151 .15807 L
.7342 .15945 L
.74569 .16793 L
.75072 .17145 L
.75622 .1755 L
.76135 .1805 L
.76612 .18647 L
.77116 .19454 L
.77654 .20631 L
.78794 .24162 L
.79294 .25733 L
.79578 .26479 L
.79717 .26781 L
.79844 .27012 L
.79973 .27197 L
.80096 .27322 L
.80226 .27395 L
.80299 .27408 L
.80367 .27402 L
.80439 .27376 L
.80507 .27333 L
.80635 .27204 L
.80772 .26995 L
.8092 .26694 L
.81216 .25883 L
.81528 .24791 L
.82086 .22509 L
.83108 .18384 L
.83681 .16576 L
.84202 .15329 L
.84711 .14408 L
.8498 .1402 L
.85264 .13676 L
.85513 .13431 L
.85787 .13213 L
.86038 .13053 L
Mistroke
.86269 .12932 L
.86498 .12832 L
.86748 .12741 L
.86885 .127 L
.87012 .12667 L
.87141 .1264 L
.87263 .1262 L
.87377 .12607 L
.875 .12598 L
.87612 .12594 L
.87714 .12595 L
.87826 .126 L
.87948 .1261 L
.88076 .12624 L
.88196 .12642 L
.88468 .12697 L
.8872 .12768 L
.88997 .12877 L
.89292 .13042 L
.89546 .13235 L
.89785 .13468 L
.90048 .13789 L
.90331 .14229 L
.90825 .15316 L
.91074 .16069 L
.91346 .17095 L
.91829 .19541 L
.92278 .2264 L
.92808 .27258 L
.93382 .32702 L
.93645 .34875 L
.93789 .35863 L
.93924 .3662 L
.94039 .37118 L
.94162 .3749 L
.94299 .37693 L
.94424 .37683 L
.94545 .37497 L
.94673 .37119 L
.94793 .36602 L
.94903 .36013 L
.95425 .32112 L
.95887 .28162 L
.96376 .24567 L
.96584 .23342 L
.96808 .22261 L
.97054 .21345 L
.97164 .21025 L
.97283 .20736 L
.97399 .20513 L
Mistroke
.97507 .20355 L
.9761 .20246 L
.97719 .20173 L
.97817 .20144 L
.97909 .20144 L
.98009 .20174 L
.98117 .20238 L
.98236 .20343 L
.98346 .20469 L
.98596 .20841 L
.991 .21823 L
1 .23543 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
000[ooooo`Ko0000NOooool6o`0000Gooooo00?o0000ooooooooool0/?ooool002Wooooo0_l00006
ooooo`03o`000?oooooooooo07Cooooo0ol00004ooooo`?o00000oooool00ol0003oooooooooo`2`
ooooo`00:?ooool00ol0003oooooooooo`07ooooo`;o0000L_ooool2o`0000[ooooo00Co0000oooo
oooooooo0000M?ooool7o`0003Oooooo000Wooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0;?ooool4o`0003oooooo00?o0000ooooooooool02Oooool2o`000003ooooool0003o0000
077ooooo0_l00007ooooo`;o0000=Oooool002Kooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Yooooo`?o00000oooool2o`0003cooooo00?o0000ooooooooool03?ooool2o`00077o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0booooo`009_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0hooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0:?ooool3o`0004;ooooo
0_l0000=ooooo`03o`000?oooooooooo037ooooo000Uooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Wooooo`;o000000?oooooo`000?l00000@?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo037ooooo000Uooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo00;ooooo0_l0000oooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0<?ooool0
02Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0<?ooool002Cooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`0Aooooo`;o00009_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03co
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0_ooooo`008oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0booooo`03o`000?oooooooooo017ooooo0_l0000Vooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02oooooo
000Sooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04_ooool3o`0002Cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Cooooo`?o00009?ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo02kooooo000Rooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool04_ooool00ol0003oooooo`00000Sooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool04_ooool2o`000004ooooool0003o0000o`0002;ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0^ooooo`008_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Eooooo`?o00006?ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooo000002?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo0_l0000Pooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool0;Oooool001Gooooo0_l000002Ol@413ooooooooooooooooo
k^k^oc8b<_l0003o<S8bonk^kP02ooooo`03o`000?oooooooooo01Gooooo00Go0000oa0@4?l0003o
<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h05?ooool00ol0003oooooooooo`04oooo
o`Go00000oooool01Oo^k^ko<S8bo`000?l0003ok^k^01Gooooo0_l000000ooooooo0000o`000002
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPSooooo00?o0000oooooooo
ool04oooool01?l0003oooooooooool0000Nooooo`Go00000_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00?o0000ooooooooool04?ooool01?l0003oooooooooooooool6o`0000;ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0Gooooo`09o`000?oooooooooooooooonHV9So410@o`000?lb<S;o
c<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo01Cooooo0_l0
00002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0>ooooo`005_ooool00ol0003o
ooooooooo`02ooooo`07ogMgMonHV9SooooooiRHV?mgMgOoooooo`00000Hooooo`05oa0@4?l0003o
ooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg01Cooooo00?o0000ooooooooool0
1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHo`00000Doooo
o`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000004ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02?ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`00023ooooo
0_l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool00ol0003oooooooooo`0@ooooo`0:
o`000?oooooooooooooooonHV9So8B4Qonk^k_ooooooA4A4ooooo`;o000000GoMgMgoiRHV?oooooo
V9RHogMgM`0Fooooo`03o`000?oooooooooo00;ooooo00Go410@okZj^_ooooooMgMgoc8b<P03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`002oooool6o`0000;ooooo1Ol00003
ooooo`07oa0@4?ooooooooooooooool@413oooooo`00000@ooooo`Ko00000oooool01?l0003ooooo
ooooool00003ooooo`05oa0@4?ooooooooooooooool@41004oooool6o`0000?ooooo00?oV9RHob4Q
8Oo^k^h01?ooool01Ol@413ooooooooooooooooo000001?ooooo1_l000000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4007ooooo`03o`000?oo
oooooooo01Cooooo00Co0000oooooooooooo00008?ooool2o`0000?ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool00onHV9So
8B4Qonk^kP04ooooo`05o`000?ooooooooooooooool@41005_ooool00ol0003oooooooooo`06oooo
o`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`05ooooo`03o`000?oooooo
oooo017ooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41003_ooool001?ooooo00CoA4A4
omgMgOoooooo00001?ooool01?l0003oooooooooooooool2o`0001[ooooo00Co0000oooooonYZJWo
410@0oooool01Ol0003ooooooooooooooooo000001?ooooo00?o0000ooooooooool01oooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000004oooool00ol0003oooooooooo`05
ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000007ooooo`03o`00
0?oooooooooo01Cooooo00Co0000oooooooooooo00008?ooool2o`0000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000005Oooool00ol0003oooooooooo`06
ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oo
oooooooo017ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000000ko
oooo000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo00Co0000oooooooooooooooo0_l0000Koooo
o`;o000000Go^[Zjooooooooooooooooo`000003ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool02?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000004ooo
ool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000oooooooooooo
ooooo`000007ooooo`03o`000?oooooooooo01Cooooo00Co0000oooooooooooo00008?ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00Gooooo00?oMgMgofIVI_ooool00_ooool3o`000003ooooool0003o
oooo01Cooooo00?o0000ooooooooool01Oooool00ol@413o0000okZj^P03ooooo`05o`000?oooooo
ooooooooool000001oooool00ol0003oooooooooo`0Aooooo`04omgMgOmEEEGoooooo`0000Cooooo
00Go0000ooooooooooooooooo`00000>ooooo`005?ooool00omgMgOoc<c<o`000004ooooo`06oa0@
4?ooooooooooooooool@413o00006oooool00ol0003o^[Zjob4Q8@03ooooo`05oa0@4?oooooooooo
ooooool@41004oooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool@41000ooo
ool00ol@413o0000ooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000001?oo
ool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool05Oooool2o`0000;ooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00Go0000oooooooo
oooooooooa0@4002ooooo`03o`000?l@413ooooo01Cooooo00?o0000ooooooooool01_ooool00onj
^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41001oooool00ol0003oooooooooo`0B
ooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@400>ooooo`005?ooool0
0oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?l000006_ooool01Ol@413oV9RHo`00
0?nj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Booooo`03o`000?oooooooooo00Ko
oooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`06ogMgMonHV9SooooooiRHV?mgMgOo00004Ooo
ool00ol0003oooooooooo`08ooooo`;o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool05Oooool01Ol0003ooooooooooooooooo000001oooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`03ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonH
V9So000001Cooooo00?o0000ooooooooool01?ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`03o`000?oooooooooo01;ooooo00?ok^k^odA4A?l0
00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000Eooooo`03ogMgMol0003ooooo00?o
oooo00Gok^k^oc8b<_l0003o<S8bo`00000Jooooo`05ojVYZOl@413o0000o`000?nYZJT00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo00?o0000ooooooooool01_ooool01OnHV9So410@o`00
0?lQ8B7oc<c<00?ooooo00Kok^k^oc8b<_l0003o<S8bonk^k_l0000Aooooo`03o`000?oooooooooo
00Oooooo00?oEEEEo`000?l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000
ooooooooool05Oooool01Ol0003ooooooooooooooooo000001gooooo00?oEEEEo`000?l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`03ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01_o^k^ko<S8bo`000?lb<S;ok^k^
o`0001?ooooo00?o0000ooooooooool01?ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo01;ooooo00?oMgMgo`000?ooool0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Oooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Gooooo
00Go0000ooooooooooooooooo`00000Nooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0[ooooo`007_ooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool0:oooool001kooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02_ooooo000Nooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0[ooooo`007Oooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03oooool3o`00
01Wooooo000Foooooooo0000@?l0000Cooooo`005_ooool00ol0003oooooooooo`04ooooo`;o0000
1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooo000000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool0
00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`04ooooo`;o
00000oooool01Ol0003ooooooooooooooooo000001?ooooo000Fooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooool000001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo
00Gooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
000000Gooooo00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
000000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooo
oooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool0
0ol0003oooooo`000007ooooo`03o`000?oooooooooo00Cooooo0_l00003ooooo`05o`000?oooooo
ooooooooool000004oooool001cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0D
ooooo`007?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Cooooo000Kooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool05?ooool001_ooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Cooooo`006oooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01?ooooo000Jooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool0
01Wooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool06_ooool2o`0000Gooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo000Fooooo`04o`000?ooooooooooo`00
02Wooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool04Oooool001Kooooo0ol0000[ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Looooo`00AOooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07?ooool004Gooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01cooooo0016
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01;ooooo00Go0000ooooooooooooooooo`00000Nooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Looooo`00Aoooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Cooooo`;o000000?oooooo`000?ooool07Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07?ooool004Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool05?ooool2o`0001oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo01cooooo0018ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Gooooo0_l00006ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool07Oooool004Wooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
7Oooool004[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo01cooooo00Go0000ooooooooooooooooo`00000Uooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool07Oooool004_ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo01cooooo00Go0000ooooooooooooooooo`00000Uooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool07Oooool004cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01gooooo00Co0000ooooool0003o0000
9Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01gooooo001=ooooo`;o000000?o
ooooo`000?l000008?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Nooooo`;o00009_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo01kooooo001>ooooo`?o00008Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`16
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07_ooool007;ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01kooooo001booooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0=_ooool2o`0000Sooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01kooooo001booooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo04Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Nooooo`00L_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07_oo
ool007;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo01kooooo001cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Nooooo`00Loooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool07_ooool007?ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0[ooooo`Go00001_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Sooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Oooooo`00Loooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo02_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01oooooo001cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;Ooo
ool00onHV9So8B4Qonk^kP07ooooo`?o00002Oooool01?l0003oooooooooool0000Uooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01oooooo001cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;_oo
ool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo0000
9_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Oooooo`00Loooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo02oooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`0:ooooo`;o00009ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Oooooo`00Loooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`19ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool07oooool007?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0/ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`0c
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo01oooooo001dooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0;?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Oooooo`00M?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Oooooo`00M?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Oooooo`00M?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Oooooo
0_l0000dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0BOooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo023ooooo001dooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0BOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo023ooooo001d
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0c
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo023ooooo001dooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0B_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo023ooooo001dooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo023ooooo001dooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
B_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo023ooooo001eooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0Boooool01Ol0003ooooooooooooooooo000002?ooooo
001eooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>?ooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Boooool01Ol0003ooooooooo
oooooooo000002?ooooo001eooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>?oo
ool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Booo
ool01Ol0003ooooooooooooooooo000002?ooooo001eooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0>?ooool2o`0003Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`1;ooooo`05o`000?ooooooooooooooool000008oooool007Gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`1<ooooo`03o`000?oooooo000002Cooooo001eooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0C?ooool00ol0003oooooo`00000Tooooo`00MOooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo04cooooo00?o0000ooooool000009?ooool007Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooo000002Co
oooo001eooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>?ooool00ol0003ooooo
ooooo`0dooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0COooool00ol0003ooooo
ooooo`0Sooooo`00MOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Sooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07?ooooo001e
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0d
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Loooool007Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0hooooo`;o0000=Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo07?ooooo001eooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0Loooool007Gooooo00Go0000ooooooooooooooooo`00000kooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1dooooo`00MOooool01Ol0003ooooo
oooooooooooo000003_ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo07Cooooo001fooooo`04o`000?ooooooooooo`0003_ooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07Cooooo001fooooo`04o`00
0?ooooooooooo`0003;ooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1dooooo`00M_ooool01?l0003ooooo
ooooool0000cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo07Cooooo001fooooo`04o`000?ooooooooooo`00033o
oooo1Ol00006ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`1dooooo`00M_ooool00ol0003oooooo`00000aooooo`04odA4A?oMgMgoooooo`0000Oo
oooo0ol0000dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0M?ooool007Oooooo
0_l0000aooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo07Cooooo001gooooo`;o0000<_ooool00omgMgOoc<c<
o`000007ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`1dooooo`00Moooool00ol0003oooooooooo`0aooooo`03onk^k_m4A4Co000000Oooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07Cooooo002/
ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo07Cooooo002eooooo`03o`000?oooooooooo03Gooooo00Go0000oooo
ooooooooooooo`00001fooooo`00]Oooool00ol0003oooooooooo`0eooooo`04o`000?oooooooooo
o`0007Oooooo002eooooo`03o`000?oooooooooo03Gooooo00Co0000oooooooooooo0000Moooool0
0;Gooooo0_l0000fooooo`04o`000?ooooooooooo`0007Oooooo002eooooo`03o`000?oooooooooo
03Gooooo00Co0000oooooooooooo0000Moooool00;Gooooo00?o0000ooooooooool0=Oooool01?l0
003oooooooooool0001gooooo`00]Oooool00ol0003oooooooooo`0eooooo`04o`000?oooooooooo
o`0007Oooooo002eooooo`03o`000?oooooooooo03Gooooo00Co0000oooooooooooo0000Moooool0
0;Gooooo00?o0000ooooooooool0=Oooool01?l0003oooooooooool0001gooooo`00]Oooool00ol0
003oooooooooo`0eooooo`04o`000?ooooooooooo`0007Oooooo002eooooo`03o`000?oooooooooo
03Gooooo00Co0000oooooooooooo0000Moooool00;Gooooo0_l0000gooooo`;o0000N?ooool00;Go
oooo00?o0000ooooooooool0=_ooool2o`0007Sooooo002eooooo`03o`000?oooooooooo03Kooooo
0_l0001hooooo`00]Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo07Kooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00:[ooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oo
oooooooo0;3ooooo002Zooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0/?oo
ool00:[ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000/?ooool00:[ooooo00Go0000
oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03oeEEEOn7QhOo
oooo00Sooooo00?o0000ooooooooool0/?ooool00:[ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0
003oooooooooo`2`ooooo`00Zoooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OlQ8B7o
V9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05oc8b<_nHV9SooooooiRH
V?lb<S801_ooool3o`000;3ooooo002Zooooo`05olc<c?l0003o0000o`000?o<c<`0^Oooool00:[o
oooo00Go410@okZj^_oooooo^[Zjoa0@402iooooo`00Z_ooool01Ol0003o^[Zjoooooonj^[[o0000
0;Wooooo002Zooooo`05ojVYZOl@413o0000oa0@4?nYZJT0^Oooool00?ooooooJOooool00;?ooooo
00?o0000okZj^_ooool0/_ooool00;?ooooo0_lb<S:cooooo`00Q?ooool2o`000006oa0@4?oooooo
oooooa0@4?l0003o410@6?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0H
ooooo`04oa0@4?l0003oA4A4olc<c0Cooooo1Ol0001looooo`00QOooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Oooooo1_l0000=ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@
00Wooooo1_l0000;ooooo`03oiRHV?l@413ogMgM00?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A01l
ooooo`00QOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01_ooooo00Co0000oooo
oooooooo410@0oooool00ol@413oooooooooo`0@ooooo`03o`000?oooooooooo01gooooo00?oQhN7
oeEEEOooool00oooool00onHV9So8B4Qonk^kP1mooooo`00QOooool01_l0003oooooodA4A?m4A4Co
ooooo`0000Wooooo1_l0000=ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00_ooooo1_l00009ooooo`05olc<c?lQ8B7o0000oeEEEOl0
00001Oooool00onHV9So8B4Qonk^kP1looooo`00QOooool01_l0003ogMgMoc8b<_mEEEGogMgMo`00
01Wooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000004_oo
ool00ol0003oooooooooo`0Jooooo`05ob4Q8On7QhOooooooiRHV?l000001_ooool00omgMgOoIVIV
ooooo`1kooooo`00QOooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001Wooooo00?o0000oooooooo
ool01?ooool01Ol@413ooooooooooooooooo410@013ooooo00?o410@o`000?l000000ol0000Ioooo
o`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`1jooooo`00QOooool01_l0
003o<S8boooooooooooo<S8bo`0001Wooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg01;ooooo00?o0000ooooooooool06_ooool01OlQ8B7oV9RHoooooomgMgOoEEEE00?o
oooo00Go0000okZj^_ooooooV9RHoa0@401looooo`00Q?ooool00ol@413o0000ohN7Q`02ooooo`03
ohN7Qol0003o410@01Sooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0
003oooooooooo`0Jooooo`05olc<c?l@413o0000oc8b<_o^k^h00oooool01OnHV9So410@o`000?lQ
8B7oc<c<07cooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(94) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .23254 m
.00488 .20445 L
.00942 .18184 L
.01441 .162 L
.01975 .14634 L
.02244 .14037 L
.02535 .13512 L
.02792 .13143 L
.03065 .12834 L
.0331 .1262 L
.03441 .1253 L
.03581 .12449 L
.03709 .12388 L
.03826 .12343 L
.03944 .12309 L
.04057 .12285 L
.04126 .12274 L
.042 .12266 L
.04335 .12261 L
.04467 .12266 L
.04588 .1228 L
.04719 .12304 L
.04863 .12342 L
.05013 .12394 L
.05154 .12453 L
.05645 .12743 L
.05921 .12961 L
.06172 .13194 L
.07358 .14685 L
.08481 .1648 L
.09004 .17276 L
.09495 .17898 L
.09741 .18144 L
.10006 .18348 L
.1015 .18431 L
.10228 .18468 L
.10301 .18497 L
.1043 .18536 L
.10498 .18549 L
.10571 .18559 L
.10702 .18565 L
.10821 .18556 L
.10953 .18533 L
.1102 .18517 L
.11093 .18494 L
.11347 .18391 L
.11585 .18266 L
.12063 .17979 L
.12295 .17849 L
.12505 .17751 L
Mistroke
.12636 .17706 L
.12759 .17675 L
.12888 .1766 L
.12961 .17659 L
.13028 .17665 L
.13161 .17693 L
.13236 .1772 L
.13306 .17754 L
.13447 .17846 L
.13598 .17986 L
.13732 .18147 L
.13877 .18366 L
.14141 .18889 L
.14398 .19568 L
.14636 .20354 L
.15085 .22258 L
.1558 .24892 L
.16059 .27643 L
.1633 .29073 L
.16582 .30181 L
.16711 .30633 L
.16833 .30973 L
.169 .31122 L
.16973 .31251 L
.171 .31389 L
.17238 .31413 L
.17307 .31375 L
.17383 .31293 L
.17518 .31051 L
.17645 .30716 L
.1789 .29792 L
.18114 .28687 L
.18617 .25664 L
.19169 .22225 L
.19755 .19122 L
.20256 .17123 L
.20541 .1625 L
.20809 .15586 L
.21053 .15097 L
.21311 .14685 L
.21534 .14402 L
.21772 .1416 L
.22028 .13961 L
.22267 .13823 L
.22414 .13759 L
.22552 .13711 L
.22676 .13677 L
.2281 .1365 L
.22946 .1363 L
.23072 .13618 L
Mistroke
.23145 .13613 L
.23211 .13611 L
.23288 .13609 L
.2336 .13609 L
.23431 .13609 L
.23505 .13611 L
.23639 .13617 L
.23721 .13622 L
.23799 .13627 L
.23943 .1364 L
.24205 .13669 L
.24446 .13703 L
.24989 .13802 L
.25483 .13903 L
.25755 .13961 L
.26012 .14023 L
.26252 .14091 L
.26512 .14185 L
.26967 .14417 L
.27227 .14599 L
.27514 .14859 L
.27814 .15223 L
.28095 .15688 L
.28357 .16263 L
.28597 .16943 L
.2886 .17891 L
.29137 .19157 L
.30217 .27439 L
.30747 .33182 L
.3098 .35644 L
.31236 .38003 L
.31346 .38847 L
.31465 .39604 L
.31577 .40159 L
.3168 .40518 L
.31795 .40746 L
.31921 .40774 L
.3204 .40592 L
.3215 .40246 L
.3228 .39635 L
.32402 .38876 L
.3263 .37071 L
.33141 .32029 L
.33623 .27412 L
.33886 .25344 L
.34132 .23783 L
.34398 .22493 L
.34539 .21974 L
.34689 .21538 L
.34827 .21242 L
Mistroke
.34958 .21048 L
.35075 .20942 L
.35202 .20897 L
.35338 .20925 L
.35466 .21018 L
.35539 .21099 L
.35606 .21189 L
.35757 .21446 L
.36059 .22147 L
.36346 .22978 L
.369 .24733 L
.37161 .25492 L
.37402 .26074 L
.37521 .26305 L
.37651 .26507 L
.37782 .26651 L
.3792 .26732 L
.38042 .2674 L
.38172 .2668 L
.38295 .26559 L
.38408 .26394 L
.38545 .26126 L
.38672 .25816 L
.38959 .24922 L
.39481 .22831 L
.40409 .18803 L
.40897 .16979 L
.41411 .15431 L
.41938 .14236 L
.42421 .13427 L
.42874 .12863 L
.43131 .12617 L
.4337 .12431 L
.43651 .1226 L
.43917 .12138 L
.44156 .12056 L
.4429 .1202 L
.44415 .11993 L
.4455 .1197 L
.44621 .1196 L
.44698 .11952 L
.44778 .11947 L
.44854 .11944 L
.44922 .11944 L
.44997 .11946 L
.45131 .11956 L
.45206 .11965 L
.45275 .11976 L
.45408 .12003 L
.45533 .12037 L
Mistroke
.45786 .12127 L
.46023 .12238 L
.46304 .12404 L
.4656 .1259 L
.47083 .13099 L
.47371 .13467 L
.47644 .13879 L
.48574 .15748 L
.49585 .18514 L
.50101 .20022 L
.50658 .21439 L
.50914 .21959 L
.51183 .2239 L
.51413 .22655 L
.51543 .22763 L
.51664 .22835 L
.51801 .22884 L
.5193 .22902 L
.52046 .22896 L
.52172 .22869 L
.52309 .22818 L
.52454 .22747 L
.52714 .22595 L
.5298 .2245 L
.53056 .22416 L
.53129 .2239 L
.53265 .22359 L
.53343 .22354 L
.53415 .22359 L
.53494 .22375 L
.53578 .22406 L
.5365 .22445 L
.53717 .22492 L
.53871 .22642 L
.53994 .22809 L
.54125 .23035 L
.54363 .23577 L
.54644 .24458 L
.54901 .25481 L
.55421 .28066 L
.55696 .29542 L
.55986 .31002 L
.56234 .32026 L
.56374 .32473 L
.56506 .32785 L
.56626 .3297 L
.56737 .33048 L
.56864 .33026 L
.56985 .32892 L
.57098 .32667 L
Mistroke
.57219 .32324 L
.57436 .31458 L
.57694 .30072 L
.57928 .28568 L
.58911 .21676 L
.59449 .18633 L
.5995 .16517 L
.60212 .15667 L
.60493 .1493 L
.60805 .14302 L
.61089 .1388 L
.61346 .13601 L
.61492 .1348 L
.61627 .13389 L
.61754 .13318 L
.61874 .13265 L
.61998 .13222 L
.62136 .13188 L
.6226 .1317 L
.62392 .13162 L
.62516 .13166 L
.62629 .13179 L
.62763 .13206 L
.62838 .13226 L
.62907 .13247 L
.63169 .13354 L
.6342 .13489 L
.63697 .13665 L
.64256 .14091 L
.6474 .14556 L
.6526 .15186 L
.65715 .15853 L
.66199 .16725 L
.66489 .17382 L
.66751 .18109 L
.67263 .20026 L
.67551 .21472 L
.67861 .23411 L
.68423 .28134 L
.6891 .33437 L
.6943 .39355 L
.69584 .40855 L
.69729 .42068 L
.6986 .42945 L
.69927 .43308 L
.70001 .43632 L
.70136 .44004 L
.70209 .44086 L
.70278 .44084 L
.70401 .43888 L
Mistroke
.70534 .4341 L
.70601 .43065 L
.70673 .42627 L
.70802 .41667 L
.71095 .38834 L
.71629 .32533 L
.72111 .2717 L
.72632 .22697 L
.72943 .20725 L
.7323 .19308 L
.73503 .18266 L
.73643 .1784 L
.73793 .17455 L
.73928 .17167 L
.74052 .16951 L
.74178 .16774 L
.74295 .16645 L
.7443 .16537 L
.74501 .16497 L
.74577 .16466 L
.74705 .16441 L
.74777 .16441 L
.74846 .16451 L
.74969 .16493 L
.75101 .1657 L
.75225 .16675 L
.75338 .16798 L
.75615 .17212 L
.75877 .17759 L
.76398 .193 L
.76963 .21585 L
.77446 .23873 L
.77966 .26308 L
.78218 .27311 L
.78342 .2773 L
.78457 .28065 L
.78569 .28336 L
.78671 .2853 L
.78784 .28683 L
.78905 .28772 L
.79033 .2878 L
.79151 .28709 L
.7928 .28546 L
.79416 .28281 L
.79535 .27978 L
.79646 .27638 L
.79898 .26692 L
.8099 .21289 L
.81538 .18778 L
.82057 .16883 L
Mistroke
.82343 .16047 L
.82654 .1529 L
.82917 .14761 L
.83199 .14288 L
.83465 .13923 L
.83709 .13648 L
.84187 .1324 L
.84441 .1308 L
.84719 .12938 L
.85012 .1282 L
.85278 .12736 L
.85414 .12701 L
.85562 .12669 L
.85831 .12624 L
.8598 .12607 L
.86062 .126 L
.86138 .12594 L
.86273 .12586 L
.86344 .12584 L
.86421 .12582 L
.86557 .12582 L
.86635 .12584 L
.86706 .12586 L
.86837 .12593 L
.8691 .12598 L
.86977 .12604 L
.87102 .12618 L
.87238 .12637 L
.87484 .12685 L
.87735 .12754 L
.88003 .12852 L
.88256 .12973 L
.88486 .13109 L
.88757 .13307 L
.8905 .13578 L
.89584 .14262 L
.8985 .14718 L
.90143 .15327 L
.90735 .16961 L
.91284 .19021 L
.91798 .21419 L
.92319 .24146 L
.92887 .27032 L
.93147 .28151 L
.93425 .29112 L
.93559 .29476 L
.93686 .29754 L
.938 .29947 L
.93923 .30096 L
.94045 .30185 L
Mistroke
.94158 .30218 L
.94283 .30202 L
.94416 .30132 L
.94483 .30078 L
.94556 .30008 L
.94688 .29853 L
.94936 .295 L
.95868 .28486 L
1 .23254 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002Rooooo`Ko00003Oooool00ol0003oooooooooo`2`ooooo`008Oooool7o`0007Sooooo0_l00006
ooooo`;o00002oooool00ol0003oooooooooo`2`ooooo`008?ooool2o`0000Kooooo00?o0000oooo
ooooool0M?ooool00ol0003oooooooooo`08ooooo`;o00002Oooool00ol0003oooooooooo`1]oooo
o`Wo0000>_ooool001oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1booooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool2o`0006cooooo0_l00009ooooo`;o
0000>?ooool001oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1aooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Rooooo`Ko0000
@Oooool2o`0000gooooo00?o0000ooooooooool0=Oooool001kooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0aooooo`So0000>?ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo03gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0dooooo`007Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02oooooo0_l00007ooooo`Go0000<_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0cooooo`007Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool02oooool3o`0002oooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool02?ooool2o`00
03_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0booooo`007?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo03;ooooo000Looooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02_ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0<Oooool001_ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0aooooo`006oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool00oooool2o`0001kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0d
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0<?ooool001_ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03;ooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0`ooooo`006_ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo02oooooo000Eooooo`;o000000Wo410@oooooooooooo0000onk^k_lb<S;o0000
oc8b<_o^k^h04Oooool00ol0003oooooooooo`06ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^013ooooo00?o0000ooooooooool02?ooool5o`0000?ooooo
00Ook^k^oc8b<_l0003o<S8bonk^k_oooooo000001[ooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^0_ooool00ol0003oooooooooo`0Eooooo`05o`000?ooooooooooooooool0
00007oooool00ol0003oooooo`000003o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h5ooooo`03o`000?oooooooooo01;ooooo1Ol000002?oooooo0000o`000?o^k^ko<S8bo`000?lb
<S;ok^k^4_ooool00ol0003oooooooooo`06ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00?o0000ooooooooool05_ooool2o`000009oa0@4?oo
ooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Fooooo`0:o`000?oooooooooooooo
ool0003oMgMgoiRHV?ooooooV9RHogMgMa7ooooo00?o0000ooooooooool01_ooool01Ol@413o^[Zj
oooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0?ooooo`03o`000?oooooooooo
00Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`07ogMgMonHV9SooooooiRHV?mgMgOooooo
o`00000Looooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`03
o`000?oooooooooo01Gooooo00Go0000ooooooooooooooooo`00000Oooooo`05o`000?oooooooooo
ooooool000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool04_oo
ool01_nHV9So8B4Qonk^k_ooooooA4A4o`0000;ooooo0_l000000oooooooV9RHogMgM`0Aooooo`03
o`000?oooooooooo00Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0>ooooo`002oooool6o`0000;ooooo1Ol00002ooooo`03o`000?l@413o
oooo00;ooooo00?o410@ooooooooool04?ooool6o`0000Kooooo00Go0000oooooooooooooooooa0@
4003ooooo`03oa0@4?oooooooooo00gooooo00Co0000oooooooooooooooo1_l00003ooooo`03oiRH
V?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4002ooooo`03o`000?oooooooooo00ko
oooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Oo410@oooooooooooooooooa0@4?oooooo
000001Wooooo00Co0000oooooooooooo00007oooool01Ol0003ooooooooooooooooo000000Cooooo
00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo01?ooooo00CoV9RHob4Q8Oo^
k^ko00000oooool01Ol@413o0000oooooooooooo410@017ooooo00?o0000ooooooooool02oooool0
1Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool00oooool00ol0003ooooooooo
o`0Cooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00kooooo000Cooooo`04odA4A?oM
gMgoooooo`0000;ooooo00?o0000ooooool000000oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo00Sooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000oo
oooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooooooooooo
ool000000_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00;ooooo00Oo0000oooo
ooooooooooooo`000?oooooo000001Wooooo00Co0000oooooooooooo00007_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo01?ooooo00?oV9RHob4Q8Ol000000oooool2o`0000;ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0:ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oooooooo
ooooooooo`000005ooooo`03o`000?oooooooooo01?ooooo00CoA4A4omgMgOoooooo00001?ooool0
1Ol0003ooooooooooooooooo000000kooooo000Cooooo`04omgMgOmEEEGoooooo`0000;ooooo00?o
0000ooooool000000oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o
410@o`000?l000000_l000000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
oooo0_l0000Jooooo`04o`000?ooooooooooo`0001kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0D
ooooo`03ogMgMol0003ooooo00;ooooo00Go0000ooooool0003oooooo`00000@ooooo`03o`000?oo
oooooooo00[ooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000000Gooooo
00?o0000ooooooooool04oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?oooooooooooooo
ool000003_ooool001Cooooo00?oMgMgolc<c?l000000_ooool00ol0003ooooooa0@4003ooooo`03
oa0@4?oooooooooo01;ooooo00?o0000ooooooooool01Oooool2o`000005ob4Q8Ooooooo0000o`00
0?l@41000oooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00Go0000oooo
oooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool000006_ooool00ol0003ooooooooo
o`02ooooo`06oa0@4?ooooooooooooooool@413o00006oooool01?l0003oooooo`000?l0000Moooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@00Oooooo00?o0000ooooooooool04oooool2o`0000?ooooo00Go410@ooooool0003ooooooa0@
400@ooooo`03o`000?oooooooooo00_ooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooo
oooooooo410@00Gooooo00?o0000ooooooooool05?ooool00omgMgOoc<c<o`000004ooooo`05oa0@
4?ooooooooooooooool@41003_ooool001Cooooo00?ok^k^odA4A?l000000_ooool01ol0003ooooo
ogMgMonHV9SooooooiRHV?mgMgL05Oooool2o`0000?ooooo0_l000000ooooooo^[Zjo`000002oooo
o`;o000000CoV9RHoooooonHV9SoMgMg3_ooool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[o
oooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`02ooooo`06ogMgMonHV9SooooooiRHV?mgMgOo00006oooool00ol0
003oooooo`00000Mooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Oooooo00?o0000ooooooooool04?ooool01Ol0003o^[Zjooooool0
003o410@00?ooooo00GoMgMgoiRHV?oooooo0000ogMgM`0@ooooo`03o`000?oooooooooo00Sooooo
00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0
003oooooooooo`0Cooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>
ooooo`005Oooool02omgMgOo0000oooooooooooo0000ooooooo^k^ko<S8bo`000?lb<S;ok^k^01Ko
oooo1?l000001OnYZJWo410@o`000?l@413oZJVY00?ooooo00Go0000oc8b<_l0003o<S8bonk^kP0>
ooooo`03o`000?oooooooooo00[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool00ol0003oooooooooo`0Fooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bo`00000Mooooo`;o00007Oooool01ol0003oooooooooooooooooEEEE
ofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00?o0000ooooooooool04?oo
ool01OnHV9So410@o`000?l0003oc<c<00?ooooo00Gok^k^oc8b<_l0003o0000onk^kP0?ooooo`03
o`000?oooooooooo00Wooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01_ooool00ol0003oooooooooo`0Dooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0>ooooo`006Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo01_ooooo0_l0000Mooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0]ooooo`006?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
01_ooooo0_l0000Mooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0]ooooo`006?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool0;Oooool001Sooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo02cooooo000Gooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0/ooooo`005_ooooooo`00043o00004oooool0
01Kooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool2o`00
00Oooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0
003oooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`04ooooo`;o00001oooool00ol0003oooooooooo`05ooooo`;o00001Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool001Kooooo0_l0
0006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Cooooo0_l0
0007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool2o`0000Gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool001Oooooo
00?o0000ooooooooool0:oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool03_ooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000oooooooo
ool07_ooool00ol0003oooooo`00000Iooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0[ooooo`005oooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0>ooooo`05o`00
0?ooooooooooooooool000002oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo000001Wo
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02_o
oooo000Fooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo00kooooo00Go0000ooooooooooooooooo`00000;ooooo`03
o`000?oooooooooo01kooooo00Co0000oooooooooooo00006?ooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool0:oooool001Kooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool07oooool01Ol0003ooooooooooooooooo000000Cooooo1?l0000?ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Zooooo`005_ooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Oooooo`04o`000?ooooooooooooooo`;o000000Coooooo`000?l0003o00000_ooool2
o`0000kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo02[ooooo000Fooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool00oooool2o`00
00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool0:_ooool001Kooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07oooool2o`0000_o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Aooooo`00A_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool04Oooool004Oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01;ooooo0017
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0C
ooooo`00Aoooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool05?ooool004Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo01Gooooo0017ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Eooooo`00Aoooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool05_ooool004Sooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo027ooooo0_l0000=ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool05oooool004Sooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool01?l0
003oooooooooool0000Tooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0Hooooo`00B?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo0000
02Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
01Wooooo0018ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00[ooooo0_l0000Uooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Jooooo`00B?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Jooooo`00BOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool04Oooool01Ol0003ooooooooooooooooo000002Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Kooooo`00BOooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool04Oooool01Ol0003ooooooooooooooooo000002[ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Looooo`00BOooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04Oooool01Ol0003ooooooooo
oooooooo000002[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Mooooo`00BOoo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0aooooo`;o00003oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Booooo`04o`000?oo
ooooooooo`0002[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Nooooo`00B_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04_oo
ool3o`0002cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Nooooo`00B_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0@Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01oooooo001:ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool08?ooool004[ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo04;ooooo00Go0000ooooooooooooooooo`00000Soooo
o`00B_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0@oooool01?l0003oooooooooool0000Tooooo`00B_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Wooooo`Go
00001_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Cooooo0ol0000Tooooo`00
Boooool01?l0003oooooooooool0000Xooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool09oooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`1[ooooo`00Boooool01?l0003oooooooooool0000Xooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0:?ooool00onHV9So8B4Qonk^kP07ooooo`?o00004?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`1[ooooo`00Boooool3o`0002Wooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Zooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1[ooooo`00C?ooool2o`0002Wooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0[ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`1[ooooo`00N?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Aooooo`05o`000?ooooooooooooooool00000
8oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06_ooooo001hooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0:?ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo
00?o0000ooooooooool04Oooool01?l0003oooooooooool0000Tooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0Joooool007Sooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Xooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0Aooooo`04
o`000?ooooooooooo`0002Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1[oooo
o`00N?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03?ooooo00?o0000oooooooo
ool04_ooool2o`0002Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1[ooooo`00
N?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0
4_ooool2o`0002Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1[ooooo`00N?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03?ooooo0_l0000jooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0Joooool007Sooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`1[ooooo`00N?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
06_ooooo001hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0K?ooool007Sooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1/ooooo`00N?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0>Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo06cooooo001hooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0K?ooool007Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo03[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1/oooo
o`00N?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0>_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06cooooo001hooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0=?ooool2o`0003_ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1/ooooo`00N?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo06cooooo001hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0K?ooool0
07Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
03[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1/ooooo`00NOooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0>_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo06gooooo001iooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0KOooool007Wooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`1]ooooo`00NOooool01Ol0003ooooooooooooooooo000003Oooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06gooooo001iooooo`05o`000?oooooo
ooooooooool00000=oooool2o`0003cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`1]ooooo`00NOooool01Ol0003ooooooooooooooooo000003Oooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06gooooo001jooooo`04o`000?oooooo
ooooo`0003Oooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo06gooooo001jooooo`03o`000?oooooo000003Sooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo06gooooo001jooooo`03o`000?oooooo0000
03Sooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
06gooooo001jooooo`03o`000?oooooo000002oooooo0_l000000ol@413oooooooooo`04ooooo`03
o`000?oooooooooo03_ooooo00Go0000ooooooooooooooooo`00001`ooooo`00Noooool2o`00033o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0kooooo`05o`000?oooooooooooooo
ool00000L?ooool007_ooooo00?o0000ooooooooool0;?ooool5o`0000Kooooo00?o0000oooooooo
ool0>oooool01Ol0003ooooooooooooooooo0000073ooooo002Zooooo`04odA4A?oMgMgoooooo`00
00Oooooo0ol0000kooooo`05o`000?ooooooooooooooool00000L?ooool00:[ooooo00CogMgMoeEE
EOoooooo00001oooool00ol0003oooooooooo`0kooooo`05o`000?ooooooooooooooool00000L?oo
ool00:_ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0looooo`04o`000?oooooo
ooooo`00073ooooo002[ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0??ooool0
1?l0003oooooooooool0001`ooooo`00[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooo
oooo03cooooo00Co0000oooooooooooo0000L?ooool00;Gooooo00?o0000ooooooooool0??ooool0
1?l0003oooooooooool0001`ooooo`00]Oooool00ol0003oooooooooo`0looooo`03o`000?oooooo
0000077ooooo002eooooo`03o`000?oooooooooo03cooooo00?o0000ooooool00000LOooool00;Go
oooo0_l0000nooooo`;o0000LOooool00;Gooooo00?o0000ooooooooool0?Oooool00ol0003ooooo
ooooo`1`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go
k^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000oiRHV?ooooooV9RH
ob4Q8@06ooooo`?o0000/?ooool00:[ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`00
0?oooooooooo0;3ooooo002Zooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0/?oo
ool00:[ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`2`ooooo`00Zoooool01?o<
c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2
o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`2`ooooo`00Z_ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000
ooooooooool0/?ooool00:[ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo0;3ooooo002Zooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`000;3ooooo002Zoooo
o`05olc<c?l0003o0000o`000?o<c<`0^Oooool00:[ooooo00Go410@okZj^_oooooo^[Zjoa0@402i
ooooo`00Z_ooool01Ol0003o^[Zjoooooonj^[[o00000;Wooooo002Zooooo`05ojVYZOl@413o0000
oa0@4?nYZJT0^Oooool00?ooooooJOooool00;?ooooo00?o0000okZj^_ooool0/_ooool00;?ooooo
0_lb<S:cooooo`00Q?ooool2o`000006oa0@4?oooooooooooa0@4?l0003o410@6?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`03ohN7Qol0003o
^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`04oa0@4?l0003oA4A4olc<c0Kooooo
0_l000000ol@413oooooooooo`1jooooo`00QOooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Oooooo1_l0000=ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000;
ooooo`03oiRHV?l@413ogMgM00Kooooo00?o0000ooooooooool0Noooool008Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooooooooa0@40?ooooo00?o410@
ooooooooool04?ooool00ol0003oooooooooo`0Mooooo`03ohN7QomEEEGooooo00;ooooo1Ol0001l
ooooo`00QOooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000=ooooo`05ogMgMolb
<S;oooooooooool000000oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo
1_l00009ooooo`05olc<c?lQ8B7o0000oeEEEOl000000oooool01?m4A4CogMgMooooool0001moooo
o`00QOooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001Wooooo00Go0000ob4Q8Ol0003o<S8bolc<
c002ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0Jooooo`05ob4Q
8On7QhOooooooiRHV?l000000oooool01?oMgMgoEEEEooooool0001mooooo`00QOooool01_l0003o
QhN7ojVYZOnj^[[oEEEEo`0001Wooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooo
oooo410@013ooooo00?o410@o`000?l000000ol0000Iooooo`05o`000?ooooooooooooooool00000
1?ooool00omgMgOoc<c<o`00001mooooo`00QOooool01_l0003o<S8boooooooooooo<S8bo`0001Wo
oooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000oooo
ooooool06_ooool01OlQ8B7oV9RHoooooomgMgOoEEEE00Cooooo00?ok^k^odA4A?l00000OOooool0
08Cooooo00?o410@o`000?n7QhL00_ooool00on7QhOo0000oa0@400Hooooo`Co00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^01;ooooo00?o0000ooooooooool06_ooool01Oo<c<co410@o`000?lb
<S;ok^k^00Gooooo00?oMgMgo`000?ooool0O?ooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(96) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .20612 m
.00236 .19032 L
.00488 .1764 L
.00706 .16662 L
.00942 .15812 L
.01087 .15392 L
.0122 .15065 L
.01345 .14808 L
.01483 .14576 L
.01598 .14419 L
.01722 .14284 L
.01852 .14176 L
.01975 .14104 L
.02113 .14052 L
.02241 .14028 L
.02315 .14024 L
.02382 .14027 L
.02459 .14035 L
.02532 .1405 L
.02665 .1409 L
.02787 .14142 L
.02921 .14216 L
.03062 .14312 L
.03536 .14755 L
.04057 .15395 L
.05161 .16835 L
.05479 .17205 L
.0578 .17508 L
.06051 .17723 L
.06203 .17815 L
.06345 .1788 L
.06467 .17921 L
.06599 .17947 L
.06723 .17957 L
.06837 .17953 L
.06964 .17934 L
.07102 .17899 L
.07172 .17875 L
.07246 .17845 L
.07381 .17781 L
.07677 .17593 L
.07957 .17362 L
.08481 .16816 L
.09502 .15651 L
.1006 .15134 L
.10333 .14931 L
.10582 .14782 L
.10691 .1473 L
.1081 .14683 L
.10923 .1465 L
Mistroke
.11027 .14629 L
.11149 .14617 L
.11259 .14619 L
.11385 .14636 L
.11505 .14668 L
.11629 .14716 L
.11759 .14786 L
.11993 .1496 L
.12244 .15225 L
.1252 .15619 L
.12784 .16118 L
.13072 .16817 L
.13594 .18561 L
.14103 .20883 L
.14572 .23517 L
.15123 .26896 L
.15639 .29722 L
.15898 .3075 L
.15969 .30967 L
.16043 .31162 L
.16177 .31421 L
.16248 .3151 L
.16324 .31567 L
.1646 .31569 L
.16544 .31507 L
.16623 .31405 L
.16693 .31279 L
.1677 .31106 L
.17018 .3031 L
.17285 .2912 L
.17766 .26435 L
.1829 .23341 L
.18861 .20395 L
.19169 .191 L
.19454 .18093 L
.19722 .17305 L
.20017 .16586 L
.20528 .15647 L
.20808 .15263 L
.21072 .14969 L
.21564 .14553 L
.22102 .14225 L
.22627 .13973 L
.23188 .13759 L
.23715 .13598 L
.24194 .13469 L
.2464 .13365 L
.24762 .13342 L
.24893 .1332 L
.25007 .13304 L
Mistroke
.25131 .1329 L
.25267 .13279 L
.25396 .13273 L
.25522 .13271 L
.25639 .13274 L
.25775 .13282 L
.25899 .13293 L
.25968 .13302 L
.26042 .13313 L
.26177 .13339 L
.26294 .13368 L
.26422 .13406 L
.2668 .13513 L
.26919 .13654 L
.27143 .13828 L
.27426 .14119 L
.27694 .14477 L
.28196 .15409 L
.28477 .16114 L
.28737 .16908 L
.29325 .19284 L
.30269 .24669 L
.30765 .27784 L
.31035 .29321 L
.31287 .3053 L
.31432 .31102 L
.31565 .31525 L
.31712 .31882 L
.31793 .32025 L
.31869 .32125 L
.32002 .32221 L
.32125 .32223 L
.3226 .32136 L
.32328 .3206 L
.32403 .31954 L
.32664 .31436 L
.32944 .30724 L
.3321 .30037 L
.3345 .29506 L
.33588 .29272 L
.33718 .29112 L
.33855 .29015 L
.33932 .28996 L
.34003 .29002 L
.34122 .29064 L
.34252 .29207 L
.34388 .29443 L
.34515 .29738 L
.34809 .30671 L
.35076 .31748 L
Mistroke
.35387 .33101 L
.35675 .34226 L
.35806 .34633 L
.35928 .34934 L
.36055 .35148 L
.36123 .35215 L
.36196 .35251 L
.36268 .35245 L
.36347 .35192 L
.36421 .35095 L
.36491 .34965 L
.36621 .34614 L
.3676 .34093 L
.37037 .32645 L
.37299 .30879 L
.37787 .2701 L
.38316 .22804 L
.38811 .19473 L
.39327 .16822 L
.39601 .1574 L
.39894 .14795 L
.40143 .14142 L
.40414 .13568 L
.40654 .13164 L
.40908 .12825 L
.41136 .12589 L
.41388 .12394 L
.41499 .12327 L
.41618 .12267 L
.41728 .1222 L
.41833 .12185 L
.41965 .12152 L
.42085 .12133 L
.42213 .12122 L
.42286 .12121 L
.42353 .12123 L
.42465 .12134 L
.42588 .12154 L
.42717 .12187 L
.42837 .12228 L
.43114 .12358 L
.43367 .12522 L
.43662 .12766 L
.43936 .13045 L
.4448 .13754 L
.45073 .14792 L
.46151 .1728 L
.46686 .18608 L
.46967 .19266 L
.47263 .19887 L
Mistroke
.47523 .2034 L
.47661 .20536 L
.47808 .20709 L
.47944 .2083 L
.48068 .20909 L
.48192 .20957 L
.4831 .20973 L
.48422 .20962 L
.48546 .20922 L
.48675 .20848 L
.48796 .20751 L
.49013 .20516 L
.49246 .20185 L
.50264 .18165 L
.50751 .17182 L
.51019 .16721 L
.51271 .16358 L
.51415 .16186 L
.5157 .16032 L
.51711 .15923 L
.51842 .15849 L
.51964 .15806 L
.52099 .15789 L
.52167 .15795 L
.5224 .15811 L
.52372 .15869 L
.52443 .15917 L
.52519 .15982 L
.52656 .16135 L
.52804 .16356 L
.52966 .16673 L
.53257 .17441 L
.5353 .1842 L
.54039 .20965 L
.54588 .24786 L
.55073 .28771 L
.55591 .32728 L
.55744 .33639 L
.55889 .34335 L
.56018 .34803 L
.56092 .34995 L
.56159 .35126 L
.56282 .35244 L
.56416 .35195 L
.56484 .351 L
.56557 .34947 L
.56689 .3454 L
.56836 .33904 L
.56972 .3316 L
.57282 .31056 L
Mistroke
.57845 .26552 L
.58396 .225 L
.58903 .19675 L
.59162 .18588 L
.59436 .17673 L
.59711 .16967 L
.59869 .16644 L
.60013 .16398 L
.60274 .16052 L
.60418 .1591 L
.60554 .15804 L
.60679 .15727 L
.60796 .15672 L
.60923 .15626 L
.61059 .15592 L
.61179 .15573 L
.61289 .15562 L
.6141 .15557 L
.61538 .15557 L
.61649 .1556 L
.61753 .15566 L
.61866 .15575 L
.61987 .15587 L
.62485 .15644 L
.62617 .1566 L
.62758 .15675 L
.62889 .15686 L
.63013 .15694 L
.63079 .15697 L
.63152 .15699 L
.63279 .15698 L
.63353 .15695 L
.63431 .1569 L
.63505 .15683 L
.63572 .15675 L
.637 .15655 L
.63838 .15628 L
.64088 .15564 L
.64696 .1536 L
.65254 .15135 L
.65787 .14888 L
.66048 .1477 L
.66284 .14677 L
.66404 .14638 L
.66535 .14603 L
.66672 .14577 L
.66803 .14562 L
.66871 .14558 L
.66946 .14558 L
.67024 .14561 L
Mistroke
.67098 .14567 L
.67229 .14588 L
.67303 .14605 L
.67371 .14624 L
.67505 .14674 L
.67633 .14738 L
.67747 .14811 L
.6787 .1491 L
.68005 .15045 L
.68148 .15224 L
.68403 .15661 L
.68639 .16222 L
.6886 .16909 L
.69102 .17871 L
.69362 .19184 L
.69642 .20978 L
.69946 .23457 L
.705 .29471 L
.71035 .36401 L
.71297 .39538 L
.71412 .40729 L
.71537 .41855 L
.71649 .42673 L
.71768 .43333 L
.71894 .43772 L
.72012 .43929 L
.72149 .43803 L
.7228 .43382 L
.72396 .42771 L
.72523 .41882 L
.72798 .39311 L
.73089 .36011 L
.73612 .30113 L
.73873 .2769 L
.74154 .25658 L
.7429 .24894 L
.74419 .24299 L
.74546 .23831 L
.74662 .23505 L
.748 .23228 L
.74877 .23128 L
.74948 .23066 L
.75076 .2303 L
.75214 .23093 L
.75287 .23168 L
.75367 .2328 L
.75528 .23597 L
.75678 .2399 L
.75817 .24431 L
.76344 .26505 L
Mistroke
.76621 .27659 L
.76916 .28744 L
.7704 .29123 L
.77173 .29464 L
.77249 .29624 L
.77319 .29747 L
.77456 .29918 L
.77573 .29986 L
.777 .29975 L
.77833 .29867 L
.77956 .2968 L
.78078 .29413 L
.7821 .29038 L
.7845 .2815 L
.78899 .2595 L
.79905 .2044 L
.80385 .18273 L
.809 .16435 L
.81196 .15601 L
.81466 .14966 L
.81994 .14023 L
.82276 .13648 L
.82537 .13359 L
.82848 .13076 L
.83129 .12867 L
.83379 .12717 L
.8365 .12589 L
.83936 .12487 L
.84077 .12448 L
.84205 .12418 L
.84325 .12394 L
.84455 .12373 L
.84593 .12356 L
.84723 .12346 L
.84845 .1234 L
.84975 .1234 L
.85085 .12345 L
.85207 .12356 L
.8528 .12365 L
.85349 .12376 L
.8548 .12402 L
.8562 .1244 L
.85773 .12492 L
.86049 .12616 L
.86304 .1277 L
.86594 .12993 L
.86866 .13259 L
.87376 .13934 L
.87662 .14431 L
.87925 .14973 L
Mistroke
.88518 .16507 L
.89472 .19751 L
.89997 .21657 L
.90495 .23186 L
.90776 .2381 L
.90853 .23941 L
.90934 .2406 L
.91005 .24146 L
.91081 .2422 L
.91213 .24302 L
.91336 .24325 L
.91407 .24314 L
.91482 .24285 L
.91616 .24186 L
.91742 .24043 L
.91876 .23839 L
.92117 .23355 L
.92664 .21883 L
.93186 .20354 L
.93472 .19617 L
.93739 .1906 L
.93878 .18838 L
.9395 .18745 L
.94028 .18661 L
.94113 .1859 L
.94194 .18546 L
.94273 .18525 L
.94346 .18525 L
.94419 .18546 L
.94488 .18585 L
.94617 .1871 L
.94755 .18925 L
.94833 .19084 L
.94905 .19255 L
.95159 .2007 L
.95396 .21139 L
.95656 .22681 L
.95934 .24767 L
.96499 .30121 L
.97021 .35273 L
.97205 .36753 L
.97377 .37844 L
.97463 .38262 L
.97556 .38604 L
.9766 .38845 L
.97754 .38932 L
.97851 .38889 L
.9794 .38728 L
.98038 .38421 L
.98143 .37949 L
Mistroke
.98253 .37302 L
.98357 .36563 L
.98552 .34899 L
1 .20612 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002Kooooo`?o00005oooool00ol0003oooooooooo`2`ooooo`00VOooool3o`0000;ooooo0_l0000E
ooooo`03o`000?oooooooooo06Wooooo1_l00011ooooo`00VOooool00ol0003oooooooooo`04oooo
o`;o00004oooool00ol0003oooooooooo`1Wooooo`?o00001Oooool2o`0003oooooo002Hooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool04?ooool2o`0006Kooooo0_l0000:ooooo`03
o`000?oooooooooo03cooooo001Tooooo`Oo0000;?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo03_ooooo001Qooooo`?o00001oooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Tooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0>_ooool001cooooo0ol0000nooooo`Co00002oooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`1Sooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0>Oooool0
01_ooooo0_l000000ooooooo0000o`00000kooooo`;o00004?ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Soooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool0>Oooool001[ooooo0_l00004ooooo`03
o`000?oooooooooo01Gooooo0ol0000Oooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0<Oooool5o`0002cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0hooooo`00
6_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo0_l00002ooooo`;o0000
7?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02kooooo0ol00004ooooo`;o0000
:_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03Oooooo000Jooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo00Kooooo0_l0000Yooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0=ooo
ool001Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0<ooooo`;o00008Oooool5
o`0000Gooooo0ol0000:ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0fooooo`006Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool00_ooool4o`0001Sooooo0_l00005ooooo`Go00003Oooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0=_ooool001Wo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`04o`000?oooooooooooooo
o`;o00000_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03Kooooo000Eooooo`;o
000000Wo410@o`000?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Gooooo00GoV9RHoa0@4?l0003o<S8bo`000003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03oooool00ol0003oooooooooo`09ooooo`Go00000oooool01oo^k^ko
<S8bo`000?lb<S;ok^k^ooooool000006_ooool4o`000004oa0@4?ooooooooooonk^kP;o000000?o
<S8bonk^k_ooool03oooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo000000?o000000So410@oooooooooooo
k^k^oc8b<_l0003o<S8bonk^kPgooooo00?o0000ooooooooool02_ooool5o`0000?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0=ooooo`03o`000?oooooooooo00_ooooo00GoV9RHoa0@4?l0003o<S8b
olc<c003ooooo`05onk^k_lb<S;o0000o`000?o^k^h07Oooool2o`000009oa0@4?oooooooooooooo
ooo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Fooooo`03o`000?oooooo000000;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_oo
ool01_l@413o^[ZjoooooomgMgOo<S8bo`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>oooo
o`03o`000?oooooooooo00[ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00;ooooo00Go
MgMgo`000?ooooooV9RHogMgM`0Aooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooo
00001Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool02Oooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0=ooooo`03o`000?oo
oooooooo00_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9Soooooo`000?mg
MgL07_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool000_o
oooo1_l00002ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooo`000005o`0000Kooooo0_l00002ooooo`05oa0@4?oooooooooo
ooooool@41003_ooool00ol0003oooooooooo`02ooooo`Ko00000oooool00onHV9So8B4Qonk^kP04
ooooo`05oa0@4?ooooooooooooooool@41000_ooool00ol0003oooooooooo`0>ooooo`Ko00001Ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?l0003oooooooooool@41004Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooo000000Kooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400>ooooo`03
o`000?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@
00gooooo00?o0000ooooooooool03oooool01Ol0003ooooooooooooooooo410@00;ooooo00?o0000
oa0@4?ooool06_ooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`004oooool0
0om4A4CogMgMooooo`02o`0000?ooooo00Go0000ooooooooooooooooo`000007ooooo`;o00001_oo
ool00ol0003oooooooooo`0;ooooo`06ojVYZOl@413oooooo`000?oooooo00000oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00gooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003o
oooooooooooooooo000000;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`02oooo
o`;o00000_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ool000001oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool02oooool0
0onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000003Oooool00ol0003ooooooooo
o`0>ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000Kooooo`04odA4
A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`004oooool00ooMgMgo
EEEEooooo`02o`0000?ooooo00Go0000ooooooooooooooooo`000009ooooo`04o`000?oooooooooo
ooooo`;o00003Oooool01ol@413o0000okZj^_oooooo0000ooooool000000oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00kooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo0000
00Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo00_ooooo00?oMgMg
ofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000cooooo00?o0000ooooooooool03_oo
ool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000006oooool01?oMgMgoEEEE
ooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool001Cooooo00CoMgMgolc<c?l0
003o00000oooool01Ol@413ooooooooooooooooo410@00[ooooo1?l0000?ooooo`06okZj^_lQ8B7o
ooooo`000?oooooo410@0oooool00ol@413oooooooooo`0;ooooo`03o`000?oooooooooo00oooooo
00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool000006_ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool@41004_ooool00ol0003oooooooooo`09
ooooo`;o00002Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool03?oo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool02_ooool00ol0003ooooo
ooooo`0?ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@ooooooooooooooooo`00000Looooo`03
ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@400>ooooo`005?ooool01?o^k^ko
A4A4o`000?l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01Ol@413oV9RHoooooonj
^[[o000000;ooooo00Ko0000ogMgMonHV9SooooooiRHV?mgMgL=ooooo`03o`000?oooooooooo00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00;ooooo00Go0000oiRHV?ooooooV9RHogMg
M`0Cooooo`03o`000?oooooooooo00Sooooo0_l00009ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3oooool00ol0003oooooooooo`08ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool03?ooool01Ol@413oV9RHoooooonj^[[o
000000?ooooo00KoMgMgoiRHV?ooooooV9RHogMgMol0000Kooooo`03onk^k_m4A4Co000000Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`005Oooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h06_ooool01OnYZJWo410@o`000?l@413oZJVY00;ooooo00Ko0000onk^
k_lb<S;o0000oc8b<_o^k^h=ooooo`03o`000?oooooooooo00_ooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00ol0003oooooooooo`0Fooooo`03
oeEEEOmVIVKo000000Cooooo00Go0000oc8b<_l0003o<S8bonk^kP0Cooooo`03o`000?oooooooooo
00Sooooo0_l00009ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03oooool00ol0003oooooooooo`08
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
00?o0000ooooooooool03?ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Kok^k^oc8b<_l0
003o<S8bonk^k_l0000>ooooo`?o00002oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03_ooool001Kooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo00_ooooo0_l000000ooooooo0000ooooo`0Sooooo`005_ooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01_ooool2o`00
00_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0;ooooo`05o`000?oooooooooo
ooooool000008oooool001Kooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo00Kooooo0_l0000;ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo027ooooo000Fooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooo000000_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool08?ooool001Kooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo
00002oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Pooooo`005_ooooooo`00043o00004oooool001Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooool000001oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo1Ol00003ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2
o`0000Oooooo00?o0000ooooool000001Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Aooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooo`00
0005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00007ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooo`000007ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooo`000005ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017o
oooo0013ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo017ooooo0013ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo0013
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo017ooooo0014ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01;ooooo0014ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo01;ooooo0014ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
3Oooool2o`0000gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Booooo`00A?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0Rooooo`;o00003?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool03Oooool3o`0000_ooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Booooo`00A?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo00cooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo01;ooooo0014ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool03?ooool0
1Ol0003ooooooooooooooooo000000[ooooo00?o0000ooooooooool08_ooool01?l0003ooooooooo
ool0000<ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04_ooool004Cooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool00000
2_ooool00ol0003oooooooooo`0Rooooo`?o00003Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo01;ooooo0015ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool03?oo
ool01Ol0003ooooooooooooooooo000000[ooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo01;ooooo0015ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01;ooooo0015
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo01?ooooo0015ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01?ooooo0015ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo02?ooooo0_l0000<ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool04oooool004Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool04oooool004Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04ooo
ool004Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool04oooool004Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04oooool004Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool04oooool004Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04oooool004Kooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool05?ooool004Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool09Oooool2o`0000kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool01oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Dooooo`00Aoooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo000003Sooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`00Aoooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_ooool2o`0000[ooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00Go0000
ooooooooooooooooo`00000hooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05?oo
ool004Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool0000jooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool05?ooool004Oooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`00
0008ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`08ooooo`;o000000?oooooo`000?ooool0>Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01Cooooo0017ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool2
o`0003_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Dooooo`00Aoooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06oooool5o`00
00Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool05?ooool004Sooooo00Go0000ooooooooooooooooo`00000/oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo01_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo01Cooooo0018ooooo`;o000000?oooooo`000?ooool0;?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Loooo
o`03oiRHV?lQ8B7ok^k^00Oooooo0ol0000>ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Kooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Eooooo`00BOooool00ol0003oooooo`00000^ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo01gooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Eooooo`00
BOooool3o`0002kooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool07_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Go
oooo001kooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`18ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05Oooool007_ooooo0ol0
0007ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06oooool01Ol0003o^[Zjoooo
oonHV9So410@00Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`18ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool05Oooool008Gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Kooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`0?ooooo`05o`000?ooooooooooooooool00000:oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo04Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Eooooo`00
Q_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
3oooool01Ol0003ooooooooooooooooo000002_ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`18ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05Oooool008Kooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00oooooo
00Go0000ooooooooooooooooo`00000[ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0B?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Gooooo0026ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool09_ooool2o`00013ooooo00Go0000oooooooooooo
ooooo`00000[ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0B?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01Gooooo0026ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0?ooooo`05o`000?ooooooooooooooool0
0000:oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Sooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Fooooo`00Qoooool01Ol0003ooooooooooooooooo000002Wo
oooo00?o0000ooooooooool03oooool01Ol0003ooooooooooooooooo000002_ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool05_ooool008Oooooo00Go0000ooooooooooooooooo`00000Yooooo`03o`000?oooooooooo
013ooooo00Co0000oooooooooooo0000:oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo04Wooooo00Go0000ooooooooooooooooo`00000Hooooo`00R?ooool00ol0003oooooo`00000Z
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooool00000;?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo04[ooooo00Go0000ooooooooooooooooo`00000Hooooo`00R?ooool0
0ol0003oooooo`00000Zooooo`03o`000?oooooooooo013ooooo00?o0000ooooool00000;Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo04[ooooo00Go0000ooooooooooooooooo`00
000Hooooo`00R?ooool2o`0002_ooooo00?o0000ooooooooool04?ooool3o`0002gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1:ooooo`05o`000?ooooooooooooooool000006?oo
ool00;Gooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo04[ooooo00Go0000ooooooooooooooooo`00000Hooooo`00]Oooool00ol0003oooooooooo`10
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0B_ooool01Ol0003ooooooooooooo
oooo000001Sooooo002eooooo`;o0000@Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo04[ooooo00Go0000ooooooooooooooooo`00000Hooooo`00]Oooool00ol0003oooooooooo`10
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0B_ooool01Ol0003ooooooooooooo
oooo000001Sooooo002eooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1:ooooo`05o`000?ooooooooooooooool000006?ooool00;Gooooo00?o0000
ooooooooool0@?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04[ooooo00Go0000
ooooooooooooooooo`00000Hooooo`00]Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0Boooool01?l0003oooooooooool0000Hooooo`00]Oooool0
0ol0003oooooooooo`10ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0C?ooool0
1?l0003oooooooooool0000Hooooo`00]Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0C?ooool00ol0003oooooo`00000Iooooo`00]Oooool00ol0
003oooooooooo`11ooooo`05o`000?ooooooooooooooool00000C_ooool00ol0003oooooo`00000I
ooooo`00]Oooool2o`0004;ooooo00Go0000ooooooooooooooooo`00001>ooooo`?o00006Oooool0
0;Gooooo00?o0000ooooooooool0@Oooool01Ol0003ooooooooooooooooo000004oooooo00?o0000
ooooooooool06?ooool00;Gooooo00?o0000ooooooooool0@Oooool01Ol0003ooooooooooooooooo
000006[ooooo002eooooo`03o`000?oooooooooo047ooooo00Go0000ooooooooooooooooo`00001Z
ooooo`00]Oooool00ol0003oooooooooo`11ooooo`05o`000?ooooooooooooooool00000J_ooool0
0:cooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo047ooooo00Go0000oooo
ooooooooooooo`00001Zooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
047ooooo00Go0000ooooooooooooooooo`00001Zooooo`00Z_ooool5o`0000Kooooo00?o0000oooo
ooooool0@Oooool01Ol0003ooooooooooooooooo000006[ooooo002Zooooo`04odA4A?oMgMgooooo
o`0000Oooooo0ol00011ooooo`05o`000?ooooooooooooooool00000J_ooool00:[ooooo00CogMgM
oeEEEOoooooo00001oooool00ol0003oooooooooo`11ooooo`05o`000?ooooooooooooooool00000
J_ooool00:_ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`11ooooo`05o`000?oo
ooooooooooooool00000J_ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003ooooooooo
o`11ooooo`05o`000?ooooooooooooooool00000J_ooool00:cooooo00?oMgMgo`000?ooool01_oo
ool00ol0003oooooooooo`12ooooo`03o`000?oooooo000006_ooooo002eooooo`03o`000?oooooo
oooo04;ooooo00?o0000ooooool00000Joooool00;Gooooo00?o0000ooooooooool0@_ooool00ol0
003oooooo`00001[ooooo`00]Oooool00ol0003oooooooooo`12ooooo`03o`000?oooooo000006_o
oooo002eooooo`;o0000A?ooool00ol0003oooooooooo`1Zooooo`00]Oooool00ol0003ooooooooo
o`13ooooo`03o`000?oooooooooo06[ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0/?oo
ool00:[ooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Z
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool0
1Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0002`ooooo`00Z_ooool01Ol0003oEEEEo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00?oEEEEohN7Qoooool02?ooool0
0ol0003oooooooooo`2`ooooo`00Z_ooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo
0;3ooooo002[ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo00Goc<c<ob4Q8Ol0
003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05ob4Q8OnHV9SooooooiRH
V?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06oooo
o`?o0000/?ooool00:[ooooo00Goc<c<o`000?l0003o0000olc<c02iooooo`00Z_ooool01Ol@413o
^[Zjoooooonj^[[o410@0;Wooooo002Zooooo`05o`000?nj^[[ooooookZj^_l00000^Oooool00:[o
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@2iooooo`00oooooomYooooo`00/oooool00ol0003o^[Zj
ooooo`2booooo`00/oooool2oc8b<[?ooooo0024ooooo`;o000000Ko410@oooooooooooo410@o`00
0?l@410Hooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo00Co410@
o`000?m4A4Coc<c<1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<07cooooo0025ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01oooool6o`0000gooooo00WoMgMgoc8b<_oooooooooo
ogMgMonHV9SooooooiRHV?mgMgL00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^
ogMgMol@41002Oooool6o`0000_ooooo00?oV9RHoa0@4?oMgMd00oooool01OmEEEGoMgMgoooooonH
V9So8B4Q07cooooo0025ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06oooool0
1?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo013ooooo00?o0000ooooooooool07Ooo
ool00on7QhOoEEEEooooo`02ooooo`05o`000?ooooooooooooooool00000O?ooool008Gooooo00Ko
0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00003Oooool01OmgMgOo<S8boooooooooooo0000
00?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`Ko00002Oooool01Oo<
c<co8B4Qo`000?mEEEGo000000?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@1looooo`00QOooool0
1_l0003ogMgMoc8b<_mEEEGogMgMo`0001Wooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05
o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0Jooooo`05ob4Q8On7QhOooooo
oiRHV?l000000oooool01Ol0003oEEEEo`000?l@413oc<c<07cooooo0025ooooo`06o`000?n7QhOo
ZJVYokZj^_mEEEGo00006Oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
41004?ooool00ol@413o0000o`000003o`0001Wooooo00Go0000ooooooooooooooooo`000003oooo
o`03oeEEEOn7QhOooooo07kooooo0025ooooo`06o`000?lb<S;ooooooooooolb<S;o00006Oooool0
0ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool00ol0003ooooooooo
o`0Jooooo`05ob4Q8OnHV9SoooooogMgMomEEED00oooool00ooMgMgo410@oiRHV01nooooo`00Q?oo
ool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo1?l00003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Jooooo`05olc<c?l@413o0000oc8b<_o^
k^h01?ooool01?o<c<coA4A4o`000?l@411looooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(98) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .25535 m
.00236 .24189 L
.00488 .22976 L
.00942 .21336 L
.0122 .20628 L
.01483 .20123 L
.01719 .19778 L
.01975 .19489 L
.04057 .17773 L
.06204 .1537 L
.06726 .14896 L
.07288 .14485 L
.07609 .14306 L
.07904 .14179 L
.08045 .1413 L
.082 .14084 L
.08481 .14021 L
.08621 .13998 L
.08694 .13989 L
.08772 .13981 L
.0884 .13976 L
.08914 .13972 L
.09046 .1397 L
.09174 .13973 L
.09311 .13984 L
.0944 .14002 L
.09558 .14023 L
.09705 .14058 L
.0984 .14097 L
.10147 .14215 L
.10418 .14352 L
.10706 .14535 L
.1095 .14726 L
.11213 .14977 L
.11688 .15584 L
.11963 .16045 L
.12253 .16634 L
.12772 .18002 L
.1385 .22491 L
.1438 .2541 L
.14868 .28103 L
.15098 .29215 L
.15312 .3009 L
.15429 .30482 L
.15536 .30778 L
.15655 .31034 L
.15782 .31217 L
.15909 .31299 L
.16026 .31286 L
.16154 .31172 L
Mistroke
.16291 .30938 L
.16421 .30613 L
.16544 .30222 L
.16773 .29298 L
.17846 .23363 L
.18317 .20864 L
.18832 .18584 L
.19347 .16834 L
.1989 .15493 L
.20481 .14464 L
.21032 .13781 L
.2156 .13318 L
.21857 .13121 L
.22132 .12967 L
.22637 .12741 L
.22892 .12652 L
.23029 .12613 L
.23173 .1258 L
.23294 .12557 L
.23426 .12539 L
.23546 .12529 L
.23658 .12524 L
.2379 .12525 L
.2391 .1253 L
.24049 .12543 L
.2418 .12562 L
.24294 .12584 L
.24415 .12613 L
.24633 .12682 L
.24866 .12787 L
.25123 .12948 L
.25386 .13173 L
.25672 .13496 L
.25925 .13856 L
.26193 .14323 L
.267 .15484 L
.27169 .16951 L
.28225 .21615 L
.2878 .24291 L
.29082 .25554 L
.2923 .26075 L
.29364 .26479 L
.29482 .26772 L
.2961 .27018 L
.29745 .2719 L
.29873 .27266 L
.29939 .27271 L
.30013 .2725 L
.3009 .27196 L
.30162 .27118 L
Mistroke
.30291 .26913 L
.30429 .26604 L
.30691 .25801 L
.30939 .24836 L
.31406 .22757 L
.3185 .20789 L
.32324 .19016 L
.32464 .18594 L
.32596 .1825 L
.32725 .17972 L
.32843 .1777 L
.32955 .17629 L
.33074 .17538 L
.33194 .1751 L
.33325 .17555 L
.33462 .17692 L
.33589 .17904 L
.33655 .18048 L
.33728 .18235 L
.33876 .18706 L
.34145 .19903 L
.34397 .21468 L
.34643 .23446 L
.34868 .25671 L
.35375 .31903 L
.35643 .35493 L
.35929 .3902 L
.36068 .40459 L
.362 .41582 L
.36317 .42357 L
.36445 .4292 L
.36581 .43179 L
.3665 .43171 L
.36725 .43056 L
.36858 .42583 L
.36983 .41843 L
.37131 .40627 L
.37267 .39242 L
.37571 .35453 L
.3807 .28627 L
.3854 .2312 L
.388 .20736 L
.39081 .18691 L
.39336 .1725 L
.3957 .16226 L
.39833 .15373 L
.39982 .15011 L
.4012 .14747 L
.40267 .14536 L
.40401 .14401 L
Mistroke
.40475 .14348 L
.40555 .14305 L
.40631 .14279 L
.40701 .14266 L
.40826 .14268 L
.40943 .14295 L
.41071 .14351 L
.41209 .14438 L
.41353 .14555 L
.41491 .1469 L
.41748 .15005 L
.42831 .17056 L
.43362 .18245 L
.43851 .19245 L
.44296 .19985 L
.4452 .20264 L
.44647 .20388 L
.44766 .20479 L
.44895 .20547 L
.45016 .20584 L
.45126 .20592 L
.45244 .20575 L
.45374 .20526 L
.45511 .20442 L
.45628 .20344 L
.45757 .20211 L
.4627 .19475 L
.46822 .18434 L
.47822 .16421 L
.48381 .15504 L
.48686 .15106 L
.4897 .14799 L
.49234 .14569 L
.49473 .14405 L
.4961 .14332 L
.49739 .14277 L
.49876 .14234 L
.49953 .14217 L
.50024 .14206 L
.50155 .14197 L
.5028 .14202 L
.50392 .14217 L
.50514 .14245 L
.50646 .1429 L
.50787 .14352 L
.51041 .14504 L
.51298 .14712 L
.5154 .14964 L
.51993 .15601 L
.52257 .16089 L
Mistroke
.52536 .16711 L
.53034 .18125 L
.53571 .20149 L
.5416 .23039 L
.54665 .25984 L
.55214 .29264 L
.55465 .30608 L
.55732 .31801 L
.5596 .32561 L
.5609 .32868 L
.56211 .33065 L
.56279 .33135 L
.56352 .33179 L
.56429 .33189 L
.565 .33164 L
.56628 .33041 L
.56765 .328 L
.56842 .32617 L
.56926 .32381 L
.57077 .31864 L
.57361 .30638 L
.58408 .24953 L
.58889 .22576 L
.59404 .20466 L
.5997 .18684 L
.60499 .17439 L
.61092 .16377 L
.61654 .15594 L
.62155 .15042 L
.62709 .14551 L
.63195 .14187 L
.6372 .13865 L
.64275 .1361 L
.64524 .1352 L
.64796 .13437 L
.65033 .13376 L
.65287 .13324 L
.65427 .13304 L
.65554 .1329 L
.65683 .13281 L
.65804 .13279 L
.65916 .13281 L
.66035 .13289 L
.66136 .13299 L
.66248 .13315 L
.66367 .13338 L
.66496 .13369 L
.66729 .13441 L
.66995 .13555 L
.67279 .13721 L
Mistroke
.67547 .13933 L
.6779 .14182 L
.68077 .14559 L
.68387 .15082 L
.68655 .15649 L
.68949 .16414 L
.69483 .18272 L
.70048 .21002 L
.71058 .27401 L
.71322 .29058 L
.71609 .30638 L
.7174 .31247 L
.7188 .31797 L
.72 .32183 L
.7213 .32498 L
.72255 .32699 L
.7237 .32794 L
.7248 .32805 L
.72595 .32736 L
.72722 .32572 L
.7284 .32344 L
.73107 .31614 L
.73654 .29744 L
.73784 .29334 L
.73922 .28953 L
.7405 .28663 L
.74169 .28457 L
.74305 .2831 L
.74377 .28273 L
.74455 .28268 L
.74538 .28303 L
.74616 .28377 L
.74687 .28478 L
.74764 .28627 L
.749 .28989 L
.75044 .29515 L
.75304 .30818 L
.75578 .32636 L
.75868 .34876 L
.76119 .36865 L
.76387 .38769 L
.76538 .39628 L
.76676 .40223 L
.76814 .40607 L
.76945 .40752 L
.77019 .40735 L
.77097 .40637 L
.77164 .40488 L
.77238 .40255 L
.77317 .39925 L
Mistroke
.77403 .39483 L
.77557 .38467 L
.77828 .36113 L
.78124 .32991 L
.78663 .26978 L
.7915 .2228 L
.79676 .1847 L
.79966 .16904 L
.80233 .15747 L
.80483 .14875 L
.80758 .14119 L
.81005 .13589 L
.81235 .13197 L
.81479 .12873 L
.8174 .12606 L
.82023 .12396 L
.82183 .1231 L
.82331 .1225 L
.8246 .12213 L
.82533 .12198 L
.82602 .12187 L
.82741 .12178 L
.82819 .12179 L
.82891 .12184 L
.83018 .12202 L
.83135 .12229 L
.83264 .1227 L
.83403 .12326 L
.83685 .12483 L
.83941 .12678 L
.84183 .12914 L
.8445 .13237 L
.84988 .14122 L
.85487 .15244 L
.85954 .16563 L
.87073 .205 L
.8734 .21439 L
.87625 .22337 L
.87871 .22984 L
.88 .23264 L
.88137 .23507 L
.88205 .23608 L
.8828 .23701 L
.88412 .23819 L
.88546 .2388 L
.88671 .2388 L
.88793 .23828 L
.88904 .23737 L
.89033 .23581 L
.89155 .23385 L
Mistroke
.89431 .22785 L
.89687 .22072 L
.90265 .20133 L
.91202 .17031 L
.91728 .15687 L
.91978 .15185 L
.92211 .14803 L
.92446 .14501 L
.92581 .14367 L
.92704 .14269 L
.92833 .1419 L
.92955 .14139 L
.93084 .14111 L
.93156 .14106 L
.93223 .14108 L
.93337 .14129 L
.93443 .14168 L
.93559 .14232 L
.93684 .14328 L
.93815 .14459 L
.9394 .14615 L
.94173 .14997 L
.94433 .15577 L
.9471 .16394 L
.95208 .18463 L
.95514 .20166 L
.95801 .22094 L
.96337 .26487 L
.96818 .30894 L
.97266 .34576 L
.97492 .35968 L
.97619 .36555 L
.97734 .36953 L
.9786 .37231 L
.97997 .37339 L
.98127 .37255 L
.98246 .37022 L
.98347 .36716 L
.98456 .36283 L
.98651 .35259 L
.99098 .32138 L
1 .25535 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo06?ooooo1_l00017
ooooo`00GOooool9o`0004oooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo04Cooooo001Looooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0C?ooool2o`0006;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`13ooooo`00
F_ooool2o`0000_ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0]ooooo`Go0000
;_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04;ooooo001Jooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Zooooo`?o00001Ooo
ool3o`0002_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`12ooooo`00<Oooool4
o`0002Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooo
oooo02Sooooo0_l0000;ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`11ooooo`00;_ooool3o`0000Cooooo0ol0000Pooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0:oooool2o`0001_ooooo1?l0000Vooooo`;o00003_ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05Oooool5o`00
02Oooooo000/ooooo`;o00002_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0:_ooool01?l0003oooooooooool0000Hooooo`;o000000Goooooo`00
0?ooooooooooo`00000Tooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Gooooo00Co0000oooooooooooooooo0_l0
000Vooooo`00:oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool05Oooool01?l0003oooooooooool00003ooooo`;o00008_ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool08oooool002[ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo01kooooo0_l0000Booooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool08oooool002Wooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00_ooool2
o`0000Cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool08oooool002Wooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo02?ooooo000Xooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Rooooo`005Oooool2o`000009oa0@
4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00?o0000ooooooooool04?ooool0
1OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03o`00
0?oooooooooo00_ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool4o`000008
oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Sooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^3_ooool00ol0003oooooooooo`09oooo
o`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00?o0000ooooooooool03Oooool0
1OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02Oooool2o`000009oa0@4?ooooooooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^00kooooo000Fooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo017ooooo00Go410@okZj^_oooooo0000oc8b
<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0<ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHo`000?nHV9SoMgMg01kooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHo`000?nHV9SoMgMg00Kooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06?ooool2
o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00Wooooo00Go
V9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02_ooool00ol0003o
ooooooooo`0>ooooo`05oa0@4?nj^[[o0000ogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`002oooool6o`0000;ooooo1Ol00003
ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`0:ooooo`Ko00001Ooo
ool2o`0000?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Cooooo
1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@ooooool0003ooooooa0@400Cooooo`Ko
00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?l0003oooooooooool@41001oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooo000000Cooooo00Go410@oooooooooooooooooa0@400?
ooooo`03o`000?oooooooooo00Wooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooo
oooo410@00[ooooo00?o0000ooooooooool04?ooool00ol0003oooooo`000003ooooo`05oa0@4?oo
ooooooooooooool@41001_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
1Ol00003ooooo`05oa0@4?ooooooooooooooool@41003_ooool001?ooooo00CoA4A4omgMgOoooooo
00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool05_ooool00ol0
003o410@ooooo`02ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003oooooooooo`0>
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooool0003oooooo`00000@ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool00_ooool2o`0000;ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Eooooo`04o`000?ooooooooooo`0000Cooooo00Go0000oooooooooooo
ooooo`00000?ooooo`03o`000?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003o
oooooooooooooooo000000[ooooo00?o0000ooooooooool04Oooool00ol0003o410@ooooo`02oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Kooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000000kooooo
000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`000002ooooo`;o
00006?ooool00ol@413o0000o`000003ooooo`05o`000?ooooooooooooooool000003?ooool00ol0
003oooooooooo`0?ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooool0003oooooo`00000?
ooooo`?o00003?ooool00ol0003oooooooooo`02ooooo`;o00000_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo01Gooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooo
oooooooo000000oooooo00?o0000ooooooooool02oooool00omgMgOoIVIVooooo`02ooooo`05o`00
0?ooooooooooooooool000002_ooool00ol0003oooooooooo`0@ooooo`03oa0@4?l0003o^[Zj00?o
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool01_ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000003_oo
ool001Cooooo00?oMgMgolc<c?l000001?ooool01ol@413ooooooooooooooooo410@ooooool00000
6oooool00onj^[[o0000ooooo`02ooooo`05oa0@4?ooooooooooooooool@41002oooool00ol0003o
ooooooooo`0Aooooo`05o`000?ooooooooooooooool@41000_ooool00ol0003o410@ooooo`0>oooo
o`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool00_ooool01Ol@413o0000oooooooo
oooo410@00Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`;o00002?oo
ool00ol0003oooooooooo`0Dooooo`04o`000?ooooooooooo`0000Cooooo00Go410@oooooooooooo
oooooa0@400@ooooo`03o`000?oooooooooo00_ooooo00Go0000oooooooooooooooooa0@4003oooo
o`03oa0@4?oooooooooo00Oooooo00?o0000ooooooooool04_ooool00ol0003o8B4Qooooo`02oooo
o`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Oooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00kooooo000D
ooooo`03onk^k_m4A4Co000000Cooooo00KoMgMgoiRHV?ooooooV9RHogMgMol0000Iooooo`05oa0@
4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000oooo
ooooool03Oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oooooo0000ogMg
M`0>ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`02ooooo`05o`00
0?nHV9SooooooiRHV?mgMgL02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`05o`000?oooooooooooooo
ool000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg013ooooo00?o0000ooooooooool01oooool0
1Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`09ooooo`03o`00
0?oooooooooo00oooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?ok^k^odA4
A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000Eooooo`03ogMgMol0003ooooo
00?ooooo00Gok^k^oc8b<_l0003o<S8bo`00000Jooooo`05ojVYZOl@413o0000oa0@4?l000000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00?o0000ooooooooool03Oooool01OnHV9So410@
o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o0000onk^kP0>ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01_ooool00omEEEGoIVIVo`000004ooooo`05o`000?lb<S;o0000
oc8b<_o^k^h02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Cooooo`05o`000?ooooooEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^013ooooo00?o0000ooooooooool01oooool01OnHV9So410@
o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP09ooooo`03o`000?oooooooooo
00oooooo00GoZJVYoa0@4?l0003o410@o`000003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?oMgMgo`000?ooool00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Nooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool08?ooool001gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0P
ooooo`007?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01oooooo000Kooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool07oooool001[ooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3oooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0Oooooo`005_ooooooo`00043o00004oooool001Kooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooo000000Gooooo00?o0000ooooool000001oooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooo`00
0007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`005_ooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00Gooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooool000001Oooool00ol0003oooooo`000007ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooool000001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo000Ioooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Noooo
o`006Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool07_ooool001Sooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo01kooooo000Hooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Nooooo`006?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool07_ooool001Oooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo01kooooo000Gooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;o
oooo0_l0000;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00Go0000ooooooooooooooooo`00000Doooo
o`03o`000?oooooooooo01kooooo000Gooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Iooooo`;o000000?oooooo`000?ooool05?ooool00ol0003o
ooooooooo`0Nooooo`005_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool06oooool2o`0001Kooooo00?o0000ooooooooool07_ooool001Kooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool07_ooool001Kooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool07Oooool001Kooooo00?o0000oooo
ooooool0:_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool07Oooool001Kooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo03Cooooo00?o0000ooooooooool07Oooool001Kooooo00?o0000ooooooooool0
:_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Aooooo`00@oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool08_ooool2o`0000gooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo017ooooo0013ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool08oooool01Ol0003ooooooooooooooooo000000gooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo017ooooo0014
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08oooool01Ol0003ooooooooooooo
oooo000000gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo017ooooo0014ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09?ooool0
0ol0003oooooo`00000>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Booooo`00A?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
02Cooooo0ol0000>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Booooo`00A?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool04_ooool004Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Booooo`00AOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo0015
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo02?ooooo0_l0000>ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`06ooooo`;o00003?ooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool004Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo0016oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0000:
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0C
ooooo`00A_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Sooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Gooooo00Co0000oooo
oooooooo00002_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool04oooool004Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04oooool004Kooooo00Go0000oooooooo
ooooooooo`00000kooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool004Ko
oooo00Go0000ooooooooooooooooo`00000kooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool06?ooool5o`0000Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01?ooooo0017ooooo`04o`000?ooooooooooo`0003_ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool0
04Oooooo00Co0000oooooooooooo0000>oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo01[ooooo00?oV9RHob4Q8Oo^k^h01oooool3o`0000kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Cooooo`00B?ooool2o`0003cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Kooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo02_ooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo01Cooooo0026ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool07?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo00oooooo00Go0000oooo
ooooooooooooo`00000^ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Dooooo`00Q_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0?ooooo`05o`000?ooooooooooooooool00000;ooo
ool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Cooooo0026ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool06Oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo
00?o0000ooooooooool03oooool01Ol0003ooooooooooooooooo000002oooooo00Co0000oooooooo
oooo00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Dooooo`00Q_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo
013ooooo00Co0000oooooooooooo0000;oooool01?l0003oooooo`000?l00007ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01Cooooo0026ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0@ooooo`04o`000?oooooo0000o`00033ooooo0_l00008ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01Cooooo0026ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0Aooooo`;o0000>oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Dooooo`00Q_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo02Cooooo0_l0001?ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01Cooooo0026ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`1>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01Cooooo0027ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0>_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Gooooo
0027ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`1?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0>_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo01Gooooo0027ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Gooooo0027oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1?oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01Gooooo0027ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Gooooo0027ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1?ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0??ooool01Ol0003ooooooooooooooooo000001Oo
oooo0027ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0??ooool01?l0003ooooo
ooooool0000Hooooo`00Qoooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Gooooo
0_l0001Aooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0??ooool01?l0003ooooo
ooooool0000Hooooo`00Qoooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0D?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03cooooo
00Co0000oooooooooooo00006?ooool008Oooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0mooooo`03o`000?oooooo000001Sooooo0027ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0?Oooool2o`0001Wooooo0028ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0?_ooool00ol0003oooooooooo`0Gooooo`00R?ooool01Ol0003ooooooooooooooooo
000002Sooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo05Sooooo0028ooooo`05o`000?ooooooooooooooool00000:?ooool00ol0003oooooooooo`1A
ooooo`05o`000?ooooooooooooooool00000F_ooool008Sooooo00Go0000ooooooooooooooooo`00
000Xooooo`03o`000?oooooooooo057ooooo00Go0000ooooooooooooooooo`00001Jooooo`00R?oo
ool01Ol0003ooooooooooooooooo000002Sooooo0_l0001Booooo`05o`000?ooooooooooooooool0
0000F_ooool008Sooooo00Go0000ooooooooooooooooo`00000Xooooo`03o`000?oooooooooo057o
oooo00Co0000oooooooooooo0000Foooool008Sooooo00Go0000ooooooooooooooooo`00000Xoooo
o`03o`000?oooooooooo057ooooo00Co0000oooooooooooo0000Foooool008Sooooo00Go0000oooo
ooooooooooooo`00000Xooooo`03o`000?oooooooooo057ooooo00Co0000oooooooooooo0000Fooo
ool008Wooooo00Co0000oooooooooooo0000:?ooool00ol0003oooooooooo`1Aooooo`04o`000?oo
ooooooooo`0005_ooooo0029ooooo`04o`000?ooooooooooo`0001oooooo0_l000000ol@413ooooo
ooooo`04ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooool00000Foooool008Wooooo00Co
0000oooooooooooo00008?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05;ooooo
0_l0001Looooo`00ROooool01?l0003oooooooooool0000Mooooo`Go00001_ooool00ol0003ooooo
ooooo`2`ooooo`00ROooool01?l0003oooooooooool0000Mooooo`04odA4A?oMgMgoooooo`0000Oo
oooo0ol0002`ooooo`00ROooool00ol0003oooooo`00000Nooooo`04omgMgOmEEEGoooooo`0000Oo
oooo00?o0000ooooooooool0/?ooool008Wooooo00?o0000ooooool000007oooool00omgMgOoc<c<
o`000007ooooo`03o`000?oooooooooo0;3ooooo0029ooooo`03o`000?oooooo000001oooooo00?o
k^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00ROooool00ol0003oooooo`00000P
ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0/?ooool008[ooooo0_l0000Yoooo
o`03o`000?oooooooooo0;3ooooo002:ooooo`;o0000:Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aoooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Oo^
k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00GoEEEEogMg
MoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003oV9RHoooooonHV9So
8B4Q00Kooooo0ol0002`ooooo`00Z_ooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000
ooooooooool0/?ooool00:[ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`2`oooo
o`00Z_ooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`04olc<
c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00:[ooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03
o`000?oooooooooo0;3ooooo002Zooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003o
ooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool0/?ooool00:[ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000/?ooool00:[ooooo
00Goc<c<o`000?l0003o0000olc<c02iooooo`00Z_ooool01Ol@413o^[Zjoooooonj^[[o410@0;Wo
oooo002Zooooo`05o`000?nj^[[ooooookZj^_l00000^Oooool00:[ooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@2iooooo`00oooooomYooooo`00/oooool00ol0003o^[Zjooooo`2booooo`00/oooool2
oc8b<[?ooooo0024ooooo`;o000000Ko410@oooooooooooo410@o`000?l@410Hooooo`05odA4A?l0
003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?oQhN7o`000?nj
^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo00Co410@o`000?m4A4Coc<c<1?ooool0
1Oo<c<co8B4Qo`000?lQ8B7oc<c<07cooooo0025ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01oooool6o`0000gooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mg
MgL00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`00
00_ooooo00?oV9RHoa0@4?oMgMd00oooool01OlQ8B7oV9RHoooooonHV9So8B4Q07cooooo0025oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06oooool01?l0003oooooooooool@4103
ooooo`03oa0@4?oooooooooo013ooooo00?o0000ooooooooool07Oooool00on7QhOoEEEEooooo`02
ooooo`05o`000?ooooooooooooooool00000O?ooool008Gooooo00Ko0000oooooom4A4CoA4A4oooo
ool00009ooooo`Ko00003Oooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0;ooooo`Ko00002Oooool01Oo<c<co8B4Qo`000?mEEEGo0000
00?ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P1looooo`00QOooool01_l0003ogMgMoc8b<_mEEEGo
gMgMo`0001Wooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool0
00004_ooool00ol0003oooooooooo`0Jooooo`05ob4Q8On7QhOooooooiRHV?l000000oooool01Oo<
c<co0000o`000?l0003oc<c<07cooooo0025ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo00006Ooo
ool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol@413o0000
o`000003o`0001Wooooo00Go0000ooooooooooooooooo`000003ooooo`05oa0@4?nj^[[ooooookZj
^_l@4100O?ooool008Gooooo00Ko0000oc8b<_oooooooooooc8b<_l0000Iooooo`03o`000?oooooo
oooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Booooo`03o`000?oooooooooo01[ooooo00Go
8B4QoiRHV?ooooooMgMgoeEEE@03ooooo`05o`000?nj^[[ooooookZj^_l00000O?ooool008Cooooo
00?o410@o`000?n7QhL00_ooool00on7QhOo0000oa0@400Hooooo`Co00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01;ooooo00?o0000ooooooooool06_ooool01Oo<c<co410@o`000?lb<S;ok^k^
00?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@1looooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .34959 m
.00942 .29577 L
.01975 .22598 L
.02496 .19961 L
.02782 .18804 L
.03053 .17884 L
.03305 .17167 L
.03578 .16526 L
.04057 .15688 L
.04331 .15333 L
.04588 .15063 L
.04894 .14804 L
.05173 .14619 L
.05466 .14472 L
.05744 .1437 L
.06037 .14294 L
.06203 .14261 L
.06357 .14235 L
.06635 .14197 L
.06896 .14168 L
.07131 .14149 L
.07263 .14141 L
.07385 .14135 L
.07516 .14132 L
.07639 .1413 L
.07774 .14131 L
.07849 .14132 L
.07918 .14134 L
.08056 .14138 L
.08207 .14144 L
.08481 .14155 L
.08726 .14167 L
.08854 .14174 L
.0899 .14183 L
.09109 .14194 L
.09239 .14207 L
.09468 .14241 L
.09611 .14269 L
.09741 .14301 L
.10032 .14392 L
.10302 .14508 L
.10557 .14648 L
.10825 .14839 L
.11108 .15105 L
.1135 .154 L
.11616 .15816 L
.11901 .1639 L
.12208 .17179 L
.12763 .1914 L
.13315 .21874 L
Mistroke
.13827 .25042 L
.14435 .28979 L
.147 .30426 L
.14839 .31054 L
.14986 .31593 L
.15117 .31952 L
.15192 .321 L
.15261 .32201 L
.15383 .32289 L
.15513 .32253 L
.15646 .32079 L
.15772 .31789 L
.15886 .3143 L
.16009 .30943 L
.16283 .2954 L
.16574 .27705 L
.17097 .24064 L
.17578 .20915 L
.18084 .18185 L
.18638 .15942 L
.18884 .15174 L
.19146 .14489 L
.19395 .1395 L
.19621 .13543 L
.20064 .12933 L
.20311 .12674 L
.2058 .12448 L
.20833 .12279 L
.21066 .12161 L
.21198 .12108 L
.21324 .12069 L
.21436 .12041 L
.21559 .12019 L
.21692 .12005 L
.21759 .12002 L
.21833 .12001 L
.21964 .12007 L
.22087 .1202 L
.22203 .12041 L
.22326 .12071 L
.22546 .12146 L
.22668 .12202 L
.22782 .12263 L
.2304 .1244 L
.23323 .12702 L
.23589 .13026 L
.24089 .13869 L
.24368 .14496 L
.24626 .15186 L
.25209 .17188 L
Mistroke
.26157 .21632 L
.2668 .24215 L
.26938 .25314 L
.27177 .26143 L
.27312 .2651 L
.27456 .26807 L
.27539 .2693 L
.27616 .27014 L
.27686 .27062 L
.27761 .27085 L
.27897 .27049 L
.27965 .26994 L
.2804 .26905 L
.28172 .26677 L
.28296 .26387 L
.2856 .25543 L
.28801 .2456 L
.29343 .2195 L
.30316 .17499 L
.30807 .15844 L
.31086 .15115 L
.31349 .1457 L
.31487 .14335 L
.31633 .14126 L
.31759 .13975 L
.31894 .13845 L
.3197 .13785 L
.32039 .13738 L
.32174 .13669 L
.3225 .13643 L
.32332 .13624 L
.3241 .13617 L
.32481 .13618 L
.32607 .13639 L
.32724 .13682 L
.32852 .13754 L
.3299 .13864 L
.33135 .14017 L
.33272 .14199 L
.33529 .14649 L
.33802 .15298 L
.34059 .16092 L
.34539 .18125 L
.34809 .19632 L
.35056 .21277 L
.35614 .25928 L
.36094 .30683 L
.36548 .35059 L
.36799 .37046 L
.36931 .37889 L
Mistroke
.37071 .38599 L
.37189 .39035 L
.37318 .39335 L
.37436 .3944 L
.37547 .39394 L
.37679 .39162 L
.37805 .38772 L
.37918 .38296 L
.38041 .37654 L
.38573 .33955 L
.39074 .3021 L
.39529 .2743 L
.39809 .26115 L
.40074 .25137 L
.40353 .24336 L
.40655 .23679 L
.4092 .23236 L
.41199 .22854 L
.41701 .22243 L
.43785 .18513 L
.44696 .16782 L
.4521 .16015 L
.45686 .15482 L
.46196 .15074 L
.46453 .14925 L
.46602 .14857 L
.46738 .14806 L
.46858 .1477 L
.46985 .14742 L
.47112 .14723 L
.47184 .14717 L
.47251 .14713 L
.47374 .14712 L
.47485 .14717 L
.47613 .14729 L
.47734 .14744 L
.48 .14793 L
.48282 .1486 L
.48787 .15018 L
.4993 .15521 L
.5092 .15936 L
.51466 .162 L
.51984 .16505 L
.52464 .16879 L
.52736 .17168 L
.52988 .17511 L
.53433 .18353 L
.53681 .18981 L
.53906 .19665 L
.54974 .24701 L
Mistroke
.55557 .28557 L
.55842 .30444 L
.56101 .31983 L
.56215 .3257 L
.56339 .33128 L
.56447 .33532 L
.56565 .33884 L
.56691 .34143 L
.56824 .34281 L
.56947 .34279 L
.57063 .34164 L
.57192 .33906 L
.57328 .33494 L
.57444 .33036 L
.57571 .32434 L
.58118 .28949 L
.59133 .21849 L
.59702 .18882 L
.60218 .16919 L
.607 .15616 L
.60972 .15071 L
.61222 .14666 L
.61683 .14101 L
.6217 .13666 L
.62436 .13481 L
.62689 .13339 L
.62915 .13238 L
.63162 .13151 L
.63716 .13014 L
.6398 .12961 L
.64228 .12918 L
.64332 .12903 L
.64441 .12891 L
.64561 .12881 L
.64671 .12877 L
.64792 .12878 L
.64905 .12884 L
.65028 .12897 L
.6516 .12918 L
.65288 .12944 L
.65427 .12979 L
.6568 .13061 L
.65925 .13164 L
.66152 .13287 L
.66407 .13471 L
.66641 .13695 L
.66911 .14037 L
.67167 .14459 L
.67622 .15466 L
.68119 .17002 L
Mistroke
.68662 .19337 L
.69242 .2259 L
.69749 .25712 L
.70026 .27285 L
.70285 .28528 L
.70425 .29077 L
.70553 .29484 L
.70695 .29823 L
.70773 .29954 L
.70847 .30041 L
.70976 .30103 L
.71095 .30057 L
.71226 .29893 L
.71292 .29765 L
.71365 .2959 L
.71516 .29118 L
.71655 .28567 L
.71968 .26986 L
.72533 .23526 L
.73068 .20422 L
.73565 .18137 L
.73816 .17244 L
.74084 .16505 L
.74237 .16195 L
.74312 .16076 L
.74381 .15987 L
.74511 .15875 L
.74579 .15846 L
.74651 .15838 L
.74779 .15885 L
.74917 .16027 L
.75048 .1625 L
.75169 .16536 L
.75399 .17299 L
.75527 .1786 L
.75643 .1846 L
.75906 .2019 L
.76191 .22727 L
.7646 .25851 L
.76707 .29342 L
.77192 .37281 L
.77428 .41072 L
.77643 .44024 L
.77752 .45236 L
.77871 .46283 L
.77996 .47045 L
.78114 .47415 L
.78244 .47412 L
.78383 .4694 L
.785 .46172 L
Mistroke
.7863 .44968 L
.79171 .37174 L
.79762 .2764 L
.80031 .24106 L
.80319 .21123 L
.80591 .18994 L
.80838 .17545 L
.80964 .16952 L
.81098 .16421 L
.81337 .15699 L
.8147 .15412 L
.81595 .15214 L
.81731 .1507 L
.81808 .15021 L
.81878 .14995 L
.82003 .1499 L
.82119 .1503 L
.82246 .15118 L
.82381 .15257 L
.82608 .15576 L
.82858 .16034 L
.83891 .18847 L
.84455 .20752 L
.8473 .21612 L
.8498 .22288 L
.85195 .22765 L
.85429 .23154 L
.85557 .23305 L
.85676 .23405 L
.85789 .23463 L
.85909 .23483 L
.8603 .23461 L
.86159 .23389 L
.86282 .23275 L
.86394 .23134 L
.86667 .22645 L
.86927 .22018 L
.87979 .18788 L
.88492 .17335 L
.88956 .16233 L
.89463 .15314 L
.89741 .14953 L
.90003 .14706 L
.90142 .14607 L
.90289 .14526 L
.90414 .14474 L
.90552 .14432 L
.9063 .14416 L
.907 .14405 L
.90782 .14398 L
Mistroke
.90859 .14395 L
.90996 .14402 L
.91074 .14413 L
.91145 .14426 L
.91269 .14459 L
.914 .14507 L
.91633 .14627 L
.91883 .14801 L
.92157 .1504 L
.93107 .16115 L
.94241 .17747 L
.95271 .19434 L
.9578 .20429 L
.96332 .21806 L
.96853 .23525 L
.97332 .25587 L
.98381 .3153 L
.98668 .33131 L
.98826 .33906 L
.98976 .3454 L
.99115 .3502 L
.99189 .35227 L
.99267 .35409 L
.99405 .35626 L
.99533 .35706 L
.99659 .35664 L
.99778 .35515 L
.99885 .35292 L
1 .34959 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
001Iooooo`Go0000Eoooool00ol0003oooooooooo`2`ooooo`00Eoooool2o`0000Gooooo0_l0001E
ooooo`03o`000?oooooooooo0;3ooooo001Fooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0D_ooool00ol0003oooooooooo`2`ooooo`00E_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo057ooooo0_l0000Yooooo`So0000P?ooool005Gooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo02Gooooo0ol00008ooooo`03o`00
0?oooooooooo07gooooo001Dooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05ooo
ool3o`0003Kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0:ooooo`;o0000OOoo
ool005?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo00;o0000=Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0N_ooool002Wooooo3Ol0000Mooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03;ooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo07[ooooo000Vooooo`?o
00003Oooool2o`0001_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool0A_ooool5o`0002kooooo000Uooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Wooooo`Oo0000
1?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
:oooool2o`0001Oooooo0_l00005ooooo`03o`000?oooooooooo02_ooooo000Tooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Tooooo`;o00001ooo
ool3o`000003ooooool0003ooooo027ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Yooooo`Co00005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02[ooooo000S
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo00[ooooo1?l0000Oooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool0:Oooool01Ol0003ooooooooooooooooo000001Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Yooooo`008oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00;o00007Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo0_l0000D
ooooo`05o`000?ooooooooooooooool000005?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo02Sooooo000Rooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool04Oooool4
o`0001?ooooo00Go0000ooooooooooooooooo`00000Cooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool09oooool001Gooooo0_l000002ol@413oooooooooooooooook^k^oc8b<_l0003o
<S8bonk^k_oooooo000001Sooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02_ooool00ol0003oooooooooo`0>ooooo`Go00000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`Co0000
00So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPkooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`03ooooo`;o00006Oooool5o`000008oa0@4?ooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h;ooooo`03o`000?oooooooooo00cooooo1_l00002ooooo`05o`000?lb<S;o0000oc8b
<_o^k^h03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00GoV9RHoa0@
4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_l000003?ooool00ol0003ooooooooo
o`0>ooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h03_ooool001Ko
oooo00?o0000ooooooooool00_ooool01omgMgOoV9RHoooooonHV9SoMgMgooooool000006?ooool0
1Ol@413o^[Zjo`000?mgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0:ooooo`03o`00
0?oooooooooo00kooooo00GoV9RHob4Q8Oo^k^koooooo`000003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00gooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo00Co0000oooooooooooo00001?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000ooooooooool03?ooool01_nHV9So8B4Q
onk^k_ooooooA4A4o`0000;ooooo00Go0000oiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00Go
MgMgoiRHV?oooooo0000ogMgM`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko00000_ooool5o`0000?ooooo
00Ko410@oooooooooooooooooa0@4?l0000Aooooo`Ko00001Oooool2o`0000?ooooo00Go410@oooo
oooooooooooooa0@4009ooooo`03o`000?oooooooooo00Oooooo1_l00003ooooo`04oiRHV?lQ8B7o
k^k^o`0000?ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo00Sooooo
1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`05
o`000?ooooooooooooooool000001?ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000
ooooooooool03?ooool01?nHV9So8B4Qonk^k_l00003ooooo`05oa0@4?l0003oooooooooool@4100
3Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00Go0000oooooooooooo
oooooa0@4002ooooo`03o`000?l@413ooooo00gooooo00?o0000ooooooooool02_ooool5o`0000?o
oooo00Go410@oooooooooooooooooa0@400>ooooo`004oooool01?m4A4CogMgMooooool00004oooo
o`04o`000?ooooooooooooooo`;o00007?ooool00ol0003o410@ooooo`02ooooo`05o`000?oooooo
ooooooooool000002Oooool00ol0003oooooooooo`0Aooooo`03oiRHV?lQ8B7o000000?ooooo00Go
0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05?ooool01Ol0003o
oooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooo
oooo00gooooo00?oV9RHob4Q8Ol000000oooool2o`0000;ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?oZJVYoa0@4?ooool00_ooool0
1Ol0003oooooo`000?oooooo000000oooooo00?o0000ooooooooool02Oooool01?m4A4CogMgMoooo
ool00004ooooo`05o`000?ooooooooooooooool000003_ooool001?ooooo00CogMgMoeEEEOoooooo
00001?ooool01Ol0003ooooooooooooooooo000001cooooo00?o410@o`000?nj^[X00oooool01Ol0
003ooooooooooooooooo000000Wooooo00?o0000ooooooooool04_ooool00omgMgOo0000ooooo`02
ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000cooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Cooooo
00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000003?ooool00ol0
003oooooooooo`0>ooooo`03ogMgMol0003ooooo00;ooooo0_l00002ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03oa0@4?l0003o^[Zj
00?ooooo00Go0000ooooool0003oooooo`00000@ooooo`03o`000?oooooooooo00Sooooo00CogMgM
oeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000kooooo000Dooooo`03ogMgMoo<
c<co000000Cooooo00Go410@ooooooooooooooooo`00000Mooooo`03o`000?lQ8B7ooooo00;ooooo
00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo01Cooooo0_l00002ooooo`05
oa0@4?ooooooooooooooool@41001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000
ooooooooool04?ooool2o`0000Sooooo00?o0000ooooooooool04oooool01Ol0003ooooooooooooo
oooo000000Cooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00kooooo
0_l00003ooooo`05oa0@4?l0003oooooooooool@41003Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413oooooo`000?oooooo410@
013ooooo00?o0000ooooooooool02Oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41003_ooool001Cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9So
000001[ooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2?ooool00ol0003oooooooooo`0@ooooo`06o`000?nj^[[ooooooiRHV?l@413o00000_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00gooooo
00?o0000ooooooooool02_ooool01Ol0003o^[Zjooooool0003o410@00?ooooo00GoMgMgo`000?oo
ooooV9RHogMgM`0=ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01Ol@
413oV9RHoooooonj^[[o000000?ooooo00GoMgMgo`000?ooooooV9RHogMgM`0Aooooo`03o`000?oo
oooooooo00Sooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo
000Eooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bo`00000Jooooo`05ojVY
ZOl@413o0000oa0@4?l000000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooo
ooooool04?ooool01_nHV9So410@o`000?lQ8B7oc<c<o`0000;ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02_ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool04Oooool01_l0003ooooooooooomEEEGoIVIV
o`0000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03o`000?oooooooooo00[ooooo00Go
V9RHoa0@4?l0003o0000olc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03oooo
o`05onk^k_l0003o0000oc8b<_o^k^h04Oooool00ol0003oooooooooo`09ooooo`03ogMgMol0003o
oooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`007oooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo027ooooo000Oooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool08Oooool001kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Pooooo`00
7_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo023ooooo000Nooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool07oooool001Koooooool00010o`0001?ooooo000Foooo
o`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000000Gooooo00?o0000oooo
ooooool01Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`05ooooo`;o00001Oooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aoooo
o`005_ooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000005ooooo`03
o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01?ooool2o`00
00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
000000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`05ooooo`;o00001Oooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Cooooo
0_l00006ooooo`;o00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017o
oooo000Mooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool07Oooool001gooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Mooooo`007Oooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo01gooooo000Looooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool07?ooool001cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Looooo`00
7?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo
00007oooool00ol0003oooooooooo`0Looooo`007?ooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Jooooo`;o0000
3Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
3oooool3o`00027ooooo00?o0000ooooooooool06oooool001cooooo00?o0000ooooooooool08_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool06ooo
ool001cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo01_ooooo000Kooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`0Jooooo`006oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool06_ooool001_ooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0dooooo`03o`000?oooooooooo01[ooooo000Kooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`0Iooooo`006oooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool06Oooool001_ooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool07_ooool2o`0000oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo03Gooooo00?o0000ooooooooool06Oooool001_ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01kooooo00Go0000oooooooo
ooooooooo`00000Fooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Oooooo`04o`000?ooooooooooo`00
01Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
03Gooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01oooooo00?o0000ooooool000005oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`0Hooooo`006_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool08Oooool2o`0001Oooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool06?ooool001[ooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool06?ooool001[ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool06?ooool001[ooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool06?ooool001[ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Oooooo`;o
00004?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`0Hooooo`006Oooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Gooooo`006Ooo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Cooooo00Co0000oooooooooooo0000
4?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
5oooool001Wooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Tooooo`04o`000?oo
ooooooooo`00013ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0gooooo`03o`00
0?oooooooooo01Oooooo000Iooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09?oo
ool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
=oooool00ol0003oooooooooo`0Gooooo`006Oooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo02Gooooo0ol0000@ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`0Gooooo`006Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo01Gooooo1Ol00006ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0hooooo`03o`000?oooooooooo01Oooooo000Iooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool05Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Wooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo01Oooooo000Hoooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0moooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05_ooool00onHV9So8B4Qonk^kP07oooo
o`?o00003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo01Kooooo000Hooooo`03
o`000?oooooooooo02[ooooo00Go0000ooooooooooooooooo`00000oooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool05oooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Fooooo`006?ooool00ol0003o
ooooooooo`0Zooooo`04o`000?ooooooooooo`00043ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Iooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo01Kooooo000Hooooo`03o`000?oooooooooo02_o
oooo00?o0000ooooool00000@?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Wo
oooo00?o0000ooooooooool05_ooool001Sooooo00?o0000ooooooooool0:oooool3o`00043ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`05o`000?nj^[[ooooooiRHV?l@
41001_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0>_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Wooooo00?o0000oooooooo
ool05_ooool001Oooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool05_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Ko
oooo00?o0000ooooooooool04Oooool01Ol0003ooooooooooooooooo000003cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo01Gooooo000Gooooo`03
o`000?oooooooooo06oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo017ooooo00Go0000ooooooooooooooooo`00000looooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Eooooo`005oooool00ol0003o
ooooooooo`1`ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`0Aooooo`05o`000?ooooooooooooooool00000??ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo03[ooooo00?o0000ooooooooool05Oooool001Oooooo00?o0000oooooooo
ool0L?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02;ooooo0_l0000Booooo`04
o`000?ooooooooooo`0003kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0joooo
o`03o`000?oooooooooo01Gooooo000Gooooo`03o`000?oooooooooo073ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo017ooooo00Co0000oooooooo
oooo0000?_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool05Oooool001Oooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool04_ooool00ol0003oooooo`00000nooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Eooooo`00
5_ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo01Gooooo000Fooooo`03o`000?oo
oooooooo077ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo05?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo01Cooooo000Fooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0looooo`04o`000?ooooooooooo`0001?ooooo002:ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0??ooool2o`000003ooooool0003ooooo01;ooooo002:oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1Coooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0?Oooool2o`0001Cooooo002:ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1Cooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0Doooool008_ooooo00Go0000oooooooooooo
ooooo`00000Uooooo`;o0000E?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05?o
oooo002;ooooo`05o`000?ooooooooooooooool000009Oooool00ol0003oooooooooo`1Cooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0Doooool008_ooooo00Go0000oooooooooooo
ooooo`00000Uooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`1Cooooo`00Roooool01Ol0003ooooooooooooooooo000002Gooooo00?o0000oooooooo
ool0Doooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05?ooooo002;ooooo`05o`00
0?ooooooooooooooool000009Oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0Doooool008_ooooo00Go0000ooooooooooooooooo`00000Uooooo`03
o`000?oooooooooo05?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Cooooo`00
Roooool01Ol0003ooooooooooooooooo000002Gooooo00?o0000ooooooooool0Doooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo05?ooooo002<ooooo`03o`000?oooooo000002Kooooo
00?o0000ooooooooool0Doooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05?ooooo
002<ooooo`03o`000?oooooo000002Kooooo0_l0001Dooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0Doooool008cooooo00?o0000ooooool000009_ooool00ol0003oooooooooo`1C
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Doooool008gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0E?ooool00;Gooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo05Cooooo002eooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`1Dooooo`00[?ooool2o`000003oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool0E?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05Cooooo002]
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo05Cooooo002Zooooo`Go00001_ooool00ol0003oooooooooo`1Doooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0E?ooool00:[ooooo00CoA4A4omgMgOoo
oooo00001oooool3o`0005Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Doooo
o`00Z_ooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo05Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Dooooo`00Zoooool00omgMgOoc<c<o`000007ooooo`03
o`000?oooooooooo05Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Dooooo`00
Zoooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`1Dooooo`00[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oo
oooooooo05Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Dooooo`00]Oooool0
0ol0003oooooooooo`1Eooooo`05o`000?ooooooooooooooool00000E_ooool00;Gooooo00?o0000
ooooooooool0EOooool01Ol0003ooooooooooooooooo000005Kooooo002eooooo`03o`000?oooooo
oooo05Gooooo00Co0000oooooooooooo0000Eoooool00;Gooooo0_l0001Fooooo`04o`000?oooooo
ooooo`0005Oooooo002eooooo`03o`000?oooooooooo05Gooooo00Co0000oooooooooooo0000Eooo
ool00;Gooooo00?o0000ooooooooool0EOooool01?l0003oooooooooool0001Gooooo`00]Oooool0
0ol0003oooooooooo`1Eooooo`04o`000?ooooooooooo`0005Oooooo002eooooo`03o`000?oooooo
oooo05Gooooo00Co0000oooooooooooo0000Eoooool00;Gooooo00?o0000ooooooooool0EOooool0
1?l0003oooooooooool0001Gooooo`00]Oooool00ol0003oooooooooo`1Eooooo`04o`000?oooooo
ooooo`0005Oooooo002eooooo`03o`000?oooooooooo05Kooooo00?o0000ooooool00000Eoooool0
0;Gooooo0_l0001Gooooo`03o`000?oooooo000005Oooooo002eooooo`03o`000?oooooooooo05Ko
oooo00?o0000ooooool00000Eoooool00;Gooooo00?o0000ooooooooool0E_ooool2o`0005Sooooo
002eooooo`03o`000?oooooooooo05Kooooo0_l0001Hooooo`00]Oooool00ol0003oooooooooo`1F
ooooo`;o0000F?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0/?oo
ool00:[ooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Z
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool0
1Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0002`ooooo`00Z_ooool01Ol0003oEEEEo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00?oEEEEohN7Qoooool02?ooool0
0ol0003oooooooooo`2`ooooo`00Z_ooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo
0;3ooooo002[ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo00Goc<c<ob4Q8Ol0
003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05ob4Q8OnHV9SooooooiRH
V?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06oooo
o`?o0000/?ooool00:[ooooo00Goc<c<o`000?l0003o0000olc<c02iooooo`00Z_ooool01Ol@413o
^[Zjoooooonj^[[o410@0;Wooooo002Zooooo`05o`000?nj^[[ooooookZj^_l00000^Oooool00:[o
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@2iooooo`00oooooomYooooo`00[oooool00ol0003o^[Zj
ooooo`2fooooo`00[oooool2oc8b<[Oooooo0020ooooo`;o000000Ko410@oooooooooooo410@o`00
0?l@410Hooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Wooooo1?l00000
2?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
07Sooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`0000go
oooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL00oooool00oo<c<co0000oa0@
400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000cooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1hoooo
o`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooo
oooo410@0oooool00ol@413oooooooooo`0@ooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
401hooooo`00POooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000=ooooo`05ogMg
Molb<S;oooooooooool000000oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_o
oooo1_l0000<ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool00000N?ooool0087ooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0
000Iooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000001;o
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000007Sooooo0021ooooo`06o`000?n7QhOoZJVY
okZj^_mEEEGo00006Oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100
4?ooool00ol@413o0000o`000003o`0001cooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@401hooooo`00POooool01_l0003o
<S8boooooooooooo<S8bo`0001Wooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg01;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg07Sooooo0020ooooo`03oa0@
4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0Booooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1hooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(102) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .37187 m
.01975 .27103 L
.02492 .23102 L
.02981 .20195 L
.03251 .18949 L
.03544 .17849 L
.04057 .16446 L
.04333 .15903 L
.04625 .15445 L
.0515 .14837 L
.05634 .14438 L
.06168 .14108 L
.06743 .13826 L
.07362 .13572 L
.07946 .13379 L
.08227 .13305 L
.08481 .13251 L
.08605 .1323 L
.08739 .13213 L
.08865 .13201 L
.08981 .13195 L
.09105 .13195 L
.09241 .13203 L
.09309 .1321 L
.09382 .13221 L
.09515 .13248 L
.09638 .13284 L
.09772 .13334 L
.09891 .1339 L
.10017 .13462 L
.10254 .13641 L
.10474 .13864 L
.10731 .14209 L
.11008 .14708 L
.11269 .15324 L
.11509 .16035 L
.12065 .18326 L
.12344 .1986 L
.1265 .21838 L
.13159 .2568 L
.13709 .29938 L
.13962 .31552 L
.141 .32264 L
.1423 .32794 L
.1434 .33131 L
.14458 .33366 L
.14589 .33466 L
.14709 .33407 L
.1478 .33304 L
.14856 .33141 L
Mistroke
.14992 .32711 L
.15154 .3199 L
.15301 .31163 L
.15862 .26997 L
.16362 .22939 L
.16909 .19103 L
.17423 .16396 L
.17703 .15272 L
.17964 .14422 L
.18205 .13791 L
.18433 .13309 L
.18695 .12873 L
.18934 .12571 L
.19199 .12324 L
.19332 .1223 L
.19479 .12148 L
.19604 .12095 L
.19739 .12055 L
.19866 .12033 L
.19983 .12026 L
.2012 .12034 L
.20248 .12057 L
.20321 .12077 L
.20388 .12099 L
.20538 .12164 L
.20682 .12246 L
.20838 .12357 L
.21122 .12618 L
.2137 .12916 L
.21637 .13317 L
.22118 .14285 L
.2269 .15917 L
.23213 .17894 L
.23769 .20429 L
.24361 .23275 L
.24604 .24341 L
.24866 .25327 L
.25016 .25787 L
.25153 .2613 L
.25285 .2638 L
.25424 .26554 L
.25549 .26631 L
.25663 .26634 L
.25794 .26557 L
.25918 .26407 L
.26033 .26206 L
.26139 .25969 L
.26379 .25274 L
.26887 .23269 L
.27425 .20834 L
Mistroke
.27925 .18728 L
.28462 .16903 L
.2877 .16102 L
.29052 .15525 L
.29335 .15086 L
.29604 .1479 L
.29735 .14686 L
.29804 .14642 L
.29876 .14602 L
.3001 .14548 L
.30133 .14519 L
.30251 .14509 L
.30361 .14515 L
.30482 .14539 L
.30612 .14583 L
.3075 .1465 L
.309 .14745 L
.31173 .14973 L
.31685 .1557 L
.32688 .17214 L
.33616 .18913 L
.34115 .19705 L
.34641 .20363 L
.34916 .20629 L
.35217 .20863 L
.35744 .21186 L
.36002 .2135 L
.36245 .21544 L
.36379 .21679 L
.36525 .21855 L
.36779 .22257 L
.37022 .22783 L
.3728 .23525 L
.375 .24336 L
.37741 .2544 L
.38258 .28589 L
.3873 .32236 L
.39238 .36218 L
.39377 .37149 L
.39525 .37998 L
.39664 .38637 L
.39791 .39058 L
.39918 .39314 L
.40035 .39395 L
.40163 .39309 L
.40298 .3902 L
.40415 .38607 L
.40525 .38096 L
.40774 .36536 L
.41707 .28312 L
Mistroke
.42235 .24056 L
.42514 .22241 L
.42809 .20649 L
.43066 .19519 L
.4335 .18523 L
.43608 .17817 L
.4385 .17303 L
.44101 .16893 L
.44341 .16599 L
.44555 .16397 L
.44789 .16229 L
.45043 .16094 L
.45185 .16037 L
.45314 .15994 L
.45434 .15961 L
.45564 .15932 L
.458 .15895 L
.46322 .15854 L
.4661 .15835 L
.46882 .15808 L
.47135 .15776 L
.47411 .15732 L
.47893 .15637 L
.4844 .15495 L
.48947 .15323 L
.49504 .15114 L
.50104 .1491 L
.50361 .14834 L
.50631 .14764 L
.50862 .14715 L
.50993 .14693 L
.51114 .14678 L
.51238 .14669 L
.51355 .14667 L
.51459 .1467 L
.51573 .14681 L
.51697 .14702 L
.51828 .14735 L
.5194 .14772 L
.52063 .14824 L
.52207 .149 L
.52344 .1499 L
.52602 .15208 L
.52879 .15532 L
.5318 .16021 L
.53443 .16592 L
.53723 .17379 L
.54226 .19349 L
.545 .20765 L
.5479 .22542 L
Mistroke
.55308 .26373 L
.55913 .31241 L
.56208 .33277 L
.56337 .34002 L
.56477 .34645 L
.56608 .35088 L
.56728 .35353 L
.56843 .3547 L
.56965 .35444 L
.57094 .35252 L
.57214 .34923 L
.57346 .34406 L
.57488 .33682 L
.5777 .3183 L
.58066 .29483 L
.58596 .2504 L
.59113 .21203 L
.59601 .1838 L
.5987 .17151 L
.60162 .16057 L
.60405 .15311 L
.60672 .14636 L
.6116 .13714 L
.61427 .13339 L
.61677 .13051 L
.62123 .12658 L
.62373 .12494 L
.62602 .12374 L
.62841 .12275 L
.63105 .12195 L
.63238 .12167 L
.63308 .12154 L
.63381 .12144 L
.63516 .12131 L
.6364 .12127 L
.63755 .1213 L
.63878 .12141 L
.63994 .12159 L
.641 .12182 L
.64224 .12219 L
.64358 .12271 L
.64602 .12398 L
.64864 .12591 L
.65152 .12882 L
.65453 .13294 L
.65735 .13802 L
.66239 .15079 L
.66522 .16045 L
.66781 .17104 L
.67815 .22984 L
Mistroke
.68309 .26252 L
.68552 .27706 L
.68775 .2884 L
.68902 .29367 L
.6904 .29829 L
.69108 .30006 L
.6918 .30159 L
.69256 .30278 L
.69328 .30349 L
.69462 .30377 L
.6959 .30273 L
.69704 .30075 L
.69828 .2975 L
.69963 .29282 L
.70111 .28637 L
.70412 .27006 L
.70951 .23501 L
.71468 .20212 L
.72011 .1738 L
.72476 .15595 L
.72739 .14831 L
.72983 .14266 L
.7312 .14006 L
.73269 .13768 L
.734 .13593 L
.73538 .13443 L
.73663 .13335 L
.738 .13248 L
.73925 .13194 L
.74042 .13166 L
.74112 .13159 L
.74188 .1316 L
.74327 .13183 L
.74462 .13234 L
.74588 .13305 L
.74736 .1342 L
.74871 .13555 L
.75173 .13965 L
.75418 .14419 L
.75687 .15058 L
.75949 .1584 L
.76229 .16874 L
.76731 .19316 L
.77199 .22362 L
.78336 .32282 L
.78836 .36384 L
.78973 .3728 L
.7912 .38094 L
.79259 .38705 L
.79387 .39121 L
Mistroke
.79514 .39397 L
.79586 .39491 L
.79653 .39539 L
.79776 .39531 L
.79906 .39394 L
.79978 .39268 L
.80055 .39093 L
.80196 .38687 L
.80458 .37688 L
.81622 .32587 L
.83736 .25916 L
.84725 .22037 L
.8527 .20057 L
.85786 .18495 L
.86078 .17771 L
.86395 .17114 L
.86659 .16672 L
.86951 .16291 L
.87225 .1603 L
.87375 .15924 L
.87516 .15845 L
.87647 .1579 L
.87767 .15753 L
.87899 .15726 L
.87966 .15718 L
.88038 .15712 L
.88172 .15713 L
.88248 .15719 L
.88318 .15727 L
.88446 .15751 L
.88582 .15786 L
.88817 .15872 L
.89076 .15997 L
.90184 .16707 L
.90682 .17006 L
.90956 .17147 L
.91216 .1726 L
.91457 .17341 L
.91594 .17376 L
.91721 .174 L
.91838 .17415 L
.91944 .17422 L
.92067 .17424 L
.92182 .17419 L
.92304 .17406 L
.92435 .17386 L
.92559 .1736 L
.92672 .17331 L
.93209 .17142 L
.93728 .16903 L
Mistroke
.94292 .16622 L
.94544 .16511 L
.94681 .16459 L
.9481 .16418 L
.94929 .16387 L
.95038 .16366 L
.95159 .16352 L
.95289 .16347 L
.95403 .16354 L
.95509 .16369 L
.95625 .16397 L
.95749 .16441 L
.9588 .16504 L
.96003 .16582 L
.96233 .16782 L
.96346 .1691 L
.96467 .17073 L
.96687 .17442 L
.96947 .18023 L
.97186 .18712 L
.97433 .1961 L
.97703 .20822 L
.98193 .23719 L
1 .37187 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
001Dooooo`Co0000GOooool00ol0003oooooooooo`0Wooooo`?o0000Q_ooool005?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo02Gooooo0ol00002
ooooo`;o0000Q?ooool005;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Ioooo
o`03o`000?oooooooooo02?ooooo0_l00007ooooo`03o`000?oooooooooo087ooooo001Aooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0F?ooool2o`0002?ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`20ooooo`00;_ooool8o`0001[ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Gooooo`Go0000Hoooool002cooooo0_l00008ooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Gooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Fooooo`;o00000ooo
ool00ol0003oooooooooo`1Qooooo`00:_ooool2o`0000_ooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Cooooo0_l00005ooooo`03o`000?oooooo
oooo063ooooo000Yooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`1Pooooo`009oooool2o`0000oooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo01Kooooo1?l0000looooo`03o`000?oooooooooo00?o
00007?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`1Oooooo`009_ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Dooooo`04o`00
0?ooooooooooooooo`;o0000>_ooool5o`000004ooooool0003o0000o`0001[ooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0Goooool002Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooool000001oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo05kooooo000Tooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0aooooo`Co00000_ooool2o`0000Oooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`1Nooooo`008oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0:Oooool8o`0000Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02;ooooo1Ol0000gooooo`008oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool09Oooool3
o`0000kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool00oooool2o`0003Gooooo000Eooooo`;o000000Wo410@oooo
ooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h00oooool00ol0003oooooooooo`0Dooooo`05o`00
0?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool03_ooool01?l0003oooooooooooooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03?ooool4o`000008oa0@4?oo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo000000?o000000So410@oooo
ooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000ooooooooool04?ooool6o`0000?ooooo
00Gok^k^oc8b<_l0003o0000onk^kP0Kooooo`0>oiRHV?l@413o0000oc8b<_o<c<coooooo`000?oo
ooook^k^oc8b<_l0003o<S8bonk^k_ooool2o`0000kooooo1Ol00007ooooo`;o000000Wo410@oooo
ooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h03_ooool001Kooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?o0000ooooooooool05?ooool01Ol0003o^[Zj
oooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo
00oooooo00So0000ooooooooooooV9RHob4Q8Oo^k^koooooodA4A0?ooooo00OoMgMgoiRHV?oooooo
V9RHogMgMooooooo000000cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`03o`000?oooooooooo00kooooo00Oo
0000oooooonHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?oooooo0000ogMgM`0Koooo
o`06oa0@4?nj^[[oooooogMgMolb<S;o00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00?o0000ooooooooool02Oooool2o`0000Cooooo0_l00007ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`002oooool6o`0000;ooooo1Ol00003ooooo`05oa0@
4?ooooooooooooooool@41000_ooool00ol0003oooooooooo`0=ooooo`Ko00000oooool01?l0003o
ooooooooool00003ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`0:
ooooo`Ko00000oooool00onHV9So8B4Qonk^kP04ooooo`07oa0@4?ooooooooooooooool@413ooooo
o`00000<ooooo`03o`000?oooooooooo00;ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@400;ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@00Oooooo00?o0000ooooooooool03_ooool01_l0
003ooooooooooonHV9So8B4Qonk^kPCooooo00Go410@oooooooooooo0000oa0@400Oooooo`05o`00
0?ooooooooooooooool@41000oooool00ol@413oooooooooo`02ooooo`;o00001_ooool3o`0000Oo
oooo0_l00003ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00kooooo000Cooooo`04
odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo01Kooooo00Co0000oooooonYZJWo410@0oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`03oiRHV?lQ8B7ok^k^00?ooooo
00Oo0000ooooooooooooooooo`000?oooooo000000gooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oo
oooooooo00kooooo00Oo0000oooooooooooooooooiRHV?lQ8B7ok^k^00?ooooo00?o0000oooooooo
ool00_l0000Nooooo`03ojVYZOl0003ooooo00;ooooo00Go0000ooooooooooooooooo`000006oooo
o`Ko00003?ooool01ol0003ooooooooooom4A4CogMgMooooool000001?ooool01Ol0003ooooooooo
oooooooo000000kooooo000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000oooooooooooo
ooooo`000002ooooo`03o`000?oooooooooo01Kooooo00Co0000oa0@4?l0003o^[Zj0oooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02
ooooo`03ogMgMomVIVKooooo00;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00002_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00ol@413o0000okZj^P03
ooooo`05o`000?ooooooooooooooool000006?ooool01ol0003ooooooooooooMgMgoEEEEooooool0
00001?ooool01Ol0003ooooooooooooooooo000000kooooo000Dooooo`03ogMgMoo<c<co000000Co
oooo00Oo410@oooooooooooooooooa0@4?oooooo000001[ooooo00?o0000okZj^_lQ8B400oooool0
1Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`03ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413o0000ooooo`0>ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00[o
oooo00?o0000ooooooooool04Oooool2o`0000[ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4008oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo
410@00?ooooo00?o0000ooooooooool07?ooool00ol0003o8B4Qooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41006?ooool01ol0003oooooooooooooooooMgMgolc<c?l000001?ooool01Ol@413o
oooooooooooooooo410@00kooooo000Dooooo`03onk^k_m4A4Co000000Cooooo00OoMgMgoiRHV?oo
ooooV9RHogMgMooooooo000001Sooooo00Go410@oiRHV?l0003o^[Zjo`000003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0Aooooo`07o`000?oooooo0000okZj^_oo
ooooV9RHoa0@4003ooooo`06ogMgMonHV9SooooooiRHV?mgMgOo00004?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`09ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00So
oooo00?o0000ooooooooool03?ooool02?l0003oooooooooool0003o^[ZjoooooonHV9So410@0ooo
ool01OmgMgOoV9RHoooooonHV9So000001_ooooo00Go410@oiRHV?l0003o^[Zjo`000003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL06?ooool01ol0003oooooooooooooooook^k^odA4A?l000001?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000Eooooo`03ogMgMol0003ooooo00?ooooo00Ko
k^k^oc8b<_l0003o<S8bonk^k_l0000Iooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool04Oooool01ol0003ooooooiRHV?l@
413o0000ob4Q8Oo<c<`00oooool01_o^k^ko<S8bo`000?lb<S;ok^k^o`00013ooooo00?o0000oooo
ooooool02?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02Oooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03_ooool0
1ol0003oooooooooooooooooEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00So
oooo00?o0000ooooooooool03?ooool02?l0003ooooooooooonHV9So410@o`000?lQ8B7oc<c<0ooo
ool01Oo^k^ko<S8bo`000?lb<S;o000001_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h06Oooool01_l0003oooooooooooooooooMgMgo`0000Cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0>ooooo`008?ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool06_ooool0023ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01Wooooo000Pooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Iooooo`007oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool06Oooool001oooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01Wooooo
000Foooooooo0000@?l0000Cooooo`005_ooool00ol0003oooooooooo`05ooooo`;o00001_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool0
0ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l0
0006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`04ooooo`;o00001oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool2o`0000Kooooo00?o0000ooooooooool04Oooool001Kooooo00?o0000ooooooooool0
1Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo0_l00006ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool00000
1oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oo
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo0_l00007
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo017ooooo000Ooooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06?ooool2o`0001Cooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01Sooooo000Nooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Hooooo`00
7_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
6?ooool001kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo01Oooooo000Nooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0Gooooo`007_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool05oooool001kooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05_ooool2o`0000go
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool05oooool001kooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo01Oooooo000Nooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`0Gooooo`007Oooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool05oooool001gooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Oooooo000Mooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Gooooo`00
7Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
5_ooool001gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo01Kooooo000Mooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool000009?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo01Oooooo0_l0000?ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Kooooo000M
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0J
ooooo`04o`000?ooooooooooo`0002Cooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool05_ooool001cooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01_ooooo0ol0000U
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo01Kooooo000Looooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool05_ooool001cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo04?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool05_ooool001cooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
5Oooool001cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo04Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool05Oooool001cooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool05Oooool0
01_ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
04Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Hooooo`;o00004?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`0Eooooo`006oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01oo
oooo00Go0000ooooooooooooooooo`00000Gooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`0Eooooo`006oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01oooooo00Go0000ooooooooooooooooo`00000Hooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Eooooo`006oooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0AOooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01oooooo00Co0000oooooooooooo00006Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool05Oooool001_o
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04Go
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Oooooo`04o`000?ooooooooooo`00
01Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo
01Cooooo000Jooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`16ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07oooool2o`000003
ooooool0003ooooo01Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo01Cooooo000Jooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
3Oooool5o`0000Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo023ooooo0ol0000Iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`0Dooooo`006_ooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00kooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Dooooo`006_ooool00ol0003ooooooooo
o`0Uooooo`05o`000?ooooooooooooooool00000BOooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00oooooo00?oV9RHob4Q8Oo^k^h01oooool3o`00013ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`0Dooooo`006_ooool00ol0003oooooooooo`0Uooooo`05o`000?oo
ooooooooooooool00000BOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo013ooooo
00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool05?ooool001Wooooo00?o0000ooooooooool09_ooool01Ol0003ooooooooo
oooooooo000004[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`03ogMg
MomVIVKooooo00Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooooooo01Cooooo000Iooooo`03o`000?oooooooooo02Kooooo00Go0000oooooooooooooooo
o`00001:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0nooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`0Cooooo`006Oooool00ol0003oooooooooo`0Wooooo`04o`000?ooooooooooo`0004[ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0>ooooo`05o`000?nj^[[ooooooiRHV?l@
41001_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool04oooool001Wooooo00?o0000ooooooooool09oooool01?l0003oooooooooool0001:ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool03_ooool01OnHV9So410@o`000?lQ8B7oc<c<
00Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
01?ooooo000Iooooo`03o`000?oooooooooo02Oooooo00?o0000ooooool00000Boooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo01?ooooo000Iooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooool00000Boooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool04Oooool01Ol0003ooooooooooooooooo0000047ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo01?ooooo000Hooooo`03o`00
0?oooooooooo02Wooooo0_l0001<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
6Oooool2o`0001;ooooo00Go0000ooooooooooooooooo`000011ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Cooooo`006?ooool00ol0003ooooo
ooooo`1gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Aooooo`05o`000?ooooooooooooooool00000@_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool04oooool001Sooooo00?o0000ooooooooool0
Moooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
4Oooool01Ol0003ooooooooooooooooo000004;ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo01;ooooo000Hooooo`03o`000?oooooooooo07Oooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo017ooooo
00Co0000oooooooooooo0000@oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool04_ooool001Sooooo00?o0000ooooooooool0Moooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool04Oooool01?l0003ooooo
ooooool00013ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`0Booooo`005oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo000004?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo01;ooooo
000Gooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo01;ooooo0_l00014ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0>?ooool00ol0003oooooooooo`0Booooo`005oooool00ol0003oooooooooo`1i
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0h
ooooo`03o`000?oooooooooo01;ooooo000Gooooo`03o`000?oooooooooo07Wooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05Wooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo01;ooooo000Gooooo`03
o`000?oooooooooo07Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Jooooo`;o
0000F_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03[ooooo00?o0000oooooooo
ool04Oooool001Kooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo03[ooooo00?o0000ooooooooool04Oooool001Kooooo00?o0000ooooooooool0N_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0FOoo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool04Ooo
ool001Kooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool04Oooool009?ooooo00Go0000ooooooooooooooooo`00000M
ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1?
ooooo`00U?ooool01?l0003oooooooooool0000Mooooo`03o`000?oooooooooo05[ooooo00Go0000
ooooooooooooooooo`00001Aooooo`00U?ooool01?l0003oooooooooool0000Mooooo`03o`000?oo
oooooooo05[ooooo00Go0000ooooooooooooooooo`00001Aooooo`00U?ooool01?l0003ooooooooo
ool0000Mooooo`03o`000?oooooooooo05[ooooo00Co0000oooooooooooo0000D_ooool009Cooooo
00?o0000ooooool000007_ooool2o`0005_ooooo00Co0000oooooooooooo0000D_ooool009Cooooo
00?o0000ooooool000007_ooool00ol0003oooooooooo`1Jooooo`04o`000?ooooooooooo`0005;o
oooo002Eooooo`;o00007_ooool00ol0003oooooooooo`1Kooooo`;o0000Doooool00;Gooooo00?o
0000ooooooooool0Foooool2o`0005?ooooo002eooooo`03o`000?oooooooooo0;3ooooo002/oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`2`ooooo`00[Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01?m4A4CogMgMooooool00007ooooo`?o0000/?ooool00:[ooooo00Co
gMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`2`ooooo`00Zoooool00omgMgOoc<c<o`00
0007ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03onk^k_m4A4Co000000Oooooo00?o0000
ooooooooool0/?ooool00:cooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000
/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Oo^k^ko
<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00GoEEEEogMgMooo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003oV9RHoooooonHV9So8B4Q
00Kooooo0ol0002`ooooo`00Z_ooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000oooo
ooooool0/?ooool00:[ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`2`ooooo`00
Z_ooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000
/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00:[ooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`00
0?oooooooooo0;3ooooo002Zooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000/?ooool00:[ooooo00Go
c<c<o`000?l0003o0000olc<c02iooooo`00Z_ooool01Ol@413o^[Zjoooooonj^[[o410@0;Wooooo
002Zooooo`05o`000?nj^[[ooooookZj^_l00000^Oooool00:[ooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@2iooooo`00oooooomYooooo`00[oooool00ol0003o^[Zjooooo`2fooooo`00[oooool2oc8b
<[Oooooo0020ooooo`;o000000Ko410@oooooooooooo410@o`000?l@410Hooooo`05odA4A?l0003o
0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?oQhN7o`000?nj^[X0
3?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Wooooo1?l000002?l@413oooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^0oooool5o`0007Sooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01oooool6o`0000gooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mg
MgL00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`00
00cooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A01hooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo01_ooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`0@ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Cooooo
00?oV9RHob4Q8Oo^k^h0NOooool0087ooooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko
00003Oooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0;ooooo`Ko00003?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000001Oooool00onHV9So8B4Qonk^kP1hooooo`00POooool01_l0003ogMgMoc8b<_mEEEGo
gMgMo`0001Wooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool0
00004_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000006ooooo`03ogMgMomVIVKooooo07Oooooo0021ooooo`06o`000?n7QhOoZJVYokZj
^_mEEEGo00006Oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41004?oo
ool00ol@413o0000o`000003o`0001cooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@00Oooooo00?o0000ooooooooool0M_ooool0087ooooo00Ko0000oc8b<_oooooooooo
oc8b<_l0000Iooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Boooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00Go0000okZj^_ooooooV9RHoa0@401hooooo`00P?ooool00ol@413o0000ohN7Q`02
ooooo`03ohN7Qol0003o410@01Sooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_oo
ool00ol0003oooooooooo`0Kooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0N?ooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(104) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .32361 m
.00236 .34472 L
.00488 .36404 L
.0061 .37161 L
.00726 .37742 L
.0083 .38139 L
.00942 .38426 L
.01066 .38561 L
.01203 .38484 L
.01272 .38356 L
.01346 .38154 L
.01479 .37622 L
.01612 .36897 L
.01738 .36048 L
.01975 .34112 L
.02982 .2442 L
.03546 .2014 L
.04057 .17354 L
.04328 .16241 L
.04622 .15276 L
.0488 .14597 L
.05154 .1402 L
.05406 .13585 L
.05684 .13192 L
.06172 .12664 L
.06473 .12426 L
.06748 .12258 L
.07066 .12113 L
.07211 .12061 L
.07366 .12015 L
.07498 .11982 L
.07643 .11953 L
.07776 .11934 L
.079 .11923 L
.07971 .1192 L
.08046 .1192 L
.0818 .11928 L
.08254 .11937 L
.08323 .11949 L
.084 .11966 L
.08481 .11988 L
.0861 .12034 L
.08753 .121 L
.0904 .12286 L
.09307 .1253 L
.09556 .12834 L
.0985 .13313 L
.10118 .13894 L
.10428 .14777 L
.10722 .15865 L
Mistroke
.11248 .18518 L
.11735 .21857 L
.1231 .26644 L
.12838 .30916 L
.13098 .32517 L
.13229 .33115 L
.13303 .33381 L
.13373 .33583 L
.13448 .33744 L
.13517 .33839 L
.13591 .33883 L
.13672 .33863 L
.13742 .33788 L
.13817 .33651 L
.13951 .33261 L
.14074 .32745 L
.14208 .32039 L
.14448 .30436 L
.14997 .25914 L
.15488 .2188 L
.16011 .18366 L
.16265 .17027 L
.16504 .15978 L
.16722 .15191 L
.16952 .14517 L
.17204 .13944 L
.17436 .13551 L
.17556 .13392 L
.17686 .13253 L
.17827 .13135 L
.1796 .13056 L
.18033 .13024 L
.18101 .13002 L
.18176 .12986 L
.18255 .12978 L
.18388 .12986 L
.18464 .13001 L
.18535 .13022 L
.18667 .13081 L
.18788 .13155 L
.18921 .13259 L
.19061 .13394 L
.19325 .13722 L
.19609 .14178 L
.20119 .15286 L
.20726 .17102 L
.21277 .19177 L
.22254 .23149 L
.22492 .23973 L
.22747 .24706 L
Mistroke
.22893 .25038 L
.23027 .25278 L
.23162 .25453 L
.23289 .25555 L
.23426 .25595 L
.23502 .25585 L
.23571 .25557 L
.23706 .2545 L
.23832 .2529 L
.23981 .25033 L
.24117 .24737 L
.24425 .23896 L
.25472 .20292 L
.25966 .18772 L
.26238 .18081 L
.26495 .17537 L
.26735 .17127 L
.26995 .16785 L
.2711 .16667 L
.27232 .16563 L
.27338 .16489 L
.2745 .16428 L
.27584 .16376 L
.27706 .16348 L
.27838 .16339 L
.27913 .16342 L
.27983 .16351 L
.28109 .1638 L
.28224 .1642 L
.28357 .16483 L
.28482 .16556 L
.29028 .17008 L
.2962 .17646 L
.30141 .18234 L
.30428 .18537 L
.307 .18793 L
.30952 .18994 L
.31085 .19082 L
.31227 .1916 L
.31358 .19218 L
.31477 .19259 L
.31597 .19288 L
.31709 .19304 L
.31837 .1931 L
.31973 .19301 L
.32088 .19283 L
.32215 .19251 L
.32352 .19204 L
.32498 .1914 L
.32762 .1899 L
Mistroke
.33368 .18516 L
.33919 .18007 L
.34426 .17562 L
.34964 .1717 L
.35185 .17042 L
.35423 .16929 L
.35559 .16878 L
.35684 .16841 L
.35809 .16815 L
.35928 .16799 L
.36066 .16794 L
.3619 .16803 L
.36259 .16812 L
.36334 .16828 L
.36469 .16867 L
.36596 .16919 L
.36731 .16989 L
.36971 .17159 L
.37252 .17439 L
.37514 .17795 L
.37802 .18317 L
.3811 .19067 L
.38379 .19912 L
.38665 .2104 L
.39178 .2376 L
.3973 .27796 L
.4034 .33237 L
.40595 .35486 L
.40864 .37554 L
.41004 .38438 L
.41079 .38837 L
.41158 .39205 L
.41232 .39486 L
.41299 .39692 L
.41429 .3995 L
.4156 .40012 L
.41681 .39889 L
.41814 .3956 L
.41881 .3932 L
.41955 .39002 L
.42212 .37493 L
.42452 .35633 L
.42974 .30874 L
.43544 .25905 L
.44082 .22225 L
.44339 .20847 L
.44581 .19751 L
.44819 .18844 L
.45076 .18028 L
.45524 .16941 L
Mistroke
.45778 .16471 L
.46046 .16059 L
.46527 .15478 L
.47049 .15008 L
.47524 .14686 L
.48592 .14151 L
.49582 .13781 L
.50065 .13642 L
.50518 .13531 L
.50751 .13486 L
.50882 .13467 L
.51001 .13454 L
.51125 .13446 L
.51261 .13443 L
.51329 .13445 L
.51403 .1345 L
.51534 .13464 L
.51607 .13476 L
.51674 .13489 L
.51825 .13529 L
.51958 .13577 L
.52099 .1364 L
.52344 .13791 L
.52482 .13903 L
.52612 .1403 L
.52863 .14344 L
.531 .14746 L
.53313 .15213 L
.53545 .15854 L
.53797 .16731 L
.54065 .17904 L
.54547 .20734 L
.55529 .29315 L
.56045 .33936 L
.5617 .34827 L
.56304 .35622 L
.56381 .35994 L
.56451 .36275 L
.56588 .36654 L
.56716 .36795 L
.56835 .36737 L
.56965 .36466 L
.57102 .35953 L
.57222 .35331 L
.57334 .34615 L
.57588 .32589 L
.58506 .23677 L
.59028 .19475 L
.59303 .17728 L
.59597 .16205 L
Mistroke
.59879 .15033 L
.60134 .14188 L
.60394 .1351 L
.60633 .13023 L
.60867 .12652 L
.61114 .12351 L
.61362 .12124 L
.61505 .12023 L
.61635 .11948 L
.61747 .11895 L
.6187 .11851 L
.62 .11819 L
.62123 .11803 L
.62237 .11801 L
.62359 .11812 L
.62463 .11831 L
.62578 .11864 L
.62706 .11915 L
.62825 .11975 L
.63095 .12159 L
.63358 .12405 L
.63638 .12753 L
.639 .13174 L
.64148 .13673 L
.6461 .14924 L
.65157 .17018 L
.65661 .19582 L
.6621 .2296 L
.668 .26681 L
.67073 .28121 L
.67208 .28704 L
.67332 .29154 L
.67445 .29477 L
.67565 .29728 L
.67698 .29888 L
.67819 .29923 L
.67942 .2985 L
.68054 .29689 L
.68179 .29413 L
.68309 .29016 L
.6853 .2813 L
.68771 .2691 L
.69354 .23425 L
.69906 .20236 L
.70401 .17945 L
.7068 .16941 L
.70938 .16195 L
.71183 .15639 L
.71412 .15243 L
.71544 .15067 L
Mistroke
.71664 .14938 L
.71803 .14824 L
.71935 .14749 L
.72061 .14707 L
.72197 .14693 L
.72324 .14707 L
.7244 .14741 L
.72576 .14805 L
.72724 .14904 L
.72992 .15154 L
.73257 .15485 L
.73548 .15939 L
.74136 .17113 L
.75189 .19661 L
.75739 .20879 L
.76009 .21373 L
.76259 .21744 L
.76486 .21993 L
.76601 .22084 L
.76727 .22158 L
.76853 .22203 L
.76989 .22219 L
.77118 .22205 L
.77236 .2217 L
.77364 .22108 L
.775 .22019 L
.77746 .2181 L
.78305 .21208 L
.78608 .20884 L
.78757 .20743 L
.78895 .20633 L
.7902 .20553 L
.79152 .20495 L
.79285 .2047 L
.7936 .20472 L
.79431 .20487 L
.79562 .20548 L
.79636 .20604 L
.79702 .20668 L
.79831 .20834 L
.79953 .21043 L
.80096 .21358 L
.80227 .2172 L
.80523 .22811 L
.80763 .24009 L
.81027 .25675 L
.81559 .30188 L
.82038 .35186 L
.82291 .3781 L
.82559 .40248 L
Mistroke
.82671 .41092 L
.82793 .41849 L
.82926 .42473 L
.83051 .42842 L
.83166 .42987 L
.83288 .42929 L
.83392 .42712 L
.83505 .42304 L
.83578 .41954 L
.83646 .41564 L
.83774 .40693 L
.84061 .38197 L
.84578 .32802 L
.85053 .28138 L
.85556 .24324 L
.85817 .22831 L
.86105 .21529 L
.86366 .2061 L
.8661 .19941 L
.86898 .19347 L
.87161 .18946 L
.87465 .18604 L
.87753 .18358 L
.88283 .18009 L
.88763 .1775 L
.89839 .17169 L
.91771 .15979 L
.92286 .15703 L
.92828 .1546 L
.93297 .15292 L
.93798 .15154 L
.94081 .15097 L
.94339 .15058 L
.94463 .15045 L
.94598 .15034 L
.94725 .15028 L
.94843 .15025 L
.94979 .15026 L
.95107 .15031 L
.9518 .15036 L
.95247 .15042 L
.95398 .1506 L
.95542 .15084 L
.957 .1512 L
.95848 .15164 L
.95987 .15215 L
.96258 .15347 L
.96507 .15513 L
.96781 .15757 L
.9707 .16107 L
Mistroke
.97322 .1651 L
.97557 .16991 L
.97815 .17662 L
.98091 .18582 L
.98337 .19604 L
.98604 .20966 L
.9909 .24192 L
1 .32361 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo02?ooooo
0ol0002:ooooo`00;?ooool7o`0008;ooooo00?o0000ooooooooool08Oooool2o`0000;ooooo0ol0
0028ooooo`00:_ooool2o`0000Kooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Q_ooool002Wooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`25ooooo`00:Oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo01Sooooo0ol0001Sooooo`;o00008?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo08Gooooo000Xooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
5_ooool01Ol0003ooooooooooooooooo000006;ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo08Cooooo000Wooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05oooooo
2?l0000Iooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Poooool002Kooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0G?ooool4o`0000Kooooo0_l0000Hooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0Poooool002Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0F?ooool3o`0000?ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0Poooool002Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo08;ooooo000Uooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Cooooo0_l00007ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo01Cooooo1?l0001Zooooo`009?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Booooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo03gooooo2_l0000Pooooo`009?ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Aooooo`03o`000?oo
oooooooo00Sooooo0_l00008ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`08ooooo`;o00007_ooool002?ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Coooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0hooooo`;o00003Oooool00ol0003oooooooooo`0Kooooo`008oooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`1>ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo03Kooooo0_l0000@ooooo`03o`000?oooooooooo
01[ooooo000Eooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool00ol0003oooooooooo`0Booooo`07o`000?ooooooV9RHoa0@4?l0003o<S8bolc<c003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Sooooo1Ol00003ooooo`03onk^k_lb<S;o000000Co00006_ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^h@ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooo`Co000000[o410@oooooooo
ooook^k^oc8b<_l0003o<S8bonk^k_oooooo00004oooool00ol0003oooooooooo`02ooooo`Go0000
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2o`0001?ooooo00?o0000ooooooooool00_l00000
2Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0>ooooo`005_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool00ol0003oooooooooo`0Booooo`07
o`000?oooooo410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A003ooooo`05ogMgMonHV9So0000oiRHV?mgMgL00_ooool00ol0003oooooooooo`0Cooooo`Co
00000_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool01OnHV9So8B4Qonk^k_oo
oooo000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`05oa0@4?nj^[[oooooogMgMolb
<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0_l0000Eooooo`05o`000?oooooooooo
ooooool000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03o`000?oooooooooo00cooooo1ol0
0005ooooo`05o`000?ooooooooooooooool@41000oooool01?l@413oooooooooool0000>ooooo`03
o`000?oooooo000000Go00000oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?l0003ooooooooo
ool@41000oooool00ol0003oooooooooo`0=ooooo`Ko00000_ooool2o`000003ooooool0003ooooo
00?ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00;ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`04ooooo`05oiRHV?lQ8B7ok^k^ooooool000000_ooool01Ol@413ooooo
oooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003ooooo`04oa0@4?oooooo0000
o`0001Oooooo1_l00003ooooo`05oa0@4?ooooooooooooooool@41003_ooool001?ooooo00CoA4A4
omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
4oooool01_l0003oooooooooooooooooZJVYoa0@40?ooooo00Go0000ooooooooooooooooo`000002
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Oooool00onHV9So8B4Qonk^kP03
ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool2o`0000Cooooo00Go0000ooooooooooooooooo`00000@ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`04oiRHV?lQ8B7ok^k^o`0000;o
oooo00Go0000ooooooooooooooooo`00000Nooooo`03ojVYZOl@413ooooo00;ooooo00Co0000oooo
oooooooooooo0_l0000Iooooo`05o`000?m4A4CogMgMooooool000001?ooool01Ol0003ooooooooo
oooooooo000000kooooo000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo01?ooooo00Ko0000oooooooooooo410@o`000?nj^[X3
ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00[ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`07ooooo`06ogMgMomVIVKoooooo`000?oooooo00000oooool00ol0003ooooooooo
o`0Kooooo`03oa0@4?l0003o^[Zj00?ooooo00?o0000ooooooooool00_l0000Kooooo`04o`000?mE
EEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`005?ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol0003oooooooooo`0Cooooo`06
o`000?oooooooooooooooonj^[[o8B4Q0oooool01Ol@413ooooooooooooooooo410@00;ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooo`000?l@4100
0oooool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003o
ooooooooo`0=ooooo`;o00002oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`08ooooo`05o`000?oooooo0000ooooool@41000oooool0
0ol@413oooooooooo`0Looooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@o`000?l0003ooooooa0@
400Kooooo`04o`000?mgMgOoc<c<o`0000Cooooo00Go410@oooooooooooooooooa0@400>ooooo`00
5?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool00ol0003o
ooooooooo`0Dooooo`06o`000?l@413oV9RHoooooonj^[[o00000oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`06ooooo`05o`000?nj
^[[ooooooiRHV?l@41000_ooool01_l0003oMgMgoiRHV?ooooooV9RHogMgM`Oooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`09ooooo`;o00000oooool01OmgMgOoV9RHoooooonHV9So
MgMg00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00go
0000okZj^_ooooooV9RHoa0@4?oooooo0000oooooomgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go
410@oiRHV?oooooo^[Zjo`000003ooooo`05o`000?nHV9SooooooiRHV?mgMgL07?ooool00ol0003o
A4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool001Gooooo00?oMgMgo`000?oo
ool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo00?o0000ooooooooool05?ooool01_l0
003oZJVYoa0@4?l0003o410@ojVYZ@?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool01_ooool03OnHV9So410@o`000?lQ8B7oc<c<oooo
ool0003oooooonk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`05ooooo`;o0000
2_ooool01?mEEEGoIVIVo`000?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`02ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool01OnHV9So410@o`000?lQ
8B7oc<c<00;ooooo00Ko0000onk^k_lb<S;o0000oc8b<_o^k^hKooooo`05ojVYZOl@413o0000oa0@
4?nYZJT00_ooool01_l0003ok^k^oc8b<_l0003o<S8bonk^kQcooooo00?o0000ogMgMol000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Rooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool2o`0000Gooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`0Gooooo`008_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00kooooo1Ol0000A
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo01Kooooo000Rooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`0Fooooo`008Oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool05_ooool0027ooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01Kooooo000Foooooooo0000@?l0
000Cooooo`005_ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool00000
0_ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo0_l00006ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo0000
00Oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Cooooo0_l00007
ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooo
oooooooo000000;ooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`0Aooooo`005_ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooool000001oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`;o00001_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooo`000007
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooo000000Oooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00004ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`0Aooooo`008?ooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo01Gooooo000Pooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool05Oooool0023ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo01?ooooo1?l00008ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0Eooooo`008?ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool05Oooool0023ooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01Gooooo000Pooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Dooooo`008?ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0@ooooo`;o00003Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Dooooo`007oooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool05?ooool001oooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01Cooooo000O
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0D
ooooo`007oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool05Oooool01Ol0003ooooooooooooooooo000002oooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool05?ooool0
01oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
01Kooooo00Co0000oooooooooooo0000<?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Dooooo`007oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05oooool01?l0
003oooooooooool0000`ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01Cooooo000Oooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Gooooo`?o0000<Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0Dooooo`007oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01;o
oooo0_l0000>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo01?ooooo000Nooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01?ooooo
000Nooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo01?ooooo000Nooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01?ooooo000Noooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1<oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Zoooo
o`03o`000?oooooooooo01?ooooo000Nooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01?ooooo000Nooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1<ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo01?ooooo000Nooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01?ooooo000Nooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool04_ooool2o`0000oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool04oooool0
01kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
04gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Kooooo`04o`000?oooooooooo
o`0002Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo
oooo01;ooooo000Nooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1=ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06oooool01?l0
003oooooooooool0000Yooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`0Booooo`007Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
01_ooooo00Co0000oooooooooooo0000:Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool04_ooool001gooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Kooooo`?o0000:_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool04_ooool001gooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Looooo`;o0000:_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02co
oooo00?o0000ooooooooool04_ooool001gooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`08ooooo`Go00001_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0B?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02cooooo
00?o0000ooooooooool04_ooool001gooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`08ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo02gooooo00?o0000ooooooooool04_ooool001gooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`09ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0000?ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool04_ooool001gooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01;ooooo000Mooooo`03o`000?oooooooooo
01oooooo00Go0000ooooooooooooooooo`00001Aooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02oooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`0Aooooo`007Oooool00ol0003oooooooooo`0Ooooo
o`05o`000?ooooooooooooooool00000DOooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool04Oooool001gooooo00?o0000ooooooooool07oooool01Ol0
003ooooooooooooooooo000005;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08
ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool04Oooool001Kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Oooooo`05o`000?ooooooooooooooool00000D_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1:ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Aooooo`005_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo023ooooo00Co0000oooooooooooo0000
Doooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`12ooooo`005_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooool00000Doooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo04[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`12ooooo`005_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo027ooooo00?o0000ooooool00000Doooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Cooooo0_l0000Aooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo04;ooooo000Fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08Oooool3o`00
05?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0@_ooool001Kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo013ooooo00Go0000ooooooooooooooooo`00001=oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0@_ooool001Kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0@ooooo`05o`000?ooooooooooooooool00000C_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo04?ooooo000Fooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool04Oooool01?l0003oooooooooool0001>ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0@oooool001Kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`1hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`0Aooooo`04o`000?ooooooooooo`0004kooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`13ooooo`005_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07Wo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo017o
oooo00Co0000oooooooooooo0000C_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
04?ooooo000Fooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0NOooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool04Oooool01?l0003o
ooooooooool0001>ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0@oooool001Oo
oooo00Go0000ooooooooooooooooo`00001kooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo000004oooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`13ooooo`005oooool01Ol0003ooooooooooooooooo0000
07_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Eooooo`;o00004_ooool00ol0
003oooooo`00001?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0@oooool001Oo
oooo00Go0000ooooooooooooooooo`00001kooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0Booooo`;o0000Coooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo04?ooooo000Gooooo`05o`000?ooooooooooooooool00000O?ooool01Ol0
003ooooooooooooooooo000001Sooooo00?o0000ooooooooool04_ooool2o`00053ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`13ooooo`006?ooool01?l0003oooooooooool0001l
ooooo`05o`000?ooooooooooooooool000006?ooool00ol0003oooooooooo`1Tooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0A?ooool001Sooooo00?o0000ooooool00000OOooool0
1Ol0003ooooooooooooooooo000001Sooooo00?o0000ooooooooool0I?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo04Cooooo000Hooooo`03o`000?oooooo000007gooooo00Go0000
ooooooooooooooooo`00000Hooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`14ooooo`006?ooool00ol0003oooooo`00001mooooo`05o`000?oooooo
ooooooooool000006?ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0A?ooool001Wooooo0_l0001mooooo`04o`000?ooooooooooo`0001Wooooo00?o
0000ooooooooool0I?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04Cooooo000I
ooooo`03o`000?oooooooooo07cooooo00Co0000oooooooooooo00006Oooool2o`0006Gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`14ooooo`00V?ooool01?l0003oooooooooool0
000Iooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`14ooooo`00VOooool00ol0003oooooo`00000Iooooo`03o`000?oooooooooo06Gooooo00Go0000
ooooooooooooooooo`000016ooooo`00VOooool00ol0003oooooo`00000Iooooo`03o`000?oooooo
oooo06Gooooo00Co0000oooooooooooo0000Aoooool009[ooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`1Uooooo`04o`000?ooooooooooo`0004Oooooo002/ooooo`;o000000?o410@
ooooooooool01?ooool00ol0003oooooooooo`1Uooooo`04o`000?ooooooooooo`0004Oooooo002]
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0IOooool01?l0003oooooooooool0
0017ooooo`00Z_ooool5o`0000Kooooo00?o0000ooooooooool0IOooool01?l0003oooooooooool0
0017ooooo`00Z_ooool01?m4A4CogMgMooooool00007ooooo`?o0000IOooool01?l0003ooooooooo
ool00017ooooo`00Z_ooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo06Gooooo
00Co0000oooooooooooo0000Aoooool00:_ooooo00?oMgMgolc<c?l000001oooool00ol0003ooooo
ooooo`1Uooooo`04o`000?ooooooooooo`0004Oooooo002[ooooo`03onk^k_m4A4Co000000Oooooo
00?o0000ooooooooool0IOooool01?l0003oooooooooool00017ooooo`00[?ooool00omgMgOo0000
ooooo`06ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooool00000Aoooool00;Gooooo00?o
0000ooooooooool0I_ooool2o`0004Sooooo002eooooo`03o`000?oooooooooo06Kooooo00?o0000
ooooooooool0Aoooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00:[ooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo
002Zooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00Z_oo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go
0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000/?ooool00:[ooooo00Go0000oeEEEOl0003o410@
olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03oeEEEOn7QhOooooo00Sooooo00?o
0000ooooooooool0/?ooool00:[ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`2`
ooooo`00Zoooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05olc<c?lQ8B7o0000
ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3
o`000;3ooooo002Zooooo`05olc<c?l0003o0000o`000?o<c<`0^Oooool00:[ooooo00Go410@okZj
^_oooooo^[Zjoa0@402iooooo`00Z_ooool01Ol0003o^[Zjoooooonj^[[o00000;Wooooo002Zoooo
o`05ojVYZOl@413o0000oa0@4?nYZJT0^Oooool00?ooooooJOooool00:oooooo00?o0000okZj^_oo
ool0]_ooool00:oooooo0_lb<S:gooooo`00P?ooool2o`000006oa0@4?oooooooooooa0@4?l0003o
410@6?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Iooooo`Co000000So
410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_l000000ol@413oooooooooo`1foooo
o`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l0000=ooooo`09
ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?oc<c<o`000?l@41003?oo
ool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo07Oooooo0021ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool06oooool01?l0003oooooooooool@4103ooooo`03
oa0@4?oooooooooo013ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41000oooool5o`0007Sooooo0021ooooo`06o`000?ooooooA4A4odA4
A?oooooo00002Oooool6o`0000gooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool02oooool6o`0000cooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00CoA4A4omgMgOoooooo0000NOooool0087ooooo
00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Iooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool0
1Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000000oooool01?oMgMgoEEEEooooool0001iooooo`00
POooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001Wooooo00?o0000ooooooooool01?ooool01Ol@
413ooooooooooooooooo410@013ooooo00?o410@o`000?l000000ol0000Looooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@4004ooooo`03ogMgMoo<c<co000007Wooooo0021
ooooo`06o`000?lb<S;ooooooooooolb<S;o00006Oooool00ol0003oooooooooo`04ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL04_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03onk^k_m4A4Co000007Wooooo0020ooooo`03
oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool4o`0000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0Booooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?oMgMgo`000?ooool0N?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(106) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .26963 m
.00488 .32833 L
.00722 .35544 L
.00942 .37762 L
.01068 .38792 L
.01204 .39675 L
.01327 .40238 L
.01441 .40537 L
.01565 .40611 L
.017 .40392 L
.01769 .40163 L
.01842 .39833 L
.01975 .39024 L
.02113 .3792 L
.02241 .36692 L
.02532 .33393 L
.03062 .26823 L
.0354 .21703 L
.04057 .17662 L
.04358 .15956 L
.04635 .14729 L
.049 .13816 L
.0518 .13087 L
.05431 .12603 L
.05665 .12267 L
.05922 .11996 L
.06198 .11787 L
.06351 .11702 L
.06492 .11639 L
.06572 .11611 L
.06647 .11589 L
.06725 .11571 L
.06811 .11558 L
.06882 .11552 L
.06957 .11551 L
.07091 .11561 L
.07165 .11574 L
.07235 .11591 L
.07311 .11614 L
.07392 .11645 L
.07533 .11713 L
.07686 .11807 L
.07963 .1203 L
.08232 .12316 L
.08481 .12655 L
.08737 .13101 L
.08972 .13616 L
.09224 .14306 L
.09499 .15243 L
.09987 .17444 L
Mistroke
.10451 .20229 L
.11037 .24642 L
.11588 .2905 L
.11829 .30712 L
.12083 .32081 L
.12216 .32595 L
.12292 .32816 L
.12362 .32975 L
.12486 .33139 L
.12618 .33148 L
.12757 .32975 L
.12885 .32656 L
.12952 .32431 L
.13026 .3214 L
.13175 .31423 L
.13702 .27916 L
.14216 .23979 L
.14688 .20769 L
.15236 .17979 L
.15523 .16943 L
.15669 .1652 L
.15825 .16141 L
.15964 .15865 L
.16089 .15659 L
.16217 .15492 L
.16335 .15374 L
.16472 .15277 L
.16545 .15243 L
.16621 .15219 L
.1675 .15207 L
.16823 .15216 L
.16891 .15233 L
.17023 .15291 L
.1709 .15333 L
.17164 .15388 L
.17416 .15648 L
.17558 .15839 L
.1771 .16079 L
.17987 .16598 L
.19026 .1932 L
.19513 .20818 L
.20034 .22314 L
.20287 .22924 L
.20526 .23397 L
.20741 .2372 L
.20862 .23857 L
.20973 .23952 L
.21093 .2402 L
.21205 .24052 L
.21328 .24053 L
Mistroke
.21461 .24013 L
.21599 .23929 L
.2173 .2381 L
.21977 .23498 L
.22249 .23038 L
.22502 .22535 L
.23075 .21283 L
.23627 .20153 L
.24147 .1931 L
.24435 .18959 L
.24587 .18809 L
.24747 .18677 L
.24882 .18585 L
.2503 .18505 L
.25164 .18451 L
.2529 .18415 L
.25422 .18391 L
.25489 .18384 L
.25563 .1838 L
.25694 .18382 L
.25816 .18394 L
.25886 .18405 L
.2596 .18419 L
.26091 .18449 L
.26388 .18542 L
.26927 .18756 L
.27428 .18956 L
.2766 .19033 L
.27879 .19092 L
.28 .19116 L
.28131 .19136 L
.2825 .19148 L
.28359 .19154 L
.28481 .19154 L
.28595 .19147 L
.2872 .19134 L
.28854 .19113 L
.28994 .19083 L
.29127 .19047 L
.29377 .18964 L
.29908 .18726 L
.30388 .18459 L
.31463 .1782 L
.32403 .17363 L
.33395 .17007 L
.33899 .16874 L
.34451 .16742 L
.35422 .16509 L
.3601 .16381 L
.36567 .16262 L
Mistroke
.3681 .16213 L
.37067 .16169 L
.37201 .16152 L
.37272 .16144 L
.37349 .16138 L
.37484 .16132 L
.3761 .16132 L
.37746 .16139 L
.37872 .16153 L
.38011 .16176 L
.38089 .16193 L
.38159 .16212 L
.38289 .16253 L
.38429 .1631 L
.38549 .16371 L
.38682 .16453 L
.38931 .16658 L
.39066 .16805 L
.39193 .16969 L
.3942 .1734 L
.39664 .17865 L
.39946 .18678 L
.40254 .19858 L
.40544 .21313 L
.40813 .23006 L
.41322 .27226 L
.41862 .32912 L
.42341 .37896 L
.42581 .39848 L
.42718 .40676 L
.42845 .4123 L
.42917 .41443 L
.42985 .41575 L
.43112 .41635 L
.43249 .41425 L
.43327 .41184 L
.43398 .40884 L
.43515 .40241 L
.43644 .39333 L
.43905 .36976 L
.44376 .31741 L
.4489 .26116 L
.45375 .21859 L
.45824 .18944 L
.46095 .17594 L
.46341 .16591 L
.46605 .15714 L
.46891 .14965 L
.47393 .14023 L
.47865 .13397 L
Mistroke
.48421 .12842 L
.48701 .12628 L
.49008 .12441 L
.49552 .12193 L
.50059 .12007 L
.50192 .11967 L
.50333 .1193 L
.50453 .11904 L
.50586 .11884 L
.5066 .11877 L
.50728 .11873 L
.50803 .11872 L
.50881 .11874 L
.51014 .11887 L
.51089 .11898 L
.51158 .11912 L
.51294 .11947 L
.51422 .1199 L
.51662 .12098 L
.5192 .12262 L
.52065 .12383 L
.52199 .12517 L
.52432 .12817 L
.5265 .1319 L
.52889 .13726 L
.53146 .14475 L
.53415 .15479 L
.5367 .16671 L
.54148 .19659 L
.5516 .29352 L
.55426 .32154 L
.55714 .34779 L
.55846 .35749 L
.55986 .36562 L
.56105 .37064 L
.56235 .37393 L
.56355 .37483 L
.56465 .37384 L
.56591 .37059 L
.56711 .36554 L
.56821 .35928 L
.56923 .35228 L
.57153 .33282 L
.58168 .22848 L
.58657 .18908 L
.58932 .17219 L
.59184 .15972 L
.59417 .1504 L
.59671 .14238 L
.59912 .13662 L
Mistroke
.60135 .13266 L
.60271 .13084 L
.60418 .12932 L
.60486 .12877 L
.60557 .12828 L
.60685 .12762 L
.60808 .12724 L
.60923 .12709 L
.61048 .12714 L
.61183 .12743 L
.61258 .12769 L
.61327 .128 L
.61484 .12893 L
.61621 .13001 L
.61768 .13145 L
.62021 .13468 L
.62301 .13943 L
.62817 .15171 L
.63361 .16986 L
.64333 .2155 L
.64839 .24281 L
.65117 .25676 L
.65379 .2681 L
.65528 .27344 L
.65689 .27814 L
.65761 .27982 L
.65836 .28132 L
.65972 .28327 L
.66107 .28424 L
.66234 .28426 L
.66307 .28389 L
.66373 .2833 L
.6645 .28234 L
.66523 .28116 L
.66654 .2784 L
.66796 .27457 L
.67053 .26572 L
.67533 .24496 L
.68056 .22103 L
.68607 .19955 L
.69088 .18592 L
.6936 .18039 L
.69491 .17828 L
.69614 .17661 L
.69726 .17536 L
.69848 .17427 L
.69959 .17352 L
.70061 .17303 L
.70172 .17271 L
.70293 .17259 L
Mistroke
.7042 .17271 L
.70539 .17305 L
.7067 .17364 L
.70809 .17451 L
.7106 .17659 L
.71628 .18321 L
.72663 .19834 L
.72915 .20178 L
.73188 .20502 L
.73429 .20733 L
.7356 .20835 L
.73683 .20915 L
.73803 .20978 L
.73912 .21022 L
.74034 .21057 L
.74165 .21077 L
.74274 .21081 L
.74392 .21071 L
.74504 .2105 L
.74608 .21019 L
.74731 .20969 L
.74861 .20902 L
.75094 .20745 L
.75617 .20258 L
.76566 .19233 L
.77065 .18767 L
.77598 .18366 L
.77905 .18193 L
.78183 .18081 L
.78318 .18043 L
.78389 .18027 L
.78464 .18013 L
.78601 .17994 L
.78728 .17984 L
.78855 .1798 L
.78993 .17981 L
.79124 .17987 L
.79245 .17997 L
.79365 .18011 L
.79474 .18026 L
.79718 .18071 L
.79855 .18106 L
.79981 .18143 L
.80266 .18253 L
.80517 .18379 L
.80782 .18541 L
.81011 .18707 L
.81256 .18916 L
.81698 .19416 L
.81969 .19845 L
Mistroke
.82224 .20379 L
.82454 .20989 L
.82704 .21819 L
.83182 .23997 L
.83422 .25442 L
.83685 .27328 L
.84236 .32308 L
.84741 .37464 L
.85032 .40103 L
.85192 .41283 L
.8527 .41768 L
.85342 .42153 L
.85409 .42454 L
.85483 .42719 L
.85557 .42913 L
.85635 .43036 L
.85773 .43043 L
.85901 .4281 L
.85968 .42596 L
.86042 .42295 L
.86175 .41573 L
.86426 .39692 L
.86989 .33938 L
.87524 .28312 L
.88027 .24043 L
.88305 .22201 L
.88606 .20593 L
.88856 .19514 L
.89131 .18561 L
.89374 .17885 L
.89634 .1731 L
.89909 .16835 L
.90165 .16489 L
.90662 .15997 L
.91115 .15677 L
.91622 .15407 L
.9216 .15185 L
.93125 .14805 L
.94176 .14339 L
.94756 .14081 L
.95307 .1383 L
.95555 .13725 L
.95819 .1363 L
.95971 .13586 L
.96109 .13555 L
.96247 .13532 L
.96378 .13519 L
.96497 .13514 L
.96623 .13517 L
.9673 .13527 L
Mistroke
.96848 .13547 L
.96976 .13579 L
.97112 .13629 L
.9724 .13693 L
.97358 .13769 L
.97477 .13866 L
.97603 .13993 L
.9783 .143 L
.98075 .14763 L
.98344 .1547 L
.98576 .16273 L
.98826 .17375 L
.99279 .20131 L
.9963 .23076 L
1 .26963 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool002Wooooo1_l0001kooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`2`ooooo`00:Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08;ooooo1ol0
002]ooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07oooooo0_l00000
0ooooooo0000ooooo`04ooooo`03o`000?oooooooooo0:[ooooo000Wooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0OOooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool06?ooool3o`0008kooooo000Vooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0N_ooool2o`0000Cooooo0_l00006ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool00_l0002=ooooo`009_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo07Wo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2;ooooo`009Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1Xooooo`Ko00007?ooool002Gooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`1hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0IOooool2o`0000Kooooo00?o
0000ooooooooool06Oooool002Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1g
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0H_ooool3o`0000Wooooo00?o0000
ooooooooool06?ooool002Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1foooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Goooool2o`0000cooooo00?o0000oooo
ooooool06?ooool002Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1dooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0GOooool2o`0000oooooo00?o0000oooooooo
ool05oooool002Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Cooooo`?o0000
G_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05Wooooo0ol0000Aooooo`03o`00
0?oooooooooo01Oooooo000Tooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04_oo
ool2o`000003ooooool0003ooooo05cooooo00?o0000ooooooooool02?ooool2o`0000Wooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05Sooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Fooooo`009?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo01;ooooo00Co0000oooooooooooooooo0_l0001Kooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0E_ooool2o`0001Kooooo00?o0000ooooooooool05_oo
ool002Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0>_ooool6o`0001Wooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`1Eooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05Oooool0
01Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP04ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool00_ooool01OnHV9So410@o`000?lb<S;oc<c<00?o
oooo00Ook^k^oc8b<_l0003o<S8bonk^k_oooooo000000Gooooo00?o0000ooooooooool04Oooool5
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Fooooo`[o000000So410@o`000?l0003ok^k^
oc8b<_l0003o<S8bonk^kQ;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool4o`000004oa0@4?oooooooooo
onk^kP;o000000?o<S8bonk^k_ooool06Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0Kooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo00?o0000ooooooooool05oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb
<S;ok^k^00kooooo000Fooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`04ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool01Ol@413o^[Zjoooo
oomgMgOo<S8b00?ooooo00OoMgMgoiRHV?ooooooV9RHogMgMooooooo000000Kooooo00?o0000oooo
ooooool04?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Booooo`Co00002?ooool00ol0003oooooooooo`02ooooo`05o`000?nHV9SooooooiRHV?mgMgL0
4_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00GoMgMgo`000?oooooo
V9RHogMgM`0Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9So
MgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0>ooooo`002oooool6o`0000;ooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@
41000oooool00ol0003oooooooooo`0<ooooo`Ko00001_ooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@o`000?ooool01_ooool00ol0003oooooooooo`08ooooo`Ko00000oooool00onH
V9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41004?ooool2o`000003ooooool0003o
000000Co00001Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool@41004_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Go410@o`000?oooooooooo
oa0@400Kooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400Oooooo`05
o`000?ooooooooooooooool@41000oooool01?l@413oooooooooool0000Hooooo`Go00000oooool0
1Ol@413ooooooooooooooooo410@00kooooo000Cooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
1Oooool00onYZJWo410@ooooo`02ooooo`04o`000?ooooooooooooooo`;o00002?ooool00ol0003o
ooooooooo`0Aooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000=oooo
o`?o00003_ooool00ol0003oooooooooo`02ooooo`;o00000_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool2o`0000;ooooo00?o0000oooo
ooooool03oooool4o`0000Oooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo
000001kooooo00?oZJVYoa0@4?ooool00_ooool01ol0003ooooooooooooooooo0000ooooool00000
6Oooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool001?o
oooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`04ooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000
ooooooooooooooooo`000009ooooo`03o`000?oooooooooo01;ooooo00?oMgMgofIVI_ooool00_oo
ool01Ol0003ooooooooooooooooo000000[ooooo0ol0000Aooooo`03o`000?oooooooooo00;ooooo
0_l00002ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`02ooooo`;o00000_ooool00ol0003oooooooooo`0>ooooo`;o00000oooool00ol0003ooooo
ooooo`05ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03
oa0@4?l0003o^[Zj00?ooooo00Oo0000ooooooooooooooooo`000?oooooo000001Wooooo00CogMgM
oeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000kooooo000Dooooo`03ogMgMoo<
c<co000000Cooooo00Go410@oooooooooooooooooa0@4003ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool01Oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool0
00002Oooool00ol0003oooooooooo`0Cooooo`05o`000?ooooooooooooooool@41000oooool00ol@
413oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00_ooool01Ol@
413oooooo`000?oooooo410@017ooooo00?o0000ooooooooool02_ooool2o`0000[ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Go410@
ooooool0003ooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Ooo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool00oooool6o`0001?ooooo
00?o^[Zjob4Q8Oooool00_ooool01_l@413ooooooooooooooooo410@o`0001_ooooo00?oMgMgolc<
c?l000001?ooool01Ol@413ooooooooooooooooo410@00kooooo000Dooooo`03onk^k_m4A4Co0000
00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03o`000?oooooooooo013ooooo00Wo0000
oooooooooooooooooa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9So0000
00[ooooo00?o0000ooooooooool03_ooool01?l0003o^[ZjoooooonHV9P4o`000005ogMgMonHV9So
oooooiRHV?mgMgL02?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?l0003oV9RHogMgM`0Aooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHo`000?nHV9SoMgMg013ooooo00?o0000ooooooooool01?ooool02?l0003o
ooooooooool0003o^[ZjoooooonHV9So410@0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo
0ol00005ooooo`?o00003_ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00KoMgMgoiRHV?oo
ooooV9RHogMgMol0000Kooooo`04onk^k_m4A4Co0000o`0000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0>ooooo`005Oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool00ol0003oooooooooo`0@ooooo`09o`000?oooooooooooooooonYZJWo410@o`000?l@413o
ZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bo`00000:ooooo`03o`000?oooooooooo00kooooo00Go
V9RHoa0@4?l0003o0000olc<c003ooooo`?o000000?o<S8bonk^k_ooool01?ooool3o`0001Cooooo
00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?l0003ok^k^017ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool01?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03oooool00ol0
003oooooooooo`05ooooo`08o`000?oooooooooooiRHV?l@413o0000ob4Q8Oo<c<`3ooooo`07onk^
k_lb<S;o0000oc8b<_o^k^koooooo`00000;ooooo`;o00003?ooool01OnYZJWo410@o`000?l@413o
ZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bo`00000Mooooo`03ogMgMol0003o000000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0>ooooo`008_ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0?ooooo`;o00002?oo
ool2o`0000?ooooo0_l0000Qooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0Dooooo`008_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00Sooooo1Ol0000Rooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Dooooo`008_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
01Cooooo000Rooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool04oooool002;ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Cooooo`005_ooooooo`00043o00004ooo
ool001Kooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`;o00001Oooool00ol0003ooooooooo
o`04ooooo`;o00001oooool00ol0003oooooooooo`04ooooo`;o00001oooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
o`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool0
0ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00Co0000ooooool0003o00000ooo
ool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`;o00001ooo
ool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooo000001?ooooo000Fooooo`03o`000?oooooooooo00Gooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
0_l00005ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00Cooooo
0_l00007ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool00ol0
003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0
003oooooo`000007ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Oooool01?l0
003oooooooooooooool4o`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooo`00000Cooooo`008Oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool04oooool0
027ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
01;ooooo000Qooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`0Booooo`008Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool04_ooool0027ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo01;ooooo000Qooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`0Booooo`008?ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo03Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`;o00003?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`0Booooo`008?ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool01Ol0003ooooooooooooooooo0000
03_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool04_ooool0023ooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo01;ooooo1?l0000looooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01;o
oooo000Pooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`1Booooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo01;ooooo000Pooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01;ooooo000P
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1B
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo01;ooooo000Pooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo017ooooo000Pooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Dooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo017ooooo000Oooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
3Oooool2o`0000gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool04Oooool001oooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool04Ooo
ool001oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo05Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool04Oooool001oooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool04Oooool001Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Go
oooo00Go0000ooooooooooooooooo`00000eooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0Aooooo`005_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Eooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool05Oooool01Ol0003ooooooooooooooooo0000
03Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0iooooo`005_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`1Eooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05_ooool01?l0003o
ooooooooool0000eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>Oooool001Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooool00000=_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Wo
oooo000Fooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0>ooooo`;o00003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Sooooo
0_l0000fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>Oooool001Kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0EOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo053ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0iooooo`005_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1F
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo03Wooooo000Fooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0>Oooool001Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo057ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0iooooo`00
5_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
DOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Wooooo000Gooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo05Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`Go00001_oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0DOoo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Wooooo000Gooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo05Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0DOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Wooooo000G
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0000>ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0DOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Wooooo000Goooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo05Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo057ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0ioooo
o`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01oooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0>_ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Kooooo`05o`00
0?ooooooooooooooool00000F_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03[o
oooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06oooool01?l0003ooooo
ooooool0001Kooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool01Ol0003o
^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo05?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0joooo
o`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooo
oooo0000Foooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1Cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0>_ooool0
01Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo0000
05_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0>_ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Looooo`;o0000G?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05?o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0jooooo`005oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0@ooooo`;o00003oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05?ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0jooooo`005oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`1Cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0>_ooool001Oooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0Doooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03[ooooo000Hoooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo05?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0joooo
o`006?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07[ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00Go0000oooooooo
ooooooooo`00001Fooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0>_ooool001So
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`05o`000?oooooooooooooo
ool00000E_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03[ooooo000Hooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool01Ol0003ooooooooooooooooo0000
05Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0jooooo`006?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00Go0000ooooooooooooooooo`00001Goooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0>oooool001Sooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0?ooooo`05o`000?ooooooooooooooool00000Eoooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo03_ooooo000Hooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo017o
oooo0_l0000@ooooo`05o`000?ooooooooooooooool00000Eoooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo03_ooooo000Hooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0O?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooo`00001Hooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0>oooool001Wooooo00Go0000ooooooooooooooooo`00001nooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo000005So
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0kooooo`006Oooool01Ol0003ooooo
oooooooooooo000007kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo013ooooo00?o0000ooooool00000F?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo03_ooooo000Iooooo`04o`000?ooooooooooo`0007oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0Eoooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03_ooooo000Iooooo`04o`00
0?ooooooooooo`0007oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo06_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0kooooo`00
6Oooool01?l0003oooooooooool0001oooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0>oooool001Wooooo00Co0000oooooooooooo0000Ooooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo03cooooo000Iooooo`04o`000?ooooooooooo`0007oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Aooooo`;o0000K?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo03cooooo000Iooooo`04o`000?ooooooooooo`00083ooooo00Go0000oooooooo
ooooooooo`00000Cooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0looooo`006_ooool00ol0003oooooo`000020ooooo`05o`000?oooooooooooooo
ool000004oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0??ooool001[ooooo00?o0000ooooool00000P?ooool01Ol0003ooooooooooooooooo0000
01?ooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
03cooooo000Jooooo`03o`000?oooooo0000083ooooo00Co0000oooooooooooo00005?ooool00ol0
003oooooooooo`1/ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0??ooool001[o
oooo0_l00021ooooo`04o`000?ooooooooooo`0000_ooooo0_l000000ol@413oooooooooo`04oooo
o`03o`000?oooooooooo06cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0loooo
o`006_ooool2o`0008;ooooo00?o0000ooooool000003?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo06cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0looooo`00
W_ooool00ol0003oooooo`000009ooooo`Go00001_ooool00ol0003oooooooooo`1]ooooo`04o`00
0?ooooooooooo`0003oooooo002Nooooo`03o`000?oooooo000000Wooooo00CoA4A4omgMgOoooooo
00001oooool3o`0006gooooo00Co0000oooooooooooo0000?oooool009kooooo0_l0000:ooooo`04
omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0KOooool01?l0003oooooooooool0000o
ooooo`00Zoooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo06gooooo00Co0000oooo
oooooooo0000?oooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`1]oooo
o`04o`000?ooooooooooo`0003oooooo002/ooooo`03ogMgMol0003ooooo00Kooooo00?o0000oooo
ooooool0K_ooool2o`00043ooooo002eooooo`03o`000?oooooooooo06kooooo0_l00010ooooo`00
]Oooool00ol0003oooooooooo`1^ooooo`;o0000@?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo00Gok^k^oc8b<_l0003o410@olc<c006oooo
o`03o`000?oooooooooo0;3ooooo002Zooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0
003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool0/?ooool00:[ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000/?ooool00:[o
oooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03
oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0/?ooool00:[ooooo00?ogMgMoa0@4?nHV9P0
2?ooool00ol0003oooooooooo`2`ooooo`00Zoooool01?o<c<coA4A4o`000?l@4106ooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002Zooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_oo
ool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05oc8b<_nH
V9SooooooiRHV?lb<S801_ooool3o`000;3ooooo002Zooooo`05olc<c?l0003o0000o`000?o<c<`0
^Oooool00:[ooooo00Go410@okZj^_oooooo^[Zjoa0@402iooooo`00Z_ooool01Ol0003o^[Zjoooo
oonj^[[o00000;Wooooo002Zooooo`05ojVYZOl@413o0000oa0@4?nYZJT0^Oooool00?ooooooJOoo
ool00:oooooo00?o0000okZj^_ooool0]_ooool00:oooooo0_lb<S:gooooo`00P?ooool2o`000006
oa0@4?oooooooooooa0@4?l0003o410@6?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003o
A4A4okZj^P0Iooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Go
k^k^oc8b<_l0003o410@olc<c01hooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Oooooo1_l0000=ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40N?ooool0087ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Kooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool04?ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05
o`000?ooooooooooooooool00000N?ooool0087ooooo00Ko0000oooooom4A4CoA4A4ooooool00009
ooooo`Ko00003Oooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0;ooooo`Ko00003?ooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003oV9RHoooooonHV9So8B4Q07Sooooo0021ooooo`06o`00
0?oMgMgo<S8boeEEEOoMgMgo00006Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000
ooooooooooooooooo`00000Booooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oeEEEOl0003o410@olc<c01hooooo`00
POooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001Wooooo00?o0000ooooooooool01?ooool01Ol@
413ooooooooooooooooo410@013ooooo00?o410@o`000?l000000ol0000Looooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oeEEEOn7QhOooooo07[ooooo0021
ooooo`06o`000?lb<S;ooooooooooolb<S;o00006Oooool00ol0003oooooooooo`04ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL04_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03omgMgOl@413oV9RH07[ooooo0020ooooo`03
oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool4o`0000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0Booooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Cooooo00Coc<c<odA4A?l0003o410@N?ooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(108) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .24234 m
.00488 .30296 L
.00942 .36071 L
.01077 .37544 L
.01204 .38756 L
.01319 .39673 L
.01441 .40423 L
.01574 .40953 L
.01697 .4116 L
.01829 .4107 L
.01904 .40876 L
.01975 .40602 L
.02103 .39884 L
.02243 .38805 L
.02499 .36197 L
.02978 .30114 L
.03533 .23397 L
.04057 .18753 L
.04336 .16959 L
.04639 .15463 L
.04914 .14444 L
.05167 .13753 L
.05309 .13458 L
.05442 .13236 L
.05587 .13046 L
.05743 .12897 L
.05821 .12841 L
.05906 .12793 L
.05987 .12758 L
.06061 .12735 L
.06128 .12722 L
.06202 .12714 L
.06279 .12713 L
.06351 .12719 L
.06475 .12744 L
.06611 .12794 L
.0668 .12828 L
.06753 .12871 L
.06886 .12968 L
.07143 .13232 L
.07376 .13565 L
.07649 .14076 L
.07944 .1478 L
.08481 .16473 L
.09467 .21271 L
.10011 .24708 L
.10527 .27861 L
.10818 .29306 L
.10971 .29914 L
.11055 .30194 L
Mistroke
.11134 .3042 L
.11207 .30594 L
.11286 .30745 L
.11422 .30913 L
.1149 .30951 L
.11562 .30957 L
.1169 .30885 L
.11819 .30703 L
.11958 .30394 L
.12089 .30002 L
.12208 .2957 L
.12777 .2684 L
.13272 .24224 L
.13796 .21856 L
.1407 .2088 L
.14372 .20027 L
.14504 .19726 L
.14646 .19453 L
.14779 .19243 L
.14903 .19088 L
.15022 .18974 L
.15148 .18889 L
.1522 .18856 L
.15288 .18836 L
.15415 .18822 L
.1555 .1884 L
.15674 .18884 L
.1581 .18958 L
.15953 .19063 L
.16411 .19531 L
.16915 .20211 L
.17418 .20975 L
.17683 .21367 L
.17965 .21739 L
.18211 .22008 L
.18341 .22127 L
.18482 .22236 L
.18611 .22318 L
.18729 .22379 L
.18842 .22425 L
.18961 .2246 L
.19098 .22486 L
.19175 .22493 L
.19244 .22495 L
.1938 .22488 L
.19509 .22466 L
.19581 .22448 L
.19658 .22423 L
.19796 .22367 L
.19945 .2229 L
Mistroke
.20108 .22187 L
.21156 .21303 L
.21656 .20914 L
.22202 .20546 L
.22451 .20398 L
.22717 .20261 L
.22947 .20163 L
.23195 .20079 L
.23505 .20001 L
.23796 .19941 L
.24341 .19821 L
.25388 .19588 L
.26387 .19294 L
.27483 .18875 L
.29696 .17943 L
.33942 .16354 L
.35901 .15538 L
.3803 .14398 L
.3832 .14233 L
.38592 .14096 L
.3874 .14036 L
.38876 .13992 L
.39027 .13955 L
.39106 .13941 L
.39189 .1393 L
.39318 .13921 L
.39455 .1392 L
.39584 .13928 L
.39701 .13944 L
.3984 .13975 L
.39918 .13999 L
.3999 .14027 L
.40122 .14094 L
.40262 .14193 L
.40393 .14317 L
.40512 .14464 L
.40641 .14663 L
.40782 .14933 L
.41031 .15571 L
.41268 .16391 L
.41546 .17665 L
.41842 .19461 L
.42122 .21667 L
.42375 .24164 L
.43361 .37423 L
.43601 .40435 L
.43733 .41802 L
.43857 .42844 L
.43928 .43313 L
.44005 .43713 L
Mistroke
.44139 .44125 L
.44275 .44155 L
.44401 .43833 L
.44537 .43121 L
.44665 .42137 L
.44955 .38953 L
.45542 .3053 L
.46085 .23377 L
.46589 .18625 L
.46841 .16899 L
.4711 .15438 L
.47408 .14191 L
.47678 .13339 L
.47935 .12733 L
.48212 .12255 L
.48473 .11929 L
.48714 .11707 L
.48947 .11542 L
.49165 .11422 L
.49404 .11325 L
.49538 .11285 L
.4966 .11259 L
.49787 .11242 L
.49905 .11236 L
.50035 .1124 L
.50173 .11255 L
.50292 .11278 L
.50404 .11307 L
.50659 .11399 L
.50914 .11528 L
.51152 .11685 L
.51412 .11912 L
.51691 .12237 L
.51983 .127 L
.5226 .13282 L
.52508 .13949 L
.52777 .14856 L
.53268 .17109 L
.53515 .18598 L
.53788 .20547 L
.5472 .29272 L
.54982 .31808 L
.55267 .34184 L
.55397 .35055 L
.55536 .35792 L
.55667 .36286 L
.55786 .36552 L
.55912 .36636 L
.56028 .36533 L
.56154 .36226 L
Mistroke
.56288 .35692 L
.56405 .35066 L
.56514 .34361 L
.56761 .32412 L
.57301 .27327 L
.57888 .22216 L
.58157 .2035 L
.58442 .18737 L
.58686 .17643 L
.58954 .16713 L
.5909 .16347 L
.59232 .1603 L
.59355 .15809 L
.59486 .15624 L
.5956 .15542 L
.59628 .15481 L
.5976 .15397 L
.59834 .15369 L
.59914 .15353 L
.59989 .15352 L
.60059 .15362 L
.60183 .15406 L
.60298 .15474 L
.60426 .15578 L
.60562 .15721 L
.6084 .16114 L
.61094 .16585 L
.61573 .17756 L
.62095 .19391 L
.63044 .22814 L
.63517 .24373 L
.63766 .25047 L
.64029 .256 L
.64168 .25818 L
.64242 .25911 L
.64321 .25992 L
.64394 .26049 L
.6446 .26088 L
.64589 .26125 L
.64719 .26113 L
.64793 .26084 L
.64861 .26044 L
.64985 .25939 L
.65117 .25787 L
.65378 .25374 L
.65658 .24802 L
.66166 .23584 L
.66765 .2215 L
.67057 .2155 L
.67321 .21092 L
Mistroke
.67568 .20742 L
.67835 .2045 L
.67982 .20325 L
.68117 .20232 L
.68246 .20161 L
.68383 .20105 L
.68521 .20066 L
.68598 .20052 L
.68668 .20043 L
.68805 .20038 L
.68935 .20046 L
.69008 .20056 L
.69086 .20069 L
.69225 .20102 L
.69541 .20207 L
.70024 .20403 L
.70277 .20501 L
.70544 .2059 L
.70686 .20629 L
.70842 .20664 L
.7091 .20677 L
.70983 .20689 L
.71115 .20704 L
.71184 .2071 L
.71259 .20713 L
.71396 .20713 L
.71528 .20705 L
.71651 .2069 L
.71782 .20666 L
.71907 .20636 L
.72142 .20562 L
.72669 .20328 L
.73621 .19818 L
.74124 .19558 L
.74658 .19325 L
.75245 .19143 L
.75789 .19021 L
.76872 .18803 L
.77169 .18739 L
.77482 .18658 L
.78042 .1846 L
.79065 .17987 L
.80161 .174 L
.80717 .17127 L
.81243 .16928 L
.81715 .16785 L
.81844 .16752 L
.81982 .16721 L
.8211 .16698 L
.82228 .16683 L
Mistroke
.82345 .16674 L
.82456 .16671 L
.82573 .16676 L
.82701 .16691 L
.82812 .16711 L
.82931 .16741 L
.83144 .16816 L
.83275 .16876 L
.83417 .16954 L
.83674 .17138 L
.83924 .17387 L
.84154 .177 L
.84412 .18179 L
.84647 .18765 L
.84918 .19654 L
.85175 .20746 L
.85632 .23421 L
.8589 .25437 L
.86129 .2767 L
.86667 .3384 L
.8695 .37367 L
.87248 .4079 L
.87374 .42027 L
.87509 .43141 L
.87587 .43668 L
.87657 .44068 L
.87795 .44614 L
.87919 .44823 L
.88054 .4474 L
.88181 .44365 L
.88298 .43775 L
.88411 .43003 L
.88532 .4197 L
.88751 .3967 L
.89249 .33321 L
.89731 .27347 L
.90256 .22256 L
.90557 .20072 L
.90835 .18444 L
.91124 .17093 L
.91386 .16114 L
.91886 .14749 L
.9216 .14209 L
.92418 .13792 L
.92908 .13162 L
.93445 .12636 L
.94006 .12237 L
.94529 .11963 L
.9501 .1176 L
.95247 .11677 L
Mistroke
.95466 .11612 L
.95585 .11583 L
.95717 .11557 L
.9585 .11536 L
.95923 .11528 L
.95991 .11523 L
.96111 .11518 L
.96221 .11519 L
.96342 .11527 L
.96469 .11543 L
.96584 .11564 L
.96708 .11594 L
.96817 .11629 L
.96933 .11673 L
.97152 .11782 L
.97354 .11921 L
.97587 .12139 L
.97804 .12416 L
.98043 .12823 L
.98299 .1341 L
.98517 .14059 L
.98755 .1495 L
.98965 .15922 L
.99188 .1718 L
.9961 .20316 L
1 .24233 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo1ol0002>ooooo`?o0000
7_ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c002ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`28ooooo`?o00000_ooool3o`0001cooooo002`ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000028ooooo`;o00002?ooool00ol0003o
ooooooooo`0Iooooo`00[oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0Poooool2o`0000_ooooo00?o0000ooooooooool06?ooool002Sooooo1?l0
0022ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`21ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06?ooool002Oooooo0_l00002
ooooo`;o0000POooool00ol0003oooooooooo`04ooooo`;o00001?ooool00ol0003oooooooooo`20
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05oooool002Oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool05_ooool002Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1mooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1nooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool05_ooool002Kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1Qooooo`Go00005oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo01Kooooo000Vooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Gooo
ool2o`0000?ooooo0_l0000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05_oo
ool002Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Mooooo`;o00001oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`1jooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05_ooool0
02Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Iooooo`?o00002_ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`1iooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05Oooool002Co
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Gooooo`;o00003Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1iooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05Oooool002Cooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Dooooo`;o00003oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo00Kooooo0_l00007ooooo`03o`000?oooooooooo01;ooooo
1?l0001Sooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05?ooool002Cooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`1Booooo`;o00004Oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Booooo`05o`000?ooooooooooooooool00000HOooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo01Cooooo000Tooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0D?oo
ool2o`0001Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo05oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Dooooo`005Oooool2
o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`06ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^01_ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_oo
ool2o`0000Sooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^6_ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05
oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00?o0000
ooooooooool04oooool3o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`005_ooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00Kooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL06oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0?ooooo`?o00003?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo0_l0
0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01OnHV9So8B4Qonk^k_ooooooA4A400?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0?ooooo`Oo00001Oooool01Ol@413o^[ZjoooooomgMgOo
<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo01Gooooo0_l0
0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool000_ooooo1_l00002ooooo`Go00000ooo
ool01Ol@413ooooooooooooooooo410@00?ooooo00?o0000ooooooooool02oooool7o`0000Kooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo017ooooo1_l00003ooooo`03
oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400<ooooo`?o00001?ooool6o`00
00Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00;ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`04ooooo`;o00001?ooool01Ol@413ooooooooooooo
oooo410@01_ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00cooooo
0ol00006ooooo`;o00002?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@oooooooo
ool01?ooool00ol0003oooooooooo`0Booooo`Go00000oooool01Ol@413ooooooooooooooooo410@
00kooooo000Cooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02?ooool00onYZJWo410@ooooo`02
ooooo`05o`000?ooooooooooooooool000007Oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oo
ooooooooooooool000002Oooool3o`0001;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Looooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`00000:ooooo`;o00002oooool00ol0003oooooooooo`04
ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo01;ooooo00?oA4A4omgMgOooool00_l00003ooooo`05o`000?ooooooooooooooool00000
3_ooool001?ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`03oa0@4?l0003o^[Zj00?o
oooo00Go0000ooooooooooooooooo`00000Nooooo`03ogMgMomVIVKooooo00;ooooo00Go0000oooo
ooooooooooooo`000006ooooo`?o00005Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo0_l0
0003ooooo`05o`000?ooooooooooooooool000007Oooool00omgMgOoIVIVooooo`02ooooo`05o`00
0?ooooooooooooooool000002?ooool2o`0000kooooo00?o0000ooooooooool00_ooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Boooo
o`03omgMgOmEEEGooooo00;o00000oooool01Ol0003ooooooooooooooooo000000kooooo000Doooo
o`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@4003ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02?ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41007oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0
0_ooool2o`0001Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`08ooooo`;o00002Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo0_l00003ooooo`05oa0@4?oooooooooooooo
ool@41007_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01?ooool2
o`00013ooooo00?o0000ooooooooool00oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41001Oooool00ol0003oooooooooo`0Dooooo`05ogMgMoo<c<co0000ooooool00000
0_ooool01Ol@413ooooooooooooooooo410@00kooooo000Dooooo`03onk^k_m4A4Co000000Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool01Oooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0K
ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01_mgMgOoV9RHoooooonHV9SoMgMgooooo`?o
00006_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00Kooooo0_l00003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL06_ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`03o`000?oooooooooo013ooooo00So0000oooooooooooo410@oiRHV?oooooo^[Zj
o`0000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo01Cooooo00Go
k^k^odA4A?l0003oooooo`000002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool001Gooooo
00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`05ooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`04onk^k_lb
<S;o0000oc8b<P;o00006oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00GoEEEEofIVI_l0
003oooooo`000002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06_ooool01OnHV9So410@o`000?lQ
8B7oc<c<00?ooooo00Kok^k^oc8b<_l0003o<S8bonk^k_ooool4o`0001Cooooo00Oo0000oooooonY
ZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oo
oooooooo01Gooooo00CoMgMgo`000?oooooo00000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00ko
oooo000Sooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04?ooool3o`0002?ooooo
0_l0000]ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Xooooo`Go00006?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool04oooool002?ooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0?ooooo`05o`000?ooooooooooooooool000007oooool3o`0002oooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Gooooo0ol0000Nooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Cooooo`008ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Hooooo`Co0000<_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool08oooool2o`00027ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01;ooooo000Sooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01?ooooo1?l0000fooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Qooooo`;o00008oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool04_ooool002;ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03oooool3o`00
03[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00oooooo1ol00007ooooo`?o00009Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool04_ooool001Koooooool00010o`0001?ooooo000Fooooo`03o`00
0?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool00ol0003oooooo`000006ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`;o00001oooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooo000000Gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000?o00000_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01?ooool2o`0001?ooooo000Fooooo`03o`000?oooooooooo00Gooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooo`000006ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`;o00001oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l00007
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l0000C
ooooo`008_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`07ooooo`;o0000@_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Boooo
o`008_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04;ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool04_ooool002;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`13ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo01;ooooo000Qooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0<ooooo`Go0000A_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Aooooo`008Oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0F?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0jooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Aooooo`008Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Aooooo`008Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0FOooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00[ooooo0_l0000;ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03[o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo017o
oooo000Qooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`1Iooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo017ooooo000Qooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo017ooooo000F
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool04Oooool001Kooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0F_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0<Oooool001Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0mooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool0<Oooool001Kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
Foooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
<Oooool001Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo01;ooooo00Go0000ooooooooooooooooo`000010ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0<Oooool001Kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Foooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00[ooooo0_l0000<ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool04_ooool01?l0003oooooooooool00011ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0<Oooool001Kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Foooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo01;ooooo0ol00012ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0<Oooool001Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0b
ooooo`005_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0FOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03;ooooo000Fooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo05gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Iooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0<_ooool001Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
GOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0booooo`005oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Mooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo03;ooooo000Gooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0<_ooool0
01Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00_ooooo0_l0000=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0FOooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo03;ooooo000Gooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0<_ooool001Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0G_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0booooo`005oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0F_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03;ooooo000G
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1K
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<_ooool001Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Gooooo`04o`000?ooooooooooo`00067ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0<_ooool001Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Goooo
o`04o`000?ooooooooooo`00067ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
o`0000Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo05_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0booooo`005oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo01Oooooo00Co0000oooooooooooo0000HOooool0
0ol0003oooooooooo`06ooooo`08o`000?oooooooooooiRHV?lQ8B7ok^k^oooooom4A4@6ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Kooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0<oooool001Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Hooooo`;o0000H_ooool00ol0003oooooooooo`06ooooo`07o`00
0?oooooooooooooooonHV9So8B4Qonk^kP07ooooo`?o00003Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo05_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0coooo
o`005oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`02ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05_ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0cooooo`005oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo07gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03ogMg
MomVIVKooooo00Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo05cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0cooooo`005ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0cooooo`006?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo07gooooo00?o0000ooooooooool01Oooool02?l0003oooooooooool0003o^[ZjoooooonHV9So
410@1_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0G?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03?ooooo000Hooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`05ooooo`08o`00
0?oooooooooooiRHV?l@413o0000ob4Q8Oo<c<`6ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0<oooool001Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1moooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo03?ooooo000Hooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0OOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0cooooo`006?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo07kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`;o0000
3oooool01Ol0003ooooooooooooooooo000005oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0cooooo`006?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00kooooo
00Go0000ooooooooooooooooo`00001Oooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0<oooool001Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1nooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0>ooooo`05o`00
0?ooooooooooooooool00000Goooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03?o
oooo000Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0O_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03_ooool01Ol0003ooooo
oooooooooooo000005oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0cooooo`00
6?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00kooooo00Go0000oooooooooooo
ooooo`00001Oooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<oooool001Wooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0>ooooo`04o`000?ooooooooooo`00063o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0cooooo`006Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo0000H?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo03Cooooo000Iooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0Ooooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03oooool00ol0003oooooo`00001Pooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0=?ooool001Wooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`1oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooo0000067ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0dooooo`006Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07oooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0<ooooo`;o00004?ooool2o`0006;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0dooooo`006Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo07oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00oooooo0_l0001Rooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0=?ooool001Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1oooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1cooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0=?ooool001Wooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
=?ooool001Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1oooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1cooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0=?ooool001Wooooo00Go0000ooooooooooooooooo`00
0022ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`1cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0=?ooool001Wooooo00Go0000
ooooooooooooooooo`000022ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0=?oo
ool001[ooooo00Co0000oooooooooooo0000P_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo03Gooooo000Jooooo`04o`000?ooooooooooo`0008;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0=ooooo`;o0000M?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo03Gooooo000Jooooo`04o`000?ooooooooooo`0008?ooooo00Go0000oooooooooooooooo
o`00000?ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0eooooo`006_ooool01?l0003oooooooooool00023ooooo`05o`000?ooooooooooooooool0
00003oooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0=Oooool001[ooooo00?o0000ooooool00000Q?ooool01Ol0003ooooooooooooooooo000000oo
oooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Go
oooo000Jooooo`03o`000?oooooo000008Cooooo00Go0000ooooooooooooooooo`00000?ooooo`03
o`000?oooooooooo07?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0eooooo`00
6_ooool00ol0003oooooo`000024ooooo`05o`000?ooooooooooooooool000001_ooool2o`000003
oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo03Gooooo000Jooooo`03o`000?oooooo000008Cooooo00Go0000oooooooooooo
ooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Loooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo03Gooooo000Kooooo`;o0000Q?ooool01?l0003ooooo
ooooool00005ooooo`Go00001_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0=Oooool001_ooooo0_l00024ooooo`04o`000?ooooooooooo`0000Go
oooo00CoA4A4omgMgOoooooo00001oooool3o`0007?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0eooooo`00XOooool01?l0003oooooooooool00005ooooo`04omgMgOmEEEGooooo
o`0000Oooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo03Gooooo002Qooooo`04o`000?ooooooooooo`0000Kooooo00?oMgMgolc<c?l000001oooool0
0ol0003oooooooooo`1dooooo`05o`000?ooooooooooooooool00000=oooool00:7ooooo00Co0000
oooooooooooo00001_ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo07Cooooo00Go
0000ooooooooooooooooo`00000gooooo`00XOooool01?l0003oooooooooool00007ooooo`03ogMg
Mol0003ooooo00Kooooo00?o0000ooooooooool0M?ooool01Ol0003ooooooooooooooooo000003Oo
oooo002Qooooo`03o`000?oooooo0000017ooooo00?o0000ooooooooool0M?ooool01?l0003ooooo
ooooool0000hooooo`00XOooool00ol0003oooooo`00000Aooooo`03o`000?oooooooooo07Cooooo
00Co0000oooooooooooo0000>?ooool00:;ooooo0_l0000Aooooo`03o`000?oooooooooo07Cooooo
00Co0000oooooooooooo0000>?ooool00:;ooooo0_l0000Aooooo`;o0000M_ooool00ol0003ooooo
o`00000hooooo`00X_ooool2o`00017ooooo00?o0000ooooooooool0MOooool00ol0003oooooo`00
000hooooo`00]Oooool00ol0003oooooooooo`1eooooo`;o0000>Oooool00;Gooooo00?o0000oooo
ooooool0MOooool2o`0003Wooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0/?oo
ool00:[ooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Z
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool0
1Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0002`ooooo`00Z_ooool01Ol0003oEEEEo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00?oEEEEohN7Qoooool02?ooool0
0ol0003oooooooooo`2`ooooo`00Z_ooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo
0;3ooooo002[ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo00Goc<c<ob4Q8Ol0
003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05ob4Q8OnHV9SooooooiRH
V?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06oooo
o`?o0000/?ooool00:[ooooo00Goc<c<o`000?l0003o0000olc<c02iooooo`00Z_ooool01Ol@413o
^[Zjoooooonj^[[o410@0;Wooooo002Zooooo`05o`000?nj^[[ooooookZj^_l00000^Oooool00:[o
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@2iooooo`00oooooomYooooo`00[oooool00ol0003o^[Zj
ooooo`2fooooo`00[oooool2oc8b<[Oooooo0020ooooo`;o000000Ko410@oooooooooooo410@o`00
0?l@410Hooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Wooooo1?l00000
2?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<
07Sooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`0000go
oooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL00oooool00oo<c<co0000oa0@
400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000cooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@1hoooo
o`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooo
oooo410@0oooool00ol@413oooooooooo`0@ooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go0000ooooooooooooooooo`00
001hooooo`00POooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000=ooooo`05ogMg
Molb<S;oooooooooool000000oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_o
oooo1_l0000<ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003oooo
o`05oc8b<_nHV9SooooooiRHV?lb<S80N?ooool0087ooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0
000Iooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000001;o
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000000oooool01Oo<c<co0000o`000?l0003oc<c<07Sooooo0021ooooo`06o`000?n7QhOoZJVY
okZj^_mEEEGo00006Oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100
4?ooool00ol@413o0000o`000003o`0001cooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@00?ooooo00Go410@okZj^_oooooo^[Zjoa0@401hooooo`00POooool01_l0003o
<S8boooooooooooo<S8bo`0001Wooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg01;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01Ol0003o^[Zjoooooonj^[[o000007Sooooo0020ooooo`03oa0@
4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0Booooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@1hooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(110) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .22836 m
.00488 .28093 L
.00942 .33413 L
.01199 .36114 L
.01441 .38144 L
.01575 .38964 L
.01651 .39317 L
.01721 .39567 L
.01844 .39824 L
.01975 .39833 L
.02104 .39578 L
.02221 .39123 L
.02357 .38354 L
.02486 .37407 L
.02966 .32641 L
.03538 .26357 L
.04057 .21795 L
.0433 .2 L
.04588 .18669 L
.0486 .17605 L
.05013 .17146 L
.05154 .16807 L
.05268 .16587 L
.0539 .16402 L
.05524 .16255 L
.05649 .16168 L
.05716 .1614 L
.05789 .16122 L
.05922 .16125 L
.06052 .16166 L
.06172 .16235 L
.06304 .16343 L
.06446 .16494 L
.06704 .16851 L
.07011 .17414 L
.07292 .18063 L
.08481 .219 L
.09442 .25287 L
.09718 .26101 L
.09979 .26732 L
.10214 .27157 L
.10346 .27332 L
.10468 .27449 L
.10602 .27531 L
.10728 .27562 L
.10866 .27548 L
.10944 .2752 L
.11015 .27481 L
.11089 .27429 L
.11157 .27371 L
Mistroke
.11312 .27204 L
.11594 .26797 L
.12641 .24691 L
.13176 .23667 L
.13457 .23227 L
.13754 .22847 L
.14014 .22582 L
.14299 .22354 L
.14559 .22197 L
.148 .22091 L
.14922 .2205 L
.15054 .22016 L
.15179 .21993 L
.15295 .21978 L
.15399 .2197 L
.15513 .21966 L
.15633 .21966 L
.15745 .2197 L
.15869 .21977 L
.15999 .21987 L
.16231 .22004 L
.16482 .22021 L
.16624 .22028 L
.16756 .22032 L
.1689 .22035 L
.16958 .22036 L
.17032 .22037 L
.17164 .22037 L
.17287 .22036 L
.17362 .22035 L
.17433 .22033 L
.17565 .22029 L
.17639 .22025 L
.17708 .22021 L
.17863 .22009 L
.17987 .21996 L
.18104 .2198 L
.1837 .21933 L
.18628 .21872 L
.18908 .21793 L
.20861 .2114 L
.25177 .1946 L
.29334 .17588 L
.33332 .15375 L
.35561 .13403 L
.36615 .12634 L
.37078 .12325 L
.37588 .12039 L
.38078 .11831 L
.38598 .11644 L
Mistroke
.38871 .11555 L
.39021 .11513 L
.39164 .11481 L
.39296 .11458 L
.39371 .11449 L
.39441 .11443 L
.39563 .11439 L
.39694 .11445 L
.39829 .11461 L
.39952 .11484 L
.40088 .11518 L
.40232 .11565 L
.40473 .11669 L
.4061 .11746 L
.40738 .11832 L
.40977 .12045 L
.41195 .12321 L
.41446 .12769 L
.41684 .13355 L
.41933 .1417 L
.42166 .15156 L
.42423 .1653 L
.42699 .18433 L
.42973 .20855 L
.43261 .2407 L
.43776 .31405 L
.44223 .38301 L
.44469 .41512 L
.44589 .42776 L
.447 .4371 L
.44832 .44492 L
.44901 .44751 L
.44975 .44906 L
.45093 .44893 L
.45224 .44504 L
.45345 .43805 L
.45475 .42719 L
.45711 .40022 L
.46227 .32287 L
.46776 .24411 L
.47092 .20918 L
.47378 .18464 L
.47665 .16569 L
.47936 .15205 L
.48193 .14214 L
.48334 .13784 L
.48465 .13448 L
.48697 .1299 L
.48819 .1281 L
.48951 .12659 L
Mistroke
.49092 .12537 L
.49167 .12487 L
.49246 .12443 L
.49315 .12412 L
.49391 .12384 L
.49525 .1235 L
.49655 .12332 L
.49727 .12329 L
.49794 .12329 L
.49924 .1234 L
.50047 .12364 L
.50177 .12404 L
.50251 .12435 L
.50318 .12469 L
.5044 .12543 L
.50574 .12646 L
.50807 .1288 L
.51053 .13202 L
.5132 .13637 L
.51607 .14201 L
.52126 .15543 L
.52374 .16389 L
.52644 .17498 L
.53135 .20062 L
.54056 .2644 L
.5453 .299 L
.5478 .31475 L
.55042 .32779 L
.55182 .33281 L
.55261 .33498 L
.55335 .33654 L
.55465 .33817 L
.55604 .33831 L
.55672 .33778 L
.55746 .33677 L
.5588 .33383 L
.56011 .32969 L
.56131 .32488 L
.5727 .25818 L
.57556 .24232 L
.57828 .22927 L
.58092 .21876 L
.58337 .21105 L
.58557 .2058 L
.58669 .2037 L
.58791 .20186 L
.58925 .20031 L
.59051 .19928 L
.59173 .19863 L
.59286 .19832 L
Mistroke
.59408 .19827 L
.59523 .19846 L
.59648 .1989 L
.59782 .19964 L
.59923 .20066 L
.60056 .20186 L
.60306 .20464 L
.61357 .22088 L
.61933 .22913 L
.62215 .23234 L
.62473 .23478 L
.62706 .23655 L
.62952 .23795 L
.6308 .23846 L
.63199 .2388 L
.63329 .23902 L
.63402 .23908 L
.63468 .23908 L
.63537 .23904 L
.6361 .23895 L
.6374 .23869 L
.63812 .23849 L
.6388 .23827 L
.64033 .23767 L
.64566 .235 L
.66502 .22403 L
.68455 .21429 L
.69486 .20955 L
.70051 .20696 L
.70328 .20589 L
.70582 .20513 L
.70846 .20454 L
.71131 .20404 L
.71738 .20293 L
.72249 .2019 L
.72809 .201 L
.73066 .20054 L
.73341 .19985 L
.73601 .19895 L
.73837 .19794 L
.7492 .19248 L
.79114 .17281 L
.83148 .14934 L
.83666 .14473 L
.83952 .14221 L
.84224 .14017 L
.84476 .13873 L
.84618 .13812 L
.8475 .13767 L
.8487 .13733 L
Mistroke
.84983 .13708 L
.85114 .13686 L
.85232 .13673 L
.8536 .13668 L
.85495 .13677 L
.8561 .13701 L
.85737 .13748 L
.85873 .13833 L
.85949 .13899 L
.86019 .13972 L
.86154 .14154 L
.86283 .1438 L
.86422 .14691 L
.86571 .15105 L
.86837 .1608 L
.87124 .17516 L
.8744 .19691 L
.87687 .21941 L
.87956 .25078 L
.885 .33513 L
.88762 .38116 L
.89009 .42215 L
.89231 .45269 L
.89357 .46591 L
.89472 .47496 L
.89599 .48107 L
.89671 .48264 L
.89738 .48284 L
.89875 .47951 L
.89951 .47549 L
.90021 .47054 L
.90164 .45671 L
.90321 .43681 L
.90607 .39142 L
.91114 .30204 L
.91662 .22321 L
.91954 .19318 L
.92222 .17196 L
.92478 .15619 L
.92749 .14332 L
.92992 .13446 L
.93218 .12815 L
.93466 .12304 L
.93606 .12085 L
.93732 .11921 L
.94015 .11641 L
.94275 .11454 L
.94561 .11296 L
.94708 .11231 L
.94865 .11173 L
Mistroke
.95002 .11135 L
.95128 .11109 L
.95254 .11093 L
.95374 .11087 L
.95442 .11087 L
.95514 .1109 L
.95643 .11101 L
.95722 .11111 L
.95797 .11122 L
.95936 .11149 L
.96172 .11204 L
.96424 .11278 L
.96701 .11387 L
.9696 .11526 L
.97251 .11746 L
.97526 .12031 L
.97773 .12363 L
.98042 .12823 L
.98274 .13323 L
.9853 .14017 L
.98798 .1494 L
.99049 .16034 L
.99498 .18664 L
.99981 .22657 L
1 .22836 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2<ooooo`Go00007oooool009;ooooo1?l0000Dooooo`05o`000?nj^[[ooooooiRHV?l@4100
1_ooool00ol0003oooooooooo`2:ooooo`;o00001Oooool2o`0001gooooo002>ooooo`Co00001?oo
ool2o`0001;ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo08Wooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Jooooo`00SOooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0R?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo01Wooooo002;ooooo`;o00003?ooool00ol0003oooooooooo`0F
ooooo`Go0000R?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Sooooo0029oooo
o`;o00003oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?o0000Qoooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo01Sooooo0028ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool05?ooool01?l0003oooooooooooooool3o`0008Kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0Gooooo`00Qoooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo01Cooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo
08?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Fooooo`00Q_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000006[ooooo0ol0000Gooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool05_ooool008Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001Xooooo`?o00000_ooool2o`00
01Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Fooooo`00Q?ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05_ooool008?ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Rooooo`;o00001oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05Oooool008;ooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`1Oooooo`;o00002_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05Oooool0087ooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Gooooo001ooooo
o`;o00006oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo0_l00005oooo
o`03o`000?oooooooooo05_ooooo0_l0000=ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Eooooo`00OOooool2o`0001gooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0F_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0Dooooo`00:?ooool2o`00057ooooo0_l0000Pooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo05Sooooo0_l0000Aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Dooooo`005Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^00Oooooo00Co0000oooooooooooo00003oooool01OnHV9So410@o`000?lb
<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00[ooooo0_l0000@ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o
<S8bonk^kPKooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool06?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o
0000oc8b<_o^k^hJooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?o0000
ooooooooool03?ooool01_nHV9So410@o`000?lb<S;oc<c<o`0000;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP09ooooo`03o`000?oooooooooo017ooooo0ol00003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03_ooool001Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02Oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01[ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02_ooool2o`0000oooooo
00Ko410@okZj^_ooooooMgMgoc8b<_l00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02Oooool0
0ol0003oooooooooo`0Booooo`;o00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;
ooooo`Ko00000_ooool5o`0000?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool6o`0000Kooooo00Go0000oooooooooooooooo
oa0@4003ooooo`03oa0@4?oooooooooo017ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@4007ooooo`;o00002_ooool6o`0000Gooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41006oooool00onHV9So8B4Qonk^kP04
ooooo`05oa0@4?ooooooooooooooool@41002Oooool00ol0003oooooooooo`0Cooooo`05o`000?oo
oooo0000ooooool@41000oooool00ol@413oooooooooo`07ooooo`03o`000?oooooooooo00oooooo
1Ol00003ooooo`05oa0@4?ooooooooooooooool@41003_ooool001?ooooo00CoA4A4omgMgOoooooo
00001?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0>ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000M
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000005ooooo`;o00005ooo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Looooo`03
oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000007ooooo`;o00005Oooool01_nY
ZJWo410@ooooool0003oooooo`0000?ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0?ooooo`03odA4A?oMgMgooooo00;o00000oooool01Ol0003ooooooooooooooooo000000kooooo
000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`000005ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool03Oooool00ol@413o0000okZj^P03ooooo`05
o`000?ooooooooooooooool000007_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooooooo
ooooool000000oooool2o`0001Wooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000007Oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool0
00001?ooool3o`0001Kooooo00Oo410@o`000?nj^[[oooooo`000?oooooo000000?ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0?ooooo`06omgMgOmEEEGoooooo`000?oooooo0000
0_ooool01Ol0003ooooooooooooooooo000000kooooo000Dooooo`03ogMgMoo<c<co000000Cooooo
00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool03Oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41007oooool01Ol0
003ooooooooooooooooo410@00?ooooo00Co410@ooooool0003o00006oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41001oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@01kooooo00Go0000oooooooooooooooooa0@4003oooo
o`03oa0@4?oooooooooo00;o00006_ooool01_nj^[[o8B4Qooooool0003ooooooa0@40?ooooo00?o
410@ooooooooool01oooool00ol0003oooooooooo`0@ooooo`05ogMgMoo<c<co0000ooooool00000
0_ooool01Ol@413ooooooooooooooooo410@00kooooo000Dooooo`03onk^k_m4A4Co000000Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool02_ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0K
ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01?mgMgOoV9RHoooooonHV9P2o`0001gooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01Ol0
003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02o`0001Wooooo00go
410@oiRHV?oooooo^[Zjo`000?oooooo0000oooooomgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o
0000ooooooooool04Oooool01Oo^k^koA4A4o`000?oooooo000000;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0>ooooo`005Oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool01OnHV9So410@o`000?lQ
8B7oc<c<00?ooooo00Gok^k^o`000?l0003o0000onk^kP0Looooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Kooooo00?oEEEEofIVI_l0
00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003
ooooo`03onk^k_lb<S;o000000;o00006oooool03OnYZJWo410@o`000?l@413oZJVYooooool0003o
ooooonk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`0Booooo`04ogMgMol0003o
ooooo`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`009?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo03Sooooo0_l0000cooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Cooooo0_l0
000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`0Cooooo`009?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Kooooo0_l0000e
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo04;ooooo0_l0000Wooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`0Cooooo`008oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo03?ooooo0_l0000gooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo047ooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool04oooool002?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0`ooooo`?o
0000>_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0@ooooo`?o0000:_ooool3o`0002[ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01;ooooo000Sooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0;Oooool3o`0003gooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`02o`0002?ooooo1_l0000]ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Booooo`005_ooooooo`00043o00004ooo
ool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000Oooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`04o`000?oo
ooooooooooooo`?o000000?oooooo`000?ooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooo000000Gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00001?ooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo1?l00007ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01?ooool2o`0001?ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo000000Gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool01?l0003oooooo`000?l00004ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Cooooo0_l00007oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooo000000Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l0000Cooooo`008oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo023ooooo0ol00018ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`;o0000??ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool04_ooool002?o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Mooooo`?o0000Boooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04Oooool3o`0003ko
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01;o
oooo000Sooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04?ooool=o`0004kooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00kooooo
0_l00011ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0Aooooo`008oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0FOooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool03?ooool2o`0004?ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo017ooooo000Fooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`;o0000G?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`13
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0A
ooooo`005_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`07ooooo`;o0000A_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo02_ooooo000Fooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05_ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`07ooooo`;o00002Oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo0_l00006ooooo`03o`000?oooooooooo04Kooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0[ooooo`005_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Looooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`;o0000
BOooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02_ooooo000Fooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo05cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`Co0000C?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02_ooooo000Fooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo05gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0:oooool001Kooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0/ooooo`005_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02co
oooo000Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`1Oooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0;?ooool001Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0Goooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0/ooooo`005oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1P
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool2o`0000_ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0;?ooool001Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo05oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0/oooo
o`005oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0Goooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02cooooo000Gooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo06;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Oooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0;?ooool001Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Booooo`05o`000?ooooooooooooooool00000IOooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0/ooooo`005oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01?ooooo0ol0
001Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0H?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo02cooooo000Gooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0H?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02cooooo000Goooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo063ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0/oooo
o`005oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo07gooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`08ooooo`;o00003?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo063ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0/ooooo`00
5oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo07gooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
;Oooool001Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1mooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo02gooooo000Gooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0OOooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0]ooooo`006?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
07gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0;Oooool001Sooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`1nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo02gooooo000Hooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0O_ooool00ol0003oooooooooo`06ooooo`Go00001_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Hoooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo02gooooo000Hooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`06o`000?nHV9So8B4Qonk^k_oooooo
A4A41_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0Hoooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02gooooo000Hooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`05o`00
0?ooooooV9RHob4Q8Oo^k^h01oooool3o`0000cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`1Sooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0;Oooool001Sooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo
00Ko0000ooooooooooooV9RHob4Q8Oo^k^h6ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0;Oooool001Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1oooooo`03
o`000?oooooooooo00Gooooo00Ko0000ooooooooooooooooogMgMomVIVH6ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0;Oooool001Sooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`1oooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo00Go0000ooooooooooooooooo`00001V
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0;Oooool001Sooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo00Gooooo0_l000001?nj
^[[ooooooiRHV?l@4106ooooo`03o`000?oooooooooo00cooooo00Go0000ooooooooooooooooo`00
001Vooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0;Oooool001Wooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo00Gooooo00Ko0000
oiRHV?l@413o0000ob4Q8Oo<c<`6ooooo`03o`000?oooooooooo00gooooo00Co0000oooooooooooo
0000I_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02gooooo000Iooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool03Oooool01?l0003oooooooooool0001Vooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0;_ooool001Wooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0=ooooo`04o`000?ooooooooooo`0006Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0^ooooo`006Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo07oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`;o0000
3_ooool2o`000003ooooool0003ooooo06Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0^ooooo`006Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00kooooo0_l0
001Wooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;_ooool001Wooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0;_ooool001Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1ooooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1goooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;_ooool001Wooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0;_ooool001[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1oooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1gooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0;_ooool001[ooooo00Go0000oooooooooooooooo
o`000023ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`1gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;_ooool001[ooooo00Go
0000ooooooooooooooooo`000023ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
;_ooool001[ooooo00Go0000ooooooooooooooooo`000023ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0;_ooool001[ooooo00Go0000ooooooooooooooooo`000023ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02_ooool2o`0007Wooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0^ooooo`006_ooool01Ol0003ooooooooooooooooo000008?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo07Sooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0^ooooo`006_ooool01Ol0003ooooooooo
oooooooo000008?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo07Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0^ooooo`006_oo
ool01Ol0003ooooooooooooooooo000008?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0_ooooo`006_ooool01Ol0003ooooooooooooooooo000008?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0_ooooo`006_ooool01Ol0003ooooooooooooooooo000008?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo07Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0_ooooo`006_ooool01?l0003ooooooooo
ool00024ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`1hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;oooool001[ooooo00Co
0000oooooooooooo0000Q?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0N?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02oooooo
000Kooooo`03o`000?oooooo000008Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0;ooooo`;o0000NOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02oooooo000K
ooooo`03o`000?oooooo000008Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0_
ooooo`006oooool00ol0003oooooo`000024ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0;oooool001_ooooo0_l00025ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0;oooool001cooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo02oooooo002Sooooo`05o`000?ooooooooooooooool000001?ooool2o`000003oa0@
4?oooooooooo00Cooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo02oooooo002Sooooo`05o`000?ooooooooooooooool000001Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0_ooooo`00Xoooool01Ol0003ooooooooooooooooo000000;ooooo1Ol00006ooooo`03o`00
0?oooooooooo07Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0_ooooo`00Xooo
ool01Ol0003ooooooooooooooooo000000;ooooo00CoA4A4omgMgOoooooo00001oooool3o`0007Wo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0_ooooo`00Xoooool01?l0003ooooo
ooooool00003ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0NOooool01Ol0
003ooooooooooooooooo000003;ooooo002Sooooo`04o`000?ooooooooooo`0000Cooooo00?oMgMg
olc<c?l000001oooool00ol0003oooooooooo`1iooooo`05o`000?ooooooooooooooool00000<_oo
ool00:?ooooo00Co0000oooooooooooo00001?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oo
oooooooo07Wooooo00Go0000ooooooooooooooooo`00000booooo`00Y?ooool00ol0003oooooo`00
0005ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0NOooool01Ol0003ooooooooo
oooooooo000003;ooooo002Tooooo`03o`000?oooooo000000kooooo00?o0000ooooooooool0NOoo
ool01Ol0003ooooooooooooooooo000003;ooooo002Tooooo`03o`000?oooooo000000kooooo00?o
0000ooooooooool0NOooool01Ol0003ooooooooooooooooo000003;ooooo002Tooooo`03o`000?oo
oooo000000kooooo00?o0000ooooooooool0NOooool01Ol0003ooooooooooooooooo000003;ooooo
002Tooooo`03o`000?oooooo000000kooooo0_l0001jooooo`05o`000?ooooooooooooooool00000
<_ooool00:Cooooo00?o0000ooooool000003_ooool00ol0003oooooooooo`1jooooo`04o`000?oo
ooooooooo`0003;ooooo002Tooooo`03o`000?oooooo000000kooooo00?o0000ooooooooool0N_oo
ool01?l0003oooooooooool0000booooo`00YOooool2o`0000kooooo00?o0000ooooooooool0N_oo
ool01?l0003oooooooooool0000booooo`00YOooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo07[ooooo00Co0000oooooooooooo0000<_ooool00;Gooooo00?o0000ooooooooool0N_oo
ool01?l0003oooooooooool0000booooo`00]Oooool00ol0003oooooooooo`1jooooo`04o`000?oo
ooooooooo`0003;ooooo002eooooo`03o`000?oooooooooo07[ooooo00Co0000oooooooooooo0000
<_ooool00;Gooooo0_l0001kooooo`04o`000?ooooooooooo`0003;ooooo002eooooo`03o`000?oo
oooooooo07[ooooo00?o0000ooooool00000<oooool00;Gooooo00?o0000ooooooooool0N_ooool0
0ol0003oooooo`00000cooooo`00]Oooool00ol0003oooooooooo`1kooooo`;o0000<oooool00;Go
oooo00?o0000ooooooooool0Noooool2o`0003?ooooo002eooooo`03o`000?oooooooooo07_ooooo
0_l0000cooooo`00]Oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo03;ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:[o
oooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05
oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000oiRHV?oo
ooooV9RHob4Q8@06ooooo`?o0000/?ooool00:[ooooo00Go0000oeEEEOl0003o410@olc<c006oooo
o`03o`000?oooooooooo0;3ooooo002Zooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000oooooooo
ool0/?ooool00:[ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`2`ooooo`00Zooo
ool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0
1_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo
00?o0000ooooooooool0/?ooool00:[ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo0;3ooooo002Zooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`000;3ooooo
002Zooooo`05olc<c?l0003o0000o`000?o<c<`0^Oooool00:[ooooo00Go410@okZj^_oooooo^[Zj
oa0@402iooooo`00Z_ooool01Ol0003o^[Zjoooooonj^[[o00000;Wooooo002Zooooo`05ojVYZOl@
413o0000oa0@4?nYZJT0^Oooool00?ooooooJOooool00:oooooo00?o0000okZj^_ooool0]_ooool0
0:oooooo0_lb<S:gooooo`00P?ooool2o`000006oa0@4?oooooooooooa0@4?l0003o410@6?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`03ohN7
Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Iooooo`Co000000Co410@oooooooo
oooooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^N?ooool0087ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00003Oooool02OmgMgOo<S8boooo
ooooooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03olc<c?l0003o410@00cooooo00Go410@okZj
^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1hooooo`00POooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo410@0oooool00ol@413ooooooooo
o`0@ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@4100N?ooool0087ooooo00Ko0000oooooom4A4CoA4A4
ooooool00009ooooo`Ko00003Oooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0;ooooo`Ko00003?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001hooooo`00POooool01_l0
003ogMgMoc8b<_mEEEGogMgMo`0001Wooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`00
0?ooooooooooooooool000004_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000007Sooooo0021ooooo`06
o`000?n7QhOoZJVYokZj^_mEEEGo00006Oooool00ol0003oooooooooo`04ooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol@413o0000o`000003o`0001cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100N?ooool0087ooooo00Ko
0000oc8b<_oooooooooooc8b<_l0000Iooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0Booooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0N?ooool0083ooooo00?o410@o`00
0?n7QhL00_ooool00on7QhOo0000oa0@400Hooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01;ooooo00?o0000ooooooooool06oooool00omEEEGoIVIVo`000005ooooo`03oeEEEOmVIVKo
000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1hooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(112) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .21919 m
.00942 .28862 L
.0122 .31042 L
.01483 .32913 L
.01739 .34404 L
.01851 .34922 L
.01975 .35382 L
.02096 .35711 L
.02225 .35923 L
.02292 .35978 L
.02364 .35993 L
.02496 .35906 L
.02567 .358 L
.02645 .35637 L
.02786 .35225 L
.02924 .34691 L
.03053 .34093 L
.04057 .27835 L
.04334 .26189 L
.04635 .24664 L
.049 .2357 L
.0518 .22666 L
.05433 .2205 L
.05567 .21794 L
.0571 .21569 L
.05842 .21405 L
.05962 .21289 L
.06083 .21204 L
.06198 .2115 L
.06329 .21121 L
.06403 .21118 L
.06473 .21125 L
.06547 .21141 L
.06614 .21164 L
.06688 .21197 L
.06766 .21241 L
.07017 .21436 L
.07291 .21724 L
.08481 .23393 L
.08989 .24157 L
.09257 .24523 L
.0954 .24857 L
.09788 .25095 L
.1006 .25296 L
.1018 .25365 L
.10308 .25427 L
.10428 .25475 L
.1054 .2551 L
.10618 .25529 L
.10688 .25543 L
Mistroke
.10766 .25555 L
.10849 .25564 L
.10922 .25567 L
.11 .25567 L
.11074 .25563 L
.11142 .25556 L
.1127 .25534 L
.11342 .25517 L
.1141 .25498 L
.11693 .25387 L
.11957 .25246 L
.12198 .25099 L
.1274 .24748 L
.14917 .23346 L
.15874 .22819 L
.16382 .22561 L
.16929 .22352 L
.17456 .22207 L
.17938 .22098 L
.18177 .22053 L
.18399 .22022 L
.18631 .21998 L
.18884 .21978 L
.19015 .21969 L
.19155 .21957 L
.19279 .21945 L
.19411 .21928 L
.19659 .21883 L
.19888 .21827 L
.20399 .21657 L
.20959 .21411 L
.252 .19064 L
.26147 .18883 L
.26626 .18761 L
.26899 .18673 L
.27155 .18566 L
.27432 .18416 L
.27686 .18243 L
.28259 .17743 L
.29282 .1661 L
.30367 .15176 L
.3151 .13809 L
.32531 .12787 L
.33622 .12018 L
.34179 .11699 L
.34706 .11477 L
.35219 .11317 L
.35692 .11181 L
.36141 .11069 L
.36367 .11029 L
Mistroke
.36496 .11012 L
.36617 .10999 L
.36746 .10989 L
.36869 .10982 L
.371 .1097 L
.3762 .1094 L
.37751 .10931 L
.37819 .10927 L
.37892 .10923 L
.38026 .10919 L
.38148 .10917 L
.38267 .10919 L
.38377 .10925 L
.38498 .10934 L
.38627 .10949 L
.39179 .11033 L
.3945 .11076 L
.39701 .11116 L
.39936 .11161 L
.40185 .1123 L
.40314 .11277 L
.40435 .11329 L
.40711 .11478 L
.41155 .11799 L
.41632 .12276 L
.41884 .12625 L
.42153 .13122 L
.42407 .13748 L
.42638 .14481 L
.4291 .15578 L
.43204 .17105 L
.43738 .21038 L
.44793 .34011 L
.45083 .37898 L
.45242 .39772 L
.45393 .41271 L
.45533 .42354 L
.45613 .42818 L
.45686 .43145 L
.45816 .4347 L
.45954 .43453 L
.46023 .43304 L
.46096 .43049 L
.46226 .4235 L
.46298 .41835 L
.46366 .4128 L
.46519 .39784 L
.4705 .33058 L
.4756 .26535 L
.48042 .21823 L
Mistroke
.4831 .19914 L
.48601 .18336 L
.48866 .17277 L
.4911 .16566 L
.49246 .16267 L
.49374 .16046 L
.49514 .15864 L
.49593 .15787 L
.49665 .15732 L
.49739 .15689 L
.49809 .15662 L
.49885 .15645 L
.49966 .15641 L
.50043 .1565 L
.50116 .15669 L
.50252 .15729 L
.50374 .15808 L
.50505 .15916 L
.50741 .16167 L
.51021 .16557 L
.51277 .17001 L
.51833 .18271 L
.5236 .19834 L
.53281 .23181 L
.53806 .25274 L
.54299 .27131 L
.54536 .27907 L
.54786 .28598 L
.54917 .28899 L
.55061 .29178 L
.5519 .29381 L
.55312 .29531 L
.5538 .29596 L
.55453 .29652 L
.55582 .29714 L
.55654 .29728 L
.55731 .29728 L
.5587 .29689 L
.55997 .2961 L
.56117 .29501 L
.56248 .29344 L
.56389 .29136 L
.56907 .28103 L
.57399 .26926 L
.58322 .24906 L
.58852 .24038 L
.59331 .23463 L
.59597 .23235 L
.59737 .2314 L
.59884 .23059 L
Mistroke
.60014 .23002 L
.60156 .22955 L
.60285 .22923 L
.60405 .22904 L
.60525 .22892 L
.60656 .22888 L
.60779 .22891 L
.60893 .22901 L
.60996 .22914 L
.61109 .22933 L
.61338 .22988 L
.61586 .23068 L
.61853 .23174 L
.62337 .23387 L
.62589 .23491 L
.62859 .23583 L
.6299 .23619 L
.63113 .23647 L
.63224 .23667 L
.63344 .23684 L
.63476 .23696 L
.63552 .23699 L
.63622 .237 L
.63696 .23699 L
.63764 .23696 L
.63842 .23691 L
.63917 .23683 L
.64048 .23663 L
.64169 .23638 L
.64302 .23602 L
.64444 .23555 L
.64705 .23442 L
.64987 .23289 L
.65497 .22958 L
.661 .22562 L
.66661 .22241 L
.67145 .22011 L
.67394 .21917 L
.67663 .21837 L
.67817 .21801 L
.67959 .21774 L
.68238 .21732 L
.68508 .21698 L
.68761 .21663 L
.69273 .21562 L
.69544 .21489 L
.69836 .21396 L
.70141 .21278 L
.70431 .21141 L
.70976 .20807 L
Mistroke
.74987 .18818 L
.75498 .18716 L
.75767 .18652 L
.76051 .18572 L
.763 .18482 L
.76573 .18354 L
.76821 .18202 L
.77053 .1803 L
.78208 .16877 L
.79255 .15535 L
.80204 .14335 L
.81213 .13223 L
.82319 .12322 L
.82811 .12015 L
.83341 .11708 L
.83627 .11577 L
.83889 .11486 L
.84139 .11422 L
.84402 .11365 L
.84695 .11301 L
.85008 .11228 L
.8516 .11196 L
.85235 .11183 L
.85304 .11173 L
.85433 .1116 L
.855 .11157 L
.85572 .11157 L
.85692 .11163 L
.85821 .11181 L
.85942 .11207 L
.86053 .11239 L
.86324 .11339 L
.86581 .1146 L
.86856 .11623 L
.8711 .11835 L
.87256 .12002 L
.87388 .12191 L
.87542 .12464 L
.87685 .12781 L
.8793 .13484 L
.88199 .14518 L
.88461 .1584 L
.88741 .17685 L
.89002 .19925 L
.89249 .22623 L
.89711 .29377 L
.9022 .38536 L
.90498 .43234 L
.90635 .45159 L
.90759 .46608 L
Mistroke
.90895 .47778 L
.9097 .48224 L
.91041 .48507 L
.91118 .48656 L
.91189 .48646 L
.91268 .4847 L
.91351 .48095 L
.91422 .47632 L
.91499 .46987 L
.91638 .45469 L
.91898 .41661 L
.9242 .32344 L
.92708 .27524 L
.9298 .23674 L
.93233 .20805 L
.93508 .18384 L
.93758 .16697 L
.9399 .15475 L
.94233 .1448 L
.94501 .13669 L
.94636 .13363 L
.94781 .13101 L
.94918 .12913 L
.95044 .12783 L
.95111 .12728 L
.95183 .12679 L
.95313 .12613 L
.95392 .12584 L
.95467 .12563 L
.95534 .12549 L
.95607 .12537 L
.95679 .1253 L
.95757 .12525 L
.95839 .12523 L
.95916 .12524 L
.96054 .12535 L
.96131 .12546 L
.96201 .12559 L
.96325 .12592 L
.96441 .12635 L
.96545 .12684 L
.96658 .1275 L
.96911 .12949 L
.97144 .13187 L
.97596 .13769 L
.98018 .14437 L
.98478 .15401 L
.98721 .16068 L
.98982 .16932 L
.99515 .1921 L
Mistroke
1 .21919 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool008Oooooo3ol0000Hooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0K?ooool4o`00043ooooo0024ooooo`?o00003oooool3o`00017ooooo00Go
0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo06Wooooo0ol00004ooooo`;o0000
?_ooool008;ooooo0_l0000Eooooo`03o`000?oooooooooo00kooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c006ooooo`03o`000?oooooooooo06Kooooo0ol00009ooooo`;o0000??ooool0083ooooo0_l0
000Gooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0IOooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo03[ooooo001nooooo`;o00006_ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo06?ooooo0_l0000?ooooo`03o`000?oooooooooo03Wooooo001moooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1Roooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool05?ooool6o`0001kooooo001mooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool05oooool2o`0006;ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Cooooo`;o00001Oooool00ol0003oooooooooo`0Kooooo`00
O?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Jooooo`00Noooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Jooooo`00N_ooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0G_ooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Iooooo`00NOooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Hooooo`00N?ooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0GOooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Gooooo`00Moooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Gooooo`00M_ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0Foooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0Fooooo`00M_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01Cooooo0_l0001K
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo01Kooooo001eooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool04_ooool4o`0005_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05_ooool007Cooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`0Booooo`05o`000?oooooo0000ooooool00000FOooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0Eooooo`005Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb
<S;ok^k^01[ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h06oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo
01Cooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^2?ooool00ol0003ooooo
ooooo`0@ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool07?ooool4o`000008
oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hJooooo`Go00000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Kooooo00?o0000ooooooooool04_ooool01OnHV9So410@o`000?lb<S;oc<c<00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`03o`000?oooooooooo00cooooo0_l000002Ol@
413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0>ooooo`005_ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`0@ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL06_ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo01?ooooo00Go410@okZj^_ooooooMgMg
oc8b<P03ooooo`05ogMgMonHV9So0000oiRHV?mgMgL03_ooool00ol0003oooooooooo`0=ooooo`;o
00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko00000_ooool5o`0000?o
oooo00Go410@oooooooooooooooooa0@400Booooo`Ko00001_ooool01Ol0003ooooooooooooooooo
410@00?ooooo00?o410@ooooooooool04Oooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h01?ooool0
1Ol@413ooooooooooooooooo410@00?ooooo00?o0000ooooooooool03Oooool6o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0
3oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41006oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?ooooooooooooooool@41001?ooool00ol0003oooooooooo`0Hooooo`05o`000?oooooo
ooooooooool@41000_ooool00ol0003o410@ooooo`0=ooooo`03o`000?oooooooooo00[ooooo1Ol0
0003ooooo`05oa0@4?ooooooooooooooool@41003_ooool001?ooooo00CoA4A4omgMgOoooooo0000
1?ooool01Ol0003ooooooooooooooooo000001gooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003o
oooooooooooooooo000001gooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo
000000;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000002?ooool00ol0003oooooooooo`0?ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`00000Looooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo01Sooooo00?oZJVYoa0@4?ooool00_ooool00ol0003oooooooooo`02o`00
00kooooo00?o0000ooooooooool02_ooool00om4A4CogMgMooooo`02o`0000?ooooo00Go0000oooo
ooooooooooooo`00000>ooooo`004oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?oooooo
ooooooooool000007?ooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool00000
7_ooool00omgMgOoIVIVooooo`02ooooo`07o`000?ooooooooooooooool0003oooooo`00000Loooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooo
oooo00oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001gooooo00?oMgMgofIVI_ooool0
0_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool06?ooool00ol@413o
0000okZj^P03ooooo`03o`000?oooooooooo00;o00003Oooool00ol0003oooooooooo`0;ooooo`03
omgMgOmEEEGooooo00;o00000oooool01Ol0003ooooooooooooooooo000000kooooo000Dooooo`03
ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@400Mooooo`03okZj^_lQ8B7ooooo
00;ooooo00Go410@oooooooooooooooooa0@400Oooooo`05o`000?ooooooooooooooool@41000ooo
ool00ol@413o0000ooooo`0Looooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@4008ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool2o`0000?ooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41007_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooool000007?ooool00onj
^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooo`000?l@41003Oooool00ol0003oooooooooo`0<
ooooo`05ogMgMoo<c<co0000ooooool000000_ooool01Ol@413ooooooooooooooooo410@00kooooo
000Dooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05oa0@
4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go0000okZj
^_ooooooV9RHoa0@4003ooooo`03ogMgMonHV9Sooooo00;o00007_ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05o`000?nj^[[ooooooiRHV?l@
41000oooool01?mgMgOoV9RHoooooonHV9P2o`0001[ooooo00Go410@oiRHV?oooooo^[Zjo`000003
ooooo`05ogMgMonHV9Soooooo`000?mgMgL03Oooool00ol0003oooooooooo`0<ooooo`05onk^k_m4
A4Co0000ooooool000000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000Eooooo`03ogMg
Mol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Jooooo`05ojVYZOl@413o0000oa0@
4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c003ooooo`?o000000?o<S8bonk^k_ooool06oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Iooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool5o`00
01_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000o`000?o^k^h03Ooo
ool00ol0003oooooooooo`0=ooooo`04ogMgMol0003oooooo`0000;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0>ooooo`00IOooool5o`0003Kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0AOooool2o`0002cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo
001Sooooo`;o0000>oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`12ooooo`;o0000;_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool006;ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`10ooooo`;o0000<?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool0063ooooo0_l0000noooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo03kooooo0_l0000booooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Booooo`00G_ooool2o`00043ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0??ooool2o`0003Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo01;ooooo000Foooooooo0000@?l0000Cooooo`005_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooo`00
0007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00Co0000ooooool0003o00001?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool001Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?o00000_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooooooo0_l00002
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo000Xooooo`;o0000
0_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
<_ooool3o`0003gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo017ooooo000Wooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09?oo
ool4o`0004Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0;?ooool5o`00043ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo000Fooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Mooooo`Oo0000COooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Zooooo`;o0000AOooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool04Oooool001Kooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo01[ooooo0_l0001Dooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
02Sooooo0_l00017ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool09oooool001Ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Go
oooo1?l0001Fooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo02Kooooo0_l00019ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool09oooool001Kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0F?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Booooo`Oo00002oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool09oooool001Kooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo013ooooo0_l0001Kooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool01?ooool2o`0000Sooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`05ooooo`;o00001oooool2o`0004cooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Wooooo`005oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool02?ooool7o`0004kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0W
ooooo`005oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool03?ooool2o`0005oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1Noooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool09oooool001Oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0Goooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05kooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Wooooo`005oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Pooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo02Oooooo000Gooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool09ooo
ool001Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0>ooooo`;o00001Oooool2
o`0006Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool09oooool001Oooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0@ooooo`Ko0000I_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
067ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Wooooo`006?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`05ooooo`;o00002oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo067o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Xooooo`006?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`1Sooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0:?ooool001Sooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0Hoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Sooooo000H
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0X
ooooo`006?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo07cooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0:?ooool001Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1looooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo02Sooooo000Hooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
OOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Xooooo`006Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo07gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Uooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0:?ooool001Wooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1mooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool2
o`0000cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0:?ooool001Wooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`1nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0I_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo02Sooooo000Iooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Xooooo`006Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00gooooo00Go0000ooooooooooooooooo`00001Yooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0:?ooool001Wooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0>ooooo`?o0000J_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo02Sooooo000Iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0O_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Nooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Sooooo000Jooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`04ooooo`Go00001_ooool0
0ol0003oooooooooo`1kooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0:Oooool0
01[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo
00Cooooo00GoV9RHob4Q8Ol0003oooooodA4A006ooooo`03o`000?oooooooooo07_ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Yooooo`006_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo07oooooo00?o0000ooooooooool01Oooool00onHV9So0000onk^kP07oooo
o`?o0000Noooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Wooooo000Jooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`06ooooo`03
o`000?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo02Wooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
Ooooool00ol0003oooooooooo`06ooooo`03o`000?mgMgOoIVIV00Kooooo00?o0000ooooooooool0
Noooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Wooooo000Jooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`05ooooo`04o`000?oo
ooooooooo`0000Kooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo02Wooooo000Jooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0POoo
ool00ol0003oooooooooo`03ooooo`;o000000?ooooooiRHV?l@41001_ooool00ol0003ooooooooo
o`1looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0:Oooool001[ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo00?ooooo00GoV9RH
o`000?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Yooooo`006_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo087ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo07cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Yooooo`006_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Yooooo`006_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo08;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`;o0000OOooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo02Wooooo000Jooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0P_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0O?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Wooooo
000Kooooo`05o`000?ooooooooooooooool00000Q?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo02Wooooo000Kooooo`05o`000?ooooooooooooooool00000Q?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0O?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo02Wooooo000Kooooo`05o`000?ooooooooooooooool00000
Q?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
O?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Wooooo000Looooo`04o`000?oo
ooooooooo`0008Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo07cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Zooooo`007?oo
ool01?l0003oooooooooool00024ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
:_ooool001cooooo00?o0000ooooool00000QOooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo02[ooooo000Mooooo`;o0000QOooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo02[ooooo002Uooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool2o`00
07gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Zooooo`00YOooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0OOooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo02[ooooo002Uooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0:_ooool00:Gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo07gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Zooooo`00YOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0OOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02[ooooo002Uoooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1moooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:_ooool00:Gooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo07gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Zooooo`00YOooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo02[ooooo002Uooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?oo
ool2o`0007kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Zooooo`00Y_ooool0
1Ol0003ooooooooooooooooo000000[ooooo00?o0000ooooooooool0OOooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo02[ooooo002Vooooo`05o`000?ooooooooooooooool000002_oo
ool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:_oo
ool00:Kooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo07gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0[ooooo`00Y_ooool01Ol0003ooooooooooooo
oooo000000[ooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo02_ooooo002Vooooo`06o`000?ooooooooooooooool0003ooooo0_l000000ol@413ooooo
ooooo`04ooooo`03o`000?oooooooooo07gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0[ooooo`00Y_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0OOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02_ooooo
002Vooooo`03o`000?oooooooooo00Ko00001_ooool00ol0003oooooooooo`1nooooo`05o`000?oo
ooooooooooooool00000;Oooool00:Kooooo00So0000oooooooooooo0000odA4A?oMgMgoooooo`00
00Oooooo0ol0001nooooo`05o`000?ooooooooooooooool00000;Oooool00:Kooooo00So0000oooo
oooooooo0000omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0O_ooool01Ol0003ooooo
oooooooooooo000002gooooo002Vooooo`08o`000?ooooooooooo`000?ooooooMgMgolc<c?l00007
ooooo`03o`000?oooooooooo07kooooo00Go0000ooooooooooooooooo`00000]ooooo`00Yoooool0
1ol0003oooooo`000?ooooook^k^odA4A?l000001oooool00ol0003oooooooooo`1nooooo`05o`00
0?ooooooooooooooool00000;Oooool00:Oooooo00?o0000ooooool000000_ooool00omgMgOo0000
ooooo`06ooooo`03o`000?oooooooooo07kooooo00Go0000ooooooooooooooooo`00000]ooooo`00
Yoooool00ol0003oooooo`00000;ooooo`03o`000?oooooooooo07kooooo00Go0000oooooooooooo
ooooo`00000]ooooo`00Yoooool2o`0000cooooo00?o0000ooooooooool0O_ooool01Ol0003ooooo
oooooooooooo000002gooooo002Xooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
O_ooool01Ol0003ooooooooooooooooo000002gooooo002eooooo`;o0000Ooooool01?l0003ooooo
ooooool0000^ooooo`00]Oooool00ol0003oooooooooo`1nooooo`04o`000?ooooooooooo`0002ko
oooo002eooooo`03o`000?oooooooooo07kooooo00Co0000oooooooooooo0000;_ooool00;Gooooo
00?o0000ooooooooool0O_ooool01?l0003oooooooooool0000^ooooo`00]Oooool00ol0003ooooo
ooooo`1nooooo`04o`000?ooooooooooo`0002kooooo002eooooo`03o`000?oooooooooo07kooooo
00Co0000oooooooooooo0000;_ooool00;Gooooo00?o0000ooooooooool0O_ooool01?l0003ooooo
ooooool0000^ooooo`00]Oooool00ol0003oooooooooo`1nooooo`04o`000?ooooooooooo`0002ko
oooo002eooooo`;o0000P?ooool00ol0003oooooo`00000^ooooo`00]Oooool00ol0003ooooooooo
o`1oooooo`03o`000?oooooo000002kooooo002eooooo`03o`000?oooooooooo07oooooo00?o0000
ooooool00000;_ooool00;Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooo`00000^oooo
o`00]Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooo000002kooooo002eooooo`03o`00
0?oooooooooo07oooooo00?o0000ooooool00000;_ooool00;Gooooo00?o0000ooooooooool0Oooo
ool00ol0003oooooo`00000^ooooo`00]Oooool00ol0003oooooooooo`20ooooo`03o`000?oooooo
oooo02gooooo002eooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool0;Oooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00Z_ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[o
oooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003o
V9RHoooooonHV9So8B4Q00Kooooo0ol0002`ooooo`00Z_ooool01Ol0003oEEEEo`000?l@413oc<c<
00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00?oEEEEohN7Qoooool02?ooool00ol0003o
ooooooooo`2`ooooo`00Z_ooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo0;3ooooo
002[ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo00Goc<c<ob4Q8Ol0003o8B4Q
olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40
1_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0/?ooool00:[ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000
/?ooool00:[ooooo00Goc<c<o`000?l0003o0000olc<c02iooooo`00Z_ooool01Ol@413o^[Zjoooo
oonj^[[o410@0;Wooooo002Zooooo`05o`000?nj^[[ooooookZj^_l00000^Oooool00:[ooooo00Go
ZJVYoa0@4?l0003o410@ojVYZ@2iooooo`00oooooomYooooo`00[oooool00ol0003o^[Zjooooo`2f
ooooo`00[oooool2oc8b<[Oooooo0020ooooo`;o000000Ko410@oooooooooooo410@o`000?l@410H
ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Wooooo1?l000001?l@413o
ooooooooooooool4o`000003oa0@4?oooooooooo00Go0000N?ooool0087ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`07ooooo`Ko00003Oooool02OmgMgOo<S8booooooooooooMgMg
oiRHV?ooooooV9RHogMgM`03ooooo`03olc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMg
oa0@4009ooooo`Ko00003?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A01hooooo`00POooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01_ooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`0@ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03
oiRHV?lQ8B7ok^k^07Wooooo0021ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`00
00gooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool02oooool6o`0000cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04
ooooo`03oiRHV?lQ8B7ok^k^07Sooooo0021ooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo00006Ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000Booooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
ogMgMomVIVKooooo07Oooooo0021ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo00006Oooool00ol0
003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol@413o0000o`000003
o`0001cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo07Kooooo0021ooooo`06o`000?lb<S;ooooooooooolb<S;o00006Oooool00ol0003ooooooooo
o`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01Ol0003o^[ZjoooooonHV9So410@07So
oooo0020ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool4o`0000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Booooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l0
00001Oooool00omEEEGoIVIVo`000004ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0N?ooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(114) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .20899 m
.00942 .24451 L
.01975 .28871 L
.02496 .30738 L
.02646 .31165 L
.02787 .31508 L
.02916 .31764 L
.03053 .31973 L
.03172 .32102 L
.03303 .32186 L
.03422 .32208 L
.03534 .32185 L
.03666 .32104 L
.03786 .31984 L
.03925 .31794 L
.04057 .31568 L
.05167 .28672 L
.05777 .26972 L
.06351 .25686 L
.06888 .24838 L
.0719 .24497 L
.07468 .24261 L
.07703 .2412 L
.07836 .24064 L
.07961 .24026 L
.08092 .24002 L
.08212 .23994 L
.0835 .24 L
.08481 .2402 L
.08599 .24048 L
.08711 .24083 L
.08965 .24188 L
.09479 .24475 L
.10402 .25101 L
.10657 .25255 L
.10797 .25327 L
.10926 .25383 L
.11047 .25426 L
.11156 .25456 L
.11277 .25478 L
.11407 .25491 L
.11475 .25492 L
.11546 .25489 L
.11675 .25476 L
.11813 .25449 L
.11891 .25428 L
.11965 .25405 L
.12219 .253 L
.12491 .2515 L
.13555 .24334 L
Mistroke
.14117 .23934 L
.1443 .23774 L
.14578 .23715 L
.14714 .23671 L
.14844 .23637 L
.14986 .23608 L
.15128 .23586 L
.15206 .23578 L
.15279 .23571 L
.15413 .23564 L
.15535 .23562 L
.15603 .23563 L
.15676 .23564 L
.1581 .23571 L
.16062 .23589 L
.16195 .236 L
.16267 .23605 L
.16334 .2361 L
.16456 .23616 L
.1659 .23618 L
.16704 .23615 L
.16825 .23605 L
.16953 .23586 L
.17092 .23556 L
.17223 .23516 L
.17344 .2347 L
.17573 .23358 L
.17815 .23207 L
.18335 .22786 L
.18906 .22213 L
.19498 .21582 L
.1979 .21301 L
.2006 .21076 L
.20299 .20913 L
.20564 .20774 L
.20701 .20719 L
.2083 .20678 L
.20966 .20645 L
.21043 .20631 L
.21113 .20621 L
.21232 .2061 L
.21359 .20607 L
.21479 .20611 L
.21588 .20621 L
.21717 .20639 L
.21856 .20666 L
.22109 .2073 L
.2235 .208 L
.22609 .2087 L
.22757 .20902 L
Mistroke
.22893 .20923 L
.23029 .20934 L
.23159 .20934 L
.23296 .20922 L
.23424 .20898 L
.23497 .20878 L
.23564 .20856 L
.23713 .20794 L
.23858 .20715 L
.24016 .20608 L
.243 .20358 L
.24567 .20054 L
.24849 .19664 L
.25354 .18812 L
.26426 .16703 L
.27441 .14807 L
.28352 .13458 L
.29343 .1241 L
.2986 .12011 L
.30408 .11693 L
.30876 .11483 L
.31393 .11297 L
.31659 .11222 L
.31939 .1116 L
.32245 .11108 L
.32526 .11072 L
.33034 .11023 L
.33174 .11013 L
.33322 .11003 L
.33394 .10999 L
.33462 .10996 L
.3359 .10991 L
.33711 .10989 L
.33841 .10989 L
.33964 .1099 L
.34076 .10993 L
.34208 .10998 L
.34351 .11005 L
.34611 .1102 L
.35135 .11052 L
.35423 .11074 L
.35693 .111 L
.36221 .11172 L
.36699 .1125 L
.37631 .11417 L
.38122 .11538 L
.3866 .11695 L
.39184 .1186 L
.39745 .12075 L
.40271 .12333 L
Mistroke
.4075 .12612 L
.41195 .12916 L
.41686 .13342 L
.42193 .13932 L
.42731 .14776 L
.43229 .15859 L
.43696 .17289 L
.43977 .18413 L
.44244 .197 L
.44747 .22779 L
.45287 .27126 L
.45877 .3269 L
.46145 .35124 L
.46435 .37361 L
.46568 .38178 L
.46708 .38861 L
.46828 .39282 L
.4696 .39561 L
.47088 .39642 L
.47205 .39552 L
.4734 .39261 L
.47468 .38808 L
.47586 .38253 L
.47695 .37633 L
.47942 .35932 L
.48489 .31434 L
.49078 .26889 L
.49349 .25198 L
.49634 .23732 L
.4988 .22717 L
.50144 .21867 L
.50398 .21254 L
.50628 .20852 L
.5074 .20705 L
.5086 .20577 L
.50974 .20484 L
.51079 .20422 L
.51202 .20376 L
.51316 .20356 L
.51441 .20358 L
.51576 .20388 L
.51644 .20413 L
.51717 .20448 L
.51851 .20529 L
.52103 .20744 L
.52388 .21077 L
.52646 .21456 L
.53225 .22532 L
.54266 .24964 L
.54779 .2615 L
Mistroke
.55059 .26716 L
.5532 .27164 L
.55544 .27474 L
.55783 .27722 L
.55919 .27822 L
.56048 .2789 L
.56164 .27929 L
.5629 .27947 L
.56425 .27939 L
.56552 .27908 L
.56625 .27881 L
.56691 .2785 L
.56841 .27761 L
.57126 .27531 L
.57426 .27227 L
.57977 .26612 L
.58477 .26095 L
.58994 .25667 L
.59481 .25374 L
.59996 .25154 L
.60553 .24945 L
.61557 .24454 L
.62482 .23883 L
.62974 .23603 L
.63245 .23477 L
.63379 .23426 L
.63502 .23386 L
.63616 .23356 L
.63741 .23329 L
.63867 .23309 L
.64001 .23296 L
.64113 .23291 L
.64235 .23291 L
.6435 .23296 L
.64456 .23303 L
.64582 .23316 L
.64716 .23334 L
.64959 .23371 L
.65224 .23414 L
.65363 .23435 L
.65511 .23455 L
.65585 .23462 L
.65667 .23469 L
.65741 .23474 L
.65811 .23476 L
.65947 .23475 L
.66024 .2347 L
.66094 .23463 L
.66224 .23443 L
.66297 .23427 L
Mistroke
.66366 .23409 L
.66624 .23314 L
.66759 .23246 L
.66902 .23161 L
.67157 .22977 L
.67734 .22448 L
.68779 .21344 L
.69229 .20941 L
.69481 .20764 L
.69711 .20639 L
.69841 .20584 L
.69983 .20537 L
.70116 .20505 L
.7024 .20485 L
.70354 .20474 L
.70479 .2047 L
.7061 .20474 L
.70733 .20484 L
.71268 .20589 L
.71766 .20721 L
.71895 .2075 L
.72017 .20771 L
.72085 .2078 L
.72158 .20788 L
.72285 .20792 L
.72354 .2079 L
.72429 .20785 L
.72507 .20774 L
.72581 .20759 L
.72712 .20721 L
.72853 .20664 L
.72982 .20596 L
.73102 .20519 L
.73374 .20296 L
.73869 .19725 L
.74318 .19037 L
.74796 .18167 L
.75819 .16169 L
.76898 .14302 L
.77463 .13514 L
.78082 .12827 L
.78651 .12318 L
.79169 .11941 L
.7971 .11645 L
.80222 .11435 L
.80808 .11236 L
.81065 .11163 L
.81349 .111 L
.81593 .11059 L
.81822 .11031 L
Mistroke
.82324 .10981 L
.82585 .10957 L
.82833 .10936 L
.8297 .10927 L
.83048 .10923 L
.8312 .1092 L
.83247 .10918 L
.83382 .1092 L
.83512 .10924 L
.83586 .10928 L
.83655 .10932 L
.83944 .10954 L
.84461 .10993 L
.8475 .11013 L
.84892 .11025 L
.85024 .1104 L
.85175 .1106 L
.8534 .11089 L
.85628 .11154 L
.86654 .11437 L
.86904 .11522 L
.87173 .1164 L
.87468 .11813 L
.87745 .12018 L
.87997 .12238 L
.88265 .12513 L
.88497 .12795 L
.88749 .13176 L
.89045 .13771 L
.89325 .14535 L
.89597 .15518 L
.89848 .16676 L
.9036 .19987 L
.90651 .22611 L
.90923 .2566 L
.91468 .33352 L
.91756 .37785 L
.92063 .42064 L
.92216 .438 L
.9236 .45087 L
.92489 .45905 L
.92562 .46213 L
.92629 .46395 L
.92751 .4647 L
.92884 .46176 L
.92952 .45881 L
.93024 .45462 L
.93154 .44451 L
.93288 .43114 L
.93433 .41375 L
Mistroke
.93696 .37712 L
.94191 .30511 L
.94681 .24665 L
.94929 .22443 L
.95202 .20513 L
.95434 .19235 L
.95684 .18169 L
.9592 .17415 L
.96137 .16909 L
.96261 .1669 L
.96379 .16526 L
.96485 .16412 L
.96599 .1632 L
.96724 .16252 L
.96856 .16213 L
.96969 .16201 L
.97093 .16208 L
.97209 .16231 L
.97315 .16264 L
.97437 .16315 L
.97553 .16377 L
.97758 .16517 L
.97982 .16717 L
.98249 .17026 L
.9849 .17376 L
.9903 .1838 L
1 .20899 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool007[ooooo4Ol0000Sooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0H?oooolAo`0003oooooo001gooooo`Co00004?ooool6o`0001Wooooo00Go
0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo05cooooo1?l0000Aooooo`;o0000
?Oooool007Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Fooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo01Gooooo
0_l0000kooooo`00M?ooool2o`0001cooooo1?l0000Oooooo`03o`000?oooooooooo05Wooooo0_l0
000Jooooo`03o`000?oooooooooo03Sooooo001cooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool0=oooool007?ooooo00?o0000ooooooooool08Oooool2o`0001cooooo00?o0000oooo
ooooool0Eoooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo03Kooooo001booooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool06Oooool2o`0005Oooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0fooooo`00LOooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo03Gooooo001`ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0=Ooo
ool0073ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo05Cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0dooooo`00Koooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Doooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo03Cooooo001^ooooo`03o`000?oooooooooo02co
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool0<oooool006gooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0cooooo`00KOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0DOooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03;ooooo001/
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool04oooool2o`0005;ooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`0booooo`00K?ooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo03;ooooo001[ooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool05?ooool2o`0001cooooo000Eooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h06_ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0Kooooo`Go00000oooool01Oo^k^ko0000o`000?lb<S;ok^k^01cooooo1?l000002?l@413o
ooooooooooo^k^ko<S8bo`000?lb<S;ok^k^2Oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo01oooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^6_ooool5o`00
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05oiRHV?l@413o0000oc8b<_o<c<`00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`02o`000004ooooool0003o0000oa0@40?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>oooo
o`005_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01Ol@
413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@00oooool01Ol0003oV9RHoooooonHV9SoMgMg01kooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Wooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0J
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOo0000oooooonHV9SoMgMg01_ooooo
00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko00000_ooool5o`0000?ooooo00Go410@oooo
oooooooooooooa0@400Booooo`Ko00001_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o
410@ooooooooool04Oooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol0003ooooooooo
oooooooo410@01?ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@4009ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41006oooool00onHV9So8B4Qonk^kP04oooo
o`05oa0@4?l0003oooooooooool@41007oooool01Ol0003ooooooooooooooooo410@00?ooooo00Co
410@oooooooooooo00004oooool00ol0003oooooooooo`02ooooo`Go00000oooool01Ol@413ooooo
oooooooooooo410@00kooooo000Cooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000oooooooo
ooooooooo`00000Mooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000M
ooooo`03oiRHV?lQ8B7ok^k^00;ooooo0_l00003ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Looooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03
ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool00oooool01?m4A4CogMgMo`000?l00004ooooo`05o`000?oooooo
ooooooooool000003_ooool001?ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooo
oooooooo000001cooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000001ko
oooo00CoMgMgofIVI_oooooooooo0_l00003ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
000Mooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`03oa0@
4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool00oooool01?oMgMgoEEEEo`000?l00004ooooo`05o`000?oooooooooo
ooooool000003_ooool001Cooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo
410@01gooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@01oooooo00Go
0000ooooool0003ooooooa0@4003ooooo`03oa0@4?oooooooooo01cooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000ooooooooool04?ooool2o`0002;o
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01kooooo00Go0000oooo
ooooooooooooo`000003ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Oooool00_ooool0
1Ol@413ooooooooooooooooo410@00;ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`05ooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@400>ooooo`005?oo
ool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01Ol@413oV9RH
oooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`06o`000?nj^[[ooooo
oiRHV?l@413o00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Joooo
o`05o`000?nj^[[ooooooiRHV?l@41000_ooool01_l0003oMgMgoiRHV?ooooooV9RHogMgMa_ooooo
00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo00Cok^k^odA4A?l0003o00000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000Eooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0Jooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01_ooooo00KoV9RHoa0@4?l0003o8B4Qolc<c?l00002ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h07?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01oooooo00?oEEEEofIVI_l00000
1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00goV9RHoa0@4?l0003o8B4Qolc<c?oooooo
0000ooooooo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00Kooooo00?oMgMgo`000?l000000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo001V
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1:
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01?ooooo001Vooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01?ooooo001Uooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo01?ooooo001Uooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`18ooooo`;o0000<oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool04_ooool006Cooooo00?o0000ooooooooool0??oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04_oo
ool001Koooooool00010o`0001?ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool4o`0000;ooooo2?l00002ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ool000001?ooool2o`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo0_l000000ooooooo0000ooooo`03ooooo`Go00001Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`00
00Kooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Aooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool01Oooool2o`0000Go
oooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`00
00Kooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Aooooo`005_ooool00ol0003oooooooooo`0kooooo`;o0000C_ooool00ol0003o
ooooooooo`0>ooooo`;o00001_ooool00ol0003oooooooooo`0`ooooo`;o0000A?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo023ooooo000Gooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool08Oooool001Oooooo00?o0000ooooooooool0>?ooool00ol0003ooooooooo
o`1?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0Qooooo`005oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo053ooooo00?o0000
ooooooooool03Oooool2o`0000Wooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`16
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool08Oooool001Oooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo00gooooo0_l00009oooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo027ooooo000Hooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0D_ooool00ol0003oooooooooo`0=ooooo`;o00002_ooool00ol0003oooooooooo`0Xooooo`;o
0000BOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo027ooooo000Hooooo`03o`00
0?oooooooooo03;ooooo0_l0001Eooooo`03o`000?oooooooooo00gooooo0ol00009ooooo`03o`00
0?oooooooooo01cooooo3?l0001;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
8Oooool001Sooooo00?o0000ooooooooool0:Oooool:o`0005Kooooo00?o0000ooooooooool03Ooo
ool2o`0000[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Eooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool08_ooool001Sooooo00?o0000ooooooooool05?ooool3
o`00013ooooo0_l0001Qooooo`03o`000?oooooooooo00cooooo0_l0000;ooooo`03o`000?oooooo
oooo01Sooooo0_l0001Hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08_ooool0
01Wooooo00?o0000ooooooooool04Oooool2o`0000?ooooo0_l0000<ooooo`;o0000Hoooool00ol0
003oooooooooo`0<ooooo`;o00002oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
05Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Rooooo`006Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00Cooooo0_l00009ooooo`03o`000?oooooooooo06?o
oooo00?o0000ooooooooool02oooool00ol0003oooooo`00000;ooooo`03o`000?oooooooooo01Co
oooo0ol0001Looooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08_ooool001Wooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000000cooooo
00?o0000ooooooooool04Oooool2o`0005oooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Rooooo`006Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo0_l0
0004ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool02oooool00ol0003oooooo`00
000<ooooo`03o`000?oooooooooo00oooooo0_l0001Qooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool08_ooool001[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0:
ooooo`Go0000J?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000000gooooo00?o0000
ooooooooool03?ooool2o`0006?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0R
ooooo`006_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo07Sooooo00?o0000oooo
ooooool02oooool01?l0003oooooo`000?l0000<ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0Hoooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;ooooo000Joooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`09oooo
o`04o`000?ooooooooooo`0000kooooo00?o0000ooooooooool02?ooool2o`0006Kooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Rooooo`006_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo07[ooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool0000>
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo02;ooooo000Jooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool0N_ooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0000oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool08_ooool001_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1koooo
o`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo00004?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0R
ooooo`006oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo07_ooooo00?o0000oooo
ooooool02Oooool01?l0003oooooooooool0000Aooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0J?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;ooooo000Koooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`09oooo
o`04o`000?ooooooooooo`00017ooooo0_l000000ooooooo0000o`00001/ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool08oooool001_ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`1looooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo00004_ooool3
o`0006gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Sooooo`006oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool02?ooool01?l0
003oooooooooooooool2o`00087ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0S
ooooo`007?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07kooooo00?o0000oooo
ooooool01oooool01Ol0003ooooooooooooooooo000008;ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Sooooo`007?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
07kooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo000008;ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Sooooo`007?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo07oooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo
000008;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Sooooo`007Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool01oooool01Ol0
003ooooooooooooooooo000008;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0S
ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07oooooo00?o0000oooo
ooooool01oooool01Ol0003ooooooooooooooooo000008;ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Sooooo`007Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
083ooooo00?o0000ooooooooool01Ol00002ooooo`05o`000?ooooooooooooooool00000P_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo02?ooooo000Nooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0P?ooool02_l0003ooooooooooonHV9So8B4Qonk^k_ooooooA4A4
ooooool00004ooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Sooooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo083ooooo
00Oo0000oooooooooooooooooiRHV?lQ8B7ok^k^00;ooooo00?o0000ooooooooool00_ooool3o`00
083ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Sooooo`007_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool00_ooool01OnHV9So
8B4Qonk^k_oooooo000000Cooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo02?ooooo000Oooooo`05o`000?ooooooooooooooool00000Q?ooool00ol0
003oooooooooo`02ooooo`04ogMgMomVIVKoooooo`0000Cooooo00?o0000ooooooooool0P?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo02?ooooo000Oooooo`04o`000?oooooooooo
o`0008Gooooo00?o0000ooooooooool00oooool00ol0003oooooo`000004ooooo`03o`000?oooooo
oooo087ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Sooooo`007oooool4o`00
08Gooooo00Wo0000ooooool0003o^[ZjoooooonHV9So410@ooooool000001?ooool00ol0003ooooo
ooooo`21ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08oooool00:Sooooo00Wo
0000oooooonHV9So410@o`000?lQ8B7oc<c<ooooool000001?ooool00ol0003oooooooooo`21oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08oooool00:Sooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo087ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Tooooo`00Z?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo02Cooooo002Xooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool2o`0008;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Tooooo`00Z?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0POooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Cooooo002Xooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool09?ooool00:Wooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Tooooo`00ZOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0POooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Cooooo
002Yooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`21ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09?ooool00:Wooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo087ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Tooooo`00ZOooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo02Cooooo002Yooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool09?ooool00:Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`;o0000
Poooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Gooooo002Zooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool09Oooool00:[ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo08;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Uooooo`00Z_oo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0P_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo02Gooooo002Zooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
9Oooool00:[ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo08;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Uooooo`00Z_ooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo02Gooooo002Zooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0
P_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Gooooo002Zooooo`04o`000?oo
ooooooooo`0000Oooooo0_l00023ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
9Oooool00:[ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`22ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool09Oooool00:_ooooo0_l00008ooooo`03o`000?oo
oooooooo08;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Uooooo`00Zoooool2
o`0000Sooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo02Kooooo002eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Vooooo`00[?ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000oooooooo
ool0Poooool01Ol0003ooooooooooooooooo000002Sooooo002]ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0Poooool01Ol0003ooooooooooooooooo000002Sooooo002Zooooo`Go
00001_ooool00ol0003oooooooooo`23ooooo`05o`000?ooooooooooooooool00000:?ooool00:[o
oooo00CoA4A4omgMgOoooooo00001oooool3o`0008?ooooo00Go0000ooooooooooooooooo`00000X
ooooo`00Z_ooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo08?ooooo00Go0000
ooooooooooooooooo`00000Xooooo`00Zoooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooo
oooo08?ooooo00Go0000ooooooooooooooooo`00000Xooooo`00Zoooool00oo^k^koA4A4o`000007
ooooo`03o`000?oooooooooo08?ooooo00Go0000ooooooooooooooooo`00000Xooooo`00[?ooool0
0omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo08?ooooo00Go0000ooooooooooooooooo`00
000Xooooo`00]Oooool00ol0003oooooooooo`23ooooo`05o`000?ooooooooooooooool00000:?oo
ool00;Gooooo00?o0000ooooooooool0Poooool01Ol0003ooooooooooooooooo000002Sooooo002e
ooooo`03o`000?oooooooooo08?ooooo00Go0000ooooooooooooooooo`00000Xooooo`00]Oooool2
o`0008Cooooo00Go0000ooooooooooooooooo`00000Xooooo`00]Oooool00ol0003oooooooooo`23
ooooo`04o`000?ooooooooooo`0002Wooooo002eooooo`03o`000?oooooooooo08?ooooo00Co0000
oooooooooooo0000:Oooool00;Gooooo00?o0000ooooooooool0Q?ooool00ol0003oooooo`00000Y
ooooo`00]Oooool00ol0003oooooooooo`24ooooo`03o`000?oooooo000002Wooooo002eooooo`03
o`000?oooooooooo08Cooooo00?o0000ooooool00000:Oooool00;Gooooo00?o0000ooooooooool0
Q?ooool00ol0003oooooo`00000Yooooo`00]Oooool00ol0003oooooooooo`24ooooo`03o`000?oo
oooo000002Wooooo002eooooo`;o0000QOooool2o`0002[ooooo002eooooo`03o`000?oooooooooo
08Gooooo00?o0000ooooooooool0:?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Oo^k^ko<S8bo`00
0?l@413oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00GoEEEEogMgMoooooooV9RH
ob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo
0ol0002`ooooo`00Z_ooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`2`ooooo`00Z_ooool0
0ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`04olc<c?m4A4Co0000
oa0@40Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0
002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00:[ooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooo
oooo0;3ooooo002Zooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2`
ooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0/?ooool0
0:[ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000/?ooool00:[ooooo00Goc<c<o`00
0?l0003o0000olc<c02iooooo`00Z_ooool01Ol@413o^[Zjoooooonj^[[o410@0;Wooooo002Zoooo
o`05o`000?nj^[[ooooookZj^_l00000^Oooool00:[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2i
ooooo`00oooooomYooooo`00[oooool00ol0003o^[Zjooooo`2fooooo`00[oooool2oc8b<[Oooooo
0020ooooo`;o000000Ko410@oooooooooooo410@o`000?l@410Hooooo`05odA4A?l0003o0000oc8b
<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?oQhN7o`000?nj^[X03?ooool0
1OnHV9So0000o`000?m4A4Co^[Zj01Wooooo1?l000001?l@413oooooooooooooool4o`000003oa0@
4?oooooooooo00;ooooo0_l000000ol@413oooooooooo`1fooooo`00POooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Oooooo1_l0000=ooooo`09ogMgMolb<S;ooooooooooomgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo
410@00Wooooo1_l0000<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1gooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01_ooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`0@ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`Go0000N?ooool0
087ooooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00003Oooool01OmgMgOo<S8boooo
oooooooo000000?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`Ko0000
3?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00CoA4A4omgMgOoooooo
0000NOooool0087ooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Iooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00CogMgMoeEEEOoooooo0000
NOooool0087ooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Iooooo`03o`000?oooooooooo00Co
oooo00Go410@oooooooooooooooooa0@400@ooooo`03oa0@4?l0003o000000?o00007?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?oMgMgolc<c?l00000NOooool0087o
oooo00Ko0000oc8b<_oooooooooooc8b<_l0000Iooooo`03o`000?oooooooooo00Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0Booooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`03ooooo`03onk^k_m4A4Co000007Wooooo0020ooooo`03oa0@4?l0003o
QhN700;ooooo00?oQhN7o`000?l@41006?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0Booooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000001Oooool00omEEEGoIVIVo`00
0006ooooo`03ogMgMol0003ooooo07Sooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(116) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .20641 m
.00236 .20856 L
.00488 .21155 L
.00942 .21872 L
.01483 .23011 L
.01975 .24299 L
.03057 .27599 L
.03533 .28878 L
.03803 .29453 L
.04057 .29861 L
.0419 .30021 L
.04312 .30133 L
.04379 .30181 L
.04452 .30221 L
.04586 .30264 L
.0466 .30271 L
.04727 .30267 L
.04804 .30252 L
.04877 .30227 L
.05007 .30157 L
.0508 .30105 L
.05147 .30049 L
.05422 .2976 L
.05723 .29359 L
.06331 .28494 L
.06868 .27869 L
.07168 .27611 L
.07443 .27432 L
.07698 .27304 L
.07976 .27196 L
.08481 .27025 L
.08726 .26926 L
.0899 .2679 L
.09468 .26442 L
.10036 .25879 L
.10557 .25313 L
.1107 .24826 L
.11211 .2472 L
.11361 .24624 L
.11503 .24551 L
.11632 .24503 L
.11702 .24483 L
.11777 .24468 L
.11911 .24457 L
.11985 .24458 L
.12055 .24466 L
.12132 .24479 L
.12214 .24501 L
.12284 .24525 L
.12361 .24556 L
Mistroke
.12501 .24628 L
.12763 .24804 L
.13276 .25243 L
.13545 .2548 L
.13829 .25695 L
.1395 .25769 L
.14079 .25833 L
.14153 .25861 L
.1422 .25882 L
.14352 .25905 L
.14471 .25907 L
.14599 .25885 L
.14721 .25842 L
.14833 .25783 L
.1497 .25684 L
.151 .25566 L
.15394 .25211 L
.15989 .24225 L
.1649 .23298 L
.16754 .2284 L
.17036 .22409 L
.17318 .22065 L
.1745 .21937 L
.17573 .21842 L
.17696 .21768 L
.17829 .21713 L
.17947 .21688 L
.18071 .21685 L
.18201 .21706 L
.18339 .21756 L
.1847 .21828 L
.1859 .21913 L
.18882 .2219 L
.1916 .2252 L
.19611 .23116 L
.19858 .23427 L
.2009 .23675 L
.20221 .23787 L
.2034 .23868 L
.20473 .23931 L
.20543 .23952 L
.20617 .23963 L
.20737 .23958 L
.20849 .23926 L
.20972 .2386 L
.21104 .23752 L
.21233 .23608 L
.21375 .23408 L
.21662 .22877 L
.22178 .21573 L
Mistroke
.23343 .17913 L
.23909 .16263 L
.24447 .14942 L
.24971 .13907 L
.25458 .13149 L
.2593 .12578 L
.26433 .12118 L
.26991 .11747 L
.27497 .11505 L
.2778 .11403 L
.2804 .11326 L
.2832 .1126 L
.28627 .11204 L
.28894 .11166 L
.29144 .11138 L
.29408 .11117 L
.29555 .11108 L
.2969 .11102 L
.29814 .11099 L
.2993 .11097 L
.30058 .11096 L
.30195 .11097 L
.30332 .11099 L
.304 .11101 L
.30475 .11103 L
.30732 .11113 L
.30973 .11126 L
.31231 .11143 L
.31696 .11182 L
.32283 .11251 L
.32838 .11332 L
.33876 .1152 L
.34898 .11769 L
.35979 .1211 L
.36902 .12484 L
.37917 .12987 L
.40132 .1438 L
.42155 .15749 L
.43156 .16505 L
.43723 .17065 L
.44248 .17766 L
.44753 .18699 L
.4521 .19861 L
.45737 .21702 L
.46233 .24012 L
.47262 .30339 L
.47534 .32081 L
.47824 .3377 L
.48098 .3507 L
.48228 .35554 L
Mistroke
.48347 .35913 L
.48458 .36166 L
.48576 .36347 L
.48694 .36438 L
.48824 .36432 L
.48935 .36339 L
.49056 .36153 L
.4917 .35902 L
.49274 .35612 L
.49522 .34724 L
.49794 .33525 L
.50289 .31099 L
.50846 .28579 L
.5112 .27559 L
.51371 .26767 L
.51843 .2565 L
.52091 .25231 L
.52353 .24893 L
.52615 .24643 L
.5276 .24536 L
.52896 .24452 L
.53023 .24387 L
.53161 .24328 L
.53286 .24286 L
.53403 .24254 L
.53541 .24226 L
.53614 .24215 L
.53693 .24207 L
.53771 .24201 L
.53854 .24199 L
.53924 .242 L
.54001 .24204 L
.5414 .24218 L
.54218 .24231 L
.54288 .24245 L
.54426 .2428 L
.54555 .24323 L
.54806 .24435 L
.55041 .24575 L
.55299 .24771 L
.55575 .25031 L
.56656 .26402 L
.56904 .2673 L
.57175 .27052 L
.57414 .27287 L
.57545 .27392 L
.57668 .27472 L
.57789 .27533 L
.5792 .27576 L
.58039 .27594 L
Mistroke
.58148 .27593 L
.58251 .27576 L
.58364 .2754 L
.58483 .27483 L
.58593 .27413 L
.62682 .25361 L
.62812 .25437 L
.6295 .25509 L
.63082 .25564 L
.63202 .256 L
.63329 .25623 L
.63464 .25627 L
.63602 .25609 L
.6368 .25587 L
.63753 .2556 L
.63906 .2548 L
.64045 .2538 L
.64357 .25065 L
.64645 .24676 L
.64916 .24243 L
.65943 .22506 L
.66193 .22169 L
.66461 .21883 L
.66614 .21759 L
.66755 .21673 L
.66822 .21642 L
.66896 .21614 L
.6703 .21584 L
.67159 .21579 L
.67281 .21596 L
.67415 .21638 L
.6749 .21672 L
.67559 .21709 L
.67833 .21913 L
.68122 .22207 L
.68646 .22843 L
.68902 .23147 L
.69134 .23386 L
.69244 .23481 L
.69364 .23567 L
.69477 .2363 L
.69581 .23671 L
.69692 .23693 L
.69813 .23693 L
.6994 .23663 L
.70059 .23605 L
.7019 .23508 L
.70314 .23383 L
.70548 .23062 L
.70799 .226 L
Mistroke
.71073 .21974 L
.72226 .18594 L
.73312 .15561 L
.74287 .13623 L
.74836 .12852 L
.75341 .1231 L
.75834 .11911 L
.76294 .11631 L
.76799 .11398 L
.7734 .11219 L
.77611 .11154 L
.77907 .111 L
.78186 .11061 L
.78444 .11034 L
.78676 .11015 L
.78808 .11007 L
.78932 .11001 L
.79062 .10996 L
.79182 .10994 L
.79313 .10994 L
.79451 .10996 L
.7958 .11 L
.79654 .11003 L
.79721 .11006 L
.79976 .11022 L
.80453 .11066 L
.80974 .11128 L
.81524 .1122 L
.82443 .11426 L
.83453 .11703 L
.85495 .12427 L
.87689 .13382 L
.88754 .13972 L
.89355 .14416 L
.89913 .14985 L
.9019 .15344 L
.9045 .15746 L
.90936 .16738 L
.91209 .17492 L
.91459 .18349 L
.91755 .19604 L
.92024 .21015 L
.92519 .24405 L
.9305 .29295 L
.93546 .34714 L
.94005 .39412 L
.94265 .41408 L
.94396 .42134 L
.9447 .42451 L
.9454 .4268 L
Mistroke
.94615 .42852 L
.94686 .42943 L
.9482 .4292 L
.94895 .42799 L
.94964 .42618 L
.9504 .42347 L
.95121 .41978 L
.95258 .41184 L
.95406 .40112 L
.95675 .37749 L
.96177 .32755 L
.96604 .28847 L
.97062 .25558 L
.97325 .24119 L
.97565 .23063 L
.97793 .22262 L
.98035 .21599 L
.98286 .21092 L
.98518 .2076 L
.98647 .20626 L
.98768 .20528 L
.98901 .20448 L
.98975 .20415 L
.99044 .20392 L
.99159 .20367 L
.99266 .20359 L
.99384 .20365 L
.99509 .20388 L
.99642 .20431 L
.99766 .20489 L
1 .20641 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool0077ooooo2ol0000booooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0DooooolAo`0004cooooo001]ooooo`Co00002oooool9o`0002Gooooo00Go
0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0
3oooool3o`0004Wooooo001[ooooo`;o00006?ooool3o`0002;ooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c006ooooo`03o`000?oooooooooo053ooooo0_l0000Eooooo`?o0000A_ooool006[ooooo00?o
0000ooooooooool06oooool3o`0002[ooooo00?o0000ooooooooool0Coooool00ol0003ooooooooo
o`0Hooooo`?o0000@oooool006Wooooo00?o0000ooooooooool07oooool2o`0002Sooooo00?o0000
ooooooooool0C_ooool00ol0003oooooooooo`0Looooo`?o0000@?ooool006Sooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo04gooooo00?o0000oooo
ooooool08?ooool3o`0003gooooo001Xooooo`03o`000?oooooooooo02?ooooo0_l0000Uooooo`;o
0000COooool00ol0003oooooooooo`0Tooooo`;o0000>oooool006Oooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0
9oooool2o`0003Wooooo001Vooooo`03o`000?oooooooooo02Sooooo0_l0000Rooooo`03o`000?oo
oooooooo04[ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0fooooo`00IOooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0B_ooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03Gooooo001Uooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool0=?ooool006Cooooo00?o0000ooooooooool0;_ooool2o`0001ko
oooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0^ooooo`;o0000=?ooool006Cooooo
00?o0000ooooooooool0<?ooool2o`0001cooooo00?o0000ooooooooool0B?ooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo037ooooo001Tooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool0<Oooool006?ooooo00?o0000ooooooooool0=?ooool2o`0001Wooooo0_l00018
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0<?ooool006?ooooo00?o0000oooo
ooooool0=_ooool2o`0001Oooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo02oooooo001Sooooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0;oooool001Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0J
ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo
1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h07?ooool4o`000008oa0@4?ooooooooooonk^
k_lb<S;o0000oc8b<_o^k^h8ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool07ooo
ool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hJooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^01_ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`0Eooooo`;o000000Wo410@oooooooooooo
ooooonk^k_lb<S;o0000oc8b<_o^k^h03_ooool001Kooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg01[ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL06oooool01Ol0003o8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`09
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01OnHV9So0000onk^k_ooooooA4A400?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool000_ooooo1_l00002ooooo`Go00000oooool0
1Ol@413ooooooooooooooooo410@01;ooooo1_l00006ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`0Aooooo`Ko000000Koooooo`000?ooooooV9RHob4Q8Oo^k^h4oooo
o`05oa0@4?ooooooooooooooool@41004oooool6o`0000Gooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@00[ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Kooooo`03o`00
0?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400Oooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo1Ol00003oooo
o`05oa0@4?ooooooooooooooool@41003_ooool001?ooooo00CoA4A4omgMgOoooooo00001?ooool0
1Ol0003ooooooooooooooooo000001gooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooo
oooooooo000001[ooooo00Ko0000ooooooooooooV9RHob4Q8Oo^k^h3ooooo`05o`000?oooooooooo
ooooool000007_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000002ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000001[ooooo00Go0000oooooonHV9So8B4Qonk^kP03ooooo`05
o`000?ooooooooooooooool000007_ooool00onYZJWo410@ooooo`02ooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`0Booooo`04odA4A?oMgMgoooooo`0000Cooooo00Go
0000ooooooooooooooooo`00000>ooooo`004oooool01?oMgMgoEEEEooooool00004ooooo`05o`00
0?ooooooooooooooool000007?ooool00ol@413o0000okZj^P03ooooo`05o`000?oooooooooooooo
ool000006_ooool01_l0003oooooooooooooooooMgMgofIVIP?ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000<ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000006_ooool01Ol0003ooooooooooomgMgOoIVIV00?ooooo00Go0000
ooooooooooooooooo`00000Mooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo01;ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003o
oooooooooooooooo000000kooooo000Dooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooo
oooooooooa0@400Mooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@400I
ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oo
oooooooo01cooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00cooooo
00?o0000ooooooooool03oooool2o`0002;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@01[ooooo00Go0000ooooooooooooooooo`000003ooooo`05oa0@4?oooooooooo
ooooool@41007_ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41001ooo
ool00ol0003oooooooooo`0Booooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooo
oa0@400>ooooo`005?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
6_ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Ioooo
o`07o`000?oooooo0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
7_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg01Wooooo0_l000001?nj^[[ooooooiRHV?l@4103ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL06oooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`07ooooo`03o`000?oooooooooo01;ooooo00?ok^k^odA4A?l000001?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00kooooo000Eooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0Jooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^01Sooooo00So0000ooooooooooooV9RHoa0@4?l0003o8B4Qolc<c0?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Looooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool07oooool00omEEEGoIVIVo`00
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06Oooool01_l0003oV9RHoa0@4?l0003o8B4Qolc<
c0?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00?o0000ooooooooool04oooool00omgMgOo0000
ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool005oooooo00?o0000ooooooooool0
@_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0
>_ooool00ol0003oooooooooo`0/ooooo`00Goooool00ol0003oooooooooo`13ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0looooo`03o`000?oo
oooooooo02_ooooo001Nooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`13ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0:oooool0
05kooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
04?ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0[ooooo`00G_ooool00ol0003o
ooooooooo`15ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0@_ooool00ol0003o
ooooooooo`0mooooo`03o`000?oooooooooo02_ooooo000Foooooooo0000@?l0000Cooooo`005_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00006ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`0Aooooo`005_ooool2o`0000Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Oo
oooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
017ooooo000Hooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0B?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo03?ooooo0_l0000<ooooo`03o`000?oooooooooo03oo
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Fooooo`006Oooool00ol0003ooooo
ooooo`0booooo`?o00002oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0<Oooool5o`0000_ooooo00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo01Oooooo000Iooooo`03o`000?oooooooooo037ooooo00Co
0000oooooooooooooooo0_l00009ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00?ooooo0_l00008ooooo`03o`00
0?oooooooooo043ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Gooooo`006Ooo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0@?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Sooooo000Jooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo04[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool06?ooool001[ooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0B_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo00[o
oooo0_l0000_ooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000015oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool06Oooool001_ooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0004oooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Wooooo1?l00016oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool06Oooool001_ooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`0:ooooo`?o0000D?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo01Wooooo000Looooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
GOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo1Ol0000Pooooo`03o`00
0?oooooooooo05Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Iooooo`007?oo
ool00ol0003oooooooooo`0Jooooo`Go00002oooool00ol0003oooooooooo`1Mooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool01Oooool2o`0000Gooooo0_l0000Nooooo`03o`000?oo
oooooooo05Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Iooooo`007?ooool0
0ol0003oooooooooo`0Iooooo`;o00001?ooool2o`0000Sooooo00?o0000ooooooooool0G_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool2
o`0001cooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo01Wooooo000Mooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04_ooool2o`00
00Gooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
01[ooooo000Mooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03oooool2o`0000;o
oooo1Ol0001Iooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool06_ooool001gooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`09ooooo`Co0000I?ooool00ol0003ooooo
ooooo`08ooooo`;o00001?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo
0_l0001Sooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool001kooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo0_l0
001Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool001kooooo00?o0000
ooooooooool04_ooool2o`0007Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1U
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool001kooooo00?o0000oooo
ooooool04?ooool2o`0007Oooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo
0000017ooooo00?o0000ooooooooool01Oooool2o`0006Sooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Kooooo`007_ooool00ol0003oooooooooo`0>ooooo`?o0000N?ooool00ol0
003oooooooooo`08ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`02
ooooo`;o0000J_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01_ooooo000Ooooo
o`03o`000?oooooooooo00_ooooo0_l0001looooo`03o`000?oooooooooo00Oooooo00Co0000oooo
oooooooo00004oooool3o`000003ooooool0003ooooo06_ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Kooooo`007oooool00ol0003oooooooooo`0:ooooo`;o0000OOooool00ol0
003oooooooooo`07ooooo`04o`000?ooooooooooo`0001Gooooo0_l0001]ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool06oooool001oooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`1mooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo0000Q?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01_ooooo000Pooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`07ooooo`;o000000?oooooo`00
0?ooool0Q?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01cooooo000Pooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`07ooooo`04
o`000?ooooooooooo`0008Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Loooo
o`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07oooooo00?o0000oooooooo
ool01oooool01?l0003oooooooooool00025ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool07?ooool0027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`20ooooo`03
o`000?oooooooooo00Oooooo00Co0000oooooooooooo0000QOooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo01cooooo000Rooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0P_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo000008Kooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Looooo`008oooool01?l0003oooooooooool00025ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooool00000Q_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo01cooooo000Sooooo`Co0000Poooool5o`0000Kooooo00?o0000ooooool00000
Q_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01cooooo002Zooooo`05oiRHV?lQ
8B7o0000oooooom4A4@01_ooool00ol0003oooooo`000026ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool07?ooool00:_ooooo00?oV9RHo`000?o^k^h01oooool3o`0008Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Looooo`00[?ooool00ol0003o8B4Qonk^kP06
ooooo`;o0000R?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01gooooo002]oooo
o`03o`000?mVIVKooooo00Gooooo0_l00028ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool07Oooool00:gooooo0_l00006ooooo`;o0000R?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo01gooooo002Zooooo`05o`000?nj^[[oooooo`000?l@41001_ooool00ol0003o
ooooooooo`27ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07Oooool00:[ooooo
00GoV9RHoa0@4?l0003o0000olc<c006ooooo`03o`000?oooooooooo08Oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Mooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo08Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Mooooo`00[_oo
ool00ol0003oooooooooo`03ooooo`;o0000ROooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo01gooooo002^ooooo`03o`000?oooooooooo00?ooooo0ol00028ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool07Oooool00:kooooo00?o0000ooooooooool00oooool2o`00
08[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Mooooo`00[_ooool00ol0003o
ooooooooo`03ooooo`;o0000R_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01go
oooo002^ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000R_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo01kooooo002_ooooo`07o`000?ooooooooooooooool0003o
ooooo`00002:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07_ooool00:oooooo
00Oo0000ooooooooooooooooo`000?oooooo000008[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Nooooo`00[oooool01ol0003ooooooooooooooooo0000ooooool00000R_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01kooooo002_ooooo`07o`000?oooooooooo
ooooool0003oooooo`00002:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07_oo
ool00;3ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`28ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool07_ooool00;3ooooo0ol00002ooooo`;o0000ROooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo01kooooo002aooooo`05o`000?oooooooooooooo
ool00000R_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01kooooo002eooooo`03
o`000?oooooooooo08Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Oooooo`00
]Oooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
7oooool00;Gooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo01oooooo002eooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Oooooo`00]Oooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool07oooool00;Gooooo00?o0000ooooooooool0ROooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo01oooooo002eooooo`;o0000R_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo01oooooo002eooooo`03o`000?oooooooooo08Wooooo00Go
0000ooooooooooooooooo`00000Rooooo`00]Oooool00ol0003oooooooooo`29ooooo`05o`000?oo
ooooooooooooool000008_ooool00;Gooooo00?o0000ooooooooool0ROooool01Ol0003ooooooooo
oooooooo000002;ooooo002eooooo`03o`000?oooooooooo08Wooooo00Go0000oooooooooooooooo
o`00000Rooooo`00[?ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0ROoo
ool01Ol0003ooooooooooooooooo000002;ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0R_ooool01?l0003oooooooooool0000Rooooo`00Z_ooool5o`0000Kooooo00?o
0000ooooooooool0R_ooool01?l0003oooooooooool0000Rooooo`00Z_ooool01?m4A4CogMgMoooo
ool00007ooooo`?o0000R_ooool01?l0003oooooooooool0000Rooooo`00Z_ooool01?oMgMgoEEEE
ooooool00007ooooo`03o`000?oooooooooo08[ooooo00Co0000oooooooooooo00008_ooool00:_o
oooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`2:ooooo`04o`000?ooooooooooo`00
02;ooooo002[ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0R_ooool01?l0003o
ooooooooool0000Rooooo`00[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo08[o
oooo00?o0000ooooool000008oooool00;Gooooo00?o0000ooooooooool0Roooool2o`0002?ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003o
ooooooooo`2`ooooo`00Z_ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000oooooooo
ool0/?ooool00:[ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;3o
oooo002Zooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`000;3ooooo002Zooooo`05o`00
0?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool00omEEEGoQhN7
ooooo`08ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03omgMgOl@413oV9RH00Sooooo00?o
0000ooooooooool0/?ooool00:_ooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool0
1Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go8B4Q
oiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Olb<S;oV9RHoooooonH
V9So<S8b00Kooooo0ol0002`ooooo`00Z_ooool01Oo<c<co0000o`000?l0003oc<c<0;Wooooo002Z
ooooo`05oa0@4?nj^[[ooooookZj^_l@4100^Oooool00:[ooooo00Go0000okZj^_oooooo^[Zjo`00
002iooooo`00Z_ooool01OnYZJWo410@o`000?l@413oZJVY0;Wooooo003oooooofWooooo002_oooo
o`03o`000?nj^[[ooooo0;Kooooo002_ooooo`;o<S8b]oooool0083ooooo0_l000001_l@413ooooo
ooooool@413o0000oa0@41Sooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X0
6Oooool4o`000004oa0@4?ooooooooooooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o
410@olc<c7Sooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool6
o`0000gooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL00oooool00oo<c<co
0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`02ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40N?ooool0
087ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooooooo
oa0@40?ooooo00?o410@ooooooooool04?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000007Sooooo0021
ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000gooooo00GoMgMgoc8b<_oooooo
ooooo`000003ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02oooool6o`0000co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`05o`000?nHV9SooooooiRH
V?lQ8B40N?ooool0087ooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Iooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Go0000oeEEEOl0003o
410@olc<c01hooooo`00POooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001Wooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@013ooooo00?o410@o`000?l000000ol0000L
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00omEEEGoQhN7ooooo`1j
ooooo`00POooool01_l0003o<S8boooooooooooo<S8bo`0001Wooooo00?o0000ooooooooool01?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00;ooooo00?ogMgMoa0@4?nHV9P0N_ooool0083ooooo00?o
410@o`000?n7QhL00_ooool00on7QhOo0000oa0@400Hooooo`Co00000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^01;ooooo00?o0000ooooooooool06oooool00omEEEGoIVIVo`000005ooooo`03oeEE
EOmVIVKo000000Gooooo00Coc<c<odA4A?l0003o410@N?ooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(118) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .26446 m
.00236 .2593 L
.00365 .25707 L
.00488 .25532 L
.00602 .25397 L
.00726 .25275 L
.00942 .25117 L
.01066 .2505 L
.01203 .24992 L
.01479 .24904 L
.01975 .24778 L
.02493 .2463 L
.02778 .24551 L
.02919 .24519 L
.0305 .24496 L
.03171 .24482 L
.03301 .24479 L
.03375 .24482 L
.03445 .24489 L
.03576 .24516 L
.03696 .24556 L
.03807 .24608 L
.03928 .24683 L
.04057 .24785 L
.04328 .25082 L
.04624 .2554 L
.05161 .26717 L
.0578 .28406 L
.06049 .29121 L
.06345 .29804 L
.06478 .30057 L
.06622 .30281 L
.06758 .3044 L
.06883 .30538 L
.07016 .30589 L
.07091 .30593 L
.07161 .30581 L
.07235 .3055 L
.07303 .30507 L
.07381 .3044 L
.07454 .3036 L
.07711 .29962 L
.07947 .29457 L
.08481 .28048 L
.08925 .26888 L
.0917 .26357 L
.09403 .25964 L
.09534 .25797 L
.09603 .25726 L
.09677 .25664 L
Mistroke
.09807 .25588 L
.09927 .25557 L
.1006 .25566 L
.10185 .25615 L
.10297 .25691 L
.10418 .25806 L
.10666 .26136 L
.10937 .26611 L
.11486 .27708 L
.11731 .28144 L
.11866 .28343 L
.11994 .28497 L
.12113 .28604 L
.12242 .28677 L
.12359 .28702 L
.12468 .28687 L
.12592 .28624 L
.12723 .28506 L
.12834 .28363 L
.12956 .28164 L
.13228 .27572 L
.13481 .26874 L
.14432 .23823 L
.14714 .23052 L
.14981 .22475 L
.15097 .22277 L
.1522 .22106 L
.15355 .21967 L
.15479 .21885 L
.15612 .21846 L
.15686 .21847 L
.15754 .21862 L
.15886 .21931 L
.16011 .22044 L
.16082 .22127 L
.16157 .22231 L
.16291 .22455 L
.16596 .23133 L
.17579 .26186 L
.17848 .2695 L
.17994 .27295 L
.18131 .27556 L
.18248 .27727 L
.18373 .2785 L
.18512 .27909 L
.18638 .27889 L
.18758 .27804 L
.18884 .27642 L
.18992 .27447 L
.19111 .27174 L
Mistroke
.19377 .26362 L
.19625 .25388 L
.20557 .2086 L
.21079 .18422 L
.21648 .1622 L
.22185 .14635 L
.22684 .13554 L
.23178 .12783 L
.23626 .1228 L
.23875 .12064 L
.24143 .11873 L
.2463 .11616 L
.24879 .11521 L
.25147 .1144 L
.25378 .11384 L
.25629 .11337 L
.25782 .11313 L
.25924 .11296 L
.26056 .11282 L
.26202 .1127 L
.26333 .11261 L
.26456 .11256 L
.26585 .11252 L
.26658 .1125 L
.26725 .11249 L
.26854 .11249 L
.26992 .1125 L
.27122 .11253 L
.2724 .11256 L
.27379 .11262 L
.2753 .11269 L
.27803 .11285 L
.2809 .11307 L
.28393 .11337 L
.28937 .11405 L
.29929 .11567 L
.30994 .11813 L
.32 .1212 L
.32918 .12478 L
.35086 .13557 L
.3614 .14106 L
.37095 .14534 L
.37577 .1471 L
.38098 .14866 L
.39041 .15086 L
.39559 .15191 L
.40113 .15321 L
.40636 .15484 L
.41112 .15684 L
.41627 .15974 L
Mistroke
.42114 .1633 L
.43212 .17429 L
.45425 .20147 L
.46443 .21269 L
.47 .21995 L
.47522 .22918 L
.47965 .24001 L
.48443 .2556 L
.49458 .301 L
.49971 .32468 L
.50252 .33524 L
.50391 .33939 L
.50518 .3425 L
.5059 .34393 L
.50669 .34521 L
.50749 .34618 L
.50833 .34687 L
.50904 .34717 L
.5098 .3472 L
.51118 .34652 L
.5119 .34579 L
.51268 .34473 L
.5141 .3421 L
.51548 .33876 L
.51676 .33508 L
.52199 .31614 L
.52763 .29476 L
.53023 .28646 L
.53296 .27938 L
.53529 .27485 L
.53662 .2729 L
.53785 .27149 L
.53907 .27045 L
.5404 .26971 L
.54165 .26935 L
.54281 .26929 L
.54385 .26942 L
.545 .26974 L
.5462 .27025 L
.54732 .27085 L
.5498 .27242 L
.55251 .27416 L
.55375 .27485 L
.55506 .27545 L
.55631 .27586 L
.55744 .27608 L
.55878 .27611 L
.55954 .27602 L
.56024 .27585 L
.56153 .27536 L
Mistroke
.56288 .27456 L
.56411 .27361 L
.56526 .27252 L
.56786 .26942 L
.57323 .26121 L
.57606 .25668 L
.57906 .25237 L
.58178 .24935 L
.58253 .24871 L
.58333 .24813 L
.58402 .24772 L
.58478 .24738 L
.58612 .24703 L
.58685 .247 L
.58754 .24706 L
.58876 .24742 L
.59006 .24814 L
.59141 .24925 L
.59287 .25086 L
.59552 .25478 L
.60047 .26472 L
.6054 .27566 L
.60809 .2808 L
.60941 .28286 L
.61061 .2844 L
.61172 .28549 L
.61276 .28621 L
.61387 .28663 L
.61507 .28666 L
.6163 .28621 L
.61761 .28521 L
.61873 .28393 L
.61996 .28208 L
.62242 .27713 L
.62511 .2701 L
.63053 .25301 L
.63562 .23713 L
.63783 .23122 L
.64024 .22591 L
.6417 .22333 L
.64306 .22144 L
.64435 .22009 L
.64572 .21917 L
.64641 .2189 L
.64716 .21876 L
.6485 .21892 L
.64932 .21927 L
.65011 .21978 L
.65081 .22039 L
.65157 .2212 L
Mistroke
.65296 .22307 L
.65422 .2252 L
.65705 .23132 L
.66213 .24571 L
.66725 .26122 L
.67005 .26829 L
.67141 .27103 L
.67266 .27301 L
.6738 .27435 L
.67489 .27516 L
.67603 .27549 L
.67727 .27523 L
.67855 .27426 L
.67991 .27246 L
.68106 .27031 L
.68234 .2673 L
.68517 .25848 L
.68777 .24824 L
.69362 .22084 L
.69874 .19619 L
.7042 .17284 L
.7096 .1543 L
.7145 .1414 L
.71943 .13175 L
.72408 .12512 L
.72672 .12221 L
.72951 .11968 L
.73451 .11628 L
.73729 .11491 L
.7399 .11391 L
.74275 .11308 L
.74436 .11271 L
.74582 .11243 L
.74849 .11204 L
.74996 .11188 L
.75134 .11177 L
.75262 .1117 L
.7538 .11166 L
.7551 .11163 L
.75646 .11164 L
.75784 .11167 L
.75862 .1117 L
.75932 .11173 L
.7607 .11181 L
.76199 .11191 L
.7649 .1122 L
.76806 .1126 L
.77903 .11456 L
.78917 .11704 L
.83046 .12904 L
Mistroke
.84108 .13214 L
.85119 .13548 L
.87016 .14429 L
.87989 .15051 L
.89052 .15822 L
.90201 .16642 L
.91244 .17288 L
.91754 .17601 L
.92306 .18014 L
.92559 .18252 L
.92827 .18557 L
.93307 .19314 L
.93569 .19887 L
.9385 .20668 L
.94356 .22621 L
.94666 .24222 L
.94959 .26056 L
.95509 .30276 L
.96031 .34752 L
.96287 .36789 L
.96521 .38377 L
.96639 .3903 L
.96767 .39616 L
.96896 .40055 L
.97033 .40344 L
.97107 .40423 L
.97174 .40448 L
.97252 .4042 L
.97325 .40339 L
.97456 .40069 L
.97529 .39849 L
.97597 .39605 L
.97828 .38518 L
.98044 .37218 L
.98536 .33782 L
.99056 .30361 L
.99299 .29041 L
.99531 .2799 L
1 .26446 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1<ooooo`Ko0000G_ooool006Gooooo4?l0000eooooo`05o`000?nj^[[ooooooiRHV?l@4100
1_ooool00ol0003oooooooooo`18ooooo`Co00001_ooool7o`0005Oooooo001Tooooo`03o`000?oo
oooooooo00kooooo1_l0000_ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`17ooooo`;o00004?ooool3o`0005Cooooo001Rooooo`;o00005oooool3o`0003Oooooo00?o
0000ooooooooool0A_ooool00ol0003oooooooooo`0Cooooo`?o0000DOooool0063ooooo0_l0000L
ooooo`;o0000=Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Oooooo0ol0001>
ooooo`00Goooool00ol0003oooooooooo`0Nooooo`;o0000<oooool00ol0003oooooooooo`14oooo
o`03o`000?oooooooooo01_ooooo0ol0001;ooooo`00Goooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo033ooooo0_l00015ooooo`03o`000?oooooooooo01kooooo1?l00017ooooo`00
G_ooool00ol0003oooooooooo`0Rooooo`;o0000<?ooool00ol0003oooooooooo`13ooooo`03o`00
0?oooooooooo02?ooooo0ol00014ooooo`00G_ooool00ol0003oooooooooo`0Tooooo`;o0000;_oo
ool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo02Kooooo0ol00011ooooo`00G_ooool0
0ol0003oooooooooo`0Vooooo`;o0000;?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooo
oooo02[ooooo0_l0000oooooo`00GOooool00ol0003oooooooooo`0Yooooo`?o0000:Oooool00ol0
003oooooooooo`11ooooo`03o`000?oooooooooo02gooooo0_l0000mooooo`00G?ooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0@Oooool00ol0003o
ooooooooo`0_ooooo`;o0000>oooool005cooooo00?o0000ooooooooool0;_ooool5o`0002?ooooo
00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo03Sooooo
001Looooo`03o`000?oooooooooo03?ooooo0ol0000Pooooo`03o`000?oooooooooo043ooooo00?o
0000ooooooooool0<oooool2o`0003Sooooo001Kooooo`03o`000?oooooooooo03Oooooo1?l0000L
ooooo`;o0000@Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03Gooooo001Koooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`10oooo
o`03o`000?oooooooooo03Kooooo0_l0000eooooo`00Foooool00ol0003oooooooooo`0looooo`;o
00006Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo03Wooooo00?o0000oooooooo
ool0<_ooool001Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0J
ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Cooooo
00?o0000ooooooooool01?ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Looooo`Co
000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPGooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`0Oooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^
kQCooooo00?o0000ooooooooool00oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0K
ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo
00?o0000ooooooooool06?ooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;o
k^k^00kooooo000Fooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0J
ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg01Cooooo
00?o0000ooooooooool01?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05?ooool00ol0003oooooooooo`03ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_oo
ooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool2o`0001Wooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Booooo`Ko00001_ooool01Ol0003ooooooooo
oooooooo410@00?ooooo00?o410@ooooooooool04Oooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h0
1?ooool01Ol@413ooooooooooooooooo410@01?ooooo1_l00005ooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@4007ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41004oooool0
0ol0003oooooooooo`05ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
400Oooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`03o`00
0?oooooooooo01?ooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41003_ooool001?ooooo
00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000001gooooo00?oZJVYoa0@
4?ooool00_ooool01Ol0003ooooooooooooooooo000001?ooooo00?o0000ooooooooool01oooool0
0onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001?o
oooo00?o0000ooooooooool01_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooooooooooo
ool000007_ooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool2
o`0001?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000000kooooo
000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000Looooo`03
oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00000Cooooo`03o`000?oooooooooo
00Sooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000001kooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Cooooo`03o`000?oooooooooo00Oooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooo
oooooooooooo000001gooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo0000
00Sooooo0_l0000Aooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`00
000>ooooo`005?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41007Ooo
ool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41004_ooool00ol0003ooooo
ooooo`0:ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Looooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4009ooooo`03o`000?oooooooooo
01;ooooo0_l0000Rooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400C
ooooo`03o`000?oooooooooo00Sooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oo
oooooooo01cooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00[ooooo
00?o0000ooooooooool03oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@
41003_ooool001Cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01[o
oooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool0
0ol0003oooooooooo`06ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg01kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00[o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Booooo`03o`000?oooooooooo00Gooooo00Go0000okZj
^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool01Ol@413oV9RHoooo
oonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0:ooooo`03o`000?oooooooooo00oo
oooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000Eooooo`03
ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Jooooo`05ojVYZOl@413o0000
oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo00?o0000ooooooooool01_oo
ool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Looooo`03
oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool07oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h04_ooool00ol0003oooooooooo`05ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool00ol0003oooooooooo`0?ooooo`03ogMgMol0003ooooo
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`00FOooool00ol0003oooooooooo`17oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`16oooo
o`03o`000?oooooooooo02Oooooo001Hooooo`03o`000?oooooooooo04Sooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo04Sooooo00?o0000oooooooo
ool09_ooool005Sooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo03cooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Vooooo`00F?oo
ool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0??oo
ool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo02Gooooo001Hooooo`03o`000?oooooo
oooo04_ooooo0_l0000=ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0BOooool0
0ol0003oooooooooo`0Uooooo`005_ooooooo`00043o00004oooool001Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`;o00001oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`005_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool04Oooool005Oooooo00?o0000ooooooooool0D?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0Boooool0
0ol0003oooooooooo`0Tooooo`00Aoooool2o`0000gooooo00?o0000ooooooooool0D_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo02_ooooo0_l0000>ooooo`03o`000?oooooooooo
04_ooooo00?o0000ooooooooool09?ooool004Kooooo1?l0000<ooooo`03o`000?oooooooooo05;o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Zooooo`Co00003Oooool00ol0003o
ooooooooo`1;ooooo`03o`000?oooooooooo02Cooooo0015ooooo`;o00000_ooool2o`0000_ooooo
00?o0000ooooooooool0D_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02[ooooo
00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo04cooooo00?o0000oooooooo
ool08oooool004Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo05?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Zooooo`05o`00
0?ooooooooooooooool000003?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo02?o
oooo0015ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`1Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0COooool00ol0003ooooo
ooooo`0Sooooo`00AOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0EOooool00ol0003oooooooooo`05ooooo`;o0000:_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0COooool00ol0003ooooooooo
o`0Sooooo`00A?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0E_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04kooooo00?o0000
ooooooooool08_ooool004Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo05Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1>oooo
o`03o`000?oooooooooo02;ooooo0014ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0C_ooool00ol0003oooooooooo`0Rooooo`007Oooool6o`00023ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Hooooo`;o00003Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Rooooo`006_oo
ool3o`0000Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo01Oooooo1?l0000<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo02;ooooo000Hooooo`;o00002Oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05_ooool0
1Ol0003ooooooooooooooooo000000_ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool08_ooool001Oooooo0_l0000;
ooooo`03o`000?oooooooooo00gooooo0ol0000;ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo057ooooo00?o0000
ooooooooool08Oooool001Kooooo0_l0000<ooooo`03o`000?oooooooooo00gooooo00Co0000oooo
ool0003o00002_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0FOooool00ol0003oooooooooo`02ooooo`;o00005_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool08Oooool001Kooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool000002Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0F_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1Aooooo`03o`000?oooooooooo027ooooo000Fooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
05_ooooo00Go0000ooooooooooooooooo`00000Fooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0D_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo017ooooo000Voooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00001Mooooo`05o`000?oooooo
ooooooooool000003Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool00000
E?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo017ooooo000Vooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00_ooooo00Go0000ooooooooooooooooo`00001Mooooo`05o`000?ooooooooooooooool0
00002oooool5o`0000Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool00_l0001Dooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool04Oooool002Oooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool01?l0003ooooo
ooooool0001Nooooo`05o`000?ooooooooooooooool000002_ooool2o`0000Cooooo00?o0000oooo
ool000000_l0000;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool3o`00
05Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Booooo`009oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0=ooooo`?o0000G_ooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000oooo
ooooool01?ooool2o`0000gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04_ooool002Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000004Oooool00ol0
003oooooooooo`1Nooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Booooo`00:?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Oooooo0_l00002ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool00_l00008oooo
o`03o`000?oooooooooo01Kooooo00Co0000oooooooooooo0000JOooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo01;ooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool02Oooool3o`0007?ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`0F
ooooo`?o0000J_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01?ooooo000Yoooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Ooooool01?l0003oooooooooool00009
ooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0C
ooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07oooooo00Co0000oooo
oooooooo00002?ooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool04oooool002[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`21oooo
o`03o`000?oooooo000000Sooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo01?ooooo000Zooooo`05o`000?ooooooooooooooool00000Q?ooool00ol0
003oooooo`000008ooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Dooooo`00:oooool00ol0003oooooo`00001looooo`Go00001?ooool00ol0003o
ooooo`000007ooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Dooooo`00:oooool3o`0007cooooo00GoV9RHob4Q8Oo^k^koooooodA4A004ooooo`03
o`000?oooooo000000Oooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo01Cooooo002[ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?o0000ooooool00000
0_l00005ooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Dooooo`00[?ooool00onHV9So8B4Qonk^kP05ooooo`;o00001_ooool00ol0003ooooooooo
o`27ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05?ooool00:gooooo00?oMgMg
ofIVI_ooool01?ooool2o`0000Kooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo01Gooooo002^ooooo`03o`000?oooooooooo00?ooooo0_l00006oooo
o`03o`000?oooooooooo08Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Eoooo
o`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`28ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05Oooool00:[o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0R?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Gooooo002eooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo01Gooooo002eooooo`;o00000oooool00ol0003oooooooooo`2:ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool05_ooool00;Gooooo0_l00003ooooo`03o`000?oo
oooooooo08[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`00]Oooool2
o`0000?ooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo01Kooooo002eooooo`;o00000oooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool05_ooool00;Gooooo00Go0000ooooool0003oooooo`00002=oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool00;Gooooo00?o0000ooooool0
00000_l0002=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool00;Gooooo
00?o0000ooooooooool0Soooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo
002eooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Fooooo`00]Oooool00ol0003oooooooooo`2?ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool05oooool00;Gooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01Oooooo002eooooo`;o0000TOooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo01Oooooo002eooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Gooooo`00]Oooool00ol0003oooooooooo`2@ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool05oooool00;Gooooo00?o0000ooooooooool0T?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Oooooo002eooooo`03o`000?oooooooooo
093ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Gooooo`00]Oooool00ol0003o
ooooooooo`2Aooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05oooool00;Gooooo
00?o0000ooooooooool0TOooool01Ol0003ooooooooooooooooo000001[ooooo002eooooo`03o`00
0?oooooooooo097ooooo00Go0000ooooooooooooooooo`00000Jooooo`00]Oooool2o`0009;ooooo
00Go0000ooooooooooooooooo`00000Jooooo`00]Oooool00ol0003oooooooooo`2Aooooo`05o`00
0?ooooooooooooooool000006_ooool00;Gooooo00?o0000ooooooooool0TOooool01?l0003ooooo
ooooool0000Kooooo`00]Oooool00ol0003oooooooooo`2Booooo`03o`000?oooooo000001_ooooo
002eooooo`03o`000?oooooooooo09;ooooo00?o0000ooooool000006oooool00:cooooo0_l00000
0ol@413oooooooooo`04ooooo`03o`000?oooooooooo09?ooooo0_l0000Kooooo`00[Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo09?ooooo00?o0000ooooooooool06_ooool00:[o
oooo1Ol00006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`04odA4A?oMgMgoooooo`0000Oo
oooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo0;3o
oooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0/?ooool00:_ooooo00?o
k^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00[?ooool00omgMgOo0000ooooo`06
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`
ooooo`00Z_ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool0
0:[ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zoooo
o`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`000;3ooooo002Zooooo`05o`000?mEEEGo0000
oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool00omEEEGoQhN7ooooo`08oooo
o`03o`000?oooooooooo0;3ooooo002Zooooo`03omgMgOl@413oV9RH00Sooooo00?o0000oooooooo
ool0/?ooool00:_ooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Ooo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Oo<c<co8B4Q
o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go8B4QoiRHV?oooooo
V9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Olb<S;oV9RHoooooonHV9So<S8b00Ko
oooo0ol0002`ooooo`00Z_ooool01Oo<c<co0000o`000?l0003oc<c<0;Wooooo002Zooooo`05oa0@
4?nj^[[ooooookZj^_l@4100^Oooool00:[ooooo00Go0000okZj^_oooooo^[Zjo`00002iooooo`00
Z_ooool01OnYZJWo410@o`000?l@413oZJVY0;Wooooo003oooooofWooooo002_ooooo`03o`000?nj
^[[ooooo0;Kooooo002_ooooo`;o<S8b]oooool0083ooooo0_l000001_l@413oooooooooool@413o
0000oa0@41Sooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06Oooool4o`00
0004oa0@4?ooooooooooooooo`Co000000So410@ooooooooooooc<c<ob4Q8Ol0003o8B4Qolc<c7So
oooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`0000gooooo
00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL00oooool00oo<c<co0000oa0@400<
ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`02ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40N?ooool0087ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooooooooa0@40?ooooo
00?o410@ooooooooool04?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000007Sooooo0021ooooo`06o`00
0?ooooooA4A4odA4A?oooooo00002Oooool6o`0000gooooo00GoMgMgoc8b<_ooooooooooo`000003
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02oooool6o`0000cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`02ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80N?oo
ool0087ooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Iooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`00_ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Goc<c<o`000?l0003o0000olc<c01h
ooooo`00POooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001Wooooo00?o0000ooooooooool01?oo
ool01Ol@413ooooooooooooooooo410@013ooooo00?o410@o`000?l000000ol0000Looooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01Ol@413o^[Zjoooooonj^[[o410@07So
oooo0021ooooo`06o`000?lb<S;ooooooooooolb<S;o00006Oooool00ol0003oooooooooo`04oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00_ooool01Ol0003o^[Zjoooooonj^[[o000007Sooooo0020
ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool4o`0000?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0Booooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000001Ooo
ool00omEEEGoIVIVo`000004ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0N?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(120) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .39394 m
.00123 .39574 L
.00236 .39609 L
.00365 .39495 L
.00488 .3924 L
.00601 .38881 L
.00706 .38455 L
.00942 .372 L
.01434 .33814 L
.01975 .30079 L
.02226 .28676 L
.02365 .2803 L
.02497 .27505 L
.02619 .27099 L
.02752 .26743 L
.02873 .26498 L
.02985 .26334 L
.03053 .26266 L
.03125 .26215 L
.03257 .26184 L
.03386 .26223 L
.03504 .26316 L
.03632 .26471 L
.03773 .26699 L
.04057 .27297 L
.04328 .27963 L
.04624 .28676 L
.04759 .28967 L
.04903 .29234 L
.05027 .29422 L
.05161 .29573 L
.0524 .29636 L
.05313 .29674 L
.05382 .29693 L
.05455 .29694 L
.05536 .29673 L
.0561 .29633 L
.05693 .29565 L
.0578 .29467 L
.05932 .29234 L
.06076 .28949 L
.06345 .28271 L
.06843 .26736 L
.0737 .25205 L
.07502 .24904 L
.07645 .24635 L
.07727 .2451 L
.07801 .24415 L
.07877 .24339 L
.07948 .24286 L
Mistroke
.0808 .24238 L
.08203 .24254 L
.08338 .2434 L
.08413 .2442 L
.08481 .24513 L
.08608 .24733 L
.08726 .24996 L
.08994 .25789 L
.09536 .28052 L
.10034 .30419 L
.10279 .31438 L
.10506 .32174 L
.10634 .32476 L
.10771 .3269 L
.10908 .32787 L
.10986 .32786 L
.11059 .32749 L
.11185 .32601 L
.11301 .32374 L
.11428 .32029 L
.11562 .31567 L
.12103 .28928 L
.12693 .2555 L
.12961 .2418 L
.1325 .22947 L
.13383 .22488 L
.13523 .22083 L
.13643 .21806 L
.13775 .21577 L
.13903 .2143 L
.1402 .21364 L
.14155 .21368 L
.14282 .21451 L
.144 .21595 L
.14509 .21787 L
.14629 .2206 L
.14757 .22421 L
.15016 .23368 L
.15296 .24672 L
.15802 .27504 L
.16091 .29148 L
.1625 .29976 L
.16401 .3067 L
.16541 .31217 L
.16614 .31459 L
.16692 .31679 L
.1683 .31962 L
.16958 .321 L
.17077 .32114 L
.17204 .32004 L
Mistroke
.17325 .31783 L
.17435 .31484 L
.17564 .31022 L
.17705 .30393 L
.17961 .28966 L
.19059 .21334 L
.19616 .18085 L
.19921 .16664 L
.20208 .15553 L
.20477 .14695 L
.20767 .13942 L
.21274 .12982 L
.21524 .1264 L
.21791 .12346 L
.22022 .12142 L
.22273 .11963 L
.22568 .118 L
.22847 .11686 L
.23118 .11605 L
.23369 .11551 L
.23496 .1153 L
.23632 .11511 L
.2375 .11498 L
.23879 .11487 L
.24022 .11478 L
.241 .11474 L
.24173 .11472 L
.24303 .11469 L
.24376 .11469 L
.24442 .11469 L
.24513 .1147 L
.24589 .11472 L
.24723 .11477 L
.24799 .11481 L
.24869 .11485 L
.25028 .11497 L
.25295 .11524 L
.25581 .1156 L
.26134 .1165 L
.26646 .11757 L
.27806 .12098 L
.28829 .12495 L
.29918 .13 L
.31001 .13518 L
.31571 .1377 L
.32172 .14 L
.32699 .1416 L
.32978 .1423 L
.33277 .14291 L
.33552 .14337 L
Mistroke
.33802 .14369 L
.34053 .14393 L
.34291 .14409 L
.34817 .14431 L
.35309 .14447 L
.35556 .14458 L
.35822 .14475 L
.35973 .14488 L
.36117 .14503 L
.36388 .14539 L
.3662 .14583 L
.36867 .14643 L
.37313 .14794 L
.37586 .14915 L
.37843 .15052 L
.38323 .15365 L
.40252 .17235 L
.40781 .17764 L
.41072 .18019 L
.41347 .18226 L
.41603 .18382 L
.41739 .18448 L
.41882 .18506 L
.42003 .18543 L
.42136 .18574 L
.42256 .18592 L
.4237 .18601 L
.42492 .18601 L
.42626 .18591 L
.42693 .18582 L
.42765 .18571 L
.42895 .18543 L
.43148 .18467 L
.43377 .1838 L
.43942 .18128 L
.4419 .18022 L
.44331 .1797 L
.44463 .17927 L
.4459 .17895 L
.44728 .1787 L
.44803 .17862 L
.44874 .17857 L
.45008 .1786 L
.45079 .17868 L
.45155 .17881 L
.45291 .17917 L
.45375 .17948 L
.45453 .17984 L
.456 .18069 L
.45869 .18287 L
Mistroke
.46116 .18564 L
.46388 .18959 L
.46674 .1948 L
.50665 .2636 L
.52889 .30401 L
.53399 .32649 L
.53679 .33698 L
.53816 .34108 L
.53941 .34406 L
.5405 .34598 L
.54164 .34727 L
.54279 .34777 L
.54404 .34738 L
.54532 .34596 L
.54668 .34335 L
.54797 .33988 L
.54914 .33596 L
.55432 .31198 L
.55921 .28547 L
.56176 .27268 L
.56446 .26116 L
.56587 .2562 L
.56742 .25168 L
.56883 .24848 L
.57015 .2463 L
.57138 .24498 L
.57273 .24434 L
.57399 .24449 L
.57517 .24527 L
.57622 .24649 L
.57738 .24838 L
.5786 .25093 L
.57974 .25384 L
.58469 .27094 L
.59004 .29287 L
.59254 .30198 L
.59392 .30616 L
.59523 .30939 L
.59644 .31168 L
.59776 .3133 L
.59896 .31394 L
.60006 .31379 L
.60137 .3127 L
.6026 .31078 L
.60395 .30772 L
.60539 .3034 L
.60834 .29179 L
.61104 .27884 L
.61647 .25085 L
.61934 .23738 L
Mistroke
.6224 .22548 L
.62391 .22078 L
.62533 .21715 L
.62661 .21461 L
.62799 .21263 L
.62931 .21153 L
.62997 .21127 L
.6307 .2112 L
.63198 .21167 L
.63319 .21279 L
.63433 .21447 L
.63554 .21688 L
.63687 .22026 L
.63808 .22403 L
.64268 .24346 L
.64747 .26986 L
.65021 .28554 L
.65276 .29888 L
.65531 .30969 L
.65674 .31416 L
.65804 .31705 L
.65878 .31815 L
.65947 .3188 L
.66022 .31911 L
.66101 .31894 L
.66235 .31754 L
.66311 .31613 L
.66382 .3144 L
.66514 .3102 L
.6664 .30509 L
.66875 .29296 L
.67405 .25775 L
.67922 .22095 L
.68472 .18687 L
.68789 .17092 L
.69076 .15887 L
.69368 .14877 L
.69636 .14123 L
.70159 .13046 L
.70434 .12647 L
.70724 .12321 L
.70977 .12102 L
.71213 .11942 L
.71472 .11808 L
.71603 .11755 L
.71749 .11707 L
.71879 .11672 L
.72019 .11642 L
.72167 .11618 L
.72305 .11602 L
Mistroke
.72443 .11591 L
.72574 .11585 L
.72692 .11583 L
.7282 .11583 L
.72899 .11585 L
.72973 .11588 L
.73112 .11595 L
.7319 .11601 L
.73261 .11607 L
.73423 .11623 L
.73696 .11658 L
.73984 .11704 L
.76098 .12149 L
.78181 .12579 L
.80082 .12944 L
.80585 .13062 L
.81133 .13211 L
.82129 .13572 L
.83269 .14152 L
.84324 .14838 L
.85266 .1548 L
.85761 .15787 L
.86282 .16055 L
.8656 .16168 L
.86864 .16264 L
.86997 .16297 L
.8714 .16326 L
.87275 .16347 L
.87397 .16362 L
.87531 .16373 L
.87655 .16378 L
.87792 .16379 L
.8786 .16377 L
.87936 .16374 L
.88062 .16366 L
.88198 .16353 L
.88444 .16321 L
.88959 .16237 L
.89241 .16192 L
.8938 .16174 L
.89507 .1616 L
.89579 .16153 L
.89658 .16148 L
.89738 .16144 L
.89822 .16142 L
.89894 .16142 L
.8997 .16143 L
.90108 .16152 L
.9018 .16159 L
.90258 .1617 L
Mistroke
.904 .16197 L
.90538 .16232 L
.90666 .16275 L
.90917 .16386 L
.91153 .16526 L
.91411 .16724 L
.91689 .16989 L
.92256 .17694 L
.92776 .18513 L
.93819 .20401 L
.94393 .21333 L
.94674 .21711 L
.94933 .22003 L
.95174 .22224 L
.95438 .22417 L
.95704 .2257 L
.95985 .22711 L
.96223 .2284 L
.96354 .22924 L
.96478 .2302 L
.96719 .23262 L
.96939 .23573 L
.97133 .23937 L
.97308 .24355 L
.97496 .24912 L
.977 .25652 L
.98063 .27364 L
.98404 .29435 L
1 .39394 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00H?ooool7o`0004?ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`00
0?oooooooooo0;3ooooo001Nooooo`?o00001_ooool7o`0003cooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c006ooooo`03o`000?oooooooooo047ooooo3Ol0001Rooooo`00G?ooool2o`00013ooooo0_l0
0015ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool02oooool5o`0005gooooo001K
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo017ooooo0ol0001Jooooo`00F_ooool00ol0003oooooooooo`0Doooo
o`?o0000@Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01Gooooo1Ol0001Eoooo
o`00FOooool00ol0003oooooooooo`0Hooooo`?o0000?_ooool2o`0003kooooo00?o0000oooooooo
ool06oooool5o`00053ooooo001Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo023ooooo0ol0001=ooooo`00F?oo
ool00ol0003oooooooooo`0Mooooo`;o0000>oooool00ol0003oooooooooo`0looooo`03o`000?oo
oooooooo02Cooooo0_l0001;ooooo`00F?ooool00ol0003oooooooooo`0Oooooo`Co0000=oooool0
0ol0003oooooooooo`0looooo`03o`000?oooooooooo02Kooooo0_l00019ooooo`00F?ooool00ol0
003oooooooooo`0Sooooo`Co0000<oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
02Wooooo0_l00017ooooo`00Eoooool00ol0003oooooooooo`0Xooooo`[o0000:Oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0A?ooool005Oooooo
00?o0000ooooooooool0<_ooool2o`0002Oooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0/ooooo`;o0000A?ooool005Oooooo00?o0000ooooooooool0=?ooool2o`0002Gooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo047ooooo001F
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool08_ooool2o`0003_ooooo00?o0000
ooooooooool0<?ooool2o`00047ooooo001Fooooo`03o`000?oooooooooo03Sooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03;ooooo00?o0000oooo
ooooool0?_ooool005Kooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo03[ooooo00?o0000ooooooooool0<oooool2o`0000Kooooo1ol0000aooooo`00
5Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00GoV9RH
oa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool00ol0003ooooo
ooooo`0:ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01cooooo1?l000001?l@413o
ooooooooooo^k^h2o`000003oc8b<_o^k^kooooo01gooooo00?o0000ooooooooool07oooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h?ooooo`03o`000?oooooooooo00Sooooo
1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool01OnHV9So410@o`000?lb<S;oc<c<
00Ko000000?o<S8bonk^k_ooool00oooool3o`0001Kooooo0_l000002Ol@413ooooooooooooooooo
k^k^oc8b<_l0003o<S8bonk^kP0>ooooo`005_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL06_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00[ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9So0000oiRHV?mgMgL07_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00Wooooo00GoV9RHob4Q8Oo^
k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool01Ol@413o^[Zjoooooomg
MgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko0000
0_ooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400Booooo`Ko00001_ooool01Ol0003o
oooooooooooooooo410@00?ooooo00?o410@ooooooooool03?ooool00ol0003oooooooooo`02oooo
o`Ko00000oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41004oooool6
o`0000Gooooo00?o0000ooooooooool00_ooool01Ol@413oooooooooool0003o410@01kooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
3_ooool00ol0003oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooo
oooooa0@400Oooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`06oooo
o`03o`000?oooooooooo013ooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41003_ooool0
01?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000001gooooo00?o
ZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool0
3?ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooooooo`;o00007Oooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooo
oooo00_ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000001kooooo00?o
ZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
4?ooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool001?o
oooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000001cooooo00?o410@
o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool03_oo
ool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003ooooo
ooooo`02ooooo`07o`000?ooooooooooooooool0003oooooo`00000Looooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000kooooo00?o0000
ooooooooool03?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000007Ooo
ool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000002Oooool00ol0003ooooo
ooooo`0?ooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>oooo
o`005?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41007Oooool00onj
^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41003Oooool00ol0003oooooooooo`0?
ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Looooo`03o`000?oo
oooooooo00;ooooo00Oo410@oooooooooooooooooa0@4?oooooo000000Sooooo1ol0000=ooooo`;o
00008_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41003Oooool00ol0
003oooooooooo`0>ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0L
ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4009ooooo`03o`000?oo
oooooooo013ooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00kooooo
000Dooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05oa0@
4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00gooooo00?o0000oooo
ooooool02oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`?o0000
1?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03Oooool00ol0003o
ooooooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9So
MgMg01_ooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2_ooool00ol0003oooooooooo`0?ooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0>ooooo`005Oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h06_ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=
ooooo`03o`000?oooooooooo00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h07?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01?ooool5o`0000Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Oooooo`03
oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03o`000?oooooooooo
00[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06ooo
ool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`03
o`000?oooooooooo00oooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00kooooo001Dooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0:?ooool005?ooooo
00?o0000ooooooooool0Doooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Wooooo`00Doooool00ol0003ooooooooo
o`1Dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0>?ooool00ol0003ooooooooo
o`1;ooooo`03o`000?oooooooooo02Oooooo001Cooooo`03o`000?oooooooooo05Cooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo04gooooo00?o0000
ooooooooool09_ooool005?ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Voooo
o`005_ooooooo`00043o00004oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool04Oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool3o`0000Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo0012oooo
o`;o00003_ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool09Oooool01?l0003oooooooooool0000=ooooo`03o`000?oooooooooo057ooooo00?o0000
ooooooooool08oooool0047ooooo00Co0000oooooooooooo00003Oooool00ol0003oooooooooo`1I
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09Oooool01?l0003oooooooooool0
000=ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool08_ooool0047ooooo00Co0000
oooooooooooo00003Oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool09?ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool0
Doooool00ol0003oooooooooo`0Qooooo`00@?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo05Cooooo0_l0000Qooooo`00@?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo05Gooooo0ol0000Oooooo`00@?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
05Oooooo0_l0000Nooooo`00@?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0GOooool01?l0003oooooooooooooool2o`0002Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05[ooooo00?o0000oooo
ooooool06oooool0043ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo05gooooo00Go0000ooooooooooooooooo`00000Uooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo
01_ooooo000oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`1Nooooo`04o`000?ooooooooooo`0002Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool06_ooool002oo
oooo0_l0000>ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`1Oooooo`03o`000?oooooo000002Gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool06_ooool002kooooo
00Co0000oooooooooooo00003Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0Goooool00ol0003oooooo`00000Eooooo`?o00003?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Foooool00ol0003o
ooooooooo`0Jooooo`00;_ooool01?l0003oooooooooool0000=ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Pooooo`;o00005Oooool01?l0003o
ooooooooool0000;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`1Looooo`03o`000?oooooooooo01Wooooo000]ooooo`05o`000?oooooooooooooo
ool000003?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0H?ooool2o`0001Cooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooo
oooo01Wooooo000]ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0H_ooool00ol0
003oooooooooo`0Booooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0H
ooooo`00;?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06;ooooo0_l0000Coooo
o`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0Hooooo`007oooool2o`00
00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Rooooo`;o00004_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool06?ooool001oo
oooo00?o0000ooooool000002_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06;o
oooo00?o0000ooooool000004Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05ko
oooo00?o0000ooooooooool06?ooool001kooooo00Go0000ooooooooooooooooo`000008ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0H_ooool00ol0003oooooo`00000Aooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0Gooooo`00
7_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`1Rooooo`04o`000?ooooooooooo`00013ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Oooooo`03o`000?oooooooooo01Oooooo000Nooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06;o
oooo00Co0000oooooooooooo00004?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
05oooooo00?o0000ooooooooool05oooool001kooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0H_ooool01Ol0003o
oooooooooooooooo000000oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Poooo
o`03o`000?oooooooooo01Oooooo000Mooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06?ooooo00Go0000oooooooo
ooooooooo`00000?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`0Gooooo`007Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Sooooo`;o00000oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0H?ooool00ol0003o
ooooooooo`0Gooooo`007Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo067ooooo
00?o0000ooooooooool05_ooool001gooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooo
oooooooo000000_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`03o`00
0?oooooooooo01Kooooo000Mooooo`03o`000?oooooooooo00Gooooo0_l00002ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`03o`000?oo
oooooooo01Kooooo000Looooo`03o`000?oooooooooo00Oooooo0ol0000<ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo06?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Fooooo`007?ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`00000?
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0F
ooooo`007?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05Wooooo1Ol00006oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08oooo
o`05o`000?ooooooooooooooool000003oooool01Ol0003ooooooooooooooooo000006Cooooo00?o
0000ooooooooool05_ooool001cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00cooooo00Go0000ooooooooooooooooo`00001Kooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool02Oooool01?l0003oooooooooool0000?ooooo`05o`000?oooooooooooooo
ool00000IOooool00ol0003oooooooooo`0Eooooo`007?ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool01Ol0003ooooooooooooooooo0000
05cooooo00?oV9RHob4Q8Oo^k^h01oooool3o`0000Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0:ooooo`04o`000?ooooooooooo`0000oooooo00Go0000ooooooooooooooooo`00
001Uooooo`03o`000?oooooooooo01Gooooo000Looooo`03o`000?oooooooooo01Oooooo00Go0000
ooooooooooooooooo`00000?ooooo`05o`000?ooooooooooooooool00000GOooool00onHV9So8B4Q
onk^kP06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0;ooooo`?o00003oooool01?l0003oooooooooool0001Vooooo`03o`000?oooooooooo01Go
oooo000Kooooo`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000@ooooo`03
o`000?oooooo000005oooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool2o`00017ooooo00?o0000ooooool0
0000I_ooool00ol0003oooooooooo`0Eooooo`006oooool00ol0003oooooooooo`0Hooooo`05o`00
0?ooooooooooooooool000004?ooool00ol0003oooooo`00001Pooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01ko
oooo0ol0001Vooooo`03o`000?oooooooooo01Gooooo000Kooooo`03o`000?oooooooooo01Wooooo
00Co0000oooooooooooo00004?ooool2o`0005gooooo00Go0000okZj^_ooooooV9RHoa0@4006oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`27oooo
o`03o`000?oooooooooo01Gooooo000Kooooo`03o`000?oooooooooo01[ooooo00?o0000ooooool0
0000Koooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo08Oooooo00?o0000ooooooooool05Oooool001_o
oooo00?o0000ooooooooool06_ooool2o`0007_ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool05?ooool001[ooooo
00?o0000ooooooooool0V?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0ROooool00ol0003oooooooooo`0Dooooo`006_ooool00ol0003ooooooooo
o`2Hooooo`;o00002_ooool01Ol0003ooooooooooooooooo000008_ooooo00?o0000ooooooooool0
5?ooool001[ooooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`09ooooo`05o`000?oo
ooooooooooooool00000Roooool00ol0003oooooooooo`0Dooooo`006_ooool00ol0003ooooooooo
o`2Hooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo0000S?ooool00ol0003ooooo
ooooo`0Dooooo`006_ooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo00Wooooo00Co
0000oooooooooooo0000S?ooool00ol0003oooooooooo`0Dooooo`006_ooool00ol0003ooooooooo
o`2Hooooo`03o`000?oooooooooo00[ooooo0_l0002>ooooo`03o`000?oooooooooo01?ooooo000J
ooooo`03o`000?oooooooooo09Sooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0C
ooooo`006_ooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo09[ooooo00?o0000oooo
ooooool04oooool001Wooooo00?o0000ooooooooool0VOooool00ol0003oooooooooo`2Jooooo`03
o`000?oooooooooo01?ooooo000Iooooo`03o`000?oooooooooo09Wooooo00?o0000ooooooooool0
V_ooool00ol0003oooooooooo`0Cooooo`006Oooool00ol0003oooooooooo`2Iooooo`;o0000Vooo
ool00ol0003oooooooooo`0Cooooo`006Oooool00ol0003oooooooooo`2Iooooo`03o`000?oooooo
oooo09_ooooo00?o0000ooooooooool04_ooool001Wooooo00?o0000ooooooooool0VOooool00ol0
003oooooooooo`2Kooooo`03o`000?oooooooooo01;ooooo000Iooooo`03o`000?oooooooooo09Wo
oooo00?o0000ooooooooool0Voooool00ol0003oooooooooo`0Booooo`006Oooool00ol0003ooooo
ooooo`2Iooooo`03o`000?oooooooooo09_ooooo00?o0000ooooooooool04_ooool001Wooooo00?o
0000ooooooooool0VOooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo01;ooooo000H
ooooo`03o`000?oooooooooo09[ooooo00?o0000ooooooooool0Voooool00ol0003oooooooooo`0B
ooooo`006?ooool00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo09_ooooo00?o0000oooo
ooooool04_ooool001Sooooo00?o0000ooooooooool0V_ooool2o`0009gooooo00?o0000oooooooo
ool04Oooool001Sooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`2Looooo`03o`00
0?oooooooooo017ooooo000Fooooo`;o0000WOooool00ol0003oooooooooo`2Looooo`03o`000?oo
oooooooo017ooooo000Fooooo`03o`000?oooooooooo09cooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00:cooooo0_l000000ol@413oooooooooo`04ooooo`03
o`000?oooooooooo0;3ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
/?ooool00:[ooooo1Ol00006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`04odA4A?oMgMgo
ooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oo
oooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0/?ooool0
0:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00[?ooool00omgMgOo
0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003o
ooooooooo`2`ooooo`00Z_ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000oooooooo
ool0/?ooool00:[ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;3o
oooo002Zooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`000;3ooooo002Zooooo`05o`00
0?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool00omEEEGoQhN7
ooooo`08ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03omgMgOl@413oV9RH00Sooooo00?o
0000ooooooooool0/?ooool00:_ooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool0
1Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go8B4Q
oiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Olb<S;oV9RHoooooonH
V9So<S8b00Kooooo0ol0002`ooooo`00Z_ooool01Oo<c<co0000o`000?l0003oc<c<0;Wooooo002Z
ooooo`05oa0@4?nj^[[ooooookZj^_l@4100^Oooool00:[ooooo00Go0000okZj^_oooooo^[Zjo`00
002iooooo`00Z_ooool01OnYZJWo410@o`000?l@413oZJVY0;Wooooo003oooooofWooooo002_oooo
o`03o`000?nj^[[ooooo0;Kooooo002_ooooo`;o<S8b]oooool0083ooooo0_l000001_l@413ooooo
ooooool@413o0000oa0@41Sooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X0
6Oooool4o`000003oa0@4?oooooooooo00Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07So
oooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`0000gooooo
00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL00oooool00oo<c<co0000oa0@400<
ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000cooooo00?o0000ooooooooool00_oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1hooooo`00
POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo
410@0oooool00ol@413oooooooooo`0@ooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool00oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@4100N?ooool0087o
oooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00003Oooool01OmgMgOo<S8boooooooo
oooo000000?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`Ko00003?oo
ool00ol0003oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooooooooooo
o`00001hooooo`00POooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001Wooooo00Go0000ob4Q8Ol0
003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo00Gooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooo
oooo000007Sooooo0021ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo00006Oooool00ol0003ooooo
ooooo`04ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol@413o0000o`000003o`0001co
oooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@oooo
ooooool0M_ooool0087ooooo00Ko0000oc8b<_oooooooooooc8b<_l0000Iooooo`03o`000?oooooo
oooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Booooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool00_ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`1hooooo`00P?ooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo
1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Kooooo`03
oeEEEOmVIVKo000000Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h0N?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(122) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .2923 m
.00488 .28509 L
.00942 .27663 L
.01077 .2746 L
.01204 .27308 L
.01318 .27213 L
.01441 .27162 L
.01576 .27176 L
.01644 .27214 L
.01719 .27281 L
.01851 .27467 L
.01975 .27726 L
.02103 .28085 L
.02243 .28583 L
.02499 .29777 L
.02978 .32866 L
.03245 .34841 L
.03533 .36885 L
.03666 .37709 L
.03806 .38454 L
.03925 .38965 L
.04057 .39371 L
.04133 .39526 L
.04202 .39612 L
.04282 .39646 L
.04358 .39611 L
.04493 .39387 L
.04569 .39172 L
.04639 .38917 L
.04761 .38356 L
.04895 .37575 L
.05167 .35575 L
.05737 .30527 L
.06036 .28 L
.06351 .2577 L
.06625 .24304 L
.0678 .23687 L
.06854 .23448 L
.06924 .23255 L
.07057 .22979 L
.07178 .22829 L
.07308 .22773 L
.07382 .2279 L
.0745 .22836 L
.07573 .22994 L
.07688 .23227 L
.07815 .23575 L
.0795 .24054 L
.08228 .25339 L
.08481 .26822 L
Mistroke
.08983 .30236 L
.09258 .32059 L
.09517 .33501 L
.09635 .34021 L
.0976 .34456 L
.09896 .34784 L
.10022 .34938 L
.10134 .3495 L
.1024 .34854 L
.10355 .3463 L
.10478 .34258 L
.10624 .33656 L
.10759 .32961 L
.11064 .31007 L
.11618 .26885 L
.12118 .23572 L
.12399 .22166 L
.12532 .21639 L
.12656 .21235 L
.1277 .20937 L
.12892 .207 L
.13027 .20536 L
.1315 .20477 L
.13278 .2051 L
.13351 .2057 L
.13417 .20653 L
.1354 .20874 L
.13669 .21204 L
.13782 .21572 L
.13903 .22051 L
.14122 .23129 L
.14619 .26494 L
.15201 .31278 L
.15487 .33436 L
.15612 .34241 L
.15751 .34987 L
.15875 .35503 L
.15991 .35846 L
.16114 .36048 L
.16246 .36071 L
.16383 .35881 L
.16451 .35704 L
.16527 .3545 L
.1666 .34851 L
.16784 .34136 L
.17738 .25856 L
.1826 .21377 L
.18749 .18113 L
.19277 .15611 L
.19557 .14651 L
Mistroke
.19858 .13856 L
.20132 .13309 L
.20392 .12915 L
.20626 .12642 L
.20881 .12412 L
.21032 .12302 L
.21175 .12215 L
.21443 .1209 L
.21593 .1204 L
.21731 .12006 L
.21803 .11992 L
.21882 .1198 L
.21965 .11971 L
.22042 .11966 L
.22109 .11963 L
.22182 .11962 L
.22314 .11965 L
.22443 .11973 L
.22562 .11985 L
.22832 .1202 L
.23119 .12069 L
.23638 .12195 L
.24125 .1236 L
.25234 .12812 L
.26173 .13226 L
.27176 .13628 L
.27752 .13804 L
.28276 .13934 L
.28528 .13981 L
.28671 .14001 L
.28802 .14016 L
.28917 .14026 L
.29043 .14034 L
.29175 .14039 L
.29299 .14042 L
.29429 .14043 L
.29503 .14042 L
.29571 .14041 L
.29696 .14039 L
.29829 .14036 L
.29961 .14031 L
.30084 .14025 L
.30314 .14012 L
.30587 .13991 L
.30838 .13967 L
.31131 .13936 L
.31274 .13922 L
.31405 .1391 L
.31524 .13902 L
.31653 .13894 L
Mistroke
.3179 .13889 L
.31919 .13888 L
.31987 .13888 L
.32061 .1389 L
.32139 .13892 L
.32212 .13895 L
.32343 .13904 L
.32483 .13916 L
.32629 .13933 L
.32788 .13956 L
.33077 .14013 L
.33359 .14092 L
.33621 .1419 L
.34153 .14472 L
.34729 .14893 L
.35774 .15919 L
.36784 .17073 L
.37278 .1756 L
.37728 .17905 L
.37846 .17976 L
.37975 .18043 L
.38086 .1809 L
.38209 .18132 L
.38339 .18162 L
.38477 .18179 L
.38605 .18181 L
.38725 .18169 L
.38859 .18143 L
.38926 .18124 L
.39 .18099 L
.39252 .17986 L
.39547 .17803 L
.3982 .17596 L
.40366 .17118 L
.40958 .1658 L
.41229 .16361 L
.41517 .16169 L
.41635 .16105 L
.41762 .16048 L
.41835 .16021 L
.41901 .16 L
.42032 .1597 L
.42164 .15955 L
.42238 .15953 L
.42305 .15956 L
.42436 .15975 L
.42559 .16008 L
.42629 .16034 L
.42703 .16067 L
.42835 .16141 L
Mistroke
.42977 .16243 L
.43133 .16383 L
.43394 .16686 L
.43674 .1711 L
.44179 .18129 L
.45193 .20859 L
.45639 .22086 L
.45875 .22663 L
.4613 .23183 L
.4627 .23413 L
.46398 .23584 L
.46521 .23708 L
.4665 .23797 L
.46786 .23841 L
.46913 .23836 L
.46986 .23814 L
.47052 .23781 L
.47129 .23729 L
.47201 .23666 L
.47342 .23506 L
.47491 .23289 L
.47759 .22792 L
.48364 .21356 L
.4885 .20155 L
.49117 .19578 L
.49371 .19132 L
.49514 .18935 L
.49589 .18849 L
.4967 .18772 L
.49737 .1872 L
.49812 .18676 L
.49943 .18633 L
.50075 .18638 L
.5015 .18664 L
.50218 .18701 L
.50345 .18808 L
.50477 .18974 L
.50607 .1919 L
.50747 .19488 L
.51001 .20203 L
.51249 .21122 L
.51477 .22163 L
.52547 .28707 L
.5278 .30123 L
.5303 .31429 L
.53151 .31948 L
.53266 .3236 L
.5337 .32656 L
.53482 .32894 L
.53601 .33044 L
Mistroke
.53727 .3309 L
.53846 .33024 L
.53954 .32876 L
.54083 .32597 L
.54222 .32179 L
.54474 .31171 L
.54997 .2854 L
.55285 .27131 L
.55557 .26026 L
.5568 .25632 L
.55811 .25295 L
.55879 .25155 L
.55954 .2503 L
.56086 .24889 L
.56206 .2485 L
.56335 .24905 L
.56457 .2505 L
.56568 .25264 L
.56695 .256 L
.56814 .26 L
.57082 .27203 L
.57623 .30583 L
.58178 .34258 L
.5833 .35055 L
.58414 .35424 L
.58492 .35719 L
.58629 .3611 L
.58702 .36246 L
.5878 .36334 L
.58854 .3636 L
.58922 .36335 L
.58997 .36252 L
.59077 .36101 L
.59153 .35898 L
.59224 .35656 L
.59358 .35079 L
.59612 .33593 L
.59886 .31566 L
.60393 .27388 L
.6067 .25245 L
.60929 .23505 L
.61183 .22108 L
.61414 .21139 L
.61546 .20722 L
.61671 .20419 L
.61803 .20198 L
.61877 .20117 L
.61946 .20071 L
.62058 .20054 L
.62162 .20103 L
Mistroke
.62276 .20229 L
.624 .20449 L
.62528 .20772 L
.62651 .21167 L
.62881 .22137 L
.63152 .23647 L
.63408 .25388 L
.63886 .29166 L
.64158 .31327 L
.64444 .33324 L
.64563 .33997 L
.64689 .34593 L
.64762 .34869 L
.64828 .35075 L
.64958 .35347 L
.65077 .35437 L
.65186 .35381 L
.65306 .35168 L
.65434 .34771 L
.65545 .34294 L
.65649 .33742 L
.65885 .32161 L
.66888 .23479 L
.67422 .19565 L
.6792 .16888 L
.6817 .15865 L
.68438 .14979 L
.68735 .14215 L
.69006 .13688 L
.69255 .13316 L
.69485 .1305 L
.69737 .12824 L
.70005 .12644 L
.70236 .12526 L
.70454 .12444 L
.70578 .12408 L
.70692 .12381 L
.70823 .12357 L
.70948 .12339 L
.71079 .12327 L
.71153 .12322 L
.7122 .12318 L
.71345 .12314 L
.71477 .12313 L
.71595 .12313 L
.71705 .12315 L
.71826 .12317 L
.71956 .12321 L
.72245 .12332 L
.72518 .12347 L
Mistroke
.72763 .12365 L
.7303 .12388 L
.74026 .12476 L
.74961 .12552 L
.75437 .12607 L
.7595 .12674 L
.76227 .12716 L
.76518 .12768 L
.7704 .12891 L
.77586 .13065 L
.78094 .13265 L
.79246 .1389 L
.81216 .1527 L
.81755 .15597 L
.8205 .1574 L
.82326 .15846 L
.82561 .15915 L
.82693 .15945 L
.82813 .15966 L
.82945 .15984 L
.83019 .15991 L
.83088 .15995 L
.83214 .15999 L
.83349 .15996 L
.83423 .15991 L
.83501 .15983 L
.83568 .15975 L
.83641 .15964 L
.83804 .15933 L
.83956 .15895 L
.84527 .15697 L
.85085 .15462 L
.85592 .15256 L
.85844 .15166 L
.86118 .15085 L
.86243 .15055 L
.86376 .1503 L
.8649 .15015 L
.86615 .15005 L
.86688 .15003 L
.86757 .15004 L
.86887 .15013 L
.8696 .15021 L
.87027 .15033 L
.8718 .15068 L
.87314 .15111 L
.87436 .1516 L
.87709 .15304 L
.87953 .15476 L
.88221 .15712 L
Mistroke
.88761 .16351 L
.8973 .17957 L
.90317 .19039 L
.90873 .19956 L
.91115 .20278 L
.91372 .20546 L
.91506 .20651 L
.91578 .20695 L
.91654 .20735 L
.91789 .20783 L
.91916 .20802 L
.92044 .20795 L
.92164 .20766 L
.92295 .20709 L
.92369 .20667 L
.92436 .20621 L
.92718 .20368 L
.92984 .20051 L
.93964 .1855 L
.94475 .17821 L
.94733 .17537 L
.9488 .17411 L
.95017 .17319 L
.95094 .17279 L
.95167 .17249 L
.95304 .17215 L
.9538 .17209 L
.95451 .17213 L
.95529 .17226 L
.95612 .17252 L
.95683 .17284 L
.9576 .17329 L
.95899 .17439 L
.96035 .17583 L
.9616 .17748 L
.96399 .18161 L
.96617 .18648 L
.97108 .2014 L
.97992 .23931 L
.98486 .26214 L
.98747 .27287 L
.99024 .28232 L
.9914 .28552 L
.99265 .2884 L
.99402 .29082 L
.99531 .29237 L
.9965 .29318 L
.99776 .2934 L
.99883 .2931 L
1 .2923 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
001Jooooo`Oo0000E?ooool00ol0003oooooooooo`2`ooooo`00F?ooool2o`0000Oooooo0ol0001A
ooooo`03o`000?oooooooooo03kooooo3_l0001Tooooo`00Eoooool00ol0003oooooooooo`0:oooo
o`;o0000Coooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00cooooo1ol0001Moooo
o`00Eoooool00ol0003oooooooooo`0<ooooo`?o0000C?ooool2o`0003cooooo0_l0000Fooooo`?o
0000F_ooool005Kooooo00?o0000ooooooooool04?ooool3o`0004Wooooo00?o0000ooooooooool0
>_ooool00ol0003oooooooooo`0Iooooo`;o0000F?ooool005Kooooo00?o0000ooooooooool04ooo
ool2o`0004Oooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Looooo`;o0000E_oo
ool005Gooooo00?o0000ooooooooool05_oooolBo`0003Gooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`0Nooooo`;o0000E?ooool005Gooooo00?o0000ooooooooool0:?ooool2o`00
03?ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
057ooooo001Dooooo`03o`000?oooooooooo02_ooooo0_l0000aooooo`03o`000?oooooooooo03Wo
oooo00?o0000ooooooooool08Oooool2o`00057ooooo001Dooooo`03o`000?oooooooooo02gooooo
0_l0000_ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`1>ooooo`00Doooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02cooooo00?o
0000ooooooooool0>?ooool00ol0003oooooooooo`0Uooooo`;o00003?ooool8o`0003[ooooo001C
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0:oooool2o`0003Sooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`07ooooo`;o00002?ooool00ol0003oooooooooo`0g
ooooo`00Doooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0Yooooo`?o00000oooool3o`0000_ooooo00?o0000oooo
ooooool0=_ooool005?ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0?ooooo`Ko
00005Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02_ooooo1?l0000>ooooo`03
o`000?oooooooooo03Kooooo000Eooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h06_ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`03o`000?oooooooooo00gooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h06_ooool00ol0003oooooo`000003o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h2ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Oooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPcooooo00?o0000oooo
ooooool02oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05oiRHV?l@413o
0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?l0003ok^k^01gooooo0_l000002Ol@413ooooo
ooooooooooook^k^oc8b<_l0003o<S8bonk^kP0>ooooo`005_ooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo00gooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool01?l0003oooooooooool00004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_l00007ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool00ol0003oooooooooo`0<ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg01_ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9So
ooooo`000?mgMgL07_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3_ooool000_ooooo1_l00002ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@01;ooooo
1_l00006ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`09ooooo`03
o`000?oooooooooo00Gooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooo
oooooooooa0@400Cooooo`Ko00000oooool00ol0003oooooo`000004ooooo`05oa0@4?oooooooooo
ooooool000002_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000ooooooooool03Ooo
ool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41007oooool01Ol0003ooooo
oooooooooooo410@00?ooooo00?o0000ooooooooool06Oooool5o`0000?ooooo00Go410@oooooooo
oooooooooa0@400>ooooo`004oooool01?m4A4CogMgMooooool00004ooooo`05o`000?oooooooooo
ooooool000007Oooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000002ooo
ool00ol0003oooooooooo`0?ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooooooooooo
o`00000Looooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool00_l0000:ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000002oooool00ol0003oooooooooo`0>ooooo`03oiRHV?lQ8B7ok^k^00?o
oooo00Go0000ooooooooooooooooo`00000Nooooo`03ojVYZOl@413ooooo00;ooooo00Co0000oooo
oooooooooooo0_l0000Aooooo`Co00001Oooool01?m4A4CogMgMooooool00004ooooo`05o`000?oo
ooooooooooooool000003_ooool001?ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000001cooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo0000
00[ooooo00?o0000ooooooooool04Oooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooooooo
ooooool000007Oooool2o`0000Cooooo00Go0000ooooool0003oooooo`00000;ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000002oooool00ol0003oooooooooo`0?ooooo`03ogMgMomVIVKooooo00;ooooo
00Go0000ooooooooooooooooo`00000Mooooo`03oa0@4?l0003o^[Zj00?ooooo00Co0000oooooooo
oooooooo0_l0000?ooooo`;o00000oooool2o`0000Cooooo00CogMgMoeEEEOoooooo00001?ooool0
1Ol0003ooooooooooooooooo000000kooooo000Dooooo`03ogMgMoo<c<co000000Cooooo00Go410@
oooooooooooooooooa0@400Mooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooo
oa0@400:ooooo`03o`000?oooooooooo01;ooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo01cooooo0ol00002ooooo`;o00000_ooool00ol@413oooooooooo`09ooooo`03
o`000?oooooooooo013ooooo0_l0000Rooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooo
oooooooooa0@400:ooooo`03o`000?oooooooooo017ooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01cooooo00?o^[Zjob4Q8Oooool00_ooool01ol@413ooooooooooooo
oooo410@ooooool000003_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00kooooo000Dooooo`03onk^
k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo00?o0000ooooooooool03_ooool0
1Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`00
0?oooooooooo00;o000000GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02_ooool00ol0003oooooooooo`0=ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`07ogMg
MonHV9SooooooiRHV?mgMgOoooooo`00000=ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00_ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool0
01Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00GoZJVY
oa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02_ooool00ol0003ooooo
ooooo`0>ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?o0000
ooooooooool03_ooool3o`00023ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00[ooooo00?o0000ooooooooool03Oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00?ooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00kooooo001Aooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool03Oooool4
o`0003Kooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool07?ooool0057ooooo00?o0000ooooooooool0D?ooool00ol0
003oooooooooo`0<ooooo`05o`000?oooooo0000ooooool00000=?ooool00ol0003oooooooooo`16
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0K
ooooo`00DOooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00_ooooo00Ko0000oooo
oooooooo0000ooooool0000dooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01_ooooo001@ooooo`03o`000?oooooo
oooo057ooooo00?o0000ooooooooool02oooool01_l0003oooooooooool0003oooooo`0003Cooooo
00?o0000ooooooooool0B?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool06oooool0053ooooo00?o0000ooooooooool0D_ooool00ol0003ooooooooo
o`09ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Oooooo`?o0000
3oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Jooooo`005_ooooooo`00043o00004oooool001Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`04ooooo`Go00000oooool00ol0003oooooooooo`05
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01?ooool2o`00
00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo1?l00007ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo
017ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0000;o
oooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool2o`0000Kooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool003kooooo
00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo05?ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007oooool01Ol0
003ooooooooooooooooo000000kooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`0I
ooooo`00?_ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool0E?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`1Nooooo`03o`000?oooooooooo01Wooooo000mooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
05kooooo00?o0000ooooooooool06Oooool003gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Goooool00ol0003o
ooooooooo`0Hooooo`00;Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05oooooo
00?o0000ooooooooool06?ooool002cooooo00?o0000ooooool000003Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0E_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`1Oooooo`03o`000?oooooooooo01Sooooo000/ooooo`03o`000?oooooo000000gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05Oooooo00Go0000
ooooooooooooooooo`000007ooooo`;o00001?ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Oooooo`03o`000?oo
oooooooo01Sooooo000[ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Eoooool4o`0000Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo01Oooooo000[
ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0F?ooool2o`0000Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo01Oooooo000[ooooo`05o`000?oooooo
ooooooooool000003?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0Hoooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo063ooooo00?o
0000ooooooooool05oooool002_ooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Sooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0Gooooo`00:oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0:ooooo`;o00003Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Gooooo`00:_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`09ooooo`Co00003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Fooooo`00:_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`08ooooo`04o`000?ooooooooooo`0000cooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool05_ooool002[o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Tooooo`;o00001Oooool00ol0003o
ooooooooo`08ooooo`04o`000?ooooooooooo`0000cooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool05_ooool002[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo06;ooooo00?o0000oooo
ooooool05_ooool002[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Tooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo0000
00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
06;ooooo00?o0000ooooooooool05_ooool002[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`1Tooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool05_ooool001[ooooo
0_l0000=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0I?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`1Tooooo`03o`000?oooooooooo01Gooooo000Iooooo`Co00003?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0I?ooool00ol0003ooooooooo
o`0Eooooo`006Oooool01?l0003oooooooooool0000<ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0IOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo01Gooooo000I
ooooo`04o`000?ooooooooooo`0000cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1Uooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool05?ooool001Sooooo00Go0000
ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0IOoo
ool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo06Gooooo00?o0000ooooooooool05?ooool001Oooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0IOooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1Uooooo`03o`000?oooooooooo01Cooooo000Gooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
06Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0Cooooo`005_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`1Uooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo06Sooooo0_l0000Cooooo`007_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0IOooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1mooooo`007_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0IOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`1mooooo`007_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Foooool5o`0000Kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0OOooool001kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo05_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo07gooooo000Nooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Looooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol00006ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1mooooo`007_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0GOooool00onHV9So
8B4Qonk^kP06ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000009oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo07gooooo000Oooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`1Nooooo`03ogMgMomVIVKooooo00Gooooo00?o0000oooooooo
ool01oooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0O_ooool001oo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooo`00
00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0O_ooool001oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo05_ooooo00Go0000okZj^_ooooooV9RHoa0@4006oooo
o`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1n
ooooo`007oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0Foooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool01oooool0
1?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?oo
ool01Ol0003ooooooooooooooooo0000083ooooo000Oooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo00Sooooo0ol0
000;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool01Ol0003ooooooooo
oooooooo0000083ooooo000Oooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_oo
ool01Ol0003ooooooooooooooooo000000kooooo00Go0000ooooooooooooooooo`00001Yooooo`03
o`000?oooooooooo00Sooooo0_l0000<ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool03Oooool01Ol0003ooooooooooooooooo0000083ooooo000Oooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000kooooo00Go0000oooo
ooooooooooooo`00001Yooooo`;o00005oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00gooooo00Go0000ooooooooooooooooo`000020ooooo`007oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00000>ooooo`05o`000?oo
ooooooooooooool00000JOooool00ol0003oooooooooo`0Gooooo`05o`000?ooooooooooooooool0
00003oooool01Ol0003ooooooooooooooooo0000083ooooo000Pooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000kooooo00Go0000oooo
ooooooooooooo`00001Yooooo`03o`000?oooooooooo01Oooooo00Go0000ooooooooooooooooo`00
000?ooooo`05o`000?ooooooooooooooool00000P?ooool0023ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000000oooooo00Go0000oooooooooooooooo
o`00001Yooooo`03o`000?oooooooooo01Oooooo00Go0000ooooooooooooooooo`00000?ooooo`04
o`000?ooooooooooo`00087ooooo000Pooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooo`00000?ooooo`05o`000?ooooooooooooooool00000JOooool00ol0
003oooooooooo`0Gooooo`05o`000?ooooooooooooooool000004?ooool00ol0003oooooo`000021
ooooo`008?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03oooool01?l0003oooooooooool0001Yooooo`03o`000?oooooooooo01Oooooo00Go0000
ooooooooooooooooo`00000@ooooo`03o`000?oooooo0000087ooooo000Pooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool07oooool01?l0003oooooooooool0001Yooooo`03o`000?oo
oooooooo01Oooooo00Go0000ooooooooooooooooo`00000Aooooo`;o0000POooool0023ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo000006[ooooo00?o
0000ooooooooool06?ooool00ol0003oooooo`00000Booooo`03o`000?oooooooooo083ooooo000P
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08?ooool2o`0006[ooooo00?o0000
ooooooooool06?ooool00ol0003oooooo`00002Eooooo`008Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool0JOooool2o`0001Wooooo0ol0002Eoooo
o`008Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo08cooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`2Dooooo`008Oooool01Ol0003ooooooooooooooooo000008oo
oooo00?o0000ooooooooool0/?ooool0027ooooo00Go0000ooooooooooooooooo`00002?ooooo`03
o`000?oooooooooo0;3ooooo000Qooooo`05o`000?ooooooooooooooool00000Soooool00ol0003o
ooooooooo`2`ooooo`008Oooool01Ol0003ooooooooooooooooo000008oooooo00?o0000oooooooo
ool0/?ooool0027ooooo00Go0000ooooooooooooooooo`00002?ooooo`03o`000?oooooooooo0;3o
oooo000Rooooo`04o`000?ooooooooooo`0008oooooo00?o0000ooooooooool0/?ooool002;ooooo
00Co0000oooooooooooo0000Soooool2o`000;7ooooo000Rooooo`03o`000?oooooo0000093ooooo
00?o0000ooooooooool0/?ooool002?ooooo0_l0002@ooooo`03o`000?oooooooooo0;3ooooo000S
ooooo`;o0000T?ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00[?ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0/?ooool00:gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool5o`0000Kooooo00?o
0000ooooooooool0/?ooool00:[ooooo00CoA4A4omgMgOoooooo00001oooool3o`000;3ooooo002Z
ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0/?ooool00:_ooooo00?oMgMg
olc<c?l000001oooool00ol0003oooooooooo`2`ooooo`00Zoooool00oo^k^koA4A4o`000007oooo
o`03o`000?oooooooooo0;3ooooo002/ooooo`03ogMgMol0003ooooo00Kooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000
/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo
00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05oeEE
EOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@06ooooo`?o0000/?ooool00:[ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03
o`000?oooooooooo0;3ooooo002Zooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0
/?ooool00:[ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`2`ooooo`00Zoooool0
1?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_oo
ool00ol0003oooooooooo`2`ooooo`00Z_ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o
0000ooooooooool0/?ooool00:[ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo0;3ooooo002Zooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`000;3ooooo002Z
ooooo`05olc<c?l0003o0000o`000?o<c<`0^Oooool00:[ooooo00Go410@okZj^_oooooo^[Zjoa0@
402iooooo`00Z_ooool01Ol0003o^[Zjoooooonj^[[o00000;Wooooo002Zooooo`05ojVYZOl@413o
0000oa0@4?nYZJT0^Oooool00?ooooooJOooool00:oooooo00?o0000okZj^_ooool0]_ooool00:oo
oooo0_lb<S:gooooo`00P?ooool2o`000006oa0@4?oooooooooooa0@4?l0003o410@6?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`03ohN7Qol0
003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Iooooo`Co000000?o410@ooooooooool0
1Ol00003ooooo`Go0000N?ooool0087ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`07ooooo`Ko00003Oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`03olc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool0
0ol0003oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OnHV9So8B4Qonk^
k_ooooooA4A407Sooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06ooo
ool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo013ooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?oV9RHob4Q8Oo^k^h0
NOooool0087ooooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00003Oooool01OmgMgOo
<S8boooooooooooo000000?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;oooo
o`Ko00003?ooool00ol0003oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?oV9RHob4Q
8Oo^k^h0N?ooool0087ooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Iooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`05ooooo`03ogMgMomVIVKooooo00Gooooo00?oMgMgofIVI_ooool0
Moooool0087ooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Iooooo`03o`000?oooooooooo00Co
oooo00Go410@oooooooooooooooooa0@400@ooooo`03oa0@4?l0003o000000?o00007?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0M_ooool0087o
oooo00Ko0000oc8b<_oooooooooooc8b<_l0000Iooooo`03o`000?oooooooooo00Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0Booooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00_oo
ool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go0000okZj^_ooooooV9RHoa0@401hooooo`00
P?ooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Kooooo`03oeEEEOmVIVKo000000Co
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0N?ooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(124) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .18863 m
.00236 .18277 L
.00365 .1802 L
.00488 .17823 L
.00602 .17682 L
.00726 .17576 L
.00839 .17525 L
.00942 .17518 L
.01066 .1756 L
.01181 .1765 L
.01307 .17809 L
.01444 .18052 L
.01586 .18388 L
.01721 .1879 L
.01975 .19773 L
.02225 .21047 L
.02491 .22752 L
.0297 .26654 L
.03536 .31981 L
.03784 .34151 L
.04057 .36102 L
.04201 .36874 L
.04336 .374 L
.0441 .37603 L
.04478 .37732 L
.04556 .37813 L
.04631 .37823 L
.04706 .37767 L
.04785 .37636 L
.04853 .37468 L
.04928 .37224 L
.05095 .36482 L
.05251 .35569 L
.05839 .31171 L
.06096 .29264 L
.06377 .27521 L
.06501 .26911 L
.06633 .26381 L
.06757 .26001 L
.0687 .25762 L
.06998 .25616 L
.07071 .25593 L
.07137 .2561 L
.0726 .25737 L
.07389 .26008 L
.07519 .26416 L
.07658 .27006 L
.07909 .28449 L
.08481 .33082 L
.08746 .35431 L
Mistroke
.08996 .37399 L
.09134 .3829 L
.09207 .38684 L
.09284 .39037 L
.0942 .39487 L
.09545 .39691 L
.09616 .39712 L
.09693 .39656 L
.09832 .39352 L
.09916 .3904 L
.09996 .38661 L
.10146 .37748 L
.10414 .35577 L
.10704 .32701 L
.11237 .27199 L
.11528 .24566 L
.11801 .22531 L
.12033 .21173 L
.12283 .20105 L
.12419 .19697 L
.12487 .19537 L
.12561 .19396 L
.12693 .19232 L
.12815 .19179 L
.1295 .19231 L
.13017 .193 L
.13092 .19411 L
.13224 .19693 L
.13347 .20057 L
.13492 .20613 L
.13625 .2124 L
.13923 .23066 L
.14459 .27667 L
.14967 .32867 L
.15202 .35115 L
.15331 .362 L
.15453 .37085 L
.15564 .37762 L
.15666 .38253 L
.1578 .38638 L
.15902 .38853 L
.16025 .38853 L
.16139 .38658 L
.16264 .38233 L
.16398 .3755 L
.16539 .36601 L
.16671 .35519 L
.1692 .3313 L
.17939 .2271 L
.18453 .18985 L
Mistroke
.18745 .17425 L
.19019 .1628 L
.19269 .15465 L
.19506 .14868 L
.1972 .14456 L
.19952 .14119 L
.20204 .13858 L
.20345 .13748 L
.20473 .13667 L
.20592 .13604 L
.20722 .13549 L
.20842 .13508 L
.20956 .13478 L
.21086 .13453 L
.21205 .13438 L
.21333 .13431 L
.21406 .13431 L
.21473 .13432 L
.21584 .13439 L
.21706 .13453 L
.21835 .13472 L
.21955 .13494 L
.23051 .13709 L
.2357 .1379 L
.23853 .13831 L
.23991 .13847 L
.24116 .1386 L
.24254 .13871 L
.2433 .13875 L
.24402 .13877 L
.2448 .13879 L
.24552 .13879 L
.24631 .13877 L
.24714 .13875 L
.2485 .13867 L
.24976 .13858 L
.25263 .13829 L
.25751 .13769 L
.26209 .13701 L
.26737 .13598 L
.27215 .13501 L
.27492 .13455 L
.27746 .13424 L
.27879 .13413 L
.28025 .13403 L
.28098 .13399 L
.28177 .13396 L
.28251 .13394 L
.28319 .13393 L
.2845 .13393 L
Mistroke
.28571 .13395 L
.28704 .134 L
.28771 .13404 L
.28845 .1341 L
.28968 .13423 L
.29101 .13443 L
.29227 .13467 L
.29342 .13494 L
.29624 .13582 L
.29887 .13692 L
.30482 .14036 L
.31007 .14443 L
.31567 .15002 L
.32666 .16355 L
.33148 .16947 L
.33678 .17523 L
.33931 .17747 L
.34203 .17935 L
.34353 .18011 L
.34489 .18063 L
.34627 .18096 L
.34757 .18111 L
.34824 .18113 L
.34898 .18109 L
.34975 .181 L
.35048 .18087 L
.35177 .18051 L
.35317 .17996 L
.35471 .17917 L
.35634 .17814 L
.35925 .17581 L
.36949 .16415 L
.37511 .15728 L
.38043 .15173 L
.38296 .14956 L
.38563 .14768 L
.38703 .14689 L
.38857 .14619 L
.38925 .14595 L
.38997 .14573 L
.39128 .14547 L
.39255 .14537 L
.39392 .14544 L
.39523 .1457 L
.39644 .1461 L
.39763 .14666 L
.39872 .1473 L
.40115 .14924 L
.40363 .15193 L
.40592 .15507 L
Mistroke
.41108 .16468 L
.41563 .17606 L
.42043 .19048 L
.42555 .20704 L
.4304 .22162 L
.43308 .2283 L
.43449 .23124 L
.43599 .23382 L
.43725 .23551 L
.43863 .23685 L
.4399 .23755 L
.44108 .23774 L
.44221 .23751 L
.44344 .23679 L
.44472 .23554 L
.44592 .23393 L
.44806 .23007 L
.45035 .22475 L
.46034 .19421 L
.46558 .17845 L
.46844 .17108 L
.47112 .16531 L
.47401 .1605 L
.47554 .15858 L
.47633 .15778 L
.47719 .15704 L
.47797 .1565 L
.47869 .15611 L
.47938 .15583 L
.48012 .15564 L
.48138 .15559 L
.48211 .15571 L
.48279 .15593 L
.48402 .15659 L
.48537 .15771 L
.48678 .15935 L
.48809 .16133 L
.49045 .16603 L
.49297 .17276 L
.49593 .18302 L
.49872 .19502 L
.50396 .22279 L
.50921 .25475 L
.51414 .28269 L
.51661 .29363 L
.518 .29837 L
.51928 .30167 L
.52066 .30404 L
.52145 .30479 L
.52218 .3051 L
Mistroke
.52351 .30468 L
.52426 .3039 L
.52493 .30286 L
.52615 .30025 L
.52743 .29651 L
.52972 .28761 L
.53491 .26084 L
.53973 .23402 L
.5443 .21234 L
.54679 .20326 L
.54811 .19944 L
.54951 .19619 L
.55068 .19413 L
.55197 .19259 L
.55315 .19189 L
.55425 .19185 L
.55556 .1926 L
.55693 .19433 L
.55811 .19658 L
.55939 .19989 L
.56078 .20446 L
.56226 .21052 L
.56492 .22455 L
.57011 .26307 L
.57501 .30933 L
.57729 .33132 L
.57975 .35281 L
.58093 .36179 L
.58206 .36918 L
.58309 .37478 L
.58418 .37943 L
.58538 .3829 L
.5865 .38445 L
.58783 .38416 L
.58904 .38191 L
.59036 .37736 L
.59111 .37389 L
.5918 .37017 L
.59439 .35216 L
.59954 .30543 L
.6052 .25533 L
.60755 .2386 L
.61008 .2244 L
.6113 .21896 L
.61246 .21471 L
.61349 .21166 L
.61463 .20909 L
.61583 .20728 L
.6171 .20638 L
.61829 .20648 L
Mistroke
.61939 .20738 L
.6207 .20944 L
.62189 .21227 L
.62326 .21667 L
.62457 .22196 L
.62729 .23633 L
.62984 .25382 L
.63463 .29444 L
.63734 .31948 L
.64021 .34436 L
.64266 .36193 L
.64405 .36962 L
.64535 .37496 L
.64655 .37814 L
.64769 .37951 L
.64871 .37934 L
.64982 .37763 L
.65103 .37402 L
.65231 .36828 L
.65341 .36196 L
.65462 .35361 L
.66465 .25884 L
.6698 .21503 L
.67262 .19591 L
.67523 .18111 L
.67987 .16109 L
.68232 .15324 L
.68495 .14658 L
.68777 .14103 L
.69084 .13651 L
.69374 .13328 L
.69641 .13095 L
.69903 .12914 L
.70147 .12783 L
.70403 .1268 L
.70538 .12638 L
.70684 .12602 L
.70821 .12574 L
.70951 .12554 L
.711 .12535 L
.71235 .12522 L
.71363 .12513 L
.71481 .12506 L
.7161 .12502 L
.71746 .125 L
.71884 .12502 L
.71962 .12504 L
.72032 .12508 L
.72169 .12518 L
.72299 .12532 L
Mistroke
.7245 .12554 L
.72589 .12578 L
.72905 .12651 L
.73392 .12797 L
.73929 .13004 L
.74489 .13287 L
.75015 .13616 L
.76957 .15046 L
.77489 .15393 L
.77782 .15548 L
.78057 .15666 L
.78315 .15751 L
.7846 .15787 L
.78594 .15813 L
.78706 .15829 L
.7883 .1584 L
.78959 .15844 L
.7908 .15841 L
.79211 .15829 L
.79284 .15819 L
.79353 .15807 L
.79478 .1578 L
.79611 .15744 L
.79866 .15655 L
.80096 .15556 L
.81187 .14947 L
.81736 .14617 L
.82025 .1446 L
.82329 .14319 L
.82596 .14221 L
.82748 .14178 L
.82889 .14147 L
.83019 .14127 L
.83137 .14115 L
.83274 .14109 L
.83403 .14113 L
.83523 .14124 L
.83653 .14145 L
.83775 .14175 L
.83887 .1421 L
.84018 .14261 L
.84161 .14331 L
.84421 .14496 L
.84691 .14723 L
.8498 .15025 L
.855 .15725 L
.86508 .17572 L
.87436 .19431 L
.87707 .19883 L
.87961 .20231 L
Mistroke
.88099 .20385 L
.88225 .20501 L
.88365 .20601 L
.88443 .20642 L
.88516 .20672 L
.88583 .20691 L
.88656 .20704 L
.88734 .20707 L
.88806 .207 L
.88936 .20665 L
.89008 .20632 L
.89075 .20595 L
.89217 .20491 L
.89372 .2034 L
.89684 .19932 L
.90793 .17843 L
.91318 .16834 L
.91802 .16052 L
.92043 .15741 L
.9231 .15472 L
.92448 .15365 L
.92577 .15288 L
.92714 .1523 L
.9279 .15209 L
.9286 .15196 L
.92988 .15191 L
.93106 .15208 L
.93235 .1525 L
.93373 .15323 L
.93505 .15421 L
.93629 .15539 L
.9386 .15829 L
.94128 .16287 L
.94411 .16917 L
.94918 .18428 L
.9606 .23147 L
.96302 .2417 L
.96566 .25171 L
.96798 .25904 L
.96925 .26228 L
.97045 .26476 L
.97181 .26687 L
.97253 .26765 L
.97331 .26823 L
.9747 .26856 L
.97596 .26809 L
.97713 .267 L
.97841 .26512 L
.97975 .26243 L
.98099 .25932 L
Mistroke
.98581 .24291 L
.99019 .22484 L
1 .18863 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo03gooooo3?l0001Wooooo`00]Oooool2o`0003cooooo0_l0000<ooooo`;o
0000IOooool006kooooo1Ol00012ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
3Oooool2o`0006?ooooo001Gooooo`[o00002?ooool5o`0000Cooooo1Ol0000nooooo`03o`000?oo
oooooooo03[ooooo00?o0000ooooooooool04?ooool2o`00067ooooo001Fooooo`03o`000?oooooo
oooo00Sooooo2?l0000>ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo05kooooo001Eooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool04Oooool7o`0004Gooooo001Dooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool05_ooool4o`00023ooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo00gooooo0ol00006ooooo`03o`000?oooooooooo04?o
oooo001Dooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool05?ooool2o`0000?ooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool02_ooool2o`0000[ooooo00?o0000ooooooooool0@_ooool005Cooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Gooooo1?l0
000Xooooo`00Doooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`;o00001Oooool2o`0003Sooooo00?o0000
ooooooooool06_ooool2o`0000Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo00;o00009oooool005?ooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04oooool2o`00
0003ooooool0003o000000?ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Loooo
o`Oo00004Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool09?ooool005;ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool04_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Tooooo`005Oooool2o`000009
oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo00GoV9RHoa0@4?l0003o<S8b
olc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool00ol0003oooooooooo`0=ooooo`Go
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00oooooo00?o0000ooooooooool02_ooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h2ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000027ooooo1?l000002?l@413o
ooooooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool00ol0003oooooooooo`0<ooooo`Go00000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00_ooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0>ooooo`005_oo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01Ol@413o^[Zj
oooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo
00gooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooo000000Cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`02ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00oooool01?l0003ooooo
ooooool0000Sooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`03o`000?oooooooooo00cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL06oooool01Ol@413o^[Zjo`000?mgMgOo<S8b00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool000_ooooo1_l00002ooooo`Go
00000oooool01Ol@413ooooooooooooooooo410@01;ooooo1_l00006ooooo`05o`000?oooooooooo
ooooool@41000oooool00ol@413oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo1_l00003
ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oo
oooooooo00Ko00000_ooool01?l0003oooooooooool00004ooooo`05oa0@4?ooooooooooooooool@
41000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooo
oooo00008oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002oooool0
0ol0003oooooooooo`0=ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@
400Nooooo`;o00000oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`08ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00ko
oooo000Cooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000Moooo
o`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooo
oooo013ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo0000017ooooo00?o
0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooo`00000Sooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000:oooo
o`03o`000?oooooooooo00oooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo
000001kooooo00?o0000oa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`04odA4A?oMgMgoooooo`0000Cooooo
00Go0000ooooooooooooooooo`00000>ooooo`004oooool00ooMgMgoEEEEooooo`06o`0000?ooooo
00?o0000ooooooooool06_ooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool0
00002_ooool00ol0003oooooooooo`0Aooooo`03ogMgMomVIVKooooo00;ooooo00Go0000oooooooo
ooooooooo`00000Booooo`;o00001?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooo000002?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000[ooooo00?o0000ooooooooool04?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?oo
ooooooooooooool000007Oooool00ol@413o0000o`000003ooooo`05o`000?ooooooooooooooool0
00001Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00CogMgMoeEEEOoo
oooo00001?ooool01Ol0003ooooooooooooooooo000000kooooo000Dooooo`04ogMgMoo<c<co0000
o`0000;ooooo00?o0000oa0@4?ooool00_ooool00ol@413oooooooooo`0Kooooo`03okZj^_lQ8B7o
oooo00;ooooo00Go410@oooooooooooooooooa0@400:ooooo`03o`000?oooooooooo01;ooooo00Go
0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01;ooooo1Ol00005ooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool01oooool3o`0002;ooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@00[ooooo00?o0000ooooooooool04Oooool01Ol0003ooooooooooooooooo
410@00?ooooo00?o410@ooooooooool07?ooool00onj^[[o0000ooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41001Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o
MgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00kooooo000Dooooo`03onk^k_m4
A4Co000000Cooooo00Go0000oiRHV?ooooooV9RHogMgM`0Jooooo`05oa0@4?nHV9SooooookZj^_l0
00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Wooooo00?o0000ooooooooool03oooool01Ol0
003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool01oooool2o`0002?ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00[ooooo00?o0000ooooooooool03Oooool01Ol0003o^[ZjoooooonHV9So410@
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`04oa0@4?nHV9SooooookZj^P;o00000_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`07ooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`00
5Oooool00omgMgOo0000ooooo`03ooooo`05o`000?lb<S;o0000oc8b<_o^k^h06_ooool01OnYZJWo
410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP09ooooo`03o`000?oooooo
oooo00oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
7?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo0_l0000Qooooo`03oeEEEOmVIVKo000000Co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0:ooooo`03o`000?oooooooooo00gooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool01_nYZJWo410@o`00
0?l@413oZJVYo`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02?ooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03_ooool001Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0boooo
o`03o`000?oooooooooo04Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08oooo
o`;o0000=_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo017ooooo000Kooooo`03
o`000?oooooooooo023ooooo0_l0000@ooooo`03o`000?oooooooooo04Wooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`08ooooo`;o00003oooool3o`0002Cooooo00?o0000oooooooo
ool0??ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0Aooooo`007?ooool00ol0003oooooooooo`0Nooooo`Co0000
3oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool2o`0000oooooo00?o0000ooooool000009?ooool00ol0003oooooooooo`0mooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo017ooooo000Looooo`03o`000?oooooooooo01kooooo00Co0000oooooooooooo0000
3oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool2o`0000kooooo00Go0000ooooooooooooooooo`00000Sooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool04_ooool001cooooo00?o0000ooooooooool07_ooool01?l0003ooooo
ooooool0000?ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0:ooooo`;o00003_ooool01Ol0003ooooooooooooooooo000002?ooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0Booooo`005_ooooooo`00043o00004oooool001Kooooo
00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`05o`000?ooooooooooooooool0
00001oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ool000001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01Oooool01?l0003oooooooooooooool3o`000003ooooool0003ooooo00Kooooo00?o0000
ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooooooo0_l00002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000004ooo
ool001Kooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`05o`000?oooooo
ooooooooool000001oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l0
0006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooo000000?ooooo00Go0000ooooooooooooooooo`000007ooooo`05o`00
0?ooooooooooooooool000000_ooool2o`0000Oooooo00?o0000ooooooooool00oooool00ol0003o
ooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooo000001?ooooo000Mooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0=ooooo`04o`000?ooooooooooo`0000ko
oooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01?o
oooo000Mooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0<ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`1Iooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool04oooool001kooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
COooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo0_l0000<ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01Cooooo000Nooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0=ooooo`;o00002oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo05Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Dooooo`007_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool2
o`0000_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool05?ooool001kooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0C_ooool01Ol0
003ooooooooooooooooo0000013ooooo0_l0000;ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0Foooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Cooooo000Noooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo04kooooo00Go0000ooooooooooooooooo`00000@ooooo`?o00002_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Dooooo`007_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1?ooooo`?o00004Oooool00ol0
003oooooo`00000:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Foooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo01Gooooo000Nooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo06?o
oooo00?o0000ooooool000002_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05_o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Eooooo`007_ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`1Sooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`1Kooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05Oooool001kooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0I?ooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0Foooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Gooooo000O
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo06Cooooo00Co0000oooooooooooo00002?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Fooooo`007oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`1Tooooo`04o`000?ooooooooooo`0000Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool05_ooool001oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1T
ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`1Mooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05_ooool001oooooo00?o0000
ooooooooool02_ooool2o`0000cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo06Cooooo0_l000000ooooooo0000ooooo`06ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0G_ooool01Ol0003ooooooooooooooooo000001Wooooo000O
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooool000002oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0I?ooool01?l0003oooooooooool0
0007ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G_ooool01Ol0003ooooooooo
oooooooo000001Wooooo000Oooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo0000
2_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
I?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0Goooool00ol0003oooooo`00000Jooooo`007oooool00ol0003oooooooooo`08ooooo`05o`00
0?ooooooooooooooool000002_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0I?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0Goooool3o`0001[ooooo000Oooooo`03o`000?oooooooooo00So
oooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`1Tooooo`05o`000?ooooooooooooooool000001Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo07cooooo000Oooooo`03o`000?oooooooooo
00Sooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`1Tooooo`05o`000?ooooooooooooooool000001Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07cooooo000Oooooo`03o`000?oooooo
oooo00Sooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1Tooooo`05o`000?ooooooooooooooool00000
1Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo07gooooo000Oooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Uooooo`05o`000?oo
ooooooooooooool000001Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo07gooooo
000Pooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`1Uooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0OOooool0023ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo06Gooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0OOooool0023ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0OOooool0023ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06Gooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0OOoo
ool0023ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo06Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0OOooool0023ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool00oooool00ol0003oooooo`00000?
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo07gooooo000Pooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1Jooooo`Go00001_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooo000000oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0OOooool0023ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05[ooooo00GoV9RHob4Q8Oo^
k^koooooodA4A006ooooo`03o`000?oooooooooo00?ooooo0ol0000?ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
07gooooo000Pooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`1Kooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0000Eooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07ko
oooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`1Looooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1nooooo`008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0G_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0O_ooool0027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo07kooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`1Kooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo07kooooo000Qooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Kooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07kooooo000Qoooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Voooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0O_ooool0027ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06Kooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`1nooooo`008_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0I_ooool2o`0001Kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
O_ooool002;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo06Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1nooooo`008_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0I_ooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool0
1Ol0003ooooooooooooooooo0000087ooooo000Rooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool00000POoo
ool002;ooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06Oooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00Go
0000ooooooooooooooooo`000021ooooo`008_ooool01Ol0003ooooooooooooooooo000000_ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool03?ooool01Ol0003ooooooooooooooooo0000087ooooo000Sooooo`04o`00
0?ooooooooooo`0000_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool01Ol0003ooooooooooooooooo0000
087ooooo000Sooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Ioooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool01Ol0
003ooooooooooooooooo0000087ooooo000Sooooo`04o`000?ooooooooooo`0000_ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0Ioooool00ol0003oooooooooo`0Gooooo`05o`000?ooooooooooooooool000003_oo
ool01Ol0003ooooooooooooooooo0000087ooooo000Sooooo`04o`000?ooooooooooo`0000_ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool0
0000J_ooool2o`0001Sooooo00Go0000ooooooooooooooooo`00000>ooooo`05o`000?oooooooooo
ooooool00000POooool002?ooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00cooooo00Go0000ooooooooooooooooo`00001Zooooo`03o`000?oo
oooooooo01Oooooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo0000087o
oooo000Sooooo`04o`000?ooooooooooo`0000_ooooo00Go0000ooooooooooooooooo`00000@oooo
o`04o`000?ooooooooooo`0006[ooooo00?o0000ooooooooool05oooool01?l0003oooooooooool0
000@ooooo`03o`000?oooooo000008;ooooo000Sooooo`03o`000?oooooo000000cooooo00Go0000
ooooooooooooooooo`00000@ooooo`04o`000?ooooooooooo`0006[ooooo00?o0000ooooooooool0
5oooool01?l0003oooooooooool0000@ooooo`03o`000?oooooo000008;ooooo000Sooooo`?o0000
3?ooool01Ol0003ooooooooooooooooo0000013ooooo00Co0000oooooooooooo0000J_ooool00ol0
003oooooooooo`0Gooooo`04o`000?ooooooooooo`00013ooooo00?o0000ooooool00000P_ooool0
02Cooooo0_l0000<ooooo`05o`000?ooooooooooooooool000004?ooool01?l0003oooooooooool0
001Zooooo`03o`000?oooooooooo01Oooooo00Co0000oooooooooooo00004Oooool2o`0008;ooooo
000cooooo`04o`000?ooooooooooo`00013ooooo00?o0000ooooool00000Joooool00ol0003ooooo
ooooo`0Hooooo`;o00004_ooool00ol0003oooooooooo`21ooooo`00<oooool01?l0003ooooooooo
ool0000Aooooo`;o0000Joooool00ol0003oooooooooo`0Hooooo`;o0000U_ooool003?ooooo00Co
0000oooooooooooo00004Oooool2o`0006_ooooo0_l0002aooooo`00<oooool00ol0003oooooo`00
001oooooo`03o`000?oooooooooo0;3ooooo000dooooo`;o0000Ooooool00ol0003oooooooooo`2`
ooooo`00=?ooool2o`0007oooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00:cooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0;3ooooo
002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool00:[ooooo1Ol00006
ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`
ooooo`00Z_ooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo0;3ooooo002[oooo
o`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0/?ooool00:_ooooo00?ok^k^odA4A?l0
00001oooool00ol0003oooooooooo`2`ooooo`00[?ooool00omgMgOo0000ooooo`06ooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_oo
ool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?nH
V9SooooooiRHV?lQ8B401_ooool3o`000;3ooooo002Zooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
1_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0;3ooooo002Zooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0/?ooool0
0:_ooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06
ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`2`ooooo`00Z_ooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0002`
ooooo`00Z_ooool01Oo<c<co0000o`000?l0003oc<c<0;Wooooo002Zooooo`05oa0@4?nj^[[ooooo
okZj^_l@4100^Oooool00:[ooooo00Go0000okZj^_oooooo^[Zjo`00002iooooo`00Z_ooool01OnY
ZJWo410@o`000?l@413oZJVY0;Wooooo003oooooofWooooo002_ooooo`03o`000?nj^[[ooooo0;Ko
oooo002_ooooo`;o<S8b]oooool0083ooooo0_l000001_l@413oooooooooool@413o0000oa0@41So
oooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
0on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06Oooool4o`000003oa0@4?oo
oooooooo00Go00001Oooool2o`000003oa0@4?oooooooooo07Kooooo0021ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01oooool6o`0000gooooo00WoMgMgoc8b<_ooooooooooogMg
MonHV9SooooooiRHV?mgMgL00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMg
Mol@41002Oooool6o`0000cooooo00?o0000ooooooooool00_ooool01OnHV9So8B4Qonk^k_oooooo
A4A400Kooooo00?o0000ooooooooool0Moooool0087ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Kooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool04?ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h01?ooool5
o`0007Sooooo0021ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000gooooo00Go
MgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
2oooool6o`0000cooooo00?o0000ooooooooool01?ooool00onHV9So8B4Qonk^kP03ooooo`04odA4
A?oMgMgoooooo`0007Wooooo0021ooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo00006Oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool01Oooool00omgMgOoIVIVooooo`02ooooo`04omgMgOmE
EEGoooooo`0007Wooooo0021ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo00006Oooool00ol0003o
ooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol@413o0000o`000003o`00
01cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03ogMgMoo<c<co0000
07Wooooo0021ooooo`06o`000?lb<S;ooooooooooolb<S;o00006Oooool00ol0003oooooooooo`04
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00;ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03onk^k_m4A4Co000007Wooooo
0020ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool4o`0000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0Booooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l00000
1?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo00?oMgMgo`000?ooool0N?ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(126) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .14859 m
.01975 .22477 L
.02492 .26468 L
.02981 .30269 L
.03251 .32007 L
.03403 .32779 L
.03476 .33082 L
.03544 .33325 L
.03663 .33647 L
.03793 .33847 L
.0392 .33882 L
.04057 .33743 L
.04129 .33597 L
.04197 .33419 L
.04349 .32871 L
.04484 .32238 L
.04628 .31435 L
.0515 .27831 L
.05639 .24356 L
.05896 .22776 L
.06168 .21403 L
.06323 .20778 L
.06493 .20238 L
.06568 .20051 L
.06648 .19885 L
.06724 .19763 L
.06793 .19679 L
.06868 .1962 L
.06937 .19595 L
.07014 .19601 L
.07095 .19646 L
.07231 .19811 L
.07308 .19957 L
.07381 .20127 L
.07516 .20532 L
.07657 .21086 L
.0791 .22417 L
.08183 .24358 L
.08481 .27081 L
.08989 .32852 L
.09257 .36055 L
.0954 .39101 L
.09659 .40173 L
.09788 .41133 L
.09861 .41582 L
.09929 .41921 L
.1006 .42378 L
.10178 .42544 L
.10306 .42457 L
.10428 .42122 L
Mistroke
.1054 .41603 L
.10691 .40618 L
.10833 .39431 L
.11098 .36714 L
.11693 .29892 L
.12196 .25152 L
.12334 .24161 L
.12479 .23269 L
.12615 .22581 L
.1274 .22065 L
.12868 .21651 L
.12935 .21483 L
.13008 .21333 L
.13131 .21165 L
.13262 .21099 L
.1338 .21139 L
.13508 .21287 L
.13628 .21525 L
.13738 .21828 L
.13867 .22285 L
.13986 .22807 L
.14258 .24332 L
.14806 .28672 L
.15286 .3328 L
.15738 .37234 L
.1586 .38065 L
.15988 .38786 L
.16055 .3909 L
.16129 .39363 L
.16259 .39676 L
.16377 .39769 L
.16504 .39662 L
.16623 .39366 L
.16732 .38938 L
.16856 .38284 L
.16972 .3752 L
.17236 .35345 L
.17771 .30009 L
.1824 .25522 L
.18734 .21726 L
.18995 .20146 L
.1928 .1872 L
.19782 .16877 L
.20065 .16139 L
.20367 .15531 L
.20913 .14744 L
.21471 .14176 L
.21986 .13804 L
.22552 .13515 L
.23151 .13263 L
Mistroke
.23402 .13171 L
.23671 .1309 L
.23802 .13058 L
.23926 .13033 L
.24048 .13013 L
.24158 .12998 L
.24291 .12984 L
.24364 .12979 L
.24433 .12974 L
.24556 .12969 L
.24688 .12966 L
.24758 .12966 L
.24835 .12966 L
.24915 .12968 L
.24989 .12971 L
.25123 .1298 L
.25198 .12987 L
.25267 .12995 L
.2539 .13013 L
.25507 .13036 L
.25645 .1307 L
.25772 .13109 L
.2603 .13211 L
.26308 .13353 L
.26778 .1366 L
.27272 .14068 L
.28314 .1528 L
.29452 .16846 L
.30008 .1752 L
.30281 .17788 L
.30401 .17887 L
.30532 .17981 L
.30643 .18046 L
.30761 .18102 L
.30886 .18145 L
.31003 .18169 L
.3114 .18178 L
.3127 .18169 L
.31386 .18145 L
.31513 .18104 L
.31663 .18035 L
.31803 .17952 L
.32066 .17751 L
.32349 .17471 L
.32655 .17106 L
.33713 .15595 L
.34715 .14336 L
.3499 .14065 L
.35283 .13825 L
.35426 .1373 L
Mistroke
.3556 .13654 L
.35691 .13595 L
.35813 .13551 L
.3594 .13519 L
.36008 .13508 L
.3608 .135 L
.36156 .13496 L
.36229 .13497 L
.36364 .13511 L
.36491 .13537 L
.36608 .13574 L
.36737 .13628 L
.36874 .13703 L
.37023 .13806 L
.37185 .13944 L
.37478 .14269 L
.37764 .14689 L
.38026 .15168 L
.39061 .17868 L
.3963 .19772 L
.4017 .21586 L
.40413 .22307 L
.40671 .2295 L
.40806 .23221 L
.40954 .23462 L
.41089 .23624 L
.41216 .23725 L
.41333 .23772 L
.41456 .23774 L
.41561 .23737 L
.41676 .23657 L
.418 .23525 L
.41932 .23333 L
.42171 .22866 L
.431 .20057 L
.44083 .16921 L
.44597 .15681 L
.44889 .15131 L
.45162 .14725 L
.45291 .14572 L
.45413 .1445 L
.45524 .14359 L
.45642 .14282 L
.4577 .14223 L
.45888 .1419 L
.45961 .14181 L
.46029 .14179 L
.46157 .14195 L
.46287 .14237 L
.46361 .14272 L
Mistroke
.4643 .14312 L
.46569 .14417 L
.46718 .14564 L
.46988 .14928 L
.47234 .15382 L
.4752 .16073 L
.47831 .17037 L
.48397 .19366 L
.49403 .24878 L
.49938 .27682 L
.50084 .28295 L
.50238 .28833 L
.50369 .29192 L
.50443 .2935 L
.50513 .29468 L
.50581 .29554 L
.50654 .29615 L
.50782 .29638 L
.50855 .29604 L
.50931 .29532 L
.51069 .29313 L
.51196 .29012 L
.51315 .28653 L
.51586 .27593 L
.52592 .22281 L
.53139 .1964 L
.53408 .1859 L
.53657 .17789 L
.53943 .17077 L
.54094 .16789 L
.54254 .16548 L
.54388 .16398 L
.54513 .16299 L
.54651 .16238 L
.54728 .16226 L
.54799 .1623 L
.54933 .16276 L
.55059 .16367 L
.55172 .16491 L
.55295 .16672 L
.55429 .16927 L
.55571 .17266 L
.55826 .18061 L
.56061 .19021 L
.56281 .20128 L
.56783 .23429 L
.57315 .27987 L
.57597 .30599 L
.57897 .33238 L
.58045 .34388 L
Mistroke
.58184 .35328 L
.5832 .3608 L
.58446 .36606 L
.58565 .36946 L
.5869 .37124 L
.58817 .37112 L
.58955 .36879 L
.59023 .36683 L
.59098 .3641 L
.59233 .35769 L
.59486 .34133 L
.60055 .2929 L
.60553 .25063 L
.60826 .23125 L
.61082 .21643 L
.61313 .20613 L
.61443 .20168 L
.61562 .19846 L
.61685 .196 L
.6182 .19434 L
.61888 .19392 L
.61961 .19377 L
.62092 .1943 L
.62213 .19572 L
.62344 .19826 L
.62468 .20165 L
.62582 .20563 L
.62798 .21549 L
.63027 .22934 L
.63545 .27354 L
.64018 .3254 L
.64265 .35291 L
.64528 .37889 L
.64679 .39104 L
.64816 .39966 L
.64953 .4057 L
.65083 .40872 L
.65203 .40912 L
.6533 .40698 L
.65438 .40314 L
.65557 .39689 L
.65685 .38796 L
.65822 .37621 L
.66069 .35064 L
.67006 .24341 L
.67276 .2186 L
.67563 .19687 L
.67811 .18164 L
.68077 .16848 L
.68363 .15758 L
Mistroke
.68631 .14994 L
.68794 .14633 L
.68949 .14354 L
.69102 .14134 L
.69241 .13973 L
.69363 .1386 L
.69494 .13762 L
.69634 .13682 L
.69765 .13626 L
.69888 .13589 L
.70018 .13564 L
.70129 .13553 L
.70251 .13552 L
.70325 .13557 L
.70395 .13565 L
.70527 .13589 L
.706 .13608 L
.70668 .13628 L
.70822 .13685 L
.7108 .13809 L
.71355 .13971 L
.72361 .1466 L
.7291 .1505 L
.73421 .15383 L
.73646 .15505 L
.73858 .156 L
.73976 .15644 L
.74103 .15684 L
.74218 .15714 L
.74326 .15737 L
.74445 .15756 L
.74576 .1577 L
.74704 .15777 L
.74841 .15777 L
.74968 .1577 L
.75089 .15757 L
.75198 .15739 L
.75316 .15714 L
.75454 .15676 L
.75584 .15632 L
.75826 .15529 L
.76369 .15217 L
.77346 .14536 L
.78411 .13821 L
.7867 .13685 L
.78947 .13567 L
.79106 .13514 L
.79251 .13474 L
.79397 .13443 L
.79535 .13422 L
Mistroke
.79656 .1341 L
.7979 .13404 L
.79857 .13404 L
.79929 .13407 L
.8006 .13418 L
.80184 .13437 L
.80314 .13467 L
.80425 .135 L
.80546 .13546 L
.80822 .13687 L
.81116 .13897 L
.81645 .14429 L
.82169 .15148 L
.82662 .16005 L
.83586 .17953 L
.84114 .19073 L
.84608 .19953 L
.84856 .20293 L
.84984 .20434 L
.85123 .20558 L
.85202 .20614 L
.85275 .20656 L
.85345 .20687 L
.85419 .2071 L
.85492 .20723 L
.85561 .20726 L
.85689 .20708 L
.85802 .20667 L
.85926 .20595 L
.86055 .20491 L
.86175 .20369 L
.86621 .19733 L
.87108 .18805 L
.87628 .17683 L
.887 .1552 L
.88994 .1506 L
.89305 .14653 L
.89571 .14375 L
.89722 .14247 L
.89864 .14144 L
.89996 .14068 L
.90065 .14034 L
.90139 .14004 L
.90269 .13965 L
.9039 .13945 L
.90464 .13941 L
.90543 .13944 L
.90618 .13954 L
.90687 .13969 L
.90818 .14014 L
Mistroke
.90956 .14086 L
.91078 .1417 L
.91208 .14283 L
.91444 .14546 L
.91724 .14966 L
.91979 .15456 L
.93032 .1871 L
.93564 .21031 L
.94152 .23721 L
.94395 .24729 L
.94651 .25635 L
.94785 .26025 L
.94931 .26372 L
.95065 .26608 L
.95189 .26754 L
.95315 .26827 L
.95435 .26823 L
.95543 .26759 L
.95659 .26625 L
.95786 .26407 L
.95921 .26097 L
.96162 .25365 L
1 .14859 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo001Qooooo`So0000C?ooool2o`000;7ooooo001Nooooo`?o0000
2?ooool2o`0004[ooooo00?o0000ooooooooool0Foooool3o`0005;ooooo001Mooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool06?ooool6o`0002Wooooo00?o0000ooooooooool0>ooo
ool5o`0001Sooooo0ol00002ooooo`?o0000D?ooool005_ooooo0_l0000?ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo03[ooooo0_l00004ooooo`?o00004oooool2o`0000Sooooo00?o0000ooooooooool06Oooool4
o`00033ooooo001Jooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05?ooool2o`00
00Oooooo00?o0000ooooooooool05oooool4o`0000[ooooo00?o0000ooooooooool0>Oooool2o`00
00Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
01Oooooo0_l00002ooooo`;o0000;oooool005Wooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05_ooool01Ol0003o
oooooooooooooooo000000[ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00cooooo0_l0000=ooooo`03o`000?oooooooooo01Gooooo0_l00005oooo
o`03o`000?oooooooooo02cooooo000Fooooo`03o`000?oooooooooo03oooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0Aooooo`005_ooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`;o0000
4Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0Aooooo`005_ooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`;o0000>?oo
ool00ol0003oooooooooo`0=ooooo`?o00001Oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo01;ooooo000Gooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`0?ooooo`Ko00005Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Booooo`005oooool00ol0
003oooooooooo`0looooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo01;ooooo000Eooooo`?o00000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^01[ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03oooool00ol0003oooooooooo`09ooooo`Go00000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`Co0000
00So410@o`000?ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo0000ooooo`0@
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00?o0000oooooooo
ool03?ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Cooooo`03o`000?oooooooooo
00Gooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02_oo
ool00ol0003oooooooooo`0@ooooo`;o000000Wo410@o`000?ooooooooooonk^k_lb<S;o0000oc8b
<_o^k^h03_ooool001Kooooo0_l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01Ol@
413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oo
oooooooo00[ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00[o0000oooooooo
ooooooooo`000?mgMgOoV9RHoooooonHV9SoMgMg3?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000001;o
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000oooo
ooooool03?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Dooooo`03o`000?oooooooooo00Cooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMg
Mol0003ooooooiRHV?mgMgL02_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo000000;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`002oooool6o`0000;ooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41004_ooool6o`0000Kooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo00cooooo00?o0000ooooooooool00_ooool6o`0000?ooooo00?oV9RH
ob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00Cooooo00?o0000ooooooooool02?oo
ool01?l0003oooooooooooooool6o`0000Gooooo00Ko0000ooooooooooooooooo`000?l@4103oooo
o`03oa0@4?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400;ooooo`03o`000?oooooo
oooo00gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@01Cooooo00?o
0000ooooooooool02?ooool01_l0003ooooooooooooooooo410@o`0000;ooooo00?o410@oooooooo
ool02?ooool00ol0003oooooooooo`0>ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@
00kooooo000Cooooo`06odA4A?oMgMgoooooo`000?oooooo00000_ooool01Ol0003ooooooooooooo
oooo000001gooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000gooooo
00?o0000ooooooooool03Oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool0
00001Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00gooooo00Co0000oooooooo
oooooooo0_l00003ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000;
ooooo`03o`000?oooooooooo00kooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooo
oooo000001Gooooo00?o0000ooooooooool01_ooool00onYZJWo410@ooooo`02ooooo`;o00000_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00gooooo00?oA4A4omgMgOooool00_l0
0003ooooo`05o`000?ooooooooooooooool000003_ooool001?ooooo00KogMgMoeEEEOoooooo0000
ooooool00002ooooo`05o`000?ooooooooooooooool000007?ooool00ol@413o0000okZj^P03oooo
o`05o`000?ooooooooooooooool000003Oooool00ol0003oooooooooo`0>ooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`;o00001Oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000002oooool00ol0003oooooooooo`0?ooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Eooooo`03o`000?oooooooooo00Gooooo00?o410@o`00
0?nj^[X00oooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000ooooooooool03Oooool0
0ooMgMgoEEEEooooo`02o`0000?ooooo00Go0000ooooooooooooooooo`00000>ooooo`005?ooool0
1OmgMgOoc<c<o`000?oooooo000000;ooooo00Go410@oooooooooooooooooa0@400Mooooo`03okZj
^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03o`000?oooooooooo00oo
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Gooooo0ol000000ooo
oooo0000o`00000Aooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooooa0@400:
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool2o`0000[ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400;ooooo`03o`000?oooooooooo013ooooo00Go0000oooooooooooooooo
oa0@4003ooooo`03oa0@4?oooooooooo01Cooooo00?o0000ooooooooool01Oooool00onj^[[o8B4Q
ooooo`02ooooo`05o`000?ooooooooooooooool@41002oooool00ol0003oooooooooo`0>ooooo`04
ogMgMoo<c<co0000o`0000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`005?ooool00oo^
k^koA4A4o`000002ooooo`07o`000?ooooooMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05oa0@4?nH
V9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooooooo
ool03?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`09
ooooo`?o00004_ooool00ol0003oooooooooo`02ooooo`05o`000?nHV9SooooooiRHV?mgMgL02_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000ooooooooool03?ooool01Ol0003o^[Zj
oooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Fooooo`03o`000?oooooooooo
00;ooooo00Go410@oiRHV?oooooo^[Zjo`000002ooooo`06o`000?mgMgOoV9RHoooooonHV9SoMgMg
3?ooool00ol0003oooooooooo`0=ooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0>ooooo`005Oooool02omgMgOo0000oooooooooooo0000ooooooo^k^ko<S8bo`000?lb
<S;ok^k^01[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03?ooool00ol0003oooooooooo`0<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^01cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko0000o`000?lb
<S;ok^k^00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`03oeEEEOmV
IVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`03o`000?oooooooooo00cooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h05oooool02Ol0
003oooooooooooooooooZJVYoa0@4?l0003o410@ojVYZ@02ooooo`06o`000?o^k^ko<S8bo`000?lb
<S;ok^k^3?ooool00ol0003oooooooooo`0>ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0>ooooo`006Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo
03gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Eooooo`006Oooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo01Kooooo000Jooooo`03o`000?oooooooooo00kooooo
0_l0000Uooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00oooooo0ol0000@ooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool05_ooool001[ooooo00?o0000ooooooooool03_ooool00ol0003oooooo`00
000Tooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00kooooo00?o0000ooooool000004?ooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo01Kooooo000Jooooo`03o`000?oooooooooo00gooooo0_l00000
0ooooooo0000ooooo`0Sooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo00Go0000ooooooooooooooooo`00
000?ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05oooool001Koooooool00010
o`0001?ooooo000Fooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`05ooooo`;o00001_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool4o`0000Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`0Aooooo`005_ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool01?l0003ooooo
o`000?l00004ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`;o00001_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`05ooooo`;o00001_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000?ooooo0_l00006ooooo`03o`00
0?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`0Aooooo`006oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool00ol0003ooooo
o`00000?ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0@ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo057ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Hooooo`00
6oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooo`00000?ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Aooooo`05o`000?ooooooooooooooool000002?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Iooooo`007?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool03?ooool01?l0003oooooooooool0000?ooooo`03o`000?oooooooooo04;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Aooooo`05o`000?oooooooooooooo
ool000001oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo057ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Iooooo`007?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool01Ol0003ooooooooooooooooo0000
00kooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo057ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Iooooo`007?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool01Ol0
003ooooooooooooooooo000000kooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo00001oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Jooooo`007?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool03?ooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool0@ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo0000
1oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Jooooo`007?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0A?ooool01?l0003oooooooooool0000Fooooo`03o`00
0?oooooooooo00;o00001_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Jooooo`007Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0AOooool3o`0001Kooooo00Co
0000oooooooooooo00001_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05?ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Kooooo`007Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Goooool01?l0003ooooooooo
ool00006ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Doooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo01_ooooo000Mooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo000000Kooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool06oooool001gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo063ooooo00?o0000ooooool000001_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0L
ooooo`007Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0H?ooool00ol0003oooooo`000006ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0E?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01cooooo000Mooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Pooooo`03
o`000?oooooo000000Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Eooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool07?ooool001gooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo063ooooo00?o0000ooooool00000
1Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Mooooo`007_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0HOooool3o`0000Cooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07Ooo
ool001kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo067ooooo0_l00005ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0EOooool0
1Ol0003ooooooooooooooooo0000023ooooo000Nooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`1Qooooo`;o00001Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo05Oooooo00Co0000oooooooooooo00008?ooool001kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06;ooooo0_l00005
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0F?ooool2o`00027ooooo000Noooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Roooo
o`;o00001?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07_ooooo000Nooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Sooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1kooooo`00
7_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
Hoooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
Noooool001kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo06?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo07_ooooo000Nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1Sooooo`;o00000_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo07_ooooo000Oooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`1Sooooo`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1k
ooooo`007oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0I?ooool2o`0000;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1koooo
o`007oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0I?ooool2o`000003ooooool0003ooooo01;ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Noooool001oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06Cooooo
00Co0000ooooool0003o00005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1kooooo`007oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0I?ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo07cooooo000Oooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`1Iooooo`Go00001_ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo07cooooo000Oooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`1Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_oo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07cooooo000Oooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Jooooo`03oiRHV?lQ8B7o
k^k^00Oooooo0ol0000Eooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo07cooooo000Oooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Kooooo`03oiRHV?lQ8B7ok^k^
00Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1looooo`008?ooool01Ol0003o
oooooooooooooooo000000gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0G?ooool00omgMgOoIVIVooooo`05oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0O?ooool0023ooooo00Go0000oooooooo
ooooooooo`00000=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo07cooooo000Pooooo`05o`000?oooooooooooooo
ool000003Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`1Iooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo07cooooo000Pooooo`05o`000?oooooooooo
ooooool000003Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1Iooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07cooooo000Qooooo`04o`000?oooooo
ooooo`0000gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo07cooooo000Qooooo`04o`000?ooooooooooo`0000gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0IOoo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07cooooo000Qooooo`03o`000?oooooo
000000kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0IOooool2o`0001Oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0OOooool0
027ooooo00?o0000ooooool000003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0OOooool002;ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`1Uooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0OOooool003;ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0IOooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07gooooo
000cooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1mooooo`00<oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo01Oooooo00Go0000
ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0OOoo
ool003?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0Gooooo`04o`000?oooooo
ooooo`0000oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1mooooo`00<oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1Uooooo`03o`000?oooooooooo01Oooooo00Co0000oooooooooooo00003ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07gooooo000cooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo06Gooooo00?o0000ooooooooool05oooool01?l0003oooooooooool0000?ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0OOooool003?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0IOooool2
o`0001Sooooo00Co0000oooooooooooo00003oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo07gooooo000cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool0
1Ol0003ooooooooooooooooo000006Sooooo00?o0000ooooooooool06?ooool00ol0003oooooo`00
000?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0O_ooool003?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool00000J?oo
ool00ol0003oooooooooo`0Hooooo`?o00004?ooool01Ol0003ooooooooooooooooo0000083ooooo
000cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool01Ol0003ooooooooo
oooooooo000006Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0?ooooo`05o`00
0?ooooooooooooooool00000P?ooool003?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0<ooooo`05o`000?ooooooooooooooool00000J?ooool00ol0003oooooooooo`0[ooooo`05
o`000?ooooooooooooooool00000P?ooool003Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0<ooooo`05o`000?ooooooooooooooool00000J?ooool00ol0003oooooooooo`0[oooo
o`05o`000?ooooooooooooooool00000P?ooool003Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0<ooooo`04o`000?ooooooooooo`0006Wooooo00?o0000ooooooooool0:oooool0
1Ol0003ooooooooooooooooo0000083ooooo000dooooo`05o`000?ooooooooooooooool000003ooo
ool01?l0003oooooooooool0001Yooooo`03o`000?oooooooooo02_ooooo00Go0000oooooooooooo
ooooo`000020ooooo`00=?ooool01Ol0003ooooooooooooooooo0000013ooooo00?o0000ooooool0
0000JOooool2o`0002gooooo00Co0000oooooooooooo0000P?ooool003Cooooo00Go0000oooooooo
ooooooooo`00000@ooooo`03o`000?oooooo000006Wooooo00?o0000ooooooooool0;?ooool01?l0
003oooooooooool00020ooooo`00=?ooool01Ol0003ooooooooooooooooo0000013ooooo00?o0000
ooooool00000JOooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo0000087ooooo000doooo
o`05o`000?ooooooooooooooool000004?ooool2o`0006[ooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooo`000021ooooo`00=?ooool01Ol0003ooooooooooooooooo000007cooooo00?o0000
ooooooooool0;?ooool00ol0003oooooo`000021ooooo`00=?ooool01Ol0003ooooooooooooooooo
000007?ooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo02cooooo00?o0000
ooooool00000POooool003Cooooo00Go0000ooooooooooooooooo`00001dooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0;?ooool00ol0003oooooo`000021ooooo`00=Oooool01?l0
003oooooooooool0001aooooo`Go00001_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo083ooooo000eooooo`03o`000?oooooo000007;ooooo00CoA4A4omgMgOoooooo00001oooool3
o`000;3ooooo000eooooo`03o`000?oooooo000007;ooooo00CogMgMoeEEEOoooooo00001oooool0
0ol0003oooooooooo`2`ooooo`00=Oooool00ol0003oooooo`00001cooooo`03ogMgMoo<c<co0000
00Oooooo00?o0000ooooooooool0/?ooool003Gooooo00?o0000ooooool00000Loooool00oo^k^ko
A4A4o`000007ooooo`03o`000?oooooooooo0;3ooooo000fooooo`03o`000?oooooooooo07?ooooo
00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo
00?o0000ooooooooool0/?ooool00:[ooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`00
0?oooooooooo0;3ooooo002Zooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0002`ooooo`00Z_oo
ool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00?o
EEEEohN7Qoooool02?ooool00ol0003oooooooooo`2`ooooo`00Z_ooool00ooMgMgo410@oiRHV008
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0:[ooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zoooo
o`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go<S8boiRH
V?ooooooV9RHoc8b<P06ooooo`?o0000/?ooool00:[ooooo00Goc<c<o`000?l0003o0000olc<c02i
ooooo`00Z_ooool01Ol@413o^[Zjoooooonj^[[o410@0;Wooooo002Zooooo`05o`000?nj^[[ooooo
okZj^_l00000^Oooool00:[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2iooooo`00oooooomYoooo
o`00[oooool00ol0003o^[Zjooooo`2fooooo`00[oooool2oc8b<[Oooooo0020ooooo`;o000000Ko
410@oooooooooooo410@o`000?l@410Hooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4
A4Co^[Zj01Wooooo1?l000000ol@413oooooooooo`05o`0000?ooooo00Gok^k^oc8b<_l0003o410@
olc<c01hooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l0
000=ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?oc<c<o`00
0?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<ooooo`03o`000?oooooo
oooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40
N?ooool0087ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Kooooo`04o`000?oo
oooooooooa0@40?ooooo00?o410@ooooooooool04?ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol0003ooooooooooooooooo000007So
oooo0021ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000gooooo00GoMgMgoc8b
<_ooooooooooo`000003ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02oooool6
o`0000cooooo00?o0000ooooooooool01?ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?nHV9So
oooooiRHV?lQ8B40N?ooool0087ooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Iooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`05ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000oeEE
EOl0003o410@olc<c01hooooo`00POooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001Wooooo00?o
0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@013ooooo00?o410@o`000?l00000
0ol0000Looooo`03o`000?oooooooooo00Kooooo00Ko0000oooooooooooooooooeEEEOn7QhMkoooo
o`00POooool01_l0003o<S8boooooooooooo<S8bo`0001Wooooo00?o0000ooooooooool01?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`02ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool00ooMgMgo410@oiRHV01jooooo`00P?oo
ool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo1?l00003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Kooooo`03oeEEEOmVIVKo000000Cooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`04olc<c?m4A4Co0000oa0@47Sooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(128) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .16863 m
.00942 .21373 L
.01975 .28149 L
.02243 .29737 L
.02496 .30953 L
.02635 .31466 L
.02709 .31685 L
.02787 .31875 L
.02925 .321 L
.03053 .3218 L
.03171 .32142 L
.03299 .31982 L
.0342 .31723 L
.0353 .314 L
.038 .30307 L
.04057 .28962 L
.05081 .22808 L
.05375 .21289 L
.05653 .20071 L
.05905 .19159 L
.06172 .18399 L
.06315 .18074 L
.06472 .17781 L
.06614 .1757 L
.06747 .1742 L
.06828 .17349 L
.06904 .17297 L
.06973 .17263 L
.07047 .17239 L
.07128 .17227 L
.07215 .17234 L
.07288 .17254 L
.07369 .17293 L
.07439 .17341 L
.07513 .17406 L
.07645 .17562 L
.07787 .17788 L
.07943 .18111 L
.08221 .18899 L
.08481 .19895 L
.12581 .31626 L
.13105 .26759 L
.13362 .24812 L
.13596 .2337 L
.13843 .22226 L
.13979 .21765 L
.14108 .2144 L
.14176 .21314 L
.14248 .21214 L
.14378 .2112 L
Mistroke
.14457 .21119 L
.14532 .21157 L
.14599 .21223 L
.14671 .2133 L
.14745 .21476 L
.14814 .21646 L
.1497 .2216 L
.15123 .22834 L
.15286 .2375 L
.15582 .25934 L
.15851 .28493 L
.16416 .35091 L
.16664 .38028 L
.16796 .39447 L
.16938 .40794 L
.17073 .41851 L
.17197 .42588 L
.17315 .43061 L
.1744 .43295 L
.17571 .43237 L
.17694 .429 L
.17828 .42228 L
.17904 .41722 L
.17972 .41189 L
.18249 .38403 L
.1855 .34642 L
.19095 .27547 L
.19612 .2209 L
.19872 .19987 L
.20158 .18129 L
.20402 .16866 L
.20663 .15797 L
.20911 .15022 L
.21136 .14487 L
.21375 .14071 L
.21512 .13892 L
.2164 .13755 L
.21765 .13647 L
.21897 .13557 L
.22042 .13483 L
.22175 .13435 L
.2229 .13408 L
.22413 .13392 L
.22529 .13391 L
.22635 .13401 L
.22759 .13426 L
.22893 .1347 L
.2302 .13527 L
.23137 .13593 L
.23398 .1378 L
Mistroke
.23641 .13998 L
.24195 .14599 L
.25316 .16157 L
.25838 .16936 L
.26114 .17302 L
.26407 .17639 L
.26689 .17902 L
.26945 .18083 L
.27068 .1815 L
.27202 .18205 L
.27328 .18239 L
.27444 .18256 L
.27557 .18257 L
.27677 .18241 L
.27791 .1821 L
.27895 .18168 L
.28017 .18103 L
.28149 .18012 L
.2839 .17801 L
.28909 .17189 L
.2939 .16509 L
.30334 .15061 L
.30829 .14363 L
.31351 .13759 L
.31629 .13494 L
.31933 .13249 L
.32213 .13065 L
.32467 .12937 L
.32602 .12886 L
.3273 .12849 L
.32864 .12823 L
.3294 .12814 L
.3301 .12809 L
.33127 .1281 L
.33255 .12822 L
.33389 .12847 L
.33515 .12883 L
.33646 .12932 L
.33786 .12998 L
.34038 .13153 L
.34337 .13406 L
.34608 .13708 L
.35143 .14541 L
.35646 .15624 L
.36582 .18336 L
.37106 .20106 L
.37593 .21679 L
.37842 .22365 L
.38077 .22897 L
.38207 .23134 L
Mistroke
.38348 .23339 L
.38476 .23477 L
.38595 .23561 L
.38726 .23604 L
.38848 .23597 L
.38983 .23537 L
.39058 .23479 L
.39128 .23412 L
.39266 .23236 L
.39417 .22986 L
.39692 .22388 L
.40853 .18827 L
.41402 .17196 L
.41906 .15944 L
.42417 .14961 L
.42685 .14566 L
.42969 .14237 L
.43216 .14022 L
.43447 .13874 L
.43579 .13812 L
.437 .13769 L
.43766 .13751 L
.43839 .13735 L
.43971 .13719 L
.44107 .13718 L
.44234 .13733 L
.44307 .13749 L
.44374 .13768 L
.44525 .13827 L
.44662 .13902 L
.44812 .14008 L
.45114 .14301 L
.45379 .14652 L
.45662 .15131 L
.46173 .1631 L
.47188 .20137 L
.48262 .25778 L
.48533 .27077 L
.48824 .28218 L
.4899 .28711 L
.49143 .29038 L
.49216 .29149 L
.49296 .29236 L
.49371 .29283 L
.49441 .29297 L
.4951 .29282 L
.49584 .29234 L
.49718 .29066 L
.49848 .28804 L
.49968 .28483 L
Mistroke
.50241 .27502 L
.50529 .26174 L
.51495 .21038 L
.52027 .18582 L
.5253 .16777 L
.52815 .15997 L
.53125 .1534 L
.53261 .15109 L
.53406 .14902 L
.53531 .14752 L
.53666 .14621 L
.53802 .1452 L
.53926 .14455 L
.54045 .14417 L
.5417 .14404 L
.54307 .14423 L
.54435 .14475 L
.54509 .14519 L
.54576 .1457 L
.54725 .1472 L
.54851 .14886 L
.54969 .15078 L
.55236 .15652 L
.55496 .16414 L
.55776 .17479 L
.56281 .20169 L
.56743 .23575 L
.57292 .28566 L
.57594 .31363 L
.57877 .33694 L
.58117 .35233 L
.58252 .35862 L
.58376 .36267 L
.58504 .365 L
.58577 .36545 L
.58645 .3653 L
.58781 .36332 L
.58858 .36126 L
.58928 .35882 L
.59052 .35316 L
.59184 .34553 L
.59421 .32836 L
.59956 .28081 L
.60424 .24031 L
.60928 .20636 L
.61208 .19268 L
.61464 .1833 L
.61586 .17982 L
.61721 .17678 L
.61847 .17462 L
Mistroke
.61965 .17325 L
.62037 .17271 L
.62114 .17239 L
.62187 .17232 L
.62255 .17248 L
.62383 .17333 L
.62518 .17503 L
.62588 .17623 L
.62663 .17778 L
.62799 .18122 L
.63107 .19225 L
.63376 .20567 L
.63662 .22406 L
.64175 .26814 L
.64775 .33235 L
.65068 .36289 L
.65197 .37473 L
.65338 .38607 L
.65451 .39376 L
.65573 .40026 L
.65701 .40504 L
.65821 .40743 L
.65888 .40788 L
.65961 .40764 L
.66094 .40527 L
.66223 .40068 L
.66342 .39459 L
.66598 .37632 L
.6688 .35043 L
.6745 .29264 L
.67998 .24533 L
.68268 .22729 L
.68518 .2136 L
.68984 .19469 L
.69231 .18751 L
.69493 .18152 L
.69778 .17651 L
.70086 .17238 L
.70644 .16683 L
.71687 .1582 L
.73744 .14063 L
.74308 .13646 L
.74911 .13283 L
.75203 .13143 L
.7548 .13037 L
.75729 .12965 L
.75869 .12935 L
.75999 .12915 L
.76123 .12903 L
.76237 .12897 L
Mistroke
.76368 .12898 L
.76493 .12905 L
.76608 .12918 L
.76715 .12936 L
.76832 .12962 L
.76957 .12996 L
.77242 .13104 L
.77511 .13246 L
.77752 .13411 L
.78014 .13631 L
.78555 .14235 L
.79126 .15094 L
.80151 .1714 L
.81145 .19317 L
.81431 .1984 L
.81702 .20247 L
.81946 .20521 L
.82084 .20634 L
.82211 .20708 L
.82321 .20749 L
.8244 .20767 L
.82552 .20761 L
.82654 .20734 L
.82768 .20681 L
.82893 .20595 L
.83023 .20477 L
.83144 .20341 L
.83623 .19592 L
.84135 .18533 L
.8521 .16122 L
.85775 .1502 L
.86375 .14105 L
.86899 .13535 L
.87196 .13306 L
.87339 .1322 L
.87475 .13153 L
.87597 .13106 L
.87731 .13069 L
.87852 .13049 L
.87964 .13042 L
.88098 .13049 L
.88219 .13069 L
.88286 .13087 L
.88359 .13111 L
.8849 .13167 L
.88621 .13241 L
.8874 .13324 L
.89007 .13567 L
.89255 .13869 L
.8949 .14229 L
Mistroke
.90015 .15344 L
.90312 .16182 L
.90586 .17097 L
.91727 .22073 L
.92286 .246 L
.92531 .25511 L
.9266 .25914 L
.92798 .26271 L
.92923 .26523 L
.93037 .26689 L
.93151 .26793 L
.93259 .26832 L
.9338 .26806 L
.93491 .26718 L
.93613 .26552 L
.93743 .26301 L
.93993 .25618 L
.94227 .24783 L
.9476 .22446 L
.95292 .19969 L
.95871 .17594 L
.96136 .16697 L
.96418 .15888 L
.96661 .15305 L
.96924 .14792 L
.97151 .14441 L
.97359 .14189 L
.97558 .14009 L
.97659 .13941 L
.97768 .13884 L
.97868 .13847 L
.97959 .13827 L
.98064 .13818 L
.98164 .13824 L
.98255 .13843 L
.9834 .13871 L
.98433 .13914 L
.98532 .13974 L
.98706 .14115 L
.98893 .14318 L
.99231 .14832 L
.99436 .15248 L
.99632 .15726 L
1 .16863 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo001looooo`Ko0000<oooool2o`0004oooooo1ol0000Pooooo`?o
0000>?ooool005gooooo0_l0000Looooo`03o`000?oooooooooo00Cooooo0_l0000aooooo`03o`00
0?oooooooooo04_ooooo0ol00006ooooo`;o00007Oooool2o`0000;ooooo0_l0000gooooo`00Fooo
ool2o`0000;ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo01[ooooo0ol0000Aooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=?oo
ool005[ooooo0_l00004ooooo`;o00005oooool2o`0000Wooooo00?o0000ooooooooool06?ooool3
o`000003ooooool0003o0000013ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0G
ooooo`Co00006?ooool005[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0Aoooool2o`0000oooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo00Co0000oooo
oooooooooooo0_l0000Fooooo`00FOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`?o0000>_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05?ooool005Wo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo001Hooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Cooooo`00
F?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2oooool2o`0000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Cooooo`00Eooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_oo
ool005Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01;ooooo000Eooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h0
6_ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0@oooo
o`03o`000?oooooooooo00Sooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Co000000So410@ooooooooooook^k^oc8b
<_l0003o<S8bonk^kPCooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0>ooooo`Co
000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQGooooo00?o0000ooooooooool00_oo
ool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0:ooooo`03o`000?oooooooooo00kooooo
00Go0000oa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00Cooooo0_l000002Ol@413oooooooooool0003o
k^k^oc8b<_l0003o<S8bonk^kP0>ooooo`005_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL06_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0@ooooo`03o`000?oooooooooo00Sooooo00KoV9RHob4Q8Oo^k^koooooodA4A?l0
0002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Dooooo`03o`000?oooooooooo00?ooooo00GoV9RHob4Q
8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02_ooool00ol0003ooooooooo
o`0=ooooo`06o`000?l@413o^[ZjoooooomgMgOo<S8b0oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`0:o`000?oooooooooo
ooooool0003oMgMgoiRHV?ooooooV9RHogMgM`kooooo000;ooooo`Ko00000_ooool5o`0000?ooooo
00Go410@oooooooooooooooooa0@400Booooo`Ko00001_ooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool03_ooool00ol0003oooooooooo`06o`0000?ooooo00?oV9RHob4Q
8Oo^k^h00_ooool00ol0003ooooooa0@4003ooooo`05oa0@4?ooooooooooooooool000003oooool6
o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@00?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@400Cooooo`03o`000?oooooooooo00Gooooo
00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool@41000oooool00ol@
413oooooooooo`02ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool5o`00
00?ooooo00Go410@oooooooooooooooooa0@400>ooooo`004oooool01?m4A4CogMgMooooool00004
ooooo`05o`000?ooooooooooooooool000002oooool4o`0000kooooo00?oZJVYoa0@4?ooool00_oo
ool01Ol0003ooooooooooooooooo0000013ooooo00?o0000ooooooooool02_ooool00onHV9So8B4Q
onk^kP02ooooo`;o00000oooool01?l0003oooooooooool0000Gooooo`05o`000?oooooooooooooo
ool000001?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooo000000?o00000oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00Oooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooo
oooo000000_ooooo00?o0000ooooooooool03?ooool01_l0003oooooooooooooooooZJVYoa0@40?o
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool00oooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000003_oo
ool001?ooooo00?ogMgMoeEEEOooool00_l00003ooooo`05o`000?ooooooooooooooool000002_oo
ool2o`0000;ooooo00?o0000ooooooooool02oooool00ol@413o0000okZj^P03ooooo`05o`000?oo
ooooooooooooool000003oooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00;ooooo
00Oo0000ooooooooooooooooo`000?oooooo000001Sooooo00Go0000ooooooooooooooooo`000004
ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00oooooo0_l00002ooooo`;o00000oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00Wooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000cooooo
00?o0000ooooooooool02_ooool01ol0003ooooooooooooooooo410@o`000?nj^[X00oooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03
ooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000>ooooo`005?oo
ool01?mgMgOoc<c<o`000?l00003ooooo`05oa0@4?ooooooooooooooool@41002_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413o
oooooooooooooooo410@00oooooo00?o0000ooooooooool03Oooool01_l0003ooooooooooooooooo
410@o`0000;ooooo00?o410@o`000?ooool06Oooool01?l0003oooooooooool00004ooooo`05oa0@
4?ooooooooooooooool@41000_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00So
oooo0_l00005ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03oooool2o`0000?o
oooo00Go0000oooooooooooooooooa0@400Aooooo`03o`000?oooooooooo00[ooooo00Go0000oooo
oooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`02ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@
4005ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool00omgMgOoc<c<o`00
0004ooooo`05oa0@4?ooooooooooooooool@41003_ooool001Cooooo00Cok^k^odA4A?l0003o0000
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Wooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`08ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9So
MgMg00oooooo00?o0000ooooooooool02Oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00?o
MgMgoiRHV?l000000_l0000Kooooo`04o`000?ooooooooooo`0000Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`02ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`02ooooo`05o`000?nHV9SooooooiRHV?mgMgL04?ooool00ol0003oooooooooo`07oooo
o`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00gooooo00?o
0000ooooooooool02Oooool01ol0003ooooooa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`04oooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`005Oooool00omg
MgOo0000o`000003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Oooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03oooool00ol0003oooooooooo`09ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo00Co0000oeEEEOmVIVKo00001?ooool0
1oo^k^ko<S8bo`000?lb<S;ok^k^ooooool000004_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<ooooo`03oeEE
EOmVIVKo000000Cooooo00Go0000oc8b<_l0003o<S8bonk^kP0?ooooo`03o`000?oooooooooo00So
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool0
0ol0003oooooooooo`08ooooo`08o`000?ooooooooooojVYZOl@413o0000oa0@4?nYZJT3ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00Kooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Goooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool07oooool001Sooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool0<oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Oooooo`006?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo023ooooo000Hooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08?oo
ool001Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Pooooo`005_ooooooo`00
043o00004oooool001Kooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooo000000Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo0_l00006ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooool000001Oooool00ol0003o
ooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`?o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`005_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo0ol0
0007ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l0
0006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ool000001Oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool04Oooool001Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00gooooo0ol0000>ooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04Kooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Qooooo`006Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03?ooool01?l0003oooooooooool0000>
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Q
ooooo`006Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool03?ooool01?l0003oooooooooool0000>ooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Rooooo`006Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool01?l0003oooooooooool0000>
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`00000@ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo04Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Rooooo`006_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool0
1Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool0=oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooo
oooooooo0000013ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo02;ooooo000Jooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0hooooo`05o`000?ooooooooooooooool000006Oooool00ol0003ooooo
ooooo`05ooooo`05o`000?ooooooooooooooool000004?ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool08_ooool001[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Wooooo00Co0000ooooool0003o
00006_ooool00ol0003oooooooooo`04ooooo`;o00000_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo04Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Rooooo`00
6_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
>oooool2o`0001_ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000013o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02;o
oooo000Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`1Hooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00004Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`1:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool08oooool001[ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Sooooo
00?o0000ooooooooool01?ooool01?l0003oooooooooool0000Aooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04_o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Sooooo`006_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0F?ooool00ol0003ooooo
ooooo`04ooooo`04o`000?ooooooooooo`00017ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Boooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo02?ooooo000Kooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo00Cooooo
00Co0000oooooooooooo00004Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool08oooool001_ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool00oooool01?l0003ooooo
ooooool0000Booooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Sooooo`006oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0FOooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000001?ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0Boooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Cooooo
000Kooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`1Iooooo`03o`000?oooooooooo00?ooooo0ol0000Cooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04cooooo00Go
0000ooooooooooooooooo`00000Vooooo`006oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooo000001?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0COooool01?l0003oooooooooool0000Wooooo`006ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0F_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooo000001?ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0C_oo
ool00ol0003oooooo`00000Wooooo`006oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
000001?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0C_ooool2o`0002Sooooo000Looooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo
00;ooooo0_l0000Dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo07Sooooo000Looooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo00;o
oooo0_l0000Dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo07Sooooo000Looooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo00;ooooo
0_l0000Eooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo07Sooooo000Looooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1Looooo`05o`000?ooooooooooooooool00000
5_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`1hooooo`007?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0G?ooool01?l0003oooooooooooooool2o`0001Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0NOooool001cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Eooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo05gooooo00Co0000ooooool0003o00005_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1iooooo`00
7Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Gooooo00Go0000oooooooooooo
ooooo`000008ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0GOooool01?l0003o
ooooo`000?l0000Fooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo07Wooooo000Mooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool05Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0GOooool4o`0001Kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0NOooool001go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo000000Wo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0NOooool001gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`1Pooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0NOooool001gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo000000[ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`1Eooooo`Go00001_ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo07Wooooo000Nooooo`05o`000?ooooooooooooooool000006_oo
ool2o`0000[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Eooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo07Wooooo
000Nooooo`05o`000?ooooooooooooooool000006_ooool2o`0000[ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`1Fooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0000Eooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo07Wooooo000Nooooo`04o`000?ooooooooooo`0001_ooooo0_l0000:ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0F?ooool00onHV9So8B4Qonk^kP06ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0NOooool001kooooo00Co0000oooooooooooo0000
7?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
FOooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
NOooool001kooooo0_l000000ooooooo0000ooooo`0Vooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0F_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0NOooool001oooooo0_l0000Xooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0E_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1iooooo`00BOooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo05Kooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0N_ooool004Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Q
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0N_ooool004Wooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0N_ooool004Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Qooooo`;o
00005oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`1jooooo`00B_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo067ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1jooooo`00B_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool05_oo
ool01Ol0003ooooooooooooooooo0000017ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1jooooo`00B_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo067ooooo00?o
0000ooooooooool05_ooool01Ol0003ooooooooooooooooo0000017ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1jooooo`00B_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo067ooooo00?o0000ooooooooool05oooool01?l0003oooooooooool0000Aooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0N_ooool004[ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo01Oooooo00Co0000oooooooooooo0000
4_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07[ooooo001:ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Gooooo`04o`000?oo
ooooooooo`0001;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1jooooo`00B_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool05ooo
ool01?l0003oooooooooool0000Booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
N_ooool004[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Qooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooool000004oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo07[ooooo001:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0HOooool2
o`0001Wooooo0_l0000Cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0N_ooool0
04[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
07_ooooo001;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H_ooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Noooool004_ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`1kooooo`00Boooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo07_ooooo001;ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0H_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0Noooool004_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Roooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1koooo
o`00Boooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06;ooooo00?o0000oooooooo
ool0;_ooool01Ol0003ooooooooooooooooo000007gooooo001;ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0H_ooool2o`0002oooooo00Co0000oooooooooooo0000O_ooool004_o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo02ko
oooo00Co0000oooooooooooo0000O_ooool004_ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`1Rooooo`03o`000?oooooooooo02kooooo00Co0000oooooooooooo0000O_ooool004_o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo02ko
oooo00Co0000oooooooooooo0000O_ooool004_ooooo00Go0000ooooooooooooooooo`00001Uoooo
o`03o`000?oooooooooo02kooooo00Co0000oooooooooooo0000O_ooool004cooooo00Co0000oooo
oooooooo0000G?ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0;_ooool0
1?l0003oooooooooool0001nooooo`00C?ooool01?l0003oooooooooool0001Mooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0;oooool2o`0007oooooo001<ooooo`04o`000?oooooo
ooooo`0005[ooooo1Ol00006ooooo`03o`000?oooooooooo02oooooo0_l0001oooooo`00C?ooool0
1?l0003oooooooooool0001Jooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00C?oo
ool01?l0003oooooooooool0001Jooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000oooooooo
ool0/?ooool004cooooo00Co0000oooooooooooo0000Foooool00omgMgOoc<c<o`000007ooooo`03
o`000?oooooooooo0;3ooooo001<ooooo`03o`000?oooooo000005cooooo00?ok^k^odA4A?l00000
1oooool00ol0003oooooooooo`2`ooooo`00C?ooool00ol0003oooooo`00001Mooooo`03ogMgMol0
003ooooo00Kooooo00?o0000ooooooooool0/?ooool004cooooo00?o0000ooooool00000I_ooool0
0ol0003oooooooooo`2`ooooo`00COooool2o`0006Kooooo00?o0000ooooooooool0/?ooool004go
oooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0/?oo
ool00:[ooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Z
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool0
1Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0002`ooooo`00Z_ooool01Ol0003oEEEEo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00?oEEEEohN7Qoooool02?ooool0
0ol0003oooooooooo`2`ooooo`00Z_ooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo
0;3ooooo002[ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo00Goc<c<ob4Q8Ol0
003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05ob4Q8OnHV9SooooooiRH
V?lQ8B401_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06oooo
o`?o0000/?ooool00:[ooooo00Goc<c<o`000?l0003o0000olc<c02iooooo`00Z_ooool01Ol@413o
^[Zjoooooonj^[[o410@0;Wooooo002Zooooo`05o`000?nj^[[ooooookZj^_l00000^Oooool00:[o
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@2iooooo`00oooooomYooooo`00[oooool00ol0003o^[Zj
ooooo`2fooooo`00[oooool2oc8b<[Oooooo0020ooooo`;o000000Ko410@oooooooooooo410@o`00
0?l@410Hooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Wooooo1?l00000
0ol@413oooooooooo`05o`0000?ooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c01hooooo`00POooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l0000=ooooo`09ogMgMolb<S;o
oooooooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o
^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<ooooo`03o`000?oooooooooo00;ooooo00GoV9RHob4Q
8Oo^k^koooooodA4A003ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40N?ooool0087ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooooooooa0@40?ooooo00?o
410@ooooooooool04?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00?ooooo00?o
V9RHob4Q8Oo^k^h01?ooool01Ol0003ooooooooooooooooo000007Sooooo0021ooooo`06o`000?oo
ooooA4A4odA4A?oooooo00002Oooool6o`0000gooooo00GoMgMgoc8b<_ooooooooooo`000003oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool02oooool6o`0000cooooo00?o0000oooo
ooooool01?ooool00onHV9So8B4Qonk^kP03ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80N?ooool0
087ooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Iooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
0_ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`05ooooo`03ogMgMomVIVKooooo00;ooooo00Goc<c<o`000?l0003o0000olc<c01hoooo
o`00POooool01_l0003oQhN7ojVYZOnj^[[oEEEEo`0001Wooooo00?o0000ooooooooool01?ooool0
1Ol@413ooooooooooooooooo410@013ooooo00?o410@o`000?l000000ol0000Looooo`03o`000?oo
oooooooo00Kooooo00Wo0000oooooooooooooooooa0@4?nj^[[ooooookZj^_l@4100N?ooool0087o
oooo00Ko0000oc8b<_oooooooooooc8b<_l0000Iooooo`03o`000?oooooooooo00Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0Booooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00_oo
ool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go0000okZj^_oooooo^[Zjo`00001hooooo`00
P?ooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Kooooo`03oeEEEOmVIVKo000000Co
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0N?ooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(130) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .20021 m
.00942 .24713 L
.01483 .27707 L
.01719 .28887 L
.01975 .29968 L
.02114 .3044 L
.02243 .30789 L
.02365 .3104 L
.02496 .31209 L
.02632 .31278 L
.02761 .31238 L
.02834 .31171 L
.02901 .3108 L
.02979 .30943 L
.03053 .3078 L
.03302 .30019 L
.03533 .29056 L
.04057 .26284 L
.04586 .23244 L
.05159 .20315 L
.057 .18132 L
.06198 .16638 L
.06476 .1601 L
.0678 .15482 L
.06934 .15277 L
.07098 .15101 L
.07178 .15031 L
.07254 .14975 L
.07321 .14933 L
.07395 .14895 L
.07526 .14851 L
.07598 .14839 L
.07665 .14836 L
.07786 .14852 L
.07915 .14901 L
.07984 .14941 L
.08059 .14996 L
.0821 .15149 L
.0835 .15343 L
.08481 .15575 L
.08757 .16243 L
.09011 .17105 L
.0929 .18366 L
.09586 .20115 L
.10082 .24137 L
.10629 .30005 L
.11115 .35514 L
.11255 .36901 L
.11388 .38055 L
.11509 .38931 L
Mistroke
.11637 .39655 L
.1176 .40123 L
.11871 .40345 L
.11983 .40368 L
.12089 .40205 L
.12212 .39794 L
.12325 .39217 L
.12449 .38384 L
.12581 .37308 L
.13578 .2652 L
.13866 .23817 L
.14138 .21721 L
.14382 .20236 L
.14518 .19565 L
.14647 .1904 L
.14767 .18637 L
.14878 .18344 L
.15001 .18104 L
.15133 .17947 L
.15253 .17894 L
.15384 .17936 L
.15521 .18091 L
.15648 .18336 L
.15769 .18659 L
.15883 .19046 L
.16096 .19987 L
.16325 .21329 L
.16573 .23189 L
.17654 .35731 L
.17925 .39109 L
.18059 .40571 L
.18182 .41749 L
.18292 .42621 L
.18413 .43371 L
.18535 .43877 L
.18664 .44126 L
.1879 .44076 L
.18926 .43705 L
.19055 .43068 L
.19172 .42261 L
.19438 .39809 L
.19718 .3661 L
.20324 .29502 L
.20588 .26919 L
.20875 .24638 L
.21143 .22988 L
.2139 .21825 L
.21626 .20986 L
.21876 .20339 L
.22002 .20092 L
Mistroke
.22139 .19876 L
.22256 .19727 L
.22385 .19598 L
.22535 .19483 L
.22678 .19402 L
.22817 .19341 L
.22945 .19295 L
.23176 .19221 L
.23426 .19133 L
.23662 .19026 L
.23879 .189 L
.244 .18475 L
.24873 .17932 L
.25909 .16315 L
.27019 .1456 L
.27557 .13849 L
.28067 .13302 L
.28524 .12933 L
.28782 .12774 L
.29021 .12655 L
.2925 .12567 L
.2937 .1253 L
.29496 .12498 L
.29607 .12477 L
.29728 .12461 L
.29839 .12453 L
.29941 .12452 L
.30074 .12459 L
.30198 .12474 L
.30311 .12496 L
.30432 .12528 L
.30565 .12573 L
.30705 .12632 L
.30956 .12765 L
.312 .12931 L
.31462 .13151 L
.31935 .13678 L
.32497 .14557 L
.33011 .15618 L
.34061 .18487 L
.34637 .2027 L
.35178 .21787 L
.35425 .22344 L
.35686 .22801 L
.35822 .22978 L
.35894 .23054 L
.35971 .2312 L
.36107 .23199 L
.36233 .23229 L
.36356 .23217 L
Mistroke
.3649 .2316 L
.36616 .23062 L
.36733 .22937 L
.36953 .22614 L
.37187 .22161 L
.38187 .19486 L
.38738 .17934 L
.39262 .16627 L
.39747 .1562 L
.40276 .14761 L
.40758 .14183 L
.41205 .13793 L
.41455 .13629 L
.41586 .13558 L
.41724 .13494 L
.41846 .13447 L
.41979 .13405 L
.421 .13376 L
.42213 .13358 L
.42332 .13347 L
.42444 .13344 L
.42545 .13348 L
.42654 .1336 L
.42773 .13383 L
.429 .13417 L
.43008 .13454 L
.43127 .13506 L
.43392 .13663 L
.43636 .13862 L
.43903 .14154 L
.44184 .14558 L
.44658 .15513 L
.44927 .16231 L
.45177 .1703 L
.45706 .19171 L
.46281 .22143 L
.46787 .25058 L
.47064 .26577 L
.47324 .2782 L
.47557 .28707 L
.47687 .29085 L
.47807 .29344 L
.47938 .29528 L
.48011 .29584 L
.4808 .29605 L
.48205 .29563 L
.48339 .29408 L
.48461 .2917 L
.48592 .28814 L
.4883 .27937 L
Mistroke
.49275 .25704 L
.49799 .22651 L
.5036 .19589 L
.5089 .1727 L
.51372 .15707 L
.51632 .15069 L
.51914 .14523 L
.52181 .14137 L
.52427 .13881 L
.52565 .13777 L
.52694 .13703 L
.52768 .1367 L
.52836 .13647 L
.52911 .13628 L
.52989 .13616 L
.5306 .13611 L
.53136 .13613 L
.53274 .13635 L
.53357 .1366 L
.53437 .13692 L
.53585 .13773 L
.53706 .13861 L
.53837 .13978 L
.54072 .14253 L
.54352 .14694 L
.54608 .15215 L
.54873 .15893 L
.55163 .16806 L
.55689 .19006 L
.56177 .21731 L
.56696 .25285 L
.5715 .28628 L
.57628 .3177 L
.57872 .32978 L
.58011 .33494 L
.5814 .33849 L
.58259 .34063 L
.58367 .3416 L
.58491 .34155 L
.58609 .34037 L
.58738 .33788 L
.58874 .33395 L
.59117 .32401 L
.59669 .2926 L
.60182 .26072 L
.60671 .23441 L
.61109 .21587 L
.61587 .20113 L
.61835 .19554 L
.621 .19096 L
Mistroke
.62349 .18781 L
.62576 .18579 L
.62713 .18492 L
.62839 .18433 L
.62977 .18392 L
.63047 .1838 L
.63123 .18375 L
.63252 .18385 L
.6339 .18422 L
.6352 .18485 L
.63639 .18569 L
.63758 .18681 L
.63884 .18834 L
.64111 .19206 L
.64356 .19765 L
.64626 .20603 L
.64858 .21538 L
.65108 .228 L
.6556 .25854 L
.66088 .30672 L
.66651 .36433 L
.66924 .38814 L
.67059 .39746 L
.67182 .40427 L
.67295 .40877 L
.67414 .41165 L
.67534 .41248 L
.67665 .41096 L
.67803 .40668 L
.67929 .40047 L
.68074 .39081 L
.68212 .37948 L
.68724 .32567 L
.69331 .25833 L
.69595 .23324 L
.69881 .21013 L
.70152 .19191 L
.70401 .17807 L
.70891 .15766 L
.7114 .15013 L
.71414 .14368 L
.71699 .13858 L
.71965 .13498 L
.72216 .13237 L
.72454 .13047 L
.72667 .12917 L
.72787 .1286 L
.72899 .12816 L
.73018 .1278 L
.73151 .12754 L
Mistroke
.73279 .1274 L
.73418 .12739 L
.73546 .12749 L
.73668 .12769 L
.73778 .12794 L
.73897 .12829 L
.74165 .12935 L
.74454 .13092 L
.74728 .13285 L
.7498 .13506 L
.75457 .14055 L
.75961 .14819 L
.77023 .16951 L
.77608 .18315 L
.78163 .19526 L
.78413 .19983 L
.78678 .2038 L
.78817 .20544 L
.7897 .20687 L
.79037 .20737 L
.79109 .20781 L
.7924 .20837 L
.79359 .2086 L
.79489 .20854 L
.79626 .20811 L
.79752 .20739 L
.79871 .20644 L
.7998 .20535 L
.80223 .20215 L
.80697 .19347 L
.81212 .18184 L
.82147 .16002 L
.82625 .15016 L
.8314 .14131 L
.83704 .13393 L
.84232 .12906 L
.84515 .12718 L
.84665 .12639 L
.84824 .12572 L
.84903 .12545 L
.84977 .12523 L
.85115 .12492 L
.85245 .12476 L
.85319 .12471 L
.85386 .12471 L
.85513 .12478 L
.85631 .12495 L
.8576 .12524 L
.85899 .12569 L
.86045 .1263 L
Mistroke
.86183 .12703 L
.86441 .1288 L
.8669 .13107 L
.86924 .13378 L
.87201 .13781 L
.87456 .14236 L
.87975 .15446 L
.88534 .17204 L
.89469 .21121 L
.89984 .23426 L
.90236 .24438 L
.90468 .25233 L
.90728 .25911 L
.90864 .26165 L
.90933 .26263 L
.91009 .26347 L
.91131 .2643 L
.91262 .26444 L
.91386 .26386 L
.91499 .26274 L
.91621 .26091 L
.91735 .25867 L
.91991 .25188 L
.92458 .23488 L
.92997 .21198 L
.93578 .1886 L
.94081 .17194 L
.94366 .16425 L
.94632 .15825 L
.94919 .15298 L
.9518 .14921 L
.9546 .14616 L
.95613 .14487 L
.95759 .14387 L
.95884 .14317 L
.96017 .14258 L
.9613 .1422 L
.96255 .14191 L
.96389 .14173 L
.96464 .14169 L
.96533 .14169 L
.96666 .14181 L
.96793 .14205 L
.96916 .1424 L
.97028 .14282 L
.97278 .14411 L
.9751 .14573 L
.97728 .14763 L
.98218 .15333 L
.98495 .15756 L
Mistroke
.98749 .16225 L
.99345 .17696 L
.99684 .18799 L
1 .20021 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo001dooooo`?o0000?_ooool00ol0003oooooooooo`1]
ooooo`;o0000@Oooool0077ooooo1?l000001?oooooo0000o`000?l0000looooo`03o`000?oooooo
oooo04Kooooo1?l0000Qooooo`Ko0000?oooool0073ooooo0_l00007ooooo`03o`000?oooooooooo
03Wooooo0_l00015ooooo`?o00000_ooool3o`0001gooooo0_l00006ooooo`;o0000?Oooool006oo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Nooooo`Co00005_ooool00ol0003o
ooooooooo`14ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo03_ooooo001^ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool07?ooool2o`0000?ooooo0_l0000Dooooo`03o`000?oooooooooo00Gooooo
1?l0000jooooo`03o`000?oooooooooo00Kooooo0_l0000Jooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0>oooool006gooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0Jooooo`;o00001oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00_l0000hooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03[ooooo001]ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool06?ooool5o`0001cooooo001/ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
03Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool05oooool2o`0000?ooooo0_l0000Kooooo`00;Oooool3o`0003co
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool06?ooool002cooooo0_l00002ooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool06?ooool002_ooooo00?o0000ooooooooool00_ooool2o`0003Sooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03_ooool2o`0000?ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Gooooo`00:oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03_ooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05_oo
ool002[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00gooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Gooooo000E
ooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h02_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00GoV9RHoa0@4?l0003o<S8bolc<c003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool5o`000008ooooool0003oooooonk^k_lb<S;o0000
oc8b<_o^k^hAooooo`03o`000?oooooooooo00Sooooo1?l000001?l@413oooooooooooo^k^h2o`00
0003oc8b<_o^k^kooooo00gooooo00?o0000ooooooooool03Oooool01Ol0003ooooooooooooooooo
000000_ooooo00?o0000ooooooooool03oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000
oc8b<_o^k^hDooooo`03o`000?oooooooooo00?ooooo1Ol00003ooooo`06onk^k_lb<S;o0000oc8b
<_o^k^ko00004?ooool00ol0003oooooooooo`07ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^013ooooo00?o0000ooooooooool02_ooool2o`000009oa0@
4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Fooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`09ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0Kooooo`0=oiRHV?lQ8B7ok^k^oooooom4A4Coooooo`000?ooooooMgMgoiRHV?ooooooV9RH
ogMgM`0Aooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool01OmgMgOo0000
oooooonHV9SoMgMg00oooooo00?o0000ooooooooool03?ooool01?l0003oooooooooool0000<oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg01Cooooo00?o0000ooooooooool00oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Ko
MgMgoiRHV?ooooooV9RHogMgMol0000?ooooo`03o`000?oooooooooo00Sooooo00Go410@okZj^_oo
ooooMgMgoc8b<P03ooooo`05ogMgMonHV9So0000oiRHV?mgMgL04?ooool00ol0003oooooooooo`0;
ooooo`;o00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko00000_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@4009ooooo`03o`000?oooooooooo00Kooooo1_l0
0006ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Aooooo`Ko0000
0oooool01OnHV9So8B4Qonk^k_oooooo000000;ooooo00Go410@oooooooooooooooooa0@400Aoooo
o`03o`000?oooooo000000Go00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?l0003ooooo
ooooool@41003oooool00ol0003oooooooooo`0<ooooo`04o`000?ooooooooooo`0000cooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
4oooool00ol0003oooooooooo`05ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Oo410@oooooooooooo
oooooa0@4?oooooo000000kooooo00?o0000ooooooooool03?ooool01Ol0003ooooooooooooooooo
410@00;ooooo00?o0000oa0@4?ooool03_ooool00ol0003oooooooooo`09ooooo`Go00000oooool0
1Ol@413ooooooooooooooooo410@00kooooo000Cooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go
0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
2?ooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000007Oooool00onHV9So
8B4Qo`000003ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooo
oooo00cooooo00Co0000oooooooooooo00003?ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`03o`000?oooooooooo00Kooooo
00?oV9RHob4Q8Oo^k^h00oooool01ol0003ooooooooooooooooo0000ooooool000003Oooool00ol0
003oooooooooo`0<ooooo`03ojVYZOl@413ooooo00;ooooo00?o0000ooooooooool00_l0000?oooo
o`03o`000?oooooooooo00Wooooo00?oA4A4omgMgOooool00_l00003ooooo`05o`000?oooooooooo
ooooool000003_ooool001?ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooo
oooo000000Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03oa0@4?l0
003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00000Nooooo`03ogMgMol0003ooooo00;ooooo
00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000oooooo00?o0000ooooooooool03?ooool01?l0
003oooooooooool0000=ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000001?ooooo00?o0000ooooooooool01oooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00_ooooo00?o410@o`000?nj^[X00oooool00ol0003oooooooooo`02o`0000oooooo
00?o0000ooooooooool02Oooool01_oMgMgoEEEEooooool0003oooooo`0000;ooooo00Go0000oooo
ooooooooooooo`00000>ooooo`005?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41002?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o^[Zj
ob4Q8Oooool00_ooool00ol@413oooooooooo`03o`0001gooooo0_l00003ooooo`05oa0@4?oooooo
ooooooooool@41004_ooool00ol0003oooooooooo`09ooooo`06o`000?ooooooooooooooool0003o
410@0oooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo0_l000000ooooooo
0000ooooo`0<ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@01?ooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo
410@00?ooooo00Co410@oooooooooooo00003?ooool00ol0003oooooooooo`0<ooooo`03okZj^_lQ
8B7ooooo00;ooooo00Go410@oooooooooooo0000oa0@400?ooooo`03o`000?oooooooooo00[ooooo
00GoMgMgolc<c?l0003oooooo`000002ooooo`05oa0@4?ooooooooooooooool@41003_ooool001Co
oooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`04ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool0
1omgMgOoV9RHooooool0003oMgMgooooool000006Oooool01Ol0003o^[Zjo`000?nHV9So410@00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Cooooo`03o`000?oooooooooo00Sooooo00[o0000oooo
ooooooooooooo`000?mgMgOoV9RHoooooonHV9SoMgMg4?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooo000000kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`?o
000000?oV9RHogMgMoooool04_ooool00ol0003oooooooooo`04ooooo`05o`000?nj^[[ooooooiRH
V?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0:ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooo
oonHV9So000000kooooo00?o0000ooooooooool02oooool01Oo^k^koA4A4o`000?oooooo000000;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`005Oooool00omgMgOo0000ooooo`03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`07onk^k_lb<S;o0000o`000?o^k^kooooo
o`00000Iooooo`05oiRHV?l0003o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01?ooooo00?o0000ooooooooool01_ooool00omEEEGoIVIVo`000002ooooo`07o`000?ooooook^k^
oc8b<_l0003o<S8bonk^kP0@ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000003ooo
ool00ol0003oooooooooo`0=ooooo`03oeEEEOmVIVKo000000?ooooo00?o0000onk^k_lb<S800_l0
00000oo^k^koooooooooo`0@ooooo`03o`000?oooooooooo00Gooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000
oc8b<_l000003_ooool00ol0003oooooooooo`0<ooooo`0;ogMgMol0003oooooooooool0003ooooo
onk^k_lb<S;o0000oc8b<_o^k^h03_ooool002Oooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0>ooooo`05o`000?ooooooooooooooool000006?ooool2o`0001oooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ool000003oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool04_ooool002Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`05
o`000?ooooooooooooooool000005Oooool3o`0002;ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo00_ooooo0_l0000@ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Booooo`009oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Aooooo`;o00009?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool02oooool2o`00013ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo017ooooo000Fooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool04?ooool2o`0002Gooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00_ooooo0_l0000Aooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`005_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02_ooool2o`00017ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Vooooo`005_ooooooo`00043o00004oooool0
01Kooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooo000000Kooooo00?o0000ooooooooool00oooool00ol0
003oooooo`000004ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool00oooool0
0ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2
o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oo
oooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00;ooooo1?l00007ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003o
ooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Aooooo`005_ooool2o`0000Kooooo00?o0000ooooooooool01?ooool2o`0000Oooooo
00?o0000ooooooooool00oooool00ol0003oooooo`000006ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooool000001?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooool000001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Cooooo0_l0
0007ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l0
0007ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo017ooooo000Gooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0??ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Oooooo000Goooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo02Oooooo000Gooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`08ooooo`;o00004oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0looooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0:?ooool001Sooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Sooooo0_l0000Cooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Xooooo`006?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0:ooo
ool01Ol0003ooooooooooooooooo000001gooooo00?o0000ooooooooool02?ooool2o`0001?ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Sooooo
000Hooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0/ooooo`04o`000?oooooo0000o`0001kooooo00?o0000ooooooooool01oooool2o`0001?ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Sooooo
000Hooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01oooool3o`0001;ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Wooooo000H
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1>
ooooo`03o`000?oooooooooo00Oooooo0_l0000Dooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Yooooo`006Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`07oooo
o`;o00005?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0:Oooool001Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo04oooooo00?o0000ooooooooool01oooool2o`0001Cooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0?oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Wooooo000Iooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1@ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooool000005?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0:_ooool001Wooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooo`00000Dooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Zooooo`006Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
000001Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo02[ooooo000Iooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`1@ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000005?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`11ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0:_ooool001Wo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo057o
oooo00?o0000ooooooooool01Oooool01?l0003oooooo`000?l0000Cooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
04;ooooo00Co0000oooooooooooo0000;Oooool001Wooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooo`00000Dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooool00000;_ooool001[o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooo`00000Eooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04;o
oooo0ol0000^ooooo`006_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0D_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0001Go
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0Loooool001[ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool00oooool01?l0003ooooo
ooooool0000Eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo07?ooooo000Jooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00?ooooo
00Co0000oooooooooooo00005Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1cooooo`006_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0D_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000005Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1dooooo`00
6_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
D_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000005_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`1dooooo`006_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0E?ooool01Ol0003ooooooooooooooooo000000?ooooo0_l0000Eooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo07Cooooo000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`1Dooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`1dooooo`006oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0EOooool00ol0003oooooo`000004ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0M?ooool001_ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooool000001?oo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07Cooooo000Looooo`05o`000?oooooo
ooooooooool000005oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1Eooooo`;o00001Oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo07Cooooo000Looooo`05o`000?ooooooooooooooool000005ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0M?oo
ool001cooooo00Go0000ooooooooooooooooo`00000Gooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo057ooooo1Ol0
0006ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0M?ooool001cooooo00Co0000
oooooooooooo00006?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1Aooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo07Cooooo000Mooooo`03o`000?oo
oooo000001Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0D_ooool00onHV9So8B4Qonk^kP07ooooo`?o00005Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`1dooooo`007Oooool3o`0001Sooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Doooool0
0onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0MOooool0
03Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0EOooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0MOooool003Sooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0E_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0MOooool003Sooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0D_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`1eooooo`00>?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Booooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07Go
oooo000hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool05_ooool01Ol0003ooooo
oooooooooooo000001Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1eooooo`00
>Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo01Kooooo00Co0000oooooooooooo
00005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07Gooooo000iooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo05gooooo0_l0000Gooooo`04o`000?ooooooooooo`0001Oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`1eooooo`00>Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Mooooo`03o`00
0?oooooooooo01Kooooo00Co0000oooooooooooo00005oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo07Gooooo000iooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0
5oooool2o`0001Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1eooooo`00>Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07Gooooo000iooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo05gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo07Gooooo000iooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo07Gooooo000iooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05ko
oooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07Go
oooo000iooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo07Kooooo000iooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05kooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07Kooooo000i
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo05kooooo0_l0000cooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0M_ooool003[ooooo00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0M_ooool003[ooooo00Go0000ooooooooooooooooo`00000?
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0b
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0M_ooool003[ooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0G_ooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0M_ooool0
03[ooooo00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0G_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0M_ooool003[ooooo00Go0000ooooooooooooooooo`00000@ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0cooooo`05o`000?oooooo
ooooooooool00000N?ooool003[ooooo00Co0000oooooooooooo00004Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0<oooool01Ol0003ooooooooo
oooooooo000007Sooooo000jooooo`04o`000?ooooooooooo`00017ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo03?ooooo00Go0000oooooooooooo
ooooo`00001hooooo`00>_ooool01?l0003oooooooooool0000Aooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0G_ooool2o`0003Cooooo00Co0000oooooooooooo0000NOooool003[o
oooo00Co0000oooooooooooo00004Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
05kooooo00?o0000ooooooooool0<oooool01?l0003oooooooooool0001iooooo`00>_ooool01?l0
003oooooooooool0000Aooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0G_ooool0
0ol0003oooooooooo`0cooooo`04o`000?ooooooooooo`0007Wooooo000kooooo`03o`000?oooooo
0000017ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooo
oooo03?ooooo00Co0000oooooooooooo0000NOooool003_ooooo00?o0000ooooool000004Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0<oooool0
1?l0003oooooooooool0001iooooo`00>oooool2o`0001;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1Eooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0d
ooooo`03o`000?oooooo000007Wooooo001?ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0E_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ool00000NOooool004oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Cooooo`Go
00001_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooo000007Wooooo001?ooooo`05o`00
0?ooooooooooooooool00000E_ooool01?m4A4CogMgMooooool00007ooooo`?o0000=?ooool2o`00
07[ooooo001@ooooo`04o`000?ooooooooooo`0005Kooooo00CogMgMoeEEEOoooooo00001oooool0
0ol0003oooooooooo`2`ooooo`00D?ooool01?l0003oooooooooool0001Gooooo`03ogMgMoo<c<co
000000Oooooo00?o0000ooooooooool0/?ooool0053ooooo00Co0000oooooooooooo0000Eoooool0
0oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0;3ooooo001@ooooo`04o`000?oooooooooo
o`0005Sooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`2`ooooo`00D?ooool00ol0
003oooooo`00001Rooooo`03o`000?oooooooooo0;3ooooo001@ooooo`03o`000?oooooo000006;o
oooo00?o0000ooooooooool0/?ooool0053ooooo00?o0000ooooool00000H_ooool00ol0003ooooo
ooooo`2`ooooo`00DOooool2o`0006;ooooo0_l0002aooooo`00DOooool2o`0006;ooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`00
0;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Zoooo
o`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OmE
EEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?nHV9Sooooo
oiRHV?lQ8B401_ooool3o`000;3ooooo002Zooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool0
0ol0003oooooooooo`2`ooooo`00Z_ooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo
0;3ooooo002Zooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0/?ooool00:_ooooo
00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Ko
oooo00?o0000ooooooooool0/?ooool00:[ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03
o`000?oooooooooo0;3ooooo002Zooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`2`ooooo`00Z_ooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0002`ooooo`00
Z_ooool01Oo<c<co0000o`000?l0003oc<c<0;Wooooo002Zooooo`05oa0@4?nj^[[ooooookZj^_l@
4100^Oooool00:[ooooo00Go0000okZj^_oooooo^[Zjo`00002iooooo`00Z_ooool01OnYZJWo410@
o`000?l@413oZJVY0;Wooooo003oooooofWooooo002_ooooo`03o`000?nj^[[ooooo0;Kooooo002_
ooooo`;o<S8b]oooool0083ooooo0_l000001_l@413oooooooooool@413o0000oa0@41Sooooo00Go
A4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOo
0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06Oooool4o`000008oa0@4?oooooooooo
oiRHV?l@413o0000oc8b<_o<c<`3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0N?ooool0087ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00003Oooool02OmgMgOo<S8b
ooooooooooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03olc<c?l0003o410@00cooooo00Go410@
okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003oooooooooo`02ooooo`05oa0@4?nj
^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg07Sooooo0021ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool06oooool01?l0003oooooooooool@4103ooooo`03
oa0@4?oooooooooo013ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`06ooooo`05
o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`1fooooo`00POooool01_l0003o
ooooodA4A?m4A4Coooooo`0000Wooooo1_l0000=ooooo`05ogMgMolb<S;oooooooooool000000ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo1_l0000<ooooo`03o`000?oo
oooooooo00Gooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000007Sooooo
0021ooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo00006Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00;ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool01?ooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool00000N?oo
ool0087ooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Iooooo`03o`000?oooooooooo00Cooooo
00Go410@oooooooooooooooooa0@400@ooooo`03oa0@4?l0003o000000?o00007?ooool00ol0003o
ooooooooo`05ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@401hoooo
o`00POooool01_l0003o<S8boooooooooooo<S8bo`0001Wooooo00?o0000ooooooooool01?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg07So
oooo0020ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool4o`0000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Booooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l0
00001?ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1h
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(132) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .21745 m
.00488 .24905 L
.00942 .28055 L
.01199 .29694 L
.01441 .31004 L
.01575 .31587 L
.01646 .31846 L
.01721 .32082 L
.01853 .32394 L
.01975 .32556 L
.02104 .32593 L
.02221 .32502 L
.02357 .32254 L
.02486 .31879 L
.02605 .31424 L
.02715 .30915 L
.02966 .29498 L
.04057 .21787 L
.04635 .18422 L
.04919 .17127 L
.0518 .16135 L
.05413 .15399 L
.05669 .14744 L
.05926 .14232 L
.06198 .13833 L
.06351 .13666 L
.06496 .13543 L
.06626 .13458 L
.06699 .13422 L
.06768 .13394 L
.06841 .13371 L
.06922 .13354 L
.07 .13346 L
.07085 .13347 L
.0716 .13355 L
.07238 .13371 L
.07305 .13392 L
.07379 .13422 L
.07523 .13504 L
.07655 .13604 L
.07806 .13754 L
.0795 .1393 L
.08205 .14334 L
.08481 .14912 L
.08728 .15569 L
.08994 .1644 L
.09475 .18519 L
.10046 .21992 L
.10568 .26089 L
.1111 .30752 L
Mistroke
.11396 .33013 L
.11554 .34095 L
.11701 .34972 L
.11842 .35656 L
.11916 .3595 L
.11994 .36209 L
.12133 .3653 L
.1226 .36666 L
.12387 .3665 L
.12507 .36498 L
.12637 .36189 L
.12711 .35954 L
.12777 .35705 L
.13834 .2936 L
.14112 .27667 L
.14412 .26086 L
.14677 .24924 L
.14955 .23928 L
.15193 .23241 L
.15454 .22651 L
.15691 .22242 L
.15912 .21954 L
.16179 .217 L
.16422 .21536 L
.16557 .21464 L
.16702 .21399 L
.1683 .21352 L
.16967 .21312 L
.17098 .21286 L
.17218 .21275 L
.17338 .21281 L
.17453 .21303 L
.17585 .21356 L
.17708 .21435 L
.17843 .2156 L
.17986 .21742 L
.18113 .21952 L
.18251 .22234 L
.18499 .22914 L
.18794 .24055 L
.19065 .25488 L
.19514 .28842 L
.20005 .33877 L
.20481 .39218 L
.20731 .41614 L
.20868 .42656 L
.20997 .43407 L
.21134 .43934 L
.21207 .4409 L
.21285 .44157 L
Mistroke
.21424 .44015 L
.21551 .43596 L
.21679 .42902 L
.21819 .41858 L
.22074 .39319 L
.23053 .26889 L
.23605 .21378 L
.23914 .19102 L
.24194 .17466 L
.24456 .16243 L
.24739 .15203 L
.25006 .1445 L
.25252 .13921 L
.25511 .135 L
.25746 .1321 L
.26018 .12958 L
.26275 .12782 L
.26391 .1272 L
.26513 .12665 L
.26619 .12627 L
.26733 .12594 L
.26855 .12569 L
.26969 .12556 L
.27106 .12551 L
.2723 .12558 L
.27357 .12574 L
.27492 .12601 L
.2762 .12635 L
.27735 .12672 L
.28288 .12923 L
.28563 .13096 L
.2886 .13329 L
.294 .139 L
.29915 .14628 L
.30395 .15473 L
.31489 .18055 L
.32032 .19575 L
.32623 .21157 L
.32894 .21783 L
.33181 .22336 L
.33322 .22553 L
.33453 .22721 L
.33571 .2284 L
.33699 .22932 L
.33833 .22987 L
.33957 .22999 L
.34094 .22969 L
.3417 .22931 L
.3424 .22885 L
.3438 .22758 L
Mistroke
.34533 .2257 L
.3481 .2211 L
.35341 .2091 L
.35831 .19593 L
.36769 .17065 L
.37778 .14966 L
.38307 .14169 L
.38792 .136 L
.39025 .1338 L
.3928 .13176 L
.39743 .12896 L
.40028 .12773 L
.40286 .12692 L
.40429 .1266 L
.4051 .12647 L
.40584 .12637 L
.40721 .12627 L
.4079 .12626 L
.40866 .12627 L
.41002 .1264 L
.41126 .12661 L
.41194 .12678 L
.41269 .12699 L
.41405 .12749 L
.41666 .12883 L
.41908 .13056 L
.42162 .13294 L
.42394 .13571 L
.42645 .13944 L
.42918 .14457 L
.4338 .15624 L
.43867 .17319 L
.44409 .19801 L
.44987 .23023 L
.45494 .25938 L
.45771 .27339 L
.4603 .2839 L
.46158 .28789 L
.46296 .29114 L
.46375 .29248 L
.46449 .2934 L
.46516 .29393 L
.46589 .29418 L
.46719 .29379 L
.46857 .29223 L
.46987 .2897 L
.47105 .28658 L
.47393 .27609 L
.47705 .26128 L
.4827 .23042 L
Mistroke
.48807 .20267 L
.49373 .17957 L
.49856 .16568 L
.5013 .15998 L
.50386 .15591 L
.50519 .15423 L
.5066 .15275 L
.50782 .1517 L
.50913 .15081 L
.50986 .1504 L
.51053 .15009 L
.51185 .14964 L
.51255 .14948 L
.51331 .14936 L
.51411 .1493 L
.51485 .1493 L
.51621 .14942 L
.51749 .14967 L
.51864 .14999 L
.51989 .15043 L
.52268 .15174 L
.52526 .15329 L
.53473 .16125 L
.53997 .16688 L
.54475 .1727 L
.54951 .1796 L
.55468 .18937 L
.56015 .20347 L
.56534 .22173 L
.57018 .24401 L
.57533 .27278 L
.57983 .29929 L
.58229 .31254 L
.58458 .32307 L
.58586 .3279 L
.58702 .33152 L
.58831 .33458 L
.5897 .33663 L
.59085 .33732 L
.59211 .33699 L
.5933 .33562 L
.59439 .33347 L
.59566 .32995 L
.59684 .3257 L
.59954 .31297 L
.60499 .27848 L
.61416 .21773 L
.61935 .19069 L
.62417 .17136 L
.62689 .16282 L
Mistroke
.62945 .1563 L
.6324 .1505 L
.6337 .14848 L
.63507 .14667 L
.63631 .14531 L
.63767 .14409 L
.6389 .14322 L
.64005 .14263 L
.64141 .14219 L
.64265 .14207 L
.64333 .14213 L
.64408 .1423 L
.64543 .1429 L
.64664 .1438 L
.64776 .14499 L
.649 .14671 L
.65034 .14909 L
.65305 .15581 L
.65554 .16446 L
.65772 .17424 L
.66009 .18768 L
.66489 .22535 L
.66997 .28288 L
.67548 .35799 L
.67801 .38987 L
.67939 .40475 L
.68069 .41638 L
.68179 .42421 L
.68297 .43024 L
.68429 .43384 L
.68548 .43417 L
.6862 .43303 L
.68695 .43072 L
.68831 .42388 L
.68915 .41808 L
.68993 .4116 L
.6914 .39716 L
.69701 .32511 L
.70201 .26083 L
.70465 .23285 L
.70748 .20861 L
.71027 .19013 L
.71281 .17733 L
.71536 .16773 L
.71777 .16129 L
.71908 .15876 L
.7198 .15763 L
.72047 .15674 L
.72166 .15554 L
.72297 .15472 L
Mistroke
.72369 .15448 L
.72439 .15438 L
.72569 .15451 L
.72641 .15475 L
.72709 .15506 L
.72783 .15551 L
.72861 .1561 L
.73113 .15861 L
.73385 .16225 L
.73879 .17088 L
.74803 .19112 L
.75283 .20057 L
.75553 .20465 L
.75799 .2074 L
.75939 .2085 L
.76017 .20898 L
.7609 .20931 L
.76223 .20968 L
.76291 .20974 L
.76365 .2097 L
.76497 .20936 L
.7657 .20903 L
.76638 .20863 L
.76763 .20765 L
.76894 .20629 L
.77158 .20261 L
.77441 .19746 L
.7795 .18611 L
.79105 .15872 L
.79627 .148 L
.80179 .13882 L
.80468 .13501 L
.80786 .13151 L
.81078 .12883 L
.81345 .12679 L
.81596 .12523 L
.81871 .12395 L
.82022 .12344 L
.82095 .12323 L
.82161 .12308 L
.82295 .12284 L
.82368 .12275 L
.82437 .12269 L
.82562 .12264 L
.82693 .12268 L
.82806 .12276 L
.82929 .12292 L
.83061 .12317 L
.83204 .12352 L
.8346 .1244 L
Mistroke
.83588 .12497 L
.8373 .12572 L
.84016 .12763 L
.84281 .12992 L
.8453 .13256 L
.85089 .14035 L
.85692 .15209 L
.8623 .1662 L
.86795 .18482 L
.87806 .2232 L
.88054 .23212 L
.88322 .24075 L
.88559 .24706 L
.88688 .24987 L
.88809 .25204 L
.88949 .25393 L
.89022 .25467 L
.89102 .25525 L
.89174 .25559 L
.89242 .25574 L
.89371 .25557 L
.89498 .25484 L
.89615 .2537 L
.89744 .25194 L
.89881 .24953 L
.90132 .24389 L
.90403 .23636 L
.90894 .22049 L
.9181 .19087 L
.92294 .17826 L
.92812 .1678 L
.9311 .16306 L
.9338 .15945 L
.9391 .15403 L
.94194 .15189 L
.94456 .1503 L
.94737 .1489 L
.95048 .14764 L
.95299 .14679 L
.9557 .14603 L
.95719 .14569 L
.95856 .14543 L
.95993 .14522 L
.96124 .14507 L
.9625 .14499 L
.96386 .14495 L
.96515 .14498 L
.96634 .14507 L
.96741 .14519 L
.96859 .14538 L
Mistroke
.96982 .14566 L
.97097 .14598 L
.97231 .14646 L
.97358 .14702 L
.97597 .14843 L
.97854 .15058 L
.98134 .15385 L
.98357 .15732 L
.98604 .16218 L
.98844 .1681 L
.99103 .17597 L
.99566 .19445 L
1 .21745 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo06;ooooo1_l00018
ooooo`00JOooool7o`0002Gooooo1_l0000Jooooo`03o`000?oooooooooo067ooooo00?o0000oooo
ooooool01?ooool2o`0004Kooooo001Yooooo`03o`000?oooooooooo00Cooooo0_l0000Rooooo`03
o`000?oooooooooo00?ooooo0_l0000Iooooo`;o0000HOooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo04?ooooo000[ooooo`?o0000>_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01gooooo0_l00008ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
Goooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04;ooooo000Zooooo`;o00000_oo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0G_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo047ooooo000Yooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo05gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`10ooooo`00:Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0Yooooo`?o0000<Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
043ooooo000Yooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo02Sooooo0_l00002ooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Looooo`Oo00007?ooool002Sooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Cooooo
00Co0000oooooooooooooooo0_l0000Tooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01[ooooo0_l00007ooooo`03
o`000?oooooooooo01Wooooo000Xooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0Cooooo`04o`000?oooooo0000o`0000;ooooo0_l0000Rooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Hooooo`00
9oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
4_ooool3o`0000Gooooo0_l0000Pooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
4_ooool4o`0001?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool05oooool002Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01;ooooo0_l00008ooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Booooo`04o`000?oo
ooooooooo`0001?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool05_ooool002Kooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool05Ooo
ool001Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool01OnHV9So410@o`000?lb<S;oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Sooooo00?o0000ooooooooool04Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o
0000oc8b<_o^k^h9ooooo`03o`000?oooooooooo017ooooo0_l0000;ooooo`03o`000?oooooooooo
01?ooooo1?l000002?l@413oooooo`000?o^k^ko<S8bo`000?lb<S;ok^k^0oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo00Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oo
oooo00?o0000ooooooooool04Oooool01OnHV9So410@o`000?l0003oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`03o`000?oooooooooo00kooooo0_l000002Ol@413ooooooooooooo
ooook^k^oc8b<_l0003o<S8bonk^kP0>ooooo`005_ooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Go
oooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool0
1OnHV9So8B4Qo`000?ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`09ooooo`03o`00
0?oooooooooo017ooooo0_l00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02_ooool00ol0003o
ooooooooo`0@ooooo`;o00003?ooool00ol0003oooooooooo`0Dooooo`0:o`000?oooooooooooooo
ool0003oMgMgoiRHV?ooooooV9RHogMgM`?ooooo00?o0000ooooooooool04?ooool02Ol0003ooooo
ooooooooooooV9RHob4Q8Oo^k^ko0000odA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01ooo
ool00ol0003oooooooooo`0Aooooo`05oa0@4?nj^[[oooooo`000?lb<S800oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03_ooool000_ooooo1_l00002ooooo`Go00000oooool01Ol@413o
oooooooooooooooo410@00Gooooo00?o0000ooooooooool02_ooool6o`0000Kooooo00Go0000oooo
oooooooooooooa0@4003ooooo`03oa0@4?oooooooooo017ooooo1_l00003ooooo`03o`000?lQ8B7o
k^k^00Cooooo00Go410@oooooooooooooooooa0@4009ooooo`03o`000?oooooooooo00Oooooo1_l0
0003ooooo`03o`000?oooooo000000Cooooo00Go410@oooooooooooooooooa0@400:ooooo`03o`00
0?oooooooooo013ooooo0_l0000<ooooo`03o`000?oooooooooo01Cooooo00Ko0000oooooooooooo
0000ooooool@4103ooooo`03oa0@4?oooooooooo00;ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`02ooooo`04oiRHV?lQ8B7ok^k^o`0000?ooooo00Go410@oooooooooooooooooa0@
4006ooooo`03o`000?oooooooooo01Gooooo0_l00003ooooo`05oa0@4?ooooooooooooooool@4100
2oooool00ol0003oooooooooo`0=ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00ko
oooo000Cooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`000005oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00onYZJWo410@ooooo`02oooo
o`05o`000?ooooooooooooooool000007?ooool01?l0003oV9RHob4Q8Oo^k^h3ooooo`05o`000?oo
ooooooooooooool000002_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo000000Cooooo
00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooool0
00003Oooool00ol0003oooooooooo`0Cooooo`06o`000?ooooooooooo`000?oooooo00000oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool0
0onHV9So8B4Qo`000003ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`0Eooooo`03ojVYZOl0003ooooo00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`00
0?oooooooooo00gooooo00?oA4A4omgMgOooool00_l00003ooooo`05o`000?ooooooooooooooool0
00003_ooool001?ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo0000
00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`03oa0@4?l0003o^[Zj
00?ooooo00Go0000ooooooooooooooooo`00000Looooo`04o`000?ooooooMgMgofIVIP?ooooo00Go
0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo
00001?ooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000ooooooooool03oooool00ol0
003oooooo`00000>ooooo`03o`000?oooooooooo01;ooooo00Ko0000oooooooooooo0000ooooool0
0003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`04ooooo`03ogMgMomVIVKo000000;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo01Cooooo00?o410@o`000?l000000oooool01Ol0003ooooooooooooooooo000000[o
oooo00?o0000ooooooooool03_ooool00ooMgMgoEEEEooooo`02o`0000?ooooo00Go0000oooooooo
ooooooooo`00000>ooooo`005?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooooooo
ool@41001?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo00?o^[Zjob4Q
8Oooool00_ooool01Ol@413ooooooooooooooooo410@01cooooo00Co0000oooooooooooo00000ooo
ool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000ooooooooool03Oooool01?l0003ooooo
ooooool00004ooooo`05oa0@4?ooooooooooooooool@41002_ooool00ol0003oooooooooo`0?oooo
o`04o`000?oooooo0000o`0000kooooo00?o0000ooooooooool04Oooool01_l0003oooooooooool0
003ooooooa0@40?ooooo00?o410@ooooooooool00_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00Gooooo0_l00002ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003o
ooooooooo`0Fooooo`03okZj^_l0003ooooo00;ooooo00Go410@oooooooooooooooooa0@400:oooo
o`03o`000?oooooooooo00oooooo00CoMgMgolc<c?l0003o00000oooool01Ol@413ooooooooooooo
oooo410@00kooooo000Dooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`04ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool01Ol@413oV9RHoooo
oonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`;o000000?ooooooiRHV?l@
41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000ooooooooool03Oooool01?l0
003oooooooooool00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooo000000oooooo00?o0000ooooooooool04Oooool00ol0003oooooo`00
0002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0>ooooo`0Ao`00
0?ooooooooooooooool0003o^[ZjoooooonHV9So410@ooooool0003oooooogMgMonHV9SooooooiRH
V?mgMgL01Oooool00ol0003oooooooooo`0Cooooo`04oa0@4?nHV9SooooookZj^P;o00000_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo00?o0000ooooooooool03oooool01Oo^k^koA4A4o`00
0?oooooo000000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`005Oooool00omgMgOo0000
ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h06oooool01Ol0003o410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`03o`000?oooooooooo00_ooooo00Go0000oooooomEEEGoIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo0000
013ooooo00?o0000ooooooooool03_ooool01OmEEEGoIVIVo`000?oooooo000000;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_oo
ool03OnHV9So410@o`000?lQ8B7oc<c<ooooool0003oooooonk^k_lb<S;o0000oc8b<_o^k^h01?oo
ool00ol0003oooooooooo`0Dooooo`06ojVYZOl@413o0000oa0@4?nYZJWo00000_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Wooooo00?o0000ooooooooool04Oooool01?mgMgOo0000ooooool00002
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool002Cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00gooooo00Co0000oooooooooooo00004?oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04ooo
ool002Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo00gooooo00Co0000oooooooooooo00004?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool04_ooool002Cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00cooooo00Co0000oooooooooooo00004Ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool04_oo
ool002Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo00_ooooo00Go0000ooooooooooooooooo`00000Aooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0Booooo`008oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooo
oooo0000017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo01;ooooo000Foooooooo0000@?l0000Cooooo`005_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`04
ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
o`000003ooooool0003ooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool04Oooool001Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01?oo
ool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
0_l00006ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool2o`0000Oooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00007
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooo000000Gooooo00?o0000ooooooooool01?ooool01?l0003oooooooooooooool2o`0000;ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Aooooo`008oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo017ooooo1Ol0000Booooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo017ooooo000Fooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Aooooo`005_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo02kooooo000Fooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0;_ooool001Kooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo01cooooo0_l000000ooooooo0000o`00000Pooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo03Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0^ooooo`00
5_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
7_ooool3o`00027ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo02oooooo000Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00ooo
ool2o`0001Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo02oooooo000Gooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`12ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0_ooooo`005oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0;oooool001Oooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo033ooooo000Gooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0`ooooo`005oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0hooooo`05o`000?ooooooooooooooool00000<oooool001Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0>?oo
ool01?l0003oooooooooool0000dooooo`005oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0iooooo`?o0000=?oo
ool001Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo04Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`;o00005Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`1`ooooo`006?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1`ooooo`006?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0AOooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`1`ooooo`006?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`1`ooooo`006?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0AOooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1`ooooo`006Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0AOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`1`ooooo`006Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1`oooo
o`006Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`1`ooooo`006Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0A_ooool01Ol0003ooooooooooooooooo000000So
oooo0_l0000Fooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo073ooooo000Iooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`17ooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1`ooooo`006_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Aoooool00ol0003ooooo
o`000009ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0L?ooool001[ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Sooooo0ol0
0009ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0L?ooool001[ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Cooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`1aooooo`006_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo077ooooo000Jooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`19ooooo`Go00001_ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo077ooooo000Jooooo`05o`000?ooooooooooooooool000006_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`19ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo077ooooo000Jooooo`05o`000?ooooooooooooooool000006_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`1:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0000Gooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
077ooooo000Jooooo`05o`000?ooooooooooooooool000006_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1;oooo
o`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1aoooo
o`006oooool01?l0003oooooooooool0000Jooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04cooooo00?oMgMgofIV
I_ooool01Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo077ooooo000Kooooo`04
o`000?ooooooooooo`0001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0LOooool001_ooooo00?o0000ooooool0
00007?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`19ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0
003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000005oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo077ooooo000Looooo`;o00007?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`19oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0Hooooo`05o`000?oooooo
ooooooooool000005oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo077ooooo000L
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0H
ooooo`05o`000?ooooooooooooooool000005oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo077ooooo000jooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool06Oooool0
0ol0003oooooo`00000Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0LOooool0
03[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0EOooool2o`0001[ooooo00?o0000ooooool000006?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo077ooooo000jooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Go
oooo00?o0000ooooooooool06Oooool3o`0001Sooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`1aooooo`00>_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1aooooo`00>_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1Eooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`1aooooo`00>oooool01Ol0003ooooooooooooooooo000001Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1booooo`00>oooool01?l0003oooooooooool0000Fooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0L_ooool003_ooooo00Co0000oooooooooooo00005_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo000kooooo`04o`000?oooooo
ooooo`0001Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Eooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`00??ooool0
0ol0003oooooo`00000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0EOooool0
0ol0003oooooooooo`0eooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool0
03cooooo00?o0000ooooool000005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
05Gooooo0_l0000fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool003co
oooo0ol0000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0EOooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool005Kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`1booooo`00E_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo07;ooooo001Fooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0E_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0L_ooool005Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Foooo
o`03o`000?oooooooooo03Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1boooo
o`00E_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Kooooo00?o0000oooooooo
ool0=_ooool01Ol0003ooooooooooooooooo000007Gooooo001Gooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0fooooo`05o`000?oooooooooooooo
ool00000MOooool005Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Fooooo`;o
0000=oooool01Ol0003ooooooooooooooooo000007Gooooo001Gooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0fooooo`05o`000?oooooooooooooo
ool00000MOooool005Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Fooooo`03
o`000?oooooooooo03Kooooo00Go0000ooooooooooooooooo`00001eooooo`00Eoooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0=_ooool01Ol0003o
oooooooooooooooo000007Gooooo001Gooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0E_ooool00ol0003oooooooooo`0fooooo`05o`000?ooooooooooooooool00000MOooool005Oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1=ooooo`;o000000?o410@oooooooo
ool01?ooool00ol0003oooooooooo`0fooooo`05o`000?ooooooooooooooool00000MOooool005So
oooo00Go0000ooooooooooooooooo`00001@ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0=_ooool01?l0003oooooooooool0001fooooo`00F?ooool01?l0003oooooooooool0001>
ooooo`Go00001_ooool00ol0003oooooooooo`0fooooo`04o`000?ooooooooooo`0007Kooooo001H
ooooo`04o`000?ooooooooooo`0004kooooo00CoA4A4omgMgOoooooo00001oooool3o`0003Kooooo
00Co0000oooooooooooo0000M_ooool005Sooooo00Co0000oooooooooooo0000C_ooool01?oMgMgo
EEEEooooool00007ooooo`03o`000?oooooooooo03Kooooo00Co0000oooooooooooo0000M_ooool0
05Sooooo00Co0000oooooooooooo0000Coooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooo
oooo03Kooooo00Co0000oooooooooooo0000M_ooool005Sooooo00Co0000oooooooooooo0000Cooo
ool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooool00000M_oo
ool005Sooooo00Co0000oooooooooooo0000D?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oo
oooooooo03Oooooo00?o0000ooooool00000M_ooool005Sooooo00Co0000oooooooooooo0000FOoo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooo000007Kooooo001Hooooo`04o`000?oooooo
ooooo`0005Wooooo00?o0000ooooooooool0=oooool2o`0007Oooooo001Iooooo`;o0000F_ooool0
0ol0003oooooooooo`0hooooo`03o`000?oooooooooo07Gooooo001Iooooo`;o0000F_ooool2o`00
0;7ooooo001Iooooo`;o0000F_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00:[ooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03
o`000?oooooooooo0;3ooooo002Zooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003o
ooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool0/?ooool00:[ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000/?ooool00:[ooooo
00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03oeEE
EOn7QhOooooo00Sooooo00?o0000ooooooooool0/?ooool00:[ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`2`ooooo`00Zoooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Z
ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool0
1OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05oc8b<_nHV9So
oooooiRHV?lb<S801_ooool3o`000;3ooooo002Zooooo`05olc<c?l0003o0000o`000?o<c<`0^Ooo
ool00:[ooooo00Go410@okZj^_oooooo^[Zjoa0@402iooooo`00Z_ooool01Ol0003o^[Zjoooooonj
^[[o00000;Wooooo002Zooooo`05ojVYZOl@413o0000oa0@4?nYZJT0^Oooool00?ooooooJOooool0
0:oooooo00?o0000okZj^_ooool0]_ooool00:oooooo0_lb<S:gooooo`00P?ooool2o`000006oa0@
4?oooooooooooa0@4?l0003o410@6?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP03ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4
okZj^P0Iooooo`Co000000So410@ooooooooooooV9RHoa0@4?l0003o<S8bolc<c0?ooooo1Ol0001h
ooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l0000=oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?oc<c<o`000?l@4100
3?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<ooooo`03o`000?oooooooooo00;o
oooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0N?ooool0
087ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooooooo
oa0@40?ooooo00?o410@ooooooooool04?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool00_ooool00onHV9So8B4Qonk^kP1iooooo`00POooool01_l0
003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000=ooooo`05ogMgMolb<S;oooooooooool00000
0oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo1_l0000<ooooo`03o`00
0?oooooooooo00Gooooo00?oZJVYoa0@4?ooool01?ooool00onHV9So8B4Qonk^kP1hooooo`00POoo
ool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001Wooooo00Go0000ob4Q8Ol0003o<S8bolc<c002oooo
o`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo00Cooooo00?o410@o`000?nj^[X01_ooool00omgMgOoIVIVooooo`1gooooo`00POooool01_l0
003oQhN7ojVYZOnj^[[oEEEEo`0001Wooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@013ooooo00?o410@o`000?l000000ol0000Looooo`03o`000?oooooooooo00Gooooo
00?o^[Zjob4Q8Oooool01_ooool00ol0003oooooooooo`1fooooo`00POooool01_l0003o<S8boooo
oooooooo<S8bo`0001Wooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
01;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02ooooo`05oa0@4?nHV9Sooooo
okZj^_l000000oooool01Ol0003o^[ZjoooooonHV9So410@07Sooooo0020ooooo`03oa0@4?l0003o
QhN700;ooooo00?oQhN7o`000?l@41006?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0Booooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000001?ooool01OnYZJWo410@o`00
0?l@413oZJVY00?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c01hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(134) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .27862 m
.00236 .29548 L
.00488 .31086 L
.0061 .31692 L
.00726 .32164 L
.0083 .32495 L
.00942 .32748 L
.01066 .32894 L
.01203 .32891 L
.01272 .32824 L
.01346 .32704 L
.01479 .32367 L
.01612 .31886 L
.01738 .31308 L
.01975 .29958 L
.02982 .22752 L
.03248 .21051 L
.03536 .19465 L
.03789 .18302 L
.04057 .17308 L
.04356 .16459 L
.04499 .16144 L
.04632 .15898 L
.04762 .15699 L
.04881 .15552 L
.05012 .15424 L
.05081 .15372 L
.05154 .15326 L
.05284 .1527 L
.05404 .15244 L
.05534 .15244 L
.05607 .15255 L
.05677 .15273 L
.05801 .15321 L
.05915 .15383 L
.06172 .15576 L
.0645 .15856 L
.06709 .16168 L
.07297 .17003 L
.07865 .17882 L
.08481 .18762 L
.09586 .19893 L
.10092 .2033 L
.1037 .20613 L
.10629 .20944 L
.10862 .21328 L
.11112 .21865 L
.1139 .22653 L
.11644 .23586 L
.12125 .25976 L
Mistroke
.12581 .28955 L
.13101 .32748 L
.13356 .34462 L
.1359 .35765 L
.13722 .36333 L
.13789 .36568 L
.13861 .36774 L
.13933 .36933 L
.14001 .37035 L
.14081 .37097 L
.14154 .37095 L
.1428 .36961 L
.14416 .36628 L
.14545 .36142 L
.14664 .35554 L
.14895 .34091 L
.1511 .32416 L
.15602 .28083 L
.16117 .23698 L
.16596 .20333 L
.17091 .17715 L
.17352 .16681 L
.17631 .15827 L
.17772 .15484 L
.17925 .15174 L
.1806 .14948 L
.18202 .14753 L
.1833 .14614 L
.18398 .14554 L
.18472 .145 L
.186 .14431 L
.1872 .14397 L
.18849 .14398 L
.1897 .14437 L
.19101 .14524 L
.19168 .14588 L
.19242 .14675 L
.19364 .14861 L
.19497 .15122 L
.19736 .1577 L
.19972 .1665 L
.2022 .17872 L
.20432 .19194 L
.20664 .2099 L
.21218 .27066 L
.21741 .34962 L
.22217 .42195 L
.22332 .43633 L
.22457 .44941 L
.22593 .46038 L
Mistroke
.22721 .46703 L
.22791 .4691 L
.22868 .47002 L
.2294 .4696 L
.23007 .46811 L
.23134 .46243 L
.23269 .45251 L
.23406 .43886 L
.23535 .42321 L
.23775 .38874 L
.24321 .30356 L
.2461 .26388 L
.2492 .22926 L
.25197 .20517 L
.2545 .18819 L
.25705 .17505 L
.25946 .16564 L
.26077 .16162 L
.26215 .1581 L
.26336 .15566 L
.26465 .15358 L
.26603 .15196 L
.26733 .15094 L
.26809 .15055 L
.26888 .15028 L
.26955 .15016 L
.27029 .15013 L
.2716 .15032 L
.27284 .15074 L
.27395 .15131 L
.27515 .1521 L
.27786 .15451 L
.28035 .15753 L
.28489 .16519 L
.28969 .1761 L
.29961 .20283 L
.30508 .21704 L
.30777 .22299 L
.30908 .22546 L
.31026 .22739 L
.31138 .22894 L
.31259 .23026 L
.31387 .23126 L
.31507 .23179 L
.3164 .23193 L
.31707 .23181 L
.31781 .23155 L
.31911 .23075 L
.32032 .22963 L
.32151 .22819 L
Mistroke
.32264 .22653 L
.32475 .22274 L
.3295 .21153 L
.33874 .18396 L
.34868 .15715 L
.35438 .14548 L
.35959 .13706 L
.3621 .13383 L
.36483 .13089 L
.36982 .12685 L
.37256 .12518 L
.37504 .12395 L
.37642 .12339 L
.37791 .12287 L
.37932 .12249 L
.38061 .12223 L
.38181 .12207 L
.38294 .122 L
.38417 .12199 L
.38549 .12207 L
.38687 .12224 L
.38818 .12249 L
.38936 .12278 L
.39064 .12316 L
.39328 .12416 L
.3962 .12567 L
.39924 .12781 L
.4021 .13046 L
.40721 .13702 L
.41272 .147 L
.41792 .1598 L
.42276 .17534 L
.43375 .22217 L
.43926 .24706 L
.44196 .25787 L
.44446 .26624 L
.44583 .27 L
.44733 .27334 L
.44806 .27463 L
.44885 .27578 L
.44968 .27671 L
.45045 .27732 L
.45115 .27764 L
.45191 .27776 L
.4533 .27733 L
.45465 .27616 L
.4559 .27444 L
.45725 .27195 L
.45868 .26869 L
.46124 .26151 L
Mistroke
.46702 .24155 L
.47243 .22208 L
.47748 .2062 L
.48198 .195 L
.4868 .18613 L
.48955 .18226 L
.49215 .17921 L
.49703 .17477 L
.50186 .17152 L
.50718 .16854 L
.51796 .16195 L
.5274 .15567 L
.53254 .15235 L
.53504 .15096 L
.53732 .14993 L
.53858 .14948 L
.53977 .14916 L
.54103 .14893 L
.54239 .14882 L
.54306 .14883 L
.54379 .14889 L
.54456 .149 L
.54528 .14916 L
.54656 .14958 L
.54793 .15025 L
.54918 .15108 L
.55054 .15225 L
.55174 .15354 L
.55302 .15522 L
.55543 .15936 L
.55766 .16453 L
.56024 .17234 L
.56303 .18331 L
.56807 .21081 L
.57407 .25676 L
.57957 .30632 L
.58212 .32775 L
.58453 .34464 L
.58587 .35195 L
.58657 .3551 L
.58731 .35788 L
.58863 .36127 L
.58984 .3626 L
.59097 .36225 L
.59219 .36015 L
.59334 .35659 L
.59439 .35206 L
.59696 .33647 L
.59941 .31705 L
.60992 .22222 L
Mistroke
.61295 .20005 L
.6158 .1826 L
.61839 .16955 L
.62113 .15843 L
.62361 .15047 L
.62633 .14375 L
.62881 .13919 L
.63112 .13608 L
.63252 .13466 L
.63385 .13361 L
.63504 .1329 L
.63634 .13236 L
.63701 .13218 L
.63775 .13205 L
.63852 .132 L
.63924 .13203 L
.64054 .13225 L
.64126 .13248 L
.64193 .13276 L
.64306 .13336 L
.64426 .1342 L
.64642 .13622 L
.649 .13952 L
.65134 .14342 L
.65378 .14851 L
.65643 .15536 L
.66124 .17206 L
.68171 .31365 L
.68458 .33592 L
.68731 .35359 L
.68882 .36133 L
.68961 .36476 L
.69046 .36786 L
.69124 .37023 L
.69195 .37194 L
.69333 .37409 L
.69402 .37458 L
.69474 .37468 L
.69603 .37386 L
.69742 .37164 L
.69821 .36981 L
.69894 .36777 L
.70149 .35859 L
.70421 .34627 L
.74559 .20761 L
.75631 .17315 L
.76195 .15825 L
.76794 .14583 L
.77317 .13765 L
.77595 .13421 L
Mistroke
.77893 .13117 L
.78167 .12893 L
.78417 .12731 L
.78669 .12604 L
.78909 .12513 L
.79039 .12474 L
.7918 .1244 L
.79313 .12415 L
.79436 .12399 L
.79546 .1239 L
.79668 .12386 L
.79795 .12389 L
.79914 .12397 L
.80053 .12414 L
.80184 .12437 L
.80431 .12499 L
.80697 .12591 L
.80986 .12717 L
.81472 .12997 L
.81988 .13402 L
.82429 .13852 L
.82916 .14465 L
.83975 .16299 L
.84946 .1868 L
.8608 .21923 L
.86364 .22683 L
.86632 .23323 L
.86894 .23843 L
.87009 .24034 L
.87135 .24214 L
.87243 .24341 L
.87358 .2445 L
.87481 .24534 L
.87595 .24582 L
.87729 .246 L
.87856 .24581 L
.8797 .24533 L
.88094 .24449 L
.8823 .24321 L
.88352 .24173 L
.88627 .23741 L
.8912 .22682 L
.90252 .19715 L
.91293 .17265 L
.92277 .15527 L
.93316 .14219 L
.93856 .13714 L
.94359 .1335 L
.94643 .13184 L
.94911 .13053 L
Mistroke
.9506 .12992 L
.95221 .12937 L
.95292 .12917 L
.95367 .12899 L
.95503 .12874 L
.95623 .12861 L
.95753 .12858 L
.9589 .12868 L
.96017 .1289 L
.96136 .12921 L
.96245 .1296 L
.9637 .13017 L
.96488 .13084 L
.96753 .13285 L
.96998 .13543 L
.97266 .13927 L
.97549 .14474 L
.97777 .1504 L
.98022 .15789 L
.98464 .17563 L
.9899 .20451 L
.9947 .23796 L
1 .27862 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002=ooooo`Oo00008Oooool00ol0003oooooooooo`1I
ooooo`Go0000D_ooool008_ooooo0_l00007ooooo`;o00007oooool00ol0003oooooooooo`1Goooo
o`?o00001?ooool3o`0004oooooo002:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool07?ooool2o`0005Sooooo00?o0000ooooooooool01oooool2o`0002Wooooo1_l0000Nooooo`00
ROooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
9oooool5o`0002Wooooo0_l0000<ooooo`03o`000?oooooooooo02Cooooo0_l00006ooooo`03o`00
0?oooooooooo01_ooooo0028ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0Wooooo`05o`000?ooooooooooooooool00000:Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Jooooo`00R?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool06_ooool008Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01[ooooo001@ooooo`Co0000<oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06Oooool004oooooo0_l00002ooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo00Wooooo1?l0000Hooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0Iooooo`009oooool2o`0002Kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Cooooo`Co00006?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool01oooool2o`0000?ooooo0_l0000Fooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Hooooo`009Ooo
ool2o`000003ooooool0003o000002Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Cooooo`05o`000?ooooooooooooooool000005oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo01Sooooo0_l00006ooooo`;o00001_ooool2o`0001Gooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Sooooo000Tooooo`;o00001?oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0Gooooo`009?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool00_ooool2o`0000_ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05oooool0
01Gooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool03?ooool01OnHV9So410@o`000?lb<S;oc<c<00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool02_ooool5o`00000:ooooool0003oooooonk^k_lb<S;o0000oc8b<_o^k^koooooo`0001?o
oooo00?o0000ooooooooool01?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h4ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00_l0000=ooooo`03o`000?oo
oooooooo00gooooo1Ol00002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool00ol0003ooooo
ooooo`0Cooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Oooooo00Wo0000oooooooo
oooooooooiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo
00?o0000ooooooooool04Oooool3o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;o
k^k^00kooooo000Fooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool01Ol@413o^[Zjoooooomg
MgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool02_ooool03onHV9So8B4Qonk^k_ooooooA4A4ooooool0003oooooogMgMonH
V9SooooooiRHV?mgMgOoooooo`00000Cooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000ooooooooool05oooool3o`00
00oooooo00?o0000ooooooooool03oooool00ol0003oooooo`000002ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool00ol0003oooooooooo`0Booooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHo`000?nHV9SoMgMg01Oooooo00Wo0000oooooooooooooooooa0@4?nj^[[ooooo
ogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo00?o0000ooooooooool04_oo
ool00ol0003oooooo`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool000_ooooo1_l0
0002ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`02ooooo`Ko00001_ooool01Ol0003ooooooooooooooooo410@00?o
oooo00?o410@ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00;ooooo00?o0000ooooool@41000oooool01?l@413o
ooooooooool0000@ooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41001Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool03_ooool00ol0003oooooo`000002ooooo`05oa0@4?ooooooooooooooool@41001Ooo
ool00ol0003oooooooooo`0Cooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@ooooool0003ooooo
oa0@400Hooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo00Gooooo00?o0000ooooooooool04Oooool5o`0000?ooooo00Go410@oooooooo
oooooooooa0@400>ooooo`004oooool01?m4A4CogMgMooooool00004ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo00?oZJVY
oa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0<ooooo`07oiRHV?lQ8B7ok^k^ooooool0003oooooo`000003ooooo`04
o`000?ooooooooooo`00017ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0Eooooo`;o00004_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`00
0005ooooo`03o`000?oooooooooo01Cooooo00?oV9RHob4Q8Oo^k^h00oooool2o`0000;ooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`03ooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo01;ooooo00CoA4A4omgMgOl0003o
00001?ooool01Ol0003ooooooooooooooooo000000kooooo000Cooooo`04omgMgOmEEEGoooooo`00
00Cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02oooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000001Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo00KoMgMgofIVI_oooooo0000
ooooool00003ooooo`05o`000?ooooooooooooooool000004?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooool000004_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
000000;ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo01Gooooo00?o
MgMgofIVI_ooool00_ooool2o`0000;ooooo00?o0000ooooooooool05oooool01ol0003ooooooooo
oooooooo410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool04_ooool01?oMgMgoEEEEo`000?l00004ooooo`05o`000?ooooooooooooooool000003_oo
ool001Cooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00;ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go
410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
3Oooool01Ol0003oooooo`000?oooooo410@00?ooooo00Go410@ooooooooooooooooo`00000@oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@00Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`02o`0001;ooooo00?o0000
ooooooooool03Oooool2o`0000?ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oo
oooooooo01Kooooo00Ko0000oooooooooooooooooa0@4?l00002ooooo`03oa0@4?oooooooooo01Oo
oooo00?o0000ooooooooool00_ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41001Oooool00ol0003oooooooooo`0Dooooo`03ogMgMol0003o000000Cooooo00Go410@oooo
oooooooooooooa0@400>ooooo`005?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00Go410@
oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Wooooo00Ko0000okZj^_ooooooV9RHoa0@4?l00002oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o
0000ooooooooool04oooool01?l0003oooooooooool0000Cooooo`03o`000?oooooooooo00gooooo
0_l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0Booooo`05
o`000?nj^[[ooooooiRHV?l@41000oooool01Ol0003oV9RHoooooonHV9SoMgMg01Wooooo00Oo0000
ooooool@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03
o`000?oooooooooo01Cooooo00?ok^k^o`000?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00kooooo000Eooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool01_ooool01OnYZJWo410@o`000?l@413o
ZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02Oooool01_nHV9So410@o`000?lQ8B7oc<c<o`0000;ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP04ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01_ooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`0A
ooooo`05o`000?ooooooooooooooool000004oooool00ol0003oooooooooo`0;ooooo`04oeEEEOmV
IVKo0000o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo017o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05o`000?lb<S;o0000oc8b<_o^k^h06_ooool0
1_l0003oZJVYoa0@4?l0003o410@ojVYZ@?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03
o`000?oooooooooo01Gooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00kooooo000Rooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool04Oooool01Ol0003o
oooooooooooooooo000001?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05Oooool0027ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0Eooooo`008Oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo01Gooooo000Qooooo`03o`000?oooooooooo013ooooo0_l0000Eooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Eooooo`008Oooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Cooooo000Foooooooo0000@?l0000Coooo
o`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000ooooool0
00001Oooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`;o
00001_ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000oooooooo
ool01Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`;o00001oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000Cooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
000000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
000000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
000000Oooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`;o00001_ooool0
0ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003oooooo`000005ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
000000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
000000Oooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool01?ooool2o`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00004oooool0023ooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Dooooo`008?ooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo01Cooooo000Oooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05?oo
ool001oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Cooooo`007oooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo013ooooo00Go0000ooooooooooooooooo`00000S
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo01?ooooo000Oooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool04Oooool4o`0002Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool04oooool001oooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Booooo`;o00009Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo0_l0000Dooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01?ooooo000Oooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Cooooo`007ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool09ooo
ool2o`0000Cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Cooooo`007_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:?ooool0
1Ol0003ooooooooooooooooo000002;ooooo00?o0000ooooooooool04oooool001kooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02Wooooo0ol0000S
ooooo`03o`000?oooooooooo01?ooooo000Nooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo01?ooooo000Nooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Aooooo`03
o`000?oooooooooo01;ooooo000Nooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo01;ooooo000Nooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Wooooo0_l0000Eooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool04_oo
ool001kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo05;ooooo00?o0000ooooooooool04_ooool001gooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0looooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool04_ooool001go
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05;o
oooo00?o0000ooooooooool04_ooool001gooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0mooooo`04o`000?ooooooooooo`0000gooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`1Dooooo`03o`000?oooooooooo017ooooo000Mooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0?Oooool01?l0003oooooooooool0000=ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0Aooooo`005_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0?_ooool2o`0000kooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo017ooooo
000Fooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`1>ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0JOooool001Kooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04kooooo0_l0000F
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo06Wooooo000Fooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0JOooool001Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo04oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Zooooo`00
5_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
Coooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo06[ooooo000Fooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1?ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0J_ooool001Kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`1Zooooo`005_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0A?ooool5o`0000Kooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`1[ooooo`005oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0A?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`1[ooooo`005oooool01Ol0003ooooooooooooooooo0000
02;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0AOooool00onHV9So8B4Qonk^kP07ooooo`?o00005_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`1[ooooo`005oooool01Ol0003ooooooooooooooooo000002?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0A_ooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0K?ooool001Oooooo00Go0000ooooooooooooooooo`00000Sooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
04Oooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
06cooooo000Hooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0B?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0K?ooool001So
oooo00Co0000oooooooooooo00008oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`14ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo06cooooo000Hoooo
o`03o`000?oooooo000002Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0A?ooool01OnHV9So410@o`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1]ooooo`006Oooool2o`00
02Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
06gooooo000oooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`1]ooooo`00?oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1@ooooo`;o00006?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1^ooooo`00@?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo01Sooooo00Go
0000ooooooooooooooooo`00000Kooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
K_ooool0043ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Hooooo`05o`000?oo
ooooooooooooool000006oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06kooooo
0010ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooo
oooooooo000001_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1_ooooo`00@?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo01Sooooo00Co0000oooooooooooo0000
7Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06oooooo0010ooooo`05o`000?oo
ooooooooooooool000005_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo053ooooo
00?o0000ooooooooool06?ooool01?l0003oooooooooool0000Mooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0Koooool0047ooooo00Co0000oooooooooooo00005_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool06?ooool01?l0003o
ooooooooool0000Mooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Koooool0047o
oooo00Co0000oooooooooooo00005_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
053ooooo00?o0000ooooooooool06?ooool01?l0003oooooooooool0000Mooooo`05o`000?oooooo
ooooooooool00000L_ooool0047ooooo00Co0000oooooooooooo00005_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool06Oooool2o`0001kooooo00Go
0000ooooooooooooooooo`00001booooo`00@Oooool01?l0003oooooooooool0000Fooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0D?ooool2o`0001[ooooo0_l0000Nooooo`05o`00
0?ooooooooooooooool00000L_ooool004;ooooo00?o0000ooooool000005_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0>Oooool01?l0003ooooo
ooooool0001cooooo`00@_ooool2o`0001Oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1@ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooool00000Loooool004;ooooo0_l0
000Gooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0DOooool00ol0003ooooooooo
o`0jooooo`03o`000?oooooo000007?ooooo001Kooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0DOooool00ol0003oooooooooo`0jooooo`;o0000M?ooool005_ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo0;3ooooo001Kooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`2`ooooo`00
Foooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0
/?ooool005cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Aooooo`;o0000/Ooo
ool005cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooo
oooo0;3ooooo001Looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0DOooool00ol0
003oooooooooo`2`ooooo`00G?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo057o
oooo00?o0000ooooooooool0/?ooool005cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`1Aooooo`03o`000?oooooooooo0;3ooooo001Looooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0B?ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0/?oo
ool005cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0/?ooool005cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`16ooooo`Go00001_ooool00ol0003oooooooooo`2`ooooo`00G?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo04Kooooo00CoA4A4omgMgOoooooo00001oooool3o`00
0;3ooooo001Looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0A_ooool01?oMgMgo
EEEEooooool00007ooooo`03o`000?oooooooooo0;3ooooo001Looooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0Aoooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo0;3o
oooo001Looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Aoooool00oo^k^koA4A4
o`000007ooooo`03o`000?oooooooooo0;3ooooo001Looooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0B?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo001L
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`2`
ooooo`00GOooool01?l0003oooooooooool0001Dooooo`03o`000?oooooooooo0;3ooooo001Moooo
o`04o`000?ooooooooooo`0005Cooooo00?o0000ooooooooool0/?ooool005gooooo00Co0000oooo
oooooooo0000E?ooool2o`000;7ooooo001Mooooo`04o`000?ooooooooooo`0005Cooooo00?o0000
ooooooooool0/?ooool005gooooo00Co0000oooooooooooo0000E?ooool00ol0003oooooooooo`2`
ooooo`00GOooool01?l0003oooooooooool0001Dooooo`03o`000?oooooooooo0;3ooooo001Moooo
o`04o`000?ooooooooooo`0005Cooooo00?o0000ooooooooool0/?ooool005gooooo00Co0000oooo
oooooooo0000E?ooool00ol0003oooooooooo`2`ooooo`00G_ooool00ol0003oooooo`00001Doooo
o`03o`000?oooooooooo0;3ooooo001Nooooo`;o0000EOooool00ol0003oooooooooo`2`ooooo`00
G_ooool2o`0005Gooooo0_l0002aooooo`00G_ooool2o`0005Gooooo00?o0000ooooooooool0/?oo
ool005kooooo0_l0001Eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo00Gok^k^oc8b<_l0003o410@olc<c006oooo
o`03o`000?oooooooooo0;3ooooo002Zooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0
003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool0/?ooool00:[ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000/?ooool00:[o
oooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03
oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0/?ooool00:[ooooo00?ogMgMoa0@4?nHV9P0
2?ooool00ol0003oooooooooo`2`ooooo`00Zoooool01?o<c<coA4A4o`000?l@4106ooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002Zooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_oo
ool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05oc8b<_nH
V9SooooooiRHV?lb<S801_ooool3o`000;3ooooo002Zooooo`05olc<c?l0003o0000o`000?o<c<`0
^Oooool00:[ooooo00Go410@okZj^_oooooo^[Zjoa0@402iooooo`00Z_ooool01Ol0003o^[Zjoooo
oonj^[[o00000;Wooooo002Zooooo`05ojVYZOl@413o0000oa0@4?nYZJT0^Oooool00?ooooooJOoo
ool00:oooooo00?o0000okZj^_ooool0]_ooool00:oooooo0_lb<S:gooooo`00P?ooool2o`000006
oa0@4?oooooooooooa0@4?l0003o410@6?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003o
A4A4okZj^P0Iooooo`Co000000So410@ooooooooooooV9RHoa0@4?l0003o<S8bolc<c0Gooooo0_l0
00000ol@413oooooooooo`1fooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Oooooo1_l0000=ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<oooo
o`03o`000?oooooooooo00;ooooo00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooo
oooo07Oooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06oooool01?l0
003oooooooooool@4103ooooo`03oa0@4?oooooooooo013ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`06ooooo`04o`000?ooooooooooooooo`Go0000N?ooool0087ooooo00Ko0000
oooooom4A4CoA4A4ooooool00009ooooo`Ko00003Oooool01OmgMgOo<S8boooooooooooo000000?o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`Ko00003?ooool00ol0003o
ooooooooo`05ooooo`03ojVYZOl@413ooooo00;ooooo00CoA4A4omgMgOoooooo0000NOooool0087o
oooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Iooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_oo
ool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`04ooooo`03oa0@4?l0003o^[Zj00?ooooo00CogMgMoeEEEOoooooo0000NOooool0087ooooo
00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Iooooo`03o`000?oooooooooo00Cooooo00Go410@oooo
oooooooooooooa0@400@ooooo`03oa0@4?l0003o000000?o00007?ooool00ol0003oooooooooo`05
ooooo`03okZj^_lQ8B7ooooo00?ooooo00?oMgMgolc<c?l00000NOooool0087ooooo00Ko0000oc8b
<_oooooooooooc8b<_l0000Iooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0Booooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413oV9RH
oooooonj^[[o000000Cooooo00?ok^k^odA4A?l00000NOooool0083ooooo00?o410@o`000?n7QhL0
0_ooool00on7QhOo0000oa0@400Hooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;o
oooo00?o0000ooooooooool06oooool00omEEEGoIVIVo`000004ooooo`05ojVYZOl@413o0000oa0@
4?nYZJT01Oooool00omgMgOo0000ooooo`1hooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(136) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30285 m
.01975 .24501 L
.02492 .22682 L
.02746 .21976 L
.02981 .21442 L
.03251 .20964 L
.0339 .20769 L
.03544 .20591 L
.03793 .2037 L
.04057 .20203 L
.04329 .20075 L
.04621 .19959 L
.0515 .19735 L
.05422 .19586 L
.05682 .19411 L
.06168 .1896 L
.06742 .18225 L
.07274 .17433 L
.07854 .16564 L
.08481 .15687 L
.08762 .15346 L
.09059 .15047 L
.09312 .14855 L
.09456 .14773 L
.0959 .14716 L
.09726 .14678 L
.09854 .14659 L
.0997 .14659 L
.10095 .14676 L
.10231 .14719 L
.103 .14751 L
.10376 .14794 L
.1051 .14896 L
.10636 .15024 L
.10875 .15364 L
.10995 .15591 L
.11126 .15886 L
.11359 .16546 L
.11576 .17332 L
.12066 .1982 L
.1234 .21707 L
.12589 .23759 L
.13568 .33954 L
.13806 .36249 L
.13937 .37322 L
.14061 .38173 L
.14131 .38571 L
.14208 .38933 L
.14342 .39371 L
.14478 .3955 L
Mistroke
.14604 .39468 L
.14675 .39318 L
.14753 .39072 L
.14826 .38763 L
.14893 .38418 L
.15154 .36561 L
.15439 .33843 L
.1574 .30579 L
.16288 .24784 L
.16788 .20593 L
.17033 .18996 L
.173 .1758 L
.17531 .16593 L
.17785 .15725 L
.18055 .15019 L
.18193 .14731 L
.18341 .14471 L
.18479 .14269 L
.18605 .14116 L
.18726 .13996 L
.18854 .13895 L
.18976 .13821 L
.19086 .13772 L
.19198 .1374 L
.19303 .13725 L
.19425 .13724 L
.19538 .13741 L
.19662 .13777 L
.19793 .13837 L
.1991 .13909 L
.20036 .14008 L
.20263 .14248 L
.20534 .14652 L
.2078 .15154 L
.21019 .15788 L
.21284 .16688 L
.2156 .17891 L
.21819 .19309 L
.22282 .22659 L
.22782 .27575 L
.23335 .34139 L
.23637 .37621 L
.23784 .39123 L
.23918 .40316 L
.24033 .41184 L
.24158 .41934 L
.24291 .42488 L
.24416 .42773 L
.24553 .42814 L
.24623 .42727 L
Mistroke
.24699 .4255 L
.24834 .42041 L
.2496 .41357 L
.29034 .25304 L
.31254 .19003 L
.32276 .15796 L
.32847 .14523 L
.33116 .14043 L
.33364 .13665 L
.33879 .13066 L
.3415 .12843 L
.34436 .12664 L
.34685 .12549 L
.34917 .12469 L
.35051 .12435 L
.35172 .12411 L
.3524 .12401 L
.35313 .12392 L
.35445 .12382 L
.35565 .12381 L
.35677 .12386 L
.358 .12398 L
.35932 .12419 L
.36063 .12448 L
.36202 .12485 L
.36449 .1257 L
.36892 .12773 L
.37377 .13072 L
.37932 .13536 L
.38457 .14097 L
.39437 .1546 L
.40493 .17471 L
.41638 .20194 L
.42717 .22979 L
.43244 .24188 L
.43726 .25087 L
.43987 .25458 L
.44234 .25718 L
.44369 .25819 L
.44495 .25884 L
.44632 .25925 L
.44709 .25933 L
.44779 .25931 L
.44852 .2592 L
.44928 .25898 L
.45066 .25835 L
.45142 .25785 L
.45213 .2573 L
.45375 .25576 L
.45646 .25228 L
Mistroke
.45936 .24744 L
.48022 .19507 L
.49121 .16898 L
.49723 .15742 L
.50287 .14838 L
.50828 .14113 L
.51323 .13575 L
.51874 .1312 L
.52181 .12922 L
.52466 .12771 L
.52704 .12671 L
.52838 .12628 L
.52959 .12598 L
.53092 .12575 L
.53167 .12567 L
.53236 .12563 L
.53363 .12565 L
.53497 .12579 L
.53614 .12604 L
.53739 .12641 L
.53857 .12689 L
.53965 .12743 L
.54091 .1282 L
.54228 .12923 L
.54478 .13169 L
.54723 .13498 L
.54987 .13978 L
.55236 .14576 L
.55464 .1527 L
.55995 .17527 L
.56261 .19058 L
.56553 .21072 L
.57148 .262 L
.57709 .3152 L
.57953 .33528 L
.58087 .34447 L
.58213 .3516 L
.58348 .35747 L
.5842 .35975 L
.58497 .36153 L
.58634 .3629 L
.58759 .36215 L
.58886 .35945 L
.59021 .35455 L
.59148 .34816 L
.59264 .34105 L
.59814 .2957 L
.60337 .24849 L
.60817 .21224 L
.61082 .19661 L
Mistroke
.61362 .18352 L
.61642 .17363 L
.61802 .16935 L
.6195 .16614 L
.62089 .1638 L
.6222 .16213 L
.62337 .16104 L
.62465 .16029 L
.62531 .16006 L
.62604 .15994 L
.6268 .15994 L
.62752 .16006 L
.62879 .16054 L
.63016 .16141 L
.63149 .16257 L
.63269 .16387 L
.63538 .16753 L
.64023 .17617 L
.65124 .19975 L
.6539 .20476 L
.65671 .20912 L
.65819 .21094 L
.6598 .21252 L
.66051 .21308 L
.66127 .21358 L
.66265 .21424 L
.66403 .21458 L
.66481 .21463 L
.66553 .21459 L
.66686 .21431 L
.66753 .21408 L
.66827 .21374 L
.66954 .21299 L
.67092 .21197 L
.6734 .20965 L
.67825 .20425 L
.68091 .20154 L
.68222 .20048 L
.68343 .19973 L
.68412 .19943 L
.68486 .19922 L
.6856 .19913 L
.68641 .1992 L
.68708 .19939 L
.68781 .19976 L
.68912 .20084 L
.68979 .20163 L
.69053 .20269 L
.69188 .20517 L
.69319 .20833 L
Mistroke
.69441 .21197 L
.69731 .22368 L
.70003 .2391 L
.70248 .25694 L
.70513 .28048 L
.71104 .344 L
.71392 .3748 L
.71518 .38672 L
.71655 .39802 L
.71784 .40667 L
.71903 .41269 L
.72017 .41649 L
.72137 .41828 L
.72264 .4176 L
.72383 .41457 L
.72513 .40867 L
.72587 .40424 L
.72654 .39952 L
.72909 .37665 L
.73188 .34522 L
.73749 .27678 L
.74304 .22043 L
.74614 .19659 L
.74895 .17939 L
.75159 .16663 L
.75444 .1559 L
.75713 .14828 L
.75961 .14308 L
.76218 .13918 L
.76452 .13663 L
.76582 .13555 L
.76723 .13458 L
.76858 .13383 L
.7698 .13328 L
.77103 .13285 L
.77219 .13254 L
.77342 .13231 L
.77474 .13219 L
.7759 .13217 L
.77713 .13225 L
.77817 .13239 L
.77932 .13261 L
.78078 .13298 L
.78216 .13341 L
.78474 .13436 L
.79054 .13684 L
.801 .14282 L
.81116 .15044 L
.81629 .1552 L
.82195 .16194 L
Mistroke
.82676 .1691 L
.83194 .17857 L
.8413 .20163 L
.8519 .23219 L
.8548 .23944 L
.8564 .24288 L
.8579 .24569 L
.85931 .24787 L
.86004 .24883 L
.86082 .24968 L
.8622 .25079 L
.86348 .25133 L
.86479 .25138 L
.86598 .25097 L
.86736 .24996 L
.86867 .24848 L
.86988 .24669 L
.871 .24468 L
.87353 .23903 L
.87888 .22324 L
.88456 .2035 L
.89439 .1708 L
.89955 .15706 L
.90499 .14546 L
.90977 .1374 L
.915 .13069 L
.91975 .12629 L
.92418 .12332 L
.92693 .12192 L
.92947 .12093 L
.9308 .12052 L
.93226 .12018 L
.93299 .12005 L
.93378 .11994 L
.93453 .11987 L
.93521 .11983 L
.93654 .11981 L
.93777 .11989 L
.93912 .12005 L
.93987 .12018 L
.94056 .12033 L
.94182 .12065 L
.94317 .1211 L
.94564 .12215 L
.948 .1235 L
.95058 .12545 L
.95328 .12811 L
.9558 .13127 L
.96031 .13878 L
.96515 .14996 L
Mistroke
.96961 .16378 L
.97373 .18013 L
.98305 .22923 L
1 .30285 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo08Kooooo1Ol0000Uooooo`00QOooool5o`0002_ooooo00?o0000
ooooooooool0Q?ooool2o`0000Gooooo0_l0000Sooooo`00Poooool2o`0000Gooooo0ol0000Xoooo
o`03o`000?oooooooooo00Gooooo1_l0001gooooo`;o00002?ooool00ol0003oooooooooo`0Qoooo
o`00P_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Gooooo0_l00005ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo023ooooo0021ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`02ooooo`;o00001oooool00ol0003oooooooooo`14ooooo`Ko0000
:?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01oooooo001Cooooo`;o0000:ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Cooooo00Go0000oooooooooooooooo
o`00000:ooooo`03o`000?oooooooooo04;ooooo0_l00005ooooo`?o00009?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo01oooooo001Aooooo`;o000000?oooooo`000?l00000:Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02?ooooo00Go0000oooooooooooooooo
o`00000;ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool02?ooool2o`0002;ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Nooooo`00DOooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0Rooooo`04o`000?ooooooooooo`0000cooooo00?o0000ooooooooool0@?ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0Nooooo`00=Oooool2o`0001Wooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08_ooool00ol0003oooooo`00
000>ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07Oooool003?ooooo0_l00000
0ooooooo0000o`00000Hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo027ooooo0_l0000?ooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool07?ooool003?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo023ooooo0_l0000?ooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool03_ooool2o`0001_ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Looooo`00<_ooool00ol0003oooooooooo`03ooooo`;o00005Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Oooooo`;o00003oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01co
oooo000aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0Nooooo`;o00004?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01_ooooo
000`ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`0Mooooo`;o00004Oooool00ol0003oooooooooo`0Booooo`?o00009oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Kooooo`005Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00oo
oooo00?o0000ooooooooool02?ooool01Ol0003o410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool5
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03o`000?oooooooooo00cooooo1?l0
00001Ol@413oooooooooooo^k^ko<S8b00;o000000?ok^k^ooooooooool06_ooool00ol0003ooooo
o`00000Aooooo`03o`000?oooooooooo00gooooo1Ol00002ooooo`05onk^k_l0003o0000oc8b<_o^
k^h06_ooool5o`0000?ooooo00Go0000oc8b<_l0003o<S8bonk^kP0Aooooo`03o`000?oooooooooo
00Oooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`07onk^k_lb<S;o0000oc8b<_o^k^kooooo
o`00000Fooooo`03o`000?oooooooooo00;ooooo0_l000002Ol@413oooooooooooooooook^k^oc8b
<_l0003o<S8bonk^kP0>ooooo`005_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03oooool00ol0003oooooooooo`08ooooo`05o`000?nj^[[oooooogMgMolb<S800ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`06ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
o`000?mgMgL07?ooool00ol0003oooooo`00000Aooooo`03o`000?oooooooooo00oooooo00?o0000
ooooool000000_ooool01OmgMgOoV9RHo`000?nHV9SoMgMg01[ooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A003ooooo`05o`000?nHV9SooooooiRHV?mgMgL04_ooool00ol0003oooooooooo`06ooooo`05
oa0@4?nj^[[oooooogMgMolb<S800oooool01omgMgOoV9RHoooooonHV9SoMgMgooooool000005_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0>ooooo`002oooool6o`0000;ooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@4100
3_ooool01?l0003oooooooooooooool6o`0000?ooooo00Co0000oooooooooooo00000oooool01Ol@
413ooooooooooooooooo410@00Oooooo00?o0000ooooooooool02?ooool7o`0000?ooooo00?oV9RH
ob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01?oo
ool6o`0000Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo000001_ooooo
00Co0000oooooooooooo00004Oooool00ol0003oooooooooo`0?ooooo`;o00000oooool01Ol@413o
ooooo`000?oooooo410@01_ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol0003ooooooooooooooooo
410@01?ooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o
410@o`000?ooool05oooool00ol0003oooooo`000004o`0000?ooooo00Go410@oooooooooooooooo
oa0@400>ooooo`004oooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool0
00003Oooool00ol0003oooooooooo`0;ooooo`04o`000?ooooooZJVYoa0@40?ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool0
0onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0_l0000Jooooo`04o`00
0?ooooooooooo`0001;ooooo00?o0000ooooooooool03_ooool2o`0000?ooooo00?o0000oooooooo
ool00_l0000Looooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000Coooo
o`03o`000?oooooooooo00Sooooo00?oZJVYoa0@4?ooool00_ooool01?l0003oooooooooooooool2
o`0001Sooooo00Ko0000oooooom4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool0
00003_ooool001?ooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo0000
00gooooo00?o0000ooooooooool02oooool01?l0003o410@o`000?nj^[X3ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o
MgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`;o00006Oooool01Ol0003o
oooooooooooooooo000001;ooooo00?o0000ooooooooool03_ooool2o`0000?ooooo00Go0000oooo
ooooooooooooo`00000Mooooo`04ogMgMomVIVKoooooooooo`;o00000oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo00Kooooo00?o410@o`000?nj^[X00oooool01?l0003ooooooooo
ooooool2o`0001Sooooo00Ko0000oooooooMgMgoEEEEooooool00004ooooo`05o`000?oooooooooo
ooooool000003_ooool001Cooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool03?ooool01?l0003ooooookZj^_lQ8B43ooooo`05oa0@4?oo
ooooooooooooool@41001_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Wooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`02ooooo`07oa0@4?ooooooooooooooool@413oooooo`00000H
ooooo`04o`000?ooooooooooooooo`;o00004Oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00;ooooo00Go410@ooooooooooooooooo`00000Nooooo`05o`000?ooooooooooo`000?l@
41000oooool00ol@413oooooooooo`0Cooooo`03o`000?oooooooooo00Kooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo000001[ooooo00Go0000oooooomgMgOoc<c<o`000004
ooooo`05oa0@4?ooooooooooooooool@41003_ooool001Cooooo00?ok^k^odA4A?l000001?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000ooooooooool03?ooool01Ol@413o0000oooo
oonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool01Oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool0
1omgMgOoV9RHoooooonHV9SoMgMgooooool000006?ooool01Ol0003ooooooooooooooooo000001;o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`06ogMgMonHV9SooooooiRH
V?mgMgOo00006Oooool01Ol0003o^[ZjoooooonHV9So410@00;ooooo00Ko0000ogMgMonHV9Sooooo
oiRHV?mgMgLEooooo`03o`000?oooooooooo00?ooooo00Go410@oiRHV?oooooo^[Zjo`000003oooo
o`05ogMgMonHV9SooooooiRHV?l000006_ooool01Ol0003oooooonk^k_m4A4Co000000Cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0>ooooo`005Oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02_ooool00ol0003oooooooooo`0=ooooo`05ojVYZOl0003o0000oa0@4?nY
ZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`05ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00[ooooo00?o0000ooooooooool03oooool00omEEEGoIVIVo`000004ooooo`07onk^k_lb
<S;o0000oc8b<_o^k^koooooo`00000Gooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0;ooooo`03oeEEEOmVIVKo000000Cooooo00Kok^k^oc8b<_l0
003o<S8bonk^k_l0000Iooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00_ooool01_l0003ok^k^oc8b
<_l0003o<S8bonk^kQKooooo00?o0000ooooooooool00_ooool01OnYZJWo410@o`000?l@413oZJVY
00?ooooo00Gok^k^oc8b<_l0003o<S8bo`00000Jooooo`05o`000?ooooooooooogMgMol000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Yooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`00:Oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06?ooool002Oooooo0_l0000Coooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06?ooool002Cooooo0ol0000Eooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Oooooo0ol0000Aooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Sooooo000Sooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool01_ooool2o`000003ooooool0003o0000013ooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool06?ooool001Koooooool00010o`0001?ooooo000Fooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00oooool2o`0000Oooooo00?o0000ooooooooool00oooool0
0ol0003oooooo`000007ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`05ooooo`;o00001_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00007ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooo`000004ooooo`;o00001?ooool01?l0003oooooooooool00007ooooo`03o`00
0?oooooooooo00?ooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo017ooooo000Fooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`04ooooo`;o0000
1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool00000
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool0
00001Oooool00ol0003oooooooooo`05ooooo`04o`000?oooooo0000o`0000;ooooo00?o0000oooo
ool000001Oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ool000001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool2o`0000Oooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005
ooooo`03o`000?oooooooooo017ooooo000Oooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00kooooo1?l00007oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool05oooool001oooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Oooooo000Nooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Gooooo`007_oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool05_oo
ool001kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo01Kooooo000Nooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0Fooooo`007Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`;o00005?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`0Fooooo`007Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool05_ooool001gooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo01Gooooo000Looooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`0Eooooo`007?ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08oooool01Ol0003ooooooooooooooooo
000002Cooooo00?o0000ooooooooool05Oooool001cooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo02?ooooo0_l000000ooooooo0000ooooo`0Toooo
o`03o`000?oooooooooo01Gooooo000Kooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Tooooo`;o00009_ooool00ol0003oooooooooo`0Eooooo`00
6oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02gooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0COooool00ol0003o
ooooooooo`0Dooooo`006oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02kooooo
1?l0000>ooooo`;o00005Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo01Cooooo
000Jooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0@Oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool05?ooool001[ooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0C_ooool00ol0003oooooooooo`0Dooooo`006_ooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo047ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1?oooo
o`03o`000?oooooooooo01?ooooo000Iooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0@Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04oooooo00?o0000oooooooo
ool04oooool001Wooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`12ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Cooooo`006Ooo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo01?ooooo000Hooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo04oooooo00?o0000ooooooooool04oooool001Sooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`12ooooo`;o00005Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo
01;ooooo000Hooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0@oooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool04_ooool001Oooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Booooo`005oooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1@ooooo`03o`000?oooooooooo01;ooooo000Gooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0@oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo053ooooo00?o0000
ooooooooool04_ooool001Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`14oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Poooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0Aoooo
o`005_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Wooooo1Ol00006ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0Aooooo`00
@?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo06Gooooo0010ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03[ooooo
00?oV9RHob4Q8Oo^k^h01oooool3o`0001Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0IOooool0043ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0??ooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0IOooool0043ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0?Oooool00omgMgOoIVIVooooo`05
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0I_ooool0043ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0?_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0I_ooool0043ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0>_ooool01Ol0003o^[ZjoooooonHV9So410@
00Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Vooooo`00@Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0kooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo06Kooooo0011ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04Kooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`1Vooooo`00@Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`16ooooo`03o`00
0?oooooooooo01Kooooo00Go0000ooooooooooooooooo`00000Uooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0I_ooool0047ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Aoooool2o`0001Oooooo
00Go0000ooooooooooooooooo`00000Uooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0I_ooool0047ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Fooooo`05o`00
0?ooooooooooooooool000009Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06Ko
oooo0011ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool05oooool01?l0003ooooo
ooooool0000Uooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0I_ooool0047ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Gooooo`04o`000?ooooooooooo`0002Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Vooooo`00@Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`18ooooo`03o`000?oooooooooo01Oooooo00Co0000oooooooooooo00009Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo06Kooooo0011ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Sooooo
00?o0000ooooooooool05oooool01?l0003oooooooooool0000Uooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0I_ooool004;ooooo00Go0000ooooooooooooooooo`00000Iooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Gooooo`04
o`000?ooooooooooo`0002Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Voooo
o`00@_ooool01Ol0003ooooooooooooooooo000001Wooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`18ooooo`03o`000?oooooooooo01Oooooo00Co0000oooooooooooo00009Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo06Kooooo0012ooooo`05o`000?oooooooooo
ooooool000006Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Wooooo00?o0000
ooooooooool05oooool3o`0002Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1V
ooooo`00@_ooool01Ol0003ooooooooooooooooo000001[ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`19ooooo`;o00006Oooool2o`0002Oooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1Vooooo`00@_ooool01Ol0003ooooooooooooooooo000001[ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo047ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Wooooo`00@_ooool01Ol0003ooooooooooooooooo
000001[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`19ooooo`03o`000?oooooo
oooo047ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Wooooo`00@_ooool01Ol0
003ooooooooooooooooo000001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1:
ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1W
ooooo`00@_ooool01Ol0003ooooooooooooooooo000001[ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1:ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1Wooooo`00@_ooool01?l0003oooooooooool0000Kooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0Ioooool004;ooooo00Co0000oooooooooooo00006oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0@Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo06Oooooo0012ooooo`04o`000?oooooooooo
o`0001_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooo
oooo047ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Wooooo`00@oooool00ol0
003oooooo`00000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Boooool2o`00
04;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Wooooo`00@oooool00ol0003o
ooooo`00000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Boooool00ol0003o
ooooooooo`11ooooo`05o`000?ooooooooooooooool00000J_ooool004?ooooo0_l0000Looooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`12ooooo`04
o`000?ooooooooooo`0006[ooooo0014ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo04;ooooo00Co0000oooooooo
oooo0000J_ooool006;ooooo00Go0000ooooooooooooooooo`00001>ooooo`03o`000?oooooooooo
04;ooooo00Co0000oooooooooooo0000J_ooool006;ooooo00Go0000ooooooooooooooooo`000015
ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`12ooooo`04o`000?oooooo
ooooo`0006[ooooo001Rooooo`05o`000?ooooooooooooooool00000A_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo04;ooooo00Co0000oooooooooooo0000J_ooool006;ooooo00Co
0000oooooooooooo0000A?ooool5o`0000Kooooo00?o0000ooooooooool0@_ooool01?l0003ooooo
ooooool0001Zooooo`00H_ooool01?l0003oooooooooool00014ooooo`04odA4A?oMgMgoooooo`00
00Oooooo0ol00013ooooo`03o`000?oooooo000006[ooooo001Rooooo`04o`000?ooooooooooo`00
04Cooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`13ooooo`;o0000Joooool0
06?ooooo00?o0000ooooool00000AOooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo
04?ooooo0_l0001[ooooo`00Hoooool00ol0003oooooo`000015ooooo`03onk^k_m4A4Co000000Oo
oooo00?o0000ooooooooool0/?ooool006?ooooo0_l00017ooooo`03ogMgMol0003ooooo00Kooooo
00?o0000ooooooooool0/?ooool006?ooooo0_l0001@ooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo
002Zooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`000;3ooooo002Zooooo`05o`000?mE
EEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool00omEEEGoQhN7oooo
o`08ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03omgMgOl@413oV9RH00Sooooo00?o0000
ooooooooool0/?ooool00:_ooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o
0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Oo<
c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go8B4QoiRH
V?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Olb<S;oV9RHoooooonHV9So
<S8b00Kooooo0ol0002`ooooo`00Z_ooool01Oo<c<co0000o`000?l0003oc<c<0;Wooooo002Zoooo
o`05oa0@4?nj^[[ooooookZj^_l@4100^Oooool00:[ooooo00Go0000okZj^_oooooo^[Zjo`00002i
ooooo`00Z_ooool01OnYZJWo410@o`000?l@413oZJVY0;Wooooo003oooooofWooooo002_ooooo`03
o`000?nj^[[ooooo0;Kooooo002_ooooo`;o<S8b]oooool0083ooooo0_l000001_l@413ooooooooo
ool@413o0000oa0@41Sooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06Ooo
ool4o`000008oa0@4?oooooooooooiRHV?l@413o0000oc8b<_o<c<`3ooooo`05onk^k_lb<S;o0000
oa0@4?o<c<`0N?ooool0087ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07oooo
o`Ko00003Oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03olc<
c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003o
ooooooooo`02ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmEEEGoMgMgoooooonHV9So
8B4Q07Sooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06oooool01?l0
003oooooooooool@4103ooooo`03oa0@4?oooooooooo013ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`1fooooo`00POooool01_l0003oooooodA4A?m4A4Coooooo`0000Wooooo1_l0000=ooooo`05ogMg
Molb<S;oooooooooool000000oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_o
oooo1_l0000<ooooo`03o`000?oooooooooo00Gooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003o
V9RHoooooonHV9So8B4Q07Sooooo0021ooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo00006Oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool01?ooool00ol@413o0000okZj^P03ooooo`05o`00
0?mEEEGo0000oa0@4?o<c<`0N?ooool0087ooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Ioooo
o`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400@ooooo`03oa0@4?l0003o
000000?o00007?ooool00ol0003oooooooooo`05ooooo`03okZj^_lQ8B7ooooo00;ooooo00?oEEEE
ohN7Qoooool0N_ooool0087ooooo00Ko0000oc8b<_oooooooooooc8b<_l0000Iooooo`03o`000?oo
oooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Booooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool00_ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00?ogMgMoa0@4?nH
V9P0N_ooool0083ooooo00?o410@o`000?n7QhL00_ooool00on7QhOo0000oa0@400Hooooo`Co0000
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo00?o0000ooooooooool06oooool00omEEEGo
IVIVo`000004ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01?ooool01?o<c<coA4A4o`000?l@411h
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(138) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .26436 m
.04057 .20716 L
.05077 .17438 L
.05648 .16081 L
.06168 .15133 L
.06463 .14696 L
.06784 .14296 L
.07066 .14003 L
.07365 .13747 L
.07641 .13557 L
.07945 .13388 L
.08201 .13272 L
.08481 .13171 L
.08624 .13129 L
.08758 .13097 L
.08885 .13073 L
.09021 .13055 L
.09154 .13046 L
.0928 .13045 L
.09392 .13051 L
.09514 .13065 L
.09649 .13089 L
.09725 .13108 L
.09796 .13128 L
.09952 .13182 L
.10093 .13244 L
.10351 .13395 L
.10626 .13623 L
.10883 .13922 L
.11121 .14295 L
.11381 .1484 L
.11658 .15609 L
.11898 .16462 L
.12123 .17448 L
.12389 .18881 L
.12636 .20513 L
.13129 .24722 L
.13668 .30525 L
.13961 .33763 L
.14238 .36464 L
.14358 .37445 L
.14486 .38309 L
.14553 .38681 L
.14626 .39021 L
.14755 .39436 L
.14877 .39602 L
.14989 .39555 L
.15118 .39268 L
.1524 .38773 L
.15353 .38137 L
Mistroke
.15458 .37409 L
.15695 .35349 L
.16698 .24679 L
.17233 .20391 L
.17534 .18657 L
.17811 .17447 L
.18054 .16652 L
.18191 .16303 L
.1832 .16041 L
.18456 .15826 L
.18579 .15684 L
.18648 .15626 L
.18722 .1558 L
.18857 .15535 L
.18978 .15538 L
.19092 .15573 L
.19216 .15645 L
.1935 .1576 L
.19483 .15908 L
.19623 .16099 L
.19873 .16524 L
.20322 .17545 L
.20812 .19007 L
.21322 .20755 L
.21874 .22562 L
.22128 .23261 L
.22395 .23868 L
.22624 .24261 L
.22754 .24427 L
.22875 .24543 L
.22947 .24592 L
.23025 .24631 L
.23098 .24652 L
.23166 .24658 L
.23295 .24637 L
.23432 .24568 L
.23502 .24516 L
.23578 .24447 L
.23716 .24295 L
.24029 .23858 L
.24295 .23467 L
.2444 .23279 L
.24575 .23136 L
.24691 .23047 L
.24815 .22991 L
.24952 .22988 L
.25077 .23044 L
.25201 .23165 L
.25318 .23343 L
.25447 .23617 L
Mistroke
.25585 .24012 L
.25729 .24548 L
.25866 .25184 L
.26123 .26747 L
.26362 .28661 L
.26585 .30822 L
.27089 .36641 L
.27374 .39929 L
.27514 .4135 L
.27643 .42475 L
.27758 .43298 L
.27884 .43969 L
.28011 .44372 L
.28145 .44482 L
.28221 .44398 L
.28292 .4422 L
.28426 .43638 L
.28501 .43175 L
.28571 .42666 L
.28728 .41249 L
.29271 .34456 L
.29731 .28227 L
.30215 .22808 L
.30469 .20606 L
.30746 .18664 L
.31001 .17245 L
.31233 .16214 L
.31512 .15247 L
.31656 .14855 L
.31811 .145 L
.31955 .1423 L
.32088 .14025 L
.32223 .13855 L
.32349 .13725 L
.32591 .13543 L
.3272 .13475 L
.32858 .1342 L
.32927 .13399 L
.33002 .1338 L
.33139 .13356 L
.33273 .13345 L
.33396 .13347 L
.33532 .13361 L
.33601 .13373 L
.33675 .1339 L
.33808 .13429 L
.33932 .13476 L
.34211 .13612 L
.3451 .13794 L
.35557 .14546 L
Mistroke
.37513 .1609 L
.38585 .16731 L
.3915 .17028 L
.39459 .17206 L
.39749 .17405 L
.40272 .17903 L
.40549 .1826 L
.40848 .18732 L
.41378 .19843 L
.41863 .21214 L
.42827 .24698 L
.43082 .25614 L
.43357 .265 L
.43483 .26851 L
.43616 .27174 L
.43732 .27409 L
.43856 .2761 L
.43932 .27705 L
.44001 .27772 L
.44138 .27847 L
.44214 .27854 L
.44296 .27834 L
.44375 .27787 L
.44447 .27721 L
.44571 .27555 L
.44707 .27297 L
.4485 .2695 L
.44984 .26555 L
.45488 .24611 L
.46031 .22096 L
.46558 .19691 L
.47121 .17444 L
.47642 .15771 L
.48134 .14563 L
.48689 .13564 L
.49192 .12905 L
.49481 .12614 L
.49747 .12396 L
.5004 .12207 L
.5035 .12057 L
.50615 .11962 L
.50746 .11924 L
.50867 .11895 L
.50986 .11871 L
.51093 .11853 L
.51213 .11839 L
.5134 .11829 L
.51477 .11827 L
.51603 .11831 L
.51742 .11845 L
Mistroke
.51811 .11855 L
.51888 .11869 L
.52017 .11899 L
.52155 .1194 L
.52404 .1204 L
.52652 .12171 L
.52921 .12355 L
.53158 .12558 L
.5341 .12826 L
.53636 .13123 L
.53886 .13523 L
.54326 .14447 L
.54844 .15966 L
.55388 .18185 L
.55853 .20655 L
.56361 .23885 L
.5691 .27579 L
.57212 .29414 L
.57497 .30834 L
.57626 .31346 L
.57762 .31782 L
.57833 .31964 L
.57912 .32126 L
.5805 .32315 L
.58175 .32378 L
.58309 .32332 L
.58436 .32185 L
.58552 .3197 L
.62731 .23228 L
.64641 .20075 L
.65729 .1721 L
.66262 .16056 L
.66751 .15205 L
.67236 .14567 L
.6748 .14336 L
.67619 .14234 L
.67748 .14159 L
.67815 .14127 L
.67888 .14099 L
.6802 .14062 L
.68149 .14045 L
.68268 .14046 L
.68396 .14063 L
.68469 .14081 L
.68538 .14103 L
.68676 .14164 L
.68824 .14257 L
.6897 .14379 L
.69106 .14524 L
.69268 .14741 L
Mistroke
.69414 .14986 L
.69686 .15583 L
.69975 .16459 L
.70236 .17494 L
.70518 .18919 L
.71028 .22484 L
.72112 .3438 L
.72383 .37508 L
.72517 .38864 L
.7264 .39961 L
.7275 .40781 L
.72871 .41495 L
.72993 .41988 L
.73123 .42252 L
.73249 .42242 L
.73385 .41936 L
.73514 .41379 L
.73632 .40656 L
.73897 .384 L
.74177 .35372 L
.74784 .28299 L
.75048 .25573 L
.75335 .23054 L
.75603 .21115 L
.7585 .19655 L
.76337 .17538 L
.76585 .16772 L
.76857 .16121 L
.77142 .15615 L
.77408 .15264 L
.77657 .15013 L
.77894 .14826 L
.78109 .14689 L
.78338 .14574 L
.78468 .14523 L
.78586 .14486 L
.78704 .14457 L
.78816 .14438 L
.78946 .14426 L
.79066 .14425 L
.79198 .14433 L
.79337 .14454 L
.79465 .14483 L
.79605 .14527 L
.79859 .14637 L
.80107 .14788 L
.80335 .14974 L
.80582 .15235 L
.80853 .15607 L
.81403 .1667 L
Mistroke
.81882 .1796 L
.82398 .19718 L
.8333 .23457 L
.83596 .24442 L
.83879 .25323 L
.84017 .25664 L
.84147 .25925 L
.84264 .26104 L
.8439 .26235 L
.84462 .2628 L
.84529 .26301 L
.84603 .26302 L
.84683 .26276 L
.84766 .2622 L
.84845 .2614 L
.84915 .26045 L
.84992 .25919 L
.85132 .25629 L
.8528 .25243 L
.85547 .24372 L
.86562 .19997 L
.87095 .17769 L
.87656 .15836 L
.88165 .14493 L
.88434 .1393 L
.88721 .13431 L
.88986 .13057 L
.89227 .1278 L
.89456 .12567 L
.89699 .12388 L
.89945 .12249 L
.90172 .12155 L
.90298 .12117 L
.90416 .12089 L
.90546 .12068 L
.90619 .1206 L
.90685 .12056 L
.90804 .12054 L
.90914 .12059 L
.91035 .12071 L
.91163 .12093 L
.91286 .12121 L
.91401 .12154 L
.91617 .12233 L
.91871 .12353 L
.92107 .1249 L
.92644 .12903 L
.93167 .13452 L
.93728 .14208 L
.94743 .16007 L
Mistroke
.95668 .18054 L
.99855 .26189 L
1 .26436 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo00Co0000
[?ooool00;Gooooo1?l00002ooooo`?o0000Moooool5o`0002kooooo002dooooo`;o00002?ooool0
0ol0003oooooooooo`1booooo`;o00001?ooool2o`0002gooooo002cooooo`03o`000?oooooo0000
00Wooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`06ooooo`;o0000:oooool003;o
oooo1?l0001looooo`03o`000?oooooooooo00;o00002Oooool00ol0003oooooooooo`1^ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0:?ooool002oooooo0ol00003ooooo`?o0000
A_ooool4o`00033ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`1^ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0:?ooool002kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`12ooooo`;o00000_ooool3o`0002gooooo00Go0000oooooooooooo
ooooo`00000;ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Wooooo`00;?ooool2o`0000[ooooo00?o0000ooooooooool0@Oooool00ol0003ooooo
ooooo`05ooooo`;o0000:oooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool09_ooool002_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0:?ooool5o`0003gooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0Uooooo`00:oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo03oooooo00?o0000ooooooooool02Oooool2o`0002Kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool00_oo
ool2o`0001cooooo1_l0000Iooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool09Ooo
ool002[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`04ooooo`;o00006_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0Tooooo`00:Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
03gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool05_ooool2o`0000Sooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo02Cooooo000Yooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool04oooool2o`0002Oooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo00Cooooo0_l0000=ooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02?o
oooo000Xooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04_ooool2o`000003oooo
ool0003o000002Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Sooooo`00:?oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00Go0000oooooooooooooooo
o`00000Tooooo`03o`000?oooooooooo017ooooo0_l0000Nooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Rooooo`005Oooool2o`000009oa0@4?oo
ooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool03oooool01OnH
V9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP09ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool02_ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0:ooooo`03o`000?oooooooooo00oooooo1_l000001_ooooook^k^oc8b<_l0003o<S8bonk^
kQKooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
013ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Kooooo1Ol00003ooooo`06onk^k_lb<S;o0000oc8b<_o^
k^ko00003Oooool00ol0003oooooooooo`0:ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00_ooool0
1_l0003ok^k^oc8b<_l0003o<S8bonk^kQ7ooooo00?o0000ooooooooool02Oooool2o`000009oa0@
4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Fooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`03o`000?oooooooooo013ooooo00Go410@
okZj^_l0003oMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00[ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02_ooool00ol0003oooooooooo`0Aooooo`0:o`000?oooooooooo
ooooool0003oMgMgoiRHV?ooooooV9RHogMgMaGooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06oooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01_mgMgOoV9RHoooooonHV9SoMgMgo`0000kooooo
00?o0000ooooooooool02Oooool01Ol@413o^[ZjoooooomgMgOo<S8b00;ooooo00Ko0000ogMgMonH
V9SooooooiRHV?mgMgLBooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko00000_ooool5o`0000?ooooo00Go410@
oooooooooooooooooa0@4007ooooo`03o`000?oooooooooo00Sooooo1_l00004ooooo`03o`000?oo
oooo000000?ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooo
oooooooooooo410@00Wooooo00?o0000ooooooooool01oooool6o`0000Gooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo410@01Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`06
ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Ko410@oooooooooooooooooa0@4?l0000>ooooo`03o`00
0?oooooooooo00gooooo00Go0000oooooooooooo0000oa0@4003ooooo`03oa0@4?oooooooooo013o
oooo00?o0000ooooooooool01_ooool5o`0000?ooooo00Go410@oooooooooooooooooa0@400>oooo
o`004oooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`0Cooooo`03o`000?nYZJWo410@00?ooooo00Go0000ooooooooooooooooo`00
0007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^
kP03ooooo`05o`000?ooooooooooooooool000002Oooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00;ooooo0ol000000ooooooo0000ooooo`0Dooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool01oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000003oooool00ol0
003oooooooooo`0<ooooo`06ojVYZOl@413oooooo`000?oooooo00000oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00Gooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000000kooooo000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo01?ooooo0_l000001Onj^[[ooooooooooooooooo
000000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00cooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000Wooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o00005Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooo
oooooooooooo0000013ooooo00?o0000ooooooooool02_ooool01ol@413o0000okZj^_oooooo0000
ooooool000000oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo00CogMgM
oeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000kooooo000Dooooo`03ogMgMoo<
c<co000000Cooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo01?ooooo
00?o0000okZj^_lQ8B400oooool01Ol@413ooooooooooooooooo410@00Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool@41000oooool00ol@
413oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo000001Gooooo00?o0000ooooooooool01_ooool2o`0000oooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00Go0000oooooooooooooooo
oa0@4003ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02oooool01_nj^[[o8B4Q
ooooool0003ooooooa0@40?ooooo00?o410@ooooooooool04_ooool00ol0003oooooooooo`05oooo
o`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@400>ooooo`005?ooool00oo^
k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0B
ooooo`03oa0@4?nHV9Sooooo00;o00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`05o`000?nj^[[ooooooiRHV?l@4100
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Wooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`02ooooo`06ogMgMonHV9SooooooiRHV?mgMgOo00004oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00Cooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9Soooooo`000?mg
MgL04?ooool00ol0003oooooooooo`08ooooo`0=oa0@4?nHV9SooooookZj^_l0003oooooo`000?oo
ooooMgMgoiRHV?ooooooV9RHogMgM`0Dooooo`03o`000?oooooooooo00Gooooo00?ok^k^odA4A?l0
00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000Eooooo`03ogMgMol0003ooooo00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo01;ooooo00GoZJVYoa0@
4?l0003o0000ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Sooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02Oooool00ol0003oooooooooo`0@ooooo`03oeEEEOmVIVKo000000Co
oooo00Ook^k^oc8b<_l0003o<S8bonk^k_oooooo000001;ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`04ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?l0003ok^k^017o
oooo00?o0000ooooooooool01oooool01_nYZJWo410@o`000?l@413oZJVYo`0000;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0Eooooo`03o`000?oooooooooo00Gooooo00?oMgMgo`000?ooool00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo000Uooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Nooooo`009?ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07Oooool002Cooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo000Tooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Looooo`00
9?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
6oooool001Koooooool00010o`0001?ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01?ooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01?ooool00ol0003oooooo`00
0005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`00
0?oooooooooo017ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1?ooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooo000000Oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooool000001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000000Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`;o00001_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool0
4Oooool002;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo01Wooooo000Qooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`0Iooooo`008?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool06?ooool0023ooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo01Sooooo000Oooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Gooooo`007_ooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`06ooooo`?o00003oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01Oooooo000N
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00003oooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool2o`0001;ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool05_ooool001gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Fooooo`007?ooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01Gooooo000Kooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0@ooooo`04o`000?oooooooooo
o`0000Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo01Cooooo000Kooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0@ooooo`Co00001_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool05?ooool001[ooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo01?ooooo000Iooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool0
0000;?ooool00ol0003oooooooooo`0Cooooo`006Oooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool06Oooool01Ol0003ooooooooooooooooo000002go
oooo00?o0000ooooooooool04_ooool001Sooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool2o`0001?ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool06_ooool00ol0003oooooo`00000^ooooo`03o`000?oooooooooo01;ooooo
000Gooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Jooooo`?o0000;oooool00ol0003oooooooooo`0Aooooo`005_ooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0A
ooooo`00@?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo063ooooo0010ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo02[ooooo00Co0000oooooooooooo00004?ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo067ooooo0010ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02[ooooo00Co0000oooooooo
oooo00004?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo067ooooo0010ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo02[ooooo0ol0000Aooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0HOooool0043ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo067ooooo0010ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03kooooo0_l0000Dooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo067ooooo0010ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1Qooooo`00@?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0HOooool0047ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo067ooooo0011ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`1Qooooo`00@Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0HOooool0047ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0<oooool5o`0000Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1R
ooooo`00@Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0cooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo06;ooooo0011ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
03Cooooo00?oV9RHob4Q8Oo^k^h01oooool3o`0001Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0H_ooool0047o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0=Oooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0H_ooool0047ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=oooool00omgMgOoIVIV
ooooo`05ooooo`03o`000?oooooooooo01Gooooo00Go0000ooooooooooooooooo`00000Xooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0H_ooool0047ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Kooooo00Co0000oooooooooooo
0000:?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06;ooooo0011ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo03Cooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooool00000:Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06;o
oooo0012ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo03Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo06;ooooo0012ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0
@oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06;ooooo0012ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo03oooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo06;ooooo0012ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo03oooooo0_l00014ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0H_ooool004;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0?oooool00ol0
003oooooooooo`13ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Hoooool004;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0Hoooool004;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`13ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Hoooool004;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0?oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0Hoooool004;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`13
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Hoooool004?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0Hoooool004?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`13ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0Hoooool004?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
?oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
Hoooool004?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0@?ooool2o`0004Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1Sooooo`00@oooool01Ol0003ooooooooooooooooo000002Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo04Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`1Sooooo`00@oooool01Ol0003ooooooooooooo
oooo000002Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`10ooooo`03o`000?oo
oooooooo04Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Sooooo`00@oooool0
1Ol0003ooooooooooooooooo000002Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`10ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`1Tooooo`00@oooool01Ol0003ooooooooooooooooo000002Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`1Tooooo`00@oooool01Ol0003ooooooooooooooooo000002Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo04Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`1Tooooo`00A?ooool01?l0003oooooooooool0
000Tooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0@?ooool00ol0003ooooooooo
o`14ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0I?ooool004Cooooo00Co0000
oooooooooooo00009Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo043ooooo00?o
0000ooooooooool0AOooool01Ol0003ooooooooooooooooo000006Kooooo0014ooooo`03o`000?oo
oooo000002Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`10ooooo`;o0000A_oo
ool01Ol0003ooooooooooooooooo000006Kooooo0014ooooo`03o`000?oooooo000002Kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo04Gooooo00Go
0000ooooooooooooooooo`00001Vooooo`00AOooool2o`0002Kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo04Gooooo00Go0000oooooooooooooooo
o`00001Vooooo`00AOooool00ol0003oooooooooo`0Uooooo`05o`000?ooooooooooooooool00000
@oooool00ol0003oooooooooo`15ooooo`04o`000?ooooooooooo`0006Oooooo001]ooooo`05o`00
0?ooooooooooooooool00000@oooool00ol0003oooooooooo`15ooooo`04o`000?ooooooooooo`00
06Oooooo001]ooooo`05o`000?ooooooooooooooool00000>_ooool2o`000003oa0@4?oooooooooo
00Cooooo00?o0000ooooooooool0AOooool01?l0003oooooooooool0001Wooooo`00KOooool01Ol0
003ooooooooooooooooo000003_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`15
ooooo`04o`000?ooooooooooo`0006Oooooo001]ooooo`05o`000?ooooooooooooooool00000>?oo
ool5o`0000Kooooo00?o0000ooooooooool0AOooool01?l0003oooooooooool0001Wooooo`00KOoo
ool01Ol0003ooooooooooooooooo000003Sooooo00CoA4A4omgMgOoooooo00001oooool3o`0004Go
oooo00Co0000oooooooooooo0000Ioooool006gooooo00Go0000ooooooooooooooooo`00000hoooo
o`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0A_ooool00ol0003oooooo`00001W
ooooo`00KOooool01Ol0003ooooooooooooooooo000003Wooooo00?oMgMgolc<c?l000001oooool0
0ol0003oooooooooo`16ooooo`;o0000J?ooool006kooooo00Co0000oooooooooooo0000>Oooool0
0oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo04Kooooo0_l0001Xooooo`00K_ooool01?l0
003oooooooooool0000jooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0/?ooool0
06kooooo00Co0000oooooooooooo0000@oooool00ol0003oooooooooo`2`ooooo`00K_ooool00ol0
003oooooo`000014ooooo`03o`000?oooooooooo0;3ooooo001^ooooo`03o`000?oooooo000004Co
oooo00?o0000ooooooooool0/?ooool006kooooo00?o0000ooooool00000A?ooool2o`000;7ooooo
001^ooooo`03o`000?oooooo000004Cooooo00?o0000ooooooooool0/?ooool006oooooo0_l00014
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Oo^k^ko<S8bo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00GoEEEEogMgMoooooooV9RHob4Q
8@06ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0
002`ooooo`00Z_ooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0/?oo
ool00:[ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`2`ooooo`00Z_ooool00ooM
gMgo410@oiRHV008ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`04olc<c?m4A4Co0000oa0@
40Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002a
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00:[ooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo
0;3ooooo002Zooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2`oooo
o`00Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0/?ooool00:[o
oooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000/?ooool00:[ooooo00Goc<c<o`000?l0
003o0000olc<c02iooooo`00Z_ooool01Ol@413o^[Zjoooooonj^[[o410@0;Wooooo002Zooooo`05
o`000?nj^[[ooooookZj^_l00000^Oooool00:[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2ioooo
o`00oooooomYooooo`00[oooool00ol0003o^[Zjooooo`2fooooo`00[oooool2oc8b<[Oooooo0020
ooooo`;o000000Ko410@oooooooooooo410@o`000?l@410Hooooo`05odA4A?l0003o0000oc8b<_oM
gMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?oQhN7o`000?nj^[X03?ooool01OnH
V9So0000o`000?m4A4Co^[Zj01Wooooo1?l000002?l@413ooooooooooonHV9So410@o`000?lb<S;o
c<c<0oooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<07Sooooo0021ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01oooool6o`0000gooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9So
oooooiRHV?mgMgL00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@4100
2Oooool6o`0000cooooo00?o0000ooooooooool00_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?o
oooo00Go8B4QoiRHV?ooooooV9RHob4Q8@1hooooo`00POooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo01_ooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`0@oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool0M_ooool0087ooooo00Ko0000oooooom4A4CoA4A4ooooool0
0009ooooo`Ko00003Oooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0;ooooo`Ko00003?ooool00ol0003oooooooooo`05ooooo`03ojVY
ZOl@413ooooo00;ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P1hooooo`00POooool01_l0003ogMgM
oc8b<_mEEEGogMgMo`0001Wooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?oooooo
ooooooooool000004_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Cooooo00?o
410@o`000?nj^[X00oooool01Oo<c<co0000o`000?l0003oc<c<07Sooooo0021ooooo`06o`000?n7
QhOoZJVYokZj^_mEEEGo00006Oooool00ol0003oooooooooo`04ooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol@413o0000o`000003o`0001cooooo00?o0000ooooooooool01Oooool00onj
^[[o8B4Qooooo`02ooooo`05oa0@4?nj^[[ooooookZj^_l@4100N?ooool0087ooooo00Ko0000oc8b
<_oooooooooooc8b<_l0000Iooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0Booooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00_ooool01Ol@413oV9RH
oooooonj^[[o000000?ooooo00Go0000okZj^_oooooo^[Zjo`00001hooooo`00P?ooool00ol@413o
0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h04_ooool00ol0003oooooooooo`0Kooooo`03oeEEEOmVIVKo000000Cooooo00GoZJVYoa0@
4?l0003o410@ojVYZ@03ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0N?ooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(140) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .29087 m
.00123 .29562 L
.00236 .29942 L
.00357 .30287 L
.00488 .30577 L
.00609 .30762 L
.00722 .30857 L
.00829 .30876 L
.00942 .30821 L
.01065 .30674 L
.01196 .30417 L
.0132 .30086 L
.01434 .29713 L
.01975 .27216 L
.03054 .2114 L
.0358 .18682 L
.04057 .16932 L
.04582 .15493 L
.05141 .144 L
.05434 .13966 L
.05751 .13579 L
.06024 .13303 L
.06325 .13052 L
.06871 .12701 L
.07149 .12562 L
.07448 .12438 L
.07727 .12344 L
.07982 .12278 L
.08105 .12253 L
.08238 .12231 L
.08364 .12215 L
.08481 .12204 L
.08604 .12196 L
.08735 .12194 L
.08846 .12196 L
.08967 .12202 L
.09099 .12215 L
.09172 .12226 L
.09239 .12237 L
.09369 .12265 L
.09492 .12299 L
.09729 .12388 L
.09947 .12503 L
.10187 .12671 L
.10441 .12906 L
.10697 .13214 L
.10973 .13642 L
.11233 .14158 L
.11471 .14747 L
.11749 .15606 L
Mistroke
.12052 .16789 L
.12604 .19728 L
.13164 .23839 L
.1369 .28481 L
.14169 .32592 L
.1441 .34279 L
.14548 .35056 L
.14674 .35618 L
.14812 .36061 L
.14887 .36222 L
.14959 .3632 L
.15087 .36362 L
.15226 .36218 L
.15354 .3592 L
.15489 .35444 L
.15733 .34242 L
.1633 .30275 L
.16592 .28512 L
.16877 .26805 L
.1711 .25651 L
.17358 .24686 L
.17495 .24272 L
.1762 .23969 L
.17745 .23732 L
.17864 .23569 L
.17993 .23452 L
.18129 .23395 L
.18246 .23396 L
.18374 .23443 L
.18511 .23542 L
.18589 .23616 L
.18659 .23694 L
.18926 .24048 L
.19398 .24735 L
.19527 .24895 L
.19665 .25038 L
.19782 .25132 L
.19912 .25202 L
.20033 .25233 L
.20143 .25229 L
.20265 .25187 L
.20394 .251 L
.20506 .24988 L
.2061 .24852 L
.20846 .24435 L
.22811 .18065 L
.23349 .16572 L
.23644 .15904 L
.2392 .15386 L
.24154 .15034 L
Mistroke
.24407 .1475 L
.2455 .14631 L
.24687 .14545 L
.24809 .14491 L
.24943 .14454 L
.25016 .14445 L
.25095 .14442 L
.25169 .14448 L
.25238 .1446 L
.25368 .14502 L
.25505 .14576 L
.25576 .14627 L
.25653 .14693 L
.25791 .14843 L
.25955 .1508 L
.26104 .15357 L
.26369 .16016 L
.26657 .1701 L
.2693 .18258 L
.27181 .19725 L
.27669 .23619 L
.27947 .26555 L
.28207 .29773 L
.28728 .36943 L
.29003 .40502 L
.29154 .42173 L
.29297 .4348 L
.29431 .44423 L
.29507 .44816 L
.29577 .45084 L
.29701 .45331 L
.29832 .45269 L
.29955 .44914 L
.30069 .44335 L
.30195 .43446 L
.3033 .42232 L
.30888 .35469 L
.31417 .28838 L
.31904 .24166 L
.32178 .22216 L
.32433 .20788 L
.32665 .19752 L
.32883 .18971 L
.33134 .18265 L
.33361 .17777 L
.33615 .17366 L
.33852 .17076 L
.3439 .16593 L
.35475 .15837 L
.36406 .15297 L
Mistroke
.36896 .15021 L
.37144 .14909 L
.37284 .1486 L
.37416 .14825 L
.3749 .1481 L
.3756 .14799 L
.37692 .14788 L
.37766 .14787 L
.37834 .1479 L
.37909 .14796 L
.37989 .14808 L
.38057 .14822 L
.38132 .14841 L
.38266 .14887 L
.38397 .14948 L
.38518 .1502 L
.38759 .15215 L
.38896 .15361 L
.39024 .15525 L
.39282 .15945 L
.39559 .16541 L
.40083 .18121 L
.40579 .20178 L
.41509 .25159 L
.41761 .26514 L
.42032 .27802 L
.42156 .28302 L
.42288 .28749 L
.42401 .29061 L
.42522 .29312 L
.42649 .29478 L
.42767 .29541 L
.42839 .29534 L
.42907 .29498 L
.43034 .29349 L
.43102 .29227 L
.43175 .29067 L
.43305 .28703 L
.43599 .2756 L
.44609 .21831 L
.45051 .19357 L
.45533 .17104 L
.4604 .15287 L
.46523 .14025 L
.4679 .13492 L
.47075 .13036 L
.47344 .12701 L
.47587 .12464 L
.47835 .12277 L
.48063 .12144 L
Mistroke
.48313 .12036 L
.48439 .11995 L
.48577 .1196 L
.48699 .11937 L
.4881 .11924 L
.48938 .11917 L
.4906 .11918 L
.49172 .11927 L
.49275 .11941 L
.49389 .11963 L
.49509 .11994 L
.4976 .1208 L
.50024 .12202 L
.50495 .12498 L
.50758 .12713 L
.51003 .12952 L
.51557 .13652 L
.52044 .14451 L
.52486 .15322 L
.53477 .1777 L
.54458 .20447 L
.54994 .21683 L
.55495 .22548 L
.55756 .22867 L
.55903 .23006 L
.56037 .23108 L
.56183 .23197 L
.56342 .23269 L
.56493 .2332 L
.56632 .23359 L
.56894 .23426 L
.5714 .23511 L
.57263 .23572 L
.57396 .23657 L
.57544 .23778 L
.5768 .23919 L
.57936 .24273 L
.58214 .24804 L
.58477 .25456 L
.58719 .26187 L
.59302 .28329 L
.59575 .29392 L
.59831 .30306 L
.60055 .30966 L
.60169 .31236 L
.60294 .31467 L
.60431 .31635 L
.60561 .31707 L
.60687 .3169 L
.60804 .31596 L
Mistroke
.60939 .31395 L
.61066 .31117 L
.61304 .30379 L
.61559 .29309 L
.61836 .27905 L
.62848 .22119 L
.63401 .19473 L
.63917 .17592 L
.64358 .164 L
.6483 .15487 L
.651 .15113 L
.65355 .14841 L
.65583 .14654 L
.65832 .14497 L
.66077 .14379 L
.66206 .14329 L
.66342 .14284 L
.66461 .1425 L
.66591 .1422 L
.66709 .14199 L
.6682 .14185 L
.66888 .14178 L
.66962 .14173 L
.67096 .14169 L
.67226 .1417 L
.67346 .14175 L
.67477 .14184 L
.6762 .14196 L
.67909 .14222 L
.68191 .14245 L
.68459 .14266 L
.68606 .14281 L
.68767 .14301 L
.68913 .14326 L
.69049 .14355 L
.6932 .14433 L
.69565 .14526 L
.69849 .14663 L
.70115 .1483 L
.70369 .15045 L
.70606 .1532 L
.70866 .15741 L
.71144 .16374 L
.71435 .17293 L
.71711 .1845 L
.71959 .19775 L
.72228 .21579 L
.72718 .26007 L
.73237 .3219 L
.73466 .35097 L
Mistroke
.73715 .38078 L
.73935 .40291 L
.74056 .41261 L
.74169 .4198 L
.74237 .42307 L
.74309 .42574 L
.74436 .42817 L
.74566 .42763 L
.74685 .42447 L
.74794 .41939 L
.74914 .41158 L
.75156 .38964 L
.75669 .32695 L
.76219 .25895 L
.76485 .23168 L
.76738 .21022 L
.76984 .19326 L
.77212 .18068 L
.77427 .17124 L
.77656 .16355 L
.77886 .15802 L
.78017 .15577 L
.78139 .15423 L
.78263 .15319 L
.78394 .15262 L
.78519 .15257 L
.78632 .15289 L
.78765 .15371 L
.7884 .15438 L
.78909 .15511 L
.7917 .1589 L
.79422 .164 L
.79698 .17127 L
.80257 .19112 L
.81253 .23665 L
.8149 .24683 L
.81744 .25617 L
.81867 .25998 L
.81983 .26303 L
.82088 .26532 L
.82199 .2672 L
.82327 .26864 L
.82444 .26925 L
.8257 .26912 L
.82709 .26805 L
.82848 .26601 L
.82925 .26446 L
.82996 .26281 L
.83265 .25464 L
.83765 .23349 L
Mistroke
.84239 .21052 L
.84749 .18696 L
.8529 .16593 L
.85572 .15697 L
.85883 .14875 L
.86146 .14313 L
.86432 .13824 L
.867 .13469 L
.86949 .13215 L
.87212 .13017 L
.8736 .12934 L
.87493 .12875 L
.87618 .12833 L
.87734 .12806 L
.8786 .12789 L
.87994 .12784 L
.8811 .1279 L
.88219 .12805 L
.88338 .1283 L
.88466 .12867 L
.88747 .12981 L
.89053 .1315 L
.89611 .13565 L
.90153 .141 L
.90656 .14695 L
.9162 .15954 L
.92636 .1721 L
.93168 .177 L
.93469 .17898 L
.93614 .17972 L
.9375 .1803 L
.93874 .18072 L
.94009 .18107 L
.94131 .1813 L
.94245 .18143 L
.94367 .1815 L
.94501 .18148 L
.94569 .18144 L
.94642 .18137 L
.94773 .18119 L
.94923 .18091 L
.95062 .18059 L
.95377 .17977 L
.95532 .17938 L
.95678 .17905 L
.95809 .17882 L
.95883 .17872 L
.95951 .17865 L
.96072 .1786 L
.96204 .17866 L
Mistroke
.96343 .17886 L
.96472 .17921 L
.96544 .17948 L
.96612 .17979 L
.9674 .1805 L
.96878 .1815 L
.97028 .18289 L
.97282 .18604 L
.97562 .19086 L
.97854 .1976 L
.98129 .20566 L
.98619 .22428 L
.99148 .24941 L
1 .29087 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
002_ooooo`Oo0000/_ooool002gooooo2Ol0001gooooo`;o00001_ooool00ol0003oooooooooo`2`
ooooo`00:oooool2o`0000Sooooo0_l0001eooooo`03o`000?oooooooooo00Kooooo0ol0001eoooo
o`;o0000>Oooool002[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1booooo`03
o`000?oooooooooo00Kooooo0_l000000ooooooo0000ooooo`1aooooo`?o000000?oooooo`000?l0
0000=oooool002Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1aooooo`03o`00
0?oooooooooo00Kooooo00Go0000ooooooooooooooooo`00001aooooo`03o`000?oooooooooo00?o
oooo0_l0000eooooo`00:?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo06oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0booooo`009oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0aooooo`009oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo06kooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02[ooooo2ol0000e
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0<?ooool002Kooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0Xooooo`Co0000@Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool3o`0000Wooooo0ol0000coooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0<?ooool002Kooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Vooooo`04o`000?ooooooooooooooo`;o00008oooool5o`00
01Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0;oooool002Gooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07_ooool3o`0000Co
oooo0_l0000Fooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool05_ooool2o`0001Ko
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0_ooooo`009?ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0:ooooo`;o00001_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool05Oooool4o`0001Cooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0^ooooo`009?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Jooooo`;o00002_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05?ooool01Ol0003ooooooooo
oooooooo000001?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0]ooooo`009?oo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08_oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Cooooo00Go0000oooooooooooooooo
o`00000Cooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0;?ooool001Gooooo0_l0
00002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP03ooooo`03o`000?oooooooooo
01Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06Ooo
ool00ol0003oooooo`000004o`0000?ooooo00Go0000oc8b<_l0003o<S8bonk^kP0Eooooo`03o`00
0?oooooooooo00Cooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^4?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05_ooool4
o`000009oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^ko000001Cooooo00?o0000oooooooo
ool00_ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool03oooool01Ol0003o410@o`000?lb<S;oc<c<00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo01;ooooo0_l000002Ol@413ooooooooo
ooooooook^k^oc8b<_l0003o<S8bonk^kP0>ooooo`005_ooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool00ol0003oooooooooo`0Dooooo`05oa0@4?nj^[[o0000
ogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg01Wooooo00Oo0000oooooonHV9So8B4Q
onk^k_ooooooA4A400?ooooo00GoMgMgo`000?ooooooV9RHogMgM`0Cooooo`;o00002Oooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9So0000oiRHV?mgMgL04?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`02
ooooo`06ogMgMonHV9SooooooiRHV?mgMgOo00005?ooool00ol0003oooooooooo`02ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0?ooooo`05o`000?nj^[[oooooogMgMolb<S800oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Wooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool000_ooooo1_l00002ooooo`Go00000ooo
ool01Ol@413ooooooooooooooooo410@00?ooooo00?o0000ooooooooool03?ooool6o`0000Cooooo
00?o0000ooooool000000oooool01Ol@413ooooooooooooooooo410@01?ooooo1ol00002ooooo`03
oiRHV?lQ8B7ok^k^00Cooooo00Go410@o`000?oooooooooooa0@400Booooo`Oo00001Oooool00ol0
003oooooooooo`02ooooo`05oa0@4?oooooo0000ooooool@41004?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool000005_ooool00ol0003oooooooooo`02ooooo`03oiRHV?lQ
8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4002ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool03oooool01Ol0003ooooooooooooooooo000000?ooooo00Go410@oooooooo
oooooooooa0@400:ooooo`03o`000?oooooooooo00kooooo1Ol00003ooooo`05oa0@4?oooooooooo
ooooool@41003_ooool001?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool05_ooool00ol0003oZJVYoa0@4003ooooo`05o`000?oo
ooooooooooooool000006?ooool00ol0003oooooooooo`02ooooo`03oiRHV?lQ8B7ok^k^00?ooooo
0_l00002ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;o00004?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000005_ooool00ol0003oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00?o
oooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool03oooool01Ol0003ooooooooooonYZJWo410@00?ooooo00Go0000ooooooooooooooooo`00
000;ooooo`03o`000?oooooooooo00gooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000000kooooo000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000oooooooo
ooooooooo`000002ooooo`03o`000?oooooooooo01Oooooo00?o410@o`000?nj^[X00oooool01Ol0
003ooooooooooooooooo000001Sooooo00?o0000ooooooooool00oooool00omgMgOoIVIVooooo`02
ooooo`;o00000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02o`00013ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02o`0001Kooooo00?o0000ooooooooool01?ooool00omgMgOoIVIVooooo`02
ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00oooooo00Go0000ooooool@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool0
00003?ooool00ol0003oooooooooo`0<ooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000oooo
ooooooooooooo`00000>ooooo`005?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41000_ooool00ol0003oooooooooo`0Hooooo`03o`000?lQ8B7ooooo00;ooooo00Go410@
oooooooooooooooooa0@400Gooooo`03o`000?oooooooooo00Gooooo00Ko0000oooooooooooooooo
oa0@4?l00002ooooo`03oa0@4?oooooooooo00oooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`02ooooo`05oa0@4?ooooooooooo`000?l@41003oooool00ol0003oooooooooo`0<oooo
o`;o00002Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooo0000oa0@400Gooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooooa0@
4003ooooo`04oa0@4?ooooooooooo`0000Oooooo00?o0000ooooooooool03Oooool01_l0003ooooo
oooooooooooo^[Zjob4Q8@?ooooo00Go410@oooooooooooooooooa0@400=ooooo`?o000000?ooooo
o`000?l000001_l00003ooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@
400>ooooo`005?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_oo
ool00ol0003oooooooooo`0Eooooo`03oa0@4?nHV9Sooooo00;o00000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg01Oooooo00Wo0000ooooooooooooooooo`000?nj^[[ooooooiRHV?l@41000oooool0
1OmgMgOo0000oooooonHV9SoMgMg013ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9Soooooo`000?mgMgL03oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9Soooooo`000?mgMgL05oooool02?l0003oooooooooool0003o^[ZjoooooonHV9So410@0ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0=ooooo`06o`000?l@413oV9RHoooooonj^[[o00000oooool01OmgMgOoV9RHoooooonHV9So
MgMg013ooooo0_l00006ooooo`;o00000_ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03_ooool001Gooooo00?oMgMgo`000?ooool00oooool01oo^k^ko<S8bo`000?lb
<S;ok^k^ooooool000006?ooool01OnYZJWo410@o`000?l0003oZJVY00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0Gooooo`09o`000?oooooooooooooooonHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^o`000?l0003o<S8bonk^kP0@ooooo`03o`000?oooooooooo00Wooooo00?oEEEEofIVI_l0
00001?ooool01Oo^k^ko<S8bo`000?l0003ok^k^00oooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo01?ooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?l0003ok^k^01Oooooo00So0000ooooooooooooV9RHoa0@4?l0003o8B4Qolc<c0?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool03Oooool01_l0003oZJVYoa0@4?l0003o410@ojVYZ@?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0Iooooo`06o`000?oooooooooooooooomgMgOo00001?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00kooooo000Qooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0Jooooo`008Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool06Oooool0023ooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo01Wooooo000Pooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0Hooooo`008?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool06?ooool001Koooooool00010o`00
01?ooooo000Fooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`;o00001_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Oo
oooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooo`000005ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Co
oooo0_l00006ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0003o
ooooo`000005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool04Oooool001Kooooo
00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool000001Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
o`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
o`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`04ooooo`;o00001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo
00?o0000ooooool000001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo017o
oooo000Oooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0:_ooool00ol0003ooooo
ooooo`0Fooooo`007oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool05_ooool001oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo01Gooooo000Nooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`0Eooooo`007_ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool05Oooool001kooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0?ooooo`;o00005Oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo02gooooo00?o0000ooooooooool05Oooool001kooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`0<ooooo`;o00002?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00oooooo0_l0000Booooo`?o00004Oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool05Oooool001kooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0;ooooo`;o000000?oooooo`000?ooool01_ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05?ooool2o`0000oooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Gooooo000Noooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool05?ooool001gooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`0Dooooo`007Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Co
oooo000Mooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`03ooooo`;o00000_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Dooooo`007Oooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool3o`0001Oooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Cooooo000M
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0D
ooooo`007Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Aooooo`;o00006Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Coooo
o`007Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool03oooool2o`0000;ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Cooooo`00
7?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
4?ooool01?l0003oooooo`000?l0000cooooo`03o`000?oooooooooo01?ooooo000Looooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0@ooooo`?o0000
=?ooool00ol0003oooooooooo`0Cooooo`007?ooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Booooo`007?ooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo01oooooo00Go0000ooooooooooooooooo`00
000Dooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0B?ooool00ol0003ooooooooo
o`0Booooo`007?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01oooooo00Go0000
ooooooooooooooooo`00000Dooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0B?oo
ool00ol0003oooooooooo`0Booooo`006oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo01oooooo00Go0000ooooooooooooooooo`00000Dooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0B?ooool00ol0003oooooooooo`0Booooo`006oooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo01oooooo00Go0000ooooooooooooooooo`00000Dooooo`;o00006ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo01;ooooo000Kooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool07oooool01Ol0003ooooooooooooooooo000001Cooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo017ooooo000F
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooo000001Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`19
ooooo`03o`000?oooooooooo017ooooo000Fooooo`05o`000?ooooooooooooooool000009_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooo000001Gooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1Mooooo`005_ooool01Ol0003ooooooooooooooooo000002Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool08?ooool2o`0001Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1N
ooooo`005_ooool01Ol0003ooooooooooooooooo000002Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0>?ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo05kooooo000Gooooo`04o`000?oooooooooo
o`0002Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0;Oooool5o`0000Kooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`1Nooooo`005oooool00ol0003oooooo`00000Xooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
02gooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0G_ooool001Sooooo0_l0000Xooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02oooooo00?oV9RHob4Q
8Oo^k^h01oooool3o`0001gooooo00Co0000oooooooooooo00009_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo05kooooo0012ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo033ooooo00?oV9RHob4Q
8Oo^k^h01_ooool00ol0003oooooooooo`0Mooooo`04o`000?ooooooooooo`0002Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1Nooooo`00@_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0aoooo
o`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool07_ooool3o`0002Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`1Nooooo`00@oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0G_ooool004?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
;_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0Aoooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo05kooooo0013ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02kooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo04Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`1Nooooo`00@oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0iooooo`03o`00
0?oooooooooo04Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Nooooo`00@ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1Nooooo`00@oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0iooooo`;o0000B?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo05kooooo0014ooooo`05o`000?oooooooooo
ooooool000009oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Wooooo00?o0000
ooooooooool0B?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05kooooo0014oooo
o`05o`000?ooooooooooooooool000009oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo03Wooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo05kooooo0014ooooo`05o`000?ooooooooooooooool000009oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo05kooooo0014ooooo`05o`000?ooooooooooooooool000009oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0B?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo05oooooo0014ooooo`05o`000?oooooooooo
ooooool000009oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03[ooooo00?o0000
ooooooooool0B?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05oooooo0014oooo
o`04o`000?ooooooooooo`0002Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1O
ooooo`00A?ooool01?l0003oooooooooool0000Yooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0Goooool004Cooooo00Co0000oooooooooooo0000:Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo05oooooo0015ooooo`;o0000:_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo03[ooooo0_l00019ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0Goooool004Kooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo03[ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo05oooooo001aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
>_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
Goooool0077ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0jooooo`03o`000?oo
oooooooo04Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Oooooo`00LOooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0B?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo05oooooo001aooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0H?ooool0077ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`1Pooooo`00LOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool0B?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo063ooooo
001aooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0>oooool2o`0004Wooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`1Pooooo`00L_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo063ooooo001booooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`19ooooo`05o`000?ooooooooooooooool00000H_ooool0
07;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
04Wooooo00Go0000ooooooooooooooooo`00001Rooooo`00L_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0BOooool01Ol0003ooooooooooooooooo
000006;ooooo001booooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0<_ooool2o`00
0003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0BOooool01?l0003oooooooooool0001S
ooooo`00L_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`19ooooo`04o`000?ooooooooooo`0006?ooooo001boooo
o`05o`000?ooooooooooooooool00000<oooool5o`0000Kooooo00?o0000ooooooooool0BOooool0
1?l0003oooooooooool0001Sooooo`00L_ooool01Ol0003ooooooooooooooooo000003?ooooo00Co
A4A4omgMgOoooooo00001oooool3o`0004Wooooo00Co0000oooooooooooo0000Hoooool007?ooooo
00Co0000oooooooooooo0000<oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo
04Wooooo00Co0000oooooooooooo0000Hoooool007?ooooo00Co0000oooooooooooo0000=?ooool0
0omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooool00000Hoooool0
07?ooooo00Co0000oooooooooooo0000=?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooo
oooo04[ooooo00?o0000ooooool00000Hoooool007?ooooo00Co0000oooooooooooo0000=Oooool0
0omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo04[ooooo0_l0001Tooooo`00Loooool01?l0
003oooooooooool0000nooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0H_ooool0
07?ooooo00Co0000oooooooooooo0000?_ooool00ol0003oooooooooo`2`ooooo`00Loooool01?l0
003oooooooooool0000nooooo`03o`000?oooooooooo0;3ooooo001cooooo`04o`000?oooooooooo
o`0003kooooo0_l0002aooooo`00Loooool00ol0003oooooo`00000oooooo`03o`000?oooooooooo
0;3ooooo001cooooo`03o`000?oooooo000003oooooo00?o0000ooooooooool0/?ooool007Cooooo
0_l0000oooooo`03o`000?oooooooooo0;3ooooo001dooooo`;o0000?oooool00ol0003ooooooooo
o`2`ooooo`00M?ooool2o`0003oooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05onk^k_lb<S;o0000oa0@
4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OmEEEGoMgMgoooooonHV9So8B4Q
00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`00
0;3ooooo002Zooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`oooo
o`00Z_ooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03omgM
gOl@413oV9RH00Sooooo00?o0000ooooooooool0/?ooool00:_ooooo00Coc<c<odA4A?l0003o410@
1_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo
002Zooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_oo
ool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0002`ooooo`00Z_ooool01Oo<c<co0000o`00
0?l0003oc<c<0;Wooooo002Zooooo`05oa0@4?nj^[[ooooookZj^_l@4100^Oooool00:[ooooo00Go
0000okZj^_oooooo^[Zjo`00002iooooo`00Z_ooool01OnYZJWo410@o`000?l@413oZJVY0;Wooooo
003oooooofWooooo002_ooooo`03o`000?nj^[[ooooo0;Kooooo002_ooooo`;o<S8b]oooool0083o
oooo0_l000001_l@413oooooooooool@413o0000oa0@41Sooooo00GoA4A4o`000?l0003o<S8bomgM
g@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOo0000okZj^P0<ooooo`05oiRH
V?l0003o0000odA4A?nj^[X06Oooool4o`000003oa0@4?oooooooooo00;ooooo0_l000002Ol@413o
ooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP1hooooo`00POooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Oooooo1_l0000=ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@
00Wooooo1_l0000<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg07Sooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool06oooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo013ooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`02ooooo`Go00000oooool01Ol@413ooooooooooooo
oooo410@07Sooooo0021ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`0000gooooo
00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool02oooool6o`0000cooooo00?o0000ooooooooool00_ooool01?m4A4CogMgMooooool00004oooo
o`05o`000?ooooooooooooooool00000N?ooool0087ooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0
000Iooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000001;o
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02ooooo`04omgMgOmEEEGoooooo`00
00Cooooo00Go0000ooooooooooooooooo`00001hooooo`00POooool01_l0003oQhN7ojVYZOnj^[[o
EEEEo`0001Wooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@013ooooo
00?o410@o`000?l000000ol0000Looooo`03o`000?oooooooooo00?ooooo00?oMgMgolc<c?l00000
1?ooool01Ol@413ooooooooooooooooo410@07Sooooo0021ooooo`06o`000?lb<S;ooooooooooolb
<S;o00006Oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00?ooooo00?ok^k^odA4A?l000001?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg07Sooooo0020ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7
o`000?l@41006?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Booooo`03o`000?oo
oooooooo01_ooooo00?oEEEEofIVI_l000001_ooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h0N?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(142) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .32332 m
.01975 .22765 L
.02492 .1953 L
.02981 .17123 L
.03251 .16069 L
.03544 .15122 L
.04057 .13878 L
.04333 .13386 L
.04625 .12972 L
.04875 .12692 L
.0515 .12451 L
.05403 .12279 L
.05676 .12138 L
.05807 .12084 L
.05933 .12041 L
.06054 .12006 L
.06168 .1198 L
.06238 .11966 L
.06314 .11954 L
.06446 .11939 L
.06521 .11934 L
.066 .11932 L
.06667 .11932 L
.06742 .11934 L
.06874 .11945 L
.06949 .11954 L
.07017 .11964 L
.07149 .11991 L
.07274 .12022 L
.07574 .12126 L
.07852 .12256 L
.08157 .12444 L
.08481 .12702 L
.08994 .13267 L
.09465 .13985 L
.09981 .15022 L
.10525 .16441 L
.11531 .19939 L
.12445 .23384 L
.12692 .24178 L
.1296 .24909 L
.13083 .25189 L
.13213 .25445 L
.13335 .25644 L
.13447 .25792 L
.13574 .2592 L
.1371 .26012 L
.13837 .26056 L
.13957 .26065 L
.14024 .26058 L
Mistroke
.14096 .26041 L
.14225 .2599 L
.14304 .25949 L
.14379 .25904 L
.14518 .25811 L
.14753 .25649 L
.14881 .2557 L
.15001 .25511 L
.15103 .25476 L
.15212 .25457 L
.15334 .25464 L
.15445 .25499 L
.15573 .25578 L
.15691 .25692 L
.15821 .25866 L
.15959 .2611 L
.16191 .26664 L
.16446 .27487 L
.17438 .3204 L
.1768 .33074 L
.17812 .33548 L
.17937 .33915 L
.18008 .34085 L
.18085 .34234 L
.18219 .344 L
.18356 .34439 L
.18482 .34356 L
.18619 .34132 L
.18746 .33801 L
.18887 .33307 L
.19038 .32638 L
.19625 .29012 L
.20673 .21858 L
.20941 .20402 L
.21227 .19085 L
.21739 .1728 L
.22024 .16554 L
.22291 .16029 L
.22584 .1561 L
.22749 .15437 L
.229 .15314 L
.23023 .15235 L
.23155 .15169 L
.23279 .15123 L
.23391 .15092 L
.23524 .15068 L
.23599 .1506 L
.23668 .15056 L
.23795 .15055 L
.23929 .15065 L
Mistroke
.24057 .15083 L
.24195 .15112 L
.24325 .15149 L
.24445 .15189 L
.25012 .15455 L
.25978 .15932 L
.27007 .16405 L
.27312 .16564 L
.276 .16728 L
.27858 .16908 L
.2799 .17024 L
.28136 .17177 L
.28402 .17551 L
.28547 .17822 L
.28682 .18126 L
.28924 .18811 L
.29184 .19781 L
.29453 .21102 L
.29739 .22936 L
.29984 .24927 L
.30253 .27631 L
.30813 .34745 L
.31107 .38768 L
.31416 .42495 L
.31547 .43754 L
.31687 .44804 L
.31768 .4525 L
.31841 .45548 L
.31915 .45741 L
.31985 .45822 L
.32115 .45705 L
.32235 .45292 L
.32367 .44514 L
.32506 .43353 L
.32758 .40532 L
.32993 .37319 L
.33529 .29565 L
.34052 .23295 L
.34348 .20634 L
.34623 .18685 L
.34882 .17226 L
.35126 .16139 L
.35406 .15183 L
.35528 .14858 L
.35661 .14557 L
.35898 .14148 L
.36028 .13987 L
.36149 .13871 L
.36262 .13789 L
.36365 .13735 L
Mistroke
.36484 .13695 L
.36597 .13678 L
.36719 .13682 L
.36849 .1371 L
.36959 .13755 L
.37081 .13828 L
.37212 .13935 L
.37353 .14087 L
.37608 .14464 L
.37874 .15013 L
.38157 .15781 L
.38668 .1765 L
.39275 .20707 L
.39826 .24121 L
.40347 .27334 L
.4049 .2809 L
.40641 .28788 L
.40772 .29292 L
.40843 .29525 L
.40912 .29716 L
.41043 .29995 L
.41164 .30142 L
.41277 .30184 L
.41399 .30123 L
.41534 .2993 L
.41602 .29785 L
.41677 .29587 L
.41935 .28648 L
.43007 .22253 L
.43592 .18834 L
.44136 .16398 L
.44602 .1489 L
.44863 .14249 L
.451 .13778 L
.4536 .13373 L
.45497 .13203 L
.45643 .13053 L
.45769 .12944 L
.45909 .12846 L
.46037 .12776 L
.46155 .12726 L
.46284 .12685 L
.46353 .1267 L
.46426 .12657 L
.46561 .12645 L
.46683 .12646 L
.46803 .12658 L
.46932 .12682 L
.47054 .12716 L
.47166 .12757 L
Mistroke
.47418 .12884 L
.47695 .13077 L
.48253 .13623 L
.48743 .14253 L
.49268 .15079 L
.50216 .16908 L
.51286 .18959 L
.51579 .19407 L
.5189 .19788 L
.52018 .19911 L
.52156 .20019 L
.52235 .20068 L
.52307 .20106 L
.52382 .20137 L
.52449 .20159 L
.52573 .20181 L
.52704 .2018 L
.52826 .20159 L
.52941 .20121 L
.53076 .20056 L
.532 .19978 L
.53479 .19746 L
.54006 .19161 L
.54563 .18449 L
.54807 .18151 L
.55072 .17862 L
.55323 .17641 L
.55443 .17558 L
.55556 .17494 L
.55684 .1744 L
.55752 .1742 L
.55826 .17406 L
.55899 .174 L
.55975 .17401 L
.56113 .17426 L
.56238 .17475 L
.56355 .17545 L
.56484 .17651 L
.56621 .178 L
.5687 .18171 L
.57139 .18739 L
.57394 .19449 L
.57629 .20267 L
.58074 .22255 L
.58545 .24943 L
.59052 .28238 L
.59534 .31217 L
.59799 .3252 L
.5995 .33087 L
.60021 .33306 L
Mistroke
.60089 .3348 L
.60218 .33719 L
.60335 .33827 L
.60461 .33825 L
.60597 .33685 L
.60717 .33446 L
.60829 .33129 L
.61084 .32113 L
.61332 .30802 L
.61598 .29167 L
.62519 .23286 L
.63037 .20609 L
.63587 .18474 L
.63874 .17623 L
.64191 .16853 L
.64749 .15811 L
.65274 .15082 L
.65839 .14477 L
.66862 .13632 L
.67868 .12975 L
.68437 .12699 L
.68692 .12593 L
.68967 .12496 L
.69117 .12452 L
.69256 .12421 L
.69388 .12398 L
.69455 .12391 L
.69529 .12385 L
.69656 .12382 L
.69792 .12391 L
.69921 .12409 L
.70039 .12436 L
.70184 .12482 L
.70319 .12539 L
.70468 .12618 L
.70626 .12724 L
.70776 .1285 L
.70918 .12994 L
.71183 .13343 L
.71437 .13803 L
.71673 .14369 L
.71933 .15169 L
.72211 .16269 L
.72503 .17742 L
.72779 .19484 L
.73296 .23787 L
.74219 .3392 L
.74472 .36459 L
.74612 .37641 L
.74745 .38575 L
Mistroke
.74867 .39251 L
.75002 .3976 L
.75124 .40005 L
.75237 .40042 L
.7537 .39855 L
.75495 .39461 L
.75607 .38943 L
.75729 .38224 L
.76254 .33889 L
.76778 .2923 L
.77065 .27178 L
.77205 .26363 L
.77332 .25734 L
.77443 .25276 L
.77564 .24871 L
.77692 .24544 L
.77813 .24327 L
.77945 .24187 L
.78012 .24153 L
.78086 .24143 L
.78217 .24193 L
.7834 .24311 L
.78453 .24476 L
.78573 .24702 L
.78786 .25213 L
.79268 .26641 L
.79537 .27415 L
.7967 .27742 L
.79792 .27997 L
.79903 .28184 L
.80021 .28328 L
.80139 .28412 L
.80269 .2843 L
.8034 .28407 L
.80408 .28361 L
.80535 .28217 L
.80672 .27977 L
.80821 .2762 L
.8109 .26752 L
.81339 .25734 L
.82265 .21167 L
.82752 .18945 L
.83267 .17074 L
.83543 .16286 L
.83846 .15585 L
.84121 .15081 L
.84378 .14718 L
.84513 .14565 L
.84642 .14443 L
.84759 .14352 L
Mistroke
.84883 .14273 L
.85017 .14208 L
.85142 .14165 L
.85276 .14137 L
.85352 .14128 L
.85424 .14125 L
.85538 .14127 L
.85663 .14142 L
.85793 .14168 L
.85915 .14202 L
.86132 .14285 L
.86365 .14404 L
.86896 .14777 L
.87378 .15212 L
.88358 .1618 L
.88894 .16677 L
.89395 .17075 L
.89656 .17239 L
.89936 .17373 L
.90096 .17428 L
.90175 .17449 L
.90247 .17466 L
.90383 .17489 L
.90455 .17497 L
.90532 .17502 L
.90668 .17504 L
.90745 .17501 L
.90815 .17495 L
.90945 .17478 L
.91082 .17451 L
.91204 .17418 L
.91319 .17381 L
.91579 .17273 L
.93542 .15893 L
.9408 .15539 L
.94374 .15381 L
.94518 .15319 L
.9465 .15272 L
.9477 .15239 L
.94884 .15217 L
.95005 .15203 L
.95137 .15201 L
.95271 .15213 L
.95347 .15226 L
.95415 .15242 L
.95548 .15287 L
.95673 .15345 L
.95802 .15423 L
.95943 .15531 L
.96081 .15662 L
Mistroke
.96229 .15834 L
.96494 .16234 L
.96741 .16733 L
.97052 .17555 L
.97346 .18559 L
.97897 .21079 L
1 .32332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo
000Xooooo`Oo0000Q_ooool00ol0003oooooooooo`2`ooooo`009_ooool2o`0000Oooooo0_l00024
ooooo`03o`000?oooooooooo03[ooooo1?l0001booooo`009Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo07Cooooo1Ol00008ooooo`03o`000?oooooooooo03Oooooo0ol00004oooo
o`;o0000L?ooool002Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1cooooo`;o
00001?ooool2o`0000Kooooo0_l0000fooooo`;o00002?ooool00ol0003oooooooooo`1^ooooo`00
8oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo077ooooo0_l00006ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo06gooooo000Sooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0Dooo
ool3o`0001[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo03;ooooo0_l0000<ooooo`03o`000?oooooooooo06gooooo000Sooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool0DOooool2o`000003ooooool0003o000001Sooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`1/ooooo`008oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo057ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`00000booooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool09oooool5o`0003oooooo000Rooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo0000037ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0??ooool002;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1?oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0;oooo
o`04o`000?ooooooooooo`00037ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo00Gooooo0_l0000looooo`008Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo02Oooooo1_l0000Qooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo0000033ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool05?ooool4o`00027ooooo000Qooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool09_ooool2o`0000Gooooo0ol0000Nooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0=ooooo`04o`000?oooooo0000o`0002kooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool04Oooool3o`0000;ooooo0_l0000Pooooo`008?ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool01oooool2o`0001cooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00kooooo0_l0000^ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00kooooo0_l00007ooooo`03o`000?oooooooooo01gooooo000Pooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0:ooooo`;o0000
6_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
3_ooool2o`0002kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo01cooooo000Eooooo`;o000000[o410@ooooooooooooooooonk^k_lb<S;o0000oc8b
<_o^k^ko00005_ooool02?l0003ooooooooooonHV9So410@o`000?lb<S;oc<c<0oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^01Gooooo00?o0000ooooooooool00oooool5o`0000?ooooo00Gok^k^oc8b
<_l0003o0000onk^kP0Gooooo`03o`000?oooooooooo00;ooooo1?l000002?l@413o0000ooooooo^
k^ko<S8bo`000?lb<S;ok^k^2oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01oo
oooo1?l000002Ol@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^o`00000Hooooo`Ko00000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Kooooo00?o0000ooooooooool00_ooool01OnHV9So410@
o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o0000onk^kP0:ooooo`;o00002oooool00ol0
003oooooooooo`03ooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h0
3_ooool001Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So000001Oooooo
00So0000oooooooooooo410@okZj^_ooooooMgMgoc8b<P?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Eooooo`03o`000?oooooooooo00?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMg
MonHV9SooooooiRHV?l000005oooool00ol0003oooooooooo`04ooooo`0:o`000?ooooooooooo`00
0?ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHo`00000Iooooo`06
o`000?nHV9So8B4Qonk^k_ooooooA4A40oooool01OmgMgOoV9RHoooooonHV9SoMgMg01Kooooo00?o
0000ooooooooool00_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?oooooo
V9RHo`000009ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool000_ooooo1_l00002ooooo`Go
00000oooool01Ol@413ooooooooooooooooo000001;ooooo1_l00006ooooo`05o`000?oooooooooo
ooooool@41000oooool00ol@413oooooooooo`0Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP04
ooooo`04oa0@4?ooooooooooooooo`;o00004_ooool6o`0000Gooooo00Ko0000oooooooooooo0000
ooooool@4103ooooo`03oa0@4?oooooooooo00Wooooo00?o0000ooooooooool04?ooool2o`0002;o
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo000001Wooooo00Go0000oooo
oonHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41005Oooool00ol0003ooooooooo
o`07ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413o0000ooooo`06ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool01Ol00003ooooo`05oa0@4?ooooooooooooooool@
41003_ooool001?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo0000
01Sooooo00?o0000ooooooooool00_ooool00onYZJWo410@ooooo`02ooooo`05o`000?oooooooooo
ooooool000005?ooool00ol0003oooooooooo`06ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Co0000
oooooooooooooooo0_l0000Eooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooooooo
0_l00003ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04Oooool2o`00013ooooo
0ol0000?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_l0000Jooooo`05o`00
0?ooooooV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000001Gooooo00?o0000oooo
ooooool01_ooool00onYZJWo410@ooooo`02ooooo`06o`000?ooooooooooooooool0003ooooo1ol0
000Aooooo`06o`000?ooooooA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo0000
00kooooo000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`00000H
ooooo`07o`000?ooooooooooooooool@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool0
00005?ooool00ol0003oooooooooo`07ooooo`03ogMgMomVIVKooooo00;ooooo00Ko0000oooooooo
ooooooooo`000?ooool2o`0001?ooooo00?o0000ooooooooool01Oooool01?l0003ooooooooooooo
ool2o`0000?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooo000000kooooo00?o0000ooooooooool00_l0000>ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_l0000Jooooo`05o`000?ooooooooooogMgMomVIVH00oooool01Ol0003ooooo
oooooooooooo000001Cooooo00?o0000ooooooooool01_ooool00ol@413o0000okZj^P03ooooo`05
o`000?ooooooooooooooool000006Oooool01_l0003oooooomgMgOmEEEGoooooo`0000Cooooo00Go
0000ooooooooooooooooo`00000>ooooo`005?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oo
ooooooooooooool000006?ooool00ol0003oooooooooo`02ooooo`03okZj^_lQ8B7ooooo00;ooooo
00Go410@oooooooooooooooooa0@400Cooooo`03o`000?oooooooooo00Wooooo00Go0000oooooooo
oooooooooa0@4003ooooo`04oa0@4?ooooooooooo`0001?ooooo00?o0000ooooooooool01Oooool0
1_l0003ooooooooooooooooo0000oa0@40?ooooo00?o410@ooooooooool02?ooool00ol0003ooooo
ooooo`0Aooooo`?o00003Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool00_ooool01Ol@413oooooooooool0003o410@01[ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05oa0@4?ooooooooooooooool@41005?ooool00ol0003oooooooooo`07
ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@400Iooooo`06o`000?oo
ooooooooogMgMoo<c<co00001?ooool01Ol@413ooooooooooooooooo410@00kooooo000Dooooo`03
onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHo`00000Iooooo`06o`000?l@413oV9RH
oooooonj^[[o00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo00?o0000ooooooooool0
1Oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool01_ooool02_l0003ooooooooooooooooo
0000ogMgMonHV9SooooooiRHV?mgMgL:ooooo`03o`000?oooooooooo017ooooo00Co0000oooooooo
oooo00002_ooool2o`0000Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9So0000oiRHV?mgMgL06_ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0Dooooo`03o`000?oooooooooo00Cooooo00Go410@oiRHV?oooooo
^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool01Ol0003oooooonk^k_m4A4Co
000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`005Oooool00omgMgOo0000ooooo`03
ooooo`05onk^k_lb<S;o0000o`000?o^k^h06Oooool01_l0003oZJVYoa0@4?l0003o410@ojVYZ@?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Cooooo`03o`000?oooooooooo00Gooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00Cooooo00?oEEEEofIVI_l000001?ooool01Ol0003o<S8bo`00
0?lb<S;ok^k^00Wooooo00?o0000ooooooooool04_ooool01?l0003oooooooooool0000:ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool00omEEEGoIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h06_ooool01Ol0003o410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0Cooooo`03o`000?oooooooooo00Gooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06_ooool01Ol0003ooooooooooomgMgOo0000
00Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`007_ooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Boooo
o`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool06Oooool001kooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04_ooool01Ol0
003ooooooooooooooooo000000Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo01Wooooo000Nooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`0Iooooo`007_ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00?ooooo0_l00002ooooo`;o00002oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo01Wooooo000Nooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
1?ooool4o`0000gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Hooooo`005_oo
ooooo`00043o00004oooool001Kooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooool000001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooool000001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o
0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`0000Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l0
0006ooooo`03o`000?oooooooooo017ooooo000Fooooo`03o`000?oooooooooo00Cooooo0_l00007
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool00oooool00ol0003oooooo`00
0007ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`0000Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l0
0006ooooo`03o`000?oooooooooo017ooooo000Mooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Sooooo000Moooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo01Sooooo000Looooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Sooooo000Looooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo01Oooooo000Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01Oooooo000Looooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo01Oooooo000Looooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo01Cooooo0_l0000Hooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool05oooool001cooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool05oooool001_ooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool05_ooool001_ooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0;ooooo`?o00002_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Kooooo000K
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool02oooool01?l0003oooooo`000?l0
0009ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool05_ooool001_ooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`0;ooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`0Fooooo`006oooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool05_ooool001[ooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`02ooooo`?o00003_ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Eoooo
o`006_ooool00ol0003oooooooooo`0Sooooo`;o000000?oooooo`000?l000000oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05Oooool2o`0001Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool05Oooool001[ooooo00?o0000ooooooooool09?ooool3o`0000Cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Eooooo`006_ooool00ol0003ooooooooo
o`0[ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool05Oooool001[ooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo01Gooooo000Ioooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Doooo
o`006Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01Oooool01Ol0003ooooooooooooooooo000003Wooooo00?o0000ooooooooool05?ooool001Wo
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Go
oooo00Go0000ooooooooooooooooo`00000iooooo`03o`000?oooooooooo01Cooooo000Iooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool04oooool01Ol0003ooooooooooooooooo0000
01Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`04o`000?oooooooooo
o`0003Wooooo00?o0000ooooooooool05?ooool001Wooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Dooooo`05o`000?ooooooooooooooool000006Oooool2o`0001_ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool3o`0003[ooooo00?o0000ooooooooool05?ooool001Sooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Dooooo`05o`000?ooooooooooooooool000006Oooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool04oooool0
01Sooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Dooooo`05o`000?oooooooooo
ooooool000006Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Gooooo00?o0000
ooooooooool04oooool001Sooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Doooo
o`04o`000?ooooooooooo`0001[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`15
ooooo`03o`000?oooooooooo01?ooooo000Hooooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool05Oooool00ol0003oooooo`00000Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0AOooool00ol0003oooooooooo`0Cooooo`006?ooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooool000006_ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo04Gooooo00?o0000ooooooooool04oooool001Oooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00kooooo1Ol00006ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Booooo`005ooo
ool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Oooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A006ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0A_ooool00ol0003ooooo
ooooo`0Booooo`005oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Sooooo00?o
V9RHob4Q8Oo^k^h01oooool3o`0001_ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Aoooool00ol0003ooooooooo
o`0Booooo`005oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Wooooo00?oV9RH
ob4Q8Oo^k^h01_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Oooooo00?o0000
ooooooooool04_ooool001Oooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Zoooo
o`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`17oooo
o`03o`000?oooooooooo01;ooooo000Fooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0B?ooool00ol0003oooooooooo`0Aooooo`005_ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo02Oooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo01co
oooo00Go0000ooooooooooooooooo`00000Xooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0B?ooool00ol0003oooooooooo`0Aooooo`005_ooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo02Oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo
01cooooo00Go0000ooooooooooooooooo`00000Yooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0B?ooool00ol0003oooooooooo`0Aooooo`00C_ooool01Ol0003ooooooooooooooooo
000002Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo01cooooo00Co0000oooooooooooo0000:_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo05cooooo001>ooooo`05o`000?ooooooooooooooool000009Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool07Oooool00ol0003oooooo`00
000Zooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0GOooool004kooooo00Go0000
ooooooooooooooooo`00000Uooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<_oo
ool2o`0001kooooo00?o0000ooooool00000:_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo05gooooo001>ooooo`04o`000?ooooooooooo`0002Kooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo01gooooo0ol0000Zooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0GOooool004oooooo00?o0000ooooool000009_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0B_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo05gooooo001?ooooo`?o00009_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0B_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo05gooooo001hooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0GOooool007Sooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1Mooooo`00N?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool0B_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05gooooo001h
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`1;
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0GOooool007Sooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo04_ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Mooooo`00N?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo03?ooooo0_l0001<ooooo`05o`000?ooooooooooooooool00000H?ooool007So
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo04_o
oooo00Go0000ooooooooooooooooo`00001Pooooo`00NOooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool0Boooool01Ol0003ooooooooooooooooo0000
063ooooo001iooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`1;ooooo`05o`000?ooooooooooooooool00000H?ooool007Wooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo04_ooooo00Go0000oooooooo
ooooooooo`00001Pooooo`00NOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool0Boooool01Ol0003ooooooooooooooooo0000063ooooo001iooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`1;ooooo`05
o`000?ooooooooooooooool00000H?ooool007Wooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo04cooooo00Co0000oooooooooooo0000H?ooool007Wo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0cooooo`;o0000COooool00ol0003o
ooooo`00001Qooooo`00NOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool0C?ooool00ol0003oooooo`00001Qooooo`00NOooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0C?ooool00ol0003oooooo`00
001Qooooo`00NOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Cooooo00?o0000
ooooooooool0C?ooool00ol0003oooooo`00001Qooooo`00NOooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0COooool2o`00067ooooo001iooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0:oooool2o`000003oa0@4?oooooooooo00Co
oooo00?o0000ooooooooool0/?ooool007Wooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool007[ooooo00Go
0000ooooooooooooooooo`00000[ooooo`Go00001_ooool00ol0003oooooooooo`2`ooooo`00N_oo
ool01Ol0003ooooooooooooooooo000002_ooooo00CoA4A4omgMgOoooooo00001oooool3o`000;3o
oooo001jooooo`05o`000?ooooooooooooooool00000:oooool01?oMgMgoEEEEooooool00007oooo
o`03o`000?oooooooooo0;3ooooo001jooooo`05o`000?ooooooooooooooool00000;?ooool00omg
MgOoc<c<o`000007ooooo`03o`000?oooooooooo0;3ooooo001jooooo`04o`000?ooooooooooo`00
02gooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00N_ooool01?l0003o
ooooooooool0000^ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0/?ooool007[o
oooo00Co0000oooooooooooo0000=oooool00ol0003oooooooooo`2`ooooo`00N_ooool01?l0003o
ooooooooool0000gooooo`03o`000?oooooooooo0;3ooooo001jooooo`04o`000?ooooooooooo`00
03Oooooo00?o0000ooooooooool0/?ooool007[ooooo00Co0000oooooooooooo0000=oooool2o`00
0;7ooooo001jooooo`04o`000?ooooooooooo`0003Oooooo00?o0000ooooooooool0/?ooool007_o
oooo00?o0000ooooool00000=oooool00ol0003oooooooooo`2`ooooo`00Noooool00ol0003ooooo
o`00000gooooo`03o`000?oooooooooo0;3ooooo001kooooo`;o0000>?ooool00ol0003ooooooooo
o`2`ooooo`00Noooool2o`0003Sooooo00?o0000ooooooooool0/?ooool007_ooooo0_l0000hoooo
o`03o`000?oooooooooo0;3ooooo001looooo`03o`000?oooooooooo03Kooooo00?o0000oooooooo
ool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`oooo
o`00Z_ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[o
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05
o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`000;3ooooo002Zooooo`05o`000?mEEEGo0000oa0@
4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool00omEEEGoQhN7ooooo`08ooooo`03
o`000?oooooooooo0;3ooooo002Zooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0
/?ooool00:_ooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Oo<c<co8B4Qo`00
0?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go8B4QoiRHV?ooooooV9RH
ob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo
0ol0002`ooooo`00Z_ooool01Oo<c<co0000o`000?l0003oc<c<0;Wooooo002Zooooo`05oa0@4?nj
^[[ooooookZj^_l@4100^Oooool00:[ooooo00Go0000okZj^_oooooo^[Zjo`00002iooooo`00Z_oo
ool01OnYZJWo410@o`000?l@413oZJVY0;Wooooo003oooooofWooooo002_ooooo`03o`000?nj^[[o
oooo0;Kooooo002_ooooo`;o<S8b]oooool0083ooooo0_l000001_l@413oooooooooool@413o0000
oa0@41Sooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X06Oooool4o`000003
oa0@4?oooooooooo00;ooooo0_l000001?l@413oooooooooooooool5o`0007Sooooo0021ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool6o`0000gooooo00WoMgMgoc8b<_oo
ooooooooogMgMonHV9SooooooiRHV?mgMgL00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj
^[[ok^k^ogMgMol@41002Oooool6o`0000cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0N?ooool0087ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooooooooa0@40?ooooo00?o410@oooooooo
ool04?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo1Ol00004ooooo`03
oiRHV?lQ8B7ok^k^07Wooooo0021ooooo`06o`000?ooooooA4A4odA4A?oooooo00002Oooool6o`00
00gooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool02oooool6o`0000cooooo00?o0000ooooooooool00_ooool01?m4A4CogMgMooooool0
0006ooooo`03oiRHV?lQ8B7ok^k^07Sooooo0021ooooo`06o`000?oMgMgo<S8boeEEEOoMgMgo0000
6Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00000Boooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool00_ooool01?oMgMgoEEEEooooool00007
ooooo`03ogMgMomVIVKooooo07Oooooo0021ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo00006Ooo
ool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol@413o0000
o`000003o`0001cooooo00?o0000ooooooooool00oooool00omgMgOoc<c<o`000008ooooo`03o`00
0?oooooooooo07Kooooo0021ooooo`06o`000?lb<S;ooooooooooolb<S;o00006Oooool00ol0003o
ooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo00?ooooo00?ok^k^odA4A?l000001?ooool01Ol0003o^[ZjoooooonHV9So
410@07Sooooo0020ooooo`03oa0@4?l0003oQhN700;ooooo00?oQhN7o`000?l@41006?ooool4o`00
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Booooo`03o`000?oooooooooo01_ooooo00?oEEEE
ofIVI_l000001_ooool00omgMgOo0000ooooo`03ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0N?oo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(144) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30858 m
.00942 .23648 L
.01483 .19819 L
.01975 .17129 L
.02496 .15112 L
.02782 .14319 L
.03053 .13739 L
.03303 .13325 L
.03534 .13029 L
.03788 .12782 L
.03916 .12686 L
.04057 .12599 L
.04198 .12532 L
.04272 .12504 L
.04351 .12479 L
.04427 .12462 L
.04497 .1245 L
.04631 .12438 L
.04761 .12441 L
.04835 .12448 L
.04902 .12458 L
.05026 .12485 L
.05157 .12525 L
.05298 .1258 L
.05449 .12652 L
.05722 .12818 L
.06046 .13078 L
.06341 .13382 L
.06867 .14101 L
.0744 .15147 L
.08481 .17715 L
.08996 .19212 L
.09552 .20765 L
.09807 .21386 L
.10076 .2194 L
.10306 .22312 L
.10436 .22477 L
.10557 .22598 L
.10694 .22695 L
.10823 .22748 L
.10939 .22763 L
.11064 .22743 L
.11201 .22681 L
.1127 .22634 L
.11346 .22571 L
.11606 .22266 L
.11894 .21796 L
.12204 .21186 L
.12763 .19984 L
.13278 .18968 L
Mistroke
.13561 .18512 L
.13827 .18178 L
.13979 .18038 L
.14064 .17976 L
.14143 .17932 L
.14209 .17904 L
.14282 .17883 L
.14358 .17873 L
.14428 .17875 L
.14501 .17889 L
.14569 .17913 L
.14698 .17987 L
.14836 .18111 L
.14986 .18301 L
.15117 .18515 L
.1524 .18757 L
.15519 .19474 L
.15791 .20407 L
.16083 .21695 L
.16613 .2479 L
.17097 .28328 L
.17596 .32119 L
.17871 .33937 L
.18005 .34691 L
.18129 .35283 L
.18244 .35731 L
.1837 .36102 L
.18498 .36337 L
.18632 .3643 L
.18746 .3638 L
.18868 .36199 L
.18983 .3591 L
.19088 .35552 L
.19366 .34231 L
.19623 .32638 L
.20205 .28508 L
.20714 .25159 L
.21263 .22308 L
.21519 .21256 L
.21789 .20323 L
.22272 .19045 L
.22725 .18192 L
.2322 .17462 L
.25383 .14987 L
.2644 .13913 L
.27439 .13126 L
.27707 .12945 L
.27854 .12861 L
.27992 .12796 L
.2814 .12742 L
Mistroke
.28219 .1272 L
.28303 .12702 L
.2838 .1269 L
.28454 .12682 L
.28591 .12678 L
.28717 .12685 L
.28851 .12703 L
.28977 .1273 L
.29092 .12765 L
.29227 .12822 L
.29373 .12905 L
.29511 .13013 L
.29638 .13142 L
.29771 .13314 L
.29897 .13519 L
.30132 .1403 L
.30386 .14796 L
.30661 .15927 L
.30902 .17211 L
.31158 .18943 L
.31616 .2328 L
.32661 .38858 L
.32947 .42899 L
.33091 .44496 L
.33173 .45238 L
.33248 .45791 L
.33383 .46472 L
.33457 .46666 L
.33527 .46729 L
.33652 .46549 L
.33786 .45947 L
.33914 .45013 L
.34033 .43854 L
.34304 .40414 L
.34851 .32066 L
.35114 .28368 L
.35364 .25408 L
.35607 .23116 L
.35832 .215 L
.36047 .20372 L
.36167 .19901 L
.36276 .19565 L
.36395 .1929 L
.36524 .19098 L
.36646 .19014 L
.36758 .19016 L
.36878 .19101 L
.36989 .19254 L
.37111 .195 L
.37242 .1985 L
Mistroke
.37509 .20813 L
.37752 .21934 L
.38728 .27371 L
.38965 .28536 L
.3922 .29532 L
.39295 .2976 L
.39366 .29945 L
.395 .30204 L
.39625 .30337 L
.39762 .30353 L
.39839 .30302 L
.39911 .30215 L
.40046 .29953 L
.40122 .29751 L
.40192 .29531 L
.4035 .28929 L
.40896 .26004 L
.41402 .22867 L
.41944 .19801 L
.42478 .17416 L
.42965 .15876 L
.432 .15346 L
.43455 .14909 L
.43572 .14751 L
.43696 .14611 L
.43919 .14419 L
.44053 .14338 L
.44175 .14283 L
.44309 .14245 L
.44377 .14233 L
.44451 .14227 L
.44576 .1423 L
.4471 .14253 L
.44836 .14293 L
.4495 .14345 L
.45096 .1443 L
.45231 .14527 L
.45536 .14805 L
.46089 .15459 L
.47118 .16984 L
.47686 .17879 L
.48225 .18604 L
.48467 .18863 L
.48725 .19086 L
.48873 .19189 L
.49008 .19267 L
.49143 .19328 L
.4927 .19371 L
.49386 .19396 L
.49509 .19409 L
Mistroke
.49614 .19408 L
.49729 .19395 L
.49853 .19365 L
.49985 .19317 L
.50111 .19258 L
.50225 .19192 L
.51227 .18316 L
.52291 .17244 L
.52729 .16857 L
.532 .16525 L
.5347 .16377 L
.53717 .16263 L
.53968 .16166 L
.54201 .16091 L
.54428 .16035 L
.54554 .16012 L
.54669 .15996 L
.54795 .15985 L
.54932 .15981 L
.55061 .15986 L
.5518 .15997 L
.55303 .16016 L
.55418 .1604 L
.55544 .16075 L
.5568 .16121 L
.55956 .16249 L
.56208 .16411 L
.56487 .16659 L
.56744 .16972 L
.57027 .17436 L
.57328 .18097 L
.57588 .18832 L
.57832 .1968 L
.58389 .22273 L
.59419 .29327 L
.59691 .31284 L
.59981 .33092 L
.60122 .33798 L
.60256 .34334 L
.60375 .34692 L
.60505 .34937 L
.60616 .35023 L
.60739 .34982 L
.60867 .34786 L
.60987 .34464 L
.61099 .34049 L
.61201 .33579 L
.61432 .32243 L
.62447 .24253 L
.62947 .20655 L
Mistroke
.63481 .1768 L
.63985 .15643 L
.64441 .14328 L
.64721 .13721 L
.64979 .13271 L
.65257 .12879 L
.65562 .12536 L
.65809 .12312 L
.66075 .12117 L
.66355 .11958 L
.66617 .11851 L
.66745 .11811 L
.66886 .11776 L
.66957 .11762 L
.67034 .11749 L
.67172 .11732 L
.67303 .11722 L
.6744 .11719 L
.67557 .11722 L
.67686 .1173 L
.67764 .11739 L
.67838 .11749 L
.67977 .11774 L
.68126 .11812 L
.68288 .11865 L
.68579 .11997 L
.68848 .12164 L
.69337 .12594 L
.69615 .12921 L
.69874 .13292 L
.70398 .1428 L
.70961 .15777 L
.75296 .26855 L
.75556 .2633 L
.75692 .26083 L
.75837 .2586 L
.75963 .25708 L
.76102 .25598 L
.76228 .25556 L
.76345 .25573 L
.76422 .25616 L
.76494 .2568 L
.76629 .25865 L
.76704 .26008 L
.76774 .26164 L
.76932 .26609 L
.77189 .27608 L
.77463 .2902 L
.77962 .32289 L
.78237 .34214 L
Mistroke
.78499 .35882 L
.78742 .37106 L
.78879 .37603 L
.79007 .37915 L
.79125 .38061 L
.79232 .38072 L
.79355 .37935 L
.79471 .37662 L
.79582 .37276 L
.79704 .36719 L
.79949 .3522 L
.80389 .31684 L
.81382 .23504 L
.81907 .20452 L
.82202 .19193 L
.82471 .18299 L
.82721 .17661 L
.82853 .17391 L
.82993 .17148 L
.83115 .16972 L
.8325 .1681 L
.83365 .16697 L
.83488 .16599 L
.83615 .1652 L
.83734 .16464 L
.83807 .16438 L
.83875 .16418 L
.84003 .16394 L
.84139 .16384 L
.84264 .16389 L
.84401 .16407 L
.8447 .16421 L
.84546 .16441 L
.84788 .16522 L
.85048 .16638 L
.85517 .16881 L
.86104 .17175 L
.86393 .17298 L
.86661 .17394 L
.86903 .17461 L
.87039 .17488 L
.87161 .17506 L
.87296 .17518 L
.87372 .1752 L
.87442 .1752 L
.87571 .17512 L
.87707 .17495 L
.87835 .17469 L
.87975 .17432 L
.88228 .1734 L
Mistroke
.88703 .17097 L
.89258 .1671 L
.89771 .16267 L
.91697 .14452 L
.92184 .14052 L
.92709 .13695 L
.9295 .13561 L
.93204 .13442 L
.93421 .1336 L
.93535 .13325 L
.93658 .13294 L
.93735 .13279 L
.93805 .13268 L
.93943 .13254 L
.94068 .13253 L
.94201 .13264 L
.9427 .13275 L
.94343 .13292 L
.94477 .13334 L
.94558 .13367 L
.94635 .13405 L
.9478 .13493 L
.95039 .13712 L
.95279 .13995 L
.95542 .14411 L
.95822 .15003 L
.96085 .15723 L
.96362 .16685 L
.96858 .19006 L
.97391 .22409 L
.97976 .26915 L
.98482 .30644 L
.98628 .31519 L
.98766 .32215 L
.98889 .32715 L
.99024 .33106 L
.99141 .33309 L
.9927 .33378 L
.99405 .33274 L
.99531 .33016 L
.99649 .32641 L
.99757 .32192 L
1 .30858 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo03;ooooo
1_l0001hooooo`00]Oooool00ol0003oooooooooo`0`ooooo`;o00001Oooool3o`0007Kooooo000T
ooooo`?o0000S_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0M?ooool002;ooooo0_l00002ooooo`;o0000Aoooool4o`0004;ooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo07?ooooo000Qooooo`03
o`000?oooooooooo00Cooooo0_l00014ooooo`03o`000?oooooooooo00;ooooo0_l00010ooooo`;o
0000;_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo07;ooooo000Pooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0?oooool2o`0000Kooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
B?ooool5o`0002Cooooo000Oooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04Gooooo0ol00004ooooo`;o00008ooo
ool001oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0looooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo023ooooo000Oooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo02Wooooo1?l0000?ooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool08?ooool001oooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0:?ooool2o`0000;o
oooo0_l0000>ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`10ooooo`;o00002oooool00ol0003oooooooooo`0Oooooo`007_ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo01oooooo000Nooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool07_ooool001kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00[ooooo0_l0000[ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0??ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01kooooo000Moooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0joooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool07Oooool001gooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02_ooool7o`0001Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0iooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool07Oooool001Gooooo0_l000002Ol@413ooooo
ooooooooooook^k^oc8b<_l0003o<S8bonk^kP0?ooooo`03o`000?oooooooooo00Sooooo00GoV9RH
oa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h06oooool5o`0000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo017ooooo1?l000002?l@413o
ooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01oooool3o`0000Oooooo00?o0000ooooooooool02ooo
ool4o`000005oa0@4?ooooooooooonk^k_lb<S800_l000000oo^k^koooooooooo`0Dooooo`04o`00
0?ooooooooooooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Kooooo1Ol000001OnH
V9So410@o`000?lb<S;oc<c<00?ooooo00Ook^k^oc8b<_l0003o<S8bonk^k_oooooo000001Cooooo
00?o0000ooooooooool01?ooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;o
k^k^00kooooo000Fooooo`03o`000?oooooooooo00;ooooo00GoMgMgo`000?ooooooV9RHogMgM`0?
ooooo`03o`000?oooooooooo00Sooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL06oooool01Ol0003o8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`09ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo0000ogMgM`0Fooooo`09o`000?oo
oooooooooooooonHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0E
ooooo`03o`000?oooooooooo00;ooooo1?l000000omgMgOo<S8booooo`02ooooo`04ogMgMonHV9So
oooooiRHV0;o00005Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0>ooooo`002oooool6o`0000;ooooo1Ol00003ooooo`05oa0@4?l0
003oooooooooool@41004?ooool00ol0003oooooo`000005o`0000Kooooo00Go0000oooooooooooo
oooooa0@4003ooooo`03oa0@4?oooooooooo017ooooo1_l000001_oooooo0000oooooonHV9So8B4Q
onk^kPCooooo00Go410@oooooooooooooooooa0@4009ooooo`03o`000?oooooooooo00Oooooo1_l0
0005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`05oa0@
4?oooooo0000ooooool@41005_ooool00ol0003oooooooooo`02ooooo`03oiRHV?lQ8B7ok^k^00Co
oooo00Go410@oooooooooooooooooa0@400Dooooo`03o`000?oooooooooo00Oooooo0_l00003oooo
o`05oa0@4?ooooooooooo`000?l@41005_ooool00ol0003oooooooooo`02ooooo`Go00000oooool0
1Ol@413ooooooooooooooooo410@00kooooo000Cooooo`04odA4A?oMgMgoooooo`0000Cooooo0_l0
0002ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02_ooool00onYZJWo410@oooo
o`02ooooo`05o`000?ooooooooooooooool000006Oooool01ol0003oooooooooooooooooV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool01Ol0003oooooo`00
0?oooooo000001Oooooo00?o0000ooooooooool00_ooool00onHV9So8B4Qonk^kP03ooooo`05o`00
0?ooooooooooooooool000004oooool00ol0003oooooooooo`08ooooo`05ojVYZOl0003o0000o`00
0?ooool00ol000000ooooooo0000ooooo`0Eooooo`03o`000?oooooooooo00;ooooo00CoA4A4omgM
gOoooooo00001?ooool01Ol0003ooooooooooooooooo000000kooooo000Cooooo`04omgMgOmEEEGo
ooooo`0000Cooooo0_l00002ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02?oo
ool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000006Oooool00ol0003ooooo
ooooo`02ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000009ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooool0003oooooo`00000Gooooo`03o`000?oooooooooo00?ooooo00?oMgMg
ofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000001?ooooo00?o0000ooooooooool01ooo
ool00ol@413o0000okZj^P02ooooo`;o00000oooool00ol0003oooooooooo`0Eooooo`08o`000?oo
oooooooooooooooMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool0
01Cooooo00?oMgMgolc<c?l000001?ooool01Ol0003ooooooooooooooooo410@017ooooo00?o0000
ooooooooool02Oooool00onj^[[o8B4Qooooo`02ooooo`Co000000?o410@ooooooooool05_ooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413ooooooooo
o`07ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@00Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`04ooooo`;o0000
0oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
0_ooool01Ol@413oooooo`000?oooooo410@01Oooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo410@00?ooooo00?o410@ooooooooool04Oooool00ol0003oooooooooo`08oooo
o`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@400Gooooo`03o`000?oooooo
oooo00;ooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00kooooo000D
ooooo`03onk^k_m4A4Co000000Cooooo00Go0000oiRHV?ooooooV9RHogMgM`0Aooooo`03o`000?oo
oooooooo00Kooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05o`000?nHV9Soooooo`000?mg
MgL05oooool02Ol0003ooooooooooooooooo0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9So0000oiRHV?mgMgL06?ooool01ol0003oooooo`000?nj
^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000oooooooo
ool01_ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0G
ooooo`03o`000?oooooooooo00;ooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00kooooo000Eooooo`03ogMgMol0003ooooo00?ooooo00Go0000oc8b<_l0003o<S8bonk^
kP0Booooo`03o`000?oooooooooo00Gooooo00GoZJVYoa0@4?l0003o410@ojVYZ@02ooooo`06o`00
0?o^k^ko<S8bo`000?lb<S;o00005oooool02Ol0003oooooooooooooooooV9RHoa0@4?l0003o8B4Q
olc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02_ooool00ol0003oooooooooo`0?ooooo`03
oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0000Dooooo`03o`000?oooooo
oooo00Oooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko0000o`000?lb<S;ok^k^01Sooooo00Oo
0000oooooonHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Boooo
o`03o`000?oooooooooo00Kooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h06?ooool00ol0003oooooooooo`02ooooo`03ogMgMol0003ooooo00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0>ooooo`006oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool03_ooool2o`00013ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooo000001Gooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`0Kooooo`006oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool03_ooool2o`00013ooooo00?o0000ooooooooool04_ooool6
o`0001Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Kooooo`006_ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03Oooool01?l0
003oooooooooool0000>ooooo`03o`000?oooooooooo01Gooooo0ol0000Hooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool06oooool001[ooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo00gooooo00Co0000oooooooooooo00003_ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`0Kooooo`006_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool03Oooool01?l0003oooooooooool0000>ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo01[ooooo000Foooooooo0000@?l0000Cooooo`005_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooool000001_ooool00ol0003oooooooooo`05ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Go
oooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l00005ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003o
ooooooooo`0Aooooo`005_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool0
00001_ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool0
1Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo0_l00005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003oooooooooo`0Aooooo`006_oo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool06_oo
ool001[ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo01Wooooo000Iooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`0Iooooo`006Oooool00ol0003oooooooooo`0Jooooo`;o00000oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`0Iooooo`006Oooool00ol0003oooooooooo`0Kooooo`Co00003oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool06Oooool001Wooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool06Oooool001Wooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06?ooool2o`0001Wooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`0Iooooo`006Oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Hoooo
o`006Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`0Hooooo`006Oooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Hooooo`006Ooo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`0Hooooo`006Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Hooooo`006?ooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`0Hooooo`006?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00;o
oooo0_l0000>ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06?ooool001Sooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool06_ooool2o`0001[ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo00Co00003Oooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooooooo01Oooooo000Hooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Gooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0
5oooool001Sooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool09Oooool00ol0003oooooo`000004ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Gooooo`006?ooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo01Oooooo000Hooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
01Oooooo000Gooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo01Oooooo000Gooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo01Oooooo
000Gooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo01Oooooo000Gooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01_ooooo0_l0000L
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool05oooool001Oooooo00?o0000oooo
ooooool0<_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0:ooooo`05o`000?ooooooooooooooool000007_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool05oooool0
01Oooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`05o`000?oooooooooo
ooooool000007_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Gooooo00?o0000
ooooooooool05_ooool001Oooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;oooo
o`04o`000?ooooooooooo`0001kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo01Kooooo000Gooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02oooool01?l0003oooooo`000?l0000Nooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`0Fooooo`005_ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooool000007oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo03Gooooo00?o0000ooooooooool05_ooool001Kooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0;ooooo`?o00005?ooool5o`0000Kooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo01Kooooo000Fooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool08_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Ko
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo01Ko
oooo000Fooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08oooool00onHV9So8B4Q
onk^kP07ooooo`?o00007?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool04Oooool004gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09?ooool00onHV9So8B4Qonk^
kP06ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=oooool01Ol0003ooooooooo
oooooooo000001?ooooo001>ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Gooooo00?oMgMgofIVI_ooool01Ooo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Oooooo00Go0000oooooooooooooooo
o`00000Cooooo`00C_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0gooooo`04o`000?ooooooooooo`0001Cooooo
001>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo02;ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0booooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0=oooool01?l0003oooooooooool0000Dooooo`00
C_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Rooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003o
ooooooooo`0Mooooo`05o`000?ooooooooooooooool00000=?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo03Oooooo00Co0000oooooooooooo00005?ooool004kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`0Mooooo`05o`000?ooooooooooooooool00000=?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooool000005?ooool0
04kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Mooooo`05o`000?oooooooooo
ooooool00000=?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Wooooo00?o0000
ooooool000005?ooool004oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;Oooool2o`0001kooooo00Go0000oooo
ooooooooooooo`00000dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0>Oooool2
o`0001Gooooo001?ooooo`05o`000?ooooooooooooooool00000:Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool07Oooool01Ol0003ooooooooooooo
oooo000003Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1@ooooo`00Coooool0
1Ol0003ooooooooooooooooo000002Wooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo01gooooo00Co0000oooooooooooo0000=_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo053ooooo001?ooooo`05o`000?ooooooooooooooool00000
:Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
7_ooool00ol0003oooooo`00000fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
D?ooool004oooooo00Go0000ooooooooooooooooo`00000Yooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo000003Kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Aooooo`00Coooool01Ol0003ooooooooo
oooooooo000002Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo01kooooo0_l0000gooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
DOooool004oooooo00Co0000oooooooooooo0000:_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool0F?ooool01Ol0003ooooooooooooooooo000005?o
oooo001?ooooo`04o`000?ooooooooooo`0002[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0^ooooo`03o`000?oooooooooo05Sooooo00Go0000ooooooooooooooooo`00001Coooo
o`00D?ooool00ol0003oooooo`00000Zooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`1Hooooo`05o`000?ooooooooooooooool00000Doooool0053o
oooo0ol0000Zooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;_ooool2o`0005Wo
oooo00Co0000oooooooooooo0000E?ooool0057ooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0F?ooool01?l0003o
ooooooooool0001Dooooo`00OOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool0F?ooool01?l0003oooooooooool0001Dooooo`00O_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0F?ooool01?l0003o
ooooooooool0001Dooooo`00O_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool0FOooool00ol0003oooooo`00001Dooooo`00O_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0FOooool00ol0003ooooo
o`00001Dooooo`00O_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool0F_ooool00ol0003oooooooooo`1Cooooo`00O_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0/?ooool007kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0_ooooo`;o0000/Oooool007kooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo0;3ooooo001nooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`2`ooooo`00O_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0/?oo
ool007kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo0;3ooooo001nooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09_ooool2o`00
0003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0/?ooool007kooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0/?ooool007oooooo00Go0000ooooooooooooooooo`00000Vooooo`Go00001_ooool00ol0003o
ooooooooo`2`ooooo`00Ooooool01Ol0003ooooooooooooooooo000002Kooooo00CoA4A4omgMgOoo
oooo00001oooool3o`000;3ooooo001oooooo`05o`000?ooooooooooooooool000009_ooool01?oM
gMgoEEEEooooool00007ooooo`03o`000?oooooooooo0;3ooooo001oooooo`05o`000?oooooooooo
ooooool000009oooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo0;3ooooo001ooooo
o`04o`000?ooooooooooo`0002Sooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`
ooooo`00Ooooool01?l0003oooooooooool0000Yooooo`03ogMgMol0003ooooo00Kooooo00?o0000
ooooooooool0/?ooool007oooooo00Co0000oooooooooooo0000<_ooool00ol0003oooooooooo`2`
ooooo`00Ooooool01?l0003oooooooooool0000booooo`03o`000?oooooooooo0;3ooooo001ooooo
o`04o`000?ooooooooooo`0003;ooooo00?o0000ooooooooool0/?ooool007oooooo00Co0000oooo
oooooooo0000<_ooool2o`000;7ooooo001oooooo`04o`000?ooooooooooo`0003;ooooo00?o0000
ooooooooool0/?ooool007oooooo00Co0000oooooooooooo0000<_ooool00ol0003oooooooooo`2`
ooooo`00Ooooool01?l0003oooooooooool0000booooo`03o`000?oooooooooo0;3ooooo001ooooo
o`04o`000?ooooooooooo`0003;ooooo00?o0000ooooooooool0/?ooool007oooooo00Co0000oooo
oooooooo0000<_ooool00ol0003oooooooooo`2`ooooo`00Ooooool00ol0003oooooo`00000coooo
o`03o`000?oooooooooo0;3ooooo0020ooooo`;o0000<oooool00ol0003oooooooooo`2`ooooo`00
P?ooool2o`0003?ooooo0_l0002aooooo`00P?ooool2o`0003?ooooo00?o0000ooooooooool0/?oo
ool0083ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05onk^k_lb<S;o0000oa0@
4?o<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OmEEEGoMgMgoooooonHV9So8B4Q
00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo0;3ooooo002Zooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`00
0;3ooooo002Zooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2`oooo
o`00Z_ooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03omgM
gOl@413oV9RH00Sooooo00?o0000ooooooooool0/?ooool00:_ooooo00Coc<c<odA4A?l0003o410@
1_ooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo
002Zooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_oo
ool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0002`ooooo`00Z_ooool01Oo<c<co0000o`00
0?l0003oc<c<0;Wooooo002Zooooo`05oa0@4?nj^[[ooooookZj^_l@4100^Oooool00:[ooooo00Go
0000okZj^_oooooo^[Zjo`00002iooooo`00Z_ooool01OnYZJWo410@o`000?l@413oZJVY0;Wooooo
003oooooofWooooo002_ooooo`03o`000?nj^[[ooooo0;Kooooo002_ooooo`;o<S8b]oooool0083o
oooo0_l000001_l@413oooooooooool@413o0000oa0@41Sooooo00GoA4A4o`000?l0003o<S8bomgM
g@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOo0000okZj^P0<ooooo`05oiRH
V?l0003o0000odA4A?nj^[X06Oooool4o`000003oa0@4?oooooooooo00;ooooo0_l000000ol@413o
ooooooooo`03ooooo`;o000000?o410@ooooooooool0M_ooool0087ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`07ooooo`Ko00003Oooool02OmgMgOo<S8booooooooooooMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`03olc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@
4009ooooo`Ko00003?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0Moooool0087ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0K
ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool04?ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo00;ooooo1Ol00003ooooo`Go0000N?ooool0087ooooo00Ko0000
oooooom4A4CoA4A4ooooool00009ooooo`Ko00003Oooool01OmgMgOo<S8boooooooooooo000000?o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`Ko00003?ooool00ol0003o
ooooooooo`02ooooo`04odA4A?oMgMgoooooo`0000Cooooo00CoA4A4omgMgOoooooo0000NOooool0
087ooooo00Ko0000omgMgOlb<S;oEEEEomgMgOl0000Iooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
0_ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`02ooooo`04omgMgOmEEEGoooooo`0000Cooooo00CogMgMoeEEEOoooooo0000NOooool0
087ooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Iooooo`03o`000?oooooooooo00Cooooo00Go
410@oooooooooooooooooa0@400@ooooo`03oa0@4?l0003o000000?o00007?ooool00ol0003ooooo
ooooo`03ooooo`03ogMgMoo<c<co000000Gooooo00?oMgMgolc<c?l00000NOooool0087ooooo00Ko
0000oc8b<_oooooooooooc8b<_l0000Iooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0Booooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00oooool00oo^
k^koA4A4o`000005ooooo`03onk^k_m4A4Co000007Wooooo0020ooooo`03oa0@4?l0003oQhN700;o
oooo00?oQhN7o`000?l@41006?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Boooo
o`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000001_ooool00omgMgOo0000ooooo`05oooo
o`03ogMgMol0003ooooo07Sooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(146) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .23782 m
.00488 .20386 L
.00942 .17911 L
.01199 .16822 L
.01441 .15984 L
.01721 .15226 L
.01975 .1471 L
.02227 .1434 L
.02354 .14201 L
.02494 .1408 L
.02613 .14003 L
.02741 .13945 L
.02862 .13911 L
.02973 .13898 L
.03111 .13903 L
.03239 .13928 L
.03312 .13952 L
.03379 .13978 L
.03529 .14056 L
.03659 .14144 L
.03801 .1426 L
.04057 .14521 L
.04591 .1526 L
.05177 .16333 L
.06361 .19013 L
.0689 .20168 L
.07181 .20707 L
.07457 .21126 L
.07714 .21419 L
.07859 .21539 L
.07993 .2162 L
.08105 .21665 L
.08229 .21689 L
.08359 .21688 L
.08481 .21661 L
.08604 .21611 L
.08736 .21531 L
.08974 .21328 L
.09256 .21002 L
.09513 .20646 L
.106 .18938 L
.1108 .18286 L
.11332 .18 L
.116 .17746 L
.11833 .17567 L
.1209 .17415 L
.12203 .17363 L
.12324 .17317 L
.12437 .17282 L
.12543 .17256 L
Mistroke
.1261 .17243 L
.12683 .17233 L
.1281 .17221 L
.12883 .17218 L
.12959 .17217 L
.13095 .17223 L
.13221 .17236 L
.13339 .17254 L
.13468 .1728 L
.13607 .17313 L
.13919 .1741 L
.14214 .17525 L
.14766 .178 L
.15292 .18153 L
.15778 .18614 L
.16032 .18942 L
.16311 .19404 L
.16603 .20033 L
.16877 .20796 L
.18821 .32562 L
.19095 .34541 L
.19354 .3606 L
.19497 .3669 L
.19577 .36966 L
.19652 .37166 L
.19783 .37384 L
.19849 .37426 L
.19922 .37418 L
.20055 .37257 L
.20177 .36946 L
.20244 .36708 L
.20317 .364 L
.20451 .35711 L
.20707 .33988 L
.20945 .32047 L
.21946 .23228 L
.22517 .19337 L
.22797 .17847 L
.23053 .167 L
.2357 .14939 L
.23841 .14254 L
.24128 .1367 L
.24673 .12844 L
.24982 .12501 L
.2527 .12246 L
.25527 .12064 L
.25799 .1191 L
.26098 .11779 L
.26373 .11685 L
.26629 .11617 L
Mistroke
.26752 .11592 L
.26869 .11572 L
.27007 .11555 L
.27132 .11544 L
.27268 .11539 L
.27344 .11539 L
.27415 .11541 L
.27538 .11548 L
.27671 .11563 L
.27796 .11582 L
.27911 .11605 L
.28129 .11662 L
.2836 .11744 L
.28608 .1186 L
.2884 .12001 L
.29094 .12199 L
.29366 .12474 L
.29636 .12821 L
.29922 .13287 L
.30436 .14443 L
.30721 .1531 L
.30988 .16304 L
.31598 .19342 L
.32608 .26672 L
.33179 .31121 L
.33458 .32897 L
.33711 .34106 L
.33835 .34529 L
.33968 .34855 L
.34095 .35035 L
.34211 .35092 L
.34335 .35045 L
.3447 .34875 L
.34539 .34747 L
.34612 .34583 L
.34745 .34224 L
.35303 .32289 L
.35436 .31845 L
.35577 .31424 L
.357 .3112 L
.35832 .30865 L
.35964 .30697 L
.36087 .30624 L
.36208 .30636 L
.36318 .30722 L
.36441 .309 L
.36576 .31193 L
.36717 .31602 L
.36848 .32067 L
.3733 .3425 L
Mistroke
.37542 .3527 L
.37776 .36274 L
.37899 .36709 L
.38032 .37076 L
.38105 .37226 L
.38172 .37328 L
.38304 .37423 L
.38376 .37412 L
.38444 .37361 L
.38518 .37257 L
.38597 .37093 L
.38673 .36886 L
.38744 .36645 L
.38877 .36084 L
.39137 .34609 L
.39377 .3291 L
.39918 .28532 L
.40409 .24759 L
.40867 .21902 L
.41344 .19742 L
.41597 .18917 L
.41869 .18248 L
.42137 .17775 L
.42273 .17599 L
.42423 .17446 L
.4255 .17348 L
.42688 .17272 L
.42817 .17225 L
.42936 .17201 L
.43004 .17195 L
.43076 .17194 L
.43206 .17205 L
.43286 .1722 L
.43361 .1724 L
.43502 .17287 L
.43788 .17421 L
.44098 .17606 L
.45103 .18252 L
.45379 .18402 L
.45675 .18538 L
.45819 .18592 L
.45955 .18637 L
.46089 .18673 L
.4621 .18699 L
.46339 .1872 L
.46461 .18734 L
.46589 .18741 L
.46728 .18742 L
.4685 .18737 L
.46978 .18727 L
Mistroke
.47088 .18714 L
.47208 .18696 L
.4748 .18643 L
.47771 .18568 L
.48296 .18389 L
.49452 .17859 L
.50505 .17253 L
.52682 .15496 L
.53638 .14643 L
.54146 .14236 L
.54413 .14043 L
.54693 .13867 L
.54945 .13741 L
.55087 .13686 L
.5522 .13648 L
.55342 .13623 L
.55453 .1361 L
.55581 .13608 L
.55702 .13619 L
.55817 .13641 L
.55938 .1368 L
.56042 .13725 L
.56156 .13791 L
.56279 .13881 L
.5641 .14005 L
.56648 .14307 L
.56786 .14538 L
.56914 .14793 L
.57204 .15538 L
.5746 .16416 L
.57732 .1761 L
.58202 .2041 L
.58722 .24672 L
.59237 .29746 L
.59518 .32459 L
.59779 .34625 L
.59895 .354 L
.60003 .36007 L
.60129 .36539 L
.60243 .36853 L
.60369 .37001 L
.60486 .36948 L
.60614 .3668 L
.6075 .36166 L
.60885 .35436 L
.61009 .346 L
.61288 .32252 L
.61792 .27196 L
.62347 .21939 L
.62652 .1958 L
Mistroke
.62939 .17749 L
.63199 .16394 L
.63481 .1522 L
.63737 .14384 L
.63973 .13781 L
.64195 .13336 L
.6444 .12965 L
.64563 .12817 L
.64695 .12683 L
.64933 .125 L
.65078 .12419 L
.65213 .12363 L
.65283 .1234 L
.65361 .1232 L
.65441 .12305 L
.65517 .12296 L
.65585 .12292 L
.65656 .12291 L
.65784 .123 L
.65921 .12324 L
.65999 .12343 L
.66071 .12365 L
.66334 .12475 L
.66573 .12613 L
.66828 .128 L
.67109 .13053 L
.67618 .13654 L
.68157 .14522 L
.68657 .15569 L
.69124 .16771 L
.70244 .20409 L
.70796 .22291 L
.71065 .23109 L
.71308 .2375 L
.71562 .24289 L
.71679 .24483 L
.71802 .24649 L
.71933 .2478 L
.72054 .24857 L
.72185 .24892 L
.72259 .24891 L
.72327 .24875 L
.72397 .24846 L
.72472 .248 L
.72608 .24677 L
.72741 .24512 L
.72864 .24324 L
.73439 .2309 L
.74376 .20653 L
.74646 .20034 L
Mistroke
.74903 .19525 L
.75136 .19143 L
.75385 .18832 L
.75517 .1871 L
.75636 .18627 L
.75757 .1857 L
.7587 .18542 L
.76002 .18543 L
.76124 .18575 L
.76258 .18649 L
.76325 .18701 L
.76399 .18771 L
.76636 .19087 L
.76769 .19328 L
.7689 .19591 L
.77349 .20993 L
.77626 .22173 L
.77882 .23509 L
.78461 .27383 L
.78968 .31472 L
.79234 .33639 L
.79514 .35712 L
.79766 .37219 L
.79908 .3787 L
.80041 .38322 L
.80163 .38595 L
.80274 .3872 L
.80403 .38714 L
.80524 .38564 L
.80639 .38296 L
.80761 .37886 L
.80979 .36866 L
.81472 .33624 L
.82514 .2635 L
.82815 .24742 L
.831 .2346 L
.83635 .2162 L
.84144 .2038 L
.84617 .19501 L
.85688 .17881 L
.8761 .15238 L
.88721 .13954 L
.89266 .13434 L
.89767 .13031 L
.90215 .12728 L
.90707 .12455 L
.912 .12245 L
.9147 .12159 L
.91722 .12099 L
.91855 .12074 L
Mistroke
.91995 .12055 L
.92116 .12043 L
.92248 .12035 L
.92323 .12034 L
.92391 .12034 L
.92465 .12037 L
.92544 .12042 L
.92676 .12057 L
.92751 .12069 L
.92821 .12083 L
.92956 .12118 L
.93084 .1216 L
.93324 .12268 L
.93582 .12432 L
.93861 .12677 L
.94096 .12946 L
.94354 .13325 L
.94624 .13834 L
.94875 .14437 L
.95326 .15891 L
.9581 .18103 L
.96344 .21428 L
.96839 .25215 L
.97143 .27656 L
.97428 .29809 L
.97705 .31563 L
.97827 .32174 L
.9796 .32708 L
.9808 .33054 L
.98192 .33256 L
.98309 .33338 L
.98435 .33274 L
.98574 .33026 L
.98704 .32629 L
.98821 .32148 L
.98949 .31505 L
.99495 .2774 L
1 .23782 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00KOooool00ol0003oooooooooo`0jooooo`05o`000?nj^[[ooooooiRHV?l@4100
1_ooool00ol0003oooooooooo`2`ooooo`00JOooool8o`0003Wooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c006ooooo`03o`000?oooooooooo0;3ooooo001Wooooo`;o00002?ooool2o`0004;ooooo00?o
0000ooooooooool0POooool6o`0002Wooooo001Vooooo`03o`000?oooooooooo00Wooooo0_l00011
ooooo`03o`000?oooooooooo02gooooo1Ol0001<ooooo`?o00001_ooool2o`0002Oooooo001Uoooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Aoooool2o`0000_ooooo00?o0000oooo
ooooool09?ooool006Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0nooooo`;o
0000;?ooool00ol0003oooooooooo`04ooooo`;o0000Aoooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo02Cooooo001Tooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
?Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
A?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02?ooooo001Sooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0=ooooo`Co00006Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo047ooooo0_l0000?ooooo`03o`000?oo
oooooooo02?ooooo000Nooooo`?o0000@_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool02oooool2o`0000?ooooo0_l0000Gooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo02;ooooo000Mooooo`;o00000_ooool2o`0003oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0looooo`03o`000?oooooooooo00Wooooo0_l00007ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool08_ooool001gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0looooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Qooooo`007?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo027ooooo
000Kooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0>_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0jooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool08Oooool001_ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0>oooool2o`0000Gooooo0_l0000>ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool08?ooool001[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo03Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Poooo
o`006_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo023ooooo000Eooooo`;o0000
00Wo410@oooooooooooo0000onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`0A
ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Sooooo
00?o0000ooooooooool01Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02Oooool00ol0003o
ooooooooo`0@ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQkooooo00Go
0000ooooooooooooooooo`00000Cooooo`03o`000?oooooooooo00Oooooo1?l000001?l@413ooooo
ooooooo^k^h2o`000003oc8b<_o^k^kooooo00gooooo00?o0000ooooooooool02Oooool5o`0000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`0=oiRHV?l@413o0000oc8b<_o<c<coooooo`00
0?ooooook^k^oc8b<_l0003o<S8bonk^kP0Cooooo`03o`000?oooooooooo00Oooooo0_l000002Ol@
413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0>ooooo`005_ooool02_l0003ooooooooo
oooooooo0000ogMgMonHV9SooooooiRHV?mgMgL6ooooo`03o`000?oooooooooo017ooooo00Go410@
okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06?ooool02?l0003ooooo
oooooonHV9So8B4Qonk^k_ooooooA4A40oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Wooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
7_ooool01?l0003oooooooooool0000Dooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool00_ooool01OmgMgOo0000oooooonHV9SoMgMg00oooooo00?o0000ooooooooool02?ooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`06oa0@4?nj
^[[oooooogMgMolb<S;o00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool0
00_ooooo1_l00002ooooo`Go00000_ooool00ol0003o410@ooooo`02ooooo`03oa0@4?oooooooooo
00Gooooo00?o0000ooooooooool02?ooool6o`0000Kooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo017ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@
oooooooooooooooooa0@4009ooooo`03o`000?oooooooooo00Oooooo1_l00005ooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooool000005Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo
00Go410@o`000?oooooooooooa0@400?ooooo`03o`000?oooooooooo00Wooooo00?oV9RHob4Q8Oo^
k^h01?ooool01Ol@413ooooooooooooooooo410@01oooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo01;ooooo00?o0000ooooooooool01?ooool5o`0000?ooooo00Go410@
oooooooooooooooooa0@400>ooooo`004oooool01?m4A4CogMgMooooool00003ooooo`;o00000ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01;ooooo1ol00003ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool00_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oo
ooooooooooooool000002_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`000006ooooo`Go00004oooool2o`0001Kooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003oooool00ol0
003oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000N
ooooo`03ojVYZOl0003ooooo00;ooooo00Go0000ooooooooooooooooo`00000Dooooo`03o`000?oo
oooooooo00Cooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000000ko
oooo000Cooooo`04omgMgOmEEEGoooooo`0000;ooooo00?o0000ooooool000000oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo013ooooo00Co0000oa0@4?l0003o^[Zj0oooool5o`00
01Oooooo00?o0000ooooooooool01?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooooooo
ooooool000002_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00?ooooo0_l0000@ooooo`;o00005ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000@ooooo`03o`000?oooooooooo00[ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooo
oooooooooooo000001gooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo0000
01Gooooo00?o0000ooooooooool00oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?oooooo
ooooooooool000003_ooool001Cooooo00?oMgMgolc<c?l000000_ooool00ol0003ooooooa0@4003
ooooo`03oa0@4?oooooooooo00Kooooo00?o0000ooooooooool03oooool01Ol0003ooooooooooonj
^[[o8B4Q00?ooooo00Go410@oooooooooooo0000oa0@400Gooooo`03o`000?oooooooooo00Gooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Sooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo0ol000000ooooooo0000o`00000Foooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
410@013ooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o
410@ooooooooool06oooool00ol0003o^[Zjob4Q8@03ooooo`05oa0@4?ooooooooooooooool@4100
5Oooool00ol0003oooooooooo`04ooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooo
oooooa0@400>ooooo`005?ooool00oo^k^koA4A4o`000002ooooo`07o`000?ooooooMgMgoiRHV?oo
ooooV9RHogMgM`09ooooo`03o`000?oooooooooo00gooooo00Ko0000oa0@4?nHV9SooooookZj^_l0
0003ooooo`04ogMgMonHV9SooooooiRHV0;o00005_ooool02Ol0003ooooooooooooooooo0000okZj
^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03o`00
0?oooooooooo00Oooooo0_l00008ooooo`;o00001?ooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool00_ooool01Ol0003oV9RHoooooonHV9SoMgMg013o
oooo00?o0000ooooooooool01oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Kooooo`05oa0@4?nHV9So0000okZj^_l000000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg01Gooooo00?o0000ooooooooool01?ooool00oo^k^koA4A4o`000004ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03_ooool001Gooooo00_oMgMgo`000?ooooooooooo`000?ooooook^k^
oc8b<_l0003o<S8bonk^kP09ooooo`03o`000?oooooooooo00cooooo00Oo0000oooooonYZJWo410@
o`000?l@413oZJVY00?ooooo00Ook^k^oc8b<_l0003o<S8bonk^k_oooooo000001Gooooo00Wo0000
oooooooooooooooooiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00[ooooo00?o0000ooooooooool03oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01?ooool00ol0003oooooooooo`09ooooo`So00001_ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00Kooooo00?oEEEEofIVI_l000001?ooool01Ol0003o<S8bo`000?lb
<S;ok^k^013ooooo00?o0000ooooooooool01oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00?ok^k^o`000?l000000_l0000Kooooo`05ojVYZOl0003o0000oa0@4?nYZJT00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^01Gooooo00?o0000ooooooooool01Oooool00omgMgOo0000ooooo`03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool001Sooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0?ooooo`04o`000?ooooooooooo`0001_ooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0Nooooo`006?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool07_ooool001Sooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo01kooooo000Hooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Mooooo`005oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool07Oooool001Koooooool00010
o`0001?ooooo000Fooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Cooooo0_l00005ooooo`03o`000?oooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooo000000Kooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo000Fooooo`;o00001_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l00004ooooo`04o`000?oooooo
ooooo`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooo000000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooo000000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`04ooooo`;o0000
1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00007ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
017ooooo000Gooooo`03o`000?oooooooooo01Cooooo0_l00002ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01go
oooo000Gooooo`03o`000?oooooooooo01Gooooo0ol0000Iooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Mooooo`005oooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0Mooooo`005_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0Mooooo`005_ooool00ol0003oooooooooo`0coooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Loooo
o`005_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`0Looooo`005_ooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo01_ooooo0_l0000Iooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01cooooo000Fooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool04Oooool004gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04Oooool0
04gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool07?ooool01Ol0003ooooooooooooooooo000000oooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool04Oooool004gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07?ooool01?l0003oooooooooool0000@
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo017ooooo001=ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01gooooo0_l0000Aoooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01;ooooo001>ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool04_ooool004kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`00C_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`0Looooo`;o00006_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool04_ooool004kooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Booooo`00C_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01;ooooo001?ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04_ooool004oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Cooooo`00Coooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo01?ooooo001?ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool04oooool004oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Coooo
o`00Coooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0Mooooo`;o00006oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool04oooool0053ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
<oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Cooooo`00D?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo01?ooooo001@ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool0
053ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`00D?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo01Cooooo001Aooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo
1Ol00006ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo01Cooooo001Aooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`06ooooo`;o00002_ooool00ol0003ooooooooo
o`0Cooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Dooooo`00DOoo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01_oo
ool3o`0000Wooooo00?o0000ooooooooool05?ooool00onHV9So8B4Qonk^kP07ooooo`?o00006_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0`ooooo`05o`000?ooooooooooooooool000005_ooool0057ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Gooooo00Co
0000oooooooooooo00002Oooool00ol0003oooooooooo`0Eooooo`03oiRHV?lQ8B7ok^k^00Kooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0`ooooo`05o`000?ooooooooooooooool0
00005_ooool0057ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo01Ko
oooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo033o
oooo00Go0000ooooooooooooooooo`00000Fooooo`00D_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo0000
00Sooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0<?ooool01Ol0003ooooooooooooooooo000001Kooooo001Boooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`04oooo
o`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`0Dooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo033ooooo00Co
0000oooooooooooo00005oooool005;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0<?ooool01?l0003oooooooooool0000Gooooo`00
D_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooool00000
5oooool005;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0booooo`03o`000?oo
oooo000001Oooooo001Booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Oooooo`;o00007?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0booooo`;o00006?ooool0
05;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Vooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool07?ooool01Ol0003ooooooooooooooooo000003Wooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`1<ooooo`00D_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo02Kooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool07?ooool01Ol0003ooooooooooooooooo000003Wooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1<ooooo`00D_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo02Kooooo00Co0000oooooooooooo00002?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool07?ooool01Ol0003ooooo
oooooooooooo000003Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1<ooooo`00
D_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Kooooo00Co0000oooooooooooo
00002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool07?ooool01Ol0003ooooooooooooooooo000003Wooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`1<ooooo`00D_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02So
oooo0_l00009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`0Looooo`05o`000?ooooooooooooooool00000>_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo04cooooo001Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0<oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool07?ooool01Ol0003ooooooooooooooooo000003[ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1<ooooo`00Doooool01Ol0003ooooooooooooooooo000003Gooooo00Go0000oooo
ooooooooooooo`00000Sooooo`03o`000?oooooooooo01cooooo00Go0000ooooooooooooooooo`00
000jooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0COooool005?ooooo00Go0000
ooooooooooooooooo`00000fooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool0
7Oooool01?l0003oooooooooool0000jooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0COooool005?ooooo00Co0000oooooooooooo0000=oooool01?l0003oooooooooool0000Soooo
o`;o00007_ooool00ol0003oooooo`00000kooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0COooool005?ooooo00Co0000oooooooooooo0000=oooool01?l0003oooooooooool0000S
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooool00000??ooool01Ol0003ooooooooooooo
oooo000004oooooo001Dooooo`03o`000?oooooo000003Oooooo00Co0000oooooooooooo00008ooo
ool00ol0003oooooooooo`0Mooooo`?o0000??ooool01Ol0003ooooooooooooooooo000004oooooo
001Dooooo`03o`000?oooooo000003Sooooo0ol0000Sooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool0>oooool01Ol0003ooooooooooooooooo000004oooooo001Eooooo`03o`000?oo
oooooooo03Oooooo0_l0000Tooooo`03o`000?oooooooooo05cooooo00Co0000oooooooooooo0000
D?ooool00;Gooooo00?o0000ooooooooool0G?ooool01?l0003oooooooooool0001@ooooo`00]Ooo
ool00ol0003oooooooooo`1Looooo`04o`000?ooooooooooo`00053ooooo002eooooo`03o`000?oo
oooooooo05gooooo0_l0001Aooooo`00]Oooool2o`0005kooooo0_l0001Aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00[?ooool2o`000003oa0@4?oooooo
oooo00Cooooo00?o0000ooooooooool0/?ooool00:gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`2`ooooo`00Z_ooool5o`0000Kooooo00?o0000ooooooooool0/?ooool00:[ooooo
00CoA4A4omgMgOoooooo00001oooool3o`000;3ooooo002Zooooo`04omgMgOmEEEGoooooo`0000Oo
oooo00?o0000ooooooooool0/?ooool00:_ooooo00?oMgMgolc<c?l000001oooool00ol0003ooooo
ooooo`2`ooooo`00Zoooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0;3ooooo002/
ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002e
ooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo00Gok^k^oc8b<_l0003o410@olc<c006
ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool0
0ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool0/?ooool00:[ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000/?ooool0
0:[ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zoooo
o`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0/?ooool00:[ooooo00?ogMgMoa0@4?nH
V9P02?ooool00ol0003oooooooooo`2`ooooo`00Zoooool01?o<c<coA4A4o`000?l@4106ooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Go
oooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002Zooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2`ooooo`00
Z_ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05oc8b
<_nHV9SooooooiRHV?lb<S801_ooool3o`000;3ooooo002Zooooo`05olc<c?l0003o0000o`000?o<
c<`0^Oooool00:[ooooo00Go410@okZj^_oooooo^[Zjoa0@402iooooo`00Z_ooool01Ol0003o^[Zj
oooooonj^[[o00000;Wooooo002Zooooo`05ojVYZOl@413o0000oa0@4?nYZJT0^Oooool00?oooooo
JOooool00:oooooo00?o0000okZj^_ooool0]_ooool00:oooooo0_lb<S:gooooo`00P?ooool2o`00
0006oa0@4?oooooooooooa0@4?l0003o410@6?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0
003oA4A4okZj^P0Iooooo`Co000000?o410@ooooooooool00_ooool2o`000009oa0@4?oooooooooo
ooooooo^k^ko<S8bo`000?l@413oc<c<07Sooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01oooool6o`0000gooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRH
V?mgMgL00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6
o`0000cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`05oeEEEOmgMgOo
oooooiRHV?lQ8B40N?ooool0087ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0K
ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool04?ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo00;ooooo1Ol00003ooooo`05o`000?ooooooooooooooool00000
N?ooool0087ooooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00003Oooool01OmgMgOo
<S8boooooooooooo000000?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;oooo
o`Ko00003?ooool00ol0003oooooooooo`02ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000
oiRHV?ooooooV9RHob4Q8@1hooooo`00POooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001Wooooo
00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000004_ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo00CogMgMoeEEEOoooooo00001?ooool0
1Ol0003oEEEEo`000?l@413oc<c<07Sooooo0021ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo0000
6Oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol@413o
0000o`000003o`0001cooooo00?o0000ooooooooool00oooool00omgMgOoc<c<o`000004ooooo`03
oeEEEOn7QhOooooo07[ooooo0021ooooo`06o`000?lb<S;ooooooooooolb<S;o00006Oooool00ol0
003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo00?ooooo00?ok^k^odA4A?l000001?ooool00ooMgMgo410@oiRHV01j
ooooo`00P?ooool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo1?l00003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Kooooo`03oeEEEOmVIVKo
000000Kooooo00?oMgMgo`000?ooool01?ooool01?o<c<coA4A4o`000?l@411hooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(148) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .19483 m
.00236 .18688 L
.00488 .18015 L
.00726 .17539 L
.00942 .17229 L
.01075 .17093 L
.01197 .17001 L
.01331 .16934 L
.01399 .16913 L
.01473 .16899 L
.01598 .16897 L
.01732 .16921 L
.01859 .16966 L
.01975 .17025 L
.02239 .17215 L
.02485 .17448 L
.03042 .18127 L
.04057 .19497 L
.04334 .19805 L
.04635 .20078 L
.04773 .2018 L
.04919 .20272 L
.05045 .20338 L
.0518 .20394 L
.05311 .20434 L
.05431 .20457 L
.05551 .20469 L
.05665 .20469 L
.05798 .20455 L
.0592 .20431 L
.06055 .20391 L
.06198 .20337 L
.08481 .19116 L
.09488 .18922 L
.09754 .18895 L
.099 .18877 L
.10038 .18856 L
.10305 .18802 L
.10549 .18735 L
.10983 .18569 L
.11228 .18445 L
.11454 .18305 L
.11935 .17915 L
.12445 .17373 L
.13494 .16075 L
.14476 .14879 L
.14734 .1462 L
.14979 .14417 L
.15114 .14324 L
.15261 .14239 L
Mistroke
.15394 .14178 L
.15519 .14134 L
.15592 .14115 L
.1567 .14101 L
.15807 .1409 L
.15885 .14093 L
.15967 .14105 L
.16037 .14122 L
.16114 .14149 L
.16252 .14222 L
.16329 .14278 L
.164 .1434 L
.16537 .14492 L
.16666 .14677 L
.16916 .15169 L
.17149 .15813 L
.17406 .16754 L
.17682 .18086 L
.17957 .19789 L
.18245 .22047 L
.18761 .27313 L
.19208 .32702 L
.19454 .3555 L
.19686 .37852 L
.19818 .38903 L
.19887 .39364 L
.1996 .39775 L
.2009 .40297 L
.20209 .40531 L
.20329 .40521 L
.20441 .4029 L
.20564 .39796 L
.20696 .39005 L
.21703 .2787 L
.22255 .21865 L
.22774 .17813 L
.23042 .16283 L
.23332 .14987 L
.23653 .1391 L
.23948 .13196 L
.24201 .12753 L
.24478 .12406 L
.24617 .12273 L
.24767 .12157 L
.25036 .12001 L
.25172 .11944 L
.25247 .1192 L
.25316 .119 L
.2544 .11874 L
.25576 .11858 L
Mistroke
.25651 .11855 L
.25723 .11856 L
.25858 .11866 L
.25933 .11878 L
.26003 .11892 L
.26161 .11934 L
.26301 .11984 L
.26432 .1204 L
.26676 .12167 L
.26943 .12338 L
.27225 .12558 L
.27723 .1307 L
.28182 .13719 L
.28675 .14637 L
.29216 .15939 L
.30357 .19859 L
.30919 .22218 L
.31438 .24335 L
.31908 .25918 L
.32146 .26511 L
.32281 .26772 L
.32408 .26962 L
.32537 .27099 L
.32673 .27181 L
.32789 .272 L
.32916 .27169 L
.33053 .27076 L
.33129 .26999 L
.33199 .26914 L
.33463 .26481 L
.34472 .23957 L
.35003 .22721 L
.35271 .22251 L
.35423 .22045 L
.35492 .21968 L
.35566 .21896 L
.35699 .21799 L
.35826 .21747 L
.35949 .21737 L
.36064 .21764 L
.362 .21845 L
.36323 .21965 L
.36391 .22052 L
.36465 .22163 L
.36598 .22409 L
.3684 .23009 L
.37095 .23872 L
.3755 .26061 L
.38073 .29627 L
.38549 .33619 L
Mistroke
.39061 .3789 L
.39202 .38883 L
.39351 .39788 L
.39479 .40423 L
.39618 .40932 L
.39745 .41226 L
.39861 .41341 L
.39978 .41306 L
.40089 .41133 L
.40218 .40767 L
.40337 .40277 L
.40608 .38701 L
.41061 .35091 L
.41545 .3088 L
.4207 .26892 L
.42624 .23784 L
.42914 .22599 L
.43232 .216 L
.43522 .20927 L
.43792 .20466 L
.44066 .2013 L
.44326 .19903 L
.4456 .19755 L
.44814 .19636 L
.4509 .19541 L
.45383 .19464 L
.45639 .19404 L
.4591 .19334 L
.46154 .19255 L
.46422 .19139 L
.46666 .19003 L
.46893 .18847 L
.47405 .18396 L
.47953 .17779 L
.49872 .15045 L
.50947 .13676 L
.51513 .13097 L
.52112 .12603 L
.52636 .12265 L
.52914 .12122 L
.53213 .11998 L
.53354 .11951 L
.53487 .11913 L
.53617 .11881 L
.53737 .11858 L
.53851 .1184 L
.53972 .11827 L
.54106 .1182 L
.54228 .11819 L
.54355 .11826 L
Mistroke
.54473 .11839 L
.54602 .11862 L
.54741 .11898 L
.54887 .11949 L
.55025 .1201 L
.55283 .12166 L
.55524 .12366 L
.55747 .12607 L
.55992 .12948 L
.56252 .13416 L
.5651 .14015 L
.56789 .14845 L
.57292 .16951 L
.57584 .18603 L
.57891 .20729 L
.58439 .25488 L
.58956 .30563 L
.5921 .32871 L
.59443 .34649 L
.59575 .35438 L
.59713 .36076 L
.59785 .36319 L
.59852 .3649 L
.59926 .36613 L
.60005 .36667 L
.60142 .36573 L
.60272 .36267 L
.60388 .3582 L
.60515 .35164 L
.60746 .33582 L
.61001 .3141 L
.61517 .26508 L
.6196 .22652 L
.62445 .19335 L
.62711 .17941 L
.6296 .16893 L
.63222 .16022 L
.63502 .15327 L
.63628 .15087 L
.63764 .1487 L
.63883 .14712 L
.6401 .14576 L
.64125 .14479 L
.64251 .14397 L
.64365 .14343 L
.64473 .14308 L
.64608 .14285 L
.64684 .14281 L
.64755 .14284 L
.64885 .14303 L
Mistroke
.65024 .14344 L
.6516 .14404 L
.65288 .14479 L
.65527 .14663 L
.65811 .14955 L
.66072 .15287 L
.66661 .16235 L
.67697 .18546 L
.68267 .2007 L
.68806 .21476 L
.69308 .22594 L
.69592 .23086 L
.69727 .23276 L
.69854 .23423 L
.69969 .23529 L
.70074 .23602 L
.70191 .23657 L
.70317 .23684 L
.70431 .23679 L
.70556 .23644 L
.70687 .23574 L
.70808 .23481 L
.71058 .23214 L
.71328 .22831 L
.71819 .2197 L
.72737 .20227 L
.73257 .19422 L
.7352 .19112 L
.73808 .18847 L
.74054 .1868 L
.74193 .18609 L
.74319 .18557 L
.74436 .18519 L
.74564 .1849 L
.74684 .18474 L
.74796 .18467 L
.74932 .18472 L
.75 .18479 L
.75075 .1849 L
.75208 .18518 L
.75331 .18553 L
.7561 .18657 L
.75909 .18793 L
.76956 .19269 L
.77449 .19476 L
.77972 .19708 L
.78187 .1982 L
.78419 .19969 L
.78673 .20191 L
.78911 .20485 L
Mistroke
.79048 .20703 L
.79198 .20991 L
.79471 .21672 L
.79736 .22564 L
.79983 .23629 L
.80546 .27069 L
.81146 .3224 L
.8142 .34833 L
.81717 .37441 L
.81853 .38469 L
.81997 .39383 L
.8212 .39996 L
.82255 .40466 L
.82386 .40698 L
.82506 .40709 L
.82644 .40478 L
.82775 .40024 L
.82895 .39411 L
.83007 .38693 L
.8326 .36611 L
.84282 .25842 L
.84857 .20913 L
.85131 .19104 L
.85385 .17703 L
.85849 .15744 L
.86094 .14966 L
.86357 .14292 L
.86633 .13725 L
.86893 .13295 L
.87125 .12978 L
.87381 .12688 L
.87861 .12276 L
.88123 .12109 L
.88369 .11982 L
.88809 .11809 L
.89055 .11734 L
.89281 .11679 L
.89408 .11653 L
.89543 .11629 L
.8966 .11611 L
.89786 .11596 L
.89864 .11589 L
.89935 .11584 L
.90004 .11579 L
.90076 .11576 L
.90201 .11573 L
.90338 .11574 L
.90469 .11578 L
.90589 .11586 L
.90727 .11598 L
Mistroke
.90857 .11613 L
.9109 .11651 L
.91221 .1168 L
.91342 .11711 L
.91596 .11794 L
.91829 .11895 L
.92085 .12038 L
.92354 .1223 L
.92808 .12672 L
.93065 .13009 L
.93304 .13392 L
.93586 .13952 L
.93852 .14608 L
.9435 .16232 L
.94887 .18675 L
.95468 .2219 L
.95989 .25866 L
.96275 .27869 L
.96548 .29572 L
.968 .30847 L
.96943 .31395 L
.97075 .31773 L
.97198 .32005 L
.97309 .32111 L
.97437 .32111 L
.97557 .31991 L
.97685 .31739 L
.97821 .31342 L
.98063 .3034 L
.9861 .27156 L
.99209 .23348 L
.99767 .20431 L
1 .19483 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool006Oooooo0_l00011ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`09ooooo`?o0000K?ooool:o`0002kooooo001Uooooo`Oo0000BOooool00ol0003ooooooooo
o`06ooooo`Co00000_ooool3o`0006Oooooo0_l0000:ooooo`;o0000;?ooool006Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool0:Oooool006?ooooo00?o0000ooooooooool01_ooool2o`0004Oooooo00?o0000oooo
ooooool00oooool2o`0000[ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo02Sooooo001Sooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0A?ooool2o`0000?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Pooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool09oooool006;ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`14ooooo`05o`000?ooooooooooooooool000003oooool00ol0003o
ooooooooo`1Nooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool09_ooool006;ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`13ooooo`04o`000?ooooooooooo`00013o
oooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Ko
oooo001Qooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0@oooool01?l0003ooooo
ooooool0000Aooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Uooooo`00A_ooool5o`0001Kooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`12ooooo`03o`000?oooooo000001;ooooo00?o0000ooooooooool05_ooool3o`0004?ooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Uooooo`00AOooool00ol0003ooooooooo
o`02ooooo`;o00005?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo047ooooo0_l0
000Cooooo`03o`000?oooooooooo01Cooooo0_l00002ooooo`;o0000@_ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo02Gooooo0014ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo047ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0?_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02Gooooo0014oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo03oooooo0_l0000Dooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool09?ooool004?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0?oooool3o`0001?ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03cooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0Tooooo`00@_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0mooooo`03o`00
0?oooooo000001Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Tooooo`00@Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0looooo`04o`000?ooooooooooo`0001Gooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0Sooooo`005Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^01[ooooo00goV9RHoa0@4?l0003o<S8bolc<c?oooooo0000ooooooo^k^ko
<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05o`00
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`03o`000?oooooooooo01Gooooo1?l00000
2?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^6_ooool01Ol0003ooooooooooooooooo0000
01Gooooo00?o0000ooooooooool02Oooool4o`000004oa0@4?ooooooooooonk^kP;o000000?o<S8b
onk^k_ooool01_ooool00ol0003oooooooooo`0@ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^01_ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h04?ooool00ol0003oooooooooo`0:ooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o
0000oc8b<_o^k^h03_ooool001Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg01[ooooo00Ko410@okZj^_ooooooMgMgoc8b<_l00002ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01_ooool00ol0003oooooooooo`0?ooooo`08o`000?oooooooooooiRHV?lQ8B7ok^k^oooo
oom4A4@3ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Jooooo`05o`000?oooooooooo
ooooool000005_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00Go0000
oiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo00oooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06oooool01Ol@413o^[Zjo`000?mgMgOo<S8b
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0@ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko00000_ooool5
o`000003ooooool0003o000000;o00000_ooool00ol@413oooooooooo`0@ooooo`Ko00001_ooool0
1Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01?ooool00ol0003ooooooooo
o`0:ooooo`Ko00000oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@4100
1Oooool00ol0003oooooooooo`0;ooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41006Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool@41002?ooool00ol0003oooooooooo`0@ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooo
oooooooooooooa0@400Looooo`04o`000?ooooooooooo`0000?ooooo00Go410@oooooooooooooooo
oa0@400Aooooo`03o`000?oooooooooo00Oooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@
41003_ooool001?ooooo00CoA4A4omgMgOoooooo00000_ooool01?l0003oooooo`000?ooool3o`00
01gooooo00?o0000oa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000
ooooooooooooooooo`000005ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000001Sooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000Sooooo00?o0000ooooooooool04Oooool00onHV9So8B4Qonk^kP03ooooo`05
o`000?ooooooooooooooool000007?ooool01?l0003oooooojVYZOl@4103ooooo`05o`000?oooooo
ooooooooool000004Oooool00ol0003oooooooooo`07ooooo`04odA4A?oMgMgoooooo`0000Cooooo
00Go0000ooooooooooooooooo`00000>ooooo`004oooool01_oMgMgoEEEEooooool0003oooooo`00
00;ooooo00?o0000ooooooooool00_l0000Looooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000oooo
ooooooooooooo`000007ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Gooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0:ooooo`04o`00
0?ooooooooooooooo`;o00000oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo017o
oooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000001cooooo00Co0000oa0@
4?l0003o^[Zj0oooool01Ol0003ooooooooooooooooo0000017ooooo00?o0000ooooooooool01ooo
ool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000003_ooool001Cooooo
00CoMgMgolc<c?l0003o00000oooool01Ol@413ooooooooooooooooo000001_ooooo0_l000000onj
^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41001oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oo
oooooooo00Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41005oooool00ol0003oooooooooo`04ooooo`;o00005_ooool00ol0003ooooo
ooooo`09ooooo`06o`000?ooooooooooooooool0003o410@0oooool00ol@413oooooooooo`07oooo
o`03o`000?oooooooooo01;ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooo
oooo01[ooooo00Co0000oooooonj^[[o8B4Q0oooool01Ol@413ooooooooooooooooo410@017ooooo
00?o0000ooooooooool02?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@
41003_ooool001Cooooo00Cok^k^odA4A?l0003o00000oooool01OmgMgOoV9RHoooooonHV9So0000
01Wooooo0_l000001?nHV9SooooookZj^_l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01ooo
ool00ol0003oooooooooo`0=ooooo`09o`000?ooooooooooooooool0003o^[ZjoooooonHV9So410@
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Wooooo00[o0000oooooooooooooooo
o`000?mgMgOoV9RHoooooonHV9SoMgMg2Oooool00ol0003oooooooooo`0>ooooo`05o`000?nj^[[o
oooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg01_ooooo00Go410@o`000?oooooo
^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool00ol0003oooooooooo`07oooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`005Oooool00omg
MgOo0000ooooo`03ooooo`06onk^k_lb<S;o0000oc8b<_o^k^ko00005_ooool3o`000005ojVYZOl@
413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00?o0000oooooooo
ool03Oooool02Ol0003oooooooooooooooooV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`0Cooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Eooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`07ooooo`03oeEEEOmVIVKo000000?ooooo00Ko0000onk^k_lb
<S;o0000oc8b<_o^k^h:ooooo`03o`000?oooooooooo00gooooo00CoV9RHoa0@4?l0003o8B4Q1ol0
00000olb<S;ok^k^ooooo`0Jooooo`05o`000?l@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01;ooooo00?o0000ooooooooool02?ooool00omgMgOo0000ooooo`03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03_ooool001Kooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0?ooooo`Co00005oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0<_ooool2o`0000Wooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`03ooooo`?o00006oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo027o
oooo000Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02oooool3o`0001cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo033ooooo
0_l0000;ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01oooool2o`0001Wooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Qooooo`005_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Oooooo0ol0000Oooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`0[ooooo`Co00003Oooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00[ooooo0ol0000Fooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Aooooo`008oooool00ol0003oooooooooo`04
ooooo`?o00008_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool0:_ooool2o`00013ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo017ooooo000Tooooo`;o00000oooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo01;ooooo000Foooooooo0000@?l0000Cooooo`005_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
o`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Co
oooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`04ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Cooooo0_l0000Cooooo`005_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`05ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool01?ooool2o`0000Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`04ooooo`;o0000
4oooool0053ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool04_ooool0053ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00cooooo0ol0000Eooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo01;ooooo001@ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0;ooooo`;o000000?oooooo`000?l000005?ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Coooo
o`00D?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool02oooool01Ol0003ooooooooooooooooo000001?ooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04oooool0053o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01?o
oooo001@ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Cooooo`00D?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool05Oooool2o`0001Sooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Fooooo`05o`000?ooooooooooooooool000006oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Cooooo`00D?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05_oo
ool4o`0001cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool04oooool0053ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04oooool0
053ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
03Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool04oooool0053ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05?ooool0057ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool05?ooool0057ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05?ooool0057ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool05?ooool0057ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo01Kooooo0_l0000Iooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Dooooo`00DOooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Dooooo`00
DOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01kooooo00Go0000oooooooooooo
ooooo`00000<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Eooooo`00DOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01kooooo
00Co0000oooooooooooo00003Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool05Oooool0057ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Oooooo`?o00003Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool05Oooool0057ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Eooooo`00DOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Gooooo001Aoooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05_ooool0057ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool05oooool2o`0001[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0jooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo01Kooooo001Aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
5_ooool005;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Fooooo`00D_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo001Booooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool05oooool005;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0booooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Gooooo`00D_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`Go00001_ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Gooooo`00D_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Kooooo00Go0000oooooooooooo
ooooo`00000Iooooo`00D_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0>ooooo`03oiRHV?lQ8B7ok^k^00Oooooo
0ol0000Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0??ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo02Kooooo00Go0000ooooooooooooooooo`00000Iooooo`00
D_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0?ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Vooooo`04o`000?ooooooooooo`0001[ooooo001Booooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo013ooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo02Oooooo00Co0000oooooooooooo00006_ooool005?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
:?ooool00ol0003oooooo`00000Jooooo`00Doooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0>ooooo`05o`000?nj
^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0?Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Sooooo
0_l0000Kooooo`00Doooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0>ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
1_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
?Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Gooooo001Cooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo03kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`15ooooo`00Doooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0AOooool0
05?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool06Oooool2o`0001_ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0AOooool005?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04Go
oooo001Cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06oooool01Ol0003ooooo
oooooooooooo0000047ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`15ooooo`00
E?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00Go0000oooooooooooo
ooooo`000011ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0AOooool005Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0004;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`15ooooo`00E?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo0000@_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo04Kooooo001Dooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool06oooool01?l0003oooooooooool00012ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0A_ooool005Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Kooooo`04o`000?ooooooooooo`0004;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`16ooooo`00E?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo
00Co0000oooooooooooo0000@_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04Ko
oooo001Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo01[ooooo0_l0000Mooooo`03o`000?oooooo000004;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`16ooooo`00E?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo01cooooo0_l00014ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0A_ooool005Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1R
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0A_ooool005Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0A_ooool005Cooooo00Go0000ooooooooooooooooo`00000iooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0A_ooool005Cooooo00Go0000ooooooooooooooooo`00000ioooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Roooo
o`05o`000?ooooooooooooooool00000BOooool005Cooooo00Go0000ooooooooooooooooo`00000i
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1R
ooooo`05o`000?ooooooooooooooool00000BOooool005Cooooo00Go0000ooooooooooooooooo`00
000iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`1Rooooo`05o`000?ooooooooooooooool00000BOooool005Gooooo00Co0000oooooooooooo0000
>Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01_ooooo0_l0001Sooooo`05o`00
0?ooooooooooooooool00000BOooool005Gooooo00Co0000oooooooooooo0000>Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0Hoooool01?l0003o
ooooooooool00019ooooo`00EOooool01?l0003oooooooooool0000iooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Sooooo`04o`000?oooooooooo
o`0004Wooooo001Eooooo`03o`000?oooooo000003_ooooo00Co0000oooooooooooo00007_ooool0
0ol0003oooooooooo`1Sooooo`04o`000?ooooooooooo`0004Wooooo001Eooooo`03o`000?oooooo
000003_ooooo00Co0000oooooooooooo00007_ooool00ol0003oooooooooo`1Sooooo`03o`000?oo
oooo000004[ooooo001Fooooo`;o0000>oooool01?l0003oooooooooool0000Eooooo`;o000000?o
410@ooooooooool01?ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooo000004[ooooo001F
ooooo`03o`000?oooooooooo03[ooooo00Co0000oooooooooooo00005_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo06Cooooo0_l0001:ooooo`00U?ooool00ol0003oooooo`00000C
ooooo`Go00001_ooool00ol0003oooooooooo`2`ooooo`00U?ooool2o`0001Cooooo00CoA4A4omgM
gOoooooo00001oooool3o`000;3ooooo002Zooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000
ooooooooool0/?ooool00:_ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`2`oooo
o`00Zoooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0;3ooooo002/ooooo`03ogMg
Mol0003ooooo00Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eoooo
o`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`00
0?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
00?o0000ooooooooool0/?ooool00:[ooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`00
0?oooooooooo0;3ooooo002Zooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
/?ooool00:[ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000/?ooool00:[ooooo00Go
0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`03oeEEEOn7
QhOooooo00Sooooo00?o0000ooooooooool0/?ooool00:[ooooo00?ogMgMoa0@4?nHV9P02?ooool0
0ol0003oooooooooo`2`ooooo`00Zoooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?oo
ool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Go
oooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`oooo
o`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Ooo
ool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002Zoooo
o`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01OlQ
8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05oc8b<_nHV9Sooooo
oiRHV?lb<S801_ooool3o`000;3ooooo002Zooooo`05olc<c?l0003o0000o`000?o<c<`0^Oooool0
0:[ooooo00Go410@okZj^_oooooo^[Zjoa0@402iooooo`00Z_ooool01Ol0003o^[Zjoooooonj^[[o
00000;Wooooo002Zooooo`05ojVYZOl@413o0000oa0@4?nYZJT0^Oooool00?ooooooJOooool00:oo
oooo00?o0000okZj^_ooool0]_ooool00:oooooo0_lb<S:gooooo`00P?ooool2o`000006oa0@4?oo
oooooooooa0@4?l0003o410@6?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj
^P0Iooooo`Co000000?o410@ooooooooool00_ooool2o`000009oa0@4?ooooooooooooooooo<c<co
8B4Qo`000?lQ8B7oc<c<07Sooooo0021ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01oooool6o`0000gooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL00ooo
ool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`05ob4Q8OnHV9SooooooiRHV?lQ
8B40N?ooool0087ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Kooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool04?ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo00;ooooo1Ol00003ooooo`05o`000?ooooooooooooooool00000N?ooool0087o
oooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00003Oooool01OmgMgOo<S8boooooooo
oooo000000?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`Ko00003?oo
ool00ol0003oooooooooo`02ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go<S8boiRHV?oooooo
V9RHoc8b<P1hooooo`00POooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001Wooooo00Go0000ob4Q
8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo00;ooooo00CogMgMoeEEEOoooooo00001?ooool01Oo<c<co0000
o`000?l0003oc<c<07Sooooo0021ooooo`06o`000?n7QhOoZJVYokZj^_mEEEGo00006Oooool00ol0
003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol@413o0000o`000003
o`0001cooooo00?o0000ooooooooool00oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?nj^[[o
oooookZj^_l@4100N?ooool0087ooooo00Ko0000oc8b<_oooooooooooc8b<_l0000Iooooo`03o`00
0?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Booooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool00oooool00oo^k^koA4A4o`000004ooooo`05o`000?nj^[[ooooookZj
^_l00000N?ooool0083ooooo00?o410@o`000?n7QhL00_ooool00on7QhOo0000oa0@400Hooooo`Co
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo00?o0000ooooooooool06oooool00omE
EEGoIVIVo`000006ooooo`03ogMgMol0003ooooo00?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@1h
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.206011 0.0515028 [
[0 .19351 -9 -9 ]
[0 .19351 9 0 ]
[.125 .19351 -9 -9 ]
[.125 .19351 9 0 ]
[.25 .19351 -9 -9 ]
[.25 .19351 9 0 ]
[.375 .19351 -9 -9 ]
[.375 .19351 9 0 ]
[.625 .19351 -6 -9 ]
[.625 .19351 6 0 ]
[.75 .19351 -6 -9 ]
[.75 .19351 6 0 ]
[.875 .19351 -6 -9 ]
[.875 .19351 6 0 ]
[1 .19351 -6 -9 ]
[1 .19351 6 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .20601 m
0 .21226 L
s
[(-40)] 0 .19351 0 1 Mshowa
.125 .20601 m
.125 .21226 L
s
[(-30)] .125 .19351 0 1 Mshowa
.25 .20601 m
.25 .21226 L
s
[(-20)] .25 .19351 0 1 Mshowa
.375 .20601 m
.375 .21226 L
s
[(-10)] .375 .19351 0 1 Mshowa
.625 .20601 m
.625 .21226 L
s
[(10)] .625 .19351 0 1 Mshowa
.75 .20601 m
.75 .21226 L
s
[(20)] .75 .19351 0 1 Mshowa
.875 .20601 m
.875 .21226 L
s
[(30)] .875 .19351 0 1 Mshowa
1 .20601 m
1 .21226 L
s
[(40)] 1 .19351 0 1 Mshowa
.125 Mabswid
.025 .20601 m
.025 .20976 L
s
.05 .20601 m
.05 .20976 L
s
.075 .20601 m
.075 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.15 .20601 m
.15 .20976 L
s
.175 .20601 m
.175 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.225 .20601 m
.225 .20976 L
s
.275 .20601 m
.275 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.325 .20601 m
.325 .20976 L
s
.35 .20601 m
.35 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.425 .20601 m
.425 .20976 L
s
.45 .20601 m
.45 .20976 L
s
.475 .20601 m
.475 .20976 L
s
.525 .20601 m
.525 .20976 L
s
.55 .20601 m
.55 .20976 L
s
.575 .20601 m
.575 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.65 .20601 m
.65 .20976 L
s
.675 .20601 m
.675 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.725 .20601 m
.725 .20976 L
s
.775 .20601 m
.775 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.825 .20601 m
.825 .20976 L
s
.85 .20601 m
.85 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.925 .20601 m
.925 .20976 L
s
.95 .20601 m
.95 .20976 L
s
.975 .20601 m
.975 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
.5 0 m
.50625 0 L
s
[(-4)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(2)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(4)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(6)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(8)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(150) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .21522 m
.00488 .21009 L
.00942 .20647 L
.01975 .20031 L
.02492 .19743 L
.02981 .19516 L
.03251 .19427 L
.03403 .1939 L
.03544 .19365 L
.03663 .1935 L
.03793 .19339 L
.03929 .19336 L
.04057 .1934 L
.04125 .19345 L
.04198 .19353 L
.0433 .19374 L
.0441 .19391 L
.04486 .1941 L
.04627 .19454 L
.04888 .19562 L
.0517 .19719 L
.05655 .20046 L
.06188 .20397 L
.06333 .20477 L
.06488 .20552 L
.06623 .20605 L
.06769 .20651 L
.06854 .20671 L
.06934 .20685 L
.07009 .20694 L
.0709 .20698 L
.07161 .20697 L
.07229 .20691 L
.07303 .2068 L
.07382 .20663 L
.07516 .20618 L
.07591 .20584 L
.07661 .20546 L
.07815 .20443 L
.07955 .20326 L
.08209 .20056 L
.08481 .19694 L
.10665 .15603 L
.11624 .1405 L
.12133 .13393 L
.12679 .12806 L
.13209 .1238 L
.13693 .12101 L
.13925 .11992 L
.14179 .11889 L
Mistroke
.14295 .11849 L
.14419 .11812 L
.14527 .11785 L
.14641 .11763 L
.14708 .11753 L
.14782 .11746 L
.14911 .1174 L
.14984 .11742 L
.15062 .11747 L
.15135 .11756 L
.15203 .11767 L
.15333 .11797 L
.15474 .11843 L
.15731 .11959 L
.1598 .12119 L
.16244 .12355 L
.16469 .1263 L
.16718 .13039 L
.16965 .13587 L
.17236 .14381 L
.17518 .15469 L
.1778 .16757 L
.18251 .19893 L
.18753 .24633 L
.19345 .31707 L
.19635 .35161 L
.19902 .37842 L
.20028 .38834 L
.20146 .39566 L
.20268 .40107 L
.20403 .40419 L
.2054 .40424 L
.20664 .40154 L
.20733 .39896 L
.20808 .3953 L
.20945 .38656 L
.21923 .28022 L
.22436 .22673 L
.22717 .20398 L
.22978 .18692 L
.23266 .17219 L
.23582 .16023 L
.23849 .15296 L
.23999 .14989 L
.24136 .14764 L
.24275 .14584 L
.24404 .14456 L
.24545 .14355 L
.24616 .14317 L
.24695 .14285 L
Mistroke
.24826 .14252 L
.249 .14243 L
.24968 .1424 L
.25099 .14249 L
.25223 .14273 L
.25357 .14313 L
.25483 .14364 L
.25718 .14494 L
.25972 .1468 L
.26245 .14935 L
.27194 .16152 L
.28313 .18123 L
.29343 .20483 L
.30298 .22874 L
.30824 .24078 L
.31082 .24572 L
.31321 .24947 L
.31455 .25118 L
.31603 .25271 L
.31751 .25385 L
.31832 .25431 L
.31909 .25463 L
.32043 .25492 L
.32166 .2549 L
.32301 .25455 L
.32369 .25424 L
.32444 .25381 L
.32581 .25276 L
.32706 .25151 L
.32987 .24782 L
.33491 .23864 L
.34471 .21755 L
.35006 .20745 L
.35507 .20019 L
.35768 .19747 L
.35915 .1963 L
.36049 .19546 L
.3612 .1951 L
.36195 .19479 L
.36278 .19454 L
.36354 .19438 L
.36433 .19428 L
.36506 .19427 L
.36644 .19441 L
.36772 .19474 L
.36907 .1953 L
.37022 .19593 L
.37148 .19679 L
.37429 .19935 L
.37692 .2025 L
Mistroke
.3822 .21105 L
.38793 .22344 L
.39298 .23705 L
.39834 .2549 L
.40317 .27511 L
.40848 .30306 L
.41785 .36411 L
.42045 .3805 L
.42183 .38821 L
.4233 .39538 L
.42471 .40099 L
.42598 .40482 L
.42727 .40732 L
.42848 .40832 L
.42966 .40797 L
.43092 .40614 L
.43198 .4034 L
.43316 .39916 L
.43442 .39322 L
.43577 .38541 L
.43822 .36807 L
.4496 .26658 L
.45461 .22782 L
.46013 .1943 L
.46531 .17119 L
.47081 .15359 L
.47369 .14653 L
.4768 .14018 L
.47949 .13559 L
.48243 .13142 L
.48779 .12567 L
.49072 .12332 L
.49344 .1215 L
.49833 .11895 L
.50106 .11789 L
.50355 .11717 L
.50597 .11666 L
.50735 .11644 L
.50864 .11628 L
.50997 .11614 L
.51123 .11605 L
.51193 .116 L
.51269 .11596 L
.51402 .11591 L
.5153 .11588 L
.51645 .11588 L
.51778 .1159 L
.51904 .11595 L
.5202 .11603 L
.52127 .11613 L
Mistroke
.52245 .11627 L
.52369 .11645 L
.52629 .11694 L
.52907 .11761 L
.5341 .11912 L
.53717 .12026 L
.54008 .1216 L
.54288 .12323 L
.54552 .12512 L
.55035 .12962 L
.55313 .13297 L
.55568 .13666 L
.56087 .14691 L
.56359 .15425 L
.56646 .16381 L
.57125 .18476 L
.5757 .2106 L
.58581 .28913 L
.58839 .30959 L
.59112 .32831 L
.59255 .33626 L
.59331 .33985 L
.59412 .34317 L
.59486 .3457 L
.59554 .34757 L
.59688 .34993 L
.59821 .35056 L
.59944 .34957 L
.6008 .34681 L
.60148 .34477 L
.60224 .34205 L
.60486 .32918 L
.60732 .31326 L
.61664 .24351 L
.61919 .22696 L
.62192 .2118 L
.62428 .2009 L
.62685 .19132 L
.62962 .18338 L
.63089 .18052 L
.63224 .17799 L
.63345 .17612 L
.63479 .1745 L
.63601 .17339 L
.63715 .17266 L
.63782 .17236 L
.63855 .17213 L
.63988 .172 L
.64117 .17218 L
.64238 .17261 L
Mistroke
.64311 .17299 L
.6438 .17341 L
.6451 .1744 L
.648 .17736 L
.65286 .18418 L
.65733 .19187 L
.66742 .21018 L
.66996 .21401 L
.67236 .21707 L
.67368 .21848 L
.67512 .21978 L
.67632 .22068 L
.67765 .22146 L
.67889 .22201 L
.68005 .22235 L
.68128 .22254 L
.68261 .22256 L
.68377 .22241 L
.685 .22209 L
.68605 .2217 L
.68719 .22116 L
.69004 .21933 L
.69263 .21721 L
.69843 .21187 L
.70341 .20787 L
.70624 .20616 L
.70763 .20549 L
.70889 .20497 L
.71007 .20457 L
.71135 .20422 L
.7127 .20396 L
.71398 .20381 L
.71534 .20376 L
.7161 .20377 L
.71678 .20381 L
.71812 .20396 L
.71938 .20418 L
.7218 .20479 L
.72402 .20547 L
.72645 .20623 L
.72778 .2066 L
.72904 .20689 L
.73041 .20713 L
.73166 .20725 L
.73284 .20727 L
.73411 .20719 L
.73478 .20711 L
.73551 .20698 L
.73628 .2068 L
.737 .20659 L
Mistroke
.73829 .20612 L
.73967 .20547 L
.74267 .20352 L
.74552 .20095 L
.75088 .1941 L
.7617 .17515 L
.77189 .15726 L
.77634 .15042 L
.78105 .14478 L
.78351 .14264 L
.78481 .14172 L
.78621 .14091 L
.78749 .14031 L
.78866 .1399 L
.78984 .13963 L
.79096 .13951 L
.79214 .13957 L
.79344 .13987 L
.79481 .1405 L
.79609 .14145 L
.79728 .14268 L
.79837 .14413 L
.80084 .14874 L
.80213 .15198 L
.80334 .15555 L
.80608 .16587 L
.80874 .17933 L
.81159 .19822 L
.81444 .22267 L
.81752 .25628 L
.82312 .33306 L
.82573 .3706 L
.82854 .40614 L
.8299 .41997 L
.83119 .43035 L
.83235 .43705 L
.83361 .44128 L
.83492 .44211 L
.8361 .4397 L
.83747 .4333 L
.83876 .42394 L
.84105 .40045 L
.84353 .36788 L
.84874 .29162 L
.8517 .25218 L
.85446 .22103 L
.85739 .19434 L
.86006 .17515 L
.86291 .15911 L
.86597 .14607 L
Mistroke
.86857 .13777 L
.86994 .13429 L
.8714 .13119 L
.87267 .12894 L
.87408 .12686 L
.87655 .12407 L
.87902 .12208 L
.88172 .1205 L
.88308 .11988 L
.88454 .11934 L
.88591 .11895 L
.88716 .11869 L
.88841 .11854 L
.88956 .1185 L
.89083 .11855 L
.89216 .11871 L
.89332 .11895 L
.89441 .11923 L
.89688 .12005 L
.90241 .12251 L
.90745 .12566 L
.91023 .12805 L
.91327 .13133 L
.91879 .13914 L
.9244 .14969 L
.92967 .16299 L
.9344 .17851 L
.93951 .19887 L
.95003 .2476 L
.95559 .27109 L
.9572 .27653 L
.95871 .28091 L
.96009 .28417 L
.96155 .28684 L
.9627 .28834 L
.96397 .28938 L
.96512 .28977 L
.9662 .28967 L
.96746 .289 L
.96863 .2879 L
.96997 .28608 L
.97124 .28387 L
.97556 .27364 L
.98027 .25965 L
1 .21522 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool2o`000003oa0@4?oooooooooo0;Oooooo
002]ooooo`03o`000?oooooooooo0;Sooooo002Rooooo`Ko00000_ooool5o`000;Wooooo002Zoooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0002`ooooo`00Z_ooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0;3ooooo002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0/?ooool00:_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2`ooooo`00
[?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o
0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0
003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooo
ooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
]Oooool2o`000;7ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooo
oooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3o
oooo002eooooo`03o`000?oooooooooo0;3ooooo002Zooooo`Go00001_ooool00ol0003ooooooooo
o`2`ooooo`00Z_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0/?oo
ool00:;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/?ooool0
0:cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo002]ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0/?ooool00:kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
/?ooool004?ooooo1Ol0001Rooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool;o`00077ooooo
00?o0000ooooooooool0=?ooool0047ooooo0ol00004ooooo`;o0000JOooool3o`0000[ooooo0ol0
001[ooooo`?o000000Coooooo`000?l0003o0000<oooool0043ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`1Vooooo`04o`000?ooooooooooo`0000gooooo00?o0000ooooooooool0
Ioooool2o`0000Kooooo0_l0000aooooo`00?oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo06Cooooo00Go0000ooooooooooooooooo`00000=ooooo`;o0000Ioooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo02kooooo000mooooo`;o00003?ooool00ol0003ooooooooo
o`1Rooooo`03o`000?oooooooooo00;ooooo0_l0000>ooooo`03o`000?oooooooooo06Cooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0^ooooo`00??ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0]
ooooo`00??ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo05oooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo067ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0/ooooo`00>oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo05kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo04Kooooo1?l0000Fooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool0:oooool003_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Dooooo`Co0000
AOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
AOooool2o`0000;ooooo0_l0000Eooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
:oooool003[ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Zooooo`00>Oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo0_l00005ooooo`03o`000?oooooo
oooo047ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo04?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0:Oooool003Wooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0@?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0@_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Yooooo`00>?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Ko
oooo0_l0000Booooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:?ooool003Sooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0?oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Xooooo`00=oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0looooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo02Sooooo000Eooooo`;o000000Wo410@ooooooooooooooooonk^
k_lb<S;o0000oc8b<_o^k^h05oooool02?l0003ooooooooooonHV9So410@o`000?lb<S;oc<c<0ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00?o0000ooooooooool04?ooool6o`0000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Looooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o
<S8bonk^kQCooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00[ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^6_ooool5o`00
00?ooooo00Kok^k^oc8b<_l0003o<S8bonk^k_l0000;ooooo`03o`000?oooooooooo00cooooo00Go
V9RHoa0@4?l0003o0000olc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00ol0003o
ooooooooo`0>ooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h03_oo
ool001Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Kooooo00Wo
0000oooooooooooooooooa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Oooooo00?o0000ooooooooool04?ooool01_l0003oV9RHob4Q8Oo^k^koooooodA4A0?ooooo
00GoMgMgoiRHV?oooooo0000ogMgM`0Nooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0Dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0J
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01_mgMgOoV9RHoooooonHV9SoMgMgo`0000_o
oooo00?o0000ooooooooool03?ooool01Ol@413o^[Zjooooool0003o<S8b00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000;ooooo`Ko00000_ooool5o`0000?ooooo00Go410@
oooooooooooooooooa0@400Booooo`Ko00001_ooool01Ol0003ooooooooooooooooo410@00?ooooo
00?o410@ooooooooool01Oooool00ol0003oooooooooo`09ooooo`Oo00000_ooool00onHV9So8B4Q
onk^kP04ooooo`05oa0@4?ooooooooooooooool000004oooool6o`0000Gooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@01?ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@01_ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooo
oooo000000cooooo00?o0000ooooooooool03oooool2o`0000?ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03o`000?oooooooooo00cooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@
41003_ooool001?ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo0000
01Gooooo00?o0000ooooooooool01Oooool00onYZJWo410@ooooo`02ooooo`05o`000?oooooooooo
ooooool000001oooool00ol0003oooooooooo`0?ooooo`07o`000?oooooooooooooooonHV9So8B4Q
onk^kP03ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000004oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo0000
00?o00006oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000003?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?l@413ooooo00;ooooo00Go0000ooooooooooooooooo`00
000=ooooo`03o`000?oooooooooo00_ooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooo
oooooooooooo000000kooooo000Cooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000oooooooo
ooooooooo`00000Dooooo`03o`000?oooooooooo00Gooooo00?o410@o`000?nj^[X00oooool01Ol0
003ooooooooooooooooo000000Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02
ooooo`03ogMgMomVIVKooooo00;ooooo00Co0000oooooooooooooooo0_l0000Mooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo
0_l00002ooooo`03o`000?oooooo000001_ooooo00?oMgMgofIVI_ooool00_ooool00ol0003ooooo
ooooo`02o`0000gooooo00?o0000ooooooooool03Oooool00ol@413o0000okZj^P03ooooo`05o`00
0?ooooooooooooooool000003Oooool00ol0003oooooooooo`0;ooooo`04omgMgOmEEEGoooooo`00
00Cooooo00Go0000ooooooooooooooooo`00000>ooooo`005?ooool00omgMgOoc<c<o`000004oooo
o`05oa0@4?ooooooooooooooool@41005?ooool00ol0003oooooooooo`06ooooo`03okZj^_lQ8B7o
oooo00;ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooool00000
7?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41004_ooool00ol0003o
ooooooooo`09ooooo`;o00005?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;o
oooo00Go410@o`000?oooooooooooa0@4002ooooo`03o`000?oooooooooo01Wooooo00Go0000oooo
oooooooooooooa0@4002ooooo`03o`000?l@413ooooo00cooooo00?o0000ooooooooool03_ooool0
0ol0003o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41003Oooool00ol0003ooooooooo
o`0<ooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@400>ooooo`005?oo
ool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool00ol0003ooooo
ooooo`04ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Sooooo00?o0000ooooooooool03Oooool02?l0003oooooooooool0003o^[ZjoooooonHV9So410@
0oooool01omgMgOoV9RHoooooonHV9SoMgMgooooool000007?ooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`05o`000?nHV9So
oooooiRHV?mgMgL00oooool00ol0003oooooooooo`0Dooooo`05o`000?nj^[[ooooooiRHV?l@4100
0oooool01OmgMgOoV9RHo`000?nHV9SoMgMg00gooooo00?o0000ooooooooool02oooool00ol@413o
V9RHooooo`02o`0000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0=ooooo`03o`000?oooooooooo
00cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo000Eoooo
o`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Cooooo`03o`000?oooooo
oooo00Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2?ooool00ol0003oooooooooo`0=ooooo`08o`000?oooooooooooiRHV?l@413o0000ob4Q8Oo<c<`3
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool00ol0003oooooooooo`0Gooooo`03oeEEEOmV
IVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Booooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`08ooooo`03oeEEEOmVIVKo000000Cooooo
00Go0000oc8b<_l0003o<S8bonk^kP03ooooo`03o`000?oooooooooo01Cooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00ol0003oooooooooo`0;
ooooo`05ojVYZOl@413o0000o`000?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo
00?o0000ooooooooool03?ooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03_ooool003;ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool09Oooool0027ooooo1?l0000=ooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo02Gooooo000Oooooo`;o00000oooool2o`0000_ooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04oooool5
o`0001_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo02Cooooo000Mooooo`;o00001oooool2o`0000Wooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool2o`00
00Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool09?ooool001_ooooo0_l0000;ooooo`03o`000?oooooooooo00Co
oooo0_l0000Oooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool09?ooool001Kooooo
ool00010o`0001?ooooo000Fooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`03ooooo`?o00001oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`04ooooo`;o00001oooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool01Oooool2o`0000Kooooo1?l00003ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool01Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`005_ooool2o`0000Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000Kooooo0_l00007ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool0
00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo000Fooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo017ooooo001@ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Aooooo`00D?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool03oooool2o`000003ooooool0003o000002Oooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool04_ooool0057ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo013ooooo0_l0000Yooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01;ooooo001Aooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo01?ooooo001Aooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01?ooooo001Aooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0<ooooo`;o00005ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04ooo
ool0057ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool05?ooool0057ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05?ooool0057o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03go
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool05Oooool0057ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05Oooool0057ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03gooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool05_ooool0057ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00;o00005_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo03gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool05_ooool0057ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Looooo`?o00005oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
03gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool05_ooool0057ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool2o`0001So
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Oo
oooo001Aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05oooool0057ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Hooooo`00D_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo01Sooooo001Booooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool06?ooool005;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0hooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Iooooo`00
D_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Wooooo001Booooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo043ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Pooooo`05o`000?oo
ooooooooooooool000007?ooool005;ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03_ooool2o`0001Wooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool08?ooool01Ol0003ooooooooooooooooo000001cooooo001Booooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo043ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Qooooo`04o`000?oo
oooo0000o`0001cooooo001Booooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0>Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Qooooo`?o00007Oooool005;ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0@?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo047ooooo001Booooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
043ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`11ooooo`00D_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`10ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0@Oooool005?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool00oooool5o`0000Kooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`11ooooo`00Doooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
@Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo047ooooo001Cooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Gooooo00?oV9RHob4Q8Oo^k^h01oooool3o`0001Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0@Ooo
ool005?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01_ooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`11ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0@Oooool005?ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0looooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00omg
MgOoIVIVooooo`05ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`11ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0@_ooool005?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0@_ooool005?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0looooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool01Ol0003o^[Zj
oooooonHV9So410@00Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo04;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`12ooooo`00
Doooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`04ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003o
ooooooooo`0Jooooo`05o`000?ooooooooooooooool00000AOooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo04;ooooo001Cooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0??ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool06_ooool01Ol0003ooooooooooooooooo000004Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`12ooooo`00Doooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01[o
oooo00Go0000ooooooooooooooooo`000015ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0@_ooool005?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0looooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool04?ooool2o`0001_ooooo00Go0000oooooooo
ooooooooo`000015ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0@_ooool005Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Jooooo`05o`000?oooooooooooooo
ool00000AOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04;ooooo001Dooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool06oooool00ol0003oooooo`000016ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0@_ooool005Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo000004Kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`12ooooo`00E?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo03kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooool00000A_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo04;ooooo001Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0?_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool07?ooool2
o`0004Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`12ooooo`00E?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`13ooooo`00E?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo06Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`13ooooo`00E?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`13ooooo`00E?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`;o0000I_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo04?ooooo001Dooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0?oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0IOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04?ooooo001Eoooo
o`05o`000?ooooooooooooooool00000@Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo04?ooooo001Eooooo`04o`000?ooooooooooo`0004;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`13ooooo`00EOooool01?l0003oooooooooool00013ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0@oooool005Gooooo00Co0000oooooooooooo0000@oooool0
1Ol0003ooooooooooooooooo000001Cooooo00?o0000ooooooooool0IOooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo04?ooooo001Eooooo`04o`000?ooooooooooo`0004?ooooo00Go
0000ooooooooooooooooo`00000Dooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`13ooooo`00EOooool01?l0003oooooooooool00013ooooo`05o`00
0?ooooooooooooooool000005?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0@oooool005Gooooo00Co0000oooooooooooo0000@oooool01Ol0003o
oooooooooooooooo000001Cooooo0_l0001Vooooo`05o`000?ooooooooooooooool00000A_ooool0
05Gooooo00Co0000oooooooooooo0000@oooool01Ol0003ooooooooooooooooo000001Cooooo00?o
0000ooooooooool0IOooool01Ol0003ooooooooooooooooo000004Kooooo001Fooooo`03o`000?oo
oooo000004?ooooo00Go0000ooooooooooooooooo`00000Dooooo`03o`000?oooooooooo06Gooooo
00Go0000ooooooooooooooooo`000016ooooo`00E_ooool00ol0003oooooo`000013ooooo`05o`00
0?ooooooooooooooool000005?ooool00ol0003oooooooooo`1Uooooo`05o`000?oooooooooooooo
ool00000A_ooool005Kooooo00?o0000ooooool00000A?ooool01?l0003oooooooooool0000Doooo
o`03o`000?oooooooooo06Gooooo00Go0000ooooooooooooooooo`000016ooooo`00Eoooool00ol0
003oooooooooo`13ooooo`03o`000?oooooo000000cooooo0_l000000ol@413oooooooooo`04oooo
o`03o`000?oooooooooo06Gooooo00Go0000ooooooooooooooooo`000016ooooo`00WOooool3o`00
00gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Uooooo`05o`000?oooooooooo
ooooool00000A_ooool009kooooo00?o0000ooooooooool02Oooool5o`0000Kooooo00?o0000oooo
ooooool0IOooool01Ol0003ooooooooooooooooo000004Kooooo002Zooooo`04odA4A?oMgMgooooo
o`0000Oooooo0ol0001Uooooo`05o`000?ooooooooooooooool00000A_ooool00:[ooooo00CogMgM
oeEEEOoooooo00001oooool00ol0003oooooooooo`1Vooooo`04o`000?ooooooooooo`0004Kooooo
002[ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0I_ooool01?l0003ooooooooo
ool00016ooooo`00Zoooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo06Kooooo00Co
0000oooooooooooo0000A_ooool00:cooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooooooo
o`1Vooooo`04o`000?ooooooooooo`0004Kooooo002eooooo`03o`000?oooooooooo06Kooooo00Co
0000oooooooooooo0000A_ooool00;Gooooo00?o0000ooooooooool0I_ooool00ol0003oooooo`00
0017ooooo`00]Oooool00ol0003oooooooooo`1Vooooo`03o`000?oooooo000004Oooooo002eoooo
o`;o0000J?ooool2o`0004Oooooo002eooooo`03o`000?oooooooooo06Oooooo0_l00017ooooo`00
]Oooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo04Gooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool0
0;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo
0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`
ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00
Z_ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0/?ooool00:[ooooo
00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003oV9RH
oooooonHV9So8B4Q00Kooooo0ol0002`ooooo`00Z_ooool01Ol0003oEEEEo`000?l@413oc<c<00Ko
oooo00?o0000ooooooooool0/?ooool00:[ooooo00?oEEEEohN7Qoooool02?ooool00ol0003ooooo
ooooo`2`ooooo`00Z_ooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo0;3ooooo002[
ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000
ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooooooo
ool0/?ooool00;Gooooo0_l0002aooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool0
0ol0003oooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003o
ooooooooo`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool00ol0003ooooooooo
o`2`ooooo`00]Oooool00ol0003oooooooooo`2`ooooo`00]Oooool2o`000;7ooooo002eooooo`03
o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oo
oooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo
0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo002eooooo`03o`000?oooooooooo0;3ooooo
002eooooo`;o0000/Oooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000oooo
ooooool0/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00;Gooooo00?o0000ooooooooool0
/?ooool00;Gooooo00?o0000ooooooooool0/?ooool00:[ooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<
c006ooooo`03o`000?oooooooooo0;3ooooo002Zooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_oo
ool00ol0003oooooooooo`2`ooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool0/?ooool00:[ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000/?oo
ool00:[ooooo00Goc<c<o`000?l0003o0000olc<c02iooooo`00Z_ooool01Ol@413o^[Zjoooooonj
^[[o410@0;Wooooo002Zooooo`05o`000?nj^[[ooooookZj^_l00000^Oooool00:[ooooo00GoZJVY
oa0@4?l0003o410@ojVYZ@2iooooo`00oooooomYooooo`00[oooool00ol0003o^[Zjooooo`2foooo
o`00[oooool2oc8b<[Oooooo0020ooooo`;o000000Ko410@oooooooooooo410@o`000?l@410Hoooo
o`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?o
QhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Wooooo1?l000001Ol@413ooooo
ooooooooooooA4A400;o000000Wo<S8bomgMgOooooooooooonk^k_lb<S;o0000oc8b<_o^k^h0N?oo
ool0087ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`Ko00003Oooool0
2OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03olc<c?l0003o410@00co
oooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003oooooooooo`06oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg07Sooooo0021ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool06oooool01?l0003oooooooooool@4103ooooo`03oa0@
4?oooooooooo013ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooooooooa0@40?ooooo00?o410@ooooooooool0M_ooool0087ooooo00Ko0000oooooom4A4Co
A4A4ooooool00009ooooo`Ko00003Oooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`Ko00003?ooool00ol0003oooooooooo`06
ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`1fooooo`00POooool0
1_l0003ogMgMoc8b<_mEEEGogMgMo`0001Wooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05
o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool00000N?oo
ool0087ooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Iooooo`03o`000?oooooooooo00Cooooo
00Go410@oooooooooooooooooa0@400@ooooo`03oa0@4?l0003o000000?o00007?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@401hoooo
o`00POooool01_l0003o<S8boooooooooooo<S8bo`0001Wooooo00?o0000ooooooooool01?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1hooooo`00P?oo
ool00ol@413o0000ohN7Q`02ooooo`03ohN7Qol0003o410@01Sooooo1?l00003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h04_ooool00ol0003oooooooooo`0Kooooo`03oeEEEOmVIVKo000000Gooooo
1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0N?ooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-45.5745, -4.3431, 0.31409, \
0.0762314}}]
}, Closed]],

Cell["Fig. 7.7 (animation)  A solution of the KdV equation", "Caption",
  CellTags->"Fig. 7.7"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 -1.11022e-16 1.16608 [
[.5 1.098 -41.125 0 ]
[.5 1.098 41.125 24.5 ]
[.09072 .22988 -5.91576 -9 ]
[.09072 .22988 .08424 0 ]
[.22151 .17463 -5.64878 -9 ]
[.22151 .17463 .35122 0 ]
[.35968 .11629 -5.38181 -9 ]
[.35968 .11629 .61819 0 ]
[.50588 .0546 -5.11483 -9 ]
[.50588 .0546 .88517 0 ]
[.66081 -0.01073 -4.84785 -9 ]
[.66081 -0.01073 1.15215 0 ]
[.30907 .06148 -8.98592 -12 ]
[.30907 .06148 1.01408 0 ]
[.00955 .82643 -3.46362 0 ]
[.00955 .82643 2.53638 9 ]
[.12079 .90442 -6.71106 0 ]
[.12079 .90442 5.28894 9 ]
[.22056 .97437 -6.52538 0 ]
[.22056 .97437 5.47462 9 ]
[.31055 1.03745 -6.36418 0 ]
[.31055 1.03745 5.63582 9 ]
[.39213 1.09464 -6.2229 0 ]
[.39213 1.09464 5.7771 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12 ]
[.07325 .26228 -6 -2.6177 ]
[.07325 .26228 0 6.3823 ]
[.0469 .42724 -18 -2.76445 ]
[.0469 .42724 0 6.23555 ]
[.01721 .61309 -18 -2.93177 ]
[.01721 .61309 0 6.06823 ]
[-0.03373 .52941 -45.25 -3.77786 ]
[-0.03373 .52941 0 8.22214 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.098 -102.125 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(wave) show
93.125 13.000 moveto
(spectrum) show
69.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.10087 .24033 m
.10595 .24556 L
s
[(0)] .09072 .22988 .97192 1 Mshowa
.23115 .18555 m
.23598 .19102 L
s
[(1)] .22151 .17463 .88293 1 Mshowa
.36874 .1277 m
.37327 .13341 L
s
[(2)] .35968 .11629 .79394 1 Mshowa
.51427 .06651 m
.51847 .07247 L
s
[(3)] .50588 .0546 .70494 1 Mshowa
.66846 .00168 m
.67228 .00789 L
s
[(4)] .66081 -0.01073 .61595 1 Mshowa
.125 Mabswid
.12637 .22961 m
.12939 .23277 L
s
.15215 .21877 m
.15514 .22196 L
s
.1782 .20782 m
.18116 .21104 L
s
.20453 .19675 m
.20746 .19999 L
s
.25807 .17424 m
.26093 .17754 L
s
.28528 .16279 m
.28811 .16613 L
s
.31279 .15123 m
.31558 .15459 L
s
.34061 .13953 m
.34337 .14292 L
s
.39719 .11574 m
.39987 .11919 L
s
.42596 .10364 m
.42861 .10713 L
s
.45507 .09141 m
.45767 .09492 L
s
.4845 .07903 m
.48706 .08257 L
s
.54439 .05385 m
.54687 .05745 L
s
.57487 .04103 m
.5773 .04467 L
s
.6057 .02807 m
.60808 .03173 L
s
.63689 .01495 m
.63923 .01865 L
s
gsave
.30907 .06148 -69.9859 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.01178 .81203 m
.01289 .80482 L
s
[(0)] .00955 .82643 .15454 -1 Mshowa
.1225 .88995 m
.12336 .88271 L
s
[(10)] .12079 .90442 .11851 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(20)] .22056 .97437 .08756 -1 Mshowa
.31143 1.0229 m
.31187 1.01563 L
s
[(30)] .31055 1.03745 .0607 -1 Mshowa
.39267 1.08007 m
.39294 1.07279 L
s
[(40)] .39213 1.09464 .03715 -1 Mshowa
.125 Mabswid
.03493 .82832 m
.03556 .82399 L
s
.05756 .84424 m
.05816 .83991 L
s
.07969 .85982 m
.08026 .85548 L
s
.10133 .87505 m
.10187 .87071 L
s
.14322 .90453 m
.14371 .90018 L
s
.1635 .9188 m
.16396 .91445 L
s
.18335 .93277 m
.18378 .92842 L
s
.20279 .94645 m
.2032 .9421 L
s
.24048 .97297 m
.24084 .96861 L
s
.25875 .98583 m
.25909 .98147 L
s
.27666 .99844 m
.27697 .99407 L
s
.29422 1.01079 m
.29451 1.00643 L
s
.32831 1.03478 m
.32855 1.03041 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.3611 1.05786 m
.3613 1.05349 L
s
.37703 1.06907 m
.37721 1.0647 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.0867 .25665 m
.09342 .25384 L
s
[(0)] .07325 .26228 1 -0.41829 Mshowa
.0605 .42199 m
.0673 .41937 L
s
[(0.1)] .0469 .42724 1 -0.38568 Mshowa
.03097 .60829 m
.03785 .60589 L
s
[(0.2)] .01721 .61309 1 -0.3485 Mshowa
.125 Mabswid
.0817 .28822 m
.08574 .28655 L
s
.07658 .32051 m
.08063 .31886 L
s
.07134 .35355 m
.0754 .35193 L
s
.06598 .38737 m
.07005 .38577 L
s
.05488 .45746 m
.05897 .45591 L
s
.04912 .49378 m
.05322 .49226 L
s
.04322 .53101 m
.04733 .52951 L
s
.03717 .56917 m
.04129 .5677 L
s
.02461 .64842 m
.02875 .64701 L
s
.01809 .6896 m
.02224 .68822 L
s
.01139 .73186 m
.01555 .73051 L
s
.00452 .77524 m
.00869 .77393 L
s
gsave
-0.03373 .52941 -106.25 -7.77786 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(\\310) show
69.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
75.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
80.250 13.000 moveto
(H) show
86.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
92.250 13.000 moveto
(L) show
98.250 13.000 moveto
(\\310) show
104.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.4186 .578 m
.42216 .58164 L
s
.41502 .57434 m
.4186 .578 L
s
.41143 .57067 m
.41502 .57434 L
s
.40782 .56698 m
.41143 .57067 L
s
.40419 .56327 m
.40782 .56698 L
s
.40055 .55955 m
.40419 .56327 L
s
.39689 .55581 m
.40055 .55955 L
s
.39322 .55206 m
.39689 .55581 L
s
.38953 .54829 m
.39322 .55206 L
s
.49063 .58498 m
.49428 .57325 L
s
.38583 .5445 m
.38953 .54829 L
s
.3821 .54069 m
.38583 .5445 L
s
.37836 .53687 m
.3821 .54069 L
s
.49981 .59432 m
.50342 .58113 L
s
.48648 .63203 m
.49063 .58498 L
s
.37461 .53303 m
.37836 .53687 L
s
.37084 .52917 m
.37461 .53303 L
s
.51839 .65405 m
.52202 .58017 L
s
.50899 .62234 m
.51265 .59042 L
s
.36705 .5253 m
.37084 .52917 L
s
.49595 .62742 m
.49981 .59432 L
s
.36324 .52141 m
.36705 .5253 L
s
.35941 .5175 m
.36324 .52141 L
s
.35557 .51357 m
.35941 .5175 L
s
.35171 .50962 m
.35557 .51357 L
s
.34784 .50566 m
.35171 .50962 L
s
.58494 .55129 m
.59004 .64304 L
s
.58314 .63365 m
.58494 .55129 L
s
.50521 .65711 m
.50899 .62234 L
s
.34394 .50168 m
.34784 .50566 L
s
.54712 .60891 m
.55047 .60111 L
s
.48216 .68228 m
.48648 .63203 L
s
.55672 .60375 m
.56 .59442 L
s
.49194 .66516 m
.49595 .62742 L
s
.34003 .49768 m
.34394 .50168 L
s
.64246 .51401 m
.64644 .53742 L
s
.64055 .54553 m
.64246 .51401 L
s
.3361 .49366 m
.34003 .49768 L
s
.47389 .53374 m
.47658 .59536 L
s
.46998 .54544 m
.47389 .53374 L
s
.5439 .64832 m
.54712 .60891 L
s
.33215 .48963 m
.3361 .49366 L
s
.55359 .63611 m
.55672 .60375 L
s
.5357 .53821 m
.53922 .5549 L
s
.53231 .58621 m
.5357 .53821 L
s
.60484 .56987 m
.60809 .57098 L
s
.44159 .71848 m
.44528 .72261 L
s
.43189 .73081 m
.43565 .73295 L
s
.64918 .51081 m
.65279 .52424 L
s
.64611 .51104 m
.64918 .51081 L
s
.53922 .5549 m
.54293 .60368 L
s
.32819 .48557 m
.33215 .48963 L
s
.66262 .52072 m
.66584 .52518 L
s
.61458 .56613 m
.61788 .56949 L
s
.60383 .52568 m
.60783 .55481 L
s
.60071 .53061 m
.60383 .52568 L
s
.4796 .71049 m
.48353 .69307 L
s
.65279 .52424 m
.65629 .53505 L
s
.43794 .71273 m
.44159 .71848 L
s
.60188 .58184 m
.60484 .56987 L
s
.67234 .51401 m
.67559 .51949 L
s
.48324 .53991 m
.48602 .60762 L
s
.47922 .5616 m
.48324 .53991 L
s
.42812 .72801 m
.43189 .73081 L
s
.3242 .4815 m
.32819 .48557 L
s
.6595 .51863 m
.66262 .52072 L
s
.59531 .58241 m
.59904 .60215 L
s
.5918 .57177 m
.59531 .58241 L
s
.43429 .70606 m
.43794 .71273 L
s
.58891 .592 m
.5918 .57177 L
s
.46395 .56137 m
.46657 .61963 L
s
.46015 .56319 m
.46395 .56137 L
s
.68216 .50909 m
.68543 .51512 L
s
.51452 .7385 m
.51839 .65405 L
s
.56664 .62217 m
.57001 .6212 L
s
.61148 .57027 m
.61458 .56613 L
s
.70123 .48786 m
.70472 .49834 L
s
.66911 .50914 m
.67234 .51401 L
s
.6987 .49435 m
.70123 .48786 L
s
.69193 .50263 m
.69517 .50845 L
s
.64414 .5404 m
.64611 .51104 L
s
.43064 .69931 m
.43429 .70606 L
s
.46515 .60075 m
.46998 .54544 L
s
.6792 .50917 m
.68216 .50909 L
s
.5013 .69627 m
.50521 .65711 L
s
.42435 .72485 m
.42812 .72801 L
s
.3202 .4774 m
.3242 .4815 L
s
.71148 .4893 m
.71463 .49416 L
s
.66577 .50215 m
.66911 .50914 L
s
.68928 .50796 m
.69193 .50263 L
s
.42696 .69321 m
.43064 .69931 L
s
.65633 .5161 m
.6595 .51863 L
s
.59815 .56123 m
.60071 .53061 L
s
.62458 .56913 m
.62803 .57747 L
s
.72141 .48466 m
.72453 .48932 L
s
.60783 .55481 m
.61148 .57027 L
s
.66288 .50538 m
.66577 .50215 L
s
.70824 .48315 m
.71148 .4893 L
s
.56369 .66116 m
.56664 .62217 L
s
.62158 .5755 m
.62458 .56913 L
s
.42323 .68832 m
.42696 .69321 L
s
.45477 .63365 m
.46015 .56319 L
s
.31617 .47329 m
.3202 .4774 L
s
.49266 .54796 m
.49493 .68846 L
s
.48849 .58932 m
.49266 .54796 L
s
.42056 .72164 m
.42435 .72485 L
s
.73128 .4787 m
.73445 .48444 L
s
.6343 .56213 m
.63786 .57386 L
s
.63183 .58247 m
.6343 .56213 L
s
.48786 .69932 m
.49194 .66516 L
s
.71842 .48216 m
.72141 .48466 L
s
.67636 .51219 m
.6792 .50917 L
s
.65306 .51142 m
.65633 .5161 L
s
.70503 .47761 m
.70824 .48315 L
s
.63861 .57851 m
.64055 .54553 L
s
.41943 .68495 m
.42323 .68832 L
s
.59875 .5885 m
.60188 .58184 L
s
.59646 .48736 m
.60068 .52616 L
s
.59344 .4999 m
.59646 .48736 L
s
.74133 .47507 m
.74449 .48072 L
s
.72846 .47831 m
.73128 .4787 L
s
.6964 .50528 m
.6987 .49435 L
s
.31213 .46916 m
.31617 .47329 L
s
.41674 .71866 m
.42056 .72164 L
s
.47479 .78074 m
.4796 .71049 L
s
.70275 .48807 m
.70503 .47761 L
s
.6495 .50017 m
.65306 .51142 L
s
.64664 .50615 m
.6495 .50017 L
s
.47769 .73258 m
.48216 .68228 L
s
.75146 .47187 m
.75452 .4765 L
s
.68675 .51621 m
.68928 .50796 L
s
.54906 .57933 m
.55282 .61511 L
s
.5456 .58207 m
.54906 .57933 L
s
.61433 .54836 m
.61798 .56293 L
s
.61132 .55656 m
.61433 .54836 L
s
.73875 .4776 m
.74133 .47507 L
s
.71557 .48211 m
.71842 .48216 L
s
.41556 .68308 m
.41943 .68495 L
s
.66019 .51383 m
.66288 .50538 L
s
.30807 .46501 m
.31213 .46916 L
s
.55023 .65043 m
.55359 .63611 L
s
.61798 .56293 m
.62158 .5755 L
s
.41289 .71609 m
.41674 .71866 L
s
.54293 .60368 m
.54664 .63854 L
s
.47463 .61348 m
.47922 .5616 L
s
.76147 .46672 m
.76467 .47333 L
s
.72565 .47846 m
.72846 .47831 L
s
.58671 .65212 m
.58891 .592 L
s
.7488 .47286 m
.75146 .47187 L
s
.67358 .51705 m
.67636 .51219 L
s
.54057 .68854 m
.5439 .64832 L
s
.47658 .59536 m
.47943 .65399 L
s
.77174 .46447 m
.77466 .46782 L
s
.53777 .67641 m
.54131 .68201 L
s
.59159 .56432 m
.59531 .58277 L
s
.58809 .55628 m
.59159 .56432 L
s
.304 .46084 m
.30807 .46501 L
s
.75865 .46507 m
.76147 .46672 L
s
.41163 .68224 m
.41556 .68308 L
s
.59531 .58277 m
.59875 .5885 L
s
.409 .71405 m
.41289 .71609 L
s
.71246 .47839 m
.71557 .48211 L
s
.58533 .58727 m
.58809 .55628 L
s
.54221 .60525 m
.5456 .58207 L
s
.54108 .52867 m
.5449 .58355 L
s
.53759 .53761 m
.54108 .52867 L
s
.73613 .47997 m
.73875 .4776 L
s
.53432 .71217 m
.53777 .67641 L
s
.78186 .45985 m
.78488 .46457 L
s
.57675 .64162 m
.58072 .67671 L
s
.57436 .70948 m
.57675 .64162 L
s
.64439 .52912 m
.64664 .50615 L
s
.76878 .46076 m
.77174 .46447 L
s
.2999 .45665 m
.304 .46084 L
s
.72269 .47655 m
.72565 .47846 L
s
.69404 .51605 m
.6964 .50528 L
s
.43573 .71603 m
.43923 .72968 L
s
.43213 .7059 m
.43573 .71603 L
s
.74628 .47593 m
.7488 .47286 L
s
.59036 .51185 m
.59344 .4999 L
s
.64216 .57175 m
.64414 .5404 L
s
.4284 .69998 m
.43213 .7059 L
s
.68401 .52107 m
.68675 .51621 L
s
.60828 .56542 m
.61132 .55656 L
s
.70898 .46861 m
.71246 .47839 L
s
.75605 .46663 m
.75865 .46507 L
s
.40767 .68156 m
.41163 .68224 L
s
.52878 .63195 m
.53231 .58621 L
s
.70056 .5008 m
.70275 .48807 L
s
.40506 .71252 m
.409 .71405 L
s
.66276 .48151 m
.66653 .497 L
s
.65988 .48596 m
.66276 .48151 L
s
.43923 .72968 m
.44269 .74551 L
s
.79214 .45662 m
.79515 .46154 L
s
.62876 .58633 m
.63183 .58247 L
s
.70629 .47213 m
.70898 .46861 L
s
.77909 .45813 m
.78186 .45985 L
s
.65731 .51875 m
.66019 .51383 L
s
.46657 .61963 m
.46943 .67107 L
s
.67033 .51275 m
.67358 .51705 L
s
.60068 .52616 m
.60472 .55557 L
s
.55089 .52934 m
.55511 .60996 L
s
.54746 .53803 m
.55089 .52934 L
s
.42454 .69797 m
.4284 .69998 L
s
.29578 .45244 m
.2999 .45665 L
s
.55282 .61511 m
.55667 .65583 L
s
.7656 .4545 m
.76878 .46076 L
s
.66653 .497 m
.67033 .51275 L
s
.44269 .74551 m
.44614 .76163 L
s
.80243 .4532 m
.80538 .45762 L
s
.59529 .58242 m
.59815 .56123 L
s
.71984 .47666 m
.72269 .47655 L
s
.58177 .75246 m
.58314 .63365 L
s
.78943 .45529 m
.79214 .45662 L
s
.54664 .63854 m
.55023 .65043 L
s
.48602 .60762 m
.48872 .69428 L
s
.73308 .47644 m
.73613 .47997 L
s
.60703 .51214 m
.61066 .5249 L
s
.60378 .51394 m
.60703 .51214 L
s
.49729 .73244 m
.5013 .69627 L
s
.44614 .76163 m
.44966 .77551 L
s
.40109 .71137 m
.40506 .71252 L
s
.76303 .45597 m
.7656 .4545 L
s
.52324 .48877 m
.52683 .55262 L
s
.51957 .5143 m
.52324 .48877 L
s
.40372 .67994 m
.40767 .68156 L
s
.44966 .77551 m
.45329 .78467 L
s
.61066 .5249 m
.61485 .55719 L
s
.77626 .45589 m
.77909 .45813 L
s
.81275 .4496 m
.81567 .4539 L
s
.29165 .44822 m
.29578 .45244 L
s
.64631 .47947 m
.65001 .49341 L
s
.64313 .4787 m
.64631 .47947 L
s
.42056 .69849 m
.42454 .69797 L
s
.75353 .46939 m
.75605 .46663 L
s
.79978 .45211 m
.80243 .4532 L
s
.74337 .47409 m
.74628 .47593 L
s
.53413 .57696 m
.53759 .53761 L
s
.48381 .72336 m
.48786 .69932 L
s
.65001 .49341 m
.6539 .51194 L
s
.68065 .51432 m
.68401 .52107 L
s
.62523 .57709 m
.62876 .58633 L
s
.72969 .46824 m
.73308 .47644 L
s
.70387 .48063 m
.70629 .47213 L
s
.65691 .48907 m
.65988 .48596 L
s
.56037 .67509 m
.56369 .66116 L
s
.45358 .51591 m
.4558 .58752 L
s
.44997 .50571 m
.45358 .51591 L
s
.63598 .59452 m
.63861 .57851 L
s
.78657 .45242 m
.78943 .45529 L
s
.67693 .50055 m
.68065 .51432 L
s
.67367 .49611 m
.67693 .50055 L
s
.82311 .446 m
.82608 .45099 L
s
.62205 .57904 m
.62523 .57709 L
s
.6539 .51194 m
.65731 .51875 L
s
.4443 .57269 m
.44997 .50571 L
s
.56705 .51456 m
.57088 .54238 L
s
.56468 .60301 m
.56705 .51456 L
s
.71681 .47425 m
.71984 .47666 L
s
.81 .44715 m
.81275 .4496 L
s
.28749 .44397 m
.29165 .44822 L
s
.72641 .46162 m
.72969 .46824 L
s
.39709 .71028 m
.40109 .71137 L
s
.39982 .67656 m
.40372 .67994 L
s
.53138 .5631 m
.53504 .59836 L
s
.52779 .56371 m
.53138 .5631 L
s
.60472 .55557 m
.60828 .56542 L
s
.52445 .70037 m
.52807 .75832 L
s
.52055 .86616 m
.52445 .70037 L
s
.69117 .51804 m
.69404 .51605 L
s
.60996 .49157 m
.61394 .51644 L
s
.60666 .49156 m
.60996 .49157 L
s
.77323 .45147 m
.77626 .45589 L
s
.63944 .46514 m
.64313 .4787 L
s
.63622 .4641 m
.63944 .46514 L
s
.48371 .6665 m
.48849 .58932 L
s
.60018 .50252 m
.60378 .51394 L
s
.59679 .50012 m
.60018 .50252 L
s
.58687 .50602 m
.59036 .51185 L
s
.66277 .46011 m
.66678 .48028 L
s
.65936 .45309 m
.66277 .46011 L
s
.83355 .44277 m
.83639 .44673 L
s
.76055 .45904 m
.76303 .45597 L
s
.74024 .46943 m
.74337 .47409 L
s
.58415 .53308 m
.58805 .55968 L
s
.58059 .52429 m
.58415 .53308 L
s
.79701 .44999 m
.79978 .45211 L
s
.54414 .57621 m
.54746 .53803 L
s
.72352 .46107 m
.72641 .46162 L
s
.41655 .69923 m
.42056 .69849 L
s
.82024 .44203 m
.82311 .446 L
s
.67049 .49367 m
.67367 .49611 L
s
.69793 .50665 m
.70056 .5008 L
s
.61994 .4879 m
.62428 .52209 L
s
.61657 .48436 m
.61994 .4879 L
s
.4603 .64966 m
.46515 .60075 L
s
.5774 .53755 m
.58059 .52429 L
s
.28331 .4397 m
.28749 .44397 L
s
.78366 .44917 m
.78657 .45242 L
s
.65613 .45039 m
.65936 .45309 L
s
.39596 .67152 m
.39982 .67656 L
s
.75074 .46894 m
.75353 .46939 L
s
.76993 .44392 m
.77323 .45147 L
s
.71327 .46413 m
.71681 .47425 L
s
.5834 .50189 m
.58687 .50602 L
s
.80732 .44567 m
.81 .44715 L
s
.53869 .61509 m
.54221 .60525 L
s
.84397 .43903 m
.84684 .44345 L
s
.70969 .4532 m
.71327 .46413 L
s
.39308 .7088 m
.39709 .71028 L
s
.7068 .45373 m
.70969 .4532 L
s
.67293 .45797 m
.67679 .47413 L
s
.66965 .45344 m
.67293 .45797 L
s
.73723 .46658 m
.74024 .46943 L
s
.8307 .43891 m
.83355 .44277 L
s
.64175 .54341 m
.64439 .52912 L
s
.62996 .48412 m
.63441 .51903 L
s
.62651 .47737 m
.62996 .48412 L
s
.59386 .51947 m
.59679 .50012 L
s
.61876 .57848 m
.62205 .57904 L
s
.63386 .48759 m
.63622 .4641 L
s
.65342 .48056 m
.65691 .48907 L
s
.52414 .61583 m
.52779 .56371 L
s
.76725 .44406 m
.76993 .44392 L
s
.60353 .4991 m
.60666 .49156 L
s
.66678 .48028 m
.67049 .49367 L
s
.61485 .55719 m
.61876 .57848 L
s
.81752 .43985 m
.82024 .44203 L
s
.64975 .46782 m
.65342 .48056 L
s
.64638 .46243 m
.64975 .46782 L
s
.39212 .66582 m
.39596 .67152 L
s
.56099 .54955 m
.56583 .65966 L
s
.55741 .54054 m
.56099 .54955 L
s
.79405 .4459 m
.79701 .44999 L
s
.55667 .65583 m
.56037 .67509 L
s
.68777 .51073 m
.69117 .51804 L
s
.27912 .43541 m
.28331 .4397 L
s
.61346 .49023 m
.61657 .48436 L
s
.47943 .65399 m
.48252 .70351 L
s
.59589 .46003 m
.59974 .48128 L
s
.59312 .48652 m
.59589 .46003 L
s
.61394 .51644 m
.61763 .5303 L
s
.67679 .47413 m
.68083 .4938 L
s
.78083 .447 m
.78366 .44917 L
s
.85448 .43574 m
.85733 .44011 L
s
.58272 .63193 m
.58533 .58727 L
s
.57088 .54238 m
.57564 .62666 L
s
.58024 .51611 m
.5834 .50189 L
s
.72055 .45959 m
.72352 .46107 L
s
.55442 .59844 m
.55741 .54054 L
s
.62378 .49332 m
.62651 .47737 L
s
.65267 .4427 m
.65613 .45039 L
s
.4126 .69766 m
.41655 .69923 L
s
.84121 .43572 m
.84397 .43903 L
s
.46301 .52547 m
.46532 .60343 L
s
.45933 .51729 m
.46301 .52547 L
s
.61763 .5303 m
.62148 .54926 L
s
.66645 .45097 m
.66965 .45344 L
s
.53708 .71462 m
.54057 .68854 L
s
.70106 .48326 m
.70387 .48063 L
s
.55936 .62779 m
.56342 .67762 L
s
.55581 .62324 m
.55936 .62779 L
s
.68439 .5039 m
.68777 .51073 L
s
.47315 .77895 m
.47769 .73258 L
s
.5449 .58355 m
.54873 .62492 L
s
.75783 .45923 m
.76055 .45904 L
s
.80455 .44329 m
.80732 .44567 L
s
.82774 .43404 m
.8307 .43891 L
s
.38824 .66063 m
.39212 .66582 L
s
.38908 .70661 m
.39308 .7088 L
s
.73396 .46018 m
.73723 .46658 L
s
.74769 .4653 m
.75074 .46894 L
s
.58805 .55968 m
.59191 .58225 L
s
.64346 .46891 m
.64638 .46243 L
s
.59191 .58225 m
.59529 .58242 L
s
.45423 .56953 m
.45933 .51729 L
s
.64955 .44339 m
.65267 .4427 L
s
.53083 .7938 m
.53432 .71217 L
s
.86499 .43204 m
.86779 .43623 L
s
.79099 .44079 m
.79405 .4459 L
s
.2749 .4311 m
.27912 .43541 L
s
.49813 .6006 m
.50126 .67428 L
s
.49307 .73031 m
.49813 .6006 L
s
.46943 .67107 m
.47262 .70781 L
s
.8149 .43879 m
.81752 .43985 L
s
.70358 .44913 m
.7068 .45373 L
s
.63976 .59394 m
.64216 .57175 L
s
.85174 .43236 m
.85448 .43574 L
s
.68083 .4938 m
.68439 .5039 L
s
.43948 .53845 m
.44292 .55622 L
s
.43289 .62696 m
.43948 .53845 L
s
.67982 .45003 m
.68348 .46203 L
s
.6766 .44669 m
.67982 .45003 L
s
.6948 .50424 m
.69793 .50665 L
s
.41884 .84723 m
.42284 .84686 L
s
.68348 .46203 m
.68737 .47832 L
s
.76467 .44568 m
.76725 .44406 L
s
.53504 .59836 m
.53869 .61509 L
s
.55238 .63536 m
.55581 .62324 L
s
.73036 .44929 m
.73396 .46018 L
s
.72692 .44063 m
.73036 .44929 L
s
.77773 .44185 m
.78083 .447 L
s
.59974 .48128 m
.60353 .4991 L
s
.63302 .60279 m
.63598 .59452 L
s
.62148 .54926 m
.62579 .58183 L
s
.83842 .43226 m
.84121 .43572 L
s
.38428 .65677 m
.38824 .66063 L
s
.82495 .43096 m
.82774 .43404 L
s
.40876 .69212 m
.4126 .69766 L
s
.71714 .45163 m
.72055 .45959 L
s
.66357 .45562 m
.66645 .45097 L
s
.87555 .42843 m
.87836 .43287 L
s
.68992 .44471 m
.6938 .46062 L
s
.68662 .43947 m
.68992 .44471 L
s
.74431 .45737 m
.74769 .4653 L
s
.72377 .43635 m
.72692 .44063 L
s
.47005 .65607 m
.47463 .61348 L
s
.78802 .4369 m
.79099 .44079 L
s
.38508 .70385 m
.38908 .70661 L
s
.80168 .44011 m
.80455 .44329 L
s
.51052 .80636 m
.51452 .7385 L
s
.86227 .42866 m
.86499 .43204 L
s
.51569 .57854 m
.51957 .5143 L
s
.27067 .42677 m
.2749 .4311 L
s
.47988 .73363 m
.48381 .72336 L
s
.68737 .47832 m
.69128 .49495 L
s
.7 .43856 m
.70358 .44913 L
s
.44292 .55622 m
.44507 .62482 L
s
.71353 .44061 m
.71714 .45163 L
s
.62428 .52209 m
.62842 .54866 L
s
.44899 .71235 m
.45477 .63365 L
s
.52611 .65626 m
.52977 .68973 L
s
.52247 .65731 m
.52611 .65626 L
s
.7101 .43243 m
.71353 .44061 L
s
.69679 .43454 m
.7 .43856 L
s
.53312 .51832 m
.53679 .54169 L
s
.52952 .53978 m
.53312 .51832 L
s
.75479 .4556 m
.75783 .45923 L
s
.74091 .44922 m
.74431 .45737 L
s
.84894 .42864 m
.85174 .43236 L
s
.77433 .43325 m
.77773 .44185 L
s
.57457 .5777 m
.5774 .53755 L
s
.40505 .68301 m
.40876 .69212 L
s
.67343 .44461 m
.6766 .44669 L
s
.69766 .47596 m
.70106 .48326 L
s
.60996 .4835 m
.61346 .49023 L
s
.6938 .46062 m
.69766 .47596 L
s
.38023 .65446 m
.38428 .65677 L
s
.69128 .49495 m
.6948 .50424 L
s
.64678 .45323 m
.64955 .44339 L
s
.88616 .42494 m
.88896 .42946 L
s
.81212 .43626 m
.8149 .43879 L
s
.70693 .42863 m
.7101 .43243 L
s
.83553 .42803 m
.83842 .43226 L
s
.68367 .44081 m
.68662 .43947 L
s
.40138 .67253 m
.40505 .68301 L
s
.46927 .88161 m
.47479 .78074 L
s
.87279 .42454 m
.87555 .42843 L
s
.77132 .42932 m
.77433 .43325 L
s
.73768 .44347 m
.74091 .44922 L
s
.82234 .42977 m
.82495 .43096 L
s
.41482 .84767 m
.41884 .84723 L
s
.39766 .66324 m
.40138 .67253 L
s
.72049 .43048 m
.72377 .43635 L
s
.49332 .75458 m
.49729 .73244 L
s
.78518 .43465 m
.78802 .4369 L
s
.63441 .51903 m
.6384 .54004 L
s
.38106 .70105 m
.38508 .70385 L
s
.26641 .42242 m
.27067 .42677 L
s
.39382 .65688 m
.39766 .66324 L
s
.60684 .49154 m
.60996 .4835 L
s
.79862 .43506 m
.80168 .44011 L
s
.85954 .4253 m
.86227 .42866 L
s
.58437 .71245 m
.58671 .65212 L
s
.52513 .65936 m
.52878 .63195 L
s
.6384 .54004 m
.64175 .54341 L
s
.76174 .44317 m
.76467 .44568 L
s
.5792 .46875 m
.58298 .48803 L
s
.5758 .47203 m
.5792 .46875 L
s
.69414 .44059 m
.69679 .43454 L
s
.64083 .48395 m
.64346 .46891 L
s
.89682 .42145 m
.89958 .4258 L
s
.75154 .44936 m
.75479 .4556 L
s
.84615 .42503 m
.84894 .42864 L
s
.88338 .42062 m
.88616 .42494 L
s
.7342 .43444 m
.73768 .44347 L
s
.83243 .42187 m
.83553 .42803 L
s
.71725 .42519 m
.72049 .43048 L
s
.67001 .43783 m
.67343 .44461 L
s
.37611 .65319 m
.38023 .65446 L
s
.70431 .43418 m
.70693 .42863 L
s
.38982 .65377 m
.39382 .65688 L
s
.87012 .4214 m
.87279 .42454 L
s
.5187 .70164 m
.52247 .65731 L
s
.5772 .54094 m
.58024 .51611 L
s
.52852 .47522 m
.53217 .48805 L
s
.52485 .51937 m
.52852 .47522 L
s
.76848 .42779 m
.77132 .42932 L
s
.80913 .43171 m
.81212 .43626 L
s
.53679 .54169 m
.54053 .57526 L
s
.73074 .42563 m
.7342 .43444 L
s
.53848 .46677 m
.54216 .48457 L
s
.53497 .50166 m
.53848 .46677 L
s
.59063 .52757 m
.59386 .51947 L
s
.66044 .45576 m
.66357 .45562 L
s
.79541 .42844 m
.79862 .43506 L
s
.53217 .48805 m
.53594 .54049 L
s
.26214 .41805 m
.26641 .42242 L
s
.7481 .44071 m
.75154 .44936 L
s
.52683 .55262 m
.53051 .58515 L
s
.62069 .49966 m
.62378 .49332 L
s
.90751 .41789 m
.91025 .42226 L
s
.37699 .69879 m
.38106 .70105 L
s
.62975 .60269 m
.63302 .60279 L
s
.52807 .75832 m
.53196 .92289 L
s
.81962 .42764 m
.82234 .42977 L
s
.62842 .54866 m
.63256 .57444 L
s
.85673 .42138 m
.85954 .4253 L
s
.41075 .84835 m
.41482 .84767 L
s
.78205 .42913 m
.78518 .43465 L
s
.72752 .42055 m
.73074 .42563 L
s
.59561 .44643 m
.59982 .48084 L
s
.59226 .44848 m
.59561 .44643 L
s
.53051 .58515 m
.53413 .57696 L
s
.89408 .4173 m
.89682 .42145 L
s
.58298 .48803 m
.58693 .51444 L
s
.66698 .43935 m
.67001 .43783 L
s
.74442 .42881 m
.7481 .44071 L
s
.74101 .42073 m
.74442 .42881 L
s
.82973 .41964 m
.83243 .42187 L
s
.62579 .58183 m
.62975 .60269 L
s
.47262 .70781 m
.47612 .72863 L
s
.68089 .4461 m
.68367 .44081 L
s
.75844 .43627 m
.76174 .44317 L
s
.71423 .4237 m
.71725 .42519 L
s
.84332 .4213 m
.84615 .42503 L
s
.54873 .62492 m
.55238 .63536 L
s
.88066 .41688 m
.88338 .42062 L
s
.46869 .53565 m
.47221 .55465 L
s
.46366 .59313 m
.46869 .53565 L
s
.63118 .50416 m
.63386 .48759 L
s
.79228 .42279 m
.79541 .42844 L
s
.54216 .48457 m
.54618 .55277 L
s
.80612 .427 m
.80913 .43171 L
s
.38571 .65271 m
.38982 .65377 L
s
.47612 .72863 m
.47988 .73363 L
s
.738 .4182 m
.74101 .42073 L
s
.54849 .46477 m
.55231 .49542 L
s
.54515 .50345 m
.54849 .46477 L
s
.86741 .41814 m
.87012 .4214 L
s
.25784 .41366 m
.26214 .41805 L
s
.37197 .65183 m
.37611 .65319 L
s
.52977 .68973 m
.53345 .71557 L
s
.48252 .70351 m
.48588 .73908 L
s
.77865 .42071 m
.78205 .42913 L
s
.75493 .4267 m
.75844 .43627 L
s
.90481 .41385 m
.90751 .41789 L
s
.72437 .41654 m
.72752 .42055 L
s
.4367 .48038 m
.43981 .51097 L
s
.43096 .53598 m
.4367 .48038 L
s
.76529 .42211 m
.76848 .42779 L
s
.57143 .75071 m
.57436 .70948 L
s
.57246 .48092 m
.5758 .47203 L
s
.85383 .41674 m
.85673 .42138 L
s
.37285 .69742 m
.37699 .69879 L
s
.53345 .71557 m
.53708 .71462 L
s
.8913 .41291 m
.89408 .4173 L
s
.75151 .41838 m
.75493 .4267 L
s
.55511 .60996 m
.55932 .67534 L
s
.59007 .50385 m
.59312 .48652 L
s
.54053 .57526 m
.54414 .57621 L
s
.78929 .41881 m
.79228 .42279 L
s
.77539 .41403 m
.77865 .42071 L
s
.8167 .42374 m
.81962 .42764 L
s
.64395 .4628 m
.64678 .45323 L
s
.56342 .67762 m
.56765 .73387 L
s
.65695 .44806 m
.66044 .45576 L
s
.84034 .41613 m
.84332 .4213 L
s
.47221 .55465 m
.47414 .67186 L
s
.87799 .41375 m
.88066 .41688 L
s
.4266 .49305 m
.42888 .54791 L
s
.41926 .58832 m
.4266 .49305 L
s
.82702 .41746 m
.82973 .41964 L
s
.69143 .44612 m
.69414 .44059 L
s
.63655 .59506 m
.63976 .59394 L
s
.40665 .84944 m
.41075 .84835 L
s
.80303 .42167 m
.80612 .427 L
s
.60363 .49766 m
.60684 .49154 L
s
.65319 .43436 m
.65695 .44806 L
s
.64953 .42305 m
.65319 .43436 L
s
.64637 .42387 m
.64953 .42305 L
s
.7484 .41415 m
.75151 .41838 L
s
.71144 .42618 m
.71423 .4237 L
s
.25352 .40924 m
.25784 .41366 L
s
.76191 .41409 m
.76529 .42211 L
s
.4558 .58752 m
.4585 .64389 L
s
.70163 .43948 m
.70431 .43418 L
s
.73512 .41771 m
.738 .4182 L
s
.8646 .41409 m
.86741 .41814 L
s
.58905 .45862 m
.59226 .44848 L
s
.60593 .45081 m
.60972 .46663 L
s
.60252 .44903 m
.60593 .45081 L
s
.63256 .57444 m
.63655 .59506 L
s
.66398 .44224 m
.66698 .43935 L
s
.38159 .65133 m
.38571 .65271 L
s
.7723 .40943 m
.77539 .41403 L
s
.9021 .40988 m
.90481 .41385 L
s
.72107 .41059 m
.72437 .41654 L
s
.85104 .41312 m
.85383 .41674 L
s
.36786 .64927 m
.37197 .65183 L
s
.8885 .40848 m
.8913 .41291 L
s
.58693 .51444 m
.59063 .52757 L
s
.83719 .4096 m
.84034 .41613 L
s
.75876 .40922 m
.76191 .41409 L
s
.78613 .41301 m
.78929 .41881 L
s
.48872 .69428 m
.49159 .78196 L
s
.43593 .77253 m
.43956 .78554 L
s
.43178 .77822 m
.43593 .77253 L
s
.51852 .50432 m
.52217 .52753 L
s
.51461 .55509 m
.51852 .50432 L
s
.61751 .50454 m
.62069 .49966 L
s
.81358 .41784 m
.8167 .42374 L
s
.79977 .41453 m
.80303 .42167 L
s
.36864 .69692 m
.37285 .69742 L
s
.52585 .55216 m
.52952 .53978 L
s
.43956 .78554 m
.44254 .82441 L
s
.60972 .46663 m
.61387 .49471 L
s
.67779 .44574 m
.68089 .4461 L
s
.87526 .41016 m
.87799 .41375 L
s
.74539 .4116 m
.7484 .41415 L
s
.63807 .49703 m
.64083 .48395 L
s
.71814 .41044 m
.72107 .41059 L
s
.45564 .68286 m
.4603 .64966 L
s
.82412 .41363 m
.82702 .41746 L
s
.24919 .40481 m
.25352 .40924 L
s
.59877 .43448 m
.60252 .44903 L
s
.59569 .44857 m
.59877 .43448 L
s
.76929 .40581 m
.7723 .40943 L
s
.86168 .40918 m
.8646 .41409 L
s
.83443 .40679 m
.83719 .4096 L
s
.48949 .75692 m
.49332 .75458 L
s
.79649 .40737 m
.79977 .41453 L
s
.89933 .40548 m
.9021 .40988 L
s
.40249 .8511 m
.40665 .84944 L
s
.78288 .40646 m
.78613 .41301 L
s
.84816 .40893 m
.85104 .41312 L
s
.88587 .40548 m
.8885 .40848 L
s
.81038 .41125 m
.81358 .41784 L
s
.75599 .40926 m
.75876 .40922 L
s
.61255 .43943 m
.61654 .4614 L
s
.60891 .42922 m
.61255 .43943 L
s
.59982 .48084 m
.60363 .49766 L
s
.37755 .64745 m
.38159 .65133 L
s
.36379 .64542 m
.36786 .64927 L
s
.64299 .41986 m
.64637 .42387 L
s
.55231 .49542 m
.55665 .57438 L
s
.60588 .44187 m
.60891 .42922 L
s
.73209 .41552 m
.73512 .41771 L
s
.57962 .65482 m
.58272 .63193 L
s
.62266 .4323 m
.62697 .46266 L
s
.61904 .42252 m
.62266 .4323 L
s
.43981 .51097 m
.44209 .57394 L
s
.67024 .41899 m
.67412 .43462 L
s
.66689 .41443 m
.67024 .41899 L
s
.7934 .40226 m
.79649 .40737 L
s
.70866 .42914 m
.71144 .42618 L
s
.51751 .47032 m
.52112 .51965 L
s
.51381 .46391 m
.51751 .47032 L
s
.87246 .40606 m
.87526 .41016 L
s
.5587 .47731 m
.56251 .49968 L
s
.55546 .51122 m
.5587 .47731 L
s
.46862 .8166 m
.47315 .77895 L
s
.61587 .42798 m
.61904 .42252 L
s
.24483 .40035 m
.24919 .40481 L
s
.77978 .40163 m
.78288 .40646 L
s
.36439 .69689 m
.36864 .69692 L
s
.80723 .40526 m
.81038 .41125 L
s
.82106 .40822 m
.82412 .41363 L
s
.68812 .4414 m
.69143 .44612 L
s
.74235 .40865 m
.74539 .4116 L
s
.56917 .49738 m
.57246 .48092 L
s
.85872 .40401 m
.86168 .40918 L
s
.48588 .73908 m
.48949 .75692 L
s
.52217 .52753 m
.52585 .55216 L
s
.66067 .43895 m
.66398 .44224 L
s
.89644 .40019 m
.89933 .40548 L
s
.76654 .40568 m
.76929 .40581 L
s
.52142 .6627 m
.52513 .65936 L
s
.52035 .66291 m
.52414 .61583 L
s
.67412 .43462 m
.67779 .44574 L
s
.84509 .40304 m
.84816 .40893 L
s
.83155 .40295 m
.83443 .40679 L
s
.69858 .43872 m
.70163 .43948 L
s
.49493 .68846 m
.49708 .87833 L
s
.62811 .51086 m
.63118 .50416 L
s
.63289 .42821 m
.63704 .4521 L
s
.62927 .41836 m
.63289 .42821 L
s
.64075 .46389 m
.64395 .4628 L
s
.37363 .64088 m
.37755 .64745 L
s
.35972 .64126 m
.36379 .64542 L
s
.88316 .40196 m
.88587 .40548 L
s
.7153 .41203 m
.71814 .41044 L
s
.63971 .41867 m
.64299 .41986 L
s
.50971 .52794 m
.51381 .46391 L
s
.43886 .62425 m
.4443 .57269 L
s
.62628 .42731 m
.62927 .41836 L
s
.5433 .55682 m
.54704 .57709 L
s
.53966 .55786 m
.5433 .55682 L
s
.42735 .79127 m
.43178 .77822 L
s
.79037 .398 m
.7934 .40226 L
s
.57412 .5685 m
.5772 .54094 L
s
.52658 .42357 m
.5303 .46257 L
s
.52284 .45861 m
.52658 .42357 L
s
.41748 .44914 m
.41993 .49573 L
s
.40914 .56001 m
.41748 .44914 L
s
.6637 .41352 m
.66689 .41443 L
s
.61387 .49471 m
.61751 .50454 L
s
.80405 .39915 m
.80723 .40526 L
s
.39828 .85345 m
.40249 .8511 L
s
.61654 .4614 m
.62039 .47806 L
s
.81784 .40146 m
.82106 .40822 L
s
.86958 .40143 m
.87246 .40606 L
s
.72884 .41036 m
.73209 .41552 L
s
.77694 .39993 m
.77978 .40163 L
s
.85587 .39992 m
.85872 .40401 L
s
.24045 .39588 m
.24483 .40035 L
s
.4657 .67919 m
.47005 .65607 L
s
.68452 .4316 m
.68812 .4414 L
s
.75316 .40881 m
.75599 .40926 L
s
.89375 .3966 m
.89644 .40019 L
s
.36973 .63353 m
.37363 .64088 L
s
.5854 .44904 m
.58905 .45862 L
s
.84197 .39677 m
.84509 .40304 L
s
.6812 .42721 m
.68452 .4316 L
s
.50126 .67428 m
.50354 .89681 L
s
.73933 .40644 m
.74235 .40865 L
s
.65705 .42895 m
.66067 .43895 L
s
.5817 .43692 m
.5854 .44904 L
s
.57832 .44368 m
.5817 .43692 L
s
.57163 .61786 m
.57457 .5777 L
s
.58655 .50088 m
.59007 .50385 L
s
.52757 .47172 m
.53127 .4926 L
s
.52385 .48901 m
.52757 .47172 L
s
.46532 .60343 m
.46783 .67934 L
s
.56251 .49968 m
.56681 .55684 L
s
.44936 .60572 m
.45423 .56953 L
s
.44585 .50262 m
.44915 .52964 L
s
.44121 .52497 m
.44585 .50262 L
s
.35559 .63779 m
.35972 .64126 L
s
.82847 .39729 m
.83155 .40295 L
s
.36011 .69666 m
.36439 .69689 L
s
.65342 .41896 m
.65705 .42895 L
s
.80098 .39423 m
.80405 .39915 L
s
.81464 .39489 m
.81784 .40146 L
s
.53594 .54049 m
.53966 .55786 L
s
.62039 .47806 m
.62443 .50028 L
s
.55087 .60596 m
.55442 .59844 L
s
.36575 .62756 m
.36973 .63353 L
s
.88033 .3975 m
.88316 .40196 L
s
.44507 .62482 m
.44786 .6732 L
s
.65012 .41679 m
.65342 .41896 L
s
.78734 .39387 m
.79037 .398 L
s
.76366 .40425 m
.76654 .40568 L
s
.72538 .40226 m
.72884 .41036 L
s
.54704 .57709 m
.55087 .60596 L
s
.70562 .42837 m
.70866 .42914 L
s
.83907 .39265 m
.84197 .39677 L
s
.86659 .39596 m
.86958 .40143 L
s
.69531 .43461 m
.69858 .43872 L
s
.40191 .69574 m
.40554 .70916 L
s
.3979 .69204 m
.40191 .69574 L
s
.23604 .39138 m
.24045 .39588 L
s
.58277 .48559 m
.58655 .50088 L
s
.5792 .48083 m
.58277 .48559 L
s
.57564 .62666 m
.57962 .65482 L
s
.5983 .4117 m
.60211 .42787 L
s
.59535 .43205 m
.5983 .4117 L
s
.63673 .42629 m
.63971 .41867 L
s
.8529 .39489 m
.85587 .39992 L
s
.47904 .72177 m
.48371 .6665 L
s
.44254 .82441 m
.44501 .88764 L
s
.63704 .4521 m
.64075 .46389 L
s
.5177 .66005 m
.52142 .6627 L
s
.40554 .70916 m
.40882 .73238 L
s
.89106 .39311 m
.89375 .3966 L
s
.67764 .41831 m
.6812 .42721 L
s
.66024 .40712 m
.6637 .41352 L
s
.53127 .4926 m
.53497 .50166 L
s
.81169 .39099 m
.81464 .39489 L
s
.82536 .39149 m
.82847 .39729 L
s
.63478 .49699 m
.63807 .49703 L
s
.72187 .39348 m
.72538 .40226 L
s
.67383 .40467 m
.67764 .41831 L
s
.67062 .40299 m
.67383 .40467 L
s
.77412 .39878 m
.77694 .39993 L
s
.61248 .42698 m
.61587 .42798 L
s
.62697 .46266 m
.631 .48356 L
s
.36165 .62375 m
.36575 .62756 L
s
.7122 .4099 m
.7153 .41203 L
s
.35138 .63531 m
.35559 .63779 L
s
.79804 .39074 m
.80098 .39423 L
s
.394 .8565 m
.39828 .85345 L
s
.73625 .40347 m
.73933 .40644 L
s
.74999 .40424 m
.75316 .40881 L
s
.59256 .46282 m
.59569 .44857 L
s
.60211 .42787 m
.60588 .44187 L
s
.87743 .39261 m
.88033 .3975 L
s
.68778 .40941 m
.69177 .426 L
s
.68413 .39879 m
.68778 .40941 L
s
.71879 .39135 m
.72187 .39348 L
s
.86358 .39036 m
.86659 .39596 L
s
.78445 .39151 m
.78734 .39387 L
s
.68072 .39292 m
.68413 .39879 L
s
.62443 .50028 m
.62811 .51086 L
s
.57587 .49209 m
.5792 .48083 L
s
.35584 .69565 m
.36011 .69666 L
s
.39365 .69354 m
.3979 .69204 L
s
.84984 .38912 m
.8529 .39489 L
s
.83607 .38766 m
.83907 .39265 L
s
.69177 .426 m
.69531 .43461 L
s
.23162 .38685 m
.23604 .39138 L
s
.65689 .40369 m
.66024 .40712 L
s
.51479 .74669 m
.5187 .70164 L
s
.64703 .42022 m
.65012 .41679 L
s
.82238 .38709 m
.82536 .39149 L
s
.76058 .40045 m
.76366 .40425 L
s
.56765 .73387 m
.57143 .75071 L
s
.51381 .69316 m
.5177 .66005 L
s
.47788 .57681 m
.48088 .63737 L
s
.47293 .63844 m
.47788 .57681 L
s
.88825 .38877 m
.89106 .39311 L
s
.80881 .38792 m
.81169 .39099 L
s
.70212 .4204 m
.70562 .42837 L
s
.35745 .62119 m
.36165 .62375 L
s
.51644 .45209 m
.52009 .49107 L
s
.51261 .46548 m
.51644 .45209 L
s
.52112 .51965 m
.52485 .51937 L
s
.56152 .64068 m
.56468 .60301 L
s
.42888 .54791 m
.43084 .6171 L
s
.44915 .52964 m
.45176 .58729 L
s
.62317 .43434 m
.62628 .42731 L
s
.7466 .39681 m
.74999 .40424 L
s
.87448 .3874 m
.87743 .39261 L
s
.67767 .39396 m
.68072 .39292 L
s
.86064 .38544 m
.86358 .39036 L
s
.631 .48356 m
.63478 .49699 L
s
.40882 .73238 m
.41195 .7606 L
s
.79497 .38612 m
.79804 .39074 L
s
.34712 .63328 m
.35138 .63531 L
s
.66734 .40049 m
.67062 .40299 L
s
.70876 .40276 m
.7122 .4099 L
s
.42297 .80123 m
.42735 .79127 L
s
.84685 .38403 m
.84984 .38912 L
s
.69836 .40801 m
.70212 .4204 L
s
.6947 .39721 m
.69836 .40801 L
s
.54151 .50636 m
.54515 .50345 L
s
.73295 .39781 m
.73625 .40347 L
s
.77125 .39724 m
.77412 .39878 L
s
.60932 .43507 m
.61248 .42698 L
s
.57498 .4549 m
.57832 .44368 L
s
.51543 .41129 m
.51906 .45836 L
s
.51148 .44691 m
.51543 .41129 L
s
.83311 .3832 m
.83607 .38766 L
s
.69126 .39049 m
.6947 .39721 L
s
.56588 .51841 m
.56917 .49738 L
s
.4585 .64389 m
.46181 .67577 L
s
.50638 .86645 m
.51052 .80636 L
s
.22718 .38231 m
.23162 .38685 L
s
.71549 .38618 m
.71879 .39135 L
s
.78162 .39 m
.78445 .39151 L
s
.81949 .38362 m
.82238 .38709 L
s
.65375 .40526 m
.65689 .40369 L
s
.74325 .39022 m
.7466 .39681 L
s
.51176 .61145 m
.51569 .57854 L
s
.35159 .69387 m
.35584 .69565 L
s
.56675 .69772 m
.57074 .72906 L
s
.56316 .69749 m
.56675 .69772 L
s
.53674 .44003 m
.54052 .46467 L
s
.53306 .44445 m
.53674 .44003 L
s
.38966 .8602 m
.394 .8565 L
s
.70505 .3913 m
.70876 .40276 L
s
.75746 .39635 m
.76058 .40045 L
s
.70173 .38615 m
.70505 .3913 L
s
.88532 .38349 m
.88825 .38877 L
s
.58144 .74812 m
.58437 .71245 L
s
.55932 .67534 m
.56316 .69749 L
s
.54618 .55277 m
.55009 .58999 L
s
.87148 .3818 m
.87448 .3874 L
s
.5303 .46257 m
.53407 .49248 L
s
.85766 .38036 m
.86064 .38544 L
s
.80588 .38449 m
.80881 .38792 L
s
.35325 .61828 m
.35745 .62119 L
s
.68825 .39171 m
.69126 .39049 L
s
.38943 .69364 m
.39365 .69354 L
s
.60148 .39793 m
.60565 .42608 L
s
.59831 .40843 m
.60148 .39793 L
s
.72951 .39016 m
.73295 .39781 L
s
.79183 .38088 m
.79497 .38612 L
s
.52714 .92588 m
.53083 .7938 L
s
.84391 .37959 m
.84685 .38403 L
s
.63365 .43243 m
.63673 .42629 L
s
.45142 .69237 m
.45564 .68286 L
s
.74007 .38588 m
.74325 .39022 L
s
.8303 .38032 m
.83311 .3832 L
s
.34286 .63097 m
.34712 .63328 L
s
.71224 .38199 m
.71549 .38618 L
s
.22271 .37774 m
.22718 .38231 L
s
.66377 .39214 m
.66734 .40049 L
s
.56583 .65966 m
.57049 .74007 L
s
.64392 .42384 m
.64703 .42022 L
s
.72611 .38323 m
.72951 .39016 L
s
.76812 .39269 m
.77125 .39724 L
s
.88235 .37804 m
.88532 .38349 L
s
.81657 .38006 m
.81949 .38362 L
s
.6986 .38461 m
.70173 .38615 L
s
.52009 .49107 m
.52385 .48901 L
s
.57912 .80919 m
.58177 .75246 L
s
.86852 .37663 m
.87148 .3818 L
s
.67468 .39692 m
.67767 .39396 L
s
.75414 .39 m
.75746 .39635 L
s
.66018 .38341 m
.66377 .39214 L
s
.46181 .67577 m
.4657 .67919 L
s
.85473 .37573 m
.85766 .38036 L
s
.77862 .3867 m
.78162 .39 L
s
.34732 .69182 m
.35159 .69387 L
s
.78896 .37871 m
.79183 .38088 L
s
.41993 .49573 m
.42183 .56121 L
s
.84108 .37619 m
.84391 .37959 L
s
.34908 .61431 m
.35325 .61828 L
s
.80283 .38 m
.80588 .38449 L
s
.41195 .7606 m
.41522 .78587 L
s
.53779 .49854 m
.54151 .50636 L
s
.45889 .62965 m
.46366 .59313 L
s
.44313 .78508 m
.44899 .71235 L
s
.43005 .48859 m
.43317 .52029 L
s
.42584 .49123 m
.43005 .48859 L
s
.72288 .37904 m
.72611 .38323 L
s
.657 .38398 m
.66018 .38341 L
s
.73676 .38013 m
.74007 .38588 L
s
.57073 .58086 m
.57412 .5685 L
s
.21822 .37316 m
.22271 .37774 L
s
.45516 .5268 m
.45825 .56779 L
s
.45098 .53338 m
.45516 .5268 L
s
.65055 .40627 m
.65375 .40526 L
s
.70929 .38274 m
.71224 .38199 L
s
.46423 .84022 m
.46862 .8166 L
s
.5725 .50437 m
.57587 .49209 L
s
.43676 .53788 m
.44121 .52497 L
s
.61569 .41056 m
.61969 .43046 L
s
.61212 .40437 m
.61569 .41056 L
s
.55193 .52407 m
.55546 .51122 L
s
.38546 .68737 m
.38943 .69364 L
s
.54052 .46467 m
.5444 .50071 L
s
.41131 .43219 m
.4144 .46121 L
s
.40347 .52207 m
.41131 .43219 L
s
.44993 .75903 m
.45313 .79485 L
s
.4459 .75939 m
.44993 .75903 L
s
.82745 .37717 m
.8303 .38032 L
s
.61969 .43046 m
.62317 .43434 L
s
.33859 .6282 m
.34286 .63097 L
s
.87942 .37296 m
.88235 .37804 L
s
.75062 .38114 m
.75414 .39 L
s
.58898 .45834 m
.59256 .46282 L
s
.38527 .86439 m
.38966 .8602 L
s
.76471 .38502 m
.76812 .39269 L
s
.42563 .57298 m
.43096 .53598 L
s
.53407 .49248 m
.53779 .49854 L
s
.86561 .37202 m
.86852 .37663 L
s
.37816 .66001 m
.38176 .67467 L
s
.37442 .64844 m
.37816 .66001 L
s
.37043 .64192 m
.37442 .64844 L
s
.68477 .3847 m
.68825 .39171 L
s
.81361 .37623 m
.81657 .38006 L
s
.41888 .80045 m
.42297 .80123 L
s
.58513 .44122 m
.58898 .45834 L
s
.58141 .43042 m
.58513 .44122 L
s
.52932 .43212 m
.53306 .44445 L
s
.52558 .43466 m
.52932 .43212 L
s
.59195 .43566 m
.59535 .43205 L
s
.85185 .37169 m
.85473 .37573 L
s
.44786 .6732 m
.45142 .69237 L
s
.57801 .43863 m
.58141 .43042 L
s
.42554 .73168 m
.43289 .62696 L
s
.60565 .42608 m
.60932 .43507 L
s
.74722 .37386 m
.75062 .38114 L
s
.44209 .57394 m
.44522 .60878 L
s
.38176 .67467 m
.38546 .68737 L
s
.77546 .38176 m
.77862 .3867 L
s
.6956 .38574 m
.6986 .38461 L
s
.34491 .60995 m
.34908 .61431 L
s
.79962 .37392 m
.80283 .38 L
s
.73349 .37494 m
.73676 .38013 L
s
.34302 .69 m
.34732 .69182 L
s
.76135 .37807 m
.76471 .38502 L
s
.57074 .72906 m
.57517 .78752 L
s
.6186 .38329 m
.62262 .40355 L
s
.61545 .39103 m
.6186 .38329 L
s
.60855 .39877 m
.61212 .40437 L
s
.50848 .52072 m
.51261 .46548 L
s
.83823 .37282 m
.84108 .37619 L
s
.78596 .37532 m
.78896 .37871 L
s
.71988 .37847 m
.72288 .37904 L
s
.54704 .44977 m
.5509 .47652 L
s
.54332 .44371 m
.54704 .44977 L
s
.51055 .60791 m
.51461 .55509 L
s
.36627 .63849 m
.37043 .64192 L
s
.21371 .36855 m
.21822 .37316 L
s
.57149 .45988 m
.57498 .4549 L
s
.6814 .38009 m
.68477 .3847 L
s
.87653 .36832 m
.87942 .37296 L
s
.60468 .38275 m
.60855 .39877 L
s
.60169 .40019 m
.60468 .38275 L
s
.63013 .42698 m
.63365 .43243 L
s
.74409 .37027 m
.74722 .37386 L
s
.51906 .45836 m
.52284 .45861 L
s
.64054 .42173 m
.64392 .42384 L
s
.8627 .3675 m
.86561 .37202 L
s
.33429 .62553 m
.33859 .6282 L
s
.82445 .37262 m
.82745 .37717 L
s
.41522 .78587 m
.41888 .80045 L
s
.67133 .3931 m
.67468 .39692 L
s
.75801 .37143 m
.76135 .37807 L
s
.56681 .55684 m
.57073 .58086 L
s
.81059 .3719 m
.81361 .37623 L
s
.79638 .36763 m
.79962 .37392 L
s
.84905 .3684 m
.85185 .37169 L
s
.65377 .38409 m
.657 .38398 L
s
.43984 .83727 m
.4459 .75939 L
s
.77209 .37454 m
.77546 .38176 L
s
.73037 .37216 m
.73349 .37494 L
s
.34069 .6062 m
.34491 .60995 L
s
.59499 .41505 m
.59831 .40843 L
s
.53962 .44313 m
.54332 .44371 L
s
.44522 .60878 m
.44936 .60572 L
s
.64715 .40297 m
.65055 .40627 L
s
.70626 .38264 m
.70929 .38274 L
s
.42082 .51595 m
.42584 .49123 L
s
.55009 .58999 m
.55388 .60591 L
s
.51651 .67866 m
.52035 .66291 L
s
.20918 .36391 m
.21371 .36855 L
s
.33867 .68852 m
.34302 .69 L
s
.62638 .41544 m
.63013 .42698 L
s
.62262 .40355 m
.62638 .41544 L
s
.36211 .63451 m
.36627 .63849 L
s
.67828 .38038 m
.6814 .38009 L
s
.83534 .36913 m
.83823 .37282 L
s
.78271 .36918 m
.78596 .37532 L
s
.87369 .36415 m
.87653 .36832 L
s
.49159 .78196 m
.49476 .85588 L
s
.38082 .86883 m
.38527 .86439 L
s
.56827 .6361 m
.57163 .61786 L
s
.75479 .36651 m
.75801 .37143 L
s
.50908 .63007 m
.51275 .66086 L
s
.50527 .62693 m
.50908 .63007 L
s
.76858 .36578 m
.77209 .37454 L
s
.85982 .36328 m
.8627 .3675 L
s
.79333 .36354 m
.79638 .36763 L
s
.74076 .36428 m
.74409 .37027 L
s
.56242 .53103 m
.56588 .51841 L
s
.82133 .36717 m
.82445 .37262 L
s
.44501 .88764 m
.44725 .96614 L
s
.55388 .60591 m
.55775 .62838 L
s
.52178 .44551 m
.52558 .43466 L
s
.44667 .54274 m
.45098 .53338 L
s
.58817 .42292 m
.59195 .43566 L
s
.58447 .41427 m
.58817 .42292 L
s
.32992 .62358 m
.33429 .62553 L
s
.71679 .37686 m
.71988 .37847 L
s
.4144 .46121 m
.41676 .51153 L
s
.69236 .38297 m
.6956 .38574 L
s
.46316 1.00133 m
.46927 .88161 L
s
.66769 .38383 m
.67133 .3931 L
s
.43317 .52029 m
.43676 .53788 L
s
.80745 .36653 m
.81059 .3719 L
s
.55665 .57438 m
.5608 .6222 L
s
.63692 .41371 m
.64054 .42173 L
s
.62928 .38695 m
.63304 .39871 L
s
.62581 .38343 m
.62928 .38695 L
s
.63304 .39871 m
.63692 .41371 L
s
.76544 .36146 m
.76858 .36578 L
s
.3364 .60329 m
.34069 .6062 L
s
.8462 .36488 m
.84905 .3684 L
s
.77943 .36296 m
.78271 .36918 L
s
.58106 .42146 m
.58447 .41427 L
s
.66407 .37508 m
.66769 .38383 L
s
.51429 .403 m
.51804 .41893 L
s
.51019 .45361 m
.51429 .403 L
s
.72728 .37016 m
.73037 .37216 L
s
.64351 .39408 m
.64715 .40297 L
s
.43421 .64293 m
.43886 .62425 L
s
.20463 .35926 m
.20918 .36391 L
s
.5509 .47652 m
.55488 .51096 L
s
.35806 .62811 m
.36211 .63451 L
s
.50961 .76737 m
.51381 .69316 L
s
.51704 .37141 m
.52076 .40859 L
s
.51301 .41922 m
.51704 .37141 L
s
.45313 .79485 m
.45643 .82871 L
s
.52833 .40672 m
.53211 .42649 L
s
.52455 .41924 m
.52833 .40672 L
s
.75173 .36366 m
.75479 .36651 L
s
.73762 .36101 m
.74076 .36428 L
s
.8708 .35971 m
.87369 .36415 L
s
.83233 .36451 m
.83534 .36913 L
s
.81824 .36204 m
.82133 .36717 L
s
.6504 .38155 m
.65377 .38409 L
s
.5359 .44287 m
.53962 .44313 L
s
.56898 .51013 m
.5725 .50437 L
s
.50108 .6684 m
.50527 .62693 L
s
.57462 .44966 m
.57801 .43863 L
s
.5679 .4603 m
.57149 .45988 L
s
.66079 .37372 m
.66407 .37508 L
s
.33428 .68715 m
.33867 .68852 L
s
.63988 .38588 m
.64351 .39408 L
s
.85698 .35957 m
.85982 .36328 L
s
.79018 .35843 m
.79333 .36354 L
s
.54821 .51888 m
.55193 .52407 L
s
.7028 .37579 m
.70626 .38264 L
s
.5444 .50071 m
.54821 .51888 L
s
.80422 .36035 m
.80745 .36653 L
s
.6079 .36694 m
.61188 .38575 L
s
.60489 .3832 m
.6079 .36694 L
s
.51804 .41893 m
.52178 .44551 L
s
.61188 .38575 m
.61545 .39103 L
s
.55746 .4595 m
.56134 .48091 L
s
.55374 .45247 m
.55746 .4595 L
s
.77625 .35789 m
.77943 .36296 L
s
.45176 .58729 m
.45488 .62734 L
s
.46783 .67934 m
.47092 .73103 L
s
.35407 .62033 m
.35806 .62811 L
s
.48088 .63737 m
.48263 .80292 L
s
.67486 .37537 m
.67828 .38038 L
s
.76236 .35811 m
.76544 .36146 L
s
.32547 .62253 m
.32992 .62358 L
s
.68861 .37159 m
.69236 .38297 L
s
.55775 .62838 m
.56152 .64068 L
s
.50423 .58616 m
.50797 .60291 L
s
.50021 .60501 m
.50423 .58616 L
s
.62224 .37771 m
.62581 .38343 L
s
.68502 .36304 m
.68861 .37159 L
s
.63635 .38041 m
.63988 .38588 L
s
.33206 .60067 m
.3364 .60329 L
s
.45825 .56779 m
.46083 .637 L
s
.84321 .36017 m
.8462 .36488 L
s
.71356 .37342 m
.71679 .37686 L
s
.40923 .41503 m
.41187 .45622 L
s
.40294 .46408 m
.40923 .41503 L
s
.20005 .35458 m
.20463 .35926 L
s
.50797 .60291 m
.51176 .61145 L
s
.37633 .87321 m
.38082 .86883 L
s
.6994 .37026 m
.7028 .37579 L
s
.51089 .76083 m
.51479 .74669 L
s
.81514 .35696 m
.81824 .36204 L
s
.86781 .35451 m
.8708 .35971 L
s
.82919 .35866 m
.83233 .36451 L
s
.53211 .42649 m
.5359 .44287 L
s
.55006 .45255 m
.55374 .45247 L
s
.35004 .61327 m
.35407 .62033 L
s
.80106 .35492 m
.80422 .36035 L
s
.59123 .40408 m
.59499 .41505 L
s
.68191 .36345 m
.68502 .36304 L
s
.43553 .5003 m
.43927 .51354 L
s
.43165 .49201 m
.43553 .5003 L
s
.72413 .36742 m
.72728 .37016 L
s
.78708 .3541 m
.79018 .35843 L
s
.46013 .84499 m
.46423 .84022 L
s
.73451 .3584 m
.73762 .36101 L
s
.57811 .76433 m
.58144 .74812 L
s
.7485 .3589 m
.75173 .36366 L
s
.58748 .39357 m
.59123 .40408 L
s
.50735 .49204 m
.51148 .44691 L
s
.43927 .51354 m
.44283 .53311 L
s
.85411 .35575 m
.85698 .35957 L
s
.64701 .37913 m
.6504 .38155 L
s
.47469 .74583 m
.47904 .72177 L
s
.77326 .35528 m
.77625 .35789 L
s
.58407 .39991 m
.58748 .39357 L
s
.51275 .66086 m
.51651 .67866 L
s
.32987 .68563 m
.33428 .68715 L
s
.61896 .38144 m
.62224 .37771 L
s
.67125 .36689 m
.67486 .37537 L
s
.42789 .47964 m
.43165 .49201 L
s
.42391 .47373 m
.42789 .47964 L
s
.633 .38017 m
.63635 .38041 L
s
.65755 .37377 m
.66079 .37372 L
s
.50567 .55466 m
.50971 .52794 L
s
.34589 .60777 m
.35004 .61327 L
s
.56134 .48091 m
.56525 .5026 L
s
.84014 .35488 m
.84321 .36017 L
s
.75938 .3561 m
.76236 .35811 L
s
.69594 .36383 m
.6994 .37026 L
s
.56427 .46049 m
.5679 .4603 L
s
.19545 .34987 m
.20005 .35458 L
s
.82597 .35223 m
.82919 .35866 L
s
.3277 .5978 m
.33206 .60067 L
s
.43084 .6171 m
.43421 .64293 L
s
.71013 .36708 m
.71356 .37342 L
s
.86494 .35035 m
.86781 .35451 L
s
.81198 .35138 m
.81514 .35696 L
s
.32094 .62207 m
.32547 .62253 L
s
.66786 .36307 m
.67125 .36689 L
s
.79794 .35012 m
.80106 .35492 L
s
.59829 .40402 m
.60169 .40019 L
s
.44283 .53311 m
.44667 .54274 L
s
.48779 .84905 m
.49307 .73031 L
s
.78404 .35059 m
.78708 .3541 L
s
.74512 .35248 m
.7485 .3589 L
s
.47414 .67186 m
.47619 .79813 L
s
.41936 .48336 m
.42391 .47373 L
s
.57762 .42932 m
.58106 .42146 L
s
.72072 .36121 m
.72413 .36742 L
s
.55874 .52982 m
.56242 .53103 L
s
.85111 .35085 m
.85411 .35575 L
s
.73131 .35479 m
.73451 .3584 L
s
.56525 .5026 m
.56898 .51013 L
s
.51976 .35644 m
.52352 .39421 L
s
.51578 .3962 m
.51976 .35644 L
s
.34168 .60309 m
.34589 .60777 L
s
.6922 .35287 m
.69594 .36383 L
s
.82287 .3471 m
.82597 .35223 L
s
.45643 .82871 m
.46013 .84499 L
s
.83702 .34925 m
.84014 .35488 L
s
.68917 .35436 m
.6922 .35287 L
s
.5463 .4455 m
.55006 .45255 L
s
.70641 .35633 m
.71013 .36708 L
s
.64361 .37675 m
.64701 .37913 L
s
.77007 .35054 m
.77326 .35528 L
s
.41099 .70177 m
.41926 .58832 L
s
.32544 .68404 m
.32987 .68563 L
s
.54249 .42963 m
.5463 .4455 L
s
.5387 .4188 m
.54249 .42963 L
s
.19082 .34515 m
.19545 .34987 L
s
.80887 .34647 m
.81198 .35138 L
s
.67841 .35725 m
.68191 .36345 L
s
.70312 .35273 m
.70641 .35633 L
s
.37182 .87728 m
.37633 .87321 L
s
.56464 .63715 m
.56827 .6361 L
s
.53112 .39466 m
.53491 .40763 L
s
.52734 .40278 m
.53112 .39466 L
s
.55488 .51096 m
.55874 .52982 L
s
.45488 .62734 m
.45889 .62965 L
s
.53491 .40763 m
.5387 .4188 L
s
.74178 .34657 m
.74512 .35248 L
s
.79498 .34713 m
.79794 .35012 L
s
.86202 .34596 m
.86494 .35035 L
s
.32335 .59465 m
.3277 .5978 L
s
.66462 .36276 m
.66786 .36307 L
s
.7562 .35195 m
.75938 .3561 L
s
.51695 1.0359 m
.52055 .86616 L
s
.62938 .37328 m
.633 .38017 L
s
.71728 .35468 m
.72072 .36121 L
s
.57107 .45417 m
.57462 .44966 L
s
.6542 .37188 m
.65755 .37377 L
s
.52076 .40859 m
.52455 .41924 L
s
.78107 .348 m
.78404 .35059 L
s
.57517 .78752 m
.57912 .80919 L
s
.84797 .34488 m
.85111 .35085 L
s
.31637 .62182 m
.32094 .62207 L
s
.33746 .59826 m
.34168 .60309 L
s
.5606 .45905 m
.56427 .46049 L
s
.50224 .90305 m
.50638 .86645 L
s
.83387 .34337 m
.83702 .34925 L
s
.41676 .51153 m
.42082 .51595 L
s
.42183 .56121 m
.42563 .57298 L
s
.81982 .34244 m
.82287 .3471 L
s
.61134 .35708 m
.61518 .37019 L
s
.60825 .36996 m
.61134 .35708 L
s
.72797 .34949 m
.73131 .35479 L
s
.67486 .35011 m
.67841 .35725 L
s
.61518 .37019 m
.61896 .38144 L
s
.76688 .34583 m
.77007 .35054 L
s
.468 .6886 m
.47293 .63844 L
s
.80586 .34264 m
.80887 .34647 L
s
.73864 .34354 m
.74178 .34657 L
s
.18618 .3404 m
.19082 .34515 L
s
.62568 .36424 m
.62938 .37328 L
s
.4415 .49945 m
.44523 .51375 L
s
.43754 .49294 m
.4415 .49945 L
s
.58065 .40862 m
.58407 .39991 L
s
.71373 .34664 m
.71728 .35468 L
s
.69956 .34476 m
.70312 .35273 L
s
.64004 .3709 m
.64361 .37675 L
s
.32095 .68279 m
.32544 .68404 L
s
.85902 .34098 m
.86202 .34596 L
s
.5608 .6222 m
.56464 .63715 L
s
.59448 .3918 m
.59829 .40402 L
s
.59072 .3816 m
.59448 .3918 L
s
.31896 .59151 m
.32335 .59465 L
s
.44523 .51375 m
.44871 .53833 L
s
.50702 .76085 m
.51089 .76083 L
s
.79194 .34351 m
.79498 .34713 L
s
.75285 .34573 m
.7562 .35195 L
s
.60143 .38454 m
.60489 .3832 L
s
.84489 .33943 m
.84797 .34488 L
s
.62224 .36342 m
.62568 .36424 L
s
.6716 .349 m
.67486 .35011 L
s
.46423 .57392 m
.46711 .635 L
s
.46036 .565 m
.46423 .57392 L
s
.33324 .59313 m
.33746 .59826 L
s
.58729 .38761 m
.59072 .3816 L
s
.83082 .33861 m
.83387 .34337 L
s
.71053 .34406 m
.71373 .34664 L
s
.54534 .40895 m
.54916 .42231 L
s
.54157 .40377 m
.54534 .40895 L
s
.6964 .34367 m
.69956 .34476 L
s
.72459 .34379 m
.72797 .34949 L
s
.68584 .35106 m
.68917 .35436 L
s
.57049 .74007 m
.57454 .76837 L
s
.81675 .33781 m
.81982 .34244 L
s
.43355 .48718 m
.43754 .49294 L
s
.49592 .6427 m
.50021 .60501 L
s
.57454 .76837 m
.57811 .76433 L
s
.65074 .36808 m
.6542 .37188 L
s
.45612 .57212 m
.46036 .565 L
s
.7779 .34331 m
.78107 .348 L
s
.76372 .34181 m
.76688 .34583 L
s
.54916 .42231 m
.553 .43781 L
s
.66128 .36076 m
.66462 .36276 L
s
.36728 .88101 m
.37182 .87728 L
s
.41187 .45622 m
.41505 .485 L
s
.18151 .33562 m
.18618 .3404 L
s
.55683 .45129 m
.5606 .45905 L
s
.63647 .36513 m
.64004 .3709 L
s
.31176 .6216 m
.31637 .62182 L
s
.80284 .3389 m
.80586 .34264 L
s
.57403 .43074 m
.57762 .42932 L
s
.74945 .3391 m
.75285 .34573 L
s
.85594 .33544 m
.85902 .34098 L
s
.73543 .33987 m
.73864 .34354 L
s
.84186 .33462 m
.84489 .33943 L
s
.553 .43781 m
.55683 .45129 L
s
.41505 .485 m
.41936 .48336 L
s
.32899 .58812 m
.33324 .59313 L
s
.42596 .46203 m
.42969 .47664 L
s
.42197 .45517 m
.42596 .46203 L
s
.61831 .3479 m
.62224 .36342 L
s
.61496 .35095 m
.61831 .3479 L
s
.31453 .58863 m
.31896 .59151 L
s
.82777 .33384 m
.83082 .33861 L
s
.78878 .33869 m
.79194 .34351 L
s
.31639 .68235 m
.32095 .68279 L
s
.42969 .47664 m
.43355 .48718 L
s
.7213 .33949 m
.72459 .34379 L
s
.53777 .39472 m
.54157 .40377 L
s
.56738 .45095 m
.57107 .45417 L
s
.47092 .73103 m
.47469 .74583 L
s
.81374 .3339 m
.81675 .33781 L
s
.52352 .39421 m
.52734 .40278 L
s
.50273 .81547 m
.50702 .76085 L
s
.53395 .38174 m
.53777 .39472 L
s
.53015 .38517 m
.53395 .38174 L
s
.7745 .33619 m
.7779 .34331 L
s
.63267 .35368 m
.63647 .36513 L
s
.68222 .3429 m
.68584 .35106 L
s
.74622 .33485 m
.74945 .3391 L
s
.62918 .35084 m
.63267 .35368 L
s
.7072 .33985 m
.71053 .34406 L
s
.64712 .36082 m
.65074 .36808 L
s
.66833 .348 m
.6716 .349 L
s
.76044 .33641 m
.76372 .34181 L
s
.17682 .33083 m
.18151 .33562 L
s
.44871 .53833 m
.45223 .56291 L
s
.41755 .45979 m
.42197 .45517 L
s
.85294 .33064 m
.85594 .33544 L
s
.5225 .3481 m
.52632 .37461 L
s
.51856 .38051 m
.5225 .3481 L
s
.5976 .37221 m
.60143 .38454 L
s
.59394 .36681 m
.5976 .37221 L
s
.69321 .34263 m
.6964 .34367 L
s
.79978 .33487 m
.80284 .3389 L
s
.6578 .35626 m
.66128 .36076 L
s
.32469 .58352 m
.32899 .58812 L
s
.49806 .52586 m
.50187 .53916 L
s
.49382 .55419 m
.49806 .52586 L
s
.8389 .33056 m
.84186 .33462 L
s
.40661 .40946 m
.41006 .43087 L
s
.40063 .44869 m
.40661 .40946 L
s
.73216 .33559 m
.73543 .33987 L
s
.50657 .62024 m
.51055 .60791 L
s
.67874 .33724 m
.68222 .3429 L
s
.50187 .53916 m
.50567 .55466 L
s
.77126 .33102 m
.7745 .33619 L
s
.82468 .32891 m
.82777 .33384 L
s
.7856 .33382 m
.78878 .33869 L
s
.30713 .62128 m
.31176 .6216 L
s
.64348 .35339 m
.64712 .36082 L
s
.49476 .85588 m
.49832 .90001 L
s
.31005 .58609 m
.31453 .58863 L
s
.71799 .33523 m
.7213 .33949 L
s
.36271 .88455 m
.36728 .88101 L
s
.56357 .44082 m
.56738 .45095 L
s
.55973 .42706 m
.56357 .44082 L
s
.5559 .41531 m
.55973 .42706 L
s
.5521 .40583 m
.5559 .41531 L
s
.50444 .53857 m
.50848 .52072 L
s
.81068 .32959 m
.81374 .3339 L
s
.75709 .33033 m
.76044 .33641 L
s
.57708 .41174 m
.58065 .40862 L
s
.58383 .39452 m
.58729 .38761 L
s
.1721 .32601 m
.17682 .33083 L
s
.57031 .42607 m
.57403 .43074 L
s
.31172 .68295 m
.31639 .68235 L
s
.74305 .33152 m
.74622 .33485 L
s
.7036 .33153 m
.7072 .33985 L
s
.49903 .57734 m
.50281 .59579 L
s
.49482 .6036 m
.49903 .57734 L
s
.4966 .72787 m
.50108 .6684 L
s
.59053 .37371 m
.59394 .36681 L
s
.84996 .32612 m
.85294 .33064 L
s
.54828 .39609 m
.5521 .40583 L
s
.44725 .96614 m
.44963 1.04552 L
s
.60465 .36665 m
.60825 .36996 L
s
.6256 .34621 m
.62918 .35084 L
s
.32035 .57926 m
.32469 .58352 L
s
.63986 .34676 m
.64348 .35339 L
s
.43748 .84186 m
.44313 .78508 L
s
.65423 .35031 m
.6578 .35626 L
s
.45223 .56291 m
.45612 .57212 L
s
.67549 .3365 m
.67874 .33724 L
s
.79652 .32893 m
.79978 .33487 L
s
.37721 .70701 m
.38075 .72562 L
s
.37315 .6999 m
.37721 .70701 L
s
.83589 .32609 m
.8389 .33056 L
s
.72895 .33233 m
.73216 .33559 L
s
.76808 .32676 m
.77126 .33102 L
s
.66492 .34484 m
.66833 .348 L
s
.54448 .38845 m
.54828 .39609 L
s
.8216 .32421 m
.82468 .32891 L
s
.70048 .33133 m
.7036 .33153 L
s
.78225 .32718 m
.7856 .33382 L
s
.61166 .35694 m
.61496 .35095 L
s
.41006 .43087 m
.41338 .45658 L
s
.75387 .32606 m
.75709 .33033 L
s
.71475 .33229 m
.71799 .33523 L
s
.68969 .33604 m
.69321 .34263 L
s
.62166 .33117 m
.6256 .34621 L
s
.61855 .34161 m
.62166 .33117 L
s
.30552 .5839 m
.31005 .58609 L
s
.50281 .59579 m
.50657 .62024 L
s
.80756 .32485 m
.81068 .32959 L
s
.52632 .37461 m
.53015 .38517 L
s
.6362 .33933 m
.63986 .34676 L
s
.56653 .41841 m
.57031 .42607 L
s
.16736 .32116 m
.1721 .32601 L
s
.36901 .69404 m
.37315 .6999 L
s
.30247 .62074 m
.30713 .62128 L
s
.54064 .37688 m
.54448 .38845 L
s
.43576 .47275 m
.43957 .48572 L
s
.43183 .46394 m
.43576 .47275 L
s
.35776 .6528 m
.36146 .66747 L
s
.35387 .6417 m
.35776 .6528 L
s
.65062 .34346 m
.65423 .35031 L
s
.53682 .36782 m
.54064 .37688 L
s
.84702 .32208 m
.84996 .32612 L
s
.79329 .32343 m
.79652 .32893 L
s
.31597 .57517 m
.32035 .57926 L
s
.7398 .32746 m
.74305 .33152 L
s
.38075 .72562 m
.38366 .75897 L
s
.40099 .65711 m
.40914 .56001 L
s
.34984 .63316 m
.35387 .6417 L
s
.43957 .48572 m
.44334 .50049 L
s
.46083 .637 m
.46392 .6871 L
s
.77899 .32179 m
.78225 .32718 L
s
.41338 .45658 m
.41755 .45979 L
s
.6008 .35411 m
.60465 .36665 L
s
.59725 .35397 m
.6008 .35411 L
s
.50896 .44275 m
.51301 .41922 L
s
.36146 .66747 m
.36513 .68284 L
s
.50615 .47172 m
.51019 .45361 L
s
.83278 .32085 m
.83589 .32609 L
s
.68608 .32819 m
.68969 .33604 L
s
.42792 .45397 m
.43183 .46394 L
s
.533 .3692 m
.53682 .36782 L
s
.81854 .31982 m
.8216 .32421 L
s
.3581 .88805 m
.36271 .88455 L
s
.76476 .32095 m
.76808 .32676 L
s
.44719 .51217 m
.45103 .52432 L
s
.44334 .50049 m
.44719 .51217 L
s
.30694 .68465 m
.31172 .68295 L
s
.56273 .40969 m
.56653 .41841 L
s
.45103 .52432 m
.45463 .54658 L
s
.63277 .33848 m
.6362 .33933 L
s
.34578 .62488 m
.34984 .63316 L
s
.72552 .32626 m
.72895 .33233 L
s
.66144 .3405 m
.66492 .34484 L
s
.36513 .68284 m
.36901 .69404 L
s
.7507 .32254 m
.75387 .32606 L
s
.42404 .44284 m
.42792 .45397 L
s
.64708 .33883 m
.65062 .34346 L
s
.67216 .33457 m
.67549 .3365 L
s
.41992 .43833 m
.42404 .44284 L
s
.57338 .40896 m
.57708 .41174 L
s
.80433 .31919 m
.80756 .32485 L
s
.71112 .32349 m
.71475 .33229 L
s
.1626 .31629 m
.16736 .32116 L
s
.55891 .40024 m
.56273 .40969 L
s
.68277 .32592 m
.68608 .32819 L
s
.50339 .49499 m
.50735 .49204 L
s
.79004 .31786 m
.79329 .32343 L
s
.30093 .58208 m
.30552 .5839 L
s
.34175 .616 m
.34578 .62488 L
s
.6971 .32698 m
.70048 .33133 L
s
.39582 .52834 m
.40294 .46408 L
s
.77587 .318 m
.77899 .32179 L
s
.31156 .57125 m
.31597 .57517 L
s
.844 .31747 m
.84702 .32208 L
s
.73653 .32324 m
.7398 .32746 L
s
.49832 .90001 m
.50224 .90305 L
s
.55507 .38931 m
.55891 .40024 L
s
.76153 .31643 m
.76476 .32095 L
s
.82961 .31524 m
.83278 .32085 L
s
.70781 .31997 m
.71112 .32349 L
s
.72222 .32221 m
.72552 .32626 L
s
.29781 .61985 m
.30247 .62074 L
s
.43143 .99377 m
.43984 .83727 L
s
.55123 .37894 m
.55507 .38931 L
s
.3377 .60721 m
.34175 .616 L
s
.58022 .39522 m
.58383 .39452 L
s
.81542 .31494 m
.81854 .31982 L
s
.58702 .37829 m
.59053 .37371 L
s
.50064 .51843 m
.50444 .53857 L
s
.49677 .50791 m
.50064 .51843 L
s
.40332 .81021 m
.40657 .83911 L
s
.39868 .81853 m
.40332 .81021 L
s
.54741 .37075 m
.55123 .37894 L
s
.65788 .33483 m
.66144 .3405 L
s
.51177 .41714 m
.51578 .3962 L
s
.80114 .31394 m
.80433 .31919 L
s
.52914 .35337 m
.533 .3692 L
s
.52528 .3426 m
.52914 .35337 L
s
.64339 .33078 m
.64708 .33883 L
s
.49242 .54073 m
.49677 .50791 L
s
.45463 .54658 m
.45802 .57992 L
s
.41566 .43723 m
.41992 .43833 L
s
.33359 .59926 m
.3377 .60721 L
s
.59383 .36061 m
.59725 .35397 L
s
.74745 .31829 m
.7507 .32254 L
s
.49959 .47481 m
.50339 .49499 L
s
.49548 .48724 m
.49959 .47481 L
s
.15781 .31139 m
.1626 .31629 L
s
.78686 .3131 m
.79004 .31786 L
s
.52136 .36743 m
.52528 .3426 L
s
.60789 .3481 m
.61166 .35694 L
s
.4083 .4036 m
.41179 .42516 L
s
.40364 .41074 m
.4083 .4036 L
s
.62891 .32628 m
.63277 .33848 L
s
.62542 .325 m
.62891 .32628 L
s
.5696 .40175 m
.57338 .40896 L
s
.69349 .31917 m
.6971 .32698 L
s
.30711 .56751 m
.31156 .57125 L
s
.30204 .68741 m
.30694 .68465 L
s
.54355 .35964 m
.54741 .37075 L
s
.66872 .33093 m
.67216 .33457 L
s
.84089 .31215 m
.844 .31747 L
s
.82653 .31049 m
.82961 .31524 L
s
.77257 .31243 m
.77587 .318 L
s
.35345 .8916 m
.3581 .88805 L
s
.53973 .35498 m
.54355 .35964 L
s
.73311 .31713 m
.73653 .32324 L
s
.29628 .58057 m
.30093 .58208 L
s
.63987 .32728 m
.64339 .33078 L
s
.67947 .32428 m
.68277 .32592 L
s
.32942 .59207 m
.33359 .59926 L
s
.75835 .31273 m
.76153 .31643 L
s
.60411 .33875 m
.60789 .3481 L
s
.48645 .6935 m
.49009 .72529 L
s
.48197 .72715 m
.48645 .6935 L
s
.71871 .3154 m
.72222 .32221 L
s
.81227 .30991 m
.81542 .31494 L
s
.70455 .31755 m
.70781 .31997 L
s
.65432 .32953 m
.65788 .33483 L
s
.5052 .84341 m
.50961 .76737 L
s
.46711 .635 m
.46971 .71958 L
s
.39597 .59689 m
.40347 .52207 L
s
.38366 .75897 m
.38639 .79791 L
s
.79797 .30914 m
.80114 .31394 L
s
.69009 .31519 m
.69349 .31917 L
s
.60067 .34319 m
.60411 .33875 L
s
.56576 .39181 m
.5696 .40175 L
s
.29314 .61862 m
.29781 .61985 L
s
.61501 .34001 m
.61855 .34161 L
s
.15299 .30647 m
.15781 .31139 L
s
.78376 .30948 m
.78686 .3131 L
s
.74412 .31326 m
.74745 .31829 L
s
.32521 .58523 m
.32942 .59207 L
s
.4916 .67249 m
.49592 .6427 L
s
.43791 .46176 m
.44174 .47489 L
s
.43398 .4515 m
.43791 .46176 L
s
.56191 .3813 m
.56576 .39181 L
s
.72972 .31177 m
.73311 .31713 L
s
.83774 .30657 m
.84089 .31215 L
s
.44174 .47489 m
.44552 .49023 L
s
.76925 .3067 m
.77257 .31243 L
s
.57647 .39039 m
.58022 .39522 L
s
.30262 .56393 m
.30711 .56751 L
s
.71526 .30959 m
.71871 .3154 L
s
.82344 .30584 m
.82653 .31049 L
s
.43005 .4412 m
.43398 .4515 L
s
.55806 .37081 m
.56191 .3813 L
s
.41179 .42516 m
.41566 .43723 L
s
.53588 .35101 m
.53973 .35498 L
s
.53199 .33098 m
.53588 .35101 L
s
.52813 .33891 m
.53199 .33098 L
s
.66519 .32569 m
.66872 .33093 L
s
.48928 .59814 m
.49382 .55419 L
s
.80914 .30524 m
.81227 .30991 L
s
.55422 .36206 m
.55806 .37081 L
s
.65067 .32258 m
.65432 .32953 L
s
.42616 .42979 m
.43005 .4412 L
s
.63622 .32075 m
.63987 .32728 L
s
.62209 .32903 m
.62542 .325 L
s
.75512 .30853 m
.75835 .31273 L
s
.46392 .6871 m
.468 .6886 L
s
.44552 .49023 m
.44925 .50799 L
s
.42212 .42223 m
.42616 .42979 L
s
.40657 .83911 m
.40816 .91766 L
s
.32098 .57858 m
.32521 .58523 L
s
.2916 .57922 m
.29628 .58057 L
s
.50231 .45473 m
.50615 .47172 L
s
.49835 .45149 m
.50231 .45473 L
s
.79477 .30408 m
.79797 .30914 L
s
.67605 .32082 m
.67947 .32428 L
s
.49027 .65028 m
.49482 .6036 L
s
.70099 .3105 m
.70455 .31755 L
s
.58336 .3771 m
.58702 .37829 L
s
.68681 .31355 m
.69009 .31519 L
s
.14816 .30153 m
.15299 .30647 L
s
.74075 .30776 m
.74412 .31326 L
s
.55037 .35297 m
.55422 .36206 L
s
.29703 .6912 m
.30204 .68741 L
s
.3938 .83186 m
.39868 .81853 L
s
.83465 .30168 m
.83774 .30657 L
s
.76608 .30296 m
.76925 .3067 L
s
.34876 .89513 m
.35345 .8916 L
s
.72634 .30673 m
.72972 .31177 L
s
.41842 .81983 m
.42554 .73168 L
s
.78049 .30412 m
.78376 .30948 L
s
.71208 .30808 m
.71526 .30959 L
s
.51458 .3933 m
.51856 .38051 L
s
.28844 .61728 m
.29314 .61862 L
s
.57265 .382 m
.57647 .39039 L
s
.41793 .41869 m
.42212 .42223 L
s
.64704 .31616 m
.65067 .32258 L
s
.39107 .32563 m
.39298 .38054 L
s
.38239 .41129 m
.39107 .32563 L
s
.61115 .3285 m
.61501 .34001 L
s
.82034 .3012 m
.82344 .30584 L
s
.63239 .31015 m
.63622 .32075 L
s
.6616 .31964 m
.66519 .32569 L
s
.2981 .5605 m
.30262 .56393 L
s
.44925 .50799 m
.45295 .52769 L
s
.3167 .57223 m
.32098 .57858 L
s
.60757 .32692 m
.61115 .3285 L
s
.5465 .34363 m
.55037 .35297 L
s
.59027 .36268 m
.59383 .36061 L
s
.62918 .31636 m
.63239 .31015 L
s
.45802 .57992 m
.46151 .61107 L
s
.80602 .30077 m
.80914 .30524 L
s
.69749 .30465 m
.70099 .3105 L
s
.39786 .44217 m
.40364 .41074 L
s
.7518 .30348 m
.75512 .30853 L
s
.56881 .37245 m
.57265 .382 L
s
.52459 1.03074 m
.52714 .92588 L
s
.79167 .30032 m
.79477 .30408 L
s
.54267 .34046 m
.5465 .34363 L
s
.49009 .72529 m
.49335 .80018 L
s
.73735 .30213 m
.74075 .30776 L
s
.49394 .48815 m
.49835 .45149 L
s
.1433 .29656 m
.14816 .30153 L
s
.67253 .31583 m
.67605 .32082 L
s
.50507 .4305 m
.50896 .44275 L
s
.50115 .4223 m
.50507 .4305 L
s
.6435 .31243 m
.64704 .31616 L
s
.28687 .57787 m
.2916 .57922 L
s
.59719 .34745 m
.60067 .34319 L
s
.56495 .36257 m
.56881 .37245 L
s
.77714 .29798 m
.78049 .30412 L
s
.83157 .29703 m
.83465 .30168 L
s
.7228 .29956 m
.72634 .30673 L
s
.31239 .56629 m
.3167 .57223 L
s
.49889 1.02164 m
.49708 .87833 L
s
.49097 .52933 m
.49548 .48724 L
s
.39436 .49065 m
.40063 .44869 L
s
.65799 .31354 m
.6616 .31964 L
s
.76288 .29894 m
.76608 .30296 L
s
.41017 .39382 m
.41391 .40973 L
s
.4058 .39328 m
.41017 .39382 L
s
.45295 .52769 m
.45668 .54682 L
s
.68342 .3104 m
.68681 .31355 L
s
.81722 .29646 m
.82034 .3012 L
s
.57958 .3712 m
.58336 .3771 L
s
.41391 .40973 m
.41793 .41869 L
s
.56109 .35291 m
.56495 .36257 L
s
.29353 .55724 m
.2981 .5605 L
s
.69421 .30286 m
.69749 .30465 L
s
.38779 .36866 m
.39011 .41476 L
s
.37888 .45784 m
.38779 .36866 L
s
.49681 .45522 m
.50115 .4223 L
s
.28369 .6162 m
.28844 .61728 L
s
.70858 .30193 m
.71208 .30808 L
s
.80274 .29493 m
.80602 .30077 L
s
.74848 .29857 m
.7518 .30348 L
s
.55723 .34436 m
.56109 .35291 L
s
.49775 .93529 m
.50273 .81547 L
s
.71965 .29824 m
.7228 .29956 L
s
.61832 .32047 m
.62209 .32903 L
s
.73404 .29796 m
.73735 .30213 L
s
.60414 .33202 m
.60757 .32692 L
s
.44013 .44897 m
.44396 .4633 L
s
.43622 .43729 m
.44013 .44897 L
s
.30802 .56075 m
.31239 .56629 L
s
.78842 .29512 m
.79167 .30032 L
s
.34403 .89844 m
.34876 .89513 L
s
.77393 .29365 m
.77714 .29798 L
s
.43229 .42588 m
.43622 .43729 L
s
.13841 .29156 m
.1433 .29656 L
s
.38639 .79791 m
.38962 .82625 L
s
.2919 .69595 m
.29703 .6912 L
s
.66894 .30979 m
.67253 .31583 L
s
.53878 .32922 m
.54267 .34046 L
s
.42836 .4148 m
.43229 .42588 L
s
.65431 .30624 m
.65799 .31354 L
s
.82849 .29247 m
.83157 .29703 L
s
.52421 .35211 m
.52813 .33891 L
s
.44396 .4633 m
.44775 .47956 L
s
.53488 .3183 m
.53878 .32922 L
s
.50787 .40484 m
.51177 .41714 L
s
.50393 .39775 m
.50787 .40484 L
s
.42431 .40712 m
.42836 .4148 L
s
.6396 .30027 m
.6435 .31243 L
s
.63629 .30332 m
.6396 .30027 L
s
.55336 .33475 m
.55723 .34436 L
s
.45668 .54682 m
.46039 .56786 L
s
.57575 .36282 m
.57958 .3712 L
s
.61456 .31294 m
.61832 .32047 L
s
.53103 .33196 m
.53488 .3183 L
s
.75959 .29415 m
.76288 .29894 L
s
.81409 .29187 m
.81722 .29646 L
s
.4694 .631 m
.47314 .65269 L
s
.46535 .62651 m
.4694 .631 L
s
.58655 .3593 m
.59027 .36268 L
s
.28213 .57638 m
.28687 .57787 L
s
.705 .29496 m
.70858 .30193 L
s
.79962 .29074 m
.80274 .29493 L
s
.54951 .32882 m
.55336 .33475 L
s
.28892 .55424 m
.29353 .55724 L
s
.67993 .30579 m
.68342 .3104 L
s
.46094 1.0469 m
.46316 1.00133 L
s
.45028 1.05975 m
.44963 1.04552 L
s
.74509 .29293 m
.74848 .29857 L
s
.44775 .47956 m
.45151 .49748 L
s
.6508 .30281 m
.65431 .30624 L
s
.30362 .55546 m
.30802 .56075 L
s
.57189 .35339 m
.57575 .36282 L
s
.42017 .40134 m
.42431 .40712 L
s
.49962 .43063 m
.50393 .39775 L
s
.66535 .30405 m
.66894 .30979 L
s
.40058 .41174 m
.4058 .39328 L
s
.78508 .28906 m
.78842 .29512 L
s
.69085 .30003 m
.69421 .30286 L
s
.73046 .29024 m
.73404 .29796 L
s
.1335 .28654 m
.13841 .29156 L
s
.61114 .31703 m
.61456 .31294 L
s
.27886 .61575 m
.28369 .6162 L
s
.46151 .61107 m
.46535 .62651 L
s
.77074 .28964 m
.77393 .29365 L
s
.51741 .36865 m
.52136 .36743 L
s
.38962 .82625 m
.3938 .83186 L
s
.62553 .31173 m
.62918 .31636 L
s
.51069 .37763 m
.51458 .3933 L
s
.50669 .37784 m
.51069 .37763 L
s
.56802 .3436 m
.57189 .35339 L
s
.70171 .29251 m
.705 .29496 L
s
.82534 .2873 m
.82849 .29247 L
s
.71621 .29294 m
.71965 .29824 L
s
.59354 .34638 m
.59719 .34745 L
s
.46039 .56786 m
.46393 .59864 L
s
.43233 .87423 m
.43748 .84186 L
s
.45151 .49748 m
.45521 .51867 L
s
.75629 .28944 m
.75959 .29415 L
s
.54563 .32213 m
.54951 .32882 L
s
.8108 .28577 m
.81409 .29187 L
s
.56415 .33491 m
.56802 .3436 L
s
.72728 .2882 m
.73046 .29024 L
s
.47314 .65269 m
.47635 .71038 L
s
.74179 .28877 m
.74509 .29293 L
s
.58274 .35225 m
.58655 .3593 L
s
.29918 .55029 m
.30362 .55546 L
s
.41616 .39167 m
.42017 .40134 L
s
.7964 .28576 m
.79962 .29074 L
s
.48784 .58243 m
.49242 .54073 L
s
.67636 .30007 m
.67993 .30579 L
s
.33929 .90131 m
.34403 .89844 L
s
.78186 .28444 m
.78508 .28906 L
s
.66168 .2969 m
.66535 .30405 L
s
.28425 .55156 m
.28892 .55424 L
s
.27736 .5748 m
.28213 .57638 L
s
.49196 .78526 m
.4966 .72787 L
s
.64699 .29303 m
.6508 .30281 L
s
.12856 .28149 m
.1335 .28654 L
s
.56027 .32588 m
.56415 .33491 L
s
.41223 .37977 m
.41616 .39167 L
s
.54171 .30834 m
.54563 .32213 L
s
.53786 .31357 m
.54171 .30834 L
s
.47717 .77379 m
.48197 .72715 L
s
.40779 .3803 m
.41223 .37977 L
s
.28666 .70147 m
.2919 .69595 L
s
.51351 .35075 m
.51741 .36865 L
s
.50944 .36479 m
.51351 .35075 L
s
.62168 .3015 m
.62553 .31173 L
s
.76747 .28491 m
.77074 .28964 L
s
.8222 .28249 m
.82534 .2873 L
s
.48731 .6911 m
.4916 .67249 L
s
.68739 .29568 m
.69085 .30003 L
s
.60056 .33288 m
.60414 .33202 L
s
.64349 .29095 m
.64699 .29303 L
s
.71262 .28563 m
.71621 .29294 L
s
.47619 .79813 m
.47904 .88772 L
s
.80766 .28125 m
.8108 .28577 L
s
.57888 .3434 m
.58274 .35225 L
s
.43853 .42117 m
.44244 .43394 L
s
.4346 .40934 m
.43853 .42117 L
s
.63278 .30171 m
.63629 .30332 L
s
.43061 .39907 m
.4346 .40934 L
s
.5564 .31818 m
.56027 .32588 L
s
.44244 .43394 m
.44629 .44864 L
s
.61821 .30289 m
.62168 .3015 L
s
.27391 .61628 m
.27886 .61575 L
s
.65814 .29274 m
.66168 .2969 L
s
.7529 .28369 m
.75629 .28944 L
s
.29471 .5453 m
.29918 .55029 L
s
.69837 .28977 m
.70171 .29251 L
s
.67278 .29439 m
.67636 .30007 L
s
.45521 .51867 m
.45885 .54396 L
s
.42655 .39102 m
.43061 .39907 L
s
.79308 .27983 m
.7964 .28576 L
s
.73824 .28139 m
.74179 .28877 L
s
.44629 .44864 m
.4501 .46554 L
s
.50239 .41243 m
.50669 .37784 L
s
.575 .33399 m
.57888 .3434 L
s
.77867 .2803 m
.78186 .28444 L
s
.58976 .34084 m
.59354 .34638 L
s
.1236 .27642 m
.12856 .28149 L
s
.70928 .28238 m
.71262 .28563 L
s
.72389 .28358 m
.72728 .2882 L
s
.27953 .54911 m
.28425 .55156 L
s
.55254 .31248 m
.5564 .31818 L
s
.39228 .32639 m
.39601 .34302 L
s
.38431 .39698 m
.39228 .32639 L
s
.27254 .57329 m
.27736 .5748 L
s
.57113 .32515 m
.575 .33399 L
s
.60763 .3193 m
.61114 .31703 L
s
.76417 .2801 m
.76747 .28491 L
s
.42246 .38317 m
.42655 .39102 L
s
.38753 .44268 m
.38984 .49076 L
s
.38315 .43978 m
.38753 .44268 L
s
.81893 .27648 m
.8222 .28249 L
s
.68384 .29017 m
.68739 .29568 L
s
.4501 .46554 m
.45385 .48507 L
s
.33302 .62058 m
.33693 .63313 L
s
.32905 .60889 m
.33302 .62058 L
s
.33693 .63313 m
.34078 .64694 L
s
.74959 .27926 m
.7529 .28369 L
s
.80447 .27642 m
.80766 .28125 L
s
.73499 .27829 m
.73824 .28139 L
s
.32504 .59795 m
.32905 .60889 L
s
.33455 .90354 m
.33929 .90131 L
s
.29019 .54065 m
.29471 .5453 L
s
.66912 .28752 m
.67278 .29439 L
s
.78986 .27509 m
.79308 .27983 L
s
.34078 .64694 m
.34452 .66256 L
s
.32097 .58772 m
.32504 .59795 L
s
.65441 .28483 m
.65814 .29274 L
s
.52028 .34064 m
.52421 .35211 L
s
.56725 .31638 m
.57113 .32515 L
s
.64005 .29095 m
.64349 .29095 L
s
.39601 .34302 m
.39879 .38137 L
s
.46393 .59864 m
.46734 .63884 L
s
.51633 .33076 m
.52028 .34064 L
s
.40296 .3892 m
.40779 .3803 L
s
.58592 .33287 m
.58976 .34084 L
s
.50495 1.01509 m
.50354 .89681 L
s
.41844 .37301 m
.42246 .38317 L
s
.62892 .29156 m
.63278 .30171 L
s
.31684 .57822 m
.32097 .58772 L
s
.69492 .28558 m
.69837 .28977 L
s
.52709 .33007 m
.53103 .33196 L
s
.54861 .30107 m
.55254 .31248 L
s
.7754 .27552 m
.77867 .2803 L
s
.48296 .9076 m
.48779 .84905 L
s
.11861 .27132 m
.1236 .27642 L
s
.34452 .66256 m
.34818 .67983 L
s
.26882 .61799 m
.27391 .61628 L
s
.59683 .32889 m
.60056 .33288 L
s
.72031 .27633 m
.72389 .28358 L
s
.54474 .29883 m
.54861 .30107 L
s
.5122 .35757 m
.51633 .33076 L
s
.39011 .41476 m
.39296 .45122 L
s
.41433 .36533 m
.41844 .37301 L
s
.8158 .27195 m
.81893 .27648 L
s
.62535 .2897 m
.62892 .29156 L
s
.39298 .38054 m
.39593 .41507 L
s
.56336 .30817 m
.56725 .31638 L
s
.31266 .5694 m
.31684 .57822 L
s
.65079 .27967 m
.65441 .28483 L
s
.28133 .70746 m
.28666 .70147 L
s
.70595 .27961 m
.70928 .28238 L
s
.66555 .28264 m
.66912 .28752 L
s
.27478 .54673 m
.27953 .54911 L
s
.45885 .54396 m
.46248 .57118 L
s
.76078 .27431 m
.76417 .2801 L
s
.68026 .28443 m
.68384 .29017 L
s
.45385 .48507 m
.45757 .50713 L
s
.61475 .30588 m
.61821 .30289 L
s
.58205 .32393 m
.58592 .33287 L
s
.53396 .31655 m
.53786 .31357 L
s
.28561 .53641 m
.29019 .54065 L
s
.80116 .27054 m
.80447 .27642 L
s
.39296 .45122 m
.39786 .44217 L
s
.3724 .56385 m
.38315 .43978 L
s
.74608 .27236 m
.74959 .27926 L
s
.26767 .57214 m
.27254 .57329 L
s
.52315 .31184 m
.52709 .33007 L
s
.51915 .32406 m
.52315 .31184 L
s
.48475 .63015 m
.48928 .59814 L
s
.40368 .7799 m
.41099 .70177 L
s
.44091 .40358 m
.44484 .41663 L
s
.43695 .3919 m
.44091 .40358 L
s
.34818 .67983 m
.35183 .6975 L
s
.78667 .27083 m
.78986 .27509 L
s
.30843 .56114 m
.31266 .5694 L
s
.43293 .38192 m
.43695 .3919 L
s
.44484 .41663 m
.44871 .43141 L
s
.73164 .27404 m
.73499 .27829 L
s
.55949 .30215 m
.56336 .30817 L
s
.39855 .31605 m
.40171 .34636 L
s
.39286 .34111 m
.39855 .31605 L
s
.40983 .3667 m
.41433 .36533 L
s
.71694 .2724 m
.72031 .27633 L
s
.57816 .31505 m
.58205 .32393 L
s
.11359 .2662 m
.11861 .27132 L
s
.42887 .37317 m
.43293 .38192 L
s
.39593 .41507 m
.40058 .41174 L
s
.77211 .27057 m
.7754 .27552 L
s
.44871 .43141 m
.45254 .44875 L
s
.69138 .2802 m
.69492 .28558 L
s
.384 .49088 m
.38723 .51898 L
s
.37459 .59056 m
.384 .49088 L
s
.3903 .55165 m
.39582 .52834 L
s
.3298 .90516 m
.33455 .90354 L
s
.30416 .55335 m
.30843 .56114 L
s
.75747 .26966 m
.76078 .27431 L
s
.59301 .32187 m
.59683 .32889 L
s
.67662 .27785 m
.68026 .28443 L
s
.81262 .2671 m
.8158 .27195 L
s
.64739 .28001 m
.65079 .27967 L
s
.60395 .31664 m
.60763 .3193 L
s
.48574 .68392 m
.49027 .65028 L
s
.74279 .26853 m
.74608 .27236 L
s
.35183 .6975 m
.35549 .71521 L
s
.66186 .27569 m
.66555 .28264 L
s
.4088 1.01836 m
.40816 .91766 L
s
.57428 .30643 m
.57816 .31505 L
s
.48939 .52504 m
.49394 .48815 L
s
.79794 .26565 m
.80116 .27054 L
s
.63623 .28194 m
.64005 .29095 L
s
.54087 .30227 m
.54474 .29883 L
s
.4248 .36405 m
.42887 .37317 L
s
.28098 .53249 m
.28561 .53641 L
s
.48263 .80292 m
.48475 .96877 L
s
.26999 .54436 m
.27478 .54673 L
s
.45757 .50713 m
.46126 .53169 L
s
.4923 .49222 m
.49681 .45522 L
s
.46971 .71958 m
.47295 .77587 L
s
.70252 .27548 m
.70595 .27961 L
s
.62192 .29282 m
.62535 .2897 L
s
.55557 .29263 m
.55949 .30215 L
s
.45254 .44875 m
.45632 .46831 L
s
.50516 .39815 m
.50944 .36479 L
s
.78341 .26599 m
.78667 .27083 L
s
.29983 .54602 m
.30416 .55335 L
s
.26359 .62083 m
.26882 .61799 L
s
.72807 .26698 m
.73164 .27404 L
s
.57039 .29822 m
.57428 .30643 L
s
.63258 .27743 m
.63623 .28194 L
s
.35549 .71521 m
.35902 .73588 L
s
.42072 .35503 m
.4248 .36405 L
s
.58914 .31337 m
.59301 .32187 L
s
.2627 .57165 m
.26767 .57214 L
s
.71362 .26952 m
.71694 .2724 L
s
.55167 .28703 m
.55557 .29263 L
s
.10855 .26104 m
.11359 .2662 L
s
.68781 .27446 m
.69138 .2802 L
s
.48304 .7018 m
.48731 .6911 L
s
.67303 .27257 m
.67662 .27785 L
s
.76873 .26485 m
.77211 .27057 L
s
.65819 .26927 m
.66186 .27569 L
s
.52999 .30072 m
.53396 .31655 L
s
.52603 .29821 m
.52999 .30072 L
s
.46248 .57118 m
.46617 .59761 L
s
.48642 .56272 m
.49097 .52933 L
s
.80932 .26122 m
.81262 .2671 L
s
.75398 .26311 m
.75747 .26966 L
s
.38984 .49076 m
.39436 .49065 L
s
.49335 .80018 m
.49686 .86482 L
s
.41644 .35101 m
.42072 .35503 L
s
.29545 .53916 m
.29983 .54602 L
s
.79475 .26129 m
.79794 .26565 L
s
.56651 .29169 m
.57039 .29822 L
s
.73946 .26439 m
.74279 .26853 L
s
.27593 .71357 m
.28133 .70746 L
s
.61111 .30423 m
.61475 .30588 L
s
.58525 .30466 m
.58914 .31337 L
s
.27631 .52873 m
.28098 .53249 L
s
.60014 .31043 m
.60395 .31664 L
s
.72468 .26255 m
.72807 .26698 L
s
.42792 .87723 m
.43233 .87423 L
s
.4054 .36557 m
.40983 .3667 L
s
.45632 .46831 m
.46006 .49079 L
s
.39879 .38137 m
.40296 .3892 L
s
.44336 .38446 m
.44731 .39738 L
s
.43937 .37313 m
.44336 .38446 L
s
.32504 .90634 m
.3298 .90516 L
s
.69899 .27019 m
.70252 .27548 L
s
.44731 .39738 m
.45122 .41206 L
s
.78012 .26098 m
.78341 .26599 L
s
.26516 .54215 m
.26999 .54436 L
s
.43532 .3632 m
.43937 .37313 L
s
.65478 .26904 m
.65819 .26927 L
s
.49516 .46501 m
.49962 .43063 L
s
.35902 .73588 m
.3622 .76394 L
s
.54782 .28867 m
.55167 .28703 L
s
.68418 .2681 m
.68781 .27446 L
s
.58136 .29617 m
.58525 .30466 L
s
.62917 .28021 m
.63258 .27743 L
s
.76542 .26005 m
.76873 .26485 L
s
.6436 .27201 m
.64739 .28001 L
s
.66937 .2661 m
.67303 .27257 L
s
.50085 .88234 m
.5052 .84341 L
s
.45122 .41206 m
.45508 .42884 L
s
.38723 .51898 m
.3903 .55165 L
s
.75067 .25885 m
.75398 .26311 L
s
.29103 .53273 m
.29545 .53916 L
s
.46126 .53169 m
.46492 .55953 L
s
.43125 .35385 m
.43532 .3632 L
s
.47635 .71038 m
.47949 .78112 L
s
.8061 .2562 m
.80932 .26122 L
s
.46734 .63884 m
.47089 .67563 L
s
.40171 .34636 m
.4054 .36557 L
s
.56259 .28311 m
.56651 .29169 L
s
.71019 .26539 m
.71362 .26952 L
s
.59628 .30244 m
.60014 .31043 L
s
.52201 .3218 m
.52603 .29821 L
s
.25762 .57198 m
.2627 .57165 L
s
.41207 .34862 m
.41644 .35101 L
s
.57747 .28805 m
.58136 .29617 L
s
.7915 .25642 m
.79475 .26129 L
s
.2078 .26967 m
.21171 .28257 L
s
.20346 .26039 m
.2078 .26967 L
s
.42717 .34454 m
.43125 .35385 L
s
.42415 .85806 m
.42792 .87723 L
s
.41988 .85502 m
.42415 .85806 L
s
.19689 .28005 m
.20035 .2969 L
s
.1929 .26777 m
.19689 .28005 L
s
.7359 .25749 m
.73946 .26439 L
s
.21171 .28257 m
.21511 .30022 L
s
.63989 .26591 m
.6436 .27201 L
s
.1885 .2589 m
.1929 .26777 L
s
.45508 .42884 m
.45889 .44834 L
s
.22256 .27274 m
.22631 .28719 L
s
.21835 .26242 m
.22256 .27274 L
s
.53689 .29024 m
.54087 .30227 L
s
.27161 .52504 m
.27631 .52873 L
s
.25825 .6245 m
.26359 .62083 L
s
.72136 .25951 m
.72468 .26255 L
s
.53292 .27848 m
.53689 .29024 L
s
.69543 .26449 m
.69899 .27019 L
s
.61832 .29187 m
.62192 .29282 L
s
.55868 .27659 m
.56259 .28311 L
s
.68059 .26263 m
.68418 .2681 L
s
.52898 .29793 m
.53292 .27848 L
s
.39053 .61827 m
.39597 .59689 L
s
.40442 .31612 m
.40807 .33661 L
s
.39977 .31889 m
.40442 .31612 L
s
.66568 .25936 m
.66937 .2661 L
s
.77676 .25532 m
.78012 .26098 L
s
.17786 .26699 m
.18178 .27984 L
s
.17347 .25782 m
.17786 .26699 L
s
.28655 .5267 m
.29103 .53273 L
s
.39467 .70208 m
.40099 .65711 L
s
.22631 .28719 m
.22954 .30671 L
s
.51502 .35063 m
.51915 .32406 L
s
.18178 .27984 m
.18513 .29743 L
s
.21383 .25485 m
.21835 .26242 L
s
.46617 .59761 m
.46989 .62431 L
s
.23716 .27738 m
.24068 .29428 L
s
.23315 .26528 m
.23716 .27738 L
s
.46006 .49079 m
.46377 .51614 L
s
.60733 .29877 m
.61111 .30423 L
s
.22877 .25665 m
.23315 .26528 L
s
.42298 .33814 m
.42717 .34454 L
s
.19884 .25341 m
.20346 .26039 L
s
.5924 .294 m
.59628 .30244 L
s
.76195 .25369 m
.76542 .26005 L
s
.57358 .28113 m
.57747 .28805 L
s
.26026 .54036 m
.26516 .54215 L
s
.18381 .25217 m
.1885 .2589 L
s
.80291 .25173 m
.8061 .2562 L
s
.20035 .2969 m
.20323 .31893 L
s
.24782 .26951 m
.25156 .2843 L
s
.24363 .25913 m
.24782 .26951 L
s
.74735 .25463 m
.75067 .25885 L
s
.32026 .90727 m
.32504 .90634 L
s
.16876 .25102 m
.17347 .25782 L
s
.21511 .30022 m
.21796 .32303 L
s
.16255 .26815 m
.16612 .2838 L
s
.15836 .25728 m
.16255 .26815 L
s
.7325 .2528 m
.7359 .25749 L
s
.70668 .26015 m
.71019 .26539 L
s
.63648 .26809 m
.63989 .26591 L
s
.22415 .25006 m
.22877 .25665 L
s
.23913 .25162 m
.24363 .25913 L
s
.48337 .60559 m
.48784 .58243 L
s
.25156 .2843 m
.25481 .30443 L
s
.24068 .29428 m
.2437 .31641 L
s
.45889 .44834 m
.46267 .4704 L
s
.55482 .27603 m
.55868 .27659 L
s
.44587 .36389 m
.44985 .3764 L
s
.44184 .35293 m
.44587 .36389 L
s
.1537 .24989 m
.15836 .25728 L
s
.58851 .28561 m
.5924 .294 L
s
.65103 .26176 m
.65478 .26904 L
s
.44985 .3764 m
.45379 .39054 L
s
.78821 .25134 m
.7915 .25642 L
s
.20912 .24877 m
.21383 .25485 L
s
.66226 .25833 m
.66568 .25936 L
s
.18513 .29743 m
.18787 .32035 L
s
.12857 .25273 m
.12401 .32561 L
s
.69181 .25825 m
.69543 .26449 L
s
.41294 .93246 m
.41988 .85502 L
s
.28202 .52097 m
.28655 .5267 L
s
.25837 .26283 m
.2623 .27591 L
s
.25406 .25374 m
.25837 .26283 L
s
.2705 .7195 m
.27593 .71357 L
s
.53984 .26277 m
.54385 .27888 L
s
.53595 .27857 m
.53984 .26277 L
s
.67694 .25625 m
.68059 .26263 L
s
.19406 .2476 m
.19884 .25341 L
s
.2623 .27591 m
.26573 .29432 L
s
.3622 .76394 m
.36509 .79894 L
s
.43778 .34288 m
.44184 .35293 L
s
.26686 .52151 m
.27161 .52504 L
s
.77344 .2504 m
.77676 .25532 L
s
.4187 .33338 m
.42298 .33814 L
s
.47883 .70487 m
.48304 .7018 L
s
.16612 .2838 m
.16899 .30502 L
s
.45379 .39054 m
.45769 .40675 L
s
.40807 .33661 m
.41207 .34862 L
s
.56967 .27299 m
.57358 .28113 L
s
.54385 .27888 m
.54782 .28867 L
s
.22954 .30671 m
.23229 .33117 L
s
.75864 .24921 m
.76195 .25369 L
s
.60348 .29125 m
.60733 .29877 L
s
.17898 .24649 m
.18381 .25217 L
s
.71794 .25532 m
.72136 .25951 L
s
.14306 .25797 m
.14634 .27565 L
s
.13865 .24854 m
.14306 .25797 L
s
.25243 .57308 m
.25762 .57198 L
s
.47295 .77587 m
.47717 .77379 L
s
.46492 .55953 m
.46859 .58907 L
s
.498 .44136 m
.50239 .41243 L
s
.6256 .27962 m
.62917 .28021 L
s
.16388 .24541 m
.16876 .25102 L
s
.4337 .33328 m
.43778 .34288 L
s
.27294 .2686 m
.27654 .2855 L
s
.26888 .25692 m
.27294 .2686 L
s
.58461 .27761 m
.58851 .28561 L
s
.2495 .24696 m
.25406 .25374 L
s
.23447 .24558 m
.23913 .25162 L
s
.26448 .24878 m
.26888 .25692 L
s
.14876 .24434 m
.1537 .24989 L
s
.64729 .25491 m
.65103 .26176 L
s
.45769 .40675 m
.46155 .42528 L
s
.61457 .28698 m
.61832 .29187 L
s
.2194 .2444 m
.22415 .25006 L
s
.79967 .2468 m
.80291 .25173 L
s
.7438 .24785 m
.74735 .25463 L
s
.38746 .5847 m
.39053 .61827 L
s
.38324 .57705 m
.38746 .5847 L
s
.50797 .38374 m
.5122 .35757 L
s
.70312 .25447 m
.70668 .26015 L
s
.25526 .53915 m
.26026 .54036 L
s
.56576 .26651 m
.56967 .27299 L
s
.72918 .24957 m
.7325 .2528 L
s
.20431 .24329 m
.20912 .24877 L
s
.42954 .32585 m
.4337 .33328 L
s
.68822 .25268 m
.69181 .25825 L
s
.20323 .31893 m
.2056 .3459 L
s
.27746 .51544 m
.28202 .52097 L
s
.5996 .28304 m
.60348 .29125 L
s
.67326 .24975 m
.67694 .25625 L
s
.46377 .51614 m
.46749 .54289 L
s
.26573 .29432 m
.26869 .31818 L
s
.25481 .30443 m
.25762 .32941 L
s
.28354 .26204 m
.28727 .2776 L
s
.27937 .25152 m
.28354 .26204 L
s
.78486 .24572 m
.78821 .25134 L
s
.1892 .24222 m
.19406 .2476 L
s
.25282 .62849 m
.25825 .6245 L
s
.46989 .62431 m
.47362 .6525 L
s
.14634 .27565 m
.14858 .30116 L
s
.21796 .32303 m
.22039 .35024 L
s
.27654 .2855 m
.27963 .30835 L
s
.58072 .27045 m
.58461 .27761 L
s
.31544 .90805 m
.32026 .90727 L
s
.46267 .4704 m
.46643 .4948 L
s
.76999 .24409 m
.77344 .2504 L
s
.41462 .32324 m
.4187 .33338 L
s
.25989 .2425 m
.26448 .24878 L
s
.17407 .24117 m
.17898 .24649 L
s
.38595 .38892 m
.39286 .34111 L
s
.2437 .31641 m
.24635 .34266 L
s
.27492 .24409 m
.27937 .25152 L
s
.39397 .34541 m
.39977 .31889 L
s
.26206 .51825 m
.26686 .52151 L
s
.41068 .30908 m
.41462 .32324 L
s
.40623 .30731 m
.41068 .30908 L
s
.24481 .24124 m
.2495 .24696 L
s
.54681 .2494 m
.55085 .26699 L
s
.54297 .26277 m
.54681 .2494 L
s
.37283 .69888 m
.38324 .57705 L
s
.16899 .30502 m
.17118 .33201 L
s
.75531 .24478 m
.75864 .24921 L
s
.28727 .2776 m
.29048 .29948 L
s
.15892 .24012 m
.16388 .24541 L
s
.18787 .32035 m
.19003 .34846 L
s
.41235 .86885 m
.41842 .81983 L
s
.64388 .25639 m
.64729 .25491 L
s
.22971 .24011 m
.23447 .24558 L
s
.48039 .64263 m
.48475 .63015 L
s
.46155 .42528 m
.46537 .4464 L
s
.48735 .8252 m
.49196 .78526 L
s
.71444 .25009 m
.71794 .25532 L
s
.47089 .67563 m
.47474 .69773 L
s
.59571 .2748 m
.5996 .28304 L
s
.7404 .24309 m
.7438 .24785 L
s
.29412 .25601 m
.29797 .27035 L
s
.28987 .24645 m
.29412 .25601 L
s
.42533 .31914 m
.42954 .32585 L
s
.65852 .25138 m
.66226 .25833 L
s
.55085 .26699 m
.55482 .27603 L
s
.31251 .57897 m
.31647 .59196 L
s
.30847 .56704 m
.31251 .57897 L
s
.45245 .35383 m
.45643 .36728 L
s
.44843 .3421 m
.45245 .35383 L
s
.21459 .23904 m
.2194 .2444 L
s
.56189 .26408 m
.56576 .26651 L
s
.31647 .59196 m
.32037 .60611 L
s
.30436 .55608 m
.30847 .56704 L
s
.44438 .33134 m
.44843 .3421 L
s
.61073 .27984 m
.61457 .28698 L
s
.45643 .36728 m
.46037 .38255 L
s
.79638 .24163 m
.79967 .2468 L
s
.69951 .24829 m
.70312 .25447 L
s
.27286 .51008 m
.27746 .51544 L
s
.66981 .24787 m
.67326 .24975 L
s
.29797 .27035 m
.3013 .29128 L
s
.19945 .23798 m
.20431 .24329 L
s
.68457 .24624 m
.68822 .25268 L
s
.5768 .26257 m
.58072 .27045 L
s
.30018 .54596 m
.30436 .55608 L
s
.32037 .60611 m
.32417 .62168 L
s
.23229 .33117 m
.23475 .35889 L
s
.63294 .26745 m
.63648 .26809 L
s
.28538 .23956 m
.28987 .24645 L
s
.78155 .24068 m
.78486 .24572 L
s
.44029 .32155 m
.44438 .33134 L
s
.27031 .23812 m
.27492 .24409 L
s
.18429 .23693 m
.1892 .24222 L
s
.47474 .69773 m
.47883 .70487 L
s
.76668 .23958 m
.76999 .24409 L
s
.2552 .23694 m
.25989 .2425 L
s
.62187 .27505 m
.6256 .27962 L
s
.24716 .57457 m
.25243 .57308 L
s
.46037 .38255 m
.46427 .40003 L
s
.72577 .24525 m
.72918 .24957 L
s
.59181 .26695 m
.59571 .2748 L
s
.3047 .25038 m
.30865 .26359 L
s
.30039 .24161 m
.3047 .25038 L
s
.29594 .53654 m
.30018 .54596 L
s
.48145 .69224 m
.48574 .68392 L
s
.16912 .23588 m
.17407 .24117 L
s
.30865 .26359 m
.31209 .28351 L
s
.32417 .62168 m
.32788 .63893 L
s
.2502 .53839 m
.25526 .53915 L
s
.26505 .72493 m
.2705 .7195 L
s
.24007 .23585 m
.24481 .24124 L
s
.43615 .31337 m
.44029 .32155 L
s
.42123 .30926 m
.42533 .31914 L
s
.65476 .24428 m
.65852 .25138 L
s
.22492 .23479 m
.22971 .24011 L
s
.25721 .51528 m
.26206 .51825 L
s
.60685 .27186 m
.61073 .27984 L
s
.5729 .25639 m
.5768 .26257 L
s
.75177 .23806 m
.75531 .24478 L
s
.26869 .31818 m
.27136 .34577 L
s
.27963 .30835 m
.28234 .33608 L
s
.71088 .24437 m
.71444 .25009 L
s
.29164 .52769 m
.29594 .53654 L
s
.46859 .58907 m
.47234 .61655 L
s
.46537 .4464 m
.46917 .46981 L
s
.73709 .23964 m
.7404 .24309 L
s
.47904 .88772 m
.48296 .9076 L
s
.3106 .90873 m
.31544 .90805 L
s
.69593 .24268 m
.69951 .24829 L
s
.20975 .23373 m
.21459 .23904 L
s
.25762 .32941 m
.26024 .35696 L
s
.29587 .23511 m
.30039 .24161 L
s
.41714 .29877 m
.42123 .30926 L
s
.26822 .50487 m
.27286 .51008 L
s
.68092 .24024 m
.68457 .24624 L
s
.29048 .29948 m
.29324 .32739 L
s
.46643 .4948 m
.47019 .52072 L
s
.28076 .2338 m
.28538 .23956 L
s
.31933 .25719 m
.32288 .276 L
s
.31529 .24503 m
.31933 .25719 L
s
.46749 .54289 m
.47125 .56945 L
s
.40116 .31884 m
.40623 .30731 L
s
.46427 .40003 m
.46813 .41987 L
s
.58791 .25966 m
.59181 .26695 L
s
.36509 .79894 m
.36809 .83288 L
s
.79304 .23604 m
.79638 .24163 L
s
.31093 .23692 m
.31529 .24503 L
s
.32788 .63893 m
.33149 .65805 L
s
.19457 .23268 m
.19945 .23798 L
s
.2056 .3459 m
.20764 .37641 L
s
.26562 .23266 m
.27031 .23812 L
s
.14858 .30116 m
.14994 .33383 L
s
.43199 .30512 m
.43615 .31337 L
s
.37269 .51083 m
.38239 .41129 L
s
.3013 .29128 m
.3041 .31929 L
s
.41273 .29591 m
.41714 .29877 L
s
.47362 .6525 m
.47743 .67825 L
s
.7781 .23437 m
.78155 .24068 L
s
.28731 .51927 m
.29164 .52769 L
s
.48499 .54097 m
.48939 .52504 L
s
.17937 .23162 m
.18429 .23693 L
s
.55791 .25492 m
.56189 .26408 L
s
.25046 .23159 m
.2552 .23694 L
s
.24736 .63225 m
.25282 .62849 L
s
.55386 .23919 m
.55791 .25492 L
s
.55004 .24952 m
.55386 .23919 L
s
.24635 .34266 m
.24891 .37032 L
s
.60296 .26376 m
.60685 .27186 L
s
.22039 .35024 m
.22263 .37971 L
s
.65136 .24516 m
.65476 .24428 L
s
.76334 .23486 m
.76668 .23958 L
s
.50086 .41849 m
.50516 .39815 L
s
.45911 .343 m
.46309 .35708 L
s
.45509 .3306 m
.45911 .343 L
s
.61804 .26814 m
.62187 .27505 L
s
.45104 .31933 m
.45509 .3306 L
s
.23528 .23052 m
.24007 .23585 L
s
.31209 .28351 m
.31496 .31143 L
s
.72227 .23997 m
.72577 .24525 L
s
.66607 .24084 m
.66981 .24787 L
s
.33001 .25106 m
.33368 .26863 L
s
.32589 .23989 m
.33001 .25106 L
s
.74839 .23339 m
.75177 .23806 L
s
.48791 .50932 m
.4923 .49222 L
s
.17118 .33201 m
.17277 .36435 L
s
.48206 .57388 m
.48642 .56272 L
s
.44695 .30931 m
.45104 .31933 L
s
.56901 .25246 m
.5729 .25639 L
s
.46309 .35708 m
.46704 .37318 L
s
.64034 .25554 m
.64388 .25639 L
s
.3064 .23072 m
.31093 .23692 L
s
.22009 .22947 m
.22492 .23479 L
s
.3215 .23234 m
.32589 .23989 L
s
.70729 .23826 m
.71088 .24437 L
s
.584 .25201 m
.58791 .25966 L
s
.42787 .29531 m
.43199 .30512 L
s
.29126 .22948 m
.29587 .23511 L
s
.19003 .34846 m
.19178 .38073 L
s
.62922 .26304 m
.63294 .26745 L
s
.28292 .51124 m
.28731 .51927 L
s
.52494 .3134 m
.52898 .29793 L
s
.69227 .23618 m
.69593 .24268 L
s
.67744 .23746 m
.68092 .24024 L
s
.32288 .276 m
.32584 .30346 L
s
.33149 .65805 m
.33499 .67936 L
s
.26355 .49984 m
.26822 .50487 L
s
.20488 .22841 m
.20975 .23373 L
s
.2523 .51246 m
.25721 .51528 L
s
.27609 .22838 m
.28076 .2338 L
s
.59907 .25601 m
.60296 .26376 L
s
.46813 .41987 m
.47198 .44198 L
s
.44282 .30026 m
.44695 .30931 L
s
.49686 .86482 m
.50085 .88234 L
s
.24509 .53764 m
.2502 .53839 L
s
.5179 .33814 m
.52201 .3218 L
s
.78973 .23087 m
.79304 .23604 L
s
.24186 .5759 m
.24716 .57457 L
s
.18965 .22735 m
.19457 .23268 L
s
.77481 .22992 m
.7781 .23437 L
s
.46704 .37318 m
.47095 .39152 L
s
.2609 .22731 m
.26562 .23266 L
s
.4237 .28681 m
.42787 .29531 L
s
.34071 .24515 m
.3445 .26132 L
s
.33653 .23491 m
.34071 .24515 L
s
.73367 .23515 m
.73709 .23964 L
s
.23475 .35889 m
.23724 .38687 L
s
.61416 .26033 m
.61804 .26814 L
s
.33368 .26863 m
.33677 .2951 L
s
.46917 .46981 m
.47298 .49454 L
s
.53198 .29169 m
.53595 .27857 L
s
.66233 .23395 m
.66607 .24084 L
s
.2457 .22624 m
.25046 .23159 L
s
.30573 .90936 m
.3106 .90873 L
s
.27849 .50355 m
.28292 .51124 L
s
.5801 .24607 m
.584 .25201 L
s
.31697 .22636 m
.3215 .23234 L
s
.33211 .22783 m
.33653 .23491 L
s
.43869 .29089 m
.44282 .30026 L
s
.23047 .22518 m
.23528 .23052 L
s
.75982 .22818 m
.76334 .23486 L
s
.71872 .23422 m
.72227 .23997 L
s
.40809 .29789 m
.41273 .29591 L
s
.47913 .60691 m
.48337 .60559 L
s
.3018 .22517 m
.3064 .23072 L
s
.38725 .66133 m
.39081 .68486 L
s
.37898 .74254 m
.38725 .66133 L
s
.49081 .47944 m
.49516 .46501 L
s
.3445 .26132 m
.34775 .28616 L
s
.59517 .24863 m
.59907 .25601 L
s
.2596 .72964 m
.26505 .72493 L
s
.70371 .23263 m
.70729 .23826 L
s
.36769 .58542 m
.37888 .45784 L
s
.47019 .52072 m
.47401 .54583 L
s
.47234 .61655 m
.47626 .63656 L
s
.74507 .2297 m
.74839 .23339 L
s
.41936 .28225 m
.4237 .28681 L
s
.68866 .23067 m
.69227 .23618 L
s
.21524 .22412 m
.22009 .22947 L
s
.35143 .23943 m
.35533 .25407 L
s
.34719 .23007 m
.35143 .23943 L
s
.2866 .22408 m
.29126 .22948 L
s
.47125 .56945 m
.47511 .59264 L
s
.47626 .63656 m
.48039 .64263 L
s
.27136 .34577 m
.27401 .37414 L
s
.51084 .36541 m
.51502 .35063 L
s
.47743 .67825 m
.48145 .69224 L
s
.56502 .24288 m
.56901 .25246 L
s
.25883 .49493 m
.26355 .49984 L
s
.28234 .33608 m
.2849 .36619 L
s
.46181 .31835 m
.46583 .3313 L
s
.45775 .30674 m
.46181 .31835 L
s
.47095 .39152 m
.47484 .41218 L
s
.61027 .25242 m
.61416 .26033 L
s
.43456 .28129 m
.43869 .29089 L
s
.46583 .3313 m
.46983 .34589 L
s
.6254 .25635 m
.62922 .26304 L
s
.19999 .22306 m
.20488 .22841 L
s
.33499 .67936 m
.33837 .70315 L
s
.27138 .22301 m
.27609 .22838 L
s
.26024 .35696 m
.26298 .38386 L
s
.27403 .4961 m
.27849 .50355 L
s
.45367 .29628 m
.45775 .30674 L
s
.35533 .25407 m
.35877 .27662 L
s
.29324 .32739 m
.29571 .35943 L
s
.78629 .2246 m
.78973 .23087 L
s
.65892 .23428 m
.66233 .23395 L
s
.25615 .22195 m
.2609 .22731 L
s
.24739 .50945 m
.2523 .51246 L
s
.46983 .34589 m
.47379 .36252 L
s
.34276 .22336 m
.34719 .23007 L
s
.53903 .27273 m
.54297 .26277 L
s
.47198 .44198 m
.47583 .46552 L
s
.32758 .222 m
.33211 .22783 L
s
.67369 .23014 m
.67744 .23746 L
s
.64782 .24391 m
.65136 .24516 L
s
.77145 .22485 m
.77481 .22992 L
s
.561 .23175 m
.56502 .24288 L
s
.73018 .22981 m
.73367 .23515 L
s
.63663 .25118 m
.64034 .25554 L
s
.44956 .28633 m
.45367 .29628 L
s
.3041 .31929 m
.3065 .3533 L
s
.43037 .27324 m
.43456 .28129 L
s
.24191 .63534 m
.24736 .63225 L
s
.2409 .22088 m
.2457 .22624 L
s
.57619 .24081 m
.5801 .24607 L
s
.75646 .22368 m
.75982 .22818 L
s
.59125 .24125 m
.59517 .24863 L
s
.31238 .22086 m
.31697 .22636 L
s
.36217 .23389 m
.36618 .24692 L
s
.35788 .22532 m
.36217 .23389 L
s
.24891 .37032 m
.25171 .39604 L
s
.36618 .24692 m
.36981 .26672 L
s
.55717 .23771 m
.561 .23175 L
s
.23998 .53643 m
.24509 .53764 L
s
.71513 .2282 m
.71872 .23422 L
s
.36809 .83288 m
.37158 .85761 L
s
.20764 .37641 m
.20963 .40794 L
s
.22564 .21981 m
.23047 .22518 L
s
.60638 .24483 m
.61027 .25242 L
s
.29715 .21977 m
.3018 .22517 L
s
.22263 .37971 m
.22503 .40822 L
s
.31496 .31143 m
.31731 .34716 L
s
.70005 .22606 m
.70371 .23263 L
s
.26953 .48886 m
.27403 .4961 L
s
.47949 .78112 m
.48311 .8264 L
s
.44544 .27628 m
.44956 .28633 L
s
.68514 .227 m
.68866 .23067 L
s
.47379 .36252 m
.47772 .38136 L
s
.21036 .21875 m
.21524 .22412 L
s
.62153 .24877 m
.6254 .25635 L
s
.28191 .2187 m
.2866 .22408 L
s
.41501 .27742 m
.41936 .28225 L
s
.47298 .49454 m
.47684 .51811 L
s
.25411 .48985 m
.25883 .49493 L
s
.23657 .57661 m
.24186 .5759 L
s
.3008 .9101 m
.30573 .90936 L
s
.37704 .24 m
.38086 .2569 L
s
.37293 .22852 m
.37704 .24 L
s
.14994 .33383 m
.15058 .37265 L
s
.39081 .68486 m
.39467 .70208 L
s
.32584 .30346 m
.32821 .34026 L
s
.37615 .46614 m
.38431 .39698 L
s
.74165 .22503 m
.74507 .2297 L
s
.78302 .22018 m
.78629 .2246 L
s
.35345 .21893 m
.35788 .22532 L
s
.42613 .26597 m
.43037 .27324 L
s
.47484 .41218 m
.47873 .43453 L
s
.26665 .21763 m
.27138 .22301 L
s
.66998 .22388 m
.67369 .23014 L
s
.44131 .2667 m
.44544 .27628 L
s
.33824 .21765 m
.34276 .22336 L
s
.36862 .22066 m
.37293 .22852 L
s
.47511 .59264 m
.47913 .60691 L
s
.58736 .23539 m
.59125 .24125 L
s
.49372 .4502 m
.498 .44136 L
s
.33677 .2951 m
.33924 .3318 L
s
.25138 .21656 m
.25615 .22195 L
s
.32301 .21653 m
.32758 .222 L
s
.4686 .30525 m
.47263 .31855 L
s
.46454 .29328 m
.4686 .30525 L
s
.50375 .39361 m
.50797 .38374 L
s
.23724 .38687 m
.24009 .41171 L
s
.47401 .54583 m
.47794 .56566 L
s
.60248 .23748 m
.60638 .24483 L
s
.17277 .36435 m
.17393 .40093 L
s
.4305 1.01307 m
.43143 .99377 L
s
.47263 .31855 m
.47664 .33351 L
s
.33837 .70315 m
.34161 .72984 L
s
.46045 .28223 m
.46454 .29328 L
s
.72663 .22401 m
.73018 .22981 L
s
.39621 .32594 m
.40116 .31884 L
s
.34775 .28616 m
.35041 .32117 L
s
.76794 .21822 m
.77145 .22485 L
s
.26501 .48168 m
.26953 .48886 L
s
.23609 .21549 m
.2409 .22088 L
s
.30775 .21545 m
.31238 .22086 L
s
.38791 .23342 m
.39188 .24765 L
s
.38373 .22332 m
.38791 .23342 L
s
.57219 .23103 m
.57619 .24081 L
s
.24248 .50595 m
.24739 .50945 L
s
.35877 .27662 m
.36171 .30824 L
s
.19178 .38073 m
.19335 .41521 L
s
.71155 .22246 m
.71513 .2282 L
s
.36981 .26672 m
.37308 .29373 L
s
.63282 .24465 m
.63663 .25118 L
s
.43714 .25772 m
.44131 .2667 L
s
.61764 .24106 m
.62153 .24877 L
s
.69647 .22097 m
.70005 .22606 L
s
.38086 .2569 m
.38443 .27896 L
s
.45636 .27151 m
.46045 .28223 L
s
.75313 .21973 m
.75646 .22368 L
s
.49485 .99542 m
.49775 .93529 L
s
.54612 .25588 m
.55004 .24952 L
s
.40363 .29472 m
.40809 .29789 L
s
.47772 .38136 m
.48165 .40212 L
s
.22078 .21442 m
.22564 .21981 L
s
.29248 .21437 m
.29715 .21977 L
s
.47794 .56566 m
.48206 .57388 L
s
.47664 .33351 m
.48062 .35042 L
s
.39188 .24765 m
.39569 .26538 L
s
.47583 .46552 m
.47973 .48829 L
s
.42196 .25652 m
.42613 .26597 L
s
.25416 .73349 m
.2596 .72964 L
s
.36418 .21451 m
.36862 .22066 L
s
.37939 .21606 m
.38373 .22332 L
s
.45225 .26106 m
.45636 .27151 L
s
.2772 .2133 m
.28191 .2187 L
s
.56823 .22384 m
.57219 .23103 L
s
.2494 .48427 m
.25411 .48985 L
s
.38833 .366 m
.39397 .34541 L
s
.34894 .21329 m
.35345 .21893 L
s
.64412 .23943 m
.64782 .24391 L
s
.26298 .38386 m
.26604 .40761 L
s
.40286 .23933 m
.40683 .25385 L
s
.39878 .22725 m
.40286 .23933 L
s
.41084 .26777 m
.41501 .27742 L
s
.66656 .22363 m
.66998 .22388 L
s
.37158 .85761 m
.37531 .87754 L
s
.48082 .53604 m
.48499 .54097 L
s
.27401 .37414 m
.27687 .4007 L
s
.65537 .23246 m
.65892 .23428 L
s
.23489 .53467 m
.23998 .53643 L
s
.39455 .2183 m
.39878 .22725 L
s
.43299 .24787 m
.43714 .25772 L
s
.68137 .21929 m
.68514 .227 L
s
.2619 .21222 m
.26665 .21763 L
s
.39846 .79756 m
.40368 .7799 L
s
.59857 .23044 m
.60248 .23748 L
s
.33368 .21219 m
.33824 .21765 L
s
.29638 .5346 m
.30041 .54755 L
s
.29228 .52254 m
.29638 .5346 L
s
.58343 .22907 m
.58736 .23539 L
s
.73816 .2196 m
.74165 .22503 L
s
.26049 .47418 m
.26501 .48168 L
s
.30041 .54755 m
.30437 .56157 L
s
.44812 .251 m
.45225 .26106 L
s
.77963 .21471 m
.78302 .22018 L
s
.28811 .51127 m
.29228 .52254 L
s
.40683 .25385 m
.41084 .26777 L
s
.25171 .39604 m
.25495 .41751 L
s
.41788 .24443 m
.42196 .25652 L
s
.61376 .23364 m
.61764 .24106 L
s
.48062 .35042 m
.48458 .36927 L
s
.76461 .21393 m
.76794 .21822 L
s
.24658 .21115 m
.25138 .21656 L
s
.3184 .2111 m
.32301 .21653 L
s
.2849 .36619 m
.28754 .39614 L
s
.47684 .51811 m
.48082 .53604 L
s
.41382 .23201 m
.41788 .24443 L
s
.47873 .43453 m
.48264 .45663 L
s
.30437 .56157 m
.30824 .57687 L
s
.23649 .63752 m
.24191 .63534 L
s
.40967 .22151 m
.41382 .23201 L
s
.72306 .21806 m
.72663 .22401 L
s
.28389 .50063 m
.28811 .51127 L
s
.62896 .23724 m
.63282 .24465 L
s
.39569 .26538 m
.39953 .28286 L
s
.42888 .23665 m
.43299 .24787 L
s
.47545 .29102 m
.47949 .30456 L
s
.47139 .27866 m
.47545 .29102 L
s
.29582 .9112 m
.3008 .9101 L
s
.48373 .50547 m
.48791 .50932 L
s
.23124 .21007 m
.23609 .21549 L
s
.7079 .21592 m
.71155 .22246 L
s
.3031 .21003 m
.30775 .21545 L
s
.46731 .26703 m
.47139 .27866 L
s
.44399 .24073 m
.44812 .251 L
s
.3902 .21151 m
.39455 .2183 L
s
.47949 .30456 m
.48352 .31966 L
s
.37495 .2101 m
.37939 .21606 L
s
.2313 .57661 m
.23657 .57661 L
s
.27963 .49043 m
.28389 .50063 L
s
.69291 .21642 m
.69647 .22097 L
s
.46321 .25582 m
.46731 .26703 L
s
.42476 .22555 m
.42888 .23665 L
s
.30824 .57687 m
.31201 .59375 L
s
.4054 .21344 m
.40967 .22151 L
s
.23757 .5021 m
.24248 .50595 L
s
.56438 .22632 m
.56823 .22384 L
s
.28779 .20895 m
.29248 .21437 L
s
.48165 .40212 m
.48559 .42339 L
s
.35968 .20893 m
.36418 .21451 L
s
.52085 .31717 m
.52494 .3134 L
s
.29571 .35943 m
.29811 .39333 L
s
.67772 .21406 m
.68137 .21929 L
s
.24473 .47813 m
.2494 .48427 L
s
.37531 .87754 m
.37835 .91388 L
s
.22503 .40822 m
.22792 .4325 L
s
.25603 .46599 m
.26049 .47418 L
s
.74971 .21485 m
.75313 .21973 L
s
.45911 .24504 m
.46321 .25582 L
s
.43987 .22996 m
.44399 .24073 L
s
.42058 .21614 m
.42476 .22555 L
s
.38443 .27896 m
.38797 .30231 L
s
.59468 .22447 m
.59857 .23044 L
s
.49665 .42001 m
.50086 .41849 L
s
.27246 .20787 m
.2772 .2133 L
s
.48352 .31966 m
.48752 .3365 L
s
.52792 .2948 m
.53198 .29169 L
s
.34439 .20783 m
.34894 .21329 L
s
.48311 .8264 m
.48735 .8252 L
s
.24009 .41171 m
.24349 .43131 L
s
.39953 .28286 m
.40363 .29472 L
s
.27533 .48051 m
.27963 .49043 L
s
.60986 .22636 m
.61376 .23364 L
s
.51377 .3409 m
.5179 .33814 L
s
.57944 .21978 m
.58343 .22907 L
s
.47973 .48829 m
.48373 .50547 L
s
.34161 .72984 m
.34468 .76054 L
s
.64031 .23296 m
.64412 .23943 L
s
.48458 .36927 m
.48855 .38925 L
s
.25711 .20679 m
.2619 .21222 L
s
.20963 .40794 m
.21193 .43725 L
s
.32909 .20674 m
.33368 .21219 L
s
.45499 .23443 m
.45911 .24504 L
s
.62508 .22972 m
.62896 .23724 L
s
.43572 .21971 m
.43987 .22996 L
s
.73461 .21373 m
.73816 .2196 L
s
.31201 .59375 m
.31566 .61258 L
s
.55326 .24037 m
.55717 .23771 L
s
.77614 .20824 m
.77963 .21471 L
s
.48665 .47406 m
.49081 .47944 L
s
.3065 .3533 m
.30865 .39154 L
s
.40105 .20701 m
.4054 .21344 L
s
.27103 .47052 m
.27533 .48051 L
s
.71947 .21215 m
.72306 .21806 L
s
.24175 .2057 m
.24658 .21115 L
s
.31376 .20566 m
.3184 .2111 L
s
.4163 .20871 m
.42058 .21614 L
s
.70435 .2111 m
.7079 .21592 L
s
.25495 .41751 m
.25863 .43447 L
s
.38577 .20569 m
.3902 .21151 L
s
.25163 .45678 m
.25603 .46599 L
s
.22977 .53278 m
.23489 .53467 L
s
.45086 .22393 m
.45499 .23443 L
s
.26604 .40761 m
.26947 .42759 L
s
.53501 .27408 m
.53903 .27273 L
s
.76127 .20968 m
.76461 .21393 L
s
.48237 .27544 m
.48642 .28911 L
s
.4783 .26279 m
.48237 .27544 L
s
.48752 .3365 m
.49152 .35479 L
s
.47421 .25083 m
.4783 .26279 L
s
.43151 .21106 m
.43572 .21971 L
s
.37308 .29373 m
.37618 .32478 L
s
.57551 .21521 m
.57944 .21978 L
s
.29842 .20458 m
.3031 .21003 L
s
.65167 .22775 m
.65537 .23246 L
s
.48264 .45663 m
.48665 .47406 L
s
.37048 .20455 m
.37495 .2101 L
s
.47012 .23947 m
.47421 .25083 L
s
.48642 .28911 m
.49046 .30411 L
s
.50668 .36503 m
.51084 .36541 L
s
.12401 .32561 m
.11938 .40068 L
s
.24009 .47133 m
.24473 .47813 L
s
.26678 .45994 m
.27103 .47052 L
s
.4467 .21428 m
.45086 .22393 L
s
.663 .22112 m
.66656 .22363 L
s
.28307 .20349 m
.28779 .20895 L
s
.60596 .21962 m
.60986 .22636 L
s
.35516 .20345 m
.35968 .20893 L
s
.466 .22861 m
.47012 .23947 L
s
.24875 .73649 m
.25416 .73349 L
s
.23264 .49827 m
.23757 .5021 L
s
.68911 .20833 m
.69291 .21642 L
s
.67428 .21308 m
.67772 .21406 L
s
.59074 .2174 m
.59468 .22447 L
s
.31731 .34716 m
.31926 .38965 L
s
.27687 .4007 m
.28003 .42441 L
s
.24349 .43131 m
.2474 .44577 L
s
.40782 .86937 m
.41235 .86885 L
s
.2474 .44577 m
.25163 .45678 L
s
.6212 .22239 m
.62508 .22972 L
s
.48559 .42339 m
.4896 .4416 L
s
.49046 .30411 m
.49449 .32051 L
s
.31566 .61258 m
.31918 .63373 L
s
.2677 .20241 m
.27246 .20787 L
s
.25863 .43447 m
.26262 .44819 L
s
.26262 .44819 m
.26678 .45994 L
s
.74621 .20929 m
.74971 .21485 L
s
.33982 .20236 m
.34439 .20783 L
s
.39494 .77039 m
.39846 .79756 L
s
.39003 .77802 m
.39494 .77039 L
s
.63646 .22569 m
.64031 .23296 L
s
.29075 .91297 m
.29582 .9112 L
s
.46187 .21831 m
.466 .22861 L
s
.4896 .4416 m
.49372 .4502 L
s
.42723 .20407 m
.43151 .21106 L
s
.48855 .38925 m
.49256 .40786 L
s
.41195 .20253 m
.4163 .20871 L
s
.39181 .32009 m
.39621 .32594 L
s
.77284 .20407 m
.77614 .20824 L
s
.36171 .30824 m
.36431 .34709 L
s
.25231 .20132 m
.25711 .20679 L
s
.73105 .20782 m
.73461 .21373 L
s
.32447 .20127 m
.32909 .20674 L
s
.44248 .20617 m
.4467 .21428 L
s
.23109 .63892 m
.23649 .63752 L
s
.22601 .57637 m
.2313 .57661 L
s
.39664 .20128 m
.40105 .20701 L
s
.49152 .35479 m
.49554 .37309 L
s
.71584 .20582 m
.71947 .21215 L
s
.32821 .34026 m
.33006 .38601 L
s
.54211 .2549 m
.54612 .25588 L
s
.4996 .38798 m
.50375 .39361 L
s
.48933 .2586 m
.4934 .27219 L
s
.48525 .24594 m
.48933 .2586 L
s
.48116 .23411 m
.48525 .24594 L
s
.22792 .4325 m
.23146 .4506 L
s
.38797 .30231 m
.39181 .32009 L
s
.30911 .20019 m
.31376 .20566 L
s
.45771 .20911 m
.46187 .21831 L
s
.26947 .42759 m
.27319 .44453 L
s
.38131 .20015 m
.38577 .20569 L
s
.19335 .41521 m
.19506 .44917 L
s
.49449 .32051 m
.49853 .33776 L
s
.2356 .46285 m
.24009 .47133 L
s
.40403 .84833 m
.40782 .86937 L
s
.39818 .88247 m
.40403 .84833 L
s
.4934 .27219 m
.49746 .28689 L
s
.47705 .22308 m
.48116 .23411 L
s
.68555 .20437 m
.68911 .20833 L
s
.35041 .32117 m
.35257 .3657 L
s
.70074 .20568 m
.70435 .2111 L
s
.15058 .37265 m
.15069 .41635 L
s
.33924 .3318 m
.34114 .3786 L
s
.17393 .40093 m
.17488 .43999 L
s
.29372 .1991 m
.29842 .20458 L
s
.36597 .19905 m
.37048 .20455 L
s
.60206 .21333 m
.60596 .21962 L
s
.28754 .39614 m
.29036 .42457 L
s
.6173 .21525 m
.6212 .22239 L
s
.58676 .20933 m
.59074 .2174 L
s
.75784 .20457 m
.76127 .20968 L
s
.64787 .22127 m
.65167 .22775 L
s
.37947 .42426 m
.38595 .38892 L
s
.57164 .21479 m
.57551 .21521 L
s
.47292 .21295 m
.47705 .22308 L
s
.49746 .28689 m
.50151 .30261 L
s
.63258 .21832 m
.63646 .22569 L
s
.49256 .40786 m
.49665 .42001 L
s
.27832 .19801 m
.28307 .20349 L
s
.35061 .19796 m
.35516 .20345 L
s
.22455 .53152 m
.22977 .53278 L
s
.56044 .2256 m
.56438 .22632 L
s
.4382 .19949 m
.44248 .20617 L
s
.45349 .2014 m
.45771 .20911 L
s
.42289 .19806 m
.42723 .20407 L
s
.27319 .44453 m
.27709 .45946 L
s
.22769 .49424 m
.23264 .49827 L
s
.74267 .20338 m
.74621 .20929 L
s
.26291 .19692 m
.2677 .20241 L
s
.49554 .37309 m
.4996 .38798 L
s
.31918 .63373 m
.32255 .65761 L
s
.23146 .4506 m
.2356 .46285 L
s
.33523 .19687 m
.33982 .20236 L
s
.51674 .31065 m
.52085 .31717 L
s
.40755 .19686 m
.41195 .20253 L
s
.49853 .33776 m
.50258 .35392 L
s
.46875 .20411 m
.47292 .21295 L
s
.49634 .24102 m
.50042 .25421 L
s
.49225 .22884 m
.49634 .24102 L
s
.52383 .28877 m
.52792 .2948 L
s
.50151 .30261 m
.50558 .3186 L
s
.50966 .3327 m
.51377 .3409 L
s
.72746 .20173 m
.73105 .20782 L
s
.50042 .25421 m
.50449 .26838 L
s
.48814 .21771 m
.49225 .22884 L
s
.65929 .21608 m
.663 .22112 L
s
.34468 .76054 m
.34751 .79664 L
s
.31983 .19578 m
.32447 .20127 L
s
.7123 .20101 m
.71584 .20582 L
s
.3922 .19574 m
.39664 .20128 L
s
.27709 .45946 m
.2811 .47322 L
s
.50258 .35392 m
.50668 .36503 L
s
.21193 .43725 m
.21484 .46124 L
s
.58287 .20576 m
.58676 .20933 L
s
.28003 .42441 m
.28343 .44555 L
s
.76949 .19952 m
.77284 .20407 L
s
.50449 .26838 m
.50857 .28332 L
s
.2811 .47322 m
.28514 .48662 L
s
.54925 .23696 m
.55326 .24037 L
s
.484 .20776 m
.48814 .21771 L
s
.30442 .19468 m
.30911 .20019 L
s
.37682 .19464 m
.38131 .20015 L
s
.53093 .26765 m
.53501 .27408 L
s
.28514 .48662 m
.28915 .5003 L
s
.61341 .20869 m
.6173 .21525 L
s
.6707 .20983 m
.67428 .21308 L
s
.37992 .98575 m
.37835 .91388 L
s
.6287 .21107 m
.63258 .21832 L
s
.59811 .20592 m
.60206 .21333 L
s
.69693 .19736 m
.70074 .20568 L
s
.28915 .5003 m
.29312 .51471 L
s
.50558 .3186 m
.50966 .3327 L
s
.64402 .2141 m
.64787 .22127 L
s
.40977 .98609 m
.41294 .93246 L
s
.29811 .39333 m
.30055 .42765 L
s
.44922 .19495 m
.45349 .2014 L
s
.289 .19359 m
.29372 .1991 L
s
.36143 .19354 m
.36597 .19905 L
s
.46454 .19672 m
.46875 .20411 L
s
.50857 .28332 m
.51265 .29812 L
s
.24335 .73883 m
.24875 .73649 L
s
.28557 .9157 m
.29075 .91297 L
s
.43387 .19359 m
.4382 .19949 L
s
.68208 .20251 m
.68555 .20437 L
s
.29312 .51471 m
.29701 .53019 L
s
.75434 .1989 m
.75784 .20457 L
s
.22061 .57684 m
.22601 .57637 L
s
.47984 .19922 m
.484 .20776 L
s
.50746 .2359 m
.51155 .24929 L
s
.50337 .22356 m
.50746 .2359 L
s
.27355 .19249 m
.27832 .19801 L
s
.34603 .19245 m
.35061 .19796 L
s
.41851 .19242 m
.42289 .19806 L
s
.49926 .21243 m
.50337 .22356 L
s
.51265 .29812 m
.51674 .31065 L
s
.51155 .24929 m
.51564 .26335 L
s
.22567 .64005 m
.23109 .63892 L
s
.73912 .19747 m
.74267 .20338 L
s
.53804 .24758 m
.54211 .2549 L
s
.36081 .77 m
.37459 .59056 L
s
.37618 .32478 m
.3795 .35278 L
s
.33061 .19135 m
.33523 .19687 L
s
.51974 .27718 m
.52383 .28877 L
s
.40313 .19131 m
.40755 .19686 L
s
.51564 .26335 m
.51974 .27718 L
s
.22289 .48841 m
.22769 .49424 L
s
.72386 .19577 m
.72746 .20173 L
s
.49513 .20267 m
.49926 .21243 L
s
.29701 .53019 m
.3008 .5471 L
s
.69345 .19465 m
.69693 .19736 L
s
.31517 .19025 m
.31983 .19578 L
s
.38773 .19021 m
.3922 .19574 L
s
.21919 .53119 m
.22455 .53152 L
s
.59417 .19936 m
.59811 .20592 L
s
.65549 .20955 m
.65929 .21608 L
s
.62482 .20414 m
.6287 .21107 L
s
.52683 .2565 m
.53093 .26765 L
s
.6095 .20196 m
.61341 .20869 L
s
.70864 .19478 m
.7123 .20101 L
s
.32255 .65761 m
.32575 .68476 L
s
.37997 .90445 m
.39003 .77802 L
s
.64015 .20684 m
.64402 .2141 L
s
.47563 .19208 m
.47984 .19922 L
s
.46028 .19042 m
.46454 .19672 L
s
.28343 .44555 m
.28701 .46487 L
s
.38346 .3687 m
.38833 .366 L
s
.56768 .21123 m
.57164 .21479 L
s
.29971 .18915 m
.30442 .19468 L
s
.37231 .18911 m
.37682 .19464 L
s
.51863 .23044 m
.52273 .2435 L
s
.51453 .21819 m
.51863 .23044 L
s
.76605 .19421 m
.76949 .19952 L
s
.52273 .2435 m
.52683 .2565 L
s
.44491 .18913 m
.44922 .19495 L
s
.55642 .22009 m
.56044 .2256 L
s
.49097 .1944 m
.49513 .20267 L
s
.51042 .20719 m
.51453 .21819 L
s
.3008 .5471 m
.30448 .56577 L
s
.57895 .20281 m
.58287 .20576 L
s
.28424 .18805 m
.289 .19359 L
s
.35688 .18801 m
.36143 .19354 L
s
.54518 .22874 m
.54925 .23696 L
s
.42951 .18797 m
.43387 .19359 L
s
.29036 .42457 m
.29337 .45138 L
s
.53395 .23665 m
.53804 .24758 L
s
.30865 .39154 m
.31068 .4328 L
s
.21484 .46124 m
.21852 .47816 L
s
.75081 .19298 m
.75434 .1989 L
s
.50629 .19766 m
.51042 .20719 L
s
.66698 .20442 m
.6707 .20983 L
s
.34143 .1869 m
.34603 .19245 L
s
.4141 .18686 m
.41851 .19242 L
s
.73553 .1913 m
.73912 .19747 L
s
.21852 .47816 m
.22289 .48841 L
s
.52984 .22452 m
.53395 .23665 L
s
.7203 .19064 m
.72386 .19577 L
s
.32596 .1858 m
.33061 .19135 L
s
.39868 .18575 m
.40313 .19131 L
s
.52573 .21269 m
.52984 .22452 L
s
.62092 .1975 m
.62482 .20414 L
s
.63627 .19973 m
.64015 .20684 L
s
.59027 .19537 m
.59417 .19936 L
s
.65164 .20246 m
.65549 .20955 L
s
.48677 .18747 m
.49097 .1944 L
s
.60556 .19482 m
.6095 .20196 L
s
.19506 .44917 m
.19724 .47951 L
s
.47139 .1859 m
.47563 .19208 L
s
.52162 .20196 m
.52573 .21269 L
s
.28701 .46487 m
.29068 .48327 L
s
.67847 .1985 m
.68208 .20251 L
s
.70487 .18711 m
.70864 .19478 L
s
.50214 .18963 m
.50629 .19766 L
s
.31048 .1847 m
.31517 .19025 L
s
.38323 .18465 m
.38773 .19021 L
s
.54108 .2181 m
.54518 .22874 L
s
.45599 .18465 m
.46028 .19042 L
s
.30448 .56577 m
.30803 .58655 L
s
.28026 .91971 m
.28557 .9157 L
s
.21499 .57899 m
.22061 .57684 L
s
.23792 .74089 m
.24335 .73883 L
s
.29498 .18359 m
.29971 .18915 L
s
.36777 .18354 m
.37231 .18911 L
s
.44057 .18351 m
.44491 .18913 L
s
.5175 .19268 m
.52162 .20196 L
s
.55235 .21126 m
.55642 .22009 L
s
.76256 .18844 m
.76605 .19421 L
s
.68995 .19184 m
.69345 .19465 L
s
.22015 .64181 m
.22567 .64005 L
s
.53698 .20702 m
.54108 .2181 L
s
.36431 .34709 m
.36691 .38752 L
s
.3523 .18244 m
.35688 .18801 L
s
.42513 .18239 m
.42951 .18797 L
s
.56364 .20419 m
.56768 .21123 L
s
.74726 .18701 m
.75081 .19298 L
s
.2138 .53077 m
.21919 .53119 L
s
.31926 .38965 m
.3209 .4381 L
s
.73196 .18566 m
.73553 .1913 L
s
.53287 .19671 m
.53698 .20702 L
s
.66318 .19782 m
.66698 .20442 L
s
.3368 .18133 m
.34143 .1869 L
s
.40967 .18128 m
.4141 .18686 L
s
.34751 .79664 m
.35013 .83793 L
s
.49796 .18287 m
.50214 .18963 L
s
.6324 .19292 m
.63627 .19973 L
s
.29068 .48327 m
.29436 .50172 L
s
.64778 .19532 m
.65164 .20246 L
s
.60164 .18918 m
.60556 .19482 L
s
.61701 .19056 m
.62092 .1975 L
s
.17488 .43999 m
.17591 .47922 L
s
.70144 .18475 m
.70487 .18711 L
s
.48255 .18139 m
.48677 .18747 L
s
.57497 .19713 m
.57895 .20281 L
s
.51336 .18489 m
.5175 .19268 L
s
.32575 .68476 m
.32875 .71591 L
s
.3795 .35278 m
.38346 .3687 L
s
.32129 .18022 m
.32596 .1858 L
s
.3942 .18017 m
.39868 .18575 L
s
.54826 .2012 m
.55235 .21126 L
s
.71661 .18378 m
.7203 .19064 L
s
.46712 .18016 m
.47139 .1859 L
s
.52875 .18774 m
.53287 .19671 L
s
.30576 .17911 m
.31048 .1847 L
s
.37871 .17906 m
.38323 .18465 L
s
.45167 .17902 m
.45599 .18465 L
s
.30803 .58655 m
.31143 .60991 L
s
.58632 .19036 m
.59027 .19537 L
s
.30055 .42765 m
.30305 .46211 L
s
.29337 .45138 m
.2965 .47713 L
s
.54415 .19145 m
.54826 .2012 L
s
.67473 .19274 m
.67847 .1985 L
s
.36321 .17795 m
.36777 .18354 L
s
.4362 .17791 m
.44057 .18351 L
s
.55957 .19527 m
.56364 .20419 L
s
.75903 .18252 m
.76256 .18844 L
s
.15069 .41635 m
.15052 .4633 L
s
.29436 .50172 m
.298 .52107 L
s
.33006 .38601 m
.33146 .44011 L
s
.35944 .72251 m
.3724 .56385 L
s
.74368 .18091 m
.74726 .18701 L
s
.34769 .17684 m
.3523 .18244 L
s
.42072 .17679 m
.42513 .18239 L
s
.5092 .17828 m
.51336 .18489 L
s
.35257 .3657 m
.35447 .41652 L
s
.65934 .1908 m
.66318 .19782 L
s
.52462 .18018 m
.52875 .18774 L
s
.64392 .18835 m
.64778 .19532 L
s
.6285 .18611 m
.6324 .19292 L
s
.49375 .17686 m
.49796 .18287 L
s
.61309 .18402 m
.61701 .19056 L
s
.72838 .18001 m
.73196 .18566 L
s
.33215 .17573 m
.3368 .18133 L
s
.40522 .17568 m
.40967 .18128 L
s
.54005 .18282 m
.54415 .19145 L
s
.47829 .17565 m
.48255 .18139 L
s
.71296 .17781 m
.71661 .18378 L
s
.59772 .18407 m
.60164 .18918 L
s
.57092 .18931 m
.57497 .19713 L
s
.6863 .18713 m
.68995 .19184 L
s
.34114 .3786 m
.34261 .43416 L
s
.55548 .18617 m
.55957 .19527 L
s
.3166 .17461 m
.32129 .18022 L
s
.3897 .17456 m
.3942 .18017 L
s
.46282 .17452 m
.46712 .18016 L
s
.23241 .74326 m
.23792 .74089 L
s
.20912 .58317 m
.21499 .57899 L
s
.27477 .92531 m
.28026 .91971 L
s
.37417 .17345 m
.37871 .17906 L
s
.44732 .1734 m
.45167 .17902 L
s
.20863 .52784 m
.2138 .53077 L
s
.2144 .64532 m
.22015 .64181 L
s
.19724 .47951 m
.20018 .50344 L
s
.298 .52107 m
.30154 .54206 L
s
.69789 .18101 m
.70144 .18475 L
s
.67093 .18608 m
.67473 .19274 L
s
.58231 .18343 m
.58632 .19036 L
s
.52048 .17369 m
.52462 .18018 L
s
.53594 .17548 m
.54005 .18282 L
s
.75548 .17648 m
.75903 .18252 L
s
.35862 .17233 m
.36321 .17795 L
s
.43181 .17228 m
.4362 .17791 L
s
.65549 .18377 m
.65934 .1908 L
s
.31143 .60991 m
.31465 .63638 L
s
.48542 .98784 m
.48475 .96877 L
s
.64004 .18152 m
.64392 .18835 L
s
.50501 .17232 m
.5092 .17828 L
s
.55139 .17792 m
.55548 .18617 L
s
.62459 .17933 m
.6285 .18611 L
s
.74013 .17536 m
.74368 .18091 L
s
.60917 .17835 m
.61309 .18402 L
s
.56686 .18089 m
.57092 .18931 L
s
.34306 .17121 m
.34769 .17684 L
s
.41629 .17116 m
.42072 .17679 L
s
.39263 .96141 m
.39818 .88247 L
s
.48952 .17113 m
.49375 .17686 L
s
.72466 .17281 m
.72838 .18001 L
s
.32747 .17009 m
.33215 .17573 L
s
.40074 .17004 m
.40522 .17568 L
s
.70948 .17458 m
.71296 .17781 L
s
.47401 .17 m
.47829 .17565 L
s
.59375 .17771 m
.59772 .18407 L
s
.2965 .47713 m
.29969 .50276 L
s
.38518 .16892 m
.3897 .17456 L
s
.45849 .16888 m
.46282 .17452 L
s
.68256 .18105 m
.6863 .18713 L
s
.32875 .71591 m
.33152 .7518 L
s
.5473 .17079 m
.55139 .17792 L
s
.53181 .1691 m
.53594 .17548 L
s
.57827 .17565 m
.58231 .18343 L
s
.56278 .17303 m
.56686 .18089 L
s
.3696 .1678 m
.37417 .17345 L
s
.44296 .16775 m
.44732 .1734 L
s
.6671 .17912 m
.67093 .18608 L
s
.31068 .4328 m
.31259 .4769 L
s
.65163 .17687 m
.65549 .18377 L
s
.51631 .16777 m
.52048 .17369 L
s
.63615 .1747 m
.64004 .18152 L
s
.30154 .54206 m
.30494 .56533 L
s
.75193 .17054 m
.75548 .17648 L
s
.62068 .17312 m
.62459 .17933 L
s
.35401 .16668 m
.35862 .17233 L
s
.4274 .16663 m
.43181 .17228 L
s
.50079 .16659 m
.50501 .17232 L
s
.20401 .51944 m
.20863 .52784 L
s
.73652 .16917 m
.74013 .17536 L
s
.72112 .16821 m
.72466 .17281 L
s
.60523 .17221 m
.60917 .17835 L
s
.69422 .17569 m
.69789 .18101 L
s
.3384 .16555 m
.34306 .17121 L
s
.41183 .1655 m
.41629 .17116 L
s
.48526 .16546 m
.48952 .17113 L
s
.20018 .50344 m
.20401 .51944 L
s
.36662 .91721 m
.37898 .74254 L
s
.22676 .74671 m
.23241 .74326 L
s
.39624 .16438 m
.40074 .17004 L
s
.46971 .16433 m
.47401 .17 L
s
.3741 .43507 m
.37947 .42426 L
s
.58973 .17047 m
.59375 .17771 L
s
.55871 .1661 m
.56278 .17303 L
s
.57422 .16816 m
.57827 .17565 L
s
.54319 .1645 m
.5473 .17079 L
s
.67876 .17433 m
.68256 .18105 L
s
.35013 .83793 m
.35265 .88286 L
s
.30305 .46211 m
.30558 .49725 L
s
.38063 .16325 m
.38518 .16892 L
s
.45415 .1632 m
.45849 .16888 L
s
.66326 .17218 m
.6671 .17912 L
s
.31465 .63638 m
.31767 .66663 L
s
.52766 .1632 m
.53181 .1691 L
s
.64775 .17004 m
.65163 .17687 L
s
.36691 .38752 m
.37 .42036 L
s
.70589 .16999 m
.70948 .17458 L
s
.63225 .16819 m
.63615 .1747 L
s
.26909 .93286 m
.27477 .92531 L
s
.17591 .47922 m
.17734 .51592 L
s
.20831 .65159 m
.2144 .64532 L
s
.20306 .58847 m
.20912 .58317 L
s
.36501 .16212 m
.3696 .1678 L
s
.43856 .16207 m
.44296 .16775 L
s
.51212 .16203 m
.51631 .16777 L
s
.61676 .16695 m
.62068 .17312 L
s
.74837 .1648 m
.75193 .17054 L
s
.34937 .16099 m
.35401 .16668 L
s
.42296 .16095 m
.4274 .16663 L
s
.49656 .1609 m
.50079 .16659 L
s
.73285 .16248 m
.73652 .16917 L
s
.60124 .16536 m
.60523 .17221 L
s
.36889 .51298 m
.37615 .46614 L
s
.29969 .50276 m
.30284 .52947 L
s
.30494 .56533 m
.30816 .59161 L
s
.40735 .15981 m
.41183 .1655 L
s
.5857 .16331 m
.58973 .17047 L
s
.48098 .15977 m
.48526 .16546 L
s
.69046 .16936 m
.69422 .17569 L
s
.57016 .16141 m
.57422 .16816 L
s
.7176 .1641 m
.72112 .16821 L
s
.11938 .40068 m
.11485 .47693 L
s
.55462 .15989 m
.55871 .1661 L
s
.67494 .16744 m
.67876 .17433 L
s
.39171 .15868 m
.39624 .16438 L
s
.46539 .15863 m
.46971 .16433 L
s
.53906 .15863 m
.54319 .1645 L
s
.6594 .16533 m
.66326 .17218 L
s
.64387 .16338 m
.64775 .17004 L
s
.37606 .15755 m
.38063 .16325 L
s
.44977 .1575 m
.45415 .1632 L
s
.62834 .16188 m
.63225 .16819 L
s
.52349 .15746 m
.52766 .1632 L
s
.6128 .16034 m
.61676 .16695 L
s
.36039 .15641 m
.36501 .16212 L
s
.3209 .4381 m
.32226 .49252 L
s
.43415 .15637 m
.43856 .16207 L
s
.5079 .15632 m
.51212 .16203 L
s
.7022 .16417 m
.70589 .16999 L
s
.74474 .15828 m
.74837 .1648 L
s
.72934 .15821 m
.73285 .16248 L
s
.59724 .15848 m
.60124 .16536 L
s
.58167 .15672 m
.5857 .16331 L
s
.4185 .15523 m
.42296 .16095 L
s
.4923 .15518 m
.49656 .1609 L
s
.5661 .15527 m
.57016 .16141 L
s
.36348 .59418 m
.37269 .51083 L
s
.68667 .16261 m
.69046 .16936 L
s
.40284 .15409 m
.40735 .15981 L
s
.47667 .15404 m
.48098 .15977 L
s
.67111 .16059 m
.67494 .16744 L
s
.22086 .75213 m
.22676 .74671 L
s
.55051 .15402 m
.55462 .15989 L
s
.33152 .7518 m
.33404 .79331 L
s
.65554 .15862 m
.6594 .16533 L
s
.15052 .4633 m
.15031 .5116 L
s
.63998 .15695 m
.64387 .16338 L
s
.38716 .15295 m
.39171 .15868 L
s
.46104 .15291 m
.46539 .15863 L
s
.53491 .15286 m
.53906 .15863 L
s
.35835 .89828 m
.37283 .69888 L
s
.71397 .1588 m
.7176 .1641 L
s
.62441 .15539 m
.62834 .16188 L
s
.37146 .15181 m
.37606 .15755 L
s
.44538 .15177 m
.44977 .1575 L
s
.5193 .15172 m
.52349 .15746 L
s
.31767 .66663 m
.32045 .7015 L
s
.60882 .15367 m
.6128 .16034 L
s
.30816 .59161 m
.31117 .62168 L
s
.30284 .52947 m
.30587 .55851 L
s
.59323 .15203 m
.59724 .15848 L
s
.74115 .15259 m
.74474 .15828 L
s
.42971 .15063 m
.43415 .15637 L
s
.50366 .15058 m
.5079 .15632 L
s
.69844 .15767 m
.7022 .16417 L
s
.57763 .15064 m
.58167 .15672 L
s
.26317 .94273 m
.26909 .93286 L
s
.19705 .59271 m
.20306 .58847 L
s
.20183 .66109 m
.20831 .65159 L
s
.68286 .1558 m
.68667 .16261 L
s
.41402 .14948 m
.4185 .15523 L
s
.35447 .41652 m
.35651 .46723 L
s
.48801 .14943 m
.4923 .15518 L
s
.56201 .14941 m
.5661 .15527 L
s
.66726 .15385 m
.67111 .16059 L
s
.72577 .1533 m
.72934 .15821 L
s
.65167 .15211 m
.65554 .15862 L
s
.37 .42036 m
.3741 .43507 L
s
.39831 .14834 m
.40284 .15409 L
s
.47235 .14829 m
.47667 .15404 L
s
.54639 .14824 m
.55051 .15402 L
s
.63607 .15051 m
.63998 .15695 L
s
.30558 .49725 m
.30805 .53427 L
s
.33146 .44011 m
.33251 .50202 L
s
.38258 .14719 m
.38716 .15295 L
s
.45666 .14715 m
.46104 .15291 L
s
.53074 .1471 m
.53491 .15286 L
s
.62046 .14888 m
.62441 .15539 L
s
.60484 .14734 m
.60882 .15367 L
s
.71026 .15263 m
.71397 .1588 L
s
.44096 .146 m
.44538 .15177 L
s
.51508 .14595 m
.5193 .15172 L
s
.17734 .51592 m
.17944 .54737 L
s
.58921 .14599 m
.59323 .15203 L
s
.31259 .4769 m
.31437 .52464 L
s
.69466 .15096 m
.69844 .15767 L
s
.73762 .14779 m
.74115 .15259 L
s
.42524 .14485 m
.42971 .15063 L
s
.4994 .1448 m
.50366 .15058 L
s
.57357 .14477 m
.57763 .15064 L
s
.67903 .14907 m
.68286 .1558 L
s
.34261 .43416 m
.34386 .49575 L
s
.66341 .1473 m
.66726 .15385 L
s
.40951 .1437 m
.41402 .14948 L
s
.48371 .14366 m
.48801 .14943 L
s
.35265 .88286 m
.35502 .93255 L
s
.55791 .14361 m
.56201 .14941 L
s
.64778 .14568 m
.65167 .15211 L
s
.63214 .14411 m
.63607 .15051 L
s
.39375 .14255 m
.39831 .14834 L
s
.46799 .14251 m
.47235 .14829 L
s
.54224 .14246 m
.54639 .14824 L
s
.72211 .14747 m
.72577 .1533 L
s
.21464 .7604 m
.22086 .75213 L
s
.61649 .14264 m
.62046 .14888 L
s
.45226 .14136 m
.45666 .14715 L
s
.52655 .14131 m
.53074 .1471 L
s
.60084 .14132 m
.60484 .14734 L
s
.7065 .14606 m
.71026 .15263 L
s
.43652 .1402 m
.44096 .146 L
s
.51084 .14015 m
.51508 .14595 L
s
.69086 .14426 m
.69466 .15096 L
s
.58517 .14012 m
.58921 .14599 L
s
.30587 .55851 m
.30869 .59118 L
s
.31117 .62168 m
.31392 .65647 L
s
.6752 .1425 m
.67903 .14907 L
s
.42075 .13905 m
.42524 .14485 L
s
.49512 .139 m
.4994 .1448 L
s
.56949 .13896 m
.57357 .14477 L
s
.65954 .14088 m
.66341 .1473 L
s
.73401 .14225 m
.73762 .14779 L
s
.64388 .13935 m
.64778 .14568 L
s
.19142 .59294 m
.19705 .59271 L
s
.40497 .13789 m
.40951 .1437 L
s
.47938 .13785 m
.48371 .14366 L
s
.55379 .1378 m
.55791 .14361 L
s
.62821 .13793 m
.63214 .14411 L
s
.32045 .7015 m
.32295 .74194 L
s
.46362 .13669 m
.46799 .14251 L
s
.53807 .13664 m
.54224 .14246 L
s
.7184 .14111 m
.72211 .14747 L
s
.61252 .13664 m
.61649 .14264 L
s
.25698 .95527 m
.26317 .94273 L
s
.70273 .13943 m
.7065 .14606 L
s
.33404 .79331 m
.33626 .84144 L
s
.44784 .13553 m
.45226 .14136 L
s
.52233 .13548 m
.52655 .14131 L
s
.59683 .13544 m
.60084 .14132 L
s
.68705 .1377 m
.69086 .14426 L
s
.19498 .67344 m
.20183 .66109 L
s
.43205 .13437 m
.43652 .1402 L
s
.67136 .13609 m
.6752 .1425 L
s
.50658 .13432 m
.51084 .14015 L
s
.58111 .13428 m
.58517 .14012 L
s
.65567 .13459 m
.65954 .14088 L
s
.41624 .13321 m
.42075 .13905 L
s
.17944 .54737 m
.18246 .57127 L
s
.49081 .13316 m
.49512 .139 L
s
.56538 .13312 m
.56949 .13896 L
s
.63997 .13321 m
.64388 .13935 L
s
.73034 .1361 m
.73401 .14225 L
s
.47502 .132 m
.47938 .13785 L
s
.54964 .13196 m
.55379 .1378 L
s
.62426 .13194 m
.62821 .13793 L
s
.71465 .13456 m
.7184 .14111 L
s
.30805 .53427 m
.31034 .57489 L
s
.45922 .13084 m
.46362 .13669 L
s
.53387 .13079 m
.53807 .13664 L
s
.60853 .13075 m
.61252 .13664 L
s
.69895 .13289 m
.70273 .13943 L
s
.68323 .1313 m
.68705 .1377 L
s
.44339 .12968 m
.44784 .13553 L
s
.51809 .12963 m
.52233 .13548 L
s
.59279 .12958 m
.59683 .13544 L
s
.18647 .58638 m
.19142 .59294 L
s
.66751 .12983 m
.67136 .13609 L
s
.15031 .5116 m
.15033 .55913 L
s
.35665 .70155 m
.36769 .58542 L
s
.42755 .12851 m
.43205 .13437 L
s
.50229 .12846 m
.50658 .13432 L
s
.57703 .12841 m
.58111 .13428 L
s
.20799 .7723 m
.21464 .7604 L
s
.65178 .12848 m
.65567 .13459 L
s
.48648 .1273 m
.49081 .13316 L
s
.56126 .12725 m
.56538 .13312 L
s
.32226 .49252 m
.32331 .55374 L
s
.63604 .12723 m
.63997 .13321 L
s
.72663 .12967 m
.73034 .1361 L
s
.30869 .59118 m
.31124 .62892 L
s
.47064 .12613 m
.47502 .132 L
s
.54546 .12608 m
.54964 .13196 L
s
.62029 .12603 m
.62426 .13194 L
s
.7109 .12806 m
.71465 .13456 L
s
.18246 .57127 m
.18647 .58638 L
s
.31392 .65647 m
.31635 .69719 L
s
.69515 .1265 m
.69895 .13289 L
s
.45479 .12496 m
.45922 .13084 L
s
.52965 .12491 m
.53387 .13079 L
s
.60452 .12486 m
.60853 .13075 L
s
.67941 .12506 m
.68323 .1313 L
s
.43892 .12379 m
.44339 .12968 L
s
.51383 .12374 m
.51809 .12963 L
s
.58874 .12369 m
.59279 .12958 L
s
.66365 .12373 m
.66751 .12983 L
s
.49798 .12257 m
.50229 .12846 L
s
.35651 .46723 m
.35922 .50795 L
s
.57293 .12252 m
.57703 .12841 L
s
.64788 .12249 m
.65178 .12848 L
s
.48212 .12139 m
.48648 .1273 L
s
.55711 .12134 m
.56126 .12725 L
s
.7229 .12322 m
.72663 .12967 L
s
.31437 .52464 m
.31589 .57769 L
s
.6321 .1213 m
.63604 .12723 L
s
.35577 .95616 m
.35502 .93255 L
s
.70713 .1217 m
.7109 .12806 L
s
.46624 .12022 m
.47064 .12613 L
s
.54127 .12017 m
.54546 .12608 L
s
.25518 .95956 m
.25698 .95527 L
s
.6163 .12012 m
.62029 .12603 L
s
.69136 .12028 m
.69515 .1265 L
s
.32295 .74194 m
.32513 .78906 L
s
.45034 .11904 m
.45479 .12496 L
s
.52541 .11899 m
.52965 .12491 L
s
.60049 .11895 m
.60452 .12486 L
s
.67557 .11897 m
.67941 .12506 L
s
.36321 .5265 m
.36889 .51298 L
s
.50954 .11782 m
.51383 .12374 L
s
.58466 .11777 m
.58874 .12369 L
s
.65978 .11774 m
.66365 .12373 L
s
.18787 .68732 m
.19498 .67344 L
s
.49365 .11664 m
.49798 .12257 L
s
.56881 .11659 m
.57293 .12252 L
s
.64397 .11654 m
.64788 .12249 L
s
.71916 .11688 m
.7229 .12322 L
s
.47774 .11546 m
.48212 .12139 L
s
.55294 .11541 m
.55711 .12134 L
s
.62814 .11536 m
.6321 .1213 L
s
.70336 .11548 m
.70713 .1217 L
s
.46181 .11428 m
.46624 .12022 L
s
.53705 .11423 m
.54127 .12017 L
s
.6123 .11418 m
.6163 .12012 L
s
.11485 .47693 m
.11057 .55317 L
s
.68755 .11419 m
.69136 .12028 L
s
.33626 .84144 m
.33819 .89691 L
s
.52115 .11305 m
.52541 .11899 L
s
.59643 .113 m
.60049 .11895 L
s
.33251 .50202 m
.33329 .57091 L
s
.67172 .11296 m
.67557 .11897 L
s
.31034 .57489 m
.31234 .62119 L
s
.50523 .11186 m
.50954 .11782 L
s
.58055 .11181 m
.58466 .11777 L
s
.20085 .78831 m
.20799 .7723 L
s
.65588 .11177 m
.65978 .11774 L
s
.48929 .11068 m
.49365 .11664 L
s
.56466 .11063 m
.56881 .11659 L
s
.64003 .11058 m
.64397 .11654 L
s
.71541 .11067 m
.71916 .11688 L
s
.34386 .49575 m
.34523 .55814 L
s
.31124 .62892 m
.31341 .6735 L
s
.47333 .10949 m
.47774 .11546 L
s
.54874 .10944 m
.55294 .11541 L
s
.62415 .10939 m
.62814 .11536 L
s
.69957 .10939 m
.70336 .11548 L
s
.53281 .10825 m
.53705 .11423 L
s
.60826 .10821 m
.6123 .11418 L
s
.68372 .10816 m
.68755 .11419 L
s
.51686 .10707 m
.52115 .11305 L
s
.59236 .10702 m
.59643 .113 L
s
.66785 .10697 m
.67172 .11296 L
s
.31635 .69719 m
.31839 .74539 L
s
.50089 .10588 m
.50523 .11186 L
s
.57643 .10583 m
.58055 .11181 L
s
.65197 .10578 m
.65588 .11177 L
s
.15033 .55913 m
.15086 .6036 L
s
.48491 .10468 m
.48929 .11068 L
s
.56048 .10463 m
.56466 .11063 L
s
.63607 .10458 m
.64003 .11058 L
s
.71166 .10457 m
.71541 .11067 L
s
.54452 .10344 m
.54874 .10944 L
s
.62015 .10339 m
.62415 .10939 L
s
.69578 .10335 m
.69957 .10939 L
s
.35922 .50795 m
.36321 .5265 L
s
.52854 .10225 m
.53281 .10825 L
s
.60421 .1022 m
.60826 .10821 L
s
.67988 .10215 m
.68372 .10816 L
s
.37776 .93806 m
.37997 .90445 L
s
.51255 .10105 m
.51686 .10707 L
s
.58825 .101 m
.59236 .10702 L
s
.66397 .10095 m
.66785 .10697 L
s
.49653 .09985 m
.50089 .10588 L
s
.57228 .0998 m
.57643 .10583 L
s
.64803 .09975 m
.65197 .10578 L
s
.18073 .70059 m
.18787 .68732 L
s
.55629 .09861 m
.56048 .10463 L
s
.63208 .09856 m
.63607 .10458 L
s
.70788 .09851 m
.71166 .10457 L
s
.54028 .09741 m
.54452 .10344 L
s
.61612 .09736 m
.62015 .10339 L
s
.69196 .09731 m
.69578 .10335 L
s
.32513 .78906 m
.32692 .84433 L
s
.52425 .0962 m
.52854 .10225 L
s
.60013 .09615 m
.60421 .1022 L
s
.67602 .0961 m
.67988 .10215 L
s
.50821 .095 m
.51255 .10105 L
s
.58413 .09495 m
.58825 .101 L
s
.66005 .0949 m
.66397 .10095 L
s
.56811 .09375 m
.57228 .0998 L
s
.64408 .0937 m
.64803 .09975 L
s
.31589 .57769 m
.31705 .63833 L
s
.32331 .55374 m
.324 .62295 L
s
.19319 .80857 m
.20085 .78831 L
s
.55207 .09254 m
.55629 .09861 L
s
.62808 .09249 m
.63208 .09856 L
s
.70409 .09244 m
.70788 .09851 L
s
.53601 .09134 m
.54028 .09741 L
s
.61207 .09129 m
.61612 .09736 L
s
.68812 .09124 m
.69196 .09731 L
s
.51994 .09013 m
.52425 .0962 L
s
.59603 .09008 m
.60013 .09615 L
s
.67213 .09003 m
.67602 .0961 L
s
.31234 .62119 m
.31391 .67565 L
s
.57998 .08887 m
.58413 .09495 L
s
.65612 .08882 m
.66005 .0949 L
s
.31341 .6735 m
.31509 .72709 L
s
.56391 .08766 m
.56811 .09375 L
s
.6401 .08761 m
.64408 .0937 L
s
.35593 .64093 m
.36348 .59418 L
s
.33906 .93177 m
.33819 .89691 L
s
.54783 .08645 m
.55207 .09254 L
s
.62405 .0864 m
.62808 .09249 L
s
.70028 .08634 m
.70409 .09244 L
s
.53172 .08523 m
.53601 .09134 L
s
.60799 .08518 m
.61207 .09129 L
s
.68426 .08513 m
.68812 .09124 L
s
.59191 .08397 m
.59603 .09008 L
s
.66822 .08392 m
.67213 .09003 L
s
.31839 .74539 m
.31994 .80316 L
s
.15086 .6036 m
.15212 .64276 L
s
.57581 .08275 m
.57998 .08887 L
s
.65217 .0827 m
.65612 .08882 L
s
.5597 .08153 m
.56391 .08766 L
s
.63609 .08148 m
.6401 .08761 L
s
.17385 .7106 m
.18073 .70059 L
s
.54356 .08032 m
.54783 .08645 L
s
.62 .08026 m
.62405 .0864 L
s
.69644 .08021 m
.70028 .08634 L
s
.60389 .07904 m
.60799 .08518 L
s
.68038 .07899 m
.68426 .08513 L
s
.58776 .07782 m
.59191 .08397 L
s
.66429 .07777 m
.66822 .08392 L
s
.57162 .0766 m
.57581 .08275 L
s
.64819 .07655 m
.65217 .0827 L
s
.55545 .07537 m
.5597 .08153 L
s
.63207 .07532 m
.63609 .08148 L
s
.34523 .55814 m
.34724 .61216 L
s
.61593 .0741 m
.62 .08026 L
s
.69259 .07405 m
.69644 .08021 L
s
.33329 .57091 m
.33398 .64421 L
s
.59977 .07287 m
.60389 .07904 L
s
.67647 .07282 m
.68038 .07899 L
s
.58359 .07164 m
.58776 .07782 L
s
.66034 .07159 m
.66429 .07777 L
s
.18501 .8328 m
.19319 .80857 L
s
.5674 .07041 m
.57162 .0766 L
s
.64419 .07036 m
.64819 .07655 L
s
.32692 .84433 m
.32826 .90969 L
s
.11057 .55317 m
.10672 .62808 L
s
.62802 .06913 m
.63207 .07532 L
s
.61183 .0679 m
.61593 .0741 L
s
.68871 .06784 m
.69259 .07405 L
s
.59562 .06666 m
.59977 .07287 L
s
.67255 .06661 m
.67647 .07282 L
s
.5794 .06543 m
.58359 .07164 L
s
.65636 .06537 m
.66034 .07159 L
s
.16754 .71474 m
.17385 .7106 L
s
.15212 .64276 m
.15434 .67458 L
s
.64016 .06414 m
.64419 .07036 L
s
.35208 .88059 m
.36081 .77 L
s
.62395 .0629 m
.62802 .06913 L
s
.60771 .06166 m
.61183 .0679 L
s
.68481 .06161 m
.68871 .06784 L
s
.31509 .72709 m
.31616 .79246 L
s
.31391 .67565 m
.3149 .74107 L
s
.34689 .86345 m
.35944 .72251 L
s
.31705 .63833 m
.31771 .70909 L
s
.59145 .06042 m
.59562 .06666 L
s
.6686 .06037 m
.67255 .06661 L
s
.65237 .05912 m
.65636 .06537 L
s
.63612 .05788 m
.64016 .06414 L
s
.61985 .05663 m
.62395 .0629 L
s
.60357 .05539 m
.60771 .06166 L
s
.68089 .05533 m
.68481 .06161 L
s
.324 .62295 m
.32435 .70075 L
s
.31994 .80316 m
.32089 .87327 L
s
.66463 .05408 m
.6686 .06037 L
s
.16207 .71081 m
.16754 .71474 L
s
.64835 .05283 m
.65237 .05912 L
s
.15434 .67458 m
.15765 .69752 L
s
.63205 .05158 m
.63612 .05788 L
s
.61573 .05033 m
.61985 .05663 L
s
.67694 .04902 m
.68089 .05533 L
s
.66063 .04777 m
.66463 .05408 L
s
.15765 .69752 m
.16207 .71081 L
s
.6443 .04651 m
.64835 .05283 L
s
.34724 .61216 m
.35058 .64447 L
s
.17636 .86027 m
.18501 .8328 L
s
.35058 .64447 m
.35593 .64093 L
s
.62796 .04525 m
.63205 .05158 L
s
.67297 .04268 m
.67694 .04902 L
s
.65661 .04142 m
.66063 .04777 L
s
.64024 .04015 m
.6443 .04651 L
s
.34741 .77706 m
.35665 .70155 L
s
.32828 .91153 m
.32826 .90969 L
s
.66898 .0363 m
.67297 .04268 L
s
.65257 .03503 m
.65661 .04142 L
s
.33398 .64421 m
.33498 .71558 L
s
.66497 .02988 m
.66898 .0363 L
s
.31616 .79246 m
.31646 .87293 L
s
.3149 .74107 m
.31518 .82042 L
s
.10672 .62808 m
.10348 .70022 L
s
.31771 .70909 m
.3178 .79191 L
s
.1685 .88604 m
.17636 .86027 L
s
.32093 .8936 m
.32089 .87327 L
s
.32435 .70075 m
.32449 .7853 L
s
.33498 .71558 m
.33698 .77292 L
s
.10348 .70022 m
.10103 .76806 L
s
.31643 .87759 m
.31646 .87293 L
s
.31495 .8637 m
.31518 .82042 L
s
.34087 .79896 m
.34741 .77706 L
s
.31753 .8528 m
.3178 .79191 L
s
.33698 .77292 m
.34087 .79896 L
s
.32475 .84547 m
.32449 .7853 L
s
.10103 .76806 m
.09953 .83008 L
s
.09948 .83614 m
.09953 .83008 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.10087 .24033 m
.10595 .24556 L
s
[(0)] .09072 .22988 .97192 1 Mshowa
.23115 .18555 m
.23598 .19102 L
s
[(1)] .22151 .17463 .88293 1 Mshowa
.36874 .1277 m
.37327 .13341 L
s
[(2)] .35968 .11629 .79394 1 Mshowa
.51427 .06651 m
.51847 .07247 L
s
[(3)] .50588 .0546 .70494 1 Mshowa
.66846 .00168 m
.67228 .00789 L
s
[(4)] .66081 -0.01073 .61595 1 Mshowa
.125 Mabswid
.12637 .22961 m
.12939 .23277 L
s
.15215 .21877 m
.15514 .22196 L
s
.1782 .20782 m
.18116 .21104 L
s
.20453 .19675 m
.20746 .19999 L
s
.25807 .17424 m
.26093 .17754 L
s
.28528 .16279 m
.28811 .16613 L
s
.31279 .15123 m
.31558 .15459 L
s
.34061 .13953 m
.34337 .14292 L
s
.39719 .11574 m
.39987 .11919 L
s
.42596 .10364 m
.42861 .10713 L
s
.45507 .09141 m
.45767 .09492 L
s
.4845 .07903 m
.48706 .08257 L
s
.54439 .05385 m
.54687 .05745 L
s
.57487 .04103 m
.5773 .04467 L
s
.6057 .02807 m
.60808 .03173 L
s
.63689 .01495 m
.63923 .01865 L
s
gsave
.30907 .06148 -69.9859 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.01178 .81203 m
.01289 .80482 L
s
[(0)] .00955 .82643 .15454 -1 Mshowa
.1225 .88995 m
.12336 .88271 L
s
[(10)] .12079 .90442 .11851 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(20)] .22056 .97437 .08756 -1 Mshowa
.31143 1.0229 m
.31187 1.01563 L
s
[(30)] .31055 1.03745 .0607 -1 Mshowa
.39267 1.08007 m
.39294 1.07279 L
s
[(40)] .39213 1.09464 .03715 -1 Mshowa
.125 Mabswid
.03493 .82832 m
.03556 .82399 L
s
.05756 .84424 m
.05816 .83991 L
s
.07969 .85982 m
.08026 .85548 L
s
.10133 .87505 m
.10187 .87071 L
s
.14322 .90453 m
.14371 .90018 L
s
.1635 .9188 m
.16396 .91445 L
s
.18335 .93277 m
.18378 .92842 L
s
.20279 .94645 m
.2032 .9421 L
s
.24048 .97297 m
.24084 .96861 L
s
.25875 .98583 m
.25909 .98147 L
s
.27666 .99844 m
.27697 .99407 L
s
.29422 1.01079 m
.29451 1.00643 L
s
.32831 1.03478 m
.32855 1.03041 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.3611 1.05786 m
.3613 1.05349 L
s
.37703 1.06907 m
.37721 1.0647 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{265.312, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005;0001Ib000`400?l00000o`00003ooooooom<
ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<
ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<ooooo`00oooooom<
ooooo`00oooooom<ooooo`00oooooom<ooooo`00kOooool2o`000003oa0@4?oooooooooo05Wooooo
003^ooooo`03o`000?oooooooooo05[ooooo003[ooooo`Go0000Foooool00>_ooooo00CoA4A4omgM
gOoooooo0000G?ooool00>_ooooo00CogMgMoeEEEOoooooo0000G?ooool00>cooooo00?oMgMgolc<
c?l00000G?ooool00>cooooo00?ok^k^odA4A?l00000G?ooool00>gooooo00?oMgMgo`000?ooool0
Foooool00?ooooooC?ooool00?ooooooC?ooool00?ooooooC?ooool00?ooooooC?ooool00?;ooooo
0_l0001Gooooo`00koooool5o`0005Oooooo003]ooooo`;o00001?ooool2o`0005Kooooo003[oooo
o`;o00001_ooool00ol0003oooooo`00001Eooooo`00j?ooool3o`0000Sooooo00?o0000ooooool0
0000EOooool00>Kooooo0_l00002ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo
0000E?ooool008_ooooo0_l00002ooooo`03oa0@4?l0003o000002oooooo00GoV9RHoa0@4?l0003o
<S8bolc<c00Mooooo`?o00003Oooool01?l0003oooooooooool0001Dooooo`00S?ooool01Ol0003o
ooooonk^k_lb<S;oc<c<033ooooo00Go410@okZj^_ooooooMgMgoc8b<P0Kooooo`;o00004?ooool0
1Ol0003ooooooooooooooooo000005?ooooo002<ooooo`04o`000?nHV9So<S8bolc<c3Gooooo00?o
0000ooooooooool05oooool2o`000003ooooool0003ooooo00gooooo00?o0000ooooool000001?oo
ool00ol0003oooooooooo`1@ooooo`00S?ooool00ol0003o410@oiRHV00eooooo`03ojVYZOl@413o
oooo01Gooooo0ol00003ooooo`03o`000?oooooooooo00cooooo00?o0000ooooool000001?ooool0
0ol0003oooooooooo`1@ooooo`00S?ooool01?l0003ok^k^oeEEEOn7QhLcooooo`03oa0@4?l0003o
^[Zj01Cooooo0_l0000Booooo`07o`000?ooooooooooooooool0003oooooo`000004ooooo`03o`00
0?oooooooooo04oooooo002<ooooo`05o`000?ooooooA4A4o`000?l@4100<oooool00onj^[[o8B4Q
ooooo`0Aooooo`;o00004Oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooool0
00001?ooool00ol0003oooooooooo`1?ooooo`00S?ooool00ol0003oooooooooo`0booooo`05oa0@
4?nHV9SooooookZj^_l000003oooool3o`0000;ooooo00?o0000ooooooooool02_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Co0000oooooooooooooooo0_l00005ooooo`03o`000?oooooo
oooo04kooooo002<ooooo`03o`000?oooooooooo03;ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0=
ooooo`;o00004oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo04gooooo002;ooooo`;o0000@oooool3o`00017ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
oooo0_l00005ooooo`03o`000?oooooooooo04gooooo003>ooooo`;o000000?oooooo`000?l00000
3_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`06o`000?ooooooooooo`000?oooooo00001Oooool00ol0003oooooooooo`1<ooooo`00c?ooool2
o`00013ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003oooooo`000?oooooo000000Kooooo00?o0000oooooooo
ool0Boooool00<Wooooo0ol0000Booooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooool000000_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo04_ooooo0037ooooo`?o00004Oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool2o`0000?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1:ooooo`00a?ooool3o`0000?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool00_l00003ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0B_ooool00<;ooooo0_l0000@ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00003ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo04Wooooo0030ooooo`;o00004_ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00004ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`02o`0000?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`18ooooo`00V_ooool5o`0001kooooo0ol00002ooooo`03o`000?oo
oooooooo00cooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooo`0000?o
oooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000000oooool0
1?l0003oooooo`000?l00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0B?oo
ool009[ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Looooo`;o00004Oooool01Ol0003ooooooooo
oooooooo000000Cooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`05o`000?oooooo
0000ooooool000001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04Oooooo002K
ooooo`03oiRHV?lQ8B7ok^k^01_ooooo0_l0000@ooooo`05o`000?ooooooooooooooool000000_oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooooooo
ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0A_oo
ool009cooooo00?oV9RHob4Q8Oo^k^h05oooool3o`000003ooooool0003ooooo00cooooo00Co0000
oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooo
ooooo`000002ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_l00002ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`16ooooo`00WOooool00omgMgOoIVIVooooo`0Doooo
o`;o00004_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Co
oooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04Gooooo002Noooo
o`03o`000?oooooooooo013ooooo0ol0000Aooooo`05o`000?ooooooooooooooool000000oooool0
1?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`15ooooo`00V_ooool01Ol0003o^[ZjoooooonHV9So
410@013ooooo0_l000000ooooooo0000ooooo`0>ooooo`05o`000?ooooooooooooooool000000_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0A?oo
ool009[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00>ooooo`;o00001?ooool00ol0003ooooooooo
o`08ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000_ooool2o`0000?ooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo04?ooooo002Zooooo`?o00004_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01_l0003ooooooooooooooooo0000
ooooo`;o00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0@oooool00:Sooooo0ol0000@ooooo`;o00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Co0000oooooooooooo00000oooool2o`0000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000?ooooo00So0000oooooooooooo0000ooooool0003oooooo`0000?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04;ooooo
002Uooooo`?o00000oooool00ol0003oooooooooo`0:ooooo`;o00000oooool01Ol0003ooooooooo
oooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooooooo00000oooool01?l0003ooooo
ooooooooool2o`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo04;ooooo002Sooooo`;o00004?ooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`11ooooo`00XOooool3o`0000kooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool00000
0oooool2o`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`10ooooo`00W_ooool3o`0000;ooooo00?o0000ooooooooool03Oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000004
ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`;o0000
0oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0@?ooool009cooooo0_l00006ooooo`03o`000?oooooooooo00Sooooo0_l00003ooooo`05o`00
0?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Ko0000ooooooooooooooooo`000?ooool2o`0000?ooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
?oooool009[ooooo0_l0000@ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000;ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooo
ooooooooo`000002ooooo`09o`000?ooooooooooooooool0003oooooo`000?oooooo000000?ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03ko
oooo001fooooo`Co000000?o410@ooooooooool06_ooool3o`0000;ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001?ooool01?l0
003oooooooooool00003ooooo`04o`000?ooooooooooooooo`;o00000_ooool01?l0003ooooooooo
ool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0nooooo`00N?ooool00ol0003oooooooooo`0Jooooo`;o00003oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo0_l00003ooooo`05o`000?oooooo
ooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_l00002ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0?Ooo
ool007Sooooo00?o0000ooooooooool05oooool3o`0000kooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;o
oooo00Go0000ooooooooooooooooo`000003ooooo`;o00000oooool01Ol0003ooooooooooooooooo
000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0_ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000002oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
?Oooool007Sooooo00?o0000ooooooooool05Oooool2o`0000?ooooo00?o0000ooooooooool03?oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000
oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0looooo`00N?ooool00ol0003oooooooooo`0Cooooo`;o0000
4Oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooo
oooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00001?oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool2o`0000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`0kooooo`00N?ooool00ol0003oooooooooo`0@ooooo`?o00004?ooool01Ol0
003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool01?l0003oooooooooool00004ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`09o`000?oooooooooo
ooooool0003oooooo`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`000004ooooo`04
o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0>oooool007Sooooo00?o0000oooooooo
ool03_ooool2o`0000;ooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool01?l0003oooooooooool00003ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000
oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02o`00
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`0jooooo`00M_ooool00omEEEGoIVIVo`00000=ooooo`?o00003oooool0
1?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`;o00000oooool01Ol0
003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003
ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooool0003oooooo`000003ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool0>Oooool008Cooooo0_l0000Booooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`;o00000_oo
ool2o`0000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool0
1?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003ooooo
ooooool00003ooooo`05o`000?ooooooooooooooool000000oooool2o`000003ooooool0003ooooo
00;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0>Oooool008;ooooo0_l00002ooooo`03o`000?oooooooooo
00cooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool2o`0000;ooooo00Co
0000oooooooooooooooo0_l00002ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo03Sooooo001oooooo`?o00004?ooool01Ol0003ooooo
oooooooooooo000000?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02o`00
00?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003o
oooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo03Sooooo001mooooo`;o00004?ooool01Ol0003ooooooooooooo
oooo000000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02o`0000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05
o`000?ooooooooooooooool000000oooool2o`0000?ooooo00Co0000oooooooooooo00000oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`00
0?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0=oooool007_ooooo0_l00002ooooo`03o`000?oooooooooo00[o
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;o00000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooooooo
ool000000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00001Oooool01?l0003o
ooooooooool00003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooo
oooo000000;ooooo0_l00004ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=_ooool007Sooooo
0ol00005ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo00000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000000oooool01?l0003oooooooooool00003ooooo`09o`000?ooooooooooooooool0003ooooo
o`000?oooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Kooooo001Boooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h07oooool2o`0000oooooo00Co0000oooooooooooo00000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000
oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo
00000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`00
0?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`07o`000?oooooooooo
ooooool0003oooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooo
ooooool00003ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0eoooo
o`00D_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01cooooo0ol00002ooooo`03o`000?oooooooooo
00cooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04
o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo
ooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
00000oooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000
ooooooooool00oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool00000
0_ooool01Ol0003ooooooooooooooooo000000?ooooo0_l00003ooooo`04o`000?ooooooooooo`00
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001Ooo
ool00ol0003oooooooooo`0eooooo`00D_ooool01Ol@413ooooooooooooooooo410@01[ooooo0_l0
000Aooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool0
1?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooo
ooooool00003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo
000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo
00Co0000oooooooooooooooo0_l00003ooooo`05o`000?ooooooooooooooool000000oooool01?l0
003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool2o`0000;ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000Gooooo00?o0000ooooooooool0=?ooool005;ooooo00Go0000oooooooo
ooooooooo`00000Hooooo`;o00004?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000
oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo
00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0
003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Co0000oooooooooooo00000oooool01ol0003ooooooooooooooooo0000ooooool000000_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0<oooool005;ooooo00Go
0000ooooooooooooooooo`00000Eooooo`?o00000_ooool00ol0003oooooooooo`0:ooooo`;o0000
0_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`00
00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02o`0000;ooooo00Go0000
ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooo
ooooool00003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo
000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooo
ooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01_l0003oooooooooool0
003oooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0<oooool0
05;ooooo00Go410@oooooooooooooooooa0@400Cooooo`;o00004?ooool01Ol0003ooooooooooooo
oooo000000;ooooo00?o0000ooooooooool00_l00002ooooo`;o00000oooool01Ol0003ooooooooo
oooooooo000000;ooooo00?o0000ooooooooool00_l00003ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003
ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`00
0?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00005
ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo0000
0oooool01?l0003oooooooooool00004ooooo`?o00000_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03;ooooo001Booooo`05ogMgMonHV9So
oooooiRHV?mgMgL04?ooool3o`0000oooooo00Co0000oooooooooooo00000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo0000
0oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool0
0003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000005ooooo`05
o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00003ooooo`05o`00
0?ooooooooooooooool000000oooool01?l0003oooooooooool00004ooooo`04o`000?oooooooooo
o`0000Kooooo00?o0000ooooooooool0<Oooool005;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>
ooooo`;o00000oooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo
ooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool0
1?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooo
ooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000
ooooooooool0<Oooool006?ooooo0_l0000Aooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooo
ooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo0000
0oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01Ol0
003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oo
ooooooooooooool000001?ooool3o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04
o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00001?ooool2o`0000;ooooo0_l00003
ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo033o
oooo001Pooooo`Co00003oooool2o`0000;ooooo0_l00002ooooo`;o00000_ooool01?l0003ooooo
ooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo
00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0
003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`07o`000?oo
ooooooooooooool0003oooooo`000004ooooo`03o`000?oooooo000000Cooooo00?o0000oooooooo
ool01?ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o00000_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
033ooooo001Nooooo`;o00000oooool00ol0003oooooooooo`0;ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_l00002
ooooo`;o00000_ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool00000
0_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01?l0
003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`?o00000_ooool00ol0003oooooooooo`02o`0000?ooooo00Go0000oooo
ooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0;oooool005cooooo0_l0
000@ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000
ooooooooool00_l00002ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooooooo
o`000002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Co
0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`05o`000?oooooooooooooo
ool000000oooool01?l0003oooooo`000?l00003ooooo`04o`000?ooooooooooo`0000?ooooo00Co
0000oooooooooooo00000oooool01?l0003oooooooooool00005ooooo`09o`000?oooooooooooooo
ool0003oooooo`000?oooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0;_ooool005Wooooo1?l0000>ooooo`05o`000?oooooooooooooo
ool000000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000ooo
ool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000ooo
ool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool0
0002ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooo
ooooool000000_ooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooooooo
0_l000000ooooooo0000ooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo02kooooo001Hooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool02?ooool2o`0000;ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
00000oooool01?l0003oooooooooool00003ooooo`07o`000?ooooooooooooooool0003oooooo`00
0003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000oooool01?l0003o
ooooooooool00003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool0
1?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo
oooo0ol00002ooooo`04o`000?ooooooooooooooo`;o00000_ooool01?l0003oooooooooool00003
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0]ooooo`00F?ooool00ol0003ooooo
ooooo`0;ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02o`0000;o
oooo0_l00002ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00003
ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`00
0?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo
000000;ooooo00Ko0000ooooooooooooooooo`000?ooool3o`0000;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00001Oooool0
1?l0003oooooooooooooool2o`000003ooooool0003o000000;ooooo00Co0000oooooooooooo0000
1?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0
003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0;Oooool005Sooooo0_l00009oooo
o`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000_ooool00ol0003oooooooooo`02o`0000;ooooo00Co0000oooooooooooo
00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oo
ooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooo
oooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000ooo
ool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooo`000?ooool00_l000001Ooooooo
0000oooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Gooooo00?o
0000ooooooooool0;?ooool005Sooooo0ol00008ooooo`05o`000?ooooooooooooooool000000ooo
ool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool0
0003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooool000000oooool01?l0003ooooo
ooooool00002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool00000
0_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool01?l0
003oooooooooooooool2o`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oo
ooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo0ol00002ooooo`05
o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`00
Eoooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo
00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000002
ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00000oooool01?l0003ooooooooo
ool00003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Wo0000ooooooooooooooooo`000?oooooo0000ooooool000000oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;o
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0:oooool004gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000001?ooool01Ol0003ooooooooo
oooooooo000000Cooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool0
0003ooooo`06o`000?oooooo0000o`000?oooooo00000_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000001Ooo
ool01?l0003oooooooooool00003ooooo`05o`000?oooooo0000ooooool000000_ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0:_ooool004gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooool000000oooool01Ol0003ooooooooooooooooo000000Cooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooool000000_ooool01?l0003o
ooooooooool00003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00003ooooo`06o`000?oooooo
0000o`000?oooooo00000oooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`00
00?ooooo00Co0000oooooooooooooooo0ol00002ooooo`05o`000?ooooooooooooooool000000ooo
ool2o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Wooooo001=ooooo`05
oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo0000
00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooool000000_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000;ooooo00Go0000oooooooooooooooo
o`000002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooo000000;o
oooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000
oooooooooooo00001_ooool00ol0003oooooooooo`02o`000003ooooool0003ooooo00;ooooo0_l0
0002ooooo`04o`000?ooooooooooooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooo
ooooool000001Oooool00ol0003oooooooooo`0Yooooo`00COooool01Ol0003ooooooooooooooooo
000000Gooooo00?o0000ooooooooool01Oooool01Ol0003oooooo`000?oooooo000000Cooooo00Go
0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooo`000003
ooooo`04o`000?ooooooooooo`0000?ooooo00Ko0000oooooooooooo0000ooooool00002ooooo`05
o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo0000
0oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooo
oooooooooooo0ol00002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?oooooooooooooo
ool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
02Sooooo001=ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`06oooo
o`04o`000?oooooo0000o`0000Cooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooool000000oooool01?l0003ooooooooo
ool00002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`;o000000?oooooo`000?oo
ool00_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000?ooooo00Oo0000
ooooooooooooooooo`000?oooooo000000?ooooo0_l000000ooooooo0000ooooo`02ooooo`04o`00
0?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Sooooo001=ooooo`05oa0@4?oo
ooooooooooooool@41001Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo000000Cooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool00_l000000ooooooo0000ooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00Go
0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000
0oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;o00001?ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool09oooool004gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03o`00
0?oooooo000000Wooooo0ol00003ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool0
1?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000
0oooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000oooool01?l0003oooooo`000?l00002ooooo`;o00000_ooool01?l0003ooooooooo
ool00003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooool0003oooooo`000004
ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Vooooo`00COooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Cooooo0_l0000;ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000ooo
ool4o`0000;ooooo0_l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000oooooooooooo
ooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo0_l00002ooooo`04o`000?oooooooooo
o`0000?ooooo0_l00002ooooo`05o`000?ooooooooooooooool000000oooool2o`0000;ooooo00Go
0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09_ooool005Ko
oooo00?o0000ooooooooool02Oooool01ol0003oooooo`000?oooooo0000ooooool000001?ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooooooo
ool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000005oooo
o`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00002ooooo`05o`000?ooooooooooooooool000000oooool3o`0000Cooooo00Co0000oooooooo
oooo00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooooooo0_l0
00000ooooooo0000ooooo`03ooooo`03o`000?oooooo000000?ooooo00Ko0000oooooooooooo0000
ooooool00002ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooo
oooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Gooooo001Fooooo`03o`000?oo
oooooooo00Wooooo00Go0000oooooooooooo0000ooooo`02o`0000Gooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`05o`000?oooooooooooooo
ool000000_ooool01Ol0003ooooooooooooooooo000000Cooooo1?l000000ooooooo0000ooooo`02
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00?o0000ooooooooool00_l00002ooooo`;o00000_ooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ooooool2o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`05o`000?oooooo
ooooooooool000000_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Cooooo001F
ooooo`03o`000?oooooooooo00Wooooo00Ko0000ooooooooooooooooo`000?ooool2o`0000Cooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0
003oooooooooool00003ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00000_oo
ool01ol0003ooooooooooooooooo0000ooooool000000_ooool01?l0003oooooooooool00003oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00?o000000Coooooo`000?oooooo00000_ooool0
1?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00?o0000ooooool000000_ooool00ol0003oooooo`000003ooooo`05
o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000002ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0Toooo
o`00E_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo0_l000000ooooooo
0000ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooo`000003ooooo`04o`000?oo
ooooooooo`0000;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000;ooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?o00000oooool0
1?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
oooo1?l00003ooooo`;o00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
00?o00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0Sooooo`00EOooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?o
oooo00Ko0000oooooooooooo0000ooooool00002ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000?ooooo00Go0000ooooool0003oooooo`000002ooooo`03o`000?oo
oooo000000;ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooool000000_ooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooool000000oooool2o`0000;ooooo00Co0000oooooooooooo00000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Sooooo`00
EOooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo0_l000001Ooooooo0000
oooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooo
ooooool000000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo
00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo000000;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooooooooooo
ool2o`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo000000;ooooo
00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000;ooooo0ol00002oooo
o`?o000000Goooooo`000?ooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00Go
0000ooooooooooooooooo`000002ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooooooool3o`0000;ooooo00Go0000ooooooooooooooooo`000002
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Rooooo`00EOooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00?ooooo00Oo0000ooooool0003oooooo`000?oooooo000000Cooooo00Go0000
ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooool000000oooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool00000
0oooool01_l0003oooooo`000?l0003oooooo`0000?ooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0oooool2o`0000;ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000?ooooo00Co0000ooooool0003o00000oooool00ol0003oooooo`000002
ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Qooooo`00EOooool2o`00
00_ooooo00?o0000ooooooooool01?ooool01?l0003oooooo`000?ooool2o`0000Cooooo00Go0000
ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooool000000oooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool00000
0oooool01?l0003oooooo`000?l00002ooooo`04o`000?ooooooooooo`0000?ooooo00Ko0000oooo
oooooooo0000ooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000oooool2o`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000002oooo
o`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00004ooooo`04o`000?oo
ooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`;o00000oooool01?l0003o
ooooooooool00002ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003oooooooooool0
0002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Qooooo`00EOooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Cooooo00Ko0000oooooooooooo0000ooooool00004oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Go
0000ooooooooooooooooo`000003ooooo`04o`000?oooooo0000o`0000;ooooo00Co0000oooooooo
oooo00000oooool01_l0003oooooooooool0003oooooo`0000;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00003ooooo`05o`000?oooooo0000ooooool000000_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooo`000002ooooo`07o`000?ooooooooooooooool0003oooooo`000004ooooo`03
o`000?oooooooooo00;o00001?ooool00ol0003oooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Pooooo`00EOooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00Co
0000oooooooooooooooo0ol00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`?o000000Cooooo
o`000?oooooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooool0003o
ooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooo0000ooooo`02
o`000005ooooool0003oooooooooool000000_ooool00ol0003oooooo`000002ooooo`05o`000?oo
ooooooooooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00;ooooo0ol000000ooooooo0000ooooo`02ooooo`04
o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo
ooooo`0000?ooooo00Co0000oooooooooooo00001?ooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool08?ooool005Gooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000
0_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003oooo
o`04o`000?ooooooooooo`0000?ooooo0ol000001Ooooooo0000oooooooooooo000000;ooooo00Go
0000ooooooooooooooooo`000002ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool01?l0
003oooooooooool00002ooooo`05o`000?oooooo0000o`000?ooool00_l000001Ooooooo0000oooo
oooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooooooool2o`00
0007ooooool0003oooooooooool0003oooooo`000003ooooo`03o`000?oooooo000000?ooooo00?o
0000ooooooooool00_ooool2o`0000;ooooo0_l00002ooooo`04o`000?ooooooooooo`0000?ooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Oooooo`00E?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool2o`000004ooooool0003oooooo`0000Cooooo00Co
0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooooooo0_l000000ooooooo0000o`000002ooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooo`000?l00002ooooo`03o`000?oooooo000000?ooooo00Ko0000oooooooo
oooo0000ooooool00002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooooooo`;o00000oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool00000
0_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Nooooo`00E?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool01?l0003oooooo`000?ooool2o`0000Cooooo00Co0000oooooooo
oooo00000oooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooooooo0_l0
00000ooooooo0000o`000003ooooo`04o`000?ooooooooooo`0000?ooooo00So0000oooooooooooo
0000ooooool0003oooooo`0000;ooooo00Co0000oooooooooooo00000oooool3o`000003ooooool0
003o000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000003ooooo`05o`00
0?ooooooooooooooool000000_ooool3o`0000;ooooo0_l00002ooooo`03o`000?oooooo000000Go
oooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00001Oooool0
0ol0003oooooooooo`0Nooooo`00E?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool01_l0003oooooooooool0003oooooo`0000Cooooo00Co
0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool00_l000000ooooooo0000o`000003ooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool00002ooooo`;o00000_ooool01?l0003oooooooooool00003ooooo`Go000000?o
ooooo`000?ooool00_l00002ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool00ol0003o
ooooooooo`02o`0000?ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00002oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooool000000_l00002ooooo`05o`000?oooooooooo
ooooool000000oooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000002oooo
o`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0Mooooo`00E?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooooooool3o`0000?ooooo00Co0000oooooooooooo00000oooool01?l0003ooooooooo
ool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooo000000;o000000Coooooo`000?oooooo00000oooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000000_ooool0
0ol0003oooooo`000003ooooo`Go000000Goooooo`000?ooooooooooo`000002ooooo`06o`000?oo
ooooooooo`000?oooooo00000oooool2o`0000;ooooo00Ko0000oooooooooooo0000ooooool00003
ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool00_ooool01Ol0003oooooo`000?oo
oooo000000?ooooo00Co0000oooooooooooo00001?ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000Cooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool0
0003ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0Looooo`00E?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool01ol0003ooooooooooooooooo0000ooooool000000_ooool01?l0003oooooooooool00003oooo
o`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooool000000_l000000ooooooo0000ooooo`03
o`000003ooooool0003ooooo00;ooooo00Ko0000oooooooooooo0000ooooool00002ooooo`03o`00
0?oooooo000000;ooooo00Co0000oooooooooooo00000_ooool2o`000005ooooool0003o0000oooo
ool000000oooool00ol0003oooooo`000003ooooo`03o`000?oooooo000000Kooooo00Co0000oooo
ool0003o00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooooooo`?o0000
0_ooool2o`000003ooooool0003ooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_l00003ooooo`04o`000?oooooooooo
o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000Gooooo
00?o0000ooooooooool07?ooool005Cooooo0_l0000<ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool01?l0003oooooooooooooool2o`000004ooooool0003oooooo`0000;o
oooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool0
1ol0003ooooooooooooooooo0000ooooool000000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
000000;o000000?oooooo`000?ooool00oooool00ol0003oooooo`000002ooooo`04o`000?oooooo
ooooo`0000;ooooo00Go0000ooooool0003oooooo`000002ooooo`04o`000?ooooooooooo`0000;o
oooo0_l000000ooooooo0000o`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`02o`000003ooooool0003ooooo00;o00000oooool0
1_l0003oooooooooool0003oooooo`0000Gooooo00Co0000oooooooooooooooo0_l000000ooooooo
0000ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooo`000004oooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00003ooooo`05o`000?oo
ooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000oooooooo
ool06oooool005?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00So0000ooooooooooooooooo`000?oooooo0000ooooo`;o00000_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool01ol0003ooooo
oooooooooooo0000ooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000;o0000
00?oooooo`000?ooool00oooool00ol0003oooooo`000002ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool00_l00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ool000000_l00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`02o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_l00002ooooo`04
o`000?ooooooooooo`0000Cooooo00Co0000oooooooooooo00000_ooool2o`0000?ooooo00Co0000
oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo
00000_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool06oooool005?o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`000002ooooo`?o00000_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Co0000oooooooooooo00000oooool01_l0003oooooooooool0003oooooo`0000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooo`000002o`000003ooooool0003ooooo00Cooooo00?o
0000ooooool000000_ooool00ol0003oooooo`000002ooooo`08o`000?ooooooooooo`000?oooooo
0000ooooool00003ooooo`Oo00000oooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo00;o00000oooool01?l0003oooooo`000?ooool2o`000003
ooooool0003ooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000004ooooo`07
o`000?ooooooooooooooool0003oooooo`000003ooooo`05o`000?ooooooooooooooool000000_oo
ool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000005ooooo`03
o`000?oooooooooo01[ooooo001Cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000oooool3o`000003
ooooool0003ooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooo
ooooool000000_ooool00ol0003oooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000Cooooo0ol000000ooooooo0000
o`000003o`0000;ooooo00?o0000ooooool000000_ooool01_l0003oooooooooool0003oooooo`00
00;ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`05o`000003ooooool0003o0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oo
oooooooo00;o000000?oooooo`000?ooool00_l00002ooooo`04o`000?ooooooooooo`0000Cooooo
00Co0000oooooooooooooooo0_l000000ooooooo0000o`000002ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool00_l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000
ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Iooooo`00
Doooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`09o`000?ooooooooooooooool0003oooooo`000?oooooo
000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool00000
0_ooool00ol0003oooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooool0
00000_ooool01Ol0003ooooooooooooooooo000000Cooooo0ol000000ooooooo0000ooooo`02oooo
o`06o`000?ooooooooooo`000?oooooo00000_ooool01?l0003oooooooooool00002ooooo`05o`00
0?oooooo0000ooooool000000_ooool01?l0003oooooooooooooool4o`000004ooooool0003o0000
o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`07o`00
0?ooooooooooooooool0003oooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`?o00000_ooool01?l0003ooooooooooooo
ool2o`0000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooo
ooooooooool000000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Wooooo001C
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0_l000000ooooooo0000o`00
0002ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`03
o`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo0000
00;ooooo00Go0000ooooooooooooooooo`000004ooooo`?o000000?oooooo`000?ooool00oooool0
1_l0003oooooooooool0003oooooo`0000;ooooo00?o0000ooooool000000_ooool00ol0003ooooo
ooooo`02o`0000;ooooo00Ko0000ooooooooooooooooo`000?ooool2o`000004ooooool0003ooooo
o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`;o0000
0_ooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo0ol00002ooooo`03
o`000?oooooooooo00;ooooo0ol00003ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool06?ooool005?o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool02Ol0003ooooooooooooooooo0000ooooool0003oooooo`00
0003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000000_ooool01Ol0
003ooooooooooooooooo000000Cooooo0ol000000ooooooo0000ooooo`03ooooo`06o`000?oooooo
ooooo`000?oooooo00000_ooool00ol0003oooooo`000002ooooo`08o`000?ooooooooooo`000?oo
oooo0000ooooool00002ooooo`;o000000Goooooo`000?l0003oooooo`000002ooooo`03o`000?oo
oooo000000;ooooo00Co0000oooooooooooo00000oooool01?l0003oooooo`000?l00002ooooo`03
o`000?oooooooooo00;o000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000?ooooo0_l000000ooooooo0000ooooo`02ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
0oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0G
ooooo`00D_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool2
o`0000?ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000002oooo
o`05o`000?ooooooooooooooool000001?ooool3o`000003ooooool0003ooooo00;o00000_ooool0
2?l0003oooooooooool0003oooooo`000?oooooo00000_ooool00ol0003oooooo`000002ooooo`05
o`000?oooooo0000ooooool000000_ooool2o`000003ooooool0003ooooo00;o000000?oooooo`00
0?l000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooooooo`;o000000Ko
ooooo`000?l0003oooooo`000?ooool2o`0000;ooooo0_l00002ooooo`05o`000?oooooooooooooo
ool000000oooool2o`0000;ooooo00?o0000ooooool000001?ooool2o`0000;ooooo00Go0000oooo
ooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000;ooooo00Co
0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05oooool005;o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo0_l00002oooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000002ooooo`05
o`000?ooooooooooooooool000001?ooool3o`000003ooooool0003ooooo00;o00000_ooool01?l0
003oooooooooool00002ooooo`;o00000_ooool02?l0003oooooooooool0003oooooo`000?oooooo
00000_ooool02Ol0003oooooo`000?l0003oooooo`000?oooooo0000ooooo`02o`000004ooooool0
003oooooo`0000;ooooo00Co0000oooooooooooo00001?ooool02_l0003oooooo`000?l0003ooooo
o`000?oooooo0000ooooool00002ooooo`04o`000?ooooooooooooooo`?o000000?oooooo`000?oo
ool00oooool01Ol0003oooooo`000?l0003ooooo00?o00000oooool00ol0003oooooo`000003oooo
o`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co
0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo001Booooo`?o
00003?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000?ooooo1Ol00003ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`06o`00
0?ooooooooooo`000?oooooo00000_ooool01Ol0003ooooooooooooooooo000000Cooooo0ol00002
ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01ol0003oooooo`000?oooooo0000oooo
ool000000_ooool00ol0003oooooo`000002ooooo`04o`000?oooooo0000ooooo`Co000000Oooooo
o`000?ooooooooooo`000?oooooo000000;ooooo00Ko0000oooooooooooo0000ooooool00003oooo
o`09o`000?oooooo0000ooooool0003oooooo`000?oooooo000000;ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooo`000004ooooo`05o`000?oooooo0000ooooool000000oooool01?l0
003oooooooooool00002ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool00004ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00001Oooool00ol0003ooooooooo
o`0Fooooo`00D_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003oooooo`000?oooooo000000?ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000oooo
ool00002ooooo`05o`000?ooooooooooooooool000001?ooool3o`0000Gooooo00Co0000oooooooo
oooo00000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool00ol0003oooooo`00
0002ooooo`03o`000?oooooooooo00;o000000Goooooo`000?l0003oooooo`000003ooooo`;o0000
0_ooool01?l0003oooooooooool00002ooooo`08o`000?ooooooooooo`000?oooooo0000ooooool0
0002ooooo`;o00000_ooool01?l0003oooooooooool00005ooooo`06o`000?oooooo0000ooooool0
003ooooo0ol00002ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool00_l00003ooooo`04o`000?ooooooooooo`0000?o
oooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000
oooooooooooo00001Oooool00ol0003oooooooooo`0Eooooo`00D_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo00Ko0000ooooooooooooooooo`000?ooool3o`0000;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`04o`000?ooooooooooo`0000Co
oooo0ol00003ooooo`?o00000_ooool01?l0003oooooooooool00002ooooo`;o00000_ooool00ol0
003oooooo`000002ooooo`03o`000?oooooo000000?ooooo00?o0000ooooool000000ol000001_oo
oooo0000ooooool0003oooooo`0000;ooooo00?o0000ooooool000000oooool3o`000003ooooool0
003ooooo00;o00000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_l00002ooooo`;o00000_ooool01ol0003ooooooooooooooooo0000oooo
ool000001?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000oooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000?o
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01Cooooo001Booooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000;ooooo00Go0000ooooool0003oooooo`000003ooooo`03o`000?oooooo
000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooo000000?ooooo00Co0000oooooooooooo00000oooool3o`000004ooooool0003ooooooooo
o`;o000000Goooooo`000?ooooooooooo`000002ooooo`04o`000?oooooo0000o`0000;ooooo00?o
0000ooooool000000_ooool01Ol0003oooooooooool0003ooooo00;o000000?oooooo`000?l00000
0_l000001_oooooo0000ooooool0003oooooo`0000;ooooo00Co0000oooooooooooo00000oooool2
o`0000;ooooo0ol00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000?ooooo00Ko0000ooooooooooooooooo`000?ooool3o`0000?ooooo00Co
0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Dooooo`00D_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`;o000000?oooooo`000?ooool00_ooool0
0ol0003oooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo0ol000000ooooooo
0000ooooo`03o`000005ooooool0003o0000ooooool000000_ooool02Ol0003oooooo`000?oooooo
0000ooooool0003oooooo`000002ooooo`05o`000?ooooooooooo`000?ooool00_l000003_oooooo
0000o`000?l0003oooooo`000?oooooo0000ooooool0003oooooo`000?oooooo00000_ooool02Ol0
003ooooooooooooooooo0000ooooool0003oooooo`000002ooooo`04o`000?ooooooooooo`0000;o
oooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00Co0000oooooooooooo00000_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01?l0003o
ooooooooool00004ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`00
0002ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`05
o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0Cooooo`00DOooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003oooo
o`Co00000oooool00ol0003oooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooo`000003ooooo`05o`000?ooooooooooooooool00000
0_ooool3o`000003ooooool0003ooooo00;o000000Woooooo`000?ooooooooooo`000?oooooo0000
ooooool000000_ooool2o`000007ooooool0003oooooooooool0003oooooo`000002ooooo`03o`00
0?oooooo000000Go000000Soooooo`000?oooooo0000ooooool0003oooooo`0000;ooooo00?o0000
ooooool000000_ooool01_l0003oooooooooool0003oooooo`0000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooooooool2o`000003ooooool0003ooooo00;ooooo00Go0000oooo
oooooooo0000ooooo`02o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oo
ooooooooo`0000?ooooo0_l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000ooo
ool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo01?ooooo001Aooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooool000000_l00002ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000
ooooooooooooooooo`000002ooooo`?o000000?oooooo`000?l000000_l000002Ooooooo0000oooo
oooooooo0000ooooool0003oooooo`000002ooooo`;o000000Ooooooo`000?ooooooooooo`000?oo
oooo000000;ooooo00Co0000ooooool0003ooooo1?l000001?oooooo0000ooooool00002ooooo`;o
00000_ooool00ol0003oooooooooo`03o`0000?ooooo0ol00002ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
ooooool0003o00000oooool3o`000003ooooool0003ooooo00;ooooo0_l000000ooooooo0000o`00
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00003ooooo`05o`000?oooooo
ooooooooool000000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01;ooooo001A
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool00ol000001Ooooooo0000oooooooooooo000000;ooooo
00Ko0000oooooooooooo0000ooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`03o`000003ooooool0003ooooo00Co00000ooo
ool2o`0000;ooooo00Co0000ooooool0003o00000_ooool00ol0003oooooo`000002ooooo`05o`00
0?oooooo0000ooooool000000_ooool5o`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo
000000Gooooo00?o0000ooooooooool00ol00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool01?ooool2o`0000;ooooo00Co0000ooooool0003ooooo0_l00005ooooo`04o`00
0?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo0000
00?ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co
0000oooooooooooo00000oooool01?l0003oooooooooool00003ooooo`04o`000?oooooooooooooo
o`?o00004oooool0057ooooo0ol0000=ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`06o`000?ooooooooooooooool0003ooooo0_l00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000?ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`?o0000017o
ooooo`000?ooooooooooo`000?oooooo0000ooooool0003oooooo`000?oooooo0000ooooool0003o
ooooo`000002ooooo`03o`000?oooooooooo00;o00000_ooool2o`000006ooooool0003oooooo`00
0?oooooo00000_ooool2o`0000;ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooooooo
ool2o`0000;ooooo00?o0000ooooooooool00_l000001?oooooo0000o`000?ooool2o`0000Cooooo
00Wo0000ooooool0003oooooo`000?oooooo0000ooooool000001Oooool00ol0003oooooooooo`02
o`0000;ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`05o`00
0?ooooooooooooooool000000_ooool2o`0000;ooooo00Co0000oooooooooooo00000oooool01?l0
003oooooooooool00003ooooo`04o`000?ooooooooooooooo`?o00000_ooool00ol0003ooooooooo
o`0Aooooo`00DOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`04o`000?ooooooooooooooo`;o000000Goooooo`000?oooooo
ooooo`000002ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000?ooooo00Ko0000oooooooooooo0000ooooool00002oooo
o`;o000000Goooooo`000?ooooooooooo`000002ooooo`;o000000Coooooo`000?oooooooooo0_l0
00001?oooooo0000ooooool00002ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000?ooooo
00?o0000ooooool000000_ooool01Ol0003oooooo`000?oooooo000000?ooooo00?o0000ooooool0
00000_ooool3o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooo`000?l00004
ooooo`03o`000?oooooo000000;ooooo0_l000000ooooooo0000ooooo`05ooooo`04o`000?oooooo
ooooo`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00004ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooooooo`Co00001?ooool00ol0003ooooo
ooooo`0Aooooo`00DOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooo`000?ooool00ol000001Ooooooo
0000oooooooooooo000000;ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000?ooooo00Ko0000oooooooooooo0000ooooool00002ooooo`;o
000000Goooooo`000?ooooooooooo`000002ooooo`;o000000Coooooo`000?oooooooooo0_l00000
1ooooooo0000oooooooooooo0000ooooool000000_ooool2o`0000;ooooo0_l00002ooooo`;o0000
0_ooool01Ol0003oooooo`000?oooooo000000;ooooo00Wo0000oooooooooooo0000ooooool0003o
ooooo`000?ooool00ol000000ooooooo0000ooooo`04o`000005ooooool0003o0000ooooool00000
0oooool01ol0003oooooooooool0003oooooo`000?ooool00_l00002ooooo`;o00000oooool00ol0
003oooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000oooool01?l0003o
ooooooooool00003ooooo`?o000000?oooooo`000?ooool01Oooool00ol0003oooooooooo`0Aoooo
o`00=_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000?o410@oooo
ooooool00_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000004ooooo`06o`000?ooooooooooooooool0003ooooo0_l000001Ooooooo0000
oooooooooooo000000;ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000?ooooo00Ko0000oooooooooooo0000ooooool00002ooooo`Co0000
0oooool02?l0003oooooo`000?oooooo0000ooooool0003ooooo0_l000001ooooooo0000oooooooo
oooo0000ooooool000000_ooool3o`000003ooooool0003o000000;ooooo0_l00002ooooo`05o`00
0?oooooo0000ooooool000000oooool3o`000005ooooool0003oooooo`000?ooool02_l00003oooo
o`;o00001?ooool02?l0003oooooo`000?oooooo0000ooooool0003ooooo0_l00002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00003
ooooo`04o`000?ooooooooooo`0000;ooooo0_l00003ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool00ol000000ooooooo0000ooooo`08ooooo`03o`000?oooooooooo017ooooo
000fooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`02ooooo`06o`000?ooooooooooooooool0003ooooo1?l00002ooooo`06o`000?oooooo
ooooo`000?oooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Cooooo0ol000001?oooooo0000ooooooooool5o`0000;ooooo00?o0000ooooooooool00_l00000
0ooooooo0000ooooo`02o`0000;ooooo00?o0000ooooool000000_ooool00ol0003oooooo`000009
o`0000;ooooo00?o0000ooooooooool00_l00005ooooo`03o`000?oooooooooo00Ko00000_ooool0
1?l0003oooooooooool00004ooooo`;o00001?ooool00ol0003oooooo`000002ooooo`;o000000?o
ooooo`000?l000000_ooool01ol0003ooooooooooooooooo0000ooooool000000oooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooo
oooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`?o000000?oooooo`000?ooool0
3?ooool00ol0003oooooooooo`0@ooooo`00=_ooool01Ol@413ooooooooooooooooo410@00kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`02ooooo`08o`000?ooooooooooooooool0003oooooo`000?oo
ool3o`000007ooooool0003oooooooooool0003oooooo`000002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooo`000002ooooo`;o000000?ooooo
o`000?l000000ol00002ooooo`07o`000?oooooo0000o`000?oooooo0000ooooo`02o`0000;ooooo
00?o0000ooooool000000_ooool00ol0003oooooo`000004o`000008ooooool0003o0000o`000?oo
oooo0000ooooool00002ooooo`03o`000?oooooo000000?ooooo0ol000001Ooooooo0000ooooool0
003ooooo00;o00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo000000;ooooo
0_l000001?oooooo0000ooooooooool2o`000003ooooool0003o000000?ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000_ooool3o`000003
ooooool0003ooooo00oooooo00?o0000ooooooooool04?ooool003Kooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002
ooooo`04o`000?oooooo0000o`0000;ooooo00Go0000ooooool0003oooooo`000002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001Oooool3o`000005ooooool0003o0000
o`000?ooool00_l000001_oooooo0000oooooooooooo0000ooooo`;o000000Coooooo`000?oooooo
oooo0_l000001?oooooo0000ooooool00002ooooo`03o`000?oooooo000000;ooooo0_l000000ooo
oooo0000ooooo`03o`0000;ooooo00Go0000ooooool0003oooooo`000003ooooo`?o00000oooool0
1?l0003oooooo`000?l00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooool00000
0ol000001Ooooooo0000o`000?l0003ooooo00?o00000_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000000_ooool00ol0003oooooooooo`02o`0000;ooooo00?o0000ooooooooool00ol00000
0ooooooo0000ooooo`0Booooo`03o`000?oooooooooo013ooooo000fooooo`05o`000?oooooooooo
ooooool000003_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00Oo0000oooooooooooooooo
o`000?oooooo000000;ooooo0_l000001_oooooo0000ooooool0003oooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000Cooooo1ol000002?oooooo0000
o`000?l0003oooooo`000?oooooo00000_ooool2o`000003ooooool0003ooooo00;o000000Cooooo
o`000?oooooo00000_ooool00ol0003oooooo`000002ooooo`;o000000?oooooo`000?l000001_l0
00001?oooooo0000ooooool00003ooooo`03o`000?oooooo000000;ooooo00Go0000ooooool0003o
ooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool3o`0000Cooooo2?l00002oooo
o`05o`000?ooooooooooooooool000000_ooool00ol0003oooooo`000003ooooo`?o000000?ooooo
o`000?ooool00oooool01?l0003oooooo`000?l00003ooooo`03o`000?oooooo000000;o00000_oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo013ooooo000fooooo`05oa0@4?oooooo
ooooooooool@41003_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00Oo0000oooooooooooo
ooooo`000?oooooo000000;ooooo1?l000001?oooooo0000ooooool00002ooooo`04o`000?oooooo
ooooo`0000;ooooo00Go0000ooooooooooooooooo`000004ooooo`Go000000?oooooo`000?ooool0
1Ol00002ooooo`07o`000?oooooo0000o`000?oooooo0000ooooo`02o`000005ooooool0003ooooo
ooooool000000_ooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo00Oo
0000oooooooooooo0000ooooool0003ooooo00;o000000?oooooo`000?ooool00_l000001?oooooo
0000ooooool00002ooooo`05o`000?ooooooooooooooool000000_ooool3o`0000Cooooo00Wo0000
ooooool0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003ooooooooooooooooo0000
ooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o00000_ooool0
1_l0003ooooooooooooooooo0000ooooo`?o00000_ooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo013ooooo000fooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000Gooooo00Ko0000oooooooooooo0000ooooool00002ooooo`03o`000?oooooo
000000?o000000Goooooo`000?ooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooo`000002o`000003ooooool0003ooooo00Co0000
00Goooooo`000?oooooo0000ooooo`02o`000003ooooool0003ooooo00;o000000Goooooo`000?oo
ooooooooo`000002ooooo`;o00000_ooool5o`000003ooooool0003o000000;ooooo1?l000001?oo
oooo0000ooooool00002ooooo`Co00000_ooool2o`0000?ooooo00Ko0000oooooooooooo0000oooo
ool00002ooooo`;o000000Goooooo`000?l0003oooooo`000002ooooo`04o`000?oooooo0000oooo
o`;o000000?oooooo`000?ooool00_ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo
00?ooooo00Ko0000ooooooooooooooooo`000?ooool6o`0000;ooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0@ooooo`00=_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?o
EEEEofIVI_l000001Oooool00ol0003oooooo`00000>ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000005ooooo`07o`000?ooooooooooooooool0003oooooo`000002oooo
o`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo
00Go0000ooooooooooooooooo`000004ooooo`04o`000?oooooo0000o`0000;ooooo0_l000000ooo
oooo0000o`000003o`000003ooooool0003ooooo00;o000000?oooooo`000?ooool00_l00002oooo
o`03o`000?oooooo000000;ooooo0ol000000ooooooo0000o`000003o`000007ooooool0003ooooo
o`000?oooooo0000ooooo`02o`0000;ooooo0_l00003ooooo`03o`000?oooooo000000;ooooo00?o
0000ooooool000000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo0_l000001?oooooo
0000ooooool00003ooooo`;o000000Goooooo`000?l0003oooooo`000004ooooo`03o`000?oooooo
000000;ooooo00Co0000ooooool0003o00000_ooool00ol0003oooooooooo`05o`0000;ooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0@ooooo`00Coooool2o`0000oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Oo0000
ooooooooooooooooo`000?oooooo000000;ooooo00?o0000ooooool000000ol000001?oooooo0000
ooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool01?l0
003oooooo`000?l00002ooooo`So00000_ooool01Ol0003oooooo`000?l0003ooooo00?o00000_oo
ool00ol0003oooooo`000002ooooo`?o000000?oooooo`000?l000000ol000001_oooooo0000oooo
ool0003oooooo`0000;ooooo1Ol00003ooooo`?o00000_ooool00ol0003oooooo`000002ooooo`04
o`000?ooooooooooooooo`;o00001?ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo
00;o00000oooool01?l0003oooooo`000?l00002ooooo`03o`000?oooooo000000?ooooo0_l00000
1?oooooo0000ooooooooool4o`0000?ooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0?ooooo`00Coooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`06o`000?ooooooooooo`000?oooooo0000
0_ooool01?l0003oooooo`000?ooool2o`000004ooooool0003oooooo`0000;ooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`02ooooo`;o000000Coooooo`000?oooooooooo1_l0
00001_oooooo0000o`000?oooooo0000ooooo`;o000000?oooooo`000?ooool00_l000001?oooooo
0000ooooool00002ooooo`?o000000Coooooo`000?l0003o00000oooool01Ol0003oooooo`000?oo
oooo000000;ooooo00?o0000ooooooooool01_ooool2o`0000?ooooo0_l00002ooooo`03o`000?oo
oooooooo00?o00001?ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00;o00000ooo
ool02Ol0003ooooooooooooooooo0000ooooool0003oooooo`000007ooooo`Co00000_ooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo00oooooo001?ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00Wo0000ooooooooooooooooo`000?oooooo0000ooooool000000_ooool5o`000005ooooool0
003oooooooooool000000_ooool01Ol0003ooooooooooooooooo000000Cooooo0_l000001?oooooo
0000ooooooooool6o`000006ooooool0003o0000ooooool0003ooooo0_l000000ooooooo0000oooo
o`02o`000006ooooool0003oooooooooool0003ooooo0_l000000ooooooo0000ooooo`02o`0000?o
oooo00Co0000ooooool0003ooooo0_l000000ooooooo0000ooooo`08ooooo`;o00000_ooool2o`00
00;ooooo00?o0000ooooooooool01?l00003ooooo`03o`000?oooooo000000;ooooo00?o0000oooo
ooooool00_l00002ooooo`;o00000oooool00ol0003oooooo`000002ooooo`03o`000?oooooo0000
00Go0000:_ooool00ol0003oooooooooo`0?ooooo`00Coooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooool0003oooooo`000002ooooo`;o000000Goooooo`000?l0003oooooo`00
0002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool2o`000005oooo
ool0003oooooo`000?ooool01Ol000001Ooooooo0000ooooool0003ooooo00?o000000?oooooo`00
0?ooool00_l000001_oooooo0000oooooooooooo0000ooooo`;o000000?oooooo`000?ooool00_l0
0002ooooo`;o000000?oooooo`000?ooool00_l000000ooooooo0000ooooo`03ooooo`;o00000ooo
ool2o`0000;ooooo0_l00002ooooo`03o`000?oooooooooo00Co00000oooool01_l0003ooooooooo
ool0003oooooo`0000?ooooo00Ko0000ooooool0003o0000ooooool00002ooooo`05o`000?oooooo
ooooo`000?ooool01Ol0000]ooooo`03o`000?oooooooooo00oooooo001?ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooo`000?ooool2o`0000;ooooo
0ol00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool2o`000005
ooooool0003oooooo`000?ooool00_l000001ooooooo0000o`000?l0003oooooo`000?ooool00_l0
00001Ooooooo0000ooooool0003ooooo00;o000000Coooooo`000?oooooooooo1?l00002ooooo`Co
000000Koooooo`000?l0003oooooo`000?ooool2o`0000;ooooo00Co0000oooooooooooooooo0_l0
0002ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool000000_ooool01?l0003oooooo`00
0?ooool2o`0000Cooooo00?o0000ooooool000000_ooool01ol0003oooooooooool0003oooooo`00
0?ooool00_l00003ooooo`Ko00000oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
00oooooo001>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000000oooool01_l0003oooooo`000?oooooo
0000ooooo`;o00000_ooool3o`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`02ooooo`;o000000Goooooo`000?oooooo0000ooooo`02o`000003ooooool0003o000000?o
000000Coooooo`000?l0003ooooo0ol000001Ooooooo0000o`000?oooooo000000?ooooo0ol00002
ooooo`Co000000Coooooo`000?l0003ooooo1?l000000ooooooo0000o`000002ooooo`03o`000?oo
oooo000000;ooooo00?o0000ooooool000000_ooool01?l0003oooooo`000?ooool3o`0000;ooooo
00?o0000ooooool000000oooool00ol0003oooooo`000002ooooo`09o`000?ooooooooooo`000?oo
oooo0000ooooool0003ooooo00Oo00000_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo00oooooo001>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool2
o`000007ooooool0003oooooo`000?oooooo0000ooooo`02o`000005ooooool0003oooooooooool0
00000oooool01?l0003oooooooooooooool3o`000003ooooool0003ooooo00;o000000?oooooo`00
0?ooool00_l000001?oooooo0000o`000?ooool2o`000004ooooool0003o0000ooooo`?o00000_oo
ool01?l0003oooooooooooooool2o`0000;ooooo1_l000000ooooooo0000o`000003o`000003oooo
ool0003o000000;ooooo00So0000ooooool0003o0000ooooool0003oooooo`0000;ooooo0ol00000
1Ooooooo0000o`000?l0003ooooo00;o000000Coooooo`000?oooooooooo0_l00002ooooo`03o`00
0?oooooo000000;ooooo1ol00002ooooo`04o`000?ooooooooooo`0003;ooooo00?o0000oooooooo
ool03oooool004kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;o
000000Ooooooo`000?oooooo0000ooooool0003ooooo00Co00000_ooool01Ol0003ooooooooooooo
oooo000000?ooooo0ol000000ooooooo0000ooooo`02o`000003ooooool0003ooooo00;o000000?o
ooooo`000?ooool01_l000000ooooooo0000ooooo`02o`000003ooooool0003ooooo00;ooooo00Co
0000ooooool0003ooooo2?l000001Ooooooo0000o`000?l0003ooooo00;o00000_ooool01Ol0003o
ooooo`000?l0003ooooo00?o00000_ooool2o`000003ooooool0003o000000;o000000Koooooo`00
0?l0003oooooo`000?ooool3o`0000;ooooo00?o0000ooooool000000_ooool4o`0000;ooooo00Go
0000ooooooooooooooooo`00000dooooo`03o`000?oooooooooo00oooooo001>ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`;o00000_oo
ool01Ol0003oooooooooool0003ooooo00;o000000Woooooo`000?oooooo0000ooooool0003ooooo
o`000?ooool00_l00002ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooo`00
0005o`000003ooooool0003ooooo00;o000000?oooooo`000?l000001?l000001Ooooooo0000oooo
ool0003ooooo00;o000000?oooooo`000?ooool00_ooool01?l0003oooooo`000?ooool8o`000005
ooooool0003o0000o`000?ooool00_l00002ooooo`;o000000?oooooo`000?ooool00ol000000ooo
oooo0000ooooo`03o`00000?ooooool0003o0000ooooool0003oooooo`000?oooooo0000ooooool0
003oooooo`000?oooooo000000;ooooo1?l00002ooooo`04o`000?ooooooooooo`0003Sooooo00?o
0000ooooooooool03_ooool004kooooo0_l0000?ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo0_l00007
ooooo`09o`000?ooooooooooo`000?oooooo0000ooooool0003ooooo00;o000000Koooooo`000?oo
oooo0000ooooool00002ooooo`;o000000?oooooo`000?ooool00_ooool01_l0003ooooooooooooo
oooo0000ooooo`;o00000oooool01?l0003oooooo`000?ooool2o`000004ooooool0003o0000oooo
o`?o000000Goooooo`000?oooooo0000ooooo`02o`000003ooooool0003ooooo00;ooooo00?o0000
ooooool000001?l000000ooooooo0000o`000002o`000005ooooool0003o0000o`000?ooool01?l0
00001Ooooooo0000ooooool0003ooooo00;o000000?oooooo`000?l000001?l000001?oooooo0000
o`000?l00002ooooo`03o`000?oooooooooo00;ooooo0_l000000ooooooo0000o`000002o`000003
ooooool0003o000000;ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0>ooooo`00
C_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1?ooool02?l0003ooooooooooooooooo0000ooooool0003ooooo0ol000001_oooooo0000ooooool0
003oooooo`0000;ooooo1?l00003ooooo`06o`000?ooooooooooooooool0003ooooo0_l00003oooo
o`04o`000?oooooo0000ooooo`;o000000?oooooo`000?l000000_l000001ooooooo0000ooooool0
003oooooo`000?ooool00_l000000ooooooo0000ooooo`02ooooo`05o`000?ooooooooooooooool0
00000_ooool:o`000007ooooool0003o0000o`000?oooooo0000ooooo`04o`000003ooooool0003o
000000So00000_ooool00ol0003oooooooooo`02ooooo`?o000000Goooooo`000?oooooo0000oooo
o`03o`0003gooooo00?o0000ooooooooool03_ooool004kooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00Oo0000oooooooooooo0000oooo
ool0003ooooo00?o000000Koooooo`000?oooooo0000ooooool00002ooooo`04o`000?oooooo0000
o`0000?ooooo00Ko0000ooooooooooooooooo`000?ooool2o`0000?ooooo00Co0000ooooool0003o
oooo0_l000001Ooooooo0000o`000?l0003ooooo00Ko000000?oooooo`000?l000000_ooool01?l0
003oooooo`000?l00003ooooo`03o`000?oooooooooo00;o000000?oooooo`000?l000001Ol00000
0ooooooo0000o`000002o`0000;ooooo1_l000000ooooooo0000ooooo`04o`0000Cooooo00?o0000
ooooool000000ol000001?oooooo0000ooooool00002ooooo`?o0000?_ooool00ol0003ooooooooo
o`0>ooooo`00COooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo0_l00005
ooooo`03o`000?oooooooooo00;o000000[oooooo`000?l0003o0000ooooool0003oooooo`000?oo
oooo00000_ooool00ol0003oooooooooo`02o`0000;ooooo00?o0000ooooooooool00ol000000ooo
oooo0000ooooo`02ooooo`;o00000_ooool6o`000003ooooool0003o000000?o000000Coooooo`00
0?l0003o00000_ooool01?l0003oooooo`000?l00003ooooo`03o`000?oooooo000000;o000000Co
ooooo`000?oooooooooo1?l000000ooooooo0000o`000002o`0000;ooooo1Ol00002ooooo`03o`00
0?oooooo000000Co00000_ooool3o`0000;ooooo0_l000001Ooooooo0000ooooool0003ooooo00Co
0000?_ooool00ol0003oooooooooo`0>ooooo`00COooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool00oooool01?l0003oooooo`000?ooool4o`000006
ooooool0003oooooo`000?oooooo00000_ooool00ol0003oooooooooo`03o`000004ooooool0003o
ooooooooo`Co000000Coooooo`000?oooooooooo0_l000000ooooooo0000o`000003o`000003oooo
ool0003o000000Go000000?oooooo`000?ooool00_l00002ooooo`Co00000_ooool00ol0003ooooo
o`000002o`000006ooooool0003oooooooooool0003ooooo0_l000001?oooooo0000ooooool00003
ooooo`Go00000oooool01?l0003oooooo`000?ooool5o`000004ooooool0003oooooooooo`Ko0000
00?oooooo`000?l000000_l0000nooooo`03o`000?oooooooooo00kooooo001=ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`05o`000?oo
oooo0000o`000?ooool00_l000001_oooooo0000ooooool0003oooooo`0000;ooooo00Go0000oooo
oooooooo0000ooooo`03o`0000;ooooo1?l000001?oooooo0000ooooooooool2o`000003ooooool0
003o000000?o000000?oooooo`000?l000001Ol000000ooooooo0000ooooo`02o`0000?ooooo00?o
0000ooooool000000_ooool00ol0003oooooo`000002o`000004ooooool0003oooooooooo`Co0000
00?oooooo`000?l000000oooool01Ol0003oooooo`000?l0003ooooo00?o000000?oooooo`000?oo
ool01?l00002ooooo`?o000000?oooooo`000?ooool02?l000000ooooooo0000ooooo`0mooooo`03
o`000?oooooooooo00kooooo001=ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`03ooooo`?o000000Woooooo`000?l0003oooooo`000?oooooo0000
ooooool000000_ooool01?l0003oooooooooool00002ooooo`;o00000_ooool4o`000009ooooool0
003oooooo`000?oooooo0000ooooool0003ooooo00?o000000?oooooo`000?l000001ol000000ooo
oooo0000o`000003ooooo`07o`000?oooooo0000o`000?oooooo0000ooooo`03o`000004ooooool0
003oooooooooo`Co000000?oooooo`000?l000000oooool01Ol0003oooooo`000?l0003ooooo00Oo
00000_ooool00ol0003oooooo`000005o`0000;ooooo0ol000001_oooooo0000ooooool0003ooooo
o`0003oooooo00?o0000ooooooooool03Oooool004gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0<ooooo`;o00001?ooool6o`000005ooooool0003o0000ooooool000000_ooool0
1?l0003oooooooooool00003ooooo`?o000000goooooo`000?l0003o0000ooooool0003oooooo`00
0?oooooo0000ooooool0003ooooo00?o000000?oooooo`000?l000001ol000000ooooooo0000o`00
0003ooooo`07o`000?oooooo0000o`000?oooooo0000ooooo`03o`000004ooooool0003o0000oooo
o`Co000000?oooooo`000?l000000oooool01Ol0003oooooo`000?l0003ooooo00Go00000_ooool0
1?l0003oooooo`000?ooool2o`000003ooooool0003o000000;o00000_ooool01Ol0003oooooo`00
0?oooooo000000;ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0=ooooo`001_oo
ool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000Sooooo00?oMgMgofIVI_ooool0
2?ooool00omVIVKoMgMgooooo`07ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0>ooooo`;o00000_ooool6o`000005ooooool0003o0000ooooool0
00000_ooool01?l0003oooooooooool00004ooooo`Ko000000Woooooo`000?oooooo0000ooooool0
003oooooo`000?ooool00_l000000ooooooo0000o`000008o`000003ooooool0003o000000?ooooo
00Oo0000ooooool0003o0000ooooool0003ooooo00;o000000Coooooo`000?l0003o00000_ooool6
o`0000?ooooo1_l00002ooooo`;o00000_ooool01?l0003oooooo`000?ooool2o`000003ooooool0
003ooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0mooooo`03o`000?oo
oooooooo00gooooo0006ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00001ooo
ool00ooMgMgo410@onk^kP09ooooo`03onk^k_l@413ogMgM00Oooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`05ooooo`;o00004?ooool2o`000004ooooool0003o0000ooooo`;o0000
00?oooooo`000?l000000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00;ooooo
1_l000002Ooooooo0000ooooool0003oooooo`000?oooooo0000ooooo`02o`000006ooooool0003o
0000ooooool0003ooooo1Ol000000ooooooo0000o`000003ooooo`Co000000?oooooo`000?ooool0
0_l000000ooooooo0000o`000002o`000003ooooool0003ooooo00Co000000Coooooo`000?l0003o
00000_ooool03Ol0003oooooo`000?l0003oooooo`000?oooooo0000ooooool0003oooooo`000?oo
ool00_l000000ooooooo0000ooooo`0;ooooo`03o`000?oooooooooo03gooooo00?o0000oooooooo
ool03Oooool000Kooooo00?o0000ooooooooool00oooool01_mVIVKo0000o`000?m4A4Coc<c<o`00
00;ooooo00?o0000ooooooooool01Oooool00omEEEGoV9RHooooo`02ooooo`05oiRHV?l0003o0000
odA4A?nj^[X00oooool00on7QhOoIVIVooooo`06ooooo`03o`000?oooooooooo01Oooooo0ol0000?
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07
ooooo`Go00003Oooool00ol0003oooooo`000003o`000003ooooool0003o000000;ooooo00?o0000
ooooool000000oooool00ol0003oooooooooo`03ooooo`0<o`000?oooooo0000o`000?oooooo0000
ooooool0003oooooo`000?oooooo00000_ooool01?l0003oooooo`000?ooool2o`000003ooooool0
003o000000Go000000Coooooo`000?oooooooooo0ol000001ooooooo0000o`000?l0003oooooo`00
0?ooool01?l000000ooooooo0000o`000005o`000004ooooool0003o0000o`0000?ooooo0_l00000
1_oooooo0000ooooool0003oooooo`0000;ooooo0ol00002ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0=ooooo`001_ooool00ol0003ooooooooo
o`02ooooo`06ofIVI_mgMgOooooooooooon7QhOo410@0ol00008ooooo`03o`000?oooooooooo00;o
oooo00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`03onk^k_l0003ooooo00Kooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0;ooooo`?o00002oooool5o`000003ooooool0003o0000
00;ooooo00?o0000ooooool000000oooool00ol0003oooooooooo`03ooooo`Co000000?oooooo`00
0?l000000_ooool00ol0003oooooo`000002ooooo`04o`000?oooooo0000ooooo`;o000000?ooooo
o`000?l000001?l000001?oooooo0000o`000?ooool8o`000005ooooool0003oooooo`000?ooool0
0_l000000ooooooo0000o`000002o`000007ooooool0003o0000ooooool0003oooooo`000003oooo
o`;o000000Koooooo`000?oooooo0000ooooool00002ooooo`?o00000_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool03Oooool000Kooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`03oc8b<_oooooooooo00;ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool03_ooool4o`0000Oooooo00?o0000ooooool000000_l000000ooooooo0000o`000002
ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool00oooool01Ol0003oooooo`000?l0
003ooooo00;o00000_ooool00ol0003oooooo`000002ooooo`04o`000?oooooo0000ooooo`;o0000
00?oooooo`000?l000001?l000000ooooooo0000ooooo`09o`000005ooooool0003oooooo`000?oo
ool01_l00002ooooo`;o000000Coooooo`000?oooooo00000oooool2o`000004ooooool0003ooooo
o`0000;ooooo00?o0000ooooool000000_l0000>ooooo`03o`000?oooooooooo03gooooo00?o0000
ooooooooool03Oooool000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>oooo
o`03oc8b<_oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04_ooool3o`0000Gooooo1?l000000ooo
oooo0000o`000002ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool00oooool01Ol0
003oooooo`000?l0003ooooo00;o00000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo
000000;ooooo2_l000000ooooooo0000o`000002o`000006ooooool0003o0000ooooool0003ooooo
1_l000000ooooooo0000o`000002o`000007ooooool0003o0000ooooool0003oooooo`000003oooo
o`09o`000?oooooo0000ooooool0003oooooo`000?oooooo000000;ooooo0_l0000>ooooo`03o`00
0?oooooooooo03gooooo00?o0000ooooooooool03Oooool000Kooooo00?o0000ooooooooool00_oo
ool01_mVIVKoMgMgooooooooooooQhN7o`0000_ooooo00?o0000onk^k_ooool00_ooool00ol0003o
ooooooooo`05ooooo`03onk^k_l0003ooooo00Kooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Eooooo`;o00001?ooool6o`0000;ooooo00?o0000ooooool000000oooool00ol0003o
ooooooooo`03ooooo`?o000000?oooooo`000?l000000_ooool00ol0003oooooo`000003ooooo`03
o`000?oooooo000000;ooooo2_l000000ooooooo0000ooooo`02o`000004ooooool0003o0000oooo
o`Go000000Coooooo`000?l0003ooooo1?l000001ooooooo0000o`000?oooooo0000ooooool00000
0oooool3o`000006ooooool0003oooooo`000?oooooo00000_ooool2o`0000kooooo00?o0000oooo
ooooool0?_ooool00ol0003oooooooooo`0<ooooo`001_ooool00ol0003oooooooooo`02ooooo`06
onk^k_mVIVKo0000o`000?m4A4Co00002oooool01?mEEEGoMgMgooooool@4105o`0000Cooooo00?o
MgMgoeEEEOooool01_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Oooooo0ol0
0002ooooo`Go00000_ooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00?ooooo0ol0
0002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`000002ooooo`[o
000000Goooooo`000?l0003oooooo`000002ooooo`Co000000Coooooo`000?l0003ooooo0_l00000
0ooooooo0000o`000005o`000003ooooool0003ooooo00;o00000_ooool3o`000006ooooool0003o
ooooo`000?oooooo00000_ooool2o`0000kooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`0<ooooo`001_ooool00ol0003oooooooooo`0Cooooo`03omgMgOl@413ok^k^00;ooooo00?o
0000ooooooooool01?ooool00oo^k^ko410@omgMg@07ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`03o`000006ooooool0003oooooo`000?oooooo
00000oooool00ol0003oooooooooo`03ooooo`?o00000oooool01Ol0003oooooo`000?oooooo0000
00?ooooo00?o0000ooooool000000_ooool=o`000003ooooool0003o000000;o000000Coooooo`00
0?l0003ooooo0_l000001?oooooo0000o`000?ooool7o`000003ooooool0003ooooo00;o00000_oo
ool3o`000006ooooool0003oooooo`000?oooooo00000_ooool2o`0000oooooo00?o0000oooooooo
ool0?Oooool00ol0003oooooooooo`0<ooooo`001_ooool00ol0003oooooooooo`0Dooooo`05ogMg
MomVIVKoooooooooool000001_ooool00omVIVKoMgMgooooo`07ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`02o`000006ooooool0003oooooo`00
0?oooooo00000oooool00ol0003oooooooooo`02ooooo`Co00001?ooool2o`000003ooooool0003o
oooo00;ooooo0ol00002ooooo`oo00001?ooool2o`0000;ooooo00?o0000ooooool000002ol00000
0ooooooo0000o`000002ooooo`Oo000000Coooooo`000?oooooooooo0_l0000?ooooo`03o`000?oo
oooooooo03gooooo00?o0000ooooooooool03?ooool004_ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07?ooool0
2_l0003oooooo`000?l0003oooooo`000?oooooo0000ooooool00003ooooo`03o`000?oooooooooo
00;ooooo1?l00005ooooo`03o`000?oooooo000000?ooooo0ol00002ooooo`;o000000?oooooo`00
0?l000002_l00004ooooo`;o00000_ooool00ol0003oooooo`000004o`000003ooooool0003o0000
00?o00000_ooool2o`0000;ooooo1ol000001Ooooooo0000o`000?oooooo0000013ooooo00?o0000
ooooooooool0?Oooool00ol0003oooooooooo`0<ooooo`00Boooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Moooo
o`Go000000Coooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
0000o`0000Gooooo0ol00003ooooo`?o000000Goooooo`000?l0003o0000ooooo`0<o`0000Cooooo
0_l00002ooooo`Oo000000Koooooo`000?l0003o0000ooooool00002ooooo`?o000000?oooooo`00
0?ooool01Ol00002ooooo`?o00004?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo
00cooooo001;ooooo`;o00004Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool07_ooool4o`000004ooooool0003oooooo`0000?ooooo00?o0000oooo
ooooool00_ooool01?l0003oooooo`000?l00005ooooo`03o`000?oooooo000000;ooooo00Go0000
ooooool0003o0000ooooo`0=o`000003ooooool0003o000000Cooooo0_l00002ooooo`Oo000000Ko
ooooo`000?l0003o0000ooooool00002ooooo`?o000000Coooooo`000?l0003ooooo0ol000000ooo
oooo0000ooooo`03o`00013ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0<oooo
o`00Boooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0@ooooo`Oo00001oooool4o`000004ooooool0003oooooo`00
00?ooooo00?o0000ooooooooool00_ooool01?l0003oooooo`000?l00005ooooo`07o`000?oooooo
0000o`000?oooooo0000ooooo`02o`000005ooooool0003o0000o`000?ooool02Ol000000ooooooo
0000o`000004ooooo`;o00000_ooool6o`000003ooooool0003o000000Co00000_ooool3o`000004
ooooool0003o0000o`0000;ooooo0ol000001?oooooo0000o`000?l0000@ooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool02oooool004[ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool9o`00
00Oooooo0ol00004ooooo`Co000000Coooooo`000?oooooo00000oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooo000000;ooooo00So0000ooooooooooooooooo`000?oooooo0000ooooo`;o
000000?oooooo`000?l000001?l000000ooooooo0000o`000006o`000003ooooool0003o000000;o
00000oooool2o`0000;ooooo3Ol00002ooooo`06o`000?oooooo0000o`000?oooooo00000oooool7
o`00013ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0;ooooo`00B_ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`;o00004oooool3o`0000;ooooo1Ol000000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo00;o000000?oooooo`000?ooool00ol000000ooooooo0000o`000006
o`000003ooooool0003o000000?o00000_ooool3o`000005ooooool0003o0000o`000?ooool02Ol0
0002ooooo`06o`000?oooooo0000o`000?oooooo00000oooool3o`000004ooooool0003o0000o`00
013ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0;ooooo`00B_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01Kooooo1Ol000001?oooooo0000ooooool00003oooo
o`04o`000?ooooooooooooooo`;o000000Coooooo`000?oooooooooo0_l000001Ooooooo0000oooo
oooooooo000000;ooooo00Go0000oooooooooooo0000ooooo`03o`000003ooooool0003o000000Ko
000000?oooooo`000?l000000ol000000ooooooo0000ooooo`02o`000005ooooool0003o0000o`00
0?ooool01ol000001?oooooo0000ooooooooool4o`000003ooooool0003ooooo00Cooooo1Ol0000>
ooooo`?o0000@?ooool00ol0003oooooooooo`0;ooooo`00B_ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool2o`0000;ooooo0_l0000Koooo
o`Oo00000oooool01?l0003oooooooooooooool4o`0000;ooooo0_l000001?oooooo0000ooooool0
0003ooooo`05o`000?ooooooooooo`000?ooool00_l00002ooooo`So000000?oooooo`000?l00000
1Ol000001?oooooo0000o`000?ooool3o`000003ooooool0003o000000Go000000Coooooo`000?oo
oooooooo0_l000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l000002oooool3o`00
00;ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0;ooooo`00B_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool2o`0001go
oooo1ol00003ooooo`04o`000?ooooooooooooooo`Co00000_ooool2o`000004ooooool0003ooooo
o`0000?ooooo00Go0000oooooooooooo0000ooooo`02o`000003ooooool0003o000000Oo000000Go
ooooo`000?l0003o0000ooooo`06o`000005ooooool0003o0000o`000?ooool01ol000001?oooooo
0000ooooooooool2o`000003ooooool0003ooooo00Kooooo00?o0000ooooooooool00_l00008oooo
o`?o00001_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00_ooooo001:ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Wooooo`?o
000000Coooooo`000?l0003o00000oooool01?l0003oooooooooooooool4o`0000;ooooo0_l00000
1?oooooo0000ooooool00003ooooo`05o`000?ooooooooooo`000?ooool03?l000001Ooooooo0000
o`000?l0003ooooo00Oo000000Coooooo`000?l0003ooooo1ol000001?oooooo0000ooooooooool2
o`0000;ooooo00?o0000ooooooooool01Oooool01?l0003oooooo`000?l00005ooooo`?o00002_oo
ool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00_ooooo0019ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Wooooo`?o000000?ooooo
o`000?l000000ol000000ooooooo0000ooooo`02ooooo`Co000000Soooooo`000?oooooo0000oooo
ool0003oooooo`0000?ooooo00Go0000oooooooooooo0000ooooo`0Bo`000004ooooool0003o0000
ooooo`;o000000Koooooo`000?l0003oooooo`000?ooool5o`000004ooooool0003oooooooooo`;o
00000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000;ooooo1?l0000>ooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool02oooool004Wooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Oooooo1Ol000001?oooooo0000
o`000?ooool2o`0000?ooooo1?l000001?oooooo0000ooooooooool2o`000003ooooool0003ooooo
00;ooooo00Go0000oooooooooooo0000ooooo`0Bo`000004ooooool0003o0000ooooo`;o000000Ko
ooooo`000?l0003oooooo`000?ooool5o`000004ooooool0003oooooooooo`;o00000_ooool00ol0
003oooooooooo`05ooooo`Go00004oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
00[ooooo0019ooooo`?o00004Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Oo
oooo1ol000001?oooooo0000ooooool00003ooooo`Co000000Coooooo`000?oooooooooo0_l00000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00;o000000?oooooo`000?l000003ol00000
1?oooooo0000o`000?ooool2o`000004ooooool0003o0000ooooo`Oo000000Coooooo`000?l0003o
oooo0_l00009ooooo`?o00005_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00[o
oooo0019ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Wooooo`Ko000000?oooooo`000?l000000_l00002ooooo`03o`000?oooooo000000;o0000
00Goooooo`000?ooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool2o`00
0003ooooool0003o000000;ooooo1ol000000ooooooo0000o`000006o`000006ooooool0003o0000
ooooool0003ooooo0ol000000ooooooo0000o`000002o`000004ooooool0003o0000ooooo`;o0000
1_ooool3o`0001[ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0:ooooo`00;ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001Oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`06ooooo`Go000000?oooooo`000?ooool00ol000000ooooooo0000ooooo`03o`000005oooo
ool0003oooooooooool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo0ol000001?oo
oooo0000ooooooooool7o`000003ooooool0003o000000Go00000_ooool3o`0000;ooooo0ol00000
0ooooooo0000o`000002o`000003ooooool0003o000000?o00000oooool3o`0001kooooo00?o0000
ooooooooool0>Oooool00ol0003oooooooooo`0:ooooo`00;oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07?ooool3o`000003ooooool0
003o000000;o00001?ooool2o`000003ooooool0003ooooo00;o000000?oooooo`000?l000001?l0
00001Ooooooo0000o`000?oooooo000000;ooooo00Co0000oooooooooooo00000_ooool2o`0000;o
oooo0ol000001?oooooo0000ooooooooool7o`000003ooooool0003ooooo00;o000000?oooooo`00
0?l000000_ooool3o`0000?ooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o0000
00Ko00008_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00[ooooo000_ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Jooooo`;o00002?ooool8o`00
0004ooooool0003o0000ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`000003ooooool0
003ooooo00Cooooo00?o0000ooooooooool00_l00002ooooo`?o000000Coooooo`000?oooooooooo
1ol000000ooooooo0000ooooo`02o`000006ooooool0003o0000ooooool0003ooooo0_l00003oooo
o`;o000000?oooooo`000?l000002?l0000Vooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool02_ooool002oooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^
00Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool03?ooool7o`0000;ooooo00?o0000ooooool000000_l000001Ooo
oooo0000oooooooooooo000000Gooooo00?o0000ooooooooool00_l00002ooooo`?o000000Cooooo
o`000?oooooooooo1ol000000ooooooo0000ooooo`02o`000006ooooool0003o0000ooooool0003o
oooo0_l00004ooooo`03o`000?oooooo000000Wo00009_ooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo00[ooooo000_ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOo
IVIVooooo`03ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo00gooooo1?l00002ooooo`;o000000Coooooo`000?oo
oooooooo1?l00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_l00002oooo
o`?o000000Coooooo`000?oooooooooo1ol000000ooooooo0000o`000002o`000006ooooool0003o
0000ooooool0003ooooo0_l00004ooooo`03o`000?oooooo000000Co000000?oooooo`000?l00000
0_l0000Wooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02Oooool002oooooo00Go
410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Kooooo0_l0000@ooooo`Go0000
00?oooooo`000?ooool01?l000001?oooooo0000o`000?l00002ooooo`03o`000?oooooooooo00?o
oooo00Co0000oooooooooooo00001?ooool2o`000004ooooool0003oooooooooo`Oo000000?ooooo
o`000?l000000_l000001_oooooo0000o`000?oooooo0000ooooo`;o00000_ooool9o`000003oooo
ool0003o000000;o0000:?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Wooooo
000_ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Co
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01?o
oooo0ol0000Booooo`Go000000?oooooo`000?ooool00_ooool2o`000004ooooool0003o0000o`00
00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000
oooooooooooo00000_ooool<o`000006ooooool0003o0000ooooool0003ooooo1?l000000ooooooo
0000o`000006o`000003ooooool0003o000000;o0000:Oooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo00Wooooo000_ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So
410@o`000?lQ8B7oc<c<00Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00oooooo1?l0000Eooooo`Go000000?oooooo`000?ooool00_ooool8o`00
00Gooooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000;ooooo3ol0
00000ooooooo0000o`000002o`0000?ooooo0_l000000ooooooo0000o`000002o`0000;ooooo1?l0
000Zooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool02Oooool004Sooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool05oooool5o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000003
o`0000Gooooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000;ooooo
0_l000000ooooooo0000o`000002o`000003ooooool0003o000000So000000?oooooo`000?ooool0
0_ooool2o`000003ooooool0003o000000;o00000_ooool4o`0002[ooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`09ooooo`00Aoooool3o`0001?ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Sooooo0_l000001?oooooo0000o`00
0?ooool2o`0000Cooooo1_l00005ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003o
ooooooooool00002ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000004o`00
0003ooooool0003o000000;o00001?ooool01?l0003oooooo`000?ooool3o`0000;ooooo1?l0000[
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02Oooool004Oooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool06Oooool2o`000003ooooool0003ooooo00?o00001?ooool8o`0000?ooooo00Go0000oooo
ooooooooooooo`000004ooooo`06o`000?ooooooooooooooool0003ooooo0_l000000ooooooo0000
o`000009o`000003ooooool0003o000000;o00001?ooool01?l0003oooooo`000?ooool3o`0000;o
oooo1?l0000/ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool02Oooool004Oooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool06Oooool2o`000003ooooool0003ooooo00?o00001?ooool4o`000003oooo
ool0003o000000?o000000?oooooo`000?ooool00_ooool01Ol0003ooooooooooooooooo000000Co
oooo0_l000000ooooooo0000ooooo`0;o`000003ooooool0003o000000;o00001?ooool01?l0003o
ooooooooooooool3o`0000;ooooo1?l0000]ooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool02Oooool004Oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool2o`000003ooooool0003ooooo00;o
000000?oooooo`000?ooool00_ooool4o`000004ooooool0003oooooooooo`;o000000?oooooo`00
0?ooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo2_l000000ooooooo0000o`000003
o`000003ooooool0003o000000;o00001?ooool01?l0003oooooooooooooool3o`0000;ooooo00Co
0000ooooool0003o0000;_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Sooooo
0017ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo01[ooooo0_l000000ooooooo0000ooooo`02o`000003ooooool0
003ooooo00?ooooo0ol000001_oooooo0000oooooooooooo0000ooooo`;o00000oooool01Ol0003o
oooooooooooooooo000000?ooooo0ol000000ooooooo0000o`000005o`000003ooooool0003o0000
00?o000000?oooooo`000?l000000_l00004ooooo`04o`000?ooooooooooooooo`?o00000_ooool4
o`0002kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`08ooooo`00Aoooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Jooooo`;o000000?oooooo`000?ooool00_l000000ooooooo0000ooooo`03oooo
o`05o`000?oooooo0000ooooool000000_ooool4o`0000?ooooo00Co0000oooooooooooooooo1?l0
00000ooooooo0000o`000008o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l00000
0_l00004ooooo`04o`000?ooooooooooooooo`?o00000_ooool4o`0002oooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`08ooooo`00Aoooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Kooooo`;o0000
00Ooooooo`000?ooooooooooo`000?oooooo000000Cooooo00Co0000ooooool0003ooooo0_l00000
0ooooooo0000ooooo`02o`0000?ooooo1Ol00004ooooo`go000000?oooooo`000?l000000_ooool3
o`0000?ooooo00?o0000ooooooooool00_ooool3o`0000;ooooo1?l0000`ooooo`03o`000?oooooo
oooo02oooooo00?o0000ooooooooool02?ooool004Kooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07?ooool2o`00
0005ooooool0003oooooooooool000000_ooool00ol0003oooooooooo`02o`000003ooooool0003o
oooo00;o000000?oooooo`000?ooool00_l000001?oooooo0000o`000?l00003ooooo`03o`000?oo
oooooooo00;ooooo3Ol000000ooooooo0000o`000002ooooo`04o`000?oooooo0000o`0000;ooooo
00?o0000ooooooooool00_ooool3o`0000;ooooo1?l0000aooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool02?ooool004Kooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07?ooool2o`000005ooooool0
003oooooooooool000000_ooool00ol0003oooooooooo`04o`000005ooooool0003o0000o`000?oo
ool01?l000000ooooooo0000o`000003ooooo`03o`000?oooooooooo00;ooooo0ol000000ooooooo
0000o`000007o`000004ooooool0003oooooooooo`;o000000?oooooo`000?l000000_ooool00ol0
003oooooooooo`02ooooo`?o000000?oooooo`000?ooool00ol0000booooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool02?ooool004Kooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07?ooool5o`0000;o
oooo00Co0000oooooooooooo00000_ooool3o`000004ooooool0003oooooooooo`Co000000?ooooo
o`000?l000000_l00003ooooo`03o`000?oooooooooo00;ooooo0ol000000ooooooo0000o`000007
o`000004ooooool0003oooooooooo`?o000000Coooooo`000?oooooooooo0_l00003ooooo`?o0000
00Coooooo`000?oooooooooo0_l0000cooooo`03o`000?oooooooooo02cooooo00?o0000oooooooo
ool02?ooool004Kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool06oooool2o`000003ooooool0003o000000Go0000
0_ooool00ol0003oooooooooo`08o`000006ooooool0003o0000ooooool0003ooooo0ol00002oooo
o`03o`000?oooooooooo00?ooooo0_l000000ooooooo0000o`000007o`000004ooooool0003ooooo
ooooo`?o000000Goooooo`000?ooooooooooo`000004ooooo`?o000000Goooooo`000?oooooooooo
o`00000dooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool01oooool004Kooooo0_l0
000Dooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Jooooo`04o`000?ooooooooooooooo`Co00000_ooool3o`000003ooooool0003ooooo00Go0000
0_ooool01?l0003oooooo`000?l00002ooooo`?o000000Coooooo`000?oooooo00001Oooool01?l0
003oooooooooooooool8o`000004ooooool0003oooooooooo`?o000000Goooooo`000?oooooooooo
o`000005ooooo`;o000000Goooooo`000?ooooooooooo`00000eooooo`03o`000?oooooooooo02co
oooo00?o0000ooooooooool01oooool004Kooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`02ooooo`Co00000_ooool2o`000003ooooool0003o000000Ko00000_ooool5o`000004oooo
ool0003o0000o`0000;ooooo0_l00005ooooo`04o`000?ooooooooooooooo`So000000Coooooo`00
0?oooooooooo0ol000001Ooooooo0000oooooooooooo000000Gooooo0_l000001Ooooooo0000oooo
oooooooo000003Kooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`07ooooo`00AOoo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00?ooooo1?l00002ooooo`?o000000?o
ooooo`000?l000001Ol00002ooooo`07o`000?ooooooooooo`000?oooooo0000ooooo`06o`0000Co
oooo00?o0000ooooooooool00_ooool8o`000004ooooool0003oooooooooo`?o000000?oooooo`00
0?ooool00_l00005ooooo`;o000000?oooooo`000?ooool00_l0000gooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool01oooool004Gooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`04ooooo`So00000_ooool00ol0003oooooo`000002o`000003ooooool0003o000000;o
00000_ooool01?l0003oooooo`000?ooool2o`0000?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`[o00000_ooool00ol0003oooooo`000002o`000003ooooool0003o0000
00Kooooo0ol000000ooooooo0000o`00000hooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool01oooool004Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`03ooooo`Ko
000000?oooooo`000?l000000_ooool00ol0003oooooo`000002o`000003ooooool0003ooooo00;o
00001Oooool3o`0000?ooooo0_l00003ooooo`03o`000?oooooooooo00;ooooo2_l00002ooooo`05
o`000?oooooo0000o`000?ooool00_l00007ooooo`?o000000?oooooo`000?l00000>?ooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo00Oooooo0015ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool03Oooool01Ol0003ooooooooooooooooo000001[ooooo0_l00003oooo
o`?o000000?oooooo`000?l000000ol000000ooooooo0000o`000003ooooo`;o000000?oooooo`00
0?ooool00ol000000ooooooo0000o`000003ooooo`?o00000_ooool00ol0003oooooo`000003oooo
o`03o`000?oooooooooo00?ooooo2Ol00002ooooo`05o`000?oooooo0000o`000?ooool00_l00007
ooooo`?o000000?oooooo`000?l00000>Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo00Oooooo0015ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool03Oooool01?l0
003oooooo`000?l0000Jooooo`03o`000?oooooooooo00?o00001?ooool5o`000003ooooool0003o
000000?ooooo0_l000000ooooooo0000ooooo`03o`0000?ooooo1_l00002ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooooooool00oooool9o`0000;ooooo00Go0000ooooool0003o0000
ooooo`02o`0000Oooooo0ol000000ooooooo0000o`00000jooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool01_ooool004Gooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo01[ooooo0ol00007ooooo`Go000000?oooooo`000?l000000ooo
ool2o`000003ooooool0003ooooo00?o00001_ooool3o`0000;ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`03ooooo`Co000000?oooooo`000?l000000_l00002ooooo`;o0000
00?oooooo`000?ooool00_l00007ooooo`?o000000?oooooo`000?l00000>oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo00Kooooo0014ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool09oooool4o`0000[ooooo1Ol000001?oooooo0000ooooool00002ooooo`;o0000
00Koooooo`000?oooooo0000ooooool00006ooooo`Co000000Coooooo`000?oooooooooo0_l00000
0ooooooo0000ooooo`04ooooo`Co000000?oooooo`000?l000000_l00002ooooo`;o000000Gooooo
o`000?ooooooooooo`000007ooooo`?o000000?oooooo`000?l00000??ooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo00Kooooo0014ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool09?ooool3o`000003ooooool0003ooooo00_ooooo0_l000001ooooooo0000o`000?oo
oooo0000ooooool000000_ooool2o`000006ooooool0003oooooo`000?oooooo00001_ooool01?l0
003oooooo`000?ooool2o`0000;ooooo00Co0000ooooool0003o00001Oooool9o`0000;ooooo0_l0
00001Ooooooo0000oooooooooooo000000Sooooo0_l000000ooooooo0000o`00000looooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool01_ooool004Cooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0Qooooo`?o00001?ooool00ol0003oooooooooo`0:ooooo`;o000000Oo
ooooo`000?l0003oooooo`000?oooooo000000;ooooo0_l000000ooooooo0000o`000002ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooool000000_ooool2o`000005ooooool0003ooooooooo
ool000001Oooool9o`0000;ooooo0_l000001Ooooooo0000oooooooooooo000000Sooooo0_l00000
0ooooooo0000o`00000mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01_ooool0
04Cooooo0_l0000Fooooo`03o`000?oooooooooo01kooooo0ol00005ooooo`;o00003Oooool2o`00
0007ooooool0003o0000ooooool0003oooooo`000002ooooo`;o000000Coooooo`000?l0003ooooo
0_l00006ooooo`03o`000?oooooo000000;ooooo00Co0000ooooool0003o00000_ooool00ol0003o
ooooooooo`03ooooo`Wo00000_ooool2o`000005ooooool0003o0000ooooool000002?ooool2o`00
0003ooooool0003o000003kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`06oooo
o`00A?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01[ooooo1?l00007ooooo`03
o`000?oooooooooo00gooooo0_l000001ooooooo0000o`000?oooooo0000ooooool000000_ooool2
o`000004ooooool0003o0000ooooo`;o00001_ooool2o`0000?ooooo00Ko0000oooooooooooo0000
ooooool00006ooooo`Wo000000Goooooo`000?l0003o0000ooooo`02o`000003ooooool0003ooooo
00Oooooo0_l000000ooooooo0000ooooo`0oooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool01_ooool004Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Gooooo`?o
00002?ooool3o`00013ooooo0_l000000ooooooo0000ooooo`02o`000004ooooool0003ooooooooo
o`;o000000Coooooo`000?l0003ooooo0_l00006ooooo`;o00000oooool01_l0003oooooooooool0
003oooooo`0000Kooooo2Ol000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?ooool0
1oooool2o`000003ooooool0003ooooo043ooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`06ooooo`00A?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Cooooo0ol0
0008ooooo`?o00004oooool2o`000003ooooool0003ooooo00;o000000Goooooo`000?oooooo0000
ooooo`02o`000003ooooool0003ooooo00;o00001_ooool2o`0000?ooooo00Co0000oooooooooooo
oooo0_l00006ooooo`Wo000000?oooooo`000?l000000_ooool2o`000003ooooool0003ooooo00Oo
oooo0_l000000ooooooo0000ooooo`10ooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool01Oooool004?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Aooooo`?o0000
2_ooool00ol0003oooooooooo`0Dooooo`;o000000?oooooo`000?ooool00_l000001Ooooooo0000
ooooool0003ooooo00;o000000Koooooo`000?oooooo0000ooooool00005ooooo`;o00000oooool0
1?l0003oooooooooooooool2o`0000Kooooo1ol000000ooooooo0000ooooo`02o`0000;ooooo0_l0
00000ooooooo0000ooooo`07ooooo`;o000000?oooooo`000?ooool0@Oooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo00Gooooo0013ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool03_ooool3o`0000gooooo00?o0000ooooooooool05?ooool2o`000003ooooool0003o
oooo00;o000000?oooooo`000?ooool01?l000001_oooooo0000ooooool0003oooooo`0000Gooooo
0_l00003ooooo`04o`000?ooooooooooooooo`;o00001_ooool4o`000006ooooool0003o0000oooo
ool0003ooooo0_l00002ooooo`;o000000?oooooo`000?ooool01oooool2o`000003ooooool0003o
oooo04;ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`05ooooo`00@oooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00[ooooo1?l0000?ooooo`03o`000?oooooooooo
01Gooooo0_l000000ooooooo0000ooooo`02o`000003ooooool0003ooooo00;o000000Soooooo`00
0?oooooo0000ooooool0003oooooo`0000Gooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o
00001_ooool4o`000006ooooool0003o0000ooooool0003ooooo0_l00002ooooo`;o000000?ooooo
o`000?ooool01oooool01?l0003oooooooooool00014ooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool01Oooool004?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`07
ooooo`?o00004_ooool00ol0003oooooooooo`0Fooooo`;o000000?oooooo`000?ooool00_l00000
0ooooooo0000ooooo`02o`000008ooooool0003oooooo`000?oooooo0000ooooool00005ooooo`;o
00000_ooool00ol0003oooooooooo`03ooooo`;o00001Oooool4o`000006ooooool0003o0000oooo
ool0003ooooo0_l00002ooooo`?o00002Oooool2o`000003ooooool0003ooooo04Cooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`05ooooo`00@oooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00Cooooo0ol0000Dooooo`03o`000?oooooooooo01Oooooo0_l000000ooo
oooo0000ooooo`02o`000003ooooool0003ooooo00;o000000Soooooo`000?oooooo0000ooooool0
003oooooo`0000Gooooo0_l00002ooooo`03o`000?oooooooooo00?ooooo0_l00005ooooo`Co0000
00Coooooo`000?l0003ooooo1?l00002ooooo`?o00002_ooool3o`0004Gooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`05ooooo`00@oooool00ol0003oooooooooo`0Fooooo`04o`00
0?ooooooooooooooo`?o00005oooool00ol0003oooooooooo`0Gooooo`;o000000?oooooo`000?oo
ool00_l000000ooooooo0000ooooo`02o`000008ooooool0003oooooo`000?oooooo0000ooooool0
0004ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00oooool2o`0000Gooooo1?l0
00001?oooooo0000o`000?ooool4o`0000;ooooo0ol0000:ooooo`?o0000A_ooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo00Gooooo0012ooooo`03o`000?oooooooooo01Oooooo1?l0
000Iooooo`03o`000?oooooooooo01Sooooo0_l000000ooooooo0000ooooo`02o`00000=ooooool0
003o0000ooooool0003oooooo`000?oooooo0000ooooool0003oooooo`000002ooooo`05o`000?oo
oooo0000ooooool000000_ooool00ol0003oooooooooo`02ooooo`?o00001Oooool4o`000004oooo
ool0003o0000ooooo`Co00000_ooool3o`0000[ooooo00?o0000ooooool00000Aoooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo00Cooooo0012ooooo`;o00005Oooool4o`0001_ooooo
00?o0000ooooooooool06Oooool2o`000003ooooool0003ooooo00;o000000goooooo`000?l0003o
ooooo`000?oooooo0000ooooool0003oooooo`000?oooooo000000;ooooo00Go0000ooooool0003o
ooooo`000002ooooo`04o`000?ooooooooooooooo`Co00001Oooool4o`000004ooooool0003o0000
ooooo`Co00000_ooool3o`0000[ooooo00?o0000ooooool00000B?ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo00Cooooo0012ooooo`03o`000?oooooooooo017ooooo0ol00003oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool4o`0000;ooooo00Oo0000oooo
ool0003o0000ooooool0003ooooo00;o000000Koooooo`000?ooooooooooo`000?ooool2o`000003
ooooool0003ooooo00;o000000Coooooo`000?oooooooooo1Ol00005ooooo`Co000000Coooooo`00
0?l0003ooooo0ol00003ooooo`?o00002_ooool00ol0003oooooo`000019ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool01?ooool004;ooooo00?o0000ooooooooool03_ooool3o`00
00Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Jooooo`Co00000_ooool01ol0
003oooooooooool0003oooooo`000?ooool00_l000001?oooooo0000ooooooooool2o`000005oooo
ool0003oooooo`000?ooool00_l000001Ooooooo0000ooooool0003ooooo00Go00001?ooool4o`00
0004ooooool0003o0000ooooo`?o00000oooool3o`0000[ooooo00?o0000ooooool00000BOooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Cooooo0012ooooo`03o`000?oooooooooo
00_ooooo0ol00009ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06oooool3o`00
00;ooooo00Oo0000ooooool0003o0000ooooool0003ooooo00;o000000Coooooo`000?oooooooooo
0_l000001Ooooooo0000ooooool0003ooooo00;o000000Coooooo`000?oooooo00000_ooool2o`00
0003ooooool0003ooooo00?ooooo1?l000001?oooooo0000o`000?ooool3o`0000?ooooo0ol0000:
ooooo`03o`000?oooooo000004[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`04
ooooo`00@_ooool00ol0003oooooooooo`07ooooo`Co00003?ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo01cooooo0ol00002ooooo`Co000000?oooooo`000?ooool00_l000001?oo
oooo0000ooooooooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l0
00000ooooooo0000ooooo`03ooooo`Co000000Goooooo`000?l0003o0000ooooo`02o`0000;ooooo
00Co0000ooooool0003o00002_ooool00ol0003oooooo`00001;ooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool01?ooool004;ooooo00?o0000ooooooooool01?ooool3o`00013ooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0Looooo`?o00000_ooool4o`000007oooo
ool0003o0000ooooool0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooooooo`02o`00
0003ooooool0003o000000?ooooo0_l000000ooooooo0000ooooo`03ooooo`Co000000?oooooo`00
0?l000001?l00002ooooo`04o`000?oooooo0000o`0000[ooooo00?o0000ooooool00000C?ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Cooooo0011ooooo`03o`000?oooooooooo
00;ooooo0ol0000Cooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool07Oooool3o`00
00;ooooo0_l000002Ooooooo0000o`000?oooooo0000ooooool0003oooooo`000002ooooo`;o0000
0_ooool01Ol0003oooooooooool0003ooooo00?o00000oooool2o`000003ooooool0003ooooo00?o
oooo1?l000000ooooooo0000o`000004o`0000;ooooo00Co0000ooooool0003o00002oooool2o`00
04gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`04ooooo`00@Oooool00ol0003o
ooooo`000002o`0001Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Mooooo`?o
00000_ooool2o`000009ooooool0003o0000ooooool0003oooooo`000?oooooo000000;ooooo0_l0
0002ooooo`05o`000?ooooooooooo`000?ooool00_l00004ooooo`;o000000?oooooo`000?ooool0
0oooool4o`000003ooooool0003o000000Co00000_ooool01?l0003oooooo`000?l0000;ooooo`;o
0000COooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00?ooooo0011ooooo`;o0000
6?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01gooooo0ol00002ooooo`03o`00
0?oooooooooo00;o000000Koooooo`000?oooooo0000ooooool00002ooooo`;o00001Oooool01?l0
003oooooo`000?l00004ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooool000000_l0
00000ooooooo0000o`000004o`0000;ooooo00Co0000ooooool0003o00002oooool2o`0004kooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`03ooooo`00@oooool2o`0001Kooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`0Nooooo`?o00000_ooool00ol0003ooooooooo
o`02o`000006ooooool0003oooooo`000?oooooo00000_ooool2o`0000Gooooo00?o0000ooooool0
00001Oooool01?l0003oooooooooool00003ooooo`04o`000?oooooo0000ooooo`So00000_ooool0
1?l0003oooooo`000?l0000<ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`03ooooo`00A?ooool2o`0001Gooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0Nooooo`?o00000_ooool00ol0003oooooooooo`02o`000006ooooool0003o
ooooo`000?oooooo00000_ooool2o`0000?ooooo00Go0000ooooool0003oooooo`000005ooooo`04
o`000?ooooooooooo`0000?ooooo0ol000000ooooooo0000o`000006o`0000;ooooo00Co0000oooo
ool0003o00003?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool00oooool004Cooooo00?o0000ooooool000005?ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo01kooooo0ol00002ooooo`03o`000?oooooooooo00;o000000Koooooo`00
0?oooooo0000ooooool00002ooooo`;o00000oooool01Ol0003oooooo`000?oooooo000000Cooooo
0_l00003ooooo`03o`000?oooooooooo00?o000000?oooooo`000?l000001_l00002ooooo`04o`00
0?oooooo0000o`0005kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`03ooooo`00
Aoooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
7oooool4o`000003ooooool0003ooooo00;ooooo00Co0000ooooool0003ooooo0ol00002ooooo`;o
00000_ooool2o`000004ooooool0003oooooo`0000Cooooo0_l00003ooooo`03o`000?oooooooooo
00?o000000?oooooo`000?l000001_l00002ooooo`04o`000?oooooo0000o`0005kooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`03ooooo`00B?ooool2o`00017ooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0Oooooo`Co000000?oooooo`000?ooool00_ooool01?l0
003oooooo`000?ooool3o`0000;ooooo0_l00002ooooo`;o000000Coooooo`000?oooooo00001?oo
ool2o`0000?ooooo00?o0000ooooooooool00ol000001?oooooo0000o`000?ooool5o`0000;ooooo
00Co0000ooooool0003o0000Goooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00?o
oooo001:ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0Oooooo`Co000000?oooooo`000?ooool00_ooool01Ol0003oooooo`000?l0003ooooo00;o
00000_ooool2o`000008ooooool0003oooooo`000?oooooo0000ooooool00004ooooo`;o00000ooo
ool00ol0003oooooooooo`03o`000004ooooool0003o0000ooooo`Go00000_ooool01?l0003ooooo
o`000?l0001Pooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00_ooool004[ooooo
0ol0000>ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool08?ooool4o`000003oooo
ool0003ooooo00;ooooo0_l000000ooooooo0000ooooo`02o`0000;ooooo0_l000001?oooooo0000
ooooooooool2o`000003ooooool0003ooooo00?ooooo0_l00003ooooo`03o`000?oooooooooo00?o
000000Coooooo`000?l0003ooooo1Ol00002ooooo`04o`000?oooooo0000o`00067ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`02ooooo`00COooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool08?ooool4o`000003ooooool0003ooooo
00;ooooo0_l000001?oooooo0000ooooool00003ooooo`03o`000?oooooo000000?ooooo0_l00000
0ooooooo0000ooooo`03ooooo`;o00000oooool01?l0003oooooo`000?ooool2o`000004ooooool0
003o0000ooooo`Go00000_ooool01?l0003oooooo`000?l0001Rooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool00_ooool004kooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo023ooooo1?l000000ooooooo0000ooooo`02ooooo`;o0000
00Coooooo`000?oooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Go
oooo0_l00003ooooo`04o`000?oooooo0000ooooo`;o000000Coooooo`000?l0003ooooo1Ol00002
ooooo`04o`000?oooooo0000o`0006;ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`02ooooo`00@?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00[ooooo0_l0000Qooooo`03o`000?oo
oooooooo023ooooo1?l000000ooooooo0000ooooo`02ooooo`;o000000Coooooo`000?oooooo0000
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Gooooo0_l00004ooooo`;o0000
00Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000002o`0000?ooooo00Co0000ooooool0
003o0000Hoooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo0010ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool2o`0001oooooo00?o0000ooooooooool08Oooool4o`00
0004ooooool0003oooooooooo`?o000000Coooooo`000?oooooo00000oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooo000000Gooooo0_l00004ooooo`03o`000?oooooooooo00;o000000Co
ooooo`000?l0003ooooo1?l00003ooooo`04o`000?ooooooooooo`0006Cooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`02ooooo`00@?ooool01Ol@413ooooooooooooooooo410@00go
oooo0_l0000Mooooo`03o`000?oooooooooo027ooooo0_l000001?oooooo0000ooooool00002oooo
o`?o000000?oooooo`000?ooool00_l00002ooooo`03o`000?oooooooooo00;ooooo1_l00003oooo
o`;o00001oooool00ol0003oooooo`000002o`000003ooooool0003o000000;o00000oooool01?l0
003oooooooooool0001Uooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool0
043ooooo00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool08Oooool2o`000004ooooool0003oooooo`0000;ooooo0ol000000ooooooo0000oooo
o`02o`0000;ooooo00?o0000ooooooooool00_ooool2o`000003ooooool0003ooooo00Cooooo0_l0
0007ooooo`03o`000?oooooo000000;o000000?oooooo`000?l000000_l00003ooooo`04o`000?oo
ooooooooo`0006Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`00@?oo
ool01Ol0003ooooooooooooooooo0000013ooooo0_l0000Iooooo`03o`000?oooooooooo02;ooooo
0_l000001?oooooo0000ooooool00002ooooo`?o000000?oooooo`000?ooool00_l00002ooooo`03
o`000?oooooo000000Co000000?oooooo`000?l000001?ooool2o`0000Oooooo00?o0000ooooool0
00000_l000000ooooooo0000o`000002o`0000?ooooo00Co0000oooooooooooo0000I_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo007ooooo0010ooooo`05oa0@4?oooooooooooooo
ool@41004Oooool2o`0001Sooooo00?o0000ooooooooool08_ooool2o`000004ooooool0003ooooo
o`0000;ooooo0ol000000ooooooo0000ooooo`02o`0000;ooooo0_l00003ooooo`;o000000Cooooo
o`000?l0003o00000_ooool01?l0003oooooo`000?l00005ooooo`03o`000?oooooooooo00?o0000
00?oooooo`000?l000000_l00003ooooo`04o`000?ooooooooooo`0006Oooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`01ooooo`00@?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01?o
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Rooooo`;o000000Coooooo`000?oo
oooo00000_ooool01_l0003oooooo`000?oooooo0000ooooo`;o00000_ooool00ol0003ooooooooo
o`02ooooo`?o000000?oooooo`000?l000000_ooool01?l0003oooooo`000?l00005ooooo`03o`00
0?oooooooooo00?o000000?oooooo`000?l000000_l00003ooooo`04o`000?oooooo0000o`0006So
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`01ooooo`00@?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^01Cooooo0_l0000Eooooo`03o`000?oooooooooo02;ooooo0_l000001?oooooo
0000ooooool00003ooooo`;o000000?oooooo`000?ooool00_l00002ooooo`06o`000?oooooooooo
ooooool0003ooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?ooool01?oo
ool00ol0003oooooooooo`03o`000003ooooool0003o000000;o00000oooool01?l0003oooooo`00
0?l0001Yooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00Oooool005_ooooo0_l0
000Booooo`03o`000?oooooooooo02?ooooo0_l000001Ooooooo0000oooooooooooo000000;ooooo
0_l000001Ooooooo0000ooooool0003ooooo00?o00000oooool02Ol0003oooooo`000?l0003ooooo
o`000?oooooo0000ooooo`02o`000003ooooool0003ooooo00Cooooo00?o0000ooooooooool00ol0
00000ooooooo0000o`000002o`0000?ooooo00Co0000ooooool0003o0000J_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo007ooooo001Looooo`;o00004Oooool00ol0003ooooooooo
o`0Sooooo`;o000000Goooooo`000?ooooooooooo`000002ooooo`?o00000_ooool01Ol0003ooooo
o`000?oooooo000000?ooooo00?o0000ooooool000000_ooool00ol0003oooooo`000003o`000003
ooooool0003ooooo00Cooooo00?o0000ooooooooool00ol000000ooooooo0000o`000002o`0000?o
oooo00Co0000ooooool0003o0000Joooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
007ooooo001Nooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool08oooool2o`000005
ooooool0003oooooooooool000000_ooool3o`0000;ooooo1?l00004ooooo`05o`000?oooooo0000
ooooool000000_ooool01_l0003oooooooooool0003oooooo`0000Gooooo00?o0000ooooooooool0
0ol000000ooooooo0000o`000002o`0000?ooooo00Co0000ooooool0003o0000Joooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo007ooooo001Oooooo`04o`000?ooooooooooo`0000_o
oooo00?o0000ooooooooool09Oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00?o
000000Coooooo`000?l0003ooooo0_l00004ooooo`05o`000?oooooo0000ooooool000001Oooool0
0ol0003oooooo`000005ooooo`03o`000?oooooooooo00;o00000oooool3o`0000?ooooo00Co0000
ooooool0003o0000K?ooool00ol0003oooooooooo`0:ooooo`7o00000Oooool1ooooo`00H?ooool3
o`0000_ooooo00?o0000ooooooooool09Oooool00ol0003oooooo`000002ooooo`04o`000?oooooo
ooooooooo`?o000000?oooooo`000?ooool00_l00004ooooo`05o`000?oooooo0000ooooool00000
1Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00;o00000oooool00ol0003ooooo
o`000003ooooo`04o`000?oooooo0000o`0006gooooo00?o0000ooooooooool02Oooool1o`00007o
oooo0Oooool0067ooooo0_l0000cooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo
oooo0_l000001?oooooo0000ooooooooool2o`0000Cooooo00Go0000ooooool0003oooooo`000005
ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool00ol00002ooooo`?o00000oooool0
1?l0003oooooo`000?l0001^ooooo`03o`000?oooooooooo00Sooooo0Ol00001ooooo`7ooooo001S
ooooo`;o0000<Oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00?o000000Cooooo
o`000?oooooooooo0_l00004ooooo`05o`000?oooooo0000ooooool000001Oooool00ol0003ooooo
o`000005ooooo`03o`000?oooooooooo00?o00000_ooool3o`0000?ooooo00Co0000ooooool0003o
0000Koooool00ol0003oooooooooo`07ooooo`7o00000Oooool1ooooo`00IOooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo00?o000000Goooooo`000?l0003oooooo`000002ooooo`;o
00001?ooool01Ol0003oooooo`000?oooooo000000Gooooo00?o0000ooooool000001Oooool00ol0
003oooooooooo`03o`0000;ooooo0ol00003ooooo`04o`000?oooooo0000o`0006oooooo00?o0000
ooooooooool01oooool1o`00007ooooo0Oooool006Kooooo0_l0000`ooooo`04o`000?oooooooooo
o`0000?ooooo00Co0000oooooooooooo00000_ooool2o`0000Cooooo00Go0000ooooool0003ooooo
o`000005ooooo`03o`000?oooooo000000Gooooo00Co0000oooooooooooooooo0_l00002ooooo`?o
00000oooool01?l0003oooooo`000?l0001`ooooo`03o`000?oooooooooo00Kooooo0Ol00001oooo
o`7ooooo001Wooooo`;o0000;oooool4o`0000?ooooo00Co0000oooooooooooo00000_ooool2o`00
00?ooooo00Ko0000oooooooooooo0000ooooool00005ooooo`03o`000?oooooo000000Gooooo00Co
0000oooooooooooooooo0_l00002ooooo`?o00000oooool01?l0003oooooo`000?l0001aooooo`03
o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo001Yooooo`03o`000?oooooooooo02Kooooo
1ol00002ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02o`0000?o
oooo00Ko0000oooooooooooo0000ooooool00005ooooo`03o`000?oooooo000000Gooooo00Co0000
oooooooooooooooo0_l00002ooooo`03o`000?oooooo000000?ooooo00Co0000ooooool0003o0000
L_ooool00ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`00J_ooool2o`0002;ooooo1?l0
0006ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool2o`0000?o
oooo00Ko0000oooooooooooo0000ooooool00005ooooo`03o`000?oooooo000000Gooooo00?o0000
ooooooooool00_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Co0000ooooool0003o
0000Loooool00ol0003oooooooooo`04ooooo`7o00000Oooool006cooooo00?o0000ooooooooool0
7Oooool2o`0000gooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;o
00000oooool00ol0003oooooooooo`02o`0000Kooooo00?o0000ooooool000001Oooool00ol0003o
ooooooooo`02ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01?l0003oooooo`000?l0
001cooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`00F_ooool4o`000008oa0@4?oooooo
ooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`?o00007?ooool00ol0003oooooooooo`0=ooooo`05
o`000?ooooooooooooooool000001Oooool2o`0000?ooooo00?o0000ooooooooool00_l00005oooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool01_l0003oooooooooool0
003oooooo`0000?ooooo00Co0000ooooool0003o0000M?ooool00ol0003oooooooooo`03ooooo`7o
00000Oooool005cooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Wo
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0=ooooo`05o`000?oooooooooooooo
ool000001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o00001Oooool01?l0
003oooooooooool00005ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooooooooooo0000oooo
ool00003ooooo`04o`000?oooooo0000o`0007Gooooo00?o0000ooooooooool00_ooool1o`00007o
oooo001Looooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400:ooooo`03
o`000?oooooo000001Oooooo00?o0000ooooooooool03_ooool01Ol0003ooooooooooooooooo0000
00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02o`0000Gooooo00Co0000oooo
oooooooo00001Oooool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooo`000?oooooo0000
0oooool00ol0003oooooo`00001gooooo`05o`000?ooooooooooooooool000000Oooool005cooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000_ooooo0_l0000Fooooo`03
o`000?oooooooooo00oooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_l00005ooooo`05o`000?ooooooooooooooool000001?ooool0
0ol0003oooooooooo`02ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003ooooo
o`00001hooooo`04o`000?ooooooooooo`00007ooooo001Looooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`00000<ooooo`;o00005?ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02o`0000Go
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooo
oooooooo0000ooooool00003ooooo`03o`000?oooooo000007Sooooo00Co0000oooooooooooo0000
0Oooool005cooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00kooooo
0_l0000Booooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooo000000;o00001Oooool01Ol0003ooooooooooooooooo000000Co
oooo00?o0000ooooooooool00_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000
ooooool00000NOooool00ol0003oooooooooo`01o`000000G?ooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL04?ooool2o`0000oooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000000_l00005
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`06o`000?oo
ooooooooo`000?oooooo00000oooool00ol0003oooooo`00001jooooo`7o00000Oooool1o`000000
F_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00oooool01Ol0003o
oooooooooooooooo000000;ooooo0ol00005ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`03ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003ooooo
o`00001kooooo`;o0000001hooooo`;o00003?ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`?o00001Oooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool00oooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooool00000N_ooool3o`000000N_ooool00ol0003oooooo`000009oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00002
ooooo`?o00001Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00ooo
ool01_l0003oooooooooool0003oooooo`0000;ooooo00Co0000oooooooooooo0000MOooool5o`00
00?ooooo001kooooo`;o00002?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Co
oooo00Co0000oooooooooooo00000_ooool3o`0000Gooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo00?ooooo00Ko0000oooooooooooo0000ooooool00002ooooo`04o`00
0?ooooooooooo`00077ooooo1?l00008ooooo`00O?ooool2o`0000Oooooo00?o0000ooooooooool0
7_ooool01?l0003oooooooooool00002ooooo`?o00001Oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool00oooool01_l0003oooooooooool0003oooooo`0000;ooooo00Co
0000oooooooooooo0000KOooool4o`0000cooooo001nooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool00oooool3o`0000Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00?ooooo00Ko0000oooooooooooo0000ooooool00002ooooo`04o`000?oooooooooo
o`0006Sooooo1Ol0000@ooooo`00Ooooool3o`0002Cooooo00?o0000ooooooooool00oooool3o`00
00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00Ko0000
ooooool0003o0000ooooool00002ooooo`04o`000?ooooooooooo`0006Cooooo1?l0000Eooooo`00
POooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00?ooooo0ol00004ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`06o`000?oooooo0000o`00
0?oooooo00000_ooool01?l0003oooooooooool0001Oooooo`Go00006Oooool008;ooooo0_l0000R
ooooo`03o`000?oooooooooo00?ooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000005ooooo`06o`000?oooooo0000o`000?oooooo00000_ooool01?l0003o
ooooooooool0001Kooooo`Co00007_ooool008Cooooo00?o0000ooooool000007oooool00ol0003o
ooooooooo`03ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000001Oooool01_l0003oooooo`000?l0003oooooo`0000;ooooo00Co0000oooooooooooo0000
E_ooool5o`0002;ooooo0025ooooo`;o00007oooool00ol0003oooooooooo`03ooooo`?o00001?oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool01_l0003ooooo
o`000?l0003oooooo`0000;ooooo00?o0000ooooool00000Doooool4o`0002Oooooo0026ooooo`;o
00007_ooool00ol0003oooooooooo`03ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000001Oooool01_l0003oooooo`000?l0003oooooo`0000;ooooo00?o
0000ooooool00000Coooool4o`0002_ooooo001dooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Oooooo00?o0000ooooooooool08Oooool2o`0000Gooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000Oooooo0_l000001ooooooo0000oooooooooooo0000oooo
ool00000B_ooool5o`0002oooooo001dooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Sooooo0_l0000Qooooo`;o00001Oooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000001oooool2o`000007ooooool0003oooooooooool0003o
ooooo`000016ooooo`Co0000=?ooool007Gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooo
oooooooooooo410@00Wooooo0_l0000Pooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000002?ooool00ol0003oooooo`000002ooooo`03o`000?oooooo0000
047ooooo1Ol0000hooooo`00M_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooooooooooo
ool000002oooool2o`0001kooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000008ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool00000?Oooool4
o`0003gooooo001gooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00000=
ooooo`;o00007?ooool2o`0000Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000Sooooo00?o0000ooooool000000_ooool00ol0003oooooo`00000iooooo`Co0000@Ooo
ool007Sooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00cooooo00?o
0000ooooooooool06_ooool2o`0000Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000Sooooo00?o0000ooooool000000_ooool00ol0003oooooo`00000dooooo`Go0000
AOooool007Cooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03oooool2o`0001[ooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000008ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool00000<?ooool4o`00
04[ooooo001dooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^017ooooo00?o0000ooooool000005oooool2o`0000[ooooo00Go0000ooooooooooooooooo`00
0008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000:oooool5o`0004kooooo002C
ooooo`;o00005oooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool000002?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooo000002Oooooo1?l0001Cooooo`00UOooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`00
000=ooooo`03o`000?oooooo000002;ooooo1Ol0001Gooooo`00U_ooool3o`0001?ooooo00?o0000
ooooooooool02Oooool01?l0003oooooooooool0000>ooooo`03o`000?oooooo000001kooooo1?l0
001Looooo`00V?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Wooooo00Co0000
oooooooooooo00003_ooool00ol0003oooooo`00000Jooooo`Co0000H?ooool009Sooooo0_l0000B
ooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo00003_ooool00ol0003ooooooooo
o`0Eooooo`Go0000I?ooool009[ooooo0_l0000?ooooo`03o`000?oooooooooo00[ooooo00Co0000
oooooooooooo00008_ooool4o`0006Wooooo002Looooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02_ooool01?l0003oooooooooool0000Mooooo`Go0000KOooool009cooooo0ol0000<
ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooo00006Oooool4o`0007;ooooo002<
ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Kooooo
1?l0001fooooo`00S?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`07ooooo`;o00002Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo017o
oooo1Ol0001jooooo`00T?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@oooooooo
ool01_ooool2o`0000Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=ooooo`Co
0000Ooooool008oooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000[o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Eooooo`Go0000Poooool007Oooooo
00GoV9RHo`000?l0003oA4A4okZj^P0Booooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`;o00001Oooool00ol0003oooooooooo`0Aooooo`Co0000R?ooool007Oo
oooo00Go410@okZj^_o^k^koMgMgoa0@400Cooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooo
oooooooooooooa0@400<ooooo`;o00001?ooool00ol0003oooooooooo`0<ooooo`Go0000S?ooool0
07Oooooo00?o0000ooooooooool04_ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0>ooooo`05o`000?oooooo0000ooooool000002_ooool4o`00097ooooo
001gooooo`03o`000?oooooooooo01;ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03oooool2o`000003ooooool0003ooooo00Gooooo1?l0002Eooooo`00
Moooool00ol0003oooooooooo`0_ooooo`?o000000?oooooo`000?l000000ol0002Iooooo`00MOoo
ool00ol@413o0000o`000003o`00033ooooo0_l0002Nooooo`00Moooool00ol0003oooooooooo`3A
ooooo`00Moooool00ol0003oooooooooo`3Aooooo`00oooooom<ooooo`00oooooom<ooooo`00oooo
oom<ooooo`00Y?ooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^09co
oooo002Uooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`2Looooo`00
X_ooool5o`0000?ooooo00Go410@oooooooooooooooooa0@402Looooo`00X_ooool01?m4A4CogMgM
ooooool00004ooooo`05o`000?ooooooooooooooool00000W?ooool00:;ooooo00CogMgMoeEEEOoo
oooo00001?ooool01Ol0003ooooooooooooooooo000009cooooo002Sooooo`03ogMgMoo<c<co0000
00Cooooo00Go410@oooooooooooooooooa0@402Looooo`00Xoooool00oo^k^koA4A4o`000004oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL0W?ooool00:Cooooo00?oMgMgo`000?ooool00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^09cooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo
003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo0033ooooo`04oa0@
4?l0003o0000o`0008Cooooo0034ooooo`03o`000?oooooooooo08Cooooo0034ooooo`03o`000?oo
oooooooo08Cooooo002Gooooo`05o`000?o<c<cogMgMo`000?o^k^h00_ooool01_nHV9So0000o`00
0?mgMgOo410@o`0000Cooooo00?o8B4Qoc8b<_ooool00oooool01_o^k^koEEEEo`000?l0003oA4A4
okZj^POooooo00Ko410@oc8b<_l0003o0000oa0@4?nYZJT3ooooo`09o`000?mgMgOo0000o`000?mE
EEGok^k^ooooooo^k^koEEEE00;o000000?oA4A4okZj^_ooool00_ooool01OmVIVKo0000o`000?m4
A4Coc<c<00?ooooo00OoV9RHo`000?l0003oA4A4okZj^_oooooo410@00Go00001?ooool01_nHV9So
0000o`000?mgMgOo0000oa0@40;o00000_ooool01Ol0003oooooooooool0003o410@053ooooo002F
ooooo`06ojVYZOl0003oQhN7oiRHV?l0003oV9RH0_ooool01Ol0003oc<c<onk^k_n7QhOo000000Co
oooo00CoV9RHoc8b<_l@413o^[Zj0oooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40Oooooo00Ko
0000ojVYZOoooooooooookZj^_l00003ooooo`0=o`000?mEEEGok^k^oooooomgMgOoEEEEoooooomE
EEGoMgMgooooooo^k^koMgMgoa0@4002ooooo`06ofIVI_mgMgOooooooooooon7QhOo410@0oooool0
1Ol@413o^[Zjonk^k_mgMgOo410@00?ooooo00?o0000ooooooooool01Oooool01Ol0003oZJVYoooo
oon7QhOo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`1?ooooo`00
U_ooool01_mEEEGoQhN7odA4A?mEEEGoMgMgoeEEE@;ooooo00Go410@ohN7Qoooooook^k^o`000004
ooooo`04oa0@4?nj^[[oV9RHoc8b<P?ooooo00?o0000ooooooooool02oooool01Onj^[[oQhN7ofIV
I_mVIVKo410@00?ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooo`000007ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
04oooooo002Fooooo`06o`000?oMgMgoA4A4ob4Q8Oo^k^ko00000_ooool00onj^[[o410@o`000002
o`0000?ooooo00KoV9RHoc8b<_oooooooooooa0@4?nj^[X2ooooo`Ko00001oooool01_lb<S;o8B4Q
ogMgMomgMgOoQhN7onk^kP?ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooo`000005o`00
00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool0Coooool009Gooooo00SoZJVYob4Q8OooooooQhN7oeEEEOoooooo<S8bojVYZ@Co
oooo00Ooc<c<o`000?ooooooooooonk^k_l0003ogMgM00;ooooo00[oV9RHoc8b<_oooooooooooeEE
EOn7QhOok^k^oooooon7QhOo<S8b1oooool01_l0003o^[Zjooooooo^k^koMgMgo`0000?ooooo00go
0000oeEEEOo^k^koooooogMgMomVIVKooooooeEEEOn7QhOok^k^oooooon7QhOo<S8b00;ooooo00Ko
IVIVogMgMoooooooooooohN7Qol00003ooooo`03o`000?oooooooooo00Gooooo00?o0000oc8b<_oM
gMd01Oooool01Ol0003ooooooooooooooooo000000;ooooo00Oo0000olc<c?o<c<co0000ojVYZOoM
gMgo8B4Q057ooooo002Eooooo`?o00000_ooool3o`0000;ooooo00Co<S8bo`000?l0003oV9RH0_oo
ool00ol@413o0000o`000002ooooo`?o000000?oooooonk^k_mEEED00_l000000om4A4Cok^k^oooo
o`06ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o00000_ooool00ol@413o0000ogMgM`02o`000005
ofIVI_o^k^koooooonk^k_mEEED00_l000001_m4A4Cok^k^ooooooooooook^k^ofIVIP;o000000Co
A4A4o`000?oooooo410@1Ol00003ooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q0_ooool01?l@413o
0000ooooooooool2o`000009ooooool@413o0000ob4Q8Ol0003oMgMgoa0@4?l0003oZJVY057ooooo
003Looooo`03o`000?oooooooooo06cooooo003Looooo`03o`000?oooooooooo06cooooo003ooooo
odcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003ooooo
odcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo003ooooo
odcooooo003oooooodcooooo003oooooodcooooo003oooooodcooooo0000\
\>"],
  ImageRangeCache->{{{0, 330.625}, {358.875, 0}} -> {-0.163248, -0.0828824, \
0.00404337, 0.00404337}}],

Cell[TextData[{
  "Fig. 7.8 Spectrum associated with solution shown in Fig. ",
  ButtonBox["7.7",
    ButtonData:>"Fig. 7.7",
    ButtonStyle->"Hyperlink"]
}], "Caption",
  CellTags->"Fig. 7.8"],

Cell[TextData[{
  "\tThis leaves us in a bit of a quandary. By including dispersion in the \
KdV equation, which should make the equation a more accurate descriptor of \
water waves than Eq. ",
  ButtonBox["(7.1.30)",
    ButtonData:>{"Chapter7.nb", "(7.1.30)"},
    ButtonStyle->"Hyperlink"],
  " ,  we have actually lost wavebreaking, one of the main qualitative \
features of such waves.  "
}], "Text"],

Cell[TextData[{
  "\tThe solution to this puzzle lies in the approximate form of dispersion \
in the KdV equation. As already mentioned in connection with the rounded \
peaks of cnoidal waves, Eq. ",
  ButtonBox["(7.2.2)",
    ButtonData:>{"Chapter7.nb", "(7.2.2)"},
    ButtonStyle->"Hyperlink"],
  "  is a poor approximation for large wavenumbers, yielding a phase velocity \
that can actually be negative for large ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  ". The exact dispersion relation ",
  ButtonBox["(7.2.1)",
    ButtonData:>{"Chapter7.nb", "(7.2.1)"},
    ButtonStyle->"Hyperlink"],
  "  varies much less rapidly at large ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  ", and results in weaker dispersion that allows real water waves to break, \
provided their amplitude is sufficiently large. "
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["7.2.4 Shock Waves: Burgers' Equation", "Subsubtitle",
  CellTags->{"i:46", "c:23"}],

Cell[CellGroupData[{

Cell["Steady solutions", "Section",
  CellTags->"c:24"],

Cell[TextData[{
  "If we take the dispersive term ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^3 f/\[PartialD]x\^3\)]],
  " in the KdV equation, change the sign,  and lower the order of the \
derivative by one, we obtain ",
  StyleBox["Burgers'",
    FontSlant->"Italic"],
  StyleBox[" equation",
    FontSlant->"Italic"],
  ","
}], "Text",
  CellTags->"i:47"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]f\/\[PartialD]t + 
          f \[PartialD]f\/\[PartialD]x - \[Chi]\ \[PartialD]\^2 \
f\/\[PartialD]x\^2 = 0\)]],
  "."
}], "NE2",
  CellTags->"(7.2.26)"],

Cell[TextData[{
  "This nonlinear  equation is a simplified model for the propagation of \
shock waves. Now ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " can be thought of as either the perturbed pressure or density of a gas \
due to a compressional wave, as seen in a frame moving with the linear wave \
speed.  The term proportional to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\)]],
  " describes diffusion of these quantities due to viscosity or thermal \
conduction, and the nonlinear term qualitatively describes a nonlinear \
increase in wave speed when the wave pressure is large. The equation also has \
application to other areas, such as the study of nonlinear patterns in \
traffic flow (see the exercises). \t"
}], "Text"],

Cell[TextData[{
  "\tA steady solution for ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " can be found using the same techniques as were used for the KdV equation. \
The solution travels to the right with speed ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  ", takes on one value, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(f\_\(-\[Infinity]\)\)\)\)]],
  ", at ",
  Cell[BoxData[
      \(TraditionalForm\`x = \ \(-\[Infinity]\)\)]],
  ", and takes a lower value, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(f\_\[Infinity]\)\)\)]],
  ", at ",
  Cell[BoxData[
      \(TraditionalForm\`x = \(+\[Infinity]\)\)]],
  ".  The form of the solution is"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(f(x, t)\), "=", 
          RowBox[{"v", " ", "-", " ", 
            RowBox[{
              FractionBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["f",
                      FontSlant->"Italic"]}]], "2"], 
              RowBox[{"tanh", "[", 
                RowBox[{
                  FractionBox[
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["f",
                          FontSlant->"Italic"]}]], \(4\ \[Chi]\)], \((x - 
                      v\ t)\)}], "]"}]}]}]}], TraditionalForm]]],
  ","
}], "NE2",
  CellTags->"(7.2.27)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["f",
                FontSlant->"Italic"]}]], " ", "=", 
          " ", \(f\_\(-\[Infinity]\) - f\_\[Infinity]\)}], 
        TraditionalForm]]],
  " is the jump in ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " across the shock (see the exercises). The speed ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " of the shock is related to ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(f\_\(-\[Infinity]\)\)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`f\_\[Infinity]\)]],
  " according to "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`v = \(1\/2\) \((f\_\(-\[Infinity]\) + 
              f\_\[Infinity])\)\)]],
  "."
}], "NE2",
  CellTags->"(7.2.28)"],

Cell[TextData[{
  "This relation between shock speed and the amplitude at ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PlusMinus]\[Infinity]\)\)]],
  " is called a ",
  StyleBox["Hugoniot relation",
    FontSlant->"Italic"],
  ". "
}], "Text",
  CellTags->"i:48"],

Cell[TextData[{
  "\tA typical shock solution is plotted in Cell ",
  ButtonBox["7.52",
    ButtonData:>"Cell 7.52",
    ButtonStyle->"Hyperlink"],
  ", in the co-moving frame. In this example, we assume that ",
  Cell[BoxData[
      \(TraditionalForm\`f\_\[Infinity] = 0\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[1/2\  - \ 1/2\ Tanh[x/4], {x, \(-20\), 20}, 
        AxesLabel \[Rule] {"\<(x- v t)\[CapitalDelta]f/\[Chi]\>", "\<f(x,t)/\
\[CapitalDelta]f\>"}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.52"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0238095 0.0147151 0.588631 [
[.02381 .00222 -9 -9 ]
[.02381 .00222 9 0 ]
[.2619 .00222 -9 -9 ]
[.2619 .00222 9 0 ]
[.7381 .00222 -6 -9 ]
[.7381 .00222 6 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[1.025 .01472 0 -6 ]
[1.025 .01472 76.1875 6 ]
[.4875 .13244 -18 -4.5 ]
[.4875 .13244 0 4.5 ]
[.4875 .25017 -18 -4.5 ]
[.4875 .25017 0 4.5 ]
[.4875 .36789 -18 -4.5 ]
[.4875 .36789 0 4.5 ]
[.4875 .48562 -18 -4.5 ]
[.4875 .48562 0 4.5 ]
[.4875 .60335 -6 -4.5 ]
[.4875 .60335 0 4.5 ]
[.5 .64303 -29 0 ]
[.5 .64303 29 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02097 L
s
[(-20)] .02381 .00222 0 1 Mshowa
.2619 .01472 m
.2619 .02097 L
s
[(-10)] .2619 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(10)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(20)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(H) show
69.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
99.000 13.000 moveto
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(L) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
123.000 13.000 moveto
(\\220) show
129.188 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
135.188 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .13244 m
.50625 .13244 L
s
[(0.2)] .4875 .13244 1 0 Mshowa
.5 .25017 m
.50625 .25017 L
s
[(0.4)] .4875 .25017 1 0 Mshowa
.5 .36789 m
.50625 .36789 L
s
[(0.6)] .4875 .36789 1 0 Mshowa
.5 .48562 m
.50625 .48562 L
s
[(0.8)] .4875 .48562 1 0 Mshowa
.5 .60335 m
.50625 .60335 L
s
[(1)] .4875 .60335 1 0 Mshowa
.125 Mabswid
.5 .04415 m
.50375 .04415 L
s
.5 .07358 m
.50375 .07358 L
s
.5 .10301 m
.50375 .10301 L
s
.5 .16187 m
.50375 .16187 L
s
.5 .1913 m
.50375 .1913 L
s
.5 .22074 m
.50375 .22074 L
s
.5 .2796 m
.50375 .2796 L
s
.5 .30903 m
.50375 .30903 L
s
.5 .33846 m
.50375 .33846 L
s
.5 .39732 m
.50375 .39732 L
s
.5 .42676 m
.50375 .42676 L
s
.5 .45619 m
.50375 .45619 L
s
.5 .51505 m
.50375 .51505 L
s
.5 .54448 m
.50375 .54448 L
s
.5 .57391 m
.50375 .57391 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(H) show
75.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(L) show
99.000 13.000 moveto
(\\220) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.03279 .60331 L
.04262 .60331 L
.06244 .60329 L
.07298 .60327 L
.08426 .60325 L
.10458 .6032 L
.1148 .60317 L
.12589 .60312 L
.13547 .60307 L
.14603 .603 L
.16586 .60282 L
.17672 .60268 L
.18689 .60253 L
.19727 .60233 L
.20714 .60209 L
.22566 .6015 L
.23525 .60109 L
.24547 .60055 L
.26386 .59924 L
.27414 .59826 L
.28527 .59694 L
.29488 .59552 L
.30544 .59361 L
.32538 .58868 L
.33627 .58503 L
.34644 .58083 L
.35689 .57557 L
.36679 .56952 L
.38535 .55473 L
.40526 .53253 L
.42368 .50469 L
.44234 .46822 L
.46295 .41809 L
.50315 .2993 L
.54184 .18746 L
.56148 .14165 L
.58298 .10242 L
.6035 .07484 L
.6226 .05638 L
.63312 .0486 L
.64306 .04252 L
.66165 .03383 L
.67137 .03039 L
.68166 .02741 L
.70011 .02339 L
.70955 .02185 L
.71969 .0205 L
.738 .01866 L
.74813 .01791 L
Mistroke
.75917 .01725 L
.76972 .01675 L
.77928 .01638 L
.79899 .01582 L
.8098 .01559 L
.81997 .01542 L
.82976 .01529 L
.84009 .01518 L
.85858 .01503 L
.86808 .01497 L
.87825 .01492 L
.8966 .01486 L
.9068 .01483 L
.91788 .01481 L
.92746 .01479 L
.93801 .01477 L
.95654 .01476 L
.96668 .01475 L
.97619 .01474 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`002?ooool5o`0000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0`ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kVSooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^;oooool5o`0000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Wooooo`002?ooool01OnHV9So8B4Qonk^k_ooooooA4A4
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0booooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`1Zooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0_ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
06Oooooo0006o`0000?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@
02Oooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@401Z
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400`ooooo`03oiRHV?lQ
8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@401Wooooo`002_ooool00onHV9So8B4Qonk^
kP03ooooo`05o`000?ooooooooooooooool00000<_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000J_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000<Oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool00000Ioooool0
00_ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000003;ooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000006[ooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000003;ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooo
oooooooooooo000006Oooooo000<ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`0`ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@401Zoooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400cooooo`05o`000?oooooo
ooooooooool@41000oooool00ol@413oooooooooo`1Uooooo`002?ooool01Ol0003o^[ZjoooooonH
V9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0booooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`1Zooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0_ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonH
V9SoMgMg06Oooooo0008ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^033ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^06So
oooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02oooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0Ioooool00?oooooo4?ooool0
0omgMgOoIVIVooooo`0]ooooo`03ofIVI_mgMgOooooo01[ooooo00GoEEEEoiRHV?ooooooooooolc<
c002o`000003oiRHV?oooooooooo00;ooooo0023ooooo`03o`000?oooooooooo08Sooooo00?ogMgM
oa0@4?o^k^h0;_ooool00oo^k^ko410@omgMg@0Eooooo`03ob4Q8OoMgMgooooo00?ooooo00GoEEEE
oiRHV?ooooooEEEEohN7Q`06ooooo`00Poooool00ol0003oooooooooo`28ooooo`04oeEEEOnHV9So
ooooooooo`;o00000_ooool2o`0001?ooooo00?o8B4Qoc8b<_ooool02oooool01OnHV9So0000o`00
0?m4A4Co^[Zj00;ooooo00?oQhN7ofIVI_ooool00oooool00olb<S;o0000o`000003o`000004oc8b
<_oooooooooooa0@40Co000000Go410@ooooooooooooV9RHoeEEE@04ooooo`05onk^k_lb<S;oc<c<
ob4Q8Oo<c<`01_ooool008?ooooo00?o0000ooooooooool0R?ooool02_l0003ooooooooooooooooo
k^k^ob4Q8On7QhOo^[Zjo`000?oMgMdBooooo`04oiRHV?lb<S;o410@okZj^P_ooooo00Go410@okZj
^_o^k^koMgMgoa0@4002ooooo`03onk^k_l0003ooooo00?ooooo00?oV9RHodA4A?ooool00_ooool0
0om4A4CoV9RHooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000omgMgOooool00oooool0
0oo^k^ko<S8bo`000007ooooo`001Oooooomo`0000cooooo00?o<S8booooooooool00_ooool01?oM
gMgo0000oa0@4?o<c<`3ooooo`Ko00002_ooool01?l@413o^[ZjoiRHV?lb<S8;ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00oooool01Ol@413ogMgMoooooooMgMgo410@00Gooooo
00?o0000ooooooooool01?ooool2ogMgM`Gooooo00?oZJVYoa0@4?o^k^h01_ooool000_ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo4ol0
0007ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo013ooooo00?o<S8booooooooool00_ooool01?o^k^ko8B4Qoa0@
4?o^k^hBooooo`06oiRHV?lb<S;oooooooooool@413o^[Zj2_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00?ooooo00GoQhN7ogMgMoooooooIVIVohN7Q`05ooooo`03o`000?oooooo
oooo00Cooooo00?ok^k^oa0@4?o^k^h01?ooool01?mgMgOoA4A4oc8b<_o^k^h5ooooo`002oooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0;Oooool:
o`0000;ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0@ooooo`03o`000?o^k^ko
oooo00;ooooo00Co8B4QogMgMomgMgOo<S8b4Oooool00oo^k^ko0000omgMg@02ooooo`03oiRHV?lb
<S;ooooo00Wooooo00?o0000ooooooooool01?ooool00oo^k^ko0000ooooo`04ooooo`05onk^k_l@
413ok^k^oa0@4?o^k^h01Oooool00ol0003oooooooooo`05ooooo`03oeEEEOnHV9Sooooo00?ooooo
00Co<S8bojVYZOnHV9SoEEEE1Oooool008?ooooo00?o0000ooooooooool0:_ooool3o`0005_ooooo
00CoEEEEogMgMooooooooooo0_l00002ooooo`;o00004?ooool00ol@413o0000o`000002ooooo`?o
00001oooool00ol@413o0000o`000003o`0000?ooooo00?oMgMgoeEEEOooool01Oooool00omgMgOo
8B4QoeEEE@04ooooo`03oa0@4?l0003o000000?o00001?ooool02ooMgMgo410@oooooooooooo<S8b
o`000?lQ8B7ok^k^oooooonHV9SoEEEE00Cooooo0023ooooo`03o`000?oooooooooo02Oooooo0ol0
001Nooooo`03omgMgOl@413ok^k^02Sooooo00?o0000ooooooooool00oooool00oo^k^ko410@omgM
g@06ooooo`03omgMgOl0003ogMgM00Kooooo00?o0000ooooooooool01_ooool00omEEEGoV9RHoooo
o`0;ooooo`00Poooool00ol0003oooooooooo`0Uooooo`;o0000H_ooool00omgMgOoIVIVooooo`0W
ooooo`03o`000?oooooooooo00?ooooo00?oIVIVogMgMoooool01oooool00onYZJWoooooooooo`05
ooooo`03oa0@4?nj^[[ooooo00Kooooo00?o^[ZjodA4A?ooool02oooool008?ooooo00?o0000oooo
ooooool08_ooool3o`000:Kooooo00Co^[Zjoa0@4?l0003o410@4oooool008?ooooo00?o0000oooo
ooooool08?ooool2o`000<3ooooo0023ooooo`;o00008?ooool00ol0003oooooooooo`30ooooo`00
Poooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo0<7ooooo0023ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool0`_ooool008?ooooo00?o0000ooooooooool06oooool2
o`000<Gooooo0023ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0aOooool008?o
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`36ooooo`00Poooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo0<Oooooo0023ooooo`;o00006?ooool00ol0003ooooooooo
o`38ooooo`00Poooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0<Sooooo0023oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0bOooool008?ooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`3:ooooo`00Poooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo0<_ooooo0023ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0booo
ool008?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`3<ooooo`00Poooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo0<gooooo0023ooooo`;o00004oooool00ol0003o
ooooooooo`3=ooooo`00Poooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo0<kooooo
0023ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0coooool008?ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`3?ooooo`00JOooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`Go00001Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo0=3ooooo001Yooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0d?oo
ool006Wooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`3Aooooo`00JOooool01Ol0003ooooooooooooo
oooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool2o`0000kooooo00?o0000ooooooooool0d_oo
ool006Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`3Booooo`00JOooool01Ol@413ooooooooooooo
oooo410@00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo0=?ooooo001Yooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooo
oonHV9So410@00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`3Cooooo`00JOoo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0e?ooool008?ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`3Dooooo`00Poooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo0=Cooooo0023ooooo`;o00002oooool00ol0003oooooooooo`3Eooooo`00Poooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo0=Gooooo0023ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0e_ooool008?ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`3Fooooo`00Poooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0=Oooooo0023
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0eoooool008?ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`3Gooooo`00Poooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0=Sooooo0023ooooo`;o00002?ooool00ol0003oooooooooo`3Hooooo`00Pooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0=Sooooo0023ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0fOooool008?ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`3Iooooo`00Poooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0=Wo
oooo0023ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0f_ooool008?ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`3Jooooo`00Poooool2o`0000Kooooo00?o0000
ooooooooool0f_ooool008?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3Koooo
o`00Poooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0=_ooooo0023ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0foooool008?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`3Looooo`00JOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B46ooooo`;o000000?o410@ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo0=cooooo001Yooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0=cooooo001Y
ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`3Mooooo`00JOooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00001_ooool2o`0000?ooooo00?o0000ooooooooool0gOooool006Wooooo00Go
0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`3Mooooo`00JOooool01Ol@413ooooooooooooooooo410@00co
oooo00?oMgMgolc<c?l000001_ooool01Ol0003ooooooooooooooooo00000>3ooooo001Yooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000006ooooo`05o`000?oooooooooo
ooooool00000h?ooool006Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003o
oooo00Gooooo00Go0000ooooooooooooooooo`00003Pooooo`00Poooool01?l0003oooooooooool0
003Qooooo`00Poooool01?l0003oooooooooool0003Qooooo`00Poooool2o`000003ooooool0003o
oooo0>3ooooo0023ooooo`03o`000?oooooo00000>;ooooo0023ooooo`03o`000?oooooo00000>;o
oooo0023ooooo`03o`000?oooooo00000>;ooooo0023ooooo`;o0000hoooool008?ooooo0_l0003S
ooooo`00Poooool2o`000>?ooooo0023ooooo`03o`000?oooooooooo0>;ooooo0023ooooo`;o0000
hoooool008?ooooo00?o0000ooooooooool0h_ooool008;ooooo0_l0003Tooooo`00P_ooool2o`00
0>Cooooo0022ooooo`;o0000i?ooool0087ooooo00?o0000ooooool00000i?ooool0087ooooo00?o
0000ooooool00000i?ooool0087ooooo00Co0000ooooool0003o0000hoooool0083ooooo00Co0000
oooooooooooo0000i?ooool0083ooooo00Co0000oooooooooooo0000i?ooool0083ooooo00Co0000
oooooooooooo0000i?ooool007oooooo00Go0000ooooooooooooooooo`00003Tooooo`00JOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`07onk^k_lb<S;o0000oa0@4?o<c<co
ooooo`000003ooooo`03o`000?oooooooooo0>;ooooo001Yooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00OoEEEEogMgMoooooooV9RHob4Q8Ooooooo000000?ooooo00?o0000
ooooooooool0h_ooool006Wooooo00Go410@oooooooooooooooooa0@400;ooooo`04o`000?oooooo
ooooooooo`;o00001?ooool2o`000>?ooooo001Yooooo`05o`000?ooooooooooooooool000002ooo
ool01_l0003oV9RHoooooonHV9So8B4Qo`0000Cooooo00?o0000ooooooooool0h_ooool006Wooooo
00Go0000ooooooooooooooooo`00000;ooooo`06o`000?mEEEGo0000oa0@4?o<c<co00001?ooool0
0ol0003oooooooooo`3Rooooo`00JOooool01Ol@413ooooooooooooooooo410@00_ooooo00GoEEEE
ohN7Qoooooooooooo`000005ooooo`03o`000?oooooooooo0>;ooooo001Yooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01OoMgMgo410@oiRHV?oooooo000000Gooooo00?o0000ooooooooool0
h_ooool006Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000o`0000Go
oooo00?o0000ooooooooool0h_ooool007cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3Rooooo`00O?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0>;ooooo001l
ooooo`03o`000?oooooooooo00Cooooo0_l0003Sooooo`00Noooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0>;ooooo001kooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0h_ooool007_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3Rooooo`00N_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0>;ooooo001jooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0h_ooool007[ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`3Rooooo`00NOooool00ol0003oooooooooo`07ooooo`;o0000hoooool007Wooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`3Rooooo`00N?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo0>;ooooo001hooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0h_ooool007Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`3Roooo
o`00Moooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0>;ooooo001gooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0h_ooool007Kooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`3Rooooo`00M_ooool00ol0003oooooooooo`0:ooooo`;o0000hoooool0
07Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`3Rooooo`00MOooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo0>;ooooo001dooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0h_ooool007Cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`3Rooooo`00JOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ob4Q8Oooool00ooo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Gooooo00?o0000ooooooooool0h_ooool006Wooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?lQ8B7ooooo00?ooooo00Go8B4QoiRHV?oooooo
V9RHob4Q8@05ooooo`03o`000?oooooooooo0>;ooooo001Yooooo`05oa0@4?ooooooooooooooool@
41001?ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001Oooool2o`00
0>?ooooo001Yooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`04oooo
o`05oc8b<_nHV9SooooooiRHV?lb<S801Oooool00ol0003oooooooooo`3Rooooo`00JOooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ooooooooool01?ooool01Oo<c<co0000o`000?l0
003oc<c<00Gooooo00?o0000ooooooooool0h_ooool006Wooooo00Go410@oooooooooooooooooa0@
4003ooooo`03o`000?oooooooooo00Gooooo00Go410@okZj^_oooooo^[Zjoa0@4005ooooo`03o`00
0?oooooooooo0>;ooooo001Yooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool00ol0003ooooo
ooooo`05ooooo`05o`000?nj^[[ooooookZj^_l000001Oooool00ol0003oooooooooo`3Rooooo`00
JOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo00?o0000ooooooooool01_ooool01OnYZJWo
410@o`000?l@413oZJVY00Gooooo00?o0000ooooooooool0h_ooool0073ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`3Rooooo`00Koooool00ol0003oooooooooo`0Aooooo`;o0000
hoooool006kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`3Rooooo`00KOooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo0>;ooooo001]ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0h_ooool006cooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`3Rooooo`00Joooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0>;ooooo
001Zooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0h_ooool006Wooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`3Rooooo`00J?ooool00ol0003oooooooooo`0Hoooo
o`;o0000hoooool006Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`3Rooooo`00
IOooool2o`0001cooooo00?o0000ooooooooool0h_ooool006Cooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`3Rooooo`00Hoooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo0>;ooooo001Rooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0h_ooool0067o
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`3Rooooo`00H?ooool00ol0003ooooo
ooooo`0Pooooo`;o0000hoooool005kooooo0_l0000Sooooo`03o`000?oooooooooo0>;ooooo001K
ooooo`?o00009Oooool00ol0003oooooooooo`3Rooooo`00FOooool2o`0002Sooooo00?o0000oooo
ooooool0h_ooool005Gooooo1?l0000Zooooo`03o`000?oooooooooo0>;ooooo001Aooooo`Co0000
9Oooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0h_ooool004Wooooo2?l0
000[ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0h_ooool003Kooooo4ol0000c
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0h_ooool000_ooooo:ol00016oooo
o`03o`000?oooooooooo00Cooooo0_l0003Sooooo`00O?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo0>;ooooo001looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
h_ooool007cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3Rooooo`00N_ooool0
0omEEEGoIVIVo`00003[ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00K_ooool00omgMgOoIVIV
ooooo`09ooooo`03o`000?nj^[[ooooo00_ooooo00?oIVIVogMgMoooool0gOooool006gooooo00?o
gMgMoa0@4?o^k^h02_ooool2oc8b<Pcooooo00?ok^k^oa0@4?oMgMd01Oooool00olQ8B7ogMgMoooo
o`3Eooooo`00H_ooool00ol@413o0000o`000002o`000003oa0@4?oooooooooo00?ooooo00CoEEEE
oiRHV?oooooooooo0_l00002ooooo`;o00000oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0
003o0000odA4A?nj^[X00oooool00on7QhOoIVIVooooo`04ooooo`03oiRHV?mEEEGooooo00?ooooo
00?o<S8bo`000?l000000ol000001?lb<S;oooooooooool@4104o`000003oa0@4?oooooooooo0<7o
oooo001Tooooo`03o`000?oooooooooo00Kooooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7
okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@4100
0oooool00oo^k^ko0000ooooo`05ooooo`03o`000?oMgMgooooo00;ooooo00?oV9RHodA4A?ooool0
0_ooool00om4A4CoV9RHooooo`03ooooo`03o`000?oooooooooo0<Cooooo001Tooooo`03o`000?oo
oooooooo00Kooooo00?o<S8booooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01?ooool2ogMgM`Cooooo00Go410@omgMgOoooooo
gMgMoa0@4005ooooo`03o`000?oooooooooo0<Cooooo001Tooooo`03o`000?oooooooooo00Kooooo
00?o<S8booooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01?ooool00oo^k^ko410@onk^kP03ooooo`05ohN7QomgMgOoooooofIV
I_n7QhL01Oooool00ol0003oooooooooo`34ooooo`00I?ooool00ol0003oooooooooo`06ooooo`03
o`000?o^k^kooooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`05oooo
o`03onk^k_l0003ooooo00Kooooo00?oEEEEoiRHV?ooool00_ooool01Oo^k^ko410@onk^k_l@413o
k^k^00Gooooo00?o0000ooooooooool0a?ooool006;ooooo00?o410@o`000?l000000ol00005oooo
o`04oeEEEOmgMgOoooooooooo`;o00000_ooool2o`0000Sooooo00?o410@o`000?l000000ol00004
ooooo`03ogMgMomEEEGooooo00Kooooo00?ogMgMoa0@4?ooool00oooool00omgMgOo8B4QoeEEE@04
ooooo`03oa0@4?l0003o000000?o0000`oooool006Cooooo00?o0000ooooooooool01_ooool00ooM
gMgo410@onk^kP0Aooooo`03o`000?oooooooooo00Cooooo00?ok^k^oa0@4?oMgMd02?ooool00omE
EEGoV9RHooooo`02ooooo`03omgMgOl0003ogMgM00Kooooo00?o0000ooooooooool0a?ooool006Co
oooo00?o410@okZj^_ooool01oooool00omgMgOoIVIVooooo`0@ooooo`03o`000?oooooooooo00Co
oooo00?oIVIVogMgMoooool02?ooool00onj^[[oA4A4ooooo`03ooooo`03ojVYZOoooooooooo00Go
oooo00?o410@okZj^_ooool0a?ooool006Cooooo00Co^[Zjoa0@4?l0003o410@>Oooool01?nj^[[o
410@o`000?l@4133ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-21.8736, -0.209845, \
0.208158, 0.00841976}}]
}, Open  ]],

Cell[TextData[{
  "According to Eq. ",
  ButtonBox["(7.2.27)",
    ButtonData:>{"Chapter7.nb", "(7.2.27)"},
    ButtonStyle->"Hyperlink"],
  "  the width of the shock depends on the diffusivity ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\)]],
  " and on the jump ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["f",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ", scaling roughly as ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Chi]", "/", 
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["f",
                FontSlant->"Italic"]}]]}], TraditionalForm]]],
  ". The smaller the value of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\)]],
  ", or the larger the jump, the narrower the shock. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["CTCS/Crank-Nicolson approach", "Section",
  CellTags->"c:25"],

Cell[TextData[{
  "For numerical solutions of Burgers' equation,  the Galerkin method used in \
Sec. ",
  ButtonBox["7.2.3",
    ButtonData:>"c:18",
    ButtonStyle->"Hyperlink"],
  " for the KdV equation can be easily adapted. This is left to the \
exercises. Here, we will instead use a grid method, for practice. We solve \
the problem under periodic boundary conditions on ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] \ x < L\)]],
  " and take ",
  Cell[BoxData[
      FormBox[
        RowBox[{"x", "=", 
          RowBox[{"j", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`j = 0, 1, 2,  ... , M - 1\)]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], " ", "=", " ", \(L/M\)}], 
        TraditionalForm]]],
  ", and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"t", "=", 
          RowBox[{"n", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  ". "
}], "Text",
  CellTags->"i:75"],

Cell[TextData[{
  "\tThe first two terms of Eq. ",
  ButtonBox["(7.2.26)",
    ButtonData:>{"Chapter7.nb", "(7.2.26)"},
    ButtonStyle->"Hyperlink"],
  "  are of the form of the wave equation ",
  ButtonBox["(7.1.30)",
    ButtonData:>{"Chapter7.nb", "(7.1.30)"},
    ButtonStyle->"Hyperlink"],
  " , and hence we expect that the CTCS method will work for these terms. The \
equation is nonlinear, which hinders von Neuman stability analysis, but if we \
replace ",
  Cell[BoxData[
      \(TraditionalForm\`f \[PartialD]f/\[PartialD]x\)]],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`c \[PartialD]f/\[PartialD]x\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " is a constant,  then one can show that the CTCS method is stable provided \
that time step that satisfies the Courant condition ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"c", " ", 
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], "/", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]]}]}], "\[LessEqual]", " ", "1"}], 
        TraditionalForm]]],
  " [see Eq. ",
  ButtonBox["(6.2.44)",
    ButtonData:>{"Chapter6.nb", "(6.2.44)"},
    ButtonStyle->"Hyperlink"],
  " ].  Thus, we might hope that if ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]], "\[LessEqual]", " ", 
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]], "/", "max"}]}], "|", "f", "|"}], 
        TraditionalForm]]],
  ", the CTCS method will be stable. Actually, it  turns out that sharp \
gradients in ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " can also destabilize the method, but for sufficiently small time step \
this method works well. "
}], "Text"],

Cell[TextData[{
  "\tHowever, the last term in Eq. ",
  ButtonBox["(7.2.26)",
    ButtonData:>{"Chapter7.nb", "(7.2.26)"},
    ButtonStyle->"Hyperlink"],
  "  is diffusive, which (as we saw in Sec. ",
  ButtonBox["6.2.1",
    ButtonData:>{"Chapter6.nb", "c:17"},
    ButtonStyle->"Hyperlink"],
  ") causes instability in the CTCS method. For the diffusion term we \
therefore use a variant of  the Crank-Nicolson scheme, taking the average of \
the diffusion operator at two time steps centered around time step ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ". The resulting difference equation is given below: "
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FractionBox[\(f\_j\%\(n + 1\) - f\_j\%\(n - 1\)\), 
              RowBox[{"2", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["t",
                      FontSlant->"Italic"]}]]}]], "+", 
            RowBox[{\(f\_j\%n\), 
              FractionBox[\(f\_\(j + 1\)\%n - f\_\(j - 1\)\%n\), 
                RowBox[{"2", 
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]]}]]}], "-", 
            RowBox[{\(\[Chi]\/2\), 
              RowBox[{"(", 
                RowBox[{
                  
                  FractionBox[\(f\_\(j + 1\)\%\(n + 1\) - 
                      2  f\_j\%\(n + 1\) + f\_\(j - 1\)\%\(n + 1\)\), 
                    SuperscriptBox[
                      StyleBox[
                        RowBox[{"\[CapitalDelta]", 
                          StyleBox["x",
                            FontSlant->"Italic"]}]], "2"]], "+", 
                  
                  FractionBox[\(f\_\(j + 1\)\%\(n - 1\) - 
                      2  f\_j\%\(n - 1\) + f\_\(j - 1\)\%\(n - 1\)\), 
                    SuperscriptBox[
                      StyleBox[
                        RowBox[{"\[CapitalDelta]", 
                          StyleBox["x",
                            FontSlant->"Italic"]}]], "2"]]}], ")"}]}]}], 
          "=", \(S\_j\%n\)}], TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(7.2.29)"],

Cell[TextData[{
  "For future reference, note that we have added a finite-differenced source \
function ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          FormBox[\(S(x, t)\),
            "TraditionalForm"]}], TraditionalForm]]],
  " to the ",
  "right-hand",
  " side of the equation. "
}], "Text"],

Cell[TextData[{
  "Equation ",
  ButtonBox["(7.2.29)",
    ButtonData:>{"Chapter7.nb", "(7.2.29)"},
    ButtonStyle->"Hyperlink"],
  "  is an implicit method. To solve it, we could apply  the Crank-Nicholson \
algorithm that we used in Sec. ",
  ButtonBox["6.2.1",
    ButtonData:>{"Chapter6.nb", "c:19"},
    ButtonStyle->"Hyperlink"],
  ", but instead we will write the procedure in a different way, using a form \
of operator splitting that we haven't seen before.   First, we set up the \
grid and choose values for ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\)]],
  ":"
}], "Text"],

Cell[BoxData[{
    \(\(Clear["\<Global`*\>"];\)\), "\[IndentingNewLine]", 
    \(M = 40; 
    L = 4; \[CapitalDelta]x\  = \ L/M; \[CapitalDelta]t\  = \ 0.03; \[Chi] = 
      0.1;\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.53"],

Cell[TextData[{
  "Next, in order to simplify notation, we split the operator, first taking \
the CTCS step and keeping that part of the Crank-Nicolson diffusion operator \
that depends on previous times.  We place the result in an intermediate array \
",
  Cell[BoxData[
      \(TraditionalForm\`F\)]],
  ":"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(F\_j\%\(n + 1\)\), "=", 
          RowBox[{\(f\_j\%\(n - 1\)\), "-", 
            RowBox[{"2", "\[CapitalDelta]t", " ", \(f\_j\%n\), 
              FractionBox[\(f\_\(j + 1\)\%n - f\_\(j - 1\)\%n\), 
                RowBox[{"2", 
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]]}]]}], "+", 
            RowBox[{"\[Chi]", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], 
              StyleBox[" ",
                FontSlant->"Italic"], 
              RowBox[{
                StyleBox[\(d\_2\),
                  FontSlant->"Italic"], 
                StyleBox["(",
                  FontSlant->"Italic"], 
                RowBox[{
                  StyleBox["f",
                    FontSlant->"Italic"], 
                  StyleBox[",",
                    FontSlant->"Italic"], "j", ",", \(n - 1\)}], 
                StyleBox[")",
                  FontSlant->"Italic"]}]}], "+", " ", 
            RowBox[{"2", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], " ", \(S\_j\%n\)}]}]}], 
        TraditionalForm]]],
  ","
}], "NE2",
  CellTags->"(7.2.30)"],

Cell[TextData[{
  "where we have introduced a finite-difference operator ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(d\_2\)(f, j, n)\), "=", 
          FractionBox[\(f\_\(j + 1\)\%n - 2  f\_j\%n + f\_\(j - 1\)\%n\), 
            SuperscriptBox[
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]], "2"]]}], TraditionalForm]]],
  " in order to further simply the notation. Defined as a recursion relation, \
the ",
  "left-hand",
  " side of Eq. ",
  ButtonBox["(7.2.30)",
    ButtonData:>{"Chapter7.nb", "(7.2.30)"},
    ButtonStyle->"Hyperlink"],
  "  must be evaluated at time step ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " rather than ",
  Cell[BoxData[
      \(TraditionalForm\`n + 1\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(F[j_, n_]\  := \ 
      f[j, n - 2]\  - \ \[CapitalDelta]t \( f[j, 
                n - 1]\/\(\(\ \)\(\[CapitalDelta]x\)\)\) \((f[j + 1, n - 1] - 
              f[j - 1, n - 1])\) + \ \[Chi]\ \[CapitalDelta]t\ d2[f, j, 
            n - 2]\  + \ 2\ \[CapitalDelta]t\ S[j, n - 1]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.54"],

Cell[BoxData[
    \(d2[f_, j_, 
        n_]\  := \ \(f[j + 1, n] - 2  f[j, n] + f[j - 1, \
n]\)\/\[CapitalDelta]x\^2\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.55"],

Cell[TextData[{
  "We then solve coupled equations for ",
  Cell[BoxData[
      \(TraditionalForm\`f\_j\%\(n + 1\)\)]],
  " according to"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(f\_j\%\(n + 1\)\), "=", 
          RowBox[{\(F\_j\%\(n + 1\)\), "+", 
            RowBox[{"\[Chi]", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], 
              " ", \(\(d\_2\)(f, j, n + 1)\)}]}]}], TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(7.2.31)"],

Cell[TextData[{
  "Equations  ",
  ButtonBox["(7.2.30)",
    ButtonData:>{"Chapter7.nb", "(7.2.30)"},
    ButtonStyle->"Hyperlink"],
  "  and ",
  ButtonBox["(7.2.31)",
    ButtonData:>{"Chapter7.nb", "(7.2.31)"},
    ButtonStyle->"Hyperlink"],
  "  are identical to Eq.  ",
  ButtonBox["(7.2.29)",
    ButtonData:>{"Chapter7.nb", "(7.2.29)"},
    ButtonStyle->"Hyperlink"],
  " . Note that this form of operator splitting differs in concept from that \
used previously in Eqs. ",
  ButtonBox["(6.2.31)",
    ButtonData:>{"Chapter6.nb", "(6.2.31)"},
    ButtonStyle->"Hyperlink"],
  " . There, different forms of the ",
  StyleBox["full",
    FontSlant->"Italic"],
  " operator were used in two substeps of size ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], "/", "2"}], TraditionalForm]]],
  " . Here,  the full ",
  "time step",
  " ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " is taken for each substep, but only ",
  StyleBox["pieces",
    FontSlant->"Italic"],
  " of the operator are used in each."
}], "Text",
  CellTags->"i:79"],

Cell[TextData[{
  "\tTo solve Eq. ",
  ButtonBox["(7.2.31)",
    ButtonData:>{"Chapter7.nb", "(7.2.31)"},
    ButtonStyle->"Hyperlink"],
  "  we introduce dummy variables ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_j\%n\)]],
  " to replace ",
  Cell[BoxData[
      \(TraditionalForm\`f\_j\%n\)]],
  ". The reason is that the equations in ",
  StyleBox["Solve ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "must be in terms of unknown quantities, but the ",
  Cell[BoxData[
      \(TraditionalForm\`f\_j\%n\)]],
  "'s are determined recursively by the procedure and so are not unknown \
variables. After the equations are solved for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_j\%n\)]],
  ", we use these values to update ",
  Cell[BoxData[
      \(TraditionalForm\`f\_j\%n\)]],
  "."
}], "Text"],

Cell["\tThe variables used in the equations are ", "Text"],

Cell[BoxData[
    \(\(vars[n_]\  = \ \ Table[\[Rho][j, n], {j, 0, M - 1}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.56"],

Cell[TextData[{
  "In these variables, Eq. ",
  ButtonBox["(7.2.31)",
    ButtonData:>{"Chapter7.nb", "(7.2.31)"},
    ButtonStyle->"Hyperlink"],
  "  becomes a list of equations:"
}], "Text"],

Cell[BoxData[
    \(\(eqns[n_]\  := \ 
        Table[\[Rho][j, 
              n]\  == \ \ F[j, 
                n]\  + \ \[Chi]\ \[CapitalDelta]t\ d2[\[Rho], j, n], {j, 0, 
            M - 1}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.57"],

Cell[TextData[{
  "Now we solve these equations (once) at the ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{
            StyleBox["n",
              FontSlant->"Italic"], "th"}]], TraditionalForm]]],
  " step:"
}], "Text"],

Cell[BoxData[
    \(varsn[
        n_]\  := \(varsn[
          n]\  = \ \ vars[
            n] /. \(Solve[eqns[n], vars[n]]\)[\([1]\)]\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.58"],

Cell[TextData[{
  "Then we substitute the results into ",
  Cell[BoxData[
      \(TraditionalForm\`f\_j\%n\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(f[j_, n_]\  := \((f[j, n]\  = \(varsn[n]\)[\([j + 1]\)])\) /; \ 
        n > 1\  && \ 0 \[LessEqual] \ j \[LessEqual] \ M - 1\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.59"],

Cell[TextData[{
  "Since we will solve for points on the grid from ",
  Cell[BoxData[
      \(TraditionalForm\`j = 0\)]],
  " up to ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(M - 1\)\(,\)\)\)]],
  " the above equations will require values for points ",
  Cell[BoxData[
      \(TraditionalForm\`j = \(-1\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`j = M\)]],
  ".  According to the periodic boundary conditions, these points are \
equivalent to ",
  Cell[BoxData[
      \(TraditionalForm\`j = M - 1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`j = 0\)]],
  " respectively. Boundary conditions for both ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " and the dummy variable ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " must be specified:"
}], "Text"],

Cell[BoxData[{
    \(\(\[Rho][\(-1\), n_]\  := \ \[Rho][M - 1, n];\)\), "\n", 
    \(\(\[Rho][M, n_]\  := \[Rho][0, n];\)\ \), "\n", 
    \(\(f[\(-1\), n_]\  := \ f[M - 1, n];\)\), "\n", 
    \(\(f[M, n_]\  := f[0, n];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.60"],

Cell[TextData[{
  "Also, the first time step must be treated differently, since in the CTCS \
step ",
  Cell[BoxData[
      \(TraditionalForm\`n = 1\)]],
  " calls ",
  Cell[BoxData[
      \(TraditionalForm\`n = \(-1\)\)]],
  ". The simplest approach is to apply FTCS to the equation for this one time \
step. This is only first -order accurate in ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ", but that is sufficient to our needs here. A second-order scheme \
involving the predictor-corrector method is discussed in the exercises. Here \
we take"
}], "Text"],

Cell[BoxData[
    \(f[j_, 
        1]\  := \(f[j, 
          1]\  = \ \ f[j, 
            0] - \ \[CapitalDelta]t\ f[j, 
              0] \(f[j + 1, 0] - f[j - 1, 0]\)\/\(\(\ \
\)\(\[CapitalDelta]x\)\) + \ \[Chi]\ \[CapitalDelta]t\ d2[f, j, 
              0]\  + \ \[CapitalDelta]t\ S[j, 0]\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.61"],

Cell[TextData[{
  "For the source, we take ",
  Cell[BoxData[
      \(TraditionalForm\`S = 0\)]],
  ","
}], "Text"],

Cell[BoxData[
    \(\(S[j_, n_]\  = \ 0;\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.62"],

Cell[TextData[{
  " and  for the initial condition, we take a simple sine wave, offset from \
the origin so that it propagates to the right as shown in Cell ",
  ButtonBox["7.63",
    ButtonData:>"Cell 7.63",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(f[j_, 0]\  := 1 + Sin[j\ \[CapitalDelta]x\ Pi];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(Table[
        ListPlot[Table[{j\ \[CapitalDelta]x, f[j, n]}, {j, 0, M}], 
          PlotRange \[Rule] {0, 2}, 
          PlotLabel -> "\<t = \>" <> ToString\ [n\ \[CapitalDelta]t]], {n, 0, 
          80, 2}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.63"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .30902 Mdot
.04762 .40451 Mdot
.07143 .49065 Mdot
.09524 .55902 Mdot
.11905 .60291 Mdot
.14286 .61803 Mdot
.16667 .60291 Mdot
.19048 .55902 Mdot
.21429 .49065 Mdot
.2381 .40451 Mdot
.2619 .30902 Mdot
.28571 .21353 Mdot
.30952 .12738 Mdot
.33333 .05902 Mdot
.35714 .01512 Mdot
.38095 0 Mdot
.40476 .01512 Mdot
.42857 .05902 Mdot
.45238 .12738 Mdot
.47619 .21353 Mdot
.5 .30902 Mdot
.52381 .40451 Mdot
.54762 .49065 Mdot
.57143 .55902 Mdot
.59524 .60291 Mdot
.61905 .61803 Mdot
.64286 .60291 Mdot
.66667 .55902 Mdot
.69048 .49065 Mdot
.71429 .40451 Mdot
.7381 .30902 Mdot
.7619 .21353 Mdot
.78571 .12738 Mdot
.80952 .05902 Mdot
.83333 .01512 Mdot
.85714 0 Mdot
.88095 .01512 Mdot
.90476 .05902 Mdot
.92857 .12738 Mdot
.95238 .21353 Mdot
.97619 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool2o`0000Ko
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool01?ooool2o`0000Kooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo01Cooooo000`ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool05?ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`1Qooooo`;o00003Oooool2o`00083ooooo0_l0000<ooooo`;o0000<oooool0
033ooooo0_l0001Rooooo`;o00003Oooool2o`00083ooooo0_l0000<ooooo`;o0000<oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo05[ooooo0_l0000Kooooo`;o0000L_ooool2o`0001[ooooo0_l0
000/ooooo`00<?ooool2o`0005_ooooo0_l0000Kooooo`;o0000L_ooool2o`0001[ooooo0_l0000/
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`3oooooocKooooo000=ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo=_oo
ool000gooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o
MgMgoc8b<_ooool01?ooool3o`000?oooooo=_ooool000gooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo
000=ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006oooo
o`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`1Cooooo`;o0000:Oooool2o`0006?o
oooo0_l0000Zooooo`;o00009?ooool0033ooooo00?o0000ooooooooool0Doooool2o`0002Wooooo
0_l0001Sooooo`;o0000:_ooool2o`0002Cooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocKooooo000Eooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000Eooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolfooooo`005Oooool01Ol0003o
oooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooo
ocKooooo000Eooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000Eoooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0
003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo04cooooo0_l0000gooooo`;o0000
EOooool2o`0003Sooooo0_l0000Mooooo`00<?ooool2o`0004gooooo0_l0000gooooo`;o0000EOoo
ool2o`0003Sooooo0_l0000Mooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000Vooooo`Co0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`3oooooocKooooo000Xooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooolfooooo`00:?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?oooooo=_ooool002Sooooo00?o0000ooooooooool01?ooool4o`00
04Cooooo0_l00017ooooo`;o0000A_ooool2o`0004Kooooo0_l0000Fooooo`00:?ooool00ol0003o
ooooooooo`04ooooo`;o0000A_ooool2o`0004Oooooo0_l00016ooooo`;o0000A_ooool2o`0001Ko
oooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolfooooo`00:?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo=_ooool002Kooooo00?oEEEE
ofIVI_l000001oooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`003_ooool4o`000003oa0@4?oooooooooo00;o
oooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooo
ocKooooo000@ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003o
ooooooooo`03ooooo`?o0000oooooolfooooo`004?ooool00ol0003oooooooooo`0<ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo
000@ooooo`03o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`3oooooocKooooo000@ooooo`03o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@
4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolfooooo`003_ooool0
0omEEEGoIVIVo`00000<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0
003oooooocOooooo000`ooooo`03o`000?oooooooooo00?ooooo0_l0000hooooo`;o0000EOooool2
o`0003Sooooo0_l0001Uooooo`00<?ooool00ol0003oooooooooo`03ooooo`;o0000>?ooool2o`00
05Gooooo0_l0000hooooo`;o0000IOooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`005_ooool4
o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00Cooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`006?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooolfoooo
o`006?ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0003oooooocKo
oooo000Hooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool001Kooooo00?oEEEE
ofIVI_l000003Oooool4o`0000Kooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`00
0?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo00_ooooo0_l0000Yooooo`;o0000Hooo
ool2o`0002Wooooo0_l0001]ooooo`00<?ooool2o`0000cooooo0_l0000Yooooo`;o0000Hoooool2
o`0002Wooooo0_l0001]ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000>ooooo`Co
000000?o410@ooooooooool00_ooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003o
ooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0<ooooo`03ojVY
ZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool0013ooooo00?o
0000ooooooooool03Oooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0=ooooo`03oeEEEOo<c<co
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0013ooooo00?o0000ooooooooool03Oooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0:oooo
o`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0?oooooo=_ooool000kooooo00?oEEEEofIVI_l000003?ooool5o`0000Cooooo1?l00006oooo
o`;o00004oooool2o`0001_ooooo0_l0001aooooo`;o00006oooool2o`0007Cooooo000`ooooo`03
o`000?oooooooooo01;ooooo0_l0000Kooooo`;o0000LOooool2o`0001_ooooo0_l0001dooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0000Jooooo`;o00003?ooool2o`00083ooooo0_l0000=ooooo`;o0000Noooool0
033ooooo00?o0000ooooooooool06Oooool2o`0000cooooo0_l00020ooooo`;o00003Oooool2o`00
07_ooooo000Uooooo`Go00001_ooool00ol0003oooooooooo`3oooooocKooooo000Uooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`3oooooocKooooo000Vooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?o0000ooooooooool08?ooool2o`0008oooooo0_l00022ooooo`009ooo
ool00onHV9So8B4Qonk^kP06ooooo`?o00008?ooool2o`0008oooooo0_l00022ooooo`00:?ooool0
0omgMgOoIVIVooooo`3oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Go
oooo00Go0000okZj^_ooooooV9RHoa0@403oooooocoooooo000Uooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`0ooooooloooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00/?ooool0
1OnHV9So0000o`000?m4A4Co^[Zj01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP2Fooooo`00/?oo
ool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00009ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0U_ooool00;3ooooo00?o0000ooooooooool06_ooool01Ol@413ooooooooooooooooo410@09Ko
oooo002`ooooo`03o`000?oooooooooo00_ooooo1_l00009ooooo`05o`000?ooooooooooooooool0
0000U_ooool00;3ooooo00?o0000ooooooooool06_ooool01Ol0003ooooooooooooooooo000009Ko
oooo002^ooooo`03oa0@4?l0003o000000?o00006Oooool01Ol@413ooooooooooooooooo410@09Ko
oooo002`ooooo`03o`000?oooooooooo01[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`2Fooooo`00
/?ooool00ol0003oooooooooo`0Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0U_ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.06) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .27173 Mdot
.04762 .34835 Mdot
.07143 .41817 Mdot
.09524 .47786 Mdot
.11905 .52653 Mdot
.14286 .56351 Mdot
.16667 .58514 Mdot
.19048 .58368 Mdot
.21429 .55035 Mdot
.2381 .48134 Mdot
.2619 .38294 Mdot
.28571 .27126 Mdot
.30952 .16641 Mdot
.33333 .08487 Mdot
.35714 .03507 Mdot
.38095 .01789 Mdot
.40476 .03006 Mdot
.42857 .06702 Mdot
.45238 .12378 Mdot
.47619 .19439 Mdot
.5 .27173 Mdot
.52381 .34835 Mdot
.54762 .41817 Mdot
.57143 .47786 Mdot
.59524 .52653 Mdot
.61905 .56351 Mdot
.64286 .58514 Mdot
.66667 .58368 Mdot
.69048 .55035 Mdot
.71429 .48134 Mdot
.7381 .38294 Mdot
.7619 .27126 Mdot
.78571 .16641 Mdot
.80952 .08487 Mdot
.83333 .03507 Mdot
.85714 .01789 Mdot
.88095 .03006 Mdot
.90476 .06702 Mdot
.92857 .12378 Mdot
.95238 .19439 Mdot
.97619 .27173 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`0006Wooooo0_l0002?ooooo`;o0000>_ooool0033ooooo00?o0000oooooooo
ool0J?ooool2o`0008oooooo0_l0000jooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0L?ooool2
o`0008kooooo0_l0000cooooo`00<?ooool2o`0006;ooooo0_l0000=ooooo`;o0000P?ooool2o`00
00cooooo0_l0000cooooo`00<?ooool00ol0003oooooooooo`1Qooooo`;o0000Soooool2o`00047o
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0Moooool2o`0008kooooo0_l0000/ooooo`003Oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool0Moooool2o`0008kooooo0_l0000/ooooo`003Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003Ooo
ool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0003oooooocKooooo000=
ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oo
ooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0F_ooool2o`0008oooooo0_l00018ooooo`003Oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0F_ooool2o`0008oooooo0_l00018ooooo`003Oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`00
0?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000
ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0O_ooool2o`0008oooooo0_l0000T
ooooo`00<?ooool2o`0007oooooo0_l0002?ooooo`;o00009?ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`3oooooocKooooo000Eooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000Eooooo`05
oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolfoooo
o`005Oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`3oooooocKooooo000Eooooo`05o`000?ooooooooooooooool000003?ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@
413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1C
ooooo`;o0000S_ooool2o`00053ooooo000Eooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo05?ooooo0_l0002>ooooo`;o0000D?ooool0
01Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`25ooooo`;o0000Soooool2o`0001gooooo000`ooooo`03o`00
0?oooooooooo08Gooooo0_l0002?ooooo`;o00007Oooool0033ooooo0_l0003oooooocOooooo000`
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0
00gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000=
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00Go410@
oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00ooo
ool3o`000?oooooo=_ooool000gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooo
oooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=
ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oo
ooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0oooooolfooooo`003Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0oooooolfooooo`003Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co
00001_ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00;oooool2o`0004kooooo0_l0000oooooo`;o0000COoo
ool2o`0003oooooo0_l0000Fooooo`00;oooool2o`0004kooooo0_l0000oooooo`;o0000COooool2
o`0003oooooo0_l0000Fooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o
0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`00
0?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`009_ooool4o`000003oa0@
4?oooooooooo00?ooooo00?o0000ooooooooool0oooooolfooooo`00:?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0?oooooo=_ooool002Sooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`3oooooocKooooo000Xooooo`03o`000?oooooooooo00Gooooo0ol0003ooooo
ocKooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolfooooo`00
:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo=_ooool002Sooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocKooooo000Vooooo`03oeEEEOmVIVKo
000000Oooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`03ooooo`;o0000Soooool2o`0009oooooo000`ooooo`03o`000?oo
oooooooo00?ooooo0_l0002?ooooo`;o0000Woooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000ko
oooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000oooooooo
ool01?ooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0A?ooool2o`0008oooooo0_l0001Nooooo`004?ooool00ol0003o
ooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`0004Co
oooo0_l0002?ooooo`;o0000G_ooool0013ooooo00?o0000ooooooooool03?ooool00onHV9So8B4Q
onk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`004?oo
ool00ol0003oooooooooo`0=ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooo
oolfooooo`004?ooool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@41001?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool000kooooo00?oEEEE
ofIVI_l000003?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000oooo
oolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`;o00003?ooool2o`0008kooooo0_l0002Hooooo`00<?ooool0
0ol0003oooooooooo`0;ooooo`;o0000S_ooool2o`0009Sooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo
=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`005_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooo
oooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolf
ooooo`006?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Co
oooo0ol0003oooooocKooooo000Hooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_oo
ool001Kooooo00?oEEEEofIVI_l000003Oooool4o`0000Kooooo00?o0000ooooooooool04_ooool2
o`0008kooooo0_l0002Aooooo`00<?ooool2o`0001?ooooo0_l0000Yooooo`;o0000Hoooool2o`00
02[ooooo0_l0001Uooooo`00<?ooool00ol0003oooooooooo`0mooooo`;o0000Soooool2o`0006Go
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`00<?ooool2o`0001[ooooo0_l0002>ooooo`;o0000R_ooool0033ooooo00?o0000oooo
ooooool06Oooool2o`0008kooooo0_l0002:ooooo`003_ooool4o`000003oa0@4?oooooooooo00;o
oooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool01?ooool2ob4Q8@Ko
oooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0013ooooo00?o0000ooooooooool03?ooool00onYZJWoEEEEooooo`08ooooo`03o`00
0?oooooooooo00?ooooo0ol0003oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?o
8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0013ooooo00?o0000ooooooooool03Oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooo
oooo00gooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo03Kooooo0_l0002>ooooo`;o0000KOooool0013ooooo00?o0000ooooooooool02_ooool01Ol@
413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0f
ooooo`;o0000S_ooool2o`0006gooooo000>ooooo`03oeEEEOmVIVKo000000cooooo1Ol00004oooo
o`Co00001_ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`0Pooooo`;o0000Soooool2o`0008;ooooo000`ooooo`03o`000?oo
oooooooo023ooooo0_l0002?ooooo`;o0000P_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo02Oooooo0_l0
0006ooooo`;o0000Qoooool2o`0000Gooooo0_l0001dooooo`00<?ooool2o`0002Sooooo0_l00006
ooooo`;o0000Qoooool2o`0000Gooooo0_l0001dooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolg
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000Uooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooocKooooo000Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooocKooooo000Vooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0
oooooolfooooo`009oooool00onHV9So8B4Qonk^kP06ooooo`?o0000oooooolfooooo`00:?ooool0
0omgMgOoIVIVooooo`3oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Go
oooo00Go0000okZj^_ooooooV9RHoa0@403oooooocoooooo000Uooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`0ooooooloooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Y?ooool0
1OnHV9So0000o`000?m4A4Co^[Zj01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o410@olc<c02:oooo
o`00Y?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00009ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40R_ooool00:Cooooo00?o0000ooooooooool06_ooool01Ol@413ooooooooo
oooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4003ooooo`05o`000?oooooooooooooo
ool00000R_ooool00:Cooooo00?o0000ooooooooool02oooool6o`0000Wooooo00Go0000oooooooo
ooooooooo`00000;ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003oV9RHoooooonH
V9So8B4Q08[ooooo002Tooooo`03o`000?oooooooooo01[ooooo00Go0000ooooooooooooooooo`00
000;ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003oEEEEo`000?l@413oc<c<08[o
oooo002Rooooo`03oa0@4?l0003o000000?o00006Oooool01Ol@413ooooooooooooooooo410@00_o
oooo00Go410@oooooooooooooooooa0@4003ooooo`03oeEEEOn7QhOooooo08cooooo002Tooooo`03
o`000?oooooooooo01[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool00ooMgMgo410@oiRHV02<ooooo`00Y?ooool00ol0003oooooooooo`0Joooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00Co
c<c<odA4A?l0003o410@R_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.12) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .2441 Mdot
.04762 .30516 Mdot
.07143 .3608 Mdot
.09524 .41167 Mdot
.11905 .46007 Mdot
.14286 .50602 Mdot
.16667 .54546 Mdot
.19048 .57128 Mdot
.21429 .5737 Mdot
.2381 .53983 Mdot
.2619 .46038 Mdot
.28571 .34423 Mdot
.30952 .22077 Mdot
.33333 .12098 Mdot
.35714 .05973 Mdot
.38095 .03621 Mdot
.40476 .04332 Mdot
.42857 .0739 Mdot
.45238 .12184 Mdot
.47619 .1809 Mdot
.5 .2441 Mdot
.52381 .30516 Mdot
.54762 .3608 Mdot
.57143 .41167 Mdot
.59524 .46007 Mdot
.61905 .50602 Mdot
.64286 .54546 Mdot
.66667 .57128 Mdot
.69048 .5737 Mdot
.71429 .53983 Mdot
.7381 .46038 Mdot
.7619 .34423 Mdot
.78571 .22077 Mdot
.80952 .12098 Mdot
.83333 .05973 Mdot
.85714 .03621 Mdot
.88095 .04332 Mdot
.90476 .0739 Mdot
.92857 .12184 Mdot
.95238 .1809 Mdot
.97619 .2441 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0J?ooool2o`0008oooooo0_l0000jooooo`00<?ooool00ol0003ooooo
ooooo`1Xooooo`;o0000Soooool2o`0003[ooooo000`ooooo`03o`000?oooooooooo073ooooo0_l0
002>ooooo`;o0000<oooool0033ooooo0_l0001aooooo`;o0000S_ooool2o`0003?ooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo067ooooo0_l0
002?ooooo`;o0000@Oooool0033ooooo0_l0001Rooooo`;o0000Soooool2o`00047ooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`1gooooo`;o0000S_ooool2o`0002cooooo000=ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Mooo
ool2o`0008kooooo0_l0000/ooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo05[ooooo0_l0000Rooooo`;o0000Joooool2o`0002;ooooo0_l0000Tooooo`00<?ooool2o`00
05_ooooo0_l0000Rooooo`;o0000Joooool2o`0002;ooooo0_l0000Tooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool001Go
oooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0003ooooo
ocKooooo000Eooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go0000ooooooooooooooooo`00000<oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKooooo000Eoooo
o`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0?oooooo=_ooool001Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo1?l00006ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
QOooool2o`0008oooooo0_l0000Mooooo`00<?ooool2o`0008Kooooo0_l0002?ooooo`;o00007Ooo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=ooo
ool0033ooooo00?o0000ooooooooool0Doooool2o`0008kooooo0_l0001@ooooo`003Oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo05?ooooo0_l0002>ooooo`;o0000D?oo
ool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYoooo
o`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003ooooooooo
o`03ooooo`?o0000oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000kooooo00?o
8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_oo
ool000gooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00Go
410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01_ooool2o`0008oo
oooo0_l0002>ooooo`;o00005_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go
00001?ooool4o`0000Gooooo0ol0002>ooooo`;o0000S_ooool2o`0001Kooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000Vooooo`Co000000?o410@ooooooooool00oooool00ol0003ooooo
ooooo`3oooooocKooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00ooo
ool2o`0008oooooo0_l0002Oooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00?ooooo0_l0002?ooooo`;o0000Woooool002Sooooo00?o0000ooooooooool01Oooool3o`00
0?oooooo=_ooool002Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocKo
oooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolfooooo`00:?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo=_ooool002Kooooo00?oEEEE
ofIVI_l000001oooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0C?ooool2o`0008kooooo0_l0001Gooooo`00<?ooool00ol0003o
ooooooooo`1<ooooo`;o0000S_ooool2o`0005Oooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool02oooool2o`0008kooooo0_l0002Hooooo`00<?ooool00ol0003o
ooooooooo`0;ooooo`;o0000S_ooool2o`0009Sooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`003_ooool4o`000003oa0@4?oooooooooo00;o
oooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooo
ocKooooo000@ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003o
ooooooooo`03ooooo`?o0000oooooolfooooo`004?ooool00ol0003oooooooooo`0<ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo
000@ooooo`03o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`3oooooocKooooo000@ooooo`03o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@
4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolfooooo`003_ooool0
0omEEEGoIVIVo`00000<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0
003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`0Booooo`;o0000S_ooool2o`00097o
oooo000`ooooo`03o`000?oooooooooo01;ooooo0_l0002>ooooo`;o0000TOooool0033ooooo0_l0
003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000
oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000Fooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000
ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0I
ooooo`;o0000S_ooool2o`0008[ooooo000Hooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Iooooo`;o0000:Oooool2o`0006?ooooo0_l0000Zoooo
o`;o0000G_ooool001Sooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`04ooooo`?o
0000A?ooool2o`0008oooooo0_l0001Nooooo`006?ooool00ol0003oooooooooo`0;ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo
000Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`3oooooocKooooo000Fooooo`03oeEEEOmVIVKo000000gooooo1?l00006ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
8?ooool2o`0008oooooo0_l00022ooooo`00<?ooool00ol0003oooooooooo`0Pooooo`;o0000Sooo
ool2o`0008;ooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolg
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000>ooooo`Co000000?o410@oooooooo
ool00_ooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`04ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolfooooo`004?ooool00ol0003oooooooooo`0<ooooo`03ojVYZOmEEEGooooo00Sooooo
00?o0000ooooooooool00oooool3o`0003gooooo0_l0002?ooooo`;o0000IOooool0013ooooo00?o
0000ooooooooool03Oooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool09oooool2o`0001Cooooo0_l0001iooooo`;o00005?ooool2o`0006Gooooo000@
ooooo`03o`000?oooooooooo00gooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Gooooo00?o0000ooooooooool09oooool2o`0008oooooo0_l0001kooooo`004?ooool0
0ol0003oooooooooo`0=ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00[ooooo00Go410@oooo
oooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`003_ooool00omEEEGoIVIVo`00000<ooooo`Go00001?ooool4o`0000Kooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo02oooooo0_l0002>ooooo`;o0000M?ooool0033ooooo0_l0000`ooooo`;o00001Oooool2o`00
08Oooooo0_l00005ooooo`;o0000KOooool0033ooooo00?o0000ooooooooool0=_ooool2o`0008ko
oooo0_l0001]ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool002Gooooo1Ol00006ooooo`03
o`000?oooooooooo0?oooooo=_ooool002Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03
o`000?oooooooooo0?oooooo=_ooool002Kooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003ooooo
ooooo`3oooooocKooooo000Wooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003oooooocKooooo000X
ooooo`03ogMgMomVIVKooooo0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`009Oooool01Ol0003o^[ZjoooooonHV9So410@0?oooooo?oooool002Gooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c03oooooocoooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002T
ooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B45ooooo`Co000000?o410@ooooooooool01Ol0002:ooooo`00Y?ooool01Ol@413o^[Zjonk^
k_mgMgOo410@00Wooooo1_l00009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oo
oooo00?o0000ooooooooool00_ooool01OnHV9So8B4Qonk^k_ooooooA4A408[ooooo002Tooooo`03
o`000?oooooooooo01[ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo
00?ooooo00?oV9RHob4Q8Oo^k^h0Roooool00:Cooooo00?o0000ooooooooool02oooool6o`0000Wo
oooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00Cooooo00?oV9RHob4Q
8Oo^k^h0R_ooool00:Cooooo00?o0000ooooooooool06_ooool01Ol0003ooooooooooooooooo0000
00kooooo00?o0000ooooooooool01Oooool00omgMgOoIVIVooooo`29ooooo`00X_ooool00ol@413o
0000o`000003o`0001Wooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0R?ooool00:Cooooo00?o0000ooooooooool06_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool00_ooool01Ol0003o^[ZjoooooonHV9So
410@08[ooooo002Tooooo`03o`000?oooooooooo01[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`03oeEEEOmVIVKo000000Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c02:ooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.18) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .22153 Mdot
.04762 .27033 Mdot
.07143 .3157 Mdot
.09524 .36044 Mdot
.11905 .40725 Mdot
.14286 .45557 Mdot
.16667 .50154 Mdot
.19048 .53953 Mdot
.21429 .56282 Mdot
.2381 .56175 Mdot
.2619 .51986 Mdot
.28571 .42378 Mdot
.30952 .29212 Mdot
.33333 .17101 Mdot
.35714 .09177 Mdot
.38095 .05704 Mdot
.40476 .05675 Mdot
.42857 .08066 Mdot
.45238 .12082 Mdot
.47619 .17007 Mdot
.5 .22153 Mdot
.52381 .27033 Mdot
.54762 .3157 Mdot
.57143 .36044 Mdot
.59524 .40725 Mdot
.61905 .45557 Mdot
.64286 .50154 Mdot
.66667 .53953 Mdot
.69048 .56282 Mdot
.71429 .56175 Mdot
.7381 .51986 Mdot
.7619 .42378 Mdot
.78571 .29212 Mdot
.80952 .17101 Mdot
.83333 .09177 Mdot
.85714 .05704 Mdot
.88095 .05675 Mdot
.90476 .08066 Mdot
.92857 .12082 Mdot
.95238 .17007 Mdot
.97619 .22153 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`1Xooooo`;o00001_ooool2o`0008Oooooo0_l00005ooooo`;o0000
<oooool0033ooooo00?o0000ooooooooool0J?ooool2o`0000Kooooo0_l00027ooooo`;o00001Ooo
ool2o`0003?ooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000=ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4
A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0007Oooooo0_l0
002>ooooo`;o0000;?ooool000gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo07Oooooo
0_l0002>ooooo`;o0000;?ooool000gooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo
000=ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006oooo
o`;o0000H_ooool2o`0008oooooo0_l00011ooooo`00<?ooool00ol0003oooooooooo`1Qooooo`;o
0000Soooool2o`00047ooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`1nooooo`;o0000Soooool2o`0002Cooooo000`ooooo`;o0000Ooooool2o`00
08oooooo0_l0000Tooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Go
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool001Go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooooooooooooooooa0@400@oooo
o`03o`000?oooooooooo00?ooooo0ol0003oooooocKooooo000Eooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0QOooool2
o`0008oooooo0_l0000Mooooo`005Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006
ooooo`;o0000Foooool2o`0002Wooooo0_l0001Tooooo`;o0000:Oooool2o`0001gooooo000`oooo
o`03o`000?oooooooooo05[ooooo0_l0002?ooooo`;o0000B?ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooo
oolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooo
oolgooooo`00;oooool2o`0008oooooo0_l0002>ooooo`;o00005_ooool000gooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01?ooool2o`0008oooooo0_l0002>ooooo`;o00005_ooool000gooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooooooo
oooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000oooo
oolfooooo`003Oooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_oo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00Go0000
ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00Go410@oooooooooooooooo
oa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3oooooocKooooo000=ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooo
oooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKo
oooo000=ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`;o
0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo00?ooooo0_l0002?ooooo`;o0000Wooo
ool0033ooooo00?o0000ooooooooool00oooool2o`0008oooooo0_l0002Oooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000
ooooooooool0Doooool2o`0008kooooo0_l0001@ooooo`00<?ooool2o`0005Cooooo0_l0002>oooo
o`;o0000D?ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`009_ooool4o`000003oa0@
4?oooooooooo00?ooooo00?o0000ooooooooool0oooooolfooooo`00:?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0?oooooo=_ooool002Sooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`3oooooocKooooo000Xooooo`03o`000?oooooooooo00Gooooo0ol0003ooooo
ocKooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolfooooo`00
:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo0_l0002>ooooo`;o0000
V?ooool002Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`;o0000S_oo
ool2o`0009Sooooo000Vooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo01;ooooo0_l0002>ooooo`;o0000TOooool0033ooooo00?o0000oooooooo
ool04_ooool2o`0008kooooo0_l0002Aooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool000kooooo1?l000000ol@413oooooooooo`02ooooo`;o
8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
0?oooooo=_ooool0013ooooo00?o0000ooooooooool01?ooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfoooo
o`004?ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000oooooooo
ool00oooool3o`000?oooooo=_ooool0013ooooo00?o0000ooooooooool03?ooool00onHV9So8B4Q
onk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`004?oo
ool00ol0003oooooooooo`0=ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooo
oolfooooo`004?ooool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@41001?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool000kooooo00?oEEEE
ofIVI_l000003?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000oooo
oolgooooo`00<?ooool00ol0003oooooooooo`0Iooooo`;o0000S_ooool2o`0008[ooooo000`oooo
o`03o`000?oooooooooo01Wooooo0_l0002>ooooo`;o0000R_ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooo
oolgooooo`00<?ooool00ol0003oooooooooo`1<ooooo`;o0000S_ooool2o`0005Oooooo000`oooo
o`03o`000?oooooooooo04cooooo0_l0002>ooooo`;o0000Eoooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo
=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`005_ooool4o`000003oa0@4?oooooo
oooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooooooo
o`0Pooooo`;o0000Soooool2o`0008;ooooo000Hooooo`03o`000?oooooooooo00Cooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool08?ooool2o`0008oooooo0_l00022
ooooo`006?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Co
oooo0ol0003oooooocKooooo000Hooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_oo
ool001Kooooo00?oEEEEofIVI_l000003Oooool4o`0000Kooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool09oooool2o`0008oooooo0_l0001kooooo`00<?ooool00ol0003ooooo
ooooo`0Wooooo`;o0000Soooool2o`0007_ooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`14ooooo`;o0000
Soooool2o`0005kooooo000`ooooo`03o`000?oooooooooo04Cooooo0_l0002?ooooo`;o0000G_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000ko
oooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03
o`000?oooooooooo00Cooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00cooooo
00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000;oooool2o`0008kooooo
0_l0001dooooo`004?ooool00ol0003oooooooooo`0=ooooo`03ob4Q8Ooooooooooo00Kooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0_ooooo`;o0000S_ooool2o`0007Cooooo000@
ooooo`03o`000?oooooooooo00gooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0=
ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3o
ooooocKooooo000@ooooo`03o`000?oooooooooo00[ooooo00Go410@oooooooooooooooooc8b<P04
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolfooooo`003_ooool00omE
EEGoIVIVo`00000<ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03
o`000?oooooooooo03gooooo0_l0002?ooooo`;o0000IOooool0033ooooo00?o0000ooooooooool0
=_ooool2o`0000Gooooo0_l00027ooooo`;o00001_ooool2o`0006Gooooo000`ooooo`03o`000?oo
oooooooo03Kooooo0_l0002>ooooo`;o0000KOooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool002Gooooo1Ol00006ooooo`03o`000?oooooooooo0?oo
oooo=_ooool002Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0?oo
oooo=_ooool002Kooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`3oooooocKooooo
000Wooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003oooooocKooooo000Xooooo`03ogMgMomVIVKo
oooo0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`009Oooool01Ol0003o
^[ZjoooooonHV9So410@0?oooooo?oooool002Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c03ooooo
ocoooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Tooooo`05oiRHV?l0003o
0000odA4A?nj^[X06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co0000
00So410@ooooooooooooc<c<ob4Q8Ol0003o8B4Qolc<c8[ooooo002Tooooo`05oa0@4?nj^[[ok^k^
ogMgMol@41002Oooool6o`0000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1ooo
ool00ol0003oooooooooo`02ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40R_ooool00:Cooooo00?o
0000ooooooooool06_ooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000008[ooooo002Tooooo`03o`000?oooooooooo00_ooooo
1_l00009ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`02ooooo`05
oc8b<_nHV9SooooooiRHV?lb<S80R_ooool00:Cooooo00?o0000ooooooooool06_ooool01Ol0003o
oooooooooooooooo000000kooooo00?o0000ooooooooool00_ooool01Oo<c<co0000o`000?l0003o
c<c<08[ooooo002Rooooo`03oa0@4?l0003o000000?o00006Oooool01Ol@413ooooooooooooooooo
410@00kooooo00?o0000ooooooooool00_ooool01Ol@413o^[Zjoooooonj^[[o410@08[ooooo002T
ooooo`03o`000?oooooooooo01[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oo
oooooooo00;ooooo00Go0000okZj^_oooooo^[Zjo`00002:ooooo`00Y?ooool00ol0003ooooooooo
o`0Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`000004ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT0R_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.24) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .20246 Mdot
.04762 .24209 Mdot
.07143 .28053 Mdot
.09524 .32112 Mdot
.11905 .36587 Mdot
.14286 .41346 Mdot
.16667 .46032 Mdot
.19048 .50234 Mdot
.21429 .53523 Mdot
.2381 .55306 Mdot
.2619 .5447 Mdot
.28571 .48855 Mdot
.30952 .37341 Mdot
.33333 .23763 Mdot
.35714 .13513 Mdot
.38095 .08318 Mdot
.40476 .07206 Mdot
.42857 .08802 Mdot
.45238 .1204 Mdot
.47619 .16076 Mdot
.5 .20246 Mdot
.52381 .24209 Mdot
.54762 .28053 Mdot
.57143 .32112 Mdot
.59524 .36587 Mdot
.61905 .41346 Mdot
.64286 .46032 Mdot
.66667 .50234 Mdot
.69048 .53523 Mdot
.71429 .55306 Mdot
.7381 .5447 Mdot
.7619 .48855 Mdot
.78571 .37341 Mdot
.80952 .23763 Mdot
.83333 .13513 Mdot
.85714 .08318 Mdot
.88095 .07206 Mdot
.90476 .08802 Mdot
.92857 .1204 Mdot
.95238 .16076 Mdot
.97619 .20246 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1`ooooo`;o0000S_ooool2o`0003?ooooo000=
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0L?ooool2o`0008kooooo0_l0000cooooo`003Oooool0
1Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8boooo
o`04ooooo`?o0000oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
J?ooool2o`0008oooooo0_l0000jooooo`003Oooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo06Sooooo
0_l0002?ooooo`;o0000>_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07Oo
oooo0_l0002>ooooo`;o0000;?ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0001hooooo`;o0000S_ooool2o`00
02cooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`1nooooo`;o0000Soooool2o`0002Cooooo000`ooooo`03o`000?oooooooooo07kooooo0_l0002?
ooooo`;o00009?ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`1Qooooo`;o0000Soooool2o`00047ooooo000`ooooo`;o0000H_ooool2o`0008oooooo0_l00011
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooo
ooooool00oooool3o`000?oooooo=_ooool001Gooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol0003o
oooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo08Gooooo0_l0002?ooooo`;o00007Oooool001Gooooo00Go410@oooooooooooooooooa0@400<
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0QOooool2o`0008oooooo0_l0000M
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000_ooooo`?o0000S_ooool2o`0008kooooo0_l0
000Fooooo`00;oooool2o`0008oooooo0_l0002>ooooo`;o00005_ooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool0
0ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooooooo
o`3oooooocKooooo000=ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?o
EEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_oo
ool000gooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o
0000ooooooooool00oooool3o`000?oooooo=_ooool000gooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<oooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`1Jooooo`;o0000
Soooool2o`0004Sooooo000=ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMg
ooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool2o`0005Gooooo
0_l0000hooooo`;o0000EOooool2o`0004Sooooo000=ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`03ooooo`;o0000Soooool2o`0009oooooo000=ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool5o`0000Cooooo1?l00006ooooo`;o0000oooooolgooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000
ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o
0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`;o00003?ooool2o`0008kooooo0_l0002Hooooo`00
<?ooool00ol0003oooooooooo`0;ooooo`;o0000S_ooool2o`0009Sooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`00
0?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`009_ooool4o`000003oa0@
4?oooooooooo00?ooooo00?o0000ooooooooool0oooooolfooooo`00:?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0?oooooo=_ooool002Sooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`3oooooocKooooo000Xooooo`03o`000?oooooooooo00Gooooo0ol0003ooooo
ocKooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolfooooo`00
:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo=_ooool002Sooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Booooo`;o0000S_ooool2o`00097ooooo000V
ooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool04_ooool2o`0008kooooo0_l0002A
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`0Iooooo`;o0000S_ooool2o`0008[ooooo000`ooooo`03o`000?oo
oooooooo01Wooooo0_l0002>ooooo`;o0000R_ooool0033ooooo0_l0001Dooooo`;o0000S_ooool2
o`00053ooooo000`ooooo`03o`000?oooooooooo05?ooooo0_l0002>ooooo`;o0000D?ooool000ko
oooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000oooooooo
ool01?ooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0;ooooo`03
oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool0013ooooo
00?o0000ooooooooool03?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0=ooooo`03ogMgMomV
IVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo
=_ooool0013ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0:
ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0?oooooo=_ooool000kooooo00?oEEEEofIVI_l000003?ooool01OnHV9So410@o`000?lQ
8B7oc<c<00Cooooo1?l00006ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool08?ooool2o`0008oooooo0_l00022ooooo`00<?ooool00ol0003oooooooooo`0Pooooo`;o0000
Soooool2o`0008;ooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo
=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`005_ooool4o`000003oa0@4?oooooo
oooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooooooo
o`3oooooocKooooo000Hooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09oooool2o`0008oooooo0_l0001koooo
o`006?ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Wooooo`;o
0000Soooool2o`0007_ooooo000Hooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_oo
ool001Kooooo00?oEEEEofIVI_l000003Oooool4o`0000Kooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`1<ooooo`;o0000S_ooool2o`0005Oooooo000`ooooo`03o`000?oo
oooooooo04cooooo0_l0002>ooooo`;o0000Eoooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0;oooool2o`0008ko
oooo0_l0001dooooo`00<?ooool00ol0003oooooooooo`0_ooooo`;o0000S_ooool2o`0007Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000ko
oooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0fooooo`;o0000S_ooool2o`00
06gooooo000@ooooo`03o`000?oooooooooo00Cooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oo
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0fooooo`;o0000S_ooool2o`0006go
oooo000@ooooo`03o`000?oooooooooo00cooooo00?oZJVYoeEEEOooool02?ooool00ol0003ooooo
ooooo`03ooooo`?o0000oooooolfooooo`004?ooool00ol0003oooooooooo`0=ooooo`03ob4Q8Ooo
oooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`14ooooo`;o0000Sooo
ool2o`0005kooooo000@ooooo`03o`000?oooooooooo00gooooo00?oEEEEolc<c?ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0A?ooool2o`0008oooooo0_l0
001Nooooo`004?ooool00ol0003oooooooooo`0=ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo
00[ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0?Oooool2o`0008oooooo0_l0001Uooooo`003_ooool00omEEEGoIVIVo`00000<oooo
o`Go00001?ooool4o`0000Kooooo0_l0000nooooo`;o0000Soooool2o`0006Gooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0
033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000Uooooo`Go00001_ooool00ol0003oooooooooo`3oooooocKo
oooo000Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`3oooooocKo
oooo000Vooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0oooooolfooooo`009ooo
ool00onHV9So8B4Qonk^kP06ooooo`?o0000oooooolfooooo`00:?ooool00omgMgOoIVIVooooo`3o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Gooooo00Go0000okZj^_oo
ooooV9RHoa0@403oooooocoooooo000Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0oooooolooooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Y?ooool01OnHV9So0000o`000?m4
A4Co^[Zj01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo
0_l000000ol@413oooooooooo`28ooooo`00Y?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo
1_l00009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A006ooooo`03o`000?oooooooooo08Wooooo002Tooooo`03o`000?oooooooooo01[o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Cooooo1Ol0002:oooo
o`00Y?ooool00ol0003oooooooooo`0;ooooo`Ko00002Oooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h00oooool01?m4A4CogMgMooooool0002;ooooo`00Y?ooool00ol0
003oooooooooo`0Jooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`02
ooooo`04omgMgOmEEEGoooooo`0008_ooooo002Rooooo`03oa0@4?l0003o000000?o00006Oooool0
1Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00omgMgOoc<c<o`00
002;ooooo`00Y?ooool00ol0003oooooooooo`0Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?ok^k^odA4A?l00000Roooool00:Cooooo00?o
0000ooooooooool06_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c005ooooo`03ogMgMol0003ooooo08[ooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .18647 Mdot
.04762 .21937 Mdot
.07143 .25312 Mdot
.09524 .29067 Mdot
.11905 .33307 Mdot
.14286 .3785 Mdot
.16667 .4238 Mdot
.19048 .46594 Mdot
.21429 .5023 Mdot
.2381 .5294 Mdot
.2619 .54068 Mdot
.28571 .52126 Mdot
.30952 .44552 Mdot
.33333 .31688 Mdot
.35714 .19325 Mdot
.38095 .11819 Mdot
.40476 .09138 Mdot
.42857 .09694 Mdot
.45238 .12078 Mdot
.47619 .15282 Mdot
.5 .18647 Mdot
.52381 .21937 Mdot
.54762 .25312 Mdot
.57143 .29067 Mdot
.59524 .33307 Mdot
.61905 .3785 Mdot
.64286 .4238 Mdot
.66667 .46594 Mdot
.69048 .5023 Mdot
.71429 .5294 Mdot
.7381 .54068 Mdot
.7619 .52126 Mdot
.78571 .44552 Mdot
.80952 .31688 Mdot
.83333 .19325 Mdot
.85714 .11819 Mdot
.88095 .09138 Mdot
.90476 .09694 Mdot
.92857 .12078 Mdot
.95238 .15282 Mdot
.97619 .18647 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0001aooooo`;o0000S_ooool2o`0003?ooooo000`ooooo`03
o`000?oooooooooo073ooooo0_l00005ooooo`;o0000Qoooool2o`0000Gooooo0_l0000/ooooo`00
<?ooool00ol0003oooooooooo`1gooooo`;o0000S_ooool2o`0002cooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`00
0?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo06Sooooo0_l0002?ooooo`;o0000>_oo
ool0033ooooo00?o0000ooooooooool0J?ooool2o`0001Cooooo0_l0001iooooo`;o00005?ooool2
o`0002Cooooo000`ooooo`;o0000Ooooool2o`0008oooooo0_l0000Tooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo08Gooooo0_l0002?oooo
o`;o00007Oooool001Gooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo
00?ooooo0ol00025ooooo`;o0000Soooool2o`0001gooooo000Eooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000oooooolg
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00;oooool3o`0008kooooo0_l0
002>ooooo`;o00005_ooool002oooooo0_l0002?ooooo`;o0000S_ooool2o`0001Kooooo000`oooo
o`03o`000?oooooooooo067ooooo0_l0002?ooooo`;o0000@Oooool0033ooooo00?o0000oooooooo
ool0HOooool2o`0008oooooo0_l00011ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o00001?ooool2o`0008oooooo0_l0
002Oooooo`00<?ooool00ol0003oooooooooo`03ooooo`;o0000Soooool2o`0009oooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool02oooool2o`0008kooooo0_l0002Hooooo`00<?ooool00ol0003oooooooooo`0;
ooooo`;o0000S_ooool2o`0009Sooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`0Booooo`;o0000S_ooool2o`00097ooooo000`ooooo`;o00004oooool2o`00
08kooooo0_l0002Aooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000Vooooo`Co0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`3oooooocKooooo000Xooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooolfooooo`00:?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?oooooo=_ooool002Sooooo00?o0000ooooooooool01Oooool3o`00
0?oooooo=_ooool002Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocKo
oooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0F_ooool2o`0008oooooo
0_l00018ooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05[ooooo0_l0
002?ooooo`;o0000B?ooool002Kooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`03o`000?oooooooooo01Wooooo0_l0002>ooooo`;o0000R_ooool0033ooooo00?o
0000ooooooooool06Oooool2o`0008kooooo0_l0002:ooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`003_ooool4o`000003oa0@4?oooooooooo00;o
oooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool08?ooool2o`0008oooooo0_l00022ooooo`004?ooool00ol0003oooooooooo`04ooooo`;o
8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`0Pooooo`;o0000Soooool2o`0008;ooooo000@ooooo`03o`000?oooooooooo00_o
oooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000oooooolfooooo`00
4?ooool00ol0003oooooooooo`0<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
oooooolfooooo`004?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooo
oooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0oooooolfooooo`003_ooool00omEEEGoIVIVo`00000<ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0
003oooooocOooooo000`ooooo`03o`000?oooooooooo02Oooooo0_l0002?ooooo`;o0000Noooool0
033ooooo00?o0000ooooooooool09oooool2o`0008oooooo0_l0001kooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`1Cooooo`;o0000S_ooool2o`00053o
oooo000`ooooo`;o0000E?ooool2o`0008kooooo0_l0001@ooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000Fooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000
ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3o
ooooocKooooo000Hooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_oo
ool01?ooool3o`0002oooooo0_l0002>ooooo`;o0000M?ooool001Sooooo00?o0000ooooooooool0
2oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0;oooool2o`0008ko
oooo0_l0001dooooo`006?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0oooooolfooooo`005_ooool00omEEEGoIVIVo`00000=
ooooo`Co00001_ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`0fooooo`;o
0000S_ooool2o`0006gooooo000`ooooo`03o`000?oooooooooo03Kooooo0_l0002>ooooo`;o0000
KOooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`03o`000?oooooooooo04cooooo0_l0002>ooooo`;o0000Eoooool0033ooooo00?o
0000ooooooooool0C?ooool2o`0008kooooo0_l0001Gooooo`00<?ooool2o`0003kooooo0_l0002?
ooooo`;o0000IOooool0033ooooo00?o0000ooooooooool0?Oooool2o`0008oooooo0_l0001Uoooo
o`003_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool0013o
oooo00?o0000ooooooooool01?ooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool0
3?ooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol00014ooooo`;o0000
Soooool2o`0005kooooo000@ooooo`03o`000?oooooooooo00gooooo00?o8B4Qooooooooool01_oo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo04Cooooo0_l0002?ooooo`;o0000G_oo
ool0013ooooo00?o0000ooooooooool03Oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooo
oooo00gooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool02_ooool01Ol@413ooooooooooooooooo
<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000>oooo
o`03oeEEEOmVIVKo000000cooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool002Gooooo1Ol00006ooooo`03o`000?oooooooooo0?oo
oooo=_ooool002Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0?oo
oooo=_ooool002Kooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`3oooooocKooooo
000Wooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003oooooocKooooo000Xooooo`03ogMgMomVIVKo
oooo0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`009Oooool01Ol0003o
^[ZjoooooonHV9So410@0?oooooo?oooool002Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c03ooooo
ocoooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Xooooo`05oiRHV?l0003o
0000odA4A?nj^[X06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05oiRH
V?l@413o0000oc8b<_o<c<`0S_ooool00:Sooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko
00002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80S_ooool00:Sooooo00?o0000ooooooooool06_ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0S?ooool00:Sooooo00?o0000ooooooooool02oooool6o`00
00Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ojVYZOl@413ooooo08gooooo002Xoooo
o`03o`000?oooooooooo01[ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oa0@4?l0003o
^[Zj08kooooo002Vooooo`03oa0@4?l0003o000000?o00006Oooool01Ol@413ooooooooooooooooo
410@00kooooo00?o^[Zjob4Q8Oooool0SOooool00:Sooooo00?o0000ooooooooool06_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oiRHV?oooooo^[Zjo`00002>ooooo`00Z?ooool0
0ol0003oooooooooo`0Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`00
0?l@413oZJVY08kooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.36) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .17345 Mdot
.04762 .20129 Mdot
.07143 .23166 Mdot
.09524 .26669 Mdot
.11905 .30656 Mdot
.14286 .34925 Mdot
.16667 .39201 Mdot
.19048 .43263 Mdot
.21429 .46942 Mdot
.2381 .50045 Mdot
.2619 .52188 Mdot
.28571 .525 Mdot
.30952 .4898 Mdot
.33333 .39386 Mdot
.35714 .26511 Mdot
.38095 .16553 Mdot
.40476 .1175 Mdot
.42857 .10892 Mdot
.45238 .12273 Mdot
.47619 .14659 Mdot
.5 .17345 Mdot
.52381 .20129 Mdot
.54762 .23166 Mdot
.57143 .26669 Mdot
.59524 .30656 Mdot
.61905 .34925 Mdot
.64286 .39201 Mdot
.66667 .43263 Mdot
.69048 .46942 Mdot
.71429 .50045 Mdot
.7381 .52188 Mdot
.7619 .525 Mdot
.78571 .4898 Mdot
.80952 .39386 Mdot
.83333 .26511 Mdot
.85714 .16553 Mdot
.88095 .1175 Mdot
.90476 .10892 Mdot
.92857 .12273 Mdot
.95238 .14659 Mdot
.97619 .17345 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0001hoooo
o`;o0000S_ooool2o`0002cooooo000`ooooo`03o`000?oooooooooo07Oooooo0_l0002>ooooo`;o
0000;?ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`1`ooooo`;o0000S_ooool2o`0003?ooooo000`ooooo`03o`000?oooooooooo073ooooo0_l0000<
ooooo`;o0000P?ooool2o`0000gooooo0_l0000Tooooo`00<?ooool2o`0007oooooo0_l0002?oooo
o`;o00009?ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0QOooool2o`0008oooooo0_l0000Mooooo`005Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`25oooo
o`;o0000Soooool2o`0001gooooo000Eooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000Eooooo`05
oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolfoooo
o`005Oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`3oooooocKooooo000Eooooo`05o`000?ooooooooooooooool000003?ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@
413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1X
ooooo`;o0000Soooool2o`0003[ooooo000Eooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo06Sooooo0_l0002?ooooo`;o0000>_ooool0
01Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool3o`0008kooooo0_l0002>
ooooo`;o00005_ooool002oooooo0_l0002?ooooo`;o0000S_ooool2o`0001Kooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`0000Cooooo0_l0002?ooooo`;o0000Wooo
ool0033ooooo00?o0000ooooooooool00oooool2o`0008oooooo0_l0002Oooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000
ooooooooool0oooooolfooooo`003Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46
ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_oo
ool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooo
oolfooooo`003Oooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?oo
ool00ol0003oooooooooo`03ooooo`?o00002oooool2o`0008kooooo0_l0002Hooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo00_ooooo0_l0002>ooooo`;o0000V?ooool000gooooo00Go0000
ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00Go410@oooooooooooooooo
oa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3oooooocKooooo000=ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooo
oooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKo
oooo000=ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`;o
0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`;o0000H_ooool2o`0008oooooo0_l00011ooooo`00
<?ooool00ol0003oooooooooo`0Booooo`;o0000COooool2o`0003oooooo0_l0001>ooooo`;o0000
@Oooool0033ooooo00?o0000ooooooooool04_ooool2o`0008kooooo0_l0002Aooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000Vooooo`Co0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`3oooooocKooooo000Xooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooolfooooo`00:?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01Wooooo0_l0002>ooooo`;o0000R_ooool002Sooooo00?o0000oooo
ooooool01Oooool3o`0001Wooooo0_l0002>ooooo`;o0000R_ooool002Sooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooocKooooo000Xooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolfooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo=_ooool002Kooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo023ooooo
0_l0002?ooooo`;o0000P_ooool0033ooooo00?o0000ooooooooool08?ooool2o`0008oooooo0_l0
0022ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`003_ooool4o`000003oa0@4?oooooooooo00;o
oooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooo
ocKooooo000@ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003o
ooooooooo`03ooooo`?o0000oooooolfooooo`004?ooool00ol0003oooooooooo`0<ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo
000@ooooo`03o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool09oooool2o`00037ooooo0_l0001Looooo`;o0000
<Oooool2o`0004Sooooo000@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Oooooo0_l0000aooooo`;o0000G?oo
ool2o`00037ooooo0_l00018ooooo`004?ooool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[o
oooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_oo
ool000kooooo00?oEEEEofIVI_l000003?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0
0006ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`00033ooooo0_l0002>ooooo`;o0000
M?ooool0033ooooo00?o0000ooooooooool0;oooool2o`0008kooooo0_l0001dooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`005_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000H
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`0>ooooo`03
ogMgMolb<S;ooooo00Cooooo0ol0003oooooocKooooo000Hooooo`03o`000?oooooooooo00_ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo03Kooooo0_l0002>ooooo`;o
0000KOooool001Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo03Kooooo0_l0002>ooooo`;o0000KOooool001Sooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool001Kooooo00?oEEEE
ofIVI_l000003Oooool4o`0000Kooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`00
0?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`1Cooooo`;o0000S_ooool2o`00053ooooo000`ooooo`03o`000?oooooooooo05?ooooo0_l0
002>ooooo`;o0000D?ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0?Oooool2o`0008oooooo0_l0001Uooooo`00
<?ooool00ol0003oooooooooo`0mooooo`;o0000Soooool2o`0006Gooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`14ooooo`;o0000Soooool2o`0005kooooo000`ooooo`03o`000?oooooooooo04Cooooo0_l0
0006ooooo`;o0000Qoooool2o`0000Gooooo0_l0001Gooooo`00<?ooool2o`0004gooooo0_l0002>
ooooo`;o0000Eoooool0033ooooo00?o0000ooooooooool0oooooolfooooo`003_ooool4o`000003
oa0@4?oooooooooo00;ooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000oooooooo
ool01?ooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool03?ooool00onYZJWoEEEE
ooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocKooooo000@ooooo`03o`000?oo
oooooooo00gooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool03Oooool00omEEEGoc<c<ooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKooooo000@
ooooo`03o`000?oooooooooo00gooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool02_ooool01Ol@
413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3o
ooooocKooooo000>ooooo`03oeEEEOmVIVKo000000cooooo1Ol00004ooooo`Co00001_ooool2o`00
0?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000
ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool002Gooooo1Ol00006ooooo`03
o`000?oooooooooo0?oooooo=_ooool002Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03
o`000?oooooooooo0?oooooo=_ooool002Kooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003ooooo
ooooo`3oooooocKooooo000Wooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003oooooocKooooo000X
ooooo`03ogMgMomVIVKooooo0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`009Oooool01Ol0003o^[ZjoooooonHV9So410@0?oooooo?oooool002Gooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c03oooooocoooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002T
ooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?l@413oc<c<
08[ooooo002Tooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00Go
EEEEogMgMoooooooV9RHob4Q8@2:ooooo`00Y?ooool00ol0003oooooooooo`0Jooooo`05oa0@4?oo
ooooooooooooool@41003oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool0R?ooool00:Cooooo00?o0000ooooooooool02oooool6o`0000Wooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oiRHV?ooooooV9RHob4Q8@2:oooo
o`00Y?ooool00ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool000003Oooool00ol@
413o0000okZj^P03ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0R_ooool00:;ooooo00?o410@o`00
0?l000000ol0000Iooooo`05oa0@4?ooooooooooooooool@41003_ooool00onj^[[o8B4Qooooo`02
ooooo`03oeEEEOn7QhOooooo08cooooo002Tooooo`03o`000?oooooooooo01[ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool00ooMgMgo410@oiRH
V02<ooooo`00Y?ooool00ol0003oooooooooo`0Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY00Cooooo00Coc<c<odA4A?l0003o410@R_ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.42) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .16341 Mdot
.04762 .18714 Mdot
.07143 .21476 Mdot
.09524 .24746 Mdot
.11905 .28474 Mdot
.14286 .32452 Mdot
.16667 .36448 Mdot
.19048 .40294 Mdot
.21429 .43881 Mdot
.2381 .47097 Mdot
.2619 .49726 Mdot
.28571 .51253 Mdot
.30952 .50465 Mdot
.33333 .44999 Mdot
.35714 .3409 Mdot
.38095 .22599 Mdot
.40476 .15342 Mdot
.42857 .12616 Mdot
.45238 .12752 Mdot
.47619 .1427 Mdot
.5 .16341 Mdot
.52381 .18714 Mdot
.54762 .21476 Mdot
.57143 .24746 Mdot
.59524 .28474 Mdot
.61905 .32452 Mdot
.64286 .36448 Mdot
.66667 .40294 Mdot
.69048 .43881 Mdot
.71429 .47097 Mdot
.7381 .49726 Mdot
.7619 .51253 Mdot
.78571 .50465 Mdot
.80952 .44999 Mdot
.83333 .3409 Mdot
.85714 .22599 Mdot
.88095 .15342 Mdot
.90476 .12616 Mdot
.92857 .12752 Mdot
.95238 .1427 Mdot
.97619 .16341 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0001hooooo`;o0000S_ooool2o`0002cooooo000`ooooo`03
o`000?oooooooooo07Oooooo0_l00005ooooo`;o0000Qoooool2o`0000Kooooo0_l0000Tooooo`00
<?ooool00ol0003oooooooooo`1nooooo`;o0000Soooool2o`0002Cooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
08Gooooo0_l0002?ooooo`;o00007Oooool0033ooooo00?o0000ooooooooool0QOooool2o`0008oo
oooo0_l0000Mooooo`005Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`1`ooooo`;o0000S_ooool2o`0003?ooooo000Eooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol0003oooooooooo`03ooooo`?o0000L?ooool2o`0008kooooo0_l0000coooo
o`005Oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`3oooooocKooooo000Eooooo`05o`000?ooooooooooooooool000003?ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Cooooo0_l0002?ooooo`;o0000S_ooool2o`0001Kooooo000Eoooo
o`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`;o0000Soooool2
o`0008kooooo0_l0000Fooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`03
ooooo`;o0000Soooool2o`0009oooooo000`ooooo`03o`000?oooooooooo00?ooooo0_l0002?oooo
o`;o0000Woooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`0;ooooo`;o0000S_ooool2o`0009Sooooo
000`ooooo`;o00003?ooool2o`0008kooooo0_l0002Hooooo`00<?ooool00ol0003oooooooooo`3o
ooooocKooooo000=ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000
onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0J?oo
ool2o`0008oooooo0_l0000jooooo`003Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`1Xooooo`;o0000Soooool2o`0003[ooooo000=ooooo`05oa0@4?ooooooooooooooool@41003Ooo
ool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocKooooo000=
ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooo
oooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooooooooooo410@00kooooo
00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo
=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb
<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0000Cooooo`;o
0000S_ooool2o`00097ooooo000`ooooo`03o`000?oooooooooo01;ooooo0_l0002>ooooo`;o0000
TOooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOo
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo01Wooooo
0_l0002>ooooo`;o0000R_ooool0033ooooo00?o0000ooooooooool06Oooool2o`0008kooooo0_l0
002:ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000Vooooo`Co000000?o410@ooooooooool0
0oooool00ol0003oooooooooo`3oooooocKooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0oooooolfooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0?oooooo=_ooool002Sooooo00?o0000ooooooooool01Oooool3o`000?oooooo=_ooool002So
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocKooooo000Xooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0oooooolfooooo`00:?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0?oooooo=_ooool002Kooooo00?oEEEEofIVI_l000001oooool0
0ol0003oooooooooo`0Pooooo`;o0000Soooool2o`0008;ooooo000`ooooo`;o00008Oooool2o`00
08oooooo0_l00022ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`0006;ooooo0_l0002?ooooo`;o0000@Oooool0033ooooo00?o0000ooooooooool0HOooool2o`00
08oooooo0_l00011ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`0Wooooo`;o0000Soooool2o`0007_ooooo000`ooooo`03o`000?oooooooooo02Oooooo
0_l0002?ooooo`;o0000Noooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`003_ooool4o`000003
oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`04ooooo`;o
8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^
k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000oooooolfooooo`004?ooool00ol0003ooooo
ooooo`0<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`004?oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00[ooooo00Go0000
okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooo
oolfooooo`003_ooool00omEEEGoIVIVo`00000<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?oo
ool4o`0000Kooooo0_l0000`ooooo`;o0000S_ooool2o`0007Cooooo000`ooooo`03o`000?oooooo
oooo02oooooo0_l0002>ooooo`;o0000M?ooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`03o`000?oooooooooo03Kooooo0_l0002>ooooo`;o0000KOooool0033ooooo00?o0000oooo
ooooool0=_ooool2o`0008kooooo0_l0001]ooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`;o0000Foooool2o`0008oooooo0_l00018ooooo`00<?ooool00ol0003ooooooooo
o`1Jooooo`;o0000Soooool2o`0004Sooooo000Fooooo`Co000000?o410@ooooooooool00_ooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_oo
ool001Sooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00ko
oooo00?oMgMgoc8b<_ooool01?ooool3o`000?oooooo=_ooool001Sooooo00?o0000ooooooooool0
2oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`00
6?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
?Oooool2o`0008oooooo0_l0001Uooooo`006?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0?Oooool2o`0008oooooo0_l0001Uooooo`005_ooool0
0omEEEGoIVIVo`00000=ooooo`Co00001_ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0A?ooool2o`0008oooooo0_l0001Noooo
o`00<?ooool00ol0003oooooooooo`14ooooo`;o0000Soooool2o`0005kooooo000`ooooo`03o`00
0?oooooooooo05?ooooo0_l0002>ooooo`;o0000D?ooool0033ooooo00?o0000ooooooooool0Dooo
ool2o`0008kooooo0_l0001@ooooo`00<?ooool2o`0004gooooo0_l0002>ooooo`;o0000Eoooool0
033ooooo00?o0000ooooooooool0C?ooool2o`0008kooooo0_l0001Gooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`003_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B46ooooo`03
o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
0?oooooo=_ooool0013ooooo00?o0000ooooooooool01?ooool2ob4Q8@Kooooo00?oEEEEojVYZOoo
ool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo
00?o0000ooooooooool03?ooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo
0ol0003oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?o8B4Qooooooooool01_oo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000
ooooooooool03Oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool0
013ooooo00?o0000ooooooooool02_ooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000>ooooo`03oeEEEOmVIVKo0000
00cooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo=oooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`00
0?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool002Gooooo1Ol00006ooooo`03o`000?oooooooooo0?oooooo=_ooool002Gooooo
00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0?oooooo=_ooool002Kooooo
00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`3oooooocKooooo000Wooooo`03oiRHV?lQ
8B7ok^k^00Kooooo0ol0003oooooocKooooo000Xooooo`03ogMgMomVIVKooooo0?oooooo?_ooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`009Oooool01Ol0003o^[ZjoooooonHV9So410@
0?oooooo?oooool002Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c03oooooocoooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo002Tooooo`05oiRHV?l0003o0000odA4A?nj^[X06?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000Co410@oooooooooooo
oooo1Ol0002:ooooo`00Y?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00009ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool00_ooool01OnH
V9So8B4Qonk^k_ooooooA4A408[ooooo002Tooooo`03o`000?oooooooooo01[ooooo00Go410@oooo
oooooooooooooa0@400;ooooo`Go00001?ooool00onHV9So8B4Qonk^kP2;ooooo`00Y?ooool00ol0
003oooooooooo`0;ooooo`Ko00002Oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo00001_ooool00onHV9So8B4Qonk^kP2:ooooo`00Y?ooool00ol0003oooooooooo`0J
ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03ogMg
MomVIVKooooo08Wooooo002Rooooo`03oa0@4?l0003o000000?o00006Oooool01Ol@413ooooooooo
oooooooo410@00cooooo00?oMgMgolc<c?l000002?ooool00ol0003oooooooooo`28ooooo`00Y?oo
ool00ol0003oooooooooo`0Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4
o`000004ooooo`05o`000?nj^[[ooooooiRHV?l@4100R_ooool00:Cooooo00?o0000ooooooooool0
6_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool00oooool01OnHV9So
410@o`000?lQ8B7oc<c<08[ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.48) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .15651 Mdot
.04762 .1764 Mdot
.07143 .20144 Mdot
.09524 .23183 Mdot
.11905 .2665 Mdot
.14286 .30342 Mdot
.16667 .34061 Mdot
.19048 .37675 Mdot
.21429 .41113 Mdot
.2381 .44309 Mdot
.2619 .47135 Mdot
.28571 .4929 Mdot
.30952 .50049 Mdot
.33333 .4781 Mdot
.35714 .40455 Mdot
.38095 .29425 Mdot
.40476 .20084 Mdot
.42857 .15123 Mdot
.45238 .1369 Mdot
.47619 .14206 Mdot
.5 .15651 Mdot
.52381 .1764 Mdot
.54762 .20144 Mdot
.57143 .23183 Mdot
.59524 .2665 Mdot
.61905 .30342 Mdot
.64286 .34061 Mdot
.66667 .37675 Mdot
.69048 .41113 Mdot
.71429 .44309 Mdot
.7381 .47135 Mdot
.7619 .4929 Mdot
.78571 .50049 Mdot
.80952 .4781 Mdot
.83333 .40455 Mdot
.85714 .29425 Mdot
.88095 .20084 Mdot
.90476 .15123 Mdot
.92857 .1369 Mdot
.95238 .14206 Mdot
.97619 .15651 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`1nooooo`;o0000Soooool2o`0002Cooooo000`ooooo`;o0000Ooooool2o`0008oooooo0_l0000T
ooooo`00<?ooool00ol0003oooooooooo`25ooooo`;o0000Soooool2o`0001gooooo000`ooooo`03
o`000?oooooooooo08Gooooo0_l0002?ooooo`;o00007Oooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0Moooool2o`0008kooooo0_l0000/oooo
o`005Oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool4o`00
07Oooooo0_l0000Dooooo`;o0000N?ooool2o`0001Cooooo0_l0000Fooooo`005Oooool01Ol0003o
oooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool2o`0008oooooo0_l0002>oooo
o`;o00005_ooool001Gooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKooooo000Eooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool0
01Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0oooooolfooooo`005Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`03ooooo`;o0000Soooool2o`00
09oooooo000`ooooo`03o`000?oooooooooo00?ooooo0_l0002?ooooo`;o0000Woooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000
ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool2o`0000cooooo0_l0001Sooooo`;o0000:Oooool2o`0006?ooooo0_l0000cooooo`00<?ooool0
0ol0003oooooooooo`0;ooooo`;o0000Hoooool2o`0002Wooooo0_l0001Sooooo`;o0000<oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`
ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0?oooooo=_ooool000gooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmE
EEGooooo00Sooooo00?o0000ooooooooool00oooool3o`0001;ooooo0_l0002>ooooo`;o0000TOoo
ool000gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Booooo`;o0000S_ooool2o`00097ooooo000=
ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oo
ooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0oooooolfooooo`003Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0oooooolfooooo`003Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co
00001_ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo
00?o0000ooooooooool06Oooool2o`0008kooooo0_l0002:ooooo`00<?ooool00ol0003ooooooooo
o`0Iooooo`;o0000S_ooool2o`0008[ooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0001Yooooo`;o0000Soooool2o`00
03[ooooo000`ooooo`03o`000?oooooooooo06Sooooo0_l0002?ooooo`;o0000>_ooool002Kooooo
1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo=_ooool002Sooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Pooooo`;o0000Soooool2o`0008;ooooo000X
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08?ooool2o`0008oooooo0_l00022
ooooo`00:?ooool00ol0003oooooooooo`05ooooo`?o0000oooooolfooooo`00:?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0?oooooo=_ooool002Sooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`3oooooocKooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0oooooolfooooo`009_ooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000:?ooool2o`0008oooooo0_l0001kooooo`00<?ooool00ol0
003oooooooooo`0Wooooo`;o0000Soooool2o`0007_ooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolg
ooooo`00<?ooool00ol0003oooooooooo`0_ooooo`;o0000S_ooool2o`0007Cooooo000>ooooo`Co
000000?o410@ooooooooool00_ooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`0_ooooo`;o0000S_ooool2o`0007Cooooo000@ooooo`03
o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000oooooooo
ool02oooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocKo
oooo000@ooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool03Ooo
ool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000
ooooooooool02_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooocKooooo000>ooooo`03oeEEEOmVIVKo000000cooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`000?oooooo=oooool0033ooooo00?o0000
ooooooooool0HOooool2o`0008oooooo0_l00011ooooo`00<?ooool00ol0003oooooooooo`1Qoooo
o`;o0000Soooool2o`00047ooooo000`ooooo`03o`000?oooooooooo03Kooooo0_l0002>ooooo`;o
0000KOooool0033ooooo00?o0000ooooooooool0=_ooool2o`0008kooooo0_l0001]ooooo`00<?oo
ool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000
ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`0mooooo`;o0000Soooool2o`00
06Gooooo000`ooooo`03o`000?oooooooooo03gooooo0_l0002?ooooo`;o0000IOooool0033ooooo
0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Kooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo=_ooool001So
oooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`00
6?ooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003o
ooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`14ooooo`;o0000Soooool2o`0005kooooo000Hooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`14ooooo`;o0000Sooo
ool2o`0005kooooo000Fooooo`03oeEEEOmVIVKo000000gooooo1?l00006ooooo`03o`000?oooooo
oooo05[ooooo0_l0002?ooooo`;o0000B?ooool0033ooooo0_l0001Kooooo`;o0000Soooool2o`00
04Sooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`1<ooooo`;o0000S_ooool2o`0005Oooooo000`
ooooo`;o0000COooool2o`0008kooooo0_l0001Gooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo05?ooooo0_l0002>ooooo`;o0000D?ooool0033ooooo
00?o0000ooooooooool0Doooool2o`0008kooooo0_l0001@ooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolg
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000>ooooo`Co000000?o410@oooooooo
ool00_ooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`04ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolfooooo`004?ooool00ol0003oooooooooo`0<ooooo`03ojVYZOmEEEGooooo00Sooooo
00?o0000ooooooooool00oooool3o`000?oooooo=_ooool0013ooooo00?o0000ooooooooool03Ooo
ool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooo
oolfooooo`004?ooool00ol0003oooooooooo`0=ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000
ooooooooool03Oooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0:ooooo`05oa0@4?oooooooooo
oooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool0
00kooooo00?oEEEEofIVI_l000003?ooool5o`0000Cooooo1?l00006ooooo`;o0000oooooolgoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`009Oooool5o`0000Kooooo00?o0000oooooooo
ool0oooooolfooooo`009Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000oooooooo
ool0oooooolfooooo`009_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0?oooooo
=_ooool002Oooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000?oooooo=_ooool002Sooooo00?oMgMg
ofIVI_ooool0oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Uooooo`05
o`000?nj^[[ooooooiRHV?l@4100ooooooloooooo`009Oooool01OnHV9So410@o`000?lQ8B7oc<c<
0?oooooo?oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Cooooo00GoV9RH
o`000?l0003oA4A4okZj^P0Hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo
0_l000002Ol@413oooooooooooooooooc<c<ob4Q8Ol0003o8B4Qolc<c02:ooooo`00Y?ooool01Ol@
413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Oooooo00?o0000ooooooooool00_ooool01OlQ8B7oV9RHoooooonHV9So8B4Q08[ooooo
002Tooooo`03o`000?oooooooooo01[ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000
0oooool01Ol0003ooooooooooooooooo000008[ooooo002Tooooo`03o`000?oooooooooo00_ooooo
1_l00009ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00004oooo
o`05oc8b<_nHV9SooooooiRHV?lb<S80R_ooool00:Cooooo00?o0000ooooooooool06_ooool01Ol0
003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001?ooool01Oo<c<co0000o`00
0?l0003oc<c<08[ooooo002Rooooo`03oa0@4?l0003o000000?o00006Oooool01Ol@413ooooooooo
oooooooo410@00cooooo00?oMgMgolc<c?l000001?ooool01Ol@413o^[Zjoooooonj^[[o410@08[o
oooo002Tooooo`03o`000?oooooooooo01[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
onk^k_m4A4Co000000Cooooo00Go0000okZj^_oooooo^[Zjo`00002:ooooo`00Y?ooool00ol0003o
ooooooooo`0Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`03oooo
o`05ojVYZOl@413o0000oa0@4?nYZJT0R_ooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.54) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .15313 Mdot
.04762 .16883 Mdot
.07143 .19111 Mdot
.09524 .21904 Mdot
.11905 .25111 Mdot
.14286 .2853 Mdot
.16667 .31986 Mdot
.19048 .35376 Mdot
.21429 .38646 Mdot
.2381 .41756 Mdot
.2619 .4463 Mdot
.28571 .47083 Mdot
.30952 .48681 Mdot
.33333 .48429 Mdot
.35714 .4449 Mdot
.38095 .35844 Mdot
.40476 .2576 Mdot
.42857 .18614 Mdot
.45238 .15296 Mdot
.47619 .1459 Mdot
.5 .15313 Mdot
.52381 .16883 Mdot
.54762 .19111 Mdot
.57143 .21904 Mdot
.59524 .25111 Mdot
.61905 .2853 Mdot
.64286 .31986 Mdot
.66667 .35376 Mdot
.69048 .38646 Mdot
.71429 .41756 Mdot
.7381 .4463 Mdot
.7619 .47083 Mdot
.78571 .48681 Mdot
.80952 .48429 Mdot
.83333 .4449 Mdot
.85714 .35844 Mdot
.88095 .2576 Mdot
.90476 .18614 Mdot
.92857 .15296 Mdot
.95238 .1459 Mdot
.97619 .15313 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo08Gooooo0_l0002?ooooo`;o00007Oooool001Gooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0QOooool2o`0008oooooo0_l0000Mooooo`005Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo0_l00020oooo
o`;o00003Oooool2o`00083ooooo0_l0000<ooooo`;o00005_ooool001Gooooo00Go410@oooooooo
oooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo1?l0001nooooo`;o00003Oooool2o`00
083ooooo0_l0000<ooooo`;o00005_ooool001Gooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol0003o
oooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo0?oooooo=_ooool001Gooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`;o0000Soooool2
o`0009oooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l00004
ooooo`;o0000Soooool2o`0009oooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000N?ooool2o`0008kooooo0_l0000/ooooo`00<?ooool00ol0003oooooooooo`1g
ooooo`;o0000S_ooool2o`0002cooooo000`ooooo`03o`000?oooooooooo00_ooooo0_l0002>oooo
o`;o0000V?ooool0033ooooo00?o0000ooooooooool02oooool2o`0008kooooo0_l0002Hooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o00004oooool2o`0008kooooo0_l0002Aooooo`00<?ooool00ol0003oooooooooo`0B
ooooo`;o0000S_ooool2o`00097ooooo000=ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocKooooo000=ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEoooo
o`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocKooooo000=ooooo`05o`000?oooooo
ooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000kooooo00?o
EEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
oooooolfooooo`003Oooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool0
0oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`00
0?oooooooooo01Wooooo0_l0002>ooooo`;o0000R_ooool0033ooooo00?o0000ooooooooool06Ooo
ool2o`0008kooooo0_l0002:ooooo`00<?ooool00ol0003oooooooooo`1`ooooo`;o0000S_ooool2
o`0003?ooooo000`ooooo`03o`000?oooooooooo073ooooo0_l0002>ooooo`;o0000<oooool0033o
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`00
0?oooooooooo023ooooo0_l0002?ooooo`;o0000P_ooool0033ooooo00?o0000ooooooooool08?oo
ool2o`0008oooooo0_l00022ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000Vooooo`Co0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`3oooooocKooooo000Xooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooolfooooo`00:?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?oooooo=_ooool002Sooooo00?o0000ooooooooool01Oooool3o`00
0?oooooo=_ooool002Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocKo
oooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolfooooo`00:?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Oooooo0_l0002?ooooo`;o0000Nooo
ool002Kooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`0Wooooo`;o0000Soooool2
o`0007_ooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0;oooool2o`0008kooooo0_l0001dooooo`00<?ooool2
o`00033ooooo0_l0002>ooooo`;o0000M?ooool0033ooooo00?o0000ooooooooool0J?ooool2o`00
08oooooo0_l0000jooooo`00<?ooool00ol0003oooooooooo`1Xooooo`;o0000Soooool2o`0003[o
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`003_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003o
ooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00_o
oooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000=_ooool2o`0008ko
oooo0_l0001]ooooo`004?ooool00ol0003oooooooooo`0<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0fooooo`;o0000S_ooool2o`0006gooooo
000@ooooo`03o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`3oooooocKooooo000@ooooo`03o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@
4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolfooooo`003_ooool0
0omEEEGoIVIVo`00000<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0
003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo0_l0000nooooo`;o0000Soooool2o`0006Gooooo000`
ooooo`03o`000?oooooooooo03gooooo0_l0002?ooooo`;o0000IOooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000
oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`14ooooo`;o00006oooool2o`0007;ooooo0_l0000Kooooo`;o0000@Oooool0033ooooo
0_l00015ooooo`;o00006oooool2o`0007;ooooo0_l0000Kooooo`;o0000@Oooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`005_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000H
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`0>ooooo`03
ogMgMolb<S;ooooo00Cooooo0ol0003oooooocKooooo000Hooooo`03o`000?oooooooooo00_ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04cooooo
0_l0002>ooooo`;o0000Eoooool001Sooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo04cooooo0_l0002>ooooo`;o0000Eoooool001Kooooo00?oEEEE
ofIVI_l000003Oooool4o`0000Kooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`00
0?oooooo=oooool0033ooooo00?o0000ooooooooool0F_ooool2o`0008oooooo0_l00018ooooo`00
<?ooool00ol0003oooooooooo`1Cooooo`;o00001Oooool2o`0008Oooooo0_l00006ooooo`;o0000
B?ooool0033ooooo00?o0000ooooooooool0Doooool2o`0008kooooo0_l0001@ooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`003_ooool4o`000003
oa0@4?oooooooooo00;ooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000oooooooo
ool01?ooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool03?ooool00onYZJWoEEEE
ooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocKooooo000@ooooo`03o`000?oo
oooooooo00gooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool03Oooool00omEEEGoc<c<ooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKooooo000@
ooooo`03o`000?oooooooooo00gooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool02_ooool01Ol@
413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3o
ooooocKooooo000>ooooo`03oeEEEOmVIVKo000000cooooo1Ol00004ooooo`Co00001_ooool2o`00
0?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000
ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool002Gooooo1Ol00006ooooo`03
o`000?oooooooooo0?oooooo=_ooool002Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03
o`000?oooooooooo0?oooooo=_ooool002Kooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003ooooo
ooooo`3oooooocKooooo000Wooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003oooooocKooooo000X
ooooo`03ogMgMomVIVKooooo0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`009Oooool01Ol0003o^[ZjoooooonHV9So410@0?oooooo?oooool002Gooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c03oooooocoooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002T
ooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool2o`000003oa0@4?oooooooooo08So
oooo002Tooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
08Wooooo002Tooooo`03o`000?oooooooooo01[ooooo00Go410@oooooooooooooooooa0@400@oooo
o`03o`000?oooooooooo00Go0000R_ooool00:Cooooo00?o0000ooooooooool02oooool6o`0000Wo
oooo00Go0000ooooooooooooooooo`00000?ooooo`08ogMgMolb<S;ooooooooooom4A4CogMgMoooo
ool0002;ooooo`00Y?ooool00ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00CogMgMoeEEEOoooooo0000Roooool00:;o
oooo00?o410@o`000?l000000ol0000Iooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0
003oooooooooo`05ooooo`03ogMgMoo<c<co000008_ooooo002Tooooo`03o`000?oooooooooo01[o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Gooooo00?ok^k^odA4
A?l00000Roooool00:Cooooo00?o0000ooooooooool06_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo1?l00005ooooo`03ogMgMol0003ooooo08[ooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .15399 Mdot
.04762 .16451 Mdot
.07143 .18347 Mdot
.09524 .20869 Mdot
.11905 .23811 Mdot
.14286 .26968 Mdot
.16667 .30181 Mdot
.19048 .33358 Mdot
.21429 .36459 Mdot
.2381 .39455 Mdot
.2619 .42297 Mdot
.28571 .44866 Mdot
.30952 .46895 Mdot
.33333 .4777 Mdot
.35714 .46239 Mdot
.38095 .40661 Mdot
.40476 .31621 Mdot
.42857 .23058 Mdot
.45238 .17758 Mdot
.47619 .15572 Mdot
.5 .15399 Mdot
.52381 .16451 Mdot
.54762 .18347 Mdot
.57143 .20869 Mdot
.59524 .23811 Mdot
.61905 .26968 Mdot
.64286 .30181 Mdot
.66667 .33358 Mdot
.69048 .36459 Mdot
.71429 .39455 Mdot
.7381 .42297 Mdot
.7619 .44866 Mdot
.78571 .46895 Mdot
.80952 .4777 Mdot
.83333 .46239 Mdot
.85714 .40661 Mdot
.88095 .31621 Mdot
.90476 .23058 Mdot
.92857 .17758 Mdot
.95238 .15572 Mdot
.97619 .15399 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool4o`0008Gooooo0_l00006oooo
o`;o0000Qoooool2o`0000Gooooo0_l0000Fooooo`005Oooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool00oooool2o`0008Oooooo0_l00006ooooo`;o0000Qoooool2o`00
00Gooooo0_l0000Fooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool2
o`0008oooooo0_l0002Oooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`03ooooo`;o0000Soooool2o`0009oooooo000Eoooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0O_ooool2o`0008oo
oooo0_l0000Tooooo`00<?ooool00ol0003oooooooooo`1nooooo`;o0000Soooool2o`0002Cooooo
000`ooooo`;o00003?ooool2o`0008kooooo0_l0002Hooooo`00<?ooool00ol0003oooooooooo`0;
ooooo`;o0000S_ooool2o`0009Sooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo01;ooooo0_l0002>ooooo`;o0000TOooool0033ooooo00?o0000oooooooo
ool04_ooool2o`0008kooooo0_l0002Aooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
001gooooo`;o0000S_ooool2o`0002cooooo000=ooooo`05o`000?ooooooooooooooool000003_oo
ool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0Mooo
ool2o`0008kooooo0_l0000/ooooo`003Oooool01Ol0003ooooooooooooooooo000000kooooo00?o
EEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
6Oooool2o`0008kooooo0_l0002:ooooo`003Oooool01Ol@413ooooooooooooooooo410@00kooooo
00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Wooooo
0_l0002>ooooo`;o0000R_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool08?ooool2o`0008oooooo0_l0
0022ooooo`00<?ooool00ol0003oooooooooo`0Pooooo`;o0000Soooool2o`0008;ooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000Vooooo`Co000000?o410@ooooooooool00oooool00ol0003ooooo
ooooo`0Wooooo`;o0000Soooool2o`0007_ooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool09oooool2o`0008oooooo0_l0001kooooo`00:?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?oooooo=_ooool002Sooooo00?o0000ooooooooool01Oooool3o`00
0?oooooo=_ooool002Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocKo
oooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0L?ooool2o`0008kooooo
0_l0000cooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo073ooooo0_l0
002>ooooo`;o0000<oooool002Kooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`03o`000?oooooooooo02oooooo0_l0002>ooooo`;o0000M?ooool0033ooooo00?o
0000ooooooooool0;oooool2o`0008kooooo0_l0001dooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`0fooooo`;o0000S_ooool2o`0006gooooo000`ooooo`03o`00
0?oooooooooo03Kooooo0_l0002>ooooo`;o0000KOooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`003_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003o
ooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00_o
oooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000oooooolfooooo`00
4?ooool00ol0003oooooooooo`0<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
oooooolfooooo`004?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0mooooo`;o0000Soooool2o`0006Gooooo000@
ooooo`03o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0?Oooool2o`0008oooooo0_l0001Uooooo`003_ooool0
0omEEEGoIVIVo`00000<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0
003oooooocOooooo000`ooooo`03o`000?oooooooooo06Sooooo0_l0002?ooooo`;o0000>_ooool0
033ooooo00?o0000ooooooooool0J?ooool2o`0008oooooo0_l0000jooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0
003oooooocOooooo000`ooooo`03o`000?oooooooooo04Cooooo0_l0002?ooooo`;o0000G_ooool0
033ooooo00?o0000ooooooooool0A?ooool2o`0008oooooo0_l0001Nooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000
COooool2o`0008kooooo0_l0001Gooooo`00<?ooool00ol0003oooooooooo`1<ooooo`;o0000S_oo
ool2o`0005Oooooo000Fooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000
ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3o
ooooocKooooo000Hooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Qooooo`;o0000Soooool2o`00047ooooo000Hooooo`03o`000?oooooooooo00ko
oooo00?oMgMgoc8b<_ooool01?ooool3o`00067ooooo0_l0002?ooooo`;o0000@Oooool001Sooooo
00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool0Doooool2o`0008kooooo0_l0001@ooooo`006?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0Doooool2o`0008kooooo0_l0001@ooooo`006?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooo
oolfooooo`005_ooool00omEEEGoIVIVo`00000=ooooo`Co00001_ooool00ol0003oooooooooo`1J
ooooo`;o0000Soooool2o`0004Sooooo000`ooooo`;o0000Foooool2o`0008oooooo0_l00018oooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`003_ooool4o`000003oa0@4?oooooooooo00;o
oooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool01?ooool2ob4Q8@Ko
oooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0013ooooo00?o0000ooooooooool03?ooool00onYZJWoEEEEooooo`08ooooo`03o`00
0?oooooooooo00?ooooo0ol0003oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?o
8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0013ooooo00?o0000ooooooooool03Oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooo
oooo00gooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool02_ooool01Ol@413ooooooooooooooooo
<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000>oooo
o`03oeEEEOmVIVKo000000cooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool002Gooooo1Ol00006ooooo`03o`000?oooooooooo0?oo
oooo=_ooool002Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0?oo
oooo=_ooool002Kooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`3oooooocKooooo
000Wooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003oooooocKooooo000Xooooo`03ogMgMomVIVKo
oooo0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`009Oooool01Ol0003o
^[ZjoooooonHV9So410@0?oooooo?oooool002Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c03ooooo
ocoooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Xooooo`05oiRHV?l0003o
0000odA4A?nj^[X06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^
k_lb<S;o0000oa0@4?o<c<`0S_ooool00:Sooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko
00002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B40S_ooool00:Sooooo00?o0000ooooooooool06_ooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go0000ooooooooooooooooo`00002>ooooo`00Z?ooool00ol0003oooooooooo`0;
ooooo`Ko00002Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RH
ob4Q8@2>ooooo`00Z?ooool00ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool00000
2oooool01Ol0003oEEEEo`000?l@413oc<c<08kooooo002Vooooo`03oa0@4?l0003o000000?o0000
6Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0T?ooool00:Sooooo
00?o0000ooooooooool06_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nH
V9P0T?ooool00:Sooooo00?o0000ooooooooool06_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo00Coc<c<odA4A?l0003o410@S_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.66) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .16006 Mdot
.04762 .16384 Mdot
.07143 .17855 Mdot
.09524 .20059 Mdot
.11905 .22724 Mdot
.14286 .25625 Mdot
.16667 .28608 Mdot
.19048 .31587 Mdot
.21429 .34523 Mdot
.2381 .37393 Mdot
.2619 .4016 Mdot
.28571 .42743 Mdot
.30952 .4497 Mdot
.33333 .46457 Mdot
.35714 .46399 Mdot
.38095 .43427 Mdot
.40476 .36646 Mdot
.42857 .28041 Mdot
.45238 .21126 Mdot
.47619 .17299 Mdot
.5 .16006 Mdot
.52381 .16384 Mdot
.54762 .17855 Mdot
.57143 .20059 Mdot
.59524 .22724 Mdot
.61905 .25625 Mdot
.64286 .28608 Mdot
.66667 .31587 Mdot
.69048 .34523 Mdot
.71429 .37393 Mdot
.7381 .4016 Mdot
.7619 .42743 Mdot
.78571 .4497 Mdot
.80952 .46457 Mdot
.83333 .46399 Mdot
.85714 .43427 Mdot
.88095 .36646 Mdot
.90476 .28041 Mdot
.92857 .21126 Mdot
.95238 .17299 Mdot
.97619 .16006 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo0_l0002?oooo
o`;o0000S_ooool2o`0001Kooooo000Eooooo`05o`000?ooooooooooooooool000003?ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Cooooo0_l0002?ooooo`;o0000S_ooool2o`0001Kooooo000Eoooo
o`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00?ooooo0_l0002?ooooo`;o0000Woooool001Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool2o`0008oooooo0_l0002O
ooooo`005Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000Q_ooool2
o`0008oooooo0_l0000Mooooo`00<?ooool00ol0003oooooooooo`25ooooo`;o0000Soooool2o`00
01gooooo000`ooooo`03o`000?oooooooooo00_ooooo0_l0002>ooooo`;o0000V?ooool0033ooooo
00?o0000ooooooooool02oooool2o`0008kooooo0_l0002Hooooo`00<?ooool2o`000?oooooo=ooo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool2o`0001?ooooo0_l0002>ooooo`;o0000TOooool0033ooooo00?o0000
ooooooooool04_ooool2o`0008kooooo0_l0002Aooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo07kooooo0_l0002?ooooo`;o00009?ooool0033ooooo
00?o0000ooooooooool0O_ooool2o`0008oooooo0_l0000Tooooo`00<?ooool2o`000?oooooo=ooo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgM
g@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool06Oooool2o`0008kooooo0_l0002:ooooo`003Oooool01Ol@413ooooooooooooo
oooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o00006Ooo
ool2o`0008kooooo0_l0002:ooooo`003Oooool01Ol0003ooooooooooooooooo000000kooooo00?o
8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_oo
ool000gooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00Go
410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`3oooooocKooooo000=ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Co
oooo1?l00006ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool08?ooool2
o`0008oooooo0_l00022ooooo`00<?ooool00ol0003oooooooooo`0Pooooo`;o0000Soooool2o`00
08;ooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000N?ooool2o`0008ko
oooo0_l0000/ooooo`00<?ooool00ol0003oooooooooo`1gooooo`;o0000S_ooool2o`0002cooooo
000`ooooo`03o`000?oooooooooo02Oooooo0_l0002?ooooo`;o0000Noooool0033ooooo00?o0000
ooooooooool09oooool2o`0008oooooo0_l0001kooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`009_ooool4o`000003oa0@4?oooooooooo00?ooooo
00?o0000ooooooooool0oooooolfooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo=_ooool002Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooocKooooo000Xooooo`03o`000?oooooooooo00Gooooo0ol0003oooooocKooooo000Xooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolfooooo`00:?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo02oooooo0_l0002>ooooo`;o0000M?ooool002Sooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0_ooooo`;o0000S_ooool2o`0007Cooooo000V
ooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`00
0?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0=_ooool2o`0008kooooo0_l0001]ooooo`00<?ooool00ol0003oooooooooo`0fooooo`;o0000
S_ooool2o`0006gooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`1`ooooo`;o0000S_ooool2o`0003?ooooo
000`ooooo`03o`000?oooooooooo073ooooo0_l0002>ooooo`;o0000<oooool0033ooooo0_l0000n
ooooo`;o0000Soooool2o`0006Gooooo000`ooooo`03o`000?oooooooooo03gooooo0_l0002?oooo
o`;o0000IOooool000kooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool5o`0000Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool0013o
oooo00?o0000ooooooooool01?ooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003o
ooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`000?oo
oooo=_ooool0013ooooo00?o0000ooooooooool03?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003ooooooooo
o`0=ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolfooooo`004?ooool0
0ol0003oooooooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0?oooooo=_ooool000kooooo00?oEEEEofIVI_l000003?ooool0
1OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000AOooool2o`0008oooooo0_l0
001Nooooo`00<?ooool00ol0003oooooooooo`14ooooo`;o0000Soooool2o`0005kooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0C?ooool2o`0008kooooo0_l0001Gooooo`00<?ooool2o`0004gooooo
0_l0002>ooooo`;o0000Eoooool0033ooooo00?o0000ooooooooool0J?ooool2o`0008oooooo0_l0
000jooooo`00<?ooool00ol0003oooooooooo`1Xooooo`;o0000Soooool2o`0003[ooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool2o`0005Cooooo0_l0002>ooooo`;o0000D?ooool0033ooooo00?o0000ooooooooool0Dooo
ool2o`0008kooooo0_l0001@ooooo`005_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000H
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`0>ooooo`03
ogMgMolb<S;ooooo00Cooooo0ol0001Jooooo`;o00001Oooool2o`0008Sooooo0_l00005ooooo`;o
0000@Oooool001Sooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool0F_ooool2o`0000Gooooo0_l00028ooooo`;o00001Oooool2o`00047o
oooo000Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooocKooooo000Fooooo`03oeEEEOmVIVKo000000gooooo1?l00006
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000>ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Ko
oooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGo
ZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`00
4?ooool00ol0003oooooooooo`0<ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool0
0oooool3o`000?oooooo=_ooool0013ooooo00?o0000ooooooooool03Oooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`004?ooool0
0ol0003oooooooooo`0=ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool03Oooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`004?ooool00ol0003oooooooooo`0:ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool000kooooo00?oEEEEofIV
I_l000003?ooool5o`0000Cooooo1?l00006ooooo`;o0000oooooolgooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`009Oooool5o`0000Kooooo00?o0000ooooooooool0oooooolfooooo`00
9Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooolfooooo`00
9_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0?oooooo=_ooool002Oooooo00?o
V9RHob4Q8Oo^k^h01_ooool3o`000?oooooo=_ooool002Sooooo00?oMgMgofIVI_ooool0ooooooln
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Uooooo`05o`000?nj^[[ooooooiRH
V?l@4100ooooooloooooo`009Oooool01OnHV9So410@o`000?lQ8B7oc<c<0?oooooo?oooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00:Cooooo00GoV9RHo`000?l0003oA4A4okZj
^P0Hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o
410@olc<c003ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0R_ooool00:Cooooo00Go410@okZj^_o^
k^koMgMgoa0@4009ooooo`Ko00002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmEEEGoMgMgoooooonHV9So8B4Q08[ooooo
002Tooooo`03o`000?oooooooooo01[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000008[ooooo002Tooooo`03
o`000?oooooooooo00_ooooo1_l00009ooooo`05o`000?ooooooooooooooool000002oooool01Ol0
003oV9RHoooooonHV9So8B4Q00?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@2:ooooo`00Y?ooool0
0ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`00
0?l@413oc<c<00?ooooo00Go0000oeEEEOl0003o410@olc<c02:ooooo`00X_ooool00ol@413o0000
o`000003o`0001Wooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Go
oooo00?oEEEEohN7Qoooool0S?ooool00:Cooooo00?o0000ooooooooool06_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P01Oooool00ooMgMgo410@oiRHV02<ooooo`00
Y?ooool00ol0003oooooooooo`0Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<co
A4A4o`000?l@4104ooooo`04olc<c?m4A4Co0000oa0@48[ooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.72) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .17244 Mdot
.04762 .16752 Mdot
.07143 .17666 Mdot
.09524 .19481 Mdot
.11905 .21838 Mdot
.14286 .24481 Mdot
.16667 .27243 Mdot
.19048 .30033 Mdot
.21429 .32809 Mdot
.2381 .35547 Mdot
.2619 .38215 Mdot
.28571 .40752 Mdot
.30952 .43042 Mdot
.33333 .4484 Mdot
.35714 .45635 Mdot
.38095 .44464 Mdot
.40476 .40131 Mdot
.42857 .32816 Mdot
.45238 .25198 Mdot
.47619 .19845 Mdot
.5 .17244 Mdot
.52381 .16752 Mdot
.54762 .17666 Mdot
.57143 .19481 Mdot
.59524 .21838 Mdot
.61905 .24481 Mdot
.64286 .27243 Mdot
.66667 .30033 Mdot
.69048 .32809 Mdot
.71429 .35547 Mdot
.7381 .38215 Mdot
.7619 .40752 Mdot
.78571 .43042 Mdot
.80952 .4484 Mdot
.83333 .45635 Mdot
.85714 .44464 Mdot
.88095 .40131 Mdot
.90476 .32816 Mdot
.92857 .25198 Mdot
.95238 .19845 Mdot
.97619 .17244 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`03ooooo`;o0000Soooool2o`0009oooooo000Eooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool4o`0000Gooooo0ol00004ooooo`;o0000R?ooool2o`0000Gooooo0_l00027
ooooo`;o00005_ooool002oooooo0_l0000=ooooo`;o0000P?ooool2o`0000cooooo0_l00020oooo
o`;o00005_ooool0033ooooo00?o0000ooooooooool02oooool2o`0008kooooo0_l0002Hooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool04_ooool2o`0008kooooo0_l0002Aooooo`00<?ooool00ol0003ooooo
ooooo`0Booooo`;o0000LOooool2o`0001_ooooo0_l0001booooo`;o00007Oooool0033ooooo0_l0
0026ooooo`;o0000Soooool2o`0001gooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0000Jooooo`;o0000S_oo
ool2o`0008[ooooo000`ooooo`03o`000?oooooooooo01Wooooo0_l0002>ooooo`;o0000R_ooool0
00gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000=
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00Go410@
oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00ooo
ool3o`000?oooooo=_ooool000gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooo
oooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=
ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oo
ooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0oooooolfooooo`003Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool08?ooool2o`0008oooooo0_l00022ooooo`003Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo1Ol00004ooooo`Co00001_ooool2o`00027ooooo0_l0002?ooooo`;o0000P_ooool0033ooooo
00?o0000ooooooooool0O_ooool2o`0008oooooo0_l0000Tooooo`00<?ooool00ol0003ooooooooo
o`1nooooo`;o0000Soooool2o`0002Cooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`03o`000?oooooooooo02Oooooo0_l0002?ooooo`;o0000Noooool0033ooooo00?o0000oooo
ooooool09oooool2o`0008oooooo0_l0001kooooo`00<?ooool2o`000?oooooo=oooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool002Kooooo1?l000000ol@413oooooooooo`03ooooo`03o`00
0?oooooooooo02oooooo0_l0002>ooooo`;o0000M?ooool002Sooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0_ooooo`;o0000S_ooool2o`0007Cooooo000Xooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0oooooolfooooo`00:?ooool00ol0003oooooooooo`05oooo
o`?o0000oooooolfooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
oooo=_ooool002Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocKooooo
000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolfooooo`009_ooool0
0omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0000goooo
o`;o0000?oooool2o`0004gooooo0_l0000oooooo`;o0000;?ooool0033ooooo00?o0000oooooooo
ool0=_ooool2o`0003oooooo0_l0001=ooooo`;o0000?oooool2o`0002cooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`0003kooooo0_l0002?ooooo`;o0000IOooool0
033ooooo00?o0000ooooooooool0?Oooool2o`0008oooooo0_l0001Uooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`003_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`Go
00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfoooo
o`004?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A4
00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`14ooooo`;o0000Soooool2o`00
05kooooo000@ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003o
ooooooooo`03ooooo`?o0000A?ooool2o`0008oooooo0_l0001Nooooo`004?ooool00ol0003ooooo
ooooo`0<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`004?oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00[ooooo00Go0000
okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooo
oolfooooo`003_ooool00omEEEGoIVIVo`00000<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?oo
ool4o`0000Kooooo0_l0001aooooo`;o0000S_ooool2o`0003?ooooo000`ooooo`03o`000?oooooo
oooo073ooooo0_l0002>ooooo`;o0000<oooool0033ooooo00?o0000ooooooooool0C?ooool2o`00
08kooooo0_l0001Gooooo`00<?ooool00ol0003oooooooooo`1<ooooo`;o0000S_ooool2o`0005Oo
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`1Cooooo`;o0000S_ooool2o`00053ooooo000`ooooo`;o0000
E?ooool2o`0008kooooo0_l0001@ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`1Xooooo`;o0000Soooool2o`0003[ooooo000`ooooo`;o0000
Foooool2o`0000cooooo0_l00021ooooo`;o00003?ooool2o`0003[ooooo000`ooooo`03o`000?oo
oooooooo05[ooooo0_l0002?ooooo`;o0000B?ooool001Kooooo1?l000000ol@413oooooooooo`02
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0HOoo
ool2o`0008oooooo0_l00011ooooo`006?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo067ooooo0_l0002?ooooo`;o0000@Oooool0
01Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
0?oooooo=_ooool001Sooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`04ooooo`?o
0000oooooolfooooo`006?ooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000F
ooooo`03oeEEEOmVIVKo000000gooooo1?l00006ooooo`03o`000?oooooooooo0?oooooo=_ooool0
033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000>ooooo`Co
000000?o410@ooooooooool00_ooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003o
ooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0<ooooo`03ojVY
ZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool0013ooooo00?o
0000ooooooooool03Oooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0=ooooo`03oeEEEOo<c<co
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0013ooooo00?o0000ooooooooool03Oooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0:oooo
o`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0?oooooo=_ooool000kooooo00?oEEEEofIVI_l000003?ooool5o`0000Cooooo1?l00006oooo
o`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`009Oooool5o`0000Ko
oooo00?o0000ooooooooool0oooooolfooooo`009Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Ko
oooo00?o0000ooooooooool0oooooolfooooo`009_ooool00onHV9So8B4Qonk^kP07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool002Oooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000?oooooo=_oo
ool002Sooooo00?oMgMgofIVI_ooool0oooooolnooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Uooooo`05o`000?nj^[[ooooooiRHV?l@4100ooooooloooooo`009Oooool01OnHV9So
410@o`000?lQ8B7oc<c<0?oooooo?oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00:Cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool00oooool5o`0008[ooooo002Tooooo`05oa0@4?nj
^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`03ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0R_ooool00:Co
oooo00?o0000ooooooooool06_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEE
EOooool01?ooool00onHV9So8B4Qonk^kP2;ooooo`00Y?ooool00ol0003oooooooooo`0;ooooo`Ko
00002Oooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01?ooool00onH
V9So8B4Qonk^kP2:ooooo`00Y?ooool00ol0003oooooooooo`0Jooooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`05ooooo`03ogMgMomVIVKooooo08Wooooo002Rooooo`03
oa0@4?l0003o000000?o00006Oooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool01_ooool00ol0003oooooooooo`28ooooo`00Y?ooool00ol0003oooooooooo`0Jooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00?ooooo00Go0000
okZj^_ooooooV9RHoa0@402:ooooo`00Y?ooool00ol0003oooooooooo`0Jooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool5o`0000?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c02:ooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.78) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .19186 Mdot
.04762 .17637 Mdot
.07143 .17834 Mdot
.09524 .1916 Mdot
.11905 .21161 Mdot
.14286 .23528 Mdot
.16667 .26067 Mdot
.19048 .28672 Mdot
.21429 .31291 Mdot
.2381 .33892 Mdot
.2619 .36444 Mdot
.28571 .389 Mdot
.30952 .41176 Mdot
.33333 .43112 Mdot
.35714 .44381 Mdot
.38095 .44343 Mdot
.40476 .41998 Mdot
.42857 .36651 Mdot
.45238 .29478 Mdot
.47619 .23123 Mdot
.5 .19186 Mdot
.52381 .17637 Mdot
.54762 .17834 Mdot
.57143 .1916 Mdot
.59524 .21161 Mdot
.61905 .23528 Mdot
.64286 .26067 Mdot
.66667 .28672 Mdot
.69048 .31291 Mdot
.71429 .33892 Mdot
.7381 .36444 Mdot
.7619 .389 Mdot
.78571 .41176 Mdot
.80952 .43112 Mdot
.83333 .44381 Mdot
.85714 .44343 Mdot
.88095 .41998 Mdot
.90476 .36651 Mdot
.92857 .29478 Mdot
.95238 .23123 Mdot
.97619 .19186 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo00?ooooo0_l0002?oooo
o`;o0000Woooool0033ooooo00?o0000ooooooooool00oooool2o`0000Kooooo0_l00027ooooo`;o
00001Oooool2o`0009Sooooo000`ooooo`03o`000?oooooooooo00_ooooo0_l0002>ooooo`;o0000
V?ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0
02oooooo0_l0000Dooooo`;o0000NOooool2o`0001?ooooo0_l0001iooooo`;o00005_ooool002oo
oooo0_l0000Dooooo`;o0000NOooool2o`0001?ooooo0_l0001iooooo`;o00005_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000
ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03
o`000?oooooooooo01Wooooo0_l0002>ooooo`;o0000R_ooool0033ooooo00?o0000ooooooooool0
6Oooool2o`0008kooooo0_l0002:ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000
ooooooooool0oooooolfooooo`003Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46
ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_oo
ool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooo
oolfooooo`003Oooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?oo
ool00ol0003oooooooooo`03ooooo`?o0000QOooool2o`0008oooooo0_l0000Mooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo023ooooo0_l0001Sooooo`;o0000:_ooool2o`0006?ooooo0_l0
000Mooooo`003Oooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool08?ooool2o`0008oooooo
0_l00022ooooo`003Oooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool0
0oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo02Oooooo0_l0002?oooo
o`;o0000Noooool0033ooooo0_l0000Xooooo`;o0000Soooool2o`0007_ooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0;oooool2o`0008kooooo0_l0001dooooo`00<?ooool00ol0003oooooooooo`0_
ooooo`;o0000S_ooool2o`0007Cooooo000`ooooo`;o0000Ooooool2o`0008oooooo0_l0000Toooo
o`00<?ooool00ol0003oooooooooo`1nooooo`;o0000Soooool2o`0002Cooooo000Vooooo`Co0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`3oooooocKooooo000Xooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooolfooooo`00:?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?oooooo=_ooool002Sooooo00?o0000ooooooooool01Oooool3o`00
0?oooooo=_ooool002Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0fooooo`;o
0000S_ooool2o`0006gooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
=_ooool2o`0008kooooo0_l0001]ooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo=_ooool002Kooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`00<?ooool2o`0003kooooo0_l0002?ooooo`;o0000IOooool0033ooooo00?o0000oooo
ooooool0?Oooool2o`0008oooooo0_l0001Uooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`14ooooo`;o0000Soooool2o`0005kooooo000`ooooo`03o`00
0?oooooooooo04Cooooo0_l0000aooooo`;o0000G?ooool2o`00033ooooo0_l0000/ooooo`00<?oo
ool00ol0003oooooooooo`1gooooo`;o0000S_ooool2o`0002cooooo000`ooooo`;o0000oooooolg
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000>ooooo`Co000000?o410@oooooooo
ool00_ooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
0?oooooo=_ooool0013ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP09ooooo`03
o`000?oooooooooo00?ooooo0ol0003oooooocKooooo000@ooooo`03o`000?oooooooooo00cooooo
00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo04cooooo
0_l0002>ooooo`;o0000Eoooool0013ooooo00?o0000ooooooooool03Oooool00omgMgOoIVIVoooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`1<ooooo`;o0000
S_ooool2o`0005Oooooo000@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000
ooooooooool02_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooocKooooo000>ooooo`03oeEEEOmVIVKo000000cooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`000?oooooo=oooool0033ooooo00?o0000
ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03
o`000?oooooooooo05?ooooo0_l0002>ooooo`;o0000D?ooool0033ooooo00?o0000ooooooooool0
Doooool2o`0008kooooo0_l0001@ooooo`00<?ooool2o`00077ooooo0_l0002>ooooo`;o0000<ooo
ool0033ooooo00?o0000ooooooooool0L?ooool2o`0008kooooo0_l0000cooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
0_l0001Kooooo`;o0000Soooool2o`0004Sooooo000`ooooo`03o`000?oooooooooo05[ooooo0_l0
002?ooooo`;o0000B?ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0
003oooooooooo`1Xooooo`;o0000Soooool2o`0003[ooooo000`ooooo`03o`000?oooooooooo067o
oooo0_l00005ooooo`;o0000R?ooool2o`0000Gooooo0_l0000jooooo`00<?ooool2o`0006;ooooo
0_l0002?ooooo`;o0000@Oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`005_ooool4
o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00Cooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`006?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooolfoooo
o`006?ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0003oooooocKo
oooo000Hooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool001Kooooo00?oEEEE
ofIVI_l000003Oooool4o`0000Kooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`00
0?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000kooooo1?l000000ol@413o
ooooooooo`02ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00Co
oooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00cooooo00?oZJVYoeEEEOooool0
2?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolfooooo`004?ooool00ol0003ooooooooo
o`0=ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?oEEEEolc<c?ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`004?ooool0
0ol0003oooooooooo`0=ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00[ooooo00Go410@oooo
oooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`003_ooool00omEEEGoIVIVo`00000<ooooo`Go00001?ooool4o`0000Kooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolg
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000Uooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooocKooooo000Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooocKooooo000Vooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0
oooooolfooooo`009oooool00onHV9So8B4Qonk^kP06ooooo`?o0000oooooolfooooo`00:?ooool0
0omgMgOoIVIVooooo`3oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Go
oooo00Go0000okZj^_ooooooV9RHoa0@403oooooocoooooo000Uooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`0ooooooloooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Y?ooool0
1OnHV9So0000o`000?m4A4Co^[Zj01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1_ooool00ol0003ok^k^ooooo`03ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0R_ooool00:Cooooo
00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00?ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@2:
ooooo`00Y?ooool00ol0003oooooooooo`0Jooooo`05oa0@4?ooooooooooooooool@41003Oooool0
0onYZJWoEEEEooooo`03ooooo`05o`000?ooooooooooooooool00000R_ooool00:Cooooo00?o0000
ooooooooool02oooool6o`0000Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooo
oooooooo00;ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P2:ooooo`00Y?ooool00ol0003ooooooooo
o`0Jooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`02ooooo`05olc<
c?l0003o0000o`000?o<c<`0R_ooool00:;ooooo00?o410@o`000?l000000ol0000Iooooo`05oa0@
4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`02ooooo`05oa0@4?nj^[[ooooookZj
^_l@4100R_ooool00:Cooooo00?o0000ooooooooool06_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00Go410@oooooooooooooooooc8b<P03ooooo`05o`000?nj^[[ooooookZj^_l00000R_oo
ool00:Cooooo00?o0000ooooooooool06_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol0
0003ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0R_ooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.84) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .21807 Mdot
.04762 .19109 Mdot
.07143 .18426 Mdot
.09524 .19139 Mdot
.11905 .20713 Mdot
.14286 .22768 Mdot
.16667 .2507 Mdot
.19048 .27486 Mdot
.21429 .29944 Mdot
.2381 .32404 Mdot
.2619 .3483 Mdot
.28571 .37183 Mdot
.30952 .394 Mdot
.33333 .41374 Mdot
.35714 .42893 Mdot
.38095 .43543 Mdot
.40476 .42593 Mdot
.42857 .39187 Mdot
.45238 .33339 Mdot
.47619 .26826 Mdot
.5 .21807 Mdot
.52381 .19109 Mdot
.54762 .18426 Mdot
.57143 .19139 Mdot
.59524 .20713 Mdot
.61905 .22768 Mdot
.64286 .2507 Mdot
.66667 .27486 Mdot
.69048 .29944 Mdot
.71429 .32404 Mdot
.7381 .3483 Mdot
.7619 .37183 Mdot
.78571 .394 Mdot
.80952 .41374 Mdot
.83333 .42893 Mdot
.85714 .43543 Mdot
.88095 .42593 Mdot
.90476 .39187 Mdot
.92857 .33339 Mdot
.95238 .26826 Mdot
.97619 .21807 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o00003?ooool2o`0008kooooo0_l0002Hooooo`00<?ooool00ol0003oooooooooo`0;
ooooo`;o0000S_ooool2o`0009Sooooo000`ooooo`03o`000?oooooooooo00?ooooo0_l0000=oooo
o`;o0000P?ooool2o`0000cooooo0_l0002Aooooo`00<?ooool00ol0003oooooooooo`03ooooo`;o
00003Oooool2o`00083ooooo0_l0000<ooooo`;o0000TOooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool00ol0003oooooooooo`0Iooooo`;o0000S_ooool2o`0008[ooooo000`ooooo`03
o`000?oooooooooo01Wooooo0_l0002>ooooo`;o0000R_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00;oooool3o`0008kooooo0_l0002>ooooo`;o00005_ooool002oooooo0_l0002?
ooooo`;o0000S_ooool2o`0001Kooooo000=ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`0Pooooo`;o0000Soooool2o`0008;ooooo000=ooooo`05oa0@4?ooooooooooooooool@41003Ooo
ool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0000Pooooo`;o0000Sooo
ool2o`0008;ooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo02Oooooo0_l0002?ooooo`;o0000
Noooool0033ooooo00?o0000ooooooooool09oooool2o`0008oooooo0_l0001kooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo08Gooooo0_l0002?ooooo`;o0000
7Oooool0033ooooo00?o0000ooooooooool0QOooool2o`0008oooooo0_l0000Mooooo`00<?ooool0
0ol0003oooooooooo`0_ooooo`;o0000S_ooool2o`0007Cooooo000`ooooo`03o`000?oooooooooo
02oooooo0_l0002>ooooo`;o0000M?ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000Vooooo`Co000000?o410@ooooooooool00oooool00ol0003ooooo
ooooo`0fooooo`;o0000S_ooool2o`0006gooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0=_ooool2o`0008kooooo0_l0001]ooooo`00:?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?oooooo=_ooool002Sooooo00?o0000ooooooooool01Oooool3o`00
0?oooooo=_ooool002Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocKo
oooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolfooooo`00:?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo=_ooool002Kooooo00?oEEEE
ofIVI_l000001oooool00ol0003oooooooooo`0mooooo`;o0000Soooool2o`0006Gooooo000`oooo
o`;o0000?_ooool2o`0008oooooo0_l0001Uooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`03o`000?oooooooooo07kooooo0_l0002?ooooo`;o00009?ooool0033ooooo00?o
0000ooooooooool0O_ooool2o`0008oooooo0_l0000Tooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`03o`000?oooooooooo04Cooooo0_l0002?ooooo`;o0000G_ooool0033ooooo00?o
0000ooooooooool0A?ooool2o`0008oooooo0_l0001Nooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`00<?ooool2o`0004gooooo0_l0002>ooooo`;o0000Eoooool0033ooooo00?o0000oooo
ooooool0C?ooool2o`0008kooooo0_l0001Gooooo`003_ooool4o`000003oa0@4?oooooooooo00;o
oooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooo
ocKooooo000@ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003o
ooooooooo`03ooooo`?o0000oooooolfooooo`004?ooool00ol0003oooooooooo`0<ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo
000@ooooo`03o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0Doooool2o`0002;ooooo0_l0001Zooooo`;o0000
8_ooool2o`0002cooooo000@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05?ooooo0_l0000Rooooo`;o0000J_oo
ool2o`0002;ooooo0_l0000/ooooo`004?ooool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[o
oooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_oo
ool000kooooo00?oEEEEofIVI_l000003?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0
0006ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0F_ooool2o`0008oo
oooo0_l00018ooooo`00<?ooool00ol0003oooooooooo`1Jooooo`;o0000Soooool2o`0004Sooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo073ooooo0_l0002>ooooo`;o0000<oooool0033ooooo00?o0000oooooooo
ool0HOooool2o`0000gooooo0_l00020ooooo`;o00003?ooool2o`0003?ooooo000`ooooo`;o0000
H_ooool2o`0008oooooo0_l00011ooooo`00<?ooool00ol0003oooooooooo`1Xooooo`;o0000Sooo
ool2o`0003[ooooo000`ooooo`03o`000?oooooooooo06Sooooo0_l0002?ooooo`;o0000>_ooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000F
ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@05ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool01?ooool2
ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000Hoooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooo
ocKooooo000Hooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool3o`000?oo
oooo=_ooool001Sooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooolfooooo`006?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolfooooo`005_ooool0
0omEEEGoIVIVo`00000=ooooo`Co00001_ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`003_ooool4o`000003
oa0@4?oooooooooo00;ooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000oooooooo
ool01?ooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool03?ooool00onYZJWoEEEE
ooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocKooooo000@ooooo`03o`000?oo
oooooooo00gooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool03Oooool00omEEEGoc<c<ooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKooooo000@
ooooo`03o`000?oooooooooo00gooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool02_ooool01Ol@
413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3o
ooooocKooooo000>ooooo`03oeEEEOmVIVKo000000cooooo1Ol00004ooooo`Co00001_ooool2o`00
0?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000
ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool002Gooooo1Ol00006ooooo`03
o`000?oooooooooo0?oooooo=_ooool002Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03
o`000?oooooooooo0?oooooo=_ooool002Kooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003ooooo
ooooo`3oooooocKooooo000Wooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003oooooocKooooo000X
ooooo`03ogMgMomVIVKooooo0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`009Oooool01Ol0003o^[ZjoooooonHV9So410@0?oooooo?oooool002Gooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c03oooooocoooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002T
ooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01Oooool2o`000003oa0@4?oooooooooo08So
oooo002Tooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000
ooooooooool0ROooool00:Cooooo00?o0000ooooooooool06_ooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go0000ooooooooooooooooo`000003ooooo`Go0000R_ooool00:Cooooo00?o0000
ooooooooool02oooool6o`0000Wooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nH
V9SooooooiRHV?lb<S800oooool01?m4A4CogMgMooooool0002;ooooo`00Y?ooool00ol0003ooooo
ooooo`0Jooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<
00?ooooo00CogMgMoeEEEOoooooo0000Roooool00:;ooooo00?o410@o`000?l000000ol0000Ioooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Cooooo00?o
MgMgolc<c?l00000Roooool00:Cooooo00?o0000ooooooooool06_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000004ooooo`03onk^k_m4A4Co000008_ooooo
002Tooooo`03o`000?oooooooooo01[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01Oooool00omgMgOo0000ooooo`2:ooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .24932 Mdot
.04762 .21178 Mdot
.07143 .19505 Mdot
.09524 .19474 Mdot
.11905 .20525 Mdot
.14286 .22215 Mdot
.16667 .24251 Mdot
.19048 .26461 Mdot
.21429 .28751 Mdot
.2381 .31062 Mdot
.2619 .33355 Mdot
.28571 .35592 Mdot
.30952 .37725 Mdot
.33333 .3968 Mdot
.35714 .41321 Mdot
.38095 .42377 Mdot
.40476 .42347 Mdot
.42857 .40495 Mdot
.45238 .36306 Mdot
.47619 .30481 Mdot
.5 .24932 Mdot
.52381 .21178 Mdot
.54762 .19505 Mdot
.57143 .19474 Mdot
.59524 .20525 Mdot
.61905 .22215 Mdot
.64286 .24251 Mdot
.66667 .26461 Mdot
.69048 .28751 Mdot
.71429 .31062 Mdot
.7381 .33355 Mdot
.7619 .35592 Mdot
.78571 .37725 Mdot
.80952 .3968 Mdot
.83333 .41321 Mdot
.85714 .42377 Mdot
.88095 .42347 Mdot
.90476 .40495 Mdot
.92857 .36306 Mdot
.95238 .30481 Mdot
.97619 .24932 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool02oooool2o`0000Go
oooo0_l00027ooooo`;o00001Oooool2o`00097ooooo000`ooooo`03o`000?oooooooooo00_ooooo
0_l00005ooooo`;o0000Qoooool2o`0000Gooooo0_l0002Aooooo`00<?ooool2o`000?oooooo=ooo
ool0033ooooo00?o0000ooooooooool06Oooool2o`0008kooooo0_l0002:ooooo`00<?ooool00ol0
003oooooooooo`0Iooooo`;o0000S_ooool2o`0008[ooooo000`ooooo`03o`000?oooooooooo00?o
oooo0_l0002?ooooo`;o0000Woooool0033ooooo00?o0000ooooooooool00oooool2o`0008oooooo
0_l0002Oooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool08?ooool2
o`0008oooooo0_l00022ooooo`003Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46
ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo023ooooo0_l0002?ooooo`;o0000P_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooooooooooo410@00gooooo00?o
ZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00Go0000ooooooooooooooooo`00
000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVY
ZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Wooooo`;o0000
Soooool2o`0007_ooooo000=ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooo
oooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Wooooo`;o
0000Soooool2o`0007_ooooo000=ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Co
oooo1?l00006ooooo`;o0000oooooolgooooo`00;oooool2o`0008oooooo0_l0002>ooooo`;o0000
5_ooool002oooooo0_l0002?ooooo`;o0000S_ooool2o`0001Kooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`00033o
oooo0_l0002>ooooo`;o0000M?ooool0033ooooo00?o0000ooooooooool0;oooool2o`0008kooooo
0_l0001dooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oo
oooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`0fooooo`;o0000S_ooool2o`0006gooooo000`ooooo`03o`000?oooooooooo03Kooooo0_l0002>
ooooo`;o0000KOooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool002Kooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo
=_ooool002Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`25ooooo`;o0000Sooo
ool2o`0001gooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0QOooool2
o`0008oooooo0_l0000Mooooo`00:?ooool00ol0003oooooooooo`05ooooo`?o0000?Oooool2o`00
08oooooo0_l0001Uooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03go
oooo0_l0002?ooooo`;o0000IOooool002Sooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3oooooocKooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooo
oolfooooo`009_ooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo0?oooooo=_ooool0
033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0A?ooool2o`0008oooooo0_l0001Nooooo`00<?ooool00ol0003ooooooooo
o`14ooooo`;o0000Soooool2o`0005kooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000COooool2o`0008kooooo0_l0001Gooooo`00<?ooool00ol0003oooooooooo`1<oooo
o`;o0000S_ooool2o`0005Oooooo000`ooooo`03o`000?oooooooooo07kooooo0_l0002?ooooo`;o
00009?ooool0033ooooo00?o0000ooooooooool0O_ooool2o`0008oooooo0_l0000Tooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`1Cooooo`;o0000S_ooool2o`00053ooooo000>ooooo`Co000000?o410@oooooooo
ool00_ooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`1Cooooo`;o0000S_ooool2o`00053ooooo000@ooooo`03o`000?oooooooooo00Co
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool02oooool00onHV9So
8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocKooooo000@ooooo`03o`00
0?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool03Oooool00omgMgOoIVIVoooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKooooo
000@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo05[ooooo0_l0002?ooooo`;o0000B?ooool0013ooooo00?o0000
ooooooooool02_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`1Jooooo`;o0000Soooool2o`0004Sooooo000>ooooo`03oeEEEOmVIVKo
000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`000?oooooo=ooo
ool0033ooooo00?o0000ooooooooool0Moooool2o`0008kooooo0_l0000/ooooo`00<?ooool00ol0
003oooooooooo`1gooooo`;o0000S_ooool2o`0002cooooo000`ooooo`03o`000?oooooooooo067o
oooo0_l0002?ooooo`;o0000@Oooool0033ooooo00?o0000ooooooooool0HOooool2o`0008oooooo
0_l00011ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0J?ooool2
o`0000Kooooo0_l00027ooooo`;o00001Oooool2o`0003?ooooo000`ooooo`03o`000?oooooooooo
06Sooooo0_l00006ooooo`;o0000Qoooool2o`0000Gooooo0_l0000cooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000
oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000Fooooo`Co000000?o410@
ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03
o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool3o`000?oooooo=_ooool001Sooooo
00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool0oooooolfooooo`006?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0oooooolfooooo`005_ooool00omEEEGoIVIVo`00000=
ooooo`Co00001_ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`003_ooool4o`000003oa0@4?oooooooooo00;o
oooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool01?ooool2ob4Q8@Ko
oooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0013ooooo00?o0000ooooooooool03?ooool00onYZJWoEEEEooooo`08ooooo`03o`00
0?oooooooooo00?ooooo0ol0003oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?o
8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0013ooooo00?o0000ooooooooool03Oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooo
oooo00gooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool02_ooool01Ol@413ooooooooooooooooo
<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000>oooo
o`03oeEEEOmVIVKo000000cooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool002Gooooo1Ol00006ooooo`03o`000?oooooooooo0?oo
oooo=_ooool002Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0?oo
oooo=_ooool002Kooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`3oooooocKooooo
000Wooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003oooooocKooooo000Xooooo`03ogMgMomVIVKo
oooo0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`009Oooool01Ol0003o
^[ZjoooooonHV9So410@0?oooooo?oooool002Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c03ooooo
ocoooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Xooooo`05oiRHV?l0003o
0000odA4A?nj^[X06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`04oa0@
4?l0003oA4A4olc<c8oooooo002Xooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00onHV9So410@omgMg@2>oooo
o`00Z?ooool00ol0003oooooooooo`0Jooooo`05oa0@4?ooooooooooooooool@41003_ooool00on7
QhOoEEEEooooo`2=ooooo`00Z?ooool00ol0003oooooooooo`0;ooooo`Ko00002Oooool01Ol0003o
oooooooooooooooo000000_ooooo00Goc<c<ob4Q8Ol0003oEEEEo`00002>ooooo`00Z?ooool00ol0
003oooooooooo`0Jooooo`05o`000?ooooooooooooooool000002oooool01OlQ8B7oQhN7oooooonH
V9So000008kooooo002Vooooo`03oa0@4?l0003o000000?o00006Oooool01Ol@413ooooooooooooo
oooo410@00_ooooo00Go0000ooooooooooooooooo`00002>ooooo`00Z?ooool00ol0003ooooooooo
o`0Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01OlQ8B7oV9RHoooooomgMgOoEEEE08ko
oooo002Xooooo`03o`000?oooooooooo01[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
olc<c?l@413o0000oc8b<_o^k^h0S_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.96) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .28234 Mdot
.04762 .23753 Mdot
.07143 .21098 Mdot
.09524 .20218 Mdot
.11905 .20642 Mdot
.14286 .21891 Mdot
.16667 .23616 Mdot
.19048 .25595 Mdot
.21429 .277 Mdot
.2381 .29853 Mdot
.2619 .32005 Mdot
.28571 .34118 Mdot
.30952 .36153 Mdot
.33333 .3806 Mdot
.35714 .39748 Mdot
.38095 .4104 Mdot
.40476 .41598 Mdot
.42857 .40866 Mdot
.45238 .38223 Mdot
.47619 .33622 Mdot
.5 .28234 Mdot
.52381 .23753 Mdot
.54762 .21098 Mdot
.57143 .20218 Mdot
.59524 .20642 Mdot
.61905 .21891 Mdot
.64286 .23616 Mdot
.66667 .25595 Mdot
.69048 .277 Mdot
.71429 .29853 Mdot
.7381 .32005 Mdot
.7619 .34118 Mdot
.78571 .36153 Mdot
.80952 .3806 Mdot
.83333 .39748 Mdot
.85714 .4104 Mdot
.88095 .41598 Mdot
.90476 .40866 Mdot
.92857 .38223 Mdot
.95238 .33622 Mdot
.97619 .28234 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o00004oooool2o`0008kooooo0_l0
002Aooooo`00<?ooool00ol0003oooooooooo`0Booooo`;o00001Oooool2o`0008Oooooo0_l00005
ooooo`;o0000R_ooool0033ooooo00?o0000ooooooooool06Oooool2o`0008kooooo0_l0002:oooo
o`00<?ooool00ol0003oooooooooo`0;ooooo`;o0000S_ooool2o`0009Sooooo000`ooooo`03o`00
0?oooooooooo00_ooooo0_l0002>ooooo`;o0000V?ooool0033ooooo0_l0000Qooooo`;o0000Sooo
ool2o`0008;ooooo000`ooooo`03o`000?oooooooooo023ooooo0_l0002?ooooo`;o0000P_ooool0
00gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000=
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00Go410@
oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00ooo
ool3o`000?oooooo=_ooool000gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooo
oooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=
ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`03ooooo`;o00008_ooool2o`0006_ooooo
0_l0000Rooooo`;o0000Noooool000gooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVY
ZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`;o0000
8_ooool2o`0006_ooooo0_l0000Rooooo`;o0000Noooool000gooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0?oooooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go
00001?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`0_
ooooo`;o0000S_ooool2o`0007Cooooo000`ooooo`03o`000?oooooooooo02oooooo0_l0002>oooo
o`;o0000M?ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`03o`000?oooooooooo03Kooooo0_l0002>ooooo`;o0000KOooool0033o
oooo0_l0000gooooo`;o0000S_ooool2o`0006gooooo000_ooooo`;o0000Soooool2o`0008kooooo
0_l0000Fooooo`00;oooool2o`0008oooooo0_l0002>ooooo`;o00005_ooool0033ooooo00?o0000
ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooooooo
ool0?Oooool2o`0008oooooo0_l0001Uooooo`009_ooool4o`000003oa0@4?oooooooooo00?ooooo
00?o0000ooooooooool0?Oooool2o`0008oooooo0_l0001Uooooo`00:?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0?oooooo=_ooool002Sooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`3oooooocKooooo000Xooooo`03o`000?oooooooooo00Gooooo0ol0003ooooo
ocKooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolfooooo`00
:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo=_ooool002Sooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`14ooooo`;o0000Soooool2o`0005kooooo000V
ooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0A?ooool2o`0008oooooo0_l0001N
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo08Gooooo0_l0
002?ooooo`;o00007Oooool0033ooooo0_l0001=ooooo`;o0000=oooool2o`0005Gooooo0_l0000h
ooooo`;o00007Oooool0033ooooo00?o0000ooooooooool0C?ooool2o`0008kooooo0_l0001Goooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`1Cooooo`;o
0000S_ooool2o`00053ooooo000`ooooo`03o`000?oooooooooo05?ooooo0_l0002>ooooo`;o0000
D?ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`003_ooool4o`000003oa0@4?oooooooooo00;o
oooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0F_ooool2o`0008oooooo0_l00018ooooo`004?ooool00ol0003oooooooooo`04ooooo`;o
8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`1Jooooo`;o00008_ooool2o`0006_ooooo0_l0000Rooooo`;o00009?ooool0013o
oooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?o
oooo0ol0001nooooo`;o0000Soooool2o`0002Cooooo000@ooooo`03o`000?oooooooooo00cooooo
00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo
=_ooool0013ooooo00?o0000ooooooooool03Oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo067ooooo0_l0002?ooooo`;o0000@Oooool0013ooooo00?o0000ooooooooool02_ooool0
1Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1Qooooo`;o0000Soooool2o`00047ooooo000>ooooo`03oeEEEOmVIVKo000000cooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`000?oooooo=oooool0033ooooo00?o0000
ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`1Xooooo`;o00003Oooool2o`00
083ooooo0_l0000<ooooo`;o0000;?ooool0033ooooo00?o0000ooooooooool0J?ooool2o`0000go
oooo0_l00020ooooo`;o00003?ooool2o`0002cooooo000`ooooo`03o`000?oooooooooo073ooooo
0_l0002>ooooo`;o0000<oooool0033ooooo0_l0001aooooo`;o0000S_ooool2o`0003?ooooo000`
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000F
ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@05ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool01?ooool2
ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000Hoooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooo
ocKooooo000Hooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool3o`000?oo
oooo=_ooool001Sooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooolfooooo`006?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolfooooo`005_ooool0
0omEEEGoIVIVo`00000=ooooo`Co00001_ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`003_ooool4o`000003
oa0@4?oooooooooo00;ooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000oooooooo
ool01?ooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool03?ooool00onYZJWoEEEE
ooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocKooooo000@ooooo`03o`000?oo
oooooooo00gooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool03Oooool00omEEEGoc<c<ooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKooooo000@
ooooo`03o`000?oooooooooo00gooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool02_ooool01Ol@
413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3o
ooooocKooooo000>ooooo`03oeEEEOmVIVKo000000cooooo1Ol00004ooooo`Co00001_ooool2o`00
0?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000
ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool002Gooooo1Ol00006ooooo`03
o`000?oooooooooo0?oooooo=_ooool002Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03
o`000?oooooooooo0?oooooo=_ooool002Kooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003ooooo
ooooo`3oooooocKooooo000Wooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003oooooocKooooo000X
ooooo`03ogMgMomVIVKooooo0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`009Oooool01Ol0003o^[ZjoooooonHV9So410@0?oooooo?oooool002Gooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c03oooooocoooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002T
ooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`04oa0@4?l0003oA4A4olc<c0Cooooo00Gok^k^oc8b<_l0003o410@olc<c02:oooo
o`00Y?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00009ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oV9RHoa0@4?oMgMd00oooool01OmEEEGoMgMgoooooonH
V9So8B4Q08[ooooo002Tooooo`03o`000?oooooooooo01[ooooo00Go410@oooooooooooooooooa0@
400>ooooo`03ohN7QomEEEGooooo00;ooooo00Go0000ooooooooooooooooo`00002:ooooo`00Y?oo
ool00ol0003oooooooooo`0;ooooo`Ko00002Oooool01Ol0003ooooooooooooooooo000000_ooooo
00Goc<c<ob4Q8Ol0003oEEEEo`000003ooooo`05o`000?nHV9SooooooiRHV?lQ8B40R_ooool00:Co
oooo00?o0000ooooooooool06_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go8B4QohN7
QoooooooV9RHo`000003ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0R_ooool00:;ooooo00?o410@
o`000?l000000ol0000Iooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000000?ooooo00?oEEEEohN7Qoooool0S?ooool00:Cooooo00?o0000ooooooooool06_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go8B4QoiRHV?ooooooMgMgoeEEE@03ooooo`03
omgMgOl@413oV9RH08cooooo002Tooooo`03o`000?oooooooooo01[ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05olc<c?l@413o0000oc8b<_o^k^h01?ooool01?o<c<coA4A4o`000?l@412:
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.02) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .31321 Mdot
.04762 .26623 Mdot
.07143 .23166 Mdot
.09524 .21403 Mdot
.11905 .21105 Mdot
.14286 .21828 Mdot
.16667 .23181 Mdot
.19048 .2489 Mdot
.21429 .26787 Mdot
.2381 .28768 Mdot
.2619 .30772 Mdot
.28571 .32756 Mdot
.30952 .34687 Mdot
.33333 .36529 Mdot
.35714 .38222 Mdot
.38095 .39646 Mdot
.40476 .40575 Mdot
.42857 .4061 Mdot
.45238 .39201 Mdot
.47619 .35964 Mdot
.5 .31321 Mdot
.52381 .26623 Mdot
.54762 .23166 Mdot
.57143 .21403 Mdot
.59524 .21105 Mdot
.61905 .21828 Mdot
.64286 .23181 Mdot
.66667 .2489 Mdot
.69048 .26787 Mdot
.71429 .28768 Mdot
.7381 .30772 Mdot
.7619 .32756 Mdot
.78571 .34687 Mdot
.80952 .36529 Mdot
.83333 .38222 Mdot
.85714 .39646 Mdot
.88095 .40575 Mdot
.90476 .4061 Mdot
.92857 .39201 Mdot
.95238 .35964 Mdot
.97619 .31321 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool06Oooool2o`0008kooooo0_l0002:ooooo`00<?ooool00ol0003ooooo
ooooo`0Booooo`;o00001Oooool2o`0008Oooooo0_l00005ooooo`;o0000R_ooool0033ooooo0_l0
000Cooooo`;o00003?ooool2o`00083ooooo0_l0000=ooooo`;o0000P_ooool0033ooooo00?o0000
ooooooooool08?ooool2o`0008oooooo0_l00022ooooo`003Oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgM
g@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooooooooooo410@00gooooo00?o
ZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o00002oooool2o`0001[ooooo0_l0
001booooo`;o00006oooool2o`0007_ooooo000=ooooo`05o`000?ooooooooooooooool000003_oo
ool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool02ooo
ool2o`0001[ooooo0_l0001booooo`;o00006oooool2o`0007_ooooo000=ooooo`05o`000?oooooo
ooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?ooooooooooooooool@4100
3_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
oooooolfooooo`003Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooo
oooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolfooooo`00
3Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`00033o
oooo0_l0002>ooooo`;o0000M?ooool0033ooooo00?o0000ooooooooool0;oooool2o`0008kooooo
0_l0001dooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oo
oooo=oooool0033ooooo00?o0000ooooooooool00oooool2o`00037ooooo0_l0001Looooo`;o0000
<?ooool2o`0006gooooo000`ooooo`03o`000?oooooooooo00?ooooo0_l0000aooooo`;o0000G?oo
ool2o`00033ooooo0_l0001]ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0?Oooool2o`0008oooooo0_l0
001Uooooo`00<?ooool00ol0003oooooooooo`0mooooo`;o0000Soooool2o`0006Gooooo000`oooo
o`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000Vooooo`Co0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`3oooooocKooooo000Xooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooolfooooo`00:?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo04Cooooo0_l0002?ooooo`;o0000G_ooool002Sooooo00?o0000oooo
ooooool01Oooool3o`0004Cooooo0_l0002?ooooo`;o0000G_ooool002Sooooo00?o0000oooooooo
ool01?ooool2o`0008oooooo0_l0002>ooooo`;o00005_ooool002Sooooo00?o0000ooooooooool0
1?ooool2o`0008oooooo0_l0002>ooooo`;o00005_ooool002Sooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`3oooooocKooooo000Vooooo`03oeEEEOmVIVKo000000Oooooo00?o0000
ooooooooool0oooooolfooooo`00<?ooool2o`0004gooooo0_l0002>ooooo`;o0000Eoooool0033o
oooo00?o0000ooooooooool0C?ooool2o`0008kooooo0_l0001Gooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0Doooool2o`0008kooooo0_l0001@ooooo`00<?ooool00ol0003oooooooooo`1Cooooo`;o0000
S_ooool2o`00053ooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo08Gooooo0_l0002?ooooo`;o00007Oooool0033o
oooo00?o0000ooooooooool0QOooool2o`0008oooooo0_l0000Mooooo`00<?ooool00ol0003ooooo
ooooo`1Jooooo`;o0000Soooool2o`0004Sooooo000`ooooo`03o`000?oooooooooo05[ooooo0_l0
002?ooooo`;o0000B?ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool000kooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool5o`0000Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool0013o
oooo00?o0000ooooooooool01?ooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0HOooool2o`0008oooooo0_l00011oooo
o`004?ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000oooooooo
ool00oooool3o`00067ooooo0_l0002?ooooo`;o0000@Oooool0013ooooo00?o0000ooooooooool0
3?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
oooooolfooooo`004?ooool00ol0003oooooooooo`0=ooooo`03ogMgMomVIVKooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo07kooooo0_l0002?ooooo`;o0000
9?ooool0013ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0J?ooool2o`0001Cooooo0_l0001iooooo`;o00005?oo
ool2o`0002Cooooo000@ooooo`03o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@
4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0J?ooool2o`0008oooooo0_l0
000jooooo`003_ooool00omEEEGoIVIVo`00000<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?oo
ool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo073ooooo0_l00005
ooooo`;o0000Qoooool2o`0000Gooooo0_l0000/ooooo`00<?ooool00ol0003oooooooooo`1`oooo
o`;o00001Oooool2o`0008Oooooo0_l00005ooooo`;o0000;?ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooo
oolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo
=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`005_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooo
oooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolf
ooooo`006?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Co
oooo0ol0003oooooocKooooo000Hooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_oo
ool001Kooooo00?oEEEEofIVI_l000003Oooool4o`0000Kooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000ko
oooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03
o`000?oooooooooo00Cooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00cooooo
00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolfooooo`004?oo
ool00ol0003oooooooooo`0=ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?oEEEE
olc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooo
oolfooooo`004?ooool00ol0003oooooooooo`0=ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo
00[ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0oooooolfooooo`003_ooool00omEEEGoIVIVo`00000<ooooo`Go00001?ooool4o`00
00Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000Uooooo`Go
00001_ooool00ol0003oooooooooo`3oooooocKooooo000Uooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01_ooool00ol0003oooooooooo`3oooooocKooooo000Vooooo`03oiRHV?lQ8B7ok^k^00Oooooo
00?o0000ooooooooool0oooooolfooooo`009oooool00onHV9So8B4Qonk^kP06ooooo`?o0000oooo
oolfooooo`00:?ooool00omgMgOoIVIVooooo`3oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Gooooo00Go0000okZj^_ooooooV9RHoa0@403oooooocoooooo000Uooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`0ooooooloooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00Y?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Wooooo1?l000000ol@413ooooooooo
o`02ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo1Ol0002:ooooo`00Y?oo
ool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<ooooo`03o`000?oooooooooo00Cooooo
0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OnHV9So8B4Qonk^k_ooooooA4A4
08[ooooo002Tooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02_ooool01Ol@413o
oooooooooooooooo410@00Cooooo00?oV9RHob4Q8Oo^k^h0Roooool00:Cooooo00?o0000oooooooo
ool02oooool6o`0000cooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo0000
00Gooooo00?oV9RHob4Q8Oo^k^h0R_ooool00:Cooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0:ooooo`05o`000?ooooooooooooooool000001_ooool00omgMgOoIVIVooooo`29oooo
o`00X_ooool00ol@413o0000o`000003o`0001cooooo00?o0000ooooooooool02_ooool01Ol@413o
oooooooooooooooo410@00Oooooo00?o0000ooooooooool0R?ooool00:Cooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0:ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Ol0
003o^[ZjoooooonHV9So410@08[ooooo002Tooooo`03o`000?oooooooooo01_ooooo00?oEEEEofIV
I_l000003?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c02:ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.08) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .33874 Mdot
.04762 .29489 Mdot
.07143 .25578 Mdot
.09524 .23019 Mdot
.11905 .21948 Mdot
.14286 .22061 Mdot
.16667 .22969 Mdot
.19048 .24358 Mdot
.21429 .26014 Mdot
.2381 .27805 Mdot
.2619 .2965 Mdot
.28571 .31501 Mdot
.30952 .33326 Mdot
.33333 .35095 Mdot
.35714 .36768 Mdot
.38095 .38263 Mdot
.40476 .39423 Mdot
.42857 .39969 Mdot
.45238 .39466 Mdot
.47619 .37457 Mdot
.5 .33874 Mdot
.52381 .29489 Mdot
.54762 .25578 Mdot
.57143 .23019 Mdot
.59524 .21948 Mdot
.61905 .22061 Mdot
.64286 .22969 Mdot
.66667 .24358 Mdot
.69048 .26014 Mdot
.71429 .27805 Mdot
.7381 .2965 Mdot
.7619 .31501 Mdot
.78571 .33326 Mdot
.80952 .35095 Mdot
.83333 .36768 Mdot
.85714 .38263 Mdot
.88095 .39423 Mdot
.90476 .39969 Mdot
.92857 .39466 Mdot
.95238 .37457 Mdot
.97619 .33874 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o00006_ooool2o`0008kooooo0_l0002:ooooo`00<?ooool00ol0003oooooooooo`0I
ooooo`;o00001Oooool2o`0008Oooooo0_l00006ooooo`;o0000P_ooool000gooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Pooooo`;o0000Soooool2o`0008;ooooo000=
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00Go410@
oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00ooo
ool3o`0001;ooooo0_l0000Cooooo`;o0000NOooool2o`0001Cooooo0_l0001kooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo01;ooooo0_l0000Cooooo`;o0000NOooool2o`0001Cooooo0_l0
001kooooo`003Oooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Ooo
ool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo02oooooo0_l0002>ooooo`;o0000M?ooool000gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0000`ooooo`;o0000S_ooool2o`0007Co
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool02ooo
ool2o`0008kooooo0_l0002Hooooo`00<?ooool00ol0003oooooooooo`0;ooooo`;o0000S_ooool2
o`0009Sooooo000`ooooo`03o`000?oooooooooo03Kooooo0_l0002>ooooo`;o0000KOooool0033o
oooo0_l0000gooooo`;o0000S_ooool2o`0006gooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`03o`000?oooooooooo03gooooo0_l0002?ooooo`;o0000IOooool0033o
oooo0_l0000nooooo`;o0000Soooool2o`0006Gooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`;o00001?ooool2o`0008oooooo0_l0002Oooooo`00<?ooool00ol0003o
ooooooooo`03ooooo`;o0000?oooool2o`0004kooooo0_l0000oooooo`;o0000G_ooool002Kooooo
1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo04Cooooo0_l0002?ooooo`;o0000
G_ooool002Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocKooooo000X
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolfooooo`00:?ooool00ol0
003oooooooooo`05ooooo`?o0000oooooolfooooo`00:?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo04cooooo0_l0002>ooooo`;o0000Eoooool002Sooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1<ooooo`;o0000S_ooool2o`0005Oooooo000Xooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooolfooooo`009_ooool00omEEEGoIVIVo`000007
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0Doooool2o`0008kooooo
0_l0001@ooooo`00<?ooool00ol0003oooooooooo`1Cooooo`;o0000S_ooool2o`00053ooooo000_
ooooo`?o0000S_ooool2o`0008kooooo0_l0000Fooooo`00;oooool2o`0008oooooo0_l0002>oooo
o`;o00005_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`1Jooooo`;o0000Soooool2o`0004Sooooo000`ooooo`03o`000?oooooooooo05[ooooo0_l0
002?ooooo`;o0000B?ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`1Qooooo`;o0000Soooool2o`00047ooooo000`ooooo`03o`000?oooooooooo067ooooo0_l0
002?ooooo`;o0000@Oooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
08Gooooo0_l0002?ooooo`;o00007Oooool000kooooo1?l000000ol@413oooooooooo`02ooooo`;o
8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
08Gooooo0_l0002?ooooo`;o00007Oooool0013ooooo00?o0000ooooooooool01?ooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0J?ooool2o`0008oooooo0_l0000jooooo`004?ooool00ol0003oooooooooo`0;ooooo`03
oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`0006Sooooo0_l0002?ooooo`;o
0000>_ooool0013ooooo00?o0000ooooooooool03?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003ooooooooo
o`0=ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo073ooooo0_l0002>ooooo`;o0000<oooool0013ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0L?oo
ool2o`0000cooooo0_l00020ooooo`;o00003Oooool2o`0002Cooooo000@ooooo`03o`000?oooooo
oooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0Moooool2o`0000Gooooo0_l00027ooooo`;o00001_ooool2o`0002Cooooo000>
ooooo`03oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_oo
ool2o`0007Sooooo0_l0002>ooooo`;o0000;?ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=ooo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool001Kooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`04
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0
01Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
0?oooooo=_ooool001Sooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`04ooooo`?o
0000oooooolfooooo`006?ooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000F
ooooo`03oeEEEOmVIVKo000000gooooo1?l00006ooooo`03o`000?oooooooooo0?oooooo=_ooool0
033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000>ooooo`Co
000000?o410@ooooooooool00_ooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003o
ooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0<ooooo`03ojVY
ZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool0013ooooo00?o
0000ooooooooool03Oooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0=ooooo`03oeEEEOo<c<co
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0013ooooo00?o0000ooooooooool03Oooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0:oooo
o`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0?oooooo=_ooool000kooooo00?oEEEEofIVI_l000003?ooool5o`0000Cooooo1?l00006oooo
o`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`009Oooool5o`0000Ko
oooo00?o0000ooooooooool0oooooolfooooo`009Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Ko
oooo00?o0000ooooooooool0oooooolfooooo`009_ooool00onHV9So8B4Qonk^kP07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool002Oooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000?oooooo=_oo
ool002Sooooo00?oMgMgofIVI_ooool0oooooolnooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Uooooo`05o`000?nj^[[ooooooiRHV?l@4100ooooooloooooo`009Oooool01OnHV9So
410@o`000?lQ8B7oc<c<0?oooooo?oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00:Cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Iooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<
c<`0R_ooool00:Cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003o
ooooooooo`04ooooo`;o8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go8B4QoiRH
V?ooooooV9RHob4Q8@2:ooooo`00Y?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
00[ooooo00Go410@oooooooooooooooooa0@4003ooooo`05o`000?ooooooooooooooool00000R_oo
ool00:Cooooo00?o0000ooooooooool02oooool6o`0000cooooo00?o0000ooooooooool02_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P2:ooooo`00Y?oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00[ooooo00Go0000oooooooooooooooo
o`000003ooooo`05olc<c?l0003o0000o`000?o<c<`0R_ooool00:;ooooo00?o410@o`000?l00000
0ol0000Looooo`03o`000?oooooooooo00[ooooo00Go410@oooooooooooooooooa0@4003ooooo`05
oa0@4?nj^[[ooooookZj^_l@4100R_ooool00:Cooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0:ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Ol0003o^[Zjoooooonj^[[o
000008[ooooo002Tooooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000003?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2:ooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.14) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .35735 Mdot
.04762 .32057 Mdot
.07143 .28124 Mdot
.09524 .2499 Mdot
.11905 .23172 Mdot
.14286 .22617 Mdot
.16667 .23008 Mdot
.19048 .24017 Mdot
.21429 .25392 Mdot
.2381 .26968 Mdot
.2619 .28642 Mdot
.28571 .30354 Mdot
.30952 .32069 Mdot
.33333 .33762 Mdot
.35714 .354 Mdot
.38095 .36926 Mdot
.40476 .3823 Mdot
.42857 .39111 Mdot
.45238 .39245 Mdot
.47619 .38216 Mdot
.5 .35735 Mdot
.52381 .32057 Mdot
.54762 .28124 Mdot
.57143 .2499 Mdot
.59524 .23172 Mdot
.61905 .22617 Mdot
.64286 .23008 Mdot
.66667 .24017 Mdot
.69048 .25392 Mdot
.71429 .26968 Mdot
.7381 .28642 Mdot
.7619 .30354 Mdot
.78571 .32069 Mdot
.80952 .33762 Mdot
.83333 .354 Mdot
.85714 .36926 Mdot
.88095 .3823 Mdot
.90476 .39111 Mdot
.92857 .39245 Mdot
.95238 .38216 Mdot
.97619 .35735 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool08?ooool2o`0008oooooo0_l0
0022ooooo`003Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnY
ZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Pooooo`;o0000Sooo
ool2o`0008;ooooo000=ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEoooo
o`08ooooo`03o`000?oooooooooo00?ooooo0ol0000Iooooo`;o00003?ooool2o`00083ooooo0_l0
000=ooooo`;o0000Noooool000gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooo
oooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Iooooo`;o00003?oo
ool2o`00083ooooo0_l0000=ooooo`;o0000Noooool000gooooo00Go0000ooooooooooooooooo`00
000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVY
ZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0_ooooo`;o0000
S_ooool2o`0007Cooooo000=ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooo
oooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0_ooooo`;o
0000S_ooool2o`0007Cooooo000=ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Co
oooo1?l00006ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`0Booooo`;o0000
S_ooool2o`00097ooooo000`ooooo`03o`000?oooooooooo01;ooooo0_l0000Rooooo`;o0000J_oo
ool2o`0002;ooooo0_l0001]ooooo`00<?ooool00ol0003oooooooooo`0fooooo`;o0000S_ooool2
o`0006gooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOo
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0?Ooo
ool2o`0008oooooo0_l0001Uooooo`00<?ooool00ol0003oooooooooo`0mooooo`;o0000Soooool2
o`0006Gooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0000<ooooo`;o
0000S_ooool2o`0009Sooooo000`ooooo`03o`000?oooooooooo00_ooooo0_l0002>ooooo`;o0000
V?ooool0033ooooo00?o0000ooooooooool0A?ooool2o`0008oooooo0_l0001Nooooo`00<?ooool0
0ol0003oooooooooo`14ooooo`;o0000Soooool2o`0005kooooo000`ooooo`;o0000oooooolgoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000Vooooo`Co000000?o410@ooooooooool0
0oooool00ol0003oooooooooo`3oooooocKooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0C?ooool2o`0008kooooo0_l0001Gooooo`00:?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo04cooooo0_l0002>ooooo`;o0000Eoooool002Sooooo00?o0000oooo
ooooool01Oooool3o`000?oooooo=_ooool002Sooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`3oooooocKooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
oooooolfooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo0_l0
001>ooooo`;o0000?oooool2o`0004gooooo0_l0001@ooooo`009_ooool00omEEEGoIVIVo`000007
ooooo`03o`000?oooooooooo00?ooooo0_l0001>ooooo`;o0000?oooool2o`0004gooooo0_l0001@
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo05[ooooo0_l0
002?ooooo`;o0000B?ooool0033ooooo0_l0001Kooooo`;o0000Soooool2o`0004Sooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo067ooooo0_l0
002?ooooo`;o0000@Oooool002oooooo0ol0001Rooooo`;o0000:_ooool2o`0006?ooooo0_l0000Y
ooooo`;o00005_ooool002oooooo0_l0002?ooooo`;o0000S_ooool2o`0001Kooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`1Xooooo`;o0000Soooool2o`0003[ooooo000`ooooo`;o0000JOooool2
o`0008oooooo0_l0000jooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000>ooooo`Co
000000?o410@ooooooooool00_ooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00Co
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo073ooooo0_l0000Cooooo`;o0000NOooool2o`0001Cooooo0_l0000Moooo
o`004?ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000oooooooo
ool00oooool3o`00073ooooo0_l0000Cooooo`;o0000NOooool2o`0001Cooooo0_l0000Mooooo`00
4?ooool00ol0003oooooooooo`0<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
Moooool2o`0000Gooooo0_l00027ooooo`;o00001_ooool2o`0002Cooooo000@ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo07Oooooo0_l00005ooooo`;o0000Qoooool2o`0000Kooooo0_l0000Tooooo`004?ooool0
0ol0003oooooooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0?oooooo=_ooool000kooooo00?oEEEEofIVI_l000003?ooool0
1OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`005_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000H
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`0>ooooo`03
ogMgMolb<S;ooooo00Cooooo0ol0003oooooocKooooo000Hooooo`03o`000?oooooooooo00_ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo
=_ooool001Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0?oooooo=_ooool001Kooooo00?oEEEEofIVI_l000003Oooool4o`0000Kooooo00?o0000
ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool000kooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_ooool00ol0003o
k^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocKooooo000@ooooo`03o`000?oooooooooo00Cooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oo
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`00
0?oooooooooo00cooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000
oooooolfooooo`004?ooool00ol0003oooooooooo`0=ooooo`03ob4Q8Ooooooooooo00Kooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooo
oooo00gooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0=ooooo`03ojVYZOmgMgOo
oooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000@oooo
o`03o`000?oooooooooo00[ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0oooooolfooooo`003_ooool00omEEEGoIVIVo`00000<oooo
o`Go00001?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolg
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000Uooooo`Go00001_ooool00ol0003oooooooooo`3oooooocKooooo000Uooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`3oooooocKooooo000Vooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0oooooolfooooo`009oooool00onHV9So8B4Qonk^
kP06ooooo`?o0000oooooolfooooo`00:?ooool00omgMgOoIVIVooooo`3oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Gooooo00Go0000okZj^_ooooooV9RHoa0@403ooooo
ocoooooo000Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0ooooooloooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00Y?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Wooooo1?l0
00000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool4o`000003oa0@4?oooooooooo00;ooooo0_l0
00000ol@413oooooooooo`28ooooo`00Y?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0
000<ooooo`03o`000?oooooooooo00Cooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0ROooool00:Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00;ooooo1Ol0002:ooooo`00Y?ooool00ol0003oooooooooo`0;oooo
o`Ko00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00CoA4A4omgM
gOoooooo0000Roooool00:Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00;ooooo00CogMgMoeEEEOoooooo0000Roooool00:;ooooo00?o410@o`00
0?l000000ol0000Looooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00omg
MgOoc<c<o`00002;ooooo`00Y?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool00oooool00oo^k^koA4A4o`00002;ooooo`00Y?ooool00ol0003ooooo
ooooo`0Kooooo`03oeEEEOmVIVKo000000gooooo00?oEEEEofIVI_l000001_ooool00omgMgOo0000
ooooo`2:ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .36908 Mdot
.04762 .34117 Mdot
.07143 .30557 Mdot
.09524 .27172 Mdot
.11905 .24738 Mdot
.14286 .23507 Mdot
.16667 .23322 Mdot
.19048 .23889 Mdot
.21429 .24936 Mdot
.2381 .26265 Mdot
.2619 .2775 Mdot
.28571 .29316 Mdot
.30952 .30919 Mdot
.33333 .32532 Mdot
.35714 .34126 Mdot
.38095 .35658 Mdot
.40476 .37045 Mdot
.42857 .38144 Mdot
.45238 .38715 Mdot
.47619 .38417 Mdot
.5 .36908 Mdot
.52381 .34117 Mdot
.54762 .30557 Mdot
.57143 .27172 Mdot
.59524 .24738 Mdot
.61905 .23507 Mdot
.64286 .23322 Mdot
.66667 .23889 Mdot
.69048 .24936 Mdot
.71429 .26265 Mdot
.7381 .2775 Mdot
.7619 .29316 Mdot
.78571 .30919 Mdot
.80952 .32532 Mdot
.83333 .34126 Mdot
.85714 .35658 Mdot
.88095 .37045 Mdot
.90476 .38144 Mdot
.92857 .38715 Mdot
.95238 .38417 Mdot
.97619 .36908 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool08?ooool2o`0000Gooooo0_l0
0028ooooo`;o00001Oooool2o`0007_ooooo000=ooooo`05o`000?ooooooooooooooool000003_oo
ool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`0Pooooo`;o00001Oooool2o`0000Kooooo0_l00020ooooo`;o00001Oooool2o`0000Gooooo
0_l0001dooooo`003Oooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool0
0oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02oooooo0_l0002>ooooo`;o0000
M?ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb
<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0000Jooooo`;o
0000S_ooool2o`0008[ooooo000`ooooo`03o`000?oooooooooo01Wooooo0_l0000Kooooo`;o0000
LOooool2o`0001_ooooo0_l0001]ooooo`00<?ooool00ol0003oooooooooo`0fooooo`;o0000S_oo
ool2o`0006gooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool2o`0003kooooo0_l0002?ooooo`;o0000IOooool0033ooooo
00?o0000ooooooooool0?Oooool2o`0008oooooo0_l0001Uooooo`00<?ooool00ol0003ooooooooo
o`0Booooo`;o0000S_ooool2o`00097ooooo000`ooooo`03o`000?oooooooooo01;ooooo0_l0002>
ooooo`;o0000TOooool0033ooooo00?o0000ooooooooool0A?ooool2o`0008oooooo0_l0001Noooo
o`00<?ooool2o`0004Gooooo0_l0002?ooooo`;o0000G_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0001=ooooo`;o0000S_ooool2o`0005Oooooo000`ooooo`03
o`000?oooooooooo04cooooo0_l0002>ooooo`;o0000Eoooool002Kooooo1?l000000ol@413ooooo
ooooo`03ooooo`03o`000?oooooooooo0?oooooo=_ooool002Sooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`3oooooocKooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02oooool2o`0008kooooo0_l0002Hooooo`00:?ooool00ol0003oooooooooo`05oooo
o`?o00002oooool2o`0004Kooooo0_l00016ooooo`;o0000A_ooool2o`00053ooooo000Xooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0Doooool2o`0008kooooo0_l0001@ooooo`00
:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo=_ooool002Sooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocKooooo000Vooooo`03oeEEEOmVIVKo
000000Oooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`0005_ooooo0_l0002?oooo
o`;o0000B?ooool0033ooooo00?o0000ooooooooool0F_ooool2o`0008oooooo0_l00018ooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l00004ooooo`;o0000G?ooool2o`00037ooooo0_l0001Looooo`;o0000@Oooool0
033ooooo00?o0000ooooooooool00oooool2o`0005cooooo0_l0000aooooo`;o0000G?ooool2o`00
047ooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000JOooool2
o`0008oooooo0_l0000jooooo`00<?ooool00ol0003oooooooooo`1Xooooo`;o0000Soooool2o`00
03[ooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00;oooool2o`0007;ooooo0_l0000Kooooo`;o0000LOooool2o`0001_ooooo0_l0
000Fooooo`00;oooool3o`00077ooooo0_l0000Kooooo`;o0000LOooool2o`0001_ooooo0_l0000F
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000>ooooo`Co000000?o410@oooooooo
ool00_ooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
07Oooooo0_l0000<ooooo`;o0000P?ooool2o`0000gooooo0_l0000Mooooo`004?ooool00ol0003o
ooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`0007Oo
oooo0_l00005ooooo`;o00001Oooool2o`00083ooooo0_l00006ooooo`;o00001Oooool2o`0001go
oooo000@ooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo07kooooo0_l0002?ooooo`;o00009?ooool0013ooooo00?o
0000ooooooooool03Oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0013ooooo00?o0000ooooooooool02_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000>ooooo`03oeEEEOmVIVKo
000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`000?oooooo=ooo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Kooooo1?l000000ol@413oooooooooo`02
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooo
oolfooooo`006?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000oooooooo
ool03_ooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`006?ooool00ol0003ooooo
ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKo
oooo000Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooocKooooo000Fooooo`03oeEEEOmVIVKo000000gooooo1?l00006
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000>ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Ko
oooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGo
ZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`00
4?ooool00ol0003oooooooooo`0<ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool0
0oooool3o`000?oooooo=_ooool0013ooooo00?o0000ooooooooool03Oooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`004?ooool0
0ol0003oooooooooo`0=ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool03Oooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`004?ooool00ol0003oooooooooo`0:ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool000kooooo00?oEEEEofIV
I_l000003?ooool5o`0000Cooooo1?l00006ooooo`;o0000oooooolgooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`009Oooool5o`0000Kooooo00?o0000ooooooooool0oooooolfooooo`00
9Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooolfooooo`00
9_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0?oooooo=_ooool002Oooooo00?o
V9RHob4Q8Oo^k^h01_ooool3o`000?oooooo=_ooool002Sooooo00?oMgMgofIVI_ooool0ooooooln
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Uooooo`05o`000?nj^[[ooooooiRH
V?l@4100ooooooloooooo`009Oooool01OnHV9So410@o`000?lQ8B7oc<c<0?oooooo?oooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00:Sooooo00GoV9RHo`000?l0003oA4A4okZj
^P0Iooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Cooooo1Ol0002>ooooo`00Z?ooool0
1Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<ooooo`03o`000?oooooooooo00Cooooo0_lQ
8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0S_ooool00:Sooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^08oooooo002Xooooo`03o`000?oooooo
oooo00_ooooo1_l0000<ooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h0S_ooool0
0:Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0=ooooo`03ogMgMomVIVKooooo
08gooooo002Vooooo`03oa0@4?l0003o000000?o00007?ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo08cooooo002Xooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
2_ooool01Ol0003o^[ZjoooooonHV9So410@08kooooo002Xooooo`03o`000?oooooooooo01_ooooo
00?oEEEEofIVI_l000003?ooool01OnHV9So410@o`000?lQ8B7oc<c<08kooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.26) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .37497 Mdot
.04762 .3559 Mdot
.07143 .32662 Mdot
.09524 .29373 Mdot
.11905 .26551 Mdot
.14286 .24712 Mdot
.16667 .23926 Mdot
.19048 .23997 Mdot
.21429 .24665 Mdot
.2381 .25712 Mdot
.2619 .26986 Mdot
.28571 .28393 Mdot
.30952 .29878 Mdot
.33333 .31407 Mdot
.35714 .3295 Mdot
.38095 .34469 Mdot
.40476 .35901 Mdot
.42857 .37137 Mdot
.45238 .38001 Mdot
.47619 .38227 Mdot
.5 .37497 Mdot
.52381 .3559 Mdot
.54762 .32662 Mdot
.57143 .29373 Mdot
.59524 .26551 Mdot
.61905 .24712 Mdot
.64286 .23926 Mdot
.66667 .23997 Mdot
.69048 .24665 Mdot
.71429 .25712 Mdot
.7381 .26986 Mdot
.7619 .28393 Mdot
.78571 .29878 Mdot
.80952 .31407 Mdot
.83333 .3295 Mdot
.85714 .34469 Mdot
.88095 .35901 Mdot
.90476 .37137 Mdot
.92857 .38001 Mdot
.95238 .38227 Mdot
.97619 .37497 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool09oooool2o`0008oooooo0_l0001kooooo`003Ooo
ool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo02Oooooo0_l00006ooooo`;o0000Qoooool2o`0000Gooooo
0_l0001dooooo`003Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooo
oooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0;oooool2o`0008ko
oooo0_l0001dooooo`003Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co
00001_ooool2o`00027ooooo0_l0000Dooooo`;o0000NOooool2o`0001?ooooo0_l0001]ooooo`00
<?ooool00ol0003oooooooooo`0Pooooo`;o00005?ooool2o`0007Wooooo0_l0000Cooooo`;o0000
KOooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`0m
ooooo`;o0000Soooool2o`0006Gooooo000`ooooo`03o`000?oooooooooo03gooooo0_l0002?oooo
o`;o0000IOooool0033ooooo0_l0000Jooooo`;o0000S_ooool2o`0008[ooooo000`ooooo`03o`00
0?oooooooooo01Wooooo0_l0002>ooooo`;o0000R_ooool0033ooooo00?o0000ooooooooool0A?oo
ool2o`0008oooooo0_l0001Nooooo`00<?ooool00ol0003oooooooooo`14ooooo`;o0000Soooool2
o`0005kooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOo
oooo000`ooooo`03o`000?oooooooooo04cooooo0_l0002>ooooo`;o0000Eoooool0033ooooo00?o
0000ooooooooool0C?ooool2o`0008kooooo0_l0001Gooooo`00<?ooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`;o00004oooool2o`0008kooooo0_l0002Aooooo`00<?ooool00ol0003o
ooooooooo`0Booooo`;o0000S_ooool2o`00097ooooo000Vooooo`Co000000?o410@ooooooooool0
0oooool00ol0003oooooooooo`1Cooooo`;o0000S_ooool2o`00053ooooo000Xooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0Doooool2o`0008kooooo0_l0001@ooooo`00:?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo=_ooool002Sooooo00?o0000oooo
ooooool01Oooool3o`000?oooooo=_ooool002Sooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`1Jooooo`;o0000Soooool2o`0004Sooooo000Xooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0F_ooool2o`0008oooooo0_l00018ooooo`00:?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0?oooooo=_ooool002Kooooo00?oEEEEofIVI_l000001oooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`;o00003?ooool2o`0008kooooo0_l0002Hoooo
o`00<?ooool00ol0003oooooooooo`0;ooooo`;o0000E?ooool2o`0003Sooooo0_l0001Eooooo`;o
0000@Oooool0033ooooo00?o0000ooooooooool0HOooool2o`0008oooooo0_l00011ooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`1Xooooo`;o0000Soooool2o`0003[ooooo000`ooooo`03o`000?oooooooooo06So
oooo0_l0002?ooooo`;o0000>_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o00001?ooool2o`0008oooooo0_l0002O
ooooo`00<?ooool00ol0003oooooooooo`03ooooo`;o0000Joooool2o`0002;ooooo0_l0001Zoooo
o`;o0000<oooool0033ooooo00?o0000ooooooooool0L?ooool2o`0008kooooo0_l0000cooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0001hooooo`;o0000S_ooool2o`0002cooooo000_ooooo`;o0000NOooool2o`00
01Cooooo0_l0001hooooo`;o00005?ooool2o`0001Kooooo000>ooooo`Co000000?o410@oooooooo
ool00_ooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool2o`00
083ooooo0_l0000=ooooo`;o0000P?ooool2o`0000cooooo0_l0000Fooooo`004?ooool00ol0003o
ooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`1nooooo`;o00001Oooool2o`0008Sooooo0_l00005oooo
o`;o00007Oooool0013ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP09ooooo`03
o`000?oooooooooo00?ooooo0ol00025ooooo`;o0000Soooool2o`0001gooooo000@ooooo`03o`00
0?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool03Oooool00omgMgOoIVIVoooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKooooo
000@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool02_ooool0
1Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`3oooooocKooooo000>ooooo`03oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c004ooooo`Co00001_ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=ooo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool001Kooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`04
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0
01Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
0?oooooo=_ooool001Sooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`04ooooo`?o
0000oooooolfooooo`006?ooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000F
ooooo`03oeEEEOmVIVKo000000gooooo1?l00006ooooo`03o`000?oooooooooo0?oooooo=_ooool0
033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000>ooooo`Co
000000?o410@ooooooooool00_ooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003o
ooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0<ooooo`03ojVY
ZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool0013ooooo00?o
0000ooooooooool03Oooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0=ooooo`03oeEEEOo<c<co
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0013ooooo00?o0000ooooooooool03Oooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0:oooo
o`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0?oooooo=_ooool000kooooo00?oEEEEofIVI_l000003?ooool5o`0000Cooooo1?l00006oooo
o`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`009Oooool5o`0000Ko
oooo00?o0000ooooooooool0oooooolfooooo`009Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Ko
oooo00?o0000ooooooooool0oooooolfooooo`009_ooool00onHV9So8B4Qonk^kP07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool002Oooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000?oooooo=_oo
ool002Sooooo00?oMgMgofIVI_ooool0oooooolnooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Uooooo`05o`000?nj^[[ooooooiRHV?l@4100ooooooloooooo`009Oooool01OnHV9So
410@o`000?lQ8B7oc<c<0?oooooo?oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00:Cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Iooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Cooooo1Ol00003ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0R_ooool00:Cooooo00Go
410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003oooooooooo`04ooooo`;o8B4Q
1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoEEEEogMgMoooooooV9RHob4Q8@2:oooo
o`00Y?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^
k^h01?ooool01Ol0003ooooooooooooooooo000008[ooooo002Tooooo`03o`000?oooooooooo00_o
oooo1_l0000<ooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003o
V9RHoooooonHV9So8B4Q08[ooooo002Tooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool03Oooool00omgMgOoIVIVooooo`02ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0R_ooool00:;o
oooo00?o410@o`000?l000000ol0000Looooo`03o`000?oooooooooo00kooooo00Ko0000oooooooo
oooooooooeEEEOn7QhN=ooooo`00Y?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
00[ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`03omgMgOl@413oV9RH08cooooo002Toooo
o`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000003?ooool01OnHV9So410@o`000?lQ8B7o
c<c<00Cooooo00Coc<c<odA4A?l0003o410@R_ooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.32) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .37639 Mdot
.04762 .36503 Mdot
.07143 .34309 Mdot
.09524 .31401 Mdot
.11905 .2847 Mdot
.14286 .26173 Mdot
.16667 .24816 Mdot
.19048 .24359 Mdot
.21429 .24602 Mdot
.2381 .25326 Mdot
.2619 .26361 Mdot
.28571 .27592 Mdot
.30952 .28949 Mdot
.33333 .30387 Mdot
.35714 .31871 Mdot
.38095 .33364 Mdot
.40476 .34812 Mdot
.42857 .36132 Mdot
.45238 .37188 Mdot
.47619 .3778 Mdot
.5 .37639 Mdot
.52381 .36503 Mdot
.54762 .34309 Mdot
.57143 .31401 Mdot
.59524 .2847 Mdot
.61905 .26173 Mdot
.64286 .24816 Mdot
.66667 .24359 Mdot
.69048 .24602 Mdot
.71429 .25326 Mdot
.7381 .26361 Mdot
.7619 .27592 Mdot
.78571 .28949 Mdot
.80952 .30387 Mdot
.83333 .31871 Mdot
.85714 .33364 Mdot
.88095 .34812 Mdot
.90476 .36132 Mdot
.92857 .37188 Mdot
.95238 .3778 Mdot
.97619 .37639 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02oo
oooo0_l0002>ooooo`;o0000M?ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go
00001?ooool4o`0000Kooooo0_l0000Xooooo`;o00001_ooool2o`0000Gooooo0_l00020ooooo`;o
00001Oooool2o`0000Gooooo0_l0001]ooooo`00<?ooool00ol0003oooooooooo`0Wooooo`;o0000
3Oooool2o`00083ooooo0_l0000<ooooo`;o0000KOooool0033ooooo00?o0000ooooooooool0?Ooo
ool2o`0008oooooo0_l0001Uooooo`00<?ooool00ol0003oooooooooo`0mooooo`;o0000Soooool2
o`0006Gooooo000`ooooo`03o`000?oooooooooo023ooooo0_l0002?ooooo`;o0000P_ooool0033o
oooo0_l0000Qooooo`;o00008_ooool2o`0006_ooooo0_l0000Rooooo`;o0000G_ooool0033ooooo
00?o0000ooooooooool0A?ooool2o`0008oooooo0_l0001Nooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooo
ooooool0C?ooool2o`0008kooooo0_l0001Gooooo`00<?ooool2o`0004gooooo0_l0002>ooooo`;o
0000Eoooool0033ooooo00?o0000ooooooooool06Oooool2o`0008kooooo0_l0002:ooooo`00<?oo
ool00ol0003oooooooooo`0Iooooo`;o0000S_ooool2o`0008[ooooo000`ooooo`03o`000?oooooo
oooo05?ooooo0_l0002>ooooo`;o0000D?ooool0033ooooo0_l0001Dooooo`;o0000S_ooool2o`00
053ooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool002Kooooo1?l000000ol@413ooooo
ooooo`03ooooo`03o`000?oooooooooo0?oooooo=_ooool002Sooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1Jooooo`;o0000Soooool2o`0004Sooooo000Xooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0F_ooool2o`0008oooooo0_l00018ooooo`00:?ooool00ol0
003oooooooooo`05ooooo`?o0000oooooolfooooo`00:?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01;ooooo0_l0002>ooooo`;o0000TOooool002Sooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Booooo`;o0000S_ooool2o`00097ooooo000Xooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0HOooool2o`0008oooooo0_l00011ooooo`009_ooool0
0omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo067ooooo0_l0002?ooooo`;o0000@Oooool0
033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0J?ooool2o`0008oooooo0_l0000jooooo`00<?ooool00ol0003ooooooooo
o`1Xooooo`;o0000Soooool2o`0003[ooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`0;ooooo`;o0000S_ooool2o`0009Sooooo000`ooooo`03o`000?oooooooooo00_o
oooo0_l0001Sooooo`;o0000:Oooool2o`0006?ooooo0_l0000cooooo`00<?ooool00ol0003ooooo
ooooo`1`ooooo`;o0000S_ooool2o`0003?ooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo07Oooooo0_l0002>oooo
o`;o0000;?ooool0033ooooo00?o0000ooooooooool0Moooool2o`0008kooooo0_l0000/ooooo`00
<?ooool00ol0003oooooooooo`03ooooo`;o0000Soooool2o`0009oooooo000`ooooo`03o`000?oo
oooooooo00?ooooo0_l0002?ooooo`;o0000Woooool0033ooooo0_l0001oooooo`;o0000Soooool2
o`0002Cooooo000_ooooo`;o0000P?ooool2o`0000Gooooo0_l00006ooooo`;o0000P?ooool2o`00
00Gooooo0_l00005ooooo`;o00005_ooool000kooooo1?l000000ol@413oooooooooo`02ooooo`;o
8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`;o0000Qoooool2o`00
00Kooooo0_l00027ooooo`;o00001Oooool2o`0001Kooooo000@ooooo`03o`000?oooooooooo00Co
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool02oooool00onHV9So
8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocKooooo000@ooooo`03o`00
0?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool03Oooool00omgMgOoIVIVoooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKooooo
000@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool02_ooool0
1Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`3oooooocKooooo000>ooooo`03oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c004ooooo`Co00001_ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=ooo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool001Kooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`04
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0
01Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
0?oooooo=_ooool001Sooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`04ooooo`?o
0000oooooolfooooo`006?ooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000F
ooooo`03oeEEEOmVIVKo000000gooooo1?l00006ooooo`03o`000?oooooooooo0?oooooo=_ooool0
033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000>ooooo`Co
000000?o410@ooooooooool00_ooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003o
ooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0<ooooo`03ojVY
ZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool0013ooooo00?o
0000ooooooooool03Oooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0=ooooo`03oeEEEOo<c<co
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0013ooooo00?o0000ooooooooool03Oooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0:oooo
o`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0?oooooo=_ooool000kooooo00?oEEEEofIVI_l000003?ooool5o`0000Cooooo1?l00006oooo
o`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`009Oooool5o`0000Ko
oooo00?o0000ooooooooool0oooooolfooooo`009Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Ko
oooo00?o0000ooooooooool0oooooolfooooo`009_ooool00onHV9So8B4Qonk^kP07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool002Oooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000?oooooo=_oo
ool002Sooooo00?oMgMgofIVI_ooool0oooooolnooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Uooooo`05o`000?nj^[[ooooooiRHV?l@4100ooooooloooooo`009Oooool01OnHV9So
410@o`000?lQ8B7oc<c<0?oooooo?oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00:Cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Iooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`Go0000R_ooool00:Cooooo00Go
410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003oooooooooo`04ooooo`;o8B4Q
1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A02:oooo
o`00Y?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool00_ooool00onHV9So8B4Qonk^kP2;ooooo`00Y?ooool00ol0003oooooooooo`0;ooooo`Ko0000
3?ooool00ol0003oooooooooo`0=ooooo`03ojVYZOl@413ooooo00Cooooo00?oV9RHob4Q8Oo^k^h0
R_ooool00:Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0<ooooo`03oa0@4?l0
003o^[Zj00Kooooo00?oMgMgofIVI_ooool0ROooool00:;ooooo00?o410@o`000?l000000ol0000L
ooooo`03o`000?oooooooooo00gooooo00?o^[Zjob4Q8Oooool01_ooool00ol0003oooooooooo`28
ooooo`00Y?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00[ooooo00Go410@oiRH
V?oooooo^[Zjo`000003ooooo`05o`000?nj^[[ooooooiRHV?l@4100R_ooool00:Cooooo00?o0000
ooooooooool06oooool00omEEEGoIVIVo`00000<ooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01OnHV9So410@o`000?lQ8B7oc<c<08[ooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.38) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .3746 Mdot
.04762 .36946 Mdot
.07143 .35462 Mdot
.09524 .33103 Mdot
.11905 .30333 Mdot
.14286 .27791 Mdot
.16667 .25956 Mdot
.19048 .24978 Mdot
.21429 .24763 Mdot
.2381 .25126 Mdot
.2619 .25891 Mdot
.28571 .26925 Mdot
.30952 .28139 Mdot
.33333 .29476 Mdot
.35714 .30892 Mdot
.38095 .32346 Mdot
.40476 .33789 Mdot
.42857 .35153 Mdot
.45238 .36333 Mdot
.47619 .37173 Mdot
.5 .3746 Mdot
.52381 .36946 Mdot
.54762 .35462 Mdot
.57143 .33103 Mdot
.59524 .30333 Mdot
.61905 .27791 Mdot
.64286 .25956 Mdot
.66667 .24978 Mdot
.69048 .24763 Mdot
.71429 .25126 Mdot
.7381 .25891 Mdot
.7619 .26925 Mdot
.78571 .28139 Mdot
.80952 .29476 Mdot
.83333 .30892 Mdot
.85714 .32346 Mdot
.88095 .33789 Mdot
.90476 .35153 Mdot
.92857 .36333 Mdot
.95238 .37173 Mdot
.97619 .3746 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo0_l0000gooooo`;o0000S_ooool2o`0006gooooo000`ooooo`03o`000?oooooooooo02oooooo
0_l00005ooooo`;o00001Oooool2o`00083ooooo0_l00005ooooo`;o00001_ooool2o`0006Gooooo
000`ooooo`03o`000?oooooooooo02oooooo0_l0000<ooooo`;o0000P?ooool2o`0000gooooo0_l0
001Uooooo`00<?ooool00ol0003oooooooooo`14ooooo`;o0000Soooool2o`0005kooooo000`oooo
o`03o`000?oooooooooo02Oooooo0_l0000Kooooo`;o0000L_ooool2o`0001_ooooo0_l0001Noooo
o`00<?ooool2o`0002Sooooo0_l0002?ooooo`;o0000Noooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`1<ooooo`;o0000S_ooool2o`0005Oooooo000`
ooooo`03o`000?oooooooooo04cooooo0_l0002>ooooo`;o0000Eoooool0033ooooo00?o0000oooo
ooooool08?ooool2o`0008oooooo0_l00022ooooo`00<?ooool2o`00027ooooo0_l0000aooooo`;o
0000G?ooool2o`00033ooooo0_l0001@ooooo`00<?ooool00ol0003oooooooooo`1Cooooo`;o0000
S_ooool2o`00053ooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000
ooooooooool0oooooolfooooo`00<?ooool2o`0005_ooooo0_l0002?ooooo`;o0000B?ooool0033o
oooo00?o0000ooooooooool0F_ooool2o`0008oooooo0_l00018ooooo`009_ooool4o`000003oa0@
4?oooooooooo00?ooooo00?o0000ooooooooool0oooooolfooooo`00:?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01Wooooo0_l0002>ooooo`;o0000R_ooool002Sooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Iooooo`;o0000S_ooool2o`0008[ooooo000Xoooo
o`03o`000?oooooooooo00Gooooo0ol0001Qooooo`;o0000Soooool2o`00047ooooo000Xooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0HOooool2o`0008oooooo0_l00011ooooo`00
:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo=_ooool002Sooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocKooooo000Vooooo`03oeEEEOmVIVKo
000000Oooooo00?o0000ooooooooool0J?ooool2o`0008oooooo0_l0000jooooo`00<?ooool2o`00
06Wooooo0_l0002?ooooo`;o0000>_ooool0033ooooo00?o0000ooooooooool04_ooool2o`0008ko
oooo0_l0002Aooooo`00<?ooool00ol0003oooooooooo`0Booooo`;o0000S_ooool2o`00097ooooo
000`ooooo`03o`000?oooooooooo073ooooo0_l0002>ooooo`;o0000<oooool0033ooooo0_l0001a
ooooo`;o0000S_ooool2o`0003?ooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo00_ooooo0_l0001Zooooo`;o00008_ooool2o`0006[ooooo0_l0
000/ooooo`00<?ooool2o`0000cooooo0_l0001Zooooo`;o00008_ooool2o`0006[ooooo0_l0000/
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo07ko
oooo0_l0002?ooooo`;o00009?ooool0033ooooo00?o0000ooooooooool0O_ooool2o`0008oooooo
0_l0000Tooooo`00<?ooool00ol0003oooooooooo`03ooooo`;o0000Soooool2o`0009oooooo000`
ooooo`;o00001?ooool2o`00083ooooo0_l0000=ooooo`;o0000P?ooool2o`0001gooooo000_oooo
o`;o0000Qoooool2o`0000Kooooo0_l00027ooooo`;o00001Oooool2o`0001Kooooo000>ooooo`Co
000000?o410@ooooooooool00_ooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01?ooool2o`0008oooooo0_l0002>ooooo`;o00005_ooool0013ooooo00?o0000oooooooo
ool01?ooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0;ooooo`03
oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool0013ooooo
00?o0000ooooooooool03?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0=ooooo`03ogMgMomV
IVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo
=_ooool0013ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0:
ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0?oooooo=_ooool000kooooo00?oEEEEofIVI_l000003?ooool01OnHV9So410@o`000?lQ
8B7oc<c<00Cooooo1?l00006ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooo
oolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo
=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`005_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooo
oooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolf
ooooo`006?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Co
oooo0ol0003oooooocKooooo000Hooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_oo
ool001Kooooo00?oEEEEofIVI_l000003Oooool4o`0000Kooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000ko
oooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03
o`000?oooooooooo00Cooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00cooooo
00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolfooooo`004?oo
ool00ol0003oooooooooo`0=ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?oEEEE
olc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooo
oolfooooo`004?ooool00ol0003oooooooooo`0=ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo
00[ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0oooooolfooooo`003_ooool00omEEEGoIVIVo`00000<ooooo`Go00001?ooool4o`00
00Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000Uooooo`Go
00001_ooool00ol0003oooooooooo`3oooooocKooooo000Uooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01_ooool00ol0003oooooooooo`3oooooocKooooo000Vooooo`03oiRHV?lQ8B7ok^k^00Oooooo
00?o0000ooooooooool0oooooolfooooo`009oooool00onHV9So8B4Qonk^kP06ooooo`?o0000oooo
oolfooooo`00:?ooool00omgMgOoIVIVooooo`3oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Gooooo00Go0000okZj^_ooooooV9RHoa0@403oooooocoooooo000Uooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`0ooooooloooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00Y?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Wooooo1?l000000ol@413ooooooooo
o`02ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Goc<c<ob4Q8Ol0003o
8B4Qolc<c02:ooooo`00Y?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<ooooo`03
o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OlQ
8B7oV9RHoooooonHV9So8B4Q08[ooooo002Tooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool03_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0R?ooool0
0:Cooooo00?o0000ooooooooool02oooool6o`0000cooooo00?o0000ooooooooool03Oooool00onY
ZJWo410@ooooo`02ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80R_ooool00:Cooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0<ooooo`03oa0@4?l0003o^[Zj00?ooooo00Goc<c<o`00
0?l0003o0000olc<c02:ooooo`00X_ooool00ol@413o0000o`000003o`0001cooooo00?o0000oooo
ooooool03Oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?nj^[[ooooookZj^_l@4100R_ooool0
0:Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0:ooooo`05oa0@4?nHV9Sooooo
okZj^_l000000oooool01Ol0003o^[Zjoooooonj^[[o000008[ooooo002Tooooo`03o`000?oooooo
oooo01_ooooo00?oEEEEofIVI_l000003?ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Go
ZJVYoa0@4?l0003o410@ojVYZ@2:ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.44) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .37064 Mdot
.04762 .37025 Mdot
.07143 .36157 Mdot
.09524 .34402 Mdot
.11905 .31994 Mdot
.14286 .29439 Mdot
.16667 .2728 Mdot
.19048 .25836 Mdot
.21429 .25158 Mdot
.2381 .2513 Mdot
.2619 .25592 Mdot
.28571 .26402 Mdot
.30952 .27455 Mdot
.33333 .28677 Mdot
.35714 .30013 Mdot
.38095 .31416 Mdot
.40476 .32837 Mdot
.42857 .34216 Mdot
.45238 .35468 Mdot
.47619 .36474 Mdot
.5 .37064 Mdot
.52381 .37025 Mdot
.54762 .36157 Mdot
.57143 .34402 Mdot
.59524 .31994 Mdot
.61905 .29439 Mdot
.64286 .2728 Mdot
.66667 .25836 Mdot
.69048 .25158 Mdot
.71429 .2513 Mdot
.7381 .25592 Mdot
.7619 .26402 Mdot
.78571 .27455 Mdot
.80952 .28677 Mdot
.83333 .30013 Mdot
.85714 .31416 Mdot
.88095 .32837 Mdot
.90476 .34216 Mdot
.92857 .35468 Mdot
.95238 .36474 Mdot
.97619 .37064 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo03Kooooo0_l00005ooooo`;o0000
Qoooool2o`0000Kooooo0_l0001Uooooo`00<?ooool00ol0003oooooooooo`0fooooo`;o00001Ooo
ool2o`0008Oooooo0_l00006ooooo`;o0000IOooool0033ooooo00?o0000ooooooooool0;oooool2
o`0001?ooooo0_l0001iooooo`;o00005?ooool2o`0005kooooo000`ooooo`03o`000?oooooooooo
02oooooo0_l0000Cooooo`;o0000NOooool2o`0001Cooooo0_l0001Nooooo`00<?ooool2o`0004go
oooo0_l0002>ooooo`;o0000Eoooool0033ooooo00?o0000ooooooooool0C?ooool2o`0008kooooo
0_l0001Gooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo02Oooooo0_l0000Zooooo`;o0000Hoooool2o`0002Wooooo0_l0001@ooooo`00<?ooool00ol0
003oooooooooo`0Wooooo`;o0000:_ooool2o`0006?ooooo0_l0000Yooooo`;o0000D?ooool0033o
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0F_ooool2o`0008oooooo0_l00018ooooo`00<?ooool00ol0003oooooooooo`1J
ooooo`;o0000Soooool2o`0004Sooooo000`ooooo`;o00008Oooool2o`0008oooooo0_l00022oooo
o`00<?ooool00ol0003oooooooooo`0Pooooo`;o0000Soooool2o`0008;ooooo000Vooooo`Co0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`1Qooooo`;o0000Soooool2o`00047ooooo
000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0HOooool2o`0008oooooo0_l0
0011ooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo=_ooool0
02Sooooo00?o0000ooooooooool01Oooool3o`000?oooooo=_ooool002Sooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`1Xooooo`;o0000Soooool2o`0003[ooooo000Xooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0J?ooool2o`0008oooooo0_l0000jooooo`00:?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Wooooo0_l0002>ooooo`;o0000R_oo
ool002Kooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`0Iooooo`;o0000S_ooool2
o`0008[ooooo000`ooooo`;o0000LOooool2o`0008kooooo0_l0000cooooo`00<?ooool00ol0003o
ooooooooo`1`ooooo`;o0000S_ooool2o`0003?ooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool04_ooool2o`0006?ooooo0_l0000Yooooo`;o0000Hoooool2o`00
02cooooo000`ooooo`03o`000?oooooooooo01;ooooo0_l0001Sooooo`;o0000:Oooool2o`0006?o
oooo0_l0000/ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo07kooooo0_l0002?ooooo`;o00009?ooool0033ooooo0_l0001oooooo`;o0000Soooool2
o`0002Cooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool02oooool2o`0008kooooo0_l0002Hooooo`00<?ooool00ol0003oooooooooo`0;ooooo`;o0000
N?ooool2o`0001Cooooo0_l0001iooooo`;o00007Oooool002oooooo0_l00005ooooo`;o0000P?oo
ool2o`0000Kooooo0_l00005ooooo`;o0000P?ooool2o`0000Gooooo0_l0000Fooooo`00;oooool3
o`0000Cooooo0_l00028ooooo`;o00001Oooool2o`0008Oooooo0_l0000Fooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000>ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Co
oooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocKooooo000@ooooo`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0013o
oooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?o
oooo0ol0003oooooocKooooo000@ooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o
0000ooooooooool03Oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0013ooooo00?o0000ooooooooool02_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000>ooooo`03oeEEEOmVIVKo
000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`000?oooooo=ooo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Kooooo1?l000000ol@413oooooooooo`02
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooo
oolfooooo`006?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000oooooooo
ool03_ooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`006?ooool00ol0003ooooo
ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKo
oooo000Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooocKooooo000Fooooo`03oeEEEOmVIVKo000000gooooo1?l00006
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000>ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Ko
oooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGo
ZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`00
4?ooool00ol0003oooooooooo`0<ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool0
0oooool3o`000?oooooo=_ooool0013ooooo00?o0000ooooooooool03Oooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`004?ooool0
0ol0003oooooooooo`0=ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool03Oooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`004?ooool00ol0003oooooooooo`0:ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool000kooooo00?oEEEEofIV
I_l000003?ooool5o`0000Cooooo1?l00006ooooo`;o0000oooooolgooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`009Oooool5o`0000Kooooo00?o0000ooooooooool0oooooolfooooo`00
9Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooolfooooo`00
9_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0?oooooo=_ooool002Oooooo00?o
V9RHob4Q8Oo^k^h01_ooool3o`000?oooooo=_ooool002Sooooo00?oMgMgofIVI_ooool0ooooooln
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Uooooo`05o`000?nj^[[ooooooiRH
V?l@4100ooooooloooooo`009Oooool01OnHV9So410@o`000?lQ8B7oc<c<0?oooooo?oooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00:Cooooo00GoV9RHo`000?l0003oA4A4okZj
^P0Iooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Kooooo0_l000000ol@413ooooooooo
o`03ooooo`;o000000?o410@ooooooooool0R?ooool00:Cooooo00Go410@okZj^_o^k^koMgMgoa0@
4009ooooo`Ko00003?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo08Wooooo002Tooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool02_ooool5o`0000?ooooo1Ol0002:ooooo`00Y?ooool00ol0003oooooooooo`0;oooo
o`Ko00003?ooool00ol0003oooooooooo`0:ooooo`04odA4A?oMgMgoooooo`0000Cooooo00CoA4A4
omgMgOoooooo0000Roooool00:Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0:
ooooo`04omgMgOmEEEGoooooo`0000Cooooo00CogMgMoeEEEOoooooo0000Roooool00:;ooooo00?o
410@o`000?l000000ol0000Looooo`03o`000?oooooooooo00_ooooo00?oMgMgolc<c?l000001Ooo
ool00omgMgOoc<c<o`00002;ooooo`00Y?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo00_ooooo00?ok^k^odA4A?l000001Oooool00oo^k^koA4A4o`00002;ooooo`00Y?ooool00ol0
003oooooooooo`0Kooooo`03oeEEEOmVIVKo000000kooooo00?oMgMgo`000?ooool01Oooool00omg
MgOo0000ooooo`2:ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .36526 Mdot
.04762 .36837 Mdot
.07143 .36468 Mdot
.09524 .35286 Mdot
.11905 .3335 Mdot
.14286 .30988 Mdot
.16667 .28693 Mdot
.19048 .26891 Mdot
.21429 .25779 Mdot
.2381 .25347 Mdot
.2619 .25479 Mdot
.28571 .26038 Mdot
.30952 .26906 Mdot
.33333 .27995 Mdot
.35714 .29237 Mdot
.38095 .30576 Mdot
.40476 .31959 Mdot
.42857 .3333 Mdot
.45238 .34619 Mdot
.47619 .35729 Mdot
.5 .36526 Mdot
.52381 .36837 Mdot
.54762 .36468 Mdot
.57143 .35286 Mdot
.59524 .3335 Mdot
.61905 .30988 Mdot
.64286 .28693 Mdot
.66667 .26891 Mdot
.69048 .25779 Mdot
.71429 .25347 Mdot
.7381 .25479 Mdot
.7619 .26038 Mdot
.78571 .26906 Mdot
.80952 .27995 Mdot
.83333 .29237 Mdot
.85714 .30576 Mdot
.88095 .31959 Mdot
.90476 .3333 Mdot
.92857 .34619 Mdot
.95238 .35729 Mdot
.97619 .36526 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0?Oooool2o`0000Gooooo0_l00028ooooo`;o00001Oooool2o`0005kooooo000`
ooooo`03o`000?oooooooooo03Kooooo0_l00005ooooo`;o00001Oooool2o`00083ooooo0_l00006
ooooo`;o00001Oooool2o`0005kooooo000`ooooo`03o`000?oooooooooo03Kooooo0_l0000Doooo
o`;o0000N?ooool2o`0001Cooooo0_l0001Gooooo`00<?ooool2o`0004gooooo0_l0002>ooooo`;o
0000Eoooool0033ooooo00?o0000ooooooooool0;oooool2o`0002;ooooo0_l0001Zooooo`;o0000
8_ooool2o`00053ooooo000`ooooo`03o`000?oooooooooo02oooooo0_l0000Rooooo`;o0000J_oo
ool2o`0002;ooooo0_l0001@ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0001Kooooo`;o0000Soooool2o`0004So
oooo000`ooooo`03o`000?oooooooooo05[ooooo0_l0002?ooooo`;o0000B?ooool0033ooooo00?o
0000ooooooooool09oooool2o`0008oooooo0_l0001kooooo`00<?ooool00ol0003oooooooooo`0W
ooooo`;o0000Soooool2o`0007_ooooo000`ooooo`;o0000H_ooool2o`0008oooooo0_l00011oooo
o`00<?ooool00ol0003oooooooooo`1Qooooo`;o0000Soooool2o`00047ooooo000Vooooo`Co0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`3oooooocKooooo000Xooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooolfooooo`00:?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo06Sooooo0_l0002?ooooo`;o0000>_ooool002Sooooo00?o0000oooo
ooooool01Oooool3o`00023ooooo0_l00016ooooo`;o0000Aoooool2o`0004Kooooo0_l0000joooo
o`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo023ooooo0_l0002?ooooo`;o
0000P_ooool002Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocKooooo
000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0L?ooool2o`0008kooooo0_l0
000cooooo`009_ooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo073ooooo0_l0002>
ooooo`;o0000<oooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool06Oooool2o`0005cooooo0_l0000`ooooo`;o0000
G?ooool2o`0002cooooo000`ooooo`03o`000?oooooooooo01Wooooo0_l0001Looooo`;o0000<?oo
ool2o`0005cooooo0_l0000/ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`1nooooo`;o0000Soooool2o`0002Co
oooo000`ooooo`03o`000?oooooooooo07kooooo0_l0002?ooooo`;o00009?ooool0033ooooo00?o
0000ooooooooool04_ooool2o`0008kooooo0_l0002Aooooo`00<?ooool2o`0001?ooooo0_l0001a
ooooo`;o00006oooool2o`0007;ooooo0_l0000Mooooo`00<?ooool00ol0003oooooooooo`25oooo
o`;o0000Soooool2o`0001gooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool002oooooo
0_l0000=ooooo`;o0000P?ooool2o`0000cooooo0_l00020ooooo`;o00005_ooool002oooooo0_l0
0005ooooo`;o00001_ooool2o`00083ooooo0_l00005ooooo`;o00001Oooool2o`00083ooooo0_l0
000Fooooo`00<?ooool2o`0000Cooooo0_l0002?ooooo`;o0000Woooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`003_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`Go
00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfoooo
o`004?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A4
00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03
o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o
0000oooooolfooooo`004?ooool00ol0003oooooooooo`0<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oo
oooooooo00gooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000@
ooooo`03o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0oooooolfooooo`003_ooool00omEEEGoIVIVo`00000<
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000Fooooo`Co000000?o410@ooooooooool00_ooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_oo
ool001Sooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00ko
oooo00?oMgMgoc8b<_ooool01?ooool3o`000?oooooo=_ooool001Sooooo00?o0000ooooooooool0
2oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`00
6?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
oooooolfooooo`006?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0oooooolfooooo`005_ooool00omEEEGoIVIVo`00000=ooooo`Co00001_ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`003_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B46ooooo`03
o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
0?oooooo=_ooool0013ooooo00?o0000ooooooooool01?ooool2ob4Q8@Kooooo00?oEEEEojVYZOoo
ool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo
00?o0000ooooooooool03?ooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo
0ol0003oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?o8B4Qooooooooool01_oo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000
ooooooooool03Oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool0
013ooooo00?o0000ooooooooool02_ooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000>ooooo`03oeEEEOmVIVKo0000
00cooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo=oooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`00
0?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool002Gooooo1Ol00006ooooo`03o`000?oooooooooo0?oooooo=_ooool002Gooooo
00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0?oooooo=_ooool002Kooooo
00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`3oooooocKooooo000Wooooo`03oiRHV?lQ
8B7ok^k^00Kooooo0ol0003oooooocKooooo000Xooooo`03ogMgMomVIVKooooo0?oooooo?_ooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`009Oooool01Ol0003o^[ZjoooooonHV9So410@
0?oooooo?oooool002Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c03oooooocoooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo002Xooooo`05oiRHV?l0003o0000odA4A?nj^[X06Ooo
ool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
SOooool00:Sooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003ooooo
ooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`2<ooooo`00Z?ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Roooool00:Sooooo00?o0000
ooooooooool02oooool6o`0000cooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`2<
ooooo`00Z?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c02=ooooo`00Y_ooool00ol@413o0000o`000003o`0001cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`2?ooooo`00Z?ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0Soooool00:Sooooo00?o0000ooooooooool0
6oooool00omEEEGoIVIVo`00000=ooooo`Co0000S_ooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.56) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .35903 Mdot
.04762 .36463 Mdot
.07143 .36478 Mdot
.09524 .35793 Mdot
.11905 .34358 Mdot
.14286 .32331 Mdot
.16667 .30089 Mdot
.19048 .28074 Mdot
.21429 .26601 Mdot
.2381 .25778 Mdot
.2619 .25563 Mdot
.28571 .25844 Mdot
.30952 .26503 Mdot
.33333 .27438 Mdot
.35714 .28568 Mdot
.38095 .29827 Mdot
.40476 .31157 Mdot
.42857 .32502 Mdot
.45238 .33798 Mdot
.47619 .34967 Mdot
.5 .35903 Mdot
.52381 .36463 Mdot
.54762 .36478 Mdot
.57143 .35793 Mdot
.59524 .34358 Mdot
.61905 .32331 Mdot
.64286 .30089 Mdot
.66667 .28074 Mdot
.69048 .26601 Mdot
.71429 .25778 Mdot
.7381 .25563 Mdot
.7619 .25844 Mdot
.78571 .26503 Mdot
.80952 .27438 Mdot
.83333 .28568 Mdot
.85714 .29827 Mdot
.88095 .31157 Mdot
.90476 .32502 Mdot
.92857 .33798 Mdot
.95238 .34967 Mdot
.97619 .35903 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0A?ooool2o`0008oooooo0_l0001Nooooo`00<?ooool00ol0003oooooooooo`0m
ooooo`;o00001Oooool2o`0000Kooooo0_l00020ooooo`;o00001Oooool2o`0000Gooooo0_l0001G
ooooo`00<?ooool00ol0003oooooooooo`0mooooo`;o00003Oooool2o`00083ooooo0_l0000<oooo
o`;o0000Eoooool0033ooooo0_l0001Dooooo`;o0000S_ooool2o`00053ooooo000`ooooo`03o`00
0?oooooooooo03Kooooo0_l0000Kooooo`;o0000LOooool2o`0001_ooooo0_l0001@ooooo`00<?oo
ool00ol0003oooooooooo`0fooooo`;o0000S_ooool2o`0006gooooo000`ooooo`03o`000?oooooo
oooo05[ooooo0_l0002?ooooo`;o0000B?ooool0033ooooo00?o0000ooooooooool0F_ooool2o`00
08oooooo0_l00018ooooo`00<?ooool2o`00033ooooo0_l0002>ooooo`;o0000M?ooool0033ooooo
00?o0000ooooooooool0;oooool2o`0008kooooo0_l0001dooooo`00<?ooool00ol0003ooooooooo
o`1Qooooo`;o0000Soooool2o`00047ooooo000`ooooo`03o`000?oooooooooo067ooooo0_l0002?
ooooo`;o0000@Oooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo06So
oooo0_l0002?ooooo`;o0000>_ooool002Kooooo1?l000000ol@413oooooooooo`03ooooo`03o`00
0?oooooooooo02Oooooo0_l0000oooooo`;o0000C_ooool2o`0003oooooo0_l0000jooooo`00:?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Oooooo0_l0002?ooooo`;o0000Nooo
ool002Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocKooooo000Xoooo
o`03o`000?oooooooooo00Gooooo0ol0001`ooooo`;o0000S_ooool2o`0003?ooooo000Xooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0L?ooool2o`0008kooooo0_l0000cooooo`00
:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo=_ooool002Sooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocKooooo000Vooooo`03oeEEEOmVIVKo
000000Oooooo00?o0000ooooooooool08?ooool2o`0005Gooooo0_l0000hooooo`;o0000E?ooool2
o`0002cooooo000`ooooo`;o00008Oooool2o`0005Gooooo0_l0000hooooo`;o0000E?ooool2o`00
02cooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`1nooooo`;o0000Soooool2o`0002Cooooo000`
ooooo`;o0000Ooooool2o`0008oooooo0_l0000Tooooo`00<?ooool00ol0003oooooooooo`0Ioooo
o`;o0000S_ooool2o`0008[ooooo000`ooooo`03o`000?oooooooooo01Wooooo0_l0002>ooooo`;o
0000R_ooool0033ooooo00?o0000ooooooooool0QOooool2o`0008oooooo0_l0000Mooooo`00<?oo
ool00ol0003oooooooooo`25ooooo`;o0000Soooool2o`0001gooooo000`ooooo`;o00004oooool2
o`0008kooooo0_l0002Aooooo`00;oooool2o`0001Cooooo0_l0001iooooo`;o00004oooool2o`00
07Wooooo0_l0000Fooooo`00;oooool2o`0000Gooooo0_l00028ooooo`;o00001Oooool2o`0008Oo
oooo0_l0000Fooooo`00<?ooool00ol0003oooooooooo`03ooooo`;o00001_ooool2o`0008Oooooo
0_l00005ooooo`;o0000V?ooool0033ooooo00?o0000ooooooooool02oooool2o`0008kooooo0_l0
002Hooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`003_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003o
ooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00_o
oooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000oooooolfooooo`00
4?ooool00ol0003oooooooooo`0<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
oooooolfooooo`004?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooo
oooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0oooooolfooooo`003_ooool00omEEEGoIVIVo`00000<ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0
003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000
oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000Fooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000
ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3o
ooooocKooooo000Hooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_oo
ool01?ooool3o`000?oooooo=_ooool001Sooooo00?o0000ooooooooool02oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`006?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolfooooo`006?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooo
oolfooooo`005_ooool00omEEEGoIVIVo`00000=ooooo`Co00001_ooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`003_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool0013o
oooo00?o0000ooooooooool01?ooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool0
3?ooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocKooooo
000@ooooo`03o`000?oooooooooo00gooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool03Oooool0
0omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`3oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?oZJVYogMgMoooool00oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000oooo
ooooool02_ooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000>ooooo`03oeEEEOmVIVKo000000cooooo1Ol00004oooo
o`Co00001_ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool002Go
oooo1Ol00006ooooo`03o`000?oooooooooo0?oooooo=_ooool002Gooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A006ooooo`03o`000?oooooooooo0?oooooo=_ooool002Kooooo00?oV9RHob4Q8Oo^k^h0
1oooool00ol0003oooooooooo`3oooooocKooooo000Wooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0
003oooooocKooooo000Xooooo`03ogMgMomVIVKooooo0?oooooo?_ooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`009Oooool01Ol0003o^[ZjoooooonHV9So410@0?oooooo?oooool002Go
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c03oooooocoooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo002Tooooo`05oiRHV?l0003o0000odA4A?nj^[X06Oooool4o`000003oa0@4?oo
oooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08[ooooo002Tooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000co
oooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00WoMgMgoc8b<_oooooooooooeEEEOmgMgOo
oooooiRHV?lQ8B40R_ooool00:Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0?
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0R?ooool00:Cooooo00?o0000
ooooooooool02oooool6o`0000cooooo00?o0000ooooooooool03_ooool02OmgMgOo<S8boooooooo
oooo0000oiRHV?ooooooV9RHob4Q8@2:ooooo`00Y?ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0R_ooool00:;ooooo00?o410@o`000?l000000ol0000Looooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool01?ooool00omEEEGoQhN7ooooo`2<ooooo`00Y?ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01?ooool00ooMgMgo410@
oiRHV02<ooooo`00Y?ooool00ol0003oooooooooo`0Kooooo`03oeEEEOmVIVKo000000gooooo1?l0
0004ooooo`04olc<c?m4A4Co0000oa0@48[ooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.62) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .35231 Mdot
.04762 .35964 Mdot
.07143 .36266 Mdot
.09524 .35985 Mdot
.11905 .35018 Mdot
.14286 .334 Mdot
.16667 .31366 Mdot
.19048 .29301 Mdot
.21429 .27575 Mdot
.2381 .26407 Mdot
.2619 .25846 Mdot
.28571 .2583 Mdot
.30952 .26254 Mdot
.33333 .27012 Mdot
.35714 .2801 Mdot
.38095 .29172 Mdot
.40476 .30433 Mdot
.42857 .31734 Mdot
.45238 .33016 Mdot
.47619 .34211 Mdot
.5 .35231 Mdot
.52381 .35964 Mdot
.54762 .36266 Mdot
.57143 .35985 Mdot
.59524 .35018 Mdot
.61905 .334 Mdot
.64286 .31366 Mdot
.66667 .29301 Mdot
.69048 .27575 Mdot
.71429 .26407 Mdot
.7381 .25846 Mdot
.7619 .2583 Mdot
.78571 .26254 Mdot
.80952 .27012 Mdot
.83333 .2801 Mdot
.85714 .29172 Mdot
.88095 .30433 Mdot
.90476 .31734 Mdot
.92857 .33016 Mdot
.95238 .34211 Mdot
.97619 .35231 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`14ooooo`;o00001_ooool2
o`0008Oooooo0_l00005ooooo`;o0000Eoooool0033ooooo00?o0000ooooooooool0A?ooool2o`00
00Kooooo0_l00027ooooo`;o00001Oooool2o`0005Oooooo000`ooooo`;o0000?_ooool2o`0001Co
oooo0_l0001iooooo`;o00004oooool2o`00053ooooo000`ooooo`03o`000?oooooooooo03gooooo
0_l0000Dooooo`;o0000NOooool2o`0001?ooooo0_l0001@ooooo`00<?ooool00ol0003ooooooooo
o`1Jooooo`;o0000Soooool2o`0004Sooooo000`ooooo`03o`000?oooooooooo05[ooooo0_l0002?
ooooo`;o0000B?ooool0033ooooo00?o0000ooooooooool0=_ooool2o`0008kooooo0_l0001]oooo
o`00<?ooool2o`0003Oooooo0_l0000Yooooo`;o0000Hoooool2o`0002[ooooo0_l00011ooooo`00
<?ooool00ol0003oooooooooo`1Qooooo`;o0000Soooool2o`00047ooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0J?ooool2o`0008oooooo0_l0000j
ooooo`00<?ooool2o`00033ooooo0_l0000gooooo`;o0000EOooool2o`0003Sooooo0_l0000joooo
o`00<?ooool00ol0003oooooooooo`0_ooooo`;o0000S_ooool2o`0007Cooooo000Vooooo`Co0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`3oooooocKooooo000Xooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0L?ooool2o`0008kooooo0_l0000cooooo`00:?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo073ooooo0_l0002>ooooo`;o0000<oooool0
02Sooooo00?o0000ooooooooool01Oooool3o`000?oooooo=_ooool002Sooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Wooooo`;o0000Soooool2o`0007_ooooo000Xooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool09oooool2o`0004kooooo0_l0000oooooo`;o0000
COooool2o`0002cooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Mooo
ool2o`0008kooooo0_l0000/ooooo`009_ooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo07ko
oooo0_l0002?ooooo`;o00009?ooool0033ooooo00?o0000ooooooooool08?ooool2o`0005cooooo
0_l0000aooooo`;o0000G?ooool2o`0002Cooooo000`ooooo`03o`000?oooooooooo023ooooo0_l0
002?ooooo`;o0000P_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
08Gooooo0_l0002?ooooo`;o00007Oooool0033ooooo00?o0000ooooooooool0QOooool2o`0008oo
oooo0_l0000Mooooo`00<?ooool00ol0003oooooooooo`0Iooooo`;o0000S_ooool2o`0008[ooooo
000_ooooo`;o00006oooool2o`0007;ooooo0_l0000Jooooo`;o0000L_ooool2o`0001Kooooo000_
ooooo`?o0000S_ooool2o`0008kooooo0_l0000Fooooo`00<?ooool00ol0003oooooooooo`03oooo
o`;o00003Oooool2o`00083ooooo0_l0000<ooooo`;o0000TOooool0033ooooo00?o0000oooooooo
ool00oooool2o`0000Kooooo0_l00005ooooo`;o0000P?ooool2o`0000Gooooo0_l00005ooooo`;o
0000TOooool0033ooooo00?o0000ooooooooool02oooool2o`0008kooooo0_l0002Hooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000>ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Co
oooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocKooooo000@ooooo`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0013o
oooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?o
oooo0ol0003oooooocKooooo000@ooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o
0000ooooooooool03Oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0013ooooo00?o0000ooooooooool02_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000>ooooo`03oeEEEOmVIVKo
000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`000?oooooo=ooo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Kooooo1?l000000ol@413oooooooooo`02
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooo
oolfooooo`006?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000oooooooo
ool03_ooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`006?ooool00ol0003ooooo
ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKo
oooo000Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooocKooooo000Fooooo`03oeEEEOmVIVKo000000gooooo1?l00006
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000>ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Ko
oooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGo
ZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`00
4?ooool00ol0003oooooooooo`0<ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool0
0oooool3o`000?oooooo=_ooool0013ooooo00?o0000ooooooooool03Oooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`004?ooool0
0ol0003oooooooooo`0=ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool03Oooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`004?ooool00ol0003oooooooooo`0:ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool000kooooo00?oEEEEofIV
I_l000003?ooool5o`0000Cooooo1?l00006ooooo`;o0000oooooolgooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`009Oooool5o`0000Kooooo00?o0000ooooooooool0oooooolfooooo`00
9Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooolfooooo`00
9_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0?oooooo=_ooool002Oooooo00?o
V9RHob4Q8Oo^k^h01_ooool3o`000?oooooo=_ooool002Sooooo00?oMgMgofIVI_ooool0ooooooln
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Uooooo`05o`000?nj^[[ooooooiRH
V?l@4100ooooooloooooo`009Oooool01OnHV9So410@o`000?lQ8B7oc<c<0?oooooo?oooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00:Cooooo00GoV9RHo`000?l0003oA4A4okZj
^P0Iooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@
olc<c003ooooo`Go0000R_ooool00:Cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko0000
3?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00?o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A02:ooooo`00Y?ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`000004ooooo`03oiRHV?lQ8B7ok^k^
08_ooooo002Tooooo`03o`000?oooooooooo00_ooooo1_l0000<ooooo`03o`000?oooooooooo00[o
oooo00Go0000oiRHV?ooooooV9RHob4Q8@05ooooo`03oiRHV?lQ8B7ok^k^08[ooooo002Tooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool02_ooool01Ol0003oEEEEo`000?l@413oc<c<
00Kooooo00?oMgMgofIVI_ooool0ROooool00:;ooooo00?o410@o`000?l000000ol0000Looooo`03
o`000?oooooooooo00[ooooo00?oEEEEohN7Qoooool02Oooool00ol0003oooooooooo`28ooooo`00
Y?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00[ooooo00?ogMgMoa0@4?nHV9P0
1Oooool01Ol0003o^[ZjoooooonHV9So410@08[ooooo002Tooooo`03o`000?oooooooooo01_ooooo
00?oEEEEofIVI_l000003Oooool01?o<c<coA4A4o`000?l@4103ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`0R_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.68) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .34539 Mdot
.04762 .35385 Mdot
.07143 .35894 Mdot
.09524 .3593 Mdot
.11905 .35369 Mdot
.14286 .34171 Mdot
.16667 .32448 Mdot
.19048 .30483 Mdot
.21429 .28636 Mdot
.2381 .27201 Mdot
.2619 .2632 Mdot
.28571 .26001 Mdot
.30952 .2617 Mdot
.33333 .26725 Mdot
.35714 .27569 Mdot
.38095 .28616 Mdot
.40476 .29791 Mdot
.42857 .31032 Mdot
.45238 .3228 Mdot
.47619 .33473 Mdot
.5 .34539 Mdot
.52381 .35385 Mdot
.54762 .35894 Mdot
.57143 .3593 Mdot
.59524 .35369 Mdot
.61905 .34171 Mdot
.64286 .32448 Mdot
.66667 .30483 Mdot
.69048 .28636 Mdot
.71429 .27201 Mdot
.7381 .2632 Mdot
.7619 .26001 Mdot
.78571 .2617 Mdot
.80952 .26725 Mdot
.83333 .27569 Mdot
.85714 .28616 Mdot
.88095 .29791 Mdot
.90476 .31032 Mdot
.92857 .3228 Mdot
.95238 .33473 Mdot
.97619 .34539 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo04cooooo0_l00005ooooo`;o0000Qoooool2o`0000Gooooo0_l0001@oooo
o`00<?ooool2o`0004Gooooo0_l00006ooooo`;o00001Oooool2o`00083ooooo0_l00005ooooo`;o
00001Oooool2o`00053ooooo000`ooooo`03o`000?oooooooooo04Cooooo0_l0000Dooooo`;o0000
NOooool2o`0001Cooooo0_l00018ooooo`00<?ooool00ol0003oooooooooo`0mooooo`;o00006ooo
ool2o`0007;ooooo0_l0000Kooooo`;o0000B?ooool0033ooooo00?o0000ooooooooool0?Oooool2
o`0008oooooo0_l0001Uooooo`00<?ooool00ol0003oooooooooo`1Qooooo`;o0000Soooool2o`00
047ooooo000`ooooo`;o0000H_ooool2o`0008oooooo0_l00011ooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo03Kooooo0_l0000`ooooo`;o0000G?oo
ool2o`00037ooooo0_l0000jooooo`00<?ooool00ol0003oooooooooo`0fooooo`;o0000<?ooool2
o`0005cooooo0_l0000aooooo`;o0000>_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03
o`000?oooooooooo073ooooo0_l0002>ooooo`;o0000<oooool002Kooooo1?l000000ol@413ooooo
ooooo`03ooooo`03o`000?oooooooooo073ooooo0_l0002>ooooo`;o0000<oooool002Sooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0_ooooo`;o0000S_ooool2o`0007Cooooo000X
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;oooool2o`0008kooooo0_l0001d
ooooo`00:?ooool00ol0003oooooooooo`05ooooo`?o0000Moooool2o`0008kooooo0_l0000/oooo
o`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07Oooooo0_l0002>ooooo`;o
0000;?ooool002Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocKooooo
000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolfooooo`009_ooool0
0omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo02Oooooo0_l0001Eooooo`;o0000>?ooool2
o`0005Gooooo0_l0000Tooooo`00<?ooool2o`0002Sooooo0_l0001Eooooo`;o0000>?ooool2o`00
05Gooooo0_l0000Tooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo08Gooooo0_l0002?ooooo`;o00007Oooool0033ooooo00?o0000ooooooooool0QOoo
ool2o`0008oooooo0_l0000Mooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool08?ooool2o`0008oooooo0_l00022ooooo`00;oooool2o`0002;ooooo0_l0001[ooooo`;o
00008_ooool2o`0006[ooooo0_l0000Fooooo`00;oooool2o`0008oooooo0_l0002>ooooo`;o0000
5_ooool0033ooooo00?o0000ooooooooool00oooool2o`0001Cooooo0_l0001iooooo`;o00004ooo
ool2o`0008[ooooo000`ooooo`;o00001?ooool2o`0001Cooooo0_l0001iooooo`;o00004oooool2
o`0008[ooooo000`ooooo`03o`000?oooooooooo00_ooooo0_l00005ooooo`;o0000Qoooool2o`00
00Gooooo0_l0002Aooooo`00<?ooool00ol0003oooooooooo`0;ooooo`;o00001Oooool2o`0008Oo
oooo0_l00005ooooo`;o0000TOooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000>ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Co
oooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocKooooo000@ooooo`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0013o
oooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?o
oooo0ol0003oooooocKooooo000@ooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o
0000ooooooooool03Oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0013ooooo00?o0000ooooooooool02_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000>ooooo`03oeEEEOmVIVKo
000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`000?oooooo=ooo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Kooooo1?l000000ol@413oooooooooo`02
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooo
oolfooooo`006?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000oooooooo
ool03_ooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`006?ooool00ol0003ooooo
ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKo
oooo000Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooocKooooo000Fooooo`03oeEEEOmVIVKo000000gooooo1?l00006
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000>ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Ko
oooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGo
ZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`00
4?ooool00ol0003oooooooooo`0<ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool0
0oooool3o`000?oooooo=_ooool0013ooooo00?o0000ooooooooool03Oooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`004?ooool0
0ol0003oooooooooo`0=ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool03Oooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`004?ooool00ol0003oooooooooo`0:ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool000kooooo00?oEEEEofIV
I_l000003?ooool5o`0000Cooooo1?l00006ooooo`;o0000oooooolgooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`009Oooool5o`0000Kooooo00?o0000ooooooooool0oooooolfooooo`00
9Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooolfooooo`00
9_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0?oooooo=_ooool002Oooooo00?o
V9RHob4Q8Oo^k^h01_ooool3o`000?oooooo=_ooool002Sooooo00?oMgMgofIVI_ooool0ooooooln
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Uooooo`05o`000?nj^[[ooooooiRH
V?l@4100ooooooloooooo`009Oooool01OnHV9So410@o`000?lQ8B7oc<c<0?oooooo?oooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00:Cooooo00GoV9RHo`000?l0003oA4A4okZj
^P0Iooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@
olc<c003ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0R_ooool00:Cooooo00Go410@okZj^_o^k^ko
MgMgoa0@4009ooooo`Ko00003?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OmEEEGo
MgMgoooooonHV9So8B4Q00?ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@2:ooooo`00Y?ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool00000R_ooool00:Cooooo00?o0000ooooooooool02oooool6
o`0000cooooo00?o0000ooooooooool02_ooool01Ol0003oV9RHoooooonHV9So8B4Q00?ooooo00Go
<S8boiRHV?ooooooV9RHoc8b<P2:ooooo`00Y?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00[ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05olc<c?l0003o0000o`000?o<
c<`0R_ooool00:;ooooo00?o410@o`000?l000000ol0000Looooo`03o`000?oooooooooo00[ooooo
00?oEEEEohN7Qoooool01Oooool01Ol@413o^[Zjoooooonj^[[o410@08[ooooo002Tooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool02_ooool00ooMgMgo410@oiRHV005ooooo`05o`00
0?nj^[[ooooookZj^_l00000R_ooool00:Cooooo00?o0000ooooooooool06oooool00omEEEGoIVIV
o`00000=ooooo`04olc<c?m4A4Co0000oa0@40?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2:oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.74) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .33846 Mdot
.04762 .34761 Mdot
.07143 .35414 Mdot
.09524 .35688 Mdot
.11905 .35463 Mdot
.14286 .34656 Mdot
.16667 .33291 Mdot
.19048 .31542 Mdot
.21429 .29709 Mdot
.2381 .28109 Mdot
.2619 .26962 Mdot
.28571 .26351 Mdot
.30952 .26252 Mdot
.33333 .26585 Mdot
.35714 .27253 Mdot
.38095 .28162 Mdot
.40476 .29233 Mdot
.42857 .30397 Mdot
.45238 .31594 Mdot
.47619 .32765 Mdot
.5 .33846 Mdot
.52381 .34761 Mdot
.54762 .35414 Mdot
.57143 .35688 Mdot
.59524 .35463 Mdot
.61905 .34656 Mdot
.64286 .33291 Mdot
.66667 .31542 Mdot
.69048 .29709 Mdot
.71429 .28109 Mdot
.7381 .26962 Mdot
.7619 .26351 Mdot
.78571 .26252 Mdot
.80952 .26585 Mdot
.83333 .27253 Mdot
.85714 .28162 Mdot
.88095 .29233 Mdot
.90476 .30397 Mdot
.92857 .31594 Mdot
.95238 .32765 Mdot
.97619 .33846 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0001=ooooo`;o00001Oooool2o`0008Oo
oooo0_l00005ooooo`;o0000D?ooool0033ooooo00?o0000ooooooooool0C?ooool2o`0000Gooooo
0_l00005ooooo`;o0000P?ooool2o`0000Gooooo0_l00006ooooo`;o0000B?ooool0033ooooo00?o
0000ooooooooool0A?ooool2o`0001Cooooo0_l0001iooooo`;o00005?ooool2o`0004Sooooo000`
ooooo`03o`000?oooooooooo04Cooooo0_l0000Kooooo`;o0000L_ooool2o`0001_ooooo0_l00011
ooooo`00<?ooool00ol0003oooooooooo`1Qooooo`;o0000Soooool2o`00047ooooo000`ooooo`;o
0000?_ooool2o`0002Wooooo0_l0001Tooooo`;o0000:Oooool2o`0003[ooooo000`ooooo`03o`00
0?oooooooooo03gooooo0_l0000Yooooo`;o0000I?ooool2o`0002Wooooo0_l0000jooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0
033ooooo0_l0001aooooo`;o0000S_ooool2o`0003?ooooo000`ooooo`03o`000?oooooooooo03Ko
oooo0_l0000hooooo`;o0000E?ooool2o`0003Sooooo0_l0000cooooo`009_ooool4o`000003oa0@
4?oooooooooo00?ooooo00?o0000ooooooooool0=_ooool2o`0008kooooo0_l0001]ooooo`00:?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07Oooooo0_l0002>ooooo`;o0000;?oo
ool002Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1gooooo`;o0000S_ooool2
o`0002cooooo000Xooooo`03o`000?oooooooooo00Gooooo0ol0003oooooocKooooo000Xooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolfooooo`00:?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo02oooooo0_l0001=ooooo`;o0000?oooool2o`0004kooooo
0_l0000Tooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02oooooo0_l0
001=ooooo`;o0000?oooool2o`0004kooooo0_l0000Tooooo`009_ooool00omEEEGoIVIVo`000007
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l00026ooooo`;o0000Soooool2o`00
01gooooo000`ooooo`03o`000?oooooooooo08Gooooo0_l0002?ooooo`;o00007Oooool0033ooooo
00?o0000ooooooooool09oooool2o`0008oooooo0_l0001kooooo`00<?ooool00ol0003ooooooooo
o`0Wooooo`;o0000Soooool2o`0007_ooooo000_ooooo`?o0000S_ooool2o`0008kooooo0_l0000F
ooooo`00;oooool2o`0008oooooo0_l0002>ooooo`;o00005_ooool0033ooooo00?o0000oooooooo
ool00oooool2o`0001_ooooo0_l0001booooo`;o00006oooool2o`0008;ooooo000`ooooo`03o`00
0?oooooooooo00?ooooo0_l0000Kooooo`;o0000L_ooool2o`0001_ooooo0_l00022ooooo`00<?oo
ool00ol0003oooooooooo`0;ooooo`;o00003?ooool2o`00083ooooo0_l0000<ooooo`;o0000R_oo
ool0033ooooo0_l0000<ooooo`;o00001Oooool2o`0000Gooooo0_l00020ooooo`;o00001Oooool2
o`0000Gooooo0_l0002:ooooo`00<?ooool00ol0003oooooooooo`0Booooo`;o0000S_ooool2o`00
097ooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolg
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000>ooooo`Co000000?o410@oooooooo
ool00_ooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
0?oooooo=_ooool0013ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP09ooooo`03
o`000?oooooooooo00?ooooo0ol0003oooooocKooooo000@ooooo`03o`000?oooooooooo00cooooo
00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo
=_ooool0013ooooo00?o0000ooooooooool03Oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool02_ooool01Ol0003o^[ZjoooooonH
V9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000>
ooooo`03oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_oo
ool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000
ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Kooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo=_ooool001So
oooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`00
6?ooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003o
ooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000Fooooo`03oeEEEOmVIVKo
000000gooooo1?l00006ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolg
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolg
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000>ooooo`Co000000?o410@oooooooo
ool00_ooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`04ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooolfooooo`004?ooool00ol0003oooooooooo`0<ooooo`03ojVYZOmEEEGooooo00Sooooo
00?o0000ooooooooool00oooool3o`000?oooooo=_ooool0013ooooo00?o0000ooooooooool03Ooo
ool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooo
oolfooooo`004?ooool00ol0003oooooooooo`0=ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000
ooooooooool03Oooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0:ooooo`05oa0@4?oooooooooo
oooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool0
00kooooo00?oEEEEofIVI_l000003?ooool5o`0000Cooooo1?l00006ooooo`;o0000oooooolgoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`009Oooool5o`0000Kooooo00?o0000oooooooo
ool0oooooolfooooo`009Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000oooooooo
ool0oooooolfooooo`009_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0?oooooo
=_ooool002Oooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000?oooooo=_ooool002Sooooo00?oMgMg
ofIVI_ooool0oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Uooooo`05
o`000?nj^[[ooooooiRHV?l@4100ooooooloooooo`009Oooool01OnHV9So410@o`000?lQ8B7oc<c<
0?oooooo?oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Cooooo00GoV9RH
o`000?l0003oA4A4okZj^P0Iooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Kooooo00?o
0000onk^k_ooool01Oooool2o`000003oa0@4?oooooooooo08Sooooo002Tooooo`05oa0@4?nj^[[o
k^k^ogMgMol@41002Oooool6o`0000cooooo00?o0000ooooooooool01?ooool2ob4Q8@Kooooo00?o
EEEEojVYZOooool01_ooool00ol0003oooooooooo`29ooooo`00Y?ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo00cooooo00?oZJVYoeEEEOooool00oooool5o`0008[ooooo002Toooo
o`03o`000?oooooooooo00_ooooo1_l0000<ooooo`03o`000?oooooooooo00gooooo00?o8B4Qoooo
ooooool00_ooool01?m4A4CogMgMooooool0002;ooooo`00Y?ooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo00gooooo00?oEEEEolc<c?ooool00_ooool01?oMgMgoEEEEooooool0002;
ooooo`00X_ooool00ol@413o0000o`000003o`0001cooooo00?o0000ooooooooool03Oooool00onY
ZJWoMgMgooooo`03ooooo`03ogMgMoo<c<co000008_ooooo002Tooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool02_ooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?ok^k^odA4
A?l00000Roooool00:Cooooo00?o0000ooooooooool06oooool00omEEEGoIVIVo`00000<ooooo`Go
00001Oooool00omgMgOo0000ooooo`2:ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .33166 Mdot
.04762 .34116 Mdot
.07143 .34864 Mdot
.09524 .35313 Mdot
.11905 .35353 Mdot
.14286 .34889 Mdot
.16667 .33885 Mdot
.19048 .32424 Mdot
.21429 .30722 Mdot
.2381 .29071 Mdot
.2619 .27733 Mdot
.28571 .26864 Mdot
.30952 .265 Mdot
.33333 .26595 Mdot
.35714 .27065 Mdot
.38095 .27817 Mdot
.40476 .28765 Mdot
.42857 .29835 Mdot
.45238 .30964 Mdot
.47619 .32093 Mdot
.5 .33166 Mdot
.52381 .34116 Mdot
.54762 .34864 Mdot
.57143 .35313 Mdot
.59524 .35353 Mdot
.61905 .34889 Mdot
.64286 .33885 Mdot
.66667 .32424 Mdot
.69048 .30722 Mdot
.71429 .29071 Mdot
.7381 .27733 Mdot
.7619 .26864 Mdot
.78571 .265 Mdot
.80952 .26595 Mdot
.83333 .27065 Mdot
.85714 .27817 Mdot
.88095 .28765 Mdot
.90476 .29835 Mdot
.92857 .30964 Mdot
.95238 .32093 Mdot
.97619 .33166 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0001Dooooo`;o0000S_ooool2o`00053o
oooo000`ooooo`03o`000?oooooooooo04cooooo0_l00005ooooo`;o00001Oooool2o`00083ooooo
0_l00005ooooo`;o00001_ooool2o`0004Sooooo000`ooooo`03o`000?oooooooooo04cooooo0_l0
000<ooooo`;o00001Oooool2o`0007Wooooo0_l0000=ooooo`;o00001Oooool2o`00047ooooo000`
ooooo`03o`000?oooooooooo067ooooo0_l0002?ooooo`;o0000@Oooool0033ooooo00?o0000oooo
ooooool0A?ooool2o`0002;ooooo0_l0001[ooooo`;o00008_ooool2o`0003[ooooo000`ooooo`;o
0000AOooool2o`0002;ooooo0_l0001[ooooo`;o00008_ooool2o`0003[ooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0L?ooool2o`0008kooooo0_l0
000cooooo`00<?ooool00ol0003oooooooooo`0mooooo`;o0000<Oooool2o`0005cooooo0_l0000`
ooooo`;o0000<oooool0033ooooo0_l0000nooooo`;o0000Soooool2o`0006Gooooo000`ooooo`03
o`000?oooooooooo07Oooooo0_l0002>ooooo`;o0000;?ooool002Kooooo1?l000000ol@413ooooo
ooooo`03ooooo`03o`000?oooooooooo07Oooooo0_l0002>ooooo`;o0000;?ooool002Sooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocKooooo000Xooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0=_ooool2o`0008kooooo0_l0001]ooooo`00:?ooool00ol0
003oooooooooo`05ooooo`?o0000=_ooool2o`0004Kooooo0_l00016ooooo`;o0000Aoooool2o`00
02Cooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0O_ooool2o`0008oo
oooo0_l0000Tooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
=_ooool002Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`25ooooo`;o0000Sooo
ool2o`0001gooooo000Vooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0;oooool2
o`0005Cooooo0_l0000hooooo`;o0000EOooool2o`0001gooooo000`ooooo`;o0000<?ooool2o`00
08kooooo0_l0001dooooo`00;oooool2o`0008oooooo0_l0002>ooooo`;o00005_ooool002oooooo
0_l0002?ooooo`;o0000S_ooool2o`0001Kooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l00004ooooo`;o00008_ooool2o`0006_ooooo0_l0000Rooooo`;o0000Noooool0
033ooooo00?o0000ooooooooool00oooool2o`0002;ooooo0_l0001[ooooo`;o00008_ooool2o`00
07_ooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
2oooool2o`0001?ooooo0_l0001iooooo`;o00005?ooool2o`0008;ooooo000`ooooo`03o`000?oo
oooooooo00_ooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l0001iooooo`;o00001Ooo
ool2o`0000Gooooo0_l00006ooooo`;o0000P_ooool0033ooooo0_l0000Cooooo`;o00001Oooool2
o`0008Oooooo0_l00005ooooo`;o0000R_ooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`003_ooool4o`000003oa0@4?oooooooooo00;o
oooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooo
ocKooooo000@ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003o
ooooooooo`03ooooo`?o0000oooooolfooooo`004?ooool00ol0003oooooooooo`0<ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo
000@ooooo`03o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`3oooooocKooooo000@ooooo`03o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@
4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolfooooo`003_ooool0
0omEEEGoIVIVo`00000<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0
003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000
oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000Fooooo`Co000000?o410@
ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03
o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool3o`000?oooooo=_ooool001Sooooo
00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool0oooooolfooooo`006?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0oooooolfooooo`005_ooool00omEEEGoIVIVo`00000=
ooooo`Co00001_ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`003_ooool4o`000003oa0@4?oooooooooo00;o
oooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool01?ooool2ob4Q8@Ko
oooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0013ooooo00?o0000ooooooooool03?ooool00onYZJWoEEEEooooo`08ooooo`03o`00
0?oooooooooo00?ooooo0ol0003oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?o
8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0013ooooo00?o0000ooooooooool03Oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooo
oooo00gooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool02_ooool01Ol@413ooooooooooooooooo
<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000>oooo
o`03oeEEEOmVIVKo000000cooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool002Gooooo1Ol00006ooooo`03o`000?oooooooooo0?oo
oooo=_ooool002Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0?oo
oooo=_ooool002Kooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`3oooooocKooooo
000Wooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003oooooocKooooo000Xooooo`03ogMgMomVIVKo
oooo0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`009Oooool01Ol0003o
^[ZjoooooonHV9So410@0?oooooo?oooool002Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c03ooooo
ocoooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Xooooo`05oiRHV?l0003o
0000odA4A?nj^[X06Oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`05olc<c?lQ
8B7o0000ob4Q8Oo<c<`0S_ooool00:Sooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko0000
3?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q08ko
oooo002Xooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02_ooool01Ol0003ooooo
oooooooooooo000008kooooo002Xooooo`03o`000?oooooooooo00_ooooo1_l0000<ooooo`03o`00
0?oooooooooo00[ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P2>ooooo`00Z?ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo00[ooooo00Goc<c<o`000?l0003o0000olc<c02>ooooo`00
Y_ooool00ol@413o0000o`000003o`0001cooooo00?o0000ooooooooool02_ooool01Ol@413o^[Zj
oooooonj^[[o410@08kooooo002Xooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
2_ooool01Ol0003o^[Zjoooooonj^[[o000008kooooo002Xooooo`03o`000?oooooooooo01_ooooo
00?oEEEEofIVI_l000003?ooool01OnYZJWo410@o`000?l@413oZJVY08kooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.86) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .3251 Mdot
.04762 .33468 Mdot
.07143 .34274 Mdot
.09524 .34847 Mdot
.11905 .35091 Mdot
.14286 .34912 Mdot
.16667 .34244 Mdot
.19048 .33101 Mdot
.21429 .31615 Mdot
.2381 .30022 Mdot
.2619 .28586 Mdot
.28571 .27513 Mdot
.30952 .26902 Mdot
.33333 .26755 Mdot
.35714 .27011 Mdot
.38095 .27585 Mdot
.40476 .28391 Mdot
.42857 .2935 Mdot
.45238 .30394 Mdot
.47619 .31466 Mdot
.5 .3251 Mdot
.52381 .33468 Mdot
.54762 .34274 Mdot
.57143 .34847 Mdot
.59524 .35091 Mdot
.61905 .34912 Mdot
.64286 .34244 Mdot
.66667 .33101 Mdot
.69048 .31615 Mdot
.71429 .30022 Mdot
.7381 .28586 Mdot
.7619 .27513 Mdot
.78571 .26902 Mdot
.80952 .26755 Mdot
.83333 .27011 Mdot
.85714 .27585 Mdot
.88095 .28391 Mdot
.90476 .2935 Mdot
.92857 .30394 Mdot
.95238 .31466 Mdot
.97619 .3251 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`00
0?oooooooooo05?ooooo0_l00005ooooo`;o0000Qoooool2o`0000Kooooo0_l00018ooooo`00<?oo
ool00ol0003oooooooooo`1Cooooo`;o00001Oooool2o`0000Gooooo0_l00020ooooo`;o00001_oo
ool2o`0000Gooooo0_l00011ooooo`00<?ooool00ol0003oooooooooo`1<ooooo`;o00004oooool2
o`0007Wooooo0_l0000Dooooo`;o0000@Oooool0033ooooo00?o0000ooooooooool0C?ooool2o`00
01[ooooo0_l0001booooo`;o00006oooool2o`0003[ooooo000`ooooo`;o0000JOooool2o`0008oo
oooo0_l0000jooooo`00<?ooool00ol0003oooooooooo`1`ooooo`;o0000S_ooool2o`0003?ooooo
000`ooooo`03o`000?oooooooooo04Cooooo0_l0000Zooooo`;o0000Hoooool2o`0002Wooooo0_l0
000cooooo`00<?ooool00ol0003oooooooooo`14ooooo`;o0000Soooool2o`0005kooooo000`oooo
o`;o0000N?ooool2o`0008kooooo0_l0000/ooooo`00<?ooool00ol0003oooooooooo`1gooooo`;o
0000S_ooool2o`0002cooooo000Vooooo`Co000000?o410@ooooooooool00oooool00ol0003ooooo
ooooo`0mooooo`;o0000Soooool2o`0006Gooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0?Oooool2o`0003oooooo0_l0001>ooooo`;o0000?oooool2o`0002Cooooo000X
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0O_ooool2o`0008oooooo0_l0000T
ooooo`00:?ooool00ol0003oooooooooo`05ooooo`?o0000oooooolfooooo`00:?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo08Gooooo0_l0002?ooooo`;o00007Oooool002Sooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0fooooo`;o0000COooool2o`0003oooooo
0_l0001>ooooo`;o00007Oooool002Sooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0fooooo`;o0000S_ooool2o`0006gooooo000Vooooo`03oeEEEOmVIVKo000000Oooooo00?o0000
ooooooooool0oooooolfooooo`00;oooool3o`0008kooooo0_l0002>ooooo`;o00005_ooool002oo
oooo0_l0000aooooo`;o0000G?ooool2o`00033ooooo0_l0001Looooo`;o00005_ooool0033ooooo
00?o0000ooooooooool00oooool2o`0002[ooooo0_l0001Sooooo`;o0000:Oooool2o`0007Cooooo
000`ooooo`03o`000?oooooooooo00?ooooo0_l0002?ooooo`;o0000Woooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo00_ooooo0_l0000Jooooo`;o0000L_ooool2o`00
01_ooooo0_l0001kooooo`00<?ooool00ol0003oooooooooo`0;ooooo`;o00006_ooool2o`0007;o
oooo0_l0000Kooooo`;o0000Noooool0033ooooo00?o0000ooooooooool04_ooool2o`0000Gooooo
0_l00005ooooo`;o0000P?ooool2o`0000Gooooo0_l00006ooooo`;o0000P_ooool0033ooooo00?o
0000ooooooooool04_ooool2o`0000Gooooo0_l00005ooooo`;o0000P?ooool2o`0000Gooooo0_l0
0006ooooo`;o0000P_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000kooooo1?l000000ol@413o
ooooooooo`02ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool01?ooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Wo
oooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool0013ooooo00?o0000ooooooooool0
3?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
oooooolfooooo`004?ooool00ol0003oooooooooo`0=ooooo`03ogMgMomVIVKooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[o
oooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_oo
ool000kooooo00?oEEEEofIVI_l000003?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0
0006ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`005_ooool4
o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00Cooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`006?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooolfoooo
o`006?ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0003oooooocKo
oooo000Hooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool001Kooooo00?oEEEE
ofIVI_l000003Oooool4o`0000Kooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`00
0?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000kooooo1?l000000ol@413o
ooooooooo`02ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00Co
oooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00cooooo00?oZJVYoeEEEOooool0
2?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolfooooo`004?ooool00ol0003ooooooooo
o`0=ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?oEEEEolc<c?ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`004?ooool0
0ol0003oooooooooo`0=ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00[ooooo00Go410@oooo
oooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`003_ooool00omEEEGoIVIVo`00000<ooooo`Go00001?ooool4o`0000Kooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolg
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000Uooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooocKooooo000Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooocKooooo000Vooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0
oooooolfooooo`009oooool00onHV9So8B4Qonk^kP06ooooo`?o0000oooooolfooooo`00:?ooool0
0omgMgOoIVIVooooo`3oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Go
oooo00Go0000okZj^_ooooooV9RHoa0@403oooooocoooooo000Uooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`0ooooooloooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Y?ooool0
1OnHV9So0000o`000?m4A4Co^[Zj01Wooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o410@olc<c02:ooooo`00
Y?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<ooooo`03o`000?oooooooooo00Co
oooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B400oooool01OmEEEGoMgMgoooooonHV9So
8B4Q08[ooooo002Tooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00002:ooooo`00Y?ooool0
0ol0003oooooooooo`0;ooooo`Ko00003?ooool00ol0003oooooooooo`0:ooooo`05oc8b<_nHV9So
oooooiRHV?lb<S800oooool01Ol0003oV9RHoooooonHV9So8B4Q08[ooooo002Tooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool02_ooool01Oo<c<co0000o`000?l0003oc<c<00?ooooo
00Go0000oeEEEOl0003o410@olc<c02:ooooo`00X_ooool00ol@413o0000o`000003o`0001cooooo
00?o0000ooooooooool02_ooool01Ol@413o^[Zjoooooonj^[[o410@00?ooooo00?oEEEEohN7Qooo
ool0S?ooool00:Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0:ooooo`05o`00
0?nj^[[ooooookZj^_l000000oooool00ooMgMgo410@oiRHV02<ooooo`00Y?ooool00ol0003ooooo
ooooo`0Kooooo`03oeEEEOmVIVKo000000cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@04ooooo`04
olc<c?m4A4Co0000oa0@48[ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.92) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .31886 Mdot
.04762 .32832 Mdot
.07143 .33667 Mdot
.09524 .34324 Mdot
.11905 .34721 Mdot
.14286 .34771 Mdot
.16667 .34396 Mdot
.19048 .33569 Mdot
.21429 .3235 Mdot
.2381 .30903 Mdot
.2619 .29463 Mdot
.28571 .28258 Mdot
.30952 .27438 Mdot
.33333 .27057 Mdot
.35714 .27091 Mdot
.38095 .27471 Mdot
.40476 .28116 Mdot
.42857 .28945 Mdot
.45238 .29889 Mdot
.47619 .30888 Mdot
.5 .31886 Mdot
.52381 .32832 Mdot
.54762 .33667 Mdot
.57143 .34324 Mdot
.59524 .34721 Mdot
.61905 .34771 Mdot
.64286 .34396 Mdot
.66667 .33569 Mdot
.69048 .3235 Mdot
.71429 .30903 Mdot
.7381 .29463 Mdot
.7619 .28258 Mdot
.78571 .27438 Mdot
.80952 .27057 Mdot
.83333 .27091 Mdot
.85714 .27471 Mdot
.88095 .28116 Mdot
.90476 .28945 Mdot
.92857 .29889 Mdot
.95238 .30888 Mdot
.97619 .31886 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0F_ooool2o`0000Gooooo0_l0
0028ooooo`;o00001Oooool2o`00047ooooo000`ooooo`03o`000?oooooooooo05?ooooo0_l00005
ooooo`;o00001Oooool2o`0000Gooooo0_l0001iooooo`;o00001_ooool2o`0000Gooooo0_l00005
ooooo`;o0000>_ooool0033ooooo00?o0000ooooooooool0Doooool2o`0001?ooooo0_l0001ioooo
o`;o00005?ooool2o`0003[ooooo000`ooooo`;o0000LOooool2o`0008kooooo0_l0000cooooo`00
<?ooool00ol0003oooooooooo`1<ooooo`;o00008_ooool2o`0006[ooooo0_l0000Rooooo`;o0000
<oooool0033ooooo00?o0000ooooooooool0C?ooool2o`0008kooooo0_l0001Gooooo`00<?ooool0
0ol0003oooooooooo`1gooooo`;o0000S_ooool2o`0002cooooo000`ooooo`;o0000AOooool2o`00
037ooooo0_l0001Looooo`;o0000<?ooool2o`0002cooooo000`ooooo`03o`000?oooooooooo04Co
oooo0_l0002?ooooo`;o0000G_ooool002Kooooo1?l000000ol@413oooooooooo`03ooooo`03o`00
0?oooooooooo07kooooo0_l0002?ooooo`;o00009?ooool002Sooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1nooooo`;o0000Soooool2o`0002Cooooo000Xooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0oooooolfooooo`00:?ooool00ol0003oooooooooo`05oooo
o`?o0000?Oooool2o`0004Kooooo0_l00017ooooo`;o0000A_ooool2o`0001gooooo000Xooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0?Oooool2o`0004Kooooo0_l00017ooooo`;o
0000A_ooool2o`0001gooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
oooooolfooooo`00:?ooool00ol0003oooooooooo`04ooooo`;o0000Soooool2o`0008kooooo0_l0
000Fooooo`009_ooool00omEEEGoIVIVo`000006ooooo`;o0000>?ooool2o`0005Gooooo0_l0000g
ooooo`;o0000EOooool2o`0001Kooooo000`ooooo`;o00001?ooool2o`00037ooooo0_l0001Loooo
o`;o0000<?ooool2o`0006gooooo000`ooooo`03o`000?oooooooooo00?ooooo0_l0002?ooooo`;o
0000Woooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`0;ooooo`;o00008_ooool2o`0006[ooooo0_l0000Rooooo`;o0000M?ooool0033ooooo0_l0000<
ooooo`;o00008_ooool2o`0006[ooooo0_l0000Rooooo`;o0000M?ooool0033ooooo00?o0000oooo
ooooool04_ooool2o`0001?ooooo0_l0001iooooo`;o00005?ooool2o`0007_ooooo000`ooooo`03
o`000?oooooooooo01;ooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l0001iooooo`;o
00001Oooool2o`0000Kooooo0_l00005ooooo`;o0000Noooool0033ooooo00?o0000ooooooooool0
6Oooool2o`0000Gooooo0_l00027ooooo`;o00001_ooool2o`0008;ooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000kooooo1?l000000ol@413o
ooooooooo`02ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool01?ooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Wo
oooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool0013ooooo00?o0000ooooooooool0
3?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
oooooolfooooo`004?ooool00ol0003oooooooooo`0=ooooo`03ogMgMomVIVKooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[o
oooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_oo
ool000kooooo00?oEEEEofIVI_l000003?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0
0006ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`005_ooool4
o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00Cooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`006?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooolfoooo
o`006?ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0003oooooocKo
oooo000Hooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool001Kooooo00?oEEEE
ofIVI_l000003Oooool4o`0000Kooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`00
0?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000kooooo1?l000000ol@413o
ooooooooo`02ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00Co
oooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00cooooo00?oZJVYoeEEEOooool0
2?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolfooooo`004?ooool00ol0003ooooooooo
o`0=ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?oEEEEolc<c?ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`004?ooool0
0ol0003oooooooooo`0=ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00[ooooo00Go410@oooo
oooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`003_ooool00omEEEGoIVIVo`00000<ooooo`Go00001?ooool4o`0000Kooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolg
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000Uooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooocKooooo000Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooocKooooo000Vooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0
oooooolfooooo`009oooool00onHV9So8B4Qonk^kP06ooooo`?o0000oooooolfooooo`00:?ooool0
0omgMgOoIVIVooooo`3oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Go
oooo00Go0000okZj^_ooooooV9RHoa0@403oooooocoooooo000Uooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`0ooooooloooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Y?ooool0
1OnHV9So0000o`000?m4A4Co^[Zj01Wooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?oo
ool01?l@413o0000odA4A?o<c<`4ooooo`Go0000R_ooool00:Cooooo00Go410@okZj^_o^k^koMgMg
oa0@4009ooooo`Ko00003?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1_ooool00onHV9So410@
omgMg@03ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0R_ooool00:Cooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0=ooooo`03ohN7QomEEEGooooo00?ooooo00?oV9RHob4Q8Oo^k^h0
Roooool00:Cooooo00?o0000ooooooooool02oooool6o`0000cooooo00?o0000ooooooooool02_oo
ool01Oo<c<co8B4Qo`000?mEEEGo000000Gooooo00?oV9RHob4Q8Oo^k^h0R_ooool00:Cooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0:ooooo`05ob4Q8On7QhOooooooiRHV?l00000
1_ooool00omgMgOoIVIVooooo`29ooooo`00X_ooool00ol@413o0000o`000003o`0001cooooo00?o
0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool0
R?ooool00:Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0:ooooo`05ob4Q8OnH
V9SoooooogMgMomEEED00oooool01Ol0003o^[ZjoooooonHV9So410@08[ooooo002Tooooo`03o`00
0?oooooooooo01_ooooo00?oEEEEofIVI_l000003?ooool01Oo<c<co410@o`000?lb<S;ok^k^00?o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c02:ooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.98) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .31303 Mdot
.04762 .32218 Mdot
.07143 .33059 Mdot
.09524 .33769 Mdot
.11905 .34277 Mdot
.14286 .34507 Mdot
.16667 .3438 Mdot
.19048 .33844 Mdot
.21429 .32908 Mdot
.2381 .31669 Mdot
.2619 .30312 Mdot
.28571 .29054 Mdot
.30952 .28078 Mdot
.33333 .27488 Mdot
.35714 .273 Mdot
.38095 .27476 Mdot
.40476 .27944 Mdot
.42857 .28628 Mdot
.45238 .29456 Mdot
.47619 .30365 Mdot
.5 .31303 Mdot
.52381 .32218 Mdot
.54762 .33059 Mdot
.57143 .33769 Mdot
.59524 .34277 Mdot
.61905 .34507 Mdot
.64286 .3438 Mdot
.66667 .33844 Mdot
.69048 .32908 Mdot
.71429 .31669 Mdot
.7381 .30312 Mdot
.7619 .29054 Mdot
.78571 .28078 Mdot
.80952 .27488 Mdot
.83333 .273 Mdot
.85714 .27476 Mdot
.88095 .27944 Mdot
.90476 .28628 Mdot
.92857 .29456 Mdot
.95238 .30365 Mdot
.97619 .31303 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`1Jooooo`;o00001Oooool2o`0000Gooooo0_l00021ooooo`;o00001Oooool2
o`0000Gooooo0_l0000jooooo`00<?ooool00ol0003oooooooooo`1Jooooo`;o00001Oooool2o`00
00Gooooo0_l00021ooooo`;o00001Oooool2o`0000Gooooo0_l0000jooooo`00<?ooool2o`0005Co
oooo0_l0000Kooooo`;o0000LOooool2o`0001_ooooo0_l0000cooooo`00<?ooool00ol0003ooooo
ooooo`1Cooooo`;o00006oooool2o`00077ooooo0_l0000Kooooo`;o0000<oooool0033ooooo00?o
0000ooooooooool0Moooool2o`0008kooooo0_l0000/ooooo`00<?ooool00ol0003oooooooooo`1<
ooooo`;o0000:Oooool2o`0006?ooooo0_l0000Yooooo`;o0000;?ooool0033ooooo0_l0001=oooo
o`;o0000<?ooool2o`0005cooooo0_l0000aooooo`;o00009?ooool0033ooooo00?o0000oooooooo
ool0O_ooool2o`0008oooooo0_l0000Tooooo`009_ooool4o`000003oa0@4?oooooooooo00?ooooo
00?o0000ooooooooool0oooooolfooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo04Cooooo0_l0000oooooo`;o0000C_ooool2o`0003oooooo0_l0000Mooooo`00:?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Cooooo0_l0000oooooo`;o0000C_ooool2
o`0003oooooo0_l0000Mooooo`00:?ooool00ol0003oooooooooo`05ooooo`?o0000oooooolfoooo
o`00:?ooool00ol0003oooooooooo`04ooooo`;o0000Soooool2o`0008kooooo0_l0000Fooooo`00
:?ooool00ol0003oooooooooo`04ooooo`;o0000?oooool2o`0004kooooo0_l0000oooooo`;o0000
COooool2o`0001Kooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0?Ooo
ool2o`0008oooooo0_l0001Uooooo`009_ooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooo
oooo00?ooooo0_l0002?ooooo`;o0000Woooool0033ooooo0_l00004ooooo`;o0000Soooool2o`00
09oooooo000`ooooo`03o`000?oooooooooo00_ooooo0_l0000Yooooo`;o0000Hoooool2o`0002Wo
oooo0_l0001]ooooo`00<?ooool00ol0003oooooooooo`0;ooooo`;o0000:Oooool2o`0006?ooooo
0_l0000Yooooo`;o0000KOooool0033ooooo00?o0000ooooooooool04_ooool2o`0008kooooo0_l0
002Aooooo`00<?ooool2o`0001?ooooo0_l0000Kooooo`;o0000LOooool2o`0001_ooooo0_l0001d
ooooo`00<?ooool00ol0003oooooooooo`0Iooooo`;o00003?ooool2o`0000Kooooo0_l0001hoooo
o`;o00003Oooool2o`0000Gooooo0_l0001dooooo`00<?ooool00ol0003oooooooooo`0Iooooo`;o
00001Oooool2o`0000Gooooo0_l00020ooooo`;o00001_ooool2o`0000Gooooo0_l0001kooooo`00
<?ooool00ol0003oooooooooo`0Pooooo`;o0000Soooool2o`0008;ooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000kooooo1?l000000ol@413o
ooooooooo`02ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool01?ooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Wo
oooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool0013ooooo00?o0000ooooooooool0
3?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
oooooolfooooo`004?ooool00ol0003oooooooooo`0=ooooo`03ogMgMomVIVKooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[o
oooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_oo
ool000kooooo00?oEEEEofIVI_l000003?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0
0006ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`005_ooool4
o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00Cooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`006?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooolfoooo
o`006?ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0003oooooocKo
oooo000Hooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool001Kooooo00?oEEEE
ofIVI_l000003Oooool4o`0000Kooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`00
0?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000kooooo1?l000000ol@413o
ooooooooo`02ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00Co
oooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00cooooo00?oZJVYoeEEEOooool0
2?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolfooooo`004?ooool00ol0003ooooooooo
o`0=ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?oEEEEolc<c?ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`004?ooool0
0ol0003oooooooooo`0=ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00[ooooo00Go410@oooo
oooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`003_ooool00omEEEGoIVIVo`00000<ooooo`Go00001?ooool4o`0000Kooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolg
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000Uooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooocKooooo000Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooocKooooo000Vooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0
oooooolfooooo`009oooool00onHV9So8B4Qonk^kP06ooooo`?o0000oooooolfooooo`00:?ooool0
0omgMgOoIVIVooooo`3oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Go
oooo00Go0000okZj^_ooooooV9RHoa0@403oooooocoooooo000Uooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`0ooooooloooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Y?ooool0
1OnHV9So0000o`000?m4A4Co^[Zj01Wooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?oo
ool01?l@413o0000odA4A?o<c<`4ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0R_ooool00:Cooooo
00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003oooooooooo`04ooooo`;o
8B4Q1_ooool00onHV9So410@omgMg@03ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40R_ooool00:Co
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0=ooooo`03ohN7QomEEEGooooo00;o
oooo00Go0000ooooooooooooooooo`00002:ooooo`00Y?ooool00ol0003oooooooooo`0;ooooo`Ko
00003?ooool00ol0003oooooooooo`0:ooooo`05olc<c?lQ8B7o0000oeEEEOl000000oooool01Olb
<S;oV9RHoooooonHV9So<S8b08[ooooo002Tooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool02_ooool01OlQ8B7oQhN7oooooonHV9So000000?ooooo00Goc<c<o`000?l0003o0000olc<
c02:ooooo`00X_ooool00ol@413o0000o`000003o`0001cooooo00?o0000ooooooooool02_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go410@okZj^_oooooo^[Zjoa0@402:ooooo`00Y?oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00[ooooo00Go8B4QoiRHV?ooooooMgMg
oeEEE@03ooooo`05o`000?nj^[[ooooookZj^_l00000R_ooool00:Cooooo00?o0000ooooooooool0
6oooool00omEEEGoIVIVo`00000<ooooo`05olc<c?l@413o0000oc8b<_o^k^h00oooool01OnYZJWo
410@o`000?l@413oZJVY08[ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.04) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .30768 Mdot
.04762 .31637 Mdot
.07143 .32466 Mdot
.09524 .33202 Mdot
.11905 .33788 Mdot
.14286 .34155 Mdot
.16667 .3423 Mdot
.19048 .3395 Mdot
.21429 .3329 Mdot
.2381 .32293 Mdot
.2619 .31085 Mdot
.28571 .29852 Mdot
.30952 .28785 Mdot
.33333 .28024 Mdot
.35714 .2763 Mdot
.38095 .27598 Mdot
.40476 .27878 Mdot
.42857 .28401 Mdot
.45238 .29098 Mdot
.47619 .29905 Mdot
.5 .30768 Mdot
.52381 .31637 Mdot
.54762 .32466 Mdot
.57143 .33202 Mdot
.59524 .33788 Mdot
.61905 .34155 Mdot
.64286 .3423 Mdot
.66667 .3395 Mdot
.69048 .3329 Mdot
.71429 .32293 Mdot
.7381 .31085 Mdot
.7619 .29852 Mdot
.78571 .28785 Mdot
.80952 .28024 Mdot
.83333 .2763 Mdot
.85714 .27598 Mdot
.88095 .27878 Mdot
.90476 .28401 Mdot
.92857 .29098 Mdot
.95238 .29905 Mdot
.97619 .30768 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo067ooooo0_l00005oooo
o`;o00001_ooool2o`00083ooooo0_l00005ooooo`;o00001Oooool2o`0003?ooooo000`ooooo`;o
0000Foooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0007Wooooo0_l00005ooooo`;o
00001Oooool2o`0000Gooooo0_l0000cooooo`00<?ooool00ol0003oooooooooo`1Jooooo`;o0000
6oooool2o`0007;ooooo0_l0000Jooooo`;o0000;?ooool0033ooooo00?o0000ooooooooool0Dooo
ool2o`0002;ooooo0_l0001Zooooo`;o00008_ooool2o`0002cooooo000`ooooo`03o`000?oooooo
oooo05?ooooo0_l0000Yooooo`;o0000Hoooool2o`0002[ooooo0_l0000Tooooo`00<?ooool2o`00
07oooooo0_l0002?ooooo`;o00009?ooool0033ooooo00?o0000ooooooooool0C?ooool2o`0008ko
oooo0_l0001Gooooo`009_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0
C?ooool2o`0003Oooooo0_l0001Eooooo`;o0000>?ooool2o`0001gooooo000Xooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0QOooool2o`0008oooooo0_l0000Mooooo`00:?ooool0
0ol0003oooooooooo`04ooooo`;o0000Soooool2o`0008kooooo0_l0000Fooooo`00:?ooool00ol0
003oooooooooo`04ooooo`Co0000A?ooool2o`0004Oooooo0_l00016ooooo`;o0000A_ooool2o`00
01Kooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0A?ooool2o`0008oo
oooo0_l0001Nooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo
0_l0002?ooooo`;o0000Woooool002Sooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`03ooooo`;o0000Soooool2o`0009oooooo000Vooooo`03oeEEEOmVIVKo000000Oooooo00?o0000
ooooooooool02oooool2o`00033ooooo0_l0001Looooo`;o0000<Oooool2o`0006Gooooo000`oooo
o`;o00003?ooool2o`00033ooooo0_l0001Looooo`;o0000<Oooool2o`0006Gooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool04_ooool2o`0002;ooooo
0_l0001Zooooo`;o00008_ooool2o`0006gooooo000`ooooo`03o`000?oooooooooo01;ooooo0_l0
0005ooooo`;o00006oooool2o`0006[ooooo0_l00005ooooo`;o00006oooool2o`0006gooooo000`
ooooo`;o00006_ooool2o`0000Gooooo0_l0000=ooooo`;o0000N?ooool2o`0000Kooooo0_l0000<
ooooo`;o0000M?ooool0033ooooo00?o0000ooooooooool08?ooool2o`0000Gooooo0_l00006oooo
o`;o0000P?ooool2o`0000Gooooo0_l00005ooooo`;o0000M?ooool0033ooooo00?o0000oooooooo
ool09oooool2o`0008oooooo0_l0001kooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000ko
oooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000oooooooo
ool01?ooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0;ooooo`03
oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool0013ooooo
00?o0000ooooooooool03?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0=ooooo`03ogMgMomV
IVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo
=_ooool0013ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0:
ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0?oooooo=_ooool000kooooo00?oEEEEofIVI_l000003?ooool01OnHV9So410@o`000?lQ
8B7oc<c<00Cooooo1?l00006ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooo
oolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo
=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`005_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooo
oooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolf
ooooo`006?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Co
oooo0ol0003oooooocKooooo000Hooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_oo
ool001Kooooo00?oEEEEofIVI_l000003Oooool4o`0000Kooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000ko
oooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03
o`000?oooooooooo00Cooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00cooooo
00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolfooooo`004?oo
ool00ol0003oooooooooo`0=ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?oEEEE
olc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooo
oolfooooo`004?ooool00ol0003oooooooooo`0=ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo
00[ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0oooooolfooooo`003_ooool00omEEEGoIVIVo`00000<ooooo`Go00001?ooool4o`00
00Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000Uooooo`Go
00001_ooool00ol0003oooooooooo`3oooooocKooooo000Uooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01_ooool00ol0003oooooooooo`3oooooocKooooo000Vooooo`03oiRHV?lQ8B7ok^k^00Oooooo
00?o0000ooooooooool0oooooolfooooo`009oooool00onHV9So8B4Qonk^kP06ooooo`?o0000oooo
oolfooooo`00:?ooool00omgMgOoIVIVooooo`3oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Gooooo00Go0000okZj^_ooooooV9RHoa0@403oooooocoooooo000Uooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`0ooooooloooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00Y?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo1Ol00005ooooo`;o8B4Q1?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_l000000ol@413oooooooooo`28ooooo`00Y?oo
ool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00009ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo
08Wooooo002Tooooo`03o`000?oooooooooo01_ooooo00?oV9RHob4Q8Oo^k^h03?ooool01Ol@413o
oooooooooooooooo410@00?ooooo1Ol0002:ooooo`00Y?ooool00ol0003oooooooooo`0;ooooo`Ko
00002oooool00onHV9So8B4Qonk^kP0;ooooo`05o`000?ooooooooooooooool000000oooool01?m4
A4CogMgMooooool0002;ooooo`00Y?ooool00ol0003oooooooooo`0Mooooo`03ogMgMomVIVKooooo
00[ooooo00Go0000ooooooooooooooooo`000003ooooo`04omgMgOmEEEGoooooo`0008_ooooo002R
ooooo`03oa0@4?l0003o000000?o00007Oooool00ol0003oooooooooo`09ooooo`05oa0@4?oooooo
ooooooooool@41001?ooool00omgMgOoc<c<o`00002;ooooo`00Y?ooool00ol0003oooooooooo`0J
ooooo`05o`000?nj^[[ooooooiRHV?l@41002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo
00?ok^k^odA4A?l00000Roooool00:Cooooo00?o0000ooooooooool06_ooool01OnHV9So410@o`00
0?lQ8B7oc<c<00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03ogMgMol0003ooooo08[o
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.1) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .30287 Mdot
.04762 .31097 Mdot
.07143 .31897 Mdot
.09524 .32641 Mdot
.11905 .33277 Mdot
.14286 .33746 Mdot
.16667 .33981 Mdot
.19048 .33917 Mdot
.21429 .3351 Mdot
.2381 .32763 Mdot
.2619 .31748 Mdot
.28571 .30607 Mdot
.30952 .29517 Mdot
.33333 .28635 Mdot
.35714 .28063 Mdot
.38095 .27831 Mdot
.40476 .27918 Mdot
.42857 .28269 Mdot
.45238 .28821 Mdot
.47619 .29512 Mdot
.5 .30287 Mdot
.52381 .31097 Mdot
.54762 .31897 Mdot
.57143 .32641 Mdot
.59524 .33277 Mdot
.61905 .33746 Mdot
.64286 .33981 Mdot
.66667 .33917 Mdot
.69048 .3351 Mdot
.71429 .32763 Mdot
.7381 .31748 Mdot
.7619 .30607 Mdot
.78571 .29517 Mdot
.80952 .28635 Mdot
.83333 .28063 Mdot
.85714 .27831 Mdot
.88095 .27918 Mdot
.90476 .28269 Mdot
.92857 .28821 Mdot
.95238 .29512 Mdot
.97619 .30287 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo06Sooooo0_l0002?oooo
o`;o0000>_ooool0033ooooo0_l0001Rooooo`;o00001Oooool2o`0000Kooooo0_l00020ooooo`;o
00001Oooool2o`0000Gooooo0_l0000cooooo`00<?ooool00ol0003oooooooooo`1Qooooo`;o0000
3Oooool2o`0000Gooooo0_l0001iooooo`;o00003?ooool2o`0000Gooooo0_l0000/ooooo`00<?oo
ool00ol0003oooooooooo`1Jooooo`;o00006oooool2o`0000Gooooo0_l0001[ooooo`;o00006_oo
ool2o`0000Kooooo0_l0000Tooooo`00<?ooool00ol0003oooooooooo`1Jooooo`;o00008_ooool2
o`0006_ooooo0_l0000Rooooo`;o00009?ooool0033ooooo0_l0001Dooooo`;o0000<?ooool2o`00
05cooooo0_l0000aooooo`;o00007Oooool0033ooooo00?o0000ooooooooool0Doooool2o`00033o
oooo0_l0001Looooo`;o0000<Oooool2o`0001gooooo000Vooooo`Co000000?o410@ooooooooool0
0oooool00ol0003oooooooooo`3oooooocKooooo000Xooooo`03o`000?oooooooooo00Cooooo0_l0
002?ooooo`;o0000S_ooool2o`0001Kooooo000Xooooo`03o`000?oooooooooo00Cooooo0_l0001>
ooooo`;o0000?oooool2o`0004gooooo0_l0000oooooo`;o00005_ooool002Sooooo00?o0000oooo
ooooool01Oooool3o`0000?ooooo0_l00017ooooo`;o0000A_ooool2o`0004Kooooo0_l0001Goooo
o`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo0_l0002?ooooo`;o
0000Woooool002Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`14ooooo`;o0000
Soooool2o`0005kooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02ooo
ool2o`0003Oooooo0_l0001Eooooo`;o0000>?ooool2o`0005kooooo000Vooooo`03oeEEEOmVIVKo
000000Oooooo00?o0000ooooooooool02oooool2o`0008kooooo0_l0002Hooooo`00<?ooool2o`00
01?ooooo0_l0000Yooooo`;o0000Hoooool2o`0002[ooooo0_l0001Uooooo`00<?ooool00ol0003o
ooooooooo`0Booooo`;o0000:Oooool2o`0006?ooooo0_l0000Zooooo`;o0000IOooool0033ooooo
00?o0000ooooooooool06Oooool2o`0008kooooo0_l0002:ooooo`00<?ooool00ol0003ooooooooo
o`0Iooooo`;o00001Oooool2o`0001Cooooo0_l0001aooooo`;o00001_ooool2o`0001?ooooo0_l0
001]ooooo`00<?ooool2o`00027ooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l0001i
ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o0000KOooool0033ooooo00?o0000oooo
ooooool09oooool2o`0000Kooooo0_l00027ooooo`;o00001Oooool2o`0007Cooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000>ooooo`Co
000000?o410@ooooooooool00_ooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00Co
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool02oooool00onHV9So
8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocKooooo000@ooooo`03o`00
0?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool03Oooool00omgMgOoIVIVoooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKooooo
000@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool02_ooool0
1Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`3oooooocKooooo000>ooooo`03oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c004ooooo`Co00001_ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=ooo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool001Kooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`04
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0
01Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
0?oooooo=_ooool001Sooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`04ooooo`?o
0000oooooolfooooo`006?ooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000F
ooooo`03oeEEEOmVIVKo000000gooooo1?l00006ooooo`03o`000?oooooooooo0?oooooo=_ooool0
033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000>ooooo`Co
000000?o410@ooooooooool00_ooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003o
ooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0<ooooo`03ojVY
ZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool0013ooooo00?o
0000ooooooooool03Oooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0=ooooo`03oeEEEOo<c<co
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0013ooooo00?o0000ooooooooool03Oooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0:oooo
o`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0?oooooo=_ooool000kooooo00?oEEEEofIVI_l000003?ooool5o`0000Cooooo1?l00006oooo
o`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`009Oooool5o`0000Ko
oooo00?o0000ooooooooool0oooooolfooooo`009Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Ko
oooo00?o0000ooooooooool0oooooolfooooo`009_ooool00onHV9So8B4Qonk^kP07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool002Oooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000?oooooo=_oo
ool002Sooooo00?oMgMgofIVI_ooool0oooooolnooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Uooooo`05o`000?nj^[[ooooooiRHV?l@4100ooooooloooooo`009Oooool01OnHV9So
410@o`000?lQ8B7oc<c<0?oooooo?oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00:Sooooo00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`Go00001Oooool2ob4Q8@Gooooo1?l0
00000ol@413oooooooooo`2;ooooo`00Z?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0
0009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Oooooo00?o0000ooooooooool0
SOooool00:Sooooo00?o0000ooooooooool06oooool00onHV9So8B4Qonk^kP0?ooooo`03o`000?oo
oooooooo08gooooo002Xooooo`03o`000?oooooooooo00_ooooo1_l0000;ooooo`03oiRHV?lQ8B7o
k^k^00kooooo00?o0000ooooooooool0SOooool00:Sooooo00?o0000ooooooooool07Oooool00omg
MgOoIVIVooooo`0=ooooo`03o`000?oooooooooo08gooooo002Vooooo`03oa0@4?l0003o000000?o
00007Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo08gooooo002Xooooo`03o`00
0?oooooooooo01[ooooo00Go0000okZj^_ooooooV9RHoa0@400>ooooo`03o`000?oooooooooo08go
oooo002Xooooo`03o`000?oooooooooo01[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`03
oeEEEOmVIVKo000008oooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.16) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .29867 Mdot
.04762 .30605 Mdot
.07143 .31363 Mdot
.09524 .32097 Mdot
.11905 .32761 Mdot
.14286 .33302 Mdot
.16667 .33661 Mdot
.19048 .33774 Mdot
.21429 .33589 Mdot
.2381 .33081 Mdot
.2619 .32281 Mdot
.28571 .31282 Mdot
.30952 .30231 Mdot
.33333 .29287 Mdot
.35714 .28575 Mdot
.38095 .28163 Mdot
.40476 .28059 Mdot
.42857 .28232 Mdot
.45238 .28629 Mdot
.47619 .29192 Mdot
.5 .29867 Mdot
.52381 .30605 Mdot
.54762 .31363 Mdot
.57143 .32097 Mdot
.59524 .32761 Mdot
.61905 .33302 Mdot
.64286 .33661 Mdot
.66667 .33774 Mdot
.69048 .33589 Mdot
.71429 .33081 Mdot
.7381 .32281 Mdot
.7619 .31282 Mdot
.78571 .30231 Mdot
.80952 .29287 Mdot
.83333 .28575 Mdot
.85714 .28163 Mdot
.88095 .28059 Mdot
.90476 .28232 Mdot
.92857 .28629 Mdot
.95238 .29192 Mdot
.97619 .29867 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo0_l0001Yooooo`;o00001_ooool2o`0008Oooooo0_l00005ooooo`;o0000<oooool0033ooooo
00?o0000ooooooooool0J?ooool2o`0000Kooooo0_l00005ooooo`;o0000P?ooool2o`0000Gooooo
0_l00005ooooo`;o0000;?ooool0033ooooo00?o0000ooooooooool0HOooool2o`0001Cooooo0_l0
0005ooooo`;o0000L_ooool2o`0001?ooooo0_l00006ooooo`;o00009?ooool0033ooooo00?o0000
ooooooooool0HOooool2o`0001_ooooo0_l00005ooooo`;o0000Joooool2o`0001_ooooo0_l00005
ooooo`;o00007Oooool0033ooooo0_l0001Kooooo`;o0000:Oooool2o`0006Cooooo0_l0000Yoooo
o`;o00007Oooool002oooooo0_l0001Looooo`;o0000<Oooool2o`0005cooooo0_l0000`ooooo`;o
00005_ooool002Kooooo1?l000000ol@413oooooooooo`02ooooo`;o0000Soooool2o`0008kooooo
0_l0000Fooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05?ooooo0_l0
002>ooooo`;o0000D?ooool002Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03
ooooo`;o0000C_ooool2o`0003oooooo0_l0001=ooooo`;o0000D?ooool002Sooooo00?o0000oooo
ooooool01Oooool3o`0000?ooooo0_l0002?ooooo`;o0000Woooool002Sooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0;ooooo`;o0000?oooool2o`0004gooooo0_l0000oooooo`;o
0000Eoooool002Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`;o0000
?oooool2o`0004gooooo0_l0000oooooo`;o0000Eoooool002Sooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Booooo`;o0000S_ooool2o`00097ooooo000Vooooo`03oeEEEOmVIVKo
000000Oooooo00?o0000ooooooooool04_ooool2o`00033ooooo0_l0001Looooo`;o0000<Oooool2
o`0005kooooo000`ooooo`;o00006_ooool2o`0002Wooooo0_l0001Sooooo`;o0000:_ooool2o`00
05kooooo000`ooooo`03o`000?oooooooooo01Wooooo0_l0000Rooooo`;o0000J_ooool2o`0002?o
oooo0_l0001Uooooo`00<?ooool00ol0003oooooooooo`0Pooooo`;o00006oooool2o`0007;ooooo
0_l0000Kooooo`;o0000IOooool0033ooooo00?o0000ooooooooool08?ooool2o`0000Gooooo0_l0
0006ooooo`;o00001Oooool2o`0007Wooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l0
001]ooooo`00<?ooool2o`0002Sooooo0_l00006ooooo`;o00001Oooool2o`00083ooooo0_l00005
ooooo`;o00001Oooool2o`0006gooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000ko
oooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000oooooooo
ool01?ooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0;ooooo`03
oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool0013ooooo
00?o0000ooooooooool03?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0=ooooo`03ogMgMomV
IVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo
=_ooool0013ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0:
ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0?oooooo=_ooool000kooooo00?oEEEEofIVI_l000003?ooool01OnHV9So410@o`000?lQ
8B7oc<c<00Cooooo1?l00006ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooo
oolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo
=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`005_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooo
oooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolf
ooooo`006?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Co
oooo0ol0003oooooocKooooo000Hooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_oo
ool001Kooooo00?oEEEEofIVI_l000003Oooool4o`0000Kooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000ko
oooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03
o`000?oooooooooo00Cooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00cooooo
00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolfooooo`004?oo
ool00ol0003oooooooooo`0=ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?oEEEE
olc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooo
oolfooooo`004?ooool00ol0003oooooooooo`0=ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo
00[ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0oooooolfooooo`003_ooool00omEEEGoIVIVo`00000<ooooo`Go00001?ooool4o`00
00Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000Uooooo`Go
00001_ooool00ol0003oooooooooo`3oooooocKooooo000Uooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01_ooool00ol0003oooooooooo`3oooooocKooooo000Vooooo`03oiRHV?lQ8B7ok^k^00Oooooo
00?o0000ooooooooool0oooooolfooooo`009oooool00onHV9So8B4Qonk^kP06ooooo`?o0000oooo
oolfooooo`00:?ooool00omgMgOoIVIVooooo`3oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Gooooo00Go0000okZj^_ooooooV9RHoa0@403oooooocoooooo000Uooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`0ooooooloooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00Y?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo1Ol00005ooooo`;o8B4Q1Ooo
ool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oa0@4?o<c<b:ooooo`00Y?ooool01Ol@413o
^[Zjonk^k_mgMgOo410@00Wooooo1_l00009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2
ob4Q8@Oooooo00?o0000ooooooooool00_ooool01OmEEEGoMgMgoooooonHV9So8B4Q08[ooooo002T
ooooo`03o`000?oooooooooo01_ooooo00?oV9RHob4Q8Oo^k^h03oooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool00000R_ooool00:Cooooo00?o0000ooooooooool02oooool6
o`0000_ooooo00?oV9RHob4Q8Oo^k^h03_ooool00ol0003oooooooooo`02ooooo`05o`000?nHV9So
oooooiRHV?lQ8B40R_ooool00:Cooooo00?o0000ooooooooool07Oooool00omgMgOoIVIVooooo`0=
ooooo`03o`000?oooooooooo00;ooooo00Go0000oeEEEOl0003o410@olc<c02:ooooo`00X_ooool0
0ol@413o0000o`000003o`0001gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02
ooooo`03oeEEEOn7QhOooooo08cooooo002Tooooo`03o`000?oooooooooo01[ooooo00Go0000okZj
^_ooooooV9RHoa0@400>ooooo`03o`000?oooooooooo00;ooooo00?ogMgMoa0@4?nHV9P0S?ooool0
0:Cooooo00?o0000ooooooooool06_ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?oEEEE
ofIVI_l000001Oooool01?o<c<coA4A4o`000?l@412:ooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.22) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .29513 Mdot
.04762 .30169 Mdot
.07143 .30872 Mdot
.09524 .31582 Mdot
.11905 .32255 Mdot
.14286 .32844 Mdot
.16667 .33295 Mdot
.19048 .3355 Mdot
.21429 .33552 Mdot
.2381 .33261 Mdot
.2619 .32677 Mdot
.28571 .31851 Mdot
.30952 .30893 Mdot
.33333 .29944 Mdot
.35714 .2914 Mdot
.38095 .28577 Mdot
.40476 .28295 Mdot
.42857 .2829 Mdot
.45238 .28524 Mdot
.47619 .28949 Mdot
.5 .29513 Mdot
.52381 .30169 Mdot
.54762 .30872 Mdot
.57143 .31582 Mdot
.59524 .32255 Mdot
.61905 .32844 Mdot
.64286 .33295 Mdot
.66667 .3355 Mdot
.69048 .33552 Mdot
.71429 .33261 Mdot
.7381 .32677 Mdot
.7619 .31851 Mdot
.78571 .30893 Mdot
.80952 .29944 Mdot
.83333 .2914 Mdot
.85714 .28577 Mdot
.88095 .28295 Mdot
.90476 .2829 Mdot
.92857 .28524 Mdot
.95238 .28949 Mdot
.97619 .29513 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo073ooooo0_l00005ooooo`;o0000
1Oooool2o`00083ooooo0_l00005ooooo`;o00001_ooool2o`0002Cooooo000`ooooo`03o`000?oo
oooooooo06Sooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l0001iooooo`;o00001Ooo
ool2o`0000Gooooo0_l00006ooooo`;o00009?ooool0033ooooo00?o0000ooooooooool0HOooool2
o`0000Gooooo0_l0000Kooooo`;o0000Joooool2o`0000Gooooo0_l0000Kooooo`;o00007Oooool0
02oooooo0ol0001Rooooo`;o00008_ooool2o`0000Kooooo0_l0001Sooooo`;o00008_ooool2o`00
00Gooooo0_l0000Fooooo`00;oooool2o`0008oooooo0_l0002>ooooo`;o00005_ooool002Kooooo
1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l0001Eooooo`;o0000
>?ooool2o`0005Gooooo0_l00018ooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00?ooooo0_l0001Eooooo`;o0000>?ooool2o`0005Gooooo0_l00018ooooo`00:?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo=_ooool002Sooooo00?o0000oooo
ooooool01Oooool3o`0000_ooooo0_l00016ooooo`;o0000A_ooool2o`0004Kooooo0_l0001@oooo
o`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo0_l00016ooooo`;o
0000A_ooool2o`0004Kooooo0_l0001@ooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01;ooooo0_l0002>ooooo`;o0000TOooool002Sooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Booooo`;o0000>?ooool2o`0005Cooooo0_l0000hooooo`;o0000Eooo
ool002Kooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`0Iooooo`;o0000<Oooool2
o`0005_ooooo0_l0000aooooo`;o0000Eoooool0033ooooo0_l0000Jooooo`;o0000:Oooool2o`00
06?ooooo0_l0000Zooooo`;o0000G_ooool0033ooooo00?o0000ooooooooool08?ooool2o`0002;o
oooo0_l0001[ooooo`;o00008_ooool2o`0005kooooo000`ooooo`03o`000?oooooooooo023ooooo
0_l00005ooooo`;o00005?ooool2o`0007;ooooo0_l00005ooooo`;o00005?ooool2o`0006Gooooo
000`ooooo`03o`000?oooooooooo02Oooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l0
001iooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o0000IOooool0033ooooo0_l0000`
ooooo`;o00001Oooool2o`0008Oooooo0_l00005ooooo`;o0000KOooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`003_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`Go
00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfoooo
o`004?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A4
00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03
o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o
0000oooooolfooooo`004?ooool00ol0003oooooooooo`0<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oo
oooooooo00gooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000@
ooooo`03o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0oooooolfooooo`003_ooool00omEEEGoIVIVo`00000<
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000Fooooo`Co000000?o410@ooooooooool00_ooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_oo
ool001Sooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00ko
oooo00?oMgMgoc8b<_ooool01?ooool3o`000?oooooo=_ooool001Sooooo00?o0000ooooooooool0
2oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`00
6?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
oooooolfooooo`006?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0oooooolfooooo`005_ooool00omEEEGoIVIVo`00000=ooooo`Co00001_ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`003_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B46ooooo`03
o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
0?oooooo=_ooool0013ooooo00?o0000ooooooooool01?ooool2ob4Q8@Kooooo00?oEEEEojVYZOoo
ool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo
00?o0000ooooooooool03?ooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo
0ol0003oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?o8B4Qooooooooool01_oo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000
ooooooooool03Oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool0
013ooooo00?o0000ooooooooool02_ooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000>ooooo`03oeEEEOmVIVKo0000
00cooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo=oooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`00
0?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool002Gooooo1Ol00006ooooo`03o`000?oooooooooo0?oooooo=_ooool002Gooooo
00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0?oooooo=_ooool002Kooooo
00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`3oooooocKooooo000Wooooo`03oiRHV?lQ
8B7ok^k^00Kooooo0ol0003oooooocKooooo000Xooooo`03ogMgMomVIVKooooo0?oooooo?_ooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`009Oooool01Ol0003o^[ZjoooooonHV9So410@
0?oooooo?oooool002Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c03oooooocoooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo002Tooooo`05oiRHV?l0003o0000odA4A?nj^[X06?oo
ool5o`0000Gooooo0_lQ8B44ooooo`Go00000oooool5o`0008[ooooo002Tooooo`05oa0@4?nj^[[o
k^k^ogMgMol@41002Oooool6o`0000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q
1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A02:oooo
o`00Y?ooool00ol0003oooooooooo`0Kooooo`03oiRHV?lQ8B7ok^k^00gooooo00?oV9RHob4Q8Oo^
k^h01Oooool00onHV9So8B4Qonk^kP2;ooooo`00Y?ooool00ol0003oooooooooo`0;ooooo`Ko0000
2oooool00onHV9So8B4Qonk^kP0=ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?oV9RHob4Q8Oo^k^h0
R_ooool00:Cooooo00?o0000ooooooooool07Oooool00omgMgOoIVIVooooo`0=ooooo`03ogMgMomV
IVKooooo00Gooooo00?oMgMgofIVI_ooool0ROooool00:;ooooo00?o410@o`000?l000000ol0000M
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`28
ooooo`00Y?ooool00ol0003oooooooooo`0Jooooo`05o`000?nj^[[ooooooiRHV?l@41002oooool0
1Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go0000okZj^_ooooooV9RHoa0@402:ooooo`00Y?oo
ool00ol0003oooooooooo`0Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`02oooool01OnHV9So410@
o`000?lQ8B7oc<c<00?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c02:ooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.28) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .29232 Mdot
.04762 .29794 Mdot
.07143 .30432 Mdot
.09524 .31104 Mdot
.11905 .3177 Mdot
.14286 .32385 Mdot
.16667 .32902 Mdot
.19048 .33266 Mdot
.21429 .33422 Mdot
.2381 .33321 Mdot
.2619 .32941 Mdot
.28571 .32301 Mdot
.30952 .31473 Mdot
.33333 .3057 Mdot
.35714 .29725 Mdot
.38095 .29049 Mdot
.40476 .28613 Mdot
.42857 .28438 Mdot
.45238 .28508 Mdot
.47619 .28788 Mdot
.5 .29232 Mdot
.52381 .29794 Mdot
.54762 .30432 Mdot
.57143 .31104 Mdot
.59524 .3177 Mdot
.61905 .32385 Mdot
.64286 .32902 Mdot
.66667 .33266 Mdot
.69048 .33422 Mdot
.71429 .33321 Mdot
.7381 .32941 Mdot
.7619 .32301 Mdot
.78571 .31473 Mdot
.80952 .3057 Mdot
.83333 .29725 Mdot
.85714 .29049 Mdot
.88095 .28613 Mdot
.90476 .28438 Mdot
.92857 .28508 Mdot
.95238 .28788 Mdot
.97619 .29232 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo07Oooooo0_l00005ooooo`;o0000
Qoooool2o`0000Kooooo0_l0000Tooooo`00<?ooool00ol0003oooooooooo`1`ooooo`;o00001Ooo
ool2o`0000Gooooo0_l00005ooooo`;o0000NOooool2o`0000Gooooo0_l00006ooooo`;o00001Ooo
ool2o`0001gooooo000`ooooo`03o`000?oooooooooo06Sooooo0_l00006ooooo`;o00004oooool2
o`0007;ooooo0_l00005ooooo`;o00005?ooool2o`0001gooooo000_ooooo`?o0000JOooool2o`00
02?ooooo0_l0001Zooooo`;o00008_ooool2o`0001Kooooo000_ooooo`;o00001Oooool2o`0005co
oooo0_l0000Zooooo`;o00001Oooool2o`0005cooooo0_l0000Yooooo`;o00005_ooool002Kooooo
1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l0001Looooo`;o0000
<Oooool2o`0005cooooo0_l00011ooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00_ooooo0_l0002>ooooo`;o0000V?ooool002Sooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0;ooooo`;o0000COooool2o`0003oooooo0_l0001>ooooo`;o0000B?ooool0
02Sooooo00?o0000ooooooooool01Oooool3o`0001;ooooo0_l00016ooooo`;o0000A_ooool2o`00
04Oooooo0_l00018ooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01;o
oooo0_l0000oooooo`;o0000COooool2o`0003oooooo0_l0001@ooooo`00:?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo01Wooooo0_l0000hooooo`;o0000E?ooool2o`0003Sooooo
0_l0001@ooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Wooooo0_l0
002>ooooo`;o0000R_ooool002Kooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`0P
ooooo`;o0000:_ooool2o`0006?ooooo0_l0000Yooooo`;o0000Eoooool0033ooooo0_l0000Qoooo
o`;o0000:_ooool2o`0006?ooooo0_l0000Yooooo`;o0000Eoooool0033ooooo00?o0000oooooooo
ool09oooool2o`0001_ooooo0_l0001booooo`;o00006oooool2o`0005kooooo000`ooooo`03o`00
0?oooooooooo02Oooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o0000
L_ooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l0001Nooooo`00<?oo
ool00ol0003oooooooooo`0_ooooo`;o00001Oooool2o`0000Gooooo0_l00020ooooo`;o00001Ooo
ool2o`0000Kooooo0_l0001Uooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`003_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`Go
00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfoooo
o`004?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A4
00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03
o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o
0000oooooolfooooo`004?ooool00ol0003oooooooooo`0<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oo
oooooooo00gooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000@
ooooo`03o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0oooooolfooooo`003_ooool00omEEEGoIVIVo`00000<
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo
=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0
033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKo
oooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000Fooooo`Co000000?o410@ooooooooool00_ooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_oo
ool001Sooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00ko
oooo00?oMgMgoc8b<_ooool01?ooool3o`000?oooooo=_ooool001Sooooo00?o0000ooooooooool0
2oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`00
6?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
oooooolfooooo`006?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0oooooolfooooo`005_ooool00omEEEGoIVIVo`00000=ooooo`Co00001_ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`003_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B46ooooo`03
o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
0?oooooo=_ooool0013ooooo00?o0000ooooooooool01?ooool2ob4Q8@Kooooo00?oEEEEojVYZOoo
ool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo
00?o0000ooooooooool03?ooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo
0ol0003oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?o8B4Qooooooooool01_oo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000
ooooooooool03Oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00gooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool0
013ooooo00?o0000ooooooooool02_ooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000>ooooo`03oeEEEOmVIVKo0000
00cooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo=oooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`00
0?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003o
ooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oo
oooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool002Gooooo1Ol00006ooooo`03o`000?oooooooooo0?oooooo=_ooool002Gooooo
00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0?oooooo=_ooool002Kooooo
00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`3oooooocKooooo000Wooooo`03oiRHV?lQ
8B7ok^k^00Kooooo0ol0003oooooocKooooo000Xooooo`03ogMgMomVIVKooooo0?oooooo?_ooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`009Oooool01Ol0003o^[ZjoooooonHV9So410@
0?oooooo?oooool002Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c03oooooocoooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo002Tooooo`05oiRHV?l0003o0000odA4A?nj^[X06?oo
ool5o`0000Gooooo0_lQ8B44ooooo`Go00000oooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<08[ooooo
002Tooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A005ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Go8B4QoiRH
V?ooooooV9RHob4Q8@2:ooooo`00Y?ooool00ol0003oooooooooo`0Kooooo`03oiRHV?lQ8B7ok^k^
00gooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol0003ooooooooooooooooo000008[ooooo002Toooo
o`03o`000?oooooooooo00_ooooo1_l0000;ooooo`03oiRHV?lQ8B7ok^k^00gooooo00?oV9RHob4Q
8Oo^k^h00oooool01Olb<S;oV9RHoooooonHV9So<S8b08[ooooo002Tooooo`03o`000?oooooooooo
01gooooo00?oMgMgofIVI_ooool03Oooool00omgMgOoIVIVooooo`02ooooo`05olc<c?l0003o0000
o`000?o<c<`0R_ooool00:;ooooo00?o410@o`000?l000000ol0000Mooooo`03o`000?oooooooooo
00gooooo00Wo0000oooooooooooooooooa0@4?nj^[[ooooookZj^_l@4100R_ooool00:Cooooo00?o
0000ooooooooool06_ooool01Ol0003o^[ZjoooooonHV9So410@00_ooooo00Go0000okZj^_oooooo
V9RHoa0@4003ooooo`05o`000?nj^[[ooooookZj^_l00000R_ooool00:Cooooo00?o0000oooooooo
ool06_ooool01OnHV9So410@o`000?lQ8B7oc<c<00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003
ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0R_ooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.34) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .29026 Mdot
.04762 .29486 Mdot
.07143 .30047 Mdot
.09524 .3067 Mdot
.11905 .31314 Mdot
.14286 .31939 Mdot
.16667 .32499 Mdot
.19048 .32944 Mdot
.21429 .33221 Mdot
.2381 .3328 Mdot
.2619 .33085 Mdot
.28571 .3263 Mdot
.30952 .31952 Mdot
.33333 .31138 Mdot
.35714 .303 Mdot
.38095 .29555 Mdot
.40476 .28995 Mdot
.42857 .28666 Mdot
.45238 .28578 Mdot
.47619 .2871 Mdot
.5 .29026 Mdot
.52381 .29486 Mdot
.54762 .30047 Mdot
.57143 .3067 Mdot
.59524 .31314 Mdot
.61905 .31939 Mdot
.64286 .32499 Mdot
.66667 .32944 Mdot
.69048 .33221 Mdot
.71429 .3328 Mdot
.7381 .33085 Mdot
.7619 .3263 Mdot
.78571 .31952 Mdot
.80952 .31138 Mdot
.83333 .303 Mdot
.85714 .29555 Mdot
.88095 .28995 Mdot
.90476 .28666 Mdot
.92857 .28578 Mdot
.95238 .2871 Mdot
.97619 .29026 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0Moooool2o`0000Gooooo0_l00005ooooo`;o0000P?ooool2o`0000Kooooo0_l0
0005ooooo`;o00007Oooool002oooooo0_l0001booooo`;o00001Oooool2o`0000Gooooo0_l00005
ooooo`;o00001_ooool2o`00077ooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l00005
ooooo`;o00005_ooool002oooooo0ol00004ooooo`;o0000Joooool2o`0001_ooooo0_l00005oooo
o`;o0000J_ooool2o`0001_ooooo0_l0000Fooooo`00<?ooool00ol0003oooooooooo`03ooooo`;o
0000Hoooool2o`0002[ooooo0_l0001Sooooo`;o0000>_ooool002Kooooo1?l000000ol@413ooooo
ooooo`03ooooo`03o`000?oooooooooo00_ooooo0_l0001Kooooo`;o0000<Oooool2o`0005cooooo
0_l0000jooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo0_l0
001Dooooo`;o0000>?ooool2o`0005Gooooo0_l00011ooooo`00:?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01;ooooo0_l0001=ooooo`;o0000?oooool2o`0004kooooo0_l00011
ooooo`00:?ooool00ol0003oooooooooo`05ooooo`?o00004_ooool2o`0004Kooooo0_l00016oooo
o`;o0000Aoooool2o`0004Sooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool06Oooool2o`0003oooooo0_l0001=ooooo`;o0000@?ooool2o`0004Sooooo000Xooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool06Oooool2o`0008kooooo0_l0002:ooooo`00:?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo023ooooo0_l0000aooooo`;o0000G?oo
ool2o`00033ooooo0_l0001@ooooo`009_ooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooo
oooo023ooooo0_l00005ooooo`;o0000:_ooool2o`0005cooooo0_l00005ooooo`;o0000:Oooool2
o`00053ooooo000`ooooo`;o0000:?ooool2o`0002?ooooo0_l0001Zooooo`;o00008_ooool2o`00
05Oooooo000`ooooo`03o`000?oooooooooo02oooooo0_l0000Cooooo`;o00001_ooool2o`00077o
oooo0_l0000Dooooo`;o00001Oooool2o`0005Oooooo000`ooooo`03o`000?oooooooooo02oooooo
0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l0001iooooo`;o00001Oooool2o`0000Kooooo
0_l00005ooooo`;o0000G_ooool0033ooooo00?o0000ooooooooool0=_ooool2o`0000Gooooo0_l0
0027ooooo`;o00001_ooool2o`0006Gooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000>ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Co
oooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
ocKooooo000@ooooo`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0013o
oooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?o
oooo0ol0003oooooocKooooo000@ooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o
0000ooooooooool03Oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0013ooooo00?o0000ooooooooool02_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`3oooooocKooooo000>ooooo`03oeEEEOmVIVKo
000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`000?oooooo=ooo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Kooooo1?l000000ol@413oooooooooo`02
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooo
oolfooooo`006?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo=_ooool001Sooooo00?o0000oooooooo
ool03_ooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`006?ooool00ol0003ooooo
ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocKo
oooo000Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3oooooocKooooo000Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooocKooooo000Fooooo`03oeEEEOmVIVKo000000gooooo1?l00006
ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000>ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Ko
oooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGo
ZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`00
4?ooool00ol0003oooooooooo`0<ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool0
0oooool3o`000?oooooo=_ooool0013ooooo00?o0000ooooooooool03Oooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`004?ooool0
0ol0003oooooooooo`0=ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool03Oooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`004?ooool00ol0003oooooooooo`0:ooooo`05oa0@4?oooooooooooooooolb<S801?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool000kooooo00?oEEEEofIV
I_l000003?ooool5o`0000Cooooo1?l00006ooooo`;o0000oooooolgooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2
o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003o
ooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000oooo
ooooool0oooooolfooooo`009Oooool5o`0000Kooooo00?o0000ooooooooool0oooooolfooooo`00
9Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooolfooooo`00
9_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0?oooooo=_ooool002Oooooo00?o
V9RHob4Q8Oo^k^h01_ooool3o`000?oooooo=_ooool002Sooooo00?oMgMgofIVI_ooool0ooooooln
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Uooooo`05o`000?nj^[[ooooooiRH
V?l@4100ooooooloooooo`009Oooool01OnHV9So410@o`000?lQ8B7oc<c<0?oooooo?oooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00:Cooooo00GoV9RHo`000?l0003oA4A4okZj
^P0Hooooo`Go00001Oooool2ob4Q8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c005ooooo`;o0000
00?o410@ooooooooool0R?ooool00:Cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko0000
2Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMg
Molb<S801_ooool00ol0003oooooooooo`29ooooo`00Y?ooool00ol0003oooooooooo`0Kooooo`03
oiRHV?lQ8B7ok^k^013ooooo00Co0000oooooooooooooooo1Ol0002:ooooo`00Y?ooool00ol0003o
ooooooooo`0;ooooo`Ko00002oooool00onHV9So8B4Qonk^kP0>ooooo`03ojVYZOl@413ooooo00;o
oooo00CoA4A4omgMgOoooooo0000Roooool00:Cooooo00?o0000ooooooooool07Oooool00omgMgOo
IVIVooooo`0<ooooo`03oa0@4?l0003o^[Zj00?ooooo00CogMgMoeEEEOoooooo0000Roooool00:;o
oooo00?o410@o`000?l000000ol0000Mooooo`03o`000?oooooooooo00cooooo00?o^[Zjob4Q8Ooo
ool00oooool00omgMgOoc<c<o`00002;ooooo`00Y?ooool00ol0003oooooooooo`0Jooooo`05o`00
0?nj^[[ooooooiRHV?l@41002oooool01Ol@413oV9RHoooooonj^[[o000000Cooooo00?ok^k^odA4
A?l00000Roooool00:Cooooo00?o0000ooooooooool06_ooool01OnHV9So410@o`000?lQ8B7oc<c<
00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@05ooooo`03ogMgMol0003ooooo08[ooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.309017 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.25)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.75)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(1.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.4) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .28899 Mdot
.04762 .29248 Mdot
.07143 .29724 Mdot
.09524 .30286 Mdot
.11905 .30897 Mdot
.14286 .31515 Mdot
.16667 .32098 Mdot
.19048 .326 Mdot
.21429 .3297 Mdot
.2381 .33159 Mdot
.2619 .33123 Mdot
.28571 .32841 Mdot
.30952 .32323 Mdot
.33333 .31625 Mdot
.35714 .30837 Mdot
.38095 .30068 Mdot
.40476 .2942 Mdot
.42857 .28962 Mdot
.45238 .28727 Mdot
.47619 .28713 Mdot
.5 .28899 Mdot
.52381 .29248 Mdot
.54762 .29724 Mdot
.57143 .30286 Mdot
.59524 .30897 Mdot
.61905 .31515 Mdot
.64286 .32098 Mdot
.66667 .326 Mdot
.69048 .3297 Mdot
.71429 .33159 Mdot
.7381 .33123 Mdot
.7619 .32841 Mdot
.78571 .32323 Mdot
.80952 .31625 Mdot
.83333 .30837 Mdot
.85714 .30068 Mdot
.88095 .2942 Mdot
.90476 .28962 Mdot
.92857 .28727 Mdot
.95238 .28713 Mdot
.97619 .28899 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00M_ooool4o`000003oa0@4?oooooooooo043ooooo1Ol00014ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0AOooool2o`000003oa0@4?oooooooooo01?ooooo001hooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A014ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80A_ooool00ol0003oooooooooo`0Dooooo`00N?ooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Wooooo00?o0000ooooooooool0@Oooool5o`0001Gooooo001hooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0Aoooool00onYZJWo410@ooooo`12ooooo`04
odA4A?oMgMgoooooo`0001Kooooo001hooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0AOooool00ol@413o0000okZj^P13ooooo`04omgMgOmEEEGoooooo`0001Kooooo001hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0AOooool00onj^[[o8B4Qooooo`13ooooo`03
ogMgMoo<c<co000001Kooooo001hooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4014ooooo`05oa0@4?nHV9SooooookZj^_l00000A?ooool00oo^k^koA4A4o`00000Foooo
o`00M_ooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A?ooool01OnY
ZJWo410@o`000?l@413oZJVY04Gooooo00?oMgMgo`000?ooool05Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool002Woooooool0000ao`00
00oooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Dooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Cooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool000go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolfooooo`003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0
oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooo
oooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oo
oooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooooooo
o`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`005Oooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo=_ooool001Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolfooooo`005Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool001Gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolf
ooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocKooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000=ooooo`05oa0@4?oooooo
ooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0
003oooooocKooooo000=ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`003Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`003Oooool01Ol@413ooooooooo
oooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo=_ooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Ko
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`00
0?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool0
0ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o
0000ooooooooool0O_ooool2o`0000Gooooo0_l00028ooooo`;o00001Oooool2o`0001gooooo000_
ooooo`;o0000NOooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0007Sooooo0_l00006
ooooo`;o00001Oooool2o`0000Gooooo0_l0000Fooooo`00;oooool3o`0000Cooooo0_l0001[oooo
o`;o00001Oooool2o`0001Cooooo0_l00005ooooo`;o0000J_ooool2o`0000Gooooo0_l0000Doooo
o`;o00005_ooool0033ooooo00?o0000ooooooooool00oooool2o`0000Kooooo0_l0001Sooooo`;o
00008_ooool2o`0000Gooooo0_l0001Sooooo`;o0000<oooool002Kooooo1?l000000ol@413ooooo
ooooo`03ooooo`03o`000?oooooooooo00_ooooo0_l0001Kooooo`;o0000<Oooool2o`0005cooooo
0_l0000jooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01;ooooo0_l0
001Dooooo`;o0000>?ooool2o`0005Gooooo0_l0000jooooo`00:?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01;ooooo0_l0001=ooooo`;o0000?oooool2o`0004kooooo0_l00011
ooooo`00:?ooool00ol0003oooooooooo`05ooooo`?o00006Oooool2o`0004Kooooo0_l00016oooo
o`;o0000Aoooool2o`00047ooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool06Oooool2o`0000Gooooo0_l00027ooooo`;o00001_ooool2o`0008;ooooo000Xooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool08?ooool2o`0003Sooooo0_l0001Eooooo`;o0000
>?ooool2o`0004Sooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09ooo
ool2o`00037ooooo0_l0001Looooo`;o0000<Oooool2o`0004Sooooo000Vooooo`03oeEEEOmVIVKo
000000Oooooo00?o0000ooooooooool09oooool2o`0002[ooooo0_l0001Sooooo`;o0000:Oooool2
o`00053ooooo000`ooooo`;o0000<?ooool2o`0002;ooooo0_l0001Zooooo`;o00008_ooool2o`00
053ooooo000`ooooo`03o`000?oooooooooo02oooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o0000LOooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l0001Gooooo`00<?ooool00ol0003oooooooooo`0fooooo`;o00001Oooool2o`0000Gooooo
0_l00006ooooo`;o0000N?ooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0005Oooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool000kooooo1?l000000ol@413oooooooooo`02ooooo`;o
8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
0?oooooo=_ooool0013ooooo00?o0000ooooooooool01?ooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfoooo
o`004?ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000oooooooo
ool00oooool3o`000?oooooo=_ooool0013ooooo00?o0000ooooooooool03?ooool00onHV9So8B4Q
onk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolfooooo`004?oo
ool00ol0003oooooooooo`0=ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`03o`000?oooooooooo0?oooooo=_ooool0013ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooo
oolfooooo`004?ooool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@41001?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo=_ooool000kooooo00?oEEEE
ofIVI_l000003?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000oooo
oolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003ooooo
ooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3o
ooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000oooooooo
ool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033ooooo00?o0000ooooooooool0oooo
oolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo
0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo
=oooool0033ooooo00?o0000ooooooooool0oooooolfooooo`005_ooool4o`000003oa0@4?oooooo
oooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooooooo
o`3oooooocKooooo000Hooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0oooooolfooooo`006?ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooolfooooo`006?ooool00ol0003o
ooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0003oooooocKooooo000Hooooo`03o`00
0?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oo
oooo=_ooool001Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo=_ooool001Sooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0?oooooo=_ooool001Kooooo00?oEEEEofIVI_l000003Oooool4
o`0000Kooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool2o`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00
<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033o
oooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo0_l0003oooooocOooooo000`oooo
o`03o`000?oooooooooo0?oooooo=_ooool000kooooo1?l000000ol@413oooooooooo`02ooooo`;o
8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`3oooooocKooooo000@ooooo`03o`000?oooooooooo00Cooooo0_lQ8B46ooooo`03
oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKo
oooo000@ooooo`03o`000?oooooooooo00cooooo00?oZJVYoeEEEOooool02?ooool00ol0003ooooo
ooooo`03ooooo`?o0000oooooolfooooo`004?ooool00ol0003oooooooooo`0=ooooo`03ob4Q8Ooo
oooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocKooooo000@
ooooo`03o`000?oooooooooo00gooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolfooooo`004?ooool00ol0003oooooooooo`0=
ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3o
ooooocKooooo000@ooooo`03o`000?oooooooooo00[ooooo00Go410@oooooooooooooooooc8b<P04
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolfooooo`003_ooool00omE
EEGoIVIVo`00000<ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooocOooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0
033ooooo0_l0003oooooocOooooo000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo
00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`
ooooo`;o0000oooooolgooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo000`ooooo`03
o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?oo
ool00ol0003oooooooooo`3oooooocKooooo000`ooooo`;o0000oooooolgooooo`00<?ooool00ol0
003oooooooooo`3oooooocKooooo000Uooooo`Go00001_ooool00ol0003oooooooooo`3oooooocKo
oooo000Uooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`3oooooocKo
oooo000Vooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0oooooolfooooo`009ooo
ool00onHV9So8B4Qonk^kP06ooooo`?o0000oooooolfooooo`00:?ooool00omgMgOoIVIVooooo`3o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Gooooo00Go0000okZj^_oo
ooooV9RHoa0@403oooooocoooooo000Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0oooooolooooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Z?ooool01OnHV9So0000o`000?m4
A4Co^[Zj01Sooooo1Ol00005ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo08cooooo002X
ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A005ooooo`;o8B4Q1oooool00ol0003oooooooooo`2=ooooo`00Z?ooool00ol0003ooooooooo
o`0Kooooo`03oiRHV?lQ8B7ok^k^00cooooo1Ol0002>ooooo`00Z?ooool00ol0003oooooooooo`0;
ooooo`Ko00002oooool00onHV9So8B4Qonk^kP0;ooooo`04odA4A?oMgMgoooooo`0008oooooo002X
ooooo`03o`000?oooooooooo01gooooo00?oMgMgofIVI_ooool02_ooool01?oMgMgoEEEEooooool0
002?ooooo`00Y_ooool00ol@413o0000o`000003o`0001gooooo00?o0000ooooooooool02_ooool0
0omgMgOoc<c<o`00002?ooooo`00Z?ooool00ol0003oooooooooo`0Jooooo`05o`000?nj^[[ooooo
oiRHV?l@41003?ooool00oo^k^koA4A4o`00002?ooooo`00Z?ooool00ol0003oooooooooo`0Joooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`03Oooool00omgMgOo0000ooooo`2>ooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.668352, -0.160437, \
0.0173014, 0.0133306}}]
}, Closed]]
}, Open  ]],

Cell["\<\
\tThe wave steepens, but also decays due to the finite diffusivity. \
 In order to see a shock wave form, it is necessary to drive the system with \
a source. The is done by reevaluating the previous cells, but now we take the \
following source:\
\>", "Text"],

Cell[BoxData[{
    \(\(S[j_, n_]\  := \ 0 /; \ j > 2;\)\), "\n", 
    \(\(S[0, n_]\  = \(S[1, n_]\  = \ \(S[2, n_]\  = \ 10\)\);\)\)}], "Input",\

  ShowCellTags->True,
  CellTags->"Cell 7.64"],

Cell["along with a zero initial condition.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(f[j_, 0]\  := \ 0\ ;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(Table[
        ListPlot[Table[{j\ \[CapitalDelta]x, f[j, n]}, {j, 0, M}], 
          PlotRange \[Rule] {0, 5}, 
          PlotLabel -> "\<t = \>" <> ToString\ [n\ \[CapitalDelta]t]], {n, 0, 
          80, 2}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.65"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 0 Mdot
.04762 0 Mdot
.07143 0 Mdot
.09524 0 Mdot
.11905 0 Mdot
.14286 0 Mdot
.16667 0 Mdot
.19048 0 Mdot
.21429 0 Mdot
.2381 0 Mdot
.2619 0 Mdot
.28571 0 Mdot
.30952 0 Mdot
.33333 0 Mdot
.35714 0 Mdot
.38095 0 Mdot
.40476 0 Mdot
.42857 0 Mdot
.45238 0 Mdot
.47619 0 Mdot
.5 0 Mdot
.52381 0 Mdot
.54762 0 Mdot
.57143 0 Mdot
.59524 0 Mdot
.61905 0 Mdot
.64286 0 Mdot
.66667 0 Mdot
.69048 0 Mdot
.71429 0 Mdot
.7381 0 Mdot
.7619 0 Mdot
.78571 0 Mdot
.80952 0 Mdot
.83333 0 Mdot
.85714 0 Mdot
.88095 0 Mdot
.90476 0 Mdot
.92857 0 Mdot
.95238 0 Mdot
.97619 0 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Tooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Ko
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Ko
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`00027o
oooo000Uooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`15ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool07oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooo
od;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool001_ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7o
oooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`007Ooo
ool00ol0003oooooooooo`05ooooo`;o0000oooooom2ooooo`007Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0oooooom1ooooo`006oooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`00
0?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`006_ooool5o`0000Kooooo00?o0000ooooooooool0oooo
oom1ooooo`006_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooo
oom1ooooo`006oooool00onHV9So8B4Qonk^kP07ooooo`;o0000oooooom2ooooo`007?ooool00onH
V9So8B4Qonk^kP06ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?oMgMgofIVI_oo
ool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom1ooooo`006_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo
00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo
@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`006_ooool01OnHV9So410@o`000?lb<S;oc<c<00Kooooo00?o0000oooooooo
ool0oooooom1ooooo`006_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Kooooo00?o0000oooooooo
ool0oooooom1ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo
@Oooool001gooooo00?oZJVYoa0@4?ooool01Oooool2o`000?oooooo@_ooool001cooooo00?o410@
o`000?nj^[X01_ooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03okZj^_lQ8B7ooooo
00Gooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01Ol@413oV9RHoooooonj^[[o0000
00Kooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnYZJWo410@o`000?l@413oZJVY
00Kooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Looooo`;o
000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool5o`0000Kooooo0_l0
003ooooood;ooooo000Jooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0oooo
oom1ooooo`006_ooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo0?oooooo@Ooo
ool001_ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3ooooood7ooooo000Koooo
o`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom1ooooo`007?ooool00omgMgOo
0000ooooo`06ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0?oooooo@Oooool001kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`3ooooood7ooooo000Oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
oooooom1ooooo`007_ooool00omgMgOo<S8booooo`04ooooo`;o0000oooooom2ooooo`006oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<0?ooooooBOooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`Co0000oooooom:ooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Y?ooool01OnHV9So0000o`000?m4A4Co
^[Zj01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP2Rooooo`00Y?ooool01Ol@413o^[Zjonk^k_mg
MgOo410@00Wooooo1_l00009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0X_ooool00:Cooooo00?o
0000ooooooooool06_ooool01Ol@413ooooooooooooooooo410@0:;ooooo002Tooooo`03o`000?oo
oooooooo00_ooooo1_l00009ooooo`05o`000?ooooooooooooooool00000X_ooool00:Cooooo00?o
0000ooooooooool06_ooool01Ol0003ooooooooooooooooo00000:;ooooo002Rooooo`03oa0@4?l0
003o000000?o00006Oooool01Ol@413ooooooooooooooooo410@0:;ooooo002Tooooo`03o`000?oo
oooooooo01[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`2Rooooo`00Y?ooool00ol0003ooooooooo
o`0Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0X_ooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.06) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .05946 Mdot
.04762 .06946 Mdot
.07143 .06379 Mdot
.09524 .01241 Mdot
.11905 .00242 Mdot
.14286 .00047 Mdot
.16667 9e-05 Mdot
.19048 2e-05 Mdot
.21429 0 Mdot
.2381 0 Mdot
.2619 0 Mdot
.28571 0 Mdot
.30952 0 Mdot
.33333 0 Mdot
.35714 0 Mdot
.38095 0 Mdot
.40476 0 Mdot
.42857 0 Mdot
.45238 0 Mdot
.47619 0 Mdot
.5 0 Mdot
.52381 0 Mdot
.54762 0 Mdot
.57143 0 Mdot
.59524 0 Mdot
.61905 0 Mdot
.64286 0 Mdot
.66667 0 Mdot
.69048 0 Mdot
.71429 0 Mdot
.7381 0 Mdot
.7619 0 Mdot
.78571 0 Mdot
.80952 0 Mdot
.83333 0 Mdot
.85714 2e-05 Mdot
.88095 9e-05 Mdot
.90476 .00044 Mdot
.92857 .00225 Mdot
.95238 .01157 Mdot
.97619 .05946 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Ko
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Ko
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l0000>ooooo`03o`000?oooooooooo01oo
oooo000Uooooo`03o`000?oooooooooo01Wooooo0_l0000Zooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`0fooooo`;o00003_ooool00ol0003ooooo
ooooo`0Oooooo`009Oooool00ol0003oooooooooo`3ooooooaOooooo0_l0000Xooooo`009Oooool0
0ol0003oooooooooo`0Booooo`;o0000ooooool3ooooo`;o0000:?ooool002Gooooo00?o0000oooo
ooooool04_ooool2o`000?oooooo;Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Tooooo`;o0000oooooolPooooo`;o00008Ooo
ool002Cooooo0_l0000<ooooo`;o0000oooooolBooooo`;o00008Oooool002Gooooo00?o0000oooo
ooooool02_ooool2o`000?oooooo=Oooool002Gooooo00?o0000ooooooooool00oooool2o`000?oo
oooo??ooool002Gooooo00?o0000ooooooooool00oooool2o`000?oooooo??ooool002Gooooo0_l0
003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Koooo
o`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Ooo
ool2o`000?oooooo@_ooool001gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
oooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1oooo
o`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo
00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`00
0?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool001[ooooo1Ol00006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00?oV9RH
ob4Q8Oo^k^h01oooool2o`000?oooooo@_ooool001cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0
003oooooooooo`3ooooood7ooooo000Mooooo`03ogMgMomVIVKooooo00Gooooo00?o0000oooooooo
ool0oooooom1ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo
@Oooool001[ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?oooooo
@Oooool001[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo
@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`00
0?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo
00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo
00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03ojVYZOl@
413ooooo00Gooooo0_l0003ooooood;ooooo000Looooo`03oa0@4?l0003o^[Zj00Kooooo00?o0000
ooooooooool0oooooom1ooooo`007Oooool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo
0?oooooo@Oooool001[ooooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooooooo
0?oooooo@Oooool001[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`007?ooool2o`000003oa0@4?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0?oooooo@Oooool001[ooooo1Ol00006ooooo`;o0000oooooom2ooooo`006_ooool0
1?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00CogMgM
oeEEEOoooooo00001oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03ogMgMoo<c<co
000000Oooooo00?o0000ooooooooool0oooooom1ooooo`006oooool00oo^k^koA4A4o`000007oooo
o`03o`000?oooooooooo0?oooooo@Oooool001cooooo00?oMgMgo`000?ooool01_ooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Kooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Nooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`00
7oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo00?o
MgMgoc8b<_ooool01?ooool2o`000?oooooo@_ooool001_ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c03oooooodWooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool4o`000?ooooooB_ooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool009Wooooo00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^
k_lb<S;o0000oa0@4?o<c<`0UOooool009Wooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko
00002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool01OmEEEGoMgMgoooooonHV9So8B4Q09Gooooo002Iooooo`03o`000?oooooo
oooo01[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@4100
0oooool01Ol0003ooooooooooooooooo000009Gooooo002Iooooo`03o`000?oooooooooo00_ooooo
1_l00009ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@2Eooooo`00VOooool00ol0003oooooooooo`0Joooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000oeEEEOl0003o410@olc<c02Eooooo`00Uoooool00ol@413o0000o`000003o`0001Wooooo00Go
410@oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41000oooool00omEEEGo
QhN7ooooo`2Gooooo`00VOooool00ol0003oooooooooo`0Jooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?ogMgMoa0@4?nHV9P0Uoooool009Wo
oooo00?o0000ooooooooool06_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP04ooooo`04olc<c?m4A4Co0000oa0@49Gooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.12) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .09618 Mdot
.04762 .12555 Mdot
.07143 .11987 Mdot
.09524 .04371 Mdot
.11905 .01197 Mdot
.14286 .00297 Mdot
.16667 .0007 Mdot
.19048 .00016 Mdot
.21429 4e-05 Mdot
.2381 1e-05 Mdot
.2619 0 Mdot
.28571 0 Mdot
.30952 0 Mdot
.33333 0 Mdot
.35714 0 Mdot
.38095 0 Mdot
.40476 0 Mdot
.42857 0 Mdot
.45238 0 Mdot
.47619 0 Mdot
.5 0 Mdot
.52381 0 Mdot
.54762 0 Mdot
.57143 0 Mdot
.59524 0 Mdot
.61905 0 Mdot
.64286 0 Mdot
.66667 0 Mdot
.69048 0 Mdot
.71429 0 Mdot
.7381 0 Mdot
.7619 0 Mdot
.78571 0 Mdot
.80952 1e-05 Mdot
.83333 3e-05 Mdot
.85714 .00013 Mdot
.88095 .00057 Mdot
.90476 .00235 Mdot
.92857 .00906 Mdot
.95238 .03167 Mdot
.97619 .09618 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`04ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool07oooool002Gooooo00?o0000ooooooooool08?ooool2o`0002?ooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo02oooooo
0_l0000Eooooo`03o`000?oooooooooo01oooooo000Uooooo`03o`000?oooooooooo01Wooooo0_l0
003cooooo`;o0000<?ooool002Gooooo00?o0000ooooooooool06Oooool2o`000??ooooo0_l0000`
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_oo
ool002Gooooo00?o0000ooooooooool0oooooolGooooo`;o0000:?ooool002Gooooo00?o0000oooo
ooooool0oooooolGooooo`;o0000:?ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo01;ooooo0_l0
003oooooobgooooo000Uooooo`03o`000?oooooooooo01;ooooo0_l0003oooooobgooooo000Uoooo
o`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Cooooo0_l0003oooooob3ooooo0_l0000Qooooo`009?ooool3o`000?oooooo7oooool2o`00
027ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool001_ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`;o
0000ooooooleooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo
0_l0003oooooocGooooo000Mooooo`03o`000?oooooooooo00Gooooo0_l00004ooooo`;o0000oooo
oollooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo0_l0003o
oooooccooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1oooo
o`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo
00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`00
0?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool001[ooooo1Ol00006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00?oV9RH
ob4Q8Oo^k^h01oooool2o`000?oooooo@_ooool001cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0
003oooooooooo`3ooooood7ooooo000Mooooo`03ogMgMomVIVKooooo00Gooooo00?o0000oooooooo
ool0oooooom1ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo
@Oooool001[ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?oooooo
@Oooool001[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo
@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`00
0?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo
00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo
00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03ojVYZOl@
413ooooo00Gooooo0_l0003ooooood;ooooo000Looooo`03oa0@4?l0003o^[Zj00Kooooo00?o0000
ooooooooool0oooooom1ooooo`007Oooool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo
0?oooooo@Oooool001[ooooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooooooo
0?oooooo@Oooool001[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`007?ooool2o`000003oa0@4?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0?oooooo@Oooool001[ooooo1Ol00006ooooo`;o0000oooooom2ooooo`006_ooool0
1?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00CogMgM
oeEEEOoooooo00001oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03ogMgMoo<c<co
000000Oooooo00?o0000ooooooooool0oooooom1ooooo`006oooool00oo^k^koA4A4o`000007oooo
o`03o`000?oooooooooo0?oooooo@Oooool001cooooo00?oMgMgo`000?ooool01_ooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Kooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Nooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`00
7oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo00?o
MgMgoc8b<_ooool01?ooool2o`000?oooooo@_ooool001_ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c03oooooodWooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool4o`000?ooooooB_ooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool009Wooooo00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l000000ol@413oooooooooo`05o`0009Gooooo002I
ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@0UOooool009Wooooo00?o0000ooooooooool06_ooool01Ol@413ooooooooooooooooo410@00ko
oooo00?o0000ooooooooool00oooool00onHV9So8B4Qonk^kP2Fooooo`00VOooool00ol0003ooooo
ooooo`0;ooooo`Ko00002Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000oooooooo
ool01?ooool00onHV9So8B4Qonk^kP2Eooooo`00VOooool00ol0003oooooooooo`0Jooooo`05o`00
0?ooooooooooooooool000003_ooool00ol0003oooooooooo`05ooooo`03ogMgMomVIVKooooo09Co
oooo002Gooooo`03oa0@4?l0003o000000?o00006Oooool01Ol@413ooooooooooooooooo410@00ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2Cooooo`00VOooool00ol0003ooooo
ooooo`0Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`02ooooo`05
o`000?nj^[[ooooooiRHV?l@4100UOooool009Wooooo00?o0000ooooooooool06_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001?ooool01OnHV9So410@o`000?lQ8B7o
c<c<09Gooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.18) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .12171 Mdot
.04762 .16552 Mdot
.07143 .17431 Mdot
.09524 .08655 Mdot
.11905 .03156 Mdot
.14286 .0097 Mdot
.16667 .00273 Mdot
.19048 .00073 Mdot
.21429 .00019 Mdot
.2381 5e-05 Mdot
.2619 1e-05 Mdot
.28571 0 Mdot
.30952 0 Mdot
.33333 0 Mdot
.35714 0 Mdot
.38095 0 Mdot
.40476 0 Mdot
.42857 0 Mdot
.45238 0 Mdot
.47619 0 Mdot
.5 0 Mdot
.52381 0 Mdot
.54762 0 Mdot
.57143 0 Mdot
.59524 0 Mdot
.61905 0 Mdot
.64286 0 Mdot
.66667 0 Mdot
.69048 0 Mdot
.71429 0 Mdot
.7381 0 Mdot
.7619 0 Mdot
.78571 1e-05 Mdot
.80952 3e-05 Mdot
.83333 .00014 Mdot
.85714 .00052 Mdot
.88095 .00183 Mdot
.90476 .00605 Mdot
.92857 .01801 Mdot
.95238 .04783 Mdot
.97619 .12171 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Ko
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Ko
oooo0_l00005ooooo`;o00003Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01oo
oooo000Uooooo`03o`000?oooooooooo02Oooooo0_l0000Looooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`0_ooooo`;o00005Oooool00ol0003ooooo
ooooo`0Oooooo`009Oooool00ol0003oooooooooo`0Pooooo`;o0000iOooool2o`0003Oooooo000U
ooooo`03o`000?oooooooooo023ooooo0_l0003ooooooaoooooo000Uooooo`03o`000?oooooooooo
0?oooooo3oooool2o`00033ooooo000Uooooo`03o`000?oooooooooo0?oooooo3oooool2o`00033o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000U
ooooo`03o`000?oooooooooo01Wooooo0_l0003oooooobKooooo000Uooooo`03o`000?oooooooooo
01Wooooo0_l0003oooooobKooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo5oooool2o`0002Sooooo000Uooooo`;o0000oooooolHoooo
o`;o0000:?ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo01;ooooo0_l0003oooooobgo
oooo000Uooooo`03o`000?oooooooooo01;ooooo0_l0003oooooobgooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`00
0?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`006oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooo
ooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001gooooo00?o0000ooooooooool01?ooool2o`000?oooooo8?ooool2o`00027ooooo
000Mooooo`03o`000?oooooooooo00Cooooo0ol0003ooooooaoooooo0_l0000Qooooo`007Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0oooooom1ooooo`006oooool00omEEEGoIVIVo`000007ooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo00?ooooo0_l0003ooooooccooooo000Uooooo`03o`000?oooooooooo00?o
oooo0_l0003ooooooccooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0
000;ooooo`;o0000ooooooleooooo`009Oooool00ol0003oooooooooo`0:ooooo`;o0000oooooole
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooo
od;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0
003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool001[ooooo1Ol00006ooooo`03o`000?oooooooooo0?oooooo@Ooo
ool001[ooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0?oooooo@Ooo
ool001_ooooo00?oV9RHob4Q8Oo^k^h01oooool2o`000?oooooo@_ooool001cooooo00?oV9RHob4Q
8Oo^k^h01_ooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0oooooom1ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo0?oooooo@Oooool001[ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`00
0?oooooooooo0?oooooo@Oooool001[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool001[ooooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001[ooooo00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood7ooooo
000Mooooo`03ojVYZOl@413ooooo00Gooooo0_l0003ooooood;ooooo000Looooo`03oa0@4?l0003o
^[Zj00Kooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00onj^[[o8B4Qooooo`05oooo
o`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go410@oiRHV?oooooo^[Zjo`000006oooo
o`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06oooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`007?ooool2o`000003
oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo1Ol00006ooooo`;o0000oooo
oom2ooooo`006_ooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo0?oooooo@Ooo
ool001[ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`3ooooood7ooooo000K
ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0oooooom1ooooo`006oooool00oo^
k^koA4A4o`000007ooooo`03o`000?oooooooooo0?oooooo@Oooool001cooooo00?oMgMgo`000?oo
ool01_ooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o
0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Kooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`3ooooood7ooooo000Nooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooom1ooooo`007oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo
@Oooool001kooooo00?oMgMgoc8b<_ooool01?ooool2o`000?oooooo@_ooool001_ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c03oooooodWooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool4o`000?ooooooB_ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool009Wooooo00GoV9RHo`000?l0003oA4A4okZj^P0H
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l000002?l@413ooooooooo
ooo<c<co8B4Qo`000?lQ8B7oc<c<UOooool009Wooooo00Go410@okZj^_o^k^koMgMgoa0@4009oooo
o`Ko00002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooo
oooo00;ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@2Eooooo`00VOooool00ol0003oooooooooo`0J
ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool00000UOooool009Wooooo00?o0000ooooooooool02oooool6o`0000Wooooo00Go
0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00;ooooo00Go<S8boiRHV?oooooo
V9RHoc8b<P2Eooooo`00VOooool00ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool0
00003_ooool00ol0003oooooooooo`02ooooo`05olc<c?l0003o0000o`000?o<c<`0UOooool009Oo
oooo00?o410@o`000?l000000ol0000Iooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0
003oooooooooo`02ooooo`05oa0@4?nj^[[ooooookZj^_l@4100UOooool009Wooooo00?o0000oooo
ooooool06_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool00_ooool0
1Ol0003o^[Zjoooooonj^[[o000009Gooooo002Iooooo`03o`000?oooooooooo01[ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo000000Cooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@2Eooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.24) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .13887 Mdot
.04762 .19224 Mdot
.07143 .22014 Mdot
.09524 .13936 Mdot
.11905 .06304 Mdot
.14286 .02301 Mdot
.16667 .00747 Mdot
.19048 .00226 Mdot
.21429 .00065 Mdot
.2381 .00018 Mdot
.2619 5e-05 Mdot
.28571 1e-05 Mdot
.30952 0 Mdot
.33333 0 Mdot
.35714 0 Mdot
.38095 0 Mdot
.40476 0 Mdot
.42857 0 Mdot
.45238 0 Mdot
.47619 0 Mdot
.5 0 Mdot
.52381 0 Mdot
.54762 0 Mdot
.57143 0 Mdot
.59524 0 Mdot
.61905 0 Mdot
.64286 0 Mdot
.66667 0 Mdot
.69048 0 Mdot
.71429 0 Mdot
.7381 0 Mdot
.7619 1e-05 Mdot
.78571 3e-05 Mdot
.80952 .00012 Mdot
.83333 .0004 Mdot
.85714 .0013 Mdot
.88095 .0039 Mdot
.90476 .01065 Mdot
.92857 .02627 Mdot
.95238 .05999 Mdot
.97619 .13887 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000gooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Oooooo`009Oooool00ol0003oooooooooo`0Wooooo`;o00001Oooool2o`0001Gooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo02Sooooo
0_l0000Looooo`03o`000?oooooooooo01oooooo000Uooooo`03o`000?oooooooooo02Oooooo0_l0
003Nooooo`;o0000=oooool002Gooooo00?o0000ooooooooool0ooooool8ooooo`;o0000=oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo023ooooo0_l0003ooooooaoooooo000Uooooo`;o00008Ooo
ool2o`000>cooooo0_l0000`ooooo`009Oooool00ol0003oooooooooo`3oooooo`oooooo0_l0000`
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooo
od;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooooaOooooo0_l0000Xooooo`009Oooool0
0ol0003oooooooooo`0Iooooo`;o0000noooool2o`0002Sooooo000Uooooo`03o`000?oooooooooo
01Wooooo0_l0003oooooobKooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo1?l000000ol@413oooooooooo`03oooo
o`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`;o0000oooooom2ooooo`007Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0oooooom1ooooo`006oooool00omEEEGoIVIVo`000006ooooo`;o0000
5?ooool2o`000?oooooo2_ooool2o`00027ooooo000Tooooo`;o00005?ooool2o`000?oooooo2_oo
ool2o`00027ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooo
od;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0
003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool00oooool2o`000?oooooo??oo
ool002Gooooo00?o0000ooooooooool00oooool2o`000?oooooo??ooool002Gooooo0_l0003ooooo
od;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo00[ooooo0_l0003oooooocGooooo
000Uooooo`;o00002oooool2o`000?oooooo=Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool5o`0000Kooooo00?o
0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o
0000ooooooooool0oooooom1ooooo`006oooool00onHV9So8B4Qonk^kP07ooooo`;o0000oooooom2
ooooo`007?ooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo0?oooooo@Oooool001go
oooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01Ol0003o^[Zjoooo
oonHV9So410@00Kooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So410@o`00
0?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooo
od;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So410@o`000?lb<S;oc<c<00Ko
oooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Ko
oooo00?o0000ooooooooool0oooooom1ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo0?oooooo@Oooool001gooooo00?oZJVYoa0@4?ooool01Oooool2o`000?oooooo@_oo
ool001cooooo00?o410@o`000?nj^[X01_ooool00ol0003oooooooooo`3ooooood7ooooo000Moooo
o`03okZj^_lQ8B7ooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01Ol@413o
V9RHoooooonj^[[o000000Kooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnYZJWo
410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0
003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Looooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3ooooood7o
oooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`006_oo
ool5o`0000Kooooo0_l0003ooooood;ooooo000Jooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o
0000ooooooooool0oooooom1ooooo`006_ooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oo
oooooooo0?oooooo@Oooool001_ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3o
oooood7ooooo000Kooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom1oooo
o`007?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`3ooooood7ooooo000Oooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0oooooom1ooooo`007_ooool00omgMgOo<S8booooo`04ooooo`;o0000oooo
oom2ooooo`006oooool01Ol0003o8B4Qo`000?lb<S;oc<c<0?ooooooBOooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`Co
0000oooooom:ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00VOooool01OnH
V9So0000o`000?m4A4Co^[Zj01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool5o`0000Gooooo0_l000000ol@413oooooooooo`2Cooooo`00VOooool01Ol@413o^[Zjonk^k_mg
MgOo410@00Wooooo1_l00009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo
00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo09Cooooo002Iooooo`03o`00
0?oooooooooo01[ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Co
oooo1Ol0002Eooooo`00VOooool00ol0003oooooooooo`0;ooooo`Ko00002Oooool01Ol0003ooooo
oooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h00oooool01?m4A4CogMgMooooool0002Foooo
o`00VOooool00ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool000003_ooool00omg
MgOoIVIVooooo`02ooooo`04omgMgOmEEEGoooooo`0009Kooooo002Gooooo`03oa0@4?l0003o0000
00?o00006Oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool0
0omgMgOoc<c<o`00002Fooooo`00VOooool00ol0003oooooooooo`0Jooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?ok^k^odA4A?l00000U_oo
ool009Wooooo00?o0000ooooooooool06_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c005ooooo`03ogMgMol0003ooooo09Gooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .1503 Mdot
.04762 .20893 Mdot
.07143 .25165 Mdot
.09524 .1945 Mdot
.11905 .10839 Mdot
.14286 .04607 Mdot
.16667 .0168 Mdot
.19048 .00562 Mdot
.21429 .00178 Mdot
.2381 .00054 Mdot
.2619 .00016 Mdot
.28571 4e-05 Mdot
.30952 1e-05 Mdot
.33333 0 Mdot
.35714 0 Mdot
.38095 0 Mdot
.40476 0 Mdot
.42857 0 Mdot
.45238 0 Mdot
.47619 0 Mdot
.5 0 Mdot
.52381 0 Mdot
.54762 0 Mdot
.57143 0 Mdot
.59524 0 Mdot
.61905 0 Mdot
.64286 0 Mdot
.66667 0 Mdot
.69048 0 Mdot
.71429 0 Mdot
.7381 1e-05 Mdot
.7619 3e-05 Mdot
.78571 9e-05 Mdot
.80952 .0003 Mdot
.83333 .00089 Mdot
.85714 .0025 Mdot
.88095 .00646 Mdot
.90476 .01527 Mdot
.92857 .0332 Mdot
.95238 .0689 Mdot
.97619 .1503 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Ko
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Ko
oooo0_l00006ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Oooooo`009Oooool00ol0003oooooooooo`0^ooooo`;o00005Oooool00ol0003ooooo
ooooo`15ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool08Oooool2o`0000Gooooo
0_l0000Looooo`03o`000?oooooooooo01oooooo000Uooooo`03o`000?oooooooooo02kooooo0_l0
003@ooooo`;o0000?_ooool002Gooooo00?o0000ooooooooool0ooooool8ooooo`;o0000=oooool0
02Gooooo00?o0000ooooooooool09oooool2o`000=kooooo0_l0000gooooo`009Oooool00ol0003o
ooooooooo`0Wooooo`;o0000oooooolHooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo3oooool2o`00033ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo3oooool2o`00033ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`0Pooooo`;o0000oooooolO
ooooo`009Oooool2o`00027ooooo0_l0003ooooooaoooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooooaOooooo0_l0000Xooooo`00
9Oooool00ol0003oooooooooo`3ooooooaOooooo0_l0000Xooooo`009Oooool2o`000?oooooo@_oo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`0Iooooo`;o0000oooooolVooooo`009Oooool00ol0003oooooooooo`0Iooooo`;o0000oooooolV
ooooo`006oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom1oooo
o`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oo
oooooooo00Gooooo0_l0003ooooood;ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7o
oooo000Kooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Cooooo0ol0003ooooooaoooooo0_l0000Qooooo`009?ooool2o`000?oooooo8?ooool2o`00027o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool04_ooool2o`000?oooooo;Oooool0
02Gooooo0_l0000Cooooo`;o0000ooooool]ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool00ooo
ool2o`000?oooooo??ooool002Gooooo00?o0000ooooooooool00oooool2o`000?oooooo??ooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool001[ooooo1Ol00006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00?oV9RH
ob4Q8Oo^k^h01oooool2o`000?oooooo@_ooool001cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0
003oooooooooo`0:ooooo`;o0000ooooooleooooo`007Oooool00omgMgOoIVIVooooo`05ooooo`03
o`000?oooooooooo00[ooooo0_l0003oooooocGooooo000Nooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom1ooooo`006_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo
00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo
@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`006_ooool01OnHV9So410@o`000?lb<S;oc<c<00Kooooo00?o0000oooooooo
ool0oooooom1ooooo`006_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Kooooo00?o0000oooooooo
ool0oooooom1ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo
@Oooool001gooooo00?oZJVYoa0@4?ooool01Oooool2o`000?oooooo@_ooool001cooooo00?o410@
o`000?nj^[X01_ooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03okZj^_lQ8B7ooooo
00Gooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01Ol@413oV9RHoooooonj^[[o0000
00Kooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnYZJWo410@o`000?l@413oZJVY
00Kooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Looooo`;o
000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool5o`0000Kooooo0_l0
003ooooood;ooooo000Jooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0oooo
oom1ooooo`006_ooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo0?oooooo@Ooo
ool001_ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3ooooood7ooooo000Koooo
o`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom1ooooo`007?ooool00omgMgOo
0000ooooo`06ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0?oooooo@Oooool001kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`3ooooood7ooooo000Oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
oooooom1ooooo`007_ooool00omgMgOo<S8booooo`04ooooo`;o0000oooooom2ooooo`006oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<0?ooooooBOooool001_ooooo00?o0000ooooooooool0oooooom;
ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`Co0000oooooom:ooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00WOooool01OnHV9So0000o`000?m4A4Co
^[Zj01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01OnHV9So410@o`00
0?lb<S;oc<c<09Wooooo002Mooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b
09Wooooo002Mooooo`03o`000?oooooooooo01[ooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo09Oooooo002Mooooo`03o`000?oooooooooo00_ooooo1_l00009ooooo`05
o`000?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`2Hooooo`00WOooool00ol0003o
ooooooooo`0Jooooo`05o`000?ooooooooooooooool000003Oooool00ol@413o0000okZj^P2Ioooo
o`00Voooool00ol@413o0000o`000003o`0001Wooooo00Go410@oooooooooooooooooa0@400>oooo
o`03okZj^_lQ8B7ooooo09Sooooo002Mooooo`03o`000?oooooooooo01[ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l00000VOooool009gooooo00?o0000oooo
ooooool06_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVY
Z@2Iooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.36) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .15796 Mdot
.04762 .21923 Mdot
.07143 .26924 Mdot
.09524 .23941 Mdot
.11905 .16481 Mdot
.14286 .08277 Mdot
.16667 .03367 Mdot
.19048 .01226 Mdot
.21429 .00419 Mdot
.2381 .00137 Mdot
.2619 .00043 Mdot
.28571 .00013 Mdot
.30952 4e-05 Mdot
.33333 1e-05 Mdot
.35714 0 Mdot
.38095 0 Mdot
.40476 0 Mdot
.42857 0 Mdot
.45238 0 Mdot
.47619 0 Mdot
.5 0 Mdot
.52381 0 Mdot
.54762 0 Mdot
.57143 0 Mdot
.59524 0 Mdot
.61905 0 Mdot
.64286 0 Mdot
.66667 0 Mdot
.69048 0 Mdot
.71429 1e-05 Mdot
.7381 2e-05 Mdot
.7619 7e-05 Mdot
.78571 .00021 Mdot
.80952 .0006 Mdot
.83333 .0016 Mdot
.85714 .004 Mdot
.88095 .00918 Mdot
.90476 .0195 Mdot
.92857 .03882 Mdot
.95238 .07543 Mdot
.97619 .15796 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Ko
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Ko
oooo0_l00006ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Oooooo`009Oooool00ol0003oooooooooo`0fooooo`;o00003Oooool00ol0003ooooo
ooooo`15ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool08Oooool2o`0002?ooooo
00?o0000ooooooooool07oooool002Gooooo00?o0000ooooooooool0ooooool1ooooo`;o0000?_oo
ool002Gooooo00?o0000ooooooooool0;_ooool2o`000=3ooooo0_l0000nooooo`009Oooool00ol0
003oooooooooo`0^ooooo`;o0000oooooolAooooo`009Oooool00ol0003oooooooooo`3oooooo`So
oooo0_l0000gooooo`009Oooool00ol0003oooooooooo`3oooooo`Sooooo0_l0000gooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`0Wooooo`;o0000oooooolHooooo`009Oooool00ol0003oooooooooo`0Wooooo`;o
0000oooooolHooooo`009Oooool00ol0003oooooooooo`3oooooo`oooooo0_l0000`ooooo`009Ooo
ool00ol0003oooooooooo`3oooooo`oooooo0_l0000`ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`;o0000oooooolHooooo`;o0000:?ooool002Gooooo00?o0000
ooooooooool0oooooolGooooo`;o0000:?ooool002Gooooo00?o0000ooooooooool08?ooool2o`00
0?oooooo7oooool002Gooooo00?o0000ooooooooool08?ooool2o`000?oooooo7oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
01_ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo@Oooool001go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003ooooooooo
o`05ooooo`;o0000oooooom2ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`00
6oooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Cooooo0_l0003oooooob3ooooo0_l0000Qooooo`009?ooool2
o`000?oooooo8?ooool2o`00027ooooo000Uooooo`03o`000?oooooooooo01Wooooo0_l0003ooooo
obKooooo000Uooooo`03o`000?oooooooooo01Wooooo0_l0003oooooobKooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool00oooool2o`000?oooooo??ooool002Gooooo00?o0000ooooooooool0
0oooool2o`000?oooooo??ooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo1Ol0
0006ooooo`03o`000?oooooooooo01;ooooo0_l0003oooooobgooooo000Jooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01_ooool00ol0003oooooooooo`0Booooo`;o0000ooooool]ooooo`006oooool0
0onHV9So8B4Qonk^kP07ooooo`;o0000oooooom2ooooo`007?ooool00onHV9So8B4Qonk^kP06oooo
o`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?oMgMgofIVI_ooool01Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom1ooooo`006_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
oooooom1ooooo`006_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo00[ooooo0_l0003oooooocGooooo000Uooooo`;o00002oooool2o`000?oooooo=Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000
oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Jooooo`05oiRHV?l@413o0000oc8b<_o<c<`01_ooool00ol0003o
ooooooooo`3ooooood7ooooo000Jooooo`05oa0@4?nj^[[oooooogMgMolb<S801_ooool00ol0003o
ooooooooo`3ooooood7ooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom1ooooo`007Oooool00onYZJWo410@ooooo`05ooooo`;o0000oooooom2ooooo`007?ooool0
0ol@413o0000okZj^P06ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o^[Zjob4Q
8Oooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oa0@4?nHV9SooooookZj
^_l000001_ooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05ojVYZOl@413o0000oa0@
4?nYZJT01_ooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_oo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oo
oooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001co
oooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`Go00001_oo
ool2o`000?oooooo@_ooool001[ooooo00CoA4A4omgMgOoooooo00001oooool00ol0003ooooooooo
o`3ooooood7ooooo000Jooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0oooo
oom1ooooo`006oooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo0?oooooo@Oooool0
01_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`3ooooood7ooooo000Looooo`03
ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003o
oooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`006oooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0oooooom1ooooo`007_ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo0?oooooo@Oooool001oooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Nooooo`03ogMgMolb<S;ooooo00Cooooo0_l0003ooooood;ooooo000K
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0oooooom9ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo1?l0003ooooood[o
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Iooooo`05oiRHV?l0003o0000
odA4A?nj^[X06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05oiRHV?l@
413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?l@413oc<c<09Gooooo002Iooooo`05oa0@
4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoEEEEogMgMoooooooV9RHob4Q
8@2Eooooo`00VOooool00ol0003oooooooooo`0Jooooo`05oa0@4?ooooooooooooooool@41003ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0Toooool009Wooooo00?o
0000ooooooooool02oooool6o`0000Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ojVY
ZOl@413ooooo00;ooooo00Go0000oiRHV?ooooooV9RHob4Q8@2Eooooo`00VOooool00ol0003ooooo
ooooo`0Jooooo`05o`000?ooooooooooooooool000003Oooool00ol@413o0000okZj^P03ooooo`05
o`000?mEEEGo0000oa0@4?o<c<`0UOooool009Oooooo00?o410@o`000?l000000ol0000Iooooo`05
oa0@4?ooooooooooooooool@41003_ooool00onj^[[o8B4Qooooo`02ooooo`03oeEEEOn7QhOooooo
09Oooooo002Iooooo`03o`000?oooooooooo01[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05oa0@4?nHV9SooooookZj^_l000000oooool00ooMgMgo410@oiRHV02Gooooo`00VOooool00ol0
003oooooooooo`0Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00Cooooo00Coc<c<odA4A?l0003o410@UOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.42) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .16321 Mdot
.04762 .22575 Mdot
.07143 .27848 Mdot
.09524 .26598 Mdot
.11905 .22024 Mdot
.14286 .13483 Mdot
.16667 .06239 Mdot
.19048 .02459 Mdot
.21429 .00893 Mdot
.2381 .00309 Mdot
.2619 .00103 Mdot
.28571 .00033 Mdot
.30952 .0001 Mdot
.33333 3e-05 Mdot
.35714 1e-05 Mdot
.38095 0 Mdot
.40476 0 Mdot
.42857 0 Mdot
.45238 0 Mdot
.47619 0 Mdot
.5 0 Mdot
.52381 0 Mdot
.54762 0 Mdot
.57143 0 Mdot
.59524 0 Mdot
.61905 0 Mdot
.64286 0 Mdot
.66667 0 Mdot
.69048 1e-05 Mdot
.71429 2e-05 Mdot
.7381 5e-05 Mdot
.7619 .00014 Mdot
.78571 .0004 Mdot
.80952 .00103 Mdot
.83333 .0025 Mdot
.85714 .00565 Mdot
.88095 .01184 Mdot
.90476 .02321 Mdot
.92857 .04332 Mdot
.95238 .08026 Mdot
.97619 .16321 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01?ooool2o`0000Go
oooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l0000>ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Oooooo`009Oooool00ol0003oooooooooo`0mooooo`;o00001_ooool00ol0003ooooo
ooooo`15ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool06Oooool2o`0000Kooooo
0_l0000Sooooo`03o`000?oooooooooo01oooooo000Uooooo`03o`000?oooooooooo03Kooooo0_l0
0031ooooo`;o00001Oooool2o`0003kooooo000Uooooo`03o`000?oooooooooo03Kooooo0_l00038
ooooo`;o0000?_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo02kooooo0_l0003Gooooo`;o0000
=oooool002Gooooo0_l0000_ooooo`;o0000eoooool2o`0003Oooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0ooooool?ooooo`;o0000<?ooool002Gooooo00?o0000ooooooooool0ooooool?
ooooo`;o0000<?ooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo02Oooooo0_l0003ooooooaSooooo000Uoooo
o`03o`000?oooooooooo02Oooooo0_l0003ooooooaSooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_oo
ool002Gooooo00?o0000ooooooooool0oooooolGooooo`;o0000:?ooool002Gooooo00?o0000oooo
ooooool0oooooolGooooo`;o0000:?ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`006oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom1oooo
o`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oo
oooooooo00Gooooo0_l0003ooooood;ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Pooooo`;o
0000oooooolOooooo`006oooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo023ooooo
0_l0003ooooooaoooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Cooooo0_l0003oooooob3ooooo0_l0000Qooooo`009?ooool2o`00
0?oooooo8?ooool2o`00027ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo01Wooooo
0_l0003oooooobKooooo000Uooooo`;o00001?ooool2o`0001Cooooo0_l0003oooooobKooooo000U
ooooo`03o`000?oooooooooo00?ooooo0_l0003ooooooccooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Jooooo`Go00001_ooool00ol0003oooooooooo`3ooooood7ooooo000J
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`3ooooood7ooooo000K
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0_l0003ooooood;ooooo000Looooo`03oiRHV?lQ8B7ok^k^
00Kooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00omgMgOoIVIVooooo`05ooooo`03
o`000?oooooooooo0?oooooo@Oooool001kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3ooooood7ooooo000Jooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003ooooo
ooooo`3ooooood7ooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo01;ooooo0_l0003oooooobgooooo000U
ooooo`03o`000?oooooooooo01;ooooo0_l0003oooooobgooooo000Uooooo`;o0000oooooom2oooo
o`009Oooool00ol0003oooooooooo`0:ooooo`;o0000ooooooleooooo`009Oooool00ol0003ooooo
ooooo`0:ooooo`;o0000ooooooleooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So410@
o`000?lb<S;oc<c<00Kooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01Ol@413o^[Zj
oooooomgMgOo<S8b00Kooooo00?o0000ooooooooool0oooooom1ooooo`007_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?oZJVYoa0@4?ooool01Ooo
ool2o`000?oooooo@_ooool001cooooo00?o410@o`000?nj^[X01_ooool00ol0003oooooooooo`3o
oooood7ooooo000Mooooo`03okZj^_lQ8B7ooooo00Gooooo00?o0000ooooooooool0oooooom1oooo
o`006_ooool01Ol@413oV9RHoooooonj^[[o000000Kooooo00?o0000ooooooooool0oooooom1oooo
o`006_ooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooo
oom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o
0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Looooo`;o000000?o410@ooooooooool01?ooool00ol0003o
ooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
oooooom1ooooo`006_ooool5o`0000Kooooo0_l0003ooooood;ooooo000Jooooo`04odA4A?oMgMgo
ooooo`0000Oooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01?oMgMgoEEEEooooool0
0007ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00?oMgMgolc<c?l000001oooool0
0ol0003oooooooooo`3ooooood7ooooo000Kooooo`03onk^k_m4A4Co000000Oooooo00?o0000oooo
ooooool0oooooom1ooooo`007?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oo
oooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2
o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001_o
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo@Oooool001ko
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood7ooooo000Oooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0oooooom1ooooo`007_ooool00omgMgOo<S8boooo
o`04ooooo`;o0000oooooom2ooooo`006oooool01Ol0003o8B4Qo`000?lb<S;oc<c<0?ooooooBOoo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`Co0000oooooom:ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00VOooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1_ooool2o`000004oa0@4?ooooooooooooooo`Go0000UOooool009Wooooo00Go
410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A02Eoooo
o`00VOooool00ol0003oooooooooo`0Jooooo`05oa0@4?ooooooooooooooool@41002oooool5o`00
00Cooooo00?oV9RHob4Q8Oo^k^h0U_ooool009Wooooo00?o0000ooooooooool02oooool6o`0000Wo
oooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Kooooo00?oV9RH
ob4Q8Oo^k^h0UOooool009Wooooo00?o0000ooooooooool06_ooool01Ol0003ooooooooooooooooo
000000_ooooo00CogMgMoeEEEOoooooo00001oooool00omgMgOoIVIVooooo`2Dooooo`00Uoooool0
0ol@413o0000o`000003o`0001Wooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<
c<co000000Sooooo00?o0000ooooooooool0Toooool009Wooooo00?o0000ooooooooool06_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001?ooool01Ol0003o^[Zjoooo
oonHV9So410@09Gooooo002Iooooo`03o`000?oooooooooo01[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0=ooooo`03ogMgMol0003ooooo00?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c02Eooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.48) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .16691 Mdot
.04762 .22998 Mdot
.07143 .28413 Mdot
.09524 .27808 Mdot
.11905 .25876 Mdot
.14286 .19525 Mdot
.16667 .10723 Mdot
.19048 .0466 Mdot
.21429 .01795 Mdot
.2381 .00651 Mdot
.2619 .00228 Mdot
.28571 .00077 Mdot
.30952 .00026 Mdot
.33333 8e-05 Mdot
.35714 3e-05 Mdot
.38095 1e-05 Mdot
.40476 0 Mdot
.42857 0 Mdot
.45238 0 Mdot
.47619 0 Mdot
.5 0 Mdot
.52381 0 Mdot
.54762 0 Mdot
.57143 0 Mdot
.59524 0 Mdot
.61905 0 Mdot
.64286 0 Mdot
.66667 0 Mdot
.69048 1e-05 Mdot
.71429 4e-05 Mdot
.7381 .0001 Mdot
.7619 .00026 Mdot
.78571 .00066 Mdot
.80952 .00158 Mdot
.83333 .00353 Mdot
.85714 .00735 Mdot
.88095 .01433 Mdot
.90476 .0264 Mdot
.92857 .04694 Mdot
.95238 .08389 Mdot
.97619 .16691 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Ko
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01oo
oooo000Uooooo`03o`000?oooooooooo03gooooo0_l00005ooooo`;o0000Aoooool00ol0003ooooo
ooooo`15ooooo`03o`000?oooooooooo01Wooooo0_l00006ooooo`;o00008oooool00ol0003ooooo
ooooo`0Oooooo`009Oooool00ol0003oooooooooo`0mooooo`;o0000^_ooool2o`0004Gooooo000U
ooooo`03o`000?oooooooooo0?oooooo0Oooool2o`0003kooooo000Uooooo`03o`000?oooooooooo
03Kooooo0_l00038ooooo`;o0000?_ooool002Gooooo00?o0000ooooooooool0=_ooool2o`000?oo
oooo2Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo2Ooo
ool2o`0003Oooooo000Uooooo`03o`000?oooooooooo0?oooooo2?ooool2o`0003Oooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0;_ooool2o`000=kooooo0_l0000`ooooo`009Oooool2o`00
02oooooo0_l0003Nooooo`;o0000<?ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooooaOooooo0_l0000Xooooo`009Oooool00ol0003o
ooooooooo`3ooooooaOooooo0_l0000Xooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`0Wooooo`;o0000oooooolHooooo`009Oooool00ol0003ooooooooo
o`0Wooooo`;o0000oooooolHooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Koooo
o`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Ooo
ool2o`000?oooooo@_ooool001gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
oooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1oooo
o`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo
00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`00
0?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Tooooo`;o
0000oooooolPooooo`;o00008Oooool002Cooooo0_l0003oooooob3ooooo0_l0000Qooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo023ooooo0_l0003ooooooaoooooo000Uooooo`;o00008Oooool2o`00
0?oooooo7oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`03ooooo`;o0000oooooollooooo`009Oooool00ol0003oooooooooo`03ooooo`;o
0000oooooollooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`Go00001_oo
ool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_oo
ool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03oiRHV?lQ8B7ok^k^00Oooooo0_l0003o
oooood;ooooo000Looooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0oooooom1oooo
o`007Oooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Iooooo`;o0000oooooolVooooo`006_oo
ool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool06Oooool2o`000?oooooo
9_ooool001[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`0Booooo`;o
0000ooooool]ooooo`009Oooool00ol0003oooooooooo`0Booooo`;o0000ooooool]ooooo`009Ooo
ool00ol0003oooooooooo`0:ooooo`;o0000ooooooleooooo`009Oooool00ol0003oooooooooo`0:
ooooo`;o0000ooooooleooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oiRHV?l@413o0000oc8b<_o<
c<`01_ooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oa0@4?nj^[[oooooogMgMolb
<S801_ooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom1ooooo`007Oooool00onYZJWo410@ooooo`05ooooo`;o0000oooo
oom2ooooo`007?ooool00ol@413o0000okZj^P06ooooo`03o`000?oooooooooo0?oooooo@Oooool0
01gooooo00?o^[Zjob4Q8Oooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05
oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05
ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool001cooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo
000Jooooo`Go00001_ooool2o`000?oooooo@_ooool001[ooooo00CoA4A4omgMgOoooooo00001ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o
0000ooooooooool0oooooom1ooooo`006oooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooo
oooo0?oooooo@Oooool001_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`3ooooo
od7ooooo000Looooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`006oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom1ooooo`007_ooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03ogMgMolb<S;ooooo00Cooooo0_l0
003ooooood;ooooo000Kooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0oooooom9ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo1?l0003ooooood[ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Ioooo
o`05oiRHV?l0003o0000odA4A?nj^[X06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B46ooooo`;o000000Wo410@ooooooooooooooooolc<c?lQ8B7o0000ob4Q8Oo<c<`0UOooool009Wo
oooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002Oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00;ooooo00Go8B4QoiRHV?ooooooV9RHob4Q
8@2Eooooo`00VOooool00ol0003oooooooooo`0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0000?ooooo00Go0000ooooooooooooooooo`00002Eooooo`00VOooool00ol0003ooooooooo
o`0;ooooo`Ko00002Oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo
00001?ooool01Olb<S;oV9RHoooooonHV9So<S8b09Gooooo002Iooooo`03o`000?oooooooooo01[o
oooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Cooooo00Goc<c<
o`000?l0003o0000olc<c02Eooooo`00Uoooool00ol@413o0000o`000003o`0001Wooooo00Go410@
oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Cooooo00Go410@okZj^_oooooo^[Zj
oa0@402Eooooo`00VOooool00ol0003oooooooooo`0Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00oo^k^koA4A4o`000004ooooo`05o`000?nj^[[ooooookZj^_l00000UOooool009Wooooo
00?o0000ooooooooool06_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?oo
ool00oooool01OnYZJWo410@o`000?l@413oZJVY09Gooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.54) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .1696 Mdot
.04762 .23284 Mdot
.07143 .28789 Mdot
.09524 .28416 Mdot
.11905 .27674 Mdot
.14286 .24598 Mdot
.16667 .1669 Mdot
.19048 .08345 Mdot
.21429 .03458 Mdot
.2381 .0131 Mdot
.2619 .00474 Mdot
.28571 .00167 Mdot
.30952 .00057 Mdot
.33333 .00019 Mdot
.35714 6e-05 Mdot
.38095 2e-05 Mdot
.40476 1e-05 Mdot
.42857 0 Mdot
.45238 0 Mdot
.47619 0 Mdot
.5 0 Mdot
.52381 0 Mdot
.54762 0 Mdot
.57143 0 Mdot
.59524 0 Mdot
.61905 0 Mdot
.64286 0 Mdot
.66667 1e-05 Mdot
.69048 2e-05 Mdot
.71429 7e-05 Mdot
.7381 .00017 Mdot
.7619 .00043 Mdot
.78571 .00101 Mdot
.80952 .00223 Mdot
.83333 .00463 Mdot
.85714 .00903 Mdot
.88095 .0166 Mdot
.90476 .02914 Mdot
.92857 .04988 Mdot
.95238 .08669 Mdot
.97619 .1696 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Ko
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01oo
oooo000Uooooo`03o`000?oooooooooo04Cooooo0_l00017ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool04_ooool2o`0000Gooooo0_l0000[ooooo`03o`000?oooooooooo01oooooo
000Uooooo`03o`000?oooooooooo0?Wooooo0_l00015ooooo`009Oooool00ol0003oooooooooo`0m
ooooo`;o0000^_ooool2o`0004Gooooo000Uooooo`03o`000?oooooooooo03gooooo0_l00031oooo
o`;o0000?_ooool002Gooooo00?o0000ooooooooool0ooooool1ooooo`;o0000?_ooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000
ooooooooool0ooooool8ooooo`;o0000=oooool002Gooooo00?o0000ooooooooool0=_ooool2o`00
0<oooooo0_l0000gooooo`009Oooool00ol0003oooooooooo`0fooooo`;o0000ooooool9ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo4?ooool2o`00
033ooooo000Uooooo`03o`000?oooooooooo0?oooooo3oooool2o`00033ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo02kooooo0_l0003ooooooa7ooooo000Uooooo`03o`000?oooooooooo02ko
oooo0_l0003Vooooo`;o0000:?ooool002Gooooo00?o0000ooooooooool0oooooolGooooo`;o0000
:?ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`Co000000?o410@oooo
ooooool00oooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool2o`000?oooooo@_oo
ool001gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Moooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00?oEEEEofIVI_l00000
1oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`0Wooooo`;o0000oooooolHooooo`009?ooool2o`0002Wo
oooo0_l0003dooooo`;o00008Oooool002Cooooo0_l0003oooooob3ooooo0_l0000Qooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`03ooooo`;o0000oooooollooooo`009Oooool00ol0003ooooo
ooooo`03ooooo`;o0000oooooollooooo`006_ooool5o`0000Kooooo00?o0000ooooooooool0oooo
oom1ooooo`006_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool08?oo
ool2o`000?oooooo7oooool001_ooooo00?oV9RHob4Q8Oo^k^h01oooool2o`00027ooooo0_l0003o
oooooaoooooo000Looooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0oooooom1oooo
o`007Oooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05o`000?nj
^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`00
0?oooooo@_ooool002Gooooo00?o0000ooooooooool06Oooool2o`000?oooooo9_ooool002Gooooo
00?o0000ooooooooool06Oooool2o`000?oooooo9_ooool002Gooooo00?o0000ooooooooool04_oo
ool2o`000?oooooo;Oooool002Gooooo00?o0000ooooooooool02_ooool2o`0000Kooooo0_l0003o
ooooobgooooo000Uooooo`03o`000?oooooooooo00[ooooo0_l0003oooooocGooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oiRHV?l@413o0000oc8b<_o<
c<`01_ooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oa0@4?nj^[[oooooogMgMolb
<S801_ooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom1ooooo`007Oooool00onYZJWo410@ooooo`05ooooo`;o0000oooo
oom2ooooo`007?ooool00ol@413o0000okZj^P06ooooo`03o`000?oooooooooo0?oooooo@Oooool0
01gooooo00?o^[Zjob4Q8Oooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05
oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05
ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool001cooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo
000Jooooo`Go00001_ooool2o`000?oooooo@_ooool001[ooooo00CoA4A4omgMgOoooooo00001ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o
0000ooooooooool0oooooom1ooooo`006oooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooo
oooo0?oooooo@Oooool001_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`3ooooo
od7ooooo000Looooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`006oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom1ooooo`007_ooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03ogMgMolb<S;ooooo00Cooooo0_l0
003ooooood;ooooo000Kooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0oooooom9ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo1?l0003ooooood[ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Ioooo
o`05oiRHV?l0003o0000odA4A?nj^[X06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool2o`000003oa0@4?oooooooooo09?ooooo
002Iooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo09Co
oooo002Iooooo`03o`000?oooooooooo01[ooooo00Go410@oooooooooooooooooa0@400@ooooo`03
o`000?oooooooooo00Go0000UOooool009Wooooo00?o0000ooooooooool02oooool6o`0000Wooooo
00Go0000ooooooooooooooooo`00000?ooooo`08ogMgMolb<S;ooooooooooom4A4CogMgMooooool0
002Fooooo`00VOooool00ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool000003?oo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00CogMgMoeEEEOoooooo0000U_ooool009Oooooo
00?o410@o`000?l000000ol0000Iooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003o
ooooooooo`05ooooo`03ogMgMoo<c<co000009Kooooo002Iooooo`03o`000?oooooooooo01[ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Gooooo00?ok^k^odA4A?l0
0000U_ooool009Wooooo00?o0000ooooooooool06_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo1?l00005ooooo`03ogMgMol0003ooooo09Gooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .17162 Mdot
.04762 .2349 Mdot
.07143 .29033 Mdot
.09524 .28814 Mdot
.11905 .28397 Mdot
.14286 .27343 Mdot
.16667 .22697 Mdot
.19048 .13806 Mdot
.21429 .06389 Mdot
.2381 .02555 Mdot
.2619 .00956 Mdot
.28571 .00346 Mdot
.30952 .00122 Mdot
.33333 .00042 Mdot
.35714 .00014 Mdot
.38095 5e-05 Mdot
.40476 2e-05 Mdot
.42857 1e-05 Mdot
.45238 0 Mdot
.47619 0 Mdot
.5 0 Mdot
.52381 0 Mdot
.54762 0 Mdot
.57143 0 Mdot
.59524 0 Mdot
.61905 0 Mdot
.64286 1e-05 Mdot
.66667 2e-05 Mdot
.69048 4e-05 Mdot
.71429 .00011 Mdot
.7381 .00028 Mdot
.7619 .00065 Mdot
.78571 .00142 Mdot
.80952 .00295 Mdot
.83333 .00576 Mdot
.85714 .01063 Mdot
.88095 .01865 Mdot
.90476 .03149 Mdot
.92857 .05229 Mdot
.95238 .08889 Mdot
.97619 .17162 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`03ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Ko
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool07oooool002Gooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`03ooooo`;o0000@?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01;ooooo
0_l00005ooooo`;o0000:oooool00ol0003oooooooooo`0Oooooo`009Oooool00ol0003ooooooooo
o`14ooooo`;o0000Zoooool2o`0000Kooooo0_l00015ooooo`009Oooool00ol0003oooooooooo`14
ooooo`;o0000/oooool2o`0004Gooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0ooooool1ooooo`;o0000?_ooool002Gooooo00?o0000ooooooooool0
ooooool1ooooo`;o0000?_ooool002Gooooo0_l0000nooooo`;o0000ooooool2ooooo`009Oooool0
0ol0003oooooooooo`0mooooo`;o0000b?ooool2o`0003Oooooo000Uooooo`03o`000?oooooooooo
0?oooooo2?ooool2o`0003Oooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo3oooool2o`00033ooooo000Uooooo`03o`000?oooooooooo0?oooooo
3oooool2o`00033ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0=_ooool2o`000?oooooo2Oooool002Gooooo00?o0000ooooooooool0=_ooool2o`00
0?oooooo2Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooooaOooooo0_l0000Xooooo`009Ooo
ool00ol0003oooooooooo`3ooooooaOooooo0_l0000Xooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`Co000000?o410@oooo
ooooool00oooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool2o`000?oooooo@_oo
ool001gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Moooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00?oEEEEofIVI_l00000
1oooool00ol0003oooooooooo`0^ooooo`;o0000oooooolAooooo`009Oooool00ol0003ooooooooo
o`0^ooooo`;o0000oooooolAooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009?ooool2o`000?oooooo8?ooool2o`00027ooooo
000Tooooo`?o0000oooooolOooooo`;o00008Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooo
od;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0
003ooooood;ooooo000Uooooo`03o`000?oooooooooo02Oooooo0_l0003ooooooaSooooo000Uoooo
o`03o`000?oooooooooo02Oooooo0_l0003ooooooaSooooo000Uooooo`03o`000?oooooooooo00?o
oooo0_l0003ooooooccooooo000Uooooo`03o`000?oooooooooo00?ooooo0_l0003ooooooccooooo
000Jooooo`Go00001_ooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01_ooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03oiRHV?lQ8B7o
k^k^00Oooooo0_l0003ooooood;ooooo000Looooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000oooo
ooooool0oooooom1ooooo`007Oooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood7ooooo
000Jooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`3ooooood7ooooo
000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool2o`00027ooooo0_l0003ooooooaoooooo000Uooooo`03o`000?oooooooooo023o
oooo0_l0003ooooooaoooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool06Oooool2o`000?oooooo9_ooool002Gooooo00?o0000ooooooooool04_ooool2
o`0000Gooooo0_l0003oooooobKooooo000Uooooo`03o`000?oooooooooo00[ooooo0_l00006oooo
o`;o0000ooooool]ooooo`009Oooool00ol0003oooooooooo`0:ooooo`;o0000ooooooleooooo`00
9Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool001[ooooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001[ooooo00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood7ooooo
000Mooooo`03ojVYZOl@413ooooo00Gooooo0_l0003ooooood;ooooo000Looooo`03oa0@4?l0003o
^[Zj00Kooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00onj^[[o8B4Qooooo`05oooo
o`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go410@oiRHV?oooooo^[Zjo`000006oooo
o`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06oooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`007?ooool2o`000003
oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo1Ol00006ooooo`;o0000oooo
oom2ooooo`006_ooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo0?oooooo@Ooo
ool001[ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`3ooooood7ooooo000K
ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0oooooom1ooooo`006oooool00oo^
k^koA4A4o`000007ooooo`03o`000?oooooooooo0?oooooo@Oooool001cooooo00?oMgMgo`000?oo
ool01_ooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o
0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Kooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`3ooooood7ooooo000Nooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooom1ooooo`007oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo
@Oooool001kooooo00?oMgMgoc8b<_ooool01?ooool2o`000?oooooo@_ooool001_ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c03oooooodWooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool4o`000?ooooooB_ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool009gooooo00GoV9RHo`000?l0003oA4A4okZj^P0H
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@
olc<c02Iooooo`00WOooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00009ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@2Ioooo
o`00WOooool00ol0003oooooooooo`0Jooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0
003ooooooooooooooooo000009Wooooo002Mooooo`03o`000?oooooooooo00_ooooo1_l00009oooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q09Wooooo002M
ooooo`03o`000?oooooooooo01[ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mE
EEGo0000oa0@4?o<c<`0VOooool009_ooooo00?o410@o`000?l000000ol0000Iooooo`05oa0@4?oo
ooooooooooooool@41002oooool00omEEEGoQhN7ooooo`2Kooooo`00WOooool00ol0003ooooooooo
o`0Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV02Kooooo`00WOoo
ool00ol0003oooooooooo`0Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4
o`000?l@412Iooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.66) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .17318 Mdot
.04762 .23645 Mdot
.07143 .29204 Mdot
.09524 .29069 Mdot
.11905 .2882 Mdot
.14286 .2835 Mdot
.16667 .26659 Mdot
.19048 .20249 Mdot
.21429 .11109 Mdot
.2381 .04835 Mdot
.2619 .01882 Mdot
.28571 .00697 Mdot
.30952 .00252 Mdot
.33333 .0009 Mdot
.35714 .00031 Mdot
.38095 .00011 Mdot
.40476 4e-05 Mdot
.42857 1e-05 Mdot
.45238 0 Mdot
.47619 0 Mdot
.5 0 Mdot
.52381 0 Mdot
.54762 0 Mdot
.57143 0 Mdot
.59524 0 Mdot
.61905 0 Mdot
.64286 1e-05 Mdot
.66667 3e-05 Mdot
.69048 8e-05 Mdot
.71429 .00018 Mdot
.7381 .00042 Mdot
.7619 .00091 Mdot
.78571 .00189 Mdot
.80952 .0037 Mdot
.83333 .00687 Mdot
.85714 .01213 Mdot
.88095 .02048 Mdot
.90476 .03352 Mdot
.92857 .05428 Mdot
.95238 .09064 Mdot
.97619 .17318 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Ko
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Oooooo`009Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo00?ooooo
0_l00006ooooo`;o0000>?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01;ooooo
0_l00005ooooo`;o0000:oooool00ol0003oooooooooo`0Oooooo`009Oooool00ol0003ooooooooo
o`1;ooooo`;o0000Y?ooool2o`0004gooooo000Uooooo`03o`000?oooooooooo0?Wooooo0_l00015
ooooo`009Oooool00ol0003oooooooooo`3iooooo`;o0000AOooool002Gooooo00?o0000oooooooo
ool0A?ooool2o`000;[ooooo0_l0000nooooo`009Oooool00ol0003oooooooooo`14ooooo`;o0000
^_ooool2o`0003kooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo2?ooool2o`0003Oooooo000Uooooo`03
o`000?oooooooooo0?oooooo2?ooool2o`0003Oooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`;o0000?_ooool2o`000?oooooo0_ooool002Gooooo00?o0000oooooooo
ool0?Oooool2o`000<oooooo0_l0000`ooooo`009Oooool00ol0003oooooooooo`3oooooo`oooooo
0_l0000`ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0
003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo5oooool2o`0002Sooooo000Uooooo`03o`000?oooooooooo0?oooooo5ooo
ool2o`0002Sooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooo
od;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo03Kooooo0_l0003oooooo`Wooooo000Kooooo`Co000000?o410@ooooooooool00oooool00ol0
003oooooooooo`0fooooo`;o0000ooooool9ooooo`007Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo0_l0003ooooood;ooooo000M
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03oeEEEOmVIVKo000000Oooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Tooooo`;o0000oooooolPooooo`;o00008Oooool002Cooooo0ol0003ooooooaoooooo0_l0
000Qooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooooooo
ool0;_ooool2o`000?oooooo4Oooool002Gooooo00?o0000ooooooooool0;_ooool2o`000?oooooo
4Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooo
oom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`03ooooo`;o0000oooooollooooo`006_ooool5o`0000Kooooo00?o0000ooooooooool00ooo
ool2o`000?oooooo??ooool001[ooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oo
oooooooo0?oooooo@Oooool001_ooooo00?oV9RHob4Q8Oo^k^h01oooool2o`000?oooooo@_ooool0
01cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03
ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`007_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go0000okZj^_ooooooV9RH
oa0@4006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c006ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool09ooo
ool2o`000?oooooo6?ooool002Gooooo00?o0000ooooooooool09oooool2o`000?oooooo6?ooool0
02Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`0Pooooo`;o0000oooo
oolOooooo`009Oooool00ol0003oooooooooo`0Iooooo`;o00001Oooool2o`000?oooooo7oooool0
02Gooooo00?o0000ooooooooool02_ooool2o`0000Kooooo0_l00005ooooo`;o0000oooooolVoooo
o`009Oooool00ol0003oooooooooo`0:ooooo`;o00001_ooool2o`000?oooooo;Oooool002Gooooo
0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Jooooo`05oiRHV?l@413o0000oc8b<_o<c<`01_ooool00ol0003oooooooooo`3ooooood7o
oooo000Jooooo`05oa0@4?nj^[[oooooogMgMolb<S801_ooool00ol0003oooooooooo`3ooooood7o
oooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`007Ooo
ool00onYZJWo410@ooooo`05ooooo`;o0000oooooom2ooooo`007?ooool00ol@413o0000okZj^P06
ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o^[Zjob4Q8Oooool01Oooool00ol0
003oooooooooo`3ooooood7ooooo000Jooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0
003oooooooooo`3ooooood7ooooo000Jooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001cooooo0_l000000ol@413o
ooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`Go00001_ooool2o`000?oooooo@_oo
ool001[ooooo00CoA4A4omgMgOoooooo00001oooool00ol0003oooooooooo`3ooooood7ooooo000J
ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0oooooom1ooooo`006oooool0
0omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00?ok^k^odA4
A?l000001oooool00ol0003oooooooooo`3ooooood7ooooo000Looooo`03ogMgMol0003ooooo00Ko
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oo
oooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`006oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooom1ooooo`007_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooood7ooooo
000Nooooo`03ogMgMolb<S;ooooo00Cooooo0_l0003ooooood;ooooo000Kooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`0oooooom9ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo1?l0003ooooood[ooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo002Iooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0
0oooool01Oo^k^ko<S8bo`000?l@413oc<c<09Gooooo002Iooooo`05oa0@4?nj^[[ok^k^ogMgMol@
41002Oooool6o`0000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmE
EEGoMgMgoooooonHV9So8B4Q00?ooooo00GoEEEEogMgMoooooooV9RHob4Q8@2Eooooo`00VOooool0
0ol0003oooooooooo`0Jooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`00002Eooooo`00VOooool00ol0003ooooo
ooooo`0;ooooo`Ko00002Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oo
ooooV9RHob4Q8@03ooooo`05o`000?nHV9SooooooiRHV?lQ8B40UOooool009Wooooo00?o0000oooo
ooooool06_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<
c003ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0UOooool009Oooooo00?o410@o`000?l000000ol0
000Iooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`05ooooo`03oeEE
EOn7QhOooooo09Oooooo002Iooooo`03o`000?oooooooooo01[ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`03omgMgOl@413oV9RH00Gooooo00?ogMgMoa0@4?nHV9P0Uoooool009Wooooo00?o
0000ooooooooool06_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o
410@1?ooool01?o<c<coA4A4o`000?l@412Eooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.72) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .17442 Mdot
.04762 .23764 Mdot
.07143 .29336 Mdot
.09524 .29234 Mdot
.11905 .29097 Mdot
.14286 .28806 Mdot
.16667 .28238 Mdot
.19048 .25462 Mdot
.21429 .17458 Mdot
.2381 .08743 Mdot
.2619 .03628 Mdot
.28571 .01384 Mdot
.30952 .00509 Mdot
.33333 .00184 Mdot
.35714 .00065 Mdot
.38095 .00023 Mdot
.40476 8e-05 Mdot
.42857 3e-05 Mdot
.45238 1e-05 Mdot
.47619 0 Mdot
.5 0 Mdot
.52381 0 Mdot
.54762 0 Mdot
.57143 0 Mdot
.59524 0 Mdot
.61905 1e-05 Mdot
.64286 2e-05 Mdot
.66667 5e-05 Mdot
.69048 .00012 Mdot
.71429 .00027 Mdot
.7381 .00059 Mdot
.7619 .00122 Mdot
.78571 .00239 Mdot
.80952 .00448 Mdot
.83333 .00796 Mdot
.85714 .01353 Mdot
.88095 .02212 Mdot
.90476 .03526 Mdot
.92857 .05596 Mdot
.95238 .09208 Mdot
.97619 .17442 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Ko
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Oooooo`009Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo00_ooooo
0_l0000hooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool02oooool2o`0000Gooooo
0_l00005ooooo`;o0000:oooool00ol0003oooooooooo`0Oooooo`009Oooool00ol0003ooooooooo
o`3aooooo`;o0000COooool002Gooooo00?o0000ooooooooool0Boooool2o`000:cooooo0_l00015
ooooo`009Oooool00ol0003oooooooooo`1;ooooo`;o0000[?ooool2o`0004Gooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0ooooool1ooooo`;o0000
?_ooool002Gooooo0_l0003oooooo`;ooooo0_l0000nooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0A?ooool2o`000<7ooooo0_l0000gooooo`009Oooool00ol0003oooooooooo`14ooooo`;o0000
`Oooool2o`0003Oooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3oooooo`oooooo0_l0000`ooooo`009Ooo
ool00ol0003oooooooooo`3oooooo`oooooo0_l0000`ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooo
oom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0?Oooool2o`000?oooooo0_ooool002Gooooo
00?o0000ooooooooool0?Oooool2o`000?oooooo0_ooool002Gooooo00?o0000ooooooooool0oooo
oolGooooo`;o0000:?ooool002Gooooo00?o0000ooooooooool0oooooolGooooo`;o0000:?ooool0
02Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo1?l000000ol@413oooooooooo`03oooo
o`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`;o0000oooooom2ooooo`007Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0oooooom1ooooo`006oooool00omEEEGoIVIVo`000007ooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Tooooo`?o0000=oooool2o`000>Gooooo0_l0
000Qooooo`009?ooool2o`0003Sooooo0_l0003Uooooo`;o00008Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`03ooooo`;o0000
oooooollooooo`006_ooool5o`0000Kooooo00?o0000ooooooooool00oooool2o`000?oooooo??oo
ool001[ooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0?oooooo@Ooo
ool001_ooooo00?oV9RHob4Q8Oo^k^h01oooool2o`000?oooooo@_ooool001cooooo00?oV9RHob4Q
8Oo^k^h01_ooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0;_ooool2o`000?oooooo4Oooool001kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0^ooooo`;o0000oooooolAooooo`006_ooool01Ol0003o^[Zjoooo
oonHV9So410@00Kooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So410@o`00
0?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooo
od;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`0Wooooo`;o0000oooooolHooooo`009Oooool0
0ol0003oooooooooo`0Pooooo`;o00001Oooool2o`000?oooooo6?ooool002Gooooo00?o0000oooo
ooooool06Oooool2o`0000Gooooo0_l0003ooooooaoooooo000Uooooo`03o`000?oooooooooo00[o
oooo0_l00006ooooo`;o00001Oooool2o`000?oooooo9_ooool002Gooooo0_l0000;ooooo`;o0000
1_ooool2o`000?oooooo;Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool001[ooooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001[ooooo00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood7ooooo
000Mooooo`03ojVYZOl@413ooooo00Gooooo0_l0003ooooood;ooooo000Looooo`03oa0@4?l0003o
^[Zj00Kooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00onj^[[o8B4Qooooo`05oooo
o`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go410@oiRHV?oooooo^[Zjo`000006oooo
o`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06oooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`007?ooool2o`000003
oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo1Ol00006ooooo`;o0000oooo
oom2ooooo`006_ooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo0?oooooo@Ooo
ool001[ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`3ooooood7ooooo000K
ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0oooooom1ooooo`006oooool00oo^
k^koA4A4o`000007ooooo`03o`000?oooooooooo0?oooooo@Oooool001cooooo00?oMgMgo`000?oo
ool01_ooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o
0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Kooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`3ooooood7ooooo000Nooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooom1ooooo`007oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo
@Oooool001kooooo00?oMgMgoc8b<_ooool01?ooool2o`000?oooooo@_ooool001_ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c03oooooodWooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool4o`000?ooooooB_ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool009Wooooo00GoV9RHo`000?l0003oA4A4okZj^P0H
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool00ooo
ool5o`0009Gooooo002Iooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`03ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0UOooool009Wooooo00?o0000ooooooooool06_ooool01Ol@413ooooo
oooooooooooo410@00gooooo00?oZJVYoeEEEOooool01?ooool00onHV9So8B4Qonk^kP2Fooooo`00
VOooool00ol0003oooooooooo`0;ooooo`Ko00002Oooool01Ol0003ooooooooooooooooo000000ko
oooo00?o8B4Qooooooooool01?ooool00onHV9So8B4Qonk^kP2Eooooo`00VOooool00ol0003ooooo
ooooo`0Jooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`05ooooo`03
ogMgMomVIVKooooo09Cooooo002Gooooo`03oa0@4?l0003o000000?o00006Oooool01Ol@413ooooo
oooooooooooo410@00kooooo00?oZJVYogMgMoooool01_ooool00ol0003oooooooooo`2Cooooo`00
VOooool00ol0003oooooooooo`0Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413o
oooooooooooooooo<S8b00?ooooo00Go0000okZj^_ooooooV9RHoa0@402Eooooo`00VOooool00ol0
003oooooooooo`0Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000?ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c02Eooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.78) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .17543 Mdot
.04762 .23859 Mdot
.07143 .29438 Mdot
.09524 .2936 Mdot
.11905 .29264 Mdot
.14286 .29112 Mdot
.16667 .28776 Mdot
.19048 .27969 Mdot
.21429 .23666 Mdot
.2381 .14581 Mdot
.2619 .06765 Mdot
.28571 .02706 Mdot
.30952 .01017 Mdot
.33333 .00372 Mdot
.35714 .00134 Mdot
.38095 .00048 Mdot
.40476 .00017 Mdot
.42857 6e-05 Mdot
.45238 2e-05 Mdot
.47619 1e-05 Mdot
.5 0 Mdot
.52381 0 Mdot
.54762 0 Mdot
.57143 0 Mdot
.59524 1e-05 Mdot
.61905 1e-05 Mdot
.64286 3e-05 Mdot
.66667 8e-05 Mdot
.69048 .00018 Mdot
.71429 .00038 Mdot
.7381 .00079 Mdot
.7619 .00156 Mdot
.78571 .00293 Mdot
.80952 .00526 Mdot
.83333 .00901 Mdot
.85714 .01482 Mdot
.88095 .02359 Mdot
.90476 .03678 Mdot
.92857 .05738 Mdot
.95238 .09326 Mdot
.97619 .17543 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Ko
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool07oooool002Gooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`0Booooo`;o0000<Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo00_ooooo
0_l00005ooooo`;o0000<_ooool00ol0003oooooooooo`0Oooooo`009Oooool00ol0003ooooooooo
o`1Cooooo`;o0000W?ooool2o`0004gooooo000Uooooo`03o`000?oooooooooo05?ooooo0_l0002L
ooooo`;o00001_ooool2o`0004Gooooo000Uooooo`03o`000?oooooooooo0?Wooooo0_l00015oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
0Oooool2o`0003kooooo000Uooooo`;o0000C?ooool2o`000;?ooooo0_l0000nooooo`009Oooool0
0ol0003oooooooooo`1;ooooo`;o0000loooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3oooooo`Sooooo0_l0000gooooo`009Oooool00ol0003ooooo
ooooo`3oooooo`Sooooo0_l0000gooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0ooooool?ooooo`;o0000
<?ooool002Gooooo00?o0000ooooooooool0ooooool?ooooo`;o0000<?ooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`14ooooo`;o0000n_ooool002Go
oooo00?o0000ooooooooool0A?ooool2o`000?[ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oolGooooo`;o0000:?ooool002Gooooo00?o0000ooooooooool0oooooolGooooo`;o0000:?ooool0
02Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo1?l000000ol@413oooooooooo`03oooo
o`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`;o0000oooooom2ooooo`007Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0oooooom1ooooo`006oooool00omEEEGoIVIVo`000007ooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`0mooooo`;o0000ooooool2ooooo`009Oooool2o`0003kooooo0_l0003ooooo
o`;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Cooooo0ol0
003ooooooaoooooo0_l0000Qooooo`009?ooool2o`000?oooooo8?ooool2o`00027ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_oo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
0oooool2o`00037ooooo0_l0003oooooo`Wooooo000Jooooo`Go00001_ooool00ol0003ooooooooo
o`03ooooo`;o0000<Oooool2o`000?oooooo2Oooool001[ooooo00GoV9RHob4Q8Oo^k^koooooodA4
A006ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00?oV9RHob4Q8Oo^k^h01oooool2
o`000?oooooo@_ooool001cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3ooooo
od7ooooo000Mooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`00
7_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go
0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo02kooooo0_l0003ooooooa7ooooo000Uooooo`03o`000?oooooooooo02kooooo0_l0
003ooooooa7ooooo000Uooooo`03o`000?oooooooooo02Oooooo0_l0003ooooooaSooooo000Uoooo
o`03o`000?oooooooooo023ooooo0_l00005ooooo`;o0000oooooolHooooo`009Oooool00ol0003o
ooooooooo`0:ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o0000oooooolOooooo`00
9Oooool2o`0000_ooooo0_l00006ooooo`;o00001Oooool2o`000?oooooo9_ooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00GoV9RHoa0@4?l0003o
<S8bolc<c006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go410@okZj^_oooooo
MgMgoc8b<P06ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03ojVYZOl@413ooooo00Gooooo0_l0
003ooooood;ooooo000Looooo`03oa0@4?l0003o^[Zj00Kooooo00?o0000ooooooooool0oooooom1
ooooo`007Oooool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001[o
oooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[o
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_oo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oo
oooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`007?ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
@Oooool001[ooooo1Ol00006ooooo`;o0000oooooom2ooooo`006_ooool01?m4A4CogMgMooooool0
0007ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00CogMgMoeEEEOoooooo00001ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03ogMgMoo<c<co000000Oooooo00?o0000
ooooooooool0oooooom1ooooo`006oooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo
0?oooooo@Oooool001cooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003o
oooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`007oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo00?oMgMgoc8b<_ooool01?oo
ool2o`000?oooooo@_ooool001_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c03oooooodWooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool4o`000?ooooooB_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
09Wooooo00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Kooooo00?o0000onk^k_ooool00oooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<09Gooooo
002Iooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`03ooooo`05ob4Q8OnHV9SooooooiRH
V?lQ8B40UOooool009Wooooo00?o0000ooooooooool06_ooool01Ol@413ooooooooooooooooo410@
00gooooo00?oZJVYoeEEEOooool00oooool01Ol0003ooooooooooooooooo000009Gooooo002Ioooo
o`03o`000?oooooooooo00_ooooo1_l00009ooooo`05o`000?ooooooooooooooool000003_ooool0
0olQ8B7oooooooooo`02ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80UOooool009Wooooo00?o0000
ooooooooool06_ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00_oo
ool01Oo<c<co0000o`000?l0003oc<c<09Gooooo002Gooooo`03oa0@4?l0003o000000?o00006Ooo
ool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00_ooool01Ol@413o^[Zj
oooooonj^[[o410@09Gooooo002Iooooo`03o`000?oooooooooo01[ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S800oooool01Ol0003o^[Zjoooooonj^[[o
000009Gooooo002Iooooo`03o`000?oooooooooo01[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`Go00000oooool01OnYZJWo410@o`000?l@413oZJVY09Gooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.84) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .17627 Mdot
.04762 .23936 Mdot
.07143 .29518 Mdot
.09524 .29459 Mdot
.11905 .29383 Mdot
.14286 .29292 Mdot
.16667 .29107 Mdot
.19048 .28732 Mdot
.21429 .27398 Mdot
.2381 .21309 Mdot
.2619 .11849 Mdot
.28571 .05167 Mdot
.30952 .0201 Mdot
.33333 .00747 Mdot
.35714 .00272 Mdot
.38095 .00098 Mdot
.40476 .00035 Mdot
.42857 .00012 Mdot
.45238 4e-05 Mdot
.47619 2e-05 Mdot
.5 1e-05 Mdot
.52381 0 Mdot
.54762 0 Mdot
.57143 0 Mdot
.59524 1e-05 Mdot
.61905 2e-05 Mdot
.64286 5e-05 Mdot
.66667 .00011 Mdot
.69048 .00025 Mdot
.71429 .00051 Mdot
.7381 .00101 Mdot
.7619 .00192 Mdot
.78571 .00348 Mdot
.80952 .00603 Mdot
.83333 .01001 Mdot
.85714 .01602 Mdot
.88095 .02491 Mdot
.90476 .03812 Mdot
.92857 .0586 Mdot
.95238 .09426 Mdot
.97619 .17627 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo0_l00005ooooo`;o00001Oooool2o`0000Ko
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l0000=ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01oo
oooo000Uooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool04_ooool2o`0000Gooooo
0_l0000Zooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool02oooool2o`0000Gooooo
0_l0000booooo`03o`000?oooooooooo01oooooo000Uooooo`03o`000?oooooooooo05[ooooo0_l0
002>ooooo`;o00001Oooool2o`0004gooooo000Uooooo`03o`000?oooooooooo0?7ooooo0_l0001=
ooooo`009Oooool00ol0003oooooooooo`3iooooo`;o0000AOooool002Gooooo00?o0000oooooooo
ool0Doooool2o`000:Cooooo0_l00015ooooo`009Oooool00ol0003oooooooooo`1Cooooo`;o0000
Zoooool2o`0003kooooo000Uooooo`;o0000ooooool2ooooo`;o0000?_ooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo2?ooool2o`0003Oooooo000Uooooo`03o`000?oooooooooo0?oooooo
2?ooool2o`0003Oooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooooooo
ool0Boooool2o`000??ooooo000Uooooo`03o`000?oooooooooo04_ooooo0_l0003cooooo`009Ooo
ool00ol0003oooooooooo`3oooooo`oooooo0_l0000`ooooo`009Oooool00ol0003oooooooooo`3o
ooooo`oooooo0_l0000`ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooooaOooooo0_l0
000Xooooo`009Oooool00ol0003oooooooooo`3ooooooaOooooo0_l0000Xooooo`009Oooool2o`00
0?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`006oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooo
ooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Co
oooo0_l0003jooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Cooooo
0_l0003jooooo`007Oooool00ol0003oooooooooo`05ooooo`;o0000oooooom2ooooo`007Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0oooooom1ooooo`006oooool00omEEEGoIVIVo`000007ooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Tooooo`?o0000oooooolOooooo`;o00008Ooo
ool002Cooooo0_l0003oooooob3ooooo0_l0000Qooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0?Oooool2o`000?oooooo0_ooool002Gooooo00?o0000ooooooooool0?Oooool2o`000?oo
oooo0_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_oo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
0oooool2o`000?oooooo??ooool001[ooooo1Ol00006ooooo`03o`000?oooooooooo00?ooooo0_l0
003ooooooccooooo000Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003ooooooooo
o`3ooooood7ooooo000Kooooo`03oiRHV?lQ8B7ok^k^00Oooooo0_l0003ooooood;ooooo000Loooo
o`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00omgMgOo
IVIVooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05o`000?nj^[[ooooooiRHV?l@4100
1_ooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
1_ooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`0003Oooooo0_l0003ooooo
o`Wooooo000Uooooo`03o`000?oooooooooo03Kooooo0_l0003oooooo`Wooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`0^ooooo`;o0000oooooolAooooo`009Oooool00ol0003oooooooooo`0Woooo
o`;o00001Oooool2o`000?oooooo4Oooool002Gooooo00?o0000ooooooooool02_ooool2o`0000Ko
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l0003ooooooaSooooo000Uooooo`;o0000
2oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`000?oooooo7oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00GoV9RHoa0@4?l0003o
<S8bolc<c006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go410@okZj^_oooooo
MgMgoc8b<P06ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03ojVYZOl@413ooooo00Gooooo0_l0
003ooooood;ooooo000Looooo`03oa0@4?l0003o^[Zj00Kooooo00?o0000ooooooooool0oooooom1
ooooo`007Oooool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001[o
oooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[o
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_oo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oo
oooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`007?ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
@Oooool001[ooooo1Ol00006ooooo`;o0000oooooom2ooooo`006_ooool01?m4A4CogMgMooooool0
0007ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00CogMgMoeEEEOoooooo00001ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03ogMgMoo<c<co000000Oooooo00?o0000
ooooooooool0oooooom1ooooo`006oooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo
0?oooooo@Oooool001cooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003o
oooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`007oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo00?oMgMgoc8b<_ooool01?oo
ool2o`000?oooooo@_ooool001_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c03oooooodWooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool4o`000?ooooooB_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
09Wooooo00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c005ooooo`;o000000?o410@ooooooooool0
Toooool009Wooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002Oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0
003oooooooooo`2Dooooo`00VOooool00ol0003oooooooooo`0Jooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol0003ooooooooooooooooo000000?ooooo1Ol0002Eooooo`00VOooool00ol0
003oooooooooo`0;ooooo`Ko00002Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8b
oiRHV?ooooooV9RHoc8b<P03ooooo`04odA4A?oMgMgoooooo`0009Kooooo002Iooooo`03o`000?oo
oooooooo01[ooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<
c<`00oooool01?oMgMgoEEEEooooool0002Fooooo`00Uoooool00ol@413o0000o`000003o`0001Wo
oooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001?ooool0
0omgMgOoc<c<o`00002Fooooo`00VOooool00ol0003oooooooooo`0Jooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Cooooo00?ok^k^odA4A?l00000U_oo
ool009Wooooo00?o0000ooooooooool06_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
ZJVYoa0@4?l0003o410@ojVYZ@05ooooo`03ogMgMol0003ooooo09Gooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .17697 Mdot
.04762 .24 Mdot
.07143 .29585 Mdot
.09524 .29536 Mdot
.11905 .29478 Mdot
.14286 .29405 Mdot
.16667 .29314 Mdot
.19048 .29082 Mdot
.21429 .2865 Mdot
.2381 .26361 Mdot
.2619 .18565 Mdot
.28571 .09414 Mdot
.30952 .03911 Mdot
.33333 .01489 Mdot
.35714 .00548 Mdot
.38095 .00199 Mdot
.40476 .00072 Mdot
.42857 .00026 Mdot
.45238 9e-05 Mdot
.47619 3e-05 Mdot
.5 1e-05 Mdot
.52381 0 Mdot
.54762 0 Mdot
.57143 1e-05 Mdot
.59524 1e-05 Mdot
.61905 3e-05 Mdot
.64286 7e-05 Mdot
.66667 .00016 Mdot
.69048 .00033 Mdot
.71429 .00066 Mdot
.7381 .00127 Mdot
.7619 .00231 Mdot
.78571 .00404 Mdot
.80952 .00678 Mdot
.83333 .01095 Mdot
.85714 .01712 Mdot
.88095 .02609 Mdot
.90476 .03929 Mdot
.92857 .05966 Mdot
.95238 .09511 Mdot
.97619 .17697 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00003Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Oooooo`009Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Wooooo
0_l0000Zooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool01?ooool2o`0000Gooooo
0_l00005ooooo`;o0000<_ooool00ol0003oooooooooo`0Oooooo`009Oooool00ol0003ooooooooo
o`1Qooooo`;o0000Qoooool2o`0000Gooooo0_l0001=ooooo`009Oooool00ol0003oooooooooo`1J
ooooo`;o0000UOooool2o`0004gooooo000Uooooo`03o`000?oooooooooo05[ooooo0_l0002Moooo
o`;o0000AOooool002Gooooo00?o0000ooooooooool0nOooool2o`0004Gooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo0_l0003oooooo`;ooooo0_l0000nooooo`009Oooool0
0ol0003oooooooooo`3oooooo`7ooooo0_l0000nooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
Doooool2o`000;;ooooo0_l0000gooooo`009Oooool00ol0003oooooooooo`1Cooooo`;o0000/_oo
ool2o`0003Oooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooo
od;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3oooooo`oooooo0_l0000`ooooo`009Oooool0
0ol0003oooooooooo`3oooooo`oooooo0_l0000`ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`1;ooooo`;o0000loooool002Gooooo00?o0000ooooooooool0Boooool2o`000<Wooooo0_l0000X
ooooo`009Oooool2o`000?oooooo6?ooool2o`0002Sooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo1?l000000ol@
413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`;o0000oooo
oom2ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool0
01gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`006oooool00omEEEGoIVIV
o`000007ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooo
oom2ooooo`009?ooool2o`000?oooooo8?ooool2o`00027ooooo000Tooooo`;o0000oooooolPoooo
o`;o00008Oooool002Gooooo00?o0000ooooooooool0A?ooool2o`000?[ooooo000Uooooo`03o`00
0?oooooooooo04Cooooo0_l0003jooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool001[ooooo1Ol00006ooooo`03o`000?oooooooooo00?ooooo0_l0003ooooooccooooo000J
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`03ooooo`;o0000oooo
oollooooo`006oooool00onHV9So8B4Qonk^kP07ooooo`;o0000oooooom2ooooo`007?ooool00onH
V9So8B4Qonk^kP06ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?oMgMgofIVI_oo
ool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom1ooooo`006_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo
00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo
00?o0000ooooooooool0?Oooool2o`000?oooooo0_ooool002Gooooo00?o0000ooooooooool0?Ooo
ool2o`000?oooooo0_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`00
0?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0=_ooool2o`000?oooooo2Oooool002Gooooo00?o0000ooooooooool0;_ooool2o`00
00Kooooo0_l0003oooooo`Wooooo000Uooooo`03o`000?oooooooooo01;ooooo0_l00005ooooo`;o
00001Oooool2o`0000Gooooo0_l00005ooooo`;o0000oooooolAooooo`009Oooool2o`0000_ooooo
0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o0000oooooolHooooo`009Ooo
ool00ol0003oooooooooo`0:ooooo`;o0000ooooooleooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`00
0?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo
00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo
00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03ojVYZOl@
413ooooo00Gooooo0_l0003ooooood;ooooo000Looooo`03oa0@4?l0003o^[Zj00Kooooo00?o0000
ooooooooool0oooooom1ooooo`007Oooool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo
0?oooooo@Oooool001[ooooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooooooo
0?oooooo@Oooool001[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`007?ooool2o`000003oa0@4?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0?oooooo@Oooool001[ooooo1Ol00006ooooo`;o0000oooooom2ooooo`006_ooool0
1?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00CogMgM
oeEEEOoooooo00001oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03ogMgMoo<c<co
000000Oooooo00?o0000ooooooooool0oooooom1ooooo`006oooool00oo^k^koA4A4o`000007oooo
o`03o`000?oooooooooo0?oooooo@Oooool001cooooo00?oMgMgo`000?ooool01_ooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Kooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Nooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`00
7oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo00?o
MgMgoc8b<_ooool01?ooool2o`000?oooooo@_ooool001_ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c03oooooodWooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool4o`000?ooooooB_ooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool009gooooo00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Co410@o`000?m4A4Coc<c<V_ooool009gooooo00Go
410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B46ooooo`03oiRHV?l@413ogMgM09Wooooo002Mooooo`03o`000?oooooooooo01[ooooo
00Go410@oooooooooooooooooa0@400>ooooo`03ohN7QomEEEGooooo09Sooooo002Mooooo`03o`00
0?oooooooooo00_ooooo1_l00009ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co
8B4Qo`000?mEEEGo000009Wooooo002Mooooo`03o`000?oooooooooo01[ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`05ob4Q8On7QhOooooooiRHV?l00000VOooool009_ooooo00?o410@o`00
0?l000000ol0000Iooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooo
oooo000009Wooooo002Mooooo`03o`000?oooooooooo01[ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05ob4Q8OnHV9SoooooogMgMomEEED0VOooool009gooooo00?o0000ooooooooool06_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Goc<c<oa0@4?l0003o<S8bonk^kP2Iooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.96) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .17757 Mdot
.04762 .24055 Mdot
.07143 .2964 Mdot
.09524 .296 Mdot
.11905 .29554 Mdot
.14286 .29497 Mdot
.16667 .29428 Mdot
.19048 .29324 Mdot
.21429 .29045 Mdot
.2381 .28458 Mdot
.2619 .24743 Mdot
.28571 .15674 Mdot
.30952 .07349 Mdot
.33333 .0294 Mdot
.35714 .01102 Mdot
.38095 .00403 Mdot
.40476 .00146 Mdot
.42857 .00052 Mdot
.45238 .00019 Mdot
.47619 7e-05 Mdot
.5 2e-05 Mdot
.52381 1e-05 Mdot
.54762 1e-05 Mdot
.57143 1e-05 Mdot
.59524 2e-05 Mdot
.61905 5e-05 Mdot
.64286 .00011 Mdot
.66667 .00022 Mdot
.69048 .00043 Mdot
.71429 .00083 Mdot
.7381 .00154 Mdot
.7619 .00271 Mdot
.78571 .0046 Mdot
.80952 .00751 Mdot
.83333 .01185 Mdot
.85714 .01813 Mdot
.88095 .02716 Mdot
.90476 .04033 Mdot
.92857 .06058 Mdot
.95238 .09584 Mdot
.97619 .17757 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00003Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Oooooo`009Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo023ooooo
0_l0000Sooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool01?ooool2o`0000Gooooo
0_l00005ooooo`;o0000<_ooool00ol0003oooooooooo`0Oooooo`009Oooool00ol0003ooooooooo
o`1Qooooo`;o0000Qoooool2o`0000Gooooo0_l0001=ooooo`009Oooool00ol0003oooooooooo`1Q
ooooo`;o0000S_ooool2o`0004gooooo000Uooooo`03o`000?oooooooooo0?Wooooo0_l00015oooo
o`009Oooool00ol0003oooooooooo`3iooooo`;o0000AOooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo0_ooool2o`0003kooooo000Uooooo`03o`000?oooooo
oooo05[ooooo0_l0002Tooooo`;o0000?_ooool002Gooooo00?o0000ooooooooool0F_ooool2o`00
0>Cooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
ooooool8ooooo`;o0000=oooool002Gooooo00?o0000ooooooooool0ooooool8ooooo`;o0000=ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo3oooool2o`00033ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo3oooool2o`00033ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`1Cooooo`;o0000
joooool002Gooooo0_l0001Dooooo`;o0000joooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo5oooool2o`0002Sooooo000Uoooo
o`;o0000oooooolHooooo`;o0000:?ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`006oooool4o`000003oa0@4?oooooooooo
00?ooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo0_l0003ooooood;ooooo000M
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03oeEEEOmVIVKo000000Oooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0Boooool2o`000??ooooo
000Uooooo`03o`000?oooooooooo04_ooooo0_l0003cooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooo
oom2ooooo`009?ooool2o`000?oooooo8?ooool2o`00027ooooo000Tooooo`;o0000oooooolPoooo
o`;o00008Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`006_oo
ool5o`0000Kooooo00?o0000ooooooooool00oooool2o`000?oooooo??ooool001[ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo00?ooooo0_l0003ooooooccooooo000K
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0_l00015ooooo`;o0000n_ooool001cooooo00?oV9RHob4Q
8Oo^k^h01_ooool00ol0003oooooooooo`14ooooo`;o0000n_ooool001gooooo00?oMgMgofIVI_oo
ool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom1ooooo`006_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo
00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`0mooooo`;o0000ooooool2ooooo`009Oooool00ol0003oooooooooo`0m
ooooo`;o0000ooooool2ooooo`009Oooool00ol0003oooooooooo`0fooooo`;o0000ooooool9oooo
o`009Oooool00ol0003oooooooooo`0Pooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o
0000ooooool9ooooo`009Oooool2o`0000_ooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo
0_l00005ooooo`;o00001Oooool2o`000?oooooo4Oooool002Gooooo00?o0000ooooooooool02_oo
ool2o`0000Kooooo0_l00005ooooo`;o0000oooooolVooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`00
0?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo
00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo
00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03ojVYZOl@
413ooooo00Gooooo0_l0003ooooood;ooooo000Looooo`03oa0@4?l0003o^[Zj00Kooooo00?o0000
ooooooooool0oooooom1ooooo`007Oooool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo
0?oooooo@Oooool001[ooooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooooooo
0?oooooo@Oooool001[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`007?ooool2o`000003oa0@4?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0?oooooo@Oooool001[ooooo1Ol00006ooooo`;o0000oooooom2ooooo`006_ooool0
1?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00CogMgM
oeEEEOoooooo00001oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03ogMgMoo<c<co
000000Oooooo00?o0000ooooooooool0oooooom1ooooo`006oooool00oo^k^koA4A4o`000007oooo
o`03o`000?oooooooooo0?oooooo@Oooool001cooooo00?oMgMgo`000?ooool01_ooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Kooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Nooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`00
7oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo00?o
MgMgoc8b<_ooool01?ooool2o`000?oooooo@_ooool001_ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c03oooooodWooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool4o`000?ooooooB_ooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool009Wooooo00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Co410@o`000?m4A4Coc<c<1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<09Gooooo002Iooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00onHV9So410@omgMg@03oooo
o`05oeEEEOmgMgOooooooiRHV?lQ8B40UOooool009Wooooo00?o0000ooooooooool06_ooool01Ol@
413ooooooooooooooooo410@00kooooo00?oQhN7oeEEEOooool00_ooool01Ol0003ooooooooooooo
oooo000009Gooooo002Iooooo`03o`000?oooooooooo00_ooooo1_l00009ooooo`05o`000?oooooo
ooooooooool000002oooool01Oo<c<co8B4Qo`000?mEEEGo000000?ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@2Eooooo`00VOooool00ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool0
00002oooool01OlQ8B7oQhN7oooooonHV9So000000?ooooo00Go0000oeEEEOl0003o410@olc<c02E
ooooo`00Uoooool00ol@413o0000o`000003o`0001Wooooo00Go410@oooooooooooooooooa0@400;
ooooo`05o`000?ooooooooooooooool000000oooool00omEEEGoQhN7ooooo`2Gooooo`00VOooool0
0ol0003oooooooooo`0Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01OlQ8B7oV9RHoooo
oomgMgOoEEEE00?ooooo00?ogMgMoa0@4?nHV9P0Uoooool009Wooooo00?o0000ooooooooool06_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Goc<c<oa0@4?l0003o<S8bonk^kP04ooooo`04
olc<c?m4A4Co0000oa0@49Gooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.02) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .17809 Mdot
.04762 .24101 Mdot
.07143 .29687 Mdot
.09524 .29653 Mdot
.11905 .29615 Mdot
.14286 .2957 Mdot
.16667 .29514 Mdot
.19048 .2945 Mdot
.21429 .29316 Mdot
.2381 .29001 Mdot
.2619 .28027 Mdot
.28571 .22541 Mdot
.30952 .1287 Mdot
.33333 .0566 Mdot
.35714 .02199 Mdot
.38095 .00814 Mdot
.40476 .00296 Mdot
.42857 .00107 Mdot
.45238 .00038 Mdot
.47619 .00014 Mdot
.5 5e-05 Mdot
.52381 2e-05 Mdot
.54762 1e-05 Mdot
.57143 2e-05 Mdot
.59524 3e-05 Mdot
.61905 7e-05 Mdot
.64286 .00014 Mdot
.66667 .00029 Mdot
.69048 .00055 Mdot
.71429 .00102 Mdot
.7381 .00182 Mdot
.7619 .00312 Mdot
.78571 .00516 Mdot
.80952 .00822 Mdot
.83333 .01268 Mdot
.85714 .01906 Mdot
.88095 .02813 Mdot
.90476 .04126 Mdot
.92857 .06139 Mdot
.95238 .09648 Mdot
.97619 .17809 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02_ooool2o`0000Ko
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l0000=ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01oo
oooo000Uooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool08?ooool2o`0000Gooooo
0_l0000Looooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool01?ooool2o`0000Gooooo
0_l00005ooooo`;o0000<_ooool00ol0003oooooooooo`0Oooooo`009Oooool00ol0003ooooooooo
o`1Xooooo`;o0000P?ooool2o`0005Cooooo000Uooooo`03o`000?oooooooooo0?7ooooo0_l0001=
ooooo`009Oooool00ol0003oooooooooo`3aooooo`;o0000COooool002Gooooo00?o0000oooooooo
ool0nOooool2o`0004Gooooo000Uooooo`03o`000?oooooooooo067ooooo0_l0002Fooooo`;o0000
AOooool002Gooooo0_l0001Rooooo`;o0000WOooool2o`0003kooooo000Uooooo`03o`000?oooooo
oooo0?oooooo0Oooool2o`0003kooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3oooooo`Sooooo
0_l0000gooooo`009Oooool00ol0003oooooooooo`3oooooo`Sooooo0_l0000gooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo05[ooooo0_l0003Tooooo`009Ooo
ool00ol0003oooooooooo`1Jooooo`;o0000/_ooool2o`00033ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo3oooool2o`00033ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooolGooooo`;o0000:?ooool002Gooooo0_l0003ooooo
oaSooooo0_l0000Xooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Kooooo`Co000000?o410@ooooooooool00oooool00ol0
003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
@Oooool001gooooo00?o0000ooooooooool01Oooool2o`000?oooooo@_ooool001gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1Cooooo`;o0000joooool001gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`1Cooooo`;o0000joooool001gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03oeEEEOmVIVKo000000Oooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000T
ooooo`;o0000oooooolPooooo`;o00008Oooool002Cooooo0_l0003oooooob3ooooo0_l0000Qoooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`;o0000C?ooool2o`000??ooooo000Uooooo`03o`000?oooooo
oooo04_ooooo0_l0003cooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`006_oo
ool5o`0000Kooooo00?o0000ooooooooool00oooool2o`000?oooooo??ooool001[ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo00?ooooo0_l0003ooooooccooooo000K
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0_l0003ooooood;ooooo000Looooo`03oiRHV?lQ8B7ok^k^
00Kooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00omgMgOoIVIVooooo`05ooooo`03
o`000?oooooooooo0?oooooo@Oooool001kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3ooooood7ooooo000Jooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003ooooo
ooooo`3ooooood7ooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`14ooooo`;o0000n_ooool002Gooooo00?o
0000ooooooooool0A?ooool2o`000?[ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0?Oooool2o`000?oooooo0_ooool002Gooooo00?o0000oooooooo
ool09oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`000?oooooo0_ooool002Gooooo
0_l0000;ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo
0_l00006ooooo`;o0000ooooool9ooooo`009Oooool00ol0003oooooooooo`0:ooooo`;o00001_oo
ool2o`0000Gooooo0_l00005ooooo`;o0000oooooolOooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`00
0?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo
00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo
00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03ojVYZOl@
413ooooo00Gooooo0_l0003ooooood;ooooo000Looooo`03oa0@4?l0003o^[Zj00Kooooo00?o0000
ooooooooool0oooooom1ooooo`007Oooool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo
0?oooooo@Oooool001[ooooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooooooo
0?oooooo@Oooool001[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`007?ooool2o`000003oa0@4?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0?oooooo@Oooool001[ooooo1Ol00006ooooo`;o0000oooooom2ooooo`006_ooool0
1?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00CogMgM
oeEEEOoooooo00001oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03ogMgMoo<c<co
000000Oooooo00?o0000ooooooooool0oooooom1ooooo`006oooool00oo^k^koA4A4o`000007oooo
o`03o`000?oooooooooo0?oooooo@Oooool001cooooo00?oMgMgo`000?ooool01_ooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Kooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Nooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`00
7oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo00?o
MgMgoc8b<_ooool01?ooool2o`000?oooooo@_ooool001_ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c03oooooodWooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool4o`000?ooooooB_ooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool009Wooooo00GoV9RHo`000?l0003oA4A4okZj^P0Iooooo`Co000000?o410@
ooooooooool00_ooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`Go0000UOoo
ool009Wooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003ooooooooo
o`04ooooo`;o8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A02Eooooo`00VOooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00[ooooo
00Go410@oooooooooooooooooa0@4004ooooo`03oiRHV?lQ8B7ok^k^09Kooooo002Iooooo`03o`00
0?oooooooooo00_ooooo1_l0000<ooooo`03o`000?oooooooooo00[ooooo00Go0000oooooooooooo
ooooo`000005ooooo`03oiRHV?lQ8B7ok^k^09Gooooo002Iooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000Kooooo00?oMgMgofIVI_oo
ool0U?ooool009Oooooo00?o410@o`000?l000000ol0000Looooo`03o`000?oooooooooo00[ooooo
00Go410@oooooooooooooooooa0@4007ooooo`03o`000?oooooooooo09?ooooo002Iooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool02_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00Go0000okZj^_ooooooV9RHoa0@402Eooooo`00VOooool00ol0003oooooooooo`0Kooooo`03
oeEEEOmVIVKo000000cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`0UOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.08) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .17854 Mdot
.04762 .24142 Mdot
.07143 .29728 Mdot
.09524 .29699 Mdot
.11905 .29666 Mdot
.14286 .29629 Mdot
.16667 .29586 Mdot
.19048 .29531 Mdot
.21429 .29469 Mdot
.2381 .29288 Mdot
.2619 .28942 Mdot
.28571 .27192 Mdot
.30952 .19887 Mdot
.33333 .10326 Mdot
.35714 .04315 Mdot
.38095 .0164 Mdot
.40476 .00602 Mdot
.42857 .00218 Mdot
.45238 .00079 Mdot
.47619 .00028 Mdot
.5 .0001 Mdot
.52381 4e-05 Mdot
.54762 2e-05 Mdot
.57143 3e-05 Mdot
.59524 5e-05 Mdot
.61905 9e-05 Mdot
.64286 .00019 Mdot
.66667 .00036 Mdot
.69048 .00068 Mdot
.71429 .00122 Mdot
.7381 .00212 Mdot
.7619 .00354 Mdot
.78571 .0057 Mdot
.80952 .0089 Mdot
.83333 .01347 Mdot
.85714 .01992 Mdot
.88095 .02901 Mdot
.90476 .04209 Mdot
.92857 .0621 Mdot
.95238 .09704 Mdot
.97619 .17854 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`04ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l00006ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool07oooool002Gooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`0Wooooo`;o00001_ooool2o`0001Cooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`04ooooo`;o00001Oooool2o`0003Wooooo00?o0000ooooooooool07oooool002Gooooo00?o
0000ooooooooool0Koooool2o`0007;ooooo0_l00005ooooo`;o0000E?ooool002Gooooo00?o0000
ooooooooool0j_ooool2o`0000Gooooo0_l0001=ooooo`009Oooool00ol0003oooooooooo`1Xoooo
o`;o0000Qoooool2o`0004gooooo000Uooooo`03o`000?oooooooooo06Sooooo0_l0002?ooooo`;o
0000AOooool002Gooooo00?o0000ooooooooool0nOooool2o`0004Gooooo000Uooooo`;o0000oooo
oom2ooooo`009Oooool00ol0003oooooooooo`3oooooo`7ooooo0_l0000nooooo`009Oooool00ol0
003oooooooooo`3oooooo`7ooooo0_l0000nooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0HOoo
ool2o`000:Cooooo0_l0000gooooo`009Oooool00ol0003oooooooooo`1Qooooo`;o0000Y?ooool2
o`0003Oooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3oooooo`oooooo0_l0000`ooooo`009Oooool00ol0
003oooooooooo`3oooooo`oooooo0_l0000`ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooooaOooooo0_l0000Xooooo`009Oooool2o`000?oooooo6?ooool2o`0002Sooooo000Uooooo`03
o`000?oooooooooo05[ooooo0_l0003Tooooo`009Oooool00ol0003oooooooooo`1Jooooo`;o0000
i?ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Kooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooo
od7ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`00
7Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o
0000ooooooooool01Oooool2o`000?oooooo@_ooool001gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Cooooo0_l0003oooooob3ooooo0_l0000Q
ooooo`009?ooool2o`000?oooooo8?ooool2o`00027ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0001Doooo
o`;o0000joooool002Gooooo00?o0000ooooooooool0Doooool2o`000>_ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`Go00001_ooool00ol0003ooooooooo
o`03ooooo`;o0000oooooollooooo`006_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o
0000ooooooooool00oooool2o`000?oooooo??ooool001_ooooo00?oV9RHob4Q8Oo^k^h01oooool2
o`000?oooooo@_ooool001cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3ooooo
od7ooooo000Mooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`00
7_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go
0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`1;ooooo`;o0000loooool0
02Gooooo0_l0001<ooooo`;o0000loooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`14oooo
o`;o0000n_ooool002Gooooo00?o0000ooooooooool0;_ooool2o`0000Kooooo0_l00005ooooo`;o
00001Oooool2o`000?[ooooo000Uooooo`;o00002oooool2o`0000Kooooo0_l00005ooooo`;o0000
1Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l0003oooooo`;ooooo
000Uooooo`03o`000?oooooooooo00[ooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l0
0005ooooo`;o0000oooooolHooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00GoV9RHoa0@4?l0003o
<S8bolc<c006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go410@okZj^_oooooo
MgMgoc8b<P06ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03ojVYZOl@413ooooo00Gooooo0_l0
003ooooood;ooooo000Looooo`03oa0@4?l0003o^[Zj00Kooooo00?o0000ooooooooool0oooooom1
ooooo`007Oooool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001[o
oooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[o
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_oo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oo
oooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`007?ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
@Oooool001[ooooo1Ol00006ooooo`;o0000oooooom2ooooo`006_ooool01?m4A4CogMgMooooool0
0007ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00CogMgMoeEEEOoooooo00001ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03ogMgMoo<c<co000000Oooooo00?o0000
ooooooooool0oooooom1ooooo`006oooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo
0?oooooo@Oooool001cooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003o
oooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`007oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo00?oMgMgoc8b<_ooool01?oo
ool2o`000?oooooo@_ooool001_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c03oooooodWooooo000K
ooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;oooo
o`006oooool4o`000?ooooooB_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
09Wooooo00GoV9RHo`000?l0003oA4A4okZj^P0Iooooo`Co000000?o410@ooooooooool00_ooool2
ob4Q8@Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0
UOooool009Wooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003ooooo
ooooo`04ooooo`;o8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go8B4QoiRHV?oo
ooooV9RHob4Q8@2Eooooo`00VOooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00[o
oooo00Go410@oooooooooooooooooa0@4003ooooo`05o`000?ooooooooooooooool00000UOooool0
09Wooooo00?o0000ooooooooool02oooool6o`0000cooooo00?o0000ooooooooool02_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P2Eooooo`00VOooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05olc<c?l0003o0000o`000?o<c<`0UOooool009Oooooo00?o410@o`000?l000000ol0
000Looooo`03o`000?oooooooooo00[ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@
4?nj^[[ooooookZj^_l@4100UOooool009Wooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0:ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Ol0003o^[Zjoooooonj^[[o0000
09Gooooo002Iooooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000003?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2Eooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.14) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .17894 Mdot
.04762 .24177 Mdot
.07143 .29763 Mdot
.09524 .29738 Mdot
.11905 .2971 Mdot
.14286 .29678 Mdot
.16667 .29643 Mdot
.19048 .296 Mdot
.21429 .29548 Mdot
.2381 .29478 Mdot
.2619 .29245 Mdot
.28571 .28818 Mdot
.30952 .25809 Mdot
.33333 .17002 Mdot
.35714 .08132 Mdot
.38095 .03265 Mdot
.40476 .0122 Mdot
.42857 .00444 Mdot
.45238 .0016 Mdot
.47619 .00058 Mdot
.5 .00021 Mdot
.52381 8e-05 Mdot
.54762 4e-05 Mdot
.57143 4e-05 Mdot
.59524 6e-05 Mdot
.61905 .00012 Mdot
.64286 .00024 Mdot
.66667 .00045 Mdot
.69048 .00082 Mdot
.71429 .00144 Mdot
.7381 .00242 Mdot
.7619 .00395 Mdot
.78571 .00624 Mdot
.80952 .00954 Mdot
.83333 .01421 Mdot
.85714 .02072 Mdot
.88095 .02981 Mdot
.90476 .04283 Mdot
.92857 .06275 Mdot
.95238 .09754 Mdot
.97619 .17894 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`04ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l00006ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool07oooool002Gooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`0_ooooo`;o00005?ooool00ol0003oooooooooo`15ooooo`;o00001Oooool2o`0000Gooooo
0_l0000iooooo`03o`000?oooooooooo01oooooo000Uooooo`03o`000?oooooooooo0>?ooooo0_l0
0005ooooo`;o0000E?ooool002Gooooo00?o0000ooooooooool0Koooool2o`0007Wooooo0_l00005
ooooo`;o0000COooool002Gooooo00?o0000ooooooooool0Koooool2o`00083ooooo0_l0001=oooo
o`009Oooool00ol0003oooooooooo`3iooooo`;o0000AOooool002Gooooo00?o0000ooooooooool0
nOooool2o`0004Gooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3o
ooooo`7ooooo0_l0000nooooo`009Oooool00ol0003oooooooooo`1Xooooo`;o0000U_ooool2o`00
03kooooo000Uooooo`03o`000?oooooooooo06Sooooo0_l0003Fooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo2?ooool2o`0003Oooooo000U
ooooo`03o`000?oooooooooo0?oooooo2?ooool2o`0003Oooooo000Uooooo`;o0000oooooom2oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
ooooo`oooooo0_l0000`ooooo`009Oooool00ol0003oooooooooo`3oooooo`oooooo0_l0000`oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0HOooool2o`000=gooooo000Uooooo`03o`000?oooooooooo067o
oooo0_l0003Mooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooolGooooo`;o0000:?ooool0
02Gooooo0_l0003ooooooaSooooo0_l0000Xooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`Co000000?o410@oooo
ooooool00oooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool2o`000?oooooo@_oo
ool001gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Moooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00?oEEEEofIVI_l00000
1oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo05[o
oooo0_l0003Tooooo`009Oooool00ol0003oooooooooo`1Jooooo`;o0000i?ooool002Gooooo0_l0
003ooooood;ooooo000Tooooo`;o0000oooooolPooooo`;o00008Oooool002Cooooo0_l0003ooooo
ob3ooooo0_l0000Qooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Jooooo`Go00001_ooool00ol0003oooooooooo`03ooooo`;o0000oooooollooooo`006_ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool00oooool2o`000?oooooo??oo
ool001_ooooo00?oV9RHob4Q8Oo^k^h01oooool2o`000?oooooo@_ooool001cooooo00?oV9RHob4Q
8Oo^k^h01_ooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0oooooom1ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo05?ooooo0_l0003[ooooo`006_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo
00?o0000ooooooooool0Doooool2o`000>_ooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
1_ooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0Boooool2
o`000??ooooo000Uooooo`03o`000?oooooooooo04_ooooo0_l0003cooooo`009Oooool00ol0003o
ooooooooo`0mooooo`;o00001Oooool2o`000?[ooooo000Uooooo`;o00002oooool2o`0000Kooooo
0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo
0_l00005ooooo`;o0000n_ooool002Gooooo00?o0000ooooooooool02_ooool2o`0000Kooooo0_l0
0005ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`000?oooooo2Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000
oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Jooooo`05oiRHV?l@413o0000oc8b<_o<c<`01_ooool00ol0003o
ooooooooo`3ooooood7ooooo000Jooooo`05oa0@4?nj^[[oooooogMgMolb<S801_ooool00ol0003o
ooooooooo`3ooooood7ooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom1ooooo`007Oooool00onYZJWo410@ooooo`05ooooo`;o0000oooooom2ooooo`007?ooool0
0ol@413o0000okZj^P06ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o^[Zjob4Q
8Oooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oa0@4?nHV9SooooookZj
^_l000001_ooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05ojVYZOl@413o0000oa0@
4?nYZJT01_ooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_oo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oo
oooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001co
oooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`Go00001_oo
ool2o`000?oooooo@_ooool001[ooooo00CoA4A4omgMgOoooooo00001oooool00ol0003ooooooooo
o`3ooooood7ooooo000Jooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0oooo
oom1ooooo`006oooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo0?oooooo@Oooool0
01_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`3ooooood7ooooo000Looooo`03
ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003o
oooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`006oooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0oooooom1ooooo`007_ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo0?oooooo@Oooool001oooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Nooooo`03ogMgMolb<S;ooooo00Cooooo0_l0003ooooood;ooooo000K
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0oooooom9ooooo`006oooool00ol0003oooooooooo`3o
oooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo1?l0003ooooood[o
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Iooooo`05oiRHV?l0003o0000
odA4A?nj^[X06Oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`Co000000?o410@
ooooooooool00_ooool2o`000003oa0@4?oooooooooo09?ooooo002Iooooo`05oa0@4?nj^[[ok^k^
ogMgMol@41002Oooool6o`0000cooooo00?o0000ooooooooool01?ooool2ob4Q8@Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2Dooooo`00VOooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool5o`0009Gooooo002Iooooo`03
o`000?oooooooooo00_ooooo1_l0000<ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool00_ooool01?m4A4CogMgMooooool0002Fooooo`00VOooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool01?oMgMgoEEEEooooool0002Foooo
o`00Uoooool00ol@413o0000o`000003o`0001cooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`03ooooo`03ogMgMoo<c<co000009Kooooo002Iooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`03onk^k_m4A4Co000009Kooooo
002Iooooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000003Oooool00omEEEGoIVIVo`00
0006ooooo`03ogMgMol0003ooooo09Gooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .1793 Mdot
.04762 .24208 Mdot
.07143 .29793 Mdot
.09524 .29772 Mdot
.11905 .29747 Mdot
.14286 .29721 Mdot
.16667 .2969 Mdot
.19048 .29656 Mdot
.21429 .29613 Mdot
.2381 .29566 Mdot
.2619 .29472 Mdot
.28571 .29198 Mdot
.30952 .28522 Mdot
.33333 .23828 Mdot
.35714 .14127 Mdot
.38095 .06311 Mdot
.40476 .02457 Mdot
.42857 .00907 Mdot
.45238 .00328 Mdot
.47619 .00118 Mdot
.5 .00043 Mdot
.52381 .00016 Mdot
.54762 7e-05 Mdot
.57143 6e-05 Mdot
.59524 9e-05 Mdot
.61905 .00016 Mdot
.64286 .0003 Mdot
.66667 .00055 Mdot
.69048 .00097 Mdot
.71429 .00166 Mdot
.7381 .00274 Mdot
.7619 .00437 Mdot
.78571 .00676 Mdot
.80952 .01016 Mdot
.83333 .0149 Mdot
.85714 .02145 Mdot
.88095 .03054 Mdot
.90476 .04351 Mdot
.92857 .06332 Mdot
.95238 .09798 Mdot
.97619 .1793 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000Kooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Oooooo`009Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo03Kooooo
0_l0000=ooooo`03o`000?oooooooooo04Gooooo0_l00005ooooo`;o00001Oooool2o`0003Wooooo
00?o0000ooooooooool07oooool002Gooooo00?o0000ooooooooool0Moooool2o`0006[ooooo0_l0
0005ooooo`;o0000E?ooool002Gooooo00?o0000ooooooooool0Moooool2o`00077ooooo0_l00005
ooooo`;o0000COooool002Gooooo00?o0000ooooooooool0lOooool2o`0004gooooo000Uooooo`03
o`000?oooooooooo0?Wooooo0_l00015ooooo`009Oooool00ol0003oooooooooo`1_ooooo`;o0000
R?ooool2o`0004Gooooo000Uooooo`;o0000L?ooool2o`000<oooooo000Uooooo`03o`000?oooooo
oooo0?oooooo0Oooool2o`0003kooooo000Uooooo`03o`000?oooooooooo0?oooooo0Oooool2o`00
03kooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3oooooo`Sooooo0_l0000gooooo`009Oooool0
0ol0003oooooooooo`3oooooo`Sooooo0_l0000gooooo`009Oooool2o`000?oooooo@_ooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0J?ooool2
o`000:Cooooo0_l0000`ooooo`009Oooool00ol0003oooooooooo`1Xooooo`;o0000Y?ooool2o`00
033ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooo
oaSooooo0_l0000Xooooo`009Oooool00ol0003oooooooooo`3ooooooaOooooo0_l0000Xooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`006oooool4o`000003oa0@4?oooooooooo
00?ooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo0_l0003ooooood;ooooo000M
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03oeEEEOmVIVKo000000Oooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`1Qooooo`;o0000gOoo
ool002Gooooo00?o0000ooooooooool0HOooool2o`000=gooooo000Uooooo`;o0000oooooom2oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooo
oom2ooooo`009?ooool2o`000?oooooo8?ooool2o`00027ooooo000Tooooo`;o0000oooooolPoooo
o`;o00008Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0F_ooool2o`000>Cooooo
000Jooooo`Go00001_ooool00ol0003oooooooooo`03ooooo`;o0000EOooool2o`000>Cooooo000J
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`03ooooo`;o0000oooo
oollooooo`006oooool00onHV9So8B4Qonk^kP07ooooo`;o0000oooooom2ooooo`007?ooool00onH
V9So8B4Qonk^kP06ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?oMgMgofIVI_oo
ool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom1ooooo`006_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo
00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`1Cooooo`;o0000joooool002Gooooo00?o0000ooooooooool0Doooool2
o`000>_ooooo000Uooooo`03o`000?oooooooooo04_ooooo0_l0003cooooo`009Oooool00ol0003o
ooooooooo`14ooooo`;o00001Oooool2o`000??ooooo000Uooooo`;o00002oooool2o`0000Kooooo
0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo
0_l00005ooooo`;o0000n_ooool002Gooooo00?o0000ooooooooool02_ooool2o`0000Kooooo0_l0
0005ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l0
003oooooo`;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So410@o`000?lb<S;oc<c<00Ko
oooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Ko
oooo00?o0000ooooooooool0oooooom1ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo0?oooooo@Oooool001gooooo00?oZJVYoa0@4?ooool01Oooool2o`000?oooooo@_oo
ool001cooooo00?o410@o`000?nj^[X01_ooool00ol0003oooooooooo`3ooooood7ooooo000Moooo
o`03okZj^_lQ8B7ooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01Ol@413o
V9RHoooooonj^[[o000000Kooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnYZJWo
410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0
003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Looooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3ooooood7o
oooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`006_oo
ool5o`0000Kooooo0_l0003ooooood;ooooo000Jooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o
0000ooooooooool0oooooom1ooooo`006_ooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oo
oooooooo0?oooooo@Oooool001_ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3o
oooood7ooooo000Kooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom1oooo
o`007?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`3ooooood7ooooo000Oooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0oooooom1ooooo`007_ooool00omgMgOo<S8booooo`04ooooo`;o0000oooo
oom2ooooo`006oooool01Ol0003o8B4Qo`000?lb<S;oc<c<0?ooooooBOooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`Co
0000oooooom:ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00WOooool01OnH
V9So0000o`000?m4A4Co^[Zj01Wooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool5
o`0009Wooooo002Mooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000cooooo00?o0000
ooooooooool01?ooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A02Iooooo`00WOooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h0V_ooool0
09gooooo00?o0000ooooooooool02oooool6o`0000cooooo00?o0000ooooooooool03?ooool00onH
V9So8B4Qonk^kP2Iooooo`00WOooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00go
oooo00?oMgMgofIVI_ooool0V?ooool009_ooooo00?o410@o`000?l000000ol0000Looooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0Uoooool009gooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@4100VOooool009gooooo00?o
0000ooooooooool06oooool00omEEEGoIVIVo`00000<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
VOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.26) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .17962 Mdot
.04762 .24236 Mdot
.07143 .29821 Mdot
.09524 .29801 Mdot
.11905 .2978 Mdot
.14286 .29757 Mdot
.16667 .29731 Mdot
.19048 .29702 Mdot
.21429 .29669 Mdot
.2381 .29626 Mdot
.2619 .29582 Mdot
.28571 .29445 Mdot
.30952 .29149 Mdot
.33333 .27897 Mdot
.35714 .21327 Mdot
.38095 .11455 Mdot
.40476 .04844 Mdot
.42857 .01842 Mdot
.45238 .00673 Mdot
.47619 .00243 Mdot
.5 .00088 Mdot
.52381 .00032 Mdot
.54762 .00014 Mdot
.57143 9e-05 Mdot
.59524 .00012 Mdot
.61905 .00021 Mdot
.64286 .00037 Mdot
.66667 .00066 Mdot
.69048 .00113 Mdot
.71429 .00189 Mdot
.7381 .00305 Mdot
.7619 .00478 Mdot
.78571 .00726 Mdot
.80952 .01075 Mdot
.83333 .01556 Mdot
.85714 .02213 Mdot
.88095 .03121 Mdot
.90476 .04413 Mdot
.92857 .06384 Mdot
.95238 .09838 Mdot
.97619 .17962 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo0_l00005ooooo`;o00001_ooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l00006ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool07oooool002Gooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`0fooooo`;o00001Oooool2o`0000Kooooo00?o0000ooooooooool0AOooool2o`0000Gooooo
0_l00005ooooo`;o0000>Oooool00ol0003oooooooooo`0Oooooo`009Oooool00ol0003ooooooooo
o`1nooooo`;o0000Hoooool2o`0000Gooooo0_l0001Dooooo`009Oooool00ol0003oooooooooo`3Z
ooooo`;o0000E?ooool002Gooooo00?o0000ooooooooool0Moooool2o`0007Sooooo0_l0001=oooo
o`009Oooool00ol0003oooooooooo`1gooooo`;o0000N?ooool2o`0004gooooo000Uooooo`03o`00
0?oooooooooo0?Wooooo0_l00015ooooo`009Oooool2o`000?[ooooo0_l00015ooooo`009Oooool0
0ol0003oooooooooo`3oooooo`7ooooo0_l0000nooooo`009Oooool00ol0003oooooooooo`3ooooo
o`7ooooo0_l0000nooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0ooooool8ooooo`;o0000=ooo
ool002Gooooo00?o0000ooooooooool0ooooool8ooooo`;o0000=oooool002Gooooo0_l0001`oooo
o`;o0000coooool002Gooooo00?o0000ooooooooool0Koooool2o`000<oooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3oooooo`oooooo0_l0000`ooooo`009Oooool00ol0003oooooooooo`3ooooo
o`oooooo0_l0000`ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`;o0000oooooolHooooo`;o0000:?ooool002Gooooo00?o0000ooooooooool0oooooolGooooo`;o
0000:?ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo1?l000000ol@
413oooooooooo`03ooooo`03o`000?oooooooooo06Sooooo0_l0003Fooooo`007Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo06Sooooo0_l0003Fooooo`007Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Ooo
ool2o`000?oooooo@_ooool001gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
oooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1oooo
o`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo
00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`00
0?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool2o`000?oooooo@_ooool002Cooooo0_l0003oooooob3ooooo0_l0000Qooooo`009?ooool2o`00
0?oooooo8?ooool2o`00027ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0HOooool2o`000=gooooo000Uooooo`03o`000?oooooooooo067o
oooo0_l0003Mooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooo
oom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Jooooo`Go00001_ooool00ol0003oooooooooo`03ooooo`;o0000oooo
oollooooo`006_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool00ooo
ool2o`000?oooooo??ooool001_ooooo00?oV9RHob4Q8Oo^k^h01oooool2o`000?oooooo@_ooool0
01cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03
ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`007_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go0000okZj^_ooooooV9RH
oa0@4006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c006ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo05[ooooo
0_l0003Tooooo`009Oooool00ol0003oooooooooo`1Jooooo`;o0000i?ooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`1Cooooo`;o0000joooool002Go
oooo00?o0000ooooooooool0Boooool2o`0000Kooooo0_l0003[ooooo`009Oooool2o`0000_ooooo
0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo
0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l0003cooooo`009Oooool00ol0003ooooooooo
o`0:ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l0
0006ooooo`;o00001Oooool2o`0000Gooooo0_l0003jooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`00
0?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo
00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo
00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03ojVYZOl@
413ooooo00Gooooo0_l0003ooooood;ooooo000Looooo`03oa0@4?l0003o^[Zj00Kooooo00?o0000
ooooooooool0oooooom1ooooo`007Oooool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo
0?oooooo@Oooool001[ooooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooooooo
0?oooooo@Oooool001[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`007?ooool2o`000003oa0@4?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0?oooooo@Oooool001[ooooo1Ol00006ooooo`;o0000oooooom2ooooo`006_ooool0
1?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00CogMgM
oeEEEOoooooo00001oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03ogMgMoo<c<co
000000Oooooo00?o0000ooooooooool0oooooom1ooooo`006oooool00oo^k^koA4A4o`000007oooo
o`03o`000?oooooooooo0?oooooo@Oooool001cooooo00?oMgMgo`000?ooool01_ooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Kooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Nooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`00
7oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo00?o
MgMgoc8b<_ooool01?ooool2o`000?oooooo@_ooool001_ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c03oooooodWooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool4o`000?ooooooB_ooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool009Wooooo00GoV9RHo`000?l0003oA4A4okZj^P0Iooooo`Co000000?o410@
ooooooooool00_ooool2ob4Q8@Cooooo1Ol00003ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0UOoo
ool009Wooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003ooooooooo
o`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoEEEEogMgMooooooo
V9RHob4Q8@2Eooooo`00VOooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00_ooooo
00?oV9RHob4Q8Oo^k^h01?ooool01Ol0003ooooooooooooooooo000009Gooooo002Iooooo`03o`00
0?oooooooooo00_ooooo1_l0000<ooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h0
0oooool01Ol0003oV9RHoooooonHV9So8B4Q09Gooooo002Iooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool03Oooool00omgMgOoIVIVooooo`02ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`0UOooool009Oooooo00?o410@o`000?l000000ol0000Looooo`03o`000?oooooooooo00kooooo
00Ko0000oooooooooooooooooeEEEOn7QhNHooooo`00VOooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`03omgMgOl@413oV9RH
09Oooooo002Iooooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000003?ooool01OnHV9So
410@o`000?lQ8B7oc<c<00Cooooo00Coc<c<odA4A?l0003o410@UOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.32) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .1799 Mdot
.04762 .24261 Mdot
.07143 .29845 Mdot
.09524 .29828 Mdot
.11905 .29809 Mdot
.14286 .29789 Mdot
.16667 .29766 Mdot
.19048 .29741 Mdot
.21429 .29713 Mdot
.2381 .29681 Mdot
.2619 .29639 Mdot
.28571 .29593 Mdot
.30952 .29401 Mdot
.33333 .29071 Mdot
.35714 .26783 Mdot
.38095 .18496 Mdot
.40476 .09105 Mdot
.42857 .03688 Mdot
.45238 .01378 Mdot
.47619 .005 Mdot
.5 .0018 Mdot
.52381 .00066 Mdot
.54762 .00027 Mdot
.57143 .00015 Mdot
.59524 .00016 Mdot
.61905 .00026 Mdot
.64286 .00045 Mdot
.66667 .00077 Mdot
.69048 .0013 Mdot
.71429 .00213 Mdot
.7381 .00337 Mdot
.7619 .00518 Mdot
.78571 .00775 Mdot
.80952 .01131 Mdot
.83333 .01617 Mdot
.85714 .02277 Mdot
.88095 .03183 Mdot
.90476 .04469 Mdot
.92857 .06431 Mdot
.95238 .09874 Mdot
.97619 .1799 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo0_l00005ooooo`;o00001_ooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l00006ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool07oooool002Gooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`0mooooo`;o00001_ooool00ol0003oooooooooo`0mooooo`;o00001_ooool2o`0000Gooooo
0_l00005ooooo`;o0000>Oooool00ol0003oooooooooo`0Oooooo`009Oooool00ol0003ooooooooo
o`3Sooooo`;o00001Oooool2o`0005Cooooo000Uooooo`03o`000?oooooooooo07kooooo0_l0001Z
ooooo`;o0000E?ooool002Gooooo00?o0000ooooooooool0O_ooool2o`00077ooooo0_l0001=oooo
o`009Oooool00ol0003oooooooooo`3aooooo`;o0000COooool002Gooooo00?o0000ooooooooool0
nOooool2o`0004Gooooo000Uooooo`;o0000n_ooool2o`0004Gooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0ooooool1ooooo`;o0000?_ooool002Go
oooo00?o0000ooooooooool0Moooool2o`0008Oooooo0_l0000nooooo`009Oooool00ol0003ooooo
ooooo`1gooooo`;o0000aoooool002Gooooo00?o0000ooooooooool0ooooool8ooooo`;o0000=ooo
ool002Gooooo00?o0000ooooooooool0ooooool8ooooo`;o0000=oooool002Gooooo0_l0003ooooo
od;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo3oooool2o`00033ooooo000Uooooo`03o`000?oooooooooo0?oooooo3oooool2o`00
033ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0Koooool2o`000<oooooo000Uooooo`03o`000?oo
oooooooo06oooooo0_l0003?ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`;o0000oooooolHooooo`;o0000:?ooool002Gooooo00?o0000ooooooooool0oooooolGooooo`;o
0000:?ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo1?l000000ol@
413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`;o0000oooo
oom2ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool0
01gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`006oooool00omEEEGoIVIV
o`000007ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooo
oom2ooooo`009?ooool2o`000?oooooo8?ooool2o`00027ooooo000Tooooo`;o0000oooooolPoooo
o`;o00008Oooool002Gooooo00?o0000ooooooooool0J?ooool2o`000=Kooooo000Uooooo`03o`00
0?oooooooooo06Sooooo0_l0003Fooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool001[ooooo1Ol00006ooooo`03o`000?oooooooooo00?ooooo0_l0003ooooooccooooo000J
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`03ooooo`;o0000oooo
oollooooo`006oooool00onHV9So8B4Qonk^kP07ooooo`;o0000oooooom2ooooo`007?ooool00onH
V9So8B4Qonk^kP06ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?oMgMgofIVI_oo
ool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom1ooooo`006_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo
00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`1Qooooo`;o0000gOoo
ool002Gooooo00?o0000ooooooooool0HOooool2o`000=gooooo000Uooooo`;o0000oooooom2oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo05[ooooo0_l0003Tooooo`009Oooool00ol0003o
ooooooooo`1Cooooo`;o00001Oooool2o`000>Cooooo000Uooooo`;o00002oooool2o`0000Kooooo
0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo
0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l0003[ooooo`009Oooool00ol0003ooooooooo
o`0:ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l0
0006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o0000loooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Jooooo`05oiRHV?l@413o0000oc8b<_o<c<`01_ooool00ol0003oooooooooo`3ooooood7o
oooo000Jooooo`05oa0@4?nj^[[oooooogMgMolb<S801_ooool00ol0003oooooooooo`3ooooood7o
oooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`007Ooo
ool00onYZJWo410@ooooo`05ooooo`;o0000oooooom2ooooo`007?ooool00ol@413o0000okZj^P06
ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o^[Zjob4Q8Oooool01Oooool00ol0
003oooooooooo`3ooooood7ooooo000Jooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0
003oooooooooo`3ooooood7ooooo000Jooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001cooooo0_l000000ol@413o
ooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`Go00001_ooool2o`000?oooooo@_oo
ool001[ooooo00CoA4A4omgMgOoooooo00001oooool00ol0003oooooooooo`3ooooood7ooooo000J
ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0oooooom1ooooo`006oooool0
0omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00?ok^k^odA4
A?l000001oooool00ol0003oooooooooo`3ooooood7ooooo000Looooo`03ogMgMol0003ooooo00Ko
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oo
oooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`006oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooom1ooooo`007_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooood7ooooo
000Nooooo`03ogMgMolb<S;ooooo00Cooooo0_l0003ooooood;ooooo000Kooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`0oooooom9ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Koooo
o`03o`000?oooooooooo0?ooooooBoooool001_ooooo1?l0003ooooood[ooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo002Iooooo`05oiRHV?l0003o0000odA4A?nj^[X06Oooool4
o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00ooo
ool5o`0009Gooooo002Iooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000cooooo00?o
0000ooooooooool01?ooool2ob4Q8@Cooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0UOooool009Wooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?oV9RHob4Q8Oo^k^h0U_ooool009Wooooo00?o
0000ooooooooool02oooool6o`0000cooooo00?o0000ooooooooool03Oooool00onYZJWo410@oooo
o`04ooooo`03oiRHV?lQ8B7ok^k^09Gooooo002Iooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool03?ooool00ol@413o0000okZj^P06ooooo`03ogMgMomVIVKooooo09Cooooo002Goooo
o`03oa0@4?l0003o000000?o00007?ooool00ol0003oooooooooo`0=ooooo`03okZj^_lQ8B7ooooo
00Kooooo00?o0000ooooooooool0Toooool009Wooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0:ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01Ol0003o^[ZjoooooonHV9So
410@09Gooooo002Iooooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000003?ooool01OnY
ZJWo410@o`000?l@413oZJVY00?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c02Eooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.38) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .18016 Mdot
.04762 .24283 Mdot
.07143 .29867 Mdot
.09524 .29851 Mdot
.11905 .29835 Mdot
.14286 .29817 Mdot
.16667 .29797 Mdot
.19048 .29775 Mdot
.21429 .29751 Mdot
.2381 .29724 Mdot
.2619 .29691 Mdot
.28571 .29653 Mdot
.30952 .29591 Mdot
.33333 .2935 Mdot
.35714 .28885 Mdot
.38095 .25078 Mdot
.40476 .15575 Mdot
.42857 .07124 Mdot
.45238 .02791 Mdot
.47619 .01029 Mdot
.5 .00372 Mdot
.52381 .00135 Mdot
.54762 .00052 Mdot
.57143 .00026 Mdot
.59524 .00023 Mdot
.61905 .00032 Mdot
.64286 .00053 Mdot
.66667 .0009 Mdot
.69048 .00148 Mdot
.71429 .00237 Mdot
.7381 .00368 Mdot
.7619 .00558 Mdot
.78571 .00822 Mdot
.80952 .01184 Mdot
.83333 .01674 Mdot
.85714 .02336 Mdot
.88095 .03239 Mdot
.90476 .0452 Mdot
.92857 .06474 Mdot
.95238 .09907 Mdot
.97619 .18016 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00003Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01oo
oooo000Uooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0A?ooool2o`0003oooooo
0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l0000iooooo`03o`000?oooooooooo01oooooo
000Uooooo`03o`000?oooooooooo08Gooooo0_l0001Eooooo`;o00001Oooool2o`0000Gooooo0_l0
001Dooooo`009Oooool00ol0003oooooooooo`25ooooo`;o0000Hoooool2o`0005Cooooo000Uoooo
o`03o`000?oooooooooo0?7ooooo0_l0001=ooooo`009Oooool00ol0003oooooooooo`3aooooo`;o
0000COooool002Gooooo00?o0000ooooooooool0nOooool2o`0004Gooooo000Uooooo`;o0000Oooo
ool2o`0007Wooooo0_l00015ooooo`009Oooool00ol0003oooooooooo`1nooooo`;o0000`?ooool0
02Gooooo00?o0000ooooooooool0ooooool1ooooo`;o0000?_ooool002Gooooo00?o0000oooooooo
ool0ooooool1ooooo`;o0000?_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo2?ooool2
o`0003Oooooo000Uooooo`;o0000ooooool9ooooo`;o0000=oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0ooooool?ooooo`;o0000<?ooool0
02Gooooo00?o0000ooooooooool0ooooool?ooooo`;o0000<?ooool002Gooooo00?o0000oooooooo
ool0Moooool2o`000<Oooooo000Uooooo`03o`000?oooooooooo07Oooooo0_l00037ooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooooaSooooo0_l0000Xoooo
o`009Oooool00ol0003oooooooooo`3ooooooaOooooo0_l0000Xooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`006oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooo
ooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo
000Mooooo`03o`000?oooooooooo00Gooooo0_l0003ooooood;ooooo000Mooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Kooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0Koooool2o`000<oooooo000Uooooo`03o`000?oo
oooooooo06oooooo0_l0003?ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Tooooo`;o0000oooooolPooooo`;o00008Oooool002Co
oooo0_l0003oooooob3ooooo0_l0000Qooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool5o`0000Kooooo00?o
0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o
0000ooooooooool00oooool2o`000?oooooo??ooool001_ooooo00?oV9RHob4Q8Oo^k^h01oooool2
o`0000Cooooo0_l0003ooooooccooooo000Looooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000oooo
ooooool0J?ooool2o`000=Kooooo000Mooooo`03ogMgMomVIVKooooo00Gooooo00?o0000oooooooo
ool0J?ooool2o`000=Kooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom1ooooo`006_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
oooooom1ooooo`006_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0HOooool2o`000=gooooo000Uooooo`03o`000?oooooooooo05[ooooo0_l00005ooooo`;o
0000gOooool002Gooooo0_l0000;ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o0000
1Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o0000
1_ooool2o`0000Gooooo0_l0003Tooooo`009Oooool00ol0003oooooooooo`0:ooooo`;o00001_oo
ool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Ooo
ool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`000>_ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
6_ooool01OnHV9So410@o`000?lb<S;oc<c<00Kooooo00?o0000ooooooooool0oooooom1ooooo`00
6_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Kooooo00?o0000ooooooooool0oooooom1ooooo`00
7_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o
ZJVYoa0@4?ooool01Oooool2o`000?oooooo@_ooool001cooooo00?o410@o`000?nj^[X01_ooool0
0ol0003oooooooooo`3ooooood7ooooo000Mooooo`03okZj^_lQ8B7ooooo00Gooooo00?o0000oooo
ooooool0oooooom1ooooo`006_ooool01Ol@413oV9RHoooooonj^[[o000000Kooooo00?o0000oooo
ooooool0oooooom1ooooo`006_ooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Looooo`;o000000?o410@oooooooo
ool01?ooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooom1ooooo`006_ooool5o`0000Kooooo0_l0003ooooood;ooooo000J
ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool0
1?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00?oMgMg
olc<c?l000001oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03onk^k_m4A4Co0000
00Oooooo00?o0000ooooooooool0oooooom1ooooo`007?ooool00omgMgOo0000ooooo`06ooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool001_ooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
0?oooooo@Oooool001kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood7o
oooo000Oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooom1ooooo`007_oo
ool00omgMgOo<S8booooo`04ooooo`;o0000oooooom2ooooo`006oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<0?ooooooBOooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`Co0000oooooom:ooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00VOooool01OnHV9So0000o`000?m4A4Co^[Zj01Wooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Go
c<c<ob4Q8Ol0003o8B4Qolc<c02Eooooo`00VOooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo
1_l0000<ooooo`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb
<S800oooool01OlQ8B7oV9RHoooooonHV9So8B4Q09Gooooo002Iooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool03_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool0Toooool009Wooooo00?o0000ooooooooool02oooool6o`0000cooooo00?o0000oooooooo
ool03Oooool00onYZJWo410@ooooo`02ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80UOooool009Wo
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0<ooooo`03oa0@4?l0003o^[Zj00?o
oooo00Goc<c<o`000?l0003o0000olc<c02Eooooo`00Uoooool00ol@413o0000o`000003o`0001co
oooo00?o0000ooooooooool03Oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?nj^[[ooooookZj
^_l@4100UOooool009Wooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0:ooooo`05
oa0@4?nHV9SooooookZj^_l000000oooool01Ol0003o^[Zjoooooonj^[[o000009Gooooo002Ioooo
o`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000003?ooool01OnYZJWo410@o`000?l@413o
ZJVY00?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2Eooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.44) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .1804 Mdot
.04762 .24304 Mdot
.07143 .29886 Mdot
.09524 .29873 Mdot
.11905 .29858 Mdot
.14286 .29842 Mdot
.16667 .29824 Mdot
.19048 .29805 Mdot
.21429 .29784 Mdot
.2381 .2976 Mdot
.2619 .29735 Mdot
.28571 .297 Mdot
.30952 .29667 Mdot
.33333 .29569 Mdot
.35714 .29301 Mdot
.38095 .28455 Mdot
.40476 .22799 Mdot
.42857 .12781 Mdot
.45238 .05506 Mdot
.47619 .02102 Mdot
.5 .00768 Mdot
.52381 .00278 Mdot
.54762 .00104 Mdot
.57143 .00046 Mdot
.59524 .00033 Mdot
.61905 .0004 Mdot
.64286 .00063 Mdot
.66667 .00103 Mdot
.69048 .00166 Mdot
.71429 .00261 Mdot
.7381 .004 Mdot
.7619 .00596 Mdot
.78571 .00867 Mdot
.80952 .01235 Mdot
.83333 .01729 Mdot
.85714 .02391 Mdot
.88095 .03292 Mdot
.90476 .04568 Mdot
.92857 .06514 Mdot
.95238 .09937 Mdot
.97619 .1804 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01?ooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001_ooool2o`0000gooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Oooooo`009Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Cooooo
0_l00006ooooo`;o0000=oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0003Wooooo
00?o0000ooooooooool07oooool002Gooooo00?o0000ooooooooool0S?ooool2o`0004kooooo0_l0
0005ooooo`;o0000Foooool002Gooooo00?o0000ooooooooool0j_ooool2o`0005Cooooo000Uoooo
o`03o`000?oooooooooo0>[ooooo0_l00005ooooo`;o0000COooool002Gooooo00?o0000oooooooo
ool0QOooool2o`0006[ooooo0_l0001=ooooo`009Oooool00ol0003oooooooooo`25ooooo`;o0000
L_ooool2o`0004Gooooo000Uooooo`;o0000n_ooool2o`0004Gooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0ooooool1ooooo`;o0000?_ooool002Go
oooo00?o0000ooooooooool0ooooool1ooooo`;o0000?_ooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo2?ooool2o`0003Oooooo000Uooooo`;o0000ooooool9ooooo`;o0000=oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`1nooooo`;o0000
`?ooool002Gooooo00?o0000ooooooooool0O_ooool2o`000<3ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0ooooool?ooooo`;o0000<?ooool002Go
oooo00?o0000ooooooooool0ooooool?ooooo`;o0000<?ooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooo
oaSooooo0_l0000Xooooo`009Oooool00ol0003oooooooooo`3ooooooaOooooo0_l0000Xooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`006oooool4o`000003oa0@4?oooooooooo
00?ooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo0_l0003ooooood;ooooo000M
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Moooool2o`000<Oooooo000Moooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Moooool2o`000<Oooooo000Mooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`006oooool00omEEEGoIVIV
o`000007ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooo
oom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Tooooo`;o0000oooooolPoooo
o`;o00008Oooool002Cooooo0_l0003oooooob3ooooo0_l0000Qooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000
ooooooooool0Koooool2o`000<oooooo000Uooooo`03o`000?oooooooooo06oooooo0_l0003?oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool001[ooooo1Ol00006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo00?ooooo0_l0003ooooooccooooo000K
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0_l00004ooooo`;o0000oooooollooooo`007?ooool00onH
V9So8B4Qonk^kP06ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?oMgMgofIVI_oo
ool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom1ooooo`006_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo
00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`1Xooooo`;o0000e_ooool002Gooooo00?o0000ooooooooool0J?ooool2
o`000=Kooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0HOooool2o`000=gooooo000Uooooo`;o00006_ooool2o`0000Gooooo0_l00005ooooo`;o0000
1Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o0000
1Oooool2o`0000Gooooo0_l0003Mooooo`009Oooool00ol0003oooooooooo`0:ooooo`;o00001_oo
ool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Ooo
ool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l0003Tooooo`009Oooool0
0ol0003oooooooooo`0:ooooo`;o00001_ooool2o`000?oooooo;Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So410@o`000?lb<S;oc<c<00Ko
oooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Ko
oooo00?o0000ooooooooool0oooooom1ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo0?oooooo@Oooool001gooooo00?oZJVYoa0@4?ooool01Oooool2o`000?oooooo@_oo
ool001cooooo00?o410@o`000?nj^[X01_ooool00ol0003oooooooooo`3ooooood7ooooo000Moooo
o`03okZj^_lQ8B7ooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01Ol@413o
V9RHoooooonj^[[o000000Kooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnYZJWo
410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0
003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Looooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3ooooood7o
oooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`006_oo
ool5o`0000Kooooo0_l0003ooooood;ooooo000Jooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o
0000ooooooooool0oooooom1ooooo`006_ooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oo
oooooooo0?oooooo@Oooool001_ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3o
oooood7ooooo000Kooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom1oooo
o`007?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`3ooooood7ooooo000Oooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0oooooom1ooooo`007_ooool00omgMgOo<S8booooo`04ooooo`;o0000oooo
oom2ooooo`006oooool01Ol0003o8B4Qo`000?lb<S;oc<c<0?ooooooBOooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`Co
0000oooooom:ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00VOooool01OnH
V9So0000o`000?m4A4Co^[Zj01Wooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_ooool2
o`000003oa0@4?oooooooooo00?ooooo0_l000000ol@413oooooooooo`2Cooooo`00VOooool01Ol@
413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<ooooo`03o`000?oooooooooo00Cooooo0_lQ8B47
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0U?ooool009Wooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0:ooooo`Go00000oooool5o`0009Gooooo002Iooooo`03
o`000?oooooooooo00_ooooo1_l0000<ooooo`03o`000?oooooooooo00[ooooo00CoA4A4omgMgOoo
oooo00001?ooool01?m4A4CogMgMooooool0002Fooooo`00VOooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo00[ooooo00CogMgMoeEEEOoooooo00001?ooool01?oMgMgoEEEEooooool0
002Fooooo`00Uoooool00ol@413o0000o`000003o`0001cooooo00?o0000ooooooooool02oooool0
0omgMgOoc<c<o`000005ooooo`03ogMgMoo<c<co000009Kooooo002Iooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool02oooool00oo^k^koA4A4o`000005ooooo`03onk^k_m4A4Co0000
09Kooooo002Iooooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000003_ooool00omgMgOo
0000ooooo`05ooooo`03ogMgMol0003ooooo09Gooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .18061 Mdot
.04762 .24322 Mdot
.07143 .29904 Mdot
.09524 .29892 Mdot
.11905 .29878 Mdot
.14286 .29864 Mdot
.16667 .29848 Mdot
.19048 .29831 Mdot
.21429 .29813 Mdot
.2381 .29792 Mdot
.2619 .2977 Mdot
.28571 .29744 Mdot
.30952 .2971 Mdot
.33333 .29679 Mdot
.35714 .29528 Mdot
.38095 .29247 Mdot
.40476 .27613 Mdot
.42857 .20089 Mdot
.45238 .10264 Mdot
.47619 .04217 Mdot
.5 .0158 Mdot
.52381 .00575 Mdot
.54762 .00212 Mdot
.57143 .00086 Mdot
.59524 .0005 Mdot
.61905 .00051 Mdot
.64286 .00074 Mdot
.66667 .00117 Mdot
.69048 .00185 Mdot
.71429 .00286 Mdot
.7381 .00431 Mdot
.7619 .00634 Mdot
.78571 .00911 Mdot
.80952 .01283 Mdot
.83333 .0178 Mdot
.85714 .02442 Mdot
.88095 .03341 Mdot
.90476 .04611 Mdot
.92857 .0655 Mdot
.95238 .09964 Mdot
.97619 .18061 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00003Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01oo
oooo000Uooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`04ooooo`;o0000=oooool2o`0000Kooooo0_l00005ooooo`;o0000@?ooool00ol0003ooooo
ooooo`0Oooooo`009Oooool00ol0003oooooooooo`2Dooooo`;o0000A_ooool2o`0000Gooooo0_l0
001Kooooo`009Oooool00ol0003oooooooooo`3Sooooo`;o00001Oooool2o`0005Cooooo000Uoooo
o`03o`000?oooooooooo08cooooo0_l0001Looooo`;o00001Oooool2o`0004gooooo000Uooooo`03
o`000?oooooooooo08cooooo0_l0001Sooooo`;o0000COooool002Gooooo00?o0000ooooooooool0
nOooool2o`0004Gooooo000Uooooo`;o0000n_ooool2o`0004Gooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0ooooool1ooooo`;o0000?_ooool002Go
oooo00?o0000ooooooooool0ooooool1ooooo`;o0000?_ooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`25ooooo`;o0000^Oooool002Gooooo00?o0000
ooooooooool0QOooool2o`00083ooooo0_l0000gooooo`009Oooool2o`000?oooooo2Oooool2o`00
03Oooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0ooooool?ooooo`;o0000<?ooool002Go
oooo00?o0000ooooooooool0ooooool?ooooo`;o0000<?ooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooo
oaSooooo0_l0000Xooooo`009Oooool00ol0003oooooooooo`1nooooo`;o0000U_ooool2o`0002So
oooo000Uooooo`03o`000?oooooooooo07kooooo0_l00030ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo1?l000000ol@
413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`;o0000oooo
oom2ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool0
01gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`006oooool00omEEEGoIVIV
o`000007ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooo
oom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Tooooo`;o0000oooooolPoooo
o`;o00008Oooool002Cooooo0_l0003oooooob3ooooo0_l0000Qooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooooooo
ool0Moooool2o`000<Oooooo000Uooooo`03o`000?oooooooooo07Oooooo0_l00037ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool001[ooooo1Ol00006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo00?ooooo0_l0003ooooooccooooo000K
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0_l00004ooooo`;o0000oooooollooooo`007?ooool00onH
V9So8B4Qonk^kP06ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?oMgMgofIVI_oo
ool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom1ooooo`006_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo
00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo06oooooo0_l0003?ooooo`009Oooool00ol0003oooooooooo`1_ooooo`;o0000
coooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0HOooool2o`0000Gooooo0_l0003Fooooo`009Oooool2o`00027ooooo0_l00005ooooo`;o0000
1Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o0000
1Oooool2o`0000Gooooo0_l00005ooooo`;o0000e_ooool002Gooooo00?o0000ooooooooool02_oo
ool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_oo
ool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o0000i?oo
ool002Gooooo00?o0000ooooooooool02_ooool2o`0000Kooooo0_l00005ooooo`;o0000oooooolV
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooo
od;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oiRH
V?l@413o0000oc8b<_o<c<`01_ooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oa0@
4?nj^[[oooooogMgMolb<S801_ooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00onYZJWo410@oooo
o`05ooooo`;o0000oooooom2ooooo`007?ooool00ol@413o0000okZj^P06ooooo`03o`000?oooooo
oooo0?oooooo@Oooool001gooooo00?o^[Zjob4Q8Oooool01Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Jooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003oooooooooo`3ooooo
od7ooooo000Jooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0
003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool001cooooo0_l000000ol@413oooooooooo`04ooooo`03
o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Jooooo`Go00001_ooool2o`000?oooooo@_ooool001[ooooo00CoA4A4
omgMgOoooooo00001oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`04omgMgOmEEEGo
ooooo`0000Oooooo00?o0000ooooooooool0oooooom1ooooo`006oooool00omgMgOoc<c<o`000007
ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00?ok^k^odA4A?l000001oooool00ol0
003oooooooooo`3ooooood7ooooo000Looooo`03ogMgMol0003ooooo00Kooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o
0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`006oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom1oooo
o`007_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03ogMgMolb
<S;ooooo00Cooooo0_l0003ooooood;ooooo000Kooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0oooo
oom9ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo1?l0003ooooood[ooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo002Mooooo`05oiRHV?l0003o0000odA4A?nj^[X06Oooool4o`000003oa0@4?oooooo
oooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0V?ooool009gooooo00Go410@
okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`2Gooooo`00WOooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0U_ooool009gooooo00?o0000ooooooooool02oooool6o`00
00cooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`2Gooooo`00WOooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c02Hoooo
o`00Voooool00ol@413o0000o`000003o`0001cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`2Jooooo`00WOooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0V_ooool009gooooo00?o0000ooooooooool06oooool00omEEEGoIVIVo`00
000=ooooo`Co0000VOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.56) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .18081 Mdot
.04762 .24339 Mdot
.07143 .29921 Mdot
.09524 .29909 Mdot
.11905 .29897 Mdot
.14286 .29884 Mdot
.16667 .2987 Mdot
.19048 .29855 Mdot
.21429 .29838 Mdot
.2381 .2982 Mdot
.2619 .298 Mdot
.28571 .29779 Mdot
.30952 .29753 Mdot
.33333 .29721 Mdot
.35714 .29682 Mdot
.38095 .29475 Mdot
.40476 .29138 Mdot
.42857 .26219 Mdot
.45238 .17172 Mdot
.47619 .08102 Mdot
.5 .03208 Mdot
.52381 .01187 Mdot
.54762 .00434 Mdot
.57143 .00168 Mdot
.59524 .00083 Mdot
.61905 .00068 Mdot
.64286 .00088 Mdot
.66667 .00132 Mdot
.69048 .00204 Mdot
.71429 .00311 Mdot
.7381 .00462 Mdot
.7619 .00671 Mdot
.78571 .00953 Mdot
.80952 .01329 Mdot
.83333 .01828 Mdot
.85714 .0249 Mdot
.88095 .03386 Mdot
.90476 .04652 Mdot
.92857 .06583 Mdot
.95238 .09989 Mdot
.97619 .18081 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00003Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01oo
oooo000Uooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`0;ooooo`;o0000<?ooool2o`0000Kooooo0_l00005ooooo`;o0000@?ooool00ol0003ooooo
ooooo`0Oooooo`009Oooool00ol0003oooooooooo`2Dooooo`;o0000A_ooool2o`0000Gooooo0_l0
001Kooooo`009Oooool00ol0003oooooooooo`2Dooooo`;o0000COooool2o`0000Gooooo0_l0001D
ooooo`009Oooool00ol0003oooooooooo`3Zooooo`;o00001Oooool2o`0004gooooo000Uooooo`03
o`000?oooooooooo0?7ooooo0_l0001=ooooo`009Oooool00ol0003oooooooooo`3iooooo`;o0000
AOooool002Gooooo0_l0003jooooo`;o0000AOooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`2<ooooo`;o0000L_ooool2o`0003kooooo000Uooooo`03
o`000?oooooooooo08cooooo0_l0001booooo`;o0000?_ooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo2?ooool2o`0003Oooooo000Uooooo`;o0000ooooool9ooooo`;o0000=oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3oooooo`oooooo0_l0000`ooooo`009Oooool00ol0003o
ooooooooo`3oooooo`oooooo0_l0000`ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`25ooooo`;o0000^Oooool0
02Gooooo00?o0000ooooooooool0QOooool2o`000;Wooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooo
oaSooooo0_l0000Xooooo`009Oooool00ol0003oooooooooo`3ooooooaOooooo0_l0000Xooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`006oooool4o`000003oa0@4?oooooooooo
00?ooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo0_l0003ooooood;ooooo000M
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03oeEEEOmVIVKo000000Oooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo07kooooo0_l00030ooooo`009Oooool2o`0007oooooo0_l0
0030ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Tooooo`;o0000oooooolPoooo
o`;o00008Oooool002Cooooo0_l0003oooooob3ooooo0_l0000Qooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`006_oo
ool5o`0000Kooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Kooooo00?o0000ooooooooool00oooool2o`000?oooooo??ooool001_ooooo00?oV9RH
ob4Q8Oo^k^h01oooool2o`0000Cooooo0_l0003ooooooccooooo000Looooo`03oiRHV?lQ8B7ok^k^
00Kooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00omgMgOoIVIVooooo`05ooooo`03
o`000?oooooooooo0?oooooo@Oooool001kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3ooooood7ooooo000Jooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003ooooo
ooooo`1gooooo`;o0000aoooool001[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`00
0?oooooooooo07Oooooo0_l00037ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0Koooool2o`000<oooooo000Uooooo`03o`000?oooooooooo06So
oooo0_l00005ooooo`;o0000coooool002Gooooo0_l0000Xooooo`;o00001Oooool2o`0000Kooooo
0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo
0_l00005ooooo`;o0000e_ooool002Gooooo00?o0000ooooooooool02_ooool2o`0000Kooooo0_l0
0005ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l0
0005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`000=gooooo000U
ooooo`03o`000?oooooooooo00[ooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l0003o
oooooaoooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`00
0?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo
00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo
00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03ojVYZOl@
413ooooo00Gooooo0_l0003ooooood;ooooo000Looooo`03oa0@4?l0003o^[Zj00Kooooo00?o0000
ooooooooool0oooooom1ooooo`007Oooool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo
0?oooooo@Oooool001[ooooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooooooo
0?oooooo@Oooool001[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`007?ooool2o`000003oa0@4?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0?oooooo@Oooool001[ooooo1Ol00006ooooo`;o0000oooooom2ooooo`006_ooool0
1?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00CogMgM
oeEEEOoooooo00001oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03ogMgMoo<c<co
000000Oooooo00?o0000ooooooooool0oooooom1ooooo`006oooool00oo^k^koA4A4o`000007oooo
o`03o`000?oooooooooo0?oooooo@Oooool001cooooo00?oMgMgo`000?ooool01_ooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Kooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Nooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`00
7oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo00?o
MgMgoc8b<_ooool01?ooool2o`000?oooooo@_ooool001_ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c03oooooodWooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool4o`000?ooooooB_ooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool009Wooooo00GoV9RHo`000?l0003oA4A4okZj^P0Iooooo`Co000000?o410@
ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0UOooool009Wooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko0000
3?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool02OmgMgOo<S8booooooooooooEEEEogMg
MoooooooV9RHob4Q8@2Eooooo`00VOooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
00oooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`2Cooooo`00VOooool00ol0
003oooooooooo`0;ooooo`Ko00003?ooool00ol0003oooooooooo`0>ooooo`09ogMgMolb<S;ooooo
ooooool0003oV9RHoooooonHV9So8B4Q09Gooooo002Iooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oeEEEOl0003o
410@olc<c02Eooooo`00Uoooool00ol@413o0000o`000003o`0001cooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`04ooooo`03oeEEEOn7QhOooooo09Oooooo002Iooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`04ooooo`03omgMgOl@
413oV9RH09Oooooo002Iooooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000003Oooool4
o`0000Cooooo00Coc<c<odA4A?l0003o410@UOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.62) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .18099 Mdot
.04762 .24355 Mdot
.07143 .29935 Mdot
.09524 .29925 Mdot
.11905 .29914 Mdot
.14286 .29902 Mdot
.16667 .29889 Mdot
.19048 .29876 Mdot
.21429 .29861 Mdot
.2381 .29845 Mdot
.2619 .29827 Mdot
.28571 .29808 Mdot
.30952 .29788 Mdot
.33333 .2976 Mdot
.35714 .29733 Mdot
.38095 .29668 Mdot
.40476 .29422 Mdot
.42857 .28866 Mdot
.45238 .24225 Mdot
.47619 .14283 Mdot
.5 .0631 Mdot
.52381 .02431 Mdot
.54762 .00895 Mdot
.57143 .00336 Mdot
.59524 .00146 Mdot
.61905 .00096 Mdot
.64286 .00105 Mdot
.66667 .00149 Mdot
.69048 .00225 Mdot
.71429 .00336 Mdot
.7381 .00492 Mdot
.7619 .00706 Mdot
.78571 .00993 Mdot
.80952 .01373 Mdot
.83333 .01873 Mdot
.85714 .02535 Mdot
.88095 .03429 Mdot
.90476 .04689 Mdot
.92857 .06614 Mdot
.95238 .10013 Mdot
.97619 .18099 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`04ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001_ooool2o`0000gooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Oooooo`009Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool04_ooool2o`0002;ooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo
0_l00010ooooo`03o`000?oooooooooo01oooooo000Uooooo`03o`000?oooooooooo09_ooooo0_l0
000oooooo`;o00001Oooool2o`0005_ooooo000Uooooo`03o`000?oooooooooo09_ooooo0_l00016
ooooo`;o00001Oooool2o`0005Cooooo000Uooooo`03o`000?oooooooooo0>[ooooo0_l0001Doooo
o`009Oooool00ol0003oooooooooo`3aooooo`;o0000COooool002Gooooo00?o0000ooooooooool0
U?ooool2o`0005_ooooo0_l0001=ooooo`009Oooool2o`0009Gooooo0_l0001Sooooo`;o0000AOoo
ool002Gooooo00?o0000ooooooooool0nOooool2o`0004Gooooo000Uooooo`03o`000?oooooooooo
0?oooooo0Oooool2o`0003kooooo000Uooooo`03o`000?oooooooooo0?oooooo0Oooool2o`0003ko
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3oooooo`Sooooo0_l0000gooooo`009Oooool2o`00
0?oooooo2Oooool2o`0003Oooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo08cooooo0_l0002booooo`009Oooool00ol0003oooooooooo`2<oooo
o`;o0000P?ooool2o`00033ooooo000Uooooo`03o`000?oooooooooo0?oooooo3oooool2o`00033o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`;o0000oooooolHooooo`;o0000:?ooool002Gooooo00?o0000oooooooo
ool0oooooolGooooo`;o0000:?ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
01_ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo@Oooool001go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003ooooooooo
o`05ooooo`;o0000oooooom2ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`00
6oooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0QOooool2o`000;Wooooo000Uooooo`03o`000?oooooooooo08Gooooo0_l0002i
ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009?ooool2o`000?oooooo8?ooool2o`00027ooooo000Tooooo`;o0000oooooolPooooo`;o
00008Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooo
od;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0
003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool001[ooooo1Ol00006ooooo`03o`000?oooooooooo07kooooo0_l0
0030ooooo`006_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool00ooo
ool2o`0007Wooooo0_l00030ooooo`006oooool00onHV9So8B4Qonk^kP07ooooo`;o00001?ooool2
o`000?oooooo??ooool001cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3ooooo
od7ooooo000Mooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`00
7_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go
0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`1gooooo`;o0000aoooool002Gooooo00?o0000ooooooooool0Moooool2o`00
0<Oooooo000Uooooo`03o`000?oooooooooo06oooooo0_l0003?ooooo`009Oooool2o`0003Oooooo
0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo
0_l00005ooooo`;o00001Oooool2o`000<oooooo000Uooooo`03o`000?oooooooooo00[ooooo0_l0
0006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l0
0005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l0
0005ooooo`;o0000e_ooool002Gooooo00?o0000ooooooooool02_ooool2o`0000Kooooo0_l00005
ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o0000oooooolAooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oiRHV?l@413o0000oc8b<_o<
c<`01_ooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oa0@4?nj^[[oooooogMgMolb
<S801_ooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom1ooooo`007Oooool00onYZJWo410@ooooo`05ooooo`;o0000oooo
oom2ooooo`007?ooool00ol@413o0000okZj^P06ooooo`03o`000?oooooooooo0?oooooo@Oooool0
01gooooo00?o^[Zjob4Q8Oooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05
oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05
ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool001cooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo
000Jooooo`Go00001_ooool2o`000?oooooo@_ooool001[ooooo00CoA4A4omgMgOoooooo00001ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o
0000ooooooooool0oooooom1ooooo`006oooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooo
oooo0?oooooo@Oooool001_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`3ooooo
od7ooooo000Looooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`006oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom1ooooo`007_ooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03ogMgMolb<S;ooooo00Cooooo0_l0
003ooooood;ooooo000Kooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0oooooom9ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo1?l0003ooooood[ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Ioooo
o`05oiRHV?l0003o0000odA4A?nj^[X06Oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool5o`0009Gooooo002Iooooo`05oa0@4?nj^[[o
k^k^ogMgMol@41002Oooool6o`0000cooooo00?o0000ooooooooool01?ooool2ob4Q8@Cooooo00Go
EEEEogMgMoooooooV9RHob4Q8@03ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0UOooool009Wooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0:ooooo`05o`000?ooooooooooooooool0
00001?ooool00onHV9So8B4Qonk^kP2Fooooo`00VOooool00ol0003oooooooooo`0;ooooo`Ko0000
3?ooool00ol0003oooooooooo`0:ooooo`05o`000?nHV9SooooooiRHV?lQ8B401Oooool00onHV9So
8B4Qonk^kP2Eooooo`00VOooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00[ooooo
00Go0000oeEEEOl0003o410@olc<c006ooooo`03ogMgMomVIVKooooo09Cooooo002Gooooo`03oa0@
4?l0003o000000?o00007?ooool00ol0003oooooooooo`0:ooooo`03oeEEEOn7QhOooooo00Wooooo
00?o0000ooooooooool0Toooool009Wooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0:ooooo`03omgMgOl@413oV9RH00Gooooo00Go0000okZj^_ooooooV9RHoa0@402Eooooo`00VOoo
ool00ol0003oooooooooo`0Kooooo`03oeEEEOmVIVKo000000gooooo00Coc<c<odA4A?l0003o410@
0oooool01OnHV9So410@o`000?lQ8B7oc<c<09Gooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.68) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .18116 Mdot
.04762 .24369 Mdot
.07143 .29949 Mdot
.09524 .2994 Mdot
.11905 .29929 Mdot
.14286 .29919 Mdot
.16667 .29907 Mdot
.19048 .29895 Mdot
.21429 .29881 Mdot
.2381 .29867 Mdot
.2619 .29851 Mdot
.28571 .29834 Mdot
.30952 .29816 Mdot
.33333 .29796 Mdot
.35714 .29767 Mdot
.38095 .29745 Mdot
.40476 .29633 Mdot
.42857 .29374 Mdot
.45238 .28275 Mdot
.47619 .21713 Mdot
.5 .11607 Mdot
.52381 .04867 Mdot
.54762 .01842 Mdot
.57143 .00684 Mdot
.59524 .00275 Mdot
.61905 .00148 Mdot
.64286 .00132 Mdot
.66667 .0017 Mdot
.69048 .00246 Mdot
.71429 .00361 Mdot
.7381 .00522 Mdot
.7619 .00741 Mdot
.78571 .01032 Mdot
.80952 .01415 Mdot
.83333 .01916 Mdot
.85714 .02577 Mdot
.88095 .03468 Mdot
.90476 .04724 Mdot
.92857 .06643 Mdot
.95238 .10034 Mdot
.97619 .18116 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`;o00003Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01oo
oooo000Uooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`0Booooo`;o00001Oooool2o`0001_ooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo
0_l00010ooooo`03o`000?oooooooooo01oooooo000Uooooo`03o`000?oooooooooo0:;ooooo0_l0
000hooooo`;o00001Oooool2o`0005_ooooo000Uooooo`03o`000?oooooooooo0>?ooooo0_l00005
ooooo`;o0000E?ooool002Gooooo00?o0000ooooooooool0Voooool2o`0004gooooo0_l0001Doooo
o`009Oooool00ol0003oooooooooo`2Kooooo`;o0000E?ooool2o`0004gooooo000Uooooo`03o`00
0?oooooooooo0?7ooooo0_l0001=ooooo`009Oooool2o`000?[ooooo0_l00015ooooo`009Oooool0
0ol0003oooooooooo`3iooooo`;o0000AOooool002Gooooo00?o0000ooooooooool0ooooool1oooo
o`;o0000?_ooool002Gooooo00?o0000ooooooooool0ooooool1ooooo`;o0000?_ooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo2?ooool2o`0003Oooooo000Uooooo`;o0000UOooool2o`00
077ooooo0_l0000gooooo`009Oooool00ol0003oooooooooo`2Dooooo`;o0000Z_ooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0ooooool?oooo
o`;o0000<?ooool002Gooooo00?o0000ooooooooool0ooooool?ooooo`;o0000<?ooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo0_l0003ooooooaSooooo0_l0000Xooooo`009Oooool00ol0003oooooooooo`3ooooooaOo
oooo0_l0000Xooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`006oooool4o`00
0003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0S?ooool2o`000;;ooooo000Mooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0S?ooool2o`000;;ooooo000Mooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003ooooooooo
o`05ooooo`;o0000oooooom2ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`00
6oooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Toooo
o`;o0000oooooolPooooo`;o00008Oooool002Cooooo0_l0003oooooob3ooooo0_l0000Qooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo08Go
oooo0_l0002iooooo`009Oooool00ol0003oooooooooo`25ooooo`;o0000^Oooool002Gooooo0_l0
003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool001[ooooo1Ol00006ooooo`03o`000?oooooooooo0?oooooo@Ooo
ool001[ooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo00?ooooo0_l0
003ooooooccooooo000Kooooo`03oiRHV?lQ8B7ok^k^00Oooooo0_l00004ooooo`;o0000ooooooll
ooooo`007?ooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo0?oooooo@Oooool001go
oooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01Ol0003o^[Zjoooo
oonHV9So410@00Kooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So410@o`00
0?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooo
od;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`1nooooo`;o0000`?ooool002Gooooo00?o0000
ooooooooool0O_ooool2o`000<3ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0Moooool2o`000<Oooooo000Uooooo`;o0000?_ooool2o`0000Gooooo
0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo
0_l00006ooooo`;o0000aoooool002Gooooo00?o0000ooooooooool02_ooool2o`0000Kooooo0_l0
0005ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l0
0005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l0
0005ooooo`;o0000coooool002Gooooo00?o0000ooooooooool02_ooool2o`0000Kooooo0_l00005
ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`000?oooooo2Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So410@
o`000?lb<S;oc<c<00Kooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01Ol@413o^[Zj
oooooomgMgOo<S8b00Kooooo00?o0000ooooooooool0oooooom1ooooo`007_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?oZJVYoa0@4?ooool01Ooo
ool2o`000?oooooo@_ooool001cooooo00?o410@o`000?nj^[X01_ooool00ol0003oooooooooo`3o
oooood7ooooo000Mooooo`03okZj^_lQ8B7ooooo00Gooooo00?o0000ooooooooool0oooooom1oooo
o`006_ooool01Ol@413oV9RHoooooonj^[[o000000Kooooo00?o0000ooooooooool0oooooom1oooo
o`006_ooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooo
oom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o
0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Looooo`;o000000?o410@ooooooooool01?ooool00ol0003o
ooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
oooooom1ooooo`006_ooool5o`0000Kooooo0_l0003ooooood;ooooo000Jooooo`04odA4A?oMgMgo
ooooo`0000Oooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01?oMgMgoEEEEooooool0
0007ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00?oMgMgolc<c?l000001oooool0
0ol0003oooooooooo`3ooooood7ooooo000Kooooo`03onk^k_m4A4Co000000Oooooo00?o0000oooo
ooooool0oooooom1ooooo`007?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oo
oooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2
o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001_o
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo@Oooool001ko
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood7ooooo000Oooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0oooooom1ooooo`007_ooool00omgMgOo<S8boooo
o`04ooooo`;o0000oooooom2ooooo`006oooool01Ol0003o8B4Qo`000?lb<S;oc<c<0?ooooooBOoo
ool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooo
od_ooooo000Kooooo`Co0000oooooom:ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00VOooool01OnHV9So0000o`000?m4A4Co^[Zj01Wooooo1?l000000ol@413oooooooooo`02
ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Goc<c<ob4Q8Ol0003o8B4Q
olc<c02Eooooo`00VOooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<ooooo`03o`00
0?oooooooooo00Cooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OlQ8B7o
V9RHoooooonHV9So8B4Q09Gooooo002Iooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool02_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00002E
ooooo`00VOooool00ol0003oooooooooo`0;ooooo`Ko00003?ooool00ol0003oooooooooo`0:oooo
o`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Olb<S;oV9RHoooooonHV9So<S8b09Gooooo002I
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02_ooool01Ol0003oEEEEo`000?l@
413oc<c<00?ooooo00Goc<c<o`000?l0003o0000olc<c02Eooooo`00Uoooool00ol@413o0000o`00
0003o`0001cooooo00?o0000ooooooooool02_ooool00omEEEGoQhN7ooooo`05ooooo`05oa0@4?nj
^[[ooooookZj^_l@4100UOooool009Wooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0:ooooo`03omgMgOl@413oV9RH00Gooooo00Go0000okZj^_oooooo^[Zjo`00002Eooooo`00VOoo
ool00ol0003oooooooooo`0Kooooo`03oeEEEOmVIVKo000000gooooo00Coc<c<odA4A?l0003o410@
0oooool01OnYZJWo410@o`000?l@413oZJVY09Gooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.74) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .18131 Mdot
.04762 .24382 Mdot
.07143 .29962 Mdot
.09524 .29953 Mdot
.11905 .29944 Mdot
.14286 .29934 Mdot
.16667 .29923 Mdot
.19048 .29912 Mdot
.21429 .299 Mdot
.2381 .29887 Mdot
.2619 .29873 Mdot
.28571 .29858 Mdot
.30952 .29841 Mdot
.33333 .29824 Mdot
.35714 .29803 Mdot
.38095 .29775 Mdot
.40476 .29751 Mdot
.42857 .29582 Mdot
.45238 .29308 Mdot
.47619 .27201 Mdot
.5 .18871 Mdot
.52381 .09256 Mdot
.54762 .0373 Mdot
.57143 .01402 Mdot
.59524 .00538 Mdot
.61905 .00248 Mdot
.64286 .00176 Mdot
.66667 .00196 Mdot
.69048 .0027 Mdot
.71429 .00387 Mdot
.7381 .00552 Mdot
.7619 .00775 Mdot
.78571 .01069 Mdot
.80952 .01455 Mdot
.83333 .01957 Mdot
.85714 .02617 Mdot
.88095 .03506 Mdot
.90476 .04757 Mdot
.92857 .0667 Mdot
.95238 .10054 Mdot
.97619 .18131 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Oooooo`009Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool06Oooool2o`0000Gooooo0_l0000Dooooo`;o00001Oooool2o`0000Kooooo
0_l00005ooooo`;o0000@?ooool00ol0003oooooooooo`0Oooooo`009Oooool00ol0003ooooooooo
o`3Eooooo`;o00001Oooool2o`0000Gooooo0_l0001Kooooo`009Oooool00ol0003oooooooooo`2R
ooooo`;o0000?oooool2o`0000Gooooo0_l0001Dooooo`009Oooool00ol0003oooooooooo`2Roooo
o`;o0000A_ooool2o`0005Cooooo000Uooooo`03o`000?oooooooooo0?7ooooo0_l0001=ooooo`00
9Oooool00ol0003oooooooooo`3aooooo`;o0000COooool002Gooooo0_l0003jooooo`;o0000AOoo
ool002Gooooo00?o0000ooooooooool0nOooool2o`0004Gooooo000Uooooo`03o`000?oooooooooo
0?oooooo0Oooool2o`0003kooooo000Uooooo`03o`000?oooooooooo09_ooooo0_l0001Sooooo`;o
0000?_ooool002Gooooo00?o0000ooooooooool0Voooool2o`000:?ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0ooooool8ooooo`;o0000=oooool0
02Gooooo0_l0003oooooo`Wooooo0_l0000gooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo3oooool2o`00033ooooo000Uooooo`03o`000?oooooooooo0?oooooo3oooool2o`00033o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0U?ooool2o`000:[ooooo000Uooooo`03o`000?oooooo
oooo09Cooooo0_l0002Zooooo`009Oooool2o`000?oooooo6?ooool2o`0002Sooooo000Uooooo`03
o`000?oooooooooo0?oooooo5oooool2o`0002Sooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Kooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooo
od7ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`00
7Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o
0000ooooooooool01Oooool2o`000?oooooo@_ooool001gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009?ooool2o`000?oooooo8?ooool2o`00027ooooo000Tooooo`;o0000oooooolPooooo`;o
00008Oooool002Gooooo00?o0000ooooooooool0S?ooool2o`000;;ooooo000Uooooo`03o`000?oo
oooooooo08cooooo0_l0002booooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`Go00001_ooool00ol0003ooooooooo
o`3ooooood7ooooo000Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003ooooooooo
o`03ooooo`;o0000oooooollooooo`006oooool00onHV9So8B4Qonk^kP07ooooo`;o00001?ooool2
o`000?oooooo??ooool001cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3ooooo
od7ooooo000Mooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`00
7_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go
0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`25ooooo`;o0000^Oooool0
02Gooooo0_l00026ooooo`;o0000^Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo07kooooo0_l00030ooooo`009Oooool2o`0004cooooo
0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo
0_l00005ooooo`;o0000`?ooool002Gooooo00?o0000ooooooooool02_ooool2o`0000Kooooo0_l0
0005ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l0
0005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l0
0005ooooo`;o00001_ooool2o`000<Oooooo000Uooooo`03o`000?oooooooooo00[ooooo0_l00006
ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005
ooooo`;o00001Oooool2o`000?[ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool001[ooooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001[ooooo00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood7ooooo
000Mooooo`03ojVYZOl@413ooooo00Gooooo0_l0003ooooood;ooooo000Looooo`03oa0@4?l0003o
^[Zj00Kooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00onj^[[o8B4Qooooo`05oooo
o`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go410@oiRHV?oooooo^[Zjo`000006oooo
o`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06oooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`007?ooool2o`000003
oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo1Ol00006ooooo`;o0000oooo
oom2ooooo`006_ooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo0?oooooo@Ooo
ool001[ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`3ooooood7ooooo000K
ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0oooooom1ooooo`006oooool00oo^
k^koA4A4o`000007ooooo`03o`000?oooooooooo0?oooooo@Oooool001cooooo00?oMgMgo`000?oo
ool01_ooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o
0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Kooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`3ooooood7ooooo000Nooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooom1ooooo`007oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo
@Oooool001kooooo00?oMgMgoc8b<_ooool01?ooool2o`000?oooooo@_ooool001_ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c03oooooodWooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool4o`000?ooooooB_ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool009Wooooo00GoV9RHo`000?l0003oA4A4okZj^P0I
ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Kooooo00?o0000onk^k_ooool01Oooool2
o`000003oa0@4?oooooooooo09?ooooo002Iooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6
o`0000cooooo00?o0000ooooooooool01?ooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01_ooool0
0ol0003oooooooooo`2Dooooo`00VOooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
00cooooo00?oZJVYoeEEEOooool00oooool5o`0009Gooooo002Iooooo`03o`000?oooooooooo00_o
oooo1_l0000<ooooo`03o`000?oooooooooo00gooooo00?o8B4Qooooooooool00_ooool01?m4A4Co
gMgMooooool0002Fooooo`00VOooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00go
oooo00?oEEEEolc<c?ooool00_ooool01?oMgMgoEEEEooooool0002Fooooo`00Uoooool00ol@413o
0000o`000003o`0001cooooo00?o0000ooooooooool03Oooool00onYZJWoMgMgooooo`03ooooo`03
ogMgMoo<c<co000009Kooooo002Iooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
2_ooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?ok^k^odA4A?l00000U_ooool009Wooooo
00?o0000ooooooooool06oooool00omEEEGoIVIVo`00000<ooooo`Go00001Oooool00omgMgOo0000
ooooo`2Eooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .18146 Mdot
.04762 .24394 Mdot
.07143 .29973 Mdot
.09524 .29965 Mdot
.11905 .29957 Mdot
.14286 .29948 Mdot
.16667 .29938 Mdot
.19048 .29928 Mdot
.21429 .29917 Mdot
.2381 .29905 Mdot
.2619 .29892 Mdot
.28571 .29879 Mdot
.30952 .29864 Mdot
.33333 .29848 Mdot
.35714 .29831 Mdot
.38095 .29809 Mdot
.40476 .29785 Mdot
.42857 .29745 Mdot
.45238 .29524 Mdot
.47619 .2915 Mdot
.5 .25539 Mdot
.52381 .15939 Mdot
.54762 .07278 Mdot
.57143 .02855 Mdot
.59524 .01083 Mdot
.61905 .0045 Mdot
.64286 .00256 Mdot
.66667 .00236 Mdot
.69048 .00298 Mdot
.71429 .00414 Mdot
.7381 .00581 Mdot
.7619 .00808 Mdot
.78571 .01105 Mdot
.80952 .01493 Mdot
.83333 .01996 Mdot
.85714 .02655 Mdot
.88095 .0354 Mdot
.90476 .04788 Mdot
.92857 .06695 Mdot
.95238 .10072 Mdot
.97619 .18146 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l00005ooooo`;o00001_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool07oooool002Gooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`15ooooo`03o`000?oooooooooo023ooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo
0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l00010ooooo`03o`000?oooooooooo01oooooo
000Uooooo`03o`000?oooooooooo0:Wooooo0_l0000Zooooo`;o00001Oooool2o`0000Gooooo0_l0
001Kooooo`009Oooool00ol0003oooooooooo`2Yooooo`;o0000>?ooool2o`0000Gooooo0_l0001D
ooooo`009Oooool00ol0003oooooooooo`3Zooooo`;o0000E?ooool002Gooooo00?o0000oooooooo
ool0lOooool2o`0004gooooo000Uooooo`03o`000?oooooooooo0?7ooooo0_l0001=ooooo`009Ooo
ool2o`000?[ooooo0_l00015ooooo`009Oooool00ol0003oooooooooo`2Rooooo`;o0000EOooool2
o`0004Gooooo000Uooooo`03o`000?oooooooooo0:;ooooo0_l0002Looooo`009Oooool00ol0003o
ooooooooo`3oooooo`7ooooo0_l0000nooooo`009Oooool00ol0003oooooooooo`3oooooo`7ooooo
0_l0000nooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo2?ooool2o`0003Oooooo000Uooooo`;o0000ooooool9ooooo`;o0000=oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3oooooo`oooooo0_l0000`ooooo`009Oooool00ol0003o
ooooooooo`3oooooo`oooooo0_l0000`ooooo`009Oooool00ol0003oooooooooo`2Kooooo`;o0000
Xoooool002Gooooo0_l0002Looooo`;o0000Xoooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooo
oaSooooo0_l0000Xooooo`009Oooool00ol0003oooooooooo`3ooooooaOooooo0_l0000Xooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`006oooool4o`000003oa0@4?oooooooooo
00?ooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo0_l0003ooooood;ooooo000M
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03oeEEEOmVIVKo000000Oooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`2Dooooo`;o0000Z_ooool002Gooooo00?o0000ooooooooool0U?ooool2
o`000:[ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooo
oom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Tooooo`;o0000oooooolPoooo
o`;o00008Oooool002Cooooo0_l0003oooooob3ooooo0_l0000Qooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`006_oo
ool5o`0000Kooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Kooooo00?o0000ooooooooool00oooool2o`000?oooooo??ooool001_ooooo00?oV9RH
ob4Q8Oo^k^h01oooool2o`0000Cooooo0_l0003ooooooccooooo000Looooo`03oiRHV?lQ8B7ok^k^
00Kooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00omgMgOoIVIVooooo`05ooooo`03
o`000?oooooooooo08cooooo0_l0002booooo`007_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo08cooooo0_l0002booooo`006_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo
00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0QOooool2o`000;Wooooo000Uooooo`03o`000?oooooooooo07ko
oooo0_l00005ooooo`;o0000^Oooool002Gooooo0_l0001Dooooo`;o00001Oooool2o`0000Gooooo
0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o0000`?ooool002Gooooo00?o
0000ooooooooool02_ooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l0
0005ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l0
0005ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`000<Oooooo000U
ooooo`03o`000?oooooooooo00[ooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005
ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l0003c
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooo
od;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oiRH
V?l@413o0000oc8b<_o<c<`01_ooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oa0@
4?nj^[[oooooogMgMolb<S801_ooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00onYZJWo410@oooo
o`05ooooo`;o0000oooooom2ooooo`007?ooool00ol@413o0000okZj^P06ooooo`03o`000?oooooo
oooo0?oooooo@Oooool001gooooo00?o^[Zjob4Q8Oooool01Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Jooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003oooooooooo`3ooooo
od7ooooo000Jooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0
003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool001cooooo0_l000000ol@413oooooooooo`04ooooo`03
o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Jooooo`Go00001_ooool2o`000?oooooo@_ooool001[ooooo00CoA4A4
omgMgOoooooo00001oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`04omgMgOmEEEGo
ooooo`0000Oooooo00?o0000ooooooooool0oooooom1ooooo`006oooool00omgMgOoc<c<o`000007
ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00?ok^k^odA4A?l000001oooool00ol0
003oooooooooo`3ooooood7ooooo000Looooo`03ogMgMol0003ooooo00Kooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o
0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`006oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom1oooo
o`007_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03ogMgMolb
<S;ooooo00Cooooo0_l0003ooooood;ooooo000Kooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0oooo
oom9ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo1?l0003ooooood[ooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo002Mooooo`05oiRHV?l0003o0000odA4A?nj^[X06Oooool4o`000003oa0@4?oooooo
oooo00;ooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0VOooool009gooooo00Go410@
okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?oo
ool01OlQ8B7oV9RHoooooonHV9So8B4Q09Wooooo002Mooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000009Wooooo002Mooooo`03o`000?oo
oooooooo00_ooooo1_l0000<ooooo`03o`000?oooooooooo00[ooooo00Go<S8boiRHV?ooooooV9RH
oc8b<P2Iooooo`00WOooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00[ooooo00Go
c<c<o`000?l0003o0000olc<c02Iooooo`00Voooool00ol@413o0000o`000003o`0001cooooo00?o
0000ooooooooool02_ooool01Ol@413o^[Zjoooooonj^[[o410@09Wooooo002Mooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool02_ooool01Ol0003o^[Zjoooooonj^[[o000009Wooooo
002Mooooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000003?ooool01OnYZJWo410@o`00
0?l@413oZJVY09Wooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.86) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .18159 Mdot
.04762 .24406 Mdot
.07143 .29984 Mdot
.09524 .29977 Mdot
.11905 .29969 Mdot
.14286 .2996 Mdot
.16667 .29951 Mdot
.19048 .29942 Mdot
.21429 .29932 Mdot
.2381 .29921 Mdot
.2619 .2991 Mdot
.28571 .29898 Mdot
.30952 .29884 Mdot
.33333 .2987 Mdot
.35714 .29854 Mdot
.38095 .29838 Mdot
.40476 .29814 Mdot
.42857 .29795 Mdot
.45238 .2972 Mdot
.47619 .29473 Mdot
.5 .28768 Mdot
.52381 .23301 Mdot
.54762 .13135 Mdot
.57143 .05668 Mdot
.59524 .02195 Mdot
.61905 .00864 Mdot
.64286 .00413 Mdot
.66667 .00303 Mdot
.69048 .00336 Mdot
.71429 .00444 Mdot
.7381 .00612 Mdot
.7619 .0084 Mdot
.78571 .0114 Mdot
.80952 .01529 Mdot
.83333 .02032 Mdot
.85714 .0269 Mdot
.88095 .03573 Mdot
.90476 .04816 Mdot
.92857 .06718 Mdot
.95238 .1009 Mdot
.97619 .18159 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo0_l00005ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Oooooo`009Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool08?ooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo
0_l00006ooooo`;o00001Oooool2o`00043ooooo00?o0000ooooooooool07oooool002Gooooo00?o
0000ooooooooool0/?ooool2o`0002?ooooo0_l00005ooooo`;o00001Oooool2o`0005_ooooo000U
ooooo`03o`000?oooooooooo0>?ooooo0_l00005ooooo`;o0000E?ooool002Gooooo00?o0000oooo
ooooool0j_ooool2o`0005Cooooo000Uooooo`03o`000?oooooooooo0?7ooooo0_l0001=ooooo`00
9Oooool00ol0003oooooooooo`2Yooooo`;o0000A_ooool2o`0004gooooo000Uooooo`;o0000Z_oo
ool2o`0004kooooo0_l00015ooooo`009Oooool00ol0003oooooooooo`3iooooo`;o0000AOooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3oooooo`7o
oooo0_l0000nooooo`009Oooool00ol0003oooooooooo`3oooooo`7ooooo0_l0000nooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo2?ooool2
o`0003Oooooo000Uooooo`;o0000ooooool9ooooo`;o0000=oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`2Rooooo`;o0000W?ooool002Gooooo00?o
0000ooooooooool0X_ooool2o`0009cooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0ooooool?ooooo`;o0000<?ooool002Gooooo00?o0000oooooooo
ool0ooooool?ooooo`;o0000<?ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooooaSooooo0_l0000Xoooo
o`009Oooool00ol0003oooooooooo`3ooooooaOooooo0_l0000Xooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`006oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooo
ooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo
000Mooooo`03o`000?oooooooooo00Gooooo0_l0003ooooood;ooooo000Mooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo09_ooooo0_l0002Sooooo`007Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo09_ooooo0_l0002Sooooo`006oooool00omEEEGoIVIVo`000007ooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Tooooo`;o0000oooooolPooooo`;o00008Oooool002Co
oooo0_l0003oooooob3ooooo0_l0000Qooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo09Co
oooo0_l0002Zooooo`009Oooool00ol0003oooooooooo`2Dooooo`;o0000Z_ooool001[ooooo1Ol0
0006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00GoV9RHob4Q8Oo^k^koooooodA4
A006ooooo`03o`000?oooooooooo00?ooooo0_l0003ooooooccooooo000Kooooo`03oiRHV?lQ8B7o
k^k^00Oooooo0_l00004ooooo`;o0000oooooollooooo`007?ooool00onHV9So8B4Qonk^kP06oooo
o`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?oMgMgofIVI_ooool01Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom1ooooo`006_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
oooooom1ooooo`006_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo08cooooo0_l0002booooo`009Oooool00ol0
003oooooooooo`2<ooooo`;o0000/_ooool002Gooooo00?o0000ooooooooool0QOooool2o`000;Wo
oooo000Uooooo`;o0000Foooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo
0_l00005ooooo`;o00001Oooool2o`000;Wooooo000Uooooo`03o`000?oooooooooo00[ooooo0_l0
0006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l0
0005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l0
0005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o0000`?ooool002Gooooo00?o0000
ooooooooool02_ooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00005
ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l0003[
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooo
od;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oiRH
V?l@413o0000oc8b<_o<c<`01_ooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oa0@
4?nj^[[oooooogMgMolb<S801_ooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00onYZJWo410@oooo
o`05ooooo`;o0000oooooom2ooooo`007?ooool00ol@413o0000okZj^P06ooooo`03o`000?oooooo
oooo0?oooooo@Oooool001gooooo00?o^[Zjob4Q8Oooool01Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Jooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003oooooooooo`3ooooo
od7ooooo000Jooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0
003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool001cooooo0_l000000ol@413oooooooooo`04ooooo`03
o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Jooooo`Go00001_ooool2o`000?oooooo@_ooool001[ooooo00CoA4A4
omgMgOoooooo00001oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`04omgMgOmEEEGo
ooooo`0000Oooooo00?o0000ooooooooool0oooooom1ooooo`006oooool00omgMgOoc<c<o`000007
ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00?ok^k^odA4A?l000001oooool00ol0
003oooooooooo`3ooooood7ooooo000Looooo`03ogMgMol0003ooooo00Kooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o
0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`006oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom1oooo
o`007_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03ogMgMolb
<S;ooooo00Cooooo0_l0003ooooood;ooooo000Kooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0oooo
oom9ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo1?l0003ooooood[ooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo002Iooooo`05oiRHV?l0003o0000odA4A?nj^[X06Oooool4o`000003oa0@4?oooooo
oooo00;ooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?l@413oc<c<09Gooooo002Iooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000cooooo
00?o0000ooooooooool01?ooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@03ooooo`05
oeEEEOmgMgOooooooiRHV?lQ8B40UOooool009Wooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0:ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000009Gooooo002Iooooo`03o`000?oooooooooo00_ooooo1_l0000<ooooo`03o`000?oooooooooo
00[ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P03ooooo`05o`000?nHV9SooooooiRHV?lQ8B40UOoo
ool009Wooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0:ooooo`05olc<c?l0003o
0000o`000?o<c<`00oooool01Ol0003oEEEEo`000?l@413oc<c<09Gooooo002Gooooo`03oa0@4?l0
003o000000?o00007?ooool00ol0003oooooooooo`0:ooooo`05oa0@4?nj^[[ooooookZj^_l@4100
0oooool00omEEEGoQhN7ooooo`2Gooooo`00VOooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00[ooooo00Go0000okZj^_oooooo^[Zjo`000003ooooo`03omgMgOl@413oV9RH09Oooooo
002Iooooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000003?ooool01OnYZJWo410@o`00
0?l@413oZJVY00Cooooo00Coc<c<odA4A?l0003o410@UOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.92) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .18172 Mdot
.04762 .24416 Mdot
.07143 .29994 Mdot
.09524 .29987 Mdot
.11905 .2998 Mdot
.14286 .29972 Mdot
.16667 .29964 Mdot
.19048 .29955 Mdot
.21429 .29946 Mdot
.2381 .29936 Mdot
.2619 .29926 Mdot
.28571 .29915 Mdot
.30952 .29903 Mdot
.33333 .2989 Mdot
.35714 .29876 Mdot
.38095 .29861 Mdot
.40476 .29845 Mdot
.42857 .2982 Mdot
.45238 .29804 Mdot
.47619 .29675 Mdot
.5 .29424 Mdot
.52381 .27996 Mdot
.54762 .20623 Mdot
.57143 .10612 Mdot
.59524 .04398 Mdot
.61905 .01714 Mdot
.64286 .00731 Mdot
.66667 .00428 Mdot
.69048 .00394 Mdot
.71429 .00481 Mdot
.7381 .00644 Mdot
.7619 .00872 Mdot
.78571 .01174 Mdot
.80952 .01564 Mdot
.83333 .02067 Mdot
.85714 .02724 Mdot
.88095 .03604 Mdot
.90476 .04843 Mdot
.92857 .0674 Mdot
.95238 .10106 Mdot
.97619 .18172 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01?ooool2o`0000Go
oooo0_l00005ooooo`;o00001_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool07oooool002Gooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`15ooooo`03o`000?oooooooooo02Sooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo
0_l00006ooooo`;o0000Aoooool00ol0003oooooooooo`0Oooooo`009Oooool00ol0003ooooooooo
o`2hooooo`;o00006oooool2o`0000Gooooo0_l00005ooooo`;o0000Foooool002Gooooo00?o0000
ooooooooool0g?ooool2o`0000Gooooo0_l0001Kooooo`009Oooool00ol0003oooooooooo`2`oooo
o`;o0000>?ooool2o`0005Cooooo000Uooooo`03o`000?oooooooooo0;3ooooo0_l0000hooooo`;o
00001Oooool2o`0004gooooo000Uooooo`03o`000?oooooooooo0?7ooooo0_l0001=ooooo`009Ooo
ool2o`000?[ooooo0_l00015ooooo`009Oooool00ol0003oooooooooo`3iooooo`;o0000AOooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3oooooo`7o
oooo0_l0000nooooo`009Oooool00ol0003oooooooooo`3oooooo`7ooooo0_l0000nooooo`009Ooo
ool00ol0003oooooooooo`2Yooooo`;o0000UOooool002Gooooo00?o0000ooooooooool0ZOooool2
o`0009Gooooo000Uooooo`;o0000ooooool9ooooo`;o0000=oooool002Gooooo00?o0000oooooooo
ool0ooooool8ooooo`;o0000=oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0ooooool?ooooo`;o0000<?ooool002Gooooo00?o0000oooooooo
ool0ooooool?ooooo`;o0000<?ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo5oooool2o`0002Sooooo000Uooooo`03o`000?oooooooooo0:;ooooo
0_l0001booooo`;o0000:?ooool002Gooooo00?o0000ooooooooool0X_ooool2o`0009cooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo1?l000000ol@413oooooooooo`03oooo
o`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`;o0000oooooom2ooooo`007Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0oooooom1ooooo`006oooool00omEEEGoIVIVo`000007ooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Tooooo`;o0000oooooolPooooo`;o00008Oooool002Co
oooo0_l0003oooooob3ooooo0_l0000Qooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`2Kooooo`;o0000Xoooool002Gooooo00?o0000ooooooooool0Vooo
ool2o`000:?ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo1Ol0
0006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00GoV9RHob4Q8Oo^k^koooooodA4
A006ooooo`03o`000?oooooooooo00?ooooo0_l0003ooooooccooooo000Kooooo`03oiRHV?lQ8B7o
k^k^00Oooooo0_l00004ooooo`;o0000oooooollooooo`007?ooool00onHV9So8B4Qonk^kP06oooo
o`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?oMgMgofIVI_ooool01Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom1ooooo`006_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
oooooom1ooooo`006_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0U?ooool2o`000:[ooooo000Uooooo`03o`000?oo
oooooooo09Cooooo0_l0002Zooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0S?ooool2o`000;;o
oooo000Uooooo`;o0000JOooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo
0_l00005ooooo`;o0000/_ooool002Gooooo00?o0000ooooooooool02_ooool2o`0000Kooooo0_l0
0005ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l0
0005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l0
0005ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o0000^Oooool002Gooooo00?o0000
ooooooooool02_ooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00005
ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005
ooooo`;o00001Oooool2o`000=gooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool001[ooooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001[ooooo00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood7ooooo
000Mooooo`03ojVYZOl@413ooooo00Gooooo0_l0003ooooood;ooooo000Looooo`03oa0@4?l0003o
^[Zj00Kooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00onj^[[o8B4Qooooo`05oooo
o`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go410@oiRHV?oooooo^[Zjo`000006oooo
o`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06oooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`007?ooool2o`000003
oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo1Ol00006ooooo`;o0000oooo
oom2ooooo`006_ooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo0?oooooo@Ooo
ool001[ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`3ooooood7ooooo000K
ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0oooooom1ooooo`006oooool00oo^
k^koA4A4o`000007ooooo`03o`000?oooooooooo0?oooooo@Oooool001cooooo00?oMgMgo`000?oo
ool01_ooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o
0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Kooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`3ooooood7ooooo000Nooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooom1ooooo`007oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo
@Oooool001kooooo00?oMgMgoc8b<_ooool01?ooool2o`000?oooooo@_ooool001_ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c03oooooodWooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool4o`000?ooooooB_ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool009Wooooo00GoV9RHo`000?l0003oA4A4okZj^P0I
ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Cooooo00Co410@o`000?m4A4Coc<c<1?oo
ool5o`0009Gooooo002Iooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000cooooo00?o
0000ooooooooool01?ooool2ob4Q8@Kooooo00?oV9RHoa0@4?oMgMd00oooool01OnHV9So8B4Qonk^
k_ooooooA4A409Gooooo002Iooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool03Ooo
ool00on7QhOoEEEEooooo`03ooooo`03oiRHV?lQ8B7ok^k^09Kooooo002Iooooo`03o`000?oooooo
oooo00_ooooo1_l0000<ooooo`03o`000?oooooooooo00[ooooo00Goc<c<ob4Q8Ol0003oEEEEo`00
0005ooooo`03oiRHV?lQ8B7ok^k^09Gooooo002Iooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool02_ooool01OlQ8B7oQhN7oooooonHV9So000000Kooooo00?oMgMgofIVI_ooool0U?oo
ool009Oooooo00?o410@o`000?l000000ol0000Looooo`03o`000?oooooooooo00[ooooo00Go0000
ooooooooooooooooo`000007ooooo`03o`000?oooooooooo09?ooooo002Iooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool02_ooool01OlQ8B7oV9RHoooooomgMgOoEEEE00?ooooo00Go
0000okZj^_ooooooV9RHoa0@402Eooooo`00VOooool00ol0003oooooooooo`0Kooooo`03oeEEEOmV
IVKo000000cooooo00Goc<c<oa0@4?l0003o<S8bonk^kP03ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`0UOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.98) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .18183 Mdot
.04762 .24426 Mdot
.07143 .30004 Mdot
.09524 .29997 Mdot
.11905 .2999 Mdot
.14286 .29983 Mdot
.16667 .29976 Mdot
.19048 .29968 Mdot
.21429 .29959 Mdot
.2381 .2995 Mdot
.2619 .2994 Mdot
.28571 .2993 Mdot
.30952 .29919 Mdot
.33333 .29908 Mdot
.35714 .29895 Mdot
.38095 .29881 Mdot
.40476 .29867 Mdot
.42857 .2985 Mdot
.45238 .29827 Mdot
.47619 .29805 Mdot
.5 .29617 Mdot
.52381 .29336 Mdot
.54762 .26689 Mdot
.57143 .17731 Mdot
.59524 .08453 Mdot
.61905 .03423 Mdot
.64286 .01381 Mdot
.66667 .00674 Mdot
.69048 .00496 Mdot
.71429 .00534 Mdot
.7381 .00681 Mdot
.7619 .00906 Mdot
.78571 .01207 Mdot
.80952 .01597 Mdot
.83333 .021 Mdot
.85714 .02755 Mdot
.88095 .03633 Mdot
.90476 .04868 Mdot
.92857 .0676 Mdot
.95238 .10121 Mdot
.97619 .18183 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool2o`0000Go
oooo0_l00006ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Oooooo`009Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0;oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0004Oooooo
00?o0000ooooooooool07oooool002Gooooo00?o0000ooooooooool0_oooool2o`0001Cooooo0_l0
0005ooooo`;o0000H_ooool002Gooooo00?o0000ooooooooool0^?ooool2o`0002;ooooo0_l00005
ooooo`;o0000Foooool002Gooooo00?o0000ooooooooool0^?ooool2o`0002Wooooo0_l00005oooo
o`;o0000E?ooool002Gooooo00?o0000ooooooooool0j_ooool2o`0000Gooooo0_l0001=ooooo`00
9Oooool00ol0003oooooooooo`3aooooo`;o0000COooool002Gooooo0_l0003jooooo`;o0000AOoo
ool002Gooooo00?o0000ooooooooool0nOooool2o`0004Gooooo000Uooooo`03o`000?oooooooooo
0;3ooooo0_l0002>ooooo`009Oooool00ol0003oooooooooo`2`ooooo`;o0000C_ooool2o`0003ko
oooo000Uooooo`03o`000?oooooooooo0?oooooo0Oooool2o`0003kooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`00
0?oooooo2Oooool2o`0003Oooooo000Uooooo`03o`000?oooooooooo0?oooooo2?ooool2o`0003Oo
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo3oooool2o`00033ooooo000Uooooo`03o`000?oooooooooo0?oooooo3oooool2o`00033o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`2Yooooo`;o0000UOooool002Gooooo00?o0000ooooooooool0
ZOooool2o`0009Gooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooooooo
ool0oooooolGooooo`;o0000:?ooool002Gooooo00?o0000ooooooooool0oooooolGooooo`;o0000
:?ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Kooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooo
od7ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`00
7Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o
0000ooooooooool01Oooool2o`000?oooooo@_ooool001gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0X_ooool2
o`0009cooooo000Tooooo`;o0000Y?ooool2o`0007Wooooo0_l0000Qooooo`009?ooool2o`000?oo
oooo8?ooool2o`00027ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`Go00001_ooool00ol0003ooooooooo
o`3ooooood7ooooo000Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003ooooooooo
o`03ooooo`;o0000oooooollooooo`006oooool00onHV9So8B4Qonk^kP07ooooo`;o00001?ooool2
o`000?oooooo??ooool001cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3ooooo
od7ooooo000Mooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`00
7_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go
0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0Voooool2o`000:?ooooo000Uooooo`03o`000?oooooooooo09_ooooo0_l0002S
ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo09Cooooo0_l0002Zooooo`009Oooool2o`00073ooooo
0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`000:[ooooo
000Uooooo`03o`000?oooooooooo00[ooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l0
0005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l0
0006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l0
0005ooooo`;o00001Oooool2o`0000Gooooo0_l0002booooo`009Oooool00ol0003oooooooooo`0:
ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006
ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l00005
ooooo`;o00001Oooool2o`000=Kooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool001[ooooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001[ooooo00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood7ooooo
000Mooooo`03ojVYZOl@413ooooo00Gooooo0_l0003ooooood;ooooo000Looooo`03oa0@4?l0003o
^[Zj00Kooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00onj^[[o8B4Qooooo`05oooo
o`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go410@oiRHV?oooooo^[Zjo`000006oooo
o`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06oooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`007?ooool2o`000003
oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo1Ol00006ooooo`;o0000oooo
oom2ooooo`006_ooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo0?oooooo@Ooo
ool001[ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`3ooooood7ooooo000K
ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0oooooom1ooooo`006oooool00oo^
k^koA4A4o`000007ooooo`03o`000?oooooooooo0?oooooo@Oooool001cooooo00?oMgMgo`000?oo
ool01_ooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o
0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Kooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`3ooooood7ooooo000Nooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0oooooom1ooooo`007oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo
@Oooool001kooooo00?oMgMgoc8b<_ooool01?ooool2o`000?oooooo@_ooool001_ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c03oooooodWooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool0
01_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool4o`000?ooooooB_ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool009Wooooo00GoV9RHo`000?l0003oA4A4okZj^P0I
ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Cooooo00Co410@o`000?m4A4Coc<c<1?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<09Gooooo002Iooooo`05oa0@4?nj^[[ok^k^ogMgMol@4100
2Oooool6o`0000cooooo00?o0000ooooooooool01?ooool2ob4Q8@Kooooo00?oV9RHoa0@4?oMgMd0
0oooool01OlQ8B7oV9RHoooooonHV9So8B4Q09Gooooo002Iooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool03Oooool00on7QhOoEEEEooooo`02ooooo`05o`000?ooooooooooooooool0
0000UOooool009Wooooo00?o0000ooooooooool02oooool6o`0000cooooo00?o0000ooooooooool0
2_ooool01Oo<c<co8B4Qo`000?mEEEGo000000?ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P2Eoooo
o`00VOooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00[ooooo00Go8B4QohN7Qooo
ooooV9RHo`000003ooooo`05olc<c?l0003o0000o`000?o<c<`0UOooool009Oooooo00?o410@o`00
0?l000000ol0000Looooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`000003
ooooo`05oa0@4?nj^[[ooooookZj^_l@4100UOooool009Wooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0:ooooo`05ob4Q8OnHV9SoooooogMgMomEEED00oooool01Ol0003o^[Zjoooo
oonj^[[o000009Gooooo002Iooooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000003?oo
ool01Oo<c<co410@o`000?lb<S;ok^k^00?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2Eooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.04) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .18194 Mdot
.04762 .24436 Mdot
.07143 .30013 Mdot
.09524 .30006 Mdot
.11905 .3 Mdot
.14286 .29993 Mdot
.16667 .29986 Mdot
.19048 .29979 Mdot
.21429 .29971 Mdot
.2381 .29963 Mdot
.2619 .29954 Mdot
.28571 .29944 Mdot
.30952 .29935 Mdot
.33333 .29924 Mdot
.35714 .29913 Mdot
.38095 .299 Mdot
.40476 .29887 Mdot
.42857 .29874 Mdot
.45238 .29854 Mdot
.47619 .29836 Mdot
.5 .2979 Mdot
.52381 .29559 Mdot
.54762 .2911 Mdot
.57143 .24794 Mdot
.59524 .14864 Mdot
.61905 .06683 Mdot
.64286 .02702 Mdot
.66667 .01174 Mdot
.69048 .00689 Mdot
.71429 .00619 Mdot
.7381 .00729 Mdot
.7619 .00942 Mdot
.78571 .01241 Mdot
.80952 .0163 Mdot
.83333 .02132 Mdot
.85714 .02786 Mdot
.88095 .03661 Mdot
.90476 .04892 Mdot
.92857 .06779 Mdot
.95238 .10135 Mdot
.97619 .18194 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Oooooo`009Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0=_ooool2o`0000Gooooo0_l00006ooooo`;o0000Aoooool00ol0003ooooo
ooooo`0Oooooo`009Oooool00ol0003oooooooooo`2oooooo`;o00001Oooool2o`0000Gooooo0_l0
0006ooooo`;o00001Oooool2o`0006;ooooo000Uooooo`03o`000?oooooooooo0;oooooo0_l0000K
ooooo`;o00001Oooool2o`0005_ooooo000Uooooo`03o`000?oooooooooo0>?ooooo0_l00005oooo
o`;o0000E?ooool002Gooooo00?o0000ooooooooool0j_ooool2o`0000Gooooo0_l0001=ooooo`00
9Oooool00ol0003oooooooooo`3aooooo`;o0000COooool002Gooooo0_l0002iooooo`;o0000?ooo
ool2o`0004Gooooo000Uooooo`03o`000?oooooooooo0;Sooooo0_l0000oooooo`;o0000AOooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3oooooo`7o
oooo0_l0000nooooo`009Oooool00ol0003oooooooooo`3oooooo`7ooooo0_l0000nooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo0_l0003oooooo`Wooooo0_l0000gooooo`009Oooool00ol0003oooooooooo`3oooooo`So
oooo0_l0000gooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`2`ooooo`;o0000G?ooool2o`00033ooooo000Uooooo`03o`000?oooooooooo0;3o
oooo0_l0001Looooo`;o0000<?ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo5oooool2o`0002Sooooo000Uooooo`03o`000?oooooooooo0?oooooo
5oooool2o`0002Sooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`006oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooo
ooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo
000Mooooo`03o`000?oooooooooo00Gooooo0_l0003ooooood;ooooo000Mooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Kooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo0_l0002Zooooo`;o0000UOooool002Gooooo00?o0000oooooooo
ool0ZOooool2o`0009Gooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Tooooo`;o0000oooooolPooooo`;o00008Oooool002Co
oooo0_l0003oooooob3ooooo0_l0000Qooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool5o`0000Kooooo00?o
0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o
0000ooooooooool00oooool2o`000?oooooo??ooool001_ooooo00?oV9RHob4Q8Oo^k^h01oooool2
o`0000Cooooo0_l0002Mooooo`;o0000W?ooool001cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0
003oooooooooo`2Rooooo`;o0000W?ooool001gooooo00?oMgMgofIVI_ooool01Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom1ooooo`006_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
oooooom1ooooo`006_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0Voooool2o`000:?ooooo000Uooooo`03o`000?oooooooooo09_ooooo0_l0002Sooooo`00
9Oooool2o`0007oooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l0002Zooooo`009Ooo
ool00ol0003oooooooooo`0:ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Ooo
ool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_oo
ool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Ooo
ool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`000:[ooooo000Uooooo`03o`000?oooooo
oooo00[ooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2
o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2
o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00037ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oiRHV?l@413o0000oc8b<_o<
c<`01_ooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oa0@4?nj^[[oooooogMgMolb
<S801_ooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom1ooooo`007Oooool00onYZJWo410@ooooo`05ooooo`;o0000oooo
oom2ooooo`007?ooool00ol@413o0000okZj^P06ooooo`03o`000?oooooooooo0?oooooo@Oooool0
01gooooo00?o^[Zjob4Q8Oooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05
oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05
ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool001cooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo
000Jooooo`Go00001_ooool2o`000?oooooo@_ooool001[ooooo00CoA4A4omgMgOoooooo00001ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o
0000ooooooooool0oooooom1ooooo`006oooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooo
oooo0?oooooo@Oooool001_ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`3ooooo
od7ooooo000Looooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`006oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom1ooooo`007_ooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03ogMgMolb<S;ooooo00Cooooo0_l0
003ooooood;ooooo000Kooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0oooooom9ooooo`006oooool0
0ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_o
oooo1?l0003ooooood[ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Ioooo
o`05oiRHV?l0003o0000odA4A?nj^[X06?ooool5o`0000Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2o`000003oa0@4?oooooooooo09?ooooo002Iooooo`05oa0@4?nj^[[o
k^k^ogMgMol@41002Oooool6o`0000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q
1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0U?ooool009Wooooo
00?o0000ooooooooool06oooool00onHV9So8B4Qonk^kP0<ooooo`05oa0@4?ooooooooooooooool@
41000oooool5o`0009Gooooo002Iooooo`03o`000?oooooooooo00_ooooo1_l0000;ooooo`03oiRH
V?lQ8B7ok^k^00_ooooo00Go0000ooooooooooooooooo`000003ooooo`04odA4A?oMgMgoooooo`00
09Kooooo002Iooooo`03o`000?oooooooooo01gooooo00?oMgMgofIVI_ooool02_ooool01Ol0003o
oooooooooooooooo000000?ooooo00CogMgMoeEEEOoooooo0000U_ooool009Oooooo00?o410@o`00
0?l000000ol0000Mooooo`03o`000?oooooooooo00Wooooo00Go410@oooooooooooooooooa0@4004
ooooo`03ogMgMoo<c<co000009Kooooo002Iooooo`03o`000?oooooooooo01[ooooo00Go0000okZj
^_ooooooV9RHoa0@400;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00oo^k^koA4A4o`00
002Fooooo`00VOooool00ol0003oooooooooo`0Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`02ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?oMgMgo`000?ooool0UOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.1) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .18205 Mdot
.04762 .24444 Mdot
.07143 .30021 Mdot
.09524 .30015 Mdot
.11905 .30009 Mdot
.14286 .30003 Mdot
.16667 .29996 Mdot
.19048 .29989 Mdot
.21429 .29982 Mdot
.2381 .29974 Mdot
.2619 .29966 Mdot
.28571 .29958 Mdot
.30952 .29948 Mdot
.33333 .29939 Mdot
.35714 .29928 Mdot
.38095 .29917 Mdot
.40476 .29905 Mdot
.42857 .29893 Mdot
.45238 .29879 Mdot
.47619 .29858 Mdot
.5 .29845 Mdot
.52381 .29755 Mdot
.54762 .29511 Mdot
.57143 .28599 Mdot
.59524 .22384 Mdot
.61905 .12216 Mdot
.64286 .05284 Mdot
.66667 .02193 Mdot
.69048 .01077 Mdot
.71429 .00774 Mdot
.7381 .00802 Mdot
.7619 .00987 Mdot
.78571 .01276 Mdot
.80952 .01662 Mdot
.83333 .02163 Mdot
.85714 .02815 Mdot
.88095 .03687 Mdot
.90476 .04915 Mdot
.92857 .06797 Mdot
.95238 .10149 Mdot
.97619 .18205 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Oooooo`009Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0?Oooool2o`0000Kooooo0_l00017ooooo`03o`000?oooooooooo01oooooo
000Uooooo`03o`000?oooooooooo0<Kooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l0
001Rooooo`009Oooool00ol0003oooooooooo`36ooooo`;o00005?ooool2o`0000Gooooo0_l0001K
ooooo`009Oooool00ol0003oooooooooo`3Sooooo`;o00001Oooool2o`0005Cooooo000Uooooo`03
o`000?oooooooooo0>[ooooo0_l00005ooooo`;o0000COooool002Gooooo00?o0000ooooooooool0
_oooool2o`00033ooooo0_l0001=ooooo`009Oooool2o`000<3ooooo0_l0000hooooo`;o0000AOoo
ool002Gooooo00?o0000ooooooooool0nOooool2o`0004Gooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0ooooool1ooooo`;o0000?_ooool002Gooooo
00?o0000ooooooooool0ooooool1ooooo`;o0000?_ooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000ooooool9oooo
o`;o0000=oooool002Gooooo00?o0000ooooooooool0^?ooool2o`0004gooooo0_l0000gooooo`00
9Oooool00ol0003oooooooooo`2hooooo`;o0000Q_ooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo3oooool2o`00033ooooo000Uooooo`03o`000?oooooooooo0?oooooo3oooool2o`00033o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooooaOo
oooo0_l0000Xooooo`009Oooool00ol0003oooooooooo`3ooooooaOooooo0_l0000Xooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
01_ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo@Oooool001go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool2o`0008kooooo000Mooooo`03o`000?oo
oooooooo00Gooooo0_l0002aooooo`;o0000S_ooool001gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009?ooool2o`000?oooooo8?ooool2o`00027ooooo000Tooooo`;o0000oooooolPooooo`;o
00008Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooo
od;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0
002Zooooo`;o0000UOooool002Gooooo00?o0000ooooooooool0ZOooool2o`0009Gooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`Go00001_ooool00ol0003ooooooooo
o`3ooooood7ooooo000Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003ooooooooo
o`03ooooo`;o0000oooooollooooo`006oooool00onHV9So8B4Qonk^kP07ooooo`;o00001?ooool2
o`000?oooooo??ooool001cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3ooooo
od7ooooo000Mooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`00
7_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go
0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`2Rooooo`;o0000W?ooool002Gooooo00?o0000ooooooooool0X_ooool2o`00
09cooooo000Uooooo`03o`000?oooooooooo09_ooooo0_l0002Sooooo`009Oooool2o`0008Kooooo
0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l0002Sooooo`009Oooool00ol0003ooooooooo
o`0:ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l0
0006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l0
0005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l0
0005ooooo`;o00001_ooool2o`000:[ooooo000Uooooo`03o`000?oooooooooo00[ooooo0_l00006
ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005
ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005
ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o0000`?ooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So410@o`000?lb<S;oc<c<00Ko
oooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Ko
oooo00?o0000ooooooooool0oooooom1ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo0?oooooo@Oooool001gooooo00?oZJVYoa0@4?ooool01Oooool2o`000?oooooo@_oo
ool001cooooo00?o410@o`000?nj^[X01_ooool00ol0003oooooooooo`3ooooood7ooooo000Moooo
o`03okZj^_lQ8B7ooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01Ol@413o
V9RHoooooonj^[[o000000Kooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnYZJWo
410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0
003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Looooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3ooooood7o
oooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`006_oo
ool5o`0000Kooooo0_l0003ooooood;ooooo000Jooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o
0000ooooooooool0oooooom1ooooo`006_ooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oo
oooooooo0?oooooo@Oooool001_ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3o
oooood7ooooo000Kooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom1oooo
o`007?ooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`3ooooood7ooooo000Oooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0oooooom1ooooo`007_ooool00omgMgOo<S8booooo`04ooooo`;o0000oooo
oom2ooooo`006oooool01Ol0003o8B4Qo`000?lb<S;oc<c<0?ooooooBOooool001_ooooo00?o0000
ooooooooool0oooooom;ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`Co
0000oooooom:ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00WOooool01OnH
V9So0000o`000?m4A4Co^[Zj01Sooooo1Ol00005ooooo`;o8B4Q1Oooool4o`000003oa0@4?oooooo
oooo09Kooooo002Mooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q1oooool00ol0003oooooooooo`2Hooooo`00WOooool0
0ol0003oooooooooo`0Kooooo`03oiRHV?lQ8B7ok^k^00oooooo00?o0000ooooooooool0V?ooool0
09gooooo00?o0000ooooooooool02oooool6o`0000_ooooo00?oV9RHob4Q8Oo^k^h03_ooool00ol0
003oooooooooo`2Hooooo`00WOooool00ol0003oooooooooo`0Mooooo`03ogMgMomVIVKooooo00go
oooo00?o0000ooooooooool0V?ooool009_ooooo00?o410@o`000?l000000ol0000Mooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0V?ooool009gooooo00?o0000ooooooooool06_oo
ool01Ol0003o^[ZjoooooonHV9So410@00kooooo00?o0000ooooooooool0V?ooool009gooooo00?o
0000ooooooooool06_ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l00000
V_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.16) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .18215 Mdot
.04762 .24452 Mdot
.07143 .30029 Mdot
.09524 .30023 Mdot
.11905 .30018 Mdot
.14286 .30012 Mdot
.16667 .30006 Mdot
.19048 .29999 Mdot
.21429 .29992 Mdot
.2381 .29985 Mdot
.2619 .29978 Mdot
.28571 .2997 Mdot
.30952 .29961 Mdot
.33333 .29952 Mdot
.35714 .29943 Mdot
.38095 .29933 Mdot
.40476 .29922 Mdot
.42857 .2991 Mdot
.45238 .29898 Mdot
.47619 .29884 Mdot
.5 .29863 Mdot
.52381 .29851 Mdot
.54762 .29702 Mdot
.57143 .29455 Mdot
.59524 .27645 Mdot
.61905 .19648 Mdot
.64286 .09912 Mdot
.66667 .04221 Mdot
.69048 .01864 Mdot
.71429 .01077 Mdot
.7381 .00928 Mdot
.7619 .01051 Mdot
.78571 .01318 Mdot
.80952 .01696 Mdot
.83333 .02193 Mdot
.85714 .02842 Mdot
.88095 .03712 Mdot
.90476 .04936 Mdot
.92857 .06815 Mdot
.95238 .10161 Mdot
.97619 .18215 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Oooooo`009Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01oooooo
000Uooooo`03o`000?oooooooooo0<gooooo0_l00006ooooo`;o00001Oooool2o`0006;ooooo000U
ooooo`03o`000?oooooooooo0<gooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l0001K
ooooo`009Oooool00ol0003oooooooooo`3Sooooo`;o00001Oooool2o`0005Cooooo000Uooooo`03
o`000?oooooooooo0<Kooooo0_l0000Rooooo`;o0000E?ooool002Gooooo00?o0000ooooooooool0
a_ooool2o`0002Wooooo0_l0001=ooooo`009Oooool2o`000?;ooooo0_l00006ooooo`;o0000AOoo
ool002Gooooo00?o0000ooooooooool0nOooool2o`0004Gooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0ooooool1ooooo`;o0000?_ooool002Gooooo
00?o0000ooooooooool0ooooool1ooooo`;o0000?_ooool002Gooooo00?o0000ooooooooool0_ooo
ool2o`0007oooooo000Uooooo`03o`000?oooooooooo0;oooooo0_l0001oooooo`009Oooool2o`00
0?oooooo2Oooool2o`0003Oooooo000Uooooo`03o`000?oooooooooo0?oooooo2?ooool2o`0003Oo
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0ooooool?ooooo`;o0000<?ooool002Gooooo
00?o0000ooooooooool0ooooool?ooooo`;o0000<?ooool002Gooooo0_l0003ooooood;ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`;o0000^Oooool2o`0008Kooooo000Uooooo`03o`000?oooooooooo0;So
oooo0_l0001Looooo`;o0000:?ooool002Gooooo00?o0000ooooooooool0oooooolGooooo`;o0000
:?ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Kooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooo
od7ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`00
7Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o
0000ooooooooool01Oooool2o`000?oooooo@_ooool001gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009?ooool2o`000?oooooo8?ooool2o`00027ooooo000Tooooo`;o0000oooooolPooooo`;o
00008Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0;3ooooo0_l0002>ooooo`009Oooool2o`00
0;7ooooo0_l0002>ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`Go00001_ooool00ol0003ooooooooo
o`3ooooood7ooooo000Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003ooooooooo
o`03ooooo`;o0000oooooollooooo`006oooool00onHV9So8B4Qonk^kP07ooooo`;o00001?ooool2
o`000?oooooo??ooool001cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3ooooo
od7ooooo000Mooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`00
7_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go
0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`2Yooooo`;o0000UOooool002Gooooo
00?o0000ooooooooool0ZOooool2o`0009Gooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0:;ooooo0_l0002Looooo`009Oooool2o`0008gooooo
0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l0002Looooo`009Oooool00ol0003ooooooooo
o`0:ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l0
0006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l0
0005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l0
0005ooooo`;o00001_ooool2o`0000Gooooo0_l0002Sooooo`009Oooool00ol0003oooooooooo`0:
ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006
ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l00005
ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l0002i
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooo
od;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oiRH
V?l@413o0000oc8b<_o<c<`01_ooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oa0@
4?nj^[[oooooogMgMolb<S801_ooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00onYZJWo410@oooo
o`05ooooo`;o0000oooooom2ooooo`007?ooool00ol@413o0000okZj^P06ooooo`03o`000?oooooo
oooo0?oooooo@Oooool001gooooo00?o^[Zjob4Q8Oooool01Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Jooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003oooooooooo`3ooooo
od7ooooo000Jooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0
003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool001cooooo0_l000000ol@413oooooooooo`04ooooo`03
o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Jooooo`Go00001_ooool2o`000?oooooo@_ooool001[ooooo00CoA4A4
omgMgOoooooo00001oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`04omgMgOmEEEGo
ooooo`0000Oooooo00?o0000ooooooooool0oooooom1ooooo`006oooool00omgMgOoc<c<o`000007
ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00?ok^k^odA4A?l000001oooool00ol0
003oooooooooo`3ooooood7ooooo000Looooo`03ogMgMol0003ooooo00Kooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o
0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`006oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom1oooo
o`007_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03ogMgMolb
<S;ooooo00Cooooo0_l0003ooooood;ooooo000Kooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0oooo
oom9ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo1?l0003ooooood[ooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo002Iooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool5o`0000Gooooo0_lQ8B45
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o410@olc<c9Gooooo002Iooooo`05oa0@
4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A005oooo
o`;o8B4Q1oooool00ol0003oooooooooo`02ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40UOooool0
09Wooooo00?o0000ooooooooool06oooool00onHV9So8B4Qonk^kP0?ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`00002Eooooo`00VOooool00ol0003oooooooooo`0;oooo
o`Ko00002oooool00onHV9So8B4Qonk^kP0>ooooo`03o`000?oooooooooo00;ooooo00Go0000oiRH
V?ooooooV9RHob4Q8@2Eooooo`00VOooool00ol0003oooooooooo`0Mooooo`03ogMgMomVIVKooooo
00gooooo00?o0000ooooooooool00_ooool01Ol0003oEEEEo`000?l@413oc<c<09Gooooo002Goooo
o`03oa0@4?l0003o000000?o00007Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00;ooooo00?oEEEEohN7Qoooool0Uoooool009Wooooo00?o0000ooooooooool06_ooool01Ol0003o
^[ZjoooooonHV9So410@00kooooo00?o0000ooooooooool00_ooool00ooMgMgo410@oiRHV02Goooo
o`00VOooool00ol0003oooooooooo`0Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool00omE
EEGoIVIVo`000005ooooo`04olc<c?m4A4Co0000oa0@49Gooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.22) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .18224 Mdot
.04762 .2446 Mdot
.07143 .30036 Mdot
.09524 .30031 Mdot
.11905 .30026 Mdot
.14286 .3002 Mdot
.16667 .30014 Mdot
.19048 .30008 Mdot
.21429 .30002 Mdot
.2381 .29995 Mdot
.2619 .29988 Mdot
.28571 .29981 Mdot
.30952 .29973 Mdot
.33333 .29965 Mdot
.35714 .29956 Mdot
.38095 .29947 Mdot
.40476 .29937 Mdot
.42857 .29927 Mdot
.45238 .29915 Mdot
.47619 .29904 Mdot
.5 .29888 Mdot
.52381 .2987 Mdot
.54762 .29845 Mdot
.57143 .29641 Mdot
.59524 .29331 Mdot
.61905 .26146 Mdot
.64286 .16826 Mdot
.66667 .08005 Mdot
.69048 .0345 Mdot
.71429 .01689 Mdot
.7381 .01168 Mdot
.7619 .01155 Mdot
.78571 .01374 Mdot
.80952 .01735 Mdot
.83333 .02224 Mdot
.85714 .0287 Mdot
.88095 .03736 Mdot
.90476 .04957 Mdot
.92857 .06831 Mdot
.95238 .10173 Mdot
.97619 .18224 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Oooooo`009Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01oooooo
000Uooooo`03o`000?oooooooooo0=Gooooo0_l00005ooooo`;o0000H_ooool002Gooooo00?o0000
ooooooooool0eOooool2o`0000Gooooo0_l00005ooooo`;o0000Foooool002Gooooo00?o0000oooo
ooooool0cOooool2o`0001Cooooo0_l00005ooooo`;o0000E?ooool002Gooooo00?o0000oooooooo
ool0cOooool2o`0001_ooooo0_l0001Dooooo`009Oooool00ol0003oooooooooo`3aooooo`;o0000
COooool002Gooooo0_l0003booooo`;o0000COooool002Gooooo00?o0000ooooooooool0nOooool2
o`0004Gooooo000Uooooo`03o`000?oooooooooo0<Kooooo0_l0000aooooo`;o0000AOooool002Go
oooo00?o0000ooooooooool0a_ooool2o`0003Sooooo0_l0000nooooo`009Oooool00ol0003ooooo
ooooo`3oooooo`7ooooo0_l0000nooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003oooooo`Wooooo0_l0000goooo
o`009Oooool00ol0003oooooooooo`3oooooo`Sooooo0_l0000gooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo3oooool2o`00033ooooo000Uooooo`03o`000?oooooooooo0?oooooo
3oooool2o`00033ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`2o
ooooo`;o0000Ooooool002Gooooo00?o0000ooooooooool0_oooool2o`0007oooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo5oooool2o`0002So
oooo000Uooooo`03o`000?oooooooooo0?oooooo5oooool2o`0002Sooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`006oooool4o`00
0003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo0_l0
003ooooood;ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1
ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03oeEE
EOmVIVKo000000Oooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooo
od;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`2hooooo`;o0000Q_ooool002Gooooo00?o0000ooooooooool0^?ooool2o`0008Kooooo
000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Toooo
o`;o0000oooooolPooooo`;o00008Oooool002Cooooo0_l0003oooooob3ooooo0_l0000Qooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_oo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`006_ooool5o`0000Kooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool00oooool2o`000?oooooo??oo
ool001_ooooo00?oV9RHob4Q8Oo^k^h01oooool2o`0000Cooooo0_l0003ooooooccooooo000Loooo
o`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00omgMgOo
IVIVooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05o`000?nj^[[ooooooiRHV?l@4100
1_ooool00ol0003oooooooooo`2`ooooo`;o0000S_ooool001[ooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c006ooooo`03o`000?oooooooooo0;3ooooo0_l0002>ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooo
od;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`2Yooooo`;o0000UOooool002Gooooo0_l0002Eooooo`;o00001Oooool2o`0000Gooooo
0_l00005ooooo`;o0000UOooool002Gooooo00?o0000ooooooooool02_ooool2o`0000Kooooo0_l0
0005ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l0
0005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l0
0005ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l0
0005ooooo`;o00001Oooool2o`0009cooooo000Uooooo`03o`000?oooooooooo00[ooooo0_l00006
ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005
ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005
ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l0002b
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooo
od;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oiRH
V?l@413o0000oc8b<_o<c<`01_ooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oa0@
4?nj^[[oooooogMgMolb<S801_ooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00onYZJWo410@oooo
o`05ooooo`;o0000oooooom2ooooo`007?ooool00ol@413o0000okZj^P06ooooo`03o`000?oooooo
oooo0?oooooo@Oooool001gooooo00?o^[Zjob4Q8Oooool01Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Jooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003oooooooooo`3ooooo
od7ooooo000Jooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0
003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool001cooooo0_l000000ol@413oooooooooo`04ooooo`03
o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Jooooo`Go00001_ooool2o`000?oooooo@_ooool001[ooooo00CoA4A4
omgMgOoooooo00001oooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`04omgMgOmEEEGo
ooooo`0000Oooooo00?o0000ooooooooool0oooooom1ooooo`006oooool00omgMgOoc<c<o`000007
ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00?ok^k^odA4A?l000001oooool00ol0
003oooooooooo`3ooooood7ooooo000Looooo`03ogMgMol0003ooooo00Kooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o
0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`006oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom1oooo
o`007_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooood7ooooo000Nooooo`03ogMgMolb
<S;ooooo00Cooooo0_l0003ooooood;ooooo000Kooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0oooo
oom9ooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo1?l0003ooooood[ooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo002Iooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool5o`0000Gooooo0_lQ8B44
ooooo`Go00000oooool5o`0009Gooooo002Iooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6
o`0000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^
k_ooooooA4A400?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A02Eooooo`00VOooool00ol0003ooooo
ooooo`0Kooooo`03oiRHV?lQ8B7ok^k^00gooooo00?oV9RHob4Q8Oo^k^h01Oooool00onHV9So8B4Q
onk^kP2Fooooo`00VOooool00ol0003oooooooooo`0;ooooo`Ko00002oooool00onHV9So8B4Qonk^
kP0=ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?oV9RHob4Q8Oo^k^h0UOooool009Wooooo00?o0000
ooooooooool07Oooool00omgMgOoIVIVooooo`0=ooooo`03ogMgMomVIVKooooo00Gooooo00?oMgMg
ofIVI_ooool0U?ooool009Oooooo00?o410@o`000?l000000ol0000Mooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Cooooo`00VOooool00ol0003o
ooooooooo`0Jooooo`05o`000?nj^[[ooooooiRHV?l@41002oooool01Ol0003o^[ZjoooooonHV9So
410@00?ooooo00Go0000okZj^_ooooooV9RHoa0@402Eooooo`00VOooool00ol0003oooooooooo`0J
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`02oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c02Eooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.28) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .18232 Mdot
.04762 .24467 Mdot
.07143 .30043 Mdot
.09524 .30038 Mdot
.11905 .30033 Mdot
.14286 .30028 Mdot
.16667 .30022 Mdot
.19048 .30017 Mdot
.21429 .30011 Mdot
.2381 .30005 Mdot
.2619 .29998 Mdot
.28571 .29991 Mdot
.30952 .29984 Mdot
.33333 .29976 Mdot
.35714 .29968 Mdot
.38095 .2996 Mdot
.40476 .29951 Mdot
.42857 .29941 Mdot
.45238 .29931 Mdot
.47619 .2992 Mdot
.5 .29909 Mdot
.52381 .29891 Mdot
.54762 .29878 Mdot
.57143 .29823 Mdot
.59524 .29586 Mdot
.61905 .29024 Mdot
.64286 .24112 Mdot
.66667 .14144 Mdot
.69048 .06498 Mdot
.71429 .02928 Mdot
.7381 .01647 Mdot
.7619 .01347 Mdot
.78571 .01461 Mdot
.80952 .01784 Mdot
.83333 .02259 Mdot
.85714 .02897 Mdot
.88095 .03759 Mdot
.90476 .04976 Mdot
.92857 .06847 Mdot
.95238 .10185 Mdot
.97619 .18232 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Oooooo`009Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01oooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0g?ooool2
o`0000Gooooo0_l0001Kooooo`009Oooool00ol0003oooooooooo`3Eooooo`;o00001Oooool2o`00
00Gooooo0_l00005ooooo`;o0000E?ooool002Gooooo00?o0000ooooooooool0eOooool2o`0001?o
oooo0_l0001Dooooo`009Oooool00ol0003oooooooooo`3aooooo`;o0000COooool002Gooooo0_l0
003booooo`;o0000COooool002Gooooo00?o0000ooooooooool0cOooool2o`0002[ooooo0_l00015
ooooo`009Oooool00ol0003oooooooooo`3=ooooo`;o0000:_ooool2o`0004Gooooo000Uooooo`03
o`000?oooooooooo0?oooooo0Oooool2o`0003kooooo000Uooooo`03o`000?oooooooooo0?oooooo
0Oooool2o`0003kooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo2Oooool2o`0003Oooooo000Uooooo`03
o`000?oooooooooo0?oooooo2?ooool2o`0003Oooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0<Kooooo0_l0001hooooo`009Oooool00ol0003o
ooooooooo`36ooooo`;o0000A_ooool2o`00033ooooo000Uooooo`03o`000?oooooooooo0?oooooo
3oooool2o`00033ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`00
0?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooolGooooo`;o0000:?ooool002Gooooo
00?o0000ooooooooool0oooooolGooooo`;o0000:?ooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`Co000000?o410@oooo
ooooool00oooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool2o`000?oooooo@_oo
ool001gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Moooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00?oEEEEofIVI_l00000
1oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0;oooooo0_l0
001oooooo`009Oooool00ol0003oooooooooo`2oooooo`;o0000Ooooool002Gooooo0_l0003ooooo
od;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0
003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Cooooo0_l0003ooooo
ob3ooooo0_l0000Qooooo`009?ooool2o`000?oooooo8?ooool2o`00027ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Jooooo`Go00001_ooool00ol0003oooooooooo`2hooooo`;o0000Q_ooool001[ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo00?ooooo0_l0002cooooo`;o0000Q_oo
ool001_ooooo00?oV9RHob4Q8Oo^k^h01oooool2o`0000Cooooo0_l0003ooooooccooooo000Loooo
o`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00omgMgOo
IVIVooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05o`000?nj^[[ooooooiRHV?l@4100
1_ooool00ol0003oooooooooo`3ooooood7ooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
1_ooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`2`ooooo`;o0000S_ooool002Gooooo00?o0000oooooooo
ool0/?ooool2o`0008kooooo000Uooooo`;o0000Xoooool2o`0000Gooooo0_l0002Eooooo`009Ooo
ool00ol0003oooooooooo`0:ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Ooo
ool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_oo
ool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Ooo
ool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Ooo
ool2o`0009Gooooo000Uooooo`03o`000?oooooooooo00[ooooo0_l00006ooooo`;o00001Oooool2
o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2
o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2
o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2
o`000:?ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`00
0?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo
00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo
00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03ojVYZOl@
413ooooo00Gooooo0_l0003ooooood;ooooo000Looooo`03oa0@4?l0003o^[Zj00Kooooo00?o0000
ooooooooool0oooooom1ooooo`007Oooool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo
0?oooooo@Oooool001[ooooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooooooo
0?oooooo@Oooool001[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`007?ooool2o`000003oa0@4?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0?oooooo@Oooool001[ooooo1Ol00006ooooo`;o0000oooooom2ooooo`006_ooool0
1?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00CogMgM
oeEEEOoooooo00001oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03ogMgMoo<c<co
000000Oooooo00?o0000ooooooooool0oooooom1ooooo`006oooool00oo^k^koA4A4o`000007oooo
o`03o`000?oooooooooo0?oooooo@Oooool001cooooo00?oMgMgo`000?ooool01_ooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Kooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Nooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`00
7oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo00?o
MgMgoc8b<_ooool01?ooool2o`000?oooooo@_ooool001_ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c03oooooodWooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool4o`000?ooooooB_ooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool009Wooooo00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`Go00001Oooool2
ob4Q8@Cooooo1Ol00003ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0UOooool009Wooooo00Go410@
okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OlQ8B7oV9RHoooooonHV9So8B4Q
09Gooooo002Iooooo`03o`000?oooooooooo01_ooooo00?oV9RHob4Q8Oo^k^h03Oooool00onHV9So
8B4Qonk^kP04ooooo`05o`000?ooooooooooooooool00000UOooool009Wooooo00?o0000oooooooo
ool02oooool6o`0000_ooooo00?oV9RHob4Q8Oo^k^h03Oooool00onHV9So8B4Qonk^kP03ooooo`05
oc8b<_nHV9SooooooiRHV?lb<S80UOooool009Wooooo00?o0000ooooooooool07Oooool00omgMgOo
IVIVooooo`0=ooooo`03ogMgMomVIVKooooo00;ooooo00Goc<c<o`000?l0003o0000olc<c02Eoooo
o`00Uoooool00ol@413o0000o`000003o`0001gooooo00?o0000ooooooooool03Oooool02Ol0003o
oooooooooooooooo410@okZj^_oooooo^[Zjoa0@402Eooooo`00VOooool00ol0003oooooooooo`0J
ooooo`05o`000?nj^[[ooooooiRHV?l@41002oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo
00Go0000okZj^_oooooo^[Zjo`00002Eooooo`00VOooool00ol0003oooooooooo`0Jooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`02oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00GoZJVYoa0@
4?l0003o410@ojVYZ@2Eooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.34) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .18241 Mdot
.04762 .24474 Mdot
.07143 .30049 Mdot
.09524 .30045 Mdot
.11905 .3004 Mdot
.14286 .30035 Mdot
.16667 .3003 Mdot
.19048 .30025 Mdot
.21429 .30019 Mdot
.2381 .30013 Mdot
.2619 .30007 Mdot
.28571 .30001 Mdot
.30952 .29994 Mdot
.33333 .29987 Mdot
.35714 .2998 Mdot
.38095 .29972 Mdot
.40476 .29963 Mdot
.42857 .29955 Mdot
.45238 .29945 Mdot
.47619 .29935 Mdot
.5 .29924 Mdot
.52381 .29913 Mdot
.54762 .29894 Mdot
.57143 .29886 Mdot
.59524 .2978 Mdot
.61905 .29537 Mdot
.64286 .28392 Mdot
.66667 .21675 Mdot
.69048 .11763 Mdot
.71429 .05361 Mdot
.7381 .02618 Mdot
.7619 .01725 Mdot
.78571 .01617 Mdot
.80952 .01857 Mdot
.83333 .02302 Mdot
.85714 .02928 Mdot
.88095 .03783 Mdot
.90476 .04995 Mdot
.92857 .06862 Mdot
.95238 .10196 Mdot
.97619 .18241 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Oooooo`009Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01oooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3Looooo`;o00001Oooool2o`0000Gooooo0_l0001Doooo
o`009Oooool00ol0003oooooooooo`3Looooo`;o00001Oooool2o`0000Gooooo0_l0001Dooooo`00
9Oooool00ol0003oooooooooo`3aooooo`;o0000COooool002Gooooo0_l0003Fooooo`;o00006_oo
ool2o`0004gooooo000Uooooo`03o`000?oooooooooo0=Gooooo0_l0000Rooooo`;o0000AOooool0
02Gooooo00?o0000ooooooooool0nOooool2o`0004Gooooo000Uooooo`03o`000?oooooooooo0?oo
oooo0Oooool2o`0003kooooo000Uooooo`03o`000?oooooooooo0?oooooo0Oooool2o`0003kooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool2o`000?oooooo2Oooool2o`0003Oooooo000Uooooo`03o`000?oooooooooo0<go
oooo0_l0000hooooo`;o0000=oooool002Gooooo00?o0000ooooooooool0cOooool2o`00077ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo3oooool2o`00033ooooo000Uooooo`03o`000?oooooooooo0?oooooo3oooool2o`00033ooooo
000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Go
oooo00?o0000ooooooooool0oooooolGooooo`;o0000:?ooool002Gooooo00?o0000ooooooooool0
oooooolGooooo`;o0000:?ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Kooooo`Co000000?o410@ooooooooool00oooool00ol0
003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0a_ooool2o`0007Sooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
a_ooool2o`0007Sooooo000Mooooo`03o`000?oooooooooo00Gooooo0_l0003ooooood;ooooo000M
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03oeEEEOmVIVKo000000Oooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Cooooo0_l0003oooooob3ooooo0_l0000Qoooo
o`009?ooool2o`000?oooooo8?ooool2o`00027ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0_oooool2o`0007oooooo000Uooooo`03o`00
0?oooooooooo0;oooooo0_l0001oooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`006_oo
ool5o`0000Kooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Kooooo00?o0000ooooooooool00oooool2o`000?oooooo??ooool001_ooooo00?oV9RH
ob4Q8Oo^k^h01oooool2o`0000Cooooo0_l0003ooooooccooooo000Looooo`03oiRHV?lQ8B7ok^k^
00Kooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00omgMgOoIVIVooooo`05ooooo`03
o`000?oooooooooo0?oooooo@Oooool001kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3ooooood7ooooo000Jooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003ooooo
ooooo`3ooooood7ooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0;Sooooo0_l00026ooooo`009Oooool00ol0003oooooooooo`2hooooo`;o0000Q_ooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`2`ooooo`;o
0000S_ooool002Gooooo0_l0002Zooooo`;o00001Oooool2o`0008kooooo000Uooooo`03o`000?oo
oooooooo00[ooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Ooo
ool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Ooo
ool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Ooo
ool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o0000UOoo
ool002Gooooo00?o0000ooooooooool02_ooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2
o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2
o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2
o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2
o`0009cooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`00
0?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo
00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo
00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03ojVYZOl@
413ooooo00Gooooo0_l0003ooooood;ooooo000Looooo`03oa0@4?l0003o^[Zj00Kooooo00?o0000
ooooooooool0oooooom1ooooo`007Oooool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo
0?oooooo@Oooool001[ooooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooooooo
0?oooooo@Oooool001[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooooooo
ool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`007?ooool2o`000003oa0@4?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0?oooooo@Oooool001[ooooo1Ol00006ooooo`;o0000oooooom2ooooo`006_ooool0
1?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo0?oooooo@Oooool001[ooooo00CogMgM
oeEEEOoooooo00001oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03ogMgMoo<c<co
000000Oooooo00?o0000ooooooooool0oooooom1ooooo`006oooool00oo^k^koA4A4o`000007oooo
o`03o`000?oooooooooo0?oooooo@Oooool001cooooo00?oMgMgo`000?ooool01_ooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Kooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Nooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom1ooooo`00
7oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo@Oooool001kooooo00?o
MgMgoc8b<_ooool01?ooool2o`000?oooooo@_ooool001_ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c03oooooodWooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001_ooooo00?o0000oooo
ooooool0oooooom;ooooo`006oooool4o`000?ooooooB_ooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool009Wooooo00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`Go00001Oooool2
ob4Q8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c005ooooo`;o000000?o410@ooooooooool0Tooo
ool009Wooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002Oooool01OnHV9So8B4Qonk^
k_ooooooA4A400Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S801_ooool00ol0003o
ooooooooo`2Dooooo`00VOooool00ol0003oooooooooo`0Kooooo`03oiRHV?lQ8B7ok^k^013ooooo
00Co0000oooooooooooooooo1Ol0002Eooooo`00VOooool00ol0003oooooooooo`0;ooooo`Ko0000
2oooool00onHV9So8B4Qonk^kP0>ooooo`03ojVYZOl@413ooooo00;ooooo00CoA4A4omgMgOoooooo
0000U_ooool009Wooooo00?o0000ooooooooool07Oooool00omgMgOoIVIVooooo`0<ooooo`03oa0@
4?l0003o^[Zj00?ooooo00CogMgMoeEEEOoooooo0000U_ooool009Oooooo00?o410@o`000?l00000
0ol0000Mooooo`03o`000?oooooooooo00cooooo00?o^[Zjob4Q8Oooool00oooool00omgMgOoc<c<
o`00002Fooooo`00VOooool00ol0003oooooooooo`0Jooooo`05o`000?nj^[[ooooooiRHV?l@4100
2oooool01Ol@413oV9RHoooooonj^[[o000000Cooooo00?ok^k^odA4A?l00000U_ooool009Wooooo
00?o0000ooooooooool06_ooool01OnHV9So410@o`000?lQ8B7oc<c<00_ooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@05ooooo`03ogMgMol0003ooooo09Gooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0 0.123607 [
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.01131 .12361 -6 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -6 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -6 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(1)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(2)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(3)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(4)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(5)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .02472 m
.02756 .02472 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .09889 m
.02756 .09889 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .17305 m
.02756 .17305 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .27193 m
.02756 .27193 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .46971 m
.02756 .46971 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .56859 m
.02756 .56859 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.4) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .18249 Mdot
.04762 .24481 Mdot
.07143 .30055 Mdot
.09524 .30051 Mdot
.11905 .30047 Mdot
.14286 .30042 Mdot
.16667 .30037 Mdot
.19048 .30032 Mdot
.21429 .30027 Mdot
.2381 .30022 Mdot
.2619 .30016 Mdot
.28571 .3001 Mdot
.30952 .30004 Mdot
.33333 .29997 Mdot
.35714 .2999 Mdot
.38095 .29983 Mdot
.40476 .29975 Mdot
.42857 .29967 Mdot
.45238 .29958 Mdot
.47619 .29949 Mdot
.5 .29939 Mdot
.52381 .29929 Mdot
.54762 .29917 Mdot
.57143 .29898 Mdot
.59524 .29887 Mdot
.61905 .29723 Mdot
.64286 .29465 Mdot
.66667 .27313 Mdot
.69048 .19053 Mdot
.71429 .09768 Mdot
.7381 .04553 Mdot
.7619 .02491 Mdot
.78571 .01919 Mdot
.80952 .01985 Mdot
.83333 .02364 Mdot
.85714 .02965 Mdot
.88095 .03809 Mdot
.90476 .05015 Mdot
.92857 .06876 Mdot
.95238 .10206 Mdot
.97619 .18249 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool4o`000003oa0@4?oooooooooo043ooooo1Ol00013ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0A_ooool2o`000003oa0@4?oooooooooo01kooooo001]ooooo`03
o`000?oooooooooo04;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A013ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80Aoooool00ol0003oooooooooo`0Oooooo`00KOooool00ol0003oooooooooo`13oooo
o`03oiRHV?lQ8B7ok^k^04Sooooo00?o0000ooooooooool0@_ooool5o`00023ooooo001]ooooo`03
o`000?oooooooooo04Cooooo00?oV9RHob4Q8Oo^k^h0A_ooool00onYZJWo410@ooooo`13ooooo`04
odA4A?oMgMgoooooo`00027ooooo001]ooooo`03o`000?oooooooooo04Gooooo00?oMgMgofIVI_oo
ool0A?ooool00ol@413o0000okZj^P14ooooo`04omgMgOmEEEGoooooo`00027ooooo001]ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0A?ooool00onj^[[o8B4Qooooo`14ooooo`03
ogMgMoo<c<co0000027ooooo001]ooooo`03o`000?oooooooooo04;ooooo00Go0000okZj^_oooooo
V9RHoa0@4013ooooo`05oa0@4?nHV9SooooookZj^_l00000AOooool00oo^k^koA4A4o`00000Qoooo
o`00Joooool00omEEEGoIVIVo`000014ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0@oooool01OnY
ZJWo410@o`000?l@413oZJVY04Kooooo00?oMgMgo`000?ooool08?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001goooooool0000bo`00
01[ooooo000Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Oooooo`009Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01oooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0>?o
oooo0_l00005ooooo`;o0000E?ooool002Gooooo00?o0000ooooooooool0g?ooool2o`0000Gooooo
0_l00005ooooo`;o00001Oooool2o`0004gooooo000Uooooo`;o0000gOooool2o`0001?ooooo0_l0
001=ooooo`009Oooool00ol0003oooooooooo`3iooooo`;o0000AOooool002Gooooo00?o0000oooo
ooooool0nOooool2o`0004Gooooo000Uooooo`03o`000?oooooooooo0?oooooo0Oooool2o`0003ko
oooo000Uooooo`03o`000?oooooooooo0?oooooo0Oooool2o`0003kooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0eOooool2o`0006Wooooo000Uoooo
o`;o0000e_ooool2o`00033ooooo0_l0000gooooo`009Oooool00ol0003oooooooooo`3oooooo`So
oooo0_l0000gooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oo
oooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo3oooool2o`00033o
oooo000Uooooo`03o`000?oooooooooo0?oooooo3oooool2o`00033ooooo000Uooooo`;o0000oooo
oom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooo
ooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0cOooool2o`00077ooooo000Uooooo`;o0000c_ooool2o`00077ooooo000Uooooo`03
o`000?oooooooooo0?oooooo5oooool2o`0002Sooooo000Uooooo`03o`000?oooooooooo0?oooooo
5oooool2o`0002Sooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000
ooooooooool0oooooom1ooooo`006oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooo
ooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood7ooooo
000Mooooo`03o`000?oooooooooo00Gooooo0_l0003ooooood;ooooo000Mooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0oooooom1ooooo`007Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Kooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Cooooo0_l0003oooooob3ooooo0_l0000Qooooo`009?ooool2o`000?oo
oooo8?ooool2o`00027ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0a_ooool2o`0007Sooooo000Uooooo`03o`000?oooooooooo0<Kooooo0_l0001h
ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0
oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oo
oooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool5o`0000Kooooo00?o
0000ooooooooool0oooooom1ooooo`006_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o
0000ooooooooool00oooool2o`000?oooooo??ooool001_ooooo00?oV9RHob4Q8Oo^k^h01oooool2
o`0000Cooooo0_l0003ooooooccooooo000Looooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000oooo
ooooool0oooooom1ooooo`007Oooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood7ooooo
000Jooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`3ooooood7ooooo
000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool2o`000<3ooooo0_l0001oooooo`009Oooool00ol0003oooooooooo`2oooooo`;o
0000Ooooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003ooooooooo
o`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`2hooooo`;o0000Q_ooool002Gooooo
0_l0002aooooo`;o00001_ooool2o`0008Kooooo000Uooooo`03o`000?oooooooooo00[ooooo0_l0
0006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l0
0005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l0
0005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l0
0006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0008kooooo000U
ooooo`03o`000?oooooooooo00[ooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005
ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00006
ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005
ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005
ooooo`;o0000UOooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
6_ooool01OnHV9So410@o`000?lb<S;oc<c<00Kooooo00?o0000ooooooooool0oooooom1ooooo`00
6_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Kooooo00?o0000ooooooooool0oooooom1ooooo`00
7_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@Oooool001gooooo00?o
ZJVYoa0@4?ooool01Oooool2o`000?oooooo@_ooool001cooooo00?o410@o`000?nj^[X01_ooool0
0ol0003oooooooooo`3ooooood7ooooo000Mooooo`03okZj^_lQ8B7ooooo00Gooooo00?o0000oooo
ooooool0oooooom1ooooo`006_ooool01Ol@413oV9RHoooooonj^[[o000000Kooooo00?o0000oooo
ooooool0oooooom1ooooo`006_ooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000oooo
ooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`000?oooooo
oooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003o
ooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o
0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;ooooo000Uooooo`03o`00
0?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool0
0ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Go
oooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uoooo
o`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`00
9Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Ooo
ool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooo
od7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo
000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1
ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Looooo`;o000000?o410@oooooooo
ool01?ooool00ol0003oooooooooo`3ooooood7ooooo000Mooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooom1ooooo`006_ooool5o`0000Kooooo0_l0003ooooood;ooooo000J
ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0oooooom1ooooo`006_ooool0
1?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo0?oooooo@Oooool001_ooooo00?oMgMg
olc<c?l000001oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03onk^k_m4A4Co0000
00Oooooo00?o0000ooooooooool0oooooom1ooooo`007?ooool00omgMgOo0000ooooo`06ooooo`03
o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`;o0000oooooom2ooooo`009Oooool00ol0
003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo
00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000U
ooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Ooo
ool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool0
02Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool2o`000?oooooo@_ooool002Gooooo00?o0000ooooooooool0oooooom1oooo
o`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo
@Oooool002Gooooo00?o0000ooooooooool0oooooom1ooooo`009Oooool00ol0003oooooooooo`3o
oooood7ooooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo0_l0003ooooood;o
oooo000Uooooo`03o`000?oooooooooo0?oooooo@Oooool002Gooooo00?o0000ooooooooool0oooo
oom1ooooo`009Oooool00ol0003oooooooooo`3ooooood7ooooo000Uooooo`03o`000?oooooooooo
0?oooooo@Oooool001_ooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
0?oooooo@Oooool001kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood7o
oooo000Oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooom1ooooo`007_oo
ool00omgMgOo<S8booooo`04ooooo`;o0000oooooom2ooooo`006oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<0?ooooooBOooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0
003oooooooooo`3ooooood_ooooo000Kooooo`Co0000oooooom:ooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00WOooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo1Ol00005
ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo09Oooooo002Mooooo`05oa0@4?nj^[[ok^k^
ogMgMol@41002Oooool6o`0000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q1ooo
ool00ol0003oooooooooo`2Hooooo`00WOooool00ol0003oooooooooo`0Kooooo`03oiRHV?lQ8B7o
k^k^00cooooo1Ol0002Iooooo`00WOooool00ol0003oooooooooo`0;ooooo`Ko00002oooool00onH
V9So8B4Qonk^kP0;ooooo`04odA4A?oMgMgoooooo`0009[ooooo002Mooooo`03o`000?oooooooooo
01gooooo00?oMgMgofIVI_ooool02_ooool01?oMgMgoEEEEooooool0002Jooooo`00Voooool00ol@
413o0000o`000003o`0001gooooo00?o0000ooooooooool02_ooool00omgMgOoc<c<o`00002Joooo
o`00WOooool00ol0003oooooooooo`0Jooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00oo^
k^koA4A4o`00002Jooooo`00WOooool00ol0003oooooooooo`0Jooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`03Oooool00omgMgOo0000ooooo`2Iooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.512639, -0.401091, \
0.0173014, 0.0333265}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "The result is shown in Cell ",
  ButtonBox["7.65",
    ButtonData:>"Cell 7.65",
    ButtonStyle->"Hyperlink"],
  ". The effect of the localized source is to create a shock wave moving to \
the right. (Think of the source as an explosive release of gas.) The height \
of the shock wave is roughly 2.5 units, which depends on the strength of the \
source: if we define ",
  Cell[BoxData[
      \(TraditionalForm\`N(
          t) = \ \[Integral]\_0\%L\( f(x, t)\) \[DifferentialD]x\)]],
  ", then according to Eq. ",
  ButtonBox["(7.2.26)",
    ButtonData:>{"Chapter7.nb", "(7.2.26)"},
    ButtonStyle->"Hyperlink"],
  " , ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]N/\[DifferentialD]t\  = \ \
\[Integral]\_0\%\(\(L\)\(\ \)\)S \[DifferentialD]x\)]],
  ".  However, for this moving shock front, ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[DifferentialD]N/\[DifferentialD]t\), " ", "=", " ", 
          RowBox[{\(v\ \(f\_-\)\), " ", "=", 
            RowBox[{\(\(f\_-\)\^2/2\), Cell[""]}]}]}], TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_-\)\)]],
  " is the height of the shock, and in the second step we have used the \
Hugoniot relation, Eq. ",
  ButtonBox["(7.2.28)",
    ButtonData:>{"Chapter7.nb", "(7.2.28)"},
    ButtonStyle->"Hyperlink"],
  " . Thus, for this shock wave the height of the shock depends on the source \
in the following way: "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(f\_-\)\^2/
          2\  = \ \[Integral]\_0\%\(\(L\)\(\ \)\)S \(\(\[DifferentialD]x\)\(\ \
\)\)\)]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "Since ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            
            RowBox[{\(\[Integral]\_0\%\(\(L\)\(\ \)\)S \[DifferentialD]x\), 
              "  ", "\[TildeEqual]", 
              RowBox[{"3", " ", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], " ", "\[Times]", "10"}]}], "=",
             "3"}]}], TraditionalForm]]],
  " for our source, we find ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_-\) \[TildeEqual] \@6 = 2.45 ... \)]],
  ", very close to the value observed in the simulation."
}], "Text"],

Cell[TextData[{
  "\tAlso, between times 0.6 and 2.4  the shock covers a distance of roughly  \
2 units, making the speed roughly ",
  Cell[BoxData[
      \(TraditionalForm\`2/1.8\  = \ 1.1\)]],
  ". This is close to the value of 1.25 expected from the Hugoniot relation, \
Eq. ",
  ButtonBox["(7.2.28)",
    ButtonData:>{"Chapter7.nb", "(7.2.28)"},
    ButtonStyle->"Hyperlink"],
  " . "
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises for Sec. 7.2", "Subsubtitle",
  CellTags->"c:26"],

Cell[TextData[{
  StyleBox["(1)(a)",
    FontWeight->"Bold"],
  " According to the description by  Scott Russell, the length of the soliton \
that he observed was ",
  Cell[BoxData[
      \(TraditionalForm\`L = 30\ ft\)]],
  ", and the height was roughly 1.25 ft. Use these facts to determine the \
depth of the water in the channel . "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Predict the speed of the soliton using the results of part (a). How does \
your prediction compare to Scott Russell's observation of ",
  Cell[BoxData[
      \(TraditionalForm\`v\_lab = 8 - 9\)]],
  "miles per hour?"
}], "Text"],

Cell[TextData[{
  StyleBox["(2)(a)",
    FontWeight->"Bold"],
  " Show that the coefficient ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " in the potential function ",
  Cell[BoxData[
      \(TraditionalForm\`V(f)\)]],
  " is given in terms of the roots ",
  Cell[BoxData[
      \(TraditionalForm\`a, b, c\)]],
  " by \n\t\t",
  Cell[BoxData[
      \(TraditionalForm\`A\  = \ \(-\((a\ b\  + \ a\ c\  + \ b\ c)\)\)/6\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "  ",
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Show that ",
  Cell[BoxData[
      \(TraditionalForm\`E\  = \ a\ b\ c\ /6\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(3)",
    FontWeight->"Bold"],
  " The Boussinesq equations describe slightly dispersive shallow-water waves \
propagating both to the left and to the right, as viewed in the lab frame. \
These are coupled equations for the horizontal velocity of the fluid surface, \
",
  Cell[BoxData[
      \(TraditionalForm\`u(x, t)\)]],
  ", and the water depth ",
  Cell[BoxData[
      \(TraditionalForm\`h(x, t)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`h(x, t) = h\_o\  + \ z(x, t)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`h\_o\)]],
  " is the equilibrium depth, and ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " is the wave height. The equations are"
}], "Text",
  CellTags->"i:32"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[PartialD]h\/\[PartialD]t + \
\(\[PartialD]\/\[PartialD]x\) \((h\ u)\)\  = \ 
      0, \[IndentingNewLine]\[PartialD]u\/\[PartialD]t + 
        u\ \[PartialD]u\/\[PartialD]x + \ 
        g \[PartialD]h\/\[PartialD]x\  + \ \(1\/3\) \(h\_o\) \[PartialD]\^3 h\
\/\(\[PartialD]x \[PartialD]t\^2\) = \ 0. \)]]], "UNNEQ"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Linearize these equations, assuming that ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  " are small quantities, and show that the resulting linear equations \
describe waves with the following dispersion relation:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\^2\  = \ \(c\_o\^2\) 
          k\^2/\((1\  + \ \(k\^\(\(2\)\(\ \)\)\) h\_o\^2/3)\)\)]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "To second -order in ",
  Cell[BoxData[
      \(TraditionalForm\`k\ h\_o\)]],
  " this is  equivalent to Eq. ",
  ButtonBox["(7.2.2)",
    ButtonData:>{"Chapter7.nb", "(7.2.2)"},
    ButtonStyle->"Hyperlink"],
  " . "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Defining ",
  Cell[BoxData[
      \(TraditionalForm\`h\&_ = h/h\_o\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`u\&_ = u/c\_o\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`x\&_ = x/h\_o\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`t\&_ = t\ c\_o/h\_o\)]],
  ", the Boussinesq equations become"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[PartialD]h\&_\/\[PartialD]t\&_ + \(\[PartialD]\/\
\[PartialD]x\&_\) \((h\&_\ u\&_)\)\  = \ 
      0, \[IndentingNewLine]\[PartialD]u\&_\/\[PartialD]t\&_ + 
        u\&_\ \[PartialD]u\&_\/\[PartialD]x + \ \[PartialD]h\&_\/\[PartialD]x\
\&_\  + \ \(1\/3\) \[PartialD]\^3 h\&_\/\(\[PartialD]x\&_ \
\[PartialD]t\&_\^2\) = \ 0. \)]]], "NE2",
  CellTags->"(7.2.32)"],

Cell[TextData[{
  "Show that steady solutions to these equations depending only on ",
  Cell[BoxData[
      \(TraditionalForm\`s = x\&_ - \ v\ t\&_\)]],
  "   are described by the motion of a particle with position ",
  Cell[BoxData[
      \(TraditionalForm\`h\&_\)]],
  " and mass ",
  Cell[BoxData[
      \(TraditionalForm\`1/3\)]],
  " moving in a potential"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`V(h\&_) = \(-\(B\^2\/\(2\ h\&_\)\)\) + h\&_\^2\/2 - 
          1\/2\ h\&_\ \((2\ A + v\^2)\)\)]],
  ", "
}], "UNNEQ"],

Cell[TextData[{
  "and where ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`B\)]],
  " are constants of integration, with ",
  Cell[BoxData[
      \(TraditionalForm\`B\)]],
  " relating ",
  Cell[BoxData[
      FormBox[Cell[TextData[Cell[BoxData[
            \(TraditionalForm\`u\&_\)]]]], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`h\&_\)]],
  " through ",
  Cell[BoxData[
      \(TraditionalForm\`u\&_ = B/h\&_ - v\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Show that a soliton solution exists with ",
  Cell[BoxData[
      \(TraditionalForm\`h\&_ \[Rule] 1\)]],
  "  as ",
  Cell[BoxData[
      \(TraditionalForm\`s \[Rule] \(\(\[PlusMinus]\[Infinity]\)\(\ \)\)\)]],
  ", provided that ",
  Cell[BoxData[
      \(TraditionalForm\`A = 1\  + \ \((B\^2 - v\^2)\)/2\)]],
  ",  and find the particle energy ",
  Cell[BoxData[
      \(TraditionalForm\`E\)]],
  " corresponding to this solution. Show that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(u\&_\)\(\[Rule]\)\(0\)\(\ \)\)\)]],
  "at ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          FormBox[\(s \[Rule] \(\(\[PlusMinus]\[Infinity]\)\(\ \)\)\),
            "TraditionalForm"]}], TraditionalForm]]],
  " only if ",
  Cell[BoxData[
      \(TraditionalForm\`B = v\)]],
  ", which implies ",
  Cell[BoxData[
      \(TraditionalForm\`A = 1\)]],
  " for solitons."
}], "Text",
  CellTags->"i:33"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " Show that the height ",
  Cell[BoxData[
      \(TraditionalForm\`h\&_\)]],
  " of this soliton is related to the speed by ",
  Cell[BoxData[
      \(TraditionalForm\`h\&_ = v\^2\)]],
  ".  Solve the equation of motion numerically on ",
  Cell[BoxData[
      \(TraditionalForm\`0 < s < 4\)]],
  " for the case ",
  Cell[BoxData[
      \(TraditionalForm\`B = \(v = 2\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(A = 1\)\(,\)\)\)]],
  "and plot the form of this soliton solution for ",
  Cell[BoxData[
      \(TraditionalForm\`\(h\&_\)(s)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\&_\)(s)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(4)",
    FontWeight->"Bold"],
  " The ",
  StyleBox["sine-Gordon equation",
    FontSlant->"Italic"],
  ","
}], "Text",
  CellTags->"i:34"],

Cell[TextData[Cell[BoxData[
    FormBox[Cell[TextData[Cell[BoxData[
          FormBox[
            RowBox[{
              RowBox[{
                
                RowBox[{\(\[PartialD]\^2 f\/\[PartialD]t\^2\), 
                  "-", \(\[PartialD]\^2 f\/\[PartialD]x\^2\), "+", " ", 
                  RowBox[{"sin", " ", "f", Cell[""]}]}], "=", " ", "0"}], 
              ","}], TraditionalForm]]]]], TraditionalForm]]]], "NE2",
  CellTags->"(7.2.33)"],

Cell[TextData[{
  "describes, among other things,  the motion of magnetic domains in a \
ferromagnetic material. Here, ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " is proportional to the magnetization in the material, which changes \
rapidly as one moves from one magnetic domain to another.  The linearized \
version of this equation is the ",
  StyleBox["Klein-Gordon equation",
    FontSlant->"Italic"]
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[Cell[TextData[Cell[BoxData[
          FormBox[
            RowBox[{
              RowBox[{
                
                RowBox[{\(\[PartialD]\^2 f\/\[PartialD]t\^2\), 
                  "-", \(\[PartialD]\^2 f\/\[PartialD]x\^2\), "+", " ", 
                  RowBox[{"f", Cell[""]}]}], "=", " ", "0"}], ","}], 
            TraditionalForm]]]]], TraditionalForm]]]], "UNNEQ",
  CellTags->"i:35"],

Cell["\<\
which has applications in several areas, including particle and \
plasma physics. \
\>", "Text"],

Cell[TextData[{
  StyleBox["(a) ",
    FontWeight->"Bold"],
  "Find the dispersion relation for the Klein-Gordon equation, and show that \
the waves are dispersive, with phase speed ",
  Cell[BoxData[
      \(TraditionalForm\`c = \(\[PlusMinus]\@\(1 + 1/k\^2\)\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Since the ",
  Cell[BoxData[
      \(TraditionalForm\`sin\ f\)]],
  " term in the sine-Gordon equation causes both nonlinearity and dispersion, \
one expects that the equation has steady solutions, depending only on ",
  Cell[BoxData[
      \(TraditionalForm\`s = x - \ v\ t\)]],
  ". Show that such solutions do exist provided that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(v\)\(|\)\(\(>\)\(1\)\)\)\)]],
  ", and find the functional form of soliton solutions for which ",
  Cell[BoxData[
      \(TraditionalForm\`f \[Rule] 0\)]],
  " as ",
  Cell[BoxData[
      \(TraditionalForm\`s \[Rule] \ \(+\[Infinity]\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`f \[Rule] \ \(\(2\)  \(\[Pi]\)\(\ \)\)\)]],
  "for ",
  Cell[BoxData[
      \(TraditionalForm\`s \[Rule] \(\(-\[Infinity]\)\(\ \)\)\)]],
  ". Show that the range in ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  " over which ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " varies from ",
  Cell[BoxData[
      \(TraditionalForm\`2\ \[Pi]\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`0\)]],
  " is proportional to ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(v\^2 - 1\)\)]],
  ". Plot ",
  Cell[BoxData[
      \(TraditionalForm\`f(s)\)]],
  "."
}], "Text",
  CellTags->"i:49"],

Cell[TextData[{
  StyleBox["(5) ",
    FontWeight->"Bold"],
  "The nonlinear Schr\[ODoubleDot]dinger equation, "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[ImaginaryI] \[PartialD]\[Psi]\/\[PartialD]t + \
\[PartialD]\^2 \[Psi]\/\[PartialD]x\^2 + \ 
          K\ \(\((\(|\)\(\[Psi]\)\(|\))\)\^2\) \[Psi]\)\(=\)\(0\)\(\ \
\)\)\)]],
  ", "
}], "NE2",
  CellTags->{"i:36", "(7.2.34)"}],

Cell[TextData[{
  "describes the evolution of a quantum wave function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](x, t)\)]],
  " trapped in a potential ",
  Cell[BoxData[
      \(TraditionalForm\`V(x) = \(-K\)\ \((\(|\)\(\[Psi]\)\(|\))\)\^2\)]],
  ". For ",
  Cell[BoxData[
      \(TraditionalForm\`K > 0\)]],
  " this particle is attracted to regions of large probability density ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(|\)\(\[Psi]\)\(|\))\)\^2\)]],
  ", i.e. it is attracted to itself. This can lead to nonlinear steepening of \
the wave function, but this steepening can be balanced by dispersion, \
allowing steady solutions and solitons. This equation has applications in \
many areas, including",
  ",",
  " of course, quantum physics, as well as nonlinear optics (where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)]],
  " is the electric field in a high-intensity wave moving through a nonlinear \
dielectric material). "
}], "Text"],

Cell[TextData[{
  "\tSolve for the steady solutions to Eq. ",
  ButtonBox["(7.2.34)",
    ButtonData:>{"Chapter7.nb", "(7.2.34)"},
    ButtonStyle->"Hyperlink"],
  " , and find the functional form of solitons for which ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi] \[Rule] \ 0\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`x = \(\[PlusMinus]\[Infinity]\)\)]],
  " ."
}], "Text",
  CellTags->"i:50"],

Cell[TextData[{
  StyleBox["(6) ",
    FontWeight->"Bold"],
  "Analyze the steady solutions of Burgers' equation, Eq. ",
  ButtonBox["(7.2.26)",
    ButtonData:>{"Chapter7.nb", "(7.2.26)"},
    ButtonStyle->"Hyperlink"],
  " . Show that these shock waves have the form given by Eq. ",
  ButtonBox["(7.2.27)",
    ButtonData:>{"Chapter7.nb", "(7.2.27)"},
    ButtonStyle->"Hyperlink"],
  " ."
}], "Text"],

Cell[TextData[{
  StyleBox["(7)",
    FontWeight->"Bold"],
  " Models of compressional shock waves in a gas require the solution of the \
",
  StyleBox[ButtonBox["Navier",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Navier.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  StyleBox["-",
    FontSlant->"Italic"],
  StyleBox[ButtonBox["Stokes",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Stokes.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  StyleBox[" equations",
    FontSlant->"Italic"],
  ", coupled equations for the pressure ",
  Cell[BoxData[
      \(TraditionalForm\`p(x, t)\)]],
  ", velocity ",
  Cell[BoxData[
      \(TraditionalForm\`u(x, t)\)]],
  "and  mass density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](x, t)\)]],
  " of the gas.  The three  equations are the continuity equation for mass \
density,"
}], "Text",
  CellTags->"i:41"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\[PartialD]\[Rho]\/\[PartialD]t + \(\[PartialD]\/\
\[PartialD]x\) \((u\ \[Rho])\)\  = \ 0;\)\)]]], "NE2",
  CellTags->{"i:37", "(7.2.35)"}],

Cell["the momentum equation,", "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\(\[PartialD]u\/\[PartialD]t + 
        u \(\[PartialD]\/\[PartialD]x\) 
          u\  = \ \(-\(1\/\[Rho]\)\) \(\[PartialD]\/\[PartialD]x\) 
          p + \[Eta]\ \ \(\[PartialD]\^2\/\[PartialD]x\^2\) 
          u\)\(,\)\)\)]]], "NE2",
  CellTags->{"i:38", "(7.2.36)"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\)]],
  " is the  kinematic viscosity of the gas (units ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox[
            StyleBox["m",
              FontSlant->"Plain"], "2"], "/", 
          StyleBox["s",
            FontSlant->"Plain"]}], TraditionalForm]]],
  "); and an equation of state relating pressure to density,"
}], "Text",
  CellTags->"i:77"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`p\  = \ p\_o\ \((\[Rho]/\[Rho]\_o)\)\^\[Gamma]\)]],
  ","
}], "NE2",
  CellTags->{"i:40", "(7.2.37)"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma] > 1\)]],
  " is the ratio of specific heats in the gas, and where ",
  Cell[BoxData[
      \(TraditionalForm\`p\_o\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_o\)]],
  " are the equilibrium values of the pressure and mass density respectively. \
(This model neglects thermal conduction for simplicity.)"
}], "Text",
  CellTags->"i:39"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Linearize these equations for small deviations from the equilibrium ",
  Cell[BoxData[
      \(TraditionalForm\`p = p\_o\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`u = 0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho] = \[Rho]\_o\)]],
  ", to show that sound waves propagate with a dispersion relation given by "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\^2\  = \ \(k\^2\)(
          c\_o\^2\  - \ \[ImaginaryI]\ \[Omega]\ \[Eta])\)]],
  ","
}], "UNNEQ",
  CellTags->"i:42"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`c\_o = \@\(\[Gamma]\ p\_o/\[Rho]\_o\)\)]],
  " is the speed of sound. Show that these waves damp exponentially due to \
finite viscosity, at a rate ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(r\)\(\ \)\)\)]],
  "given by ",
  Cell[BoxData[
      \(TraditionalForm\`r = k\^2\ \(\(\[Eta]/2\)\(\ \)\)\)]],
  " when ",
  Cell[BoxData[
      \(TraditionalForm\`k\ \[Eta] << \(c\_o\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Analyze steady shock-wave solutions to Eqs. ",
  ButtonBox["(7.2.35)",
    ButtonData:>{"Chapter7.nb", "(7.2.35)"},
    ButtonStyle->"Hyperlink"],
  " -",
  ButtonBox["(7.2.37)",
    ButtonData:>{"Chapter7.nb", "(7.2.37)"},
    ButtonStyle->"Hyperlink"],
  " , which depend only on the variable ",
  Cell[BoxData[
      \(TraditionalForm\`s = x - \ v\ t\)]],
  " (where ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " is the shock speed). Show, for a shock moving to the right into still air \
where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho] = \[Rho]\_o\)]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"u", "=", 
          RowBox[{"0", "at", 
            FormBox[\(x \[Rule] \ \[Infinity]\),
              "TraditionalForm"]}]}], TraditionalForm]]],
  ",   that the fluid velocity in the shock satisfies"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\ \[PartialD]u\/\[PartialD]s = \(c\_o\^2\/\(\
\[Gamma] - 1\)\)[\((\[Rho]\/\[Rho]\_o)\)\^\(\[Gamma] - 1\) - 1] + \ \(1\/2\) 
            u\^2 - \ u\ v\)]],
  ","
}], "NE2",
  CellTags->"(7.2.38)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]/\[Rho]\_o = v/\((v - u)\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Use the result of part (b) to derive the following Hugoniot relation:"
}], "Text",
  CellTags->"i:43"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\(\(c\_o\^2\/\(\[Gamma] - 
                1\)\)[\((v\/\(v - \(u\_-\)\))\)\^\(\[Gamma] - 1\) - 
            1] + \ \(1\/2\) u\_-\%2\ \  - \ \(u\_-\)\ v = 
      0\)\(,\)\)\)]]], "UNNEQ"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\_-\)\)]],
  " is the velocity of the gas well-behind the shock."
}], "Text"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " Show that the shock always travels with speed  ",
  Cell[BoxData[
      \(TraditionalForm\`v > \ c\_o\)]],
  " and that ",
  Cell[BoxData[
      \(TraditionalForm\`v/c\_o\)]],
  " is an increasing function of ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\_-\)/u\)]],
  ". (Hint: Scale ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\_-\)\)]],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " in the Hugoniot relation, and note that ",
  Cell[BoxData[
      \(TraditionalForm\`\((1\/\(1 - x\))\)\^\(\[Gamma] - 1\)\)]],
  "is an increasing function of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ".) \n",
  StyleBox["(e)",
    FontWeight->"Bold"],
  " Analytically solve for the shock assuming it is ",
  StyleBox["weak, ",
    FontSlant->"Italic"],
  " so that ",
  Cell[BoxData[
      \(TraditionalForm\`v\  \[Rule] \ c\_o\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\__\) << \(c\_o\)\)]],
  ". Show that in this limit,"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(u\_-\), "=", 
          
          RowBox[{\(\(\(4  c\_o\)\/\(\[Gamma] + 1\)\) \((1 - c\_o/v)\)\), "+",
             " ", 
            RowBox[{"0", 
              RowBox[{"(", 
                SuperscriptBox[
                  FormBox[\((1 - c\_o/v)\),
                    "TraditionalForm"], "2"], ")"}]}]}]}], 
        TraditionalForm]]],
  " ."
}], "UNNEQ"],

Cell["and", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`u(
          s)\  = \ \(u\_-\)\/\(1\  + \ exp\ [\(\(u\_-\)(1 + \[Gamma])\)\ s/\ \
2  \[Eta]]\)\)]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "Plot ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  " vs. ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  " assuming that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\  = \ 5/3\)]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(c\_o\), "=", 
          RowBox[{"340", " ", 
            RowBox[{
              StyleBox["m",
                FontSlant->"Plain"], "/", 
              StyleBox["s",
                FontSlant->"Plain"]}]}]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{"v", "=", 
          RowBox[{"360", " ", 
            RowBox[{
              StyleBox["m",
                FontSlant->"Plain"], "/", 
              StyleBox["s",
                FontSlant->"Plain"]}]}]}], TraditionalForm]]],
  ", and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Eta]", "=", 
          RowBox[{"1.", " ", "\[Times]", \(10\^\(-2\)\), 
            RowBox[{
              SuperscriptBox[
                StyleBox["m",
                  FontSlant->"Plain"], "2"], "/", 
              StyleBox["s",
                FontSlant->"Plain"]}]}]}], TraditionalForm]]],
  ". Roughly speaking, what is the width of the shock in meters? (Hint: \
Expand the Hugoniot relation and Eq. ",
  ButtonBox["(7.2.38)",
    ButtonData:>{"Chapter7.nb", "(7.2.38)"},
    ButtonStyle->"Hyperlink"],
  "  to ",
  StyleBox["second",
    FontSlant->"Italic"],
  "-order in ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\_-\)/v\)]],
  ")."
}], "Text"],

Cell[TextData[{
  StyleBox["(8)",
    FontWeight->"Bold"],
  " Use the Galerkin method to numerically solve Burgers' equation with \
constant nonuniform forcing, in periodic boundary conditions, on ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < 20\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FractionBox[\(\[PartialD]f\), \(\[PartialD]t\),
              MultilineFunction->None], "+", 
            RowBox[{"f", " ", 
              FractionBox[\(\[PartialD]f\), \(\[PartialD]x\),
                MultilineFunction->None]}], "-", 
            RowBox[{\(1\/10\), " ", 
              FractionBox[\(\[PartialD]\^2 f\), \(\[PartialD]x\^2\),
                MultilineFunction->None]}]}], 
          "=", \(\(2\/15\) e\^\(-\((x - 5)\)\^2\)\)}], TraditionalForm]]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < 20\)]],
  ". "
}], "UNNEQ"],

Cell[TextData[{
  "The forcing function on the ",
  "right-hand",
  " side describes an explosive local increase in temperature, pressure, or \
density. Take 13 Fourier modes (",
  Cell[BoxData[
      \(TraditionalForm\`M = 12\)]],
  "), and solve for",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(0 < t < 25\)\)\)]],
  ". Note the formation of a shock front propagating to the right."
}], "Text"],

Cell[TextData[{
  StyleBox["(9)",
    FontWeight->"Bold"],
  " Use the CTCS method to solve the sine-Gordon equation ",
  ButtonBox["(7.2.33)",
    ButtonData:>{"Chapter7.nb", "(7.2.33)"},
    ButtonStyle->"Hyperlink"],
  " , in periodic boundary conditions on ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < L\)]],
  ", with ",
  Cell[BoxData[
      \(TraditionalForm\`L = 10\)]],
  ". For the initial condition, take ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, 0) = \ 3\ \(sin(\[Pi]\ x/L)\)\)]],
  ". Integrate the result for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 10\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(10)",
    FontWeight->"Bold"],
  " Use the CTCS method to solve the traffic flow problem ",
  ButtonBox["(7.1.43)",
    ButtonData:>{"Chapter7.nb", "(7.1.43)"},
    ButtonStyle->"Hyperlink"],
  " , taking ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, 0) = 0\)]],
  " (i.e. an initially empty freeway) with ",
  Cell[BoxData[
      \(TraditionalForm\`s = 1\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < 1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`s = 0\)]],
  " otherwise (i.e., there is an on ramp at this location, feeding cars onto \
the freeway at a constant rate). Take ",
  Cell[BoxData[
      \(TraditionalForm\`c = 1\)]],
  "and use periodic boundary conditions on  ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < 10\)]],
  ", and integrate in time up to a time as close as possible to the formation \
of a singularity (the CTCS method will become unstable at some point before \
this time, depending on your choice of step size)."
}], "Text"],

Cell[TextData[{
  StyleBox["(11)",
    FontWeight->"Bold"],
  " A diffusive term is often added to the traffic flow problem in order to \
model diffusive spreading of the cars in the absence of nonlinearity (see for \
example, ",
  ButtonBox["Whitham",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  ", Sec. 1.4). The equation now becomes"
}], "Text",
  CellTags->"i:51"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]f\/\[PartialD]t + \((c - 
                f)\) \[PartialD]f\/\[PartialD]x - \[Chi]\ \[PartialD]\^2 f\/\
\[PartialD]x\^2 = s\)]],
  ". "
}], "UNNEQ"],

Cell[TextData[{
  "Using the numerical method of your choice, redo the previous problem, \
taking ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\  = \ 0.2\)]],
  ". Solve the problem over the time interval ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 15\)]],
  ". Note the formation of a backward-propagating shock (a traffic jam, \
propagating back from the on ramp). "
}], "Text"],

Cell[TextData[{
  StyleBox["(12)",
    FontWeight->"Bold"],
  " Here's another numerical method for solving PDEs: finite-difference the \
spatial operator on a grid, and then solve the resulting coupled ODEs in \
time. These ODEs can be interpreted as the equations of motion for a system \
of coupled masses and springs, which provides us with another way of thinking \
about the problem. Consider, for instance, the following nonlinear PDE:"
}], "Text",
  CellTags->"i:86"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[\(\[PartialD]\^2 \[Eta]\), \(\[PartialD]t\^2\),
            MultilineFunction->None], "=", 
          RowBox[{\(c\^2\), " ", 
            FractionBox[\(\[PartialD]\^2 \[Eta]\), \(\[PartialD]x\^2\),
              MultilineFunction->None], 
            RowBox[{"(", 
              RowBox[{"1", " ", "+", 
                RowBox[{"\[Alpha]", 
                  FractionBox[\(\[PartialD]\[Eta]\), \(\[PartialD]x\),
                    MultilineFunction->None]}]}], ")"}]}]}], 
        TraditionalForm]]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "Centered differencing of the spatial operator on a uniform grid of \
positions ",
  Cell[BoxData[
      FormBox[
        RowBox[{"x", " ", "=", " ", 
          RowBox[{"j", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  " yields"
}], "Text"],

Cell[TextData[StyleBox[Cell[BoxData[{
    FormBox[
      RowBox[{
        RowBox[{
          
          FractionBox[\(\[DifferentialD]\^2 \[Eta]\_j\), \
\(\[DifferentialD]t\^2\),
            MultilineFunction->None], "=", 
          RowBox[{\(c\^2\), " ", 
            
            FractionBox[\(\[Eta]\_\(j + 1\) - 
                2\ \[Eta]\_j + \[Eta]\_\(j - 1\)\), 
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], "2"]], 
            RowBox[{"(", 
              RowBox[{"1", " ", "+", 
                RowBox[{"\[Alpha]", 
                  FractionBox[\(\[Eta]\_\(j + 1\) - \[Eta]\_\(j - 1\)\), 
                    RowBox[{"2", 
                      StyleBox[
                        RowBox[{"\[CapitalDelta]", 
                          StyleBox["x",
                            FontSlant->"Italic"]}]]}]]}]}], ")"}]}]}], " "}], 
      TraditionalForm], "\[IndentingNewLine]", 
    FormBox[
      RowBox[{"           ", 
        RowBox[{"=", 
          RowBox[{
            FractionBox[\(c\^2\), 
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], "2"]], 
            RowBox[{
              RowBox[{"(", " ", 
                
                RowBox[{\((\[Eta]\_\(j + 1\) - \ \[Eta]\_j)\), "-", 
                  "  ", \((\[Eta]\_j - \[Eta]\_\(j - 1\))\), "  ", "+", 
                  RowBox[{
                    FractionBox["\[Alpha]", 
                      RowBox[{"2", " ", 
                        StyleBox[
                          RowBox[{"\[CapitalDelta]", 
                            StyleBox["x",
                              FontSlant->"Italic"]}]]}]], 
                    "[", \(\((\[Eta]\_\(j + 1\) - \[Eta]\_j)\)\^2\  - \((\
\[Eta]\_\(j - 1\) - \[Eta]\_j)\)\^2\), " ", "]"}]}], " ", ")"}], "."}]}]}]}], 
      TraditionalForm]}], "NumberedEquation"], "NumberedEquation"]], "NE2",
  CellTags->"(7.2.39)"],

Cell[TextData[{
  "These equations are the same as the dynamical equations for a series of \
masses of unit mass, at positions ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Eta]\_j\)(t)\)]],
  ", connected to nearest-neighbors by nonlinear springs with a nonlinear \
spring force vs. displacement ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\)]],
  " of"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`F\  = \ \(-\ 
              k\)\ \[Eta]\ \  - \ \[Gamma]\ \[Eta]\^2\)]],
  ","
}], "UNNEQ"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{"k", "=", 
          RowBox[{\(c\^2\), "/", 
            SuperscriptBox[
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]], "2"], " "}]}], 
        TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Gamma]", " ", "=", " ", 
          RowBox[{\(c\^2\), \(\[Alpha]/2\), " ", 
            SuperscriptBox[
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]], "3"]}]}], TraditionalForm]]],
  ".  In a famous ",
  ButtonBox["paper",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  " from the early days of computational physics,  ",
  ButtonBox["Fermi",
    ButtonData:>{
      URL[ "http://scienceworld.wolfram.com/biography/Fermi.html"], None},
    ButtonStyle->"Hyperlink"],
  ", Pasta and Ulam (FPU, 1955) studied the behavior of this coupled \
mass-spring system. The authors were expecting that the nonlinearity of the \
system, combined with the many degrees of freedom, would result in chaotic \
dynamics that would lead to a thermal equilibrium state, where energy was \
shared equally between all degrees of freedom. Surprisingly, however, this is \
not what the authors observed. In this problem, we will repeat a portion of \
their work."
}], "Text",
  CellTags->"i:52"],

Cell[TextData[{
  StyleBox[" (a)",
    FontWeight->"Bold"],
  " Use the molecular dynamics code in Chapter ",
  ButtonBox["1",
    ButtonData:>{"Chapter1.nb", "c:27"},
    ButtonStyle->"Hyperlink"],
  " (modified for 1-D motion and nearest-neighbor interactions) to solve Eqs. \
",
  ButtonBox["(7.2.39)",
    ButtonData:>{"Chapter7.nb", "(7.2.39)"},
    ButtonStyle->"Hyperlink"],
  "  for ",
  Cell[BoxData[
      \(TraditionalForm\`M + 1\)]],
  " masses, where ",
  Cell[BoxData[
      \(TraditionalForm\`M = 15\)]],
  ", with boundary conditions ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\_0 = \(\[Eta]\_M = 0\)\)]],
  " (i.e., the end masses are fixed to walls).  For initial conditions take \
",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\_j\  = \ sin\ \((\[Pi]\ j/M)\)\)]],
  " (i.e.,  all energy in the lowest normal mode of the linearized system), \
and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\& . \_j = 0\)]],
  ". Taking ",
  Cell[BoxData[
      \(TraditionalForm\`k = 1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\  = \ 1/4\)]],
  ", integrate the equations for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 1000\)]],
  ". Plot  ",
  Cell[BoxData[
      \(TraditionalForm\`2  j + \(\[Eta]\_j\)(t)\)]],
  " vs. ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " on a single graph for ",
  Cell[BoxData[
      \(TraditionalForm\`j = 1,  ... , M - 1\)]],
  ".  (The ",
  Cell[BoxData[
      \(TraditionalForm\`2  j\)]],
  " is used to separate the different curves.)"
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Perform the following analysis on your results from part (a). FPU \
expected that the nonlinearity in the force would result in coupling between \
normal modes, and a cascade of energy to higher and higher Fourier modes, \
resulting in eventual energy equipartition where, on average, all modes have \
the same energy.  The amplitude of the ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  "th Fourier mode vs. time is "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(a\_k\)(t)\  = 
        2\/M\ \(\[Sum]\+\(j = 0\)\%M\(\( \[Eta]\_j\)(
                t)\)\ \(sin(\ \[Pi]\ k\ j/M)\)\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`k = 1, 2,  ... , M - 1\)]],
  ". "
}], "NE2",
  CellTags->"(7.2.40)"],

Cell["\<\
The energy in a normal mode (neglecting the nonlinear terms) is \
\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{Cell[TextData[Cell[BoxData[
              \(TraditionalForm\`\(E\_k\)(
                  t)\  = \(1\/2\) \((a\& . \_k)\)\^2 + \(1\/2\) \
\(\(\[Omega]\^2\)(k)\)\ \((a\_k)\)\^2\)]]]], " "}], TraditionalForm]]],
  ","
}], "UNNEQ"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Omega]\^2\)(k) = 
        4\ \(sin\^2\)[\[Pi]\ k/\((2\ M)\)]\)]],
  " is the ",
  Cell[BoxData[
      \(TraditionalForm\`frequency\)]],
  " squared of these normal modes. [See Eq. ",
  ButtonBox["(4.2.30)",
    ButtonData:>{"Chapter4.nb", "(4.2.30)"},
    ButtonStyle->"Hyperlink"],
  " .] Evaluate these mode energies  and plot them versus time to show the \
spectral distribution of mode energies. Is energy being shared equally among \
these modes?"
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  "  What do you think would happen if we used this technique on the KdV \
equation? Would energy be shared equally among the modes?"
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["7.3 The Particle-in-Cell Method", "Subtitle",
  FontColor->RGBColor[1, 0, 0],
  CellTags->{"i:55", "c:27"}],

Cell["", "Text"],

Cell[CellGroupData[{

Cell["7.3.1 Galactic Dynamics", "Subsubtitle",
  CellTags->"c:28"],

Cell[TextData[{
  "\tOur galaxy is a good example of a nearly collisionless (ideal) gas. The \
\"particles\" in this gas are individual stars (see Fig. ",
  ButtonBox["7.9",
    ButtonData:>"Fig. 7.9",
    ButtonStyle->"Hyperlink"],
  "). Although these stars interact via the gravitational force,  for \
individual pairs of stars the interaction potential energy is, on average,  \
very weak compared to the  kinetic energy of typical stars, and so these \
binary interactions can be neglected to  lowest approximation. This can be \
seen using a simple order of magnitude estimate. The average speed of a star \
in the galaxy is roughly ",
  Cell[BoxData[
      \(TraditionalForm\`v \[TildeTilde] 100\)]],
  " km/s. This gives a kinetic energy for a solar mass star of  ",
  Cell[BoxData[
      \(TraditionalForm\`K = \(m\ v\^2/2\  = \ 10\^40\)\)]],
  " joules.  However, the average distance between stars is roughly ",
  Cell[BoxData[
      \(TraditionalForm\`d\  = 1\)]],
  " light year (somewhat more near the edge of the galaxy, less near the \
center).  This gives an interaction potential of ",
  Cell[BoxData[
      \(TraditionalForm\`U = \(\(G\ m\^2/
              d\)\(\ \)\(=\)\(10\^34\)\(\ \)\)\)]],
  "joules, so ",
  Cell[BoxData[
      \(TraditionalForm\`U/K\ << 1\)]],
  " . The typical gravitational interaction between stellar pairs is \
negligible compared to the stars' kinetic energy. "
}], "Text",
  CellTags->"i:76"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000<Z0003:R000`400?l00000o`00003ooooooooo
oooooooooooo;Oooool00?ooooooooooooooooooobgooooo003oooooooooooooooooool]ooooo`00
oooooooooooooooooooo;Oooool00?ooooooooooooooooooobgooooo003oooooooooooooooooool]
ooooo`00oooooooooooooooooooo;Oooool00?ooooooooooooooooooobgooooo003ooooooooooooo
ooooool]ooooo`00oooooooooooooooooooo;Oooool00?ooooooooooooooooooobgooooo003ooooo
ooooooooooooool]ooooo`00oooooooooooooooooooo;Oooool00?ooooooooooooooooooobgooooo
003oooooooooooooooooool]ooooo`00oooooooooooooooooooo;Oooool00?oooooooooooooooooo
obgooooo003oooooooooooooooooool]ooooo`00oooooooooooooooooooo;Oooool00?oooooooooo
ooooooooobgooooo003oooooooooooooooooool]ooooo`00oooooooooooooooooooo;Oooool00?oo
ooooooooooooooooobgooooo003oooooooooooooooooool]ooooo`006oooool04P0;2@X03@/<00`:
2`0B41405aDF00/92P0=2``03`d>00h<3@0=2``03P`=014?40081P/03@/@010>4`0B41D03`dB00L5
2P802`T>00`02PP=00h<4@0?3A8030X=00l:3@0=2@X030P900d92P0@30d04@d>010<3@0B3Pl200X6
1`0300T51P0@30d05A4@00805A4@00D02`L601hJ6@0:1PD030P700X61@0200`81`0;00l;2P0D40l0
3`/:00h:2@0<20L03@T8018>3@0E4A004@d<00d9200<20L00P0>2PT06@0>2PX05A4B014=3P0?30`0
4Ph?00d92P0;20P02@D600/7200A3@h040`=014=3P0D3a005Q0B018>3`0?2``03PX;00/92P0:20T0
3P`=020P800b<S804A4A00D51@0=30d00`0;2@X00`0<2P/03P`=00`:2`0200/92P0900`:2`0;2@X0
2`T:00`:2`0>30d040h?014?400@3Pl02`T:00803@/<018030X;00X82@0:20T02@L800T72P0J61/0
2@L:01PF6@0100803@/>01LE601>C4l07Q`O018@4`0G5AP01`D800X82@0;2@X200h<3@0;00d;300;
2@X00`42018@4@081PL04@l@00/92P091`P01`D600T7200>30d00P0@3Pl0100>30d03@/<014?4007
1@H200l=3P0?00h<3@0>31404A0D0040100E4aP02PP=01<A5P0<2Pl03`dB00X83@071@X02@L<00`:
3`060`X03@XA008030T@00@08AhU00D22@0;20l02`P?0P0<2A0200d:4@0>00`:3`0;2@h03@/@00h<
4@0=2a002@L<00/93P0:20d020H;00L52P0:20d03@/>00h<3P0?3@h2014?400>00`:2`091`P030X;
00X82@071@H03P`=0040000P7Ql030/=01@B5@0=2`h030X=01dK7P01008600`:3@0400X83@0:1`h0
2PL>00X74P802PHD00/02`LE00T64@0:1a002`P?00d;400?3A0020H700`:2`0M6ad05A<F00`:3`02
00d;400<00/83`091Pd02PL>00X73P0<2A8030TD00P5400710h02@H?00d:4`0>2a<030T@100<2Pl0
2P0<2A00514J03Tf?`0]:S802`P?01@A600:20h030X?00`:3@0;2@`200X82`0=00401@0F4aX02@H=
01dJ8@0T8BP02PP>01DB6@050PT02PL>00H32P091Pd030X@00`73@0200d8300B00/62P0<1`/04`hB
05IAE@0P6al03@P<00h93@0<1`/03`X>00`:3@0:20/020H901LE600B41<01`D800`:3@0=2`h03`d@
0P0<2Pd03`0>30l040dD00D32@0B3aH02PL>00T63@0C41L01P<:02PU;00B3aH00P0600`9400=2a00
2@L:00T7200200X82@0:00/92P0<2P/01P@500L51P0=2``02`T:00L51P0?3@h030P900X61`8020@5
00T02PH700`82@0K5aP02@D600D10P0B3Pl020@5010<3@091@H00P0>2P/0100<20T03PX;014=3P0?
2``200d92P0800/720070`@0100100`82@091@H020@500X61`0=2@X200h:2`0300`82@0;1`P02PH7
00802PH700P020@500/720050@803@T:00l;30050@803@T:00`82@802@D600<04@d>01LC500<20T0
100<20T02P0=2@X03PX;01<?400F4Q<03PX;00d92P0>2P/02PH700/7200>2P/200`82@0300l;300>
2P/02`L800802PH70P091@H0300;1`P03@T:00h:2`0=2@X02`L800`82@0H51D07QXK010<3@070`@0
2`L800d82`D02PD900@02`H:00`72`0<1`/02`H:0P0:1@T01P0?2Q403PT@00/63@0910/02PD<00`7
3P803PT@00@02PD<00`73P0?2Q402@@;1P0<1Q001P0?2A<03@LA00/53`0@2Q@01P0:00d74@H030L>
01X03PT@00T42`0<1`h04@`C00/63@0<1`h03@/@00X93P0920h02PPC00T84`0411001`LC00h?6P0L
7bH0=3Ln00/=4@020`L02PP=00h93`0910X03PT?00T52P0A31802PD;00/6308030L=00P02`H<00X5
2`0:20/01`D801<A500<2Pd01P@700@21@8020H900d01P@700d;3P040`D04@lB00l:3P0=20`030L;
00/62P0:1@T02@@800d8300;1PX030L;00803`X>00H03@P<00d;3P030@@02PP;01@B5@071@P300`:
3@802`T<0P0:20/08`0?2Q0030L=00`73@0?2Q403PPB00d74@0;1@l02`H=00`73P0>2@l03`X@010;
4P0?31H03P/D00d:4`0;21402PL>00P52`0>31404Q0C00d;3@0>30d04Q0A00h<3`040PL02PP=00d;
40071@X09R@Y07ajO`0M6b000`4600P62`0C4AH020H;00802PP=01002@L<00`:3`0?3A803`dB00d;
400@3Q<04a4F014?500E4aP040hC00`:3`040PL03`dB00h<4@0H5Q/04PlF0`0:1a0200X74P0300X7
4@0:1a002`P?008030T@0P0;20l00`0?31<03P/B00d:4@0200`9400@00d:4@0:1a002`PA00d:4`0<
2A002`P?00X73P0>31401P@900`:3@0>30l05Q@G00L6200<1`d03@P>00l:4@803`TC00P03@LC00<0
1`0E3aP040/A00/6300A3@l03PX;00/62P804@`@00D050lC00/62P0C3Q8040/?00l:3P0200h93@0E
00l:3P0@2`l040/?00l:3P0=20`03PT=010;3`0A31003@P<010;3`0;1PX03@P<01<>4P0>2@d04@`@
010;3`0=20`02`H:00h93@0C3Q803@P<00<03`X>00H040/?014<400A31003PT=00`72`0;1PX200`7
2`803`X>0P0@2`l0400?2Ph03PX;00`8200@2`l02PD900`83P0K5Al01`4;014;500A31<03@P<010<
2`0C3``040`901<=3P0G4A<200l92`0V01<=4@0<1PX03PP<00d63@0>1`h03`P?00T22P0F41D030H8
00X41P0=1`T050h@01LA4`0>20X01@0101hH6P0=1`T08A/M00@0000=20T030H800d72@0C3@l02P@6
01hH700Y8bL02@<700D01@0H4AP01`0701D>5P0=1`d05Q0D00d72`0=20/03`T=01D?4`090`L200`6
2P0400d72`0<1PX02`D900h52PP040D;00/03`@:00h32@0>0`T0304701873@0>10T02`0601<83P0<
0`L03P<900l42P0201052`803`@:00T03P<;00d22P0=0PX03@8:00h32`0@1@d03`@<00h32`0?10`0
0P0A1Ph01`0>0`/03`<=00h2300>0P`03@4;00h2300?0`d00P0=0@/200h230803`<=00`01`040187
3`0<0@T0304901D:4P0=0PX04@H>00/1200>0`/040D=00`12@0;00PDooooo`006oooool03P0<2P/0
3`d>00d;300>30d03`d>00P61`0@3Pl030X;00/92P0=2``03P`=00`:2`0?3A0030X>0P0:20`0200=
2`l03`dA00`:3P0:20`02@L;00d;3`0<2Ph02`T<0`0>2P/200l;300=010<3@0?2``020@501<?400P
71d03@T:00`82@0>2PT03@T801<?3P0<20L040`;018>3@0200d9200<014=300?2`X03@T800l;2P0;
1`H03PX900l;2P0>2PT03`/:010<2`0>2PT03@T80P0?2`X0700;1`H02`L700/7200@30d0510A00D1
0P070`@0510A01LC500@30d03@T:00l;300;1`P03@P900`6200;1`P03@T:00l;300?3@h04@l@00H4
1@0<30`0410@00H61P0:2PX02`X;00/92P0<2P/300d;300300`:2`0;2@X030X;008030X;00L02`T:
00d;300=2``03P`=010>3`0?3@h02`T:00803@/<018030X;00/92P0:20T02PP900/930061@L0G5YM
020N8@0<2Pd03`d@00@21@0G5AP02@L:00d;3P0;2@`030X=00`:2`0=2``200l=3P0700h<3@0=2``0
928S02XX:@0>30d02`T:00H41@0200`:2`0400d;300?3@h03`d>00`:2`802PP901L03P`=00`:2`0@
3Pl01`D600l=3P0:20/03@/?00`:3P0?3A403P`@00H4200:20`03@/?00h<400=2`l03`dA01<A5@0?
3A<02`P>010=4`081@/08QlU01PF700200/93`8030X@00P03@/A00d;400<2Pl02`T=00d;3`0>3100
3@/?00X830@02`T=00<03`dA01<A500>30d00P0:20T03`0;2@X02PP900T7200>30d03`d>00L51P0:
20T05A<D0490@@0Y9bX01@<600T72P0?3A003@/>00l=400600/9300400X8300:20h02PL>00X74@80
2PLC01T03P/F00`9500<2A4030X?00d;400?3A001`D700H41P0A3a803@/>00X83@0?3A801@<800T6
3@0P7B@05Q<J00/8400A3QP04a0K010=600>2aD03@XC00h;500>2a<03@XA00@03@/@00T03P`C00L4
3@0E4Q/03``D00L42`0A3QD02@L=00`:3`0<2Pd00P0;2@`0400:20/040hC00L52P0:1`d030/@00h<
4P0<2@l01P@9010>500=2Q00=c@j01LD6P0:20d030L;00d8300>2@d200`72`0400l:3P0@30l030L;
00`72`804@`@01X03PT=00P72@0920X03`d@00/9300920X040hA00T72P0;2@`030X=00X82`091`X0
2`T<00/93P0>2a407A/Q06]XKP0;20h0;b`b05=@EP0B3aD04a4F00l<4P0;2@l020H;00P62@802@L8
00T02PP900/92P0;2@X02@L800X82@0?3@h03@/<00P61`0;2@X01P0<20T00`0=2@X03`/<00/72002
00d92P802@D601402`L800`82@0<20T02PH700T51P0;1`P02PH700`82@0>2P/030P900X61`0>2P/0
30P900/7200<20T03`/<010<3@0200/7200:00X61`0<20T03@T:00d92P0E4A8071PI014=3P0:1PL0
3PX;00d92P8030P900@02`L800d92P0C3a005a<D0P0=2@X400`82@802PH700d03@T:00X61`0:1PL0
2`L800T51P0:1PL030P900d92P0>2P/03@T:00/720091@H030P900803`/<00<030P900/7200<20T0
0P0<20T0200;1`P030P900h:2`0=2@X02@D600`82@0;1`P02@D71@0:1@T00`0;1PX030L;00`72`02
00/62P0800X52@0<1`d03`XA018=4`0=20h02`H<00`73P080`T200/6300300X5300>2@l03PT?00H0
30H@00L0208<00X43P0C3AL08adW01H@6P070P/030L>00D030L=00@030L>00P32P0:1@`03PT?0P0:
1@/04`0810X02`L=00P6300610d03P/G01PG8`1EE60061PS09RJX@33aLX06A/P00H72`081P/030L=
00D01P0<1`d02PH;00h93`0;1P`0100<1`d0100;1P`0108500X82`061@L200X82`0900h<3`0?3A00
2`T<018@4`061@L030X=00L5200>2@d03@P<00<030L;00@02`H:00h93@0;1PX030L;0`0?2Ph02P0;
2@`01P@700d;3P0B41<01`D800X82`0<2Pd02`T<00X82`091`X200P62@05010<4P0>2Q003PXA010<
4`0@2aD00P0?2Q@01P0=2A0030P?00`83P0<20h030P?00/84P<02`PA00P02`P?00/83P0;2@h02`T<
00d;3@0D4Q<04a4B00l=40802@L<00`02PP=00D4200:20d06aTN00<21P0B41D01`D:00l=4P061@T0
3@/@010>4`0=2a0200/93P802@L<00/02`T>00h<4@0=2a002@L<00P62`0;2@h071XO03Pf>`0R82D0
30X?01DB6@0300d:4`803@XE00<03@XD00/84@0;20l00`0<2A0200/83`0D00X73P0;20l030T@00h;
4P0@3A@030TB00d:4`0?31D03``C00h;4P0=2Q403`dB00X83@0?3A0020H900T72P0=2`h03PT>00l:
3`0@2a82010:500?00l95@0<2100;BL`03Lb>00E41H03PX<01DA4P0<1`/04PdA01PC5`0P6al04PdA
00h93@0=20`03`X>00804@`@00<03`X>00d8300@2`l00P0@2`l0300B3A405A0D01LB5P0=20`04`hB
00l:3P0=20`04@`@010;3`0;1PX03`X>010;3`<03`X>00<03@P<00l:3P0?2Ph00P0?2Ph00`0@2`l0
4PdA010;3`0400h93@803`X>0P0@2`l0400?2Ph03PX;014=3@0A31003`X>00h9400<1Q003@PA00d8
400<1`d040/?00h:2P0;1`@03PX701@>3`0H4Q@200l92`0D014;3`0<1PX04P`@01<<4`0<1@`050dD
00X32`0>20d04@/=01PB500A2`d03`T;014;3@0;1PL0618D03H`<P0D3Q004@/=00H10P0D3Q0200/5
1`0@014;3@0:1@H02`D901@>4P070PD050dD00`6300=1Pd06A8J00h83P0=1`/01`45014<3`070PD0
5@lC00`62P803PP<00@03@L;00`62P0<1PX03PD:200@1@/200l42P0900h32@0B1`d03`@:00`11`0=
0PP03`@:01052`0>0`T03`@:008040D;0P0?10X03@0>0`/03@8:00d22P0=0PX03P<;01053@0;0@P0
3@8:00h32`0=0PX03P<;01463P0?0`d00P0>0P`0100=0@/03P8<00l33@0=0@/300h230803`<=00`0
3@8:00h32`0?10`03`@<00d32P0900H02P0700d22P0A1Ph03`@<00X01`0?10`Dooooo`006oooool0
4`071@H02`T:00X82@0:20T030X;00h<3@0M6a`05A<D014?400C4A804@l@00X82@0>30l03`d@018@
4`0@3Q402PP;00/9300B41<00P0=2`h0700?3A003P`?00l=400=2@X03`/<010<3@0A3@h03`/<00h:
2`0B3Pl04@d>010<3@0D41403@T:01<?400:1PD030P700/71P091@@01P8101<?3P0<20L02@D400d9
200>2PT03@T800l;2P0;1`H200l;2P0300h:2@0?2`X04@d<008030P701P03PX9014=300?2`X03@T9
018>3`0A3@h03`/<01`H6@0J5QL03`/<01dI6P0>2P/09R8S04A0@@0T82404Pd?018<3P0A3@h03`/<
00d92P0<2P/03P`=00D3100@410200/;2`0601PH600920T02`T:00d;300?3@h03@/<0`0;2@X01`0<
2P/03@/<00`:2`0;2@X030X;00/92P0<2P/00P0>30d01@0:20T03@/<00d;300=2``030X;00802`T:
00d040hA00/9300?3Q0040hA00X82`0>30l04a4D00P62@0=2`h03P`?00X82`0>30l02@L800D02PP9
00H04@l@01`J6`0;2@X040h?00d;300@3Pl300h<3@0A00d;300:20T020H700T7200:20T04@l@01DC
500<2P/08R0Q01TG6P071@P02`T<00`:3@030P@04@lB00/9300:20/00P0<2Pd020091`X030X=00/9
3P0=2a009R@Y018@5@0@3Q<00@040P0;2@h200`:3`803@/@00<03@/>00`:3@0<2Pd00P0=2`h02P0:
20/030X=00`:3@0:20/020H900T72P0;2@`040h?00/92P0:20T300/92P0:00P61`0=2``040h?014?
400100002@L800d;3P0A3a800P0300P62@P02PP;0P0;2@`06@0;2@h02`P@00/84@0;21403``F00d:
4`0=2Q0030X=00/9300>30l02`T<00P62@0=2`h030X=00`:3`0A3a@01`D:00H32P0E4QT04@hE00h;
500>2aD02@HA00X74P0;21800P0;21400`0;21002`P?00/93P0300/93P0800d;4P050P/02PL@00h;
4`0@3A@04PlF00P6300;2@h400/9300@00l=4P0G5AX00@0400d;400100@02@L<01PF6`0100@040hC
07EcN00G5AX01`D:00/62P0<1`/03@P<00`72`802`H:00l01`8601LB5P0?2Ph040/?00/62P0@2`l0
H5iQ04E3AP0Y9bX00@0200T72P0@3Q4020H900T72P0;2@`00P081PT02P0:20/04@lD02h/<@0D4QL0
1P@901DC600A3a@03`dB010>4`091``200/93P0300<110081PT020H700@02@L800P02PP900`:2`0>
30d03@/<00P61`0610D02`L800d92P803PX;01X03@T:00/720091@H030P900h:2`0;1`P03`/<00X6
1`0>2P/030P900d92P0?2``02PH700H20`0>2P/02`L800`82@0=2@X02`L800T51P0=2@X030P900/7
200=2@X03PX;00l;30<02`L800P030P900d92P0>2P/0510A01XF5`0?2``01@4200/720803PX;00<0
3@T:00/720091@H00P0810D0200?2``03@T:00d92P0;1`P02PH700d92P0:1PL020@50P0>2P/01@0;
1`P030P900h:2`0>2P/02`L800803@T:00<03`/<010<3@0=2@X00P0<20T00`0;1`P02PH700X61`04
00X61`0700`82@0;1`P01P8300P41@0B3Pl04@d>00/72@0;00/62P0900T42P0>2@l04@`B00P32@04
00D02`H<00h93`0C3Q@04@`B00<02@@:00<030L>00`6400<1Q000`0<1Q0200X43P0400T33@0G4A/0
4P`F00`63`H02`H<01X03`X@00d83P0=20h03PT?00d83P0;1P`030L=00d83P0910/01`4;00/84P0F
4R00:bLe00D43@0;2a<0:2L]00h?4`0A41D02@L<01@?5@0;1P`03@P>00/6300A31802`H<00`73@80
3@P>00h030L=00/6300C4A@02PP;00/9300>30l04Q0C07ilO`0G5AP01`D800@21@0O7B002@L:00X8
2`8030L;100=20`0100>2@d02PD900X52@0<1`/200h93@0300X82`0610L01085008020H900<01085
00X82`0:20/00`0:20/02P0:20d03P/B00d:4@0>2a8040dD00l<5@0>2a@03``E00d:4@0<2A0200/8
3`0300/84@0:1a402PL@00802PL@00P02PL>00X83P0;2@h02@L:00X82P0A3a003`d>00P62P801P@9
01003@/@01LE6P0C4AH03@/@01DC600K6Ah0108701/I7P0?3A803P`A00`:3`0:20d02`T>00d;400<
2Pl03P`A0P0;2@h0100?3A802`T>00`:3`0C4AH200X83@0300T7300?3A802@L=00<02`PA0P0;21<0
0`0;21802`PA00/83`0200d:4@0600`9400;20l040dD00l<4`0=2Q402PL>0P091Pd00`0;214030TB
00l<5@0200l<4`0700d:4@071@X02@L<01HD5`0:20/01@<601/I7002010;3`0B010;4@0@2a8040XD
010:5P0S7BL030P?01@?5@0>2@l050lB00<0000B3A403@T<00L21P0>2@d020<700h93@0=20`03`X>
0P0A31001P0?2Ph03@P<00`72`0=20`03PT=00l:3P804@`@00<03@P<01@?4`0B3A400P0=20`02P0A
31002@@800h93@0@2`l03`X>00h93@0?2Ph03PT=00d8300>2@d2010;3`0300l:3P0A310040/?0080
3`X>0P0>2@d200l:3P8040/?01003`X>00h:2`0<20P020@501<>4P0j=C/09R0Z01D?6@0>2A002`H<
01HA5@0A30l020@3010<2`0A2`d050h@0P0?2@/04P0A2`l03`T=010:3P0;10/03PL>01@=500700P0
40X?00@0000500402`D700`6200@2P`03PP:00D00@0=1`T02`D701hH6P803`T;01@040X<00`62009
0`D03@L900`62P0=1`/08Q`P00T22@0D3a@0100400P12@0<1@`04`dA010:3P0D3Q803PP<01PB5P0<
1PX03`T=00h830<03@L;00<03`H;01052`0@1@/00`0@1@/600l42P0801<83P0:00D04@H<01P=4`0@
1@/04@H<00h32@0?10X201052`803`@:00d03P<;00d22P0=0PX03@8:00h32`0@1@d0200500`12@0?
10`03P<;01463P0M4QX03`<=00803P8<00<03@4;00h2300?0`d01P0>0P`0300A1Ph0304901<8400@
1@d02@0601P=5@0B1`l03`@<01053@0>0`/02`0800l431Cooooo000Kooooo`<02PP901402@L800/9
2P0?3@h05A<D00h<3@0;2@X03`d>00h<3@081PL02PP;00/9300@3Q403P`?00/9300A3a804Q0C00X8
2`0200/9300400T72P0=2`h03@T:00l;30804@d>0P0?2``0100<20T040`=00L3100A3@h2018>3`09
01DA400400000`00014=300?2`X02PH501<?3P0;1`H030P700803PX900<04@d<00l;2P0?2`X00P0>
2PT05@0B3Pd05A4@00h:2@0;1`H030P7014=300E4A004Ph>00T51P0>2P/04Ph?00<000050@8040`=
01XF5`0<20T09R8S04I2@`0W8b@03`X<00/51`0200d92P0@00`82@0<2P/03P`=00H41@0>3Ph01PH6
00d=3@0W9bL05aHF00/92P0=2``03`d>00d;300;2@X02PP900`:2`<03@/<0P0<2P/200/92P0300d;
300>30d02`T:00<03@/<0`0<2P/0300100805Q@G00T72P0D4QD01@<601<A500<2Pd0108500`:3@0:
20/040hA018@4`<02PP900T02@L800X82@0:20T00@0000h<3@050`@04@l@00l=3P0A3a001@0<2P/0
3`0;2@X03@/<00/92P0@3Pl0518C00h<3@0W9BH0=38e01DC5P0100807Q`O01DC5P0200<040hA00`:
3@0200l=400600/9300>30l0:RP]01/I7P0Q7b@03P`A0P0A3a@200/93P8030X?0P0=2a001P0>30l0
2`T<00/9300<2Pd03@/>00/9308040hA01H03`d@00`:3@0<2Pd03@/>00d;300;2@X030X;00d;300;
2@X02PP900T820091`P02`T:010>3`0:20T040h?01@B5@0A3a80518E00X82`030@@0518E1P0<2Pd0
100;2@X02`T<00/93P0;2@l200/83`0I00d:4P0<2A0030X?00/9300:20T03@/=00d;3P0<2Pd03`dA
00d;400<2Pl03@/A00l<4`0>2a802@H>00`94P0?31D03@XD00`9500>2aH03``F00l<5@0>2a@03@XB
00d:4@0400d;400400`:4@081@h02`PA00h;4`803@XA00<02@L=00/93P0;2@`00`0;2@`00`071@X0
1@<8014?500200d;400301DC600:20d05A<H00803`dB00@05Q@I010>4`0<1`/030L;0P0=20`08@0<
1`/02`H:00/62P0?2Ph01P45010;3`080`L050lC0:VWZP0Q7b806ALJ034_<P01008030X=00T72P0;
2@`030X=00X82`091`X02`T<00`:3`1UHfP00`46010>4`040PL07A/P01<A5P020@D0GE]P08n=TP0:
20d04Q0C00T72P0600T7200700`:2`0;2@X02`T:00T720050`@02PH700`82@0200d92P0900`82@0:
1PL03`/<00X61`0<20T03`/<00h:2`0@30d03`/<008030P900@03`/<00/720070`@03PX;0P0;1`P0
0`0=2@X02`L800X61`0300/7208030P900D03@T:00h:2`0=2@X030P900/7200200`82@803PX;00L0
2@D600P41@0<20T03@T:00P41@091@H02PH700803@T:01L030P900l;300=2@X03@T:00/7200:1PL0
30P900X61`0;1`P04`l@010<3@0;1`P02@D600`82@0;1`P02@D600h:2`0@30d04@d>018>3`0?2``0
3@T:00/7200200T51PD02PH700L02`L800`82@0:1PL02@D6010<3@0B3Pl03PT<00/02`H:00T01P47
00/6300=20h01P4700L2200C3Q@05A0F01XE6`0G4QP00P0=20h00`0<1`d030L>00`73P0400`73P06
00/63@0=20l01P4800/63@0:1@`040/B1P0;1P`06@0@2a403`X@00d83P0=20h03PT?00/6300>20`0
30D;00X32`0;0`h030HA00`64P0300T02`PB00`;4`0@3A@00P4600000P081P/06A@J00l:400>2@l0
30L=014<4P0;1P`0100=20h03@0;1P`02`T<00D31P0;2@`04Q0C01LE6029QhX04a4D014?4P0E4aH0
HEmR010>4@0=2`h00`0=20`300h93@0I00d8300910P02@@800/62P0<1`/02`H:010>4@030@@05aDH
014?4P081PT04Q0C00T72P0:20/02`T<00h<3`0?3A003`dB00`94@0<2A803P/D010=500>2a803@XA
00h;4P0200d:4@0<00d:4`0>2a@03P/D00`94P0;21402PL?00T63@081@`02@H<00`:3`0<2Pd02@L:
0P0;2@`0400=2`l04Q0E00d;400:20d04@lD010>4`081P/04@lD01@B5`0E4aP08b4V00l=4P0<2Pl0
2PP=00T7300;2@h200h<4@0500l=4P0:20d01`D:00d;400?3A800P0>31401@0<2Pl03@/@00P62`0<
2Pl0514H00<02`PA0P0;21<00`0;21802`PA00`9400300d:4@0:00`940091Pd02PL>00/83`0<2A00
3P/B010=500:1a002`PA00d:4`803P/B00L03@XA00/93P0?3A8081hQ01<A500=2`h08AlR008040`=
018040/@010;4P0@2a8040XD00l94`0=2A003`X@00<0100A3@l06aLH00`72`0D3a<05a8F01`G6`0@
2`l04`hB010;3`0?2Ph200h93@0300l:3P0@2`l03@P<00@03@P<00P030L;00h93@0C3Q8050lC00l:
3P0<1`/04@`@00`72`803PT=00@03@P<00h93@0A310040/?0P0>2@d00`0B3A404@`@00l:3P0400l:
3P0400h93@0=20`03`X>00l:3P8040/?01803`X>00h:2`0A3@d081`M00h93@0H51T03PT@00@01P0?
2Q4030L=01LB5P0A30l020@3010<2`0>20X04@/=00l92`0@2P`2018<400Z00d72`0400@05@hE01H?
5P0@2A40;2H[01@>4004000040X<00`6200=1`T03`T;010:300H4Q@030H800d72@0;1@L03`T;018<
3P0C3@l030H800h82P0@2Ph030H:00@00P0I4QT04P`B02lX;`2RVj<06A8I010:3P0400805a8E00@0
0P0:10P04P`@00l93@0>20`03@L;00h8300?2@d040P=1@0@1@/600l42P0801<83P0<0@L06PlE02DJ
800G31804PL=00h32@0?10X201052`803`@:00d03P<;00d22P0=0PX03@8:00h32`0@1@d02`0800h3
2`0A1Ph03P<;00l4300J3aL03`<=00803P8<00<03@4;00h2300?0`d01P0>0P`02@0?10`03@8:01D:
4P0>0`/03@@:02XO9`0N4a/040D=00`12@0200h32`0300d22_oooooooooo01;ooooo000Kooooo`0H
01HD5@0=2``030X;00`:2`0;2@X03P`=00d;300<2P/02`T:00h<3@0@3Pl03`d>010>400;2@/03P`>
00l=3`0E4aD0:BLY01XH6P0>30h040h@00h<3P0;2@/04@lA0P0?2``2010<3@804@d>01804`l@00/7
200;1`P05Q8C00h:2`0?2``03P/:00h:2@0J5QD0510?014=300>2PT06aLF00h:2@0?2`X04@d<010<
2`0A3@`2010<2`803`/:01P04`l>01HB4@0D40l03PX900d9200A3@`0510?014=3@0C3a003@T:00l;
300k=cP0<bl`00d92P0C3a003PX;00d92P0B3Pl03PX;018=3`0F41805a<D018>3`0;1`P200X82@06
00/92P0C4a<03`l?00T92@0=3@d030/<0`0=2``00`0<2P/02`T:00`:2`0200d;300400h<3@0=2``0
3@/<00d;308030X;00<03P`=00l=3P0>30d01P0=2``0100@3Q401`D8014?4P081PT200h<3`803@/>
01@03P`?00/9300>30l03@/>00l=3P0>30d03@/<00`:2`0=2``03`d>00`:2`0G5AH01`H600h<3@0;
2@X03`d>00/92P0:20T02`T:00`:2`803@/<01P03P`=00l=3P0;2@X040h?00`:2`0G5AH02`T;034_
<@0>3@h030X<00d;3@0?3Pl04a4C00P6200<2P`03P`>00/92`0B41806QPL01@B5P0;2@d03@/?00/9
3@0<2Ph200/93@8030X>00T03@/?00d;3P0?3A002`T;00X82P0<2P`03@/=00`:300;2@/00P0=2`d0
1P0<2P`03@/=00h<3P0:20T020H700T720803@/<00d030X;00X82@0F51D0518C00T8200<2P/04@l@
010>4@0;2@`04@lB00h<3`0B41<02`T<00D030X=00D030X;00`;2@0<2`X030X<00`:3P0200`:4006
00/93P0<2Pl03@/>00`;2P0;2PP030X;0P0=2`l200`:3`0400/93`091`d04@hE01DB6P803@XC0P0<
2A<2010=600500h;5@0<2A802`PA00d:4P0@3A@0100@3Q<0200?3A@040dF00`94P0:1`l02`P?00h;
4P0?3A<02PP=0P0;2@`200`:3@0@02TW:`1JF5`040hB00/93@0@3Q802`T=01HD60050`L030X>014?
4`0610P02`X=00h93@0<1`/02`H:00d830803`X>01D04`hB00d8300>2@d040/?00/62P0>2@d0928U
01<A500<2Pd01`D800d;3P0>30l02`T<00`:3@0=2`h02`T<00X82`0<2Pd03P`@00d;3`0<2Ph00P0?
3A401`081PX01@<7014@4`0A3a<0<c4e00X8300920X00P0<2P/300/92P802PP900D02`T:00T7200<
2P/040h?00/92P0600`82@09010<3@0S7b0020@5014=3P0?2``04Ph?00d92P0<20T02`L8008030P9
0P0=2@X200/7200300h:2`0?2``03PX;00802`L8100<20T00`0?2``03@T:00`82@0300`82@0300d9
2P0810D02PH700803PX;00L030P9018>3`0>2P/03@T:00h:2`0=2@X02`L800803@T:0`0<20T02P0;
1`P02PH700d92P0B3Pl03@T:00X61`0B3Pl07ATJ01TE5P0<20T200h:2`0500/7200=2@X02`L800`8
2@0=2@X00`0<20T01@0;1`P02PH700/7200<20T02PH700802`L800@02@D600d92P0>2P/03@P;1@0<
1`/0100;1PX02PD900/62P0;1PX200`72`0<00T42@0;1P/030L<00/62`0?2Pl06QDJ00`7300>2@h0
3@P=00/62`0>2@h03@P=1P0<1`h01`0910/040/B00`73P0@2a803PT@00d83`0=20h01@0=20d200l:
3`0E00/62`0:1@X03@P=00T3200;0`P02`<900d5300?1Pl03PHB00/44@0=1Q803@LB00P42`0810X0
2PL;00h:3P080`T050lE00l:400H4aT05Q4G008030L=01403@P>00h93`0>2@l03@P>00`73@081`T0
3P`?00T72P0=2`h02@L:010>4@0C4A@02PP;00/93013@D@02`T<00l=400200l:3P803PT=0P0=20`0
3@0>2@d030L;00d8300>2@d030L;00T4200=30h00`4400X82`0@3Q40518E00P72@0;2@`00P0<2Pd0
3@0>30l03`d@00l=4P0;2A4030XB00l=4`0A3aD03`dC00d;4@0@3Q@03P`B00d;4@0=2a<00P0>31D0
2P0>2a<030TA00`9400:1`h02@L=00/83P0>31403@/?00/93@0?3A4200h<400=00l=4P0<2Pl02@L<
00P62`0:20d02`T>00l=4P0@3Q<0518G00h<4@0<2Pl040hC00h<4@0200`:3`0>00d;400;2@h02PP=
014?500@3Q<020H;00/93P0<2Pl020H;00/93P0:20d03P`A00l=4P0<2A0300h;50803P/F00<03P/E
00`94P0=2Q400P0>2a8200d:4@03018?5P0@3A@03``C00<030T@00<02PL@00/84@0>2a@00P0?31<0
1`0>2a803@/@00d;400H5QT03@/>00`:3@0@3Q400P0@30`0400?2Pd03PT?00l:400@2a<0618L02XT
;@0D3aH04`hD010;3`0>2P`0=C0d024L800>2@d04PdA00`72`0?2Ph2010;3`803PT=0P0@2`l06@0A
31004PdA018=4@0B3A4040/?00h93@0@2`l04@`@01D@500D3a<03`X>018=4@0?2Ph04PdA014<400@
2`l03`X>010;3`0C3Q803`X>010;3`0D3a<04`hB010;3`0?2Ph00`0@2`l0100?2Ph03PT=00l:3P0?
2Ph2010;3`0?00l:3P0>2@d04Ph>00d92P040@40:B@Y03Xe>P0S7R@04@`B00l:400B3A<03`X>00/7
2@0=2@/03PP:008040X<00h03`T;010:3P0B31005Q0D00L21`0F3aH02@@901dF7P0R72405Q0B00T4
1@0A2`d040X<018<3P8040X<0P0?2@/06`0=1`T03`T;00d72@0B30h0618D01@>400<1PP03@L;010:
3P0C3A402P<:00`6300:0`X0<BXb00h83P0=1`/06Q@H04Q2AP0F4A@01P4400l93@0>20`03@L;00h8
300A2`l04`dA01<:3`0501052`803P<90P0?10X201052`0800h32@0:00D04`P>01T>500@1@/03047
00h32@0?10X201052`803`@:00D03P<;00d22P0=0PX03@8:00h32`0201053@0601463P0@1@d03049
00/1200=0PX03`<=0P0>0P`00`0=0@/03P8<00l33@0200l33@<03P8<00d03@4;00l4300?10`04PL?
00d22P0?1@`09AXR01hC6`0>10/02`4801053@0?10`0304901Cooooo000Kooooo`0301TG600:20T0
2`T:008040h?02804a4B014?400A3a003P`=00`:2`0;2@X03@/<00X82@081PL040h?00h<3@0;2@X0
6aTJ01XH6@0=2``03P`=00/92P081PL040h?014=3P0?2``03PX;010<3@0B3Pl04`l@00d92P050@80
5A4B018>3`0L61T0BDE6075]K00300003`/:0P0E4A001@0<20L03PX900L30P0<20L04`l>00804Ph=
00<030P7010<2`0A3@`00P0@30/00`0A3@`05Q8A014=3002010<2`0F00`81`0<20P03`/<00T51P0?
2``0>CDf034];P0A3@h02@D600`82@0A3@h03`/<014=3P0=20T04@/=01@@4@0B3Pl03@T:00d;300A
3a003P`=00H61P803Ph>00@02PX:014@400>30d030X;0`0;2@X0100<2P/03@/<00d;300>30d200d;
300400h<3@0=2``030X;00h<3@8040h?1P0=2``01P0;2@`03@/>00d;3P0:20/03`d@00h<3`802PP;
010030X=01<A50091`X03@/>00h<3@0=2``02`T:00X82@0;2@X03P`=00X82@0H5QL030X;01@B4`0=
2``02`T:0P0<2P/04@0;2@X02PP900/92P0;2@X01P@500l=3P0;2@X04a4B014?400<2P/040h?00H5
1@0@3Pl03`d>00X82@0C4A808AlP008040h?00T04@l@00`:2`0C4A803P`?018@4`0100804Q0C00`:
3@091`X00P0;2@`200`:3@803@/>00X03`d>00/92P0:20T02`T:00d;300<2P/04@l@018@4@0@3Pl0
3@/<0P0;2@X01@0>30d020H700P61`0>30d0518C00805Q@E00/030X;00T720091`P030X;00@20`06
1@L071XM05ABE@0K6A`0108501<A500500X82`0500X82@0<2`P030/900`;2@0<2Pd00P0<2Pl04@0;
2@h03@/>00l=3P0?3P`03Pd900l=3P0@3Q<03`dB00X83@0;2@h03P/B014>5@0:1`h020D>010=5P0;
21402@HA00803@XE00H030TD00`94`0=2Q<03P/D00h;4`0<2A0400`:3`0:00P63@0:1a0020D>00/8
400=2Q402@H=00d:400:20d02PP;00/9308030X=0240108504Y8B`0<2Pd00@0201`J7@081PT01@<6
00l=400B41<01P@700/9300>30l040/?00`72`0:1@T03PT=014<400B3A403@P<00/62P0?2Ph00`02
00d8300@2`l05Q@G014?4P0<2Pd05Q@G00h<3`071@P02PP;00/9300=2`h00P0:20/03`0<2Pd00P03
00h<3`0<2Pd00`4401HD5`081PT04a4D00`:3@0=2`h01`D800/9300<2Pd03P`=00d;300200`:2`80
2`T:0P0<2P/01P081PL03@/<01LE5P0C4A8040`=00h:2`8030P901H03PX;010<3@091@H0AT9300L3
100=2@X04Ph?00/7200?2``040`=00d92P0<20T04@d>01LC500C3a003PX;00`82@0;1`P02PH700T5
1P0<20T03@T:0`0>2P/02`0=2@X030P900`82@0<20T03PX;00l;300@30d03PX;00`82@0>2P/030P9
008020@500H03@T:00T51P091@H03`/<010<3@0?2``500`82@0@00h:2`0=2@X03`/<010<3@0:1PL0
30P900l;300@30d03PX;00H20`0?2``04@d>00`82@0;1`P02@D600X61`8030P90P0=2@X300/720<0
3@T:0P0<20T00`0A3@h03PX;00X5200500`72`0400/62P0:1@T02`H:00/62P8030L;00@04PdA014<
400>2@d030L;0P0;1PX200d8300500`72`0?2Ph050lC00l:3P0<1`d01@0<1`h01P0=20l040/B00L2
2@0A31<04PdD00T42PH03PT=01D04@`@01<>4P0=20`02`H:010;3`0;1@T03@@901<9400A1`l0308;
00/2300@21D03@DB00L22@0C3QD040/A00T4200D3a<030L=00d83P0>2@l00P0X8bT00`0910X030L=
00d83P0200h93`0F00d83P0<1`d020H900H41`0C4A@030X=00L520050`H03`d@00X82`0K6A`00`44
014?4P040PD04@`@010;3`0?2Ph03PT=00`72`0;1PX03`X>010;3`804PdA00X03@P<00T4200;2@`0
6aTL085oPP1NG5l01`D8014?4P0=2`h030X=0P0;2@`030091`X02@L<00`;4P0=318040lD01<C5P0@
41803Ph@01<C5@0@41803PdB00`;40802`XB01`02`P?00`9400<2A003@XA00d;400?3A803@/@00T7
300?3A806aTN01LE6P0>31402PP=00/93P0C4AH03@/@00X83@0<2Pl02PP=00/93P0C4AH03P`A00l=
4P081`/03@/@00/93P0<2Pl03@/@0P0<2Pl0200U8bP0:RP]00h<4@0<2Pl040hC00T7300=2a002PP=
0P0<2Pl0100<2A0030TB00`94P0<2A8200`9500300`94`0<2A803@XA00803P/B0P0=2Q4200l<4`07
00h;4P0?31<03``C014>5@0;214030TB00l<5@02014>5@0K010=500@3Q<02`T>00l=40091`X04Q0C
00h<3P0?2`X03`/800d92@0<1`/03@P>00l:4@0300L0;RPa00X5300E41H030P<00`72`0n>Cd081/O
014<400O6Qh061<G00d8300<1`/03`X>00804PdA00D03`X>00`72`0>2@d040/?018=4@0201<>4P05
014<400@2`l03@P<01D@500G4QH00P0A31001`0?2Ph050lC01LB5P0D3a<03PT=00/62P0E41@00P0A
31001@0G4QH05A0D014<400@2`l04PdA00804`hB00@04@`@010;3`0?2Ph03`X>0P0@2`l03`0?2Ph0
3PT=00l;300<20T03`/<018=4@0K5QX02@@801HA5`0E41H040/A014<4P0B3A<03`X@018<3`02014;
3@0;00d72@0;1@T03PP<010:3P0?20l05a0G018;4P1?B5005@lD014;3@0I4aD00P0A2`d01P0D3Q00
3@L900h82P0600803PP:00`620803PP:01804@/=00l92`0A2`d03PP:01D?4`0H4QH01@0301H?5P0<
1@`071DL00@01@0C31<05a4E018<400=20/02`D901PB5P0:10P200`62P0400h8300B31005Q0D01@<
4@D040D;0P0>0`T200l42P8040D;00P060dC01873@0=0PP03@8800h32@0A1P`03P<900l42P8040D;
0P0?10X02@0>0`/03@8:00d22P0=0PX03P<;01053@0>0`/03@8:00h32`0201463P0600l4300?0`d0
3P8<00h2300=0@/03P8<0`0?0`d200h230803@4;00<04@H>00d22P0<0@T00`0<0@T0100>0`/02`08
00l4300@1@d200`12ACooooo000Kooooo`0800l=3P0=2``03`d>00X82@0B41402PP900h<3@0<2P/2
00X82@0500`:2`0>30d03P`=00d;300<2P/00P0>30d02`0<2P/03@/<00X82@0=2``030X;00X82@0=
2``03@T:00h:2`0?2``040`=00804@d>00`04`l@00d92P0?2``03@T:01lK700f<S<0FEED00d9200?
2`X04@d<010<2`0B3Pd600l;2P08014=300:1PD04@d<010<2`0H51<01@4000h:2@0@30/2014=300]
00h:2@0>2PX03PX;00d92P0?2``04@d>01@@4@0@30d01@42010<3@0F4Q<01P8301DA4P0;1PL03PP:
010<3@0A3@h02@D600L51P0;2@X0Cde>01/K6`0A4A40N7Qh03lo?`071PL04@l@00d;300;2@X03`d>
00T7200B41401@<400H41@0A3a002`T:00`:2`0;2@X030X;018@4@0A3a002PP900P61`0<2P/03@/<
00803`d>00<03@/<00`:2`0<2Pd01@0<2Pd0100?3A003P`?00h<3`0=2`h200`:3@0300h<3@0=2``0
3@/<00804@l@00T030X;00h<3@0=2``03@/<00P61`050`@03P`=00`:2`0=2``00P0>30d3010>3`06
00h<3@0C4A804Q0A00`:2`0A3a0030X;100;2@X02@0:20T0518C00h<3@091`P02PP900h<3@0@3Pl0
2`T<00d;3P0200l=400500d;3P0;2@`01`D800X82`0>30l00P0?3A000`0=2`h03`d>00h<3@0200`:
2`0400h<3@0?3@h030X;00`:2`803@/<00H030X;00/92P071@H020H700T7200<2P/200d;300;00/9
2P0@3Pl02@L800h<3@0;2@X03P`=00P72@0Q7b809R@W05YHF`0=2`h00P0;2@`04@0>30l030X=018@
4`0:20/030X;00d<2@0F5A<02PT700`:3@030@H020H;00l=4P0=2`h030X;00`;2@0<2`L030/;0080
30X?00D030X@00`9400<2A0030TA00`94P0400`9500:00/84`0A3QT01`@?010=5`0100L05a@M00d:
4P0;20l030X?00d;40801P@900`030XA00<02@0a;SL02`P@01@A600100D03@X@00H42@0;2@`03@/>
010>4@0<2Pd300d;3P801P@700h06ALJ01hL7`0F51L02`T<00X82`0;2@`020H900d8300;1PX040/?
018=4@0=20`030L;01@?4`8040/?01403`X>00`72`0>2@d03P`?00/9300>30l020H900800`0I5aX0
DU1C01LE600=2`h020H900@21@0?3A002PP;00/9300200`:3@0J00/9300:20/040hA00/9300E4aH0
3@/>00@21@0A3a8030X;00l=3P0;2@X01`D600`:2`0C4A803`d>00X82@081PL02`T:014?400C4A80
2`L800h:2`0;1`P04@d>00/7200<20T200h:2`803@T:0P0<20T0300=2@X03`/<00/7200;1`P05a<D
020L7@0N6Q/02PH700l;300B3Pl02PH700T51P802PH700D0?SXk00h:2`091@H02@D600d92P0200X6
1`0500d92P0<20T030P900d92P0E4A800P0<20T03@0>2P/01`<400H20`091@H02PH700/7200=2@X0
3`/<018>3`0810D02@D600X61`0;1`P00P0>2P/02@0=2@X030P900X61`0:1PL02@D600`82@0B3Pl0
4`l@00T51P0200P41@0=00`82@0@30d02`L800X61`0<20T03`/<00<000070`@04Ph?00H20`0<20T0
3`/<00`82@0200d92P0800/7200<20T04@d?01`G6`0M61`04@`@00/62P0=20`200`72`803@P<0P0<
1`/08@0910P061<G01dH700=20`02@@800`72`0=20`081/O00T5200F4AD071LK00h93@0=20h02PD;
00/7300B3A<03@P>010;4@0;1P`00`0401/F700300@050lE00H21`0=20`020<700l:3P0<1`/03`X>
00T5200C3Q804@`@00d8300200T4200=00/52@0700403@<700P01P0G3AH040PA01H>6@0500P040TB
00l:4@0<1`d02PD900h93@0200d83P803PT?0P0?2Q00100910X02PD;01@?5@0D3aD200/6300=00@2
1@0@3Q400@0201@B5@0;2@`03P`?014?4P0;2@`020H900/9300<2Pd02@L:00d8300200`72`0k00d8
300>2@d03`X>014=400;1PX00`02018=4@0400<05A0D00P72@0:20/0DU1C03Xh>`0:20/040hA00h<
3`091`X04@lB00l=40091`X03@/@00h=50081`d010<801PH6@0M7A/03`l=01HF500A4A403Ph@00L6
300;2Q804A0H010>500;2@h02PP=00h<4@0=2a0030X?00H42@0F4aX01`@;00l<4`0O72<01@8800X8
3@0=2a002PP=00P62`0=2a004Q0E00d;400;2@h040hC018@5@0=2a002PP=010>4`0B41D00P0?3A80
200=2a002PP=00`:3`0>314040hC00h<4@0<2Pl02`T>0P0<2Pl02`0;2@h02PP=00T63@0100L04a0I
00H3300?31L01`@?00/84P0=2Q<03@XA00803P/B0P0?31<0100A3QD01@89014>5@0?31<200T63@0Q
01HC700710d0>3Dn018?5P0>2a8030T@00d;400610T0518E00400P0<2Pd03`d?00/7100C3``04Ph<
01HB4`0B3A402`H<01@?5P0A31<03PT@00h93`0A314050lC00l:3P0A3A007aXN01HA5@0;1PX050lC
01<>4P0@2`l03`X>008040/?00<03`X>010;3`0@2`l00P0A3100100B3A404`hB018=4@0A3102010;
3`0M014<400B3A404@`@01`G6`0R7B407QTM01<>4P0<1`/04PdA00`72`0=20`05Q4E01TD600C3Q80
4@`@010;3`0A310050lC01LB5P0I51P03`X>00`72`0B3A405A0D00h93@0;1PX0510A00h:2`0=2@X0
0P0@30d05P0>2P/04PdA01<>500C3Q@04`hE014<4`0@2a804@/>00/51`0<1PP040X<010:3P0>20`0
3PT<01/D6`0>1`h05PlF02DN9P0H4AL040X<00h82P0?2@/2014;3@0S00`6200G4A<02084028L7P08
0P@05a4C00d72@0;1@L02P@600h82P0J51H0208600/52@0A2`l050dD00l83`0A2Q4040TA00`5300=
1`/030H:00/52@0=1`/03PP<00/52@0W8BD08adQ00/52@0_:Bd0;2HZ01893P0?10X04@H<01<83P0B
1`d00P0>0`T00`0?10X04@H<014630020146300401P=4`0D2@l03@8800h32@803`@:00P02`0601D:
400C20h02P0501T>500A1P`0304901053@804PL?00@0200500l4300C210040D=0P0=0PX00`0>0`/0
304900l33@0500l33@0B01H:500?1Pd02`0901D94`0<0@X03`<=01873`0<0PT03`@<00L0100A1Ph0
200500L0100D2A403`@<00/0200B1`l040D=5?ooool001_ooooo00H040h?00l=3P0?3@h02@L800l=
3P081PL600`:2`0300h=300=30/030/:00803Pd<00/030/:00h=300;2PT03Pd<00d<2`0;2PT03Pd<
00d92P0>2P/03`/<010<3@02014=3P0<00l;300E4A807ATJ01DA4P0?2``05Q8C010=300E4A005Q8A
00/81`0S7ah03@T81P0?2`X01`0B3Pd030P700h:2@0:1PD06ADD00`9200?2`X00`0@30/0100?2`X0
40`<014=3P0@30d200l;308040`=00X03`/<018>3`0<20T061@E00/7200?2P/040X<01LC500N6Q/0
510A0P0<2P/05`0a;c004Q8B00l?3`0k>c/06ATI00d<30040`<03P`=010>3`0;2@X0518C00/92P0B
41403P`=00X82@0>30d03`d>01@B4`091`P02PP900d;300<2P/03@/<00802PP900@02`T:00`:2`0<
2P/03@/<1P0<2Pd200h<3`0700d;3P0<2Pd030X=00`:3@0>30d03@/<00h<3@02010>3`0700d;3009
1`P02@L8014?400D4Q<03`d>00h<3@0300d;308030X;00<02`T:00l=3P0=2``00P0A3a001P0=2``0
3`d>00`;2P0<2`X03@/;00d<2`803Pd<00H02@L700d<2`0?3@d03@`;00`:2P0;2PT700d;3@0700`:
300:20X02PP:00`:300=2``02@L800d;2`0200l>3@0400d;2`0920L030/:00`;2P803@`;00<030/:
00/:2@0;2@X00P0<2P/300d;300F010>3`081PL061HG00d;300;2@X02@L800l=40091`X0108501<A
50050`H0518E00l=400<2Pd02@L:00l=40081PT030X;014@3P0510<061HH00l=40803`dC00H03`dB
00d;400<2Pd030/:00d<2P0=30d300d;4@0500d:4@0=2Q803@XC00`94`0<2A@00`0<2AD0400<2A@0
4PlJ00`9500<2A<03``E00l=5@0<2A402PL>00X83@0?3A803P`A00d;400>2a8030TB01lL9@0<2A42
014>5@06014>50091``02`T<00`:3@0>30l03`d@0P0;2@/02`0?3@l03@/=00X82P0A3a40518D00l=
3`0:20X030X<00d;3@0;2@/04PdA00803PT=00@03`X>00h93@0C3Q804PdA0`0>2@d03`0;1PX03@P<
00`:3@091`X02PP;00T72P0:20/09B<V00l=400C4A@081hQ00d;3P0l>Sd0518E00/92`0400`:300>
00/92`040P@03`d?00T72@0:20X04@lA00H41P0:20T02`T:018@4@0F51D04Q0A00P61`0;2@X200d;
30<030X;00H02PH7010<3@091@H030P900/7200F4Q<200h:2`<03@T:00h030P900/7200?2``03PX;
00X61`0<20T040`=018>3`0D414040`=00P41@0<20T04@d>00l;30803PX;00D04`l@00h;2`0<20T0
6ADF010<3@0200`82@803@T:00P061@E028N7`0G4a@030P900d92P0<20T02PH700`82@803@T:00@0
3`/<014=3P0@30d02PH70P0;1`P00`0:1PL03PX;010<3@0200l;30<03@T:00l03PX;018>3`0C3a00
2`L800`82@0B3Pl02PH700D20P0=2@X04@d>00h:2`0:1PL05Q8C018>3`060P<00P0@30d02P0>2`/0
2@D600X61`0=2@X03PX;00`82@0:1@P030L;00/62P0:1@T200h93@0h00`72`0=20`030L;00/62P0<
1`/03@P<00X5200C3Q405A0C00/62@0:1@P030L:01LC5@0l>3X07a/M00P31P0=2@/04Ph@010;400;
1P/030P<00d83@0:1@X02`L;00X52P0A3140IV5V00h93P070`L03`X?00l:3P091@L03@T;00H2100D
41803`X=00l;3@0>2@`02`L900X5200<20X03PT:00l82P0D3A003@L:00`52`0=1Ph040XC00l84@0:
1@`02`P=00T62@081@L03``=00d8300=20h200h93`803`X@00`061<I00/6300?2Q003`X@00P32@0C
3Q@030X=020N8@040PD01`H800T72P0>30l200`:3@802PP;00D030X=00d;3P0>2@d03@P<00`72`02
00/62P0=00`72`0@2`l03`X>01HA5@0=20`04`lB00X62@0<2Pd02PP;00/930091`X03`d@00<11002
00/9300L00d;3P0A3a804Q0C014?4`0;2Pl0410C01DF5`0N81`09bTR02X/900S9Ad04Q@?01PI5`0A
4A<03`lD00P73@0@3Q<02`T=018@50030@D0;B/`06ARI`0I5Q`00`4700d:4P0:20l02`P@00l<4P80
30X?00L02`T>00X83@0=2a003P`A00/93P0:20d03P`A008040hC00P03P`A00d;400>31402`T>00L5
2P0@3Q<0518G00d;40<03P`A00<03@/@00`:3`0<2Pl00`0<2Pl02@0<2A003``E00P63P0A3QL02PLB
00X84P0B41T03@XC00d:4@0200h;4P803``C00X01@89014?5@0:1`h04@hE00L42`0B3aH04a0I00P5
3P0F4a`01P<:0P0@3A@0300C4AH040hC01DC5P0E51H05Q@G02LU9`0n>SH07a`F01HC3`0C3`h03@T:
01D@5@804PdD01<040/B010;4@0B3A804PdA01<>4P0@2`l03PT=014<400C3Q802PD901<>4P0@2`l0
3`X>010;3`0A31003`X>010;3`0B3A404`hB00804PdA00<040/?018=4@0A31000P0@2`l01P0A3100
4PdA00h93@0C3Q805A0D01<>4P804@`@00L03@P<014<400B3A404@`@00l:3P0@2`l03`X>00803PT=
00X04@`@018=4@0D3a<04PdA00l:3P0E41@05a8F010;3`0?2Ph04@d>0P0?2`/0100B3Ph04@d=00l;
2`0B3A02010;4@0401<=5P0G4A`06A<L010:3@<040X<0P0@2Ph07P0M5a/08AXQ01D>5@0>1`h03PL?
00l83P0B30h040X<014;3@0C3@l04P`>01@>400?2P/07aTK071ZK00O6A/03`X;01D@4@070P<06aDG
00l:2`0D3Q0020<601@>4P0A2`l04@XA00`5300>1`h03`P@00h73P<03`T=00H040X>014;3`0F41@0
9AlS01lI7@0?2@d2018<400801L?500D2@l03`@:00l42P0@1@/04@H<00h32@0?10X40146300300l4
2P0>0`T03`@:00804PL=01<03`@:01873@0D2@l04@H<00`11`0D2@l03`@:00l4300@1@d04PP?020E
7@0:0@L050TA00/2200B1`l05``D00l4300:00L03P<;00H03`<=00T03@8;01<74@0<0@X0304:0104
3P0<00X0200500l4300900H00P0@1@d0100>0`/05@XB01053@0>0`/201873`0300`22Ooooooooooo
01;ooooo000Kooooo`08014?400D4Q<05aDF014?400J61T05Q@E00X82@0<2P/200h<3@0500`:2`0:
20T03Pd;00d<2P0<2`T00P0>3@/01`0<2`T03Pd;00/:200>3@/03@`:00/:200>3@/00P0>2P/0400?
2``040`=010<3@0@30d04Ph?010<3@0F4Q<05A4B018>3`0D41403PX900l;2P1;AdH08AdL01LC4P0@
30/700l;2P05014=300E4A003@T801lK6P0F4Q401@0?2`X0100A3@d04Ph?014=3P0?2``200d92P0U
01PD5@0@30d00`0002/W:01dL7407ATJ00`72@0>20X030P900h:2`0<20T03@/<00`:2`0?3@h02@T9
00h>3P0C4a<02`/;01@C500C4A804@l@00`:2`0E4a@04Q0A0040000:20T02`T:024O800;2@X030X;
030^;`0F51D03@/<00l=3P0>30d030X;00d;300200`:2`0300d;300?3@h04Q0A00X030X=0P0;2@`3
00d;30803P`=00L03@/<00`:2`0@3Pl05aDF010>3`050`@0108300<03`d>00d03P`=00d;300=2``0
3@/<00`:2`0>30d03`d>00d;300<2P/02PT700/:200<2`T03@`:00803`h<00P03Pd;00l>300<2`T0
2PT701HE4`0V9B<03`d>00d;30802`T:00@03@/<00l=3P0@3Pl03P`=0P0<2P/0100=2``03P`=00L6
100;2PP200l>300400/:20071P@030/900`;2@803@`:00<030/900/:200>30d00P0=2``08@0<2P/0
2`T:00/92P0B41408b4R04U7B00B414030X;01@B4`071PP0518E01LE60081PT03@/>010>4@0=2`h0
1`D800T72P0B41<030X=018@4`0@3Pl0928U01@B5`1:Add0?3U003Xg?P0>2a<03@XA00`:3`0<2Pd0
3@/<00h<3`0200d:4@8030T@00D030TB00d:500=2QD03@XE00d:5P0200d95`0900d95P0300/03P/F
01<@6P081@h04@hG04=0B00C41L030X?00803P`A01@02`T>00h;4P0K62403@XC00h;4`0>2a807a`S
00l<4P040PL01`D800X82`071@P02PP;00`:2`091`P03@/<010>3`0<2P/02PP900d;308030X;00X0
3P`=00l=3P0<2P/04@`@00`72`0;1PX030L;00d8300D3a<04@`@0P0=20`00`0>2@d02`H:00d83002
00T72P0<00d;3P091`X00`4400T72P0D4QD020H900/930071@P0108500h<3`0;2@X030X;0P0=2``0
4@0<2P/02`T:01@B4`0:20T01P@500d;300610D04@l@00/92P0?3@h030X;00<10P0510@05A<D00h<
3@0?3@h03@/<00802PP900L03@/<00h:2`0810D02`L801lK700G4a@0100100H03@T:01H020@500d9
2P0@30d03PX;00d92P0>2P/0510A018>3`0:1PL040`=018>3`091@H040`=00d92P0300002`L800l;
300D41404@d>00/720091@H02`L80P0>2P/01`0=2@X05A4B00h:2`070`@02PH700/720091@H00P0;
1`P02@0:1PL030P900d92P0=2@X02`L800h:2`0<20T02@D600`82@0200d92P0O00`82@0;1`P02`L8
00`82@0;1`P030P900d92P0810D02PH700/720050@803PX;01LC500;1`P040`=01HB4`0<20T00`00
01@@4@091@H00`0001@@4@0=2@X02@D600`82@0@30d03@T:00`72P0@2`l03`X>00d83002010;3`06
00h93@0=20`02PD900T4200;1PX03PT=0P0<20T200/7208030P900T03@T:00/7200810D04@d>00T5
1P0J5QL05A0D018=4@0A31000P0<1`/03@0@2`l03`X>00D0100810L030L;01LB5P0=20`05a<D00/7
200=2@X0100100X61`0810D00`0:1PL0400;1`P03PX;010<3@1TGUh03`T:01D?4`0E3QD02@@:010;
4P0300D06QLM01@C600C4A@02`/:00@4100:20/300d83P803PT?00d03`X@01XE6`0m>3h0?3Lm01HA
5`0;1P`020H900@21@091`X03P`?014?4P1:B4/01`D8008030X=00@02@L:00/9300?3A003`X>100=
20`03@0>2@d040/?00T4201`Jfl0BTE901LB5P0C3Q802@L:00l=400@3Q403@/>00/9300610L00P0>
30l07P091`X03`d@018@4`092@/04a@F01@F5@0<3PT09BPO051CB01LH580DUI802<V7@0Q91d05QPE
01dN800C51H04Q0C01TG6P0H5QT03P`?00h<4@0J5ad02PL>00D22@0B3aL04a0I00L43@0<2A403@/@
00/93P8030X?0P0;2@h200d;400>00`:3`0=2a0040hC01`J7`0J61d05Q@I01DC600;2@h0518G01XH
7@0=2a0030X?00/93P0<2Pl200d;408030X?00X03@/@00h<4@0?31<08AhW00`94P0=2Q<05A8M00H3
3P0:1a403P/D1@0>2a809`0I5Qd0FUMN020M900<2A004a0G00`:400?31D05Q<L00l<5@0?31<05Q<J
00X73P0B41D05A<H06YXJ`0R82<0928U09JDU@3`kNH0MgA[01hK5@0?2`P03`/:018=4P0@2a804@`C
018=500B3A<04@`A010;3`0300802`H:00<00P0E41@030L;01dH700D3a<04@`@00l:3P02014<4003
00l:3P0A31004`hB00804`hB00@040/?00d8300B3A404@`@0P0@2`l00`0A31004PdA010;3`03014<
400901<>4P0E41@05A0D01lJ7P0400<04PdA01/F6P0@2`l04PdA00D04@`@00@03`X>00d8300B3A40
4`hB0P0>2@d06`0>2P/03`/:014=300B3Pd04@d<00l;2P0A3@h03`X>00l:4@0C3AP05a4O01TC7`0?
2@d05@lA01@>400@2P`040X>018<400<1PX03`P?01<<4`0@2A003PL?014;400>20X030H800d72@03
00h82P0B01D?4@070@<03`T;00L10`0E3a402`D702PR90080P@040X<00`6200H4QH02`H9010:3P0?
20l040T@018;4P0B2a<03`P?0P0=1`/200h8300?00l93@0>20`040X>00d72`0@2Ph03PP<014;3`0O
5Q/05``B00l42P0=0PP03`@:01873@0>0`T03`@:00D04@H<0P0@1@/01`0?10X03P<900`11`0C20h0
40D;00h32@0=0PP00P0>0`T0300900H03`@<01D:4P0700@06a0H00L0100900H04@H>01L<500>0`/0
2@0600l430H03P8<0180300:00l53@0@10h03@4;01<74@0>0P`03`@<01873`0;00P05@XB02lT;007
00@03@8:01053@0700@02`0801X?5`0700@Dooooo`006oooool0200=2``04@l@01@B4`0=2``05Q@E
01<A4P0:20T030X;0P0>30d01@0<2P/02PP900h=2`0=30X030/900803Pd;00P030/900l>300<2`T0
3`h<00h=2`0<2`T03`h<00h:2`<03`/<0P0@30d0300?2``020@500T51P0=2@X040`=01<?400?2`X0
2PH502@P7`0H51<0:2@S018>3@L03`/:00D02@D400h:2@0J5QD0CDU805=?CP0500l;2P0300l;2`0?
2``03`/<00803`/<02D03PX;00T51P0@30d061@E00@00@0R7Ql00`0001<>3`0=1`T03`/<01HB4`0B
3Pl03@/<00l=3P0B41404A4A00l?3`0A4A403Ph>00P7200E4a@03@/<018@4@071@H00@0001PF5`0G
5AH020H700800@0100009R@U05IDE@0O7Ah020H700D310091`P04a4B00803@/<00@030X;00d;300?
3@h04Q0A300<2Pd300d;308030X;00@03P`=00d;30050`@01P@50P0A3a000`0<2P/03@/<00d;3002
00h<3@803`d>0P0=2``0200<2P/03P`=00h<3@0:20T02@P600X91`0;2PP030/90P0>3@/0200A40h0
3`h<00T81P081`D05QDC02TX9P0?3@h03@/<0P0;2@X0100=2``03`d>00X82@0<2P/300h<3@0300`:
2`0:2@L02`X8008030/900@02`X800X91`0<2`T030/90P0=30X01P0<2`T02`X800d;300=2``030X;
00/92P802PP900l040h?028P8@17ADH040h?00/92P0C4A8020H900l=400>30l020H901dK7P0S8B@0
71XM00D31P0100800P071@P01@0B41<01`D801/I70050`P0;b`d00807Q/T00d03P/E00`94P0<2Q00
3@/>00h<3`0>31003@XA00`9400<2A402`PA00X7400<2A<03@XE00@03@TG00P04@dJ00P5400;21<0
20D?00X7400X9Bh0FeQP01XG7P8040hC01@03`dB00h<4@0B3aH08b0Y00X7400@3AD03@XA01lL8`0?
3A<02@L<010>4@0E4aH03@/>00h<3`0?3@h02PP900/92P0?3@h030X;00X82@803P`=0P0?3@h02P0>
30d030X;010;3`0<1`/03PT=014<400?2Ph04`hB018=4@0>2@d200l:3P0400`72`0?2Ph020H900X8
2`803`d@00<02`T<00`:3@0@3Q400P0@3Q40100610L04Q0C00d;3P0;2@X400d;300?00/92P0@3Pl0
1PD50040000B41402PP900T7200<2P/01@<400`:2`0B41403@/<00P61`0100002@L800803P`=00P0
20H700@20`0B3Pl03@T:014=3P0U8B8071PI00P41@H03@T:00/02`L800d92P0=2@X030P900h:2`0?
2``03@T:00`82@060P<03@T:014=3P0200X61`0800/7200U8B80104100L3100;1`P02@D600P41@0:
1PL200d92P0800`82@0;1`P03@T:00X61`0<20T03@T:00`82@0:1PL200`82@0300X61`0;1`P03@T:
008030P900@03`/<00`82@091@H03@T:0`0<20T200/7200:00`82@0;1`P02PH700`82@091@H02`L8
00`82@0:1PL05Q8C01hJ6`802`L800P03PX;014=3P0A3@h02`L800<0000j=SL0HemP018>3`802PH7
00P03PX;00d92P0:1PP040/?018=4@0;1PX020<700/62P803@P<00P02PD900T4200;1PX03PT=00l;
300;1`P02@D600d92P803PX;01P04Ph?00D10P091@H05A4B00X61`0B3Pl00`0200`72`0>2@d04@`@
00d8300:1PT03PT=00/62P080`L050lC01LB5P0>2@d04`l@00X61`0>2P/040`=00L3100;1`P200T5
1P0B00/7200<20T03`/<010<3@24P7l06ADE00`72`0=20h020H<01@A600T8BP0@d9700L830061PP0
2`d;018B4P0:20/030L=0P0=20h200h93`0C00H11`060PL06aHL01/F70070`P01`8801HD5`0:20/0
5A<F018@4`0:20/0>3Hi00L5200<2Pd03@/>00X82`0;2@`03`d@00`72`0200/62P0_00d8300>2@d0
3`X>00d9300D3a<030L;010<3`0?2Ph01`8600d;3P071@P02PP;00/930081PT03`d@00d;3P0>30l0
1`D800d;3P0A3a8020P:00d>3`0C5A009BPQ02<V6@1_Lf@0b/jm0:JZV@1DF4X0?3ld02d`:P0S9B@0
3a4@01/I6P091`P00P4200h<3`0;2@h02`T?01HC6P050P/01@<;01TF7`0B3aX04PlG00d;400<2Pl0
0P0=2a004P0;2@h030X?010>4`0?3A803@/@00`:3`0?3A806aTN01DC600>31404a4F00X83@0<2Pl0
4Q0E00d;400;2@h02PP=00/93P803@/@0P0<2Pl01P0=2a003P`A00l<4`0100L0924Z00T73`803P/F
00<040dG00h;500>2a80100>2a80<P0=2Q40CdaC01PE70081@`04PlF00h;4P0?31D07AXS01@A6P0F
4aX0514H00`9400I5a`02`T>01DC5P0F51L01P@70::QX@3oo_L0Ogac01XG4@0>2PL04@d<014<4@0@
2a804@`C018=500B3A<04@`B010;4@0A3100=S4e00d8300J5AT02@@801/F6P0D3a<04@`@010;3`0A
31004PdA010;3`0A31004PdA01<>4P0B3A4040/?00h93@0B3A404@`@0P0@2`l0100A31004PdA01<>
4P0B3A4201<>4P08018=4@0@2`l06QDI00D1100B3A404`hB00<00P0A3102018=4@804@`@0`0@2`l0
7P0>2@d04PdA018=4@0>2@d03`X>00d92P0@30/04Ph=018>2`0A3@X040`9014=3@0A31004PdD01<=
600B31X04P`H00l93@0E3a4050h@010:300@2Ph04P`@014;3`0B2a805a0G01<<4`0@2A404``B00l9
2`803@L900<03PP:00d72@0=1`T00P0=1`T04P0M5aT03@L900d72@0910D0618D0;J`/P0K5AL0AT12
01H@500P6Qh03@L;00d63@0A2Q404P/B014:4P0>1`h03@L;00h830<03`T=00h03PP<01@>4P0?2@d0
3@L;014;3`0<1PX04`/@01H;4@0A1P`040D;0146300@1@/03P<900l42P@04@H<00L04`P>0146300?
10X0304700d2200@1@/03`@:008040D;00X03P<900`11`0?10X05@XB00T01P0=0PX02`0806AIH@0C
21003P<;0P0@1@d00`0=0PX0304900l4300600h2300B01043P0:00P03P8<0186400?0`d040@>0146
3P0=10X04PL?01X?5`1ICUH04@H>00L0100=0`X06@hF01`A6@0B1`l01`045?ooool001_ooooo00D0
3`d>01<A4P0B41402@L800l=3P0700`:2`0300h=2`0=30T030/800803Pd:00L030/800l>2`0<2`P0
3`h;00h=2P0<2`P03`h<00H03`/<00`05A4B014=3P0@30d03`/<010<3@0?2``040`;00l;2P0A3@`0
4Ph=014=300<20L600l;2P0>010<2`0=2@P04Ph=010<2`0Z9RD09B4P010<2`0?2`X03PX900l;2P0@
30/03PX:00d92P0>2P/2010<3@803`/<02<040`=01@@4@0;1`P0510A00P41@0E414040X<00X61`0=
2@X03PX;00d;300?3@h030X;00/;2`0>3Ph06ATI01PH600?3Ph0G5YK05ABD`0A3a004a4B00T8200=
2``03`d>00P61`0<2P/05A<D010>3`0C4A803P`=018@4@0D4Q<03P`=00P61`0300`:2`803@/<00<0
3P`=00`:3@0<2Pd0100<2Pd200d;3P803P`?0P0?3A000`0<2P/03@/<00d;300200/92P0700h<3@1^
K6d0AdE6014?400:20T040h?00h<3@0200/92P8030X;0P0=2``01`0?3@h03P`=00`:2`0?3@h04Q0A
00T7200:2@L00P0;2PL400`;200500d<2@0<2`P02PT600/:1`0>3@/01P0=2``0200;2@X03@/<00l=
3P0>30d03@/<00`:2`0>3@/03@`90P0;2PL0100=30T03Pd:00`;200<2`P200d<2@0300`;200;2PP0
3@/<00803@/<00L030X;00/92P0;2@X040h?00H41@0D4Q<02`T:00802PP901T03@/>00`:3@081PT0
40hA01dK7P0P7R403P`?00`:3@0G5AP07Q`O00/9300=2`h040hB00X83@0J5ah02@L@00`85@0@31T0
3@XF00`9500<2A403@/@00h<4@0?3A<03``C00803P/C00@030TB00/84P0=2Q@03P/F100>2QP0100=
2QH05A8M014>6@0<2A<200h;500H01HC6`0>2a802PP=00d;400;2@h030X?010=500O72D030TB00h;
4`0@3A@04a0G00d;4@091``04@lB01LE600;2@`03@/>00h<3@0;2@X03P`=010>3`0<2P/03@/<0`0?
3@h07@0>30d03@/<00d;300A31003PT=014<400D3a<04@`@018=4@0A31003PT=00l:3P0@2`l03@P<
010;3`0A3a803`d@00/930091`X02PP;00`:3@0>30l02PP;00`:3@0>30l02PP;00X92`0<2P/03@/<
00803P`=01/03@/<00`:2`081PL0=C<d01PF5`0@3Pl02PP9014?400=2``02`T:00d;30081PL03@/<
02@R8`0b<3407A/L00X82@081PL03@/<010>3`0810D040`=00`82@0>2P/02`L801<?400<20T00`0=
2@X200h:2`0K00l;300=2@X02`L800X61`0;1`P02PH700l;300A3@h03PX;00/7200D414071PI00l;
300H51D0@cm001LC500:1PL03PX;00d92P0<20T03@T:00l;300=2@X02`L800h:2`0;1`P02PH70080
2`L800@02PH700l;300@30d03`/<0P0=2@X01`0>2P/030P900`82@0?2``02`L800X61`0?2``01@0>
2P/0100?2``030P900/7200?2``200d92P0E014=3P0<20T02PH700l;300=2@X02`L8010<3@0?2``0
1`@400`82@0:1PL02@D601HB4`0A3@h030P900X61`0;1`P030P900X6200?2Ph04PdA00802`H:0P0>
2@d01P0=20`030L;00/62P0<1`/03@P<00l;30802PH701/03`/<00d92P0=2@X02@D6010<3@0A3@h0
1`<400T51P0:1PL0:RDY03lj?P0<20/02PD900D1100=20`04PdA00<00P0D3a<01P8500T4200?2Ph0
0`0001TE5P091@H04`l@00H20`0<20T00P0;1`P400d92P803P/;00/02@P800X9300=2a001`L<040o
A@1BDeP03Q0B00d@3`082`P02@X900T72P0200`73@<03@P>00P03`X@00/6300=20h03@P>00`73@0?
2Q0040hA00X82`802`T<00<03@/>00X82`0:20/0100<2Pd01@0:20/03PT=00`72`0<1`/02`H:0080
30L;00d040/?00X52@0?2`h04@`@08=nPP1@Bdl02`T<010>4@091`X03@/>00L5200>30l03`d@0080
2`T<02T03`d@014?4P0@41404aHC01dQ6@0[<2<0GF=B0<G;]@3mond0m_[V0:neXP1TJET0:RhU018F
4@0J71X040l?01@B4`0C4A<02`X<014?500>31802`P?00d:4`0a;SL0;2Tb010>600:1`l03P`A00l=
4P0>314030X?00/93P0>31403@/@00`:3`0=2a003P`A00d;400@3Q<030X?00T7300200`:3`0800/9
3P0=2a0030X?00/93P0:20d02`T>00`:3`0=2a0400`:3`0800`9400A3aL0I65Z03<`>@0=2QD04a0K
01<@6P0?31D200l<4`803P/B01T03@XA00/93`0E4QT02PL>00l<4`040PP040dD014>5`0C41T040dF
018?5P0<2A00514H010>4`081P/05Q@G00/:300K6A`0<S0a05YGC`0/:Qh03``500l<1`0?2`X04`lA
00804PdC00L040/B010;4@0B3A<04PdC018>4@12?D4030P;00804`hB00@03`X>01D@500B3A4040/?
0P0B3A400`0@2`l04PdA018=4@02010;3`04018=4@0C3Q804PdA014<408040/?00<04@`@018=4@0D
3a<00P0A31002P0B3A4040/?00`72`0B3A40AD14010;3`0>2@d05Q4E00h93@0?2Ph3014<400E010;
3`0?2Ph04PdA014<400D3a<04`hB010;3`0D3a<040`=018>3@0A3@`03`/8010<200B3P/04@d=014<
400A31<040XF00h75`0>21D040X>00<040X<0`0@2Ph01P0?20l040T@014:4@0@2A404`dB01<=3`<0
4@/=010040X<00h82P0@2P`04@/=00d82@0A2`d040X<018<3P0<1`P05Q0B00l92`0X8b@04@/?01PB
5P0A2`l030D<0P0?20l05@0>1`l03`P?010:3P0A2`l04`dA018<400A2`l03PP<01@>4P0@2Ph03@L;
018<400<1PX040L<01<83P0A1P`04PL=0146300?10X03P<900l42P040146300700l42P0@1@/040D;
00l42P0@1@/05P/A00`11`0201`A5`0?01052`0>0`T04@L<00h52`0=0PX04`P@00T01P1<@DT050XA
01463P0>0`/03@8:00l4300@1@d03P<;00H03@4;00L04@D?01hD700800H04PH@00d12`0?0`d04PL?
0080308900T04`P@03`a>@0900H05P/C01473P0i;SH0>2de00l5300D2A405?ooool001_ooooo00P0
20H700h<3@0?3@h01@<400d;300<2P/03P`=00`:2`802PP900h030X;00h<3@0>3@/03@`900`;1`0>
3@/03Pd:00`;1`0@3`d03@`9010?2`0?3P/03@`:010?3@H03`/<00d05Q8C01<?400>2P/03@T:018>
3`0D4140>cXh018A3`0300004Ph=00d9200E4A0040/:00803`/:02X03P`:00d<2P0=30X03`/:00d9
200A3@`02PH501LC4P0:1PD04@d<00h:2@0=2@P03PX9010<2`0?2`/03PX;00l;300@30d03PX;00d9
2P0C3a0030P900h:2`0B3Pl01`<401LC500<1`T03@L;00l:3P0H51D04Ph?00X61`0<2@X02@L800D3
100<2P/03`h<00X91`0:2@P04@l@018@4@0@3Pl200X82@0;00h<3@040P<030X;010>3`040P<03P`=
01DC500>30d030X;00X82@081PL00P0>30d01@0?3@h04@l@014?400@3Pl03P`=00H030X=0P0>30l2
00l=4003010>4@0A3a802`/=008030`>0P0820X01`0=3@h02@T900l=3P0F51D03P`=00H41@0=2``0
0P0@3Pl0100?3@h03P`=00d;300<2P/200l=3P0B00`:2`0@3Pl0518C00T7200>3@/03Pd:00d<200=
30X03@`900`;1`0@3`d03Pd:00d<200?3P`03`h;00`;2@0;2@X03@/<0P0?3@h01@0=2``02`T:01PF
5`0E4a@04@l@008040hA00<04@l@00h=2`0=30X00`0=30X00`0>3@/030/900`;2@0200d<2P0300`;
2@0;2PP03P`=00D03P`=01h03`d>014?40081PL03@/<00l=3P0C4A804@lB00d;3P091`X03`d@00T7
2P081PT03P`?00400P091`X04a4D00T72P0A3a803`dB014>5@081@`04a0I00T64@081A0030TD00`9
4P0<2A403@XA00l=4P0A3aD2018?6003014>5`0?31D03P/F00803P/F100>2QP07`0A3A`04`lN0080
3@0>2QP01P<>01LD7`091Q402`PA010=5P0F4aX03``C00`9400;20l0514H00d:4`091`d04@hE00H3
2P0<2A001P<:00d;400A3a@01@<800`93`091``02`T<018@4`0C4A@03@/>00h<3`0;2@`00P0<2P/2
00/92P0K00h<3@0=2`h02@L:00X72P0<1`/02@@800`72`0?2Ph02`H:00`83@0<2Pl02@L<00/:3`09
1`X02PP;00`:3@0@3Q404@lB00/9300:20/02@L:00@21@0?3A002`T<00d;3P0>2P/03`/<008040`=
00L03P/<00`:2`0E4a@04a4B0040000?3@h01P@5008040h?01402PP9018@4@0C4A802@L800h<3@0@
3Pl020H700X82@0B41404@l@00H41@0810D03`/<00h:2`0E4A8030P900T51P0200`82@803@T:0P0>
2P/00`0;1`P030P900h:2`02014=3P0>00l;300L61T01@4200T51P0>2P/02`L800`82@0?2``02`L8
014=3P0@30d00`0001<?400<20T200T51P0900`82@0?2``03`/<010<3@0A3@h040`=00/7200>2P/0
510A00803PX;00@03@T:00X61`0:1PL02`L80P0<20T0100>2P/02PH700/7200>2P/600`82@0=00P4
1@080`L03@T;00`82@0:1@T02PD800l;300A31002@@701LC500_:Rh09b<T00L3100200`82@0600<0
000;1`P02`L800T4200;1PX030L;0P0:1@T0200<1`/03PT=00d8300;1PX03`X>00d8300:1@T030L;
0P0=20`200`72`0:00d92P0810D02`L800l;300:1PL02`L801@@4@0300002PH700h:2`802PH70180
40/?03`g>`060PD05A0D00T420091@P030L;01LB5P060@D061<G00T420070`H03PX;04Y6A`0E4A80
4Ph?00/7200810D300d92P0A00`82@0;1`P02@D600800@0<2``00@4300P82P040`P04a@I00X;400>
3a@0004200/<3P041PH00`D400T72P0;1PX00P0<1`/200d8300=00d83P0D3aD03`X@00h93`0@2a40
20<9044o@P0@3Q403`d@010>4@0:20/02`T<00d;3P0200/9300?00h<3`0<2Pd01@<601PC5`0D3a<0
4PdA00l:3P0=20`030L;00T4200I51P01P45010<3`0E41@02PD900<03@/>02d02PP;00/9300a;c80
5aDH00h<3`0B41<03`d@00`:3@0A4A403Q8=01lU6`0e>bd0LGQT0<C<]03^mm`0m?[S08ZBO@0a>2H0
92XN00`A2`0@4Pl02@P802DS9P0O7B004Q0C01dK800710X03@XA014>5@0G51`03P/D00P53P0;2100
3@/@018?5P0?31802PP=00`9400<2Q001P@900D22@0<2@l040hC00`940091``00P0?3A8010081P/0
2PP=00d;400<2Pl500/93P<030X?00T02`T>00X83@091Pd03@XA01HC6P0?31D040dF00P53P0E4Q/0
0`0?31<01@0>2a803@XA00d:4@0?31<00@05008030T@01H02PL>010=500B3aH01P<:010=5@0F4aX0
2@H=00h;4P091``02`T>018@4`0N71l04a4D00d<3@0>2`H0514800h;1@0@30T03`/:010<3P0D3aD0
4@`B0P0>2@l02`0A318050lE01D@500;1`X03@P<01PC5`0=20`04PdA01D@500B3A404@`@00804PdA
00T04@`@01<>4P0@2`l03@P<00h93@0C3Q805Q4E018=4@0A31000P0@2`l02P0A31004PdA01HA5@0@
2`l03PT=010;3`0B3A4040/?00l:3P0I51P201D@500400D0100E41@04PdA01<>4P805A0D024050lC
01<>4P0@2`l03`X>018=4@0?2Ph03PT=018=4@0B3Pl04`l>010<2`0=2@L03`/8018>2`0@30`03@P<
00/6300<1Q403`TG014;5@0A2`l02`D700`6200@2P`040X>00h8300B31004@/?00/52@0@2A004``C
014;400B30h00P0@2P`08P0?2``03PX;010<3@0=2@X03`/<00/51`0@2P`03PP:01072P0O5QL04`X;
01092`0K5AL05Q0B020K7`0M61`040/A00l83`0>1`h03`P@0109400=1`/04@P=018:3`0@2Ph04@P=
00`52@0>20`03PD:00l8300:10P03PD:01T?5@0A1P`200h32@0401052`0A1P`03P<900l42P@04@H<
01003`@:01<83P0E2Q004PL=01052`0B1`d03P<902XO9@0X7B<04PL=01052`0A20`04PL?01D:4P0?
10`05P/C0P0@1@d01P0=0PX03P<;01873`0C21004PL?00h32`803@8:01H03@8;00d12`0=0P/03@8:
01864013>4401`0400h2300B1a0040D=00X01`0B1`l01`0401P=5@0900H05P/C00T01P0=0PX02P07
00d22P0B1`l02P075?ooool001_ooooo00P01`D600`:2`0B41403`d>00L51P081PL061HG00l=3P80
3@/<00d03P`=01@B4`0>2P/040`<014=300A3@h03`/;00`81`0B3Pl04@d=00l;2P0?2`/03`/<0080
40`=01P03`/<00h:2`0?2``03`/<010<3@0B3Pl03`/<00h:2`0B3Pl00`0001XH6@0H6AH01PL200d<
200C3``03PT6014<2@0B2`T03@T6014=2P0B4Ph03a4<00d=2`0@3Pd201DA4P0?014=3P0>2P/03PX;
00h:2`0C3a00Cd]<01lK70030000510A00H20`0C3a004@d>00l;300>2P/04@d>00D03`/<00X04P`A
00h73P0B2a806A<G00l93@0I4aL030L900h:2@0=2@P03`/:0P0=2@H0500A3P`03P`=00X82@0B4140
2`T:00T7200B41402`T:00l=3P0;2@X03@/<010>3`0<2P/040h?00/92P0B41402`T:010>3`0A3a00
3P`=0P0;2@X07`0=2``03`d>00`:2`0;2@X030X;00d;300@3Pl04a4B00P61`0?3@h040h?00`:2`0>
30d02PT;00hB5@0?51P01@T<01@H6`0:3Q4010D800X;3@0;2`d03@d=00d<2P0;2PP03Pd;00X82@07
1@H02`T:00l=3P0=2``00`0>30d0400K6AX0518C00h<3@0610D03@/<00X9200=30X040h?00h=300=
30X03@/<00/:2@0=30X03`d>00d<2`0610D400`:2`0J00`:300<2Pd01P@703hl?`1]Jfh07A/P00l=
4P091``02`T<00d;300;2@X03P`=018@4@0>30d03`d>00X82@0>30d04@l@00/92P081PL030X;00d;
300<2P/02@L801@B4`0Q7b0200`:2`0<00d;300>30d02`T:00P61`0D3a<04@`@010;3`0A310040/?
00l:3P0A31003`X>0P0<1`/09`0@2`l050lC00l=4P0<2Pl02`T>00X73P0?31<03@XA018?5P0;20l0
2`T?00d;400<2Pl040dE00h;5P0J5b805a@O00l<5`0E4Qd030TD00/84`0D4A`02PLB014>6@0;21<0
4PlO0080500E4RL02`PK01HC900f<d@0518P00h<6@0G5B805aDQ00d;5P091a802`T@00d;400300d:
4@<03@XC0P0=2QD01`0>2aH040dI01DB6`050P/03@XA00`9400?31<00P0=2a0200d;3P0C00d;300<
2P/02PT900/;3@0D5AL020L901/G600?2``03PP:01D@500I51P00P4601@D700;3QL03a<K01DD6@05
0`H030X=00d;3P0200P62@08014?4P0?3A003@/>00l=400>30l02`L;00l93@0<1PX200h8300:00P3
1P0:1@T030L;010<400100803@/>00h<3`0C4A@02`H:00`72`803@P<00H03PT=00l:3P080`L040/?
00h93@0400<300d8300G00`72`0;1PX030L;00h93@0@2`l03`X>00T4200B3A4050lC00`72`0D3a<0
3PT=014<400>2@d02`H:00d8300A3100DTeA00H11@0@2`l03@P<01<>4P070PH00P0>2@d200l:3P0b
00h93@0=20`01`<6014<400D3a<01P8501PC5`0;1PX03`/<08j:R`0O6a`02`L801<?400>2P/02@D6
00<0000W8b@01P8301DA4P0@30d03PX;00d92P0@30d0510A014=3P0?2``04@d>00l;300<20T02@D6
00/7200>2P`01`8601`G7@091@T05Q4E00h93`0;1P/030L;01@?5@0@31002`H:059=D`12?Sl030P7
00/71P0=2@T03PX;00/62P0:1@T400/6300500/63@0;1P`02PD900X52@0;1PX00P0<1`/01`0=20`0
30L;00`72`0;1PX030L;00d8300910P00P0B3A40400:1@T030L;00h93@0:1@T02@@800X52@0;1PX0
3PT=014<400>2P/00`0000h:2`0;1`P02@D600`82@0@30d200X61`0301DA4P0D414020@500<030P9
00<02`L800X61`0:1PL00P091@H02@0;1`P030P900l;300@30d03`dB020O900000@05QDJ018A5`02
00L6300C01HE6`0h>Cd0000400l?50061PP030X;00l;2`0A3@h020@500d92P0;1`P02`H:00d8300B
3A403`X>00L21`0<1`d03PT=00/7200200h:2`0400X61`0<20T030P900`82@803@T:00`03PX;00h9
3@0=20h03PT?00H11`0=20h04PdA014<400?2Ph030P900<0000A3@h200P41@0I00X82@0<2P/030X;
00`:2`0:20T020H7028P8@0:20T01`D6018@4@081PL06a/K018F4@0K81T0>d4e03Dl:P1[Le`0XJVA
0;W1Z@1DG4L09RdM01@J3`0?50h03a4>00`;3P0201<A5P803@/@01l05aDJ06YXK@1=Be003P`B00`9
40060`X02PH=00d83`0=1a403@P@00d83`0;21402`P@00d:4@0:2A402`XA00`;4@0>3AD02`X?00D3
200<2Pl03@/@0040100c<CH0AD=800/93P091``03`dB00P62`091``040hC00803@/@00L030X?00d;
400>31407Q`Q01HD6@0;20l030T@00803``C00L030T@00d:4@0@3A@040dD00l<4`0=2Q4040dD00<0
3``C00D040dD018?5P0A3QD04@lD014>5002010>4`0D00l=4P081P/03@/@01<A5P0A3a@03`dB010>
4P0B41405QDC01@C4P0>30d040h?018@4`0>30l02`T<00l=40091`X03@/>00T72P0?3A02014?4P0Y
00l=400<2Pd020H900`:3@081PT04@lB00H41`0n?3l04a4D01<A5P0A3a@030X?01<A5P1HEU/0BDM<
014?500@3Q<04@lD01<A5P0E4aP04a4F01D@5P0>2@l02`H<00h93`0B3A<04@`B010;4@0B3A<040/A
00h93`0B3A<05Q4G010;3`0I51P030L;014<400P6al03@P<01D@50070PH00P0?2Ph0;00=20`030L;
014=3P0A3@h04`l@010<300?2`X0510?01@@4@0G4a@04`hB00d83@0H4aT04`hB014;3P0>20X030H8
00d72@0@2P`04@/=00h92P0@2P`06A<E00P31P0K5AT0204501483@0>20`040X>00X82`081PT03P`?
00X82`0100803@P<00T31`0C2Pl07a8F01L92@0?0`<04PP9014;2`0@30/030X<0P0@3Q40900;1P/0
3PL>014:4P0B210040L<01052`0B20d04PT>0146300A1``05PdB01T>500@1P`03@@901L<4P0H3A<0
3`@:01873@0C20h04@H<00l42P0>0`T04PL=01@93`0=0PP02`0601052`0900<03@0701@73P0E20l0
4@@;00X0100B1@`04@@;0185308050L>00L04@@;01D83`0>0@P03@0701/>5@2hZk8091LN00<040<:
00<03`8900h1200>0@P00P0>0@P02P0?0PX03`8;01032`0@0`X0200401853@0A10/03`8;00h12@09
00<800l22@8040<:00<04@@;01853?ooool04oooool001_ooooo00<04Q0A00/92P0<2P/00P0@3Pl0
0`0A3a0030X;00X82@0300d;300301<A4P0@30d03`/<00@03PX;00@04`l@018>3`0@30d040`=0P0A
3@h0100?2``03PX;00h:2`0?2``2014=3P0T00d92P0F4Q<030P901<?400k=cP020H700h@30041@80
2PX7010<2P0@20L05@d<01H?3P0<1`D03@`900h>2`0B51007QlM01DB4`0D41404@d>00h:2`0A3@h0
510A014=3P0>2P/06aLH00`82@0=2@X03``<01XF5`091@H040`=01hJ6`0j=SL0510A1@0?2``0400C
3A<020@901H@5`0B3A803`X>00/6200>2@/03@P800h92@0D3`d040`900l:1`0>2`T04Q0A00d;300:
20T200h<3@0:01DC50091`P030X;00l=3P0<2P/040h?00d;300T8R<07Q`M014?40802`T:00@03P`=
00`:2`0;2@X030X;0P0=2``300`:2`0Y00d;300>30d040h?010>3`0:20T01`D601LE5P0Q7b0051<E
00P<3`0?5Q/092T/00/@50062`h02`lB00T:300`<C<09bLW0040000?3P`04A0=010>3`0<2P/03@/<
00h<3@0<2P/03`d>014?400<2P/02PT900L51P0A3a0030X;00T7200>30d040h?00d;30091`P02PP9
00h<3@0=2``00P0:20T600`:2`0D00`:300<2Pd0518E014?4`0R82D02`T>01LE6`0=2a002`T>00d;
3P0;2@`03P`?018@4`0=2`h03`d@00h<3`091`X02PP;00/930081PT200`:2`0400l=3P0>30d03`d>
01@B4`802`T:00P03@/<010>3`0?3@h03@/<00d8300<1`/03PT=018=4@8050lC0P0@2`l04`0>2@d0
3@P<010;3`0B3A403@/@00l=4P0<2Pl04a4F00d;400D4QL02`T>00`:3`0?3A8040hC00d;400;2100
3``G010=600?31L00`0;21<04`0K62<0;BXe018?6P0D4A`03@XE00l<7@040QL03`/Q00l<800>2al0
6QLZ00h;7@0D4B806QPW01TG9@0A3a`03P`J00h;5@0=2a000P0=2a409@0=2Q403@XC00`94`0<2A@0
3@TG00h:6@0>2QP03@TH00d95`0@3AP02`PA00L43@0?31D02`P?00`:3`0=2a003@/>00d;300<2P/0
2PT:00T;3P0520X01`T;01<A500<2@/03`X<010;3`0?2Ph030/@00T;4`000@/0LGIn02XY;P0A3a80
2@L:00X82`0;2@`00P0>30l200`:3@803P`?00d02`P;00T41`0A20d04PT>00P31P0T7R803PP<01TD
60081@P03`d@024O8P0d<SD02@L:00H03@P<00H02`H:014<400<1`/020<700d8300?2Ph600d83008
020K7`0G4QH061<G00L31P0T7b<02`H:00h93@0=20`200/62P8030L;00D03PX=00`82`0K5QX030L;
01@?4`0200l:3P0300d8300<1`/02`H:00802`H:00/03@P<00/62P0>2@d03`X>00H21@0@2`l030P9
024M7P081@D03PX;00l;300200X61`0J01DA4P0Z9RL05Q8C00T51P0:1PL06ADF00L4100<20T08AdN
01PD5@0=2@X03`/<00h:2`0?2``040`=00h:2`0:1PP05A0E03D`=@0B3A80100400L21`0>2Ph04`hC
00<00`0=2@d201@?500800h:2`0<20H02`L600`8200=2@X02`H:00X52P0<1`d300`73P0400`73`0<
1`d02`H:00/62P<030L;00/03@P<00`72`0<1`/02`H:00`72`0=20`020<700h93@0?2Ph02@@800X5
2@0500/62P0>00d8300?2Ph04@d>00D10P0<20T02`L800h:2`0E4A80JfMX01XG5`0?2``0104100X6
1`0B3Pl300`82@802`L802002PH700`82@0=2@X03PX;00d92P0<20T01`D800L52P0Q82D030/@00T8
3P0410T03`hC00`<4@0i>3h0UIBI01<C60081`d030`?014=300=2@L03`/:00h:2@0A3@d03PX;00d9
2P0>2P`04PdA010;3`0<1``040/?018=4@8030P900@02`L800X61`0?2``030P90`0=2@X0<`0>2P/0
3PT=014<4`0810T03PT?00d93P0C3Q80<B``00l;3P0C3a004Ph?00h:2`0:1PL03@T:00/92P0?3@h0
2PP900l=3P0C4A803P`=02@R8`0H5QL030X;00l=3P0C4A803Ph>00lA3P0F6A<06alE02H[700U;1H0
>D0Y04Y@>`0[<B007b@E01@H3`0>4@h03a4@00`;3`0<2Pl03@/@00l=4P0A3a@030X?02DS:00C4AH0
2PP=00`:3`0>31403`XB00h64@0300d74@0D00/84@0A3QL00`4900l>5P0E51`0Ti:J01`K8`0=2a80
2@L<00`:3`0A3a@02PP=020N8`0X9R/03@/@01<A5P0M6b004Q0E00/93P0>314200d;400900`:3`0=
2a003P`A01@B5`0?3A802PP=00d;400A3a@040hC00<030T@0P0=2Q40100>2a803``C00l<4`0?31<2
010=5003014>5@0?3A803`dB00803P`A0P0=2a001`0O7B804@lD010>4`0B41D03P`A02HT:@0A3a80
0P0F51L01@0A3a804Q0C018@4`0B41<02`T<00804@lB00P06ALJ01<A500@3Q403`d@010>4@0C4A@0
6QPK01lM80804@lB0100518E00l=400Z:2/04@lB00X83@0I5a`040hC00d;400Q7b@071XO014?500D
4QL05A<H018@5@0@3Q<03`dB0P0B3A<01P0D3aD05A0F018=4`0;1P`04@`B018=4`8040/A00D04`hD
01HA5`0@2`l05a8F018=4@02014<400401@?4`0>2@d04PdA01D@50804PdA03<061<G00l;300@30d0
4`l@010<3@0?2``0510A01<?400?2``020@502@P8@0c;c004Ph?018<3P0@2P`03PP:00l92`0A2`d0
4P`>01@>400;1@L02`H701LA4`0910D050`@01@;400=1`/04PdA014?4P0>3Q004a<E00/;3@0H5QT0
2`L:01LA5@0D2a006`lA020@4@0H2PX05P/<010:2P0<20P03Pd=01@D5@0D4QD030T=00`73@0?1@d0
3P@;01052`0B1`d00P0C20h201873@0701<83P0F2a404`P>00h32@0@1@/04@H<00l42P0301052`04
00l42P0=0PP03`@:01052`803`@:00<040D;0185300D1`h00P0H2a800`0F2A004@@;018530020144
2`804PD<00L03P8800d01`0A10/05`XA00h3200S6Ad03P8800<040<:0P0?0PT300h120803`890P0@
0`X01P0E20l0304601462`0E2`l04`H=00h220H03`8900<03P4800l22@0?0PT00`0@0`XDooooo`00
6oooool03P0>30d030X;018@4@0B41402`T:00T7200B41402PP900`:2`0?3@h03@/<00`:2`0@30d0
3`/<0P0<20T01P0=2@X03PX;01<?400C3a004@d>010<3@804@d>0`0>2P/09`0@30d04@d>018>3`0E
4A8061@E01@@4@0B3Pl0R8B502h/;@0<3@/02`/900l?3@0A3@`04`d=01/B4`0T7Ad03PX900l>3009
2@L020X701LG5@0A3Pl03`/<00`82@0:1PL03@T:010<3@0<20T0510A00H20`0=2@X06ADF01@@4@0a
;Bh05a<D00X61`0<20T081`M00T61P0500l;300Q00`72`0S7R@0E4mE01XE6P0?2Ph00`0001PD5@0?
2``03@T800h:200<20D03`/8014>3@0:20T030X;01DC50030@807Q`M04]9BP0H5QL00P0100l=3P0D
4Q<04@l@00/92P1eLg@0FeUJ00<10P0C4A806QPI00/92P0:20T02`T:00803@/<00D02PP900`:2`0<
2P/030X;00/92P0200`:2`0C00/92P0>30d03@/<00H41@071@H03@`>00lC5P1bMg/0]kc001`Q900>
4aH03a<F00D6200=3Q003Ph>00/:200?3P`04A0>010>3`0200`:2`802`T:01<04@l@01lM7P0<2P/0
4@l@00d;300>30d040h?00/92P0C4A80518C01<A4P0A3a0030X;00d;300@3Pl03P`=00X82@0;2@X0
40h?00@030X;01D030X<00`:3@0200<02@L;01<A5P0B41D03``B00L52P0<2Pl03@/>00/9300=2`h0
4@lB00`:3@0;2@`03`d@00P62@0=2`h04Q0C00X82`0>30d00P0;2@X02P0:20T03P`=01DC500=2``0
30X;00d;300A3a0040h?00l=3P0?2Ph200d8300400l:3P0>2@d03@P<00l:3P8040/?01003PT=00l:
3P0@2`l030X?00P62`040PL040hC00l=4P081P/03`dB018@5@0D4QL04a4F00l=4P0=2Q805a@O0P0>
2aH01@0?31L020D@01HC7P0100T00P0:00803@XE00L02PLB01TF900:1aP02`PI01TF9`0E4R<040dP
00803``M00H040dN00d;6P091aD02@LE00`9500=2a0300d:4@0R00d:4`0=2Q@03``G014=6`0C3ad0
4PhL00l;6@0A3QT0:BHa01@A6P091Pl0514J00l<4`0;2@h030X?00d;3P0=2``030X;00/:2`072Pl0
8bP/01TL800B4AH01@<600T6200@2`l030L;00D31`0B4AL02PXB00l?5`0E51T020H900`:3@803`d@
00@03@/>00X82`0:20/02`T<0P0<2Pd03`0<20`050hB00l62`0=10T04`dA03D_<`0600@00`0204=0
@`0a;c804@lB00@21@0D4QD03`X>00h93@0200d8300500`72`0;1PX03PT=010;3`0:1@T00P0>2@d0
4P0@2`l03@P<00l:3P0?2Ph03PT=00`72`0:1@T07APL00d8300>2@d01`8603<^<P080`L04PdA00h9
3@0<1`/040/?00h93@802`H:00H040/?01@?4`0?2Ph040/?00<00P0;1PX200T4200H00d8300A3100
4`hB00`72`0D3a<040/?00h93@0:1@T04`hB00`82@0>2P/06ADF00@10@060P<03`/<00h:2`0;1`P0
0`0000X61`0810D07ATJ010<3@0G4a@03`/<0P0300004`0>2P/02`L800X61`0@30d04`l@00l;300=
2@/00`0200D010091@P04PdA01@?4`070PH00`0200h93@0_:Rh00`0200@00`0:1PP00P0;1`H0100<
20P02`L800X52@0;1P/200d83P<03@P?00<030L=00`72`0<1`/00`0<1`/02@0=20`030L;00`72`0;
1PX030L;00d830080`L02`H:00d8300200T4200300X52@0=20`030L;00@030L;00`00`0000D10P0C
3a001@4200P41@0N6Q/0R8B5020L7@0=2@X0100100h:2`0<20T600/720803`/<01803@T:00/7200:
1PL01`D601DC60040`P00P4600H52P0;2Pl030/@01DD6@0A41D0000401PG700920d0000200<0000<
20H2010<2`0400D20@060P<03@T:00h930803`X>00P03`X?014<400A310030P900d92P0<20T02`L8
00l;30D03@T:01803@P<00`83P0Q72806QDK00/6300>2@d0:B@X08F0Q00?2``04@d>010<3@0A3@h0
6QHG014?400C4A801`D600d;300C4A8200T7200B02HT9@0K6AX03@/<00D3100>3Ph0414@0001000<
3`P0Gf9F038f9@0S9aH0>3`[02P/7P0K7Q<02P`600/=300D5AL04@lD0P0:20d02P0>31403@/@014?
500A3a@020H;018@5@0;2@h04@lD00/63@0>1Q4300d74@0>00/84@0610`01`@=01HE7@0<2a<071/S
00L63P0?3Q<03`dB00`:3`0;2@h02@L<00X83@0?3A8200d;4004014?500=2a0030X?00l=4P803@/@
00@030X?00d;400>31403@/@0P0<2Pl02@0@3Q<04Q0E010>4`0=2Q4030T@00/83`0<2A003@XA010=
500200h;4P@040dD0`0A3a@2010>4`0900l=4P0I5a`04@lD018@5@0@3Q<02@L<01HD6@091`X03P`?
00803`d@01/04Q0C014?4P0@3Q403@/>01<A500@3Q40518E00h<3`0C4A@040hA00d;3P0?3A005Q@G
01`J7@0;2@`040hA00h<3`0@3Q403@/>00`:3@0>31405Q@I010>4`081P/03@/@01TG700A3a@00P0J
61d02@0D4QL03`dB010>4`0C3Q@040/A00l:400A31805Q4G01TD6P04014<4P0C01<>500D3aD050lC
00L21P080`L04PdA07ehO01ED5@061<G00X52@0?2Ph08ahR018=4@0400<03@T:00l;300C3a0040`=
00l;300201<?400900l;300C3a002`L800d92P0;1`P04P`>014;3@0@2P`04@/=00804P`>02<05@lA
01hH6P0G4A<030H801/E5`0?1`/05@`A014;3`0>2@d05A<F05]IG02IVI/06ATK00`:3@0=1`/06Q@H
00X11P0F2@`03`4100/0000?1@D03PP800h:2`0>30d03@d=00h<3`0>2Pl03`P?0188400@1Pd04@H<
01<83P0B1`d03`@:01052`0201873@0401<83P0E2Q004`P>01052`803`@:0`0>0`T0200@1@/03P<9
0146300D2@l03`@:00d2200?10X03`890P0@0`X200l22@0=00h1200C1Pd04@@;01442`0B1@`04@@;
00h1200?0PT04PD<00/11@0I31<02P0401L:4@0600l22@803P480P0?0PT201032P0600h1200?10T0
;1lV03DX;`0J3A@020021P0?0PT600h121Cooooo000Kooooo`0D00@20`0<2P/05Q@E01DC500D4Q<0
71XK028P8@0>30d02PP9010>3`0>30d01`D6014=3P0?2``03@T:00`82@0>2P/03`/<01<?400B3Pl3
010<3@0Z014=3P0?2``03PX;00h:2`0?2``040`=014=3P0>2P/02@D600<0000;1`P06aLH00X82@0;
30T030`:00h>300>2PT03`T901<=3@0E3`l01@4000/:200>3P`02`d:01<C4@0>2``040`=00l;300<
20T02`L800d92P0;1`P05A4B00`82@0B3Pl06ADF00`82@0>2P/04`l@00X61`0B3Pl05a<D1P0?2``0
3@0E4A@01`88028M8@0;1PX03PT=03<_<01HE5D0510A01<?3P0E4A0040`;00l;200@3@`00P071@H0
4P0B41400@0001@B4`0n?3d0518C00@20`0?3@h040h?00h<3@0:20T040h?01LE5P0H5QL00@0000h<
3@0;2@X02PP900/92P803@/<00<02PP900`:2`0<2P/00`0<2P/0100;2@X0108300`:2`0A3a0200P6
1`0G01TH6@052@`0@DA906eaM0000@@02`lB00H6200B4aD01@H800P8200A4A402@T900X82@0B4140
40h?014?400@3Pl04@l@01XH6@2WYJH0;B//0040000:20T00P0?3@h01`0=2``04@l@018@4@0G5AH0
61HG00/92P0<2P/00P0B41400`0?3@h03@/<00l=3P0400`:2`0A00`:300<2Pd01@<600/93@071@X0
108700P6300>314030X?00d;3P0:20/030X=010>4@0;2@`03P`?010>4@0=2`h00P0C4A@0200:20/0
40h?018@4@0B41403P`=014?400I5aP03`d>0P0=2``01@0?3@h03P`=00d;300B3A403PT=00803@P<
00<02`H:00X52@0?2Ph00P0@2`l05P0>2@d03`X>010;3`071@X02@L<01DC600:20d071XO00L52P0;
2@h030X?00h<4@0?3A804@lD01HC6`0Q7RL0514J00l<5@0<2A800`09010=5P040@X2010=5P0?00L4
3@0A3QL08b4]00X85P061180518P018@7P0;21T04@hO010=7P0?31d030TJ00/86@0<2AX03@/F0080
3@XA00l03@XB00d:4`0=2Q<03P/E00l<5`0B3aX04a0L014=6`0>2QP03P/F02PU;P0@3AH00@0500T6
3@071@/00P0;2@h300d;3P0E00/:3P0G7280X:N]06U]L`092Ph03`lA018@4`091@H0510A014<4@0@
2a404@hE00H42`071@X01085014?4P0=2`h030X=00h<3`091`X02PP;008030X=01002`T<00`93005
00<04`X?01483@0=1`/05@lC00l93@0910P0BTI:0490@`0V92L02`T<00T72P0?2Ph03PT=0P0=20`0
1`0<1`/02`H:00`72`0;1PX01P45014<400;1PX00P0=20`200l:3P0:00h93@0<1`/02PD900<00P0?
2`h040/?00<00P0A3A004`hB014<40803@P<00X040/?00h93@0:1@T02`H:00X52@060@D030L;018=
4@080`L02`H:0P0:1@T02P0>2@d04`hB01D@500;1PX02PD901@?4`0>2@d03@P<00h93@0>2P/200`8
2@0:00d92P0@30d01P8301<?400F4Q<02`L8010<3@0:1PL040`=00d92P802@D600T03PX;010<3@0>
2P/02@D600P41@0>2P/04Ph?00h:2`0=2@/00P0=20`0100810L01P4501<>4P0:1@T2020K7`0404e8
C00Q72000`02014<3`<030P900@02PH700X52@0<1`/03@P<0`0=20h00`0=20l03@P>00`72`0400`7
2`0;00d8300<1`/030L;00/62P0<1`/03@P<00X52@0;1PX03@P<00`72`0;1PX00P0<1`/200d83080
30L;00d02`H:00l;3003000020@500`82@0C3a0030P900d92P03000040`=00d92P0:1PL02@D600H0
2`L802@03`/<00h:2`0:1PL02@D600`82@0=2``03@/@00/:3`0?3Q<0000400d<4@0e=3T00@0500d<
4@0510T02@P=00/:3`0=3@l06ADD00X71@0300004Ph=018>3P0I5AH03@T:00d82`0;1PX030L;010;
400@2`l03PT=00d92P0A3@h040`=00/7200<20T500d92P0b00d8300>2A000`04018=4`0C3Q@00`02
02TT:01LEe/03`/<00h:2`060P<02PH700h:2`0@3Pl04@l@00L51P0;2@X03`d>00L51P0G5AH03@/<
00P61`0B41400P0100h>3P0<30h04A<@014C3P0]<2H02@d0024U5P0H70d061/@01TL4`0B51003@h@
010A5@0@3Q<030X?00h<4@0?3A802`T>00X83@0<2Pl02@L<00l=4P0;2@h05aDJ00X6300>1`l300d8
3`0800/83`0B3aH0514H00`;4@0A41H0000500d<4P081P`200d;400500`:3`0C4AH05aDJ01@B5`0;
2@h00`091``01P0<2Pl03`dB00d;400=2a0030X?00d;40<03P`A00@040hC018@5@0B41D03`dB0P0?
31<200d:4@0400l<4`0B3aH03@XA00d:4@<040dD00@03``C014?500A3a@04@lD0P0@3Q<0<P0?3A80
3@/@01<A5P0D4QL03@/@00`:3`0:20d03@/>010>4@0?3A003P`?014?4P0>30l03@/>00l=400F51L0
3P`?014?4P0=2`h04Q0C010>4@0>30l03@/>00l=400@3Q403@/>01DC5P0B41<05aDH00`:3@0D4QD0
4@lD00/93P0?3A801P@900l=4P0G5AX03@/@01HD6@0H5Q/04a4F00l=4P0A3a@04`hD018=4`0@2a40
4@`B01HA5`0J5A/04PdC0P0A318301<>500I014<400O6Qh05Q4E02HQ9@11?400:B@X02lZ;P0I51P0
81/O03Lb=P0R7B4040/?00d92P0@30d0510A014=3P0?2``04Ph?00d92P0@30d061@E00T51P0>2P/0
5A4B018<3P04014;3@0[018<3P0:10H03PP:00l92`0>20X06A<E01PA500G3Q<03PP<00d72`0J61/0
Q8:50=;Ad`0X9RT03`X>01<>4P0E3a<01P0201T>4@0G2@T04PH801882@0<1PH02`L800X82@081PL0
2`H:00l93@0@2Ph04PP@01@9400E2Q005P/A01@93`0A1P`040D;01873@0A1P`03`@:01873@0D2@l0
4`P>0146300200l42P0900h32@0?10X040D;00l42P0F2a406PlE01052`0;00H03`@:00804PD<00D0
4@@;01032P0@0`X040<:01<63@02018530804`H=00L040<:00/01@0C1Pd050L>00/01@0A10/040<:
00H03`890P0>0@P200l22@8040<:00H04`H=00d11`0L3aH07a8I0185300F2A0600l22@H03P485?oo
ool001_ooooo00`03@/<00h<3@0>30d02@L800`:2`0K6AX08AlP00l=3P0;2@X040h?00d;30091`P2
014=3P8040`=0P0?2``00`0B3Pl04@d>00l;300300l;3003014=3P0@30d03`/<00<03`/<01<04@d>
010<3@0C3a003`/<01@@4@0=2P/03`h=010?3`0A40l04@l?014<3@0A30`03PT:010<300@3Ph03`h>
00/:2P081`L040d>0080510A00l04@d>00h:2`0=2@X03PX;01<?400>2P/03`/<01HB4`0@30d020@5
010<3@0B3Pl03`/<014=3P0@30d01@0?2``03P0@30h02PL:010=400C4180510C00h;300M6Q/04@h?
01LD500M6QX05A8A00l<2`0?3@d05A<D0P0=2``04P0A3a002PP900`:2`081PL03P`=00l=3P071@H0
3P`=00/92P0I5aP04@l@01<A4P0L6Q/05aDF00h<3@0<2P/02`T:00`:2`803@/<00<030X;00d;300?
3@h00P0>30d0100=2``04@l@00/92P0:20T200l=3P0G010?4@0A4QH01PL<010C5P041PP03@lB018B
50061`T03@d?00h>3`071`P020P900`;300<2P/03@/<010>3`0>30d03@/<01HD5@1FE5D061LG00l=
3P0A3a000P0=2``02`0:20T03@/<00/92P0A3a0061HG00P61`0>30d040h?014?400@3Pl03P`=00D0
30X;014030X<00`:3@0=2`h02`T=00h<4@0=2a0040dC00/93P0<2Pl03@/>00X82`0<2Pd03`d@00X8
2`0<2Pd03@/>00l=400200/93008018@4`0A3a403@/=010>400>30h02PP:00/92`0?3@l200/92`80
3P`>00@03@/=010;3`0=20`03@P<0P0?2Ph05P0=20`040/?010;3`0>2@d03@P<010;3`0B3A404a4F
00<21P0D4QL04a4F018@5@091``02`T>00`:3`0>31404@lD01LE6P0F4aX03P/D00`94P0>2a@2014>
5`0:00l<5@0<2A80514J00X7400F4a`03@XC00l<5@0@3QP03@/E00d:5P803@XH00L040`K00d:6P0<
2AX03@TJ00h:7@0?2al03``J00803@XB0`0=2Q<03P0=2Q@03@XE00h;5P0>2aL03@XF00`8500610`0
5A8J014>5P0>2a805a@K02XX;P0:20d02`T>0`0=2`l0700<2a004AHM061WL00m@TX02@`A00T:3P0=
30h03@T:00`82@0C31003PH<00/42@0B2a003P/>00/9300B41<01P@700L5200@3Q402`T<00d;3P0?
3A0030X=00X82`0=2@d04@/?00l62`0A20d200l93@0700h8300:1PT03PX>010>4@030P@040hA00l=
400600d83006014<400@2`l03@P<020K7`0A310040/?1P0=20`01`0E41@07QTM01LB5P0F4AD03PT=
018=4@0<1`/00`0=20`02@0;1PX02PD900h93@0E41@03`X>00/62P0=20`040/?00l:3P0200d83080
3PT=00<03`X>02@O8`0b;C400P0?2Ph01@0:1@T04`hB01`H6@0O6a`020@500803@T:00`040`=00h:
2`0810D02PH7018>3`0f<S<07a/L018>3`0=2@X03PX;010<3@0=2@X200/7200E00X61`0<20T03PX;
00d92P0<20X03`X=00h:300B3Q001@43018>40091@L04`lA010;3P0A3@l020@601@?4P0<20X03PT<
00l;3@0>2P`02`L900<030L;00D030L<00`73@0<1`d030L>00d83@0200h93@0400d8300<1`/030L;
00d8308030L;00/02`H:00`72`0=20`03@P<00X52@0=20`040/?00`72`0=20`02`H:00`72`0300d8
300=00`72`0A3@h04`l@01`H6@0=2@X030P900X61`0<20T040`=00X61`0@30d0510A00T51P0200X6
1`802`L80P0<20T07@0=2@X030P900/7200;1`P03PX;00l;300920X02`T=00h=4@0610P03PdA02l]
<@0B4A@081hR01DC5`1mNgl06APL00P6200?2`X030P601XF5@0o>cX09B4Q014>3P0A3@h03`/=00T4
200:1@T04@`A00803PT=00<03@T:018>3`0B3Pl00P0<20T200h:2`<03@T:00d030L;00l:40091@X0
3PT?02hY;`0E4A@04@`@01@?4`0A3@h03@T:01XF5`0K5aP02PH700802PP90`0;2@X0800<2P/03@/<
00`:2`0H5QL03P`=02HT9@081PT030`A00/<300>3`h03Pl:00D70`0D5Pd05AL>010B2`0C51004Q<B
00d=4@0>3A<02`T>00l=4P0B41D040hC00d;400;2@h040hC00/93P0>314020H;01<A5P0<20h03PL?
0`0=20l04`0;20l030T@00X73P0A41H020L=01`K8@081`d02`X?00d;400>31403@/@00`:3`0=2a00
30X?00/93P0=2a003`dB00h<4@0<2Pl00`0=2a002P0<2Pl03@/@00h<4@0>314040hC018@5@0A3a@0
40hC00l=4P0A3QD2010=50<03``C00<030T@00d:4@0@3A@00P0@3A@00`0?31<03`dB00l=4P0200h<
4@<03@/@01405Q@I01@B5`0=2a004@lD01<A5P0J61/06ALJ014?4P0>30l04@lB00d;3P0F51L03@/>
00h<3`0;2@`04@lB00`:3@04010>4@804@lB01003@/>018@4`0B41<04Q0C010>4@0E4aH04a4F010>
4`0H5Q/03`dB01<A5P0<2Pl03@/@014?500C4AH04@lD0P0@3Q<0500@2a405Q4G01LB600E41H04@`B
00l:400C3Q@04@`B018=4`0F4AL050lE018=4`0E41@02`H:014<401aK70030L;01LB5P0C3Q8040/?
0P0C3Q80200?2Ph040/?014=3P0D41405a<D01<?400>2P/04@d>0P0?2``01@0>2P/04Ph?01PD5@0:
1PL040X<00<04@/=0P0@2P`09@1@BT`0NG=e01lI6`0C3@l03PP:014:3@0=10T03PH:01LB5P0<1`/0
:2HY04Q6B@0<2Pd03@P<00h93@0C2a003`D:01D:3@0A1PL040L901892`0=1`P03PP:010;300;1PL0
2PD8010:3@0?2@`03PH<01883P0@1@/03`@:0146300C20h040D;00l42P0@1@/00P0>0`T0100@1@/0
4`P>01873@0A1P`201873@804@H<00T04PL=01D:400H3A<050T?01873@0@1@/04PD<01442`0@0`X0
0P0?0PT0100@0`X04@@;01032P0A10/201@73P070185300C1Pd02@030186300?10T060/B00d31`02
00h120803`890P0@0`X200h120803`890P0@0`X01P0?0`T040<:01<63@0A10/03P8801D83`H03`89
0`0@0`X200l22@0300h12?oooooooooo01;ooooo000Kooooo`8030X;0P0B4140100?3@h04Q0A00d;
300;2@X200d;300400/92P0?3@h04@d>018>3`804`l@00@04@d>00h:2`0@30d03`/<0`0=2@X01@0>
2P/04`l@010<3@0?2``03PX;00803@T:02@03`/<014=3P0>2P/040`=01XF5`070`@02@L800/92P0<
2P/040h?00l;300;1`P04`l@02HT9@0M6a`04Q0A01<A4P0@3Pl040`=018>3`0A3@h03PX;00`82@0=
2@X03`/<01PD5@0C3a0040`=01PD5@0?2``071PI00@00@0E4A802@D6024M7P0:1PL500l;300P010=
3P0B41403`d>03Hd=@0X9RL04a4B00d;30091`P020H700d;300<2P/03`d>00h<3@0;2@X02PP900h<
3@071@H03`d>02LU9P0I5aP040h?00X82@0B41405A<D00X82@0G5AH0518C010>3`0;2@X03@/<014?
400>30d200/92P0P00d;300?3@h02`T:00d;300?3@h040h?00l=3P0>30d03`d>00/92P0<2P/03`d>
00/92P0?3@h01PH800/<40071``07alQ00l?4@0b<S@03`lA00T92`0:2P`03`lA00d=3`0<30h030X;
00h<3@0B41403P`=00X82@0A3a02018@4@0@014?400:20T03P`=00D310081PL040h?00T7200:20T0
4Q0A00P61`0A3a002`T:00P61`0;2@X03@/<00/92P@030X;01h030X<00`:3@0D4QD03P`@018@5@04
0PL040hD018@5@0<2Pl03@/>00X82`0;2@`03P`?00T72P0?3A005Q@G01`J7@0?3A0071XM03Pf>@0Y
9bX01`D800<1100?3A004Q0C010>4@0;2@`020H900T72P0=2`h200l=4008018=4@0>2@d03PT=00l:
3P0>2@d03@P<014<400?2Ph200`72`0V010;3`0D3a<02`X>00d;400j>3d0QhF:01XH7@0>31403@/@
00l=4P0<2Pl02PP=00`:3`0B41H01`@=00d:4`0>2a@03@XC01<@6@091Pl01@8;01@A6P0@3AH02PL@
00P53P0A3QD03@XA018?600:21002`PC014>6@0>2QP03PXI00d96P0?2a`04`hR01@?8`0A3A/500d:
4`0300l<5P0@3AP03P/F00803@XE00L03@XD010=500>2a804a0G00h;4P0?31<0:bT^00802PP=0`0=
2a001`0=2a405ALS00013@0;3aT03Q4H00l@500E51P00P0?2``07P0E30l03PD:01H;4@0D2Pl030L;
00P62@0?3A002@L:00/930091`X03@/>010>4@0A3a8030X=00X82`0<2@`02`D900l62`0F3A801002
01@?4P0G4AD030L;01<?4`0>30l05A<F00@31@0A3a802`H:00`72`803@P<01803PT=00l:3P0;1PX0
2`H:00X52@0R7B4030L;00T4200=20`030L;00/62P0<1`/03PT=010;3`060@D05A0D00/62P080`L2
00h93@0?00/62P0A31004@`@00d8300<1`/03PT=014<400<1`/02`H:01<>4P0;1PX03PT=00T4200;
1PX030L;00<03PT=01P0QX650=7<d00S7R803PX=00L21P0@2`l03PX;01<?400?2``05Q8C00<0000L
61T03`/<00<0000@30d04`l@05IBD`0V8R<030P900/7200=2@X03PX;00/7200<20T200h:2`802`L8
01403@T:01@@4@0L61T05A4B018>3`0300004Ph?00/7200>2P/00`00018>3`050@802`L800h:300?
2Ph04@`@00l:3P0200`72`0400d8300;1PX02`H:00/62`802`H<00@03@P=00h93@0>2@d03@P<0P0<
1`/01@0=20`030L;00`72`0;1PX030L;00803@P<01L020<700/62P0@2`l030L;00d8300910P02PD9
00d8300>2@d03@P<00`72`0:1PL030P901HB4`0;1`P03`/<00d92P0A3@h01`<400T51P0=2@X0510A
00T51P0200X61`802`L80P0<20T0800810D02`L800l;300@30d030P900P41@050`H020H900X82`0?
3A001@<600L5200>30l03`d@00400P0D4QD02`T<00/92P0300004Ph<01@@3`0R7Qd02@H501dI6P0E
4A804Ph@00T4200;1PX04`hC00h93@0A31003PX;0P0?2``0100<20T03`/<00h:2`0>2P/200d92P0T
00`82@0<1`/02`H=014<4P0=20h05Q8G00<00P0O6Qh03PT=00`82@0>2P/04`l@00<0000B3Pl03@/<
00T7200A3a002`T:00<10P0:20T02`T:0040000Q7b007Q`M08N5QP0H5QT03`hD00<21`0<30h04Q8A
01LG5@0720<02@T700h>300E5AD04a<F0P0;2Q000`0@3Q<05A<H014?500200/93P0800d;400?3A80
0P05018@5@040PL02PP=014<4`0>1`l300d83`0D00/83`0=2Q4020D<00X93`0920h02`X@00`;4@0;
2Pl02@L<00d;400F51T03@/@00D320071@X03@/@00`:3`0;2@h03P`A00l=4P0>314200d;400600`:
3`0=2a003P`A00/93P0<2Pl03`dB0P0>31403@0@3Q<03``C010=500@3A@03``C00d:4@0:1`h02`P?
00`9400?31<04@hE010=500>2a800`0A3a@2010>4`803`dB00T030X?01<A5P0B41D02PP=00l=4P0F
51L0518E00`:3@0;2@`00P0A3a80200l>Sd071XM014?4P0D4QD07Q`O018@4`0A3a803`d@0P0>30l0
500@3Q404a4D00h<3`0?3A0040hA00/9300E4aH04@lB00X83@0B41D03P`A00d;400C4AH05A<H01LE
6P0E4aP0518G01DC600D4QL04Q0E0P0C3Q@08P0@2a403PT?014<4P0G4QP04`hD014<4P0B3A<05Q4G
01@?5@0A31804@d@01TD600H4aL03@P<01hI7@0;1PX04PdA00d8300B3A402`L:00d8300B3A404`l@
01HB4`0I5AH0510A00h:2`0@30d030P900T51P0J5QL03PX;00`82@0G4a@200l92`8040X<01@03`T;
00h82P0L5QP0<B/]01/E5`0=1`T05a4C01D;400H3A<04@P=00`42@0@2`l03@P<00T72P0>30l020<7
014:3P0=10T04PL=01@:3P8040L:00@04PX=00d72@0>20X04@/=0P0:10H02@0C3@l04@/=00h82P0E
31404`P>00l42P0I3Q@081DK01/@5P0201D:400301H;4@0C20h040D;00804PL=00/04@H<01@93`0E
2Q004`P>0146300B1`d03@8800h32@0J3aD0714G01052`03018530804@@;00d040<:00d01`0=00L0
3P480185300C1Pd04PD<00/01@0I31<05PT@00l22@0<00H04@@;00803P480P0?0PT201032P803P48
0P0?0PT201032P0600d01`0@0`X02P0400T00`0>0@P03@071P0?0PT0100B1@`04@@;01032P0@0`X2
00l22ACooooo000Kooooo`0I00h<3@0?3@h03`d>00l=3P0>30d030X;018@4@0:20T02@L800P61`07
1@H03P`=014=3P0@30d03PX;00l;300I5AH08alP00/7200>2P/040`=014=3P0@30d03`/<01<?4002
00X61`0601@@4@0810D0510A00`82@0:1PL030P90P0>2P/200l;300300X82@0C4A803@/<008030X;
00H0518C038`<@0]:b`0518C00/7200@30d200d92P0401`H6@0;20P040`=01HB4`804Ph?00H07QXK
00X61`0B3Pl03`/<00h:2`0@30d3014=3P04010<3@0<20T02PH700d92P804@d>01T03``=010>3`0@
3Pl040h?00l=3P0>30d030X;014?400=2``08R0Q00`:2`0;2@X03P`=00/92P0@3Pl03`d>00@20`0T
8R<0EeEF01LE5P0200403`d>0040000?3@h04Q0A00D03P`=00D020H701@B4`0D4Q<02PP900l=3P03
00h<3@0>00l=3P0A3a0040h?00`:2`081PL03`d>00h<3@0:20T03P`=00H41@0?3A003Ph@00l>400?
3A0300h>400600000P0Q8B<061LL00H52P0?3a802`T:0P0:20T00`0;2@X03P`=010>3`0200h<3@0:
00l=3P0A3a004a4B01<A4P0B414030X;00L51P081PL040h?01HD5@803@/<00@030X;00l=3P071@H0
4Q0A100>30d0800>30h03P`?00`:3@0@3Q80518G00/93P0A3Q@04@lD01@B5`091`X04a4D03hl?`0C
4A@02@L:00X92`0?3A00?S`o038`<`040PD04@lB00l=400>30l03`d@00h<3`0:20/020H900d;3P07
1@P071XM00d;3P091`X05aDH0P0@2`l200l:3P803PT=0P0A3102010;3`803`X>01D04Q0E00P62`0M
6b00;2X_00L52P0E4aP03`dB014?500<2Pl04@lD018@5@0=2Q002`P?00`9400=2Q403P/B00l<4`0:
1`h02@H=00d:4@0?31<00P0=2Q40100>2a8030X?00/83`0<2A0200h;500400d95P0<21H030PG00d9
60803PXK00d040`J010=600=2QD030TD01<@6`0B3aX040dG018?600A3QL040dF00d:4`0<2A803@XA
00D03@/@01@02PP=00`:3`0>2a8030T@00/83`0<2Q802`dI00/=6P092aH020P@00X;3`0<2`l03@T:
00H20`0E30l040D;00/01P0F2Q003PT=00`:3@803@/>0P0>30l02P0C4A@0EE=F018@4`0;2@`00@02
00l;3`0>20`040L<01483@0?2@d2010:3P08014<400;20/03P`?010>4@0;2@`02@L:00`72`0>2@d2
010;3`0400h93@0=20`03@P<00h93@803`X>00<03PT=00d8300;1PX00P0A31001`0;1PX06aHJ01/F
6P0A31003`X>00d8300<1`/00P0;1PX02P0=20`03`X>014<400A31003PT=00d8300:1@T02`H:00`7
2`0=20`200h93@0W00d8300<1`/030L;00d8300>2@d03`X>03dh?01NFEd08ahR00T4200E41@0;2L[
02DQ8P0?2``00`00014=3P0300008alP010<3@0<20T02`L800h:2`0B3Pl05A4B00d92P0300005a<D
00L3100F4Q<03@T:00`82@0@30d03PX;00T51P0:1PL030P900d92P0?2``03PX;008030P900<03@T:
00`82@0;1`P00`0:1PL01P0=2@/030L=018=4`0@2a003@P<05MBEP803`X>00D040/?00`72`0=20`0
3PT=00`72`0200/62P0I00`72`0=20`03@P<00l:3P0500@03@T<01@?4`030080;BP/00H11@0910P0
3@P<00/62P080`L030L;018=4@070PH04PdA055<D0080`L03@P<00h:2`091@H02`L800P41@02010<
3@<03@T:00P030P900/7200;1`P03@T:010<3@0A3@h0100101DA4P803@T:0P0>2P/01@0<20T02PH7
00T51P091`X02`T<00803@/>01H02`T<00T72P0>30l030X=00X82`091`X02`T<00`:2`0=2@P02PH4
01HB4@091@@04Ph>04M3A00E4A803`X=00H11@03008040/@00X52@0>2@d03@T:0P0<20T0500=2@X0
3PX;00/7200<20T03@T:00l;300>2P/02`H:00d83`0A31801@0600/6300@2`l01P4500h93@0;1`P0
30P9014=3P0@30d03@T:1P0=2``0400A3a0040h?00`:2`0=2``04a4B00h<3`1CDUL02`X?00L72@0>
3Pl030`<014A3`0@41004Q8B00l?4@0<2`l200`;4@03014?500?3A803P`A00<030X?00X05Q@I0040
100C4AH00@0401PF6`0G4aT050dD018=4`0@2a403PT?0P0<2Pl00`0;2@h030/@00l>4`0200X93P0;
00h<4@0?3A803@/@00`:3`0B41D04@lD00h<4@081P/01`D:01LE6P0?3A800P081P/0200K6Ah00@04
01DC600>31403@/@01<A5P050`P040hC0P081P/00`091``030T@00d:4@02010=500300l<4`0=2Q40
40dD00803``C01d03P/B00l<4`0@3A@01`D:010>4`0>31404@lD010>4`0?3A800P05018@5@0A3a@0
2PP=01<A5P0B41D04@lB01@B5@0F51L040hA00`:3@0?3A00>3Hi00`:3@091`X07adP092>T@0Q7b80
40hA014?4P0201<A500@014?4P0@3Q405A<F03@b=@0<2Pd05A<F00D41P0S8B@04Q0E014?500=2a00
30X?00l=4P0C4AH04Q0E014?508040hC00l04@lD018@5@0>2@l05a8H00L220080`T06A@J00l:400D
3aD040/A02PS:@1/Ifd071LM010;4@0B3A400P0A31001@0B3A404`hB01<>4P0E41@04`hB00<04PdA
00P04`hB03<_<012?Sl040`=014=3P0C3a00510A010<3@803`/<01803@T:01HB4`0@30d04@/=00h8
2P0<1PP03`T;010:300>20X04@/=018<3P0H4Q@04P`>01PB500C2@d04`P>01893P0A2Ph200l:3P0Z
01<>4P0910P030H:01D=4P0A20d05@X@01L>4`0H4Q@01`4300h92P0E3a403PD801D<3`0800801P00
01L>4@0H3a8040X<0148300B1`d0304701<83P0J3aD01`0201<83P0:00D06@hD00l52P0?10X03@88
01052`0A1P`04`P>01873@0700804@H<00h32@0?10X04PL=01D:400D2@l03`@:1P0A10/?01032P03
00l22@0>0@P03P4800H03`891P0@0`X01@0?0PT03P4800h1200>0@P040<:00804@@;00D03`890185
300F2A005@P?00h1200Dooooo`006oooool00`0=2``03P`=00h<3@0200d;30<02`T:0P0B414200`:
2`0600l;300@30d040`=010<3@0F4Q<071PI0P0A3@h0100@30d03`/<00h:2`0=2@X202l[;00Q00X6
1`0@30d05a<D00X61`0C3a003`/<00h:2`0?2``040`=014=3P0?2Pd03@P;00`:300<2``02`X<014B
4`0=30d05A@E00d;3@0:1`T03`X=00/62@0B3Pl030P900l;300C3a0061@E00P41@0E4A80920Q02hZ
:`0?2``03PX;00803`/<00P040`=014=3P0A3@h04@d>01XF5`0M6AX05Q8C010<3@803`/<01T03P`;
00h>2P0>3@`03@`<00`;2`0<2``02PT901PG600510D040l@00h=3`0;2Ph04a8D00/92P081PL03`d>
00/92P0:20T040h?00H41@0E4a@0<Bl`01/I6P0?3@h03P`=00D03@/<018020H7014?400A3a002PP9
010>3`0B414030X;00/92P0:20T030X;00d;300;2@X03@/<00T7200<2P/03P`=00T7200?3@h400l<
3P0?00h<3P0>30l03`h@00L6200];C00:2L/00X93P1BDEH0518E01@B4`0B41403`d>00h<3@0<2P/0
2`T:00803P`=0P0;2@X09`0>30d0518C014?400<2P/02`T:00`:2`0=2``02`T:00X82@0=2``040h?
00/92P0>30d030X;00d;300>30d03`d>010>400A3a8030X=00/93@091``0518G01LD6P0R82D040hC
00/9300B41<0;R`_01HD5`091`X03`d@00d;3P091`X05Q@G01@B5@091`X03P`@00`:3P0200d;3`80
30X>00H03`dA00X9300<2Ph030X>01HD60081PX2010;3`803`X>0P0>2@d2014<408040/?0P0?2Ph0
30091``04@lD00D4200A3a@02@L<00X83@0>314040hC00h<4@0C4AH05A<H014>50803P/B100=2Q40
1@0>2a803``C00h;4P0;20l030T@008040dC0`0>2Q401@0=2A803@PB00d85@0=21D03PTG00803`XI
00L03PXH010<6@0>2aL02`LC00h;5P0?31L03@XD00803@XC00@03P/D00l<500?31@030X?100<2Ph0
100<2Pl02PP>00`93`0=2Q4200X73`0M00`94P0;2QD02PTE00/:500;2a002PX?00X:300A3a0040`=
01@<400?10/060dD01@8400A31003`d@00h<3`0<2Pd02`T<00X82`081PT04a4D018@4`0200<04a4D
00h:3P0>20`040L<01483@0?2@d00P0@2Ph01`050@@040d@00X82`0:20/04Q0C00X82`0=20`01@0>
2@d01@0=20`03PT=00l:3P0?2Ph03PT=00803@P<00T04PdA00`82`0=20`0C4M;018=4@0?2Ph03PT=
00d8300<1`/00P0=20`2010;3`0500d8300>2@d040/?010;3`0>2@d00P0=20`200`72`0M00/62P0=
20`030L;00`72`0=20`03PT=00l:3P0B3A402@@800D1100E41@020<700h93@0@30d00`00014=3P0<
20T03`/<00`82@0=2@X03`/<010<3@0?2``030P900X61`0?2``01`<400/7200?2``00P0@30d00`0?
2``02`L800`82@0200d92P0400/7200=2@T03`/;00h:2P8030P80`0>2PX04@0=2@T030P800d92@0>
2@d04`hE014=4P0E41D05a8G02TT:00@2`l03@P<00`72P091@L030P:00/72@0:1@P03@P<00803PT=
0P0?2Ph01P0@2`l01`<601`G6`030080>cHj06iYK@<03PT=00l02`H:00X52@0;1PX02@@801LB5P08
0`L03`/>00P31`0>2@d02@D601DA4P0R7Ql02`L800P51@0C3a000`0=2@X200`82@0=00/7200810D0
3PX;00h:2`0D414030T900`82@091@H03PX;018>3`0;1`P03PX;01HB4`0200d:30802`P:0P0=2P`0
500>2`d03@X<00/82P0;20X030T;00`92P0<20L04@d;00T5100:1PD02`L701/G600>2P/03@T;00`7
2`0@2`l03@T=00d8300>2@d03@T:0P0<20T01@0=2@X03PX;00d92P0=2@X03PX;008040`=00P03@P<
00`83P0K5Q`0JVE[01PC6@060PD04@`@00d830803@T:00<03PX;00l;300?2``00`0:20T200/92P80
30X;01h0518C00d;300>30d02@L800h<3`0N72402`T>00h<4@0@3a402`X;00`;3@0@3a003Pd?00l>
4@0B41D03`dC00/93`0@3Q<03`dB00h<4@0=2a003P`A00l=4P071@X07A/P00d;400O7B803`dB00`9
3@0@2@l200l:3`0G010;400>31003P`@00/93@0;2`h0410C00d<400<2`l03@/@00`:3`0@3Q<03`dB
00T7300?3A8061HK00/93P0B41D03`dB014?500I5a`03@/@00P72`0B41D00P0A3a@01`0B41D01@<8
01DC600<2Pl04@lD00X83@0?3A801P0>2a80400@3A@03``C00l<4`0>2a803``C010=500=2a00518G
018@5@0G5AX04a4F00h<4@0@3Q<07Q`Q01`J7`0=2a02010>4`0>014?4P0>30l030X=014?4P0B41<0
3`d@00h<3`0A3a804a4D010>4@1lNWd03`d@00h<3`0?3A02010>4@0=00l=400>30l07Q`O04]9C00@
3Q402`T<01TG6P091`X040hC01<A5P0G5AX061HK01DC6007010>4`0=01HA5`0?2Q007APN01dH7P0@
2a406A@J014<4P0F4AL04PdC04e8CP0J5A/06aHL01@?4`03018=4@0301<>4P0D3a<04`hB00804PdA
0`0A31001P0E4A8020@500/7200F4Q<03`/<01LC50804Ph?02d04@d>00h:2`0B3Pl04@d>01@>400C
3@l04@/=00l92`0B30h05@lA01H@4P0I4aD0=S0b03`f>01/IVP06A0D01@73P0C20h04@X>010:3P0?
2Ph03`/>018=4@0D3Q806aDH01P=4`0D1`h0610E014>4@0;20/04Pd?00h82`0<10H04@L;01882`0H
3Q004@P:01092@0W8B40;2@V01D:400@1@/04@H<00h52@0M4QP00P0B1`d03@0E2Q0040D;01X?5@0;
0PH06@lD01052`0<0PL040D;01/@5P0B1`d04`P>0146300B1`d00P0C20h00`0?10X04@@;01442`04
01442``040<:0`0B1@`201442`0301032P0?0PT03`8900@03`891P0@0`X0300?0PT03P4800h1200>
0@P040<:01442`0D1`h060/B01L:4@0B1@`03P8800d11aCooooo000Kooooo`0J00d;300>30d03P`=
00h<3@0=2``02`T:010>3`0<2P/02`T:00d;300D4Q<06QPI00d92P0@30d04@d>010<3@0A3@h04`l@
00l;300>2P/03@T:00l;300A3@h04`l@00l<300A3@h400l;30803@T:01D02PH700h:2`0D41405A4B
00l93@0@2`l02@L:018A4`092P`07AhP02l`<P0S8bD03`lA00h93@0F41@040X>00l;300A3@h03@T:
00h:2`0B3Pl00P0;1`P01`0810D04@d>018>3`0=2@X030P900l;300@30d00P0A3@h02P0@30d05A4B
01LC500C3a003`/<00h:2`0?2``03`h<00d>2@0=3@/200`<2P0=00`<300@41002@T900`<3P0^;S00
2PX<00X93P0=30l03`d>014?400<2P/03P`=018@4@0201<A4P0501@B4`0D4a<02`T:00/92P0=2``0
0`0<2P/200d;300:00/92P0@3Pl03P`=00X82@0>30d04Q0A00l=3P0=2``02PP900`:2`803P`=00H0
4@l@00/92P0:20T03`d>00h<3@0<2P/500h:2`0900d:3@091`X08AlR01TH7@0F5AX01`H;01XK800<
2Pd03@/<00803`d>00<03P`=00`:2`0?3@h00P0>30d200l=3P0?00h<3@0100003@/<018@4@0?3@h0
5Q@E02DS900B41402PP900/92P091`P03P`=00d;300<2P/03@/<00803P`=01T03`d?010>4@081PT0
>CLk00D3200100@03@/A014?500<2Pl040hA014?4P0M6ah061HI00X82`0<2Pd01P@702@R9@0L6Qd0
1085010>4@0@3Q<03P`A00`:3`0:20d02`T>008030X?00D05Q@I010>4`081P/03`dB00<11P02010;
3`803`X>0P0>2@d00`0@2`l03`X>00l:3P0300l:3P0600d;400>31402`T>00`:3`0=2a004Q0E0`0;
2@h02@0=2a003`dB00`:400:1`h02`P?00d:4@0?31<040dD00l<4`0200d:4@0800`9400>2a804@hE
01DA600C3QD040/B00h9400=20l200`640803PPB00@03`TC010:500@2Q@04@`I0P0F4R00100>2QL0
2PLB00/84`0:1a4200X7400300d:4P0>2a803``B00D03`d@00@03`dB00h;4P0?31<03P/B0P0;2140
1@0>2a@050hH018<5P0@3AD03PdB00802PX<00X0108300T7200H4QP040H>01@84P0H31H040/A00h<
3`0=2`h02`T<0P0:20/02P0;2@`00@0201DC5P0=2`h06QPK00h:3P0>20`040L<01483@0?2@d2010:
3P0800d8300;1`/00P0300P62@0F51L04@lB014<400?2Ph200d8300300h93@0?2Ph030L;00@03PT=
00P030L;00X52@0>2@d030L;00d83003008050lC00d830<030L;00T03PT=00l:3P0@2`l03`X>00d8
300>2@d03`X>010;3`0>2@d00`0=20`200`72`0>00d8300<1`/030L;00d8300>2@d03`X>010;3`0B
3A404`hB00/72P03008050lC00d92P0K5aP200d92P0700T51P0?2``0510A00h:2`0:1PL02@D600/7
200200d92P0400<0000N6Q/01@4200X61`804@d>00P03PX;00d92P0>2P/030P900/71`0=2@P03`/:
00h:2@8030P700@03@T800h:2@0>2PT03PX90P0=2@P01P0=20`00`0500h93`0@31404`hD00<00P80
2`H:00D02@D600d92P0F4Q<0510A00h9300200d830803PT=00T03`X>00/62P0P6al02PD902DP900=
20`02`H:00d8300>2@d00P0=20`2014<400600l:3P0>2@d04PdA00d8300>2@d02PD90P0:1PL0100D
414040`=01@@4@0@30d600`82@0>010<3@0<20T03`/<044m?P0U8B803PX;00/7200>2P/040`=00`8
2@0@30d06QHG00h:2`0=2@X200`82@0500d92P0>2P/03PX;00h:2`0=2@X00P0<20T03`0<20L02`L6
00l;2@070`807ATH00l;2`0810D04Ph?00d92`0910P04PdA00/62`0D3a<03PT=00d92P0200`82@03
00d92P0>2P/03`/<00803PX;010040`=014=3P0?2Ph040/B00X52`0U82H04@`B01XE6@0=20`02`H:
00l;300>2P/02`L800d92P0@30d030X;0P0=2``300l=3P0A010>3`1=Bd`020H700l=3P0A3a006ALH
00`:3@0@3Q<030X=00T72P0>30l040hA014?4P0;2@`030X=00d;3P0<2Pl00P0>314200d;400>00h<
4@0?3A803@/@00P62`1]Jg00A49705eKH00>31404PhB014;3`0?2Ph03@P<00`72`0:20/200l=4007
00/;3@0=3@l030`>00`<3P0?3Q8020H;00L52P0200`:3`0H024O900Z:2d02PP=00d;40081P/02@L<
01HD6@0A3a@03`dB01dK80040`L04@lD018@5@0<2Pl09R@Y00T7300M6b000@04010>4`0@3A@03``C
00d:4@0<2A003@XA0P0@3A@200l<4`0400h;4P0?31<040dD00d;40804Q0E00L07A/P01PF6`0A3a@0
20H;014?500B41D040hC00806ALL00`02`T<010>4@0D4QD03@/>00/9300B41<0518E014?4P081PT0
7Q`O00/9300L6Qd6014?4P0;00l=400=2`h06QPK01@B5@0@3Q407Q`O01<A5P0D4QL071XO024O900M
6b000P0B41D401<A5P0>018@5@0A318071LM00h93`0@2a409B0V01hI7`0H4aT04@dB00X52`0U82H0
3@P>01<>500B3A42010;3`0300l:3P0@2`l040/?00<04`hB01404PdA014<400A310040`=01DA4P0@
30d03`/<01TE5P0?2``04Ph?01<?400G4a@06ADF00`82@0=2@X030H800d72@02010:300;00l92`0B
30h050h@010:30070@<0EU1B0=7;c@0^92P050L>01<83P0C2@h00P0@2Ph09P0@2`l04PdA01H@501f
K740@CHl00P00P0?2@h05aHK01`J7@0B3Q804P`@00h31`0F2`l060dA01T?400@1PL01P0000H1000@
20X04`P>01052`0E2Q00714G069GG@0]8RP0304700d2200E2Q001`0200`11`14>Cl01`0201D:400C
20h03P<902TO900F2a4050T?100@1@/<01442`H040<:1@0A10/00`0@0`X03`8900l22@0400l22@H0
40<:00`03`8900h1200>0@P03P4801032P0A10/02`0500l22@0@0`X03@0700`01P0=00LDooooo`00
6oooool00`0@3Pl04@l@014?4002010>3`0300h<3@0;2@X03`d>00<03P`=01002PP900`82@0@30d0
4Ph?010<3@0?2``040`=014=3P0@30d03PX;00l;300@30d04@d>01<?40070`@04Ph?0P0A3@h00`0>
2P/04@d>01DA4P0200l;300901@@4@0B3Pl040X>01<=4@0610L040lB018C5@1?D5806AXL008030`>
00/040/?01@=4@0D3Q804`l@00d92P0A3@h04`l@00X61`0A3@h03PX;014=3P0200h:2`0300X61`0B
3Pl040`=00804@d>00@040`=00l;300=2@X03@T:0P0?2``03`0>2P/03`/<010?3@0@4@`03Pl:00d=
2P0=3@/03Ph>00l?3`0A4A40LW9d0:VX[00I61d03PdB00h=4002010>3`0<00`:2`0?3@h03`d>00/9
2P071@H02PP900/92P0A3a004Q0A00X82@0=2``03P`=0P0?3@h2010>3`03014?400?3@h02`T:0080
3@/<00@03P`=00/92P0:20T03@/<0P0?3@h050091`P03`d>00`:2`0G5AH0:2HW01TF5`0?2@T040T9
00l92@0?2@/03`X;00h93@0<2Pl08R0U00P7300>3a@03@hC00l@500;2@`030X;0`0>30d0:00=2``0
4@l@00/92P0<2P/04Q0A01DC500>30d03@/<01@B4`0>3@d020H7024P8016A4D030X;00d;300H5QL0
3@/<014?40071@H04@l@010>3`0?3@h03P`=00d;3@0<2Pd0518E038`=00@3Q<03P`A00`:400<2Pl0
2`T>014?4P0<2Pd061HI01@B5@0;2@`03`d@00/9300<2Pd2010>4@0=00H41`0=2a003`dB00h<4@0=
2a0040hC01<A5P13@DH0KVaa00l=4P0D4QL01`H:018@5@02010;3`803`X>0P0>2@d600l:3P0700h<
4@0?3A803P`A01PF6`0Q7b@03P`A00l=4P0200d;40802`T>0`0=2a0300h<4@0300l=4P0>31403P`A
008030X?00<040hC01@@5`0A2aD00`0?2A<200d83`803PT@00/03`XA010;4@0@2a803PTD010<6`0B
3Q`03@TG00h:600?31L03@XD00`94P0300`9400400`:3P0>30l03P`=00h<3@803P`?01D03P`A00`9
400>2a803``E00/84@0:1a003@PC01894`0B21006Q<J01dI7P0D4QD04A4A030`<P0A41<030L>0148
4P0=0`l04PLC00h93`0<2Pd0100=2`h00`0B41<030/=00l=400200h<3`0504I2AP0>20`040L<0148
3@0?2@d00P0@2Ph0200F4AD040`@00h<3`0<2Pd0;R`_06e[KP0C3Q804@`@0`0?2Ph00`0@2`l030L;
00d8300200h93@0800d8300<1`/04PdA00`82`0C3Q801`<601<>4P0910P300`72`0800d8300?2Ph0
40/?00`72`0>2@d040/?00l:3P0=20`200`72`803@P<0`0?2Ph01`0=20`030L;00`72`0=20`03PT=
00l:3P0;1PX00P080`L03@0@2`l04PdA010;3`0I5QH04@d>00L3100:1`L0;BTZ01PD5@0C3a0040`=
00l;300>2P/00P0=2@X02@0<20T04`l@05]GF00F4Q<04@d>00h:2`0@30d0510A010<3@0200X61`04
00/71`0=2@P03`/:00h:2@@030P701<03@T800h:2@0>2PT030P700h93@0D41H0HeiU04E0A`0=2@h0
20@900l:3`0>2@d030P900h:2P0F4Q40510?00d92P0;1PX030L;00<03@P<01P03PX=00T5200>2@d0
1P45010;3`0B3A402`H:014<400?2Ph02@@800`72`0;1PX04@`@00P31`0:1PT030L;010;3`0=20`0
3`/<00T51P0<20T02`L801<?400A3@h500`82@0?00d92P0<20T03`/<00d92P0T82403@T:00`82@0B
3Pl03PX;00/7200>2P/040`=00h:2`0<20T03@T:00803`/<00<03@T:00`82@0>2P/00`0>2P/0400=
2@X030P700h:2@091@@03PX902<O7P0>2PX03`/<00d92P0=20/04@`@010;3`0@2a0030P;00h93@0=
2@X200`82@0300d92P0>2P/040`=00803PX;00X040`=014=3P0?2Ph09b8X00h:3`0H4aT04@dB00H1
1@0=20`030L;0P0?2``00`0=2@X03PX;010<3@0600h<3@0<00X82@0]:b`00`8200l=3P0;2@X03@/<
014?400B41803@/=00d;3P0@3Q403@/>0P0<2Pd0200?3A003`d>01`J700[:B/03`dB00h<4@0=2a00
3P`A0P0?3A801`0<2`l0518G014?500>314040hC00l;3`0@2Ph00P0>2@d0100?2Ph03@/>01DC5P0D
4QD200`<3P0300/;3@0<30h03`hB00801`D:01X040hC00T730081P/03P`A00X83@0E4aP0;R`a01HD
6@081P/04@lD01DC60081P/03@`@01<A5P1=Be005aDJ04Q6B`0E4aP03@/@018@5@0A3a@040dD00l<
4`0>2a803@XA00h;4P8040dD0P0?31<03`0>2a803``C010=500>314040hC00l=4P0F51T03P`A010>
4`0B41D04@lD00h<4@0B41D06QPM01@B5`0200`:3@0;00l=400E4aH05Q@G018@4`0A3a8040hA018@
4`0A3a805aDH00T72P0A3a80100@3Q402P0A3a805aDH00h<3`0C4A@04Q0C01LE60081`T05A<H014?
500C4AH201PF6`0301<A5P0A3a@04a4F00805A<H00@04a4F014?500G4QP09B0V0P0E41H02`0U82H0
5a8H01D@5P0E4AH06QDK010;4@0H4aT040/A01HA5@0D3a<04`hB00<04PdA00d05A0D01HA5@0F4AD0
5Q4E01<>4P0B3A403`/<018>3`0C3a004Ph?01<?400?2``0510A008030P900D061@E00`82@0H51D0
4P`>00h82P0201@>40803@L903404`d?00X51P0F4180618D02XT9P0E2Pl05@L>01@83P0C2@h04@X>
010:3P0?2Pd04@`?01<;3`0F31805`/A01P:4@0?20h05AHJ04M6B`1>BTl050`A01<8300E2Ph04`L;
01<72@0E30`050`:014<2@0B2@/05P/A01873@0@1@/03@@803L/<P0G3A8040D;01<83P0B20d03`D:
01L<4P11=c`04@P<01<83P0=10P05P/A03X`=@0F2a4050T?008040D;0P0A1P`601442`H04PD<1P0@
0`X500l22@0301032P0?0PT03`8900@03`891P0@0`X01@0?0PT03P4800h1200>0@P040<:00804@@;
00D03@4700h1200B1@`04PD<00h2200Dooooo`006oooool03`0?3@h040h?010>3`0@3Pl03`d>00d;
300<2P/02PP900H41@0>30d0:2HW03Dc=00<20T040`=014=3P02010<3@09014=3P0@30d040`=010<
3@0?2``03@T:00`82@0A3@h02PH700803@T:020071PI00d92P0E4A8071PI01<?400@30d04Ph?00d9
2P0E3A<03PL>00L52P0F51T01`P<05QLG`1ZK70051<H00h=4P0G4QP03`D=018<400D3a007ATJ01<?
400@30d02PH701XF5`0<20T03`/<01PD5@0a;Bh040`=00/720<04@d>01D040`=00l;300>2P/03`/<
014=3P0?2``030P900h:2`0@3``03a0:00d>2@0;30P030`:00d=2`0E5AD02`/=028R9019BD`02@P=
00P73@0<2Ph00P071@H05@0D4Q<06ALH01@B4`0?3@h04a4B00/92P091`P03P`=00/92P0<2P/02`T:
00d;300>30d03`d>010>3`0>30d03@/<00h<3@0?3@h03@/<00`:2`0200/92P0600`:2`0?3@h040h?
00l=3P0=2``04Q0A0P0<2P/01@0E4a@02PL8010:2P0B2PP04PT:008040X<00/03`X>00L52P0>3140
2PT?01<D6@010PL01PH=018@4`0A3a0040h?00h<3@0200d;300A00/92P0=2``03@/<00d;300>30d0
3`d>00`:2`0H5QL07A/L01PF5`0C4A805A<D00`:2`0?3@h061HG00D3100F51D00P0@3Pl03`0?3@h0
3P`=00h<3@0=2`d030X=01DC5P0:20`04Q0E01LE6P0=2a4040hC01<A5P0F51L03@/>02DS9P0201<A
500B00l=40030@@06QPK010>4@050`H03P`?00h<4P0D4AP04a0G00h;4P0@3A@04a0G01`I800V8bX0
0P0600/93`0P7B@02`T>0P0@2`l200l:3P803PT=0P0=20`05P0>2@d03`X>00l:3P0?2Ph040hC00<1
1P0=2a00;bdb03Tg?00;2@h040hC00d;400@3Q<030X?00d;400A3a@040hC00l=4P0=2a002`T>00X8
3@0<2Pl200h<4@0:00/93P0:20d030X?00l:4`0?1a@03@DB00l74`0B2QD04P/C01094@803`P?00D0
40X>014;3@0A2`l03@TA00`85`0200d96009014=6`0@3AP03@XD00h;500=2Q403@X@00`:3`0<2Ph0
2`T<00802`T:0P0;2@`0500;2@h030T@00l<4`0B3aP03``E00`94P0<1a806PlG01032P090@D020<7
00H41@0E5AD0?Ci001XJ700;20h04PXG01<;6P0A21H04@`B0P0?3A0300h<3`0:01@B5@0100805aDH
00800`0F51L05A8E00h8300@1``04@P=00l93@8040X>00H01@0400l<3`0D4QD030X=01HD5`0j>3/3
00l:3P0500h93@0=20`02`H:00/62P0<1`/00P0=20`0200<1`/02`H:00@00`0E41@00`0201XE6@0D
3a<030L;0P0=20`200`72`803PT=0P0=20`200h93@803@P<1P0>2@d02P0=20`030L;00`72`0=20`0
3PT=00l:3P0>2@d040/?00l:3P070PH200d8300800L4100300001`<402HR8`2IUIH0PGen00d92P0?
2``2010<3@0800h:2`0<20T03PX;00H20`0L61T01P<300`82@0@30d200h:2`0700d92P0;1`P02`L8
00/71`0=2@H03`/800h:1`0400`81@0A00h:1`0@30T03`/800h:1`0H4aL030H@02hY<00Q72<02PD<
01HA5`0;1P/03PT=00h:2`0;1`L03PX900h:1`0<20P00P0<1`/200d8300800h93@091@P03@P<00d8
300@2`l05Q4E00/62P0D3a<2028M8@804`hB00`04PdA00@00`0A31005A0D00P31`0?2Ph05a<F00d9
2P0;1`P03@T:00<000070`@300/7208030P90P0=2@X0300H51D04@d>00H20`0;1`P0510A00/7200?
2``03@T:00`82@0>2P/03`/<00`82@L03PP:01<03`T;010:300?2@/03PP:00`61P0<20L03PX800d9
200>2PT030P8010<3@0?2``03@P;01D@500400<07aXO00P31`0>2@d03@T:008030P900l03@T:00h:
2`0?2``030P900/7200=2@X03`/<00l:3P0I51/050lE00<0100E41H020<702LR9P0?2Ph00P0>2P/0
1`0A3@h040`=00l;300=2``030X;00/92P0:20T00P091`P02P0;2@X01@<400d;300A3a003@/<00h<
3@0;1`H040`=01DA4P0D4142010;3`0901@?4`0@30d04Ph?00X61`0?2`X07ATJ014?4`0?3A803P`A
00803@/@01@04@lD01@B5`040PL03P`A00H42@0K6Ah03`/?00h8300=20`03`X>014<400@3Q40518E
010>4@0<30h04a<E014A4`0=3@l040lC00h<4@801`D:01H03@/@018@5@0C4AH01`D:00h<4@0J61d0
2PP=00/93P0B41D0>SPm01<A5P0I5a`040hC00X83@0=2a002`T>00X83@0<2Pl01P@900l=4P0=2Q40
3P/B0P0?31<200h;4P0=010=500?31<03``C00h;4P0?31<040dD014?500B41D03`dB01<A5P0=2a00
7Q`Q00d;400200l=4P0A014?500F51T06ALL010>4@0B41<06ALJ01`J7@0J61/04Q0C01PF6@0?3Q00
1`D801hL7`0B41<09R@W010>4@0?3A000P0>30l02P0?3A0040hA00400P0L6Qd040hA00@21@0<2Pd0
3P`?01DC600B41D2010>4`0401<A5P0E4aP040hC01<A5P805A<H00P04a4F010>4`0H4aT04`hD01XE
6`0I51X03`X@014<4P805A0F00L07QTO00l;400J5A/050lE01HA5@0D3a<04`hB00<04PdA02<050lC
01HA5@0F4AD05A0D018=4@0A31005A4B01hJ6`070`@09B4R02<O800=2@X04`l@00d92P0V8R<0B4A5
01DA4P091@H03PP:00`6200A2`d030H8014;3@0O6A/02PD600d72@0A2`d050h@00P2100F2a005PL>
01@73P0C2@h04PT>010:3P0201<=4@0Q01D<4@0A20`0200201832P0G4AL04Q<H04i=DP1PG6406Q4F
0146300900004`@701X>400I3`l040P600`70`0<10@040D;00l42P0G31806@hD01P=4`0G31805@X@
01P=4`0900@05``B00T0100A20`06@hD00l52P0;00H050T?00804`P>00D04@H<01052`0A1P`04PL=
0146300601442`H04PD<1P0@0`X200l22@<040<:00<04@@;00l22@0?0PT0100?0PT601032P0800l2
2@0>0@P03P4800h1200@0`X04@@;00l22@0=0@L300`01P0300/01Ooooooooooo01;ooooo000Koooo
o`0800h<3@0>3Ph03Ph>00h>3P0=3@d02`/;00X:300<30h200H6200>00l?4@0=3@l02PP9010<3@0A
3@h040`=014=3P0B3Pl02`L800h:2`0@30d04@d>010<3@0?2``200`82@0R01XF5`0<20T04@d>00T5
1P0?2``06QHG010>3`0>2``04Ph?00d92P0>20`07aXN00l=400@3Q80>CXn0<K:c@2g^K/08B0U00T9
2`0D3a<02P@8018<3P0H51D0@Cdn02@P8@0<20T05A4B030/;@0I5AH0510A00T51P0F4Q<020@5018>
3`<04@d>00<040`=00h:2`0>2P/00P0?2``01P0<20T02`L800l;300A3`h03Pl:00d<20802PX800`0
3@`:00X92@0?3a400@02018A4`0:2@h03@/@01@B5P0;2@X02PP900h<3@091`P200`:2`0@01HD5@0?
3@h040l?00d;30030@8030X;00X82@0;2@X030X;00d;300>30d02`T:00X82@0=2``040h?00l=3P<0
3@/<00@040h?01<A4P0D4Q<04@l@0P0=2``300`:2`0D010=3@0@2PX040/8010:2P0@2P`03`/<00l;
3@0>30l03`d@00L62`0@3a@02P/?00`;400A3a803`d>00d;300<2P/03P`=00l=3P0:20T2018@4@05
00/92P0:20T04Q0A01@B4`0>30d00`0:20T01`081PL02`T:00/92P0D4Q<01`D603Dc=015@d@0100>
30d0800>30h03P`?00/9300>31003`dB00D3200:20d02`T>00h<3`0>30d01@<402@R8`0:20T03@/<
01HD5@0100004@l@00T7200:20/05ADG01@D600G61d05A@I00d<4@0920h02`X?00T73@0:1`h06aTN
014>500<2A0030L=0P0@2`l200l:3P803PT=0P0=20`0;P0>2@d03`X>00l:3P0?2Ph030X?010>4`0M
6b001PD900h<4@0<2Pl03@/@00X83@0?3A802`T>00`:3`0@3Q<03P`A00h;4P0=2a4030X?00`9400:
20h02PP=00/83`0;2@l030X?00h;4P0?2a<030H@00`43`0?21<04PdD01@=5@0A2a803PT?00l93@0@
2Ph040`=014;3`0A3AD04PhL010<6P0?31P04PlJ00h;500:1a0200d:4@0500d;4@0=2a003@/@00d;
3P0=2``00`0=2`h0700=2a0040dD01<@5`0H5A`05A8K014>5`0?2a<04PP@00l42P0F3a<061<G00X8
2@071PP03`lA00T83@0>31802@<=00`44@0>1Q@050lE018@4`0A3a803`d@00h<3`0=2`h00@0201`J
7@081PT201<A500300`9300>1`h03PL>00803`P?00T040X?00l:3P0F4AD040`@00X82`0?3A004Q0C
00P62@0=20`00P0>2@d01@0=20`02PD900P31`0;1PX030L;00803@P<00X030L;00/62P0>2@d02`H:
01HA5@0<1`/02`H:018=4@0>2@d03@P<0P0<1`/02P0=20`03PT=00l:3P0=20`02`H:00`72`0>2@d0
3`X>010;3`0?2Ph200h93@8030L;00h03@P<00`72`0<1`/03@P<00h93@0?2Ph050lC00/62P0E41@0
4@`@00h93@0:1@T03PT<024M7P800`0001L0<Bd^01`H6@0>2P/02PH700T51P0;1`P040`=01<?400B
3A403@P<00<0000B3Q003@T:014=3P0=2@X020@500X61`0>2P/03@T:00/71`0=2@P03`/:00h:2@03
00`81`0B00d9200?2`X04Ph=014=300?2`X0920S01`G7P0C3Q@02`H<00T42P0G4QP02@@900`72`0>
2@d030P900l;300A3@`03PX<0P0=20`0300>2@d03`X>00l:3P0C3Q801@0400/62P0B3A4020<700l:
3P0400<05Q4E01TD60802@@80P0:1@T06P0>2@d04PdA00D00`0B3100BTA801LB5P0?2``03`X=00h9
3@0E4A803PX<00/62P0;1`P030L:00`72`0=2@X03@T;00<0000>2P/05a<D00<0000>2P/04Ph?00X6
1`0=2@X040`=0P0>2P/00`0@30d040X<00h82P0200`6200F00h82P0@2P`03@L900l92`0@2P`03`T;
00d72@0;1@L0208201@?3P091@@00`00010<3@0A3@h03`/<00T51P0E4A801P4504@o@`0g<SH03PT=
00d92P8030P901P03@T:00h:2`0?2``02`L800X61`0<20T03`/<00h93@0;1``040/A01D@500=20d0
6A@H01dH700@2`l03@T:00h:2`0C3a004Ph?00l;300>30d03@/<00`:2`0:20T200P61`0E00X82@0B
414030X;00T8200B4140518C00`82@0?2``05A4B014=3P0@2`l05a8F01@?4`0?2``05A4B018>3`0A
3@h06QHG014?4`0?3A803P`A008030X?02`02PP=00T7300Q7b@02`T>00l=4P0:20d0510C018<3P0@
2`l03`X>010;3`0>30l03`d@00`:3@0=3@l05aLI01DE5`0>3Q002PT=00h<4@0@3Q<03`dB014?500?
3A803P`A00D3200C4AH04@lD00P62`0C4AH040hC0040100D4QL01@@8020N8`0?3A803@/@00X83@0B
41D020H;018@5@0>314030T@00d:4@8040dD00<03``C00d:4@0@3A@00P0?31<0100>2a803``C010=
500A3a@201<A5P0601PF6`0F51T0;bdb00h<4@0C4AH0518G0P0<2Pl03`0D4QL03`d@024O8P0_;C00
6QPK00`:3@0E4aH03`d@01XH6`0C4A@09R@W00h<3`0:20/04a4D014?4P02010>4@0@014?4P0C4A@0
518E010>4@0B41<06ALJ00l=400D4QD05aDJ01PF6`0E4aP04a4F01DC600I5a`04a4F01DC608061HK
01805A<H01<A5P0G5AX04`lE014?500D3aD05Q4G01`G7@0P6b4030L=01TD600F4AH030L=014<400C
3Q804@`@010;3`0?2Ph200h93@0;01<>4P0E41@05Q4E01@?4`0A310040/?010<3@0A3@h040`=01PD
5@0300000P0E4A804@0>2P/030P901PD5@0D4140=S8c00/51`0?2@/04`d?00h82P0P6Q`0>C<e048l
?P0@2P`0208401TC5@0=1`T04PL<008050L>01d04`P>01893P0B2@h03@D:01L>4`0C2Pl05@X@01X=
500A10/03@H<00T83@0@3a@03PX>01/B5`0W72@07Q4H01T=4@0D20`03`D601491`0E3@/05`h?01@;
400900D030<801<:3`0700804`P>00L00P0201<83P0901X?5@0D2@l03PD900d2200C20h060dC00l4
2P0H3A<04@H<008040D;00<04PL=01<83P0A1P`01P0A10/6018530P040<:0P0A10/2018530H03`89
0P0@0`X01P0@10P040<:01442@0@0`X03P<900d220803P4800P04@<:01<42@0@0@P050D:01452@0>
0PH03`<701@831Cooooo000Kooooo`0400h>3`0930d04aDG00D82P806ahP00P041@G01PL7`0Q9BT0
2PlC00L=400@51L030`>00l=3P8030X;02H040h?00h<3@0=2``03@/<00`:2`0=2``03P`=00l<3@0D
3a006ADF01LC500?2``03@/<00l=3P0A3a002`X:00l?3`0a<C4030/;00l=3@0>2@L040`:01<B400;
2P/08R<U04E6B01BDeD04Q8D00d=3@0>2PT071LD00X60P0C40d06APF014@3P0;2PP03@`:020O7@80
40h?03003`d>00h<3@0<2Pd02@L:018@4`0:20/03P`?01HD5`0:20/02`T<00l=400F51L03`h@00T7
2P0?3A003@/<010=3@0B3Ph040d>018?400A3@h03PX;00l<3@0@30d03PX;00/82P0>2P`03P`=01PH
600:2PX030`<00L71`0C4A8030X;01@B4`0G4a@03@T:010<3@0B3@h040d=014@3P0<2`T02`X8014@
3P0;2PP03@`:00`;2@0=30X200l>300300`;2@0?3P`03`h<00803`h<00<03Pd;00d<2P0>3@/01@0>
3@/0300<2PP040d<018@3`0710@0;Rd[03Dd<P0A40l03P`<00/92@0<2PX02`/:00h=30803@/<100<
2P/200h<3@0500X82@0<2P/040h?00/92P0>30d00P0@3Pl03@0>30d03@/<00h<3@0;2@X040h?00l=
3P0=2``0;B//02h/;@0U8bH0<Blb01PF6@0C4A@00P0<2Pd08@0;2@`03@/>00h<3`0>30l03@/>00/9
2`0?2P/04@`<018>300<20D04a0=00d<200G5Q802PX800l?3@0?3`h02`/;00h@3`0M9bD0WjRY0;W1
`@0k@D803Q8D00`>400?3a802PP<00h<3`0?2Pl04P`A00h93@0;20/030X=00d;3P0200h<3`0@00d;
3P0G5AP04@lB00h<3`0?3A0030X=00X82`0<2@l040dD00L42`0C41L020H<01PE700F4aX0:2D/014>
5@803P/B02403@XA00/8400=2Q<040dE00P53@0?31D040dE01@A6@060``030TA01<@60050P/03@XA
00H42P0<20h05a@J01DC600D41H03@X?00P62`0E4AL03P/@00/:3@0E4QL03@X@00h;4@0<2Q002`T?
010>500@3A<030X@00d;400?3A800P0@3Q<01@0>314030X?00h<400A3a@03`dB00803@/@00`04@lD
00T7300P7R<03@/A00`93`0;2@h03@T?00d:3`0@31803`dB00h<400<2Pl200d;400900l=4P0@3A<0
3`/A00h:400=2a00:BL/01DC600=2a003`dB00803@/@01T03P`A00l=4P0<2Pl02`T>00d;400B3QH0
3PXB00X63P0A3A@02`P>00d;4@0?3A803@/?00X82`091`X02`T<00h<3`0B41<05aDH00@31@0>30l0
2`T<00h<3`0=2`h030X=00802@L:00@030X=00d;3P0<1`/03PT=1@0?2Ph01@0B3A4020@7010<3`0<
20/02`H:00803@P<0P0<1`/00`0=20`03PT=00`72`0300h93@03010;3`0B3A402PP=008020H;00D0
2`T>00l=4P0A3a@02@L<00P62`0200l=4P0300/93P0=2`l03PT=00802PD90P0=20`0100<1`/03PT=
00d8300<1`/200d8300X00h93@0<1`h03@P>00h93P0>2@l03@P<00`72`0@2`l040`=01HB4`0@30d0
20@500l;3@050P<05Q4D00h:300A30l020D606IRI00g<SD03`X=01D@4`0;1`T04@`?010<3P0=2@/0
2`L900X6200;1`T03@P<01D@500G4QH04@`A010;400I51T05A0G018=500@2a402`H<00`73@802@@:
02@03PT?00/6300<20d040/A00l:400>2@l03`X>00`72`0>2@d03`X>00`72`0B31003`T=00h8300?
1``04@P=01893P0C2Pl03`X>010;400910X03@P>00X52P0D41D02`H<01LB5`0F4AL02PD;00h93P0A
31803`X>01@@4`1[IVX061@G00P31`0@2`l300d8300800`72`0;1PX02`H:010<3@0<20T0<Rh_00/7
200@30d300`82@803@T:01<03PX;00h92`0?1`/040L;00l72`0>20`03PP;00h82P0;1`P03@X:00P7
1@0;2@T02PP8020N7P0@3Q403@/>00/9300:20/030X=00L03@/>00X02`T;01<A4`0D4Q<030X;00l=
3P0J61T02PP900`:2`0;2@X030X;0P0>30d0100?3@h03P`=00d;300=2``200`:2`802`T:00X02@L8
00d;300>30d030X;00d;3P0@3Q404a4D05YHF`091`X04@lB1P0>30l01@0=2`h030X=00`:3@0<2Pd0
3@/>00802`T<01403@/>00h<3`0>30l03`d@014=3`0@2PX03`/;00h:2`0?2``03@/<00l=3`0?3A00
3`hC01<B5`0B4AH030/@00/93P0200h<4@0300d;400<2Pl030X?00<03@/@0`0>31401`0;2@l04@hE
010=500>2a802`P?00h;4P0:1`h00P0=2Q402`0;20l03P/B00h;4P0?3Q@03PdC01<B600E51X040lE
00h=4`0@3aD04A0F00803@`B00T04Q4G010?5@0=31403`hC00d<4@0F5AX03@`A00l>4`0@3a@00P0>
3A802@0A41D04Q4F010?500C4A@061<G01XE6@0C3Q8040/?01<>4P06018=4@0<014<4P0B3A<071LM
010;4@0E41H06aHL01HA5`0O6R004`hD00h93`0E41H050lE0P0B41D201<A5P0=01@B5`0E4aP05A<H
014?500H5Q/05A<H01PF6`0=2a004Q0F014@5@0E51T040lD01@C5`02018@4`0801<@4`0E4A805Q8C
01LA500G4A<05Q8C00l;300@30d201<?400:01@@4@0C3a004Ph?010<3@0B3Pl04@d>01<?400D4140
5a<D01<?40804Ph?00D040`=014=3P0A3@h04@d>010<3@02014=3P804@/?01`0618F00h8300C3A40
4`dA01D?4`0A2`l05Q0D010:3P0?2@d06A0E01@93`0B1`d04@H<01873@0E2Q005@/@01D:400F2a40
50T?01873@0C20h03`L:01@?400=20T04``@01H<500P5R0050TD0P0@1@h06P0A1@/04@H901871`0@
20T03`X>010:3P0>20`030H:00h62`0@20d040L<01483@0?1P/0?C<i03DZ<00>1@T06@hD00h42@0K
41H030<704]0AP0F2a404`P>0146300?10X03P<90`0@1@/2014630@040D;00L03@8801P=4`0C20h0
4@H<01032P0E20l03P4800804`H=00<04@D;01032P0@0`X00P0A10/201032P803P<;01H03P<900l2
2@0?0PT03`8901842P0A10L04P<701011P0C10P03P<600T21P0=1`/040H900l4200B0`L04`450180
1@0B0PD04@<40103100?10@03P@45?ooool001_ooooo01803A4D010E600A5QT01``@00/@50001@T0
000506U/L@2/[k@0:Rha00D9300L82<03Ph@014?400<2P/02`T:00h<3@0;2@X600d;300N00T41@0D
4140510A01DA4P0T8R<0<Bl`00d;300?3`l0410@03Ti>@0<30`04A0>018=2P091@@030X;014@4@08
2@d01@H:00`=400H61X0410@01@@400400005Q8?014>3@0@3`d03@`:014@3P0:20T04@l@0`0>30d0
2`0=2``02`T<00`:3@0:20/02`T<00`:3@081PT02@L:00X82`091`X01085008061HI00<020H900X7
2@0=2@X00P0@30d00`0B3Pl040`=00d92P0200l;300H00h:2`0=2@X03`/<018@4@0000001`L700d=
3@0D51@040h?00T7200A3a00510A00d92P0A3@h04`d?00`8200100002`X800L6100E51803`h<00d<
2P0<2`T03@`:0P0?3P`00`0<2`T02`X800`;2@0400d<2PH03Pd;00X051<A014@3P0:2@P040l=00l>
300O7Q`02PT700`;2@0>3@/030/90P0:2@L07P0>30d03@/<00`:2`0;2@X03@/<00h<3@0<2P/03@/<
00X82@0;2@X03`d>00T7200<2P/04@l@01<A4P0A3a003P`=00`:2`0C4A805A<D01LE5P0<2P/02`T:
00P61`091`X061HI00d;3P0?3A003@/>010>4@803@/>0P0<2Pd200d;3P0P01<=4@0A30l04@d>00`8
2@0D4Q003Pd;00`;2@0;2`/02`/=00T83@0920h02P/?03Dn?@3QjnX0logl04]BDP0830d03A4B010A
4`0<2Pd04a4D00`72`0E3a<02@@8010<400=2`h030X=00h<3`0?3A0040hA01PF6@0?3A0200`:3@0L
00d;3P0>30l061HK01/I7P0:20d01P@9018@5@0X9R/0518G00/93P081P/03P`A00P62`0>2a<06QLP
014>5`0710d05A8K00d:4`050`/04PlH00`94P0A3QL04PlH00P53P15@TT0>SPm00d;40801P@900P0
3@/@00l=4P0610T02`T>00L52P0B41D05Q@I00H52@803@/@00@030X?00l=4P0=2a002`T>0`0=2a02
00`:3`0300T7300<2Pl03`dB00803P`A00T040hC00h<4@0<2Pl05A<H010>4`0200D03@/@00`:3`0=
2a000P0>314200d;400@014?500?3A8030X?00X83@0;2@h03@/@014?50081P/03@/@01@B5`0:20d0
3@/@00/93P0>314040hC00h<4@8030X?00`03@XC00d;4`040@X06aPO00X73P091Pd09bDZ01XH700<
2Pd02@L:00H41`030@@201XH6`0600P62@0<2Pd02PP;00d;3P0@3Q403@/>0P091`X03`0=2`h040hA
010;3`0?2Ph03@P<00`72`0>2@d03`X>00/62P0:1@T01@0401HA5@080`L06aHJ00h93@0200`72`06
00l:3P0=20`02PD900T4200=20`03PT=0P0=20`03@0>2@d030X?00X83@091``02`T>00d;400>3140
1`D:01LE6P0o?D80;bdb00H42@0<2Pl00P0=20`00`0<1`/02`H:00d8300200h93@0900d8300<1`/0
3@P<00d8300>2@d02PD<00`73@0=20h03`X@00803`X>01H02@@800`82@0O6a`02`L8018>3`0M6A/0
5A0D00<00P0;1PX00`0201TD601BCE40:RDY00<00P0D3a<02`H:00`72`0>2P`03PX;00`82@0;1`P0
2PH70`0;1PX01`0<1`d03@P>014<4P0?2Q403`X@00d83P0:1@/00P0<1`d01@0=20h03PT?01LB600F
4AL02PD;00802`H<00P02PP;00T72P081PT03@/>018@4`0>2@d03@P<00`72`803@L;01@03PP<00l9
3@080`T04PdC00d83P0?2Q0030L=010;4@0<1`d04`hD014<4P0;1P`03`X@00h93`0[9RX020<701XE
6@0300802@@801XE6@<03@P<0`0<1`/01P0<20T04Ph?03<_<00<20T040`=00d92P@040`=0P0?2``3
00l62`<03@L900H03PX;01HC50091`P020L500@30@0:2@L200d;3P8030X=0P0;2@`600d;3P08010>
3`0;2@X03@/<00`:2`071@H020H700`:2`0=2``200h<3@8030X;01003@/<00X82@0:20T02`T:00h<
3@0@3Pl03@/<00D3100=2``03`d>00T7200:20T02@L:00`:3@0>30l02@L:2@0>30l300d;3P0=00h<
3`0D4QD03`d@00P62@0A3a806QPK01<A500>2P/040X:00l;300>2P/03`/<00d;3P0200l=400500`;
400>3A803PdB00d<4@0=2a000P0>31400`0=2a0030X?00`:3`0300`:3`0800d;400>31403P`A00T7
3@0A3QD03``C00/83`0B3aH200`9400?00l<4`0=2Q402`P?00h;4P0=2Q403@`B00`;4@0@3aD04a8H
00h=4`0=318040lE01<B600A41H030/A00803`hD01<03@`A01LF6`0=31402PT>00d<4@0H5a`03`hC
010?500A41D03`hC00h=4P0@3a@02`T<00l=400B41<040hA00l=400C4A@03P`?00803`d@00l040hA
014?4P0A3a807adR01HD6@0=2a0040hC01hL8@091``04Q0E01HD6@0>31403@/@01@B5`0@3Q<00`0A
3a@3018@5@0801<A5P0G5AX05aDJ01<A5P0L6Ql03`dB00`;4@0J6Al201@C600600l=4@0Y9bX04Q0C
01<@4P0D41404`l@0P0D3Q001@0K5aP0:2@U01`H6@0>2P/040`=00804Ph?00/04`l@01PD5@0;1`P0
4@d>00/7200M6AX071PI01@@4@0?2``03PX;00`82@0600l;300301D?4`0A2`l08adQ008030H:00L0
4P`@014;3`0@2Ph03PP<00l93@0D3Q805@dB00L04`P>00/050T?01873@0@1@/04@H<01072@0F4100
3`T;01@<4@0?1@d05@/F00l43`0201<74@0601@83P0D20`050P:01892`0>20`03PD:0P0?1P/03@0<
1PX040X>00`62P0400804P`@00l93@0:0@H04@L<01D:400;0@H050T?0146300700800P0B1`d01P0A
1P`03`@:00l42P0?10X03P<900l42P804PL=00<04@H<00l42P0;00H00P0?10X03`0I3Q@050T?00l4
2P0>0@P05`XA00d21`0;00D0300600P00P0B1@`04@@;01032P0?0PT040<:0185300400l22@0D00l3
2@0>0`T04`P>01042`0E20l03@0701@73P0E2Q004@XA00h83`0A20d04PL=01<32P0A00H04@0400h0
000@0@@05PL:01<82@0;0@8Dooooo`006oooool04`0:3aD041DK01<H7P0=4QP041DJ00T>4P0c=S/0
7B0U030c>00310P04A8F0042100>3Ph04@l@00`:2`0;2@X03`d>00`:2`0=2``00P0>30d04`0=2``0
30X;00`:2`0B30h05A4B018>3`0?2``05Q@E01hL7@0?3@h020P801@D500>3Ph030`<00/92P0>2@P0
40`=00/9300>31000P0B4aL0300>3a<02`X?00/;3@0D41809AlO014=300<2PP02PT700P71@0?3P`0
20H700l=3P<03@/<00l030X;00X82`0>30l01P@701<A500D4aD01P@7014?4P0C4A@00`4401DC5P11
?d80>SPk028P8`091PP00P0A3@h00`0>2P/04@d>018>3`0200l;30<04@d>0140510A04e;C00P8200
20P800/;2`0>3Ph02PP9010>3`0?3@h04@d>00d92P0A3@h04`d?00`8200920H04Q4?00l>300200T8
1P0300d<2P0<2`T03@`:00803`h<0P0<2`T01@0=30X03`h<00l>300@3`d03`h<00H03Pd;00T010<1
01DD4P0920H06APF004000081`H02PT700l>300@3`d00`0<2`T200`:2`@03@/<01H02`T:00d;300:
20T02`T:00h<3@081PL03@/<014?400C4A804@l@00h<3@0=2``01`D600P61`091`P05aDF00T7200B
41400`44010>4@081PT030X=0P0:20/0800A3a8040hA00h<3`0>30l040hA014?4P0B2a804`dC01LB
5P0B3A405A8C00P61`0@3Q003Ph@00`;400A41L061HQ01TI8@0G8240GFMV06YcLP0O9BD02`l@00`@
4@0=3Q002PP;01<A500:1@T05a4E00P31`0D4QD03`d@0P0<2Pd02@0>30l03`d@00/930081PT01`D8
00T72P0<2Pd03@/>00H52@0200H42@0A014?500610T00`4600X83@0=2a005A<H01<A5P0=2a003`dC
03llA@2`[KH07Q/T00401`0<2A806QLP018?600;21400`0<2A803@1;B4h0?C]000l=4P0?3A8061HK
01LE6P0D4QL05aDJ0040100K6Ah0BDM<02LU:P091``00P0=2a00100<2Pl03`dB00`:3`091``200X8
3@0600/93P0=2a0040hC00/93P0<2Pl03P`A0P0=2a001P0?3A8040hC00d;400<2Pl05A<H00801@T0
3@/@01h02PP=00L52P0:20d02PP=01LE6P0610T03`dB010>4`071@X030X?00X83@0<2Pl040hC00h<
4@0;2@h02PP=01HC700;21403@XC01@A60050PT06AHM01DC600<2Ph020H900d;3P0@3Q403@/>00`:
3@0@3Q4200d;3P0400X82`091`X04@lB00h<3`802@L:01`03P`?014?4P0B3A403`X>00`72`0;1PX0
3@P<00l:3P080`L071LK00<00P0Q720040/?00H11@0=20`02`H:00l:3P0F4AD050lC00l:3P0=20`0
4@`@01<>4P0A31003`X>010;3`0<2Pl02`T>0P0:20d04@0;2@h030X?00d;400@3Q<0518G01DC600@
3Q<03@/@00`72`0?2Ph03PT=00/62P0<1`/03`X>00h93@0=20`030L;00803@P<00<03PT=00/63@0<
1`d00P0>2@l0600>2@d04@`@00P31`0300003`/<00D10P0F4Q<09b<U00d8300S7R802`H:00X52@0=
20`03PT=00d8300C3Q8020@7018=4@0G4QH02PH800l;300=2@X02`L800X61`802PD900T030L;00d8
3P0<1`d02PD;00X5300>2@l03@P>00/6300<1`d00P0=20h0300:1@/08ahT02PS:@060@L01@0601HB
600820X02`/=00P82P0:20/03`d@00`8308030L;0P0<1PX0500=1`/03PP<00l:400>2@l02`H<014<
4P0500H03`X@00d83P0@2a403@P>00`73@0?2Q0030L=01hI7@060@D05Q4E01lJ7P0G4QH03PT=1@0=
20`01`0<1`/040`=00T51P0G4a@00`0000`82@0B3Pl00P0A3@h2010<3@0300l;300>2P/040L<0080
40L<0`0>20X01`0H51D07Q/L00L51P061@<02`X8010>3`0;2@`00`0=2`h00`0<2Pd02`T<00`:3@05
00`:3@0400d;30071@H02`T:00d;30802PP900@04Q0A00l=3P0@3Pl03`d>0P0;2@X04P0D4Q<03`d>
00`:2`0<2P/03P`=010>3`0R82402`T:00l=3P0>30d01`D600d;300;2@`030X=014?4P0920X05A<F
00X82`H03@/>00<03`d@00h<3`0=2`h00P0>30l03P0:20/03@/>018@4`071@P00@0200L5200B3Q40
40X:00l;300>2P/03`/<00d;3P0>30l03@/>100<2a00100=2a003P`A00h<4@0=2a0200`:3`<03@/@
00D03`dB010>4`0@3Q<040dC01<@5`0200/83`0<00h;4P0=2Q4040dD01<@5`0A3QD03P/B014>5@0?
31<03`hD00d<4P0B4AL051<I0P0@3aD0600>3A<051<I018A5`0;2Q0030/A00h=4`0=31404A0E01HE
6P0D4aP03PdB01TH7@0?3Q<04Q4F01<B5`0>3A8030/@00l>4`0B41<0518E01DC5P0A3a803`d@014?
4P803P`?01003`d@010>4@0A3a804@lB014?500H5Q/081hS014?500<2Pl061HK010>4`0B41D03@/@
00l=4P0E4aP040hC1P0A3a@03P0B41D05A<H01@B5`0=2a00518G00P62`0G5Q`04a8G00X93P0?3Q<0
6APL00d;3P0B41<04a0B0P0C3a02018<3P0502TU9P0g<c@08alP014=3P0C3a000P0A3@h02@0E4A80
5Q8C010<3@0P71d01P8301PD5@0G4a@04@d>010<3@0201<?4004010<3@0>2P/03`/<010<3@803`/<
010040X>01@>4P0a:bl05Q0D00`62P0B31002`D9010:3P0>20`040X>00l93@0>1`/04`P>01@93`0E
2Q004`P>0P0B1`d0900C20h050T?01873@0@1@/04@H<00l72P0D3Ph03@L901@<4@0@1Ph05`dF0105
400A1@l04@H>01<73@0D20`050P:01@8300?1P/03P<900l62`0A20d03PD:00T31`0O6Ad04`dA00/5
2@0?2Ph04@/?00`42@0C20h050T?00T0100>0`T060dC014630804`P>00D04@H<01873@0@1@/03P<9
00l42P0201873@0<0146300?10X03`@:01@93`0A1P`05``B01873@0?10X0200201<63@0>0PP04@@;
0P0F2A001P0A10/040<:01032P0B1@`05@P?01T<4`@03`8900@03P<900h32`0:00L030<;0P0800L0
3P0A1a00100500@0100=1`h02@0700L0100B10/04P4900l01P0B0@L05@H901D93@0B1`P030835?oo
ool001_ooooo01<01@/G05QOJP2HWjP0GFA]01lU;@0A5A/030dD00`<4@0A4AD04Q4F00h=400=30l0
30X;00l=3P0;2@X030X;014?400?3@h03@/<00803`d>00@03P`=00/92P0:20T050h@0`0@30d0100=
2``030X;00l=3P092@T2014A4@0A00h>3P0;2@X04@`>014=3`0<2Ph03P`B00h?5@0;2a807QhU051?
EP0d<cP02PH901<>400?2``040d>018@4P0=2``00P0A3a000`0N71d030X;00d;300200d;300K00`:
2`0:20X0518E00/9300]:bh0<S0c00d;3P0B41<040hA01DC5P0K6A`030X=00T72P0@3@l04Ph?010<
3@0>2P/05Q8C01/G600C3a0030P900h:2`0@30d04@d>01@@4@0f=3D061PH00803Ph>00@03`l?00T7
200;2@X03@/<0P0?2``02`0A3@h04@/=00d92@0E51802PT700/:20081`H040l=00d<2P0<2`T03@`:
00803`h<00@030/900/:200;2PP03@`:0P0>3@/00`0=30X03Pd;00h=2`0400h=2`0Z018A3`0:2@L0
3@`:00/:200C4Q0040l>00l>300B4@l03`h<00d<2P0C4Q004Q4?00T7200;2@X03`d>014?400?3@h0
30X;00/92P0>30d030X;00d;300?3@h02@L800l=3P0@3Pl03P`=00`:2`0=2``040h?00X82@0A3a00
2PP902l];P0<2`/03@/<00X82`0@3Q4030X=014?4P0>30l03@/>0P0?3A0200d;3P0T00l=400?3A80
50dE010:4@0B3A<04@`A01`I6`0E4aD03@/>00X93P0<2a402PPD00`:5`0?3aT0318D00H=3@0B61P0
41HF00lB4`061`T03Ph@00T72P0>30l040/?01<>4P0@2`l061HI014?4P0=2`h02`T<00`:3@0=2`h0
2PP;00d;3P0>30l030X=0P0;2@`200l=4P0F00h<4@0Q7b@020H;00X83@0=2a002PT=02DS:00[:Bh0
5A<H00d;4@0>2a80>3Dl010=500B3aH02@H=00P6300;20l03P/B018?5P0:1`h02`P?01@B60802`T>
00l030X?00d;400?3A801`D:018@5@0A3a@03@/@020N8`0T8RL0518G00h<4@0=2a002`T>010>4`0?
3A80100<2Pl01`0=2a003P`A00h<4@0?3A803P`A00/93P0:20d00P0=2a001P0>31405Q@I01HD6@09
1``03`dB00h<4@@03@/@02L03P`A00T7300>31403P`A00`:3`0A3a@03`dB00h<4@0=2a003P`A00T7
300:20d03P`A00d;400?3A804Q0E010>4`0>31403@/@010=5P0>2a@03@XC00h;4P0X9B`020D<018@
5@0=2`l030X=00l=400=2`h01`D800h<3`0<2Pd040hA00T72P0;2@`03P`?00l=400=2`h00P0;2@`0
4`0=2`h03`d@014<400?2Ph03@P<00`72`0>2@d03`X>010;3`0J5QT06A@H00h93@0910P05A0D00l:
3P0<1`/03PT=01@?4`0A31000P0>2@d00`0B3A404`hB014<400200l:3P0300`:3`0;2@h02`T>00<0
2`T>00T030X?00h<4@0;2Ph03`dB010>4`091``03@P<010;3`0?2Ph00P0=20`0100?2Ph03PT=00d8
300<1`/200d8300C00h93@0?2Q403`X@00h93`0=20h02`H:00T4200?2Ph03PX;00l;300<20T020@5
010;3P0=2@`0510C00l:3P0?2`h02@D800h:3@0200d8300900`72`0=20`03`X>00l:3@0>2P/03@T:
00`82@0;1`P02`H:008030L;0P0<1`d01P0;1P`03`XA018=500@2a403@P>00`73@803PT?01P030L=
01<>500?2Q003@P>01D@5P0<20h02PX<00`=3`0?41802`/=00P82P0;2P`02`X=00/9300;20`02`L;
00`72`0=20`03PT?00`73@0V8BL0=c8h018=4`0<1`d200h93`0:00`73@0=20h03`X@00`73@0A3100
2`H:00h93@0A310040`?018=4@<03@P<0`0>2@d01P0<20T02@D601<?400B3Pl0510A00/720803`/<
0`0>2P/0100=2@X04PT<0189300B2@`3010:300800X61`0B3a001P@500T7200:20T030X;00/9300<
2Pd300d;3PL030X=0P0=2``03P0?3@h030X;00/92P0@3Pl03`d>00L51P0<2P/03@/<00/92P0>30d0
71XK01DC500A3a003@/<0P0<2P/0300H5QL020H700h<3@0?3@h020H700`:2`0<2Pd0518E00/9300=
2`h030X=00l=40H03@/>00<03`d@00h<3`0=2`h00P0>30l0400C4A@030X=00T72P0O7B00;B/^01dK
7P0>2P`040X<00l;300>2P/03`/<00d;3P0<2Ph030X?00d<4@0>3A8200`;4@0400d<4@0>31403P`A
00d;40@030X?0`0=2a005`0>31403P/A00h;4P0<2A0061DL00l<4`0=2Q403``C018?5P0@3A@03P/B
010=500?31<03PdC00`;4@0?3Q@04Q4G00l>500@3aD04A0F01HE6`0E51X040lE00804A0F00d05QDJ
010?500S8RL040lD06UXK@0K6Ql040lD018A5P0C4QL03`hC00h=4P0@3a@04Q0C00804a4D00<04@lB
010>4@0?3A000`0A3a83018@4`0;01XH7@0D4QL04Q0E018@5@1VI6T040hC00l=4P0@3Q<03`dB014?
500D4QL0100B41D3014?500@01@B5`0E4aP04a4F01dK800b<3D05aDJ018A5`1FEE/0D4mD00h=4P0D
4aL05aDH018@4`0C4180510A01<?40804`d?01006ADF01lK700D41404Ph?01LC500D414040`=01TE
5P0E4A809b<T03di>P0F4Q<04Ph?01<?400?2``04@d>0P0F4Q<04`0B3Pl03`/<010<3@0D41404Ph?
00l;300C3A4040X>02TS9`0B31002`D9010:3P0C3A4040X>00d72`0?2@d040X>01493P0C2Pl00P0D
2a00;00B2@h040L<01483@0D2a005@`A01<:3`0A20d04PT>014:3@0B30d0208401493P0;0@T05@/D
01463`0@1@h04@H>01@83P0F2Ph05`/>01H:3`0B1P`04@@;0186300B20d03`H;00l7300H4aL030L;
010<40040PD0514D01D>4P0900@04`P>01@93`0A1P`03@<800d2200C20h04@H<00h32@0B1`d03`@:
0P0@1@/30146300501052`0G31807A8H01873@0A1P`00P0@1@/0300>0PP04`H=01032P0B1@`03@47
01042P0B1@`04@@;01032P0A10/04`H=01H940803`<701H03`8900h32@0>0`/030@<01D<5P0:10l0
2P@A00h95@081A00BDA@09J@V@0a:c803@@=01D;4`0>0PX060PB01002P0I2Q806``B0185300>0`L0
40D95?ooool001_ooooo00h07RLf09NP[@3hool0WjFa02L]=P062A005aLO01DE6P0A3a@05Q@G00d8
300A3@h03@/<00l=3P8030X;02L040h?00h<3@0=2``03`d>010>3`0>30d02PP900T7200D3Q004Ph?
014=3P0@30d030X;00/92P0920P05QHF014A4@051@D01PH6014?400A2`l030L=00l=4P0C4AP03`lI
00h>600_;cP0Xj:Z03@c>@0C3Q<05Q0D00X52@091PT030X?00P62@091`X01@<6010>4@0=2`h00`0>
30d03P0=2``03`d?01DC5P01008040hA02TW:P0C4A@03`d@00/930030@@02`T<014?4P071@P02PL9
0P0>2P/0100=2@X0510A01HB4`0A3@h200h:2`0<00d92P0<20T03PX;00`:2`0C4a<030`<00<30`08
20P05aDF010>3`0=2``03@T:0P0?2``02P0>20X0510@00h=2`0C4Q002`X803Xi=`0920H03@`:00`;
2@0=30X200l>300300`;2@0;2PP02`X8008030/900<02`X800X91`0>3@/01@0>3@/0300100007QdK
00h=30040`403`h<01<B40081`D02`X800P71@0=30X05aHD00l>308030X;01d03@/<00h<3@0@3Pl0
40h?00`:2`0?3@h03P`=010>3`0A3a002PP900`:2`0?3@h03P`=00`:2`0;2@X030X;00800@0>30d0
30X;01lM7P0;2@X01`D601PF6@0E4aH03`d@018@4`0;2@`02PP;00/9300400`:3@0A00/9300C31<0
3`X=01<?400D40l07adI01HE400?3P/01PH600h>400E51/0?C]806ATKP0>4Q@01`/<00T=3P0;3Pl0
0P0?4180?@0R8R@05A<F00l=400G5AP01`8601<>4P0B41<03P`?00`:3@0=2`h03P`?00l=400;2@`0
3P`?00d;3P091`X020H900T72P0;2@`00P0302DS9P20OX40;B/^00/9300B41<01P@700L5200@3Q40
3@/>00d;4@0C41L00@05018?5P050PT04@hE010=500;20l05A8I01lL8`0A3QD03P/B01<@5P0:20d0
3@/@018@5@0>31404Q0E00h<4@0100@03P`A00P62`0;2@h09R@Y01DC600>314030X?00X83@0B41D0
518G00l=4P0>31400P0?3A800`0>314030X?00d;400200d;40802PP=00L03@/@0040100J61d0?ce2
01DC600610T02PP=00803P`A0`0<2Pl03P0>31403`dB01DC600?3A802@L<010>4`0=2a001`D:014?
500:20d06ALL01HD6@0<2Pl02PP=0P0<2Pl05P0:20d02@L<00X83@0100L02@H?00@12P0710/0924X
00401@071@X02@L;00`:3@0?3A004a4D01@B5@081PT03`d@02@R9@0E4aH030X=00<1100;2@`400`:
3@0300/9300=20`03PT=00803PT=0P0?2Ph02@0I51P0MW5e00@00`0300806A@H00<00P0@2`l03`X>
00d8300300`72`0300d8300>2@d03PT=008030L;00D03PT=00X83@0;2@h02`T>00`:3`0200/93P06
014?50040PL01P@900L52P0;2@h0518G0P0=20`01`0?2Ph040/?00h93@0<1`/03PT=00d8300<1`/0
0P0=20`0400>2@d03PT@00h93`0>2@l03@P>00/62P0:1@T03`X>00X61`070`@03@T:00h:2`0@2`h0
8ahR0;Ze^@0P6al200/62P07018=4@0F4AD05Q4E00X52@0>2@d040/?010;3P0200`82@0Q00d92P0<
20T02`H:00d8300910P020<900h93`0<1`d03PT@00l:4@0>2@l03@P>00/6300A318040/A00X52`0=
20h04@`B00d83P0;1P`03``A00L82P021PL04QHG01TM7P0:3Pl020T;00/<3P0<30h02`/=00T92`0:
20/02`T<00802`H<00H040/A01TD6P080`T030L=00d83P0<1`d200d83P0300`73@0=20h02PD90080
40/?00<00`0200H11@0:1PT00P0=20`200h93@803`X>00H04Ph?00/7200400403`/<010<3@0>2P/4
00d92P803PX;0`0@1`P0200>20P03PP900h82P0810D030T;00d;3P0B41<020H90`0<2Pd0100:20/0
2`T<00d;3P0?3A0600/930803P`=01P03`d>00/92P091`P03@/<01lM7P0=2``03`d>00/92P0610D0
2`T:00H41@071@H020H700`:2`0?3@h040h?00H41@071@H02PP900h<3@0<2P/02PP900T72P0C4A@2
00T72P0301DC5P0<2Pd030X=00D030X=01003@/>00`:3@0<2Pd030X=00d;3P0;2@`020H900/9300F
51L06ALJ014?4P0=2@`040X<00l:3P0>2@d03`X>0P0=2a001P0>31403@`B00/:400;2Q003PdC010>
50803P`A00X03@/@00`:3`0<2Pl03P`A010>4`0?3A803P`A00d;400<2Pl02PP>0P0I5Qd0400?31<0
40dD00P5300;20l03P/B00d:4@0<2A003``C00h;4P0<2a402@P>00`;4@0?3Q@03@`B00l>500=3183
00l>5009014@5P0=31803PdB01HE6P0K6al07QdR02XY;P0G5Q/04A0E008040lD0`0B4AH200h>4004
010@4P0B4Q@04Q8D018B508051@F00d04a<E018B500A4A<0410B00H52P0J6Ah010<802LV:`0F5AX0
71/P00d<4@0A41D04a8G008040lD00@051<H01@B5`0C4AH04a4F0P0B41D04@0A3a@05Q@I01/I7P04
0PL0:BL/06ARI`0E4aP071/Q02DT:P0A41D071/P01PF6P0<2Pd04Q0C01<@4P0D41405A4B00805Q0B
0P0F4Q<01`0E4A80510A014=3P0@30d04Ph?01@@4@0>2P/00P0H51D05@091@H0510A01LC500B3Pl0
4@d>018>3`0A3@h04Ph?00d92P0>2P/04`l@014=3P0=2@X04`dA00/52@0D3Q8030H:00l93@0=1`/0
4@/?00/52@02014;3`0D00d72`0C2a0050/@01@;400C2Pl04@P=0107300A20d04`X?01@;400B2@h0
40L<01483@0C31005@lC00`62P0F3Q<02`8701@:4P0B210201<8400@01@83`0E20l05@P?01D73P0F
1`h05`P?01<63@0A1P`040L<00/4200E41@04PdA00/9300N7R00BTY<01H@50804@H<00P03@8800/0
1P0F2a403`@:01D:400@1@/0304701@93`804PL=00T04@H<00l42P0>0`T03`@:01873@0@1@/06PlE
0146300>0`T00P0?10X01P0:00@02@0301H9400Y72<08A@K03<V;@804@@;00@040<:00l22@0>0@P0
3P480P0A0PL03`0?0`P03P<900h3300;10`0100700D13@071A<0:BLe01<B8@1iMhD0oo[o04]3CP0:
0Pd08aTT01H:500200h12`8050L@00<03`8;00d12@0B1@`05?ooool001_ooooo01d07BHe05YSL@2k
`m00EeeY01<F800?4Q/03`lG00T83@0?3A003`X>01<>3`0D3Q004@d>014?400<2P/02`T:00h<3@0;
2@X03@/<00l=3P0@3Pl03P`=00X82@081PL04@/=018>3`0@30d03@T:00h<3@02018@4@0I0000000B
4Q801PH602TY:@0K6AX04PdA00l:400<2Pl00`8:00P84P0E5Al06QXT07elQ00J6Al03`X@014;3`0D
3a<03``A014?500?3A8040hB00H41`0<2Pd03@/>00h<3@0200l=3P0@00h<3@0@3Q00108501<A500<
2Pd04Q0C01lM80091`X02PP;01PF6@0>30l02@L:01<A50081@L03`/<010<3@803PX;01@030P900d9
2P0C3a004Ph?00l;300;1`P030P900X82@0E5AD00`<3018B4P071`L04Q0A00l=3P0=2``030P900l;
300>2P/030H800T51@8030/900H0:BPV0=_Jf00d<c403@`:00`;2@0=30X200l>300300`;2@0>3@/0
3Pd;00803Pd;00<03@`:00/:200>3@/01@0>3@/03P0F5A<00@0001<B40030P003`h<00h=2`0;2PP0
3`h<00h=2`0G5Q@08B0N01<B400?3@h03P`=0P0;2@X0700@3Pl0518C00`:2`0@3Pl03`d>014?400B
41402PP900T7200>30d040h?00h<3@0:20T02@L800/92P0?3@h030X;00T7200=2``03`d>018@4`0=
2`h02PP;010>4@0=2`h03P`?00/9300=2`h200l=400K00d;3P0;2@`03`T;01<>3@0N6aH07Q/D01`K
40061P004A4800h?2P0D51801PD9028Q:@1@CeL05aXL00D92P062P/04A8D00l@4P0:2`d05aLI00/9
300610L06QPK00L21P0K5QX03@/>008030X=01h03P`?014?4P0B41<030X=00h<3`0=2`h02`T<00h<
3`0B41<03P`?00P62@010080:BLZ00400P0A3a8020L901<A500@3Q403`d@00L520081PX02@H=01`I
800610X04a0G00l<4`0:1`h01`@;00d:4@0E4QT200X73P0;03Le>`0X9R/00P0500X83@0>314030X?
00X83@081P/03@/@00/93P071@X00P0<2Pl0200?3A802`T>00X83@0C4AH05Q@I00l=4P0;2@h03P`A
0P0A3a@08P0@3Q<02`T>00/93P0<2Pl02PP=00/93P0@3Q<03`dB00@21`0@3Q<00@04018@5@0=2a00
3`dB00h<4@0<2Pl02`T>00`:3`0?3A802PP=010>4`0=2a003`dB01dK800S8BH03P`A01@B5`0=2a00
:RP]01dK80091``03P`A00l=4P0>314200/93P0E00d;400;21403@XC00l<5@091Pd01`@;01<@5`0=
2a003@/?00X82`091`X02`T<00l=400A3a8030X=01XH6`0:20/03P`?010>4@091`X02`T<00803@/>
00@02`T<00T72P0;1PX03@P<100?2Ph020060@D061@G010;3`0910P02`H:014<400>2@d03`X>0P0>
2@d02P0A31004`hB00h93@0>2@d03@P<00/62P0=20`03`X>00X83@0;2@h300`:3`0@00/93P091``0
3@/@00d;400?3A802PP=00@21`0>2@d030L;00h93@0A31003PT=00X52@0>2@d03@P<00`72`803@P<
00<03PT=00`73P0=20h00P0>2@l05P0=20`030L;010;3`0=2@X030P900L310050@804@d?00`72`1H
DeL03PT=018=4@0910P02@D800L21P0300804`hB00h93@0400<030L:00/7200<20T200d92P0800`7
2`0>2@d02PD900T42P0?2Q002PD;00L22@0910X200`73@0300/6300C3Q@04`hD008030L=00X04PdC
010;4@0;1P`040dB00h?4@0420T07B4R02lc=00K7b004A8D0P0<3@l02P0<30h02PX<00X:300<2Pd0
1`88014<4P0<1`d03@P>00/6300>2@l200`73@0:00l:400=20h02`H<00h93`0C3Q803@P<00T42006
0@D071LK00T420803@P<0P0>2@d200l:3P0800/7200@30d02PH701@@4@0<20T020@500`82@0=2@X2
00h:2`803`/<0`0>1@H03`0<1PH030H700`6200C3a0030T;00/9300?3A001P@701<A500=2`h02`T<
00T72P0:20/03@/>010>4@0600/9300800`:2`091`P03@/<00d;300;2@X03@/<01PF5`0610D200T7
200400P61`0>30d03P`=00h<3@803@/<00h030X;00/92P0@3Pl03P`=00P61`0;2@X03`d>00d;3009
1`X030X=01<A500E4aH0:bT/00<110H030X=00<03@/>00`:3@0;2@`00P0<2Pd0300E4aH05Q@G00h<
3`0:20/030X=00h<3`0@30h040X<00l:3P0>2@d03`X>00d;40803`dB00D03@`B00T83P0:2@l040lE
018@5P0200h<4@0@00d;400<2Pl030X?014?500E4aP0518G01<A5P0A3a@040hC01DB600d<CP0:RL^
00H32P0D4AP03``C00`940803``C01h03P/B014>5@0A3QD03PdC00/:400>3A<04A0F00l>500B4AL0
40lE014@5P0@3aD04a8H01HE6`0@3aD03@`A010?501fMGX0T8nD00d<4@0?3Q<04Q4F00l>4`0>3A80
4a8G01DD6@0B4AH04a<E018B500C4aD201DE5`0E01<C5@0F5QP05QHH01@D5P0C4aD04A4C010@4P0D
4aP0?Se202HU:P0^;C805A@I00T83@0<2a004Q4F01DD6@0A41D03`hC01HE6P0E4aP0518G00804a4F
0P0B41D00`0H5Q/03P`A01XH7@0201LE6P0;01PF6`0;2Q006APM00P7300g=S/04@lC01LE600B41<0
4a0B01DA4P0F4Q<00P0H4Q@0200B3Pl0510A01XF5`0G4a@04Ph?01@@4@0E4A80510A0P0F4Q<01@0<
20T0510A01DA4P0I5AH05A4B00804`l@0P0@30d0200;1`P03@T:018>3`0@30d030P900d72`0<1PX0
4`dA0P0D3Q805`0<1PX03PP<014;3`0S7B407aTM00l93@0C2a0050/@01<:3`0B2@h04@P=0107300A
20d04PT>01<:3`0A20d03`H;0107300>1`/03PP<00L11@0D3A402@05008040H>00<04`P@01873@0A
1@`00P0@0`X05P0C10/06@P@01X;4P0E1`h040D;01873@0B31002`H:00@21@0=30h010@603<d=P0;
1PX04`P>01052`0I3Q@06PlE00l42P0D2@l06PlE01@93`0?10X201P=4`0901<83P0A1P`03P<900d2
200?10X04PL=00T0100E2Q0040D;00803`@:00L03P<901H9400=00L050L>01hA600:00@06@dC0080
3`89100B1@`201421`0F00l31`0>0`/03@<<00/4300<1Q804@dJ028P;P24Pi<0BTYK01hM;@19@e40
7ADQ00T1300?1A003@<=00`02P0=0@/03`8<00l22`0>0@X03`8;010331Cooooo000Kooooo`0=00T@
7@0>5R806R4]01TN:P0>4Q/03Q0H00l?5P0?3Q804`hB01H@4`0F3Q0040X:018>3`0200l=3P803P`=
1`0=2``0900?2@/03PX;00l;300?2``030X;00/92P0@3Pl02PX:00h>3P0?3`l0ADE505ECE00A3100
30L=00d;400F51`0L71j07=cO@0@41X04Q4I010?5@0@2a404@/?014<4P0B3QD03P`C018?5P0:1`d0
40dC00`:3`0<2Pd03@/<00h<3@0A3a004Q4?00l=3P804Q0C00H02@P:00d;3P0=2`h02@L:00/9300=
2`h200h<3`0500`:3@0=2P`03PX;00h:2`0?2``00P0>2P/0100?2``04@d>014=3P0B3Pl2014=3P0B
03hl?@0Z:RX02`/;00`<300@41005aDF00/92P0>30d03@T:018>3`0@30d030H8018>3P0>3@/02PT7
01HE4`13@T0061LE1P0<2`T00`0>3@/03@`:00d<2P0200h=2`0700d<2P0?3P`03`h<00d<2P0<2`T0
3@`:00X91`0700d<2P0700L6100=30X030/901dL6P0;2PP02PP900`:2`0200l=3P0401<A4P0I5aP0
2PP900d;30803P`=00@03@/<00`:2`0;2@X03@/<0`0>30d0200=2``03P`=00h<3@0B414040h?00h<
3@0;2@X04@lB0P0@3Q4200`:3@0301LE600C4A@04@lB00803P`?01@03`d@00l>3@0F4@/05a@801PF
1P0`;Q`0J6YC038d700H6PP04aD702X[8@0I6QD020P:00`;3`0<30h02PX<00/<3P0?3a4030`>00T9
2`803@/>0P0<2Pd300/9300<02DS9P0920X030X=00H41`0B41<03P`?00l=400B41<02`T<01PF6@0/
:Rd04@lB0P0=2`h05`0?3A003@/>00X82`0;2@`0518E00`:3@0>30l04Q0C00d;3`0<2Pl03@/@00`:
3`0@3Q<03`dB00/93P0=2a003P`A00l=4P0A3a@040hC00d;400<2Pl03@/@00803P`A0P0<2Pl500/9
3P0600d;400<2Pl02`T>00h<4@0;2@h030X?0P0=2a001P0?3A803P`A00/93P0=2a0030X?00/93P80
2PP=00H030X?010>4`0=2a003@/@00`:3`0;2@h200`:3`0B00h<4@0E4aP04Q0E00l=4P0F51T03@/@
010>4`091``030X?00l=4P0<2Pl061HK06ARI`0V92T03@/@00T7300G5AX0<c4f100>31403`0=2a00
30X?00/94@0;21404PlH00l<4`0;20l05A8I00h<4@0=2`l030X=00T72P0H5QT05Q@G00X82`0200`:
3@0?00d;3P0?3A003P`?00P62@0?3A002`T<00T72P0=2`h02`T<00l:3P0@2`l030L;018=4@0@2`l0
2PD9008040/?00<07APL01`G6`0?2Ph00P0B3A404P0:1PT04@`@00h:3@0;1PX03@P<014<400=20`0
3`X>01@?4`0<1`/04PdA00T7300<2Pl02`T>00d;400;2@h030X?00h<4@<030X?00`02`T>00T7300=
20`03PT=018=4@0?2Ph03PT=01<>4P0<1`/040/?00/62P0?2Ph200h93@0P00h9400=20h03@P>00h9
3`0@2`l050lC010;3`0g<c@05A4B00@00@0C3a002@D701dH70060@D03@P<01<>4P0]:2`04PdA00D1
100C3Q806aHJ00h:3@0@2`l030P:00l;300F4Q<030P9010<3@0F4AD02`H:00`72`0;1P`200h93`0W
00`73P0>2A003PT?014<4P0>2@l03@P>014<4P0;1P`04`hD00T42P0C3Q@04@`B00`93P0?41805QXK
05eQHP3Ri^H0^ko003/l?P0B4aD0414C00d=3`0:2P`02`X<00d;3P0>2@l040/A024L8P0910X05Q4G
00T52P0;1P`03@P>00h93`0<1`d02`H<00d83P0=20`02`H:00803@P<00P02PD900h93@0;1PX030L;
00d8300?2Ph02`H:00h93@H03PX;00L03`/<00h:2`0?2``030P901<?400X92@03`L6008040P60100
3PP800l92P0?2@/02PL700l<3P0;2P`04Q0E00h<4@0920`03`d@00h<3`0<2Pd03@/>00l=400@3Q40
4@lB0P0;2@`01@081PT03P`?00P62@0=2``03`d>00803P`=00T030X;01XH6@0X9RL02PT900P61`0<
2P/02PP9010>3`0?3@h00P0<2P/0100=2``030X;00X82@0<2P/200d;30803P`=01<03`d>018@4`09
1`X040hA00T72P0G5AP02@L:00d;3P0E4aH07Q`O00l=400C4A@02`T<00l=40081PT04Q0C02`Z;@1:
B4/03`d@008040hA01@03@/>00X82`0;2@`040`?01@>4P0A31003@P=018=4`0A3a@03`dC00D32@0<
2a409bH]01PG7`0=31@03`hD00h<4@0<2Pl03P`A00l=4P803@/@0P0;2@h02@0C4AH03@/@00/93P0C
4AL0AT=:03@a>00<2Q005A8I00d:4@0200l<4`0700h;4P0?31<03``C014>5@0Z:Bl0AdI<01<B6002
00d<4P0=010?5@0A41H03@`B00h=4`0?3Q@02`X@00h=4`0E51T02`X?01/J7`0T8bP04A0E00h=4P04
018A5P07014@5@0@3a@04A4C01@D5P0?3a405aLI01@D5P0200l?4@0>014A4`0;2`d05QHH014A4`0@
41805A@I02<R9`0D4aP04A0E01lN8`0F5AX04A0E01DD6@0G5Q/201<B5`0800h=4P0E4aP061HK00P6
2`0D4QL040hC01LE6P0d<SL201DC600301LE6P0@3Q<06ALL00804a8H00/061LL01dL8@0J61`04@lB
01HD5`0C41805a<D01@@4@0I4aD04Pd>01@@4@0301DA4P0601@@4@0C3a005A4B01LC500B3Pl040`=
0P0C3a001P0B3Pl05a<D00X61`0B3Pl05Q8C00l;30804`l@0P0B3Pl2014=3P0600l93@0@2Ph04@/?
014;3`0?2@d03PP<0P0A2`l02P0C3A405@lC00l93@0B31003`T=01@>4P0?2@d03PP<01D?4`0@2Ph2
00l93@0:010:3P0K5AT040X>01<<4P0>1`h02`@:01<;400I41D050/@014730804`P>01@050P>01@7
3P0D1a0050D=01X:4@0P4AP06PdD0146300B20d050dA00H11@0C3a<0?3/n0:f][`1VIfT05A0D01D:
400@1P/0714G00/21PL04PL=1P0A1P`201873@040146300?10X03`@:00l42P804PD<00@03`8900h1
200>0@P030460P0?0PT20185300J01442`0?0PT04@8701421`0?0`P03P<:00h3300;10`02@<=00T5
4P1>C5X0a<;>06=SL`020@l03`TF00d54@0E3aP06A4L00/4300=1Pd050/D00d42`0>0`/03@8901<6
3`0B1@dDooooo`006oooool03P031a802Q0J00`@6@0<41T03a4H00h?500?3Q@03`hB00d;3P0=2@X0
3PT9014;2`0B3Pl040h?0`0?3@h00`0>30d030X;00`:2`0400`:2`0400l92`0?2``03`/<00l;3080
30X;00<02PP901<C4`0C4a<00P0@41005P0?3@h03@P901LB5P091``01`H<030`>00N7RH03PhF010?
5`0>3A<03`X?00l93@0?2Ph020@>00402@091Pl02PL?00h;4P0=2a003`d@00l=3P0@3Pl2014@3P07
01@B4`0h=ST0@T1301TG6P0B41<07A/N01@B5@0300`:3@0:00d;3P0>30l040d?010<3@0?2``03PX;
00l;300@30d04@d>010<3@<04@d>018040`=02DS900J6QX04A4A00P8200000004a4B01LE5P0E4a@0
3`/<018>3`091@H0100000`8200?3P`06QTG01LF50071P@=00d<2P06018A3`0<2`T030/900`;2@0;
2PP06QTG0`0A40h200l>300D00h=2`0@3`d01@@200h=2`0?3P`03Pd;00/:20081PL03@/<01DC500D
4Q<030X;00H41@091`P020H700X82@0>30d03`d>00/92P0>30d300l=3P0@00h<3@0=2``00@0000l=
3P091`P05A<D00h<3@0:20T03P`?00l=400A3a803`d@00h<3`0F51L04a4D014?4P803P`?01P03`d@
00l>30050@005aD2038b6P2MWH<0mOOI0<O:Z`1:CC4051L201<F1@0<3PD0410>01HF5P0<30h030X=
00d;3P0?3A003@/>00/9300:20/02`T<00`:3@0=2`h200h<3`0L010>4@050`H04Q0C018@4`0C4A@0
1085018@4`0@3Q404@lB00/9300F51L09R@W00h<3@0<2P/03@/<00l=3P0>30d030X;00/92P0C4A80
2PP900h<3@0100001P@6010>4@0F51L03@/>00T72P803@/>00H02@L:00d;3P0B41<01`D800D31P0=
2`l200X83@0401<A5P0F51T03`dB00X83@8030X?0`0;2@h0:P0<2Pl02`T>00`:3`0@3Q<030X?00/9
3P0<2Pl02`T>00X83@0<2Pl03@/@00X83@0<2Pl02`T>00X83@0;2@h030X?00l=4P2ASi@0CD]@00/9
3P081P/01@<800`:3`0;2@h04@lD018@5@0D4QL06QPM01<A5P0U8bP04a4F00P62`0>31403`dB018@
5@0I5a`00`4601@B5`0=2a001P@900l=4P8030X?0P0=2a00300<2Pl02`T>00/84@0A3QL00P080040
1@050`T030T@00h<4@0<2Ph03@/>00X82`806QPK0P0@3Q405`0=2`h02PP;00/9300A3a802`T<00X8
2`071@P02@L:00l=400<2Pd05a8F00l:3P0300803@P<01HA5@0E41@02PD900`72`0G4QH05A0D00X5
2@0;1PX04PdA008030L;01003PT=059=D@070PH03@P<00/62P0D3a<07aXN00h93@0<1`/02@L<00h<
4@0@3Q<01@<8010>4`091``030X?0`0=2a001`0<2Pl02`T>00/62P0>2@d04PdA00l:3P0;1PX00P0>
2@d01`0E41@01P4500`72`0B3A402PD900d83`0>2@l00P0?2Q003P0>2@d05a8F00X52@0?2``00`00
00`82@0@30d06A@G02TT:00=20`030L;00H11@0J5AT03`X>0P0@2`l02@0C3Q802PD900/62P0D3a80
2PH700l;300<20T02@D600h93@0200`72`0S00/6300<1`d03PT?00d83`0910/0100500L2200<1`d0
3@P>00`73@0:1@/04PdC00X52`0?2Q003PT?00h;400<30h04a@F09fNX03`lO<0hnCV02`/;P0@4180
3`d@00`:3@0:20/030L;00d8300=20h020<9014<4P0910X06A@J00P32@0<1`d00P0=20h03`0:1@/0
2@@:00/6300D3a<03@P<00`72`0A31003`X>00/62P060@D020<702HQ9@0C3Q802`H:00`72`0600h:
2`0I00l;300=2@X03@T:00d92P0B3Pl071PG018:200B2PL040P500h91P0=1`H030H801hJ6`060`L0
0@0401DB6@081P`06QPM00T72P0;2@`03@/>00l=400D4QD05Q@G00@21@0200L5200400H41`0:20/0
3@/>00d;30801`D60P0?3@h0200J61T0<c4b00D310091`P03`d>00L51P0@3Pl030X;0P0:20T0100<
2P/02PP900T7200>30d300d;308030X;01801@<600`:3@030@@05A<F00800`0;2@`030X=01DC5P0M
6ah04Q0C00l=40091`X020H9018@4`0G5AP0SH^>0<K4a`0U8bH200h<3`0@00`:3@0;2@`03@/>00l;
400A2Q4040/A00d83P0@2a403``C00/83`0M6R406QTQ0860R01OGVH0000900X83`803`dB00l03P`A
00`:3`0<2Pl03`dB00/93P0?3A801P@901XH7@0g=CX0:2D[010=50050PT0514H00h;4P071@/00P0@
3A@05P0?31<040dD010=500B3aH0=SDk06UXKP0=31802`X@00H52`0?3Q@03@`B00/:400>3A<04A0F
00l>500A41H04a8G00P7300F5AX09B@Y01LF6`0<2a02010?50<04Q4F02d04A0E00h?4@0A4Q@03a0B
02//;P0a<S@051DG00d>400D5AL05AHH01@E5`0?41803PlA00L830061`/07AhR01XK7`14ADT06AXN
00@52@0C51P02P/?014B5P0?41@06QTN00d;400;2@h0928W01TG700H5Q/04Q0E01HD6@0?3A804Q0E
01@B5`0E4aP061HK018A5`0E51T051<H014@5@0C4QH06ALJ01<A500F4aD00P0@30d00`0H4Q@01P02
014=3P03018>3`04014=3P0@30d04Ph?01HB4`804Ph?00L04`l@014=3P0?2``04`l@00h:2`0C3a00
5A4B00804Ph?0P0A3@h2010<3@0300l;300?2@d040X>008040X>0P0?2@d0600A2`l03`T=01D?4`0A
2`l03@L;00/52@0L5QX0100201<=4@0O6Ad01002018<400:10P05a4E00L21@0500<01P0401/D6P0F
3aH04@XA00l7300?1PT03PD8010620804PL;01L04`L=01<63`0C1Q004PD=01<63@0D1`h04PD<00l4
2P0>1@X04PX?00H11@080`L0C4Y=0>7OhP29QhX02@@700h32@0?1@X04@H<00L00P0B1`d040D;0146
300201873@0301052`0>0`T040D;00L040D;0P0?10X200h32@0800l22@0>0@P03P4800h1200?0PT0
40<:00l22@0@0`X201442`8040<:0P0?0`L05P0?0PT03P<900h3300;10`01P0900d74`0>2QP0:RHd
00d<60081180100700l73`0=1Ph00`05010;4P0;1P`0<2/a00d4300<0@L0200200`01@0H2@hDoooo
o`006oooool0300:3A@051LN00hA600<3a@04A8F00X;3`0@3a@04a8E014?4P0=2``03PX:018>3@80
40h?100?3@h600`:2`0400l92`0?2``040`=010<3@8030X;01T03`d>01@D500:2PX03@d=00X:2P0A
3a0050lA00h:2`0>30l020L<01/L8@051P/030`C00h=4`0=31403PT<00l92`0?2Ph08A`W014>6@0<
2A@02`PB01DB6@081@`03`dA00803`d>0P0?3P`01@0;2@X05aDH01TG6P0510H020H900802`T<00X0
4Q0C010>4@0?3A003`d@010>4@0B3a404@d>00l;300>2P/03`/<0P0A3@h05`0@30d04@d>014=3P0A
3@h040`=00X82@010@403`l?010@400410@03P`=00`:2`0C4A804`l@00d92P0@30d04@/=014=3@0>
3@/07ahL03<b<00B4@l040l=00H02`X800<030/900d<2P0>3@/00P0<2`T01`0>3@/03`h<00P71@0>
3@/04Q4?010?3@0V9B<00P0B4@l0300A40h03`h<00h=2`0>3@/02`X800X91`0?3P`03@`:00`;2@0>
3@/02`T:00`:2`803P`=0P0=2``01P0@3Pl02`T:00`:2`0B41404a4B00`:2`803P`=00X03`d>00h<
3@0>30d030X;01<A4P0Q7b000`42014?400>30d03`d>0P0<2Pd05P0@3Q403`d@00`:3@0C4A@03@/>
00`:3@0:20/02`T<00d;3P0?3P`061@9030^6`1IFD40aLFY0?cnh03>d[40?d8U018F000A50<03@h6
00h>3P0?3a4200d;3P803P`?00D03@/>00`:3@0;2@`02`T<00`:3@0300d;3P0<00T72P040PD0518E
00X82`0=2`h02PP;01<A500A3a8040hA00P62@091`X04Q0C0P0<2P/05P0=2``03P`=00h<3@0>30d0
6QPI0040000>30d04a4B01DC500B41804Q0C01HD5`0>30l02PP;00d;3P0@3Q4020H900L5200<2Pd0
108500h<3`0G5AT200`:3`04010>4`0B41D03@/@00/93P<030X?0`0;2@h01@0:20d030X?010>4`0<
2Pl02PP=00803P`A00D030X?010>4`0B41D03@/@00`:3`0300/93P0M00`:3`0>3140O7Yo03dk@007
1@X05A<H018@5@0:20d040hC018@5@0?3A803@/@014?500=2a00;bdb01hL8@0?3A8040hC00h<4@0<
2Pl02@L<00P62`0Y9b`09bDZ01HD6@0=2a002`T>00`:3`0=2a000P0<2Pl0800;2@h01`@=028O:00_
;3D09B8Y014>5@0200H05A<H00l=4@0>30l01P@700X82`0610L040hA00`:3@0;2@`02PP;00T72P0<
2Pd03P`?00/9300:20/03@/>00l=400:20/02PD9018=4@0<1`/050lC018=4@0910P04PdA0P0>2@d0
:@0<1`/02`H:01<>4P0A31003`/>01@?4`0M6A`0]K2d02hY;@0=20`02PD9014<400K5QX030L;00d8
300=2a004@lD00T7300G5AX0<S0e00L52P0=2a003`dB00h<4@0=2a002`T>00`:3`0<1`/03@P<010;
3`0=20`02`H:00l:3P0D3a<00`0201LB5P0R7B404`hB00<00P0=20l03`X@008040/A01/03PT=00/6
2P03008040`=01@@4@0L61T02`L801PD5P0U82@03PT=00d8300300803`X>01@?4`0E41@00`0200T4
200?2Ph00`0200T61`060P<02PH700d92P091@H03PT=00l:3P0=20`00P0;1P`02P0=20h03PT@00h9
3`0>2@l04@`B00l:400<1`d03`X@010;4@0?2Q0200/6300;00T42P0>2Q0061PJ02<T9P2JVid0V9RJ
07AdMP0L6ah03`d@00h<3`0<2@`00P0;1PX03`0<1`/03@P>00L2200<1`d020<901D@5P0910X02`H<
00`73@0>2@l03@P>00h93`0A31806QDI018=4@0200h93@8030L;00H02`H:00P31`0]:2`05Q4E00l:
3P0;1PX600h:2`0C00L3100=2@X04`l@01<?400810D00`0001491`0A2@H040P500h91P0=20H03@L7
00/62P0B3a<04Q0E00401@0D4AP01@8900`:3`0200d;3P0300h<3`0@3Q4040hA008040hA01P03@/>
00l=40091`X03@/>018@4@081PL01`D600`:2`050`@030X;00@20`0E4a@04Q0A00`:2`091`P020H7
00`:2`0:20T02`T:00d;300;2@X02PP900l=3P0>30d200d;300800`:2`0;2@X04@lB00/9300200<0
5aDH00<1100<2Pd200X82`0:00d;3P091`X030X=00l=400H5QT02@L:00X82`0Q7b80:BLZ00H51`<0
3@/>00D030X=00h<3`0?2a0040T@00l:400200h93`803P/B01P01@8900`;4`0Z:C408b8Z018@6`0<
2Q403`dB014?500>31402PP=00`:3`0?3A801`D:01PF6`0?3A8020H;01HD6@0;20h04PlF01LD6`0A
3QD04a0G01DB6@0>2a8300d:4@0D00h;4P0@3A@06aXP00P73@0A41H04a8H00l>500E51X03`hD00d<
4P0@3aD04A0F00d<4P0<2a4040lD00/:3`0J6Ah09RDZ01XI7P0>3A8200l>4`09014@5@0B4AH04Q4F
018A5P0=3Q0051DG00l@4P0V9bT0;Rla008051DG00X030d?01`M7`0>3a40414C01@E5`0C51P05QLK
04]<D00S92P0QXN;0P0E5QX07@0?41@04Q<G02@U:@0H6Ad0Bda@02PV:`0>31405A<H01LE6P0A3a@0
3`dB018@5@0F51T04a4F018@5@0G5AX05Q@I00d<4P0C4QP05QDJ01DD6@0B4AD04Q0C01/I700?30h0
5a<D01`H6@0N61X050h@00804@d>0P0B3Pl0100A3@h040`=018>3`0F4Q<201@@4@0401DA4P0A3@h0
4Ph?00l;30803@T:00<04@d>01HB4`0A3@h00`0@30d200l;30D040X>02803`T=01D?4`0>20`05Q0D
01LA5@0C3A403PP<01<=4@0G4AD04@/?00l93@0C3A404@/?01<=4@0400805@lC020J7P0A2`l03@H>
018;4`0A2Q4040P=00l62@0A20T04PP90147200A1PX04PH<01853P0B1@l05@PA01@93`0C1Pd04@H<
0P0A20d02`0D31404P`@01D@500J5AT0BdU<02lZ;P0>1``04@H<01873@0L4AL07A8H008040D;00D0
4@H<01873@0B1`d040D;00d2200600l42P0300h32@0?10X03`@:00803`@:00L03P<900d01`0;00D0
3@4700h1200=00L04PD<00H040<:0P0?0`L00`0?0PT03P<900h32P0200d3300A00d5400400L0208<
00L130090`d08QPQ00H01P0=1Ph05a8I00/7300910X02PD;01D@500D2`h05P/A00/00P0:00005?oo
ool001_ooooo00`02`/;01@D500@41003@h?00l?3`092@X03@d>018B4P0C4a<0410@00d<300<2P/2
00h<3@@03`d>1P0=2``0100@2P`040`=010<3@0@30d200d;300:00P61`0E5AD0410@00h>3P0<30`0
40h>014<2`0I5QD0=C<e010>4@<02``@01X03@d@00d=3P0>2P/03`X8010<3@1IE600E51N00H33`0A
3QT03P/C00d:4@0>31003@/=00d;300=30X030/900h<300:20/020H900h<3`0=2`h02`T<014?4P0D
4QD04@lB00h<3`8030X=00D03``>014=3P0?2``03PX;00l;3002014=3P0700l;300@30d04@d>010<
3@0?2``03@/<00/;2`0300d=3@0=00h<3@0@3Pl0;bd^02l[;00@30d04`l@01@>400C3`l040l=00T8
1P0D4a401@@300h=2`0600`;2@0;00/:200>3@/040l=00`;2@0;2PP03Pd;010?3@0;2PP03`h<00h=
2`061@<00`0@3`d00`0?3P`03Pd;00d<2P0200`;2@0501`K6@0B4@l02@P600`;2@0=30X00P0=2``0
1`0<2P/03P`=00h<3@0=2``05A<D00l=3P0=2``00P0@3Pl00`0:20T02`T:00`:2`0300d;300900`:
2`0P7Ql0:2HW00X82@0B41403@/<00`:2`0=2`h02`T<00803@/>01D02`T<00l=400=2`h03@/>00h<
3`0@3Q40518E01LF500R7AH081d?03Lf8@1BDST0YZR905eQ@@0Q90X041<001<E2@0>3``03PdD00/9
400>2Pl00P0A31001@0@2`l03@/>00d;3P0>30l03@/>008030X=0P0;2@`03@0@3Q403P`?00`:3@0=
30h01`D800d;3P091`X03@/>010>4@0>30l030X=00d;3P0;2@X00`0=2``03P0>30d03`d>05]IFP0?
3@h06QPI00D4100L6Q/04@lA010>4@0?3A003P`?014?4P0?3A003@/>0P0:20/02P0?3A002@L:014?
4P0H5QX040hC00l=4P0;2@h02@L<00X83@0=2a0200h<4@0300d;400<2Pl02`T>00803@/@00D03P`A
01<A5P0>31403@/@010>4`0200h<4@03010>4`0A3a@03P`A00D030X?01/03@/@00h<4@0@3Q<03P`A
00`:3`0=2a0030X?01@B5`0B41D02`T>00T7300<2Pl03P`A010>4`0>314030X?00d;400<2Pl03@/@
014?500<2Pl02`T>00X83@091``03@/@00/93P0<2Pl00`0>31407`0=2a003@XC018?600S82T07Q/R
00`9400C41L03P`A00/93@0C4A@03P`?00l=400;2@`03`d@00L5200<2Pd040hA00`:3@0>30l03@/>
00X82`0=2`h03P`?00/930071@P03@P<010;3`0400<04`lB01`H6`0B3A400P0>2@d02`0=20`02`H:
00X52@0>2@d02PD9018>4@0;1`X04PhA018=4@0D3a<040/?00802`H:00@03PT=00T4200B3A402@L<
0P0@3Q<05`0F51T0;B/`01DC600;2@h030X?00X83@081P/02`T>00l=4P0>2@d03@P<00l:3P0<1`/0
2`H:010;3`0>2@d02@D800d9300W8RH0:2<W01@?4`0>2A003`X@008040/A01D03@P<010;3`0<1`/0
40`=00l;300F4Q<02PH7014<3`0<1`/01P4500h93@0<1`/040/?024L800[9RX02PD900/72P0F4AD0
20@701<?4@0;1`P00P0=2@X0200;1`P03`X>00h93@0>2@d030L=00d83P0?2Q003PT@0P0>2@l04@0A
318040`A00d93P0@2a404`hD00/6300B3A<030L=00L2200=2@l03`hA00P72P0N7Al040hA01HD5`0C
3a<03`X>00803PT=00L03PP<00d72`0=1`/030L=00h93`0@2a402@@:00<030L=0P0=20h200`73@04
014<4P0D3a<040/?00d830802@@800L05Q4E01TD60080`L04`hB00@00`0<1`/03`X>00H03PX;01D0
3@T:00/7200810D02`L8014=3P0A3@`03`L400l80`0@20D03PT6010:2@0@2PX040/?014=4P29Qh`0
<2hd010>5@0:1`h030X?00`:3@0=2`h00P0<2Pd0100;2@`01@@601`K7@091`X200`:3@0E010>4@0=
2``02@L800`:2`0D4Q<02PP900h<3@0E4a@03@/<00`:2`0=2``02PP900/92P0=2``02`T:00`:2`0?
3@h03P`=00d;300?3@h03P`=00803@/<0P0<2P/02`15@dH04a4D00P62@0920X04a4D010>4@0?3A00
3@/>00h<3`0=2`h01P@700<03P`?00D040hA00X82`0<2Pd040hA00`:3@0200d;3P0P00`:3@0?3A00
3`/@00l83`0A31804@`C00h9400>2a804a0H01XG800=31@03`hG014?6P0>3AL05aDM010>4`0A3a@0
3`dB00`:3`0=2a00928W01<A5P081`/04@lD010>4`0E4aP03@X@00d:4@0A3QD02PL>00h;4P0A3QD2
00l<4`0<00h;4P0?31<03``C014>5@0:2@l04Q4G00X93`0L6b403PdC00l>500@3aD03@`B0P0?3Q@0
200<2a403PdC010?500>3A8040lD00l>4`0=31404a8G0P0@3a@4018A5P03010A4`0H6A/0414C00<0
4Q<E02/03a0B03/l?P0S92H06Q/M01DF600?41804A8F01@E6@0@4AD03a0D01PI7@0?41@03@hB014B
5P0=3Q806Q/O01DF6P0e=SX05aDJ01DC600U8bP0DDmD02h/<@0G5AX0518G01LE6P0A3a@040hC01HD
6@0H5Q/051<I014@5P0@3a@04Q4F01<A5@0A3a806ALJ018?4@0N6Q/04`l@01D?4@0I4aD04`l@00<0
510A0P0C3a003@0@30d04Ph?014=3P0D41405A4B010<3@0C3a005A4B01lK700D41402PH7010<3@0B
3Pl00P0A3@h2010<3@0300l;300A2`l040X>008040X>0P0A2`l05`0E3a<02P@8014;3`0K5AT06A<G
00h830060@D05Q4E01HB5@0:1@T05A0D00h:3@1=B4`040/?01LB5P0B3A402PD900l9400@2A404``C
01@<4@0A20/04@P900804PP901P04PL;01<73@0C1Pl04`DA01D94P0B2`l04@L<01483@0B2@h04@X>
010:3P0>20`03`T=00d72`0C3A4040P=00h52P0A1P`04@L<00/21P0J3aD040H;0146300@1@/30146
30L040D;00<03P<900l42P0A1P`00P0A1P`00`0@1@/04PD<00l22@020185300300h2200G2Q404@@;
00@040<:00<04@@;00l22@0?0PT00P0?0PT00`0?0`T03P<:00`2200200l4300?00`12@0G2a<03`@<
00d52`0?20h04@/@028M8P1SHF@020L907UgN@2KV9P04@P900d41P0A10H04@8501Cooooo000Koooo
o`0=00l;200>2`P040l;00l>300@3``05QDC00`<2P0<30/03@d=00d?3P0<3Pd02PX:00/92P0200`:
2`0300d;300>30d03P`=00H03P`=00L04@/=010<3@0A3@h04@d>00h<3@0=2``05Q@E00802`/;0240
0@4100d=3@071P@02@D201TE4P0a<2h02`X;00T:300H6A/02``>00h>400=3@d03`/9010;200A3@h0
4PdJ00d95`0?2aT01P<>00l<5@060`X030X>00d;3P0=2``03@`:00d<200>30`04@lB01<A500?3A00
30X=00h<3`0@3Q400P0?3A001@0>30l030X=00/9300=2P`03`/<00<03PX;100?2``05@0@30d03`/<
00l;300>30d04Q8B00`<300C4a<071`L00h<3@030P805Q@E01PD5@0@30d04Ph?01<=3`0>2PX01@@2
014@3P0B4@l03@`:00l>300600d<2P0<00X91`0>3@/040l=00/:200:2@L03Pd;00/:200<2`T03`h<
00h=2`0=30X030/90`0>3@/300d<2P0>01@C4@0P7ad04a8@010?3@0;2PP04A0>00l=3P0>30d03`d>
014?400>30d01`D600l=3P0=2``200X82@802`T:00@02@L800/92P0=2``03P`=0P0?3@h00`040P<0
2@L800`:2`0200l=3P0300h<3@0D4QD03@/>00803@/>00<02`T<00l=400<2Pd00P0<2Pd0400=2`h0
40hA01<A4P0C3PX05Q<9030_7@1jNF@0DU@j03`o900D5@804A<601PI4`0E5AP04a4N00X74P0>2@h2
014<40803PT=00<040/?00`:3@0<2Pd00P0<2Pd200/;3@0700X82`091`X020H900d;3P0J61/04@lB
010>4@0300l=400C00/930071@P02`T:00h<3@0=2``02`T:00`:2`0>30d05aDF00<10P0B41401P@5
00X82@081PP030X=00X82`0<2Pd04a4D00l=400200L5200600X82`0<2Pd02PP;00L5200:20`03@/@
0P0<2Pl200d;400700h<4@0?3A803P`A00d;400<2Pl02`T>00`:3`0200T7300500`:3`091``02@L<
00/93P0<2Pl00P0=2a001@0;2@h030X?00`:3`0<2Pl03@/@00<030X?00X01@<800/93P0?3A805A<H
01TG70091``040hC00h<4@0=2a003P`A0P0?3A80100>314040hC00l=4P0=2a0200`:3`04010>4`0B
41D02@L<00h<4@8040hC00<030X?00d;400?3A800`0?3A805@0T8BX05Q<L00l<5@0;20l01`@;00h;
4P0@3Q<020H:010>4@091`X02PP;00/9300B41<02`T<00`:3@081PT01P@701LE600=2`h02@L:00`:
3@0200/9300801@B5@0500@02`H:01dH701;ATX0@Se100D0100?2Ph201@?4`03018=4@0?2Ph030L;
00804@`@02<02`H:00T4200@2`l03`X>010;3`0<1`/03`X>01D@500;1PX04@`@00/93P0>314040hC
00@31`0100@01`D:00d;400>31403@/@00l=4P0J61d08AlT00d8300@2`l050lC00l:3P0:1@T03@P<
00`72`0I51P00`0200P41`0G4QH03`X>010;4P0200h93`0?00d83P0=20`03PT=00<00P0E4A80=S8c
03hj>`0G4a@020@600`72`0@2`l03PT=014<400:1@T01@4400803PT=01804PdA01<>4P0=20`04`hA
00X61`0<20T020@5014=3P0F4AD030L;00d8300=20h03`X@010;4@0>2A003`XA018=4`0H4aT202hY
;`0701PC6@0>2Pl03PT?024L8P0F4AL03PT?018=4`02014<400401LB5P0>2@d05a8F00X420803`T=
0P0A20d20107300=00`5300?2Q0040/A00h93`0910X03PT?00d83P0>2@l030L=00X52`0;1P`03`X@
00l:3P0200/62P803@P<00L05A0D00/62P0:1@T04PdA01LB5P0?2Ph01`8600H03PX;00<01P8300h:
2`0=2@X00P0<20T03`050@0040P501090`0@20D03PT600h91`0>20P02`H:00X72`0d<SL00@0500`:
4P091Pd02PP=00`:3@0300d;3P0800/9300G5AP0Kfe`020N8@0100803`d@00@21@0A3a0200d;300<
010>3`0610D030X;00d;300@3Pl05A<D00X82@050`@04Q0A00`:2`0:20T02`T:0P0>30d200`:2`<0
3@/<0P0>30d01`0?3A0020H900d;3P0<2Pd0518E00T72P0<2Pd00P0;2@`07@0?3A000`4400l=400=
2`h05A<F00L6200D4QD07A/N00/9300=2`h03P`?00d;3P0<2Pd03P`?00l;400?20l04PdC01D@5P0>
2A003P/D00l<5@0P7BH05Q@O00H53`0200/0?Sa705]IH00@3Q<03P`A00803`dB00d03P`A01<A5P0B
41D03`dB00T730030@H03@/@01LE6`0:1`h01`@;01DB6@0H5A`05Q<J008040dD01H03``C010=500@
3A@04PlF00X93`0>3A<040lE05ACF@040`T06aXP01HE6`0B4AL040lE00l>500>3A<04Q4G00`;400?
3Q<051<H01DD6@0D4aP030/@0P0A41D2018A5P0Q014@5@0@3a@03a0B00dA4P0>4Q<06QhO01@H6@0I
7Ah0310A05aPH@0h?3d05a/L00`@4@0C5aP041@G00hB5@062Pd05ATL01TM800420/02`lB01PL7`0@
51L03a<F01DI700@4AD06QTN01<A5P0=2a008AlT01LE6P0:20d05Q@I00<04Q0E01004a4F01DC600D
4aT051<H014@5@0?3Q<04@lC01DC5P0:20/06aPJ00`82@0h=3D0DD]=020J700C3a00510A0P0E4A82
01<?400=01DA4P0D41404Ph?01TE5P0L61T05a<D014=3P0D4140:2@U01HB4`070`@04@d>01<?4002
018>3`804@d>00<040`=018<400@2Ph00P0@2Ph01@0A2`l04P`@018<400A2`l030H:00804`dA00d0
5A0D00<00P19A4P0GUUM014<400Z9BT030L;01XE6@0400<0K6M[09:=T@0U82@040XA00804@XB01d0
4PX?0189300@1`P04@P601882@0B1`/04`L=01<63`0C1A804@P@00l:3P0@2Ph03`T=00d72`0>20`0
4PX?01XA5P0C2Pl030<80107300F2a40714G00/01P0>1@T0?c@j06YOI@0E31004PL=014630020105
2`0301873@0E2Q0040D;00D040D;00`03P<900l42P0C20h050T?01<83P0A1P`03@0700X0100A10/0
4`H=01032P0O4QT201442`<03`8900@04@@;00h32`0>0`/03P<90`0?0PT04P0<00H0408701<42@0>
00@050D:01862P07008030D9020L7@0?2``0;2/[00d=2`13@d40KV]Z01/C4@09000040D501<51ACo
oooo000Kooooo`0>014=2P081P<02`X800/:200:2@L061LE010@3P0;2`/02PX:00`>3@0?4A003@d=
00X82@0;2@X200`:2`803@/<1P0?3@h2010<3@0O00l=3P0@3@h03P`=00d;300>30d01P@501@D500?
3@h06ALH00D3100>2PT03PX701`K6@0=30d02PX<00/<3P0=3@l03Ph>00l=3P0>30T040`9018>3`09
1`l06aPS01<@6@0A3QL00@0501DB6@0=2`l03@/<00h<3@0200l>300C00d;2`0B41<04@lB00T72P0B
41<04@lB00X82`0>30l03`d@014?4P0@3Q403`d@00h;3@0=2@X03PX;00l;300>2P/03@T:00h:2`02
00l;300E010<3@0?2``03`/<00X7200@410030`<00L71`0@41003`d>00h<3@0:20T02@D601<?400=
2@X01`<4018@3`020@003Pd<010?3@0>3@/020L500H02`X800D02PT700h=2`0@3`d02`X800T81P02
00h=2`05010?3@0=30X02`X800d<2P071P@00P0=30X400h=2`0F00/:200?3P`020L600l>30020@00
3`h<018@4@0?3@h02`T:00h<3@0@3Pl03P`=00`:2`0=2``02`T:00X82@0<2P/03`d>00T7200;2@X0
3P`=010>3`804@l@00<05A<D00d;300C4A800P0=2``00`0>30l061HI00l=4P0200d;3P0N00d;3@0@
3Pl040h?00l=3P0?2``040`=018>3`0C3a004Ph;01DB301PH5@0h^3C0;>dXP0a<R0051@600h?1`0D
518061LL01TG900=2aH030T>010>4@0?3A003@X<00h:2`0@30d030P900d92P0<2Pd03PX>0P0>30l0
3`0A3a8020H;00L5200E4aL0IF=X06e[KP0?3A402`T>00X82`0>31003`dB00`:3@0<2P`03P`=00d;
300200/92P0700h<3@0:20T04@l@00X82@0>30d01@<4010>400200/9300A00`:3@0A3a803`d@00T7
2P0<2Pd03@/>00`:3@0@3Q403P`?00`83@0<1`d02PD;018=4`0G4QP04`hD010;4@0A31800P0@2a40
1`0>2@l03@P>00h;400<2Pl02`T>00h<4@0;2@h00`0<2Pl00`0?3A803@/@00X83@0300`:3`803@/@
00D030X?00/93P081P/03P`A014?500200T73007018@5@0>314030X?00h<4@0@3Q<03P`A00X83@02
00d;400700/93P0=2a0040hC00h<4@030@H03@/@00X83@02010>4`0300/93P0=2a003P`A00@040hC
01h06QLN01DB6P081@`020D<00h;4P081@`0518G00T72`0>30l02@L:00d;3P0B41<02@L:00X82`0?
3A002PP;01<A500f=3L04@lB00`:3@0=2`h030X=014?4P0S7R8030L;01<>4P0300803@P<01XF6@0F
4AD2014<400@00/62P0910P030L;00h93@080`L03@P<01<>4P0A310040/?018=4@0?2Ph030L;01D@
500P6al03`X>00h93@803@/@00<01`D:01DC600A3a@00P091``02@0;2@h02PP=00l=4P0N7240:2H[
00/62P0C3Q806A@H01<>4P0200T4200:00/62P0@2`l03@P<00`72`0?2Ph03@P<014<4P0>2@l03@P>
00`73@803@P<01X01P4501/F6P0D41802PH700T4200@2`l030L;01<>4P0>2@d061<G010;3`0=20`0
50lC00d8300910P030L;00X52@0>2@d03@T:014<400>2@`081/O02PS9`0C3Q803@P<00d83P8040/A
01<03PT@00P32P0F4AL091lV01D@5P0300@02PD;01D@5P080`T081/Q01@?5@0:1@/030L<01TD6006
0@D03PT=01D@500>2@d04@/?00803`T=00/040X>01893P0A20d040L<00/42`0=20h03PT?014<4P0;
1P`03PT?00`73@0300d83P0300l:400F4AH04`hB008030L;01L04@`@00l:3P0=20`030L;010;3`0<
20/05A0D00l:3P0@30d03PX;00h:2P0>2PT03PX;00h:2P0>2PT01`<400h:2P0:1PD02@D600l;2`0>
2PT040/7014;1@0200h91@0900d81@0<1PH01`<401<@4P0@3Q40518G018@5@081P/03@/>00803`d@
01/03P`?00`:3@091`P020H901lM7P0<2P/05A<D00P61`0B41402PT700H50`071P@02`X800L6100A
3a002@L800l=3P0610D03@/<00l=3P0610D02PP900T7200:20T03@/<00`:2`0;2@X00P0<2P/05P0=
2``03P`=00h<3@0?3@h02@L:018@4`0<2Pd02PP;00/930091`X030X=00L520050`H040hA00d;3P0P
7R402@L:00/9300C4A@02PP;00<1100@3Q4200h<3`0<00`:3@0;2@`03@/>00h;3`0>2@l04`hD01HA
5`0>2A003``C01LD6`040@P01@@<0P0?3QH0500E51`04a4G00l=4P0=2a003`dB014?500?3A802PP=
014?500?3A8040hC01HD6@0>2a802PL>01@A600C41L03``C010=500:1`h03P/B0`0=2Q40500>2a80
40dD00h=4`0510X051<I00<2200V9b`03@hC01hN9P0H6Ah04Q8H00l>500=31804A0E01TH7@0C4QL0
20L<00X93P0A41D040lD0P0B4AH07@0B4QD04A0E010@4P0?3a805aPJ00`@4@0=41407b0R00lC5009
2`d03a0B00/=3`0P92D03PlA01DG6@062P/04A8F018E600<41<04Q<G00/>4@0G6ah051DI00X<400A
5AP03PlC010B5P0E5QX06APM00805A<H00D02`T>01LE6P0@3Q<071XO01@B5`0201LE6P0>010>4`0A
3a@02PT>01HE6P0J6Ah051<H00l=4@0A3a806ALJ00l<3P0G4a@05Q8C01TC5@0B30h201<?4080510A
00h04`l@018>3`0B3Pl040`=00l;300F4Q<06QHG01HB4`0B3Pl02`L801dI6P0=2@X020@501TE5P80
4`l@0P0B3Pl01`0A3@h04@`@01<=4@0@2Ph03`T=010:3P0B31000P0C3A40:P0J51P03@L;00d82`0@
2Ph03@P<00T4200/9b/0Pgj203Lb=P0300805a8F00h93@0O6Qh0J6=W07agN`0300804P`C01094@0=
1Pd03`L=01<:3@0D2``04`X;01892P0C20`04`P?01<8400C1a404@TA010;3`0B3A4040X>00h8300?
2@d03@D:00d42@0>1@X05`dB00T0100?10X04PL=01052`805``B00@0>Bhd00l42P0B1`d04@H<0P0?
10X00`0C20h05``B014630050146300700h32@0@1@/04`P>01D:400D2@l04PL=01P;4P0201853009
00h12008008040D:0185300A10/03`8900h1200?0PT04PD<00803P<;01H03P<900l22@0?0PT03`89
01<42@0?00D04P<601H7300G1`/0404601H;4@0?1PX0100000l;30091`L01@@201@B4`0=2@P05`h?
00T0000?1PH0BSi05?ooool001_ooooo00<030/=00h>3`0?3a000P0=3@h01@0>3Pl030`=00h>4007
1`T0410B00802PX<00<030X;00h<3@0?3@h00`0A3a00600D4Q<03@/<01DC500>30d02@L801<A4P0A
41<04Q4C00d=3`0;2Pd04@lB00`:3@0B41<03``?00l;3`0B3A404`hB018>400I5QH03Pd<00h<3@0@
3Pl03@/<00X92P@03`d>00X03`d=00l=3P0>30l03P`?02@R900B41800`43018@4P0:20T04a4B0P0=
2``020091`P04a4B00P61`0<2P/06ALH014?400>30d03@/<0P0A3a004`0:20T03P`=00l=3P0?30d0
4@d>010<3@0>2P/040`=014=3P0B3Pl0510A01LC500C3a003PX;014=3P0@3Pd03@`:00l>300>3@/0
0P0<2`T0100=30X03Pd;00h=2`0=30X200`;2@0600l>30061@@05aHD02DT8P0B4@l03Pd;0P0;2PP2
00`;2@803@`:00P04Ph;00h:1`0;20D03@T700h:1`0C3``03PX7018>2`803`/800l05Q8?01LE4@0=
30X05ADC00X:200C4a402PX8014@3P0920H04A0>00h:2@0:1PD071PG00l;2P0?30/00`0>3@/200d<
2PH030/904T03@`900d<2P0>3@/03Pd;00l>3@0?3@h03P`=00d;3@0<2Pd03P`?00h<400<2Pl02`X@
01DE6P0=3A402@T;00l?3@0:2@H04@h:010<2@0D3``030H501@<300D3Pl05Q<C01HF5@15AD<0XJ6O
07UiM`0B4a405QHF00/:3@0E51P061LL01DD6`061@`0>C/o00lA4`0:2``03`h=018>300<1`L04P/:
014;2`0A30`040/?00h93`0<2@h04Q0F00l<4`0I5Q`04PlF05QEG01NFf404PlE010=50091``03P/B
00d:4@0?3A803@/>00`:3@0@3Q402PP;010>4@0?3A002`T<00`:3@0?3A002`T<00l=400=2`l04@lD
00803P`A00<03@/@00X83@0@3Q<00P0C4AH300d;400500d73P0A2A0050/C01<:4P0A2A000P0C2a80
3P0B2A404PXA00l73P0>1Pd03`L>01<<4`0?2Q004@`B00d83P0;1P`040/A00h93`0?2Q003PT?0P0=
20h03@0?2Q0040hC00h<4@0C4AH02`T>018@5@0=2a003`dB014?500C4AH03`dB00d;400?3A800`0;
2@`03@0J61/05A<F00h<3`0:20/03P`?014?4P0>30l02`T<00`:3@0=2`h030X=00/9300=2`h00P0>
30l200/9308030X=00D03@/>00h<3`0>314040dC00l=4P0200d;400?00h<4@0:20d030X?00h<4@0=
2a002`T>00T7300@3a@02PT>01@C600:2@h03P`A010>4`0=2a003P/@008030L=00H040/A014<4P0@
2a403P`A00`:3`0;2@h200`:3`0B00X83@0<2Pl03@/@00d;400<2Pl02`T>00h<3`0;2@`03`d@00d;
3P0;2@`03P`?02@R9@0:20/030X=00l=40091`X02PP;0P0<1`/400d830803PT=00L03`X>00h93@0;
1PX02PD900l:3P0=20`03PT=00804@`@01803`X>00d8300;1PX030L;010;3`0>2@d02`H:01@?5@0@
31403@P>014<4P0<1`d05a8H00h:3`0810T03`X@00H11P0G4QP600`72`0H00d8300<1`/030L;00h9
3@0?2Ph03@P<00`7300;1P/03@P>014<4P0=20h030L=00d83P0E41H06QDK014<4P0<1`d03PT?00d8
3`0E41P0?SQ201<>5@0:1@`04@`C0P0=20h200h93@803`X>00<03`X=00h:2`0>2P/00P0>2P/03P0?
2``04@d>00l;300=2@X02`H800`72@0>2@/03PT=00H21@0L5a/02`H:01<>4P0<1`/03@P<0P0<1`/2
00d83007010;3`0>2P`040`=010<3@0=2@X030P900d92P0400`82@0@00h:2`0?2``040l=00T8100:
2@H081lL00d<200@3`/020L400d<2@0:2@D05aHC01<B400@3@X03P/700l;1P803@X500<030T400`8
100>2PH00P0>2`L05P0>2`P03@X700/81P0>30d030`=00/;2`0:2PX02`X:00`;2@0=30/030X900h:
2P0E4A004@d<00h:200;2PD03@`600/:100A40/04a8>00l>2`0;2PP200/92P<02`T<00P02`T:00l=
3P0>30d03@/<00T7200:20T04@l@00h<3@803@/<00/03P`=00d;300=2`h03P`?00X82`0=2`h040hA
00d;3P0?3A003P`?00d;3P0200h<3`0400l=400>30l03P`?00h<3`803@/>00d02PP;00L5200A3a80
3@/>010>4@0C4A@030X=00d;3P0A3a803P`?00X8300<2Ph03`dA00H03P`@01003@/>00l=400B41<0
3@/>00h<4@0A3Q@03``C00h;4P0=2Q803P/C00l<5@0=2a803@`B010?5@0B4AL040lE0P0<2a405P0A
41H030/A014@5P0?3Q@03PdC01DD6@040`L03a0E01<D700?4QT0DUQO0=SMh`1PIF`05QPO010A5P0;
31004A0E010?5@0B4AL051<H018A5P0A41D2018B500:01<C5@0C4a<04A4B014A4@0C4a@071`N01LH
6P0C51H05aLI014B50804Q8D02/04A4C018C5@0@41804Q<E01@D5P0B4AH04a<G01LG6`0K6Ql071/P
01PH7@0C4QL05ADJ01TI7@0F5AX03`lD01<B5`0E4aH04a4D00h<3`0N71l0518E03`j?@0W9BP04a4D
01@B5@0I5aX05A<F01<A500=3@l051@F01HF600G5aT03Pd@014?4P0C4A@04@dA014<400F4AD06Q@H
01<=4@0F4Q<0510A00<04Ph?00T04`l@01DA4P0A3@h04`l@018>3`0A3@h06aLG01@@3`0C3`h00P0A
3@`0800@30d03`/<018>3`0?2Ph040/?01lJ7P0I51T02PD901DA4`0A3@h02`L8014=3P0F4Q<0510A
00d92P0?2``04@d>018>3`0?2``03`X>00P42@0D3aD0?3Lm028M8`0<1`d04PdC00d83P0<1`d050lE
01XE6`0E41H03`T?0P0?20l01P0@2A003`T>00l93P0>20d05@lD01D=4`8040P?00@02`@:04@nA@0P
6b403@P>0P0>2@l01@0E3QD03@D<00l53@0?1@d04@H>00804PL?01804PL>0146300A1P`040D;0146
300B1`d03@8801P=4`0B1`d01`0201@;3`0k<3H03P<90146300B1`d04@H<01052`0B1`d200l42P80
4@H<00/02P450146300H3AD05P/C01463P0=0PX03P<;01463P0?10`040D=01873`0200l430030146
3P0?0PT03`8900H03`89010040<900l22@0>0@L03@0700l42P0>10T03@<800l72`0>1@X0308600/3
1`0C2@d040D:00l42@0=0`L08AHK5?ooool001_ooooo00d03@d?00h>400<30h02`/=00`<3P0@4180
20P:00X:300@41802`/=00d=3`092@/03@/<00@03P`=01T03@/<00`:2`0>30d02@L800X82@0>30d0
30X;018B500C4aD02PX<00d=3`081PT040hA014?4P0@2`l03`X>014<400A2`l03`X>05eJF`0H5QL0
4a4B00/92P091`P07A/L00H03P`=00<02PP900`:2`0;2@X00P0=2``01@0>30d0518C00l=3P071@H0
3`d>008040h?00L020H702DS900m>c`04a4B00@20`081PL03`d>008040h?00l04a4B018@4@0?30d0
3`/<00h:2`0B3Pl061@E01dI6P0G4a@04@d>01<?400@30d030P900h:2`0>30/00P0;2PP00`0>3@/0
40l=00l>300300h=2`0800d<2P0<2`T030/900d<2P0B4@l030/900D40P0<2`T400h=2`<03@`:00L0
2@P601DD4P0E51803Pd;010?3@040`8020L500802`X800/02PT700d<2P0;2PP010@201<C4@0<30X0
410>00H6100<2`T05A@B00d<2P02014=3003010<2`0E41003`/:00803@`:0P0;2PP00`0:2@L030/9
00`;2@0400`;2@0C00d<200>3@X03Pd;00h=2`0?3@d03`d>00d;300;2@/02`T<00d;3P0=2`l02`T>
014@5P0N7B<051<H00/9300=30X03Pd9014=2P0200l;200F00H20@0@2P`05@lA00l=3P0=3@d00@41
00h>3P0A4A805ADG02DU9`0Z:Bh0?ci307IeNP0@3aD03PlD034f>@093@h05ALF02LW9P0]:BH07APE
01491`8040X:01L03PT=00d83P0:20d01`D:00T7300G5AX02`T>01<A5P0100@02`T>00@21`071@X0
<S0e01PF6`0@3Q<08b4T00X82`0200<01`D800d;3P040PD030X=00h<3`0200/9300>00d;3P081PX0
108700T7300A3a@02PP=00L52P0>31403@/@00T7300?3A806QPM01HD6@0A2a420188400<01@:4P0E
2a<050XB0188400A1`l04PP@00l53@0>10`03`D=00l83`070PP02PD;0P0;1P`06@0?2Q002PD;00/6
300<1`d03@P>010;4@0B3A<02@L<00X83@0B41D02@L<00l=4P071@X03P`A010>4`0B41D03`dB00h<
4@0?3A801`D801DC5P0>30l02@L:00P62@071@P00P0A3a801`0@3Q4030X=00/9300=2`h02`T<00X8
2`0<2Pd00P0?3A000`0<2Pd03@/>00d;3P0300`:3@0700/9300<2Pl03`dB00h<4@0<2Pl02`T>00d;
400300/93P<030X?00D04a8G00T83@0<2a000P4600H52P0200X83@0700/83@0=20h03PT?00l93`0?
2Q0030L=00`:3`0200l=4P0400d;400:20d01`D:00T730<030X?00L02PP=00`:3@0=2`h04a4D014?
4P0;2@`030X=00802PP;00H04@lB00`:3@0610L02PP;014<400>2@d200d8300300h93@0?2Ph03@P<
00<03PT=00D030L;00/62P0>2@d030L;00d8300200l:3P0800d8300>2@d030L;00d8300?2Ph03PT=
00`72`0D3aD200d83P09014<4P0300@02PD;00d83P0H4aT02@D:00T42P060@L02PD:00D030L;0P0>
2@d01@0=20`03`X>010;3`0>2@d03PT>00803@P>014040/A00d83P0<1`d03PT?00l:400>2@l030L=
00h93`0=20h030L?00P2300Q6bD040/C00d83`0A31<03PT?00d83P0200h93@803`X>00H030P900d9
2P0@30d040`=00l;300=2@X300h:2`0;00d92P0<20T030P901<>4P0F4AD00`02010;3`0?2Ph020@7
00/62P0<1`/00`0>2@d02@0=20`040`=01@@4@0G4a@04`l@00h:2`0810D02@D600X61`0300d92P0E
00/7200B4@l06aXH01XI5`0[:RP051<A00`;2@0:2@L03`h<00X91`0D4a40:BPV00T8100;1`@03@T6
00h:1`0=2@H030P500X60`0B3P/03`/8008030P500@03PX7010<2@0?3@h03P`=0P0<2P/200d;3007
0040000E4a@00@00018@4@0610D07A`J00X:0`0200/:1@04014@2`0C4Ph040l;00X91`802PP90`0:
20/03`0:20T01`D602PV9`0Q7b006ALH018@4@030P8071XK0040000E4a@04Q0A00l=3P0<2Pd03`d@
00h<3`0200l=400300`:3@0>30l03@/>00803@/>0P0>30l0100:20/02`T<00`:3@0=2`h200h<3`03
02HT9`0100804@lB00800@0200D03`d@010>4@0C4A@04@lB00d;3P0200l=40D03@/>02X040hA014?
4P0A3a804Q0C00`:3@0<2Pl03P`B00d:4@0?31<04@hF00l<5@0=2Q<03P`C00h=4`0<2a402`X@00`;
4@0?3Q@02`X@00`;4@081`d04A0F00h=4`0@3aD04Q0E00X:300B4aP03a8I00hA600a=Ch0P8B=038f
?`0520l02``A014B5P0E4aL040lE018A5`0D4aP04Q4F014@5@0B4Q@201<C5@0501<C4`0D51@051@D
01@D500Z:R`00P0D51H0700I6A/07QhP01dM7`0:2P`061PJ00L72@0>3Q006QXL01<C5@0B4AH03`hC
00h=4P0A41D05QDJ01PG700A41D05A@I01`K800J6Ah04a8G018A5P0A3a803`d@01dK7P0L6Qd04@lB
06UWJP0a;c8200l=400@01TG6P0C4A@03`d@018B500P82803`lA014A4`0K6Q`05Q@G00l=400C41<0
61<G01`G6`0C3A406A<G01<?40804Ph?00/0510A01DA4P0F4Q<05Q8C01<?40091@H0;BTZ048n?`0A
3@`05a<A01@@3`02018>3@804`l@00h0510A01LB5P0G4QH05a8F01@?5@0?2Ph02`L9010<3@0F4Q<0
4@d>00h:2`0C3a003PX;010<3@804@d>00P040`=00l:3P0B3A<05A0F00H21`0;1P`061<I00`73@@0
3PT?00<03`X@010:4@0?20l00`0@2A003P0?20l030D<00@0100:0`X05PlF00X32P0X8BP0`[c207Ia
M`0K5Q`050lE00X52`0A2Q404PTA0P0?1@d0100A1Ph04PL?01873`0B1`h20146300G01052`0A1P`0
4PL=00/01P0<0@L050X?00l42P0700803PD901hC6@0F2a403`@:01@93`0G31803`@:01052`0A1P`0
3@8801873@0:00D03PD900l4300>0`/00P0=0PX02P0>0`/040D=00d22P0?10`040D=00h32`0=0PX0
3`@<00`01P0=00L200h120803`89100@0`X02@0?0PT03P4800`11`0C2@h02P0500/01P0B1`d040D;
00/01P0201052`0301<83P0900@03P<901Cooooo000Kooooo`803Ph@00P02`/=00X:300=3@l04A4C
010@4P0<30h04Q8D00@41P80410B01<03@/<00h<3@0>30d03@/<00`:2`0;2@X030X;010>3`0?3@h0
2@L800`:2`0C4A80>SXl01dM7`092@/05aLI00X82`0A3a8040hA00803`X>00H040/?010:3P0=20`0
7Q/L00P61`030@82010>3`0300L51P0=2``03@/<00D03@/<01P04a4B00D3100@3Pl0518C00`:2`0V
92D05A<D00T7200@3Pl03P`=00d;30050`@03`d>018@4@0?3@h06QPI010>3`0;2@X03`d>01LE5P0E
4a@03`d>00l<3@0@30d200h:2`0?014=3P0E4A804Ph?00h:2`0?2``03@T:00/7200=2@X03``<00d<
2P0;2PP03@`:00h=2`0;2PP030/900803Pd;00T03@`:00`;2@0<2`T020L5014@3P0F5A<03`h<018A
3`0;2PP00P0?3P`0300>3@/03@`:00d<2P0<2`T02@P600`;2@0:2@L020L500d<2P0@3`d02`X800d<
2P803Pd;00@03@`:00X91`030`405ADC0P0;2`T03P030`4030/901<B400920H04@d<01@@3`060P40
4Pd=010<2`0>3@/03@`:00`;2@0;2PP02PT71P0<2`T0:`0>3@T03Pd:00h=2`0>3@/03Pd<00h<3@0?
3@h03P`>00d;3P0?3A003`dA00d;400<2Pl0518G00l=400:20T03@`900l>2P0A3@X03PX7010?3@0;
1`P03PT=00T420091`P03Ph>014A4@0D51@051@E01<C5@0B4Q@040lD01dL8@0k>Sl03`hD00H73004
1PT07B4R01<E5029RHP0XIbI020K600D30X00P0B30`05@0A31003@/@00`:3`0D4QL02@L<00d;400>
31406ALL00d;40091``05A<H018@5@0?3A80518G05]IGP1>C4l02@L:00h<3`0H5QT04Q0C010>4@02
00l=400F00h<3`0?3A002`T<014?4`0=2a003`dB00h<4@0200D01`D:00l=4P0=2a002@L<00d;400F
51T04a4F00l93`0@1Ph03P@<0188400D2Q804PP@01473`8050XB00X04@L?01063P0A1`l03PP?00X5
2`0B3A<04@`B00`73@0@2a402`H<0P0<1`d02`0>2@l040/A014<4P0@3Q<01P@900D420071@X0518G
00/93P0>31403`dB008040hC0P0?3A80300H5QT04@lB00D31P0F51L061HI01<A500=2`h030X=00/9
300:20/02`T<00h<3`802`T<00D03P`?014?4P0@3Q403@/>00h<3`0200d;3P0600`:3@0;2@`02`T<
00`:3`0>31403@/@0P0;2@h300`:3`802`T>0P0=2a00200>3A802PX>010?500@3a@08R0U00d;400@
3Q<03@X?0P0>2@l0300=1`h03`X@00l:400;2@h02PP=00d;400D4QL06ALL01<A5P0A3a@03P`A00`:
3`802PP=00T03@/>00`:3@0@3Q403P`?00/9300=2`h03`d@00`:3@0=2`h00P091`X01`0@3Q403PT=
010;3`0A31003`X>00/62P0910P01@0=20`02@0<1`/03@P<00/62P0<1`/03PT=00d8300<1`/04@`@
00h93@0200d8300>00`72`0;1PX02PH;018=4`0:1@/03PT?00l:400;1P`03`X@00T42P0I5AX0C4M=
01hI7`0>2@h500`72`803PT=00h03@P<00l:3P0?2Ph03@P<00h93P0=20h030L=00h93`0;1P`030L=
00h93`0=20h030L=00/630803@P>00P03PP@00D02@0C3AL03`TB00P32P0?2Q403PT@00d83P803PT=
0P0?2Ph01`0;1`P03@T:010<3@0A3@h03`/<00`82@0=2@X00`0>2P/01@0=2@X030P900<00P0@2`l0
5a8F00800`0200<05a8F00/62P0<1`/00P0?2Ph0700>2@d03@P<00/7200?2``05A4B01<?400@30d0
3@T:00`82@0>2P/04@d>018>3`0@30d03@T:00/92P0_;Rd05QDC01LE5P0=2`/010<100/92P0=2`/0
1@@200/92P0N7A`01`H400X60`0<20D200h:1`0400`81@091@804Ph;010<2@803PX700H03`/8010<
2@0>2PT03@T:00X82@0<20T200/92P0700d;300;2@`06ALL01/I7P0@3a@0000200`;1P0200X91004
00`;1P0;2PH02@P400d<2P803@/<0`0=2`h03@0;2@X00`4202TW:00Y9bP0;2X[01`J6`0G5AH0DU1A
00@20`091`P020H70040000<2Pd00P0=2`h200h<3`0500d;3P0>30l03@/>00`:3@0=2`h00P0>30l0
0`0;2@`030X=00d;3P0200d;3P0;00/9300Q7b802`T<00X82`0200<08R0S00`:3@0@3Q404Q0C014?
4P0>30l00P0?3A0500d;3P0Z00h<3`0<2Pd03@/>00l=400;2@`03@/@01<@5P0@3A@03@XA00/8400=
2Q<040dF01<A600@3aD03PdC00`;4@0>3A<04A0F00l>500L6b404Q4G00d<4P0@3aD04A0E01LE6P0C
4A@0410F00T<4`0>4AP082@]01DI8P072a@05APO01LH7@0D4aP0518F010?5@0B4AL051<H018A5P0A
41D04Q8D0P0A4A<0200A4A404a<C01<C4`0B4Q804Q8D00@41P0K6ad02`/=0P0<30h03P0:2P`05QHH
00H6200A4A<06QXL01LG6@0=31403PdB014@5@0D4aP04a8G010?500A41D04a8G0P0I61d201<B5`0I
018@4`0I5aX04Q0C01<A500?3A00:2HY01TG6P0J61/0518E010>4@0D4QD071XM03hn@01ADE<02PX<
01@D5P0B4A<04a4D00h<3`0F4aH04`hB02PS9`0O6Ad05@lC01DA4P0201@@4@<04`l@00P05Q8C01LC
500810D0=S8c05IBD`0?2`X05A4?018>3@8040`;01004Ph?01<?40091@H04@`@01<>4P0=20`030L=
00l:3P0B3A0040`=018>3`0D414040`=00/7200>2P/040`=0P0A3@h0800@30d04PhA00X52`0A3180
6QDK01LB600E41H03PT?018=4`0A31803`X@010;4@0B3A<04@/B00l83`0@2A004@XA0109400?20l0
4``C0109400B2a803PL>00l83`0F3aH0HE]Q03<^=00=20h040/A00D01P0;10/030<;0P0?1@d0100A
1Ph04PL?01873`0B1`h20146300301052`0A1P`04PL=00803`@:00L04`P>01@93`0?10X060dC02DJ
800L4AL04@H<00804PL=00<02P4500l42P0900@00P0A1P`00`0D2@l02`8600l4300200l4300900h3
2`0=0PX03@8:00d22P0>0`/03`@<00d22P0<0@T03`@<0080300600<03@0700h1200?0PT00P0@0`X3
01442`0>01032P0>0@P01`02034V;00D2@l07a@J00P00`0<0@L04`P>01052`0<0@L04`P>00d2200A
1P`Dooooo`006oooool200h>400;00`<3P0;2`d03@d?014A4`0;2`d02PX<014A4`071`T03@d?00`<
3P0>30d00P0?3@h06`0>30d03@/<00/92P0C4A8030X;01<A4P0<2P/08AlP0490@@3=cLl0De=E01DE
5`0H61X04@lB01<A500@3Q403`X>014<400B3A404@/?00h93@0A3Pl040h?00T7200E4a@07A/L01@B
4`0600h<3@0N00`:2`0B41401`D600h<3@0?3@h01`D601lM7P0B414020H7018@4@0?3@h09bDV04E3
A00E4a@05Q@E01LE5P0>3@d0<c4b01<A4P0=2``03P`=00P61`0<2P/05A8C01<?400@30d03PX;00`8
2@0=2@X03`/<1@0@30d01`0>30/030/900d<2P0=30X030/900/:200=30X00P0>3@/01@0=30X030/9
00`;2@0<2`T02`X800803`h<00D02PT700l>300>3@/03Pd;00d<2P0300`;2@08010?3@0:2@L05QDC
01TH5P0920H030/900l>300=30X200h=2`0@00d<2P0>3@/06ATG02PX9P0D51803Ph<00P81P0@3`d0
1PD301@C4@0@30/06aLF00/71P0G4Q404@d<00l>30<03Pd;00<03@`:00`;2@0<2`T0100<2`T01@0?
3PX03`h;00h=2`0>3@/03Pd<00803P`=02X03@/=00`:3@0>30l03P`@00`:3`0?310030T;00X61P0=
2@T03``:00/:1P0A40h02PX900d=3P091`/03`hC00`<4@0=3@l030`<018B4P0K6a/04Q8C00T92`0<
30h051<H00X93P0?3Q<020P=01PH7@0<41<030d?00@51@19AdL0EU5>01`G500A30T04@/;014<2`0?
2`l030X?00/93P071@X200d;400W014?500<2Pl030X?00d<400A3a@02PP=00h<4@030@H08b4V01LE
600?3A005A<F00`:3@0:2@/02`T<00l=40091`X03`d@00d;3P081PT0BDM;03Xh?@0A3a@030X?00d;
400C4AH02`T>00`:3`0>31402PP=00`:3`0>314040/A0109400>1`h040T@014:4@0@2A003`P?0080
4@XA00T03PL>00d63@0>1`h03PP?010;4@0N6Al06QDK00h93`0A3180100?2Q00200>2@l03@P>01HD
6@0H5Q/07A/P00/93P0=2a0030X?0P0>3140400?3A8040hC014?500?3A80@Cm202DS9P0?3A0040hA
00@21@0U92H04Q0C00l=400<2Pd02`T<00d;3P0>30l200d;3P0300l=400B41<04Q0C00803P`?0P0=
2`h200`:3@0700/9300<2Pl03`dB00h<4@0<2Pl02`T>00d;400300`:3`0Y00d;400>31403P`A00/:
3`0I6Ad0>CPm0:RW[012@DH05Q@I01TG700@3A8040/A00l:400<1P`04PdC00h93`0<2Pl03@/@00h<
4@0A3a@04Q0E01PF6`0B41D02PP=00P62`0;2@h03P`A00l=40091`X02PP;00T72P0:20/03`d@010>
4@0:20/02`T<00l=400=2`h030X=01<>4P0?2Ph00P0<1`/00`0>2@d03`X>00d8300300d8300300h9
3@0?2Ph03`X>00803@P<00<03PT=00d8300<1`/00`0=20`03`0>2@d04PdA01@?4`0`:c401@4600d8
3P0<1`d02PH;00l:400810T06QDK00`73@1ED5H0FUEK010;400500`72`803@P<00P030L;00h93@0=
20`02`H:00d83@0=20h030L=00h93`802PD;0P0=20h0300@2a403`X@00X52`0=20h040/C00d74@0>
21803`XB00<01@0?2Q403`X@00d83P803PT=0P0?2Ph01P0<20T03@T:010<3@0A3@h03`/<00d92P@0
3PX;00P03@T:00`82@0?2Ph01P4500d9300G4aH0EU5E02PT9`803@P<0P0?2Ph01@0>2@d030L;00`8
2@0=2@X03PX;00803@T:01@040`=00h:2`0@30d04`l@01@@4@0@30d030P900/92`0B41<01`D701@B
5@0;2@`05Q@F00D31P0=2`d030X<00X82`0@3Q003P`=00`81`803@T60P0>2PL00`0=2@H03PX7010<
2@02014=2P0B00l;200=20D040T901092P0>2@X03PP:00l:3@0@2a0040hB00d<4P0:2A40410H00d?
5`0>3aD03@`:00X91@0=30P03Pd90`0<2`T300`:2`8030X=00h040h?00<10P0>30d03`d>01`J6`07
1@H06QPI05ECE00F51D02@L800`:2`0B41403@/>00`:3@803P`?00<03@/>010>4@0>30l00`0<2Pd0
0`0=2`h03P`?010>4@0200l=40803@/>00P03`d@04i<C`0^;2l030X=00d;3P0G5AP020H900h<3`80
3`d@200>30l01`0@3Q403P`?00l=400@3Q4030X=00l=4P0B41H00P0@3A@0100?31@040dF010=5P0?
3AD200h=4`0J00l>500>3A<03PdC01LF700f=C/09B@Z00d<4P0F5A/04Q4F00T7300>30l04Q4G00h?
5`0?4QT030lH018F7`0>4Q/03Q4H01TI7`0O7R<04a4E010?5@0B4AL051<H018A5P0A41D2018B500<
014A4`0C4a<05aLG01LG5`0D51@03`lA01HF6010@4807AdO01<C5@0@41805aLI0`0B4Q@04@0G5aT0
4Q8D018A5P0A41D040lD018A5P0C4QL04Q4F01DD6@0@3a@04Q4F01<B5`0A41D051<H018@4`0H5QT0
518E00805Q@G01@030X=01<A500V92L05A<F00d;3P0G5AP03`d@01<C5@0I6A/0820R01@D5P0C4QD0
5Q@G01<A500B3Q8071LK018=4@0?2@d04@/?01@@4@@05A4B00P0510A018>3`0G4a@07ATJ00d92P0K
5aP04Ph=01@@3P<04`l>0P0C3a00300i=CH03`X>00h93@0H4aL050lE018=4@0@30h05A4B00l;300@
30d05A4B018>3`8040`=0P0A3@h03`0B3Pl04@d@018=4`0A31803`X@00P42@0;1P`050lE010;4@0;
1P`030L=014<4P0@2a403`T@01094003014:4@0>0109400A2Q402`H;014:4@0<1@`050dD00/42`0A
2a403@P>01TD6P0>2@l02@D:01<<4`0<0`/200l53@0401463P0B1`l04PL?01873P804@H<00/040D;
0146300B1`d03`@:01H;4@0@1@/03P<901H;4@0D2@l04PL=0146300200l42P080146300C20h04`P>
00/11P0C20h03PD900/11P0C20h200l4300:01463P0B1`l04@H>01053@0=0PX03`@<01053@0>0`/0
3@8:00l430803P48100?0PT04P0@0`X04@@;01442`0A10/040<:00h1200>1@T0;R@Y01dB600L4aL0
3P@901893@0>0`T03@<801052`0J3aD04@H<00l42QCooooo000Kooooo`0=00`<3P0>3Q003Ph@00`<
3P0=3@l03Ph@01/K7@0G5aT03@d?014A4`0@418051@F00h<3@0300l=3P0400h<3@0=2``04@l@00X8
2@803P`=01@08R0Q03Tg>02VYZP0?cm100l?4@0<30h04@lB00L5200=2`h040/?018=4@0D3a<050hB
014<400;20T03`d>01HD5@0B41401`D600D310H03P`=00H03`d>00h<3@0D4Q<03P`=00d;300C4A82
00h<3@0@00X82@0A3a003@/<01/I6P0/:R/00@0000T7200;2@X02@L8040n?`0@3Pl02PP900h<3@0;
2@X07A/L02@Q8P804`l@00@04Ph?014=3P0@30d03PX;0P0<20T02P0>2P/03`/<00l;300<2PT040l=
01@C4@0?3P`02@P600`;2@0?3P`200h=2`0900d<2P0<2`T030/900d<2P0<2`T051<A01PG5@0A40h0
2`X800803@`:100>3@/02@0;2`/00P8200@4100;2`/03Ph>02XZ:P0@41002PX:00T92@0200/;2`0A
01@D500A4@l08B4O00`<2P0:2PP020P600`;2@0@3`d0?Sdk018>3@0E4A003@T800d81`0=2@P030/9
00d<2P0>3@/00P0?3P`600`;2@0500l>2P0?3P/03Pd;00h=2`0=30/00P0=2``0900;2@/02`T<00d;
3P0=2`l02`T>01D@500@2P`03PP800d9200=2`L030/700L71@0D51D06AXN00L83@062A403A0G00T:
30092@T01PH601hN7P0?3a00410B00/;3@0L6b00:RT^00P8300K6R003@`B00X;3`0Q8B<020P801DB
4P0K5Q<01`8000l:1`803`/:00<03@X=00/93P0920d00P0H5QT0;`091`X03@/>00800`0?3A004a4D
00P62@010080518E010>4@071@P03@/>00800`0100801`D8010>4@030@@030X=00H41`0>30l00`44
010>4@1GEET081hS0040100=2a0040hC00l=4P071@X04Q0E01DC600=2a002PP=00d;400=2@l03PL>
00l83`0=1Pd02`@;00`5300>1`h03`P?0109400=1Pd030D<00d63@0>20h02@@:00803`X@00@030L=
00l:400<1`d03`X@0P0@2a401`0=20h02`H<0040100:20d06ALL00L52P0;2@h00P0>31403@0<2Pl0
3@/@010>4`0A3a@03P`A00400P081PT04a4D00H41`010080AdE801@B5@0A3a800P0=2`h00`0>30l0
30X=00d;3P0200`:3@0300h<3`0?3A003P`?00802`T<0`0<2Pd0100=2`h03@/@00l=4P0>314200`:
3`0400h<4@091``02`T>00h<4@803`dB01`03P`A01<B5`0C4QL092<X08b;T00U8bP06ALL01<A5P0=
2Pl05A0F01@?5@0<1Pd04@`B00d83P0=2a003P`A00d;400:20d01`D:00/93P0:20d020H;00T7300<
2Pl03P`A00h<3`0:20/02`T<0P0:20/02`0>30l01`D800P62@0;2@`03`d@00`:3@071@P08QdQ01XE
6@0E41@03`X>00<03@P<00@030L;00/62P0=20`03`X>0P0@2`l200h93@0400l:3P0>2@d030L;00`7
2`803@P<00l03PT=01<>4P0G4QH0<bhd00<0100C3Q@04@`B010;4@0>2@l030L=01LB600910X0JFAZ
08Z5R`0B3A801@0<1`/200h93@0F00d8300>2@d03@P<00/62P0=20d03`X@010;4@0C3Q@03@P>00/6
300>2@l030L=00d83P0A318030L=00/6300=21005a4K00`6400@2a<01`8901@?5P803@P>0P0>2@d2
00l:3PH03PT=00l040/?00l:3P0=20`02`H:00`72`0=20`03PT=03dh?00=20`03PT=04I1A@0I51P0
3`X>00h93@0=20`00`0<1`/200h:2`0600d92P0:1PL02PH700d92P0<20T03PX;0P0@30d0500=2@X0
2PH700X82`0D4QL02@L<01HD6@0@3Q<071XO00d;400?3A803@/@00L52P0k>Ch0AdE800l;300>2PT0
30P700d9200?2`X04Ph=100>2PT0400=2@P03@L701<92P0B20T04@P;0189300@2a004@`B00h;4P0:
21807AdY06EWL`20Q9005QTR00h>3P0;2PP2010?3@0300d;300@3Pl030X;00D030X;00@040h?00`:
2`0>30d03`d>0P0C4A803`0@3Pl020H700T7200D4Q<030X;00P61`0<2Pd03`d@01HD5`0D4QD03@/>
00h<3`0=2`h030X=00/9300200`:3@0300d;3P0>30l03@/>00<03@/>00L04@lB010>4@071@P06aTL
00800`0100805A<F00803@/>0P0>30l00`0=2`h03P`?00l=400500l=400<00`:3@0;2@`030X=00T7
2P0=2a004@hD00l<4`0A3QD04PlG014>5`0?31D03P`C1@0=3180;P0000D05A@J014@5P0=31804A0F
00l>500C4AH040hA00L630061Ph041<J01lR:`0:3AH05aXS01LG7`0?3Q@03@`A010>4P0@3aD04Q4G
01@C600B4AH04A0E018B500C4aD04Q8D01<C4`0J6QX06a/K01DE5@0J6Q`04Q8D014A4`0F5QP05ADG
01LG6@0B4Q@030`>01LG6@092@/08b<U00/;3@0F5AX04Q4F010?500B4AH201<B5`0401LF6`0@3a@0
4Q4F01@C608040lD01X05aDH01<A500J61/04a4D010>4@0F51L040hA00l=400=2`h04@lB01LE600A
3a803@d?01`L7P061PP020P:01HE600A3a805Q@G01HB5P0M61`04PdA02lY;@0H4QH0510A01DA4P80
5Q8C00X05A4B01@@4@0H51D05A4B00l;300J5QL06aLH00X61@0A3@/04`l>0P0E4A002@0B3Pl04@d>
03`h>@0A31003@P<00h93@0@2a406QDI04E0@`02010<3@0301@@4@0:1PL02PH700<040`=00l04@d>
018>3`0=2@`05a8H01lJ800>2@l030L=010;4@0?2Q004@`B010;4@0?2Q004@`B018=4`0B31800P0A
2Q40400B2a804@XA014:4@0E3QD03PL>01L@5`0=1Pd030D<00P1200@2Q000`0402LR:01@Be406QDK
00l83`0C2Q8200l53@0401463P0B1`l04PL?01873P804@H<00d040D;0146300B1`d02P0500h32@0@
1@/050T?01D:400B1`d04`P>01873@0A1P`03P<900803@8800L03P<90146300E2Q00NVme044f?00@
1@/03`@<008040D=0P0A1Ph01`0B1`l03P<;01053@0A1Ph03`@<00h32`0@1@d00P0B1@`0100A10/0
40<:00l22@0>0@P200l22@0@01032P0?0PT03P4800d01`0C20h03P<90146300=0PP05P/A01<83P0=
0PP040D;01D:400O51X050T?01052aCooooo000Kooooo`0>00/;3@0>3Q003`lA00d=3`0<30h03@d?
04e=C`0f=SP03Ph@010@4P0820X04A4C00h<3@0?3@h3010>3`0300h<3@0;2@X03`d>00<03P`=01<0
30X;02PX:P0=3@l02PX<01<C5@0I5aX01@<600d;3P0@2`l04PdA01HA5@0E3a<04PdA014>3`0<2P/0
1P@500`:2`0A3a0030X;00H03`d>00<03@/<00P61`0G5AH00P0;2@X00`0K6AX040h?01DC5002010>
3`0800H41@091`P040h?00h<3@0E4a@020H700800@0G5AH200X82@0400l=3P050`@04Q0A01lL7@<0
510A00H04@d>00l;300@30d040`=00l;300A3@h201<?4007014?3P0F5A<06QTG014@3P071P@02PT7
00l>300200h=2`0;00d<2P0<2`T030/9010?3@0A40h030/900/:200?3P`02PT700d<2P0>3@/00P0?
3P`07P0@3`d04A0>018B4P0C4a<03Ph>00H61P051@D03Ph>01<C4`0;2`/02@T900`<300=3@d06ATI
00<30@0D51801@D300`<2P0>3P`03`h<00`;2@1:BDL03@T8010<2`0A3@`03`X:00/71P0920H02`X8
00d<2P803`h<1P0<2`T0:@0?3PX03`h;00h=2`0>3@/03@`;00d;300?3@h03P`>00d;3P0?3A003`dA
00d;3P0B31004@/<00h:2@0<20L02`X6010A30071`D0:2TZ03<f>`0E61l01PTC00/>5@092Ph03`l?
01DE5@0i>CT05ADF00410`0?3a4010<800h=4P0?3Q<00`8800l>500:2`l03`lA018@4@0;1`L03PT6
00804Pd:0P0A3@`0900>3A0030/@00/:3`0=2`h040hA00@21@0A3a801`D801LE600=2`h0518E01DC
5P0=2`h01P@700/9300A3a800@02010>4@0<2Pd03@/>00l=400=2`h02PP;00l=400100806ALJ05QF
FP0F51T020H;00h<4@0200D03`dB01<A5P0K6Ah06QPM010>4`802`T>00H030P>01<<4`0E3QD04@XA
00h73P0?20l3018;4P0900l83`0>1`h03`P?01<=500:1@/02@@:00d83P0C3Q@05Q4G00803PT?00D0
3`X@010;4@0>2@l030L=00d;400200H42@0400D3200B41D030X?00h<4@8030X?00h040hC018@5@0>
31407A/N00l=40071@P061HI014?4P0C4A@03P`?00/9300:20/03@/>00h<3`8030X=00<02PP;00T7
2P0;2@`00P0<2Pd02@0:20/02`T<00`:3@0<2Pd03@/>00h<3`0>314040hC00l=4P0200d;400700h<
4@081P/030X?00l=4P0@3Q<03`dB00d;400200X93P0<00l>4`0F5AX03`hC00X83@0;2@h02PL<01LB
600H4aT03@L=00l:400C3Q@03@/@0P091``01@0=2a004@lD00L52P0:20d030X?00803@/@01X030X?
00d;3P0;2@`03P`?00d;3P0:20/03@/>00`:3@0;2@`020H900T72P0;2@`02PP;00/62P0C3Q8061<G
01LB5P0?2Ph02`H:00d8300<1`/02`H:00d8300?2Ph040/?014<40803`X>01D040/?00h93@0=20`0
4PdA014<400>2@d02`H:00h93@0B3A403@P>00l:400>2@l020@901D@5P060@L05a8H00D01P0F4AL0
30L=01@?5@0?2Pl01@0<1`/06P0?2Ph040/?00h93@0?2Ph03PT=00`72`0?2Pl04@`B018=4`0F4AL0
3`X@00d83P0@2a402PD;00P32@0B3A<03`X@00X52`0:1@d06aDO00X43P0A31@03PT@01TD6`0<1`d0
3@P>0P0>2@d300l:3P803PT=01803@P<00h93@0?2Ph04@`@00l:3P0<1`/02PD900/62P0>2@d02`H:
05IAE@0910P04`hB018=4@0?2Ph040/?00l:3P0=20`200/62P0400d8300<20T03@T:00h:2`8030P9
0P0>2P/04`0?2``040`=00l;300=2@X02`L800<11P0l>Sl040hC00H42@0>31402`T>00h<4@0:20d0
20H;00`:3`1mNh00UI>F014=3P0>2PT00P0<20L0100A3@`0510?010<2`0>2PT200/71P0D00`81`0?
2@T040H701461`0@1PL03`H;00l83P0=2a003``E00/;5@0=3a/09BLd0<O:f02UYk<04A0A00`:2`0?
3P`03@/<00P61`0:20T600h<3@0600`:2`0=2``04Q0A00`:2`0200404@l@0P0?3@h0200=2``01P@5
00l=3P0=2``030X=01<A500M6ah06ALJ0`0=2`h02@0<2Pd02`T<00`:3@0<2Pd03@/>00X82`0;2@`0
30X=00d;3P0200h<3`0600400P0>30l030X=01<A500?3A002@L:0P0=2`h200l=40803P`?1@0@3Q40
0`0?3A0030X=00d;3P02014?4P1K01HD6@0H5Q`04PlF00h;4P0<2A403P/D018?600C4AP040lE00h=
4`0=31803PdC014@5P0@3aD04a8H018A5`0I61h04A0F00`;4@0<1`d03`X>01@B600C4QX0410H00/>
5`082a@051LP010@600?3Q@04Q0E01/H700A3QD04Q4G01@C600B4AH04A0E018B500A4A<03`lA014A
4@0H61P06ATI01<C4`0>3Q009RHX02`/;P0P828010@601DE5`0=3@l04A4C01hN800=3@l0>c/m01HF
600?3Q<04Q4F01LF6`0H5a`04Q4F00/:3`0G5Q/04Q4F01HE6P0G5Q/04A0E00h=4P0C4A@0518E01PF
6@0E4aH071XM010>4@0I5aX04@lB01TG6P0G5AP04Q0C028P8`0?3a40ShnA018B500H61X03Pd@028P
8`0D4QD07a/O014<400`:bl0J69V01`F6P0301PD5@0L01DA4P0A3@h03`/<01DA4P0@30d06ADF01<?
400810D06QHE00d91`0A3@`04`l>018>3@0?2``03@T:00/7200E41@071LK00l:3P0T7bD0Ad960;fi
^`0K5aP01`<401DA4P0=2@X0510A014=3P8040`=00l04@d>018>3`0C3a801`8800X52`0>2@l03`X@
018=4`0:1@/03`X@018=4`0>2@l02`H<010;4@0B31<00P0A2Q40400B2a804@XA014:4@0A2Q4030D<
01H?5P080@P06a@K01D>5@0<1P`03PT?01dH7P0D3aD01P4700h73P0:0`T200l53@0401463P0B1`l0
4PL?01873P804@H<00`040D;0146300B1`d050T?00h32@0@1@/050T?00d2200A20`04PL=0146300@
1@/20146300;00d2200>0`T05P/A02@I7`3`iN/0SX>901062`0D2A404`P@01463P0?10`00P0>0`/0
0`0?10`040D=01873`0200l4300601463P0D1`h050L>01<63@0A10/03`890P0>0@P200l22@803P48
00d0300601D:400;0@H0200301L<4P0>1@T0304700l42P0<0PL02P0501<83P0=0PP04@H<01Cooooo
000Kooooo`0301<C5@0=3@l04Q8D0080410B00h06a/M096AT`1iNG/03@d?00h>400<30h0410B00d;
300?3@h040h?014?400@3Pl03P`=010>3`@03`d>00P040h?010@4P0A4A<0410B00h>400>30l040hA
00l=40804@`@00T04PdA01@>4P0C3Q804a0A00T720081PL03@/<00l=3P091`P01P0?3@h03@0>30d0
40h?00h<3@0=2``040h?01<A4P0B4140518C01<A4P0?3@h040h?00l=3P0=2``00P0?3@h02`0>30d0
3`d>010>3`0;2@X08b4R00l=3P0=2``02@L8010=3P0B3Pl03@T:00803`/<00D02`L801<?400?2``0
3PX;018>3`0200h:2`0K010>3@0J6AL0I6=Q00l>300:2@P061LE00X91`0@3`d05QDC00/:2@0?3Pd0
;Rd[018A3`0<2`T03Pd;00l>300@3`d05A@B01HE4`0I61H04Q4?00T81P0<2`T03`h<00P8200C4a<0
2`/;00803@d=00`0:BTY014A4@0;2`/03@d=00l?3`092@T030`<014A3`0;2`T01`L500d=2`0<30X2
00h=2`0:00l>300?2`X0510?01`H5`0G4Q8040`;00h=2`0?3P`03Pd;00d<2P802`X803`051<A00`;
2P0>3@/03`h<00d<2P0@3`/03@`900X91`0920H02`X900d;300>30d030X<00d;3P0?3A003P`@00T7
2`0D3a<03PP;00`92@0E4Q802@T701DE4`0?41002@/<00/>4`072a803Q8L00/>5@0:2`h02`/;00T9
2@0>3Ph0410A00`<3P0=3@l03@`A00`;400:2Ph020L=00l>500<31002PP;010>3`0=2@T040/800d8
1@0?2PL03@T800/91`0?3a403@dA00P8300<2Pd02PP;00/9300>30l03@/>00`:3@0=2`h200/93004
014?4P0:20/03@/>00d;3P8030X=00D04Q0C00h<3`0;2@`02`T<00`:3@0200h<3`0C00`:3@0<2Ph0
2PP=00X83@0?3A802`T>01lM8P0@3Q<02@L<010>4`0T8RL0BTQ=010>4`0?31403`X@01`G7@0B3Q<0
4PdC00h93`0200d83P0:00h93`0@2a403PT?00h93`0?2Q003PT?014<4P0=20h03@T>014<4P803PT?
02D03@P>00/6300A318040/A00T7300G5AX061HK00/93P0=2a003P`A010>4`0920`020H;018@5@0<
2Pl04Q0E00L5200A3a801P@7010>4@0=2`h03Pd?014?4P0;2@`02PP;00h<3`0=2`h02`T<00d;3P09
1`X02PP;00h<3`0;2@`030X=00T72P0C4A@0:BLZ008030X=00<03P`?00l=4P0=2a000P0<2Pl01P0=
2a003`dB010>4`091``03`dB00/93P8030X?01@030/@00T83@0?3Q<01PD:00l=4P0:20d03P`A00`9
3P0@2a403`X@00d73@0?2Q003PT?00`:3`0=2a0030X?00/93P0:20d030X?00d;40803P`A0P0?3A80
3P0=2`h02PP;00l=400>30l02`T<00h<3`0<2Pd02@L:00h<3`0C4A@01P@700/9300>2@d040/?0P0A
310200h93@0400l:3P0>2@d03@P<00d830<030L;00P02@@800h93@0<1`/04@`@00X62@0<1`/03@P<
00`72`803@P<00h02`H:010;4@0<1`d04PdC00/6300F4AL02`L<00d83P0?2Q0040/A00l:400=20h0
3PT>00h93@<030L;1@0>2@d01P0=20`030L;00`7300;1P`03PT?018=4`802`H<014040/A024L8P0A
318030L=00d83P0B3A<03@L?010:500B31H04@/D00h9400?2Q404@`C01@?5@0L5a/040/?01@?4`02
00h93@0400l:3P0A31002@D800P31`803@T<00D050lC00d8300J5AT01@4400h93@0600l:3P8030L;
0P0=20`0300>2@d03`X>00/7200@30d02@D6014=3P0B3Pl03@T:00/7200<20T03PX;00l;308040`=
00h03P`@01PF6`0F51T030X?00P62`0>314020H;00`:3`0E4aP0108703/j?P0a;c8040`=010<2`80
3PX900D06QHE014=300=2@P040`;00l;2P0200h:2@0G010:2P0G3@h04@L801<92`0B2@d091hT00`9
3P0?31@030/E00l@70082QL0G5m/0453C`0?3A403@`>00/92`0:20X05Q@F00l=3P0>30d03@/<00`:
2`0=2``00P0>30d0100=2``030X;00/92P0<2P/200d;3004018@4@0?3@h03@/<00h<3@803`d>00<0
3P`?00d;3P0<2Pd00P0=2`h01`0>30l03@/>014?4P0<2Pd04Q0C00h<3`0@3Q400P0?3A00400H5QT0
3`d@00/9300?3A004@lB01<A500>30l02`T<00h<3`0B41<02`T<010>4@0N71l03`d@00T72P0?3A04
00h<3`0a00l=400>30l03`d@014?4P0?3A003P`?014?500H5A/05Q<J00/83`0@3AD0514J00d:4`0>
31<04a8H00/:400Q82H07ahT014@5P0B4AL04A0F00l>500@3aD03`hD00d;4@0C3Q@04`hB014>5@0@
3aL03`lG00h@6@0=41T03Q0I014@600B3aH04a4F01DA5@0A3QD040lE01<B5`0E51T05QDJ01DE5`0G
5aT0410B01@D500E5AD03`l?01TI6@0201@D5P805QHH00X05ADG01@D5P0M7Al05aLI018B500C4aD0
51@F018B500H5a`05A@I0P0D4aP03@0C4QL040lD01@C600G5Q/05QDJ018A5P0A41D04a8G01HD5`0E
4aH061HI01/I700I5aX00P0C4A@04@0B41<04a4D01DC5P0E4aH04a4D014A4`0T92H05QHH00h>400H
5aT04Q0C01`J7@0E4QD05A0D01hI7@0P6Qh07QPL008061@E00D05A4B01@@4@0J5QL07a/L01@@4@02
01<?4004018>3`0@30d040`;01@@3P805A4@00l0510?014=3P0@30d0EE5B01LB5P0D3a<03`X>01PC
6@0I51P0>cLi01TE5P0D41406ADF010<3@0E4A800`0B3Pl0100A3@h03`/<010;3`0A318301<>5080
4@`B00l06aHL010;4@0@2a403`X@01PC6@0=20h06a@K02<L8`0B2a803@H=018;4P0D3A@04``C018;
4P0@2A000P0>1`h00`0>20h03PT?00h93`02010;4@0400h73P0?1Ph04@L?01473`<04PL?00P050T@
06=HGP0H3A<04`P>00`11`0B1`d050T?00d420805@X@0P0@1@/70146300S00/01P0D2@l091TO01lD
6P0B1`d04PL?01463P0@1@d04@H>01053@0>0`/050TA00X01`0O51`05P`C00h32`0?1@`03`D901@9
3P0>0`P04PD<00d31`0E2`l03`8901442`0@0`X03`8901032P0A10/03`H:0146300<0PL03`@:0146
300>1@T00P0>0`T200l42P0301052`0A1Pcooooo01?ooooo000Kooooo`0500T92`0E5AL00002014A
4`0;2`d00P0A4A<02@0P82800`<501<C5@0@418061PJ00`:2`0>30d040h?014?4002018@4@H040h?
00L03@d?00h>400=3@l02`/=00`:3@0>30l030X=00803`X>00T040/?014;3`0@2`l09B8S01<A4P0?
3@h04Q0A01DC500B4140200=2``200`:2`0500h<3@0@3Pl040h?014?400@3Pl00`0>30d200`:2`80
3P`=00@02`T:00d;30071@H061HG0P0?3@h02`0>30d03P/<01XF5`0G4a@03`/<018>3`0@30d04@d>
00d92P0>2P/04`l@008040`=00d040h=00X91`01000030/900L6100H5aD04a8@00@30@0510804A0>
00l>300g=S@07QdK00802`X801X03@`:00l>300A40h02PT700d<2P0<2`T02@P600/:200=30X020P8
014B500<3@l03PlA01PI6`16AdT03@h@00l@4P0>3a4030d?00d>400@4A8030`:010@3P0M7A/02PX8
00d=2`802`X800H030/900d9200A3@`05a<B01@?3P0A3@`200h=2`<03@`:00P00@00034`;P1AD4h0
0@0000l>300P7ad04A0<00l>2`803@`:02d03`d=010>3`0?3@h03@/=00d;3P0>30l03`dA00`:3`05
0`P03P`A00X:30030`D06a/K00840`0?4A001PT:00`?500>4AP05APP00/>5@0:2`d04Q8B02@T900>
3Ph020P900d=3`0>3Q001`H;00D42@0@3a@00P4701XI7`19Ad`061<G01LC500?2@X04`h;01`G500G
4Pl0510?00h=2`0;2`d05aPL00@52@0>3@l00P0=2``01@0?3@h03@/<00`:2`0=2``03P`=00802`T:
02T01P@500d;300>30l040hA01<A500:20/040hA00D31P071@P030X=014?4P0?3A003@/>00d;3`0;
2@h04Q0E00`;3`0B41D0<S0e00h<4@081P/03`dB01<A5P0_;C803`dB01DC600100@0JVQ]02XX;@0F
51T00`4600d;400?3A804@lD00T7300;2@h02PP=00T52`0=20h050lE01PC6@0200/6300400l:400>
2@l03PT?00/630803`X@00@02@L<01<A5P0D4QL02PP=0P0;2@h0300:20d03@/@01DC60030@H03`dB
00D3200F51L02`T<01<A500:20/04@lB00l=40802PP;01003P`?00d;3P091`X03@/>010>4@0>30l0
4Q0C014?4P0=2`h03`d@01PF6@0;2@`04a4D00l=400J61/03P`?0P0<2Pl200/93P8030X?01<04a4F
00T7300?3A803@/@00X83@0M6b005QDJ00l>4`071P/02@P=0040100N72403@/@00/83@0?2Q0040/A
00h83P0@2a403`X@00<03@/@00<030X?00/93P0?3A800`0?3A8200h<4@0=00T72P0;2@`03@/>00T7
2P0>30l05A<F00d;3P0>30l05aDH020N8@0:20/01@<600d8300300h93@803@P<00@030L;00d8300=
20`03@P<0P0>2@d01P0F4AD061<G00<00P0;1PX03PT=028M8@804@`@0P0B3A40200A310040/?00l:
40060@L05a8H00`73@0C3Q@03`X@0P0>2@l0100?2Q003PT?00h93`0>2@h200d8300300`72`0=20`0
3@P<00@03PT=02H03@P<00`72`0=20d03@P>00l:400A31803@P>00l:400;1``05A0F00`73@0@2a40
3`X@014<4P0;1@d03@LA00l94`0>2A4030L>00d83`0?2Q003@P>014<40080`L040/?00`72`0;1P`0
4PdC01<>500N6Al03@P>00X62`0C3Q@02@@:00d93P0E41H06QDK010;4@H03`X>0P0>2@d300d8300:
00`72`0>2P/030P9010<3@0S7b006ADF00X61`0;1`P030P900h:2`<03`/<00@030X=00P62@0610L0
2PP;0`0=2`h08@0:20/06QPK014?4P0<2Pd02`T<010<3@0;1`P02PH701TE5P0K5aP030P900X61`0?
2``04Ph?014=3P0=2@X03@L901P?400C2P`0618D01@>400=2@/03`X@004010071Pd02PXD01@D7P04
1a4051@N00X83P040PL07Q`Q018@500200800`0400/9300:20T02@L800X82@802`X80`0<2P/0100>
30d03`d>010>3`0?3@h200h<3@803@/<00@030X;00h<3`0=2`h030X=0P0=2`h200h<3`0>01<A5001
008020H901DC5P0?3A0040hA00l=400F51L03P`?00/9300A3a804Q0C010>4@0>30l200`:3@0700/9
300=2`h07A/N02TW:P0B41<02@L:00d;3P0200`:3@0H00l=400B41<0518E018@4`0=2`h02`T<00X8
2`091`X02`T>018?5@0D4AP04@hE00X73`0A3QL0514J00`:4P0D4aT030/A01LF700D4aT040lE018A
5`0A41H03`hD0P0@3aD0100>318050lE01@?4`0C3aH2014@600C010@6P0?3aT0410J014@600C41L0
5A0F01H@5@0=2Q405A@J01LF6`0@3a@04Q4F00l?4@0B4Q@03Ph@018B4P0E5AD04Q8B01/K6`0201@D
5P805QHH00X05ADG01@D5P0D51H04a<E018B500D51H05ADG01<C5@0H5a`05A@I0P0B4AH04@0@3a@0
30/@01@C600E51T051<H018A5P0A41D04Q4F01HD5`0C4A@06QPK028P8`0O7B004Q0C01@B5@0C4A@0
518E00805Q@G00/04a4D018B500A4A<0410B01@D5P0G5QT03`d@01TG6P0G51L050lC01<>4P0201@>
4P0701LC500F4Q<0510A01@@4@0L61T08QhO01@@4@0201<?4005018>3`0A3@h04@d<01<?3@0B3Pd0
0P0A3@`2018>3`0>01hJ6`0:1@T05a8F018=4@0A31804`hB00h9300>2P/061@E00/7200=2@X00`00
00h:2`0?2``3010<3@04010<3`0@2a4040/A00l:408040/A00L050lE00P32@0A3180:RD[00P32@0@
2a403`T@00806Q<J00@04@XA018;4P0A2Q403`P?0P0A2Q405P0@2A003`P?00l83`0?2@l03@P>00`7
3@0>2@l04@`B018;4P0@1`l03P@<00l53@0B1`l050TA01D:4P0C20l040D;0148300;00H03P<900l6
2P0F2a4200T0100301P=4`0I3Q@03PD900H04@H<00P04PL=01052`0>0`T02P0500T0100A1P`04`P@
01053@803@8:01X03P<;00l4300<0@T01`0401`A6@0G31@01`0401<8400I31<040<:01L:4@0J3A@0
50L>00`01P0>0@P040<:01442`0@0`X04`H=01H9400<0@L09a`R03H[<@0B1`d02P45014630<03@88
0`0>0`TDooooo`006oooool02@0>3Q0030`>00410`0=3@l04A4C00P82P0:2P`04A4C00L72@0201LG
6@04024Q8`0=2``03P`=00l=3P<040h?00<03@/<00h<3@0>30d00P0>30d0200=2``03@d?00h>400=
3@l030`>00d;3P0>30l02`T<0`0=20`0200>20`03@P<014>3`071@H02PP900h<3@0=2``02PP92P0=
2``300h<3@0300l=3P0>30d03P`=00803P`=02@030X;00d;300@3Pl04Q0A010>3`0A3a0020H700l=
3P0=2``030X;00l=3P0@3@h09B4R024M7P0@30d04Ph?010<3@0=2@X030P900l;300C3a004Ph?014=
3P0B40l051<A00<2000G5Q@00@0000h=2`0920H01@@200/:200@3`d02@P601HE4`061@@300`;2@03
010?3@0?3P`03@`:00803`h<0P0=30X09`0<30X02@T;00h?4@0<3@l01@H800H72@0J6ad01PL901<D
5P0720X010D700P92`072@T06QXJ00@40P0820H00P8001DE4`0A40h040l=00h=2`0>2PT03@T800h:
2@0;1PD04Ph=00l>300=30X030/900h=2`0?3P`06aXH00/:2@0T8b400@0000h=2`0K6QP040l;010?
300200h=2`0400l=3@0@3Pl03`d>00d;3@8030X=01l03P`@00h<4@0A41H01`P=00h?4`0[:Rl0GUmQ
00P:2@0?4A001`X:00`@4`0;3Q<05QPO01@E6P0>3Q006ATI03dm?@0N7Qh03Ph?00T92`0V9RP09bH[
0000100D4aP02PT?00T83P0F51T01`8601<?400C3@h03@P5008020<000H020@3014A3`082``02@d@
01DF600?3Q0200d;300W00h<3@0<2P/02`T:00l=3P0:20T01P@500/92P081PL03P`=00D31P0B41<0
20H9010>4@0Y9bX00P0300/9300>30l03`d@00d;3P0:20/03@/?00l=4P0>31402@L<00P62`0M6b00
2PP=00d;400A3a@020H;014?500100@030X?014?500100@06ALL00d;400B41D01P@900803P`A01<0
2@L<01DC600A3a@02PL<00X52`0A3180:bH/028M8`0B3A<02`H<00d83P0?2Q003@P>00l:400=20h0
108700/93P0=2a002PP=00803@/@00/05Q@I0040100D4QL06QPM01@B5`081`/02@L:00L5200E4aH0
3@/>00@21@0200h<3`0500d;3P0@3Q403`d@00/9300<2Pd00P0;2@`02P0@3Q404@lB00h<3`0B41<0
5aDH00H41`0=2`h030X=01PF6@0;2@`600/93P0C00X83@0A3a@03@/@00X83@0?3A80;B/`010?5001
00D02`X?01LF6`0C4QL03`dB00d;400;20d03`X@010;4@0>20h040/A00l:400300h<4@0400d;400;
2@h040hC00l=4P803P`A00<03@/@00`:3`0;2@`00P0<2Pd200X82`0700`:3@0?3A002`T<00d;3P0F
51L02PP;00/9300600d8308030L;01H03@P<00h93@0>2@d03`X>00D1100;1PX01@04014<400?2Ph0
0`0200`72`070PH04PdA00`72`0500@040/?00h93`070PP04@`B00P32@0C3Q@03@P>1@0>2@l00`0>
2@h03@P<00d8300400d830<03PT=01803@P<00`72`0<1``03@P>00h93`0?2Q003PT?010;4@0G4QP0
9R4W01<>500?2Q002PD;010;4@0<1`l03@LA00h84P0?2A8200d83`0B00d83P0@2a406A@H00h93@0@
2`l01`8601@?5@0910X050lE059=D`0M61h03`X@014<4P0300@03PT?00<0100?2Q0030L=1P0>2@d0
100?2Ph03PT=00h93@0=20`200`72`08014=3P0<20T04Ph?02<O800E4A803@T:00`82@0=2@X400l;
300c014?400;2@/020H700/9300=2`d02PP901HD5`0=2`d03@/<00h<3`081PP05A<D00T51P0?2``0
30P9010<3@0=2@X03PX;00/7200?2``04@d>00l;300>2P/03@T:00`61P0@2P/00`0000`6200E4A<0
0`0200<1100D4QP01@@:014@5P0?3aH05aLO00d;4@0C4AH00@0401HD6@0100@081hQ00/9300:20T0
2@L800X82@0:2@L02`X8014?400?3@h03P`=00D03@/<0P0>30d200`:2`0300h<3`0=2`h030X=0080
3@/>00L03P`?00`:3@0>30l05Q@G00l=4029QhX0;bd`00802`T<00D040hA00/9300:20/03P`?00d;
3P0200/9300S00`:3@0;2@`02`T<00X82`0@3Q405Q@G00P62@071@P03@/>00`:3@0=2`h03`d@01<A
500E4aH0518E014?4P0@3Q404@lB018@4`0D4QL030T?01<@5`0W92/04PlG00/84@0G51d03`dE014@
5P0920h02`X@00T83P0?3Q@04a8H014@5P0?3Q@00P0@3aD01P0?3Q<050lE01D?4`0D3aH04PlH014@
60<0410J01004Q0I01D@5`0E41H05a4F01DB6@0J6Al04a8G00`;400C4QL04A4C018B500?3a404Q8B
01DE5@0D51@06ATI0P0C4aD301@D5P0901<C5@0?3a404A4C01<C5@0E5AL05QHH01@D5P0J6Ah05aHK
00805QDJ00<051<H014@5@0C4QL00P0C4QL3014@5@0M01HD5`0D4QD05aDH01/I700H5QT03`d@01DC
5P0D4QD05A<F01LE600F51L04a4D01`L7P0C4aD051@F01LG6@0C4Q@03@/>01DC5P0H5AP061<G01D@
500H4QH06aDI01PD5@0I5AH05A4B00l;300A3@h00`0D414201<?400C018>3`0A3@`03`/9010<2`0A
3@`05Q8A01XF5`0L61T03@T:00d8300L5a/050lC00l:400E41@05Q8D01DA4P0X92D03`/<01PD5@03
010<3@804@d>01@040`=010<3`0@2a403PT?00d83P0>2@l040/A01<>500300@08A`R06]VK00L5ad0
1`8801<=500?20l02P<:00d63@0G41L04@XA00/52`D040T@00L04@/B00l:400<1`d03@P>010;4@0A
2Q404@T@00804@L?0`0B1`l0300D2A001`0201D:400?10X05@X@01052`0B1`d06a0F01L<4P0?10X0
1`02014630L040D;00P04PL=01@93`0@1@/03@8801052`0<0@T03P<;01@94@806@hF00<050TA0146
3P0?10`00P0>0`/201D:4P0702`O9P0800802`0500P00P0C20d0200200l22@0201032P0900l22@0B
1@`05@P?00L00P0e:S00CD9801dB600?10X0200300H03@885?ooool001_ooooo01004a<E00/;3@0I
6A/01`L900/;3@0A4A<05QHH00d=3`0820X04Q8D00l?4@0@418040h?00l=3P0=2``030X;0P0;2@X0
100>30d03`d>014?400A3a0200h<3@0700d=3`0?3a403Ph@00d=3`0?3A004@lB00l=4003014<4006
014;3`0@2`l06QLH00`:2`0?3@h040h?0P0>30d600l=3P07010>3`0?3@h040h?010>3`0>30d03@/<
00h<3@0200d;30803`d>0`0@3Pl0@P0?3@h03P`=00l=3P0@3Pl02PP900h<3@0M6a`04Q0A01HD5@0<
2@X07QXK01/G600=2@X040`=00h:2`0=2@X03PX;014=3P0B3Pl04`l@018>3`0D4A4010<201TH5P0<
2`T04A0>00l>300A40h03Pd;01<B400m?3X051<A00X9200>3@/040l=00h=2`0?3P`05A@B010?3@0>
3@/030/900h=2`0@3`d03`h<00d=2`0=3@l02@X<00`=3`082@/02P/=00L82P0=3Q00<S<e01DF600F
5aT01PL901PJ6`2<S8`0<c<a00/;2P0<30X010@300d<2P0;2PP02PT700h:2@804Ph=00<050l>014=
300?3P`00P0>3@/2010?3@0800/:2@0?3P`02PT700d<2P0<2`T04A0>00d<200=30T200d<2P0]00h<
300>30d03`d>00h<3P0;2@`02PP;00d;3`0@3aD03a4I014D7@0<3aD020T>01<F600<41403@l>00`>
3P0>3a801PH:018A5`0J6Al03`lA00L71`0J6QX02@T900h>3`0D51H0<C4c04E4B@0A41D02`X?00T8
3P0A41H030X?018=4@0@30d05A0@024I5`0G3`d03PX700X81P0@40h0=cXk02LZ;@0U:BX03Pd?0080
30X;01003@/<00`:2`0;2@X03@/<00`:2`0B41407Q`M00d;30071@H030/=00l>400A3a807adP03<a
=00F51L03@/>0P0;2@`02P0<2Pd03P`?00d;3`0?3A801@<801PF6`091``02PP=00l=4P0<2Pl200h<
4@0C00h=4@0:20d06QPM07ilP@14@TL0<2hc010>4`091``030X?00l=4P0:20d040hC02<Q9P0N7240
3``A00/6300B3A<07aXP01<>500200/63006018=4`0E41H040/A00d83P0:1@/03@/@0`0>31408@0@
3Q<03`dB00X83@0`;S<0?3Xo00d<40091``040hC00h<3`0F51L02`T<01DC5P0610L0@Cm201TG6P0@
3Q403P`?018@4`0@3Q402`T<014?4P0=2`h030X=00d;3P0:20/03@/>01@B5@0;2@`06QPK00l=400C
4A@04@lB00/93P0400`:3`0D00/93P071@X04@lD00H42@0B41D03@`@00`:3`071P/06QXN018A5P0;
2Pl0<Bld010>4`0<2Pl02`L=00l:400@2a403`T?014<4P0?2Q0300h<4@0400d;400;2@h03@/@00d;
408030X?0P0;2@h03@0=2`h030X=00l=400F51L040hA00H41`0;2@`03`d@00X82`0<2Pd02@L:00h<
3`0>2@d00`0=20`200h93@0300`72`0=20`03@P<00803PT=01<03`X>00h:3@0C3Q803PT=028N8@0J
5AT03@P<01D@500K5QX03`X>01@?4`0H4aL030L;00l:400A31803PT?010;4@0V8BL040/A00D03PT?
00@03PT>00d8300=20`03PT=0`0=20`300h93@0?00d8300<1`/02`H;00h93`0?2Q0030L=00d83P0?
2Q005A0F02@O9@0A31803PT?00P32@0=20h03PTA00803PPB014040XC010;4P0?2Q403PT?018=4`0K
5QX03PT=01<>4P0D3a<040/A00`73@0B3A<0>C@j01PC6@0=20h050lE03@_=@02010;4@0300P42@0@
2a403PT=00D03PT=00<03`X>00h93@0>2@d00P0=20`01`0<1`/040`=010<3@0?2``0510A00X61`0B
3Pl00P0=2@X300l;300F00h:2`0;2@T03@`;00d<2P0;2PT02PT800`;2@061@@03`h<00T81P0A40l0
40l=00`;2P0>2P/02`L8018>3`0=2@X040`=00d92P0>2P/03`/<00h:2`803@T:01@04@d>00h;300@
3@h040h?00X7200G5AH04Q0A014?400=2`d030X=00H41`0@3a8020L;00/8400E4QT02@H=01@B6024
PXL0EUAI00d;3P8030X;00H030/900d<2P0=30X03`d>00h<3@0=2``200h<3@0500l=3P0;2@X030X;
00h<3@0?3@h00P0@3Pl00`0>30l03@/>00`:3@0200d;3P0300h<3`0=2`h04@lB008030X=00@0Cde@
01lM800>30l03P`?0P0A3a802`0B41<040hA00`:3@0;2@`03@/>00l=400@3Q404a4D00h<3`0;2@`0
3`d@00803@/>00<040hA00l=400?3A000P0@3Q40;`0B41<040hA010>4@0A3a803`d@00/9300;2@h0
3``B01XG7P0T8BP04a0H00h;500E4Q/03@/B010?5@0C4QP051<I00l>500=318051<I014@5P0?3Q@0
40lE014@5P0A41D04PdC01<=4@0B3A@040dF010>5P0?3QP04A4K014@6`0C4AT05Q4H01HA5`0G4AL0
4PlF014@5P0@3a@04Q4F01HE6P0@41805QHH01@D5P0D51@05ADE008051@D00<04A4C018B500C4aD0
0P0C4aD00`0B4Q@03Ph@018B500401DE5`0301LF6`0F5AX05A@I00805aHK00@05A@I01LF6`0F5AX0
5A@I0P0F5AX0200E51T04@lB01DC5P0E4aH04a4D01HD5`0J61/05Q@G0P0E4aH01@0G5AP05Q@G01<A
500C4aD04A4C00805QHH00T051<E01LE600A3a805Q8F01HA5@0C3Q805@lC01PB5P0F4Q<00P0L61T0
0`0H51D05a<D01PD5@0401@@4@0601<?400C3`h05a<A01@@3`0C3`h04@d<0P0B3Pl04P0D41404`hB
01PC5`0@2`l03`X@01HA5@0C3a40:bLX048n?`0A3@h02PL7014=3P0D41405A4B01@@4@0B3Pl040`=
010;3`803`X@00X03PT?00l:400?2Q0040/A01lJ800@2a404`lD00d93P0>2@l04@/A0P0D3A@0100@
2A003`P?014:4@0A2Q4401094008014:4@0D3QD04`hD00l:400=20h03PT?00l83`0@20l201473`08
01873`0C21004PL?0106300D2@l04`T>01D:400F2a4301052`040147300D2@l05``B014630H040D;
0`0?10X00`0@1@/04`P>0146300201463P0@01D:4P0H3AD06@hF01H;4`0=0PX03`@<00l5300C2100
3@@:01483P0D1`h03`D90185300M41L04@D;01D83`804@@;00X03P4800`01P0?0PT04PD<01<83P0:
0PD0=BX`02/R9P0F31403@@80`0>0`T300d221Cooooo000Kooooo`0500@41P0D51H02`/=03`l?P0F
5QP00P0<30h200h>400;00l?4@0=3@l02@T;010>3`0>30d030X;00/92P0<2P/03@/<00h<3@0@3Pl0
0P0B41400`0?3@h03P`=00/;3@0200d=3`0400`<3P0>30l040hA00h<3`803`X>00T03PT=00h8300=
20`06QLH00X82@0?3@h03P`=00X82@0<2P/01P0>30d03P0?3@h03@/<00l=3P0A3a003@/<00X82@0>
30d030X;00d;300A3a0040h?00h<3@0@3Pl04@l@0P0<2P/03P0D4Q<06QPI014?400;2@X06ALH00L5
1P0D4Q<02PL8018>3`0=2@X03PX;010<3@0=2@X04@d>0P0B3Pl05P0>2P/04Ph?018>3`0?3@`04A0>
03Th=P0@3`d02PT700/:200E51807QdK00l>300<2`X02PT701@C4@0;2PP03@`:00l>300F5A<08B0N
01`K6@0A40h200/:200G010?3@0=30X030/:018C5@072`h02`lB00<72P0<41<02`lB05=GFP3MhN@0
JVia014E600@51L020/=0000000=3@/05ADC00/;2@0:2PP02PT700h=2`0:2@L00P0>2PT01@091@@0
30L700l;2P0>3@/03`h<008040l=00T03`h<01HE4`0>3@`07ahL00/:200<2`T040l=00/:1P0<2`P0
0P0=30X0<P0=30/03@/<01<A4P0A3a403@/>00/9300?3A405A@J028V<@1<Deh06QhW01<H7P093A40
5ATJ00`>3@0<3@`03`l?00L5200=2`l040hC00L72@0<30`04a<C01@D500D51D04Q8D00/;3@071P/0
10<800d<4@081`d030/A00D21`0D3Q80618D018<3@0C2`T02000018>2`0:2@L01@D3024S9@0<4A@0
10P900d<3P0<2P/03@/<00l=3P0>30d03@/<0P0>30d02P0B41407A/L00`:2`081PL05aDH00h<3`0B
41<040hA00`:3@0>30l200X82`0G00/9300=2`h03`d@010>4P0E4aP03@/@01`J7`0<2Pl02`T>00h<
4@091``01`D:01DC600A3a@03@/@00401016A4T06aTN00X93@0C4AH06aTN01DC600C4AH00P0<2Pl0
4@0>31402PP=00d:3`0E41H061<I00h93`0500H02`H<00d83P0?2Q0040/A00/6300>2@l05Q4G014?
500=2a002PP=008030X?00D02@L<018@5@0:20d03`dB01HD6@0200`:3`0900<1100:20/02@L:00d;
3P030@@06aTL01DC5P0>30l02PP;00803@/>00l03P`?02<Q900H5QT03P`?014?4P0@3Q403`d@00P6
2@0100803@/>00D31P091`X02PP;00/93P0=2a000P0>31406`0=2a002`T>00`:3`0;2@h01`D:01HD
6@091``0:2H[01@C601DDeP09RDZ01TH7@0=31400@0400/93P0:1``03`X@010;4@0?2@l04PdC00h9
3`0<2Pl03@/@00`:3`0;2@h02PP=00/93P0400`:3`0D00d;400:20/03@/>00h<3`0F51L04a4D00T7
2P0<2Pd040hA00X82`0>30l02PP;00`:3@0@2`l03PT=00d8300>2@d03`X>010;3`0>2@d300d83080
30L;00d061<G014<400Z9BT0Yj:V018=4@0;1PX040/?01PC5`070PH03PT=01@?4`0300803`X@0080
3PT?00@040/A02DP9P0A31803`X@0`0=20h00`0?2Q003PT>00`72`0300h93@0300`72`0=20`03PT=
00803PT=00D03@P<00`72`0;1P/04@`B01<>500200h93`0G00d83P0910X04`hD00L2200?2Q002@@:
00h93`0>2A403@LA00`6400>2A4040/B00d83`0;1Pd01`8800/62P080`L05A0D01<>4P0;1P`040/B
00d83`0500L00P0;1Pd01P0Q72<0=C0g024L8`080`X03@P?00X530H03@P<0P0<1`/300d8300900h9
3@0;1`P04@d>00`82@0?2``03@T:010<3@0=2@X03PX;00803`/<00@03PX;00d92P081`D02@P40P08
1`<0100;2PH03`h:01@C3`0?3PX200<2000900P70`030P003PX;00T51P0Q7Ah030P901<?40060P<0
30P900803`/<0P0>2P/0500?2``02PP;01/K70000000<C4a0;:a/00I61H05QDC00`9200J5QD05Q8A
00X61@0;1`P03@XB00l<5@0B3aP030T@08b:S`1<BTl03P`?0P0<2P/00`0<2`T03@`:00h=2`0300/9
2P0600d;300>30d03`d>01<A4P0@3Pl03P`=0P0<2P/0100=2``03P`?00d;3P0<2Pd200d;3P0;00h<
3`091`X04a4D00D31P0H5QT00@0201TG6P0?3A003@/>00/9300=2`h00P0>30l0100?3A004@lB00l=
400>30l2014?4P0600d;3P0?3A004Q0C00d;3P0;2@`03@/>0`0>30l07@0?3A0040hA01@B5@0P7R40
9bDX020N8@0E4aH0518G018?5@0;20l0104800X73`0B3aP040dF01@B6P0@3aD03PdC00T83P0=3180
4a8H01@C6@0A41H03PdC010?5@0A41H04a4G01@=500D3Q804`hE00804@hG00`040hI018@6`0B41/0
514J01HA600F4AL0618G01PE700C4QP051<H014@5@0;2Pl201LG6@0701HF600D51@05ADE01DE5@0A
4A404a<E01@D5P0301DE5`0401@D5P0B4Q@05QHH01HF608051@F00P05ADG01@C600C4QL04Q4F01<B
5`0D4aP04A0E01@C60804Q4F0P0D4aP00`0A41D040hA01<A500201HD5`0301TG6P0M6ah05A<F0080
518E01805A<F01@B5@0@3Q404Q8D01@D5P0B4Q@04A4C018A500?3A005Q@G01TE6@0I51P05a8F01H@
500G4AD06ADF01/G600H51D2018>3`0301DA4P0D4140510A00<0510A00D0510?018>300B3Pd04`l>
018>3@02014=3P0901LC500@2`l04@`@00l:3P0A31804PdA014<3`0<20T03PX;00805A4B1@0C3a00
0`0A3@h040/?00l:4003010;4@803`X@00`040/A00@01@0910X01`8801HA5`0H4QP03`P?00H01P0>
1`h05@hE00h73P0;1@/50109400301<=4`0B3A<03`X@00803`X@00@03`P?01073`0A1`l04@L?0`0B
1`l0300@1@`04PL=00l52P0F2a402P0501873@0N4aT0>Rle05A9C`0?10X01`0201H;4@H03`@:00@0
4PL=01<83P0?10X03P<90P0D2@l00`0A1Ph03`@<00h32`0201053@0=00l4300E2Q804`P@00l4300G
31@03@8:02dR:P1MD5L04PD<01H9400A10/0?C0g03HY<00201442`0;00d01`0<00H03`8901D83`0B
1`d02@0401T>500C20h01`0201<83P0@1@/00P0?10X200h32@0300d22?oooooooooo01;ooooo000K
ooooo`0>00l>4`0820/0BDU;0<[9cP0N7B404a<E00T83@0C4QH03`lA00/:3`0=3A003@d?00l=400>
30d200`:2`0400l=3P0@3Pl02`T:00h<3@8040h?00T03@/<00/92P0:2@/03@/>00/;3@0;2@`03@/>
00l=400B41<00P0C3Q801`0B3A404P`@014<400@3@h02`T:01PF5`0I5aP00P0A3a0600d;300a010<
3@0>2P/03`/<014>3`0>2P/020L500l=3P0<2P/03@/<018@4P0A3a8030X=00`<300A3a003@d;010@
3P0N7AT0;RhY02<T7`0>3@/040l>0000000G5AH04Q0B01<?400=20`04Pd@010<3@0<1`/04@d?01<?
400B3A403@T;018>3`0B3A403@X:01LF500d<c408B0N018A3`0<2`T040l=00d<2P081`D04Q4?00D4
0P0A40h03Pd;010?3@0200`;2@0S01@C4@0920H06APF014@3P0>3@/040l=00/:200920L020T;00<4
1P0?41801@H800l@4P0A4Q@0ATM90>c]k`1bLgD03@h@00H72@0=3Q005QHF00l?3@0410803Ph<00/;
2@0<2`T03Pd;00d9200A3@`04Ph=00l92@0C3@d03PX900d<2P0@3`d00P0A40h0900?3P`00@00014@
3P2AT8h0B4M500l>300>3@/02`X600`;200=30X03Pd;00h=300>30d05A<D01@B4`0?3@h030X=014?
4P0H5ad0TIFP0=CIgP0h?4D04aHM00d@4`0620L02`d<00T:2P0@41802`T<00d;40050`P02`/=018B
4P0:2PX03Ph>00d=3P803@d?01@04Q8D00h>400:2@h02`X?00l=4P0C41D03PT?01@?4`0=1`T040X:
014;2`0?2PX04@l@01TI6@0720/0004401@E6@0>3@h03@/<00h<3@804@l@01<03`d>01@B4`091`P0
108300d;300:20T040h?00`:3@0A3a801@<600/9300?3A0040hA00`:3@0=2`h03P`?00`:3@0;2@`0
20H:008030X?00<0518G00l=4P0F51T00`0;2@h0400@3Q<01P@9014?500=2a005aDJ00H42@0D4QL0
0@04020N8`0;2@h03@/@00/93P0=2a002`T>00h<4@0D4AH2014<4P0J00d83P0A318040/A00T42P0A
31804PdC00l:400L5ad0;RT_01<A5P0>314030X?014?500B41D040hC00`:3`0I5a`030X?00D3200D
4QL02PP=00`:3@071@P03P`?00L5200?3A0200h<3`802PP;01402@L:00P62@0B41<081hQ018@4`07
1@P03@/>00l=400>30l040hA00400P0:20/02`T<018@4`0@3Q4030X?00d;400200l=4P0300d;400<
2Pl02`T>00803P`A01003`dB00h<4@1/JVl0WifR010?500D4aP02`T>010>4`0C4AH02`T>00X6300?
2Q0040/A00l9400B3A<03@P>0P0<2Pl200/93P0300T7300;2@h030X?00803@/@00l03P`A00l=4P0:
20d03P`@00X82`0=2`l03@/@00L5200@3Q802PP=00800`0=2`l030X?00d;400?3A800`0<2Pl0900>
31403`d@00d;3P0>2@d03@P<00d82`0<20T02`L800h93@0=20`04`hB03Td>00C3Q806A@H010;3`0<
1`/050lC00h93@080`L03`X>00h93@060@L030L;00D11@0C3Q@03@P=00l:3P0=20h030L<00d8300?
2Q003PT=00`72`0>2@d03`X>00h93@8030L;0`0>2@d03@0=20`030L;00`73@0C3Q@05A0G010;4@0?
2Q003@P?00`73@0G4QP020<:00h9400910X00P0A31<0100;1Pd02P@>00d83`0?2Q4200`73P0A00T4
2P0>2@d050lC01hI7@0>2@h04PdC00P32@0;1Pd04PdD010;4@0A318020<:01HA5`21O8<02PD<00l:
400A31801P0=20`06`0;1PX030L;00d8300=20`03PT=00l:3P080`L04@`@00`7300C3Q@050lE00`7
2`0>2P/03PX900l;2@0?2`X03PX900d9200C3`h02`X600H50@071P8030/700l>2P0<2`L01PD2010?
2`0200h=2@0R00L6100=2@X05Q8C03Te=P0<20T04@d>00d92P0:1PL03`/<018>3`0@30d03PX;00`8
2@0@3Pl020L701TI6@0R8240Hf9Q018A3`061@<040d;00X60`0C3``02`L4018>3@0=2@l081dT0080
1P0B41D040hC01TG6P0=2`h030X;00/92P8030/902/03@`:00l>300=2``02`X800/92@0;2@X02`X8
00P71P081PL02`X8018@400I5aP071XK00h<3@0=2``030X;00d;300=2`h03P`?010>4@0@2`l050lC
00h93@0L5a/020<701<A500@3Q402`T<00`:3@0=2`h030X=010>4@0B41<03P`?00T72P0=2`h03`d@
010>4@0C4A@040hA00T72P0<2Pd03`d@008030X=01803@/>00l=400@3Q402PP;00h<3`0H5QT04a4D
00H41`071@X02`T>018@5@0@3A@0514H00d:4@060`X04Q0G00`;4`0C4QX201DD6P0=00h=4P0D4aP0
4A0E00h=4`0?3Q@04Q4I01@B6@0D3aD05@hE01<?5P0B3aH04PlH014@6002018A6@0C01@A6@0D4AP0
5a8H01PB600F51T03PdC00l>4`0=314030/@03De=`0F5QP05ADG01@D5@0E5AL05aLG018B4`0E5AL0
5QHF01LG600201LG6@0401HF600E5AL061PJ01LG6@804a<E00<05QHH01LF6`0D4aP00P0C4QL00`0B
4AH03`hC01PG700201DD6@8061LL00P05A@I01<A500C4A@05Q@G01TG6P0H5QT04a4D01DC5P804a4D
00/0518E01<A500?3A00410B01<C5@0?3a4051@F01XI6`0A3a804a4D01DB5@0201LB5P0801HA5@0E
41@061@E01PD5@0E4A804`l@01TE5P0N6Q/601@@4@<05a<B0140510?010<3@0>2P/05A4B00h93@0@
2`l04`hB01HA5@0B3A404Ph@01hJ6`070`@04@d>01PD5@0I5AH040`=014=3P02018>3`09014=3P0@
2a003`X@014<4P0B3A<04@`B00l:400@2a404@`B00804PdC00T02PD;01PC6@080`T03`P?0109400>
1`h02`@;00l83`0D3A@00P0A2Q406P0@2A003`P?00l83`0A2a804@`B00l:400@2a404@`B014:4@0C
2a805@/C01@:4P0A1`l03P@<00h2300D2A403@8801D:400J3aD01`0201<93P0B1`d05``B03H]<@0A
1P`050T?1`0?10X0600900@04@H<01<83P0?10X04@H<00d2200>0`/040H>01P>5P0N4a/0714I01@9
4@0;00P05P/C00/1200G31@05P/C01053@0I31<0200201062P0I31<04PL<01442`8040<:0P0>0@P0
2P0C1Pd060/B00d2200C20h01`0200`11`0M4QP02P050146300@1@/200l42P803P<95?ooool001_o
oooo00`04PlF00h;4@0E4QP0:BH]00l=4`0=2a003@XA00/93`0=2Q003``C00l=4`0<2Pl2018B500=
01TI6`0>3Q003`h@018@4`0?3A003@T=014<400?2Ph03PP<018<400B3Pl04@d>010=3P03010<3@0<
01`H6@0?2``03`/<010<3@0=2@X03PX;018>3`0@30d0Ee=D03Pd=@0A3@h05A4B0P0?2``02`0@30d0
4@d>014=3P0A3@h04P`@018;3@0A2`d04@`;014;2P0A30T04Ph<008040`=01d040/@010=4`0>3180
2``>01<D4`0>40/05aX?03/n<@3Gfl`0GF5D01DG3@0@4Pd02P`;01@D5P0A41@08AlS01lM8P0?3A80
4@lC014?500C4AD030X>00l=4P0@3Q80518F0040100>30h04A0>020O7@02010?3@0300P71P0@3`d0
3`h<00@03`h<02P040d<014=300A3@`03PX900d9200?2`X04`l>018>3@0A3@`040`;00l;2P0>2`X0
3`h=014A400;2PT02@P8018A400=30`03`h=02l_;P0M7A`040l>014@3`0;2PT03`h<00H50`0>3@/0
20L500/:200=2@P04@`<018<300>20P040P901H=3P0D3@d0:BDT01TH5P0?3P`040l=0P0=30X300`;
2@0400h=2`0K6QP0:2LU00`;2@<03@`:0P0>3@/04`0E51808B0N0040000A40l03P`<02PW:01ZJW40
UYFM024Q9P0=3Q402``;014A3`0>3P`03`l>00d=3`0=314030/B00P73@0<2Pd00`0=2``200h<3@0=
00l=3P0>30d03@/<00d;3@0<2P`030X=00d:400C41L02PL=010<4P0<20h03`/B00h;4P0200`93`08
00d;4@0>31803P`A00`:3@0:20/03@/>010>4@0=2`h300/9300B018@4`0@3Q404a4D00D31P0=2`h0
4Q0C00810`0A3a802@L:00h<3`0F51L04a4D00`:3@0=2`h02@L:00`9300>2@d03`X>0P0@2`l06@0>
2@d040/?00`82`0G4QH02PH900`72`0B3A4030L<00l:400A318040/A00l:400@2a403PT?00d83P0A
318040/A00/6300B3A<0;2L]00T42P0L5ad03@T>01<>500;1P`00P0@2a401@0<1`d040/A00h93`0O
6R004@`B00803`X@01`0100500`73@0A31802PH;00`73@0D3aD03`X@010;4@0?2Q0030L=014<4P0@
2a403PT?01@?5@0>2@l04PdC00l:400=20h06QDK00T42P091@/03P`?00T92`0B4Q@03@d?00P82P0B
4Q@03`lA0P0>3Q0200d=3`0700l?4@0=2`h03`d@00h<3`0=2`h03P`?00l=400200X82`0=00l=400<
2Pd03`d@02PV:P0_;3403PT@00d9400S7RD03`XA00h9400=20l04`hE018=500200h9400601<>5@09
10/040/B00L32@0G4QT03@P?0P0?2Q407P0@2a804@`C010;4P0?2Q4030L>00/63@0>2A002@@;010<
4@0@2a804@`B00d83`0?2Q404@`B018=500A31<03``D00/;5@0A4Qd01@L@05UHH@0f=S`04Q8G00X9
300<2`/02@P800l=300A40d03P/9018<3P803@L90P0A2`d0100?2@/03PP:00h82P0?2@/3010:3007
014=3P0?2`d03PX;00h92`0>2@`03PX<00h:2`0200h:300800h:2`0>2P`03`X>00l:400>2@l03@P>
00h93`0?2Q0200h93`0=00`73@0>2@l05a8H01D@5P0>2A0030L?01<=5`0N6B8030L?01@>600910d0
3PTA00h84P02010:4`0400h84P0=20l03PT?00h940<03PT?01<03@P>024L8P0J5A/03@T>01hI7`0E
41H04`hC00H11@0A3100If9W030[;`0A31003`X?01D@500J5AT04@`A00`72`0=20`040X=00803`T;
01X03PP:00l92`0@2P`03PP:00`6200@2P`04P`>00l92`0?2@`03PL=014:4P0T72P04@TH01@<6P0?
2A004@`:01D@2P0C3`H05A09014=200B3P/040`:00/71P0@30/04Ph=00h:2@8040`;00X0:bLV00`8
1`0B3Pd030P700h:2@091@H04`l@01HB4`0A3@h030P90P0=2@X03@0>2P/03`/<00l;300>2P/03@T:
018>3P0?2`X03`d;01@@3`0F4Q404`l>014=300@30/00P0>2PT01`0@30/04@d<01PD5P1^JF`050lB
014=3`0>2P`00P0?2``300h:2`0400l;300?2`/04@d;010<2P803`/800@03`/900l;200?2`P03`/9
0P0@30T01P0?2`T03PX8018>300A3@/040`:010<2`803`/;01004`h?010:300D3Q005@dB018;3`0C
3A403``?014?4P0=2`h03`d@00d;3P0C4A@02`T<00l=400>30l04@lB0P0>30l01@0:20/04Q0C010>
4@0?3A0040hA00803`d@00D040hA01@B5@091`X061HI00h<3`0500l=400f010>4@0B41<030X>00h<
400F51P04Q0D01DC6`0F5200518M014@5`0@3a@0410A014A4P0A4A<04A0E014@600B41/04a8L01@B
600@3Q<04Q4F01LF6`0B4AL03`hC01@C600B4AL040lE018A5P0D4QL04a4F00d<4@0A41D05A@I01@C
600F5AX06QTN01DD6@0K6Ql04A0E01hM8P0G5QX04Q8E01@F5@0G6AH05QPF018D4P0C5A<071hM00h?
4@0?41805aPJ018C5`0E5QX03a0D0P0B4AH201<B5`8051<H01T03`hC01<B5`0G5Q/05aHK01DD6@0A
41@05Q@G01HD5@0H5QL05Q@E018@4@0F51D0518C01TG600J61T05Q@E018@4@0A3a005Q@G01LE600D
4QD04Q0C014?4P0C4A@071XM00806QPK00@04@lB01PF6@0F51L04a4D0P0E4aH201@B5@0I01HD5`0A
3a803`d@00l=400O7B003P`?010>400F4Q<04Ph?01DA4P0C3a004Ph?01HB4`0A3@h040`=01LC500A
3@h0510A010<3P0C3A4030H:00/62@0D3Q807QPL014;3`02018<40804`dA00L04P`@01093`0A2a40
9AhU01dF7@0?20l04``C008050dD0P0C31<0400B2a8040T@014:4@0=1Pd0614H00h83P0>2@h06Q<J
03hg?P0C31<02P@:01@=50090PT05a0G00d7300@2Ph201@>4P0D014;3`0@2A0040T@01094@0=1Ph0
4``D00d63`080@X04PTA00d22P0C210040D=01T>5P0>1@/05P/C00`22@0=0`X0714I00/1200A1`h2
010330804@@=00T04PD>01<63`0>0PP04@@;01<63@0A1@T040@801462`0?1Ph00P0>1`h301063P80
3`D=01803`@<00l22@0@0`X04@@;01052P0A10/03`D900`01P0Q5A/0>Rdd01032P0?0PT03P480103
2P0D1`h05`XA0146300@1@/200h32@803`@:00H02`8601L<4P23N7h0=2T_00d3200C20hDooooo`00
6oooool02@0610T04@lD02XX;@0@3Q<08R0U01TG700>31403@/@00h<4@02010>4`0@00d;400>3Q00
ATI80;Ng^@0/;2h04a8D010>4@0<2Pd03P/>014<400=20`03PP<01<=4@0>2P/03`/<014=3P804Ph?
00T04@d>00d92P0@30d04`l@00l;300>2P/04`l@01DA4P0400400P0:1PL01@0L61T03PX;00l;300?
2``040`=00<04@d>00@03`X>010:300@30d04@d<0P0B3P/0900A30T04@/=014;3@0C318050dE01<@
5P0;2`d05QHF00d>2@0A4`P08bDH08V;O@18BS`030h300/<1`0C4a<04Q8D010?4`0;2@`020H900`:
3@071@P04a4D05IDE`0A3a800@0204U7BP0n?3l06aTL028P8P040`401@@200d<2P0N7A/040l=00`;
2@D03@`:00D03``;014=300@30/03PX900d92007010<2`800@0001d0;bh/00L6100D4a403`h<010?
3@0A40h03@`:00L6100?3P`030/900l>300<2`T051<A01TH5P0@3`d03@T8018<300C3@d03PP800`3
100@1`P03`P8024M700C4Q0020L500T81P0:2@L030/900h=2`02014@3P0400h=2`0<2`T02`X800`;
2@803@`:0`0>3@/050040`403Pd;00T81P0B4@l03Pd;00l=3P0000@04a8H00H52P0?3a402@T801<D
3`0>3`X03Ph=00`<3P0:2@h02PT?00`;4@0?3A003`d>0P0=2``00`0<2P/02`T:00`:2`0300d;3009
00h<3@0>30l03@/@01PF6`0=2a0040hC00D320081P/02`T>00803`dB0P0=2a004@0@3Q<040hA00X8
2`0I5aX01`D800400P0<2Pd02@L:018@4`081PT00P4301<A500P7R4040hA00P62@0E4aH03@/>0080
4a4D00H04Q0C00l=400;2@`03@/>00T72P0?2`l3018=4@0<00l:3P0>2@d03`X>00d8300300802`L:
01@?4`0@2`l03@P=00l:400A318040/A0`0>2@l00`0<1`d03`X@018=4`0200`73@0h01XE6`0G4QP0
0`0402DP9P1hLgT0;RT_00L3200E41H040/A00X52`0?2Q002`H<00`73@080`T06A@J020K8@0F4AL0
40/A00`73@0L5ad02PD;00H11`0@2a403`X@00h93`0?2Q0030L=00/6300B3A<02PD;014<4P0C3Q@0
2PH;010;4@0;1P`040`B00400P092@/01`L900d=3`0?3a402PX<00h>400?3a404Q8D014A4`0?3a40
30`>00l=400@3Q403`d@00d;3P0<2Pd03P`?014?4P0;2@`2014?4P0900X82`0=2`h03`X@01@=500:
0`X04``C01PA600B2a803PL>00804P/B0P0?20l0200C31<050lE00`73@0D3aD020<900d83P0H4aT0
3`X@0`0@2a400`0?2Q003@P>00T42P0200h93`0301LB600;1P`05Q4G00803PT?0P0?2Q003`0>2@l0
2`P?00H74P072Q<0I6M`01HF7`0G5Q`02@P=00h>4@0;2@X030X;01LF500G5Q8040l;00l92`0200`6
200300l92`0>20X03PP:00804@/=100@2P`300`82@0:00d92P0>2P/040`=010<3@0?2``03PX;00d9
2P0<20T03@T<00`73@802`H<01D03@P>00l:400A31803`X@00h93`0?2Q0050lE01<>500A31@040XD
00X43P0A2aD02@<=01PB700=1a4030H@010:500?2A<02`D?00`6400=20l01@0=20h0300:1@/0>SDk
02lZ<00300@040/A018=4`0?2Ph02@@800P31`0O6Qh030L;00h93@802`H:00@03@P<00l:3P0?2Ph0
3@P<0P0A2`d0:@0@2P`03`T;010:300A2`d03`T;00`6200?2@/04P`>00h82P0@2P`04@/;01@>3P0L
5A/02`@<01PA6@0B3@d05Q89028O400_;1T02`P0018?1P0K5`h04@d:00l;2P0>2PT030P700X61@0?
2`X03@T801XF5@0<20L0510?00T5100<20L02`L800h:2`0?2``03PX;00`82@0:1PL03`/<00@040`=
00T03`/<00l;2P0>2PT03`/:014=300C3`h04@d<00h:2@0?2`X00P0@30/02@0?2`X03PX900/7200L
61T01`<4010<3@0?2``04@d>010<3@0300l;308040`=00H03`/:014=300B3Pd040`;00d9200;1`H6
00l;2P<03`/801X03PX900h:2`0>2P/03`T;01LA5@0F41@04`dA014;3`0?2@d04@dA00d;3P0;2@`0
3`d@00<110040`D05A<F01<A500<2Pd020H900@21@0B41<0:BLZ00X82`0?3A002@L:01DC5P805Q@G
00D05A<F01<B500200<071XM01@B5@0500l=400D010>4@0B41<040hA01dK7P0G5AP02`T<018@600B
41d04Q0K018A600A41D0410B00d=3`0?3a404Q4G01@C6`0C4A`04@lK01HE6`0A41D200l>4`0300d<
4@0A41D04Q4F00804A0E01/051<H01DD6@0D4aP05A@I00l>4`0B4AH03@`A00l>4`0/:c00D4mD018A
5P0O7R<0DU5F020O900G5QX04Q@C01DG500G6AH04Q@C010B4@0B51<05QLI01DF6@0G61`03PlC01DF
6P0G61`00P0B4AH301<B5`0;01@C600C4QL051<H01DD6@0D4aP04a8G018B500H5QT04@l@01<A4P0F
51D00`0C4A80400F51D05A<D01<A4P0B41404a4B01HD5`0E4aH04@lB010>4@0C4A@061HI010>4@0F
51L07adP01DC5P0G5AP2018@4`805A<F00L04a4D018@4`0B41<04Q0C010>4@0B41<071XM00803P`?
01805a<D01DA4P0G4a@05A4B01<?400E4A80920Q01XF5`070`@04@d>010<3@0Q7Ah05a4E01H@5009
0`L03@L;01@>4P0C3A42018<40804`dA00P04P`@00/62P0T7B@0`K[106eVK@0700L04P/B00l83`80
4@XA02L04P/B014:4@0?20l04@XA00/42`0?20l050dD01<<4`0700L05a0G018;4P0;10/03`P?020I
800>1`h03PP=014;3`0B31004@/?00h8300=1Pd04@XA01L@600D3AD0610J018:5@0;0`h050/D038W
;`0h;CD03@8:00/0200J3aL04`P@00`12@0D2A405@XB01dB6P0D2a400P0B1@l301443@070103300;
00L040<<01D83`0B1@`04@@;01L;4@0301063P<04@H>0P0@1@/300l42P0901452@0<00H03`8901<6
3@0D1`h05@P?01L:4@0@0`X03`8900803P4800<04@@;0185300?10X00P0?10X02@0@1@/04PL=01<8
3P0B1`d03PD902<H7P0E2Q003`@:00L00P0Dooooo`006oooool01P0B41D02`T>01DC600100@02`T>
00d;408030X?01403@/@00h<4@0>314030X?01DE5`0o?d40Zj^]01<C5@0=30h03`d@00X82`0?30l0
4@`@00`72`0>20`04`dA014=3P02010<3@03018>3`0C3a00510A00804Ph?00X0510A010<3@0=2@X0
4@d>00h:2`091@H05a<D014=3P0B3Pl02PH70P0?2``0100@30d04@d>014=3P0A3@h200d;3P0K00h<
3@0B3Pd04`l<01<?300B3@X04@/;010:300A2`l04P/B01D@5`030`D02PP9018B3@0G6@h01`L001`N
400F60/030`201<C3P0>3Ph020H900L52@0A3a806aTL01DC5P0B41<0518E00805A<F00T08R0S00d;
3P071@P040hA00H41@0:2@L01`H401@C4@0100000P0@3`d500d<2P07010=300C3`h04`l>014=300@
30/04`l>00l;2P04010<2`0U014=30071P@040l=0450?P0=30X020L500l>300E518040l=00h=2`02
0@0040l=00h=2`0920H04Q4?00X91`071P@00P4001@@3`0=1`L040X:01<=3@0J4A8071<D00l8200;
1`H02`X8018A3`0F5A<051<A01<B400>3@/04A0>01<B400B4@l03Pd;00/:200200d<2P803Pd;0P0?
3P`200h=2`0B01@C4@0E51805A@B00/92P0>3A802`X?00h>400@410020P500h?2P0=3PT02`/800l?
3`0A4A<03PdB00X93P0>30l03P`=0P0=2``400`:2`0Z00d;300>30d03P`=00l=3P0:20/0108700P6
2@0:20`05Q@I00d;3P0;2@d04Q0E014?4P0;2@d02`T>00h<3`0@3Q402`T<01/I700A3a8040hA01@B
5@0;2@`04@lB00d;3P0L6Qd040hA00X82`081PT05A<F00h<3`0<2Pd0518E00L5200>30l03@/>00/9
300>30l02@L:00`9300<1`/03@P<100>2@d02P0910P05A0D00T5200M61`030L;00h93P0C3Q@050lE
018=4`0@2a4200l:400300X52`0910X03PT?00803PT?00P02PH;00l:40080`T05A0F02lZ<00400D0
4PdC01@?5@8030L=02404PdC00l:400;1P`040/A00d83P0300@04@`B010;4@0C3Q@05a8H00H21`0H
4aT030L=00`83@0>2@l030L=00/6300D3aD07APN00`73@0?2Q004`hD00X52`0A31804PdC01<?5@0I
5aX071`N00H6200;2`d04Q8D00/;3@0?3a400P0@41808@0?3a403@d?00/;3@0?3A0040hA00l=400<
2Pd02`T<00`:3@0J61/020H900T72P0B41<040hA00`72`090`L050hC010:3P0A2Q4040T?00L11@0?
20l04P/A014;3`0?20l03`T>018;4P0E41H03@P>02PS:@0<1`d040/A01LB6002018=4`804@`B00P0
40/A00l:400K5Q`050lE00H11`0:1P/07APN00d83P<03PT?01003@P>00`73@091Pd02P/F02@W<00b
=Ch0000700X93`0<2a402PT=00X82`0=2``05Q@D01PG5@0G4a803`T;0P0>20X200l92`0500h82P0A
2`d04@/=010:300?2@/00P0>20X07P0>2P/03@T:00`82@0=2@X03PX;00d92P0<20T03@T:00h:2`0?
2``040`=010;3`0>2@l030L=00d83P0?2Q004`hD018=4`0=20h030L=00d83P0?2Q003PT?00/63@0=
1a401`4;018<5P070@/03PPB00X43P803PPB00@030H@00T33@0:10h03@P?1@0?2Q002@0=20h06A@J
01PC6@0:1@/03`X@018=4`0;1PX03@P<018=4@0200`72`0900h93@0=20`03@P<00d8300>2@d040/?
014<400A2`d040X<00<03`T;02004@/=00l92`0<1PP03`T;014;3@0>20X040X;01<>2P0E40`050h?
00@00P0E3a4040X7010<0017A340XIn704A2;@0N6`T040`1010=200@30/03`/:00d9200?2`X05Q8A
00d9200@30/03@T801DA400:1PD03@T8014=3P803PX;0P0A3@h00`0=2@X03`/<010<3@03010<3@04
00l;300>2PT03PX900l;2P<040`;00l03@T800l;2P0A3@`04@d<00l;2P0=2@P03`/<00D10P0;1`P0
3PX;010<3@0>2P/04@d>010<3@0?2``00P0@30d01`0A3@h03`/:010<2`0A3@`040`;00h:2@0=2@P0
1P0?2`X300h:1`0<00h:2@0>2P/03PX;010:300D3Q803`T=014;3`0D3Q8040/?01@B5@081PT02PP;
0P0=2`h04`0D4QD040hA00T72P0B41<03@/>01PF6@0k>C`0IfEX02LU:00K6A`00P0300h<3`0@3Q40
6aTL00L5200E4aH04a4D00d;3P0<2Pd01@0@3Q405@0<2Pd03@/>01HD5`0_;C0081hQ00/9300@3QH0
40hI014@600C4QT04Q4F014A500?3a40410B018A5P0C4QX04Q4I014?6P0H5ad04A0E00l>4`0301DD
6@0O00d<4@0@3a@05aHK01`K800J6Ah04a8G01TH7@0100D05A@I01TH7@0G5Q/0O7^00>;QiP1FEEX0
5A@I030_=00;2Pl06APL010B4@0B514051HC018D4`0A4a804aDD01XK7@0F5aX06AXN01<D600J6al0
6AXN01DD6@0601HE6P0601DD6@0D4aP04a8G01<B5`0C4aD05A<F0P0D4Q<2010>3`0G01XH6@0D4Q<0
4a4B018@4@0A3a004a4B01DC500C4A@06ALJ01`J7@0J61/05Q@G01@B5@0@3Q404Q0C01LE600@3Q40
6ALJ01LE600B41<05A<F01HD5`0C4A@00P0A3a801`0E4aH040hA00l=400@3Q403`d@01@B5@0C3a00
0`0A3@h03P0C3a005A4B00X71`0K5aP04Ph?01@@4@0<20T02`L800`62P0400809AlS01D?4`0F41@0
2`D90P0B310201<=4@08018<400F3aD0100402LP9`0?2@l07QLN01XC6P0A2Q42010940804@XA0180
3`P?0109400>1`h030D<01H?5P0G41L02P<:018;4P0G41L0614H00T22@0@2A001P0601<=4P0A2`l0
4P`@00l93@0<1PX200`5300E014:4P0600L01@07018:5@0C2aH030D<00d22P0O51`060dE01T>5P0A
1Ph04`P@00T01P0E2Q802@0600l4300;0PP04`H@01853`0B1@h04@@=008040<<00H04`H?01P;500K
3QH050L@01032P0E2A4301053@0401443@0@1@d040D=01052`<03`@:00<040D901862P0A10/00P0A
10/00`0@0`X0304600P00P0201032P803P4800<03`8901032P0?10X00`0?10X0200A1P`04PL=0105
2`0<0`L01`0200P00`0@1@/01`025?ooool001_ooooo00L0OWb1034_=0081P/05aDJ00h<4@0B41D0
3P`A008040hC00/03`dB00h<4@0>31403@d?00l?4@0E5AL0410B00h=400?3A003@/>014=4@02010;
3`0D018<400A2`l061@E018>3`0?2``040`=01<?400F4Q<04`l@00d92P0@30d04@d>00l;300@30d0
4Ph?00l;300@30d03@T:018>3`0A3@h200l;300^010<3@0A3@h04@d>00l=3`0<3A003@hA00h>3`0A
40h04A0<01<@3@0C3P/04`X;01892`0B2@h04PP@01<;4P0?2`l05A4B00h;200=2`@03``2018@1P0K
6@l06AH>010=2P0=2P/03@P<010>4@0F51L07adP018@4`0:2@/0:bT/030_<@0G5AP01`H8010>4@0D
4QD03P`?018@4@1VIF<051<A014@3`0=30X05QDC014@3PD03`h<00<040d<014=300B3Pd00P0@30/0
0`0C3`h040`;010<2`03010<2`08014=300:2@L04A0>038a;`0D4a4030/9010?3P0920H200d<2P0K
00P71@0A40h03Pd;00D40`0F5A<04A0>030_;@0M71X040`;018<300@2PX04@/;020G600W7Ql06a<D
01@@3`0>3@/03`h<01/J600I61H01`H400h=2`0<2`T02`X800`;2@0=30X030/900<03Pd;0P0?3P`0
2`0@3`d04Q4?00L6100>3@/030/901@C4@0A40l02PX;00/;300<30/02P/700802``700H08B8M00h?
2P0;30P0410?00h>3`0<30d200`:2`803@/<0P0?3@h00`0<2P/03@/<00d;300200h<3@0@00l=3P0[
:BX01@<5010>3`0B4140BDM903Tg>00>30h04Q0B014?400;2@X02PP:00`:300A3a800P0300`:3@80
;B/^00D040hA00`:3@0A3a801P@702PV:@02014?4P0?00X82`0E4aH020H9018@4`0>30l0518E00`:
3@0=2`h02`T<00l=400:20/03P/>010;3`0?2Ph03PT=00803@P<00X03`X>01HA5@1ED5@040`?01LB
5P0910P04@`A010;4@0B3A<04@`B0P0>2@l0EP0?2Q003PT?018=4`0J5A/05A0F00l:400>2@l04@`B
010;4@0>2@l030P=00H21`0A318030L=00X52`0M61h04PdC00`73@0=20h04`hD02/V;00H4aT06QDK
00d83P0?2Q001@0601@?5@16@DL071LM010;4@0A31803@P>010;4@0T7bD0;bX`01HA5`0?2Q004`hD
00l:400B3A<040/A014<4P0H5aT02`/=00d=3`0@41803Ph@014A4`0@41803`lA00/;3@092@/02PX<
00`<3P0A3a804a4D014?4P0?3A003P`?00l=400<2Pd06QPK01dK7P0A3a802`T<01LB5P0O6A`04PT<
01L>4@0B2@d03`H901L>4@0A20`04PT=0189300A20`04PT<014:3@0<1P/03`X@02/V;00F4AL03`X@
00`73@0@2a403`X@100>2@l02@0B3A<040/A010;4@0F4AL0XIbR03`g?@0?2Q003PT?00d83P0200`7
3@0>00X73@0L72D0<30j00P84@0;2a<03`lD00`;4@0;2@h040hA010>400=2@T03PX901@@3`0@2P`2
014;3@<040X<0`0?2@/0200>20X03@L900d72@0C3a004@d>00l;300>2P/03@T:1P0>2P/01@0>2Ph0
3@P>00d83P0=20h03`X@00804@`B00<03PT?00d83P0?2Q000`0=20h02@0B3A@01`8901HA600@2a80
4`hE00l:4@0=20l030L>00d83`0200h9400300l:400>2@l03PT?00<03PT?00l040/A00d83P0>2@l0
40/A00d83P0?2Q002`H:00d8300B3A401`86014<400@2`l03@P<010;3`0A31000P0<1`/06`0A3100
3`T;00l92`0>20X03@L900h82P0?2@/040X<00d72@0?2@/040X<00h82P0A2`/03`/200h:0@0@2`H0
2@@201LB3`0I5@`0?3TW09jLQ03moN40V9Ml02LU4@0A3@<04@h9010<2`0200d920804@d<00T040`;
00`81`0?2`X04Ph=00h:2@0?2`X04Ph?00h:2`0?2``00P0B3Pl00`0?2``03PX;00l;300300l;3004
00h:2`0>2PT040`;010<2`803`/:00<040`;00h:2@0@30/00P0A3@`02`0@30/03PX900l;300?2``0
4`l@00/7200A3@h03@T:014=3P0@30d03`/<008040`=00<04@d>018>3@0?2`X00P0>2PT0200?2`X0
40`;014=300?2`X03PX900l;2P0@30/04@d<0`0>2PT0100?2`X03`/<00l;300B3A4201<>4P04014<
4P0=20h02PL<00h<3`804@lB01D01P@702HT9`0k>C`04Q0C00`:3@0Z:2/040hA00l=400:20/08AlR
00P62@0H5QT02`T<010>4@0H5QT00P0301LE600A3a801`D803Le>00@3Q401@0A3a802`0C4A@04@lB
00X82`0F51L04@lB00X82`0B41L03P`G010?5`0C4QT04a8G00804Q4F00`04A0E010?5@0@3aL04A0H
01@B700A41H03`hC01hM8P0_;S<0:BP]01@C600B4AH2014@5@0K01@C600E51T051<H01dL8@0=3140
5QDJ01<B5`0B4AH0DE1E09bKX00l>d006APM01/J7`0<2a005QDJ01LI6@0F61L04aDD014B500B4aD0
51DG01DF6P0B4aL06a`P01PI7P0J6b00414F00805aHK0`0F5AX00`0E51T05aHK01HE6P0301@C600;
01DE5`0I5aX04a4B01dK700V92D071XK00h<3@0E4a@04a4B014?400B41400P0E4a@03@0G5AP06QPK
01TG6P0F51L0518E018@4`0G5AP061HI01`J7@0C4A@05aDH01@B5@0C4A@00P0E4aH201@B5@0;01DC
5P0A3a804a4D01TG6P0C4A@05aDH01XH6`0M6AX05a<D014=3P0B3Pl00P0F4Q<0300H51D06QHG092<
S@1fLW<07a/L02DQ8P0D3a80=c4e085kO`0G4AD0;BL[03li?@804P`@0P0C3A401`0B310040T?01H?
5P0D3A@05a0G01<<4`0G41L00`0@2A02018;4P0V0109400>1`h06A8I0109400B2a803@H=00l83`0F
3aH03PL>00/52`0D3A@02PD:010:400C31804@/?018<400@2Ph03@L;00d63@0@2A403`P@00l:400@
2A80200;028L9@0g;CH03P<;01D:4P0800D060dE06=HH00M4QX03@<:01D:4P0B1`l05P/C03db>P0B
1Q0201453`8040@>00L03`<=01<74@0E2A<05P/D0186400?0``040@?00804P<>01004P<=01<33@0B
0`d04P@<01442`0@0`X040@801052@0A1PX04`P;0185300@0`X03P8801032P0A1@/04PP<0`0@0`X3
00l22@030146300@1@/03P<900<03@8800H03`@:020E6`0>10T02@0401062`0@1@/Dooooo`006ooo
ool01`0H5QT03`d@00d;3P0F51L03@/>01XH6`0?3A000P0B41<04@0?3A003P`?010>4@0I6A/03@d?
014A4`00008040lB00l=400A3a804PhB00l:3P0E41@05Q0D00l93@0B3Pl04@d>008040`=0P0A3@h0
200=2@X040`=01DA4P0B3Pl03`/<018>3`0@30d071PI0P0C3a001@0B3Pl030P900l;300?2``040`=
00804@d>00D03`d@00d?4`0<41<03PlA00l@3P02010?2`0D014<2@0C2P/050/<01L<400J3A@05@/@
01H@500A2`d06QDC01/F4P0F4@/04Ph6018=1`0C3PX04@/:01@>400A2`l02`L;00/92P0:20T200/9
2P0>00X82@0<2P/07Q`M00800@0F51D01`D600<10P0E4a<051<A01HE4`0<2`X00`8007QgM@1PGed5
00h=2`0300h;2P0>2PT03`/:00803@T800D04@d<018>3@0A3@`04@d<010<2`0200l;2P0B01dL6P1<
BdT0QhJ403Th=P0>3@/02PT801XI5`0A40h020L6028Q7`0;2PP03Pd;01TH5P0A40h051<B04E4@P0A
40h03PX90P0>20P0400;1@D040L801H=3P0D3@d01@4000l>300A40h01@@200d<2P0G5Q@051<A00l>
300<2`T03@`:00l>300=30X200h=2`803`h<0P0@3`d04P0I61H03`h<00d<2P0=30X02`X8010?3@07
1P@040l=00h=2@0D4`l03Pd900h=200Q81/04Q4<010?2`0?3PX02PT7018@4@H03@/<00@03P`=00d;
300=2``03@/<0P0<2P/01P0D4a401`H400l>300:2@L05aHD00T81P803@`:01l030/900d<2P0=30X0
3P`=00d;3P0B41<03P`?00`:3@0?3A002PP;010>4@0=2`h06aTL075_LP0X9RT00@0203Pf>@081PT0
3@/>00`:3@0B41<01@<600d;3P0>30l03@/>00l=400:20/04@hA01D@500C3Q8040/?00<03PT=00L0
20<701D@500?2Ph05a8F018=4@080`P030L=00803PT?0P0<1`d02@0?2Q0040/A01<>500I51X04PdC
00l:400C3Q@040/A01@?5@02014<4P0:01XE6`0<1`d04@`B014<4P0K5Q`050lE00d83P0F4AL030L=
01/F70802PD;01X03`/@01dH7P0D3aD030L=01<>500E41H03@P>00`73@0=20h03`X@01D@5P0M61h0
3PT?00l:400@2a403@P>00L2200:1@/0=c8h0<6o`P1<BTd02@L:00800`071@P040hA00h<3`803@/>
0P0<2Pd0100=2`h02`T<00d;3P0<2Pd200/9300>00`:3@0?3A00:BLZ02XX:`0I5aX03`d@01`G6`0J
4A@06a4B03@Z:`0U6a`04@T900`20`0C2@X301882@0:01<92P0A20/05a4E018=4@0400<03@P<00`7
2`0F4AD040/?00l:3P8030L;01/03@P<00h93@0@2`l03PT=018=4@0G4QH05A0D01/F6P0@2`l03@P<
00`72`0=20`03PT=00`:3`1_KWH0AdM?00L73`0B4AP04a0G00X73P0C4AH05A0D01LB5P0?2``03@T:
01<?400>20`00P0B31000`0?2@d03PP<010:3P0200h830@03`T=00<04@`@00l:3P0>2@d00P0=20`0
2@0?2Ph040/?00l:3P0>2@d03@P<00`72`0<1``030L=00d83P0200h93`0D00d83P0>2@l030L=00d8
3P0@2a4030L=00d83P0:1P`04PdD00X5300O6R4050lF00P32P0400H03`XA01TD6`0F4AP02PD<00/6
3@0>2A0500d83P0>00X52`0@2a404@`B00X52`0>2@l05A0F00l:3P0<1`/02@@800`72`0=20`040/?
00`72`0=20`300h93@0300l:3P0@2P`03`T;00<03PP:01l040X<014;3@0=1`T03PP:00l92`0>20X0
4@`;00h:00091@0050l8018=2P0D3`/07AT@020M2P13@BX0_KbP05ME?00L6PH01P80010=200=2@P0
2PH500l;2P0D40l02PH5014=300@30/03PX900X61@0@30/03PX900803@T:00D03PX;010<3@0@30d0
3PX;00l;3004010<3@0400l;300>2PT04@d<014=30803PX900<04@d<010<2`0?2`X00P0>2PT02@0?
2`X040`;00X61`0E4A803`/<00d92P0<20T040`=00l;300300h:2`803`/<00<04@d>00l;300?2``0
0`0>2P/01`0A3@h03PX;00d92P0>2P/040`=014=3P0>2PT00P0?2`X05`0@30d040/?014<400;2@`0
3@/@01<A5P081P/03`dB02<Q9P0B41<03@/>01DC5P0<2Pd00P0300H41`0W9BP03P`?01dK7P0610L0
3@/>00l=400>30l02`T<008030X=00P040hA00/9300I5aX030X=03Tg>P10?T407Q`O010>4@D04@lB
00L04Q0C01@B5@0?3A004a4D01@B5@0<2Pd03P`B00803`hF00<040lF014@5P0C4QP00`0@3aD2014@
600401<B6P0G5Q`040lD00l>4`8051<H00T05QDJ01@C600B4AH04A0E01<B5`0D4aP04a8G00l>4`0F
5AX00P0H5a`0500N7B806QTN02<R9`0B4AH061LL00T83@071P/04A0E01LH6P0F5aT05AHH01@E6@0C
51P04Q<G01PI7P0G61d061PP00`<500B4QX05QLL0P0G5Q/00`0F5AX05A@I01DD6@0201@C60@05A@I
00d05ADG01XH6`0C4A807A/L02HT9@0N71d03`d>01LE5P0D4Q<04a4B01DC500F51D04a4B00805aDH
00X05A<F018@4`0B41<0518E01DC5P0F51L06aTL01@B5@0M6ah06aTL100D4QD06P0H5QT06aTL01/I
700:20/05A<F01@B5@0G5AP03@/>01HB4`0E4A8040`=014=3P0C3a003`/<01<?400L61T0WYZK08N3
Q00?2``0510A02@N8P0500<0<2X^00h8300D3Q8020860P0B310201<=4@07018<400H4AL03PL>01XC
6P0?2@l0100400T22@02014:4@0B0109400B2a804``C018;4P0=1Pd08Q/R01D>5@0?20l01`0701XC
6P0T7B@0>34h014:4@0U7RD02P<:01TB6@0<1P/040X>0P0C3A40500@2Ph03`P?00h73P0=1Ph05@hF
020H8P0400L01`0:02LN9`0=0PX05``D01<8400<0@T04PT?02@I8@0I3QH03`@<00T01P0700@071<I
0P0?0`d301043P0701454@0@11003`<?00l33`0C1a<050PD01<64`0201H44P0401H44@0F11005@D?
01D53`8040<:00`04@D90147200B20T050X;01@73P0B1@`03P4800`01P0B1@`060/B00l22@0@0`X3
01442`0301032P0@1@/03`@:00803P<90P0?10X01P0L4AL0@CHl0146300:00D0304700X01ACooooo
000Kooooo`07010>4@0>30l04Q0C00`:3@0?3A000`4400`:3@02010>4@0L00d;3P0<2Pd03P`?00T9
2`0>3Q005aLI00l?4@0A4A<04Q0C01<A500A3Q403PT=01PC5`0G4AD03PP<00/7200?2``04@d>018>
3`0?2``03PX;00l;300J5QL07ATJ01<?400>2P/04`l@010<3@80510A00<040`=00X61`0D41400P0?
2``0700@30d04@d>014=3P0?3A003A4E00`?500<41<03Q0?00l?3@0?3PX040`9018<300E30d06PlC
01lB6@0G3A806Q@H00d72@0@2P/030L400d8100E40/04Pd901PC400B30d04@/=01LA5@0B3A02018@
4@0@00d;300>30d04Q0A01DC500l>S/07adN01<A4P0I5aP061HG00h<30030P006aXH00/:200E5180
>3Le02d/:PD03@`:00<03P/:00l;2P0@30/00P0?2`X0100B3Pd04`l>018>3@0A3@`200l;2P0500h:
2@0B4@l03Pd;01dL6P0:2@L00P0<2`T07P071P@00@0001LF501EE5807ahL00`;2@020@003`h<04I5
@`24Ph406aXH00T61@0;1@D04`d=01LA4@0C2P/04PT:00l8200A3@`04A0>00`;2@0:2@L03Pd;00D4
0P0A40h03@`:00/:200=30X03`h<00`;2@803Pd;0P0?3P`2010?3@0B00`;2@0;2PP030/901<B400=
30X05aHD00d<2P0=30P01`H201@C3`0920@040l:00`;1`0@3`/06aXF01HE4@0920@04Q4?0P0?3@h2
00d;300400`:2`0;2@X03`d>00h<3@803@/<00`030X;00/92P0<2`T04Q4?00T81P0?3P`03@`:010?
3@0<2`T02@P600X91`0?3P`2014@3P0J00/9300<2Pd03`d@00d;3P0<2Pd03`d@00d;3P0H5QT00@02
01dK7P040PD05Q@G0:bZ[@0b<3<06QPK00h=3`0k>C`04@lB00h<3`0?3A003@/>010>4@0:20/03``?
018=4@0A3102010;3`804@`@00L05a8F00<00P0J5AT01`8601HA5@0<1``03@P>00803`X@00@03PT?
00l:400@2a4030L=0P0910X0:00:1@/04PdC01/F700910X01`88010;4@0400D040/A00T42P0A3180
2`H<00H21`0>2@l040/A00T42P0?2Q004`hD00<0100B3A<030L=00X52`0G4QP03PT?00<0100O6R00
3@P>00h93`0C3Q@04PdC00/6300@2a402`H<00@01@0A31809R4W01XE6`0=20h0=c8h0;6_/P0f=3L2
018@4`0400X82`0@3Q402`T<00d;3P8040hA00<03`d@00d;3P0<2Pd00P0?3A001@0=2`h03P`?010>
4@0A3a803`d@00<030X=00X020@500`31P0=0`@06Q0A00`20`0B20T07A<D01<92P0B20T04@L80P0C
2@X09P0@1`P02P@801D@50070PH081/O00h93@0910P050lC018=4@0@2`l03`X>014<400B3A407APL
010;3`0<1`/03`/>00<00P0K5QX040/?00d8300<1`/03PT=00l:3P0>31403`lF018B6P0;2a<01@@:
01@A600@3A@02`T>00X52@0?2Ph03`X=00d92P0A3@h030H:0P0A2`l200d72`0400h8300?2@d03`T=
010:3P804@/?00D04P`@00d8300<1`/030L;00d8300200h93@0N00`72`0=20`03PT=00l:3P0@2`l0
3`X?00l:400@2a404PdC010;4@0>2@l030L=00T42P0:1@/03PT?00T42P0:1@/06A@J02@O9P070PT0
30L>00T42`0;1Pd03`XA01lJ8@0`:c809B0W00d83`0<1`h04@`B1@0?2Q004`0@2a402`H<00`73@0=
20h02@@:00h93`0@2`l03`X>00d8300H4aL03@P<010;3`0?2Ph02`H:00`72`0C3Q805A0D010;3`0A
2`d00P0@2P`08`0?2@/040X<014;3@0A2`d03@L900h82P0?2@/03@L9014<2`0A3@@02@D001HA300B
30`030L401HB2`0M6P/06QL403dk900W9A003PX000l;0P0>2PL030P700/71P0E4A0071PG00h:2@0A
3@`04Ph=00d920050@0040`;00`81`0<20T03PX;00804@d>00@040`=00l;300@30d04@d>0P0B3Pl0
0`0A3@h040`=00h:2@02018>3@0500l;2P0>2PT04Ph=014=300?2`X00P0=2@P02`0?2`X04@d<00d:
2P0D414030P9014=3P070`@04@d>00l;300>2P/03@T:00803PX;0P0?2``02`0@30d04@d>010<3@0=
2@X030P9014=3P0>2P/03@T:00h:2`0@30d04@d>00803`/:024040`;014=3P0A310040hA014?4P0?
3A804a4F00T7300S8RL0C4]@01DC5P0A3a802@L:018@4`0@3Q40D4iA09>AU00N71l01`H801LE600C
4A@04Q0C00d;3P0H5QT03`d@010>4@0A3a805Q@G01LE600A3a804Q0C00T72P0I5aX01`0A3a804@0C
4A@030X=00/9300E4aH04Q0C010?500@3aL03`hF00l>5@0@3aD04a8H00h=4`0?3Q@04Q4G01<B6P0B
4AT04A0G008040lD02<051<H014@5@0<2a004A0E00l>4`0C4QL071/P01lN8`0K6Ql03`hC010?500B
4AH05QDJ01<B5`0@3a@06APM01@C600B4AH05A@I010?500B4AH051<H00l@4P0@4A<051DH01LH700F
5a/04a@H00h?500Z:S40?Ce502XZ<P0H62003PhF01XI7`0201TH7@0501PG700G5Q/05aHK018A5P0D
4aP00`0F5AX02P0F5QP05A<F01LE5P0D4Q<03@/<014?400S8B8061HG01DC500D4Q<201HD5@0=018@
4@0@3Q405aDH01`J7@0K6A`05A<F014?4P0J61/05A<F01LE600I5aX0;bd`03<a=00201@B5@0J01<A
500E4aH06aTL01lM800d<SD02PP;00l=400B41<06QPK00`:3@0>2P/0510A018>3`0G4a@061@E01<?
400D41404`l@020L7@0/:2T030P900l;300D3Q80618F01`F6P0C3A4201D?4`804P`@0P0C3A40200B
31004``B00H01P0F3aH03`P?02@M900M5Qd0=Bhe0P0A2Q40:@0C31<050dD018;4P0@2A008AXQ00d6
3@0A2Q4030D<0109400400@0614H01lH7`2ITYT05PlF00@0100@2@l040X>01@>4P0E3a<04@/?0109
400@2A4050dE00T22P090`/05PhI0149500@1a002@0601883`0H3AD05P/C01@94@0:00L03P<;00l6
300H3AD0304901053@0>0P`03`<=008040@>00P04@D?01864P0E2AD04PHB01454`0G2aT06@dK01D7
5`8060HF018060HE01P6500G1a805`LB0103300@0`X04@@:01462P0B20T050T<00X0100>0@P04PD<
01032P0>0@P03@0700l22@0A10/4018530<03`@:00T040D;01873@0C20h0;b@Z05Y?E@0>0`T04@H<
01@93`0<0@L05?ooool001_ooooo00<03@/>010>4@0@3Q400P0?3A005`0B41<030X=01<A500K6A`0
>SPk01HD5`0<2Pd0410B018B500=3@l0GUiP02/Z;0091`X04a4D01@A500:1@T04`hB01H@500G4AD0
4Ph?014=3P0@30d03`/<00803PX;00d04@d>01/G601XI6D05Q8C00L3100D41403`/<010<3@0D4140
4Ph?01PD5@0B3Pl0510A00804@d>03@04Ph?01<?400B41<06R0T05IKG`18CE006ahM01TI5`0N7QX0
4a0=01@?300F3`d07aHG01D:3P0D30l04P`@010:300B30d06Q@C00L20P0D3``05A0=01<=300A2``0
618D01LA5@0@30h04Q0A00X82@0>30d03`d>018@4@0C4A80=C<d01<A4P0>30d04a4B00P61`0@3`h0
4A0>00h=2`0<2`T040l=01<B400A40h03@`:00/:200=30X04A0>010?3@0@3P`040`;0P0?2`X01@0@
30/04`l>018>3@0A3@`04Ph=00803PX900L08QhM00X91`0H5aD040l=00`;2@0?3P`030/900803Pd;
00X04Q4?04U8AP0J6AL03Pd;00`;2@0>3@/051<A01DD4P0D4a404Ph=0`0A2`/201<:2`04018;2`0=
2@P030/900h=2`8040l=0P0?3P`300d<2P803Pd;00h02`X800l>300=30X030/900X91`0A40h02@P6
00h=2`0@3`d03@`:00/:200<2`T030/7010?2`8030/700@03`h;00d<2@0=30/03@`9100=30P02@06
1@@04@l@018@4@0?3@h02`T:014?400K6AX03P`=00P61`02010>3`0900l=3P0?3P`03`h<00l>300=
30X030/900X91`0;2PP03@`:008030/900`03Pd;00l=3@0>3@l0FeUL07ekOP0?3A002@L:01TG6P0>
30l03@/>00`:3@0>30l2010>4@0O02XX:`0F51L04@lB00l=400X9RT03`d@014?4P0=2`h03P`?00`:
3@0=2`h0:bP[010<3`0A31003PX=01<>4P0D3a<030L;00h93@0B3A403PT=00`72`0>2@d04@`A00l:
400;1P`03`X@01@?5@0:1P/03PT?00l:400200h93`0?00l:400A31805a8H01HA5`0C3Q@04@`B00`7
3@0?2Q005A0F01lJ80080`T050lE00P32@0=20h040/A00804@`B00X03`X@010;4@0F4AL04`hD00d8
3P0?2Q0040/A00/6300=20h040/A0P0?2Q000`0>2@l03`X@010;4@03014<4P09018=4`0C3Q@050lE
01DC5P0?3A0071XM014?4P0;2@`03@/>008030X=01h03P`?010>4@0<2Pd03P`?00l=400=2`h02`T<
00d;3P0>30l030X=00h<3`0<2Pd02PP;00/9300?3A00510B014;3@0D2``02P@401L>3`0=1@H04``<
01@;300B2P/040T901482@0A2@T040T:014<3P0@2`l200l:3P803PT=00X05Q4E02<N8P0300805A0D
00d8300F4AD03@P<00h93@0?2Ph040/?0P0A3100500@2`l02`H:010;3`0>2@d05Q4E05IDF00C4AL0
2`X@00d<4P0=2Q4030X?00l=4P0A31803PT?00h93P0?2@d04@/?018<400>20`030H:0P0A2`l01P0E
3a<071HJ014;3`0?2@d03PP<00d72`803PP<01P040/?00d8300>2@d04@`@00l:3P0@2`l03@P<00/6
2P0=20`04`hB00l:3P0?2Pl030L=02<N901AC5804`hD018=4`0A31803PT?01D@5P0=20h05A0F02PS
:@0J5A/200`73@804`hD0P0?2Q006`0H4aT0?CPn04E0AP0@2a402PD;00l:400D3aD03`X@00`73@0@
2a402`H<010;4@0<1`d03`X@018=4`0810T04PdC00L21P0H4aL040/?00h93@0<1`/04PdA00l:3P0B
3A403`X>00d83002014<400I00l92`0=1`T03@L900l92`0>20X030H800d72@0?2@/040X<00l92`0>
20X040X;014<1`0D3`/03`X;018;4@0>20h050h?01<>1`0D40<05a<501HB1P0C3PL040/900l;2@05
00l;2P0>010<2`0>2PT030P700d9200?2`X04Ph=00l;300<20T03`/<014=3P0>2P/040`=01HB4`0B
3Pl200d92P0>010<3@0C3a004Ph=00`81`0B3Pd03PX901<?3P0?2`X03PX901<?3P0<20P03@T8024M
700/:2L2014=3P0@01<?400?2``03PX;018>3`0?2``05Q8C00`82@0C3a004Ph?00h:2`0?2``03@T:
00`82@0=2@X03PX;00l;30H040`=00d04@/=01<=3`0@2P`04PdA018@4`0>30l02`X?00l>4`071``0
2`/@02PY;P1lO8405aDI00<03@/>01X03`d@01hL7`0T8RD05A<F00l=400B41<03P`?01@B5@0F51L0
>3Hi01HD5`0C4A@03@/>014?4P0E4aH04Q0C014?4P0?3Q003P`?014?4P0?3A003P`?014?4P0>30l0
3`d@018@4`804@lB00X04Q0C014?4P0A3a8040lD010?5@0?3Q@040lF01<B6P0?3QH04a8J0P0@3aL0
0`0E51X05QDK014@5P0601<B5`805A@I00/051<H018A5P0B4AH04a8G01PG700E51T051<H01PG700I
61d05A@I01HE6P0201LF6`0801<B5`0A41D05A@I01TJ7P0F5a`05aPM01@E6P0?41D201DE7@0f01PH
8@0R8R`051@N01DE800P82X05aHL01/J7`0F5AX05A@I01PG700B4AH05QDJ01DD6@0F5AX061LL01LF
6`0C4aD06ALJ01TG600G5AH07Q`M01DC500H5QL07A/L01DC500B41405Q@E01DC500G5AH040hA01DC
5P0B41<05A<F02<Q900Y9bX05aDH01@B5@0F51L0HV1S020N8@0D4QD05Q@G01TG6P0F51L05A<F01HD
5`0C4A@05A<F01hL7`0>30l0518E01TG6P1@CU4061@E0P0A3@h01@0D41405A4B01<?400D41404`l@
00805a<D00P04`l@01@@4@0F41@05Q0D01D?4`0B31004`dA01H@50D04`dA00<04P`A018;4P0C31<0
0`0D3A@00`0C31<04P/B018;4P02014:4@050109400C31<05a0G01<<4`0B2a800P0I4QT03@0C31<0
3@H=018;4P0O61l04P/B00d63@0B314040X>014;3`0B310040X>00l83`0@2A000P0=1Ph03`0?2140
2P<=01<;5P0B21403P<;01D:4P0B1`l050TA01473P0C21004PL?01053@0?10`040D=01<840020188
4@0N020F7`0C2A@03PH?01@95`0D2AP04@HE01055@0C21P05@XJ01@86P0G1a/03@0A01T96`0>0100
5@HF01<44@0K3AT05`XD0185300A1P/04@H:00l42@0>0@P04@@;01032P0>0@P04@@;00h1200?0PT0
4@@;0P0J3A@03P0B1P`04@@;00l42P0D2@l060dC00h32@0@1P/0;B8X0;:W[@35_<407Q<I00l62P0?
10X02`065?ooool001_ooooo01P04a4B018@4@0>30d02`T:00d;300@3Pl04a4B00h<3@091`P06ALH
00`:2`0D4Q<03@d?01@D5P0E5AL0>CTk00`;3P0@3Q403`d@00T52@0?2Ph04@`@00P21P0C3A42010<
3@0A014=3P0B3Pl04Ph?01<?400?2``030P900P41@0K5aP06QHG00L3100D41403@T:018>3`0H51D0
7a/L01LC500C3a000`0A3@h05P0B3Pl040hA04mCF@3lool0hnOZ02`^;P0M7A/020T400h=2@0=2PD0
6A@@02`W900I41404`d>01DA4P0;1`P0J6AU01PD4`0G4a8040`;01<?3P0G4a@201<?400G01LC500C
41400@000040000A40h05aHD010?3@0;2PP05QDC00L6100D4a404A0>018A3`0@3`d03Pd;00d<2P0<
2`T04A0>010?3@0>3@/03@`:00`;2@0=30X00P0?3P`01@0@3@`03`/:00l;2P0?2`X040`;00804Ph=
01004@d<018>3@0?2`X02`L600h:2@0H5aD0:2LU020O7@0E51804Q4?01@C4@081`D06APF00X9200>
3@/06APF0P0<2`T01@0>3@/04a8@01<B400@3`d03PX900<04@/;0P0C2P/02@0B2`/040`;00d<2P0>
3@/03`h<014@3P0B4@l02`X800d<2P0200l>300900d<2P0;2PP01`H400l>300E51804A0>00l>300@
3`d04A0>00804a8@00`04A0>018A3`0C4Q003@T600l;200>2PL04@d<01@@4@0<20T03`X>00l;300?
2`X300l;200300/:200Y9bP0>SPi00807A/L01/0:BLX06UWJ00:20T00@0000P71`040P<030X;00d;
30081PL040h?00X82@0@3Pl05A<D00d;300>30d030X;00P61`0:20T03P`=00h<3`0I5aX09B<V00/9
300>30l02@L:00h<3`0=2`h00`0<2Pd01P0=2`h03`d@00L5200F51L020L900d;3P802`T<00X02@L:
00l=400@3Q404@lB04E1A@0M61`020<7014<400;1PX02PD90P0D3a<02P0E41@04@`@00d8300>2@d0
4`hC01@?5@080`T04@`B00h93`0U82H2010;4@803`X@00D040/A018=4`0N6Al071LM010;4@0200l:
400D010;4@0B3A<06A@J00T42P0?2Q0020<900l:400E41H04`hD00l:400<1`d03PT?01HA5`0=20h0
40/A00l:400=20h040/A00l:400@2a4200l:400300h93`0?2Q0040/A00<03`X@00L040/A014<4P0C
3Q@01P4500X52@0;1PX04PdA00803PT=00P04`hB00`72`0C3Q802@@8010;3`0B3A407Q`O01LE6080
4@lB0P0B41<200`:3@0A00d;3P0>30l03`d@00l=400B3Pl02`L801<?400I4aD04Pd?00l;300A2`d0
4@`=00l;300A2`d04@`>018>3`0@30d00P0?2``300h:2`0500P41@0C3a0020@5010<3@0?2``00P0=
2@X00`0>2P/03`/<010<3@03014=3P0B010<3@0:1PL04Ph?00T51P0D4QD03@/@00X83@0>31403`dB
00d83P0>2@l040/A0109400?20l040T@0188400C2A404``C0P0A2Q4200h73P0501<<4`0D3A@04@XA
00l83`0>1`h00P0<1@`0=00@2a403PT?00h93`0@2a403`X@010;4@0;1P`00`0401XE6`0K5Q`01@06
00h93`0=20h04PdC02HQ9`0910X03`X@00X52`080`T04@`B00/6300<1`d06A@J01D@5@0>2@d03@P<
00l:3P0<1`/03@P<014<400V8BD050lC00h93@0F4AD01`8600h93P0;1P`03@P>010;4@0;1P`02PD;
00d83P0@2a404@`B01D@5P0R7B<02@D:01@?4`0910P040/?00h93@0500@200`72`803`X>01`03@P<
010;3`0>2@d04P`>01<=3`0F41806A<E01PB500C3@l03PP:010:300B30h040X<00l92`0@2P`05Q0@
00/51@0@2@l03PHC00l7500>1`h04@/;018=1`0D3`T04`h:014;3@0?2@d03`/<1@0?2`X03P0C3`h0
4Ph=014=300A3@`04`l>01DA400=2@X03PX;014=3P0>2P/02PH7010<3@0A3@h040`=0P0>2P/200l;
300501@@3`0B3Pd05A4@00h:2@0C3`h00P0@30/01@0:1PD06aLF00h:2@0B3Ph0Ee=B00804`l@00d0
510A00l;300=2@X04@d>01@@4@0G4a@05Q8C04]7B00W8b@071PI010;3`0?2Ph03PT=00803`X>00<0
40/?00l:3P0?2Ph0100?2Ph0100C3@l040X>00X4200<1`/200l=4P0>00l>4`0L7B804A8G014C600:
3A@01@P=00d;3`0;2@`040hA00h<3`0<2Pd020H900/9300<2Pd2014?4P0D00X82`0=2`h00`4403lm
@0081PT05aDH00L5200D4QD00@0201/I700<2Pd00@0201lM800:20/03P`?00d;3P0A3a803`d@010>
4@0B41<2014?4P0<018@4`0A3a804@lB01<A5@0C4QL04Q4G01<B6@0B4AT040hI01LE800C4A`040lG
0P0B4AL00`0?3Q<04Q4F018A5P04018A5P804a8G0P0B4AH0100C4QL051<H028Q9P0M724301PG7005
01@C600F5AX05QDJ01DD6@0C4QL00P0D4aP04@0I6Ql05aLO014A6@0C4a/05QHN00l?6@0Q8B/0410K
02LW<`0U9C406QXW028R;P0I61h06aXO01PG700G5Q/06APM00805A@I0P0G5Q/07P0F5AX05aHK01XJ
700J61/0?cdn02/Y:P0F51D040h?01lM7P1?CDh06aTJ028P8@0I5aP05A<D02HT9@0N71l071XM018@
4`0@3Q406ALJ01lM800100807adP01LE600P7R404a4D01dK7P0I5aX08R0S01`J7@80518E00X05A<F
01LE600D4QD05A<F02LU:00S8B@081hQ028N7`0C3a004Ph?0P0K5aP00`0G4a@05Q8C014=3P0201<?
4003010<3@0B3Pl050hB00805Q0D200C3A400`0B31404P/B01<<4`0201@=500301<<4`0D3A@04``C
00804``C0P0B2a80100M5Qd07aPO01<<4`0@2A0201/D6`0301@=500B2a804P/B00<04P/B03D050dC
00`62P0;1@T04`dA00X4200:0`X04@XB00h73`0@2A403PL@00l74P0C2aH05`dF01X?5`0=0`X07A8J
01T>5P0@1`d050TA01<8400B1`l04@H>01873`0D2A4050XC01<94P0C2a@03@8@00`13`0@1AD05@XK
0187600>0aD03`<G01866P0E2Al060`T00h26P0I3B<03P8H01H:7P0D21T03P8@00l33`0@10l040<<
01032P0B1@d04@@;01032P0<00H03P4801@73P0201032P0A01@73P0900<02`0501@73P0800801`02
0146300F2a402`0601hC6@1BAdd0mncb07aaM`07008060dC00h32@0?10X05?ooool001_ooooo01P0
3P`=00l=3P0>30d03P`=010>3`0A3a005A<D010>3`0<2P/03`d>00/92P0E4a@05QHH00/;3@0B4Q@0
8b<U03`k?@0>30l02`T<014>4@0G4QH04`hB00/52@0C3A43010<3@804@d>03`04Ph?01hJ6`0T8240
4Ph?03Pd=@070`@05a<D00l;300=2@X040`=018>3`0G4a@040`=00h:2`0?2``040`=01<?400E4A80
4a4D03/mA@3Gf^40_[o402DV:00F5QH00`@000/:1P0@3`X04Pl:01PD4@0A3@`05a<C00/92P0:1PL0
JfQY00l=3P0D41403``<010>3`0E4A804@h?00l=3P0D414051<B00X91`0I61H071/I010?3@071P@0
4a8@01TH5P0B4@l081lM010?3@0C4Q002@P6010?3@0F5A<03@`:00P71@0<2`T200h=2`0500d<2P0>
3@/03`h<00h=2`0?30/00P0?2`X2010<2`0I014=300B3Pd040`;014=300B3Pd04@d<00l;2P0>3@/0
6QTG01@C4@0?3P`03Pd;00l>300100002`X801DD4P0510802@P600/:200A40h04Q4?01<B400B4@l0
40l=010<2`03014;2`804`X;00@04P/;01<?3P0@3`d03@`:0P0;2PP03@0<2`T03@`:00l>300@3`d0
3`h<00h=2`0?3P`03@`:00h=2`0100003`h<01@C4@020@000P0@3`d03P0?3P`03Pd;010?3@0A40h0
30P500h:1`0A3@`06ADF01dH700C3Q803`X@00l:3P0?2``03`/:0P0?2`P01P0E4a@09B<T02XX:@01
000020H701TG60803@/<01T0:2HW038`<@0A3a002@L800X92@0;2@`04@l@00l=3`0?3A003`d>00d;
3@0>30l03`d>00/92`0;2@`03`d@00P72@040PD02`T<01<A500F51L020H900h<3`0=2`h030X=00<0
2`T<00P03@/>00`:3@0@3Q402`T<01HD5`0=2`h02`T<00L520802`T<01D02@L:01dJ7@0=20`04@`@
00/62P0@2`l03@P<014<400D3a<05A0D01<>4P0?2Ph040/?00d83@0>2@l00`0401`G7@0300@04`hD
00X62`0@2a400P0?2Q001`0@2a404PdC01D@5P0A31803PT?018=4`0@2a400`0>2@l04@0:1@/04@`B
00l:400=20h030L=00d83P0@2a403`X@00d83P0<1`d02@@:010;4@0>2@l030L=01@?5@0A318040/A
00803`X@00<03PT?00l:400@2a400`0>2@l04@0?2Q0040/A018=4`0=20`05Q4E00`72`0H4aL050lC
010;3`0C3Q804PdA00l:3P0:1@T0=S4e020K7`0E4aH04@lB00<03@/>0P0;2@`04@0=2`h03`d@00l=
400?3A003P`?00<1100B3a4061HG00h93@091@P05aDF00l:3P0>2Pd03@/<00l:3P0@30l04Ph?0080
3`/<0`0>2P/01`0=2@X04@d>01@@4@0B3Pl03@T:00l;30070`@00P0>2P/0200?2``040`=010<3@0@
30d03@T:00h:2`091@H04`l@0P091@H01@0>3A802`T>00h<4@0>31403@P>00803`X@0`0@2A020188
400:01L@5`0D3A@04@XA00d63@0;10/03@H=01@=500A2Q4040T@00l83`803PL>1@0?2Q003P0@2a40
7QTO00D01P0C3Q@00`0401dH7P0>2Pl02`H<00`73@0?2Q001P4700`73@0?2Q002PD;0P0A31809`0;
1P`02@@:00X52P0=20`03PT=010;3`0;1PX030L;00d8300P6al05Q4E00X52@0?2Ph02PD9014<4@09
10X03`X@018=4`0:1@/030L=00d83P0<1`d020<9055<DP2FTIL09R4W01PC5`080`L03`X>00X52@0;
1PX04`hB00/62P0?2Ph040/?00l:3P0A31003@P<00d72@0300l92`0E014;3@0<1PP03PP:010:300B
30h040X<00h82P0?2@/04P`<00`61P0@2A001`0<00h64`0<1@h03`T9010;1`0A30H04@`9014:3`0?
20l03`/<00L03`/:0P0>2PT02@0@30/04@d<00T51P0@30d05A4B010<3@0810D03@T:00l;3003010<
3@0>00l;300>2P/040`;018>3@0D40l03@T801<?3P0A3@`030P700d9200B3Pd040`;01@@3`0Z9RD2
018>3`0:01@@4@0@30d03PX;01<?400=2@X020@500l;3016@T<08QhO01<?40H040/?1P0=20`0400?
2@/04P`@018<400@2`l02PP=00P62`0@41@03PlD00021`0;3a<0314G01TL8@0=2`l02`T<010>4@0=
2`h200/93009014?4P0?3A003`d@00h<3`0;2@`040hA00T72P050`H03@/>00804a4D00L05aDH0040
0P0F51L03P`?01lM800A3a8061HI00803@/>00@04@lB00l=400@3Q404Q0C0P0A3a803`0B41<04@lB
014?4P0A41@03`hC010?5@0D4aX04a8J01@B7@0B41/040hI00l>5P0B4AL05A@I01HE6P06014@5@<0
4Q4F01404a8G01@C600E51T071/P01LF6`0C4QL05A@I01PG700G5Q/04A0E01LF6`0H5a`04a8G01DD
6@0J6Ah061PP01LG7`02014A6@0=01PH800D51h0:2Pb01hN:@0R8Rh0@d=?01lN:`0@41`061LM01PG
700F5AX05A@I01HE6P0201DD6@0H01TH7@0G5Q/05A@I01PG700N7R001`D801PF5`0C4A806ALH020N
7`0W9BH0clg>03Tg>00A3a006aTJ02XX:@0D4Q<05Q@G01PF6@0E4aH04Q0C010>4@0>30l05A<F0P0C
4A@0400@3Q40108501dK7P0N71l081hQ01TG6P0E4aH05Q@G01DC5P0C4A@0108500400P29QhX0Ti6D
00400P0K5aP201<?400501TE5P0K5aP06ADF01XF5`0D41400P0E4A800`0C3a005A4B01@>4P0201H@
500301D?4`0B31004P`@00D04`dA00<04``B018;4P0C31<00P0D3A@00`0C31<04P/B018;4P02014:
4@8040T@00L050dD01<<4`0@2A004@XA01<<4`0>1`h030D<008050dD01403@H=01@=500D3A@030H;
00l93@0Y8bL0B49602PR9P0=1Pd02@89018;4`0E3QH02@8;01P@6`0?1a802`<:01053@0201873`04
01P=5@0=0`X04`P@01873`<04@H>01H04`P@01884@0E2a@03`L@00/03P0?118060dM01<86@0A1QL0
3P8F00l36@0C1ad060dT01D=9@0;0Qd05PhV00`46`0C2b004PPJ00h34`0B1Q@04`LD0P0@0`d01P0F
2A<04`H=01@73P0A10/03`8901@73P804PD<01405PT@00`01P0;00D04PD<00/01@0D2@l03`@:00`1
1`0:00D04`P>02PM8`21MW`0:B0T00L00P0L4AL03`@:00T0100Dooooo`006oooool05P0<2P/03`d>
018@4@0C4A8040h?00`:2`0B41403`d>01DC500:2@T03P`=00l=3P0;2`d04a<E00`<3P0D51H071/M
02XX:`0@3Q40:2DX01hI7@0C3Q8200h830<040`=0P0?2``03P0>2P/0:BDV00T51P0G4a@061@E00d:
2P0C3a003`/<01PD5@0J5QL03PX;014=3P0=2@X040`=0P0A3@h07`0B3Pl04@d>00l=400D4ad09bH`
020O9@0D4aH02@T900l@2`0=3PP03a0:00`<1`0=3PT02@T500h=2`0D51@04a8B014A4@0>3Ph05QDF
01<B500A4A8040l?014A4@0B4Q8051<C01PG5@020@005A@B014@3P0I61H00P0?3P`02`0;2PP02@P6
01XI5`0<2`T04Q4?00d<2P0?3P`03Pd;01<B400M71X06APF00803`h<00H040l=00l>300=30X03Pd;
00l<2`0?2`X4014=300901<?3P0B3Pd03`/:00l;2P0B3Pd04@d<010?3@0D4a403@`:008051<A00<0
3`h<03Pg=@0O7Q`00P0>3@/01@0Q81h03@`:01<B400B4@l03Pd;008030/900@040`;014;2`0A2`/0
4@/;0P0C2P/0200B2`/04Ph=00l>300>3@/03@`:00h=2`0?3P`02`X80P0>3@/200/:200400l>300B
4@l03@`:03Xi=`8030/901T05A@B00h=2`0=30X030/900d<2P0>3@/03@`:00l;200@30/04@d?01LB
5`0K5Q`04PdC00l:4P0?2Q403`X?00l;3@0?2`X03`/900X82@0<2P/05A<D00L51P0d<S<0F5IG0080
3@/<01H01083014?400B414030X<00`:3P0D4QL03@/?018@50050`P0518F00l=4@0:20d03P`@00d;
400:20d03P`@014?4P0=2`h04Q0C00T72P0A3a802@L:100=2`h200/9300B010>4@0:20/04@lB00d;
3P0K6A`0;2X]018@4`0<2Pd040hA00h<3`0:20/05A4E010;3`0G4QH030L;01@?4`0<1`/03PT=0`0?
2Ph200h93@0;00d83@0H4aT040/A044l@P0D3aD030P=00h93`0@2a403`X@00h93`0@2a400P0A3180
400>2@l040/A014<4P0<1`d03PT?01<>500:1@/04@`B00d83P0D3aD04@`B018=4`0A318040/A014<
4P0B3A<2014<4P0601D@5P0A31803@P>010;4@0=20h040/A0P0?2Q00100>2@l03`X@010;4@0@2a42
00l:400G00h93`0?2Q0040/A00`72`0D3a<030L;018=4@0A31003PT=00`72`0:1@T04@`@00l:3P0Z
9BT08QdQ00d;3P0?3A004@lB018@4`0@3Q402`T<00`:3@0?3A000P0@3Q40400?3A003@/>00T8300?
3Q801PD901@C600[:Bh03PdA00`:3`0;2Ph02PX=00/:3`0=31003P`@00h;3@0?2``200h:2`803@T:
00H030P900X61`0>2P/02@D6014=3P0<20T400l;308040`=00L03`/<00`82@0A3@h040`=00d92P0D
41405Q@H00803@/@0P0>2@l01@0A318040T@01094@0A2Q804`TB00804PPA00@03PL>014:4@0?20l0
40T@0P0B2a8300l83`040109400A2Q404P/B00l:408040/A0P0?2Q005P0=2@h061<I06AOI@0R7B<0
30L=00P42@0F4AL04PhC02/V;00@2a403`/@01DA5P0>2Pl03`X@00T42P0<1`d03@P>00T52P0>2@h0
30L;00h93@0A310200d8300C014<40060PD03@P<010;3`0:1@T04@`@00h93P080`T03`X@00h93`0=
20h050lE00h93`0G4QP04@`B02XU:`1@Be405Q4G014<400200l:3P0400d8300Q7200:RDY00d83080
4@`@00L040/?018=4@0?2Ph03`T;018<3P0>20X03`T;0080618D01<03PP:00l92`0A2`d03PP:00d7
2@0=1`P030L3014<2@0@2Ph04``E01094P0?20d03`X800l:1@0@2`@040/7010;2`0@2Ph03`/<00D0
3`/:100=2@P200l;2P0500`82@0D414071PI01PD5@0?2``00P0@30d0500A3@h04Ph?018>3`0B3Pl0
4@d>00`81`0?2`X040`;00d9200H51<040`;014=300?2`X040`;01<?3P0?2`X02@D400h:2`0?2``0
4`l@0P0A3@h01`0F4Q<03`/<014=3P0D41403`/<00d92P0<20T00P0@2`l2014<40P040/?00l04`/@
018<400D3Q804PdC00`:3`0<2a002`/@00X<4@0>4QL0JFie0;Nm`P0`=CT04a4E00d;3P0?3A000P0=
2`h06@0@3Q405Q@G01<A500C4A@04@lB00`:3@0D4QD04a4D034_<P0@3Q404@lB00/9300@3Q4061HI
00T72P0F51L020H903`k?@0F51L03`d@00h<3`0A3a803`d@010>4@0B41<00P0A3a803`0B41<04@lB
014?4P0A41803`lA018A5P0G5Qd040hH014?700B41d04@lK018@6@0D4aT05QDJ01TI6`06018A5P80
4a8G00P04Q4F01<B5`0D4aP05A@I01PG700E51T04a8G01LF6`806QTN00T02PT>01LF6`0L6b004Q4F
01HE6P0Q82H071`T01/K8`0G5b400P0D51h02@0H62@04a<O02TY=P0Q82h07ah/01PG9P0G5b<06aXQ
01TH7@0301PG700<01XI7P0G5Q/06QTN01PG700F5AX061LL01`L7P0I5aX05Q@E01@B4`0F51D040h?
0P0T8R<02`0G5AH071XK00/92P0F51D0518C01HD5`0E4aH05Q@G01@B5@0B41<05A<F0080518E00`0
4Q0C01TG6P0?3A006QPK024O8P0G5AP04@lB01LE600J61/05A<F01HD5`0D4QD201/I7005024O8P0C
4A@04`l@01HB4`0E4A800P0A3@h00`0C3a006ADF01@@4@0201DA4P0301<?400E4A805@lC00805@lC
00<05Q0D01<=4@0A2`l01@0C3A40200C3A804``C01@=500D3A@04``C018;4P0C31<050dD0P0C31<2
018;4P804@XA01`050dD01D>5@0?20l03`P?0109400D3A@05@hE00l83`0E3QD050dD014;400;1@T0
3@L;01TC5`0<1PX02P<:014:4P0<1@d06Q<K01<;5@0;10h04PXE06UPJ@0S62005P/C00l4300B1`l0
4`P@0P0A1Ph301053@0N01463P0?1`h0614I00d6400=1A803`LD0108600A21X04@PK01487@0C2B40
60hV01lG<00G5C402P/X01HD<00;1b404PdU00l97`0A2Ad04`TK01855P0?01004@4?01L7500D1a00
60/B01D83`0=0@L03`890P0>0@P01`0A10/05@P?01<63@0?10T04`H=00h52@0=0PP00P0?10X0200>
0`T03`@:01L<4P0B1`d040D;00T0100?1@X03`@:5?ooool001_ooooo0P0=2``05P0@3Pl04a4B014?
400<2P/03`d>00h<3@0P7Ql02PP901DC50091`P051@F00/;3@0E5AL03@d?00X92`0610L01`D801DA
5@0B3A404@`@00l93@0C3A4200l;30<040`=00d04@d>00X61`030000510A00l;300G4a@03@T:01<?
400J5QL071PI018>3`0D414040`=00804`l@03404Ph?010<3@0<20T02`H:00h;5P0K62<06AHM01@C
5`020P805aPC010C3@0<3`P02`h701<G400:30L02P`800/=2P092`X051HF00/<3P010P@051DG00l@
4P0>3a403a4A00lA400H6QL06QTG02LV8P1YJ6@0:2LS004000030P005A@@01LF4P0>3@T061LC014@
300C4Ph040l<00h=2`0920H04a8@024P7P0K6QP03Pd;00l>300A40h040l=008030/901P03P/:00l;
2P0A3@`04Ph=014=300@30/03PX9018>3@0@30/030P700l;2P0>2PT02PT700d<2P081`D03Pd;00/:
200920H03`h<01PG5@0G5Q@03`h<01LF500@3`d300d<2P0300`;2@0;2PP03@T800<04@/;0P0C2P/0
1@0B2`/03@T800`;2@0>3@/04A0>00804Q4?00@01`H4010?3@0D4a404A0>0P0<2`T0>00920H040l=
05mNG00L6aT03Pd<018A3`0>3@/03@`:00l>300A40h040l=00/:200?2`X04`d>00l93@0?20l04@XC
00d5400@21D040TB0109400@2Ph040X;00l;2P081PL040h?01<A4P0?3@h040h?01<A4P0>30d05Q@E
00X82@0G5AH05A<D00<1100=2a404PlF00L42`0A3QD040dD06MTJ`0N6b801P<:00T63@0>2a8030T@
010>4`0:20/06aTL04=1A00H5QT0518E00/9300<2Pd03P`?0P0?3A0200d;3P0800P62@0A3a804Q0C
00`:3@0l>Sd0MWAg00h<3`081PT200d;3P0900L5200G51L030L;00P31`0>2@d050lC00T4200G4QH0
50lC00804`hB00X04PdA014<400B3A8040/A00T42P0D3aD02`H<00d83P0E41H03@P>0P0<1`d01P0>
2@l03`X@00l:400<1`d03@P>00l:40802PD;01<03PT?00d83P0Y92X04@`B00`73@0=20h04@`B00d8
3P0:1@/03@P>010;4@0A31803PT?00`73@0?2Q004PdC010;4@0C3Q@040/A00803`X@00L03PT?00l:
400@2a4050lE01<>500@2a403PT?00803@P>01D03@L;00l93@0E3a<030H:010:3P0B310040X>00`6
2P0D3Q803PP<00@00P070PD01P@700L520091`X02`T<00X82`071@P03P`?00l=400@3Q400P0?3A00
0`0>30l020L<02TZ;`0201hO900405EFF`0;314030dB00`=4P802P/@00@02``A00`;400<2Pd03PX;
0`0=2@X01@0<20T04@d>010<3@0@30d03`/<008030P91P0?2``0100>2P/03`/<01@@4@0>2P/2014=
3P0701<A500<2Pd03@/>00l:400>2@l040/A00l83`0301<94P804@L@00L050dE01H?5`0@2A403@H>
00`53@080@T03`P@00803PL?0P0?21003P0@2A403PT@014<4`0@2a803PT@00l:4@0I51/01P48040k
@P0<1`h07APO00<01@0:1@/02`H<0P0<1`d0300X8bT03`X@00h93`0D3aD04@`B01@?5@0=20h01`88
01TD6@0B3A4030L;00h93@803@P<00P04PdA00`72`080`L04@`@01@?4`0@2`l03PT>00@01@803PT?
018091lU034/<P0E41H0100500D01P0A318030L=01HA5`0>2@d05A0D00/62P0>2@d04@`@01HA5@0>
2@d04@`@00l:3P0=20`2010;3`0C00T31@0>20X02P@600X41P0D3Q004P`>00l92`0A2`d04P`>00h8
2P0<1PP03@L8018=1`0>2@<04@`:04@n@P0E3a<03`X900l:100200l;000300l;0P0A2`T04@/=00H0
3`/:00<03PX900l;2P0@30/00`0@30/01@0=2@X030P9010<3@0@30d030P900<03`/<0P0@30d0700A
3@h04Ph?01@@3`0B3Pd04@d<018>3@0O6aX040`;01DA400>2PT0510?01<?3P0<20L05A4@00d92P0>
2P/04@d>00l;300>2P/04`l@018>3`0300003PX;014=3P0G4a@02PH700l:3`0@2a42014<4P0300l:
400>2@l03@P>00D03@P>00l04PT>010:3P0E3a<04PdC00`:3`0>3A8020T>00`?5P083A<0@4I<09RO
Y@0I7R804A0D00`:3@0@3Q400`0?3A005@0@3Q403@/>01<A500E4aH03@/>00l=400=2`h0Cde@018@
4`0J61/03@/>018@4`071@P07adP018@4`0d<SD0_[bo02d[;P0@3Q403`d@014?4P0200d;3P04010>
4@0A3a804@lB018@4`804@lB00`04A0A010@4P0F5AX07A`S00l=600?3AX04Q0M01<A7P0C4Q/04Q4G
014@5@0A4A<6018A5P8051<H00D04a8G018A5P0B4AH04a8G01TH7@0201HE6P0G01/J7`0M72406aXO
01LF6`0O7R<06QTN010?500D4aP04a8H01DE7@0<31H051@N01lO:`0F5R8051@P01`K:@0C4R005aHT
00X96@0L6b/05QHR01hM9@0H5a`00P0J6Ah00`0H5a`07QdR01XI7P0301PG700Y01LF6`0D51H09B<V
018@4@091`P061HG00l=3P030@8020H701PF5`0J61T04a4B01HD5@0M6a`03`d@00d;3P0B41<04a4D
01DC5P0N71l07A/N01@B5@0W9BP06QPK01@B5@0;2@`061HI01@B5@0A3a805aDH01TG6P0E4aH0518E
01<A500M6ah04Q0C00T72P0F51L06ADF01XF5`0H51D00`0D41401`0B3Pl03`/<01<?400D414040`=
014=3P0F41@00P0B31000`0E3a<050hB018<400501<=4@0701<=4P0D3A@050dD01@=500C31<04P/B
01<<4`0201D>5@0401@=500C31<04``C01@=508040T@00@04@XA00d63@0@2A0050dD0P0B2a805P0A
2Q404P/B018;4P0B2a4030H:00T31`0:10P0208600X32P0F3aH02`@<01<<500=1Pl04`/F024I902V
W:D0AS]300`32@0G31@06a0H00l4300@1@d401463P0Y01063P1BB540BdA<01084`0<11405PhK01`C
8`0;0QD03@@G01067@0@1Ql04PPQ01P@:`0/;D/0724o028VA00A4Rh051@^014<900?1ah03`HK0185
600F1AL05PDE01@34P0P4a`06`hE00l32@0>0@P050L>00l22@0@0`X04@@;00`01P0@0`X04`H=00P0
0P0B1`d060dC01D:400>0`T00P0:00D200L00P0400h32@0E2Q005@X@00L00QCooooo000Kooooo`0H
010>3P0=30/03@`;01DC4`0_;Bd051<B018A400=2`/04A0?00H5100>3@`02PP800X9200A41002`X9
00`;300B4A403@`;01<A4`0@3Pl03@X:018?40091PP04@d=0`0@30`04P0A3@d04Ph>014=3@0@30`0
510@01DA4@0A3@d03`/;014=3@0B3Ph02`L701PD500D41003`/;010<300?2`/04@d=01<?3`804@d=
03H04Pd@01<>5`0B3QH03`/B014?4`0=30h02`X:01DE500;30/04a@B00/=2`0F5aL030d<01<D4P0:
2@P03Ph<00d>300<2``030`<00h?3P0A41402`/:00X;2@0D4a405QDB00/91P0P7Q/03P`901<A3P0?
3@X03@X8018?3@0:20D04Pl=01<@3P0A3``03@/9014?3@0B40h03P`:00h;2P0@3P`03P/:01TG5@0h
=S@03`d;010>300B40h040`;00h:2@0E4A006ADD014=300@30/200d9200F018>3@0D40l0920O01DA
400;2PP04a8@00/:200E51803@`:00l>3@0C4Q003`h<00/:200@3`d03Pd;010?3@0;2PP03@`:010?
3@0A40h03`h<00`:20803`d;02P04@`<018=300B3@d04`h>00d;2@0<2`T03@`:014@3P0;2PP03@`:
00`;2@0A40h07A`J01LF500;2PP04Q4?01@B4P0:20P04a4A00h=300A40l02@P700l>3@0;2@T04Q0@
01LE5@0A3`l02PP800l92P0C3@l03PP<00d73@0B31@03`/B010:4`0?2Q803PX@00d93`0R7b<03P/>
0P0>30h0@P0:20X02`T;00h<3P0D4Q@03P`>010>40081PP02PP:00h<3P0=2`h030X>00d;3`0<2Ph0
4Q0D01/I7@1PGV807adQ00`:3P0>310040hB00`:3P0>31003P`>00X92P0M6ad02PP:010>400;2@/0
3`d?014?4@0>30h040h@00d;3@0@3Q003`d@00h<3`0610L05Q@G01TG6P0<2Pd04Q0C00H41`0B41<0
2@L:00P62@0=2@d05a8G00h93P0A314050lD00X52P0C3Q<04PdB014<4@0@2a003`X?00h93P0?2Q00
3@P>01@?5@0@2a403PT?00d83P0?2Q002`H<00`73@803PT?03804@`B01<>4`0@2`h04@`A01LB5P0E
4A<03`X?00h93@0E41<0:RDZ01/F6P0@30h03@P=00/6300<1`h040/A01<>500B3A<03PT?01PC6@0@
2a403`X@01<>500>2A0030L>00l:400>2@h03`X?00h93`0=20h040/A010;4P0B3A@050lF014<500B
3A@03`XA010:3`0?2Ph05A0D00`62P0>2@d040/?01<=4@0<1`X05a4E04M2AP0K5AT03PX=014<4080
3`/?00<040`@014=4@0@3100100@3100:@0?30l03P/>01PG6P1?CU003@/>00T72`0>3A409R@Z01@B
600?3AD02`TC00`:500=2aD02`TA00X8300@3@l030T;00l<3P0@3@l02`P:00X72@0=2P`03P/=010=
3`0<2@/03@X;00l;2`0>2PT03@T900l;2`0B3Ph04`l?00h:2`0E4A804`l@010<3P0C3a403@T;00l;
400>2`l03PX?00804@`B00X040/A00l93`0@2Q404@/B014:4P0@1`l03@L>00h83P0A2a803`T>0P0?
2A001`0=1`h04@XB014:4P0?21003`L@00l6400>1`l01@0>2A006P0<1`d040/A00l:4@0>2A003@P?
01D@5`0>20l04P`B01L?5P0>2@l050hD00X42P0?2Q004@`B00X730081@X02PH<014>4`0O6al04`lA
00`82P0<1`X030P:00d92`0<20X04`hA0P0@2`h0600?2`d02PH8018=4P0<1`d03`X@00`73@0J5A/0
7aXP00`73@0;1P`04@`B01@?5@0<1`d03@T>00d72`0@2Ph03@P<01@>4P0>2@d04@`@010:3P0B3100
4@/?00h830803PT=01/04P`?018=400@2Pd03PT<014;3P0?2@`03PT<01/E600Q6ah02PD7014<3`0?
2P`050l=00`71@0G4Q80?STk01<>3`0@2`/02`L3018>200=2@<06aHC01D@3`0E41803PX:00l;2`0@
30`00P0A3@d00`0@30`03`/;010<3003014=3@07010<300C41002PP700h;2`091PH03P/;01DB4P02
00l=300900h<2`0>2`/03`d<010=3@0@30/03PX900d9200>2PT05Q8A008030P701403`/:00h:2@0>
2PT04@d<010;2`0A2@d03`P;0108300?1`X03`P9010;300C3@d04@d;018>300@30X04Pl<00h:2@02
00h:3`0?01<?500@3A403@T>018>4`0?30l03@X>00h;3@0@3A003``>00h:3@0A310050lC01lK7`0V
92P04Q0D00804A0D01<01PD:00`=4P0@4QL04A<H014B5`0?3A8040hB018@500?3A4040hB018@500A
3a<03@/?00h<400@3Q803`dA014?4P0B3a4030X<00803`d?01402`X<018A4P0<2``04A0A00h>3`0B
4a@04A8C01DE5P0@3a403`h@010?400>3@l03`h@014@4P0@3a404A0A01<B5002014@4P0F018@4P0@
3a405A@G01XI7@0C4QP04A8I00d<500?3QH04Q4G01<A5@0B4A<04A0C01@C6@0F5AX05A@I01<B5`0E
51P05ADG01@D5`0C4aH05A@I01HE6P8051<I02X05QHI018C500C51D06Q/K01/K7P0H61`04Q8G01@D
6@0B4QT04a8J01PH800H5b406QXY01@B900N7Bh0=SE503hmC@1BDF006aXX01PH9@0I62D05aHR01@D
800J6RD07A`T01PF7P0H5ah05aLN01HH7P0I6b405QPN01PJ800H5ah05QDL01HD6`0D4aP03a0B03Lh
>00F5aL04a8B01HE5@0A410201HE5@09014?400B41404Q0A01LD5@0C4A<05A<E01PF600J61X04a4C
00805aDG01h0518D04=1@`0[:B/06ALI01LE600E4aH09B<W028P900D4QH06aTM00h<400D4QH03`dA
01DC5`0J61`04@lC01LE600E4A804`l@018>3`0D41404Ph?01DA4P0B3Pl04@d>018>3`0G4a@05A4B
010<3@0E3a<2018<400301D?4`0D3Q804`dA00@04`dA00h04P`@01D?4`0@31404P`B018>4`0@2Q00
4P`A014;400G4AH04@X@01@=4P0@20h050`B01D=50804P/B00L05PlF01<<4`0@2A005@hE00l83`0>
1`h05@hE00803`P?01804PXB01@;4`0E3AD04`/C0109400@2Q403PPA00h:4P0B3QH05A4J06EPJP0d
<SX06a@L01463P0B20l050TA01463P0D2A4301873`804@H>03404`P@03H]=014?4@04@L@01hB800A
1aD040@G01477@0A1b403PXT010?:`0@4Rh061hj02`jE01?GWP0A51/01hXA@0J8D00414b01@B<00E
3R`05`dV01T;800E21X050DD01lC700H31@03`@:01453@0G2a804PH=02HJ800H31402`4501H:3`0P
51X04@H;01052P0@1@T02@0101042@0C1`/03`@701<8300B20/040D800`21@0=10H05``?01Cooooo
000Kooooo`0600@30@0<2`T020L500H50`0H5aD02PT7100>3@/200l>300=018A3`0H5aD04A0>00l>
300B4@l030/900/:200920H07QdK00`;2P0D4a40ATE3018>3@02014=308040`;0P0?2`X07@0;1`H0
3@T801@@3`0D40l04@d<00T5100L61L02`L6038^;@0O6aX0510?01`H5`0F4Q406QHE014=300;1`H0
3@T:010:3`0A31803@P>010;4@0A3a@03@/@00d<401?CU<04Q4F00d=4@0?3Q<03`h@00D03Pd;00/0
3`h<01HE4`0G5Q@03Pd;00`;2@0>3@/03`d;014=300B3Pd040`;00h:2@0300l;2P804@d<0`0@30/0
8`0?2`X03PX900h:2@0>2PT03`/:01@@3`0300008QhM01LC4P070`801P8102<O7P0A3@`06ADD01dI
600D40l04`l>01HB4@0I5A@02PH500d9200F4Q402`P700h=2`0100003Pd;0040000>3@/03@`;010?
3@0?3P`03@`:00`;2@0=30X040l=008030/90`0=30X00`0<2`T03`h<00l>300200l>3005010?3@0B
4@l030/901XI5`0B4@l00`0>3@/02`0920H03@`:00L6100<2`T051<A00D40P0=2``030X;01@B4`0E
4a@03`d>00<03@/<01805Q@E01LE5P0?3@h03P`=010:300C3Pl03@T:00d8300A3Q403@/>00H42@0I
5a`01`H;00/:4029R8h0;B`a00h<4@0>30l200d;3P803P`?1@0<2Pd0700=2`h04Q0A00P61`0;2@X0
3P`=00L51P030@8020H700H41@0;2@X03P`=00l=3P0A3a0040h?014?400>30d03@/<00h<3@0<2P/0
2PP901/I6P0F51D04@l@00H41@0<2P/03@/>00h<3`091`X201HD5`0=00H41`0?3A004@lB00L5200=
2`h0518E01`H7@0?2Q004`hD014<4P0<1`d03@P>00h93`0500l:400A014<4P0=20h02`H<010;4@0<
1`d02`H<00h93`0<1`d06QDK01@@5@0300@04`hD01`H6P0B3Pl03`/<010<3@0A3@h00P0?2``01`0>
2P/03@T:00h:2`0?2``03@P;00d83P0=20l00`0?2Q402P0=20l04@`C00`73P0>2A005A0G018=500>
2@l050lC00h93@0<1`/200`73@0801<>500I51/05a8I00H22P0:10h00`0701@?5`0?2Q0200l:3P<0
40/?00L04PdA014<400:1PT0;bX^00l:3P0@2`l03PT=00803`X>0P0@2`l00`0A31003`X>010;3`02
010;3`0?00l:3P0=2@X07QXI00/71@060P4030P901@@4`26PHL0<bhe018<5`0=1a<03PPF00/5500L
5R8081hS008020H901<00@0200/9300?3A002PP;00/9300?3A004Q0C01<A500A3a0030P700d91P0>
2PL040`;014=300B3Pd05Q8C01LC500A3@h03@P<00804@`@00<04@`B010;4@0>2@l00P0>2@l00`0<
1`d03PT?010;4@02014<4P0300l:400>2@l03PT=00<03`X>0P0>2@l06P0B2a<04``D018;4`0A1a80
40HA00l74P0?2Q403PT?00d83P0<1`d02PD;00h93`0;1P`050lE018=4`0@2a405A0F00h63@0A1`l0
4PP@018:4@0A2Q4040T@014;4P0B3A<03P`A0P0=2a000`0>31403`/?00h:2`0200h:2`803`/<0180
3PX;00d92P0>2P/03PX;00d92P0?2``040`?00h93`0=20h03`X@014<4P0@2a403`X@010;4@0A3180
40/A00l:400=20h600l93@0T010:3P0B310050hB010:3P0>20`03@L;018=4@0<1`/03PT=018=4@0@
2`l03@P<01/F6P0300805a8F02<N8P0>2@d030L;010<3@0>2P/05Q8C01DA4P0;1`P040`=00`82@0B
3Pl03`/<024M7P0A3@h0<bl`010<3@0>2P/02`L800X61`0<20T03@T:1P0?2``03@0920H05QDC00h=
2`030P003`h<00d<2P0920H03Pd;014@3P0?3P`03@`:00h=2`0?2`X00P0>2PT06`0?2`X040`;014=
300>2PT04Ph=014=300>2PT03`/:01H@4P0C2A004PL=0146300B1`/04PT:01<:2`0C2`T04@`800d8
100>2`H04@h700h:1`0<2Pd02`T<01<A500@3Q403@/>01<A500200d;300=00h<3@0?3@h02`X800T8
1P071@P06ALJ00/9300H5QT020H900X82`0?3A003@/>010>4@0200l=4006018@4`0@3Q<04@lD010>
4`0?3A8040hC0P0?3A801P0A3a@040hC00d;400>31403@X<01@@4@804a4B00D03`d>00`<300B4Q80
3`l?00h@3`0200lA400600hB4@0@4Q804A4A010@400?3`l0410@0P0B4Q8200h>3P0N014A4@0?3`l0
410@01HC5@0G4QH05Q@G01DD5P0A4Q@03Q8C00`@4@0=4A804A8D01@B5@0C4A@04a0D01`I800K6R80
5A@I018A5P0E5AL051@D01PH600G5aL05aLI010?5@0<2a405aHM01LH6P0D5QD04aDD0P0F5aT0400C
51P0414F014A6@0C4ad051@P01DE8@0H5bH0518W01TG;@0S8CP06AL/01`K;@0l>d`05aHT01HF8P0D
51h301<C6`8061DP01805QHP01LG8@0E6B804aLP01@H8@0H6b@051LP018@6`0A3aX04Q4I00d>400X
:bX02`d<01<E500E5QH061PH00/;2`0D4a<201DC500?01PE5P0F4Q<09R@U01LE5P0X9RL0B4I703@b
<`0:20T05aDF01@B4`0H5QL05aDF01DC500I5aP04Q0D00808AlT01T040hC01lM8P0<2Pl07Q`Q010>
4`0F51T061HK01<A5P0I5aX05Q8C01@@4@0C3a0061@E014=3P0E4A8061@E01HB4`0B3Pl07ATJ024M
7P0H51D05Q0D01<=4@0A2`l04P`@00804`dA0P0B310201<=4@0/018<400E41@04@lB010>4@0>30l0
40hA01HA5@0B3A407ALK00d72`0@20d02`8701D<4@0E3A<04P/B01<<4`0D3A@04P/B0109400?20l0
2@8900d63@0@2A004@XA01L@5`0D31@05`dH01T?6P0G3QT04PXE014;5@0B31H05A8K00L43@0K6R80
fMSP09FEW@0C3A@08QLO03X_=`0H3AD01`0401483P0A1Ph201873`0U01053@0?10`04PL?02@K801S
FF408aHP01814@0G1QP05@PJ00`0600I42/03P`Z00489@0>73T07S5=055ZP02fcnD0/lSQ06]jV@0m
BV`0=ciS01LI?`0C4S@04``Y0188800@11P050LG0104400@10h040D=00l4300>0`X03P<90146300>
0`P02`0400d21P0200l4200:00P0000>0P@02P0000X0000900006Ph@01D92`0?0`D03P8401041P80
20005?ooool001_ooooo00T03`h<01DD4P0E518040l=00T81`0A40h03@`:00l>300@3`d00P0A40h0
3@0@3`d03Pd;00/:200T8b4061LE030_;@2NWI/0>cXh00h=2`0;2PP04A0>018A3`0D4a400`0B3Pd3
014=30803@T801`030P7014=300=2@P04Ph=01@@3`0H51<04Ph=020L6`0;1`H01`<200`81`0@30/0
20@3018>3@0H51<020@501<=4@0B3A4040/?018=4@0B41<040hA01DC5P0N7R004A4C01HF60061PP0
4a8C1@0>3@/0500A40h061LE01XI5`0B4@l03Pd;00l>300?3@/04@d<018>3@0@30/03PX900l;2P0>
2PT04`l>01LC4P0A3@`030P7018>3@0D40l03`/:0`0@30/06@0?2`X04Ph=00<0000>2PT04@d<01hJ
6@0C3`h08AdL010<2`0C3`h0510?01<?3P0A3@`02PH501/G5P0;1`H06QHE020L6`0/:2L03@`:00L6
100F5A<06aXH00l>300H5aD01P0>3@/200d<2P<030/900<03@`:010?3@0@3`d00`0?3P`06`0A40h0
4a8@02d/:P0M71X02`X8014@3P071P@03`h<01LF500920H03`h<020O7@0;2PP030X;00h<3@0B4140
4@l@00h<3@0@3Pl02@L8014?400G5AH04Q0A00`:2`0B41404@/=018=3`0200h:2`0:014>400>30l0
7A/P00P730030PL04a8H01TH7P0920d03`dB00l=40803P`?0P0?3A0200/9300^00`:3@0>30l03P`?
00l=400<2P/04a4B014?40081PL04a4B028P8@0D4Q<02`T:00`:2`0=2``03P`=018@4@0;2@X02PP9
00T7200?3@h040h?00/92P0<2P/08R0Q01`J6`0B41401`D6014?400<2Pd03@/>00/9300>30l030X=
00H41`0<2Pd0?S`o00h<3`0B41<02@L:00l;3`03008050lC00h93@070PH050lC00h93@D03`X>00l0
4@`@00d8300;1PX040/?00l:3P0=20`040/?00D0100300807APL01/F6P0>2@d04@d?014=3P0>2P/0
0P0?2``02@0>2P/03@T:00`82@0;1`P03@T:00l;300>2P`03@P>00h93`0200l:40<03PT?00H03@P>
01<>500F4AL04@`B00l:400A310200/62P0:010;4@0?2Q003`X@02`W;P1:AD`04`hE00`6400I4ad0
:R@]00l:40803`X>0`0>2@d010080`L050lC00`82`0?2Ph200h93@0300d8300>2@d03PT=00803`X>
00<040/?00l:3P0@2`l00P0@2`l0500?2Ph03@T:00H20@0B3Pd02PH501PD5@091PP0>SDk03Lb>@09
0`h03`TE01D?7@0H4R00@ce909NEVP0G5AP03P`?02PV:@10?T40518E0P0>30l0300?3A0040hA00d;
3P091`P02PH500h:1`0B3P/04Ph=00h:2`0=2@X05a<D01<>4P8030L;00`04@`@010;3`0C3Q@040/A
018=4`0A31803PT?00l:400>2@l040/A014<4P0B3A<2014<4P8040/?0P0A31002`0@2a403`X@01<<
500D3AD04P/C01084`0?1a8040PC00h9400?2Q403PT@008030L>00X040/B00<01@0<1`h040/B00P3
2P0A31<02`<;01063P0A1`l04PXA0P0A2Q400`0A2a8040/A00d;400300`:3`0D00d:3@0>2P/03`/<
010<3@0A3@h040`=00h:2`0<20T03PX;00d92P0<20T03@T:010<3`0?2Q003PT?00l:400@2a403`X@
00h93`0?2Q02014<4P8040/A1`0?2@d05P0A2`l04P`@010:3P0>20`03`T=010;3`0;1PX03@P<018=
4@0>2@d02PD900T42016@DD0CDQ<00@00`080`L04PdA01<?400=2@X040`=014=3P0;1`P200h:2`0;
01DA4P0A3@h02`L803Pd=@3;alP06aLH01DA4P0=2@X02`L800d92P0A3@h01P0>2P/030071P@0:RTW
018A3`0;2PP05aHD00`;2@0?3P`030/900L6100510802`X8018A3`803`/:00/03PX900l;2P0@30/0
4@d<010<2`0D40l04Ph=00l;2P0@30/05@lA01@:400201<83P0M0189300C2P/050/<01<>2`0A30T0
3@P500h;1P0B3`X04@d:00/92`0<2Pd03`d@014?4P0@3Pl03P`=00`:2`0@3Pl04@l@010>3`0?3P`0
40l=00l=400b<3<02`T<00l=400<2Pd040hA00l=400=2`h00P0@3Q405P0>30l04@lB010>4@0>30l0
3`d@010>4@0?3A003@/>00h<3`0A3a804Q0C00l=400>30l03``>01LC500C4A804Q0A00d;30051@D0
30`<00l?3`0?4A02010B4@0300hB4@0@4Q804Q8B00@04A4A00`04Q8B00h>3P0=3@d0410@00h>3P0?
3`l05Q@F01TD600G5AP05QDG018C5@0>4Q<200lC500A01<C5@0C4A@04Q0C018>4`0A3QD04A0H00h=
4`0?3Q<05ADG01HF5P0D51@05aLG01PH6P0?3Q@04A0F02/Z<@0E5QX00P0E5QP04@0E5QX051DI01<D
6@0A4AT04Q8J01@D7P0F5R005aLQ01LG900Q83807A/`01`J;`0Q7c@0<S5301TH9`0G5R@05aLR0080
5QHN00@051DJ01<C6`0I5R406aPS0P0K6bD01@0G6b@05ATR01HJ8`0E6B805APQ008061HQ03406APP
01PI6`0B5A@04A<B02<U900C51@06QXJ00l?3`0E51@05Q@E01PF5`0K61T05Q8C01/I6P0@3Pl05aDF
02`Z:`0N71d02`T:01DC500C4A805Q@E01DC500D4Q<05aDF01<A500B41<05Q@G014?4P0N71l04Q0C
014?4P0E4aH06QPK00X82`091`X05Q@G01LC500B3Pl04@d>01XF5`0C3a005Q8C01DA4P0B3Pl03PX;
01PD5@0O6a`06ADF00805Q0D00@05@lC01<=4@0@2Ph03`T=0P0A2`l01P0B31004`dA01@>4P0@2`l0
3`d@018@4`803P`?01L050lC010:3P0I4aL040X>01TA5P0A20d04`X?01493`0A2Q404P/B01<<4`0A
2Q403`P?01D>5@0M5Qd08AXQ01<<4`0@2A004``C00d4300C2A805P`E01@<500201094@0Z00d83`0@
3A@07Q/R00d;4@1?CU@0=C@j00`53@0;00P04`T@01T>5P0F2a<04PL?00l4300A1Ph04`P@01463P0@
1@d04@H>00H0100Z82P04`H@01H55@0O3R00?2a101lA:P0O5S4061Hd01PO?00]>5@0<dAP08VO]P3M
lol0k_oo0=;Qo`20SJl0?D=X01XJ?P0D434040TU01<:7`0C21T05@TF0P0A1@l05P0A1Ph040D=0105
300?10X01`0201D:3`0@1@T0200100/1100=0PH04@D90104200F2Ph0710D00h31P0E2@d04`L;0147
2@0800002`0301/?4`0D20`Dooooo`006oooool0200A40h02@P6014@3P0>3@/05QDC00h=2`0@3`d0
4A0>0P0@3`d03P0?3P`03@`:00/:2@0D4a4092<Q01HE4`13@T00^[Zh03/j>00D4a403@`:00h=2`0@
3`d03@`:1P0B3Pd0400A3@`05A4@018>3@0A3@`030P701@@3`0A3@`01P8201XF5@0810<06aLF01DA
400A3@`02PH6010<2`0C3`h2010<2`04010:3P0@2`l040/?014<40803`d@00<0<S0c09ZJW00S8bD0
0P0@41800`0=30`03Pd;00h=2`0200h=2`0Y00l>300@3`d04Q4?01@C4@0B4@l03`h<00h=2`0?3@/0
4@d<018>3@0@30/03PX900l;2P0A3@`0510?01HB4@0B3Pd03`/:01@@3`0F4Q404`l>01@@3`0E4A00
510?01<?3P0?2`X04@d<01/G5P0?2`X08alN01XF5@0C3`h061@C01<?3P0>2PT0510?014=300@30/0
5A4@00l;2P0;1`H00P0C3`h0200D4a403@`;010?3@0?3P`04Q4?00l>300=30X03Pd;0P0@3`d01`0>
3@/03@`:014@3P0@3`d03`h<00h=2`0?3P`00P0A40h00`0@3`d03`h<00h=2`0200l>300=00`;2@0J
6AL03Pd;00`;2@0@3`d02PT700P71@0@3`d02PT700P71@0@3`d051<A00/92P0200l=3P0;00d;300>
30d04Q0A00/92P0A3a004a4B00l=3P0>30d040h?018<3@0A30d00P0@30d02P0@3@l03`d@00/93@0>
3A404a8G00`<4@0?3Q@02@P=010>4@0?3A0200h<3`0300l=400@3Q403@/>00D03@/>00L03@/<00`:
2`0;2@X02`T:01`J6`0[:BX05aDF00803`d>00/03@/<00X82@0=2``05aDF01PF5`0B41403P`=00d;
300;2@X040h?01DC500200d;300D00X82@0B414030X=00h<3`0A3a8030X=00X82`0@3Q4030/=051>
D@0I5aX02`T<00l=400C41<0?3Lk018=4@0@2`l02`H:01LB5P0=20`700l:3P0=014<400?2Ph03PT=
00l:3P0>2Pd04`hB018=4@1GDUH0EE1D01@?4`0=20/03`/<00h:2`0300d92P803`/<00@03PX;00l;
300A3@h03`/<1P0>2@l200l:400A01<>500B3A<03PT?01@?5@0@2`l03@P;01HA5@0P6b006QDJ00h9
3`0>2Pl07APN018=500>2A408Q`U02XU;@0?2Q000P0?2Ph02@0>2@d03@P<00d8300E41@030L;01@?
4`0@2`l03@P<00h93@0200d830803PT=0`0?2Ph3010;3`0]00l:3P0=2@X03`/<01LC4P0<20P05a<D
014=3`1LEed0<B`c010:4`0?2A@03@LD00P33`0Q6bH0<S0e00d;3P081`T03@/>00h<3`0:2@/030X=
01<A500A3a802`T<00l=400J61T03@T800l;2@0@30X03`/:00d92P0<20T03`/=00d8300:1@T03`X?
014<4@0=20d03PT?00d83P0A318040/A00d83P0@2a403@P>00803PT?00@04@`B018=4`0B3A<04@`@
0`0B3A42014<4P03018<4`0C3A@04P`C008040TC01004@XD00l94P0:1@d03@P@01D@600D3QL04`hF
01H@6@0A2a@03@P@00h94@0@2a<04P/B01063P0A1`l04PTA0P0B2a800`0A2a403PT?00`:3`0300`:
3`0300d93@0>2P/040`=00804Ph?00P04@d>00l;300>2P/040`=00l;300=2@X03PX;014<40<040/A
00D03`X@00h93`0=20h03@P>00h93`0200l:4003010;4@0?2@d03`T=00@03`T=00H03PP<010:3P0A
2`l040X>00l93@0B310200d8300700l:3P0;1PX020<701<>4P0@2`l06ADH01lJ7P0200l:3P0600h9
3@0@30d02`L800h:2`0D41404Ph?0P0?2``02`0;1`P040`=01dI6P0C3a00:BDV01TE5P0F4Q<04@d>
00l;300@30d04@d>00H03`/<00H030/9020O7@0;2PP04A0>01@C4@0=30X2010?3@0401<B400E5180
4A0>00T81P804@d<0P0?2`X01@0@30/04@d<00l;2P0@30/03PX9008030P700D03`T901<93@0C2@d0
4`T=01893002014:2P0=010:2@0@2`P040`9010<200?30L03PX700l=3P0@3Q003@/=014?4@0A3a00
2`T:00`:2`0200l=3P0D014?400H5aH07A/L01<A500V92L03@/>00l=400>30l04@lB00l=400>30l0
4Q0C010>4@0>30l040hA018@4`0>30l04@lB01<A500A3a8600l=400>01hK7@0W8b@0518C00l=3P0D
4Q<04A4A018B4P0>3Ph03a4@014C4P0@4Q403A4@010B4P0D51@201<C4`<04A4A00X0410@01<C4`0H
61P04a<C014A4@0E4Q@05A0D01<A500D51H051DG0`0?4a@0900A4Q@04a4D01<A500D4AD04@hE01/J
8P0O7R@051<H018B500C4a@05ADF01<C500C4QL03`hD018A5`0W9Rh04Q<J01HF7`0F5ah05ADN01LG
800D51d05QHO01DE7P0E5Al06ATR01XJ8`0I6B<071//02<R<`0E52D08B0`04M6E00U9C4061PS01XJ
8P806Q/P01<061TM01HG6`0K62406aTT01PH8P0G5b405aXS01XN9`0L82T05APQ01@G800G5B00518M
01DD700E5QP051LF028T8`0Y:bX04a@C00805QHF00/05aHG01HD5@0I5aP06QLH010<3@0F51D061HG
01<A4P0D4Q<04@l@01lM7P02018@4@804a4B0P0D4Q<0<@0K6A`0518E01LE600B41<061HI01HD5`0G
5AP03`d@01hL7`0C4A@05A<F01HD5`0H51D05A4B018>3`0G4a@040`=01HB4`0D41404`l@014=3P0E
4A805a<D01<?400A2`l0618F01XD600G4AD04P`@014;3`0B31004@/?018<400D3Q805Q0D01D@500E
4aH04Q0C01DC5P0@3Q403`X>01D@500K5AT030H:018:3`0?1P/05PdB01@<4P0B2a800`0C31<07@0B
2a805@hE00/42`0=1Pd04@XA0109400C31<040P?01<9400D2Q<050`C018;4@0@2A4050hE00D11@0?
2a804@lD00X93@0:2@h05@hE01873`0G3A@03P<;00l4300B20l03P<;01463P0D2A404PL?008040D=
01P04`XA01473`0F2A<05PHF01<75@0N3b<07@lX00l77P0b<4/07R8n034iE@1WMY00`]C^0>_lo`3^
oOl0c=Sb071iV`0c=e/07Adn01DB<00?22404`XL01<85`0B1Q4201453`804@H>01@04PL>01873@0@
1@/06PlD00l4200<0`D05@X>00`11@0:00<04@D;00X00`0=0PP02`4501L:400E2a003P@801/>500S
5Qh04PH<01052ACooooo000Kooooo`0600l>300F5A<071/I00P71@0U92806aXH0P0>3@/00`0=30X0
3Pd;010?3@02014@3P8051<A0P0C4Q001`0F5A<06aXH01/J600510804Q4?014@3P0920H00`0A3@`3
018>3@0J01<?3P0810<02`L600l;2P0G4a8030P7018>3@0@30/04Ph=01HB4@0300003PX9028N7@0L
61L03@T8018>3@0I5A@02`L6018<3`0C3Q805a8F01HA5@0@3Q404@lB01`J7@13@dD200h>400500D5
1`0?3Pd03`h<00l>300>3@/00`0=30X00`0:2@L02`X800l>300200`;2@0:00l=2`0A3@`04Ph=010<
2`0>2PT03`/:018>3@0A3@`040`;014=30804`l>00@04Ph=014=300A3@`04Ph=0`0A3@`0500=2@P0
4`l>00l;2P0:1PD040`;01@@3`0I5A@04`l>00d9200B3Pd040`;00d920060P405A4@00l;2P0P71/0
5A4@00h=2`0`;bd0:2LU0P0100001`0?3P`03Pd;00l>300@3`d03`h<00h=2`0<2`T00P0A40h3010?
3@03014@3P0?3P`03Pd;00<03Pd;01/040l=01HE4`0?3P`02@P601LF500@3`d04a8@00l>300I61H0
1`H401@C4@0_;R`05A@B00X82@0?3@h03@/<00`:2`0?3@h03P`=010>3`0?3@h030X;00h<3@0A3a00
2PP901<=3@0?2P/00P0@30d0200>2`d040hA065OHP0I5a/07ahS010?500920d01PD:0P0?3A0200h<
3`803`d@00h040hA00l=400>30l03@/>00`:3@0;2@`040h?00h<3@0A3a003P`=00L51P0610D03P`=
00`:2`8040h?00P030X;00d;300B41406ALH01<A4P0<2P/03P`=010>3`<03`d>010071XK00h<3@09
1`P03@/>014?4P0B41<03@/>00l=400F51L04Q0C01DC5P0>30l03`d@01/I700D41@0FUEI0P0@2`l0
0`0A310050lC00d8300500l:3P0900`72`0>2@d040/?00`72`0=20`03PT=01@?4`0B3A402PD90080
30L;00L04PdA01PC5P0?2``03`/<00d92P0<20T03PX;00804Ph?00D040`=014=3P0A3@h03`/<00l:
3P0200h93`0F00d83P0>2@l03`X@00/6300:1@/03@P>00l:400@2a4071LL01@@4@0?2``04@`@01HA
5@0D3a<04PdC00h93`0300@04@`C00X5300J5A`061<K010;4@8040/?00X03PT=00d8300=20`04`hB
00l:3P0>2@d020<7018=4@0>2@d03@P<0P0>2@d200l:3P03010;3`0?2Ph040/?008040/?01`03`X>
00d92P0N6Q/02PH600d9200Q7Ah03PX<014<40060@L02@@<00`6400>21804@/G018<5P091``01PD7
00<1100>30l03`d@00/930091`X04a4D010>4@081PT03`d@028P8@0@30d03PX90P0<20L0300>2P/0
3`/<00X52@0>2@d030L;00l:400A31803PT?01HA5`0M61h05a8H00h93`8030L=00@03@P>00`73@0=
20h03PT?0P0@2a42014<40804PdA00<04@`B010;4@0?2Q400P0@2a8200h84P0=010:500E3aT030H@
00l94`0F41X04P`F00L32`0F41X02@<=01LA6`0I4ad00`0701494P0201473`0601083`0A2Q404P/B
00l9400<1`d02`T>0`0<2Pl00`0=2Ph03`/<010<3@02010<3@803`/<00/040`=014=3P0?2``03@T:
00h:2`0@2a0040/A014<4P0?2Q003@P>00h93`02010;4@0400d83P0:1@/02PD;00T42PL03`T=0140
40X>014;3`0>20`03PP<018<400:1@T03@P<010;3`0<1`/03@P<02@O8`080`L071LK01@?4`030080
4PdA00/62P0200`82@07010<3@0F4Q<05A4B010<3@050@80510A01PD5@0200H20`0700T51P0;1`P0
3@T:00l;300@30d03PX;00`82@06010<3@0<014@3P0;2PP020L500l>300=30X04A0>00T81P0<2`T0
40l=018A3`0A40h03Pd;0P0B3Pd3010<2`03014=300@30/040`;00803PX900<03`/:010:2P0A1`/0
0`0B2@`06P0?2@T03PP8018<300D40d06ADB01LC400A3PT04@d:014@3P0A3a0040h?00l=3P0B4140
5A<D010>3`0<2P/02@L800X82@0A3a005A<D00l=40050`H03P`?010>4@0=2`h03P`?0P0?3A001P0B
41<040hA00`:3@0>30l04Q0C010>4@804Q0C00<04@lB018@4`0@3Q400P0=2`h02`0?3A0040hA00/8
2P0B3Pl040h?00d;300K6AX0<c<c030`<00?3`l03a4@0080418A00<03Q8A00lA4@0B4Q800P0B4Q83
014A4@06018B4P0G5aL07AdM01HF5P0A4A404A0A0P0?3A000`0B4aD051PI014E5P0200lC500T010A
4`0B4Q@0518E01LC600C4QX08B0X02TX;`0H5a`040lD010@4P0K6ad05ADG01<B5`0B4AL040lE014@
6@0A41h05QDU01LF900K6RP08b8`01/K9`0O7b/06QXT01DE7P0H620071`T01lO9`0E5B4071/Y01HF
8`0A4Ad03@dG028R:`0E5Ad05QLL0P0F5a/0100F5aX051DI01XG800K62<201LG8@0b01dP:@0W:c@0
6QhW01<G800G6R<06QPS01PF8@0P7bL05AHH01/N7@0H6QT04Q@C01@E5@0J6QX0410@01DD500E4a@0
5aDF01TF5`0C3a004Q0A010>3`0B41406aTJ014?400?3@h040h?01<A4P0A3a004a4B01DC500B4140
5Q@G01PF6@0E4aH04a4D01@B5@0G5AP04@lB02HT9`0k>C`0518E00h<3`0?3A005a<D01HB4`0D4140
6ADF010<3@0C3a0301PD5@0501HB4`0C3a004@d>01D?4`0C3A400P0@2Ph00`0I4aL081XN01@>4P02
018<400401<=4@0F41@04@`@01PF6@803@/>00T05Q@G010;3`0K5AT0:28V01XD600Q6Qh060lD01H=
4P0B2Q000`0C31<201@=500G02lX;`0U7RD04``C01@=500<1@`03`P?018:400A20d04PT>01@<4@0C
3A404@/?010:3P0F4AD061<G00T420030@@02PD900d6300800D06PlG01H;4`0J3aL00P0?10`07@0A
1Ph04`P@01463P0@1@d04@H>01H<500G3AD04PHA00/0300H2QT05@LJ00T04`040180;2U1010B:`13
BF40SiZd05ESOP2JZ<D0f>?o08jG^00f?5h05QPh014>;@0;1b802P@H01465P0A1a804PL?00803@4;
00/03@8:00h32`0>0`X03P<900T0100<0@H040D901/@500O51P02`0600h12P0201<63`0501/>5`0?
10/0200401853P0M4aT00P0800@00`0E21402`07ooooo`0Cooooo`006oooool01@071P@04Q4?01<B
40040`4051<A00804Q4?00L040l=00d<2P0=30X040l=01<B400?3P`01@@200804Q4?00P020L501LF
500@3`d0HV5O01TH5P0:2@L05A@B010?3@<040`;02404@d<018>3@0B3Pd04Ph=02<O7P0Y9B@02`L6
01TE500810<0510?00/71P0=2@P06ADD00<0000O6aX0AT91044m?00E4A00510?01hJ6@03000050h@
01LC500N6Q/071PI018@4@0C4A803`d>00P8200<30`01`L703@d=00K6aX00P0@3`d01`0>3@/030/9
00`;2@0>3@/030/900/:200?3P`00P0;2PP01`0@3@`04@d<018>3@0@30/03PX900l;2P0@30/00P0?
2`X5014=30<040`;00D04@d<00l;2P0J5QD040`;00h:2@0201HB4@05014=300@30/03PX900`81`0>
2PT0100?2`X02@0;1`H03PX900X61@0J6AL0]KBb06ASH@061@<08b8P014@3P03010?3@0300h=2`0=
30X030/900803Pd;0`0?3P`06@0>3@/03@`:00d<2P0=30X03Pd;00l>300A40h07QdK01TH5P0@3`d0
5aHD00d<2P0B4@l020L500d<2P01000030/9024P7P0920H02PP900h<3@0;2@X03@/<014?400:20T0
0P0@3Pl01P0:20T030X;014?400:20T050h>00l:2@804@d<00D03@X:014?400X9RT0?Sdo00l?4@02
014@5@0301<B5`0>30l03P`?00803@/>1`0>30l04@0=2`h030X;01TG600J61T02PP900T7200B4140
518C00l=3P0A3a003`d>00/92P0<2P/01P@500d;300;2@X03@/<00804a4B01L040h?01<A4P0F51D0
9R@U01<A4P0;2@X03@/>014?4P0>30l030X=00l=400A3a803`d@00L5200?3A004Q0C00T72P091PP0
81`M014=3P0;1`P04Ph?01@@4@0800l;300F00`82@0=2@X05A4B01<?400=2@X02@D6010<3@0B3Pl0
3PX;00d92P091@H03`/<010<3@0>2P/030P900l;300A3@h03`/<00h:2`0@30d04Ph?014=3P803`X>
0`0=20`0100?2Ph030L;00X52@0=20`2010;3`0>01LB5P0?2``02`L800`82@0=20`030L;00l:3P0A
318040/A00l;400300D05A0G00H2200B3A<2014<400500l:3P0>2@d03PT=00P31`0A31000P0B3A40
0`0D3a<03@P<00h93@0200l:3P8040/?00<04@`@00l:3P0@2`l00P0@2`l0200?2Ph03@T:00<0000W
8b<05Q8C00<0000?2Pd04PdA0P0E41H03@0B3A@03`XA00X53P0910/03P`A010>4@0W9BP00P0300L6
200@3Q403@/>014?4P0<2Pd00P0610L05`0=2``03PX;00d9200<20L03@T:00h93@0?2Ph040/?01<>
500?2Q003@P>014<4P0B3A<06aHL02TT:P0J5A/03PT?014<4P0=20h040/A00h93`0=20h03PT?0080
40/A00@040/?014<400A31004@`@0P0@2a402P0;20l03@XA00`9400;214030TB00d:4`0D3QX04@/G
010:5P0A2aL200l95@0>01H@700H4Qh0CTQD03dg@`0@2QH05PhG0188400A1`l040P?0109400A2Q40
3PP>00X52`0:20d200/93P0500X83@0>2Pl040/?00l:3P0>2@d00P0=20`03`0>2@d040/?010;3`0>
2@d030L;00d8300>2@h03`X@014<4P0?2Q003@P>00l:400A31803`X@00d83P0200/6300300`73@0?
2@d03`T=00@03`T=0`0A2`l200h8300=014;3`0?2Ph03@P<00h93@0=20`03PT=01dH700>2@d01`86
00X62@0C3Q804@`@010;3`03010<3@804@d>00T03`/<01<?400=2@X02`L8018>3`0N6Q/02PH700d9
2P0?2``00`0B3Pl00`0@30d03`/<00l;300400l;300>018A3`0<2`T040l=00`;2@0@3`d04a8@00`;
2@0F5A<04a8@00T81P0;2PP06APF01<?3P0B3Pd4010<2`0L014=300@30/03`/:010<2`0A3@`04P`<
01892P0C2P/050/<018<300@2PX03`T901DA400F4Q406aLF01LF4P0B4@d051<?00h=2@0?3P`04Q4?
00l>300F5A<092<Q014@3P0=2``030X;00d;30803P`=00<04Q0C00T72P0E4aH00P0B41<0200C4A@0
3`d@00l=400C4A@040hA00`:3@0=2`h040h?0P0A3a004@0?3@h040h?014?400?3@h03@/<00l=3P0A
3a0040h?018?400P71d071XK00l=3P091`P0410@01TI6@0?3`l03Q0?00803a4@00D03Q8A00lA4@0?
3`l04A4A018B4P02014A4@0b018B4P0A4A404a<C01LG5`0B4Q803`l?018A4`0A3a@040hC01<C600D
61/03a@G014F6@0@5AP04A<G014@5@0B4AH0518G00T8400B4QX061TO018C5`0A4QH04Q<E01DF600A
4Q@051DI01TJ7`0F5Qh05QHQ01@C8`0H5bT06APZ02<R<P0^;Cd08b<`038b?P0X:38061PQ01@D700G
61d06AXO01PH8P0N7RX04Q8M01XJ900E5Ad06ATP01DF6`0E5QX201@E6@0Y01DF600E5QX06aPQ01hL
9`0K6bD061PR01/O:00T:3405ATR018E7P0J7BH07Q`W01lL9`0^;CD08b@X01`N800E5QP03PlA01DE
5`0B4Q@03`lA01HE600G5AP05Q@G01PD600E41@05A<D01TG600G5AH06aTJ01@B4`0N71d040h?01@B
4`0A3a004a4B01HD5@0B41405Q@E01PF5`0@3Pl0100E4a@0300n?3d0EE=D01XH6@0E4a@06aTJ01LC
500A3@h0510A02<O800F4Q<04Ph?01DA4P80510A01/04Ph?014=3P0C3a005Q0D01D?4`0A2`l03`T=
01PB5P0O6Ad05@lC01<=4@0B31004`dA01D?4`0B3A40FeUL06e[KP0_;C005A<F010;3`0F4AD09R0T
01lI7@0/92T07aHK01L>4`0@20h00P0A2Q402P0B2a804``C01<<4`0M5Qd040T@00L01`0:0`X03@H=
018;4P0@20h200h5200@0149300A2`d03`T;01<=3`0A2`d01000010:300A3@h030H801<;4@0W72@0
=b`d00h32`0700@060dE01463P804PL?020040D=00l4300B1`l04`TB00H01@0<0`d04`LE00h2400E
21X09AT]01H=8P0C3bD071db01/P=P0e?5D0;cQE04QCL@1dO9/0CU=c03DhF@0K6cX030TV00T5700=
1aT04PLE01063`0C20h03@8:00h2300>0`/03`@<0105308040D;01403`@901<8300H3A405@X>00`1
1`0@0``0200501853`0K3QP03@0:028E7`0800D0NFaf04i1B`0800D0300900h12`0Dooooo`006ooo
ool0600=30X03`h<014@3P0A40h040l=01@C4@1/JfT09B@R00/:200B4@l03Pd;010?3@0C4Q003`h<
00X91`0920H04Q4?01<B400;2PP0:2LU00/:200A40h03@`:00/:208040`;00P03`/:018>3@0B3Pd0
3`/:01@@3`0d<2l0?c/j014=30804Ph=00h0;BTX02XV9@091@@03`/:01LC4P0A3@`05A4@00h:2@0@
30/03`/:010<2`0F4Q404P`>014=3P80510A0P0>30d00`0?3@h051@D01<C4`0200h>3P07010?3P0>
3@/04A0>010?3@0:2@L03`h<014@3P0200h=2`07014@3P0>3@/03@`:018?3P0E4A004Ph=00h:2@02
01<?3P0400d9200>2PT04@d<018>3@803`/:00`040`;018>3@0A3@`040`;014=300B3Pd04@d<018>
3@0:1PH05A4@01<?3P0;1`H2010<2`0A014=300@30/040`;01<?3P0>2PT0510?00d9200@30/03@T8
01HB4@0J6AL0?Sdk03Th=P0?3P`02`X800`;2@0@3`d00P0<2`T01@0D4a402`X8010?3@0=30X03Pd;
00<03`h<00<03Pd;00/:200<2`T0100>3@/00`0=30X03`h<00`;2@0200h=2`804Q4?01/03@`:014@
3P0<2`T02PT801LF500;2@X030X;00d;300?3@h03P`=00/92P0>30d040h?00`:2`0;2@X03@/<00/9
2P0C3@d03`X9010<2P0@30/03P/:010>3P0B4180AdI803@d=P0=31000P0:2Pd0500?3A0030X=00L5
200@3Q403P`?010>4@0>30l04a4D00h<3`0=2`h040hA00h<3`0@3Pl03@/<00h<3@0?3@h03P`=00l=
3P0>30d030X;0P0>30d200`:2`8040h?00`03@/<00l=3P0@3Pl02`T:00d;300A3a004a4B01/I6P0A
3a003P`=00d;3P0?3A0200`:3@0400h<3`0<2Pd030X=014?4P<02`T<00@04@h@00X71`0I5AH03@T:
0P0?2``01@0=2@X040`=014=3P0@30d04@d>00804`l@00X04@d>00/7200A3@h0DDe>01hJ6`0:1PL0
3`/<010<3@0<20T02`L8100?2``0100>2P/03@T:00l;300A3@h300l;308040`=0P0?2Ph01@0>2@d0
3@P<00h93@0?2Ph02PH900<040/?01T04PdA00l:3P0<20T03@T9014=3@0A3@l03`/=010;3`0@2a00
4`hC00/6300F4AP04@`C00d83P0B3A404@`@00l:3P0B3A403PT=00h:3@0<1`/03`X>00`72`0?2Ph0
3@P<008040/?00@04@`@00h93@0>2@d04@`@0P0@2`l200l:3P8040/?01d03PT=01@@4@0=2@T04Ph?
014=3P0C3a402@D800l:3`0=20d03PT?00`73P0=20h050lF00/93@0D4QD0?3Xm01PF6@0?3A002@L:
00/9300>30l02`T<014?4P0O7B003P`?00h:2`0>2PX03`/;00l;3@0200l:3P0505=>D`0a;3804PdC
00h93`0A31<00P0B3A<00`0K5Q`04PdC00`73@0200l:4003014<4P0?2Q003PT?00803`X@00<040/A
010:3P0A2`l00P0A3100500B3Q@04Q0E00d:4@0<2Q002`T@00`;50051@`040lG010;5P0B31L040XE
00d74P0?2A@04@/F01DA6P0l=T40@ce8038/=`0C3AP040PA0P0C2A403`0A21003`P?0109400>20h0
5A0F00l=4P0D4QL0=S@i018@5@0@31403`X>00h93@0=20`02`H:00`72`0200h93@0@00l:3P0>2@d0
3@P<00d8300=20d03`X@00d83P0A31802`H<02@O9@0e<3H03`X@00d83P0>2@l040/A014<4PL03`T=
00P04P`@014;3`0?2@d03`T=010:3P0B3A403PT=00`72`803@P<00T03PT=018=4@0?2Ph04@`@01/F
6P0D3a<040/?018>3`0C3a000P0?2``01P0>2P/03`/<00l;300<20T05a<D010<3@803`/<00P02`L8
018>3`0=2@X03`/<01@@4@0:1`L03`/<00h:2`804@d>01@03PX;00l;300=30X03`h<014@3P0:2@L0
40l=00l>30081`D07ahL02LV900C4Q002`X900h=2`0?2`X04`l>01HB4@0I5A@03@T8014=30803PX9
01l03`/:010<2`0A3@`040`;014;2P0C30/050d<01<=3@0A30`04@`;014=300=2PT05Q@B00d<2@0C
4a003`l:00l>2P0=30P04Q4<010?2`0C4Pl07QdJ010?3@0;2@X030X;01<A4P0C4A<040h@014?4P0B
41<02PP;00<04@lB00h040hA014?4P0<2Pd04a4D00H51`0C4A@03`d>010>3`0?3@h03P`=010>3`0A
3a003`d>00h<3@804@l@01003`d>00h;300@30d03@/<01@B4`0]:b`0>SXj01DE5@0?3`l03Q0?00lA
400>40l041@C01<E500G5aL04Q8B0`0A4A40<00E5AD0410@010@400A4A403@d=00h>3P0E51L04@lE
01DD6@0?4AH061/O018G6P0T:B`05Q/O00hB5P0D5AT051<I018@5P0A3aX04A4K018B6P0B4aP061TM
01<D600E5QT051DH01<D6@0E5Ad05aLO01LF8P0F52P07A/`01@B:00Y:3X0=SE502h]?00g=d<0:RXd
01PH800F5a`061TM01<D600>3aD08b<Z01HF7P0E5A`061TN014B5P8051DI00/05AHJ01LH6P0H6A/0
5aPL01XG800L6B@061PR01HF800C5Ql05ATR01TM9P0201DH8@0N01HD7`0D4Qd06aXR01TJ7P0C5AL0
4Q<E03@e=`0J6ad04Q8D01LG6@0G5QT061HI01HD5`0D41@06QDI01LE5P0C4A806aTJ028P8@0G5AH0
5A<D01@B4`13@D806QPI01PF5`0B41405A<D01LE5P0D4Q<03P`=0P0F51D01@0C4A805Q@E01@B4`0O
7Ah040h?00805Q@E00L05a<D00h:2`0F4Q<0:RHW024M7P0B3Pl05A4B00804Ph?0P0C3a00100D4140
5@lC01PB5P0H4QH201D?4`805Q0D0`0E3a<0:`0F41@08ahR0;:`/`3Zj>/0FEMJ018@4`0C3Q804`dA
01PB5P0?2@d04``@01<:3`0F3A805@dC00h73P0?20l04``C014:4@0D3A@06a@K01TB6@0F3aH05@hE
01<<4`0@2A0030H:00h62@0?1`X04P/>018<3P0C2`h04PX=01XB5@0A2P`040P;014:300A2@`050X?
00h32`0I3QH04`P@01L<500C21000`0B1`l0<`0@1@d04@H>01<8400@1Pl040LA01<9500K41h04@DC
01P<7@0B1aT040LI01PC9@1JEf/05aPZ01HJ;P0R9D807RA103XmG00a<U40<S5?010=:@0?2R804@XP
018;6P0B21<04@L?01873@0C210030<:00h42`0C21003`D;01@93`0K41H02`8500h31`0;0@@03P@7
00h52@0G2Q<04@@>01L:500;00P0718I07AWL@0X6bD09a/T01P;5@0;00P04@@>01853`0Dooooo`00
6oooool05P0<2`T03Pd;018A3`0@3`d03`h<01LF501RHEl07ahL00T81P0D4a403`h<00/:20051080
2`X800d<2P0E51804Q4?0040000;2PP03@`:00h=2`0@3`d2014@3P0300h:2@0A3@`03@T8008040`;
00@030P7018>3@0A3@`05Q8A0P0>2PT01`0E4A008QhM05QDD`0G4a8040`;01PD4`070`801P0@30/0
100C3@l03PX;00h:2`0@30d200h<3@0<010>3`0>3Ph03@d=00`<300?3`l04A4@01LF50020@003`h<
01lN700920H02`X80P0?3P`03`0>3@/02`X800/:200=2PT04Ph=014=300B3Pd08alN02@P7`0B3Pd0
30P7014=300F4Q40510?014=3006010<2`804Ph=00P040`;00l;2P0?2`X040`;00l;2P0A3@`040`;
00d920803`/:01803PX9010<2`0C3`h03`/:00`81`0;1`H020L500T81P0C4Q0030/900/:200?3P`0
4A0>010?3@0C4Q003Pd;00L6100920H600h=2`8030/90`0=30X00`0<2`T03Pd;00h=2`0400h=2`0<
01<B400;2PP03Pd;04e<BP0K6QP02@P601@B4`0>30d03`d>00d;30091`P03@/<0`0?3@h06`0>30d0
30X;00X91`0A2`/040/800h:1`0>2PT03P`:00h=2`0<2P/04Q4B018B500=3@l02`/=00d=3`0610L0
6ALJ01lM800100802`T<00h<3`0C4A@061HI00l=400>30l04Q0C00d;3P0300d;300400`:2`0:20T0
2@L800h<3@803`d>00/03P`=00d;300<2P/03P`=010>3`0;2@X03@/<00h<3@0:20T030X;010>3`02
018@4@0300l=3P0=2``03@/>00H03@/>00D04@lB00d;3P0@3Q4061HI00h;3@0201<?400E00h:2`0@
30d040`=00/7200<20T04@d>00T51P0300002@D600/7200300006aLH010<3@0Y9BH00`00018>3`0>
2P/03`/<00d92P0<20T03@T:00803`/<0P0@30d200l;300600h:2`0?2``040`=00l;300=2@X03`/<
1P0>2@d01`0L5a/07aXN00l:3P0>2@d061<G02<N8@0?2`X00P0@30/2010<3@0O014<400<1`/03`X>
00T42P0K5Q`05A0F00d83P080`L06aHJ00l:3P0<1`/04`hB02@O8`0B3A406aHJ01LB5P0=20`04@`@
010;3`0<1`/02`H:00X52@0@2`l04`hB00P31`0D3a<04PdA014<400B3A404@`@00h93@0400l;300D
00l;3@0?2Ph03PT=010;3`0>2@d030L;00d83@0A310030X=00h<3`0?3A003P`?00`:3@0:20/02@L:
010>4@0610L02@L:024O8P050`H300l;30<03`X>00l0BDA:03Ha=`0E41H03@P?014<4`0<1`h030L=
018=4`0?2Q002PD;00`73@0A31803`X@00h93`0=20h00P0>2@l06@0?2Q003@L;010:3P0@2Ph03PT=
00`:3`0=2a003PdC00P73@0G61d02PXB01TI8@0000L040`D00l94`0=20l03@P@00h84P0>214040/B
03La>`090``04`hE014;5@0D31@00P0C2A403P0A2A003`P?00l83`0A2a4030L=0040101FE5T0f]SM
05MEFP081@T040/?014<400@2`l03`X>0P0@2`l500h93@0900h93P0F4AL03PT?010;4@0400D04@`B
02dX;P0B3A<040/A00803`X@00<03PT?00l93@0?2@d0100?2@d01P0;1@T03@L;00l93@0D3Q80618F
018<408030L;0`0=20`05P0>2@d02`H:00T4200;1PX04PdA01<>4P0>2@d030P900l;300A3@h03PX;
00H20`0`;2d0@cm001TE5P0<20T0510A00/7200:1PL03PX;034];P0T824200d92P0301HB4`0@30d0
3PX;00804Ph?00<03PX;010<3@0=30X01@0=30X03P030P003`h<00l>300P7ad02`X801@C4@0E4A00
40`;00<0000400009B4P00T5100>2PT03`/:0`0@30/01@0?2`X040/8010;200A30T04P`<00804@d<
00d03P`:00`;2@0C4Q003@`:01<C4@0;30L04a<<00d=1@0E50l07QdH00/:1P0M71P040l=00803`d>
00D040h?014?4P0B41<030X=01PF6@0201<A500800800`0@3Q404@lB01@B5@0<2Pd04a4D01LE600C
4A@200h<3@0400l=3P0@3Pl04@l@014?40803`d>01L040h?00l=3P0?3@h0514B018>3`0>30d03@/<
01HD5@0^;Rh02PX:00l?3`0@4Q404aDD010B4@0A5A@0418B00P8200?3`l07QhN00l?3`071`L04a<C
01HF5P0201DE5@1^010@400B4Q805A@G00h=4`0H6Ah04aDJ01@I7@0>4aL07b@X010E6@0<3a@051DJ
010A5P0?3QD05QHP00H64P0I6B8030dB01<D6@0H6Ad06Q/O01/L800H6Ah06ATQ01dM9`0F5B806QP]
02PV?00K6Bh08R4c038a@@0o?d`08R8/01PH800?41H051DI01LH700@4A<051DJ01XK800B4aP04A8G
010A5P0C51P051DI01HG6`0I6Qh06a`P01dN8@0O82@06aPQ01XH8`0H62805aLQ01DH8@0D62404aLP
01<F7`0D5b0061HQ01PE800D4a/03a0D01XL7P0L7Al0^[^m051AD`0G5aT07AdO01HE600K6A`06QPK
01HC5P0R7B40>cTj02HT9@0M6a`05aDF00/92P0=2``01`D6051>C`0J61T06ALH010>3`0J61T05A<D
01@B4`0G5AH06ALH01HD5@0C4A805Q@E01LE5P0E4a@04a4B01DC500G5AH07ATJ01@@4@0F4Q<06ADF
01PD5@0>2P/04`l@010<3@0A3@h0510A01<?400@30d201D?4`@050hB00<04`dA01@>4P0E3a<00P0E
3a<03`0J5AT0=38e04a:C@0G5AP040hA01`G6`0K5QX050hB018<400B2`l04`X?01@;400Z8RP081TP
014:4@0301@=500701D>5@0B2a8030D<01<<4`0E3QD04``C018<4@0200l92`0401<=3`0?2@/040L:
018930804@P;00H04PT<01<:3@0D2@d04`P?01<8400F2a<201@94@0301P=5@0A1Ph04@H>00<04@H>
03404@H?020F8@0:0Pd04`TD00X03@0=0Q004PXG01D:6P0C2aX0208A02LS<P0<21L040hN01DB;@0>
3RX071Tf01XF<@0H52l030LO00h66`0@2A/03PHD00h43`0A1a004@H>01<74@0L41X05``D00X01`0?
10/03P<9020E6`0800807A8F01462P0800404PL=01@7400?0P`05@PB01033@0:00L07A0J00h12`0<
00T03`8<01D84P0C1Q002P0701Cooooo000Kooooo`0Z00l>300=30X040l=010?3@0>3@/04A0>00h=
2`0A40h030/900d<2P0@3`d02PT700h=2`0C4Q0040l=01LF500;2PP07ahL010?3@0?3P`03Pd;00l>
300A40h04Q4?00l;2P0B3Pd040`;00l;2P0@30/03PX9014=300C3`h02`L6010<2`0E4A004Ph=01TE
5@1HE5<05a<B00h:2@0L61L030P71P0@30/0200A2`/03PX900l;2P0B3Pd03`h<00d<2P0?3P`03Ph<
0P0=3@/01`0@40h02PT800L6100Q81h03Pd;00D40P0H5aD00P0?3P`01@0>3@/030/900`;2@0=30X0
3P/:00<04Ph=00T071PG01/G5P0>2PT03@T8018>3@0H51<05Q8A018>3@0?2`X00`0@30/2014=3080
4`l>00<040`;00h:2@0?2`X00`0A3@`01@0?2`X03PX9018>3@0?2`X04@d<00804`l>00<03`/:00d9
200=2@P00P0B4@l02P0920H030/900`;2@0;2PP03Pd;00/:200C4Q002`X8020O7@0<2`T600h=2`06
00l>300>3@/03Pd;00d<2P0>3@/03`h<1`0>3@/03@0E5180H5mM0=GDdP0];2X01@@201LE5P0@3Pl0
3@/<00/92P0:20T03P`=00l=3P0@3Pl00P0?3@h0100=2``030/9014;2`0@2`P200h:1`0400h<2@0>
3@/03Pd;00h=308030`<01403@d>00h>400?3A001P@700T72P0=2`h03`d@010>4@0B41<0518E00h<
3`0@3Q404@lB00`:3@0>30d03@/<00`:2`0300/92P0300l=3P0>30d03@/<00<03@/<00P03P`=00l=
3P0<2P/03@/<00h<3@0;2@X030X;00d;30803P`=0P0=2``600d;3P0?00`:3@0>30l030X=010>4@0F
51L03``>014=300@30/030P7010<2`0A3@`03`/:00d9200B3Pd05A4@00802PH500@040`;00<0000H
51<040`;0P0300004P0B3Pd03`/:010<2`0=2@P02`L600`81`0>2PX04@d>018>3`0C3a0040`=00h:
2`0<20T03PX;00l;300>2P/03@T:00l;30H03PX;00H02`L800h:2`0:1PL05A4B00l;300A3@h2014=
30<040`;00D040`=018=4@0<1`/03@P<018=4`0200X52`0D00/62P0M61`04`hB010;3`0910P040/?
01D@500Q72007aXN00h93@0=20`04PdA010;3`0<1`/04@`@01dH700N6Ad02PD901D@500B3A42014<
4003010;3`0=20`03`/<00D03`/<00H03PX;00l;300>2P/03@T:00h:300@2`l300d;3P<030X=00P0
4a4D01HD5`0K6A`030X=00X82`0A3a803PX;00h:30803PT=0P0>2@l02@0I51X04PdD00H1200=20l0
7QPR00`73P0>2@l04PdC00l:400201@?5@0400/6300?2Q003PT?00d83P803PT?01003`X@014;3`0E
3a<05@lC014<400<2Pl02`T>00h=4`0I6Ql0VibQ02`]=@082a8092@/00h:4@0>2A003PT?0P0=20l0
6@0@2a801@0601D@5`070PT04`hD00X5300F3aH04`TA0188400A2A0040T@00l83`0@2Q006QDK00`:
3`0S8BH0JVQ]02<Q9P0;20d04PdC01<>500B3A<040/A018=4`0A31801@0>2@l00`0<1`d05A0F00h9
3`02014<4P0500@01@0>2@l04@`B018=4`0?2Q000P0>2@l600l93@803PP<00@03@L;01D?4`0K5AT0
4`dA0P0;1PX200`72`803@P<00P02`H:00d8300?2Ph03@P<00`72`0?2Ph040`=00d92P8040`=00/0
1P8303/g>01SGf00:RHW014=3P0J5QL04@d>01DA4P0:1PL05Q8C01<?400300`82@0600l;300>2P/0
4@d>014=3P0>2P/03`/<1P0=30X03P0@3`d051<A00<200030P00?C`j01LF500E4A005Q8A01PD4`0C
3`h0C4Q702HR8@0A3@`040`;100?2`X2010;2007014<2@0A3@X04@d<014=300D4a4040h?00D51@02
00/;2`0>00d=2`0<30<03Ph404i>AP28R8007A`G00T8100A40h05Q@E01DC500@3Q403`d@018@4`0>
30l200l=400<00/9300?3A00>cTl05QFF@030@@04a4D00T72P0>30l01@<600h<300?3P`040l=0P0A
40h00`0@3`d03`h<00l>300300l>300n018?3`0@30d030X;01<A4P0610D04A4A00`<300@41004Q@C
01HH5`0B51<04ADD01LI6@092@T071`L03dm?@0O7al04a<C01PH600F5QH051@D01<C4`0>3Ph0410@
01DE600B4AL04A8G01<E6P0>4aL05ahQ00hF6@0;4aH04aLK01LH7@0@4AH04Q4H01`L9P082QH07B0X
01XM8P0L7b@03a<F01DI700G6ah06A`Q01`O9P0N8BX051HS01LF:00Q7c@05QDX014@8P0Q83009bHc
01`L9P0F5Qh0414G014B5P0C51P0414C01PI7P0L7B8201<D6@0Q014B5`0E5Q/051DJ01TJ7`0K7240
6Q/P01hO900T9BX06AHO01TF8@0G5b405QHP01<G800B5Ql041@M018E7P0F6B806aTT01TF8@0C4QX0
8B8W018D600J6al09BHZ01XJ7P0I61d06aXO01PF6`0M6b0071XO01PD6P0P6al08R0Q00805A<D00/0
5Q@E01DC500M6a`071XK03lm?P0P7Ql06QPI00d;300C4A805QDC01TH5P0201`K6@0301DD4P0A40h0
61LE008051<A01005A@B01@C4@0C4Q008alP01`H6@0I5AH040`=014=3P0E4A804`l@014=3P0B3Pl0
510A01<?400B3Pl050hB0P0C3A40100B31004@/?014;3`0A2`l2018<40804`dA0180CDQ<0490@`0M
6ah05A<F01/I700>2@d04P`@01D?4`0B31004@X>01<:3`0F3A80:20V01`E700>1`h040T@018;4P0D
3A@2014:4@0500h73P0A2Q406Q<J01L@5`0B2a400P0>20`0100B31003PP<00h52P0A1``201873@80
4`P>00@050L>01<83`0C21005@XB0P0D2A400`0G31@040D=01053@0301053@0G01053P0D2QD0610M
01L?700<11405PhK01L?700800d05@dJ00X44@090a4030HD00l:600B3B@030PS00h:8`0C3RD06QD/
00l97P0=1QP040LH00l44`0=0`h00P0@1Pl200L01@0F00d22P0800D04`P?01T>5007008050T>00T0
0P0700005``@00L00P0@0``03P4:01@7400H2a@04@@=00/01`0<00P03`<;01443@0W6R<070lH00l2
2aCooooo000Kooooo`0401@C4@0?3P`04A0>018A3`803`h<01802@P701@C4@0A40h02`X800d<2P0?
3P`040l=00`;2@0I61H09RDS02LV902>SH/061LE01@C4@0>3@/030/900h=2`0?3P`2018>3@0@010<
2`0?2`X04Ph=01@@3`0?2`X05Q8A00P40`0D40l061@C00h:2@0A3@`06aLF00X61@0C3`h0510?01LC
4PH040`;00L04@/;00l;2P0@30/04Ph=00l>300=30X03Pd;00<03@d;01T04A4?01@C4@0?3P`010<1
014@3P0G5Q@030/900h=2`0=30X03Pd;014@3P0D4a404a8@014?3@0C3`h0510?018>3@0D40l040`;
00d9200B3Pd04`l>01@@3`0B3Pd04@d<00<040`;00@04@d<018>3@0B3Pd04Ph=1@0A3@`05`0B3Pd0
4`l>010<2`0B3Pd05a<B018>3@0E4A004`l>00l;2P0=2@P04@d<01`H5`0J6AL081lM00h=2`0C4Q00
3Pd;00X91`0H5aD02@P600h=2`0A40h0?C`j00L03@`:00H04A0>010?3@0?3P`03Pd;00l>300A40h6
00h=2`0:00P71P0?3P`0;bh/06QWI@0B4@l04a8@00l=3P0>30d03@/<00`:2`<03@/<0`0>30d03`0=
2``030/9014<2@0@30P03P/700h:1`0>30T03Pd:00h=2`0;2`X03@d=014A4@0B4Q<03Ph?00D31P02
018@4`0601LE601HEUT03@/>00l=400>30l02`T<0P0>30l02@0:20/03P`=00`:2`0<2P/03P`=010>
3`0B414040h?00d;300200`:2`0300d;300>30d03@/<00H03@/<0P0<2P/0100=2``03P`=00l=3P0<
2Pd200d;3P<03P`?0P0@3Q401`0<2Pd03`d@00l=400=2P/03PX900l;2P0A3@`00`0@30/0300;1`H0
4@d<02<O7P0L61L04Ph=00d:2@0@30/04`l>00d:2@091@@06QHE00l;2P804Ph=00@040`;00d9200=
2@P040`<0P0A3@h01@0@30d03PX;00d92P0<20T03@T:00803`/<00<03PX;010<3@0?2``01@0?2``0
1`0>2P/040`=01@@4@0U8B805A4B010<3@0?2`X00P0?2`T00`0>2PT03@T800d92P0200l:3@0;018=
4@080`P03@P=014<4@0A310030L;00/62P0G4QH03PT=00l:3P0=20`00P0D3a<00`0<1`/03@P<010;
3`02010;3`07014<400J5AT06aHJ00h93@0A31003`X>00h93@02010;3`0300h93@0?2`d03`/=00H0
3`/<0`0?2`/01@0?2``040hA00l=400>30l03@/>00803`d@00X02PP;01@B5@0610L0518E03Tg>P0:
20/03`/=00l;3P0?2Ph03`X?0P0?2Q003`0@2a40>3<j03dh?`0:10d050hH00/63@0C3Q@03`X@00d8
3P0R7B<07aXP00X52`0?2Q003PT?00d83P0200h93`0I00l:400B2`l04P`@014;3`0?2Ph03`dB014?
500<3180=SLl07QkP01_LgT06QlU00H93P0>2Ph040/@010<3P0@2`l03`X?010<3`0?2`d03PT>00h9
3@0H51H01@4501093`020188400@0149400@2A0040T@00l9400:1@/01@<800d;400E4aP01@@8014>
4`0@2a404@`B010;4@0>2@l03`X@010;4@D03PT?00`03@P>010;4@0:1@/03@P>018=4`0<1`d03PT?
010;4@0C3Q@03`X@00`73@0>2@l600l93@0601@>4P0F41@05@lC014;3`0C3A403`T=0P0=20`200h9
3@@03`X>01D03PT=00`72`0<1`/040/?01@@4@0B3Pl03@T:01HB4`0A3@h05a<D020L7@0?2``040`=
00`82@0=2@X040`=01DA4P0;20P04@d>01TE5P0F4Q<01`0?2``600l>300B00/:200C4Q0020L501DD
4P13@T00:bXX00d9200<20L05A4@00d92@0M6AP0>3@c01@@3`0A3@`03`/:00h:2@0@30/040`90P0@
30P05@0A3@T04@d:010>2`0@3P/02PT701LG5`071`L04A4B010@4@0<30X04A4801dM4P1lO740a/Jn
03<b;@0@3`X03`h;014?400@3Pl03P`?00l=4003010>4@0>00X82`0;2@`04a4D03Tg>P1CDE@03`d@
01@B5@0>30l03`d@018@4@0?3@d04A0>018A3`0A40h2010?3@1Y014@3P0@3`d03`h<010?3@0A40h0
4Q0?01DA4P0@3Pl05A<D018@4@0<30`04Q8B010@400B51<06A/J01@F5@0@51<05QPH00h>3P0A4A40
8b<S01DE5@0?3`l051@D01<C4`0E5AD06ATI01DE5@0C4a<04a<G01HE700@4AL05QXO00H;400C6Ah0
3ADI00`C600B5a`05APN01<C6P0B4QT03`lK01DG8`0O8R/0FEaS038e>P0G6Ql04aLK018E6@0D5ah0
6ahW01dP:@0J72P06APW01hM;@0G5RD071/Y02TY=@0H62806a/S01/L8@0I6Ql05QLK01DF6@0H6A/0
51DJ01LH7@0F5a`07AhT01PH7`0G5ah04Q<I01/K8P0L72<061PO01LG7`0K6b@06aPS01XG8P0H6280
5aLQ01DH8@0C5b006AdV01LJ8`0F6B806QPS01XG8P0F5Ad04Q<H01@F6P0B4aL0C4eA028R9`0G5Q/0
51<H01DD6@0J61d061HK01DB5`0I51P061HI01LE5P0I5aP061HG00804@l@00<05Q@E014?400A3a00
0P0D4Q<0200H5QL05A@B01LF500H5aD05aHD01<B400A40h06QTG0P0C4Q00100G5Q@051<A010?3@0J
5QL201HB4`804`l@00@06ADF01<?400D4140510A0`0E4A801`0E3a<050hB01@>4P0C3A404P`@014;
3`0C3A400P0B310201@>4P0J02<N8P0B41<0518E01<A500D4QD040/?01D@500C3A404P`@01<;400C
2Pl050/@01<;4@0=1Pd05@hE01@=500;10/040T@014:4@0F3aH050dD014:4@0H4AP050dD00`5300>
20d2014:4@0:00l83P0H3QL06a0H01873P0C1a0050L?01@63P0D1Q004PH?01463P804PL?0P0C2105
01463P0Q01463`0@1Q40Bd=@01dF8P0@21D030@A00d64@0;1@l03`LC01<:5@0700X05`hH01<85P0B
21d05@`S01@;800D2al05`hQ01886`0=0a@040HE00l44P0=0Pl040HB01054@0B21006`lI00h52`0D
2A404`T?00/01P0F3A40308600804@L:00h03@<601<8300B1@/040@:00h11`0C1Ph05PT@00d21P0:
00D04PH<00h21`0W6R805`/A01@83ACooooo000Kooooo`0801DD4P0B4@l04a8@018A3`0>3@/04A0>
01<B400=30X2018A3`8030/901`04A0>00l>300510802`X800P71@0T8b404a8@010?3@0<2`T03@`:
010?3@0B4@l04@d<00`81`0?2`X040`;00l;2P0@30/04@d<00l;2P0;1`H03@T8014=300E4A00510?
01XF5@0>2PT0510?0P0>2PT6010<2`0801<=3@0?2`X03`/:014=300=30X030/900l>300>3P`200d=
2`08010@3P0X9bD06APF01hM6`0W9R@04a8@01LF500?3P`200d<2P0;018A3`0C4Q003Pd;00d:2@0A
3@`04`l>01DA400D40l04Ph=014=300@30/00P0?2`X01P0B3Pd05A4@01@@3`0@30/04@d<018>3@80
4`l>0P0B3Pd01P0E4A0061@C01HB4@0D40l04@d<018>3@8040`;01@04`l>010<2`0>2PT040`;018>
3@0A3@`040`;018>3@081`D03`h<00h=2`0@3`d03@`:014@3P0@3`d03@`:01@C4@0;2PP07ahL00/:
20H03Pd;00H040l=00l>300?3P`03Pd;00l>300@3`d600h=2`0>00P71@0@3`d051<A00@30@0B4@l0
0P4000`:2`0?3@h03@/<00`:2`0;2@X01P@500/92P0<2P/200d;300;00`:2`0;2PP04@`9010<1`0>
2`H03PX700h<200>3@T03@`:00`<2`0@41000P0D51@02@0>3Ph02PP;00/9300D4QD00P03038`<`07
1@P03P`?00l=400400h<3`0300h<3@0=2``030X;00<02`T:00<03P`=00d;300<2P/0100<2P/01P0;
2@X03P`=00d;300<2P/03`d>00h<3@803@/<00L03P`=00l=3P0@3Pl02`T<00`:3@0=2`h03P`?0080
3`d@020030X=00/930091`X03@/>00T72P0>2`/03PX9014=300G4a804`l>010<2`0<20L03PX901DA
400>2`X01@4000`81`0?2`X04@d<00l;2P0F4Q402`L6014=300C3`h04@d<018>3@0@30/03@T800h:
2@0A3@d040`=00h:2`8030P900H03@T:00h:2`0?2``040`=00l;300>2P/9010<3@0700P41@0@30d0
2`L800h:2P0A3@`04@d:010<2@02010<2`0Q010<3@0;1`P03@T:00T4200B3A406A@H00X62@0?2Ph0
2`H:01D@50060@D04`hB00`72`0@2`l03PT=00/62P0>2@d03`X>00/62P0:1@T03`X>00/62P0:1@T0
3PT=00d8300?2Ph03PT=010;3`0C3Q8050lC01<>4P0?2Ph03`/=00@03`/<00L040`=00l;2`0@30/0
4@d<010<2`0>2PT02PP900802`T<0`0<2Pd01P071@P02`T<00P62@0C4A@0;2X]00X82`<040/?0`0@
2a40200G4QT0DTeD069MI00B31H01`4;01D@5`0;1Pd050lE0P0>2@l01@0C3Q@04@`B00l:400>2@l0
3@P>00803PT?00h03`X@01483@0>20`030H:00d8300C4AH05QDJ00@52P0E61d05a`P01dS:@001`d0
5AXN00l=3P8040`=0P0A3@h06@0<20T0510A00`82@091@H061@E01HB4`0F41<04@L?0188400A2A00
40T@014:4@0A2a406A@J01@B5`040`L01`D:00l=4P0A3A<040/A014<4P0@2a403PT?00l:400@2a40
1@0>2@l0300?2Q0030L=010;4@0B3A<01P4700`73@0C3Q@03`X@010;4@0>2@l03@P>00h93`H03`T=
00<03PP<01D?4`0F41@00P0=1`/00`0B31003`X>00l:3P03010;3`0K014<400C3Q8040/?00`72`0?
2Ph04@`@00l:3P0810D05A4B00h:2`0<20T03PX;00l;300B3Pl04@d>01<?400@30d07QXK00`82@0;
1`P04@d>018>3`0<20T020@5014=3P0?2``04@d>00803@T:00<04@d>00l;300=30X01@0=30X03P0<
2`T04A0>00h=2`0F5A<04a8@01LF500E4A0061@C00P40`0B3Pd03`/:01dI600B3Pd04@d<0`0@30/0
1@0A3@X03``700l<1`0@3@P04@d:00803`h:00d040l=010@400000004Q8D06EVJ01VJ6D07AdC0082
000M7A40<C4W00L7000C4Pd03Pd900802`T:01003P`?010>4@0@3Q403P`?01LE600<2Pd04Q0C00<1
10081PT01P@701@B5@0?3A006ALJ00d;3P0K6AX040l=0`0A40h05@0@3`d04A0>014@3P0@3`d03`h<
010?3@0A40h05Q<C01LC500C4A802`T:01PF5`0820P03`l?010@400A4a8061XI01DG5P0?4a804Q@D
01`L700201@D500f01XJ6P0A4A404Q8B00l?3`0C4a<071`L01TI6@0E5AD05QHJ01TI8@0=41L04ADL
02DZ<01>EE/05ahT014H7P0?51X04aHM01@G7P0A4AX06Q`X00T;600b=3l0j>_b09>FW@0L7b@082<X
01TL8@0E61l06A`U01TK9`0J72T06a/W034a>`0K6bH05ADO01<C6`0H6Al061TN01XK800K72005aPJ
01HG6@0J6ah05AHK01PI7P0N7b@0;2`d028R:P0K6b<05aLO01`L900L72H061PR0P0D51h0:`0K62<0
6QPS01PH8P0G5b405APQ01@H8@0R9Rl06QdV018E7P0E4ah061HQ01TH800M7R<05aXM01/L800J6al0
410D00`;400C4QL05aDJ01TG700G5AX05Q<H01PC6@0E4aH05A<D01@B4`0E4a@06QPI024O800h=SL0
928S01/I6P0E4a@04a4B014?400G5Q@05QDC01@C4@0C4Q005A@B01PG5@0I61H00P0B4@l00`0G5Q@0
5A@B014@3P0201DA4P0:018>3`0H51D05Q8C018>3`0C3a005A4B01HB4`0E4A805a<D01PD5@L05@lC
0P0C3A405@0D3Q805Q0D06AOH`1IEeX08R0S01<A500K6A`03`X>00h93@0A2`l04P`@01@<4@0C2Pl0
4@P=01<;4@0<1@`03PL>018;4P0E3QD05PlF00l83`03018;4P0<01D>5@0C31<03PP?00h9400@2A40
30D=00L0200D2Q<06PlH0186400C1Q0050D@0P0D10l01P0E1Q004`P@01<8400D2A405@XB01@94@D0
4PL?03404PL@00H01`0=1A802`<@00D02P0N5R<0:20[01L?6P0<1@d040P?00X0200B1Q003P8=0103
500E2Q/05``L01<86@0;01006@hM00h34@0A1Q@03`@B00d2400A1Q@04@HE02/O:`0700D050XA01X?
5`1ZGfH06@hD02HK8@1MDUL050T=00L0000H3A401`0000`0100B1PX04@D900l31`0=0@D02@0100P0
000A1@T02@0101862P0;0@<040@801Cooooo000Kooooo`06014@3P0B4@l051<A010?3@0<2`T04Q4?
0P0=30X0800>3@/040l=00l>300;2PP03@`:018A3`0<2`T03`h<01LF500D4a404A0>00h=2`0<2`T0
3@`:010?3@0A40h040`;00h:2@0F4Q406QHE00l;2P0;1`H04@d<010<2`0O6aX04`l>00X61@0F4Q40
30P701/G5P0>2PT04@d<0P0?2`X6010<2`0I01HA3P0@30T03PX700l;200<2`L02`X6010?2`0>3`X0
3@h900`=200?40/0GUiJ065PGP030P004Q4?03`k>@0M71X04A0>00d<2P0<2`T040l=01<B400?3P`0
3P/:010<2`02014=300E00d9200<20L03PX900l;2P0>2PT03`/:018>3@0D40l04`l>010<2`0A3@`0
4Ph=01<?3P0D40l04Ph=014=300C3`h05A4@01@@3`0C3`h040`;00804Ph=00`03`/:014=300A3@`0
3`/:014=300D40l04@d<00l;2P0=2@P04A0>00h=2`0C4Q0200`;2@0700h=2`081`D02@P6010?3@0?
3P`030/9014@3P0800h=2`<03`h<1`0>3@/03P0J6AL02@P601LF50081`D030/901<B400<2P/040h?
00/92P0:20T03P`=00X82@0<2P/03@/<0P0>30d0200=2``030/9014<2@0@30L03P/600h:1`0>30P0
3Pd90P0=30X02`0=3@/03`l?014A4@0@4100:bT/00P62@0<2Pd09R@W00`:3@0J61/030X=00803`d@
00<030X=00d;3P0@3Q400`0=2``00`0<2P/02PP900T7200400d;300800/92P0:20T030X;00X82@0?
3@h03P`=00`:2`0@3Pl200d;300800h<3@0?3@h03`d>00l=3P0;2@`030X=00d;3P0>30l300l=4009
00`:3@0:20/03@/>00L5200?30`03@T600h:1`0C3``03`/800803PX700@04Ph;01LC400=2@H03`/8
0P0D40d0300:1P<03@T601LC400B3P/03@T600l;200>2PL03`/800h:1`0<20D03@T6010<30803`/<
0P0>2P/01`0?2``040`=014=3P0B3Pl040`=00l;300A3@h01P0@30d01`0=2@X05Q8C018>3`0B3Pl0
4`l@00h:2P0?2`X00P0@30T2010<2`0Q014=300>2P/04Ph?00`82@0C3Q8030L;01hI7@0c;S800`02
00l:3P0<1`/06QDI01@?4`0B3A403`X>00d8300@2`l03`X>00`72`0;1PX040/?00h93@0=20`04@`@
00l:3P0A31003`X>010;3`0B3A404`hB018=4@0?2Ph03`/=00@03`/<018040`;00l;2P0@30/04Ph=
014=2`0=2@P020H700X82`0<2Pd03@/>00`:3@0;2@`04a4D00`:3@0Q7b804Q0C00@21@0E4aH300l:
3P<03`X@00/030L>00l94`0M5b402@@=00<01`0P6b804`hE018=4`0=20h02PD;00`73@0200l:400H
00h93`0=20h03PT?00h93`0?2Q004`X?014;3`0@2Ph04@`@01DC600G5Q/04Q<H00001@011PX04aTO
00XA5`000@D03P`<00h:2@0=2@P03`/:014=300?2`X04`l>0P0;1`H00`0D40l07ATH01XD5`020147
3`0@0149400A2Q404@XA00X52`0=20h03`dB00h<4@0C4AH05A<H00T52`0@2a804@`C010;4P0>2A00
3`XA010;4PD03PT@00D03@P?00/6300B3A<04`hD00d83P0201@?5@0300h93`0=20h03PT?00803`X@
1P0?2@d01P0<1PX04P`@018<400=1`/040X>01<=4@803PT=0P0?2Ph2010;3`0401<>4P0A310040/?
018=4@804`hB00L02PH701<?400>2P/03PX;00`82@0D41404@d>00802`L800<020@5018>3`0810D0
0`0@30d01@0D41405a<D018>3`0>2P/04@d>008030P900<04@d>00h:2`0=30X01@0=30X03@0I61H0
4Q4?00d<2P01000051<A00@30@060P403PX9014=300D40l05Q8A00@0000@30/00P0A3@`2018>3@05
014=2P0?30H03``7010=200A3PT00P0?3PX0800<30X02`/;00X:2P0_<380e]OK0=cNg@0[;20030`0
01<C1`0B4PP04Q8:00h=200A40`0518C01<A4P0?3A003`dB018@5@0B41<040hA00H41`0B41<02PP;
01@B5@0F51L02@L:00h<3`0B41<00@02010>3`0B4@h04A0<0P0@3`/0@00A40`04Q4=018A3@0@3`/0
3`h:010?2`0B4@d05Q<C00`82@0D4Q<03`d>01XH6@0=3@d051@D018B4P0A4a806A/J01LI600A5A@0
418B018B4P0=3@d03`l?01@D500>3Ph03`l?00h>3P0?3`l05QHF01DE5@0B4Q805aLK01/K8`0>4AP0
4QHM055FG02FWZ@0624V01DL8P0B5ad051LN01DH7`0D51d03@lK018F8P0T:380JVme03]0AP0W;300
82DY01LL800E6R0061`U01HJ9@0H6bL09bLa04I6CP0T92d08b<[01<D6@0M7R<05QLL01LH700H6Ad2
01HG6@0;01PI700K72406a/S020P:00];CD08R8Z01/K9@0L72H06QXT01LG8`0E5B400P0F5R8201TF
8@0I01LG8@0F5R004aLP018F7`0O8b`05a/T010C700C4A`061DP01TH800@4AH06A/P01@E6P0G61d0
51@J02TX;P0D4aT061HL01PE700F4aX061@K01TD6P0M6ah071XK01DC5002010>3`0>01<A4P0J61T0
6ALH014?400E4a@06ALH01HD5@0F5A805QDA01DD400C4Ph05QDA01TH500G5Q8201<B3P0@01HE4@0E
51004a8@01PD5@0M6AX04@d>01TE5P0K5aP0510A01<?400G4a@05Q8C01DA4P0G4a@06QHG01<=4@80
50hB0P0F41@0400G4AD05Q0D01<=4@0B310050hB01H@500L5a/02@L:01DC5P0C4A@02@L:00/62P0G
4QH04`dA018<400C2a0201<:3`0701<;4@0<1@`03`P?018;4P0G41L06Q<J018;4P0200l83`0501@=
500A2Q404@XA014;4P0;1@l00P0;0`h03P090@`03P@?01<84`0B1Q804`DB01<44@0C0a00508@01D6
400C21004PL?01@94@0E2Q804`P@1@0A1Ph01`0A1Pl060dK00X24@0?2AD01P0<01@>6P0F4AX00P0>
1`l05@0E2Q<05`XC01H94P0=0@X03`<A01H96P0T62L0:1//0186500J3Q`040@B0186500@1AD03P<C
01875`0B1aP01`0701hB700E2Q801`04028G7P0200L00P0=01H;400;00@02P0300P00@0L4AD02`01
00l31@0C1`T04PH801041P0D20X040@601451`0200h2100300d10`0?0`Gooooo01?ooooo000Koooo
o`0D014?2@0B40/04a0>010>300?30/04Q0?010<3`0D4A003``;00d;200B40X040h900h<2@0=2PP0
4Q0=00d:200>30T03P/901<A3P0@3@/2014>300=00d:200>2`T04@d<00h:2@0J5QD06ADD01LC4P0:
1PD040`;01DA400U8B006ADD00/71`02018>3@0501<?3P0?2`X03`/:014=300J5QD0100A3@`2010<
2`0901<?3P0C40h03@X800d:200C4Pl03@`9010?300<30T03Ph:00803@d900<061@B01PB4@0E3`h0
0P0C3@/01@0C3`d040`:00l;2@0>2PP04@h<00805A<@00D04@h;00h:200@30X04Ph<010<2P03014=
2`0;018>300@30X03`/9014=2`0A3P`02PL600d;200C40h03``:010=2`0?3@X00P0>30T200l<2P07
00l=2P0@3@`05A8B018?3`0C41003``<01HC4`02014>3P0;010=3@0>2`/03``<018?3`0B4@l02`X8
00h=2`0?3P`07QdK01HE4`0@3`d00P0=30X07`0D4a402`X800h>300E5Q<02``8010@300<30T051@A
00d<2P0>30T03`d:014>300A3@/040`:010;2@0B40h03`h<010?3@0C4Q0040l=00d<2P0K6QP0:BPV
00d<2P0F5A<03@`;00X91`0<2PX03P`<00/92@0<2PX00P0@3`h02`0A3`l03@/;00`;2P0>3@`03`d=
00/:200?3@X03`d;00`91`0=2PP03P`;00803@`;00l030X:00X9200<2``04A0@00l>3P0;2@/03`d?
014?4@0H5QP03@/=00L51`0<2P`03`d?010>400=2`d00P0<2P`00`0?3@h02PP900h<3@03014?4005
00d;300:20T03@/<00h<3@091`P00P0=2``01@0<2P/03P`=00h<3@0=2``03`d>00802`T:00@030X;
00d;300=2``030X;0`0<2P`0=P0=2`d03P`>00h<3P0I5aT0518D01<A4`0K6A/01P@601lM7@0>2`T0
2@L4010=2`081P<040h;00l<2P0>30T03``:01DB400P7A/061HC00/81`0>2PT05a<A00/71@0@30X0
3`/900`81P0:1P@03PX800`91`0:1P@04`l=00`:2P0920P03Pd>01PE5P0:1`L07APJ018:3@0F3a40
:20S024L7P0D3a0061@E01<?400D414030P9010<3@0B3Pl04@d>00`82@0B3Pl03@T:00T51P803PX;
01804Pl?00T6100Q7Qh02`P801@A4@0@3@d02@H701LD5@0f<c@04PhA00T6200i=SP0OGUk02DQ8`0>
2@`04@`?00/62@0:1PP200d92`0:01<?4@0J5AP06ADG01@@4P0>2`h030P<01DB5@0=2Pd03``?00h:
3P<03P/>00H03``?010<400?2`l04PdB014<4@0?2Pl300h93P0O018>4@0@2`l0510C01LC5P0X8bH0
2PH900/72`0?2`l04PhB01<?4`0@3A003PX>00h;3P0>2Ph03@X=00l<3`0D41@01P<600P52@0B3Q<0
2PH;00h;40091P/03``A014=4`091@/030T?014=500F4QX0<blf01dH7P02010;4@0:01<>500>2@h0
2`H;014<4@0>2@h03`X=010<3`0A31404`hB00l93@<03PT=00/03``@010>4P0:2Pd030`A010A5P0>
3a@01PL;010A500@30d04@T;00h92P0201092P0U010:2`0>2@X03`L901092`0>2@T05@h?014;3P0?
2@l040P>00h83P0?2@l040X@01D?500:1@X030P=01<?50091@X04`lD00h:3`0@2a003@P>010;4@0;
1P/04@`C010;400?2Pl03`XA00l:400>2@h03@P>00/6300C3Q@03`X@00`83@0A318030L=00h93`02
00d83P0:00l:400@2a4040/A010;3`0@2Ph03`T=00h8300>2@d03`X>010:3P804@`@00D040X>014;
3`0@2Ph040`>00h9300200l:3@0>00d82`0=2@/03PT<00l:3@0>2P`04`hA01LB5@0@30h04Ph?00h:
2`0?2``05a<D00h:2`0=2@X2014=3P0<01LC500>2P/03@T:01DA4P0<20T040`=00/7200@30d0510A
00`82@0?2``04@d>0P0=2@X0100A3@h03PX;010>300@3P`2010=30803`d;00h05a@C00d:2@0I5aD0
30X900h;2P0?3@/0510?00h:2@0G4a802`L6014=300<20L03`/:014=30804`l>06X04Ph=00l;2@0>
30T04@l<01@B3`0>2`T03Pd:00h=300?3Ph040l@014@400E51H0JfY/06IUIP0D4`d04A0901DE3P0;
2PH05A@A00h=2@0B4@l06QPI01PF600D4QD04@lD00l=4@0A3a004a8A00P61P0A3`l040l>00d;2`0@
3`h06ALG014@3`0?3Pd05A@C010?3P0A40l040l>010>3P0A3`l04A0?01<A4@0B410040l>00l>3@0A
3`l04a4A01DC50061@D03`h>01@C4`0?3Ph020P801HF5P0D51@04A8A01HG5`0G61L051DE01@F4`0D
5A403Pl;01TJ5P0M7Q/04a@B01<D4`0D5A@04a@B01HG5@0F5aH05AHF01@F5`0F6Ad05APL01/O8`1;
D580Jg9e018I700B61d04aLN018D7`0A51l0414O02ha@P0X;3d07B8_01LK9@0N8R/04aPN01LK800B
5Q/06QhW028S;`0G6RL05QLV01@G8`0V:S@05QTS028V;P0G6b405aTN01DH6`0E5a/05aPL0P0J6b00
1`0G5ah05QLP01HH800G6B407QlW01XL8`0H6B000P0K72D0300G62<03@lI02d^>@0L72L05QDO01TI
7`0F5ad04Q8K01DF7`0G6b<06a`V01`N:080:2Pc00L05aHS01TH900G5Qh04Q8G01XJ800F5Q/06QXP
008051<I01<05aHL01TG7@0E4aX061HM01<A5P0D4QD05aDG01PF600F51D05A@D01<B4@0E51<07A`I
01HE4P0G5Q<05QDB018A3P0B40`061<@00805Q<@00D06ADB01TG4`0G51405a8?01DC3`0201PD4@0Y
01LC400E4A805A8C01<@4@0L6AX05a@F01<@4P0A3Q004a0B01TF600F4QL05a@H01TF6P0B3Q804@/?
014>4@0F4QD05A0D014=4@0C3Q8050hB010<400B3Q805A0D01HA5@0A3A405@lC010<400J51P05@lC
01<=4@0D3Q804P`@018;400D31405@hB01<<4@0E3a@07QPM01XC6@0A2a000P0C3180B00B2a404@/@
01@=4`0?2@h040X?01@>5@0=1`h030@>01@=5@0@2A4040LA01<;500>0``04`PC01874@0O4a`09QTT
01@94P0C1a0040D?01863`0C21404PL@00d32P0C21003`D;01463@0C20l04@D=01053`0D2aH03PD?
01074@0<0`d03`H?00d4300D2Q8040H=02lS;00`92`05PXC01@95@0<11408AHT02TM:`0E2QP04PLB
01454P0G2aP04@DB00`23@0>10l04`HC01H:4`0>0`X03`@;01463@0?10X04PL=00h32@0?1@T02P44
01072P0@1PX040D901472P0=10H03@<500`2100<0PD04PH9014520804@@700<0408601841`0;0040
5?ooool001_ooooo00P04a07018?200B3`X04@d<014=3@0@2`l04PdA018>3P804Ph;0P0B3`P04P0J
5a806QHC00L3000F4Pl04Ph;01dI5P0?2`P030P501DA3P0H51405A4>01HB3`0?2`X04@d<00T5100A
3@`01P8101TE50H04@d<00L03`/:00d9200>2PT04Ph=01@@3`0E4A004`l>00<04Ph=0P0A3@`0300C
4Q002PT701<B400J6AL01`H400/:200@3`d02`X800l>300@3`d03Pd;01@>30@05@/:00<050`:01<;
2@0B2PP00P0@2`P200h:1`804Ph;0P0@30T00`0A3@X040`900l;2002010<2@0:00l;200>2PL040`9
01dK5`0C4Ph030/7010?2`0<2`L04A0<010?2`D03Pd900H03@/:010>3`0A3a002`T:081nO`1ZJ6T5
00h<3@0700l=3P0:2@L02`X800l>300B4@l08R4O01LF500300h=2`0f00`;2@0;2PP02@T700010009
3PP0>C/f01PI500@4@`05aHB010<2@0A3@X04`h;010;200?2PL04P/9014=300<2`T040l=01HE4`0B
4@l040l=00X91`0M71X01`H401XI5`0>3@/040l=00`;2@0;2PP030/900d<2P0@3`d04A0>00d<2P0A
40h040l=00d<2P0>3@/04a8@01DC500X9RL07Q`M00h<3@040P<02@L800h<3@0<2P/020H700`:2`0?
3@h01P@500X82@0<2P/03@/<0P0>30d01P0=2``03`d>00l=3P0A3a004Q0A00h<3@8030X;00X071XK
03<a<P020@402`T:00l=3P0;2@X040h?004000091`P02`T:1`0=2``01`0>30d04@l@01<A4P0:20T0
81hO03hl?@0>30d00`0<2P/300d;300D01TG600G5AH0Cde>01hL7@0D4a803@`:0040000:2@L020L5
00`;2@0@3`d02`X800X91`0@3`d04a8@00l>300<2@P03PX9010<2`0C3`h2018>3@0H01HB4@0C3`h0
1000018>3@0F4Q409b<R00`;2P0K7A`01PH600L51P0810D0NG1c038X;00B1`/08QTL01L?4P080P@0
510A00<0000@30d05A4B00X61`0C3a001P<30`0?2``300h:2`0B00L51P0=2``0N7Ig00h<3@081PL0
4@l@01@B4`050`@08R0Q00l=3P0I5aP030X;01hJ6`0;1`P01`@401<?400@30d05A4B0P0?2``02`0D
41406QHG01PD5@0>2P/02@L:01LE600H5QT01`D800X82`0?3A003@/>00<03P`?0P0?3A00100@2a40
40/B00h9400>2A0200l:4@0800`73P0:1@`05A0G018=500R7B@040/A00`72`0>2@d2010;3`0300h9
3@0<1`/03`X>00803PT=00L03`X>00h93@0;1PX04@lD00P62`091``03P`A00803@/@00l030X?00X8
3@0:20d030X?010>4`0B41D05Q4H010;4@0<1`d03@P>014<400C3Q804@`@00`82@0?2``00P0A3@h0
1P0C3a003`X>00d8300<1`/03@P<00l:3P8040/?00D03`X>00h93@0?2Ph03`X>010;3`0301<:3@05
0189300@1`X05@`?01482`0<0`H00P0F3A000`0C2Pd04`d@00l:3P0300h93@803`X>00d02PD901dH
700/9b/06A@H010;3`0910P04@`@00L21P0@2`l030L;00T4200A31003`X>008040/?00`03@P<00`7
2`0B3A804`hD00H11`0@31402@@:00H11`0C3Q@030L=00h93`0?2Q02010;4@03010;3`0?2Ph03PT=
00803@P<0P0>2@d00`0@2`l04PdA010;3`0200h93@0>014=3P0>2P/040`=018>3`0?2``04@d>01HB
4`0A3@h03PX;01LC500O6a`05a<D010<3@0<20T200h:2`0300H20`0A3@h04@d>00804Ph?0`0?2``0
1P0M6AX02@D601XF5`0A3@h040`=00d92PH03`/<0P0@30/200l;2P0800h:2@0=2@P00`0002/W9P1I
EE@0920O01@@3`0A3@`200l;2P05010<2`0A3@`04Ph=018>3@0@30/00`0B3Pd09`0@30/03PX900<1
0P0610D03`d>00h<3@0E4a@04a4B010>3`0?3@h030X;00/92P0>30d04A0>014@3@0>3@/04A0>010?
3@0?3@h04Q0A00`:2`0>30l071XM03@b=@0W9BX040hA00l>2`0H5a<02`X601hM6@0R8Ad010<000l>
2P0=30P02`X600d<200B4@d051<A00l=3`02010>4@@04@lB00L040hA014?4P0A3a804Q0C01@C500B
4Q804A4A00@04Q8B0P0?3`l0100F5QH06ATI01@D500@4@h201DH4@0:01HH4P0?4@`030h901DG4`0D
5Q<05ALD01DG5@0E5aH05QPG01@G5`805ATJ05L041@D01@H5`0L82404aLJ01<F6`0D5R004aDR01DG
9P0L7S00^;[?09jS]`0P9CL020/J028V<@0>4Q/04aHM01@G7P0S8bd08b<_01TH9P0H62P041<R014G
9@0E72L05a/V01DJ800F6b005ATL01<G6P0F5a`06a/S01`L900F5R008R@`02<U<@0M82T05QTP01LJ
8@0D5a`05aXO01@G7@0I72<020/D02HY<`0>4AX030dB01TJ7P0@4AH08B8W00`=4`0X:3007AdW07Mg
PP0`<3`0FeYX01`K:P0H62@06aXR01LF700D4aT05A@J01PG7@0G5Q`051<I018A5`0I61h06QTO02<R
:00F5AX0928U01TG6P0C4A@05Q@E01HE500B4@l05A@@01HE4@0F5A0051@<014A2@0@3`X0510=01/F
4`0M61D06aHC01TD4@0H4a000`0G4Pl201PC400I01LC4P0D4Q<06aTJ01TG600A3a002@L:01@B5@0E
4aH05Q@I00L52P0F51T04PlF00l=4P0H5QX05A<F01LE600@3Q404Q0C020N8@0@3Q404Q0C00l=400A
3a804Q0C018>4@0201D?4`0401@>4P0C3A4050hB01@>4P<04P`@0`0C3A402@0>20`03@L;00d72`09
0`L03@L;014;3`0@2Ph04`dA01@>4P02018<400b01093`0F3aH03`P?0109400_:2l09QlV01094007
00L040T@00d63@0N5ah0:24X01@:500F2QH04@DA0186400C1a404PH@00`12@0B1`l03`@:0146300C
20h050T?01@94@0C21004@H>01053@0C21005``D00T01P0D2A402`4802DJ8P0Q5Qh03P@<01<95021
NHH07AHR01<85P0<0@l040LA01P<600700L03@<;01/>5`0>0@X04PD>00h32@0?10X201052`0900l4
2P0>0`T02`0600T0100I3Q@05@X@00d4200C2Pl03@@700802`D700T03@@700h41`0>0`L0200001H:
3@0:00008Q4G01@62@0/6b405?ooool001_ooooo00P04Pl6014>1`0A3PT040`;010<300?2``04Ph?
018>3P804Ph;0P0B3`P02P0F4`h08alL00`81@0O6aP03@T701lK600D40d04@d:01DA3P0D40d200l;
2006018>3@0N6QT02PH501HB4@0:1PD040`;1P0A3@`01`0C3`h03PX901<?3P0L61L05a<B010<2`0C
3`h00`0B3Pd2014=300C03Dd<P0100001`H401DD4P0100006APF00l>300<2`T03`h<014@3P0@3`d0
50h=01H<2`0G3@`05Pd<01@<2P0B2PP04@/8014<2@02010;20803PX700D04Ph;010<2@0<20D03PX7
01<?3002018>2`0;01<?300B3P/04`l<01@@3@0C3``081hJ01DD400;2PH030/700d<200A40`01P0>
3@T01P0@3Pd02`T:01`J6`0610D0M79c06i/K@<03`d>0`0>30d01`0920H02PT701@C4@0?3P`04Q4?
00l>300@3`d00P0?3P`05P0>3@/03@`:00d<2P082PD04A<>03do>P0C50l0004000P71@0@30T04@d:
018>2`0@2`P03`X7014<2@0A3@`030/900h=2`0=30X02`X800l>3001000200`;2@0;01HE4`0=30X0
3Pd;00l>300<2`T02@P600P71@0:2@L030/900/:200=30X00P0?3P`09P0@3`d04A0>00T7200C4A80
4Q0A01@B4`0B41403@/<00X82@0;2@X030X;014?400H5QL04a4B00P61`0<2P/03`d>010>3`0>30d0
30X;00h<3@0<2P/03@/<00l=3P0>30d030X;00l=3P10?Sl0Kfe^01hL7@0F51D02`T:00d;300@3Pl0
5Q@E00h<3@071@H02`T:200=2``01@0C4A8020H7028P8@1;BDX03P`=00<03@/<03003P`=00l=3P0=
2``08b4R01DC500=2``00@0000L61P0?3P`04a8@00d<2P0O7Q`030/900P71P0<2`T02PT700h=2`0A
40h03`h<00l=2`0:1PD030P7018>3@070`802PH5014=300J5QD02`L600d9200810<05A4@00P81`05
1`H030`<01<A4@0O6a`0M6]^02hT:00C20`04@P;00X31@070@<03@T:010<3@0E4A8061@E00<0000?
2``2018>3`804@d>01@03`/<00h:2`0>2P/0518C00h<3@0J61T00@0000d;30040P<04@l@00L51P0<
2P/02PP900h<3@0:20T02PH700T51P0<20T03`/<00d92P804Ph?00/040`=00l;300A3@h040`=00X6
1`0;2@`01@@600400P0C4A@05A<F00<1100200l=40<03P`?00@03@/>00d83P0?2Q003`X@0`0@2a40
100H4aT02@D:01@?5@0I51X2018=4`D03PT=00@03@P<00h93@0>2@d03@P<0P0<1`/02`0>2@d06aTN
00D3200E4aP03@/@018@5@0<2Pl02PP=00`:3`0=2a003P`A008030X?00d04@`C00h93`0<1`d03@P>
014<400C3Q803PT=00/7200?2``040`=00h:2`0@30d03PT=00803`X>00H040/?014<400A310040/?
00l:3P0>2@d200l:3P03010;3`0B2@`04PT<00804`X=00D04PT<034X:`0h;c804`X=00/31@0200H0
0003018<3`0?2Ph040/?008040/?00h03`X>014<400<1`/061<G020K7`0C3Q8040/?00d8300B3A40
2`H:018=4@0E41@00`02018=4@<03`X>00T03@P<00`72`0?2Pl03@P>02<N9018@dT08QdS00L2200:
1@/00P0=20h0100>2@l03`X@014<4P0>2@d200l:3P803PT=0P0=20`06P0?2Ph04@`@00h93@0=20`0
3PT=010<3@0>2P/040`=018>3`0?2``04@d>02dY:P0P71d04`l@014=3P0>2P/020@500l;300:1PL0
3`/<014=3P0300004Ph?010<3@0>2P/03@T:0P0@30d02@0=2@X00`00014=3P0A3@h01@4204M3A00G
4a@03@T:00h:2`0200l;3003010<3@0A3@h03PX900803`/:00l03PX900d9200<20L030P701@@3`0U
8B00100000/71P0D40l03`/:010<2`0A3@`04Ph=01<?3P0D40l00`0@30/300l;2P07028P8@0?3@h0
40h?00d;300C4A802`T:00`:2`02010>3`0@00l=3P0>30d03`h<010?300>3@/040l=00l>300>30d0
4Q0A014?400@3Q403P`?014?4P0>31401`D8018@408040l=00D02`X900X91`0B4@l05QDC010?3@02
00h=2`04010?3@0B4@l040h@010>4@@04@lB00<040hA014?4P0B41<00P0B41<01P0A41405ADE01@D
500=3@d051@D01DE5@804A4A00`0410@014A4@0B4Q80410@00h?2`0520403a8;01TK5@0;3@P03Q0;
01DG4`0F61D301DG5P1F01@F5@0D5aL05QXM01TM7P0E6AT04aLF02P/;@0C5aX05APM01@G800C5B80
6Q`[02/]?`0d=dX0BTmR01hS=01DF6@05QXU01HK8P0?4QT051LN01/K9@0G5b<051<Q01PI9`0E62L0
5Q`Z01TO:P0I7BP061dS01PM8P0F6Qd051PK01DF6`0I6B406a/S01PH8P0J72P071hZ01TL9@0E61l0
5QTP01@G700L7b@04QDK01/N9@0C5Ql04aHP00hA6P0Q8RL061TM00/<4@0?41D0=SHm00001`0N7RP0
7alZ024Q;@0L6bT092<a00H64P0K6R805aHK01@C600E51T05QDJ01DD6@0L6b004a8G01DD6@0G5Q/0
81lT010?500/:Rd06aTL014?4P0F51D061LF01<B400G5Q805QDA01DD3`0C4Pd04A49014@2`0G4a42
01TE500301LC4P0F4Q4061@C00805A4@01l05Q8A01LC4P0G4a805a<B01@B4`0F51D02`T:01HD5@0C
4A@0518E01DC5P0R82D030X?01LE6P0=2Q40=C<h01@B5P0@3Q403`d@014?4P0>30l02@L:014?4P0B
41<040hA014?4P0B41<040`?018<400D3Q804`dA00804P`@0P0C3A43018<4009014;3`0C3A403`T=
014;3`0I4aL03`T=010:3P0C3A4040X>008050hB01@04@/?00l93@0A2Q004``C00/42`080`P040T@
01D>5@0H4AP02P<:014:4@0>1`h04@XA01XC6P0B2A805@TE0104400D21805`/E01<74@804@H>01h0
4@H<00h32@0;00H03`@:01873`0A1Ph040D=01463P0C21005``D00X01`0G31@0308901463P0<0@T0
3PD<01@:5@2;Pi008ATV01/A700B21<050XE0186400800H05PXD01853P0<00P03P<:00h32@0?10X2
01052`0:00l42P0>0`T04@H<01P=4`0:00D01`0201D:400H3a@03@@700`51`803@@700P03P@700h3
1`0G2`l0304301H7300;00004`D801D42QCooooo000Kooooo`0>014>1P0A3PP040d8010<2@0?2`X0
3`/;014=3@0A3@`04@d:014>2@0A3PP04@h7010=2`0B3P/201PD4@0301@@3@0F4Pl04@d:00804@d:
00T040`900h:1`0=2@H071TH01DA400F4Q404@d=01HB4@0C3`h01P0@30/01P0B3Pd03`/:01<?3P0I
5A@05A4@010<2`804@d<0P0@30/200l;2P0@04I5@`0@3`h04Q4?00d<2P0<2`X04a8@00d<2P0;2PP0
30/9010?3@0A40h04`d<01H<2`0H3`d05`l=01@<2P8040X70P0A30T2018>2`0301<?300@30T03PX7
00804@d:00l040`9014=2P0C3``04@d:00l;200C3``05A4>01<?300C40d02`X600h=2@0B4@d03Pd9
010?2`0=30P01@0>3@T01P0=30X04a4B018@4@0E4a@04Q0A01TG608040h?00X04@l@010>3`0?3@h0
3@/<010?3@081`D04Q4?00d<2P0;2PP03`h<0P0<2`T07@0=30X03Pd;00l>300B4@l0@D8m010A3P0;
3@P02``701<D3`0=30T03`d9010>2P0B3P/040/800l:1`0@30T03PX900/:200<2`T02PT701<B400U
92806APF00`;2@0C4Q003@`:00`;2@0B4@l03@`:008030/900h03`h<01HE4`0K6QP06QTG00d<2P0>
3@/06QTG01TH5P081`D040h?01HD5@0@3Pl03`d>00h<3@802`T:00T03@/<00`:2`0?3@h0518C010>
3`0A3a0040h?00l=3P0>30d00P0?3@h04P0=2``02PP900X82@0<2P/03P`=00d;300?3@h02@L801DC
50091`P02PP900l=3P0<2P/02`T:00`:2`0=2``04a4B00X82@H03@/<00L040h?00/92P0=2``03@/<
00h<3@0B41403P`=00803@/<03803`d>010>3`0@3Pl0<Bl`020N7`0G5AH02PP900d;300G5AD01PD3
018A3`0J6AL03`h<00P71@0C4Q0040l=00d<2P0>3@/040l=014@3P0A3Pd030P700X61@0=2@P030P7
00l;2P0B3Pd02`L701@@3`0F4Q40>3@c00X61@12@D003@l>01HF5P071@D03`/<014:2`0D2Pd05``@
00d41`0D30l0618D00h:2`0@30d02`L800d92P0e<C803PX;00`82@H03`/<01d03@/<01TG600@3Pl0
2`X:01@B4`0<2P/02PP901HD5@0<2P/03P`=00@30`0C4A803PX;01<?400B3Pl03@T:00h:2`0=2@X0
4@d>00l;300<20T03PX;010<3@0A3@h030X=00d;3P0>30l02@L:01HD5`02010>4@0700l=400>30l0
3P`?00d;3P0<2Pd03@P>00l:4002014<4P0K00l:400=20h0?cY001DA5P0<20d091lU01/F700>2@l0
4PdA014<400@2`l04@`@01@?4`0G4QH03`X>014<400?2Ph030L;00h93@0C3Q803`dB00h<4@0@3Q<0
3@/@00/93P0=2a0030X?00<03@/@00X02`T>00X83@0?2Q404PdC01D@5P0C3Q@03PT=00/62P0?2Ph0
30P90P0A3@h01@0>2P/03`/<00l:3P0@2`l04PdA00<04`hB00<040/?00l:3P0>2@d00P0?2Ph0100@
2`l03`P;0149300B2Pd2018;3@0I01P@4`0Y8B@06A8D01TB500K51H03`L:01D@4`0?2Ph04@`@018=
4@0A31003`X>010;3`080`L030L;00d8300910P040/?018=4@0>2@d04`hB00`72`0F4AD03`X>00h9
3@0300l:3P0:00d8300>2@d04@`A00X52`0?2Q008AdR010;4@0910X03`X@00h93`803@P>00@03PT?
014<4P0=20`03PT=0P0@2`l0200>2@d030L;00d8300>2@d040/?00d8300<1`/03`X>0P0@30d01@0?
2``03PX;00d92P0=2@X05A4B00802PH700`04Ph?00l;300B3Pl04Ph?00/7200A3@h06ADF00T51P0@
30d03`/<010<3@0A3@h200h:2`0800l;300D41404`l@00`82@0E4A80EE5B01<?400<20T200h:2`0G
010<3@0A3@h04Ph?00l;2P0@30/04@d<010<2`0?2`X03@T801@@3`0:1PD04`l>018>3@0C3`h02@D4
00h:2@0?2`X040`;014=300B3Pd04`l>010<2`0?2`X00P0>2PT02@0?2`X040`;02/Y:P0?3@h03@/<
00h<3@0G5AH02`T:00l=3P02018@4@8040h?01X04A0>010?300=30X040l=00l>300>30d04Q0A00l=
3P0=2`h03P`?018@4`0C4AH04a4D00h<300=30X02@P6014@3P0>3@/040l=00h=2`0<2`T04Q4?01<B
400@3`d04A0>010>4@804@lB0P0B41<2014?4P1I018@4`0D4QD0518E018@4`0C4Q<04a<C01LG5`0J
6QX051@D01<C4`0D51@05QHF01LG5`0@41004a<C028R8P0i>SL05aTC00T;1@0C5Q004aD@01PJ5P0E
5a@05QPE01HH5`0E5aH051HE01@F5P0F6A/051PK01<G6@0C5aP041@D02P/;@0D61/05aXO01PK8`0C
5B405aTV02PZ>P0G6RX03Q@S01@J:01=DE`092Pa014F700G6R0061/Q01@E700D51d06a/V01/L:00L
82d06b4_01/R;@0H72L05Q/Q01DJ7`0H71l05QXM01HG700H62006QXR01XJ900C5B4061XV01dP:@0M
82L07b8Y01TL8@0G6Ql05QTO01@G7P0J7BH05QPS01hQ:P0E5A`05AHJ01HG700R8bP0CTmE02d]=@0F
5R009RH`02<S;P0h>4D06a/X01XJ9@0G5Q`00P0D4aP0100E51T05QDJ01DD6@0L6b0201TH7@0E01HE
6P0P7b@06QTN01XH6`0F51H04a4C01@B4`0G5QD05aHD01@C400D4`l04a8>01@C3`0E51005QDA01LC
4P0E4A005Q8A01DA400H51<07a/J00805A4@01<05Q8A01LC4P0G4a8061@C018@4@0P7Ql02`T:01HD
5@0D4QD04@lB01DC5P0M6b0061HK01LE6P0a;SD0_kg209FCU`0C4A@05A<F008040hA00<05aDH018@
4`0B41<00P0C4A@0200B41<04PhB010:3P0?2@d05a4E01dG6`0I4aL050hB0`0C3A40400B310040X>
010:3P0=1`/06Q@H02hX;00G4AD030H:018<400C3A4050hB018<400@2Ph04@/?010:3`0E3QD201<<
4`0401D>5@0@2A004``C00l83`804``C02P030D<014:4@0B2A8040@@00l33`0G2aD06`lI01P<5P0B
1`l03@8:01P=4`0B1`d03`@:01D:400B1`l04@H>00l4300>0`/03`@<01873`0@1@d04`P@00d22P0G
31@05P/C00h4300E2aH02P@?01H>6P0600L0?cE00107400?0`d06`lI01863`0@1P`050L@01<63`0>
0`T03`@:0P0@1@/02`0?10X03P<900T0100A1``03`D:01<83P0=10P03`@:00d41`0=1@L03@@70080
3P@700L03P<700/10`0C1PX03P4500h00`0N3a@04P@701Cooooo000Kooooo`09018?200A3PP04@h9
010<2@0@30X03`/:010<2`0@30X040`900<040d800D0HUiK01TE4P0F4Pl03PX702PT8@02014=2P0;
01HB3`0C3``04Ph;01@@3@0C3``0RHF407QdL`0<20L04`l>010<2`0>2PT01P0A3@`4010<2`03014=
300C3`h040`;008040`;01003`/:00h:2@0>2PT05QDC01@C4@0I61H030/901HE4`061@<04A0>00l>
300=30X04Q4?01@C4@0D3P`05P`;0P0F3P`01P0D30X040/8014<2@0B3@X040`900l;20<03@T600<0
5a<@01hJ5`0I5A800P0=2@H0300A3@X03`/800d91P0?2`P04`l<01DA3P0A3`/02`X6014@300=30P0
20L300l>2PH03Pd900H03@`9014?400>30d02@L8018@4@0D4Q<200l=3P804@l@00/040h?00h<300D
4a402PT700h=2`0<2`T03Pd;01<B400G5Q@05A@B018A3`02010?3@0G014@3P0S91l010D000h?2P09
2PD051D@01LF4P0>3@T03`h:018>2`0?2`P03PX7010<2@0?3P`03@`:00/:20081`D03`h<020O7@0>
3@/020L601@C4@0>3@/00P0<2`T200d<2P0800`;2@0>3@/04a8@01HE4`0@3`d04Q4?014@3P0?3P`2
00d<2P0E0040000?3@h04Q0A01<A4P0?3@h02@L800d;300?3@h030X;00/92P0>30d02PP9014?400>
30d02`T:00d;300C4A8061HG01<A4P0?3@h03P`=008040h?00d03`d>00X82@0?3@h02PP901LE5P01
00001P@5010>3`0>30d0BTQ902`Z:`0E4a@02PP900L03@/<00D05Q@E00/92P091`P03`d>00X82@03
00`:2`0A00h<3@0?3@h040h?010>3`0=2``02@L801/I6P0L6Q/01@@3014@3P0I61H0<2l]018A3`0=
30X02@P600h=2`0<2`T00P0;2PP0100<2`T02PP600d9200A3@`200l;2P0B00`81`0@30/00`0001`H
5`0M6AP0DDe<00X61@0H5aH00`D40000000I5aL03PX;020G6P0B20/05P/?00X1100@20/0618D0P0B
3Pl05`0=2@X06ADF06MSI00R7Ql040`=00`82@0=2@X03PX;00l;300@30d04@d>02DS900a;c003`d>
00d;300F51D03`d>00X82@0G5AH01`D601DC500:20T03P`=00803PX;010030P900d92P0A3@h04@d>
00l;300>2P/03@T:00`82@0=2@X03`/<01`J7@0:20/01@<6020N8@1OGF00518E0P0?3A0300h<3`04
00d;3P0@2a4040/A010;4@803`X@00L03@P>01XE6`0F4AL02PD;01`G7@0F4AL01`8800<03PT=00@0
40/?01<>4P0F4AD040/?0P0A31004@0@2`l04@`@01<>4P091``030X?01@B5`0>31402`T>00P62`0?
3A803@/@00/93P0<2Pl03@/@00h<4@0E41L04@`B00803PT?00@040/?014<400B3A403PX;0P0B3Pl0
1P0?2``040`=00`72`0<1`/03@P<00h93@803`X>00<040/?00l:3P0>2@d00P0?2Ph00`0@2`l03PP:
010:3003014;3@08010:300Y8bD09R0R01H@4P0E3a402@<500/5200?2Ph3010;3`0A00l:3P0A3100
3`X>01@?4`0A31002`H:00h93@0?2Ph02@@8018=4@0D3a<00`0201hI7@0<1`/03`X>00h93@0=20`0
0P0>2@d01`0<1``04@`B01<>500C3Q@050lE014<4P0?2Q000P0>2@l0100=20h03PT?00l:400>2@d2
00l:3P803PT=0P0=20`01P0>2@d03`X>00d8300=20`040/?00`82@<03`/<0P0C3a002@0F4Q<04`l@
01<?400@30d02`L800T51P0I5AH04`l@00h:2`0200d92P0<010<3@0?2``0510A01HB4`0=2@X030P9
01<?400U8B802PL701XF5`0E4A802`L80P0=2@X01`0>2P/03`/<00l;300@30d04@d>00l;2P0A3@`0
0P0C3`h0200@30/03@T801@@3`0=2@P0100000/71P0<20L06ADD0P0>2PT200l;2P8040`;0`0?2`X3
010<2`0600/92P081PL04Q0A00l=3P0A3a001`D60P0>30d02@0=2``03P`=014?400C4Q003`h;00d<
2P0?3P`03Pd;00d;3002014?400A00d;3P0>30l030X=00X83@0=2`h04Q4@00d<2P0H5aD020L600l>
301<BdT06QTG00d<2P0@3`d04A0>018A3`0G5AH00P0A3a84018@4`03014?4P0B41<04a4D00804a4D
01@051<E00l?3`0F5QH08b<S010@400>3Ph04a<C01HF5P0O7al06ATI01<C4`0K6a/0:b`Y01TK5P0A
4`h051HA00h@2`0A4a005ALD01HH5@<05ALF02P051DG01<E600@51L04aLJ01HJ700A5AH041@E014E
600E6A`05QTQ010B7P0?4Ah051HU01XM;00:41`04aTT01dQ:P21QX`0;34e01XM8P0E61d04a@I01HF
7P0I6B405QPP01@H900C6BL051/V01@H8`0D6Al05Q/P01LK7P0F6Qd05aPM01LG7`0I6B406a/U01HH
900L7RX082</0P0P8bX06P0J7B804QDJ01LJ800;3QD03a8K01LI900N8BX07alW01dN8`0G61d0414F
01`M8`0E5Ad06ATS02`/=P0S8bd03`lI030`>`0L72H04a8H018A5P0C4QL05A@I01HE6P0E51T04Q4F
0P0G5Q/03@0?3Q<06APM01XJ700A3a806ALI01/I6P0F51D04a8A01DD4P0G5Q@05QDC01DD400C4Ph0
0P0A40`01P0B3Pd06QHE02DQ800Q7A`061@C01`H5`H05a<B00d0518C02DS900H5QL07adN01PF6@0C
4A@04Q0C01LE6P0C4AH05aDJ02DR:@1kNGh0HV1T008061HI01/03`d@02`Z;@0100804a4D018@4`0E
4aH0518E018@4`0F4QD04@/?00h8300H4QH081XN01/E6@0D3Q804`dA01@>4P0E3a<04`dA018<400E
3a<040X>00d72`0B31002P@800l93@0E3a<00`0@2Ph03`0D3Q806A<G01hH7@0F3aH03PL>00l93`0@
2A004@XA01<<4`0?20l03PL>00l83`0<1@`03@H=01<94`0201864P8050PB00X04`LA01P=5@0?10`0
5P/A00P00`0=0PP03PD901D:4P0D2A404PL?0P0@1@d05@0?10`040D=01463P0A1Ph02P0700T01P0@
1@h02@0:00`44@080@/01P0702XP:`0900P03`<=00L01@0>1@/07Q4J00P0100>0@X03P<900l42P02
01052`0800l42P0>0`T01`0200`31`0>0`T07Q<I00`31`07008300d41`<03P<700H040@800`2100V
6Qh03P0405]<D@0^7b@Dooooo`006oooool00`0C40/04Pl;018>2`02014=2PD040`90P0@3@P04P1P
G5T08AdJ01@@3@0A3@X07ATF014=2P0E4@h06QHC01@@3@0A3@X04`l<014=2P27Ph80PWim00/71P0G
4a80510?00D100H04@d<00<04Ph=01<?3P0C3`h00P0C3`h00`0D40l04Ph=018>3@02014=308040`;
00`02PT700H50`081`D02`X800h=2`0E51804Q4?014@3P0=30X04Q4?01@C4@0B3@/201@<2P0=01<=
2P0B3@X04Pd:018=2P0B3P/04@d:00h;200;2PH02PT500d:1`0E4@h06QHC01HB3`0200l;20804Ph;
0P0A3@X0200E4@h06QHC01LE4@0<2`L04A0<00h=2@0=30P04Q4=1P0>3@T05@0C4Pl02`X801DD4P04
0`4020L501<B400=30X03Pd;014@3P0B4@l04A0>00l>300@3`d030/7014@300:2@D03`h:01<B3P0K
6QH06APD01DD4002014@300>018A3@0;2PH00P4001PG4`020@001`H200/:1P0>3@T03`h:010?2`0?
2`P03PX7010<2@0B4@d200l>2P0500T8100510002PT500/:1P0>3@T00P0A40`08P0:2@D01PD1014@
3P0?3P`02`X800T81P081`D01`H400T81P0=30X030/900P71@0920H03Pd;01@B4`0=2``020H701<A
4P0B41400@0000T7200?3@h03@/<00h<3@0D4Q<04a4B00d;300<2P/02`T:00d;300B41405A<D01@B
4`0@3Pl200l=3P0400h<3@0<2P/04a4B00X82@802@L800P01`D601DC500@3Pl04a4B065OH00]:b`0
40h?00/92PH03@/<00H02@L8014?400<2P/01P@500d;300C4A8300/92P0400d;300?3@h040h?00X8
2@80518C00T00`4200`:2`0=30/09bHT00<2000R8Al03`h<010?3@081`D00P0=30X08@0<2`T02PT7
00/:200=2`T03PX9014=300>2PT01@4000l;2P0E4A003`/:01`H5`0@30/07ATH00<0000<2`X061XI
00410@091`L00`0001@;3P0@1PX060dA01482`0A2P`050h@01<?400>2P/00`0000`82@0X92D03PX;
010<3@0200l;30@040`=00/00`0003Lc=00C3a006aLH014=3P0?30`02@D601/G600A3@h0510A00X6
1`02018>3`0B010<3@0?2``03PX;00`82@0@30d03@T:00h:2`0?2``03@T:00`82@0=2@X020H901@B
5@040PD00@0201TG6P0100803@/>0`0>30l200l=40803`X>0P0>2@d2010;3`0600@00`0?2Ph04`hB
01LB5P0>2@d020<7100>2@d2010;3`803`X>00/040/?018=4@0B3A4040/?00d;400R82D0GUaQ00l=
4P0A3a@01`D:00l=4P0300h<4@0700l=4P0@3Q<04`hE00h93`0;1P`030L=014<400201@?4`0600h:
2`0@30d040`=00l;300A3@h03PT=0P0<1`/01P0=20`03PT=00l:3P0@2`l03`X>00h93@803`X>00<0
40/?00l92`0@2P`00P0A2`d02@0@2P`05@lA01/E5`0B30h01@0100d72@0D3Q004`hA00l:3P0300h9
3@0600l:3P0B3A404PdA018=4@0:1PT01`860`0?2Ph01P0N6Ad0BDA800<00P0K5QX03@P<00h93@80
3@P<00P03PT=00l:3P0@2a003@P>00l:40091@X02`H<014<4P803PT?0P0?2Q0200h93`03010;3`0?
2Ph03PT=00803@P<0P0>2@d01P0?2Ph040/?00h93@0>2@d04PdA00/720<03`/<00@0510A01<?4008
10D03@T:0P0@30d02`0D41405Q8C01<?400L61T07ATJ00/7200B3Pl03PX;00l;300A3@h04`l@0080
3`/<00L04Ph?00H20`0?2``04@d>00@00@0?2``03PX;00H03`/<00d03@T8010<2`0B3Pd04Ph=00l;
2P0;1`H04Ph=010<2`0<20L081`K014=300>2PT04@d<00<040`;0P0?2`X00`0>2PT040`;018>3@02
018>3@0U010<2`0?3@h05A<D01XH6@0<2P/03P`=00d;300;2@X03P`=010>3`0B41405Q@E01TH5P0?
3P/030/900l>300>3@/03@/<010>3`0;2@X04Q0C014?4P0;2@`07adR03Dc=P0=2``01@<402LU9P0D
4Q<09bDV092>S`0T8R<04@l@01<A4P0A3a003@/<01<A4P02014?4P804Q0C0P0C4A@3018@4`0F01<A
500D4QD04Q4C00l?3`0D51@05aLG00d=3@0>3Ph05ADE01LG5`0I6AT05QHF00l?3`0=3@d02@X800d?
2P0B50l06adI01@F4`0<3P/04aDC01@F5@<05AHH01l05QLI01<E600E61d06AdP01TM7`0J7Ql061`M
01@H6`0F6Qd05aXR01@F8P0B52004QDR01TM:@0=51h05A`U00T=5P0_=3X05a`P01HI7P0C5Q/06AXO
01PI7P0A4QL04aDL01LK9`0F72X05ahY01PL9`0H7B<06b0U00805QXM01l06AXO01PH800I6B406a/U
01@F8P0H6RH06A`U01TL8`0N8BP07R4V01TL8@0H6b4051LN018E7P0G6B@07R4Z02HV;P0I6Ql0824V
00X;401;Be804A4I010@600F5Qh04a<K01`L900G5b002PXB01<B5`0B4Q@04a<E00805ADG00h04Q8D
01<C5@0D51H04a<E00/;3@0B4Q@03@d?01@B5@0I5aP06QPI01LE5P0C4A804@l@01DC50805QDC00P0
51<A014@3P0@3`d04@l@01PF5`0S8B807Q`M01@B4`8061HG0P0G5AH07P0F51D05A<D01@B4`0E4a@0
518C01HD5@0]:b`081hQ01<A500>30l061HK01HD6@0G5AX030T@01LE6P0G5AT05Q@G00D31P0/:Rd0
ZjV/061NH@0D4QD04Q0C01HD5`0D4QD04Q0C01DA500C3A404@/?018<40@04`dA01P05@lC01LA5@0F
41@050hB01PB5P0D3Q8030H:00X4200>20`06A<G01XD600?2@d040X>014;3`0C3A405a4E01LA5P0=
1Pd09b0W04Q1B00C31<010040109400A2Q4200d63@0>0109400>1`h040L@01864P0D21@04@D?0104
3P0B1Q007Q<K01873`0B1`d01`0201D:400E2a0201<8400701873`0A1Ph040D=01053@0A1Ph040D=
01@94@0200X01`0?01063P0;0@`0610K00P22`0F31D02`4:01073`0=0PX01`0401L<500A10/09APO
00/01@0>0`T03`@:008040D;00P03`@:00h32@0O51X02`8606QMH`1oM7X030<701`A5`@03P<70P0?
0`L01P0A1@T06@lA00P0000=0@D040H800P001Cooooo000Kooooo`0A00h:1P0E4@h02`L601@@3@0Q
7AT0510<010=2@0A3@X04Ph;014=2P0B3P/03@T501LC400A3@X04Ph;020L6@0A3@X00P0>2PL04@0E
4@h04@d:01<?300G4a00510=01HB4@0E4A005Q8A010<2`0=2@P05a<B018>3@0@30/04@d<01@@3`0C
3`h04Ph=00803`/:02<04@d<01<?3P0@30/03PX9014=300H51<040`;018>3@0;1`L04@d<010?3@0<
2`T03`h<01<B40071PD04A0>01<B400:2@L03`h<010?3@0:2@L05Q8@01@>2`0C30X04P`9018=2P0C
3``050l<01@@3@0A3`/040h;00`;1`0?3`/03@X700h:1`02014=2P8040`90P0?2`P0200A3@X04Ph;
01<?300F4Pl0514>00/:1P0n?CT0CDa80P0H5a<2010?2`803`h:0P0=30P0200>3@X03`h<00h=2`0D
4a405A@B00`;2@0>3@/04A0>0P0B4@l02@0E51804A0>00d<200=30P040l;00`;1P0?3PX040l:00d<
200200l>2@0700`;1`0E51003Pd8014>2`0;20D04a0=00/:1P02018A3@0800l>2P081`D04A0<00/9
1@0?30T03`d900h=200=30P2010?2`0600h=2@0?3PT03@`8014@300>3@T040l;0P0>3@T01`0A40h0
30/9010?3@0D4a403`h<014@3P0@3`d00P0<2`T02`0?3P`04A0>00h=2`0>30d03@/<014?400D4Q<0
8AlP030^;`0>30d04@l@00803@/<00D040h?00`:2`0@3Pl03@/<00`:2`0200h<3@0B00d;300A3a00
3P`=00/92P0=2``03P`=00/92P0?3@h020L701DC500;2PX03P`=00`:2`0;2@X0518C010>3`0920P0
518C100=2``02@0>30d03`d>00l=3P0:20T0518C00`:2`0A3a0030X;00X82@0300`:2`0@00h<3@0=
2``03@/<00h<3@040P<03P`=01@B4`0<2P/03@/;01dL6P0P7ad0[JbZ030_;@081`D040l=00l>30@0
3Pd;00<040d<00d9200<20L00P0>2PT0A@0Q7A`08alN018>3@0<20L03PX900d9200?2`X030/:00lA
400;2`/03P`=00h:2`0?1`T050X=01462P0C2Pd04P/=00`6200A3@h03PX;00`82@0E4A8020D500d9
2P0C3a004@d>00d92P0@30d03`/<010<3@0?2``040/<01PC5@0<1`T02PD600l:2`0B3@h040/<01D@
4P0@2`d04Pd?00l:300?2P/02`L8014=3P0?2``03PX;010<3@0D41403PX;00T51P0B3Pl02PL701/G
600?2``03`d@00h<3`0@3Q403`d@00/9300B41<040hA00`:3@0?3A003@/>00h<3`0A3a803@P<010;
3`0200l:3P<04`hB00D03PT=00l:3P0@2`l03PT=010;3`0400l:3P803PT=00`04PdA00l:3P091@P0
3`X>018=4@0>2@d03P`A02XX;@1RH6D03`dB018@5@0>314600l=4P0800d83`0?2Q0050lE010;4@0@
2`l03`X>014<400;1`P2018>3`0500d92P0@30d04@`@00l:3P0@2`l00`0A3103010;3`0@00l:3P0>
2@d03PT=01<>400;1PL04@`>010;300@2`d03@P900/61`0B3@h04Pd?00l:2`0A30d03@P:00h93@<0
3@P<01D03PT=00`72`0@2`l03@P<00l:3P0<1`/04@`@00/62P0E41@09B0T04i9C@0A310050lC00d8
300H4aL0CdY>00l:3P0;1PX05A0D010;400=20h00P0C3Q@03P0>2@l040/A00h93`0:1@/04@`B00d8
3P0C3Q@03@P>018=4@0N6Ad0>SDi010;3`0B3A4030L;0`0?2Ph200d8300@00l:3P0?2``05a<D02HR
8`0A3@h03PX;00l;300D41405A4B01<?400:1PL04Ph?010<3@0:1PL06QHG02XV9`805a<D00D03`/<
00`82@0=2@X04Ph?014=3P02010<3@<04@d>00<030P901@@4@0710@00P0@30d3014=3P03010<3@0@
30/040`;008040`;00P03`/:00d9200D40l04Ph=00T5100F4Q402PH601<?3P8040`;00D04@d<018>
3@0B3Pd040`;00d92002014=300A01<?3P0?2`X04@d<00d;300?3@h04@l@00d;300I5aP08AlP014?
400H5QL02PP901@B4`0=2``03Pd;014@3@081`D00P0>3@/0500=2``04@l@00l=3P0=2`h04@lB010>
4@0?3A8040hA01<A4`0;2@X040h?00h<3@0:20T061HG010>3`0;2@X03`d>018@4@0?3@h040h?0P0A
3a802P0B41<04a4D01<A500D4QD05Q@G01DC5P0B41<05A<F01HD5`0C4Q@201DE5@0C018B4P0D51@0
5ADE01HF5P0>3Ph061PH00h>3P0Q8B405QHF01HG5P0J71P04Q@@01<E4P0G6AH051HD01HH5`0D5QH0
5AHH01HG6@0201@E600n01HH7@0H6b004A@I01@H6`0E6A/05QXK01@H6`0F6Qd05aXP02DX<@0D5b40
4aHR01DI900?5Ql06R4Y030d?00F6R8051PO01@G7@0I72808R<X01`M8@0G61d07R0U01TM:@0H7R`0
6b4/01dQ;00K82H05a`Q01HJ7@0W:bh08B8W01PH800J6R806ATS01hP;00L7RX061/T01LJ8@0I72<0
6QdR01TL8@0G6R006ahU01@G800M82X0=cY301LG7`0H6Al05aPN01<D6@0R8bP05QLM018B6@0P82L0
4a<J00l?5P0G61h071dR01HE6P0F5QP201DE5`0301<C5@0A4A<04Q8D008051@F00@04Q8D01TI6`0H
61X05Q@E0P0C4A803P0G5AH061HG01@B4`0E4a@04Q0A01@C4P0F51D04a4C018@4@0F51D05aDF01XH
6@0F51D04a4B0P0G5AH0100E4a@06QPI01XH6@0E4a@201<A4P<05aDF01P05A<F01LE600A3a808R0U
05=AEP0A3a@06aPO01HD6@0D4QH05aDH01`J7@0E4aH0CD]>02DS9P0C4A@03`d@01<A500E4aH05aDH
01@@4`0F41@0618F01D?4`0A2`l201<=4@03018<400C3A405@lC008050hB01404P`@014;3`0B3100
4`dA01D?4`0G4AD05Q0D00d72`0<1`X04`dA014;3`0>20`040T?00T32@0<1@`071DL01D>5@0200l8
3`0A018;4P0>1`h03PL>014:4@0?20l03`H?0104400C1a<04PH@01043P0B1Q004`P@00h32`0A1``0
5P/A034V;01SF5h00P0?10`401053@0B00d22P0<0`T03`@<01D:4P0M4QX060hE00d3300?21403PL@
00h43@0B21403@<;01873`0?10`03@<901L:4@1WFV405P/?100@1@/200l42P0B00l52P0B1`d06PlE
02LL8P0C2@h02P4500/2100>0`L04@H:00l31`0@10P06@dA00`1100D2@`04PP:00l41`0B1`/03P86
5?ooool001_ooooo00X0<Rh[014=2P0D40d02PH301DB3@0;20<03``701<@300>2PL01`<00P0@30T0
4@0C3``01`@2014=2P0K5a@02@D401/G500@30T0510=014=2P0C3``0510=010<2@0?2`X040`;00d9
200A3@`05A4@0080510?0P0A3@`0400B3Pd040`;00h:2@0A3@`03`/:014=300B3Pd040`;00l;2P0F
4Q409R8Q01`H5`0<20L08AdL01PD4`0?3P`2010?3@0H00h=2`0;2PP02@P600X91`0P7ad05A@B01PG
5@0I61H02`P701@?300B3@X04@`9018=2P0C3``04Ph;00d<200<2`L03Pd901XI5@0N7aX030/7014=
2P0C3``04Ph;0P0?2`P0500>2PL03`/8018>2`0D40d04Ph;010<2@0@3PX01`H203<b;P16AD404Q4=
010?2`0=30P040l;00l>2P0>3@T03@`800`;1`0=30T03Pd;0P0?3P`200h=2`0B00X91`0=30X03@`:
00@30@0@3`d051<@00l>2@0<2`H02`X500h=200?3PT03Pd801XI500>3@P03@`702HU8011@3/081lJ
0P0@30T04`0A3@X03`h:00l>2P0@3`/0B4M302PW8`061@806APD00`;1`0@3`/04A0;010?2P0?3PT0
3Pd800l>2@0@3`X020L200X9100<2`H00P0;2PD01`0<2`H030/900l>300>3@/02@P6014@3P071P@0
1P0>3@/01@0=2``030X;00<10P0R82408AlP00804@l@00d03P`=00@20`01000071XK05YHF@0C4A80
3`d>00`:2`0=2``03P`=00/92P0@3Pl03`d>00802PP900P030X;00X82@0A3a003P`=014?400<2P/0
40h?00`:2`H03@/<00@03P`=00d;300<2P/030X;0P0=2``01`0A3a000@00014?400A3a004a4B01HD
5@0>30d00P0=2``0300>30d030X;00X82@0>30d030X;00d;300>30d03@/<00h<300A40h03Pd;05IE
D`8040l=0P0>3@/01P0<2`T03@`:00l>300?3P`03@/900`81`803@T800D03`/:018>3@0A3@`03@T8
00h:2@0300l;2P0@010?3P0O8B00:BTY01@B4`070`@071<F00l52@0?10P03`H901<;3P0O6A/09b<T
00d92P0>2P/040`=00h:2`803@T:0P0E4A80500<20T0100100H20`0E4A8030H8018<3P0<1PP071HH
01dG6@070P<050h@01PB500K5AL05Q0B01<=3`0F41802`L801@@4@0@30d03@T:0P0?2``02@0:1PL0
<2`]03di>P0F4Q<0;BTZ01hJ6`0@3Q403`d@00h<3`0300d;3P0800<1100:20/03P`?010>4@0200<0
30X=00d8300B3A4200h93@03010;3`0:1@T03`X>00D03`X>00@040/?014<400A31004@`@0P0B3A40
1`03008040/?02<N8P0E41@02`H:00h93@0;2@h00P0A3a@200/93P0/00h<4@0:20d02`T>00/93P0<
2Pl03@/@00h<4@0<20h00`0400/6300=20h03`X>00P31`0=20`04Ph?01`H6@0F4Q<030P9010<3@0=
20`02`H:00d8300?2Ph03@P<00`72`0@2`l04@`@018=4@0C3Q804@`@010;3`0>2P/020@501@@4@0A
3@h03`/<01LC500A3@h02@D600`82@0A3@h0510A018=400>2@d300l:3P0E00h93@0=20`06A@H00h9
3@0D3a<01`8600H11@050@@02`H:010;3`0B3A403PT=00/62P0?2Ph02`H:04E0A00>2@d02@@800H1
1@0=20d03`X@00803PT?0P0=20h0300?2Q0020<901HA5`070PP04PdC00/6300910P0BDA807MbMP03
00802`H:010;3`803@P<0`0>2@d08@0?2Ph00`0000H20`0G4a@01P8300l;300>2P/030P900d92P0C
3a002`L801<?400;1`P040`=00`82@0D41403`/<01<?400I5AH061@E018>3`0?2``01`<4018>3`0J
5QL03PX;010<3@0A3@h040`=00l;300=2@X03PX;010<3@03018>3`03010<3@0E4A004`l>00804@d<
0`0B3Pd01P0>2PT03@T801TE500=2@P03PX9010<2`<04@d<0P0@30/01`0=2@P0510?018>3@0E4A00
3PX901<?3P0@3Pl00P0=2``03@0>30d04@l@018@4@0>30d05A<D00<10P0C4A802PP901@C4@0];2T0
5A@B00d<2P0>3@/00P0D4Q<0100B414040hA00l=400>30l200h<4@0700l=3`0C4A80518C010>3`0E
4a@03`d>014?400200l=3P0301<A4P0D4Q<04a4B008040hA00@04@lB018@4`0B41<04a4D0P0H5QT0
200C4A@05Q@G01HD5`0D4aD051@D01<C4`0F5QH061PH0P0G5aL0200L71`0:RXZ01PH600>3Ph04Q8B
01LH5P0C5A8051HC0P0E5a@0;P0E5aH051HF01@E5`0F5aT05aPK01@E6@0E5QX051HL01PK8P0A51/0
71lT018F6@0G6a`09BT/01<G6P0H6b0030lF014D7@0Q92l07B4Z01@K8`0Q:300E5QQ01HJ8`0I7BH0
5QTR01XM900K72805aPM01TJ7P0J72406al[01LM:`0G7BP0720[01`Q9`0H7B8061`O01LK7P0I6Ql0
71`T014A6@0F5R006Q`X01PJ9P0H6b@201/N9@0C01LJ7`0C5Q/05aXP01XM900C5Ql0418M01`O:00D
51h061PP01<C6`0B4aP06AXO01XK800F5a`07AhS01LH7@0A4QL04a@I01<D600201LG6@0C01DE5`0D
51H051@F01<C5@0?3a404a<E01DE5`0F5QP08R8T02l_;`0J61T04a4B014?400F51D06ALH01HD5@0G
5AH04@lA01@B5@0201LE600=01TG6P0C4A<030X;00h<3@0H5QL06QPI01HD5@0H5QL0518C01LE5P0J
61T061HG01LE5P0401DC500E01PF6@0J61/040hA024O901QGf@05A<H014>5@091``071XN02PV:@0K
6A`02`T<01TG6P0;2@`04a4D01LE600L6Qd040hA01@B5@0D41<04P`@00@04`dA00<04P`@014;3`0A
2`l0100B31003`0A2`l04`dA01<=4@0C3A404@/?01@>4P0?2@d04`dA02DO8`0P6Qh0618F01D?500@
2A003`P?014:4@0200h73P04014:4@0<1@`030D<00l83`8030D<00<04@PA01864P0B1Q800`0B1Q00
1P0R5al050TA01873@0D2@l0200302LL8P803`@<0P0@1@d201463P0?00h32`0A1Ph0308901053@0K
41P05@/C01@:4`0=1Ph03PL?00`22`0800L05`dE02/P:00Y7R@06PlE0080200200<050P<01052`0@
1@/00P0?10X200h32@0;00T0100:0@D04`P>01P=4`0F2a4050T?01452@0?0`L04@D900l31`0>0PH0
0P0E2@d01@0F2`l04PL;01052@0@1@T0304501Cooooo000Kooooo`0H09FAT00H518081`I00/80`0D
4@`03@X300/80@0A3PP0514<00h:1`0C3`d05Q8A01XF4`0H51403@T600l;200L61D02`L400l;200B
3P/03`/8014=2P0B3P/03`/80P0@30/0100810<04@d<01HB4@0=2@P201<?3P0[018>3@0@30/03`/:
010<2`0B3Pd040`;014=300C3`h04@d<00l;2P1EDE002`L601TE50091PD06QHE00`81`0=30X03Pd;
00l>300>3@/02`X800T81P0A40l03@`:014@3P0h=cD051<A014>2`0C3P/04Pd:014<2@0A3@X04Ph;
010=2P0C4Ph05A@@01hO6P0H6A@030d801<A3@0B3P/0510=018>2`03010<2@804@d:00@04Ph;014=
2P0@30T040d:0P0?3PX00`0C4Ph040l;00d<200600h=2@803`h:00h03@`800`;1`0=30P040l;014@
300B4@d05QDA00P70`0L6aL09bHR00h=200=30L030/600h=20803`h900P00`8000H5000;2PD02@P3
01TH4`0=30L03`/8010;20<040`900X03`h:0040000100001@H201PI500:2`H05aPC01<B3@0B4@`0
4A0;0`0?3PT0100;2PD03@`700d<1`0>3@P200d<1`0600`;2@0;2PT00`8001LF500<2`T01`H41P0?
3P`01@0:20T0=S@e00h<3@0F51D03@/<00804Q0A00L03@/<01TG600F51D03@/<020N7`0B41403`d>
00803@/<00@03P`=00/92P0>30d04@l@0`0=2``01`0;2@X04@l@00/92P0A3a003@/<00l=3P0:20T0
1P0=2``0100>30d03@/<00`:2`0;2@X200X82@0703lm?P0J61T02@L800H41@0L6Q/00@0000h<3@02
00d;300B00h<3@0<2P/02PP900d;300C4A802@L8018@4@0C4A802`T901<B40081`D030/900/:200E
518030/900h=2`0<2`T03@`:0P0?3P`01`0>30X03PX900l;2P0>2PT03@T800`81`0=2@P00`0?2`X0
3P0@30/04@d<01PG5P0620L02@T900P61`0<20T05Pd@00`41P0D2@d03`H900h72@0Q6ad07a/L0P0=
2@X08`0>2P/040`=010<3@0>2P/01001014=3P0?2``06QHG018>3`0810D0208401TC5@0A2`d02084
00h82P0O6A/04@/=01@>400G4A<04`d?014;3@0D3Q003PX;018>3`0E4A803`/<00`82@0=2@X04`l@
01lK700W8b@07QXK01`H6@0J5QL03P`?00<03`d@00P03P`?00`:3@0=2`h040hA00X82`0E4aH04Q0C
01DC5P803PX;00@03@T:010<3@0D41403PX;1P0?2``300h93@803`X>00d040/?00l:3P0B3A402@@8
00`72`0C3Q804@`@00`:3`0@3Q<03`dB00X83@091``02`T>00<030X?0`0>31403@0A31<040/A01HA
5`0A31804@`@00`72`0>2@d06ADF028N7`0H51D03PX;018>3`0A31000P0>2@d01P0@2`l03`X>00h9
3@0?2Ph040/?018=4@804`hB00X04PdA00/92P0;2@X04Q0A00l=3P081PL03P`=00`:2`081PL03`d>
0P091`P00`0D41<03`X>010;3`02010;3`0600l:3P0<1`/050lC00H11@0>2@d03@P<0P0E41@01@0=
20`02PD900l:3P0910P020<700803`X>00D050lC014<400J5AT030L;01D@5@0200l:40<03PT?0P0@
2a405`0M61h030L=018=4`0>2@l05Q4E00D0100D41<07QTM03<^<P0;1`X030L;00d8300?2Ph04@`@
018=4@0D3a<061@E01@@4@091@H01`<401HB4`0=2@X030P900804`l@00D030P901<?400=2@X04`l@
00T51P0200/7200<01<?400I5AH0100101@@4@0F4Q<00`0001TE5P0300003@T:00l;300@30d04@d>
0P0@30d0100>2P/03`/<010<3@0A3@h2010<3@0401@@3`0C3`h04@d<014=30804Ph=00D04@d<010<
2`0C3`h08AdL01DA4002010<2`0>01<?3P0A3@`03`/:014=300E4A002@D4018>3@0?2`X0510?00l;
2P0C3`h04@l@010>3`0?3@h200h<3@0?00d;300;2@X0518C00h<3@0C4A803@/<01PG5@0?3P/040l=
00d<2P0@3`d020H70040000C4A804@lB00803`d@0P0?3A80300?3A004a4D018@4`0B41<06ALJ00d;
3P0B41<040hA014?4P0E4aH05Q@G01DC5P804@lB0`0B41<0100D4QD05aDH01LE600D4QD201HD5`0E
01DD5@0E5AD051@D01HF5P0H61P05aLG01DE5@0?3`l00`<301PH600E5AD07QhN01HG5@0D5Q<061XI
01/M700I6aX05QLI01@E5`0F5aT061TM00805aPL03L061TM01DG7@0K7RD04aHM01hQ9P0B5QT06QhO
01PL7@0:3Q405QTN01LJ8@0X:c80@TE>00022`0M92`03QDM02X^>@0G6bH041@O020R;P0K7RL06a/T
01XK800G61d05ALK01XN:P0G7B/061hY01/O:P0L8BL06QlT018F6@0C5aX05aPM01PH800V9Rh08R8/
01<E8@0D5R8061/T01TL8`0H6b805QTN01XM8P0M82H092L^02<V;`0H6bD04QDN01@D7P0F5Qh04a<K
01<D6@0K72407b0U00806Q/O00H051DI018C5`0D5AP04Q<E01PH6P0F5QH201<C4`@051@D00d04Q8B
014A4@0K6a/09bLW01XH6@0D4a804Q0A01DC500F51H04a4D01TG6P0C4AD05A<H00805aDJ00@06ALJ
01HF600A4A<04Q8D0P0F5QP0200D51H05ADG01DE5`0B4Q@04a<E01@D5P0B4Q@05aDF0P0D4Q<05@0F
51D05Q@G01HD5`0G5AP02`T>01XH7@0C4AH040dD014?500B41@06aTL01HD5`0N71l09bDX00h<3`0?
3A004Q0C01TG6P0>30l04Q0C01DA5@02018<40804@/?00<04P`@01<=4@0C3A400P0C3A45018<400:
01<=4@0B31004P`@00h830080PH030H:01TC5`0B31002`D900h73@<03PL>01@02`@;00l83`0B2a80
30D<00h73P0B2a803PL>00`5300A1a404PHB01454@0@10h04@D?01@84P0;00P01`0400l42P0G3180
5@X@00d420803`@<0`0@1@d0500A1Ph03`@<01873`0<0PT0304901<8400=0`X050XC00H01`0>1`l0
4PP@00T01`0`9Rh0JEiT02dR:007004060`@01D93@0;00<03`@:0`0>0`T200d2200B00P00`0C20h0
40D;00L00P0M51P0CT=901L;3`0@0PH040460104200>0PH02`0300d21P0700004PL;00`31P0=10L0
2P445?ooool001_ooooo01@0GEUI010<2`0B3P/02@H300d:100?30@03P/300`91@0N6aH0510=00l;
2P0h=3<0DTi;01HB3`0:1P@05A4>02HR7`0C3``04@d:010<2@<03PX700P03`/8014=300A3@`04`l>
00l;2P0@30/05a<B014=30805A4@01004Ph=01DA400H51<04`l>014=300B3Pd0510?018>3@0@30/0
@3`k018?3P070`<061@C00`81`0A3@`03Pd;0`0?3P`200h=2`0B010?3@0F5A<0?C`j08f<RP0;2PP0
518?018>2`0B3@X04@`9014=2P0A3P/03`d900/:1P0C50l0QHJ108N8P`0J6aH03`l;0P0B3P/00`0@
30T03PX700l;2002018>2`0;014=2P0@30T03`/800l;200>30P05QDA00l>2P0?3P/03`h:00X91@0A
40`00P0=30P0100>3@T03`h:010?2`0?3PX500h=2@0400X91@0920@040l;00P70`806APD00`03Pd8
00h=1`0=3@H03@d600l>200@3`T03@`601/K500T91d020P300d<1P0F5@l3018=2P804@d:01T040h:
01HE4@0=30P06Q/F00d>2@1@DD`0QXN2018A300A4@X04A0:00l>200>3@L030`5010?2@0>3PL03Pd7
00h>1`0=30H02@P3018A3@0=30X061LF05EDDP0A40l04A0>00<03`h<0P0>3@/0300=30X020H701/I
6P0A3a002PP901<A4P0@3Pl02`T:00/:2P0;2@X030X;00h<3@<03@/<00@03P`=00l=3P0?3@h040h?
0P0<2P/02P0>30d061HG01HD5@0>30d04@l@00P61`0?3@h02`T:00d;300<2P/800d;30803P`=0P0=
2``01`0a;c00;R`]014?400:20T04a4B018@4@0>30d00P0=2``01@0>30d030X;00X82@0=2``04@l@
008030X;00@03@/<00h<30061@<03Pd;0P0B4@l01@0:2@L040l=00h=2`0<2`T03@`:00803`h<00<0
4@l=014=300?2`X00P0?2`X00`0>2PT03`/:010<2`0200l;2P0?010<2`0B3Pd0:RTX00/=30092@T0
3`d=01XF5`0;0PD060hA01@93@0<0`H040T;010:300C3a003PX;008030P901804@d>018>3`0>2P/0
2`L801DA4P0A3@h0=C4b02hZ:`0<20T050h@00d6200<10L06a@F018;3@0F3a403PL901082`0A2P`2
00l82P0?014:300C3a002`L801<?400>2P/040`=014=3P0>2P/02`P800h:2`0@30d04@d>00`82@0=
2`h03`d@008040hA00h03`d@00d;3P0?3A00GeeP06ESIP0D4QD04a4D00l=400T824061@E010<3@0A
3@h04Ph?00h:2`H03`/<00@03PT=00l:3P0?2Ph03`X>0`0@2`l05@1?BTh05Q8E01<>4P0>2@d04PdA
010>4`0B41D04@lD00h<4@0<2Pl03@/@00`:3`0;2@h030X?00h<4@0=2a002`T>010;4P0Y92X0:RD[
010;4@0200h93@09010;3`0C3a0061@E01DA4P0?2``040`=01<>4P0>2@d03@P<00803`X>00<03PT=
00l:3P0?2Ph0100?2Ph03@0>30d030X;018@4@0C4A803@/<01<A4P0B41402@L800`:2`0B41402PP9
00`82`0>2@d00`0?2Ph0500>2@d03@P<01PC5`0:1@T04@`@00/62P0?2Ph07APL01XE6@0@2`l05A0D
00d8300;1PX03`/>03@_<`0V8BD030P;014<400D3a<03`X?0P0?2Q003P0>2@l03`X@010;4@0?2Q00
4PdC01PC6@0=20h04PdC00h93`0>2@d03`/>018=4@0<1`/03@P<0`0>2@d03P0@2`l04@`@018=4@0C
3Q80:BDV02DQ8P0>2P/05a<D00/7200A3@h040`=01LC500<20T03PX;0`0A3@h02`0<20T0510A00l;
300@30d03`/<01@@4@0>2P/0=C8b02XW9`0@30d04Ph?00804@d>0`0@30d00`0?2``03PX;00h:2`02
00l;308040`=1`0@30/04`0?2`X03PX901`H5`0D40l030P700X61@0?2`X040`;00h:2@0F4Q408QhM
010<2`0D40l02@D400l;2P0@30/04Ph=00l=3P0@3Pl00P0A3a003`0>30d03@/<014?400R82405Q@E
00l=3P0C4A801`H401@C400920H040l=01@C4@0C4A805Q@E00l=3P0200l=400:014?4P0B41D04a4F
014?4P0B41<03P`?010>4@0J61/03P`?01@B5@804@lB00<05A<F01@B5@0C4A@01@0B41<00`0D4QD0
5A<F01DC5P0301DC5P0401DD5@0E5AD05ADE01DE5@805QHF04<051@D01LG5`0M7Ad04a<C01XJ6P0>
3Ph05AHE01<E4`0E5aH061XI01LI600E5QP05AHI01XK7P0J6al05AHK01LH700I6Qh06A/R01PK900A
51d06A`R010C600F6Qd05ATJ01`P8@0G6Qh0<3<j01DH7`0F6R<07B4[01<J8`0D6bD07B4]01hR;`0X
;3T08bDc01PJ:00I6BD08B4Y01`M8P0I6b0061`X01PN;00K8Rd07R8]01dR:00J7b@06AdP010D5`0M
7R<06a/S02HV;P0X:3804aDQ01`N:P0U:3406A`S01<F7@0I72405aXO01@G7@0C5Qd04aHO01<E800A
51d05QHP00805aLO00l061TN01hO900U9R/07b0T01TJ7@0D5AL05QLI01LI6@0D5QH061PH01DE5@0B
4Q804A4A01<C4`0F5QH00P0G5aL03@0D51@04Q8B01<C4`0G5aL05aHD01@C4P0D4Q805A<D01HD5P0E
4aH06aTM01HC600E4QP00P0C41H02P0G51X061LJ01LG6@0I6A/051@F01<C5@0H61X05ADG01XJ700F
5QP201DE5`0K014A4`0H5QL04a4B01@B4`0G5AH05A<F014?4P0E4aH06QPM014?500E4aP05Q<J01TG
700G5AT040hA01@B5@0C4A@04Q0C01PF6@0E4aH04a4D014?4P0@3Q405Q@G014=4@0E3a<04`dA0080
4P`@00@04`dA01@>4P0D3Q8050hB0`0C3A46018<400401D?4`0D3Q804P`@014;3`802`D900L03`P>
00d63@0@2A004@XA0109400H4AP06Q<J00803`P?00l04@XA00l83`0?20l04@LA0104400C1a<050PB
01<74@0B1Q0040D=01D:4P0E2Q002`8601L<4P0?1PX01`0@1@d04@0B1`l040D=01463P0E2Q804@L?
01063`080`T03@H=00l53@0:0@P08APN02XO9@0E2Q0040H901D93@0<0P@04@D800H03`@:018040L;
01883@0@1P/03`@:02PN8`1?@TT04`@90182200B0`P04`@901852P0?0`L04PL;00l5200B20/03`H9
00`51P0<1@LDooooo`006oooool04`050@8061@D00X60`0H51405A8;01LD2`0=2P4040d601HC3P07
0`80:BDU08Z6Q`0]:BP01`<1010<2@0H51405A4>01dI5P0H51400P0C3``2014=2P0701@@3@0?2`X0
2`L601DA400?2`X07QXI03di>00201HB4@0@01DA400B3Pd04Ph=01<?3P0B3Pd040`;014=300C3`h0
4@d<00l;2P0E4A003PX900<0001@C4/06QHE00<000803Pd;00X03`h<010?3@0A40h04A0>00l>300=
30X01`H4024P7P0E51803P`9100@30T0200>3@T02`X601DD400F5a806Q/F03dn>@0:30L03@d80P0@
30T01@0>2PL030P500h:1`0A3@X040`900@03`/800L04a4=00`;1`05100040l;018A3@0:2@D02`X6
00803@`800D03Pd900l>2P0?3PX03Pd900d<2002010?2`0D00l>2P0=30P040l;018A3@0@3`/04a8>
018A3@0;2PH03@d500h>1P0?3`L03@d500h>1P0A4@T051@<014A2@0B4PX02PX201<C2`0@3`L301@?
30<04Ph;00L01`H201HE4@0=3PX051HA028T7`0Z;2H03Pl900803`l701803Ph600d=1@0;2`<030`4
00X:0P0=3@D04A4901<C2`0?3PT01`H2018A3`0D4a409B@R014@3P071P@03`h<00h=2`0=30X200`;
2@0?00/:200E4a@0:BLX04E3A00>30d02`X:01@B4`0610D0:RPY01lM7P0:20T02@L800L51P081PL0
3@/<00803`d>00h040h?018@4@0=2``02@L800/92P0D4Q<040h?00D3100@3Pl030X;01DC500;2@X0
30X;00l=3PH03@/<00@02`T:00h<3@0@3Pl040h?0P0?3@h01@0`;Rl0I69S01<A4P0E4a@04a4B0080
3P`=0P0=2``00`0>30d030X;00X82@0200d;3004010>3`0;2@X02`T:01<A4@802`X800L01`H400l>
300=30X04Q4?00h=2`0<2`T03@`:00803`h<00@040d<00d920091@@02`L60P0@30/400l;2P0>010<
2`0A3@`03Ph=010B4@0l?3`030X:038^;`0B2@`040H901@93@0:0@@05PlA00L10`0A3@h200d92P0A
00h:2`0@30d040`=00h:2`0?2``061@E00h:2`0F4Q<04Ph?010<3@0<0`H04`X=01L>4@0800801P00
05YAE00C2Pd00P0B2@`201482`0?014:300L5QP02PH7010<3@0>2P/07ATJ00h:2`0@30d02PH700`8
2@050@8030P901<?400<2Pd03P`?00<03`d@00@03P`?01<A501kNG`0S8Z=0P0A3a80100<2Pd081`M
01<?400>2P/200l;3003014=3P0?2``03`/<00@03`/<00<03PT=00l:3P0?2Ph00`0@2`l01P0910P0
7APL01<>4P060@D07aXN059=D@803P`A00@03`dB00h<4@0<2Pl030X?0P0;2@h03@0@3Q<05Q@I01DC
600B41D03@P?010;4@0A31803`X@01<>4P0910P04@`@00X61`0;1`P00P0@30d0100>2P/040/?00d8
300=20`200l:3P0400d8300D3a<04PdA014<40<040/?01`03P`=00X82@0@3Pl03`d>020N7`0J61T0
2`T:018@4@0?3@h03@/<01<A4P0<2@/030L;00d8300>2@d03@P<00`72`0K5QX0;BP/01@?4`0?2Ph0
2PD901@?4`0K5QX04@`@00X52@0@2`l03PT=0P0=20`01P0F4AD061<G00X62@0300803@P<00X62P<0
3`X@00h040/A014<4P0>2@l04@`B00h93`0=20h05A0F01HA5`03008030L;00h93@0910P01P4501<>
4PD03`X>01d03PT=00h:2`0C3a0030P901@@4@0300004`l@00X61`0@30d03`/<02PT9@0H51D03@T:
00l;300;1`P04@d>00P41@0:1PL040`=01DA4P0<20T06QHG00L310050@805Q8C01DA4P0C3a0040`=
00l;300200h:2`803`/<00H03PX;00l;300A3@h04@d>010<2`0B3Pd301<?3P0F018>3@0?2`X04Ph=
00P40`0B3Pd03PX900/71P0>2PT040`;00l;2P0>2PT04`l>01`H5`0V8R40920O00l;2P0B3Pd04`l>
010<2`0<2P/03P`=010>3`804@l@014040h?00h<3@0L6Q/03@/<014?400i=cP07ahL01@C400L6aT0
?3/i038a;`0A3a0040h?01HD5@0D4QD04a4D018@4`02018@5@07014?4P0D4QD05A<F00h<3`0E4aH0
4@lB01@B5@02014?4P80518E100C4A@2018@4`0401@B5@0C4A@04a4D01HD5`80518E00l05A@E01<C
4`0E5AD051@D01<C4`0D51@07alO018B4P0G5aL0;bl_07EeM@0a<C406AXJ01LI600F61L00P0G6AP0
:00I6Q`061TL01`M8@0K72004Q<H01LH7@0I6Ql05ALO01<E8@0M82T051LN02lb=`0E6A`04aLH00/?
400F6Qd04A@I02<V;@0e>4402@dH00XA6`0E6bP05aXY04Y=GP1=D6406Q/]01<D9P0E52807AdW01hN
9P0L7R@0720/01TO;@0G7BP05ATT01HK8@0K82D05ATL010D5`0I6Ql201HF7P0D01/K9@0F62@08B<_
02P[=00G6R4041<J01TL8@0H6b0071lU01TL8`0G6R<061/U01HI8P0D51h051@L01LG7`0G61d06AXO
020Q9@0N7b<201HG6@0501PJ6@0F61L05ALF01DE5@0D51@00P0B4Q80200D51@05ADE01DE5@0G5aL0
6QXJ01TI6@0G5aL051@D0P0E51804P0F5A<05Q@E01LE5`0G5AP06ALL01HC6@0G51/05Q<J01/H8@0Q
7RD0<S4e00d=3`0>3Q006QXL01PH6P0F5QP061PJ014A4`804Q8D01d051@F01TI6`0F51D0518C01DC
500F51D04a4D014?4P0C4A@07adR01LE6P0<2Pl03P/B01@B5`0D4QH0518E01<A500O7B00518E010>
4@081PT06QPK01LE600@3Q406ALJ01@@500F41@05@lC01@>4P0201<=4@<050hB00<04`dA014;3`0A
2`l00`0B31001@0A2`l04P`@018<400?2@d030H:00803`T=00@02`D900T31`0=1P`03PL>0P0?20l0
0`0<1@`040T@01@=500200d63@0;0109400=1Pd03@H=0107400C1a<06PhJ01`@6P0J3QP05@TC0146
3P0700@00P0D2@l0100700806@hD01463P0A1Ph301053@0600l4300A1Ph04PL?01873`0A1Ph040D=
0P0>10`0300B2a8040T@00l53@0C2A4030@800d2200>0`T02`0401D93@0M4AD03`D600l42P<040D;
0P0A1P`04P0900@02P4501D:400K41H04`P>00`01P0@0@H06PT?01H52`0@0@H040<7010420070000
3@<700H0000U71l01P0101LA4aCooooo000Kooooo`05014<400=2PX00`00018>2`0?30D00P0;2000
300@3@H03``701DA4011?Cd0L6a]00<0000H51404@d:01LC400E4@h02PH301TE4P804`l<00X04@d:
010<2@0E4@h040`;00h:2@0C3`h03`/:01/G5P0`;2/0510?0`0B3Pd03`0@30/03`/:014=300?2`X0
4@d<018>3@0@30/03`/:00h:2@0A3@`04Ph=01LC4P0B3Pd03PX900`;2@0200d<2P0900l>300A40h0
4A0>00l>300C4Q005A@B00X91`0@3`d040d;008040`900X04@d:010<2@0>3@T0410<00d>2@0>3`X0
?Slj0:V[YP1EEe80410;0P0A3@X0100>2PL03@T600l;200@30T300l;208040`900L04@l;00d<2007
1P803@`801DD400?3PX02`X600D03Pd900l03`h:00h=200>3@P03@`700h=200?3PT01PD000l>2@05
100040l:00D4000?3P`03@d500l?1`0@40P00P0=3@D02P0A4@T04Q8:014A2@0D50`01PH000`<100>
3@D04`h;01D=2`0C3P/2018=2P09010<2@0;2PH05A@@010A300?4@`00P@000lC300=3PP03`l70080
410800`03`l700d=1@0>3PH030`4010@200F5Ph06ATA01DD3`071P803@`:00P71@01000200T81P80
40l=00L03Pd;00d<2P0<2`T02`X800/92P0510@071XK00804a4B00X01083010>3`0D4Q<02@L800L5
1P0B41405A<D00X82@0?3@h040h?0P0>30d03@0?3@h030X;00h<3@0<2P/03P`=00d;30081PL03P`=
01@B4`0Q7b004@l@00/92P0?3@h01P0=2``03@0<2P/03P`=00l=3P0?3@h03@/<00`:2`0?3@h081hO
01@B4`0;2@X00@0001DC500>30d00P0=2``01P0>30d030X;00X82@0=2``03`d>00h<3@805Q@E00X0
3`h=01@C4@0@3`d03`h<018A3`0C4Q003@`:00h=2`0<2`T03@`:0P0?3P`01P0?3@/030P700X61@0?
2`X04`l>010<2`803@T801@03PX900l;2P0?2`X03`/:00l?3P1OHF00emOG038`<@0=2@X050/>01lE
6@0N4aL03PD801@=3`090`D02PH700d92P0>2P/040`=00h:2`803@T:00H00`0000/7200?2``02PH7
00D10P070`@20189300F00l62@0D2`h03PD801H=400D2`h04PT<01072P0?1PT040L:00l82P0L5QP0
20@5010<3@0F4Q<0;RX[00d92P0F4Q<00`0001@@4@0810D01@42014=3P<03@/>00l03P`?00l=400@
3Q403`d@02HT9`0^;2l00@0200T72P050`H03@T:00/7200@30d04Ph?014=3P0E4A801P0?2``200`7
2`803@P<0P0>2@d01P0G4QH02PH901LB5P0H4aL03`X>00`72`802`T>01@03@/@00h<4@0=2a0030X?
014?500@3Q<04a4F01TG700F51T04@lD00l:4@0;1P`030L=01@?5@0J5AT03@P<018=4@0>2P/030P9
00h:2`804@d>00P04@`@010;3`0A31004`hB018=4@0@2`l04`hB014<408040/?02H04@`@018=4@0C
4A802PP9018@4@0N71d0JfUZ06QVI`0O7Ah071XK01PF5`030@80518C00l<3P0=20`03PT=00l:3P0>
2@d03@P<02TT:012?D407QTM00X52@03008020<700h93@0;1PX02@@800`72`0?2Ph03PT=00`72`03
00803PT=00l:3P0>2@d04`hB010;40<03`X@00h040/A014<4P0?2Q005a8H014<4P0?2Q006A@J02HQ
9`0N6Ad040/?01LB5P0J5AT01P4500`72`H03`X>00H03PX;01LC500A3@h03@T:018>3`0@30d200l;
300E01<?400k=cP07a/L010<3@0C3a002`L800h:2`0;1`P03`/<01<?400=2@X06aLH01HB4`030000
6QHG010<3@0D41404Ph?010<3@0?2``040`=00804@d>00l040`=00l;300?2``04Ph?01<?400@30/0
4Ph=01<?3P0D40l04`l>018>3@0@30/061@C00h:2@0E4A000P0A3@`02@0B3Pd04@d<00h:2@0>2PT0
4@d<01<?3P0O6aX08QhM010<2`0201@@3`0E00d9200=2``03P`=00l=3P0@3Pl04@l@010>3`091`P0
4a4B018@4@0E4a@0@T1102PW9@0B4@h01PD301@C4@0E51804@l@01PF5`0E4a@04a4D00804@lB0P0A
3a@02P0@3Q<06ALL028P9@0B41D040hC018@5@0C4AH04@lD018@5@0G5AX201PF6`80518E00@04a4D
018@4`0B41<0518E0P0B41<02`0G5AP0518E01@B5@0E51H051@D01HF5P0E5AD04a<C01DE5@0D51@0
61PH00806QXJ00<0:b/[00P8200E5QD00P0I6aX0100J71`06a`N01/L7P0H6A`201/L800k01<D6@0K
72407b0U01PJ8P0A4al07R4Z02@W;P2>TIH0:2`_02@X:@0J7Ql07B4T018E6P0R9BX0<SHn02T]>00<
4ad05Q`Y02/^?`0C5RT05aX]01PI;@0H6B/05aHU01TI9@0N7RH06Q`R01XN:P0K8Bl07R@_01`P:`0H
7B<05a`Q00hB5@0O8bH05aPM01DE7@0Q8BT06ATS01DG8`0I6bL06QdV01@G7P0@4aX04aHK00`?500B
5A/04QDL01@G800G6R@041<L01DE7`0D51`06ATQ01PI7P0E5Q/06a`P01XK7`0D5AL00P0G6AP00`0C
5A<051HC01<C4`0501<C4`805aLG01d05QHF01DE5@0B4Q803Ph>01LF500I61H061LE01LE5P0F51H0
5aDH01PF6`0E4aT05a@K01HC700M6R<09B8Y03<b=`0A41D04Q4F01XI7P0G5Q/061LL01DD6@0>3A80
6QTN01TH7@0A41D05aLI01<A4P0201HD5@0E01@B4`0C4A@04a4D01LE600@3Q<020H;01`J7`0?31<0
518G01<A5@0=2`h02`T<01<A500G5AP0<2ha01XH6`0<2Pd0518E014?4P0E4aH05Q8F00805@lC00@0
50hB018<400A2`l04P`@0P0C3A401@0B310040X>010:3P0A2`l04`dA00<04@/?0P0C3A402@0D3Q80
5@lC01D?4`0E3a<04P`@010:3`0<1@`02`@;00d63@0200X32P0B00h73P0=1Pd04@XA01L@5`0A2Q40
3@H=00l63`0C1a<060`H01X>600I3AL05PXD01dB6P0<0@T060dC01X?5@0700804`P>0`0A1Ph0200@
1@d03`@<00l4300?10`040D=01873`0@1@d03P<;0P0<0PX02@0?20l040T@0188400H3QH04`X?00X0
0`0K41@06@hB00d10`0201D92`803P<90P0?10X201052`0B00/01P0B1`d05@X@00d2200:0@D040<:
00l01@0J2@l05@@:00l01@0?0PH03@4500/0100C2@`04`X=05UCE@0D3Q00>C<e5?ooool001_ooooo
01h0:RHT00/71@0K61@04a0:00l<1@0U8QX04a08014>1`0<2@<06aPD02TV8`0E4Pl04`l<01@@3@0>
2PL0510=00h:200D40d05A4>010<2@0D40d04`l<00h:1`0@30T04@d;010<2P0C3`d04Ph<00d91`0E
4@l200l;2@1B010<2P0A3@/04@d;014=2`0>30T0518?014?300J61H04Q0=00l=2P0A3P`04a0>01DC
400Z9bD0E55?01`I5`0=30T030/800h=2P0@3``03`h;010?300A40d03`h;00`;200B4@h03Pd:010>
2`0F4a002PP5010>2`0B3`l020L601<B4@0G5QH03Pd=075aKP2j_;L0DE5=018A300B3`/04@d9010<
200?30P040d900l;1`0A3@T04Pl;010=2@0@30P04@d900h:1`0B3``05A8?010>2P0H5Q8071TF014?
2`0F4a004@h;00`:1`0A3`/040h:018@300?3@L02`T300/9100?3@P04@l:00/91@0D4@d03P`801DB
400=2PH071XF00h=200=3@H03Pd700l>2P0@40T0410:01@C3`8040l900@03Pd901@D3@0E4`l04Pd:
0P0B3@/01P0A3@/040`:00l;2@0A40d01PD400l?308030d902L03a4=01XK5P0:30H051H@00`<1`0@
40/02`/600l?2P0?3PX04Q4=01@C3P0B40`04a0=00h;300>2Pd04Pl?018@400=30/0410>00l?2`0?
3P`040d<014<2`0A2`/040/:00d;300?3Pl03Pd=00`;2`0;2PX05aHF014@4@0;2PX04Q4B00X92P09
20T02`X:00`;2P0>30`00`0=30/200`;2P0:014?3`0?3@d03P`<010>3P0@3`h02`X9018@400K6QT0
?C/k00X9208030X:01803@`;00h<300=30/03@/;00d<2`0=2`/02`T900d;2`0A3`l03P`<00/92@0?
3Pd02`X900X9200>3@`02PT800`:2P0?30`200h;2`0600l<300>2`/03@X:00h;2`0?30`03P/;0P0H
5AD02@0?3@`03Pd;00T81P0@3`d03@`:00h=2`0<2`T02`X800d<2P0200l>301i00X91`0B4@l04@l=
018?3P0?3@/03P/:01PF500;20L03@X900d;2@0>2`X03`d;00h;2P0>3@/0<C4^07QhM`0Q7Qd020@2
00l:2`0D3@d0614@01492`0B3@`04`h=018>3P0=20P03`X:014;2`0?20T03@P900l92P0D30h03PT:
01092`0@20X040/;014;300;1@H05A0@00`61`0E3@l050l?00h82@0B2``04`h?018;3@0A2@/04`h>
01<<3P0D41402PH7010<3@0H51D0:2@U00l;3004004071PI05UEEP0B3Pl05a<D00/7200B41003`h=
00`;300920/040hB018@500A3a<020H900d:300B3`l03P/:018=2`0?2PT03`/;01<?3`0B3Ph03@X:
00d:2`0>2``030T;00d<3@0@3@l03`d>00l<400>2Pl03``@00l<3`0C41804Q0?00h<2P0@3@`03P`;
00T6200=2Pd02PL;010<4`0;2@l02PP=018@5@0U8bP04Q0D00T72`0?3A4030X>010>400@3Q402@L;
00/:3@0;2Q004Q4F00h=4P0K6Al03P`B00d<400K6Ah06aPL00`83@0<2@d03PX?018?4`0200l:3P80
40/?00@03`X>010;3`0=20`03PT=0`0?2Ph06P0>2@d040h?00`:2`0B4140B4I70=;@d@3Zj>T0De5B
01<A4P0A3a002`T:01TG600<2@/040`@01@A5013@4<040`@01<@4`0;20/040d@00`8300@3A003PX>
00l<3`0>2Ph040/@0P0>2@h0300E41D08A`Q00/62`0<1``04@`A010;400=20d03`X?00/62`0A3140
40/@00l:3`<040/@02P05A0E010;400;1P/04@`A028M8P0;1PX04`hB01D@500?2Ph04@`@00l<3`0>
2`h03@X=010>4@0W8bL03`hA01PE600;1`P04@d>00l<30060P<08QhO00d92P0G4a@02`L801HB4`0Z
9RL0510A010<3@0J5aP02`P900l<3@0L6AX09b@U00h;300?30d02PL8010=3P0A3Pl03P`<0`0@3@h4
014>3`0i018?400@3@h04Pl@014>3`0?30d05Q<D00l=2`0A3``040h;00h<2@0=2`P03``:00d;200E
4Q0040h;01TG500D4@l03@/8014>3@0@3@`03``;00l=2`0@3P`040d<00d;2@0B40h04a0?00h<2P0@
3P`04@l=00l=3P0A3a004Q0A014?400E4a@030X;00h<3@0@3Pl05A<D00l=3P0M6a`03P`=01DC4P0A
30d04Pl?01<?3`0B3@h03``=010<3P0A2`h040d?014=3`0C3A004@h@01<@4@0G51D07AXK00804PlA
00/05a@F01<@4P0@31404PlC01TE6P0J5Q/05aDI01@C5`0C4QH05A<G01@C5`0201<B5P804Q4E00D0
5QDI01DC5`0E51P05QHG01HF5P0201LG5`805ADE00L05QHF01hN7P0D51@06QXJ01HF5P0E5AD06a`L
00805APH0P0E61T0@`0E61X051LJ01XL800K7B405ALL01hP9P0R92X07R0X01@G7`0F6B40;C0f096D
V@0_<SH061/O01PL800D5a/071lT01@G700G6R4051PS01/O;@0L82l0;C1001lR<`0N8C806A/Z01TL
:`0I72P06a`V01XN900I72404QLQ01`S;P0Y<3X09B/c01`Q:P0C6Al061hS018F700@51/07R4Y01DH
800C5b0061XV01LH900F5b805aTS01PI8P0E5ah05aTQ01DG7P0@4AT0:R`d02DW;`0?41T05ADM01@D
700J6R<04a<L01DF7P0J6b805aPO01DF6`0G61/05QLJ01<D5@0D5AH00P0C4a@301@D5@0;01<C500B
4Q<051@E01<C500E5AH061PI01@D500M71`061LF01/K6P0G5QH00P0C4Q<0=`0G5QL051<G01<B5P0E
4aP061LK01`K7@0H5aT05ADF01HF6@0C4QL051<H01XI7P0J6Al05A@I04E4B@1=C4l05aLG01@D5@0C
4QD04a4E018A4`0E4aL04a4E01PF6P0G51P0510F01LC6@0d<CH06A<J010=4P0C4A@061HI01dK7P0=
2`h0G5UL0<W5b@13@4<02@@801@>4P0H4QH04`dA01@?4`0/:2`030L:01LB5P0B31002@D8018<400A
2`l04P`@01L@500B2Pl03`P<01@=4@0D3Q400P0@2Pd02`0A2`h040X=01TC5P0H4QD02`D800h82`0=
1`X04`d@018<4@0?21003PL?008040TA03004@XA02HO9`14?DD06A8I01PA6@0C31<04``D00l63`0@
10l04@HA01H:5`0C1a@050PE01L;5`0D21804@H@00l42`0>1@T03P@900l42`0@1@`04PL>01<83`0A
1Pd040D<00d22@0B1`h050T@00l42`0E2Q403`D;01473P0:0`P04`X@00/1200@1Pd03@<800l42@0F
2a004`P=00d21`0B1`X04`L<01lD6`0:0@H050T@00`2200>0`X200`21`0A02HL8@0b9b`07A8G00d4
1`0I3A40300201/:3P0?0@<04@8601<5200?0P<04PD801851`0E2@X0@cLj00l51@0T6AT05?ooool0
01_ooooo00L0XIjG01dJ5@060`003P/401TF3`0D4@X04@h7008040d600<04Pl801<@2@0@3@H0100B
3P/201<?300?00/7100G4a006ADB00l;200=2@H04@d:018>2`0=2@H03`/801@@3@0M6AH0=C4^014=
2P0C3``04Ph;00<040`902@04A0<0040000=30P0ATE1038a;@0L6aL02PT700L60P0;2PH02`X701dL
60061@403Pd900d<200C4Ph05A@@01<B3P0E510030/700X91@0H5a<03Pd901@C3`0<2`T04a8=00l>
2P0B4A0030X;02DS9P1kNG`03P`?0040000X9RH05QDA028Q700G5A02014>2@03010=200?30L03``7
00803``70P0>2`H0100@3@P0514<01`H500B3P/200l;200J01<?300F4Pl06aLD03<_;00T81d04@d:
00l;20060P003@X501PE3P0I5Pl040d800h;1P0@3@P07QXG01HB3`0C3`h03@T800T5100Q7A`05aHB
018A3@0=30P04A0<01<B3P0A40`200l>2P<03Pd900<03`h:014;2`0B30`00P0A3@`0<P0@30/03@`:
014@3P0>3@/030`:00/;2@0=3@/07b0M0=7Cd00L8Ad0004002DW900J6aT02`/900h>300@40h051<A
018A3`0?30/0510A00h8300?2@l040/?00l=3P0=3@`030`:00h?2P0?3`/04@d<018<300E2``050/<
00h<3@0<30`03Ph>00/;2`0:2PX05ADE00820P0D51@020P801<C4`0G5aL03@d=010?3@0?3P`02@P6
00P71@0=30X04Q4?1P0=30X03`0A40h05aHD01XI5`1FEE<03@`:00h=2`0<2`T03`h<010?3@0?3P`0
3Pd;00l>300<2`T020L500`;2@0201HE4`07018A3`0>3@/01`H400X91`0<2`T02`X8018A3`0300h:
2@<03`/:01804Ph=01LC4P0=2@P03@T800h:2@0=2PT03@`:00`;2@0?3P`03Pd;00X91`071P@06aXH
01DD4P061@@05A@B01HE4`0510<201XI5`0401LF500100006APF00d<2P803`h<00T02PT700/:2009
20H02`P601<?300E4@h03`/800T50P0;1`@00P0=2@H300h:1`03010<2@0@1`P040L800@04@P90`0E
30d02@0D2``04`X;018;2`080P8040`;00/71P0<20L03@T800T5100301DA400600l;2P0810<02@D4
01HB4`0C3a004Ph?0P0F4Q<05@0@30d06ADF00d92P0S7b001001018>3`0@3Pd04A0<00d>2P0820H0
10@600T82`0E4aP03P`A00d93@0=2@P03`/8018>200A30H040/700l;2@0200h:2@0C00l<300>30d0
9B<T010?4@0820X02`/=00d=400>3A801@8901@B5P1BD5405Q@E00T81P0920<03Pd800d<2@0=30X0
30X=00`:3P0200/83`0N00l=4`081P/04Q0E00<1100J61/03P`?010>3`0K6AX030X;00X82@0<30h0
4Q@H00P;400L7b@0UIJK01@E6P0E5Q/04a8H01DD6P0@3aD03``C00X73P0?3A804`hB00<00P0<1`/0
61<G00`72`0;1PX03`X>0P0>2@d200l:3P0E010;3`0F51D081hO01hL7@0`;Rl0R8J70:VWZ00b<340
3@/<01@B4`0;2@X04Q0A010>400A3a8030X=05IDE`0:20/02`T<00d;3P0;2@`030X=00803@/>01/0
30X=00X72`080`T01P47014<4P0U82H0@Se301@?5@0R7B<01`8800/630070PP01@06018=4P0B3A40
4@`@010;3`0?2Ph030L;00h93@0910P03PT=018=4@0@2`l030L;00h8300?2@d00`0>2@d0400=2`h0
108501@B5@0B4Q@06ATK03Xj?00O7b408AdN00X61`0C3a005Q8C00D10P0K5aP02PH700L3100G4a@2
00/7200L01@@4@050`@03@/<00/92P0>30d04@l@01LE5P0L6Q/02@L801/I6P0>30d05aDF00d;300?
3@h040h?014?400@3Pl03P`=00`:2`0@3Pl030X;00L51P0<2P/04@l@00`:2`0<2`T03`h:00h=2@80
3@`800<03Pd900/:1P061@800P0C4Ph00`0=30P05A@@00l>300500l>300<010?3@0F5A<04Q4?018A
3`0N7A/04Q4?028P8@0>30d07A/L00H41@0;2@X081hO0P0B41402P0C4A80518C01DC500E4a@04`h?
01@>400E3a4050h@014;3@0@2P`501@>400?01<?3P0C3`d0510=01@@3@0F4Q406aLF01lK6P0E4A80
40`=018>3`0H4aL05a8F018@4`0@3a@04A0E00@051<H0P0C4QL0100D4aP05QDJ01LF6`0F5QP201@D
500301DE5@0F5QH05QHF00805aLG00H061PH01XJ6P0I6AT061PH01LI6@0D61T301<G600]01@H6`0C
5a/05aXO01PK800E61h06A`S01`O9P0K7R@061/P01HI7P0L7b@08RDZ01HI7P0I72404aHK01LJ7`0A
51T051LL01LJ800D62@05aX[01`O;P0R9C@09b/g030d?`0J7RT05a/V01`P:@0O92X06b0V01`Q9P0D
6b<05A`T01/R:P0N9Bd06b8Z01LN9P0I82P061lW01TP:00=51`020lG02H/=00F62@061PT00<06ATU
00/061PR018B700F5Ql071`T028R:P0Q8RP05AHK01DE7@0@41T05aLQ014A7@0201`L:00601PH900G
5b005QLL01DF6P0D5AL04a@F1P0F5QP02P0B4Q@05QHH01<C5@0C4aD05aLI014A4`0J6QX04Q8B01PH
600D51@201PH600:01HF5P0C4a<04Q8B01DE5@0F5QH05ADE01XJ600G5aL05QHH01@C6@804a8J02`0
6QTQ00l>500L6b009RHW01LG5@0:2PP06aXN010?500K6Ql0?ce201LE6P0:20d07QTO01PC6@0G4QP0
6A8I01<<4`0=20h07a/O00l=400>30l05A<F01lJ7P0T7b<06Q@H01<=4@0I4aL05@`A01T@5@0d;c<0
_[bo02/Y;00>30l04Q0C01TD600L5QX07ALK018<400A2@h04PT>020G700W82<05a4C014;3@803PP:
00<02P@600h82P0D3Q000P0B30h0700F418050h@00X42@0>1`l03@H>00h73`0B2a<05@hF06URJP39
`/X0<2Ta01<<500K51`03PL?018:4P0B1Q006PhJ01@85P0@0a@07A0Q0186500?0a402P0901873`0K
41H060dA00l42P0@1@/20146300A00l42P0>0`T04@H<01L<4P0M4QP04PL=01P=4`0;0PH01`0202LL
8P1MDUP06PlE00L00P0G318040D;01873@0A1P`00P0>0`T05P0C20h01`05028F800A20h02P0701<8
3`0D2@l030470189300:00<01`0001lD601SEe/0GDiA01@61`0V5QL05@D601H61`0;00004`<401H6
1`0G1`P201D51P0301H61ooooooooooo01;ooooo000Kooooo`0`02/X8@0=2P@06aPA00`90P0:1`40
514:00l<1@0@3@H04Pl801@A2P0C40T03P/401DA3P0D40d04Ph;014=2P0C3``0510=00/7100H5140
510=018>2`0E4@h04Ph;014=2P0>2PL03@T6010<2@0K5a@0=30]018>2`0@30T04@d:018>2`0A3@X0
40`900h=2@0I61@05A@@010?3@0510004a8>010?2`0=30P051<?00X91@0F5A403`h:0P0>3@T09@0E
51005aHB01<B3P0D4`l02`X600h=2@0R8Ad03@`801@C3`0I61<020L20040000C4Q404Q0A00L5200l
>Sd03@/>00X82@0F5A@01@@001PG4P0A3`X0514<01HC3P0C40/040d8014>2@0I5Q404a0;00d:1@0A
3PT03``701<@2`0T8Ad05a<@00l;200B3P/00P0A3@X0500?2`P06aLD01@@3@0@30T06ADB01DA3P0C
40/07AXC028O600A3PT030T4010=200A3@X01P8000d9200B3Pd040`;03Pd<`0L6aL05QDA0P0?3PX2
014@30803`h:0`0@3`/00`0?3PX04@/;018<3002014=3004010<2`0=30X03`h<00`;2@802PX800l0
30`:01/L6P0];b`041DA01HH5@000@00IFIS01hN700=3@/03Pd;018A3`0A40h03P`:01<?400?2@d0
0P0?2Ph06`0>30d03@d<00`>2`0?3`d040l=018>3@0B30`04``=018<3P0>30d03Ph>00l?3`0;2`/0
20P800h>3P0C4a<03Ph>00820P00000010@4018B4P0;2PP03Pd;00d<2P0920H02`X801<B400600`;
2@0900h=2`0:2@L00P40020O7@0510803`h<00`;2@0?3P`040l=00803Pd;00T03`h<00d<2P0920H0
3@`:01DD4P0D4a4040l=00/:20061@<00P0<2`T01@0:2@L030/900d9200=2@P03PX900<03`/:00H0
4Ph=01lK6P0=2@P04Ph=01DA400=2`T200`;2@0C00h=2`0=30X02@P600/:200920H00@0001PG5@01
00001PD300l>30081`D081lM00T81P061@<030/900P71P0C4Q0051<A00d<2P0200T81P0300`:1`0?
2`P030P500803@T60P0;1`@01@0=2@H030P500h:1`0>2PL03@T600804PT:100A20T201D<3@8050/<
00l04`X;018;2`0?2@T05A4@01LC4P0;1`H04`l>018>3@0810<0100000h:2@0C3`h02`L601<?3P0F
4Q<00P0C3a0201HB4`0E014=3P0I5AH01@4200X71`0>2P/0510A00h;2`071P803@h:018B400@4180
3@`?01DC600D4QL04@dA00l;2P0@30T04Ph8018=1`0A30P040`:00803PX902X03P/;00d;300^;2d0
51<D00P82P0<30h03@d@00/:3`0;2@h08AlS0>k/k@24PX<05QDB00d<200>3@T03Pd:00h=2`0=2`h0
3@/?00d;400200H040dC00h<4@0C4AH0:2HY06=QI00<2Pd02`T:028P8@091`P03`d>00X:300;3A40
00<601LK7P1JFel071/P0000100<2a003`dB01PF6`0?3A8200/93P0O05]FFP0F4AD04`hB018=4@06
0@D03PT=01@?4`0?2Ph03@P<00h93@0B3A4050lC00l=3P091`P040h?014?400Y9bP0@T1101DC5009
1`P0518C00/92P0<2P/020H802DS9P0K6A`05Q@G014?4P0?3A001`D800`:3@0200d;3P0@00`:3@0;
2@`05a<G01LB5P0?2Ph03PT=00l:3P0O6Qh050lC071[K`12?D403`X>02@O8`0?2Ph02`H:014<40<0
3@P<00L02`H:010;3`0F4AD081/O01D@500=20`030L;008040X>02803`X>00h93@0>2@d030X=00T7
2P0<2Pd05ADG065QH`3Zj^`0G5aN00X61`091@H030P901<?40091@H02PH700h:2`0?2``04Ph?00P4
1@0>2P/02PL701HD5@2:R8T0:BLX01LE5P091`P030X;0040000?3@h00`8200L51P0N71d061HG0`0@
3Pl0400>30d030X;00X82@0E4a@06QPI00d;300<2P/04Q0A00H41@0>3@/03@`:00h=2`0?3P`03Pd;
00`;2@0L6aT2014@3P0300P71@0C4Q001PD300H03`h<00`040l=02PW9@0A40h051<A02@S8@0?3P`0
O7Yk00@20`0:20T07Q`M00l=3P081PL2010>3`@04@l@00H04Ph?01<?400C3a004`l@014=3P0@30d5
01@@4@0=01@@3`0?30X04Q4=01@C3`0C4Q00518C01DC500C4A803`d@014?4P0F51L05aDH01DC5P03
018A5P0300l>4`0=314040lD008051<H00@05A@I01HE6P0G5Q/05QHH0P0C4a<01`0D51@05aLG01TI
6@0H61P05aLG01PH600J6QX00P0I6AT03@0G6AT04aLH01<G600B5QL04aLH01@H6`0B5QX051LL01LJ
7`0E61h05aXQ01PK8P0H6b400`0G6Ql01@0B5AX051LL01PK800E61d071lT00804aHK00/05aXP01XN
:P0H6bX05aXY01`P;00R9S80:2`h01TM:00G6b@06QhW01`Q9`0201XO9@0702`c>`0N9Bd06B0X020W
;`0L8b/05QdU00P?5`0200L>5P0500/B6P0U;3@0MG^301LI9@0I6BD00`0J6RH04`0I6B<07alW01`L
900X:3003@hC01<D6@0A4QL04a@I01TI800J6R8030`F014A6`0J6R@05aLQ01HF7`0E5Q/051DI01<D
5P0B51<01P0D51H09@0E5AL05aLI01@D5P0C4aD051@F010@4P0J6QX051@D01<C4`0>3Ph061PH014A
4@0G5aL051@D018B4P0E5AD051@D01<C4`0G5aD05QHF01DE5`0F5AX05QDM01LF7P0H5al04A0F01@C
600;2``0410>01LG5`0M72000`8700H52P0B4AH02PP=01@B5`0G4QP00P0E41H201H?5P0J01D@5P0:
1`X06ALJ01HD5`0E4aH04`hB00d8300=1`/06A<G01XD600E31406a8G01@>4P0k>C`061HI00X82`0J
61/01`8600`72`0C3A403PP<00d62P0:0@H04PT>01dF6@0E3a42010:300P014;3@0?2@/040X<00d7
2@0C3@l02`D701D?4@0?2@/03PL=00l83`0>1`h040T@01<<4`0E3QD0:24X04i7CP0400@0204800l8
3`0D3A@02`8:01T=5`0M4Ad03`<A0186500E21T05`/I01X>700@10l03`@<01P=4`0=10H201052`80
3`@:01`04@H<01<83P0A1P`040D;01L<4P0@1@/04PL=00d3200C20h04@H<02/P9P0C20h04PL=00L0
0P0>0`T040D;0146300?10X03P<901052`1QEEl0YYZT03@Y<@0@1@d04`P?01dB600D2@l03PD80P0<
0@D02`0C20`0:AdQ01T:3@0N4A802`0001X:3@0D10L070`?01821@0E1@P05PH9008050@700<05@D8
ooooooooool04_ooool001_ooooo00L04@h:00`91@0B3`T03P/5018?2@0@3@L04Pl9008040d70100
4Pl901<@2P0A3PT061@A01DA3P0A3@X040`9018>2`0D40d04Ph;01<?300=2@H081`I028N6`0B3P/0
4`l<0`0B3P/01@091@804`l<014=2P0<20D03PX700804Ph;014040`9014@300920D03`h:01DD4009
20H03`h:00/:1P0F5A4051<?00d<200E51003Pd9010?2`0?3PX051<?01<B3P0300d<2003014@300U
92002`X6008040l;01d04Q4<01HE4@0>3@X07Q`M06ESIP0P7R403`d@00H41@0J6AH040l;01@C3P0?
3@X05A8=01TF4@0E4Pd04@h901@A300S81/07AXE01DB3@0J5a803P/600`9100H51002`L400d91P0E
4@h030P500l;2002018>2`07010<2@0?2`P04`l<010<2@0;20<0514:01LD3@0200d:1@09018?2P0A
3@X04@d:01@@3`0A3@`03@T8018>3@0C4Ph04A0<00D03@`800L03Pd9010?2`0@3`/03`h:00h=2@0A
2`/04P`<00804@d<01h040`;00d<2P0@3`d03Pd;014A3`0@40h02`/900`=2`0>40d01P/7034c<009
2`P0414?00/;2P0>3P`030/900l>300@3`d03``;018>3@0A2`d040/>00d;3@0>30d03@h>00h@3P0=
3Pl03Ph=00h=300?30`2010;300400`:2`0>3Ph0410@00h>3P8030`<00X01`L700P8200F5QH0410@
00`<300;2`/03@`:00/:200?3P`04A0>200=30X0100@3`d03`h<00/:2@0;2PP200h=2`0B00`;2@0=
30X03@`:00/:200<2`T03@`:010?3@0;2PP030/900l>300=30X02@P600h=2`0=30X030/900d<2P0D
4a401PD30P0=2@P09`0>2PT03`/:00l;2P0@30/07a/J01/G5P0A3@`040`;00l;2P0:20H02@P600X9
1`0<2`T03@`:00`;2@0>3@/04A0>00`;2P18AdD040l=01@C4@0i>3H08R4P03@c<@0R8Al04A0>00H5
100C4Q005QDC01TH5P0@3`d030/900h=2`0@3P/04@d:00l;200@30T03`/800h:1`02010<2@0500d9
1P0?2`P04@d:00d91P0?2@T00P0@20T300l720804@X:00X04@T:01082@0@20T03`P8014=300E4A00
7a/J00d9200I5A@071PG0P0A3@`0FP0?2`X04Ph=01HB4@0=2@P04@d>00l;300>2P/040`=014=3P0?
2``030P901HB4`0B3Pl03@T:00l;300=2P/040l=00`<2P0<30`03`lA04M6BP19Ad`07A/P01LD600A
3@h040`<010;2@0@2`L04Pd:014=2`0?2`X03PX900d:2P0<2P/0518C00h=3P0@41804Q8D00`<3`09
20d04@lD00`:3P15@d@04Q0A01DD4@0;2PH03@`800d<2@0=30X03@/>00d;3`0=2a0030T@00/93`0@
3Q<05A<H01HD5`0o?D005Q@G081nO`30_[l0@Cm000`:2`0?3`l03a0D01`O8P22Q8P05aPL00h=4P08
1``02`T>00h<4@0A3a@03``A01`H7P0>2a003`/>00h:3@0B3A404@`@00/62P0>2@d04`hB010;3`0>
2@d03`X>014<400B3A404@l@00l=3P804Q0A00h04a4B01DC500E4a@03`d>010>3`0=2``02@L8010>
40081PT02`T<00h<3`0A3a8030X=01@B5@<03@/>0P0;2@`0600B3Q802`H:00/62P0@2`l03PT=010;
3`0;1PX06aHJ00P41`0S7R804@`@00/72P0E41@04@`@00h93@0B3A4040/?00`72`0D3a<040/?00d9
300A31005Q4E00l:3P804P`@00<040/?00l:3P0>2@d00P0<2Pd0300=2`h0410B04i>D02`/;40>SXl
010<3@0H51D040`=01<?400:1PL04@d>018>3`803PX;00l03@T:00`92@0A3@h030X;051>C`0I5aP0
3P`=00L51P0@3Pl09B<T07QfM`0G5QH0518C014?400<2P/01P0@3Pl02`0B4A4040h?018@4@0>30d0
30X;01HD5@0I61H04Q4?00d<2P0?3P`040l=00803@`:00D03Pd;00P71@0?3P`0A4=1014@3P0600l>
300<00`;2@0`;bd05QDC00l>300B4@l04a8@014?400I5aP04a4B014?400C4A804Q4A0P0B4144014?
40H04Ph?1P0E4A804@0E51405QDB01DD4@0B4@l040h?014?400B418040hA014?4P0E4aL05Q@H01DC
5`0C4QL04Q4F020O900V9BX07A`Q008051<H00H04a8G01@C600D4aP05A@I01LG6@0F5QH201@D5003
01HF5P0H61P06ATI008061PH00@06ATI01XJ6P0J6QX06Q/L0P0G6a`01`0E6AX051PI01<G6P0C5QX0
5APM01PK800H6b400P0F6B001P0H6b4051LL01HI7P0M82D05APM01XM8P806A`Q00X08bH[01LJ7`0E
61d06A`R01`P;00H72T051PU01LK9`0J7RT06AdX0P0L82T02P0J7RL061dS01PM8`0H7B<0;38i01dS
:P0H7RD07R@[01TO9P0F72<2010F7@0M01HL8`0G7B@05A/R01/P:00G6BD06QXV01`L:00L72L06a/V
01XJ900O7bL05aLO01hO9@0I6Ql061TN01DF6`0F5a/04A8F00d>500C51X061PQ00l?600F5Ql05QLL
01@E600C5AD04aDC018D4P0E5AH01@0E5AL0100D51H05aLI01LG6@0E5AL201@D5P0A01DE5@0F5QH0
5ADE01DE5@0R8R805QHF01PH600E5AD051@D01DE5@0B4Q804A4A01HF5P0E5AL051<H01DD6P0E51`0
0P0F5Ad07P0I61h061LM01@D5`0E5AH06QXK06m_L`0N7B8030/@01HE6P0@3Q<05Q@I01LC6@0I51X0
5Q4G01<=500F41H06A@J018@4`0C4A@07A/N00l=400O6Qh0AT5502HP900C3A405a4E01T@5@0J4AH0
5@lC01`J7@804Q0C03D05aDH00/72P0E41@05Q0D01<=4@0H41D05@`A00l62`0H41@07ALI01H@4P0C
3@l04P`>00h82P0C3@l03PP:01H@4P0B30h04`d?00h82P0D3A804P/B014:4@0@2A003`P?0109400D
3A@0100401XC6P0>1`h081TP09VBV@1?ADh05PXD01464@0G2aT0;20^01/?7P0H3AX04PHB01874@0F
2a<04`P>01872`0@1@/03`@:00h32@0A1P`05P/A01dB600D2@l02`460146300200d2200901L<4P0?
10X02P4501@:3`0900@04@H<01873@0=0PP03P<900@040D;01P0ACU306YNJ00N4a/01`0400d22@0G
318050T?00d31`0>0`L040D901062@0E2@d04`H803h_<@0C0`H06P`>01851P0J2Pd03`0201821@0C
0`H04@4401000`0A0@@Dooooo`006oooool02P03000040d801PE400E4Pd03``700`9100D4@`040d8
00h;1P0@3@P201<@2`0301HB3`0D40d04@d:008040`900H04@d:00`81@0G4a004@d:010<2@0E4@h2
01<?30802`L400L05Q8?010<2@0C3``0510=010<2@0>2PL03`/800803PX702X03`h:01HE4@0D4`l0
0P4000<2000@3`/04Q4=01<B3P0Q81`061LC00d<200K6QH03`h:00d<200B4@d04a8>014@300C4Ph0
1`H400P70`0B4@d03Pd900l>2P0K6QD02PT400P70`0?3P/0;Rd[0:RVY`0V9BL09bDV01@C4@0D4a00
2PT40040000=2`H03``7014>2@0?30L03@X500l<1`0D4@`2010=200801PE400B3`X040d8018?2`0:
1P<0510=01PD4@0<20D2010<2@0C00L3000=2@H04@d:01DA3P0K5a@04a0;018?200>2`@03@X5014>
2@0@3@P01@4000d91P0<20L040`;01dI600I5A@03@`800h=2@0300l>2P0300h=2@0<2`L030/700<0
3@`800<030/7014;2`0B30`00P0A3@`0100@30/03@`:01<B400>3@/200/;2@0K00X:200>3`d03Q0=
00/@300A4a004Q@A01HG5@030`403`l=00X:200=30X040l=010=300C3`h040X:014<3@0?3@h03Ph>
00d?3`0>3a404A8D010A4`0@41003`l?014>3`0A3@h02PP900803Ph>00l03`l?018B4P0>3Ph01`L7
00l?3`000000410@01TI6@2ZZZX0:2LU010?3@0;2PP03`h<00h=2`0?3P`01P0>3@/03`081`D03Pd;
00l>300;2PP03Pd;0081000?3P`040l=00h=2`0<2`T03Pd;00l>300=30X030/900d<2P02014@3P80
40l=00D01PD300`;2@061@@05A@B00T81P0600l;2P0U01PD4`0810<03`/:00h:2@0<20L03@/900d<
2P0>3@/030/900T81P0:2@L01PD401DD4P0<2`T04A0?010?3@0I61H03`h=092?S@0`;bd02PT70040
000C4Q003`h<00h=2`0A40h03@`:00`;2@0>3@/03@/8010<2@0A3@X03PX700/7100<20D04@d:018>
2`03014=2P0300l;200=1`L03@L700803PP80P0?2@T00`0B30`04@/;014;2`03010:2P0=00T5100<
20L04Ph=00/71P0?2`X04`l>00@0000>2PT02`L601LC4P0`;2/09B4P00l;300300h:2`0F00l;300@
30d03`/<01/G600A3@h02@D601PD5@0B3a0051<A00h>3@0@41001PH804a;CP0i=c`05Q@I018>4`0@
2`l04@d>01<>400C3@d04@`9010<2P803PX903<03P/;00d;300?3@h03`h?010@4P0=3@l02`/>014@
5@0M6b0020H900X82@0G5AH01@@302@S7`0<2`L030/800`:2`0=2``03@/?00d;400;20l03P/A01PF
6`0G5AX07A/N02l]<00D4QD0LW1a0;Fc]00e<c@00`4200l?3`0O7b8010D903<d>0082@d06aXO04m>
D`0<2Pl05aDJ00h<4@0@2a405A0F00<0100@2`l01P4500<00P0<1`/061<G01@?4`0?2Ph00P0@2`l0
0`0?2Ph030L;00/62P0200/92P0B00@20`0;2@X04Q0A00`:2`0C4A804Q0A01<A4P0A3a0020H700L5
1`0H5QT05aDH00L5201BD5<0@T1300T72P0=2`h030X=0P0;2@`0100<2Pd04@hA00h93@0E41@2018=
4@0C00D0100:1@T05Q4E00l:3P0?2`h05Q4E01`G6`060PD040/?01LB5P0W8RH071LK00/62P0=20`0
6A@H01/F6P0=20`03PT=010;3`02014;3`06010;3`0?2Ph03`X>00d;3P030@@03@/>0P0<30h04@08
20X06QXL014=3P0A3@h01`<403hj>`0B3Pl05A4B00<0000;1`P04`l@00l;300;1`P0Ad=402<Q8P06
10D04@l@008040h?00L03@/<00P61`0L6Q/0518C00/92P0=2``030X;00<040h?00h04Q0A01@B4`0F
51D0DDm@01lM7P0F51D06ALH00X82@0=2``05QDC014@3P0=30X03Pd;018A3`8051<A00D04Q4?01LF
500=30X05aHD00`;2@0600l>3003010?3@0D4a403@`:008040l=00L03`h<01@B4`0@3Pl01@<400`:
2`0?3@h06aTJ00<04@l@0`0B41401P0B3Pl04@d>014=3P0B3Pl04`l@01@@4@D05A4B00<04a4B01@C
4@0D4a400P0C4Q003`0F51D061HG01<A500C4A@04Q0C01@B5`0E4aP051<H01HE6P0A41D08R4V02/Z
;`0O7R<04a8G01@C600201<B5`8051<H00<05aLJ01PH600G5aL00P0E5AD00`0F5QH061PH01TI6@02
01TI6@0<01XJ6P0K6a/06ahN01XN7`0I7Ah061`M01DI6P0C5aX05ATM01LJ7`0H6b006QdS0P0E61l0
400I72805APM01DH7@0J7B805aXO01HI7P0G6Ql05APM01hQ9P0F6Ah05APM01HI7`0J7RT061`W01HJ
9P0G6bH201PL9`0801/O:00L82T05a/T01@I7`0G72806AhT01dR:00K82H301TN900P01HK8@0X;C<0
9R/a01XO9@0;41H0314G01dR:00G5b4061PT01`L:00L72H06a/U01PH8@0A4AT06a/R01@E6P0F5a`0
4A8G014B5P0G61X09RLZ01TJ7P0F5a`05AHL01TJ7`0G61d05QLJ01DG5P0D5Q<04aD@018D4@0F5QH5
01HF600=01<C5@0F5QP06ATK01HF600C4aD06ATK01HF5P0B4Q805QHF01LG5`0P82005ADE01LG5`03
01DE5@03018B4P0?3`l05ADG008051<H02h05A@J01HE7@0F5Ad071/S024P9P0a<3H051<H00h>400H
61X03PlC01HE6P0I61d06QTN01PF6`0T8RL05Q@I01/F700I51X05A0F01LB600I51X0;R`_00/9300?
3A006QPK01HA5@0B3A406Q@H01@>4P0L5QX04`X?01D<4@0>2Pd03@/>01<A500=2`h05Q@G018=4@0;
1`X04@/?00L11@0?20`06A0E01893P0D31006A<E0P0C3@l0800E3a404P`>01<=3`0J51H03PP:00X4
1P0=1`T0618D00/5200=1Pd03PL>00l83`0@2A004@XA00h73P0G41L03@H=00X32P0;10/08Q/R01XA
6@0B1Q0040@@01D95`0T62H08aLU04m3D@0V6RH02`8901H;4@0>0`L020010P0@1@/200l42P0?0146
300C20h04`P>00h32@0E2Q00304700T0100?1PX04@H<00T0100<0`L0304701T>500<0`L03`@:0080
3P<901/04@H<01873@0A1P`050PB00L01@0C210050TA00l42`0700802@0401@93P0H3A404@H:00T0
0P0800006P/>00/0000W5aX03@00020@4`0?00804@4401@41`0E1@P04`<601821@0C0`H05?ooool0
01_ooooo00L06aPC018?2`0<2@@05Q<>018?2P0<2@@04Pl:008040d800<04Pl:01<@2`0A3PT00P0B
3P/04P0A3@X040`9010<2@0?2`P030P501HB3`0E4@h02`L400d91P0B3P/03`/800X60`0810404Ph;
010<2@0E4@h04`l<018>2`8040`901404`l<01HB3`0;2PH02`X600h=2@0D4`l061LC01@C3`0;2PH0
1@@0014@300D4`l02PT501LF4P0@3`/02`X600l>2P02014@300C01<B3P0G5Q803Pd900T8100A40`0
2@P401<B3@0>3PH05A@?014@3@010000;2X[01TG601mNg`0BDQ600l>2`0F5A0010<001<B2`0200d:
1@803P/600@03``700d:1@0=2PD040d80P0B3`X04`0C40/0510<010<2@0G4a005Q8?018>2`0E4@h0
510=00h:1`0D40d03`/800X60`0A3@X03@X5018?200@3@H040d801<@2`0?30L00P0H5140100B3Pd0
3@T800l;2P0?2`X2010?2`0400l>2P0=30P03Pd9010?2`803Pd90`0=30P00`0>3@T04@/;018<3002
014=300J010<2`0=30X03Pd;00T81P092@L02`/900X:200>3``03Q0=00D:1P0>40d0418?00P91P0H
61H0410>00X91`0=30X040l=014?3@0D40l03`T9014<2`0@3Pl0410@00h?4P0:3Q4200lC5P803a0B
00X03`l@00l=3P092@T03Ph>00/;2`0=3@d04A4A00`<300820P0410@0P0<30`0200:2PX0EeMG02<R
800@3`d03Pd;014@3P0<2`T040l=1P0=30X01P0C4Q004Q4?00/:200=30X05A@B00l>308040l=00P0
3Pd;00`;2@0=30X03`h<00/:200<2`T03@`:010?3@804A0>00L030/900H50`0/:bT05A@C00`;2@0:
2@L04Ph=00804@d<00T040`;00l;2P0>2PT030P700T5100>2PT05A4@01@@3`0?3@/00P0?3P`0300<
2`T02@P600/:200@3`d04Q4?00T81P081`D02@P600l>300U9280`;nm05ACD@803`h<00P06aXH00D4
0`0<2`T03@`:00X91`0=30X030/900`91`803`/800l03PX700`81@0=2@H03`/8014=2P0B3P/040`9
00l;200@30T03@L700h8200?2@T04@/;018<300C3@d00`0A2`/2010:2P0=00l92@0>2PT040`;00h:
2@0C3`h03@T800h:2@0F4Q406QHE014=300@30/06aLF01DA400300l;300G00h:2`0?2``04Ph?00l;
300B3Pl05Q8C01LC500H51D03``=00d<2P0A4@l07alM00P8200R8B<03@/>010>4@0?2`l03`X>014<
400D3Q804`d?010:2P0?2`T00P0>2PT0:00?30`03P`=01@B4`0?3Pl03Ph@00d=3`0;2Ph03PdB0040
0P0G5AP01083010>3`0?3P`010<100`;2@0=30/03@/<00h<3@0?3@l03`dB010=500B41H05A<H00T7
300D4QD04@lB00/:300H5QL0?cdn00X82@091`P02`/;00d>400F5aT0004300410`0Q7b808b4T01<A
500H4aL200l:3P0800`72`0=20`02`H:00h93@0C3Q805Q4E00d830070PH2010;3`0G00l:3P0>2@d0
30L;00`72`0D4Q<01`D600X82@0E4a@04@l@00/92P0<2P/03`d>018@4@0?3@h030X;00d;3@0@3Q40
1@<601LE600^;2l0:2HY010>4@0<2Pd00P0;2@`06P0<2Pd03@/>00/82P060P<04@d>00`82@0H51D0
2@D601<?40070`@00`0001@@4@070`@04@d>00h:300?2Ph04`hB02@O8`0J5AT02`H:014<400[9RX0
<2/_00`72`0500@04PdA0P0@2Ph3010;3`0L00l=400H5QT02`T<00T92`0G5aT02PX<00L72@0Q7Ah0
0`0003lk?02h];D0;RX[00d92P0U8B80<Rh_02<O800>2P/00`0001hJ6`0:20T071XK00P71`0E4a@0
6aTJ00`:2`0@3Pl00@0001HD5@803P`=00X02PP9014?400@3Pl03`d>010>3`0C4A80518C01lM7P05
10@01P@50P0A3a003@0D4Q<03`d>014?400@3Pl03P`=00l=3P0A3a0020H700T7200D4Q<040h?00`:
2`0L6Q/01P0?3P`03`0>3@/03@`:00/:200:2@L05A@B010?3@0A3a006QPI01PF5`0F51D00`4200l=
3P0=2``03P`=00l=3P02010>3`07014?400@3Pl03`d>00h<3@0@3Pl04Q0A01<A4P06018@4@0E00l?
3@0A4@l0410>010@400C4aD05ADG01HF600F5AX05A@I01@C600E51T05QDJ01TI7@0A4QH05QLK01TJ
7P0B4aL04A8F01HG6`0E5QX051DI00805AHJ00<05QLJ01DF600E5QP00`0F5aT03@0H6A/06AXL01PI
6`0H6A/06AXL01XK7@0I6ad05QXK01LK700H71d05QXK01DI700H6al00P0H6b00;P0I72804aHM01DH
7`0H6b4061/P01LJ7`0C5Q/05APM01HI7P0H6b0051LL01/N8`0F6Ah05aXO01LJ800N8R/0720Y01LK
9@0A5Ah041@M01<G800E6B805a/T01<G800B5ad06AhT01`Q9`0O92X08BH/01/P9P0H7B<07R<Y01DJ
80083A<04AHL01/P9P0F6b4051TO01HK8@0F5R005aLQ01/K9@0L72H06QXT01LG7`0I6B4201XK800@
00h?4`0P8BD030dA01<D5P0d=SH08B8T014B5P0;31007AhS01PI7P0G61/05QPG01DG500D5Q404aD@
01@D50D051@F00`05QHH01PH6P0K6ad05QHH014A4`0H61X09RHV01@D500E5AD04Q8B01DE5@0>3Ph3
01DE5@1101HF5P0B4Q80410@01DE600E51T05QDJ01PG7@0J6Al06aXP01hM8`0P7bD0A4=9020O9009
20d07QdR01XK7`0;31006AXN02//<00Q82D02PT>014?500D4QL05Q@I01XE6`0K5Q`071LM01`J7@0G
5AP05A<F01TG6P0I51P050lC00l93@0I4aL06aDI01483@0H3a@08A`P00400P0L6Qd03P`?01HD5`0G
4QH05Q4E01LA5@0D3Q807aLL02DL8@0J4AH04@X=010:300=1`T04@/=01H@4P0E3a405Q0B01PB5004
0000:R@V00T31@0J51H03@L:00h8300?2@d00`0A2`l0500<1PX071HJ00L11@0D3Q806A<G00P21P0>
1@/04PL?01<74@0A1A403`<?01@85P0^8Rh050PD00T01P0E2Q005P/?01L<400?10X040D;0P0A1P`0
4P0?10X03P<90146300?10X04PL=00T0100@1@/07A8H00h32@0C20h050T?00L00P0;00H05``B0146
300?10X03@88014630804`P>01<0710J00L01@0@1Pd04`P@01<83`0B1`d03P<900d31`0900802001
00h41`0F2Ph02P0001`=4P0H2@h070dB01T<3`0B0`P04@87008050D:00<04`@90183200C10T05?oo
ool001_ooooo00L03@X8014>2P0D40`05a@@00l<2@0<2@D030P40080514=00@05a<?01<?2`0>2`L0
4Ph;0P0A3@X2018>2`0>010<2@0C3``040`9014=2P0B3P/03`/8010<2@0B3P/04@d:00l;200B3P/0
3`/8014=2P0@30T2018>2`0@01<?300F4Pl06ADB010?2`0>3@T040l;018A3@0D4`l04A0<018A3@0@
3`/02`X601@C3`0B4@d03Pd9018A3@8030/702@03@`800h=2@0?3PX0;bhZ01hM6@0=30P03Pd900X9
1`0B4P/04A4900d<1`0@3`X05aHC00/92@0>3@`07QdK01XI5`0=30L02`X500l?1`0>3@H04Pl:01@A
300B3`X0514<01DB3@0A3PT04a0;01@A300@3@P04Pl:01<@2`0@3@T02`L400`81@0>2PL201<?3009
018>2`0=2@H040`9018>2`0>2PL05A4>01<@2`0A3PL04a0900804Pl:00/04@h9010<2@0B3P/040`;
00h:2@0:1PD0510?00l>2P0B4@d040l;00/:1P0200h=2@0600l>2P0@3`/03Pd900d<200?3PX040l;
0P0B30`09`0A3@`040`;014=300?3P`04A0>00d<2P0?3`d06ATG018B400<3@/02@/800lD400V:2D0
418?01HG500=3@/04A4?00/:200<2`T03`h<014?3@0B3Pd03PX700l=2P0<30X0410B00d?4P0;41<0
3A8G00lF6P083A005AXM00d@4@0;30d02`/;00l?3`0<30`02`/;00d=3@0200`<300?00/;2`0C4a<0
>CTi08B4Q00E5AD03@`:00`;2@0B4@l04a8@00d<2P0>3@/040l=00`;2@0=30X03Pd;00803@`:00H0
3Pd;01<B400=30X03Pd;00`;2@061@@300h=2`0300d<2P0>3@/03Pd;00803`h<00`04Q4?00l>300<
2`T03Pd;00d<2P0F5A<0>CPf028Q7`0@3`d05A@B01PD4`0B3Pd3010<2`803`/:01<0510?010<2`0@
30/03`/:00`9200<2`T03Pd;00`;2@0;2PP03@`:00h=2`081`H05QDC010?3@0:2@P030/900d<2P0I
61H03`h<008030/902@02PT700l>300<2`T04A0>00/:2@0?3P`030/900h;2@0>2PL030P500l;200B
3P/03`/800/7100B3P/03@T600`81P0?2`P03PX700X51@0J5AD03@P801<>3P0A30/07APG00X51@0B
3@`03PT800`71`0E40l03PT800l;2P0A3@`03@T801@@3`0A3@`200l;2P0R010<2`0A3@`03PX900h:
2@0B3Pd030P9010<3@0=2@X05Q8C00d92P0@30d03`/<014=3P0I5AH04@d>00P41@0@3@h03`h<014A
3P0F5a<00P<0010@3`0A40l040h>014>400?2`d040/?01<>4P0@2Pd030H6018>300>2PT05a<B00`9
2P8040h?00`03@`=01@D5P0P82804Q4E00L72P0>30h03@/<00l=3P0@3Pl03`d>00h=300?3@l300l=
3P04010>3`0@3Q002@L<00/83P8030X?01D04Q0C00L5200B41<0:bTZ03dk?00E4a@02`T:014?400=
3Q0030`>00T92`0B4A<02PP;00l=400@3A004@`@010;3`0C3A4050lC028L800B3A400P0=20`03`0;
1`X03@P<018=4@0C3Q803`X>014<400D3a<03`X>00`72`0;2@X030X;018@4@0;2@X03P`=010>3`02
00/92P0500d;300;2@X03`d>01TG6@0N71l00P0;2@`04@0=2`h03P`?00/9300<2Pd03@/>00X82`0<
2Pd03`d@014>400A3@h0510A00`82@0B3Pl02@D600X61`0E4A804@d>00803`/<034040`=014=3`0A
31003@P<01<>4P0>2@d030L;01D@500I51P05A0D00l:3P0B3A403PT=010:3P0A2`l03`X>00h93@0A
31003`d@018@4`0>30l03`lA00X:300B4Q@030`>00/8200G4a@03`/<024M7P0>2P/04`l@00/7200D
41403`/<01@@4@0>2`/05A4B010>3`0>30d03`d>00`:2`091`P03`d>010>3`091`P06QPI01PF5`0<
2P/04Q0A008040h?0P0?3@h2010>3`0400/92P0A3a004a4B014?40<03`d>00<04Q0A014?400?3@h0
0P0<2P/03@0H5QL0518C010>3`0A3a002`T:010>3`0=30X03Pd;00d<2P0?3P`04Q4?00h=2`0<2`T0
0P0B4@l020061@@05aHD03He<`0A3a004a4B00d;300C4A803P`=0P0A3a02018@4@804a4B01L0518C
018@4@0A3a0040h?018@4@0C4A80518C014?400C4A805A<D01<A4P0B41405Q@E018B4@0I6AP07AdL
00l?400K6ad04A4C01HF6@0I61d05aHK01DD6@0201DD6P804a@H00d04A8F01<D600J6al06a`P01DF
6P0I6Qh05QLK01TJ7P0H6Ad05AHI01@E5`0F5aT061TK00806AXL01L061TK01DF600J6ad08b@V01TJ
700L7Al05aTK01@H6@0E6AX061`M01TM7P0G6ah06A`P01TL8@0J7B806A`R01DH7`0G6R405aXP01LJ
7`0H6b004aHK01HI7P0201XM8P0H01LJ7`0I72405APM01LJ7`0K7R<06b0V01XN9P0G72<05ATQ01HK
8P0M8BT04ADM01hR:P0G72<06QlV02T]=@1>DeX06QhU01/O900D61h06alT02HZ<00J7R@06alT0P0F
6Ql05`0K7bD06alT01DI7`0F5R006ATS01dM9P0H62406ATQ01DE700L7B803a0D01LH700D5AT0;c0d
01LH6P0I6Q`06a`M01LH6P0I6Qh061TN01DF6`0E5QX05QLI00805ALD00@05QPB01HH4`0F5QH051@F
0P0G5aT02`0D51H06ATK01PH6P0H61X06a/M01LG6@0C4aD06ATK028R8P0F5QH061PH00806ATI00<0
61PH018B4P0D51@00P0E5AD201@D500901HE6P0H5a`06aXO01dL800N7B8081lS01TH700H5a`05aHK
008061LL00P03`hC01@E6@0G6Ad04Q@H02<T:00E5AX04A4E01HD6@805A<H00D05Q8H01DB5`0E4AL0
5Q@G010>4@0201HD5`0E01<>4P0J5AT05a4E01TC5`0D3Q805@`A01T@5@0@2Ph07A/N00d;3P0E4aH0
20H9018=4@0F41@0;RP/01<=4@0A2Ph05@`A01P?500B2`h04`d?00804@/=00T040X<00h82P0?2@/0
3`T;00h82P14?T0050h@01<=3`0A2`h00P0?2@d05`0E3a<03PP<014;3`0@2Ph0208601@>4P0=1`/0
4`dA01PB5P0;0`T0<bP`0187400P52004@DA01864`0>0Ph040@>01<73`0?10X03P<701061`0@1@T0
4@H<00804`P>00P04PL=01052`0B1`d04@H<00l42P0<0PL060dC02HK8@<04`P>00L03@8801052`0<
0PL04@H<01052`0>0`T040D;00804PL=01P04PH@01@84P0>10/03`@<00h42P0>0`T03`@:00l42@0?
10P040D900l4200:0@<040@801852@0=0P@05@L<01041`0E1``04@@800l21P0F2@d040<700l31P0A
0`PDooooo`006oooool0100?2`P03PX700d91P0>2PL3010<2@0800L30@0@30T03@T600X60`0H5140
4Ph;010<2@0?2`P2014=2P0400h:1`0B3P/04@d:010<2@803`/800L040`9018>2`0>2PL03PX7018>
2`0A3@X03`/800H04@d:00P03@`800l>2P0=30P02`X600X91@0;2PH03Pd900l>2P8040l;00<03`h:
00h=2@0A40`00P0=30P03@0?3PX040l;00l>2P0G5Q802`X600@3000<2`L03Pd900P80P0:2P003Ph6
010?2`0?3PX00P0<2`T03`0>3@/03Pd900h=2@0>3PH03Ph4014?200A3PT03``700/80`0<2@@04a0;
014>2@0=2PD03``700h;1P02014>2@07010<200?2`P03`/801<?300F4Pl05A4>018>2`0200T50P04
01DA3P0@30T03@T6014>2@804@h70`0B3`X02@0>2PL04Ph;01@@3`0D40l01P8101<?3P0B4@d020L3
00d<200201DD400700X91@0C4Ph05A@@014@300=30P03`h:00d<200201@>3P0U018>3@0@30/040`;
00h=2`0:2@L051<A01<C4@0?3`d02@T7018C400A4a0000<003Li=P082PL030d;014A3`0?3`d03@`:
00`;2@0=30X03`d;010<2@0=2PD03`d800P81P0?41802@dB00XA5`042a408bX`00hE6`0?5aX010X;
00@82@0<3Pd0410@00l?3`0200`<300900h>3P071`L03Ph>00d=3@0B4Q806QXJ0000000=30X03`h<
00@040l=00H051<A00d<2P0?3P`03Pd;00`;2@0>3@/200d<2P0500X91`0<2`T03@`:00/:200>3@/0
0P0=30X09@0>3@/03`h<00l>300?3P`03Pd;018A3`0?3P`02PT700d<2P0>3@/051<A018A3`0>3@/0
4A0>01LF500E4A003PX900`81`0?2`X040`;00l;2P0<20L040`;01HB4@0C3`h040`;00h;2P0>3@/0
3`h<00d<2P0;2PP03@`:01@C4@0=30X030/900T81P061@<00P0?3P`200/:200<00`;2@0=30X03@`:
018A3`0100004a8@04M6A00l>cT061LE00L50`0A3@X04`l<0P0@30T04`0?2`P030P5010<2@0C3``0
6aLD01PD4@0<20D05a<B00<0000M6AP02PH503Hb<@1;AdH0510?010<2`0;20L01P8100/71P0A3@`0
0P0D40l200l;2P0d01LC4P0I5A@02PH500d9200?2`X03PX900d9200>2PT03`/<01@@4@091@H0510A
00H20`0@30d03@T:01HB4`0N6Q/0510A00h:2`0A3Ph051<?00l@2P0E5Q002``6010@2`0<2`H03Pd9
01<A3`0@30d03`/<014;4@0<1PX03@L7010<2P0?2`X04Ph=01HC4`0>30d08b4R01DD5@1bLW@0^[Zl
04e<D00M7Al040h?00l=3@0>30d03@/<00d;3@0=2`h03`d@00h<3`803@/<00@03Pd;00l=3P0<2Pl0
3`dC0P0C4AH03`0>30l040hA01<A500@3Pl0518C00X82@0D4Q<0:RPY034a<`0@418030`>00d;3P0:
20/03P`?00h93@02018=4@8040X>02/04@/?01@?4`0?2Ph03PT=01PC5`0K5QX05Q4E00D0100G4QH0
6QDI01LB5P0M61`09b8V00d;30071@H03P`=00/92P0C4A802PP900/92P0?3@h05Q@E010>3`0<2P/0
5Q@F01<A500<2Pd03P`?00T72P0:20/040hA018@4`0A3a802`T<00`:3@0>30l03``>014=3P0@30d0
3`/<00h:2`0=2@X03PX;00804@d>01h03`/<014=3P0D414050lB01@?4`0G4QH05Q4E00h93@0=20`0
4@`@00h93@0?2Ph04PdA00h93@0?2Ph04P`@01D?4`0@2`l02`H:00l:3P0@3Q40<c4d08N5R00@4180
0`<500h>40092@/03@T:00`82@0=2@X200h:2`0E00/7200A3@h04@d>010<3@0A3@h040`=01<?400>
30d03@/<00l=3P0C4A805A<D01<A4P0B41403P`=01PF5`0>30d040h?01<A4P0>30d03`d>008040h?
00<03`d>00h<3@0>30d01@0>30d2014?40<040h?00<03`d>010>3`0>30d00P0=2``02P0?3@h040h?
00d<2P0@3`d03`h<018A3`0F5A<04Q4?01LF500;2PP2014@3P0800h=2`0O7Q`040h?00h<3@0@3Pl0
4a4B010>3`0>30d6018@4@0401<A4P0B41404Q0A018@4@804a4B01h04Q0A01<A4P0G5AH05A<D01<A
4P0G5aL06QXJ00/;2`0A4A40?Si001@D5P0K6ad040lD014@5@0B4AH05A@J01HE6`0D5AX0414E020Q
9@0I6Qh06Q/O01LH700:2`l06Q/O01HG6`0N7b<03PlC01<D600N7b8201TJ700H01PI6`0G61X05aPJ
01LH6P061`T07AhP01HG6@0=3Q005aPJ01PK700E6AX05QXK01PL7@0J7Ql061`O01PL800K7R<071lT
01TL8P0E61l05QTP01HI7`0E61d05aXO0P0I724201PK800501TL8@0J7B8061/P01TL8@0L7b@00P0F
6al04P0F6b405a`R01PM8`0J7bD05AXP020U:`0A5Q`05ATR028V;`0c=cl06QdT01/N8`0H6b006A`Q
01hQ9P0I72406QdR01LJ7`806A`Q01/04aHK01@G700I6B407AdW038b>P0W9bl071`T01PI7P0I6Ql0
5AHK01LH700K720071dQ01PI6`0D5AL04Q<D01@E5`0>3a<04Q<H01DF6`0D5AX05QLJ01DG5P0D5Q<0
51HA01<E400M7Ad00P0G5aT00`0C4aD05QHH018B500201DE5`0E01PH6P0F5QP051@F01XJ700E5AD0
5QHF01TI6@0K6a/06QXJ01LG5`0D51@05aLG01HF5P0B4Q804A4A018B4P0E51P05A@I01PH6P0K6a`0
6a/K008071`L00`030`<01LG6@0A4A@081lT028S9`0D5QX020`?010D5`0P8BD0414E01HG6`0D4aP2
018@5@0:01HD6@0L6Ql07adR01hL7`0D4QD05aDH01HD5`0<1`/05A0D01LA5@805Q0D01@05PdB01<:
3`0B3A404a4D018@4`030P@020H901LB5P0J51P0>cDi018<400B2Pl03`H;01XA5P0A2@d040X<014;
3@0C3@l04P`>014;3@8040X<01d04P`>01@>400B30h04@/=010:3@0=1`/03PP<014;3`0E3a<04`dA
01hH700=1`/02`D900d72`0;1@T01002020H7P2n/k/0>2le00X0200N4Qh04PHB01454@0A1@l04@H=
01052@0@1PL040H601052@0201052`0300l42P0>0`T03P<901803`@:0P0?0`d200l4300400l42`0?
10X03@8800d21`8030450P0>0`L600l31`0600P0000A1@T020000104200C1`/0A3Pl5?ooool001_o
oooo00l04@d<01<?3P0?2`X030P701<?3P0P71/0GUYI01HB4@0J5QD06aLF00l;2`070`804`l<010<
2@0?2`P00P0@30T0100=2@H04Ph;014=2P0A3@X2010<2@0700l;200A3@X03`/8010<2@0B3P/040`9
00l;2006014=2P0701@C3`0L6aL05A@@010?2`0B4@d03Pd900l>2P03010?2`0E00h=2@0=30P03`h:
00d<200>3@T040l;00l>2P0>3@T05QDA014@300;2PH05A@@01HE4@0@3`T03Ph4018B2P0B4@`04A0<
01<B400B4@l03Pd;00803Pd901<03Ph600h>100A3`P03@X500`9100@3@P02`P300h;1P0B3`X040d8
018?2P0A3PT0514<01<@2`0B3PX04Ph;014=2P0C3``05A4>0080510=01<040`901<?300S7a`07ATF
01DA3P0@3@P03``5010=1P0A3PT04Pl:01<@2`0A3@X0510=00h:2@0B3Pd03`/:01LC4P0G5Q803@`8
008030/700D051<?00l>2P0H5a<06APD01@C3`0200h=2@0a00/:1P0D3Ph050h>01<?3P0A3@`040`;
00`;2@0;2PP04a8@014A3`0D51803Ph<00@50`0B51407R<O01HH5@0h>SL0?d0n00h>300=3@/03`h<
00h=2`0=30X03`d;018>2`0=2P<03`d700P81P0>3a402PlC00dD700D6b<0GVM^04I?E00I8bD031DE
014G5`0=3`h0410@00l?3`0>3Ph03@d=00l?3`0>3Ph04A4A00P820010@402`/;01`L7002010?3@07
00l>300@3`d04A0>018A3`0@3`d03Pd;00l>300200d<2P0?01<B400?3P`040l=00`;2@0?3P`04A0>
00h=2`0?3P`030/900X91`0;2PP03@`:00l>300>3@/02`X800803Pd;00T030/900d<2P0?3P`03Pd;
00`;2@0:2@L03@`:014@3P0?2`X00P0<20L200l;2P0D00h:2@0=2@P03`/:018>3@0D40l040`;00/9
1`0>3@/040l=00h=2`0=30X03Pd;00`;2@0920H02PT701HE4`0B4@l010<100H5100:2@L200/:2080
30/901h03`h<00@30@0?3P`0A4=1034`;P0B4@l030T701DA3P0K5a@04Ph;00d91P0@30T04@d:00`8
1@0G4a00920M01PD4@0?2`P04Q4?00X91`0i>3H020L501PG5@0H5aH02`X800X91`0A40h03`h<018A
3`0G5Q@2014=308030P70P0B3Pd00`091@@02`L600h:2@0200d9200]00h:2@0>2P/0510A00d92P0D
41402@D601PD5@0=2@X0510A01/G600C3a003PX;010>3@0?3PT03@h701`M5@0G6@h061T?01lO5@0;
2`<04Q0<014=300?2``040X@00d72`0G4A403`/9018>3@0300005a@D00@20`0@3Pl05A@E0:JVZ03o
ool0GeiR00`<3P0A40h03`h;00`:2`0;2@X03P`@010>4`0>31403@/>008030X;00X03@`:00h=2`0C
4AH02@L=00H42@081P/03P`?01<A500>30l02PP90P0;2@X02@0?3@h05Q@E01@D50040P<01@<4010>
3`0=2@X0100100h:2`02018<3P0D010:300A20/040X<00h93@0=20`03PT=01LB5P0J5AT05A0D00l:
3P0A31003PT=00d8300910P02`H:010>3`071@H03P`=00`:2`0?3@h200`:2`0:018@4@0H5QL04@l@
00/92P0:20X020H900/9300A3a802@L:00X82`8040hA00`03P`?00X82`0=2`h030X=00d:300A3@`0
40`;00l;2P0>2PT03@T800l;2P0>2PT200d9200900/71P0?2`X03`X=010;3`0G4QH04`hB00l:3P0@
2`l04PdA00802PD901@040/?00/62P0=20`040X>018<400=20`020<700/62P0<2Pd06ALJ07ajO@0<
30h020P:00d=3`0:2P`03PX;00l;300A3@h040`=00l;308040`=00D030P900l;300?2``06ADF00h:
2`0200/92P0<00d;300A3a004a4B014?400E4a@04Q0A00h<3@071@H05A<D00/92P0>30d03`d>0P0@
3Pl00`0?3@h03P`=00h<3@0500h<3@804Q0C0`0A3a800`0@3Q404@lB01@B5@0200d;3P04014?4P0=
2``03@`:01<B40804A0>00h05QDC01DD4P0D4a402`X8010?3@0F5A<04A0>00P71@0A3a003`d>010>
3`0B414040h?00h<3@H04Q0A00<04Q8B014A4@0@41000P0A4A400`0B4Q8051@D018B4P0201HF5P0?
01@D500E5AD06Q/K02@U9`18BD/0OGj0018C5`0;31004A8F00h?500A4QL05QLL01LG7`0F5a`071lR
00804aLJ01803Q8E014E600L82<06QhQ01@H6`0W:bh03Q8E01`P8`0K7b80720S01XN8@0F6Qd051PK
01<G6P0L82<01PX=01XN8@0E6A`2024U:00B01TM7`0F6Q/05QXK01PL7@0J7Ql061`O01PK7`0K7R<0
71lT01XM8`0E61l04aHM01HI7`0H6b006A`Q01XM8P0I724061/P0P0K7R<05@0M82D07R4V01dP9@0J
7B8051TM01@I700D6Ad05AXN01HK7`0H7B406AhT01@I7`0N8bT0720Y01XN9`0B5A`05APO01`M8P0J
6b004a@I01@E6P0201TJ7`0901/L8@0N7b@05aPM01<D6@0K72405QHN01LG7`0`<3P09RL/00804a@I
00<04A8F01@E6@0F5a/00P0G61X01P0E5QP04a@F01<D5`0A4QH0414F01DE70805AHK00X05AHI01HH
5`0E5a@051HA01<E4P0A4A4051@F01HF60092@/05aLI0P0E5AL04@0D51H05QHH01DE5`0C4aD06ATK
01DE5@0F5QH061PH01/K6`0J6QX05aLG01PH600J6QX061PH01@D500B4Q804a<C00804a<E014051@D
01`L6P0O81/071dH01XK5P0B4Q00:b/Y018B4`0C4aD04Q<E018E600K7b807b<V038f>@0^;c<06AXN
01DF6P0201<B5`0301LF6`0O7B808b4V00805aDH00D040hA01@B5@0?2Ph061<G01LA5@0201H@500A
01H=4P0D2a003@P<00h<3`0N71l061HI01@B5@0H4aL03`T=02/U:@0>20`04PX?00X11P0D2a004PX>
010:300A2`d00P0C3@l2018<3P<04@/=0P0@2P`04P0?2@/040X<01TC5@0>20X04`d?00@0000910D0
1P02014;3@0>20X04P`>00D00@0F3Q80>Rle01X?5`0E2A<050PB01P<60804`LA00X04PL>01462P0A
1`P040H600h31`0?10X04@H<01052`0?10X03P<94P0?10X200l33@803`@<00P03`@;00l42P0;00H0
2`0500/0100<0@D03P<700l420H03`8900H07a8I01062P0G2Q402`0501@73P0H2a8Dooooo`006ooo
ool04`0D40l05A4@010<2`0>2PT05A4@01hJ6@1RGUd071PH01<?3P091PD04`l>014=300E4@h04`l<
018>2`0C3``04Ph;010<2@0A3@X00`0B3P/0100@30T03`/8010<2@0B3P/201<?308040`91P0A3@X0
1`0;2PH04Q4=00/:1P0C4Ph05A@@00P70`0A40`00P0@3`/04`0?3PX03Pd900h=2@0>3@T03@`800h=
2@0@3`/03Pd900`;1`0A40`03`h:01@C3`0<2`P02PT500l?200B4PP04A4900/;100?3PT00P0I61D2
00h=2@0A00h>1`0>3PH03Ph4010>1P0=2PD05A8=02@Q700E4Pd03@X500l<1`0A3PT04a0;014>2@0D
4@`04a0;00l<200@30T01@0?2`P01P0:1P<02@D201@@3@0C3``03@T600d:1@8040d60`0@3@P0500<
20D05A4>00l;2P0B3Pd04`l>018>3@0A40`01`H301<B3P0;2PL05aHB014@300E51005aHB018A3@0=
30P03Pd900`;1`0A2`/04P`<0P0C3`h0100B3Pd03`h<018A3`0?3P`200d=2`0700L71P0Y:RP0?3dk
00lD400;3@X0?T0m04A5@P0200`<2P804A0>01003Pd;00l=2`0D40d03``4010>1`071`@03@h@00hD
6P0J8b`0CEIP0=OOi`3@f^00GFM/020[;00A61P0418A0P0@410300l?3`08038b<P0l?3`05ADE00@4
100B4Q802`/;014@3P0@3`d200h=2`0800l>300A40h030/900h=2`0?3P`030/900l>300F5A<2014@
3P0600d<2P0>3@/03`h<00`;2@0@3`d03`h<0P0>3@/200d<2P03010?3@0=30X03@`:008040l=00L0
3`h<00`;2@0:2@L02`X800h=2`0=30X030/900@03`/:00P03@T800`81`0B3Pd04@d<00`81`0A3@`0
4Ph=00l<2`D03@`:00L03Pd;00`;2@0C4Q003@`:00P71P0C4Q003`h<00D03@`:00/030/9014@3P06
1@<040l=00X91`0>3@/02`T701DA3P0I5A804Ph;00h:1`02010<2@0J00d91P0:1P@05Q8?00d91P0A
3@X020L5010?3@0S8R002PT800/:200=30X020L501<B400@3`d020L5010?3@0;2PP05A4@01<?3P0A
3@`03`/:00h:2@091@@030P700h:2@0@30/200l;2P0]014=300?2``05Q8C01TE5P0E4A802PH701@@
4@0<20T040`=01<?400@30d03PX;00l=300B4PT05QP;01TK300W:AX0<C<T01TJ300C4`L04a8901@A
3@0D40h050lA01@>4@0D3Ph04@`:01HB4@0?2`X03``<018@4@0H5QL04Q4B03De=`1FEUP0:2L[014A
4`0>3@/03Pd:00h=2`0>30l03P`@00h<4@0?3A803`dA00803@/<01D03`h;00l>30091``03``B00d;
400>31404a4D00L5200>30l04@l@00h<3@0?3@h03P`=00T8200:2@T030X;00X82@0G51D06ADF00h:
2`0A30d00P0A2`d07`0C2`h04`X=018<3P0>2@d040/?00h93@0B3A404@`@00`72`0>2@d05a8F00d8
300A31003PT=018=4@0=2``02`T:00h<3@0=2``030X;018@4@0>30d02`T:00`:2`091`P030X;010>
400:20/01`D800h<3`0@3Q400P0>30l01P0=2`h02`T<00l=400I5aX05Q@G010=3P8040`;0P0?2`X0
4@0>2PT04@d<010<2`0@30/04@d<00`81`0=2@P03`X<010;3`0A31003`X>01<>4P0D3a<040/?01D@
500C3Q803`X>008040/?02H04`dA014;3`0>2@d05A0D01XE6@0>30l04@lB00L6200?3a4030`>00l?
4@0=3@l03PX;018>3`0E4A804Ph?014=3P0D41404`l@00P41@0@30d04Ph?01PD5@0G4a@06QPI01HD
5@0@3Pl03P`=00l=3P0@3Pl04@l@00/92P0A3a003P`=00l=3P071@H03P`=00l=3P8040h?00<03`d>
00h<3@0?3@h01@0?3@h7010>4@0B018@4`0F51L04Q0C00l=400H5QL03`d>01DD4P0@3`d030/900l>
300@3`d03@`:01DD4P0A40h03@`:014@3P0C4Q004@l@0`0B4142014?40H04a4B00<04Q8B014A4@0@
41000P0A4A40=`0B4Q805QHF018B4P0D51@05aLG01@D500@410061XJ00/<3P0G61X05AHI010A5@0G
61`05AHJ01@E6P0H6Ah05aPN01HF7P0J6b007R4U01TM800B5QT06QhQ01lS9P0F6Qd01PX=01hR9@0C
5aX03Q8E01`P8`0J7R406alR01PL7`0D61/04aLJ01@H6`0C5aX09RX]01lS9P0K7b805ATL01HJ7@0F
6Q`05a/L01HJ6`0H71d06QhO01XN8@0H72006A`Q01/N8`0L7bD06A`S01LJ8@0H6b400`0I724201LJ
7`0701hQ9P0K7R<06A`Q01/N8`0L7b@061/P01HK7P0201DK700i01HK7P0G71l061dQ01lT:P0?51X0
>3e3024U;P0C5b006AdU01XK800K720061TN01<D600B4aL05aPM01DF6P0F5a`06AXN01/L800M7R<0
92DY01`L900D51`061PO01XK800R8bP06Q/P018C5`0F5aX05AHI018C5@0E5QP06a`N01@E600E5Q/0
4Q<I01/K8P0E5Ah04A4J01@D7@0@4AH051DH01LH6@0E5aD05QPF01PH6@0G5aT07QhP00d=3`0D51H0
820R01PH6P0F5QP05aLI01DE5`0D51H06a/M00804a<C00D05ADE01LG5`0H61P05ADE01LG5`0201XJ
6P<061PH03005aLG01XJ6@0K6aP07R0H02HW7`0Y:R407b4G01lP6@1VIf00:b/Y00l?3P0Q8R<05QXM
00T>4@0Q9RT0][Zm0:na]@0W:Rd05aPL01LF6`0F5AX05A@I01HD6@0F5AX05aDH038`<`0D4QD05Q@G
01TD600F4AD05Q0D01LA5@0F41@060lD01D<4@0H4QH040hA00l=400N71l0518E010;3`0A31006A<G
00d72`0E3A802P4601483@0D3A02014;3@06018<3P0C3@l04`d?01@>400B30h040X<0P0?2@/02@0@
2P`04P`>00X41P0D3Q0030H801dG6@0E4140O7Ih03Xd=P0200l92`0D01D?4@0A2`d03`L;0148300C
2@l07Q8L02`P:P0I3AP05@TC01@94@0D2@l04PL;0147200@1PH03`@801052`0C20h050T?01873@0@
1@/B00l42P803`<=0P0?10`01P0?10/03`@:01052`0?10T03P<700d21P803P<71P0?0`T01P0@10X0
5``A01L;4P15>cl0<RP]02/O9ACooooo000Kooooo`0=01<?3P0?2`X03PX9010<2`0A3@`03PX900l;
2P0<20P02`L600<0000E4A005Q8A014=2P0200l;20804@d:00P03`/8014=2P0C3``0510=01<?300@
30T03`/8014=2P804`l<00<04Ph;014=2P0B3P/01P0A3@X00`0C4Ph04A0<018A3@02024P700301DD
400A40`03`h:00803Pd90P0?3PX04@0>3@T030/700`;1`0?3PX03Pd900`;1`0A40`03@`802h]:@0]
;2P06APD00`;100@40@04Q8800l>200:2@@02`X600803Pd900h03Pd800h>1`0>3P@03Ph2010?1P0=
2PD03``701PE400A3PT030T400l<1`0C40/04Pl:010=20804a0;00P040`8010<2@0A3@X03`/800h:
1`0?2`P0510=01DA3P804Ph;00<0510=01HB3`0E4Pd00P0B3`P04`0@3@P03``700l<1`0F4Pl030P5
018>3@0A3@`00`0004Q4@`1XIf<061LC00d<200E510040l;01<B3P0=30P03`h:00d<200;2PH00P0?
3PX0200>20P03`T9014=300B3Pd04`l>014@3P0=30X02PT70P0@40h07@010@00:2TV02/]:P000P00
4A<@00lA3P0>3``03@d;00`<2P0?3P`040l=00l>300?3@/04@d:00l<0`0@40L01`T400`@4@0@5Q`0
7RHa03M1C@2c_/T0[kc404UDFP0>6A/00@/:010A4`0?3`l03Ph>00803`l?00L030`<00/;2`0H61P0
51@D00H61P0410@02PX:00803`h<0`0=30X01P0>3@/04a8@00l>300?3P`02PT700T81P803@`:01/0
3Pd;00`;2@0@3`d051<A018A3`0>3@/04A0>018A3`0A40h03Pd;00`;2@0=30X04A0>00d<2P0<2`T0
3Pd;00d<2P0:2@L030/900h=2`0A40h03Pd;00`;2@0A3@`04Ph=014=300>2PT00P0=2@P02P0>2PT0
30P7014=300?2`X03PX900h<2P0<2`T02PT700`;2@0=30X200`;2@0701PG5@11@3h0>CPf01XI5`0N
7A/03Pd;010?3@0200l>30803Pd;00L04A0>00H50`0:2@L05A@B0040000M71X03@X8008040`901`0
3`/8010<2@0>2PL020@101<?30091@804`l<00d91P0=2@P00P4003Xi=`061@<010<1010?3@071P@0
2@P600L6100@3`d06APF00P71@0=30/09B4P01`H5`0B3Pd03PX900d9200A3@`03PX90P0?2`X200`8
1`0700l;2P0@30d03`/<01<?400@30d0510A02PT9@02014=3P804Ph?02804`l@01<A3`0F5PX051L6
034d8@27RWL0[:jK05IGA@0`<B407ahA01HC300F4Pl04`h?014;3@0;1@D03PX8014=300D40l01P<3
00h<3@0=2``03Pd>01hN800?3a40410C00@41P0;2PP03Pd:010?3@0A3a803`dA00`:3`0@3Q<040hB
0P0>30d02P0@3``040l=00l=4P0=2a404Q0E00T7300D4QD040hA00l=400?3@h200X82@09010>3`0C
4A804@l@01@B4`0>30d04@d>01@@4@0?2``03`T;008030H800H04@P;01072P0=1`T03`T=018=4@0@
2`l2014<400=00d8300B3A406QDI00d8300H4aL02PD900H11@0;2@X061HG00l=3P0=2``02`T:010>
3`0200X82@0@00`:2`091`P02@L800/92`0?3A004Q0C00X82`071@P04Q0C01HD5`0=2`h02`T<00h<
3`0E4aH04Q0C00d:2PD03`/:00@030P700d9200A3@`03`/:0P0@30/02P0>2PX030L;00h93@0B3A40
3@P<00T4200:1@T04PdA010;3`0:1@T2010;3`0?01@>4P0A2`l03`X>01`G6`0R7B403`d@00`:3@0T
8RD020P:00`<3P0D51H02`/=00/7200=2@X040`=00803`/<01004@d>00/7200=2@X02PH7018>3`0>
2P/081`M02DS900O7Ah0518C00l=3P0@3Pl04Q0A01@B4`091`P04@l@0P0;2@X00`0D4Q<03P`=00l=
3P02010>3`0300l=3P0>30d040h?00D040h?0P0>30l300l=400=010>4@0?3A003P`?018@4`0@3Q40
30X=010>4@0E4a@05aHD010?3@0=30X040l=00h=2`02010?3@05014@3P0E518051<A00T81P0A3a00
0P0C4A800`0B41404@l@018@4@0601@B4`0301<C4`0B4Q804A4A00804Q8B01L04a<C01HF5P0E5AD0
4a<C01@D500B4Q803Ph>00`=3`0F5aT02``>01HG6`020`L07AhR01HG700@4AH05AHK01DE7@0F5Qh0
6QdR01HI7@0=4A@0=3Pk010D5`0201DI700H020T9`0D61/06QhQ02<W:P031`X06alR01DI700D61/0
4aLJ01@H6`0F6Qd05ATL030d=`0U:B`04QHI01@H6`0O8bH06QhP01PL7@0F6Q/061`M01XN7`0J7R40
6A`P0P0H6b00200L7bD07B0W01`O9P0J7B<06A`Q01PK800G6Ql05QTN0P0G6Ql201DH7@0301PK800K
7R<07B0T008061hN03805adM01LL7`0H7B006AhR020U:`0G72807b@Z01<G800O8b`051PP01hO900I
6Qh05aPL01PI7@0F5a/05aPL01XK7`0H6Ad05AHJ01dN8P0T9BT07QlS01hO900K6b<06AXO02X[<015
AT/0;Rlc01LH700F5aX04Q<E010A4`0F5aT07b0R018C600E5A`04a<K01dM9`0C4ad0;bli024Q:`0D
51d05AHK01HG6`0B4aD05ALF01dM7`0<30h02PX<01@D5P805ADG00<06a/M01PH6P0G5aT00P0E5AL0
2`0L71h05QHF01DE5@0E5AD061PH01TI6@0H61P05QHF01PH600G5aL04a<C00804A4A01@06Q/G01/L
5`0N7aT0828F0494=`1UIeT0@D<f02T[7P0j?34061TD028S7P092`X05Q/M020U:00E6Qd0?41304A8
B`0K7b804Q<G01@C60@05A@I00L07Q`O03`j?@0K6A`05Q@G01LB5P0?2Ph05Q0D00805a4E010060lD
01H=4P0C3A403@/>01/I7019AdX0<Blb018=4@0A310040X>018<400E3Q804PT>01@;400E3A404`d?
0`0B30h0100C3@l050h@01<=3`0A2`d200l92`8040X<01`01@01010:300@2P`04@/=01D?4@1nN7X0
=2h`00l92`0>20X030H801D?4@0F3A40304701H;4@0F2a<03`<=01dA6`0C1a404`P@0187300A1PX0
4@L601061@0=0PH03P<901052`0A1P`040D;4`0?10X200l33@803`@<00H03`@;00l42P0E2Q004`P=
01052@0>0`L200d21PH03P<900H01`0200X11@0;00H0LVM]04@i?`0=0PPDooooo`006oooool04@0D
40l04Ph=014=300D40l04`l>010<2`0H51<04`l>01@@3`0I5A@061@C00L30P0?2`P03PX700l;200A
3@X04Ph;00804@d:00/04`l<01@@3@0C3``040`900l;200B3P/0510=018>2`0@30T04Ph;01@@3@06
014=2P0700`;1`081`<02PT5018A3@0@3`/030/7010?2`0200h=2@0400l>2P0@3`/04A0<00l>2P80
2`X600d03@`800h=2@0=30P02@P400d<200Z:BD08R4M00l>2P0<30@04A4501<C2@0D50d040l:0080
3@`800T03Pd900h=200>3PL03Ph400h>0P0A3`L040d800`9100=2PD00P0?30L04`0B3`X05Q<>01DB
3@0@3@P05A8=01HC3P0A3PX040`9018>2`0@30T03PX7010<2@0?2`P03PX700l;200<20D02`L400d9
1P0@3@P00P0B3`P3014>2@0>01TE4P0>2PL030P700l;2P0;1`H0BdM606i]J@0M71P02`X600T8100;
2PH051<?00/:1P0=30P200`;1`8040l;0P0A2`/03`0@30/04@d<018>3@0A40h030/900d<2P0?3`d0
6QXH00l?3@020`401`T601<H50082PP061XG018C400200`<2P0B00d<2P0>3@/040l=00l=2`0=2@H0
30T0018B2@0<3PT03Q8C00`B6@0D72L03ALS04=@FP14DET05R<Y00HB500640l03a0B0P0=3@d200h>
3P0500/;2`0E5AD01PH6014A4@0C4a<00P0:2PX0500?3P`040l=010?3@0?3P`03Pd;00d<2P0B4@l0
30/900d<2P0<2`T02@P600/:200?3P`04A0>00l>300D4a405aHD01HE4`0=30X03Pd;0`0?3P`200h=
2`0301HE4`0A40h02`X800<03@`:0`0>3@/06P0=30X03Pd;00l;2P0A3@`040`;00d9200>2PT040`;
01lK6P070`8040`;00`81`091@@03P/:00`;2@0;2PP03@`:00l>300=30X030/900l>300L6aT03@`:
00<2000>3@/030/90P0?3P`04@0>3@/03@`:00d<2P0>3@/09B@R00l>300=30X00@00018A3`0A3``0
3PX700l;200=2@H03`/800h:1`0:1P<05A4>00804@d:00L03PX700`81@010000@d90018A3`0P7ad0
61LE008040l=00L04A0>00l>300<2`T00@0001DD4`0L61L05A4@00804@d<00X03@T800l;2P0A3@`0
4Ph=010<2`0=2@P030P700l;2P0<20T020@50P0?2``0700I5AH0;BTZ018>3`0A3@h040`=01<?400E
4A80518@01@D200P8a00IFQC0=OJa@3mo^X0XZB?0493<@0T91H05A8901HC3P0C3Pd040X<014;2`0>
2@L04Ph=00/71P0L6AT0108301HD5@0;2P`200d=3`0700d=400D51H030/700h=2P0>3@/03`d@00l=
4@0200l<4`0?00l=4@0=2``03@/<00l>2`0?3P`0108701TF701NG640=cDj00d;3P091`X03P`?010>
3`0B41403P`=008020H70`0:20T0100=2@X02`L800L3100?2@/200d41`8040L:01H03@L900h8300@
2`l03@P<00h93@0@2`l03@P<010;3`0A31004PdA03lj?P0/9b/06QDI00h<3@0W9BH04Q0A00d;300:
20T03`d>00/92P0=2``04@l@0P0=2``03@0:20X03@/>014?4P0;2@`020H9010>4@0A3a803@/>00`:
3@0;2@`03`d@00`:3@0:1`L01@0?2`P07P0=2@H05A4>01DA3P091@8040`9014=2P0<20P02@@800/6
2P0@2`l01P4500l:3P0Q72004@`@00`72`0A310030L;00h93@0A2`l040X>00`72`0A31005A0D00/9
300100807Q`O00D51`0@41804a<E00X:30803PX;00h03`/<018>3`0C3a004Ph?00`82@0U8B802`L8
010<3@0<20T05Q8C01HD5@0C4A803P`=00d;30803P`=00P04Q0A00h<3@0@3Pl020H701<A4P0D4Q<0
3P`=00l=3P8040h?00<03`d>00h<3@0@3Pl01@0@3Pl0100?3A003`dB010>4`0@3Q<2014?5008018@
5@0F51T03@/@01HD6@0R82D02`T<01LE5P0F5A<200l>300901@C4@0@3`d04a8@00`;2@0B4@l06QTG
01PG5@0@3`d04@l@0080518C0P0A3a000`0C4A80518C01@B4`0401@B4`0401@D500C4a<04a<C01<C
4`8051@D00<05aLG01XJ6P0E5AD00P0C4a<0700?3`l041<D01HJ6`0<41406alR00/?4P0G6ah09BP]
00/>5@0=41L04aHM01@G7P0H6b004aLK020U:01nPhH07b@W00hC5P0B5aX07R<V00X?4P0i?T4051TL
01HK7P0F6al04aPL01@I7@0E6Qh201HK7`0J01@I7@0C61`0EEYN01`Q9@0H7B406QlS01@H6P0H71d0
5QXK01PL7@0J7Ql06alR01XN8P0H6b005aXO01XM8`0L7bH06QdT01XM8`0J7B8061/P01LJ7`0H6b00
6A`Q01HI7P0H6b0301/N8`0301dP900I7al061hL00<05adM05H061dP01PM8@0J7b<041DK01DI8P0S
9c005QXT01/L8@0G61`06AXN01XK7`0F5a/061TM01`M8@0K72005aPL01`M8@0R8bL06AXN01`M8P0H
6Ah06Q/P02<T:@0c=3T092DY01DF6P0D5AP04A8D014C4P0E5aH06a`N01DF6`0I6B805ADO01/K9`0L
72P0IFEa02/[=`0H62405aPM01PI7@0D5AL06AXL01HF600T92H01`L900l?4@0F5QP05aLI01/K7@0G
5aT05QHH01@D5P0C4aD06a/M01HF5P0D51@05ADE01LG5`0I6AT061PH01DE5@0H61P05aLG01@D500B
4Q804a<C01/K600H6A<08B8J02la9@1jO6h0_l:a09jPTP0b=2L0Ce5601hO600J6aH08bDR01HK7@0<
4A@03A8E01dQ900H71l08RHY01@E6@804Q<G00D05aHK01/J7`0M72405A<F01lM800201LE600301<>
4P0F4AD05Q0D00805a4E00<06A0E01L>4`0D3a<00P081PT04`0H5QT05aDH01D@500D3a<040X>01H@
500D314060lD01H=4P0D31005@lA01<=3`0B30h04@/=018<3P0C3@l050h@018<3P0A2`d00P0@2P`0
4P0>20X03@L901@>400C3@l01@0100@0000=1`T02`D701TC5@0=1`T05Q0B010:300@20/01`0001L<
4P0:00L04@H>01P>5P804@H>00H04@H;01052@0@1PD040H500h31`0>0`T200l42P8040D;4P0?10X2
00l33@803`@<00H03`@;00l42P0C20h04@H;00l4200>0`L200d21P0300h32@0>0`/03P<;00<03P<;
00H06PlG01L<500<0@T01`0400d32P0H3ADDooooo`006oooool0<P072`l04QDF00T;3@0B51H02`/=
028R8@0=30/04A0>00l<2P0>2PP03@P501HB3P0>2PL040h:014>2`0=2`L04Q0<014?2`0@3@X04@l;
018?300A3`/03`d900l<2@0B3``04Q0<01<@3@0>30P05Q<@024O6`0L6QH030X600h<200C40d040d:
00l=2@0@3`/03@`800h=2@0?3PX040l;00T8100@3`/03Pd900d<200?3PX04A0<018A3@0B3``040d:
0P0?30T0@`0@3@X040h:00l<2@0K6AD0?c`i00d;1`091`<04Q0;00l?1P0;2`804Q4;00l>2@0A40/0
3`h:010?2P0?3PT03@`600h>1@0?3`H04A4900h>200C4@`03Pd8014A300:20D040l:00`<1`0D4Pd0
40l:00`<1P0:20H04@h:010=2P0A3P/03`d900h;200?30T03`d9014>2`0C4@d04@h;00l<2@0?3@T0
30`701PI4P0?3`X03P`7014>2P0C40`030P5014=2P0?2`T04A4=018C3`0>3``04Q8>00X:200>3PX0
20P400h>2P0<30T03`l;00/;1`0>3PT03`l:014A3@0G5a800P0?30X02`0?3@X03``:00l=2P0?3P/0
2PT601@C400A40d03Ph;010@3@0<30T0414?00803Pl<0P0<30X0;@0?3`d03@d;00`<2P0=30X03`h<
00l=2`0<2PL030`700l@300<3`d03A4A00dC5@0C6Ql03A@J00hE6P0B6Qh04a/M00/C500;4A003@l>
00d=3@0;2`X02@T800h>3@0=3@`04A4@00/;2P0>3Pd03@d<00`<2`0?3`d040l=010>2`0C40h04a8?
010@3@0?3``03@h:00T:1`0;30T02`h:00/=2@0=3P/03Pd<010?3P0200l=3@0400h=300<2`X03Pd<
00d<2`8030/:02H03`d=014@3`0?3`h051<B01LF5@0?3`h020L6010?3P0A40l03@`;00X:2@0=3@`0
2`/:00d=300>2`/03``<00/8200<2@T040d=00l<300V8b<03@X:010=3@0>2`/03@X:00h<2P0@3`X0
3Pd:00l>2P0=30P040l<00T81@0@3`X040l<00d<200=30L03@`9010?30D03@`:02l03Pd;034`;P0?
3P`03`h<01@C4@0920H03@`900H60`0A3P`02`X800d;20081@@040d;018?3@0D40h03@T800/71@0?
2`T05a<A010=2`0:20H040h;00D30P0<2@L01`D401XG5@0<2@L02`P603@a;`1nNgT03`/900h;1`0B
3``05A4?018>2P0?30T04`l=01<?2`0A3P/03`/900h;1`0?2`T04@d;00h:200=20L03@P900h:2002
018=3P1J010<2P0>2@T03`X;014=2`0D3`d06aX>03Dd901ZJeL0blbh0?Geh@2@TG`0>CLV024N400A
3@H04Ph:01<>3P0C3@l050h?00l:2`0F4A403`X;02hY:P0D4A802`H800l<3P0;20X04PlA00/82P0=
2P/03@`800l>2P0>3@X030/:00d<300@3Q003`d?00h=3@0=30/03@`900h=2@0>3@/04@lB00h<400e
<cL071XN00T72P0E4aH07adP00`:300>30h030X<01LE5`0@3Q00JfYZ018A4@0?3Ph040h?014>3`0=
2P/040`>00l:300=20T05@d@01@<3`0<1PP04Pd@014<3`0?2`d040`>00l;3@0<1`X03@P;010;3P0?
2Pd07QXL018=400<1`/04@lB020N8P0A3a4030X=00T72`0;2@`04Q0B00X8300=2`h04a4C00d;3`0@
2`d03PT80P0A30`2014>3P0c00X82P0C4A@04a4E01XJ7@0m?D005AHI00`;3@0?30X03P/;00d;2@0>
2`T03``<01DB4@0S81h07Q/K00/91`0B3`d04Pl?00l:2`0?2Pd040T<014;3P0<1`X06Q@G02`W:P0H
4aH04Pd@01LD5P0?30h04PhA01<=4@0D3Q804@/?00h8300?2@d03PX>01lJ7P0300<04@hA00d:3@07
10L04a0C00d92`0;20X030T;00l<3P0A3Q003@X<018?4@0/:B/04PlA00804@h@00@040d?00h<3@0>
30d03`d>0P0@3Pl02@0?3@h030X;018@4@0@3Pl03P`=01TG60081PL03`d>010>3`0200h<3@03010>
3`0<2P/040h?00803`d>01<040h?014?400B41403P`>014?4P0A3a4040hB014?4P0C4A<040hB01HD
5`0>30h06QPL02/Y;00E4aD0514B018@3`0>30/03`d<00804a4@00l05aDD010>3@0B3`l04a0@00l=
300>3@`051<D01dL700C4Q<03@`=01<B4P0C4Q<04a8B018A4@0B4A800P0E51@0100D51@051@E018C
500B4a@201@E5P0701@D5@0E5QL06ATJ01@E5P0A4A804a<D01<D5@02018D5`0>01@G6@0=3a<06A`O
00lB5@0X:Rh04A<H018D600H6Ql05ALM018E6P0G6al051PL03Xn@P0E6Ad201HJ7P0701XN8P0b=SX0
E5QL01<G6`1OHfL0<cPl01HK7`0301LL800501HK7`0G720092T]07^0Q00i?T800P0F6al0F@0J7b80
7B4S01`P8P0L828061`N01HK7P0I7R406alS01@H700F6Qh06QhR03Tm@P0V:Rl06B0S01TM8@0J82@0
61hR01XO8`0M8BD06R4T020U:@0R9R/06b4U01HK7`0G71l05QXM01XN8P0O8bL03Q8F01/O8`0G71l0
6alS01HK7P0I7B805ATN01HJ7`0F6Ad04A<G01LJ7@0N82@04QDH01HH700D5aX05aXM024T9`0I71l0
71lR01LI7@0L7B406QXM01XJ7P0D51T05ADH01PH6`0H6A`05aPJ01HG6@0G61P06AXK01XK7@0G61d0
61XP01@E700E5Ql071dV05AEGP0V:3807b4Z01PJ8P0L7R@05aTO05=EFP1jOH00@DA501TM7P0?4A<0
5aTK01/K7@0G5aT061PJ01DD5P0G5QT051<F01HE600C4a@04a@E018C500C51D05QHG008051@E0300
71dN01XK700F5aP071dN024R8`0M7A/06Q/F02<T7@0o@CD0YZRJ0?ool@3Ce<D0CU1302@V6`0R8ad0
>CTg018D500E6A/04QLF024T8`0Q9B40=3Pb03Li<@0J71H06a`H01`L6@0I61T06aXN01/I7P0J61d0
1`H:01<B5P0I61`04a0C01TF6@0D41@05a8D018=400H4Q@05PlB01H@5@0?2a004@dC010=4P0C4AD0
5aDK00d:400B3a<2014?500;01@B5P0E4aP040`@01D?4@0D3Q003`T;010:300C3@l05@lA00l92`0@
2P`00`0B30h05@0>20T04@/<010:2`0@2P/04P`=01H@4@0@2P/04`d>00h82@0A30`03`T:00H10@0E
30h03@@601472P0E2`l02`8501@93`0@1@X04@H;01872`020147200D01061P0C20d0:b0W01883P0E
2Q4040D<01873P0>0`X04@H=01873P0=0PT030880105300E2Q003`@:00d3200B1`d04`P>00h42@0A
1P`201052`<03`@:00P040D<00l42`0>0`T03`@;00l42@0>0`P03`@900l420@03P<700`03`<800l3
2@0?0`P03`<:00l32@0?0`P03P@:01042`0>0`L05@TA01052`0?0`PDooooo`006oooool04P074QP0
214F02Pb=00@61/03Q8D0414A@0A4a803`l<00d<200A3PT05a<>01XG400B3P/05aHB01hM6@0M71P0
4Q4=00d<20L03Pd901@030/7010?2`0<2`L05A@@02@S7`0R8Ad03Pd9014@300B4@d03`h:01<B3P0@
3`/051<?00`;1`0=30P05A@@01PG4`0@3`/03`h:00h=2@803`h:00@040l;018>2`0C3``04Ph;0P0@
30T0800A3@X06QHC00T50P0W8b004Ph;01DA3P0E4Ph04a8=01DD3`0>3@P03@`700h=20071P@00`80
00`;1P0B4@`04A0;010?2P0<30L03Pl9010A2`0<3@L05AH@01/L5P0<3@P04a@>00T:100720D061TC
0083000;2`H03@`80P0<2`L200/:1P0C00d<200>3@T03@`800d<200>3@T03`h:018E40001@0030h9
01DD400K6QH05A0=018=2P0@30T03@d900d>2@0=3`X03A8<00P:1@0200P9100=024R7@0R8ah030d8
00h?2P0A4Pd03Pl:010A300:2`H06a`G01HE4@0E51004A0<00h=2@0200d<200600l>2P0@3`/04A0<
010?2`0A40`040l;0`0?3P`200h=2`0300d<2P0>3@/03Pd;00<03Pd;01D03@d;01PJ6@0A5A@02@d<
00L;2P0830/02`l>0001000N8R4010P70045100@51<020X900P81P0/;2X01`L500l?3@0=3@/051@B
00l?3@0<30X00P0>3P`03`0<30X040l=00l;200<20D03`/800`;1`0920@030d800d>2@0A4`h03A8<
00H<1P083`P03A8>00d<3@0200l=3P0300h<3@0=2``03P`=00803`d>01H03P`=00d;300>30d040h?
00`<30092@T04a<C00L71`0410@04Q8B00`<300;2`/03Ph>010@400?3`l04A4A01TG600H5QL03`d>
010>3`0C4A803@/<0P0>30d0300?3@h03P`=00h<3@0C4Pl02`X500H5000=30L051<>00D4000;2PD0
0`8000X9108030/600<04a8=00l>2`0=30X00P0<2`T0700=30X03Pd;00d<2P0=30X03`h<01@C4@0E
51804a8@00P81`071`D05QHD00L71@0H61H051<A00`;2@0=30X04@d<00h:2@0;1`H03`T900@0000=
2@H03`/800d91P0Q7AX05A4>01HB3`0D40d200l;200800H2000Q7AX04a0;014>2@0?30L03P/600l<
1`0B3`X2010=200<00l<1`0>2`H03@X500`9100@2`P05Q4>01@?300400004`h;010;2P0B3@X04@`9
0P0?2PL04P0B3@X05Q4>01hJ4@0S7a<06QL8048o<01bKeh0?c`[01hK300H50T04Pd7018=2P0C3@l0
4P`@01@>400C3@l04@/=010:30804@/=1@0?2@/01P0>2P/03@`:00l>2P0>3@T03@`800`;1`<03@`8
0P0>3@T06`0?3PX03`h<00l=3P0=2`h02`T<00`:3@0>30l03`d@01DC5P040PD02`T<014?4P0]:bh0
71XM02@T9000000030`<00L71`0:20T05Q@E01<A4P0E4A804Ph?01/G600L5QP04P`>010<3@0200l;
300:010<3@0>2P/030P900l;300=2@X040`=00l;300;1`P03@T:014?4`8040hC02403`dB00h<4@0?
3A805A<H00`:3`0?3A800@0400`:3`0g<C<03@P500d50`0C3P/02@D200`81`0>2``01`D800/:3`1D
EET0ZJZ^0452AP092@`03P`=00`:2`0;2@X030X;00h<3@0?3@h05A<D018@4@0:20T04@l@018@4@0>
2@/00P0A20/01P0B2@`04@P;00l92`0?2P`040`=014=3P803`d>00D03P`=018=4@0B31004P`@014;
3`02010:3P0C00@00P0E3a<05a4E01@>4P0J51P06aDI01HD5`0:20/030X=00h<3`0H5QT04@lB00l=
400200<02@L:01<A50091`X02`T<010>3`03014?4003010>3`0?3@h03@/<00804Q0A00<05aDF01lM
7P0B41400P0@3Pl01`0<2P/03P`=018@4@0=2``030X;00h<3@0A3a000P0B4140100A3a004a4B01DC
500D4Q<201<A4P0401@B4`0>30d040h?01<A4P80518C01@04a4B018>3`0D41409B4R02<O800B3Pl0
510A01XF5`0G4a@05Q8C014=3P0@30d06QPI02PX:00`<30061PH014A4@0J6QX04Q8B01DE5@804Q8B
00H04a<C018B4P0A4A403a0B00d>400>3a42014B500:00l@4P0B4aD04Q<E018C5@0@4A<04Q<E01<D
5P0F5a/05aPL01PI7@806AXN01<061TM01XK7`0E5QX051DI01LH700F5a/051DI01LJ7`0E61d071lT
01DH7@0A51T051LL00`?500D5a`061/P00<62`0Y;340720T008061dQ00h05AXN01PM8@0G720051TM
01TN8P0M8RH051TM014F6P0K82@092T/01HK7P0;41<041DH01PM80805a`O01X082DX010E600O92L0
;34d05EJG@0/<SD05QhQ01@L7`0I8B@05QhQ01LO8P0D71l04ATL01HN8@0J8RD05AdP01@L7`0S9Rd0
4aHM018E700:3A80=STn00L:3`0D61/05ATL01LK70<061`M00X03a<F02DY;00K7b802`lB018F6@0N
8RD06alR01`P8`0Z;S406QhQ0P0M8B@01P0C4aD05ADG01LG6@0E5AL04a<E014A4`@05QHH01`061PJ
01PI6`0?41@061`O01LK7P0F6Ah05APN00T<4`0M82L041<K00lB6`0A51d09RTb0823RP2e^[d0;cLf
01HL700:41003a@D01<G600C51H04a<E00h<3`0E4aH04Q0C01PF6@0B4Q@05AHH0P0C51H0E`0E5QP0
4A8D01LH6P0R8bD07AhP01@E5`0G61X06a`N01XJ700N7Q`0824K02`^8`1KGDl0VYf<08nAPP0/;R40
5QP=01`M6@0K6ad03@h@020R9@0H6QT06adH03<g:`2c]JL0_L2_05aOC`1CDdT0CTi601DD4P0B3A40
8R0U030^=00K6Ql04a8G01DD6@0F51L03`d@01@B5@0D414020@5010<3@0A2`d04PdB00h9400A31<0
5Q8I00T63@0B4AL0;Bdb010A5P0B5AX0=STn051EF@0G72004Q0D01H@4P0G4A<050h@010:300?2@/0
3PP:00X41P0?2@/04P`>01<=3`0F41803PP900h8200@2PX04@/;010:2P0>20P030H600T30`0;1@D0
4@/;01@>3P0C3@d03PL700h41@0H3Pl02@0000P0000D2P/03`D601061`0301882@0C01462@070080
;B8Z00d42P0C21002`0800h32`0@1@d02@0600X11`0I3QH07A8J01053@070080200301L<4P0A1P`0
6@hD00`21`0300h32@0400l42P0@1@/04PL=00l420803@8600<03`@801462P0@1@T01P0>0`L600l3
1`0400d11@0D20`02@0101@8308040@85?ooool001_ooooo01802A8G04UBEP3Dg=d0Ifia01DJ6`0:
3Ph0<C<a01hN6`0@3`/0514<01LC3@0B3`T03@X701DD400=30P071/G00l>2P0A40`700l>2P0C00`;
1`0@3`/040l;014@300H5a<04A0<00l>2P0B4@d03Pd900/:1P0A40`03`h:00X91@0>3@T092<O00d<
2@0>3@T03`h:010?2`02014@300500l>2P0>3@T03`h:010?2`0?3PX00P0=30P200h=2@0:00l>2P0;
2PH051<@00d<200?3PT010<002TX8`0920D040l:00d<1`804Q4<018040l:00l>2@0<2`H03@`701DE
3`0720<03Pl903Hg<@061`4051D?00h?2P0A4P`06Q/E00h?2@0B4`d01PL3010@2`0A40`3010?2`0=
00l>2P0>3@T03@`800d<200?3PX040l;014@300?40/0=S/e0822O@0H5a<04A0<010<2@0200l;2004
00d=200<3@P02`d800/@2P803a0;00d03Pl:02@U800T9B004Q<>00/<1`0A4Pd02P/6010A300D5A00
30d:01HE4@0C4Ph03`h:008030/70P0?3PX200h=2@0900l>2P0=30P03`h:00h=2`0?3P`04Q4?014@
3P0?3P`03@`:00D03`h<01D03Ph<00`=300;3@`02`d<00`>3@0>40l03a4@014C4P0f>3L051HE00H8
1`0B51<03a4@00h>3017AdD020P601TI5`092@L03@d;00h>300<30X00P0?3`d03`0<30X03`h<014=
300B3@`0510?014=300@3P`06ATG00d>300C5180418?00P;200:3PX04A<@010?400200h<3@803@/<
01<030X;00d;300@3Pl040h?00h<3@0=2``03P`=00l?3`0:2PX05ADE00d=3@0D51@01PH600L71`08
20P04A4A00X:2P0=3@d030`<00804@l@00@02PP900h<3@0B41403@/<0P0>30d04P0?3@h03P`=00h<
3@0;2PP03Pd9014@300920D051<?00T81P0?3P/040l;00h=2@0=30P03Pd900d<200=30T03Pd;00d<
2P8030/902803@`:00l>300?3P`03Pd;010?3@0B4@l04A0>010?3@061PD0;Bd[01LG5@0?3`d040l=
00/:200=30X040`;00l;2P0=2@P03`T9018>300:1P@04Ph<02/W901FDTl05A4?00d91P0=2@P04@d:
01dI5P0H514030P601DA3P0D40d04@d:0P0?2`P0100A3@X030P500d91P0>2PL2010<2@0O018>2`0L
61L01P8201<?3P0=2@P03`/;014=300F4Q405A4@018>3@0@30/04@d<01@@3@0C40L05A<701/I2`0O
7@l081h@01lM3`0C4@<04Pl501<@2`0D40h04`lA010;3`0A3@h04Ph?014=3P0@30d03PX;00`82@06
00l;300:00l>300<2`T030/900h=2`0@3`d03Pd;00`;2@0=30X03Pd;00l>30804A0>01/03`d?00d;
3P0;2@`030X=00h<3`0?3A0040hA00L5200=2`h040hA01hL7`0@3Q404A4A00P820071`L04Q8B00P6
1`0A3a005aDF01@@4@0>2P/040`=014;3@0:10H03`/<018>3`0A3@h00P0>2P/03P0?2``040`=01<?
400G4a@04Ph?00h:2`0A3@h040hA00d;3P0<2Pd03@/>00l=400>30l04Q0C0P0?3A0060050`H05aDH
030^;`0<2PP02PD601DB4@0F4a<0514B00`:2`071@H040lA00h>3`0T92D03@`>00d;300>30d030X;
00/92P0<2P/03P`=00/92P0=2``03P`=00/92P804@l@00@03`X;01482`0A20/04@X<0P0?2@/00`0?
2P/040`=014=3P0200l=3P0400h<3@0C3Q804PdA018=4@803`X>00X03PT=00l:3P0C3Q802PD901<>
4P0A31003PT=010>4@0<2Pd0:bT/0P0?3A001`0>30l04Q0C010>4@0T8RD04Q0C00`:3@0?3A000P0@
3Pl2014?4007010>3`0?3@h03@/<00l=3P0=2``040h?01LE5P02014?4007018@4@0=2``03`d>01@B
4`0?3@h03P`=014?400201DC500501<A4P0A3a005Q@E01<A4P0B41400P0C4A800`0?3@h03P`=014?
400201DC500E01<A4P0A3a00518C014?400T8R<08R0Q010>3`0G5AH04a4B018@4@0H5QL04@l@01LE
5P0k>CX092@T028R8P0B4Q80410@01@D500>3Ph051@D00804Q8B00P051@D01<C4`0B4Q8051DG018C
5@0C51H05QLI01DF608051DG00H04Q<E01@E5`0F5aT051DG014B500D5AT301DF6P0H01@E6@0C51P0
7AhR01HG6`0C51P051DI01HG6`0G61d07R4X020S:P0?4QT05aXQ01/N9@0E61l04aHM018E700L7bH0
4aHM01XM900G6b4061dQ01LL800D6Ad061dQ0P0J7b<05`0M8RH0724U01LL800H7B408RL[02@Y;00K
82<082DX01PM800E6Qd07B8U01LL7`0T:B`05AXM01`Q900F6ah08bP[01TP8`0G7b80620S01dU:00L
92L06R8U00804a/N0P0H82<00`0G7b8072@W01LJ8@0201/N9@0501XM8P0f>Ch08RDZ01DI700F6Qd0
0P0G6a`201HJ6`0E024U:00D61/0720S05aPH`0`=3L05a/N01XN8@0G6ah06QhQ018F6@0E6A`061`O
01PH6P0I6A/071`N01lO8@0L71h051@F018B500D51H05aLI008061PJ01/05aPJ01LH700F6Qd05ATL
01DH7@0F6Ah05APM01PK8P0B5A`06ahU01PK900B5Ah05QTP02X^<@0@4a@051PI01HI6P0A4a@06AXL
01DF600A4Q@061PJ02<S9@0F5aT06ATK018C5@0F5aT00P0D5AL0>P0F5aT04Q<E01HG6@0L7Al061TK
01LH6P0F5aT051DG01/J7`0I6AX06a`H024R6P0R91L0;BlR03Hh:P0J71805QL@020P800F5QT071dQ
01`O8@0H6QT092HQ06Y]I03cmNP0oooc09>EQ`0Q8AL0:2LR01`K6@0K5QX061HK02h/<P0R8BH04Q4F
014@5@0F51L03P`?02XX:`0R7Ql0510A01DA4P0C3@l050hC01D@5P0A31805A8G00<11P0M7240IfI[
01<D60092Ph0LWIi0=3De`0n@TD04@lB010:300?2@/3010:3007018<3P0?2@/050h@014;3@0?2@/0
5a4C018<3@0600l92@804P`<00/03@L700l92@0@2PX040T901@<300@1`L060h?01@:2`0@1PL03`D6
01061`0301882@0C01882P0<0`L05P/A01<83P0E2Q003P<901873@0D2@l03`@:01<83P0R5ad091TO
01D:400H3A<0308701<93P0=10P0@SLm01lD6P0201052`<03`@:00L040D;01052@0>0`L03P<70105
2@0C20`04PL;00H03P<71P0?0`L01P0>10H04@H901<82`0>10H0714D00d31ACooooo000Kooooo`0?
00@<3`0g?d80UibO03m4A`0@5AD061XI01LG5@0?3``02@P400`9100?30L040d801XI5@0_;RX020L3
00<040l;1`0?3PX00`0<2`L03`h:018A3@02010?2`803`h:00`051<?01HE4@0B4@d04A0<01<B3P08
1`<061LC03Th=00@3`/030/700h=2@0@3`/2014@300700h=2@0=30P03Pd900l>2P0>3@T030/700/:
1P0200d<200B018A3@061@4030/700P70`0^;BP09RDP059AC00F5A0030/600P70P0F5A0040l:00P7
0P0?3PT040l:00/:1@092@@02``60P0>3`T03@0<3@L05QLA07amM`0U9R001PL100h?2@0@4@/05AH@
00/;1P0=30P03Pd900l>2P0>3@T00`0=30P02P0>3@T040l;014@300A40`05aPC00X?2@0e=c8030/7
00H50@0:1P<2010<2@0D00h>2@0=3PT030h900T>200;30L04Q<>00X;1P092PD01@H100P9100A4Pd0
2``7018C3P051P405aPC00d>2@0920@02PT500`;1`0=30P200h=2@0;00`;1`0;2PH04Q4=01DD400>
3@T030/700`;2@0>3@/04A0>018A3`0?3P`01P0=30X00`0<30X02`/;00`>3@0200h@3`0@00d?3P0;
3@`03a4@00d?3P092`X03a4@00`>3@0E5aH00@4001HF50061P@030`:00/;2@0=3@/03`l=00h>3080
4Q8@01P03Ph<010?3@0=2@P03`T9018<300?2@T040`;01XI5`0?3P`03@`:00`<2P0=3@/030`:00X:
200>30d030X;00d;300?3@h02`T:00P61`0=2``040h?014?400>30d200d;300B00T92@0;2`/03`l?
00d=3@0B4Q802`/;00d=3@0820P03Ph>014A4@0@41002PX:00/92P0>30d02@L8010>3`0G5AH04a4B
0P0>30d04`0?3@h03P`=00h<3@0?3P`05A@@00L60P0@3`/03@`801/J5P0920D0O7]g079aK@0B4@d0
4a8>00L60P0@3``03Pd;00d<2P0<2`T00P0=30X0100?3P`03@`:00X91`0;2PP200`;2@0G00h>301I
FEL0k^k/03lo?@0000000`8000l>300<2`T03@T800h:2@0?2`X03`T901DA3P0;1`@00`0001DA3P0<
20D02`L400l;200G4a004@d:00T50P0G4a000`0@30T300l;2004010<2@0=2@H03@T600l;208040`9
00X04@d:010<2`0;1`H0I61O02TU900H51<05a<B01HB4@0E4A004Ph=0P0?2`X03`0?2`T04a0900l=
0@0C4@D061H:01XH300M6`l05186014>1P0?30L040`;014<3`0?2Ph03@T:00l;3002014=3P0300l;
300=2@X03`/<00D03`/<00D040l=00`;2@0<2`T040l=014@3P0700h=2`0F00l=400=2`h02`T<00`:
3@0>30l03`d@00/9300:20/03P`?00l=400B41<02@L:00T92@0G5aL0410@01<C4`0@3Pl0518C00`:
2`0=2@X030P901DA4P8071HH00<03PX;018>3`0A3@h00P0>2P/02`0A3@h030P9014=3P0E4A803`/<
00`82@0@30d05Q@G018@4`0?3A003P`?00803`d@01L06QPK01DC5P0:20/04@lB00L520091`X02`/;
00/9300a<3805aDF0040000A3a000@0000L51P0?3@`04a8@00`82@081`L03P`=00`:2`0;2@X030X;
00h<3@0200d;300:00l=3P0>30d040h?00h<3@0?2P/04`X=014;3@0B30h04@/=010<3@804@d>00@0
3@/<00`:2`0=2``03`h?0P0B3A400`0A310040/?00l:3P0200h93@0A010;3`0H4aL00`0201<>4P0R
7B4040hA01<A500o?D005Q@G00l=400A3a802`T<014?4P0U8bH030X=00l=400=2`h00P0?3@h3014?
400=010>3`0E4a@0518C010>3`0?3@h04Q0A010>3`0C4A804Q0A00d;300>30d04@l@00/92P0201@B
4`0501<A4P0D4Q<05A<D01DC500@3Pl00P0=2``01@0A3a004Q0A00h<3@0D4Q<04a4B008040h?00L0
4Q0A01<A4P0D4Q<0518C00`:2`0:20T04a4B00805Q@E00`02`T:01<A4P0C4A803@/<01HD5@0K6a/0
3@d=01DE5@0B4Q803Ph>01LG5`0A4A4200l?3`<04a<C00<04A8D00l@4P0@4A<00P0C51H0200A4Q@0
51DG018C5@0E5QP061TK01@E5`0@4A<05aPL0`0H6Ad201HG6`806AXN00H061TM01HG6`0E5QX05AHK
01DH800G6R<2010C700<01@G800E62406ahW01`O:00N8BX06QdV00lB6`0G6b4061dQ01LL800D6Ad0
6AhR100K82@04P0J7b<061dQ01HK7`0G7R403aLJ00dE600K8bH09Bd`02@/;`0G7b806b<V01@L7`0I
8B@04a/N01PP8`0I8B@05alR01`T9`808BT/00d0620S01@L7`0C6ah05AdP01XR9@0L92L051`O01HI
800Q92/06A`S01`O900K7R<041<H00805a/N00T05a/L01HJ6`0E6AX051PI020T9`093A0041@G051D
E`0;3a800P0G6ah00`0H71l05QXM01LK7P0201HJ7@0301/K7@0H61X05aLI00806ATK00@051@F014A
4`0D51H05aLI0P0I6A/0600G61X04A8F01<G6P0g>ch0>3`o01HJ7P0C5Q/06ahS02@W;@0<3aH08B@[
018E7@0F6B007QlS020Q8`0A4Q@05ADG018C5@0L7Al05aPJ014B500J7Ql0;2d_01`O80804a@F02L0
5aPJ01DF600E5QP05aPJ01<D5P0E5QP04a@F010A4`0G61X06a`N01LH700N7B<05aLI01LG5`0O81X0
:BXR02HX7@0R91X06Q/E01@E400I6AX030/A01LH7@0E61X08B<R02T[:00h>c80SHn20;bn/@15AcX0
8B4G02TX8`0C4A4061<G01`J7`0E4aX030/@01<B5`0E51T00P0D4QD04P0?3A003PX;00T51P0A3@h0
3`T;01<>4P0L5ad040/A00l;4@0=2a006QPM051?E012@DH06Q/O01PI7@0`<CD01@H:01<@4`805@lA
00X050h@00d72@0?2@/04`d?00`6200A2`d04`d?01`F600/9RP081XK0P0?2@T04`0>20P03`T900l9
2@0?2@T02P@400`61P0=1`L0208201TC4`12>SX06a4B01882@0=0`@0200001L=3P0D2P/04`T:0188
2@0@1PL00P0?1@H00`0E2Q00200301<83P0200`11`0@00l42P0;00H03@8801052`0=0PP02`0600`1
1`0>0`T081DK01873@1BAdd0l^O]06mTJP0B1`d04@H<01052`<03P<900<050T=01872`0?10P00P0@
1@T700h31`H03`<700H03@4500T00@0Q5AT0200003HZ;P0G2`lDooooo`006oooool04P0>4aL0314D
028X:0083Ph020/;01<E500A4@l04a<@01<B3P0E4Pd061D@01`I500:2@D09B@P00`;1`0>3@T04A0<
00d<20H040l;01803@`800/:1P0=30P03`h:00h=2@0=30P040l;00d<200@3`/05QDA018A3@0>3@T0
4Q4=00X91@0=30P04a8>00P70`0L6aL200l>2P8040l;00D03`h:00h=2@0>3@T03`h:00h=2@0200`;
1`0300d<200;2PL051<?008051<?01l01@@001LF4`030P009bHQ00d<1`0K6QD0;B`W04M6@@0a<2/0
4Q4<00L60@0:2@@04A0;01LG4P0<3@L03Pl901PI4`0?40X03Pl90:2QV`0c=2h01`P201<D3P0A4P`0
4Q<=00L7100>3@T03`h:014@300@3`/03`h:00803Pd901h03`h:014@300A40`04A0<01XK5P083@L0
3a0;00/<1`0E510061@A018>2`0A40`04A4<010A300>40/03@l:01<D3`0F5a803a0;01HG4P0C50l0
30d800X;1P0720<04a@?00H70P020`004A8=00`;1`0=30P200l>2P0=00h=2@0=30P03Pd900`;1`0F
5A406QTE014@300=30P030/900d<2P0?3P`040l=00l>300700d<2P0D00`<300=3`h03a4@00lA400>
40l030h=01DG5P0>40l0008100X<2`072@P0004000h>30071`D04A4?00X:200?3`d02`/9010@3P0?
3`d201<C4@0V00l?3@0A40h040`;010:2P0A2`/03PP800/61P0B3Pd03`h<00X91`0;2PP03`l=00d<
2P0920H030X;00T7200<2P/040h?00l=3P0<2P/03@/<010>3`0?3@h03P`=00d;300>30d0410@01DE
5@092@T00`<30000000D51@03`l?00X:2P030`<04A4A00`<300;2`/2018@4@0400`:2`0@3Pl05A<D
010>3`803P`=01003`d>00h<3@0>30d03`h=00h=2@061@403`h:0040000<2`L0:BPT0=gLf03Cd/h0
9RDQ01LF4P0:2@D02PT60`0<2`T06P0=30X03Pd;00h=2`0:2@L02@P600`;2@0?3P`040l=00/;2@0I
6AL0Ph>101dM6`0E5A<03`h<00d<2P0;2PP030P700h:2@0@30/040X:00`81@0>2PL0510=02/W9006
0P002`L40P081040100?2`X02PH300h:1`0F4Pl200h:1`@03`/800d04`l<018>2`0A3@X03`/800h:
1`0=2@H00`0001LC4P1/J6L0=c<b03hj>@0k=cH040`;00803`/:014040`;014=300B3P`03P/401HC
2P0C40L040d401@A200F4`X05Q<<014>200=2@H03PX9010<3P0@2`l03PX;00l;300:010<3@803Pd;
00@03`h<010?3@0@3`d03@`:0P0?3P`200h=2`0800d<2P0=2``03`d@00d;3P0;2@`030X=00h<3`0?
3A0200X82`0600d;3P0@3Q403`d@00`:3@061PH04A4A0P0820P02@0S8B802@L800/92P0>2P/03`/<
01DA4P0L5QP07QPJ00d92P02010<3@803`/<030040`=00/7200>2P/04Ph?00l;300<20T03`/<01@B
5@0A3a803P`?00d;3P0<2Pd020H900D31P0:20/040hA01<A500D4QD04a8D01@D5P0B4Q@061PJ01DE
5`0?3A005Q@E01<B400I5A@03@T800@0000A2`/04a0@00h<3@0<2P/02`T:00`:2`0>30d03@/<00/9
2P0>30d040h?014?400@3Pl04@`>01<:3@0B30h04`d?018<3P0@30d2018>3`0600l=3P0>30d03`d>
010@400?3A004@`@0`0@2`l05@0?2Ph05Q4E00<00P0>2@d040/?00/62P0?2Ph03`d@00D31P0K6A`0
30X=010>4@0:20/04a4D00400P0?3A005aDH010>4@0;2@`03P`=00l=3P03014?4007010>3`0B4140
4Q0A014?400@3Pl04a4B01@B4`02018@4@803@/<03T04@l@00`:2`0E4a@04a4B014?400B4140518C
01DC500?3@h03P`=00l=3P0A3a004a4B018@4@0D4Q<04@l@00h<3@0?3@h0518C01LE5P0>30d05aDF
00`:2`0:20T05A<D014?400F51D03P`=01@B4`0J61T04Q0A00P61`0K6a/03@d=01TI6@0D51@030`<
01LG5`0D51@04A4A010@400C4a<04Q8B014A4@0B4aD0414C014B500D5AL04a@F018C5@0D5AL04a@F
01@E5`0E5QP051DG018C5@0H6Ad00P0I6Qh0100J6al06AXN01PI7@0F5a/201/L800601PI7@0E5QX0
5AHK014D700C5Ql061/T0P0B5Ah0500H6b@07B0Y02@W<00P8b`08RD^01DH8@0K7bH06AhR01PM8@0F
6al06AhR01XO8`0N8bL082DY01`Q9@0N8bL08BHZ020U:@0M92L06b<V0P0C6ah03`0=5AP04a/N02/c
=P0E7B002A4D01@L7`0I8B@0620S01@L7`0F7R406R8U01dU:00N9RT05AdP01PP8`0201LO8P0M01`T
9`0O9bX051`O01`Q9`0I72<05QTP024T:@1gNWl0:bhc01@H6`0E6A`05a/L01PL7@0I7Ah061`M00/?
4P0T:2/09RX]02lc=P0K7b804QHI00hB5@0D61/041@G01@H6`0>4QD041@G01TJ700H61X00P0D51H2
01DE5`0P01@D5P0F5QP05aLI01PH6P0I6A/061TK020T9`0M8B@0?D5403a0@`0K7R8071lT02d`=@0f
>Cl02PdD01hQ:0082a<05aLO00d<4@0C4aD030`>01@D5P0I6Q`06a`N01LH6P0A5AH03Q8C01/O800F
6a/041@E01@E5`0H6A/201HG6@1401PI6`0D5AL061TK01@E5`0>3a405AHH01TJ700F5a/07A`R01XI
7P0L71h06AXF024R700L7AL07b0J01LH4`0B4Q005QDI01<B600H6Ah04ADG01LI600M7a`05aXB038d
:@1EEdX0;BlT01HF3P0J6A@08AlO01PC5`0:20d05Q@J00d<4@0I61d061LL018@4`0D4QD05A<F01LC
500D41406ADF018<3P0C3A006QDK01<>500B3Q@04@lD00`:3`0l>Sl0E5=H01DD6@0<3A405QLK01@E
6@0?3@l030H800l92`0H4Q@04@/=010:300E3a403@L900l92`0>20X05@lA028L7P0I4a@500l92@0@
010:2P0:10@030H6014;2`090`<06aDE06aTI00c:BX02@4100l51P0K4A8050`<01H<3@0E2``04PP9
00l51P803P@500@04`P<00L00P0@1@/02P050P0A1P`0300F2a404PL=00l42P0C20h05@X@01873@07
00804@H<00`11`0/8BL0TXN=040e>`<03P<900D03`@:01052`0B1`d050T=01872`0300l4200300`1
1@0>0`L03P<700@03P<71P0?0`L01P0;00<05P/>00T00@0C1`/0710D01P<41Cooooo000Kooooo`0B
01XN800?4a@04QHF018E5@0B51<03a4?00l?3@0>3P/03Pd900h=200?3@P03``7014@3@0>3@T05QDA
01<B3P0>3@T03`h:1P0@3`/02@0>3@T040l;00h=2@0?3PX04A0<018A3@0A40`03Pd900d<2002010?
2`0@00h=2@0?3PX03Pd9014@300?3PX0?chj06a[I`0A40`03`h:00h=2@0?3PX040l;014@300>3`X0
3a0;00h?2P8030d800P03@h901<D3`0A4Pd04A8=02HW8`0<3@P04A4<010?2P803`h900H02@P400h=
200C4Pd03@`700`;1P0B4@`200/:1@0?00h>2P0J6aD03Pl:00d>2@0:2`P03Pl901hO6@0;30H030d:
00h?2@0C50h02P/500h>2@0?3PX04A0<00804a8>01T04A0<010?2`0@3`/04A0<018A3@0A40`040l;
018C3P0:30T04a@?010A300>3`X03@d900h=2@0>3PT03a0;00h?2P0<3PT02``700X;1P0A4Pd02``7
00`=200:2`H03Pl:00803@h900T051D@05QIE00A4Pd03@h9010?2`0?3PX03@`800`;1`0=30P00P0?
3PX00`0:2@D04Q4=01HE4@0200d<200400/:200<2`T030/900`;2@803Pd;1P0?3P`00`0<30`03@d=
00h>3P0200l?3`0900h>3P0<30`02PX:00T92@0B4Q8030`<01<C4`0>3P`030`:00803`l=00@03Ph<
00/;2@0>3P`03Ph<0P0C4a402`0>3P`03`h<018>3`0?2P`04@`>018<3P0=2@X03PX;014=3P0B3Pl0
4@d>008040`=00L03``=01XH6@0=2``02PP900h<3@0?3@h03P`=00803`d>01003P`=00`:2`0>30d0
4@l@00X:2P0820P03Ph>04A4A00F5QH0=SHf028R8P0S8b<00P82010@40030`<0410@0P0G5AH0100>
30d040h?018@4@0=2``200h<3@0?00l=3P0>30d03P`=00h<300920H03Pd;00l>301XIfD05A@B014@
3P1=C4X0E5=A01<B400=30X040l=00<02`X800@03@`:00l>300A40h03`h<0P0;2PP06`0=30X03`h<
00h=2`0=3@/03`l=00`<2`0=3@/02PX800L6100>3@/02`X800/71P0?2`X04@d<010:2P0B3P/03PX7
00`91P0:1P<06QHC00h:200B3P/05a<@00h:1`0:1P<05A4>00h:1`0301<?3P06014=300?2`X03PX9
014=300@30/04@d<0`0@30/01P0B41401`D6018@4@050`@07A/L04Q6A`<03P`=01403`d>010>3`0@
3`h030/600`<1P0A4@X051<=010@2P0=30H04A0<00h=2P0>30`03`d>010>400?3A004Q0A014?4003
00h<3@0300l=3P0>30d03P`=00@03P`=00D02`T:014?400D4Q<04@l@00d;300200`:2`0300d;300>
30d03`d>008040h?00D03`d@00d;3P0;2@`030X=00h<3`0200l=400<00h<3`0=2`h03`d@00/9300>
30l03`l?01<C4`092@T092@T07AbL`0E4a@03P`=0`0@30d03P0C3@l05Q0B00h:2`0=2@X03`/<018>
3`0@30d03PX;00l;300<20T04@d>01<?400@30d04@d>0`0>30d06@0=2``02`T:00l=3P0<2P/03@/<
00h<3@0?3@h05A<D00l@4`051`/03a0D05QIG@0j>ch020H900X8200A3@d03PX8014;200@2@L04PX8
00l;2@0>30d030X;00/92P0<2P/00P0>30d200`:2`0400l=3P0>30d03P`=010<3@804@/=00T04Pd>
010<3@0@30d03P/<00l=3P0D4a<051@D018B4P0=3@d00P0=2`h200h<3`0F00l=400@3Q406QPK06]Y
K00f=3L03@/>01<A500=2`h03`d@00X82`0@3Q404@lB01LE600>30l03@/>00h<3`0@3Q404@lB00/9
300@3Q403P`=00l=3P@04@l@0P0>30d3010>3`0901<A4P0?3@h04@l@00h<3@0@3Pl05Q@E01<A4P0>
30d040h?00804@l@00D03`d>00d;300@3Pl04a4B018@4@0200l=3P04014?400E4a@0518C018@4@<0
4@l@0P0A4A401P0C4a<04Q8B010@400C4a<0410@01LG5`804a<C00`05aLG00h>3P0C4a<04Q8B00l?
3`0A4A40410@00d=3@0C4a<04Q8B01<C4`0H61P201TI6@0?018C5@0@4A<04A8D01@E5`0C51H04Q<E
01@E5`0E5QP04a@F014B500C51H05QLI01HG6`0G61`061TM00<06AXN00<05AHJ01XK7`0K72000P0H
6Ad04P0I6b0061`V01/O:P0N8Rd082@_01/O:P0I7BP04ADP01hR;@0G6bH092Pc01HJ9@0G72<06QlS
01/P900H7B406AhR01PM8@805a`P00H05Q/O01hS9`0T:Bd07b@X01LN8@0V;S4201TQ900J024Y;01B
FUd0O8B701dU:00L92L06b<V01XR9@0O9bX06b<V01`T9`0I8B@05AdP01/S9P0I8B@05AdP01TQ900F
7R405AdP01XR9@0H82<0724W01hS:@0E6R004AHJ03Xo@`0J7b<201LL7`806AlO0P0H7Qh03@0C5aX0
7R8U01LK7P0B5QT05a/N01TM800G6ah082@W01PL7`0L82<04aLJ01`P8`0F5a/00P0G61`2018C5`08
01@E6@0H6Ad05aPL01HG6`0G61`06AXN01XK7`0D61T201HJ6`0;01LK7P0F6Qd051PK01DH7@0K7R<0
4QDJ01DH7`0C5Qd061TN01XH7@0J5aX00P0J61/02P0M7Al04Q<E00/?400Q9BH051XJ014H600@61P0
4ALG01<G600I6Q`201HG6@0501TJ700E5QP051DG01HG6@0C51H00P0G61X07P0C51P05QLM01PI7P0U
9R/06Q`M01dO7@0G6AD06A/H01dN7`0N7b805AHK01/K8`0C51T04aLI01@F5@0C5A<071lJ01DF3`0M
7aD06a`E01/J5P0?3P/05A@D00l:3P0M6al04a4G01PG700D4aP04A0E01LE60805A<F0240510A018>
3`0E4A803PP:01HA500A3a804a4D01@B5@0>30l040hA01HD5`0C4A@01P@701LF6@0:2P`03`hA028O
8@0L5QP030H801<=3`0E3a404`d?01H@4P0>20X040X<014;3@0@2P`04@/=00/51P0>20P040X:018<
300@2PX00P0>20P02@0@2PX04P`<010:2P0>20P03`T901L?400E2``04PP901<92P020147200H01@:
2`0C2@X04@L800l51P0@1PL04@L800l4200<0@D040H900d21P0I3Q803P@701462P0@1@T040H900h3
1`0=0PH03@<600l62P0@1@/040H;00l52P0M4QP03`@:0P0@1@/300l42P0601052`0A1PX03`@800d2
1P0>0`L03`@81`0>0`L600l31`0301462@0>0PH03@<500803`D700<03@<5ooooooooool04_ooool0
01_ooooo00P0418A01TK6P082PL02`/9010@3P0?3`d04Q4?02@S7`8010<001X04Q4=01DD400A40`0
3Pd900d<200>3@T04Q4=01DD400@3`/03`h:00H50@0<2`L04a8>010?2`0:2@D030/7014@300@3`/0
51<?00d<200C4Ph05A@@01@C3`0>3@T02`X600d<20H03`h:00d04A0<010?2`0?3PX03`h:00h=2@0=
30P04A8=00d>2@0F5a801`P500P9100I6QD03a0;00802@X500D03Pl:00l@2`0D50l00@0000l>2@02
00h=200500@3000>3@P03`h900l>2@0<2`H00P0@3`X01`0:2PD04A8<00l@2P0@4@/03@h801<D3P0;
30H01@0<3@L01@0<30L03`h:00l>2P0;2PH03Pd9008040l;0P0>3@T04@0A40`03@`800d<200=30P0
4a@?01@E400720<020T401DF4@092PD03a0;00X;1P0=3PT01PL200`=200:2`H02@X500803@h900/0
2@X500h?2P0<3@P03Pl:018C3P0@4@`03Pl:00d>2@0>3@T02`X600`;1`02010?2`07018A3@0A40`0
40l;018A3@0F5A405A@@00h=2@0200l>308040l=00P03`h<00h=2`081`D05aHD04A3@@0[:RP02PT8
010?3@802`/;00H0000000X:2P0@410020P800l?3`0<30`200T92@0300`<300?3`l030`:008030`:
00d03@d;00l?3@0?3`d02`/900l?3@0820H01@D300`<2P0A4@l01P@500`92P0F51D00`0000804@d>
00P040`=01DA4P0?2``03PX;01HB4`0810D040h?00h<3@<03@/<00l03P`=010>3`0P7Ql061HG014?
400C4A803`d>018B4P0G5aL03@d=07inOP0J6QX07AdM01<C4`0>3Ph00P0:2PX03P0<30`03@d=00X8
2@0=2``030X;010>3`0;2@X04@l@00T7200?3@h040h?00h<3@0<2P/03@`;0P0?3P`02@0A40h04Q4?
00h=2`0?3P`01`H400H50`0G5Q@020L500h=2`0600d<2P0700`;2@0;2PP03@`:00l>300>3@/03@`:
00`;2@0200P81P1300`<2P0?3`d030/900`;2@0>3@/040`;018>3@0A3@`03`T900L3000=2@H04`l<
00`81@091@803@T600l;200@30T04@d:00h:1`0=2@H03`/801LC4P0>2PT04@d<01@@3`0<20L04Ph=
01XF5@0@30/04Ph=00`81`0;1`H03PX900T7200@3Pl03@/<01DC500<2P/0?C/l01<A4P0I5aP03@/<
01DC500;2@X03@/;00d<200D4`l05A@@00d<200;2PP04A0>00T7200?3@h06aTJ010>3`091`P04@l@
05mMGP0B41406QPI01TG600>30d03`d>018@4@0@3Pl03P`=00d;300200`:2`0600h<3@0<2P/02@L8
014?400E4a@01P@50P0<2P/02P0200406QPI00`:2`0R82403P`?00l=400>30l03@/>00h<3`0@3Q42
00h<3`0800`:3@0>30l03@/>00P62@0?3`l04A4A01HF5P0C4a<200d;300900`:2`0B3Pl04@d>00`8
2@0=1`T03`T;00/7200=2@X03PX;00<040`=1P0=2@X01P0>30d040h?00h<3@0@3Pl03`d>00`:2`D0
3P`=00d03@d@00T<4@0L7B40<C8f01hO8`0B41<03P/<00d9200F4@h0614?00T1000=1@804`h<00D0
3P`=01l02`T:01@B4`0C4A806aTJ00T720081PL030T:00`82@0B3Pl03PX;010<3@0D4Q<03P`=010>
3`0?3`l03@d=00840`0D5AD05aDH00400P0?3A002`T<00400P0E4aH07adP0:f[[P1;BD`02@L:00l=
400B41<04a4D008040hA01P02@L:01LE600Y9bX04a4D00400P0?3A007Q`O00H41`0=2`h05A<D00/9
2P0?3@h04Q0A01TG600B414061HG00/92P0=2``05aDF01@B4`0J61T01@<4018@4@0?3@h201LE5P03
01@B4`0B41404a4B00804a4B0P0D4Q<01@0C4A804@l@018@4@0E4a@05Q@E00804Q0A01@05A<D00d;
300?3@h05Q@E00l=3P0D51@061PH01<C4`0=3@d03Ph>01PH600?3`l07AdM01@D500C4a<0410@01HF
5P0I6AT061PH00/;2`80410@00L04A4A01hN7P0410@07QhN018B4P0[:b/03`l?00H051DG00L092DW
03<d=P0I6Q`06Q/M01HG6@0E5QP061TM00804a@H01H05aPL01@E6@0@4AD07QlS01@E6@0M7R804a@H
01HG6`0L7b@05Q`U02L^>01MI6h0QhjH02H]=`0J8B/02Q4K01PO:@0R:C<04QTS00T@6P0A5ah07R<W
0P0I7R801P0O92P0:Bhb01TN8P0P9BT092T]020U:@808BHZ01P06b4V01HO900D7B805b0U01`U:P0N
9b`08R/`01hW;00H8BH06b@Y01hW;00K92T07BDY01TQ900C6ah05alR01TQ900H82<05QhQ01/S9P0I
8B@05alR01/S9P0L92L201PO9@0?01@K8@0E7B0072@W01@L7`0K8bD05AdO01DN7@0G81l04a`K018I
6@0E6A`05a/N01XN8@0K7b806AdP00<05QXM01807B4T01`P8`0D61/04QHI01PI7P0J6b005QLL01<D
6@0H6Ah05AHK00h?500N7b@05aPM01<D6@0G61d07QlS01HJ6`0F6QX201DI6P0:01@H6P0D61/04ADH
01LK7`0E61d03a8G01PK800=3Q<07A/P01/H6`8061HI00T05ADG014B500G6a`07b@U02X`<00F7ah0
3QLF010F5P0E6AX00P0F5aT02P0G61X06AXL01TJ700L7Al04a@F01PI6`0J6ad04A8D010A5@0L7B<2
01TJ7`0F01`M800L7Al06adL01PI6`0F5aT061TM01/L8@0D51`03PlD01DI6`0F61L051HE018D400F
5a8061TC01<D3`0J6AD05QDC00l=3P0G4QH07Q`O01@B6@805A@I02L04a8G018@4`0C4A@05A<F01LC
500E4A804`l@01D?4@0F4Q@04Q0C00l=400=2`h03P`?014?4P0B3a802`H:01`G6`0c;S802`T<00H1
1@0J5AP050h@010:300C3@l05@lA018<3P0?2@/04`d?01H@4P0C3@l03PP:00d72@0?2@X05a4A00X4
100D3Ph0100001@>3P0A2`/00P0>20P03`0=1`L03PP800h8200B2P/04@L800l51P0D2P/05@/<00h4
1@0=0`@04PP900l61`0N51D03P@501D;300201052@804@H:02004PL;01<8300>0`L040D900h31`0E
2Ph040D900l4200?10X03@8800`11`0A1P`060dC02<H7P0A1P`040D;00h32@0=0PP03P<90146300F
2`l02P0301L<400>0`L040D900l4200F2`l0304501H;3`0J3a<03`@800d21P803`<70P0@10P20145
2@060104200?0`L03P8600h21P0?0`L040@85?ooool001_ooooo00<02@T900X;200?3`d00P0>3P`0
1`0A4@l0<S4]04E4@00Q81`051<?00`;200100000P0=30P01@0>3@T03`h:014@300A40`02`X600<0
4a8>00`030/700@3000@3`/03Pd9010?2`0=30P04A0<00/:1P081`<01`H200T8100<2`L2010?2`H0
3`h:00@040l;00l>2P0?3PX03`h:0P0>3@T04P082@D010D002HW8P0E5Q408B8M00P910092PD03@h9
00h?2P0<3@P03a0;01<C3P0510005A@?00l>2@0K6QD051<>014@2`8040l:00T03@`700l>2@0?3PT0
3`l900X;1@0310001PL100d>20082@<01P0=3PP07P0=3@P04Q4=01@C3`0@3`/04A0<01<B3P0B4@d0
3@`800`;1`0@3`/03Pd900l>2P0C4Ph03Pd900l?2P0B4`h03Q0;018D3`0C5A00418=00`=2P0H6A@0
5QLB01@C3`0@4@`030d800d>2@0@4@`03Pl:010A30803@h9010030d800T:1@0A4Pd092DP014@300>
3@T030/700d<200<2`L02`X600D400061@4030/7018A3@0D4`l04A0<0P0<2`T200h=2`0@00d<2P0<
2`T05QDC00/:200J6AL02`X800L6100K6QP02PX:00h>3P0G5aL0410@00X:2P0D51@03`l?00h>3P80
30`<00@03Ph>00l?3`0=3@/03@d;0P0<30X200h>300?00L71@0<30X05aLE01@D4P0820H030`:01@D
500E5AD04a<C00L51P0H5QL01@<400l;300<20T03PX;00805Q8C00<020@5010>3`0>30d00`0=2``0
4`0>30d04a4B01hL7@0E4a@03`d>010>3`0<2P/030`<010@400Y:BT04A4A01TI6@051@D03@d=00X:
2P092@T02PX:00h>3P0?3`l00P0D4Q<05P0@3Pl04@l@00T7200>30d040h?014?400>30d030X;00d;
300=30/03`h<014@3P0@3`d04a8@01LF500B4@l061LE01/J60071PD03@`:01hM6`0B4@l400h=2`0?
00l>300=30X030/900d<2P0?3P`03Pd;00d<2P0?3P`03@d;00T91`0820H03@d;014@3P0C4Q004A0>
008040`;03404Ph=01<=3@0;1`@04@d:01LC400B3P/03`/8014=2P0?2`P040`9014=2P0>2PL03@T6
00l;200@30/03@T8014=300C3`h04@d<01dI601mNGP0<bl^00d9200I5A@03`/:00X61@0R82400@00
01HD5@010000518C00X92@0200404@l@018@4@091`P04@l@00h<3@0;2PP03`h<00<10P0:20T04Q0B
00X82`0@3Q404@lB00D31P0100803@/<00807A/L00D03`d>00L51P010000518C00L51P0500h<3@0=
00d;300D4Q<04Q0A010>3`0G5AH06QPI00d;30050`@03@/<00l=3P0;2@X04@l@03Hd=@0200h<3`07
00d;3P0<2Pd03P`?00l=400;2@`030X=00X82`0200h<3`0800T72P0>3Ph03`l?01@D500B4Q803P`=
00l=3P0=2``2014=3P0600l;300>20X03`T;00`82@0=2@X03PX;200?2``01`0>2P/02PP900/92P0:
20T03@/<00h<3@0=2``01@0>30d03@0>3a403PlC00/<400C51P03`lA00/9300C41403PX901D?3`0J
5A804`h;01H>300C3`d01@0>30d0?P0@3Pl02`T:00/92P0:20T04@l@01<A4P0A3Pl04Ph?01@@4@07
0`@06ADF01TG60081PL03`l?03Hf=P0C5A@05QPG00/=30092@/061HI01@B5@0b<3<05aDH00/9300B
41<04a4D01HD5`0E4aH01@<6010>4@0<2Pd01`D800l=400>30l0518E01TG6P0@3Q405Q@G010>4@02
00<02@L:01HD5`0?3@h081hO01@B4`0J61T03P`=04U7B00X9RL06aTJ01DC500G5AH040h?018@4@0K
6AX06ALH00/92P0C4A805A<D018@4@0@3Pl04Q0A0`0C4A806P0B41404@l@018@4@0E4a@061HG01HD
5@0@3Pl0;B//01/I6P0E4a@061HG01@B4`0=2``05ADE01hN7P0O7al061PH00l?3`0;2`/07QhN01PH
600@410061PH010@400:2PX04Q8B0P0P82002@0C4a<051@D01TI6@0G5aL07QhN01LG5`0>3Ph0820P
010@400601@E5`0701hO8@0Z:bd05aPJ01XK7@0F5aT05aPJ01LH700301TJ7P0Q01XK7`0L7B405AHJ
01<D600L7B405aPL01`M8@0M82D07b@^01DL9P2^]K`0dm[T03a3C@0D6bD09B`f02<Z=00B6B<0<CQ2
030g@@0G7B@0;c@h020U:@0F6al0724U02/`=00M8RH082DY028W:`0O92P08BHZ028W:`0N9RX072DZ
00806B8W00<06R<X01/T:@0K92T00P0J8bP301`U:P0301hV:P0K8bH05alR00806b<V01T06R8U01TQ
900I8B@06R8U01/S9P0M9BP08BT/00lF700I82H06R4W01PP8`0D71l06b<V020X:P0L92H06R<R01LP
7`0D7A`06R<R01/O8P0L82<07B4T01`P8`0I7B0051PK00807B4T0180720S01hR9@0O8bH07R8U01DF
6`0G61d04a@I014B5`0D5AX04Q<H01/L8@0<3A80:R/`00D62`0J6b004Q<G01PL7@0H71`201LK7009
01LK7@0F6Qd04aLJ01PK7`0G6Ql04aHK024T:@0K72005Q@I00805Q@G00/05aDH01LH6P0I6Q`04QHG
02T];P1cNGT02a4A028Z:@0B61P05a/L01PI6`0301LH6P0S01PI6`0W:2X05aPJ01<D5P0G61X06AXL
01dN8P0J6b0061TN01LH7@0I6Qh061TK01LH6P0L7Al06Q/O01`M8@0O82D061TN018C600E6AX05QPG
01@F5@0B51405QHD01PI500G61<06QTG01HE4`0?3@h050lC01PF6@0E4aT051<H01<B5`0B4AH00P0C
4A@06`0?3A004`l@01@@4@0E4A806Q@F01XG6@0F51L04a4D00l=400=2`h03P`?01HB5P0@2`l02PD9
01@?4`0@2`l03`X>01H@4`0C3@l03`T;014;3@0D3Q004@/=00l92`0B30h05@lA01<=3`0200h82P07
00h82@0@2PX01000014;2`090`<05Q0@014;2`0200h8200500d71`0>20P03PP801082@0@1PL00P0A
1`P0200@1PL03P@500L0000O5AH03P@50147200:00404@L80P0?10P301462P0>01052@0D2@d04`P<
01872`0?10P03P<700d21P0?10X03P<900`11`0?10X050T?01/@5P0@1@/200l42P0?00h32@0?10X0
40D;00X00`0700002P4301L<400C20`01`0001T>4P0@1@T06@hB01dB5P0C20`04@H:00804PH:00H0
4@D90104200@10P03`<70104200?0`L200h21P0300l31`0@10Sooooo01?ooooo000Kooooo`0?01TH
5@0?3`X092<O01@C3`0C4Ph03`h:00<2000G5Q802PT500h=2@0D4`l05QDA00/:1P0>3@T03`h:0080
40l;01<03`h:014@300A40`030/700h=2@0C4Ph051<?00l>2P0=30P040l;00d<200B4@d030/7028Q
7@0@3`/030/7014@300D4`l030/700H03`h:00<03Pd900l>2P0?3PX00P0@3`/05P0@40`04Q@?03Xl
=`33aL00DE=>01@F4@0E5a803a4<010B3@0<3PT0418=02`^:@0W9b8030/601DD3`0:2@@05QD@01@C
3P0<2`H04Q4<014@2`0>3@P200l>2@07010@2P0<3@P0414;00h?2@0V9b400@80010A2`0500h?2@09
00/;1P0>3@T04A0<014@300D4`l04a8>010?2`0<2`L02`X600803`h:00l04A0<01LD4@0A3`/03Ph9
00`=20092`H0310;00X?2@0C61802`d800X:200:2@D04a4=00d=2@0:2`H00P0>3`X00`0;30L03@h9
00`=200200h?2P0C00`=200B4`h09RLR018A3@0A40`03Pd900d<200?3PX03@`801DD400G5Q806APD
01@C3`0?3PX03Pd900/:200<2`T03Pd;00l>3003010?3@0300/:2@0@3`d03Pd;00804A0>00H0IVAU
01<A4P0@3Pl05A<D01`J6`0C4A8200l=3P8040h?0P0?3@h200l?3@0300d=2`0<30X03@d;00803@d;
01<03Ph<01/K6@0H61H02PX8010A3`0<3`l02`d?014D5@0<3Q002`/=01<C5@0=30l01PD800/9300<
2Pd02PP;01<A500@3Pl03P`=00<03@/<02003P`=01HD5@0F51D03`d>00h<3@0=2``020H700l?3`0C
4a<0E5AD00d=3@0E5AD03Ph>01<C4`0@41003`l?010@400B4Q804a<C01@B4`0C4A803`d>010>3`08
1PL03P`=014?400?3@h03@/<00l=3P0C4A805Q@E00l=3P802`T:00X030X;00d;300@3Pl02@L800`:
2`0A3a003`d>00X82@0B4A004A0>0`0?3P`0100@3`d03Pd;00d<2P0=30X300l>300P00`<2P0:2PP0
30`:018B400C4a404A0>01@C4@0F5A<04`l>018>3@0E4A006A<C00`81@0?2`P04Ph;010<2@0?2`P0
40`900l;200@30T04@d:00h:1`0=2@H03`/800h:2P0@30d03`/<00d92P0?2``06ADF01`I6@0>2P/2
010<3@0N01@@4@0@3@h04@lB01LG6@14A4H03@d?00T92`0>3Q004A4C00@41P0?3a404Q8D00l?4@0<
30d03@d=00X:2`0J6Ad02`/>010?500=3A802@P?018A5P0<2`l03Ph@014A4P0;2`/05aLG00P8200E
5AD04a<C0P0<30`0300:2PX03@d=00l?3`0@41003Ph>00`<300@3Q403@/>00`:3@0@3Q404Q0C00/9
30804a4D00P030X=00@21@0C4A@02@L:00l=400=2`h02`T<00d;3P803P`?01<03@/>00l=400>30l0
518E01HD5`0A3a80410@00h>3P0A4A403`l?00h<3@0A3a003`d>00h:2`0@30d04@d>010:300=1`T0
40`=00@03`/<00<03PX;010<3@0B3Pl00P0C3a002`0@30d03`/<00h=2`0?3P`030/900l>300C4Q00
4A0>010?3@0?3P`03Pd;00803@`:00d02PT:00`<3@0=30h03`l@014@4P0=2`d03@/<00L61@0:1`L0
40d<01<@3`0E41003P/<00D03P`=010030X;01<A4P17ADH07Q`M018@4@0<2P/04@h?018>3`0?2``0
4Pl@04I4A@13@D8040l@01@D502?T8l0@4910P0=3`h03@0<30h04A4C018B500O7b4061PJ00l?4@0B
4Q@04a<E00l?4@0=3@l05aLI02XZ;00V92L00P0>30l0800B41<03`d@00l=400<2`d05Q@G00d<3P0M
6ah05aDH00l=400H5QL020L701DC500610D02`T:020N7`0M6a`04a4B00h<3@0@3Pl03`d>01<A4P1G
EEH0>3Hg00l=3P0>30d04@l@01DC500=2``040h?01<A4P0D4Q<04Q0A0P0?3@h0200C4A805aDF01TG
600E4a@03`d>01dK700<2P/03`d>0P0F51D06@0H5aP03Ph>014C4P0H6QT071hM01dO7P0J71/07AlN
01@F5@0=3`h0418A01<E500`<S4092@T01@D500U9BD04a<C018B4P0A4A406a/K01PH600F5QH05aLG
010@400E5AD00P0D5AL301DF60805QLI02806a`N01HG6@0J6ad061TK01XK7@0J6al07QlS01`M8@0I
6Qh06Q/O01dN8P0G61`06Q/O01TJ7P0F5a/06a`P014D6@0W;C@09Rde0499D@1lPh/0<cY201`S:`0C
6R80:C0h07=jPP0P9bl06B0X020V;00_=3P08BHZ01/P900M8RH0:2da0P0O92P201`Q9@07024V:P0P
9BT07bL[024Z;`0O:2d06b@Y01TR9`0201XS:00601`U:P0N9b`07BH[01/T:@0L9BX07BDY0P0I8B@0
100L92L06R8U020X:`0R:Rd201PP8`0Y01/S9P0E7B006b<V01HM8`0M92X05A`R01dU:00>5QT05AdP
01<K7@0D71h06b@S01XS8P0E7Qd05b0O01PL7`0I7B006alR01XN8@0H71l05ATL01@H6`0I7B006alR
02<W:P0[;c806QhQ01LJ7`0I724061/P01DH7@0F6Ah051LL018E6P0J7B8061/P01DH7@0N8BH07R8U
01LK700G6aX00P0F6QT05P0F6QX05ATJ01PL7`0I7B0061`O01@G700Q92T071lR01/K7P0L7Al05aLI
018B500C4aD06AXL01@E5`0K7Al0:Bd^01TK7@0K7b00828T01TJ700H6A/401HG6@0J028S9@0H6A/0
5AHH01PI6`0I6Q`06a`N01LK7@0D61/05ATL01HJ7@0E6AX04aLH01PL7@0F6Qd061`O01XN800E6A`0
4ADG01DI600F61L051HE018D4`0F5QD061PF01HF5@0E4a@201<A4P0601HB4`0E4aH05Q@J018A5P0A
41D04Q4F0P0E4aH06@0@3Q40510A01@@4@0E4A806A<E01PE5P0C4a<04a4B014?400?3@h040`=00d9
2P0@30d05@lA018<3P0G4A<050d?00l92`0A2`d03`T;014;3@0C3@l04P`>010:300A2`d00P0B30h2
014;3@06018<3@0B30`02`D5014;2`0=1`L04@/;0`0>20P04@0=1`L03PP800h8200?1`L040H70188
2@0@1PL03`D601061`0I3a00AS`m024G600C2@X03`D601061`0A1`P04PP9008050X;00T04PP90106
1`0A1`P0308301D;3008000060h?01`B500?10X00P0>0`T200d2200300l42P0>0`T03`@:00804@H<
00h040D;00l42P0?1PP04PL;00l5200B1`/03P@701062@0B1`/0304501<8300E2Ph03P<700`21@80
50P<00H04PH:01452@0@10P03`<701452@0@10P200l31`030104200A1@Wooooo01?ooooo000Koooo
o`8040d801@06aPC00/80`0M6aH03`h901TH500H5a<02`X601<B3P0D4`l03@`8014@300?3PX03@`8
00h=2@0@3`/04a8>00`;1`0A40`04a8>00`;1`801PD100`02`X600d<200A40`03`h:018A3@0:2@D0
7ahJ00X91@071P8040l;01HE4@0=30P600l>2P803Pd900P03`h:010?2`0@3`/0414<00d?2P0;3@P0
AdU401`N6@802P`700l01@L3010B3@0B50l030h900H80`0:2`H02@P300/:1@0A40/03`h901DD3`0>
3@P04Q4<014@2`0>3@P00P0@3`X02@0C4`h03@h800/<1P0M7QP0HV=M028S7@0=3PP02``600`=1`03
00d>200V014A300A40`03`h:01HE4@0P7a/06QTE014@300>3@T03@`800l>2P0=30P03Pd900d;1`0A
3@X03`l;010A300G6A@03Q<=010E3`000P00:bdX05iMF@0E51001`@300X91@0@4@`06a`G01DF4@0<
3@P0414<00h?2P0=3PT03Pl:00d>2@0:2`H010D100h=2@0@3`/200d<200<018A3@0@3`/030/7010?
2`0C4Ph03`h:00d<200@3`/030/900d<2P0?3P`040l=0P0A40h0100=30X04a8@00T81P0920H200l>
300702HT9@081PL040h?00@20`0@3Pl00`4200`:2`0400h<3@0400`:2`0?3`d03`l=00d=2`<030`:
01@020P6014A3`0820H010@200/;2@092`P01@/;00`B4P0010@0318B00/?40062P/030l@00P92`0C
4aD06ATK00T92`0H61X040h?00h<3@<03@/<00@03P`=018@4@0>30d02`T:0P0?3@h02`0;2@X02PX:
01LG5`051@D0;Bd]00`<300410@0410@00d=3@0<30`02`/;008030`<0P0<2P/01@091`P03@/<00T7
200@3Pl02`T:00803@/<00P03`d>018@4@0;2PX02@L801@B4`0G5AH030X;00h<3@<04Q0A00H01`D6
01/I6P0100002PT8010?3@0>3@/200d<2P0500h=2`0?3P`03@`:00d<2P0>3@/00P0?3P`05@0?3`d0
3@d;014A3`0Q8Al08b<Q01DD4P0;2PP030/900`81`0=2@P03PX900h8200C3``04@d:00l;200@30T0
4Ph;01@@3@0>2PL03`/8010<2@0200h:1`0H010<2@0<20T02`L800d92P0C3a005a<D01PD5@0Q7Ah0
2PH701TE5P0M6AX02PH700/82@040PD03`lA010@4P0F5QP02PX<00l?4@0D51H061PJ028R900P8280
2`/=0P092@/06@0L6al01@@901/J800=31@04a8J01<A70081`h04A0E02<S9@0@414030`<00H61P0G
5aL03@d=00P8200=3@d03`l?00d=3@0?3`l0410@00l?3`0<30`020P800l=400=2`h00P0>30l01P0=
2`h03P`?00d;3P1?CE000@0201lM80803@/>00L03`d@00`:3@0<2Pd03`d@00h<3`0<2Pd03P`?0080
40hA01405aDH01TG6P0D4QD04Q8B00h>3P0?3`l02`/;00X82@0=2``03P`=00d92P0>2P/04@d>00l9
2`0;1@L04Ph?010<3@0400h:2`0<00l;300@30d04@d>014=3P0?2``03PX;00l>300@3`d02`X800X9
1`0=30X03Pd;0P0?3P`03`0>3@/03@`:00d<2P0?3P`02PT7010<3@081PD02PP901<A4P0?3@h02PP9
00/92P0=30d020P800`:3@0600h<3@09014?400100007adN00L61P0M6a`03@/<00T8200I5aP081hO
00803`d>03<05ADE01<C4`0G5aL04aDD00H:2@0Q9B@07R4P00T92`0@41807AdO00@41P020P@04A4C
00@41P0=3@l030`>02@T9P071`T0D51B03@b=@0F51L030X=010>4@0?3A004a4D01lM80010080<Blb
08f;SP0V92L03@/>00<10P0L6Q/03P`=01@B4`0C4A804@l@028P8@0K6AX0518C010>3`0>30d040h?
00T7200?3@h04@l@01XH6@0C4A804Q0A00/92P0?3@h00P0C4A809P0A3a003@/<010>3`0B41404a4B
018@4@0A3a0040h?01<A4P0V92D06ALH00h<3@0E4a@051@D01PH600?4A0030h=014C4P0F61L05ALF
00d?3P0D5QD04aDD00h@3`0D5QD0AdU803<c<`0<30`07alO01<C4`0F5QH04A4A03Lg=`0:2PX0410@
00`<300R8R80410@0P0D5AL00`0E5QP05QLI01HG6@0301LH6P0501XK7@0I6Q`06Q/M01TJ700K7200
0P0H6Ad07P0I6Qh05aPL01DF6P0H6Ad07QlS01/L800P8BD0<34e02<V:`0N9R`04AXO01<L8@0h@DH0
5b0U014J7`0C7240;SLl07^4R@0B6b003AHK014G700I7R804QLK01TN8P0K82@08BHZ01XO8`0K82@0
5a`P01TN8P80724U02H06B4U01TT:P0K9R`06bH/01XU:`0L9bd09S4g02D`=P0M:2h06RD[01`W;@0K
9R`07RHZ01dU:00K8bH07RHY020X:`0]=CP0;SHi024Y;00P:2/08b/^01XR9@0M9BP04a`Q01PQ9P0B
6b007RPZ01LQ8`0Q:bd08B//01/U9P0K9B@082XY01`V9@0E7ah05AXM01LK7P8061`O01H05a/N01HJ
7@0F6Qd07b<V024U:00X;2l0;c<f01LK7P0E61d05QTP01PK8P0E61l04QDL01<F7@0J7B@02PdD02HY
<00=41L06QdT03@g?00F6QT05QXH0P0E6AP0500D61P051PI01LK700G6ad06AdP018F6@0F6Qd03a<F
010D5@0F6AX05ATJ01DF600K71h09bPZ01`M7`0D5AL0824S01DE5`0H6A/051DG0P0B4aD01P0C51H0
51DG01HG6@0G61X051DG01LH6P806AXL00P05AHH014B500F6QX05QXK01PL7@0L82406alP01TM7P80
6QhO01d06alP01`P800I7Ah05a/J01DI600F61L051HE018D4`0F5QH061PH01<C500A3a004Q0A01DC
500G4a@0518E01HD6P0@3a@03`hC01<B5`0F51L05A<F01@B5@0F4Q<0510A018>3`0C3@l04@h?00h>
3P0300l=3P04014=3P0H4a@06Q@F01D<3`803PD800<05@X>01L@4P0D3Q000P0B30h201<=3`0;014;
3@0?2@/03`T;014;3@0B30h04`d?00l92P0;1@D040X:00l92@0C3@d00P0B30`200h8200?00d71`0>
20P03PP8018:2P0A1`P040H701D;300F30d04@L800L0000U6a`03PD501@:2`0=0`@03`D600804PP9
0P0C2@X02P0A1`P03`D601882@0<0P<06@l@00`20`0Q5aP09adN00d2200>0`T201052`0400h32@0=
0PP03@8800h32@804@H<00D040D;00h32@0<0@D06a0D00l4200200d21P0701T>4P0B1`/040D901<8
300D2@d040D900l4200801452@803`<70P0A1@TDooooo`006oooool03P0?30L0514<018?2P071000
61HA00/:1@081`<02@P500/:1P0F5A404A0<00L60P0C4Ph040l;0P0=30P0100A40`051<?00l>2P0@
3`/201<B3P0>01PG4`0P7a/03`h:010?2`0C4Ph040l;018A3@0:2@D051<?00L60P061@4030/7014@
300;2PH600l>2P0H00h=2@0?3PX03`h:00l>2P0@3`/03a0;00/=200F61<05aTD01XL5`0>40/01`T4
00d?2P082PD01`T400d?2P0H6QD06AXE010?2P0920<04A0;00L60@0B4@`030/60P0A40/03@0>3@P0
4A0;014@2`0;2`H030d700/<1P041@40;BhX00`=1`082@<02P/500/<1P0<3@L00P0=3PP01`0A4@`0
40l;00`;1`0C4Ph07QdI01LF4P0?3PX00P0>3@T08`0A40`03@`800`;1`0?3@T03`/800/;1P0D5A00
6A/F0045000D6A<02a0:010B3@0P7a/00@0001DA3P0920@03a0;01XK5P0D5A002``700h?2P0<3@P0
2@X500X;1P0B4`h05QLB01@E400=30P04A0<00`;1`0:2@D04A0<00d<200920@02`X600<03Pd900@0
40l;00X91`0;2PP03@`:0`0>3@/00`0<2`T05aHD00/:200200`;2@0600h=2`030@804a4B01/I6P09
1`P04Q0A1`0=2``200h>308030`:0P0=3@/050061P@05aLE00`<2P0820H04A4?00H81`0A5aL0CeQG
01DN7@0740l03Q@D00lE5@0<41401@H801PI6`0c<cD04A4C010@4P0@3Pl03P`=0`0=2``03@0>30d0
3`d>00d;300=2``03`d>010>3`0?3@h03`l?00H61P0O7al06ATI01LG5`0>3Ph00P0;2`/03@0<30`0
3Ph>00l?3`0@41003`d>00h<3@0:20T03@/<00T7200A3a0030X;00l=3P0>30d00P0<2P/03`0@3Pl0
4Q0A00d;30030@807A/L05iLG@1EDe@02PP9010>3`0<2P/05aDF0040000I61L04A0>00h=2`0200`;
2@0300h=2`0?3P`03Pd;00803Pd;01L03`h<010?3@0B4Q003@d;00X:200D51806QXH018A3`0;2PP0
30/900l;2P0A3@`040`;00d71`0A3@X03PX700d91P0A3@X04`l<014=2P0=2@H03`/8010<2@0200h:
1`0U010<2@0B3Pl02`L800d92P0A3@h030P9010<3@0H51D01P8300T51P0>2P/040`=01@A4P0>30l0
2PX<01LG6@051@L05ADG010@4P0>3Q0061PJ07emO`2?Si408R8T00X:300@41801PD901<B60020@T0
CD]F02DS;P0;2A@03@/E02TX;P0o?T<05aLH00d=3@0201@D500400L71`0@41003Ph>00H61P<03`l?
02T03Ph>00/;2`0820P040hA00h<3`0@3Q403P`?00`:3@0A3a804Q0C01`J7@0I5aX00@02055?DP0T
8RD03`d@00d;3P0>30l04Q0C00h<3`0:20/030X=00h<3`0=2`h04a4D01@B5@0?3A004A4A00d=3@0>
3Ph02`/;00T7200<2P/03`d>00l;300@30d04@d>010:300>20X04`l@010<3@0200h:2`0300l;300@
30d03PX;00D03PX;00D04A0>01@C4@0>3@/02`X800d<2P0600h=2`0=010=300?2`X050h>018>3@0<
20L03PX;010>3`0;2@X030`>01HF60061PP01@D700h=3P0500h<3@0?00l=3P081PL08R0Q00T8200C
4A805A<D01TG600200400@0000h<3@0J61T051@D00820P0B4Q803@l>00801@T800/04QHE00`<3P0D
51H020P:03/k?@0i>C/04A4C01<C5@0H61X051@F0082100200`<3P0301hL7`0;2@`030X=008040hA
01404@lB01DC5P040PD01@<602HT9`0610L03@/>01<A4P0J61T0518C01PF5`071@H040h?01lM7P0L
6Q/05aDF018@4@02010>3`0801<A4P0G5AH05aDF01/I6P0?3@h04Q0A00d;300?3@h2018@4@05014?
400?3@h04@l@01<A4P0B41400P0@3Pl0600B41405Q@E03<a<P0O7Ah03P`=01@B4`0?3`l051HE014C
4P0@4Q404A<B010B4@0:30/03Q0?01<E500G6AP06Q`K014C4P0P8R406QXJ010@400L71`03Ph>01@D
508061PH00H07alO07YjNP12@T808B4Q01PH600D5AL201DF60<05aPJ02H06AXL01/L7P0M7R0061TK
01hO8@0G61X06Q/O01DF6P0H6Ad07QlS01`M8@0I6Qh06Q/O01dN8P0J6al071dQ02TZ;P0O8bH051`P
020Y;P0M9R/05QlT01<L8@0S;34082T^014J7`0Q:Rl04Q/P02D^<`0K8RL08BHZ01HK7`0L8BD07b@X
02P]<@0O92P06QlS01LL80<06AhR00<05b0U01LR:00K9R`00P0K9R`03P0O:S00:cHl02Pc>@0M:2h0
6B@Z01hY;`0M:2h07RL/01/S9P0H82<06b<V01hV:@0X<3<09Rha0P0M9BP0300R:Rd07RHY01dU:00@
6Ah06B8W01dV:`0A6ad04adO01/U9`0d?Sl09Bl`01LQ80806B<R00H05R0O01dR9@0M8B@07B4T01XN
8@0H71l201LK7P0C01/O8P0F6Qd051PK01TM800B5QT05aXQ01PK8P0L7bH061/R01<F7@0E61l092L^
0454B`0<3aH01`XA01`O9P0@4aP061`K01PM6P0201LK6P0=01LK6`0F6Q/05ATJ01DI6`0K7b805ATL
01LK7P0A5AP04aLH01DJ6`0E6AX051PI01XM7P02028S9@0501DF600X:2X0410B01/K7@0@41800P0A
4Q@0400B4aD051DG01LH6P0I6Q`061TK01XK7@0E5QP05aPJ01XK7@0H6A/05QXI01LK6P0J7Qd07B4R
01/O800I7Ah201PL7@806AdL0P0G6aX09`0E6AP05QPG01@F5@0B51<05QHH01PH6P0F5QP0518C01<A
4P0D4Q<04`l@00l=400E4aT03`hC010?500E51T05Q@G01@B5@0B41<0510A01<?400B3Pl050h@01@A
4P0A4A404@l@00l=3P0>30d04@d>02DP8P0Q6ad040L:01L>4@0J4A@05``@01L>4@0E3a4050h@01<=
3`03018<3P03010:300>20X040X<00804`d?00H04P`=00h8200E3`l03PP801D?3`0;1@D300h8200@
00d71`0>20P03PP8018:2`0A1`P040H701L=3P0I3a004PP900P0000A1`P02P4201<92P0=0`@04@L8
01061`803`D60`0>10D0200D2P/03`D601@:2`0800004`T:01@:2`0>0`L03`@:0`0A1P`00`0?10X0
3P<900l42P0201052`803`@:00H02`0401D:3P0:0@<03`@801H=3`0<0@D201872`0401<8300B1`/0
4@H:01052@803`<70P0@10P401452@8040@80P0A1@TDooooo`006oooool0300C3PT04`l901<@2P0C
40/03@X5018?2P0E51005A@A018A3@0C4Ph030`800l@2`D03`h:00d03Pd9014@300=30P03`h:018A
3@0P7a/0;RdY01DD4@0@40d04Q8=01<B3P0N7AT06QTD00<04A0<00<03Pd900d<200?3PX01P0?3PX0
2`0A40`040l;00l>2P0?3PX03Pd900d>2@0<3`T02@`700`?2P0O8ad020X60080310:00X03a<=00hB
300:3@P01`/600X<200G5Q403@`700l>2@0G5Q40:bXU0`0@3`X02P0?3PT04a8=01@C3P0@40/0414;
00h?2`0?40/01PL200`=1`0A4P`200`=1`0700h?2@0?40X0414;00h>2@0?3PX03Pd900`;1`02010?
2`0J00d<200;2PH03Pd901@C3`0@3`/03Pd901LE4@0@30T03Ph:010@3@0=3`X0<SPb08F;Q@1BEe40
3a4<00h=2P0B4@d03PX8018A3@0<3@P03Pl:014B3@0>3`X02``700l@2`0>3`X200`=200;00l@2`0E
5Q402`X6014@300?3PX040l;01XI5@0H5a<051<?014@300?3PX00P0@3`/00`0<2`L03Pd;00h=2`02
00l>300:00h=2`0=30X030/901@C4@0>3@/05QDC00`;2@0=30X04@d>01<?408030P90P0>2P/01P0C
3a004@d>00h:2`0>2P/04@d>014?40803@d;01P030`:00d=2`0?3`d03`l=010@3P0D51804A4?00d=
2`0>3P`03a4@01TP801nR8P05R0P00H?3`0P:2T01Pd>00`A4`052@/01`X<01/L7`061PT0410B010>
3`0>30d300d;30803P`=00/03`d>014?400?3@h03`d>014?400D51@04A4A00@4100F5QH04a<C014A
4@0200d=3@0N00h>3P0?3`l03`l?010@400?3@h03P`=00X82@0>30d02`T:01<A4P0=2``03P`=00d;
300;2@X03@/<00l=3P0<2P/03P`=010>3`081PL030X;01LE5P091`P05Q@E00/92P0;2PX04Q0A040o
?P0D4a404A0>0P0>3@/00`0@3`d04A0>00l>300200h=2`0;00l>300A40h04A4?00h>300<30X02@T7
00X:200=30X03`h<00h=2`0?2`X00P0A3@`01P0?2@T02`L400/7100B3P/06aLD01XF4`803@T600L0
3PX7010<2@0>2PL03PX7014=2`0C3`l02PH600804`l@02H020D402HR8P0L61T04`l?018>3P0<20T0
4@d=00l<3@0<2Pd04a<F00T93@0:2@h04A0D00/;3`0<2Pl030/?020O8`0A41D02PT=00d<4@0A41D0
2PT>01HE700>3AD0P7j:02LU<P0>31P05Q@N010?5@0L6b002@T:01@D500A4A40De=C02`/;00B4Q80
3Ph>014A4@803Ph>0`0=3@d03@0=3@h04Q0C010>4`0B41D03P`A00/93P0D4QL06QPM00h<4@0<2Pl0
4Q0E02l]<P0B41D00P0>30l01`0C4Q@05QDH00h=40071PT03Pd@00l>400=30h00P0@3Q40<@0:2@`0
2`/<00X:2`0>3`h03@d>00`;300?3Ph04A0A01DB500E4Q<04@h@018=400D3a004Ph?00l;300>2P/0
3`/<014=3P0B3Pl04@d>00h:2`0<20T03@T:010<3@0A3@h03`h;01HE4@0A40`03Pd900l>2P0>3@T0
30/700d<200?3PX040l;014@300>2@H06A@A00/5100E3`d05A4?00L30P0W92D040hA01@C5`0d=3P0
61TM00P93@0@41<01`0>30d08@091`P03P`=00d;300<2P/040h?00`:2`0?3@h03`h>00`<300?3`l0
3Pl>00/=300<3Pd041<B00<5100A51<03`lA00H6200C4aD0AdM903lo@@0;2`d051@F00@41P0B4Q@0
2`/=01@D5P0>3Q004Q0C00l=400D4QD030X=010>4@0201<A50804Q0C00d03P`?01<A500C4A@0:RPZ
03Le=`0C4A805Q@F010>3`0D4Q<040h?018@4@0C4A8040h?00804Q0A00@03`d>00h<3@0C4A807adN
0P0E4a@2010>3`0<014?400B41404Q0A018@4@0A3a005aDF01TG600F51D04a4B018@4@0E4a@061HG
0P0B41404@0G5AH04a<C01<E500A5A@041@C010C4P0?4a803A4@014D4`0F6AP04QHE01XM700@51<0
2P`;01<D4`0D51@0410@008051@D0P0C4a<0A@0N7Qh0LW9b03lo?`0Q8B406QXJ01@F5P0E5aL05QLH
01LH6P0H6A/06AXL01TK700P8b@071lP01@F600S9BL05API01TK7`0K72006A`O01TJ7P0J6al06QdP
01/M800M7R807R4T01PJ7@0J6al04QHI01PQ900E7R404adO014K7@0Q:bd05R0R010J700D7R005b4S
01XT9P0H8BD06B4T028W:`0F6al07R<W01lT:00W;3007R<W01`Q9@0M8RH07R<W01LL800I7R8072@Z
01`W;@0P:c407bX`01/V;00N:Bl092le028]<`0N:Bl06bH/01hY;`0Q;3809Bhc01lX:P0K8bL082P[
01hW:P0201/S9P0A01TR9@0H82<06b<V01`U9`0D71l072DY01<M800O:2`072HX03U3A00F82808R`]
01XT9@0F81l0628Q01LQ800H8B000P0L8B@02P0L82<06QlR01TN8@0I7B007R8U020T9`0Q9BP061`O
01<G6P0H71l201PM8P0=01hS:00J7bD04aPM01HK8@0a=S`0RHjC020U:P0I7R@06QlT01XO8`0G6a/0
5a`I01HK600201HJ6@0901DI6@0I7Ah051PJ01TM800C5aX061`O01HJ7@0F71`051/K008051XJ00T0
51TJ01<G600D5AL051@F014@4P0P7R405Q@G01`J7@0F5QP00P0E5QP04P0F5aT061TK01TJ700F5aT0
6a`N01HG6@0H6A/06a`N01TJ700G71X05Q/I01LM6P0H7Ad051TI010F5P0E6Q/05Q/K01HL6`805AXH
00P05Q/I01DJ5`0F61L051HE018C5@0F5QP061PJ01<C5@805A<F01h04a4B01<@400B4140518H00l>
4`0A4A@05aHK01HD5`0B41<04@lB01@@4@0C3a004Ph?01@?4@0D4A804Q4A010?400A3a005A8C01TE
5P0J5AL050h@01@;3P0N5AP08ALK01P=4@0C2`d05Q0B01D?4@0B30h200h82P0E018<3P0A2`d03PP:
010:300C3@l04P`>01H@4@0=1`L050`=01@=3@0[9BD05a0@01092@0>20P03`P800h71`0>20P03`P8
0108200@1PL04PP900<04`T:01<05@/<01882@0C2@X02`<30147200M4a@04`T801881`0@1PD03`D4
01471P0E2`X040H501471P0@1PD04PP700h4100>10D040D900804@H<01D04PL=0146300@1@/04@H<
01052`0?10X03P<900l42P0A1P/04PL;01052@0D2Pd0@3Di04Xo@`0;0P@03@8600l4200>0`L03045
00d21P0<0@D00P0@10P01P0?0`L03P8600d11@0=0@D04PH:01452@8040@800<04@D901862_ooool0
4oooool001_ooooo01006ADB01hM6@0F5A4020L300`;1`0@3`/03`h:01HE4@0@3`/03@`8010?2`0;
2PH051<A00d<2P081`D06APF0`0?3P`01@0>3@/020L500l>300=30X05QHD008041@C01@04aDB00H6
0`0B4@`05Q<<01<@2@0;20403@X501<B3@0?40/02P/601HF3`0A40/03Ph600h=1`0@3`X04A4900h>
1`0>3@P03Ph600h>1`803Pd800X04a@?0001000>3`X0@44l01HG4P061`803a0;00`=200=3PT0414<
0P0>3`X02P0=3PT02@X500d>2P0L7AP0EUMB01PI500:2`H04Q<>01<D3`0<3@P200l@2`0<00d>2@0<
3@P02``700d>2@0?40/03Pl:00/<1`0<3@P04A8=018C3P0=3PT02`/60P0@3`X0@@0>3@P040l:00h=
200<2`H04A0;01DD3`0K6QD05aHA010?2P0H5a@09RDS014A400@4100BTY804Q:B03SiN@0Ngej020P
7`0I6AT03Ph<014@3`0?3PX02`X600h=2@0;2PH04A0<010?2`0A40`02`X600d<200D4`l04a8>018A
3@0920@05aHB00l>2P0I61@020L3018A3@0>3@T02PT500T8100@3`/04Q4=00X91@0<2`L04A0<010?
2`0<2`L03@`800/:1P0@3`/071/G02l^:P0X9b<04a8>01@C3`0>3@/03`h<010?3@0?3P`03@`:00/:
200A40h040l=00803Pd;0P0?3P`00`0E5A<03@d;00d=2`0200h>300@01<C4@0>3P`0410>014A3`0@
40h04A4?01<C4@031@@06QdL014C4P0B51<030h=00H81`0?4A00418A00l?3`803Ph>00@0410@018A
3`0B4@l040l=0P0=30X01`0>3@/040l=00l>300B4@l02`X80040000?3P`00P0>30d03`0;2@X04a4B
01<A4P081PL01`D600d;300D4Q<02`T:01<A4P0G5AH03Pd;00l>300B4@l03Pd;018A3`0300d<2P0?
00h=2`0=30X03@`:00/:200?3P`02`X800d<2`0=30X01`H400/:200?3P`040l=00d<2P0:2@L02`X8
00803`h<00X03Pd;00l>300A40h03`h<00h=2`0<2`T00@0001<B400f=C<07QdK0P0<2`T0400@30/0
3@/900`81`0=2@P040`;01DA400F4Q403`/:00/71P0:1PD04`l>01@@3`0C3`h03`/:00`81`0=2@P6
010<2`0L00/:200>3@T04a8?014@3P0>3@T04a8?00d<2P0=30P03Pd:00l>300A40`04a8@00/92P07
1@H03`/>00/62P0B414030T;010;3`0:20T05A4D00`72`0D4Q<020D801HC6P0B3aP020D>00L43@80
3P/D00d030T@02dZ<@0J61d05Q@G01<A500D4QD0=CDg0>CTiP1<C4h05ADG00d=3`030`D030`>0080
410B00D03@d?00`<3P0>3Q003`d@00h<3`0200d;3P0S00h<3`0?3A0040hA00l=400F51L061HI02d[
;P0=2`h01PH800d=3`082@/05QPJ00@82@0:41004AHF00<7200720X05aPJ00L72@0@41801@P900`=
4@0A5AH02@X=00L8300C51H03a0C08>4R02?T9806a`O01@E6@0820X03P`=00`:2`0:20T00P0?3@h0
10091`P03`d>00`:2`0<2P/200d;300300`:2`0<2`T03`h<00802`X80P0:2@L500l>300C00l<2`0?
2`X040`;018>3P0?3@h03P`=00l=3P0A3a0040h?00d<3@0<30h03Ph@00h=3`0B41405aDF01@B4`0;
2@X02@L800h<3@02018@4@0N010>3`0=2``02`T:00/92P0D4Q<05Q@E00L61P0?3@h0518C00L51P0K
6a/0;B`/01DE5@051@D03@d=00d=3`0?3a404A4C00d=3`0<30h04A4C00T92`0820X061PJ00L72@0I
6A/030`>00/:3`0B4AH03PdB0P0A41D0100@3a@02`X?00`;400?3Q<3014@5@0600X93P0b<CH030/?
01LF6`061PP04A4C0P0=3@l0:P0A4A405ADE01@D500B41403`d>014=3P0D41405Q8C01DA4P0B3Pl0
40`=01DA4P0D41402@D601HB4`0I5aP04@l@01LG5`0E5AD051@D01DE5@0B4Q803`l?01HF5P0E5AD0
51@D018B4P092@T05QHF01@E500E5aH04a<C00l@3`0B51<05QHF01XK6P0D5QD04a<C01@E500A4a80
51HE01DG5P804A<B00`051HE01DG5P0A4a8051HE01PJ6@0L7Qd05aTH01<E500H6QL071hK01dO700I
7A`201LK6P0a01@I5`0J82004QPH01dS8`0C61/07B8U01PM800J7R405a`O01/O8P0I7B004aPK014E
600R9RT02a0C01TM800M8B@041DH01HM7`0B5aX04a/M01PP8P0H82<0<CXn03Dn@`0K92T05AlS01dX
;00H8bT04a`P02@/;`0>5QT07bLZ00XB5@0S:bh07RHY01dU:00C6ah082P[01hV:@0@61/06b<Z02Tb
>`0J8b`06b@]01dV;`0N9c008BXc020Y<P02024Z<`0D020Y<P0O:3408BXa01/V:P0E7RD05R0T01`W
:`0L9R/07bT[01`W:@0N:BX06bDV02Da<@0F824082X[01DM7`0K8bD08RX/01PQ800J8R<201XS8P04
01lX9`0J8b804a`K01@M70807BDW02@05AdO01`T9P0I8B<05Q/N01LL7`0X;C00:2`_01@H6`0F6Qd0
61`O00lC5P0D61/06alS01XM8P0G6ah04aLK01@G700L7b<05a/N01HI7P0K7b<06alR01PL7`0E6AX0
6QhO00dA4P0C5aT041@G01DI700H71l06AdP01XN8@0H71l04ADH01<G6P0E6A`201HJ7@0>01DF6P0C
51P06AXN01PI7@0F5a/06aXO01<B5`0L6b006a`N01PI6`0E5QP051DG01HG6@0H6A/201LH6P805QLI
0P0E5QP0900J72005QLK018F6@0D5aX06AXN01XN8@0F6Ad05aPL01PL7`0F6A`05AHJ01PI7@0A4Q@0
5QHH01`L7P0B4Q@04A4C01hN800^;S006a/M01`L7P0G5aT03`lA014?4P0F51L06ALJ01PF5`0F51H0
5A<D01HD5@0E4a@04Q0A01@B4`0B41404a4B01HB4P804`l>01804@d<014;2`0C3@d0618B00d71`0D
3Ph040X:01TC4`0600005Q0@014;2`0@2PX050h>00h8200?2@T050h>00d71`0:10@2014;2`0<00d7
1`0?1`P04@P901D;300B20T030<401882@0D2P/04@P901<92P0C2P/04@P90P0@1PL60147200500L0
000H3Pl060h?01@:2`0?1PL00P0@1PL0100D2P/06@l@01P>3`0A1`P600l51P0=01052@0C20`03@<6
00l4200H3A403@@600h31`0=0PH04PL;00T00P0L4AD03P<70104200201041P0300l31@0>0P@03P84
00803P840P0?0`D201041P0600h21P0@10P03P8600h21P0@10P03P861P0?0`LDooooo`006oooool0
100@3`/030/700P70`0@3`/300l>2P0S01@C3`0?3PX03@`8010?2`0=30P02PT7018A3`0C4Q002PT7
00`;2@0@3`d020L5014@3P0?3P`02`X800D40P0?3`d01`h>010D4`0<4@d0410<01`I500=2P<05148
010=1P0C40T06APC01XK5P0H6A<05AD>014A2@0>3PH03`l7014A2@0B4PX01P0>3PH0600<2`L01`H2
00H50@0K6QH02PT501<B3P0>3@T04A0<010?2`0>3@T03`h:01<C3P0E5Q402``700X;20061`80;BhY
00d>2@0H6A@030d800P9100>3`X01`P300`=20803@h901803Pl:010A300A4Pd03a0;014B3@0D5A00
2``700D60@0>3`X04Q8=00h=200=30L04A0;01XI500G5Q403`h900d<1`0?3PT2018A300g00h=200<
30T03@d=00P820061PH06a/K01HF5P1nOWh0MGEe03dm?@071`L0410@00h>3@0B4@d02`X601@C3`0?
3PX00@0000`;2@0>3@T02`X600d<200>3@T030/7014@300=30P04a8>00/:1P061@401`H200X91@0?
3PX040l;01TH500T8al08R4M01@C3`0@3`/04a8>014@300=30P03Pd900T8100?3PX04a8>020O6`0L
6aL03@`8010?2`0>3@/03`h<010?3@0?3P`03@`:00/:200300l>3008010?3@0B4@l04a8@01`L6P0C
4a403`l=00d=2`0820H200X:20803@d;0P0<30X03@0>3P`02PX805eMF`0H61H04a<A01/K6@0@40h0
3Ph<00l?3@0@40h03`l=00`<2P0;2`T00P0@3`d04P0>3@/030/900`;2@0>3@/040l=00`;2@0>3@/0
4Q4?014@3P0C4Q003P`=010>3`0?3@h04a4B010>3`0;2@X040h?00h<3@803@/<00P04Q0A00H41@0G
5Q@05A@B00h=2`061@<02PT7018A3`803@`:02<03Pd;00d<2P0=30X03`h<014@3P0?3P`01@@300l>
300G5Q@03@`:00l>300@3`d03Pd;00X91`0<2`T03`h<00h=2`0=30X03`h<010?3@0?3P`03@`:00L6
100/:bT05QDC0040000J6AL020D400l;2P0@30/03PX900`81`0>2PT030P700l;2P0201<?3P0801HB
4@0E4A002`L600d9200>2PT03@T800h:2@0B3Pd6010<2`0600`;1`0>3@T03`h:00`;1`0:2@D02`X6
0P0@3`/02@0?3PX03Pd900h=2@0?3P/071PI01/G600?2``02PH7014=3P0200l;300M00L3100<20T0
2`L801dI6P0J5QP06aPO014>5`0D4AX05a@M01<@600@3A@02@L<01PF6`0A3a@04a4D00X82`0?3A00
61PJ06EUI`0U9BL03@d?010@4P0G5aT03@d?010@4P0?3a403@d?00`<3P0?3a401P0=2`h200H41`04
01@B5@081PT04a8D00l=408030`>01/02@X<00dA4P0;4A404AXI00P?3`0>4Q<01PX;00P92`020P@0
4Q8D00`>4P0830l02PhA00L;3P0A5AP08RHY02DY;03IgN00em_N028U:00010L0414C00l>3P0?3@h0
3@/<014?400B41400P0>30d200/92P0800`:2`0;2@X02`T:00/:200?3P`030/900l>300@3`d600d<
2P0500d<2`0>30d03P`=00l=3P0<2P/00P0;2@X0300=2``03P`=00/92P0:20T02`T:00h<3@0@3Pl0
4Q0A010>3`0;2@X02PP900`:2`803@/<0P0>30d08P0?3@h020L7018@4@0C4A8061HG010>3`071@H0
40h?01HD5@0O7Ah04a4B00/92P0?3@h02PX<00`<3P0@41804Q8D01DE5`0K6ad0?Cdo01DE5`0?3a40
DU9D05QHFP0I6A/04A0E01<B5`0A41D03@`A00`;400>3A8030/@00d<4@0@3a@2014@5@06010?500b
<CL0D4mE01lN8`0M72402PT>0P0C4aD0;`0A4A<03`l?014A4@0A4A403`l?00l=3P0A3@h04`l@01@@
4@0C3a0040`=01PD5@0=2@X0510A01LC500J5QL02PP900/;2`0?3`l03Ph>010@400D51@0410@01<C
4`0=3@d01`L700T92@0B4Q806QXJ01DE5@0B4Q804a<C018B4P0?3`l0410@00`<300D51@0410@00d=
3@0@41004Q8B01<E500D5QD04Q@C014C4P0B51<04aDD008051HE00P05aTH01XL6`0E5aH04Q@A01LI
5@0J71T06adJ01LL60805a/J00T03Q@B01dV9@0=5QD072DT01dU9`0?5aT08BHY02@Y;00O92L00P0K
82<01@0I7R407b@W028W:P0F6ah05AXM008061dP0P0G71l0A`0I82806R8T01TQ901HH6@0DU]P01TR
9`0H8RP04ahT018M8`0V;c@0GfMZ03]3AP0J8RD05QhQ02@/;`0I8B@08RX]01HN8@0J8RD07BDX01DM
800H82H07RL`01DN9`0J8b`0:34j03@mAP0^=d007RL`01lX<@0N9c006b@]01`U;P0N:2l06bH/01TT
:P0J9BX072L[01/V:P0O:R`09S4c02Te=@0E8B406bLW01/V9`0`>CP072DT01XS8P0L9B@06R<R01LP
7`0f?ch0:S<b01/T8`0F7ah05AhM01TR8@0<5QL04Q`M01TS900Y<C<08RX/01LO8@0K82<09R/^02@X
:`0H71l06alR01LK7P0C5aX05QXM00806QhQ00@061`O01DI700J7R406AdP0P0A5AP03`0F6Qd04ADH
01`P8`0J7R405QXM00`@4`0D61/07B4T01PL7`0F6Qd05ATL01HJ7@0G6ah051PK01DF6P0201HG6`80
5AHJ0P0C51P01`0B4aL04a@H02HW:`0T9BT05QLK01TJ700G61X00P0E5QP0100G61X061TK01DF600G
61X401PI6`0401PI7P0G61d05QLL01LH7@8061TN01<0C4eB01hO900B4aP051DJ00d>4`0720`07QhP
01TI6`0J6Q`04a<E01/K7@0/;2h0XJ6S01`L7P071`T03@d?010@4P0O7b40518C00805Q@E0`0C4A80
1`0B41403P`=01@B4`0H5QL04@l@010<300B30`00P0C3@d01@0B30`050h>01/E5@0X8R806Q@D0080
4P`<00D04@/;01<=3@0B30`040X:01<=3@0200h8200A01@>3P0@2PX03PP801<=3@0B30`03`T901<;
300G3@h04`T:00l51P0H3Pl05P`=00l51P0B20T04`T:01@:2`0B20T01`0A1`P01P0=0`@0;bDV00L0
000:00404`T:01X@4@803@<400@04@L801@:2`0C2@X03@<41P0?1@H0300700004@H:01@93@0;00@0
3P<701X?4`0P5AT01`0000P00@0A1PX0200100d31P<040@600@03`<500h2100>0P@03P840`0?0`D2
01041P8040@80`0?0`L00`0=0@D03`<700l31`0400l31aCooooo000Kooooo`0A00d<200E5100>STe
00`;1`0<2`P030/700l>2P0A40`03Pd900`;1`0A40`04a8>018A3`0>3@/03Pd<00l>300>3@/00P0=
30X0300@3`d02PT700d<2P0K6QP0<c<a06adL`0830/010P400l@300>2`H0514:010=10804Pl800T0
4A0;01<D3`0E5Q404Q4;010@200>3PH04108018B2P0C4`/01@0>3PH06`0>3PL040l;014@300:2@D0
3`h:00T8100G5Q803Pd901<B3P0B4@d030/700h=2@0?3`X04a@?00P9100B4`h01`P401DF4@092PH0
3Pl:00/<1`0A4Pd03a0;00P9100>3`X03@h900h?2P0500d>2@0S00`=200A4Pd04a@?00l@2`0>3PT0
3`h900`;1P0A40/06QTD01HE400>3@P030/600/:1@0=30L040l:014@2`0>3PX02`/8018B3`0E5A<0
2`/800h?300B4Q002PX701<C400C4a403Ph;00/;20061@<05aHB00/:1`0B4@d040l;014@300B4@d0
0P0@3`/0300<2`L02@P4018A3@0E51002PT6018A3@020@004Q4=00l>2P0=30P02`X600h=2@805A@@
00T030/700h=2@0?3PX03Pd901<B3P0F5A403Pd901<B3P0<2`L00P0@3`/00`0;2PH03@`800h=2`03
00l>300A00h=2`0=30X03@`:00h=2`0?3P`04A0>01@C4@0F5A<04A4?00l?3@0@40h03`l=00`<2P0@
40h03Ph<010@3P0?3`d00P0=3@/200h>300;01XJ6@0?3`d051@B00L71@0>3P`03@d;00/;2@0>3P`0
4A4?00`<2P061P@00P0>3@/06`0=30X030/900h=2`0@3`d06QTG010?3@0>3@/030/9014@3P0;2PP0
30X;014?400F51D03`d>00X82@0?3@h01`D6010>3`0?3@h02PP9014?40081PL04A0>00P71@0B4@l0
<S4_01DD4P0300d<2P0=00h=2`0=30X03@`:018A3`030P404Q4?03He<`0C4Q002`X800l>300>3@/0
3`h<00h=2`0200d<2P0A00h=2`0=30X030/900d<2P0>3@/03@`:00`;2@0>3@/02`X800d<2`0>3@/0
3@`:00h<2P0?2`X040`;00l;2P0>2PT00P0?2`X2010<2`03018>3@0H51<0510?00@040`;00<04Ph=
01PD4`0@30/01@0@30/01P0>3@/040l=010?3@0?3P`040l=00h=2`803`h<0P0>3@/0800?3P`040l=
00d92P0E4A802`L801`H6@0A3@h0510A00h:2`0=2@X04Ph?014=3P0G4a@03PX<01dJ8@0<2A80KFYc
07=`M`0C41L05a@K014?500<2Pl03`dB01DC5P0=2`h04Q0C014A4`0B4Q@061PJ00<31@0F5QP04Q8D
0P0@41801P0=3@l030`>00d=3`0@41802`T<00d;3P803`d@02@03@/>00/9300F51L03@/>01@B5@03
0P@05Q@G059@D`0J61/03@d?00T:300<41401P`<03<i>@0X;Bd0310A00dA4P0L7Al03Pd@018A4`0@
4A<03@h@00h?4@0:2P`04Q8D01dN800>3Q00>c`n03dn@00B4aD02PX<00`=3`0<2P/040h?00d;300<
2P/200h<3@803`d>0P0>30d200d;300300`;2@0>3@/03@`:00803Pd;00<03@`:00h=2`0>3@/00`0>
3@/02P0>3@`03P`=00h<3@0>30d030X;00/92P0<2P/040h?018@4@0@3Pl200h<3@0600l=3P0=2``0
2`T:00d;300?3@h03P`=0P0=2``200`:2`0A00h<3@0@3Pl05A<D00800@0I5aP0;B//01@B4`0E4a@0
3P`=00l=3P0<2P/03P`=014?400@3Pl06ATK01DE5`0B4Q@00P0A4A<00`0>3Q0061PJ00H6200201@D
5P0801DE5`0>3Q004Q4F00/:3`0B4AH03PdB00l>4`0B4AH200l>4`<040lD00/03`hC00T83P0Q82H0
2`X?01@C600<2a0051@F018B500?3a403@d=00l?3`02018B4P8040h?00P04@l@018@4@0@3Pl030X;
01`J6`0B414081hO01/I6P805A<D01P04a<C018B4P0A4A405aLG01hN7P0I6AT03Ph>014A4@0T92@0
9BDU01DE5@0D51@06a/K01<C4`0E5AD061PH01DE5@0B4Q804a<C01TI6@0F5QH051@D01LG5`0H61P3
01DG5P0401@F5@0G6AP06Q`K01HH5`805ALF01@05QPG01DG5P0D5Q<05aTE01TK600H6QL05Q/G01PL
6`0I7A`06R0N010F5P0I7al041TH01XR900K8bD06QlR020U:00I7R405AXM01TN8@806b0S02D06QlR
01lT9`0H7B005a`O01dR9@0J7b807b@W01hU9`0K8bD06b<V01`U:@0N9b`07bP]01lY;`0R;C<082/a
01LP9P0`>3/06b<V014I700K8bH0;3@g01TQ900N9RT072@W01/S9P0P:2/07RHY01dU:`0O:3406b@]
01hW<00^=d008b`e01lX<@0K92d072D^00806b@]00T072D^01`U;@0N9bh08R/b024Z<00M9R/07RL/
01hX:P0J92H00P0J92D06P0[=CH08B//02Pa<00G81l0624P01TR8@0M9RD06R<R03U2@@0X<C00624P
01/T8`0M9RD06B8Q024[;00O:BX0628S01hV:00I8B<072@V01`Q900O92L07B4T01XN8@0K7b805ATL
0P0F6Qd0100H71l06QhQ01TM800F6Qd201PL7`0D01HJ7@0H71l05a/N010D5`0D61/05QXM01`P8`0/
<3<082@W00hB5@0L82<05ATL01<G6P0D61/05QXM01LK7P0G61`05QLK01@E6@0C51P201DF6P07014B
5P0P8BD04Q<G01`M8@0T9BT05QLK01DF600201HG6@0601LH6P0F5aT05QLI01@E5`0G61X06Q/M0P0K
71h00`0J6ad061TM01TJ7P0201XK7`0E01PI7@0G61`0ATM;01dN8P0A4QH05AHJ01`M8@0P8BD051@F
01dM7`0T92H06a/M01@D5P0I6A/0;Rh`010@4P0D51H05aLI00l?4@0A4A<04Q0A0080518C00X04@l@
010>3`0A3a00:bTZ01TG600J61T07A/L010>3`0=2@T04P`<0P0D3Ph02@0C3@d05@l?01LA4@0`:RX0
6A<C014;2`0>20P06Q@D010:2P0200l92@0401<=3@0B30`050h>01D?3`8040X:00X04P`<00h8200?
2@T050`=0147200=0`@05@/<0147200>1@D05@/<0`0C2@X00`0B20T04@L80147200501472006034W
:01gKFh060h?0147200C2@X03`D60P0A1`P00`0C2@X050X;01<92P0700l51P0<01<8300=0PH03`D8
01462P0<0@D04PT;00X10`0E2Ph04@L:00l4200A20X03P@70`0@10H00`0?0`D03P8400h2100200l3
1@8040@60P0A1@L20104200301862P0A1@T03`<700L03`<75?ooool001_ooooo02D020L3018A3@1;
BTH02PT501@C3`0E51003`h:00h=2@0=30P030/700l>2P0E51005QDC061OG@0=30X030/901lN700H
5aD020L500l>300E51804A0>00L6100E5A<07B@T010D4`0730P0410<01TF4@0>2`@0514801HC300C
40T02`X500`=200?40/03`h900803Pd800<040l:018A300C4Pd01P0>3@P0600A40`02@P400`;1`0G
5Q803@`800P70`0@3`/03Pd900l>2P0@3`/03`h:00`<1`0A4Pd01`P3014B3@0720<01PL2018C3P0;
30L04Q<>00L81@0N7aX0<34/00d>2@D030d800L04A8=00/<1`082@@0824L02d^:@0J6aH02PX50080
4Q4<00<030/600d<1`0>3@P00`0=30L06P0A40/04a8=018A300@40/03Pl900`=1`0310000@8000X;
1@000@002``6018C40041@00414;01DF4@0>3@T030/7010?2`0P7a/04Q4=07UhM00I61@04A0<00d<
200?3PX03Pd90P0@3`/02`081`<04a8>014@30071P8020L301XI5@0E51003@`800h=2@0B4@d051<?
00<030/700T051<?01XI5@0B4@d04a8>00`;1`0=30P040l;00l>2P0<2`L01@0>3@/01`0?3P`03Pd;
00d<2P0=30X03Pd;00l>300@3`d00P0?3`d0600A4@l03Ph<00/;2@0?3`d02PX800`<2P0;2`T02@T7
00P81P092@L02`/901<C4@0B4Q002PX8014A3`0?3`d04A4?00T91`0:2PP03`l=00h>300;2`T03@`:
00l>30803Pd;01X040l=01<B400920H020L500l>300920H03Pd;01HE4`0B414061HG01hL7@0D4Q<0
3`d>01TG600M6a`02`T:018@4@081PL03@/<01PF5`0D4a403@`:00L6100H5aD02@P601PG5@803@`:
00X03Pd;00d<2P0=30X01`H500h=2`0=30X04A0?014@3P071P@02@P60P0>3@/300l>300=00h=2`0;
2PP02PT700`;2@0=30X030/900X91`0=30X04A0>00`;2@01000010<1018?3P0300l;2P08010<2`0?
2`X03`/:00h:2@0<20L040`;01dI600P71/2010<2`0300d920091@@02PH500L040`;00D02@P600h=
2`0=30X02`X800h=2`0500d<2P0@00h=2`0@3`d02@D600`82@0J5QL0BTI7038^;`0n>S/04@d>01HB
4`0>2P/020@500X61`0D3a803P/B00/940805a@K01H03@`A01HD6@0<2Pl04@lC00d;3P081PT03`d?
00h<3@0820X04Q8D00`<3P0;2`d0K6a^09:BU00B4Q@03`lA00/;3@0<30h03Ph@00l?4@0<2Pd03`d@
0P0A3a807P0?3A0030X=00H41`0=2`h04@lB00X82`0;2@`07adP00X82`0G5QT01`P:00dA4P0Y;bl0
_/C408jDU00>4Q<01`/<01XJ700;2@`030X=010?4@0C4A@04Q8D00`;3@081PT02PX<01LF600F51L0
4a<E018A50802@L:00@0518C01LE5P0B41403`d>0P0@3Pl00`0:20T03@/<00d;300200T7200300X8
2@0=30X030/9008030/900<02`X800h=2`0?3P`0100?3P`0100?3@d03P`=00h<3@0?3@h2010>3`0X
00h<3@0=2``03`d>00h<3@0;2@X02PP900d;300;2@X02PP9014?400E4a@04@l@00h<3@0?3@h03@/<
00`:2`0>30d04@l@00/92P0G5AH03`d>01TG600C4A800@00018@4@0>30d030X;00h<3@0?3@h03P`=
010@4P0=3@l02`/=00l?4@0A4A<03`lA010@4P0B4Q@02PX<00P82P804A4C00H06APM00h=4P0?3Q<0
40lD00h=4P0:2@h2010?50@03`hC00H04a8H01dL8P0F5AX061LL018A5P0>3Q0200d=3`0K00l?3`0C
4a<04a<C010@400C4A804Q0A01<A4P0D4Q<04Q0A00d;300610D06aTJ03`j>`0Z:2T040h?00l=3P0F
5QH04Q8B00h>3P0D51@06QXJ01<C4`0J6QX04A4A01XJ6P0I6AT03Ph>00805QHF01403@d=010@400D
51@04A4A00h>3P0D51@04Q8B014A4@0F5QH06QXJ01<C4`0C5A@0418A01<E500D5QD06Q`K02<U9003
01@F5@0401DG5P0G6AP06A/H01TI5P<06A/H00h06QhM01`P7`0c=cH0<CLg01PN7P0N92@0?DE701/S
9@0I7R4061dP01DJ7@0I7R40724T01XO8P80724T04D05a`O01/P8`0J7b805AXM01dR9@0O92L06b4T
01PP8P0L92L0;CDi020Y;P0E7R<08R`b01XU:`0H8bT08R`b01PQ9P0M9R/0;3Dj07N0Q@21RXl06b@Y
01PQ9P0L9BX06R<X01`U:P0O:2d06R<Y028/=@0[=Ch05R0Y02<]=P0L9Rl0:38k01/U;P0G8BX07BL`
02<]=P0Q:c@07BH^020W;`0S:S807bH]01XQ9`0Q:2h0620S02H^<@0_=cT05QhP01/S9@0P:2X05b0O
01`U900[=3<09c0_01hW9P0Q:RT06b@S01HO7P0J8b808BXY01hW9P0I8R405R0Q01TS900K9BH082PZ
01@L7P0E7Al00P0L8B@07P0N8RD06alR01HJ7@0F6Qd04QHI01<G6P0H71l06QhQ01PL7`0C5aX061`O
01TM800E6A`04ADH01DI700P92L06alR018F6@0830l06QhQ01@H6`0>4QD06alR01HJ7@0J7R406alR
01HJ7@0G6ah06Q/O01PI7@805AHJ00X05aPL01PI7@0@4AD0:BX^01XK7`0H6Ad07AhR01hO8`0E5QP0
5QLI0`0G61X00`0E5QP05QLI01PI6`0201TJ700301LH6P0F5aT06a`P00<06AXN00T06Q/O01/L800M
7R806AXN01DF6P0?41@06AXN02LX;00C4aD00P0B4Q@0600>3Q004A4C01LG6@0N7R004Q8D00/;3@0C
4aD05QHH010@4P0B41405A<D01@B4`0B41404@l@018@4@0E4a@04@l@01HD5@0J61T05Q@E01@@4@0D
3Ph05Q0@01@>3P804@/;00L040X:00d71`0F410040X:01@>3P090`<05a4A00<04`d=01005@l?01LA
4@0D3Ph03`T9010:2P0A2`/03@L700l92@0H41007A<D0147200F30d06a4B00h41@0B20T04`T:0P0B
20T80147200601H<3@0U6a`04`T:01061`0B20T030830P0>10D0100?1@H03P@500h41@0>10D600l5
1P803P<700@04PL;00P00@0?10P0DdQ<0P0?10P0100>1@L0:b0T01052@0F3@l301041P0400l31@0>
0P@03P8400l31@<040@60P0A1@L01P0=0@D0304401@8300E2@d04@D901<72`H03`<75?ooool001_o
oooo00T04a8>00L60`0J6AD04A0<01<B3P0<2`L03`h:00d<200?3PX00P0>3@T06P0D4`l03Pd;03He
<`0100002@P600D40`0C4Q003Pd;00d<2P0A40h03Pd;00L6100H61H0;C@d00`@3`0<4@d04A4=01TF
4@0B3`P04Pl601@A2P0B3`P03@`700d>2@0@4@`03`h90P0>3@P00`0@3`X04A0;018A300600h=200H
00l>2P0;2PH02PT500d<200?3PX03Pd9010?2`0=30P03Pd9014@300?3PX03Ph9014B3@0<3@P03Pl:
00X;1P051P402``700X;1P0F5a802P/603Tj=@14AD002P/60P0<3@P0100=3PT04A8=01@E400B4`h2
00/<1`0<01DF4@0L7AP05aPC00l?2P0C4Pd05A@?00h=200=30L04A0;00l>2@0;2PD03@`70P0A40/0
800?3PT03`l:010A2`0B4`d02``600`=1`0>3`T07b0J038c;@0Z:bD02P/5014B300;30L05A@@00l>
2P0>3@T02`X60040000m?3P05QDA00h=2@0:2@D03`h:00h=2@0=30P010<001<B3P0=30P07A`H00L6
0P0C4Ph02`X60P0:2@D03`0=30P03Pd900h=2@0@3`/04A0<010?2`0B4@d05A@@00h=2@0?3PX030/7
00d<200@3`/03`h:00/:1P0200h=2`803@`:00D03`h<010?3@0?3P`03`h<00d<2P0200`;2@0400d<
2P0:2PP02`/900l?3@803@d;00@05QHD00/;2@0=3@/030`:0P0;2`T03P0<30X01@D301DE4`000000
2PX800`<2P020P004Q8@00X:20092@L03@d;00l?3@0>3P`03Pd;0P0?3P`0300>3@/04A0>01<B400B
4@l03`h<018A3`0F5A<02@P600X91`0>30d0518C01HD5@8040h?00d05Q@E044o@0071@H03`d>00`:
2`0:20T04a4B010?3@0;2PP01`H4010?3@040`4030/900803@`:00d03Pd;00d<2P0=30X03`h<01`K
6@0B4@l03Pd;01@C4@0?3P`04a8@00h=2`0=30X03`h<008040l=01803Pd;00`;2@0;2PP030/900d<
2P0<2`T03Pd;00d<2P081`D05A@B00h=2`061@<040h<00l;2P0>2PT040`;014=300@30/200h:2@04
00/71P0:1PD04`l>01LC4P<03PX900<030P700d9200B3Pd01P0@30/02@0<2`T05A@B01<B400:2@L0
3@`:00`;2@0A40h040l=00h=2`0200`;2@0W00/:200H51D03`/<00X61`0L61T0100100/820070`@0
4`l@00l;300<20T01`<400X6200100D040dE01HC6P0C41L04@hD00d;400;2@h0518F010>4@050`H0
40h@00d;300D51H04Q8D00`<3P0K6ad0GEeO08J6R00B4Q@03Ph@00`<3P0=3@l03Ph@00d=3`0>30l0
40hA00804@lB02L040hA00h<3`0?3A005aDH014?4P0D4QD04@lB00`:3@0>30l03`hA00L72@0G6A/0
5a/L08N=S@1VK6`020`=00d>400?3a401P@700X82`0A3a804PdA00l=400>2Ph03`X>010>4@0B3a80
1P4500@21@0C3a<061<G01HD5`0B4140518C010>3`0>30d03`d>00d;300>30d00P0C4A801`0>30d0
3@/<00l=3P0<2`T02`X800h=2`0@3`d00P0A40h500d<2P0:00h<300>30d03P`=00l=3P0A3a004a4B
014?400>30d040h?00h<3@8030X;00H03P`=00`:2`0;2@X04Q0A01DC500A3a0300`:2`0K00h<3@0A
3a00518C00l=3P0H5QL03`d>00`:2`0?3@h01@<400h<3@0?3@h04@l@00h<3@0=2``03P`=00h>400<
30h03@d?010@4P0B4Q@04a<E00000P0S8bD03Ph@01XJ70030`D03`lA00803`hC00H01`H;01<B5`0@
3a@061LL010?500?3Q<200h=4P0800l>4`0@3a@03`hD00d<4P0:2@h030/@014@5@0F5QP2014A4`0H
018B4P0D51@04Q8B00d=3@0C4A804Q0A01@B4`0E4a@0518C00l=3P0E4a@04a4B02@R8`0M6a`0518C
00h<3@0C4a<04Q8B00h>3P0A4A405ADE00l?3`0H61P03Ph>0`0?3`l01@0J6QX05ADE00l?3`0A4A40
51@D00804A4A0`0G5aL02P0M7Ad08b<S01`L700A4a803a4@01@F5@0C5A@05ALF01hP7`0D5QD201DG
5P0501HH5`0I6aX06adJ01PI5@0J71T00P0K7AX02`0J7Qd0720O01PL6`0P9RH041HF01LM7@0S:bd0
2Q8D01dR9@0J7b805a`O00806QlR00D05AXM01PM800G71l041DH01TN8@0201lT9`0I01hS9P0M8RD0
6R0S01TQ8`0L92L06b<W01HO900J8bP07bT^01TT:P0H8bT06bD[01dV:`14CE809Bhc01hW;00h@DH0
6B8W01`U:P0M9R/072DZ01TR9`0P:Bh08R`c024[=00202/e?P0Z04E?F00M9c006bD^01`V;`0H8R/0
7RPa02H`>@0T;SL082P`01lV;P0P9bl06b8Y01PO9@0Q:2h0620S024Y;00Z<S@0620R01hV:00L92H0
7bPW02`e=00kA4<0;CHe01hW9P0R:bX06b@S01PQ800J8b8072DT01XS8P0M9RD07bTZ01hX:@0M9bP0
8RX/01PP8P0T;2h08bP[01lT9`0R9RT082@W0P0H71l05P0B5QT05ATL01XN8@0H71l05QXM01@H6`0H
71l05ATL010D5`0?4aH092P[04=7BP0Q9BP0:blb028V:@0J7R4051PK01hR9@0J7R405QXM01lS9P0P
92L201HJ7@0301XK7`0I6Qh05aPL00<05aPL00H05AHJ020Q9@0M7R807QlS018C5`0A4QH201PI6`80
5aPJ0P0F5aT00`0I6Q`061TK01LH6P0201LH6P0J01HG6@0K72006AXN01PI7@0I6Qh06Q/O01/L800C
51P061TM01lP900J6al030dA00P93@0@41806ATK01dM7`0H61X0410B00d=3`0A4A<02@T;01HF600H
61X0410B01DE5`0C4A8201DC500I01<A4P0B41404Q0A01hL7@0D4Q<03`d>00T7200:20T04Ph>01D?
3`0G4A405@l?014;2`0?2@T040X:00H0000G4A404P`<01PB4P0400006A<C01PB4P0G4A404P`<01<=
3@02018<3003010:2P0A2`/05Q0@00804P`<00T04PX;020F5`0:004040H7048h>@0[8B8040H701<9
2P0B20T00`0A1`P00`0B20T04@L8014720030147200701061`0700003`D600L0000B20T040H700l5
1P0201061`803`D600<04PP900l51P0?1@H0100?1@H0300<0@D03@8601@93@0?10P040D903/`=00<
0@D081DI01hC5`0700002@0201@93@<040@600<03`<500h2100>0P@00`0@10H201451`070186200>
0PH0304401D93@0F2Ph040@801@8300600l31aCooooo000Kooooo`0?00X91`0D4`l051<?010?2`0?
3PX04A0<00h=2@0=30P04Q4=010?2`0<2`L04A0<01PG5@0:2@P04a8@008030/:01<02PT8010?3@0?
3P`040l=014@3P0R8Al0A4A20=?KfP0[;bh05Q/G00d>2P0A3PT03@X3018?1P0A3PL040d600d<1`0=
3PT03Pl:00@03`h90P0@3`X600h=200O014@300@3`/04A0<00d<200?3PX02@P500l>2P0B4@d04A0<
00h=2@0?3PX03`l;00/<1`0C50l03@h9018C3P0>3`X02``700l@2`092PH04Q<>00P91P0J6aH0=3D`
014B3@0>3`X030d800h?2P0B4`h04A8=00/<1`0200X;1P0900`=200>3`X0410;018A300A40/03Pd8
018A300C4Pd040l:00803Pd800P03`h9010?2P0?3PT0410:00D6000=3PL05aP@00T:0P803a0800P0
1`P400h?2@0A4PX0414900d>1`0?3PX02`X600l>2P8040l;0P0A40`03@0>3@T040l;010?2`0<2`L0
40l;01/J5`1@Cd/03@`901@C3`040`403`h:00h=2@0=30P00`0>3@T200d<2005014@300B4@d040l;
018A3@0?3PX00P0>3@T200d<200:00l>2P0>3@T03Pd;00h=2`0<2`T03@`:00l>300A40h040l=00l>
30<03Pd;00P03`h<00/;2@0;2`T03@d;00/;2@0=3@/06ATG00/;2@803Ph<00T03@d;00h>300@40h0
2PX800h>3@0>3P`03@d;00l?3@0:2PP00P0=3@/08P0<30X02`/900/;2@0<30X03Pd;00l>300>3@/0
30/900h=2`0@3`d03Pd;00d<2P0;2PP0D4m=03Lf=00C4Q003@/<014?400<2P/03`d>01DC500C4A80
8R0Q00X82@0C4A803@/<00`:2`0>30d03Pd;00`;2@0@3`d04a8@010?3@0:2@L200d<2P0U00h=2`0=
30X03@`:00h=2`061@<03`h<018A3`0510803@`:014@3P0=30X030/900l>300B4@l04A0>00h=2`0=
30X030/900d<2P0>3@/03@`:00l>300:2@P05aHD02h]:`0L6aT04Q4?014>3@0@30/03PX9010<2`0B
3Pd04@d<00l;2P0D40l05A4@010<2`0200l;2P03010<2`0A3@`04Ph=008040`;00<04`l>010<2`0@
30/0100@30/01P091`P061HG01PF5`0:20T03@/<014?40803`d>01403P`=00`:2`0<2P/03@/<01@@
4@0F4Q<03`/<00T61P0F4Q<04@d>03/g>00f<S<04@d>00l;300=2@X04`hA00l=4P0200`9400600h<
4@0@3Q<04a4F014?4P0:2@/061HH0P0=2``0100B4140518E00h<3`0;2@`200l=400701PF6@0B41<0
3`d@00l=400A3a8040hA00`:3@0200l=40803P`?0P0?3A009@0>30l04@lB00d;3P0D4QD030X=010>
4@0B3A402`T<010@4P0=3Q00310A00dA4P0?4a@03@h@01DF600=30h0514D00h93@0?2P`04`d?018=
3`0B30h04@/=00l:2`0@2``050h@01HA4`0=20X050h@00d92P0<2P/02`T:00X82@0?3@h040h?00/9
2P0@3Pl00P0F51D01@0@3Pl03`d>014?400=30X02PT700803Pd;00<03`h<014@3P0>3@/0100>3@/0
1P0?3Pd03`d>00h<3@0=2``03`d>010>3`804@l@00P040h?00d;300<2P/03P`=010>3`0=2``02`T:
00d;308040h?00<03P`=00`:2`0=2``00`0?3@h0200A3a002`T:01@B4`0@3Pl020H7014?400<2P/0
3P`=0P0?3@h09P0>30d040h?014A4`0B4Q@04A4C00d=3`0<30h03`lA01<C5@071`T03`lA00X:300Y
:B/0<30b01<B5`0X9b`040lD01PG700@3a@0=C@i00l>4`0>3A803@`A00h=4P0@3a@04a8G01XI7`0=
31804A0E00`;400B4AH0410B01@D5P0B4Q@04A4A01<C4`0E5AD051@D0P0?3`l01@0B4Q8051@D01<C
4`0?3`l06ATI00804A4A01403Ph>01LG5`0@41003@d=01<C4`0A4A40410@01<C4`0?3`l0410@018B
4P0A4A404Q8B01DE5@0D51@05ADE01<C4`0201HF5P0?01<C4`0F5QH05ADE01dM7@0I6AT04Q8B01@D
500F5QH05ALF01TK6P0R92<06Q`K00lA400E5aH05aTH00806Q`K00L05aTH01PJ6@0I6aP05ADB01XJ
600L71X06a`J00806adL04X05QXI01TM7P0H71d06R0P00hC5P0G71l06AhQ020U:00L8B@06QlR01`Q
900K82<09BX]02db=@0l@D@08RLZ01HK7P0P9BP07b@W01dR9@0O9RP07bLY01`T9`0K92P092db02L`
=@0M9b`06bH/01lZ<00P:Rl06R<X02L`=@0X<CH082T^01dV:`0V;c@05b0U028[<00e?T<09Rld02D^
<`0S;C@06bD^02Pb>`0Z=3d0DUaU02H`>@0K9Bh072H_01hX<@0L9Rl07BL`028/=@0R:S807B4Z01hR
:`0L82P06QlU01hS:@0Q9RX07B8V01dR9@0L8B@0:Rlb01hS9P0K8bD07bLY02Ta<`0J8R@06b<U024Y
:`0R:R`06b<U01LO8@806R8T00h07BDW01/U9P0I8b@06B<T01lW:@0H8280;cLi02X_<P0L8B@07B4T
02@X:`0K7b804aLJ01PL7`80720S0P0C5aX00`0N8RD0720S01LK7P0201PL7`0?01lS9P0_<cH05QXM
01/O8P0P92L04aLJ01DI700G6ah06alR01@H6`0M8B@07R8U01DI700G6ah05QLK00<061TM01/05QLK
01@E6@0D5AT061TM02HW:`0R8bL06Q/O04e>DP0O828071dO01LH6P0F5aT05aPJ01PI6`0K71h061TK
01HG6@0H6A/071dO01hO8@0F5aT061TK01XK7@0I6Q`05QLI01DF600I6Q`00P0E5QP01@0D5AL05AHH
01/L7P0G5aT05ADG00804Q8D00H051@F01DE5`0C4aD05aLI01<C5@0A4A<201<C5@0=01<A4P0E4a@0
5A<D018@4@0A3a004Q0A00d<300C4A806QPI01LE5P0?3@h03`/<01<=3@0201H@400<01<=3@0A2`/0
3`T901XD500=1`L03PP8018<300C3@d03`T901@>3P0C3@d03PP80P0C3@d03`0A2`/03PP800h8200G
4A405Q0@014;2`0@20P060h?00L0000G3@h0<2HW01X@4@0F30d050X;01882@02014720804PP91@0A
1`P0300E2``03@D501<92P0700006a4B0147200?1@H04@L801882@0@1PL04@L801P>3`H03`D600`0
50T=01052@0@1@T040D900d21P0=10H03PD701052@18?D40;R@W01892`0E30h301041P0300l31@0>
0P@03P84008040@60P0A1@L20186200601@8300?0`L060`@01L;3`0=0@D040@81P0?0`LDooooo`00
6oooool0300B4@d05aHB01HE4@0B4@d03Pd900l>2P0>3@T02`X6018A3@0>3@T04Q4=014@308040l=
02803Pd;00l>300A40h04a8@018A3`0A40h051<A00d<2P0J6AL092@R05ELG00C5aH05a`H014B3P0:
1`806AH?01@A200A3PL040d600l>2@0@4@`04A8=01DD400G5Q80D4m;02HU8@0?3PX030/701<B3P0<
2`L02`X600l>2P0@3`/03Pd90P0?3PX07P0@3`/03`h:00/:1P0920@03@`801@C3`0@3`/03@`800/:
1P0=3@P030d800h?2P092PL02@X5020Q700720@0414<00`=200=3PT04A8=01@E400H6A@04A8=00l@
2`0;30L02P/600h?2P0A4Pd04Q<>014B3@802``700/03@h900`<1`0@3`X051<>010?2P0A40/040l:
00T80`0A40/04a8=00`;1P02014@2`0E00X:100?40P04a@<00h?1`0<3@D041490001000W:20020T1
01HG3`020`003a0800T8100<2`L03`h:00`;1`0;2PH040l;00/:1P0C4Ph05A@@00804A0<00T030/7
020O6`0h=c<04Q4=00P70`0A40`040l;00d<200?3PX00P0>3@T02@0A40`03@`800T8100?3PX040l;
00l>2P0C4Ph030/700h=2@02010?2`0600h=2@0?3PX040l;00H50`0?3P`04a8@0P0B4@l03P0?3P`0
40l=00d<2P0;2PP03Pd;00l>300920H01`L500`<2P0:2PP02`/9018B40051@<03@d;0P0>3P`01P0=
3@/03Ph<014A3`0=3@/03Ph<00`<2P802PX800@030`:00h>300=3@/030`:0P0=3@/0500>3P`02`X8
00h=2`0B4@l02`X801LF500=30X040l=00h=2`0=30X03`h<014@3P0B4@l02`T:00h<3@0:20T02`T:
00d;300;2@X030X;0P0?3@h01P0;2@X02@L800X82@0>3@/03@`:00`;2@803@`:00d03Pd;01HE4`0B
4@l03`h<00T81P061@<04A0>00`;2@0:2@L03@`:00P71@0;2PP03`h<00803@`:00X03Pd;00d<2P0=
30X03@`:018A3`0@3`d01`H400h=2`0A40h03Pd;0P0@3`d0100?3P`03@`:00h=2`0>30X200h:2@09
00l;2P0@30/040`;00h:2@0@30/04@d<00d9200A3@`030P700804Ph=01l040`;00l;2P0?2`X03`/:
01HB4@0>2PT040`;00X61@0=2@P04@d<00/92P081PL02`T:00d;300:20T04@l@00h<3@0=2``05A<D
014?40071@H04a4B01HB4`0@30d03@T:00l;300>2P/04Ph?02l[;00V8R<05a<D00803`/<00T03PT<
01<A5P0610T04Q0E01PF6`0610P02`T<00`:3@0=2`d00P0>30d0900?3P`040h?014?4P0B41<020H9
00d;3P0<2Pd03`d@018@4`0?3A0040hA00d;3P0?3A007adP03hl?`0A3a802`T<014?4P0:20/0518E
01<A500A3a8081hQ02<Q900D4QD03`d@010;3`0?2`l030`>00`=3`0;3a00310A00T=3P0;30h030`>
00d;3P803`X>00L030H800l92`0A2`d04P`>00l92`0>20X04`d?00805@lA00L04`d?018<3P0B3Pl0
3P/<00T720081PL030X;00803`d>01P06ALH00`:2`0<2P/03`d>00D3100:20T02PT700L6100;2PP0
4a8@014@3P0?3P`02PT700l>300>3@/01PD300`;2@0A40l00`4200D3100>30d01P@500h<3@0A3a02
00h<3@0400`:2`0;2@X03@/<00d;30802`T:00h030X;00d;300=2``03P`=01hL7@0:20T030X;00L5
1P0<2P/03@/<01<A4P0A3a003P`=018@4@803`d>00L04a4B01TG600@3Pl030X;018@4@0A4A<04a<E
00803`lA01h04a<E00/;3@0>3Q003`lA010@4P0?3a40410B01<C5@0S8RL09RDZ01LF6`081``03PdB
00l>4`0A41D02`X?051?E0081``00`87018A5P0=31805aHL00d<4@0A41D06aXO00L72@0A4A<0410B
010@400?3`l2014A4@803Ph>00<030`<00/;2`0=3@d00P0@4102018B4P09010@400A4A404Q8B00d=
3@0F5QH04a<C01HF5P0B4Q806ATI00@051@D00@04a<C014A4@0@41004Q8B0P0E5AD03P0B4Q80410@
01LG5`0H61P04A4A010@400C4a<04A4A01@F5@0O8B00<38a02DW9P0C5A@06Q`K0`0G6AP02P0I6aX0
6Q`K01/M6P0L6aP05QDC01PH5P0F5Q@051HE01XL6`0H6QT201PL7@0301TM7P0I7B006QhQ00<082DX
01T07R<V01/P8`0J7b80LgQk03m4A`0X;C007b@W028W:P0D6A`082DX01hS9P0M92H06B4S028Z;@0W
;c<072DZ02Xc>00T;S@06B@Z02<^=00H8bT092le01TT:P0N:Bl08bhd00807RT_00<092le024/<P0O
:S000P0V<CL0500U;cL09C8j02@a>@0R;cL08Bhf028_=`0I9Rh07R/c01l/=00Q;SH08c0h01XW;`0L
9Bd07R8[01lS;00O8b/07R<Y024V;00P9BT06QlS0P0M8RD0900F6ah08RLZ01/S9P0`>3/0<SXm01TQ
900K8bH0Ri>F06ifN@0O9bX06R8U024Y;00M9BP06B4T01dW:00O:BX05R0Q02H^<00M9BL05QhP01`Q
900M8RD07B4T01TM800G6ah061`O01lS9P0@51L06QhQ01dQ900G6ah07B4T014E600F6Qd09b/^02HZ
;@805a/N01h05QXM01LK7P0C5aX05QXM01/O8P0G6ah05ATL02DY;00>4QD082@W01PL7`0g>ch07AhR
01DF6P0C51P05aPL01/L800I6Qh05QLK01LH700D5AT05QLK01/L800H6Ad05QLI01@E5`0F5aT05aPJ
01PI6`0M7R0201PI6`805aPJ0P0F5aT0100B4aD05AHH01/L7P0J6ad201@E5`0401LH6P0E5QP051DG
01<D5P804Q<E01805ADG01XJ700H61X04a<E01DE5`0I6A/0410B018B500C4aD051@F01<C5@0B4Q@0
5aDF01PF5`0A3a005Q@E01LE5P0<2P/500l=3P0301<?3`0E3`l04`d=00804P`<0P0C3@d2010:2P09
01@>3P0F41004`d=01D?3`0?2@T02`D501D?3`0A2`/030H600<03PP800T03`T9010:2P0@2PX06a<C
01dC500C2@X06a4B01061`0J41400P0B20T0200@1PL04@L801<92P0C2@X050X;01H<3@0<0`@02@00
0P0C2@X04P0A1`P03@<400l51P0=0`@06@l@01`B4`0=0`@050X;00l71`0B20T01`0001@:2`070000
6Q0A01H<3@0900004@L800h41@`03`@800H03`<501D92`0?10D02P0001@82P0>0P@600l31@0500h2
1P0I3A408ADI01T=4@0>0PH00P0@10P01@0D20`040@800l31`0?0`L02@0101Cooooo000Kooooo`09
00h=2@0A40`04A0<00l>2P0=30P030/7018A3@0?3PX05QDA00803Pd900<030/7010?3@0?3P`00P0>
3@/03`0A40h04Q4?00L6100B4@l01`H401@C4@0@3`d00000024X:0031`H000<001<C3`0F4`h03``5
01<@1`02014>1`0<00l>2@0@4@`0414<018A3@0A40`0=SDa01TH500E510030/701HE4@0@3`/03@`8
0`0>3@T06`0<2`L040l;00l>2P0<2`L03`h:01<B3P0>3@T03@`800T8100>3@T04Q4=00l?2`0<3@P0
4A8=01@E400K71L0=3D`01HG4P0D5A003Pl:00X;1P0;30L02P/601<D3`0?40/030d800h?2P02014B
3@0700l@2`0>3`X03Pl:00d>2@0<3@P02P/600d=200201HE400A010?2P0A40/04A0;00/:1@0C4Pd0
5QD@00h=200A40/04Q4<00`<1@0?40P04a@<00h?1`0<3@D0414901<D300m?SH00P0D5@d01@082@40
3Pl800/:1P0<2`L03Pd900803@`800h03`h:00d<200A40`03Pd900/:1P0@3`/051<?00h=2@0Y:2@0
51<?00h=2@0@3`/01PD100`;1`802`X60P0:2@D0200<2`L03`h:018A3@0>3@T02PT500h=2@0:2@D0
3@`80P0?3PX200d<200700l>2P0B4@l040l=00/:200:2@L030/900h=2`0300X91`0:00d<2P0?3P`0
30/901<C4@0B4Q00410>00l?3@061P@05aLE00`<2P803Ph<00/030`:00h>300A4@l030`:00l?3@0>
3P`030`:00/;2@0<30X03Ph<00d=2`0200`<2P803@d;0P0?3P`01@0@3`d030/9014@3P0=30X030/9
00<02`X800D030/900d<2P0>30d03`d>00h<3@02014?400400d;30091`P03@/<00h<3@803@/<00@0
3P`=00h=2`0=30X030/90P0=30X02`0>3@/01@@300L610071P@03Pd;00/:200>3@/02`X801TH5P0S
8R0051<A00802`X80P0=30X02@0>3@/03@`:00d<2P0>3@/04Q4?01<B400?3P`03Pd;00d<2P0200h=
2`0500X91`0<2`T03Pd;00d<2P0=2PT00P0>2PT0300?2`X040`;010<2`0>2PT0510?01PD4`0>2PT0
1`<200/71P0B3Pd04@d<010<2`803`/:00/040`;00l;2P0:1PD040`;00d9200A3@`05Q8A01@B4`0@
3Pl04@l@01@B4`0200l=3P0800/92P0?3@h05A<D00X82@0<2P/0?3Xk01hJ6`0H51D201<?400?014=
3P0C3a005a<D01<?400?2``04@d>01DA4P0I5AH00P0502XX;@071@X040hC010>4P0C4A@03@/>0080
3P`=00X03Pd;00l>300?3P`061HI010>4@0>30l02`T<01HD5`1HEUT061HI0P0C4A@03`0A3a803@/>
018@4`0N71l030X=014?4P0C4A@02PP;00l=400>30l02`T<01LE600I5aX03@/>00/93002014<4005
00h<3`0=3@l02``>00P<3@0:3@h00P0<30h01@0=2`h03`X>00l:3P0A2`d04P`>00804`d?00<04P`>
014;3@0@2P`00P0C3@l2014;3@05014=3P0>2``02@L800X82@0=2``00P0>30d02P0K6AX04@l@020N
7`0=2``040h?00l=3P0;2PP02PT700`;2@0A40h2010?3@0<018A3`0=30X03`h<01dL6P0J6AL040h>
00h<3@0E4a@04@l@018@4@0E4a@03P`=0P0B41401@0@3Pl03`d>014?400@3Pl03@/<00803P`=0P0?
3@h04P0<2P/04a4B00T7200B41403@/<01@B4`0=2``040h?00h<3@0A3a005Q@E00h<3@0?3@h061HG
01/I6P0D4Q<040h?01@B4`805ADG00h03@d?00`<3P0B4Q@04A4C00h>400?3a40410B00h>400?3a40
4Q8D014@5@0G5Q/040lD00P730803`hC00`051<H00l>4`1>CE806APM01PG700C4QL01`H<01HE6`0B
4AH01`H;01@C600F5QP2014A4`80410@00T04A4A018B4P0;2`/04A4A018B4P0?3`l04A4A01LG5`0@
41000P0B4Q802@0@41004A4A018B4P0M7Ad03`l?00X:2P0>3Ph04Q8B00d=3@0201<C4`0601@D500C
4a<04Q8B010@400F5QH061PH0P0K6a/0100I6AT05aLG018B4P0D51@2014A4@0701LG5`0F5QH04aDD
01TK6P0S9B@06adL014C4P0301HH5`0>01LI600I6aX06A/J01XL6@0M71T061LE01XI5`0H61H06ATI
01dO7P0J71/06alP01`P8@0K7b0201TM80<07B8U01H0724T01XO8P0J7b80<3Dh01<H6`0P9BP06AhQ
01XO8P0T:B`07B8U01hS9P0Q:2X092`^030h>`0_>3`0624V01hW;00J92X06B@Z02@_=@0P:c409S4g
0P0L9bd0300O:S0082/a01hY;`0Q;3808Rdc01dX;P0Q;38092le02Lc>P0X=Cd09C8j02@a>@809C8j
00L08Bhf02Hc>`0P;CD07b`d024^=P0I9Rh07BD^00807b</01D082@/024V;00Q9R`08BHZ02<X;00h
?D00?D9502db=@0R9bX08RX]020X:`0N9RT06R8U020X:`1IHF@0@DU<024Y;00G7b807RHY01/S9P0Q
:B`00P0P:R/0500I8b@07RHX01XR900J8R@06QlR01/P8`0L82<061`O01HJ7@0H71l082@W01TM800H
71l04aLJ00dA500P92L05QXM01TM800O8bH07R8U0P0F6Qd0100C5aX06AdP01DI700C5aX201LK7P03
01lS9P0A5AP082@W008061`O00L0[K6d02PY;@0M7R805AHJ01@E6@0B4aL03@hB008061TM00L06a`P
01PI7@0B4aL05QLK018C5@0E5QP04A8D008030d?00<03PlA01/L7P0K71h00P0K71h201TJ700302X[
;@0G61X051DG00805AHH0`0G61X0300F5aT05AHH01<D5P0B4aD05ADG01TI6`0G5aT04Q8D01<C5@0F
5QP04A4C018B50804a<E00P04Q8D014A4`0E4a@02`T:01@B4`0I5aP040h?00h<3@D04@l@00<04`l@
01@>3P0C3@d0100B30`200l92@07018<300D3Ph04@/;00l92@0>20P03`T9010:2P0200X4100400h8
200?2@T040X:010:2P804@/;00H04@T901D;300900003`D600`20`0D2P/20147200400l51P0@1PL0
4PP9014720803@<401H06a4B01H<3@0800003@@401<92P0B20T05P`=00d3100@1PL030<401<92P07
00004PX:01@:2`0<0P<04@P901dC500900002@0101dC500B20T03@<4300?10P01P0J3Q007Q8D01H:
300>0P@04`L900d10`H03`<500`02P020104200E2@d040@800X00P0B1PX04@D900T00@0>0PH04PH:
01452@0G2`lDooooo`006oooool00`0?3PX03@`800h=2@02014@300500d<200K6QH03Pd901<B3P0>
3@T00P0@3`/0100?3P`03Pd;00d<2P0>3@/200l>300:01PG5@0@3`h01PD401DD4P0920H04Q8@034g
=`0F6QT01PX700h>2`804a0;01/04a07018?200B3`P040l:00l@2`0@4@`03Pd;00X91`0C4Q002@P6
01/J600<2`T04Q4?014@3P0?3P`03@`:018A3`0F5A<040l;01<B3P0A40`030/7014@300F5A404a8>
014@300>3@T00P0A40`0200=3@T03Pl:00/<1`0:2`H020T401PI50082@D04A8=0P0=3PT09`0?40/0
3Pl:01@E400>3`X02``7010A300E5Q404a@?014B3@0>3`X02``700l@2`0@4@`03@h9010@2`0D4`h0
4Q4<00h=200?3PT040l:00`;1P0B4@`05aHA00l>2@0>3@P040l:00h>200?40X04A8=00h?2P0=3PP0
3a0;00L8100X:B<02``700/<1P0:2`D03a0;00l>2P0200d<200400l>2P0@3`/03Pd900`;1`803`h:
00T03@`800h=2@0@3`/030/701`K5`0920@01`H200/:1P0B4@d00P0=30P0200J6AD06aXF00h=2@0@
3`/071/G01XI5@0C4Ph03@`80P0?3PX00`0<2`L03`h:00h=2@0200d<200400h=2@0B4@l03@`:00d<
2P@040l=00D03`h<010?3@0?3P`030/900/:200200d=2`0C00X:200B4Q002`/900T91`0<30X03Ph<
00d=2`0<30X03Ph<014A3`0<30X0410>014A3`0?3`d03@d;00`<2P0@40h03Ph<00d=2`0300`<2P07
00h=2`0;2PP020L500l>300:2@L04A0>00h=2`0300l>300400d<2P0<2`T030X;018@4@8040h?00<0
3`d>00/92P0<2P/00P0>30d200`:2`0400h<3@0>3@/03@`:00`;2@803@`:00X03Pd;00`;2P0@3`d0
3`h<010?3@0920H03@`:00`;2@0>3@/04Q4?0`0@3`d200h=2`0400d<2P0>3@/03Pd;00h=2`802@P6
00X03Pd;00l>300F5A<06APF00d<2P0:2@L03@`:010?3@0>3@/03@X9100?2`X02P0@30/04@d<00l;
2P0?2`X04`l>010<2`0C3`h04Ph=014=300@30/200l;2P0H014=300B3Pd03@T8018>3@0<20L03@T8
00h:2@0?3@l030X=00h<3`0@3Q403P`?00`:3@0@3Q402`T<00h<3`0A3a802`T<00X82`0E4A803`/<
00d92P0?2``03@T:0`0?2``0200A3@h04Ph?018>3`0@30d03P`@03@b=`050`P04@lB0P0<2Pd00`0@
3Pl03`d>00h=2`0200h=2`0W00d<2P0B3A005a8F010;3`0?2Ph07QTM04e8C00>2@d03`X>018=4@0C
3Q803PT=00d8300:20/03`d@010>4@0=2`h030X=00d;3P0A3a8030X=014?4P0B41<03@/>00l=400B
31004PdA018>4P0>3Q002@X<00L82P0;30h030`>00d<3P0?2`h040X>010:3@0D3Pl04P`<00804@/;
00T04P`<01<=3@0=1`L040X:014;2`0@2PX04@/;014=300=2``00P0<2P/0300?3@h03@/<00`:2`0H
5QL040h?00H51@0;2@X03@/<00/92P0=30X03Pd;00l>30803Pd;00/040l=00l>30081`D04a8@00@3
0P0;2PT0;2/Z00d;30091`P04@l@00/92P0200l=3P803P`=00@03@/<00`:2`0=2``03P`=0P0=2``3
00h<3@0@010>3`0=2``01P@500X82@081PL06aTJ02XX:@0e<c@05aDF00X82@0C4A804@l@01<A4P0B
41404a4B014?408040h?01403`lA010@4P0?3a40410B014A4`0@41803Ph@00l?4@0@41803@d?00h>
400A4A<03PdB01DD6@0F5AX04Q4F01HE6P0201@C600>014@5@0Z:Bh05A@I01`K800@3a@05aHL00l>
500G5Q/03`hC018A5P0G5aT04Q8D014A4`0A4A42010@4004014A4@0C5A@03Q0?00h@3`804A<B00@0
2`d<010B4@0B51<04Q@C0P0@4Q403`0B51<03@d=00d=3@0K6a/02`/;01<C4`0:2PX04A4A018B4P0C
4a<04Q8B014A4@0@41003Ph>010@400301<C4`03018B4P0H61P06QXJ00805QHF00/06ATI01LG5`0F
61L05aTH01@F5@0E5aH061XI01LI600E5aH05QPG01LI600201PJ6@0301TJ5`0N7AX06QTG00806QTG
00<06QXJ01dM7@0I6aX00P0M7R001@0H71d05a/N01TM800J7b806AhQ00806QlR0P0K82<07`0E6Qd0
6AhQ02<X:`0Q9RT06b0S02@Y;00R9bX07b@W01`S9@0J8R@082P[02</<00K92T07RL/024[<@0T;cD0
9C0f020[<@0J9B/09S4g028]<`0J9B/07BP^01hY;`0P:c408bhd01dX;P0L9bd082/a02Ld>`0U=3/0
0P0P;cH3028a>00H02He?00K:S407B`c02He?00M;3<082/b01lV;P0L8b/082L^02@[<@0P9bd09Bd`
01hV:@0O9bT08b/]01hV:00M9BL09Bd`01LO8P0L92L0620S01hV:@0O9bX0;cLj0P0N9RT0;00X<3<0
7BDX01lW:P0N:2T06R@U01dW:00D71h06b<U01hV:00F6ah061dP01XN8@0G6ah05QXM01PL7`0F6Qd0
:2`_01LK7P0C5aX08RHY038f>@0J7R407R8U01DI700B5QT05a/N01HJ7@0D61/07B4T01XN8@0E6A`0
61`O01/O8P0D61/06alR01dQ900F6Qd06QhQ01TM800L7B405QLK01<D600E5QX05aPL0P0F5a/0300I
6Qh07b0T01XK7`0C51P061TM01PI6`0D5AL05QLI02LX:P0`<C<061TK01XK7@8071dO00X06a`N01TJ
700G61X0:bd/01HH5`0C5A@051HE01<E500D5QD05QPG0P0H6QT0200F61L051HE018D4`0G5aT061PJ
01HF600B4Q@04A4C1@0C4aD0200A4A<0410B014?400F51D030X;02TW:00`;Rl04a4B1@0@3Pl01P0B
3Ph04`d=01@>3P0D3Ph04P`<014;2`<04P`<0P0C3@d0200B30`03`T901TC4`0N61P04`d=00l92@0C
3@d04P`<0`0A2`/2018<300401L?400e:b`07Q@E01@:2`8040H700@04PP901061`0?1@H040H70P0A
1`P05P0F30d03P@500l51P0=0`@030<404Hl?@0E2``04@L801882@0900403P@501@:2`0A1`P06Q0A
0107200E30d0JEmP01dD500O5AH060h?01@;2`0<0`@201061``03`@800D03@<401451`0>0`@02`01
0186200700l31@<04PH:00T03`<701452@0N4QH091PL00l41`0?0`L04PH:00/00`0?10L05?ooool0
01_ooooo00`040l;00d<200>3@T04Q4=01DD400B4@d0>3Lc01HE4@0A40`03Pd9010?2`0?3PX500h=
2`0>00d<2P0<2`T0HV5O02l^;00<2`T040l=01LG5@0=5A@05ATH01DJ5P0A4Ph02`P3014>1`0B3`H2
018?200Y010?2P0?40/03a0;00l>300<2`T051<A00/:200C4Q003Pd;00/:200>3@/03@`:00`;2@0B
4@l05QDC01@C3`0B4@d04a8>01HE4@0C4Ph03`h:00T8100>3@T030/700l>2P0B4@d0410<01<D3`0=
3PT03a0;00X;1P0E5Q403@h901LH4`0B4`h03a0;00`=200720<0414<014B3@0?40/00P0<3@P0200>
3`X04Q<>00h?2P0?40/06a`G01PI500@4@`03@d80P0920<07`0>3@P040l:010?2P0=30L04A0;01DD
3`0@3`X03Pd800l>2@0>3PT03Pl:00l@300>3P`03@h900h>2`0=3@/04Q<>00d>2P0A4@l01PL200X:
1`0A40`03Pd900d<200@3`/04A0<00h=2@0<2`L03@`8014@300?3PX00P0=30P05@0920@04A0<014@
300?3PX01@@000P71@0;2PH02@P401PG4`0I61@02PT500d<200B4@d040l;00l>2P0=30P02`X600X9
1@0>3@T040l;00l>2P0200h=2@03010?2`0A40h02`X800803@`:00d020L500T81P0:2@L01PD300/:
200=30X02`X8010?3@0<30X051@B01/K6@0=3@/02PX800802`/90P0=3@/02`0;2`T03@d;010@3P0:
2PP03`l=014A3`0@40h03Ph<00d=2`0?3`d03@d;00<030`:00T03@d;01lN700G5Q@03`h<014@3P03
0P0030/900/:200<2`T00P0=30X04@0:2@L02@P601<A4P0Q7b006aTJ00h<3@0?3@h04Q0A00l=3P0@
3Pl03P`=00`:2`0;2@X03@/<00h=2`0=30X030/900803@`:00L03Pd;01XI5`0?3P`040l=00H50`0A
40h030/900802`X801405QDC01`K6@0B4@l02`X800l>300>3@/03@`:00h=2`0?3P`04a8@00l>300;
2PP02PT700D40P0>3@/04a8@00l>300201DD4P03010?3@0?3P`03`d;00D03`/:00P030P700l;2P0F
4Q403`/:00<0000>2PT04@d<010<2`803`/:00T040`;014=300>2PT02PH501DA400D40l06ADD01`H
5`0;2@`00P0>30l02P0:20/02`T<018@4`081PT02`T<010>4@0<2Pd02PP;01HD5`0B3Pl200d92P09
010<3@0?2``04@d>00d92P0@30d05A4B01HB4`0C3a0040`=008030X=01405Q@G00d;3P0?3@l03P`=
010>3`0?3Pd03Pd;00h=2@0=30P030/900L3100E41@03@P<014<400<1`/0100300d83002018=4@05
010;3`0A31004`hB014?4P0B41<00P0:20/00`0?3A0030X=010>4@0200`:3@0Z00/9300<2Pd04@lB
00h8300A2`l04PdA010?4@0;30h02P/=00/<3P0<30h03@/>00l:3P0@2Ph040X<01@@400@30/03@T8
00h:2@0@30/04@d<00`81`0@30/04@d<010<2`0A3@`04`l>00h<3@0<2P/03@/<00l=3P0=2``02`T:
00H41@0:20T06ALH010>3`0200403`d>00l>300@3`d03`h<0P0=30X04@0@3`d03@`:00<2000A40h0
0@0002HU8`1UI6<07A/L00P61`0D4Q<03@/<00h<3@0?3@h03P`=00l=3P0>30d03@/<00803P`=1@0=
2``03@0@3Pl02PP900H41@0B41406aTJ03@b<`11?d00@T1101dK700;2@X04Q0A014?400D4Q<00P0?
3@h01@0B41404a4B018@4@0;2`d02PX<008030`>00D02`/=00`<3P0>3Q003`lA010@4P0200h>400C
014A4`0A41D051<H01<B5`0?3Q<040lD014@5@0B4AH06APM010?500;2Pl03`hC01<B5`0C4QP03@`B
018A5P0F5AX03@`A01/K7@02010@4P0;00l?3`0=3@d03@d=00h>3P0<3Pd05aTH01DG5P0;3@`02P`;
01DG5P0@4Q400P0B51<02`0@4Q404A<B018D4`1HF5P061PH00/;2`0?3`l0:2PX00d=3@0@41004A4A
00804Q8B00@04A4A010@400D51@05ADE100F5QH05P0M7Ad07alO01TI6@0G5aL05QHF014A4@0F61L0
6A/J01<E500K7A`08R@S01/M700E5aH05QPG01LI600H6QT06A/J01XJ600T8Al08AdL01dI600J6AL2
01XJ6P0701dM7@0N7b407AhP01/L7P0P8BD08bLZ01XO8P0201TN8@0T01/P8`0L8B@07B8U01TN8@0N
8bH05AXM01lT9`0M8RD082DX01/P8`0O92L07RDW01hV:00N9RT072@X020Y;P0T;C809Ble020[<@0L
9bd07BT`01LT;00d@DT0:3Dm01h[<`0J9bl08c0h028_=`0Q;SH08Rlg01l/=00M:S808Blf020_=P0J
:C006BP_0`0K:S40A@0O;SD05RD/01l^=@0/>d8082lf020/<`0P:C007BH]024Z<00U;S<07bP]01hX
:P0J92H072HW028/;@0P:R/07BLX028Z;@0L8bT09Rdc01LN900M92X072<Y01/R:00/<cT092/a01PO
9@1`Mgd0=3a001dW:00D7Ql07BLX01LO8@0M9BL0620R01DJ7@0F6ah061`O01HJ7@0E6A`05a/N02X^
<@17Bdh07b<V01LK7P0b=ST04aLJ01LK7P0N8RD05ATL01@H6`0L82<06AdP01@H6`0H71l05a/N01TM
800M8B@061`O020T9`0B5QT0=SXm01lS9P0A5AP0;C4d01TJ7P0F5a/051DI01DF6P0201HG6`0N018C
5`0J6al04A8F014B5P0J6al051DI01XK7@0F5aT06a`N02h_<@0_<3803PlA01LH6P0H6A/06AXL01PI
6`0F5aT05AHH010B4@0D5QD06A/J01LI600C5A@05ALF01<E500D5QD05ALF01@F5@0B51<04A<B0P0I
6A/01`0G5aT051@F018B500C4aD051@F01<C5@0B4Q@00`0A4A<01P0C4A8020H701PF5`0A3a000P01
00d;30D03`d>00L040`=018<300C3@d050h>018<300@2PX04@/;00804P`<0`0A2`/0200?2@T05@l?
01LA4@0?2@T04P`<01<=3@0?2@T040X:100?2@T0100=1@H0:b4R01D;300=1@D200l51P0?01@:2`0B
20T040H70147200C2@X04PP901061`0?1@H05@/<01@:2`0<0P<02`8200/10P08000050X;008040H7
00d03P@500l51P0@1PL06@l@00L0000U6a`02`8301D;300700005@/<02TO800B20T06@l@00`03`@8
00H04`L901@82P0A1@L03@4300h2100:000600l31@0301862P0@10P04@D900803P8600L05PX>01D9
3@0C1`/0300401862P0J3Q803@4501Cooooo000Kooooo`0400d<200<2`L030/700l>2P804Q4=01h0
:2LS00`;1`0?3PX030/700d<200B4@d03Pd;00l>300@3`d03`h<00h=2`0=30X03`h<02PW9@051080
5A@B010?3@0000001@X900hB4@042@D03Ph:01<@2`0>2`@04Pl6018?200C40T04A0;00l@2`0>3`X2
010?3@0?01XI5`0@3`d03`h<00h=2`0=30X03`h<00h=2`0=30X030/900d<2P0@3`/03@`8018A3@0J
6AD05QDA008040l;014030/700L60P0:2@D03Pd900P8100<3@P010D000`=20082@@04A8=00X;1P0A
4Pd03Pl:00d>2@0;30L01`P300h?2P02014B3@0A00d>2@0:2`H030d800h?2P0;30L04a@?02@U800J
6aH03a0;00h>2@0;2PD02PT4018A300C4Pd04A0;010?2P0B4@`00P0D4`h0100B4@`04A0;00l?300=
3@/300h>300:00d=2`0C4a402@T7018B400F5Q@02@T700`<2P0@3`/03`h:00h=2@803`h:00<03Pd9
010?2`0<2`L00P0;2PH05@0<2`L05QDA00/:1P0:2@D040l;01@C3`0>3@T081lK014@300<2`L03@`8
00/:1P061@404A0<00`;1`0;2PH03`h:014@300<2`L02`X600h=2@02010?2`0:00h=2@0?3PX040l;
018A3`0:2@L02`X800`;2@0A40h08R4O01dL6P803`h<01@040l=00X91`0<2`T04a<A00D5100;2`T0
3`l=00X:200?3`d02`/900d=2`0<30X02`/900`<2P0?3`d02PX800h>300@40h03Ph<00d=2`803Ph<
00l03@d;00`<2P0=3@/03@d;00h>300E51804A0>00d<2P0?3P`02@P600d<2P0<2`T03@`:00h=2`0?
3P`00P0>3@/0200B414081hO01TG600;2@X03@/<014?400<2P/03P`=0P0=2``01@0?3@h04Q0A00h=
2`0=30X030/900803@`:00L03Pd;03ln?00O7Q`05QDC0040000G5Q@03@`:008030/901L05A@B01dL
6P0B4@l02`X800l>300>3@/03@`:00h=2`0?3P`03@`:00/:200@3`d03`h<00P71@0:2@L030/900l>
300G5Q@05QDC00h=2`0?3P`04@h=010<2`0300l;2P0700h:2@0@30/03@T800T5100C3`h07a/J018>
3@02010<2`803`/:014040`;018>3@0>2PT02PH5014=300?2`X04`l>01HB4P0<2Pd040hA00h<3`09
1`X030X=00h<3`0C4A@040hA00X82`0200D31P0500L5200F4Q<04@d>010<3@0B3Pl00P0?2``03`0@
30d04`l@01LC500E4A804Ph?010<3@0I5aX08b4T02PV:@050`H040h@00P61`0?3@h03`d=00h=2`02
00h=2@0@00d<2P091@H03@P<01HA5@0K5QX05A0D02hY;@0C3Q8050lC00h93@0<1`/03@P<00/62P0=
2`h03P`?00d;3P8040hA00h020H9010>4@0@3Q403`d@00d;3P0?3A0050lC00h8300@2Ph04@`@010>
4@0=3@l030d?00`<3P803@/>00X03`X>010:3P0@2P`0510?014=300?2`X040`;018>3@0C3`h03PX9
0P0B3Pd0100A3@`04Ph=01<?3P0?3@h200d;300:00h<3@0=2``030X;01HD5@071@H0CD]<03Le=P0G
5AH04Q0A010?3@<03Pd;0P0?3P`03@0I61H04a8@00d<2P0100001@@2024O7`0@3Pl01`D600P61`0J
61T06ALH00P61`0=2``00P0>30d200`:2`0400l=3P0@3Pl040h?010>3`803`d>0P0>30d02`0<2P/0
7A/L01lM7P0Z:2T05aDF00`:2`030@803`d>01LE5P0@3Pl04@l@00803@/<00H03`d>010>3`0A3a00
4Q8D00d=3`092@/200L72@0L010@4P0>3Q003`lA010@4P0?3a40410B01<C5@0@3a@04A0E010?500=
31403PdB018A5P0:2@h05aHK00l>4`0<2a002`X?010?500=31800@0601PG702ZZJh0<C0e00l?4@0A
4A<0410B00l?3`<03@d=00T04A<B00H81`0;3@`06A/J01PJ6@072@P0418A01<E500B51<00P0A4a80
2`0C5A@0FEUI028R8P0C4a<06QXJ02l_;`0K6a/0410@014A4@0B4Q804a<C00804Q8B1P0D51@0300F
5QH06ATI01HF5P0E5AD05aLG018B4P0D5QD05QPG01@F5@0L7Qd0828Q01XL6`<05aTH03D06A/J01XL
6`0L71X09b@R02@P7`0O6aX07A`J01hN7P0L71`06a/K01dN800J6ad05aPJ01dN8P0Q9BP0720S01XO
8P0I7R406b0S01dR9@0N8bH07B8U01<H6`0I7R407b@W01TN8@0/<C@06QlR01lT9`0O9BP082PZ01lW
:P0O9b/0:S<h02H_=00R;3807bX`01`W;@0T<3L06bP`030mA@0M:S809C8j01PU;@0T<CT08c0h02@a
>@0Y=Sh0934i01h[<`0P;SH08C0g01d/<`0201PW;P0J01XY<00L:c8082lf01TX;`0Q<3L0:cY101h]
=00O:c808BXa01lX;`0Q:S008b`a01lX;@0F82805b4S01/U9P0N:2T07BLX01XT9@0S:S006b8X01`S
:@0K8RP08RT_020W;@0V;C<202T`=P0G01dT:P1hOhD0>D55028/;P0I8b@07BLX01/S9@0J8R@06b<U
01HK7P0G71l06AdP01HJ7@0E6A`05QXM01LK7P0`=3L06alR02DY;016BTd09BT/01DI700K7b800P0I
7B000`0M8B@0720S01<G6P0201DI700;01PL7`0K7b804aLJ01XN8@0D61/05ATL01LK7P0U:B`00044
01TJ7P0H6Ad0100F5a/0200C51P06Q/O014B5P0>3a<05QLK01<D600@4A<05QLI0P0L7Al01@0G61X0
3a0B01XK7@0J6ad06AXL00<061TK00L03a4@01DG5P0I6aX051HE01DG5P0K7A`04aDD00D04Q@C00@0
6ATK01PH6P0G5aT05QHH0`0D51H00`0B4Q@04A4C014A4`02018B500601@B4`0C4A807adN01LE5P0D
4Q<08AlP1@0A3a001P0B3Ph04P`<018<300B30`04@/;010:2P803`T900<040X:00l92@0?2@T00P0A
2`/01P0@2PX03`T900l92@0A2`/040X:00h820<03`T90P0>20P02P0;10@0718C00`20`0=10@03P@5
0147200C2@X04PP901061`0B20T301<92P0G01@:2`0=0`@040H701`B4`0K4A808ALH01882@0@1PL0
308301061`0J41406@l@00L0000>10D060h?01dC500D2P/04@L800L0000J4Q801`0000P0000=1@D0
300?10P00`0A1@L04PH801451`0201041PL03`<500`04@D90104200B1PX03`<700`0100@10P02`03
01@8300<00@04PH:01lC5`0<00@Dooooo`006oooool03@0;2PH03Pd900d<200<2`L03`h:01<B3P0B
4@d05A@@02TX900J6AD030/701DD400@3`d00P0B4@l01P0A40h03`h<00d<2P0?3P`030/900d<2P80
51<A00/03Ph=00lE500>4Q00310<01XK5P0A3`X04Q09014?1P0C40T04a4:018A300200h?2P0500h=
2`0B4@l04Q4?010?3@0A40h00P0=30X0<@0>3@/04A0>01<B400>3@/02PT700h=2P0<2`P03@`8014@
300B4@h04Q4=010?2`0>3@X05QDA02HU8@0J6AH02PX601DF4@0:2`H04A8=00T:1@0=3PT02@X600l@
2`0>3`X0414<00l@2`0:2`H03Pl:00d>2@0?40/05AHA01@E400?40/03Pl:00`=200=3PT051D@00h?
2P0@4@`07AdH01HE400>3@T04A0;00h=200<2`H03Pd800`;1P0;2PH00P0A40/02`0=30P030`900d=
300>3Pd03Ph>00h>3@0=3@`04Q8B00L71P0?3`l030`<00803`l>00P03`h:014@2`0B4@`03Pd900`;
1`0?3PX04A0<00d<20803`h:00X03@`701DD3`0B4@d020L300l>2P0B4@d02@P502DT800?3PX040l;
0P0=30P02@0?3PX040l;00h=2@0;2PH040l;018A3@0=30P03`h:00d<200200l>2P0=00d<200>3@T0
3`h:010?3@0=30X04Q4?00d<2P0?3P`09B@R02XY9`0A40h03@`:014@3P0200`;2@0B00/;2@1?Cdd0
5ADC01<C4@0>3P`03@d;00/;2@0=3@/030`:00/;2@0<30X03`l=00X:200=3@/030`:00/;2@0=3@/0
3`l=0`0<30X02@0>3P`0410>014A3`0;2PP030/900l>300:2@L04a8@00`;2@0300h=2`09014@3P0D
4a405A@B00h<3@0B41403P`=00d;300>30d03@/<00803`d>00L03P`=00`:2`0?3@h04@l@00h=2`0=
30X030/900803@`:01P03Pd;01HE4`0;2PP03`h<00L6100G5Q@030/9010?3@0>3@/020L500h=2`0@
3`d03`l=010?3@0>3@/03@`:00h=2`0@3`d02`X800h=2`0D4a403@`:00`;2@0?3P`200`;2@<03@`:
00D03Pd;010=300@30/040`;00l;2P0300h:2@0601TE500K5aH05A4@024M7@0C3`l040`;0`0?2`X0
8@0@30/04Ph=01DA400>2PT040`;00T5100<20L040`<00l=400?3A4040hB01XH7@0O7B404Q0D00d;
400>31003`dA014?500A3a<03P`@018>400=2@X03`/<018>3`0?2``040`=014=3P0C3a00510A00l;
300=2@X03`/<00X92`0200d;3P0@00`:2`0=2``04@l@00d;2`0>30/03Pd;00h=2P0?3P/040l=00l;
300C3A402`D9014;3`0A30l05A0D01@>4P803`T=00D071HJ028M8@0A31004a4D010>4@02014?4P05
00`:3@0?3A002PP;010>4@0?3A000P0=2`h01@0?2`l04`dA018=4@0?30l03P`?00<030`>0P0=2`h0
4P0?2`h040X>010;300>30T03@`900`;1`0=30P03`h;010?2`0>3@X040l<010?2`0?3PX03Pd:00l>
300B41403@/<00`:2`<03P`=00T05A<D05UGF00_;Bh071XK00d;300k>CX04A0>00`:200<2`T00P0B
40h03P0>3@/03`h<01HD4P0G5A<04A0>00h<2P0;2PT03@`;018A400@3`h05aHE01/I6P0>30d03`d>
0P0A3a0200h<3@<040h?00l03`d>00h<3@0>30d03`d>01/I6P0=2``06ALH01DC500A3a003P`=01<A
4P0A3a0061HG018@4@0;2@X00P0C4A80200A3a003P`=00d;300?3@l04A4C010@4P0G5aT05ADG0P0>
3Q001P0=3@l03`lA014A4`0B4Q@04a<E01LG6@804Q4F00T04a8G018A5P0?3Q<04A0E00l>4`0C4QL0
4A0E00P7300@3a@00P0C4QL01@0@3aD0410D01hM8P0B4QD06QXL008051@F00/04Q8B010@400@4100
410@01@F5@0=4A007B4P030d<`0X;2/020`;00lC4P02014E500700lC4P0@51<04aDD01PH600C4a<0
3Ph>018B4P0201<C4`03014A4@0C4a<051@D00<051@D00@071`L01/K6`0I6AT05aPH0P0F5aL02@0E
5QD06Q/J01PI6@0I6AX06a/L01HF5`0H6QT051HE01DG5P0201TK6P1;01PJ6@0K7A`05aTH01HH5`0I
6aX07AlN020Q7`0N7AX07a`K01TG5@0K6aT081lO01dL700O8200:2PY02HW9`0L7Qh06Q/N01/O8@0L
8R<06QlQ01TN800I7b80724T01`S9P0W;C008BP[02H]<00Q9bX0728U028Y:`0O9RP07b@X01TQ8`0N
9RT07bLZ01hV:`0Y<cL08BX_02H`=P0V<SP06R@/01l/<`0I9bl09S<k024^=P1;F600934i01h[<`0Q
;SH0:SLo030mA@0U<SX08Bhf02<a>00R<CP07bhe01LV;@0B8BP062L^01h]=00U=3X07R`c02<a>00[
>D008Blf020/<P0P:c408B`b020[<00N:Bd07bX^01`W:P0P:bd08bl_00807b/[03@07bX[020X;00Q
:Bd06b<X02<Z<00N9RX082L/028Y;`0K8bL08BT^020W;@0W;c<08BT^028[;P0P:R/06R<T01hV:00I
8B<0?TI801TN8@0J7b806alR01LK7P0E6A/05QXM01`P8`0J7R40720S01XN8@0M8B@05a/N01TM800F
6Qd06alR01XN8@0G6ah07b<V01LK7P0O8bD07B4T01TM800G6ah05ATL01<G6P0H71l07R8U01/N8P0L
7b<061`O01TJ7P0J6al06AXN0`0G61`07`0F5a/06a`P02`]<@0O82@0414E02l`=00/;Bl061TK01`M
7`0O828061TK01/L7P0M7R006a`N01LH6P0H6A/06Q/M01/L7P0F61L05ALF01PJ6@0G6AP051HE01LI
600F61L04Q@C014C4P0B51<05ALF01LI600F5QP00P0D51H0100E5AL051@F01<C5@0C4aD2014A4`09
018B500D51H05ADF01PF5`0J61T04@l@00h<3@0A3a003`d>00D040h?00<04Ph?01<=3@0A2`/00P0@
2PX02`0A2`/04P`<01<=3@0D3Ph04`d=01@>3P0H4Q805a4A00h8200@2PX05@l?00803`T900@04`d=
018<300A2`/04@/;0P0@2PX01P0B2P/05@/<00d3100G3@h03`D601L=3P804@L800L03`D601061`0B
20T04PP900l51P0C2@X05@/<008040H700H040L802XP8@0H3a004PT90108200@1`P200h41@0;01@:
2`0D2`/03PH600l71`0@1`L03P@501@<300c:BX03`H701hD5@0@1PL0300?10P200h3100401041P0A
1@L040@601451`H03`<500L04PH:0104200C1`/04PH:00l31`0B1PX040@800804@D90P0B1PX00`0?
0`Ooooooooooo`0Booooo`006oooool0:@0@3`d02@P600T81P0?3P`04a8@00l>300K6QP02PT801dL
6P0A40h040l=01<B400@40h03`l=014A3`0E5A<04a<A00L71@092@L03@d;00h>300;2`T020P6014A
3`0F61<03a4<014B3@0B4`d03Pl900H70@0>3PP04Q4<00X;1@0;30H0414;00/<1`0>3P`030`:00/;
2@0=3@/03Ph<0080410>01@02`/9010@3P0J6QP05ADC00d=2`0:2PP07alO014A3`0820P0:RXZ0000
000=3@`06a/K0000000P81l01PH600l?300A4Pd03Pl:00X;1P803a0;00@02@X500X;1P0=3PT03Pl:
0P0<3@P00`0=3@X030`:00h>300201LG5@0U010@3P0>3P`0410>00P81P0<30X05QHD0492@01<C4X0
2@X500`<2P0;30P07QlJ00@40P0>3P/03@h900l?3@0@4@d03a0;00d=2`0>3P/03@h900/<200=3@/0
3Pl:00h>2`0=3@/03@h900`=2@0<30X03@h900h?2`0=3@D0514800l<1@0@3@P06AHA01<?300200d9
1P0L00l<1`0C40T0514:010?1P0E50l03@h800/<1P0<3@L02P/500d>200;30H030d700l@2P0E5Q00
3@h800/<2@0D5A000000014A3`020P0051@B00L71@0o?cd051@B014A3`0F5Q@030`:018B40803@`:
0P0>3@/2010?3@0U00X91`0F5A<010<1010?3@071P@03Pd;00H6100n?S`07QhL01HF500<30/03Ph<
014A3`0=3@/030`:00l?3@0@40h03@d;018B400=3@/03`l=00d=2`0;2`T04a<A02TY9`0A4@l0410>
00`<2P0A4@l06QXH01<C4@051@<020P600d=2`0B4Q003`l=00X:200200d=2`0=00/;2@0=3@/0410>
00d=2`0A4@l01`L500`<2P092@L01`L5018B400@40h02`/900P81P0200T91`0301<B400?3P`030/9
00<02PT7018030/900/:200<2`T03Pd;010?3@0B40h030P700T81P0=3@/01PP500X?2`0l@Cd0QHZ6
014C400;2PP040l=01TE500>2`X2010?3@0400/:200>3@/03Pd;00X91`8030/900D03@`:00`;2@0;
2PP030/8014@300201@C4@0A00d<2P0:20T02PP900d;300>30d040h@00l=400>30l04@l@00`:2`0:
20T04Q0A00<10P0N71d04@l@010>3`0>30d00`0=2``0@@0<2P/00`4200h<3P1PGV40QhF600h<3P0<
2Pd03@/<00h<3P0>30l03@/<00d;3P0;2@`04Q0C01DC5P0;2@`020H9010>4@0;2@`01085010>4@0<
2Pd0518E00T72P0<2Pd03P`?00d;3P0<2Pd03`d@01<A500?3A0030X<00H41@0D4Q<030X;01/I6P0=
2`h03@T=014?4P0A31005A8E02l]<0080`L03``?01HD5`0<1`/0Ad=701PF6@0D4QD05A<F014?4P0=
2`h06ALJ00X82`0<2Pd04Q0C00@21@0J61/02@L:01<A500>30l02PP;018B500A4A<02PX<00803@d?
0140410B00/;3@0:2@`05A<F00X82`0=30/040h?00d<2P0;2@T03@/<00h=2`0A3`l03P`=00h=2`0?
3@d040h?00d;300200h>3P0500/;2`0=3@d03@d=00P8200J6QX00P0C4a<09`0>3Ph030`<024O800>
2PT03`T900l;2P0@2`/04@/;02XU900K5aH03`T9018=300<20L050h>00h:200@30T04@d:010<2@0C
3``04Ph=00`81`0C3`h06aLF01HB4P0=2@X040`=018@4@0>3Ph030`<00d=3@0?3`l03Ph>00d=3@0@
41004a<C00l?3`092@T02`/;00l?3P0200l?3@0>00d=300=3@d0410@020P8@0?3a4020P:01@D5P0:
2P`040lC01HF600410@07QhN00X:2P0C4a<2014A4@0Z00`<300B4Q80<C4a01@D500=3@h06APM00P7
300C4QL00`8701/J7`0F5AX07A`Q00H52P0D4aP04Q4F02<R9`0H5a`0410B01HF600A4A805QHH01<C
4`0>3Ph04a<C00l?3`0B4Q80410@00`<300B4Q804a@F01@E5`0f=cT06AXL01DF5`0B51<04A<B00lA
3`0@4Pl03Q0=01PJ5`0_<Bh0410>0P0A4@l00`0@40h04A4?01<C4@0201HF500A014A3`0D51804a<A
00L71@0E5AD05aPG01LI600D61L051TH01DK6`093`l0Ff1P06AXJ@0I6Qh07AdQ01TH7@0E61T00P0A
5AH0900D61T05QXK01HJ6`0C5aP06alP00P<3@0K7b0082@U01@H5`0O8Ad07AlJ02la;00J71L051HA
01HH4`0L81`0<C<`03<h=00Q9R806QlK024V8P0D71H06B8M01LP7@0I8R<072<Y01PQ9P0/=C`0:SDi
02<^<P0X<cD07RXZ02@`<00J92H06B0V01`V:@806B8W04X07BP^038oA@0P:c409c@l01XY<00P;CH0
7Rdd01X[<P0V=C`0>4M>03=2B@0_?TD0;Sa402Tf?P0U<SX09S4j02H`>@0S;CH07R`b01/Z;`0H9b`0
5B@Y01PW;00P;C<08Bhd01l]<00U<3H09c8g02<^<P0N:Bl06R@[02D^=`0N9c008b`c02@]=00Q:S00
8b`a01hW;00J8bL07BLY020Z;00O:B/092h`01/W9`0M:2T082X/01LS8`0I92D07RPZ01l[:`0P:b`0
72HX01XV9P0O:B/08BT/01XR9@0K82<0724T01LL7`0G7Ad06b4Q01XP800I7ah06AlO01XP7P0M8b<0
5a/L01/O800H71d08RHW020T9@0H71d06QhO01/O8080720Q01406alP01XN7`0K7b007R8R01PL7@0D
61T05a/M01TM800L7b@061/P010C600B5A`07R4X01LJ7`0P8BD061TK01XK7@0201<D5P0301TJ700E
5QP05AHH00806a`N00L05AHH01/L7P0Q8RH06AXN01hO8`0R8bL071dQ00D061TM00T05QLK01DF600C
5aP05QXK01@H6@0I7Ah030d?010A4`0D5AL00P0?3a401@0G5aT071`N01dM7`0C4A80518C00805A<D
0P0D4Q<0100P7Ql0:BLX00L51P0G5AH201@B4`0D01<?3`0D40l04`l>010<2`0?2`X040`;01<?3P0G
4a804@d<01HB4@0J5QD03@T801DA4012?Sd02PL601PD4`0B3Pd02PH5010<2`0A3@`200h:2@0B014=
300F4A805Q0B01@>400B30h04@/=018<3P0>20X06aDG00/51`0G4A<0100001dG6@0@20T040H700l5
1P0F30d05@/<0P0B20T00`0>10D03@<401882@0200l51P0601@:2`22O7`0<2PX00h51P0@1`P02P82
0`0A1`P30186200601T?400700004PP900/10P0F30d040H70P0B20T200d3100501061`0;0P804@L8
01061`0?1@H00P0A1`P01`0@1PL0308301L=3P0C2@X05@/<01<92P0;0@801P0>10D04P0;0@802P01
01061`0B20T03P@500X00@0:008040@800l31`0@10P04`L;00X00P0C1`/040H800P0000Q5AT03`D7
01452ACooooo000Kooooo`0501TH5P0C4Q003`h<014@3P0@3`d00P0=30X02`0?3P`00P400040000L
6aT03@`:00/;2@0:2PP030`:018B400E5A<04A4?00<03Ph<02d06ATG02TY9`061P@01`P301LH4P0H
6A<051D?00P90`0F5a403@h800l@2P0=3PP0414;014B300=3PT03Ph<00d=2`0<30X03Ph<010@3P0A
4@l03`l=00/;2@0?3`d05QHD018B400<30X04a<C09RHV01FEUH05ADE00L71`0>3Ph04Q8B00410@0>
3Ph05QHF010@400=3@/030d8010A300?40/0414<00/<1`0720@00`0<3@P07P0>3`X04Q<>018C3`0=
3@/030`:018B400D5180410>00`<2P0A4@l0410>00l?3@030`404Q8@014A3`071`D061PF00L71@0;
2`T01PH400l?3@0<30X03@d;00h>300=3@/030`:00h>2`0=3PT02``700d>2@@03Pl:01403@h900`=
200<3@P03@h9010@1P0F50P04Pl7018?2P0J5a80510=00d91P0>2PL04@h9014>1`0A3PD040l400d>
1P0200/<1P0E00h?2@0A4P`04A8<018C3@0L7AL04A8=00D6000E5Q002P/50082000F5Q@02`/:00d=
2`0>3P`04A4?020P7P0;2`T030`:00h>30071`D03Ph<00<03@`:0`0>3@/03@0;2PP03@`:0040000B
4@l05aHD00H50`051@<02@T700@40P0A4@l0410>00D50`0@40h00P0<30X01@0>3P`03`l=00d=2`0B
4Q0030`:00803Ph<01403@d;018B400U9B<030`:00L71@061P@01@D300l?3@0410804Q8@02PX9P09
2@L08B4O0000000<30X03Ph<00d=2`0200/;2@0A00d=2`0>3P`030`:00l?3@0C4a403`l=00X:200@
40h030`:00X:200=3@/0410>00l?3@0>3@/03@`:00`;2@0=30X00P0>3@/04P0=30X02`X800`;2@0=
30X03`h<014?3@0<20L02`X8014A3`0<3P/03a@@07MmN@3DfMD0BD]800d>30081`D03@T800h;2P80
4A0>01`030/900l>300?3P`030/900d<2P0?3P`040l=00d<2P0;2PP02PT600d<200?3P`040l=00l>
300@3Pl03`d>00`:2`0>30l040hA00l=400?3A401P@7018@4@0=2``030X;00l=3P0A3a003@/<0P0>
30d200d;300900l=3P0:20T04Q0A00l=3P0A3a009bDV00`;2`0<2P/03@/<00803P`=0P0=2``05P0<
2Pd040hA01<A500<2Pd02PP;010>4@0A3a801`D800h<3`0<2Pd05aDH01<A500=2`h03P`?00d;3P0<
2Pd03P`?014?4P0:20/040hA01hL7`0=2`h200`:3@0F018@4`0?3A004Q0C00d;3P091`X06ALJ00d;
3P0;2@`05Q@G00/9300[:B`03`d@00D31P0;2@`04Q0C01HD5`0[:B`08b4T00P62@0@3Q4030X=00X8
2`802@L:02L03Ph@01@D5P0=3@l01`L900T92`0:2P`0410B018B50051@L02@T;00X:300G5aT02PP9
00D3100;2@X06ALH01LE5P0?3@h0518C00X82@0;2@X03`d>014?400:20T03@d=00h>3P0=3@d0410@
014A4@0=3@d0000000D51@0C4a<04A4A00`<300A3a003`X900l92@0@2PX00P0A2`/03@0F41004@/;
014;2`0C3@d04@/;00l92@091@<04@h9018?2P0@3@T04Ph;014=2P0>2PP00P0=2@P01`0@30`04@d>
010<3@0?3Ph03`l?00d=3@0>3Ph00P0?3`l200d=3@0F010@400B4Q803`l?00/;2`0;2`X03@d;00h>
300>3Pd03Ph>00l?3`0B4Q<05ADG01LG6@061@X02`X?01HE6@0h>3X03`l?00d=3@0<30`05aLG014A
4@803`l?00d09RHV03dm?@0T92@04A4A014A4`0C4QL03`hC01TH7@0E51T01PH:0000100B4AH05A@I
00804A0E00T06QTM014A4@0G5aL0410@018B4P0?3`l0410@014A4@0C4a<00P0N7Qh01`0@410030`<
00`=4@051PT07AhP018C5@0@4A800P0<3Pd01@0?4@l05ALD01<E4P0@4Ph05aTD00805ADC01X04a<A
018B400B4Q004a<A018B400@40h05aLE01<C4@0D51804a<A01HF5P0F5aH04aLF01@H5`0C6QT04AXI
02L`;`2b^KX0]KZm03Xk?`0D51T05AHJ01TL7P0E6AX051PI01HJ6`805a/L04L06QhO02T];P0N8R<0
5a/L00hB4`0R9RD05a`G02ld;P10ACl07B8L01<H4P0I7QP06b0J020U7`0R9b40724K01/P6P0Q:240
7BHN01`U800J8b00628R01TR9`0L9B`0MX2909bY[`0nC4l09C<e01l];@0J:2P07bP]01dV:`0P:Bh0
7RL/01dX;P0R;S@09C8h028_=`0R<3P06bTb02Hd?@0P<3P07Rlf02<d>`0[>d809SDl024`=`0X=Sd0
<Sm702hk@`0Q;CD06bD^028/=@0R;cH07B`a01l^<`0S<SL08S4f020]<`0O:c007bX^020[;`0R;340
92db02D^<`0Q:S40;SM002L`>@0P:C40:S<j02D^=@03020Y;P807RPZ00@08B/]01`X:00F8R8062@T
0P0R;Rh03@0O:b/07BTY01l[:`0P;2`07BTY01/W9`0N:BX07RHY024V:P0U:Rd07B8U01DJ7@0K8B40
0P0J820201TO7@0;01XP7P0L8R006QhO01dQ8P0K7b005a/L014E5P0_<c@06AdN01XN7`0K7b000`0L
82404P0D61L061`K01`P7`0L82407R8T02<W:P0L7b@08RD[02HY<00T9bh0=3Lo00`?5P0J6al04Q<E
00H72@0A4Q@05aPJ020Q8`805AHH00L06Q/M01TJ700D5AL06AXL01LH700E5QX05aPL008071dQ00@0
5AHJ01@E6@0F5a/05aPL0P0H6Ad02P0F6Qd05a`M01lS900Q9BH0:2`]01DF600D5AL061TK01HF600C
4aD2014A4`03018B500D4Q<0518C00@0518C00@0>3Hg03Tg>00G5AH061HG0P0;2@X0500M6AP0510?
00l;2P0?2`X05A4@01LC4P0<20L03`/:01TE500=2@P030P7018>3@0U8B00Ge]J01@@3`03000040`;
01PD4`0@30/04@d<0P0>2PT01@0A3@`05A0@01<=3`0B30h04@/=00803`T;00T05a4C00@0000;1@L0
O7Ih01PB500400004PX;01061`0?1@H00P0D2P/01@0C2@X04PP90147200F30d05@/<00802P0100H0
3PD602TS8`0<1PH05@`=00`3100F3@h301061`<04@D700D03`D600d3100D2P/03083014720020106
1`804PP900H04`T:01H<3@0?1@H04@L801061`0?1@H20147200701061`0>10D03P@500h41@090000
308301P>3`0600h41@0B01P>3`0F30d0MVa]079XJ@0@1PL06Q0A00h21P0E2@d040@800l31`0A1@T0
3P8601862P0?0`L0300401P<400J3Q8020005?ooool001_ooooo00@05QDC01DD4P0B4@l03`h<0P0>
3@/2018A3`0M01@C4@0;2PP03`h<01@C4@0H61H0410>00d=2`0?3`d0410>014A3`0@40h03Ph<010@
3P0U9B<0@T9001<C4@0P8A`0P85l05mPF`0J6aH030d800l@2`0@4@`020T400h?2P0@4@`030d800d>
2@0>3P`00P0=3@/00`0?3`d04Q8@01<C4@0200h>30803`l=01D03@d;00`<2P0A4A40GemO02d];@0C
4a<04Q8B00`<300:2PX05QHF04U9B@0o?cl03`l?010@3P0?40/04A8=010A300?40/03@h900h?2P0@
4@`00P0?40/01P0C50l06Q/F01PI5@0=3@/02PX800`<2P80410>00d03@d;00l?3@071`D02`/901LG
5@0X:2H04a<A00d=2`0>3P`030`:014A3`0D518020P600D03@d;00@03Ph;00d>2@0;30L03@h90P0>
3`X2010A300900h?2P0<3@P030d800`=200>3P@04A4600h>1P0<2`H04A0;00803@`801d03`h:010?
2`0;2`<02PX1010@1P061`404A8=014B3P0:2`L0414<00h?2P0=3P`01@H1018C3`051@<0414<01TJ
5P1PH5h04Q8@00d=300=3@/02@T700l?3@0:2PP03`l=010@3P0=3@/02`/900d=2`0300d<2P8030/9
00h02`X800X91`0>3@/02`X8010?3@0Q81h04Q4?01<C4@0>3P`05QHD00l?3@071`H05QHD00h>3080
3@d;0P0>3P`0300<30X04A4?00X:200;2`T0410>014A3`0@40h04a<A00P81P071`D0410>00`<2P80
4A4?00D02@T700H6100F5QD02`/9010@3P0200l?3@0=00h>300<30X02`/900`<2P0?3`d04A4?01<C
4@071`D03Ph<00d=2`0>3P`02@T700X:200200`<2P0300d=2`0=30X03Pd;00803`h<0P0=30X04P0>
3@/03@`:00d<2P0=30X03Pd;00l=2`0<20L02`X800l?3@092`P020d901/P700i?SX0418?00`<2P0P
7ad02`P700h;2P8040l=00H03Pd;00l>300?3P`030/900/:200<2`T200d<2P0B00/:200=30T03`h:
00d<2P0<2`T03@`:014?400@3Pl02`T:00d;3P0?3A0040hA014?4`091`X05aDF00`:2`081PL05Q@E
0P0:20T03@0>30d04@l@00h<3@0=2``040h?00P61`0?3@h05Q@E018@4@0=2``02`T:00`:2`0=2``0
0P0>30d200d;300300d;3P0>30l03P`?00803`d@01D040hA00d;3P091`X03`d@01<A500E4aH02PP;
00l=400A3a803`d@00`:3@0=2`h03P`?010>4@0;2@`04@lB00H41`0E4aH02@L:00l=400<2Pd00P0A
3a805P0<2Pd040hA00l=400:20/05A<F01<A500>30l03`d@01<A500B41<04@lB00/9300C4A@02@L:
01<A500:20/04Q0C00`:3@0B41<03P`?00L72@0@418200X:300:010@4P0>3Q003@d?00H6200@4180
2PX<010@4P0<30h03`d>014?40805A<D00d03`d>00h<3@0C4A801`D600/92P0@3Pl06QPI00d;300@
41003`l?00`<300?3`l051@D00804a<C00D051@D01<C4`092@T05ADE00D41006010<2`0601PD4`0A
3@`03PX901<?3P0>2PT040d:0P0A40/01`0>3@T040l;00l>2P0>3@X040l=010>3`0?3@h00P0>30d0
200@3`l0410@00h>3P0?3`l04Q8B014A4@0@41003Ph>0P0=3@d200`<300@00`<2`0=3@/03@d;00l?
3@0@40h0410@01TI6@0=3@d03Ph@00X93P0B4AH040lC01@D5@0<30`051@D018B4P803Ph>00<04Q8B
00/;2`0J6QX00P0B4Q809@0?3`l061PJ010@4P0C4aD06ATK04=3A@0U9BL03@d?01dM7`0>3Q00Bd]=
04A4AP0>3Q003Ph>01<C4`0>3Ph051@D01<C4`0@41004a<C01HF5P0N7Qh07AdM018B4P0=3@d05QLK
010A500=3Q0071dO018D500B51<04A<B00lA3`0B514051HC010B3P0?4@`00P0E5A<201<C4@0F018B
400@40h0410>01@D4P0N7Q`01`L501<C4@0F5Q@061PH01<D500A5A@05ATH01@K6P0>5aH03aPG04iE
EP1?E5L06Q/O01hN8`0F5a/06Q`O01LK70805ATJ02d05QXK01LK700I7Ah03A4B02<W:020Q8D0ATY;
01`P7`0N8al051TE01lT800J7a/06AhJ01@I5@0J7a/05Q/G01`Q7@0O92006b0L01XQ6`0L91d0624L
020Y9P0N:2T08R/`02hg?02HXjL0bMKL055OHP0W=CL082h^01/Y:@0S;34082T^02<]<`0Q;3808Rdc
02Te?00J9bl0:CHn02@b>P0Z>4408Blh01h_=`0T=Cd00P0W>4005@0/?DD0;C]402Pf?`0W=3d0934j
02Td?P0Z=3h09Bli01l/=00Q<3D08c8g028a=P0O;S<07R/a024]<P0S;S8082/_020Z;`0S;3409Rld
02</<P02024Z<`0<02</=00O:2l08BXa01lX;@0Q:Rl08b`a01lY:`0N:2X08bd_01dY:@0Y=CD0;3Ph
0P0O:b/0400R;Rh072PX01hZ:P0Q;Bd07b/[01dY:@0M:2P072@W01hS9`0T:B`09b`_028W:P0L8R80
6R0P01TO7`0I7ad201XP7P0701`R800M8B806AdN01XN7`0R9RL07b<T03i2@`0201dQ8P806alP0P0J
7Ql0;@0K7ah05a/J01lS8P0N8R<05a/M01hR9@0E61d0:Rdc02X]=00G6R406ahV02<V;@0S92P05QLI
01`M7`0O828061TK01HG6@0E5QP05aPJ01PI6`0F5aT04a@F01HG6@0?41@05aPL018C5`0G61`07b0T
01@E6@0H6Ad06Q/O01/L800N7b<08B8V020T9`0C61T05QXK01LK700V:R/05AHH014B500D5AL0820R
01hN800201@D5P0301TI6`0D4Q<0518C0080518C0`0C4A806@0F51D030X;018@4@0>30d05aDF01@@
3`0A3@`04`l>01HB4@0@30/02`L601HB4@1bKVd0/Jf/01hJ6@0P71/03PX900H20P0N6QT030T801@@
3`0@30/03`/:014=300@30/00P0?2`X00`0A3@`04`h>01<=3`0201<=3`0?014;3@0@2P`04@/=01TC
5@0;1@L071HH00h82P0F418040P900l51P0@1PL04`T:01882@0F30d05`d>00804PP900T0308300l5
1P0T6Q/09AdM00/51@0?2@T02P420107200D30d00`0@1PL301451`0?01@:2`0A1`P0L6IW01H<3@09
00405@/<00`20`0@1PL04@L801<92P0F30d04PP90147200@1PL03`D600804@L800L040H700l51P0D
2P/0>S0a01`B4`090@4040L800H03P@50180200002TO802l/[<0/jVZ01X@4@0:0@4030040104200>
0PH03@850104200A1@T02@010106200E2@d050P<03<W:`0?0`LDooooo`006oooool00`0<2`T03`h<
00l>300200h=2`<040l=01P00@0001DD4P0U92800@0000d=2`092@L03Ph<010@3P0?3`d04Q8@00h>
300?3`d02PX800d=2`092@L0:2PV07IgLP3ooo/0iNKQ02//9`0J6aH0414<01lP6`0>3`X2014B3@03
00d>2@0A4Pd03@d;00802`/901P03@d;010@3P0A4@l03`l=014A3`0@40h03@d;00`<2P0>3P`03@d=
00@4100A4A402@T901lO7`0410@05QHF0000000D51@05aLG000000092@L02``700d>2@0<3@P200P9
10802``700L030d800/<1`0;30L03Pl:00l@300=3@/030`:00803@d;00d030`:00h>300E5A<03`l=
01DE4`0P81h0:2PV00l?3@0=3@/02`/900l?3@020P00410>00H03`l=00@03a0<00d>2@0;30L03@h9
0P0>3`X2010A300X00h?2P0<3@P02``700/<1`0C4`/05AD;01@D300A40/04Q4=014@3P0=30X040l;
014@2`0:2P802@T1010@1`0;30L07QhL01lO7P0<30`03Ph<010@3`020P802PX800d=300D51@0DU9@
034a<00F5Q@061PF00`<2P0@40h02`/901<C4@0;2`T0410>00/;2@0:2PP03@d;00H610803@`:0P0<
2`T03`0;2PP02PT7014@3P0?3P`04A0>00P71@0:2@L03`h<014A3`092@L01`L502<S8@0C4a401PH4
00d=2`0200l?3@0E00h>300<30X02`/900l?3@0;2`T02PX8010@3P0C4a403@d;00<30P071`D01@D3
00`<2`0E5A<0410>00X:2@092@L05ADC00L71P0D518010@2008030`:01403@d;00h>300>3P`03Ph<
00T91`0B4Q003Ph<00l?3@0C4a402@T700h>300A4@l051@B00d=2`092@L03Ph<00l>3002010?3@03
00l>300<2`T02`X800@03@`:00h030/9010=300A3@`03`h<014A3`0=3``02@h:00L<200@5A404A<@
00d=2`0O7Q`040`;01LE4`802`X801H03@`:00`;2@0<2`T03@`:00/:200920H02PT700h=2`0B4@l0
4a8?014@300@3`d03@`:00X91`0;2@X03@/<00`:2`0=2`h03P`?00l=400A3a<05Q@G0P0<2P/04@0N
71d03@/<010>3`0>30d040h?014?400=2``02`T:00`:2`0;2@X03@/<01HD5@0?3@h00P0100h<3@0<
2P/03@/<00803P`=0P0=2``06P0>30l030X=00`:3@0?3A004@lB00l=400D4QD040hA00H41`091`X0
3P`?01HD5`0?3A004@lB010>4@0=2`h02`T<00`:3@030@@07Q`O00l=400G5AP00`4400l=400H5QT0
4@lB0P0@3Q40600<2Pd02`T<00H41`0@3Q403P`?01DC5P0>30l0518E00X82`0;2@`040hA00/9300D
4QD04@lB01PF6@0;2@`01P@701@B5@0A3a80CTa?03De=`0@41802PX<00h>40801@D701l02`/=01/K
7@0?3a405QHH014A4`0410H01`D6010>3`0E4a@03@/<00`:2`0D4Q<03`d>00`:2`0@3Pl01`D601PF
5`091`P03@d=00h>3P0;2`/05ADE02LW9`0];Bd0IFEU0000000A4A401PH600/;2`0G5aL04@d<00D0
40`;00H0510?018>3@0U8B006QHE00D1000=2`P2014@300=00d<200@3`/04A0>00d<2P0;2PP02`T:
018@4@0C4A803@/>00`;3@0?3`l03Ph>00l?3`02018B4P0_014A4@0E5AD061PH010@400820P02PX:
014A400@4@`03@h900l?300C4a405ADC01DE50061PH05ADG010@4P0;2`d051@F01@D500A4A402PX:
00d=3@0H61P030`<01<C4`0?3`l08B4Q014A4@0G5aL051@D00L72@061PP04a<E00P82P1=CDl0BDU;
00H6200C4aD04A4C00d=3`092@/05ADG00`<300?3`l04Q8B02LW9`0U9BD00P0A4A4201<C4`0Y010@
400A4A404Q8B01@E6@0N7b800P<501`M7`0?41407R0O01PJ6@0@4Q0030h;010B3`0F61@05QPC014A
3`0@40h04Q8@01DE4`0D51804A4?01/K6@092@L03`l=01TI5`0n?S`0410>01TI6@0B4a<04ADD01HJ
6@0E71/03QLF01PQ800@5aP061dP018C5`0I6Ah04a@H01HH6`0F6Q/00P0E6AX0300I7Ah0720Q00X>
3`0R9RL06QhO05=GF00Z;Rl0720O01DJ5`0N8al082DQ01@I5@806QlK0P0L8Ad07P0P9B407B8N01TN
6P0J81`08RXU01hW900W<2d07RPX01PQ9P0S;340<Se1041>D@0^?3l07B//02Hd=00Y=cL092db024/
<P0T;cD08bhd02@a>@0b?dL0;ca402`j@`0^?4D0?TaE01`]=@0[?4@0;d990352BP80:CY202L09C<l
01l]=P0M:c@082df03E2B`0mBU<0;CY302<a>@0/>d80;Ca302<b>00L:c00934g02Lc>00T;c<09c8f
02Xd=`0W<C<092h`02@^<`0S;CH09Blh02<^=@0R;C<0;STo02@_<`0P:bl06bHZ01`W:@0O:R`082/]
01DP8P0U<380:3<e01PS9@0J9BL082/]01/V:00L9bT00P0O:R`0200M:2X06RDW01XR9@0P9BT09R/^
02DZ;@0R9bX06R0P0P0I7al01`0J81h06b4O01/Q7`0K8Al07R8S024U9P0E6AX00P0K7b000`0@51D0
7B4R01`P8@0201XN7`806alP01H09RX[01/O800K7b006AdN01@H6P0K7b807R4V00lB5`072Pl082<Z
028U;02JWJ80UiRL024R900S92H02P/=01/L7P0I6Q`05AHH01LH6P0E5QP04a@F0P0D5AL01`0B4aL0
71dQ01DF6P0F5a/07b0T018C5`0E5QX00P0D5AT04@0F5a/061TM01LK7P0I7Ql0720Q01XN7`0/<340
7b0R01LH6P0M7R00:b/]02HV:00E5AL0410B01DE5`0E4a@04a4B00<04Q0A01X04a4B01TG600H5QL0
5aDF01<A4P0=2``0518C03Xf=@0N6QT04@d<010<2`0E4A005Q8A01dI600N6QT0?CTh018>3@060P40
3`/:014=300S7ah04Ph=00D1000?2`X061@C014=30803`/:020040`;014=300A30d04P`>01<=3`0D
3Q004P`>014;3@0=1`T05a4C01@>400N61X03@L900/51`0A2P/03PD600l61`0A20T040L801D<3@0C
2P/02`8301482@0D2``03PD60107200A2@X0100000h8200F3@h02@0100l820<03`D60`0@10H03`0:
00406@l@02LM7P0O5AH05P`=00d41@0?1@H04@L800h41@0;0@803P@500l51P0A1`P040H700l51P02
0147200401061`0Q5aP01`0000l71`804PP900<03@@500h41@0>10D0100>10D04P0B20T040L801X@
4@0H3Pl03@D501061`0A1@T03P8601452@0E2@d050P<00l31`0@10P04@D900l31`0=0@D04`L;00d1
1ACooooo000Kooooo`8040l=0P0A40h02P0@3`d03Pd;00/:200F5A<040l=01DD4P0H5aD081lM01<C
4@0@40h201LG5@0J010@3P0C4a400P8000`<2P0A4@l061PF014A3`1@D4h0PH9m09ZKUP2?T8/05aPC
01@E40061`806a`G00h?2P0<3@P03@h900h?2P0A4Pd03Ph<00`<2P0;2`T030`:00h>300?3`d2014A
3`0P010@3P0>3P`03Ph<00l?3@0>3Ph04Q8B01PH600<30`03@d=018B4P1YJFT030`<00h>3P061PH0
6QXJ00`<2@0=3PT051D@01PI500>3`X02P/600`=200>3`X04A8=010A300=3PT030d800`=2@0=3@/0
3Ph<00l?3@0=3@/200`<2P0=018B400<30X0410>014A3`0I6AL02PX800<30@0820H02`/900H61009
2@L03`l=010@3P0300l?3@05010@3P0@4@d03@h900/<1`0=3PT00P0>3`X00`0@4@`03a0;00h?2P03
00`=200?014A2@0C4`T04a<<014@300@3`/04Q4?00`;2@0>3@/040l;00`;1P0;2`<0410700L71@0E
5AD061PH00802PX:01<03Ph>018B4P0V9RH0;Bd]01PH600_;bl05ADE00T91`061P@051@B00`<2P0:
2PP04A4?00h>300<30X02@T700`<2P0@40h02`/900<03@`:0`0<2`T0100?3P`03@`:00d<2P0C4Q02
01DD4P0:01<C4@0>3P`01PH402l_;@0R8R0020P600d=2`0@40h04A4?00l?3@8030`:0P0=3@/04`0;
2`T03`l=018B400<30X03`l=01PH5P0C4a402`/:028R800@40h02`/:00<30@0;2`T0:BTW01@D4P09
2@L030`:00/;2@0<30X00P0@40h0400?3`d03Ph<00X:20092@L05QHD00D50`00000030`:00/;2@0@
40h02PX800H6100>3P`03@`:00h=2`0?3P`2010?3@0300l>300<2`T03@`:00803Pd;00h03@`:00d;
2@0;2PP02`X800h>300?4@h03Q0=00dB3P0G71P071hK018B400<2`T00`0000/91`802@P600<03@`:
00X91`0;2PP00P0>3@/200`;2@08014@3P0F5A<04a8?00h=2@0?3P`03Pd;00`;2@0=2``200h<3@80
3@/>00/03P`?010>4P0B41<01@<4018@4@0]:b`030X;00h<3@0C4A804Q0A00l=3P0200`:2`0900/9
2P0@3Pl030X;00`:2`081PL01@<4018@4@0<2P/03@/<00803P`=0P0=2``0200>30l03@/>00d;3P0>
30l03`d@00h<3`0@3Q405A<F0P0=2`h01P0610L02PP;00h<3`0A3a8040hA00h<3`8030X=00X03@/>
00h<3`071@P04a4D00T72P0A3a804Q0C00h<3`0;2@`030X=0P0?3A000`071@P04Q0C00/9300200l=
400b00h<3`0D4QD04Q0C01<A500:20/030X=00T72P0B41<03`d@00400P0=2`h06QPK08F3QP1ADE<0
6ATK00h>400C4aD03Ph@01DE5`0@4180H61R0410@P1CDeD04A4C00d=3`0>30d01P@500d;300?3@h0
2`T:00d;300<2P/02`T:010>3`040P<071XK00`:2`0?3`l03Ph>00P8200=3@d06a/K020P800?3`l0
0@4101@D500?3`l030`<00H61P0@3P`2014=308040`;00L04`l>00/71P0810<07ATH01@@3`0810<0
3Pd:008040l;00d03@`8014@300B4@l05A@B00l>30091`P07adN02h/;@0O7B003`h?00h>3P0=3@d0
3`l?00804Q8B00X03Ph>01HF5P0Q8B406a/K00`<300;2`/04A4?010A300=3PT0414=0P0F5Q@06@0@
40l04A4A014A4`0>3Q0030`>00H6200>3Ph01`L700/;2`092@T05QHF00d=3@0>3Ph02`/;014A4@0<
30`04A4A01PH600G5aT0=3@f020P8P0C4aD05ADG01LG6@0N7R000`0=3@l07@0B4Q@04a<E010@400C
4a<05QHF02`/;00Z:RX051@D00/;2`0A4A405ADE018B4P0C4a<0410@010A5@0A4QD0414C05EFF00l
?Sh03a4@01DG5P0C5A<03a4>014C400C5A403@l:018B400A4@l051@B00806ATG01D051@B00l?3@0A
4@l04A4?018B400`<2h051@B01PH600E5QD04QHE01HJ6@0E71/041TH00`E500=51D06b0S01HG6`0G
5a`07AhR01HJ700I7Ah00P0H71d08P0M8B808BDV02T];P0T:2T05a/L01XN7`0:3Pl08BDV01XN700J
7a/05a`H01HK5`0Q9R807R<O020U8@0L8Ad06QlK01DJ5P0J7a/08BLS01hW8`0O:2D09Bh]01lY:P0K
9BL08BX_024/<00W=CP0;3Xk01`Z:`0]>c/0:CLh02La=@0S;S@202Ha=`0]02Ld?00a?TH0:SLo01l]
=P0U<c`0;Sa501`]=@0Z?4@0;d990352BP0[?4@09SLo028`>@0O;CH08Blh02Hc?00[>440;3U202Xg
@00V=3d0:SU002lnA@0Y>3l07Rdb024^=00R;S<08B``02Lb=P0/=SP0:S@f02D_<@0P:Rl092hg02Tc
?00F8BP08Rdc02/f?00U<3@07bX^01TT:00M:2X08B`^01lZ;00W<S@09C0b008082/]01008Rd_01/V
:00N:B/07BPZ01hY:`0O:R`07RT[01/V:00H82<0:c0d038g>P0K82<04aPK01`R8P0H7Qh06AlO100K
8Al0100A5AH08bLX01dQ8P0M8B8202@X:@0L01TM7P0H71d061`M01XN7`0N8R<08BDV02hb<`0T:2T0
6QhO01PL7@0I7Al06AdP01LJ7`0S9R/06ahS02@W;P0Z;C@0f=_P0<k?d`0b<cD0:BX/00l@4P0O8280
3@h@01DF600H6A/051DG018C5@805QLI01X051DI01/L800F5a/05QLK01TJ7P0A4QH05QLK01DF6P0C
51P051DI01HG6`0E6A`051TI01hR8`0L8240;30a01/L7P0@4A<06AXL028R900P82805ADG018B500E
5AL05Q@E01<A4P804@l@0P0B4140200;2@X03`d>018@4@0B41404a4B01HD5@0/:2L06ADD0P0@30/0
4@0D40l05Q8A00`9200D40l08alN014=300;1`H061@C00X61@050@003`/:01LC4P0B3Pd03`/:014=
300>2PT03`/:008040`;00@040/;00l92`0@2P`040X<0P0?2@/0600=1`T07aTK00h82P0400006Q@F
018<3P0=1@L03`H70107200B2@X040L801<:2`0E30d03PD600l61`0C2P/03PD600X10P0=1@H04`d=
00T4100K4Q<08aXK00d41@<040H70`0A1@L03`0=0`@03P@500P0000?1@H05@/<00l71`0D2P/05P`=
01061`0:00403@<401061`0A1`P040H700l51P020147200401061`0D2P/0308301T?40801`0000<0
7A<D00h41@0>10D0100>10D04P0A1`P040H700h41@0@1PL04PP900/10P0B1PX03@4500l31`0A1@T0
3P8600`0100B1PX040@800d11@0A1@T02P0201<72aCooooo000Kooooo`05014@3P0>3@/040l=01@C
4@0C4Q000P0=30X02`0@3`d02PT700d<2P0E5180DU5?01TI5`0C4a406ATG01PH5P0?3`d05QHD0080
410>018020P600h>300=3@/04Q8@01DE4`0R8R009BDS00h>300@40h04Q8@00h>300B4Q003`l=01@D
4P0K6aT061PF014A3`0?3`d200d=2`0300h>300?3`d0410>00803@d;0P0?3`d04P0>3P`0410>00l?
3@0>3P`03`l=010@3P0B4Q00=SHd01HF50092@L04a<A00X:2@0?3``03a0;01HG4P0H6A@03@h900`=
2080414<00D04Q<>014B3@0>3`X03Pl:00l@300200l?3@0300h>300=3@/03@d;0080410>01@02`/9
00l?3@061P@05QHD010@3P0D5180>SXh01PH5P0F5Q@02PX8014A3`0@40h03Ph<00d=2`0>3P`0410>
010@3@0=3PT02``700d>2@@03Pl:01403@h900`=200=3PT03Pl:00`=1@0>3`H0414:00h?2P0<3@P0
410>00X:200;2`T03@h:00l@2P0@4@X03a0800l?3P0200X:30803`lA00l02PX<00T92`0;2`d04Q8D
00h>400<30h09BDV05QHE`0I6AL02@T800`<2P0@40h02`/9010@3P0<30X00P0?3`d0100;2`T03`l=
00d<2P0=30X200h=2`803`h<00d04Q4?03Pg=@0B4@l04a8@010?3P081`D04A4?00h>300;2`T0410>
00X:200=3@/03Ph<008051@B00D04A4?00d=2`0=3@/02`/9014A3`0200d=2`0?010@3P0<30X02PX8
00h>30092@L04Q8@08B4PP1nOW`04A4?01@D4P0H61H0=3@b00/;2@0<30X0410>00803@d;0140410>
00h>300<30X03Ph<00P81P071`D03@d;01@D4P1MGE/07QhL00L71@092@L03@d;00T91`0<30X04Q4?
010?3@0400h=2`0300/:200=30X03`h<00803`h<00d03Pd;00/;2@092@L02`/900l@3@0>3`d03@h<
00l@3@071`D03@d;00P81P0A4@l040l=00802PT700L03`h<00`;2@0<2`T03`h<00d<2P0>3@/03`h<
00803Pd;00T03Pd:00h=2@0=30X030/900/:200>30d04@l@010>3`0>30l00P0=2`h03@0?3A402`T<
010>3`0A3a005Q@E018@4@0<2P/05aDF010>3`0:20T03@/<010>3`0>30d00P0?3@h00`0>30d030X;
01@B4`0200`:2`0300d;300>30d03P`=00803@/<01003@/>00l=400?3A003@/>00/9300=2`h030X=
01HD5`0<2Pd040hA014?4P0`;S403@/>010>4@0A3a803`d@0`0=2`h03P0H5QT0GeeP00T72P0A3a80
2PP;00d;3P0?3A003P`?00d;3P0@3Q404@lB01@B5@0<2Pd040hA0P0=2`h0:@0>30l030X=00/9300A
3a802@L:00h<3`0?3A002`T<00l=400C4A@03`d@00`:3@0D4QD06a/M00d=3`0:2P`02`/=00X:300>
3Q003`lA01lO8@0A4A<071`N00h>400=3@l04@l@00/92P0?3@h030X;014?400N71d05Q@E00/92P0D
4Q<04Q0A03Le=P0T8R<030`<014A4@0<30`02@T900803@d=00@03`l?01<C4`0;2`/02PX:0P0<30`2
010?3@803`h<00P03Pd;014@3P0;2PP03`h<00d<2P0<2`T04a8@00d=2P803Pl:00d030d9018B400D
5180410?00/;2`0:2P`04A4C01@D5P0?3a4030`=00d=3@0<30`03Ph>00804A4A01<03Ph>014A4@0E
5AD04A4A00d=3@0?3`l04A4>00d>2@0>3`X05QLB01TJ5@0D51803Ph<01DE4`092@T05QHH00X:300c
<cD0C4a<00804A4A0`0?3`l0300B4Q804a<C00h>3P0I6AT03@d=01<C4`0820P06QXJ00/;2`0A4A40
5QHF01XJ6P803Ph>0280410@01HF5P0>3Ph02`/;01<C4`0G5aL0410@01LG5`0E5AD04A4A010@400F
5QH051@D00l?3`0C4a<0410@010A5@0@4A@0:b`^08b=S`1^L7004Q@C01HH5`0G6AL03a4>00h@3@0D
5Q80418=01@D4P0B4Q0051@B01PH5P0G5aD0410>0P0D51801P0J6QP05QHD014A3`0E5A<061PH01PI
6@805QXI01T05A`K01@M700D7A`072<T018G6P0H6Ad0:2P]01`M8@0G71h06R0P01PN7P0E6a/06AlO
01hT900T:RX05A/K024W9`0F71`082HV01PN7P0G7A/07B<Q01LM6`0K8Al08bTW00807B<Q01`06R0N
01dS8@0L8R00728P020V900M9BD07bLX01dU9`0O:BX092h`02H`<P0P:bd07bd^01LU9P0K:BT06RPX
028`<@0U<3D08B`b02<_=P0S<3P09S<k02/i@@0L:S<0=TA=04IFH00Z>dD0A5EO0`0V>4801`0Y>dD0
8cDo02@e?`0Z>T@0938m024_>P0V<cl00P0^>TH02P0[>4809cDn02Le?P0Y=cl09cHm02<`=P0S;c@0
9C0d02@_<@0S;Rl2028/;@0K028]<@0F82T0<Sa504UCF`0S;S@07RT_01dX;00P:bl092lc02<^<00Q
;2h07bX/02Pc=@0V<C<09c8d024/;P0K9RP09S4c02@_<@0Q;2h07bX/024/;P0R;Bl082X/01dU:00W
;30092T/00806AhQ00/06b4Q01PN7P0I7al06b4O01`R800K8Al06R0O01LL7P0M8RD0724T020U:002
01TN8@0E01dR9@0K82<061dP01PM800J7b80724T01/O8P0P92L05a/N01/O8P0Y;C008BDX01TM800F
6Ad04QDJ01LJ7`0S9R/0?D140493AP0H6A/06Q/M00805AHH00D06AXL01@E5`0I6Q`051DG01<D5P02
01TJ700J01LH700H6Ad06a`P01XK7`0F5a/05aPL01PI7@0G61`05AHJ01LH700J6al06AdP01@I6@0F
6Q/02Ph?01PL7@0F5aT051DG01HG6@0E5AL05QHH01LG6@0F5QP05ADF01HE500C4Q02010?3@03014@
3P0B4@l051<A00805aHD01404Q4?01DD4P0=30X04Ph=01HB4@0G4a805Q8A018>3@0@30/05A4@00l;
2P0F4Q40510?018>3@0A3@`0510?014=300201<?3P0301HB4@0D40l04@d<00803PX900<04@d<010<
2`0@2``00P0@2P`06`0?2@/040X<014;3@0A2`d05Q0B01<=3`0J51H05@lA00@0000F3a004PT:0107
200D2``04PT:0107200B2@X03PD600d41@0@1`P03PD60107200B2`/020<300h8200B2@X0;2<T01L>
3`03014720<04PH800l060h?00`3100C2@X03`H601L=3P0?1@H04@L801D;300C2@X03@<400h41@0@
1PL04@L801061`0?1@H00P0A1`P01`0@1PL03@<400l51P0<0`@03P@501061`0=0`@01P0>10D04P0E
2``03`D600h51@0?1@H03P@500l51P0=0@D040@801452@0<0@@040D802HJ7P0A1@T03`@701452@0E
2@d03`@701462ACooooo000Kooooo`0U014@3P0?3P`03@`:00d<2P0?3P`04Q4?01HE4`0;2PP04A0>
01<B400>3@/05A@B01PH5P0<30/0820N00/;2@0A4@l02@T701@D4P0>3P`051@B00h>30030`40410>
00h>300@40h04Q8@00l?3@0=3@/03`l=018B40000000?clm024Q7`2j^[P0>SXh00l?3@0200h>3009
00X:200H61H0410>00T9200D51804Q8@01LG5@061P@04Q8@00803@d;00@03Ph<00l?3@0?3`d03`l=
0P0>3P`01@0=3@/02@T701/K6@0Q8Qh0414<00803a0;00`030d800d>2@0A4Pd02``700X;1P0?40/0
3@h900`=200>3P/0410>00l?3@0;2`T2014A3`04010@3P0?3`d03@d;00h>3080410>01@03@d;01dM
6`0n?S`071`J018B40051@<04Q8@0000000e=C<071`J018B400A4@l03a0<00h?2P0<3@P0414<014B
3@0;30L030d800d>2@803a0;01<03@h900/<1P0@4@T04149014B300<3@P01`L500`<300E5AD04Q8@
00X:1`082@<04Q<=00/<1P0=3@d04A4C00`<3P0@418000020080410B01l020P:00T92`0?3a4030`>
00h>3`0C4a<030`:014A3`071`D02`/900X:200>3P`03@d;00l?3@0A4@l03Ph<00H6100920H04Q4?
00@30@0;2PP04a8@018A3`0N7A/0<2l]00T81P0P7ad030/9018A3`0=3@/03`l=0080410>00L03Ph<
00`<2P0>3P`04Q8@01LG5@0Y:BL05QHD00<03Ph<00/04Q8@00h>300<30X061PF00P81P092@L04Q8@
02TY9`1ZJVP06QXH00h>300300`<2P0P00/;2@0:2PP01`L500h>300<30X05aLE00P81P0A4@l02PX8
00d=2`0@40h03Ph<01<C4@0=3@/030`:00l?3@0@40h02@T700P81P0>3P`02`X800h=2`0B4@l03`h<
00`;2@0D4a403@`:00l>300=30X040l=014@3P0?3P`201HF500?018B400000004a<A00l>300F5Q@0
410>00/;2@0?3`d05aLE00P81P0?3P`02@P600l>30071P@03`h<00802`X800H03Pd;018A3`0:2@L0
30/900l>2`0>3@T2010?3@0>00d<2P0=2``04@l@00T720071@P030X=01HD5`081`X020H901DC5019
AdP08b4R01dK700920P200/92P0:00d;300>30d03P`=00h<3@0=2``03`d>010>3`0>30d030X;00d;
30803`d>00@03P`=00d;300>30d03`d>100=2`h00`0>30l040hA00l=4002018@4`0500`:3@0=2`h0
6ALJ00h<3`0<2Pd00P091`X01@0<2Pd03P`?00h<3`0=2`h04@lB00805A<F00<03`d@00d;3P091`X0
0P0A3a803P0<2Pd05Q@G00h<3`0C4A@02@L:00P62@0B41<03P`?00X82`0<2Pd03@/>00l=400A3a80
4Q0C0P0?3A0400`:3@0E00d=3`0>3Q003Ph@00h>400<30h02`/=02DU9`0@41804Q8D01<C5@0820X0
10@6010>3`0;2@X040h?00`:2`0=2``06aTJ01@B4`0=2``03`d>008030X;00/04Q0A01@D500410@0
30`<00X:2P0M7Ad030`<00l?3`0;2`/02PX:00`<300200h>3P803`h<0P0<2`T01@0A40h03Pd;018A
3`0A40h040l=00803`h<00d03Pd;00l?3@0A4@l03`l=00d=2`0@41004a<D00h>400A4A<04A4D00P7
300000@0410A00803Ph>01X03@d=00`<300<30`03Ph>01<C4`0410@04Q8B00@4100D51@03@h:00h?
2@0<3@L03@h800l@2`0@4@`03Ph;01DE4`0=3@/05aLG00l?3`1LG5`0RHV902@T900D51@01`L700l?
3`8051@D01804a<C014A4@0@41004A4A01@D500>3Ph051@D00l?3`0;2`/051@D010@400G5aL0FUYJ
01LG5`0:2PX06QXJ00l?3`0>3Ph2018B4P0c00P8200B4Q805QHF018B4P0>3Ph04A4A00/;2`0E5AD0
4A4A014B5P0D5AP05aPJ01PI6`0G6AT05QPG00X<2`0L7Q`0828O010B3`0F61@03a4<01@D4P0C4a40
4Q8@01@D4P0F5Q@05ADC00l?3@0B4Q005QHD01LG5@0F5Q@051@B01DE5@0T9BD03a<B020T8`0Y<Bl0
6B8Q01hW9P0E71d051TL01TJ7P0K6b007QlS01/R8`0L9B@04Q/J010I600J8b806b@S00806B8Q0`0F
7ah05P0D7A`04a`I01LP7@0F7a`082TV01PQ7P0S;2T06R<P020Y9P0A6QL06R<P01@M6P0V;bh0:S8e
038j?@0P:2/0628S020Z:`0M9bP07BTY01XX:00X=SH201h/;00a020^;`0T<CP08Rlg01/X<00R;cL0
:cU202Tg@00V=3d0EfQb09^//`0eAe40:C]703E7DP0Y?DH08CDn01lb>`0V>480;3i802TkA@0[?4H0
9cE002@b?@0S<C`0=49=04UGHP0jB5<0>4IA02Le?P0S<ST0:CHl02Lc>00O:Rh07BPZ024/;00W<C00
:38a02Lb=@0gA4`0@DiF0:6^]@0S<3H082dc024_<P0O;C008S0c02<a<P0P;Rl09S@e024/<00202<^
<P0L020[;`0Q;3009S4e02Xe>@0R;C409S4e02Td>00O:Rh082X^02<[;P0Q9RX0724T01dR9@0O92L0
7bDU028X:00E6a/05Q`J01hT8P0I7ad08bTX01lW:@0L92L0D5QK04aDE`1oQhX0<c/n01hV:@806R8U
00l04QXM01hV:@0=4QH0=cXo07]nP`0W:Rl04aHK018F6P0G6ah07B4T01/O8P0G6ah061`O01XN8@0F
6Qd01P0H6A/0?P0F5aT061TK01<D5P0B4aD05aPJ01DF600M7R805QLK01PI7@0M7R806AXN018C5`0H
6Ad05QLK01@E6@0E5QX05aPL01HJ7@0E6Q/041@E014E5P0C5aP06Q/M024R900K71h05aLI01PH6P0E
5AL04a<E01LG5`0J61P02PT700l>300E51803@`:01LF500N7A/071/I01<B400F5A<05aHD00l>300D
40l05a<B01/G5P0D40l04@d<01LC4P0B3Pd040`;00l;2P0@30/03`/:010<2`0H51<02PH501TE500G
4a801P8101@@3`0@30/03PX90`0=2@P00`0@2`/04P`>018<3P03018<3P0701@>400A2`d04P`>01LA
4`0@2P`03@L9018<3@0200h8200901<=3@0=1`L03PP8010:2P0;1@D05@l?01H@400;1@D02P@40080
3PP800@03@L700H0000@1`P050/<0`0@1PL00`0A1@L04PH801@82P0600l51P0301D;300U6a`091XK
00803P@500d04`T:00l51P0?1@H040H70147200B20T05@/<01882@0@1PL03P@500l51P0@1PL03`D6
00@03@<400<03`D601061`0>10D00P0<0P<0100=0`@03`D601882@0:008300h21P0801L;3`0S5a/0
3`<70104200A1@T040@800h21P0<00@Dooooo`006oooool0200F5A<03@`:00T81P0C4Q00<C0^04U8
AP0>3@/02`X80P0D4a409P0C4Q0081lM0000000b<S00000000`<2P0B4Q00410>00/;2@0=3@/04A4?
018B400>3P`02PX8010@3P0A4@l0410>00h>300@40h051@B00X:200;2`T030`:00D50`0N7Q`08b<Q
00h>30092@L02PX801TI5`0>3P`04a<A00h>300D51800`<100`<2`0@40h01`L50P0=3@/02P0>3P`0
3`l=00l?3@0?3`d0410>00P81P092@L06QXH04I6A00k>cP2018C3P04014B3@0>3`X03a0;018C3P80
3a0;00@04a@?010A300A4Pd04A8>0P0?3`d01`0<30X0410>014A3`0?3`d03@d;00`<2P0=3@/00P0?
3`d04P0<30X04A4?01hN700>3P`02PX800P81P0C4a403`l=02@T8P0Q8Al05QHD00`<2P0C510030d8
00L80`082@@030d8010A30803@h902<03Pl:00l@2`0?40/0414<00d>200C50`04A8=00d=2`0A4@l0
3Ph>00D51@0820P04A4?01`M600>3`T051D?0000000>3Q0030`>01HF60092@/03Ph@00/;3@0<30h0
4A4C01<C5@0?3a403@d>00H6100A4@l02`/:00D50`0D51<061PF00h>300200`<2P0A00h>300=3@/0
2PX801TH5P0=30X03`h<00h=2`0;2PP03Pd;00@30@0H5aD010<101PG5@0>3@/04A0>00`<2P0>3P`0
0P0?3`d0200>3P`03@d;00`<2P0?3`d03Ph<01@D4P0<30X01PH40P0?3`d02`0A4@l03Ph<00l?3@0K
6aT03`l=00`<2P0;2`T03Ph<03<c<@0000003Ph<00<030`:00h02`/900X:200@40h03`l=00D50`0K
6aT03@d;00P81P0;2`T01`L5010@3P071`D030`:018B408030`:02803Ph<00/;2@0@40h061PF01<B
400:2@L02`X8018A3`0<2`T040l=00h=2`0?3P`02`X800h=2`0=30X01`P500`>2`0410801`L601`L
6P0:2@L03Pd;00<2000@3`d030`:00P:1`0;3@X020T601TH5P0<2`T02@P6010?3@0N7A/04a8@0P0?
3P`01@0A40h02`X800/:200>3@X03Pd900803`h<00h03@`:00h<3@0?3@h06ALH01@B5@0E4aH00@02
01DC5`0A3a8040h?01PF5`010000108301DC508030X;0`0>30d200d;300600l=3P0@3Pl03P`=00`:
2`0=2``03P`=0`0=2``01@0>30d03`d>00X82`0:20/02`T<00<030X=00P01`D8018@4`0K6A`040hA
00P62@0:20/03P`?00d;3P802`T<00<03@/>00h<3`0=2`h00P0>30l03P0?3A004Q0C01DC5P0>30l0
3@/>00l=400=2`h02`T<010>4@0L6Qd09B<V01LE600>30l03`d@0P0;2@`01`0<2Pd03@/>00l=400@
3Q404@lB00l=400>30l00P0<2Pd200d;3P0N00d=3`0>3Q003Ph@00h>400<30h02`/=018B500:2P`0
20P:00L72@061PP07alQ00P61`0=2``05Q@E00`:2`0>30d00P01010>3`0>30d04@l@00l=3P0:20T0
3P`=00@4100V9RH010@4010@40020P8000000`0=3@d02P0<30`02`/;00/;2`0:2@L03`h<00X91`0=
30X040l=00h=2`0@3`d400l>300>014A3`0C4a404Q8@00l?3@0=3@/03`l?014A4P051@L03`lA00h=
4@0>3A804A0E00`<3P0>3Ph400d=3@0G00P8200C4a<04Q8B00h>3P0?3`l05ADE00`=2@0<3@L02P/5
00/<1`0=3PT030d800`=2@0@40h04Q8@01HF5P092@T05ADE02h^;P0000003Ph>00/;2`0G5aL00`0A
4A43010@400D014A4@0E5AD07AdM01DE5@0;2`/04A4A01@D500;2`/07QhN00P8200A4A404a<C00l?
3`0G5aL05ADE00h>3P092@T0410@01@D500O7al2010@400500l?3`0D51@051@D00h?4`0@4A@00P0B
4aD02@0C5AD04aDD01@F5@041P@01`T601DG500@4Ph04Q@?01@D4P0201<C4@0301@D4P0E5A<05ADC
008051@B02405ADC01HF500H61H06ATG01@D500N7ah05a/J024U901lPh80[[Nf02Xc<P0K8R<05a`O
01hO8`0L724061TM01DL7@043@`03aPG01LP7`0A6QT04a`K01PQ800G81l06B8Q01XS8P0K92<072DT
01hW900L9B8051dJ01XS800E7Q/00P0O:2D02@0H8Ah0;CHc020Y9P27T8d0<c`k028Z;@0Q:B`07bLZ
01lY:P02020Z:`08028^;P0N;2`05bDU02hl?00K:BT0;3Xk01dZ<@0V<c/202Pe?@0@02@b>`0J:340
7c0h03Y;E@0nD5X05BLa02LiA@0R=Cl0:3a502TmAP0[?TP0:ce702XlAP0X>D<09SM101h/=`80:CM2
01X0938m02lmB00`?TT0<d5<02/i@`0Z>D00;3U102Te>P0T;c408B`^028];00S;B`08R`[02Pe>00O
;3@06RL_04UFG@0Y=S`0;ca2024_<P0O;C008Blb020^;`0M:b`08Bl`02D`=0809S4e0P0T;c<0100Y
=3P08B``01XU:@0H8bL201HQ9@0U02hh?00]=CP09R/_01dR9@0P9BP092T/020V9P0V;2`07R@T01hT
8P0P9R@06b4O020V9@0M9BL05QhQ03Lo@P0b>Sd0CEEH02D]<00O9bX09Bd`01TQ900N9RT04QXM01dU
:0041``0<C@i01XM8P0A51T0720T01HJ7@0M8B@06QhQ01LK7P0H71l06AdP01LK7P0201HG6@805aPJ
00@061TK01TJ700L7Al07QlQ0P0J6ad0200N7b4071dO01LH700M7R8071dQ01HG6`0A4QH05AHJ0P0F
5a/201DF6P0A01HG6`0D61/04QLG00lC500C5aP05QXK01hO8@0T9BL06a`N01LG6@0H61X05ADG01@D
5P0G5aL04A0>01XI5`0F5A<00P0G5Q@04@0J6AL04a8@01PG5@0A40h051<A014@3P0I61H05Q8A01@@
3`0H51<05A4@014=300D40l04Ph=010<2`0A3@`0510?00804`l>00D07ATH01DA400E4A00510?00X6
1@02014=3005010<2`0?2`X03`/:010<2`0A30d01`0B30h05`0C3@l04@/=00/51`0=1`T040X;00l9
2@0@2PX04@/;00d71`0?2@T04@/;04]5A@0F41002@@401PB4P0E3`l02`D500L10@0?2@T04@P901L>
3`0=1PH04@L8008040H700<04@D70186200D20X01P0@1PL01@0?1@H06Q0A01P>3`0=0`@040H700<0
3`D600T03P@500d3100=0`@03P@500l51P0=0`@0308300d3100?1@H00P0>10D200d3100500h41@0?
1@H040H70147200?1@H00P0F30d02P0?1@H040H700l31`0C1`/040@800d11@0A1@T06@dA00h21P0@
10P301452@0300l31ooooooooooo01;ooooo000Kooooo`0900/:200=30X03Pd;00l>300@3`d04A0>
00/:200<2`T04a8@008040l=00L07ahL01`L6P1SHf403Ph<01<C4@0<30X0410>00803Ph<00/02@T7
014A3`0?3`d02PX8014A4@0D51@03`l?00/;2`0@41005ADE010@400200d=3@0?01DE5@0820P03Ph>
00h>300820H06QXH00`<2P0C4a403@d;010@3P092@P0BTY8024Q7`010@0061PF00803@h901T03Pl:
00l@2`0?40/03a0;01<D3`0@4@`03a0;00`=200<3@T03Pl;00h?2P0@4@`030d800/<1`0<3@P03Pl:
010A300B4`h0414<00`=200?40/04A4>00h>300?3`d03Ph<0080410>00@03Ph<00d=2`0;2`T03@d;
0`0@40h04@0B4Q002@T701XJ600=3@/04a<A00d=2`0D518010@3014A3`0820H05QHD00h?2`0A4Pd0
4Q<>00h?2P0=3PT04Q<>008030d803L02``700`=200<3@P030d800X=1P0D5a00418=00P:1`0@4Q00
3Pl@010A4`082@X03Pl=00lA30072P@030h901TI5`0];B`03@d<00X:2P0<30/03@d=00L71`0=3@`0
3Ph>00/;2`0=3@`03Ph>018B40092@L030`:014A3`0U9B<05ADC00h>300<30X02`/900`<2P0?3`d0
3Ph<010?3@0=30X03`h<00T81P0R8Al02`X800P71@0B4@l03Pd;010?3@0>3@/01@@200X:200;2`T0
3@d;00<03Ph<00L03`l=014A3`0=3@/01PH401LG5@0>3P`030`:00803@d;00@02`/900h>300F5Q@0
30`:0P0=3@/00`0:2PP02@T700`<2`0300d=2`0J00`<2P0;2`T030`:00d=2`0>3P`010@201/K6@0=
3@/01`L500/;2P0<30X03Ph<00d=2`0B4Q002`/900`<2P0:2PP02`/900d=2`0F5Q@0820N010?3@05
10<02PT701HE4`0<2`T200h=2`0B00l>300=30X040l=010?3@0=3P`020d900X<2@0?40d061LE00X6
1P0D40l07A/I00D40P0D5180Q8J303e0?@0@4@h06APF0P0>3@/02P0K6QP08b8P01@C4@0C4Q003Pd;
00l>300=30X030/900d<2@0=30P200h=2`0?00d<2P0@3Pl03`d>010>3`0=2`h06QPK07EcMP0T8RH0
5aDH00X82@0Q7b00928S010>3`0A3a003P`=00803`d>00T03P`=00d;300=2``03@/<00l=3P0@3Pl0
3P`=00`:2`0=2``0100<2P/01`0=2``03`d>00/9300<2Pd03`d@010>4@0?3A000P0=2`h01P0G5AP0
81hQ01DC5P0<2Pd03`d@00h<3`@03`d@01<03P`?00/9300>30l03`d@010>4@0I5aX08b4T00`:3@0A
3a802`T<00X82`0?3A003@/>00`:3@0I5aX0518E00h<3`0A3a804Q0C00@03P`?0P0?3A001`0>30l0
3@/>00d;3P0=2`h03`d@010>4@0=3@l00`0>3Q009P0<30h02`/=00l?4@0?3a4020P:00h>400:2P`0
3`lA014?400N71d05Q@E00P61`0L6Q/040h?00`:2`0?3@h04Q0A010>3`0:20T02@L8014A4@0:2PX0
0`<301@D500:2PX04Q8B00`<300A4A40410@00/;2`0<30`03`l?00/;2@0C4a401`L500l?3@0@40h0
3`l=0`0=3@/03`0>3P`03`l=01@E4P0D5Q<03a4@00d?3P0>40l03@h@00h?4@061`T030dA00h?4`0=
3Q8061TM00X:300200d=3@0300h>3P0?3`l03`l?0080410@00d030`<00P8200B4Q800@4101<C3`0=
3PH03@h8010A2`0B4`d04Q<>00h?2P0C50l030`:00803@d;00T04a<C00l?3`0D51@04a<C00H61P0I
6AT092@T00l?3`0@41000`0A4A409@0@41005ADC01/K6@0E5A<02`/9010@3P0G5aD061PF00`<2P0A
4@l03`l=01@D4P0A4@l05ADE014A4@0E5AD08b<S01`L700A4A407alO014A4@0C4a<04Q8B01DE5@0D
51@04Q<G018C5P0A4Q@04Q<E01@F5P0F61L051HE01<E4`0F61D03Q0=018D400F61<00`0D51801@0C
4a405ADC01HF500E5A<051@B00804a<A06L05QHD01PH5P0M7Ad061TI01TM700G6aX0LGQg09fVY@0Y
<S406B0Q01LL7`0O82@07QhS01PI7@0G7Ql06b@S01<L6`0F7ah06B8Q014J6@0K92<05QlN01/T8`0G
81l051dL01/T8`0@6AP092d/01lX9`0M9RD05QlN01TR8@0N9bH05QlN02D^;@0M9RD0Hfa[02@/;P0N
9B/07B@[02@/<00T;Rl082XY028/:P0O:bP04b8O020_;01gQHD0;3Xj01PV9`0W=3/0934i02Hc?00Z
>4409C<l02Xj@`0[?4H0<T=@07:4T010DUh07Blk02Dh@`0Y?DP0:cm:02e1C00[?dX0:ce902PjAP0U
=d<08c=002XjA`0U=D808c4n02XhA@0Y=d@0:3I202Hd?`0X=cl0:CHn028^<`0N:B/07b//02@_;P0X
<S00:3<_02@a<P0a@4L0H6mf03]:D00`?d@07B`a02@c=P0S<SD09SDh02De=@0O;bl08C4a02<^<P0T
;c<08bhb024/<00R;C409C0d00<08bhb0P0K9RX05P0g@DD0;3@g02DZ;P0L8B@08BHY02@Y;00N92@0
728R020V9P0Q9bD07bDS020V900Q9bH06b<U01LO8P0J8RD06B4T01HN8@0M9BP06R8U03a4A`0841<2
01dU:00:01HN8@0L82L06QdT020S:P0H6b007R4V00lB5`0M8B@05a/M01DI6P<05QXK0P0I6Q`01P0H
6A/05aPJ01LH6P0F5aT061TK01/L7P805aPJ00<06a`N01TJ700J6al00P0I6Qh0100L7B406a`P01@E
6@0E5QX301LH700401HG6`0C5aX05Q/K01@H6@805a/L00h06AXL01dN800I6Q`05ADG01HF600D51H0
4a<E01LG5`0];2T05aHB01XI5@0C4Ph06aXF010?2`805A@@00d071/G08n>RP1UI6006QTE01HB4@0D
40l05A4@01<?3P0@30/04Ph=014=300?2`X040`;00804`l>00L040`;00l;2P0B3Pd04@d<01<?3P0E
4A004Ph=00<04@d<00<04Ph=01@@3`0C3Pl01@0B30h02@0@2P`04P`>01@>400>20X03`T;018<3P0A
2``04`d=01D?3`0200l92@08014;2`0G4A40I5iN04I0@00H4Q801000018<300L5QH2014;2`0900d5
1P090@405@`=01882@0A1`P040H701451`0B1PP050P:00H04@L800H03@<401061`0>10D040H701H<
3@0@1PL200h41@0300d3100>10D03`D6008040H70P0>10D00`0A1`P04PP901882@0200l51P803P@5
00/03`D601061`0C2@X040H7020F5`0O5AH03P@500l51P0?0`L04PH:01452@0200h21P0401452@0=
0@D03P8600l31`8040@800<03`<7ooooooooool04_ooool001_ooooo00P04A0>010?3@0@3`d04A0>
01DD4P0G5Q@04Q4?00d<2P<03Pd;02D040l=01dM6`0=3@/04A4?010@3P0?3`d01@D301dM6`030`40
71`J04e=B`0F5Q@01PH4010@400F5QH0410@00/;2`0=3@d030`<01<C4`010@403`l?01@D500A4A40
7QhN01<C4@0000002PX801TI5`0?3`d04a<A010@3P000000:2PV00`<2P0;2`T05QHD00803@h900@0
3Pl:00l@2`0?40/03a0;0P0<3@P06@0=3PT04Q<>01HG4P0B4`h051D@01PI500A4Pd0414<018C3P0C
50l061TD01TJ5@0B4`h03@h900l@2`0@40d030`:00d=2`0@40h03`l=00h>300@40h03`l=00d=2`0?
3`d00P0B4Q00500?3`d0410>00L71@0R8R0020P600h>300<30X03@d;010@3P0C4a407AdK06EUH`0Q
8Ah05aPC014B3@0>3`X06AXE03@e<00<3@P03Pl:0P0A4Pd08P0?40/030d800/>1`0;3PL03a4<00T;
20051`H06Q/M00D6200720X0C4i<01HH4`000@0030h:00l@2`0Y:RD051DA00l?3@0B4`h00P<100l?
3@0@4@`03@d:00`<2P0?40/03@d;0000000H61H04a<A00D50`1@D4h03`l=00/;2@0>3P`2014A3`0>
010@3P0?3`d02`X8018A3`0A40h030/903Dd<P0C4Q002PT700T81P0?3P`020L5010?3@0:2@L200X:
200;00/;2@0<30X03Ph<00l?3@0<30X02PX800`<2P0:2PP08B4O00d=2`0:2PP00P0=3@/0300<30X0
2`/900X:200=3@/02PX800h>300B4Q00000001LG5@0<30X03Ph<00d=2`802`/900/03@d;00/;2@0>
3P`02PX800D50`000000820N01lO7@0=3@/04A4?00/;2@0200`<2P0?00h>300;2`T03@d;00`<2P0=
3@/04Q8@00l>300B4@l07A`J01@C4@061@<030/900h=2`0?3P`030/900803`h<01003a0=00<81007
2@H02P/900d<2P1WHf80>SHe00<0000J6AL03`l=01`N6`021`<03Pl=00h=2`081`D06QTG0P0C4Q00
2@0>3@/03`h<00X91`0:2@L03`h<00h=2`0=30T03Pd900h=2`0200d<2P0<010>3`0=2``03`d>01dK
7P0?3A00JfU/010>4P0:20/05aDF00X82@01000030X;1@0?3@h01`0>30d03@/<00d;300?3@h040h?
00h<3@0<2P/00P0=2``200`:2`803@/<00T03`d>00l=400@3Q404a4D01@B5@0B41<03`d@00h<3`0=
2`h00P0<2Pd00`0=2`h03`d@00h<3`04010>4@<03P`?01004Q0C01LE600K6A`06QPK010>4@0F51L0
30X=00X82`0A3a803@/>014?4P0@3Q402`T<00`:3@0@3Q403P`?0P0?3A0300h<3`@03@/>00@03P`?
010>4@0A3a803@d?0`0>3Q00100<30h02`/=018B500820X201TI6`09024Q8`16ATP02@L8014?400?
3@h04@l@00/92P0B41403@/<00803P`=01D03@/<00`:2`0;2@X03`l?01TI6@0M7Ad04Q8B00d=3@0D
51@03@d=00l?3`0=3@d02`/;01<C4`0J6QX0410>01<C4@0410804A4?00d=2`0@40h00`0<30X03`0=
3@/03`l=014B4@0>40l02P`;00/=300>40l03PlA00T:3@0@4AD00`@801HG700:2a004Q<H01<D5`02
00d=3@803`l?01/0410@00`<300:2PX09RHV00d=3@0S8b<05aLG00/<200<3@D02``400`=1P0=3PP0
30d700X;1P0T9B003Pl:01LG5@030`402`/900D51@0B4Q80410@00d=3@0@41006a/K010@400A4A40
0P0C4a<0700B4Q804A4A018B400B4Q00410>018B400E5A<04A4?00<30@0D51806QXH00P81P0=3@/0
410>01HF5P0;2`/02PX:01LG5`0=3@d04a<C00T92@0?3`l05QHF00h>3P0I6AT03@d=010A5@0?41<2
00d>401@010A4P0A4a804A<B00d?3@0F61D05aTF01LI5@0=3`X051@B01HF500D51804Q8@01<C4@0F
5Q@04Q8@01@D4P0E5A<05QHD01DE4`0C4a405aLG01`M700A5A@06alN01TQ7`0D7A`06R<R01DL7@0G
71l06a`P01/K800O82@092d^01PR8@0A6aX0=d5003i8A`0M9bH0628Q01DO7P0L9RD07BLV01lY:00V
<2l06bDT02D_;P0L9RD051hM01dW9P0Q:bX06bDT02D_;P0F81l09Bl^00@>3@0Z=3D07bH_038i@@0X
;cD07RPY02D_;P0V<Bd0:SHa02@c;P0P;bX072/X01h/;00iAdP0938j02Xh@@0e@d`0<d5:020a>`0Y
>T@0;3e703U;E`17FVH0:Ce802m2D00V>TH202a2C@0_02a1C00_@dh0<dMB02e0C00U=d<0:c]802<c
@00J:SL093A102hmB`0[>DH0:3I302/iA00X=Sl08c0h024]<P0T;c40930`02@_;@0S;RX092l[01PU
9@0eA4/0Hg9i03]:D00K:Rl072/`01d/;`0N;C008c8e02@d=00N;Rh07bl_02Pc=`0W<SP09C0f02@_
=@0U<3H09c8h01dX;P0O:S008bhd01hY;`0G8RP05b4W01/S9P0N8bL00P0P9BP02P0O92L0728R01TO
7`0N92@07bDS01hT8P0R:2H08RPW01TQ900Q:Rl201TR9`0D01XS:00K92T07bP]069[L01:DeP07BH[
01TR9`0I82H051PQ024T;00>4AP06A`S01HI7`0O8RL0720S01<G6@0C5aP04aLF018F5@0E6AP301TJ
70<061TK00h05QLI01XK7@0G61X061TK01/L7P0H6A/05QLK018C5`0A4QH06AXN01dN8P0=3Q805QLK
01PI7@806Q/O01@05aPL01@H6`0I7Qh05QXK01LK700B5QL03a0B014B500E5QP04Q8D01<C5@0A4A<0
410B01@D500M71T03@`801<B3P0;2PH06APD00X91@804a8>00/061LC0:ZYY@1iN7@05A@@01@@3`0I
5A@05Q8A00l;2P0@30/04`l>018>3@0200l;2P07014=300?2`X0510?00`81`0=2@P05Q8A010<2`02
014=30803`/:00@040`;014=300B3Pd04Pd>1P0A2`d03P0B30h04@/=00l92`0A2`d03`T;010;2`0F
4Q404`l>00d9200>2PT040`;01@@3`0810<04`l>0P0@30/01`0H51<0RXF5061JFP0A2`/071<D01<:
2`0<0`@00P0B20T0100A1`P04@D701451`0C1`T60147200600h41@0A1`P04PP901882@0D2P/04`T:
0`0?1@H0100A1`P04PP901D;300A1`P200l51P0301882@0D2P/050X;008040H700H03`D600h41@0?
1@H040H700l51P0;0@8201P>3`0400d3100A1`P02`0300h21P@040@800@04`L;01862P0@10P03`<7
0P0>0PHDooooo`006oooool06P0F5A<04A0>00/:200920H02`X800d<2P0D4a403`h<00h=2`0@3`d0
4Q4?014@3P061P@05aLE014A3`0=3@/02`/902PX9P0M7A/02PX801HF500];B/020P601<C4@0>3Ph0
51@D0P0?3`l0500@41002`/;010@40051@D071`L00h>3P0410@02`/;00/;2@0S8b40>SXh07emN`04
10801`L500h>3@0C4a407alM01HF500E5A<02PX80P0=3PT00`0>3`X03a0;00l@2`0200l@2`0300h?
2P0:2`H02P/6008030d800H05aPC01/L5`0A4Pd0414<018C3P0A4Pd201LH4`0900l@2`0=3PT03Pl:
00h>2`0;2`T03@d;014A3`0>3P`03@d;00804A4?02`03`l=010@3P0B4Q004A4?00h>300;2`T020P6
01DE4`071`D03Ph<018B400:2PP05ADC00d=2`0C4a40Fe]I010A3@0720<02P/600P9100:2`H05QLB
00T:1@0;30L03Pl:00l@2`0>3`X030d800`?20062@803a4=00lA40072@P08B8T09fNX00O828020X9
00`>2`0I6aH02Pd60001000=3PT01`P300P910804a@?00H030d800/<1`0?40/03Pl:00P9100720<2
00d=2`0G014A3`0@40h051@B00L71@0:2PP03`l=01<C4@0A4@l03`l=00d=2`0D4a402@P6018A3`0=
30X06APF00l>300>3@/02PT700d<2P0920H040l=00h=2`0<30X00P0;2`T0700<30X03Ph<00l?3@0>
3P`030`:00d=2`0A4@l06a/I00T91`0<30X0410>00l?3@0>3P`03`l=00/;2@0?3`d02PX800`<2P0A
4@l00000014A3`0<30X03`l=00h>300:2PP02`/900d=2`0<30X200l?3@0?00T91`0F5Q@0C4a:09VI
U`0:2PP02@T7010@3P0820H030`:00d=2`0<30X03`l=00`<2P0820H02PX800802`X800@05aHD00l>
3@0;2PP04Q4?0P0?3P`05@0;2PP030/900/:20092PP041DA00lA3P0=3P/06aXH07UeM00R7Qd01`<2
018A3`061PD092HS01<H500@4@h03Pd;00D40P0G5Q@02@P600l>300200d<2P0I00/:200920H03`h<
00l>300>3@X03`h:00l>300=30X030/900h<3@0C4A802@L800400P0D4QD08b4T01LE6@050`H040h?
01@B4`0M6a`02PP901<A4P0>30d03`d>010>3`0200l=3P0700h<3@0=2``03`d>010>3`0>30d030X;
00d;300200l=3P0600h<3@0=2``03P`=00l=3P0>30l03`d@0P0A3a800`0?3A003P`?01@B5@02018@
4`805aDH00<040hA00l=400?3A00100?3A002P0B41<040hA014?4P0E4aH04Q0C00T72P0G5AP061HI
00l=400<2Pd200h<3`0601@B5@0<2Pd020H900`:3@0@3Q403@/>1P0>30l01`0?3A003P`?00h<3`0>
30l03`d@010>4@0=3@l00`0>3Q009P0<30h02`/=00P82P0V9RP02`/=00d=3`0>3Q004a<E014?4002
00404a4B018@4@081PL04a4B00h<3@0?3@h02`T:00d;300?3@h03@/<02@T900>3Ph00P8200l?3`00
00004a<C00d=3@0<30`02PX:00/;2`0D51@06a/K010@3P0?3`d01@D301HF500:2PP03Ph<0`0=3@/2
00h>300=00h?3@0;3@`02P`;00`>3@0>40l03PlA00/<3`0D5AT00@86018C5`0310T03a0E00`<3`02
00h>3P<03`l?01P09bLW01/K6`0S8b<03@d=00410@0A4A4051DA01DF3P0@4@T030d600X;1@082@<0
3Pl:02<T7`0>3`X0820N014A3`0@40h05QHF01<C4`0@410030`<00H61P0820P2018B4P<04a<C00@0
4Q8B01PH5P0D51804A4?0P0E5A<05@0<30X02`/901dM6`0];B/092@R014A3`0G5aD03`l?00/;2`0G
5aL06a/K00/;2`0C4a<03`l?018B4P0F5QH03@d=01LG5`0<30`04A8F014B5@02010A4`0@014B4`0A
4a805QPG010B400A4a007R0M00d?2`0I6aH04a<A01LG5@0E5A<04A4?018B400F5Q@05ADC01PH5P80
6QXH03H061PF01HF500D51@07b0O00hB4@0J7Qd04APG01lX9`0K92<06R4R01`Q900K72006ATN020Q
9@0K92D02Q@C014K6P0Q:bX07BLV01LQ800J92<0628Q01LQ800I8b807BLV01hX9`0Q:bX07BLV01lY
:00K9B@07bTX01PR8@0P:RT09Bl^020Z:@0J92<08bd/024[;@0l@Td0BU5K038i?`0N:2T08R`[01lZ
9P0J9b004B0K02Th<`0W=S<09S@d01d[;00X=cl0:SQ103=1BP0`?TL202Hg@@0?03Q9D`0[?DT0:ci9
02TmB00[?T`08cQ402DkAP0Z@4/0;45<02/oBP0]@D`0<DA@02XlB00^?T/0:c]800809SI300L08c50
02PeA@0]>dP0=TA@02hlA@0T<CX082`a00808Rh^01408bh[02@_:`0X<bd09c@d02@c>P0R<CP082le
01`[<00U=3T07Rd`01l^<@0W=ST0:3Ph028b<P0P<300:3<i02Ha=`0202<^=0809C0f00l0:SDk02Pc
>@0W<SP09S4g02@_=@0P:Rl061lU01hS9`0S:2/08BHY01lT9`0P9RH0:S0`02H/;00R:2H00P0Q9bD0
;00P9bH06B4T02</<@0L9BX06B8W020Y;P0E7R<0214F0:F^/P1jPhP031DJ020Y;P0<4aT06AdV03Hi
@@0I72<08RD/018E6`0J7B807R8U018F600C5aP051PG014E500G6aX051DG01HG6@0G61X06AXL01/L
7P0L7Al05AHH01XK7@0H6A/06AXL01`M7`0I6Q`04a@H024R9P0K720051DI01HG6`0E5QX05aPL0`0H
6Ad08@0G61`05ATL01DJ6`0C5aP05ATJ018F5`0B4aD05AHH01@E5`0A4A<04Q8D014A4`0@418051@D
00h=300O7QX07A`H01@C3`0R8Ad071/G01DD400H5a<030/7038a;@0L6aL030/7018>3@0I5A@05Q8A
018>3@0C3`h04Ph=01DA4003018>3@05014=300@30/030P700/71P0@30/00P0>2PT00`0A3@`03`/:
00l;2P0200l;2P03010<2`0A30`040X<00@040X<00X04`d?010:300>20X040X<00/51`0:10H05a8B
01PD4`0@30/03`/:0P0>2PT03`0<20L03PX901`H5`0:1`H05Q8A00P40`2KUYD0K6IV010:2P0B2@X0
30<401482@0C2@X04PP90147200201451`030186200@1PL040H700@040H700T03@<40147200C2@X0
3`D600h41@0@1PL04@L801061`0?1@H00P0>10D200l51P0300d3100<0P<03`D6008040H70P0A1`P0
2`0@1PL03`D600l51P0@1PL0308300/10P0?1@H040H700h41@0A1`P03`<7008040@80P0?0`L01@0=
0@D060`@01H:3P0C1`/04@D9008040@85?ooool001_ooooo01P030/900h=2`0A40h04Q4?014@3P0?
3P`04A0>01<B400?3P`02`X800d<2P0@3`d0410>01<C4@0H61H05QHD014A3`061P@03`l=010@3P0=
3@/02PX9014A3`0@40h200l?3`0?00/;2`0F5QH07AdM01DE5@0h>3P0410@00l?3`0=3@d071`L010@
400>3P`02PX800`<2`0V9R@03`l=00803Ph<00D04A4?00T91`0=3@/01`L500h>300200d>2@0300h?
2@0?40X03a0;00803a0:00h061TD01@E3`0B4`d0414<00d>2@0I6QD07QlJ014B3@0?40/0414<00h?
2P0B4`h0414<00d=20804Q8=00H03@h:00X:200<30X04a<A00h>300<30X2018B40<03`l=00h03Ph<
010@3P0820H04a<A00h>300D518030`:01<C4@0H61H02`/9010@3P061PD0410?00l?3080414<0340
3@h900l@2`0D5A007QlJ01/L5`0C50l03@h900/<1`0<3@P03a8<00/@2@0;3`/030l>00X>3@0=4100
9RTZ00dA4@0=4A001`X800@9100@4`h04a@>00X;1P0?40/02P/501DF400V9b803@h800P90`0?40/0
2``700D60@0W:2<07QhL00T91`0b<S00=3@b00h>300D51802`/900h>300=3@/02`/900X:200=3@/0
3`h<00d<2P071P@02@P600802`X80P0?3P`0100=30X040l=00d<2P0@3`d200l?3@0:00d=2`0<30X0
3Ph<00l?3@0<30X03`l=00`<2P0F5Q@03Ph<010@3P803@d;01T01`L500X:200D51804a<A00`<2P0>
3P`03@d;00`;2@0?3`d03@d;00`<2P0@40h03Ph<00T91`0:2PP03Ph<00T91`0A4@l03`l=014A3`0B
4Q00<c<a06MWI@0A4@l02PX800803Ph<0P0;2`T030092@L03@d;00d=2`0;2`T03Ph<0450?P0D4a40
30/900l>300B4@l03`h<00d<2P803`h<020051<A01DD4P0=3P`04QHB00840P0>3P`03P/:01/G5P0?
2PX05a<B00d<2P0=3@/02@/800L:1`092`P04A0>00P71@0<2`T01`H4014@3P0:2@L03`h<014@3P0<
2`T03Pd;010?3@0>3@X040l;018A3`0@3`d030/900/92P804Q0A00P02`T;014?4@0A3a803P`?00h<
3P0L6Q/02`T:00d;30804@l@00<03@/<00h<3@0@3Pl00`0@3Pl02P0=2``03`d>010>3`0>30d030X;
00d;300C4A804Q0A014?4@0?3@l200h<3P8040hA00D03P`?00d;3P0=2`h03@/>00`:3@0200/93080
30X=00<03@/>010>4@0?3A000P0<2Pd00`0?3A0040hA00l=4002018@4`0500l=400<2Pd02PP;018@
4`0>30l00`0@3Q401P0J61/03P`?00h<3`0?3A003P`?00d;3PD03P`?0P0?3A02014?4P0500l=400>
30l03`d@00l=400=3@l00`0>3Q001P0<30h02`/=00l?4@14A4H07QhP00d=3`803`lA00h040h?030^
;`1]Jf`040h?00d;300>30d03`d>014?400=2``03`d>014?400=2``0@T9202@T90803`l?00l07alO
00L71`0>3Ph02PX:00T92@0;2`/03Ph>00l?3`0>3P`03@d;018B400W9bD0410>00h>300@40h00P0?
3`d200h>300=00`=300;3`h03a8A00hA4P0;3a0030l@00hB4`0830h030hB01PK7`0/<3@0FE]O00l@
5002010@4@0K00l?400?3`l03Ph>03/k>P27QhH07alN00l@3`0d=C@03Pl?01`M6@0J6a@051@=00l?
2@0?40T0410:014A30092PD071dH00L6100C4a4051@B01DE500:2PX04Q8B00l?3`0F5QH04a<C0080
4Q8B0`0@4100;@0B4Q805ADC018C3P0@4@d04A4>010A300?40`03`l<014B3@0I6QH051DA014C3P0B
4`l051@C014A4@0N7Qh04a<C00`<300c<c<0@D5101/K6`0@41004Q8B00d=3@0E5AD04Q<F01<D5`0D
5AH051DG01<D500A4a804aDD010B400G6AH07b4N05YLF00B50l04a<A01LG5@0F5Q@04A4?018B400G
5aD06QXH01TI5`0201PH5P0?01TI5`0J6QP06QXJ01@E500M81l061`K01/R8@0F7ah082PW01XP8@0K
82807R0T01`L8@0K7R406R8R00807RLV01005AlN01@N7@0H8R40628Q01`V9@0E7ah08B/Z02dg=`0X
<S40JWAd024[:`0L9RH08B//02Tc=00H8R<08bd^0P0R;2d0C00N:2T09Bla01TR9P0nADl0<CQ202T`
>00S;C008B/[01lZ9`0Y=S40:cXf02He<@0U=3809S@d028a=@0X>4009cHo02`lA@0W>D00:ca502Hh
@@0Z?4L09CM202e0C00S=T@0:ci<02DhAP0Y?TT0;D9=02XoBP0U>D@0:3]60312CP0W>D@0;Cm:02/m
B00^?dX0=DEA02XiAP0X=D@0:3I302`jAP0T<S/08Rlg028^<`0R;Bh08Bd]024/:P0T;b/0:cHa02dj
>`0K:S408c4h01l^=00P;c@07R`b02Hd>@0W=SX0;Se102hm?P0U=CH08c8c02Lc>@0T<3H08Bdc028^
=00U<3H08bhd01hY;`0Q;3808Rdc028]<P0S;S<08B/`02<Z;`0R9bX201hS9P0P020U:00P9BL0@4E7
02dc<`0R:2L09B/Y020V900O9RD072DZ01/S:`0M9Rd05b0W01XS:@0K92X08BX_02Ta=P0V;S804QXP
01hV;00O9R`05Q/R01XN9@0N8BL06ahU01PK800J7B808bLZ01HJ700H71d061`L01@H600M8B4201HG
6@<05AHH0P0D5AL201TJ7@0;01XK7P0M7R4061TL01<D600Q8RH06Q/O01@E6@0H6Ad051DI01HG6`0E
5QX00P0D5AT0100F5a/051PK01@I6`0B5QP201@H6P0501LH6`0K71h05AHH01<C5@0E5AL00P0C4aD0
200G5aL0F5QC00h>2@0K6aD051<>00/:1P0I61<07ahJ0P0A40/00`0G5Q404a8>01XI5@02018?3P0B
01<A3`0L6QP05a@C00/81`0@3P`03`/:010<2`0C3`h04Ph=01<?3P0j=SD0<bl^014=300E4A0040`;
018>3@0A3@`040`;0`0?2`X00`0@2`/040X<010:3003010:300H014;3@0;1@L03`T;01<=3`080P@0
5a4C03<^;P0J5QD02PH5018>3@0=2@P02`L601<?3P0710<040`;00l<2`0@30/040d<01@?3P0>20P0
40X:00l61`0=10D03PD60P0C2@X0100A1`P04@H701461`0A1PP601061`0400h41@0=0`@03`D60106
1`803P@500D03`D600h41@0>10D03P@500l51P020147200500l51P0=0`@03P@501061`0?1@H00P0B
20T01P0@1PL03`D600l51P0?1@H03P@501<92P80308300@04PP900`20`0C1`/04@D90`0@10P00`0?
0`L050P<01862P0200l31`030104200A1@Wooooo01?ooooo000Kooooo`0500X:200>3P`03@d;00h>
300A4@l00P0>3P`01@0=3@/03`l=00d=2`0:2PP0410>00803@d;00X03Ph<00l?3@0A4@l04Q8@00P8
1P0?3`d05QHD00X:200@40h03`l=0P0A4@l04P0@40h03`l=00`<2P0<30X04Q8@01@D4P0E5A<05QHD
02TY9`0L71X04A4A00L71`0E5AD03@d=018B4P071`L03`l?00d=3@<030`<01<030`:00d>2P0=3@/0
3Pl:00l?300?3`d03a0;00l@300@40h0414<014B3P0A4@l03A4=04iCC`3=d/h0?T8n01XL6@0F61D0
2PX800803`h<01<040h<014=300A3@`030T601DF4@0>3`X03Ph<00h>3P0H61P03Ph?00d=3@051@D0
3`l=00`=20092PD05QHC01LG5@0B4Q002PX800803Ph<00L02`/900T91`0?3`d04Q8@00P81P0;2`T0
3Ph<00803@d;0P0:2PP09P0H61H051@B018B400=3@/02`/900d=2`0@40h04Q8@00lA3P0=3P/030`:
00/=2P0>3`d03Ph>00h@3@0@4@l0410>00d?300;30P03Ph<00l@2`0@40d03`l=00h?2P0<30T01@D3
018C3P071`D06ATG00h?2P0>3Pd04Q8@00D50`1=CD/0IfMU00/;2@0C4a402@T70P0@40h200/;2@07
01<C4@0820H02@T700`<2P0>3P`03@d;00T91`0600h>30802PT700`03`h<01DD4P0B4@l02@P600X9
1`0>3@/03`h<00h=2`0?3P`040l=00d>2@0?40/200/<1`0300l?2P0=30P03@`800803@`80P0?2`P0
200=30P020X7018D4@0D5Q<06A/H00X:200G5aD0410>0P0A40h3018A3`0700d<2P0?3P`03`h<00`;
2@0;2PP030/900h=2`0300l>3005010?3@0A40h051<?00d<200<2`L00P0?3PX06`0=30P03`h:00h=
2@0B4@d0;bhZ02LV8P0=30P030/700d<200@3@X04@d:014=300=2PT03@`:00T7200;2`/03Ph>00`>
3@0?3`h02PT700d<2P0?3P`03@`:00`;2@0:2@L02`X800d<2P0200l>300400d<2P0<2`T03@`:00d<
2P803`h<0P0@3`d02P0?3P`04A0>010>3P0<2P/08AlP018@4@0?3@h02`T:01`J6`0S8B8200d;3080
30X;00/03@/<00l=3P0B41406ALH00l=3P091`P03@/>00h<3`0@3Q404@lB010>4@02010>4`0:018@
5@0D4QL02`T<00h<3`0?3A002`T<00T72P0:20/02@L:00/930<03@/>01L040hA00l:400@2a403`X@
00d83P0>2@l04@`B01PC6@0J5A/04PdC010;4@0C3Q@030X?01@B5`0B4AH03`hC00d<4@0;2Pl02PT>
01@C600F5AX051<H010?500200d<4@0800d;400?3A804@lD014?500@3Q<03P`A010>4`0>314200`:
3`0900h<4@0@3Q<02PP;014?4P0;2@`030X=018@4`0A3a8040hA00803P`?0P0:20/02P0?3A003Ph>
01LG5`0K6a/04Q8B00X:2P0=3@d03`l?010@400<30`200l?3`0l00T92@0<30X01`L5018B400:2PP0
6a/I00d=2`0>3P`02@T700`<2P0@40h04Q8@00@40P0;2`/03Ph>01@D500B4Q804a<C01XJ6P38b<P0
:b/[00D51@0C4a<05QHF00d=3@0>40l03Ph>00h?3P0=3`h03@d=00`=3@0?4A004A4C00T:300j>cd0
VYZL00l@5P0M7BD02PT?00d<400B4Q8051@B01lP6`2:S8L061XE01DK5`1MHf401@/900d?3P0>3@T0
5Q8?00d:2@0@3`/05a<@010>300E518061HD01<?3P0>3@/0518@1@0?3`d00`0?3`l08b<S01dM7@02
01HF600>01DE5`0>3Q003Ph>00h>300?3`h03`l?010@3P0?4@l051HE0001000D61D061XI014F4P0F
6QP6014C400U01DG500:30T07R0M01`N6`0G6AH04A<@014A4@0G5aL051@B018B4P0E5A<04a<A01TI
5`0B4Q0061PF01`L6P0/;2X0410>018D4@0C5A804A<@01@F4`0J71T05QPE028T8@0D5Q<05aTF01TK
600E5a@07R0M01dM7@0D51@07AlN00/=300C5aH06AlM01XN7@0201XP7P1V01XP800J7Ql061`M01LM
6`0I7ad0728P01dT8P0M8b<06b@S01HN800K9BH0:cDf01lY:P0a>cd0:cDf02lk=`0P;2P07b/W01hZ
9`0N:RP08bl]01hZ:P0P:bd08Rd_02Ha<`0Q;30072DZ02Xa=`0U;3808bX`02/d>@0/=cT09S4c02<_
<P0S<C@07Rd`02@d=`0Q<3D08C8i02PlA00W>T4093Ln01T^<`0N<CL09CPn020c>@0R=C`0:Ca402Li
A@0T=T809SQ602LiA`0Y>dT0;T1>02`nBP0X>4D09cQ202Df?P0T=Cd09SLo02@e?00X>D00;Si702Le
@00Q;cX0<Cm802Lf?@0O;3@0;c]0028];`0M:2X09C0`024[:P0R;2/0:3<e02Ld>P0N:Bl09S4i01l/
=00T;cP092hg01h[<`0R;CH0:cDo020]=P0V<CX09cHk024`=@0L:c006bX_01/X;P0Q;c806RP[028`
<`0V<C@0:3<e01dX:P0J92H07BHU01/T8`0H8240620R0P0K8bH0<@0N9RT07BDX01`T9`0M9RD07RLV
024Z:P0K8S@061hf02@[@00Z<400728`01DL9@0N9B/06b0T01lT9`0O92P06AhR01dR9P0G72006B0S
018G6P0@5AT051TL030e>011ADP05ALK01lP90061`/07b0S01PI6`0];S007QlQ01LH6P0F5aT051DH
01@E6@0L7B404a@H03@e>P0=3Q<08b@Y01DF6`0C51P05QLK01TJ7P0J6al061TM01HG6`0I6Qh00P0F
5a/02P0H6Ad05AHJ00lC5P0<41D020/@01@G700L7b@061TN01hO8`0A4QH2018A5P804Q8D01004Q8B
01hP700?4@h06adH00h?2`0E5A<07AhI09RIU@0K6QP03@`801DD4@0>2PT04A0>01<D4P082PL030h;
0P0K6aT03@0?3`d02@T700h=2`0C4Q003`h<00`;2@0<2@P061@C01hJ6@0>2PT04Ph=01LC4P0A3@`0
0P0?2`X0100@30/04@d<014=300C3Ph201<=3`04018<3P0A2`d04@/=010:30804@/=02403`T;01@>
400E3a404@/=018<3P0=1`T040X<00d72@0H4Q@02@<5010:300G4A<040X<00d72@0A2`d03@T900h:
2@0@2PX04PT:01482@0B20T04@L800X00@0A20T02@0101D?3`0<1PH06a8C01<92P0B20T03`D601<9
2P0>1@D01P0>10D01@0=0`@04`T:00`20`0?1@H03P@500804@L80P0@1PL00`0C2@X04PP900d31006
01061`H03`D600`04@D901D93@0<00@0300401H:3P0B1PX030040106200C1`/02`0301<92`08000D
ooooo`006oooool01@0:2PP03`l=00d=2`0>3P`04A4?00803Ph<00@02`/9018B400E5A<0410>0P0=
3@/00`0>3P`03`l=010@3P02014A3`0800d=2`13@d40410>014A3`071`D03Ph<010@3P0?3`d200h>
30803`l=00h04A4?010@3P0=3@/03Ph<01HF500>3P`03Ph>00D51@0B4Q803Ph>01<C4`0;2`/0410@
00h>3P@03@d=0P0=3@/04@0>3P`03`l=00l?3@0?3`d02`/900h>300?3`d0410>00h>300H71P0N7ei
0??hm01AEU80008000`>2`0C4a403`h<00@04@d<00l05Q@@010A2`0310004Q<@00/;2`0<30h03@d?
00X:300A4A402`/900h?2P0C50h0410<01<C4@0D51800P0A4@l04P0?3`d04A4?00X:200=3@/0<30^
03Lg=@0O7ad030`:00l?3@0B4Q005ADC00h>300410804A4?010@3P0=3@/02`/900`<2P@03`l=0P0>
3P`00`0=3@/03`l=00d=2`0200X:200@00/;2@0?3`d03Ph<00h>300@40h03`l=00h>300<30X03Ph<
00l?3@0<30X04a<A00L71@0?3`d03Ph<00`<2P8061PF00d01`L600h>300C4a4020P600h>300E5A<0
410>00`<2P0=3@/03Ph<010@3P0C4a404A4?00L03@d;01<03Pd;00d<2P0A40h05A@B01@C4@0=30X0
30/900l>300@3`d03Pd;00d<2P0>3@/03@h9010A300;30L02P/600l?2P0<2`L03Pd900<040`900<0
4@`9010<2@0C5Q<00P000@00101bM740IfMU018B400;2`T300`;2@803@T800D03Pd;010?3@0?3P`0
3@`:00`;2@0200d<2P<03Pd;00D03`h<010?3@0C4Ph03@`800`;1`0200h=2@0900d<200:2@D02`X6
00/:1P0L6aL061LC00d:1P0@2`L040`900804@d:00`03Pd;00/:200@3`d03Ph>018B4P0@41001`L7
00X9200<2`T03Pd;00l>300<2`T200X91`8030/900@03@`:00h=2`0>3@/03@`:0`0<2`T300/:2005
00X91`0<2`T03@`:00P71@0D4a400P0=2``03P0:20T040h?01PF5`0A3a003P`=00d;300<2P/03@/<
00h<3@0A3a00;R`]024O800C4A803P`?0P0<2Pd03`0?3A803P`A00`:3`0<2A003@XA00l<4P0=2a00
40hA014?4P0=2`h02`T<00`:3@0:20/030X=00h<3`0200d;3P0=010>4@0?2Q0040/A00l:400=20h0
3PT?014<4P0@2a404`hD00h93`0=20h04@`B00`:3`0300d<4@<03PdB00H020L<00/:3`0<2a0030/@
00d<4@0@3a@200d;400600h<4@0=2a003@/@00`:3`0@3Q<03P`A0P0<2Pl0100>314040hC00X82`0A
3a8200`:3@0N010>4@0?3A003P`?00d;3P0?3A003@/>00h<3`0C4A@0410@00d=3@0>3Ph02PX:00/;
2`0@41002PX:00/;2`0:2PX03`l?010@400;2`/051@B01PH5P0D518010@201HF50092@L030`:020P
7P0O7ad02`/90P0>3P`0300>3Ph04Q8B01DE5@0>3Ph0410@00h>3P0g=cL05ADE01PH6000000051@D
00T92@803@d=0P0>3Ph07`0=3@d0410@00l?3`0H61P04A4A02DU9@1]KFd04a<H00X:500;2Q8051<G
014A4@0?3`d051H@02<V7`0E5a8010X5014G4`0L8R002`d;018>3@0E4A003`/:018>3@0I5A@0510?
01<?3P0D40l040`;00h:2@0@3P`00P0?40/300l?3@0:00l?3`0G5aL04a<C010@4P0C4aD051@F010@
4`0?3a403`l?010@40804A4A00P0418A00h@3`0W:BP02`l>00T=300G6aX03A<A01<E4P804Q@A01h0
4A<@010B3`0@4Pl0418?02HX9@1@DTl051HC00<50P0I6aP04A4?01<C4@0@40h04A4?01LG5@0D5180
6a/I01`L6P0820H05ADC01XJ600H61H04aDB01HH5@0C5A804Q@A01HH5@0D5Q<06Q`I010B3`0B5142
01HH5@0901PJ5`0M7Ad071`L01dM7@0D5QD06ahM01<G5P0I7A`06AhL00806AlM0P0K8Al0100I7A`0
6alN01dQ800M8b4201dS8`1]01hV:00K9BH082X[01LQ8`0V<3808bd^02Te<00M:BD07b/W028^:`0U
<Bl0:SHf02Lc=00Q;2h04A`P01TT:00T;c<06RDY01lW:`0S:S0092/a02Tb=`0V<CD082/_02<`=P0S
<SL07bhc02@f>P0O<3L083<i020f?@0T>3l093To01db=`0O=3L093Pl028e>@0S=S`09SU102Li@`0U
=D807Rhm024a@00Y>DP0;Ce<02dmBP0^?dT0;Ci702Tj@P0]?TH0<D9902Li?@0T=C`0:SY202Xh@`0X
=Sl0=49:02dl@`0V<cT0<Si302Pc=`0M:2X092h`02@^;`0S;B`0:cHh03U4BP0O:S008bhd02Xd?@0V
<3T09S0j02Xd?P0R;3H0:C<o024[=`0U<3/08c8i01la=@0P<SH08C0e01d/<@0P;S409C<f02@b=@0J
9BL06BDU01LS8`0R;B`06R<R01PQ7P0G81l06R8U01hV:@0P9bd08BP^020W;@0O9bT07BDW01dV9@0M
9BL06R0f01PM>P0T:D@0:Rm301hT<P0I82X07B8V01/P8`0201dQ900?01/O8`0L8BD082DX01dU9`0I
8B<08BHY01`Q900I7R4051PK00T;3`0@4AD0:2T]01LH70092Ph06a`N00<05QLI01/05aPK01hO8`0B
4aP08R<X069SJ00/;3@07AdU02LX;@0M7R<07AhR01`M8@0I6Qh05QLK018C5`0E5QX051DI01DF6P0I
6Qh061TM01<G6P0N8RP03a8I01XM900V:C00LW=h00d>4`0B4aL00P0C4QL201<C5@0C01<E500=40h0
71hK00L91P0E5a@06QXH00`<2P0o?cd05QDC01<B400F5A<04Ph=00l>300?4`l02a0<00dB3P0B5140
3Q0=00H81@02010@3P0400l?3@0A40h04a8@00l=2`802`L600@03@T8010<2`0>2PT03@T80P0?2`X0
100@30/04@d<014=300B3@h4018<3P07014;3@0?2@/04@/=014;3@0<1PP03PP:00l92`02010:300=
00/51`0B30h0208401D?4@0<1PP0208400d72@0:10H02084014;3@0?2`/02`X800l92@0201482@0=
0147201CBDX08QPI00d41@0;1@D03PX900d9200@1`P02`4200d3100800003`D601D;300600h41@06
0147200O5AH04`T:00l51P0E2``050X;0P0?1@H0100A1`P05@/<01H<3@0C2@X<00l51P0<0104200B
1PX03P8600h21P0A1@T03P8600d11@0?0`L02@0101lC5`0?1@L060`@5?ooool001_ooooo00/02PX8
00l?3@0>3P`03`l=018B400?3`d03Ph<00/;2@0E5A<06a/I01@D4P0200`<2P0<00h>300A4@l04Q8@
014A3`0?3`d04A4?03hn?00J6QP04a<A00X:200B4Q003Ph<1@0?3`d03`0C4a40410>00`<2P0E5A<0
30`:010@3P0F5QH030`<018B4P0?3`l04A4A00`<300@41003`l?00h>3P0300l?3`803@d;01403Ph<
00l?3@0?3`d03`l=00`<2P0>3P`03`l=010@3P0>3P`030d:01/M6P15AT<07b0M00H71@0H61H02`/9
00h>300400l>300A00l@300B4`d04a@?01<D4@0?3`l01`L9038b=00@418030`<018B400:2`H04A8<
00X:1P0?3`d04Q8@00h>300=3@/00P0@40h2014A3`0:010@3P0=3@`030`:00l?3@0<30X04a<A01@D
4P0A4@l051@B00d=2`<03Ph<00@03@d;00`<2P0=3@/03Ph<0P0@40h01@0?3`d03@d;00/;2@0=3@/0
410>00804A4?00<0410>00h>300>3P`00P0?3`d200h>300701<C4@051@@04A4?00P81`0@40h08B4O
00/;2@0200l?3@0900T91`0B4Q002@T700X:200B4Q005ADC00l?3@0:2PP03Ph<008030`:00@03Ph<
00l?3@0>3P`02`/91P0<30X04`0@3`d03@`:00h=2`0A40h04Q4?00l>300>3@/04A0>010?3@0>3@/0
30/900d<2P092PD030d800X;1P0<3@P04Q8=014@300?3PX00`0A3@X02@0B3@X04@d:00/>2`0E5a@0
4A<@01TK600P81h0:b/Y018B4002014@3P04010?3@0A3@`040`;00l>30804A0>00H03`h<00h=2`0>
3@/03@`:00`;2@0=30X300h=2`03010?2`0=30P030/700803@`800T030/7010?2`0@3`/03`h:00d<
200>3@T04@h:01<>2P0A3@X00P0@30T03P0=30X03Pd;014@3P0;2`/03`l?014A4@071`L02`/:00h=
2`0?3P`03Pd;00`;2@0:2@L02`X8100=30X300h=2`0@00d<2P0<2`T02`X800/:200<2`T03@`:00h=
2`0@3`d03@`:00`;2@0;2PX04Q0A01`J6`0C4A804@l@00`:2`803`d>0`0>30d04P0?3@h08R0Q01PF
5`0>30d03@/<00`:2`0?3A003`dB00h<4@0<2Pl030T@00d:4@0?31804@lC014?4P0C4A@040hA00l=
40803P`?00d040hA014?4P0>30l03@/>00l=400=2a003P`A00d;400;2@h030X?00l=4P0;2@h03@/@
008030X?0P0@3Q<00`0<2a003@`A00`;400300d<4@8040lD00L03@`A00X93P0;2Pl03`hC014?500@
3Q<03P`A00<03@/@00/040hC00l=4P0=2a003@/@00l=4P0@3Q<03@/>014?4P0?3A003P`?00d;3P02
00`:3@0900d;3P0@3Q403`d@014?4P0G5AP03`l?00X:2P0?3`l04A4A00803@d=0P0>3Ph0200=3@d0
410@00l?3`0;2`/03`l=00P81`0=3@/03`l=0P0A4@l05P0>3P`03@d;00l?3@0;2`T04Q8@00l?3@0=
3@d04A4A01<C4`0<30`04A4A01<C4`0G5aL02`/;010@400C4a<030`<018B4P0?3`l04A4A018B4P0A
4A42010@400H00820P0E5AD0410@00@4100N7Qh03PlB00l?5P0?3Q<03@d?01<C4@0M7QT03a0;00D7
0`0>40T0:bdX010C400F6AL03Pl=00T81P0D4a406aXH014@3P0B4@l03`h<1@0@3`d03@0A4Pd0414<
010@3P0@40h03`l=00l?3`0B4Q80410@010@4P0C4aD051@F010@4`0A4A<00P0A4A42018B4P07018D
4`0=3`h051HE03Hj>@0>4Q404QHE00lD4P02010B3`0<014C400B51404aDB01@F4`0F61D02``:01PJ
5`0B51806adJ014C400A4@l051@B0P0A4@l02P0F5Q@05ADC02TY9`0d=3804a<A01hN700@40h06ATG
01PJ5`0J71T201DG500F01HH5@0A4a005ALD01DG500C5A8071hK02@V8`0F61D0418@01/M6`0E5aD0
6A/J01TL6`0E6AL06alN01TO700H7Q/06AlM01`S800M9R<0728P01dS8`807R@T0P0L92H05P0L9BL0
82X/01/U9`0P:bd08bh`02<^;`0[=cD08bl^024];00Q;Bd08bl`02Ha=00a?400;3Ll03Q3B@0/=ch0
6bH]028/=00O9bd09Bhc02</<@0S;C8202Ha=@1602Db>00V=CX08S4f02Pg?00Q<cL08C@i024e?00W
>d80:Ce2024f>@0P<cL093Lk02`o@`0]@4H0:C]40394C`0`@Tl0:CY803=4C`0iBEH0<T9>02Lh@`0[
?4H0;Sm902XkA00/?DH0;Ci702Tj@@0Y>T<0<3m9041>F@1@GVL0>dUA02<b>@0X=C/0<Si302dh?00Q
;2h092l`02H`<@0U;bh092l`06QfN02d`<40BUQK03=0A@0f@dT0@TmF04QEG@0O;3@09S<k02@a>P0[
>44082le02<b=`0[>Sl0:CPk024`<`0Q;c8082h_02<a<P0S;S009c<c024];@0R;2`072DT01XS800I
8R406b<V01dU:0<07RD[0P0P:2X09`0P:BP07bLW01PO<@0G7C<07bHi02@Z>@0M8bh06R4X01PM800K
82<05a/N01PL7`0M82@06AhR01PM800W;c407bLY01DJ7@0H7B005Q/N01DI700J7B00414E04U:CP0Q
8RH0824U01TJ700J6ad07AhP01TJ700E5QT06Q/O01PI7P0Q8RL0?Sm401LG7`0J6R80:BX_01LH7@02
01LH700301PI7@0I6Qh06AXN00805QLK00/05aPL01PI7@0F5a/04aLJ01LK8P0<3aH05QTP030c>01l
OH807QlT01@E6@0201DD6@0D01DE5`0D51H04aDD00lC400F61D03a4>01TK600D51805aLE01DE4`0E
518030/9014@3P0I5A@04A0>01<G4`093PX02a0<010B3`0A4@l200h>300500h=2`0920H04a8@01DD
4P0?3@/00P0A3@`0100E4A0040`;00l;2P0B3Pd4010<2`04014=300A30d04@/=014;3@804P`>0280
4`d?018<3P0G4A<0618D014;3@0?2@/040X<014;3@0C3@l050h@01`F600;1@L05Q0B018<3P070@<0
3`T;01HA4P0:1@H03PP:00h:2P0;2PP03`T901482@0@1`P04@L801hD5@0<0P<03`H701@>3P0B3Pd0
3@T800l61`0<0P<050X;0P0?1@H00`0B20T03`D600l51P0400l51P060147200S6AX05@/<00l51P0G
3@h04PP90`0@1PL201882@030147200>10D03P@500@03P@51P0?1@H01P0B1PX040@801L;3`0G2`l0
3P8600l31`8040@800@040H801862P0h;3005@/=5?ooool001_ooooo00D02`/9010@3P0>3P`03`l=
018B400300l?3@0V01<C4@0B4Q003Ph<010@3P0<30X03`l=014A3`0B4Q00410>00d=2`0:2PP030`;
01dM6`0@40h04a<A00h>300=3@/04A4?01<C4@0A4@l02PX800H6100=3@/02`/900X:200F5Q@02@T7
018B400>3Ph01`L700T92@0?3`l04A4A01<C4`0@41003`l?00h>3P0?3`l2010@40803@d;00/03Ph<
00l?3@0?3`d03`l=010@3P0>3P`03@d;00h>300A4@l04a<A01@D4P0201LF50030000000D51804A4?
00803Ph<02T03Pl<00d?300>3P`03@h900h?2@031000414>01LG5`0B4Q@0A4A6018B50051@D051@B
00L80`0=3PP02PX600h>300C4a404A4?00/;2@0<30X03@d;014A3`0<30X03`l=018B40092@L02`/9
00P81P0>3P`04Q8@00d=2`0820H030`:00h>300@40h04A4?010@3P0>3P`03`l=00h>300200d=2`08
00h>300@40h030`:00l?3@0E5A<05QHD018B400;2`T500h>300D00l?3@061P@010@200X:200V9R@0
QHF3028R800B4Q0010@200/;2@0:2PP03Ph<00l?3@092@L03@d;00P81P0L71X0<30^00h>300?3`d2
00h>30803`l=00<030`:00h>300>3P`0100>3P`0100?3P`03@`:00`;2@0=30X200l>300300/:200>
3@/03`h<00803Pd;00P040l=00T:1@0<3@P02P/600/<1`0B4Pd04A0<00d<20<03`/800`040/800l;
20072`L0004000<50P0<3P/051@B02<S8@0@40h040l=00l>300>3@/200h:2@0400l>300A40h04A0>
00l>30803Pd;00H040l=00d<2P0>3@/040l=00l>300=30X200h=2@0<00d<200<2`L030/700d<200>
3@T020L300h=2@0;2PH02PT5014>2P0C3PX040`90P0?2`P0200=30X03Pd;010?3@0820P02PX:00d=
3@092@T03Pd<0P0=30X200h=2`0800d<2P0<2`T030/900h=2`0@3`d03Pd;00`;2@0;2PP200`;2@0?
00d<2P0>3@/03Pd;00l>300>3@/030/900d<2P0@3`d03@`:00d;300F51D09B<T01lM7P0E4a@04Q0A
00D03P`=00d03@/<01XI5`0F5A<0518C01<A4P0?3@h03P`?00l=400>30l03P`A00l=4P0A3a@0518G
00<040hA00@03`d@00h<3`0<2Pd040hA0P0A3a802P0>30l03@/>00h<3`0=2a003P`A00d;400;2@h0
30X?00l=4P0@3Q<300l=4P04010>4`0B41D03@`A00d<4@8030/@0P0;2Pl02P0920d02PT>00T83@09
20d03PdB01@C600C4AH04@lD00h<4@0=2a0800h<4@803`d@00L040hA00l=400<2Pd02`T<00`:3@0=
2`h040hA00803@/>00/04@lB00l?3`0?3`l061PH01`L700@41002PX:00P820092@T03Ph>01@D5002
01HF5P0<00P81`0A4@l00@4001HF500A4@l00`<100T91`0G5aD07QhL00l?3@0@40h04Q8@0P0<30`0
1@0@41003Ph>01<C4`071`L0410@00805QHF02403Ph>01dM7@0=3@d030`<00l?3`0>3Ph02`/;00`<
300@410030`<01PH600?3`l03Ph>00X:2P0C4QH04A0E00H6201UIF@03@h900/<1P0=3@H05AD=00h=
200g=S808b8N00l>2P0C4Q0030/901XI5`0V9B<05aHD01@C4@0@3`d00P0A40h02@0B4@l04a8@018A
3`0B4`h04A8=014A3`0@40h03`l=00l?3`0201DE5@0501@D5P0C4aD04Q8D00h>4@0?3a400P0@4102
014A4@07014C4P0/;Rd08R@S08N;RP0>4Q4061`K01/Q7`04018D4@804aDB02/02`d:01TK600o@Ch0
7R0M01HH5@0@4Pl03`l=01hN700L71X051@B018B400D518030`:00h>300A4@l03`l=01HF500B4Q00
71hK01LI5P0E5a@071hK01hP7@0A4a003a4>01HH5@0B51407AlL02PZ9`0C5A80828O01lQ7@0G6A@0
61dI00dB3@0H7AL07R@P01`R7@0I81T05b0K01TS700L9B007R@S008072DT0P0M9BL0200L9RL09S0b
02Pa=P0L9b/07bX^01/V:P0H9RT072X[0P0M:b`0A00S<C@0:SPk02dj@00^>d80<Sm7055NIP0lBE80
6BH_02Tc?00W<3L0<CY102`g?@0V<CL09c8h02Db>00W=CP09SDh024`<`0W=ST08C<e02<e>@0U>3l0
;3m602`oA00X>cl093Pi024e=`0[?T80;3m502Lj@P0fB5@0=TQF02hoBP0a@TX0<D9<02hoB00/?DL0
;Sm90393C@0dADl0<D9<02hoBP0dADl0>d]H03Y:E013DE`0EVA]03]9D@0V=C`0;S]102Te>P0W<SH0
92la02H`<P0U;c009c4`02<_;P1YMgL0]L?404QFE`0_?Ch09C<e0;K4a`2Q[[@0>4E;020]<`0M:S00
934h0P0U=3T08`0[>Sd0:CLj02<a=00T<S<08B`^028];`0K9bL08R`]01hX:@0P:RX072DT01XS800I
8R406b<V01`T9`0K8RP072<Y01dT:P0P:2/08BT[024Z:@0P:2P07BH_01`T<@0M9S007RD]01XQ9`0J
8R@05a`O01/P800I7Ah06AdP01`O8`0G72007B8U00804QXL02P0724T03Hk?P0P9BP07B4T01DH6`0H
6Ad07AhR01LH700M7R805aPJ01@E5`0J6ad07QlQ01/L7`0J6al06AXO01DF6`0L7B805aLO01hN9P0>
3a@06a`Q01TJ7P0F5a/051DI01<D600B4aL05aPL01PI7@0G61`05QLK01@E6@0B5QT04ADL01@G700>
4AH06ahS00`=4@0T9BT051DI0P0D51H05P0C4aD04Q8B014C4P0E61D030h;03m1?P0Q8b004A4?01LG
5@0@40h04Q4?01HE4`0I61H05A4@010?3@1OH5h07R0M00`>2`0A4a004a<A00l?3@0=30X201<B4009
02LS8P0V8R404Ph=01@@3`0C3`h04Ph=020L6`0M6AP04@d<00D040`;00@040/;00l92`0@2P`04@/=
0P0B30h00`0?2@/04@/=01@>400200l92`0C010:300?2@/05Q0B01H@4P0C3@l02`D701XD5P0@2P`0
4P`>030Z;016@4809R0R01@>40091@D02`X800l92@0A20T040L80147200201D;300:01@;300?2@T0
2@D400h:2P0H3a002P0100h41@0C2@X050X;014720L03`D600P04`T:00l51P0B20T0308300h51@0?
1@H040H700l51P803P@500<03`D601061`0@1PL0100@1PL600l51P0<0104200>0PH06@dA01X>4P0@
10P04`L;00`0100>0PH05`/?0104201JCU808ADI5?ooool001_ooooo00d02`/9010@3P0?3`d0410>
01<C4@0@40h04A4?00h>300?3`d03Ph<00`<2P0B4Q003Ph<00@0410>01T03`l=00`<2P0B4Q004A4?
01DE4`0?3`d02`/900d=2`0A4@l04Q8@010@3P0:2PP01`L500l?3@0<30X0410>014A3`0<30X03@d;
020P800E5AD03@d=014A4@0:2PX0410@00803Ph>00@03@d=00l?3`0@4100410@0P0=3@/0100>3P`0
3`l=00l?3@0?3`d300h>300300l?3@0@40h040l=00803P`:00@05Q@B00l>300;2PP03@d;0P0=3``3
00`@300D00d@2P0@4@/0:b`W07]kN@0?3`l04a<E030`<P0A4A<051@D00`<2P0<3@P051D?00d>2P0>
3P`05ADC01XJ600@40h02`/900l?3@0L71X200h>300:01@D4P071`D0;Bd[030`;P0>3P`03`l=01<C
4@0>3P`03@d;00h>30<0410>0P0?3`d0100>3P`03@d;00d=2`0>3P`2014A3`0400l?3@0<30X02PX8
00/;2@<03Ph<0P0=3@/05`0>3P`04A4?00/;2@0E5A<03`l>03Xj>02MWI/06ATH010@3P092@L0410>
00D50`0D51803@d;00L71@0B4Q002@T700`<2P0H61H020P600h>300<30X02`/9008030`:00<02PX8
00h>300>3P`0100>3P`2014@3P8040l=0P0A40h03@0;2PP03Pd;010?3@0>3@/03`h<010?3@0?40/0
4A8=00/<1`0:2`H03Ph900/:1P0>3@T00`0@30T02@0A30T040`900`@2`0:30X04Q@@00d?2`092@H0
3Pl;00l?300300l>2`8040`:00l03`h;014@3@0@3``03Pd:00d<2@0>3@X04A0=00d<2@0>3@X04A0=
00l>2`0;2PL03Pd9010?2`0?3PX00P0>3@T04`0?3PX03Pd900/:1P0?3PX04Q4=00l>2P0@3@T04Pd9
010<2@0>2PL03`/800l>300=30X04Q4?00l?3`0>3Ph030`<00T92@0?3`h0100>3@/200l>30<03Pd;
00<03@`:00`;2@0<2`T00P0<2`T200d<2P0500h=2`0@3`d051<A018A3`0?3P`00P0C4Q002@0=2``0
30X;00d;300@3Pl03`h>03Dc=00<2P/03@/<00l=3P02010>3`0>00l=3P0@3`d03Pd;01<A4@0E4a<0
40h>00l=3`0A3a8040hA00l=4@0>31403`dB018@5@0@3Q4200h<3`0A00l=400>30l02`T<00h<3`0?
3A0040hA00d;3P0<2Pd03P`?00d;400>31403@/@00/93P0<2Pl03`dB014?500=31400P0?3Q<00`0=
2a0040lD00`;400200d<4@<03PdB00H04Q4F01<B5`0@3a@03PdB00d<4@0?3Q<300h<4@803@/@00<0
30X?00h<4@0>31400P0?3A8200h<4@0A014?4P0<2Pd03`d@010>4@0=2`h03`d@00d;3P0>30l04@lB
00d;3P0;2@`03`d@01<C4`0;2`/03Ph>014A4@0?3`l00P0@41003`0=3@d0410@00h>3P0:2PX02`/;
010@3P0>3P`0410>00d=2`0Z:RP0S8b:024Q7`0>3P`0410>00/;2@02014A3`0Y018B4@0J6QT06QXI
010@3`0D51<0<S8a01`L6`0D51<0OWim02/[:P0?3`h04Q8A01DE500F5QD04A4@00d=300@40l051@C
01DE500?3`h030`;010@3`0=3@`03Pd>01HE5@0;2`X0?3di014B3@0;3@L03Pl801LF400A40`05Q8>
014=300K5a@04Q0=00l>300C4Q0040l=00h=2`0C4a400P0>3P`0100?3`d03Ph<00h=2`0@40h201<D
3`03018B400@40h0410>00803`l?00P04A4A01<C5@0C4aD04A4C010?4`0@4180410@014A4@804Q8B
00L04A<B01HH5`0>40l0RHf<0496A@0B5QD0318@00805QPE01/051HC018D4@0A4a00418?01<E4P0J
71T0?Cll020R7`10@Sl07b4N01DF500N7ad06Q/I01@E4`0C51804a@A01XK6@0B4a004a@B010A3`0G
61H051HC01PJ5`0G6aL05QXF01/O6`0M8Ad00P0C5a<08@0I71T061/H01lR7`0U:2D05aXG01hR700D
618071lJ03Hk=@12B48082HP01hU7P0L91d06b@L01XT700J9Ad06bDO01dV9@0M9RH07BHX01hW:@0P
:R/082/^024/;`0Q;34082`a01TV:`0Q;S<07B``02<`>00U<cX08Blf028`>00202Hd?00V02dj@`0^
?4H09S<m02Hd?P0/>DD0:CI002<_=`0a?D<0<3a202Xf?00R;cD07BX`02Xh>`0U=3L07Rd`02@c=P0R
<c@09cLj02Hg?P0[>d80:Sa002i1A00^@D<09STl02@g>`0U>3l09SQ302i0C@0^@4l0;T1:02`m@`0V
=cl09CHn02Pi@00X>D80:ca603A5C`0gAe@303=3D@0Z02lnB`0]>dH0:cU202lmA@0eA4/0;ca202@`
=@0V<CD09S4c02D_<@0U;c00:38a02Tf=@1BHF00?Te;02Xi>00I:2P09C@d03A3A@0eA4H07B`_02Le
>P0R<3@08Blc02/i?@0U=3P09C<f02Le=`0U<cD09C8c01/W:00R;Bh0:3<c038l?00W<C406R<S01XS
800I8Ql06b@S01lW:P0Q:B`082L]0P0R:Bl0:@0Q:B`082PZ01lX9`0O:2H08B/^020Z;P0M9RT072@U
01`U9P0N9bH07B<S01/P8@0T:2T092P[01TM800I7R807B8U01TQ8`0R:R`051TL020U:00C61/061`O
01PK7P0_<3@09BHZ01dN8P0F5a/07AhP01DF600F5aT05aPJ01DF6@0F5a/07QlT01HG700O82D07QhV
018B6P0P8BH05QLL00<061TM00l06AXN01PI7@0B4aL05QLK01PI7@0F5a/05aPL01LK7P0C5a`06ahS
01<F6`0?4aL051DI01HG6`0E5QT00P0E5AL08@0D51D04a<C014C4P0?4`l092HS09BFT`1HFUL03Ph<
01@D4P0C4a405QDC01TH5P0B4@l05Q8A01hM6`1GF5H06Q`I00`>2`0@4@h04A0>00h>300D4a403``;
00d;2@0G4a806ADD01DA400C3`h02`L601DA400^:RT09B4P010<2`02014=308040`;00@03`/:010;
300A2`d040X<0`0A2`d08@0@2P`04@/=018<3P0D3Q00618D01H@4P0A2`d03`T;010:300N61X02`D7
01<=3`0@2P`030H8010:300?2@/02@<5018<3P0@30`03@`:014;2`0C2P/04PT:01<92P0>1PH03P@5
01482@0:10@02PH507YfM@0g;Rl07Q@E01882@0200l51P030147200@1PL040H700@040H700`03P@5
00l51P0?1@H05@/<00d3100A1`P03@<400l51P0@1PL03`D601061`0E2``601061`H03`D600`040@8
01452@0A1@T04@D90104200?0`L04@D90104200900406PhB01<82`0@1PPDooooo`006oooool0300<
30X0410>00l?3@0@40h04a<A010@3P0A4@l02@T700h>300D51804a<A00l?3@80410>0P0>3P`02@0?
3`d0410>018B400B4Q0061PF00/;2@0=3@/04Q8@00d=2`0200`<2P0?00d=2`0>3P`03Ph<00/;2@0:
2PP051@B00/;2@0C4a4030`:01LG5`0?3`l01PH6010@400:2PX04a<C00<030`<00<03@d=00h>3P0?
3`l00P0=3@/00`0>3P`03`l=00l?3@0200l?3@0<01@D4P0G5aD05QHD014A3`0D4A004`d=00l;2P09
1@@06aLF00X91`0A4@l03@l<0`0;40`0400:40`03A0;018C3@0?40/0J6QV014A4@0G5aT061PJ01lO
8@0A4A404Q8@00X;1P061`404a<?00/;2@071`D200/;2@0700d=2`0;2`T04Q8@00D50`092@L05QHD
00T91`0201<C4@04014A3`0?3`d030`:00l?3@8030`:0P0=3@/01@0>3P`03`l=00X:200<30X03`l=
0080410>00P03Ph<00X:200<30X03`l=014A3`0@40h03`l=00h>30<03@d;00/03Ph<014A3`0E5A<0
1PH401DE4`0@40h02PX8010@3P0C4a40000001@D4P0200/;2@0:014A3`0@40h01PH400h>300A4@l0
2`/900h>300C4a403`l=00h>30803`l=00<03@d;00`<2P0<30X0100<30X0100<2`T03`h<00l>300>
3@/200d<2P0=00h=2`0@3`d040l=00h=2`0<2`T03@`:00T:1@0<3@P02P/600/<1`0B4Pd04A0<00l>
2P03014=2P09018=2P0A3@X03Q8<00h@2`0<3PT0418=01PI500>3`X03@h900<03`h:00<04@d:018>
2`0=30P00P0?3PX05P0<2`L02`X600`;1`0@3`/02PT500/:1P0@3`/03@`800P70`0>3@T04Q4=014@
300>3@T03`h:014@300<2`L04A0<00h=2@0B4@d040l;00h;1`0A30P200h:1`0<010<2@0@3`d03`h<
01<B400=3@d02@T900d=3@0E5AD071`K014@3P0?3P`03Pd;0P0<2`T2010?3@0400`;2@081`D02PT7
00h=2`804Q4?0P0A40h200l>300600`;2@0A40h04a8@00`;2@0=30X02`X80P0?3@h01`0<2P/03`d>
00`:2`1?CDh02PP900/92P0>30d00`0@3Pl02P0@3`d03Pd;010?3@0@3`d030/900l=3P0H5QT05Q@G
018@4`0?3A8200h<4@09014?4P0?3A003P`?010>4@0?3A002`T<00`:3@0=2`h03P`?008030X=01/0
3P`?00`;400=314030/@00X93P0;2Pl03PdB014@5@0<2a0040lD014@5@0?3Q<051<H01<B5`0B4AH0
3`hC00d<4@0;2Pl02PT>00/:3`0>3A803`hC00d<4@0<2a003@`A00d;400?3A800P0A3a@0100@3Q<0
3P`A00d;400>314200l=4P0U00h<4@0=2a004Q0C00X82`0=2`h03`d@00h<3`0B41<030X=00l=400C
4A@040hA00h<3`0A3a804A4A00/;2`0=3@d030`<00X:2P0<30`03@d=00/;2`0B4Q8051@D014A4@0D
51@04A4?018B40071`D051@B00@40P0b<S0061PF02PX9P0`<2h051@B00d=2`02014A3`0l02PX9P0W
9bD04A4?01/K6@1NGU`0<c<a018B400[:bT05ADC01TI5`0<30X04a<A018B400:2PP01PH400/;2@0@
40h04a<A00H6100B4Q002PX8018B400G5Q@01`H201dL600:2`P06Q`G00`>2@0@4P`05aPB00L60P0?
2`P06aHC02HN700I5Q<051@B01TI5`0?3`d04Q8@01HF500<30X03Ph<014A3`0<30X02`/9014A3`0D
5A004a@?018B400A4@l0410>00l?3`0A4A404a<C01HF600D51H04A4C00l>4P0B4Q@04Q8B0P0C4a<0
900D51@04aDD01/M70082PT0<CDd00`@3`0F6QT03aDC00lA3P0@4Pl04Q@A01@F4`0E5a@05aTF010B
3`0H6QL03a4>018D4@0R92406A/H01dO700F61D03Q0=018D4@0H6QL04Q@A00`>2`0L7Q/0418?02<U
8P0>40d06A/H00hC3`0I7QX061dI01<H508051TE00<04QLC01@I5@0F6aL00P0I7QX01P0D6AD03a@>
01lT7P0Y;RP0Ada606Q^I`806B0I02406B<K01/U7@0M9al07BLO01`W8@0L9RL06bDW01`V:00N:B/0
8B``028]<@0S<3<0;S]103i;D@0U<cT08c8g01DT:`0U=3l0:cU602<d?P0T<cl0:3I102@e?`0Z>T@0
;ce802XkA@0Y>4D0;C]802hlA`0X=cl0:CHn02@a=`0U<SP00P0Z=cd0@@0Z>C`08c8e01XY;00Q<C80
8c<c02Ti>@0/>d00:cXo02Lf>P0/?T00;Cm102i0@`0]@4H0:ci50312CP0_@Dl0;d1@03A5D00a@dL0
;3i202Tk@00/?D@0;d1802m0B@0dADl0=DED02loCP0`@4l0<41@02hmB`0c@D`0:CM002Tg?`0U=3/0
7R/a02di?P0/=c/092la024/;@0V<3409S0_02Ld<P0L;2T0=DE202Hf=00^?Sd07Bd/01l_;`0Q<C40
9CDe02Dd=`0K:Rd0:STl02`j?@0S<C@082ha02Le=P0V=3D08bh`02@`<00U<C408bd^02/e=00T;Rd0
7BHU008082TV00X082TX028Z;@0R:Rd07bH/020W;@0O9R`07RHY01lW:@0P:BP08b`Y0P0K9R805`0F
8Ad05AhK01TR7`0N9b@08bTY01/P800^<S<0;30c01HJ7@0K82<092T/01<K7@0R:R`04QLJ01hS9P0J
7b807B4T01PJ7P0?41@0;Bhb01HG6`0H6Ad05aPJ00805AHH00X051DG01PI700V9b/0414F01hO900C
51T06a/S01PH800B4aP05QLL0P0H6Ad0100G61`04a@H00l@500E5QX201TJ7P8051DI02X04aLJ01DI
7@0F6Ah06ahS00hB5@0E5QX051DI01PI6`0G5aT05aLG01HF5P0D51@04aDD01LJ5`0<3P/071hK01LI
5P0A4@l0410>014A3`0@3`d04A0>01XI5`0E4A002@P601@E4`0:30T04Q@A018B400B4@l05aHD04A3
@@0V8R405a<B00h:2@0?2`X0510?014=300C3`h0510?00T5100:1PD3014=3004010<2`0?2`X03`/:
014<30804@/=00<040X<00l92`0?2@/00P0?2@/04`0>20X04P`>01TC5@0C3@l03`T;00L10`0L5QP0
Dde?01`F600=1`T030H8014;3@0F41803@P900T31@0=1`T030P800h=2`0B30`00P0D2``03@0D2P/0
308300l51P0=10D0618B00X61@0E4A406Q4B00X00@0>10D03`D600`20`0A1`P01P0@1PL01@080000
5@/<00l51P0?1@H04PP900803P@500D040H700l51P0;0@802P0100l51P0600h41@H03`D600D05`/?
01X>4P0=0@D02`0301452@0200`010050106200C1`/02`0301<92`0800005?ooool001_ooooo00@0
4a<A018B400A4@l04A4?0P0@40h03`0C4a403`l=00P81P0;2`T04A4?00/;2@0<30X03`l=00h>300<
30X04a<A01hN700/;2X03Ph<018B4002014A3`0800l?3@0@40h02@T700L71@0H61H04A4?01LG5@0?
3`d200d=2`0R00h>300?3`d03`l=00d=3@071`L05ADE01@D500000006ATI014A4@0:2PX02`/;00X:
2P0820P02PX:00/;2@0K6aT09RHT01LG5@0A4@l03Ph<010@3P0J6QP0:2PV01TI5`0;2`T04Pl>01D?
3`0E4A003`/:01DA400920H03Ph<00d?30<02a0<01@02Q0<00`?2P0A4P`05AHA01DE4`0?3`l02`/=
00X:30071`T02PX:018B400>3`X03Pl9010@300=3@/0410>018B400A4@l03`l=00h>30D03@d;0100
3`l=010@3P0@40h03@d;00`<2P0;2`T03Ph<00T91`0?3`d03@d;00l?3@0:2PP02`/900`<2P0K6aT0
71`J0P0>3P`0200=3@/030`:00d=2`0;2`T02PX800d=2`0?3`d0410>0P0A4@l3010@3P0600l?3@0>
3P`030`:00`<2P0;2`T09RHT0P0<30X07`0A4@l030`:00d=2`0;2`T03`l=00d=2`0:2PP0410>01XJ
60071`D04Q8@00`<2P0];B/061PF00h>30071`D04Q8@00T91`000000410?018B400G5Q@020L500X9
1`0E51803@`:01HE4`0B4@l040l=00d<2P0<2`T00P0=30X01`0720<03a0;00L80`0>3`X02`/600l>
2P0;2PH00P0=2@H0600?2`P040/800d91P0=4@X00`H001/N5`072P<04A8<01DF400=3PP02@P301LF
4@0?3PT03P/600l<1`16AD0051<>018A300;2PL02PT4014@2`0=30L030/600/:1@8030/600<03@`7
010?2`0?3PX00P0>3@T200`;1`0700d<200>3@T04A0<00d<200<2`L03``800l:1P0300h:1`0/00`;
2@0F5A<00@0001DE5@0820P0410@04E5A@20P7l05QDC00d<2P0@3`d02PT700T81P0<2`T02PT700d<
2P0?3P`03@`:00X91`0<2`T01`H401@C4@0@3`d02`X800`;2@0=30X03Pd;014@3P0>3@/04A0>00l>
300A3a003`d>00d;300>30d03`d>00h<3@071@H03@/<018@4@0<2P/02@L800d;300H5aD200/:1P0?
018A3`0=30X03Pd;00X82@0@3Pl04Q0C00h<3`0?3A003@/>00X82`0=2`h04@lB010>4@0>30l03@/>
00<03`d@01D03P`?00d;3P0=2`h05QDJ00/:3`0a<3D05A@I00D52@0M72402@P=01PG70061@X06aXO
00l>4`0100D02`X?01PG700>3A804a8G01@C60040`P00P0?3Q<0200@3a@04Q4F018A5P0?3Q<03`dB
00`:3`091``05A<H0P0?3A807P0>31402`T>00X83@0=2a005aDJ01lM8P0;2@`03@/>00`:3@0:20/0
30X=00d;3P0?3A002`T<00d;3P0B41<00@0200l=400A4A404a<C00h>3P0820P030`<014A4@0<30`0
2`/;00d=3@0A4A403@d=00X:2P803@d;01003Ph<010@3P0A4@l04Q8@010@3P20P7h0Ng]i01dM6`0I
6AL01`L5010@3P0J6QP01`L501LG5@0S8b4051@B200?3`d01P0@40h04A4?014A3`0C4a405QHD01@D
4P803Ph<01D03@d;00`<2@0?3PX040l;00d>2@0:30L02`d800hC3P0@4Pd05ADC010=300=1`L0610>
01HC4@0820H01`L500T91`0S8b40000001DE4`0B4Q000P0@40h0200B4Q004A4?00/<1`0C50l051@B
00l?3@0A4@l0410@0P0=3@d01@0@41803`lA00h>400L71l071`N00802PX:00l0820P01LG5`0F61L0
6A/J01@F5@0C5aH0310?00hB4@0D6QP05ALD018D4@0>40d0418?018D4@0@4Pl00P0B51401@0A4a00
3a4>01DG500I6aP071hK0080418?00l05ALD01LI5P0I6aP04aDB018D4@0C5A805QPE01TK600H6QL0
4AHB01TO6`0C6AD01P`801TO6`0E6aL00P0G7AT0G@0H7QX06R0L01TO6`0F71P05Q/E01LL5P0R9b40
7RDN028Y8P0L8a`05b4I01TS6`0M:2006B@L01LR6P0S;RP072PZ01`W:`0O:Rh07RT]024/<P0R;cD0
:cTo05i]M03Ij>l0;Si501`]=00T=Cd0834m02LgAP0Y>dL0:ca902`lB@0/?TX0:ca802Hf@`0S=D40
:S]702@d@@0Y>T@07c0g02Xi@00_?TD093<j0391AP0kBTl0:STl02@d=00X>3P07Bd]02Lg=`0Q<C40
9c@j03=0AP0a@4<0EFAW04EDE`0eAdX0<D9902e0A`0Z?4P0=4EE03M:F`0`@Td0;T1402Li?@0W>Ch0
;Sm60393B`0a@T/0<D9<03A4D`0a@E00;3a;02/kB`0c@U00<3i902Hd?@0O;SH093<j02/h?P0^>Sl0
9c8f024/;P0O:R/08bd^02H`;`0U<S00:SXg02Hf<`0V=S@09SHe01h^;@0202Ti>@0502<c<`0U=3L0
8S4d02Th>`0U<c@00P0V=3D01@0X<cD09S4c01/W9`0Q:b`082X[00<08BXY02407RLT01/T8@0L9B80
72DT01/S9P0]=CP0;SDk01DL8P0Z<CL09Rha01@L7P0M9RD072DQ01/V800J9Ad07BPQ01/T7`0F7aX0
6R<P01PN7P0M8R<082@U01lS900M8B806b4Q01XO8P0G7b405QhP01PM800F6ah04QLJ01PL7`0I71l0
100J6al03P0J6ad05AHH01<D5P0F5aT06Q/N01TJ7P0D5AX07b0U01DF6`0G5al06QXR014B5`0E5Q/0
61TM0P0E5QX00`0H6Ad05AHJ01LH700201<D600801PI7@0F5a/04ADH01HJ7@0G6ah051PK014E600E
5QP201TJ700D01HF5P0A4A404A4@01<C4@0B514041@@00d?300>40d04aDB018B400>3P`04Q8@01@C
4@0C4Q004A0>01<?3P0B4@l04Q8@014A3`0?3`d200h=2`0:00l>300F4Q40510?01<?3P0B30`040X:
01<>3P0D40l04@d<010<2`803PX900l04Ph=01<?3P0E4A0061@C00h:2@0=2@P050l?00`6200B30h0
50h@00/51`0A2`d04`d?00@0000A2`d00P0E3a400`0=1`T05@lA014;3@02010:3004014;3@0C3@l0
FUAF00@000805Q0B01<040X<00P2100=2@T04A0>00l92@0=10D04@P90147200?1@H04`T:0107200<
1PH03`/:00d920070000200001061`0>10D05@/<00804`T:00X04PP90147200?1@H03`D600h41@0D
2P/0308300h41@0A1`P02`421`0?1@H03`0900004`T:01882@0E2``03@@400P0000<0P<05@/<00P0
000;0@803PD500h41@0K3a<06PhB01@8300200l31`0301<72`0A1@T04@D900@04@D95?ooool001_o
oooo0P0@40h400l?3@0L00/;2@0=3@/02`/900`<2P0A4@l03Ph<018B400D51804A4?00d=2`0?3`d0
51@B01DE4`0<30X0410>00l?3@0C4a402PX800d=2`0D51805aLE02@T8P0A4@l03`l=014A3`0?3`d0
3Ph<00d=2`803Ph<0P0B4Q801`0?3`l02@T901LG5`16ATH05QHF00d=3@0>3Ph00P0=3@d01@0@4100
3@d;01<C4@0H61H03Ph<0080410>00`03Ph<010@3P0C4a403Ph<00T91`0C4A000`4001XH5P0@3P`0
40l=018A3`0>3P`200lA3P0B00d@3@0;3P/02Ph:00h@2`0?40X030d800`=2P0>3Ph03Ph@00l?4@0N
7R008R8R014A3`0@4@`04A8<00`<200=3@/03`l=0P0@40h200h>30D03`l=0P0@40h200l?3@803Ph<
01803`l=01HF500<30X030`:00X:200@40h03Ph<00`<2P0C4a404Q8@00X:200@40h02PX800`<2P0=
3@/02`/900X:200<30X200d=2`803`l=00<03Ph<00d=2`0>3P`00P0>3P`300d=2`05020P7P0A4@l0
4A4?00h>300@40h00P0=3@/05`0@40h03@d;00/;2@0?3`d05aLE014A3`0@40h010@201PH5P0<30X0
2PX8018B400:2PP06QXH00T9200>3P`020P601dL6`0B4@l02`X800H50`0B4@l03@`:008040l=02<0
3`h<00h=2`0=30X030/900d>2@0<3@P02@X500/<1`0=3@P03`h:014@300?2`P03PX700l;200B3@X0
4@d:00/?20082`@03a8;01@G401<CDL0H65K02HW8@0F5A004A0;00d<1`0C40/03P/600l>2P0:2@@0
30/6010?2P081`803Pd800d<1`0300`;1P803@`700@040l;00l>2P0>3@T03Pd90P0<2`L01`0=30P0
30/7010?2`0<2`L02`X600h;1`0?2PH00`0>2PL02`0<2`T06APF00d<2P0>3Ph03@d=010@400=3@d0
6a/J00X91`061@<03Pd;008030/90P0>3@/02P0@3`d04Q4?010?3@0>3@/02`X801<B400E518040l=
01@C4@0@3`d200l>300500h=2`0<2`T04Q4?00l>300>30d00P0=2``01@0@3Pl04Q0A018@4@0?3@h0
3P`=00<03@/<018030X:00/:200@3`/02`X601<B3`0510403`h<02/Y:@0S8B404@lA00/92`0@3Q00
3`d@00d;3P0?3A004a4D014?4P0@3Q4400l=40803P`?01H03@/>00X93P0<31003`lD00h>4P0>3Q<0
3PhB01`L800M7B40LW9f03De>@0C4aP04Q8G00l>4`0=31402PT>01<B5`0J6Ah0@T5600h=4P0=3140
3PdB0P0@3a@0800=31401`D:014?500610T04a4F010>4`091``04Q0E010>4`0>31403`dB01@B5`0H
5Q/030X=00l=400@3Q403P`?00d;3P0>30l03`d@00d;3P0K6A`02@P:01PF6@0A3a803Ph>00l?3`0=
3@d02`/;00`<300>3Ph03`l?0P0=3@d00`0A4A404Q8B018B4P0300h>300?010@3P0A4@l04Q8@018B
400F5Q@04A4?05]KF@0820H05QHD00l@300F5Q<01PH300h>2`0D51403@h:00H0414=00<0410=010A
3@0@4@d00P0@40d06`0A4Ph05ADB01<D400?3``04A4>014B3P0A3PX04`l;01@@3@0?40`02a0=00`A
3P0<4a802a8A010D4`0D51D05Q@D01HB4P0F51<05AHD00`=2`0F5a@03@h;00`=2P0F5a@051DB014B
4002018C4@0400l@3P0E5Q406Q/F01TI5`804a<A0P0B4Q804P0A4A4051@F01<C5@0?3a404a8F01TI
6`0B4Q804a<C01DE5@0A4A404Q@C01@F5@0C5A@041@C00hB4@0C5aH0728P01@F4`804Q@A01`05QPE
01PJ5`0I6aP03a4>01@F4`0E5a@04Q@A01DG500C5A803Q4>01@H500I7AT051PD00lC3`0F6QH05QTF
01@H500E6AD05QTF01@H500?510061hJ01@J5P0E6aL04QPD01@J5P0J81`051XF0`0F71P0QP0I7a/0
728N024W8`0H7QX06b0K01PN6`0O9b806R@M01XS7`0F8A/06bHO01dY900N:R<08BdZ028]<@0Y=CX0
9c<h02Db=P0K:C008S4g0391B00gAdh0=DI=02Hh@00G:C80:C]5028d@P0W>DP0:C]:02PkB@0W>DH0
9cY702TlB00U>4808cI002TlAP0S=T009cY302@f?P0[?DD0<TA;02Pi@00Y>Ch09cLl02hm@00Q<C40
7Bd]024`<00T<c<09C<c02Hc=`0^>Sh0:cPk03e;C@0_?T40:SXo02Pi@@0[?DL0:3Y70312D@0hBe`0
<dEA02`n@`0U=Sh093Dl02Tj@@0]?TL0;Sm902dnB00[>dP0:3Q602TiA`0^?T`0<D1=02/iA00W=Ch0
9SDm02Th?`0[>3h0:cLl02Lb=P0S;S008bd_02La<P0X<S40934_02@e<`0R=3408cDc024b<P0T=CD0
:c`m02Tj>`0S=3H093@h02Df>@0Y>C`0;C/l02Xf>00T<3808Rd^024/;@0N:BX07bPX01lX9`0N9bH0
82LV01lW9@0N9R<07bPU01hW900U;Rd08BT/02D]<00S:S008BP^02/b>00[<cH08RX/02</:`0N9b<0
7BPP01XV700L9al072DP01PQ7@0N9bD06AlP01dR8`0M8B806alO01XN7P0J81l061hO0P0F7R0201XO
8P0301LL7`0G6ah06Q`P008071dQ01006a`P01TJ7P0H6A/051DG01<D5P0E5QP061TL01PI7@0Q8RL0
EUML01LH7@0I6B4061PP01@E6P0E5Q/061TM0P0E5QX0300H6Ad05AHJ01DF6P0F5a/05AHJ01HG6`0E
5QX04aLJ01@H6`0C5aX04QHI014E5`804a@F01804aDE018B4P0D51<061PF01<C4@0=3``03a8?01<E
4P0A4a003a4>014A3`0C4a40410>01<B400B4@l040l=018>3@0A40h201<C4@0@014A3`0?3P`04@h=
018@3P0C3`h05A0?01HA400I4a<06Q<C01@?3P0A3@`04Ph=010<2`0C3`h040`;00d9208040`;00l0
4Ph=01<?3P0C3`h04`h>00d72@0A2`d04P`>01<=3`0E3a4040X<01<=3`0A2`d040X<00T31@0L5QP0
0`0?2@/06`0@2P`04@/=014;3@0E3a406aDG00X51P0B30h02`D700d72@0@30`020L600X4100@1`P0
3`H70147200?1`L03`D601D<3@080P804Ph=07EaL00i<3405P`=00h51@0A1`P02P0100h41@030147
20<040H700H03P@501061`0A1`P03P@500d3100>10D600l51P804`T:010030830147200=0`@05`d>
01882@0D2``060h?0147200?1PL03@<400l31`0A1@T03`<700d11@0>0PH04@D91P0@10PDooooo`00
6oooool05P0:2PP030`:00h>300?3`d04Q8@01<C4@092@L02`/900`<2P0B4Q005QHD00d=2`092@L0
3@d;00l?3@0>3P`03`l=018B400?3`d02`/901@D4P0<30X2014A3`07010@3P092@L00000014A3`0@
40h05ADC00l?3@0200h>30803`l=00d0410>00d=3@0C4a<05ADE01<C4`061PH05aLG00l?3`0;2`/0
3Ph>00d=3@092@T02PX:00803@d;01003Ph<00L71@0@40h03`l=014A3`0@40h02`/9014A3`0C4a40
3@d;01TI5`0?3P`03Pd;00X:200I6AL0410>0P0?3`d04P0>3``030h;00d=2`0=3PT030d700`=200C
4a405QHF010@4P0;2`d05aLI01XJ6P0<30X03Pl:010A2`0;30P02`/900d=2`803Ph<1`0=3@/200h>
300400l?3@0@40h0410>014A3`803@d;00/08R8P03lo?@0820H04A4?00l?3@0=3@/03Ph<00d=2`09
2@L0410>00/;2@0200l?3@0300/;2@0<30X02`/900803`l=0`0@40h00`0?3`d030`:00d=2`0300d=
2`0600h>300;2`T030`:00l?3@071`D05ADC0P0?3`d0100@40h03@d;00/;2@0=3@/2014A3`0Z00h>
300<30X04Q8@00l?3@0B4Q0030`:00d=300F5Q@00P8001HF500Y:BL0TY6?01PG5@0M71X06aXH00/:
200C4Q003Pd;00l>300@3`d03`h<00d<2P0;2PP04a@?00d>2@0E5Q402``7014A3@0?3PX03@`800l;
200@30T04@d:01@?300E4@h0310901@G40062@80;c8[0<[;a@3oooX0Kg1Z0P0E50l02P0?3PT01P<0
01<@2`0@3`/05A@?00T80`0>3@P02PT4018A300>3@P300`;1P0400d<1`0>3@P03`h:00l>2P803Pd9
0P0=30P00`0;2PH02PT500h=2@0200/:1P0300l<200@2`L03`/800803`/801P03@`:00L61@0=30X0
3Ph>00`<300>3Ph0:b/[01HE500>3@/030/9014@3P0>3@/030/900h=2`0?3P`04A0>018A3`0A40h0
3`h<00d<2P0H5aD030/900h=2`0=30X200/:20<030/900L03Pd;00l>300=2``030X;00d;300@3Pl0
4@l@008040h?00D03`d>00d;300=2``03P`=010>3P02018A3@0300L60P0P7a/02@P400805A@B00/0
4a8@00d;300?3@h05A<D018@4`0;2@`03@/>00l=400=2`h030X=00d;3P0500h<3`0F00h=3`0F5AX0
3PlC00d>4P0720`07QlS00`=4@0D5AT0FU]O0?3am@2EUYX06Q/O02<T:00;2Pl05A@I00T83@0F5AX0
3PdB00401@0=314030/@00d<4@803`hC00T03@`A01PF6`0:20d020H;01@B5`0:20d04a4F00l=4P0>
31400P0<2Pl200h<4@803P`?00<030X=00/9300>30l00P0@3Q40300=2`h07Q`O00l=40030@@02PP;
00d=3@0<30`03@d=00l?3`0=3@d030`<00l?3`803Ph>0`0@410300h>300600l?3@0@40h04A4?00d=
300>3P`02@T70P0?3`d01`0;2`T030d8014B3@0<3@P0414<01<D3`0@4@`01P0A4Pd2010A30<03a0;
03003@h900l@2`0?40/03@h9014B3@0B4`h04Pl;01H>2`0D3``03`l>00/A4@0<5A@04QdN014L7P0>
61X051XM00P<3@0:2`d061TG01DG500A4a0020X700lA3P0I6aP06Q`I01DG500=3``030h;00d?300?
4@h03Pl:010A300A4@l0410>014A3`0A4A404a<C00l?3`0B4Q@05QHH01<C5@0B4AD0000201LG5`0H
61P02@T901lO7`0P8R4202la<00401/O7P0A5A@0310?00hD4P803a4>00D04A<@01<E4P0E5a@05aTF
01PJ5`02028T8@0601/M6P0G6AH03a4>01@I5@0C61@05AXF0P0D6AD0N`0L8Ad04QLC014F4P0B5a<0
51TE01HK5`0E6QH03A<?014G4`0K8Ad02Q0<01DK5`0I7a/04QPD01XP700L8Qh06AlK01`R7P0S:BD0
7B<Q01XP7`0M8b405A/K01/R8@0J8b00628Q01LQ7`0I92006RHT01dY9P0O:b/09C8g03A1A`0I:2d0
9C@i02<b>@0X>D00FV]c051QJ@0^@DP09CM102doB@0G:cH09SU802/nC@0]@4l0;3m=02/nC00[?dX0
:cm902PlA@0V>T<0;41902Di@P0Y?DH093I002<f?@0W>T4093Ln02Tk?`0R=3P08c8e020`<00I:BP0
9C<c01/Z9`0T<300:38e02/d>@0Y=3L0:C@f01h/;`0[>Sl09cQ002XlAP0]?dh0>4]L04EGJ`0jCE/0
:ca402Df@00Q<S/08c@n02Hg@@0Z>dD0;3e702hoB@0^?TX0:S]502LgA00X=d80:SQ302dkA00c@DT0
<d99030m@`0X=3T08B``020[;@0R;Bh09Bl`02H`;`0U<c809CPf02Dg=`0R=3@07Bl_02@f=`0P<S@0
7S0d02Dg>`0V>3`0:Sa001h^=00S<C808Rd_02<^<00R;Rh07BTY01/U9P0K92<072DT01`U8P0201dS
8@0L01lU8`0V;b`08BXW02df=@0U;C007bLZ020W;@0R:Bl07bH/020X:P0Q:B/07BHU01XS7`0N:B40
6RDM01/V7`0M9R<06b@S024Y:P0M8RD07R8T01`P8@0I7A`06AhJ01XP700I7al05QhP01LO8@806b0S
00<061dP01HJ7@0I71l00P0L7B40100J6al061TM01LH6P0F5aT201DF600:01LH6`0G61`051DJ01<D
6@0K7240;blg00h>5P0U9R/05AHK01PI7@805AHJ02L061TM01DF6P0C51P061TM01LH700D5AT05AHJ
01HJ7@0B5QT041@G018F6@0H71d06AXL01HG6@0E5aH03`l=010@3P0A4@l0410>010B3`0>4Ph04Q@A
014C400?4@h04A4?01<C4@0@40h051<A01<B400A40h04@d<018>3@0C4a4051<A018A3`0@3`d04`l>
01DA400C3`h00`0D3Ph03P0E30d050h>01HB4@0B3Pd030P701DA400K5aH05A4@01@@3`0C3`h04@d<
01DA400B3Pd040/;0P0@2P`0:00:10H040X<01H@4P0?2@/04@/=01<=3`0D3Q002`D701D?4@080`@0
3@L900l92`0@2P`03`T;00h82P0=1`T07ALI00D00@080`@0618D00T31@0Z9RH08B0N018<300B2@X0
2P4200h41@0Q5aP05`d>01482@04000061@C09VEU012>CX060h?00h61P0E2``0308301D;300?1@H4
01061`060147200;0@805@/<01@:2`0<0P<040H71`0?1@H200d3100<0147200K4A803@<401@:2`0f
;2d0V8j?01H<3@0H3Pl05`d>00l51P0=0@D03`<7100@10P600l31aCooooo000Kooooo`0G00d=2`0>
3P`03`l=010@3P0A4@l04Q8@014A3`0=3@/0410>01/K6@0N7Q`03Ph<00/;2@0@40h04a<A01@D4P0F
5Q@05aLE00X:200@40h01`L500D5100C4a400P0;2`T01@0A4@l030`:01PH5P0>3P`030`:00803@d;
01403Ph<010@3P0B4Q004a<A010@400J6QX04Q8B00/;2`020P804a<C014A4@0B4Q805aLG01DE5@0=
3@d030`<00d=2`0200l?3@0300X:200A4@l030`:00803`l=00X02`/901DE4`0G5aD03`l=05EGE00@
40h04Q<A00H6100D51803Ph<0P0=3@/0400?3P`03`l=010?3@0?40/02``600/<1`0B4Q005ADE010@
4P0;2`d020P:00L71`0<30X030d800`=1`0<3@T200`<2P<03Ph<200=3@/200l?3@07010@3P0A4@l0
410>010@3P0T9280?clm00L71@0200l?3@0600h>300?3`d03`l=00`<2P0?3`d02`/90P0@40h01@0=
3@/04A4?014A3`0>3P`03`l=0080410>0P0?3`d00`0<30X03@d;00d=2`0200d=2`0700h>300:2PP0
3Ph<01<C4@0;2`T06ATG018B400200l?3@0800d=2`0<30X03@d;00l?3@092@L02`/901LG5@0B4Q02
00l?3@0>00D50`0=3@/02@T701/K6@030`804Q8@01hM6`0510<02PT70040000A40h040l=00d<2P0?
3P`2010?3@0N00h=2`0<2`T06AXE00L81@0@4@`0004000d=200C4Ph03`h:01DA3P0F4Pl0510=01D@
3@0F4Pl02`l701LJ4@0C5Pd0=3L^0;Nh/03cm>`0FeaD014A2@0G5`l04A4900P5000E4P/01`L201@D
300@40P04Q8:0P092@401`0>3PH03@d500`<100=3@D03Ph600h=200?3PX00`0>3@T200d<200700/:
1P0920@03@`800/:1P0<2`L040d9010;1`0300l;200400d<2P0A40h04a8@00820P802PX:01D0:2PX
014@3`0A40h040l=014@3P0>3@/030/900d<2P0>3@/03`h<010?3@0?3P`03Pd;014@3P0F5A<00P40
00`;2@061@<05A@B00l>300:2@L00P0>3@/01@0;2PP03`h<00h<3@0=2``03P`=00803`d>0P0<2P/0
3`0?3@h04@l@00d;300=2``05A<C01DD400A40/02`X501PG4`01000051<?008100071P@02`T:00d;
3002014?400600/9300=2`h03P`?00`:3@0;2@`03@/>1@0>30l05P0>3@l03`hC00/<40051PX051DI
07MhO00J6al04A8F02<T:027R8`0BDY>00X;3`0D5AT05aHK010?50030PL020L<01LF6`0H5a`03PdB
00d<4@0>3A82010?500700h=4P0C4AH03@/@01<A5P0G5AX04Q0E00L52P04010>4`804Q0E01T04a4D
010>4@0;2@`02PP;014?4P0E4aH04@lB01HD5`1HEUT09R@W02DS9P0K6A`03`l?00h>3P0?3`l04A4A
00l?3`0=3@d03Ph>00l?3`0>3Ph03@d=00/;2`0:2PX03`l=00803Ph<00d03`l=010@3P0A4@l030`:
01/K6@0G5aD05QHD00L71@0C4a402@X500/<1`0=3PT03a0;0080414<1@0A4Pd00`0@4@`03a0;00l@
2`0400l@2`804A8=01h03a0;01<D3`0E5Q40510<01H<2P0C3P/03`d>00/@4`0;5AL041hP02dl?`0X
=ST03aXL01<K7@0@5AP061/K00840@031@8051HC03<e<P0>40d04Q@A00h@3@0A4a005QPE01@F4`0H
6QL051D@018C3P0C4a4201@D4P0F01DE5@0F5QH04A4A014A4`0C4aD04A4C018B5@0L71h0:b/[00L7
1`0/;2`0Ogmo03Li>00N81l092HU014E500C5aH04ADD01HL6P0?4@h0418?018D4@804A<@0P0B5140
3@0L7Q/07AlL01LI5P0D5Q<030h;01<H500D6AD02Pl;00dB3P1FFeL0];Ve01dR7P0G71P00P0A5Q80
2`0C61@04QLC010F4P0?61<07BHQ00lH4`0b>cH05b0K014J5@0J8ah07BHQ00806R<N06T07bPU01HL
700Q9RP0:Bl_01XR900L92D07bPW01TS900N:BT07BTW01TU9@0L:2L08B`^02/i?`10CeH06bXa02Ph
?`0U=Sh0834i045CFP0nD5X09SQ201`_>@0[?dX0730k02DjB00Z@4h0;D=A02e3D00/@Td0;D=>02Hl
AP0S>T808STo02PoA@0P=cd08cY002Di@P0W>d@0:Si502`oAP0eB4`0;d960312A00W=cL07bl^02Pg
=@0S<Rl0=41002Tb=00]=CP0:cHh02Ha<`0N;2l0=DA902/lA00W>D<0:ce<03M:F`11EVT0>deM0352
C00/?4T09cM302Hg@@0X>D<0;3e702hoB@0`@D/0<D9;02dnAP0Y>T@09cM102Xh@`0_?DH0=DA<03A3
BP0_?4809c<h024/<00P:bd08bh_02H`<@0V<2l09C<c020b<P0R=3H0:cdo02i0@P0H:Rd0;d5502Pi
@00[?4<09SLn02m0A`0M;C<08S0a024];@0S;bl092h_01lY:P0P:RT06R<R01/T8`0N92800P0L8R00
6P0Q9b<08R/X01`U8P0U;Rd07RHY01XR9@0O9R`09B`b01hU:`0M9BP08BT[01hW9P0P:BD07RTQ01XU
7@0K9R407RLV01`T9P0P:2X07R<W01lT9P0M8B806QhM01XO6P0K8Ad06R0P0P0G7b401@0K82<06AhQ
01HK7P0G6ah06A`O00806a`P00<06Q/O01TJ7P0H6A/00P0H6A/02`0G61X061TL01PI7@0B4aP071dR
01/L8@0<31@04a<K014B5`0E5Q/061TM00805AHJ00<061TM01DF6P0D5AT00P0H6Ad0200D5AT05QLK
01LK7P0D6AX04ADF018F5`0G6a`061XI0P0E5aH0300D51805aLE018C3P0A4Pd05QPC010D400>40d0
3a4>018D4@0A4@l03`l=014A3`805QDC01H04a8@01<?3P0C3`h04a8@01@C4@0B4@l04Ph=01@@3`0E
4A005@l?01@>3P0C3@d04`X;01482@0>20P0510?01XF5@0G4a8040`;00`81`0;1`H03`/:0P0A3@`0
3@0D40l04Ph=00l:2`0?2@/050h@014;3@0C3@l06A<E01H@4P0=1`T02`D700d72@0A2`d00P0@2P`0
4@0=1`T03`T;00l92`0>20X03@L9024K7@2QVid091hP01@>400G4A<05@lA01XF5P0B4@l02`D50189
2P0<0`@040H70080200000L03`H700T30`060P407a/J024H6@0=0`@030<300803@<400<04@L800l5
1P0@1PL00`0@1PL01`0A1`P03`D601P>3`0E2``03P@501882@0A1`P01P0?1@H0200<0P<03`D601@:
2`0M4a@03P@50147200I3a00OG=d0P0700000`0;0@801`000104200201452@0301862P0A1@T03`<7
00H04@D95?ooool001_ooooo0P0B4Q001@0@40h03`l=00h>300<30X03Ph<008030`:00<04Q8@01DE
4`092@L00P0>3P`04@0?3`d0410>014A3`0A4@l04Q8@00`<2`11@Cl08R8P00<30@0A4@l03@d;01<C
4@092@L05ADC00l?3@0>3P`0410>00803`l=0100410>014A3`0B4Q003`l?00/;2`0<30`0:RXZ01LG
5`092@T03`l?014A4@0G5aL05ADE00d=3@0<30`03@d;0P0A4@l08@0>3P`04a<A00X:200<30X03@d;
00`<2P0A4@l04Q8@00X=2P0o@cl020/8010D400420@03a0>00l?3@0=30X03``;014>3@0B3`h04Q0>
018A3@0=3PP02@X500P91P0=3@d03`lA014A4`0;2`d020P800d=2`0>3`X03@h800h>2P0300h>3080
3`l=00<0410>00l?3@0?3`d00`0?3`d00`0>3P`03@d;00h>300300h>300701<C4@0J6QP03`l=00d=
2`0:2PP03`l=010@3P0300l?3@80410>00@03`l=01DE4`0@40h020P60P0>3P`00`0;2`T030`:00d=
2`0200d=2`0400`<2P0>3P`03Ph<00h>30<03@d;00H03Ph<00d=2`0C4a402`/9014A3`092@L200h>
30803@d;0P0>3P`2010@3P0402LW9@0A4@l03`l=00l?3@803Ph<00/03`l=00D50`1JFUP05ADC00/:
200@3`h04A0>00L61@0?3P`040l=00l>300500h=2`0Q00T:1@0<3@P0=3D`00d>2P0@40`01PD200d<
200B3P/040`900d91P0B3@X05A8=010D30021@005AP?00hA2@0_<2P0A4Dm01`M5@0C4`/04A49010@
200F4``04Pl801DE3@0>3PH01PH100l?200=3@D04A4900l?1`0>3PH03@d500803Ph600<03`l700h=
2@0>3@T0100>3@T01`0=30P02PT500h=2@0=30P03Pd9018?2`0A30P00`0@30T0200>3@/03@`:018A
3`092@T04Q8B00P8200@410030`;0P0>3@/500d<2P<03Pd;02<03@`:00h=2`0F5A<03Pd;01@C4@0B
4@l0=C@b01TH5P0A40h03Pd;00l>300=30X03`h<00l=3P0>30d040h?018@4@0A3a003P`=00/92P0?
3@h04Q0A00h<3@0=2``04Q4@00d<200?3PT04Q4<00H50@0I61D03`h:00d<2P0@3`d03P`<00/92P02
00h<3@0600h<3`0?3A0040hA00h<3`0=2`h03`d@0P0=2`h200h<3`0G00l=400?3Q0051DI00X=400>
4A@02Pd@03Hh?00:3A002@`?00/=400J7200<cHi00lB5@0?41@030/@01<B5`11@4D07A`Q00`<400;
2Pl03PdB00d<4@0>3A800P0@3a@03`0=31403`dB00l=4P0J61d00@0401<A5P0:20d03`dB00h<4@0=
2a003P`A010>4`0A3a@0518E018@4`0200d;3P08018@4`0F51L0?S`o01`J7@0?3A004@lB01HD5`0>
30l2014A4@0>010@400>3Ph03`l?014A4@0@41003`l?00d=3@0<30`03`l?018B4P0@40h03`l=00h>
300?3`d2010@3P0<01@D4P092@L03@d;010@3`0>3P`0410>018C3P0<3@L051D@00l@2`0=3PT04A8=
1@0@4@`0C`0>3`X03@h800d>2@0?40/0414;010A300B4`h05QLA01DF400B4`d05AHA01HG4@0F3``0
5P/;01D<3@0?3Q002a<F00dH7@0X>3h0^lkB0<OGf@0iBDd06BHY01/W:@0?5QD05APE01/O6`0H6aP0
Ngmk04iACP0<3``0310<01HI5P0D5a@02Pd:010C400J6aH051D@01<C4@0D51804Q8@018B4P0G5aL0
5ADE01DE5`0B4Q@03@d?010?4`0@41803`l?01<C4`0F5QH06ATI01PJ6@0O8B00:bd/01<G5P0G6aX0
4ADD014G5@0B51405ALD01HH5@0D5Q<04Q@A01<E4P0@4Pl05ALD01HH5@0D5Q<05aTF01DG500>4`l0
51TE01XO6`0G71P0724M02hc;`0F6aL00P0D6AD0300G7AT06b0L01/Q7@0F7aX03QLB018K5P0H8A`0
>D8m014J5@0I8Qd06b@O01XS7P80624L07806R<P01lT9`0T:Rh0:Blb01`T:00P:2/08R/]01dV:P0T
;c4082//01`W:P0P;2h08Bla02Dc>@0Z>T40;cm602Xk@`0Y>d807c4h01la>P0Z?DL09SU404MKI@0d
B5<0:Ce802HlBP0[@Dl0;D=@02e3C`0/@Td0;DA<02a3BP0Y@4H0:41502i6BP0U?D40:41402XoB00_
A4d0:Sm802Di?`0jCE<0?4mC02Pj>`0K:b/0;3`k0391?P0S<Rh09c<a02H^<@0/=3L0;3Dh02Td=P0P
;S40=dI;02`mA@0W>480:3]902e0D@0cB5d0=dQJ03Y:F00iBEL0<d=A02`lB@0[?4H0;Sm802dnAP0Z
>d<0:ca402i0A@0_@4L0;3a502Xh@`0/>T<0;Se502dl@`0Z=cd0:3@i02Lb=P0U<3809S4b02Tc=00Y
<c809C<d02<e>00Z?3l0>Ta?05e^M010DEL0A5EM03E6C@0`@DT09CHo03Q9DP0U=Cd08c4b024];@0W
<S809c4b01hX:@0P:RT06b@R01dV900P9R@07B<P01hT8@0V;2P08BXW01hW900S;2/07RHY02@/;`0V
;C<201lV;00A01lW:@0N9RP07RLV01dV8`0M:2<06B@O01/U8`0P:2X07BDX01/S9`0K82D07R<V01lS
8P0M8Qh06b0J01`S700I7al00P0F7R001@0J7b806AhQ01HK7P0I7B006Q`P00806AXN0P0K72003P0H
6A/06a`N01XK7@0H6A/05aPK01TJ7P0/;C805aPM01HG700C4a/0:RXb01HG700E5Q/061TM0P0E5QX0
0`0H6Ad05AHJ01LH700401LH700D01DI700F6a/04QHG010D5@0@51@04aDD01DG5P0D5Q@03Ph<01DE
4`0D5A003Pl:010B3@0@51003Q0=00lA3P0B51404Q8@00l?3@0B4Q0201LF500301@C4@0D40l04`l>
00804Q4?00L04A0>018>3@0C3`h05A4@01@>3P0D3@d05@d>00805Pd>014050h>00l;2P0B3Pd04`l>
00`81`0M6AP0:2@S01<?3P0B3Pd04@d<00P40`0<20L06A@D00X41P0;1@L050h@014;3@02018<3P06
044k?@0A2`d04`d?00`6200I4aD04@/=0`0?2@/300h82P0302PS900<1PP03@P9008040X<01805Q8B
00H50`0=1`L05Pd>01892P0>10D0=B//02PN7`0B2P/03PP801@@3`0?2`X03`H700h41@0C2@X03@<4
01882@0@1PL3014720<040H700H060h?01D;300@1PL040H70147200@1PL600l51P0B01H<3@0L4Q<0
4@L80147200@1PL04PP90107200C2`/05`d>01061`0?1@H03PH601<72`0?0`L03@4500l31`0@10P0
3@451P0A1@TDooooo`006oooool0100;2`T030`:00d=2`0=3@/200l?3@0400d=2`0E5A<04A4?00d=
2`<03`l=0P0=3@/04`0?3`d04Q8@014A3`061P@05ADC00h>300=3@/061PF00L71@0?3`d05QHD00X:
200F5Q@04A4?00l?3@0D51804Q8@010@3P0?3`d00P0=3@/0200?3`l03Ph>00L71`0U9BD071`L014A
4@0?3`l02`/;0P0?3`l02@0<30`03@d;00h>300@40h03Ph<00d=2`0D51802@T701HF5002018B4009
010@3P0A4@l05APE0002000?51004QHB00L91P0:30T03@d;00803`h<00L040h<014=300A3@`03`d:
00h?2@0@4@`0410=00803@d=00T030`<01HF5P0F5QH02@T6018C3P0E5Q003`l<00l?3@0>3P`00P0?
3`d00`0@40h03`l=00d=2`0500d=2`H030`:01<020P6010@3P0@40h04a<A00l?3@0A4@l03a4>00/<
2P0;2`T03Q0=00l@3P0`<2h0<S@a028S8`0A4A404Q@C00l?3P0=3@/03Ph<00803`l=0P0>3P`00`0@
40h03`l=00h>300200`<2P0300/;2@0B4Q002PX800<04Q8@01/030`:00d=2`0<30X030`:00h>300?
3`d03@d;014A3`0;2`T08R8P00<30@0:2PP04A4?00T91`0A4@h00P<001HG4P0@4@`02``701DD4P0=
30X040l=01LF500:2@P03@`:00l>300>3@/00P0<2`T06`0?3P`040l;010A300>3`X0=3D`0083000?
3`X040l;00l>2P0A3@X03`/801<?300Q7AX0:bPS00D70@0E6140CE1702<V7P0@4``082<J04I9@@0B
4`d03@h600`<1@0A3PT03Ph600T90`0200`<100601lO6P0A4@T04a<;00l?1`0>3PH03@d50P0>3PH0
3P0?3PT03Pd900h=2@0>3@T03Ph900h=2@0=3PT030d800X:200>3P`030`:00h>300B40`040d80`0@
30T200h=2`0801@C4@0820H020P8018B400:2PX04A4?014@3P0?3P`200/:200300`;2@0>3@/03Pd;
00@03Pd;00l02`X8014@3P071P@03@`:06IVI03GemD0N7Uf01`L6P0:2PP03Pd;018A3`0>3@/03P`=
00l=3P0B41400P0F51D05P0C4A8040h?00l=3P0>30d03`d>00d;30081`H04Q4=00d<200:2@D04A0<
06ETH00F5A<03@`:00h=2`0@3`d05Q@E01TG600=2``02`T<00`:3@0=2`h200X82`<03@/>0P0>30l0
5`0?3A003`h@00D62P0C51P01PL;01HG6`0=3Q80414E00d>4P0:2`l030dA010A5@0>3a<00004018A
5P0A41D0=cHk00/:3`0O7R<01`H;00/:3`0:2@h030/@00803PdB00T02`X?00d;400>3A40J6I[02h/
<@0;2@h061HK01DC600B41D00P0?3A800`0A3a@04a4F00X83@0200d;3P0I00`:3@0;2@`030X=020N
8@0100804@lB014<400@2`l03`d@014A4@0C4a<03Ph>00P8200<30`04A4A01DE5@0@41002`/;00d=
3@0J6QX08R8R010A3@0?40/03Pl:00h?2`0200l?3@0;01LG5@030`403@d;018B4P092@T01PH400h?
2P041@00414;00T:1@0720801P0?40X09@0=3@P030/600d<1`0>3`T0414;014B300B4`d051D?01<D
3P0>3`T03Q4:00h@2`0B3@X05`h?01@>400@41<03a@H014J7`0X=S/0[/340;[<d00c@TH05R@W01PS
9@0G7ah041DA018F5@0A5A<06AhJ030d<`0B5Q@03a@@010E4P0<40l0314=02hc<00F61D00P0?3`d0
;`0F5QH051@D01HF5P0<30`03`l?01PH6P0E5AL03Ph@018A5@0?3`l0410@018B4P0G5aL04Q8B018D
4`0?4A008B<R00/?3P0H71/04QHE01<G5@0?4@h04aDB01HH5@0C5A804A<@01<E4P0J71T06A/H01DG
500?4@h04aDB01@F4`0A5Q804aTE01DK5`0A5a<041HB01TO6`0D6QH05adI01/Q7@0M8al06R0L01DK
5`0G7QL08bdU00804adE00@03QLB01XS7P0Y<Rd07bPU0P0F7a`0S@0I8b0072DT02`c>@0L8bX05QdS
014H800K92X072DZ01XS:00L9b/05R@W01`W:`0R;c8072X]04QFG00M;3<0BU]R02@e?00W>4009cY1
02@g?`0_@D/04bL`02XnB00W>dH0:Si902e3D@0aAeD0<TQE02m5D@0]@dh0;DA<02e4B`0/@dT0:d=7
0359C@0W?d<0:D5502]1B`0`AU40:D1803Q<E01gRY00Sj:V06AfN@0M;Bd09cLf02Hd<`0S<Rl08Rh/
028X:`0X<3<09c0b02Pc=@0O:Rh0;C]202Tj@P0]?d/0<4=B02e2E@0gC640>4]O03Q:F00jC5X0=DEC
02/kB00W>480:3U102Tj@@0Z>d80<3m402hm@00W=S/0:3Po02`mA`0Z>d<0:cU202Xi@00Y=Sh0:CDk
02Pc=`0U<3@092la02H`<@0W<C80:3Dg02Xl@00[?D40;Sm505IWKP0Y>D00;Se402<b>@0_?TD0:cU2
045?F00S<SX0938e02Pf=`11CDd0@de>02dg=P0N9bD072DR024W9@0R:2H07bDS020V900Y;bd07BHU
01hX9`0Q:R/07RHY02/c=P0T:c406b8X02@/;`0V;S4082TX01lX9`0G81d07BHS01TR7`0L9B<08BXY
01`T9P0H7B005Q/O01/P8P0N8R407B8N01/P6@0J7aT051XH01<I700F6ah06AhQ01XO8P0H7B006alR
01TL7`0201LH700@01XK800M7R805QLK01XK7@0I6Q`05QLI01DF6@0G61`03@hC01`M8P0C51T071dR
01TJ800F5a`05AHJ01PI7@805AHJ00<061TM01DF6P0I6Qh00P0E5QX00`0J6al061TM01DF6P02018F
5`0M010D5@0C5A@071hM02<U900c=C<03Ph>00d=2`0E5A<051@B01HF500?4@h04aDB018D4@0?3`d0
410>01@D4P0@40h05A@B01HE4`0C4Q004Ph=014=300@3`d04A0>010?3@0@30/04Ph=01@@3`0C3Pd0
100C3@d06`0E40l03@T8014=300D40l00`0001LC4P0/:2L02PH500T5100C3`h03PX9024M7018@d@0
8Q`N00P2100?2@/03PP:018<3P0P6Q`0U8j@01@>4P0@2Ph0618F07E_L`0l=SP04@/=00l92`0200h8
2P0?00l92`0:1@H081XL00@0000F41804@/=01LA4`0=20T03`/:00h61`0=10D04PT:01D;300J4140
5P`=00804PT:00H03`T901@?3`0E30d030830147200@1PL20147200301<92P0B20T04@L800803`D6
00D03P@501hD5@0?1@H02P4201061`0200d310H03`D600D05P`=02@J6`0C2@X03@<401882@0200X0
0@0;01@:2`0900003P@501<92P0D2P/050P<00h21P0<00@03`<701862P0A1@T01P0?0`LDooooo`00
6oooool0300G5aL030`<00d=3@0B4Q803`l>00/;2@0C4a4030`900X;1P0>3`X0414<00`=20802`/9
00@03@d;010@3P0A4@l03`l=0P0=3@/200h>308030`:01403`l=018B40071`D03`l=00h>300<30X0
2`/9014A3`0B4Q002`/900X:200A4@l02`/:01@D4P0Q8Al07alN01hN7002010@3P0600h>300?3`d0
4A4?00l?3@0=3@/03Pl;1@0>3`X04P0?40d04A8=00@5000F5a8010D001<D400>40d030h;00`=2P0<
30X02`/900d=2`0C4a405ADC018A3`0=30X03Pd;00l?30803@h901T030d800d=2`0=3@/030`:00/;
2@0=3@/03a0;00h?2P0=3PT04A4>018B40051@<03@d;024Q7`0D51802PX801<C4@0B4Q002@T700d=
2`0@40h03Pl;00d>2@0G61<01@H100804A8=0`0:2`H0500<3@P03a0;01<D3`0<3P/03A8>00d@3@0B
51<00@D401@G5P1`LW40nOgl05EHF@0>3a4010P900d>3`0>3P`06AXE02TZ9@0N7aX03@h90P0>3`X0
0`0@4@`04A8=00h?2P0200`=201900@3000K6QH040l;01TH500?3PX0BTU5024P700<2`L051<?00/:
1P0>3@T02PT5010@3P0;2`T061PF00l?3@0;2`P04A8=01@E400;30H01PL1010A2`0:2`D02``601PG
4`0D4`l05QDA00<2000A40`020L3014@300920H06aXF00@3000@3`/02PT500T8100>3@P04A0;010?
2P0<2`H02`X500T80`0A40/040l:00/:1@0A40/061LB00T91P0G61<0ATU2038h<@0I81T0>48i0;S0
^00H7AL00@@0018C3@0;2PH02`X500d=20061`40004001`M5`061`403a0:00h?2@020`003Pl900`=
1`0>3`T06Q/E00`=200200T:1@0?00/=200@40h0418?00lA3P000P402`h=00H:2@0@51<02@T700l>
2P0>3@T030/700L60P081`<040l;008030/700H030/800`;1`0<2`T030/700/:1P0<2`L300h=2@0H
00d<200>3@T03`h:00d<200;2PH03`h:00`;200N7A/020P601`M6`1eNWH0mogi07f5P00<4Ph04AHB
00l@3P061P@05QDC06ETHP0D4a402@P701dL6P040`403Pd;0P0<2`T200d<2P803Pd;0P0<30X0600@
40h00P8000l?3@092@T02`/;01@D50092@T0410@00@4100=3@d03`d>00h<3@0<2P/02`T:00`:2`0?
3@h04@l@00h<3@0?3@h06QPI00h<3@0;2@X03Ph@00T92`804a<E00h02PX<00l?4@0>3Q003Ph@00`<
3P0;2`d030`>010@4P0;2`d020P:01<C5@0A4A<051@F00`<3P803@d?00X020P:00/;3@0?3a401`L9
00d<4@0G5Q/0JVU^03<b=`0C4QL04A0E100=3140100?3Q<040lD00d<4@0?3Q<2014?500@018=4@0A
310040/?01`H6@0A3@h04`d?01PB500>2P/03@`=01DE5@0B4Q8020P801`L70061PH03@d=00l?3`80
4Q8B00T02`/;00L71@0B4`h04Q<=00l@2P0=3PT03a0;014B3@0A4@l00P0A4A40>`0?3a4030`>00/;
2`0?40T02P/300L8000<3@D03Pl700d>1P0@4@T04A8:00@50@0A4PX010D001@B2`0@3@H0514:014@
2P0:2@@04a8=01LH4`0?4@`03@l:00X<200?50h041DA018B400F5A<0518C014A4P0F5aT051PK01HK
7P0`>3/0BE5D028Z;@073a8072@V01@K700?5A<02Q0@00hD4`0T:RP092XZ00lE500;4@l051XI00@:
2P001P@0Jg1_00`>3@0J71/04A<B00`=3`0=3Q005AHH00l@4P0@4A<04A8D00803PlA00<04A8D01dO
7P0G6AH00P0@4Pl05P0?4@h04aDB018D4@0@4Pl04A<@01<E4P0D5Q<04aDB01<E400G61<061TD01<D
3`0A4Pd05ADC024Q7`0F5Q@04Q8B01/K6`0I6AT04A<B01@I5@0I7QX201@I5@0401HK5`0@5A4051TE
01DJ5P806b0L0:805AXF01<J4`0D6a<0620F01/R6P0G8AP05R0I01HO6P2LYj<0H6YZ01hX:@0V<380
92h`020Y;P0M9Rd0>45902</<`0L9Bh0628Z01DP9P0C7R@07BX`020_=00N;2l07bd`024_<P0Z>3/0
:CPm028a=P0R<cL08c@k01l`=`0V>3l083<j0395C00]@4P09c]402i2C@0[@E00<4EF0398EP0aAe@0
;49?02Y0B`0bB580;4=;02LnA00[@TP09ci402i5B`0^AU008cU402U0B00_@d/0JGb3055TJP0b@dT0
8c8g020_<P0Z>3X09C0b01TS900X;S808BHZ01`U:00T;c40:SDi02`j@@0hBE<0?E1N049GJ00dBV40
;TAL03U?H@0dB5<0<dMB03A6D@0V>48093Dm0310A`0W=S/0=DA9049@D`0W=CH09S@g02hnA00/?TP0
;T1:028c>`0]?TD09C@k02Hd>@0V=3L0:3<g02Pc=@0V<C<09S0b02Hb=P0W=Sd0:SU002Pg?@0V=CX0
:SPn02/h?P0Z=cd0:3Dk02dh?00a?400=dA70353A@0V>3X0V:NW0=;NgP0oBDP0:C0]02<Y9@0T:BD0
8RLT02P/:`0M8B80=3Pj01lY:`0O:R`082X/02@]<P0X<CH08R`^024[;@0M9bP08BT[024Z:@0J8b80
6b4P028X900P9R80728N01dS7`0P9R807b@P01HJ6@0G71P07b@P01hS7@0H7AL06b0J01`P7`0J7b00
6QhO01`P8@0L82806QhQ01HI7P0K7R<071lT01XM8P0L7bD08R<X01PI7@0M72407QdR01/J7`0G5a/2
01@E6@0T030c=P0420/05a/N01DI7@0A5AP03a0D01DF600H6A/05aPJ01TJ700M7R00824S018C5@0H
6A/05QLI01DF600C51H04Q<E01XK7@0G61X05ADG018B500=3@l04Q8C00l?4@0D51@05ADE01<C4`0D
51@03@d;00/;2@0F5Q@04Q4?01`K6@0C4Q004Q4?0P0C4Q001@0A40h04Q4?01<B400D4`l04a8>0080
4Q4=00/04A0>010?3@0=2PT03PX;00d92P0R7Ql03@T:00d92@0A3@`03`/:00h:2@0200d9208040`;
00T03`/:01<?3P0F4Q404`l>01@@400M6AX04Ph?00T51`0B3A400P0=20`04`0400<07QTO01<>500L
5ad0_k[0085lO`0F41004@/;00h8200:10@03@L7010:2P0Y8b<03PP800d71`0?2@T0:bDU01092@0@
1`P0100A1`P401<92P804PT:1P0@1PD0800W7A`03`D400l5100E2`X02P0001<9200=0`@040H701hD
5@0A1`P0308300l51P0700002`420147200D2P/060h?0147200A1@L040@600h2100=0@<03`<50145
1`0E2@/02@0000l31@0D20X03@<400d10`0B1PX04@@;0P0@0`X0200A10/04PD<01442`0@0`X03`89
00P00P0C20d04`H=5?ooool001_ooooo00d04Q8B00h>3P0=3@d030`<018B4@0P81h0:BTW01XK5`0=
3PT030d800d>2@0<3@L0410>00803@d;00@03`l=010@3P0?3`d03@d;0P0>3P`300l?3@07020P7P0F
5Q@02`/900/;2@0?3`d071`J01TI5`0200/;2@0600h>300=3@/03`l=04Y:B00@40l0410>0P0?3`d0
1`0>3P`03@d;00/;2@0<30X0410>00l?3@0=3@/01P0>3`X02@0E5Q40G5eH010A3P0<3@T061TD00h>
2`0=3@/03Ph<00l?3@0200d=2`0400h>300=3@/03@d;00h>30803@d;00@03Ph;00d>2@0=3PT030d8
0P0=3PT00`0>3`X03a0;00l@2`03010A300V00h>2`0C4a40410>00h>300:2PP020P600l?3@0=3@/0
3`l=014A3`0<30X03@d;014A3P0@4@`09BHQ00l@3@0;30P03@h9010A300?40/04Q<>00h?2P0:2`H0
4A8=00P:1`0:3PX041<@00T<2P0F6AL04A@C03Hi>@28Rh/0:B/]00D72`0>4A@02``?00`<2P0;30L2
010A300400/<1`0<3@P0414<00h?2P803@h902T030d800T:1@0>3@T04A0<00`;200F5A403`h:01HE
4P0B4@d03`h:018A3@0:2@D040l;018A3@0<30X03`l=02@T8P0M7A/0414=00/<1`0<3@L03a0:01DF
400O81P04a@<00h?1`0@3`/03`h:00d<200D4`l02`X600d<200:2@H05A@@02@S7`15A4009B@P00`;
200;2PD03Pd800l>2@0300d<1`0400h=200=30L03@`700h=20803`h901T03@`800T:1@0A4`h02Q0:
00LA2@0D7QH0<3Xb00P?20083@L02@X500X91@0E51003Pl901PI4`0j>cD03@h900T:100=3PP030d8
010A2`0C50h03@h8018C3@041@003Pl:008030d800l02``700/=2P0;3@X0310>018F5@093@`04aTH
00@92@0D5QD0;bhZ02XY9@0@3`/04Q4=00h=2@0;2PH01@0>3@T00`0=30P030/700d<200400h=2@03
00d<200>3@T03Pd900803`h:01<03Pd:01HE4`0;2`T03Q4>01/Q7@1;E4l09S0Z00`E400D6QH02`l;
014A3`0G5Q@0:BPV01DD4P0?3P`02@P600h=2`0?3P`030/900803@`:0`0>3@/02P0=3@d030`<01hN
7P0F5QH02@T901<C4`051@D06QXJ00X:2P0<30`200/;2`H03`d>00L03@/<010>3`0?3@h040h?00T7
200G5AH08AlR00804Q0C00H04a4D00d;3P0A3a803`d@00h<3`0=2`h200l=400C00d;3P0<30h0410B
00/;3@092@/05ADG00l?4@0=3@l03`lA00/;3@0=3@l05ADG01@D5P0A41D030/@01PG70071P/02`X?
00`;4002010?500H00h=4P0=31403PdB00h=4P0?3aD03@dB00/:3`0<2a0040`@014>4@0F4QH08QdO
01`G600B3@l05A0B01PC500?3`l03@d=00820P0A4A400`<301HF5P0A4A4051@D0P0@4100A00A4A40
3Ph<014B300B4`h04A8<00l@2P0?3``0414=00l?3@0>3Ph03Ph?00d=3P0<30d03@d<00/<1@0D5@d0
4Q<;00l@200>3`L04A8:014B3@0<3@H05QL?00`=1@0C50`04a4:018>1`0C40T0518<018A300H6180
6Q/F00T;1P082PL03Q4>01LL6013B4@0C51<020Q7@0I6QH04A4@01<C4P0A4a403a4A01DG5`0?4aD0
51PJ03Di>`0E6a`04QLH01@I600@5AD0314A01DJ6@0C61L0314A014F5P0<4A004aPH014F5P0?51@0
51HF01TJ6`0@4A8051DF01HG600Z;2`04Q@D0P0C5AD02@0A4Q<0418B01<E5@0=3``04aDB01HH5@0C
5A805ALD01@F4`0301<E4P0601HH5@0E5a@04Q@@01HG4P0F5a405QLB0P0E5Q400`0E5A<05aLE01HF
500201TI6@0401@D500E5aH05aTF01HK5`804AHB00@06AhJ01PM6@0I7QX05a`H0P0K81`04@0G71P0
6AhH01LO5@0I8AL06B0H01DO5P0F7aT05b0K02dg=P0f@4008R`]02Xe=P0H8bH0>dI;02lh?`0W<3P0
92de00806RD/05L07RT^01`Y;P0H9R/06bX^020_<P0P;c405bHX020^<@0T<cH08c8e02Dd>@0S=CT0
7c4e02/l@`0]@4L0:Se402`oAP0]@DP0:cm802m3DP0fBUX0=DYH0315D`0^@U00;T=@02i3CP0Z@4P0
9Sa402Y0AP0V>d80:d9:0358D`0[@D`0;TA?02e1BP0iC5<083<j02/m@P0]?440:cXm02lm@00b?Cl0
;cTk02he>00W;C00:C8d02Lb=00X<cH0:CPn03E7D00mD5d0@5IX03A:H00]A5`0=daN04MJH`17FV@0
;d9;02m2B@0a@TX0:CY102Hf?00_?D@0?4]?0391@`0]>Ch0<45702XmAP0[?DL093Dn03=4C00[>T40
:SPn02Pe>`0Y=CT0:SDi02Td=`0Y<cD0:3@i02Pg?P0Z>D00:CPn02Lf>`0[>3h0<ci2030k?`0[=SX0
0P0X<S@06P0[=CL0<dE902Tm?P1ZNg/0RING03i9A@0U;BT08bPT024V8P0T9b@08BDV028V9`0T:B`0
92db02<^<P0O:Rh07RT/02<^<@0S;Bl08b`^01hW:@0N9RP07bLV01`S8`0P9RD07B8N0P0M8Qd201lT
7`0801XO6P0R9b807R<N01hS7P0L8A`06QlJ024V8P0L81l201XN7`0401/O800L82806AdP01PK8080
6QdR00@061/R01XM900N8BH06APN0P0J6Ah0300H5a`06ATM01/L800L7B40:bda01`P8`0D61/05AXM
00hC5P0F5aT05aPJ01PI6`805aPJ01P05AHH01@E5`0J6ad08B8T01XK7@0L7Al06Q/M01XJ700C4aD0
5aLI01HF600D51H06ATK01/K7@0B4Q@04a<E018B500A4A<051@D01DC4`0920H04Q4?010?3@0E5182
018A3`804a8@00<04A0>018A3`0C4Ph00P0@3`/2014@30<040l=00/04@l@01HD5@0A3a0071XK014>
3P0D40l04@d<010<2`0D40l061@C01HB4@02010<2`0B01<?3P0E4A004`l>018>3P0=2@X02PL701DA
4`0;1`T01P85014<4@0L5ad08QdS040k@@0F4AP08ahU01TD600>20P03@L70P0@2PX00`0C3@d06A<C
02TS8`02014;2`0300L20P0I4a<030@500/04@L81P0@1PD04P0I3`h0=2XY01<92@0<0P809alN0106
1P0?1@H05P`=028H6@0>10D02P420147200`9RL06a4B00`3100?1@H02`4201061`8040@60P0?0`D2
01041P0702DI6`0I3@l03@8300/10P0>10D04PP900l22@0401032P0700l22@0@10X040@:01D83`0?
10T05@X?01<63@0Dooooo`006oooool200/;2`0>00h>3P0=3@d04a<B028R80092@L02@T600`=200@
4@`04Q<=010A2`0D51803`l=00`<2P0=3@/200l?3@803@d;00/03Ph<010@3P0B4Q004Q8@00L71@0:
2PP04A4?018B400?3`d092@R020P7P0200/;2@0:014A3`0B4Q004Q8@06EUH`0I6AL04A4?00/;2@0<
30X03Ph<018B40803`l=00<0410>00l?3@0>3P`01P0>3`X02@0;30L07b0K0001000B4`h0414<00/<
200<30X02@T700`<2P02010@3P0700l?3@0=3@/02PX800h>300A4@l0410>00h>2`0200d>2@0<00`=
200=3PT03@h900h?2P0=3PT030d800/<1`0=3PT03Pl:018B3`0?3`d020P60P0I6AL0300=3@/04a<A
00H610061P@03`l=0082000410804A4>0042000<3@P03Pl:01/L5`803@h901@02P/600h?2P0@4@`0
2``7014B3@0A4a0010H300/=2P0A4a00?d4n014C4P0D5QD04Q@C018C5@0F5a/01`P<00/<3`0G5aD0
4A8=00/<1`803@h901@030d801<D3`0?40/03@h9018C3P0C50l03@h901HE4@081`<02`X600L60P0?
3PX02PT501@C3`0B4@d03Pd901`K5`0@3`/0;2/W01TI5`802`/901`010@200`<2@0D5A004Q<=00d>
20082@<03Pl700X;0`0A4PX02PT501DD400H5a<0>3Lc010?2`0F5A4030/700`;200H5a<0EeIB038a
;@0:2@D03@`700h=200<2`H02`X500`;1P0@3`X04A0;0P0>3@P2014@2`0C00l>2@0D4`l0414<00d?
2P0D5a805ahG018L50094@X02a0:00hC3@0@4@`030/700/:1P0;30H08R<M075bK00L7AL00P<0010A
2`0200h?2@0800l@2P092P@06a`F00T:10092PD02``700`=200>3`X200d?300600`A3@0]<C005AXH
04iDDP0O9BD01@H40P0>3@T0100B4@d02`X600T8100C4Ph500l>2P0400h=2@0=30P03Pd900l>2P<0
3Pd90P0<2`L05@0@3`/04Q4=00h=2@0<2`P03Pd;014A3`0@4Pl03A8>00L=2@0:4`h00`T500/@3007
2PL030`:00`;2@0=30X020L500T81P0<2`T04Q4?00l>300200d<2P<03Pd;00@03`h<00@4100820P0
2PX:0P0E5AD02@15ADD09BDU030`<00E5AD04A4A00h>3P0@41003@/<00h<3@02010>3`0V00l=3P0>
30d040h?01DC500@3Pl03P`=00/92P0O7Ah09R@W01<A500>30l04@lB00l=400=2`h040hA00`:3@0=
2`h04Q0C014?4P091`X03@d?00H6200=3@l05ADG00`<3P0D51H02PX<00l?4@0=3@l02PX<00`<3P0@
41801PD:014@5@071P/06QTN01@C60071P/200l>4`803@`A0P0>3A804`0?41D030dB00X;3`0:2Pl0
3@d?00h>400>30l040h?01HB4`0=2@X030P901@B4`0E5AD03@d=01PH600B4Q804a<C018B4P0@4100
0P0000001`0A4A4051@D00L71`0>3`/04A4?018C3P0?3`d00P0>3P`0A`0@40h03`l=00h>300@40l0
4Q8B018B400?40T03a0800/<100<3@D04A8:020Q6@2CU8`00`@001XK4`000@009bPP00l>1`0D4@X0
4Pl8018@2P0A40/04A8<00h?2@0:2`H04aDB010C400;40`0B4e905MJEP0K71L05QLB014B3@0E5A<0
5ALD01<E4P0<3Pd0:Bd/00lC4`0L82404ALG00dB400B5a<05QPG014D4P0B5a<051HE00X=2`0F6aL0
4A@B00H81`093PX05aTG00H81`0I6aP03Q0>00X<2`0?4@h03a4?010B4@0A4a004A<A00h@3`0>40d0
4A<A00lA3P0G6AH04Q@A00h@3@0E5a@04aDB00805aTF00X06A/H01/M6P0I6aP04aDA01PI500E5Q00
4a@?01HG4P0H6A@051@B0P0G5aD01@0K6a/061PH01DE5@0K7A`04aDB008051TE00D04aPD014F4P0=
4Ph06b0L01LL600201TN6P0301LL600K81`05ahG00806R4J06D05QlJ01DN6@0F7a`05B0L038l>`0A
6aX04alO01TU9@0A71h09Bhc01hW;@0b>d00G6M]02Pc=`0S;S8062HY01l^<@0Q<3<06bX]01TY:P0S
<c<07bd`028a=00U=3L0:3Ll02Hh?00T=SX0;3e4069eO014Eeh09SU003=7CP0mDEX0=4ME03U<F`0d
AeH09cY802@gA@0W>dH0;T9=02a0B@0Z?TL0;d=:02TmA00^@TT0;4=<02PnB@0V?DD0;D5902i1B00^
@DL0<41503E3AP0^?3l09S@e02@_<@0S;Bh0;C@e02Ta<`0e?cl0;c/k02di>@0]?3l0<T=:03I8DP11
EFD0?eIX03I<H`0gBeX0:Se402Lh@00aA4/0=DQ?03M8D00cA4`0;Sm6024b>@0R<ST0;Sm602hmA00`
@DP08C<m02Dg@@0V>400=DI>02/j@@0Y=ch0:3Dk02Le>00X=CP0:C@h02Td=P0Y=S/0:SU002/j@@0/
>d40:cXo02`i?`0b?D40;cXn02/f>P0202Pb=00F02Td=P0/?T806bl`024b<`0U<C4092l[02H]:P0R
9b<082DQ02T^:P0R9RL0:Bd^01hT9`0V;c@09c8f02<^<P0P:bd08Rd_024[;@0R:R`082PZ01lW:@80
8BLW00/08bTX020U8@0N8al082DQ024V8P0N8al07B8N01`Q7@0N8al07B8N01TN6P0201@I5@0601lS
900N8R<07B4R01lS900O8bD07B4T0`0E61d0200G6R406ahU01lR:@0J6Al071/P01/J7`0I61d06QXN
0P0K7200300@4QH092P[00X>4@0K7b804QLJ01XK7@0F5aT05AHH01PI6`0F5aT0414C01DF60806a`N
01H05QLI01/L7P0D5AL05aLI01DE5`0G5aT05QHH01<C5@0E5AL051@F01DE5`0L71h06ATK010@4P0>
3Ph030/:01<B400K6QP04A0>010?3@0G5Q@04Q4?0P0C4Q000`0A40h04Q4?01<B3P0200l>2P03010?
2`0A40`04Q4?00804Q4?00H04a4B00d;300<2P/03P`=018?3`0A3@`2010<2`0301<?3P0G4a805A4@
00804@d<0P0B3Pd04@0A3@`030P801<?400@30d02`L800d92P0?2Ph05a8G00/630060@L06aLM00<0
1@0D3aH05A0D00d71`0>20P04P`<00<040X:00H04@/;00H0000B30`0208201@>3P0@20P;014720H0
40H5018081HE08AjN@0M4a806a4@06eSHP0H3Pd03@<401@:2`0X7Ql06Q0A0147200@1PL08QPI0188
2@0<0P<03`D600T0000:0@8301041P0300l31@0@10H040@600802`010P0F2P`0100>0`@050P:00d0
1`0?0PT20185300800l22@0=00L03`8901P;4P08008040<:00l52@08008Dooooo`006oooool0400C
4a<0410@018B4P0B4Q803@d<00`<2P0;2`T03@h:010A300A4Pd0414<00d>200E5A<0410>00`<2P0=
3@/200l?3@0800h>300=3@/03@d;010@3P0B4Q004a<A018B40092@L200h>300:014A3`0Z:RP04a<A
00T91`0:2PP02`/900`<2P0?3`d04Q8@00D50`803`l=00<03Ph<00H6100A4@l00P0>3P`00`0A4@l0
4Q8@014A3`0600h?2P0B03Pi=0082@@02P/6014B3@0<3@P08B8N01LG5@0;2`T030`:01<C4@0?3`d0
3@d;00l?3@0;2`T03@d;010@3P0>3P`03@h:0P0=3PT05`0<3@P03@h900d>2@0>3`X03@h900`=200;
30L03@h900h?2P0?40`03Ph<00l?3@0];B/0:RXX00l?3@0@40h04Q8@01lO7@0b<S006ATG00d=2`0D
5A403@h900804Q<>00<0:2TT010A300D5A000P0@4@`05P0B4`h0414<00h?2P0A4`h01PP3010B3@0A
4a00>S`i00h@3@0=3`h00`D400P92`0:2`d0:2T[00420`0820H02@X500X;1P0;30L03Pl:014B3@0@
4@`200`=200W01<D3`0E5Q40414<018A3@0920@06aXF00<2000<2`L05QDA00l>2P0<2`P05QDA03Pg
<`0F5A40?3/g01<C4@0>3P`05ADC00l?3@0@40d030d800L80P0<3@L03@h8018C2`0720802``400L6
0P0?3PX040l;034`;00<2`L05A@@014@300<2`L01@@000/:1P0920@051<?00803Pd800H030/600X9
100=30L040l:00d<1`0?3PT200h=2009010?2P0C4Pd09B@P00h?2P072@@02Pd8010G400E71D02Q4:
00801``601<04Q<>01<B3P0>3@T02``701DF400P8A/030d800d>200:2`D0414;00X;1@0?40X01`P3
00l@2P0:2`D02PT400/<1P0<3@L03Pl:00803@l:00`0;c4^0>KZj@1EFEP03a<B00X>3@0<3@`03@`8
00`;1`0B4@d02@P400H50@0B4@d600l>2P0300h=2@0?3PX03`h:00<03Pd901003@`800`;1`0@3`/0
4A0<00h=2@0;2PL03Pd;014A3`092`P041DA0088100>51001@/700X?2`0A4a002`/90P0<2`T01@0A
40h040l=00d<2P0920H040l=00803@`:0P0>3@/200l>300>00D51@0L71`03@d=010@400820P05ADE
00`<300>3Ph010@400l?3`030`<02@T900`:2`0=2``200l=3P0V00h<3@0=2``03P`=014?400:20T0
3P`=00`:2`0D4Q<071XM00l=400=2`h04@lB00l=40091`X040hA00`:3@0=2`h04Q0C014?4P091`X0
6a/M014A4`030`D03@d?00/;3@0C4aD030`>014A4`0D51H0410B00`<3P0?3a403PdB010?50030PL0
61LL00d<4@0A41D200`;400I00d<4@0>3A8040lD014@5@0?41D03A4E00dA500=3a<03@h@00`=3`0C
4aD02`/;01<A4P0A3a0030X;01<A4P0C4a<04A4A01@D500A4A404a<C01@D500B4Q805aLG01DE5@02
01@D500601<C4`0=3@`04A4A014A3`0?3`h03Ph<0`0?3`d0500?40/04A4>018B400C50l04Q<=00`=
1`0:2`D04Q<=01@E3`0>3`T0;2dW01dN600720D0BT]50001000M71D0514:010@200@3`T04a8=0P0A
4P`0@P0=3PT03Q0=01@F4`0<3P/02a0<018E400B4`d04A8<018C3@0G61<05QPC018D3`0B5140=S/g
010E4P0;3`h05A/I010C4@0A4`h05ADC01@E4@0F61<06ATG018C3`0A4`h03a0=01@D4P0>40/03Pl;
00lA3P0E5a804aDA01XL6@0C5A0061XF01@F4`0E5a805ALC018D4@0B50l05ALD010B3`0D5Q<04aDB
01HH5@0N81d061XG018D4@0C5A805ALD01LI5P0E5a@03a4=01LH4`0D5@l04a@?01LH4`0H6A@05ADC
01LG5@0C4a404Q8B01@D500C4a<05QPG01XL6@805a`H00D05Q/G01DJ5P0D6AD06b0L01HK5`0201LL
601Z01HK5`0K81`05Q`H01/Q7@0M8al06B8O01LP7@0F7a`082/W01@O6`0N:BD072PV01dY9`0O:bT0
6bDW01/U:00d?T00G6M[02Pc=@0Z=CL06bTZ01`[;00P<30072`/01XZ:P0T=3@08S0c024`<`0S<SD0
9SDj02Dg>`0W>Cd0:S]2049EG00]@4L0<4=:03M;DP0^@T/0>4]H03]>G00fBEL0:3]902LkAP0[?dX0
;D5;02e1BP0/@4T0<DE<02XnA@0^@TT0<4M?02m3C00Y?DH0:Si602m2B@0nCeH0<T5603=1A00_?Ch0
;cXl02/g=`0W<C809bl]02L`;`0a>cT0;3Pf02Te<`0Y>3T0:Sa002Tl@`0kD5d0AU]/03Y?HP0eAe@0
:ca302Th?`0X>D408c@l02Df?P0Z>d<0<45902/lA00^@4L0=TU@0311B@0]?TH08c@l02/lA00`@DT0
>DYA02dl@`0Z>Cl09SDj02Hc>@0U<cL09S@g02Td>00Z>3`0;3]202dl@`0`?dD0;ci302hk@@0^>Cd0
;3Lk02Td>080:38d00P0:C@f02<e>@0P=3D0;Sm002hj>P0Z=C407bHS02<X9080724M00H0728R01lU
9@0S:B`09Bhc02Pc=`0X<cD202D_<@03020Z:`0O9bT08BT[00<092XZ00<08BLU028W8`0N8al00P0Q
9R802@0L8Ad07b@P024V8P0R9b<07b@P01hS7`0R9b<092TU01`P8@0201XN7`0F01/O800L82806AdP
01PK800G6Ql05QTN01LJ8@0I72<06QdT01/J800N7B<07ahT01dL8P0I6Al061TN01HG700b=3T0EUUN
01TL8@0=4AD03A8E01PI6`805AHH0P0H6A/00`0B4aD04a@F01@E5`0201TJ700?01hO8@0H6A/04Q8D
01PH6P0G5aT061PJ01HF600@41804a<E01HF600L71h06QXL010@4P0>3Ph05A@C00805A@B00@05QDC
010?3@0B4@l04Q4?0P0C4Q00100A40h04Q4?01<B3P0@3`/2014@300901<B3P0C4Q004a8@018A3`01
0000928S038`<@30_[l081dM00L04@d<0P0B3Pd2010<2`0@014=300C3`h02`L8018>3`0H51D02PD9
00H21@0>2@d0=C0f04a7C@0F4AL04PdC00`72P0>20P03`T9018<30803PP800L04P`<01<=3@0>20P0
5a4A00`61P0@2PX040P900/04@L81P0@1PD04P0<0P403P@301471P0700002P0001471P0@1PL03`D6
01`B4`0G3@h05@/<0147200700002`4200h41@0<0P<03@<400/10P8040@60P0A1@L201041P0800h2
100A1PL02P0000P0000@1PL03`<500h1200A10/201<63@0801442`0>0@P04`H=00`21P0I31<06PdD
05I9D00Y72<Dooooo`006oooool0200G5aL030`<00h>3P0C4a<04A4@00`<2P0@40h03Ph;0P0;30L0
500=3PT0414;01<C4@0@40h03`l=010@3P0A4@l03Ph<00l?3@0>3P`030`:00d=2`0@40h04A4?00l?
3@0<30X04a<A01LG5@0?3`d06a/I0P0>3P`03P0A4@l03`l=00d=2`0A4@l03`l<010@3@0=3PX030`9
01<C400A4@h03`l<00/<200<30T0410=0P0B4Pl600h?2P0B00l@2`0=3PT05aPC00/<200@4@`09BDR
01dM6`0A4@l03`l=018B400=3@/02`/900h>300<30X02`/900`<2P0>3P`03`l<0P0=3PT0100<3@P0
3@h900d>2@0>3`X200l@2`<0414<00X03a0<014A3`0=3@/03`l=014A3`0<30X0410>00/;2@0=3@/0
5aLE0P0:2PP06@0@4@d01PL2018C3P0<3@X05QLB00l@2`051P804Q<>014B3@0;30L04a@?014B3@0;
3@P02``701LH4`0A4Ph04a@@00/<2P082@L05aPF00h>3`0@4180J6QZ020Q8@0;2`T00P0@4@`01P0;
30L030d800`=200=3PT030d800d>2@80414<02<03Pl:00T8100?3PX09B@P00`;2@0;2PL051<?010?
2`0;2PL07QdI02DT800920@06APD01@D4P0=3@/03`l=00X:200?40`02@X600h?2@0?40X02@X400`=
1@0=3PH0824I00l>2P0<2`L02PT5018A3@0>3@T05A@@00l>2P0=30P05A@@00l>2P0200h=2@0300d<
1`0>3@P03@`7008030/600<040l:00/:1@0<2`H00P0<2`H0700>3@P03`h9014A3@0<3@P03@h900`>
2@0830H01P`600X>200<3`X03@l:00h?2P0?3`X03`l;00h?2@092P@03@h:00h?2@092P@04Q<=00h?
2P092P@02P/5014B30092P@0414;00l>2@0=3@L200`<1`8030d800X0;c4]0::UX`0o@d403a@A00T=
30092PP05QDA01@C3`0<2`L04Q4=0P0<2`L600l>2P<040l;00<03`h:00h=2@0>3@T00P0?3PX200h=
2@0?00d<200=30T0410>014A3`0?40h041<@00/>2`0<40d02`h;00X=2P0A4Pl02`/900`<2P0:2@L0
6aXH00807ahL00@01@@300l>300>3@/03Pd;0`0?3P`01@0@3`d04Q8B03De=@0?3`l04a<C00803@d=
00H030`<014A4@0B4Q809BDU018B4P0>3Ph600d;3003014?400C4A8030X;0080518C00@04@l@014?
4P0>30l030X=0P0?3A00100;2@`03`d@00h<3`0=2`h200l=400900d;3P061PP06ATK00T92`0A4A<0
2@T;01@D5P0>3Q002`/=00803`lA00@02`/=00d=3`0A41D03`hC0P0A41D0A00=314030/@00`;400<
2a003@`A00h=4P0A41D04Q<G00lC600@51P03a@G00hC5P0>41803@lA01HH6P0;30`03Pl?01@D4`0B
4A804a8B061PH02PX:00:2PX00h>3P0B4Q8061PH05YJFP0D51@02PX:014A4@0@41004A4A00d=3P0@
41403`l@00h>3`0?3`d04A4?00d=2@0?40/0414<014B300?40X03Pl9010A2`0?40X04A8<01XK5@0E
5Q00414;018C3@03104051D?01LH4P0O81X03Pl9014A2@0B4PX0414:01HF4@0G61804a@>01<D3`0B
4a003Pl=014C400B51403a4;0`0@4@X02P0D5@h04A@>01<F400e=c405Q/F014F4@0C61<0318=00lB
3@0B4Pd201<C3P0A01@D3`0E5A005QHA01HF4@0A4@`04Q8=00X:1P0C4`h051LA00`?2@0X:R@0?T0j
01HH4P0?4P`04Q@>01<E3`0C5Q000P0@4`d02P0C5Q0051HC018D4@0F61D05aTF01<E4P0F61D05ALD
01@F4`0E5a@201LI5P0?01@F4P0D5A0051H?01@F4@0E5a805QLB01HG500K71T051DC01DF5P0L7A`0
6AXJ01HH5`0J7a/051TE00805AXF00@05a`H01hS7`0K81`05a`H0P0I7QX0;@0G71P06b0L01TO7@0L
8R407B<R01XS8@0L9B807BHS01LR7P0N:BD07bXU018N6@0N:bD06BDQ02<^;00M9bL09S0`01`X:@0N
:BT0<cm003M5A@0N;Bd08C4`02dm?00X>3P0830`028`<`0P;c8093<f02Dd>@0T=SX0:3Xn02Pi@00S
=Sd08C@k02`oAP0eBE00=4QA02m2CP0a@e00;T1=02XlB00/?dX0<4==02XmA`0202e0B@0l03=6CP0Z
?DH0;T9:02e2B@0aADd0<dM>0354BP0dAD`0?U1D03=3A@0`?Sl0:cPi02/g=`0W<S408B/Z028Z9`0R
:bL08R`W02@_:P0Q;BX07Rd/02<e=P0P<CL0;T5:03eBG`0bAUH0;Ce9045?E@15De/0;3]302`kA00d
ADh0<D=<02/mB00/?TT0:Sa902]0C00bAe<0;d5;02<c>P0^?TH0<4170392B@0X=ch0:cY002He>`0U
<cT09C<h02Ld>@0Z=S/0:cU002`k@P0]?4<0<D160350A@0^>d40;3Lk02/f>P0W<SH09S0b0P0U;c40
<@0M;S80:3Xl02<a<`0T<3008RdY024W900Q9R807B8N02hd<01PIVH0=Sdm02D/;P0S;Bl0:3<f02Xd
=P0U;c0092h_01lX:P0N9BH08RTZ02<Y:@0P9B@08RLV01hS8P0O8b407B4O02@X9P0U:BL06b0M01dQ
7`0N8b007b@Q01PL6P0I7Q/0:2dZ030d<`0M8B80720Q01/O800M8B807B4S01/O8P0L7b@06QdR01TL
8@0J7B@061/R01<F7@0J6Al00P0N7B<02`0L6b4061PN01HG700A4QL07R0U03@g?00M82D05a/P01DJ
7P0G61`061TL00806AXM00T061TL01LH6`0E5QT05aPK01/L7`0F5aX0@T=606=TI`0h>3X00P0E5AL0
3P0K6ad05aLI01PH6P0I6A/04a<E01@D5P0C4aD0410B018B4P0B4A005aHD00L61@0E51805QDC0P0B
4@l201<B4003014@3P0B4@l04a8>00@04Q4=0P0B4@l01P0?3P`04a4B014?400M6a`0H5iO03Db<P<0
510?00H04Ph=010<2`0?2`X04@d<01<?3P0A3@`200l;2P0=01@@3`0C3`h04Ph>01@@400400006aHI
02hY;@0E41@07aXO020K8@0A3A802PD;014<3`0200`61P0:014;2`0?2@T04@/;014;2`0=1`L03`T9
010:2P0A2`/03`T901082@/04@L81P0@1PD04P0>10@06A0@00h5100@1PD060h>01071P0D2P/02`<3
00`310090@403P@501882@0<0P<040H700l51P0;0P803PD501<92P8040@60P0B1PP02P0A1@L040@6
01882@0A1PL0Ed]=05U=C`0C20T04`T:01032P0A10/20185300801442`0@0`X02`45020C6P0F2a00
200201@73P0@1@XDooooo`006oooool0500Z:RX05QHF00X:2P092@T02PX900d=2`0820H03`l<01<D
3`0B4`h03Pl900X;1@0@40h03`l=010@3P0B4Q004A4?00h>300@40h03@d;0P0;2`T01@0=3@/03`l=
01lO7@0>3P`020P600804Q8@00D061PF010@3P0<30X0410>014A3`0200d=2`<03a0;00T04Q<>00h?
2P0>3`X06Q/F01<D3`0?40/03Pl:00d>2@0<3@P01P0>3`X0200?40/02``700D60@0?40/05QLB00/<
200:2PP030`:0P0>3P`300l?3@05010@3P0>3P`03Ph<01@D4P0C51000P0=3PT0;`0<3@P03@h900d>
2@0<3@P02``700d>2@0?40/03Pl:00d>2@092@H030`:00X:200A4@l07AdK014A3`0:2PP030`:00/;
2@0>3P`03@d;01<C4@0`<2d04A8=00X;1P0<3@P02@X500h?2P0F5a80<c@_02X[9P092PD03a0;00d>
2@0D5A001PL200/<1`0T9B003Pl:00l?3@0;2`T00@40010@400J6Q`030`>00l?40092@L030d80080
2P/600<03a0;00`=200A4Pd00P0C50l01`0@4@`03@h900d>2@0:2@D04A0<010?2`0920@00P0C4Ph0
1`0J6AD03`h:01hM6@0100006QTE01hM6@0C4a400P0=3@/03P092@L03Pl;00H70P041@003Pl900l@
2P0@4@T01PL0014B2P0=30P03`h:01TH50081`<05A@@0P0:2@D01P0B4@d03`h:01DD40081`<04A0<
00`;1P803Pd8028030/600d<1`0>3@P05A@?00`;1P0=30L04a8=010?2P0:2@@03a0;00h?2P031000
1`T5014B3@0:30L03Pl:00@500092PD0414<00/<1`092PD03@h801LH4P0O81X02@X500d>20041@00
;c0Z01hO6@000@004A8<00@5000<3@L03@`70P0:2@@03`0=30L0414<014B3@0B50l05ALD010C400@
5A40004001<E4@0B4@d03`h:01PG4`0920@00P4000l>2P0500h=2@0N00l>2P0@3`/040l;010?2`0?
3PX03@`800h=2@0@3`/04A0<00`;1`0:2@D03@`8018A3P0:2PP00`<1018B400210403`l=00T:1`0B
51403Ph<00L71@0@40h03Ph<01TH5P01000051<A05ACD@0D4a4040l=0P0>3@/200l>308040l=01X0
0`<302d];@071`L04Q8B00H61P0@41003Ph>01TI6@0;2`/05QHF018B4P0>3Ph04@l@010>3`0>30d0
3@/<00h<3@0A3a002`T:014?400;2@X04@l@018@4@0A3a004Q0C014?4P803@/>0P0A3a8200l=400<
00d;3P0<2Pd03@/>014?4P0D51H01PH8010@4P0G5aT03`lA07IfN00P82804A4C0P0>3Q00200;2`d0
3Ph@01LF6`0=31403PdB00811P0P7b@05QDJ0P0>3A8200d<4@0400l>4`0>3a<04aPL00hD5`802a0C
03D03A4B00lC500>4Q<03a4@00h@3`0G6AP08B4Q02<S8`0L71`0<S8b01dM7@0:2PX03`l?024Q8@1V
IVH04A4A00h>3P0F5QH02`/;00l?3`0>3A803Ph@00d=3`0=3@h0410@018B400?40/04a@>01DF400D
5@d03a0800d>1P0>3`T030d700T:100>3`T04Q<=00T:1P0J6aD05aPB00T:1@0F5a40414;00d>1`0@
4@T04A8:00`=1P0@4@/04A8<018C3@0?40/03@d;014A3`0200l?3@0O018C3@0C5@X0414900`=1@0A
4PX04A@=00d@2@0n@CX00`P200hB3P083@L04APA01@G4@0E50l04A0;01<B3@0E50l05QD@01@C3P0H
5a8051<>01XI500I61<03`l:014B300F6A8030l8010C300B5@h05aXC01@G400201DH4@0501<F3`0B
5@h05APA01HH5@0?4@h00P0C5A800`0D5Q<0?d4n01<E4P02018D4@0901DG500F61D05ALC010B3@0C
5Pl05QPC01<E400B50l05aTF00804aDB00`06adL024S8P0H6QT051HE01LL600K81`09b`X02H[9`0H
7AT04aPD01/P700I7QX201`Q7@1W01TN6P0K81`07R@T01`R8P0I7al05b0O01lX9P0W<2d09c8^01DP
6`0I91h07R/T01<P6@0/>C80:cHb02`g=00L9RD07RXX02<_;@0^>SP0=TA4024`<00Q<C0093@c01`/
:`0M;Bd08Blb02<b=@0[>Sd0;3]002Li?@0[?D40:ca302Pk@P0hBe80:ci502@h?`0^@TT0<D==02i0
C00]?dT0;T1:0312C00a@dd0;Cm90353C@0bA4h0=dUC02m1B`0bA4h0?E5H03A8C`0hCE80<TE:03A6
BP0_@D<0;chn030l?00Y=C<09C4_02La<00V;bh07bLT028[9P0I8ah0:3<]02Pd<00O;2T0:3Pg02Dd
=`0X>T00<TA>02`nBP0]?DL09C8j028_=`0^?DD0<45902m0BP0a@dh09c]603Q;F@0gCEX09C]902]2
D00[?TT0:SU003=2B@0_?TD0;Se402Pg?P0`?dH0:3Ln02He>P0V=3X0:CHl02/h?P0/>T00:CPo02Xi
@00`?dD0<3m402/h?P0202Xe>@0C02Td>00Y<cD0:S@f02Xe=`18Ee`0F6MZ02Hc=00O:BX082TV024W
900_=3006b0L01lU8@1fOgh0=Sln02@/;P0Q:bd09c4c02H`<P0201lY:P07024Y:`0O9BD08RPX01`R
8@0H71/0720O01/O7P0201dQ800;02``;`0_<c808BDT01dQ800A5A@06alN01XN7@0H71/06AdL01<G
5P0J7Ql00P0H71d05P0I7Ah06QhP01PL7`0D5a`05APM01XM8P0N8BP07B0W01LJ8@0G5Q`061LM01LF
700F5A/05aLM01XK800;31405QPM01TL8@0N8BH04QHJ00/@500H6Ah201`M8@0A01PI7@0G61`06AXN
01HG6`0L7B407b0T02HW:`2SY:P0o_oo07AdMP0A4A<05ADG01PH6P0>3Q007alQ00l?4@0A4A<00P0G
5aT02@0A4A<04A4A020O7P1FEE<0;bh/014@3P0=30X05A@B018A3`0201<B4005014@3P0B4@l04a8>
018A300A40`00P0@3`/02P0?3P`03Pd;00l>300?3@h03@/<01@B4`0610D07a`L01<?3P0A3@`200l;
2P<04@d<01d0510?014=300=2@P03PX9018>3@0E4A003PX9014=300C3`h03`/<01<>4@080`L050lC
00d83@0A31804PdC00l:3@0=1`L030H600l92@0=1`L03`T9014;2`0@2PX05@l?00d71`0D3Ph03PP8
00l71`05014720H03`D61P0@1PD0500;0@002P0000l5100D2PT01`0001071P0<0P<02`4201D;300=
0`@0308300d3100I3a00308301061`0H3Pl03P@501882@0?0`D040@60P0C1`T02P0A1@L03`<500h2
100E2``050P:01P<3P0F2P`0200001032P0?0PT200h1200800l22@0@0`X04PD<00/01@0D1`h07A0G
01/A5@0C1PdDooooo`006oooool0400N7Qh02@T901XJ6P0H61P030`;00X:20051@<02`/8010A300E
5Q402``7018C3@0A4@l02`/900P81P0;2`T2010@3P0;01HF500:2PP04Q8@00l?3@0B4Q00410>00h>
300D51801@D300h>300F5Q@00P0B4Q004P0=3@/03`l=018B400<30X01`L500d>2@0;30H03a0:00`=
1`0:2`D03Pl901lP6P0I6Q@030d700d>200?40X01`P200h?2P803a0;00/03@h900h?2P0?40/05aPC
014B3@0=3PT030d800h?2P0?40`03Ph<00d=2`0200`<2P0400d=2`0?3`d04A4?010@3P<03Ph<00@0
3@d:00`=200=3PT03a0;0P0@4@`07P0A4Pd02P/600X;1P0>3`X01`P300X;1P0C51003Ph<00`<2P0?
3`d04a<A018B400?3`d0410>018B400>3P`02PX800d=2`0A4Ph0004000/<1`0<3@P0414<01<D3`0>
3`X0Q8F005MHD`051P407QlJ00l@2`802``601L030d700d>2@0>3`X0414<00`<2P0=3@/0410>00l?
3`0=3@d02`/;00h>300=3PT02``700X;1P0;30L03Pl:014B3@082@@02``700l@2`0:2`H03Pl:00d<
200200`;1`803Pd900<02`X600l>2P0?3PX00P0@3`/03P0?3PX03@`800P81P0;2`T02@T701dM6`06
1`<02P/600`=1`0=3PP02``600P90@0;30@04A8:1P0=30P02`0>3@T03`h:00l>2P0<2`L03@`801<B
3P0A40/030/600l>2@0B4@`04A0;00<03Pd80P0=30L200`;1P0Q00/<1`092PD02@X500`=200=30P0
30d800d=2@0=30P0414<00d>2@0;30L04A8=014B300H6A<04A8<00X;1P0J6aD01`P202DV800@4@/0
6Q/E00`=1`0C50h010D000h=1@0A3PL03@X300d<1`0?3PT02P/500`=200G6A@020T7008051HC0180
414=018A3@0>3@T05A@@00`;1`061@404A0<01@C3`0@3`/02PT501<B3P0?3PX02`X7014@300@3`/0
3Pd900`;1`0;2PH200d<200B014@300=30P05A@@00L60P0C4Pl020P601<C4@0:2PP00P80018A3`0>
3P`02PX800P71@0<30X03`l=01@D4P0>3@/03`h<0P0@3`d200l>300300d<2P0>3@/03`h<00803@`:
00d03`h<00d=3@0B4Q80410@00`<300?3`l02`/;00D51@0=3@d051@D00h>3P0;2`/03`l?00<040h?
00T03`d>00h<3@0>30d03@/<01@B4`0L6Q/05aDF010>3`0=2``01P0;2@`201HD5`0=01@B5@0B41<0
3`d@00d;3P051@L0410B00T92`0:2P`071`N08Z:S00S8bD05ADG00l?4@0201@D5P0I00`<3P0<2a00
3PdB00d<4@0@3a@05A@I014@5@0=31403`hC01DD6@0D4aP03`hC010A5@0I7R802Q4D00D:3@1WK6l0
3a<D01HJ6`0?4a@01PP700`>3@0;3@`02`/;01<C4`0400l?3`0500d=3@0<30`06ATI00l?3`0<30`0
0P0=3@d0200<30`040lD02h^<00Z:R`03@d>010@400A4@l03a0;0P0;30H03`0?40P0414900l@200G
61<05AHA00`=200G61<05QLB00L8100E5Q404A8=00`=200C50l04A8=018C3002010A2@0R010A2P0@
4@/0414;00l@2`0C50l04Q8@00h>300D51805ADC014B30082P004Q<;00h?1`0<3@D061/D018E3P0C
5Pl05AXD00lD3P0A5Q004aXC00/>200K6QD06QTD018A300F5A0010<001TH4`0=30L061LB00P70P0F
5A004a<=018C3@804QD>0P0?4P/03@0A50d08RDN01LJ4`0I71D061/D01/N5`0F6A804A<@01DG500D
5Q<04Q@A02DW901FF5D00P0@4Pl01`0C5A805ALD01HH5@0H6QH04A<>01<F3`0F61<00P0E5a800`0G
6AH061XG01PJ5`0201LI60806A/J04H07R<O01dR7P0J7a/061dI01HK5`0D6AD061dI01TN6P0F6aL0
51TE01HK5`0I7QX09B/[01TO7`0P9RH02Q<B01lX9P0G81d07BPT01dX8`0I91h05B8K01TV7`0P;BH0
7bXT01hY900O:RH082`X02Da;P0Y=C<0?Ta<02<b<P0R<S809CDe01d];@0O;bl08Blb01h]<00Q<3<0
:3Ll02Hh?00T=SX0;3e402e0A`0dAdh0:ci502a0A`0[?dH0?E1G03a>F00Z?D@0?E1G0=;Uk01JKG@0
;T1:0312C00oDE/0<D==03I8DP0/?TP0<dM=03M:D01NLGD0:C/o03Y9C00_?cl0;3Xk03A0@00Z=S@0
82/X0P0R:bP0>`0a>SL0:34^01hX900L9b408RlX02Ld<@0O;bh08C0c02Tk@@0X>D<09CI002dlAP0X
=Ch0<3i702`jA00W>480=4AA02m1CP0]@4h0?e9Q03=9F00^AED0>U5Q02PkAP0d@DL0>DI<02hl@P0[
>Sl0;ci5030oAP15E5/0NHR?0350A`0^?D@0:SU002Pg?P0/>d80;Ca302hm@`0b@DH0;S]102Lb=P0Y
=3P0;cXn02hh>P0Y<cD0;3Li04QEF`10Ce80:CHh02<];P0]=S<09B/X02H[9`0R9b<08RPT024Z:@0O
:2L08R`]00807BLX00/07RHX01dU9`0Q:B/0;C<c01`R8P0M8b<082@S01lS8P0N8al07B8N020T8`02
024U900301/O7P0H71/05QXI00<06alN01@06QhM01TM700G6aX09BTZ04A8B@0F6Q/0720Q01hR900N
8RD06ahS01HI7P0D5a`05QTP01DH7`0B5A`05QDM01LF7P0J6B407A`T01dM9@806QXR01L04a@L01@G
7P0M82L08RH]01hS9`0J6b0061TN01DF6`0D5AX05QLL01PI7P0K72406Q/P01LH7@0H6Ah0Jfaa0<O8
c014A4H04Q8D01LG6@0K6ad04Q8D01LG6@0201@D5P804a<E00P04Q8D018B4P0e<c<0dm;@03/j>00A
40h05QDC01<B40D040l=01@040l;01<B3@0<2`L04Q4=014@300D4a403Pd;00l>300;2@X06ALH00l=
3P0F51D05A8B00l;2P0A3@`03`/:014=300E4A003PX901@@3`<04@d<00X03PX901DA3`0C3``04@d:
010<2P0@30/04@d<01<?3`0B3Pl04@`@0P0@2`l04`0A310040X=00l92@0=1`L03`T901D?3`0F4100
6A<C00X4100<1PH050h>00h8200B30`04@T:01061`0B20T050X;01D;300G3@h00P0B20T04@0A1`P0
3P@500l51P0C2@X03`D401<9200E2`X03P@300`20@0A1`H01`0000`20@0H3Pd02P0000/1000?1@@0
2`4200804@L800T03P@501<92P0A1`P03`D600h41@0?1@H03P@500`20`0@1PL01P0@10H0300A1@L0
40@600l31@0?0`D040@601451`0:00@03@4701442`0B1@`040<:00/01@H040<:5?ooool001_ooooo
00P04A4A018B4P0;2`/03`l?00h>3@0F5Q@06ATG00d=2P80414<01404a@?00P90`0B4Q002PX801DE
4`0V9R@08B4O00P81`0B4Q0030`:018B400:2PP03`l=00h>300M7A/030`;00h>300201<C4@0H00l?
3@0B4Q003Ph<00d=2`0>3P`0410>014B3@0=3PT03a0:00`=1`0>3`T03a0:00`=1`0C50h04Q<=00/<
1P0?40X04A8<00T:100=3PT03a0;00h?2P0<3@P03@h90P0>3`X200d>2@8030d800T0414=01<C4@0A
4@l03`l=00d=2`0<30X03`l=010@3P0?3`d00`0>3P`0100=3PX030d800d>2@0?40/3010A300700T:
1@0:2`H061TD01DF4@0@4@`04A4>00l?3@0300h>30803`l=01h03@d;00`<2P0?3`d04A4?00h>300;
2`P0414<018C3P0;30L030d8010A300A4Pd0414>00d>2@0O81/04a@?00`=2@0=3@L030d600d=1`0>
3PT03`l:014A300=30T03Pd:010?3@0@3`h03Pd<00`;2P0=3@/500d>2@0800/<1`061`@05AHA00<4
000C50l051D@01LF4P0B4@d200d<2003018A3@0C4Ph040l;008051<?00`04A0<00d<200=30P05ADC
00/;2P0;2`T02`/:0492?`0G61D03a0:010A2`0>3`T200`=1@0300l@200=30P03@`800@03@`800@0
3`h:00`;1`0;2PH03@`80P0?3PX00`0=30L030/600l>2@02018A300300l>2@0>3@P03Pd800803@`7
0P0<2`H0A`0=3PT02``700/<1`0@3PX04@h;010=2P0?30P03`d9014@300>3`X03@l:018D3`0F5a40
4a@>02@U7`0A4P`02``6010A2`0B4`d0<c@^01LH4P0<3@L02``601<D3P0@3@D04@h700h;100?3@L0
3`h900`;1P0<3@P051D@00h?2`0>40`01PP4010A3@0@3`/030/701HE4@0C4Ph04Q4=01TH500>3@T0
3`h:01HE4@0@3`/03Pd9010?2`0>3@T03@`800h=2@0?3PX040l;00l>2P0<2`L040l;00`;1`0F5A40
3Pd9018A3`0I6QP02`/900l>300F51801@81018?3@0?30/04Pl>01<B400=3@/03Pl=00803Pd;0`0?
3P`0400>3@/030/900d<2P0>3@/030/900/:200>3@/04A4A010@400:2PX02`/;014A4@0?3`l02`/;
00`<300=3@d200`<300500l?3`0@3Pl040h?010>3`0?3@h00`0>30d01@0D4Q<061HG01@B4`0?3@h0
3P`=00H03`d@00<03P`?00l=400@3Q400P0?3A004`0>30l030`>00l?4@0>3Q006ATK00D51`0F5QP0
3Ph@00/;3@0=3@l04A4C018B500=3@l02`X?00d<4@0<2a003@`A014@5@0;2Pl00P0@3a@0400E51T0
4a8G010?500C51P04ADJ00`@500?4QD0Ada?01<E5`0?4A<030l@01LH5`0U9RD0820P00h=3@0;2PX4
00l?3`0600d=3@0<30`05ADE014A4@0?3`l03Ph>0P0?3`l01`0C4a@06a/L01PH6@0?3`l04Q8@00/;
2@0>3PX00P0E5Q40A00@4@/03a0:014B300=3PX03Pl;010@3@092PH08B8N02LW900U9B80;BhZ010@
3@092@H04Q8?018D3P0@50/04A<;014C300A4`d04Q<=010A300A4Pd04A0>00h>300B4@l0518@018B
3@0I6Q<0:b`U01hO600:2`@04Q@>014D3P0A4`d041D@00hC3P0E6QD06B0J01TL5`0D50l061PC018B
3@0O7aX04A4<01@D3`0F5Q404Q8=00T91P0J6QD03Pl:01<E3`0D5Q0061/E01`O6@0J7AL051LA01HI
4`0A50h05aXD010C3@0B50h051LA014C400C5A805QPE01DG500G6AH07b4N0`0E5a@201HH5@0601HH
500A5@l051PA01HJ500E61<04aHA0P0B5Q803P0E61D05aXI01DH5`0G6QT071lN01LL600F6aL051TE
01DJ5P0F6aL05a`H01PM6@0K81`06QlK0P0I7QX0I`0K81`04ALE01hT8`0Z<2l0D5UG01/T8P0R:bP0
51lK01`W8`0G8Qd05R<M01h[9@0M:B@08B`V020[9P0N:BD07BTV01l[:@0Q;B`09cDf020_<00S<S@0
9cHh02Dd>00T<cL08c4d01l^<@0P;c809SDj02do@`0bA4P0:S]202e0A`0cATd0:Ca302e1B00^@TT0
;T5802Xl@`0^@4L0;Cm603mAF@1AHf/0@E=L02XlAP0fB580;Sm903I7DP0eAe40=dY?04ULH01GJfd0
=4I80351@@0_?ch0;3Th02Xe<`0[=c<09c4^028[9`0T;BT09Bh/02@^;00Q;2P082/V028^:@0U<Rl0
9C<c02/i>P0fA4/0<T9:02hkA`0Y=d<0:3M302hmB@0a@Td0=DMD03A6D`0]@4h0<DAC03Q>G00aAeH0
;TAE03A:G00b@dh0=415030m@P0[>Ch0;C]002Th?P0Z>Cl0Q9>J0=?RiP1@H6L0830h02Ph@00/?4<0
;ci502hmA00]?480<3m402hk@@0`>cl00P0/=c/03P0`>S`0;3Hh02Pb=00W=3X09S@g02<]<00Z<S@0
<S/h02X`;@0V:bL08BLS028Y9@0R:bX07bTX0P0R;2d03`0S;2h09Bd_02P_<00Y<340:c4a01hS8`0N
8b807b<R01lR7`0L81`06ahK01LK6P0K7al082@T01lS8`0201hR8P0?01/O7`0L82007B4Q01dQ8@0K
7al06AdM01@H6@0R9RL05a/L01TM7P0H71h07b<V01dP9@0J7B8061/P00806A`S01h05QTP01PG7`0I
62007QdU024P:00O7bL06a/S01dM9@0I6R805QTP01LJ8@0G6b805AXP01`M8P0J6b005aPM01HG700G
61d061TN024R9`0A4QL07AhS01PI7P0P8BH0:2T]020O8`0:2P`04A4C01XJ700E5AL301@D5P804a<E
00P04Q8D018B4P0@3Ph0;B`Z010?3@0D4a4030/901@C4@D04a8@03<04a8>028Q700C4Ph04a8>00h=
2@0D4a404A0>018A3`0E4a@030X;01<A4P091`P04@h>00d9200D40l04`l>00l;2P0E4A006ADD02@P
7`0K5aH04`l>00l;2P0<20L04`l=018>2`0A3@X04@d;010<2P0@30/04@d<014=3@0@2`h03`X=00h:
300?2Ph040/<01LA4@090`<050h>00d8200S7Ad0DTa<01<=3@0<1PH04@/;00l92@0A2`/03`L80147
200B20T00P0C2@X05P0D2P/040H701882@0C2@X04@L801061`0B20T03`D401<9200D2PT040H500l5
100C2@P05@/:00T0000J40l05@/:00/30P0L4Q404@L801061`0?1@H200h41@0400d3100>10D03`D6
01061`803P@500<04@L801041P0@10H0100@10H02`0A1@L040@600l31@0?0`D040@601451`0C1Pd0
3`8900d01`0?0PT04@@;00L040<:5?ooool001_ooooo024010@400L71`0E5AD08B4Q00L71P0j>SP0
VYZH02@U8@0G61<030d800L8100D5@l02`/9020P7P0N7Q`02PX800<30P0C4a404Q8@00H6100820H0
2@T7014A3`0=3@/0X:2N02@T8P0>3P`02PX800l?3@0A4@l02PX801@D4P0F5Q@00P0B4Q001P0D5A00
414;01@E3`0;30H0414;01DF40802``600P03Pl900`=1`0@4@/0414;00/<1P0>3`X0414<00l@2`80
3Pl:00@0414<00h?2P0=3PT03@h90P0<3@P01P0=3@X03@d;00`<2P0<30X03@d;00h>30803`l=00L0
3Ph<00d=2`0>3P`03Ph<00h>2`0=3PT03Pl:00@03a0;00`02P/600`=200I6QD05aPC014B3@0?3``0
4A4?018B400>3P`02PX800d=2`0@40h200h>300A018B400C4a40410>00/<200B4`h03a0;01XK5P0=
3PT010D200/<1`0E5Q405aPC00H70P0<3@P03a0;00d<1`0=3@D00P0=30L0100>3@P040l;00h=2@0>
3@T200l>300400h=2`0=2`/030d800d>2@80414<01L03a0;00d>2@041@0061TD00`=2P0;30L04a@?
04E6@@0N7AT06APD010?2`0=30P03`h:010?2`0?3PX05QDA01LF4P0B4@d03Pd900l>2P0G5aD03Ph<
00410002014A3`04000100092P@02``600`=1`802``400<02P/300d<200=30P0100=30P2010?2`0:
00d<200>3@T04A0<00d<200=30L02PT401PG4P0/:bH09RDP00@300803Pd80P0=30L0<P0<2`H02``6
00d>2@0:2`H02``7014=2P0B3@X04@`901<>2`0B3P/040l;00`<200:30L030h901PI4`0U9R0061TC
00h?2@0?40X01@H000X;1@0M7QP030d701<D3P0;30H02PX2010=1@0@3@H03``5010=1P0>3@P03@`7
00h=200<3@P02``703dn>@0Q8ah03@d9010?2`0:2@D03`h:00h=2@0=30P04a8>00P70`0920@05QDA
01DD400@3`/03Pd90P0<2`L05`0>3@T03`h:014@300E51003@`800/:1P0B4@d081lK00X91@0B4`l0
0P@10000000F51806ADD01LA4@0C3@d04P`<00`81`0920H051@B038d<@0<2`T03@`:00803Pd;0P0=
30X00`0<2`T03@`:00h=2`0200`;2@0=00h=2`15ADD0=3@d01HF5P0;2`/03`l?014A4@0?3`l03@d=
00/;2`0>3Ph03`l?00d=3@03010>3`0900l=3P0>30d03P`=00h<3@0@3Pl04@l@00d;300:20T030X;
00L03P`?00<040hA018@4`0B41<00P0B41<00`0820X03Ph@00H6200200l?4@0K01DE5`0>3Q00410B
00l?4@0=3@l030`>00/;3@0B4AH051<H014@5@0B4AH04a8G00/:3`0@3a@03`hC014@5@0@3a@03`hC
01DD6@0720d041<G00P<3`041PX02@X<00`=3`0C4aD03@d=00804@l@00<03`d>018@4@0?3`l00`0?
3`l04`0=3@d030`<00h>3P0C4a<04Q8B00l?3`0@41004Q8B00h>3@0;2`/03Ph<01HF5@0M7A/04A4?
00l?3@0F5Q@05QLB014A3P0?3`d00P0@40h05`0;2`T061PF010@3P0A4@l08R8P02LW9@0N7Q`06a/I
01hN700B4Q004A<=00lE2`0A50/04A@<014D3@0B4`d04a@>01<D3`0C4Q004Q4?01@C4@0G4a804Q4>
00802``602D04Q<=01LH4`0F61<03Q0;00d?300?51004ADC00/?3P0`=S@0FeiL01/M600H61H06AXF
01`N6@0K6aT04A8>01DG4P0=3P/0410>02PZ9@0F5a<051HC01<E400H6QH08B<P020R7@0G6AD05QPE
018D3`0H6QH04aDB01HH4`0I6aP05QPE01@F4`0A4a004Q@A00804aDB1@0B5140100B51004aPB01@I
4P0E6Q@201<H4P0401HK5`0M8Qh06b0L01TM708061`K00T05a/J01PM6@0G71P05Q/G01LL600J7a/0
7B8N01HK5`0K81`00P0L8Ad201/P701M01HL600R:2@0=C/g06igM00R:bP03QLD01dX900L9b<08B`X
024]:`0P;2X09C4]020[9`0P:bH082/W020/:P0R;Rd092la01h/;@0U<cH08c8g028a=P0U=3/08C0g
02Le>@0T<cH08C0c024`=@0Y>cl0<49604MHG`0/?dH0:Ca302`oAP0^@TT08SLl02m1A@0iBU40:S]2
02m0A`0a@TX0RY^S061aN@0^?dT0;3e704=DGP0lC5T0:CY403E9C00bATL07S8a02m2@@0eAD@0<T4n
030l>@0X<bl0;cXd02L`:`0K9Ad08BXU02</;00S;Bh08R`[020[9`0O:bT08Rh/02Lc<`0]>ch0=T=:
03A1BP0`?4P0;Ce;03A7EP0[?Td0;3i>03Y=G00dAeH0;D1?03I9F00kDEl0?E9R03I;G00aA5D0>DUD
03M2AP0/>Sd0:cPm02ll@P0/>d00;Ca202Th?`0mCUD0:3U10080=4E=0280:CU002`k@P0]?4<0;ci4
03=2A`0`?D<0;cXn02/f>P0/=c/0<S`n030j?00_>C/0:SDk02/f>P0T;S407bLY028[:00P9R<09B/W
028X900R:bH08R`[01l[:@0Q;Bd07RPY020X:P0T;2h0:S0`02L];@0O9BD06QhM01/O7P0M8Qh0828O
0P0Q8b00200L81l082@U02DY:P0T:2T08BDV01lS900J7Ql07B4R0P0P92D02`0M8B806QhO01dQ8P0L
824082@U01XN7`0M8B<0720S01/N8`0I72405aXO00<05aXQ00l06QTQ01PG7`0G5Qh06APP01PH800E
5Ad05QHN01PJ8@0G6R405APO01DI7`0H7B<07AdU01/L8@0I6Ql00`0G61d0300b<cP061TN014B5`07
20d08R<X01HG700C4aH05ADG01LG6@0M7Al06QXL01<C5@8051@F0P0C4aD0200B4Q@04Q8B01XH600G
5Q@071/I00l>300>3@/03`h<1@0D4a401P0D4`l03@`800`;1`0C4Ph040l;01<B40803`h<00T05Q@E
00`:2`15@d@06ALH01TF5P0@30/04`l>01@@3`0@30/00P0E4A001`0L61L05Q8A010<2`0>2PT02`L6
018>300@30T00P0B3P/01@0@30T03`/:00l;2P0@30/03`/<00803PX;00D03PT=00d8200M5aL04@/;
00/51@0200@0000702<M7@0@2PX03@L700l92@0@2PX05@l?01<;2`050147200400h41@0A1`P050X;
01882@8040H701<03`D401471P0C2@P04PP701471P0E2`X03@<201/A4017?C`0:AlN00/1000l<S40
4`T:00d3100?1@H04`T:01061`0D2P/02`4200803P@500<0308300l51P0A1`P01P0@10H0300A1@L0
40@600l31@0?0`D040@601451`0B1@`040<:01442`0B1@`040<:00/01@H040<:5?ooool001_ooooo
00P051@D01HF5P0=3@d03Ph>01HF5@1hN7H0g]kL03Hg<`8030d802L03@h900/<1P0820H05QHD01hN
700I6AL03`l=00X:200<30X05aLE01`L6P0<30X04A4?010@3P0/;2X020P601DE4`0>3P`030`:01<C
4@0?3`d03Ph<00`<2P0A4@l09BDS038c;P0N7aP07b0H018C2`0A4PX04Q<;00L8000=3PH03a0800h?
1`0A4PX03a0800X;1@0@4@`00P0A4Pd02@0?40/0414<014B3@0E5Q40414<00d>2@0<3@P03Pl:00h?
2`0300`<2P0400d=2`0>3P`03`l=00h>30803@d;0P0>3P`00`0>3P/03@h900h?2P0200l@2`0<00h?
2P0=3PT030d800h?2P0B4`h03Pl:00d>2@0@40d04Q8@01<C4@0?3`d030`:0`0>3P`05P0A4@l0410>
00d=2`0>3P`05ADB01TJ5@0;30L03@h9018C3P1LGEP04Q<>00/<1`0?40/02@X500`=200=3PP03Pd8
00h>1P0=3@D03@`700h=200@3`X300l>2P803Pd;00<03@`:00`=200=3PT00P0@4@`02`0?40/03@h9
04E6@@25QX405aPC00@500082@@03Pl:01LF4P0D4`l040l;00803`h:00P03Pd900X91@0@3`/04Q4=
010?2`0>3@T03`h:00L71@803@d;00H07QhL00X;200M7QT020T300T:100;30H200d>1P0300`=1@0=
30P03@`800D03@`800/04a8>00h=2@0<2`L03`h:00`;1`0@3`X020L300D4000A40/06APC00X91002
00h=20803@`700`030/600/<1P0;30L02@X500X;1P0?2`P04@`9018:200B2`T04Ph;00h=2@0<30L2
00/=200801PI4`0[;2H0414;00/<1P0C50h01`P200l@2P000@02014B300@018C3@071`004@h6014=
100B3PD04@h7010=1P0A3PL03`h900`=1`0;30L0?Chi024R7@0=3@P04A0<00X91@802`X600T020L3
00l>2P0<2`L02PT5014@300N7AT05aHB00/:1P0>3@T00P0=30P00`0>3@T03`h:01<B3P02010?2`0A
014@300O7QX040l;010A3@072@H0:RXX04I4@P0B3Pd0100001482@0@2PX04Ph=014@3P0>3P`06A/H
00`;2@0=30X00P0>3@/200d<2P0300h=2`0?3P`040l=00803Pd;00H040l=03@d=00U9BD03`l?00/;
2`0?3`l2010@40803Ph>0P0C4a<01@0<30`040h?010>3`0@3Pl03`d>00803P`=0P0@3Pl0100?3@h0
30X;00`:2`0>30d600h<3`0;00l=400@3Q4040hA010>4@0?3A003@/>00410`0?3a402`/=00h>400?
3a400P0;2`d01`0=3@l030`>00`<3P0@41805QHH014@5@0D4aP00`0A41D03`0920d03PdB00d<4@0?
3Q<03PdB00`;400C4QL01`P=00`=4@0F5a/06a/O01XJ70051@L03`d@014?400201PD5@0300l;300:
20T03`l?00<03`l?00<03@d=00`<300<30`00P0B4Q803`0@41004A4A01@D50092PH030`:00l@2`0E
5A<071`J014A3`0B4Q00410>00l?3@0A4A004A4A014A3`0200h>300:01@D4P0?3`d00P8001DE500g
=cD09RHT02DU8`0F5Q@00P8001@F40803A<902d03Q<:00lB2`0@4@/04A8<010A300@3`d04@l=014=
300B3Pd04Q4>01PI500I6QD05QLB01<C4@0C5A805aTF010B4@0;3`h03a<C01/O801eNg/0fn3O04eB
CP0A4a804QHC01dR7P0I6aX03Q8?00P=2@0D61D03Q0?00X?2`0=3P`05ALF018D4@0C5A<06Q`K01`N
6`0F61H06A/J010B3`0D5Q@05ALF01TK600G6AL00P0E5a@0100C5A804Q@A01HH5@0O8Ah2010B3`0=
014C400B51404aDB01@F4P0K81X06QlH01DJ500A5Q004QLA01PM6@0Q9R806b0L01HJ6@0201/O7P03
01@H5`0K81`06QlK00806AhJ00D06b0L01`Q7@0D6AD06AhJ01`Q7@0201/P700G01`Q7@0O9Ql0:S4Z
02T`:@0W<2/06b@O02D^:`0K9R8082XY04E?CP15DE408bl_01dY:@0Q;2P08B`Y024[:P0Q;Bd092l`
02@_<@0S<C@09cDj024`=`0O;SD00P0S<CX0I@0W=CT0:3Lj02Lf>@0V=CX0:C/o02i0A00oD5L0<4=:
02i1B00`@dX0=DU@02a1AP0_@D@0;3i202Li?@0eAd/0<T=:04AEG00dADd0=dQB028c?@0b@dd0<T9?
03=4CP0bADP0?4i@02Xl?00a@D00<d5102Pg=00/>3D0:C@`030k=@0U;RP072<L02</9`0Z<cD09Bla
024[;00O:BP07RPY02@_;`0]>3X0<Se103E0A`0g@D/0=T1<0311C`0cB5T0;D9C0355EP0fBe`0<4EF
02m3D`0fBEP0>diM03e@G`0fBEP0<T=C03U7D@0c?T00:cHj02Hb=P0W=CP0;3To03=1B00U=3/0>DYB
03A5CP0Q<cd09cU302Xj@P0/>d80;ci50391A`0d@dP0;S]102Xe>@0Y=3P0;3Lk02`f>00Y<cD0;SPj
020[<@0U<3@09Bha01hV:00P9R@09BTW02@Z9P0R:2@08R/V02<];00O:bT08Bd]024[:P0T;B`0;38b
02hd=00Y;bl08RHU00807B4P00T0828O024S7P0R91l092HR01hR8@0Q9BH092PY024U9P0N8R<00P0L
82402`0N8R<082@U01lS900M8B806QhO01hR8`0M8B8061`M018F5`0L828041@G00806A`Q00H061/P
01LJ8@0H6b806A`S028P:`0L6RD201HD7`0;01PG8@0G5b4051@N01TK900I72D05QTR01LK900K82H0
71`T01/K8`0I6B400P0H62003@0G5al05QHN01HF7P0R8RX09RH^059BFP1;C5404a<F01PH6P0E5AL0
5aLI01HF600@41800P0D51H201<C5@08018B500B4Q805aDE014@3P0>3@/04a8@01LF50030P05018A
3`0D018A3@0F5A0051<?01PG4`0A40`040l=00`;2@0A40h05Q@E00/92P10?Sl0518C020M7@0E4A00
3`/:01<?3P0D40l05A4@00h:2@0B3Pd2010<2`0;00l;2P0;1`H04@d;010=200A3PT04Ph:010<2@0>
2PL03`/9014=300@30d00`0?2``03P0:1PH02`D501H@400F41007aTI01hH600;1@D02@<300l92@0=
1`L02@<3014;2`0B2P/04PP90P0A1`P201061`0400h41@0A1`P050X;01882@8040H700<040H50147
1P0B20L00P0B20L02@0D2PT03P@300d30P0P5QD04`T800L0000@1PD03`D600d3100200l51P0600d3
100@1PL04`T:01L=3P0D2P/03@<40P0@1PL601041P0:01451`0@10H03`<500l31@0@10H04@D700h1
200=00L03P4801032P804`H=1P0@0`XDooooo`006oooool0<@0e=CD0:2PX00/;2`0@41004a<B00h>
300X:2H04Q<?00l@2`0>3`X051D@00/<200C4a40410>00X:2@092@L03@d;010@3P071`D0:BTW038b
<00A4@l0410>014A3`0F5Q@020P700/;2@0@40h04A4?010@3P0>3P`04A4?010@3P0=3@/03`l=01<D
3`0>3`P03a0800d>1P0@4@T04A8:00h?1`0A4PX03a08010A2@0A4PX03Pl700`=1@0?40/00P0@4@`0
300>3`X03a0;010A300E5Q40414<00d>2@0<3@P03Pl:014A3P0A4@l0410>00l?3@<03Ph<0`0=3@/2
00h>300400h?2`0>3`X03Pl:00l@2`803Pl:00P030d800d>2@0=3PT03Pl:00d>2@0>3`X0410=010@
3P<03`l=0P0@40h200l?3@0@00`<2P0820H02`/900l?30092PD0414<01<D3`0>3``04a@@00L8100H
6A@04a@?00T:1@0>3`X0414;00l>2@803`h600L03P`600l=1`0@3PT04@h;010>2P0@3@X03``;0080
3P`:1P0=3PT02@0I6QD0;c0[00X;200C50l04Q<>00/<1`0<2`L02`X600d<2002010?2`0>00h=2@0<
2`L02PT500X91@0=30P03Pd900`;1`0=3@/03`l=014A3`0000004A8?00d>2@0@4@/200d>200300l@
200A4PX0414900H03@`800/02`X600h=2@0:2@D040l;01LF4P0:2@D01`H201dL5`0G5Q402`X500`;
1P0300h=20803@`700h030/600/<1P0<3@P02@X500/:1P0@30T04`/90189200D30X05A0=010<2@0>
3PX03a4<00d?2P803Pl902@03@h800h?2@0310003Pl900l@2P0720@05aPB00`=1`0A4P`04A49018>
1P0@30<05107014>1P0?30D04a0900d=1P0D50h03@h800`=2@041@803@d8014@300<2`L03@`800h=
2@0;2PH040l;014@300?3PX040l;01/J5P0F5A403Pd9010?2`0?3PX300d<200B00`;1`0?3PX05aHB
00/:1P0E51006APD04Q9A@0?4@h020P701TG5P0@2PX07aHG01<:2P0D2``04P`<014?3@0:2PP030h;
0P0>3@/300l>300C00h=2`0?3P`040l=014@3P0?3P`03Pd;014@3P0A4A4030`<00h>3P0D51@0410@
00/;2`0@41003`l?010@400C4a<04Q8B00d=3@03010>3`0600l=3P0>30d03P`=01<A4P0B41404@l@
0`0@3Pl6010>4@80518E00`04a4D018@4`0@3Q403P`?010@4P0;2`d020P:00X:300A4A<02@T;010@
4P0>3Q0200`<3P0700h>400A4A<05A@I01PG700F5AX05aHK01DD6@0300`;400A010?500?3Q<030/@
010?500>3Q<04a<H00`:3`0=31404@dA01<?4`0A3A403`X<010;300A30h040/<00h92`0?3Pl00`0?
3`l0600=3@d030`<00d=3@0?3`l0410@018B4P0C4a<04a<A00d>200A4P`0414<00d>200B4`l02PX7
01@D4P0>3Ph03@d>010@4@0F5QL061PI00l?3P0E5A<04A4?00`<2P803`l=03/05aLE00`<2P0A4@l0
5ADC00`<2`0A50h03A@:00hD2P0?50/041<<010B300D5@l04a<>018A3`0F4a804`l>01@?3`0D4Q00
4a@@00`=2@0F5QD06a/J00d?3@0@4Q806Q/L01<G6@0E6A/05a/M04iDE@2IWYl0;C8b00dB4@0A5QH0
3a@C010E5@0L8B0051TI01<H600F6a/0EEYI02X_;`0E5QL04aDE018C500D5AH05QLH01DG5`0M7Ql0
4aDE01LI6@0H6AX071dN01TK6`0A4a005ALD01XL6@0G6AH05QPE01XL6@0201@F4`0B01DG500F61D0
5QPE01LI5@0M8Q`06b4J01HL5@0@5Pl03aD?01@I5@0F6aL051TE01<H5`0G71/06QlN01PM700H7AT0
6AhJ0P0J7a/0100I7QX05a`H01HK5`0I7QX201/P700F01dR7P0P9Al07RDL028Y800H7aP04Q`D024Z
900H8A`082XY01/U9@0_>C/0<Cdn020[;P0R;C008R`/02<];00S;Bd08Rh_028]<00Q;340:SLm02@b
>P808c4k02T0938n02Xh@P0V=3P09cHi02Xi?00]?440;T1402m1A@0/?D@0>diE03U<D`0/?dH0<TI=
02i3B00Y>ch0:S`o0394A`0/?T80>T]B03U:D@0cA4`0>DYD04MHHP2P/;`0DF5^02/lAP0eAdX0@eEE
06]mO@0Z>ST09SDb02Th=@0S;b/09C0Z02Td;@0V<2P08bXR028[9P0[<cL08b`a024[;@02028/;P0O
02H`<P0^>C/0<3Y102dg?`0`>T@0<Sa802dnC`0/A5L0AUic05M/P00lDV<0=T]M03A8F@0_@U40=dUI
03I8E`0^?dh0=TME03I3C00`>S`0;3Lj02Xe>@0V<cH0:cPn02lmA00Y>3l0=DI>02dnA`0[?DL0>DaE
02doAP0203=2B@040350AP0`?d@0:CHl02/f>P80:C@h01P09c4c028/;P0W<C<0=d57034k?`0X<3<0
9BX]02<Y9`0R9R@092XV028X900S;BP09Bl^024]:`0P;Bd082TX02L_;P0]<c<0:Bl^02@Z:@0S9bH0
92PV02<W9@0R9242020R7@0=020R7P0L82007R8T01lS9@0M8B<0720R01dQ8`0Q9BL082@V01dQ8`0L
82806alQ01XN800201XN7`0701LK700O8b@06alQ018F6@0I72406ahS01XM8P0201PK8P0=01/N9@0M
6bH061HQ01DC7P0F51l061LQ01LG8@0I6B<071dW01/N9`0I72D061/T01PL9@0201PH800<01TI8@0H
620061PP01PH800I6B4051@L018B6P0D51`07alW01PI7P0F5AT05QHH0P0E5AL0100F5QP05aLI01@D
5P0D51H201<C5@08018B500B4Q805A<C01DD4P0>3@/04A0>01DD4P0G5Q@5014@3P05014@300G5Q40
4A0<01<B3P0<2`L00P0D4a400`0?3P`05Q@E00d;300201HD5@0302`Y:@0F4Q4030P700804`l>00<0
510?00d9200D40l00P0B3Pd00`0@30/030P7014=2P02010=200F010<200?2`P03`/8010<2P0A3@`0
40`<00l;2`0>2P/03`/<01@?3`080P8040X:014;2`0:10@05@l?00l92@0@2PX06Q@D01@>3P0<1PH0
4P`<018:2PD04PP900L040H701882@0C2@X04@L801061`0B20T04@L6008040H50P0A1`H0200@1PD0
5`d<01061@0?1@@030<301<9200D2PT040H70P0M4a@02@0>10D03`D600l51P0G3@h07A<D01L=3P0>
10D04@L800l51P0601041P0701451`0@10H03`<500l31@0@10H04@D700`01P020185300300l22@0D
1`h07a8I00H040<:5?ooool001_ooooo00`06ATI01LG5`0K6a/03`l?00T9200;2`T061PF00`=2@0:
2`H05QLB010A300?40/200X:200@00`<2P0>3P`03@d;00T91`0D51803Ph<00d=2`0A4@l05ADC00H6
100:2PP06QXH00P81P092@L06QXH020P7P803`l=0P0>3P`0300@40h04a@?014B300>3`T04A8<00h?
2@0<3@L03a0:010A2`0<3@L03Pl900l@2P803@h800/030d800d=2`0=3PT02`/800`<2P0=3PT030d9
00`<2P0<3@P030d900`<2P0300/;2@0400d=2`0>3P`03`l=00h>30<030`:00@03@d;00l?3@0?3``0
3Pl:0P0?40/03P0>3`X03@h900d>2@0;30L02P/6010A300G61<04a@?00h>2`0<30X02PX800d=2`0A
4@l0410>0P0D5180@@0>3P`03@d;010@3P0?3`d02``800X;1P0A4Pd01`P301PI500C50l02P/601DF
4@0?40d04a@?00H70P092PD03`h:00l>2@0?3@P03``700d<1`0?3@P04Ph;00l>2P0?30X03`/:00d;
300?30`03Ph<00d>2@0;30L02P/600/<1`0>3`X06AXE00H70P17B4<00040010A300?40/04Q4=00l>
2P0=30P030/700/:1P0920@06APD00l>2P0<2`L04A0<01<B3P0>3@T03Pd;00h>300:2PP05aHD00d=
2P051P405aHA010@2`0;30H03@`700h>1`0<2`H03@`700D03@`800`040l;00T8100920@071/G02PW
8`0>3@T030/6018A30071P401@@000l>2@0;2PD200h=20803@`70P0<2`H08@0=3PT02``700`;1`0B
3@X05@d;01@<2P0P61H07QTF01DA3P0=3@T02``700L80`0?40X01@H000l@2P0S91h02``600h?2@0:
2`L05AH@00<4000C50h01PL100X9100A3PH040/501<@1`0A3PL03``501<@2@0=3@D06APC00P81@02
014B3@0300T91@0A40`03@`8008030/700P01`H200d<200;2PH03@`8018A3@061@402@P4014@3080
3Pd901L03@`800h=2@0?3PX03@`800T8100=30P030/701HE4@071P803Ph;010@3P061P@03``;018<
300;1@D060l@00h8200;1`H03@d;00X<2@0;3@X03@d;00l>3002010?3@803`h<00<03@`:00h=2`0?
3P`00P0=30X01`0?3P`03`l?00/;2`0@41005ADE01<C4`0G5aL00P0@4100100>3Ph030`<00`<300>
3Ph3010>3`0400l=3P0>30d03P`=00h<3@803@/<0P0>30d00`0<2P/03@/<00d;300400d;3P1A00h<
3`0?3A003`d@00h<3`0>30d030X;00@41P0?3a4061PJ00X:300;2@`03@/>00T72P0;2@`040hA01DC
5P0H5QT05aDH018@5@0E51T04a8G01@C600C4QL02PT>00/:3`0=31404a8G014@5@0=31403`hC00h=
4P0>31400P0301XH700:1@T04@`@018=4@0A3@h040`=01@>400B30h03@T:00l>3P0?3`l03`l=00l?
3P0=3@d030`:010@3`0;2`/03@d;01<C4P0C4a<04A4?018A300A40/040l:00h>2@0G5Q803Pl:018B
400E5AD04Q8B010@4P0H61X0820R018B3`051@<020T400l?300A4@l061PE03Lh<`1:BTP03a0<0001
000D5180310:00lE2`0?50d041@=00804A@=02X04aD?010A300@3`d051<A00h=2`0A3@`04a<@028S
7P0K6aT0410>00X:200:30/051HE01/M700=4A003Q8B01HJ6@0>4Q<08RLU00P>300@51<04aPF01<I
5`0E6AP0;S<a00hD4P0O92800`L601lU8`0F6QT051HE01DG5P0G6AP051HE01<E500E5aH04aDD010B
4@0F61L03a4@010B4@0D5QD201PJ5`0<01LI5P0F61L051HE01<E500F61L05QPE01DG500D5Q404aD@
014E3`0=4P/03aL<0P0C6Q803`0C6Q<051XE018H500H7QX06b4O01<I5`0D6QP07B<Q01@H5`0H71/0
720O01dQ800J7a/05adI01TN6P0201XP700N01/Q7@0O9R0092/T01TS6`0]=bl03aPC02Tb;@0G8Ad0
8bhZ01/U900N:2P05b4S01/V:00X<cL08bhb020Z;00R;2h09C0b02Lb=P0Y=CX0:3Dk034nAP0S<CT0
9cQ002Pi@`0O;c/09SM102He>@0O<C<08C<e0P0V>3`08P0U=c/0;3e402Lj@@0Y?4<0<TE<03e@E`0`
@dT0;Sm00391A00Z>C`0<D1302Th?@0W=S/0?4]B03=2B@0`?TL0MXB=02@b>`0a@4L09CDe03=1@@2l
b/X0EFAQ02Hb<00M:BD09C0[024/9P0R;2@0:38[02<Z8`0G7AT08BT]01hX:P0S;Bl202Pb<`0X02Tc
=@0b?D40=3m502di@P0_>dL0<3a:02a0D00V?e<0Dfb006AlS`0^AEL0;T=D02m3E00U>4L0?U1N04=D
HP0a@Dh0=dMD02/h?P0V<S809c<c02/f>@0S<C@08Bhd02Dc>`0gADh0CUmW03i@FP0Q<cd0<dE?0312
B@0d@dX0<3m602/j?`0_?T<0;Sa002hi?@0W<SH09C0c02`f>080:cDg00X0JgEg04aDE`0R:Rd08BHY
02T_;`0Z;Rh092XX028X9P0T;BX09Bl^0P0Q;B/05P0O:2L0:2h^02dc<`0S:BL07R@R02DY:00P92<0
7b@P020R800N81d07b4N024R8@0S9bP08bLZ024U:00M8B@0720S01lS9P0T:2/082@W01XN8@0H71l2
01TM800K01`P8@0F6Q/08RHW03Lk?00E6A/061`O01@H6`0G6al05QTN01@G700E61d06a`Q01HG700H
5ah07A`T020N:@0P7b/071`X01PH900H6R@06A`U01XM900J7B<061/P01@D700F5Qh05aLO008061PP
00d05QTP018B6P0L72@06ATQ01@E6P0<3A8051<I01HE6@0B4Q@05ADG018B500?3a405ADG008051@F
0P0C4aD2018B5006018A400J6AL040l=01/J600C4Q0030/91P0B4@l08@0A40`04a8>01TH500?3P`0
40l=00d<2P0B4@l030X;01<A4P040`<04a4B024M7@0A3@`03@T801@@3`0>2PT040`;00l;2P0F4Q40
4@d<010<2`0?2`X03@T801@@3P0A3@X03`/800d91P0>2PL03`/:010<2`0>2PT03@T800`8200200`8
2@0J00l:2P0G4A403@@500/51@0C3@d03`H701092@0<1PH05@`=01092@0=1`L050/<0107200A20T0
4PT:01<92P0C2P/050X;01882@0A20T04@L800h41@0>1@H04`T:0147200@1PD300l5100;00d30P0B
20L02`4001<9200?1@@03P@301471P0700007aDF024G600:00400P0@1PL01P0700003@<400`30`08
00004@L801882@H040@600`04@D701041P0?0`D03`<501041P0A1@T02P02020C6P0X6b806`hE00d1
1`0=00L601032QCooooo000Kooooo`0300h>300?3`d03`l=00<03`l=01800P8001HF500A4@l0410>
01DE4`0=3@/03`l=00`<2P0820H02@T700l?3@0@40h03@d;010@3P0=3@/05ADC00<30@0A4@l200h>
30803`l=00@03Ph<00d=2`0A4@l03`l=0`0>3P`02@0?3`d03a4<00`>2@0=3`X02`d800X<1`0>40/0
51HA00h@2`0200/=200h014C3P0M7A/05QDC00/92P081`D04a4A01<C4`0;2`T02`/:01PJ6@031@80
4A<A0001000>40d030h;00h@3@0=3``03a4>018D4@0D5Q<0418?00d?300;3@X030h;00/=2P0@4Pl0
2`d:00L91P0@4Pl03a4>00d?300?4@h04A<@01LI5P0H6QL02`d:00T;200=3``020X700h@3@0C5A80
1`T601DG501VJ6D02P`9010B3`092`P061XG0043000:2`L03a0:00d>200:2`D02``601LH4P0?40X2
00d>20804A8<00l030d701LG5`0000004a8B00/:200<3@P030`9018A3@020`004a<A0040000;2`d0
3`hA00d=2`0;2`T00`0=3@/03`0G5aD02`/901`L6P0I6AL0410>00h>300820L03a0;00`=200H6A@0
1PL2020Q700I6QD03@h900`=200200/<1`0C00`=200>3@T04Q4=01<@3@0C4Ph040`900P60P0;2PH0
3PX700X71@0<2`L04@d:014>2P0A40/051<>00/<1`0<3@L0414;00P90`0500X;1@0;00/<1P0=3PP0
2PT400`;1P0:2@@04A0;01TH4`0>3@P08b8M00l>2@0;2PD00P0@3`X0400<2`H03@`700/:1@0;2PD0
3`d800l<1`0=2PD08b0K01hK5P0C4Pd051<>00T80`0E50l03@`700l>2@0=30L200h=200j00/:1@0=
30L02`X500/:1@0=30L03`h9010?2P0B4@/0104000/;0`0?3PT04A0;00T80`0>3@P03`h900h=200?
3PT03Pd800`;1P0:2@D040l;00/:1P0920@051<?01<B3P0H5a<06aXF01<B3P0A40`04Q4=00l>2P0;
2PH03Pd901LF4P0@3`/02`X600h=2@0@3`/03Pd900d<200C4Ph04Q4=00`;200:20T02@L800h<3@0F
51D040h?00P61`0C4A802@T900P92@0P8R4030h=00/;2@0>3@/02`X801<B40803Pd;00H02`X8018A
3`0@3`d02@P600d<2P0@3`d200/:200@00h=2`0@3`d04Q4?01<B400E51802PT700h=2`0A40h051<A
04i=B`0@3`d03`h<010?3@0=30X02`X801<B40<040l=01L03`h<00h=2`0>3@/02@T700d=2`0>3Ph0
3Ph@00l?4P0B4AH03PdB00/;3P0>3Q003Ph>00`<2P0@40h02PX:00l>3`0A3a0040h?018>3`0D4140
5a4C01TB500201XA500901`C5P0O5Q/030L=01dK800C4AH020H;00d;400B41D0518G00804a4F00L0
3`dB00/93P0B41D02`T<00d;3P0?3@h04@lA00804Q0A02/03`d>014?400A3a00510A018>3`0<2P/0
3@h:018B40041@003a0<00X:200<3@P0410=00L71@0:2`H05ADB01DE4`0A40`03PX701HB3`0G4a00
3P/9010<2`0G5Q@040l=018A3`0C4Q004Q8B00l?3`0>3P`03Pl900l@2`0?40X03@h900h?2P0?40/0
5aPB01PI500@4@`05AH@01<D3`092`D03Q4:00802`d800d02P`701XL5`0U9b805QPC00T:1@0A4Pd0
6AXE01DF4@0B50h05QTB01PK500E61404aH?00804QD>0P0A50d03`0C5Q0051L@018D3`0A50l04AH@
00lA300K7aT0<cPb02la;00J7QP05Q/E01DH4`0A4`h03Q<=01<E400401@F4@0301HH4`0G6A@06adH
00805ALB00H061XE01LI500I6aH041DA014F4P0A5A@200hB4`09014E5P0C5aP06alN00X?2P0C6140
3Q@:01HL400D6Ph05A/?00805adC0P0G71D01P0D6A<06AhH01LL600E6AP06QhM01HJ6@@06b4Q07P0
6b4O01TR7`0D6QH072DO01`V7P0G8AT05B0G01/V800X<S@0624V02dg>@0F828072LX024]:`0M:BL0
8Bd[01DQ8@0L:2P08Rd_02Ha=@0R;3D09c4j01PU;@0X=Cd09cDm01h]=00V=ch08c@k024d>P0S=S`0
8SHl01db=`0W>cd0:Ca002@g>`0U>3`0;D1602i1A`0U>3h0:3U103m@F00jBe<0V:Va05ASJP0gADH0
:CLh02/i>P0gADH0>TQ90390@@13DE80=dE602Pf>@0Y=cX0;ce002`h>00]>3<0:S<^06I_JP15CTT0
9RlZ02</9`0R:bH08b`W02L]:@0[<Bh0:Bl[02L]:`0R:b/06b<U028[:P15Cdh0C5QF03I1@P0b@4<0
;3]002lmAP0`?T/0<D5>03E9E`0[@U80>e9R03I=G00W?T`0>DmM0315DP0V>DL0>dmJ045DH00bA4h0
<D==02Xj?@0]>CD0:3@b02Hd=00V<cT08c0h02Xh@@0`?TT0;Sm902dnB00Z>dD0<T==03I6CP0^?D80
=TE:02ln@`0[>Sd0;C/n02Td>00Z=CL0:cHg02Tc=00X<S<0:S@e02L`;@0]<c409R`/02DZ;@0N8bH2
02@Y;@0602H[;P0T:R/08b`[02Pa;P0V;bX08RPX0P0S9bP0300R9RL08BDV024U9P0^<S<08bLV01XN
7P0h?3/08bLV02<V9P0F6Qd08bLZ01XN8@80720S00X092P[01`P8`0K7b8082@W01hR9@0G6ah06alR
01XK7@0G61X0824S0P0I6Q`0:`0K71h04Q<E028S9P0H6Ad06AXN01XK7`0L7Al06Q`K01PJ6P0H6Ah0
5QHN01dM:P0^;C/05A@R01HF8`0G5al05AHK01HH600H6A/07QdR018A600X9bl07AdW04Q:D`0K7bP0
4aHO01<D700D5AX061LL01LG6@0F5QP061LL01LF6`0I61d051<H018A5P0F5AX04A0E00X93P0A41D0
5QDJ018A5P0H61X00P0E5AD01`0C4a<04Q8B01DE5@0G5aL03@d=01@D500=3@d00P0C4a<0400E5AD0
5QHD00`<2P0F5Q@04A4A00T7200A3a0040h?018>3`0D41404@d>010<3@0D41404@d>00l;300@30d2
018>3`0701<?400;1`P03@T:014=3P0F4Q<06QHG018>3P02014=300R010<2`0?2`X03`/<00h:2`0?
2``03PX;00X61`0>2P/04Ph?01D>3`0A2@L05P`;01891`0@20H060h=01<:200A2@L0718A00/20@0A
2@L07A<B00d51P0@2P`04@T<01482`0>20X03`P:00X1100:10H040T;00L00@0C3@l04@X;01472080
40H700@03`D600h41@0>10D03`D60P0=0`@00`0A1`P04PP900h41@0301061`0;00l51P0>10D03P@5
01<92P0700005@d=0147200@1PL02`8300l4200=0PH00P0?10P01@0<0@D040D900/0100=0PH040D9
00804@H:00d040D900h31`0:00<03P<701052@0A1PX04PL;00/0100<0@D02`0400h31`0@1@T02@02
01Cooooo000Kooooo`0>00l?3@0A4@l04a<A018B400?3`d03@d;01HF500=3@/0:2PV00d=2`0B4Q00
51@B00h>300?3`d3010@3P0700d=2`0<30X03`l=00X:200B4Q001@D3014A3`0200h>30803`l=00@0
3Ph<00d=2`0A4@l03`l=0`0>3P`06@0?3`d03Q0=00`>2`0?4@h0418?00h@3@0?4@h06A/H014C400F
61D02P`9014C400?3`d04a0A010>3`0A3a0030X;00/;2`0@41003@d=00T:2@0>40l02@/:01DI600;
3@/00P0A4a000`0>40d02`d:00/=2P0300`>2`0300lA3P0@4Pl03Q0=00803Q0=03<030h;00X<2@0;
3@X03Q0=00lA3P0>40d0418?014C400<3P/03a4>01TK600A4a002P`900lA3P0A4a003Q0=01DG5008
2PL03@l=014C400:30T051HC00h?300:2`D0414<00X;1P0<3@P04Q<=00d>2@0<3@P03Pl9018C3@0C
50h0414<00T92`0D4aP051@E010@400<30X051D@014B3@051P403@d;0410@P0@418051@G010@400>
3P`03`l=00d=2`0:2PP00P0@40h02`0F5Q@0410>00L71@0A4@l03`l=01DF4@0720<04Q<>00T:1@0Z
:bH0>c`g00803@h90P0<3@P200d>2@0E00`;1`0>30P04a4=01<@3@0A3P/05Q<@00`:1`0@3P/04@l;
00l=2@0=2`L02`X600T:100M7QP02P/800h?300@4@`0LgA^01`M5`0B4`d03a0:00805QLA00X030d7
00h=200=30L03Pd800l>2@0=30L02`X500h=200920<02PT40P0?3PT200d<1`06010?2P0?3PT040l:
01TH4`0P7aX03@`70P0?3PT0200=30L03Pd800l>2@0@3`X03`h900X91@0=30L040l:0P0?3PT00`0=
30L030/600d<1`0200h=200Q00l>2P0;2PD03Pd800/:1@0?3PT04A0;00h=200?3PT030/600/:1@0=
30L03Pd801<B3P0T8al07ahJ00d<200;2PH02@P501@C3`0F5A4040l;00h=2@0?3PX03@`800T8100;
2PH04Q4=00l>2P0<2`L03@`800l>2P0<2`L02PT500803Pd901P02`T7010<3@0>30d03`d>01@B4`0@
41003Ph>01`L701/KVd0?T0o02HX9`0C5QD0410>014@3P0>3@/04Q4?01<B400A40h02`X800l>300>
3@/030/900l>300>3@/600d<2P0<00l>300>3@/03@`:00`;2@0A40h07QdK01DD4P0?3P`04Q4?01/J
600G5Q@030/90P0B4@l2014@3P8040l=00l03Pl:018B3`0B4Q00410B00d<400;2Pl03PdB00`;3`0@
41004A4A00d>2P0@4@`04A4A00h>3P0?3Pl00P0E4Q<04`0C3Q0071LH028K7@0N51P05P`?01<9300H
3a8040/?01lM8@0K6Ad04a4E014?4`0:20`02`T=00`:3P0@3Q803`dA00d;3`0B41<0100@3Pl01@0>
30d03@/<00d;300E4a@0518C00803P`=01<04@l@00d=2P0I6AH03a0<00d=2P0=3PX0414=00h?2`0@
4@d03`l<00h>2`0A4Ph05QDB01TD500B30`050h>01DA400D40l05Q8A00<040l=0`0?3`d00`0@4@`0
4Q<=014B3002010A2`0?00h?2@0A4Pd04a@?010A2`0G61805QLB014C3@0A4`h02`d8014C3`0<3PT0
5ALB02`^:@0K7AP0418=00804aD@00D03Q0;00hA2P0B5@`051L>018E3003014D2`803a8900`04A@;
01<F3@0B5@`041<;01@F400C5@l0418<01LI4`0D5Q003Q0:018E3`0D5Q02018E3`0301@G4@0C5Q00
4aD?00804aD?024051H@01DH4P0G6A<06adG01TK5@0C5@l051LA01<F400C61805AXE01HK6@0B5QL0
4ADG01HJ7@0@51D06QhM014F4@0K81P04QP=01@J3@0G7A005adB01HL4P0F6a<05Q`C01LL5@0F6aD0
61dG01@I500C61D06b0M01dQ800I7al00P0K82<0N@0K8B406R4P01LP7@0F81/05b4K01TT700L:1l0
7BXP01/W8`0<61h08Rdg01dY;`0Q;C<082d^04EBDP0S<Bh072TW028`;@0Q;Rh082`]02@a=00T;cP0
;SY402Tf?`0[>D8093<k02/l@`0U=Sd08C<i020c=`0R=cT09cdn02Pn@00V>cd0:3e002@i?00T>3`0
:3]002Lj?`0/?d@0:3To02Xk@@1PL7L0a]?F07n<T@0f@D80DeiN034l?00T;bh09c8b04A?CP0f@D00
:SDe02@_;`0T;bh09c8b02Td<@0]=Bd09B`U02he;P0]=2d0:S0/02L]:@0R:2@07bDS020V900V;2X0
:S0^02/a;`0Q:RT092d[02@^:`0X<bl09S8`02Hc<P0^?D00=dI;03a=EP0eAE80=4ID03U=F`0]A580
?UES03U@G@0gCUX0;dEA03U>F@0aAE00<dMA0313C@0[?DL0<D==02lo@P0a?CT0:STf02Hd=@0W=3X0
:3Ln02/i@`0]>dH0;cm<0351C@0[?4H0;3e603A4B`0gAT/0;Se204MFFP14DeH0:SPk02Lb=00Z=CL0
;SXj02`f=`0X<S<09Bl_024W900U:bL0;38a034f>@0Z;c<00P0V:c401P0X;C<09R/^02D[:`0W;B/0
8RPT02<W9P808bLX03L08RHW024U9P0Q9BH08BDV020T9@0V:R/0?D5202HZ:`0K7b007b<U01`P8P0N
8R@05a/M02HZ;00J7R007R8T01`P8P0N8R@06alQ01PL7P0L82806Q/M01hO8@0J6ad092DW024R900J
6ad07QlQ01/L7P0H6A/06Q/M01LH6P0Y:bX06Q`I01LH600H6Ad06ATQ020P;@0];3`071/[01PH9@0N
7RH05QLK01/M700F61H0518G01dK8`0L6b<0:BTc06a`NP0O8bh03a<L01DI7`0I6Qh05aHJ00805Q@E
00D05aHK01PG700J6Ah05QDJ018A5P0201HE6P0:01PG700<2a003`hC01PG700@41804Q8C018B4P0@
41003Ph>010@40804a<C00D03@d=01@D500@41003@d=010@400201@D500300h>3P0;2`/04@l@0080
4Q0A00D04`l@010<3@0C3a0050h@014<3@02014=3P09018>3`0C3a004@d>010<3@0A3@h06QHG01DA
4P0>2P/04`l@00<04@d>00@040`=00l;300?2``03PX;0P0?2``01@0A3@h05a<D01DA4P0B2``03`D5
00804`T900X04PP801H<300C2@T03@<300P0000D2PX04PX900l51@0D2`d03PP:0`0=1`T01`0>20X0
4@/=010:300>20X030H800l92`0a:bd00P0@1PL01@0?1@H040H701061`0@1PL050X;00804PP90P0D
2P/401061`0;00l51P0>10D03P@501061`0Q5aP0<BLX00T10@0=0`@04PT901052@0>0`L00P0@1@T0
100?10P05@X>01@93@0A1PX200d21P0>00h31`0?10P04@H:01<8300B1`/02@0201<8300<0@D03`@8
01<8300>0`L02P0300l4200A1PXDooooo`006oooool2018B40804A4?00P0410>00h>300<30X051@B
00l?3@0;2`T0;Rh/00X:20802`/90P0>3P`0200<30X0410>00h>300B4Q002@T700l?3@0:2PP0410>
0P0>3P`200l?3@0300h>300=3@/0410>00803Ph<00<03@d;00h>300>3P`00P0?4@h06@0@4Pl030h;
010B3`0H6QL0KFm/05YLF@0R92404A<@01@F4`0A4@l0514B01HD5@0@3Pl0518C01@D500;2`/04Q8B
028T8`0P8R401@L600/?3P0<3`d02`d:00h@3@0A4a000P0<3P/01`0=3``02`d:00/=2P0@4Pl04A<@
010B3`0=3``00P0?4@h00`0;3@X04A<@018D4@0400d?300700`>2`0A4a004A<@01DG500H6QL030h;
00/=2P0200h@3@0>01`N6`0620D04aDB0002000A4a004A<?00H70P0A4Pd01@H1010A300=3PT030d8
00/<1`0=3PT200h?2P0Q00h?2`0Z:R`0BTU>01XJ6`0H61P02`/900`=200G61<03@h900/;2@1;Bdd0
3@d?00l?4P0;2`/02@T700`<2P0?3`d030`:00l?3@0;2`T04A4?01@D4P030`403Ph<01lO7@0];RT0
0`@000@50P0F5a807AhI01<D3`0>3`X03@h9008030d801L03@h900h?2P0=3PT03@d8010A300A40`0
3Ph9010A300J6AD03`l;00T:1@0@3`/04a<?00P9100310003@h8014B300U9R003a0:02@U7`0I6Q@0
30d700X;1@02018C3@0:00H70@0=30L030/6014@2`0@3`X02`X5010?2P0:2@@03@`700h=20<03@`7
00d030/600l>2@0=30L030/6018A300H5a803Pd8018A300G5Q403@`701DD3`0:2@@01PD1008030/6
00H040l:00l>2@0;2PD03`h900h=200=30L300`;1P0401<B3@061@001PD0010?2P802`X500P030/6
01@C3P0E50l02`X500T80`0<2`L02@P400d<20802PT500D05A@@014@300?3PX04A0<00h=2@0200`;
1`0:00h=2@0<2`L030/7010?2`0B4@d04A0<010?2`0A40`040l;00`;1`803Pd9010030T8018>3`0B
41403P`=00d;300<30`0410@01@D501JG5/0?Cln020R8@031PD05QHD00l>30081`D01@@20P0;2PP0
1P0?3P`03Pd;00h=2`0B4@l04a8@00h=2`803@`:00X03`h<014@3P0B4@l04a8@00l>300>3@/02`X8
00d<2P0@3`d04A0>0P0:2@L0100A40h04a8@00d<2P0<2`T2014@3P8040l=0P0?3P`0200>3`X03a0<
00d=2`0;2`d02`/>00d<4@0>3A802PT=0P0<30`06P0;30P0414<01<C4`0A4A40410@018B4P0C4A80
4Q0A01HB4`0J5QL06A<E01<=3`0D30l0618D01PC5`0F51L03`d@018@4`0P7R408b4T00/9300<2Pd0
4Q0C01<A500A3a80518E0P0A3a00100@3Pl03`d>00`:2`0;2@X300l=3P1400`:2`0?3@h05A<D010@
3`0G5aL01@D301LG5P0>3Ph02PX800h>3@0C4a<04A4?00d=300C4a<06QTG02TT900F41004`d=010<
2`0<20L02`L6014@3P0=3@/030`:00d=2`0?3`d0410>010A3@0B4Q004A8=010@3@0@40h0410=014B
3@0A4@l03Pl;018C3P0B4Q003Pl:01<E40072@@051HA04A6@@0T9R402`d800X<1`0;3@P04Q@?014C
3P0B50l051LA01<F3@0B5@`04A@;00`?1P0>4@P04aH=018E300@4`X04A@;018E300A50/03Q4;01@F
4@0F61<04aD@01LI500J71L201DG4P0501HH4`0D5Q404A<>010B3@0D5Q40100C5A006@0D5Q405ALB
02<U800Q8ah05ALB01XL5`0H6QD03a@>01<H4P0E6QD03a<B00hB4`0E6AX05QXK01hR8`0?51405a`F
010E3P0E6a406QlH01TN5`0E6Q<051TC01DJ4`0H7AH00P0G71H201DJ501o01XO6P0L8Ad06b4Q01dR
9@0O92L07bDU01dU8`0J8b00:cHb01`W8@0G8Q`07R/R020]900G8b406RL]02Ld?02V/kT0?Ta?01/Y
:P16E5@0<T4n020_;00Q<2d072XZ024_;`0L:Rd0:CHn028_>00Y=Sl0;3Y3028a>@0T=C`08c@k024d
>00P<cL083Df02<h>@0T>CX093Tl02Pm@00U>Sd09cXn02Pk?`0T=c/0:ce002<e=`0jC4h0;C`o0350
@`0`?Sl0=T0n04QBD@0[=S809C0]02Xd<`0d?c/0;3Hd020Z:@0S;RX08B/Y020Z:@0X<Bh09RlW01lV
7`0R:B809RdV01`R7P0/<Rh0:Bl[02H/:P0W;B/0;38`030f=00a=cD092d/01XS800S;BT082/W01HR
800U<S40;3`l03Q7BP0nCeL0=4E?02m1C`0fBUP0;TEC03mFI00mE640Bf5^02i4C`0jCeX0=DUD03A8
D@0fBE<0<D==02doB@0[>ch0;c/i02dk>`0Y=cT0:3Dk02`k@P0b@4X0<Cm:02`lB@0X>D<09SM102Xk
@`0W=ch06RT^03=2A`0jBDd0;Se0028`<`0Y=3H0:cHh02di>@0Y<c@09Bl`028/;00`=S@0:2h/02/`
<P0Y;S80:2da02/`=P0202T^=00402<X;00Q9RT092XZ024W9@<08bLX04408RHW024U9P0Q9BH09RX[
01lS900I7Ah0720Q01LK700O8b@07B4R01HJ6`0Y;Bh061`M02hb<`0J7Ql07R8S01dQ8P0K7b006AdN
01PL7@0L82407b0R02//;P0A4Q@092DW01dN800F5aT06Q/M01dN800J6ad07AhP01<D5P0J6ad07b4P
01LI6@0G61d06ATQ01XJ9`0O7Rh0:2Lg01hN:`0V9Rh05aPM01hO800B51<08AlT01<A6@0N7RH05APQ
01<G8@0:3QT03a<L01DI7`0J7R407AdP01/I6P0I5aP05QDJ01LF6`0K6Ql05QDJ018A5P0E51T04a8G
020O900201<B5`0V01hM8P0C4aD05QHG01DE5@0C4a<0410@018B4P0D51@05aLG01XJ6P0;2`/06a/K
01lO7`0C4a<030`<014A4@0@41003`l?010>3`0=2``04Q0A01<?400<20T05a<D01/E5`0?2P/040`=
014=3P0E4A80510A014=3P0@30d05Q8C02DQ8P0N6Q/040`=01@@4@0B3Pl2014=3P0Q010<3@0?2``0
3`/<00`82@0=2@X03`/<00h:2`0A3@h03`/<01492`0?1@H04PP901@:2`0E2``05`d>0147200@1PL0
8ALH01H>3P0=0`@05`d>00/51P0?2@/03PP:00l92`0@2P`04`d?01@>400<1PP04`h?00@0000B30h0
3PP:00803P@500@03`D601061`0A1`P04@L80P0C2@X201882@0301061`0>10D040H7008040H700`0
3`D600h41@0>10D05@/<00L0000;0@8050X;01P>3`0<0P<03`@800d21P0>0`L200l4200501L<400E
2Ph04PL;00h31`0<0@D00P0=0PH02P0B1`/02`8401@93@0700004`P<00/0100=0PH04@H:00d21P0<
0@D201052ACooooo000Kooooo`0H01@D4P0A4@l03Ph<00d=2`0?3`d04A4?00D50`0H61H02@T701LG
5@0J6QP051@B00X:200@40h06ATG01DE4`071`D01@D300L71@0>3P`01PH400l?3@0B4Q004a<A0P0>
3P`200l?3@0400h>300=3@/0410>00h>30<03@d;02803Ph<00d?300B51404A<@00`>2`0J71T0:R`Y
0=SIe`2e]k@0=SPe01LI5P072@H02PX8024N7`0n?3d081hO00X82@0C4a<03`l?00L71`092`X01PP7
03Dg=P0830/030l=00D710092`P03a4>00X<2@092`P03a4>00h@3@0<3P/03@l<100?4@h200h@3@05
014C400>40d02P`900h@3@0?4@h00`0>40d02P092`P051HC01/M6P0<3P/02`d:018D4@0;3@X030h;
00d?30041P<200T;200601LH500?40/03a0;00@5000B4`h061TD0`0@4@`05`0>3`X03@h900h?2`0U
9BL0B4M<00l?400?3`l01@D3014B3@0B4`h02P/600P81P0K6ad01`L900X:3@0=3@d02PX800`<2P0?
3`d03@d;00h>300?3`d02`/9008030`:00P05ADC02/[:@1CE4l071dH00T:1@0?40/03@h900P91080
3Pl:0P0<3@P200h?2P0H00l@2`0;30L03@l:00h?2P0:2`H02P`70001000=3P/02`d800/<1`0?4@`0
3a0;00`=1`0?40X02``60001000:2`L030d700h?2@0:2`D02@X400`=1`0=3PP02P/50P0;2PD02P0?
3PT03Pd800/:1@0?3PT03Pd800l>2@0=30L02`X500d<1`0?3PT300`;1P0?00d<1`0<2`H02PT400`;
1P0?3PT051<>00X9100A40/010<001HE400E50l040l:00l>2@0>3@P02PT400<03Pd800L03@`700`;
1P0;2PD02PT4010?2P0A40/05QD@00800P4000T020L200`;1P0A40/030/600h=200B4@d02@P400h=
2@0B4@d00P0A40`01`0<2`L03`h:00l>2P0?3PX030/700d<200?3PX00P0=30P0100?3PX04Q4=018A
3@0@3`/2014@300H00`;1`0>3@T03`h:01@B400P71d07Q`M018@4@0;2@X02@T900H61P0@41002`d<
00X<2`051`H02`h=00l?3@0A40h081lM010?3@0=30X05QDC010?3@0<2`T03@`:0P0B4@l0400?3P`0
3Pd;00h=2`0@3`d04A0>018A3`0C4Q0040l=00X91`0?3P`04A0>00X91`0A40h06APF00l>300;2PP2
010?3@0400h=2`0?3P`03`h<00l>30803Pd;00T03@`:00h?2P0=3PX02`/900X:300A41@061LL01<B
5`0<2`l00P0:2PX06`0=3PX05AHA00`>3@0B51<051HE018D4`0G5aL07alO018@4@0@3Pl04Ph?01DA
4P0H4a@05a<D02DS9P0G5AP01`D800H41`0?3A004@lB00d;3P0:20/03P`?00l=400<2Pd03@/>00l=
3P03010>3`803P`=0P0;2@X04P0C4A805A<D00d;300;2@X04A4A014A4`0820P04a<D00L72@0H61P0
3`l@00l?4@0@41004Q8C01HF600J61T06QHE014=308040`;02004Q4?01PG5@0A40h03@d;00`<2P0=
3@/03Q0=00lA3P0?3`d04A4A010@3P0?3`h03`l?010@3`0@40h0410@00l?3P0A4@l04Q8B01<D4@0B
50l051HA00d?2P0H6QD020X501@F4@0A4`h04aD@01DG4P0@4Pd03a4<018D3P803A0900<03a8;00/>
1`0>4@X00P0G6Q<03P0C5Pl04QD>014D3@0@4``04aD?01HH4`0D5Q404Q@?01@F4@0C5A004Q@?01HH
4`0H6QD05QPC0P0C5A000`0F61<05ALB01DG4P0201@F4@0B01DG4P0=3`X06adH01/M600@4Pd05QPC
01DG4P0>4``04AH?01<H4P0?51003Q8A01DI6@0C5aP07R8S01<G5@0N8al05a`F0P0J7aT01@0H7AL0
5Q/E01DJ5P0F6aD06AhH008061dG0P0I7QL01@0H7AH05a`H01/Q8@0M8RD07R<V00807BHU01/06b@Q
03Q3?`0S;bT06BHO024^9`0V<b`07RXX02Hc>@0P;CH0IG9h01DS9P0T<S<06BLW02Lf<`0R<Bl07bd]
028`<@0[>C/08Bhd02Tf?P0S<3T0:cU202Th?`0S<cX0:3U001la=@0R=3P00P0T>3T0C`0S=cP08CHi
02<f?00X>d409cY002`n@P0/?T00:3Xl02`l?@0c@d<0;Shn02hl?00hATH0>TU603<m>00/=C80:C8]
02H_:`0_>3D072DP02Xc;`0Q:RL09BhY028[9`0N9b@092dX02<]900[=Bd09BlW02Tc:`0X<B`06R<N
02D^:@0T;BX09Bh[02Pa;P0W<2d09Rl/02</:@0L9B808B/X020[9`0S;b/0=45002Ph>00/>ch0=4E<
0393C@0`@U00<dQE02i6DP0jD5d0>4iK04AJI`0^@Td0<dMA03=7D00dAU00>deF03A7CP0Z>d<0:3Hj
02Xf=00[>CT0:cTk02Xg?@0/>d80<3i8034oBP0^?dT0:ca602hoA`0b@d/0=4A;03]:C`0c@TL09cHj
03I5B00S<C@00P0/=cT0400Z=SH09Bl`028/;@0T;Rl09bd]01`R8P0U:R`08BHZ02H[<@0a=S`0:Rle
02P]<`0P9BX07R<V02@Z:P0V;2`302<W:00>028V9`0Q9BH08BDV020T9@0O8b@09RX[028V9`0P92D0
720Q01/O800M8B80<CDf01`P8@0Y;Bh201dQ8P1?01hR8`0J7Ql061`M01TM7P0K7b007AhP02`];`0?
418071dO01TJ700K71h04a@F024R900D5AL06AXL01dN800H6A/07AlN01HG600F5a`05aLO01PG900K
6RP08b8`01XJ9`0O7bL05aPM01hO800F5aT040hC028P9`0C4a/03A0I01`O:@0G6bH051PQ01@H7P0G
6ah07AdP01XH6@0E4a@05QDJ01LF6`0J6Ah05QDJ01<B5`0G5Q/03@`A01HE6P0B4AH04A0E01<B5`0C
4aD04a<D018B4P0@41003Ph>010@400B4Q80410@01HF5P0J6QX030`<00l?3`0N7Qh061PH00`<300C
4a<04Q8B00/92P0?3@h04@l@01<?400=2@X06QHG01lI6`0B3@h04@d>018>3`0201DA4P03014=3P0@
30d04`l@00807a/L00<05A4B01HB4`0A3@h00P0A3@h02`0@30d03`/<00l;300?2``0510A01HB4`0>
2P/03@T:00l;300C2`d03PD600<04@P900T05Pd>0107200F3@h02@0100d41@0C2P/01`0000l82@0@
2P`00P0?2@/0200@2P`050h@048l?P0B30h0>S@f02<M7`0E3a403@L90P0?1@H00`0@1PL04@L80147
200201882@804`T:00<04@L800l51P0>10D00`0@1PL01@0?1@H03P@500h41@0F30d0308300804PP9
00@04@L800h51@0=0PH02`040`0>0`L0300E2Ph040D901052@0@1@T03`@800h31`0=0PH07A8F00X0
0`0F2`l03`@800h31`80304500D03P<700l4200E2Ph060dA00h31`0Dooooo`006oooool200h>300<
00d=2`0>3P`0410>010@3P0I6AL0Bd]901PH5P0@40h0410?00T91`0D51802`/90P0<30X0100B4Q00
:2PV01PH5P0P81h2014A3`0401<C4@0:2PP03Ph<00h>30803`l=00H03Ph<00d=2`0?3`d03Ph<00d=
2`0<30X200d=2`0O00/=2P0A4a004Q@A010B3`0M7a`0;2h[09VKV022Q8408bDR01<E4P082PL04A4?
01PE5P0R824040h?00l=3P0C4a<01`L7010@400>40l02@/:04=5A00D5aH06A`J00d?300B51406A/H
00h@3@0;3@X04Q@A014C400200h@3@803a4>00T0418?00`>2`0<3P/03a4>00X<2@0@4Pl051HC010B
3`0A4a000P0@4Pl07`0>40d030h;010B3`0?4@h03@l<014C400@4Pl030h;01lQ7P1=Cd`04Q@A01<E
4P0<3P/03Ph<00l@300K6aP09BDR00H60`0F5a<051DA01DE4P0D51403a0<00l?300A4Pl03Ph@01LF
6`0=3@h0?clo03/k>@0D5A000P0>3`X0200>3P`01@D7014A4`0B4AD05aLG010@3P0=3@/03Ph<0P0<
30X02`0?3`d03Ph<00h>300C4a402`/901hN700E5Q400P<000d>2@0?40/020T400803a0;00T03Pl:
00d>2@0=3PT03Pl:00l@2`0<3PT01`/500/?2@0=4@/00P0:3@P08`0G6QD02Pd900hB300/;bX0<CD`
00P:1@0B4`d03Pl;00`=1`082@H07b0K00P9100=3PP03Pl900d>200<3@L03@h8010A2`0920<03`h9
00X9100<2`H04Q4<00X9100>3@P030/600/:1@0<2`H03Pd8010?2P0=30L03`h9010?2P0A40/03`h9
00803@`700X02`X500d<1`0A40/040l:00h=200[:RD07ahI014@2`0<2`H03Pd80P0=30L300h=2007
00d<1`0<2`H04A0;01DD3`081`<03Pd800`;1P0201lN6@803Pd800`02`X5010?2P0C4Ph01`H200/:
1P0=30P03`h:01@C3`0@3`/03@`800`;1`0?3PX200d<200T00h=2@0=30P03@`800`;1`0A40`040l;
00/:1P0?3PX040l;00`;1`0>3@T040l;010=2`0C3`l04a4A00h=300@3Ph0410?00h>3@0V9RD02@/9
01@F500>40h04ADB059BD00J6AP020L500/:200@3`d03`h=010?3@0<2`T03@`:00l>300>3@/04a8@
0P0A40h0400@3`d03Pd;00h=2`0=30X04Q4?00l>300B4@l040l=00X91`0B4@l0:BPV01HE4`0;2PP0
6APF01dL6P0@3`d200l>30803Pd;0P0=30X0200?40/0410=00h>300>3Q005A@H01/J7`0E51T03`hB
0P0>3Ph05P0@4@d061TD00X<2`0C5A@051HE018D4`0I6QT09BHV01<D4`0?3`l03Pd>014@4@0B4140
3`d>02@R900L6Q`05A<E01<A4`0@3Q003@/=01XH6P0A3a42010>400400h<3P0?3@l03@/<00l=3P@0
40h?00H03P`=01@B4`0T8R<0928S014?400=2``200l?4P0B014A500E51P0FUYM03Ti?00A41@03@`@
00h=4@0C4QH051<G01<C5@0B3Ph04Ph=01<?3P0@3P`04a8@01XI5`0@3`d03`l=0P0?40d200h@3@03
010@4@0B4Q<04A4B0080410A01/04A4B00l?400?3a004A4B018B4`0D51D04Q<A03Pj=@1YJfH071hI
01HG500E5a8051HA00d?2P0?4@`04aD@00lA300>40/04aH@00lB2`0>4@X051L@01<F3`0I71D07b8K
01LJ4`0C5Pl00`0B5@h03`0C5Q004A@@00dA300A51005ATD01@G4`0B5A404QHA01DI500D61<05APD
01PL5`0F6AD05ATD01@H4`0201<F4P0P01@G4`0?4`h051PC01@H4`0B5A4051PC01DI500C6@l04QT>
01<I400C6A805A/E01HK600@5AD06b0P01<H5`0N8b805A/H01HL6@0F6a/05Q/J01HL6P0G71T061hJ
01XP6`0I7aT05adG01XP6@0L8QT05QdD01HM5P0I7ah201PO802001PQ800J8b806R@S02D_;@0J9R<0
5R<M01/Y8`0P;RP07B`Y01<P9P0U<cX07B`_02Lf>@0N;Bd08c8b01TX9@0S<S407Rd/02Dd=@0O;C00
@e5G02Le?@0V=3`0:CQ0020`=`0Z>T40;Sm501d_<`0S=ST09cXl02Lj>`0V>SX09c/m02@f?@0V>3l0
9cTo02ho@`0_@480:S/k02/j>@0Z>SP0:cPe03E3?@0[>C<0:SL`034j<P0U;BL0<CXb02D]9P0^=S00
82PP02D^9`0S:bD08b`T02@]9P0S:bD08BXR02La:00`>S80OXR004mID@0j@ch0:S<^02D^:@0T;BX0
9Bh[02Pa;P0V;b`09Bh[02</:@0X<Bd08R`X020[9P0b?SX0=dA202@d=00W=ST0<49803E6D00fB5@0
=DYG03M>FP0dBUL0=T]H02m4C`0nDUd0;d==03A7D@0_@DX0<TA<02doA`0V=cl0:SPl02Hb<@0V=3D0
;3Xl02ll@P0_?DH0:cU302`jA@0^?dT0;Sm80352BP0_@4L0;Ce301l^<`0_?T<0=TE905ETI`0X=ST0
;3Li02/f>00X=3@08bd^028/;@0T;Rl0:Bha024V:@0h?D00:Bhd02H[<@0/<CL0:Bhd02P]<`0Q9R`0
82DY02H[;`0X;S0302<W:00l028V9`0Q9BH08BDV02DY:P0P92D092PY01PL7@0S9bP07B4R01/O7`0V
:RX0;S8b01hR8P0O8b<06AdM01XN7P0P92@06alO01TM7@0K7al06AdM01XK7@0O82805AHH01TJ700J
6ad07AhP02@U9`0[;2h0414C01<D5P0L7Al05AHH01DG5`0E5QT06AXO01TI8@0I6B@081l/03LgA00^
;ST06a/S020Q9P0D5AP04a@F01PG700K6b803`lG01/N9`0H6bD051TT01HK900E6R004aLJ01@E600H
61P06QTJ01LF6`0F5AX05aHK0P0E51T05@0J6Ah0@T5602TX;@0C4QL05A@I00h=4P0G5aT051@E01@D
500C4a<04Q8B01DE5@0H61P0Bd];05EEE@0820P06a/K02l_;`2/[:`09BDU00d=3@02010@400D00h<
3@0D4Q<040h?01<?400B3Pl05a<D01/E5`0E41404`l@018>3`0D41405A4B01<?400@30d03@T:01DA
4P0F4Q<04Ph?01<?400>2P/2014=3P0Q010<3@0?2``03`/<00l;300B3Pl04@d>00h:2`0A3@h040`=
00h82@0?1PP05`h@01D<3P0@1`T05@`>01482P07000071<E03L^<00D2`d03@D601@<3P0@2P`03@L9
00`6200>20X04@/=01D?4@0=20T0618D00@0000<1`P03PP:00L04@L800D04`T:01D;300B20T04@L8
01882@0301061`0A00l51P0>10D03P@500X10P0D2P/030<400P0000G3@h03P@500d21P0<0@D040D9
01462P0=0PH04@H:00h31`0?10P00`0@1@T01`0?10P030<501472P0:0@<04@H:00d21P0C20`00P0>
0`L0100A1PX06@hB01`A5@0@1@TDooooo`006oooool02@051@<02`/9014A3`0B4Q003`l=00/;2@0F
5Q@03`l=01@D4P0200d=2`0=018B400;2`T03Ph<01/K6@0H61H03@d;01HF500<30X06ATG00h>300@
40h05ADC00T91`0200h>30803`l=00@03Ph<00d=2`0?3`d03@d;0`0<30X07P0=3@/03@l<00/=2P0>
40d03@l<00/=2P0>40d04Q@A010B3`0H6QL0418?00lA3P0A4@l04@h?00l=3P0A3a003P`=00/;2`0?
3`l04A4A00X<2`0>40l03@l>00lC4P0=40h020X700h@3@0G6AH02`d:00P:1`<03Q0=0P0A4a003@0?
4@h030h;00L91P0<3P/04Q@A00X<2@0R9240:R`Y014C400@4Pl03Q0=01<E4P0B51400P0<3P/04@0=
3``02`d:00L91P0;3@X03a4>0001000V:2D03@h<0001000F61D02``900d=2`13@d40K6aZ00X:200;
2`T03@d;00803`l=0P0;2`T0400@40l02`/=00d<4@0=3@h0410@00X:200D5A002@X5014B3@0<30X0
5ADG010@4P0;2Ph05aLG00l?3@0;2`T200h>300;010@3P0;2`T061PF00d=2`071`D092@R0:NWY@0C
50l00@8000`=200B4`h00`0?40/06@0>3`X03@h900d>2@0>3`X03Q0;010B3@083@L02a0:00dB3009
3PP01``600/@2P0@5@l00@H00003000;40X0314;00X;1@0=3PP020T301DF400>3`T04a@>00l@2P0<
3@L00P0:2`D02@092P@020T300L60@0B4@`02@P3014@2`0S8Qd04A0;018A300200l>2@0S010?2P0=
30L02`X501<B3@0F5A004Q4<00/:1@0>3@P04a8=018A300:2@@01@@0018A300920<04Q4<00`;1P0@
3`X03Pd800l>2@0=30L02@P300/:1@0=30L03Pd800l>2@0>3@P03@`700`;1`0;2PD030/602d/9`0C
4Pd040l:00l>2@030P000P0@3`X03P0=30L030/700/:1P0E510040l;00P70`0@3`/04A0<00/:1P09
20@03Pd900/:1P0<2`L03`h:0P0A40`08@0?3PX04a8>010?2`0;2PH04A0<01<B3P0?3PX04Q4=01DD
400D4Pl0510?014@3P0=30X03`h<00h>300<30X02`/900`>2`072@H04A<@00lB3`11@Cl03Pd;01DD
4P0?3P`00`8000l>300F5A<04Q4?01<B400A40h03`h<01/J6002010?3@804A0>00h04Q4?01<B400H
5aD06QTG00X91`081`D07QdK02h]:`061@<02PT701@C4@0C4Q003Pd;018A3`<040l=00/03`h<00h=
2`0>3@/030d8010A3@0@40h03Ph@00`<3`0<2a003@`A00/:3P0200l?3`0;00`=2@0?40/04Q@C010B
4@0<3Pd02P`;00/=300>40l03a4@014C4P0?4A000P0<30`0300?3`l04@l@00d;300=2``03`d>018@
4@0E4a@07A/L014?400=2``03P`=00`:2`803P`=00<03`d>010>3`0@3Pl00P0>30d06P0;2@X02@L8
014?400>30d030X;01@B4`0@3a@04Q4F0000100d<cP0knkc03Th?@0B4AH03`hC00d<4@0;2Pl030/@
00d=3`0A3Ph04@d<01HB4@0D4a404Q4?01<C4@0?3`d0418?0P0A4a000`0>40d03@l<018B500201<C
5@04014A4`0B4Q@05ADG01@D5P804Q8D00T03`lA010@4P0B4a804A<>03m1?00:30P05aTD01@F4@0?
4@`00P0@4Pd04@0E5a804Q@?014C3P0E61803Q4:00/>1`0?4P/02@`500hA2P0H6a@04QD>00lB2`0@
4``04aH?01@G400D61<04AHB00<041DA00H04AHB01@I5@0C61@04QLC00lD400@5A4301<H5005014F
4P0@5A4041DA010E4@0G71P00P0A5Q80GP0D6AD04QLC01<I500D714041P;00lG300E71@061lG01DK
5P0d>SP0=C/i01HL700E6a/03aDE01/Q8@0B5aX04aPK01HL700I7al06R0N01XP7@0J81`05A`E01LN
5P0I81P05alD01dT700J8b005b0O01DN7@0F7ah06R@S01hX9`0F8R006bLU01l[:@0N;BX07RdY01d[
:`0Q<3<05bH[02Pg>P0J:RX0:SXi01/[:P0L;2T08S8`01l_;`0_?T40;3/o0:Fd^@11D5L08S<j024b
>@0_@4L0AUQL02Li?@0S=CT09SPj02@f>00Q<c<0838b02@f>00W>3l09CHm02He>P0/>cl0;3`l02Pf
=P0Y>3@0:SHb02@a:P0S<2L07BXQ024]8`0R:R8061lG024X800W;RH08BPP02H]9@0T:b<0:2lW02@[
8`0[<RX0;C@/02D/900U;bH0;CL_09jXX01HHUX0DU]F02lh<`0T;BP2020Y9P0o02D^:`0Y<Rl0:S<`
02/d<@0Q:RD092hY030k=@0c?c/0934^02/k>P0eADD0>T]A03E6CP0gBED0>D]H04AJI`0hCU/0@eQS
0355D01SMh00>diG03U;E@0bAD`0<dE<02/lA00R<c/0;C/o02Da<@0R<340:CHk038oA`0c@DX0>TQB
041>F@0iBU@0;Sm702m0A`0]?TD0;cm502/j?`0W=S/0=DA804iMH00X=ST09S4c02Pc=@0Y=CD09S0a
02<];P0R;2d08RL[01XO8`0g?4008bP^028W;@0^<cP09b`b02P]<`0V:c409R/_02T^<P0U:Rd08bLZ
00808bLX06008RHW024U9P0Q9BH09RX[01hR8`0Q9BH04ADF02@X:@0K7b005QXI020T8`0N8R40720O
01lS8P0I7A`061`K020T8`0L81l06AdL01/O7P0F6QT08B8T01HG6@0N7b407AhP01XK7@0A4Q@051DG
01PI6`0E5QP07QlQ01XK7@0L7Al05aPJ01/L7`0N7b@06ATQ01LG800P82`0;Bdi02XZ<`0;2a<0824V
00l@500I6Qh04a8H01/K8P0G6R4092Pa00`A6`0I82X03A@L01PN900F6ah04A@F02@T900c<c<061LL
01@C600E51T04a8G01HE6P0L6b00QXF:04Y9CP0A41D05QDJ018A5P0G5aT03Ph?00l?3`0>3Ph03`l?
01<C4`0F5QH061PH01LG5`0E5AD03Ph>01@D500H61P03`l?014A4@0=3@d0410@018@4@0<2P/040h?
018>3`0E4A804@d>010:300E41804`l@014=3P0B3Pl201@@4@07018>3`0?2``05Q8C014=3P0;1`P0
40`=00l;3002014=3P0R010<3@0?2``03`/<014=3P0@30d030P901LC500S7b006ADF00X51`0D2`h0
91/N02<J7@0F3A0060lB0189300A20/03@@701TA4`0D2`h02@0301D>400D3Q0040X<00h82P0?2@/0
4P`>03/e=`0d;S002@@501/E5`0B30h02PD601<92P804PP900T04@L801061`0@1PL02`4200h41@0A
1`P03P@500d3100?1@H00`0@1PL00`0?1@H03P@500h41@0201<92P0401892P0;0@802@0000h51P80
3P<70P0D2@d0100=0PH03`@801<8300@1@T200`11@0>00h31`0A1PX04@H:03/`=00;00@040D900d4
1P0=0PH02P0300h31`0=0PH03`@801<8300?10PDooooo`006oooool00`0B4Q004A4?00l?3@0300h>
300<010@3P0>3P`030`:00`<2P0>3P`0410>01DE4`0;2`T02@T700`<2P0=3@`00`<10P0>3P`02P0J
6QP04A4?00l?3@0;2`T03Ph<00l?3@0=3@/02PX800d=2`0A4@l200d=2`0E00`<2P0>3P`01`L5014A
3`0?4@h030h;00/=2P0<3P/03Q0=00lA3P0A4a004aDB018D4@0>40d03a4>018B400A3Pl03`d>00h<
3@0?3@h03Ph>00803`l?00H04Q@C0001000D5QD051PG020S8@0=3``200/=2P0600d?300?4@h03a4>
018D4@0A4a002P`90P0@4Pl01`092`P02P`900h@3@0A4a002P`900/=2P0@4Pl00P0:30T0900T9R<0
51HC0043000:30T02`d:00X<2@0;3@X03@l<00lA3P0A4a005aTF00840@0A4a004Q@A00lA3P0<3@X0
3@d;014A3`0F5Q@05ADC00h>300J6QP02`/9014A3`0@40h02PX800`<2`0@41803`hC00l?400>3Ph0
3`l=010A300B4`h02@X500l?3@802`/=01003@`@00L71`0;2`T01@D300l?3@0A4@l03`l=00`<2P0@
40h03`l=018B400Q8Al0ADE300l@2`0=3PT030d80P0>3`X0700;30L00P<001@E40092PD020T400X;
1P0;3@P02@/600T<200F6aD01@X400@910062`D020d700X?2@0320801P/501<H4P0H7AL061TC00d>
200@4@/03a0:00P90`0A4P`05AH@00h?2@0<3@L300d>200f010?2P0<2`H02PT4018A300@3`X02PT4
01<B3@0B4@`03`h901@C3P0G5Q4010<000l>2@071P402`X5010?2P0B4@`020L200`;1P0D4`h02@P3
00h=200A40/03Pd800/:1@0H5a802@P303He<0081`8040l:00h=200?3PT040l:00l>2@0<2`H02`X5
00h=200<2`H04A0;01TH4`0G5Q404Q4<010?2P0=30L030/600d<1`0>3@P02`X600X91@0=30P02PT5
00L60P0920@03@`80P0A40`04@0>3@T04A0<014@300<2`L03Pd9014@300@3`/03@`800l>2P0A40`0
3Pd900P70`0A40`02`X601@C3`0?30X04@d<00803Pd;00T040l=00h>30092@L05QHD00L91P0=3``0
004000dA3@0?3`d00P0A40h0100?3P`03Pd;00d<2P0>3@/400l>3003010?3@0=30X03Pd;00803`h<
0P0>3@/02@0920H06aXH014@3P0D4a404A0>055@CP0B4@l03Pd;00`;2@02014@3P0G00/:20071P@0
40l=010?3@0E51804A0>00`;2@092PD03Pl;00d=2`0:2P`0410C01`K800H5a`051<G01PH600C4a<0
2PX701@E400B4Q804A4A010@400?4A000P0>40l00`0=3`h030h=010B4@0201@F5@03014A4@071@H0
3`d>008020H700D04@l@00/92P0;2@X030X;010>3`02018@4@06010>3`0<2P/040h?010>3`0>30d0
3`d>0P0B41407P0=2``04Q0A01<A4P0?3@h04@l@00h=4P0D4aP04A0E01/J7`0S8RL07A`Q00h=4P0F
5AX040lD00`;400B4AH051@F00h=300B4@l05A@B01<B400<30X02PX8010A3`0<3P/0418?010E4@0D
6AD03a4>00h>408051@F0P0@41800`0B4Q@04A4C014A4`03014A4`04018C4@0A4`h04A<>010B3@80
3a4<01D04Q@?01DG4P0C5A00418=00lA300A4`h05ALB01<E400D5Q403@l:010B3@0H6QD0418=014C
3P0?4@`04Q@?00lA300>40/05ATD00H<200;4@d00P0G7AT0;@0E6aL020h:01TO6`0D6QH03aDA00/A
3@0C6AD05adI00/A3@0A5a<06b4M014G4`0>51003aDA010F4P0B61@05A/G01LM6@0I81X06b8J01<M
4P0?6A003AL>00`F3@0C7AD031D@01TR7@0@6AL04a`K01<K7@0B6Q`07BDW00L?4@0S;2`04Q/J01TR
7`0H8Ad0624L018L500H8QT06B<J00lI3`0G8AP06B8O01TR8@0301PR8@0/01LS8@0L:2P062DU020^
;P0L:RX072XY01XX:00J:B`07Rdb02@c=P0V=SH08c<b01`/:@0R<S409CDe02Lg=`0U=3L09C@j02He
?00M;SD0:S]202Lh?`0T=SX09SPl024c=@0M;c409SPj024c<`0_@D4093Hf02Lf>@0Z>Ch08S4f028`
<`0U<cD08Bl_01hZ:00W=2h0:SD_02D`:00M:Ah07b/Q02<_9@0L91`201hU7@0701lV7P0Q:20092/S
02H]9@0S:R8092/S02P_9`0202/b:P0802Ha:00U<2P0:cH^02Td;00W<R`0;3La024/9P0U<2`202Lb
;P0_02Pc;`0Y=300;CHa02D^:@0T;RP0;CP`038o>00T<Rh0:3Pg02Ti>@0_@DH0>4UA0312CP0gBUH0
<DE@03I:E@0jCUT0BemX0;?5c`1NL7T0=4M>0393B`0[>d80:cY104EDF`14DUH0?DQ:02Xh>`0c@DD0
:SLo05QVK`18EV00<Cm:02dnAP0[?4@0:ca302dnA@0a@TH0;Ca102Xi?P0b@DD0;C`o03=1A00U<380
9S4c02Pd=00Y<c@00P0X<S<01`0]<SH07b@X02<X;00/<CD09BX^02H[;`0Q9RX00P0U:Rh02@0V:bl0
:c0d02T^<@0V:Rd092PY01hR8`0P92D092PY01`P8@0201hR8`0501/O800N8R<08RHW01/O800O8b80
0`0L81l201PL6`0[01HJ6@0N8R4051PG02<W9P0V:RT07B4P01/L7P0O82802@X<028S9@0H6A/06a`N
04m@DP0F5aT06Q/M01`M7`0C51H061TK01/L800M7R<06AXO01HF7P0L72D09RH`02XZ=00L72D05ADM
01HG700F5a/06Q/O01PI7P0H6Al06A`S028V;`0F6bD01PlH00TB6@0G7B<061dP00`@4P0Y:bX0B4Y9
01PG700401LF6`0U01HE6P0N7B807A`Q00d<4@0A41D061LL00l?4@0H61T02`/;018B4P0=3@d04a<C
018B4P0E5AD04A4A00d=3@0D51@03`l?018B4P0K6a/02PX:00H61P0A4A404@l@01XH6@0B414061@E
01<?400>2P/03PP:00`72@0D41404@d>00h:2`0A3@h03`/<01<?4005014=3P803`/<01l03PX;00d9
2P0A3@h03`/<00h:2`0?2``07a/L00/7200@30d03@T:00`7200B30h0Qh6303hh>P0F41802P@600h8
2P090`D03`T;014;3@0<1PP04`d?03H`<P0E3a403PP:00@0000:10H05Q0B02TS9@0M5aT03`T;0080
2P@600L03PP:01L=3P0:00406Q0A00L0000<0P<050X;00H040H700H04@L800l51P0<0P<02`4200d3
100@1PL600l51P0800`11@0A1PX05P/?01462P0?10P04PL;01462P0;00@200d21P0>00l4200J3a<0
OW=g01T@4P0D2@d04PL;01052@07000050T=00d21P0A1PX0200101D:3P0A1PXDooooo`006oooool3
00h>300500l?3@0A4@l04Q8@018B400@40h00P0>3P`07P0@40h04Q8@00/;2@0<30X02@T701<C4@0?
3`h030`:01dM6`0>3P`04A4?00l?3@0@40h02`/900h>300?3`d03@d;00`<2P0>3P`0410>018B400`
<2h03Ph<014A3`0C4a402`/900h@3@0=3``030h;00d?30<03Q0=01404A<@010B3`0>40d030h;00h>
300A3Pl03`d>00h<3@0?3@h03Ph>00l?3`0;2`/04aDD0412@@0>3`h03a<B00X=2`0300d?300300h@
3@0?4@h030h;008030h;00@02P`9018D4@0E5a@04Q@A0P0<3P/0600>40d02`d:00/=2P0=3``05ALD
01HH5@0;3@X03Q0=018D4@0=3``030h;00d?300>40d03a4>010B3`0?4@h020X801dO700@4Pl01@L5
01<E4P0=3P`03@d<00l?3P804Q8A00D03`l>00d=30092@P071`K01LG5P0200d=300K00l?4@0>3A80
3@d>00d=3@0=3@/03a0;00d>2@0@4@`04A4?00L72@0B4Q@03PhA00/;2`0>3P`02`/9010@3P0:2PP0
3Ph<00d=2`0A4@l03`l=00P81`0820H04A4?00l@2`0=3PT030d800803Pl:00l030d800l@2`092PD0
414<014B3@0@4@`02@X5010B3@0?4`h03A4;00D90`0=4@/01`/501HI5020Q7h00P0@50h02`1ZKVP0
418=010A2`092P@03@h800h?2@0:2`D04a@>00L80P0=3PP03a0:00803@h801803a0:00h=2@0M71L0
2`X501DD3`0=30T0CTe801`K5P0;2PP03@`700X91`0@3`X04Q4<01HE400@3`X030/6014@2`0;2PD2
010?2P0;00l>2@0D4`l03`h:00/:1@0B4@`030/6018A30061@0081lJ00`;1P0?3PT00`0<2`H04@0>
3@P04A0;018A300:2@@030/600d<1`0>3@P040l:014@2`0=30L03Pd8010?2P0?3PT03Pd800h=2@0=
30P03Pd9008040l;00D03`h:00d<200@3`/040l;00d<2002010?2`0300d<200>3@T03`h:00<040l;
01P03Pd900d<200C4Ph0:bXV051?B`0A40d04Q0=01<?3@0A40d03@`900X91P0;2`P03@d:01@E4@06
20@03@l;00`>2P0?4Ph02`/900d<2P0?3P`04Q4?01<B400E5183010?3@<03`h<0P0>3@/300l>300h
00h=2`0D4a401PD301HE4`040`4040l=010?3P0B4@l03Pd;00d<2P0@3`d04A0>00`;2@0D4a403Pd;
00/:200A40h02@P702<R800L7AP04A4>00X:200=3@l04a<F01@C600T8bP05A@H01<C4`0B4Q8030`9
010A300B4A804a4A014@4@0A4100410@00l@3`0B4a80414A010B4@0A4a803a4@00/=300>3@`03`h=
00l=3@0I5aL081lN00l>3@0>30`04a8A00X8200A40l07ahM00d<2`0>30d2014?400?010>3`0A3a00
4a4B00l=3P0;2@X03`d>010>3`0=2``03P`=00h>4@0B4AD030/?010?4`0C4aH03@`@00803`hB01<0
4A0D00h>4@0>3Q4051@F018A400=3@/030/900d=2`0B4Q0051DB00lA3P0F6QH08RHR01@I5@041`@0
4aPD01<C4`0B4Q<04A4B0080410A1P0A4A800`0A4Q404A<>010B3@04014C3P804aD@00/04A<>00lA
300A4`h04aDA01DG4`0F61@09RPT01XL600<3PX051HB01PJ5P0201HH500C00lA3@0=3`/05ATF010F
4`0D6QL04QPE01@J5`0H7Q/051XG014F4`0G7AX05Q`I01PN6`0@5A804ALD00lE4P0E6aP07B<P01TO
7003010F4`804QPE04/04aTF01@J5P0A6Q<03QP?014K4`0D7QD04A/B01<M5@0F81P0624K018K5`0>
5aH03aLH01TQ8`0D71d05b0P01<L700H8B00624O01TR7`0J8al05AhI01PQ6`0H8Q/04adE01dV800I
8al06R@R01XT8`0K9R@06bLV01`X9`0F8b<06BLW01/Y:@0Q<30062LW01`[;@0L:bh072`_020a<@0R
<c808C8`01`]:P0N;bh08S<b02<d=00R<cL08c<i02@e?00X>d409STn02Li?P0V>Cd093Hi02Li>`0X
>S/0:S/l02@e=@0^?ch0:SXj02hm?@0`?T00:3Df02Ld<`0Y=SD0:3<`02Da;00Q;BH08R`T020[8@0M
:1d07bXO028/8@0J91/00P0L9A`02`0L91`07bLO024Y8@0M9Qd08R/R02H_9P0X<2P092`T020Z8@0U
<BL08bhV0080:3<[00D092lY02D`:P0U<2X0:C@`02/f<P0202Xe<@0R02/f<P0T;BP09BlX02Pc:`0T
;bL0:3D]02Dc;@0W=c@0:CTi0352A`0a@TX0;Cm903M:E@0cAe80?51J03U=EP0V>D<0BEaT045CF`0h
BU80<D5902lnA@0^?D@0:3Lm02Tf>P15D5<0<Sm4034nA@0X=Cd0>TQA02`jA@0a?dX0;d180311B080
<49600T0;d1402ln@`0a@4D0<T550350@`0`?T40<3/m02`g>@0W<c<00P0Y<c@01P0Q:b`09b``01dR
9P0Z;c80<3Dg02<X:@<09R`[00T092X[02P]<00[<3@092T/02@X:`0U:BX08RHW020T9@0S9bP00`0N
8R<04@0L82407R8S028V9`0L824092PW020T8P0P9B8082@R01`P7P0L8Ah07R8P01PL6P0I7A/06QhL
03@h=P0M8B007QlQ00806Q/M02806AXL01XK7@0R8bD0HfAV02HW:@0E5QP05QLI01XK7@0F5aT05QLK
01/L8@0J6b005QLM01@D700F5Ql07AdV01LG7`0G61h05aPM01<D6@0C51P04a@I01`N900F6B004QHO
00lG800W<3T0:C8i01LO900H7B0041@F020R8@0G6AP04a8G0P0D4aP301DD6@03014@5@0I61d05QDJ
008051<H01h04Q8D018B4`0F5QH05aLG01@D500G5aL03Ph>01<C4`0B4Q803@d=010@400?3`l06ATI
014A4@092@T04a<C01@D500;2PX04Q0A010>3`0F4Q<04`l@018>3`0E3a405a8D02<O800M6AX0510A
014=3P0<20T600l;300@010<3@0A3@h04@d>018>3`0F4Q<04Ph?00h:2`0?2``02PH700l;300B3Pl0
3PX;00h92`0B3@l0BTA7028L7`804P`?00<04@/>00`62@0=1`X00`0@2Pd04P0B30l04P`>010:300@
2P`04@/=00l92`0A2`d03@L900h82P0A2`d03PP:00d72@0D2P/0200001071`10=SL03`L700l61PH0
40H700H03@<400h41@0A1`P04@L801061`0>10D600l51P0800X00`0?10P04`P<00l4200=0PH03`@8
01872`0>0`L200l4200>00h31`0C20`0I5UM01/@500?1PP02`8401@93@0?10P030<500l5200?10P0
40L901052@0<0PDDooooo`006oooool00`0B4Q004A4?00l?3@0300h>300B014A3`0@40h03`l=00l?
3@0@40h04A4?00X:200I6AL04A4?01`L6P0<30X02`/901LG5@0<30X04A4?00l?3@0D5180410>0`0>
3P`02@0=3@/03Ph<00l?3@0I6AL0Cdm=01HF500:2PP05ADC014A3`0600d?300F010B3`0B51404aDB
014C400>40d03Ph<014>3`0?3@h03P`=00l=3P0>3Ph03`l?010@40010`802P`;030b<@0<40l02@`:
00d?300?4@h0418?00lA3P803@l<00X03Q0=014C400D5Q<04Q@A00lA3P0D5Q<04A<@00`>2`0>40d0
3@l<0P0<3P/050051`@0418?01<E4P092`P030h;00X<2@0<3P/03Q0=010B3`0?4@h03Q0=00T;2008
2PL04Q@A00X<2@0C5A80<cDb00L81`0=3@d030`<0P0=3@d01`0>3Ph0;Rh^01@D50061PH02@T9010@
400B4Q800P0>3A804P0=3@h030`<00d=2`0>3`X0414<01@E400K6aT01`L900D51`0?3a8020P800X:
20092@L0410>00X:200?3`d020P600`<2P803@d;00<02`/900`<2P0=3PT01@0=3PT09`0@4@`03Pl:
014B3@061`803a0;018C3P0;30L06adH0084000:2`H04A8=014C3P0C50l0>S`g0001000];RT0=3D`
01@E400?40X02``600l@2P0@4@/03a0:01DF40092P@03Pl900d>200<3@L03@h800X;1@05100030/6
00<2000?3PT00P4002HU800@3`X03Pd801HE400200d<1`0E00`;1P0A40/020L2018A300g=S405aHA
01<B3@0920@05A@?03Lf<@0S8Qd01PD000/:1@0>3@P03`h900/:1@0:2@@04A0;00d<1`0@3`X03@`7
008030/600X03@`700h=200>3@P03@`700`;1P0=30L03`h9014@2`0;2PD03@`70`0@3`X01@0=30P0
30/700h=2@0>3@T03@`8008030/70P0@3`/0700=30P040l;010?2`0?3PX03Pd900`;1`0@3`/04Q4=
00l>2P0A40`03Pd900X91@0^;BT0IFAP01dL600?3@T04@d:010?2`0C4Ph040l;00l@2`0@4@`05aPC
018D3`0C5A001PP300hB300A4@l2014@3P8040l=00@04A0>018A3`0A40h040l=0P0>3@/00`0=30X0
3Pd;00h=2`02010?3@0;00l>300>3@/03Pd;00X91`0510<061LE01<B400>3@/040l=00h=2`0=30X0
0P0?3P`05@0>3@/040l=00h=2`0=30X040l=00H50`0D4a408B8M018C3`0;2`T0410B018B5@0<2a00
61LL00l?4P0@41004Q8B010A3@0D4`l04@d>018=3P02014=3P<03`d>01803Ph>00d?3P0>40l03Q0?
00h>3P0E51803`h<00d<2P0F5A<06APF00P71@0<2`T040l=00L6100>3@/06aXH00l>300>30d3010>
3`<04@l@00<040h?014?400B41400P0A3a009`0@41004Q8D00l?3`0B4Q<05ADG014A4@0?3a002@T;
01DE5@0D51D030`>018B4P0?3P`04a<A01HF500E5A<0418?00h@3@0=3``041DA014F4P083@T0;C8^
08N<R00O81d05ADE018B400B4Q40410@010@3`0B4Q004Q8B018B4@0B4Q004Q8B014B3P0?4@`0418=
014C3P02018D3`80418=0P0B50l2010B3@0H014C3`0C5A8061XG01`N6`0>40d02P`9010B3`0B5140
418?014C400@4Pl04Q@A01`Q7P0;4@l03aDC01LM6`0@5Q@04QPF010F500Q9bD06R0N010F500A5aD0
4aTG0P0E6aT0100?5A<041HD01PN700I7ad201<I5`8051XH04D05A/I01@L6@0C71T04AXG01@M6@0E
7aL041XA00lI400;5@`0218901TS700Q:RL0;SLf04]DD`0>5aH06B8O014J600E7Q/03aPE00dF4`0C
71T05AhK01lX900Q:RL06B8N01TR7`0G8Qh06B<Q01XT8`0K9bD07BTX01hZ:P0A7al07B//01XX:@0_
?cl093<e0391A00O<C<07S0`01lb<00R=C<08cHc024d<00N<Bl08SDd02@f>00T=SX09CHm02Dh?`0W
>T0093Pk02Pk?`0cATX0=dY<02`n@00W>CT0:CXj02<c<`0P<2l07bh^02Dc<`0^?CT0:3@`02Da;@0V
<b`09S4[02D`:00P:b<00P0L9Qd0100N:1d082PM01lW700K9A`301`V7@1001hX7`0P:R409BlV02@^
9@0S;B@092hU02Pb:@0Z=R`0:3@Z03M2>P0d?cL08bhV02D`:P0`>cD0:SD_02hi=@0_>SH0;STe02dh
=00^>CD0B55<02<]9@0[=Bd0;STa02Tf;@0P;RL093@a02Ti>00dATT0<45803Q:E01[OXP0AUYU03Q<
E@0hBeD0>4YD02e0A`0gBE00B5UQ055PI`0a@4L07B`c02He>P0c?d@0<Se102dj@01?G6<0<d1903A2
C@0e@dh0=49;0393BP0bA4T0<49402i0@P0Z>Sh0;ci30391AP0[>Sh0;Se002Xh>`0[=SP0:3<e02Da
<@80:38c01X09Bl`030e>00R9bX0:Bh`02dc<@0R:2@0:C0Z02H/:00W;BT09bdZ02H/;00V:bh08RLZ
020T9@0T:2T08RHW01dQ8P0O8b@07R8S01`P8@0M8B80720Q01hR8`0Q9BH07B4Q020T8`<07B8N0P0I
7QX06P0P9B405AXF01/P701CF5@0`/O302ld<00P8B<07QlQ03dn@00O82806Q/M01TJ700^;c408b@V
01PI6`0>3a406a`N01lP900F5a`071dR01dN8`0I6Ql051@K018B6P0G5al05ADL0P0I6Ql201@E6P0<
02//<@0Y;380724W01DL900@6240=3e608VBV@1jPXL09bla01DJ700N81l06Q`K0P0E51T04@0F5AX0
61LL01TH7@0I61d05aHK01<B5`0B4AH02`X?01@C600T92H06QXK00L71`0R8R806ATI00X:2P0G5aL0
3Ph>008061PH01D04a<C00`<300H61P092@T010@400820P03`l?01PF5`0?3@h03@/<01<?400A3@h0
510A01H@4P0A30d05a<D01<?400A3@h0510A018>3`0D41401@0A3@h2018>3`0N014=3P0D41406QHG
01@@4@0<20T06aLH00h:2`0D4140100100T51P0<1`T030H:00l93@0;1@T01`4501<=4@0@2Ph02@<7
014;3`0=1`/04@/?01`F6P0K5AP04`d?01D?4@0?2@/0100000h82P0B30h03PP:0P0=1`T0200:10H0
3@L90147200=0`@06a4B06=IFP0P5QL03`D61P0@1PL01P0<0P<03`D601<92P0D2P/04PP900h41@H0
3`D600T03P<701052@0C20`040D900l4200A1PX0304500/0100=0PH00P0?10P03@0>0`L01`0000l6
200I3Q802@0200/2100=0PH02`0400X10`0A1PX03P<700/1100;00@05?ooool001_ooooo00<04Q8@
014A3`0?3`d00`0>3P`200l?3@803Ph<0P0?3`d0300:2PP09BDS008200061P@051@B00L71@0=3@/0
3Ph<01TI5`0?3`d04A4?00l?3@<03Ph<00T03`l=00h>300=3@/03Ph<028R80010@005QHD01LG5@0<
30X01P0=3``07@0@4Pl04A<@014C400B51403a4>00h>300A3Pl03`d>00h<3@0?3@h03Ph>00l?3`0D
51@05aTH014C4P1IFeX051PG00`?3@0=3``0418?014C400?4@h03@l<00lA3P0=3``02P`900`>2`07
2@H02@/80080828O03<03a4>00D710051`@02P`9018D4@051`@00`D200h@3@0A4a004aDB00lA3P0;
3@X03@l<00h@3@0=3``030h;01@F4`0P8Ql0008001DG500@4Pl0@TA1018C4@0>3Ph03@d=00/;2`0<
30`03Ph>01HF5P0@41005ADE00P820061PH03Ph>010?500?3Q<03Ph?00h>3P0>3P`0414<00L80`0=
3PT03@d;00L72@0H61X04a8F014A4@0B4Q0030`:014A3`0>3P`00P0<30X01@0>3P`02`/900T91`0;
2`T0410>00H03@h901@020T4010A300=3PT02``701HG4P0@4@`05QLB034a;0051P4040l;00L71@0>
3`X02PT501@D4@0J6aH00@00014A3@0=3PT030d700X;1@8030d700h02``600d>200=3PP02P/500D6
000:2`D0414;00P90`0@3`X03`h901@C3P0@3`X04a8=00<200803Pd801402PT400/:1@0I61<04Q4<
01DD3`0<2`H04a8=038a;00?3PT02PT400`;1P081`807QdH018A300920<05aHA00l>2@02018A3004
00T8100C4Pd03@`700d<1`<03Pd800D02`X500X9100A40/02PT400/:1@02010?2P803@`700/030/6
00d<1`0?3PT04A0;01<B3P0H5a<06QTE010?2`0510001PD100/:1P0200l>2P0E00`;1`0?3PX03`h:
00l>2P0>3@T03@`8010?2`0B4@d03`h:00`;1`0D4`l04Q4=00/:1P0920@01PD100/81`0?2`P03@`8
01HE4@0D4`l03Pl:00804Q<>00L0004000lA300C5A003Q4<01<C4@0C4Q0040l=00<03@`:00<04Q4?
014@3P0@3`d00P0>3@/00`0=30X03Pd;00l>3003010?3@0;00l>300>3@/06APF01HE4`0M71X02`X8
00h=2`0@3`d03Pd;00`;2@0=30X00P0?3P`0500:2@L04a8@00d<2P0@3`d03Pd;00D40P0F5a804Q8?
00l?3@0@41803`lB00`;400:2@h03@`@014A4@0@41003a0<01DD400?2@/04@T<0P0@2P`0400?2``0
3@/<00h<3@0?3@h03Ph>00d=3@0>3Ph03`l?01<B400?3P`02@P600/:200>3@/02@P600d<2P0<2`T2
00l>3005010?3@0H5aD03@/<00d;300>30d0100?3@h00`0@3Pl03`d>00l=3P0200l=3P0T00`<2`0>
3Ph03@d;010@3`0B4Q80410>00X:2@0C4a<0:2PV02<S8P0;2`/020P600`<2P0D518061PF01HF500=
3``020X700dB3P062`L010T500D;1`0a=c<0RXn;01TJ5P0@40h03@h9010@3@0@40h0414=018C3P0B
4Q004Q<?018C3P0B4Q004A<>0P0@4Pd2018D3`0301<E400@4Pd0418=00804Q@?00X04A<>018D3`0B
51005ALD02LY9P0D5Q<02`d:01XL6@0A4a005QPE0P0B51409@0D5Q<071hK03]0?@0L9B80214>00hG
500330T031DB01HO700G81d07RLT051IEP0L9B805QlL014J5`0B6aP03AHC00`E4P0C71T05QlL00lH
5@0@6AH04AXG01<L6@0D7AX05AhK01HN800B71d04QdJ018M5`0>6A4041`B01HR5P0?6a4051lF00TD
3P084`l00P0F8Ad0;00B7AL05R4L00dH4P0A71H07bXV018M6@0D7a/06RDQ01/U900G8Al05b8N01<N
6P0D81d05B4O01HR800H9B@05bDU01TW:00J:B/03ahQ02Th>`0`?d<0CUeP01d_<@0L;Rh072l]01ha
;`0P<bl07c8^01lb<00S=C@093Hh02@f>P0T=C`09CPo028e>`0V>ch093Tl0396A`0jCDl07Bl_02<e
=@0Y>SX0:3Pg0P0O;Bd03P0U=340:CD`02@_9`0Q;2@082/S024[8`0P:R408bdT020W7`0N9Ad07bHN
01hU7@0M91`072LO0`0N:B40100Q;2@092lW02Pc:`0W<RX202D`:00702Xe;@0_>S80;3T_03M4>`0d
@CP0:CH]02Pe;P0202dj<`0a030l>00a?CT0;c/g02hj=P0_>SH0HVaU02dg;`0V<BP0;CT_030m=00Y
=c00<40m03=3@P0Y>ch08c@k045CG@2;WJL0BUaV03a>F00cADh0=DQ?02Xk@`0_@4L0>T]B03]:D@0]
>d40;3To02/h?P0Z=S/0;cXn03]8CP1NJg80=T=<02Tg@P0^?4H0<Cm80352B@0b@dT0<49402m1@`0/
?400<T5603=2A`0Z>Cd0;3/n02/i?00U<3809c8d02Lc<`0202@^;`0A02Tc=00_=3L09B/[02X`;`0e
>cL0=3/d03Y1>P0V;BH0:C0Y02Xa:`0T:RP08BLW02D[:`0M8B808BDV020T9@0K7b000P0M8B801`0J
7Ql07B4R01dQ8P0M8B808BDV01dQ8@0O8b800`0K81`201LL600G01/P700I7QX0724M05eRGP3Kh=`0
>Slk020Q8`0N7b40?Sm1020Q8`0J6ad061TK018C5@0?41805aPJ01dN800T9BL02@X>01PI7P0J6R80
6a/S01TJ7`0G61d00P0F5a`04@0D5AX05aPM01LG7`0E5Ad06ATQ00X=4P0K7R@06AhT00lF7P0O9bl0
JgEn0>Scn@3?e]T0<CTk01XP8@0?4a806Q`K00805QDJ02L05aHK01TH7@0J6Ah06QTN01HE6P0B4AH0
5A@I01<B5`0S8RL0>3Pj06YZJ`0;2`/02PX:00h>3P0@41006QXJ018B4P0G5aL051@D00`<30092@T0
6QXJ018B4P0D51@092@T01@D500>30d030X;018@4@0E4A804`l@01HB4`0G4A<040/=01LC500B3Pl0
3@T:00l;300<20T01`0A3@h0400B3Pl040`=018>3`0H51D04`l@00d92P0<20T00`00014=3P0C3a00
40`=00d82`0I51P04`hB01D@50060@D2010;3`0B00L21P0?2Ph03PX=018=4@0/9b/0RhF804U3A@0:
1@H05a4C00h82P0A2`d040X<00d72@0>20X03@L900T31@0:10H05@/<0P0;0@800`0S6AX040H70106
1`0601061`0300l51P0@1PL04@L800804@L800<040H700l51P0?1@H0100?1@H00`0?10P040D90146
2P0601052@804PL;00<03@8601hC5`0B1`/00P0<0@D0200C20`02P0300L0000K41@050T=00L0000B
1`/03`@85?ooool001_ooooo0`0>3P`0100?3`d04A4?018B400>3P`400l?3@0:00h>300C4a403`l=
03Xj>00[:bT02@T701DE4`0?3`d04A4?01/K6@803Ph<00h03@d;00l?3@0>3P`03`l=014A3`0?3`d0
3@d;00l?3@0G5aD020P600h>300;2`T04Q8@00d?30<03Q0=01T03@l<00`>2`0A4a003@l<00`>2`0?
4@h03Q0=00h>300A3Pl03`d>00h<3@0?3@h03Ph>00l?3`0>3Ph030h=00h@3`0@4Q403a<B00d?3@0?
4@h0418?014C400?4@h03@l<008030h;00@061XG02/]:P0I6aP03@l<0P0>40d01P0B51405aTF018D
4@0?4@h030h;01@F4`802`d:00@03a4>00L81P0>40d030h;0P0=3``02@0<3P/03@l<00/=2P0;3@X0
3a4>03do?0082PL04A<@00h?3@0200l?3`0700`<300;2`/03@d=01<C4`092@T02`/;00X:2P0200l?
3`8040lD00h03`l@00h>3P0?3`d0414<00`=2@0C50l02@T701@D5P0m?Cl08b8V00L71`0J6QP04A4?
00/;2@80410>01L02PX800l?3@0=3@/02`/900l?3@0L71X030d800d>2@0?40/030d800d>2@0?40/0
30d800d>2@041@4051D@00T:1@0H6A@061LC02TW8`081P80518>00l<2@0201@B3P0500`91`0=2`L0
518>00/91P0;2PH00P0?40X300h?2@0@00`=1`0?40X03Pl900X;1@0B4`d07AhH01<D3P0;2PD030/8
014@2`081`@04A0;00P7100=30P06aXE01lN6@8071/F00T03@`700`;1P0>3@P030/600l>2@0;2PH0
4a8=00d<1`0?3PT00P0>3@P0300@3`X04A0;00h=200B4@`04A0;00h=200A40/040l:00T80`0<2`H0
3@`700l>2@<03Pd800H02@P300/:1@0@3`X03`h900/:1@0?3PT200d<1`0700h=200@3`X040l;01@C
3`0H5a<04Q4=00h=2@0201LF4P803`h:00@030/700l>2P0?3PX03Pd90`0@3`/05`0?3PX03Pd900`;
1`0>3@T030/700/:1`0;2PH07QdI02<Q7@0@30P03Pd801<B3P0?3PX04Q<=03dn>@2:RhH0H69L01`N
600;3@L041<=014A3`0@3`d03`h<00803Pd;00@04A0>010?3@0@3`d040l=100?3P`00`0@3`d04A0>
014@3P02010?3@0500h=2`0H5aD0<S4_01<B400B4@l00P0?3P`0600>3@/03@`:00`;2@0>3@/04A0>
00d<2P0F5A<03@`:018A3`0F5A<03Pd;00h?2P0@40d04A4?010@4P0>3Q403PdB00T83@0?3Q80410@
00h>3P0<3@T03`h:01082`804PP<00/04`T<018:3@0A30d04`h@01<@4@0@3Pl03@/<00d<300?3`l0
3`h<00l>2`0200`;200H00l>2`0D4a0040l<00l>2`0E51404a8?00l>2`0I61H03P`=00`:2`0=2``0
40h?00l=3P0=2``04a4B01HD5@0B41404@l@01@B4`0B4140410=00l@300@40d03a0<0P0?3``01P0?
40`02`/800l?300@4@d03`l<014A3P803@d;01003Ph<00l@3P0A4a004Q@A00hC3`0:3`/03A8>00hD
40093`/061dI018D3`0A4Pd0414<01@E3`0G61<05aPB1P0C50l5018D3`804A<>0P0B50l0600C5A00
5QPC01<E4@0A4a00:2XW01@F4`0<3P/07AlL00lA3P0I6aP05ALD014C400@4Pl05aTF034f<`0C71T0
1Pl<014J5`0:4a003QLD01/T8@1NIf@0>44n03Ho?0804AXG00D02a@A00`E4P0D7AX0624N018K6003
00hG501E010I5P0A6QL04Q/H018K6@0D7R0041XM010J6`0B7AT04A`D01HQ600G8aL06BDH01HR5`0A
71@041/D01HQ700I91d06RDN01LR6`0B7AL072LQ03M2?P0G8Al05b8O01HP800C7Ad05R0P01TS8`0I
9B806RHS01/W900L:2H072TX01/Y:@0J:2T08S0b02Pg>P0^?d808S8f028b=@0P<S@07c8a024d<P0S
=S8093Lc028e<@0O<S008SDe02<e=`0Q<ST08C8j020c>P0U>Sh09C/m02<h>P0U>CX0:Shn02Tk>`0]
?cl09CHe02Ph=`0P;Rh0:3He02@a;P0U<RP09C4V028^8`0O:b007RPN01dW7@0R:R808RTQ01lV7P0N
91d07bDN020W800M:2407b/S020/9@0R;RL09c<[02Xf;P0V<RX0;3Pa02di<@0202Pd;@1?02/g;P0_
?380;3T`02dj<@0d@CP0;CXc028_:00`?CH0<clk03A0?00`?3P0;c/g02ll=@0X<R/0<cde03<n=@0e
@CL0=T<j02`j<`0X>3D08c<b02m1A00hBE00<DA;03iAFP0Z?4H0=4I@03E7D00eAdh0<T=;03A4C00_
?dH0<T5703M5B`0c@4H0:SLm02/g?00f@DH0>4E<034nA`0`?DH0;ce8034oB@0b@4T0<D990353A`0b
A4H0<TA40310@`0a@4D0<d9702ln@P0X=cX0:SPk02Pc=@0Z=CL0:CDe024[;00P:R/09S0a02@Z:P0Y
;bl0:S0]03<j<P1?ETd0K7AY03Dl<`0_=bd0:S8Y02D[9`0P9R@092XZ01hR8`0O8b@07B4R01`P8@0P
92D0720Q01TM7P0301dQ8P03020T9@0O8b<08BHR00<07B8M0P0I7QT03@0M8Qd082DP01/P6`0Q9R40
@DI101@I5@0L7Qd06Q/M01`M7`0K71h06Q/M020Q8`0O82800P0P8B<0100G61X07AhP01LH700G61d2
01LG7`0301PI7P0H6Ad05aPL00804a@I01405aPM01HF7P0G5al07alW04a?E00O8bT03A8H01@K8`0J
92`0@deF09RSZ@2;UIT04QXL01HK7@0?4a804ADD01<B5`0201@C60<05A@I00d04a8G01DD6@0G5Q/0
4a8G01@C600K6ad05aLH01HF5P0E5AD04A4A01<C4`092@T04Q8B00803Ph>01D04Q8B01lO7`0h>3P0
CDe=00410@0J6QX051@D00h<3@0A3a003P`=010<3@0>2P/04Ph?018<3P0=20T05Q8C01<?400?2``0
4Ph?010<3@0B3Pl01@0?2``0:P0@30d04`l@01<?400?2``04Ph?01<?400?2``05a<D04]7B00P71d0
3PX;00d92P0F4Q@030L<00d93@0@2a002PD:00h93P0A3A403PT>00T42@0P6b0061<H00`8300T7b80
2P@601@>40060@802`H7018<3P0;1@L03PP:01TC5@0K5AL04`d?00l92`0=0`@040H701<92P0;0P<0
4PP900l51PP040H700@03`D600h41@0?1@H040H71P0?1@H00`0>0`L03@8600d21P0300d21P0B0105
2@0?10P0304501052@0C20`02P4300h51`0A1`X03P<700d41P0<0`D040H901<8300B20/03P@700`2
1@0@1PT050T=5?ooool001_ooooo00<04a8@014A3`0?3`d00P0?3P`01P0>3P`040l=014@3P0A4@l0
4Q4?014@3P803`l=00T04A4?02HV900820H04A4?00`<2P0E5A<02`/9010@3P0=3@/00P0E5A<03P0?
3`d03@d;00l?3@0B4Q003`l=00/;2@0<30X03`l=00T91`0?3`d02PX800`<2P0<3P/03Q0=0P0?4@h0
3@0<3P/02`d:01@F4`0=3``030h;010B3`0A4a004A4?010>3`0?3@h03@d=00h=3P0>3Ph00P0?3`l0
1@0E5aH02`d<00H71P0D61L03a8@00<0418?02003a4>00h@3@0@4Pl01`T600P:1`0D5Q<01`T600H8
1@0C5A80418?00h@3@0<3P/02@/800lA3P0@4Pl04Q@A00@60`0D5Q<02`d:01PJ5`0j?3T03a4<00h@
3@0<3PX03@l:00h@3@0B5100004001PJ5`0;3@T05QPC00H81@803`l=01X04Q4A00h<3@0;2`T03Pd<
00T7200<30X05QDD00L51P061P@03`h?00h>400=31403@d?00`<300=3@d03Ph<01DE4`0820H04a<C
010@4P0820X04A0D01`L700n?S`0;Bd[00T91`8030`:00T020P6014A3`0C4a402PX800H6100@40h0
2``700d>2@0?40/00P0<3@P05@0?40/01@H100`=20092PD06Q/F01<D3`1lOGP071/G014>30030P00
30P5014>2`0510001`<001LD4@071P803`/8014?2`0>3@T02`X600d>200200`=1`0B00d>200;30H0
1PL100l@2P0;30H03@h801DF400:2`D04Q4<00`;1P0920<05QD@00d<1`0H5a803Pd800`;1P0F5A00
2`X50P081`800`0=30L03Pd8014@2`0200h=200F00L60@0@3`X07A`G00T80`0?3PT04a8=00H5000<
2`H03Pd800P70P0?3PT02`X5018A300?3PT030/600X9100;2PD030/600d<1`0;2PD03`h9010?2P80
3`h900/040l:00d<1`0?3PT040l:00l>2@0=30L03@`800l>2P0<2`L020L300X91@02014@30803Pd9
00T02`X600h=2@0>3@T030/7010?2`0C4Ph040l;00`;1`0=30P00P0>3@T01P0F5A403`h;01TH5001
00009B@P00h=20804Q4<01H03`h902<T7P20PG/0oooj0<G8`@0Z;BH05aXC00hA2P0E51804a8@010?
3@0>3@/03`h<018A3`0>3@/03`h<010>300A3@`04Pd:01<=3@0A3@`040l=0P0A40h2010?3@0600l>
300L6aT02`/900L610061P@04A4?0P0>3@/0600=30X02`X800d<2P0B4@l03@`:014@3P0C4Q006QTG
010?3@0D4a404a@?00l?300=3@/03Ph>00l?400>3Q00410B00d=3P0:2PX03Ph<014B3P0>3@T04`X=
01@:3@8050/>00<050d?01@>400?2@/00P0A3@h01P0>30d04A0@01HF5P0?3P`03Pd9014@30<04Q4=
00L03Pd901<B3P0>3@T04A0<01HE4@0:2@L040l=00803@/<02P04Q0A010>3`0>30d03`d>01<A4P0>
30d03@/<014?400?3P`03@h:00d=2`0?40/03`l<00h>300@4@`030`901@D4P0C50l051DA014A3`0:
2PP030`:00h>300B4Q005QPE01TK600J71T030l<01PJ5`0?51003A8>01HK5`0:3`T04A8=01<D3`0A
4P`03Pl9014B3@0D5@l04a@>0P0C50l00`0C50h04a@?01<E400201<E4P04018D4@0A4a004A<@014C
40<04Q@A020051HC01PJ5`0K7AX04A<>01@F4`0D5Q803a4<01LI5P0D5Q806Q`G01XL6@0H6QH04aD@
01PJ5`0V;2P06R0L01@J5P0<4Ph051XF01TO6`0=4`l0B4i:02L]:`0J81h06AlM01@J5`0C71L031D@
01DN6@0H8A`03AHC010I5P804a`K01`04a/L018J700A6A/04ATL01LN9P0B6b804a`P01@M700?6QH0
4A/E020Z8@0Y=BT06B@I01PR6@0H8a/06R@L00/G3@0/>2h05B0H024/9P0E81X06bHR01<M700K9B@0
92h_02<];`0K9BL04adN0P0H928201TU8`0b01PU9@0G9BD072X[01XX:@0U=3L08S4d02@c=P0S<SD0
7Bl_01h`;`0P<c408cHb028e<@0O<Rh08cHd02Hh=`0U=cT08cDi024b>P0P<cX09ca101he>@0/@D@0
9CPl02Xn@01UNGX0D69R02ho?`0/?3/0:CTh03E4@@0R;bP0:3@Y02Xf:P0Y=BT0930T020Z8@0O:B00
7B@L024X800N9Ad06b0J020U7`0T:b@06RHP01dZ8`0P;BH08c0Y02Tf;`0/>C8202dj<`0802Tf;`0V
<b`0;CXc03A1>P0[>2l0>TLn03E2>@0]>S4202hk=004034n=`0d@3`0=40l034m>@80;c/g05L0=D0i
03@m>00Z=Bd0?DQ004=@B@0_?CL0>TU603Q8A`0^?Sl0<3m403A5C00b@d/0@55I0311B`0a@TX0=DI>
02Pi@@0jBU40;ci502hmA00iB4l0=4=:030mA@0c@4P0:SLo0350A`0iAe00<3i702Le@00hAU00?4YC
03M8D00b@dT0;T1402do@@0Z>cl09CLk02dl@@0`?d@082lb028`<`0[=SP0:3@d02D`;`0S;B`09Bh]
02H_;P0W;Bd0>Clo03Hk>017CTH0TIV>0>[`iP17Cd80=Cdb02L^9@0X;RX092XX01hT900Q9BH07b<R
01/O7`0O8b@08bLV01`P800G6a`0720O01dQ8@0L82407b<R01lS8`0O9200724K01`Q700L8Ad061dG
01PM600C61@06QlJ02<X8P0Y;RX04aPC01XO6`0H6QT07b0R00`=3`0U9RP00P0H6A/0200Y:R`071dO
01lP8P0O82807QlQ00h?4`0H6Ah06AXO0P0K7240600H6Ah04a@H01<D600G61`07AhS01dM9@0L72@0
8b<[05QKH00H72803Q<I01dT:P0@62005QlV01XS:P0T;C407RHY010E5`0G6a`03a0B01<C5`0C4QP0
4a8G01<B60804Q4F0P0F5AX08P0C4QL051<H01@C600B4Q@05aLG0000000<30`05ADE01TI6@0A4A40
51@D010@400B4Q803Ph>00X:2P0M7Ad0410@00`<300H61P03Ph>01hL7@0@3Pl04Q0A01@@4@0C3a00
6ADF01PD5@0B3Pl06ADF01DA4P0@30d04@d>00l;300B3Pl6014=3P0M01DA4P0F4Q<03PX;00l;300D
41404@d>01HB4`1jMWL0;b//01TE5P0>2P/0<2`^01PC5`0@2`l03@P<01@?4`0<1`/01`8601XE6@0H
4aL0KVU]05mJGP0=20`04@/>00P2100I4aD09R0R00`6200>2@X00P0;1@L02P0?2@/03@L900P2100<
1PP03@<401H<3@0=0`@04PP900l51P0C2@X601061`803@<40P0?1@H00`0>10D03@<400l51P0500l5
1P0501462P0?10P03P<700l4200@1@T00P0?10P04@0A1PX040D901T>4P0T6Ad07Q<G00`11@0:0@<0
3@8601T>4P0A1PX040D901462P1lLGD05``@00L0000H3A403P<701Cooooo000Kooooo`0V010<2@0A
3P/040l;010<2@0@3@X040l;018>2`0=2PL040l;01DA3P0C4@d051<?010A300;30L03@h901DF4@0>
3`/0HV=N06Y[IP0C50l020T401<D3`031000;Rh/01lO7P071`L02PX:00h>3P0=3@d04A4A01@D500I
6AT0000001DE5@0D51@030`<00d=2`0C4a42018B400300h>30071`D03Ph<00L03Ph<04803@l<00h?
300=3``03@l<010B3`0=3``01@L401<E4P0A4a003a4?00d?3P0A4a804aDD00D71P0620L03a4@00T;
2P0:30/0418A00`>3@0=3`h03Q0<00T;1P0<3PT04Q@?01DG4P0L7Q/061XG01/M6P0=3`h06Q`K0001
000L7Qd05aPD00T:100>3`X02P/601DF400;30L030d701/L5P0R8ah04A8<00d>200C50l04A4=00d<
200<2PL03`/:00l>2P0A3P`04@d<00L60P0H5Q<040`;01lN6P0F4a803@d?00X93P0F5AX03Ph@00L7
2@0>3Q004Q8D01<C5@0:2P`2018A5P0T00d<400>3Ph0/k>a05QHEP0C4a405QHD00X:200A4@l0410>
00h>300=3@/03Ph<014A3`0=3PT03a0;00d>2@0<3@P04a@?018C3P0A4Pd03@h901HG4P0?40/03Pl:
01<D3`0D51803@d;00`<2P0>3@/03@d;010@3P0:2@L02`X800h>300B4@l04A0>0P0=30P02@0>3@T0
3`h:00l>2P0>3@T03@`8018A3@0>3@T03@`800h=2@02010?2`0600/:1@0?3PT03@`700h=200B4@`0
40l:0`0=30L01@0:2@@04Q4<01dL5`0B4@`030/600803@`700<03`h901@C3P0=30L00P0=30L01@0?
3PT040l:010?2P0?3PX03@`8008030/70P0=30P01`0@3`/03`h:00L60P0=30P040l;00d<200?3PT0
0P0@3`X02P0?3PT030/600/:1@0920<04Q4<01LF4@0>3@P02`X5010?2`0?3PX200`;1`0?00l>2P0>
3@T02`X600d<200@3`/03`h:00d<200>3@T03`h:010?2`0B4@d03`h:00`;1`0>3@T040l;00D03`h:
01d03Pd900l@2P0A4P`0414;01@E3`0N7aT0ADI00=KGd@27R8805aPB01@E3`0C50h040`;014=300B
3`h04a4B00D51@0:2PX06aXH014@3P0>2@H06@l>01/@3P0G2PX06A<C014=300C4Q00:2LU02TX9P02
010@3P0?00T91`0:2`P05aLE014C400<3P/0000001XJ600:2PP05ADC01lO7@0<30/04Q8@010@3P0>
3P`03`l=00804A4?00H051<?010?2`0>3@T03`h<010?3@0?3P`200h=2`0D00l>300>3@T03Pd900d<
200@30d030P901TE5P0<20T04@d>01/G600>2P/04Q0A010>3`0I5aP03P`=018@4@0F5A<051<A014@
3P0@3`d2014@3P1B00l>300;2PP020L501@C4@0@3`d03`h<00L6100;2PP040l=018A3`0?3P`03Pd;
018A3`0A40h040l=00l>300=30X030/9010@3P0;2`/030`:00l?3P0?3`l03@d;00`<2`0?3`l03Ph<
00d=300?3`l04A4?00l@300=3PT03a0;01TJ5@0H6A@0414<018C3P0D5A0030h901DG4P0K7AP051HA
00lA300B51403Q0;00h@300?4@h03a4=014C3P0A4a00418>00lA300B51404aDC01/O7P093@`03Q8A
00lC4P0D61L0310?010D4`0D61L03A4@00`@3`0@51<04QHC01<H4@0D6A<04QLA00lD3@0?50h041D?
00lD3@0A5Q004QL@00dB2`0@5@l04QL@014F3`0C61404AH?00lD3@804AH@01h05AXD01TN6P0L8Ad0
4QLC00lD3`0G7QH05QhC01@K4`0C6Q<04QPD01<I600?51L04aPL01@I800G6bH06alZ01LK9`0@5200
41LQ01DK900G72005alQ01`S8P1:D4`0_lW104A<A00P9al07bTP01XR6P0P:R4201/U700<01LQ6@0R
;2@04AXE01<L6@0B6aP07BHU01dU9`0H82806bDW01LS8`0J9RH06bLW0P0J9RH0100K9bL07b/[020/
;00P;Rh2028`<00P020^;P0S<c<08C4`028b<@0U=C808c@_01h_:@0S<c007bl^02@d=00U=3L08S4g
02Df?P0T>4<0:d5<02HmA@0W>d80Bf1V055TJ016FU/09CTg01T/:P0Z?CT093D_01LX800Y>2h09C8X
02Hc:@0R;bD082/S02D`:00i@c/201hU7P0;02L/9P0V:2<08RLQ02La;@2>VID0;3Lc02dh=00/=c<0
;cXf02/f<P0]>3@00P0Y=300100[=S80:CH_02/j<00Y>34202Lf;`1K02`k=P0`?cX0<D0k02hm>P0]
?3T0;Sdj02`k>00]>CL0=D4l03@o>`0b?cP0>4Dn03<o>`0Y=C80;3Pf02lm?@0c@D40<T11034o@P0_
?4<0;ca40390B@0c@TT0=4=:03E3C00hATl0=49;02Hg?`0hBE80=DI@0390B`0W>440;d9902Lh@00i
BU@0;Sm903E6D01WN880>daF03U7DP0b@4T0;C]403Y8D@0]?DD0;3m502/l@`0Y>Ch0:3Ll02hl?`0R
;Bl09c4b02/d<P0V;2X08RPV02@Y9`0R9RL0:2`]03Hj=`0]<R`0LWM`0:fcZ@0g?C<0;38X028Y8@0Q
9b<07bDS028X:00S9bH07R<O01`P7P0H71/08bPT01`Q7P0M8B007R<O01dR7`0E6AP03Q<?01/O7@0Q
8b807R0M01/M6`0K7A`06adJ01HH5P0K7A`071hL01`N6`0L7Qd071hL01dO7P0201`M7`<06a`N00P0
6Q/M01`M7`0H6A/07b0R01<D5P0A4Q@051DG01@C608061LL00/05aHK01TH7@0N7B806aXP01TH7`0H
5al06APP01LF7P0B4QX05APM01DJ7P02010E6@0N01HK8@0E6R0051LN01LJ7`0C5Q/03PlD010A5@0E
5Q/05QLL00X:4P0D5AX05QHM01<B600>3A<04A0E01@B5`0>31406aTL00h<3`0E4aH0518C00@20`0D
4Q<07Q`M04e;C01?CDh03`d>010>3`0A3a004Q0A0P0C4A801P0K6A`0BDM:00/9300<2Pd071XM00/9
30D040hA00@050lB01LC500G4a@04Ph?0`0A3@h2018>3`04010<3@0>2P/03@T:01@@4@803@T:00X0
4@d>00d92P0K5aP01P8301@@4@0C3a004Ph?00`82@0D41403PT;0P0?2@/01P0@2P`03`T;00l92`0?
2@/03PP:010:30806A<E03d040X<00d72@0@2P`03PP:010:300A2`d03PP:014;3@0:10H03PP:00@0
000K5AL030L800l4200C20`040D900d21P0B1`/04@H:00X00`0=0PH04@H:00X00`0G31003P<70105
2@0B1`/04`P<00l4200=0PH03P<700l4200<0@D040D904Hk?`1<@DD09Q/O01@8300900405@T=0145
2@0=0PD04PH:00h21P0@10P04@D901<72`0E2@d05PX>01X?4`0<0`D04`P<03<X;01EBTh030450146
2P0U6Qh06@hB00`11@0@1@T05@X>01Cooooo000Kooooo`0J00l<2@0B40`04a4=014?2`0@3PX04@l;
01LD4@0A3`/040h:00h<200=2PL040l;00P9100@4@`02@X501@E400<3@P08R<N01DF4@0B4`h03a0;
00/<1`0@4@`0=CHa01dM7@0<30`300h>3P0901@D500J6QX04a<C010@400G5aL0<c<c010@400=3@/0
2`/900803Ph<00<03@d;010@3P0>3P`01@0>3P`600d?301600/=2P082PL051HC01@E4`072@H061XH
00d?3P082PT04A<B00`>3@0:30/03@l>00X<2`0;3@`03a4@00/=300:30/03a4=00lB2`0?4@`0418=
00d?2P0@4Pl051HC00P:200U9bH0KFm^010B4@0<3Pd0418>00/<1P0E5Q003@h8014B300:2`H04a@>
01XK5P0J6aD03Pl:00l@2P0A4P`07AdI02HS8@0E4a003@/800l<2P0D4@l061DC00`91`0H5Q<03`d:
01LD4P0@3P`02PX<00l?4P0:2Pd0410C018A5@0J6Ad061PK00`;3`0B4QD03PhA00/:3P0B4QD09bLW
01`L6`0U9B<01`L6018B40L03`l=01002``700l@2`0@4@`03a0;018C3P0=3PT04a@?00T:1P082@@0
4Q<>00/<1`0C50l0410>00`<2P0?3`d0410>0`0=3@/01`0>3P`0410>018B400A4@l03@d;00/:1P0<
2`L00P0=30P05P0<2`L02`X6014@2`0>3@P030/600d<1`0>3@P030/700X9100>3@P030/600h=200D
4`h04A0;00l>2@0>3@P040l:00l>2@0F5A0081lJ018A300>3@P200l>2@0D010?2P0D4`h030/600l>
2@0A40/040l:00d<1`0<2`H03`h:014@300B4@d04A0<00h=2@0<2`L03`h:00d<2P0C4Ph030/800l>
2P0920@700h=208051<>01H0QhJ1030_:P0>3@P03`h:00d<200>3@T03`h:00h=2@0<2`L03Pd9010?
2`0?3PX03@`800h=2@0?3PX040l;014@300?3PX03Pd900l>2P0@3`/03`h:0`0>3@T0100?3PX03`l:
00l@2P0>3`T200d>200b014B300F5a40;RlY01dN600E5Q801@H101DE4@0D4@d04a0<00l=2P0D5A40
3Ph;018D400:2PL03`h:01<?2P0G3@T07A0<01hA3`0F3`d04Ph=014@3P0E518051<A00d=2`0:2PP0
4a<A00d?300:2`T0;Bl/03]0?00F5Q@02`/901TI5`0:2PP05ADC01HF500@40h04Q8@01HF500D5180
4Q8@014A3`0C4Ph040l;00h=2@0?3PX040l;00l>2P0>3@T200l>2P<040l;01<03`d>010>3`0=2``0
2`T:00d;300A3a003@/<01@B4`0_;Bh0clg>040n?`0@3Pl040l=018A3`0C4Q004Q4?00l>300<2`T0
3@`:00804a8@00L04A0>01@C4@0B4@l071/I014@3P0;2PP03`h<00804A0>00T03`h<00h=2`0>3@/0
3Pd;00d<2P0<2`T0410@00d=3@0>3Ph00P0@41003@0?3`l03@d=00l?3`0?3`l03Ph>00l?3`0A4@l0
4Q8?014B3@0B4`h04A8=00d>2@0<3@P00P0A4Pd02@0<3@P04Q<>01LH4`0@4@`04A<@018D4@0>40d0
3a4>01@F4`02018D4@0D01@F4`0C5A804Q@A01@F4`0D5aD05ATI01<G5`0G6a/05ATI00dA4@0A5AD0
4aLG01@H600?4a<04ADE01DI6@0A5Q8041D>01<H4P0D6A82018G4008014F3`0?50d04AH@01@I4P0?
50d041D>01<G3`0C5Pd201DH3`0]01@G3`0F6A805aTC01PJ5@0E5a806Q`I01<E4P0@50l051TA02Xb
9`1FGE@06B0I00lE4@0B61L04aPK01DJ7P0D624051PR01HJ9P0B5B804aLS01@H8P0E6B805AXP01LL
800L8R<0LgUi0;Fk^@17CDP07B@M01LO5@0M91d08R`S01<M500F81T04adF01TS700C71P07RLT020Y
9P0F7ah072@U01/S900N:2X06B@V00806RHX04006BDW01/X:@0N:b/07b`/01h[:`0M:RX07R/Z024^
;@0R<3008c<c02Ph>00_?ch0<40m02Ti=@0N;bT0830]020`;P0W=cH0:STl02/j?`0]?TH0AEUU0316
D`0S>D@08SHo0396C@0^@dH0<TE902Tm?00V>SH08SDa02Pl=00M<BP093@[02@a:@0X=Bd09c@/02Td
;@0/=c00;SPa02L]:00U;2H09BXU02HZ9@0Y;b/09S0]059MF@0X<bl0;3Lc02/f<P0c?SX0<C`h02lj
=P0]>3@0<C`h038m>@0]>S<0<d8i0350>@0_?SL0;C`e02hm>00a@3/0;Sdh0`0_?S/01`0X=SH093<`
02lk>00a?CT0=40l03M3?`0a?C/00P0[=cD0AP0Y=CD0;SXj030l?00/=cT0;STn03E0A`0e@TX0<d18
030mA@0^?4D0<3i702Tg@00lCEL0;d1;0311C00^?dX0:Sa80396D00[?DX0<dE@02doBP0^?dT0BU]U
02`mA`0`?TP0<T1:0350B00kB580;Si602Dh?`0U=ch0<T9802`k@00W=CL09S0a02Tc<P0Z<c409R`X
02DZ9P0Z;bX0;c4c02/];`0_<S0092TU02`a:P0m@cX0:2hT02@Z800a>340>3hl02T_;@0T:RX09RXY
01PM6@0Q9R808RLS020U8@0Q9R805a`H028W8`0O92007R<O02`a;@0h?CT07b4P01dO7P0L7Qd07AlN
01hP7`0K7A`201dO7P<071hM00@06adL01`M7`0K71h06a`N0P0J6ad02P0I6Q`07QlQ01`M7`0B4aD0
6Q/M01`M7`0J6ad06ATK01/K7@0J6Q`201PG700O01XI7P0M728071/Q01/J8@0M72@071/S01PH800E
61d05a/O01@I700G6Qh07b8V020R9P0I6Ah071`Q01TI7P0F51X061HL01/J800D5Qd05aLO01TI8@0?
3aH07ahT010?5@0G5Q/071XO018@5@0D4QD06A@H01LB5P0201PF5`0402PV9`0K6AX07adN014?4080
4Q0A0P0A3a02010>3`0601<A500h=ST0518E00`;3@0E4aH04a4D1@0A3a800`0@3@l040`=014=3P03
018>3`0<014=3P0@30d04Ph?01<?400B3Pl040`=00`82@0A3@h06ADF00d92P0D41402`L80P0>2P/0
1@0?30`04@d>02HS8`1VHV<04Pd=00803`T900X040X:00l92@0?2@T040X:014;2`0?2@T03@L700h8
200A2`/04P`=0P0>20X2010:300W00h82P0E3a401000010:300=1`T040X<00d72@0@1@T04PL;0146
2P0?10P04PL;01462P0F2`l02`0400l4200P5AT0<RL[01H;3`0A1PX04`P<01@93@0A1PX03`@80105
2@0C20`03`@801472P0F2`l07Q<G028H6`14>3`07Q<F00/20`0A1PT050P<00X00P0?0`L040@80080
4@D90P0C1`/0300:00<05@X>00`31@0800405@`>01872`0:00<04PL;00d31P0=0PH050T=01052ACo
oooo000Kooooo`0600T8100=30P03`h:00d<200<2`L02`X60P0>3@T02@0B4@d04A0<014@300G5Q80
3a0;01<D3`0720<04a@?01@E400200l@2`0G00X;1P0720<05QLB00X;1P061`802`/;00T92@0=3@d0
4A4A01TI6@0R8R80BDU900h>3P0820P02@T902DU9@010@403@d;00l?3@0M7A/05aLE00/;2@0@40h0
1P0>3P`600d?300:01HH5@0C5A805QPE00/=2P0Q8b00ADM502DW9P0B51<03@l>00h@3`803a4@01`0
3@l>00lA400A4a803a4@00d?3P0?4@d03A0900`>2@0>40/02`d800d?300@4Pl020X700T;2P0B51<0
2@/:01hP7`0=3Pd02``7018B400A4Ph06AXE00`<2P092PH02@X500X:20092PH03a0;0P0A4@l0200A
40h03Pd;00h=2`0>3@/03@`:00l>30030P003Pd;0P0<2`T03`0@3`d03Ph@014A4`092@/03@d?01<C
5@2XZ:X0DE5C01XJ700?3a4030`>00l?4@0A4A8092@T00l?3@0201<C4@0403Ph=P0>3P`03@d;00h>
3080410>00<03`l=00h>300<3@P00P0@4@`02`0>3`X0414<00/<1`0<3@P051D@010A30092PD06Q/H
09nPV`0J6QP03`l=00<02`/900T03`l=00d=2`0<30X03@d;00h>300<30X020T400d<1`0>3@P00P0?
3PT0100>3@P03@`7014@2`0>3@P300d<1`0<00/:1@0?3PT04Q4<00d<1`0<2`H03Pd800/:1@0@3`X0
3@`700`;1P071P801`H10P0=30L01P0:2@@02`X500/:1@0;2PD03`h900h=20803`h900d03Pd800/:
1@0:2@@03@`800h=2@0?3PX03Pd900/:1P0:2@D010<101DD40081`<030/800803`h:01003Pd800`;
1P0<2`H03Pd8010?2P0A40/02PT60040000_;RT0j>OR06]ZI@0D4`l03@`800h=2@0@3`/03`h:0P0=
30P300h=2@0400d<200>3@T03`h:00h=2@<03`h:0P0@3`/0200>3@T03@`800`;1`0=30P03Pd9010@
2`0@4@/03Pl90P0?40X05P0>3`T02P/500l@2P0E5Q002``60493?@1BDdd04Q8:01DE3@0>3`L04Q<;
010C2P0G6Q405aP@01@F2`0=2`<06a@<02PO600H3PP03PT6010<2`0@3`d200h=2`0M01<C4@0E5A<0
2PX800h@3@041P<06A/H02`a;@0I6AL0:RXX014A3`0G5aD05ADC014A3`0?3`d051@B01PH5P0B4Q00
3Ph<010@3P0B4@d03`h:00h=2@0?3PX040l;00d<200A40`040l;00h=2@0=30P00P0<2`L03P0=2``0
5aDF00h<3@0I5aP04Q0A00/92P0<2P/0518C01dK7011?d0071XK018@4@0?3P`04A0>0P0B4@l03P0?
3P`030/901HE4`0E51806APF00D40P0?3P`02@P6010?3@0=30X02`X800d<2P0<2`T02PT70`0@3`d3
014@3P04014A4@0?3`l03`l?010@40804A4A00`03Ph>010@400@41003Ph>00l?3`0@40h03`l<018C
3P0E5Q404A8=010A300C50l2010A300400`=200@4@`04Q<>00`=20804aDB00L03Q0=014C400H6QL0
51HC014C400D5Q<05ALD00804aDB03005QTF00lD400G6aX07R<P01PM6@062PT04QHD01@I5@0I7A`0
4QHD010E4@0C5aH04AHA010E3`0D6A<05AXD018G4@0A5Q0041D?00hC3@0@5@l05AXD014F400?50h0
4QH?01@G3P0E60l05QTA01LJ4`0H6a@061XD01HH4`0B50l071hK01LI5P0C5Q803a@=04eEBP22RH40
7RDN01/R6`0B61D04ALG01<H6`0B5a/04aPN01LL8P0D624201HK8@0H01HK7`0E6Qh061dP020U9`0<
4Q80:S0^01LM6P0L8Qh05A/G01TQ700F7aX07bPS020Y9@0>5a@06R<P01LP7@1NIf@0FV=P02D^;@0M
9RD06R<Q01hX9`0J9RH06BLX0P0H9RL00`0L:R/08S0`01d[:`0301h/;00N020^;P0R<3008S8b02Ti
>@0`@3l0<D4n02Ph=00O<2X07Rh[024a;`0V=SD0:CPk02Xi?P0Y>T80JGf803Q>F@0S>T807c<l02Xo
A@0aATT0>Ti?02Xm?00mD4`0<4<o03Q<A00_@3P08c8[02Db:`0V<b`0934Z0P0S;RP04`0T;BP0:S0/
02X`;00X;BT0:Rl[02dc;`0Y<c008bhZ02/f<P0^>CD0<chj03@o>`0e@3`0;cXf02dh=00c?SX0<Sdi
02Xg<00/?3<00`0_?SL02P0a@3/0<T4l02`k=P0]?3T0;chk030o?00[>CT0:3Ld02Xf<`0`?3P203Q4
@00X034m>`0_>cT0;SXh02Pd=00Y=CD0<3`l03E0@P0b?D40<Se303A1B@0e@TX0<3e502`j@`0b@4T0
;Sa502m0BP17F680PY>M03e>F00]?d`0<dID03=5D`0bA580>4YF03I7D@0mCUP0=TM?03Q6C`0fAD`0
<T5603E2B00[>d408S<j02Df?@0gB4`0;Se002Xf>00X<S<0:38a02L`;@809B/W01D0;34]02HZ:`0Z
;Rl09b`Y02ld<00P9Al0:RlW02/a9`0S:240<3L`03@j>00U:bT0;38a02@X9`0J7a/07b@P01`Q7@0M
8Qh082DQ01XO6`0Q9R800P0H7AT00`0U:RH09R/W01hP7`0501hP7`0301lQ800N81l07AlN00806adL
00<06A/J01XK7@0J6ad00P0I6Q`201PI6`0:01dN800H6A/07AhP01LH6P0=3Q007QlQ01@D5P0F5QP0
61PJ01PG70806QTN02@05aHL01DD6P0D4aT05QDM01LF7P0E51X04Q<G01<G6P0?4aH041@G01LH700E
5QX051<H01LF6`0F5AX05A<H01LE6P0H5a`03a4G01XJ8P0G5al06a`Q00/:400T8bT06QTN018@5@0K
6Ah03P`?01hI7@0G4QH02`T:00h<3@0I5aP04@l@018@4@081PL2018@4@804@l@0P0@3Pl201<A5004
00D31P0A3a80518E00800`D04@lB00T04PlA00l;300?2``04`l@010<3@0?2``04@d>010<3@0>2P/0
0`0?2``03@0A3@h04Ph?01<?400?2``0:RHW00<0000S7b0030P900<0000B3`l07ATJ04Q4A@0<1`P0
0P0?2@T02P0@2PX03`T900l92@0C3@d05a4A01H@400A2`/02`D500T30`0;1@H200d72@0:00h82P0?
2@/03PP:014;3@0>20X04@/=00T31@0=1`T04P`>01462P804PL;00P04@H:01872`0B1`/03P<700d2
1P0E2Ph04`P<01`A5@804@H:00<04PL;01@93@0A1PX00P0@1@T0300?10P01`0001D:3P0E2Ph05``@
00P00@0:00802`0301/?4`0>0PH02`4301<72`H03`<700H04@H:00h51`0700007a@H01<8300=0PH2
00l4200400/0100>0`L04PL;00X00aCooooo000Kooooo`0400d<200A40`04Q4=010?2`803`h:0P0@
3`/01@0D4`l04Q4=00`;1`0=30P03Pl:00802P/600D04A8=00d>2@0C50l030d800h?2P0201<D3`03
00l@2`0H6A@03`l?00803Ph>00l03@d=010@400E5AD06ATI01<C4`0A4A402PX:00d=3@0B4Q804A4?
018B400O7ad05QHD00X:200?3`d01P0>3P`600d?300:00/=2P031@8010H300/=2P072@H07b4O02<U
900F61L03a4@00h@3`80418A00<03@l>00h@3`0?4A000P0?4A006`0>40`02`h700/=200@4Pd03Q0;
00h@3@0:30T05aTF00P:2@0G6AP02P`;0001000>3`l051@B02XZ:P0F5QD030`:00h>3P0F5QD03`l=
018B4P0?3`h03Ph<00h>3P0;2PP02PT700l>300201@C4@0K00l>300C4Q0030/900h=2`0920H01`H4
00`;2@0D51H05ADG00/;3@092@/020P:09FEU`1?Ce4061PJ00d=3`0;2`d03@d?00l?40030`<04Q8@
00l?3@0b<S00K6aZ018B400<30X03@d;00803`l=00L03Ph<00d=2`0>3`X0414<00d>2@0;30L03a0;
00803@h900L01@H300/<1`0S91l020T601@E400F5Q@03`l=0080410>00X03Ph<010@3P0>3P`03@d;
00`<2P0=3@/02`/900P9100=30L03Ph60P0?3`L05`0>3PH03@d5014A2@0?3`L03Ph6010@200?3`L0
30`400l>2@0B4@`03@`700`;1P0>3@P02PT400d<1`0<2`H03`h900h=200?3PT051<>00d<1`0920<0
30/600802`X500<03Pd8010?2P0=30L00P0;2PD0100<2`H03@`700l>2P0=30P400`;1`0700`;200[
:RH05QDA03/j=P0H5a<00@0000h=200200`;1P0>00h=200@3`X04A0;014@2`0O7QT01`H203Lf<@0C
4Pd02@P400d<200?3PX040l;00h=2@0=30P200l>2P803@`81@0>3@T02P0?3PX040l;010?2`0@3`/0
3`h:00d<200<2`L03@`800l>2P0?3`X200d>200J010A2`0B4`d04A8<014B300?40X0414;00/<1P0H
6A<05AHA00/<100N81D02`d600T;000L7a@02`l50085000@4PD06Q/A01XG3P0J5Pd04P/400l:1`0?
2`X040l=014@3P0B4@l2018B400B00X:200E5a@061XG01dO700Q9R804a<A024Q7`0D51806ATG00L7
1@0K6aT0410>01<C4@0D51803@d;00X:200?3`d04A0<0P0?3PX00`0@3`/03`h:00`;1`02010?2`80
3`h:00L04A0<018A3@0=2``04a4B00X82@0E4a@040h?00803`d>00L02@L801@B4`0100006ALH00P6
1`0B4@l04A0>00@040l=00T05A@B00/:200D4a402`X8038a;`0G5Q@03@`:010?3@0?3P`00P0=30X0
100>3@/03@`:00d<2P0=30X300h=2`0E014A4@0@4100410@00l?3`0@41004A4A00l?3`0A4A40410@
00h>3P0?3`l0410>014A3P0B4`h0414<00h?2P0:2`H020T4018C3P0A4Pd03a0;00804A8=00P03@h9
01<E4P0D5Q<03a4>014C400H6QL04aDB010B3`804aDB0P0A4a004@0C5Q<051TC00hC3`093PT051TC
00hC3`0D6A@08RLQ02X_:`0K81/03A8<00hC3`0@5@l04aPB01DJ500D6A<04AH@008041D?01d03A8<
00lD3P0F6aD04QLA00lD3P0C5a0051L>01DH4@0G6Q<061/D01PJ5@0F61<05ALB01@F4`0P8Ql071hK
01DI5P0M8Q`04QTA02H]9P0L8a`05ahG01`R7`0B61H04aTI014G5`0A5QT05AXM018G6P0301@L7P03
01DM7`0I8R408BXY00808b`[01806b@R01dV8`0E7Q/06R<P01PQ7P0S;RX0:S@b01/U900F8Ad06B@P
04aGD`1;EU807RTU01`W8`0L9b808B`X01/W9`0J:2P201TW9`0601h/;00S<C406bTY024_;`0T<S80
8c4a0P0R<3008@0L;2`0830`02@d<`0S<c00830/01d^:00Y>CH0;3`j02hn?@0_?T40;ci302Xk@`0j
C5H093Q302/oB00X?4D0:Si402i1A@2>XZ<0>De;03Y=B@0mD4`0=dU301DV800Y=c00:cPa02Xg<00X
=Bh09C0Z028]9`0R:bH09RlZ02Pa;00202dc;`0?02Xc;P0^>CD09S8^034m>@0b?SX0>DE1038n>P0l
B4@0=D4m034m>@0f@Sh0<clk02/h<@0^?SD0<D0i0080<T4j00@0=4<n03I5@00c@Sd0<3ll0P0_?S/0
B@0/>SX0:STf02<_;00Z=S80<Shj034m>@0/>3H0:SHd02Pd<P0U<C409S8b03A0@016DE<0@4]?038m
@`0gA4X0>DI=034nAP0[>T407bde01h/=@0]?TH0;d1905IWL@0R<cd0;3e;0395E00gB5P0<dEC03e?
F`0nCeT0<45:02hoA`0^?D@0;Se20350@`0d@TD0:cTm020_=00S<SL0;ce202Dc=P0[=SP0:38c02H`
;`0T;BX08bTU02D[9`0[<2`08RHW038f=`0U:RL09R/W01/P6P0T:B80:c0Y020U7P0U:R@09BTX01XN
7@0W:b/09BTX02<X900L8Ad041DA01`Q7@0J7a/07b@P01`Q7@0H7AT06QlK01PM6@0E6QH00`0P8R40
1P0N81l07AlN01dO7P0O8B007R0O01dO7P806adL00<06A/J01XK7@0J6ad00P0I6Q`201PI6`0D01HG
6@0E5QP0824S01<D5P0T9BL05aPJ018B4P0D51D05QHH01PH6P0I61`061LL01XI7P0G5Q`05QDK01PG
7@0I61l06APN01@E6@0G61X201<D5P0501PH6P0F5QP04a4D01DC5P0F51L00P0G4QH04`0F51T09BL]
00d>4`0@4AH051DJ00P7300E51T092<X010>4@0U8bH040hA01LC500B3Pl06ALH01@B4`0F51D04Q0A
01HD5@0C4A800P0@3Pl02P0A3a004Q0A018@4@0B4140518E01dK7P0=2`h03P`?02<Q900F51L500d;
3P0400l<3P0:1PL02@D6014=3P8040`=01<05a<D01DA4P0?2``03@T:00l;300@30d03`/<00/7200A
3@h02PH7020L7@0N6Q/0MW9c00X61`0C3a006aLH00<0000G4a@04@`<00803`T900X040X:00l92@0?
2@T08Q`L02XT900I4a<030H600/51@0<1PH03@L8100>20X02`0?2@/0100001D?4@0:10H01P0200d7
2@0>20X03P<700d21P0?10P040D900803P<701<03@8600h31`0E2Ph02@0200h31`0?10P040D90146
2P0C20`04@H:00l4200A1PX0714E00P00@0?10P03P<701D:3P0>0`L06PlC008040D900<01`0000h4
1`0B1`/00`0>0`L300d21P0<00l4200B1`/0304501hC5`0800403`@801052@0B1`/03`@800d21P0>
0`L030455?ooool001_ooooo01403Ph900l?2P0>3PT030`800d=2@0@40`04A4=00/;1P0?3`/04a<>
010@300>3PT03a0;00/<1`0H6A@04a@?00X;1P02010A300700/<200A4Pd03a0;00`=200A4Pd03`l=
00l?3P0200h>3@0900d=300>3Pd03Ph=00/;2P0:2PT05QHE00H61@0C4a8051@B00803Ph<00<030`:
00/;2@0@40h01P0>3P`600d?300900h@3P0B51402P`900h@3@0<3P/02`d;00`>300?4@l0418@00<0
3a4?00<04Q@B010B400<3P`00P0>40h05@0?4@d03A0900`>2@0A4`h03Q0;00d?300>40d020X7014C
4P092`X030h=01LI600>3`l030`=01LH6@0>3Pl0410A00X;300A4Q<03@h?00h>3`0200h?400S00l@
4@0B4Q404A0?00l?3P0@3`h03`l>00`<2`0:2@P04A0?00d=300<30/04Q8A01hM7@0;2`/04Q8C00h>
3`0C4a@04A4B01@D5@0E5AH02@T:00l?400;2``01`L800h>3`0A4@l03Ph<01@D4P0;2`X0:2PV018B
400>3P`03@d;00h>300=3@/00P0>3P`05@0<3@P03a0;00`=200:2`H0414<00l@2`061`<05QLB00D6
0`082@@03a0;010A3P0:2PP02`/901DE4`0G5aD0410>00`<2P0@40h03Ph<00d=2`0200h>300300`=
200;2`@030`300803@d400D030`300/;0P0>3PD03@d400l?1P02014A200300h>1P0:2@@03Pd80080
30/601H04A0;00h=200B4@`03`h9014@2`0>3@P02PT400`;1P0?3PT03@`7010?2P0?3PT03@`7014@
2`0>3@P02`X500X9100;2PD03@`700l>2@0A40`040l;100?3PX01P0>3@T0>3Lc01`K5`0G5Q805QDA
01LF4PH03Pd80P0=30L03@0E50l03`h:018A300;2PD03Pd900l>2P0>3@T03@`800l>2P0B4@d040l;
00`;1`0=30P00`0>3@T200d<200;010?2`0B4@d04A0<018A3@0A40`03`h:00d<200?3PX04A0<00l?
2P0<3@L00`0=3PP2010A2`0C01@E3`0B4`d030d701<D3P0A4P`04Q@<00/>1P0@4PX03Q4700D8001@
ETT0=cX^028U6`0>40L04A8;01<A2`0@3@P04@d;018>3@02010?3@0E00l>300=3@/03Ph<01hN700D
5Q<06A/H01DG500;40`0410>01@D4P0B4Q005aLE04I6A015AD<03Ph<010@3P0?3`d03@d;00`<2P0>
3P`040l;00803`h:00<040l;00l>2P0;2PH00P0@3`/0400A40`04a8>01PG4`0K6QH03`h<00`:2P0C
4A404A0?00X9200B41004a8A00h=300=30/071XJ00d;2`0A3`l2014@3P<040l=00h04A0>00d<2P0G
5Q@01PD303Th=P3<blT0>3Le01<B400?3P`03@`:014@3P0@3`d03Pd;018A3`<04A0>0P0@3`d2010@
3`0300l?3P0>3Pd03`l>00804A4@00X04Q8A014A400?3`h03`l>010@3P0@4@`04A8=00/<1`0Q8Qd0
9BHQ0P0A4Pd0300@4@`04Q<>01<D3`0A4Pd03a0;01@F4`0F61D04A<@018D4@0F61D04aDB014C4080
4Q@A00L04A<@018D4@0D61<0314;01lT7@29SXP0<cPa00803Q<<00`05Q/D01hS700G71D04AH@01<H
4P0D6A<051TD01DJ5@0C61<04AHA018G4P0C61<200hC3P0E01@I500B5a804AHA01@I4P0E6A404aL@
01DI4P0G6a@05ATC01<F4P0F6AD05QTF01hQ7`0H6aT05aXI01@J5@0H7QT04aTD018H4`0D6QD05A/F
00807bHP00H06R0L01LM6@0I81/05A`G01@M6@0E7QX201HO7@0E01PQ7`0N9bH06B8R01DN7P0K92@0
8b/^020X:P0J8RD06R@U01HP8@0O:BX08R`/028/:`0J92<072LS020[9`0J9B008B`V01hY8P0O;2D0
6bXW00807B`Z00T072/Z01h];00Q<2l072/Z02@c<`0Y>3P09SDe02<b<P0U=3@00P0Q<C40KP0P<2l0
830]02@e<00Z>cD09cLd02hn?00]?C`0;Se002hm@P0V=cl0<dI>02TmA@0^@TT0:Ce402e1AP0^@T<0
;3lo02Pk>@0iBTT0;d4m02Hg<P0Y>S@08c0Z02Te<00X=2l0:3D_02Ha;00P:bH09S0/02La;00V<2/0
;CLc038i=P0/=S80<3`i03Q4@@0c?c`0=D4n03U5@P0d@3d0=d=003A0?@0`?3T0<Cdj030l>@0/>3@0
<40g030o>00^?CH0;C`e030o>P0b@C`0>dY503I5@P0c@Sl0<D0m02/i>@0X=c@0:CDb02/g<`0b?SX0
;c/g02lk>@0d@3h0<clm02`h>00T<300:SHf03U4AP0oBTd0>TE:03]8CP0iATd0<Sm602dl@`0`?dH0
<Cm7049CF`0]?TH0:S]402m0B@0dAE<0;d9C03]<GP0eAUH0?e5O04QHI@0`@DX0=4E<030oA00Z>S`0
;Cdm02`j>`0/>S`0;3Xn02/i?@0X=SP0:3Df02`g>00Z<c80:34`02@]:P0T:RL09R`Y02T^:P0T:BL0
:c0^01hS800S:2@082HP0P0W;2H01@0T:B<09BXV02DY9@0Q928082<Q00807R<O00@0724M01lT800e
>SH0;c@`0P0M8Qh02P0N8al082DQ01dR7P0M8Qh07R0O01lQ800P8R407AlN01/M700N81l201dO7P<0
71hM00@06adL01`M7`0K71h06a`N0P0J6ad05@0I6Q`06a`N020Q8`0P8B<07QlQ04i?D@0H6A/061PH
01LG600H61T06QXL01PH6`0C4aH06aXO01LF6`0E51T05QDK01LF7@0G5Q`04a@G01LG600201DE5P0H
01TH6P0F5AH05Q@F01PE5`0I5QP06QHH01TC5P0G4aL0:R`a01dN8`0K72405QLL01DD6@0A41D04a8F
01PF6@0I5aX04Q0B01DA4P0F4Q<04Q0A01<A4P0B41404a4B0P0A3a000`0@3Pl04@l@014?4003018@
4@06018@4`091`X03`d@01DC5P0Y9bX05Q@G1@0B41<02`0M6Q`06aLH01<?400E4A803`/<00d92P0H
51D06ADF018>3`0A3@h04`l@00804Ph?00`02`L8014=3P0E4A804@d>00/7200T8B40510A01LC500@
3@d0510A00T51P0@2`/200l92@0:010:2P0?2@T03`T9014;2`0?2PX03@L7014;2`0E3`l04P`<010:
2`804P`>00d03`T;00d72@0?2@/02PD601D?4@0@2P`0DD]=01/E5`0=1`T050T=01462P0E2Ph05``@
00804`P<01P05@X>00`11@0A1PX040D901P=4@0A1PX03@8600l4200A1PX040D900l4200@1@T03PD7
01052@0E2Ph040D900h31`0C20`04@P:00h51`0A1PX02`8400h41`0;0P@300h31`<03`@800T04@H:
00h51`0800406@hB00h41`0D2@d03@8601052@0?10P00P0=0PH00`0?10Soooooooooo`0Booooo`00
6oooool0400B4`h04A8=00h?2P0<3@P0414<01DF4@0W:2<051D@00h?2P0B4`h0414<00`=200C50l0
3@h900h?2P082@@2010A300300d>2@0F5a805AHA00804a@?01<020T4010@3P0@40h03`l=014A3`0>
3P`02PX800l?3@0A4@l03Ph<00`<2P0>3P`04A4?00d=2`0@40h03@d;00h>300=3@/02@T700H03Ph<
1`0=3``020072@H020X701DG500;3@X0418?018D4@0>40d02`d:0P0=3``02`0C5A807AlL01PJ5`0>
40d0418?014C400=3`X02@`500P:1@0?4@`0418=00803Q0=02H04A<@018D4`0>40l0418A00P:2@0C
5AD030d?01HG6@0<3@l03a0B00/<3P0P8B<07AhP00l@4P0>3a403a0B00`=3`0;2``03@d=014A4@0D
51@04Q8B00`<30061PH05aLG00`<30092@T05ADE020P800A4A402`/;01<C4`092@T01@D5014A4@0B
4Q804a<C00X:2P804Q8B00l03@d=00T91`0?3`d02`/901/K6@0?3`d03@d;00l?3@0>3P`030`:00/;
2@0<30X03`l=00L80`0;30L00P0>3`X02P0A4Pd030d800h?2P092PD06AXE00l@2`082@@05QLB01LG
5@0=3@/200X:200:00P81P0;2`T03@d;00X:20092@L02`/900`<2P0;30L03@d500h>10803`l500D0
3Ph400d=0`0:2P002PX100d=0`02010@1P0F00d=1@0<2`H03`h900`;1P0;2PD03Pd800/:1@0>3@P0
3@`7014@2`0B4@`03Pd800l>2@0=30L02`X500h=200=30L02`X500l>2@0:2@@02`X500`;1P<03@`7
00d030/700l>2P0@3`/03`h:00/:1P0920@03Pd90040000H5a<02`X701dL600;2PH03`h9008040l:
00H03`h900`;1P0;2PD03Pd8010?2P0<2`H200l>2@0300l>2P0>3@T03`h:008030/700H03`h:01@C
3`0@3`/02`X600`;1`0?3PX200h=2@0400`;1`0;2PH03`h:01<B3P804Q4=02004a8>010?2`0>3@T0
40l;01<B3P0B4Pd04Q<=01<D3P0<3@L020T300`=1`0C50h01PL1014B300G61803Pl900l@2P0;3@P0
51HA01<E3`0F6A804aH=01PK4`0K7QD03A0900d@2P0C5A8020X700d=3@0=30X04Ph=018A3`803Pd;
02d05QHD01PH5P0K6aT02`d;01/M6P010`0041DA00h>300I6AL0410>01PH5P0000007AdK00/;2@0<
30X03`l=018B400A4@l030`:00l>2P0>3@T03`h:010?2`0>3@T02PT501@C3`0A40`03Pd900d<200?
3PX04A0<00`;2@0C4Q00>STg02XY9`0?3P`02PT7010?3@0=30X04Q4?00L6100B4@l040l=00/:200>
3@/00P0A40h06@0>3@/02`X801/J600?3Pd0;2/Y01DD4P19B4H05QDC014@3P0=30X06QTG02XY9`0L
6aT030/9018A3`0@3`d03`h<00h=2`0=30X030/900h>300@40h03Ph<00`<2P0>3P`00P0A4@l02`0B
4Q004A4?00l?3@0?3`d0410>01@E400A4Pd01`P302`]:00a<Rd03@h900803Pl:00H04A8=01<D3`0@
4@`03a0;01<E4P0F61D2018D4@0401@F4`0C5A804aDB01<E4P804Q@A01H051HC018F400H7AH02a09
075fK`0Z;bP07b@M010E3P0H7AH051TB010E3P0D6A804QL@014F400C61@04QLC014F4P0B5a<05AXF
01LL600?5100314=0P0B5a<07`0A5Q805AXE01@I4P0B5a004aPB01@I4`0B5a404QLB01TN6P0D6AD0
51PG00hB4@0D61L051XH01HL600M8al03aDA00X@300E71D061lH01TP6@0D6a<04QTA01HM5@0D6a<0
51hF01HO6P0G81/051dJ01<L6@0E7Qd00P0K8bD04`0I8B@07RHY028Z;@0H82D06R<X02L`=@0I8bD0
628T05QRH`0[=CD05R0O01@O6`0L9b8072LQ01hY8@0V<b`072/V01h^:`0O;b`00P0M;B`201h^;@1?
02@d=00U=CD08S8b02<c<`0X>3P07Rh^01l_;`0N;Rd07Rh[02@e<00]?SP06b/X02De<`0W=cH0:CPk
02hm@P0V=ch093Ln02Pl@`0dBDh0=4M=0396B00P=3D08C<c03A5A@0P<2l07Rh[02Hg<P0Y>3<09C4]
02`h=00Z=S80:cLc02Lb;P0P:bL0:C@`02/f<P0V<Bd0:SDa038m>@0`?3P0;CTg03]7A@0_>cT0=40n
030l>P0iAD<0<Shl03E1?`0`?3X0<Cdk03<o?@0b?SX0<40g030o>00_?SL0<D0i03M6@@0kBTD0<T4l
03=2?`0fAD80=DA102lm?@0[>SL0;3Pe02Xf<P0_>cL0;3Pd02lk>@0hA480=40n02`h>00W<c<0:cLg
034l?P0iA4L0?4M;03Q5B`0203A1A`80=TE<01X0=dI=02m0B00dADd0:S]303I7C`0iBeT0:Sa@03]<
GP0jBe`0AeUW05UYMP0fAdl0=dU=0391A00[>c/0;3`i02He<P0/>cX0=49302hi>`0U<380;SXj02@^
;`0]=SD0:c@c02L`;@809bd[00<09bdY05mUH@12B4@00P0T:RH05`0O9B409b`V024V800R9b40724M
01dO700R924071hK02@Y9@0G71P0724M02DZ9P0Z;b/07B8N01DJ5P0R9b<06QlK018G4`0L8Ad06b0L
01TK6P0K7A`07R0O008071hM00<0828Q01/M700L7Qd00`0L7Qd00`0M7ah071dO01`M7`0301/L7P07
01XK7@0M7R006AXL01lP8P0E5QP06a`N01XK7@0201LG5`0N01/K6`0O7b407QhP01TI6`0L6b005aHK
01<B5`0D4aT05A@J01DD6@0K6ad07QhN01PH600F5QH05aHF018@4@0F51D05a@E01TE5P0J5QL05a4C
01@?4`0D5Q/030dB010A5P2@TID081lT01<B5`0K6ad0@d540P0C4A802P0B3Pl04`l@014?400C4A80
40h?01<A4P0?3@h04@l@01<A4P0B4142014?40803`d>00H030X=00T72P0P7R402@P:01<A500F51L5
00h<3`0301LD5P0?2``01`<400803PX;01@040`=01HB4`0@30d03PX;018>3`0C3a003`/<00`82@0@
30d06ADF014=3P0;1`P07ATJ00`82@0E4A801`<4014=3P0=2@X0510A00h92@803`T900X040X:00l9
2@0?2@T04@/;01<=3@0A2`/03@L700`61P0@2PX050h?0P0E3a406P0?2@/030H800h82P0G4A<01000
01H@4P2ZY:H081XL00P2100@1@T03@8601462P0D2@d03P<700l4200=0PH02P0301D:3P0=0PH03`@8
00`31@0;00@03@8600l4200>0`L03@860P0?10P00`0D2@d01`0001462P0201052@0600/010070000
3`@801052@0D2@d01`000P0>0`L200l4208040D900L01`0001872`0@1@T050T=00X00`0900805@X>
00<04@H:00<03`@800d21_ooool04oooool001_ooooo01T03a0;010A300>3`X061TD014B3@0T9B00
DeA?00d>2P0:2`P04A8=02`]:00A4Pd04a@?010A300=3PT02``702//9`0D5A0030d8010A300D5A00
2``701HG4P0<3@P03@d;00803Ph<0`0?3`d301DE4`0900`<2P0A4@l03@d;018B40071`D0<C4_018B
400?3`d03@d;00H03Ph<00`03a4>01TK600=3``0418?014C400:30T030h;010B3`0>40d04Q@A014C
400;3@X200lA3P0;00`>2`0?4@h03a4>00/=2P0@4Pl04A<@00h@3@0B51404A<@00h@2`0>4@X00P0<
3PT01P0=3`X03Q0=00h@3@0?4@h03a4@00d?3P803Q0?01<04A<C00`=3`0J6ad03a0B014B500;30h0
GUmQ02X[;@0E5QP04A8D00d>400I6Q`09BHW01HF5P0:2PX010@4014A4@0@41003`l?008030`<0180
3Ph>00d=3@0>3Ph030`<018B4P0@410030`<00l?3`0>3Ph020P801TI6@0B4Q80BDU903lo?`0@4100
2PX800/;2@0@40h201@D4P803`l=00D02`/900`<2P0;2`T03@d;01<C4@0200d>2@803Pl:00@03@h9
00`=200?40/03Pl:0P0:2`H200h?2P08014A400B4Q0030`;00l?3@0:2PT04A4?010@3P0>3P`200`<
2P0F00h>300?40/03Pd801LG400B4PX05AD>00`<1P0D50`02`X5014A2P0820004a<<00l?200F5Pl0
5aHA00l>2@0:2@H05A@?00`;1P0C4Pd040l:00l>2@803Pd81@0=30L05`0?3PT040l:014@2`0>3@P0
4a8=038a;00C4Pd02@P300h=200>3@T03`h:00`;1`0>3@T04A0<00d<200?3PX03Pd900d<200C4Ph0
3Pd901@C3`0A40/03Pd800803@`700@03Pd800l>2@0=30L03Pd80P0=30L01@0A40/03Pd900`;1`0?
3PX040l;00<03Pd900`02`X600`;1`0A40`03@`800`;1`0=30P04Q4=014@300;2PH03Pd900`;1`0>
3@T200d<200N014@300:2@D02`X6010@2`0?40X02``8010A2`0720@0:2TS01@E3`0>3`T020T301DF
4@0=3PP04Q<>00d?300>40d06A/G00H70`0I6Q<061TB01HF4@0A4Pd04Q<A01<F600>4QH03a0E018@
4@0M6AP071/I0P0G5Q@2014A3`0600h>300C5A802P`9014C400>4`l05QHD0P0?3`d02`0>3P`03@d;
00d=2`0>3P`030`:010@3P0?3`d02PX800l?3@0@3`/03`h:00803@`800P03Pd9010?2`0:2@D03Pd9
00T8100G5Q804A0<01hM6@804A0>100@3`d0200<2`T03`h<01DD4P0D4a405A@B00h=2`0C4Q003`h<
0P0@3`d05P0=30X04A0>00d<2P0S8R00?Sdk010?3@0A40h030/900d<2P0>3@/04A0>01<B400A40h0
3Pd;00l>300A40h03@`:00l>300A40h03@`:00h>300?3`d2014A3`803`l=00L04A4@00h>300=3@/0
7AdK00H6100@40h03a0;0080414<0`0A4Pd0300C50l05AHA018C3P0B4`h04a@?014B3@0B51405ALD
01<E4P0A4a005ALD01<E4P804A<@01404Q@A01<E4P0C5A804aLB014F3`0=4P/05a`E018G400;40T0
4QL@00`A2P0G71D04aPA010E3P0=4P/05AXE014F4P03010E4@05014F4P0C61@051TE01@I5@0C61@0
0P0B5a<00`0A5a8041L@010G4002014H4@1K018H500A5a<05A/G018H5P0M8b<04aTI01HL6`0A5aD0
51XH01LM6`0E6aL051XF01DL5P0F7AH05A`E01TP600M91`06R8G01<K4P0C7AD072LO020[8`0G8Q`0
62<M01TT8@0Y<c@0NXB5024[;@0H8BH05AhS01dV;00L9R/07bX^01`W:P0H8bD072PY01`X9`0M:BL0
72PU01`X900L:2<07R/S01h/9@0M;BL07BhX01h_:@0N;R/0830^020`;`0U=CD09SHf01d];@0S<SD0
8C0c02Lf>@0M;Bd0>DU804IFE@0_?c`09CHa02@e;`0U=C80:CTg02`l>`0/>ch0;Se202dnA@0]?dH0
;3m402e0A00^@DD0;T5302`n?`0^?Sh0;clo02dm?00T<c009cHb020_:P0S;RX0:C@`02/f<P0W<bl0
9C4]02@`;00U<Bd0<clk03A0?00b?SX0<Cdi02ll>0020350?@0<02dl>@0`?c`0<D0m02`k>00c@Sl0
9SDb03Q7A00_?S/0?Da9030o>P0kBT80=D@m0P0c@S/20391?00702dl=`0a@3d0<d8o03E4@@0b@400
<D0m02lk>002030l>01202lk=`0_>cT0;c/i03I2@00iADD0;CTi02Te=@0[=SP0:SDh03Y5B@0d@TD0
>4I903i<C`0`?d@0<d9803Y9D00iBU40;Sm70393B`0cA4`0;d5>03I9F`0jBed0>daL03a>F`0jBeH0
<D9:0312A@0]?3l09CDd02hn>`0a@3d0:SHe02Pc<P0Z=3D0:cDe02D_;P0W<2l0;cPg02Tb<@0S;2T0
8BLU02P^;00R:BH0;3H_02Tc:`0T;BP0:2hZ02X`;00X;RX08RHT028W8`0R92407AdK01`M6@0O8A`0
7B0M024V8P0S:2@07b@P01PM6@10AD4082DQ01hS7`0L8Ad06b0L0P0L8Ad401lQ800501hP7`0M7ah0
7AlN01XL6`0K7A`00P0N81l0200K7A`07QlQ01lP8P0L7Al06Q/M01TJ700J6ad05aPJ0P0K71h201XK
7@0S01XL700F5QH05aLE01XJ600b<S809RHW01HF600G5aT04a<F01@C600G5Q/06QTN01PG700H6A/0
6A/M02<T9P0Q8B<07AdO01TI6`0D4aH05Q@G01/I700^:bh03`X>01PF6@0E5a/04a@H01LH700N7b<0
61PJ010@4P0C4a@07A/L01PF5`0A40l00P0B3Pd04@0D4Q<04Q0A014?400C4A805A<D01HD5@0I5aP0
4Q0A010>3`0B41406ALH01`J6`0C4A@05A<F018@4`0A3a80518E008040hA00l03P`?014?4P0>30l0
4Q0C00d:300A3@h04Ph?014=3P0?2``040`=014=3P0>2P/05a<D00h:2`0D41400P0=2@X01P0C3a00
3@T:00d92P0E4A8030P900d92P8040`=0`0?2``00`0?2P/03`T900l92@0200h8200=00l92@0@2PX0
40X:014;2`0B30`040X:00h8200=1`P03PP:018<3P0G4A<05Q0B014;3@0300h82P804@/=00<03`T;
01052@0@1@T00P0A1PX201872`0301H;3`0D2@d040D900803P<700<04@H:01052@0@1@T0100@1@T0
300?10P040D901052@0@1@T03`@800h31`0@1`X04PT<00d51`0B2@`030<600l72@803PD800@05`hA
00X3100N5QP03PL81P0?10P01P0A1PX03`@800h31`0A1PX08QLK01<931Cooooo000Kooooo`0J01HH
4`0<3PT05QPC00h@2`0f>3<02`d800d?2P0B50l01@L204M9A03=clX0;2hY01HG4P051P805aPC01HG
4P0;30L00040014B3@0<3@P03Pl:00d>2@0<3@P051D@010A300?40/200h?2P8030d800`0414<00h?
2P0>3`X020T400l@2`0:2`H03`l=010@3P2XZ:H0BDU70000000B4Q0600h>300<00T;2@0T9R<09bTV
00<50`082PL04Q@A00d?300@4Pl03@l<00h@3@0@4Pl03Q0<0P0?4@`01`0;3@P03a4<00lA300>40/0
418=00lA300;3@P00P0<3PT00`0<3`T03Q4:00d?2P0200d?2P0P00h@3@0;3@X010H300@61@0@4Q40
5ALF00d?3P072PT000@300L;2P0;3`h04aLF00T=300830/061`K0045100^<S406alN01<G5P0V:BT0
414C01<D5P0?41804A8D00@41P0A4Q@03@h@018C5@0E5QP0414C00`>3P0<30`200`<2P0C014A3`0E
5A<03`l=01HF500A4@l010@201hN700S8b404A4?00/;2@0=3@/04a<A01LG5@0D518030`:00d=2`0C
4a406ATG00T91`0200h>300800`=200>3`X04a@?01DF4@0B4`h03a0;00T:1@0<3@P300h?2P0500l@
2`020P003@d;00l?3@0@40h00P0<30X300d=2`0F00`<2P0;2`T02@T7010?2`0?3PX02PT40081000C
4Ph03`h900T8100:2@D03@`7014@30071P4061LB00P70P0:2@@06aXE00P70P0<2`H01@@000d<1`<0
3Pd80P0?3PT06@0>3@P03@`700l>2@0F5A0081lJ02@S7P0E50l05aHA02<R7@0?3PT02PT400T80`0?
3PX0:bXV0040000A40`03Pd90040000@3`/03@`800T8100=30P02@P400l>2P0=30L00`0>3@P200l>
2@0700h=200?3PT03`h9014@2`0D4`h04A0;00d<2002010?2`0<00`;1`0;2PH03`h:00h=2@0;2PH0
3Pd900d<200;2PH03`h:00d<200?3PX040l;0P0C4Ph0900920@04Q4=01@C3`0?3PX05QDA01PG4`0B
4Pd030d701<D3P0?40X0<34[0:^/YP0l?CL01`P202<T7P1<CDL051D?01<D3P0A4Pd030d801LH4@0N
7Q@051@:01LF2P0F4`X04a<;014C3`0D61T06A`Q018F6`0N71d06QHE01DD4P0C4Q003Pd;00/;2@80
5QHD01@030h;01DG500I6aP061dI014A3`0F5Q@04Q8@01hN700D5180410>00d=2`0<30X03Ph<00d=
2`0:2PP03@d;014@300@3`/03Pd900d<20803Pd900H07QdI014@300L6aL03Pd900l>2P0<2`L2014@
300<010?2`0>3@T030/700X91@0=30P030/7018A3@0F5A402@P4014@300D4a4040l=0P0A40h05P0?
3P`04Q4?01HE4`061@<02@P600P71@0B4@l020L501<B400B4@l04A0>018A3`0@3`d03`h<010?3@0A
40h03Pd;010?3@0A40h03Pd;00d>2@0>3`X400l@2`0601dN6@092PD0824L05EFD@0W:2<020T40P0=
3PT200h?2P803a0;01<04Q<>01XK5P0E5Q40414<01@E400F5a803a4>02`^:`0I6aP05QPE00X<2@0@
4Pl04Q@A01@F4`0E5a@04aDB014C400<3`/04QLA00803a@>00l051TC00lD3P0F6aD03A8<00lD3P0K
81X0314;01PM5`0C61<04QHE01@H5`0E6AP04QHE00lC4P0@51<00`0B5QD2014E5004018H4P0B6A80
4QTB01<J508051XF01D06R0M00lE4`0B61P05Q`L01@J6P0@5QH03aDC01`R800X;R`06b4O018H500D
6QH0318>02L]:@0h?ST06b8K00lF3P0J8Q/04Q`D01XU7@0P:bD00P0K9R802P0L9RD05AlP03I0@@0Q
:bd0:S@f02H`<P0I8RL07RT]020[;@0M:2X201XU9`0D01HR8P0N:RX07BTW01/W9@0L:2H082`X024`
:`0S=2h07C4Y01T/9P0J;BT083<`02Dh=P0A8b<09SPi02<e=`0S=CT062X^018T9P0Z>SX202Lg=P0B
01h^:`0]?CT0>4U302Ph=@0Z>SP0;Cdl02ln@@0`?d@0;Sm60394B00`@dD0<D=503=5A`0cA4@0<D51
02Ti>@0`?ch0=4920P0[>SL0200Q<2d0:38a02`f=@0]=cH0:cLe02`h=P0^>SP0:3Ld0P0c@Sl04`0a
@Ch0<D0m02hn>`0^?Sd0<T910351@00`@3l0:c/j02Hf=@0`@3l0=dM602Hf=@0`@3l09SHe03=3@00_
?cH0;3/d02dl=@0a@3T00P0c@Sd0200^?CP0;Sdj0350?@0hAd@0>4I603E4@@0^>SL0;CTe0P0a?CT0
1P0^>SP0;CTg038n?00a?Cd0;3Ph02Te=@809S4c03D0>4=502Le=P0Y=cT0>DM:02ln@@0c@TH0>TU>
03i?EP0a@TT0;Ci50311B00`@Td0=TUH03U:FP0cAE80<TA>03=4CP0a@TX0;Cm102Xi?00W=cL0:3Pg
02Tg=`0/=cH0:c@a02Xc<P0/=C809Rl/028[:00T;BX09Bh[02@]:P0S;2T0;CHc02df<P0]=bl0:SH/
028]9P0K91l072DR02L]:`0T:2T08BDT01dO7@0M7A/07QlJ020P700L7Q/061dI02@Y9@0S:2@0BDi:
0;Bi]@0201lT800401hS7`0L8Ad07B8N01hS7`<0828Q00@07R0O01dO7P0K7A`071hM0P0J71/201/M
700401TK6P0O82806AXL01LH6P806a`N02`05QLI01XK7@0H6A/06AXL01/L7P0J6ad05ALF014A4@0H
61H0410>01<C4@0B4Q40820P01DE5`0D51H05QHH01TH7@0K6Ql06AXN01`P8`0J7b803Q8E00lC5P0=
3Q804Q<G01<D600J6Ah04a8G01lN8`0?3A8051<H01LI7@0C51P04Q<G018C5@0A4A<03`lA014A4@0D
4Q<04A0>01<B400F4Q404`l>018@4@804a4B0P0D4Q<0=00C4A804Q0A010>3`0?3@h04Q0A01HD5@0H
5QL04Q0C01PF6@0<2Pd04@lB028P8`0=2`h05aDH01DC5P0F51L04Q0C01HD5`0@3@l04Ph?01<?400B
3Pl040`=014=3P0B3Pl06ADF00P41@0F4Q<00`0003hj>`0G4a@0510A00@00@0c<300:bLX00H20`0<
20T07a/L03di>P0f<S<04Ph?00H20`070P803PP8018<300>20P02P@4018<300D3Ph03PP800l92@0@
2PX200l92@0<00l92P0?2@/040X<01<=3`0D3Q004P`>00h82P0=1`T03PP:010:300A2`d03`T;0P0@
1@T301462P0701872`0F2`l05P/?01@93@0A1PX040D900l4200601462P@040D900h03`@800h31`0:
0@@01P0000l62@0H3a8030@601<:3@0>1@P03@@701H=400A20/0:1lR020G6PH03P<700H02`0400l4
200A1PX0304501H;3`0<0@DDooooo`006oooool060000@004Q@?0001000C5A00WZ2K010B3@031@00
4Q@?0002000N81/0MgUd018D3`0@4@`03a0;01DF4@0=3PT030d801`M600;30L0414<00d>2@0@4@`0
2P/601@E40803a0;0P0>3`X300d>2@0;00T:1@0A4Pd061TD01HG4P0720<05ADC0000000];B/01`L5
00d=2`0D51801P0?3`d07@0H6QL01PP501TK600D5Q<04aDB0002000<3P/03@l<00lA3P0B51404aDB
010B3P0B50l04A<>00d?2P0A4`h04Q@?010B3@0?4@`03@l:00/=200<3PT03@l:00d@2P0>4@X03a4<
00h@2`0=3`X03Q0=00805aTF02803a4@00`>3@0;3@`030h=01@G5P0?5100310?00`A3P0B5a<03A4@
00P<2P0@5A407R8Q034e<`0:3`/01`/:00h@4@0?4180414C01DF600L7Al05aPJ014B500=3Q0051DG
01`M7`0G61X04Q@D00h>3P0>3P`03`l=014A3`0B4Q003@d;0P0B4Q00100A4@l00@400000000<30X2
00d=2`0=010@3P0B4Q00410>00X:200C4a40410>01TI5`030`401PH400l?3@0:2`H030d800l@2`02
014B3@04010A300F5a803Pl:00d>2@803Pl:01l03a0;00l?3@0N7Q`01PH400/;2@0A4@l05QHD00P8
1P0;2`T03Ph<00l?3@0>3P`030`:00T81P0?3P/061LC00`;2@0E51401PD1010?3@0:2@H03@`801@C
4@0>3@X02PT501DD3`0=30T0QHAo06=RG@0>3@P04a8=00803@`700D03Pd800l>2@0?3PT040l:00l>
2@0200d<1`0G014@2`0G5Q406QTD01DD3`0=30L01`H100D40P0B4@`05A@?01DD4@1bLFd0:BPT00P7
1@0<2`L08B0L014@300>3@T02PT500d<20061@402`X600`;1P0=30L0100?3PT2010?2P0;00h=200=
30L040l:00l>2@0<2`L03Pd900`;1`0;2PH030/701LF4P0E51000P0;2PH0=`0>3@T040l;010?2`0:
2@D04a8>018A3@0?3PX051<?00`;1`0?3PX04Q4=00/:1P020@000`8000l?2P041@004a@>00`=2000
0@00?d0j00d>200<3@L0;c0Z05UJE00@4@/061TC01LH400@40H06aX?03@b9@0O70d08Ql>01XG200L
6Pd05aL?01DG500H71d04aLJ02d[;00R7Qd06aXH01`K6@0F5A<05ADC00T91`0C4a4061XG01/M6P09
2`P08RLS00D50`0m?C/09bLU00/;2@0@40h00`0?3`d01`0@40h03`l=00h>300@40h04A0<010?2`0?
3PX00P0>3@T0200=30P01PD100T8100;2PH020L3010?2`0920@030/7100>3@T02@0<2`L03`h:00h=
2@0<2`L05QDA00T810071P8051<A010?3@02018A3`0=010?3@0C4Q002@P600l>300A40h051<A014@
3P0B4@l04a8@010?3@0?3P`04Q4?014@3P03010?3@0400l>300@3`d040l=00l>30804Q<>0P0A4Pd0
200@4@`03a0;00T:1@0<3@P04Q<>01lP6`0=3PT02``70P0?40/2010A30804A8=00@04a@?01PI500D
5A004a@?0P0F5a80100I6aP0@dE202h`;@0`<Rl401@F4`0B01DG500B51404A<@014E4@0U:R@092TU
01@I500D6A<04aPD014F4@0B5a4020d900lD3`0>4`d061dI00dB3`0A5A@04QHE0P0E6AP00`0D61L0
4aLF01<G5P0401<G5P0401<H5@0B6A804aXC01<J508051XF02@061hK010F500I7al04aTI01/Q8@0B
61P04QPF01hT8P0Y;bd07R@R01@J600F71T06b4O01LM6@0J81d0728N01XP700T:bL05R4K01PS7@0E
81X03aXF018M6@0K9B@07BLX01<M7P0E7b4072HX020Z;00I8bD06bHX01`X:00M:2X06bHX01TT9P0F
8R8201/W9`0Y01/W9P0K9bL07BTY01/Z9`0Q<R`07C4Y01`_:@0O<Rh09cXg02`o?@0U=cL08S@e01DW
:@0U=c/0;d5502do@`0Y>3/0830_02Xj>@0Z>SL0:CTe01d^:00[>cP0;3`j02hn?@0a@4<0<d970350
A@0^@480;D1102do@@0_@D40;d1002`l?00U=C@0:cXi030n?P0X=c@0:cXg02Da;`0[=C@00P0^>3L0
1@0_>cT0<Shl03A0?P0]?3T0=4=000<0<T8o00h0<40m0310?`0dA4<0<d=20310?`0[>cX0:3Pg0392
@@0iBDP09CDd0392@@14E5<0<D4n03=2>P80;chg03@0<D0i030o>P0_?ST0<D0k02dl>@0_?S/0=DA1
03A2@P0a@3d0;SXg02Te<@0^>SH0=40l034m>`0/>3H0:3@b02@`<00U<C40:CDe02Pc=@0U<38082/]
01PV9`0^?3h0<d5402He>00Y>3`0<d9703E6C@0^?dH0;Ci50352B@0cATh0>TiI03e?F`0eAe80<dI=
03M8D00fAdd0;3i202Xi?00/?3`09cLf02Le=P0_>SP0;SLd02`e<P0^=c@0:34^02</:@0Q:RL0:C8_
0P0Q:RL0500g@3d09c0/028]9@0T<2H09c8Z02Pa;P0W<2d0:2h^02L[;00Q9BH07AlM01lO7@0Q8Qd0
8R8L024S7P0/<Bd061dI01lT800A5Q80A4U50P0L8Ad0100M8Qh06b0L01XO6`0L8Ad2024S8P05020R
8@0N81l071hM01XL6`0K7A`0100J71/0<`0I6aX07QlQ01XK7@0I6Q`06Q/M01/L7P0H6A/05aPJ01PI
6`0G61X05AHH01LH6P0Q8b8071`J01PH5P0G5aD07AdK01/K6P0E5AD04Q8D01<C5@0E5AL05aHK01TH
7@0H6Ad061dP02D/;`0J7b807b@X01hR9P0M8B@04aHK01PI7P0:2`l051@I018A5`0F5a/05ATL01DF
6P0C51P04a@F01PH6P0K6ad051@D01<B400A40h061LE01dI600H51<04@l@01<A4P0201DC500401<A
4P0B41404Q0A010>3`803`d>0P0>30d04P0>30l061HI01HD5`0@3Q4071XM00L5200D4QD04@lB018@
4`0>30l04Q0C00h;3@0B3Pl0510A018>3`0A3@h04Ph?00l;308040`=01T0;RX[02TU9P1iMGH0:bLX
01XF5`0M6AX0HUiO05IBD`0?2``03@T:018>3`0D41401`<400P41@0U8B80:B@U00d71`0;1@D040X:
014;2`0@2PX03`T900`61P0=1`L03PP800803`T900@03`T:00h82P0=1`T03`T;0P0A2`d01P0>20X0
3@L900h82P0@2P`04@/=00h82PH04@H:00<040D901462P0C20`00P0C20`00`0B1`/04@H:01462P04
01462P8040D901004@H:01052@0@1@T03`@800/21@0700403PH800l62@0=1@L01`0100l62@0=10L0
40L:00/21@0H3a8040L:1P0=0PH01P0;00@0:AhR02hS9`0B1`/02@0200X00aCooooo000Kooooo`0<
01<E400A4`l0=CLb00lA300N81/02`d:01@F4@0?4@d02`d8010B3@0C5A004Q@?0P0?40/02P0>3`X0
4A8=00`=2@0L7AT03a0;00d>2@0<3@P04A8=01<D3`0A4Pd200d>2@0500h?2P0?40/0414<010A300=
3PT00P0F5a802@0:2`H04Q<>018C3P0=3@`051@B00h>300C4a403Ph<00`<2P0600l?3@0B00d?300C
5A801PP500/=2P0F61D03@l<00h@3@0:30T03a4>018D4@0=3``03@l;018D3`0@4Pd02`d8010B3@0B
50l03a4<0P0<3PT0700>40/03@l:00lA300?4P`03a8;014C3P0@4Pd030h900h@3@0@4Pl02`d:00h@
3`0D5QD03Q0?00/=300:3PX0314;00P=200;40/02@h800hC3P0@5@l00`P200X>2P0>4Pd05Q/E00/@
2`0=40h200h?4@0G014B500C51H061TK01PI6`0<3@l03@h@01@E5`0=3Q002``=00`<2`0>3P`04Q8@
010@3P0=3@/04Q8@01DE4`0:2PP030`:00/;2@0A4@l0410>01<C4@0A4@l00P0>3P`200l?3@08014A
3`020P406ATG01HF500H61H03Ph<00h?2P0=3PT200`=2006010A300C50l0:R/V018C3P0;30L03a0;
0P0=3PT0200=3@/0410?020P7P0;2`T03Ph<00/;2@0<30X03Ph<0P0A4@l05@0>3P`030`:00l=3@08
1PH04a4A01lM7P091`P03Pd<01<A4P0A3a0040l>00/92P0@3Ph02`X800/:1P0:2@D0:RTT010?2P0?
3PT02PT400d<1`0200h=20803`h900<040l:00d<1`0=30L0100=30L0500@3`X051<>00/:1@0B4@`0
40l:00l>2@0<2`P09RDQ00D40P0C4Ph02PT5010?3@0=30P03Pd900d<200B4@d02`X600l>2P0=30L0
3Pd8100?3PT400`;1P0;00l>2@0A40/03`h:00h=2@0<2`L03Pd901<B3P0G5Q804A0<00h=2@0A40`0
0P0>3@T00`0@3`/04A0<00l>2P0200l>2P0c01HE4@0d<bl08B0L00X91P0E51003`h:00/:200A4@d0
2@X601<D3P0<3@T04a@>00X;200?40X05aPB014B300D5@l03Pl901<D300F5PD04a<001hL1@0l>B00
?cXP040k7`0Z9@/09b@;01hN2P0E60/04QL<01@J4`0S8Ql071PG01HE4`0G5Q@04a8@01@D4P0C4a40
4A4?01<E4P0A4a00418?07IkM`0[:bT0GEeK03dm>`0C4a405QHD00l?3@0>3P`03`l=00803Ph<00<0
410>00h>300@3`/0100@3`/01`0?3PX05aHB030_:`0;2PH06APD01DD400<2`L00P0>3@T400d<2008
00/:1P0B4@d04A0<00/:1P0B4@d05aHB01<B400@3`d2018A3`05010?3@0D4a403Pd;01<B400:2@L0
0P0=30X01P0I61H03Pd;00d<2P0=30X04A0>018A3`804A0>00D040l=018A3`0A40h040l=018A3`02
00l@2`03010A300A4Pd04a@?00804a@?00@03@h:00`=200B4`h0414<0`0?40/01`0@4@`04A8=014B
3@0A4Pd051D@014B3@0@4@`00P0H6A@02@0A4Pd04A<@02<U8P0E5a@0828O00d?300C5A805ALD01@F
4`02018D4@0:01<E4P0G6QL0<3Db030d<`0G6aX04QLD01DI600H71X04AHC018F5@8051PF00L04ADD
01TM700D61L04aLF018F5@0C5aH051PG00H05QXI010051XG010I500@6A@04AXE018K5P0B6aP051dJ
010I5P0D7A`03aLI01DM7`0I8R805Q`K01LM6`0H7Q`05adM0P0F71`01`0P9RH05Q`K01TN7`0I7al0
7B8S05MNG@0O:BL00P0L:2@0;P0H92805R8P01/W9@0O:bT05b<Q03E1@@0Q;Bd072PX01l[:P0E8b40
52<P01PV9@0K:BT06RPX01/Y:@0I9bP06bTZ020^;`0S<C808c4c024`<00M;RP07C4W020d:`0R=Bl0
8cHa02<f<`0N<300:S`m02m1@`0bA4P09SLm02Pj?P0[>Sd093@d02Xj>@0S<c009cLc02ho>@0Y>CH0
:3Pf02/k>P0_?T40<D1502dl@@0[?Cl202Tk>`0B02Xl?00Y>SX09cLf02Pf=P0Z>3P0:cTi02Pd<P0c
?cd0<Cdk02/e=00]=cH0;SPg02hj>00b?S`0=44o0391?P0dA440<d=00P0bAD40900_@Sh0<D5003=3
@P0c@d80;Cdl02Xj>@0]?C`0<40o02lo?P0`@3l0=dM607V9R00eAD80<T8i02ln=`0^?CH0;chg02dl
=`0[>SD0<T4l0391?P0d@d00=dI303I4A00eA440;c/h02Te<@0]>CD0=D4m03M3@@0iAD<0<3`j02Da
<@0T<3009S8b02@_<@809S4c0180BUQI06AbL`0c@D80:CPk02ln@P0_?T<0;3i202Xl@@0]?TD0;d17
0313BP0hCE@0>diF03A7C`0eB4h0>DYB03M8CP0_@DD202ln@@0802/k?00Y=cX0;3He02db;P0]<bl0
;S@`02H/:00U:bT202@Z:00E02lh=@0Y<Rl08R/X030j=`0T<2H082hR024/900Y<Rl0:c@a02H/;00V
:BX092DW024Q800S8R0092<O02DS7P0H6QD082DQ01lT800Q9R8082DQ00806b0L00D07B8N020U8@0M
8Qh0724M01lT8002024S8P05020R8@0N81l07AlN01/M700I6aX00P0K7A`01P0J71/06adL01`N7@0M
7R00824S01dN80806AXL0P0M7R003@0D5AL07b0R02X[;@0T9BL071hM01`L6P0F5a8061TD01@D4P0F
5QD0410@01<C4`0G5aP00`0I6A/03`0I6Qh061hS028Z;`0>5QX0620V03Y0AP0I7b@05Q/R01TL8`0E
61h05aTP01DF7`0C5Q`04ADG018C5@02010A4`0:01HF5P0J6QX05ADE018A3`0A40h061LC01dI5P0I
5A<04@l@01@B4`805Q@E00<04a4B018@4@0B41400`0B4140;00A3a0040h?014?4P0A3a805aDH00d;
3P0@3Q404Q0C01<A500B41<05A<F01HD5`0O7B005Q<E018>3`0D41404Ph?014=3P0B3Pl0510A00P5
1@0H51D040`=00/8200Y9BH0510A00P41@0C3a004Ph?00d92P0F4Q<02PH700l;300@30d03`/<00h:
2`0?2``03`X;00d71`0?2@T04P`<00d71`0A2`/05@l?0`0>20P200l92@0400l92P0<1PP02`D700`6
20803PP:00<03@L900`6200=1`T00P0@2P`00`0>20X04PL;01872`0401462P0500l4200@1@T04PL;
01872`0A1PX01`0?10P201462P0;01872`0A1PX040D900l4200>1@P02`D700l:2`0:10H091hP00d7
2@0:10H0100;1@L00`080P<03P<700h31`0400h31`0600T00P0J41<08AHJ01062@0>0`L04@H:5?oo
ool001_ooooo00H05Q/E00X?2@0A5Q0041D?00P=1`0L8A/200lD3P0401<H4P0=4P`010T400h@2`80
3@h900X07AhI00T:1@0A4Pl0/;6/059CCP0=3PT04Q<>00h?2P0D5A00414<1P0>3`T0300D5@l0<S<]
03<d;P0F5a404a@>01@E400<30X071`J00/;2@0C4a4061PF00@40PH03Ph<0180418?07=eLP0`<Rl0
4Q@A014C400K7AX03a4>00d?300?4@h030h;00lA3P0C5A403a8;00d@2@082`@03A0900lB2`0>4@X2
00X=1P0a00lB2`0;3PL02`h700d@2@0?4P/04aD@010B3@0<3PT03Q0=03`n>`0g>CH02@/:00H81`0C
5A@03@l>020S7`0h?cL072<K00`C2`022@404AP@00@9100N9Ad061lG01LN5P00100000<0018G500D
61/020`?01LK7P16BTd0[k>f02X^<@0F6Qd02`lB00lC5P093A003Q4C018B400>3`X03a0;010A300=
3PT04a@?00X;1P0A4Pd05aPC014B3@0200/<1`0401<C4@0A4@l03Ph<00l?3@804A4?00<02@T701hN
7015AD<00P0A4@l00`0=3@/0414<00l@2`0200d>2@0?00l@2`0A4Pd03@h900L80`0?40/04Q<>00d>
2@0C50l0@40n05]KF@00000010@200h>300G5aD03Ph<00803`l=01403Ph<00`<2P0:2PP02@L801@B
5@1@CU40Shf@01dK7P0:20/0;bd`00/9300I5aX0518E00`:3@0<2P/030/701XI50020040000301/J
5@0=30L03`h900<03Pd80`0=30L200`;1P0<00h=200@3`X04A0;018A300>3@P00@0000d<1`0920<0
4A0;010?2`0510000@000P0:2@D02@081`<04a8>00h=2@0920@030/700P70`0>3@T040l:00h=2002
00d<1`0300h=200?3PT04A0;00804Q4<00D051<>01LF4@0C4Pd030/700d<200200`;1`0`00h=2@0=
30P02`X600l>2P0A40`030/700h=2@0B4@d05QDA00D4000T8al0<c8^01HE4@0S8Qh02`X60040000:
2@H04Q4=01<B3P0?3`X02P/501PI4`0E5Q0061TC00d>200>3`T0414;014B300R8ad010D001TJ4@0G
5`007Qd002l/2P17@ah0OWUC07iiD@1=B280=c<>02LW2@0V:180724;01`R4P0K6QD081`K01`K6@0F
5A<05aHD0P0E5A<03@0;2`T05ALD01TK600B51402Pl;014A3`0D51804Q8@014A3`0?3`d02`/900d=
2`0>3P`00P0<30X02`0A4@l030`:00d<200?3PX04A0<018A3@0A40`040l;00d<200G5Q801`H20080
40l;00<04A0<010?2P0>3@P00P0;2PD02P0>3@P040l:03ln>@0@3`X081lJ00l>2@0@3`X02`X6014@
3P0=30X2010?3@0800l>300C4Q003Pd;00h=2`0A40h051<A014@3P081`D200h=2`0A010?3@0C4Q00
4A0>00l>300A40h03`h<01<B400A40h03`h<01<B400A4P`03a0:00h?2@0?40X04A8<018C3@0<3@L0
0P0H6A<0100=3PP04a@>01DF400?40/2010A30<04A8=00<04Q<>010A300?40/00P0F5a80100A4Pd0
61XG014C400A4a0201@F4`0301LI5P0D5Q<04aDB008051HC01405ALD00hA3`0B5QL041@E00`@4@0D
61T05a/L01TM7P0A5AH0A4Q900dA4P0F6Q/0310A00lC4`0D61L04aLF018F5@02014E500401<G5P0E
6AP05ATH01HJ6@805a/J00@05A/H018K5P0B6aH04a`H0P0C71T03@0E7Q`01Pl>018K6P0a>C/03QHH
01DM7P0L8R806AlM01DK6@0F71`061hN01XO8P0E6Qd00P0H7B005`0>4aL04AHJ02Xa=00J92<062@R
01dY9`0N:RP062@R01TU8`0jAT@0:3@b01l[:@0B7Q`07b/Y01TU8`0P;b`072/V01d/9`0N;BX06RTV
01`Z:P0O;Bh07R`]00807R`_020082dc020_<P0O<2X07c<Y024e;00Q=2h083<^01ha;@0W>CT093Hg
02Dg>`0U=Sd0<45806anPP1MK6l0;Shn024a<00Q<Bh0:SXf02`m=`0/?3T0:CTg02`l>`0a@4<0<d97
02hm@P0Z?3`0:C`j02Pk>@0[>cX0:CTh02De=080:cTi01d0;C/k02/g=@0jAT@0?4Q6038l?@0e?d00
=T1103I2@P0fA4@0>4I603E4@`0dA4<0;d900395@`0aAD<0;d9003A4A00iBDT0?De=03E5A@0a@D40
=TI603];B`0dA4@0=TI60392@P13De<0;3`k0350>00202ln=`0@030o>00^?CP0;3/f0391?00iB4D0
>TU603I5@P0fA4@0>4M4030l>@0`?3P0<clk03A0?00e@Cl0>dM503E1?`80;3Ph00X09c<c02<^<00Z
=CL0:SDg03A2@`0/>S/03adN02<b=@0d@dH0<3m20P0bA4P0<P0^@4@0;Sm60313B@0cB4/0=4M=0313
B00bADT0<TA802i0A00a@dL0<T5602`k@00_?T<0;3To02D];@0W;2H0;34]02/`;00R9b<09bdY02H/
:P0P9R@0:c@a02H_;00Y<Rl0FfER02Te:`0R<2<06RLN01/V8P0N9b@08RPY01lP900Q8R@08b<R024P
7P0P7aX08R0K028T7`0G71P08BHR01DJ5P0I7QX08BHR01XO6`0N8al08RLS01lT800M8Qh08BHR100O
8B00;@0N81l071hM01LI600K7A`071hM01/M700M7ah0828Q020Q8`0O828071dO01TJ700G61X061TK
01lP8P0D5AL08b@V02d^<00R8bD061XI01/K6@0H6A@071dH00/;2@0D51805ADC01DE5@0J6QX071`L
01XJ700H61X061TM00dD6P0?6R406B@Z04eGH033c=@0PhbC02he?`0D6b@03A4J00T=5`0C5b806AhT
01@H6P0201@E5`0=01@F5@0D51@04a<C01<C4@0C4Q0040l=01<B3P0G4a004`l<014?400C4A80518C
01DC500201<A4P803P`=100?3@h0200<2Pd040hA00H41`0O7B0030X=01LE600>30l030X=0P0>30l0
1P0G5AP04@h@014=3P0B3Pl04@d>00l;308040`=01/03@T:018>3`0<20T03PX;018>3`0?2``05Q8C
00D10P0=2@X05Q8C00/7200C3a004Ph?00h:2`0;1`P02@D600H20`0;1PL03PP800d71`090`<02P@4
028L700X8R804@/;00l92@0>20P00P0?2@T01P0@2P/03@L900d72@0>20X03`T;00d72@<030H80P0?
2@/01@0=1`T04PL;01872`0B1`/04@H:008040D90`0B1`/00`0A1PX040D900l4200601052@804@H:
00X04PL;01462P0A1PX03`D9018930070@<03PT:00@0000E3a4010000P0<1PP0100:10H040X<00h8
2P0@2P`600h31`0601P=4@0<0@D03P<700/0100A1PX030455?ooool001_ooooo01X000@0010E3`00
1@005Q/E00T>200:3`T010T300T>200E6Q@01``6010E3`0K7AP030d801<D3`092PD0414<014B3@10
@C`0R8V401@E400J6aH030d8010A300?40/0414;00l@2P803Pl90P0<3@L0300@4@/04a@>01@E3`0:
2`D03Pl900X;1P0D518010@201TI5`061P@04Q8@01<C4@H03@d;00L03Q0=05IHE@010`004Q@A00lA
3P072@H03Q0=00804A<@04X030h;01XL6@0N81/04A@=00h@2`0930H03Q4:014C3P0?4@/02Pd600X<
1`0?4P`020/400H80`0:3@L03a4<01<E400A4`h030h900h@3@0C5A802`d:00X<2`0F61L04Q@C00lA
400?4Ph04QTB00870@083PP01Pd601@I4`0<4P/08bXS00@90`0M8ad00`X301XO6@062`P051PI00`@
4@0J7Ql0E5QI0=kRh`0^<S<05a/L00T=3P0?4a@02`l@01DH6@0L71X04Q<>00d=2P0@40h03@h900h?
2`092@L03a0;00/;200=3@/02``700l?3@0>3P`03@d;00h>300?3`d0410>00d=2`092@L092@R03lo
?@061P@06QXH00d=2`D03@h9010030d800h?2P0D5A008B8M01/L5`0:2`H03a0;0082000R8R004a<A
00d=2`0@40h02`/900T91`0;2`T030`:0`0=3@/0500G5AH00P41030^;`2:R8T04a4B01PF5`2;RHX0
6APH00d;300?3@h02`T:01@C4@0C4Ph02PT700T80`0M71L020L401DD3`0@3`X03`h90P0>3@P0200=
30L030/6010?2P0<2`H02`X500d<1`0B4@`051<>0P0>3@P04P030P004Q4<00L60@0@3`X030d800X;
1P0@4@`03a0;01<D3`0;30L09RLR01XI5@0?3PX03Pd900T8100@3`/04A0;00h=208030/600T03Pd8
00l>2@0A40/04A0;00l>2@0>3@P040l:014@2`0@3`/00P0C4Ph00`0?3PX03Pd900l>2P0200h=2@1n
00/:1P0920@051<?01HE4@0D4`l00`8003dl>01@Cd/04a8>00X91@0@3`/05A@@018A3@0920@03Pd9
01PH4`051P002``6010A2`000@006Q/F01DF4@0@4@`010D000h?2@0E5Q005QL=01@C000V8`00A3lI
06MP=P31^8d0b/:D08MnD`1PFc<0@T0O03Xm8P0V:A@06Qh>018A300N6QT06QTG010?3@0B4@l03Ph<
00P81P0>3P`05aPF00<30@0?4@h051HC00d=3@0>3P`06Q/G01PG4P0I6A406APC018>2`0B4@d03`h<
00h>3P0D51@03`l>00X:200=3PT0414<014B3@0B4Pd04A0<01/J5P0;2PH05A@@00/:1P0=30P040l;
00l;200<2PH02@P300d91P0C40`05aHA09nKV00F51004Q4<00/7100E4`l03`h:010?2`0<2`P03`h:
010?3@0?3P/04a8>00h=2`0<2`P03Pd900L6100=30T03Pd;010?3@0A40h04a8@01@C4@0@3`d03@`:
014@3P0?3P`04a8@014@3P0?3P`04a8@01/K5@0F5A004Q<=00l?2P0>3@P03@h800d=200<2`L0414<
014A300C4Ph020T4018C3P0C4a404a@?0`0D5A003P0?40/04a@?010A2`0B4`h05AH@01<D3P0B50l0
3@l:01PJ5@0?4@`03Q0;018D3`0@5@l051HA0P0D6A<00`0C61805QXH01PN7P0200hD500;01@J6P0@
5QH061hN05EKF`2na<@0728R00dC4`0K8B403a@C00lC4P0B5QD00P0D61L201<G5P8051PG00L05ATH
01HJ6@0F6QT05Q/H01<L5`0D7AP051dI00805AhK02h06B8O00H?300S;2/0GFIU01XS8P0D7A`061hL
01LM6`0D6QP04ALG018H600F6ah051TL01/P8`0E6al061dQ02@[<@0H7b@072PX01HR800G8b<062@T
01HR8P0M:BT072PX02Hb<P0W<c<06BDU02@`<00P;2`062LT01@S7P0J:BH08S4^02<a<@0[>CX0;3Xk
02Pf>@0P;C806RL]01/X<00M;340830_020c;@0R=Bl08cH`0P0U>3@0<P0[?S`09CLh03E7B`0eATd0
7Rlf03]<D`0]?4<09SDi0392@P0X>3P093@b02Xj=`0X>3D09CDc02Ph=`0]?Cd0;ci202Xi?00[>cX0
:CXg02Ti=P0Z>SL0:3Pe02@d<@0Y=cL0:SPh02hl?00/>3H0>dM503a8AP0`?3`0=41003E1@@0c@D40
=49203A4A00eADD0<TA402i0@00a@d<0<DE402i2@@0^@400=dU903e?C`0eADD0;Shn03=3@`11DE40
?dm?0P0lC4`00`0L;2`0>d]:03I5?`0203=2>`0I03=2?@0_?ST0;C`g03=2?@0lBdP0>dY70391?P0_
?Cd0<T4n030m=`0g@S`0>4@n03A0?00b?CT0<chk02/g=@0Y<c80<3/k02di>@0Z=3D0:38c02Da<@0Y
=CD0:SPi02Le=P0202Dd=`0<02ln@`0hBTh0>daC03A3BP0e@d`0=TQ=03A7B`0cATX0<4960394B00_
@DD0:cXo0P0c@TL0:@0[>C`0<T1302hl?`0R:b/09R`X02hc;`0/<Bd08BLS02/a;@0N9280:c4_02L`
;@0M9R<0:c@a02@]:P0R;BD08BhU01l/900K9R8072DT024X:00H71l07QlQ028S8P0O7ad071dH01lO
6@0P8Ql07R8Q01/O7P0_<c800`P401/O7@0G71P0724M024V8P0M8Qh06b0L01lT800N81d07R0O0080
7b4P00h07R0O01dO7P0F61L06adL01dO7P0L7Qd07R0O028T8`0T9BL07AhP01TJ700J6ad061TK018C
5@806Q/M02T0824S01PI6`0C51H09RPW01/K6@0C4a407AdK01<C4@0H61L02@T901<C4`0I6AT06a/K
01PH6P0E5AL05AHJ01TP9P0E82H0;3Lm075jP@3eoOl0Y:^e038i@`0I82T07R8[018F7`0@51d04aHM
010C5@0A4Q@04a@F01DG5P0C4a<0410@01@D4P0F5A<04Q4?018A3P0C4Q0040l=018@4@0201<A4P80
518C00D04a4B01HD5@0D4Q<04a4B014?400200l=3P0M00`:3@0O7B002`T<03/i?00F51L061HI01/I
700E4aH0518E00l=400D4QD03``>010<3@0A3@h040`=00h:2`0@30d03`/<01/G600<20T040`=00h:
2`0B3Pl03`/<00@00@0H51D05a<D00P41@0D41400P0;1`P300h:2`0:014=3P0D3`l030H600d71`0D
3Ph02P@400T30`0A2`/04P`<010:2P<03`T900<040X;00l92`0?2@/00P0A2`d0100>20X030H800/5
1`0<1PP200l92`0500d72@0B1`/04PL;01872`0A1PX0100@1@T0100A1PX04PL;01<8300D2@d70146
2P<04PL;00h04@H:01052@0600005a4C00/51P0[8RD0VI:D01hH6P0D2`h03`L:00H00P0>1@P02P@5
01072PH03`@800H0304500/2100A1PX02@0200`21@0<0@DDooooo`006oooool01@0=3`X0418=00d?
2P0=3`X03a4<008030h900L02`d800h@2`0A4`h04A<>00d?2P0@4@`03a0;00803@h900X03a0;010A
300K71L051D@014B3@0>3`X05QLB00l@2`0<3@T0414<0P0B4`h0200M7QT0>CXe00l@2`0E5Q404Q<>
00`=200=3PT03a0;0P0?3`d2010@3P03014A3`0@40h03Ph<00<0410>00T03Ph<00d=2`0>3`X04A8=
00l@2`0>3`X03a4<010B3@0=3`X00P0>4`d01`093PP03Q@>00`?2P0=3PX03Ph<00h?300?3``00P0?
3`d01P0>3`/03Ph<00h?300>3`/03Ph<00h?30<03`l=00<03Ph<00d=2`0=3@/00P0@40h09`0>3P`0
4A4?018B400@4@l0310=00L91`0>4@l0310=00/=2`0<3`d01@P600lA3`082`T02Pd;01<E4`082PP0
4aDC010B400L7Q`03@l=04=5@`0I6aT0418@00lA3`0>40h02`d;01XL6P0W9bL05QHE00/;2`0>3Ph0
3@d<01HF5@0C4a<04A4@00l?3`0A4A404A4@010@4005010@3P0E014A3`0>3P`03`l=00l?3@0<30X0
2`/9010@3P0B4Q004a<A034a;`010@003`l=00h>300=3@/06QXH00P81P0G5aD02PX800h>300>3`X0
3@h900@02``70P0<3@P200d>2@803Pl:01004A8>01<C400>3P/03@h:010@3@0=3@X051@A010@3@0>
3`/0414=00l@300<3@P03a0:00l@200=3PH030d50P0=3PH00`0?40P03@h600`=1@0300d>1P0501@E
3`0?40X03Pl900l@2P0>3`T00`0=3PP0;@0>3`T030d700/<1P0=3`P04aPA02D[900D6Q805ATB00P<
1`0>4P/03Q4:00d?2@0;3@H0414;00X;1@0?40X03@h900X;200A4Pd04A8>00T:1`0H6A@02P/600l@
2`0>3`X02P/600d>2@0@4@`030d801HG4P0?40/04Q<>00P9100;30L051D@00T:1@0B4`h01PL301<D
3`0<3@P061TD018C3P0@4@`051D@00/<200200d>2@0N00l@2`0=3PT02P/600/<1`0@4@X030h401TJ
500<3@P03@d;02/[:`0G5aP04A4A00d=2`0C50h05aPA01lP4`0a;0h0<2X606=J<02`XWL0m^o10?ok
c@3gkL80_[::05iF=`0_;AP0;2dN01dP5P0H6A@05aHB0`0E5100>@0C4Ph04A0<018A3@0B4Ph040l;
00l?2P0A4@h07AdN05]KFP1WIUh0UYB303Te8P0T7@`06a8801`C3P0E3`l04PhB01LE600D5AD03Q4>
010E4@0;3`/030h;014B3`0=3@/03Ph<00d<2P0>3@/04`l>014=300>2@P050h>01<=300E40l03`T9
01@?3P0?2PP05@l?01@?3P0B3@`04P`<014;2P0?2`T03@`800l@2P0G6180414<014B300?40`02P/5
00h?2P0?40X051D?00`=200A4Pd04A4?00T92@0200d=3@0R00h>3P0B4Q804Q8B00l?3`0;2`/0@d=3
04e=C@0>3@/04a4;01LD3`0;2@@04a0;01@@3@0A3`/0514?018>3P0@3@d04PhA01HA5P0E4aD04A8A
014C4P0<3P`04Q@A00`>2@0C5A004QD>01DH400E60l04QD<01PK4@0@4`T04QD=01@G3`805AP@00D0
4AH>00lE300A60l04AL>010H3P02014I4007018L5@0?6AH07BLS00hH500D7Q/05R0M07J0O00203Do
>`0601@N6`0A6aP041XG01LN6`0F6aL04aPD0`0B5a<02P0D6AD06AhJ01dR7P0I7QX04aPD01DJ5P0I
7QX05A/G018H500C6AD201DK5`8051XF09D06R0M01lU8P0M8b005Q`I01PN700F71X05adK01TO7@0K
8Al0624P01`U900F7ah05QlP01TR8`0G8B<06RDW02Da<`0=6a/06BLX01PV:00E8bD07B/]02Ha=P0_
>Sl0?4M<03Y3B`0[=3`09Ble024_<00K:RP08Bl_02Dc<`0N;2d0938d01h/<00T<CL072Ta020]=@0T
<CX0938j02@d>P0O<C@08cHf02Dg=P0T=c@0:Sdi02Lj=P0V>3P0:C/n02m0AP0X>D00:3U402De@`0W
>4D0:ca502Dg?@0Q=3D0;D0m02`o>`0T=c<09cXg02/n?00[?Sd0;Cln03E6@00b@S/0=4<m0350>P0Y
>3<0:3Lb02/j=P0]?3T0;3/h02hm>P0a@3d0:CPf02/m>`0/?S`0<dA303A5A@0b@d@0=TQ:0353AP0c
ADX0=DM<03I7CP0cA4`0<DA902a1?`0cAdD0<TI403=7A@0dAdD0<DA20395@`0b@T40=TI503A4@`0g
ADD0=D=303M7@`0b@ch0=dQ303I6@`0b@Sl0=DE203I6@`12DTl0@E5>03I6@`0a@Ch0=4<n038m=@0d
?SH0BeE>041;A00^=c80;cTd02H`;00X<Bh0;SPe02/d<P0Z<c40;3Dc02@]:`0W<2l0<Cdm02Pf=`0U
=3L0:c`o03]=D@16E5`0>4E?03e9E015Ced0>dQA03];D00`@DD0;Ce202hm@P0[>C`0=D95041<D00f
@TD0=3m002/f=`0R;Bh0;cPh02@]:`0202Ta;`03028[:00U;R/092dX00809c0[01T09BhX02L`:P0T
;BP07RPV02D`;P0Y<c409Bh]01/T8`0O9bD0728Q01hS8@0Q928082<P01lS7P0R9B40EEUK01dP900M
8B<07B4R028V9P0O8b<0:2`Z02<X900L8Ad0724K00807R<M00<07b4N020R7`0O8Ah00P0M7a`201XL
6@807AlL00L06adJ01TK600H6QL08B<R01hP7`0J71/061XI00805aTH03407R0O02@V9@0O8B008bDT
01HH5`0I6aX071`M01DE5P0G5aP061PI01@D5P0B4Q@0410B01XJ700@418061PJ018B500M7R0051/L
01@N7`0H8B<09bhc07j5R`1>DU/07B4Z018F7@0C5Q`051PL014E5`0C5AP04A4B010@400E5AD04A4A
01XJ6P0C4a<04Q8B01<C4`0K6a/0=CDd01LG5`0D4a@04Q0A01<A4P0D4Q<06ALH020N7`0C4A804@l@
00803`d>00h040h?00l=3P0=2``04@lB01TG6P0M6ah04a4D01/I700_;C00>SPk00X82`0L6Qd02`T<
01LE60803P`?00D0518E00d;3P0E4aH01`D800l=400200h<3`<03`d@00L04PlA00X61`0B3Pl071PI
014=3P0>2P/03@T:00@03PX;00D03@T:00d82@0>20X03PP:00l92`02010:300300l92`0>20X03PP:
00<03PP:00<03`T;010:300?2@/00P0=1`T01`0?2@/03PP:00h82P0>20X03@L900h82P0B30h00P0C
20`08P0?10P04PL;01462P0B1`/03`@801T>4P0K41@050T=00`21@0B1`/0304501@93@0>10L04@H:
028G6`0J3a<040H900l4200>0`L03@8600`31@0?1@P03@@600/3100>1@P07Q<G05Q>DP0?1`P03PD7
00d31P0?1@P040L900d31P0?1PP200h31`<03@8600<0304500l4200?10P0100?10PDooooo`006ooo
ool02P0<3PT03a4<00d?2P0=3`X0418=00d?2P0>40/04A<>01<E400B50l2010B3@0O00d>2@0>3`X0
3a0;00l@2`0>3`X03@h904e>B@0K71L03@h9018C3P0A4Pd01`P3018C3P0=3PT02P/600L80`0<3@P0
8R<N010A300=3PT02``700d>2@051P4030d800h>300=3@/030`:00d=2`0?3`d0410>014A3`03018B
400?014A3`0@40h03a0;00X;1P0;30L03Pl:00d?2P0<3PT04Q@?00dB300:3`T082DO01XQ6P072@L0
3`l=00<03Ph<00<03@d;00h>300>3P`01@0>3P`300l?3@0300h>300=3@/03@d;00804A4?01T03Ph<
010@3P0@40h03@h<00D71P0:30/02@/:01<E50010`80418A01`N7@0>40l071hM01DG5P000@006A/I
01<E4P051`@061XG01@F4`0@4Pl03a4>00`>2`0A4a00418?00801PP500H04A4A00d=3@0@41003`l?
00X:2P0B4Q83010@4003014A4@0D51@071`L00H03Ph<00@03@d;00`<2P0;2`T03@d;0P0?3`d200X:
200?01HF500820H0410>00X:200B4Q006a/I00`<2P0F5Q@02`/900`<2P0A4Pd03@h900`=200>3`X0
3a0;00<030d80P0=3PT200h?2P06018C3P0C50l03@h900/<1`0>3`X02P/60P0<3@P01P0>3`X0414<
00l@2`0<3@L03@h800d>1P8030d50P0>3`L02P0;30@03@h600h?1`0>3`L030d500/<100P8A/05AH@
010A2`0=3PP200`=1`1@00d>200>3`T020T300`=1`0>3`T01PT200T?200[<RX0SiJ>06icK00C6140
0@H0018E3P0?40X02P/500h?2@092P@03a0:018C3P0D5A000040020Q700U9R40:b`W010A300?40/0
3Pl:00`=200;30L03@h902<T7`0f=c8051D@014B3@0<3@P03@h901@E400B4`h04A8=00<4000?40/0
51D@04a=B00k?3L0:BXU02`]:00@4@`05AHA00d>2@0<3@P03a0;01<D3`0D5A005AH?00X<0@0?40X0
4A4=02@T8P2b/[80A4A4010@400?3`d05AHA01TJ4P0R8aL0;RX=03Tc3`1hKdP0a[V?0?ojc`3oom@0
imVb08IlF011>Qd05aH405mQE00>4`/051D@01@C3`0C4Ph201DD400401<B3P0B4@d04Q4=018A3@80
40l;01d051<?04=4?`2VYil0EeM40;JeV@2IUGP0Ad4W02HO3@0V7Q<07ALB01<?3P0B4@l04Q@?00hC
3`0@5A403A8>00h@3@0A4Pl03`l=01PH5P0E51803Pd;00l;2P0D40l06QHE010<2`0A3@`05a<B00h:
2@02018>3@0>00l;2P0A3@`04`l>018>3@0?2`X02`L600h=2@0;30L03a0;01@E400A4Pd00P<000T:
1@0<3@P200H70P0401<D3`0Q8Qd0IFES01/K6`80410@00`01PH601<C4`0=3@d00`<3018B4P0n?Sh0
@41001PH5P0B4@d040l:01HE400=30P2014@300B01@C4@0B41404Q0A01<A500E4aH05Q@G055BD@0L
7Qd04Q@C01TK600=3`X05QPC00P:1P0B5@`061/B00/>1@0J7A803A050`0B5@`08@0D5`h04aT?01HM
4`0=5@X06B4F01PQ5P0C7A806bDJ018M5@0540`051lK01PS7`0951005R4M08RCS`0`>cL031LC00/F
4P0G8Qh03QTE01@L600C61@041DA01<H500I7QX06QlK01TN6P0G71P05AXF01<H500B5a<04aPD01<I
5@02018H500401HL600H7QX05Q`H01DK5`805adI00H051XF01<I5@0E6aL06R0N01TO7@0G7A/201TO
7@0;01DN7@0E7ah05b4P01/U9P0G8b<062@T02Xe=`1HIVL0<Cm001/Y:P0M:bh00P0O;C00:`0d?dD0
@diD07Z5R`1UKgP0ADmH02`f?P0Z>3T09CDd02Ti>@0Z>SX08C4a01h]<00T<cP0<D1502@c>P0O;SD0
9C<k01XX<@0T=Cd08S<j02Dg>`0V>3P09STg02Xm>`0N<Bl0:chm028d=P0gBDd0=TM>02Lh@P0Z>TT0
9CE502Hg@@0W>4009SPk02Tl>P0aA4009STe02Pk=`0^@Cl0;T5002/n?00cA3h00P0_@3X02`0/?CL0
9SLb02Lg=00Y>CH0<D500392@@0a@D00<40o02Xj>@0`@d40;T100080<D=301L0<D=503A6B00`@TH0
<dA;03E6C@0fAdh0=TM?03A7C@0dBDL0;T9002a0?P0cAdD0=TU70354@P0bAD<0=4A303e=C00c@d80
<Clo030n?P0b@Sl0<d=003I6@`0203E5@P0703Y:A`0hB4D0Be]H04MGE00a@Ch0;Cdj03I5@00202Xd
;00T04I@B00oBD40:34/02L`:`0_>3<0;CHc028[:00]=S<0<3Tf03Dl>`0[=3<07bPW02Lc<P0[>CT0
9cHi02Hg>P0W>Cd0@U1I03e:E00c?d/0@D]G03=0B@0jBDh0<d9702Xi?@0T<cH09C<f02hj?@0mB4X0
9c8d02Pb=00a>c`0HVa]08bEU@0c?3/0:34`0P0W<2l05P0R:bP09Bh[02Tb;`0X<B`09S0X02Pb:P0U
;bP092h]028/;@0kAD@0;SLf024Z:@0U;R/07B<Q01hT8P0O9200724M01/P700N8ah092PY01/O8P0U
:B`2028V9`05028V9@0N8R40720O01/P700L8A/00P0M8Q`01P0M7a`07b4N024S800L7Q/06Q`I01hP
7@807AlL00L06Q`I01PJ5`0J71T07R0M01dO7P0K7A`05aTH00805ALF00P05QPG00T;2P1lOWd05QPG
01XL6`18BTT06adL01lO8@<061PJ02L05ADG01HF60071`T04Q8D014A4`0N7R006QXL00d>400L8R00
5A/L01`Q900=4QH04ADJ020S:P0F6B004aDK01DF6`0C51P0414C01<C4`0H61P03Ph>01<C4`0A4A40
20P8014A4@0D51@0410@00h>3P0O7al09bLW024Q8@0A3a00518C01DC500A3a005A<D00/92P0B4140
0P0@3Pl05@0B414040h?00l=3P0E4aH06QPK01hL7`0C4A@03P`?01HD5`040PD05Q@G01LE600:20/0
518E00l=400@3Q403P`?018@4`0?3A006aTL010>4@0200/9300600`:3@0@3Q404a4D02<P8P0G4a@0
30P90`0@30d0100<20T03PX;00h:2`0=2@X200`82@0300d82P0>20X03`T;00803`T;00<040X<00l9
2`0>20X01@0>20X01P0=1`T03`T;00l92`0?2@/03PP:00l92`802P@600D050h@01PB500C3@l05``@
01<8300201052@0P01462P0=0PH03@8601<8300F2`l04`P<00h31`0F2`l03@8601052@0?10P03@86
00l4200=0PH0;24U01T>4P0E2Ph05``@00/0100?1@P06@hB00P00@0C20`050T=00P00@0?10P05``@
01462P0N4aL01`0001<8300D2@d300h31`803@8600<0304500l4200?10P0100?10PDooooo`006ooo
ool03P0>40/04A<>00h@2`0>40/04Q@?00lA300=3`X04aD@01@F4@0A4`h03a4<014C3P0<3@P03Pl:
0P0@4@`06P0>3`X030d8024R7@0<3@P04Q<>00X;1P0=3PT04a@?018C3P041@0030d801XK5P031000
004001/L5`0:2`H02@X501PI500@4@`04A8=00l?3@0=3@/030`:00d=2`0@40h04Q8@1P0A4@l200l@
2`0:014B3@0<3@P01@L200D70P0B50l03A8<018G4@0k@3X0>T4j014D40803`l=00@03Ph<00d=2`0=
3@/03@d;1P0>3P`300l?3@0K00h>300=3@/03Ph<018B400A4@l03Ph<010@3P0?3`d03Pl>00lA400I
6aX03@h=024S8P000@005QPG00<510000@004Q@C01/M700F61L03Q0>00/=2P0@4Pl07R0M018D4@0<
3P/04A<@00<030h;00/02@/800h@3@0A4A403`l?018B4P0@41002@T900X:2P0=3@d03`l?010@4002
00d=3@0301@D500>3P`03Ph<00<03@d;00L030`:00l?3@0<30X030`:014A3`0C4a404A4?008030`:
00P03`l=018B400@40h01@D300P81P0A4@l020P6010@3P803@d;00H04A8=00`=200;30L03Pl:00l@
2`0;30L200`=20803@h90P0>3`X0200;30L03Pl:00X;1P0:2`H03a0;00`=200;30L03@h90P0@4@`0
0`0>3`X02``700`=1`0200`=1@0<00d>1P0?40P03a0800d>1P092P802P/300d>1P0:2`<01PL001@E
3`0>3`T030d70`0=3PP06@0B4`d061TC00`=1`0<3@L0414;00L:0`093`P04AP@07Z1N@1JGeP03A8;
00X?200J7AH051D?00h?2@0@4@/02``6014B300;30T02@X502h_:P0J6aH0`<6l01lP6`0?40/00`0<
3@P0<P0;30L01`P300l@2`0Q8Qd02P/600T:1@061`803Pl:010A300E5Q403a0;00P9100@4@`01PL3
020Q700G61<0414<01@E40010P003@h900l@2`0<3@P03a0;01DF4@0F5a805AH?00h?1`0?40X030d7
0000001FEUH04a<C010@3P0C4a407b0K01lP6P0H6@d0:bX>03Lb4P1CC2T0N6m80;JZPP3`h[/0_;2:
061H=010?B<0<S0Q071bI`0P9Ah04A8=0P0@3`/0100B4@d04a8>014@300?3PX2010?2`0P00h=2@0?
3PX051<>00H8001@DT@0QhU`0?kng03ooml0WIUj02lY4`0Z91@07AXA01HC3P0D4`h04Q@>00lA300>
4`l03A8>00lA3P0?40h03Ph<00T91`061P@01@@2010<2`0a;B`0CTY901/G5P0D40l05a<B010<2`0A
3@`2010<2`804@d<01l040`;00l;2P0;2PP030/7010A300:2`H030d801@E400S91l05aPC01HG4P0?
40/020T401@E400L7AP0GEeM00l?3`092@T05QHF00/;2`0?3`l04Q8B01PH600:2PX02`/;00`<300=
3@/03Pd900`;1P0N7AP03`h:00804A0<02004a8@014?400A3a004Q0C01<A500B4Q80;Rl^018D4`06
20L01`T600<5000?4@`05QTB01<F3@0G6Q402@`302<V6`082`005AP?018E300A50/04QD<018H3P0?
5P`03aL<018J3`0H8AH04adB00`F2`0?6A802QDA018M6@8041/G00P00Pd901`W8`0?6QH07BPT00PC
3`0G8Qh051lK014H5@8051TE00X06QlK01`Q7@0G71P051TE01<H500A5Q804QLC01<H500@5A404ALC
0P0C6AD01P0E6aL05adI01HL600D6QH05Q`H01LM6@804QPD00@05adI01TO7@0H7Q`05adK0P0I7ad0
7`0F7ah041XI01@N7@0H8R<04alO01DQ8@0S;S00;S`m020^;`0M:b`07R`_01l]<00`?T40>DA:05=N
I02jaL/0[kW208>=UP18E5/0?De=03=3@P0X>3P08c<c01h^;P0R<C@0<T56041?E00Z>D007Rdd02He
?@0G9Bh00P0R<c/08`0S=3/093Hh02Dg=`0W>SP08cHd02Tk>P0J;2`0;d5302i0A00]?TH0;Ce:02Xj
B00Y>T@0:CY202Xl?`0]?cl0<TE302Dh=00X>cL0;d9002m1@00[?S`0<40m02dm>@0^?cT0;Shk02`l
>@0`@3l0:SXi03A4A00c@d<0;clo02lo@00]?Cd0<TA30080<49200@0<TA403A6B00gBD/0=DM;0`0f
Adh0400cA4`0<TE;03]@CP0fBTP0<4A20396A00cAT@0;T4o03E8AP0a@D00=DE403A4@`0`?Sh0=492
0310?@0b@Sl203=3@00m03A4@@0gAd@0>DU603=3@00b@Sl0=4A103=3@00c@Sd0;SP`02`f;P0`>S80
92hV020Y900Z<bh0;SLb02lh=@0S;2T09c0]02`e<P0l@d80=3dl024Z:@0R;Rd0:cTj02dl?`0]?D40
8S@h03Q7CP1ULW`0AU9N03<mB@0gA4d0=TE:0350A@0_?T80;C`o02Tg>P0b?T40@Te?03U4AP0^>3X0
7RPY045;C01[M7@0;3Dd028[:P0T;B`09Rl^02@]:P0W<2d0:S<`02Tb;@0V<2P0:38Z02D_:00M9bH0
;SPi0:bf]@2IXZ40>T=2024Z9`0201hT8P0:01hS7`0J7a/06QlK01dR7@0A5AH0GV9U028V:@0A5AH0
4QHG01`P7`807R8Q00/07R<O01lT7P0O91h07R<M01`N6`0K7AX07b4N024S800O8Ah0828O01PJ5`02
01TK600601PJ5`0L7Q/0828O01`N7@0J71/05aTH0P0F61L07P0G6AP06A/J02LY:00^<2l07AlN00d?
3P0Q8b807alQ01PH6P0G5aT05QHH01@D5P0H61X09RHX01`L7P0?3a406ATK01hN800>3a403a<B014G
5P0=4QD04aPL01TL8P0J7B@04aHM01LG7P0G61d05ADH01@D50805ADE0180410@00T92@0I6AT05aLG
01hN7P0;2`/051@D00l?3`0>3Ph0820P01LG5`0>30d0518C01LE5P0A3a005aDF014?400D4Q<2014?
400801<A4P0A3a0040h?00h<3`0B41<06ALJ01HD5`0A3a8201DC5P0H01<A50091`X03`d@018@4`0@
3Q402`T<01<A500H5QT0NWQk0:2NX@0B41<03P`?00d;3P0>30l04Q0C01DC5P0U8R@06aLH00l;300@
30d04`l@01DA4P0>2P/03@T:0`0>2P/00`0@30d04@`=00l92`0400l92`0300h82P0=1`T03@L900D0
3@L900L03PP:010:300@2P`03PP:010:300=1`T050h@008091hP00<04P`>00l4200:00<00P0?10P0
2P0C20`0304500d21P0>0`L04@L:01872`0<0@D050T=00/0100<0@D201462P0A00d21P0@1@T07Q<G
01462P0<0PD040D900X00`0800404@H:00h31`0;0P@05``@01@93@0A1PX05@X>00L0000d:Bd00P07
00000`0@1@T03`@800l4200200h31`803@861P0?10PDooooo`006oooool03P0:30L03Q0;00`>2@0<
3PT0418=00d?2P0<3PT04A<>018D3`0?4@`03Q0;00lA300=3PT03a0;0P0@4@`06`0?40/03@h901@E
400@4@`06a`G00X;1`0<3@P04a@?00`=200?40/03@h900h?2P0=3PT06Q/F00`=200N7aX06a`G018C
3P0@4@`020T4014A3`0?3`d03Ph<00l?3@0B4Q004a<A010@3P0300h>300>00l?3@0@40h03@h9010A
300A4Pd02``701DG4P0U9b804A<>00L<1P0O91h051TC01XQ6P0=4@`200l?3@803Ph<00<03@d;00h>
300>3P`01@0>3P`300l?3@0600h>300=3@/03Ph<018B400A4@l03Ph<0P0@40h05@0<3@`020X900P:
2@0A4a80Bde<01PJ6@0;3@`02@X902<U900c=C@071hM01TK6P0=3`d03@l<00h@3@0=3``061TG06AV
H`0?4@h030h;00/=2P0200d?300500h@3@0=3@d02PX:00/;2`0@41000P0B4Q80100820P02`/;010@
400>3Ph200`<30803`l=00D03Ph<00d=2`0<30X030`:00d=2`0200`<2P804A4?00<03`l=018B400?
3`d00P0<30X03P0>3P`04Q8@00X:200?3`d03Ph<010@3P0B4Q003`l=00h?2P0<3@P02``700d>2@0>
3`X03@h90P0<3@P200d>2@<03Pl:00/04A8=00d>2@0<3@P0414<00h?2P0?40/04A8=018C3P0@4@`0
30d800/<1`0200d>200700`=1`0=3PP03a0:00l@2P0>3`T02P/500d>200201<D3P0>010A2`092P@0
2@X400`=1`0?40X03@h800/<1P0G6180824K01<D3P0;30H03a0:00`?200>4P/200X?200Z00lD3@0?
4P/03A0900lB2`0<3@L020T300h?2@0<2`H04a8=00l@30092PD020T600h?2P0D5A003@h900`=2009
2PD02``700d>2@0>3`X05aPC00`=200?40/0414<00l@2`061`804A8=00d>2@0R8ah03a0<00/<200B
4`h04a@?00<40@0720<0414<00d>2@0@4@`02P/700d>2@0:2`H02``70P0>3`X06`0A4P/03a0800T:
100?40X04A8=010@3`0H61H051@B014B3P0O81/09BHP01`M4`0T8Pd0;BX@03Db5011?1`0FE8`075Y
A`1SFc/0>cDH034_6@0M7Q404QH>018H4P0B4`h04Q4=014@300201<B3P03018A3@0@3`/04A0<0080
4a8>010051<?01PG4@0W:QT0=CTQ08B7IP3gn=<0ko3807UhD`0`;1<09B4>01PE2P0G5@`05aL=01HH
3P0=3`X030l<0P0?4@h02`0<3@X030`:00l?3@0B4Q004a8@014@3P0B40h05a<B01dI600?2`X05A4@
00804@d<00<040`;01PD4`0E4A000P0A3@`0500D40l05A@B01DE4@0=3PT030d801PI500:2`L061TD
01hO6P0:2`L0414<00/<1`0F5a805QHC01TI600?3`l04A4A00h>3P0;2`/030`<0P0>3Ph02`0M7Ad0
51@D01TI6@1;BdT06APD00T8100C4Ph04A0<00`;2@0F5A<051<A00@04a4B01X04Q8A01@F500`<Rl0
7R0M01<E4P0?4@`051HA03e0>@0I71D00`H001TL4`0@4`X04A@;01PK500D5a004A@=010C300@5@h0
3Q@=020W7`0B6A40O8Al09fWWP0h@ST05R0I014J5`8041TF00@0624N014J5`0E7Q/04a`I0P0@6AH0
1P0B6aP03AHC01<K5`0C61@04QLC01<H50@05a`H00P061dI01hS7`0N8al061dI01LM6@0H7QX051XF
01<I5@805A/G00<051XF01DK5`0I7a/00P0H7QX01`0I7a/05adK01HL6P0F71X05b0M01TR7`0H8R40
0P0I8b801@0G8b<06BDU01`X:00G8R@072X[00807bd^02X09C<f02Le>00oCE00Gfab09RUZ`3^nO`0
joSl0>;^lP28UY`0A5=F03U9B@0Y>CT08S4d020_<P0Q<3<07bhc02dl@@0P;c@08C0g03A3BP0`@4P0
8c@n02Hg@P0V=d009SLo02Pj?P0V>3T0:S`m02Dh=`0Z?C`0;T1002Dg>00^?dD0:CY302loB`0/?DH0
:3U102/m@00^@400;d5002Dh=P0X>cT202i0@00C02do?`0a@D00;Cdl02lo?@0_?ch0;3`k02lo@00_
?T00<d=502hm@@0]?400<T5503=2AP0bA4D0<dE50394A00fB4X0>Ta>03U;C@0203E7B`0E03I8C00g
B4l0=dQ?03I9C@0iCT`0?U9@03Y>C00eBDL0=DQ603A7A@0gBTP0=dM603U9B019FEP0<T1003E3@`0d
A440=DE203A4@@0fAT<0=dM40080=DE20P0a@Ch00`0dA440;cll02dl=`0202`f;P0R034k<`0W<BT0
7bPS02D^:@0Y<Rd0;CHc02L`;@0J8b006b@Q02H^;00S;2/082PZ02D`<@0/>S/0;Se003A4B00Z?400
?4]B04mMI@0gA4d0=Cm;03=0B00Z>Ch09SDh04]JG@1NKG00?de>02hj?00Z=CL0<clo02/f=P0S;Bh0
<cdn030j>`808R`]02X09Bl_02<];00T;Rd09S4]02Td<00X<bd09C0Z02Lb;00S;RT0:S@c03Q2@`2S
[:`0S9FD02lh=`0T;BX07bDS01hT8P0M8Qh06QlK01/P700O91l0:2`]05QLGP0a=CH08BDV01dQ8P0Q
9B@07R8Q01lS8P0P9B407R<O01`Q7@0K81/092HS01dO700O8Ah09BLT020R7`0N81d06A/H01`N6`0K
7AX301TK600=01dO7P0L7Qd06A/J01TK6P0J71/071hM01DG5P0I6aX092HU01TK6P0O8B0051HE01XJ
700201LG6@0301HF600D51H06QXL00805QHH02<07AdO01HF600E5AL04a@F018E500C5aL03a8D01XL
8@0J6R405aLO01<C6`0G5A`05Q@J01LE600G5AH05Q@E034a<@0V9RH03`l?01LG5`0H61P051@D02`/
;00G5aL03`l?010@400I6AT03`l?014?400B41405Q@E00l=3P0C4A8040h?01@B4`02018@4@0>01<A
4P0B414040h?014?4P0?3A004@lB018@4`0?3A0040hA018@4`0:20/030X=01DC5P0:20/2010>4@0A
014?4P0H5QT0BTQ;069PH`0D4QD03`d@00h<3`0=2`h03P`?00l=400C418030P900h:2`0?2``03@T:
018>3`0=2@X00P0?2``01@0<20T02PH700`82@0@2`d040X<00@03`T;00<03PP:00d72@0=1`T00`0=
1`T0<@0?2@/03PP:00d72@0?2@/040X<00d72@0C3@l03`T;014;3@0L5QP06aDG00`6200=10H02`84
01P=4@0@1@T05``@01062@0D2@d040D901462P0F2`l03@8601462P0;0@@0304501872`0@1@T03045
01052@0;0@@04PL;01052@0B1`/07A8F01@:3@09008060dA01D:3P0;0@@03`@801<8300?1PP04@L:
040e>@0J41<04`T<00d41P0@1@T00P0?10P300h31`H03`@85?ooool001_ooooo00h02@/600d?2P0;
3@P030h9010B3@0=3`X030h900d?2P0?4@`04A<>010B3@0=3`X03a0;00h?2P803@h900T03Pl:00l@
2`0;30L00`@000T:1@0=3PT05AHA00l@2`0>3`X00P0@4@`02P0G61<03a0;014B3@0O81/0XJ:M092A
S00O81/05aPC01<D3`0>3P`200l?3@<0410>01<03`l=00d=2`0<30X03@d;00h>300?3`d03Pl:00/<
1`0=3PT02``701LI500[;BP04A<>00/@2P0D6A<0<CH`071gL00H6aL03@d;00<03Ph<0P0?3`d600h>
30<03`l=00<03Ph<00d=2`0=3@/00P0@40h04P0>3P`04A4?014A3`0Q8R00;Bl^01XL6`051PD02`d<
00P:2@072@P06A/J00P:2@0=3`h04A<B0001000B518030h;01<E4P801`T600@0=SPe00`>2`0<3P/0
3@l<0P0@4Pl01P092`P03`l?014A4@0@41002`/;00X:2P<02`/;00@03Ph>014A4@0A4A403Ph>0P0@
40h0200?3`d03@d;00`<2P0<30X02PX800`<2P0?3`d03Ph<0P0=3@/200/;2@0501lO7@092@L020P6
018B400>3P`00P0?3`d02@0:2PP03Ph<00L71@0;30L03a0;00h?2P0;30L03@h9018C3P0200`=2080
3@h90P0>3`X02@0@4@`04Q<>00`=200<3@P03a0;00`=200=3PT0414<00l@2`0200`=200300d>2@0>
3`T03Pl9008030d70P0=3PP09P0:2`D06AXD01TJ500@4@/03a0:01@E3`0>3`T030d700d>200?40X0
30d700X;1@061`402@X400X;1@0<3@L0414;010C300:3PL03A8;00/@2@0>4@X01@P101<F3`0<3@L0
30/600/:1@0B4@`03Pd801@C3P0;30L06Q/F00D60@0A4Pd00040014B3@0?40/04A8=0P0@4@`0100E
5Q4071dH00h?2P0@4@`200`=200>00<4000>3`X07AhI04Y;AP0D5A00004000T:1@0J6aH03Pl:00l@
2`0C50l04A8=01<D3`0<3@P3010A300M00h?2P0?40/030d700/<1P0H6A@05aPC024R7@0:2`H061TD
014B3@0=3PT04A8=01DF400I6Q804A8201DG0P0J6@D0;R`C03`h6`13?R40@ShS03@b6`0D50L04aH;
010E3P0A5a<04Q<>014@300@3`/00P0A40`0100>3@T040l;01<B3P0H5a<201TH500?01/J500M7P`0
:B/C034e501PHS/0Q8IN03Xk6@0S8@X071X;01@B200;2`<020P001@D2`0>40/030d;00804Q8@0100
2`/900d=2`0J6QP04Q8@00T91`071`D02@T700X91`0@3`d04A0>020O7@0E51803@`:010?3@0?3P`0
3@`:0P0:2@L06`0=30X040l=00X:200G5aD03Ph<0082000J6QT0YZJT08N7Q@0_;bd061PF00T91`0>
3P`04Q8@01LG5@092@L010@200`<2P0B4Q004A4?01LG5@0410804Q8@01PH5P030`4061PF01DF4@02
00T:1@05028R800410804Q8@018B400C4a400P0B4Q02010@3P0;01HH500:30L00@<001XL5`0H6QD0
418=01@F4@0A50d041<<00/>1`0N8AX00P0D5a008@0B5@h04A@=01<F3`0B5a003A<<01hU7@0I81P0
TYZB0:jh[`0kAC`04Q`E00`E400?61<0624L00XC3P0<5A00214<01XS7P0?61<03QLB01XS7P0E7QT0
5QdI01XP700M8al06b4M01LM6@0J81`05Q`H010F4P0C6AD061hJ01TO6`0201HL600301LM6@0D6QH0
5A/G00@05Q`H01h05adI01XP700J81`061hJ01HO700D7AX05AhK01LP7@0H8Ah05R0O01/U900J9R@0
5b<S01PV9P0N;2`05bDV01<Q8P0K:BX0528S02@b=@0`?T40D5iQ07Z9SP2Z^Kh0jOOi0>kmo`3?g^D0
Lh>90394AP0]?d4202@f>00:02Dg>@0P<S@07S0d02Li?@0P<SH09CLk02i0A00^?dH093A102PjAP80
9SQ203T0:Se302@g>`0Z?Sl08SHe03A8A`0Z?S`0=4Q602Xn?@0X>D00;Sm702dnAP0/?D@0;T1302Tk
?@0Z?3h0:3Xj02`n?P0]?cl0;d5103E7A`0_@D40;Clo0312@P0_@D<0:C/m02Tk?`0_@DD0<D=702ho
AP0`@DP0=TM>03=4B`0dATP0=dU;03E7B@0hBT`0>Ta>03I8BP0dATX0=DM;03I8C00hBTh0>D]?03U=
CP0cB4H0>De;03M;B@0hC4X0>Da:03E8AP0fBDL0=TI503Y:B@1=GE`0<Clo03U7A`0b@Sl00P0_?c`2
03Y:A`1D0392?`0dA440?Ti;03];B00]?CX09cLd02Xi=015CdL0<S`d02/e;@0X<RX08b`W02D^:@0W
<2/09Rl/02L`;@0]=S<09c0]02L^;@0Y<C<08RX]01lZ;00W=CH0;C`o02lo@`0[?D40>TU@02`j@P0_
?4@0@D]E030mA00a@4<0:cXm02dl?P0`@400;S`m02ll?@0T<300:CDe02Xe=@0^>3L0<C/j02La<@0Q
:b`09Bl`02Tc=00T;Rl092h]02H`;`0X<bl09c8^02<^:00U<2X08B`W00hH5`0J92D0=d5003M0?`0S
;2/082TV01lU8`0N92807B8N01/P700L8Ad08RLR04E9B00T:2T07B4Q01/O7P0M8B008bLV01`P7`0N
8R407b<R01`P7`0K81`07R<O01hP7@0I6aP071hK01dO700L7Q/0<38_0P0N81d01P0K7AX06A/H01/M
6P0N81d07AlN01`N7@806Q`K01T071hM01hP7`0J71/061XI01`N7@0N81l061XI01HH5`0E5AL05QHH
01XJ700H61X05aLI01dM7`22PX@0;Bd_01<C5@0B4Q@071`N01hN800B51<051DF01TI6`0D4aP040lD
00805a@K01H05a<J01<>500J5AT07ATJ01DD4P0D51@00P8201`L700?3`l03@d=028R8P0W9bL06QXJ
01/K6`0H61P04Q8B020P800B41403@/<01<A4P0B41405Q@E0P0C4A82014?400=018@4@0A3a003`d>
00/9300=2`h03`d@018@4`0C4A@04Q0C01PF6@0A3a8030X=00X82`02014?4P0701LE600:20/02`X<
02LU:00@3Q402`T<00d;3P0200`:3@802`T<00d030T;00X61`0@30d03`/<00h:2`0C3a003@T:00h:
2`0?2``030P900/7200@30d04`h?008040X<00<03`T;00h82P0>20X01P0?2@/02@0C3@l04@/=00/5
1`0=1`T03`T;00`6200?2@/03PP:00`6200300X41P0;01X?4`0D2@d08AHJ00T00P0C20`05@`>0187
2`0;00@03P@701P=4@0=0PH00P0>0`L04@0A1PX03`@800`11@0=0PH03P<700L0000<0@D0308500`1
1@0B1`/03`@800h31`0700003`H800l4200C20`0200100804`P<00@02`0400L0000C20`04`P<0P0@
1@T200l420803P<71P0?10PDooooo`006oooool02@0<3PT0418=00h@2`0?4@`051HA014C3P0=3`X0
2`d800h@2`0201<E400300h@2`0@4@`03Pl:008030d800<03Pl:010A300B4`h00P0B4`h04@0=3PT0
4Q<>00P9100F5a8051D@00`=200?40/03Pl:01LH4`0[;2L0kNkY0=;CcP0N7aX03@h900l@2`0=3@/0
3Ph<00803`l=0P0>3P`0100?3`d03@d;00`<2P0=3@/200l?3@0<00l@2`0<3@P04Q<>00X;1P0620<0
3a4<010B3@083@L041D?00lC3`1CFU<03A4<0P0=3@/0100>3P`03`l=00l?3@0?3`d600h>30<03`l=
03403Ph<00d=2`0<30X03`l=010@3P0>3P`04A4?018B400D5A@03a4@00<5100D5QD0418A01DG5P0B
51<02`d<00lA400;3@`0418A01LI600A4a403@l<014C40092`P03a4>01<E4P0?4@h03Q0=00/=2P0>
40d04Q@A010B3`0820P03`l?018B4P092@T01PH600/;2`0A4A403Ph>00`<300?3`l0410@00d=3@0A
4@l0410>00l?3@0>3P`03@d;008030`:00T03`l=01<C4@0?3`d03@d;00h>300<30X05ADC03lo?@0M
7A/00P0=3@/01`0?3`d0410>018B400;2`T04Q8@00X:200:2`H00P0A4Pd00`0<3@P03@h901HG4P02
00`=20803@h90P0>3`X030082@@02``700P910092PD03Pl:00`=200:2`H03@h900`=200:2`H02``7
010A30803a0:00/03@h800`=1`0<3@L030d7018C3@0];RP0:R/U014B300=3PP05QLA00l@2P0200/<
1P803@h802P030d701<D3P0:2`D03Pl9014B300:2`D02@X400T=1P0@5@h000D000hA300B5@h030l8
00h?2@0=30L02`X500l>2@071P4030/601HG4P000@007b0K00L81@0H6A@02@X500`=200?40/02``7
00T:1@0?40/04Q<>00l@2`0J6aH030d8018C3P0=3PT051D@00X;1P0[;2L03Pl:0P0?40/01P061`80
5AHA010A300=3PT05AHA00d>2@8030d803403a0;00h?2P0;30L03@h901<D3P0E5Q00824L00@50007
20<051D@014B3@0E5Q405aPC01HG4P0>3`X04a@=018D1`0L7`h06QX801/J1@0L6P<0:RPA02TW4P0f
=B405QL900@7000G71H0318>01PH5P0G5Q805A@@01HE4@0E51004Q4=00d<200A40`061LC01XI5@0I
61@06ATC01<D100a<ad06A`602//2P0T9@<08R@8018A000C4@D05a<>008040l;00H0:bXU010A300>
3P`051@B01<C4@0<30X200h>30802@T700T03@d;010@3P0?3P`03`h<01/J600^;B/06aXH00/:200A
40h01@0>3@/07`0?3P`071`J00D50`092@L06ATG00/;2@1EEE<0H61N00`<2P0A4@l03Ph<018B400A
4@l0410>01lO7@0Y:BL04Q8@00T91`0A4@l02@T701XJ600=3@/04a<A0041000A4@l03a0;01DF4@0G
61<0?Shl00`<2P0D51800`0@40h0100?3`d03@d;00d>2@0:30L201HH4`0Z01DG4P0:30L04Q@?00d?
2P0I71D04A@=01`O600=40T0:bhW010C300A50d04QD>01@G400D6A805A/C01hU7@0;4PX0;CD]03Do
=P0D7QD08b`V01PQ700=5Q403aPC018K5P0K91l03aPC01dV8@0>5a807RLR01PQ700>5a8051/G01XP
700V;2P092XV01HL600?5A403A<?00lE4@0A5a<051XF0`0F71P201@J5P0_01LM6@0I7a/05adI01PN
6P0G7AT05A/G01PN6P0I7a/05Q`H01PQ7P0F7a`05AhK01LP7@0F8Ad051hM01@P7P0E8Al04AdM014O
7`0I9bL062HW01<Q8P0V=3D082h_024_<P0U<cH0BUUL05ASJ01YN7d0a]GJ0>[io`2GZ:l0AEIM02i0
A00X>S`07S0b020b=00V>3X09cTk01`^<P0R=3P07c4e02@f>P0S=CT08C8i020b?P0W>DH00P0T=T80
400X>T<08SDk02i1A@0O<c@0:cln020d<P13Ee@0;D4o02do@`0_@4P0;Sm603=5B@0dATT09SPj02Tk
?@0Z?3h202i0@0040312@P0iBd/0;T1002i0@@80<dE700/0;T1302i0A00_@DD0<4970352B@0eATd0
>DYB0393BP0fB4/0>Ta>03M9B`0203U;C@0303=5A`0iBdl0=dU=0080=TQ<06L0=dU=03I:B`0gC4X0
=4Q60396A00gBdT0=dY80313@@0hBdT0;cln0351@010D4l0<3hn041>CP0fAT<0<D4n0392?`11DDh0
@e=@03Q8A@0gAd@0=DE20392?`0/?3T0:CTf02Xi=00a>c<0<cde02Pb:P0L9Qh07RLR02H_:P0W<2/0
8b`Y02H_;014CDX0?DI3024X:@0M9BL082P[02Td=P0a?d00;3/n02Ph?00^@4@0;ci503Q6CP0b?dL0
9Bli02Tf?@0^?D00:3Lj02hm?`0c@d<0;S`m030m?@0d@400;CTi02/f=@0T;Rd07BLV02Tc<`0O:BX0
8B//02Pb<`0V<34092h]02D_;P0X<S409S4]028]:@0T;bT082/V01dW9P0R;2d07bTX028[:P0J8b80
7RLT01lU8`0N92807B8N01/P700M8Qh092TT01XN7@0Q9B@06alN02``;`0Y;B`05QXI01dQ800O8b80
8BDT01hR8@0O8b8092PV02@V8`0P8Ql07R0M01@F4`0A4a00<C<`008071hK00/06A/H01XL6@0Q8b00
:B/X01`N7@0K7A`06A/J01XL6`0L7Qd07R0O01/M700201TK6P0^010B4@0H6QT03Q0?01@D5P0G5aT0
71`N01/K7@0I6A/07alQ055AD`0I6A/09BDW024Q8`0F5QP04A4A01PJ6@0M7Qd05aLI018A5P0N7280
3``C01/H7`0I5A/050lE01hI700Q7A`061LE01@C500I6AT05QHF01DE5@0X:2P04Q8B01PH600F5QH0
4Q8B01@D500m?Cd0OGem028P8@0D4Q<05aDF014?400@3Pl02`T:01<A4P8040h?01404Q0A010>3`0?
3@h03`d@01<A500B41<040hA00d;3P0:20/03P`?014?4P0?3A00518E01PF6@0@3Q400@0201<A5002
010>4@0?00H41`0B41<03@/>00d;3P0>30l03@/>00`:3@0?30h030P900h:2`0<20T03@T:018>3`0:
1PL030P9008040`=00<04`l@01XF5`0I51D00P0@2P`0100?2@/03PP:00h82P0@2P`5014;3@0T01D?
4@0B30h02P@600/51`0>20X030H800T31@0>20X04`d?010:300<1PP02`D700X00`0700006@hB00L0
000I3Q80:QlS01H;3`0>0`L04`P<01lD600D2@d04`P<00l4200C20`03`@800`11@0C20`04PL;01<8
300@1@T04@H:00h31`0;00@03`@80P0<0@D02P0C20`03@8601`B5@08004040D900/1100@1@T060dA
00/1100B1`/201052@803`@80P0>0`L600l421Cooooo000Kooooo`0<010B3@0C5A004aD@04U;AP1Y
JfH05ALB01@F4@0?4@`04A<>010B3@0<3PT0418=0P0C50l0@00B4`h04A8=00h?2P0<3@P03@h901@E
40092PD04Q<>01LH4`0=3PT06Q/F00l@2`0>3`X04Q<>014B3@0=3PT03Pl:038c;P0j>cH030d801TJ
5@0720D03Ph<00P81P0H61H04A4?00/;2@0<30X06ATG01PH5P0820H04Q8@00@40P0>3P`0414<00d>
2@0<3@P03@h900lA300@4Pd02`d800lD3P0;40X02Pl900XA2P0:3@T03`l=00/;2@0I6AL04a<A00L7
1@0B4Q003`l=00h>300@40h04Q8@014A3`0<30X04A4?00T91`0@40h02`/901HF500;2`T200`<2P05
00l?3@0<30X030`:00l@3P0?4A000P0A4a80300>40l03@l>00`>3@0C5A@02@/:014C4P0=3`h0418A
00d?3@041@<0418?00P:1`803@l<00d03a4>00/=2P0?4@h03Q0=00T;200I6aP0=cLg00T92@0>3Ph0
2@T9010@400=3@d02`/;00803@d=0P0<30`04`0?3`l03`l=00h>300>3P`03@d;00h>300?3`d02`/9
00h>300@40h03Ph<00d=2`0A4@l0410>00/;2@0J6QP051@B00l?3@0=3@/00P0>3P`03@0G5aD0EEEC
01XJ600?3`d03a0;018C3P0720@00`@100d>2P0B4`h0414<00h?2P0=3PT00P0>3`X200/<1`0800`=
200=3PT03Pl:00h?2P0=3PT02``700h?2P0?40/200h?2P0900l@2`0<3@T05AHA00d>2@0<3@P04Q<>
00D60`0=3PT03Pl:00@03a0;00<02``600`=1`0=3PP00P0>3`T02@0=3PP03Pl900/<1P0>3`T03a0:
00`=1`0@4@/08bHO00lB2`0200/>1`0;00/<1P0=3PP030/6018A300=30L03P/6014>2@0=30L03a0<
00`=200A4Pd00P0=3PT200l@2`0;00h?2P0=3PT03@h900`=200:2`H0DU=>04M8@`0?40`03Pl:01DF
4@0@4@`01P0=3PT200h?2P0401<D3`0N7aX061TD00l@2`804A8=01h03a0;00d>2@0?40/04Q<>00l@
2`0>3`X04A8=014B300D5@l05QLA01<D3P0@4@`03a0;00h?2P0@4@`04QD=018E2P0D5PT05aP801XJ
200N7P`07Qh=01/L3@0F60/04A@=00lD3P0?51005aLD00d<200C4Ph6018A3@0f01<B3P0D4`l051<?
01PH400F5`X06Q/801`O1`0I70@06Qd;00h>1@0>3@X04Q0C014?4`0A3a407ahL010?3@0;2`T04Q8@
01HF500?3`d030`:010@3P0;2`T03Ph=01<C4@0=3P`02P/900l?3@0A40h0>STg00h=2`0?3P`04A0>
00d<2P0>3@/02`X8010?3@0>3@/04a8@00d=2`0?3`d03Ph<00T91`0<30/030`:024Q7`0A4@l07QhL
020P7P0A4@l05ADC00h>300N7Q`07alM0P0=3@/01@0E5A<04a<A014A3`0@40h03`l=0080410>00d0
51@B010@3P0F5Q@06QXH01<C4@0@40h05ADC01hN700E5A<04A8=01@E400D5@l04A<=00804QD>00<0
4A@=00lA300>40/00P0B50l04@0@4Pd03a4<01<E400G6A@051HA01LI500D5Q406adH018G4@0C6A80
4QTB010G400C71@051hF014K4`0A6A<04QPD00804ALC018051XF01HL600F71P05A/G01LM6@0E6aL0
4QPD01<I5@0C6QH03QLB01/T7`0]=S404a`G00/D3`0F7aX04a`G01@M600G81/201@M600401@L5`0D
6QH05adI01PN6P<05Q`H00P05adI01TO6`0I7a/061hJ01HL600D7AX05AhK01DP70805R4M01T05R4O
01<O7@0D81h05R@T01PV9P0I9bL072X[024/;P0N:B/092la020^<@0Z>3/0:3Lj03=4B00hBTh0G6mc
06AfO01DIfd0>4]A02Hi?@0Q<cL07c4e028d>00Q<cL08S@h00807Bla0P0T=SP08P0Q<cD0:ce202@f
@@0W>DH09cU502HhA00V>480:3]102Lj@@0Y?4009c/k02Di>00V>cP0:Shl02Xl?P0Y>d00;T1402m1
A@0/?T80;d550353A`0a@dH0=DM903=5AP0`@T80=dU903mAD`1:G5h0<D=503A6BP0bA4P0;3i202ho
AP0Z>d<303Q9D@0L05=TJ`22U9T0=DM;03=5B@0eAd/0?U1D03U;C`0eAdT0>4Y<03U;C@0hBT`0=DM9
03=7A`0dBDL0<dM503U=B`0fBTP0@eID03=6A00gBTP0@U9A04ADD`0jBTT0>dU903E3@`0gAd@0=DE2
03I6@`80>DU604D0>4Q503];B00iBDH0>d]803=3@00[>cP0;chi02hi<00/=Rh09BlW024[8`0T;BP0
9RlZ02Xc;P0]=S<08b`Y02Tb;`0N9b@0;C@e02<[;P0K8RP09c8f02lm@00]?3l0=DI902/m@@0`?d@0
;3Y002dj@00/=Sl0;S]002dm?@0a@D40;clo02`l?00fA4@0:cPh02@`;`0W<c40:SDc02Pb<@0Z=C40
92l^024/;P0X<cD0Ef=T02/g=`0T<3009C4_020/:P0R;R`08bl[024]:@0K9b<08B/[028/;@0U;bh0
7bPW01dV9@0`>CH0:c4_01hT8P0L8Ad06AhJ01dR7P0P9Al07R<O020T8P0R9RD00P0P92<02`0R9RD0
CU9A04U=C00S9bH07b<R01dQ800R9RH08R@R024S800M7a`06Q`I00@06A/H01007AlL01/M6P0K7AX0
9bTV01/M700H6QT05aTH01TK6P0K7A`061XI01HH5`0H6QT06A/J01PJ6@0F61L051HE0P0C4aD01P0E
5AL06QXL020P8P0H61X06ATK01PH6P805aLI028061PJ01TI6@0E5aD061XH01XJ6`0I61`05A@J018?
5P0D4AP061@J01D@5@0F4Q<061@C01@C4@0C4Q<0410@014A4@0F5QH05ADE01<C4`0E5AD05QHF010@
400C4a<09BDU08R8R00P7Ql020H700h<3@0B41403`d>01@B4`0A3a004Q0A100A3a00100A3a8040hA
010>4@0@3Q4200l=400300d;3P0A3a804@lB00803`d@01003@/>018@4`0@3Q4040hA014?4P0<2Pd0
3`d@010>4@0>30l02PP;00h<3`0?3A0030T;00l;300>2P/02`L80P0A3@h05@0>2P/04@d>010<3@0=
2@X03PX;00l;300?2P/03`T;014;3@0F418040X<00`6200A2`d05@lA01@>400@2P`03@L9010:300A
2`d03`T;00h82P0200d72@0700h82P0?2@/03PP:00h82P0=1`T03PP:00l92`0201052@0:01H;3`0>
1@L04@H:01462P0G3Q00=b``01062@0E2Ph0304501462PH040D91P0?10P01P0A1PX03`@800l4200A
1PX04`P<01462PH03P<700<03`@801462P0A1PX00P0?10P01`0A1PX02@0201`A5@0C20`02P0300l4
200;0@@05?ooool001_ooooo00P010H1014C3P0:30L05ALB02HX8`0620<04A<>00h@2`803a4<00D0
3@l:010B3@0D5A004a@?014B3@0200l@2`0700h?2P0E5Q403@h900`=200=3PT0414<00l@2`0300h?
2P<03a0;02P04Q<>00d>2@0A4Pd04A8=01TJ5@0?40/03@d;00`<2P092@L01`L6028R80092@L04a<A
014A3`061P@04a<A00T91`0=3@/02P/600/<1`0=3PT0414<014C3P0B50l02`d800P=1`0730H02a0:
00`C300>4@d05ADC00d=2`0_;bd0<c<a00h>300=3@/0410>00h>300@40h04A4?0P0@40h03P0G5aD0
5ADC00/;2@0<30X02@T701hN700>3P`02`/9010@3P0?3`d03@d;00h?3@0>40l03@l>0`0<3Pd01006
20L02@/:018D4`0<3Pd200L9200@03m1?`0K7AX03@l<01LI5P0E5a@04A<@00d?30092`P03a4>01<E
4P0=3``0418?01HF5P071`L04Q8B00T92@803Ph>00<030`<00d=3@0>3Ph00P0<30`07P0?3`l03`l=
00h>300>3P`03@d;00h>300?3`d02PX800/;2@0<30X03@d;014A3`0J6QP0410>00H6100;2`T02PX8
00h>300;2`T061PF00L71@030`40;bl]01LG5@0:2PP02``702l`:`0N7aX02``7010A30803a0;00H0
3@h900`=200=3PT03@h900/<1`0<3@P2010A300A00d>2@0<3@P03Pl:00/<1`0A4Pd051D@018C3P0<
3@P020T400@40P0Z:RP02`/901<C4@0=3@/06a/I00X:200;2`T00`0<30X05@0;30L02``600X;1@0:
2`D02``600`=1`0=3PP030d700H70@0Q8Q`01`P300P90`0?40X04aH?00T:100;30H03a0:01@C3P0G
5Q403Pd8018?2P0200h;1P09014>2@0>3@P020P500`=20020`003a0;018C3P0A4Pd030d800<03@h9
00P03Pl:010A300H6A@03a0;01HG4P0:2`H030d800X;1PD03@h90P0C50l0100?40/030d800P9100;
30L2010A30804A8=02803a0;014B3@0B4Pl0410>014B3@0B4`d02P/500T:100;30@03Pl7014B300C
50l04Q<>00l@300=3`X03A09010A2P0C5@X05AL:01PJ3@0E5`T061X=01PJ3P0C50h03a4<010B3`0F
5a8040l;01HE4@0@3`/03@`8010?2`0B4@d04A0<0P0@3`/08P0A40`04a8>01hJ6@0I5A805AD;018D
1P0@4P@04aD:01<E4P0B4aL040lF010=500B41D03`/;01LC4P0A40h0;bh/03<b<00H61H05ADC01PH
5P0K71T03Q0=024S800?4@h02@/800/;2@0D51800000014A3`0?3`d05ADC00d=2`0?3`d200h>300B
00d=2`0<30X02`/;00X:2P0D51@08b<S018B4P0F5QH0410@00l?3`0G5aL06QXJ01<C4`0<30X04A4?
00P910061`804Q<>0P0H6A@05@0@4@`03a0;00l@2`0@4@`04A8=018B400J71X08B<R01<E500=3`h0
4A<@00`>2`0C5A805aTD00/=200<3PT04aH?00lB2`0@4`/04A@;018E300301<F3`03018D3`0@4Pl0
418?00<04aDB00H06Q`I01PJ5`0:30T02@/802/`;00@5Q8201<I5@0:00lF4P0=5Q404AXE018J500A
5Q004QLA01@I4`0F6aD061dG01HK5@804aPB00@05AXD01PM5`0G71H05QhH0P0;50l01`0I8Qd07RLR
02lh<`0/=C003QLB010I500E7QT00P0C71L0100F7QT061hJ01TO6`0H7QX201HL60805adI020061hJ
01LM6@0F71P05A/G01TR7`0G8Qh05R4M01DQ7@0F8Qh06BDS01PW900D8b004R0P01DU900G9bH05bHV
01hY:`0^>C/08Rd_01DS9P0U<cH08C0c02@f>P0V>3`0>4]?03U<DP0dBDh07S<h020c>@0L;cD07C0f
024d>0807S4e0P0S=cP0A00V>S/093Pg02@h=`0]@4@08C@k02Di@`0V>TD09CU402@h@`0U>D80:Ce6
02Hj@00T>C`09S`j02Y0?@0/@3h0:C/k02Li>`0]?d40<TA802m0AP0/?D@0<T=:0353A`0cADL0<D=5
02i0@@0bA4@0Jgn007fATP0]@D80C61Q02i1A00/?d<0<4=702m2A`0_@TP0;T5703M:D@1:GF@0E6E/
02Pi@00cA4/0?4iB0394B00T=SX0>4Y<03U;C@0jC4h0>4Y:03E7A`0cAdH0=DY7049FE00W>cT0>4a:
02m2@00bAD<0=TU704]KFP1>GUd0>d]:03M5A@0b@400>4Q503I6@`0gAd@0>TY70`0kBdP0=00fAT<0
=DE20351?P0]?CX0<3lj02Td:`0S;BD07RPP024[8`0X<B`0<S/f02/d;`0/=C809Rl/02Pa;P0h@Ch0
E5]L024X;P0O9R`0<Ca002Le>00^?D00<T=603E7B`1IJ6d0;3Y003=0AP0d?dD09S@h02hn?P0c@d<0
;Cdl02@d<`0H9RH0934`02@`;P0Q;B/072PT02lj=P0d?c/07bXZ02`g>`0b?Cl0>4=502Pc=@0[=cL0
8bl_02Te=@0P;2X0:SHd024]:`0K9b<202D_<00<02<];00L9B@06R<R02Xc<00U:bT07B<Q024V8P0P
9B4092TU01lT7P0I7QP0724K0P0Q9R80100P9B408RHU02X^;@0[;bh301/O800501lS9@0Q8b80828O
01dO700J71T00P0I6aP01P0J71T06adJ01dO700I6aP05QPE01`N6`8061XI00D06Q`K01`N7@0J71/0
5ALF01PJ6@0301TK6P0:01PJ6@0F61L04A4C02PX:P0P82801`L904M7B@0b<S@04a<E01HF608061PJ
01X05QHH01<C4`0D5Q<04QLB01<E500B4aD04A8E014@5@0F5AX061HK018@4`0B4A004a8@010?3@0B
4Q80410@014A4@0D51@04a<C018B4P0>3Ph02`/;00`<300F5QH071`L000000804Q0A00<040h?00h<
3@0A3a000P0D4Q<00`0C4A804Q0A010>3`0200h<3@0401@B5@0C4A@04Q0C014?4P803`d@00X040hA
00l=400?3A0040hA00h<3`0A3a804Q0C00X82`0=2`h04a4D0P0Q7b8200d;3P0400L5200=2`h03`d@
00`92`803`/<01<03PX;010<3@0@30d040`=00/7200:1PL040`=00/7200:1PL03PT:01<=3`0L5QP0
7ALI014;3@0@2P`0618D01XD5P0H4Q@04P`>00<03PP:00D03@L900h82P0?2@/04@/=01@>4002010:
300@00l92`0>20X03`T;010:300E2Ph03`@800X10`090080200101462P0V6al0?C8f01<8300@1@T0
3@8601<830H040D91P0?10P01P0<0@D02`0400d21P0@1@T03`@800`11@H03P<700<03@8600l4200?
10P00P0=0PH01`0?10P04PL;00l4200<0@D03@8600l4200@1@T05?ooool001_ooooo00L02P`701<E
400<3PT01`T4018D3`082PD03a4<00<03Q0;00l03a4<010B3@0E5Q404Q<>00l@2`0>3`X03a0;010A
300F5a802P/700l@2`0;30L02P/600d>2@0;30L00P0@4@`200h?2P0G010A300>3`X04A8=010A300?
40/03Pl:01@E400<30X0410>018B400=3@/0;Rh/00l?3@0@40h030`:00H6100C4a4030`:00d=2`09
2PD030d800l@2`0A4Pd00P0@4Pd02`0?4@`02Pl900/@2P0@5@l03QD>00P<1`030`406a/I01XJ6007
1`D04Q8@0080410>02P03Ph<010@3P0@40h03`l=00`<2P0410803`l=014A3`0=3@/08R8P05IFE00J
6QP03@d;00/;2@0=3@/03`l=018C4@0?4A0030h=00/=300=3`h03Q0?01@F5@082PT05aTH00X<2`0Q
8b801PP704Q:B00N81d010H300h@3@0A4a002P`9014C400<3P/03a4>01DG500A4a003Q0=0P0<30`0
1`0B4Q8030`<014A4@0@410030`<00d=3@0>3Ph00P0;2`/01`0>3Ph03`l=00h>300>3P`03@d;00h>
300?3`d0100=3@/05@0?3`d051@B00h>30061P@03Ph<018B400C4a4020P6010@3P0A4@l030`:00L7
1@0820L02@T700T:1@0O81/04Q<>00@5000<3@P04Q<>00l@2`0200d>2@0400h?2P0?40/030d800d>
2@804a@?00<03Pl:00`=200A4Pd00P0B4`h02P0>3`X02``700/<1`0>3`X03@d;01TI5`0C4a403@d;
00L71@0J6QP200/;2@8030`:01P02`/900/<1`0>3`T02``600X;1@0;30H03@h800h?2@092P@03Pl9
03`m=`0A4P`020T300X;1@062@802``601<D3P0B4`d020L200D4000?3PT040d800h;1P0?30L2014>
2@0604I6@@0_<2/0004000h?2P0D5A00414<0P0<3@P02P0=3PT03Pl:00h?2P0<3@P01PL200P9100@
4@`051D@0493?P0a<Rd500h?2P0801XK5P0C50l01`P3014B3@0B4`h03Pl:00l@2`0@4@`2018C3P05
014B3@0B4`h0410=00P81P092@L00P0C50h05P0@4@T03Pl700h?1`0A4P`04a@?018C3P0?3`d030h;
00d?2P0@4@/04Q<;01@F2`0F60`0418501HH2`0I6a004a@<00l@2P0A4Pd05aHB00l>2P0B4@d200P7
0`804Q4=01d04A0<00l>2P0>3@T03`h:018A3P0I5AH05A4@018A2`0@4PL030l400dA2P0B51<04Q<G
00/;4`0>2a805Q@G01LC4@0C3`h02`T701TH5P0M71X03`h<00h>30061P@00`@200X<2@0?4@h02`h;
00D:1P0200X:200L00h>300M7A/02@T7010@3P0:2PP030`:00h>300;2`T03`l=00T91`0G5aL030`<
00d=3@0A4A403@d=00T92@0C4a<03@d=00@410071`L04Q8B01@D4P0:2PP04A8=01<D3`0@4@`04a@?
01PI50803Pl:00h03a0;014B3@0B4`h04a<A014C4P0M7ah05ALF00d?3P0>40d03@l<01/M6P0B50l0
3a4<018D3`803a8;0P0B5@`05`0C5Pd051L@01@G400D5a005ALB014C400C5A8061XG01LI5P0D5Q<0
4A<@01HH5@0@4Pl0;Bl/08F:QP0l@Cd04QPD01<I5@0A6A@04AXE01@M600F7AL05AXD00805Q/E0180
5AXD01@I4`0E6Q@04aPB014F400E6Q@06AhH01LL5P0G7aT04AXE00lH4`0D7AP04AXE01XS7P0M9R40
3QLB010I500D7AP2014J5@0401HM6@0H7QX06AlK01LM6@<05A/G02<051XF01HL600G7AT061hJ01PP
6`0L9B806B@P01HQ7@0C7a/0520L01LS8@0L:bP05RDR018P800F9RD06RXY01PW:00J9BL08Rd_01HQ
8`0K:B`0:CLj01LV:@0S=CT08cHj02a0@`0X?D80;DE902Q0A00N<cP06bhd01lb>00S=SX083<g01ha
=@0202Di>P0802@h>@0R=SD093Pg02/o@00O=3T093Po02LkA00V>T<202DiA00;02TmAP0U>D409S]0
02]0@@0^A480:d4n02i0@00Y>c/0<D=503M9C@0dAD/00P0_@4L03P0`@DP0<TA80394AP0cADH0=4I6
049FE@0fBT/0;41102Xn?`0[?d40<4=702Xm@@0dAd`0<dI<0`0_@TP01P0eATd0@E9I04mPI`15Ee/0
>deA03i@E0<0>Ta>01@0>4Y:03E7A`0cAdH0=DY7041DDP0Z?S`0=4Q604MJF00eB4H0<4=103Y:B@0l
C4/0<T9103U7A`0fA4@0>4Q503I6@`0gAd@0>d]803a<B@80>d]800T0=TI303E5@P0a@Ch0:c/h02Xi
=00U;bL082XR01hX800S;BD00P0Y<Rd0>P0J8ah0:34^03@m>P0c?3T0:C8_03U0@@0V;C<0;3<i02dh
?00a?d80>dY=03=4A`0cADT0<T5602hl@P0L:Bl092le02<a<`0Z>SX0;Cdm02Lg=`0V=SD0C5YJ02dj
>@0P;2X08RhZ02<_:`0/=c<0<C`h02D_<00R;C405b8T01`W:@0_>S`0;c/k01`X:019EED0=40n028^
;00S;bd082`Y01dW:00Q:b`092h]01hW9P0I8R406R<P020V900V;2X0;c@`01/P700I7QX08RLQ01/P
6P0N8ad082DQ01lT800L8Ad201`P7`0C01hR8@0L8240720Q01`P8@0N8R@0828Q01lQ7P0M7a`06adJ
01XL6@0I6aP05ALD01TK600K7AX06A/H01PJ5`0J71T06Q`K01/M700201`N7@0401XL6`0H6QT061XI
01PJ6@805aTH0P0F61L0200;2`d0410B018B500E5AL09BDW00h>400C4aD05ADG0P0F5QP03`0E5AL0
4Q@C01DJ5P0D6A@04QLC014E5P0D5AP05AHJ01HG6`0H61/04a<C01@C4P0E51004Q4=018B4P02014A
4@<04Q8B00T071`L01DE5@0820P05ADE03Hf=P0F5QH06ALH01hL7@0F51D00P0A3a000`0=2``04a4B
018@4@02014?40803`d>00@0518E018@4`0A3a8040hA0P0>30l02@0A3a803P`?00l=400A3a803P`?
00/9300>30l03`d@01@B5@0200H41`0701@B5@091`X02PP;01@B5@0@3Q402PP;00/82P0200l;300=
00`82@0=2@X03`/<00l;30091@H04@d>01dI6P0<20T01`<400d82P0@2P`05@lA01LA4`0200h82P80
4P`>00<04@/=00l92`0>20X00P0?2@/01`0>20X040X<014;3@0C3@l05Q0B010:300?2@/00`0>20X0
3@0@2P`040D900l4200A1PX0714E00l4200=0PH02@0201lD600<0`D040D901<8300A1PX0300@1@T2
00d21P0401052@0C20`04PL;00d21PH03`@800<03@8601052@0?10P00P0>0`L01`0?10P08aPL0105
2@0>0`L04PL;00h31`0?10P05?ooool001_ooooo00P02P`700X<200>40/03Q0;01XL5`0F61<03Q0;
00lA308030h900@03a4<00h@2`0B4`h04A8=0P0>3`X200l@2`0P00X;1P0=3PT0414<00l@2`0>3`X0
414<00h?2P0C50l04Q<>00d>2@0<3@P03Pl:01HG4P0C50l03@h9010A300;30L04a@?010@3P0B4Q00
8R8P018B400O7ad030`:00h>300<30X02`/9014A3`0@40h03@d;00d>2@0?40/2010A300900`>2@0;
3@P03a4<00X?2@0>4`d041D?00`C300B5A404A4?00802`/900D03@d;00h>300@40h0410>00h>3002
00l?3@0:00h>300?3`d04A4?01HF500@40h020P600`<2`0c<c4051@B00`<2P<03Ph<00@04a@B014C
4P0<3Pd03@l>0P0@4Q403`092`X04aDD00P:2@0=3`h051HE00H81`0B518020X701@F4`0:30T0418?
018D4@0C5A803Q0=00/=2P0200h@3@0800`>2`0?3`l05aLG00X:2P0@41003`l?00h>3P0=3@d200h>
3P802`/;00L03Ph>00l?3@0>3P`03Ph<00d=2`0>3P`03`l=008030`:00T03@d;00l?3@0?3`d03@d;
00h>30071`D03Ph<00d=2`0?3`d00P0;2`T0400@40h00P8101HF500=3@/05ADC01<D3`092PD03Pl:
018C3P0=3PT0414<00`=200;30L02P/600`=200=3PT200/<1`804A8=010030d800/<1`0?40/03Pl:
00l@2`0>3`X03@h900h?2P0A4Pd051@B00X:200@40h010@201@D4P092@L03@d;0`0>3P`01@0=3@/0
30d8010A300>3`T03@h800803Pl900T03a0:00`=1`0@4@/0=cPb01@E3`0;30H03@h8018C3@0<3@L0
0P0=3PP02`0?3PT051<>014>2@0?30L04@h901<>2P0A30P04@h903@d;`0W:2<01PL200803a0;0P0<
3@P200d>2@803Pl:00L04Q<>00D60`0?40/0;2dX00/<1`0E5Q40414<00D03a0;00D04A8=00`=200:
2`H04Q<>014B3@03010A300?018C3P0C50l04A8=014B3@0[;2T0;Bd/01HF500?40X03a0900`=1@0>
40D04Q<:014B300?40/03`l=0080410@01404A4@01<C400D5@l051D>01@E300>40D04aD:01TI3`0D
50`04A0:01<A300?3PX030/701LF4P0C4Ph040l;018A3@02014@300R010?2`0?3PX040l;010?300A
31003`X=014A3@0B50X0314500XA200A5QD041DG014B5P0A41404A0;014>1@0F4Ph05Q8A00l;2P0?
3P`051<A00X:200=3@/04a@A01@F4`0730P0@4E103Pm>@0B4a4030`:01TI5`092@L04Q8@00l?3@80
4Q8@014051@B00T91`0C4a401PH4018B4P0=3@d05ADE014A4@0b<S804a<C00`<300@41003Ph>00l?
3`0B4Q803@d;00h>2`02010A30803Pl:01D03a0;00h?2P0>3`X03a0;014B3@0C50l051@B00h@4009
2P`03a0B010B4@0G6AH08bDR03<e<00>40/04A<>010C300:3@H05QTA01HI3P0D5`h00P0C5Pd2018E
3P0301<E400A4a004aDB00805aTH01805QPG01LI5P0M7a`04A<@010B3`0g?3P04AHB010F4P0A5a<0
4a/F01<L5`0@6A@041LA01@I4`0F6aD061dG01HK5@0E6Q@201HK5@0501<H4P0D6A<05Q/E01HK5@0C
6aD00P0?6Q@0100B7AL041/E014L5P0F8A/201DP6P0401PS7@0C7QP04A`F01DM6@805adI00<05A/G
01<I5@0D6QH00P0F71P0D`0I7a/06R0L01XP700H7a/05R0L01@O6`0C7a/05B4M01PT800J:BH07bh[
01/Z9`0H:2L07Bd/020`;`0P;bl072LY01XT9P0K9RP06BLZ01l]<00Q<C<07C0d01P[;`0P=SP08SPm
02@l@00T?D4083@k01ha>00S=S`0:3]102@g?@0R=CT08SHg02<g>00Q=C@083@c02Hj>00V>cT08SLi
02Dj?P0W?4809SY202PlAP0Y?DP09c]602PlAP0/@4P0<4A:0315B00/@D40;d=102/m>`0`@T<0=DM:
0394BP0`@DT0:S]302/l@`0Y>cl0:C/n02/m?P0W>CT0:3`j02e1@00fBTT08cLf03E9B@0aADH0:Sho
03E8B`0gBTh0=TU=03Q;C`0dAd`0>4UA0393BP0cA4/0>T]B03Q:CP0oDED0>Ta>0080>D];05/0>4Y:
03I9A`0eBDL0=DY803M;B@0oDe40>Ti<07f@SP1;GU`0=DQ603E5A00hB4L0=dM603e;B`0fA4@0=dM4
03A4@@0eAD80>4Q503U9AP0hB4D0>DU603Q8A@0fAT<0<T8o02Lg=00O;RT082/R020Z8P0T;RH0:38Z
02Tb;@0[=2l08R/V02hg=00/=C80<CXg02Pa;P0Y<38082L_02Xa>@0_>T00;ca20391AP0`@4@0;T12
03Y9C00[>Sd0JgUl02hi?@0/>S/0:SXi02hn?@0`@3l0A5AC0:Vh]@16E5407b/Y02di=@0jAD409c8^
02Td;P0]>CP082ha02<a=00/>S`0;S`m028`<@0X=SH0?de=02`j>P0T<c0082l/01/Y9P0N:2T08B//
028/:`0Q:RT08R/Z028[:00Q9bD092XX02L/:00H7AT0724M028W8@0M8Q`07b@N024V800P9B407b@P
00808BDT00H0720O024U9P0O8bH082@W01dQ8`0N81l201hP7@0501`N6`0K7AX06Q`I01HH5@0I6aP0
0P0G6AH0200H6QL05aTF01lQ800O8B006adL01XL6`0K7A`07R0O0P0F61L401@F5@0801TI6`0F5QP0
51@F01HF600K6ad05aLI01HF600D51H2018B500A01@D5P0E5aH051XF018I4`0@5Q8041HE018G6@0D
61/041@G01<E600@4Q404Q<A01<E400A4Pd04a<C01@D500C4a<00P0B4Q802P0C4a<0:2PX020P800?
3`l0410@00d=3@0>3Ph04Q0A01DC500@3Pl201@B4`0400/92P0A3a004@l@014?40<04Q0A00@04@lB
010>4@0@3Q403`d@0P0>30l0100@3Q403`d@00l=400A3a8300h<3`0;00T72P0=2`h04@lB01hL7`0l
>Sd071XM00D31P0?3A002@L:00`:3@0E4Q@00P0?2``0300=2@X02PH700h:2`0A3@h040`=01LC500K
5aP02PH700`82@0E41403@L900/51`<03PP:00L040X<00h82P0=1`T03`T;010:300?2@/03PP:00<0
3@L901@03PP:00l92`0>20X03PP:00d72@0<1PP03@L900h82P0I3Q8040D900/2100P5AT03@8601@9
3@0<0`D05P/?00l5200=0`H05``@00h31``040D90P0>0`L0100@1@T04`P<01872`0>0`L700l42080
4@H:00T03`@801052@0A1PX08aPL01052@0>0`L04PL;00h31`0@1@T05?ooool001_ooooo00d02P`7
00lA300@4Pd03@l:014C3P0:30L03Q0;014C3P0;3@P02P`700h@2`0:30L03@h900803Pl:0P0=3PT0
2`0;30L02@X501hO6`092PD030d800h?2P0;30L03Pl:010A300?40/03Pl:00803@h900@04A8=00X;
1P082@@02``70P0=3PT0300B4Q0030`:01PH5P0?3`d03@d;00P81P0?3`d0410>018B400<30X0410>
00h>30<03a0;00D03Pl:00`>2@0;3@P03@l:00P=1`0200/@2P0900lF3`0A510020P601XJ600<30X0
0P8001HF500D5180410>00<03Ph<01X030`:00H61@0:2PP01PH400d=2`0D51805QHD00T91`0:2PP0
2`/9014A3`0=3@/030`:014B400?4A002`d<00d?3P0@4Q403a4@01/M70031@@02@/:01XL6`1lOWd0
6A/J01<E4`801@L400<00P@1018D4@0:30T00P0@4Pl200h@3@0;00lA3P0>40d07alO02TY:@0@4100
61PH00P8200:2PX03Ph>00l?3`0>3Ph00P0;2`/0200=3@d03`l=00h>300>3P`03@d;00h>300?3`d0
3@d;0P0;2`T05P0>3P`0410>00h>300=3@/02PX801HF500;2`T02PX8010@3P0C4a4030`;02PX9P08
20H0410>00H6100?40/02P/600l@2`0C50l03@h900H70P0<3@P200/<1`0500d>2@0>3`X030d800l@
2`0A4Pd00P0B4`h2014B3@0=00l@2`0@4@`03Pl:00/<1`0<3@P03Pl:00D50`0@40h08B4O04a<BP0;
2`T04a<A00h>300200l?3@0400h>300<30X030d800l@2`<03a0:00D03@h800`=1`0;30H01@H000d>
200200P90`0A00d>200?40X0414;018C3@0>3@P01`H100P70P0@3@P03P/601@A300F4@d03`X600h;
1P0=3@/03@h9018C3P0?40/00P0:2`H0300>3`X03@h900d>2@0=3PT030d800L8100E5Q405QLB00/<
1`092PD061TD00X;1PD03a0;00P030d8014B3@0G61<051D@018C3P0E5Q404Q<>00l@2`804Q<>00h0
3a0;00h?2P0G5aH04Q8B00H610092PD04Q<;01PI4@0G6@h0418700l@2P0?40`0410>018B4`80518C
02D05A@B01<D3`0A4P`03a0800lA1P0@4PL051@:01HC2P0E4PT0510;01@C3`0=30P06QTE01TH500E
51004A0<010?2`0A40`04a8>018A3@0A40`03Pd:014=3P0?2``03`l9010C200;4@D031@8038h=00J
81h02`h<00l@200<300061H7010;1`0?2PX03@T800803Pd;02D010@201<C4@092`P05QPE01XO6`08
3@T02@h:00T;20092@L00P8001PH5P0?3`d02PX8014A3`0?3`d04a<A00@40P0H61H02@T700D51@0E
5AD06a/K0000000F5QH04A4A01@D500>3Ph02@T900L71`092@T04A4?01LH4`0>3`T030d701<D3P0D
5@l04Q<=00<03a0:01<04A8<018C3@0B4`h05aXL00lC500<41402Ph=010E4@0G71P06QlI00hC300;
40T03Q<<01@J400M8aT051L<018E300A50/04QD<00804aH?01@04A<>014C400@4Pl04A<B01HH5`0I
6aX04Q@A014C400;3@X051HC01lT800D6QH04ALC01<I5@0C6QH04Q/F01<L5`0D6aD051TB01DJ4`<0
5a`E00d05Q/D01DJ4`0D6A804aPA01@I4P0G71D0620J01PS7@0I91h05R4K018M5`0<5a403APB0080
4A`F00@051lI00lJ500>6A<04a/F0P0F71P0FP0E6aL051XF01LM6@0G7AT061hJ01hT800O9B40728N
01LN6P0C7QX04alK01DQ7@0I9B406bLS01/Z9`0G9R<05RDR01DU900C9R@052LU01@U9@0G8R@051hP
02@_<@0C8B@0938e01d^<01fRHd0AEQL01/b=00F;S806c@h02Q1A@0N<ST06blf01hb>@0S>3d08CHk
020e>00O=3D08cPi028h=P0S>CH0:T0m02Hl>@0V?3X09Cdn02@l@00T>d40:3m802e3D00Y?d`0:d5<
02]2BP0Z@DL0;DE90397B00]@Cl0:Sdj02/m?@0/?T00:Sa202hoA`0_@4X0;d1702Tk?`0Z?400;Cm0
02Dg=`0M<Bl0=4]602Y0?@0^A440=de;03Q>C00gCD/0=4Y903=8B@0aATL0<4E703A7B`0iBU80>daD
0352BP0b@dX0;T1403a>DP0gBD/0=dU903I8B080=TU700H0=TY803I;B@0eBDL0;D4o0355@`1:GE/2
03E8AP0603Q8A`0kBdX0=DE403E3@`0]>c/0=4A10P0a@Ch0;P0c@d00<T8o0351?P0eAD80=4A10351
?P0b@Sl0:CTf01l^:@0S;RD092hV02Tc:`0[=Bd0:S<^02Tb;@0D7AP0:c@a03a5@P0i@Sl09c0]02<Z
;@0a>480<SU1030k@@0^>d409cHk02Lh>`0oDE<0EfIY03E3AP0oCE0082/]030n?P0/?3/0=dM603A4
@`0fATD0@E1=02@b;P0L:2@09c<_034m>00S;RP09S4[02Lb<@0M:bh202hl?`0302Hd=`0Y=cP08c4a
00805R@T00<08c8_01h]:P0K:RL00P0W<C804@0O:BP06b@S01hW9P0L9B808RPV020V900P9B406AhJ
02@Y9@0P9Al06QlH01/P6@0K81X06QlK01/P700Q9B<0<cLf00808RHW01T0720S01lS9P0G6al07AlN
01dO700N81d07AlL01/M6P0J71T05QPE01TK600D5Q<05ALD01/M6P0H6QL071hM01hP7`0L7Qd06A/J
01PJ6@0K7A`05aTH01HH5`0D5QD04aDD00805ALF00H0410B01XJ700K6ad0LW9d04Q8BP0<30h201@D
5P804a<E014051@F01<E500@5Q803AL@00dF4@0=5Q<03aHG010E600B5aX051TK00lC4P0@5A4041D?
00lA300E5AD05aLG01HF5P0201<C4`0>01DE5@0=3@d02`/;00X:2P0B4Q8051@D01`L700H5QL05A<D
018@4@0A3a003`d>00`:2`0B4143014?408040h?0P0?3A03010>4@04014?4P0>30l040hA010>4@80
3`d@02403@/>014?4P0?3A003`d@00h<3`0;2@`06ALJ018@4`0:20/03P`?00X82`071@P02`P:00l;
300E4A805a<D00d92P0<20T03`/<00d92P0;1`P02@D600P41@0;1`P03`X<00d72@0<1PP03PP:00`6
200>20X04`d?010:300?2@/00P0@2P`00`0=1`T03PP:00l92`0300h82P803`T;01403PP:00d72@0=
1`T03@L900l92`0700003P<702<H701CB4`09a`P00h41`0B1`/03`@800h41`0900807A8F01@93@06
01052@H03`@800H03@8600`11@0<0@D03P<700l4200=0PH700h31`0701462P0@1@T03P<700l4200@
1@T03`@800h31`0300d21P0301052Ooooooooooo01;ooooo000Kooooo`0K0001000?4@`04A<>00/=
200?4@`02`d800h@2`0A4`h02P`700T;1P0=3`X02@/600/<1`0=3PT03Pl:00d>2@0<3@P02@X501`M
600e=S403Pl:010A300B4`h030d800d>2@0<3@P03@h900<03Pl:01402P/601LH4`0I6QD03@h901@E
400E5Q40410>00T91`0;2`T03Ph<010@3P0>3P`0410>01<C4@0E5A<02`/900l?3@0300h?2P0A00h?
2@0>3`X03@l:00d@2@0?4@/020d700X?200;40X05QdF04U=B0061P@02PX800/;2@0c<c40JFUW01TI
5`0@40h00`0>3P`02@0<30X03`l=01DE4`071`D0410>00H6100M7A/04Q8@00h>300200d=2`0W00X:
200<30X04Q<B00d?3P092`X030h=010B4@0=3`h01@L601XL6`0<3Pd02`d<03Hh=`0F61L0418@00D7
100F61D030h;00h@3@072@H020X700X<2@0;3@X02P`900/=2P092`P03@d=01/K6`092@T06QXJ00P8
200B4Q803Ph>00l?3`0>3Ph02`/;00X:2P0=3@d03`l=00803Ph<00L03@d;00h>300?3`d051@B010@
3P0;2`T030`:00803`l=01<02`/900h>300U9B<061PF00d=2`0A4@l02PX800D50`0=3@/051@B00P8
1P0>3P`030`:01<D400;30L02@T7010A300<3@P0414<00803a0;00H04A8=01<D3`0A4Pd03@h900`=
200>3`X2010A300=00h?2P0A4Pd03Pl:00`=200@4@`07b0K02h_:P0I6AL061PF069RH03Rh^009bLU
00P81P0400h>300300`<2P0;30L03Pl900803a0:01403Pl900/<1P0:2`D03a0:00/<1P0720804A8<
00h?2@0A4P`03@h800`=1`0>3`T03Pd8010?2P0E50l03@`700h;1P0201HC3P0D00h;1P0=2PD04A4=
00P70`0;30L020P500d<200@4@`03`l;00l>2P0>3PT030d800d<200A4Pd030d80042000E5Q4020T4
014B3@0B4`h500l@2`0I010A300B4`h03a0;00l@2`0J6aH05AHA00/<1`0?40/04Q<>014B3@0>3`X0
30d800X:2@0820P030`:018C3`0=3PP02``400`=1@0=3PH03Pl9014A3P0B4Q004a<C01@B4`0201DD
4P0A018C3P0@4@`03@h7014B2P0@4@T04A4901@D300F4``0514;01lN6P0A40`04Q4=010?2`0A40`0
4Q4=00l>2P0A40`00P0D4`l0=@0B4@d03Pd:01HB4`0B3Pd03`l:00d@1`0:40@03A<902H[9@0<4@d0
2Pd901`M5@0C4`L04@l201HC3P0;1`H03`h<018A3`0=30X03`l=00h>300K7AX0004002@V8`0F6aL0
3a@@00h@3@0=3@/05ADC05QHEP0A4Pd05QLB010A300?3``05aLE00T91`0T92@05aLG01<C4`0<30`0
3`l?00H61P0C4a<05QHF01DE5@0B4Q005ADC018B400;2`T03Ph<00d>2@0B4Ph04a@?00803a0;01@0
4A8=010A300?40/03a0;010A300A4Pd04A<@00L:2P0D61T03Q8A00lC4P0D6AD03a@@00T>200K81X0
4QL@00lD3@0@5@h02a47018E308041<:00T04QD>01@G400E61404aD@01<E4P0B51404A<@01PJ6@0M
7a`00P0F6aD03`0D6A<07b@N018I4P0C6AD03aPC01HL600C71L05AhI01hW8P0O9b4061dF01LL5P0F
6a@05AXC01@I4`0201<H4@0>01@I4`0C614051TB01TN600E7AL03aXD018K5P0B7AL05b8L01HQ6`0B
7AL04A`F018M5`0F8A/2018M5`0301@N6@0E7QT05AhI008051dH00T05b0K01@M600C71L072DP020Y
9P0N9b@06R<P01PT800I9B400P0J9R804@0I9B405bHS01HU8P0H9b@062PW01@T8`0@8b404R8R028]
;`10BT`0HVe_01d[;00R<3<08S8e07^=T@0oDUH06Bha00807cLk00`06C8f02Di@00Q=C`093Po02Tm
A00W?4409ca0020e>00U>S/09C/j02Lm>`0]@d4202Pn?00]02Ln?P0T?4009SY102XoB@0_AE80;d9@
02i3CP0Y@4P0:3a302e4B00gC4d0;T<n02Xn>@0Z?S`0:C/k02Lj?@0^@DL0:ca302`nA@0W>Sh0:cdo
0313@`0W>cT0<DM402Dl=`0bB4D0:Cll02a2?`0bB4D0=D]90398AP0iCdd0>4i<0397A`0fBdh0>DaB
03M:D00`@dT0>deB0353A`0iBdd0=TQ903E7A`0eB4H0=TU70080=dY804P0>De:03iBD00R=c80?4m<
02Tl>00hBdL0=TU503U9AP0hB4D0;cll03M6@`0d@d00=DA00310?@0_@3X0<D4m0310?@0^?cT0=4A0
0351?P0]?SP0<d8n02hm>P0V<Rh09S8Y02@`9P0Y<bX0;3H]02Xd:`1BG5@0=Clg020Y900/=c<0=d50
038l>`0b>d80EEeZ04eGH@0`?TH0@e9I03U8C`0_@DD0Sj6S06YiO00gATT07B/^04IDE`0Q<340<d=2
03A4A00/?3/0>d]:00`J6P0/>cT07RdZ02Da;`0X=340:CDa02hj=P0V<c80:CPk03M6B@0R<C@0<T54
02Dc=@0]>c`0;3Xj02Xg=`0M:BT082`Z01dY9`0K9B@2020Z:@0902</:`0W<2l082TV020V900X;R`0
;34]01PM6@0M8Qh08BHQ00808RLQ00H07b@O01/P700L8Ad08BHS02da<00I7Ah201`P8@0?02DY;00P
92H071hK01dO6P0N81d07AlL01`N6`0J71T04Q@A01DG500A4a005ALD020R7`0O8Ah05aTH00807AlN
01406A/J01HH5`0F61L06A/J01LI600E5a@05ADE01LG5@0H61P05aLG01<C5@0N7R006QXL01HF600H
61X04Q8D01@D5P0201HF600K01@D5P0A4a8041HB00lG4@0@5Q8041HD014F5@0A5AH06QhQ01/O800D
61L051LE01DG500A4a005QHF01PH600G5aL04a<C01@D500F5QH04a<C01hN7P0L71`02`/;00l?3`08
20P04Q4?008040h?00d03@/<00l=400C4A@0518E01<A4P0B414040h?00l>300>30d03`d@010>4@0A
3a804Q0C00804a4D00<030X>014?500A3a@00P0?3A801@0@3Q405Q@G010>4@0;2@`03@/>008020H9
00/030X=00h<3`0:20/04Q0C01@B5@0=2P`03`/<01XF5`0O6a`040`=00/7200200l;300600d92P0>
2P/0510A00l;30080`@030H80P0@2P`020090`D030H8018<3P0=1`T030H800l92`0@2P`03@L9100:
10H00`0;1@L03@L9010:300200l92`0?00h82P0?2@/040X<01072P0900<0200202lT:00>1@P04PP<
01D:3P0?1PT05@/?00h31`0P5aX040H900803`H901003`H:00l62`0@1@T040D:00h32@0>0`L03P<8
00h32@0>0`L03P<800l4200=0PH0304500h31`0@1@T03`@81`0=0PH200l4200900d21P0>0`L03`@8
00X00`0A1PX03`@800/0100=0PH03`@801Cooooo000Kooooo`803a4<0P0M7aX200lA300500X<1`0>
40/02`d800`>2@0@4Pd00P0=3`X0100@4Pd03a4<00d?2P0>40/2010B3@803@l:00@0418=00d?2P0:
30L03Pl:0P0;30L0100A4Pd03@h901HG4P0>3`X200l@2`0300d>2@0>3`X03a0;008030d800X03@h9
00h?2P0>3`X03Pl:010A300B4`h03a0;018C3P0P8A`0:R/U0P0=3PL05`0>3`L03a0800hA2@0>4@P0
4A@;00dB2P0<4PP0318900dD2`0@50d051HC00/=2P0<3P/0<S@a07]mNP0D5Q<03@l<00X<2@0=3``0
418?00d?300?4@h01PP500803@l<00D07b4N01XL6@0D5Q<0418?00h@3@0200lA3P0500h@3@0=3``0
3Q0=00h@3@0?4@h00P0>40d200lA3P<03@l<01003a4>010B3`0?4@h03a4>00H81@0E5a@02`d:018D
4@0f>3D0418?01`N6`0;3@X0418?00T;2P0=3`h0418A0P0?4A00>`0>40l01PP701@F5@0;30/03Q0?
00lA400=3`h04Q8@00h>300C4a401`L501DE4`0I6AL03@d;010@3P0?3`d03@d;010@3P0?3`d030`:
018B400H61H04A4?00`<2P0?3`d03@d;00`<2P0>3P`03`l=00h>300;2`T03@d<010@3`0<30/02`/;
00h>3@0;2`T0410>00h?2`0@4@`04Q<>00l@2`0:2`D03Pl;00d=2`0>3P`0410>00h>30092@L03`l=
00`<2P0:2PP03Ph<01/K6@0U9B<03a0;010A300=3PX0<c@_00<03@h900<0414<01DF4@0C50l00P0=
3PT01P0>3`X02@X501DF4@0<3@T02P/600h?2P803a0;00/02``700d>2@0>3`X030d800h?2@0?40X0
414;00d>200C50h030d900d>2002018B300B00h>2@0=3@P03`l9010>2P0?2`P03``9014>2`0B3P/0
4@l;010=2P0E4@h03``8010>2P0D40d03`l;00`>2@0;3@P030h90P0?4@`07`0@4Pd04A<>00lA300>
40/051HA01<E400C50l04Q<>014B3@0?40/0:2TT02`]:00A4Pd0414<00l@2`0<3@P03a0;00h?2P0=
3@X01PH501<C4@0>3P`03Pl;00/<200A4@h04Q<?00l@300>3P`04A4?00l?3@0A4Ph00`0@4@`02P0A
4Pd04a@?01HG4@0=3PT04A8=014B300C4`h03`l;01DF4@0@4@`200h?2P1300l@2`0E5Q403a0;024R
7@0D5A003a0;01<D3`0@4@`0410=010@2`0?40/03Pl:00h@2P0?4@/03a4<018D3`0A4Pd03a0:014B
3@0A4@/07QhK01<C4@0=3@/03`l=010@3P0<30X04A4?010@3P0>3P`04A4?00l@3P0@4@l04A4A010@
3`0A4Ph03a0;014B300P8AX05QL@010A300J6QP0;bl`03`l@00@3a@0510F018?4`0?3A003P`=00l>
3P0?3`d04A8>00d>2@0;3PP03Q4;010C300>4@/03@`:01<?3`0B3`l03`h=018@400E4a<04A4@010@
3`0=3@`04Q@B00`>300200lA3`0900h@3P0C5A803Q0=018D4@0?4@h051HC00d?300C5A404aDB0080
4A<?00L04QL@00/@2@0D6A8041D?01XO6@0_=2h051TC00<04aPB02004aPC018H4@0@6Pl041/?00hI
300D7a@05R4G00lJ4@0>6A4031H@014L5`0E81`0DUeI0458A00?5A005A/G01@J5P0N9Al03A<?01@K
5P0C6A@04QPD01HL5`0J81/06AlK01XP700D71L05adI01<L5`0D7AP06B8M01@N608062<M00H04AdF
01/X8@085@h06BHN01HR6@0E8A/201@P6@805b<O00H05B4M01PS800I92<06RDS01TT8`0F924201HU
8P03010O700?7Q/04b8O00@062LT04P05bLT01PW9@0G8b<072PX01l[:`0J:2P06RPY01TX:@0N;C00
830c01//;P0J;3008S@h02@f>`0Z?D@062`e02a0B@1?Hf`0;d=;02TnA00Q=S/08CHj028g>`0T>C`0
9S/m02Pm?P0W?3/0:3`n02Xn@`0Y?4<0:ci803U<E`0iBeL0:ci802`oAP0aA4X0;45202Tn?00X?SP0
9chf02Hm=P0W?CT0:3hk02To?@0W?3X0:Sln02a1@@0]@T00:T0n02Lm>`0Z@3d0;D@o0358@P0cBTD0
<TU402m6@00eBdP0@5IB03mFD@0gCDX0=Ta803Q>B`0cBTX0>4e?03]@D@0hCD`0=d];03=7AP0eBDP0
>Te:03Y=B@0fBDD203=6@P0703U;AP12E4l0<dDo03U:A@0`@CX0>T]403E6?`0203=4>`120393>P0b
@cP0<d<j03E2>`0[>S@0:c`d03M:@P0eBD40:She02m2>P0]?CH0<3hg02Xe;`0Y<2d082PS02Hd;00T
<BP0?4Tm02Xf:00^>B/0930R01l[7`0Z=Rl0:cXg03M7B015EeX0>TaI05IVO00kC5l0>4YI0354D00]
?dX0>4UA0393B@0]?d<0<45502ln@`0_?T@0;ci205ATI@0b@D@0;Sdo01h^;`0]?Ch0:cXl02Ti>P0/
>S`0:cXl02Pg>@0W=SP09cTk02Hj?@0X?3l0:Se102@f>@0W=ST0:3Dh02Td=`0X<cD09Bh`02@];P0T
;2`08R/Z020[9`0Q;2P0;CHc0P0N9b@02`0N92808bTW02<W9P0M8B007R8Q01lS8@0L8Ah07B4O01dR
800M8B007b<R008092PW0P0S9bH0100R9RD082@T01dQ800N7aX201lP6P0f01dN6@0L7AP06a`G02@T
8P0R8R005aLE01DE5@0I6AT061XI01dO7P0F6AP06adL01`N7@0H6AL06QXH01/K6@0J6QL05aLC01LF
4`0F5A405A@@01DE500G5aL05QHF00`<300H61P04Q8B01PH600B4Q805ADE01PH600E5AD04a<B01HG
500E5Q8051DC01DF4`0E5QD04a@C01HF5`0B4aD04A4C01@D5P0C4aH04Q8D01HF5`0>3Ph07alO010@
400j>SX07QhN014A4@0C4a<04Q8B0P0?3`l05@0A4@l0414<014A3`0A4A003`lA00X93P0@3aD040lD
00l?4@0?3`l03Ph=00h?2P0>3P/03@/=01HD5`091`X04a4F00L52P0B41D030X@01@A6@02010=5@03
018@5`0@3Q803`d>00@03`d>01004@l@00D4100=2``030X;00D3100B4140514C00T4200o>Sh0If9V
01D@500;1PX06QDI014<400@2`l03`X>0P0>2@d03@0?2Ph03PT=00l;3P0<20/03`X>01D@501JEET0
5a<F00H21@0B3A4030P;01<>4P0=20`00`0;1@T0700<1PX03@L;00d72`0E3a<030L:014;3`0F41@0
3@P;00`62P0@2Ph030H:00P21@0@2Ph03@L;00`42@0;1@T03@H;00h72`0=1`/03PL;00X52@0?2Pl0
71HL00/42`0=1@/05P`C00h4300>1@/200l4300300l42`0?10`03`@:00D03`@:00D02`460146300?
10X03P<901052`0700h32@030146300@1@/03P<900803P<900<03`@:ooooooooool04_ooool001_o
oooo00@03@l:00h@2`0J71L06adH0P0@4Pd0400=3`X0418=00`>2@0<3PT03Q0;00/=200<3PT03a4<
010B3@0>40/03@l:00h@2`0620<03Q0;018D3`0?4@`200h@2`0301DF4@0B4`h020T40080414<00@0
4A8=00l@2`0?40/03Pl:0P0;30L00`0<3@P03a0;00l@2`03010A300;014B3@0@4@`03a0;00h?2P0<
3@P02``700/<1P0=3PL03@h600h?1`0?40P00P0>4@P0600@4`X03Q@:00hD2P0=4`T02Q8700dB2`0E
5a@03Q0=01<E4P000@003a4>018D4@0<3P/02@/800h@3@0A4a003Q0=00T;200?4@h05QPE01PJ5`2D
UY<0Ce5>00T;20803Q0=00<04A<@010B3`0>40d00P0<3P/300d?300500`>2`0=3``03@l<00d?300<
3P/00P0=3``04@0<3P/02`d:00T;200>40d020X7014C400@4Pl0:bdZ00d?300D5Q<01PP500P:1`0<
3Pd020X900h@3`0@4Q402`d<0080418A018071hM018D4`0;3@`01`T800/=300B4Q001@D301LG5@08
20H05ADC00`<2P0:2PP03`l=010@3P0=3@/03`l=00d=2`0<30X200T91`803`l=00T02PX800h>300=
3@/03Ph<00l?3@0>3P`02`/900d=3@0@41000P0<30`02`0>3Pd02`/900h>300=3PX03a0;014B3@0C
50h04A8<00h>300=3@/03Ph<0080410>01@03@d;00T91`0=3@/0410>00l?3@0:2PP01@D300/<1`0<
3@T03a0;00d>2@0A4Pd04a@?00d>2@0>3`X04a@?014B3@0<3@P03Pl:01@E40802``700<03Pl:0001
000C50l00P0>3`X0100;30L03@h9010A300=3PT200`=1`04014B300?40X03Pl900@500803a0:00D0
3@h800`=1`0?40X04A8<00l>2P0200h=2@0B00l>2P0@3`/04A0<00X91@0<2`L03@`8018A3@0A40`0
3@d800d?2P0?4@`04aD@014C3P0<3PT02P`7018D3`0E5a804Q@?0P0@4Pd01@0<3PT04a@?014B3@0?
40/04A8=00803@h900<0414<014B3@0>3`X00P0>3`X00`0?3``030`:01LG5@0201<C4@0800L71@0;
2`T03`l=010@3P0A4@l020P600h>300A4Pd3010A300;014B3@0C50l030d800l@2`0D5A002P/6010A
300B4`h051D@00l@2`0B4`h00P0A4Pd0200b<bh071dH01@E400A4Pd030d8010A300D5A003a0;0P0>
3`X0100=3PT03Pl:00l@2`0;30L300h?2P10018C3P0A4Pd03@d;00d=2`0<30X03@d;010@3P0A4@l0
6QXH00l?3@0l?3X0;2`Z00/;2@0>3P`03`l?010@3`0C50l04A8=01<D3@0L7AD06AXD00d>200@40h0
DU9D04m>DP0I61h06A@J01HC5P0C4A@04Q0A014@3`0@40h03Pl:010A300D5Q405QTB014E3P0=3`X0
40l=01<?400A3@h04@l@01HF5P0J6QX02`/;00D71P0@4Q407b4P018D4`0E5aH04aDB018D4@0F61D0
3@l<00lA3P0<3P/04aDB00D7100E5a@04Q@A00lA3P0K7AX03a@>00hC3@803a@>00@05a`F020U7`0D
6A<051TC0P0C61806@0B5a404AP@018L400A6a003QP=010J3`0@6Q403QP@01/U7@0@6A@0624L01DN
6@0@6AH04ATE00P>2P0A5a<0>T0l01@J5P0B61@05Q`H01LM6@0H7QX04aTE018H500H7QX00P0J81`0
4P0V;2P07RDQ00lH4`0D7AP04A/E01`W8@0F8A/05b<M01<P6@0F8a`04b0H01@Q600D8AX04b0I018O
600E8Ad05b<O01DQ7@80520N00D05B4O01HR8P0E92405RDR01@S8002018Q7P0301HU8P0I:2D06BPU
00@06BPU00d07RXZ01DQ8@0L:2P09C<c01l];@0R<3405bHY028a=00O<C<0:Sa003i@E00]@4D0:Se4
0080<4A=00<0V:be020d?@0[?dH00P0T>Ch02@0U>Sl09CXm02Hk?P0V>c`0:3`m02Hi>`0Z?D40;3m6
02TkA00202TkA@0=02i1B@0cAT`0;T5702Xn?`0`A480:T4k02U0>P0X?cT09chh02Po>P0X?S/0:Cll
02Y0?P0202]1?`0H02a1@@0/@T00;D=102a2@00_AD80<dU70357A@0[@Ch0=de;05Q^J`0lDTl0;dE3
02i4@@0hCT`0=dm?03M<C@1@IFH0<TQ604IJF@0eBDP0=TY803Y=B@0iC4P0=TU50P0dAd<0C`0lCDL0
AUMA03A5?`0_@3X0:3Ta03U:@P0_@3P0;3dc02/l<P0^?cD0<dDi03I6>`0_?3D0:cXc02ho=`0iC4<0
=T]202i3>P0[?cH0<3lh02`i<P0W<B/092XV020Y900nBdT0<clk03E1>@0^>S00@4Y102La:@0b?CL0
;CTi02hl@@0kC5H0=dUG03M9G014EVh0=dUO03mAI017FVP0AUQT065dN`1ZOH<0@eEI02/l@P0]?TD0
=TE<03e<D@1WMWT0@U5D02@c=P0W=ST0<d9502Pg>P0^?D00;ci102dl?`0[>Sd0;3/n02/n@@0U>Sd0
9CPl02Xl?`0W>C/0:3Lj02/f>00X<cD09Bla02H^<00U;Bl082LX020Y:00D7a/07BPT02Pa;P0I8Ql0
7bPU01`R800N92800P0M8B000`0P92<07B4P01lS8P0201hR8@0601lS8P0P92<082@S024U900M8B00
8RHU0P0_<c80E@0O8b407AhI01dN600M7QP06a`G01TJ5@0G61<04Q8@01PH5`0H61P06ATI01dM7@0I
6aX071hM01LJ6@0J71/071hM01TJ600H61H05aLE01LG500G5Q805QDA01LE400E51006QTG01DE5@0A
4A405QHF010@400E5AD04a<C01DE5@0H61P05QHF01<C4`0G5aD051@B014A3P0D51806QXH01/K6P0F
5QH04a<C01DE5P0E5AL04a<E018A5P0B4Q@061PI00`<300J6QX07AdM055AD@15ADD04Q8B01<C4`0B
4Q804A4A010@400B4Q004a@?00h>300F5Q@04a<E014@5@0B4AH040lD01<C5@0D51@04a<B00l@2`0=
3@/0518D01PF6@0<2Pd0518G00T7300A3a@05Q<J01dJ8@0;20l061DN01@A6P0:20d01@0?3@h0400B
41402PP901XH6@10?Sl05A<D0040000>2`d02PD900D0100<1`/03PT=014<400E41@04@`@010;3`0?
2Ph2010;3`0300l:3P0L5a/020<700805A0D00X00`0203Lb=P0<1`/00`0200P31`0<1`/05A0D00l9
3@0@2Ph04`dA0P0D3Q803P0C3A405Q0D00@00P0=20/040X>00H0100>20`02P@8010:3P0I4aL07ALK
01LA5@0B310030H:0`0=1`/200`62P0300/6300@2a406aHL00802@8900@03`P?00h4300>10`03P@<
0`0?10`700l42P0401D:400A1P`03`@:01052`L03P<900@04@H<01052`0>0`T03P<90P0?10XDoooo
o`006oooool0500C5A002P`700X<1`0:30L03@l:01LI500?4@`04A<>00d?2P0<3PT03Q0;00X<1`0>
40/03a4<00h@2`0<3PT03@l:010B3@0<3PT03a4<0P0A4`h200lA3005028S7P0M7QT02P/600l@2`0>
3`X00P0;30L200d>2@0300`=200>3`X0414<00H0414<00X03a0;00d>2@0>3`X0414<00h?2P0;30L0
3@h700d>1P0>3`L03a080P0>4@P0300?4PT03Q@:00hD2P0=4`T02A4600`A2P0@4Pl03a4>010B3`0D
5Q<02`d:010B3`803a4>00h03Q0=00`>2`0;3@X03@l<00lA3P0<3P/02`d;020R7`0a<c001PP500/=
2P0<3P/03a4>00h@3@802`d:00D03Q0=00lA3P0?4@h03a4>00h@3@0600lA3P0S00h@3@0A4a003@l<
018D4@0?4@h02`d:00840@0E5a@01PP5014C400;3@X04A<@01DG5P0=3`h0418A018D4`082PT03a4@
0001000L7Qd030h=00430P0;3@`05aTH04I6A01?Cdd06ATG00l?3@0D51803`l=00d=2`0?3`d0410>
01@D4P0G5aD00P0@40h01P0<30X02@T700d=2`0=3@/02@T700l?3@803@d;0P0?3`d00`0<30X03@d=
010@400200`<300500l?3P0;2`T03`l=00h>2`0<3@P00P0=3PT01P0=3PP03Ph<00d=2`0>3P`04A4?
018B40803`l=1@0@40h00`0?40/0414<00l@2`0200h?2P0<00D60@0:2`H02P/600h?2P0<3@P02@X5
00/<1`0I6QD020T400l@2`0@4@`020T40P0=3PT02`0>3`X02``700h?2P0A4Pd03a0;00h?2@0;30H0
5QLA00T:100>3`T06Q/E00@03Pl900@03a0:010A2`0?3PX03`h:0P0>3@T0300@3`/04Q4=01<B3P0?
3PX02`X600`;1`0?3PX03a0;00d?2P0?4@`04Q@?010B3@8030h900d04A<>010B3@0=3`X05ALB01/M
600E5Q406AXE01DF4@0I6QD04Q<>00P9100B4`h04A8=00804Q<>00l05QLB018C3P0=3PX03`l=014A
3`04108051@B014A3`0H61H04A4?00`<2P0:2PP04A4?00`<2P0A4Pd00`0@4@`0500A4Pd04a@?00h?
2P0A4Pd04a@?00T:1@0C50l05AHA014B3@0:2`H03Pl:00/<1`061`808b@O02HW8P0>3`X0414<00X;
1P0=3PT051D@0P0>3`X300d>2@0800h?2P0=3PT0414<00l@2`0>3`X04Q<>014B3@0<30X2010@3P0e
00`<2P0;2`T03@d;010@3P0D5180SHf;07IfM00A4@l010@2010@400B4Q004Q<>00l@2P0>3`P04A8:
00T:100D51401PH4014A4`0D4aL04a8G01TD600G4aL0518E01<A4P0A4100410>00d>2@0@4Pd051HA
01DH4@0A5@h03Q0;010?3@0B3Pl04@d>014?400C4a<05ADE01LG5`0>40l03a4@00T;2P0620L071hM
01<E4P0@4Pl04Q@A00`>2`0C5A8051HC010B3`092`P00P0E5a@01P0@4Pl051HC01<H4P0C61803Q<=
00/@2P803Q<=00L05AXD01@I4`0C61804aPB014F400A5Pl04A/>00803aT>01004Q`A018L4`0?6A00
5AlG00hG4P084@`051dH01XS800C6QL03A<?02`b;P1iOg/08RPT018H500E6aL051XF0P0I7a/201@J
5P0I01DK5`0I7a/09bdY01lV8P0@6A@051dH01@N600K9R0072LQ02@`:P0>6a@08BhW014N5P0D8AP0
524J01<P6@0B7aP05B4M01PT800G8al05R8P01DQ7`0G8b406BDU01LV8`0201PW900301HU8P0E9240
5B@Q00H062LT00<05b<S01HR8P0J9RH00P0L:RX03@0P;Rl06bX]024`<`0P<S@0:Sa003I8C00V>3d0
93Po02e1BP0V>T<0?51I02LkA00T>3l00`0V>d0202Hk?P0?02Dj?@0W>c`09CPk02Pk?`0Y?480:C]4
02m1B`0Z?4H0<4=:02/nA00Q=3P093Lj03=7AP0Y?c`0:3li00809Sdg01P09S`h02Hl>@0/@Sl0:d4o
02Y0?P0[@Cl0;T=302m4A@0^A480;D=10357A@0gCD/0>4i<0398AP0cBDL0>e5?02Lm>`0jD4h0:d4o
04EKF@0fCTh0DfQY0;gBd`1EJfT203M;BP0403I:B00iC4P0>Da803I9A@80=DQ400L0;3dg02/l=P0S
=2h0<T<m02Tj<P0b@c/0;Chf0080:c`b02h0;Chd0312=P0a@cL0;S`e02dl=@0a@3T0=DLo02i2>@0V
>c80;d8i02/j<`0^>c@0:C<^02<Y9@0X<Bh0@Di>03Y6AP0hA440>dI205AMF00Y<c40?DQ:02lj@00/
>TH0BeY]03Y;G`0Z?5<0AeUa03a>I00lCV40>4]I0312CP17FV40CF1V03a>DP0hBDl0=TM>0350A`0a
@4D0DF1S03M6B@0P;c80:cXm03I5B00Y>3/0:STl0P0/>ch0500]?3l0<3m203=6B@0/@D@09CPl02Dh
>`0T=SP0:3Hi02Pc=@0S;S008R`^02L_<@0X<3808bX[02</:`0K9R808bhZ02D^:`0T;BX08b`Y0P0K
8Al01@0J7Qd07B4P024U900M8B008BDT008082@S0P0R9RD0200O8b808BDT01dQ800N8R40:2`[02T]
;00M8Al07b0K0P0O81X04@0L7AP06Q/F01PI500C4a406ATH01XJ6P0K6a/07AdM01PJ6@0J71/061/J
01XL6`0K7A`06AXI01LG5@0E5A<05QDB00805QDA00<05aD@01DD400J6AL00P0C4a<0100Q8B403`l?
01PH600J6QX201HF5P0E01DE5@0C4a<05aLE01XJ600B4Pl04Q8@01XJ600N7Qd061PH014A4@0E5AH0
51@F018B500D4aP061PJ01<C500<30`05QHF018B4P0[:b/07alO00<04a<C00L04Q8B014A4@0B4Q00
3`l<00L71@0@40h02PX<00803PdB01804Q4F01@D5P0E5AD051@C010A300?3`d04a4C01@B5@0<2Pd0
4a4F00d;400A3a@02PL>010=500?31<0QX><01TF7`0=2Pl500h<3@0:00`:2`0=2``04a4B02l];P0O
7Ah02`T:010<3`0C3Q805A0D00d830803PT=01@03@P<00h93@0=20`03@P<00h93@0?2Ph04PdA00L2
1P0;1PX02PH900l:3P0:1@T0100300H11@0F4AD040/?00<00P0<1`/02`H:00`62P803`T=00d03@L;
00X4200C3A405@lC010:3P0B31001P04010:3P0C3A402P@8034[;`17@DD06Q@H00@03PP<00T03@L;
00`62P0;1@T020<900<010080`T030D<01@=500<1@`00`0?1@d301053@H03`@:00H04PL=01P=4`0D
2@l04@H<01873@0?10X600h32@8040D;0P0>0`T00`0?10X040D;ooooo`0Cooooo`006oooool0700<
3PT03a4<01HH4`0F61<04A<>00d?2P0@4Pd04Q@?00h@2`0=3`X03a4<00/=200A4`h03a4<00/=2009
2`H03@l:01<E400I6aH0418=00d?2P0C5A004Q@?00lA300J6aH05aPC00T:1@0B4`h201<D3`0300h?
2P0?40/03Pl:00803@h90`0?40/300h?2P0400d>2@0@4@`02``700`=20804Q<>00D0414<00d>200=
3PP03Pl900l@2P0300hA2P<03A8;00H02Q49014F40041P<03a4>00d?300@4Pl200h@3@0<01LI5P0I
6aP04A<@00P:1`0;3@X03Q0=00d?300A4a00=SPe04A6A00B51403@l<0P0<3P/0100?4@h0418?00d?
300<3P/200d?300400h@3@0=3``03@l<00d?30803Q0=00l03a4>00h@3@0>40d0418?01DG500=3``0
10H401`N6`0<3P/03@l<018D4@0>40d03a4>00d?300>40d00P0:30/0900J71/07R0O010B4@0;3@`0
6adL065SHP0?40l03a4@01PJ6@0O8B00b/[80>WYi`0b<S005QHD00X:200C4a404Q8@00h>300=3@/0
6QXH028R800E5A<030`:00l?3@0@40h03@d;00l?3@0D51804A4?00h>300=3@/03`l=010@3P0>3P`0
3Ph>014A4@803@d=00T0410?00`<2P0<30X03Ph;00h?2P0=3PT03Pl:010A2`0@40h00P0>3P`06`0?
3`d04A4?010@3P0:2PP030`:00h>300?3`d0410>00l?3@082@@04A8=00T:1`0?40/03Pl;01HG4P0A
4Pd03Pl:014B3@0@4@`03a0;018C3P0<3@P03@h901`M600;30P04Q<>00X;1P0200l@2`0L00`=200>
3`X04A8=00l@2`0A4P`03a0:00/<1P0L7AL09BHP00/<1P0<3@L03Pl9010A2`0B4`d03Pl900`=1`0>
3@T04A0<010?2`0=30P040l;01<B3P0>3@T03`h:010?2`0>3@T04A0<014B3@8030h902804A<>01LI
500I6aH05ALB010B3@0>40/04Q@?01dO6P0L7QT04Q<>010A300<3@P05QLB01@E40092PD0414<00l@
2`0<3@P04A8=01TJ5@0C50l03Ph;00d=2`0B4Q00410>00`<2P0W9bD0ATI400d=2`0J6QP03@d;01LG
5@0@40h04A8=0`0@4@`00`0A4Pd04a@?01@E400200h?2P0@00X;1P0B4`h04a@?01DF4@0A4Pd05AHA
01@E400>3`X04a@?02HW8P0@4@`03a0;00d>2@0<3@P04A8=010A30803a0;00X03Pl:00l@2`0@4@`0
4A8=01@E400B4`h03a0;014B3@0@4@`03Ph<0P0B4Q005`0>3P`030`:00l?3@0@40h03@d;024Q7`0@
40h04a<A00d=2`0?3`d04Q8@010A300@4@/04Q<=014B300@4@`0410=01XJ6@071`P05ADH00L62P0F
4A@05A8C00804a4B02H04A0@00l?3@0>3P`0414=010B3@0?4@`03a8<014C3P0@40h04a4B01DC500D
4a<03`l?00d=3@0E5aH05QPG018D4`0>4Q40:Bd/05=GEP0?4@h05aTF01dO700A4a00418?00`>2`0S
9B806A/H00h@3@0A4a005aTF00h@3@0@5@l04aPB014F400D6A<05Q/E01<H4P8051TC0`0C61804P0C
61405ahE01<I4P0D6a<05A`D01<I4P0B61806B0I03Dj=P0I7a/04ALC01`Q800>5140<SPd02hd<00H
7QX03Q@@01TO6`<051XF01/05A/G01HL600F71P05adI01@J5P0K8Ad0620K01@M600I8Qd05R0K01dX
8P1LIf40Oh^501PU7P0G91d04QlG01@Q600F8a`05B8K01@Q6P0F8Qh05b<O01HR7P0E8Al05R8P01LS
8@0J9RH00P0D8b00100F9B805bHS01PW900F9B8601TX9@0W020^;P0`?Sh0:CLg01HT900N;2`0830`
028a=00L;Bl0838d02@f>P0N<3@08C@i01lc>P0N<S/0:3a501P/=@0Y?DH09c]202Hk@00W?440:3e2
02Pm@00V>ch093Tl024e=P0[?d40=4M;02i1A`0W>T00;D160354B`0Z?D@0:3]102m2AP0cATT0:Shm
02]1?P0Z@C/0:3li00<0:3hk0P0^A4805`0/@T00;D930356A`0cB4T0<DI70397B00dBDX0=da=03Q=
CP0fBd`0=DY;03iCE00kD540<dQ903]@D@0aATL0>51@04AIFP24VIX0@5ID03]?CP0cAdH0=d]90080
>Da80P0gBTH0=@0hBdL0=TM10352?00gB480DV=M03A5?@0/?CD0;Chf02m0=P0`@CL0;Sle02Xl<00X
>Rh0;Sdf0350>@0fACh0<dDm02/o=P0Z?SD0<44i02hm=P0]>S<0:SD_024Z9@0^>CD0<3do02dh?00^
>3X0<3Xl03m9BP0/=CT0?4I?03i9E`1IIWd0EVF203a;J`19FWL0NhnW04iSN@17Ffd0@5=Q02@h@`0j
CED0=DQ>03=4B`0dAD`0<D990393B`0c@dP0<d=302/k>`0V=SH093@d0080:c/k01h0:3Ph02Xj>P0Y
>CT0:3Ph02Xj>P0/?T00:Ca002/m?`0a@T@0;3/n02Hd=@0/=cT0:3<e02H`<@0Z<S@0:c<e02H];P0N
:2H082/W024/:00G81d0<3Tf01/T8@0L8R007B<Q01`P7`0N8R408RHU020T8`0O8b82020T8`0:01lS
8P0N8R407b<R020T8`0N8R406QhM01TM700M8B0092TV01`N6P807AhI00h071dH01XK5P0I6AL05QHD
01TI600G5aL061PH01hN7`0K71h05aXI01TL6`0J71/06adL01/L6`805ADC00h05aLD01PG4`0H5a<0
5aD@01@C3`0I61H05QHF01lO7`0Z:RX061PH01lO7`0Z:RX06a/K01DE5@8061PH01@061PF02/[:@0L
71T04a<A01@D4P0F5QD04Q8B014A4@0C4a@04Q8D01<C5@0I61d07AdO014A4P0?3`l05ADE018B4P0?
3`l02PX:01@D50<04Q8B01804A4A010@3`0C51003`l=014A400L71d06QTN01<B5`0D4aL04Q8D014A
4@0A4A004Q8?018B400D4Q<03P`?00`:3@0A3a82018@5@06010>4`0I5Qd0;b`c08N4R`0@3QH040dB
1@0>30d0500?3@h0>SPi044o@00C4A801PD500`:2`0A3Q0030L;00l:3P0>2@d03`X>01HA5@0A3100
40/?00l:3P0>2@d03`X>010;3`0B3A403PX=0P0@2`l02`070`H05Q4E00l:3P0<1`/02PH900/72P0B
3A404@`@00`72`0?2@d04`dA00805Q0D00H05@lC00d72`0e;c<04@/?018<400;1PT200d72`0500T3
1`0L5QX0:28V018<400=1`/00P0>20`02P0?2@d03PP<00h8300=1`/03PT?00P32@0?2Q002`H<010;
4@0;10/200h73P<040H>00<04@H>00l42P0?10X01@0?10X01@0D2@l04@H<00h32@0?10X03@8800H0
3P<900H040D;00l42P0>0`T03P<901052`0A1P`Dooooo`006oooool03`0B50l03a4<00X<1`092`H0
3@l:00h@2`0?4@`04Q@?00h@2`0=3`X03a4<00`>2@0=3`X03a4<00h@2`0200d?2P04010B3@0D5Q40
3a4<00d?2P80418=00d03a4<00d>2@0<3@P02P/601<D3`0B4`h06AXE014B3@0B4`h04A8=00h?2P0=
3PT03a0;00<03Pl:00@03@h900`=200<3@P0414<0P0=3PT00`0>3`X03@h900`=200200d>200500h?
2@0?40X03Q4:00hA2P0<3`P00P0:3`P0300<4@X031<;00hC3@041P<00@<0010B3`072@H030h;010B
3`0?4@h0418?00d?30802@/800L04A<@000100031@80@dE204i@C@000@005QPE00803Q0=00@0418?
018D4@0A4a003@l<0P0;3@X0C@0<3P/02`d:00/=2P0;3@X030h;00d?300>40d03@l<00`>2`0:30T0
2@/801/M6P0:30T0828O01XL6@0@4Pl02P`9018D4@0?4@h04A<@010B3`0?4@h03Q0=00X<2@072@H0
2@/8014C400?4@h03@l<01DG500620D0418?01<E4P19BDL0I6AR01LG5@0A4@l05ADC018B400?3`d0
3Ph<00`<2P0B4Q0061PF018B40092@L03@d;010@3P0=3@/03Ph<01<C4@0A4@l03Ph<00d=2`0>3P`0
410>00l?3@0>3Ph04A4A00h>3P0=3@d0410?00`<2P092@L03Pl;010A300>3`X03Pl900l@2P0A4@l0
3@d;00`<2P0=3@/03Ph<00d=2`0<30X03`l=00804Q8@00d03`l=00/;2@0F5a800`@001XK5P0H6A@0
7b0K00@5000A4Pd03@h900l@2`0>3`X03a0;00804a@?00D02``700`=200Y:RD02@X500l@2`02010A
300R00d>2@0>3`X0414<00h?2P0>3`T03@h800/<1P0Y:R@0<S<]00d>200<3@L02``600h?2@0B4`d0
414;00d>200=3PT0414<00l@2`0;30L03a0;01<D3`0L7AP02P/600d>2@0>3`X02``700h?2P0>40/0
30h900lA300E5a8061XE018D3`<03Q0;01/04A<>00d?2P0<3@P030d800h?2P0@4@`051D@01DF4@0<
3@P03a0;00h?2P0=3PT04Q<>014B3@0:2`L0418?00lA3P082PL03a4>00P:1`10@Sl02P`9018D4@0=
3``0418?00d?300A4Pd00`0@4@`0300A4Pd04a@?01<D3`0:2`H05QLB01@E400=3PT0414<00/<1`0?
40/03Pl:00/<1`803Pl:00H05QLB01DF4@0>3`X04a@?018C3P0@4@`2014B3@<0414<04d04A8=00l@
2`0B4`h04A8=00l@2`0B4`h0414<00h>300@40h03`l=00h>300?3`d0410>00d=2`071`D03`l=00h>
30092@L03`l=00d>2@0A4Pd03@h900l@2`0F5a804a@?01<C4@0A4A003Ph>00820P0=3@h03`lA018>
3`0C40l04a8@01@C4@0B4Q004A4?00d=2`0@4@h03a4>00d?2P0=4@/04A<>00h>300>30d03`d>010@
400<30`020X901PJ6@0;3`h03A4@01XN7@062PT000<2014C400M7a`09BLT01LI5P0B51403Q0=02@V
8`0F61D03Q0=00lA3P0C5A803Q0=01LL5P0E6Q@05a`F01HK5@0B5a404aPB014F400B5a404aPB01@I
4`0201DJ500B01LL5P0D5Q405Q/E01DI4`0C5A005QXE01<H500[;BX04QDB018G4`0D5Q<06R0L02<Y
9@0U:bL04ALC00lE4@0>51006b4M0P0G7AT03@0D6QH05A/G01XP700L8Qh04aTE01PN6P0E7AP051dH
01XS7P0E7aX072LQ03E0>P0Q;BH00P0K:2401P0C81P05R<J01LT7@0G91d05R<L01LS7`806BDQ00X0
6BDS01LS8@0F8R005B4Q02Dc<`0O;Bd05R@T01DS8`0I9bL07B/[1P0K:BT01P0N;2`0:SPh028`<00A
8B005bLV01`/;0807Bla01d07c8c01ha=@0M<3@09STn0396C@0gBe@093Q10396C`0E:C80;D5802<h
?@0T>Ch09ca102Pm@00V>ch093Tl02Di>P0[?d40<TE902i1A@0X>cl0;3m302m2B011E5P0?4mC0313
A`0^@T@0<dM602Lm>P0302Hl>@0W02Lm>`0X?S`0;TA202i4@`0_A4D0<DI703=8BP0dBD`0<dQ;03Q=
D00iCU40=DY=03I;CP0jCe80@eQK06AiO00Y?T40<dQ;02i3AP0lDE@0=dm?03eBD`0fBd`0=de;03iB
D@0Y?C`0=d]903U<B00hBdL0=dY603Q;A`0jCDT0=DI003a=A`0b@cd0<44k02dn=P17F500<44i0080
<D8h04P0;Sle02/m<@0Y>bl0;3de0311>@0fAcl0<d@l02m0>00b@c/09cH_055NE`0S<2T08bhX024/
9P0V<Rh0;chn02@b<`0^>c/0<3`l03M1@`0_>Cl09Bli03i:FP1DHGT0@e9c04QHO00nD6h0@EE^02e1
F@13F6`0?eES03A7E@0fBU80<TI=03Y=D`10DeT0=dYA0393B`0gAd`0<T1103E3A00[>CX07bd^02Dc
=00]>c`0;3Xk02dk?00/>S/0:3Hg02Le=P0U=CH0:3Lj0350@`0hAdT0;cdn02Td=P0U<C40930`02<]
;P0R:bX08BXY020Y:00T;b/07bXV02Td<00U;R/0BU=@02/d<@0M8b408BLU028V9@0O8b82028V9@1>
024U900U:BP09b/Z020T8`0O8b809b/Z01`P7`0M8B00720O01PL6`0J7Qd08RHT01dO700N81/07b4L
01lQ7P0N81d07AlL01PJ6@0M7Ql06a`N01dN800S92H08R<U01@H5`0J7A`06A/J01/M700L7A/04a<A
01LG5@0I6AH06QTE01TH500G5A004a8>01@C4@0A4A406a/K01HF5P0D51@05QHF01dM7@0D51@04Q8B
01<C4`0B4Q804a<A01PH5P0C51004A4?01@D4P0H61L06ATI018B4P0C4a@05ADG01PH6P0F5AX051@F
01<C500B4Q805ADE01`L700C4a<06QXJ018B4P0?3`l0410@018B4P0@41003Ph>00P81P092@T020P8
03Ti>@0S8bD020P:0P0@4180400@41003`l>00h>300>3P`09B<T01LE5P0D4Q<040hA014?4P0;2@`0
5aDJ01HD6@12@4D0Q86800P5300>310500d;300900P61`0J61T0:2HW00<10P0100003`d>00d9300:
1@T03`X>00805Q4E00D05A0D018=4@0B3A404@`@010;3`0200l:3P0<00/62P0O6Qh01@0400h93@0F
4AD04@`@00`72`0F4AD061<G01@?4`0:1@T010030P0;1@T04P0=1`/03PP<00l93@0@2Ph04`dA00/5
2@0=20/04P`@00P21P0J51P02`D901<=4@0:10P0100201<=4@0B310030H:00d72`<03`T=00L03PP<
00H11`050`P04@lD00T42P0=20h040/A00<03PL>0`0@1Ph600l42P0600h32@0D2@l04PL=01052`0B
1`d040D;1P0>0`T01P0?10X03P<900h32@0>0`T040D;014631Cooooo000Kooooo`0I010B3@0A4`h0
3Q0;00`>2@0=3`X02P`700h@2`0A4`h03Q0;00d?2P0@4Pd03@l:00X<1`0?4@`04Q@?010B3@0=3`X0
30h900X<1`0>40/03a4<00h@2`0?4@`04A<>01@E400200l@2`09014B3@0:2`H04a@?00h?2P0@4@`0
4A8=010A300B4`h04a@?00803a0;0P0>3`X0200=3PT030d800h?2P0@4@`04A8=00l@2`0=3PT030d8
0P0=3PP01@0>3`T03a0:00hA2P0>4@X030l800802@h700P02a0900dD300A5A0071hK0043000B5140
61XG010B3`803Q0=00X030h;00lA3P0B5140418?00`>2`0J71T04aDB00X<2@082PL05QPE0P0=3``0
1@0;3@X03@l<010B3`0@4Pl03Q0=00803@l<03403Q0=00d?300=3``03@l<00h@3@0@4Pl04A<@010B
3`0>40d0418?014C400f>3D06Q`I01HH5@0<3P/04A<@00L91P0B514030h;00lA3P0<3P/04A<@01HH
5@0D5Q<03Q0=010B3`0?4@h05QPE00840@0:30T04Q@A00X<2@0?4@h05ADC018B400E5A<01PH401HF
500<30X02`/900l?3@0=3@/02PX800d=2`0>3P`030`:00h>300?3`d030`:00802PX801X04Q8@00h>
300=3@/03Ph<010@3P0?3`d03`l?014A4@0>3Ph03@d=010@3`0<30X04a<A01TI5P0I6QD05AHA014B
300@4@/04A4?00h>300;2`T030`:00d=2`0<30X0410>00h>308030`:00X03Ph<010@3P0?40/04A8=
0083000D5A00TY>>02LX8`0C50l03a0;0P0@4@`0200A4Pd05AHA00`=200<3@P071dH07IgLP0D5A00
3a0;0P0A4Pd06`0=3PT03Pl:010A300=3PT04a@>00X;1@0C50h03@h8010A2`0D5@l03Pl900X;1@0;
30H0414;014B300@4@/03@h9014B3@0?40/02``700h?2P0C50l0@d@o01HG4P0?40/04Q<>010A3002
014C3P0C00h@2`0=3`X03@l:00/=200?4@`05ALB01<E400<3PT03a4<01<E400C50l02``7018C3P0<
3@P0414<01TJ5@0:2`H04Q<>01DF4@0200h?2P0>018C3P0E5a<03@l<00`>2`0E5a@01`T6010B3`1l
OW/061XG00H81@0?4@h06A/H014C400A4Pd3010A300D014B3@0C50l04Q<>00`=200R8ah071dH00`=
200A4Pd03Pl:01LH4`0B4`h020T4014B3@0F5a802``701LH4`0=3PT05aPC01DF4@0A4Pd2018C3P06
014B3@0@4@`04A8=018C3P0<3@P03a0;0P0>3`X0100B4`h04A8=018B400@40h300d=2`0e00`<2P0=
3@/03`l=00l?3@0F5Q@03Ph<00l?3@0?40/0414<00X;1P0;30L04Q<>00h?2P0:2PP05QHE00h>3P0G
5aL03@d>010@400A3@`04a0?01@C4@0E518051@B018B400<30X0414?014C400?4@`03Q4<014C400B
4Q8040h?00l?3`0C4a<04Q@C010B4@0I6aX06QhM00hB4@0<40l03A4@01HJ6@0<3P/04A<@01DG500<
3P/04aDB01DG500A4a0030h;01DG500C5A800P0;3@X02P0B5a403a@>01DJ500E6Q@04AH@01DJ500@
5@l04AH@018G4@0E6Q@201HK5@0U01@F4@0@4Pl05QPC01LI500E5a806adI01@F4`0M7a`05QPE02<U
8P0B514061dI00P>2P0K8Ad05adI01TO6`0;4@d05A/G01HL600O9B40728N01HL600J81`0728N01DK
5`0K8Ad05ahJ018K5P0I8Qd04adH01hY8`0mB48082`V01<P6@064``06BHN01HS6P0201PU7P0>01LT
7@0G8al072PT01l[9`0N:RP06bLU01LS8@0C7al0>DM702lm?@0L:RX05R@T01XX:00O;Bd601d[:`80
82h^01h07bd]01d];00O;bh0:3Ti01X/;P0Q<cD07S8c01`_<`0T=c/093Ll014U;00gBe@08SHo02Xn
A`0R=Sl09CU0024f>`0S>3d09S]002Pm@00V>ch093Tl02i2@`0U>3/08cHj02Hi?@0]@4@0>4]?02/n
@P0_@TH202Pk?`030395B00cAdP0:T0n0080:T0m0100:d4n02e3@00^A480;TA202m4A00aATL0<TM8
03A9B`0eBTd0<DI903Y?DP0lDE@0>DiA03]@D`14FE`0?55D0P10EEP0D`0hCE00>e1C03U>D@0lE5@0
>4e>03iCE00aAdD0:Cdl03U=C00gBdT0>Da803Q;A`0gBTH0>4]703Y=B@0gB480;Chh02`m=`0jBdD0
93D]02Xk<`0b@c/0<44g02m0=P0^?cD0;T0d02do<`0[?3@0;Slg03=4?00^?cL0:c`d0350>@0eA3d0
Ohb5034n=`0d?cT0=T4k03A0?00a@3h08S4^03=0?P0lB4H0A4i?045<C`0iATh0Df1`03M5G00lBfX0
Ff^=04iQO`1:GWL0@5A/03]@I00P=T@0<dID03eAF`0kCeH0=dYA03A7CP0_@TT0<45903Q7C00c@D80
>TQ902Pf=`0Q;c00:CLh02hl?@0[>CX0;S`m02lm?P0/>S/0:cTj02dk?@0^?D00<T130390@P0Y=cP0
;3Li024];@0R;Rh092h_00808b`[01<09Bh]02Td<00H8al08RdY01hW900j@d005AhK01hT8P0S:BL0
9BTX01lS8P0Q9B@08bLV01hR8@0S9bH09BTX01`P7`0K7ah09b/Z00807B4P00L07R8Q01/O7P0H71/0
5a/J01PJ5`0I6aH06adH00806adJ01P06Q`I01HH5`0K7Ad06Q/M01/L7P0N7b406a`N01@H5`0K7Qd0
6A/J01/M700L7A/04Q8@01PH5P0J6QL06aXF01XI5@0G5A004Q4=01TH5P0C4a<06QXJ00`<300E5AD2
01@D500701DE5@0H61P05QHF01<C4`0G5aD04Q8@01<C400201<C4@0/01<C4P0B4Q804a<C01@D5@0I
6A/06a/M01<B5`0<30h04A4B018B4P0D51@06QXJ00P8200@41004Q8B00h>3P0?3`l04Q8B00l?3`0=
3@d04Q8B01HF5P0E5AD0G5aL03Ti>@0B4Q803@d>010@400A4A403`l?00`<300:2PX05aDF00/92P0=
2``03P`?01DC5P0?3A00518G00D3200D4QL07AXQ00/83`0@3Q8500d;300@010>3`0200402`T:018@
4@0A3a00518C00L41P0J5AT071LK010<3`0910P030L;01<>4P0@2`l03`X>00h93@8030L;00X03`X>
018=4@0L5a/0@ci200L21P0:1@T04@`@010;3`0:1@T03@P<0P0;1PX04P0F41@04`dA014;3`0>20`0
3@L;00`62P0:10P04P`@01D?4`090`L0?SPl03li?@0>20`040X>01@>4P0@2Ph04`dA00X4208030H:
00X03PP<00l93@0?2@d03`T=01@B5`0;2@h03`dB010;4@0F4AL030L=0`0>1`h301063PH03`@:00H0
2P0501052`0>0`T0304700l42P0=0PP:00h32@0301052`0A1Pcooooo01?ooooo000Kooooo`07018D
3`0@4Pd03@l:00/=200=3`X04A<>010B3@03014C3P0900lA300=3`X03a4<018D3`0A4`h03Q0;00lA
300D5Q4030h900803@l:00D030h900h@2`0@4Pd04A8=010A300200l@2`803Pl:100@4@`01P0>3`X0
3@h901DF4@0K71L051D@00l@2`804A8=00h08b@O038c;P0I6QD030d8010A300720<0414<00`=200C
50l03a0;00d?2P0>40/02`d8010E3`803A8<01d02@h900dA300>40d03@l<010B3`0B51404A<@00`>
2`0?4@h05aTF01HH5@0?4@h030h;00lA3P0=3``03a4>01DG500@4Pl03a4>01lQ7P0F61D07AlL010B
3`0B51401`T6010B3`0>40d03@l<010B3`0200d?300T010B3`0=3``030h;010B3`0H6QL010H4018D
4@0620D0418?01<E4P0A4a0030h;00h@3@0D5Q<05ALD00lA3P0:30T03@l<00/=2P0=3``03a4>00d?
300<3P/03@l<00D7100F61D030d;00T;200?4@h03@l<00d=2`0>3P`03`l=00d=2`0;2`T03`l=0P0A
4@l0100?3`d03@d;010@3P0A4@l300l?3@0500h>300=3@/03@d;00`<2P0>3P`00`0?3`d03P0>3P`0
2`/;01`L700G5aL03@d=00/;2P0=3@/04A4?01lO701hNG@04Q<>010A2`0>3`T03Ph<0P0=3@/02@0<
30X03Ph<010@3P0=3@/03`l=00X:200;2`T0410>00h>300200`=200401@E400720<0824L014B3@80
3@h901@03Pl:00l@2`0?40/0414<00h?2P0<3@P03a0;01<D3`0>3`X02@X500h?2P0=3PT030d800h?
2P0A4Pd04Q<>00`=1`0=3PP03Pl9010A2`804A8<00h04Q<=014B300?40X030d700d>200?40X04A8=
00/<1`0D5A003@h900T:1@0=3PT03a0;010A30<04A8=00H04Q<>018D3`0B50l04A<>010B3@0?4@`2
00`>2@0300h@2`0@4Pd03a4<0080418=0P0>3`X01P0A4Pd04a@?018C3P0B4`h04A8=010A30<03Pl:
01l03a4=01/M6P092`P030h;01<E4P072@H05aTF01@F4`0<3P/04A<@00lA3P0T9R<04a@?014B3@0?
40/03@h900h?2P0@4@`04A8=01PI500];RT0414<00l@2`0D5A005QLB00d>2@0?40/04a@?00h?2P0B
4`h030d800804A8=00l0414<018C3P0>3`X03Pl:014B3@0@4@`03a0;018C3P0A4Pd0414<01@E400C
50l03@h9010A300B4`h00P0>3P`200l?3@80410>00`04A4?00X:200>3P`04Q8@010@3P0=3@X03@h9
018C3@0>3`T03@h9010@3@0=3@/2010@40804A4A0280410@00h>3@0G4a404@l;018A3@0G5Q@05QDC
00h>300C4a405aPE0001000K7AX03A4=01DI5@0>3Ph051@D00l?3`0C51<05QPG010B4@0<40l05ATH
00lC4P0A5aD02a4?00dB400@4a003a4>018D4@0A4a004Q@A01LI5P0E5a@03Q0=0P0D5Q<01@0J71T0
4aDB014F400J7aT06AhH00804aPB01<05Q/E01<H4P0F6aD04AH@018G4@0H7AL061dH01PK6@0@4Q40
61/I01@G500T9R<061XG01dP7@0K7AX061/G01PL600H6QL051TE00805adI03/05A/G01dS7`0S:BD0
8BLS010F4P0O9B406AlK01dS7`0G7AT06AlK01PN6P0I7a/0620K01HO6P0D7AP04adH01/V800E81X0
5b<M01<P6@0B7aP08BhV01XW7P0G91d062DN01XW800H92005b<O01HR7P0I9B<0CUYH020/:P0K9bL0
9S@e01`Z:`0F92D06RPY01TW:00H9RL06BLX01PV9`0G9BH06BLX01`Z:`0P;Rl06BTX01h^;@0M;B`0
7Rh]02<d<`0O<C408C@e02@h>@0N<S<07c@g01/`<`0N<cL09c]2028f?`0202@h@@0>01da>P0W>d80
734f02@i?P0X?D80:d1302Hk?P0S>3/09cXn02Pl?P0Y?Ch0:cm002i2@`0Z?Sh302Tm?P0602m3A00d
B4X0;D5202Y0?P0X?S/0;48o0P0aAdD0=00Z@3h0;45203I;C@0iCU40=T]>03Q=D00kD5<0=T]>03U>
D@0mDUD0=DY=03]@D`1KL7<0DVMZ03Y?DP0hCE00?E9E03U>D@0lDE@0>U9B03Y?D010EEH0=de;0355
A00fBTT0>4a:03a?B`10Ddl0=dY603Q;A`0aA400=TM103Q9@`0dACl0;Chh02m0>00b@c/0=4Dm03E6
?00fAcd0=dPn03M9?@0fB3`0;d<j02dn=P0cA3`0<D0i02Pf;`0X=Bh0<3df02/h<@0/>C8202/h<@0N
02dl=@0_@SX0<D8i03U8?`0hACd0=d@m03Y7A00c@D<0>4I?03m?H@1AHWX0GW2<05Q/R01<HG/0@eUa
03mDJ00kDEl0=TaI03M<EP0lD5P0?51G03E9D00cATd0=DMA03U8C@0kAdL0=T9202`h>00Z=SH0:cLg
0P0/>3P01P0]>CT0;c/k02hj>P0[=cL0:cHg02Xf>080;3Li00/092la028^;P0T;Rl09Bl_02<];00P
:BP08BXY02Tb;`0U<2`092l[01lZ9P0201XS800301dV8`0U:bT08BLU00<07b<R00@0:Bd/02@X9`0P
92<07R8Q0P0T:2L03P0N8R406QhM01`P7`0L81l06QhM01TM700L81l07b4N01hP7@0I6aP0828O01HH
5@0J71/07b0R0P0P8B<0400O82@07QlS01hO8@0J7Qh061/J01LI600H6QT06AXI01TI5`0H61H05aLD
02PW8`0N7AT05A<?01@C3`0H5aD201HF5P<05ADE00h092@T02TY:@0E5AD05QHF01DE5@0@40h04a<A
01HG4`0F5Q@051@B018B4@0D51@04a<C01<C50804Q8D00D04A0E014A4`0C4a@05QHF01DE5@02018B
4P0301<C4`0H61P020P800804Q8B00X061PH01DE5@0C4a@03`l@00`<300E5AD06ATH00`<2P0A4A00
410@0P0?3`l200h>3`0700l=3@0?3P`040l=010>3`0?3A003P`?00l=400400l=4P0300l=400>30d0
3P`=00<03P`=00L03`d>00d;300>30d03P`=00T7200<2P/04@h@008040/?00@03`X>00h93@0>2@d0
3`X>0P0A3105010;3`0501PC5`0Q72004@`@00X52@0?2Ph01@0>2@d0300<1`/03`T=01@>4P0?2@d0
30H:00l93@0A2`l01`85018<400C3A40618F01/F6@803PP<0P0=1`/03P0@2Ph04@/?00/62@0;1@T0
5Q4D04m9C@0?2Pd03PT=01HD6@0920d061HK030^<`0X9R/050lE0P0?2Q002`0?20l03@H=00d63@0>
1Ph03P<901873@0?10X04PL=00d4200M4QP040D;00803P<900<040D;0146300?10X01P0?10X01P0F
2a403P@900d4200D2@l02P0500h52ACooooo000Kooooo`0800d?2P0>40/03Q0;00`>2@0>40/04A<>
00`>2@0>40/2014C3P03010B3@0>40/02@/600804aD@00X03@l:010B3@0J71L030h900h@2`0=3`X0
30h900h@2`0@4Pd03Pl:0`0?40/2010A300@014B3@0;30L03@h901<D3`0?40/02@X5018C3P0I6QD0
4a@?00`=200>3`X04A8=00d>2@0F5a803a0;00h?2P8051D@01804A4?00T91`0@40h03`l=00T;200A
4a00418?00lD400320@02a0<00L=2@0B5Q<03Q0=00X<2@0<3P/04A<@00lA3P0>40d201<E4P0700lA
3P0;3@X030h;010B3`0>40d03a4>01<E4P02010B3`0b01/M6P0A4a005aTF01PJ5`0C5A802P`9014C
400=3``03Q0=014C400<3P/02P`900d?30051`@02@/801TK600U9b@03a4>01HH5@0H6QL05QPE034c
<00H6QL0418?01LI5P041P<01`T600T;200A4a002`d:00/=200=3`X03a4<00d?2P0<3PT03@l:00X<
1`0D5Q404Q@?00d?2P092`H02`d8014A3`0=3@/02`/9010@3P0C4a40410>00h>300?3`d2014A3`03
010@3P0?3`d03`l=00803`l=00D03Ph<00d=2`0=3@/030`:00h>300300l?3@0B00h>300@4100410@
00T92@0:2PX061PG024Q7`0A4@l02@T602d^:@061`803Pl900X;1@0A4@l02PX800T91`0>3P`04A4?
0P0=3@/04P0>3P`0410>00h>300=3@/051@B01DF4@0=3PT0:2TT01LH4`0;30L02P/600l@2`0=3PT0
30d800h?2P0?40/0414<00X;1P803a0;00L030d800/<1`0<3@P03a0;00h?2P0=3PT03Pl:00803a0;
00L030d700X;1@0:2`D03Pl901@E3`0F5a403@h80080414;00T03Pl900d>200=3PP04aD@010B3@0:
30L0418=00lA300:30L00P0@4Pd4014C3P0900lA300>40/03Q0;010B3@0A4`h0418=00lA300A4`h0
418=00803Q0;00H03a0;00`=200=3PT05AHA01TJ5@0D5A0200l@2`0:00h?2P0=3PT03Pl:00l@2`0D
5A4051TE00T>2P0?51004aPD00X?2`803A8>00@020d900`?300@5A405aXG0`0A4Pd3010A300N018C
3P0A4Pd051D@00@5000C50l04A8=01@E400=3PT051D@018C3P0H6A@06Q/F01LH4`0@4@`03@h9014B
3@0@4@`03Pl:00d>2@0A4Pd0414<014B3@0E5Q4051D@00d>2@0J6aH07b0K00l@2`0;30L04A8=0`0@
40h01@0A4@l04Q8@018B400W9bD05aLE00803Ph<02L03`l=01@E400>3`T05QL@00l@2P092PD03Ph=
01@D500;2`d04A4B014A4@0?3`l03`l>014A3`0A3@X040h:010?2`0B4@d051<@01@D4P0@40h0414?
01<E500?4A005QTH00/?3P0C4a<03a0@01<E500>40l041@C01/O7P0@51<04aTG00P>300220H0;cPe
02P^;00J7AX00P0E5a@04@0B51404A<@01DG500O8Ah03Q0=01LI5P0H6QL04A<@00h@3@0D6A<04AH@
01<H4P0H7AL051TC00lD3P0E6Q@061dG00805AXD00h05a`F01HK5`0<4A000PH700hD500O92<06QhM
018H5@0L8Qh01@X601XO6P0C6Q<05Q/E01<J508061hJ00<051XF01TO6`0N92000P0E6aL05P083PX0
:Bl[00dC3`0K8Ad07R@P01`R7P0H7QX061lK01XS7P0I8Qd05R0J01dX8P0I91h05R8K01HS700?71D0
5B8J01HS6P0F8a`062DN01LT7@0F8Qh201DQ7@0[05=OG@3@g=X0DEeK01DQ8@0T<S<07R`]01`Z:`0K
:BX062HW01/Y:P0X=SL08Bl`01PV9`0I9bP07B//028`<@0N;Rd06b/Z01d`;P0R=C<083<a01ha<@0I
;Bh06bl`01`a<P0W?3l083Dh02Ll@00cAdh07c<l01hb>`0aADh0:cm802Pl@`0dBDh0:Sm402Dj?`0g
C4l0;dA702Ll?`0Z?D40:3`n02Tm?P0202a0?`0I02/o?@0U>CP0:3`k02Xn?@0_@d@0<dI902/o@00[
@Cl0:Clm02e3@@0aAdD0<DM602a1@P0T>C`0<4E803eBE@0nDeP0=T]@0315B00jCe80=DY;03Y?D00h
CDh0<4E603E:B`0203I;C00;03eBD`0lDE80=T]<03eBD`0iDE40>e1A045FE`15FeT0CV9Q0396A@0/
@3h00P0cAT801@0Y?3P0=dY603]>BP0fAd40<T<m0080;d0j00h0<D8j03=4?00fAcl0<d@j0352>00b
@cT0=4Hj03E7>`0jCTD0?U9903m@B00`?cP09c@]02Xe;`80<3/e02<0<C`f02dj<`0]?3D0<d8k02`o
=00a@SP0>DXo03I6>`0e@SP0<T0i02Le=@0/>ch0?e5L05Y]OP1QMXT0DFIo05E]Q`1GKHD0@EM]03I=
G@0hCU`0>E1I03aCF`11EEh0@5AM03]?F00jCUL0Df=W04EAC`0[=cD0=40n02Da;`0O:bT0;c/i038n
?003030l>P0:02hj>00`>c`0;SPj02/e=`0Y<c@08bd^02D_<00Z=3<0:38a02D_;@<09C0/0P0T;b/0
2P0S;RX07bPU01hW900P:BH07bDS01hT8P0S9bH08RHU01hR8@0Q9B@4028V9@0C024U900P92<07R8Q
01hR8@0L81l05a/J01PL6`0O8b806b0L028W8`0H71/04QHE01/O7P0H71d08RHW01dQ8`0K7b807B4T
01lS9P0201`P8@0=01PK6P0E5aH05QPG01XK6@0K6aT061PF010?300I61@04A0<01<A300G5Q8051<A
01@D500201DE5@805aLG01<04a<C01dM7@0C4a<06QXJ01`L700K6aT04a<A01HG4`0F5Q@051@B01<C
4P0D51@04a<C01<C500C4aD04Q8D018A5P0B4Q@04Q8C0080410@01L04Q8B01<C4`0B4Q8051@D00h>
3P0E5AD0410@018B4P00000020P:01XJ700B4Q8030`;00`<2P0B4`h03Pl:00l?3@0?3`l03`l@010?
500@41803`d=00l>3002010?3@0300l=3P0>30d03`d@00803`d@0P0?3A800`0?3A003P`=00h<3@03
00h<3@<04@l@00D05A<D010>3`0<2P/03P/=010;3`0300l:3P0>00h93@0A31003@P<00X52@0?2Ph0
3@P<00/62P0?2Ph08ahR01D@50060PD04PdA00h93@0=20`500`72`0[00`62P0?2@d04P`@00l93@0=
1`/03`T=01H@500@2Ph02PD800T31`0;1@T040X>00d72`0?2@d04@/?00d72`0;1@T03`T=010:3P09
0`L0100200d72`0A2`l0510C01`J7`0000@0<S4f0<[9cP3Lfn00BTQ=018=4`0=20h02@@:00h73P0@
2A003@H=01052`0>0`T04@H<01X?5@0F2a40=BX`0146300200l42P8040D;00<03P<900l42P0?10X0
100?10X01P15>T0060lC00`11`0E2Q005``B01<83QCooooo000Kooooo`08010B3@0A4`h0418=00d?
2P0<3PT03Q0;00lA300>40/200`>2@803@l:00`02@/600lA300?4@`030h900h@2`0D5Q403@l:00lA
300>40/030h900h@2`0@4Pd200h?2P0>00l@2`0@4@`0414<014B3@0@4@`030d800h?2P0C50l03a0;
00/<1`0A4Pd04Q<>010A300>3`X200d>2@0L00h?2P0=3PT03Pl:00h?2P0A4Pd05AHA00`<2P0D5180
3`l=00`<2P072@H04A<@010B3`083@T02a0<014F4P0@5Q8041@@018D4@0<3P/03Q0=018D4@0@4Pl0
3Q0=014C400@4Pl03@l<00/=2P803@l<0P0:30T03`0<3P/02`d:00/=2P0>40d020X7000100041P@0
3a4>00`>2`0@4Pl02`d:00d?300A4a002`d:00P:1`0200`>2`0F01DG500?4@h0418?00D7100>40d0
3@l<00/=2P0L7Q/03a4>00d?302Z[:T0BTa900lA3P041P<01`T6010B3`0;3@P03@l:00lA300=3`X0
30h900d?2P<03Q0;00/03@l:00P:1@0;3@P03Ph<00d=2`0<30X04A4?01LG5@0E5A<04A4?00h>3002
00d=2`0300`<2P0@40h03`l=00803`l=00D03Ph<00d=2`0=3@/030`:00h>300300l?3@0300h>3008
20P030`<00803`l?00T02`/:00<30@0B4Q002@X600h?2P0;30L04A8<00d>200=3@/00P0<30X01@0=
3@/030`:00T91`0?3`d02`/90080410>00l03@d;018B400F5a8051D@02//9`0L7AP02P/600`=200@
4@`03@h900`=200=3PT03a0;010A300?40/00P0B4`h0100@4@`03a0;010A300@4@`200l@2`<03Pl:
00L03@h800/<1P0;30H03Pl9018C3@0D5@l030d700803a0:0P0>3`T00`0@4@/04A<>01`N6@0200X<
1`05014C3P0>40/051HA018D3`0A4`h00`0@4Pd0100>40/030h900/=200<3PT300lA300C014C3P0@
4Pd03Q0;00lA300A4`h03Pl:00/<1`0D5A006Q/F01DF4@0@4@`03Pl:00d>2@0<3@P03Pl:010A300E
5a<04aPD00lD400200hC3`0700dB3P0B5a<0KW=_01HK5`0I7QX04QLC00D91P02014B3@804Q<>0P0A
4Pd04@0;30L04A8=01<D3`0:2`H06AXE00`=2P0@4@`05QLB00/<1`0=3PT00@8000P9100>3`X03a0;
01HG4P0A4Pd02@X500803Pl:0P0A4Pd02P0?40/04a@?018C3P092PD05AHA01XK5P0<3@P02P/6014B
3@0?3`d2010@3P804A4?02@04Q8@03Hf=00S8b4051@B010@3P0?3`d051D@00`=1`0B4``03a0:00`<
2P0A4A004a<C00l?4@0E5AL051@D00h>3P0<30X0414<010=200B40/040l;00h=2@0A40d05QHD010@
3P0@4@l05ALF00L9200A51<00@D400d?3P0A4Q805QPG01@F5@0>4Q42010D4`0601TO7@0?5A<07B<Q
09ZSX02[/Jl0720L0P0F61D0400D5Q<04Q@A01DG500V:2D07b4N03i0?@0g>CH04aDB01@F4`0D6A<0
41D?018G4@0G71H04aPB00lD3P0D6A<401HK5@0V01DJ5P0H7Qd08RPX01`R8P0@5QH0318@01<I5`0R
:2@01P`801TO6P0H7aP072<L01@J5@0M8al06b4M018H500A5a<04QPD01<I5@0M8al05A/G01/Q7@0@
5Q809R`X01LM6@0I7a/05A/G01LO6P0L9B006b@O01HP6P0J9Al062<M01<O6@0I9Ql05B8K01DR6P0G
91/201@Q6P1801DR6`0G8al07b/W01dY9@0D81h0BeME018N700G8b<06bTZ01XX:@0L:R/06bTZ01TW
:00Q;c00;C/l02Hd=@0J:2T062HW01XX:@0I9bP07bl^01PX9`0L;bd08cHd01d`;P0L<2l062`]024e
=P0N<c@09CXm02Pm@00]@TH0SZ:Y03A8D@0[?dP07c<l028f?`0V>T40:Ci3014V:`0U>Sl08cPk07>8
R`16Feh0;T5502Xm@00[?d00;D5002a0?P0]@Cl09CTg02Xn?@0[?ch0;T9302m3A@0W>Sh0;45202]1
?`0^A480<DM50397A`0_A4D0Bf1S03U>D@0aATT0=DY?03I;D00eBTd0>Di?03I;C00lDE80?E9C0P0f
Bd`0BP0jCe00?55B049GF00mDU<0=DY;03U>C`0iDE40<dQ903Y?D024VYP0X[Je04YNG@0jCT`0;T4m
03I9A@0aA400<4<o02m2?P0gB480<44k02ho>@0`@C/0<d@l03A5?@0gB400=4Dk03=4>P0b@cT0<T@h
0355>@0fBd80C61G04AHC`0Z>C80:C@^03@o>@0^>C<0;3La030k=@0_?3D0;Sdf0352>P0Y?C@0;Chf
03A5>P0b@SL0<Sle0392>P0U=C809cTk03]=EP17FVT0Aea]04ELM01AJH<0Bf1k03iDJP17GVh0A5YX
03Y@G00kDUX0?U9K03mCG00iCEH0=d]D04aLH00mBDL0:CDc03A0?P0V<S008bl]038n?00c?cd0;c/i
0`0]>CL02@0_>ST0:C<e02@^<00S;Bl08R`]02H`<@0f@3l0;cTh02Ha;@0202D`;00<024/:00T;b/0
9C0/02@_:`0P:BH07RLT01lX9@0S:BL08BLU02DY:00S9bH07B4P0P0N8R401P0Q9B@092PW024U900P
92<08RHU01/O7P806AdL00`07b<R02<W9P0U:BP082DQ028W8`0E6AP04aLF01XN7@0P92D0:Bd^01lS
9@0I7B0201`P8`0301HJ7@0Q9BH07B0O00806Q`K00X06AXH01LG5@0I6AL04A0=01LF4P0A40`05aD@
01XI5@0D4a404a<C0P0D51@201DE5@0300h>3P0G5aL0410@00805aLG0P0E5A<0100F5Q<05QHD01DE
4`0D51<201<C4`0O01<C500C4aD04a<E01<B5`0B4Q@04Q8C010@400C4a<061PH01DE5@0B4Q8051@D
00h>3P0@41004A4A020P800F5QH071/P00/;3@030`<051@C00d>2@0;30L03Pl:00h>300?3`d0410B
010?500A4A<03`d=00l>3002010?3@0300l=3P0>30d03`d@00803`d@0P0?3A800`0?3@l03P`=00h<
3@0300h<3@<04@l@00@06ALH01@B4`0>30d03@X<1@0?2Ph200h93@0;00`72`0?2Ph06QDI01PC5`0=
20`07aXN01<>4P0810L05A0D00X52@0;1PX01P0<1`/02P0?2@d04@/?00l93@0>20`03`T=00`62P0A
2`l030H:01<=4@0A2`l200l93@0300d72`0>20`03PP<00802`D900T0618F00/52@0K5AT04`dA014;
3`0b;C40;R`a01PG701XIf`00P3oo_l0401LFUl04`hD010;4@0:1@/02P<:00`5300=1Pd06A0E0146
300>0`T04@H<00/21P0`9B/04`P>01052`0?10X201052`0300d2200?10X03`@:00@03`@:00<03@88
01052`0C20h00P0700800`0<0@Ooooooooooo`0Booooo`006oooool06@0;3@P03@l:00`>2@0;3@P0
30h900lA300I6aH051HA00`>2@0;3@P03@l:010B3@0C5A003Q0;00d?2P0?4@`0418=00d?2P0?4@`0
418=00lA300=3`X03Q0;010B3@0>3`X00P0?40/2010A300T014B3@0>3`X04A8=014B3@0@4@`03a0;
010A300B4`h02P/600d>2@0B4`h03@h900X;1P0>3`X02@X500h?2P0=3PT02``7010A300C4a40410>
00`<2P0?3`d04A<@00/=2P0=3``02@d:04A9A@0`=3404QPD00lC3`0B51403Q0=00d?300?4@h03Q0=
0P0<3P/01@0=3``03Q0=00h@3@0?4@h03Q0=00803@l<02T030h;00h@3@0?4@h03a4>00L91P0R9240
?T0m00`>2`0=3``03a4>00d?300?4@h04aDB00lA3P0<3P/07AlL018D4@0@4Pl02P`901@F4`0=3``0
4Q@A00/=2P0A4a001@L401DG500N81d08R@Q00D7100?4@h02P`900P:1`0A4a002`d800d?2P0?4@`0
3@l:00`>2@0=3`X0418=00T;1P0200/=200600`>2@0>40/030`:014A3`0>3P`02`/90P0A4@l01P0>
3P`03@d;01HF500J6QP04Q8@00h>30<03`l=00D03Ph<00d=2`0=3@/030`:00h>300300l?3@0D00h>
300>3Ph04a<C00d=3@051@D06QXI03lo?@0>3P`04Q8?00X;1P0D5A00414<00l@2P0;2`T05QHD01PH
5P0@40h02PX800/;2@0A4@l200h>300;010@3P0?3`d02PX800P9100B4`h051D@00l@2`0>3`X030d8
010A300?40/0100>3`X01P0?40/030d800d>2@0@4@`03Pl:00`=20<04A8=00/0414<00h?2P0=3PT0
3Pl900l@2P0@4@/03a0:00h?2@0=3PP03a0:00h?2@0200`=1`0;014B300D5@l04aD@02<U800B50l0
4A<?01LI500F61<061XE01@F4@0@4Pd00P0=3`X01P0A4`h04aD@014C3P0>40/03@l:00h@2`803@l:
00T03a4<010B3@0?4@`0418=01PI500G61<03a0;010A300B4`h00P0?40/04P0@4@`03Pl:00d>2@0@
4@`04a@?010C3P0@5A403a@@010E4@0?5100314=01DJ5P19CTX0724M01<G500?51004QLC010A3080
4A8=0P0B4`h03`0A4Pd061TD01PI500>3`X071dH02l`:`0H6A@05AHC051AC00I6QH05QLB018C3P0@
4@d03Pl:00d>2@0200`=200?00l@2`0C50l04A8=01@E400A4Pd03@h900h?2P0<3@P061TD01XK5P0F
5a80414<01<D3`0D5A003Ph<00803`l=0P0@40h0>00A4@l06ATG014A3`0?3`d03Ph<00d=2`0B4`h0
3Pl7014B2P0C50h061TE01/K6`0@41803`hC01DE5`0E5AD04A4A00l@3@0C50l04a0;01DC3P0B4@`0
3Pd900l?2`0C50l03Ph<014B400?4A006a`N03m2@`17Bd`03Q0?01<E500=3`h06QhM01lS8P0A5A@0
2Q0>01DK6@0>518041TF05eVH`1LHV004aLC00d?300A4a004aDB018D4@0C5A804Q@A01DG500L7Q/0
9RPU020R7`0B51404QLA0P0E6Q@2018G4@0801DJ500C61804QLA01DJ500G71H05AXD01HK5`0?5aL2
018J701P01DN7P0C71/05AhL01HO700=5Q40628K018L500K9Ad072@N01HL600H7QX05A/G01LM6@0H
7QX06AlK00lE4@0J81`05Q`H01LM6@0Q9b<05Q`H01PN6P0G7AT061lK01LP6`0E7QT05AlJ01LR700K
9R0062@N01h[900R;bP062DM01DR6@0J9b008BhW01TV7`0F8Qh05b<O01`X900G8b404AdK01dY9`0M
:BT06BLY01TW:P0K:B`06BLZ01HT9`0M:bh06BLZ01PV:@0I9bX072X]01d[;P0L:bd08c<b01/^;00N
<Bl08cHd01lb<00O<c809CXk03E:B`0W?3d07cLi02U1@`0W?d80@EEL051TK@0_@d`08cM00355CP0Z
?TD0:d1502Ll@@0Y?T<0;T=606MlO`13F5/0<dI<02/n@@0]@D40;T9102Xn?00^@ch0:Chi02i3?`0]
@Cl0;D5202a0@`0U>3`0;T=402i4@P0`AT@0<DI70P0cB4T02@11EUT0?U=G04=HG@10EEX0=daA03Q=
D00dBDT0=Ta:03Q>B`0203I<BP0503Y@C@0gCD/0=4Y703I<B@0iCdd00P0jD4h04@0kDe<0=DY;03M<
C@1JL6h0Jgmn0355A00fBTP0?e9>03M:AP0bAD40?E1<03E8A00jBdD0=4Do0352?00b@cd0=4Dm0080
=TLo0P0gB3h09`0eAS`0<D<g02i2=P0]@ST0=TY103A7?P0^?CH0;CPb02`g<@0[=2l09c8/02dh<P0b
?cP0<40h0312?00^@T00;3hl0392?P0c@Sd0=D@n03I5@00a@D40<495041CG01/PHl0JGnA04YQN@1=
IGl0AUih03aDJ@16GFd0Aei/049II00mDeh0>U5I03aBFP0fBU<0<dMB03M6B`0203I0?`0703<m?00[
=C@0;SPg03@n?@0_>CP0:cDd02Tc<P0202Xd<`0802/d=@0U;Bl082PZ02@/;P0X<380;CHe03Q1@00`
>CP202<^:P0:02D`;00R;BL08bhZ02@_:`0R;BT07RLT01`U8P0M9R<08bTW020V90808RHU00<082@S
02L[:P0S9bH00P0V:RT05`0O8b806alN01`P7`0L81l05a/J01XN7@0Y;B`0;C4`02@X9`0K7ah05a/J
01TM700/<2l07R8Q024U9P0V:Rd07b<V01/O8P0M82D07R4V01XN8@0H71d06ahM00807R0O00X06AXI
018B400G5aD04a8?01XI5@0F5A406QPD01HE4@0J6AL06ATI0P0H61P03@0G5aL05QHF01@D500J6QX0
5ADE01/K6`0H61P06ATG01LG5@0F5a<05QHD01LG5@0F5QD00P0C4a<0600C4a@04a<E01@D5P0D4aP0
51@F01@D5@0G5aL06QXJ01dM7@0G5aL04a<C00d=3@0I6AT061PH010@40092@T06ATJ018A5P0?3a40
5QHF00h>3@0>3`X05aPC00h?2P803`l=00X0410B010?500A4A<03`h;00l>2P0@3`/040l=00l=3P0>
30d03`d>100?3A000`0?3@l03P`=00h<3@0400h<3@0600X82@0<2P/04a4B010>3`0<2P/03@X<100?
2Ph03P0@2`l03`X>01TD600H4aL03`X>02@O8`0R7B403`X>010;3`0>2@d04`hB00l:3P0;1PX03`X>
1@0>2@d200l93@0[010:3P0?2@d03`T=00l93@0;1PT03PP<00l93@0>20`03@L;00h8300B31002P@8
00/52@0A2`l03PP<00l93@0=1`/04P`@02DO8`0910L020<604E0A00W9R/03PlC02`[<02:RHh0V9NL
02TW;0081P/04@lD01dH7P0E41H03@P>00X42P0=10T04@H<01@93`0A1``09a`R07EZL00C20h04@H<
01052`020146300300h32@0?10X03`@:00@03`@:00H040H;01D:400=10P040H;01D:400;0PHDoooo
o`006oooool200lA30803Q0;00D04Q@?01LI500F61<04aD@00lA300200h@2`0>00lA300A4`h03Q0;
00h@2`0?4@`04A<>00lA300@4Pd04A<>00lA300=3`X03Q0;010B3@0@4@`300l@2`@03Pl:01@03a0;
014B3@0@4@`03a0;010A300=3PT04A8=00l@2`0<3@P0414<01@E400B4`h051D@014B3@0=3PT03Pl:
014A3`0F5Q@0?clm00h>30802`d:00l04aDB01LL600P9B405AXF00@:1P0>4Ph0418?014C400>40d0
2`d:00`>2`0=3``02`d:00X<2@0<3P/00P0>40d03@0<3P/03@l<00`>2`082PL03@l<00lA3P0H6QL0
0`D20001000X:RL04A<@01LI5P0:30T00P092`P08`0>40d030h;00`>2`12A4409bTV00d?300B5140
1@L40001000<3P/02P`900/=2P072@H03@l<018D4@0;3@X03a4>01<E4P0B514051HC00H71@0;3@P0
3A0900lB2`0=40T030l800d@2@0;3PL03a8;01XM5P0<3`P03a8;014C3@0=3@/04A4?008030`:00P0
5ADC010@3P0>3P`030`:01PH5P0M7A/04Q8@00d=2`<03`l=00D03Ph<00d=2`0=3@/030`:00h>3003
00l?3@0M00h>300B4Q801`L700`<300C4a<03`l>00T91`0;2`T03a0<014B3@0>3`X030d8010A2`0=
3@/051@B01DE4`0?3`d03@d;010@3P0<30X06a/I014A3`0;2`T04A4?00X:200:2`H0414<00P9100<
3@P00P0@4@`01P0>3`X0414<010A300?40/030d800/<1`80414<00D03a0;00h?2P0?40/04A8=010A
3003014B3@0300l@2`0>3`X03Pl900<03Pl90P0?40X2014B300A010A2`0?40X04A8<01<D3P0>4@`0
00<000X?2@0W;2H08BHP00/@2P0C61803a@>00`A2`0:3`T02a0:00hB300A4`h00P0@4Pd0100?4@`0
3Q0;00`>2@0<3PT200h@2`8030h900<04a@?01DF4@0A4Pd00P0?40/200h?2P0C00l@2`0>3`X04Q<>
01XK5P0P8A`051PC010F4P073@T0:Bl[03Hl>00@5Q801`d900lE4@032@D04QPD020V8P093@X03a4<
00l@2`0200h?2P05010A300B4`h05QLB02PY900K71L00P0=3PT02`0F5a80004002`]:00>3`/02``7
01@E400E5Q404A8=024R7@0M7QT02@X5008030d800`05QLB01PI500E5Q404A8=01<D3`0@4@`04a@?
01@E400@4@`03Pl:014B3@0=3PT3010@3P0A014A3`0B4Q004Q8@01DE4`0C4a405ADC01<C4@0<30X0
3@h9010B1`0B50X04a@>01LH4`0H61T03`hC00h=4P0@3a<00P0A4A40@@0@4@d0414;018?2P0D4P`0
51<>01<B3@0B4Pd04Q<>00`<2P0B4a4030h=010A4`0H6ad00`L8014C4P0>40l02P`;01@H5`0J7Qd0
51PG01@J600Y<Rl09Bh[01LP7@0?61D02a4?014E4@0>40d05ALD01TK600F61D05ALD01dO700K7AX0
3@l<010B3`0Q8b004Q@A018G4@0E6Q@04aPB010E3`0B5a405AXD01XO6@0C61805AXD01HK5@0C6180
51XF01XS9@1aNgd0IW1a00hH6@094a805R4N010K5`0b?CL051lH01`W7`0F8AT04a/E01HL600H7QX0
51XF00804aTE01X03Q@@03@j=P0<4Ph05adI01PN6P0F71P0728N01TO6`0K8Ad05ahJ01DN6@0I8Qd0
6R@O00hI4`0J9Al06bLQ01<P6@0I9Ql05R<K01PU700P;BH0:SL`01dZ8`0I9B407BTU02@`;0806RHT
02/072PV01/W9`0L:Rd06BLZ01XX:`0I9bX05B<V01LU:00M:bh08S0c02Dc=P0P;S4072X]01d/;@0P
<3007c8`01/^;00J;R`07c<a01lc<P0Q=SL0:3dn02Ll?@0[@dD0:D5302]3AP2;WjH0i_[o05IZL`0R
=Sl07S8k028f?@0[@4D0<dQ=02Ll@@0gC4l09CXm02i3AP0bAD/09STm02Tm?00Z?Sd093Te0080:Slh
00L0;d=002a0?P0/@440;T5502Xm@@0_A4D0<4E50080<DI702L0=4U;03I;CP2hcM00HgQl02]0A@0]
@TL0>DiC045FF@0fC4X0=Te803A;A@0bB4D0=4Y603A;A@0nE540>U1<03E<AP0fC4T0=di903I<B@0c
BdX0>Di?04=HF@0eBdT0>De<04IJF@1cQhD083<_03A7@`17FUH0=dY602i1?@0lCDL0>da603Q9@`0c
A3h0=4Dm03M8@00eASh00`0dAC/09P0bA3P0;d<g0398?P0^@ST0;Slg03I4?@0d?cT0:S<^02/b;P0`
>cD0=D0j0390>@0dACd0>Te90354B@0`@TH0=TI903I6AP0iAdL0>dY:02`k?P0gB4l0AeYV03eBH`1;
HGH0DFR104YRO01>IX00A5eb03]EIP10EfL0AEeX03aDGP0kDUX0@UQQ03U=F00dB5<0=TE:0P0e?ch0
1@0_>CP0:38a02Xd<`0_>CP0;3He0080:C<b0P0Z=3<02@0Y<S<092T/024V:@0Z;c80;C8e02`e=00[
=340:34^02<^:P0202@_:@0=024/9P0P:bL082/W01hY9@0L9B807BHS024Z9`0Y;bd09B/Y02DY:00P
92<0720O01lS8P0202DY:00702<W9P0M8B006QhM01LK6P0I7A`05a/J01TM700201hR8@0701TM700I
7ad05Q`J01LM6`0]<c<09R`/01LM7@0301HK7P0801HK7`0G72005a`O01HJ6`0I71/07R0O020R8@0M
7Q`201LG5@0601@D4@0K6QH05aHB01`J5@0A40`05QDC100E5AD09P0D51@06a/K01/K6`0C4a<05aLG
010@400D518061PF01HF4`0F5Q@061PF01LG5P0B4Q804a<C01<C500D51H05ADG01DD6@0E5AL05ADF
01LG5`0F5QH05ADE01@D500E5AD061PH00l?3`0000003`l?02h^;P25QHL0MGAi00D51`0@41005ADD
01TJ5@072080414<0P0?3`d02@0?3a403PdB00h=4P0?3P/03`h:010?2`0@3`d03`h<00h=2`0300l=
3P803`d@00<03`d?00h<3@0>30d00`0>30d01`0?3@h030X;00d;300>30d02PP900/92P0?2`h00P0>
2@d0400?2Ph040/?010;3`0@2`l04@`@010;3`0=20`03`X>00h93@0@2`l01P45014<400?2Ph01P45
01<>4P0?2Ph500d830803`T=00`03PP<00l93@0?2@d03`T=00P21P0:10P0:bDY01lI7@0H4QH02@<7
00l93@0;1@T2010:3P0K00`62P0K5AT03PP<00h8300910L03@L;01LA5@0D3Q8051<H00P93@010PH0
3`hC01LF6`0920d01@<800d;400I51X05A0F00h93`0;1@/05PdB01873@0<0PL05P/A00X11@0=0PP0
4@H<008040D;00<04PL=01<83P0@1@/01P0?10X01P070080EDY@02dR:00E2Q00200301H;4ACooooo
000Kooooo`0J014C3P0?4@`030h900X<1`0=3`X04Q@?00d?2P0>40/03a4<00h@2`0<3PP02P`700T;
1P0<3PT03@l:00/=200>40/04Q@?010B3@0A4`h03a4<00d?2P0>40/0418=014B3@0@4@`200l@2`0;
00h?2P0=3PT03a0;00X;1P0=3PT051D@014B3@0<3@P03Pl:018C3P0D5@l00P0;30L01@0E5Q002@X4
00d>2@0?40X04Q<=00804Q<>01<03Ph;03@d<P1lO7X04Q8@00L91P0J71T0;S0]09^PW01DFED06QlK
00<8100>4@h04A<@01DG500A4a0030h;00h@3@0A4a003@l<00802P`903h030h;00d?300=3``0418?
00lA3P0;3@X0418?018D4@0:30T08R@Q010B3`0>40h01`T601<E4P0>40d02`d:00`>2`0@4Pl03a4>
014C400B51402@/801DG50072@H0;S0]02T[:00620D04A<@00/=2P0J71T02`d:00T;2@0@4Pl030h;
00P:1`0?4@h01`T600h@300;3@P03A0900lB2`0=40T030l800d@2@072P<05QTB02LZ8`0?4P/041<<
018D3P0>3P`03`l=00X:200C4a408B4O01PH5P0E5A<030`:00h>300A4@l02PX8014A3`<03`l=00D0
3Ph<00d=2`0=3@/030`:00h>300300l?3@0300h>300A4A403@d=00804A4A02P03@d<018B400=3@/0
2``801<D3`092PD030d801<D3`0=3PT03@d;00`<2P0;2`T03@d;010@3P0820H092@R01@D4P071`D0
4A4?00d=2`0>3`X03@h900H70P0>3`X02P/600l@2`0=3PT0414<018C3P0@4@`02``700T:1@0<3@P0
4Q<>00l@2`082@@030d8018C3P0?40/04A8=0P0B4`h200l@2`0700h?2@0;30H02``600d>200A4P`0
4a@>010A2`0201<D3P0;014B300@4@/041<<00hA300A5Q005a`F018G4@0?50h0314;010E3`0=4P`0
0P0;40X0100=4P`0310:00/=200<3PT200d?2P8030h900<03Q0;00lA300=3`X00P092`H0100;30L0
30d800h?2P0@4@`201<D3`0f01DF4@0C50l0414<00`=200=3PT0414<00dA300D6AD01P/703m4@01E
FUH061dI00X?2`0B5a<03Q<?00`A3@042@D04QLC00lA3P0?40/03@d:00d=2`0?40/04Q<>00d>2@0J
6aH03@h:00l@2`0>3`X03@h901<D3`0:2`H04A4>010A30041@00414<01DF4@10@C`0BDY401DF4@08
2@<030d700h?2P0A4Pd03a0;00`=200>3`X030d800X;1P0?40/04Q<>010A300B4`h0414<0P0A4@l2
018B40804a<A054051@B01DE4`0I6AL061PF01<C4@0D5A003Pl901<D3@0?40/03Ph<010@4@0>3Q00
4A4C00l?400>3Ph03`l=00d>20092P@03`h9014@300C50l05QDA01DF4@0C50l0410>010A3P0?4@h0
4Q@C02X];00H71/03@l>00X<2`0B51<03A4@00H:2@0830/041HD02dc<@0K924020l=00@:200N9280
3Q4>00`>2`0C5A8061XG018D4@0@4Pl03@l<00h@3@0M7a`03Q0=00lA3P0D5Q<04QLA01<H4P0B5a40
4AH@018G4@0D6A<082DO01DJ500G71H05AXD014F400C6AD04ATJ059JG01>EUP03aPG01HO7P0?6QH0
AU5=09ZUW`0R;BH051lG018M5@0=5@l05adI01/Q7@0I7a/00P0K8Ad05`0N9200Q8f8024W8`0D7AP0
5QlJ014J5@0E71P05adI01XP700F7aX0624L02</9`0S;RP04A`F020[9@0R;bP041dF01DR6`0E8QX0
524H01HS700K:2404QlH00805B4M02/0:3@`01DQ7`0M:BL04AdK020/:`0L9bT05bDV01TW:00K:BX0
62HW01XX:P0G9BP07B/^024_<P0J:2/05R@W01`Z;@0S=CD09STg01la<@0L<2l09CTh02@h>00V>c`0
8CHi02U0@P0dC4h08CTk02@l@011EU/0RinV03Q<D`0Z?TD08cLn02a0A`0Z?d@083Dj02Tn@`0N<cP0
8cPm02Tn@`0`@dL08cLi00809c/j00@08CHb02Pm>00X?CP0;D<o0P0[@Cl00`0_A4H0;T=602m4A`03
0356B@0k03A9C00gC4l0H7Ej04=HG@0lDEH0?U=H0397C00]@TD0>U1>03Q?BP0gCTP0>Dm<03YAC00e
C4H0=4Y703M>B@0dBdD0<dU603M=B@0iCd`0@5UG03E:B`0gC4d0>4i<0355A00bATD0@5AB03Q<BP0j
CdX0<4A003E8AP0hBdL0>Te803e@BP0iC4H0<d@n03A5?`0hBD40=DHn0393>`0`@CL0<D8h0393>@0c
A3X0<4Dl03Q<@`0a@SX0:SP`02hi<`0_>S80:S@_03U4?P0kB440<3li03M8@P15EE@0;d560311B00h
Ad/00P0fATH0:P0gB4T0=4M;03U=EP0oEF@0DVQm05eeS@1>IX80AEak04MON`1;Hg`0@U]_045HJ012
FFD0>E9I03YAF@16Ff<0?51I03E9DP0kBTh0<Cdk02Tc<P0Z=C<08bl]02D_;P0/=cH0:cLe02Xd<`0[
=S@0;3Pf02`f=@0Y<S<082PZ01hV:00W;c40:C4c02H_;P0W<2l09c0]02Ha;P0U<2`08RdY01/V8P80
7RTU00l07BPT01`U8P0O:2D09Rl/01lU8`0N92808BLU028V9@0N92808RLU020T8`0N92807b<R01hR
8@0M8B000P0K7ah0C`0M8B007b<R01dQ800M8B008BDT02<W9P0M8b4041DD01hR8@0Y;bd05a`L01TM
7P0K82406R0P01PL7`0F6Qd05a/L01DI6P0F6AP05aTH01PJ6@0E5QD04A4?01XJ600G5aD06a`G01PG
5@0M71P04a8>01HG4P0G5aD061PF01TI6@0J6QX06QXL01PH6P0G5aT04a<C01TI6@0E5AD071`J01PH
5P0F5Q<05QHD01PH5P0G5aH04Q8B01<C4`0C4a@051@F01DE5`0E51T05ADG01DE5P0D51@04A4A00d=
3@0A4A405QHF00h>3P0J6QX03`l?010@40092@T0IfMW03`l?P0820X0:BTY00l?3@0D5A002``7014B
3@0@40h03`l?00l?4@0>3A803@`A00l=300?3P`00P0@3`d00`0?3P`03Pd;00l=3P0200l=3P803`d@
00<03`d?00h<3@0>30d00`0>30d01`0B4140518C01<A4P0@3Pl02PP900h<3@0B3Q400P0>2@d01`0?
2Ph040/?010;3`0C3Q8030L;00d8300F4AD00P080`L01`0C3Q80100301LB5P0=20`01@0401HA5@0:
1@T01@0<1`/200l93@0^00h8300?2@d040X>010:3P0B3100100201/E6@0400802P@8010:3P0=1`/0
3PP<01H@500?2@d02P@802<M8@0>20`04@/?00`62P0=1`/02@<700d72`040PD01`L900l?4P0A3a@0
40hA014?4`0;2@h02`H:00P320060@L02@@8010:3`0<0`P040L<00h42P0E2Q003P@901893P0A1P`0
3`D:00l62`0B1`d04`T>014630L03`@:00D0@cPn00L00P0?10X05@X@01052`0Dooooo`006oooool0
1P0C5A803a4>00h@3@0A4a004Q@@010B3@<03A0900D03Q4900lB2P0@4`/03A0900hA2P02010C3005
00hA2P0=40T030l800d@2@0>4@X00`0?4P/0300?4@`02`d800`>2@0?4@`02`d801DG4P0@4Pd02P`8
010B3@0?4@`030h900h@2P803a8:01`03a8900lB2P0>4@T03A0700d@200A50`03a8900hA2@0A50`0
4QD=010B3@0B50l04A<>00lA300@4Pd04Q@?04a>B@3=c/X0K6iY01<E400A4`h0418=014C3P072@@0
51HA00l@3@0E5a8030h:0P0=3`X0100?4@`0418=00d?2P0<3PX500d?300500lA3P0@4Pl03a4>00lA
3P0>40d00P0?4@h00`0>40d03@l<00d?300200`>2`0<00h@3@0:30T02P`901<E4P0B51403@l<00X<
20082PD0418=00d?2P0;3@P03Q0;0P0@4Pd02`0?4@`03Q0;00lA300@4Pd03@h901DF4@0?40/02@X5
02<T7`0C50l03Pl:00<03a0;00h03Pl:00d>2@0;2`T03`l=00`<2P0:2PP03`l=00h>300;2`T051@B
010@3P0D51803Ph<00d=2`H03@l<02P0418?00d?300;3@X02`d:00d?300@4Pl03`l=00d=2`0>3P`0
410>00l?3@0<30X03Ph<00`<2`0A4@l02@T7014A3`0F5a<06A/F010B3@0:30L03Pl:010A300=3PT0
3`h:010?2`0G5Q801`@1034^:`0C4Ph03Ph900l@2`0=3PT02``700`=200@4@`04A8=010A300?40/0
3Pl:0P0<3@P02@0J71L03a4<014C3P0<3PT03Q0;00/=200>40/0418=00lA300200/=200300d?2P0>
40/03a4<00803a4<01403Q0;00d?2P0<3PT03Q0;00lA300A4`h04Q@?01<E400D5Q404Q@?010B3@0>
40/030h900/=200>40/03@l:00`>2@0200d?2P0600lA3@0;3@X051HC00`>300<3P/03Q0=0P0<3P/0
400?4@h0418?00d?300<3P/02`d:01DG500A4a003Q0=00`>2`0:30T03Q0=014C400C5A803@l<00h@
3@0?4@h200h?300@00l@3@0?40h0414>010A3P0@4@l03a0>010A3P0A4Q00414?018C400D5Q@0418@
00h@3`0E5aH06A/I01LI5P803a4>00D03a4<00`>2P0A4`h03Q4;00`>2`02010B400;00lA3P0A4a00
2`d8018E3P0G6Q<04aH=00X=1@0=40L03Q4800lB2`0>40/00P0=3`X02`0>40/0418=00T;1P0I6aH0
3@l:00P:1@0Q8ah0<cD`01@F4`0B5140418?00@03a4>00P03@l<01<E4P0;3@X030h;014C4@0@4Q80
418C010B4P80418A02H0418@00lA3@0=40/03A0:010B300A50d0418<00h?3@0D51D051HF018C4P0@
4Q004A<@00/=200>4@/051H@00lA2`0Q8ad03Q4;01<H500R9RD05ATH00`@3`0C5aH051PG010D4`0J
7Qd05a`J00hC4P0E6AP03Q8A018G4`0?51003Q<?01@I5@0>4`l04AHB01<H50803A8>00P05a`H01DJ
5P0=4Ph051TE018G4`0A5Q804aPD01DJ5P805Q/G03/05AXF01@I5@0D6AD05Q/G01PM6@0D6AH061hK
01TN6`0H7AX051XG01LO6P0Q:RD0JG9]028[9P0D7aT0<chh010I500I7a/05A/G018J5@0@6A@05AhI
024Z9@0W<R`0628M01DQ6P0?6aD082`V01HQ6`0C71L05AhI01LP6`0A71H07bXT02Xe;`0H9Ah072XS
01PW800=71D062LP01PV7@0F8QP06RDM01PS6`0I91`07RTS01/V800I91h06RDQ01TT800J9B407BPU
01dY9`0J9RD07b/Z01XV9@0S;bh07BTY01lZ;002020[;@8082/_01X07b`_01d_<@0I;Bd09SXk03]>
D@0Z?T0083Dh02Y0A010F5`09ci302M0A00Z@dP093e102<h>P0V?3/0;45302]0A00Y?T80:Sm402a0
A`0Z?TD0:3a402Lk@`0Y?DH0;41702@g>`80:3`k02@0:Cdl02Ll>P0^A4808cXg02]3@00`BDH0;dU6
02i7A@0]ATL0<dY@03A:E00dBe@0=TeD03YAE`0lE5T0>e9H03M>D`0eCE40>51D03YBEP0iDE<0?EED
03M@C@0dCDX0=e1=03YCD00iDTl0=Tm<03UBC`0fCd`0=e1=03eFD`0lEE80?UAB03]AC`0jD4h303U?
C@1305M]J`0hCT`0;48o03Y@CP0_A4<0=4U703Q=BP0dBD@0=T]603=7@P0`@cd0=4M103A7@00dACd0
<D8j02`m=00`@3H0<d@j03i@B014ED/0<D8h02/l<@0a@SL0:c`a03M8?@0hB440<T8j03I6@P0b@T00
;Shm02lk?P0c@D80=4=20354@@0dB4@0=di;03YBEP0lEUl0@5a]04AQNP1:IX<0EW2D06N0Y`1BJY00
DV^:04=KL`0nE6T0Aei[04iUK00nDeP0A5QL03Y=D00_@d@0=4E302`k=P0^?3L0;C/f02He<00^>cT0
=D=002dl>@0/>CT0:cPh02Tg=`0d@D40=D9202Hc<`0202@a<@0<02Ld=00W<S<0:38c02li>@0V<300
92d]02H^;`0S;2`08BXW01hW8P0L9B007BHQ0P0N9b802@0/=C007bPS01`U800P9b<07RLR01lX8`0S
:RP07RLT028Z9`02024W9@0G01TO7@0G6aX07B4P024S8P0O8B00828Q01lQ800L7Q/06QhJ01dP7@0I
6aP06A`I01lR800M7ad071lM01hQ7`0M7ad061/I01dO7@0M7ah071hM01PJ6@0C5A@00P0E5aH0>00H
6QT06adL01DG5@0E5QD06AXI01DG4`0G6Q4061/B01@F400D5Q<05aTJ018C5`0L7B805aPL01@E600G
61X071hN01dO700P8Ad07AdJ00h>300E5A<05ADD030`<00N7Qh06ATJ01HF600G5aT05A@I01<C5@0B
4Q<04A4A01<C4`0E5AD04a<C010@400A4A40410@01<C4`0E5AD04a<C01<C4P0F5A804Q4?014@3P0B
4@l04@l?010>3P0O7Qh03@/=01HD5`0=2`h030X?018@500A41004@l@0P0@3Pl200l=3P03014?400?
3@h03P`=00803@/<00T030X<01@B5@0<2Pd04a4D00l=400;2@`0JVQ[06=QI00K6A`00P0;2@`0600:
20/03P/>014<400@2`l05Q4E00/62P0910P05a8F00d8300;1PX03`X>00d8300?2Ph04PdA00d8300<
1`/03@P<00h93@0=20`030L;00d8300?2Ph04@`@00l:3PL03@P<1P0<1`/02@0@2P`03PP:00d72@0?
2@/040X<00l92`0>20X030H800d72@0200l92`0900`6200?2P`01`<300d72@0@2Pd03`X<00l:2`0;
1PT030H8008030H900D030H800`62@0=1`/03@L;00d62P0200`52@0>00X4200?1``02`@8014;3`0G
41@02`D801XC5`0D2@d040L901052@0=0`H05P/?00`31@0@1@T400l4200301052Ooooooooooo01;o
oooo000Kooooo`0700lA3P0@4Pl03a4>00d?300>40`04A<>00d@2@0200hA2P0500hA200?4PT03a89
00d@2@0>4@X00P0?4P/00`0>4@X03A09010C3002010C30<04A@=00d03a4<00H80`072@@03a4<00T;
1P0@4Pd051HA02DW8P0=3`X030h9018D3`0;3PL03Q4900803a8900X03Q4800/>1@0:3@@051L>00`?
1P0@4`X020/300X=100G6Q403Q0;0P0?4@`05@0=3`X03Q0;00lA300@4Pd0=3Ha01PJ5@0D5Q40418=
00h@2`0H6QD05ALB00L9100:30L020X501`N6@0@4Pd030h9010B3@0D5Q40418=00`>2P0500d?30@0
3Q0=0P0=3``05@0;3@X03a4>01<E4P0>40d020X700/=2P0>40d02P`900`>2`0A4a003Q0=00d?300@
4Ph051HA00lA30072@@03@l:01@F4@0<3PT03@l:00lA3003010B3@0700l@2`0;30L06Q/F01hO6P0P
8A`0>CXe00h?2P0300l@2`0>00h?2P0=3PT04Q8@018B400<30X02@T700h>300A4@l0=SHd04U9A`0D
51802`/90000000G5aD<00d?300800`<2P0?3`d03`l=00h>300=3@/03Ph<018B400J6QP200d=2`0D
010@3`0A4@l05QPC010B3@0>40/0418=010A300<3@P03@h900l?2P0B4@d03PX701LC40071P8040l;
00d>2@0<3@P03@h900h?2P0=3PT600h?2P0501lQ700<3PT03Q0;014C3P0D5Q400P0<3PT01@0?4@`0
3Q0;00`>2@0;3@P030h900<03@l:01803a4<010B3@0A4`h03@l:00h@2`0?4@`04A<>018D3`0C5A00
418=00d?2P0;3@P02P`700/=200<3PT03Q0;00d?2P0<3PT200d?2P0I00T;1`0210403Q0=01`N6`08
2PL00`D200`>2`0L7Q/01`T600P91`0<3P/01@L401<E4P0B51404A<@01@F4`0C5A803@l<010B3`0B
51404aDB00h@3@0?4@h0418?00d>300200`<2P803@d;00X03Ph<014A3`0B4Q003`l=010@3P0A4@l0
3@d;014C4P092`X0418A0P0F61L05P0k?CX03Q0=01<E4P082PD02@/600`>2@0@4`d02P`900`>3@08
2PT020X700`>2`0Q8ah02Pd600hA2P0>4@P030l6010C2P0B5@/04A@=014C3P0?4@`300d?2P0300/=
200@4Pd0418=00802@/600H06Q`G014C400A4a004A<@010B3`0?4@h200d?300500D710092`P03@l<
00`>2`0<3Pd00`0A4Q@01P0A4a804A<A014C400C5A004A<>010B3@804A@=02H03Q0;018D4`0D5AL0
4a@F014C4P0@4Q004A<@014C3P0>40/04aD@00`?200@4``02`d800hC3`0F6QT03Q8A00`@3`0B5QD0
41@C00lC4P0F6QT051PG00dA400C5aH03A4@01<H500>4`l0314=01<H500>4`l04aPD014F4P0E6QH0
5Q/G01XO6`0H7AT04QLC01<H50804QLC00@04aPD01@I5@0E6QH06AhJ0P0F6aL301PM6@8051TE0P0E
6QH02`0B61@02Q8=010I500K91l06B<M018M5`023@L0620K01TO6`0G7AT0620K008051dH02@05R0K
01<N600?6Q@0520I00TF3`0D8AX06B@N01LP6`0H8A`06R@O01DP6P0L9b40?DU3014N5`0O;RL03ahG
01/Z8`0]?3D09cD/01hZ800N:B406RDM02@_9`0S;RP062<M01`W8@0L9b<06B@P01PS7`0K9R806RHT
01LV8`0N;BX06BPU024`;@0J:2P2028`<@0D024_<00P;S407bd`01h/;`0Q<cD06Bd^01/_<00/?d<0
83<g01ld=`0Q>Cd03RHZ02Y1A`0V?d@093e202a5BP0W?3l0:Cho02a1@P0[@4<202Xo@P809ca100D0
:3a302a0B@0aADh0=DU@03A7B`0202<g>00:02@h>@0S>3T07c@e03UAD@0cBd/0:D5102Do?P0^B4L0
>eEF03=:D0<0=DaD01D0=DaC03A;D@0gCU@0=TiC03Q@E00kDeL0?5AG03YBE00kDe<0=Di;039;B00d
CDX0>U=@03aEDP0fCd`0>eAA03UBC`0jDe00?EIC03UBC`0jD4h00P0kDDl0100lDU00>e5?03Y@CP0g
CD/203E;B@0e03eCD@0eBdT0>Dm=03Q>B`0fBdH0=da70397@P0^@C/0;d8l03U<AP0eASh0;Slg02/l
=00dA3X0>d]103e>AP0oD4H0;d0f02Pj;P0/?S80:3X^03Q:?P0lCDD0<D8j03Q8A@0dA4<0:CTh030k
?@0b@400<d900354@00cB4<0=4a903QAE@0mF640AF5b04YVOP1;JHD0GWVM05efWP1FKY@0AEam03]C
J`10EV/0B5i[03Q?E@0W?440?eAF04iRH`0`@T80;3dk02Th<`0X=c800P0[>SD0:00^?CX0;chk02ln
>`0^?3`0:CLg02Pf=P0W=CH082h^01l^:`0T<c009cHc02He<P0W<c409c4`01XT8`0T;Rd08b`[05iW
IP0[=3<07bPU01dV8@0L9B007BHQ01lX8`0N9b80624L02H_:P0N9b809BhY02</9`0O:2<06R<P02H_
;00K92405adK014G5@0K8Al05a/J01dQ800O8B0201/M700E01TK6P0F61D08B<P01TK600U9b@08bDR
01DG500:30T06Q`I01@F4`0U9b@04aDB020R7`0J71/0:bd/01@F5@0G6AP061XI01hP7`0E5aH061XI
00805QPG01<061XI01<E4P0H6a@05aXC01HH4`0J71/071dP018C600F5a`061TM01LH700G61X06A/J
01`N6`0<3@P051DA01DE4`0J6QP04Q8A00806a/K01805ADF014A4`0>3Q002`X?00T92`0A4A804Q8B
014A4@0?3`l04A4A018B4P0C4a<030`<00l?3`0I6AT051@D00d=2`0C4Pl2010?3@0:018A3`0B4140
4@l@01DC50050`H04Q0C01HD5`0D4QL05Q@G014?4@8040h?0`0?3@h500h<3@0C00l=3`0B41<081hQ
038`<`0O7B002PP;01HD5`0D4QD01085010>4@0H5QT04a4D01@@500I51P05A0D00H21@0F4AD07QTM
010;3`0200X52@803@P<00L03`X>014<400=20`030L;00d8300>2@d03@P<008030L;00D03@P<00h9
3@0=20`030L;00d8300500h93@H030L;00<03PP:00d72@0>20X00P0@2P`01@0=1`T03PP:00`6200:
10H030H800803@L900H040X<01D?4@0F4180100001TC5@0:1@H600d72@<03@L;0`0<1PX03P0;1@T0
1P04014;3`0B31005Q0D05UCE`1ZGf<050/=01hC5`0>0`L030<501L<400>0`L040D90P0A1PX00`0@
1@T03P<7ooooo`0Cooooo`006oooool01`0@4Pl04aDB018D4@0?4@h0418>01@F4@0?4P/00P0@4``3
010C2PH03Q4:0P0=40T400hA2P0?010B3@082PD030h901@F4@0:30L03Q0;01DG4P0U9b803a4<00`>
2@0B50l02P`700d@200=40L03Q4800803a8900<041<:01@G3P0:3@@00`0930<00`0<3`P03@l:00h@
2`0400d?2P0B00/=2@0B50l03@l:014C3P0>40/02@/600<5000B50l03a4<014C3P0T9R40Ce5<01TK
5P0@4Pd030h900d?2P0>40/03Q0<1P0=3``300h@3@8030h;00X02P`900h@3@0C5A804A<@00d?300@
4Pl04A<@00/=2P0<3P/03Q0=0P082PL00`0620H02P`700d?2P0200X<1`0400<50@0:30L02`d800h@
2`<0418=00L02``700H70P0;30L01PL200P9100B4a003Pl:00<03a0;00h03Pl:00d>2@0B4Q004A4?
00d=2`0;2`T03@d;010@3P0N7Q`0;Bd[00P81P0@40h02`/900h>30H03@l<00L030h;00d?300>40d0
3Q0=00d?300<3P/02`/90080410>0P0=3@/0500?3`d00P8004e=B`0l?3X051@B00@40`0W9bD03Q0;
00`>2@0>40/04A<>018D3`0@4@`02``700l?2`0C4Ph06ADB014=2P0>3@T0414<0P0<3@P200l@2`04
00`=200=3PT03@h900h?2P<03a0;00/020X500h@2`0C5A003a4<01LI500E5a803a4<00d?2P0;3@P0
30h900lA3002014C3P0D00h@2`0=3`X030h900d?2P0>40/04Q@?014C3P0@4Pd03a4<00h@2`0=3`X0
3a4<00`>2@0:30L02`d800`>2@0=3`X03Q0;00d?2P0<3PT200d?2P0C010B3P0V:2D01PP500d>3008
2PL00040014C400M7a`07R0M01@F4`0E5a@02P`900T;200B51404A<@01LI5P0D5Q<03@l<014C4002
00lA3P0400h@3@0=3``03@l<00d>2`8030`:00H03@d;00h>300>3P`0410>01<C4@0B4Q0200l?3@0L
00d=2`0B51<03@l>00d?3P082PT02@/:02d_;0041P<05ALD01PJ5@0G6A@03a4<00lA2`0F61D04aDD
00T;2P0:30T05QPE04E7@P0@4``04A@=014D2`0?4PT041<:010C2@0@4``0418=00lA30<03Q0;00L0
4aD@00lA300=3`X04Q@?01DG4P0?4@`03a4>00<04A<@00T03Q0=00`>2`0>40d030h;00h@3@0F61D0
4A<@01<E4P0?4A000P0?4180100?4A003a4?00lA3P0A4`h2010B3@04018E3P0A50d03a4<00lA4080
3a0B01/03a4@014C4@0C5A805QPC014C3P0R91l02Pd600lB2`0D5Q403A8>00lC4P0:3Pd03Q8A018F
5@0?4a803A4@01/O7P0O8b805QXI01<G5P0:3Pd06AhJ01HK5`0C61@05a`H00dB3P0@5A400P0B5a<0
100>4`l04QLC01TN6P0I7QX3018G4`0501<H500D6AD051TE01HK5`0G71P00P0I7QX03P0C61@03Q<?
018G4`0F6aL0724M01/P700A5a<04aXF01<L5`0A6QD04Q`F01LR700D7aT05QhI0P0H7QX04P0L8al0
51dH00dF4@0E7aT04A`F00lJ500G8a`03AXC010M5P0J9Al06B8M01PQ700K9Al05b8L01TT7P0Q;BH0
6BHO01LV7`8052<L00<03A`E01LU700G8aT00P0B7AD01@0E81P06RDO01`W8@0L9b407BPT00806RDQ
00L072PT01XY9P0E92406bXW01d/:@0V=C806BLW00<08Bl`0`0P;S40<P0B92H08cLh01lc=00T=c/0
:ci201`a=00X@4@07CDi02PoA@0B:c007cPm03YCE`0Z?d80:d1102e2@`0/@D@0:d1302Xo@P0V>d00
9ca102Pl@`0[?dP0;d=<0355C00Y?400;T9302@h>@0iCDh0<dQ902Tn?`0O=cL09Cdm0318B00eCdh0
=U1?035;C00`Add0<dYB03I=E@0hCeL0>4mF03M>E00hCeD0>U9G03eEF@0nEUX0?EEH03YBDP0kDe<0
=Tm<0P0bBdP0200gD4d0>eAA03M@C@0lEE80>U=@03]DD@0mEU<0>55>0`0nE5800`0lDU00>4i<03M=
B`0203I<BP0<03Q>C00mDe40>4i<03Q>C00iCd`0>4e803I;AP0aAT40;D0j02`o>@0cAT00<T<k0P0]
?SH0?P0hB3h0?dm503]<A00lCD<0<D8h02Li;@0U=b/08C<W02m1=@0iBT80<44i03];B00fATD09SHe
02dh>@0/>SX0;Sdj02e0?00_@Sh0<4Q503E?D00lEeh0B6=c055]P`1HLi00HGfO04iXS@1BJXh0@eai
03UBJ00hCf40?UAQ04UPIP17G640=DY<03Y>C`0Y>c/0<D8o02dl=`0Z>C@0;C`g030o>P0`?c`0;C`i
02ln>`0^?3`09cDe02Xh>00U<c@072XZ028a;P0Y>3D0:cXg02Dd<@0U<Bl0=d5001HP7`0`>ST0KWMf
0:Zc/P0U;R`07RLT0P0L9B009P0M9R407RLR01hW8P0X<B`0>D8m01`U800Q:RD08b`W01lX8`0O:2D0
;cPe01@M6P0b>3H09bd[01LM6`0J7Qd07b<R024S8P0M7ah07R0O01dO7P0H6QL08B<P01LI5P0];b`0
8B<P01lQ7P0Q8b006adJ01TK600Q8b0071hK01hP7@0J71/0;S0_00d?3P0H6QT06A/J0`0J71/04P0G
6AP05QPG01HH5`0E5a@05QPE01HH500H6QT08B8T02DV:P0I6Ql05AHK01XK7`0J6ad05QLI01DG5@0H
6QL03a0;01DF4P805QHD00@04A4@018B4P0E5AD04a<D0P0A4A<04`0A41D0410B018B4`0D51@04A4A
00h>3P0A4A405ADE014A4@0G5aL04a<C00h>3P0@41004A4?018A3P0?3P`040l=018A3`0B41400P0A
3a001`01008030X=014?4P0;2@h01`D8010>400@3Pl00P0?3@h200h<3@0I00d;300>30d03P`=00l=
3P0>30d030X<03<a=01QGf80BDM:00X82`0>30l06QPK014?4P0@3Q403P`?00`:3@0610L01`@700H1
1@0C3Q8040/?00@00`0A31003`X>00/62P0200X52@0700T4200:1@T03@P<00d8300<1`/03@P<00h9
3@0200d8300400h93@0?2Ph03`X>00l:3PD03PT=0P0=20`600`72`803`T;01004@/=01@>400C3@l0
3`T;00h82P0<1PP02P@600/51`0=1`T030H800T31@0B30h03@L900@000090`D02@@51P0>20X600d7
2`0900T31`0<1PX04P`@00l93@0<1`X0>38f02TN8P0<0`D01`00008040D900<03`@801052@0B1`/0
0P0E2Ph00`0B1`/040D9ooooo`0Cooooo`006oooool03@0@4Pl04Q@A014C400>40d03a4=01<E400=
40T03Q4:00lB2`0?4PT03A0700/>1@0?4P/0100>4@X00`0?4P/03Q4:00hA2P0400d@2@09018D3`0?
4@`051HA01XL5`0<3PT03Q0;01<E400@4Pd04Q@?00803Q0;00h02`d800lB2`0=40T03A09014D3@0F
6A8061/D010C300?4P/020/401/N5`0O8Q/030l800h@2`8030h900T03Q0;00d?2P0<3PT04A<>00lA
300D5Q40418=00h@2`0=3`X00P0<3PT01`0@4Ph04A<>00<40@0J71L051HA01PJ5@0C5A000P0<3PT0
0`0>40`03@l<00d?300400d?300600h@3@0?4@h03a4>00h@3@0<3P/03@l<0P0?4@h0100>40d030h;
00d?300>40d200/=2P0F00h@3@0=3``03a4>014C3`0B50l02P`801LI500=3`X0418=00X<1`0<3PT0
3Q0;00lA300@4Pd03a4<00d>2@0A4Pd03Pl:00T:1@0N7aX03Pl;00h?2P<03a0;00X03Pl:00d>2@0>
3P`030`:00h>300?3`d03@d;00h>300?3`d04a<A0P0?3`d00`0B4Q002`/900d?300500d?300E00/=
2P0=3``03a4>00lA3P0=3``02`d:00`<2P0?3`d0410>00h>300=3@/03`l=00h>300D51801PH500h>
300A4@l02``;00`>2@0:3`T02a0:00803Q0;00P030h900l@2`0A4@`04a8>01PG4`0<2`L051<?010A
30803Pl:0P0@4@`300d>2@0500h?2P0?40/0414<010A300D5Q400P0@4Pd0400?4@`05ALB00/=200<
3PT04A<>01HH4`0G6A@04A<>00d?2P0@4Pd03Q0;00d?2P0>40/03a4<010B3@0?4@`500h@2`0300lA
300>40/03Q0;00803Q0;00@03a4<00h@2`0=3`X030h90P0=3`X04`0O8Ad0<38_00/=2P0I6aT0418?
01DG500l?S/07b4N00X<2@0<3P/020X701PJ5`0<3P/03a4>00d?300A4a0030h;00T;200D5Q<00P0?
4@h0100A4a003a4>00h@3@0?40h200l?3@80410>01004A4?00d=2`0@40h04Q8@00`<2P0>3P`03`l=
00H81`0?4A004Q@C00h@3`0A4a80418?01LI5P0@4Pl03a4<0P0=3`X0400@4``02`d900lA3P0@4Pl0
3@l<00T;200J71P04A@=00hA2P0?4P/041<:00lB2@0=40P03Q0:00h@2`0@4Pd3014C3P07010B3@0L
7QT05aTD00d?2P0B50l02P`700h@3@03010B3`0800lA3P0=3``030h;00h@3@0A4a008bDR01DG500A
4a04010B4@09010B400@4Pl03@l<00d?2`0@4Pd04aD@01<E3`0@4Pd04Q@A00804A<B00h04Q@C018D
4P0A4a003@l<01@F4P0m?cX051HA01LJ500C5A004AHB00hB4@0;3`h04ADD01<G5P804ADD00D05a/J
01dQ800E6AP051PG00hB4@0301DJ5P0;01XO6`0>4`l03a@@00lD400C61@041DA018G4`0F6aL05AXF
018G4`0C61@0100D6AD07P0C61@04AHB014F4P0C61@061dI01XO6`0H7AT04QLC01HK5`0G71P04QPD
01DM600A6QD07bPS03Q2?@0E81X041/E01@L5`0H7QX04QPD01PO6`0I8Qd05AhI01hX8P0A71H04ahH
01HR700J9b004b0I01XU7`806B8M02h06R@N01LR700G8Q`05B4J020]9P0B8AX062LP03E4?@23TX/0
BEM>01XW7@0I9Qd0;c`c01LT6`0A7QL07BXS01XW800L:2@06bLS01`X900P;2P093<`01TX9@0L:bP0
9C@a0350?@0N;2`07B//01h/;@0O;Bh08Blb028`<`0S<C@07Bla02Di>P0Q=CH09STm02Pk?`0S>3/0
7cLk02a4B00R>Cl0:dA905M`M@1[Q8T0:3e00P0W?3d202Pm@00802Ll?`0Y?T<0:Ci302Pm@P0V>d40
9SY002Dj@00Y?44202e0A00<05]^LP12EUT0;T=6059ZK00mEEL0;TI8035;C00dCTl0;TM;0358CP0c
BU80=DaD0P0fCE<03`0eC580=dmC03YBEP0kDeL0>U9D03I>D00cBd/0>E9@03M@C@0cC4T0<T]803E>
B`0hDDh0=Tm<03]DD@0203UBC`0N03aEDP0hDDh0?E=A03iDDP0oEE<0?UAB03aBD00kDDl0?eEC03M=
B`0iCdd0?59@049HEP0lDU00>U1=03Q=B00dBD@0<4E002i1>`0[?SP0;d8l0393>`0`@CT0;Slg0392
>00gAcd0>T]303Y;@@0gB3h0<48f0P0[?C407`0]?c<0=TLo03E6?P12DTl0?4a;02lo?P0^>cX0:cTh
02dm>@0^@C/0;d8n03A:A`0kE5H0?eUP04QRL01BKH40FWF>05igUP1@JHX0@U]k045JM00nF6X0@EQW
03mGH00_ATX0=TY=02i1@P0mCe40;d5103E5@`0`?cX00P0^?CP01@0c@Sd0<D0m030o?00d@d00;cdm
00809C<c00L08c4b01d/:`0S<Rl0:STf02hm>P0Z>CH0:cLe00809c4`00L08B/Z01/T8`0]=SD07bPV
020Y9@0O:2<082TT00808b`W03l08R/V03<l=`0j@ch07BHQ02H_:P0W<2/07BHQ024Z9`0N9b@072DR
02/a;`0U:bT07B<Q01PL6`0M8B00828Q01dO7P0P8R408B<R01`N6`0Q8b007AlL01hP7@0?4@h0BD]8
06]]JP0N81d061XG018D4@0`<Rl04Q@A01@F5@0O8B0020X901XL6`0M7ah05aTH028T8`0L7Qd06A/J
01LI600E5aH061XI01<E5P0C51H04a@H01XK7`0M7R@04Q8I01TJ7`0K72006AXL01DG5`0B51804Q@A
01HG4P0D514051@B010@3P0G5aH05ADE018B4P0C4a@00P0B4Q@03`0D4aP05ADG01DE5P0E5AD051@D
014A4@0B4Q8051@D014A4@0D51@04A4A01PH600K6a/05ADC018A3P0200l>300:018A3`0B41404@l@
01lM7P0B41<05aDH01hL7`0E4aP03P`?010>40<03`d>0`0>30d02`0?3@h040h?010>3`0>30d04@lA
018@4`0=2`h03P`?00d;3P0;2@`03@/>00804Q0C00L02`T<00l=400B41<0AT=6034/<00:1PT04`hB
008030L;0`0@2`l02P0?2Ph04PdA018=4@0?2Ph03@P<00`72`0=20`03PT=00d8300<1`/800d83080
30L;00<02`H:00`72`0<1`/0100<1`/200h82P0500l92`0A2`d04@/=00d72@0>20X00P0<1PP200h8
2P8030H800D04P`>00`7200V828020<400l92`0600h82PH03@L;00h02086014;3`090`L03`T=00l:
3@0=1`/04`X<01P>4@0:0@<06A0B01D:3P0>1@L03`@801462P804`P<00<04@H:00l42?ooool04ooo
ool001_ooooo00h04A<@00h@3@0=3``03a4>010B3P0?4@`030l800hA2P0?4P/03a8900`?1P0930<0
3a8;00hA2P803A0900@03Q4:00lB2`0@4``041<<0P0?4P/200hA2P0@00d?2P0;3@P03@l:010B3@06
20<03@l:00lA300:30L02`d800`>2@0>40/0418=00hA2P0?4P/041<<014D3@804QD>00L03A09018E
3P0?4P/06ahG01lR6`0D5a003Q0;008030h901D0418=00h@2`0<3PT030h90084000C5A0030h900lA
300>40/08B<N01PJ5@0>40/020X5010B3@082PD02`d801<E400E5a803a4<00`>2@0<3PX01P0=3``0
5`0>40d0418?014C400?4@h03@l<00/=2P0>40d03a4>00/=2P092`P03a4>01DG500<3P/020X700`>
2`0=3``03Q0=00`>2P0A4`h0:R`W05YLE`0Z;2L03Q0;00D03@l:00P03Q0;01XK5P0D5A0051D@00/<
1`0=3PT02P/600h?2P<03a0;00`03Pl:00d>2@0>40d02P`900`>2`0?4@h03@l<018D4@0?4@h0418?
00`>2`0J71T800d?300900`>2`0=3``03Q0=00h@3@0=3``030h;00h>300=3@/03Ph<00803`l=0100
30`:00d=2`092@L03Ph<00l?3@0@40h010H300lA300=4P`0314;00X?2@0:3PP02`d8014C3P0?4@`0
3a0;0P0=30P01@0C4Ph03@h9010A300A4Pd0414<00L03Pl:01003a0;018D3`072@@01PP300lA300F
61<020X500d?2P0E5a8071hI01lQ700E5a803Q0;00`>2@0=3`X03Q0;0`0?4@`200X<1`0=00/=200=
3`X03Q0;00h@2`0?4@`0418=014C3P0@4Pd03@l:00/=200>40/03@l:00`>2@0200d?2P0I018D4007
2@H061XG07j0O@0];b`03a4>02LY9P051`@0004001<E4P0:30T04A<@00d?300A4a003a4>014C400;
3@X04Q@A01lQ7P0@4Pl03Q0=01<E4P0A4a003a4>010A3`02010@3P<04A4?02004a<A01LG5@0C4a40
3`l=01TI5`0@40h06Q`K018D4`072@P01@L600L9200=3``02P`9018D4@19BdH0:B/V01HH4`0D5a00
4Q@?01DG4P0A4`h03a4<018D3`0E5a803Q0;00T;1P0<3`P04QD>00hA2P0=40T03Q0;00lA30<04A<>
00T0418=014C3P0P8Qd07R0K00d?2P0:30L04A<>00lA3P0>40d00P0=3``200lA3P0600h@3@0:30T0
7AlL04a>B`0`<Rl02@/81P0A4a001`0>40d03a4>018D4@0D5Q404aD@00lA300A4a000P0?4@h0300A
4a003a4>00X<2@0B51403Q0=01HH5@072@@04A<>018D3`0D6AD03a<B00hB4@<04ADD00L04QHE00lC
4P0E6AP03a<B018F5@0@51<041DA00803A8>00@051TE00hC3`0B5a<03Q<?0P0C61@01`0E6QH04aPD
00hC3`0B5a<04aPD01@I5@0E6QH00P0C61@01`0H7AT06QlK01PM6@0F6aL07b@P02L/:00/<Bd00P0F
6aL0<P0C61@03aDA01DL600F7aX05AhI03Y4?P0E81X03QTC010H4`0D6QH05Q`H02D]:00Q:RD04Q/F
01@N6@0D7aT08RdW01HR6`0M:R<04QlH01PS7@0J8ah06b@O01TS7@0H8ad06RDO01LS7@0=6Q<052<L
01h]9P1@GeP0_Lc506akL@0U<RP09S<Z05MTF`12CdH082dV01PU7P0L:B807BTU01/W8`0L:2@07b/W
020_;00H:2D072`Y01l_;00[>cP0830_0P0N;Rh04@0P<3008C0c028a=00S<SD05RPZ01X^;`0/@440
?4mC02Pk?`0O=3L08SXn01P`=00Y@4H07cPm01Tb=`0Z@dP0:3e000809S/l00<0:Ci102]0@`0Y?T40
0`0Y?T402P0X?D009ca002Dj?`0Y?480:Se302e0AP1OLWP0YKVo03Q=DP0dC5020359C@0303=<D00a
BTh0:dA800<0=DaB01D0=TeC03Q?E00iDED0=4a@03Q@D`0hD580=De?03=;C00dC4`0<4U603A=BP0e
CT/0<da903E>B`0iDTl0=4e:03M@C@0eCT/0=Tm<03]DD@0jDe000P0lDU006@0mDe40?UAB041FE011
EeD0>e5?03aBD00nE580=de;04AJF00nE580>U1=03M<A`0_A3l0;T<n0313?@0]@3X0;d8l03=4?00a
@SX0;3de02hn=00a@CL0@55903M8?P0fAcd00P0`@SH07`0gBCd0B5Y>03e>AP0kC4@0?dm<03E5A00c
@d80<T4n02dl>@0`@3X0<TDo03=6@P0gC4X0?EEG041IGP12GFP0Af5b04]TN01LMXl0PI^f04aTOP14
Fg40>4mO04UOK00cBDl0Fg1c09nc]012EED0=DM703a<C00]?C/00P0`?cX05@0_?ST0=TE003I5@P0c
@Sl0<D0m02hl?00W=CD07R`/020^;`0T<c408c8]02Dd;`0[>SD0;C`g02`h=00U<2`0:SDa020[9`0C
71T07bPU02</:@0201`U800701hW8P0Q:RD08R/V01lX8`0G81/051dH01PQ700202@]:00N024Z9@0I
8Ql0:C8_024Z9`2AUiD0NX1n01TO7@0I7A`07B4P01hP7`0J71/07AlN01lQ800R924061XG01/M6P0U
9b@07AlL01lQ7P0Q8b004Q@A024S800=3``061XG018D4@0E5aH05aTH01HH5`0L7Qd0828Q0P0K7A`0
7P0I6aX07AlN01`N7@0F61L061TK01TJ7`0I6B405ADM01HF7P0H6Al04Q<H01XK800G61`05AHH01DG
5P0D5Q@04A<@01hO6P0F5a<05ADC00d=2`0P81l071`L01LG5`0I6AX05aLI01DE5`0F5AX061PJ01DE
5P<04a<C00T0410@00h>3P0B4Q80410@00h>3P0M7Ad07QhN014A3`0C4Pl00P0?3P`02`0@3`d03`d>
00h<3@0E4a@03@/>00l=400G5AP04Q0E00h<3`0?3@l03`d>00803P`=0P0=2``01P0?3@h040h?014?
400?3@h030X;00h<3P802PP;01<03`d@014?4P0=2`h02@L:00h<3`091`X020H9018@4`0F51L04@hA
01hI7@0F4AD0100301D@500D3a<020<700`72`0>2@d030L;00804@`@00L03PT=00d8300<1`/03@P<
00h93@0=20`030L;00802`H:00L02PD900/62P0;1PX03PT=00l:3P0>2@d030L;00802`H:1P0<1`/0
1P0=1`T02`D700/51`0<1PP03@L900/51`803@L900@03`T;018<3P0A2`d030H80P090`D0100<1`P0
6A<E02/U9`0;1PL600d72@0400X4200;1@T02`D900`62P803@L;00@02`D900l93@0400802@<70P0:
10P01P0800403`@8024F6P0=0PH0MV]_04@i?@803P<70P0?10P200h31aCooooo000Kooooo`0>01@F
4`0@4Pl03a4>018D4@0C5A40418=00lB2`0A50d04aH?018E300?4PT030l6010C300>4@X200`?2004
00hA2P0@4``03a8;00lB2`803Q4:01D03A0900`?200C5A00418=00h@2`0@4Pd02P`701DG4P0>40/0
418=00D70P092`L0418=01<E400=40T04A@=01<F3`0B5@h03A0900X=1P0<3`P00P0?4P/03@0=40T0
3Q4:010C300?4@`030h900d?2P0@4Pd03a4<00`>2@0=3`X010H101TK5P051`<00P0=3`X01`082PD0
0`D001LI500210005QPC010B3@0>40/00`0<3PT00`0=3`X03@l;00d?300400d?300U00h@3@0?4@h0
4A<@018D4@0@4Pl03@l<00T;200=3``04Q@A00d?300<3P/06A/H02@V8`0G6AH03a4>014C400@4Pl0
3@l<00lA3@082PD02P/803Pj=@0>40/04A<>00lA300>40/030h900/=200<3PT03Q0;014B3@010P00
3a0;00/<1`000@005AHA00h?2P0300l@2`0300h?2P0=3PT04A<@00802`d:0P0>40d01`0F61D0OGml
05iPG@0?4@h061XG00840@0>40d0300=3``00`0?3`d03@d;00d=2`02010@3P0900/;2@0?3`d03Ph<
01@D4P030`402PX801HH5@0;40X0314;00802a0:00<03A4;014C3P0@4Pd00P0>3`X02@081`<04Q4=
01LF4P0;30L04A8=018C3P0?40/03Pl:010A300600h?2P0500`>2@0E5a804aD@00h@2`0D5Q400P0;
3@P010092`H030h9018D3`0A4`h200lA3080418=00@03a4<00`>2@0:30L030h90`0;3@P200X<1`09
00h@2`0A4`h04Q@?010B3@0;3@P02@/600h@2`0=3`X030h900803@l:00`02P`8018D4@031@80;2h[
00d?300E5a@03Q0=010B3`0C5A80418?00lA3P0B514200d?300<00`>2`0>40d020X701<E4P0R9240
3@l<00/=2P0A4a003Q0=00`>2`0?40d03`l=0P0@40h3014A3`0[010@3P0<30X05QHD02l_;@0S8b40
61XI00/=300?4A005ALF00`>3@0B51408bDR00P:1`0S9B000P@000@60@0E614020X500d?2P0?4@`0
4A<>01DG4P0<3PT04aD@00d?2P0?4P/051L@00lB2`0<3`P0418=014C3P0B50l04A<>010B3@0>40/0
4aD@014C3P0>40/0418=00/=200?4@`03a4>00h@3@0200`>2`0800h@3@0@4Pl02@/801<E4P092`P0
6Q`I00T;200F61D600lA3P804Q@A00@051HC01DG4P0C5A003Q0;0P0A4a00300D5Q<05aTF01HH5@0A
4a003a4>014C400>40d05aTD018D3`072@H05ATH010D4`<03a<B00`04ADD00hB4@0A5A@06QhM01<G
5P0@51<02`l>01@I5@0=4Ph02@h:010E4@0=4Ph2018G4`0m00hC3`0:3`/03a@@01<H500@5A404AHB
01<H500D6AD05AXF01<H500B5a<04aPD020U8@0O92005AXF01<H500G71P06QlK00dB3P0D6AD05Q/G
01<I5@0B6QD0624L018K5P0F81/02QD?01`W8@0D7AP06b4M01<I5@0J8Qd06B8M00lH4`0D7QP072LQ
034l=P0I9Ah06bPQ00hK500F8A/06b@O01dV8@0I8ah062<M01`W8@0L:28072TR01d/9@0@7aP07RdV
041?B00W=R`05b@J01dZ8@0V<bX03a`C018O600S<2T07R/T01hZ9P0201/W8`0801`Z9@0G9b@05BDR
01XZ9`0F9R<08C4^01d];00Q<C42028b<P808S4d00L08S<e024c=@0X?3d083@e02<f>P0X>cl0;D95
008083Pl00X09ci4018[<00iDUL073Di02@i?00Q=SL083Df02Dj?@0W?3l09S/n0P0X?D00400Z?d80
:d1302]0@`0[@4<0;d9802Pk@@10DeT0<TE;082DVP0]@TL0:d=702i6BP0_Ad/0;TM;039;C`0hDED2
03M>E00<03Q?E@0kDUP0@EQM04ALH00eCE40>E5C03YBE00gCe40=dm@03YBDP0[A440<DY70P0eCT/0
1P0gD4d0>eAA03=<B@0fCd`0<da903A=BP80>eAA00@0@EME03iDDP0mDe40?E=A0P0nE580200gCD/0
@EME04AJF00cBDL0?eEC03U?C@0jD4d0=T]60P0]@Sd0@`0bACl0;d8l02i1>`0a@SX0;d0h02dn=P0b
@SP0=THl04MHD00eAS`0<44g02Tk;`0Z?300=4Hj041BAP0]?SH0;Slg03I6@`0b@T40>4Q70391?P0]
?3L0<40j03A5?`0cAT80=DU703]@D`0nEE/0@UYU045KJP15G6h0B65g07bF[@10F700@5QZ03E=F@1A
J700?59G03A9BP1/P840<DA403E7A`0oCdl0;C`j0350>`0c@Sd0<T4l03Y9A00lBdP0<d8o02Th=@0Z
>3P0:CLg01h/;00R<340;3Xi02He<00U=2l0:3Lb02Xi=00X=300;CPd02Pc;`0P:bL07RLT03Q1?P0N
9b@00P0O:2<02`0R:bH09BhY02H_:P0S;2L09BhY01XS7P0Q:RD07bPS01XS7P0O:2<06B8O00807RLT
0140=C/i02P^;00Q9bD0720O020T8`0P8R406adL01dO7P0N81l07AlL01/M6P0N81d061XG01dO700K
7AX05aTF01@F4`0201LI5P0@01@F4`0H6QL051HE01<E500I6aX04aDD01DG5P0B51<051HE01DG5P0O
8B00828Q01LI600F5aT05QHN01TI8`8051@L02L06AXO01HG6`0I6Qh051DG01<E500E5aH05QPF01<E
4P0E5Q404Q<?01LG5@0<30X061PG00T92@0@410051@E01<C5@0@41804a8G01HF600C4a@0410@018B
4P0D51@03`l?00X:2P0A4A406QXJ014A4@0@410051@D010@3P0D4a0040l=00l>300@3`d03P`=00d;
300C4A800P0=2`h01@0E4aH040hC00l=400?3@l03`d>00803P`=0P0=2``0200?3@h040h?014?400?
3@h02`T:00d;3@071@P03`d@0P0;2@`03P0G5AP03P`?00`:3@0;2@`04@lB010>4@071@P02PL:01<>
4P0;1PX05A0D00h93@0300803`X>0P0@2`l0200<1`/03`X>00h93@0<1`/03@P<00`72`0=20`03PT=
100=20`00`0<1`/03@P<00d83002010;3`0300l:3P0>2@d03@P<00L030L;00@03`T;00d72@0;1@L0
3@L90P0>20X0300<1PP03@L9018<3P0D3Q004P`>00`6200@2P`0100001D?4@1FD580Y9jP01/E5`H0
3@L900@02@<700X4200;1@T02`D90P0<1PX03P0:10P040X>00l93@0@2Ph02@<701XD600?10P04`X<
00L0000O51P0:R4S020E6@0A1PX040D90P0?10P00`0@1@T04@H:ooooo`0Cooooo`006oooool01P0A
4a003a4>00X<2@0<3P`04A<?00h@2`803a8;01403Q4:00d@1`0<3`H02`h500T<1@0@4``03A0900/>
1`0=40T030l8010C300:3@H041<<018E3P0<3`P03A0900h@2`02014C3P0700lA300>40/03a4<014C
3P0@4Pd03a4<010B3@02014C3P0D00/=200=3`X04Q@?00lA300;3@P0418=014C3P0:30L04Q@?018D
400E5a803@l:01<E400K7AP051HA00h@2`0?4@`03Q0;00d?2P0;3@P200lA3008010B3@0G6A@03Q0;
00T:1`0=3`X03Q0;00`>2@0>40/2014C3P0A00`>2@0>40/02P`700lA3P0C5A8030h;00lA3P0:30T0
3a4>010B3`0/;R/0?T0m014B400E5a@0418?00`>2`0A4a000P0<3P/01@0H6QL03@l<024S800I6aP0
4Q@A008030h;00l03@l<014C3`092`H0418=00d?2P0A4`h03@l:00lA300@4Pd05ALB01@F4@0>40/0
30h9010A300>3`X00P0@4@`0100;30L03@h900`=200<3@P200d>2@803Pl:00/02P`901HH5@092`P0
5ALD00@61012A440h^CQ055CD00?4@h01`P601DG500200lA3P0;00/=2P0>40d03a4>00lA3P0=3``0
3a4>00X<2@0?4@h02`d:00lA3P092`P00P0@40h200l?3@80410>018030`:00l?3@0>3P`03@d;00h>
300A4a003A8<06M^I`0F7AH02Pl901@I500=4P`0418=00lA300>40/03a0;00h?2P0=3PT2014B3@05
010A300?40/03Pl:00`=200=3PT00P0:2`H00`0=3PT03a0;014B3@0200d?2P0600h@2`0?4@`0418=
010B3@0>40/03a4<100@4Pd200`>2@0<014C3P0@4Pd06A/F02X/9`0A4`h030h9014C3P0?4@`05ALB
00X<1`0@4Pd03a4<100=3`X00`0C5A005ALB00h@2`0200lA300<00/=2@0<3P/03Q0=014C400?4@h0
3Q0=00d?300A4a00;c4^014C400@4Pl03Q0=0`0?4@h0100:30T020X700h@3@0A4a0500h@3@0700h?
300>3P`0410>014A3`0@40h03Ph<00l?3@02010@3P03014A3`0B4Q004Q8@0080418A01T03Q0?018D
4`0O8B00418@01@F4`0=3``03Q0;01XL5`0I6aH041<<00hA2P0=40T04QD>01<F3`0B5@h04A<>01HH
4`0C5A004A<>00X<1`0I6aH0:bdX010B3@0B50l04A<>00803@l:00T0418=014C3P0:30L04A<>01@F
4@0F61<03Q0;00`>2`0>40d0100?4@h4010B3`0300h@3@0=3``03a4<00804aD@0P0A4a00400C5A80
3a4>01@F4`0E5a@04aDB010B3`0?4@h05ALB010B3@0E5a804Q@A01<E4P0;3@X04aDB01@F4`0C5A82
01@F4`09014C400@51<04aLF00hB4@0@51<04aLF010D4`0A5A@0310?00804ADD00D030l>014E500B
5a<03A8>00`A3@02018G4`0<01`Q7@0=4Ph05Q/G01@I5@0F6aL03a@@02H[9`0F6aL051TE00dB3P0J
7a/01``80P0G71P201DJ5P0901PM6@0E6QH04AHB01<H500D6AD061dI01LL600D6QH05AdH00804Q/F
00L04Q`F018M5`0C7QP0624L01`R7P0K8Ad06B0L00805QlJ00L0628L02lj=00nBD<0:CD^01<P6@0G
91d07RTS00809BhY01405b4L01XU7`0U<2X08RhW01XW800K:R<06BPQ01LV7`0M;2D08C4W01XZ7`0H
:1h072`R01/[8@0I:2406bXS01d/9@0201d/9`8072/V01H05bLT024a;P0J:RL07BdZ01h^:`0U=C@0
72`/02<c<`0M;Bd09C@g02Th>`0R<cD093Li01X^;`0Y?Ch083<g04MJGP10EEP09Si203E=D@0dBe40
9Ci30P0[A4T01`0V>cl09CXm02Hk?P0X?Ch09c`m02Dj>`0Z?d000P0W?3d202Xo@00702Ll?P0[?T<0
;T5702/nA00^@DL0<dM<02]0A@020318C00A0359C@0aBTh0=4eA03I?D`0bBDl0>U5G02m6C00oEe/0
=dmC03aDE`0gCe40>E5B03UAD@0hD500=dm?03E=C@0dCDX00P0_B4D01@0eCT/0>U=@03QACP0lEE80
>E9?0080=e1=04`0?5EB03mHE@0mDe40?UAB03mED`10EU@0@EME04=IE`0kDDl0?59@03Q>C00oEE<0
@5ID03M=B`0iCd`0=4U40356@@0`AD00=4M103I9@`0/?cT09cP`02Xk<`0/?CD0;Shd0351=`0fAcl0
=DHl03=4>P0`@SH0;d4e0312=P0bA3P0<T<k02dn=P0hB4D0=dM60351?`0nCDT0>da603A5?`0^?cT0
9STe03iAD01;H680=DY?049GH012FF@0@UQU04]RL`11FVd0@U]]04IOK013G6@0>e9G0397BP0hC4d0
;Cm00352@P1?Gel0>4M:0391@00d@ch0<d8m03E4?`0fAD00=4=00350?@0[>SL09cDe02Tg=`0P;Rh0
=TA502Hd<`0a@3/0:3Lb0P0V=C00100Z=S809S4]02@_:`0P:bL201`U8P0401lX9@0J8ah072DP020Y
90808R/V00L08BXU01dV8@0O:2<08BXU01dV8@0K91l07RLR00<07BHS0P0O9B<03@0P9R@06QhM01/O
7P0N81l071hM01XL6`0L7Qd08bDR01XL6@0T9R<07AlL01LI5P0M7a`00P0L7Q/02@0I6aP07R0M028T
8@0G6AH05ALF01XL6`0D5QD04aDD01PJ6@0201LI600F01PJ6@0I6aX05QPG01<E500H6A/0KVie05=C
G00D51/09BH/01PI7@0K71l05aTI01HH5`0D5QD05ALE01@F4`0A4a004A8=01@E4@0E5A<051@B01<C
4P804a<C01805ADF01<C5@0E5AL05A@I010@4P0@41405aLG00d=3@0C4a<04A4A01HF5P0B4Q803Ph>
00l?3`0>3Ph03@d=00l?3@0?3P/300l>300A010>3`0?3@h04@l@014?4P0F51L0518E00l=4P0B41<0
40h@01<A4P0?3@h03P`=00l=3P0<2P/03P`=028P8@1HEUL00P0=2``01`0=2`d03P`?00l=400=2`h0
30X=00h<3`0?3A001@0=2`h01`0>2`h03PT=00d8300>2@d04@`@01@?4`0A31000P0@2`l03@0=20`0
3`X>01<>4P0<1`/040/?00d9300>2@d02PD900`72`0>2@d040/?01<>4P0@2`l0100=20`01`0A3100
50lC018=4@0<1`/03`X>00d8300<20/00P0>2@d00`0<20/03PP:00`6200200l92`0D018<3P11>cd0
40X<00L10`0A2`d07ALI01<=3`0=1`T030H800/61`0?2@/0?CLi05eGF@0C3@l0<B/]010:300=1`T0
3PP:00/51`0:1@H200l93@803PP<0P0=1`/0200<1PX04`dA00H1100?2Pd03PP<00T41`0@1@T03`@8
0P0>0`L0100?10P040D901052@0?10P200h31`0300l4200@1@Wooooo01?ooooo000Kooooo`0700lA
3P0B514020X701DG500@4Ph030h900`?200200d@2@0800hA200?4PT03a8900T<1@0@4``03a8;00hA
2P0B5@h3010C3005018E3P0?4P/041<<01HI4P0=3`X00P0@4Pd01P0>40/03@l:00h@2`0>40/03@l:
00`>2@803@l:00<03Q0;00/=2P0:30T00P0=3``02@0<3P/03Q0=018D4@072@H03a4>014C400B5140
1`T600lA300200/=200R014C3P0@4Pd02P`700h@2`0B50l04aD@00lA300E5a80>S`g02T[9P0;3@P0
4aD@00h@2`072@@03@l:018D3`092`H0418=00X<1`0T9R4030h:0001000>40d04A<@00P:1`0@4Pl0
3Q0=00840@0>40d0418?00/=2P041P<03Q0=01PJ5`8020X701001`T600T;200A4a00418?01HH5@0D
5Q<030h;00/=2P0;3@T05ALB00/=20092`H03Q0;00T;1P0>40/02`d80P0<3PT0100:30L0418=01HG
4P0B4`h2014B3@0400d>2@0>3`X030d800`=20<03@h900@03Pl:00L91P0A5Q802Pl;0P0;40`02`0G
71P05Q/G01DJ5P0?51003Q<?00H;1`0:3`/05aTF030b;`0D5Q<01PP500804aDB00H01`T600X<2@0?
4@h02`d:018D4@0:30T600`<2P0D00l?3@0=3@/03@d;00h>300@40h03Q0=01HM5P0nAcl02A0901HM
5P1LHU`0<SLa01LL5P0D5a803Q0;00`>2@0=3`X03a0;010A300?40/200d>2@0800l@2`0@4@`03a0;
00/<1`0<3@P0414<00l@2`0<3@P300d?2P<03Q0;0P0?4@`0600@4Pd03a4<00h@2`0=3`X02P`700P:
1@0:30L01`T4018D3`0R91l061XE00h@2`0:30L03a4<00P:1@0:30L030h9014C3P0<3PT03a4<00/=
200Q8ah03a4<014C3P803@l:00<03Q0;00lA3@0@4Pl00P0@4Pl200lA3P0=00h@3@051`@04Q@A00/=
2P0@4Pl03Q0=00lA3P0>40d0418?00lA3P0@4Pl05QPE01DG500500h@3@0600l@3P0A4@l04Q8@01<C
4@0B4Q004A4?100@40h200l?3@<030h=00l071hM01PJ6@0@4Pl04A<@00/=2P0@4Pd07AlJ01`N6@0C
5Pl071lF00d@1`0B5@`01`X300lB2`0B5@h00P0E5a801`092`P00P@101<E4P0E5a@04A<>010B3@0>
40/00`0?4@`01P0B50l03a4<00h@2`0@4Pd04A<>00h@2`803@l<0P0>40d200lA3P1;010B3`0?4@h0
3@l<00h@3@0@4Pl04A<@00h@2`0A4`d0418=00lA300?4@d0418?00h@3@0@4Q004A<B00lA400@4Q40
4A<@018D3`0?4@/03Q0;00lA300A4`l0418?01HH5@0Q8b403Q0?00P:2@0F61L04Q@C00hB4@0B5QD0
3a<B010D4`0A5A@03A4@01hR8@0l@3l0004001`P7`0;3`h03a<B01PM6@0@5A405Q/G00lD40062`L0
6b0L01@I5@0H7AT03Q<?00`A3@19CTX0e]_G024V8P0D6AD07b@P018G4`0E6QH06QlK01@I5@0A5Q80
5Q/G01`Q7@0I7QX05AXF018G4`0P9B40:BhZ024V8P0E6aL05QhI01PQ700F7aX051hI00804QdG01/0
72@O024W8`0K8Ad051`G01<L5`0E7QT09c4/02Pc;@0F8A/04alH01l/9@0M:R<05b8L024Z9@0S;2L0
6bDO01HQ6`0H8ad06RHO01`Y8P0L:b@06BPQ01HU7P0I:2407BdS01LY7@0E9Q`00P0K;280400L;BD0
834Y020a:@0O<2X07BhX01`]9`0K;2H08c<`014T800P<bl0H7=_02<f<P0U>3H05RPX028d=00P<S82
028d=P0@024c=@0S=cP093Pi02Xn?`0U>3`0;d9602@i?00T?400:d=702U0AP0/ADX0>55F039;C`0U
>Sl09S/n02Dj?@808SLh010093Tj02]1?`0Z@3h0:Clm02Y0?P0[@Ch0:3hl02Xm@@0/?d<09cXn02Dh
?00X?3l09c`o02]3A@0_AdT0<TY<0P0bC4d05`0`BT/0>U9F0359C@0U?D40<4Q<0359C00eCDl0=Ti@
03M?C`0hD500=e1=03I?C00eCT/0?5EB03M@C@0eCT/0>55>03YCD00hDDh0=Di;03M@C@0hDDh0>E9?
0080>U=@01<0>U1>03]AC`0nE580@5ID03eCD@0jD4h0AE]I03Y@CP0mDe40@EME03aBD00iCdd0>e5>
03=8@`0aAT40<dQ303=6@00aA3h0=4M10080=DHn00L0<D8j03=3>@0jBT00<44i02ho=@0]?S@0;Clc
0080;T0d01h0=DLk0311>@0eASh0A5AA03Y:B@0/?3T0=4Dm0352>P0cA3d0>DY403E8A00kCTd0;D52
03mBEP0jCeD0Cf=/05=WL012FFD0A5]Y04INJP15GFH0?eMK03Y?DP0nDU<0>4a;03=5A@0iBTX0=4A4
03=1A00/>ST20391?00@03A3?P0c@Sd0;chk02`k>00T<c00<3hn02Pf=P0O;Bd08Bl`02Tg=@0[>S<0
8S4Z02Lf;`0P;bP09S</02@_:@8082/U00D09c0[02Pa;00O:2<07RLR01lX8`02024Z9@0X020Y900N
9b8082TT024Z9@0P:B@072DP01XS7P0L9B006B8O01XS800M9R<082HT01lU8`0N92806alN01`P7`0N
81l06adL01XL6`0M7ah04Q@A01`N6`0C5A804Q@A030b;`0K7AX07AlL01TK600C5A805QPE01/M6P0G
6AH05ALF01PJ6@0C5A@04Q@C01PJ6@0K7A`06Q`K01HH5`804Q@C010061XI028S9@0C51T04a@I01TJ
7P0C51H0;Bl^03<e<P0K7AX05aTF01DG500E5aH05QPG01DG500F5a804a@@0P0A4@l08P0C4a805ADE
014A4@0E5AH04a<E01@D5P0E51T04A4C010@4@0D51@030`<01<C4`0?3`l0410@02h^;P0D51@04A4A
01HF5P0E5AD051@B018A3P0A40h040l=00l>300>30d03@/<00l=3P0@3Q404a4D018@4`0>314040hA
010>400A3a0200l=3P08010>3`0<2P/040h?0040000<2P/04@l@00<10P0?3@l200d;3P0300/9300:
20/030X=00H03P`?00<040d@014<400?2Ph00P0=20`04@0>2@d030L;00P31`0C3Q803@P<01<>4P03
00805A0D00<00P0G4QH02`H:018=4@0:1@T03PT=00l:3P0>2@d03@P<00802`H:0P0<1`/00`0>2@d0
40/?010;3`0200`72`803PT=01`02PD900d8300J5AT0?SPj00/51`0>2@X04`d?00D00@0E3a404@/=
00d72@090`D02`D700d72@0;1@L030H8018<3P0?2@/01P0200X41P0:1@H03@L901hH6P0;1PL03@L9
00h82P0D3Q003@L;0`0<1PX400/52@06010:3P0A2`l02086014;3`0@1@T03`@80P0>0`L0100?10P0
40D901052@0?10P200h31`0300l4200@1@Wooooo01?ooooo000Kooooo`06018D4@0;3@X04A<@00lA
3P0M7a/04A<>0`0>4@X300hA200800`?200?4P/030l800`?200>4@X02Pd600T<1@0>4@X2014D3@03
00lB2`0>4@X03@l:0080418=00@03Q0;00d?2P0>40/03Q0;0`0=3`X200h@2`0800h@3@0<3P/030h;
00lA3P0@4Pl03a4>010B3`092`P2010B3`0301DG500=3``03Q0;008030h900/03Q0;00d?2P0;3@P0
30h900d?2P0A4`h03a4<00h@2`0A4`l02`d800X<1`0200d?2P0:00lA300A4`h04Q@?00H80`0E5a80
3Q0;03Pj=@0N81`0ADM400/=2P803Q0=00l04A<@00h@3@0=3``04aDB00T;200J71T04A<@00h@3@0N
81d02P`9014C400D5Q<02`d:00`>2`0>40d00P0=3``0500>40d03a4>00h@300D5Q403Q0;01PJ5@0>
40/03@l:00lA300=3`X03Q0;00`>2@0:30L03a4<00d>2@0:2`H03@h9018C3P0@4@`03a0;1P0=3PT0
6P0?4@h02@h:00hC3`093PX02a0<00`A3@0@5A400@D1010E4@0:3P/03Q4>069WH`0I6aP08B<P00lA
3P0A4a006adJ06U[J00_<Bh03@l<018D4@0@4Pl02`d:00h@3@0<30X03@d;0P0>3P`00`0=3@/030`:
01<C4@0200l?3@0A018B400D5180418?02H]9P0B71@04AXB02/b:`3Af=40AD]4018G4@0A5@l03Q8<
00h@2`0=3`X03@h9018C3P0@4@`00P0>3`X0300B4`h051D@00h?2P0;30L03@h9014B3@0?40/030d8
00d?2P0>40/0418=018D3`8051HA100?4@`0700=3`X030h900`>2@0?4@`05QPC01DG4P0=3`X02`d8
01dO6P0C5A002P`7018D3`051`<03Q0;04I8@`0j?3L05QPC018C3`0b=2l02P`700`>2@0>40/03@l:
00`>2@0=3`X04A<?014C400>40d200d?300800h@3@0@4Pl03@l<00d?300@4Pl030h;00/=2P0?4@h2
010B3`0400d?300<3P/03Q0=00lA3PD03Q0=00<0414>014A3`0B4Q000P0B4Q02014A3`03010@3P0?
3`d03`l=00803`l=01l04A<B01@F5@0:30/03a4@010B4@0Q8b0051HC00lA3P0>40/0418=00d?2P0=
40T0:2/R0495>`0M81L06A`D00d@200A50d02`d:03<e<00/;R/03@l=02HX9P0A4a404aD@010B3@0>
40/04A<>01<E400@4Pd02`d800804aD@00<06Q`G01DG4P0A4`h00P0>40d08`0=3``03Q0=00lA3P0@
4Pl03a4>00h@3@0<3P/03@l<018D4@0D5Q404A<>014D3@0?4P`0418=014C3P0A4`l0418?014C4@0@
4Q403a0A018C500F61H03@l:01@G400;3PP0418=01<E4@0J71P04A<@00lA3`0@4Q404Q@D01<E5@0B
4a@02`l>008041@C0P0C5aH0600?4a804QHE010D4`0=4A003a<B01TM700E6AP04QLC014F4P0>4`l0
5AXF010E4@0B5a<051TE018G4`0C61@06AhJ01PM6@0X;BT061dI01@I5@0A5Q805Q/G01LL60804aPD
00<03a@@01DJ5P0H7AT00`0D6AD01@0L8Ad08BHR01XO6`0C6AD05QdI00805AhI01T051hI01@O6@0E
81X0620K01TO6`0G7AT05QdI01LP6`0J8ah07BLQ01`W8@0I91h05b<M01PU7P0I9Ql05b8L01LP6`0K
91l07BLR01lZ900Q;2H08BdW024^9`0N;BH072/T008062LP00d06b/Q01LY7@0F9ad06BXP01LX7P0I
:R807RlW01d^9P0M;RP07RlY01d^:00N;bT07C0/00807c8^00X0DfIR02@g<`0J;B/07c4a02Hh>00M
;bl08S@f02Dg>@0R=3H08CDf0P0X?3d05P0/?d<09cXn02Dj?@0W?d<0:T9602LnA00V?d@0;DI;02Ho
@`0Y?T<0;45402Tn@@0T>CX09c`m02Tn?`0T>SP09C/i02Lm>P0X?S/0:T0l02Y0?@0V>S/202Tm?`0?
02Pk?P0]@D<0=4U;03A<C@0cBd`0<TY;031:BP0_BDT0;TQ903I>DP0aBDd0>E5E03A<C`0hD5<0>E5C
0080>E5A00`0>55?03UBC`0iDTl0>55>03aEDP0hDDh0=Di;03I?C00eCT/0<da903E>B`0hDDh203YC
D00:03M@C@0dCDX0>U1>03mED`0nE580>Dm=03eCD@12F5H0C69P03I<BP80?59@00X0<DM503=9A`0f
C4T0=T]603Q=B00kD4/0=TU30354?P0bACl0;Chf0P0`@CT202`l<P040393>`0`@CL0<D8h03E7>`80
=TPl0280=DLk02Xk<`0]?SH0<40m02dm?00dA440;Chd02`m=00a@S/0=4Do02e0?00hBdX0>di>045D
EP0lCe<0AeYQ049EG015Ff<0B61Y04URJ@15GV80?EEF03]AD00hCD`0;40n04=DE01XN7L0QIBD03e;
CP0c@T40;C`g02hm>00a@3/0<T4l0P0^?CX04@0Y>3D09cDe02Hd=00/>SX07R`]02dl>@0^?CH08c8[
02Xi<P0M;2D09C8[020[9@0K9R007BPR02`e<00_>3<08BXU00807bPS100Q:RD00`0N9b807BHQ01hW
8P0301dV8@0J01/T8@0M9R<082TV02<Y9`0R:2H082HT01`P7`0M8B007b4P01`N7@0K7A`07AlN01lQ
7P0H6QL07R0M01dO700P8Ql07R0M01/M6P0G6AH04Q@A010B3`0C5A805QPE018D4`0F61L201PJ6@0L
01TK6P0J71/08R@S01LI600Q8b808R@S01PJ6@0S9B@07QlQ01XK700Q8b00@dE20;>e/014ASl07AlH
01PJ500D5Q<05ALF01PJ6@0H6QX05QHD01<D400B4Q004a<A01@D4`0B4Q803`l?01DE5P804a<E00l0
5A@I01<C5@0A4A804Q8B014A4@0S8b<05QHF00`<300G5aL02PX:00/;2`0?3`l03Ph>00l?3@0@3``0
0P0@3`d01@0A40h04@l@014?400@3Pl040hA00804@lB00D040hC010>4@0=2`d03P`=00/92P0200l=
3P0=00T7200A3a005A<D00/92P0>30d030X;00d;3@0=2`h03`d@010>4@0A3a805A<F018@4`0500d;
3P0300l<3`0@2`l03`X>00<03@P<01D03PT=00@00`0C3Q803`X>00d8300N6Ad0NGAh00h:3@0;1PX0
2PD901LB5P080`L040/?00/62P0=20`04PdA00h93@0<1`/03PT=00d8300<1`/00P0>2@d0100=20`0
20@700l:3P0E41@200X52@0I01hI7@1YHfD09R0R00h92P0<1PP03PP:018<3P0>20X04P`>00/51`09
0`D04`d?014;3@0B30h030H800h82P0A2`d03@P9010:300=1`T01000018=3P1SGEl07ALI00d72@08
00d72`0600l93@0@2Ph0DTe@02XU:00@1@T03`@80P0>0`L0100?10P040D901052@0?10P200h31`03
00l4200@1@Wooooo01?ooooo000Kooooo`0601LI5P0D5Q<04A<@02X/:@0M7a/00P@00P0@4``02`0?
4P/03Q4800hA200=40L02Pd600hA2P0=40T041<<01DH4@0@4``030l80080:B`U00@04QD>01<F3`0L
7aP03Q0;0P0A4`h400lA300800h@2`0=3`X03Q0;00h@2`0?4@`0418?00h@3@0=3``2018D4@0800d?
300D5Q<02@/800X<2@0=3``0;S0]03Tk>00?4@`201@F4@0I00/=20082PD03@l:00h@2`0;3@P0418=
014C3P0;3@P03a4<01TK5P0E5a8030h901<E400@4Pd02`d801@F4@092`H030h900@60@0K7AP06A/G
06IXI@0;3@X020X700`>2`0200d?300700P:1`0?4@h030h;01<E4P0:30T03a4>010B3`0200/=2P03
02HX9@0@4Pl04aDB00802`d:01804A<@01<E4P0>40d02`d900/=200<3PT04aD@00X<1`092`H03a4<
00h@2`0A4`h0418=00/=200=3`X0:R/V01hO6P0?40/200`=2003014B3@0>3`X03Pl:00<03@h901/0
30d8018G4`062`L03A8>00/@30083@T04aPD00870`0a=S802Pd:00dB3P0F6aL0>d0l00T;200;3@X0
4aDB00L91P0];b`0fM_H04A6@`0=3``04aDB018D4@0620D03a4>00d=2`0?3`d00P0@40h00`0?3`d0
3@d;00l?3@0200d=2`0A00h>300@40h03Q0=01DL5@0H8QX04A/C00P?200V;BH061lH00T>200;40X0
314;00h@2`0=3`X02`d8014B3@0@4@`00P0?40/01P0B4`h051D@018C3P0A4Pd0414<00h?2P803@h9
00H03Q0;00lA300A4`h051HA01HH4`0G6A@400h@2`0D00d?2P0<3PT020X500D70P0:30L04Q@?00h@
2`0:30L03Q0;00`>2@0;3@P0418=00`>2@0A4`h04A8?01lQ70000@003Pl<02<U800U9b8200d?2P0>
00lA300;3@P030h9010B3P0>40d030h;00/=2P0<3P/03@l<00/=2P0E5a@02`d:010B3`0:30T200lA
3P@03Q0=0P0?4@h500h@3@0300l@3@0?3`d03`l=00H03`l=0P0@40h02@0A4@l02@/:01@F5@0?4A00
4Q@C02`^;@1<CT/04A<@00lA3P02010B3@0B014C3P0Q91`0Z:^R0?KikP1JGE@07B0G01HI400=40T0
8B<N01@F4@0M7a`09BLV014C4P0<3P`04A<@010B3@0>40/0418=0P0A4`h0200F61<08B<N014C3P0G
6A@05ALB01hP6`0?4@h03Q0=0P0<3P/00`0?4@h04A<@00h@3@0200d?301100h@3@0A4a004aD@01<F
3`0@4``03Q4:010B3@0B50l04A<>018D4@0C5A<04A<B010A4`0B4aD05QPG01<E400<3`P04aH?018D
3`0C5A40MWQc02d_;00A4a404Q@C01LH6P0?41805AHH00X>3@0?4a80310?00hB4@0?4a80310?01DI
600J7Qd04ADD020T8`1YKF`03A4@01DJ5P0F6aL0724M00`A3@0H7AT0AT]701dR7P0N8al08bPT00D:
1P0>4`l01``8010E4@0J7a/0:BhZ01DJ5P0B5a<04aPD01HK5`0D6AD061dI01DJ5P0F6aL07b@P01PM
6@0B5a<00P0C61@01@0C6AD061lK01LP6`0F7aX051hI00804QdG01D051`G01LM6@0I7a/06R4M01TR
7@0H8A`06B<M01HQ6`0E81X06RHP01/X8@0L:B808bhX020Y900M9R407bTS01hY8`0O:R@07BTR01TV
7`0H9b000`0K:R<01@0J:b4062XN01X[8@0O<2H07BhT00807c0X02/06BXR01//9P0L;BL07BhX01l`
:P0J;BT0:chj014T800H:bL07C0/028e<`0W>CT0:3Xj01/];@0S=CL0:3Xl028d=P0R=SL09c/l02@h
>@0V>Cd08SDi02Hk?P0Y@DD0;TI:02e4BP0X@DH0:T=802U2A`0W?440:Sm202Hk?P0U>S/0;45202Pm
?@0R>3H093Xg02Lm>P0W?SP0:D0j02a3?@0Y?C`0:3`m0080:cm00100;4520397B00cBd/0<DU902m7
A`0^B4L0<Ta;03E?CP0kDeD0=4a@04ALH00Y@D<0<TY<03UAD`0dC4`0=4a;0P0cC4T0200eCT/0=Tm<
03YCD00iDTl0>55>03I?C00eCT/0=4e:0`0hDDh02`0gD4d0=Tm<03E>B`0nE580@UQF03mED`0jD4h0
@eUG04eSH@15FeT0=4Y80080>U1>00`0<TQ603I<BP0`AT<0=T]603U>B@0jCdX0=dY403I9@`1LKfT0
?Tm703M8@00jBd<203Y:@00503=4?00_@3H0<T<i03Q:?P0iBcl00P0gBCd0A00fAcl0?Tm703Q8A@25
UI@0<d=002Li;P0]?S@0=TLo03]<AP0iC4X0<D=203]=C@0_@D<0AUQK04=FFP14Ee/0BEmS04MPI@16
Gf<0@eaM03iGE00mDe00?E1>02@g=@18F5L0AEAD06IdM@0_?D00=4=203Q7@P0fAD00=4<n0350>`0]
?3T09SDb02hm>P0[>CT0;C/k03m=C@0G9BH08S0^02/j<`0Q<2T09SD^01h]9P0U<R/07bXT01XU7`0I
91h08BXU02</9`0M9R407RLR01lX8`0P:B@08BXU028[9P0S;2L08R/V020Y900N9b8072DP01/T7`0H
8A`0624N01XS800N9b@092XX0P0U:bT03`0J7Qd0720O020R8@0N81l071hM01dO7P0P8Ql0;Bl/018D
4@0e=c@0Q8J304E7A00B51404aDB01HH5@0201@F4`0901/M6P0H6QT06Q`K020R8@0O8B006adL01dO
7P0H6QT06Q`K00804A<B02X05aTH00lA400K7AX0:2XU020S7017BT40cM3504I9?P0H6a005AP@01<E
400E5a@05QPI01DF600F5Q@04a@@01<C4@0E5A<051@C00h>3P0H61P07alP01TI6`0D51H04a8G014A
4`0A4A804Q8B01<C4`0X:2P061PH00`<300A4A405ADE01PH600B4Q803`l?01<C4@0D4a004a8@014@
3P0?3P`200d;3009010>3`0A3a803P`?010>4@0A3a@03`d@010>400?3@h03P`=00804a4B00<030X;
010>3`0;2@X00P0<2P/01P0I5aP02`T;00l=400@3Q403P`?00d;3P803P`?1@0<2Pd00`0=2Pd03PT=
00h93@0300l:3P0;01LB5P0I51P07QTM00P31`070PH020<703Td>00C3Q8061<G00X52@0J5AT00P0>
2@d01P0?2Ph03@P<00h93@0910P04@`@01HA5@803@P<01003PT=00l:3P0=20`04`hB00`72`080`L0
3`X>010;3`080`L02@<500D00@0?2@/0100000L10`0<1PP01P020P0=1`T0100<1PP04P`>010:300A
2`d200d72@0:00X41P0600803PP:00d72@0;1@L0100001lI6`0E3a402`D700d72`<03PP<0P0?2@d0
200C3A404@/?00H010040080G5IJ01XD600@1@T03`@80P0>0`L0100?10P040D901052@0?10P200h3
1`0300l4200@1@Wooooo01?ooooo000Kooooo`0600T;200K7AX05ALD01/M6P0?4@d03Q0;0P0>4@X0
4@0?4P/03a89010C2P0@4`X03A09010C300?4P/04aH?01PK500B5@h00@@001PK500F6A801PT200P;
100=40T03a4<00804Q@?0P0@4Pd0100A4`h03a4<00h@2`0=3`X200h@2`0F00lA300?4@h03Q0=00d?
300D5Q<04Q@A00X<2@0<3P/03a4>010B3`0H6QL0DeEB071bK`0A4`h05QPC01TK5P0@4Pd02`d800lA
300@4Pd03Q0;010B3@803a4<018030h900H80`051`801PP300lA300A4`h03Q0;010B3@0>40/03@l:
00h@2`0B50l02P`801TK600D5Q<03a4>00/=2P0?4@h200h@3@0H01/M6P0A4a0020X700@60`0H6QL0
008000/=2P0h>SL0MgUf01hP7@0620H03@l<010B3`0C5A804A<@00`>2`0=3`/04A<>00h@2`092`H0
51HA010B3@0>40/030h90P0?4@`01P0;3@P03a4<034b;@0T9B0051D@00l@2`803@h90`0>3`X0100=
3PT030d800`=200;40`200L=2@0A00T?2`083PX03Q@@00lE4@2CVID07R@P00H<200D6QH041HB018D
4@0?4@h030h;01<E4P0H6QL05aTF02@V8`092`P00`0?4@h00`0A4a003@d;00l?3@02014A3`0?00l?
3@0=3@/030`:00h>300=3@/030`:00h>300?4@h0<CPa030j<P074@T031H>00dF3P0?5Pl02a0:0080
2Pl900<030h900d?2P0=3`X00P0>3`X400l@2`07010A300C50l04Q<>00l@2`0D5A0061TD00`>2@02
00d?2P<03a4<00@030h900d?2P0>40/03Q0;0P0=3`X0100D5Q40418=00h@2`0?4@`2014C3P0B00h@
2`0@4Pd04A<>00/=200<3PT020X500X<200A4`h04Q@?010B3@0;3@P0;BlZ00h@2`0=3`X0418=00X<
1`0;3@P03a4=0`0=3``02@0>40d03a4>00`>2`0L7Q/02@/800d?300?4@h05QPE00lA3P0200`>2`04
00h@3@0@4Pl04A<@010B3`D03Q0=00<03a0>010@3P0?3`d00P0?3`d08P0@40h03`l=00h>300?3`d0
4A4?018B400C4a404Q@C01/M700=3`h00040014C4P0F61D02@/8010B3`0G6A@03@l:00`>2@0W:R80
/;>Z0??fj`1DEdh04aH=00lB2@0@4``03a4<00D70P092`P061XI014C4P0>40h03@l<00d?2P0>40/2
00d?2P09010B3@0J71L09bTT00lA300C5A00418=01`N6@0?4@h03Q0=008030h;00@03a4>014C400>
40d03Q0=0P0?4@h07@0@4Pl04A<>01<F3`0>4@T030l800hA2P0A4`d0418=014C400C5A<04Q@C010A
4`0@4A@04Q@C00h@2`0;3PH04QD>01/N5`0G6Q@0JF]V02PZ9`0E5aD04Q@C01@E5`0@4A@04a@F01<G
5P0D61L03Q8A00803A4@03l02Ph=00hB4@093@`06AdL020T8`0m@D0051PG00D:1P0:3`/06AhJ01HK
5`0Y;RX0FUmK02T^:P0>4`l04QLC01@I5@0H7AT04aPD018G4`0b=c<0PhR401hS7`0B5a<05AXF014F
4P0D6AD06QlK01PM6@0Q9R80<SLc01hS7`0E6QH061dI01/P700H7QX06R4M01PQ700G81/05AlJ01@O
6@0E81X05alJ01XP700K8Ad072@O01XS7P0I8Qd072HP01TT7P0H8ad07BTS01dZ8`0N:b@09S4[024Z
9@0L9B007RPR01/V800J9Al072PQ01`Y8P0K:R<00P0N;BH02P0M;2D06b/Q01T[7`0N;bD08S<Y01h_
9@0O<2P07RlW01PY8@0I:R@201X[9@0/01//9P0O<Rh06bhZ01d`;00U>3@05bXV028e<`0R=3@0:3Xj
020b<P0U=cT09SPj020b=00T>3T09SXk02Lk?00T=c/09CPl02Ll?`0U?D40:41402PoA@0V?d@0:456
02M0A@0S>3d09S]0028g>P0V>c`0;dA502Dk>@0S>CL09S`i02Ln>@0U?3H09C`e02Po>@0/@3l0:3`k
02e1@00_@d80;D9002m5@`0^Ad@202m8A@0C02m9AP0aBdP0<Ta;02m7B@1=IFP0O9BF04aTIP0hD540
;DE503=;B`0bBTT0<DY7039;B00dCDX0=Di;03M@C@0iDTl0>55>03M@C@0203I?C00603UBC`0gD4d0
=Di;03I?C00iDTl0>eAA0`0kDDl0100mDe40@eUG04ILFP13FEL203I<BP0g03=9A`0/@T00;D=102m5
@P0dBD@0<dQ30356@@0dAd40>4]505=VH00gB400;d0h0311>@0c@cT0=THl0352>P0]?S@0<44g03M9
?@0hBSh0=DLk0394>00Z>c<0=TLo0351?P1]OG`09CDb0311=P0b@cT0<T<k0393?@0eAD@0<D9104AF
EP0fB4X0CEmQ045CE@1LKW00@EIJ04AMH@11FEd0@UQJ045GE@0nDU00@EEA03E8A01<G5/0>DQ802Le
=P10CU40BUQG03m>B@0jBD@0=D@o0391?00202ln>`0A01<R7`0N;2`0>dU909j/[00`?Sl09S@a0392
>00W=bd093@Z01l_9@0Q;RD07RTQ01`W7`0I91`072HN024[8`0W<BT00`0Q:RD02@0P:B@08BXU028[
9P0S;2L082TT01dV8@0L9B006b@O01LP6`0201PQ7P0;01XS800M8b407R@R01lU8`0I7A`0720O028T
8`0P8R407AlN01`N7@0K7AX00P0H6QL0<P0E5a@07b4N01HH5@0A4a005QPE01`N6`0H6QL04A<@01PJ
5`0L7Qd06Q`K01dO7P0K7A`06A/J020R8@0R92<05ALF01/M700L7Qd04Q@C01PJ5`0>40/082<J01dP
5@0C5P/0CU9401XN400D60X04aH=018D3`0D5Q<05AHH018C5@0J6QP04a<@010@3P0C4a404a<B010@
400F5QH07AdN01PH6P0C4aD04a8G018B500?3a004Q8B00d=3@0I6AT0410@0P0=3@d02@0?3`l0410@
00X:2P0820P03@d;01DD4@0C4Q004Q4?010?3@0200d;300700h<3@0?3A002`T<00d;3P0?3A8030X=
014?4@0200l=3P0501DC500D4Q<03@/<00h<3@091`P00P0F51D01`0@3Pl02`T;00l=400?3A0030X=
00X82`0;2@`01P0=2`h00`0>2`h03`X>010;3`02010;3`0D00l:3P0;1PX00`0200<00P0>2@d071LK
00h93@0300801`86018=4@0C3Q805Q4E00l:3P0<1`/03`X>018=4@0A3100100300X52@0D3a<200h9
3@8040/?01403@P<00T4200=20`03`X>00/62P0:1@T040/?01H@4P0=1`T01`4301<=3`0L5QP03PP:
00T31@0<1PP03PP:00d72@0200h82P803@L900X04`d?01PB500K5AL03@L900`6200C3@l040X<00@0
000A2`d020<40P0<1PX200d72`803PP<00P02`D900d82`0?2@d07ALK01H@500>20`040D900l42080
3P<700@03`@801052@0@1@T03`@80P0>0`L00`0?10P040D9ooooo`0Cooooo`006oooool04@0=3`/0
3Q0<00h@30072@D0418=01<E400;3PP03@l900hA2`0@4P`041<<010B300=3`T03Q4;00/>200>4@/0
4QD?00802`d700D03Q4;00lA2`0@4`d051H@014D3P03010B3@<03a4<01003@l:00lA300A4`h02`d8
00T;1P0A4`h02`d9018D400<3PX04A<?00d?2`0?4@d04A<?00`>2P0=3`/02`d90P0@4Ph200h@2`0X
014C3P0?4@`02P`700/=200>40/04A<>010B3@0<3PT04aD@01PJ5@0D5Q404aD@010B3P092`H030h9
010B3@0>40/0418=00h@2`0B50l030h9014C3`0B4a00O7ij024S7`0620@05ALC014C3`0?4@d0418>
014C3`0O8Ad05QPD00lA3@082PH051HB00`>2P0S9B401`T500lA3@D03Q0<01H02P`8020R7@0A4`h0
30h902X/9`19BdH071hI014C3P0<3PT03Q0;00`>2@0?4@`03@h900T;1P0;3@P0418=00h?2P0?40/0
3Pl:00h@2`0?4@`03@h90P0<3@P01P0>4Pd02Pd9018F4@0N8Qd03a8>00hA3@803Q8=01<041@?00X>
2@0A51002Ph900l@3P0=3P`0414>00P91`0;30X03Pl=014B3`0<3@/051DB00P91P0@4@h030d;00d>
2P0>3`/03`l<0080410=01003Ph<014A3`0@40l03Ph=00L71P0C4a805AHC00H8100>40`04AHA00/?
3@0>4a403A8A00`B400<4@l03A4?0P0=3`/04`0@4@`03Pl;00`>2P0<3PX03a0<010B3P0@4@d03Pl;
018C3`0C51003a4=01<D400I6aL03a4<014C3P0<3PT05aTD00`>2@0@4Pd00P0;3@P0700=3`X03a4<
00/=200>40/02@/700h@300<3PX02`d9010B3P0A4`l03Q0<010B3P0C5A403Q0<010B3P0:30P03@h;
00h?2`0?40`02P/8018C400:2`P03a0<014B3`0B4`l03@h:00`=2P0>40`200d?300A00lA3P0A4a00
418?014C400K7AX02P`900d?300D5Q<05aTF00h@3@0=3``02`d:018D4@0A4a004Q@A00`>2`0=3``0
0`0>40d05P0A4a004A8B00d=3P0>3@l0518A01<@3`0A3P`040l<00`<2@0@51002@l;00hI5`0F8Ql0
314?01HH5P0@4Q002@/901@F500>40d04Q@A00lA3P0?4@d2018D400J01@F4@0R91d0?T0h01TK500A
4`d02P`600`>200F5a80>S`g034c;`0:2`L04A8>014B3`0<3PT03@l:00h@300@4Ph02@/9010B400>
40h05QPD00`?2@0?4PX02Pd400/>1@0A4`d300h@300300lA3@0A4`l03Q0<00@03a4=01D03a4<010C
3@0=40X03@l900lB300@4`d03Q0;014C3`0B51004Q@B010B400?4A003a4?00d?2P0D5Q003a4;01PJ
5P0?4@d051HB014C400B51400P0B51805P0C51D051DE01lR7`0L7a/04aHB014D400B5A404AD@010D
3`0B5Q404A@@01TL600D5a<03Q4=01DJ5P0B5a<041DA014F4P0@5A405AXF01<H500I7QX201@I5@07
014F4P0F6aL05QTF03@h=01nPGh09BPU01@H500201<F4`0T01@H500H6aP04QHB01PK600S:2@06QlJ
01<I500H7QP082LQ01@L5P0H8Q/05R0J01PR700G8Q/04AdF01LS700K9Ah06R@M01dU7`0K9Ah07BLQ
01hX8@0K9b007B/S024]9P0M;2<05bLO01/Z8@0R<2L082`T01dY8P0O:b<07B`S020/900S<RT093<Z
0P0R<RT0100P;bL072`S01`/900M;bL201d_:00;01X/9@0L;RL0838/01T[9P0O<B`07BlZ01T[9P0M
<2/07S4^01``;@0M<2d00P0O<Rl01@0T=cD07c8a02Lj>@0V>CP093Lf00808SDd04808cLg01hc<`0W
?3d0:Ce002<g?00W?4809ce302PmA00X?T@0:T1402U2A00X?T00:3`m02a0@@0U>CX0<DA503U>C00Z
?S`093Pe02Lm=`0X?CH0730Z02@j<@0W?CL0:d9102Y2@`0[@d@0<4I802e3A@0`B4L0<4Q902m8AP0a
BDP0<da:0359B00^A4D0>U5C02e4A`11F5X0=Ta?03M=D00dBT`0=Te>03U?D@0dBdX0;DA504=JFP0k
De@0=Ti?03I?C`0jDe40>55>03UBCP0fCdX0>e=>03A<B00bBDL0>Tm>03iCE@14FET0=de:03=8AP0g
C4P0?55=03Y@C00iCd/203I;AP0A03E:A@0bAd40;T@n02i3?P0cAd80<TI002m3?@0]@C`0<dI003Q;
A@0^@C/0<48k02i0>@0dASl0>de603Q:@`0iBd@00P0dASl0A`0iBd<0>DY103i?AP0kC4<0;clh03A4
?@0b@S`0;clj02hn>00_?cD0;clf04=CC00c@ch0?Ti=03]<B`12De@0>D]>045CEP18FUl0LhB:059U
J`16G640@UIL03eBE010De40>dm;03M;AP1FJF@0?e1<03]<B`0lCTd0>dY<03Q7AP0jBD@0<3lj0391
?00Y>3<0<D0l02Dd<00b@Cd0:3Lc024`;@0iB4H09S@c02Db;@0c?cP0;SXc02<_:00Q;BH08bhW020Z
8`0O:B<07RPR01hX8@0R;2D0:cD^028/9`0S;bX082/V024[9P0R;2P07RPS01dW8P0H8Qd07RLS01XS
7`0L9B407BDQ01PQ7P0P:BH07RLT00807R@R0280728P01TM700K7ah08B<R020R8@0N81l06adK01TJ
5P0K71L07b4M01HH500E5a<06AXH01PI600`<C00@dA501/L7@0B4a@071dM01PJ6@0G6AP071hM01DG
5P0G6AP06adL01lQ800G6AP0@49103m1@00E5aH07R0N01`M6P0D5Pl07R0I0P0E5`l0:00K7AD051H>
01<E3P0B4a004a@A01@E500C51<06ATF01DF4P0B4Pl04A8>01<C4@0C4a804A4@01DE5@0C4a@04Q8C
01@D5@0E5AH0410@01XJ6P0@41003`l?00/;2`0B4Q805ADE010@400B4Q803`l?018B4P0A4A404Q0@
00l>3@0@3Ph04Q4@014?400?3@h04Q0A00l=3`0>30h2010>400C00l=400>31004@lC014?4@0?3A00
4@lA00`:300B418030X;014?400>30d02`T:00l=3P0>30h03@/=00h<3P0?3@l04@lA01<A4`0200`:
300T00l=3`0=2`d030X<00d;3@0A4180510C00d:3@0920X040d?03Xg>P0c<S@030P;00h<3P0;2P/0
3PX=01<@4`0@3A0020D800d8300910P03@P<014<400@2`l05Q0D01PB5P0<1`/030H:00d9300:2@X0
40h@038^<@0]:B/040`>00l:3@0B2Ph04@T=0P0=10P01P0?1PX030D700l92`0>20X02`D700T41@<0
3PP:0P0?2@/04P0=1`T03PP:00X41`0=2P`04`hB00L21`0@3@l0@Si201LB5`0;2@X0<bhb00l93P05
0`@050hC00/52@0;1@P03`T<010:3@<030H900D03@L:01LA500;1@P02`D800h82`0201052@0:00l4
200>0`L040D901<8300?10P040D900l4200>0`L03`@801462QCooooo000Kooooo`8030h90P0=3`X0
100<3PT02`d800`>2@0=3`X300h@2`0>00d?2P0>40/03a4<00`>2@0>40/04aD@00d?2P0G6A@01`T4
00d?2P0E5a80418=0043000?4@`200h@2`803@l:0P0<3PT03`0;3@P00040018D3`0K7AP0004000h@
2`0I6aH04A<>018D3`0620<03@l:010B3@0?4@`03@l:00`>2@0200/=200600h@2`0<3PT03@l:010B
3@0A4`h0418=0P0>40/01P0=3`X02`d800h@2`0;3@P00P@000L9108071hI00<03a4<00X<1`0<3PT0
0`0=3`X03`0>40/03@l:0084001@DTd061XE0002000A4`h03Q0;00d?2P0;3@P03@l:01DG4P0A4`h0
30h900h@2`0400lA300B00h@2`0;3@P02P`700h@2`0A4`h0418=018D3`0620<03@l:01<E40000P00
<cD`028T7`0C5A002`d800lA300:30L02`d80P0=3`X00`0<3PT02`d800/=200200X<1`0<00`>2@0?
4@`03Q0;00d?2P0?4@`02P/600L80`0B4`h05QLB00D60@0?40/030d80P0?40/0AP0>3`X04A8=014B
3@0>3P`01`L503@d<P12@T003`l=00h>300820H04A4?00h>300<30X051@B00L80`0<3@P03a0;014B
3@0B4`h0410=00/;2@061P@06QXI01dM7@0G5aL010@400@30@0<20L05a<A01`L6P0E5AL020X=00T=
400=4QD0310B01@H5`0@4Q40418>00X;1P0I6aP04aDB00lA3P0@4Pl04A<@00lA3P0@4Pl03Q0=018D
4@0A4a002`d:00`>2`0@4Pd04A<>00P:1@0C5A000`D000L9100<3PT02`d800d?2P0>40/02P`7010B
3@0<3P/03@l<00/=2P0?4@h04aDB014C400?4@h200d?300300h@3@0=3``02`d:00803Ph<0P0A4@l0
2@0@40h04A4?010@3P0B4Q00410>00h>300?3`d04A8@010B3`0200h@3@<0418?00@03a4>00d?300>
40d03a4>0P0@4Pl060082PL04A<@00L81P041P<051HC014C400=3``03a4>010B3`0C5A8061XG02LY
:@0P7b@03P`?00T41P0>1@H04`/902<O7011@Sd041HB00`I5@0kDT`0WkJb02@]:P804A<@00`03@l<
00L91P0>40d03@l<00lA3P0@4Pl03a4>00h@3@0?4@h04a@?018C3P0A4Pd3010A300D00X;1P0I6QD0
61TD00d>2@0F5a8061TD01@G400I6aH01PP500L9200<3Pd03PlA010B4@0?4@h03a4:010C200@50H0
3A4300hA2P0<3PT2010B3@0400h@2`0A4`h030h900d?2P803Q0;0P0@4Pd00`0?4@`03Q0;00lA3002
014C3P0300lA300@4Pd04A<>00804A<>00/0418=00lA300:30T05aTF02LY9P0U9b@05ALD00d?300@
4Pl03Q0=01<E4P0201@F4`0=01dO700D5Q404aH?018E3P0C5Pl05APA01HI4P0C5Pl04A@=01<F3`0A
50d03a8;018D3`06014F4P804QLC02P04aPD01@I5@0D6AD051TE01HH5@0I6aP06adJ01TK600E5a@0
4aDB01@F4`0F61D06Q`I01TK600J71T07B8N01LM5`0B6A809bhW02hh<00F81P04Q`D00lJ4P0J9Ad0
5B4I010M500D8AP04alF01XU7@0K9Qh06RDM01hY8@0L:B006BPN01TY7`0N;R@093D[01d^900J:b40
72`R0P0M;B<201/[8@0301d]8`0Q<BL08C4W0080830V05X07RhT01/[8@0K;BH072l[01X]:@0H:bL0
6RdY01`_:`0G:RH07C0/01LZ9P0P<bl0:chj01ha;@0K;bd07S8`02Lk>@0U>CL0730^01T]:`0P=380
7C4_01/_;@0Q=C<09SXh02@h=P0S>CH08SPe02Dj>`0V>d00;T=80314C00Y?DH0:Si502]0A00[@4<0
:d4o02Y0?P0Y?3X0:3/i02Hi=`0^@Cl09cXh02`o>`0U>3807c8/02Pk=@0X?3<0:clf02@i=00Y@D40
:DA602U3A00cC500;dU:02i8B@0bBT`0<DU:03=;B`0eCDd0=Da<03=8B@0bAdX0=DY=0397BP0`ADP0
<TM:03U>D@0cB4/083Dh049GFP0lDE@0BUmR02Lo@@0nEUX0=e5C03==C00Z@d00>55<04=ME010Edl0
>Di:03I:B@0oDe@0?4mD03]>DP0gBdP0>Di903eBC@0hCDH20356?`0403=8?`0gC4<0=da30398?080
<4Hj03@0<dI003I9@`0eB480<D@n0395?`0dAd40=DQ203a?B@0^@C/0;3li03M:A00mD4X0=4M303=6
@P0Y?3P0>Te803U:A00eASh0=4Dm03=2>`0c@cT0=DDk03A1>00a?SD0;c`c03a;A02a`;X0?Da7024a
<00nCTh0?Te@041BEP15EU`0BEYQ04YKH`19FV<0A5EM03i?EP0iBdh0>Da:03=6@P0dB400@UI=049E
C`0lCd/0?4m=03e?C`0iBTL09cHa02/j=@0b@C`0<3lj0P0X=c802`0]?3L0:cXe02/j=@0]?3L09cHa
02Pc;P0V;bX0:34/02D^:@0O:2<06b@O00808R/V0P0Q:RD0;00R:bH08R`W01lZ9P0Q;BT08bl[01hZ
9P0Q;BT072LS02D`;00G8Qh07BHS01HO700J8b005Q`J01PQ7P0S;2T06b@Q01`R800M8b406R0N020T
8`0O8b807b4P01`N7@0J71/061XH01HG4P0L7AL06a`F01LH4`0L7AP071`J02PX:00H61T0:2PZ018A
5P0K6Ql04A4C01XK7@0Q8b807b4P01HH5`0K7A`06Q`K0P0E5aH0300N81l071hM018D4`0E5aH05ADC
018B400G5aD06ATG01`L6P0U9B<05ADC01<C4@804A4?00<04a<A01DF4@0A4Pd00P0D5A001P0B4`h0
4a<@01HF500B4Q004A4@010@40804A4A01d04Q8B01PH600<30`02@T901HF5P0B4Q80410@014A4@0>
3Ph05ADE018B4P0I6AT04a<C010>3`0>30d03`d>014?400@3Pl03`d>00d;300F51D06QPI01<A4P0<
2P/03P`?01TG7@0<2Pl03@/@00X83@0201DC5P0J00T72P0610D02`T:00h<3@0J61T040h?01lM7P0^
;2d040h?0040000>30d0518C00/92P091`P040h?00l=3P0>30d0BdY;0410@00:2PX04Q8B014A4@0C
4a<0N7Qh07AdM00Q8B4200H61P0;00P8200=30d030X=00`:3@0<20`030L;00d8300>2@d03@P<00h8
300?2@d00P0@2Ph02@0B41802`d<020P803oo_l0bLO801hH6P0B2@`04@P;01<72`0201<42@0901<3
200A20/03PP:00h82P0=1`T03PP:00l92`0<1PP03@L900803PP:0P0=1`T07`0>2@d05Q@I01dI7`0?
2Q005A<H04A0AP0:1@/00@0403Hc>00300@00@0400T52@0<1PP0208400P3100;1@L03PP:01@>400J
51H03PP:00X41P0;1@L03@L9018<3P0>0`L040D900l4200=0PH03`@801@93@0>0`L00P0@1@T00`0>
0`L03`@801052@0Dooooo`006oooool0200;3@P03Q0;010B3@0A4`h03a4<00d?2P0?4@`03Q0;100=
3`X03@0>40/03a4<00d?2P0?4@`04Q@?00d?2P0:30L05QPC00<5000;3@P0008001lQ700@4Pd00P0?
4@`200h@2`0=00d?2P0C5A000P@001PJ5@0B50l03@l:018D3`0<3PT04Q@?00h@2`0B50l02P`700d?
2P0400h@2`0600d?2P0<3PT03Q0;00`>2@0>40/051HA0P0E5a803@0@4Pd02`d800/=200>40/030h9
00d?2P0?4@`061XE01`N6@0;3@P03a4<01DG4P0>40/00`0=3`X0500<3PT051HA00h@2`051`8051HA
00X<1`0H6QD04Q@?010B3@0?4@`03Q0;010B3@0=3`X020X500X<1`0=3`X0418=00lA300>40/03@l:
0P0<3PT0=@0>40/04A<>010B3@0C5A00004000h@2`072@@01@L200`>2@0G6A@03Q0;00/=200=3`X0
2@/600`>2@0=3`X0418=00`>2@0=3`X051HA00h@2`0=3`X03Q0;010B3@0>40/03@l:010B3@082@@0
51D@01DF4@0=3PT020T4014B3@0=3PT0414<00l@2`0=3PT0414<00l@2`0E5A<01PH4030`;P10@3h0
30`:01@D4P0=3@/03Ph<0000000D5180410>010A300;30L03@h800803a0;02@03Pl;00h>300>3P`0
20P70000000N7Qh08B4Q00/:200B3Pd02`L600/;2@0D51H030hA01@I700>4aH02@l@01PL6`0D5QD0
7R0L018D3`0?4@h030h;00/=2P0>40d04A<@010B3`0>40d02`d:018D4@0E5a@03@l<00X<2@0=3`X0
418=00`>2@0@4Pd300d?2P0<00`>2@0>40/030h900d?2P0A4`h03Q0=00lA3P0<3P/0418?01<E4P0A
4a003Q0=0P0<3P/02@0>40d03@l<00/=2P0;2`T020P600d=2`0:2PP010@200H61002010@3P0800l?
3@0>3P`04A4?01DF4`0D5Q<04A<@00d?300<3P/2010B3`0[00lA3P0@4Pl03@l<00/=2P0>40d0418?
01TK600B51404A<@024S80000@003a4>00`>2`0=3``03Q0=010B3`0D5Q<04a@E00X;3`0<30h061DF
01`F5P0G4Pl04`l<02`]:00320@04AhJ04UNF@2ldLd02a@A00@60`0E5a@01@L400/=2P0C5A803a4>
00h@3@0<3P/03Q0=00lA3P0>40d04A8=010A300200h?2P0N014B3@0D5A003a0;01@E400C50l03a0;
014B3@0B4`h0004000L9100?4@h061XI010B4@0K71h04Q@C010B3`0?4P`04A@;018F200B5PL02`h7
00/=200A4`h04Q@?00lA300A4`h02`d800d?2P0>40/03a4<0P0A4`h00`0@4Pd03a4<010B3@02018D
3`03010B3@0?4@`0418=00<04A<>00L0418=018D4@0D5Q<06A/H01PJ5`0B514051HC00803a4>0P0C
5A801P0D5Q<06adJ010B3@0D5Q405aTD01TK5P805aTD0P0D5Q40100A4`h04Q@?018D3`0?4@`601@I
5@804QLC00D04aPD01@I5@0D6AD051TE01HH5@0201DG500H01HH5@0G6AH05aTF01DG500F61D06Q`I
01TK600J71T07B8N03Xo>`0B61@07bDQ01TR7@0@6A@051hH01HQ6`0L9b404QhG01/X8@0S<2T05b<L
01XU7`0K9R006RHP0P0M:R<0200M:b@062LP01HU7P0O;bL06b`T01`]9@0O<2P06b`T0P0M;RH01@0L
;BD07BhV01l`:00M;RH072dU00807BhV00<06R/S01X/9@0K;RX00`0J;BT01`0K;RX09CPd010S7`0R
=C405BPT01ha;@0L;b/00P0Q=C<01`0T>3H083@b01hb<00/@3h09SXh02<g=@0P=3800P0S=cD01`0Q
=C<07S@a02]1?P0R=cP05R/`03=8C@0I;C@00P0Z?TD0>@0Y?T80:Ci102To?@0Z@3d093Le020c<@0X
>cT0;d90024d<P10Ddl0J7]g04MJEP0hBdD0=4M102Pk=00R=c0093dj02Q1@P0W?cl0;dM902e5A`0a
BD/0<4Q:03=<C@0cCDh0<Ta=03=<C@0dC4h0=4U<03aAE00hCE00<DI903Y?DP0lDE@0;dA705aaM00K
<3<0;T=6041EF00mEEL0=DeA03YCEP15Geh0?eQE03mHD`0hDD/0:D0j03aAC@0jCTd0=TY;0395BP0n
DED0=d]803Y?BP0mDTd0=DY502m4?@0203=8@@0Q03E:@@0dBD00<DLk02m5>@0`ASX0<TDo03Y=A`0i
C4H0<D@n0313?@0dAd407S4[02Pk=@0[?SP0>Te703A7@@0fBD<0=4M103M:A00W>S@0A5M@04EFCP0_
@3P0<D8i0351=`0b@SP0=4@i03=0=P0b?cH0=D8j03Q7@01FIEl0>DQ30080>4Q701P0>dY=03]=D@17
FEh0CUmV04UJH@15EUd0?TmG03U:D@0jC4l0=DQ602i1?@0cASl0?e=:041CC@0jCDT0>Da:03U;B`11
DU00<d8m045@B`0jBD@0>dY501/Z9@0S<Rd202dl=`0902hm>00H9b803ahI02hi=00S;2L082TT02D^
:@0O:2<072DP00<082TT02l08BXU028[9P0S;BP0:3<_01l[9`0Q;BT03a/G01PT800R;BT05b0M02`e
<P17D4d08bTW018H5P0T:RP05QlL01`U8P0F7a`07R@R020V900N928082@S01lS8P0N81l06Q`K01TK
6P0H6QP051D@01XK5P0G61<05ADC01`L6P0G5aD071`L014A4P0K6ad05aHK01XI7P0C4aD06AXL01TK
6P0;3@`05aTH020R8@0B51<08B<R01/M700201DG5P0:01LI600I6aX061PF01@D4P0F5Q@061PF01LG
5@0I6AL04a<A018B4080410>00@04Q8@01<D3`0?40/04Q<=0P0B4`h0100C51005ADC010@3P0A4A02
018B4P804A4A00d03`l?010@400C4a<03Ph>00`<300@41003Ph>00P8200>3Ph02`/;00l?3`092@T0
3`d>008040h?01d03P`=00l=3P0@3Pl03`d>01`J6`0O7Ah04@l@00h<3@0F51L04Q0F00P62`0E4aP0
4Q0E00h<3`0:20/040hA00/92P0=2``02@L800d;30071@H0>3Hg051>C`0?3@h03P`=028P8@0=2``0
2PP900P61`0200`:2`0>00d;3013@T80<30`00410@0>3Ph00@410000000P820030`<010@400[:b/0
7alO018B4P081`P200l:3P0500h93@0<1`/03PT=00l:3P0=20`00`0?2@d01`0@2Ph02PL900d=3@0N
7Qh0f=KG08:0P@0E3a400P0?1PT01@0A1@T04`@901<42@0B1@T04@P;00803PP:00D03@L900h82P0?
2@/030H800d72@0200h82P803@L901h030H:01/F6P0L5a/040X>01HA5@0B3A0071HJ00X52@0e;c<0
50hB01D@500E3a<081XL00@0001@BT`0H5YL014;3@25Oh408Q`N00l92`090`D030H800l92`0@2P`0
3@8600l4200>0`L03@8600l4200B1`/200h31`0401052@0A1PX040D900d21QCooooo000Kooooo`04
00d?2P0>40/03Q0;00h@2`803a4<00@04Q@?00lA300=3`X030h90P0>40/600lA300601`N6@0=3`/0
3a4<010B3@0?4@`02`d80P0@4Pd200lA30803Q0;00T06A/F05YLE`0C5A007AlJ01DG4P0;3@P03a4<
014C3P0@4Pd00P0>40/0100?4@`030h900h@2`0?4@`2010B3@0500lA300>40/030h900h@2`0C5A00
0P0D5Q4200h@2`0:00lA300@4Pd0418=014C3P0=3`X05aTD024S7P0>40/02P`7010B3@803Q0;00d0
3@l:00`>2@0<3PT020X601HH4`0<3PX02`d800h@2`0@4Pd030h9014C3P0B50l0418=00803@l:0P0?
4@`01@0>40/03a4<00lA300>40/03@l:008030h900/03@l:00h@2`0>40/030h9014C3P0?4@`02P`7
01TK5P0:30L030h900/=200200h@2`0K00/=200?4@`020X500lA300<3PT04Q@?024S7P0J71L04Q@?
01<E400A4`h03@l:00/=200>40/03Pl:01HG4P0I6QD05QLB00d>2@0>3`X03a0;014B3@0?40/030d8
00l@2`0=3PT03Ph<00803`l=02<02PX800`<2P0:2PP04A4?00d=2`0H61H0?Cdk00d=2`0F5a803a0;
00d>2@0@4@`03a0;00l?300E5A<04Q8@018B4@0h>3P05QHF00h>3P0H5aD040`<01dK600L71X071`N
00hB500?51L04aTL00X@4@0A5aD03Q8A024S7`0F61<03a4>00h@3@0200d?300K00h@3@0?4@h0418?
01@F4`0H6QL04aDB00`>2`0>40d03Q0;00d?2P0?4@`02`d8010B3@0<3PT03@l:00/=200A4`h03@l:
01<E400>40/03Q0=00lA3P0<3P/03Q0=014C400?4@h03Q0=008030h;01D03a4>00h@3@0<3P/02`/9
00d=2`0C4a404Q8@010@3P0C4a403Ph<014A3`0B4Q00410>014A3`0@4@l0418?018D4@0?4@h030h;
00lA3P0A4a001@0?4@h02P0B51401`T7014C400c=C80GEmL01@F4`0?4@h04A<@010B3`0?4@h200h@
3@0H00`@400>4aH04aHG01@D4`0?30/03`/801<A3@092PD05QTF00dF4`0@7a`0830]014G5@0B5140
3Q0=01HH5@1WJFH0Gf5N01<E4P0?4@h030h;00lA3P0A4a00418?0P0?40/2010A3003014B3@0B4`h0
5AHA0080414<01D04a@?010A300@4@`05QPC00H8100Z;2T0=SPf00P91`0l?Cd04Q@C010B3`0>40X0
41<:018E2P0C5P/03Q4:00h@2`0D5Q405ALB010B3@0A4`h01P0?4@`2010B3@03014C3P0C5A004aD@
0080418=00L04Q@?01<E400D5Q4051HA01<E400E5a@04A<@00804Q@A00<04A<@01DG500A4a000P0C
5A82018D4@0=01@F4`0D5Q405QPC01HH4`0E5a804Q@?010B3@0C5A005aTD018D3`0G6A@06adH01DG
4P06014F4P804QLC00@04aPD01@I5@0D6AD051TE0P0F61D08@0G6AH061XG01TK600I6aP05aTF01HH
5@0H6QL05ALD01@F4`0F6aL0<3Hb018H500D6QH03aPC01hW8P0G8A/03APB01/V800U<BX07BXS01XW
800D81X06B@N01XV800M:B807BXS01d[900K:B806bXS01`/900L;2D08c@/024d:`0201`]9@0<01l`
:00P<BT07c0X020a:@0Q<RX07RlW01d^9P0N;bL07c0X01h_9`0L;RP07C0/0`0N<Bd0G`0M<2`0;d8n
07^>RP0`@cl07C0/020c;`0O<Rh083@b01hb<00P=3808cLf02Di=`0_@d408CDc028f=@0V>ST08SHd
01``;`0Q=C<09C/i02To?@0P=CH0AU]N08BIW@0bAT`0:Si402Tn@`0W?4009CXk02Hk?00W?C/0:3Xi
02@g=P0S=SD0;3lm02Hi=`0gBTL0@UEA02Xm>@0X>cD0:Sdg02`o>00bAT00:3di02a2?`0/@d80=Te<
039:BP0aBDX0;DI803==C`0cCU00;dY<031<C`0gDU@0=Ti@03=8BP0mDU@0=4U;03E:C00cB4X0DfQZ
06UnP00_A4H0;D9403]@DP0eCDh0>U9E03]EE@0oFEP0=Tm<03YCC`0kE4l0?5=>03iCD@0cAdH0?U9C
03e@D`0_@dD0=d]903U>BP0jCT/0<TM203=8@P0jCdT0<TM00356?@0`AC`0<4Dk02m4>P0^@cX0<4<m
0354?P0bACl0<dI00080<TDo00@0LHAn0313?@0W>S@0?E1:0P0hBdD01@0dB3l0=TU202Xn=00mDDL0
?4e40080<T<h02@0;cle0392=P0a@CD0;S``02ll<@0_?3@0;3/d03e<AP0b@C`0<D4n03E5A@0gAdL0
=TQ:03i@E014EE/0@UAI049CF@0oD5H0?e5E03i@D@0_@T00;d8n03M:A00kCdL0?U5;03U<A`0fBDH0
=4I502`m>P0hAd80=dI102ln>@0gAT40<3lj02@c;P0^?CP202dl=`08028a;00oCTT0JWIa02lh<`0P
:B@08b`W01dV8@0O:2<201dV8@0F01lX8`0P:B@08R/V02@^:@0X<bl07BTU03Q4@00O:RH09C4]01dX
900P:BH072DR01hV8`0O9B<06b4O01`R800G81d06B8O01XS800X;R`08RPV01XP7P806AdL0P0M7ah0
6P0K7A`06A/J01hN700G61@07alL02HV900M7A/05aLF01TI6P0O7b006a/M01/J7`0E51T092@V01HG
6@0c=C@06Q`K01DG5P0F61L06A/J02@V9@0P8R405aTH01TK6P0M7ah05aTH0P0I6AL0100F5Q@04a<A
01@D4P0G5aD201@D4P804Q8@00<051@B01@E400A4Pd00`0A4Pd0100A4Ph04A4?014A3`0D51<201HF
5P0A01DE5@0D51@06QXJ00h>3P0J6QX03@d=00l?3`0B4Q80410@00T92@0A4A404a<C01XJ6P0D51@0
40h?01<A4P0A3a000P0=2``06P0@3Pl05aDF01@B4`0B414030X;01<A4P0M6ah0K6Y`014?500:20d0
4Q0E01@B5@0=2`h040hA00X82@0=2``030X;01<A4P0>30d03@/<01/I6P0c<C805A<D00T8200>30d0
3@/<0`0?3@h03P0>30d040l?018B4P0?3`l03@d=00l?3`0=3@d02`/;00T92@0=3@d04a<C00P8200@
41005aDG0P0>2@d01@0=20`030L;00d8300?2Ph03PT=00@03`T=00H03`/>00<30`0;2PX071TJ01PD
5@0A2`d200l62@0501462P0D1P/050L;01@8300A20/00P0>20X01@0=1`T03PP:00l92`0<1PP03@L9
00803PP:0P0=1`T0500=1@X040P=00h72`0>1P/05@dB00d62P0;0`P02`@801L?500A2Ph02`D801PA
5@080P@03`X;02PR900Z92H040X<01HA4P0B30h03`T;0P0C3@l00`0=1`T02`D700d21P0300h31`<0
3`@800D03@8601052@0C20`04@H:00X00`0Dooooo`006oooool0200K7AP05aTD014C3P0>40/03@l:
00h@2`0@4Pd03a4<0`0>40/01`0?4@`0418=010B3@0A4`h03a4<00d?2P0A4`h00P0B50l01@0J71L0
LgE`01XL5`0J71L0418=00803a4<0P0>40/01`0=3`X0<C<^0;Rj]@0U9b802@/600L9100>40/00P08
2PD0200@4Pd03@l:010B3@0:30L04aD@010B3@0>40/03@l:0P0<3PT00`0?4@`030h900d?2P0200lA
30803Q0;00T04A<>010B3@0<3PT030h900T;1P031@0020X501DG4P0A4`h00P0:30L0200>40/03@l:
00d?2P0=3`X030h900lA300:30L07R0K0P0B50l01`092`H0418=00/=200=3`X0418=00/=200<3PT0
0P0A4`h0100>40/030h900`>2@0=3`X200`>2@0<00d?2P0<3PT02`d800`>2@0=3`X05aTD00/=2P0?
4@`02@/600X<1`0;3@P030h90P0?4@`0100>40/0418=00lA300B50l200d?2P0301<E400=3`X03@l:
00803Q0;00/030h900h@2`0B50l04A8=00H70P082@@04A8=00L80`0B4`h030d8010A3002014B3@80
5QLB02/0410>00h>300@40h0410>00d=2`0:2PP01`L5018B400<30X08B4O01<C4@0:2`H04Q<=01LH
4`0R8ah07AhI00d>2P0=3@/03`l=01TI600h>3P03@d=01PH60020P00;b/Z00/91P0:2PP05aPJ02DY
:`0=4QD0:S8d02<Z:`0=4a40310?00dA300620<03a4>014C400@4Pl03Q0=00d?300>40d05ALD0080
7R0M00l04A<@00d?300E5a@03Q0;00T;1P0?4@`04Q@?00h@2`0<3PT061XE00X<1`0A4`h03Q0;01PJ
5@092`H00P0>40d06@0;3@X030h;00h@3@0;3@X03Q0=00`>2`0=3``0418?00lA3P0>40d03`l=01HF
500=3@/020P600`<2P0;2`T03@d;018B400D5180410>00l?3@0<3@/02`d:00h@3@0@4Pl00P0?4@h0
3@0@4Pl03a4>00h@3@0A4a004aDB010B3`0G6AH00`D2010B3`0L7Q/0=cTf01lQ7P0@4Pl00P0=3``0
4@0?4@h04A<@010B3`0730/03ADG01dS8`0M81l05aLE01DD400>3@T05aPC00`>2`0;4@l01a4@010L
6`0;3`h02@/8008020X700H0=cTf038d<@0B5140418?00lA3P0@4Pl2014C400500h?2P0?40/04Q<>
018C3P0@4@`00P0=3PT01@0:2`H030d8010A300@4@`04A8=00802`d801T0=3Ha04U;B00E5a@02P`9
00lA3P0>40d03@l:00hA2P0@4`X03a89018E3P0@4Pd051HA01<E400?4@`0418=01<E400B50l0418=
00lA300>40/03@l:010B3@0?4@`0418=00804Q@?00D0418=014C3P0C5A004aD@01@F4@0201<E4008
010B3`0B51406adJ01dO700D5Q<03Q0=00/=2P0B5142014C408051HC00`04aD@018D3`0A4`h04Q@?
01<E400D5Q404aD@01HH4`0E5a806A/F01`N6@0J71L601<H50804QLC00H04aPD01@I5@0D6AD051TE
01<E4P0E5a@201LI5P0501@F4`0C5A805QPE01LI5P0J71T00P0H6QL06P0K81`03Q@@01PN6P0G7AT0
5b0K020Y900J91l04ahH02Ha:`0kAd0082dV01PU7P0I9Al062<M01TV7`0O;2D07BXS01`[900N;BH0
8C0Y01l`:00F9al07RlW020d:`0N<2P07c0X0P0P<BT02P0O<2P08C8Z02@e;@0R<b/07c0X020a:@0R
<b/08C8Z020b;@0O<Rh3020c;`0L01lb;P0S=S80Sj:N024d<00S=S806bhZ02<f<P0U>CP083@c028f
=@0W>cX09CTh02<g=P0eBDP09SXi020d<`0X?3/09CTh024e=00T>SP0;D=102Hk?00U>Sd0A5UL024f
>@0Y?T<0:Ci102Pm?`809S/l04T09S`j02Xn?@0_@D408C<c02Xm>`0`@d409CPf03=6@P0^@Cd0<TE0
02Hi<`0^@C/0<dI003mBC00gC4L0B5aJ06UmN`1JL6h0<TY:031:B`0eD580<e5C031=D@0bCe<0>UII
04=KG@12EeP0AU]L02]0@@0eBT/0AEYK0:g2``1:Gf00@EIG03I;C00eBT/0?5AD02U1@`1LMWH0MHn>
05A]JP0iDTh0=e1<02]1?P0oE580<DE403Q<C@12EEP0@5AE03=7AP0kCdd0@5AB03U>B@0bAd80<dQ3
0315?P0^@c`0;d@k0315?00/@CP0:Slf02m2?00X>cD0:Sdg03=6@00bACl0;T4k03E8@P0/?cT0@EA>
03Q;A@0fBD<0=d]20080<DDj0140;d<h02i2=`0W>Bd0<T@h03A6>@0_?c80<d<f02m0<@0Y=bP0;3X]
03I3>`0fACh0<d8l03Q7@P0`@3d0<D4o03Q8B00203M9B`0303U;C`0oDED0@UAH0080@59D0140>4Y9
02e0?P0bAD40>Da703a?B@0oDT`0>di903M:AP0cAT@0<d@o06AcKP17EU40<T4l02Lf<@0`?cX09SD`
02dl=`0202Dd;`0801h]:00S<Rd0?DU402H_:P0R:bH09c0[028[9P0O:2<2024Z9@0D028[9P0T;BP0
9RlZ02Pa;00Y=3007BTU03<o>`0R;BT09S4]01`W8`0@6AH05AhK01TO7@0N92804aTG01HL6P0G81d0
5QlL01`U8P0]<c4202<Y9`806alN01H07R0O01/M700H6QT051HE01/K6@0B4Q007alM02TY9`0L71`0
6a/K01LG6@0I6A/06QXL020O900H5a`07AdO01HH5`0Y:bX07AlN01XL6`0H6QT04A<B0P0F61L02P0H
6QT06A/J01DG5P0A4a8051@B01HF500B4Q004A4?01@D4P0B4Q0501@D4P8051D@00P04Q<>014B3@0A
4Pd0414=00h>300@40h04Q8A01<C4`<051@D0P0C4a<01P0a<C404A4A00T92@051@D05aLG00/;2`80
410@01l05ADE00`<300B41404Q0A014?400?3@h03P`=00l=3P0B41403@/<010>3`0B41403P`=00l=
400;20h06QPM01lM8P071@X05aDH02`Z;@18ATT0:bTZ01`J6`0=2``05Q@E00h<3@0200400@0001hL
7@040P<00@0000802`T:00d03P`=00d;300?3@h040h?00h=3@0:2PX020P800T92@0:2PX020P800h>
3P0C4a<00`<3008020P800L0000000/82P0<1`/03@P<00/62P0:1@T030L;00803`X>0`0>2@d01`0=
20`040h@00T92@0B41401`<4018>3`0=1`T00P0@1`X01@0B1`/050P<01@8300D2@d04@P;00803PP:
00D03@L900h82P0?2@/030H800d72@0200h82P803@L901804PT>00X11P0?1P/04@P=00`3200A20d0
3`H;00d42@0?1P/030<800/21`0F3A802@<500@0000=1`T04@/=00`7200S7Al200`6200700l92`0=
1`T02`D7018<3P0>0`L03@8600h31`0201052@<03P<700@040D901462P0@1@T03@865?ooool001_o
oooo00L06adH01PJ5@0E5a804aD@010B3@0?4@`03Q0;00803a4<0P0@4Pd03P0?4@`0418=010B3@0B
50l0418=00/=200A4`h03@l:01/M600f>3<0gn7L01`N6@0620<03a4<0P0>40/200d?2P0D00`>2@0:
30L08B<N00/=200H6QD01PP3010B3@0U9b8020X500X<1`0;3@P051HA00T;1P0B50l03Q0;00`>2@0=
3`X03a4<014C3P0>40/200`>2@0300lA300@4Pd03a4<00803a4<00/0418=014C3P0?4@`03Q0;01HH
4`0D5Q400`D10084000>40/04Q@?00`>2@0300d?2P0700h@2`0B50l01PP300lA300<3PT01PP300<5
000300d?2P05018D3`0>40/03@l:00d?2P0;3@P0100:30L03@0;3@P03@l:00lA300=3`X02`d800`>
2@0=3`X06Q`G00d?2P072@@051HA00`>2@0=3`X00`0>40/02@0?4@`03Q0;010B3@0?4@`03@l:00/=
20092`H020X500/=200200`>2@0;00/=200=3`X04aD@00h?2P0;30L03@h9010A300720<051D@00d>
2@0A4Pd00P0@4@`201@E400l01HG4P0=3PT03@h900h?2P0;30L03a0;00d>2@0>3`X00@800001000@
4@`03@h9014B300E5Q00824L01/L5`0<30T0410>01@D4P13@d804a<C00@4100D51@07AdK09VEU00O
71X03Ph<01PI6`0V:R`00`/=020X:P0W<3002a4?01@H5`0;40/02Pl900P:1`0=3``03Q0=00d?300>
40d04Q@A014C400F61D061XG00lA3P0<3P/04Q@A00d?2P0620<0418=020R7@0B50l05ALB02T[9P0<
3PT0418=00`>2@0L7QT020X50P0@4Pl01`0<3P/03@l<00h@3@0<3P/03a4>00d?300>40d00P0A4a00
2P0?4@h0:2PV034a;`0J6QP03@d;01<C4@0=3@/03`l=018B400A4@l200l?3@08010A3P0>40d03@l<
00lA3P0@4Pl03a4>00h@3@0?4@h2014C400400lA3P0>40d04aDB01XL6@803@l<00d04Q@A00<50P0<
3P/02P`900T;200=3``0418?00h@3@0H7ah08R`]01LP7`062`X02@/80080414<01407AhI00lA3P0<
4Q0000D400T@40072`X03a4>01hP7@0=3``020X700/=2P0>40d03a4>014C400?4@h03Q0=010B3`02
00l@2`80414<0P0?40/00`0B4`h051D@014B3@0200d>2@0800/<1`0E5a804Q@?00d?2P0F61<03@l:
00h@2`0?4@`200h@2`8041<<00T03A09010B3@0=3`X0418=014C3P0>40/04A<>018D3`0A4`h00P0@
4Pd01@0?4@`03Q0;00lA300>40/03a4<00804A<>00@03a4<014C3P0A4`h04Q@?0P0A4`h0300?4@`0
61XG00lA3P0>40d0418?014C400E5a@02P`9018D4@0A4a00418?01DG50804Q@A00<04aDB01@F4`0F
61D00P0G6AH00`0D5Q<04aDB01HH5@0201HH5@0301TK600E6QH05AXF00@05AXF0P0B5a<01P0C61@0
51TE01@I5@0D6AD04aPD01@I5@805AXF00D04QLC014F4P0D6AD05AXF01PM6@0201HK5`0@01/P700L
8R0061hL018H5P0@6AH03aPE01LQ7@0>6AD05R4M01/V8P0<61@04QhJ01XV8P0G8al06BDQ01l/:080
72/V00L08c<]024b;00S=2h08cD_01HY8`0J;BL093La00807c8/0P0M<2X0100O<R`08cH`024d;P0N
<B/301lb;00301lb;@0O<Rh07c8^00<07c8^00T09STe0313?`0P<bl08cHb00hQ7@0R=C40:3`k02@h
=`0S=cH00P0T>3L00`0/@3l0?U9A02m3@P0302Di>00803=7AP0J<2h09C/i02a2@00O=3D08cPi03I;
C00[@4<202]0@@0802Xo@00Y?cd0:3hl02Hj>@0^@T409CTh02a0?`0aAD@202/o?@8093Td01h07c@_
0315?`0hBdD0:chh02Tl=P0bAd80BUmJ03eCD00Q>CT0<4Y;039=C`0`CU00;da@035@E@0gE5P0<TY<
03U>C`0hCDh09S/l049GF00eBT/0>e1A03=8B@0]@T<0@UMH03Y?D00kDe<0=4a<04EOGP18HV420319
AP0b03iGE01<HV00=4U702/o?P1PM7D0LXJ703eADP0kCdh0>dm=03eAC`0hC4X0<TM203=8@`0_A3h0
;D8k02m4?@0`AC`0:d0g02Ll<`0_@S`0;D0j02m2?00bACl0;d8l02/n>00aA3h0?4m905=VH00W>S@0
=dY403mCBP0eBCd0=d/o03I:?P0cAc/09cT]0312=00cACH0;Sl_03A5=@0`@C00:SPW02hl;@0f@c/0
=4<n049AC00fAD009SHc03A4@P0gAdH203I8B00M03U;C@0nD580@UAF045CD`0mCdl0<TE303=6@P0g
BTH0=DQ403U<B00lCd/0>4]703A7@`0_@Sh09SLc03e<A`0a@3/0:3Lb02He<00R<B`0:3Lb02Lf<@0Z
>C@0<3lj03=2?@0/>cH0930[01dV8@0S;2L00P0U;RT07@0V;bX092dX02</9`0T;BP09BhY02L`:`0Y
<Rd0:SD_020[9@0M:28062<M01XU7`0Q:RD09B/W01lU8@0P9R80AT]703a1?@0K8Ad08BXW01XS800I
8Ql09bd[024W9@0`=S@07R8Q01`P7`0J71/05aTH00805QPG00@05aTH01XL6`0K7A`061XI0P0H6A/0
3P0;30h06a`N02X[;@0S92H05aPJ01PI6`0E5aH03@l>018D4`0K7A`07b4P00P:2@0F61L04aDD0P0J
71/00`0E5aH06adL01HF500201DE4`0301XJ600I6AL020P600804a<A0P0D51800`0C4a404a@?01@E
4002014B3@0B01<D3`0C4a003`l=014A3`0A4A004Q8B01@D500E5AD05QHF01<C4`0];Bd0DU9B01`L
700B4Q805ADE02/[:`0J6QX07AdM0P0I6AT01P0?3`l0518C014?400A3a004Q0A010>3`<03P`=0P0D
4Q<03P0;2@X020H9018?5@0100@02`T>01LE6P0L6Qd04a4D01/I700;2@X01`D600@20`0B41402PP9
0P0H5QL06`02004040h?01@B4`0;2@X04Q0A014?40091`P02PP900d;300<2P/03P`=01DC500F51D0
2@L800X82@0?3@h02`T:00T7200B41404a4B00`:2`0;20X03PP<00l93@0=1`/030H:00d8300300l:
3P0900d:3@0;2@`02`T<02<Q8`0C4A8020@501@@4@0H51D02@<5008040L:0P0A1PX201872`080148
2`0>20X03PP:00d72@0>20X03`T;00`6200=1`T200h82P803@L901D040L:00`11@0@1@T03P<700T0
0P0=0PH05``@00h31`0@1@T02`0400l4200;0`D06A<E00d72@06008050h@010:300400003`T;00X4
1P0;1@L00P0<1PP0100A2`d03`@800h31`0?10P201872`0700d21P0>0`L040D901052@0>0`L03`@8
01052@0Dooooo`006oooool500lA300300h@2`0B50l03@l:008051HA00<03Q0;01<E400@4Pd00P0?
4@`200h@2`09010B3@0A4`h04A<?01<E400k?CP04aD@018D3`0?4@`04Q@?00802`d800l0418=00T;
1P0A4`h0418=00h@30092`L05QPC01<E400j?3L061XE00h@2`0;3@P04Q@?00/=200>40/00P0<3PT0
100?4@`04Q@?01@F4@0=3`X400h@2`0C00lA300>40/04A<>00d?2P0o@C`051HA00/=200>40/03@l:
00d>2P0A4`h03Q0;00/=200@4Pd04A<>010B3@0B50l04aD@00h@2`02010B3@0400h@2`0?4@`051HA
00lA308030h900T04A<>00h@2`0<3PT03Q0;010B3@092`H03@l:00T;1P0B50l00`0=3`X200`>2@07
01<E400=3`X04A<>00T;1`0<3PT05QPC010B3@0200lA300=00d?2P0D5Q406Q`G010B3@0>40/030h9
014C3P0B50l03@l:00h@2`0;3@P03@l:00h@2`0200/=200=00lA300720<05AHA03Df<@0C50l030d8
00d>2@0@4@`02P/8014B3@0<3@P03Pl:00d>2@0200l@2P0400h?2P0=3PP0414<00l@2P803Pl:0280
5QLA00d>200@4@/03@h9014B300=3PT0414<00d>2@0:2`L05QHD010@3P0L71/05ADE04=3@`0[:b/0
=SHd04]:B00@40d051HC00h?4@0C6AX02a<E00TB500F7al01Pl<01<I5`0<4@`051TC01@F4`0];b`0
51HC01DG500?4@h051HC0P0;3@X300h@3@08010B3`0@4Pd02@/600d?2P0H6QD030h900lA300Q8ah2
00lA300600`>2@0E5a802P`700h@3@0@4Pl03a4>0P0>40d0400=3``0418?00lA3P0?4@h03Q0=010B
3`0B51405aLE01`L6P0G5aD020P701TI5`0>3P`0410>014A3`0@40h200h>300D018C4@0B51403Q0=
00d?300A4a00418?00h@3@0@4Pl04Q@A00h@3@0;3@X03@l<00h@3@0<3P/03@l<00lA3P0;3@X04aDB
00h@3@0?4@h4010B3`0>00`C4P0:5QH02a@C00XB3`0?5100418=00lA300=3PT03@l<01TK6P083@h0
5a`M01<F5@0A4a0300h@3@08018D4@0:30T04aDB018D4@0<3P/0418?00lA3P0>3`X200`=200O00h?
2P0@4@`04a@?018C3P0D5A004A8=00h?2P0@4@`04A8=010B3@0C5A004A<>018E3`0>40X041<=014C
3@0@4P`03a4<00lA2`0>4@/03@l:00h@2`0=3`X03Q0;00lA300>40/0418=014C3P0@4Pd03a4<00h@
2`0200d?2P08010B3@0?4@`0418=018D3`0A4`h030h900lA300A4`h200h@2`0?014C3P0?4@`04aDB
014C400C5A805ALD01<E4P0B51402`d:01TK600;3@X04aDB01@F4`0E5a@04aDB00804Q@A00<051HC
018D4@0?4@h00P0D5Q<0100F61D04Q@A018D4@0H6QL6018G4`08014F4P0B5a<051TE01@I5@0C61@0
4QLC01HK5`0D6AD201DK5`1B01@I5@0F6aL051XF01XP700C61@04QPD00hD400@5A405adK01DK6@0H
7Q`06b@Q01DN6`0H8Qh05b8N01`W8`0J9R805R8N01TU8@0K:2@07R/W01TW8P0P;RX072/V02@d;P0P
<2/07c0Z03=5?`1=H5X093Pa01@X8P0P=2h08C@^02<f<00Q=2h072lY01ha:`0P<bd08SD_01lb;00N
<B/09CPb01d`:P0R=C008SDa01lb;P0M<2`0:chj04=FDP0S=S8062/W02Dh=00[?SX07S4]02@g=00T
>3L09SXj02/o?`0X?3`08cLg028f=P0/@4009SXj02Pl?00O<c<07C4a03eAD@0hCDd08SLg028h=P0^
A4<0:T0o02]1?`0_AD@0;49102a1@@0aAdD0IWaj02i3@`0V>SX0:Shn02Lk>`809c/j02`0:Shm0396
A00Y?C/0=4Q503Y?BP0aAT40;D8k03I7?`0fB400<4<m02m4?`0]@Sh0<da902e5A@0`C4h0;Ta>02Y9
C00ZBTh0<E1C039:B`0jCdl0>Di>03mDE01HKFd0<dU803U?CP0hCTd0>4e=0397A`0iCdh0=4a;03aD
D`0iDe40=e5?03Q@C`0oEeH0>51?03M=C00kD500<DE503mCD`19GEd0>Ti=041DD`80=d]90380=DU7
03M;B00lDDd0<4E002m4?P0^@c`0;T<k02m4?00`ACd0<4<m03=6@00dAd40<D@n02e0>P0Z?CL0<dI0
04QKE@1FJF<0=4M103E8@P0_@cX0<dLl041DB00jCT80=DTm02Xl;P0^@380=4Hf02`m;@0b@c<0<44_
02dk:P0b@340=D8k03I5@00hAd80>DQ302hn>`0a@Cl0=DE30395@P0fB4L0?4i=03e@C`0oDDl0>di;
03I9AP0gBTH0>Te903U<B080>4]700d0>Da803Q;A`0eB4@0?4m;03M8A00X=c80;3/f02/j=@0W=S40
7bhY04YIE01;FUD0>TU400809C@_00H0:cXe02Pc;P0T;BP09RlZ020Y900O:2<402D^:@8092dX03L0
9RlZ01dX8P0P:bD08B/U02H`:`0P:RD072<O01dS7`0Q9b<07b@P02<X900O9200:2hZ03a2@00Z<c00
6b@Q01lU8`0K8Al08bTW01`P7`0I7A`06A/J01LI600F61L071hM020Q8P0V9bP07AhQ01<D5`0I6Qd0
6Q/N01lP8P0J6ad07AhP01PI6`0J6ad061TK01PJ6@0L7Qd0828Q01HH5`0G6AP061XI01HH5`0D5QD0
6Q`K01TK6P0F61L07b4P01PH5P0D51806a/I02/[:@0];B/04Q8@00804a<A00h04Q8@014A3`0B4Q00
4Q<>01@E400C50h04Q<>01<D3`0C4a00410>01<C4@0C4a804Q8B01@D50805ADE00l03`l?00`<300N
7Qh030`<00h>3P0?3`l07AdM018B4P0>3Ph04a<C018B4P0=3@d04Q0A01<A4P0G5AH00P0@3Pl02@0<
2P/040h?01<A4P0B41404@l@00d;300:20/040hD01<A5P0200h<4@0G01<A500A3a80518E01hL7@0G
5AH03P`=018@4@0>30d01P@500l=3P0A3a002PP901PF5`0I5aP0NGMh02<Q8P0=2``05A<D00T7200@
3Pl03`d>00`:2`0:20T00`0<2P/01P0>30d02`X:00d;300:2@T020H7014<3`804@X>014040T>00l9
3@0?2Ph04@`@01<>4P091@T03@/>00P72P0@3a403@/=00P51P0D41402PD700T51P0@2P`04@P;00l6
2@0300h4200500h41`0>20X03PP:00h82P0=1`T00P0>20X0600?2@/03PP:00`6200@2P`03`T;00`6
200A1PX04PL;01462P0@1@T03P<701472P0>0`L03@@601062@0@1@T050T=00l52@0=10L040X<014;
3@0;1@L03PP:018<3P803@L900L03`T;010:300;1PL02`D701052@0?10P040D900804@H:00L03`@8
01052@0A1PX040D900h31`0?10P04PL;01Cooooo000Kooooo`08010B3@0>40/030h900`>2@0>40/0
418=00/=200A4`h2010B3@0L014C3P0;3@P01PP300h@2`0B50l04aD@00h@2`051`8010H101@F4@0A
4`h0418=00`>2@0>40/06Q`G010B3@0>40/05ALB0043000S9B003Q0;01hP6`1OHE`0<cD`00X<1`0;
3@P030h900h@2`802P`700D03Q0;00d?2P0=3`X03@l:00h@2`0400lA3005018D3`0A4`h03a4<00lA
300A4`h00P0?4@`040010`008B<N00`>2@0A4`h030h900/=200<3PT03Q0;00`>2@0;3@P0418=014C
3P0;3@P03@l:00h@2`0;3@P200d?2P0700/=200>40/03Q0;00d?2P0;3@P030h9014C3P0200h@2`0G
00X<1`0?4@`03@l:01LI500?4@`06Q`G00D70`0G6A@061XE00H810082PD03@l:00D70P0E5a8061XE
010B3@000@002P`700`>2@0@4Pd030h900lA300G6A@00P0?4@`01@0=3`X04Q@?01@F4@0>40/030h9
00804aD@00H04Q@?00d?2P0:30L02P`701/L5`051P4201TJ5@08018C3P0:2`H04A8=0042000720@0
414<034b;@0=3PT300l@2P0500`=1`0=3PP0414;010A2`0>3`T00P0<3@L02`0>3`T0414;00T:100>
3`X04a@?018C3P0@4@d051@B00l?3@0@40l03`l?00805aLG01<05aLE00l>300?3``04A<@00lC500H
7b005QhP00hH6@0C7Ad02a@A01@J600D6A@041D?00T;200M7a`02@/800h@3@0@4Pl09RPU00803@l<
00@03Q0=00lA3P0?4@h03a4>0`0=3`X00`0>40/03a4<00lA300200d?2P0500`>2@0=3`X0418=018D
3`0C5A800P0=3``03`0?4@h03Q0=00`>2`0@4Pl03Q0=018D4@0A4a003Q0=00lA3P092@L05QHD02h^
;00C4a406QXH00X:200200h>300700l?3@0>3P`03Ph<00l@3@0A4a003Q0=00`>2`02010B3`0400lA
3P0@4Pl03a4>00h@3@<030h;01P03@l<00lA3P0@4Pl0418?00lA3P0=3``03Q0=010B3`0?4@h03@l<
00lA3P0?5A@031HG00`E500:4Pl02Q0<00hC3@0A4`h03a4<00@60`0@4A404Q<E02/_<@0?4A02018D
4@0>00d?300<3P/04A<@01@F4`0E5a@02`d:00`>2`031@804A<@01HG4P0D5A00414<00l@2`0@4@`2
014B3@0A010A300>3`X03@h900h?2P0A4Pd0418=00lA300>40X03A0900hA2P0?4P/03Q4:00lB2`0@
4Pd03a4<00lA3P0>40d00P0A4`h2010B3@<03a4<0P0@4Pd2014C3P09018D3`0G6A@02P`7010B3@0B
50l03Q0;01TK5P0A4`h051HA0080418=00D05aTD01@F4@0@4Pl04Q@A01<E4P0201@F4`0:01<E4P0K
7AX0:2XW00h@3@0H6QL04A<@01@F4`0C5A804Q@A014C40<0418?00H05QPE01PJ5`0F61D04Q@A01DG
500J71T601<H500@01@I5@0G71P06AhJ01TN6P0F6aL05AXF01HL600D6QH02Q0<01DK5`0?5A406b4M
01hT80001@408BLS01PN6P807B<O00H05Q`J014G5@0D6QP0624N01LP7@0E7a/201DP700601HR7P0H
92006RHR01/Y900Q<2/06BPS0P0M;2L04@0dACl0:CXd01`_:@0Q=2h0;D4k01/`:@0L<BX0>De60354
?P0N<B/08C@^02Hi<`0N<B/06RdW01`_:@0S=S009STc00809CPb00T06bhY02<f<P0H:bL07C0/028e
<@16FED083<_02@g<`0J;BT00P0R=C40100aA440:Cdl02Tm?P0X?3d302Hj>`0F018V9`0T>3T0;d=4
02Hj>`0X?3d0>4a=05AYJP0fBd`0:d4o02Lm>`0S>CH0:T0m02a2?`0V?3T0:3hl02a2@01cRHL0;D93
0355AP0_@d@0;41102Xn?@80:Cdl01T0:Shl02Tm>`0W>cT0<dQ303U>B@0W?3L0=4M10396?@0dBD80
<dQ302i4@00]AT80<D]8035<C00^C4h0;D]=02a;CP0]Bdd0=Ti>03A:B00^A480=de;03iDDP0/@T00
=Ta:0080>4i<00@0=de;03Q>C00hDDh0>U=@0P0iDe004`0oEeL0@5QH03A<C00fBd`0=DU:02m3A00c
AdH0?51?03Q<B`0dB4L0<dM603Q<B`0fBTP0<TI403I:B00`AD00;D8m02a1?00]@S/00P0^@c`0:`19
G5H0FVeW04=FD00]@3X0;T4k02/n>00fBD<0=DQ20395?`0eB480>4]503I:@@0]@CH0>Ti20355>@0`
A3P0<48f03M9>`0iBc`0=TLg02m0<00/?B`0;cd/02lm<00c@3X0<d8m03I5@00^?CP0:c/h0392?`0c
@d00<4<o03Q;A`0nDDd0?4m=03E8@`0/@3L0;D4h03U<AP0gBTH0=TU503e@C00gBTH00P0eB4@0700b
AD40?E1<03m@C00Z>C@093<^020_:P0L:bH0:3Lb03A3?P0T<bh07B`W02<b;@0X=c80:STd02Pc;P0Q
:RD08R/V01lX8`0N9b808b`W02lh<`0/=C00:C8]02Xc;P0/=C00;SLb01lZ900Q;2H2020Y900@02</
9`0O9B4082HR020V8P0O92007B8N01hS7`0S:2@09bd[01`U8P0G81d06b4O01PN700G7A/04aLF018F
5@805QPG00/05ALF01hO800Q8RH071dQ01PI7@0J6al071dQ01XK7`0I6Q`0824S01HG6@0201/L7P04
02//;P0F61L061XI01LI60805ALF00P05QPG01LI600H6QT05aTH01DG5P0F61L06A/J01PH5P805QHD
00D07AdK01`L6P0:2PP05QHD01@D4P02018B400:01<C4@0C50l03@h900h?2P0A4Pd051D@01LG500H
61H04A4?014A40@04A4A1P0?3`l05`2GUiL0?3`l01`L700820P04a<C00T92@0K6AX0F5IG04a:B`0>
30d03`d>01HD5@0B4140518C00h<3@0;2@X03@/<00d;3P050PP03`dB01HD6@0=2a002PP;008040hA
00<07A/L018@4@0=2``00P0@3Pl0200C4A801`D600d;300H5QL020H700/92P12@4402`T:0P0=2``0
1@0:20T03@/<00d;300>30d040h?00802PP900L02`T:014?400?3@h02@L8018@4@0>30d030H900<0
4PT>0P0@2Ph01`0:1@P04PdA00X82`0:2@`00`<500410`091`P00P0>2P/300l92`0601072P0A20/0
40L:00h5200A20/06A0C1P0=1`T03@080P@09R0R01/E5`0F41801@0101<>3`0E30l05``@01@93@0A
1PX03`@801D:3P0;00@00P0@1@T00`0<0@D03P<700`21@0600h82P06010:3005004050h@00@0000H
4Q@02@<51P0?10P201052@803`@80P0@1@TDooooo`006oooool0200>40/03@l:00/=200;3@P03@l:
00h@2`0=3`X06A/F0P1ADdh0100I6aH03@l:01<E400?4@`200d?2P0300lA300C5A0020X500805ALB
0P0B50l04`0C5A00EEMB07MiM00=3`X05ALB00h@2`0:30L03Q0;01TK5P1IFeH0;BlZ00<5000<3PT0
2`d800h@2`0;3@P030h9014C3P0@4Pd00P0=3`X01`0>40/03a4<00lA300?4@`0418=018D3`0A4`h0
0P0@4Pd03@0A4`h03@l:010B3@0D5Q40008000`>2@0>40/030h900/=200=3`X03Q0;00d?2P0>40/0
0P0B50l02P0<3PT02`d800/=200=3`X04Q@?014C3P0>40/04A<>010B3@0=3`X200/=200I010B3@0<
3PT030h900h@2`0F61<03@l:00P:1@0210002`d800X<200>40/00@<001DG4P0?4@`03@l:02@V8@0>
40/02`d800h@2`0<3PT05aTD00/=200B50l03Q0;00L9100200`>2@0400h@2`0<3PT03Q0;00lA3080
2`d801H07AlJ01/M600F61<04aD@014C3P0>40/05AHA00X;1P082@H04a@?00L80`0C50l061TD010A
300>3`X06Q/F04Y;AP0D5A003@h800l@2P0@4@/03@h80P0;30H0800@4@/03@h801DF400E5Q003@h8
010A2`0;30H04A8=010A300>3`X03`l<00d=2`0?3`d03Ph=010@40092@T03Ph>018B400>3P`04A8>
01DG500D61T06b8S02D_<00O:BX09c4a00hI5@094Pl01`l900X?2@0D5Q<03@l<0P0B5140100=3``0
7b4N010B3`0?4@h200h@3@8030h;01l02`d800d?2P0?4@`03a4<00d?2P0;3@P03Q0;00/=200:30L0
30h901@F4@0I6aH071hK00d?300:30T03a4>00h@3@0;3@X0418?00h@3@0E5a@05aTF00lA3P0<3P/0
4A4?02DU8`0l?3X0820N024Q7`0C4a403`l=00<03Ph<00D03`l=00l@3@0?4@h03Q0=00`>2`02014C
400900h@3@0?4@h03a4>00lA3P0=3``030h;00d?300?4@h0418?00804Q@A00`04A<@00lA3P0=3``0
3a4>00h@3@0=3``03Q0=00hD4`0=5AL031DD00/A3`0:40`200hC3@0600`>2@0I6aP09BLV03Hg>@15
ATT03Q0?100=3``08@0?4@h04A<@01<E4P0O8Ah0<C<`00P:1`0=3``0414<014B3@0@4@`03Pl:00l@
2`0D5A004A8=010A300>3`X03@h900h?2P0A4Pd04A<>00lA300=40T02`h700`?1P0>4@P030l600hA
2P0A4`h04Q@A014C4P0?4A00418?010B3@0300lA30803Q0;00L0418=01<E400D5Q4051HA01<E400A
4`h03Q0;00809BLR00@03a4<01LI500C5A005ALB0P0B50l06P0F61<051HA01<E4P0A4a00418?014C
400E5a@061XG01@F4`0P8Ql030h;01DG500@4Pl04aDB01<E500E5aH051HE014C4P0C5A@05ALF01LI
600H6QT05QPG01<E500F61L06Q`K1P0C61@09P0D6AD05AXF01LL600G71P05AXF01@I5@0J81`05adI
00D;1`0E6aL03Q@@01`R7P0C6AD03aDA01HL600>51004QPD01LM6@0F71/041HF01PN7P0I8R404a`K
01DN7@0E7ah05R0O01PS8P0K9bD07BTW020]:`0L:bP04R4N01`/:@0W=c@0=4A102Hg=00P<bl07C0/
0P0M<Rd06`0Y?ST0>e1;02m4?`0Q=S407c@_024f<@0S>3<0:3dh01ld;`0F:bH0;T<n018W8P0U>SD0
8cLb02<f<P0D9b<08C@`01<V8P0Y?3P06bhZ01ha;@0hBdL0:3/g02Dh=00D9b@09SXi02Lk?00202Pl
?@0D02Lk?00V>S/0<4A502a0@@0L<340:cm002Pl?@0/@440>e1A01hc=00W?C/0=D]802a2?`0U?3L0
:D0j02Hm=`0Y?c`09C/i03eCD@0W?3d202e2A@0b02a1@P0[@440;45202e3@@0kDDl0>Dm=02Y0?@0V
?3T0<DM402i3?P0dBD80<TM003E:@`0dBD@0;D@o02a5@@0hDTl0;dY902Y8B00_CDd0<DmA02a8B@0e
CDd0<4I402i4@P0kDDl0AE]I03E;B@0jD4h0=de;03Q>C00kDDl0?59@03I?C00kE500=4m;03iHE@17
Gel0@5QI03A<CP0gC4l0<dQ:0314A@0fBTT0?E5@03Q<B`0aADD0=4Q703U=C00fBTT20314@P0f0355
@`0/@C`0;D8m0315@00Z?cP09CXc04IID`1NLF/0@EA>02i1>`0eB480;d8l03Q;A@0/?cT0;d8l03I9
@`0gBT@0=d]203Q<@@0gBd00:Shc02m3>00fB3`0>D/o03U;?P0nCT40;clb02`m;P0d@S<0;cd`03A1
>`0fAD00>4M20391?00b@cd0=4Do0311>`0_@S`0?4m904=FD00mD4`0<4@k02Lk<00/@3D0>De503Q;
A`0iC4P0?e9@03]>C00gBTP0=4M403=6@P0bACl0;3dg0P0V=C005@0U=2l09cHa02`k=P0`?cX0:STd
02Pg<P0/>cH0:STd02Lf<@0T;bX08R/V024Z9@0O:2<07RLR028[9P0a>SD0;3D`02L`:`0X<B`0:S<^
02/d;`0202<]9@0d020Z8P0R:B809RdV02D/9@0R9b4082DO01hS7@0Q8ah08R@O024T800J81h0624N
01/T8@0L8R005adK01TO7@0L81l06AdL01XL6`0H6QT05QPG01hO800P8bP06QdR01HI7P0K7R<07R4V
01XN8@0F6Qd09BT[01PL7@0O8b@07B4Q03Hj>@0G6AP061XI01DG5P0C5A@051HE01PJ6@0L7Qd06Q`K
01@F5@0B51<05ALF01XL6`0?3`d04a<A018B400D51805aLE018B40@05ADC00@051@B01<D3`0D5A00
51D?0P0C50l0100C51004Q8@014A3`0A4A04014A4@80410@100?3`l02`1`L70061PH01lO7`0<30`0
5QHF01@D500B4140D4i?04A2@`0F51D04@l@00803P`=00h03`d>010>3`0@3Pl06ALH02@R9@0[:Bl0
108701@B5`0@3Q<04@lB01<A500;2@`03@/<00`:2`803`d>01403P`=00`:2`0P7Ql03@/<00l=3P07
1@H04Q0A0040000<2P/04@l@00X82@0<2P/03P/<00h:2`0B3Pl05Q8C00h:2`0200`82@0602/W:018
A4D05A4B00@00@0I5AH03`P;0P0C20h201893P08010:3P0E3a<04PdA00@21@0<2`h092@V010A4`0?
3@l500l92`0600d72@0@2P`04@/=00`6200?2@/07QPJ1P0=1`T04P0F4180SHN904<m?`040000:28T
00d82@0@1`P04`X;01D<3@0=10D030<40107200:0@8040L801482@0=10D03PD600`310H03PP:00H0
50h@00P2100E3a40100000/51`05004800l420803P<70P0?10PDooooo`006oooool200lA30803@l:
0`0?4@`02P0P8Qd0aLO20<G7`P0P8Qd03a4<00h@2`0<3PT051HA018D3`0;3@P2010B3@0G00`>2@0@
4Pd03@l:01<E400=3`X092HQ03<e<00>40/04Q@?00P:1@0E5a804A<>00X<1`0C5A002@/700h@2`0A
4`h03Q0;014C3P0>40/03@l:00lA300>40/00P0=3`X0200>40/03a4<00lA300?4@`03Q0;00d?2P0<
3PT03@l:0`0>40/02`0=3`X03a4<010B3@0B50l02P`700d?2P0<3PT03@l:00lA300=3`X03Q0;0080
4A<>00@03@l:00/=200<3PT03a4<0P0B50l0300>40/0418=00lA300=3`X02P`700/=200>40/02`d8
00X<1`0<3PT04A<>00d?2P803Q0;00h02P`800d?2P0D5Q404A<>00`>2P0;3@X05QPC03Tk=P0F61<0
2P`7024S7`1EEe803@l:00`>2@804A<>00H03@l:00h@2`0=3`X03a4<00h@2`0=3`X200`>2@0:00d?
2P0D5Q40418=00h@2`0A4`h04aD@010B3@0720@05aPC01@E40803@h900<051D@00`=20082@@00P0>
3`X0100G61<02``700d>200>3`P200l@2@0401<D3@0G6140414:00l@2@808B8K02403a09010A2P0D
5@l03a0;00T:1@0>3`X05ADB00h>300@40h03`l>01PH60092@T03Ph>01<C4@0B4Q004aDA018G4`0E
6AX06b@T04MADP1ZMGH0@de=02<^:P0X<Bh06R8L01<J4`0H6QL051HC01PJ5`0S9B803Q0=00/=2P0@
4Pl00P0?4@h00`0>40d03@l<00`>2`0200d?2P803Q0;00<03@l:00`>2@0=3`X00P0<3PT01P0>40/0
5ALB01TK5P0G6AH03a4>00`>2`803@l<01<030h;00lA3P0@4Pl051HC018D4@0>40d0418?00h>300=
3@/061PF00d=2`0D518030`:014A3`0?3`d03Ph<00l?3@0@40h0414?0080418?00X03a4>01@F4`0D
5Q<03a4>00h@3@0?4@h0418?00h@3@0=3``03Q0=0`0@4Pl3014C40D03a4>01`03A4A00dB5@0=4Q<0
2a0>00T?2`0;4@X03aD>00P>1`0=4`l061/J014D5@0;3@l04A<B00lA3P0>40d04Q@A01@F4`0A4a00
51HC01TK600X:RL0>C/h01LI5P0D5Q<03a0;018C3P0E5Q404a@?0P0B4`h00`0@4@`03a0;00l@2`02
00l@2`0>010A300?4@`0418=014D3@0A50/03a8800d@1P0@4`X03a8900lA3@0@4Q404A8C01<D5P0?
4@h500lA300:00d?2P0@4Pd04Q@?018D3`0?4@`03@l:00h@2`0E5a807AlJ01TK5P803a4<0P0A4`h4
010B3@803a4>00L0418?014C400C5A805ALD00d?300F61D03@l<00804Q@A00L05ALD01DG5P0A4a80
4A<B01HH5`0D5QD04Q@C00805QPG00@051HE01<E500F61L061XI1P0C61@601DJ5P0<01HM6@0@5a<0
4QXE018J5@0J8Qd04a/F01XQ7@1UK6P04a/F01/R7P0?5Q80620K0P0D6QX0100N92@05b0O01HO7P0O
:2L201XT8`0o01/V9@0M:BL07RXX01h/:@0N;BX09cHc02@d<@0S<c009SLd01la;@0T=c<09CXe020f
<00S>C<09S`g02Hk=P0O=2l07S<^028g<P0Q=S4083D`01db;@0Z?cX0:Chi06YoNP0W?3L07c@_02<g
<P0W>SH07C0/02Lj=P0M<2`093Lc02Dh=00V>CD0PiJB02@g<`0P<bl09cXg028f=P0U>3/0:Cdo02/n
@@0Z?D009SXl02<g>@0Z?T00:Se002e1@`0I;Bl0H7=f06b1P`0mDU<09S`j02Hl>@0Q>380:3li02Hm
=P0]A3d0:T0l02a2@00X?S`0:Sm10080:Ci103P0:Sm102]0@@0[@440:d5002i4@P0Z@3h0<4I402a2
?`0eBdP0HWQe03Y@C00bBD<0;dM202i6@@0]AD40<T]703UBC`0bC4P0;DU6031<B@0bCT/0<Da:03A=
BP0eBdP0<TQ503I<B@0kDDl0=D]903M=B`0hCT/0>4i<03U?C00iCdd0>55=03aED@0fDD`0?eUF049J
FP0hD540>E5D03iCE`0hC4h0=d]<03eAD00oDe40>dm=03M;B`0iCDd0>dm?03]?CP0jCT`0>De<03=7
A@0bAT<0<DE20315@080;T<m00X0=DQ203I9@`0aA3h0=TU303M:A00^@C/0BUeG03=6@00hBdD0?U5;
0P0hBdD0201<H5L0?4m802Xn=00bAS`0>T]203Q9?P0fAc`0=4@j0P0b@SH0:`0d@CH0=D8h03<o>`0`
?cX0=4<n03Q7@P0gB480=TM103=4?P0dAd00@UE>04MKD`0oDd/0;D4f02Hk;@0aACT0@5A:03]>B00j
CD/0?e9@03a>C@0hBdT0<dI30395@@0Z?CL08C8/02Th<`0/>cH0:CPc02ln>@0d@ch0;chi02He<00T
<bh09SD`02Th<`0[>SD0:3<^028[9P0Q:RD07bPS020Y900R:bH00`0X<B`0300S;2L08BXU028[9P0T
;RH08bdU02@/9@0S:R<08RTR028X8P0R9b4082DO020S7P808bDP01l07R4L01dS8@0K924072DR01hT
8P0M8b40728P01`P7`0H71/071hM01dO7P0K7A`07QlP024T:P0O8RT07B0W01/N900J7B806QhR01<G
6P0L82809BTZ00lC500C5aL05a/J01/M700J71/05aTH01DG5P0G6AP06adL008061XI00`05aTH01DG
5P0G6AP06Q`K01`L6P0G5aD04a<A01@D4P0F5Q@05ADC018B400D518201HF500:01<C4@0?40/061TD
01LH4P0D5A004a@?010A3@0?3`d04Q8@018B4@804A4A0P0@4100100B4Q804A4A010@400@410200l?
3`1201<C4`0F5QH030`<014A4@092@T03`l?010>3`0F51D04a4B00h<3@0A3a006ALH00l=3P0>30d0
4a4B00h<3@0B414081hQ02d[<@0;2@h05A<H00T7300H5QT04a4D010>4@0=2``03`d>00d;300<2P/0
4Q0A00l=3P1[JFX0?3Xk00l=3P0A3a003@`<01DC500>30d02PP9018@4@01000040d>00h:2`0A3@h0
5A4B00l;300>2P/040`=02<O800e<C805A4B00/7200G4a@040P<01<73@0B1`d04PP=01483@0?2@d0
3@L;01LE601gMGP0JVY/01PI6`051PP03P`=1@0?20X01P0>20X03`T;00h82P0<1PP03@L9014;3@H0
3@L9018030L801<=3`0?2@/040X<00d72@0?2P/0204101082@0L51D04PX;00l7200;10D04@T:01@<
3@0A2PX030D500l8200B2P/600d72@0600/51`0C3@l02@@500l92`0J5AH03`T;1`0?10P01@0>0`L0
3@8600d21P0>0`L03`@801Cooooo000Kooooo`H03a4<02404A<>00`>2@0[;BP0:bdX00`>2@0A4`h0
5aTD00h@2`0G6A@051HA00/=200L7QT02@/601@F4@0T9R401`T400h@2`0=3`X05QPC018D3`0A4`h0
4Q@?01@F4@000@0030h900d?2P0I6aH0418=00/=200B50l0418=01<E400?4@`00P0>40/0100;3@P0
3@l:00d?2P0>40/300lA300E010B3@0<3PT02`d800h@2`0?4@`03Q0;00lA300C5A000080014C3P08
2PD03Q0;00d?2P0<3PT03Q0;00lA300>40/030h900/=200=3`X03a4<00802`d800L03Q0;010B3@0?
4@`030h900lA300>40/030h900802`d800D03Q0;00X<1`092`H03Q0;00d?2P0200`>2@0>00T;1P03
1@009RPS00H80`0>40/04aD@01@F4@000@00418=00X<1`092PL0F5YE0;2b[@0N81/200X<1`0;00d?
2P0B50l04A<>00X<1`0?4@`04A<>00h@2`0<3PT03a4<00h@2`0?4@`00P0>40/200lA300>00`>2@0H
6A@010D000h?2P0A4Pd03@h9018C3P0J6aH02P/6014B3@0N7aX02P/601PI500=3PP200d>1P0500l@
200G61007b0H01DF3P0=3PH00P0@4@T02`0=3PH05AH>01<D3P0=3PT0414<01<D3`0?40`030`:01<C
4@0:2PT04A4A00803Ph>01@051@B01XJ600I6QH05a`H024W9`0g@D40SiVJ0>kjnP39e=<0R9>?05aU
HP0O9b405QdF00h@3@0B51401@L401PJ5`0C5A803a4>00d?30<03Q0=0P0?4@h0100@4Pd03Q0;00h@
2`0=3`X200h@2`0<00`>2@0>40/03a4<00lA300@4Pd04Q@?00`>2`0?4@h03Q0=00/=2P0<3P/03Q0=
0P0?4@h02`0>40d02@/800d?300E5a@05aLE00/;2@0B4Q0051@B01LG5@0>3P`0410>00<03`l=00L0
410>010A3P0A4a004A<@010B3`0D5Q<04aDB00<03Q0=00<03a4>00h@3@0>40d00P0>40d0100=3``0
3Q0=00h@3@0@4Pl2014C400A00lA3P0A4a004A<@010B3`0?4A404A8F018C5@0>4Q40314=00`C300@
5a003aH?00dC3`0Z;bd07B4R01XN800?4A000P0=3``2014C400700h@3@0B51405ALD00`>2`0@4Pl0
3a4>01<E4P0200d>2@0400l@2`0C50l051D@018C3PH03a0;00h02P`700`>2@0@4`/04A@;00lB1`0;
3P<04aH=014D2`0<3`X02`d<00h?4@0C51L04Q@A018D3`804aD@0P0D5Q400`0<3PT03a4<018D3`02
01<E400?018D3`092`H051HA00/=200:30L05ALB00lA300@4Pd03a4<018D3`0C5A00418=014C3P0=
3``0418?00804aDB01@04A<@00lA3P0C5A805ALD01HH5@0C5A8051HC01DG500H6QT04A<B01DG5P0Q
8b806Q`K010B4@0E5aH04aDD018D4`0C5A@051HE01DG5PH04aPD00l05a`H01DJ5P0C61@051TE01DJ
5P0E6aL05QhI00hG4P0F7aX03aPC024Z9@0?61<0624L01@M600K91l00P0@6A@01`0C71T061hN01DK
6`0F71`05AhM02Xc<P0]=cH00P0J92<05@0I92<06RHT01/W9@0L:bP04b<P01h^:`0K:bP0:SXg02Hi
=@0R=C40:3/g02Tn>@0P=S007cH`020g<@0R>3808SLb020e<00O=2l07C8]028g<P0202Dj=@0I01`a
;00R=c806c0[0315@00J;RT09CPd02<f<P0P<bl093Lc024d<00[?SX072l[01ha;@0Z?CT0>Da801ha
;P0R=SL093Lk02Tl@00[?T80:Ca002Hi?@0`@dL0>TeA02Tl@0020313A`0A024d>00X?D005R//028h
=`0^A440:D0j02Dl=00P=bl0:d8j02Po>@0cBDL0>e5?03A9C00Y?T40:Sm202a1A00]@T<00P0^@d@0
200`AT@0=de;03A:B00_AD80;TA1028k=`0Z@cl0:T@o0P0`BDD202U2?P0?03=<B00dCTX0<Te802i9
A00`BTH0=Di:03=9AP0iCd`0>4i;03=9AP0aAd@0=4Y703=9AP0fC4T0=de:0080=D]808h0=e1<03QA
B`0hDdd0>59?03A<C00aBD`0>E5E0356B`0_@dL0=4Q903Q<B`0jCd/0?E5?03]?C`0jCTl0=TY;03Y>
C@0oDe80?U9A0314@P0bAT@0;T9002]0>`0aAT40=da703=6@00bACl0=dY40395?`0`@cd0=dY403mB
C00cAT00=DQ203U<AP0dAd40<TDo03Y=A`0cAT009cXd0395?P0jBd<0>da403U:@@0^?S@0=THl03A4
>@0]>S00<Slf02hj=`0[>SD0;Sdh03M6@@0hBD<0>da603i?B@0kCdH0?E5803]?AP0eBD00:clb02Xo
;P0fBc`0@5A903A7@@0dAd<0>de<03E7A`0aA480;3ll02Lj=P0S=S00834/02@c;P0[>SD0<D0k02hm
>00[>SD0:STd030o>P0a@3/0;C`g02Xi=00V=C008bhY028[9P0P:B@08BXU02@]:00U;RT08BXU02@]
:00X<B`09RlZ02@]:00V;bX08R`T024[8`0U;2D08bXS01dT7@0N8ad07b@N01hS7@0Q8ah08R@O024S
7P0N8Q`08BLS01`U8P0G81d082HT02L]:`0S:BL092PW01lS8P0O8B007R0O01XL6`0H6AX07R4X02<V
;`0S9Rd06A`S01@G7P0I72408bLZ028V:00g>c`06AdN024U9@0D61L05aTH01PJ6@0E5aH04aDD01@F
5@0H6QT04A<B01HH5`0J71/06A/J0P0H6QT0200W9bD05aLE018B400F5Q@05ADC018B400@40h04a<A
0P0D5180100A4@l03Pl:014B3@0A4Pd2018C3P0401<C400C4a404a<A01<C4P804A4A0P0?3`l2018B
4P0@014A4@0@41003`l?00l?3`0C4a<02@T900`<300D51@0410@05iNGP0R82404a4B01@B4`0A3a00
3@/<02TW:08040h?00/04@l@00d;300:20T03P`?00T73@0A3a@05Q@I00/93P0C4A@02PP;00`:3@02
00l=3P0L00X82@0<2P/03P`=00H41@0O7Ah05aDF01DC500100001`H600l=3P0100004@l@00L51P0=
2``03@X;00d92P0>2P/040`=00`82@0>2P/04@d>00`82@0400403PX;014=3P091@H040L;01853080
4@H<00T040L<00h8300>2@d05Q@G08B4QP1nOX001PL900<720091`T01@0?1PT00`0<1PP02`D700`6
2002010:300300`6200=1`T03@L900@03@L9018040X<00@0000A2`d0100000/51`0B30h03PP8010<
2`0B3@d02P@400T5100=20L03PP8010<2`0<1`H01`4100X61@0?2@T600`6200600P2100:10H02@<5
01hH6P2HTY@0D4Y<200?10P200h31`803`@85?ooool001_ooooo0P0>40/200lA30803Q0;014010H1
01HH4`0B50l04Q@?01HH4`041P400P@0018D3`0g>C@0=3Ha00h@2`082PD06adH01LI500U9b802P`7
01@F4@0200`>2@0A00h@2`0I6aH020X500h@2`0K7AP02`d900/=200H6QD03a4<00@60@0B50l0418=
01@F4@0A4`h0418=014C3P0>40/00P0=3`X01@0>40/03a4<00lA300?4@`04A<>008030h900D03a4<
010B3@0?4@`02P`701HH4`02010B3@0600P:1@0=3`X03Q0;00`>2@0>40/03a4<0`0>40/01@0B50l0
5QPC00lA300>40/03a4<0080418=00@03@l:014C3P0A4`h03Q0;0P0<3PT03`0?4@`02`d800X<1`0>
40/020X500/=200@4Pd06A/F02`^:@2WZJ@0?3hi00T;1P0=3`X03Q0;0043000200d?2P0Z01PJ5@0A
4`h0:R`W00`>2@0;3@P02P`700d?2P0?4@`03@l:00X<1`0=3`X04A<>00h@2`0<3PT03a4<00d?2P0>
40/04A<>01@F4@0B50l03a4<00d?2P0D5A0020T4018C3P0@4@`01PL201LH4`0>3`X02@X500P9100@
4@`030d8014B300<3@L03@h600h?1`0=3PH04A8:01HG3`0A4PX03Pl70P0;30@03@0>3`L04A8:01DF
400>3`X051D@00l@2`0=3@X08b<Q020P7P0<30/02PX:01HF5P0C4a<00P0J6QP03`0J6aL07B8N038h
>01JI6@0cmWJ0?;noP3`n_T0WZVU05=LF@0S:bD0<CPa01PJ5`0D5Q<03@l<00lA3P02014C40H03Q0=
00d0418=014C3P0A4`h0418=00h@2`0<3PT03Q0;00lA300>40/030h900d?2P0?4@`03@l<00802`d:
0`0=3``02@0?4@h030h;00d?300;3@X03@l<018D4@0?3`d01`L500/;2@0200d=2`0400P81P0@40h0
410>014A3`80410>00L03a0=010B3`0@4Pl03a4>018D4@0?4@h03@l<00803Q0=00D03@l<00h@3@0>
40d03a4>00h@3@0200d?300X00h@3@0@4Pl04Q@A010B3`0>40d03a4>014C400?4@h03Pl@018A5P0C
4aD041<B00`A3@0<4``02Q<;00PB2P043@P05AdJ00<92@072P`030h=00`>2`0=3``03Q0=00d?300:
30T02`d:00lA3P0<3P/04aDB00h@3@0=3``061TD014B3@0;30L0414<01DF4@0D5A003Pl:00l@2`80
414<0P0?40/200d?2P0;00hA2@0?4PT03a87010D1P0B5@X041<:00d@2`0<3Pd03@h@010A5@0A4a00
0`0B50l201<E4004010B3@0A4`h04Q@?018D3`804aD@00h02`d801<E400F61<061XE01LI500=3`X0
418=00h@2`0D5Q405ALB014C3P0C5A004A<@01<E4P8051HC00l04Q@A00lA3P0>40d03a4>01HH5@0B
51405QPE01LI5P0E5aH051HE01XL6`0S9B@06adL01<E500F61L00P0C5A@00`0D5QD05QPG01HH5`06
01<H500H01LL600C61@04AHB018G4`0D6AD051XF034i=00W<2/031D@018K5P0H8A`04Q/F01PQ7000
1P4082TT01HO6P0G81/05QlL01PM7`0E6Qd051TL01PP8P0W;c409Bh_0P0J92D02P0K9RL072PX01hZ
:P0R<3006RXY02Ti>00R<c80<DA202Xm>`0X>cT202Xn?00M02<h=P0S>CH0:3hk02Dk>00T>SL0:3hk
028h=@0L<Rl0:T0m0316@`0V?3T0:T0m02Lm>P0Z@3d0;48o01ha;P0O<Rh08SDa020c;`0R=C407c8^
01ha;@0W>SH0:Sdi02Hi=@0J;BT09CPe02@h>@0V>Cd00P0Y?4008P0X>cl09STm01lb=P12EET0@eIJ
02Tl@00_@TH0:Se103E:C@0W?3d09CXi024g=00V?CL0<DPo02Hm<`0Z@CT0:T4k02]1?`0iCdd0;T=6
02Dm?`0V?T00:d=502i6B00`B4X0<4Q802Hn?P0[@d<0;DI3039;A`0dCDT09Slk02Q2?`0X@d02031:
A`0?02Y4@00YA3l0<DY603A=B00cC4H0<4U30359@`0dBdD0;dE203E;B00jD4d0>Dm<03M=BP0iCd`0
=D]80080=4Y701`0=Ta903M=BP0cC4P0<DY403A?B@0`BTL0<4Q803=;CP0cBdl0;D9702i2A`0fBT/0
=d]:03M<B010EE00?51@03]?D00eBDX0=d]<03]?CP0hC4/0<dM50355@`0_@d40;d@o0397@P0eBTD0
<D@n0P0eB480;@0cAT00=dY403Y=A`0cAT00=4M10354?P0bACl0<D@n02`o>@0`@cl0=TU502e0?00d
Ad80=TM103Y;@`0iBT80=TDn03I6?00c@cT0<Slf038o>00b?S/0=TE00391?00gAT40?Di8041ABP0n
CdL0>4a303=7?P0_@cX0;T8g0314=P0cB3L0>Tm003a@A@0^@C/0<TE103e?CP0dATH0<4=102Tl>@0N
<Bd08SD_02m1>P0202Lf<@0N03M6@@0eA3l0:STd01l^:@0P;bX09C@_02He<00Y>3<09cHa02@`:`0R
:bH082TT02</9`0W<2/0:34/02/d;`0V;bX08BXU02D^:@0X<B`09BhY02D/9@0R:B408bXR024X800L
8a/08BHO01dR6`0N8a`08B@M0P0P8A/03P0R91h07bDQ01`U8P0H8Ah07bDS02H/:P0P9R@0<3@c02L[
:P0P8R407AlN01XL6`0J6a`07R4X0P0P92d0300I7R@05Q/Q01LL800K82<06R0Q01LM7@0F71X04aTG
018F5@0F61L061XI01LI60805ALF00h05QPG01<E500H6QT06Q`K01TK6P0G6AP05QPG028R800D5180
4a<A01HF500E5A<05QHD018B40<051@B00X04Q8@010A300C50l04a@>014B3@0@4@`03`l<00h>300C
4a404a<B0P0A4A4200l?3`0401<C4`0B4Q804A4A010@40<03`l?03D00@4101<C4`0<30`000000451
@@0G5AH02`T:00d;300G5AH02PP901TG600?3@h03P`=00d;300C4A805A<D014?4P0F4aT02PP=00`:
3`0A3a@04@lB00d;3P0<2Pd04@l@00h<3@0<2P/03P`=014?400@3Pl00P0100P61`0E4a@04@l@01TG
600:20T02`T:01HD5@081PL04a4B00X7200=1`T03PP:010:300<1PP03PP:014;3@0G4A<05Q0B01<=
3`0;1@L02P@601D;3`020185300:0146300@1``03PP<01@?4`0200<03@d?024R90041@L03a<D00/8
2PD03`H900<030H800d72@0>20X00P0<20T00`0=2@X03@L900d72@0400d72@0B018<3P0;1@L050h@
00/51`0:10H040X<00`81`0;2PH02@H400L300030P002PP400T50P0<2`L030X600T50P0920@02`L5
1P0<1PP01P0J51H03PP:00H00P070@<0E4i@01LA4`H03`@80P0@1@T200l4208040D95?ooool001_o
oooo02H020`700/>2P0>4@d03a8>00dA300;3PX03Q8=00lC3P0@50l04A@@00lB3P0<40/05QPD00d?
2`0E5a<04Q@@00lA3@0E5a<092HR00h@300B510030h:01<E4@0620<02`l800d@2P0=4@T03Q4;018E
3`0K7QP03Q8<014D3`0D5a803Q8=00/?2P0:3PT03@l;00lA3@<03@l;00@030h:00/=2@0=3`/03a4=
0P0@4Ph03@0@4Pd04A@>00`?2@0<3PP03a4;010B300?4P`030h800T<1P0>4@/02`d7010C3@0?4@`0
0`0?4@d00`0=3`/030h:00/=2@0201<E4@04018D400C5A403Q0<00`>2@<02`d800<03Q0;00d?2P0=
3`X00`0=3`X0600;3@P02P`700/>2@0W:bH041<A00`?30072`L04aDA05YLF00J71P01`T4010A3@0=
3`X0414<018D3P061`@03@l:00`>2@051`@03a4<00h@2`0=3`X03Q0;00d?2P8030h900P03@l:010B
3@0=3`X030h9010B3@0<3PT02`d800`>2@803Q0;07H03@l:00X<1`0>3`X0414<00h?2P0?40/0414<
00l@2`0;30L04a@?00l@2`0:2`H04A8=010A300;3@L03a4:014C300<3PP030h700d?1`082@@0418;
00d?1`0B4`h03Pl900`=1`0F5Q403@d900l@2`0A4Pd08R<O09nSWP1OH5`051DA00/<200E5A@03Ph<
018A3P0I6aH03Q<=01/Q700b>cL0HVaX0<?=bP3SkNX0f>?N05aXH`0/>34051lG01<K500D5Q803a0<
01DF4P0?40`04A8>014C3`0?4@d04A<?00lA3@0>3`/03a0<00h?2`0?4@`030h900d?2P0B50l02`d8
00lA300F61<03@l:00X<1`0;3@P030h900d?2P0?4@`030h:00P:100@4Pd0418>00hA2`0@4`h03a4=
010B300?4@`03Q0<010B3P0A4Q002``900`=2P0B4a404A8@018C4@0>3``03a0>014B400A4Pl03a0>
00lA3`0;3@/04aDC00T;2@0I6aT030h<00d?3@0?4@l03@l=00`>300F61H0:B/Y01<E4`0B51805ALE
01<E4`082@L05QPF010B400?4@l03@l=0P0?4@l01`0>40h03Q0@010A4@0@4A803a4>00d@3@0=40`0
0P0>50l05P0:40`03a@A018G5`0R9BD0418@014C400C5A804Q@A014C400?4@h04A<@010B3`0>40d0
51HC00h@3@0A4a008B<O01`M6@0D5Q804A8>00l@300>3`/200/<2004010A3@0D5Q803@l;018C3`80
3a4=00`03a4<00h@2@0?4P/04aH>014D3@0?4P`03Q0=00lA3`0?4A403Pl@00h@2`0@4P`3014C3@0L
00lA300E5a<04aDA010B400>40h04A8A014C4@0C5A404Q@@014C3`0B51003Q0<01LI5@0C5A40418>
04Y<B00L7QX04aDA01PK5`0I7Q/05Q`I00lD4@0=4Pl05QXH010C4@0E61H04Q@B01HH5P804aDC00H0
51HD00`?3`0A51@04aHF014D500G6QX301@G5`0701PK6`0@4a<06ahN018E500C5aD05AXG01DI5`02
01@H5P0<01DJ5`0H71X05a`I01DJ5`0L81h05Q/H01DI5`0e>c/09B`/01<J6P0B6AT041LG0P0C6QX0
O00J8B4051/K01XQ8@0F7Ad04Q/J01HO7P0?5QL0624Q01LQ8P0L9BL06B<U01`Y:`0Q;S008Bda01l^
<@0V<SL07Rh_02i2?P16FUL0;40m02@i=@0[?c/0;48n020f<P0W?CT0:3hi02Ln>@0^AD00?5=>02]0
?00S>3@0:Clk02a2?P0Y?SX0:Clk028h=00M<bl093Te01ld<00I;RX0:Chh024g;P0V>S<093Ta02Hl
=@0V>SD09CXf01hc<@0Z?S`08cLf01da<@0W>c`09SXl02Tm@@0_@dL0;41302Tm@00W>cl0:3a002Hj
?P0[?d807C4e02e1A00T>3`0:Cln02Hl>00Y?c/09Sdg028i<`0V?CH0;48m02Y0>`0]@d409C/j02Tn
@00Y?T40:d5302e4@`0`AdL0;TE60317AP0X?ch0=Te<02i5A00_Ad@0;DE202Hm>P0aBDD0<D]602a6
@P0]Ad80;dU5035:AP0cBdL0=4]802m7A00bBDH0=4Y803=9AP0dBTH0<4Q2039:A00cC4@0=4Y60399
@`0bBD80?55=03E;A@0bB440>e1<03E:AP0mDT/0<DLl0399?@0^A3`0<DE103I;BP0cAdP0<dM90354
A`0iCDh0=TY903A9AP16FeL203]@CP1P03mDE00kCe00=d]=03Y@DP0jCe40:D1003I=C@0lDe40=De:
03=;B00bAT@0>Ti;03I9A`1:GE/0=d]803Y>B`0gBTH0>4]803M;A@0bAT40=4Q302i2?00fBT80?558
03U>A@0fBT<0<DDm03E9@00gBD40>D]303A7?P0eAch0=TM00393?@0a@T80>T];03=4@P0hBDL0?U1=
049DCP0jC4D0<TDl02Xm<`0/?S@0<dHk03]?@`0lD4H0>dm603E8@@0bA3h0>DY704ADD@0nCDX0=T@o
02Le;`0P;RL0:CL_049BBP0iBD<09SHa02Xi<`0^?3H0;c/f030k=P0_>c<0;STd02/g;`0Y=bl09S@/
02@^:00Q:B@082HR02<Z9P0Y<B`0:34/034k=@0[=Bl082/U02@`:P0Z=S0082/U02<[9@0R:B808RPR
01lV800N9Ah09B/U01XP6`0L8Q/07b<N01lR7P0N8Q`082@O01`Q7`0K8b006b0O0P0J7ad09`0F6aT0
7b<R01/O7P0D5aH06QdL01hQ800O8b<07b@X01/R9P0I7bD07B@X01XP9@0S:Bd0;C<f01dS9P094140
72<T01DL7@0H7Qd061XH01XK600J71P061TG01HF500H61D061PG01/J600K6QL06aTH01XH5P0H61H0
<c8`01PH5`0D51<06QXI00l?3P0B4Q005ADC01HF500201DF4P0>01@E4@0C50l030`901@D4P0A4A00
3`l>018B4@0?3`h04Q8C01@D5@0F5QL03Ph?014A4P0B4Q<2018B4P0O01<C4`0A4A403Ph>00d=3@0A
4A407QhN00D51@0D51@03`l?00P8200@3a404a8D00h=3`0?3Pl02@P:010?4@0@3a003Pd?00/:2`0>
3@l03`h?00T82`0=31003`hA010?4P0<2`l02PT<01@C5@0B4A@051<D00/:2`0200h=3P0I00`;300;
2@X040h?00h<3@081PL0518C00d;300>30d04a4B00`:2`0?3@h030X;00/92P0;20T03@P:00l;300<
2@X03PT;00l;30091PL03PT:00l;300?30d030L800l92`020148300<0108300?20/03PT;00/72@0F
4aD030T;014@4@061@H061LI01LC500@20X040T:0P0>1PP02@0@2@X03`T:010:2`0?2@X02`H600X5
1@0?2PX030H700d7200300h82@0O00d7200;1@H05@l@00P3100;1PL040X;00`61`0:1@@02`T600/7
1`0C3Ph02`P600/8200;1PL02PL500h:2@0<1`L03@X800`71`0?20X03PH900h5200?1@T03PD900/4
1P0>10L040T:0149300C2@d03@@701D;3`0600l4200601872`0n<cL04`P<00h31`0C20`091TM5?oo
ool001_ooooo00@051TE00hC3`093PX02Pl;0P0=4Ph00`0>4`l03A8>00`A3@0200`A3@0800/@300:
30T02`d:0043000J71T04Q<A01HH5@0D5Q<200h@3@0B00lA3P0S9B809bTT00dC2P0>50X02a4700X@
1P0?50d04aPA018G4@062`D0<cPb00D:1P0730P04QLC00lA3P0>40d03@l<0P0>40d00`0?4@h030h;
00lA3P02014C4080418?00L03Q0:00`?200=40T03a8;00hA2P0<3`P03A09008030l800@03A0900hA
2P0<3PX030h;0P0?4@h200d?300800h@3@0@4Pl051HC00lA3P041P<01`T600h@300>40/400d?2P03
00h@2`0=3`X030h900<030h901006QlK05AJF00Q9B@05ATH00L;2P082PL02P`9014C400>3`X020T4
01TJ5@0?40X020X400`>2@0>40/03@l:0P0<3PT04P0A4`h03@l:00T;1P0<3PT03@l:00T;1P0B50l0
4aD@00h@2`0<3PT03a4<00`>2@092`H02P`700h@2`0A4`h0418=00d?2PH03@h91P0>3`X09@0B50l0
20X500<50@0:30L030h900lA300=3`X02`d8010B3@0;3@P05ALB00P9100D4`l04@h;00/<1`0B4`h0
5QXD08V>R01OI5h04QD@01@F4@040`004@h;01dL6015BT@08RTR01DL5@0G7QL07RPP03Do=`1KIEd0
KGQ`02<`9`0I9Qd03a`C014K4`0@4Pd00P0G61<04P0B4`h051D@01`M600>3`X04a@?00l@2`0>3`X0
414<00h?2P0a<bh0@48m00`>2@0=3`X05QPC00H80`0K7AP03Q0;00`>2@80418=01<03a4<00X=1P0;
3PL02`h7010C300;3PL030l800lB2`0C5Pl04A@=00`?200>4@X04A<>01@F4`031@807R0M06a^J`0E
5a@0004000803@l<01403a4>010B3`0?4@h051HD00840`0A4a809bTX05=EE00P8R402P`;010B4@0>
40l02`d<014C4P0];bh0418A00lA400200/=300301LI6016B4L0:2XY00D03Q0?00@03a4?00lA3P0?
4@h03Q0=0P0?4@h2010B3`@03a4>0P0A4a00100@4Pl03a4>00lA3P0?4@h200d?30803Q0=0P0?4@h0
100620D03@l<010B3`0@4Pl201@F4`0901HH5@0B514051HC01DG50072@H02@/800`>2`0>40d03a4>
00803@l<00@03a4>018D4@0?4@h03Q0=0P0@4Pl00`0>40`03a8;010C2`02014D3@0A010C3@0?4@`0
30h;00lA3`0A4a804A8D00l@4`0;30h092HU00L91P0A4a00?Cll03@f<`031@805ALD00`>2`16B4D0
0P0C5A806P0E6QH06R0N00D;200E7Q/06b4O00dC4@0>51803Q8A00lB4@0C5A@051HE01`N7@0/;Rd0
2@d>01<G600E6AX08RHW00`@4@0C5aP06QhO00`@4@0>4Q<05QXK010D5@0F6Q/04QHE100D61L0400E
6AP04aLF01<G5P0B5QD082@S01LK6P0E6AX041DI01dR9P0J7b<07B8V01LL800B5a/05a`P01DJ7P0G
720201/P900N01LO8@0H8B8041XI01HP8@0J9RH04ahP01XV:@0J:2/08c8g01h]<`0H9bh082lf01P[
;00S>S@09C`f01dd;P0R>C<09chh02U0>P0R>C<0:d8l02Ln>00U?3H093/e03A:A@0X?CP08cPc02]0
>`0/@C`0:3dh0P0S>3<03@0V>cH09c`g02a1?00]@Sd09S`c02Q0<`0Z@SD08SX^02Ln=P0X?cT093/g
02Dk>@0U>S/00P0U>Sd09P0S>3d07c@g02i3AP0nDeH0=4U<02Hk?P0O=3L0:3e002]0@`0`ADP0<DI9
06AiO00]@T@0;4<m02]2>P0Y@3P07cH`01`c;@0R>3D0:3hl02Hl>P0[@440<dQ903eBD`1FJfd0<4I4
02Pn?00P=S@08CLe02e3@@0eBdT0<dU702m5@`0`AT@0<DM502i4@P0bB4D0<DM40P0_AT002P0aB480
<TU40398A@0cBDL0;TA20398AP0dBDX0<TM803I<BP0_B482031:@@1/0399@@0cBT80=Te503I;A010
EDh0<DHo0354?P0iC4H0:Shc03I6>@0gB3P0=dTm03Q9?`0hBTD0=dY803E7A`0cATH0>De>03M;BP0h
CD`0BV1M03Q?B@0iCd`0AE]H045FE`10EEP0BV9V04UPI@0[@dL0=U1A03E?C`0`BTT0;TQ703Y?D00/
@440<4A50396A`1KKfh0;T910396A00fBTP0<DE303=8@`0fBdH0=4U203A:?@0fC3l0>Dm203I<@00e
Bcl0>4i203U>A@0gC4<0>4e403U>A`0eBT<0<TM2049GF@16FEd0?51A041DD`10De40@5=?03Y=A`0c
A3`0:S/b03E6?00oCd@0?dm903a?C@0hBdT0<dE203Y:A`0oCTT0?D]503M4?@0/=bl08R`T02Xd:`0^
>2l0;3Xb02Pk=@0[?3H0<T4k02dj<`0Y<Rd0:C4[02/b:`0/=Rh0:C@[02@`9P0Q;R@0:34Z02T^:P0T
:BD09BXV02P^:P0T;BP08RdW02D`:P0Q;RL093</02dl=@0U<b`09RlZ02L]:@0R:2@06R0L0P0G7AT0
;`0L8Qh07B<O01dS7`0M8al06b4M01TO6`0N8al06QlK01TM700L81l06alN01HJ6@0D61L061`K014E
500L81l08RHU01hS8P0]<SD09blb01XR9@0@61/00`/>01XR9@0>5QT07RHY02@/;`0G7b803ADH01XO
8P0H6QL05QLB01PI500H5a<051<?01HE4@0I5A806QHC01/G500L5a@06aHC01XF5@0E4a@05ADE028R
8P0V9RH05aLF00805ADC00<05ADB01@E400C50l00P0C50l0200E5AD03@d?01LG6@0O7b405ADG01LG
6@0?3a402PX<0P0B4Q@01P0C4aD02@T;01<C4`0A4A40410@00l?3`803Ph>00L03@d=00X:2P0G5aL0
10@400l?3`0;2`/03Ph@00<03`lA0P0=3@l01P0>3Q003`lA010@4P0?3a403@d?00`<3PH03`lA00<0
6ATK01PH6P0:2P`00P0<30h01@0>3@l03@/<00d;300<2P/03@/<00803`d>0`0>30d00`0=2``030X;
00`:2`0200/92P0:00`:2`0=2``03@/<00`:2`0@3Pl01P@500X82@0<2P/0518C00h;30803`/<00X0
3PX;00d92P0=2@X02`L8018>3`0;1`P03PX;00<0000<20T02`H60P0=1`L0100:10@02`D500h8200?
2@T200h820803@L700@03PP800X4100;1@D03@L70P0?2@T05P0@2PX0<B/[03H`<00I4a<02@<3014;
2`0C3@d071HH00X41P0?2P/03`T;00@0000=20T03PP:00`6200C3@l030H800h82P0@2P`050T=0146
2P0@1@T201872`0700l4200;00@03P@700X00`0>0`L04@H:00L0000600l4200600h31`0T6Ad02001
01052@0C20`0;R<W5?ooool001_ooooo01<04QLC00/@30093PX0314=00dB3P0730P041DA00`A3@0B
5a<04AHB00P=2@0;40`04aDB01PJ5`000@0051HC04i@C@0E5a@04Q@A00<03a4>00h0:B/X034c;P0?
50`03A<900H<0P0>4``06AhG01PM5P0=4P`05a`F069WH@0J7a/02a0<00`A3@8030h;00D03@l<00lA
3P0A4a004Q@A00h@3@0300lA3P803@l<00P02`d800`>2@0?4@`0418=00`>2@0:30L03Q0;00d?2P80
30h900<03@l:00`>2P0<3P/00P0?4@h03`0=3``03Q0=010B3`092`P03a4>00/=2P0>40d05aTF00d?
2`0?4@`03Q0;00`>2@0:30L030h900h@2`0300d?2P0N00h@2`0?4@`0310=024W9@0420L02`l>00H:
2@0A4a0071hK01LI5P0F5a803@h901hO6P0720803a4;00h@2`0?4@`03Q0;00d?2P0>40/05QPC010B
3@0:30L030h900d?2P092`H04aD@01HH4`0B50l03@l:0P0>40/01P0;3@P03@l:00h@2`0;3@P02@/6
00P:1@H03a0;1P0>3`X0;00F61<03@l:014C3P0H6QD03Q0;00`>2@0=3`X020X501XL5`0<3PT0:R`W
014B3@0?3PX04a0=00`=200A4Pd03Q4<02DZ900I7QP02`d900d?2P0?3PX04a0=00`;1`0];bX04aPB
00`A2`0E6Q@07RDN01lY8@0P:R80=T0h01`W7`0D7aL02aH>00D?1`0:30L02``700T:1@0:2`H03Pl:
010A300>3`X04Q<>0P0?40/02`0@4@`03Pl:02X/9`0a<bh04Q@?00H80`0=3`X0418=018D3`0;3@P0
2P`700803Q0;0P0<3PT04`082PD030h900d?2P0:30L03Q0;00lA300A4`h0418=00`>2@0=3`X03a4<
00lA3P0A4a0051HC020R7`0B51404aDB00d?300>40d00P0?4@h0500>40d020X800T;2P0W:BP05ALF
01/M700<3Pd051HE00d?3P0>40l03@l>00P:2@0H6QT01@L600T;2P0?4A002`d<00lA400X:RT04A<B
1@0>40l0100?4@l03a4>00lA3P0>40d200lA3P80418?00X03a4>00h@3@0=3``030h;018D4@0@4Pl0
3@l<00`>2`0=3``0418?0P0=3``300h@3@0F00lA3P0:30T0418?00d?300<3P/051HC00lA3P0B5140
3Q0=00lA3P0D5Q<03@l<00lA3P0>40d03a4>010B3`0>40d03@l<00lA3P0A4a00418?00h@3@80418?
01803Q0<014D3@0@4``03a8;00lA300@4Pd04A<>00d?300?4@l04Q@C018C5@0@4A<03PlA00lA400B
51403a4>01LI5P0C5A8201DG500P00h@3@0E5a@0418?01DG500A5Q8000H402hg=00C71T03A<A014G
5@0>51804aLF01<F5@0C5A@0418A01PJ6@0Z;2/07B4R01DI6P0T:2T041@E00dA4P0G6a`0ATY;03Lk
?0052@X08RHW00dA4P0420T04QHE014E500B5QD201@H5`0@01<G5P0B5QD06alN010D4`0=4A002Ph=
01LK700C61/0DeQK02@Y;00K82<04QLJ01XO8P0F6ah05AXM01HK7P806AhQ01T05QhP01XS9@0`>S/0
7BLY01LR90084aD08c0b01XX:`0S<SD082lc01/Z;`0Q<3D07S4a01lf<00N=Bl083La028i<`0T>cD0
9chh02<j=00]A3h09chh02e4?P0T>cD0:d4l0080:3dh00@0;T<n02a1?00Z?cX0:Chi0P0bAd8202Dj
=@0M024f<@0L<RT09clb02U0=P0S>S409Sde02Hm=`0V?CT09S`j02@i>P0X?D00:Ci102@i?P0W?3l0
<DI903M<C`0W?3l07S<f02@i?00W?3l0:d1302m4A`0bAdX0J7f002m4AP0W?CX0:d8l02Po>@0P=S<0
0P0]@d00600eBdP0;dE202Hl>P0R>3H093Xh03I<B`0^A480;49003Q>C00/@T008CLe02Pn?00]@d40
:d4o02i4@P0bB4H0<DM50398A@0_AD80<4M102m6@00^ACl0<4I20398A@80<4I403L0=4Y803A9BP0b
AdP0=Ta:02m8@P0_BD00<D]203E<A00fCDD0=4]303M<A@0_@cd0=TU302e0>P0aA3h09CT^03=3=P0e
AcL0>4Xn03U:@00gBD@0=4M502do?`0cATH0=4Q70396A@0gC4X0@5IC02i3?P0_@d40<dM503A8B@0h
CE00?U=F049IG@0bBTh0=Ti@0359BP0_AdL0:dA10355AP0_@d@0>De>04MKFP2calH0KH6003U=B`14
F5H0=TY803aAC00cB4<0<dQ10398>`0dBSd0>4i10080=de102`0>e5503E:@@0eBT<0=T]403M<A@0c
B440<4E0049GF@16FU/0?e=D049FE@0nDDl0?4m;03iAB`0kC4@0;d0g03]<@P12DTL0>da503Y=B`0l
C4/0>DU703a<B@0mC4L0=T@n02`i<P0U<2X09C0X02hi<@0^>300:SP`02Tl=P0_@3X0=T@o02hj=P0Z
<bh0:30Z02dd;@0_>C40:cH]02@`9P0S<2H0:S</02X_:`809B/W00h09bdY028[9P0T;bT09S4[024^
9`0V<b`0<3df02Tg<00O:2<08BLS01lU8@0J81`06AlK01/Q7@<0728N02406b4M01XP700I7a/07B8N
01XO6@0H7AT07B8N01hS7`0H7AT04QLC01TN6P0E6AP08BDT02L[:P0S:2P05AXM01HN800D71h04QXL
00lG6@0e?Cl0GfMY03@l?P0D71h04QXL01DM7`0H7Qh05QPG01@D4P0I6AL06a/I01TI5`0K6QP00`0H
51<201TC4`0K01PD4`0<2P/05ADE01TI6@0L71`051@C01LG5@0C4a404a@@01<D3`0B4`h04Q<=014B
3@0H61H04A4A00h>3P0@410020P801TI6@0N7Qh04Q8B010@400A4A405aLG00d=3@0D51@0410@0080
3Ph>00P03`l?014A4@0>3Ph03Ph>01`L700I6AT04A4A00/;2`803Ph@0`0?3a4200h>400300l?4@0@
4180410B00803`lA1P0=3@l00`0M7Al071`N00h>400200`<3P0300l>400=2``03@/<00<030X;0P0>
30d00`0=2``030X;00`:2`0200`:2`0<00/92P0<2P/030X;00`:2`0=2``02`T:014?40040P<03`d>
00T7200E4a@030T:0P0?2``03`0>2P/03@T:00d92P0A3@h05a<D00X61`0<20T020@501DA4P0A30`0
30H600X4100<1PH03@L700`61P0200d71`8030H600<03@L700h8200>20P00`0>20P04@0?2@T040X:
01dG5`0U7al03PP800@0000600002`D500@000080P@040/<00T31@0R71h050h@00P210070@<040X<
0080208400d03PP:01462P0@1@T040D901872`0C20`04@H:01<8300D2@d03@8601/@500/8BD05P/?
00H03`@800H04`P<00P00@0=0PH04`P<01052@0F2`lDooooo`006oooool090093PX04AHB02<X900[
<2`082DQ00X?2`0=4Ph03Q<?01lT800N8al0314=00lD400;3@X02P`9024S80092`P05QPE00X<2@0@
4Pl03a4>01@F4`0>40d051HC014C3P0=4`X03aD<00L=100D6A807b@N01LL5P0>4`d03A8=01@H500;
3``04QHD00dB3`<03@l<00@03a4>010B3`0A4a003a4>0P0<3P/200lA3P0300h@3@0A4`h03Q0;0080
3Q0;00D03@l:00/=200?4@`03Q0;00d?2P0200`>2@0400h@300@4Pl04A<@00h@3@8030h;00L0418?
00`>2`0?4@h02`d:03/m>P13AD80418>00803a4<00@03@l:00/=200;3@P03@l:0P0<3PT04P0=3`X0
3Q0;00lA300?51002Q0>00@81`0?4a801`/:01HH5@0?4@h06Q/I04]<A`0E5Q403a0;00`=1`0G61<0
3Q0;00lA308030h901<03Q0;00lA300@4Pd04A<>00h@2`0<3PT03@l:00h@2`0C5A004Q@?00/=200=
3`X0418=00lA300=3`X030h900d?2P0>40/03@l:00H04A8=1P0>3`X0;@072@@03Q0;00lA30082PD0
3@l:00lA30051`804Q@?01<E400@4Pd07AlJ00l@2`0>3@T03``900h?2P0<3@P041@>00870P093PP0
@D@o02T[9P0l>cT08AlK01lN6P0@4Pd03a8<00hB300G6A@07b8M01HL5P0V;2D08BLQ01dU7P0?6100
3AH?00dD3@0];bX06Q/F00`=200?40/0414<00/<1`0?40/04A8=00l@2`02010A300F00d>2@0<3PT0
0P@100T;1P0>40`03Q0;010B3@0;3@P03@l:00X<1`0<3PT03Q0;00/=200<3PT03a4<00`>2@0:30L0
5aTD014C3P0>40/03a4<00h@2`8030h901P03@l:01@F4`0<3P/020X7010B3`0:30T03Q0=00d?300@
4Pl03a4>00d?300>40d04Q@B00lA400D5QD02P`;01DG5P0=3`h04A<B00X<2`0>40l04A<B00d?3P0A
4a8200`>3@0501XL6`0:30/0418A02DW9P0D5QD01@0>40l0100?4@l03a4>00lA3P0>40d200lA3P03
010B3`0?4@h03a4>00<03a4>300>40d03`0?4@h03@l<00lA3P0?4@h03@l<018D4@0C5A804A<@010B
3`0C5A8051HC01DG500>40d0418?014C400200h@3@@0418?0P0?4@h0=00>40`04Q@?010C3@0>4@/0
3Q0;010B3P0B51004aDB00d?3@0=3`h03Pl@00l@4@0E5aH03a4>01DG500B51405aTF01<E4P0G6AH0
3a4>01<E4P0?4@h061XG018D4@0>4`l06AlM04I?C00G81d03Q8@01TN700;4@l04QHE014D4`0F61L0
5ALF018D4`0C5A@051HG03Pl?@2=TI8051PI01dQ8P0=4A80<3@e0414A@0F6Q/04aLH010D5@0F6Q/0
4aLF00hB4@0@51<201@H5`0>018F5@0C5aH07B4P00hB4@0G6aX04QHE01<G5P0F6ah0>Sm201hS9P0F
6ah06QlR018G6P0E6Qd201HK7P805a`O01`05AdO01lW:`0V;c<06bDX02lj?@0G8R@072PZ01PV:00M
;2h07Rh_01d];P0R<S<09SXh01he;`0O=S00;4<m02U0>P0W?SP0:d8l0317@@0jDD/0:T4k0399@`0Z
@C/0;dE003=8@`0bAd80;d@o0P0Z?cX09P0cB4<0;T<n02@i=00W?3L0:Chi02Pm>00U>c<09clc02U0
=`0T>c<09C`e02Dl=`0U>cT09S`j02Hk?00U>Sd09S/n02Ll@@0S>3/09c`o02Xo@P0W?3l09CXm02Pm
@00^@dH08SLj02Tn@@0W?3l0:Ci102]0@P0U>cT0>Dm;0398AP0S>CH0;D=102Hl>@0Z@3d0:3hk0P0[
@Cl03@0Y?c/0;490055WI@0]@d40:d4o02e3@@0/@T00<4I402]1?`0/@T00;dE30316A00_AD<00P0^
A440200aB480<4M102e4?P0^A400<TQ502a2@00cBDL0=D]90P0cB4T0100eBdT0<DU30318@00cC4<2
03Q?A`0c03=9@P0gC4D0A5QA02Xm=`0_@S`0C5iH03I7?`0[>bh0;3h_02do<`0^?cD0;T0j02`o>`0Y
?3X0=TY80355@`0]@D00=DY703I;AP0hBdD0>T]803E8AP0gBDX0>4Y>03=7B`0V>Sl0=TY>03iDE`0j
D500>E1>0357A@0iCDh0@eMG0355A@0jCTd0B5aK03]?CP1<H5h0?U=?03Q<B@0nDdh0;D8l03M<A@0e
Bch0=D/o03Q>@P0fC400=T]103Y@A@0dBD00=DY30080=T]40240=T]503I:A`0hCDh0?E5B04EIF@1?
Hf80@eID03]>B`14Ee40A5E=03Q9@010DDL0@E5703I6@00iC4X0?dm>03m?C@0nCT/0>DQ402lm>00/
>S@0;SXd02lk=@0^>S<0;SPa03I4?P0eB4<0;d0j0390>`0`?3P0;SLb02dd;`0[<B`00P0Y<b/03`0U
<2L07b`S020Y8`0R:2@08BLS02@[9`0W;bX09c0[02Xe;`0X<bd08RhW024^9`0U<R/08BhW01dV8@02
01lU8@80728N00<082HR01XP700J81`00P0K8Ad07P0L8Qh072<N01`Q6P0O91`07B8L01XO6@0K81/0
61dH014F4P0I7QX051PG01XN7P0M8B4061`M01HK7P0G7R0051/M01DL7P0C6A`0:c8d0<;9b`1MI6H0
5A/N01LM800J8B<0318B01`N7@0G5aD061PF01LG5@804a8@00/06ALE01TF500G4a8061<B01PC4`0H
51<04Q0A014A4@0?3`l0820P00d=300201DE4`0A01@E4@0D5A004a@?01<D3`0B4`d03@h:01HF500:
2PL05aLF01HF500L71T07QhM014A3`0C4a003`l=01@D4`0@40l00`0A4A402`0@41003`l?00l?3`0>
3Ph05QHF00X:2P17AdL03@d=00`<300>3Q003`lA00@0410B0P0=3@l0100>3Q003`lA010@4P0@4186
00h>400601DE5`0I6A/0410B00d=3`0820X03Pd?0P0=2``00`0<2P/02`T:00/92P0200d;300500`:
2`0:20T02`T:00`:2`0=2``01@0<2P/01`0>30d02`T:01<A4P0>30d03`d>00H41@0=2P/00P0?2``0
3P0>2P/03@T:00d92P0G4a@081`M014=3P0B3Pl02`L801@@4@0?2P/03PP800d71`0@2PX04@/;1P0>
20P0200@2PX05Q0@01@>3P0@2PX03@L700`61P0=1`L01`820P0H4Q803`0B30`04@/;00l92@0;1PL0
5A0A018<3P090`D0G5IH014<3@0G4A<02`D700d72@090`D02P@600h82P0200d21P0300l4200@1@T0
4@H:00804PL;00D0308501`A5@0>0`L07A8F01<8300600l4200600X10`0G31004`P<00l4200C20`0
2@025?ooool001_ooooo00D02Pl;010E4@0L8Ad08RLS01XO6`0200/@300=00X?2`0A5Q804AHB014F
4P0O920061XG02/]:P082PL03Q0=0494@@0H6QL0418?00X<2@0200h@3@0@01<E4P0;3@P03149010E
3P0:3`P03A8;00hC3@083@L03a@>01DJ5P093PX07b@P00D9200830/0418?00lA3P@03@l<00h051HC
00h@3@0>40d04aDB01@F4`0C5A80418=00/=200:30L030h900h@2`0=3`X03Q0;00d?2P8030h900<0
3@l:00d?2`0=3``00`0>40d02P0A4a004aDB00P:1`0=3``03a4>01XL6@0T9R<051HB010B3@0A4`h2
01@F4@03014C3P0>40/030h900<030h900h03@l:00X?2`000P001PX900T=30072`X051HC00L91`04
1P<0<C8]00`=200;30L03a0:00h@2P803@l:0P0;3@P0200=3`X01`T400/=200?4@`02`d800T;1P0<
3PT02@/60P0=3`X02@0:30L03Q0;010B3@0;3@P030h900lA300>40/02`d800@60P0600d>2@H03Pl:
01X03a4<01<E400@4Pd03a4<01<E40082PD01PP3018D3`0620<04A<>00`>2@0A4Pd03@`8010>2P0G
61<03Pl:00X=20083@L03A8<02X^:00G6A@05QDA01hK600F4Pl01PD100l?2`80414<00h04a@?01@F
4@0F61<030h9018G4@0?50h041H?014F400A4`h06AXE014B3@0720<04Q<>02//9`803a0;00H03Pl:
014B3@0@4@`030d800d?2P0B50l200d?2P0>01LI50041P4030h901<E400=3`X030h900lA300<3PT0
2`d800h@2`0B50l03a4<01`N6@0:30L200h@2`803@l:0P0<3PT07P0>40d03@l<00L91P0620D030h;
01LI5P0>40d04Q@A00lA3P0;3@X030h;00P91`092`X05ALF00`>3@031@@02@/:01<E500:30/0418A
00d?3P0A4a802`d<01DG5P0F61L0=3He01hP7`0?4A00418A00d?3PD03Q0?00@03a4?00lA3P0?4@h0
3Q0=0P0?4@h0300>40d02`d:00`>2`0=3``03Q0=00lA3P0;3@X03@l<010B3`0A4a00418?00h@3@80
3a4>0`0>40d0400=3``04Q@A00`>2`0?4@h0418?00T;200<3P/0828O02<U8P0N81d04A<@01<E4P0>
40d03@l<00lA3P0@4Pl200lA3P09014C400?4@h0418?014C400>40d03@l<00lA3P0A4`h041<=0080
3a4<00H0418>014C400?4@h0418@01`N7@0M7ah2018D4`060043000D5Q<04Q@A00lA3P082PL051HC
0P0B51407@0I6aP0418?00d?300D6AD04aTG014J5`0M9R<06b4O00lE4`0G7A/04QHE010C4P0L7Qd0
8bDT01/M700@4Q402`l@01<G600X;2d0310A00/?400J7Ql02Ph?01DI6P0H71d0310A01DI6P0C5aP0
4aLF008041@C00L04aLF01@H5`0D61L051PG03/o?P0F6QT041@C00804QHE00L04aTJ00D:3@0E6Qd0
4aPK020U:00C61/05Q/N00805a`O01d05AXM01HK7P0E7Al07BD[01lX;@0_>3d0D5]O03Q3A@0O:bd0
8c4a01d];00L;2/07Rh[01`/:`0S=c<07SD_020g<@0]A3h0:d8l02Po>@0^ACl0=Da603mFD00[@S`0
;dI002U0>P0aAd40=4U403=8@`0202e2?@0<02i3?P17G5L0@5E@02Tn>@0^@ch08CHa01`a;00U>cD0
:3lg02Y1>@0W?SL09C`f0P0U>cP01P0W?C/09c`m028g>P0R=cX0:Sm402Ll?`808cPk00@0:3e002Xo
@P0V>ch0;D950P0W?3l05P0bAdX09CXm02]0@`0aATL0Fg5_05Y_K`0]@d409C/i0357A00[@Ch09cdj
02Hm>00V?CL09C`f02Po>@0bB4D0738`03E;B@0W?C/0:d4o0357A@0`AT@203M=B`80;D=104@0;dE2
0316@`0aB480<4M102i5?`0_AD40<4I302e3@@0cBDL0<TQ60356A`0eBT/0<dU703=:A00bBD40<dY2
03E<A00eBd@0=4U20315?P1@I5d09CPb02i1>`0nD4X09CH^02Ti;00Y>R/0:3X^02Tj<00Z?3H0:Sdi
02e0?P0iC4X0<dM50314@P0fC4L0>4e60394?00dACl0=4A103M7A`0fADP0<49603M9C@0lCe<0@5AE
03Q=C00iCdd0<dU703mCD`0[?ch0>De<03eAD00R=S@0=d]909jb/01NLfh0D6EP03eBC@0]@S/0=da3
03U>A00gCD40>4i203=9?@0cB3l0=da303=8?`<0=4U202h0>Di903a@CP1<HF40CF5R04mSHP1CIfH0
@eID03I9AP0iC4P0?Di803Y;@`0lCDD0>d]103E5@00iC4X0@51?03i>C00jBTL0=4=002Lf<P0X=c80
<Cdi03=0>@0^>c@0<Slh03a:A`0cAT80<44k03=2?@0_>cL0:34^02T`;00W;BT08B/S02D`:00W<RX0
7BXQ01`V800U:bL09R`X02L^:P0X<B`0:C8]02Pc;@0W<R`092lY0P0R;bP06@0Q;BH07RLR020V8P0N
92006AlK01LM6@0J81`08RPT024W8`0N92006R0L01TO6`0H7aT05a`E01dS6@0K8AL05Q/D01XO600F
6aD05Q/G01hS7`0F6QT061`M01LK700D61T00P0C61/0300>4aH061dP01HK7P0J7b805Q/N01LL7`0E
6Qd041DH014F6@0N92@05ALF01@E4`8061PF00X071/I02HU8`0K6QP06QLF01PD4`0G4a8061@C01LF
500V92D05QHF0P0>3Ph01@0>3Pd061PF01DE4`0E5A8051D@00804a@?00X04a@>01/L5`0C50l03Pl:
010A300?40/0Ngag0;>d[`13A3l04A8=0P0B4`h03P0>3`X03`l>014A4@0C4a<04Q8B00l?3`0=3@d0
410@00h>3P0H61P04a<C014A4@0B4Q803`lA0P0@4180100A4A<0410B00l?4@0=3@l200`<3P0300d=
3`0>3Q003Ph@00H03`lA00H02`/=00l?4@0=3@l03`lA00H6200;2P`200d;300600h<3@0=2``030X;
00d;300>30d03@/<0`0<2P/200d;30<030X;00P02`T:00`:2`0:20T05Q@E00l=3P0C4A802PP900l<
3@803`/<00l03PX;00d92P0=2@X071PI020L7@0300001P8301hJ6`19ADH0=2l_00`61P0=1`L03`T9
00h8200<1PH00`0>20P0100?2@T040X:018<300@2PX200l92@803PP801D03`T900/51@0E3`l040X:
00/51@090`<01`4102@N800500403@L901<=3`0I4aD030L802hX:P0G4A<040X<00l92`0>20X030H8
00d21P0?10P00P0A1PX0200B1`/05@X>00l4200D2@d0?S<g01hC5`0C20`04@H:1P0?10P01P0B1`/0
3`H800L0000A1PX03P<701D:3QCooooo000Kooooo`8020d901T02Pl;00`A3@0;40`020d900hC3`0?
51002Pl;00P=2@0?51006QlK00/=2P0G6AH02P`901DG500<3P`06Q`I00h@3@0=3``04aDB00lA3P0E
5a@04A<>00/@2@0?50d03A8;00802@h800T02Pl9010E4@042@D000@000P<2`0420L04ADD010B3`0>
40d00`0=3``03P0>40d05aTF00h@3@0<3P/04A<@018D4@0@4Pl03Q0=00`>2`0>40d04aDB01DG500D
5Q<03@l<0P0<3P/0100=3``03Q0=00d?300=3``200h@3@0300lA3P0B51404Q@A00802`d:00`030h;
00X<2@0>40d0418>00d?2P0>40/05QPC01TK5P0B50l03@l:00lA300>40/300d?2P0=010E4@0>5180
61`K00`@3`0:3Pd04A<@01TK600<3P/00@8000h?2P0@4@`02@X400lA2`0200h@2`8030h900D03a4<
018D3`0?4@`02P`700/=200300`>2@0600h@2`0;3@P02`d800lA300=3`X030h90P0?4@`00`082PD0
2`d801/M600600l@2`H03Pl:00<01`T400H80`0>40/00P0;3@P09@0R91l07R0K00/=20092`H03@l:
01<E400F5a8030/7014>2`0A4Pd03a0;00/>2@0<4@/03a@>00P<1P0;3@P04a8>02XX900@30T061@A
01LE4@0D4`l040l;00d<200A4Pd06a`G01@E400D5Q405QPC00hA30092`H01`P301HG4P0H6A@04a@?
01lP6`0f=c800P0?40/0200=3PT04A8=014B3@0;30L02`d800L9100F61<020X60P0=3`X0800@4Pd0
61XE00lA300;3@P0418=00`>2@0W:BH01`T601@F4`0>40d05ALD00X<2@0?4@h03Q0=00d?300>40d0
3@l<00`>2`0<3P`0418?01lQ7P0?4@h06A/H0001000=3``04Q@A00lA3P0:30T030h;01DG5@0E5aH0
30h=0P0@4Q402P0C5A@03a4@00/=300D5QD02P`;01DG5P072@P051HE00430P0G6AP200@61@03010B
4@0E5aH03Q0?00@03Q0?00@03a4?00lA3P0?4@h03Q0=0`0?4@h200d?30D03Q0=100@4Pl300lA3P0:
00h@3@0=3``03@l<010B3`0B51403@l<014C400J71T03@l<01@F4`807AlL00D03Q0=01@F4`0A4a00
30h;00h@3@03010B3`0i01<E4P0>40d0418?014C400>40d030h;00lA3P0?4@`0418=014C3P0A4a00
418?00lA3P0@4Pl04Q@A028T8@0S9B805ALD01@F4`0P8Ql05ALD00X<2@0E5a@04Q@A00h@3@0D5Q<0
4aDB01HH5@0?4@h05ALD014F4P000P004a`I00lH5@0D6QP03aDC01TO7@0G6aX051LF01TK6P0L7Qd0
5aTH01@F5@0;3a00310A00X>3`0N8R<02`l@014E5P0L82406alP00hB4`0D61T05QXK00861`0D61L0
4aLF00804QHE02005ATH01PL6`0T:2L0GV9Q02HZ:@0C5aH07B4P01lS8P0G7Ad06R0P01lU9@0=4a<0
4ALG01hT900F71`06AlO01PN7P0E6a/05Q`L01HN80073aH07BH]01lX;`0S;S807BPZ028^;`0^?3`0
830_01l_;00S=2h07BdZ02@h=0808SPe00X0:3hk02Y0?@0[@Ch0;D=002]1?P0gCDX0<4I303Q>B`0a
Ad@0=D]80P0fC4T03`0bB4D0=D]803=9AP0fC4T0;D=002<i=P0[@Ch0:Cll02Y0?@0]A3h0:T4k02]2
?00Z@3`09S`i02Dk>@0202Pn?00S02Ll?@0U>Sd09c`o02]0@`0`ADP0:Sm2024f>@0R=cX0:3e002i3
AP0/@D@0:3e002Hk?P0cB4/0:Sm202e2A@0P=CP0?E9C03aAD`0M<S<083Hd02To?@0X?S/093Xg02Ln
>00_AT00<TU103YAB@0W?CX0<TQ60767Q@15FeT0>e5?03=9A`0_AD<00P0iCdd0@00X?S`0:Clm0316
@`0cBDH0<DQ202m6@00`Ad40<DM302m5@P0`AT@0<TQ602i4@P0`ADH0=T]<0398AP0cBT80=4]103=:
@00bAch0<dPo03A9@00dB3l0<TDl02`m=@0Y>S807BhV02Lh;P0W=bX0:CX[02/m<@0/?C<0:cdg02Pk
=`0Z?C/0<DE20397@P0`AD00=Ta403iCBP0hB400=D@o03U8A@0mC4`0?De=03i=D010D5<0=dU;03a>
CP0gBTT0>Ti<03Q<BP0kCdh0;d=203iBD@0oDe40>De;049FE01QMW40?E9=03aAC00fBd@0?U=<045F
C@0iCT@203M=@@80<dPo02d0>4e40356?`0aAT40;d@o0315@00hCDP0?U9@051VI01BIVD0AUYI049F
E00jCD/0>4]803I9A@0jBdD0?Tm803Q9@@0fACh0=dM203a<B@0oCd`0?4a903M7A00_?c`0:3Pe02Pg
=00/>cP0<T4l0350>`0gAT40>dY60354@00dA440=D=102/g<`0X<Bh0:C4]02H/:00R:bH09c4Z02Pc
:`0Q;RD082XS02@]:00V;bX00P0W<2/00`0X<B`09S4[02@_:@0202D`:P0302<^:00Q;2H06B8M0080
728N01`06R0L01/Q7@0P9R809R`X02@Z9P0O9B406b4M01TO6`0H7aT06R0F01`R5P0G7A<0724J02DZ
8`0J7aT06QlK028W8`0J7Qd0720Q01dQ8P0M8B@082HV01lU9@0E6a/061hN01<I6@0@5QH07R@T0P0J
82001@0H7Qh04aTI01@J6P0B51<051HE00806A/J01@08b@S03De=@0K6AX06ALH01DC500F4Q<061@E
01LE5P19AdP06QXJ010@40030`<0?Cdl024Q7`0C4a404a@@01<D3`0B4`h04Q<=014B30804Q<=00/0
5aPB01TJ500];RP0e=G?0?oonP1NGeT0414;014B300C50h05QLB010@3`02010@400:014A4@0@4100
410@014A4@0B4Q807AdM00<30`0C4a<051@D010@4P<04A4C00@03`lA00h>400@41803Ph@0P0=3@l2
00h>40H03@d?00/03Ph@00X:30092@/0410B00P82P0<2``030X;00h<3@0?3@h03P`=00d;300400h<
3@0300d;300<2P/03@/<00803@/<00X030X;00/92P0;2@X030X;00T7200E4a@0IVAU014?40081PL0
3``=0P0?2``03@0>2P/03@T:00d92P0<20T0510A00l;300C3a002@D6014=3P0=20P03PP8010:2P0?
2@T00P0>20P300d71`0300h8200?2@T04@/;00803@L7100>20P07P0?2@T050h>00d8200=1`L03PP8
010:2P0>20X0100000h92P0A2`d0100001<=3`0R71h03PP:00l92`0>20X02P@600/51`0>0`L040D9
01872`0@1@T04@H:01@93@070000304502<H700M4QH040D900d21PH03`@800H06PlC00`21@090080
50T=00d21P0@1@TDooooo`006oooool0100=4Ph041DA00`A3@0>4`l200lD400@00hC3`0B5a<03a@@
00`A3@0=4Ph03Q<?010B3`0>40d03a4>00d?300@4Pl03a4>00L91P0U9b@0@48o018D4@803Q0=0100
314;00lD3@0?50h02a0:00dB3@0C61<02Pl;00X>300E6AL03a<C014E5@0I7A`04A<@00h@3@0=3``0
3Q0=0P0?4@h04`0D5Q<03@l<00`>2`0=3``030h;00/=2P0=3``04Q@A01<E4P0E5a@09RPU00lA3P0C
5A801PP601DG500;3@X05QPE00lA3P0G6AH00P0?4@h04@0:30T061XG04=5@P0U9b@04aDB00`>2`0U
9b@0GV1M01LI5@0?4@`02@/601lQ700R91l030h9018D3`0A4`h0418=00<03Q0;01H0314=00@:200=
4A002Pd<00X>3@0I6aP02`d:01DG500;30L03Pl;01<D3`0?40X03Q0:00`>2@0C5A003@l:00`>2@0>
40/061XE01@F4@0<3PT03Q0;0P0C5A0200lA300G00d?2P0>40/0418=00lA300:30L0418=00h@2`0<
3PT04Q@?030b;@0A4Pd05AHA01<D3`0H6A@04Q<>00l@2`0=3PT02``700d>2@0?40/03Pl:00l@2`0>
40/00P0?4@`06`0:30L06A/F04e?BP0Y:bH02`d900h@2`0:30T02`d800T:1@0>3@T04@h;00/<1`0@
4@`041@>010E3`0:3`T03A4;00`>2@0D4`l06aTE01LC400A3@X05Q4>01DA3P0@3PX04@l<01LF4P02
018B3P04018C3P0F61<04Q@?00l@2`803@h900<03Pl:010A300@4@`00P0>3`X04`0@4@`04A8=03@e
<00A4Pd0414<014C3P0:30L04A<>00d?2P0A4`h03Q0;01dO6P1TIV405aTD00h@2`0E5a803a4<02la
;P072@H00P0<3P/200d?300O010B3`0G6AH02P`900d?300<3P/03Q0=00lA3P0=3``02`d:00d?300>
40d05QPE00h@3@0@4Pl03Q0=00d?300>40d03Q0>00lA400<3Pd04A<B018D4`0A4a802P`;00lA400E
5aH03Q0?01HH5`092`X0418A00L81`0201@F5@0A01<E500<3Pd03@l>00lA400>40l03@l>00h@3`0?
4A003a4?010B3`0=3``04Q@A014C400?4@h05QPE00d?300A4a000P0>40d01`0@4Pl04aDB00/=2P0F
61D0828O01DG500B51400P0@4Pl07@0A4a00418?00h@3@0=3``02`d:014C400>40d0:R`Y08^=RP0i
>cP03@l<018D4@0D5Q<02P`901<E4P0?4@h03@l<01XL6@0L7Q/0418?01<E4P0B51404A<@010B3`0?
4@h0418?018D4@0C5A80418>00804Q@@00L04Q@A014C400?4@h04Q@A00lA3P0E5a@05QPD00804A<?
02002`d:010B3`0C5A805QPE018D4@0?4@h0418?01<E4P0B514051HC01PJ5`0<4@d06b4O00hG500;
51405adK00lE4`0<4Q004aLF010C4P0B51<051HE01LI600J71/04ADF01LK700A5AH03a<D01dQ8P0B
5QL051PI014E5P804aLH03L03a<D01XN7`0@51<04QHE01@H5`0B5QD08RHU01XN7@0B5QD092PW00`@
3`0G6aX06AdL00`@3`0F71`06AlO01<I6@0D6QX041HF01XP800F71`06AlO01PN7P0F71`06AlO01/S
9@0I8BP082T`01HO9@0I92P06B@V01hZ:`0O;R/05RHS01`]9`0S=2d0834Z02<g<`0W?C/0:3hk02Dk
>@0[@Cl0;dE30357A@0`AT@0=Ta903M=B`0mDe40>4i;03U?C00kDTl0?5=@03UACP0hCd`0=Da900<0
<DQ502d0;DE202Y1?P0Y@3d0:T4n02a2?P0_AD80<4I302]1?`0Y?cd0:Cln02e3@P0W?3d0:Sm2049G
FP17G5l0:Sm202a1A00Z?d80:d1302Xo@P0bAdX0<dQ;02Pm@00]@TD0:d13028g>P0`ADP0;45402i3
AP0V>ch083Df0315AP0V?3X0:Cll02Dk>00Y@3X0;TDm02]2>P0Z@CP0;dE202m5@`0nE580;TA203Q>
C00`AT@00P0_AD<01@0aAdD093Xh02Pn?00_AD80<dU60080=di800X0=4]50357@`0`AT<0=de;03A:
B00^A480;dA503E:B`0eBdT0<TQ00P0bB3h07`0bAch0<dLn03=7?P0dASh0<dDm02Hg;`0Q<BT09cL`
02hn=00T=2P09CHZ02/m<@0b@c/0:cdf02Pk=P0/?c`0;40k0397@00dBD80>4i4045GB`0b@cT0:3P_
02dl=P0^?CX0;cln03M7AP0eADH0<49203Q;B@0kCT/00P0nDdh03@13EeD0@UIE03]?C@0lD4h0>Di:
03U=BP0lDD`0>4e703U>A`0hCDH0@EI>03Y?AP0hCT@00P0iCd@0>`0eBT40=DY203Q=A@0eBT@0=DY5
0356@@0iCTX0@UIC03mCD@17GEX0C61N03a@CP0hC4X0>Te:03iACP0lCd/0?Ti:03i?B@0iBT<0=dI0
03Y:AP0jBTL0?Ti;03U9AP0_?c`0;Shk02hm>`0[>SP0;chl0392@00iBdH0>TU703U;B@0eB4D0AUID
03a:B00Y=C<0;3Dc02L_;00O9B807bPS024[9@0O:R<07b`T028^9`0N:28082XT02La;00Q:bD09S0Z
02La:`0Q:bH09c4/05QRG00g@C`08BXU024W8`0P9R807B<O00806b4M00@07bDQ02<Y9@0Q9b<07B<O
0P0N92002P0K8Q`07R<K01`Q6@0F71@0724K02<X8@0I7QT04QLD01LL6@0G6a/201TM7`0401hR9@0F
6a`05a`L01@I6@806AhN02806QlO01hS8`0D6AT05a`M01TN7P0F6a/06AdN01XN7@0H6aX04A@C01<E
500C51@08b@T01PG600F5AD0518C01DB4`0F4a@0518C030`<00I6AT06QXJ020P801XJ6L06a/I018B
400A4Ph0414<014B3@0A4P`03a0:010A2`0E5Q004a@>0P0H6A<0101<CDL0OWmi02`]9`0@4@/2014B
300301LH4`0B4Q403`l?00804A4A00D0410@018B4P0C4a<04Q8B00h>3P02018B4P0300X:2P0@4180
410B0080410B0P0?3a40100@41804Q8D018B500@418200h>400F00d=3`0>3Q003`lA00h>400<30h0
2`/=03Hf>00<30h020P:010@4P0?3a403`h@00d;30091`P04Q0A00T7200B414030X;00h<3@0?3@h0
40h?00h<3@<03@/<01`030X;00/92P0<2P/030X;00d;300A3a005Q@E085oP00B414040h?00l<3@0?
2``03PX;00d92P0<20T03@T:00X61`0C3a002PH700d92P0<20T04`l@00l:2`0?2@T04P`<014;2`0>
20P040X:0P0;1@D00`0=1`L03`T900l92@0200h8200700l92@0>20P03@L700`61P0;1@D03`T9010:
2P0200d71`0400h8200=1`L040X<00`720803`T;00@06Q@F00/61`0@2P`02PD60P0=1`T04@0>20X0
40X<00l4200?10P04PL;00/2100B1`/050T=00l4200A1PX03@@601072@0B1`/03@8601052@0E2Ph0
4PL;00803`@800<03P<700X10`0?10P00P0A1PX00`0B1`/030<5ooooo`0Cooooo`006oooool0200B
5a<03A8>00P=2@0010003Q<?010E4@0;40`03A8>0`0>4`l00`0<4@d0418?00lA3P0300d?300G00h@
3@0C5A805QPE02HX9@0;3@X04aDB00`>2`0=4P`03Q<=00dB300:3`T0314=00lD400@5A403Q8A00H:
2@0@51D09RX[05mSHP0A4a4030h;00/=2P0=3``00P0>40d09P0@4Pl03a4>00h@3@0>40d03@l<00`>
2`0@4Pl00`D201/M6P0A4a000`D202@V8`0`<Rl02P`90002000C5A80FeeJ03Xl>@0@4Pl00@<0010B
3`082PL02@/8038d<@0@4Pl0004001HH5P031@80=cTf01HH500A4`h010H104mAC01SIF007AlJ00P:
1`0?4@`03Q0;0`0=3`X01P0;40`02a4?01<G5P072`X03A4@01@F4`8030h;01003@h900h?2P0?40/0
3a0:014B3@0=3`X05aTD014C3P0@4Pd03Q0;00`>2@0>40/03@l:00`>2@0@4Pd04A<>0`0;3@P300`>
2@0;00lA300F61<0418=01DG4P0G6A@030h;00/<1`0@4@`030d800l@2`0>3`X00P0=3PT300h?2P80
3a0;00h020X5010B3@092`H03Q0;00lA300>40/020X5014C3P0I6aH01`T4024S7P1=CTT03`h:014>
2`803a0;01003A0;00/@2P0=4P`041<>00`>2@0>3@T03``900P40@0E40d07APE01HB3`0@30T04Q0<
01@C3`0=30P05ADA0P0L7AP0100E5Q4030d800d>2@0>3`X300l@2`0:00h?2P0H6A@01`P301/L5`2;
S8L03a0;0042000A4`h03a4<018D3`803Q0;01l051HA01<E400];bX00040018D3`0<3PT051HA00T;
200:30T03Q0=018D4@092`P04A<@00X<2@0@4Pl00@<001/M6P0A4a002@/800P:1`0?4@h06Q`I01/M
6P0;3@X00`D200d?300>40d03a4>00d?300:30T02P`:00804A<B00/03Q0?018D4`0C5A@03Q0?01LI
600C5A@01`T800lA400@4Q403a4@00`>3@0200X<2`0?010B4@0>40l030h=00lA400=3`h030h=00d?
3P0?4A0051HD01LI5P0B51403a4>00T;20082PL061XG00803@l<00T03Q0=01PJ5`092`P05ALD00T;
200I6aP09bTV01DG500<3P/00P0@4Pl06`0A4a00418?00h@3@0<3P/04aDB00h@3@0A4a0010H304M9
AP0I6aP030h;00/=2P0@4Pl04aDB024S800N81d06Q`I02HX9@0L7Q/01`T600`>2`0@4Pl0?T0m02h`
;@0@4Pl01@L400T;2002018D4@0601@F4`0F61D05ALD018D4@0?4@h04aDB0P0A4a002@0C5A004Q@?
00d?2P0B5140418?014C400C5A8051HC01<E4P0201@F4`0>01<E4P0D5Q<05ALD01@I5@000P007BHS
00TB3`001@<05A/I018H5P0B5QD04A@C014C4P0C5A@201@F5@0301<G600@51D03A4B00806alP00@0
6QhO018F5`0B5QL04QHG0`0A5AH03P0G6aX05QXI01TM700B5QD0720O00hB4@0H71/051PG01<G5P0E
6AP05QXI01DI600D6QX06AlO0P0L8R80100G7Ad05A/K01@J6P0F71`201DK6`0;01TO7`0J8R@05AdS
01LP9@0E7b405R4T01PS9@0M:RT07RdZ020a:`0V=c400P0Y>S803@0S=S809cdk02To?@0X?S`0;dE3
03=9A`0eBdT0?59@03iDDP0oEE<0AE]I04ILFP14FeT00P13G5T01011FUL0?5EB03]DD@0fCd`2035:
A`050319AP0]AT<0;DI302e5@P0^A4800P0_AD<0700^A480;49002Pn?@0Z?d009S/l02Hk?P0dBD`0
@eQK04IKGP10EEP0;T=602Pm@00U>Sd0<TM:02<h>`0[@4<0;D9502Tn@@0aATT0:d1302e2A@0_A4D0
:Sm102Dj>`0`AT@0:Clm02Y0?@0W?CX202Po>@0902Hm=@0]A3`0<4I302a2@00_AD<0;TA202m5@`0b
B4H0>U1>0080<DM501P09cdk02e3@@0]@d00;48o03E<AP0fCDL0<4M102a3?P0`AT<0=4Y803]AC`0l
DU00>Tm@03A9BP0/@T00<4Dn0397?P0aASd0;d@k02a1>00[?cH0:CXb02dn=P0P<BT2028a:P0K02Xj
<00W=b`08c@X024c9`0[?3@0:C/d03A7@@0fBDD0>De703M<@`0_A3/0=D`o051VF@0iBSl0;Shd0310
=P0/?3H0:c/h03A4@`0gBDP0>4]903U<B00kCdX0?55:03eBB`0kCd`0>4a:0080?E5?00h0=T]603A9
A00lDD/0=T]40356?`0eBT40>Di503M<@`0hCD@0>e1703Y?AP0gC4<0=da503Q=AP80?E9=01X0>Tm:
04AHEP16FUP0?E5?03aBC`10E580>4a:03E9A`0dAd<0=DQ403a?B`0oCd`0?4e803i?B@0mC4L0>TY6
03E5@P0hB4D0<T8o02`l>@0^?S/0:c/i02Ph=`0a@D00;T4o03U<BP80;d9000`08cHd0351@00[>CL0
8Bd[02Tb<@0X;bh092XX028[:00R;2H072LQ01`Y8P0P;2D201dX8P0N02D`:P0^>C<0:C@^02`e<00R
:bH07bPS05aUH00b>cH082TT024W8`0O9B40728N01XP700L8Qh07bDQ020V8P0L8Qh06AlK01`R7P0M
8al06AlK01PM5`0G71H05a`H01TN6P0K81`05QXI00hB4@0=4A804QHG0P0F6Qd05P0M8B@09RX[028V
9`0J7Ql05QXK01@H6@0@51D0Ngn002da<P0830d061`M01@H6@0Q9BH03Q8A00lC4P0@51<04Q@C01dO
7P0?4A005ADE01@C4`0D4Q<201DC5006018@4@0G5aL04A4A010@400A4A4071`K0P0G5aD07@0D5140
4A8=014B3@0A4P`03Pl901DF400P8A/06Q/E018C3@0@4@/03a0:024R700D5@l03Pl9014B300H6A<0
4Q<>01@D4`0?3`l04a<C018B4P0>3Ph0410@00T92@030`<02`/;01@D500A4A404a<C00L03`lA00<0
4a<E01@D5P0A4A<00`0=3@l03P0?3a40410B00l?4@0<30h02`/=05eMG`0d=3H04Q8D00d=3`0A4A<0
0`8300l=3P0U8b@0<2h_0P0N71d0100<2P/03@/<00h<3@0>30d200`:2`802`T:0P0=2``0800<2P/0
2`T:00P61`0?3@h00@0001`J6`091`P07A/L014>3`0:1PL02`L801<?400F4Q<040`=00/7200A3@h0
2PH7014=3P0810D0=C4b010;300=1`L03`T9010:2P0=1`L03`T900/51@0:10@02`D500d71`0?2@T0
3PP80`0=1`L500`61P<02`D501P030H605==C`0W8B<03`T;00L10`0:10H04P`>00/51`0?2@/03PP:
00`6200>20X03@L901052@0800404@H:020E6@0Y7R804PL;00h31`0E2Ph02`0401H;3`0>0`L200l4
200601<8300?10P03`@801<8300?10P03P<70`0?10P201052ACooooo000Kooooo`0800T>2P0:3`/0
5a`H00L<200F6aL0314=00/@300=4Ph300hC3`0300dB3P0@4Pl03a4>00<03@l<01H03Q0=01XL6@04
1P@00`D201<E4P0a<c009bTV00`A2`0=4P`02a0:00X?2`0<4@d03A8>00X>3@0F6Q/020`=014E5P05
2@X0720O00lA3`0;3@X02P`90P0=3``00`0<3P/03Q0=00h@3@0400h@3@0700lA400@4Q400040010B
4@0[;B`0004000T:2@0201<E500G010B4@0E5aH0418@00d?300620D04aDB00`>2`010`004aDB01LI
5P0D5Q<0=CLd00lA3P0<3P/0418>00`>2@092`H061XE01TK5P0B50l05QPC00lA300>40/00`0=3`X0
3`0A5Q800@L500`@3`0B5QD04ADD0001000@4Pl030h;00d>2@0>3`X03a0;00l@2P0@4P`02`d8014C
3P0200lA300300/=200:30L03@l:008030h900<0418=00lA300;3@P00`0;3@P200X<1`0600<5000@
4Pd020X50001000G6A@04Q@?0P0?40/0600=3PT01`P301<D3`0I6QD03Pl:01@E400A4Pd03@h9018C
3P0?40/02@/600h@2`082PD04A<>00h@2`0620<02P`700/=200=3`X0004003Tk=P1fMg803Pd900l=
2@803@h901H02`l900X?2@0:3`T04A@?00h@2`0>3@T04@h;00l;200F4Pl05a<@010<2@0:2@D03Pd9
00l>2P0=3PT04a@?01TJ5@0H6QD04Q@?00`>2@0@4@`03a0;100>3`X2018C3P0700h?2P0S91l02``7
01HG4P0@4Pd03a4<014C3P0200h@2`0=01<E400g>C@0004000/=200I6aH00@<0010B3@0<3P`03@l>
018D4`0?4A001@L601<E5002018D4`0;00X<2`0>40l00P@301`N7@0G6AH030h;010B3`0D5Q<03Q0=
00/=2P0=3``00P0>40d00`0<3P/02`d:00`>3002010B4@0:00h@3`0A4a804Q@C014C4P0210<00081
01XL6`0C5A@01@L600P:2@803Q0?00@02`d<00h@3`0>40l03@l>1@0>40l00`0;3@/030h;01DG5002
01LI5P0=01TK600@4Pl03a4>01/M6P0?4@h04Q@A010B3`0A4a0030h;01<E4P0J71T04Q@A00/=2P03
00lA3P0M00h@3@0=3``030h;01`N6`0=3``05ALD00H81@082PL04Q@A00lA3P0=3``0418?00lA3P0J
71T05aTF01<E4P0F61D0418?00T;200>40d05aTF01hP7@0G6AH03Q0=00lA3P0E5a@06A/H00lA400D
5QD00P0G6AP02@0B51803Q0=018D4@0A4`l04A<>018D3`0A50h03Q0;01<E4P02018D4@0L01<E4P0D
5Q<04Q@A01@F4`0C5A804A<@018D4@0D5Q<051TE01`R8014CDX07BHS00@:200C6AL02Q0>018F5@0D
5aH05ALF01@F5@0E5aH061XI00`@4@0R9RL01`/<01@H6@093@h05ATJ01@H6@804aLH00H04QHG014E
5P0A5AH04ADD00/?3P0D61L201HJ6@0401PL6`0F6QT05a/J01LK6P805ATH00P05QXI01PN700@5Q@0
5Q`J01PN700F71X06R0N01DK6@805adK02805Q`J01LM6`0G81l051dP01<M7`0E7b005B0Q01`X:00O
;B/072/X020`;@0Q<R`08S<]02<d;P0P<c009S`j02To?@0[@Cl0<TQ603I<BP0hCT`0?E=A045GE@14
FUP0Bf5O04eSH@1:HUl0BV=P04URG`16Ge`0@U]H03mHE@0iDTl0=4e:0P0cC4T01`0aBTL0<4U60317
AP0_A4D0;45202Xo@00[@4400P0/@D80G@0Z?d00:Cho02a1@P0L<C80;T=403aAE00dBD`0:Sm202Tn
@@0X?D00;T=602]0@`0_A4L0:Ci102i3AP0U>Sd0:3e002Pm?P0/@T00:T0o02@j>00Z@3h0:3hl02To
?00X?S/0:d4m02U0>P0V?CL0;D@n03mEDP0[@Cl0>U1>02i4@P0`AT@0>U1>0316A00]@d40;TA202Lm
>`0cBDL0=D]80316@`0bBD<0<4M102m6@00`Ad80=4Y703I<BP0iCdd0<TQ60356A`0eBT/0<4I402i3
?00dBCh0<dLl02e1=P0Z?C80;Chd02<d:P0W=bd08C4W028b:00N;R@0;3`b02Lg;00Y>Rd09CL[02Xk
<`0Z?3D0=dY403E8@P0]@CX0:3dd02Dk;`0W?S40<DPh0396=`0[?C40;Chd02Tj<`0X>3D0;D0l03]>
C00jCT`0>e1;03]AB`0kDTX0?5=;03M<B00kCdd0@5AB03]@B`0203A9A00703aABP0fBd@0<4Dl03=8
?`0eBT40<TLn03Q=A00203]@B@0=03Q=AP0hCDP0>Di903aAC00iCD/0>dm=03mCD@0lD4h0>4a:03U@
BP0mDTd0=da703A9A00203=6@P0n03Y=B@0oCd`0?dm<045ACP10Cd`0?4]703Q7@P0hAd@0<d=003U9
AP0jBTT0;d0o02Xm>`0cADD0=DU803iBD@0aAD@0?U9@03U<BP0dA4<0;C/k02Te=@0c?3/0<3Lg02L]
:`0R:bP092hZ024/:00P;BH07R/T03A1>P0mBT<08BdV01lZ900Q;2H0:C8]02D^:@0O:2<0<3Hb01lU
8@0Q9b<08RPT020V8P0M8al06b4M01`R7P0O9B408BLS01dS7`0J81`0728N01dS7`0I7a/07B4P01XN
7`0I7Ah06QhO01LK700@51D04ADF00dA500@51L201HJ7@0401XN8@0U9RP08B<R01XL6`<05aTH01X0
D59A02T[:P0H6QT0:2XY01PJ6@0F61L08BDV01DI6P0I7Ah041@E01lQ8`0<3@l05AHH01<D5P0C4aD0
51@F01@C5P0B41<071`L010@400A4A40410@00H61@0K6aT071`J01LH50804Q<>00D04A8<00l@2P0?
40/05AHA01<D3`02010A300C00d>2@0C50l04A8=00d>2@0A4Pd07AhI018C3P0H61L04A4A018B4P0A
4A403Ph>00l?3`0H61P04a<C01@D500K6a/00`<3010@400700l?4@804A4C00D03`lA00h>400?3a40
30`>00h>400200l?4@803@d?00h05aLI00000P010@<03`lA00/;3@0G5QL020H700d;300A3a005aDF
00`:2`081PL03@/<00`:2`<02`T:02H02@L800`:2`0B41404a4B00d;300;2@X030X;014?40010000
3`d>0040000C4A803``=00`82@0>2P/07a/L02DQ8P0H51D04@d>00/7200300004Ph?020L7@27Ph@0
>C@d00d71`0?2@T040X:00d71`0?2@T040X:00d71`0;1@D030H600h8200@2PX02P@400/51@803PP8
00@03@L700`61P0<1PH030H60`0=1`L07`0<1PH04`d?00D00@0<1PP03`T;010:30090`D02P@600l9
2`0A2`d040X<014;3@0=1`T02P0300d21P0I3Q8060dA01X?4`0>0`L02@0201<830070000714E00P0
0@0@1@T04@H:00d21P0:00<03`@801D:3P0>0`L00P0@1@T300l4200300h31ooooooooooo01;ooooo
000Kooooo`07014F4P0<4@d02a0<01HK5`0U:RH08RLS00`A3@0200dB3P<03Q<?00<0418?00lA3P0=
3``00P0=3``05P0>40d02`d:010B3`0F61D051HC02DW900Y:bP0314<00/@2`0:3`X02a0<00/@3@0<
40h0310?00X>3`0;3a002@d?014E5`0:3Pl03a4?00d?300<3P/200lA3PH03Q0=01h03a4>01<E5006
20L06adL00lA400@4Q404aDD00/=300=3`h04aDD00h@3`0=3`h0418@00h@3@0C5A803a4>00/=2P0A
4a003Q0=00X<2@0B51403@l<01<E4P0<3P/03a4=00X<1`0>40/0418=00/=2@0?4@`200h@2`0D00d?
2P0<3PT03@l:00d?2P0>4Pl0BDm=08F9R00H71/03A4@00/=2P0?4@h030h;00d>2@0>3`X03a0;00l@
2P0<3@P02`d800lA300>40/200d?2P0600/=200>40/03Q0;00h@2`0A4`h03a4<0P0@4Pd0900?4@`0
3Q0;00h@2`0=3`X08B<N06QZI@0D5Q802`d:00`>2@0@4Pd04A8=00l@2`0B4`h01@H101HG4P0K71L0
3@h901HG4P0B4`h03@h901LH4`0B4`h02`d8018D3`0=3`X03a4<00X<1`0?4@`03Q0;010B3@0620@0
418=00/<200J6aH040l;014>2`803@h901003A0;00`A2`083@L041@>00d?2P0<2`L040d:018>2`0D
4@h04a0=014@300B4@d04A4=00d>2@0B4`h03a0;0P0:3PP01P0=4@/04A<>01<D3`0@4@`03Pl:00d>
2@803a0;00@04A8=00h?2P0?40/0414>0P0=3PT200h@2`0I00d?2P0<3PT03@l:00lA300D5Q802P`7
00lA30092`H0418=014C3P0@4Q403Q0?00L9200?4A003Q0?014C4P0B51<01`T8014C4P0@4Q402`d<
03m1@00O8Ah02P`900P:1`0200d?300300h@3@0?4@h03Q0=008030h;00<0418?014C4@0?4A00100?
4A002@0B51<051HE01LI600;3@`02@/:01<E500@4A004aDD01DG5P0200lA400I014C4P0?4A003@l>
00lA400@4Q403a4@00d?3P0?4@l02`d:00lA3P0:2`T071hK038d<@0N81d04Q@A01dO700?4@h04Q@A
00h@3@0=3``03a4>00d?300>40d04aDB014C4003010B3`803a4>02003Q0=00`>2`0?4@h09RPU00lA
3P0H6QL04aDB00lA3P0;3@X03a4>00X<2@0@4Pl03Q0=00lA3P0<3P/04A<@01HH5@0A4a003a4>01<E
4P0B51404A<@018D4@0@4Pl030h;00lA400@4Q804A<C014C4P0@4Q003a4>010B3P804Q@?00@04QD?
018D3P0@4``05ALD0P0C5A8201@F4`03014C400C5A804Q@A0080418?00H04aDB01<H500F71X041LD
010I5P0D6QP201<I5`0800lC4P0D5aH05ALF018D4`0D5QD061XI01HJ6`1IGEh201LK700300`@4@0J
7Ql05a/L00805QXK01405ATJ01@H6@0D61T06AdL00dA400O8b809b/Z018F5@0G6aX05ATH01`P7`0M
8B0061`K01@H5`0E6AP05Q`J01<I5`02028X9P1901@J600F71X061hL01TO7@0J81h06b4O01TO7@0G
81h06B8R01TS8`0O:BL06RHU020/:`0X=S@082l/020`;P0S<c40:3Td02/k>@0W>SP0:3dm02]0@00^
A4<0<TQ703M=C00lDE40A5UI04]PH01CJ6P0G79a05idL`1KLg40F75_05E^K01@JVP0BfAR04IPGP10
FUP0>UAB03M@CP0dCT`0<Ta:031:B00_ATH0;dA602e2A00[@480:Sm102]0@P0]@T@0<DI802]0@@0a
ATL08CHg02Xo@00X?D008SLj02a1A00_A4L0<DI902Pm@00]@TD0=4U<055VJ@0eBTd0D6EX0397B@0V
?3T0:Clk02]1?P0W?CX09C/i02To?00202Lm>P0N02]1?`0`AT<0<DQ302m5@P0aAdD0:Clm04YPGP0d
BTP0>e5?0398AP0_AD<0<dU70357A@0_AD<0>U1>03Y@C@0gCDX0<DQ202]2?00]A3h0<TQ403E;B00e
BdT0>4i<03A:B00eBT/0>4e>0398A@0]@S/0;d@i0P0aACX0=00a@cT0<44g02Lh;P0V=R`093@Z02/i
<00U<bX0;C`a02Hf:`0_@3<0<T@h03a=A@0bA3d0;D0j0396?P11ETd0@UQ<03E;?P0Y@C40;4<b02Pl
;00Y?Bl0:d0c02a0=P0_@cd0=4Y403U?BP0jD4X0>E5903YCB@0kE4T0?5=904UNFP0nDTl0?55=03U>
B@0fBdD0>Di803]@B@0hCD@0=4U003Q=@`0jD4D0=da303eBBP0mDT/0?55:03Y?B00gC4L0=T]603M<
B00dB4H203U=B`0d03E9A`0fBTP0=Te703A9A00bAd80<4E00395@@0fBDD0?E1<03m?C@0mCD/0?dm=
03m>C00kBTH0=dI103A3@00`@3d0@U9?049DDP0`@d40:3/j0355A@0hC4`0@5AD03=7B@0fBDX0=DM6
02Ti>@0Z>3P07BTY02Pa<@0X;bl08RPX01dV8`0S;BX09S4]02Lc;P0Z=c40?de604EBB`0Y=Bl08blY
024/9P0O:2<092dX02`d;`0P9R8092XV02H/:00Q9b<082HR01dS7`806b4M00@07B<O02<Y9@0P9R80
7B<O0P0L8Qh03P0L8Ql061`R01TK900J7BH05APP018E700K7R@061/Q01@G6`0H6al07R8U01XN8@0D
61X06Q`K0P0H6QT0400J71/06adL01XL6`0H6QT051HE02<U900A4a806Q`K01dO7P0Q9BH0;34a00lD
5@0K7b004aHG01TK7@0E5QP201@D5P0M01DE5`0E51L04a8D010@400F5QH02PX:01`L700K6aX02`/9
01TI5`0E5A804A8=018C3P0C50h04A8=010A3@0@40h04A4>01<C4P0C4a40410=00l?3P0D5180410=
00/;2@0C4a807AdL01XJ6P0D51@00P0@410200h>3P0601<C4`0<30`030`<010@400A4A403Ph>200?
3a40200>3Q003@d?00h>400@41802`/=00d=3`0>3Q003`lA0P0>3Q003P0D51H0;Bd_01HF600>3Q00
2PX<01dL7@081`L03P`=00X82@0>30d01@@4018@4@0?3@h03@/<0P0<2P/01@0=2``030X;00l=3P0E
4a@04a4B00803@/<00L03P`=00l=3P081PL04a4B00P61`0>30d03P/<00803@T:01405a<D01/G600D
414030P9010<3@0<20T03PX;010<3@0L61T04@`<00d71`0?2@T040X:00d71`0?2@T04`d=014;2`02
00l92@0:010:2P0?2@T02@<300/51@0>20P040X:00l92@0=1`L03PP800l92@804@/;00<040X:00l9
2@0<1PP00P0@2P`0100;1@L030L800X51P0>20X200d72@03018<3P0F41803`T;00804`P<00L03PD7
00/2100@1@T0304501462P0B1`/0;24U00804@H:00T03`@801872`0?10P03`@801052@0?10P03045
01462P0@1@T00P0?10P00`0>0`L03@86ooooo`0Cooooo`006oooool02@093PX03A8>00P=2@0b=c<0
ADY605=HE00B5a<041DA00dB3P0200/@300300X?2`0@4Pl03a4>00<03@l<00P03Q0=00P:1`0?4@h0
5ALD00/=2P072@H02`d:00dB3P802Pl;00l0314=00`@3`0;3`h03Q8A00451P0D61T02`lB00`@4`02
1PL03a4?00d?300>40d04A<@010B3`0?4@h01P0>40d07P0?4A004Q@C01TK6P1mOgh0004000lA400=
3`h030h=00@61@092`X03a4@00X<2P082PL02P`900d?300C5A804Q@A00T;200?4@h03Q0=00`>2`0>
40d00P@1010B3P0<3PT03a4<00D7100210004A<>018D3`<030h90P0=3`X03`0I7AX0PhV70<G9b00R
9RD01PX901/M6P072@H030h;00d>2@0>3`X03a0;00l@2P0C50l06A/F00h@2`0200`>2@0500lA300:
30L03@l:00`>2@0:30L00P0=3`X200h@2`@03@l:02000P@001lQ70051`<06Q`G01DG4P0A4a003@h9
00h?2P0@4@`02@X5014B3@0?40/030d8018C3P0@4@`03@h901@E400A4Pd03@l:01@F4@0@4Pd03@l:
00/=200N81/00@<000/=20000P004A<>01@F4@1KG5L04A0<014>2`803@h901003A0;00dB300730H0
3A0;00/=200=30P04a4=01@@3@0>3@T03`h:01HG4P0H6A@04Q<>00h@2`0=3`X03a8=0P0@5@l0100>
4`d02a0:010B3@0@4@`300l@2`09010A300B4`h03@h900T:1@0720<04A8=01@E400?4@`04A<>0080
3@l:01d0418=00lA300D5Q405QPC00/=200A4`h05ALB00P:1@0>40l04A<B00T;2P0>40l02@/:00P:
2@0<3Pd05QPG014C4P0@4Q4020X900D71P0<3P/02P`9010B3`0B514030h;00/=2P0<3P/04Q@A014C
400200/=2P0?00lA3`0>40l03Q0?010B4@0=3`h030h=02LY:00E5aH0418A01/M700<3Pd0418A00`>
3@0@4Q404Q@C00803@l>01T03a4@00h@3`0=3`h03a4@010B4@0?4A003@l>018D4P0B51404A<@00X<
2@0@4Pl071hK01PJ5`0;3@X04Q@A00h@3@0C5A8051HC018D4@0E5a@0418?00/=2P0@4Pl03Q0=0080
4A<@01D0418?00lA3P0@4Pl04A<@01@F4`0A4a00;Bl/00h@3@0L7Q/03a4>00h@3@092`P0418?00d?
300A4a004aDB01HH5@0@4Pl03a4>018D4@0A4a000P0?4@h03P0=3``02`d:00h@3@0B51406Q`J01<D
5P0A4Q@03a0B00lA400B51805ALD00h@2`0A4`h04Q@?0P0A50d01`0B5@h051HA01<E4P0C5A8051HC
01DG500C5A800P0A4a02018D4@0C01<E4P0A5Q805Q`J01@M6P0?61D041HD01<I5`0>518041@C018E
500C5A@04Q@C01<E500F61L0310A024U9P062P/04QHG00H:2`06018F5`0F01<G600;3`h04ADD02da
<00a=C@06alN01@H5`0R9RD06alN01DI600A5A@051PG01LK6P0C6AL061hL02@Z:00S:BL051XH018H
5P0G7A/05A/I01HL6P806AlM02005QlL01HP6`0G8Qh06RDQ01LS7`0J9R@07bdZ01DT8@0L;2/0:SXi
02<c<P0V=SD0:Sdm02Xo@00]@T<0<dQ903A9BP0iCTl0@UMH04mTI@1IKVl0IW]l07:7R01dRHX0LHV9
06^5Q01UOgh0GWQg05I`K`1?JFP0AEmN03aFE@<0=U1?02X0=4i=0318B@0_A4L0;dA702i3AP0[@4<0
:Sm202]0@`0cB4/09c`m02Dj>`0[@44093Tj02m4A`0S>3/0;D9502Pm@00`ADP0;45402<h>`0B9bX0
?E9E02Pm@00_A4L0:3do02To?00V?CL09chh02Y0?@0T>SL0;48o02Y0?@0Y?c`093Xh02Lm>`0`AT@0
=4U902Lm>`0/@T00?E=A02Y0?P0gCD/202]1?`0Z02m5@`0/@T00=4Y803A:B00aAd@0>Dm<03=:A00]
A3h0;TDo03=9A@0fC4T0>U1>03E;B@0nE580@5EF03=8B@0]@d00<4@k02a0=@0[?c@0;T8g02`n=00U
=R`08c<Y02Ti;`0S<bT0;CXa02`i<00/>Bl0;Cd`02m0=00[?C40>4U103A6?`0[?SP08CD/0397?@0a
AcX09S`_02Dm;00/AC80:T4_0P0]A3@02`0]A3L0<TU103M>AP0fCTP0=Dm603I@A`0hDTL0>E=603UC
B00oEDh0=T]60080>4e801H0<TM00315?P0fBd@0=DY103=8?`0iCd<0?UA803]AA@10EDh0?E9;03aA
BP0kD4T0=da703A9A00iCD/0>4a:03M;B@0iCD`0>Ti=03]?C@0dBd@0;T<n0P0`AD00:`0cAT80>Te9
041CC`0oCdh0>DU803Y:B@0kBDT0>TU603A3?P0a@3d0:cXg03A4@@0gBTP0<4A202Tm?00aADH0<DI7
03=8B@0Z?d80=T]<03e?C`0L;2`08c4a01DQ8@0T;2h09B`]028X:00M9R<082XV020[9`0Q;BT082hX
01`[900N:b@07b`U02@a:P0R;BL08b`W028[9P0W;BT07R@P028X900S:2@00P0O9B401`0M8al06R0L
01XP700J81`082HR01hT800I7a/00P0F71P08P0H7Q`06Q`Y01/L;P0P8C806A/Z01<E8P0T9c405APQ
01@G7P0M82D08bLZ01hR9@0I7Ah05QPG01LI600J71/071hM01/M700F61L061XI01`N7@1dMWD0>cdl
01XL6`0R9RD0WJ6R0;:h^00D6QX06AdN018F5`0E6AX05QLI01@E5`0D51H201DE5`0>018B500D51@0
5QHF00l?3`0B4Q80410?018B400@40h03a0<010A300C50l051D?018C3P0H61H301<C4`803`l?00T0
30`<00h>3P0<30`071`L00410@0I6AT05aLG01<C4`0>3Ph00P0?3`l01`0<30`0>CTi02LW9`0L71`0
30`<01`L700410@01P0?3a4300d=3`0300`<3P0>3Q00410B00<030`>0`0=3@l0300410H0<S8d014A
4`061PP03Ph@00d<3@0;2@X061HG00`:2`0D4Q<05A<D018@4@803`d>00<03P`=00d;300>30d00P0<
2P/01P0>30d02`T:00T7200;2@X03P`=00d;30<02`T:01/030X;00h;300?2``03@T:00X61`091@H0
30P9010<3@0H51D02`L800<0000F4Q<00`0001HA4P0=1`L03`T9010:2P0=1`L03`T900/51@0:10@0
2`D500h8200?2@T03@L700/51@0<1PH00`0?2@T00`0>20P030H600`61P0300d71`0500`61P080P@0
1@0102PR900m=cT00P0E3a402@0;1@L03@L900/51`0<1PP040X<00d72@0=0PH04@H:00d31P020187
2`0=00d21P0@1@T04@H:04]0A00:00<04@L:00T00P0C20`04@H:01872`0A1PX03P<701462P020105
2@<03`@800<03P<7ooooooooool04_ooool001_ooooo00P02Pl;01DJ5P0;40`06AhJ010C400:3`/0
3a@@00hC3`80314=00@03A8>00hC3`0@4Pl03a4>0`0=3``0200>40d030h;00lA3P0:30T04Q@A014C
400B51403Q<?0P0:3`/04@0>4Q403A4@00`@3`093@h0<SHg00020`062Pd05QXM01@H6@0>40h030h;
00h@3@0A4a003a4>00h@3@0@4Pl03a4>00803Q0=02003@l<00`>2`0>40l020X900T;2P0Q8b803@l>
01DG5P0>40l03a4@03Pj>@0a<c808R@S01<E4`0<3P/02@/8010B3`0C5A803@l<00X<2@0F61D04A<@
01LI5P0<3P/02@/8018D400=3`X02@/6010B3@0F61<03Q0;00T;1P802`d80P0<3PT04@0=3`X01PX7
01<I5`0^<S4041@C00P<2`0G6AH03Q0=00`>2`0=3PT03Pl:00l@2`0?40X08R@N02d_:P0<3PT02@/6
008030h900@03@l:00lA300;3@P02@/60P0=3`X00`0;3@P030h900`>2@0200`>2@0=00d?2P0D5Q40
10H101HH4`0;3@P04aD@00X<1`0=3PT04a@?00l@2`0C50l0414<00h?2P0300l@2`<03Pl:00h030h9
014C3P0>40/0418=00h@2`0Q8ah092HQ00X<1`0E5a80418=00<50P0N7aX04A0<00l=2@802``700X0
2`l900dB30083@L02`l900`>2@0B4@d06aTE01/G500=30P030d80P0B4`h02@0;3@P03@l:00d?2P0>
4`d04AH@010G400=50d02a0:00h@2`02010A30804A8=01@0414<01<D400@4@`06AXE00h?2P0J6aH0
004000lA300A4`h030h900d?2P0@4Pd03Q0;00/=20082PD01PP301<E400A4`h0418=01<E50804Q@C
0P0:30/03`0Q8b803a0?010B4@0>40l030h=01TK6P0C5A@03@l<00/=2P0>40d03@l<00h@3@0B5140
3@l<014C4002010B3`0D01DG500F61H03@l>00d?3P0@4Q4030h=00/=300:30/01`T804i@C`1_LG00
30h=0001000>40l03a4@010B4@0<3Pd03Q0?00lA400=3`h200h@3`0C00lA400>40l03Q0?00T;2@0=
3``04aDB01`N6`0E5a@03@l<018D4@092`P051HC00lA3P0;3@X07R0M018D4@0D5Q<04A<@00d?3002
00h@3@80418?00d03a4>00h@3@0?4@h04A<@00/=2P010`003@l<00lA3P0J71T030h;01<E4P0=3``0
4Q@A00802`d:03L03@l<00lA3P0?4@h030h;00lA3P0D5Q<05QPE010B3`0B514051HC018D4@0>40d0
2P`:014B500A4QD0414C010B4@0C5A<04aDB00d?2P0B50h04aH?014D3@0A50`04aH?01<E400B5140
4aDB01DG500F61D051HC010B3`0B514051HC01DG500D5Q<041DA00@:200A6QL02A8?00P>300C6AL0
4QPF01@H5`0C5QD051HE01DG5P0G6AP05QPG01@H6@0?4a@0310A01PL7@0G6a`05QXK008041@E00L0
4ADF018F5`0C5aP04aLH01/O7P0N8R40:Rh]00805a/J00<041@C01lS8P0I7A`00P0F6QT201LK6P05
01DK6@0B61H04QPF01@J600F71X00P0G7A/09@0D6QP05A/I01XP7P0K8Al0624N01LQ6P0G8Q`051lI
01PU7P0L:2@082dZ01h]:P0eAD@0Be]J02dm?@0[>c/0<4=502]0@@0_A4D0>4e>03U>C`0nDe@0BUmP
05M/K@1SN7T0LXN8082EUP22UiP0P9RH07ZDT`1bS8/0JXB3061jN@1FL6l0BfET041JF@0jE5<00P0h
DU40:@0eCdh0<TU:0315BP0_A4T0;T=802a1AP0[@4<0;4540315B00^@d@08CHg02i3A00U>S/0:3e0
01`a=00[@4<08SLj02m4A`0^@dH0?E9E02Pm@00^@dH0=T]>01X_<P0bAdT0;D@n02Dl=00T>c<0:d8l
02<j=00]@d009S`j02i4@P0`ADH0:Sm002e2@`0cB4X0=4Y803=9A`0bB4H0;TA20080<dU700P0=de;
03Q>C00hCT`0C69P04=IE`10EU<0=D]803A;A@80<TU302H0=Te803Y@C@0oEE<0<TQ604AJF018GEh0
=T]<03Q>B`0aAC`0<4@h02e1=@0]?c<09cT]028d:00Z>Rl0?Ti302hn<`0^>c40;c`b02hk<@0^?S40
<T<g02Xl<00cA3`0<dDm02m3>P0cAch0:Chd02Dk;P0_ACP0=Ddk02Ho:P0[A300;THf02a4=00Z@SD0
<DQ003A>A@80=e5800X0=U5803IBAP0fDT@0=U9603I<AP0fBdH0>Di903E:@`0`ACh0<DHo0P0eBT40
2P0cB3l0>U1403iDB00kDDD0?U=<03]@B@0lDDX0?E9=03Y?BP0gC4L203]?C@0<03A8AP0gBdX0?E5@
03U=B`0cBT<0<4Dn03I;A@0dBD@0=4M303Q;A`0nDDd0?dm>0P0jBTT09@0iAdL0>4M403=2?@0c@Sd0
;chj0310?@0hBdT0>Ti<0355A00fBd`0<dQ:0318BP0]ADL0KX>408FGU`0fATH0;3Xj02Da<@0b>S`0
:C0a02@Z:P0O:2L07RPV01/V8P0N:RH0938/02hm=P0a@3T09cD^02Tf;`0a?3H092dX024Z9@0S:BD0
9R/W01lT800Q9R800P0P9R801`0N9200728N01/Q7@0J81`07R@P01dS7`0H7QX00P0C6AD07@0F71/0
8bDd01lP=@0R8cL07Qla01@F9@0I6bL051LP01@G7P0K7R<07R8U01XN7`0K7b005ALF01HH5`0I6aX0
7R0O01lQ800L7Qd061XI01HH5`1IFeX092HU01dO7P0f>ST0]KVj0;Zo`P0K82<05QXM00804aLJ00<0
5QLK01@E6@0C51P00P0E51T03`0C4aD05QHF01@D500E5AD03Ph>014A400I6AL03Ph<00l?300B4`h0
5AHA01@E400A4Pd0410@00`<3P02010@4P0300h>400C4aD03Ph@00803Ph@00H0ATI800L72@0C4aD0
4Q8B014A4@0=3@d2010@400300/;2`0I6AT04a<C00803@d=00<05aLG00l?3`0?3a401@0?3a401`0;
2`d03@d?00d=3`0<30h03@d?00h>400=3@l01@0<30h0300=3@l02PX<00h>400?3a4010@600l>4008
1PL00P0101LE5P0=2``03P`=00/92P<03P`=00@03@/<00`:2`0;2@X02`T:0P0<2P/200/92P<03`d>
00@020H700T7200610D030T:0P0A3@h01P0?2``03@T:00h:2`0:1PL030P901<?40805A4B00T00`00
00l:2P0=1`L03`T9010:2P0=1`L03`T9018<300?2@T00P0<1PH200d71`D03PP800<03@L700`61P0<
1PH00`0;1@D0800<1PH04P`>00d72@0B30h06Q@F00@000090`D02P@601D?4@0I4aD030H800T31@0<
1PP01`0001H;3`0E2Ph03@8600/2100=0PH02`0400h41`0/8BD0304500d41P0W72008AHJ01<8300@
1@T04@H:00l4200B1`/03P<70`0?10P201052ACooooo000Kooooo`0;00P>2`0[<Rl06AhK00H<2@0;
4@h03A8?00X?300;3`d03A0>00hB3`0A5A800P0C5Q@01`0930X06QdK00L81P0=40h04A@B00hA3`0F
6AL00P0>4@l0400?4Q002Pd;00hA3`0>4Pl03A0>010C4P0F6AP03a8A01`O7`2;SXh0=CPh014D500?
4Q@04aHG00d?3`0?414200d>3`0800lA4@0<3Ph071hN00lA4@0A4Q<03@l?00d>3`0;3@d200d?3P0;
014C4P0;3@`05ALF00H71P0D5QD02P`;03/m?00X:RT02P`;00d?3@0?4@h00P0=3``04@0<3P/02`d:
00h@3@0;3@X04aDB00/=2P0?4@h051HC00lA3@0E5a804Q@?00`>2@0:30L02``700h?2P0<3PT03@l:
00<03Pl:01D04A@?00lC3P0930X03a4>00/<200>40`03a4=00h?2`0?40/05AHA01LH4`0B4`d0824L
02T[9`0>40`02`d900h@300?4@d0418>01dO6`0Q8al00P0>40`09`0?4@d03Pl:00h?2P0=3PT030h9
00d>2@0>40/01`P501PI500;30P030h900P91P0B50l03a0;014B3@0;30L04A8=00h?2P0A4Pd04a@?
010A300?40/03Pl:00/<1`0<3@T0:R/Y01HG5@0<3@/051DD00d>2`0N7a`0KFi[01DF4P0<3@P020T5
010A300?40/03`l:00l?2@0200`=200d00`?2@0<40T02Ph800hB3@062@D04Q@@00d?2`0?4Ph02Pd9
00/?2P0C5a804A@@00X=200?4@`03A4;00hB300<40T02@d7014E3P0830L03Q0;010C3`16BTD0ATM3
00lB3@0B5A40?3lk014C3`052@@02`h900P:1P0F61@03Pl:00l@2`0<3PT02P/6010A300=3PT04A8=
01@F4@0?40/03Q0;00P9100@4Pd03a4?00`>300B518030h<01/M6`0o@Cl0@49000X<2P80418@00h0
61XH05mQG`0B5Q<0:Rd[05ILF@0B5Q<020/900P>2`0?4a403A0>00/?3@0@5A806ahL01XM6`803a4?
01P0418@00h@3P0>40h0418@00d?3@0E5aD04A<A01<E4`0G6AL03Q0?014B4@0>3`l03a0?010A4@0A
4Q804Q<C00`=3@0A4Q40414A014B4@0;30`03a0?018C4P0A4Q02018C4P0:00h?3P0H6AP04Q<B00l@
3`0?40h03@h=01<D4P0=3`l03Pl@010B4@804A<A01/04A<@014C3`0@4Ph03Q0;00d?2`0>4@/0418<
00lA3P0C5A<04Q@B01<E4`0A4a403@l=018D4P0>40h04A<A00lA3`0@4Q004aDC01DG5`0<3Ph04A<@
01<E4P0@4Ph04A<=00lB300@4`d00P0B51401P0C5A<04aDE00d>3P0@4Q004Q@B014C4@804A<@00H0
4aDA018D400@4Ph03a4=014C3`0C5A42018D4P0_01<E4P0D5Q<05ALC01<F400D5Q805ALD01@F500C
5AD04aDF00lB500@5A@041HD014F5@0@5A@04QLF01TN700@51<04A@C01DH5`0=40l05APG014D4`0?
4a<05a/K014E5@0D61P04aLG014E5@0@51@05ATI01LK6`0B5QH051PH01PL700G6aX07B4P01lS8P0F
6QT0<cLf03e1@00E6AP05a/J014E500Q9B@051PG01XN7@0A5aD00P0H7Q`04P0G7A/05Q`K01@J6@0H
7Qd051XI01HL6`0L8R<07R<U01`R8@0K9Ah06bDM01PS6`0M:28082dW01d[9P0N;BT0<D4m03i?C@80
9SLf01h0;T9102]2@@0^AD@0>Dm?03eCE013FUX0E6U[06UmO`1iS8l0S9bP09bZ[P2P[[@0XJbd09fW
/02CWjH0QY>J07R9SP1ZOh<0FW9c04YTI010G5X0>eQF03IDD@0aCd/0<D];0398BP0_ADT0;D=602]2
@`0[@D<202]2@`0802m6AP0S>SX0:D1002To@00[@D@08SXm02e4A`0S>C`202]2A01?02a1@`0fBdd0
:d1202m4AP0cAdL09cdm03I<B00V?SP0:40k02e5@00V?CX0<4M402@l>@0iDDh0E6]Z02m6A@0]A4<0
<4I702m5@`0`AD@0<dQ603M<BP0`AD<0<DI303=8AP0`AD40;D8n03Y?B`0cBDD0<DM30399@P0`B480
;dM202m7A00dBdX0>E1@03M>D00hCU40EF]/06^1PP0oEU@0>4i90398?00dB3`0<DDl02i0>`0Z>cT0
:CXj03A5AP1QLG00AUEA03I6?P0a@CH0:c`_02dm<00gASX0<d@h03=4>@0b@cX0<dHl0396?@1>HeX0
:d0g0316?00dBSl0<4Ll03A:@P0eBd40<dTn0399?@0gCD<0>55803U@C00jDDh0>E1>03Q@B00fD4@0
=e1503Y?B00203U>B080>4e602P0>e1903E:@P0fBd<0=da403aAB00oE4`0?E9:03eBB`0lDD/0?U==
03iCCP0kD4/0?55<041DD@0mDDh0=da803]?C015FEP0?U=?02i2>@0W>c40=DQ103E7@00bA3d0=dU3
03Y<A`0kC4L0?4e903I6@P0c@T00<D0k02hl=00a?cT0;chh02lo>`0hBD@0>Te:03A9A@0iCD`0=D]9
0P0aB4L03@1aQ8<0TZ6Q02ln?P0Q;B`09S0^02Pc<00Z<c009RdZ024Z9@0S;2H08RdV02D`:00Y=Bd0
0P0U<BT08P0P;2D0:38[02Pb;@0R:bH07bPS024X9@0]=34082PT02@Z9`0Q9b<082HQ01hS7P0O9B00
7R<N02L]:00P9R406b4L01PN6@0J7aX06R0K01`Q7@0M82L061/T01/N9`0M82P05APO01@G7P0E61d0
4QDH01DI6@0L8Al07B8N01dQ7@0I7A/201XM700>01TL6`0L7ah08bDS01PJ600A4a407b4M01<D4`0P
8Qh03@h;02LZ:@0e>3P05APH01LJ6P0D5AH201DF5`0601TI6P0C51D04Q8C01XJ6`0>3Pl0410?0P0A
4A00:00@3`h06aXI01<C4@0E5180410=01@D4@0E5A805aLC00l?300C4Q804A0B014@4@0E51D051<D
018A4`0D4a@04A0B01XI6`1<Bdd040l@01<B4P0@40l05QHE00X:2@0A4A003Ph>00l?3`0A4A404A4B
00T92P0>3Pl04A4B00d=3`0@3a403Pd?01<B4`0?3Q002`X;018A4`0<2`d200h=3P803@`>01403Pd?
00h=3P0;2P`03@`=010?4@0?3Pl030/<00h=3`0L6a`03@`=00`;3@0?3Pl02`X;00T82@0P7b00W9^K
01hM7P0200l>3P0600`;300=30`03@`<00/:2`0:2@X030X;100>2``03`0=2P/030T:00/82@0?30d0
3P/<00l<3@0<2@X03@X:00l;2@0?2`/040`<00l;2`0=2@T03`/;00`82@0200l;300@00T61P0E4A80
3PX:010;2`0?2PT03@P800/61@0>2@P06QDE01HA4@0>2@T02`H600`71P0>2@T03PP800l92@803PP8
02<030H600l92@0>20P03`T900d71`0<1PH03PP800l92@080P<04P`=00d7200;1@H02P@500h82@0<
1PL0618C01/E5P0B30d02PD500d7200A1PX04`P<00h41`0B1`/04@H:00l4200>0`L04`T<00`21@0F
2`l050T=030V:00P5QH04`T900d30`02010620803@<700D03@D900/31`0>1P`04@T?00`42P0Doooo
o`006oooool0200010404a`I00/D4@093`d0728P01lU8`0<40l03A0?0P0?4A02010B4@0U00T=300F
6QT0D5AC02@X9`0G6aX010P70001001:CTd0Gf=R01@H5`052@P04QHE010B4@0B51<02`d<00P:2@0?
4A000`D4010B4@0I6aX02P`;014C4P0;3@`00`D4018C5P061`/051DI010A5@0=3Q804Q<G030a=@02
0`L01`P<01TJ7P0S92P071dO00h@3`0201@F5@804A<B0P0B51<04P0<3Pd0418A01HH5`082PT0418@
014C400:30T01`T600d?300@4Pl04A<@00L91P0E5a@04A<@01TK600>40d04Q<?00h?2P80414<00@0
3Pl:00l@2`0?40/03Pl:0`0?40/0200>3`X03@h900d>2@0@4@`04Q<>00d>2@0<3@P03a0;0P0<3@P0
3`0D5A005aPC010A300=3PX03a4>00h@3@0;3@X02P`900h@3@0=3``07R0M01XL6@0;3@X030h;014C
400200l@2`0500h?2P0=3PT03Pl:010A300B4`h00P0?40/0100L7AP04A8=014B3@0;30L200l@2`06
00L80`092PD061TD01<D3`0B4`h0414<0P0>3`X0300>3`/0:b/[01LG6@0;2`d0410@00l?3`0E5AD0
8B4O00X:1`0>3`X03@h9010A30803a0:02l03a0800h?1`0>3`T03@l900`?200H6QD03A4<01DJ5P0V
:bL01P`801<I5@0H7QX051TE00D:1P042@D03a8>00lA300C5Pl02P`6014B30082@402P/401/L5P0A
4`h03a@@055FDP1?E5004aPD020U8@1JGe/05a`H00@91@062`L0314=01@F4`0>3`X03@h900h?2P0=
3PT04A8=00d>2@0O81/06Q/F01@E400B4`h020T400`=200200/=2P0A010B3`0<3P/02`d:01@F4`0?
4@h0418?0043000C5A807b4N06MYIP0B5A@02@l=03e3@@062PP04QPF00X@3P0<4Q000P0;4@l00`0<
4Q003A<A010C4@02010B3`0F00lA3P0@4Pl0418?01DG500J71T05aTF014C400B51404A<@01HG5@0F
5QH04A4A010@400<30`02`/;00X:2P0B4Q805QHF00d=3@0P8200410@01DE5@803`l?00`02`/;01<C
4`0L71`04Q8B014A4@0C4a<03`l?00`<300B4Q803@h@00d>4P0>3a42014C4P0<010B3`0B50l04A<>
00lB2`0=40T03Q4:00lB2P0D5Q<04A<B01<E500E5aH0418A0P0A4a803P0@4Q403a4@010B4@0A4a80
4aDD00/<3P0E5QP051HD00<50P0?4P/02Pd800lB2@0@4`X04Q@?0P0B51<03`0A4Q@0418=014D3P0@
4Pd03a4<014C3`0E5a@0418?00h@3P0>40l04A<B01@F5@0C5A@04A8D018D500201<E4P0P018E3`0A
50d04aH?01DG4`0@4A<03a0D018C6@0?3aL041@E00lC4P0C5aH04QHE01<G5P0K7ah05QXI01<G5P0A
5A@05ATH014E500=4A007R8Q00lC4P062PT041@C00030P0J7Qd061`K018F5@0F6QT07B4P04Y>C@0@
51<201XN7@1E01PL6`0G6aX07R8Q02<W9P0F6QT07B4P01LK6P0L81l06QhM01PL6`0C6AL05adK01PN
700G7A/05adM01PN7P0I7al061dP01TN8@0L8B@0724U01/P8`0I8Q`06R@L01`V7P0M:2807BXS01l]
9`0O<2X08C8/02@g<P0Y?3P0:Chi02]1?@0Z@d00;4E203M@CP10F5P0BV9R05eaM01hRXh0SibR0:Ra
^@2m`L`0aLOC0<_6eP37`=80^[K50:>T/@2=UJ00O8VA06^0Q01ILg@0AV=Q03aJE`0fEU40=EE@03IC
D00cBd/0<DU90318B00_AdL0;DE502a4A00^ATH0;dM702]3@`0Y@D40:d=301lh?00H<CD0;DI:03E=
C`0/A4H0;TI803A9BP0]@T<0:Cdn02/o?P0]@D00=TY90357A@0W@3d0;DI302U2?`0202Y3@00903E>
B`0]AT<0?5EB01lh=@0cC4T0<4Q502m3@P0aAD@0<dM50080<4A20440<dQ303A9A00bAd80<DHo03A9
@P0fBd@0=DY303E<A00cC4L0<T]803=;B`0eCE00=dmC049JGP0fCU40;DE5051YIP0bBdH0>4m503=9
?00cAcX0<DA00353A@0^?dP0;3a903E5DP1TMGd0BeeO03Y=B@0`A3L0;3h^02dm<00e@cL0=DDj0351
=P0a@CL0=4Dk04YNE@23Uhl0>4e603I=A`13FUD09cdk03U=CP0hC4X0=da503Q>@@0nDdX0@UM@04YN
GP0fBDd0>Da@03M;B00fBd80?eE903aABP0hCDH0=da503Y?B00iCTL0=da503=8@@0fBd@0>4e603]@
B@0203eBB`0303eBC@0lDD`0?U=>0080>Tm:03<0?eA?03]@B`0bAd80>4e803iCCP12Ee80=4U203]=
@P0oD4H0@eA:03A5>`0b@c/0>da403M8@00hBD<0?Di802m0>P0Y>S@0:CLa02Tf;@0[>2l0:SPa0391
>P0gB480<T@n02i1>`0aA400;T<n02Pn>`0Y?C/0:SXi06A`L019EE<08Rh[02Xe<@0N:B<082XS020Z
8P0N:1l09blW02Xa:@0Z<RL0:C8X02H`9`0`>S80<C/c02<]9@0Q:RD05b0K024Z9@0U;R/00P0N9b@0
6`0H8Ah0724M020U7`0L8A/08BHP028W8@0b=c40724K01PM5`0I7QP0724K01/P6P0M8Q`061dG01@I
5@0G6aT06QhM01PL7@0K7b008bLX01`P7`0G6aT0724K01dR6`0D6A4061hJ01TO7@0201/O7P0;01hR
8@0V:2D05aTF00h@300B4`h04a@?014B300I6Q@04Q8@01HF500H61H00P0G5aD02@0J6QP092@R018B
400?3`d0410>01/K6@0B4Q005A@B01@C4@0201<B400V01@C4@0E51806QTG00l>300;2PP00`8000l>
300E51803`d>01XH6@0c<C806QPI014?400@3Pl0518C01/I6P010000GUaM04=1@P0;2PP02``803Ph
=P0o?cd05aLE010@400;2`/02PX:01@D5P0=3@l04A4C00/:3`061PP0518D00L51P0F51D05aDF00P6
1`0D4Q<600h<3@0400l=3P0=2``03@/<00l=3P8040h?00d04@l@02d[;00J61T04Q0A010>3`0:2@T0
20P800H61P18B4P02@T900`<300>3Ph030`<00@02`/;00<03P`<00l;300=2@X00P0<20T01@0=2@X0
3PX;00l;300?2``03PX;00803@T:00@03`/:00l;200>2PL03@T70P0=2@P00`0=2@T03@T:00h:2`03
00l;300C00`8200I5A@04@d<00d9200>2PT04Ph=010<2`0?2`X02`L600T5100:1PD03@T801D?3`04
00003`T901dG5`070@405@l?00`61P0400/51@0=00`61P0=1`L03PP800/51@090`<03@L700h8200?
2@T03PP800D000070@401P00010:2P0601052@0600d21P0>0`L050T=01H;3`0@1@T03P@50P0=0`80
2P0;0@0030@200l71P0@1`X05Q0B00X52P0E41H03PT?00X62`0910XDooooo`006oooool00`0B6aP0
214>00PA3P0200`B400300hD4P0<40l03Q4@00803a4@0P0@4Q402@0B5QD02Ph=02<W9P000P4020`;
014E500I7A`07R8Q01/O7P0200X>3@0900T=300?4A004aDD010B4@0?4A006A/J00h@3`0620L061XI
0080418A01`04Q@C01dO7P0?4180414C018C5@0:2`d02@X<00/<3P14ADL04A8D00d>400A4Q@04a@F
00T:300H6QT08R@S01DG5P072@P01PP700D71P0C5A@03a4@01HH5`0O8B0030h=00h@3P0@4Pl03Q0=
0P0@4Pl02@0>40d0418?00d?300A4a004Q@A014C40041P<03a4=00h?2P02014B3@<03a0;00@03Pl:
00l@2`0?40/03a0;0P0>3`X02@0@4@`04A8=014B3@0B4`h03Pl:00`=200=3PT02``700d>2@0200l@
2`0300d?2`0>40d03a4>008030h;00L03@l<00`>2`0:30T03a4>028T8@051`@02`d:00<03Pl:0180
3a0;010A300C50l0414<00/<1`0H6A@07AhI018C3P0>3`X02P/600d>2@0>3`X02@X500X;1P0D5A00
4a@?018C3P0A4Pd200l@2`0>00l@300?3`l04Q8D00/;2`0<30`051@C00X:200820H02@X6018C3P0?
40/05QLB01DF400?40X200l@200T00h?2@0>40T030l800D70P0F6QD020d90;Fj]P0M8al08BLS05UO
F`0T:BD03A8>01@I5@0A51001`T401HI4P0:30H04Q<=01HG3`0=3PH04Q<=00X<1`0=3``08B<P020R
7`0C5A8071hK010B3`0?4@h030h;018D4@0?4@h010H300h?2P0=3PT03Pl:0P0@4@`06P0=3PT05AHA
018C3P0>3`X04Q<>00/<1`0@4@`03@l<00/=2P0A4a003Q0=00L91P0;3@X03a4>01dO700<3P/071hK
00d?300;3@X03A4@01XN7@0T:2L00`D4014E500>4Q403A4@0P0<40l0100=4A003Q8A010C4@0@4Pl3
00lA3P0<010B3`0A4a003a4>00d?300:30T01@L400X<2@0D5A<0410@00h>3P0B4Q80410@0P0?3`l0
1`0I6AT02PX:00l?3`16ATH08R8R01<C4`0;2`/00P0=3@d04@0<30`05QHF01<C4`0@41004a<C014A
4@0>3Ph0410@00l@4P0>3a4030d?00h@3`0?4A003Q0=014C3P0@4Pd03a4<00803Q4:00P03a8<01<E
4P0A4a8051HE01DG5P0B51<04aDD014C4P<0418A00/04A<B01<E500;30h01@H8028T8P0O8Ah030l8
01LJ4P0C5Pd04QD<014C3P02010B4@0?014C4`0B50l04Q@>00h@2`0=3`X04A<?01HH5@0>40d03Q0>
010B4@0C5A@05ALF018D4`0A4Q@04Q@D00804aDB00X04QD?014D3@0?4@`04aDA010A4`0@4AD04a@J
00l@5@0C5aP04QHE0P0E6AP08@0C5aH061`K010D4`0A5A@05a/J02L[:P0G6aX0:bl^010D4`0B5QD0
4aLF01XN7@0Z;Rd0IVYY01<G5P072`X06alN02T];01iOG`09RXY01LK6P0B5QD04aLF01LK6P0E6AP0
4ADD018F5@0H71/06alN014E500N8R4041@C01DK6@0201PN700^01LM6`0I7al06b4Q01LM7@0H7B00
5a`O01HK7P0F6al061dP01PR6`0J91`072HN01dX8P0N:RH08BlZ020a:`0Q<Bh0:3/g02i1?@0[@3/0
:T0l02Y3@00^Ad@0>U=A04EMG@1CJ6T0IgYm08>BU`2NZJl0_<;;0=OGh`3Qgn`0i]o`0>;Ik03DcMd0
]kO509^S[P26Ti/0MHR=06=kO@1<JFL0?eeK03QFE00gEU40>5=A03A<C0<0<TY:00@0<4Q802]3@`0X
@400;4A40P0[@d<03P0]ADD0?EIJ02]4B00S?4009cm102<k?@0[@dD0@eQI03]@D@0`A4D093Pg01lc
<P0X?3/0;dE20P0^A440300V?3T0;dE202e3@00eBdP093Xg02i4@@0Z@3d0@5IC02]1?P0cAdH0=4Q7
03=7A@80<4A203`0<dQ30397@P0aAT40<TM003A9@P0cB440;d@m0399@`0eC4L0>Dm=03U>C`0iCU00
=da?03]@D`0kD540<TQ6051WH@0hCdL0<TTo02m5>00`A3X0<4<o0312A00`@DX0<41=03U9EP1GJ700
BE]M03e@C00bAS/0<D<e02/k<00c@cP0=THk03A4>P0b@cT0=4Dk02i2>@12Edl0<dQ103U@BP0lDdd0
<dU603Y>C`0kD4/0>4e403M=@010ED`0B5eF055UI@0`@dL0>4a=03U=BP0dBD00?eE903eBB`0jCdP0
>Di703Y?B00iCTL203M<A@0303U>A`0jCdP0?55:0080?55:00T0?E9=03Y?BP0kD4/0>Di903aAC012
Ee80>e1;03=8@`0lDD`00P14FE@04`0bAd00=DHk03m@AP15ET`0>4To03A5?@0gB400<T<k03M8@P0n
CdT0<D8l02Tj=00Z>S<0:cXc02Th<@0W=S40;chi0311>`0^?cT00P0/?cT0100Z?CL09c`g02Tl>00a
@Sl206ijN00;02hi=P0b?CT08bhX020Z8`0N:2008B/S02Pa:@0W;RH09RdU02<[8`0U;bH00P0W<BT0
1P0M9al07RLR02/d;`0L9B008R/X01hW90809Bh[00H07b@P02L/:00M8Qh06QlK01/P700Q9R8201PM
6@0C01`Q7@0J7a/05Q/G01XO6`0K81`05a/J01LK6`0M8B807B4T01`P8`0R9RT07B4R01PM6P0I7QP0
6QlH01LL5@0I7a/061hL01TM700201/O7P0:01dO700P8Ql06AXF00T:1@0M7QT05AH@02//9P0P81h0
51@B01DE4`805aLE00T08R8P04=3@@0G5aD05ADC01HF500D51805ADC01<B400D4a400P0E51809P0D
4a404a8@00l>300D4a4081lM01/J600G5Q@02`X801XH6@0Q7b00BDM801lM7P0D4Q<05Q@E010>3`0?
3@h07A/L01XH6@0=2``04a8@01TI5P1`L6h0LW9`00/;2@0O7al06QXJ01PH600B4Q@02@T;00l?4@05
10T04a<E014?4@0G5AH02PP900d;300:20T01P@51P0>30d200l=3P0700d;300;2@X03`d>01<A4P08
1PL07Q`M01@B4`0201DC5007010?400?3`l04a<C00L71`0E5AD04Q8B014A4@0300/;2`8030`<00P0
3P`<00l;300>2P/03@T:00`82@0=2@X03PX;00l;30<03PX;00L03@T:00l;2P0?2`P03PX700d91`0=
2@P03PX900803@T800d03PX900l;2`0?2``03PX;00`8200E4A004`l>00`81`0>2PT03`/:00d9200<
20L02`L600802PH501T02`L600/51@0>20P0618B00D0000400002`D500l92@090`<02`D500d71`08
0P8030H600h8200?2@T02P@400`61P0C3@d040X:00P20P0@2PX05Q0@01dG5`0B30`030H600H040D9
00H050T=00X10`0E2Ph040D900h31`0C20`200l51P0:00d3100;0P<03PD70189300600803`X=00D0
10030080:RDY018=4ACooooo000Kooooo`0800D>2`094Pl041TF00lE4`0;4@l04QPF00dA400>4A04
00lA400900dA40072`X06alN00/?3P0>4Q403a<B00X>3@0=40l04ADD00803Q8A01l041@C014C4P0D
5QD05ALF01@F5@0N81l05aTH01<E500?4A003@l>00lA40082PT05ALF010A4`0:2`d05QLI01LH6P0>
3a404Q<E014B500D5AL05aPJ00/<3P0A4Q@04a@F01dO7P0T9RD051HE00lA400F61L04aDD00803Q0?
01<04Q@C01LI600:30/04A<A00d?300;3@X030h;00X<2@0;3@X03a4>00h@3@0;3@X051HC00d?3009
2`P04A<?014B3@0D5A004Q<>00803Pl:1P0?40/01`0>3`X04Q<>018C3P0=3PT03a0;014B3@0?40/0
0P0@4@`03@0?40/03@h900l@2`0?40`03Q0=010B3`0>40d03@l<00lA3P082PL06Q`I01/M6P0b=340
0P0>40d600l@2`08014B3@0B4`h09bPS01HG4P0720<04A8=00l@2`0A4Pd201@E4003014B3@0;30L0
4A8=00804A8=0P0@4@`03@0?40`030`<014A4P0@41003Ph>00l?3P092@L0414=014B3P0<3@P020T3
01LH4P0@4@/00P0@4@T05`0?40P03a0:00h@2P0=40T02`d:00T<200H7AT06b0L01DK5`1OIF40gN?O
04M=B@0=4Ph05AXF00`?2`0Q8ah01`X301PJ50092P@051D=00d>1`0@4@/02P`700803a4>00H03Q0=
00d?300<3P/04aDB00h@3@0;3@X200d?300=00`>2`0A4Pd0414<00`=200?40/02``7018C3P0=3PT0
30d800X;1P0A4Pd030d801<D3`0200d?300B014C400;3@X03@l<01HH5@0c=C<0418?014C400>3`d0
2`d:00h@3@0?4a80:Bd/02DY:00@51<02Ph=00hB4@0<40l03A4@0`0>4Q407P0?4Q00418?00lA3P0>
40d03a4>010B3`0A4a003@l<00lA3P0A4a0030h;01LI5P0N7ah0410@00l?3`0D51@04A4A00l?3`0@
41004A4A00h>3P0@4100<c<c01`L700B4Q802`/;01HF5P0N7Qh030`<00h>3P<04A4A00T03`l?00h>
3P0B4Q8051DF014C4`0>41003Q0?00lA400?4@h00P0?4@d01P0?4@`03a8<00lB300?4P`03@l<00h@
3`80418A00<04A<B010B4@0>40l00P0@4Q4200h@3`0:010B4@0C51H01`P:02/]:`0a<c005aTD01lR
6`0F6A4051L@014C3P803a4@00X0418B014C3P0B5@l04A<>010B3@0A4`l04aDB01/M6P0F61H04Q@C
0P0C5A@0<P0A4a804A<C018D4`0C5A804aD@018E3`0A50h04A<?01HH5P0D5QD04a@H01@E6P0?41D0
4QHG010D4`0E6AP05QXI01<G5P0F6QT05ATH01<G5P0G6aX08BDT04=7AP0O8b8051PG01DI600C5aH0
3Q8A01PL6`0f>ST051PG00lC4P0J7Qd0310?01hR8@0B5QD05QXI01@H5`0G6aX06QhM01DI600A5A@0
61`K01DI600A5A@07b<R01HJ6@0I7A`05Q`J0`0G7A/00`0I7al0728R01LM7@0201/P8`0Y01PM800K
82@07R<V01TR7@0I8a`06bDN01hY8`0Q;BT08BhZ020a;00T=340:3/h02/n>`0Y?SX0:d8o02e6@`0a
BTL0?5AC04MOG`1HKFh0LH:5096MX`2^][h0dmCO0>o[n@3jloh0oOCo0?_`o`3]iOH0d<kL0;2e`@2G
XJX0Nh^B06AiO01BJf`0AV5Q03YHEP0fDU00=Dm>03A<C@0cBd`00P0dC4d05P0bBT/0;TI702]3A00/
A4D0;dM8039:B`0fCU00=DiB03=<D00/ADT0;dM902U1@`0iDE<0=da=0315AP0]@D80;D5002/o?P0/
@3l0<TQ502To?00^A44202Pn>`0=0316@`0bB4D0:d4n03E;B00X?S/0<TQ50316@`0hC4/0=TY90396
A00aAD<0<TI403A9A00202i3?P@0;T<l03@0<dY403E<A`0hCT/0>Dm<03Q>C@0gC4/0=4Y903U?B`0_
ASh0A5]A03Q?@`0/A3L0;40d02a0=P0[?SX0;3i00393B`0iBUD0>daG04IGG`1;GEl0@eIB03I:?`0a
ASP0;3hb03=4>@0hB3h0=dPn03E7?@0dB3h0=d]202e2>P0fBd@0>4m803aCC00aAd<0>4a<03aAC00i
CTD0=4Xm03Q=A00oE4d0?51?03=6BP0hC4d0?51=03U?A00hCT80>e1803Y?B00kD4T0?55:0P0mDT/4
03aABP0O03]@B@0jCdP0>e1;03eBC@10EE00?U=>03eBC@11EU40>Di903M<A`0nDdh0@EIA04MLE`0k
D4T0=4Dj02m0=P0kC480?Tm503Y;@`0dACd0;d0h03=4?P0hBD<0<D8l02`m=`0Z>cD0:S`g02`k=`0_
?c/0=TI203A5?`020351>`0H02`l=P0W>3409SH_02Lg<@0X=c<08Rh[03<o?00^>SH0<C`h01XU7`0U
;bT08b`V02D_9`0Y<BX09B`U02H]9@0/=2`0=3he02Pb:P0Q:b<08R`T03Dn>@1lQH00=Chi0P0Q:RL0
1`0K924072DR01hS7`0Z;b/07b@P01`Q7@0O92000P0M8Qh03`0I7QX06b0L01hS7`0J7a/05a`I01PL
700G6ad06alR02@X;00V:Bd07b8W01`O9@0K7b<0720Q01`P7P0201/P6`0C028X9@0L8R005QXI01PL
6`0J7Qd061XG01DG500G61@07QlJ01DF4@0D5A007AhH03/k>@0M7A/05QHD01LG5@0E5A<08R8P034a
;`0201HF500501@D4P0E5A<051@B018A3`0D4a400P0F5A<05@0D4a404Q4?01LF500?3P`04a8@018A
3`0G5Q@03Pd;01HD5@0G5AH05A<D018@4@0A3a0040h?00h<3@0@3Pl061HG018@4@0?3@h03`h<00d=
2P0201<C4@0>02d]:`1=CDd04a<C04U9B@0@41804A4C00h>400=31403Ph@014?4@0?3@h03P`=01LE
5P0;2@X900h<3@0@010>3`0C4A804Q0A014?400@3Pl03@/<00T7200>30d04@l@00`;30051@D03@d=
00l?3`0>3Ph01PH600d=3@D030`<00H03P`=00l;300?2``03`/<00h:2`0=2@X600h:2`0600l;2`0?
2`T03PX800d9200>2PT03`/:0P0>2PT0300?2`X03`/;00l;2`0>2PX040`<00@1000B3Pd02`L600l;
2P0=2@P02`L600`81`803@T801X030P700/71P0A2`/01`8200`61P090`<05Q0@00d8200B30`02P@4
01<=3@0I4a<03@L700h8200<1PH03@L700h8200C3@d0618B00l92@0D3Ph03`T900H10@0B30`040X:
00/51@H040D901805``@00l5200?10P02`0401872`0>10L04PL;01462P0C20/040L;00d41`0A20/0
3PP:00T51P0<20T0920R03Hb<`0K5aLDooooo`006oooool0200C71T03QLD00@=2P093`d03Q@B00H<
2P0>4Q403a8A0`0?4A000`0>40l04aLF00P<2`0200H:2@0800P<2`0>4Q406alN00P<2`0420L0310?
00hB4@0C5aH200h@3`0@00lA400:30/03a4@00T;2P0620L07R0O01LI600<3Pd0;2h]05eOGP0H6A/0
=CHh014B500720X04Q<E00D620804Q<E00/051DG00/<3P0<3@l01@L6014C4P0C5A@03Q0?01TK6P0W
:BP09RPW00lA4002010B4@0A00lA400:30/04Q@B00lA3P0H6QL08B<P01@F4`0<3P/03a4>00`>2`0:
30T03Q0=00L91P0D5Q<02P`800h?2P0?40/00P0@4@`2018C3P0;010A300?40/03a0;00l@2`0@4@`0
30d800P9100;30L04A8=00d>2@0<3@P00P0>3`X01`0?40/03Pl:00`=200<3@P03@l;00h@3@0?4@h0
0P0>40d2010B3`0500L91P0j?3T0LgEb01<E4P0<3P/00`0@4@`04@0?40/03Pl:00`=200D5A002``7
014B3@0D5A0030d8010A30092PD06a`G02TZ9@0D5A001`P3010A300>3`X03a0;0080414<00l03a0;
00h?2P0D51@030`<00l?3`0B4Q803@d;01@D4P0A4Pd03Pl:00d>2@0;30H04a@>0083000A4PX00P0@
4@T05`0?40X03a4:00hA2P0A4`h04QDA0002000]<Rh03Q@@01LM6@0Q9b<03A<?00dB3P0B5a<03Q8=
00d?2P0A50d02`d601LH4P15ASh06AXB010A2`0@4Pd03@l<00803a4>00d03Q0=018D4@0<3P/010H3
01HH5@0G6AH02@/800d?300B4`h03Pl:00`=200J6aH02``700804a@?01T04A8=00h?2P0B4`h030d8
014B3@0<3P/05aTF01dO700?4@h02@/8018D4@0O8Ah01@L400d?30072@H05QPE01TK600A5A@00@D4
00T=300?4a801PX900/?3P0<40l03A4@00<03Q8A00<03Q4?00lA3P0>40d00P0>40d08P0?4@h0418?
010B3`0@4Pl02P`900<50P092`P051DD010@400?3`l051@D014A4@0?3`l04A4A00T92@0E5AD04A4A
010@40092@T04Q8B00P8200?3`l05aLG00`<300@410051@D018B4P0>3Ph030`<00h>3P0C4a<051HE
014C4P0?4A02010B4@0300lA3P0=3``03Q0=00<0418=01L03a8<00d?300@4Q40418A00lA400A4a80
418A00`>3@0?4A004Q@C00h@3`0;3@`03Q0?010B4@0H6QT04Q@B00@60`0F61<04aH@01@G400C5Pl0
4Q@@010B3`0200lA400c00lA300C5@l051HA018D3`0@4Ph0418?01`N6`0F61H04A<B018D4`0F61L0
61XI014C4P0B51804aDB01<E400B50l04A<>01DG500H6QP051DG01@E6@0E5QX0414E01<G600>4Q40
4QHE01DI600D61L05ATH01LK6P0@51<03Q8A04E9B03=dM00>Cdl01@H5`0M8B00?T9101`P7`0N8R40
4ADD00hB4@0H71/03a<B02@X9`0C5aH08RHU01<G5P0G6aX061`K00<05a/J00L061`K01`P7`0G6aX0
=CTh00`@3`0L81l051XH00805adK02005Q`J01PN7P0J82005adM01XO8P0K82<0724T01lT:00P9BP0
6R<O01XS7P0K91l07RTS020/:00N;2P07bl/02De<P0U>3D093Le02Lk>@0]AD80;dU6039<B@0kE580
B5eN05Y^K`1iR8`0WjR_0;g1bP3Sgn/0o_?o0?oio`80ooSo00/0ooCo0>KRl@36b=D0ZK2j08NFWP1[
OX@0EV]^04MOH@0oFEX0?UQI03eFE`0203Q@DP0503UAD`0hD580=4a>03=;C@0aBD/00P0]ADL0G00^
ATP0;dM902i7B`0X@DD0;DI:03YBE00dC4h0X[Zl04mTI@10EEH0;d=402/o?P0Y?C`09c/j02e3@00Y
?c`0A5YG03eCD00Y?c`0;D=003=9AP0[@Ch0<4I302i4@@0cBDH0<TQ503I:B@0cAdH0<DE30396A00c
AdD0<dQ302m4?`0`AD00<4Dn02e2>`0_A3d0<dQ10399@`0bBD@0<TQ503=9AP0eBdP0=Te703U@BP0`
Ach07CDX02Hn<00U?Bd09C`/02Hl;`0[?cD0;D0l02do@@0fAdd0?e1J03e>F00oD5P0BUaN045DD00j
CT@0<THj0394>00fAc`0>DY003Y;@@0hC480=TY102Xo=P0X?CD0;D8k02e4?00jDDT0=Te703=7AP0k
D4/0>e1703M=@@0iCd<0?55:03M;B@0lD540<TI703E:A`0nE4P0>Dm303U>AP0iCTL0>4e603I;A00g
C4D0>Di70`0hCDH02P0gC4D0=4U203A9@P0jCdX0?U=>04=HD`0oE4l0>Tm:03aAC011EU4203mDC`0H
03M<A`0oE4l0>Tm80393>00iBT00=dPn03U:@014EDd0@5590311>@0_@3X0;3dg02Pi<`0U=S009SPc
02`o>`0_@Sh0=4E203Q8A@0eAT00<T8l02ln>@0X=c00938[0P0T<BX0<P0W<bh0:SHb03M3?`0g@cl0
;cXf01dX8P0R;2H08R/V020Z8P0U;BH09RdV02T`:00Z<RX0<3Xa03@n=P0^>30072HN01`U800X<B`0
6B8M020Y9P0L9B808b`Y028[:00J7a/08BHR01XO6`0M8Qh07R<O01`Q7@0Q9R806AhJ01PM6@0O9200
7R<O01PL6P0L82<07R4V01lR:00R9B`092L^01dP:00P8b`07b8Y01hQ9@0K7b006QhM01TM6`0V;2X0
7R@R0P0E6AP0300H71/061XG00`>2`0I6QH0Si2;03<d;`0H6A@01PL101lO7@0C4a405aLE01/K6@80
5QHD00P03@d;01HF500G5aD03`l=01PH5P0@40h04a8@01@C4@805A@B02H051<A01<B40081`D0;B`Z
04E4@P0_;R`06APF00d<2P0?3@h0;2X[00T7200L6Q/0518C01/I6P0D4Q<03`d>01TG600:20T01@<4
01@C4@0@4@`04Q8@00/;2@0=3@/03@d=00X:2P0d=3@01PH801@D5P0@41805aHK00<31@0F51H0=S@e
00l=3P071@H02`T:00P61`H03P`=01<03@/<00`:2`0A3a006ALH01<A4P0;2@X03`d>00H41@0?3@h0
40h?00X82@0<2`/05ADE00L71`0@41001`L701HF5P0?3`l03Ph>00803@d=0P0<30`01@0>2``03`/<
010<3@0@30d03PX;00<03@T:0`0>2P/00`0?2``03`/;00h:2@0200d9200>00h:2@0?2`X03`/:00h:
2@0?2`X03`/900h:1`0=2@P02@D401PD4`0?2`X02@D400/71P0?2`X200d920@03`/:01P0208200T3
0`0F4100100001hH600>20P030H600X4100D3Ph0618B00l92@0;1@D04@/;00T30`0:10@040X:00d7
1`0>20P01P0000d71`0O6AT0>cDe02lY:@0>20P601052@0B00`11@0F2`l03@8601462P0?1PP05``@
01052`0900@040D;01893P0=10T040L:00h82P0?2PT05Q8A020L6`091@D03@T65?ooool001_ooooo
00P02Q<@00D>2`053P/03Q@B018H5P0@5Q@03Q8A00lB4@803a4@0P0>40l0:`0;40`04AHB018G4`0C
61@02a0<014F4P011P803Q<?01LL600<4@d041DA02H[9`0<3P/03@l<010B3`0<3P/04Q@A00lA3P0G
6AH02P`900P:1`0B5140418?01XL6@0Y:bX0FUaK01/M700:30/08R@S00d?3P0@4Q402`d<00h@3`0?
4A005QPG00h@3`0>40h03Q0=00d?300?4@h04aDB01DG500C5A800P0A4a003`0B514030h;00lA3P0>
40d07b4N02h`;@0I6aP02`d:00h@3@0=3``03Q0=00`>2`082PL08bDR00P91@0300d>2@0400h?2P0B
4`h04a@?010A30<03a0;00X0414<01`M600B4`h020T4014B3@0=3PT02``7010A300>3`X03@h90`0<
3@P01P0=3`/03a4>00lA3P0=3``03Q0=018D4@805ALD00@03@l<038d<@0G6AH03a4>0P0?40/2014B
3@0@010A300?40/03a0;00X;1P061`804Q<>00T:1@0=3PT02@X501LH4`0P8A`03a0;00H70P0?40/0
30d800d>2@803a0;00h03Pl:00d>2@0C4a<03@d=00`<2P0@40h03`l=018C3P0A4Pd03@h9018C3@0?
40X04a@>00P90`804A8:01d04149010A2`0?4@X03Q4:00<5000930T092TU0002000=4`l00PP400hD
400F6aL0314=00@91@0:3PT03@l:01LJ4`082P<05QLA05IGC`0M7QH010D000l@2`0<3@P02@X500/<
1`0@4@`04Q<>034b;@02010A300900l@2`0>3`X061TD010A30082@@03a0;02d^:@0A4Pd03a0;0080
30d801D02``7018C3P0>3`X051D@00lA3P0F61D07AlL018D4@0:30T04A<@00lA3P0@4Pl05ALD018D
4@0@4Pl00@<001<E4P0@4Pl05QPE010B3`072@H00P0>40d00`0?4@h04A<@010B3`0200lA3P803Q0=
00X03@l<00h@3@0>40d04Q@A01XL6@0K7AX04A<@00h@3@0@4Pl0414?0P0;2`T201<C4@0=01@D4P0I
6AL03`l=00d=2`0D51807alM00X:200@40h01`L500X:200>3P`030`:010@3P02014A3`803Ph<00<0
410>018B400@4Pl00P0?4@h2014C400I00h@3@0<3P/03@l<010B3`0A4`h0418=00lA300>40d04Q@A
014C400?4@h04Q@A00lA3P0=3``04A<@01DG500?4@h03@l<010B3`0A4a0020X700d?30092`P02`d8
01@F4@02018D3`0B018D4@0A4a00418?00lA3P0A4`h04aD?018D3`0@4Pd0418>014C400F61D04Q@B
014C4P0D5QD05aTH01PJ6@0A4a004Q@A0P0C5A806P0B51404A<@01@F5@0F5aP04Q<E018C5`0F5a/0
4a@H01PL7@0A5A@04QHE01DI600D61L05ATH01TM700A5A@02@d<02/_;P22QXD05a/J014E500Z;Rd0
K71_00lC4P0D61L03A4@0P0D61L01@0=4A004ADD01HJ6@0;3`h05QXI00805ATH00d05QXI01LK6P0H
71/04aLF01PL6`0I7A`08RHU00lC4P0I7A`05A/I01PN700J81h06AlM00806AlO00L05Q`L01DJ7@0G
71l06QlR01XO8`0J7b807BHR00806b@O01D07BPT020/:P0P;R/07bl/028b<@0S=S@09cXh02Pl>P0]
AD80;T]703A>B`0kE5<0BUmP05ibL`1oS900XjZb0<;5cP3Wh^l0ooCo0?oho`3omol00P3on?l02P3`
j_T0c]3M0;2f`P2>Vj<0L8>905aaMP1=IFT0A5aP049JGP0nEUP303UAD`0M03M?D@0cBdd0<4Q:02m7
B@0^ATP0<4Q:02m7B@0Z@T@0;4E903=<D00bBdl0=4a>01/c=@17Gf40=T]<02i3A00Z?Sl0;T910355
A00iCD`0;d=103I;AP1?I5l0?55<02]0>`0^@ch0<TM202]0>`0bAd800P0jCdX0@`0`A440<dM60355
A00`A480<dM503A8AP0bAd80;d@o0397@P0cB440;d@m02e2>`0_A3d0;d@o0315@00aAT40<TM203=8
@`0cB440=4U002i4>00Y?c80;D@d02Dl:P0Q>2H08SP[02e3>00dBD@0=DU803Q;D@0nDEP0@5=J03mB
E`14F5L0>Di903aAA`0dBSh0=TXo03M;@00hC440>De403U>A@0gC4<0>e1703M<@`0lDDP0=T]202a1
>00jCdP0=TY903U>A`0hCT80=de003Q>@P0jCdH0>4a;03Y>C`0eBDP0<dQ303Q>@P0iCd<0>4e503Y?
B00iCTL0=da503U>A`0lDDX00P0hCDH0700gC4D0=T]403A9@P0cB440>Di903aAC010EE00?55<03M<
A`0jCdX0AU]F041ED00oE4l0=da703aAC00cB4409SP]03E6?00hBCl0?4e304MHD010DDT0;d0h02m0
>P0/?CL0:S/e02Pi<`0/?ST203=7A@0702i1?P0/?c/0;Chh02hn>00_>cL0:CH_02Lc:`0202Td;00E
02@`:00]>S<09C8[02Te;P0Y=2h0<chh03@n>00X<B`08b`W02L_:@0W;RL09RdV02Xb:P0a>c80@4Y2
03]5?@0S;BD08R/V01<L5`0M9R408R/X00806R<P00P051dJ01lS8P0P92<061`K01`P7`0G6aX05QXI
01hR8@8061`K01h06alN01TM700I7Ad07b@X024V;00M8RP06QhW01lS;00P92h09RXe020T;@0I7R<0
61dP01XP800K8Al082HT01/Q7`0F6QT05ATH01HJ6@0G6AH092HS018C3`15AT400P<0014B300O81X0
4Q8@014A3`0E5A<201TI5`0901DE4`0F5Q@07AdK01`L6P0A4@l05QHD010@3P0E518051<A00804a8@
00D051<A01DD4P0B4@l07ahL028Q7`0200h=2`0O01LF50061@<06QTG00X91`0B4@l02`X8010?3@09
20H03Pd<00`;2@0H5aD0:2LU00L6100F5A4040l=01TH5P0H5aD0518C010>3`0C4A803P`?00T72P0?
3A005aDJ010>4@0T8R@0GE]L01TG600;2@X07Q`M00l=3P0800h<3@0@010>3`0C4A803P`=00X82@0A
3a001083014?400?3@h02`T:00X82@0@3Pl02PP900/92P0:20T040h?00/92P8040h?00D03P`=00`:
2`0;2@X03@X;00l;3002010<3@0300l;300=2@X03@T:00803@T:00@03PX;00l;300?2``03`/;0`0=
2@P00`0>2PT03`/800l;200200l;200900l<200>2`H03@T600/71@1bKVd08alN00d920060P4030P7
00<03PX90P0?2`X02@0@30/04P`<00/51@080`<07aTI07I`L00/9RH02`D500`61P02010:2P0>00l9
2@0<1PH04P`<00L10@0D3Ph07ALG00`61P0=1`L03PP800`61P090`<05a4A01D?3`0A2`/601052@0B
00d21P0C20`02@0201@93@0?10P0DTM=01dB6P0<0PT03`@<0188400>1@X04@P;00@0000D3`l02@D2
00<000091@<03@X55?ooool001_ooooo0P0<5A801P0B6aP04QPF00X@3P093`d03a<B010C4P80418A
0P0?4A00200>4`l08RLS00X?2`0:3`/03a@@01PM6@0:3`/02a0<0P0=4Ph0100C61@082DQ01@F4`0>
40d200lA3P0<014C400@4Pl02`d:010B3`0?4@h04Q@A00/=2P0<3P/04A<B018D4`0?4A00418A0P0=
3`h01`0@4Q404Q@C014C4P0;3@`03@l>00X<2`0?4@h00P0@4Pl00`0?4@h030h;018D4@0200d?3003
00h@3@0@4Pl02P`900803a4>00d04A<@01@F4`0=3``030h;010B3`0<3P/0418?018D4@0H6QL0;2h[
01<D400?40/03@h900<03Pl:00X03a0;010A300?40/03a0;010A300A4Pd07b0K01TJ5@0=3PT03a0;
0P0<3@P08`0B4`h03Pl:00l@2`0E5Q404A8=00`=200@4@d04A<@00lA3P0D5Q<0:R`Y01<E4P0X:RL0
2`d:01PJ5`0m?c`05QPE00lA3P0@4@`03Pl:00l@2`0B4`h04A8=010A300A4Pd05AHA00h?2P0C50l0
3@h900l@300>3`X03@h900l@2`0>3`X03a0;008030d800<03@h900h?2P0>3`X00P0>3`X01`11@Cl0
9BDT00X:200?40`03a0;00d>2@0?40/00P0>3`T0700:2`@0414:014B2`0@4@T03a08010A2@0A4P`0
418<00hA2P0<3PT04QHA00@81@0?51002a0<00dC3`0B61@03Q@@01@I5@0?51002`l:00lA300=40T0
5QPA00X;1`0I6Q8030d501<D300@4@/200l@2P80414<01D03@h9018C3P0=3PP03a0;010A300=3PT0
3Pl:00d>2@0:2`H03a0;02LX8`0D5A002``700l@2`0A4Pd0414<018C3P0=3PT0414<00h@3@092`P0
0P0@4Pl200h@3@09010B3`0>40d03Q0=00`>2`0A4a00418?014C400@4Pl03Q0=00804aDB00@03a4>
00h@3@0?4@h0418?0P0?4@h400h@3@803a4>00L03@l<00`>2`0@4Pl03Q0=010B3`092`P04a@A0080
4A4?00@04a<A014A3`0?3`d03Ph<0P0D51801@0A4@l051@B00X:200D5180410>00804Q8@00H04a<A
018B400?3`d04Q8@01<C4@0B4Q0200l?3@0>00d?2`0>40`0418>014C400@4Pl03@l<01@F4`092`P0
4Q@A00lA3@0B51003a4=014C400B5142014C400801<E4P0<3P/03a4>018D4@0E5a@04Q@A010B3`0C
5A8200lA3@0401DG500>40d02P`900lA3@80418>01@04A<@018D4@0A4a00418=01<F3`0@4`d03@l:
01PJ5@0Q8al04aDB01`N6`0E5aD05ALF00h@3`0D5QD04Q@C018D4@0B51005QPD014C40804A<A01L0
30h>01<E5P0>3a404a@G01LH6`0E5QP05a/J01DI600A5A@04QHE01DI600C5aH041@C018F5@0F6QT0
4ADD01HJ6@0C5aH04ADD024U901RIVD061`K01TM700201<G5P0N01LK6P0T:2L041@C02HZ:@0O8b80
6QhM01LK6P0C5aH05QXI01LK6P0J7Qd05QXI01DI600G6aX04ADD01TM700J7Qd05A/I01dS8@0L8R00
;C<a01TO7`0N92@061hN01PM800K82<07R<V01<H700N8bH072DR0P0M9R80:@0N:BH07b/Y020];00N
;R`08C4`024c<P0[?C`09c/j02i6@`0]BTH0<D]803eFE@1@IFH0H7Ae07n<T02PYjl0`L7;0>SQkP3o
lol0ooSo0?ofo`3omol0ooSo0?C]n`3Ee>80/kW508fJX`1^PHP0H7=j05EZL015GF80?UEL03UAE@0h
D5<0>E5D03I>D@0eCE00<d]>039:C@0aBD`0=4a?0080>U9E00/0<DU<02i7B`0fCe<0:4550318BP0c
Bdd0;TI802]0@@0/@D80<DE60355A00202i2@@0903E9A`0gC4L0>e1;02m4?`0]@Sd0<DI103I;AP0a
AT40;T<n0080;D8m00H0<4E002m3@P0/@3l0=4Q60355@`0cAdD203E:A@0h0315@00`ACh0;d@m02Tn
=`0/@CX0:d0k03eBC00hCDL0<TM103A9@@0]@SP0=Ta002Y0<`0X?bl0:T4a02i5=00bBCP0:3hb02m4
?00lDDd0?51?03iAEP10DeT0A5MM041CF011EE@0>De:03U>AP0gCD80=4Xo03I;@@0gCT<0>4i503Y@
A`0lDTP0<dPo07^@Q`19GUD0<4Hk03Y@A@0hCDD0>De<03Q=AP0fC400=4/l03A:?@0eBT00=4Q603M;
C00lD4l0=TY60357>P0fC400=DY203U>A`0kD4T303aABP0?03M<A@0iCTL0>e1903Y?B00gC4D0=DY3
03U>B@0hCDP0>Di903Y?BP0mDTd0?eA?041ED00gC4L0>Tm:0080>4e800X0=DY30352=`0hBCl0?4e3
04aMD`1=GUH0<T<k02dn=P0W>380<44k0P0dACl08P0^@3/0<TE20314@@0Y>cL093Ha02Xj=@0_?3P0
:3@`02D`:`0X<bd0:C</02Ta:`0X<b`0:cP`01dZ8P0T<2T072LQ02<^:00[=C00;3D`02Xc;P0[<Rd0
:S0[02D[9P0S:b<08B/R02Pb:P0T;RH07BLO02@]:00Q:RD07RLR01PQ7P0V;b`201`U8P1302<W9P0N
8R407B4P02@X9`0N8R40720O018F5@0U:BP051PG020T8`0D61L07b<S01PM8@0H7R@05Q`T01/P:`0W
;CL0=S]602hd?P0U:c<06AhU01LM8@0H7R4051`J02<Y9`1;DDl092PW01LK6P0F6QT06A/H01DG500H
6QH04Q<>014B3@0F5a804Q<=01XJ600F5Q@051@B01LG5@0H61H05aLE01HF500D51805ADC018B400F
5Q@061PF01<B400F5A<04a8@014@3P0D4a405QDC01<B400B4@l06APF01HE4`0C4Q0040l=01/J600@
3`d06QTG02@S8@0O7Q`04A0>01TH5P0301<B400:00X9200F5A<05QDA01dL6P0F5A<030/901LE5P0<
2P/03@/<01hL7`803`d@00P03P`A018@4`0;2@/05A<D00d;300D4Q<040h?00`:2`804@l@01P03P`=
00l=3P0@3Pl03@/<018@4@0?3@h03@/<00/92P081PL040h?01`J6`0?3@h04@l@00d;300:20T03P`=
00`:2`0>30d03@/<00h<3@0;2@X03P`=010>3`0A3a0300d;300700d:2`0>2P/04Ph?014=3P0>2P/0
2@D600l;300200d92P<040`=00D03`/;00h:2P0>2PT03@T800l;2P02018>2`0Y00T6100B3`X04Pl9
010=1`0C40X04Pl<07YfM@0[9bH0510?00`81`0=2@P0510?00d9200<2@P030P7014=300=2@P030H6
00T30`0=20P040X:038/;00@2PX02P@400d71`0?2@T03PP8014;2`0D3Ph04P`<00`61P0I4a<071HF
01<=3@0;1@D03`T900h8200<1PH05@l?00`61P0;1@D01P0@1@T04P0B1`/03P<700X10`0@1@T050T=
05=8CP0P5Ad04PL@00l4300@1Ph03`H<0189300G4A<02`H5010<2@0=2@H02`L400`91ACooooo000K
ooooo`03010I5P0=5Q<02a@A00<0318@00@03a<B010C4P0@4Q40418A0P0?4A00400:3`/05Q/G00P=
2@083@T0314=00/@300A5Q803Q<?00dB3P0?51003Q<?00dB3P0O8Ah04Q@A014C400?4@h200X<2@06
018D4@0C5A804A<@01<E4P0E5a@04Q@A0P0?4A0200h@3`803@l>00d030h=00lA400?4A003a4@01<E
500G6AH04A<@00h@3@0;3@X0418?00T;200>40d0418?00804aDB00P0418?00h@3@0>40d03a4>010B
3`0A4a00418?00lA3P804A<@0`0@4Pl02@0?4@h03Q0<014B3@0C50l05aPC01DF4@0A4Pd03Pl:00l@
2`0200h?2P0D00l@2`0@4@`0414<014B3@0B4`h03a0;00`=200>3`X0:R/V018C3P041@00?3dh034b
;@0C50l030d900h@3@0@4Pl01PP502@V8`0>40d300lA3P803Q0=00D03@l<010A300<3@P03@h9010A
300200d>2@0<00T:1@0:2`H04a@?00d>2@0?40/02@X601<D3`0?40/01@H201hO6P0;30L04Q<>0P0?
40/2010A30804A8=00X0BDU702PX9P0=3@/04Q<>00h?2P0?40/02``600l@2P0;30H02P/30`0>3`L2
00d>1P0M00h?2@0<3PL020/4018D3`0;3PX0008000dB3P0A5Q809B/W00lE4@0<4Ph08bPT01/P700=
4@`03Q0;00`?200?4@X03a0:00h?1`0?40P04149018C3@0>3`T04A8<018C3@0>3`T0414;01<D3P0A
4P`0100@4@/02P0B4`h04a@?00h?2P0>3`X03@h900P9100D5A003@h900X;1P0;30L200d>2@803Q0=
00H03a4>00`>2`0<3P/04Q@A014C400@4Pl200lA3P803Q0=00<04A<@00lA3P0C5A800P0=3``00`0F
61D03Q0=00h@3@0600h@3@803a4>0P0@4Pl01P0A4a004Q@A01DG500Y:bP04Q@A010A3`804Q8@00X0
4a<A014A3`0?3`d03Ph<010@3P0B4Q00410>00`<2P0=3@/0410>0P0C4a40900?3`d0410>00l?3@0>
3P`04A4?01<C4@0D51804a<A01DE4P0C5A004A<>00`>2@0;3@X03@l<018D4@072@H04A<@024S8009
2`P02P`901TK600=3``02`d:00d?300D5Q<05QPE014C400@4Pl04A<@018D4@0A4a00418?01<E4@0@
4Pd04A<>014C4080418?00D04A<@010B4@0?4@h0418?014C4002018D3`0J00/>1`0H6aD04Q@?00h@
2`0D5Q80418?01LI5P0?40h03a4@02T[:P0f>3L0418?01`N6@0B50l01`T400T;200N81h06adL020Q
8`0H6A/04a@F00l@4P0;30h09RLY00lC4P0D61L2014E500301<G5P0>4Q405QXI00805a/J01H05QXI
01<G5P0A5A@03a<B01<G5P0W:bX04ADD01dQ800H71/05a/J020T8`0U:BP05a/J01PL6`0I7A`0:Bd/
02@X9`0H71/05a/J014E500D61L061`K0`0F6QT201LK6P0S00dC4@0B61H0728P059HEP0P9RH051XJ
01lU9@1/LG@09BX]01LL7`0J7b<07R<V01PQ7`0K92407BHS01dW9P0L:2H08c0_02@d<`0/?3/0;3hm
03E7A`0mDE00Df]X02]8A00nF5D0GgQf065fM`1VNW/0MX>709^RZP2h^l@0h=_X0?[]oP3omOl00P3o
n?l05P3onOl0lnck0=?EhP2c^LD0S9RR06n2R@1PM7/0DVU`04MNIP13FV80?eIM03]CE`0lE5P0?EEI
045IG@10F5`0>U9F0318C00]ADT0<DU=039:CP0^ATX202i7B`0402m8C00^ATP0;4A602U1@`80:Sm0
01P0;D520355A00bATD0<TI403E:A@0bAd80;T<n02a1?00^@ch0<4E00397@P0aAT40;T<n02]0>`0Z
?cX0:d0k02e1?`0]@D00=TY80355@`0cAdD0>Tm:045FD@0dBD@202m4?@0L02Tn=`0^@c`0:d0k03mD
C@0lDDP0<DHm02i4>00/@SH0<DLj0398>`0eBch0=4Xm03iDA`0bB3`0<4Dl0315?`0oDe40?U9A045E
E`10DeL0>TeC03]?D@0nDU40>De;03M<AP11F4h0?eI<03aCB@80>4m501h0?EA:049IC`0iCTD0K85h
03iCBP0bB3`0>4i202e2>@0fBTP0>Di703Q>@P0gCSl0>e5403iDB00hCDT0>4a;03U=C00cAd<0<4Hi
03A:?@0gC4@0>Di703]@B@0jCdP0=T]403=8@@0gC4D0>4e603U>A`0jCdP203U>A`0403]@B`0eBTD0
<dQ303Y?BP80?U=>01/0>e1;03U>B@0mDTd0?55<03I;AP0eBT<0>de2041AA`0iBT00@eA:04MHD00X
>C408S<[02`m=`0`@C/072dW03U:A00nCdT0=DQ203E6@00_@3X08c@^02@c;P0X=S408bl[02D`;00Y
<c000P0W<2d0>00X<R`09C8Y02@a:00P;2D07bXT024/9P0S;BL09c0[02Tb;@0X;b/0:Bl[02L]:@0S
:bD08bdT02@^9P0U;bL08bdU020Y900L9B0041TD02H_;00K92404a`I020Y9P0F6QT05a/J01XN7@0L
81l07B4P01`P7`0M8B007b<R01`P7`0S9bH0720O01TN7P0O92P072<Y01XQ:@0K8R`082La02L]>@0Q
:3807RD]01TQ9P0H82<0620R01LP7`0>5180>3hl014E500I7A`020`;01/M6P0P8Ql061XF0P0G61<0
3P0F5a4061TC01DE4`0?3`d04A4?01<C4@0G5aD08R8P01DE4`0D51804Q8@01<C4@0E5A<05QHD0P0G
5Q@04`0E51804Q4?014@3P0D4a4040l=01@C4@0K6QP05aHD00l>300C4Q005aHD00h=2`0E51807QdK
01LF500;2PP04a8@018A3`0A40h00P0B4@l0200C4Q006APD024P7P0L6aT05A@B018@4@0@3Pl04a4B
0P0F51L04@0D4QD04Q0E01<A500S8B<04@l@00l=3P0=2``02`T:010>3`0A3a0040h?00/92P0=2``0
40h?00d;300;2@X02PP9008040h?00@03`d>00H41@0>30d03P`=0P0=2``00`0<2P/03@/<00d;3004
00d;300=00/92P0?3@h04@l@00`:2`0=2``03P`=00X7200B3Pl030P900L4100?2``040`=00/72002
00d92P0500h:2`0?2``040`=010<3@0?2``00P0@30/02@0>2PT02`L400h;1P0/:B804a0900T60@0@
3@@01040010=2@0200l;2P0Q014=300?2`X02PH5085mO01NFUT06ADD00<0000D40l03@T800d71`0>
20P05@l?00T30`0400005Q4A01LA4@0D3Ph03`T900h8200?2@T04@/;00`61P0D3Ph01`8200X4100B
30`03PP800X4100D3Ph01`4100@0000:10@040X:00L040D901403`@800d21P0>0`L040D90146300?
10`03P<;00d22P0=0`/03`H;01482`080P@02`H501<?300A3@X03@T601/H4`0Dooooo`006oooool0
2@043@X0214>00TB3`093`d02a4?00lE4`0?4a803a8A010B4@0300lA400900lD40062`D041D?00dB
300;40X03Q<=01HK5@0=4P`02@h800803A8<00D02Pl901HH4`0>40/0418=014C3P0200h@2`08010B
3@0A4`h03a4<014C3P0C5A00418=010B3`0>40d200d?300D00h@3@0?4@h04aDB018D4@0>40d01`T6
00H81@082PL04Q@@00lA300<3PT03a4<00P:1@0=3`X04A<>01@F4@0C5A003a4<00d?2P0>40`200lA
3P<0418?00<04A<@00lA3P0=3``00P0>40d01P0<3P/02``800l@2`0D5A005QLB018C3P803a0;01X0
414<00l@2`0>3`X03Pl:00l@2`0A4Pd04Q<>014B3@0>3`X03@h9010A300A4Pd04Q<>01hO6P0Q8Qd0
2P/600P9100C5A405ALD01<E4P010`003a4>00h@3@0@4Pl03a4>00h@3@803@l<00<03Q0=00d>2@0<
3@P00P0>3`X0200:2`H03@h9014B3@0=3PT04Q<>000100092PD03a0;0P0>3`X0100=3PT04A8=00`=
200A4Pd200l@2`80414<0P0A4Pd08P0L7AP051D@010A300A4Pd03Pl:00l@2P0<3@L0414:00`=1@0:
2`<03Pl600d?100@4@T03a08010A2@0A4P`0418<00d@2@0;3@P02`d900X?2`0J7a/00PH300D;1`04
2PH01@/707YoN`1cN7@02`h:00T;1P0=40T030h700/<1P0=3PH2010A2@0F01@C3P0B4@`04a8=014@
2`0>3@P04Q4<01LF4@0D4`h04a8=018A300A40/04Q4<00d>2@0?40/03@h9010A300D5A004Q<>01DF
4@0<3@P02P/600d>2@803Pl:00P03Q0=00lA3P0A4a0061XG00`>2`0C5A804Q@A010B3`@03a4>00H0
3@h901XK5P0`<B`071dH00H70P0E5Q4500l@2`0300lA3@0?4@h03a4>00<0418?00T04aDB018D4@09
2`P06Q`I055CD00[;BX030h:010A300A4Pd00P0B4`h0100A4Pd03a0;00d>2@0>3`X200l@2`0500h?
2P0?40/04Q<>01<D3`0B4`h00P0F5a80100A4Pd03@h900h?2P0B4`h201@E400?01<E400A50d030h9
00/=200=3`X04Q@A00/=2P0?4@h01`T8014C4P0I6aX03Q0>014C400?4@`03Q0;00804Q@?02/03@l:
010B3@0A4`h04Q@?010B3@0?4@`04A<>010B3@0?4P/0418>01@F4`0D5QD04A<B014B500A4a804Q@B
018D4@0C5A004aH@00lB2`0B50h04A<>010B3@0A4`l051HC01HH5@0C5A<05aTH01`N7@0S9B@0828O
018D3`0>40X06Q`G01DG50082@X04Q<E010A5@0;31005AHJ01TJ700A4Q<051HE00804QHE0P0G6aX0
0`0@51<03a<B01@H5`0201@H5`0n01<G5P0A5A@03a<B01`P7`0C5aH05ATH00lC4P0M8B004aLF01PL
6`0K7ah07b<R01DI600F6QT04aLF024U900K7ah04aLF01PL6`0C5aH051PG01/O7P0H71/05a/J01HJ
6@0G6aX061`K01dS8@0W;B/06b4O02D[:@0>51@0728R01dS8`1YKW406b0S01dR9@0U:Rh05Q/N01TR
800K92<07BHU01dW9P0L:2P06RLW01`/:`0Z>SX06bd]03E7A`23UiP0X;Nf03==BP0eCd`0EVm]05Q]
KP1QMGH0M8>709>LX`2]/KX0dloK0?3Um@3ml?l20?oio`0f0?ofo`3/j?H0cLoL0:jd`027UZ00LhF?
06AhP@1AJ740Bf=]04MOJ@0mEE/0?5=I041GG@0jDEL0;dI<03A;D@0iD5H0<dY@02m6C00^AD/0;dI<
0399C`0Z@dL0;TM;039;C`0_AdT0:d=502U1@`0aATL0;T=402e1@P0`A4<0<TI50314@`0_@Sh0>Da6
03I9@`0Z?CL0;D0j0313?@0bACl0<4<m02/n>00X>cD0:C`f02`o>P0fBTP0?51?03Q<BP0gBdT0=4Q6
03Q=B011EU40=da70P0bAd001`0/@CX0<DHo02m2?00eB480>dm603E9?P0/@3@00P0bASX04`0_@cL0
;D4f02e1=P0nDTP0=DY10356?`0bBD80@eUF041FE010EEH0?E9C03Y?DP0oE5D0?eEC03Y@C@0mE4d0
C6=K03E?AP0gDDP00P0jE4/0@@0gD4H0<dY003U@AP0hCd@0<4Hj03E;?`0gC400;40g03I:B00jCdH0
>4i103I=?@0kDD@0@EM;03]@B`0dB4L0=TY803E:@`0eBch0>4i103U>AP0jCdP0>e1903U>A`0fBd@0
=DY303aABP0jCdP0>Di703Y?B00mDT/0?U=<03mDC`0dBD@0<TM203M<A`0jCdX0>e1;03U>B@0kD4/0
>Tm:03]@B`0gC4L0<DHo03m@A@12DdT0>DY003A5>`0fAcl0<D8j02Lh<00`@C/0>T]504EFD02L[JL0
PY><03I7?`0fACh0=4<l02/j<`0Y=C40:3@`02Da;@0X<S40:S@c00809Bl^01`0:CD_02Tf;00W=2/0
8RhU01hY8@0O:R@08bdW02Tb;@0Y<Rl09bh/02P^;00V;2X08BTS02<]900U;bL09S0X028/900N9b80
82TT034j=@0B6aP092dZ02Tb;`0P:BH05a/L01hR8`0M8B805QXK0P0J7Ql02@0P92D02Ph?024U9P0P
92D0:bl`01lT9P0R9b/07bH/01hU;00301`S;@0H01/R;00L8b/06b8X01HN8@0E7Al06B8P00hD4P0G
7A/02`l>01hR8@093@`06Q`I020R7`0I6QH061TD01TJ5@0G61<06AXD01/K6@0F5Q@04Q8@014A3`0L
71X0;bl]0P0E5A<401@D4P0=01LF500>3@/04Q4?01@C4@0A40h061LE010?3@0E518061LE01@C4@0?
3P`05A@B01TH500301<B3P04010?2`0B4@d04Q4=018A3@804A0<0P0B4@d0200G4a007ATH01TE500D
40l04@d>00l;300D41404PdA0P0C3Q80200A31803`X>02@R900;2@X040h?00h<3@0=2``06ALH0P0>
30d02P0;2@X030X;010>3`0?3@h04@l@018@4@0L6Q/03`d>01`J6`0:20T200h<3@803@/<00<030X;
00h;300?2``0100?2``00`0>2P/040`=018>3`0200l;300:010<3@0?2``04@d>00<0000K5aP030P9
01DA4P0<20T03@T:00l;30803@T:01X040`=01<?400>2P/02`L600`81`0A3@`05A4>01@A300l>C80
8AhG01/H3`0R81@00`40010<1P0@30/04`l>01DA400<20L03PX902dY:00[9bH03@T800/71P0Q7A`0
1P8101XD50803@L701D0100000P20P1FD5008adM01XD500>20P030H600h8200=1`L0100001@>3P0E
3`l03`T900d71`0?2@T01000014;2`0G4A4050h>01TC4`0=1`L01P0@1@T201462P0501052@0?10P0
3`@800h31`0=0PP00P0>0`T02@0=10T03PD:00h5200G4A<03@P700H20@091@@02PH503Da;P0Doooo
o`006oooool0200@6AH02Q8?00L?300;4@l03A<A00`B400>4Q403a8A0`0?4A00200>40d04AHB00X?
2@0F6aD02@h800dB300;40X03A8<0P0@5@l0600>4`d03A8<00hC3@0<3PT02P`700h@2`0?4@`03@l:
00h@2`0?4@`0418=00d?2P0@4Pd04Q@?00lA300@4Pl03@l<00`>2`0=3``03a4>014C400I6aP03Q0=
00d?30804Q@A00P0418?010B3@0>40/030h9010B3@0:30L03a4<00d?2P80418=0P0>40/0100?4@d0
3a4>00lA3P0>40d200d?300@00`>2`0;3@X02`d:00d?300@4Pl03a4>00d?2`0@4@`04a@?014B3@0?
40/0414<018C3P0A4Pd0414<00l@2`803Pl:01P03a0;010A300@4@`0414<00l@2`0>3`X04A8=00X;
1P0:2`P05AHA018C3P0=3PT06AXF01PJ5`0>40d04A<@00lA3P0=3``0418?00lA3P0=3``030h;00d?
300@4Pl200`=200700l@2`0=3PT02@X500h?2P0:2`P061TD00h?2P02010A300700d>2@0>3`X03@h9
010A300A4Pl04Q<>010A300200d>2@<03Pl:03/03a0;00H70P0<3@P03a0;00h?2@0A4P`03Pl900d>
1`0B4`/03Pl700h?1P0B50X04Q@900`=1@0=3PH0414901<D3P0D5Q004QD>014C3P0B5A406AhJ00<8
100C61@041@A00X@300A5a<0J6eY065VHP0D61<03@l:01@G400>40T02``600h?1`0@4@T03Pl700h=
1`0@40T04A0:00l?200@3`T04Q4;01HE3`0C4``04Q8;014A2P0A40X04A0;018C3P0@4@`03a0;010A
300A4Pd04Q<>00`=200B4`h051D@018C3P02010A300700d?300:30T05QPE034c<00B514030h;00d?
300200`>2`0900h@3@0A4a004Q@A018C3P0H6A@09BHQ01/L5`0=3PT04a@?00D03a0;00<0414=010B
3`0@4Pl00`0@4Pl01`0>40d04A<@018D4@0A4a00;S0]01DG500<3PX00P0@4@`2018C3P0<01<D3`0A
4Pd03Pl:00h?2P0A4Pd04a@?014B3@0@4@`04Q<>014B3@0=3PT03a0;0P0@4@`05@0A4Pd0414<01@E
400E5Q404A8=00d@2@0>4@X04A@>014C3P0@4Pd03Q0<00d?300C5A804Q@C014C4`0<3@h05QLG01<E
4P0A4`h03a4<014C3P02018D3`0;010B3@0A4`h04Q@?00lA300>40/03a4<00hA2P0@4``04A<>010B
4@0A4a800P0E5QP03P0F5aT05QPF018D4@0@4Pd04QD=018E3P0>40X04aD@018D3`0@4Ph07AlL06U[
J00E5aD05aTH0P0B51<04`0C5A803Q4;01HH4P0<3PT04aDD01LH6@0E5QT05QLL01PI7@0D5AT03@h@
01TK6P0C5A<06alN01@H5`0J7Qd06AdL014E500F6QT00P0D61L02P0E6AP05QXI01LK6P0G6aX051PG
01LK6P0A5A@05ATH01`P7`0A5A@201DI600301TM700H71/07R8Q00805a/J00<04aLF00lC4P0K7ah0
0P0F6QT0>`0N8R406QhM01LK6P0G6aX061`K01TM700F71X06AlM01DK6@0M8b405adM01XP800K8B40
5a`O020U:00M8RD04aPL020U:00N9bD07RLV01lX9`0O:BT07b/[020];@0P<300:CTi02@f=P0]?d00
;D5203eDD`0gDDh0:48o03QAD017Gel0Bf1Q06inPP22SY@0UinV0;Vja@3Gdn00j^;a0?K[nP3gk?X0
l>Wg0=_HiP2l`Ld0XJZf086AV`1aQHl0HWV204aUK`18Hfd0A5iX03iFG`0kDUP0=TeC03YAE`0nEE/0
>U5G0080<dY@01H0=4]A02m6C00^AD/0<TU?02i7B`0bBdl0<da@02i6B00[@dD0<4Q:0315AP0^@d@0
;T9303=7AP0dB4L0<4A202/n>P0hBdD0=DQ202`o>@0cAT00<4<m0P0Z?CL01P0[?SP0;D0j02m2?00a
A3l0@eME04]OGP80>Ti<00@0=4Q603A9A00iCTT0=DY50P0cB4401`0bAd00=da50396?P0hC4<0=TXo
03A8?00fBch00P0dB3`0:P0^@SL0B5]D04QKEP0oDTl0>Di;03E:AP0fCDL0AeeJ04=IE`10EUD0>e1A
03iCE010EED0?eEC03aBC`0mE4h0?UQ@03mJDP0jETh0>5=;03YDB`0lET`0?EI;03I>@P0gCT80@UQ<
0398>`0cB3`0>De203Q=B@0jCdH0=T`o0399>00hCcl0?UA803]@BP0`A4<0=4Q603aABP0mE4D0?UE6
03E:@P80>Di700L0>4e603U>A`0jCdP0@5E>03iCC00mDT/0?U=<0080?eA=05/0>e1;03Q=B00gC4L0
=4U403eBC@19GUT0?eA?03aAC00cB4<0>4e803]@B`0dBD80>D]003Y;@@0oD4H0=TLm02ho=`0Z>c<0
9CH^02Tj=00hBD<0;Sli04UJE013DTT0<cld02ll<@0`?C<0<3`e02di<`0/=c<0:3@b02Td=00b?3h0
;cXm02Lb=@0W=2l0;3T_02Xg;P0T<2P07bXR01lZ8`0T;RP0:S<^02Tb;`0T;2X09B/Z02@Z:@0R:RD0
8bdT02<]9@0R;2@082XR01lX8`0M9R406b@O02D^:`2:Ti00DeaI01`U8P0K7b008bLX01dQ8P0J7Ql0
9BTZ01lS900N8R<0<cLh01dQ8P0O8b@09BTZ02<X:@0S:bd07bP/01/T:00J8RT07RH^02@/=@0N9Rh0
72@[01TQ9@0E7R0051hM01HO6`0D6QP06b4O01HJ6@0B5QD05a/J01/M6P0L7Q/05ALC00805QLB00P0
51D@01HG4@0L71X05aLE01<C4@0B4Q0061PF01`L6P@05QHD00/051@B01<C4@0Z:BL05A@B01PG5@0J
6AL04A0>01DD4P0F5A<04a8@014@3P0201<B4003018A3`0I61@04a8>00804Q4=00H04A0<01HE4@0B
4@d04Q4=010?2`0A40`2018A3@0D010<2@0E4A004`l>01<?3P0C3a004@d>01DA4P0@2`l04@`@01@?
4`0A31803PT=014?4@0=2``04Q0A01<A4P0=2``030X;00h<3@0?3@h2010>3`803`d>0P0=2``0100;
2@X04@l@00P61`0<2P/200h<3@803@/<00<030X;00h;300@30d0100@30d300l;3004010<3@0?2``0
3`/<00l;30804@d>00L0E51A01<?400B3`l030P9018>3`0F4Q<04`l@00803@T:00@03PX;00X61`0=
2@T04`l?0P0A3@X0:00H5@l0Cda5092=Q01eLfL0;R`O02DS5P0I5Q004Ph=00h:2@0B3Pd02`L601hJ
6@0@3@`04`l>00T61@0?2`X040`;00h:2@0@2PX01`8200h8200B30`02`D501TC4`0D3Ph04P`<00l9
2@0<1PH03@L700l92@0G4A403@L702hX:00:1@D04P`<00X4100E3`l01`4100d8200=1`L200`61PH0
40D900<03`@801462P0A1PX00P0A1PX200l4200;01052@0A1`T040L;01072P0>1@P01P42018=3`0@
3@d0BTI802`X:@1FDU805?ooool001_ooooo00T0IVm/03i7A00H8Ah04QPF00/A3`032@L03A4@00hA
400?4A000P0>40l0;00=3``01``6014F400>4`d01@X4010E3`0<4@/03A8<01TN600K81X03a@>00/@
2P0?50h04Q@?00lA300A4`h03Q0;00X<1`0<3PT03@l:00lA300<3PT03Q0;010B3@0=3`X03a4>00d?
300<3P/03Q0=00lA3P0@4Pl0@dE201dO700=3``02`d:00P:1`051`803Q0;00d?2P0;3@P0418=00/=
200A4`h03@l:0`0@4Pd02P0B50l04A<?00h@3@0?4@h0418?00d?300;3@X03@l<00lA3P0=3``200h@
3@0:00`>2`0=3`/03a0;00h?2P0<3@P03Pl:018C3P0C50l0414<00l@2`803Pl:01<03a0;00h?2P0=
3PT03Pl:014B3@0@4@`030d800X;1P0@4@`05QLB00h?2P010P002P/6014C3`0=3``030h;018D4@04
1P<04aDB00803Q0=0P0=3``0100>40d0418?00l@2`0=3PT200l@2`0900/<1`0?40/0004001/L5`0<
3@P07AhI00H70P0>3`X0414<00803Pl:00<0R8V402`]:00=3PT00P0?40/2010A30@04A8=00P03@h9
00d>200A4P`03Pl900/<100@4@T03@h600`>0`804A<80200414900l@200?40P04A8<010B2`0<3`P0
1@L205mSGP1dNGD02@h:00H<200?5A4051XF00hC3`083@T000D100d@300@4Pd05QTB018D3P0?40X0
3a0800h?1`0=3PH051@<018B2P0=3@D03`l701HF3P0D50`04A49010@20<03`l700X0410801<D3`0@
4@`04A8=00h?2P0<3@P03Pl:00l@2`0A4Pd03a0;0P0=3PT0200?40/03@l<00lA3P0?4@h04Q@A00T;
200C5A803a4>0P0=3``02@0A4a005QPE01PJ5`0A4Pd03Pl:00P9100?40/04a@?00d>2@0500l@2`04
010A3@0@4Pl0418?010B3`803a4>00X04A<@00d?300;3@X03a4>01dO70092`P04aDA01DF4@0C50l0
414<0P0>3`X0100?40/04A8=018C3P0C50l2018C3P07010A300?40/03a0;00h?2P0D5A005QLB01<D
3`0200l@2`0/014B3@0B4`h0414<01<F3`0A50d030l800/=200=3`X04Q@?01DG500:30T0:B/Z01@E
5`0F5aT03Q0@01HH5@0D5Q404A<>010B3@0B50l05ALB010B3@0A4`h04Q@?010B3@0?4@`04A<=00`?
1P0A50/04aD@010B4@0B51<07b0R01DF600H6A/05aTG014C400>4@X041<;01`O600A50h051HA01LI
500D5Q8201PJ5`0B01LI5`0>40l03@l>01`N7@0K7AX041<<01HI4@0J71L05aTF00d>4@1CE5P0GUmT
014B5P0J6ad071dO01@F500@4Pl05a/J0`0B5QD0700@51<051PG014E500A5A@04QHE01<G5P0F6QT0
61`K01DI600N8R404ADD01<G5P0J7Qd0720O01DI600G6aX061`K01LK6P0M8B0051PG01TM700G6aX0
4QHE01XN7@0E6AP05QXI01dQ800I7A`201HJ6@0:01TM700K7ah0728P0416A00oAD<06b4O01TO7`0L
8R807R@T01TN8@807b@W00<06QlS01PM800M9RH00P0L9B@0;00M9bP07BTY020];P0fATH0@U9B01d_
<00L;S0083@e02e2@P0[A440<4U603I?C@18H600CfAU05]^L@1bPHH0QI2F0:2V[`2k^lL0b/SE0=SB
h03Le><0em7O0<;2c`2W[kX0TYjZ07J9T`1TNXD0EG1i04ERJ`11GFP0?5QS03QBFP18GfD0Bf9X03Q?
E@0cBU00=DaB0317C@0bBDl0=DaB0399C`0_AT`0<4M=0P0cC500100aBTh0;4A602e5A`0dC4h20315
AP0F0314A@0^@T40;D5002/o?P0dAd<0=dY40354?P0^@C/0<TDo02Xm=`0U>3809cXd02e0>P0bACl0
=4M103E8@`0iCD/0>dm>03=7A@0dB4H0<dM503E:A@80>4e804P0=DY30356?`0aASl0=4U202e1>00i
CD80;d<g02a0=00fBSd0;T8f03I:?`0]@3T0DVEQ05=UI@0mCe80?4mC03Y@C@0hCdX0AE]H03mED`0n
E5<0>Tm@03]@D@0kD500>e5?03mEDP11F5<0=Tm903QCC00nFU<0@UeF03iID00eCdD0;dTn02U1=00b
BCd0?59602m5>00hCD40=d]003M<A`0gC4<0=de003U@?`0oETH0@UQ;03U>B00bATD0=TY803Y?B00f
CCd0=D`l0356?P0iCTL0>e1903Y?B00lDDX0?eA=03iCC010EDh0@EI?041ECP0mDT/0>e1903I;AP0i
CTT0>e1;03E:A@10EE00DFIQ03]@B`0nDdh203eBC@0S03I;AP0^@c`0=4Hk03A5>`0mCT@0=dPn02Lh
<00Y>S80<T<k02Hg<@0Z>cD09SLa03I7@@0kB3l0=3la02dh:P0W<BH0:3@Z02Lb:P0V<Bd09C4a02Xe
=`0lAd/0>DI<02dj@00S<Bh08c0V02Db:00U<BP092lW02Ha:@0W<B/0:34/02D^:`0P9bH00P0R:2P0
4@0R:RD08R`S01lY8@0M9al07RPP024Z9@0E7QT05QlJ02H_;01XLFh0=Sll01`U8P0M8B807R8S01TM
7P0M8B809BTZ0080720Q01d0EUYK01PL7@0N8R<05QXK01hS8`0N9RP06B<T018L7P0A6Ql05AhS01hW
;@0J8bP05b4S01<M7`0E7ah05b8N01HQ6`0B61H03A<A018F5@0=4A003a<B01TK600K7AX05ALC01LH
4`0H6A@05QLA01LH4P02018B4004014A3`0F5Q@05aLE00h>30<05QHD0`0E5A<0400T8b405A@B01HE
4`0H5aD04a8@01@C4@0H5aD05A@B010?3@0C4Q005aHD010?3@0B4@d030/7010?2`0C4Ph4014@3080
40l;0P0A40`01`0E4@h05Q8A01<?3P0D40l0510A010<3@0D41400P0A31005@0D3a<050lE01<>4P0A
3a40518C00d;300?3@h05A<D018@4@0F51D03@/<014?400E4a@040h?00d;300<2P/06ALH01<A4P1:
B4T02`T:018@4@0200h<3@803@/<00<030X;00h;300?2``0100?2``04P0@30d03@T:00d92P0A3@h0
3`/<00h:2`0;1`P06QHG01TE5P0]:BX04@d>01@@4@0;1`P04`l@01LC500E4A803PX;00/720804@d>
01X040`=010<300@30T07ATF04Y7@@2PWI@0oO__0?Cci`1THUD0928E014?1P0?2`X03PX901LC4P0?
2`X05Q8A00d9200300002PH501@@3`0=2@P030P7010:2P0B30`03PP800d71`805a4A01801`4100`6
1P0A2`/03@L700X4100<1PH0100001@>3P1jM7@07ALG00T30`0?2@T0100001D?3`0l=SH05@l?028L
700:1@D601052@0400l4200@1@T040D901462P804PL;0P0C2@X02P0B20T04@P901072@0@1`X02`D7
00P31@13?T80h]gQ07]fNP03008Dooooo`006oooool0100G81l031DD00D>300:4Q02010F500P00dA
400>4A003Q0?00h@3`0>3`l03@l=010D3P0@5@h01P/5010E3`0=4P/03a@>00X?2@0?50h041D>00`A
2P0:3`T0314:00lB300>40X0418<00d?2@0<3PP0418<00h@2P0?4P`030l900lA2`0A4`d03Q0:00d?
2P0>40/400lA300401DG4P0A4`h03a4<00h@2`803a4<01/04A<=00lA2`0<3`P0418<00T<1P0>4@X0
3a8;010B300?4P/03Q4:010B300=3`/030h:010B3`0E5a<051HB014C400?4@d030h:00`>2`0=3`/0
3Q0<00d?300?40`03a0;00`=200?40/00P0C50l06`0A4Pd03a0;00h?2P0?40/0414<014B3@0B4`h0
414<00h?2P0?40/04A8=010A300=3PT04A8=018C3P0@4@`05QLB01@E400=3`/051HC00h@3@0E5a@0
10H301<E4P0<3P/03@l<00lA3P02010B3`0500lA3P0C50l03Pl:00l@2`0B4`h00P0@4@`01P0C50l0
3Pl:0493?P0R8ah03Pl:00l@2`803@h900@04A8=0452?@0P8A`03a0;0P0>3`X200l@2`80414<02X0
4A8=00h?2P0@4@`04A8<00d>1`0?40P04A8:01DF3@0@4PL030h400lA1P0>3`H03a0800h?1`0?40P0
4A8<00lA2`0<3`P030h901<F4@0B5a803Q4>00lE400830L041DA00dA3@0>4`h01`/700d?2`0=3`X0
3A09014C3@0A4P`03Pl700d>1P0?40P0?clg02/Y8@0?3@H03P/401@B2P0=30@2014>2004010>200B
3`T04a0:018B2`8030d800<04A8=010A300=3PT00P0A4Pd04`0>3`X05AHA01dN6@0C50l02@X5018D
4@0A4a004Q@A00X<2@0>40d04aDB018D4@0?4@h03@l<00h@3@0B514051HB00h?2P0D5@l00P0@4@/0
2@0D5@l05AH@00l@2P0?40X03a0;00l@2P0?40/0414=010B3`0200lA3P@03Q0=00H03@l<010B3`0U
9b@0418?018C3`0A4P`2010A2`0:014B300C50h04A8<018C3@0E5Q004A8<00d>200?40X0414;014B
3080414;00H061TC01`M5`0I6Q@06AXD01XK5@0E5Q0200l@2P0:010C2`0@4`X03a8;00hA2P0?4@/0
418>00/=2P0f>3H0TiFD01<D5@805AHG00<06A/F01LJ4`0A50d00P0=40T0;@0A50d041<<014D3@0C
5Pl04QD>014D3@0D5a004A@<014E3@0A4`l04A<B010B4@0A4QD0414D01@E5`0F5aH04A8>00lA2`0D
5Ph06ahG010C3@0@4Pd06A/F01/M6@0B514030h;01@F500B51<051HE02/];00F61D061/C00hA2@0B
50l06A/H01LH6`1kO800OWn401TJ7P0G61X04Q@D01@F500L7Q/03Q8A01DI6002018F5@0401DI600>
4Q405QXI01@I60804QLE04l04aPG01@I600F6QT08BDT01HJ6@0E6AP04ADD01HJ6@0D61L06QhM01PL
6`0E6AP06alN018F5@0E6AP061`K018F5@0F6QT04QHE01HJ6@0K7ah05a/J01DI600F6QT06QhM01`Q
800H7Q`06R0N02H/:P0R:BL0;38b01XQ8@0I82004APJ01XQ8`0P9bT08bT/01/Q900P:2T07RLV01dV
9@0N:2T07RXZ020^;P0O;bl08S<d01h`<@0U=cP06Rh_02Xo?P0^Ad@09Cdj03M?C@11FET0?5AD05EY
K01SMGT0LX:708JAV@2FWJL0X:J`0:n__02g]L80/k>o0::W/`2>VJ<0OXbG06QlQP1CJgD0BFA^04ER
K00mFVD0>UMR03aGG`1HL7D0GWEk03eDFP0nEE/0?EAJ00<0<DQ>03P0;dI<02m7C00aB4d0<4U=02m8
B`0^AdX0;TI802m7B00_AdT0<4E60397B00cAdP0<4A303A8A`13EeH0<TI202m3?@0^@S`0;T4l02a0
>P0]@3X0:chi02Xn>00[?cT0;T4l0314?P0eB4@0=d]:02i2@@0dB4H0;d=103E9AP0iCTP0=DY403M<
AP0gC4D0<dQ103E:@`0hCDD0<4@j0355>P0dB3`0;T8f02Lk;P0^@SL0=d]102m2?00bAT@0<dE703i?
EP0jCE80@EMD03QAB`0nEe<0>55>03YCD080>eAA02@0?UMD03UBC`0hDDd0?eQC03eFD00jEDl0BFEO
051]I@1:IE`0?eU?03eFB`0fCT40<dXm03I<?`0dB3`0=DXm03I:?`0gC4L0=4U003M=@00mE480?EA4
03]AA00hCDL0>De<03mCD@0oE4`0>4i003M>@00eBT80?eA=045FC`0nDd`0?E9;041ECP0nDd`203mD
C@0C03iCC00lDDX0>e1903]@BP0dBD@0>Tm903Q=A`0iCTT0@eQB03]@B`0hCDP0?E9<03Y>B00aAD40
<dM003U:?`0lCD@0=dPo03A5?00202Xk=00N01//9@0Y>SD0B5UD02`m=`0fAd40<Shd03<k;00_=bT0
9BlR02H`9`0T;bL08RdY02Xf=@0f@d@0@4e@034oA@0U<cX08Rl]02<`9@0T<BL09C8X02@_9P0U<2P0
9BlY02D^:@0R:bP072@R020V9P0Q9bP07bLS0P0N:200<@0O:B4082TS024Z9@0M9R405alJ03@m>P0e
?S/08BXW01TR7`0M8R80724R01dR900M8B<06AdP01LK7P0L7R807B4T01XN8P0N8bH08BHY01lT9`0G
7b005b4Q01XT9P0K92T06R<X01LP900H8BD06b@V01TS900B6aT03aTE01@O600E6aP04QLE018F5@0E
6AP05a/J01<E4P0J71T05QLC01PI500J6aH05aPB01PI4`0C4a4061PF018B400A4@l00P0H61H01P0G
5aD05QHD01@D4P0D51805aLE01TI5`8051<A01h04Q4?01DD4P0H5aD05A@B018A3`0L6aT05QDC010?
3@0E51805aHD014@300?3PX04Q4<014@2`0?3PT04a8=014@300@3`/03`h9010?2P0@3`/04A0<018=
2`0D3Ph04@`;01D@400G4A<04`h?01<=3`0E3a<201<>4P0901L@5`0I51P04@lA010>3`0B41403P`=
01XH6@0/:R/08R0Q008020H700T04@l@010>3`0?3@h03@/<014?4@0<2P/09B<T00h<3P0;2@X00P0>
30h200d;300300`:300>2``040X<00@040X<00L04P`>00d72@0<1PP04`d?010:300>20X03PT;0080
3@T:00D040`=014=3P0;1`P040`=00h:2`0200d92P0400h:2`0?2``04@d=00l;2`8040`<02`04`l<
02`X9025PW`0YJ:I0=_HcP3Acl@0?S`_01hL3P0D40T05A4@010<2`0I5A@04`l>00`81`0A3@`03`/:
03Xf=@0:1PD03@T800l;2P0>20P03@L7010:2P0D3Ph05Q0@00T4100<1PH03@L700l92@0A2`/040X:
00`61P0C3@d02P@401@?3`0=1`L030H600d71`0@2PX02PD501TC4`070P8040X:00h820H040D90180
5@X>01<8300@1@T03`@801052@0A1`P050X901881`0?1@@03@D400l71`0@1`X040T;00d7300F4AH0
=2hd01hH7`0?2@lDooooo`006oooool020053QD02A<I00D?4@0<5QL041LF00hD400<4@d03a0=0P0@
4102018@4`0800lA400>40d03@l<00d?300>40d03a4>00d?300>40d200lA3P0?00h@3@0=3``04A<@
01@F4`0C5A803Q0=00/=2P0=3``03Q0=00@60`0>40d04aDB01@F4`0T9R<02`d:00803a4>00L03@l<
010B3`0C5A804aDB01HH5@0D5Q<02@/800804A<@01P03Q0<00X<2@0>40/030h:00/=2P0@4Pd04aDA
00lA3P092`H03a4=00L91P0C5A003a8;00h@2`0C5Q004A@=010B3@0@4P`03A0900d?2P0=40X03Q4:
010B3@0?4@`200h@2`0400d?2P0<3PT030h900d?2P803a4<00l0418=014C3P0B50l051HA01TJ5@0F
5a8030d800l@2`0C50l04A8=02//9`1<CDP05aPC0042000K71L00P0>3`X200l@2`803Pl:0P0A4Pd2
00l@2`09014B3@0E5Q409bTT01TK5P0<3PT03a4<010B3@0:30L0418=00<03a4<00<03Q0;00`=200@
3`X00P0@3`X00`0>3@P03@`700/:1P0300h?2P0c00h>300?3`d0418>010A300A4P`030d900`=1`0>
3`T01`P201@E3`092PD03@h600h?2@0R8al030d7018C3@0F5a403Pl900/<1P0@4@/03Pl900`=1`0:
2`D030l8018C3P0C5@l03a8;01@F4@0;3@L03Q4:00X;1P0<3@L01`P200/<1P0H6A<071dG018C3@0:
2`D05QLA018C2`0>3`L04149010?2P0>3PT04A8<00d=200F5A4051D@00L70`0A40`04A8=00803a0;
02404A8=018C3P0>3`X02``700X;1`0M7QT05AHA04M8@`082@@03@h9010A300:2`H0414<01DF4@0;
30L03Pl:00d>2@0F5a804A8=018C3P0?40/04a@?00h?200@4@T04A8:014B300>3`T03@h800h?2P0A
4Pd04A8>010A300@40h00`0A4Pd02@0B4`h04a@?01<D3`0A4Pd03a0;01DF4@0@4@`04a@?00/<1`02
01<D3`08018C3P0A4Pd0414<00l@2`0H6A@01@H100h?2P0G61<200h?2P0H01DF4@0A4Pd04Q<>00h?
2P0=3PT05AHA02<T7`0K71L03@h9010A300I6QD04Q<=00lB2@0<3`H03@l;020R7@0K7AX0418A00/=
300H6QT07b4O01<E400D5Q403Q4:1P0?4@`06P0C5A0020X500lA300D5Q4030h9014C3P0A5A@03A<A
00lC4P0830/03a<B01@F5@0=3@/03`l=01<C3P0D4`h04Q4<00h>1`0G61<0418?014C400m?c`04aDB
01TK600F61D051HC0`0C5A80800@4Pl06AhJ014F4P0?51003Q8A014E5@0N8R<04aLH01@H6@0D61L0
4aLF010D4`0=4A004aLF010D4`0E6AP041@C01@I600@5Q@04ALE00hF4`0D7AX082TV00`E4P0G81d0
3A<A01<I5`0=4a40<3Hd01<I5`0=4a4051XH0P0J81h00`0=4a406AlM01<I5`0201<I6@0701@J6P0F
71`05adM01PN7P0G7Ad04aTI01@J6P0201LM7@0601DK6`0E7A`031DD020Y:00@6QT06b@S0P0H8R40
8`0G8b405R8P01/W9@0D81h06BDU02@`<00W<c<09S8b01h[:`0O;Bd07Rh]01TY:00K;R`08C@c02@g
=@0/?Sh09SXi02Pn?00`A4<0=DY:03Q=CP0nDe@0BEiP05I[KP1PMGP0K86507J;T01oTYP0S9jU092Q
Z@2:WJ@0P9>J0724R`1VOH<0FW9g0080CFI]00T0C6M^03aGGP0gDUT0>eIM03QCFP0iDUL0=e1E03E>
D`0dCE400P0`B4`0GP0]@TH0>4eB0356B@0`ADT0?55B039:BP0`ADH0<DI702i4@P0bAdL0=D]90316
A00cBDL0=de;03E;B@0jD4h09C/h03=:A00aAT809c/i02i5?`0[@Cd0:3`j02]2?00bAd<0<TI402e4
?P0Y?C/0<TI70314A@0dB4H0=4U40356?`0fBd40<dTm0357>`0fC440>e1903Q=A`0hCD@0>4a00312
=00^@3@08CDY02Pl<P0cAch0=T]403M<AP0bBD<0<4E003E;A@0mE4`0?5I;03UCB@0fD4L0=Tm903UB
C`0lEE80?eQE041IEP1>If@0<T]704AMF00mEU00>E9<041JD@0nF4l0>eE<03eDB`0jCdH0<DHm03aA
A@0jCT<0>De203eAA@0jCT<0=da503M<@`0gCD40>4i103M=@00gCD40?59704EJD`0nDdh0?55<03]?
C@0dBD@0>Di703Q=AP13F540>e1904QMEP15FU<203aABP80>e1901X0>Tm803U>A`0hCdH0>e1903U>
A@0lDDT0@5==03eAB00oDT/0=dY403I:@@0iBT<0<T<m02dn=P0iBT<0<40m03=3@@0Y>CP0@51@06If
MP0B8R80<40o07R8Q`13De00;d0j03A1>P80<3Xa0440:cD/024[8`0S;2L08BXV03a7@`1dOWd0BUAD
02H`<@0O:BX08bhZ01`/8P0U=B/07RhU02Ld;@0X=Bh0:3@]02<^:00M:2807BLQ01PQ7P0J8b007BHR
01hW8P0R:bH092dY024Z9`0P:BH0624N024Z9`1SK6T0DU]H01`U8P0H8Ah051lI01LR700I8Ql061hL
01LK700M7R406aXO01HG700N8RP06b8Z020W;`0R:c809B`d018I8@0a>3h0EUeS024X;P0P9BT05Q/N
01@J6P0G71T05AXF014F400C618051TE01PJ5`0G6AH061XG01/M6P0D5Q<05aTF01HH5@0301@F4`03
01DG500A4@l051@B00<05aLE00@05ADC01PH5P0D51804a<A0P0D51800`0C4Q005a<B01LC4P0201LC
4P0501HD4P0E51802@P602h^;00J6QP00P0;2`T0600@40h040l=01<B3`0C4Ph04A0>010?300@3`/0
3`h<010?300@3`/040l<010?3@0A40h04@l@018>3`0?3@h04@dA018=4@0A3a804PlB020K7`1VI6L0
5A8E00l:3P804@lB01h020H9014?4P0A3a8030X=014?4P0?3A003P`?00`:3@0:20/03@/>00l=400=
3@l02PT>00d=3`0B4QD040lD00d=3`0?3Q802`X?01LG6@081`/02`X?00h;3@0>2P/040`=014=3P0@
30d03PX;00l;300E4A8200h:2`0?01LC50070`@0510A018>3`0>2P/04@d>00l;300;1`P04`l@010<
3@0B3Pl0510A00d92P0;1`P03PX800803PX701<04@d:01@A300D4@`061D@020M5P0j=c00De1902@Q
6P0>2`@040`800d71`0@2PX04@/;00l92@0<1PH0<2XZ01XD500;1@D04@/;00803PP801<04@/;00L1
0@060@402@<301<=3@0;1@D040X:01D?3`0?2@T04@/;00d71`090`<03PX9014=300B3Pd02PH500L3
0P0<1PH040L800803`H700<03PD600l61`0A1`P01P0@1@T01P0E2Ph050T=01<8300B1`/04@H:0105
2@804@L800X040H701052@0?10P03`@801462P0=10L02@0301483@0K4QL04PT>5?ooool001_ooooo
00h05AlY014K8`0?6Qh03QPJ00T@3`0=4`l04A<>014B3`0A4@l04@l@018>4`0@3Q404Q8D010B4@80
3a4@00<0418A014C4P0=3`h01@0=3`h03@0?4A004Q@C014C4P0=3`h030h=00d?3P0A4a8030h=00h@
3`092`X0=cTh01@F5@0<3P/00P0?4@h0100=3``03a4>014C400;3@X200D7100E01LI5P0R92403Q0=
00lA3P0<3P/03a4>00h@3@0=3``04A<@00`>2`0>40d02`d:014C400?4@h051HB00d@2@0@4``051L@
00d@2@0930D030l800<03A0900<03Q4:00lB2`0?4P`00P0>40/0100=3`X030h900`>2@0>40/300lA
30803Q0;00h0418=01HG4P0E5Q403Pl:010A300B4`h03Pl:01hO6P0c=2l04Q<>00H70P0E5Q402``7
00h?2P803a0;0P0>3`X0100D5A004Q<>010A300@4@`2014B3@0600T;1P0=3`X04Q@?00h@2`0<3PT0
418=0`0?4@`01@0@4Pd03a4<00h?2P0?3PT04@h900<03Pd800T03Pd900d>2@0=3PT03@h900d=2`0>
3P`03a4=00D6000;30H00P0?40X0300@4@/02``60001000E5Q003@h801dN601;C4H0:BXT00d>200A
4P`02P/500P90`8030d703L04A8<010A2`0A4P`051D?01DF400A4P`04a@>00`=1`0A4P`03@h801<D
3P0@4@/04a@>010A2`0A4P`03a0:00d>200C50h04Q<;00l@200B4`/04Q<=00l@2P0B4`d03a0;01`L
6P0N7Q`03`l=010@3P0=3@/03a0;00d>2@0<3@P03Pl:014B3@0B4`h02P/600h?2P051P409RLR00H7
0P0>3`X04Q<>030a;00E5Q4020T400X;1P0?40/051D@00l@2`0D5A005QLB00T:1@0>3`T03Pl80080
414900H0414;00h?2@0>3`T03Pl:010@3P0A4@l2010@3P03010@3@0@4@`0414<00804A8=00D04Q<>
010A300`<B`04a@?00l@2`0200d>2@03010A300A4Pd04A8=00<04A8=01l02``700h?2P0:2`H03a0;
018C3P0?40/0414<014B3@0@4@`03a0;00h?2P0?40/04a@?010A300;30L030d800l@2`0=3PP04aH=
01@G300<3`P02P`900d?300;3@d030d?01@F5@0F61@04A<>018E300<3`H04A@=00804A<>0`0@4Pd0
300E5a80418=010B3@0D5Q402`d801@G4`0A5AH020d@00`B4P0;3`h03a<B01<E4P804Q<>00/04a8=
01HC3P0F4`h0518<01<D3`0?4@h05ALD02HX9@0B51406A/H01@F4`02018D4@0901@F4`0E5a@04Q@A
01/O7P0D61L04aLF018F5@0D61L07b<R00<04aLF01<04QHE014E500?4a806AdL02da<00d>3L0720O
014F5@0C6AL03QLD01@M6P0?61D03QTE01LR7P0;5Q8051XH01hT8P0E6aT0;C<a00805Q`J00H051XH
01DK6@0I7ad08BLU01`R800@5Q@201DK6`1801HL700G7Ad061hN01PN7P0J82005adM01TO7`0O9BD0
8BLW020V9P0H8B005QlN01XS8P0G8B0092h]01<M700N:RP062LT01<R7`0F9B8041lL01HU8P0X=3@0
;3Xj02Hd=00L:RX07Rh]028b<@0Y>CP09CPf01P[:@0[?S`0;D0n020c<P0[?ch0<DE403=7A`0eBDX0
>Tm@049IFP1<I6H0EFe_05mgNP1VOh<0KHJ:07J?U01iTYL0N96F076:S`1WP8D0H7Un05UbM`1CK740
E6eb05=/L@18HFH0@U]P03aFG00hDeX0=e=G03IAE@0eCU<0=4eA0359C@0Y@DD0>4e@02Xo@P0/@D@0
=4U;03iDDP0eBdT0;TA20P0]@d403@0gCD/0=D]90316A00aAdD0<dU70316A00cBDL0<TQ502e3@00/
@Sl0=D]803Q>B`0[@Ch00P0_AD80B00^A440;48o02i4@@0dBTL0<dM80396A`0fBTT0=da703=8?`0f
C400>U1303=9?00eBcl0?55:03M<AP0aASd0<dDi02i0<@0Z?3007c<X02e1>@0gBT@0<DI103E;A00i
D4P0>e9803YAAP0eCD00>E=603QBAP0fD4D0=e1:03UBCP0lEE80AUmL049KF01<IF80=4e904=LE`0n
Ee40>E=:03I>AP0gCTH0=4]303Q>A@1=HUT0B5eD03Y?A@0hC440>De203E9?@0gBd00>Di603aAB00k
D4L0>4i203=9?@0bB3`0>Dm303iCC00dBD80=DU703iBD`0mDE00>e1:03M<A@0hCDH0>e1904=HD@0n
Dd`0?eA=03eBB`<0?55:02h0?E9;03Q?A@0lDDP0>Tm603eBB@0oDdX0?51703eAB00gB400=TLo03M8
@00b@CX0;Sdf02m0>P0lC4T0=DE403m?C`28UiX0_<[<03e=C@0L;2`0;cln02/k>00cA3h0>dQ1030j
<P0^>3009c4Y01hX800Q:RD0:S<_079kN03foo`0UYnM02D^;@0Z<c80:CDa02<b:`0X=c009cH_020_
:00Q;RL09S8/02<^:00Q;2H082XU0P0J8ah0:00P:BD08R/X02@]:P0R:bP07BHS01`U8P0H8Ah08BXW
01`U8P0O:2D05QlL01PR7@0F8A/05b@K01TS7P0H7Q`05a/J01`L7P0G5Q`07AhS03XmA@0l@dd0=Ci7
02<]=P0Z<C/082La02H]=@0k@4H07B8V02@Y;00N8R<06alN01dO7@0J71L05QPC01TL5@0;3@X04Q@A
01/M6P0G6AH201<E4P0301LI5P0F61D051HC008051HC00X05ALD01<C4@0D51805ADC01HF500E5A<0
51@B01HF500D51804a<A0P0E5A<00`0C4Q005A4@01HA400201DA400901@B400C4Q006QTG00l>300;
2`T05aLE01@D4P0K6aT040l=00804a8@00<04A0>010?3@0A40h00P0B4@l4014@3P03014?4P0@3Q40
3`d@008040hA00`04@lB018@4`1NG5l0THnB01TG6P081PT07Q`O00d;3P0;2@`0518E018@4`0:20/2
00h<3`06010>4@0?3A003@/>00`:3@0=2`h03@`A0P0>3A802@0=314030/@00`;400I61d0Lg9g00/:
3`0K6Ql03@`A00P61`0200l;300F010<3@0?2``03`/<00d92P0C3a003PX;00l;300@30d030P900T5
1P0>2P/02@D600h:2`0=2@X020@500h:2`091@H02`L8010<3@0>2P/03@T:014=2`804Pl:00/04a0;
01@A300D4@`05A8=014>2@0I5Q40:RLR010=20040@002`H500d71`02010:2P0B00l92@0=1`L08adM
01<=3@0<1PH04P`<00l92@0=1`L02`D5010:2P0^:2P050h>01<=3@0;1@D01P0000`61P080P803PP8
0P0=1`L01`0@30/04`l>01@@3`0=2@P02`L6010:2P0@1`P00P0?1PL00`0?1@H040H7014720060105
2@804`P<00@04PL;01462P0@1@T040D90P0A1PX201052@803`@800H04@H:01052@0>0`L04PL;01P=
4@0A1PXDooooo`006oooool03P0e?dP0U9jU00D;3`0E7B003QDD00P>2P0B5Q404a@A018B400B4140
4PhB010>4@0A4A803a4@0P0>40l02@0?4A00418A014C4P0?4A003@l>00h@3`0@4Q404A<B00d?3P05
00h@3`804A<B00D02`d<00lA401`LW40>3Xi00h@3@0200lA3P803Q0=0P0?4@h01`0A4a0030h;01XL
6@0X:RL04aDB010B3`0>40d00`0?4@h0200A4a00418?018D4@0B514030h;010B3`0?4@d03Q0;0P0=
3`X0100<3PT051HA01LI500>40/200d?2P0300h@2`0?4@`03a4<00803Q0;00@03@l:00`>2@0<3PT0
3Q0;0P0?4@`01P0>40/03@l:00d?2P0=3PT04A8=018C3P80414<00T04A8=00l@2`0A4Pd03Pl:010A
300B4`h03@h900`=200>3`X00P0@4@`0400?40/03Pl:01@E400A4Pd0414<018C3P0C50l03Pl:00h@
2`0@4Pd03a4<00d?2P0>40/03a4<00T;1P0:30L400d?2P06010@2P0?3PT03Pd800d<1`0>3@P0414<
0P0>3`X200d>2@0]00h?2P0>40/02@X401@E3`0O81X06AXD018C3@0C50h061TC01<D3`051P404a@>
014B3P0=3PP03Pl9014B300=3PP030d7010A2`0B4`d03a0:00h?2@0?40X0414;00l@2P0=3PP03a0:
00d>200@4@/02P/501<D3P0B4`d09RLQ014B300<3@L04A8<018C3@0?40X03Pl700d>1P0B4`/04a@>
00h?2@0?40X04a@?00806ATG00d03Ph<018B400?3`d04a@?014B3@0=3PT030d801HG4P0N7aX04Q<>
010A300=3PT0414<00804A8=00H05aPC03`m>00E5Q403Pl:018C3P0@4@`200`=200801@E400A4Pd0
20T401DF400?40T03a08010A2@0@4@/200l@2P0600h?2P0>3P`0410>010@3P0?3`d03a0<0P0?40/3
010A300:01DF4@18BD@061TD018C3P092PD03a0;00h?2P0?40/0414<014B3@804Q<>00L051D@04]<
A`0K71L03Pl:01LH4`0E5Q4030d800803Pl:00D0414<00l@2`0=3PT02``700l@2`02018C3P0?00l@
2`0A4P`05AP?00`?1@0A50d06A/G00D7100Q8b802`d<00X<2P0?4@h06A/E00lB2P0A50/04aH?0080
4Q@?00l04A<>010B3@0@4Pd03Q0;01@F4@0A4`h061XE00h@2`0B5A40?40o020V9P0C6AT0310?00T=
300A4a000`0A4Pd02P0B4@`051<>01HE400>3`/04Q@A01/M6P092`P04aDB01LI5P0C5A82018D4@06
01@F4`0F61D051HC018F5@0A5A@04QHE0P0A5A@00`0G6aX04aLF018F5@02014E500J01<G5P0D61L0
3a<B01/O7P0S9bH051PG014F5@0A5aD06B8O01<L6@0G81d04QdI00XE4@0E81`051XH01`R800A5aD0
6AlM00hD4P0F71X06R0N01LM6`0;4@l06AlM00dC4@0J81h601LM7@0a01TO7`0F71`05A/K01PN7P0K
8B40728R01TR8@0C71/05b0O01DO7P0P:RT04Q`K01hZ:00G9R<04b8O01TX9@0E924072/X01`X:00W
=CD07bd]01XX:00L;2/08C4`02Ti>00V>CL07C0^020c<@0U>3H09cXi02Pl>`0/@3l0;T9203=7B00h
CDh0?eEG04EMG`1<I6H0Df]^05M`M01KM7P0H7Un065jO`1RNh00GgQm05M`M@1@JFh0BF9W04QQIP02
04MPI@0@04]TJ@16Gf@0>EAH03MCE`0fDUH0=U1E03E>D`0dCE40=e1D03Q@D`1>HfH0;D9303Q=CP13
F5T0<TQ60357A@80<TQ60100<4I40357A@0dBTP0<TQ603=9A`0dBTP0<dU703I<BP0`AT<0<DM403Q>
B`0fC4T0<DM403M=BP0_AD80<TQ50P0fC4T0NP0gCDX0>U1=0314A00`A4@0=T]803I;AP0aASh0<TPl
03I<@00_ACP0<4Hj03U>AP0eBT@0<4Dl0395>@0aACH0:clc02Pl<P0lD4P0=4U203=8@`0dBT@0>U59
041GCP0oET/0>51303E?@P0gDDD0>UA903]DCP0lEE40?EIC045JE`0nEe@0BF9O045JEP11FUD0?EI@
03mID00kDd/0@eYB045HD012F4l0FFiU05Q]I00lD4H0>dm4041DB@0iCD80?U9703]@B00nDdX0?558
03A:?P0_ACT0<4Hj03M=@@12Ee00>e1903I:B00kCe00?51?03eBC01RMg00C65J03aABP0dBD80>e19
03iCC00kD4T0>Di703Y?B00lDDX0?U=<03YAA`0oE4/0?E9903iCBP0lD4L0>4a303I:@@0dACd0<d@l
03A5?@0a@3T0;Sdf03I7@00b@c`0<44m02Ph=`0mCD`0D61O0392@P0Y>CP09SHc02/l=@0U=Rl0:CH^
02D_9`0T;RH08B/S01`V7P0S;2L09RlZ04]DC`2U[Z/0H6UV02Tb;`0V;bh082`W02<b:`0R<BX08C0Y
02@c;00Z=c009C4Z02@_:@0U<2X08R`V01/T7`0M9R408R/W0P0S;2T0:@0P:BH072DR01hW900N9b@0
6R<P01`U8P0/=C8072DR01TR7P0K9R006bLN01XT7P0H7Q`05a/J01TJ7@0N7b@071hS02da=`0]=3`0
;cLn02`e?P0Q:300:C0h01hU;@0N8bP05a`P01lU9`0L824061`K01PJ600F61<04aD@01TL5@0];b`0
6adJ01@F4`0M7a`06A/H01PJ5`0G6AH05QPE00<051HC00D05ALD01DE4`0E5A<051@B01<C4@03018B
400701<C4@0E5A<05aLE01HF500C4Q005A4@01HA400201DA400;01@B400C4Q003`h<01<C4@0;2`T0
410>010@3`0B4Q004A0>01<B400B4@l00P0@3`d01@0B4@l051<A01@C4@0C4Q004Q4?008040l=00@0
40hA00l=400?3A003`d@0P0@3Q403@0A3a803P`?01/I700>30l04@lB018@4`0>30l0518E01/I700D
4QD03@/>014?4P0?3A000P0A3a8300h<3`0@00`<3P0?3a403Ph@00/;3@0<30h03`lA028R901oOh40
71`N00`<3P0=3@l04@l@010<3@0?2``03PX;00l;308040`=01h04Ph?00/7200?2``04Ph?03Te=P0@
30d04@d>00d92P0?2``03PX;00d92P0G4a@03`/<00X61`0?2``040`=00h:2`0>2PT03PX700h:200=
2@L030P500`81P0D40h05A4>014=2`0E4@l05A4>010<2P0>2@P300l92@0@00h8200?2@T04@/;00/5
1@0=1`L04P`<00h8200?2@T030H600h8200^:2P05Q0@018<300:10@06Q@D01dG5`804P`<00T03PP8
00`61P0;1`H03PX900l;2P0;1`H02PH500h8200@1`P00P0?1PL00`0?1@H040H70147200<01052@80
4@H:100@1@T01P0=0PH040D900h31`0=0PH040D901462QCooooo000Kooooo`0>00/D6`0e?T<02Q@F
00072@0A61H04aTE00hC3`0?4`l0418?014A4@0B4A804Q0C010@400>40l200d?3P0<00h@3`0?4A00
4A<B00h@3`0<3Pd03@l>00lA400A4a8030h=00/=300<3Pd03Q0?0P0?4A001`0:30/05aTH018D4`0C
5A@05aTH018D4`0?4@h0100>40d02`0=3``030h;01<E4P0D5Q<01@L400`>2`0?4@h03Q0=00d?300<
3P/03@l<00<03Q0=00H03@l<01@F4`072@H05aTF00/=2@0=3`X200/=2005010B3@0N81/07R0K00lA
300>40/00P0=3`X01@0>40/03a4<00h@2`0>40/03@l:008030h90P0=3`X00`0>40/03a4<00lA3002
00lA30<03Pl:00X03@h9010A300C50l0414<00@5000C50l05AHA00T:1@0@4@`03a0;0`0@4@`02@0?
40/0414<00h?2P0>3`X04Q<>01<D3`0@4@`02@/600/=200200T;1P80418=00<02`d800h@2`0A4`h0
0P0@4Pd01`0C5A004a@?014B3@0=3PT02``700`=200>3`X00P0A4Pd04@0@4@`03a0;00l@2`0@4@`0
3a0:01HG4@0L7AL04a@>00X;1@0?40X0004001LH4P061`406Q/E01`M5`082@<02``6008030d700H0
2``600d>200A4P`03@h8010A2`0A4P`3018C3@0<01<D3P0I6Q@06AXD00l@2P0H6A<05aPB01PI4`0=
3PP02``600d>200;30H02P/50P0<3@D08`0B4`/04Q<=00h?2@0>3`T03Pl:00d=2`0>3P`02PX8018B
400?3`d04a@?01@E400A4Pd030d8018C3P0H6A@03a0;018C3P0C50l0414<01@E40092PD03@h900T:
1@0;30L03Pl:00H70P0=3PT04a@?01HG4P0?40/05AHA010A300<3@L03a0900803a080`0?40X01P0>
3`X03@d;010@3P0B4Q00410>010@3@<04A8=0P0@4@`01@0=3PT00@8000T:1@0<3@P03@h9008051D@
00<04A8=010A300@4@`00P0?40/0100H6A@0DeA?01DF4@0?40/200d>2@0700h?2P0A4Pd04a@?00l@
2`0<3@P0414<018C3P0400l@2`0>00h?2P0C5Pd020/2014D3@0U9b804A<>01hP7@0D5Q<0H69O05EG
D`0:3@H03a8;01PK4P0A50d2010B3@803a4<01003Q0;018D3`0@4Pd03Q0;01@F4@0C5A004aLB030d
<`0C6AL02Q0>00X>3@093@`04aPD00/=2P0=3``04A<>0P0D5A003P0B4`d03Q0=01PJ5`0I6aP03Q0=
01DG500B51405ALD01<E4P0B514051HC01<E4P0A4a0041@C0P0D61L02P0C5aH051PG01@H5`0B5QD0
4ADD010D4`0A5A@04aLF01HJ6@0P92<201<G5P0E018F5@0H7A/03aDC00hG5017D4d03AHC01LR7P0J
9B404A`H01XP7P0F71X03aDC01<I5`0B61H05Q`J01@J600A5aD06R0N059HEP0N92803aDC00805Q`L
100E6a/03@0K8B4061hN01HL700F71`061hN01TO7`0L9B@04a`K04I?CP0P:RT04adL024[:P0G8b40
0P0F9B809`0N;BX06RTV020_;00I9BD082h^024_;`0W=CD0830_028b<@0O;bh04B@R02@g=@0^@Cl0
9CPf02Pk>P0U>CP09c/j02/o?`0aADH0=T]<03M>C`0jDU@0@EUK04ENH@17H6@0C6EY055ZKP1CK740
E6eb059[L01;I6T0AUmT04AMHP16Gf@0@EYO03iGG019HVL0Af1U03YDF@0203EAE@0Q03E?D`0eCU80
=4eA02m8B`0kDeD0=DY<02i3A00bAdP0;T=402To?@0^A480=4Y80357A@0]@d40:Clm03A:B00eBdT0
=de;03Q>C00iCdd0>U1>03]ACP0eBdP0:d4n03eCD01@IV<0@eUF02m5@P0fC4T0@5IC045GE00lDTl0
=Ta90080<DE404d0=T]703I;AP0`ACh0;d@j02a2=P0Z@3@0;dDi0315?00_A3`0<dPo02e1=@0_@cH0
=d/o04AHC`1IKFD0@EIA0399@`0gCTP0>U5903QBB@0iDdP0?EM<03E?@P0iDdL0?EM<03mHDP10FE@0
?eQE06IoO018HEh0=e1=03aED@0jDdh0B65K03UCBP0oF4l0?5=;03iEC@10ETd0<DHm03I;@P0hC480
>4a103Y>@`0lD4D0=d]003U>AP0gC4<0<dPo02m5>@0bB3`0=D/o03U?@`16Fe@0A5UB03a@CP0jCTl0
>Ti=03]@BP1cR840EfaU03eBB`0`ACh0?E9;03aABP0hCDH0=T]403M<A@0kD4T0?E9;03]BB010ED`0
?E9903aAB00hC4<0<dLn0355?0020352>P0h0393>`0b@CX0<D0i02dn=00a@SP0=TM002dm>P0`@3d0
CemM04eMFP0T=340834Z03Y;@@0/?C<09S@Z01lY800S;B@09BlW024[8`0U;bL09BlX01lX8`0i@Sl0
;CHc02</:@0Q:RL08RhY01h]9P0A81T0;3/d010O600K:240:cL`02@_:@0R;BL072HP01`U800P:B@0
8R/W024Z9`0P:BH07BHS01`U8P0O:2D0QXn<024Z9`0F7a`07RLT01/T8@0I8Ql07BPR01/V800J8b00
6AlO01PN7P0G6ah201@G700C028V;00O9Rh07RD]01TR:@0D6b<08BP^01lW:`0N8bL05AXN01PM7`0I
7Ah05ATH01LI5P0G6A@05QPC01hP6`0o@Ch08B<P00lA3P0201hP7@0301XL6@0G6AH05QPE00<051HC
00l05ALD01HF500E5A<051@B01<C4@0A4@l0410>014A3`0B4Q005ADC01PH5P0F5Q@04a8@01HB4@0G
4Q400P0F4Q403P0E4a4051<A00h=2`0B4Q001`L501<C4@0F5Q@020P6018A3`0C4Q004A0>00l>300@
3`d04Q4?0P0C4Q001@0A40h040l=00h=2`0>3@/040hA00<03P`?00H03`d@010>4@061@L05A<F00l=
400;2@`200P62@0=010>4@0D4QD05Q@G014?4P0?3A004a4D018@4`0@3Q403@/>00`:3@0?3A004a4D
018B500200`<3P0D00h>400=3@l02`/=00h>400000805aLI00X:300I6A/0518C010<3@0>2P/03@T:
00h:2`0@30d04Ph?01<?400;1`P03`/<01HB4`1;AdP201DA4P0901HB4`0H51D06ADF02DQ8P0_:b`0
5a<D00l;300A3@h03`/<008030P901<03PX9010<3@0>2PX03@T800l;300=2@T03`/:014=3P0>2PX0
4@d<00h:2`0;1PH040X:00l92@0>20P03`T9010:2P0?2@T03@L700803PP801403@L7010:2P0?2@T0
2P@400H10@0>20P0208200`61P0@2PX050h>00/51@0?2@T03PP8010:2P0=2@P03PX900l;2P0200h:
2@07014;2`0@1`P03`H700l61`0?1@H040H70147200601052@803P<7100?10P601052@803P<700@0
2`0400T00P0>10L06@hB5?ooool001_ooooo00h051hP00LA4`0H8R<06R<R00TA3`052`T0314=00dA
3@0?4@h0410@018A4P0A4A<04A<B010B4@803a4@00L0418A014C4P0=3`h030h=00X<2`0;3@`030h=
00803@l>00<02`d<00`>3@0?4A000P0?4A003`0E5aH03Q0?00020@0;3@`0004001hP7`0>40d030h;
00d?300@4Pl03a4>00d?300@4Pl030h;01PJ5`02018D4@0E01@F4`0=3``03Q0=00/=2P0=3``03Q0=
00`>2`0A4a002`d:01DG50082PL0828O00L91@0;3@P03Q0;018D3`0@4Pd051HA01HH4`0?4@`03Q0;
00803@l:100>40/0100=3`X030h900`>2@0<3PT200d?2P0A00lA300@4Pd0418=014B3@0>3`X03@h9
00h?2P0<3@P0414<01<D3`0A4Pd01`P3010A300A4Pd020T4014B3@0?40/00`0@4@`0100?40/03@h9
00h?2P0?40/2010A300@018C3P010`005ALB01hP6`0=3`X02P`700h@2`082PD02`d800lA300=3`X0
30h9010B3@0B50l04A<>00l@2`8030d800@03@h9018C3P0B4`h04A8=0P0@4@`0400A4Pd04A8<014B
300E5Q0051D?00d>200A4P`04a@>01@E3`041@002``600P90`061`403a0:00d>200?40X200h?2@0?
01@E3`0:2`D03Pl9010A2`0?40X0414;018C3@0=3PP06Q/E01/L5P0@4@/06AXD01LH4P0:2`D02``6
0080414;02T03@h8014B300?40P03a0801@E3@0E5Q004A8<01<D3P0:2`H03Ph<01<C4@0@40h04Q8@
00X:200>3`X04A8=010A300<3@P03@h900l@2`0>3`X03a0;00T:1@0=3PT04a@?00/<1`0D5A003@h9
01PI500A4Pd020T401/L5`0F5a803Pl:00X;1P0Z:bH092DP00d>200@4@X03a0800h?1`0200l@2P07
010A2`0@4@`03@d;014A3`0D51804A4?010@3@03014B3@80414<00D06AXE0083000J6aH05aPC00l@
2`04014B3@0Q010A300>3`X03Pl:00X;1P0V9b801PL2018C3P0?40/03Pl:01<D3`0E5Q405aPC010A
300:2`H03a0;01DF4@0@4@`030d800d>2@0?40/03@h901<F3`0E60l03Q4:00`>2@0E5a802P`900`>
2`0b=340<cD`00`?200520402@`500H03a4<01@05ALB00T;1P0>40/010H100/=200B50l05AXF00D;
2@0;4@l041@C00lC4P0?51003Q0=010B3`0E5a805aPC01HG4P0C50l04Q@A01LI5P8061XG00@05QPE
00lA3P0F61D051HC0P0C5A801`0B5140418?00dA400C5aH04ADD010D4`0C5aH0100A5A@0700B5QD0
51PG01@H5`0?4a803Q8A01<G5P0<40l03Q<A00X@3P0:4a00?4E200L@3@0E81`041/G00/F4P0M8b40
4aTG018H5P0D6QP05A/I01HL6P0B61H05Q`J01XP7P17CD/0728P014G5@0D6QX501DK6`0N01HL700H
7Qh05adM01LM7@0J8200728R01PQ800F7ah0FF9Q02La<00>61L07bTX01TU8`0H9b@05bHS01d/:@0F
9B806bXW01dY:@0L:RX08S0`02Le=@0K:bX06RXY03U9B00fBDL09STg01lb<00M<2h0:chm0P0X?3/0
2@0[?cl0;d=40356A`0cBT/0>E5C03mGF@12FUd0@U]O04IOH`0204QQIP0;04YSJ01;I6T0BF9W04MP
I@14GF80@EYO03]DF@0fCe@0>E9G03M@E@0dCU<00P0dD5@07`0eCe<0=DiB03A=D@0cC4l0@UYL03A9
BP0iCTl0>4e>02m4A@0]@d40<DM502i4@P0X?S`0:T0n02m5@`0fC4X0>Dm=03Q>C00fC4X0=de;03A:
B00bB4D0=Ta902m5@P0kDDh0DVQU04eSH00hCT/0>U1=03aBC`0jD4d00P0hCT/0:@0fBTT0=DU803U=
B`0hCDP0<TM00397?`0]@ST0;T@h0398?00]@ST0:Slg0397?P0_@cL0;T8e03Q<@@11ED`0Bf1J03A9
A00`Ad40>e9<041GD@0jE4/0=e5703QBA`0fD4<0>E=703eGC00oF580@5UE03mHE@1AJVL0@5UF03mH
E@1AJVH0?5E@049KE@13GE@0AUmF03U@B00lDd/0@eUA0080:d0g02T0>e1603]?A00iCD80>Ti303=7
?00gC4@0<DHm02i3>P0aAc/0=Ta003U?@`0kDDD0?U=<03aABP0jCT`0?51A03mCDP0jCdT0CfAM041E
CP0mDT/0>Tm803aABP0mDT/0>Tm803U>A`0jCdP0?E9;03mDC@0mE4X0?eA;03]@A`0iCTD0=DU00314
>`0_@cX0<D8j0393>`0cA3`0=4<l03A4>P0203=5>@1:02m0=`0V=c40;3dg03e=B@0lCDL09CH`02`m
=00gBCd09SP/02Hd:P0T;RD0:C<Z02Xd:`0R;2@092hV028/9@0J8ah0:34^02`e<P0G81d0;SLd01PT
7P11D4T0:CPa028a:P0P;bP0;CXc02@`:P0T;bT07bXT01XT7P0O:2<08R/V02</:00S;2T08R/X01dV
8`0J8b0072DR06]dL@0N9b@07bPU01<L6@0R:bP08BXW01/V800I91h06B8O01/Q8@0J82006AdP01TL
8@0F6Ah08BH/01XQ:@0G7RH03aPN01HM8`0N9RT072@W01XO8`0D6A`061hN01DI600B5QD05ALD01HH
4`0D5Q406adH01dO700F61D05aTF01PJ5`0C5A8201LI5P0601HH5@0D5Q<051HC01@F4`0E5a@051@B
0P0F5Q@00`0E5A<04Q8@00l?3@0201<C4@0601DE4`0F5Q@05ADC01<B400C3`h050l>0P0C3`h0200B
40h04A0>010?3@0@40h05aLE01TI5`0<30X08b<Q0P0C4Q00100@3`d03Pd;010?3@0C4Q02014@3P05
010?3@0?3P`03Pd;00h=2`0?3A000`0>30l200l=400501TG6P0>30l02PP;01@B5@0F51L00`0?3A00
5P0>30l03@/>00h<3`0@3Q404a4D00h<3`0:20/02@L:00l=400D4QD05aLI00h>400<30h03@d?00X:
30061PP04a<E010@4P0=3@l01`L900<31@0;20X200l;300600h:2`0?2``03`/<010<3@0D41403PX;
0P0A3@h0300Z9RL020@500l;300?2``02@D600<0000:1PL07ATJ018>3`0=2@X03`/<00d92P8030P9
00`03@T:010<3@0>2P/030P900h:2`0@30d0510A01DA4P0>2P/040`=01<?400@2``5010:2P03018<
300@2PX03PP800803@L700d03`T900d71`0B30`03PT901<=3@0400003`T900P20P0=1`L0208200h8
200=1`L03`T9008030P70`0=2@P01`0>20P040L800l61`0?1PL03`D601061`0A1`P01P0@1@T700l4
20<040D90P0A1PX01P0B1`/040D900h31`0=0PH04@H:01dB5QCooooo000Kooooo`0:00/D50084100
41TG01<I60093`d03Q@B00dA400>4A003Q0?00h>3P803@d=00L0418A00lA400>40l03Q0?00lA400@
4Q403Q0?00@03a4@00@03Q0?014C4P0<3Pd030h=0P0@4Q402P0?4A003Q0?01DG5P082PT051HE00d?
3P0@4Q403@l<00/=2P0=3``2014C400700lA3P0:30T03@l<00lA3P0;3@X04A<@00T;2002010B3`0?
00`>2`0>40d04A<@00h@3@0@4Pl01`T601/M6P0H6QL0?T0m01<E4P0<3P/03@l<01<E4P0?4@h03@l<
0080418?00D03Q0=00d?300=3``03@l<00h@300200h@2`0300d?2P0<3PT030h900D03@l:00d030h9
00h?2P0=3PT0414<01@E400>3`X03@h9018C3P0@4@`02P/600d>2@0A4Pd03a0;0080414<0P0A4Pd2
010A300:00l@2`0B4`h04Q<>00/<1`0:2`H04A8=00L9100H6QD06Q`G00/=208030h900X02`d800lA
300C5A003Q0;00d?2P0A4`h03A0=00`A3@0>4@h03A4<0P0>40/00`0A4`h0418=010A2`0300l@2P0C
01<D3P0;30H03a0:01XK5@0B4`d03@h801PI4`0=3PX04a@>00l@2P0?40/04A8=01@E3`0@4@/04Q<=
014B300?40X05aPB00`=1`02010A2`0400d>200<3@L03Pl900/<1P807QlI02D03Pl901<D3P0=3PP0
30d700l@2P0D5@l04A8<00`=1`0@4@/04Q<;00l@200C50`051D?01<D3P0F5a404Q<>00d=2`0A4@l0
410>01@D4P0<30X03Pl:00l@2`0A4Pd04Q<>014B3@0?40/03Pl:014B3@0:2`H03a0;010A300?40/0
3@h901LH4`0720@03a0;008030d800L03a0;00`=200>3`X07AhI01HG4P0A4P`04A8;00803Pl700T0
3Pl9010A2`0A4P`04Q<>00h>300C4a405aLE01<C4@0@40d00P0@4@`02`0?40/03Pl:00h?2P0;30L0
5QLB00T:1@0A4Pd020T401LH4`0?40/03Pl:00803a0;0`0@4@`0300=3PT0414<018C3P0F5a8051D@
018C3P0@4@`04Q<>01@E400C50l04Q<>014B3@80414<00D04A8=010A300@4@`03A09014D3@0200lA
300800h@2`0_<B`030h900`>2P0@4Pd04aD@01LI4`0?4P/200h@2`08010B3@0A4`h04Q@?01<E400F
61<03Q0;03Li=00B50l2014C3P06010E4@0;40`041DA00/@300A5Q804QLC0`0@5A402P0A50l04AD?
018D3`0G6AH03a4>01XL6@0C5A8051HC014C400D5Q<2018D4@0;01@F4`0E5a@04aDB00`@3`0B5QD0
3Q8A00dA400B5QD041@C014E500B5QD00P0D61L06`0C5aH04ADD01DI600B5QD05a/J018F5@0F6aT0
4ALE01DN6`0@6AH05QlL01HQ7@0X<bl08B`X01hT8P0G7A/06b4O01<I5`0E6aT05Q`J01<I5`0P9R@0
3aDC01LM6`0@5Q@06R0N01DK6`0201HL708061hN02X06AlO01HL700J82006R0P01LM7@0F71`05adM
01TR8@0B6aX0;cPg01TS8P0L9RD06bDT01dY9`0G9R<052<P01TX9@0E924072/X020/;00I9bL08c4a
028`<00L;2/0830_06MgMP1RMG<0:C`j03A7A@0/?cd093Lf02Hj>@0X?3/0;D510355AP0aATL0<dU;
03Q@DP0lE5H0?5AG03UBEP0jDeL203aEFP0303eFF`0oF5d0@EYO0080@eaQ00H0?UML041IGP13G640
>U=H03M@E@0hDUH203A@D`0603A?DP0eCe40=4i?03M@DP0]ADH0>4e>0P0[@Cl0200/@T00:Clm0316
A00_AD<0:T0n02m5@`0gCD/0=4Y80P0hCT`02P0fC4X0>Dm=03I<BP0/@Sl0<DM403M=BP0fC4T0=de:
03eCD00hCT/203U?C080=Ta904L0>4i;03U=B`0hC4X0>De;03I;AP0aAT00<dQ103=8@00_A3/0<DHm
03=8?`0aASd0=4Xn0355>@0aAST0>e5503A9@@0gCDH0=Te704=IEP0mEE40=e1:03QABP0iDdX0>UA9
03I@@`0hDTH0>UA903]DCP0mEU40?EIC04IOG012FeP0DFYW076:QP16GeX0@U]E03mID010FE00@eYB
04IME@11Edl0=T]203U>A@0hCD<0@5A903mCB00gBd00?E5603Q=A@0`AC`0<DHm03U?@`0jD4@0>4i2
03eCA`0mDT/0?eA=03iBD00gBd`0=DU803iCC@0jCdP0?U=<03Y?B012Ee00?U=<03Y?B00iCTL0>Tm8
03]@B@0203aABP0O03iEB`0nDdX0>4e403E:@@0cAch0;T8i02m3>P0cA3`0=4Dm03E6?P0gASl0>DTo
03E7>00bA3H0;d4e02/l<`0/?CD0:3Tb02`m=@0X>C00:C/_03=5=`0`@S<0;3X^024[8P0T;RD08bdT
01dW7P0Q:b<09BlW079lM00202</9`0?01`U800P:BH08BdX05QWH00d@c`082lX01`[900Z=c0082`U
02@_:@0O:R@07bTS02Pa;00V;bX07RLS008082TV00X07RLT01`U8P0N9b@06B8O01/T8@0Q:RL07bPU
01PQ7P0K92406R<P0P0G81d06@0M8b<07R@T01`Q900H7B405AXN01lT:00J8BL072<Y01/R9`0A6A`0
8RX/01TR8`0C6AX06R0P01<I600G6aX05ATH01TK600G6AH04aDB01LI500C5A805QPE01LI5P0E5a@0
0P0F61D00`0G6AH05QPE01@F4`0201@F4`0301DG500B4Q005QHD00806ATG00D051@B00l?3@0G5aD0
51@B01<C4@0201DE4`0301<B400D40l05A0?0080510?00@04a4?018A3`0D4a405aLE0P0>3P`02@0K
6aT0ADE301<B400C4Q0040l=00h=2`0@3`d051<A014@3P05018A3`0300l=400>30l03@/>00803P`?
0P0?3A001P0>30l06QPK00d;3P0@3Q403P`?014?4P803P`?0P0A3a802@0>30l040hA00h<3`0<2Pd0
2PP;00d;3P0@3Q4040h?00h<3@0200`:2`0400h<3@0A3a0030X;01<A4P<03P`=00P03``=00l;300@
30d04@d>010<3@0?2``03PX;01<?40803PX;01`04`l@00T51P0?2``04`l@014=3P0B3Pl02`L800L3
100A3@h03`/<00h:2`0?2``02`L800`82@0?2`d04PdA01@?4`0@2`l02`H:00d8300>2@d03@P<00h9
3@0=20`030L;00d8300>2@X03`T90P0B30`05@0A2`/03`T900l92@0>20P03@L700l92@0@2PX030H6
00l92@0:1@D04P`<01D?3`090`<03PP800/51@0A2`/030H600l92@0=1`L02`D500d9200400`81`07
00`61P0@1`P03`H700l61`0?1@H040H70147200601052@804PL;00@04@H:01052@0?10P03P<70P0?
10P201052@<04@H:00D03P<701872`0B1`/03P<701872`0Dooooo`006oooool030042PP03Q@A010F
500;4@l03A8@01DI600C5aH041@C00lC4P0?4A003Q0?01DG5P<0418A00@03a4@00h@3`0<3Pd03a4@
0P0A4a802`0@4Q404aDD01DG5P0C5A@04Q@C00`>3@0:30/03@l>00/=300=3`h03Q0?00<03a4@00<0
3Q0?00h@3@0>40d01@0>40d06P0A4a003a4>00h@3@0@4Pl04A<@01XL6@0>40d030h;014C40021040
6adJ00/=2P0I6aP0S8j;02LY9P0B51403Q0=01HH5@072@H0418?018D4@010`003@l<010B3`0?4@h0
30h;0P0=3``0300=3`/00080010B3@0T9R80418=00h@2`0C5A001@L201XL5`0D5Q401`T401PJ5@<0
2``700`03a0;00`=200<3@P03a0;010A30092PD03Pl:00`=200T9B003a0;00d>2@0B4`h200L80`L0
3a0;01P04A<>010B3@0>40/030h900d?2P0>40/030h905UKEP1YJfH03@l:0043000i?CL03A<?00`B
400;4@h0318>01HK5`083@L030l800d@2@0A4P`04A8:010A2@0?3`L201<D3P0800`=1`0=3PP04Q<=
00X;1@0=3PP0414;00`=1`0:2`D200l@2P0500h?2@0@4@d00`@000X;1@0B4`d00P0>3`T300l@2P05
00h?2@0<3@L03a0:00/<1P0<3@L00P0A4P`0900;30H0414;00l@2P0=3PP03a0:014B300=3PP03Pl7
014B2P0?40P03@h8010A2`0E5Q006AXE00d=2`0;2`T04A4?00`<2P0D51804a@?014B3@0?40/03@h9
010A300B4`h0414<018C3P0=3PT0414<01@E400@4@`03Pl:00l@2`0>3`X030d800h?2P80414<0P0D
5A004`0A4Pd03a0;00l@2P0<3@T0414901HG3`0=3PP0414;00h?2@0?40/0410>01<C4@0>3P`03`l=
014B3P0@4@`04Q<>01<D3`0B4`h00P0@4@`03`0?40/061TD00h?2P0E5Q403@h901<D3`0J6aH03Pl:
00`=200E5Q404Q<>01@E400B4`h04a@?010A300201<D3`0E010A300C50l05AHA01LH4`0B4`h03Pl:
00l@2`082@@051D@00`=200@4@`03Pl<01DG4P0>40/03a4<01DG4P0A4`h041<<00lB2`062@807R0K
00803@l:00H04A<?04]=B00[;BP0418=01LI500F61<200h@2`05014C3P0E5a8051HA018D3`0A4`h0
0P0<4@/03@0>4`d03Q<?00lD400@5A403aDA01<I5@0>510041HB00dC3`0<4@d030h;01LI5P0>40d0
0P0B51408`0C5A803Q0=01<E4P0I6aP05aTF014C400C5A804QHE01`P7`0?4a804ADD00hB4@0O8b80
720O00`@3`0D61L03A4@01<G5P0E6AP051PG01<G5P0B5QD04aLF01LL6`0J81h06b@Q00hG500I8Ql0
>TE1079mN@0U<2`04QPF01TO7@0J81h05adK00806R0N00H06AlM01LM6`0@5Q@051XH01XP7P0G7A/2
01HL70805adM0P0E6a/0400L8R806R0P01`R8P0N92@06AlO01DK6`0J8b805b0O01DN7@0G8B0072HU
01lY:00J9R@06BPU01XY9P0K:RL201`[:00G01TU9@0H9RH07R`/02Dc<`0O;bh07Rh]020`;`0K;R`0
7C0^028e<`0T=cD09CPg02Lk>P0bATD0>De=02/o@00^@d@0=D]=03A<CP0gCe40<d]>03M@E00lEET0
0P0gD5D0200mEU/0?eQM045JG`11FUl0?UML03]DF@0lEEX0?eQM0P0fCe@04@0hDUH0<TiA035=D00b
CDl0=4i?03I@D@0eCTh0=4a<03=9B00Z@3h0:3hl02i4@P0Y?cd0;D=10357A@0_AD<0;TA20080<TQ6
00/0:T0n0398AP0]@d40<TQ60357A@0[@Ch0<dU603Y@C@0dBTL0=D]804AJE`0203]ACP1203Y@C@0h
CT/0=Ta903E;B00/@C`0AU]F03A9A00`AD00;44l0766P00^@c`0=da502a1>00`ASX0=D/o02a2=P0e
Bch0>Dm203iDB00hCdL0=Te604AJE`10FEH0?5EA03YCC@0jEDh0?UU@03iJCP12G4l0?UQ<03A>@`12
FeD0?EIA03aEDP17H5d0@U]H041IEP13G5P0@U]F03iGD@12G5<0@e]C049ID@0oETh0>e5903Q=A00j
CdH0@eM=04QLD@0[?c@0?E56061dJ@1=HUX0?U=:03Y?AP0hCT80>U1403mEB@0lDTH0AU]D03aABP13
EeD0=TY;03M;BP0mDT`0?U=<0P0oE4d203eBB`0W03aABP0fBd@0=DY303Q=AP0jCdP0>e1904IMD`0k
D4L0>4e403U>A@0dB3l0<4@k0396?@0]?SH0<44i041AB@0iB4409cL]03=5=P0a@cD093HY03Y;@@0d
ACd08S<[02`m=@0cA3X0>T`o03I8>P0]?bl0:CLY02dg;00Z=2T07RPN01PR6@0O:B00:38Y02@^9P0N
:2007RLQ00808BXU00h08BdW02Dd;@0R<BX06bXS01h]9P0Q;RL07RXT038m=`0R;BL07bTS05MPF`0Y
<Rd07bPT01lX9@806R<P0P0L9B800`0V;b`08b`Y020Y9P02020Y9P0>01hW900I7al04ALG024W9`0=
5AL0A4a>049:C00K8bD06B4S018J7@0K82@082DY01/P900I8B<201@M700501/Q8@0M8b404QPF01`P
7`0D6AD00P0A4a00100W:BH04aDB010B3`0E5a@201TK600@01XL6@0E5a@04aDB01DG500F61D05ALD
018D4@0?4@h061PF014A3`0E5A<04Q8@01/K6@0J6QP04A4?01<C4@805ADC00@051@B01<B400B3Pd0
5A0?0P0E4A00500C4@l040l=01DD4P0D51800P8001PH5P0B4Q00410>00`;2@0F5A<06aXH01PG5@0A
40h03Pd;01DD4P0C4Q0040l=00l>300920H051<A0P0?3A0200d;3P803P`?00D040hA00d;3P0>30l0
5A<F01<A500200d;3P0=00h<3`0A3a804@lB018@4`0F51L04@lB01<A500A3a802@L:00H41`0<2Pd0
40h?00h<3@0500d;30803P`=0P0?3@h0100@3@h040`=00l;300>2P/200l;30803PX;00<040`=018>
3`0@30d00P0>2P/200l;300@00h:2`0=2@X03@T:00P51@0J5QL06ADF00/7200D41400`0001@?4P0@
2`l04PdA01@?4`0B3A4040/?00l:3P803PT=01@03@P<00`72`0<1`/03PT;00`61P0@2PX04P`<00d7
1`0>20P04`d=00l92@0;1@D03@L700l92@0@2PX030H6010:2P070P805@l?00X410L03PP800L04Ph=
00h:2@0:1PD03`/:01<?3P0>2@T040L800803`H700T03`D601061`0A1`P09AXN01@93@0J41<01`00
01H;3`0;00@01P0?10P201462P0400l4200@1@T04@H:00h31`H040D95?ooool001_ooooo00d02a8;
00hE3P0?5A403A<?00dB4@0?4a804aLF010D4`0?4a803a4@00h@3`0E5aH03a4@00@0418A0P0>40l0
1`0?4A003Q0?00`>3@0=3`h03a4@00d?3P0@4Q400P0<3Pd00`0?4A003@l>00d?3P0200h@3`<03a4@
1P0?4@h02`0:30T03@l<010B3`0B51403a4>00/=2P0?4@h02P`902<U8P0:2`T05QPE0080418?00/0
10H304I8A@0:30T04A<@00lA3P0620D07b4N01HH5@0B51408bDR00d?3002010B3`0@00d?300@4Pl0
418?00lA3@0>40/07b4L038d;`0N81/04Q@?00`>2@000@007b4L030b;@072@@030h9014B3@8030d8
00l0414<00h?2P0?40/0414<014B3@0<3@P03a0;018C3P0/;BP051D@00P9100=3PT04Q<>010A300E
5Q401P0?40/04P0A4`h0418=00h@2`0=3`X03Q0;010B3@0<3PT0>3Xe04]=B00D5Q4020X500`?2`0<
4Q0000P5010H5@073@T04ALC00T>20803Q4:00H03a0900l@200?40P0410800h?2@0=3PP200h?2@06
00l@2P0C50h030d7014B300=3PP030d70P0A4P`03`0S91h03Pl:01<D3P0G618010D0018C3@082@<0
2P/500d>200@4@/04a@>01DF400A4P`03@h800l@2P0201<D3P803@h800`0414;00l@2P0?40X04Q<=
014B300=3PH0414900l@200=3PP03a0:018C3@0>3`X200h>300;00l?3@071`D04A4?010A300?40/0
3@h900/<1`0=3PT03a0;018C3P0A4Pd00`0=3PT07P0;30L04A8=014B3@0@4@`03a0;010A300B4`h0
3@h900h?2P0=3PT030d800l@2`0A4P`061TB000100061`004Q<=01dN600<3@L03Pl:00`<2P0A4@l0
3`l=00d=2`0>3`/03a0;010A300A4Pd0414<00l@2`803Pl:00/061TD00h?2P0E5Q403Pl:00l@2`0>
3`X03a0;01HG4P0D5A003@h900h?2P02018C3P03010A300C50l04Q<>00803Pl:02004A8=018C3P0@
4@`03@h900h?2P0=3PT05aPC01@E400`<B`0;2dX014C3P0?4@`05QPC01dO6P0F6A803a8;01DH4@0?
4P/0MGMb06maK00I6aH04Q@?07n1O01BE4l05aTD00L910092`H051HA00lA300A4`h051HA018D3`80
4A<>0P0@5@l01P0?50h03Q<?00dB3P0=4Ph010X600lE4@8041HB00X051XF01DK5`0E6QH04A<@00lA
3P0G6AH0418?01PJ5`0C5A803a4>0P0@4Pl00`0G6AH092HS01TM7002010D4`0;01@H5`0J7Qd05QXI
00D9200J7Qd02@d<01LK6P0E6AP061`K01LK6P0E6AP00P0C5aH05@0E6QP05adK00PA3P0F7a`0:c@a
086<R03]mo@0IW5]030f=00J81h08RPV01HL6P0L8R00318@01LM6`0F71X04ALE01@J600H7Q`05A/I
01HL700301LM7@805Q`L00<05adM01HL700J82000P0O9BD02`0N92@0:34`028[:P0N9bH072HU01hX
9`0O:BP062@R01LV8`0H9b@06BPU00806RTV01P082`/01d[:`0R<300:CLg02@d<`0O;bh07Rh]01lb
<00T=cD09CPf028e<`0Q=C<08SHe02Pl>`0bATH0:Sho02]0@@0`ATP0;DE702m7B@0`BD`0<DY>03A=
D@0fCe<203QAEP0F03I?E00lEEX0@EYO045JG`0jDeP0>55F03iGG00jDeP0=e1E03IAE@0cCe80<TiA
035<CP0bC4d0<de<03=<B`0bBTX0<TQ602e3@@0_AD<0>Dm=0316A080<dU700l0;D=102Y0?P0]@d40
<TQ603M=B`0jD4h0=de;02To?@0bB4H0;TA103A:A`0iCd`0=D]803A:A`0mDe000P0iCd`0=@0jD4d0
>Dm<03M=BP0dBTL0A5UD02@i=00aAT40>Di902i3?P1QMW40>Di903M<A@0aASh0;48f0398?00^A3P0
=T`o03E;?`0jCdH0>E1803Q>BP0oEE80?UMD03]DD@0jDdl0>eI?03aGC`0kEd/0AEmD045KC`0gDDH0
@eaF03iGD`0mEU<0@5UF04AMFP15GU/0@eaH045JE@10FE<0?UQ?03mHC`10Edl0?UE=03aBB@0iCTD0
?eA;04EIC`0_@cP0<THk03Q<@@10E4T0@UM?0080>4e40100>Dm303Y@A00nE4P0AE]?0397@01;H5T0
=d]902m3A00kCdh0@EI@03mDC@0nDd`0?eA=041ECP11ETl0>Tm80P0fBd@01@0jCdP0?55:03aABP0n
ED/0>Tm60080>Di500d0=DU00355?00_@cX0;Slg0352>P0oD4P0>TU202`l<P0[?Bh0:cd_02Tk;P11
DTP0?e180080:S/c0140<44g03E7>P0a@cD0:cd]02Le9`0X<RL09S0U01hX7P0H8QT06bDL028/8`0R
;2@082XR024[900U;RT09RlZ02Da:`0202Dd;@0A024`:@0U=2d09c@]028^9`0T;bT05B0J02/e<01/
MG00@4U402Xc;`0X<Bh08BXW01hW900M9R<072DR01lX9@0N9b@00P0L9B802`0K9240624N01PN7P0S
:BT051XJ0418BP3;dmD0Z[:c018J700I8B<07BDX008082DY00L08BHZ01DN7@0F7a`04Q/I01@J600R
:2H06R0N008051TE00<06Q`I01`N6`0F61D00P0E5a@201TK600601PJ5`0K7AX06A/H01HH5@0E5a@0
4aDB0`0B5140200G5aD04Q8@01PH5P0E5A<07AdK01XJ600B4Q004a<A0P0D5180100C4a404a8@01<?
3P0E410201HB4@0<01@A400A40h03`h<01hN700E5A<05QHD00d=2`0F5Q@03`h<01DD4P0F5A<04a8@
0P0A40h0800;2PP03`h<01DD4P0M71X03`h<014@3P0@3Q404Q0C010>4@0?3A004@lB018@4`0E4aH0
71XM01@B5@071@P040hA01/I700D4QD0108500d;3P0>30l02@L:010>4@0610L03@/>018@4`0C4A@0
40hA00l=400@3Pl03P`=0`0=2``0100>30d03@/<00d;300=2``200h<3@0800l<3@0>2P/03PX;00h:
2`0?2``040`=00l;300>2P/3010<3@803PX;0P0?2``00`0>2P/03@T:00d92P0201HB4`0;00L31006
0P<01P8300T51P0<20X030L;00h93@0?2Ph03PT=00`72`0=20`00P0>2@d05@0=20`030L;00`72`0>
2@X03@L7010:2P0B30`03@L700l92@0@2PX03@L700`61P0>20P03`T900d71`0400004`d=01H@4004
000081XJ00`71`0600d71`0300`81`0C3`h04@d<00800`0000`040X:0107200?1PL03`H700l51P0@
1PL04@L800T00P0N4aL0ACXn00l4200;0P@800l4200400d21P0900802`0400l420L040D95?ooool0
01_ooooo00L04QL?00lE300>4`d041D@00hB40093@`04ADF00803a<D00D03Q8A00`A3P0B5a<03a4@
014C4P03018D4`04014C4P0?4A00418A00lA40803@l>00@03Q0?014C4P0D5QD04A<B0P0?4A001@0<
3Pd03Q0?00h@3`0>40l03a4@0080418A1P0@4Pl06`0=3``030h;010B3`0B514030h;00T;200D5Q<0
10H302DW900@4Pl05QPF00lA3P0>40d03a4>018D4@0?4@h030h;01`N700?4A004aDD00`>3@0O8B00
<38a010B4@0B51<04A<B00d?3P0200lA400600d?300B50l03Q0;00lA300>40/02@/60P0<3PT02P0:
30L03Q0;018D3`0>40/04A<>00l@2`0>3`X0414<00l@2`0B4`h201<D3`0:00l@2`0:2`H03Pl:01TJ
5@0>3`X04Q<>00/<1`0A4Pd0414<01@E40H03a0;01T03a4<00h@2`0=3`X03@l:00h@2`0A4`h0418=
00`>2@0B50l02@/600h@2`0J7AX0A4e:04aFE@0[=C<01Pl;00@=200<4`d03a<<00lB2`0>3`L03`l6
00l?1@0B4PP03Pl800804A8<01803@h800l@2P0B4`d030d7010A2`0<3@L02``600l@2P0>3`T020T3
010A30020`002``6018C3@092P@05aPB01@E3`0?40X300d>2003010A2`0=3PP03Pl900804Q<=00<0
3Pl900/<1P0?40X00P0<3@L00`0B4`d03@h8010A2@0201<D300:018C3@0@4@/0414;018C3P0@40h0
3`l=00h>30071`D04Q8@00l@2`804A8=00H03a0;00h?2P0?40/03Pl:00`=200@4@`200l@2`0I01<D
3`0@4@`0414<00l@2`0>3`X03a0;014B3@0K71L05AHA010A300>3`X04Q<>01DF400@4@X03Pl7010A
2@0>3`T06a`F00h?300>3`X030`:014A3`0>3P`02`/900d>2P0200l@2`0?010A300?40/03a0;01HG
4P0L7AP09RLR01@E400C50l02``7014B3@0B4`h051D@020Q700H6A@03a0;00804A8=00D04Q<>00l@
2`0B4`h04A8=00l@2`04014B3@0H018C3P0F5a805QLB01<D3`0<3@P0:b`W024R7@0>40d03@l<010B
3@0B5@h041<<00d@1`0520406QdD04mBB`11@ch04Q@?010B3`0F61<03Q0;010B3@0J71L05QPC0P0@
4Pd01@0A4`h04Q@?010B3@0@4Pd04Q@?00803a@=0`0?50h0=00>51004aTE014H500D7AX04a`I01<M
6@0<5A805Q/G014C400L7Q/09RPU01<E4P0E5a@051HC00lA3P0@4Pl04Q@A01TK600T9R<061`K01HJ
6@0D61L04QHE01@H5`0E6AP03a<B034e=00B5QD06alN01TM701dN7L06QhM01LK6P0C5aH04QHE01<H
5P0D6QP05AhK01XS800L9B80G6MS0:>^ZP0[=S806R0N04iDDP1fO7X05Q`J01DK6@0F71X05A/I01HL
6P0E6aT201HL6P0301<I5`0G7Ad061hN00806AlO0`0H7Qh00`0G7Ad061hN01hT9002024W9`0702@]
;00O:2L06b@S01TS8P0K9B@072HU01XV900201TX9@0<01/Z9`0L:bP072/X01dY:@0I9bL072XZ024_
;`0P<2l08C4`028b<@0O<S008cHd0P0V>CL0I@0V>CP08CDd02<g=P0/@400:cm002]0@@0cBD/0;DE7
02m7B@0jDeH0=4eA035:CP0eCU80=TmD03M@E@0dCE80>E9G03eFF`0nEe`0>E9G03I?E00kE5T0?5EJ
03M@E@0dCe80=51A039>C`0aC4d0<4Y:031:B@0aBTP0<DY70316A00]@d00<4I303Y@C@0cBDL0=4Y8
03=9A`0]@d40:d4o0357A@0jD4h0<DM50398AP0hCT`0=D]903A:B00/@Sl0;TA103=9AP0gCDX0>4i;
03M=BP0dBTL0=Ta903Y@C@0kDDh0>4i;03A:AP0dBD<0Ni2905mdK`0bAT@0<DE303=7A@11EE80;44k
03Y?A`0bB3d0=4Xm02a2=@0eCCl0<TXn03M>A00kDT/0>e=>03YCD00mEU<0?5EB03aFDP0nFE<0>eQ@
03QEBP19HeP0AEmC041JC`16GeT0A5eI04=LF@12FeP0C6ER04mXI@19HUh0AEiI04QQF`0oFE00@EUA
045HD010Edl0?eE=0080?eA;03T0?E5703Y>@`0fBSl0>dm303iBA`0hCDD0=4U003Q=A00lDTH0?E=7
041FBP0oEDT0>e19041ECP13EeD0LhN805EYJ00nDdd0>e1903U>A`0jCdP0?E9;03iCC00iCTL0>4e6
03Y?B00nDd`0?E9;03]@B@0iD4H0>Tm603U>A@0dBD00<4@k02m3>P0[?cH0;d0h0393>`0hBD40=dHo
0351=`0/?S009cT[02Xl<00eAS`0<T<k02Xk<`0/?CD0;d0g02i0=00Z?2h0:S`]02Xh:@0W<R@092hS
024[800P:Ql00P0N:1l04`0Q:b808bdU028/900R;2@092hV02<_:00R<BX093</02He;P0W=Rl0:3D^
02<_:@0T;bT09C0Z020Z9@0Z<bh07BHQ01dV8P0R:bP00P0L9B8201dV8`@07bPU00P07BHS01TQ7`0R
9bT051PK030e>00W;c40OXJ806I`L@80628S01@0620R01/P8`0K82<07R<U01DM6P0D7AP06B8N01LM
6@0U:bL05adI03]0?01fNgL071hK01/M6P0B51406Q`I01TK600K7AX05aTF01<E4P805ALD00/061XG
01DG500B51404Q@A01<E4P0D5Q<05QHD014A3`0F5Q@04Q8@01TI5`0201DE4`0701@D4P0B4Q004Q8@
01<C4@0E51805A4@01HA400201HB4@0G01@B400C4Q004Q4?00h=2`0E5A<05QHD01@D4P0<30X04a8@
018A3`0@3`d03`h<010?3@0B4@l04a8@010?3@0E51806QTG00`;2@0D4a4040hA018@4`0C4A@00P0?
3A0201<A500C010>4@0B41<04Q0C00`:3@0;2@`03P`?018@4`0?3A0040hA018@4`0?3A00518E00T7
2P081`T03`d@018@4`0>30h04Ph>010<2`0200l;2P03010<2`0A3@`03PX900803PX90P0?2`X01@0@
30`03`/<00l;300>2P/03`/<008040`=0P0?2``00`0>2P/03`/<00l;300300l;300I00h:2`0=2@X0
3@T:01@@4@0:1PL04Ph?01<?400?2``03PX;00d92P0<20P03@T:00h:2`0=2@T030P900d92@0>2PX0
3PX;00d92P0<20P030P900h92@0>20P040X:014;2`0200l92@8030H600X03@L700h8200>20P030H6
010;2`070P8040/;02@O7`1jM7@04@`<1P0<1PH01`0C3`h02PH500/71P0<20L03`/:00d71`0@1`P0
0P0?1PL02@0?1@H040H70147200@1PT04PL;024G6P0;0P@04`P<01462P0701052@0501872`0F2`l0
5@X>01052@0?10P01P0@1@TDooooo`006oooool03P0<4PH03aD:010E3P0>4`d03A8?00hB4`0>4QD0
3A8C00lE5@0=4a402a4>014F4P0?4A00418A100B51<03@0?4A004A<B014C4P0@4Q404Q@C01@F5@0B
51<05QPG014C4P0>40l03@l>00X<2`0?4A000P0>40l00`0?4A004A<B014C4P06010B3`0O018D4@0>
40d03Q0=00X<2@0A4a007AlL00l@3P0I6aP05ALD02`^:`3@d/l0IVQU00lA3P0F61D00P@1014C4006
20D06A/I01LI600:30/030h=00T;2P072@P05aTH014C4P0@4Q403@l>014C4P0C5A@02`d:01<E4002
018D3`0:01DG4P0<3PT051HA010B3@0620<04Q@?0001000L7QT0@dE0014B3@803Pl:00d030d800h?
2P0@4@`03@h900h?2P0@4@`051D@00d>2@092PD04A8=00h?2P092PD03Pl:00L03a0;01D030h900/=
200;3@P02`d800`>2@0?4@`03@l:00P:1@0C5A0061XE00`>2@0O8Qh0`<[90=?Og@0P;2T041/G00/D
3`093`X02a0900d@2@0@4@T00P0A4@L06@0?3`@03Pl701XK5@0B4`d030d701TJ50072080414;01@E
3`0?40X030d700d>200:2`D03a0:00X;1@0>3`T05AH@00X;1@0G61804A8<00l@2P0=3PP03Pl9014B
300D5@l00P0=3PP0100>3`T03a0:010A2`0=3PP2010A2`0500`=1`0D5@l07QlI00l@2P0A4PX00P0B
4`/02P0B4`d0414;00d>200?40/02PX800d=2`0F5Q@02@T700`<2P0?40/2018C3P80414<01004A8=
00h?2P0;30L030d800X;1P092PD030d800h?2P0?40/03Pl:00`=200>3`X0414<01PI500D5A00414<
0P0:2`H03@0<3@L04Q<<00h?1`0C50`05AH@00P90`000@004A8=01<C4@0B4Q002PX800`<2P0A4Ph0
0P0A4Pd03`0@4@`04A8=014B3@0>3`X02``701PI500=3PT04a@?00l@2`0B4`h04a@?00P9100A4Pd0
3a0;00<40002018C3P0:01<D3`0@4@`04A8=010A300B4`h05QLB01DF4@0C50l04Q<>01<D3`808b@O
01L06AXE018C3P0?40/030d8014C400B5140418>00hA2P0@4``04QD;01DH3@031P002`h800h@2`0A
4a004aDC020R7@0J71L04Q@?00h@2`0=3`X04aD@00lA3002010B3@803Q0;00@04A<>00lB2`0@4``0
3a@=0P0@5@l09@0@5a004AXE059KEP1[MG805b4P010J6@0>6AH02@h:01PJ5`0G6AH07AlL01DG500@
4Pl04A<@010B3`0F61D05aTF01@F4`0E5a@02`l>01@H5`0P92<0GF5P03Pl>`0=4A008RHU010D4`0H
71/06QhM00P<2`0T:2L061`K01DI600C5aH04QHE01DJ600F71X00P0I8Ql02@0N9b@06bHR024/:00Q
;2P07bDS01LM6`0K8Al04QPF01lU8`0201HL6P0701LM6`0I7ad061hL01HL6P0E6aT05adM01PN7P04
01TO7`0?01`R8P0K8B406R0P01XP800L8R807B<S01dV9@0K92<06R<R01/U900N:2L082XY01`X9P0J
:BH06bXW00<07B`Y00D07b/[01/Y:@0L:RX07bd]024a<00202@d<`0F01lb<00Q=3809CPf02Pk>@0V
>SP09CTh02Pl>`0[?cl0:Cdn02e2@`0dBd`0:T9402]3A@0jDeH0<DY>02a5B@0aBTl0=TmD03UBE`0f
Ce@0>E9G03YCF080>E9G00D0>U=H03QAEP0fCe@0=TmD03=>D@02035=CP03035<C00aBdX0<D]:0080
<4U600D0<TQ50316@`0_AD80;dE20316A0020398AP1B02m5@`0aAdD0>Dm=0398AP0oEE<0MXb:03E;
B@0iCdd0;D=103=9AP0bB4D0=de:045GE013FEH0?E=@03=9AP0fC4T0>U1=03]ACP0iCd`0=4Y603eB
B`2<XIP0IW]e049FE00aAD<0I7Qg06n3P@11EU40>4e502a1>00hCT40>Dm2039:?00hD4@0?5=903]D
CP0nEe<0@5UF03iHE`0oFEL0@5YG03mLE`0lFU80=eE;03eGC00jE4P0?5I;03eFD012FeL0@eaI04AM
FP16Ge`0AEiK049KE`11FUD0@U]E04ANE@13G5<0@UUA041GC`0oEDd0?eA;049GCP17G580>4a104=G
C01bQW/0?E5603]@B00eBT40=da303U?@`0kDDD0?UA804iTF01AIUl0>Tm803a@CP1_Ph@0=TY903mD
CP<0@5E>0P0oE4d08@0lDDX0>e1903eBB`0nDd`0>Di703I;A00hCdD0=da303A9@00_A3/0<4@k0396
?@0Z?SD0;d0h0352>P0^?cL0;3/d02dm<`0Z?2l09SP/0311=`0hBD40>4U303=4?P0^?cL0;Chf02Xk
<@0V>2`09cT[02Pf:00R;Al06RDG01TT5`0201dW700E01dW7@0Q:b808bdT024[8`0O:B408B/S028^
9P0O;RL08S4Z02He;P0S<R/08RlX02Lc;@0V<B/07BPR01LQ6`0@6A@06R<N01hW8`0T;BX07BHS0080
72DR02006b@Q01hW900M9R<07RLT01lX9@0M9R<0620N01XN8@0P8bP0>Ce100hF6@0U;C00:C@e01XV
9P0N:2T07RHX01LL7`0G6ah0<S@g02D[9`053`L04Q`D01HM5P0I81T05A/G01HK5`0Y;RX06adJ0001
000Z;2T07b4N01@F4`8061XG00@05QPE01PJ5`0E5a@05ALD0P0F61D04@0E5a@04aDB014C400M7A/0
4a<A018B400<30X04a<A00l?3@0F5Q@051@B018B400A4@l04a<A01@C4@0E4A005Q4@00805A4@00T0
518@01<B400A40h05aLE01HF500820H02`/9010@3P0A40h0100@3`d200h=2`0E00/:200F5A<03`h<
018A3`0c<S00518E010>4@0B41<03P`?00d;3P0B41<020H9014?4P0D4QD02PP;00d;3P0I5aX04@lB
00h<3`0<2Pd03@/>00803P`?00<0B4I902HT9`0E4aH00P0@3Q401@091`P04@d=00l;2P0?2`X040`;
00804@d<0P0=2@P200h:2@0500l;2P0A3@d04Ph?010<3@0?2``00P0=2@X200h:2`<03@T:00D03PX;
00l;300?2``03`/<00h:2`0200d92P0T02DQ8P0K5aP05a<D01/G601IEEH03`/<00/71`0>2PL03`/:
00l;2@0?2`P03PX900h:200>2PL03PX900d91`0<20D030P700d8200?2@T040X:00l92@0@2PX03`T9
00h8200=1`L02`D500T30`0:10@03PP801PB4P0N61P040X:00@0000G4A402`H61P0>20P01`0<20L0
0`0001XF5@050@003@T800/51@0@1`P00P0?1PL01`0?1@H040H70147200A1PX050T=01D:3P070000
0P0=0PH601052@0600`11@0=0PH05@X>01<8300>0`L04`P<1P0@1@TDooooo`006oooool03P0:4080
3aD8010F300>4``03Q8@014E5P0=4A@0314B00lE5@0=4a402a4<010G400?4A00418A0`0A4a800`0@
4Q403@l>00lA400200lA4004014C4P0C5A@03@l>014C4P803@l>00<03Q0?00`>3@0@4Q400P0>40l0
0`0?4A004A<B018D4`0700lA3P0G00d?300>40d02@/801HH5@0X:RL08R@Q01/M6P0?4@h02@/906]]
JP0N81d030h;01DG500:30T0418?00@60`0C5A<01PP701@F5@0n@3l0<38a010B4@082PT00`0?4A00
1P0G6AP06adL010B3`0:30L02`d800X<1`8030h900h020X500T;1P0@4Pd08B<N0084000:30L0:R/V
00l@2`0=3PT03Pl:00/<1`0<3@P04Q<>00h?2P80414<00@03@h900D60@0P8A`0414<0P0>3`X00`0C
50l04Q<>00l@2`0500l@2`0700d?2P0<3PT02`d800/=200<3PT03a4<010B3@0200d?2P0H01/M600:
30L03a8>05iXI`2CWil031PF018M6@033PX02Q8<00X?2@0;40T04A89018B200A4@L03`l400/<100G
61803a0:00h?2@0N7aT02@X401<D3P0H6A<04a@>0P0@4@/0100<3@L02P/501DF400;30H200d>2009
01DF400=3PP030d700d>200?40X04a@>01DF400>3`T0414;00<04A8<00P0414;00`=1`0>3`T02@X4
018C3@0O81X03a0:00l@20803Pl701D03a0:00h?2@0;30H02``700`<2P0G5aD092@R014A3`0>3P`0
3@h900l@2`0>3`X03@h900h?2P0@4@`02``700h?2P0=3PT04a@?01TJ5@0G61<00P0A4Pd01`0@4@`0
3a0;010A300B4`h03Pl:00l@2`0>3`X00P0<3@P07`0=3PP03Pl801DF3P0E5Ph04Q<=00P90`0Y:R@0
5QLB01@D4P0B4Q0030`:00h>300C4a004Q<>014B3@0@4@`04A8=018C3P0?40/02P/601@E400<3@P0
5AHA00l@2`0A4Pd05AHA010A300F5a8061TD00h?2P0B4`h00P0D5A001`0A4Pd04Q<>014B3@0B4`h0
5AHA01<D3`0A4Pd00P0?40/08@0H6A@05AHA00l@2`0B4`h020T400d>2P092`X03a4@01@F4P0A4`h0
4A@;00d@1P0G6Pl00`H001HI4P0?4@h06Q`I00lA40072@H02P`700lA300@4Pd03Q0;00d?2P0>40/0
3a4<010B3@0>40/03@l:00lA300D5a004aH?014F3`0200lD3P0D00dD3@0P:B@0VZ>N0;O2_P0H8R40
3ALF00/F5@0:3Pd05aTF00/=2P0>40d04Q@A01<E4P0D5Q<03Q0=014C400D5Q<05ALD01TK600;3`h2
010D4`0J04Q<B`0[;bh04QHE014E500>4Q407b<R01TM700T:2L03Q8A01HJ6@0D61L04QHE01<G5P0F
6aT061hL020Y9P0[=3409Bh[01DP700=61@06RDQ00H<2P0K8Al07bDS01`R800F71X301LM6`0701/Q
7`0I7ad05Q`J01PN700F71`05adM01PN7P0301TO7`0701XP800K8B406b4Q01XP800L8R807R@T01`U
900201XS8P0601XT8`0L9RD07BLV01XV900H9b@06BPU0P0K:RL01P0L:bP07b/[01d[:`0N;2`082h^
020`;`808C4`01H08C@b02Lj>00X>cT09CPf028e=00U>CP0:Cdl02Tm?@0Y?Ch0;D930398BP0[@dD0
;DE703M?DP0`BDd0;DI:03A=DP0jDeP0>55F039;D00gD5D0?5EJ0P0iDUL01@0kE5T0=TmD03A=DP0e
CU<0<Te?0080<De>00D0<di>039<B`0bC4T0<4Y70319AP0203I<B@0303E;B00bB4D0=4Y80080=Ta:
0P0cBDL203Q>C00=03mED`1WOG/09C/i03U?C@0`AT@0=de:03E;B00hCT/0?eEB041FD`0hCT/0=Ta9
03Q>B`0203]ACP0O03U?C00eC4L0=da503Q=A00nDd`0=DU702Tm>`1=HF00DfMU03E9A`0dBD80=D/o
03YA@P0gCSh0<DTk03]CA`0nED/0?EI@049KEP13G5T0@5YI041JF011FeP0@5eH03eKE00hET`0?5I;
03YDB010FTl0?EI@04MPF`0204QQGP0O04MPG@13G5T0@EYF041IE010FE<0@UaC045JD@0nEDd0?EA<
03aBB@0lDDP0<TLn0355>`0^@SL0@5A9049FB`15FDh0>e1803A9@00fBd80=de103Q>@P0lDTH0=4Xn
02Pm=P14FE80=d]904iRH`13EeH0?E9<03mDC@02041ECP0403eBB`0lDDX0?E9;03]@B@80?55:05L0
>4e603E:@`0eC480<TLn0356?@0cB3l0=TY103M;@P0]@CP0;d0h0311>@0[?3@09cH_02Xj<00Y>bl0
:3T_02m0=`0iBT80>T]503=4?P0[?3H0:CXd02Xk<P0Y>S009cT]02Pf:00T;b407BPJ01XU600O:Ah0
8B/P024[8@0Q:b808R`S028/900T;RH09S0X02Hb:`0Q<2T08c8[02Lf;`0R<BX082dV01l[9@0S;RP0
7bXT02H`:`0X<B`0@da7034j=P0J8b005b0M01`U8P0Q:RL09Bh[028[:00Q:RL082TV024Z9`0O:2D0
72<R00lC5P0];S<06AdR020X:`0P:R`0Ef=S01XV9P0Q;Bd072DV00lD5`0/<3<0VYbO05AJEP0J91`0
5R0H018I4P0A61404aTE014F4P0^<bl05ALD02T[:00^<2d03a4>00d?300B51400P0D5Q<0100G6AH0
5QPE01@F4`0F61D201LI5P0;01<E4P0@4Pl08B4O01LG5@0E5A<03`l=01@D4P0@40h05QHD01DE4`0C
4a400P0B4Q000`0C4Q005A4@01D@3`0201<?3P0801<A3`0C4Q002`X800d<2P092@L06ATG02<S8@0@
40h2010?3@03014@3P0B4@l040l=008030/901h040l=01dL6P0@3`d03`h<02h]:`0L6Qd03`d@018@
4`0A3a803P`?018@4`0K6A`040hA018@4`0@3Q403P`?01@B5@0]:bh00@0200h<3`0A3a801P@7018@
4`0<2Pd00P0300400P071@P03@/>00/92P0@30/200l;2P03010<2`0A3@`04Ph=00<03PX90P0?2`X0
100B3Ph04Ph?010<3@0?2``500d92P0400h:2`0=2@X03@T:00h:2`803`/<00X03PX;00d92P0=2@X0
3PX;00d92P0M6AX0;RX[071/K@0I5AH03`/9200>2PL0100=2@H030P500`81@0=20H2010:2P0?00l9
2@0A2`/03`T900l92@0>20P030H600P20P0:10@040X:00@0000:10@040X:01/E5@0400004@/;00H0
3PP800L02@D402TU901oNgX0:BDT01HB4@0?2@T040L800803`H700T03`D601061`0A1`P03@8601H;
3`0D2@d02`0401052@0D2@d01`0A1PX01@0<0@D03P<700h31`0C20`09AXN00H040D95?ooool001_o
oooo00d04QD800hA1P0?4PX04AH@014E4`0;3a00310C00`A4P0?5AD03Q@B00/A300@5Q003a8A00<0
418A00l03a4@00d?3P0?4A00418A00lA400=3`h03a4@010B4@0C5A@051HE00lA400>40l04A<B010B
4@0A4a800P0>40l00`0?4A004Q@C01<E500600lA3P803@l<01D04aDB00h@3@0>40d06A/H010B3`0>
40d04A<@00lA3`0>40d0418?00h@3@0?4@h04Q@A010B3`0?4@h02`d;00X<2`0K7A`05aTH00/=300E
5aH00P0?4A001P0>40l02`d<014C4P0D5QD051HB00P:1P80418=01X02@/601<E400?4@`04A<>00`>
2@0:30P030h900/=200>40/02``700/=200@4@`03a0;010A300C50l01`P4010A300=3PT02P`701PJ
5@2BThh0AdQ3018C3P0A4Pd03@h901@E40H03a0;02X04Q@?014C3P0?4@`03@l:00h@2`0@4Pd03@l:
01<E40092`L0418=00/=200=4@`0318@010L70094a404AXG00H=2@0<4Pd03Q8<00hB2`0?40L03`l5
010@100B4@L0414900d>200B4`d04a@>00d>200B4`d030d701<D3P0A4P`03a0:010A2`0>3`T04a@>
02TZ900A4P`02``6010A2`0I6Q@400l@2P0500h?2@0=3PP03@h800l@2`0@4@`00`0@4@/04P0E5Q00
824K018C3@0=3PP051D?00X;100B4``03a0800h?200A4P`04a@>014B300?40/030`:010@3P0H61H0
3@d;018B40803a0;0P0=3`X0200@4Pd051D@010A300G61<030d801HG4P0N7aX051D@0P0@4@`0100?
40/03Pl:00l@2`0A4Pd2010A300400l@2`0=3PT0414<018C3@80414:01`01@H1018C3@0^;bT0UiRB
01dN6@0;2`T03`l=01<C4@0A4@l0414=014B3@0?40/03Pl:00l@2`0A4Pd051D@010A300F5a803Pl:
01TJ5@0>3`X04Q<>00L80`0F5a803a0;01TJ5@0Z:bH0414<0P0F5a801@0C50l051D@018C3P0?40/0
414<00804A8=01L0414<00l@2`0>3`X0414<00`=200>3`X04A8=00l@2`0;3@`04Q@C018D400=3`T0
41<;010C2@0;3P@041<900lB2`0:30P03a4>010B400A4a004aD@014C3P0200lA3005010B3@0;3@P0
3Q0;014C3P0@4Pd00P0>40/00`0B5@h04QD=010E3P02010E3P0I010F3`0@61<0;cLb04I@C00=6AH0
5B0M00XD4P0B5a@04Q@A01HH5@0O8Ah04Q@A01<E4P0E5a@04A<@01DG500H6QL05aTF01HH5@0F6QT0
3a<B01<G5P0<40l05ATH018F5@0201@H5`0O01LK6P0>4Q405ATH018F5@0G6aX05ATI01<G5P0C5aL0
5Q/J01LM6`0A6AL06b<Q010I5P0B71T05AlK01HP7@0M8b405adK010F500I7ad041HD01/Q7`0G7A/0
5A/I01TO7@0G7A/05A/I01PN700D6QX05Q`L01LM7@0301PN7P0301XP800N92@07R@T00806b4Q00l0
728R01LP7`0G81l05b4P01TS8P0K9B@072LU01/X9@0J:BH06bXW01`[:00M;2T07B`Z01`Y:@0M:b/0
0P0M;2`0:00M;Bd0830`024a<@0O<S408cDd02Hh=`0U>3L09CTh02Hj>@0W>cX0;4100396A`0aATL0
;D=50359B`0eCDl0=4a?03=<D00dCE40=4aA03QAE@0jDUL0=TmD03M@E@0iDEH0=e1D03UBEP0gCe@0
=DeB03UBE`0fCe<0<Ta?03IAD00fDU00=E1?039<B`0`BDP0<T]903E>B`0fC4X203M=B`0C03I<B00e
C4/0>4m>03]BD@0gCTd0=Te<03U@C`0gCTd0@EQG03A;BP0eC4/0?EAC03=:B@0hCT`0=de;03Y@C@10
EU@0@UQE03iDD@0203aBC`0Z03eCD00kDDh0>Dm<03M=B@0dBD80>Tm603I;A00iCTX0;T<o03Q<BP0`
A480;T<o02e2>`0cBCd0=Tdn03mFAP0eCD00>U5603aCBP11FU@0B65M03iHE@11FeX0?eYH03eJEP0o
FeH0?EYC03UFC00oFDh0?EM;04EOE00mETl0BF9M04YSG`16Ge`0D6UU04iWI014GET0?UMB049KE@0o
FE00?eI>0P0mE4/0E`0nE4/0@5E;049GC@0oE4T0@EE:03a@A@11EDX0DfML03M<@`0fBd80?E99045G
B`0oEDT0@5I:04=ICP0oE4d0AeaF04=GE00lD500A5QF03eBB`0kD4T0>Tm703]@B00lDDX0?E9:03Y?
B00hCDH0>Di603]@B00iCTL0=da403I<@`0cB3l0=DY103U>A@0gBd80<dLn02m3>P0^?cL0<T<k02dn
=P0X=c00:c/b02ho=00_@3H0;Slf03Y;A@0jBdH0<D4m02Xk=@0Y>S@0<d@l03U:@00dACX0;3X]02Pc
9@0U<2808bhP02@_8@0V<2D09c4V02<^8`0O:B0082XQ02<]9@0T;RH08blX020^9`0R<2T09cD^024_
:00Q;RL082/U02Td;P0H8ad08B/U01`U800S;2L072DQ024Z9`0N9b@08b`Y02Xc<00]=S<09Bh[02</
:@02020Y9P0S01lX9@0N9R@07AhR01hO900E6Ah06B4T01dV:00b?Cd06RDU01/V9P0E7Qh05Q`L04=7
A`37b<P0EUeF01`U7@0E7AH041L@01dT7@0E6a@04AHB01XO6`0E5a@06Q`I01TK600J71/08R@Q02<U
8P0L7Q/05ALD01LI5P0E5a@061XG01LI5P0E5a@00`0D5Q<01P0H61H05ADC01XJ600E5A<05QHD00d=
2`<05ADC00D051@B018B400A40h0510?01<>3P02014=300;018?3P0B4@l051<A01<C4@0A4@l0DE5?
05MGE@0C4a4051<A014@3P0@3`d00P0B4@l05`0>3@/040l=014@3P0:2@P040l=00d<2P0C4A408R0S
00X82`0=2`h04Q0C00d;3P0>30l0?C/n018@4`0;2@`03P`?00l=400C4A@09bDX01@B5@0<2Pd03P`?
008040hA01804A0B01<A500C4A@03`d@00`:3@0@3Pl040`:010;2@0@2`P04@`901<=300C3P/040/9
014;2P0@30T04@d:018<2`0@30`200h:2`0:00l;300@30d04@d>00l;300<20T03PX;010<3@0>2P/0
30P900d92P803`/<00`03PX;00d92P0=2@X03@T:01@@4@0<20T040`=00l<300D41402`L500l<1`0>
2`L200h;1P0I00l<200?30L03P/600h;1`0=2PH030T400`91@0<1`H04@/;010:2P0>20P04P`<00l9
2@0<1PH03PP8010:2P0=1`L030H600l92@0?2PX05a4A00/61P0H4Q802`D5010:2P0600d71`07014=
3018A4<0`[jm024M700:1PH04@`<0107200200l61`0:00l51P0@1PL04@L800/2100C2@`03PD70146
2P0A1`X03PD701462P804@L:00l04@H:01472P0A1PX04`P<00l5200F2`h04`P<01462P0Q5QT040D9
01062@0@1PP040D901062@0@1PP05?ooool001_ooooo03@03A8>00lD400?4a803Q8A00`@400:3Pl0
2@d>01XN7`1UJFX0310A00hB4@0<40l03A4B020T9@0=4A800PH700lC500@51D02@d>00lC500B5QL0
2Ph?00dA4P0:3Pl02`l>00D9200=4A003Q8A00/?3P0C5aH03A4@00hB4@0:3Pd02`l>00dA400;3`h0
418?00lA3P0;3@X030h;00d?300:30T03Q0=014C400@4Pl030h;00d?300@4Pl051HE018D4`0@4Q40
3a4@0P0=3``020092`P03@l:010B3@0@4Pd06adH010B3P0;3@X03Q0=0P0<3P/09`0@4Pl02P`900/=
2P0<3P/03@l<00h@3@0?4@h0418>00L9100@4Pd02@/601LI50051`80418=00L910041P404Q@?00lA
300:30L0314;00/B2`0:3`T03Pl:00l@2`0>3@T03`d901PG4`0J6aH02`d801PM5`1<Dd`0JfmY02<U
800@4Pd02`d800D70P0?4@`04Q@?010B3@0300h@2`0700`>2@0<3@P03Pl:010A300=3PT030d800l@
2`03014B3@0E00l@2`0>3`X030d800l?3@0?3`l04A4@00l?3@0<30X03Pd:00/:1@0>3@P04Q0:00l<
1@0?30<04a8:00l@2P0?4P/02`h700L:0`0E61403Q4:00@02@`500@02`h700`?200?40X030d:0P0=
3PP00`0G6180ADI000l@2P0200l@2P0=010A2`0B4`d04Q<>00lA3P0>40d03a4>00@60`0>40/05ALB
00/>1`0<3`P01PT001@G3P0200hA2009010C300G6Q@030h901<E400:30L04Q@?00d?2P0A4`h0418=
00803@l:00<03a4<00T>2P0@5A400P0>4`l00`083@L02`d800d@2@0200h?2@0800h?200>3`T03Pl9
00l@2`0B4`h06AXE01LH4`0@4@`2018C3P0D01<D3`0B4`h04A8=00l@2`0>3`X04aD@010B3@0?4@`0
418=018D4@0D5Q<05QPE014C400=3``0004002@V8`0;3@T03a4<00h@2`0=3`X200lA300:00h@2`07
2@@03Q0;018D3`0;3@P04Q@?01<E400@4Pd03a4<00h@2`803@l:00L030h901@F4@0E5a8030h901<E
400D5Q403a4<0080418=01403a4<010B3@0@4Pd03@l:00/=200>40/04A<>010B3@0=3`X01@L201dO
6P0>40X041<<00d@2@0?4PX041<<014D3@02018E3P804A<>00`03Q0;00/=200F61<06adH010B3@0?
4@`07R0K010B3@0?4@`061XE018D3`0@4Pd5014C3P0;010D3P0=4P`03a@>00dB3@062`L04QLC01DJ
5P0F61<04A<>01@F4@0F61<00P0D5Q408`0G6A@051HA01DG4P0D5Q404Q@?01HH4`0A5Q8051TE01HK
5`0A5Q803a@@01XO6`0G71P04aPD00P=2@0@5A404QLC010D4`0F6Q/04aLI018F5`0D61/05ATK01@H
6@0E6A`05AXK01@J6P0E6Qd051XK018H600A5aD05adK01@J600F71X06AlM008061hL0P0L8R002@0B
61H05A/I024W9@0J81h05A/I01HL6P0E6aT061hL01hT8P0201HL6P0F01LM6`0I7ad06R0N01XP7P0O
:BD062<O01dX900L:2@06BDQ01`X900N:bT06RPX01PX9`0K:bX08C4`02<c<P0J:B`06bX]01X/;P0P
<C<02Q`N02Dg>@808C<e02L08S@f02Tk?@0X>S`09cXj02Pn?00W?C/0:3hm02]0@@0^@d@0<DI80397
BP0cB4/0=T]?03E=D@0hCE80=de@03A<C00gC4d0>Dm@03M?C`0fBd`0=Da<03E=C@0gC4d0=de>03I>
CP0fBd`0=dm@03UAD`0gCe40<d]=02m7B@0^@dH0<DI803M<C@0iCTl0=4U:03=8B@0fC4d00P0cC500
1@0iDUH0>U=G03I?D`0gD5@0=TmC0080>eAH00T0=4eA03eFFP0mEUX0?UIH03M?D@0bBT`0?UIF03Q@
D00mEE@00P0jDe008P0kE500>E9<03M@BP0eCDH0<DHo0397@00^@c`0<DHo03M<A@0`ACh0>4e402i3
>P0aAc`0<4Hi04=IC01BJ5/0>4m503QBB@0jDdd0?5EA03iGE00oEeL0?5AD03eEE00nF5D0@5UE03mI
DP0lETd0@E]@045IC@0oET`0@EQ>04IME@19H5X304IME`0@04ELEP14FUH0@UUC04=JD012Edd0?596
03I<@00iCd80@5I903mEB00lDd<0>E1003]B@P0jDD40<DPh03eBB080<TLn02@0GW=Z0;_@a`19GUD0
AU]D0397@00gC4L0B5aI049FE010EE00>e57041EC00eBcl0>e5603M<@`0hCT80>e5603U>A@0fC400
=DY003Q=A00kD4L0?51903E8@P0aA3h0=4M1041AB`0eAT00<44k03A3?P0fAD00<3lj030l>00b@CX0
;chg0391>P0gASl203e<A@0C03E4?P0V=Bh0;Sdf03A3?00_?SL0=4<l02Xi;@0T<RD08RhR01l/800N
;1l07b/Q01l/8P0L:B006RDM01dY8@0R;bP09C0Z02@_:P02020[9`16028]:@0Q;2P07RTU01lX9@0M
9R<06B8O01`U8P0N9b@06R<P01XQ800L8R805adM01lU9@0f?3`09bd[01lU8`0N92809B/W02L]:@0T
:RH09R`X01TM7P0H71l06QhP01lT9`0Q9bL07B<R01PN7P0J81h061hL01XN7@0T:BD0;34]01lT800C
61@02Pl;00hC3`0N8al061XG05UKF00`<Rl04Q@A01XL6@0E5a@061XG01`L6P0@40h071`J010@3P0P
81h05ADC01/K6@0E5A<071`J01HF500=3@/0820N01DE4`0J6QP05ADC01<C4@0F5Q@051@B00/;2@0T
928051@B01LG5@0;2`T06a/I01<A4P803`d>0P0C4A801@0?3@h0108301/I6P0C4A80OG]l00805aDF
02003P`=00l=3P0D4Q<04a4B010>3`0D4Q<030X;00l=3P0@3Pl03P`=00d;300>30d03`d@00d;3P0D
4QD04a4D00d;3P0A3a803@/>00/9300?3A004@lB010>4@0B41<05A<F00L5200:20/04@lB06YXJ`0k
>C`02`T<00h<3`803@/>01@03`d@010>4@0@3Ph05A4B00@30@0>2`/03`/<00T81P0:1`L030P901`K
6@0;20P02@D600d92P0>2P/03`/<00h:2`0?2``03PX;010<3@803@T:00X040`=00P41@0;1`P04@d=
01HB4@0E4A003`/:00H20@0A3@`040`;1@0>2PT03@0?2`X03`/800l;2P0?2`T03`/800l;2P0?2`T0
3PX700h:2@0?2`T040`9010<2`0?2PT01@0=1`L03P090`<02`D500l92@0?2@T030H600T30`0:10@0
3@L700l92@0;1@D02P@400l92@090`<04P`<0P0=1`L0200;1@D04P`<01PB4P0=1`L05a4A010:2P08
0P8040X:1@0=1`L06@0>1`L04`X=00P2100:0`D040L:00T1100=1`T03PD8024J700K5AL040L:00d5
200B2@`060h?00d3100900004`T:01@:2P0800005`d>00/20P0@1PD05`d>0188200a9bH05?ooool0
01_ooooo00<02Ph?00`@4@0>4Q<00P0?4a@02P0>4Q<06AdN01PL7@12ATL010P900lC500B5QL0<CDf
03/o@00O8b@200dA4P0C00@82@0@51D02`l@00hB4`0?4a@0310A00X>3`0=4A004ADD01`P7`0I7A`0
3a<B01<G5P0830/051PG01<G5P0=4A002Ph=00T=3002014C400500d?300?4@h0418?00d?300>40d0
0P0?4@h00`0=3``03Q0=00lA3P0300lA400@010B4@0A4a004Q@A018D4@082PD01PP3010B3@0;3PL0
4QD@00h@3@0D5Q<04Q@A010B3`0F61D0418?00lA3P803Q0=0P0<3P/06`0:30P03Q0;01TK5P0I6aH0
3Q0;01<E4017BD@071hI00lA300@4Pd02`d800X<1`0<4P/02Q@<00lD3P0?4Pd0414<018A3@0?2`P0
2`X600l@2`0<3PT05QdF03U0>@0i?cP02P`700lA300201TK5P0>00h@2`0;3@P02P`700X<1`0=3`X0
3Q0;00d?2P0>3`X0414<014B3@0>3`X03@h9010A300B4`h201<D3`06018C3P0A4Pd0414<00l>300A
3@`04`l>0P0E4A00100F4Pl04a0;018?2P0@3@P2014>1`07010?1`0<3@L041<<00X=1P0>4@X030l8
00@7000200/>1`8030l80P0=40T0;@0<3@L051D?00l@2P0<3@L01@H2014B300@4@/03a0:00h?2@0?
40X04A8<01<D3`0@4Pl03a4@018D4`0C5A802@/700h@2`0J7AH05AP@00X=100=40L03A06014D2`0A
50d03@l:00L9100>40/03@l:00h@2`0=3`X0418=00lA300=3`X03Q0;010B3@0<4Ph02a0<01XP7005
2PH03Q<=01<H4P0?4P/0414;00l@2P0300l@200401PI500>3`X03Pl:00l@2`803Pl:00@04Q<>014B
3@0A4Pd04A8=0P0@4@`07`0@4Pl03@l<00`>2`0<3P/03Q0=00lA3P0A4a0051HC01<E4P0>40d06A/H
00H8100=3`X0418=00lA300>40/03a4<018D3`0>40/04aD@01@F4@0>40/03a4<00`>2@0?4@`0418=
014C3P0@4Pd03Q0;014C3P0?4@`00P0<3PT00`082PD03@l:018D3`0200h@2`0300lA300>40/03Q0;
008030h900`03a4<018D3`0B50l04Q@?02<V7`0d=c0051L@00`?200J7AH03A0900lB2`0@4``3018E
3P09014D3@0G6A@04Q@?00/=20010`002@/603`n>@0c=C008B<N00804aD@00<03a4<018D3`0A4`h0
1P0A4`h0600?4@`07R0K01XL5`0B50l02`d801HH4`0E5a806A/F01LI500A4`h04Q@?01<E400B50l0
5ALB01@F4@0A4`h051HA01<H500D6AD06b0L01`Q7@0E6QH04QLC01DJ5P804aPD01T051TE00hC3`0D
61L05QXK01<G6P0B5QT051PK01DI700C5aX041@G00lC5P0A5AP05QXM01LK7P0D61T06AlM01/Q7`0D
6QP04aTG01LM6`0F71X05A/I02H/:P0]<c407bDS00803Q@B00<05A/I01TO7@0L8R000P0H7Q`0100N
92806R0N01XP7P0J81h201TO7@0?01LP7@0J91l06bHP01hY8`0K9b<07BTU02@`;00G9R<05bLV01PX
9`0J:RT072`[01`/;00C9BP09cTm00805BL[01T07c4e020b=P0R=3P08cDi01la=@0R=3P093Hj02Di
>P0V?3X09C/i02Dj>P0V>c`0:Cho02e2A00`ADP0<DI903=8C00dBDh0=DY?03A9B`0cBDL0=D]903U?
C@0hCT`0=D]900<0<dU700P0=Ta:03U?C@0hCT`0=Ta<03E:C@0fBdh0>4e@03Y?DP80?55D00X0>TmB
03Q=D00bAdX0<4E80316B@0fCe@0<dmC03QDF00iEET0=51D0P0fDUH03@0jEUX0?e]O03iJGP13Gf<0
=U9F039:CP0kDeL0?UII03Q@DP0jDU@0>51@03QACP0iDTl00P0jDdl0@00hDD/0=Tm803U>A`0iCTL0
<TM00315?00dBD00<DHm0316>P0gCD40?UA802To<P0bB3/0?UI903eDBP0mETl0?eQB045JE`13FeX0
A5aL05UaL@17H5h0>U=?03aED@13G5D0A5iC041GC@11FDd0@UU?04=JD016GE@0AeiF04UPF018GeP0
AeiH04IME`13FUD0@EQB04YOEP13FDd0>4i2049HB`17GDl0@5M703iEA@0fCC`0<4Le03=:>00kDT00
?5=303Y@A015FU40C65H03Q=A01RMg00;D8k03Q=AP15FUD0EV]V03=8@`11EE<0>4e803U?A00iCd<2
03aBAP0803Y@A00oEDT0>U1403U?@`0fC400=D/o03U?@`0lDDP203U<AP0603A7@@0`@cd0=TM102m0
>P0a@S`0;Sdh0P0a@3/02@0`?3P0<Cdi03=2>`0d@c`0<d8k0391>P0`?cP0<T4j02dl=@0202/j<`0A
0350>@0eA3d0=4<i03A2=@0]>bh082hQ01d[7P0S<2H0<3dc02Xg;P0N:b807BXR02@a:P0U<R/092lZ
02@]:P0R:bP00P0S;2T3024Z9`0]020Y9P0O:2D07bPU01hW900L8b<07R<V01dS8`0N92@0:S0`028X
9P0U:bT08RPV028X900O9B406R0L01/Q700O8b@07R8U01lS900P92D08BDV01lS8P0J7Qd0720O01`Q
7@0E6QH04aPD01/P6P0B51403a4>01hP7@0F61D03Q0=01PJ5`0j?3T0828O014C400K7AX061XG01XL
6@0B4Q005QHD01XJ600G5aD0Fe]I00807QhL018051@B01PH5P0F5Q@06ATG03Hf=00O7ad061PF014A
3`0?3`d0410>01<C4@0F5Q@0820N01PH5P0L71X04a<A01LG5@0C4A82018@4@804a4B00P04@l@00l=
3P0:20T03`d>02`Z:`0C4A802@L801DC50804@l@0P0?3@h0100F51D03P`=014?400@3Pl200l=3P0>
010>3`0>30l03`d@01PF6@0B41<01`D800P62@0?3A0030X=00h<3`0=2`h030X=010>4@0;2@`200l=
400900h<3`0f=3L07Q`O01DC5P0A3a8030X=00/9300>30l03`d@00803P`=00<02`T:00l=3P0=2``0
0P0A3a001@0J61T0:RPY014?400<2P/03``=00D03`/<00d03PX;00l;300@30d040`=01<?400A3@h0
2PH600X61@070`803PX900X61@0=2@P03`/:00`03PX90P0=2@P200h:2@0300l;2P0>2@T03@L700H0
3@L70P0?2@T01P0>20P02`D500d71`0<1PH03@L700h820803`T900`030H601@>3P0>20P040X:00l9
2@0H4Q80A3hn02HP800C3@d030H600/51@0<1PH600d71`0:00`6200:10H03@L900l92`0=1`T040X<
00L10`0C3@l04@/=00`620803PP:00`03@<401@:2@0?1@@0200000l71P0L4Q4050X901L=300@1PD0
3@<200l51@0[8B0Dooooo`006oooool200dA4P803Q8C0P0=4A805@0J7Ql051PI01@H6@093@h03a<D
00hB4`0:3Pl04aLH00/?400830d03Q8C00X>3`0=4A804aLH00H:2`0>4Q<04ADF00/?400:3Pd03a<B
01<G5P0200hB4@0401HJ6@0G6aX07R8Q01LK6P<03Q8A0P0@4Pl02P0<3P/03Q0=010B3`0>40d03a4>
00`>2`0=3``0418?00lA3P0=3``200lA400:00h@3`0@4Q404A<@018D4@0?4@h03@l:01@F4@0A4`l0
71lH01TK5P803@l<0P0<3P/00`0A4a003Q0=00h@3@0400h@3@09010B3P0T9R405aTD00d?2`0<3P/0
20X602d_:P0A4`h02@/600<03@l:01<02Q0:00P@2@0<4@/030l900/<1`0>3@T040l;00h=2@0>3`X0
3Q0;00L=1P0940T02Q0:01HH4`0@4Pd06adH024S7P0A4`h03Q0;008030h90P0>40/0100=3`X03a0;
010A300A4Pd200l@2`03014B3@0=3PT03@h900<03Pl:00<03@h9014@3P0A40h00P0?3P`03@0A40h0
3`h:01DD3`0A40/03Pd8010@200A4@T03Ph600/<1P0D5a003Q4:00T<1`0>4@X00P0<3`P0200>4@X0
41<<014D3@0?4P/03A0900L81@0N7aT03Pl90P0A4P`00`082@H04Q<=00l@2P0200d>200B010A2`0C
50l04aDB00h@3`0;3@`05ALD010B3`0=3`X04A@=010C2`0A50/01PT3010C2@0G6Q403Q4:01TK5P0S
9B004A<>100?4@`200h@2`0900lA300@4Pd0ATQ502h_;@0;3@X05QLD00D60`0A4`h04A@=00804A8<
00P0414900l@200?40P0414=01DF4@0A4Pd03a0;01<D3`804Q<>00L0414<00l@2`0A4Pd04a@?01DF
4@0@4Pl03Q0=00803@l<00T03Q0=00lA3P0=3``04Q@A00lA3P0:30T04A<@014C3`0@4Pd00P0A4`h0
3@0>40/03a4<010B3@0<3PT0418=00`>2@0?4@`05ALB00d?2P0>40/0418=01<E400B50l00P0@4Pd0
300:30L06Q`G03@f<@0F61<01`T400lA300@4Pd04Q@?01<E400B50l0418=014C3P804Q@?00`04A<>
018D3`0C5A003a8;018E3P0K7QL04A@=00hA2P0C5Pl03Q4:00lB2`0A50d3018E3P0<00d>2`0=3`X0
4aD@018D3`0<3PT05QPC01`N6@0A4`h03Q0;01@F4@0C5A005ALB1`0A4`h0200@4Pd051HA010B3@0K
7AP04A<>01@F4@0@4Pd04Q@?0P0D5Q406@0H6QD04aD@01<E400H6QD05aTD01DG4P0L7QT05AXF014F
4P0K81`08RLS01PM6@093PX05AXF01HK5`0C61@0724M018G4`0H7AX05ATJ018F5`0A5AH04aLH01@H
6@0C5aP00`0G6a`01@0H71d05a/L01DI6P0J81h0728P008051XH0P0I7ad00`0L8R0061hL01PN7002
01LM6`0[01XP7P0Q9bD06AlM01LM6`0E6aT061hL01hT8P0G7A/061hL01TO7@0K8Al0728P01/T8@0J
9Al07RTU01lZ9P0I9B407BTW02@`;P0F9B806RXY01d];00N;Rd06b/Z01TY:@0J;2l0@UAH08:DV00`
@TH09SPl01la=@0U=c/0:3Xn02<e>@0T=SX09SPl02Pl?@0Y?cd0:3hl02Pn?@0Y?Sl0:Sm002i3A@02
0356B@060397B`0bAd`0<dQ=03=8BP0eBdT0>4i<0P0lDU006`0hCT`0=Ta:03A:B00bB4H0=4Y803M=
B`0hCT`0>Di?03M<C`0fBdh0=DY=03M<C`0jCe80>4e@0356B@0_A4L0=4U<03Q=D00iD580>eAI03QD
F00lF5`0>eMK03IBEP0hE5P0>eMK03MCE`0203EAE@0;03iJGP0mF5`0KhN:049JF`0gCe00=4a<03M?
C`0kDe<0=Di;03M@C@0jDe000P0lEE40;P0kE500?eA>03mDC@0gC4D0;D8k02m4?@0fBd80>U1403=9
?@0jD4@0=D/n03U?@P0hD4<0?5=903aFCP0oF580@EYG049KF@12FUX0Jh>305E]K012FeL0@5UE041J
DP0lET/0@5M=049ICP14Fe40AUeC04IME016GED0Bf9J04]RF`19H5X0B5mI04EKE`13FU@0B5eD05M]
H@15Fdl0BV1C03]AA014FTd0>U5103Q??`0jDD4203aC@@0C03eDA00mDdL0A5U@03eBB@0eBT40?E9;
03]@B@1DJF80A5UD03Q=B00mDTd0AUYH045FD@0nDd/0>e1704IKDP0lDDP0@UM>04MLD`0203U>A@80
=da300`0>Tm603eBB@0nDD/0>Te703A7@@0eB480>T]503a=A`0b@cd09SD`02Th<`0_?ST2030l>005
02hm=P0c@S/0<D0i02`k=00^?CH00P0a@3T03P0R<BX07bhW0350>@0/>c@0:cX`02hl;`0[>B`08BhS
01`Y7`0R;bD0<Chd02dj<@0O;2<07R/S0P0U<R/0100V<B`09c0]02</:@0R:bP202</:@0901hW900K
924072DR01/T8@0J8b006b@Q01dT900U:Rd09bd]00807bDU01P082HT028X9P0N928082HR028X900P
9R808BPR01`P8@0M8B@0720Q01HJ6`0E6AX061`K01dQ800H71/06QlK01PM6@0D6AD0:2dW05]MFP0W
:BH0418?01/M6P0G6AH201PJ5`805aTF01<06A/H01XL6@0I6aP05QHD01dM6`0H61H0410>04E5@`0C
4a405aLE018B400G5aD051@B01<C4@0U9B<07AdK018B400K6aT07QhL00804a<A00L061PF018B400H
61H06ATG01HF500=3@/04@l@0080518C0P0B41402`0E4a@04a4B01HD5@0H5QL01083018@4@0>30d0
4a4B01HD5@0L6Q/06QPI00804Q0A00`04@l@018@4@0A3a003`d>014?400C4A8040hA00d;3P0C4A@0
40hA00l=400F51L200l=400<010>4@0=2`h04@lB01XH6`0F51L06ALJ01<A500@3Q4030X=01<A500G
5AP03`d@0`0=2`h04@0>30l040h?00d;300A3a003@/<00/92P0=2``02`T:01HD5@0Q7b003@/<00/9
2P0?30d03`/<00h:2`0?2``03PX;00803`/<0P0@30d0200>2P/05A4B018>3`0;1`L03`/:01<?3P0?
2`X04`l>0P0<20L600h:2@D03@T80`0<20L300d9200300h9200=1`L03@L700<03@L700D04`d=010:
2P0<1PH03`T9010:2P0200h8208030H600`04@/;01@>3P0A2`/02`D5014;2`0;1@D030H600/51@0A
2`/05a4A00P30`0=1`L200h820L03@L701402`D7010:300@2P`03PP:014;3@090`D03PP:00/51`09
0`D030H800l92`0:10H040L700l51P0C2@X050X;0147200200/10P0501882@0<0P<04@L800l51P0D
2P/05?ooool001_ooooo0P0?4a@02P0=4A80310A00`@4@0;3a001@T:010D5@062P/04aLH00dA4P0:
3Pl201@H6@0F014E5P0@51D03a<D00`@4@0B5QL02Ph?00T=3P0D61T02@d>00hB4`0=4A003Q8A010D
4`0E6AP09b/Z03@h=`0E6AP03a<B00T=300:3Pd02`l>00L;2P80418?00`030h;00h@3@0?4@h03@l<
00lA3P0;3@X030h;014C400?4@h030h;010B4@0?4A0200h@3`803a4>00`0418?00T;1P0E5a8061XE
0;Nj/`1^LF`061XG00`>2`0=3``03a4>014C400;3@X200d?30803a4>0280418?00/=2@0B50l051HA
010B3@0j?3L0B4Y501lQ700?4@`03Q0;018D3`0?4@`02`d800`B300=50d02Pl900lB300B4`h03`h:
00`;1`0;2PH030d800lA30093PP020l800X@2@0B50l02`d801PJ5@0@4Pd01PP300d?2P0;3@P02P`7
0P0<3PT0100:30L03a0;00h?2P0>3`X200l@2`803Pl:00<03a0;010A300A4Pd00P0@4@`0500:2@L0
3Pd;00`;2@0?3P`05QDC01HE4@0>3@P040l:014@2`0>3PH03`l7018C2`0J6aD030l8010C300930D0
3Q4:00lB2`0;3PL03Q4:0P0@4``02P0>4@X02`h702X[9@0m?SP06Q/E01@E3`0G61803a0:014B300?
40X200d>200A00l@2P0A4Pd0004001<E4P0A4a00004001HH500D5Q403Q4:00X=1P0A50d04QD<04E8
?`1/KfH02`h701HH4`0S9B000P0<3PT03P092`H0418=00lA300>40/03a4<010B3@0@4@`05A@B0040
000N7A/010@301TH500@4@`0414;0P0?40X02P0>3`L030l600`?1P092PD0004000H70P0H6A@05AHA
00L80`0A4Pd200h?2P03014B3@0E5Q405QLB00803a4>00`0418?018D4@0C5A8051HC010B3`0<3P/0
5ALD01HH5@1`LVl0GEmK01LI500=3`X200h@2`0700d?2P0?4@`04Q@?01XL5`0B50l03@l:018D3`02
00h@2`803@l:00d03a4<010B3@0A4`h02`d800h@2`0E5a802P`700P:1@0@4Pd04A<>01<E400E5a80
4aD@00<04A<>00X03a4<00h@2`0@4Pd04aD@00lB2`0<3`P0:B`U01`O60062@8041<<0P0>4@X0400@
4``04A@=014D3@0A50d0;BlZ01/M60092`H0418=01HH4`0E5a804aD@014C3P0F61<06Q`G01HH4`0=
3`X6014C3P0902d_:P0G6A@03Q0;00h@2`0E5a801@L303i0>`0R91l04aD@00<051HA00l04aD@018D
3`0C5A004A<>01@F4@0P8Qd06AhJ018G4`0D6AD05Q/G01<H500B5a<05AXF01HK5`001@400P0J7a/0
3`0A5Q805ATJ018F5`0A5AH04aLH01@H6@0C5aP06QhO02<W:00P92D05QXK018F5`0I7Ah051XH01XP
7P0201PN700M01XP7P0H7Q`041HD014G5@0D6QP06R0N01TO7@0F71X09Rl/010I5P0>5a@05AhK01HO
700G81d0624N01TR7`0K92407RLT024Z9`0R:bP072LS01/V8P0J9B406bLS01`X9P0K9bD072XZ01`/
:`0M;B`00P0N;Rh01@0O;bl09CLj02Pj?P24UYX08cDi00807c4e00H07S0d020b=P0W>Cd0;T1402Pj
?P0P=3D202<i=`0702Hl>`0Y?Sl0:Sm002i3A@0aATT0<TM:0397B`020397C00303A9B`0fBd`0>Di?
0080?E9C00<0>Di?03Q=CP0gC4d00P0dBDX01P0gC4d0>4e>03eBE00nDeH0>4e@0356B@80;D950380
<dQ;03E:C@0`ADP0=4U<03Q=D00hCe40?EIK03]DF@0mEU/0?5EJ03QAEP0jDeP0>55F03YCF00nEe`0
=e1E03UBE`0mEUX0WkNg05E^J`0mEU<0>E9?03A=BP0gD4d0=4a<03I>CP0jDU80?EEE03iFEP0nEUD0
?U9@03iCCP0jCdP0<TM003A9@P12Edh0A5U@02e2>@0oEDT0AUa@03=9?@0iDD@0?UE;03mHD@13G5H0
A5eJ04EMG014G5`0@5QH04ENG080BF9N00X0B69J04QRE`13FU00@eY?045HCP13FU00AeiE04YQF@18
GeL0BF1I0P19H5X06`18GeX0AeiH04EJD@2EZil0CVAH03mEB@1<HUD0;48e03I<?`0nE4H0BF1@04QO
C`0nED@0?eI603I<@01=HUT0=T]203]@A`0bAd00>e1904=HD@0dBD@0?E9=049GDP0dB4H0CV=N03Y?
A`02059WGP0304IKDP0nDdX0=4U00080>Tm600/0>Di503M<@`0jCdH0?55803]>B00_@S`0;T4k03a?
B@0eAT00>DY40311>`0202Lf<@0G02Pg<P0]>CD0<Shj03I5?P0eA3d0<3lh02@c;00U=2d0;C`e0391
>P0N;BH062LP02ln=`0Y>3409SD[02@b9@0Q;R@0934W02Ld:P0V<bX08BhU01h[8P0P;BH00P0R;bP0
:@0R;RX09C0/02D^:`0P:BH07BHS01lX9@0P:BH08BXW01hW900L9B8082TV02D^:`0R:bP07bHV02<X
:`0U:b/08BLW020V9P0P9R@07bDS01`R800N920082HR01/Q7@0F71L06AdN01/O8P0J7Ql05ATJ01@H
6@0I7A`092PW01HJ6@0E6QH06AhJ01<H500L8A/0;Bl/01/M6P0H6QL05aTF008061XG01l05QPE01dO
700J71T04A<@01@F4`0I6aP05aLE018B400J6QP05QHD00d=2`0J6QP05ADC01LG5@0N7Q`06ATG00h>
300@40h05aLE00l?3@0P81h09BDS01HF500C4a403`l=018B400G5aD0410>01<C4@0?3`d03`d>0080
4a4B0P0@3Pl0300D4Q<04Q0A00`;2`0;2@X0518C01HD5@0>30d03@/<01@B4`0O7Ah07A/L018@4@80
3`d>01L04@l@010>3`0>30d03`d>014?400<2Pd04a4D01/I700@3Q400P0300@21@0>30l040hA014?
4P0>30l0518E01hL7`0Q7b803P`?00`:3@0:20/05A<F010>4@0200`:3@0R018@4`0@3Q402@L:00X8
2`0=2``040h?00d;300@3Pl07Q`M00h<3@0@3Pl02`T:00`:2`0;2@X04Q0A010=3P0<20T02`L800l;
300;1`P030P9018>3`0<20T02PH700l;30091@H05A4B038^;P0=2@P02`L600h:2@0B3Pd02`L6014=
30D03PX91P0?2`X00`0>2PT03@T800d9200300h:2@0300h92@0=1`L03@L700<03@L700T04P`<00l9
2@0;1@D03@L700l92@0=1`L02P@400`61P0@2PX00P0?2@T02P0D3Ph02P@4014;2`0=1`L04@/;00h8
200=1`L04@/;00`61P0B30`200T30`03018<300=1`L03@L700@03@L701P0208400/51`0<1PP0618D
028L7P0C3@l050h@010:300=1`T02`D700X41P0<1PP040H701<92P0900002`4200L0000J41405P`=
00d3100A1`P05P`=00/10P0O5AHDooooo`006oooool400`@4@0D00lC500@51D010P900lC50093@h0
3Q8C00`@4@0A5AH020`=00L;300:3Pl02`l@00`@4@0A5AH051PI05eQHP0N8R<0310A01DI6P0830d3
00/?3P0300X>3@0@51<05ATH00802Ph=00@02`l>014E500>4Q401@T80P0C5A801@0?4@h0418?014C
400>40d03a4>00803@l<00<03a4>00h@3@0=3``00`0=3`h02`0?4A004A<@018D4@0=3``03@l:01dO
6P0[;BP0i^WR08b?RP0I6aP030h;00803a4>00l0418?00h@3@0@4Pl0418?00lA3P0>40d03@l<01DG
4`0F61<051HA018D3`16B4<0VifH061RG@0A4`h00P0=3`X200h@2`0F018F400>5@h020d700lA300D
5A003@h900l?2`0E5Q4051D@010B3@062`D020d701`O6P0K7AP03@l:018D3`0:30L03a4<00h@2`0=
3`X03Q0;018D3`8051HA00<03a0;00h?2P0=3PT00P0?40/00`0>3`X03a0;00l@2`02010A300;00l@
2`0>3`X03`h<01DD4P0?3P`01`H400/:200;2PH030/6010?2P0B4@`00P0>3PH05@0D5@d03Q4:0044
000?4P/06A`E014D3@0D5a0030l800hA2P0?4P/03Q4:00d@2@0;3PL00P<001DF40092P@030d7010A
2`0A4P`0414;00l@2P0400h?2@0O02@V8@041@<05ALD02`^:`1GFED02@/6010C300?4P/02Pd60044
000?4PT07R4J01@F4@082PD02P`700`>2@0C5A003@l:010B3@0?4@`0418=014C3P0?4@`03Pl:024N
7@0:1PD09R8Q00h<2P0D4`l030/700l?2@0200h?2@0:00h?1`0=40L03A0701PI500L7AP061TD00X;
1P0>3`X06AXE010A30803a0;00H04A8=01@E400E5Q403@l<00h@3@0?4@h2014C4009018D4@0E5a@0
1@L4010B3`0R9240WZ2M07]mN@0G6A@02`d800803Q0;00H0418=00h@2`072@@051HA01TK5P0>40/2
010B3@0B00lA300<3PT02`d800d?2P0@4Pd04aD@014C3P0<3PT01PP300X<1`0A4`h04aD@00lA300@
4Pd04A<>010B3@0?4@`03Q0;0P0=3`X02@0>40/0418=01@F4@0>4@X04aH?018E3P0@4``05aXC01<F
3`0200lB2`<041<<00T03a8;01<E400B50l04aD@01@F4@0B50l03Q0;01LI500E5a800P0D5Q400`0C
5A004A<>014C3P05014C3P0907IhL`0k?CP061XE01@F4@0=3`X0828M03do>P0R91l04aD@00<051HA
01<05QPC01LI500G6A@051HA01LI500U9b80724M01HK5`0C61@04AHB018G4`0J7a/051TE01HK5`0>
4`l04aPD01PM6@0;40`05QXI00804aLH00@051PI01DI6P0D61T04QHG0P0M8B805@0D61T04QHG01`P
8@0D6QP06b4O01XP7P0H7Q`05Q`J01<I5`0B61H05adK01TO7@0L8R006AlM01<I5`0K92403aPE01DN
6`0M9R<05b0M018K600301PQ7P<06B8O00L06bHR01TT800H8al07RXV01l[:@0K9bD07B/[00806RXY
00P06b/[01d];@0O;bl062X^04IHG01NL7@09CLk02/m@@808C<g00/08cDi02do@`0fB4`0;T14028f
=`0S>CL09C/i02To?P0/@D80;T=402m4AP0202m4A`060315B@0aAT/0<DI;03=8B`0eBT/0=T]<0P0i
CTl03P0fBd`0=4U:03=8B@0bAdP0=T]<03]@D@0lDE80?E9D03]@D`0gC4l0<dQ;0356B@0bAdX0<dQ;
0P0bAdX04`0fBdh0>DiA03aBE@0lE5P0>E9G03]DF@0jDeP0=e1E03YCF00`BDh0?5EJ05=/L@1<IFX0
?eQM039;CP12FeP0<T]703I?B`0bBdP00P0iDTl02@0fCTh0>51@03]CD`0mEED0?UIH03eEEP10E580
?eA?03mDC@0203]@B@0K04MLE039g]D0LhQo0357>`0jD4@0?E=703]CAP0lDd/0?UQ@04=LEP14GEX0
A5aK04=KF`0oEeL0A5eK045JEP0jDdl0=Dm703I@A@15G580@UY>045HCP12FDl0AeiE04]RFP16GED0
B5mH0080BF1J00l0BEmK04QOF@0mDTT0H7IZ045GB`12F4`0@EM;0316>@0gCD00>U12049IB@10EdL0
?UE404]RDP14FTd00P0eBT403@14FE00>Di704EJD`19GUL0AU]F03mDC`15FUD0KX:00397@P0mDTX0
AEYA0356?@0lDDP00P0hCD@203]@A`0A03Y?AP0hCD@0>Di503Y?AP0kCTP0<dI003M:A017FU@0;Sli
0311>`0_@3X09cHa02He<00W=S40;CTe03<o>`0_?SL00P0]?3D03P0R<BX093</02hm=P0Z>C8062LP
010O600S<R/09cH_02Th;P0T<RD072TO01dZ800U<RP09C8Y0P0N:b80200T<BX09S</024^9`0O:bL0
8bhZ02</:@0O:2D072DR0P0M9R<0200Q:RL07bPU01`U8P0R:bP09c0]02@]:P0N9BD07R<V0`0O9BD0
@P0N928082HT01/Q7`0N92008RPT01hT800I81X05a/L01PL7`0H71d05QXK01DI6P0H71/06alN01<G
5P0H7AT07b@P01PM6@0A5Q002P`901<E4P0O8Ah04A<@01DG500I6aP05aTF01TK600E5a@03a4>01<E
4P0I6aP05ADC018B400I6AL06a/I01HF500H61H05ADC01@D4P0F5Q@05ADC01<C4@0I6AL071`J010@
3P0D51805QHD018B400E5A<02@T701dM6`0@40h020P600`<2P0>3P`040h?018@4@0A3a0040h?014?
400B41405aDF01@B4`0H5QL020H701@B4`<040h?00L04Q0A014?400>30d04a4B00d;300@3Pl04@l@
00803`d>00P040h?018@4`0>30l04Q0C00h<3`0C4A@07adP010>4@803`d@01@02`T<00`:3@0C4A@0
8AlR00`:3@0C4A@02`T<01XH6`0610L02PP;00d;3P0C4A@03P`?00T72P0>30l02PP9010>3`0=2``0
5A<D02l];P806ALH00/03@/<00P61`0<2P/0518C00l<3@0;1`P030P9018>3`0<20T02`L801<?4002
00X61`04018>3`091@H06ADF051<C0804Ph=00@05a<B00d9200;1`H0510?1@0>2PT600l;2P0300h:
2@0=2@P03@T800803PX900<03`/:00h92@0=1`L01@0=1`L05`0>20P03`T900h8200=1`L030H600T3
0`0=1`L04@/;00d71`0<1PH04P`<00X4100@2PX030H6018<300?2@T03PP800l92@070@403@L700h8
200B30`03`T900H03@L701P03PP:00/51`0:10H04`d?01LA4`0:10H03PP:00d72@0>20X02`D700X4
1P0A2`d01`0000d3100;0@80:AlP00d4100>10D040H700h41@0D2P/04PP901@:2`1:@44Dooooo`00
6oooool05@0>4Q<03A4B00`@4@0<41403Q8C00lC500<41403A4B01TM7P0<41402`l@00dA4P0@51D0
310A00lC500=4A80310A01LK700Z;Rl0EUYK01dQ8P0200lC500400`@4@0A5A@03A4@00X>3@802`l>
00X02Ph=00dA400>4Q402`l>00dA400?4a803A4@01DG500D5Q<03a4>0P0>40d02`0;3@X03Q0=010B
3`0@4Pl03@l<00h@3@0@4Pl0418A00lA400>40l03@l>00<03Q0=0P0D5Q400`0C5A00<SD_038d;`02
00`>2`03018D4@0;3@X03Q0=00H03a4>00<030h:01@F4@0620@00P0:30L06P0X:RD07b4L010B3@0>
40/030h900lA300@4Pd041@>00lD3P0>40/0418=014C3P0?4@`03@l:00`>2@0>40/04A<>00d@2`0?
50h08BDO01LI500@4Pd030h900lA300C5A00418=0P0?4@`0100B50l051HA01<E400A4Pd200l@2`03
014B3@0B4`h03a0;00<04A8=01D0414<00l@2`0>3`X061PF028R800K6aT02PX800d=2`0@4@`04a@>
014B300?40X04149014B2P0@4@T03a4=03m2>`0[;RL05APA00hA2`0:3@H00P0?4P/05@0>4@X03A09
00d@2@0=40T05AH@00h?2`0B4`d06Q/E00l@2P0A4P`03Pl9010A2`0A4P`0414;00h?2@0;30H04A<>
00`>2P0E5a801PP401@F4P02010B3@0;01TK5@0D5a005aXC00lB2`0C5Pl020X7010B3@0;3@P04Q@?
00h@2`0E5a800P0?4@`03P0C5A005ALB00lA300<3@P050l?010:2P0;1`L05a<B00T50P0H5a<03Pd8
00h?2@0?40X04A8:0P0A50/0200A4Pd030d8014B3@0A4Pd0<c@_05YKEP0@4@`04A8=100B4`h3010B
3`0G00lA3P0=3``030h;00`>2`0E5a@0418?00/=2P0V:2D0828N00lA300=3`X04A<>00h@2`0H6QD0
;S0[01HH4`0=3`X051HA00`>2@0@4Pd04aD@014C3P0@4Pd00`0?4@`01`0@4Pd03Q0;00lA300C5A00
3a4<018D3`0D5Q401@0?4@`02@0C5A0051HA018D3`0@4Pd03@l:00`>2@0O8Q/0:2/T010C3@02010C
300801<F3`0A50d04A@=014D3@0@4``03Q4:00d@2@0?4@`2010B3@803a4<00<0418=014C3P0A4`h0
0P0@4Pd2018D3`H04A<>00H0828M01HH4`0B50l04Q@?01dO6P0Y:bH201DJ500<01LL5P0D6A<03a@>
018G4@0=4P`04aPB01TN600D6A<04AH@01XO6@0H7AT04QLC0P0C61@01P0@5A404QLC01PM6@0L8Ad0
EeaH01<H50804QLC00P061`K01DI600E6AP05QXI01LK6P0F6QT04ADD01@H5`805QXI01005a/J01PL
6`0B61H05adK01DK6@0F71X06R0N01TO7@0H7Q`06b4O01LM6`0H7Q`06b4O01PN700E7Q/051dJ0P0I
8Ql01@0E7Q/05b0M01LP7@0G81d0624N00<06B8O00L08B`X02D_;P0N:2L072PV01l[:`0N:RX072XZ
00806b/[00T072`/01d];@0M;2h07Blc02Dg>`0O<CD09SPl01PZ;P0T=SX00P0V>3`01`0X>Sh0;d55
02do@`0W>c`0:3hl02Y0?P0/@T400P0^@d@0200_A4H0;dA70315B00bAd/0=4U>03E:C`0hCE00>Di?
0`0fBd`03@0eBT/0<dQ903=8B@0cB4T0=da=03Y?D00iCTl0>Di@03Y?DP0hCE00=T]>03=8B`0bAdX0
0P0`ADP01P0dBD`0=DY=03M<C`0lDU@0>51D03I?D`80>55E02P0=DiB03YCE`0fCe<0>55E04ENHP13
G600?EIJ03MAD`0lEE00?UQ@03mHDP0oF5@0>E9>03I?C00jDU80>e=C03iFF00nEUT0?EEI03aDE`12
EU@0?eA?041ED00oE4l0>Di803iCC00oE4`0=4U003U>A@0iCd<0?UA803aCB00nEDd0@5YB04ENF017
H5d0AemN04ALG017Gel0B61O0P19HUh01`17HET0AEmD049IC`14Fe00AEaB04IMD`18GeH00P18GeL0
2019H5T0B5mI04QOF@17GET0AEaF04UNE`0oE4/0?E990P13FDd06@12F4`0?E=603]AA010ETT0>e92
03YA@@1>IEH0DfUM02m4>`0iCTD0>Tm603Y?B00hCDH0>Tm8049GDP0lDD`0GG9]09FYY`1=HUd0>Di8
03iCC00gC4D0HGI_03I;A00oE4d00P0nDd`01@0lDDX0>4e603M<A@0hCDH0?U5;0080=4M10140A5MA
0311>`0oD4X0<D8l028a;00T<bh0;3/f02hj=P0]>CD0:STb02@c;00Z>C8093</02Dd;@0[>S<07bhW
020_:002024`:@0@02Dd;@0O;RD07R/Q01h[8@0P;B<082dT01l/8`0P;BD08BhW01l/9@0R;bT08bl[
024]:@0S;BX08b`Y01lX9@807BHS00<072DR01/T8@0K92400P0K9240;`0L9B806b@Q01`S8`0O92L0
8bTY024W9`0K8B4082HT02`b<00S:BL0728N01hT800L8Qh06b4L01`P8@0J7R406QhO01`P8@0K7b00
5a/J01DI600H71/06AhJ01PM6@0I7QX061dG01dO700J71T07AlL018D4@0G6AH06Q`I01TK600D5Q<0
5QPE01/M6P0H6QL05QPE01@D4P0L71X05QHD01DE4`0I6AL04Q8@01PH5P0F5Q@05ADC008051@B00<0
5aLE01<C4@0D51800P0@40h02`0E5A<05aLE01/K6@0o?cd05QHD01<C4@0D51805QHD01@B4`0B4140
4@l@0080518C00P04@l@00d;300C4A8071XK06m]KP1YIfP05A<D01@B4`804Q0A03<03`d>00`:2`0A
3a003@/<01<A4P0F51D04a4B010>3`0?3@h0518E00l=400@3Q403`d@01TG6P0X9RT040hA00d;3P0@
3Q403P`?00`:3@0>30l06QPK00`:3@0G5AP03@/>00l=400<2Pd03@/>00/9300>30l030X=01PF6@0/
:Rd06ALH010>3`0C4A802`T:01hL7@0>30d03`d>018@4@0<2P/03P`=018@4@0>2``03@T:00l;300H
51D03`/<00d92P0B3Pl00`0?2``02@0:1PL03PX;01LC4`0D4A00Ee=B010<2`0;1`H08AdL00l;2`0;
00h:2@0400d9200;1`H02`L600`81`803@T800<03@P800d71`0=1`L00`0=1`L01`080P803`T901PB
4P0C3@d03@L700`61P0=1`L00P0<1PH03`0>20P03`T900l92@0N61P07aTI010:2P0?2@T030H600/5
1@0=1`L030H6010:2P070P804@/;02TS8`0600d71`0H014;3@0>20X040X<00h82P080P@03PT:010:
300<1PP040X<014;3@0>20X04P`>01D:3P0D2@d03`H804Tn@P0I3Q803`@800`31@0?10P030850187
2`0E2Ph09a`P5?ooool001_ooooo00@020`=00`@4@0=4A80310A0P0:3Pl01`0@51D020`=00`@4@0D
61T02@d>01@H6@0=4A800P0?4a@0300=4A803Q8C00lC500N8R<0:Bd^00@82@0A5AH01`/<00dA4P08
30/04QHE01DI608020`;02005ATH01lS8P0Q9B@01PX9014E50072`X03A4@00h@3@0@4Pl03Q0=00/=
2P0A4a005aTF00`>2`072@H04A<@00`>2`0A4a005ALD01<E500H6QT02`d<00h@3`0A4a0010H300T;
200B50l04aD@00h@2`0<3`P0418=01PJ5`803a4>00<01`T601HH5@0<3P/01@0=3``0100<3PX03Q0;
00h@2`0;3@P200h@2`0K00d?2P0B50l03@l:01DG4P0h>SD0<C<^01<E400=3`X05aTD014C3P000@00
<SLa01/P6P0:3`T030h9018D3`0:30L02`d801<E400?4@`0418=00h@2`0<3PT04aD@00`>2@0=3`X0
3Q0;00<03a4<0P0B4`h02`0@4@`03Pl:00d>2@0=3PT02``701<D3`1ADTd06Q/F00L80`0D5A002`/9
00803Ph<00H04A4?00H6100B4`h03@h800l@2P0@4@/200h?1`0I00`=1@0E61403Q4:01/N5`0R9Ah0
3a8;01<F3`0>4@X02`h700X=1P0<3`P03A0900/>1`0<3@L04A8<018C3@0>3`T02``600`=1`0H6A<0
3Pl900/<1P092P@04A8<00<4000200d@2@803Q4:02003a8<00lA300;3@P05QPC00h@2`0620<03a4<
018D3`0<3PT04A<>00/=20072@@030h900lA300>40/02@/600/=200N81/04A<>00H70P0A40h06QHE
014@3P0@3`d02PT501PG4`0=3@P03@h801@E3`0C50`03a0801<D30803@h900L03a0;02<T7`0J6aH0
1PL2018C3P0=3PT03Pl:00804a@?00@0414<00d?300@4Pl03a4>0P0;3@X0400=3``051HC010B3`0B
51405ALD00L91P0F61@03@l:00L9100?4@`03@l:00lA300I6aH05aTD01<E400?4@`200d?2P0A010B
3@041P403Q0;018D3`0;3@P05QPC00d?2P0D5Q403@l:01<E400D5Q401`T4010B3@0C5A004Q@?00d?
2P0@4Pd00P0?4@`01P2BU8l07AlJ01DG4P0B50l03Q0;00hA2P804A@=00d03Q4:010C300J7AH06ahG
00d@2@0A50d05APA02@W800?4P/051HA018D3`0@4Pd04A<>00804aD@00<061XE01HH4`0B50l00P0?
4@`09`0@4Pd03a4<01DG4P0H6QD02@/6018D3`0G6A@07R0K01dO6P0?4@`04Q@?01@F4@0H6QD04QLA
020W8012BD809B`U01<J4`0P9b0061lH00lF3`0E71D051/D00lF3`0G7QL04aPD010E4@0D6AD0J6eY
01@I5@0?51005AXF01HK5`0@5A403a@@01<H500A5Q804aLF01@H5`0201DI60805a/J00d05ATH01dQ
800H71/04QHE01@H5`0F6QT06b4O01PN700P9R@04QPF01HL6P0G7A/06R0N00805adK0P0J81h00`0I
7ad05R0L01DP700401HQ7@0701TT800R;BT062<O01HQ7@0L9b<051lK02<];002020Z:@0601l[:`0V
<S807RXZ020^;`0R<S808C4a0P0N;C000`0Q<3<06R``01h`=00201la=@04020b=P0R=3P0838f020b
=P809CLk01@09cTm02/o@00U>cT0:T0n02Y0?`0Z?d00<TM802i3A@0^@dH0<dQ;03=8C00aAT/0<TM<
03E:CP0`ADP0;dA70397BP0aATT0=T]>03mDE`80>4e@00D0?eAG03U>D@0fBdh0>TmB03Q=D00203U>
D@1D0315B00eBTd0>DiA02Pm@00bAdX0?eAG0397BP0iCU40=4a>03=;C@0hD580>e=E03UAD`0kDeD0
@EUK049JG013Fed0@EUK041HFP11FEX0>55;03aFC@0nEe40>U=?03eFDP0oF5D0>E5A041HF013Fed0
BF5U03E=D@17Gf80AEUH03a@CP10E580AU]F03mDC`0mDT`0?55:03I;A00gC4<0?E9903iCBP10Edd0
@UUA045JD`12FeD0A5eJ04MPGP19HF40B61P04MOGP15GUX0@eaH049KE010FTl0@UU?04QPE011F4h0
AEaB04AKDP15G5@0NY6905ieKP18GeT0BF1J04QOFP10Ee40AEYC045FCP14FE00AeaC04AJC`14FTh0
>e55049HC00^A3L0>e5403aBA@0nE4L0=de103U>A@0kD4L0?E990P0nDd`05P0oE4d0?U=>03]@B`0h
CDP0?E5?049GDP0lDD/0?E9;03aABP12Ee00A5UB041ECP0nDd`0<TM003aABP0oE4d0<dQ103eBB`0f
BD<0?U5;0395?`0mD4X203U:A00:02/l=P0O;RT08c8]0350>`0a?CT0:SHb02He;P0U=2d0:STb02Dd
;@<093</00h08c8[01d/9@0W=Rl0:STb02Pf;P0X=B`09C8Y028_9P0P;B@07b`U02@a:P0P;BH07RXV
02<_;0807RXX00<08bd[020Y9P0L9B800P0K9240400I8Ql0624N01hW901QJVL0GVMT01PQ7P0O:2D0
61lO020U:00T:RX09R`/028X:00M8b408RPV024W9@0L8Qh201LM6@0601`R7@0K7b00:2`_04E9BP0P
92D0:bl`0P0A5A@03@0B5QD05AXF01LL600G71P05Q/E01/M6P0C5A807AlL01LI5P0B51405ALD01PJ
5`0F61D00`0D5Q<00`0A4a006a/I01<C4@0201DE4`0>00h>300F5Q@04Q8@00h>300K6aT05aLE01@D
4P0?3`d0410>01<C4@0D51804Q8@014A3`0C4a42014A3`804Q8@0P0C4a4601<A4P0601TG600@3Pl0
5aDF06m]KP1WIFH0518C1P0?3@h07P0;2@X03P`=010>3`0@3Pl03P`=00`:2`0H5QT09bDX03hl?`0Q
7b8040hA00T72P0;2@`04@lB01DC5P0>30l04Q0C00l=400C4A@030X=010>4@0?3A0020H901LE600=
2`h030X=01HD5`0C4A@02PP;00h<3`L03P`=00T02PP9010>3`0=2``040h?010=3P0:1PL03`/<014=
3P0:1PL00P0@30d500h:2`04010<300B3Pd04Ph=00l;2P8030P700L03`/:01HB4@0@30/01P81018>
3@0D40l03`/:00803@T800X030P700d9200=2@P030P700l;2P0<20L03PX900d9200810<03`X90P0?
2@T200`61P0400l92@0=1`L030H600d71`804@/;00l03PP800H0000B30`05a4A00d71`0<1PH03@L7
014;2`0I4a<02PD500/51@0A2`/03@L700h8200@2PX00P0>20P00`0S7Ad0Dde=00h8200200d71`0=
00`61P0=1`L03PP800/51`0E3a402`H700d72@0;1PL02P@600T31@0>20X02P@601LA4`0200l92`03
00h31`0H3A401`0000804PL;0P0=0PH01@0?10P05@X>01H;3`0?10P04`P<01Cooooo000Kooooo`0=
00T=3P0<41403A4B00`@4@0;3a003A4B00hB4`0S9bP020`=00T=3P0B5QL01PX;00`@4@0200hB4`80
310A00L03Q8C018F5`0J7Ql01PX;010D5@0;3a0041@E00804ADD00@00PH50496A@0f>ST000810P0N
8R4010072`X03Q8A00861@0:3Pd200X<2@0K00/=2P0G6AH0<38_03do?00M7a`030h;018D4@0?4@h0
418?00lA3P0N81l08bDT01PJ6@0L7Qd07R0M01<E4P0@4Pl02P`700P:1@0:30L04A@=01<E40010`00
3Q0=00lA3P0B5140418?00H03@l<00@03@l;00lA300?4@`030h90P0?4@`04P092`H04A<>01@F4@0<
3PT05aTD01TK5P0A4`h03@l:00T;1P0E5a80>3dg0<76`01]LV`05AXD00d?2P0A4`h02P`700H80`80
3a4<00d03@l:010B3@0?4@`03a4<00X<1`0<3PT03a4<014C3P0@4Pd03Q0;018C3P0A4Pd0414<00<0
3Pl:0P0:2`H06P0c=2l04Q<>00P9100D5A0051@B0000000F5Q@020P6014A3`0J6aH030d700h?2@0=
3PP030d5010A2@0A4PX04A@=00`?200B5@h05QTB00`?200>4@X04A@=00hA2P0<3`P03A090P0>4@X0
0`0?40X02``600/<1P02010A2`0700X;1@03100030d701DF400;30H03@h800h?2@0200`?20803A09
00`03Q4;00h@2`010`0030h900lA300H6QD01`T401PJ5@092`H03a4<00h@2`0<3PT300h@2`0700/=
200>40/04Q@?00/=200@4Pd0410>00/;2@02018B400U00/<1`0H6A@0414;00d>200?40X03a0800h?
1`0?40P03@h901LH4`092PD061TD01hO6P0O81/03a0;010A300?40/04A8=01@E400F5a803a4>018D
4@0A4a003Q0=00d?300?4@h00`D200`>2`0:30T05QPE01PJ5`0J71P071hI01@F4@0F61<03@l:00`>
2@02018D3`0:010B3@0>40/03@l:00h@2`0B50l02P`7010B3@0?4@`02@/600h@2`804A<>01404Q@?
00h@2`0?4@`061XE014C3P0C5A004Q@?00h@2`0@4Pd03a4<00H7100j?3L00`D001<E400c=C006adH
00`?200200lB2`0<00/>1`0<3`P051L@01XM5P0?4P/04aH?01TL5@0X:b@05QTB00lA300>40/03a4<
0P0A4`h0100>40/05aTD01DG4P0B50l200lA300Q014C3P0N81/02@/600P:1@0F61<061XE00T;1`01
0`002`d800lA300A4`h071hI01@G4P0F6aD0EeiG0?3gl01/Lf`06B0I018I4P0@5a0031<<01DL5@0F
7AH03QD>01<J4`0M8Qh061dI01/P701IGUX07B8N01TN6P0B5a<05AXF00804AHB00<05AXF01<H500D
61L0100D61L01@0C5aH061`K01lS8P0K7ah061`K00806QhM00L0728P018H5P083P`05A/I02P^;00=
4a406R0N008061hL00@06R0N01TO7@0F7a`05b4M0P0F8Ad301LR7P0?01TT800G8Qh051lK01TT800l
Ad<0:cHb024[:P0@6QT082XY02Da<@0I9BD06RHV01`Z:`0N;Rh07Bd]00806bX]00X07B`_01la=@0Q
<cL0838f024c=`0T=SX09CLk020b=P0R=3P09SPl0P0S=CT02P0Y?Ch08CLe02@j>00[@D00:d1102m4
A@0/@D<0;T=60356B@0bAd/203=8C@0H03A9C@0bAdX0<dQ;03Q=D00dBD`0=T]>03Y?DP0fBdh0=da?
03Q=D00dBD`0<dQ;03]@D`0eBTd0:d130397BP0gC4l0<DI902e2A@0oE5L0=4U<0315B00W?3l0>e1C
0P0dC4h01P0jDU@0?5AF03Q@DP0iDE<0>e=E03aDEP<0?UIH0240?eMH03aED@0nEe40>U==03YCC`0e
CTX0>eAA03UAD@0nEUH0?eMI04aTIP1;HfL0KXJ906MkNP1FJVP0?E5?03=8@`0dBD@0?E9=045FC`0o
E4d0?E9:041EC012Edh0?UE;045HD010FU80@EYD04=LF@16Ged0B61P049JFP13FeX00P14GET06`13
G5D0@UaA049IC`13Fdl0B5mE04ELDP16GE@0CFAL05E/I019H5T0@UUC04ELEP19H5/0B5mI04=HD`0l
DDT0?U=:041EC00oE4/0@5I:055WF`0jD4@0@EM:04ILC`0eBch0@EM:03]AA@0203]@A`0T03eBB@0m
DT/0?U=<045FC`0oE4l0?E9=03]@B`0nDU00@5AB03mDCP0mDT/0>Di703Y?B00iCTL0=4U203]@B@12
Ee00>Tm80356?`0lDDX0=4U203I9@`0eB480<TDo03I9@`0^?cT0<d@n02Tj=00L:bH07RdX02dl=`0c
?c/0;c/g02Lf;`0V=Bh0:STb0P0U=2d05P0X=c00:CPa02Pg<00V=Bh0:STb02/j<`0Y=bl09S<Z02<`
9`0P;B@07b`S01l/9@0Q;RL082dV020/:00S;b`082`Z01l[:@0O:RL07RLT01`U8P0J8b0201/T8@09
01lX9@0R:bP0CEIC051IEP0R:bP0:34^01lV9P0M8RD07bDU00808BLW01H08BLU020V900P9R@07B<O
01PN6P0G7AT06b4L01PL7@0I7B007B4R01LK700N8R<05QXI018F5@0D61L05a`H01XO6`0L8Ad07B8L
01`N6`0C5A806A/H0`0E5a@04`0D5Q<04aDB01<E4P0E5a@05QPE01DG500H61H04a<A01PH5P0I6AL0
4A4?01@D4P0H61H04a<A01@D4P0?3`d05ADC00h>300E5A<00P0B4Q000`0D51805ADC018B4002014A
3`804Q8@0P0C4a46018@4@0600/92P0D4Q<00@0001DC500I5aP04Q0A1P0@3Pl07P0>30d040h?014?
400@3Pl03@/<00`:2`0N71l05Q@G01TG6P0@3Q406QPK01@B5@0B41<02PP;00H41`0F51L040hA0040
0P0:20/04a4D00h<3`0;2@`04@lB00l=400@3Q403P`?01PF6@0E4aH03@/>010>4@L03@/<00/02`T:
00d;300;2@X03`d>014>3`0;1`P030P900h:2`0<20T040`=00d92P0500h:2`0500`8200<20L03PX9
00h:2@0=2@P00P0?2`X01P060P403@T801TE500B3Pd03`/:00`81`803@T800X030P700d9200=2@P0
3`/:01DA400A3@`040`;00`81`070`803@P80P0?2@T200`61P0400l92@0>20P03`T9010:2P803@L7
00@04@/;00l92@0G4A40618B0P0?2@T0100@2PX02P@400X410080P8201@>3P0800L20P090`<02`D5
00X4100600002`D501TC4`0>20P200d71`0<00`61P0=1`L03PP800d72@05004040/<01/E5`0<1PP0
71HH01XD5P0<1PP03PP:0P0400002@0I4aD03`@801D:3P0;00@03@8601462P0G31001`0001872`02
00L0000301872`07003ooooo01?ooooo000Kooooo`0?00`@4@0=4A803A4B00`@4@0?4a@04QHG014E
5P0S9bP03A4B00/?400?4a@02Ph?00/?400>4Q<03A4B0080310A03003A4B010D5@0;3a003Q8C00/?
400<41403A4B00dA40093@`02Ph=06Q/J`1MHF005ATH00hB4@0?4a802Ph=010D4`093@`05QXI010B
3`0>40d030h;010B3`0L7Q/092HS01dO70092`P03Q0=018D4@0F61D0418?00d?3P0A4a8030h=010B
4@0C5A8030h;00lA3P0<3PT03@l:010B3@0@4``04Q@?00d?300:30T030h;020R7`082PL600h@3@04
00h@300A4`h04A<>00h@2`804A<>01h03a4<010B3@0?4@`03Q0;00d?2P0?4@`03a0;01@D400@4@`0
51HA028W8@2NY9d0CeI?00hE3P042@<04A<>01LH4`0D510051D@00d?2P0<3PT04Q@?014C3P0<3PT0
2P`700d?2P0@4Pd04Q@?010B3@0=3`X2010A300600l@2`0>3`X03a0;010A300C50l030d80P0>3`X0
300=3PT03a0;018D4@092`P0CDm<00d?300>40d051HA010C300C5Pl03a8;00`?1P804A@;00X03A09
00lB2`0=40T02Pd600hA2P0<3`P05QTB010C300=40T03Q4:0P0@4``03@0>3`T0414;00h?2@0;30H0
3@h8018C3@0S91h03@h8018C3@0?40X03Pl900l@2P0<3`H00P0=40L300d@2@0?01@F4@0?4@d07R0M
00X;2@0@4Pl03@l<00lA300<3PT03a4<010B3@0?4@`04Q@?00h@2`0:30L03Q0;00804Q@?00d04QD@
01@J5P0D6aH03A@?00X>2P0?50h03a8=014D3@0?40X030d7018C2`0E5@d03`l700804A8=00<01PL2
01`M60061`800P0@4@`02@0A4Pd0414<00h?2P0D5A006AXE00h@3@0@4Pl03a4>00h@3@0200d?300<
00lA3P0;3@/04aDB00T;200C5A803a4=00h@2`0<3PT04Q@?00h@2`0?4@`0418=0P0=3`X300h@2`06
010B3@0>40/03a4<018D3`0H6QD05aTD0P0;3@P0100D5Q403a4<00/=200D5Q42018D3`0T014C3P0?
4@`03a4<00lA300A4`h01@L2014C3P0@4Pd092HQ010B3@0@4``04QD>01DH4@0B5@h041<<01<F3`0D
5a003a8;00hA2P0A50d06QdF00lB2`0@4Pd03a4<018D3`0E5a8051HA00lA300D5Q404aD@018D3`0A
4`h04Q@?01<E400=3`X04aD@0P0D5Q403P0E5a805QPC02<U80092PL08R@O020R7@0A4`h051LB00hD
3P12BD80VJ2I04U@B@0P9b002a8;0P0@5a00400K8Q/072<L01@K500D6a@04QLC00`A3@0@5A4082DQ
01<H500>4`l03a@@01@I5@0C61@051TE01LL600D6AD201DJ5P8051TE00h04aPD018G4`0D6AD05a`H
01DJ5P0G71P06b0L01LL600A5aD07bDS05ILFP0R:2H06b4O01dS8@806AlM00@06b4O01`R800I7ad0
51dJ0P0G8Qh01@0H8al06B@P01XU8@0J9B4072LS008062<O00X07BPT05YUH@1LIf<09c4b01dW:01:
E5D0BeMG01/V:00M:2X07R`]0P0M;2l05@0L:bh07B`a01h]<P0Q<cL0838f01la=@0P<SH09CLk02Tk
?`0X>Sh0:Sa002m1A@0/?T80:ce10355AP0S>CL09C/i03E:BP0_A4D0<4E602i3A@0202e2A@0=0397
B`0fBe00=T]@03A9C@0eBTd0>DiA03aAE00gC4l0=DY=03Q=D00jCe80>DiA03Y?DP02041EF00403Y?
DP0mDUD0?U=F03I;CP80=DY=00D0<dQ;03E:C@0dBD`0=4U<03]@D`0303Q=D080?E9E04/0>TmB03eB
E@0nDeH0?eAG045FF@13F5/0A5UL04=HFP0gD4`0@5UE03iGE017H5d0<da903aEDP0jDU80AEeM04IN
GP12FUX0?5AE045IFP11EE@0A5QF049FE013EeD0B5aJ041ED00hCDP0A5UC04=HD@0mDT/0A5UA03mF
C012FE40@EYC049KE@13G5T0AUiM04MOG`16GUh0B65O04YSG`18HEd0AEiG045KD019H5H0@e]?04YQ
E`0lDdT0BF1G041GC`17GUH0B5mH04UPFP1:HE/0B5mJ04ELE`10EE00@eQA04MLE@13F540?U=;04=H
C`0fC400?UA803]AA@0`AST0@eU<03eCAP10ETX0?U=:03eBB@0nDdX0@5E>045FC`15FU<00`12Ee80
2P0oDe40?51>03aAC00lDD`0>Tm:03iCCP10EE00?55<04MLE`13F5<203aAC080?E9=00l0?U5;03I9
@`0gBT@0<D@n02m0>P0Y>S@08S<]02<b;@0Y>3<0<T4l038n>P0]>CD09SD^02Lf;`0/>c@00P0]?3D0
2P0Z>C808C0Y024`:@0W=Rl08S4Z024`:@0V=2`09C8Y02@a:00S<2P2028_:00@020/9`0R;RX0930^
028^;00U<Bl0930^01dX9@0L9B807BHS01/T8@0J8b0072DR01hW900H8Ah06R<P02</:@806b@Q00<0
82LW020U:00N92@00P0M8b<06P0P9R@0728P01dS8@0L8Qh06AlK01LM6@0I81X06alP01XN8@0I7Ah0
61`M014E5P0S9bH07b<R01hR8@0J7a/05Q/G01@I5@0C61807AlL01XL6@0K7AX051HC01PJ5`0D5Q<0
5ALD0P0D5Q<00`0F61D05aTF01HH5@0201@D4P0301`L6P0M7A/05ADC008051@B00/04Q8@01/K6@0G
5aD06ATG014A3`0J6QP04Q8@010@3P0E5A<05aLE01<C4@03014A3`<04Q8@1P0B41401P0?3@h04Q0A
01@B4`0?3@h040h?00l=3PH04@l@01h040h?014?400@3Pl040h?00l=3P0>30d03P`?014?4P0@3Q40
4Q0C01HD5`091`X03`d@01<A500@3Q402PP;02@R9@1VI6L09R@W00T72P0C4A@030X=01<A500;2@`0
30X=00X82`0@3Q403`d@00X82`0<2Pd800`:2`0:00/92P0?3@h03`d>014>3`0?2``04@d>00d92P0A
3@h05A4B00`82@D03PX;00d03`/;014=300B3Pd040`;00h:2@0?2`X04Ph=01hJ6@0`;2/03P/:018?
3P0c;bh08QhM00803@T800H030P700d9200=2@P030P7014=300?2`X200h:2@0400/71P0?2PT03PP8
00l92@803@L701H040X:00h8200?2@T03`T900/51@0:10@03`T900/51@0>20P03`T900`61P0=1`L0
3PP800`61P0;1@D040X:00l92@0<1PH03`T900h8200=1`L03`T90P0B30`05`0<1PH03PP800d71`0=
1`L030H600d71`0>20P040X<05MAD`0H4a@03`X;01TC5@0=20T030H8014<3@0910D01`83014<3@0B
3@h060dC00h42@0J3aD04@H<00803P<900H04@H<00d4200K41H0200301D<400Q5Q`Dooooo`006ooo
ool03`0<41403Q8C00dA4P0<414041@E01@H6@0B5QL02@d>00lC500F6Q/01`/<01DI6P0=4A803a<D
00hB4`0200dA4P0D00lC500O8b@041@E01@H6@093@h02`l@00lC500B5QD01PX901DI600>4Q403a<B
00861@0B5QD03a<B010D4`0=4A001PX900hB4@0?4@h2018D4@0I00lA3P0;3@X02`d:00/=2P0:30T0
418?00lA3P0E5a@04Q@A00`>3@0>40l03a4@014C4P0C5A804A<@010B3`0C5A00418=00`>2@0F6A80
7R4L05QJE`0>40d03a4>020R7`02010B3`D03Q0=00@03Q0<014C3P0A4`h03Q0;0P0A4`h05`0@4Pd0
20X500<5000@4Pd04aD@010B3@0?40/040l;018C3P0>40/000<000`C300@6Q803QD>00`A2`0A50h0
4A8=00l>2P0=3PT02`d800lA300@4Pd03@l:00<03a4<00@03Q0;00d?2P0=3`X03a4<0P0?40/200h?
2P0R00l@2`0@4@`05AHA01@E400;30L05QLB014B3@0;30L04aDB00T;200C5A801`T6014C400=3`X0
4A@=01TL5@0G6Q<04QD<01HI400?4PT02`h701<F3`0A50d03Q4:01DH4@0<3`P04aH?00lB2`0<3`P0
3A0900lB2`0>4@X03a0:014B3080414;00X04Q<=01DF4013A3h0414;00X;1@0@4@/04Q<=00`=1`0?
4PT03a880P0?4PT0:@0?4PX03a8;00/=20092`T061XG00430P0C5A@061XG00`>2@0:30L05aTD01HH
4`092`H03@l:00T;1P0K7AP02`d800h@2`0J71L00@H0010M5`001@000a09018M5`0B71@07RDN00lC
300@4@/03a0:01DE3@0E4P/03Ph600`=200C50l0414<01LH4`0S91l0JFYU01DF4@0?40/03Pl:0080
4A8=00<0414<00lA3P0@4Pl00P0A4a00200@4Pl03a4>01`N6`0:30T03a4>00X<2@0;3@X051HB0P0?
4@`00`0@4Pd030h900/=200200h@2`0A00lA300@4Pd03a4<00h@2`0@4Pd04aD@00d?2P0<3PT04A<>
00d?2P0@4Pd0?T0k01`N6@0=3`X051HA018D3`0b=2l00`0@4Pd200d?2P08010B3@0=3`X03@l:00lA
30051`804aD@00X=1P0=40T2014D3@8041<<00`05APA01LJ4`0A50d04QD>01@G400C5Pl05QPC01@F
4@0C5A0051HA01DG4P0D5Q42018D3`0T014C3P0B50l04Q@?01<E400E5a806adH01@F4@0G6A@04Q@?
01`N6@2DUY40;S0[00X;200D5Q4030h900`@2P0X;bP000L001lY8@0C7AD0:38Z014K4`0?6A403QP@
010J4P0?6A4031H>00hE3P0F6aL051TE01XO6`0>4`l06AhJ018G4`0A5Q805Q/G0P0D6AD0100F6aL0
4AHB01DJ5P0E6QH201HK5`805a`H00H051TE01HK5`0E6QH061dI01dR7P0H7AT201`R800=071fM00h
?S`03A<A018H5P0H7Q`06AlM01/Q7`0L8R0061hL01<L6@0F8Ad05R8N01LS7`0201TU8@0>01XV8P0L
:2@09C4]024]:@0I9B4041`H028^:P0O:BX031HG02@^;`0P:bd062<U02@_<@0P;S4201l^<@<08C0e
00D072hb01la=@0P<SH0838f028d>00202Li?@0a02Dg>`0V>3`093Hj02Hh?00/@44083Hd02Lm>`0a
AdH0:3dn02a1@P0_A4H0;D9502a1A00aATX0=T]@03E:C`0dBDh0=daA03Q=DP0eBTl0=4U>03E:C`0g
C540=DY?0356B`0fBe00@UML045FF`10EET0>TmB0397BP0gC4l0@UMJ03U>D@0cB4/0KhB703I;CP0Z
?d808SLj04AIG00jCe00>Di?03]@D@0jCe00>Di?04EJF`0nDe@0?E9C03iCE002045FE`0j03aADP0d
C4`0?EEE03mGE`13Fe/0<TY:03iFEP0mEU<0@EYG049KF00jDe00?eQE04AMFP0mDE00@EED03eAD00n
DU00AUYH041DDP16FeH0FVmZ05M/I@0mDT/0?U=<03eDC015G5@0@eeE04AME`15GU/0Af1N04UQH@1;
Hf<0CFET04eVHP1;I600AEmG041JC`15G580AeiC04ELDP12FDl0JX5h04YQF@16GED0@UUB04ELEP1;
HU`0C6=N04ILF@11EU40AU]E04MLE@19GUL0K85i09baZ018GE@0:d4f03I<@080A5Y>01L0?E=7041F
BP0nDdX0?U=:045FC@15FU<0AeaE04EJD`13F5<0A5UD04EJE@0oDe40>Ti<04AIE012Ee80?U=>03mD
C`0nDdh0>Di908bQW02dbL@0B5eH03]@B`0203I;AP0?03Q;A@0eB480<D@n0395?`18FE<09CH`01l`
:P0Y>3<0;chi030o>P0]>CD0:cLc02`k=00^?CH0;chg0080<3lh00@0:STb01l^9`0P;bP0:CPa0P0S
<R/03@0T<R/07b`U01l/9@0P;BH07b`U01l[9`0M:BD082`X028^;00O:bX082`/028^;P0P:RP00P0N
9b@0:P0M9R<06R<P01XS800P:BH0:34^01`U8P0O:2D08R/X01/T8@0S:RX08RLZ028X:00P9RH07R@T
01`R800J81h0728P01`R7P0I7a/05adI01TO6P2CUiP0If]^02P/;@0R9RL07b<T01TM700E6AP051PG
01<H500D6AD05AXF01PM5`0D5Q<05ALD01dO700B51404aDB01@F4`0H6QL05QPE01DG50805QPE01<0
4aDB01DE4`0E5A<06QXH01TI5`0F5Q@05aLE024Q7`0<30X071`J01DE4`0820H03`l=01@D4P0C4a40
410>00l?3@0B4Q005ADC00D04A4?00<0410>014?400A3a00100A3a001P0D4Q<02`T:01PF5`071@H0
3P`=014?40L03`d>00D03P`=00d;300>30d040h?014?400300l=40802`T<00`05aDH00l=40010080
3`d@01LE600/:Rd0NGMj038`<`071@P06ALJ00X82`0@3Q4200l=400300`:3@0?3A0040hA00803P`?
1P0>30d02`0@3Pl02@L800T7200A3a001@<400/82@0=2@X05A4B014=3P0>2P/0510A00H03PX;00d0
4Ph>01HB4@0F4Q404@d<00d9200<20L03PX902dY:019AD@03@T800<0000L61L04@d<00803@T800H0
30P700d9200=2@P02PH5018>3@0A3@`200X61@0400P40`0<1`L03@L700h820803@L70P0@2PX01@0=
1`L03PP801<=3@0D3Ph030H600802`D500H040X:014;2`0?2@T03@L701<=3@090`<200L10@0901D?
3`0=20P03PP800d71`0:10@02@<300X4100=1`L03PP800803@L700X030H600d71`0>20P040X<048l
?P0;1@L0100000P2100?2@/050h@0P0:10H03`0I4aD0;2HX0=WCe@18?D<04`T>00l42P0;00H04`P>
01@93`0J3aD060dC0146300G3180B3e301873@0Dooooo`006oooool01P0<41403Q8C00hB4`0=4A80
3a<D018F5`803A4B00D020`=010D5@0=4A803Q8C00dA4P0200lC500C00dA4P0>4Q<03a<D01`P8@0B
5QL041@E00dA4P0<414051PI00dA400;3`h05ATH00P;2P0N8R4061`K010D4`0?4a804ADD00hB4@02
00`@3`0<00h@3@0=3``03Q0=010B3`0B51404aDB00h@3@0F61D061XG00`>2`0?4@h030h;0P0:30/2
00h@3`0>00d?300?4@h0418?00d?2P092`H051HA03/n=`0o@Sd0LG=`01PJ5`0C5A804Q@A00h@3@0;
3@X500lA3P0400h@300@4Pd0418=00d?2P80418=01h030h900h@2`0B50l04Q@?00/=200=3`X0410<
00X91@0@4@`05aTD014H4@000`003AL?00`F3P0@5@l041<>00d>2@0=30P03Ph900d?2P0@4Pd03a4<
00/=200@4Pd04A<>010B3@0=3`X02`d800`>2@0?4@`2010A300500l@2`0>3`X03Pl:00l@2`0<3@P0
0P0?40/02P0G61<04A8=00`=20082PL03Q0=00830@0<3P/04A<@00d?2P0;3PL201HI4P0M01<F3@0I
71<04A@;00X=1P0A50d04QD>010C300D5a0030l800lB2`0=40T030l800d@2@0>4@X03A0901@E3`08
2@<03@h801dN600O81X03Pl902<T7P0>3`T04A8<00h?2@0A4P`04Q<;014D2`0A50X00P0@4`X03@0?
4PX03a8;010B3@0A4`l03@l<01PJ6@041PD03a4>00d?300B50l0:R`W02LY900@4Pd00P0C5A00600f
>3<05ALB00P:1@0R91l02A09051RFP1@I5/04R<K00TG400D7aL04Q`D00hD3@0>4@X04A8<010@200@
3@H04A4900h>2P0@4@`051D@01<D3`0H6A@0DeA?01HG4P803a0;00l04Q<>00l@2`0;30L030h;00/=
2P0<3P/03Q0=00d?300;3@X0>C/h02PZ9`0A4a005QPE014C400>40`00P0A4`h0100?4@`030h900`>
2@0@4Pd2014C3P0@010B3@0?4@`03Q0;00lA300B50l030h900d?2P0>40/04A<>01/M6016B4<071hI
00h@2`0C5A001@L202h`:`803a4<00`04A<>00d?2P0<3PT03a4<01`N6@051`805aTD00h@2`0A4`h0
3A0900hA2P0A50d201<F3`04018E3P0?4P/05aXC014D3@8051L@00P06ahG01@F4@0B50l03a4<014C
3P0B50l04aD@014C3PD04Q@?00L030h901LI500P8Qd06adH0043000`<Rd0=CLb00804A<>00`071hI
01hP6`0C5Q4000L001lY8@0=5`l03QP@00PB2P002P804adE010J4P0=5`l200`F3P0900dG3`0A5Q80
4QLC01HK5`0=4Ph04aPD00lD400C61@05a`H008051TE00<05Q/G018G4`0E6QH00P0F6aL01@0G71P0
6AhJ01TN6P0D6AD061dI00805AXF01806AhJ01LL600B61H06b4O02X`;P0U:bT06b4O010F500I7ad0
61hL01XP7P0K8Al06AlM01@M6P0E81`05B4M01HR7P0H920201TU8@0?05UUH@0U<Bd04alK02lk=`0D
81`05b<O028/;@0G8B8082X[01/V:00S;S00:3<e01l]<00L:bh07Rd`00808C0e00<07bhc01d_<`0R
=3P00`0S=CT04@0^@4@0<TA802do@`0[?D40:3Xn02Xl@00/@44093Xh02a2@00_A4@0:d110356A`0a
ATP0;dA702i3AP0`ADT0<dQ=0080=4U>0P0fBe005@0aAT/0<dQ=03E:C`0iCU<0=T]@03=8C@0hCE80
>TmD03eBE`11EUX0=T]>02m4A`0hCE00A5UL04MLG`0mDUD0AEYM03M<C`0eBTd0OiBG04IKGP0203]@
D@0Q03aADP0iCTl0>4e>04EJF`11EUL0?eAE041EEP14FEX0@eQI03eBD`0lE5H0>E5C03Q@D@0iDE40
?EEE03iFEP0lEE80>U=@041IE@0dCDT0=Tm;03E>BP0iCD`0?E5@049FE@18G5X0BemM049FE013F5<0
DfQS05AYHP0oE4d0@EI?0080AUeE0100A5iF04ENF015GU/0B61O04UQH@16GUh0B65O04URGP18HEd0
AEmG049LD@15G580BV5F045HCP14Fe40JH1g0P1:HET06013FU<0@eYD04YQF`1<Heh0AUaI04EJE@19
GUP0AEYC03aABP14FE40GgA[0315?010ED/0<dTm04AJCP0lDTH0AUa@03mEB@0nDdX0?eA;049GCP15
FU<0AeaE04AIDP<0@eQC00h0?e=A03a@CP0mDTd0?55<03Y?BP0nDdh0?eA?03Y?BP27W9L0Ykbg04IK
EP14FE@0=T]603iCCP80?E1:00H0>di8045DCP1WN780=TM102@e;`0V=C0202Dd;`0802lk=`0d@3`0
=4<l03A3?00_?SL0;C`e02/j<`0V=Bh202<b:`0502He;P0T<b`09C@]02Hd;@0T<BX00P0U<R/04@0T
<BX08bl[01l[9`0M:BD082`Z028^;@0K9bL07BTY028/:`0O:2D07RLT01lX9@0N9b@072DR01XS800V
;b`07bPU008072DR00L05AhK01`S8`0O92L08BLW028X:00Q9bL07R@R0080728P00X0728N01TO6`0H
7QX06b4L04iBD`0k?d803Q8C01XN7`0F6Q/06AdL0P0F6QT02@0F6aL05a`H01PM6@0I7QP05aTF010B
3`0H6QL04Q@A010B3`0201HH5@805ALD0P0G6AH04`0F61D05ADC01HF500G5aD05QHD01DE4`0H61H0
3Ph<02HV901UIF<0HV9P02h^;00=3@/04A4?01<C4@0B4Q003`l=014A3`0E5A<00`0A4@l3010@3PH0
4Q0A00H06ALH014?400I5aP030X;01<A4P0B414600l=3P06014?400?3@h03@/<00h<3@0A3a004a4B
0P0@3Q404`0?3A0020H900@21@0H5QT02`T<00d;3P0>30l040hA00400P091`X0518E01HD5`0E4aH0
1`D801<A500>30l03`d@00/9300<2Pd00P0>30l00`0=2`h03P`=00h<3@0400h<3@0:018@4@081PL0
20H700d;30010000514B00`82@0A3@h040`=00T51PL03PX;00@03`/;010<2`0A3@`03`/:0P0<20L0
1`0:1PD020@301/G5P0D40l01`<201@@3`0@30/00P0=2@P0100<20L03@T800d9200;1`H201HB4@06
00d9200>2PT030P700h92@0=1`L03PP80P0=1`L01`0A2`/04P`<00h8200@2PX06Q@D01/E5@0>20P0
0P0=1`L04@0@2PX03`T900X4100<1PH04P`<00l92@0G4A40100000L10@0E3`l03PP8014;2`0D3Ph0
40X:00h8200?2@T03PP800803@L701/030H600d71`0>20P0100001/E5`0=20T05@lA00H10P0L5QP0
3PP:00h92P06008040X<01@?402DSY00=b`b01<83P0A1P`04`P>01052`0:00D01`0200l42P0;00H0
1`0202<H7P0900@05?ooool001_ooooo00d02`lA00hC500?51D03A8D00`A4P0=4Q802Ph@018F5`0:
3Pl03A4C00/?400A5AH0310A00803Q8C0100310A00dA4P0>4Q<02@d>014E5P062P/04ADF00@82@0@
51D02`l>018F5@0<40l02`h=00lC4P062PT0310?0P0?4a80200>4Q404QHE00T=300?4@h03Q0=00lA
3P0@4Pl03a4>0P0>40d05`0I6aP06Q`I010B3`0C5A803a4>010B4@0=3`h04Q@C00lA400;3@X0418?
00lA3P0A4Pd03a4<018D3`0Q8ad06A/F01TK60082@L03a4>00H81@0B514030h;00D03a4>00@03Q0<
00lA300?4@`030h90P0?4@`0100<3PT05QPC01`N6@0C5A0200d?2P0B00l?2P0A40`020T4018D3`0=
4`d06R4J00XB2`0;4``0314;00d?2P0A4Pd04a8>01LG4`0C5A003Q0;010B3@0>40/03@l:0`0?4@`2
00h@2`0400d?2P0B4`h04Q<>010A30<03Pl:00L03a0;00X;1P0A4Pd04A8=00h?2P0=3`X030h;0080
3a@@00T02a0<010E4@0=4P`02Pl901DJ4`0@5@l02Q0701<H400;4@P00P0?4P/01`0A50d04QD>018E
3P0B5@h02`h700`?200>4@X00P0A50d03@0=40T03@h8014B300H6A<06a`F01DF400:2`D03@h800l@
2P0A4P`02@X4010A2`0?40T00P0@4`X0:@0?4PT03a8:00hA2P0>4@X04A<>00`>2P0>40d02@/905EG
E@0O8Ah04aDA00lA300P8Qd06adH010B3@0[;BP08B<N02PZ9@0<3PT03Q0;034c;P0I8AX0SYnG08jQ
V00L;bD01QL>00PD300;4``03Q@<00T=1P0D5Pl0414:01TG4@0/;BH03`l:01DF4@0C50l03a0;00P9
1P0@4@`04A8=008051D@01T04A8=00h?2P0>3`X03@l<00/=2P0>40d04Q@A010B3`0=3``05QPE00T;
200B51401`T701@F4`0<3PX03Q0;010B3@0>40/03a4<018D3`0C5A004A<>00lA300>40/03a4<0080
4A<>01P04aD@00d?2P0@4Pd02@/601HH4`0[;BP06Q`G01<E400>40/03@l:00`>2P0C5Q003a8<00hA
2`0B50h030h900/=200B50l061XE018D3`0?4@d051LA00h@2P0C5Pl3018E3P0?018E3@0A50`02Pd5
01LJ4`0?4P/04A@=00h@2P0K7AL0418=00lA300@4Pd04aD@018D3`0?4@`04Q@?00<04aD@01X04Q@?
014C3P0H6QD0<S@_01XL5`0E5a804aD@01HH4`0G6A@05ALB018D3`0A4`h03Q0;01HJ500i@3T0@Ta4
00`F3P0D7AD04Q/C018L500C71@04Q`D010J4P0@6A404Q/D018K4`805Q/F00X041D@01TN6@0@5A40
51TE018G4`0E6QH04QLC01<H500I7QX061dI0P0G71H201HK5@805AXD00d05a`F01hS7@0J7aT05AXD
01LL5P0H7AT051XH01TO7@0@5Q@0:Bl]01TO7@0H7Q`06R0N008061hL0P0J81h06@0G81d04ahL01@P
7@0E8Ah05b<P01PT8@0I9B805b<P01dY9P0C7a`07b/X028^:`0I9B807bTZ01`V9`0Q;2`09c8d024/
<00J9bX07Rd`01/Z;`0M;3408S4f024`=@0O;c@00`0Q<cL03`0R=3P09SPl02Pj?P0U=c/093Hj02Li
?@0V>3`09cTm02]0@@0Z@3h0;D9202a2@P0hCDh0?E9C0356B0020397BP090315B@0_A4T0<TM<03=8
C@0fBe00=daA0397C00eBTl0=daA0080=T]@04P0?E9G045FF`0cB4d0@UML06f2QP1MLGD0@eMJ03Y>
DP0aATT0>TmB049HF`0`AdT0?E=F049GFP23V9/0A5UL03aADP0nDe@0@eQI03eBD`0gC4d0?U=D045F
E`0oE5D0@EIG04QMGP19GUh0@EIG03eCE`0^ATX0A5aP05M_LP1eSHl0AemP04AMFP0dCDX0?UMB03I?
BP0hDDX0?eQ@04iSG`14F5L0@EEC04AHEP13EeD0AEUH04YNF`17G5P0AUYG04EIE@14FE<0A5]D04IM
EP14GUH0A5eG04ENFP17Ged0B61O04aTH`1;I640BF9N04MPF`15GUL0@eeC04MNE018H5@0@UU?04EL
DP1;HUT0C6=K04IME@17GUL204MNF00<04UOF`1:H5d0AeaG04IKEP19GUP0B5eF045FCP10EDd0?eE:
06UnL`0nE4P0JX1d0P11Ed`01010ED/0@EI>049GC`12Edh2049GD00J041ECP12Ee80@EIA03iCCP0n
DU00@5AB03eAC`0oDe40?U9@04AHEP17FeT0@eME04AHEP10E580=TY803iBD00eBDL0=T]603U<AP0_
@S`0>4]503A7@@1IJV@0:CXd02Lh<P0Z>C@202Lf<@0403I3?`11CTX0<T4j0391>P80:cXc00D0:3L`
02Dd;@0Z>C809cH_01l^9`02028a:`0Y028`:P0V<b`09c@]02Ld;P0U<Bd08bl[02<_;00O:bT0:3@b
03A0?`0P;2/072PX02D_;@0M9R<06b<P028[9`0W<2`08BXV01`U8@0T;BX09Rl/01hX9@0Q:RP08R`[
020W:00O9BH082HU01lU900M8b806b4N01hT8P0N9240728N01PN6P0I7a/07R@O01PL7@0Y;Bl05QXK
01hR8`0G6a`00P0F6QT01`0G6aX06AhJ01TN6P0I7QX05a`G0412?`0Q8b000P0H6QL01@0B51405QPE
01/M6P0I6aP05aTF00805QPE00@04aDB014A3`0E5A<05aLE0P0F5Q@0200G5aD05ADC01PH5P0M7A/0
6a/I02<S8@0G5aD05ADC0P0B4Q0201DE4`<04A4?0P0@40h200l?3@0301<A4@0C4A804a4B00<04a4B
00H03`d>014?400@3Pl03P`=01@B4`0>30d6014?400N01/I6P0G5AH040h?00l=3P0A3a004a4B014?
4P0G5AP030X=01@B5@091`X03@/>00l=400B41<03`d@00h<3`0G5AP05Q@G00d;3P0>30l04@lB018@
4`0<2Pd03P`?010>4@0<2Pd02PP;00h<3`0?3A003P`>1P0=2``0300>30d02PP900d;300=2``05A<D
04=0@@0E4A802PH7014=3P0:1PL03@T:00l;30D03PX;00X03@T900d;2@0?2`X03P/:00h:2@0?2`X0
4Ph=010<2`0>2PT03@T80P0@30/300d9200T00`81`0=2@P03@T8018>3P0U8B008alN018>3@0>2PT0
2PH500`71P0=20L03PT800d71`0>20P04@/;00d71`0<1PH03PP801<=3@0D3`l04@`;00d7200<1PL0
3`T:00d7200<1PL07ALH03`f=`0C3@h08A`L01H@4@06004030H600X51@0;1@D03@L70P0?2@T200h8
20803@L701/030H600d71`0>20P03`T;00d82@0?2P/03PT:00l:2`0=1`T04Pd>01PB500B30h03PT:
02@N800G4A<03P@901@:4@0?1@/04`P@01063@0R61l04@H>00d42P0D2Q004@H>00`42@0G3A@05?oo
ool001_ooooo00H03QHI00TA4`0U;Bl09Bd`00`D5`053@l200hC5`0G00hC5P0?4QL03a<G00lC5P0?
4a@03A4@014E500B5QD06alN020T8`0;3`h03A4@00X>3@0?4a8041@C00`@3`0A4a803Q0?00`>3@0=
3`h0418A018D4`0?4A000`0@4Q403P0>40l03@l>00X<2@0?4@h05QPE010B3`0C5A80418?00P:1`0B
514030h;01dO7029RhP06Q`I0P0;3@X0300E5a@030`:00X:200C4a4030`:010?3@0>3@/04A0>018A
3`0>3`X02a0:00`A2`803A8<00P0314=00dB3P0?5100310?00D9200;3`h02Ph=00`@2`8030h900D0
2`d800lA300C5A004Q@?00h@2`0200d?2P0L00h@2`0?4@`0418=01<D3`0@4@`03Pl:01dO6P0N81/0
4A<>00h@2`0@4Pd04A8=010A300A4Pd06AXE018D3`082PL010H100X<1`0;3@P061XE00d?2P092`P0
1PP301HH4`0:30L03a4<00h@2`8030h900<03Q0;014C3P0B50l00P0A4`h0400?4@`03@l:00`>2@0?
4@h02@/8014C400O8Ah0;Bl/00`>2`0;3@X051HA01@F4P092`H02P`700/=200A4P`2010A2@06014B
2P0@4@T03Pl700d>1P0;30@041490P0C50`02P0G61803Q4:010B3@0@4Pd04Q@?00d?2P0>40/02@/6
00d?2P0F61<2010B3@0800/=200;3PL041<<00X=1P0@4Pd03Q0;00lA30072@@2010B3@0I00d?2P13
AD40:B/V00h@2`0=3`X03a4<00T;1P0V:2<0JF]V010B3@0L7QT04Q@?00/=200I6aH041D>01TP5`0S
:R8051/C00L<1@0<4@X03A8;00X?2@0C61802@h:00h@3@02014F4P0>00hA2`0;3PL03A09010C300?
4P/03A0901<F3`0D5a003a8;00`?200I71D01PP300h@3@0=3``200P:1`0?01PJ5`0F61D0418?00h@
3@0<3P/04Q@A00`>2`0>40`04aD@00lA300<3PX05QPC00lA300@4Pd04aD@00803a4<02T051HA01LI
500D5Q401`P300h?2P0E5Q40414<01<D3`0@4@`02@X502HW8P12@ch03@h90001000@4P/03a8700lB
2@0?4PX03a4<00lA3P0<3P`05QPE014C3P0@4`/05AP?018E2P0?4P/03A09014D2`0B5@`03A05018E
2P0>4@H07b8I02d`:@0=3`X01`T601@F4`0?4@`03a8;014D3@03018E3P1=01HI4P0C5Pl041<<014D
3@0D5a005QTB01LJ4`0b=Bh092LP0085000@4``061/D01HI4P0C5Pl04QD>01HI4P0G6Q<051L@01XO
6@0E6aD04QTB05aQF`0D6Q@03QD>014F401>E4d061lH01hS7@0D6Q<02Pl901HK500L8AX06AhG01<H
4@0?50h04aPB01@I4`0C61<051TE01HK5`0E6QH04QLC0088100K8Ad05A/G01`R7P0F71P04ALC03Pn
>P0^=30061hJ01/Q7@0E6aL03A<?01LM6`0J81h07B<Q01/Q7`0G7A/051XH020V900E6aT092XX01@J
600T:RP051dL01XU9@0K9bL062@T01LS8`0P;2`05B4Q01XV9P0K9bL06BDU01hZ:P0L:2P00P0O:b/0
500Q;Bd072XZ01PV9P0I9bP06RXZ01h]<00P;c807c4c01h`=00L;S806R``02<f=`0Q=CH093Pi01hb
<`0[?d008SHg01lc=00L<3409c/l0P0]@D803`0/@D80:3dn02Xo@P0bAdX0=4U<0315B00]@TD0;dA7
0356B@0dBD`0<dQ;0397BP0`ADT0<4E:03=8C@0203M<D@1U03I;D00hCE80A5UN04iSJ01KL7D0=DY?
05U^L`3FiNP0dn3V09:QYP0kCE40@eQK03M?D@0lEUL0>59C03=<CP18GF00@UMJ03]>DP12EET0?U5E
03a?D`0oDUH0@UEI041DE@11EEH0@UIG04]OGP1<H5l0@UID03iBDP10EEX0@5AK045EG@1OM7T0LXN:
04]PHP15FeT0@5ID03A;AP0dBdD0?5=;03eDB`0nEDd0A5]C03iED01CJFH0BV1N06j3Q02=XZD0B5eP
04IKG@1dRHX0@eQI04AJF019Ge`0@5MA04QOF@13FU@0AUaI04UOG01=Hf00CfER051WH@1?IV00C6=M
04QOE`1>IE/0BV5G04ELDP14Fe<0AeiF04YQF@16GEL0@UUC041GD@13FEH0B5iK04YPG@19GE/0AeaG
04aQFP16Fe80B5iA03aBA@0cBC`0@5I:02e3=`1ZOgH0@EI@04IKEP0oEE80B5mI04=JE012FE40AeiD
04IMD`10Edd0<dY203aCC@1<HUh00P0nE580700nE540>U1=041FD`0iCd`0?E5?07>7Q@0nDU00A5ME
03Q;B@0kCT`09CPf03M:AP0iBT80=DHn03A5?@0cA3`0834[02@e;`0S=2h0:3Pe02dm>P0_?c`0>4Q5
0391?P0fACd0;chg02Pg<00V=Bh202Th<`0D041?BP0O;RT08C0/02@c<00V=C80?4Y602Xf<P0O:bL0
82`X028^:P0Q;BT08RhZ02<_:`0T<2`08bl[01l[9`0M:BL08BTV024W8`0N8al201dT700K01/U700L
9ah062<M02@_:`0H8b<0?TU=0;>na00b>C`07R<O028W8`0L8Ad082DQ020U800M8Qh07B8L02T^:00F
6aD06QlI01`Q702UYjH0HfET01`N7@0J71/061XI01TK6P0C5A@051HE00806Q`K01`061XI01hP7P0J
71T05ALD01HH5@0H6QL04aDB014C400L7Q/0=3Hc04]=BP0O8Ah01`T601HH5@0H61H03@d;01XJ6006
1P@06ATG01LG5@0F5Q@05ADC024Q7`051@<05QHD00/;2@0@40h04A4?0P0B4Q00100A4@l03`l=01HF
500G5aD201lO7@0A01TI5`0H61H03`h<01@C4@0J6AL061LE018A400E4a@03@/<00`:300I5aX04@lB
01HD5`0D4QD05aDF01<A4P0A3a000P0B4140200?3@h04Q0A010>3`0?3@h04@l@00l=3P0>30d03`d@
0P0>30l0400?3A0040hA010>4@0?3A002PP;00h<3`0Q7b807Q`O00l=400>30d01@<401HD5@0<2P/0
0`4201@B4`0<2P/200h<3@0400d;300<2P/03@/<00`;2PD030/902004A0>00H50`0?3P`03Pd;014@
3P0?3@`04@d>01<?400=2@X03PX;00l;300E4A80100101@@4@060P<06aLH00<0000=2P/02PX:00T7
200<2``020H700H41@0>30d02PP900X61`0<20T03@T:00d72@0>2@X03`/<00h:2`803`/<00X040`=
00h:2`0=2@X03`/<00h:2`0;1`P03@T:014>3P0<2`T02`P70P0?2@T05P0D2``05Pd>01892P0<1PH0
3@T800d<2P0>30`02PD901@?4`0<1`/03PT=014<400@2`l03`X>00`72`0Y92P050lC01D@500810H0
2`D500X50P0<1`@2014<2@802`H300P050l<00l:1`070P0020<001@>3@0>20X03@L900`620803PP:
01<030H800/51`0A2`d0208400l92`0A2`d04P`>00@0000H4A@02P@600d42@0?1`/0208400`3200>
1`X02`D700X11P0?1`/05a4C01Cooooo000Kooooo`0900041P0G8B<0[kVk0;o9b`0L9BP05QhQ00/C
5P0<4aH03A8F00803Q4F00X03Q8E00861`0B5QD010P701<G5P2@U9<0J6a[00lC4P0A5A@0310?0P0=
4A002@093@`04A<B00h@3`0=3`h03Q0?010B4@0A4a803@l>010B4@02018D4`0V00lA400=3`h04aDB
014C400:30T02@/800h@3@0B51404A<@00`>2`092`P05ALD04U;B00>40d02@/800lA3P072@H04Q8@
01@D4P0000003@`:010?3@0=30X04Ph=01<?3P0>3PX0314:00`A2`0=4P`0314;00`A3@0?51000`P4
00P<2`0C5aH01`/:02da<00?4`l2010B3@803Q0;00d03a4<00d?2P0;3@P02`d800d?2P0@4Pd04A<>
00`>2@0?40/04A8=00X;1P0A4Pd04a@?00803Pl:00<03a0;00h?2P0=3PT00P0>3`X03@0=3`X051HA
00/=200:30L05aTD00P:1@0=3`X051HA00@60@0;3@P051HA00lA300>40/00P0=3`X0100>40/0418=
00d?2P0>40/3010B3@0800lA300J71T04A<@018D4@0>40d05ALD00lA3P0:30T200lA3P0W00`>2`0?
4@h03@l;00l@2P0@4@T04A8:010A2@0>3`L03@h601<D300@4@T04A8:00l@200;30@03Pl700h@2`0F
61<0418=00T;1P0F61<04A<>00`>2@092`H01PP300T;1P0>40/051HA00h@2`0B50l02P`7010B3@0<
3PT03a4<018D3`0>40/04A<>00<5000E5a80004000803a4<03D04A<>00/=200S9B00Gf5L01`N6@00
0@004aD@01@F4@0;3@P030l801<D2`0?40P020T1018C2`0H6a@04A@=01@F4@0F6aL000D101DI6006
30X01@/700lB300<3`P03A09010C300>4@X030l800`>2P0B5@h01@P1014D3@031P005APA00`>2`00
0@007R0M01@F4`0=3``01`T600`>2`0;3@X04A<@00X<2@0A4a002`d900P:1@0=3`X05ALB010B3@0B
50l04aD@014C3P0200h@2`0800lA300>40/04Q<>00/<1`0>3`X0414<00/<1`0?40/200h?2P0M01hO
6P0_<2/05aPC00l@2`0B50`03a<500lB1`0?4PX03a4<010B3`0@4Q406Q`I00P:1@0V:B402@`101HJ
3@0A50/03Q4:014D2`0A50T03A05014E1`0D5``06ahC02ha:P0S9B802@/800`>300@4Pd00P0A50d2
018E3P0@01<F3`0B5@h04A@=014D3@0C5Pl051L@01<F3`0E614061/D01TL5@0@4``030l801HI4P0E
614051L@01<F3`805APA010051L@01<H4P0?50h03Q<=03Hk=@0<4@/03a@>01<H4P1hOGL0<3D_010E
3`0E6Q@05AXC00hC300C6@l051X@0P0B5a00400F6a@04QLA014F4@0C61@05Q/G01LL600E6QH09B/W
02le<@0H7QX05adI018H500A5a<051XF01PN6P0?5A4201HL600>01LM6@0G7A/06AlM01XP7P0I7ad0
5A/I01@J600C6AL05A/I01PN700C6AL06AlM01LP7`0M:2T301TT9P0601LR900=61X062<U01PS9@0@
6ad05R4S0P0M:2X0100K9bL07B/[01l];@0N;2`201`/;00302@c=P0Q<cD08C<e00808C<g00<08S@h
024e=P0O<c@00P0O<c@0;@0Z?Sl0:cm002Pl?@0V>S/0;D5202a0@@0W>c`0:Ci002a1A00^@dH0<TM:
03=8B`0bAdX0;D9502a1A00_A4L0<dQ;03E:C@0dBD`0<TM;0397C00eBTl0>4eB03U>D`0hCE80;dA9
041EFP0lDEH0IW^006EjO`1bQh`0h_3c0=ORj022SI<0BeaP04=HF`0lE5H0G7Ig06J2P`0nEeT0>DiA
03=8B`0hBdl0@eIJ045DF00203iAE@0`03mBEP0nDU<0@UIG049FE`1:GUd0BUiL049FE010E5<0>4eB
03U=E019GFD0NXnD08^PX`1?I6H0?59@03]AC`0cBTD0<dY403]BBP0nED`0<dY004=JDP19H5/0D6IT
049GF014FE`0HgQm03iCF01GK700Q9VL05I[KP1=HV<0A5YG04ELEP1CJV@0CfIP04eTGP15G5H0C6=M
04iUG`1?IV00CVEO04]RG019H5P0B5mG04MNE015G580AEaD0P16GED0A@17GUP0A5]E04=JE016G5T0
BV1M04]QGP18G5X0BUmI04eRF@12Edh0@UQ;03aC@`0mE4@0Bf5C03iDB00oE4d0AU]E045ED`14FUP0
BV1M04ELEP12FE80A5]A04=JD011F4h0>E1803YAB@15FeP0?E=A045GE@0oF5@0AUaI041FD`0jD4d0
Ef]Y09>WY@1=HEl0>Da:03I9A`0iC4X0=4M5049ED@0fAch0:c`d03Y;@`0a@SX09SLa02Pi<`0N;bT0
9SHc02`l>@0a@Ch0>TY903=3@00`?cL0;chg02He;P0P;bP09C@_02Th<`0X=c806BPU03Y9AP0X=c@0
62HV01dZ:00K9b<05b<O01l[9`02024]:@808bl[01@0930/02<_:`0P;2P07b/W01`U8@0I7QX06AhH
01`R6`0P:1d07bTN02H`:00S;RP08BdY01XW:00[>3h0NhR@038j?00W;2H08BHP028W8@8061dG0180
5a`F01HK5@0S:28061dG01hS7@0Q9R40IfUX0453@P0O8B008R@S01hP7`0H6QT051HE01DG5P0B51<0
4aDD01TK6P0E5aH201lQ7P0F01`N6`0J71T06adJ01`N6`0F61D0828O03Dg=00H6QL04A<@01HH5@0P
81h04A4?05UIE`18B4H09BDS014A400b<S0051@B00l?3@0F5Q@04Q8@01TI5`@04a<A0P0D5182014A
3`0F01LG5@0H61H04Q8@01<C4@0H5a<04a8?014@3P0@3`d05A@C02<Q8P0e<c@06QPJ00l=400F51L0
20H:00P62@0C4A@040h?00h<3@0?3@h03P`=00`:2`804@l@0P0@3Pl200l=3P04010>4@0?3A003P`?
00h<3`<03`d@00/03P`?00d;3P0E4aH04a4D00X82`0B414071XK00T7200B41406QPI00H41@0600l=
3PH030/900T01PD3020O7@1<BdT01@@300P71@071@D04Ph?01<?400?2``00P0A3@h04`091@H01P83
010<3@091@H01P8300D10P0;2@X02`/;00`<300:2PX02@T900`:2`0>30d030X;00`82@0>2P/03`/<
00l92`0=20T00`0;1`P200`82@0C00d92P0?2``040`=00d92P0<20T03PX;00X820092@L040l=018<
300A2`/03@@501<:2`0A20T03PT9010<2`0?3P`02`/:00L21P0200/6300:01@?5@0E41H0L6]a00X5
2`080`T05a8H00D01P0?2Q002PD:00l92@803PT600`03`X700h91P0;1P<04@`901HA3P0B3@X03PT6
00X50P0;1@@03PP:00d72@0<1PP200h82P0300`6200C3@l04P`>00803PP:00h0100000l92`0S7Al0
6aDG018<3P0D3Q003@L900l92`0@2P`04@/=00l92`0@2P`07aTK02lY:aCooooo000Kooooo`06018L
7@094A80=Cm004M?D@0?5QP0CUIH0`0<4A@200dA500=00dA4`0=4A804ADD010D4`0M8B00X:BS03Hj
>@0;3`h041@C00`@3`0;3`h03A4@00/?3P0200lA4080418A0P0?4A000`0>40l0418A014C4P02018D
4`0J014C4P0B51403@l<00X<2@0E5a@020X701LI5P0B51401@L400d?300@4Pl01@H400lA3P0>40d0
418?00X<2@0@4Pl05aLE01DE4`0>3P`040l=00d<2P0A3@`04Ph=00h>2P0>4@X200lA300@00h@2`0=
3``02`d:010B3`0Q8b8071hM02HX9`1IFeX03Q0=00X<1`0;3@P03a4<00h@2`0=3`X03a4<00h@2`<0
3@l:00P03Q0;00d?2P0F5a806a`G010A300>3`X04A8=010A30804A8=00l03a0;00d>2@0>3`X04A<>
00X<1`0;3@P04Q@?010B3@0:30L03a4<00/=200@4Pd04Q@?01@F4@0F61<0100?4@`00`0>40/03@l:
00lA3003010B3@803a4<00P0418?00P:1`0?4@h03Q0=018D4@0=3``03a4>010B3`803a4>00/0418?
00`>2P0>3`T04Q<;01HG3`0@4@T030d500d>1P0<3@D03Pl701<D3002010A2@0=01LH4@0I6aL02`d8
00P:1@0b=2l02P`801<E4@0:30P04a@@00X<1`0L7QT03Q0;00d?2P02014C3P0300/=200@4Pd030h9
00804A<>00D01PP301PJ5@0A4`h061XE01hP6`0200h@2`0H014C3P0;3@P061XE0412?@0g>C@02`d8
00lA300@4Pd04Q@?018E3P0C5@/08R<K01TJ4P0=3PH03Q4:014D3@0=3`X03a@@00/@300>4Q4051PF
01HL600A4`d03a8;0P0>4@X03@0=40T02`h7018E3`0=40T061/D00/>200K7QL02Pd6010B3`0:30T0
3a4>00h@3@0B51400P0>40d0>P0B51403a4>014C400E5a@03@l;00D70`0M7aX0=SPc01@F4@0;3@P0
3@l:00h@2`0=3`X03a4<010B3@0?4@`04aD@00l@2`0A4Pd03a0;00d>2@0C50l03Pl:018C3P0?40/0
3@h901DF4@0C50l03Q0800hB1@0?4PP041<;014C3P0A4a00418?010B3P0H6QD0K6mW014D2P0?4`L0
41<:010C300B5@`041<800hA1P0A5@L041<800`?100G6Q<0;Bl/00X<2@0D5Q@051HA01<F3`0B5@h0
4A@=018E3P0E614200hA2P09014D3@0C5Pl04aH?00lB2`0B5@h03a8;018E3P0G6Q<051L@00804aH?
01@05APA01HI4P0C5Pl04QD>01DH4@0Q9R005a`F018G4@0?50h041D?01PM5`0;40X061dG014F400F
6aD05AXD00/@2@0G71D05Q`B01<I3`804QL@01<03a@=01HK5@0E6QD05AXF01HK5`0D6AD04AHB01LM
6@0Q9b<05adI01DK5`0F71P05adI00lE4@0I7a/04QPD01PN6P0G7AT06AlK00805adK100F71X00`0J
81h07R@R01PN700201PN700X01hW9@0F8B805b<S01PT900E8B405b<S020/;00I9BD082`/04=?C`0]
>CT04QhN02Da<@0O:b/07B/[020^;P0R<3007Bd]01XZ:P0S<SD07c4c01h`<P0O<CD08C<g028d>00Q
=3P0:3/o02Lj?P0Z?D408cHj03]>DP0iC500:ci202Hi?@0/?d<0=DQ<03=7BP0[@4<0;T=602e2A@80
:d1300<0;D9502i3AP0`ADP00P0aATT01@0`ADP0<4E90397C00dBDh0=daA0080=T]@01P0>TmD0315
BP0mDUL0AEYO03U>D`19GV<0LX:808JAU`1CGfD0A5AI03Q<D00lDUD0>eAE03UCE00iDE<0BUmR04EJ
G@0oDUH0?4mC03iAE@10DeL0?U9C03mCE013EeP203iBD@0P049FE@11EE<0?E5?03iBD@0eBT`0?55E
03eBEP0nDeL0A5UK03Y?D@0hCT`0?59@03aBCP0iD4/0?eI@04ELEP0nEDh0?eI?049HE@12F5L0BUmP
05EZK@1:Gf@0@eQL04YOH@1CJ6X0AU]K04ILF@0oEE40DVUS05Q_J@17GUP204QOF@0804YQF`1<Hed0
CFAN04eTGP1<Hed0BV5I049ID014Fe4204IMD`1:04IME014Fe<0B5mG04MNE`17GUP0BV1M04aRG`1;
HEh0@eQC04EJE01;H5L0?eA;041FB@11F4P0?5=303Q?@@1?IET0KhAm049GD@15FEH0BEmM04]QGP17
GUP0@EQA041GC@0oET`0@UU?049ID@0iD4P0?UAA03eCD@12F5D0>eA?045HDP0iD4X0>U5;03M<A`0m
DTd0=da704EHE00fBDD0@5=?03Q;A`0aA3h0=TLn02`m=@0`@CT0<d@l05Y[I@0eAT008S<]02Lg=00X
>3D0:c/h0392@@0V=S<0:SXa02hm=P0V=Bh07bhW028a;00U=2l0:CPc02Lf<`0c@Sl07B`Y02<a<@0T
<Rl08BdY02@`;00X=3008BdY01l[9`0R;RX302<_:`0L028^:P0Q;BT08b/W02<X900Q:2408RTQ02<Z
8P0O:B007RPP01lZ900T<2`0<3`m02<^<`0O;3<07RHX02L/:00P9280724M020U8@0I7Q/061`J01HK
5`0L8Ad06QlL01lT800N8b00828Q01hP7`8071hM00d06adL01TK6P0K7A`06Q`K01HH5`0G6AP07R0O
01/M700F61D07b4N01XL6@0?4@h05aTF00806Q`I00l0418?01TK600B51407AlL01@F4`0L71X0410>
028R800D51805ADC01@D4P0U9B<04a<A01TI5`19BDL00P0D5180100B4Q004a<A01<C4@0D518201DE
4`0A010@3P0>3P`04A4?014A3`0?3`d04Q8@014@300C4Pl061LE01LF500@3`h04@l@028P8@0F51H0
3P`?01`J7@1:B4`00P0E4aH03P0C4A804Q0A01<A4P0B41403`d>00h<3@0C4A804Q0A00d;300>30d0
4Q0A018@4`0@3Q403`d@0`0>30l03@0=2`h04@lB00l=400=2`h03`d@010>4@0:2@T05aDF038`<@0V
92D02@L800l=3P0>30d00P0<2P/200d;300300h<3@0=30X03@`:00@03@`:00L040l>01`K6P19B4H0
4a8@00P71P0B40l04Ph?00804@d>00D04Ph?010<3@0>2P/04Ph?00/8200200l;300301<?400>30d0
2@T900<030`<00T040h?00`:2`0>30d03PX;010<3@0A3@h04@/=00l:300>2P/00P0?2``03P0>2P/0
3@T:00h:2`0?2``03PX;00d92P0<20T03`/<00d;2P0:2PP03@/900`61P090`<04@P90P0@1`P01`0@
2PX04@d<00h=2`0:2PP03`X>014<400=20`00P0A31005P1ED5@050lC00d8300;1PX020@700X52@0?
2Ph030H700h8200?2@X03@L800h8200C3@d04P`=00d71`0:10D040X;018<300>20T03`T;00h82P0=
1`T200l92`0C00d72@0910D040X<00T31@0C3@l04@/=00`7200;1@L040X<01@>400A2`d03`T;00X4
1P0;1@L03@L900/51`0910D02`D7010:300Dooooo`006oooool01@29Ti@092d_00TA4`032`d02@hA
0080314D100=4A@03@0=4A802Ph?00`@3`0A5A@0004001<G5P0@51<01`/:00`@3`0:3Pd0310?00hB
4@0=4A000P0?4A02010B4@0Q00lA400>40l0418A00d?3P0<3Pd03a4@01@F5@0F61L02P`900/=2P0<
3P/03a4>02d_;01jO7T030h;00T;200E5a@03@l<00D7100D5Q<02@h:00P=2@093PX051HC018D4@0A
4a004A4?014@3P0=30X03Pd;010?3@0?3`X03a8;00803a4<01803Q0;00d?300<3P/03@l<03<e=00`
<S4030h=01lQ8015Ad@051HA014C3P0D5Q403Q0;00X<1`0>40/03a4<00h@2`0<3PT200/=200700lA
300D5A004Q<>00h?2P0@4@`04Q<>014B3@02018C3P04010A300>3`X03Pl:00/<1`803Q0;00T00@<0
00L9100C5A003a4<01@F4@0M7aX03@l:00@60@0D5Q40100?4@`00`0=3`X030h9010B3@02010B3@0D
00lA300>40/03@l:01@F4`0B51403a4>00D7100D5Q<04A<@00lA3P0B51405ALD00lA3P0;3@X03Q0<
010A2`0E5Q0061TC014B300=3PP200l@2P0i010A2`0B4`d0414;00d>200C50h051HA01<E400^<2/0
Kg5/018D3`072@@0DUA?0453?P0H6QD07b4L00T;1P0<3PT03a4<00h@2`0=3`X04aD@00d?2P0F61<0
4aD@010B3@0>40/02@/6018D3`0F61<04Q@?014C3P0E5a804A<>01@F4@0W:B@01@H301HH4`0@4Pd0
2`d801<E40041`0051D=018C2`0D5@d06Q/E018E3P082`@04Q@?00lD40042@D0CU=?0;Jl^00]<bl0
41<=010C300?4P/03A09008030l802004QD>00D80@0G6Q<05QTB00d@2@0I71D05QPE020R7`14AT<0
JVaY00T;200A4a005aTF00/=2P0=3`d030h;00d?300M7a/05ALB014C3P0E5a802@/600L9100D5Q40
418=00d?2P0?4@`04Q@?01<E400C50l03Pl:014B3@80414<00`05AHA00l@2`0C50l0414<00l@2`0@
4@`03Pl:014C300?4PL03a89010C2`0A50d2014C3P0M01DG4P0O8A`05aXB01DH3`0B5@X030l600lB
2`0@4`X03a87010C200C5`T04aH;01DH3@0<3`P05aTF00<50P0?4@l05QPC01@G400B5@h04A@=018E
3P0E61404QD>010C300?4P/041<<014D3@0@4``00P0F6A805`0D5a004aH?01DH4@0F6A804QD>01DH
4@0G6Q<04QD>014D3@0E6140?T<m02T^:00E6Q@041D?014F400;40X02@h802@Y8`0H7AL02@h801HK
5@0@5@h04QL@00804AL=00D05AXC01PM5P0H7AH06AhH01LL5`0201DJ5P07018G4`0=4Ph02a4=01HL
600M8al05adI01TO6`0201@J5P0N01DK5`0?5A406b4M01hT800M8al06AlM01PN700F71X05adK01TO
7@0J81h0728P010F500N92806R0N02`b<00P:BH072LW01PT900M:BT0:3@d01TU9@0M:BT072PX020/
;01BGUh0<3`l00TE5@0T<3008Rh^0P0K:BT04@0N;2`07Bd]01`/;00R<C@08C<e028d=P0S=CT08S@h
024c=`0Q=3X06Rdc01LZ<00W>T00<TE;03Y=D`0S=S`09CPn0080;D1600H0;3m502e1AP0`ADP0=T]>
03E:C@0_A4L502i3AP80;45400<0;dA80397C00cB4d00`0cB4d0?@0^@dP0A5UN0356B`0eBTl0?55F
02a1AP18FEh0=dE805i/K`0mCU00BUiO03Y?D00cBd/0@EUI03mGE`18GEh0@EIG03]?D00gBTh0>TeA
041DE@0oDe@0@5AE04EIF00oDe80@EED045ED`0mDDl0?U9@041DDP0lDU00?E9C041EEP15FU/0AE]I
03iDDP0iCdd0@EME049HEP0lDU00?eEB04MMFP1?IF80@EMD04MMF`17G5d0AEYM04eRI@18GF00E6U/
05Q^K@1DJVL0DVUS04ELEP1DJfD0AeiH04YQF`1>IEl0EFaV049ID`1:HE/0101;HU`07@1;HUX0AEaB
04EMD014G4l0AEaB04MNE018GeD0AeiF04IMEP16GEL0BF1J04YQF`18GeT0AEYE03iCC@17G5<0@EI=
03mEB00lDTD0;dDh03]AA@16G500<4Dn04MLEP0aAT40AE]I04EKF015G5H0@EQA0080?UE;0300@EQ>
045HD00lDd/0@UQE03mED`14FUL0=Tm:04]RG010Ee40=Te704=HD`17G5L0AU]F03e@C024Ui<0//G1
03M:AP0nDD/0=dPo03M8@00a@SX0<T<k069cK@0/?CL08c@^02De<P0V=S<0<d=0049BD@0fAT<0:SXa
02Lf;`0V=Bh093</024`:`0L:bH09C@_01@S800a@3d0:STf01XX:00M:bP07BTU024]:@0S;b/07BTU
01l[9`0T<2`5028^:P0n01hX8`0J81`06R4J01dV7P0P:R808B/S020Z8`0M:28082/W020[;00S;S80
51lU02T`=00K7ah07b<T01`P800R9RD06alO01dQ8P0L81l061`L01/O800I7A`061`L01`N7@0O8B00
61XI010B4@0E5aH061XI01LI600E5aH06adL01LI600>40l071hM02PZ9`0d=S<0:bdZ01PJ5`0J71T0
5ALD01hP7@0C5A8051HC01HH5@0G6AH051HC02h^;00G5aD04a<A01lO7@0H61H03Ph<010@3P0?3`d0
2PX802PX9P0@40h05QHD01<C4@0G5aD201`L6P0401XJ600F5Q@04a<A010@3P804Q8@00X04A4?01HF
500L6aL04A0=00d<2P0<2`T03@/;01<A4P071@H05A<E0P0G5AP01`1JF5`05Q@G010>4@0?3@h040h?
014?400@3Pl00P0<2P/02@0B41404@l@00/92P0=2``04@l@018@4`0@3Q403`d@00h<3`0300d;3P07
00`:3@0>30l04@lB018@4`0D4QD030X;00D3100200P61`0300/92P0C4A803@/<00802PP90P0=2``0
0`0;2@X03@`:00d<2P0400d<2P0901<B40040`400@0001@C4@0;2PP0518A010<3@0>2P/03@T:0080
30P900`040`=00L3100K5aP03`/<028N7`0<20T04@l@00<30`020P8030`<00/;2`0;2@X200`:2`05
00d92P0?2``040`=010:300>2@X00P0=2@X01@0<20T02PH700T51P0;1`P03@T:00802`L800L030P9
00d92P0;2@P01@@202HR8@0_:BT04@/;00<03`H701l03PP800`81`0:2@L02`X800T4200A31003@P<
00h93@0B3A402@D801@?4`080`L03PT=020K7`080`L02@@800/52@0=1`T03PP;00`62P0>20X05a4D
01H@500@2P`03`T<01<=4@0A2`d02P@700l92`0>20X03@L900803`T;00@03@L900h82P0@2P`02`D7
0P0<1PP03@0T7R00:B<U00H10P0?2@/03@L900T31@0400002@<500h82P0C3@l04P`>00l92`0=1`T0
5?ooool001_ooooo00L051hO0003100D71h01@d?01DK7P011PT03A8E00@03Q8E00d03Q8C01LK6P0;
3`h03A4@01HJ6@0B5QD04ADD00dA400>4Q402`l>00hB4@0?4a802Ph=00H03a4@01H0418A00`>3@0:
30/03@l>018D4`0E5aH0;c4^010B3`0?4@h02@/800d?300k?CX0418?00lA3P0F61D02``:010B3`09
2`P02Pl;010E4@1DFED0DeEB0P082PL01`0D51804a8@00h=2`0?3P`04A0>00l?2`0?4P/00P0?4@`0
300=3`X030h;00h@3@000@003@l>00lA400A4a804Q@C04a>B`0>40/02@/600lA30803@l:00X03Q0;
00/=200;3@P030h900d?2P0?4@`051D@018C3P0<3@P03@h90P0C50l200l@2`0?010A300>3`X030d8
00d>2@0>40/05ALB00d?2P0:30L09BLR01`N6@0K7AP051HA01LI500<3PT01`T400<03a4<0`0>40/0
1@0=3`X02`d800`>2@0?4@`0418=00804A<>02@00`D200T;200F61D02P`900lA3P0=3``02P`900h@
3@0D5Q<03a4>00/=2P0C5A404Q<>01@E3`0E5Q00414;00l@2P0@4@/03@h800/<1P0?40X0414;00h?
2@0A4P`05ALB00d?2P051`806adH014C3P0?4@`061XE01<E40041P404A<>00lA300F61<200d?2P0R
00lA300F61<03Q0;01LI500<3PT04aD@00/=200:30L03@l:0084000>40/03@l:010B3@0?4@`03Q0;
01DG4P0O8A`05aTD018D3`092`H04A<>00lA300A4P/02@X200X;0`0B4`d04A@=00hA2P0<3PT0314=
00lD401DFED0bm7=04I=AP8041<<01d03a8;00d@2@0<3`P03A09010C300?4P/0;2lX00T<1@072P<0
2@`500d?2`0E5a@07AlL04e?C0010`00418?00D7100U9b@0F5YG028T8@031@802@/701HH4`0>40/0
2`d800`>2@0;3@P061XE018D3`0200h@2`803a4<02L0418=00h?2P0B4`h03Pl:010A300D5A0030d8
00l@2`0@4@`051D@00h?2P0<3@P04aD>014D2@0A50/04A@<010C300@4Pd05aTD0001000=40T03a8:
00L:0@0A4`h030l8010C300A50/03Q46014D2@0C5`T030l401@G300A50d04aDB00h@3@0@4Q005ALB
01@G400B5@h00P0A50d0100C5Pl051L@018E3P0@4``2018E3P0:014D3@0K7QL03A09018E3P0G6Q<0
2`h701PK500C5Pl051L@01DH4@804aH?01T05APA02L/9P0H7AL041D?01DJ500C6180314;01@I4`08
3@L02a0:01PM5`0M8Q`02a09018G400B60h04AL=018G400E6Q<05a`E01DJ500D6A@051TE01DJ5P0D
6AD04AHB00805A/G01806R0L00lE4@0F71P05Q`H02D[9`0O9B404ALC01TO6`0F71P03aDA01XP7P0I
7ad061hL01TO7@0K8Al0728P01lU8`0A5aD202P^;00?0457A@0_>3D06RDT010L700L:2P0A51@02Da
<@0D8200930`024];@0W<c<07BTY01XV9P0R;Rh082`/00806BLW00`07R`/028b<P0S<c<07Rd`020b
=00R=3H08cDi020b=P0O<CD07S4g01lb>@0U>3h202Pk@P0C02e0A`0R=C/093Ln02/nA@0Z?D<0:Ca3
02e1A@0`ADP0=4U<03I;CP0bAdX0;dA702e2A@0[@4<0;45402i3AP0`ADP0<DI903=8C00303E:C`80
=4U>01@0=DY?03]@E@0W?440:d1503Y?E00/@DH0<45504aKGP2ga/T0BeiP024e=P0cB4T0AUaM03]C
D`0aBDT0>4e>03U>C`10E5D0>diB03e@E080@5AE00`0?e=D045EE00nDU40@EED03mCD@0jCT`0>dm=
03eAC`0jD4d0?eEB04ILFP0oEE<203I<BP0H049HEP18GU`0B5iL049HEP15FeT0C69P04QNG00oEE<0
@eQH04aQI017G5l0E6U/04AIG01=HV<0CVAQ04UPFP19H5P0?eI>04YQF`16GEL0D6MQ04]RG01<Hed0
BV5K0`1<Hed204]RG00P04]RFP18GeD0AemB04EMD015G580AeiD04UPEP17GUH0AEaE04AKE@16GEL0
B5mI04MNF01<HE`0@EI?04YOEP12Edh0>U140398>`0lDTD0@UQ<05=XG`1GK6<0CF9K03M<A`12F5H0
@EMD04AKE@12FE80?eI<041GC@11F4h203mFCP0L04AJE`14FUP0DFMT03iGD@17GUP0Bf9L041GD@0m
DTd0=DY503]@B`0oDTh0RYfI0;K9a@0_@Sh0<D@n03U:@@0cA3`0>T]301h_9`0R<bd02Q/E02<d;P0T
=3408c<`0310?@10D4l0<D4n02Xi<@<08S4Z00d07B`W01l^:@0S<Rd05RDR03Q7A00U=3407B/[02Hc
<@0R;RX08BdY01l[9`0H92006bLS00808RhZ00P08BdY020/:00P;2P082`X024[9P0O9B407B@M01dV
7P807bTQ018072HO01TT800J92<05b8Q020[;@0E82@082L[014E5P0E6AX07B4R01DI6P0M8B806QhO
01dQ8P0G6a`0720Q01PL7@0I7Ah201lQ800T01XL6`0E5aH05aTH01HH5`0H6QT05aTH01dO7P0K7A`0
4aDD01/M700D5Q<07AlL01`N6`0D5Q<05QPE01<E4P0G6AH04aDB01DG500I6aP0418?01HH5@0S8b40
7QhL00l?3@071`D05QHD01<C4@0B4Q005QHD00`<2P0@40h04Q8@01HF500?3`d051@B0P0G5aD0100C
4a403`l=018B400?3`d2018B400C014A3`0E5A<05aHB010?300B4@l051<A01<B4@0E4a@01@<401DC
5@0>30l01`D801<A5@0B41<040hA010>3`0B41404a4B018@4@0200d;3008014?400@3Pl030X;00d;
300?3@h04Q0C010>4@0?3A0300h<3`0400l=400:20/03@/>010>4@8030X=00`02`T:01LE5P0C4A80
5Q@E018@4@0610D040h?00d;300?3@h04Q0A00l=3P0<2P/600h=2`0700`;2@0D4a402`X800L6100G
5Q@02PP800l;300200d92P0H00/7200A3@h07a/L00<0000?2``07ATJ051<C@0H51D010<301@D500?
3`l02@T900d=3@091`P03@/<00/92P0<20T03@T:00l;300?2@/040/<014=3P0?2``03@T:0P0;1`P2
00d92P0=00`82@0=2@X03PX;00d92P0=2PX00`8001lK6P0Z92@03@L700l71`0?1PL040L800l72002
00/71P0=00/:200>2P/05A0D018=4@0?2Ph03@P<01D@500>2@d020<701<>4P0Z9BT03`X>00d83002
010:3P0;00h8300;1@T030H:014;3`070@D02`D900l93@0>20`030H:00h9300@2Ph00P0>20X05@0?
2@/040X<00d72@090`D01`8301/E5`0C3@l04Pd>06IPHP1lMWP05@lA01TC5@0L5QP040X<01D?4@0:
10H02@<500L10`080P@02`D700h82P0Dooooo`006oooool01P0740l031DD00dF5@083@d03A8B00L=
3@<0310A0`0>3a400`0;3Pd03A4@01DI600200hB4@0400`@3`0A5A@03A4@00dA40806AdL00P04ADD
014C4P0>40l03@l>00h@3`0@4Q404Q@C00d?3P<03Q0?0P0=3`h02@0G6AH03@l<00lA3P0A4a00418?
00d?300@4Pl02@/800d?3002014C400O00X<2@0>4`l04aPD030e<@0f>SL0418?00lA3P0F61D05ADC
00l?3@0@3`d04Q4?014A300A4P`04A8=010A300>3`X03@d;010@3P061P@05ADE00l?3`0<30`03`l?
024R800G6A@030h900h@2`0:30L02`d800h@2`0200/=200600`>2@0=3`X03a4<01@E400B4`h03a0;
0P0B4`h00`0?40/03@h900l@2`02010A300900l@2`0@4@`0418=01DG4P0<3PT07AlJ05=ED00Q8Qh0
7b4L00803@l:00D02P`700lA300@4Pd03a4<00h@2`0200d?2P0400h@2`0A4`h03@l:00h@2`@0418=
02l0Ce5>01hP7@0>40d061XG018D4@0=3``03Q0=00X<2@0>40d0418?00/=2P0=3``04Q<>014B300>
3`T03@h800l@2P0@4@/061TC00l@2P0B4`d05QLA01<D3P0?40X0418=00h@2`0;3@P03Q0;018D3`09
2`H030h900d?2P0@4Pd03@l:00h@2`0<3PT03a4<00h@2`0C5A006Q`G00`>2@0D5Q403a4<00d?2P08
2PD04A<>010B3@0200lA300400`>2@0?4@`04A<>00lA308030h901H0418=01DG4P0>40/04Q@?00lA
300@4@/03@h801HG4@0O81X05QPC00`>2@0@4Pd02@h8014F400?50h08bXS01/R6`0>4@X041<<00lB
2`0=40T03Q4:0P0@4``00`0]<2X0FUeF01<F3`02014D3@0601<E400@4Pd02P/801<E400F61<051HA
0P0@4Pd02P0K7AT030h900d?2P0E5a803@l:01@F4@0C5A002@/6010B3@0A4`h2010B3@0@018D3`0C
5A00418=010B300@4@/04Q<=00l@2P0H6A<08B8L01PI4`0I6Q@051D?010A2`0C50h03a0:010B2P80
4aH=01P04QD=010C300?4P/03A09018E3P0A50d041<;01@G3P0@4`X041<<01DH4@0C5Pd03A0500lB
1`0>4P@05QT>00/>0`0A50d0418?01TK600D5Q@04Q@?01<F3`0B5@h2014D3@0;010C300D5a0051L@
01LJ4`0H6a@05aXC014D3@0F6A804aH?00lB2`0B5@h00P0D5a000`0F6A8051L@01<F3`0201HI4P07
01@G400A5Q003a@>01hS7@0B5a403a@>01DJ500201HK5@0L01@I4`0I7QP04QLA01LL5@0D6A805adC
01DK4@0B5a005Q/D01dR6`0F6aD05AXE01DJ5P0F6aL051TE014F4P0I7a/051XF01dS7`0=4`l05adI
01HL600A5a<06R0L01@J5P0K8Ad061hJ01LM6@<06AlM01H06R0N01/Q7`0K8Al06R0N01TO7@0L8R00
7R@R01lU8`0K92408B`[01dY9`0@71X0;CTg01hZ:00J9R@082`Z02<_;@0D81h07BTW02Da;`0O:bT0
82`/0P0Q;bl0600P;Rh08S8b02@d=00R<C@07c4c020b=00R=3P08cDi02@e?00T=cl09SQ203A6C`0Z
?DH0:Sa602/mAP0Z?4D0:C]502/mA`0[?DH0;d5;03E9C`0aATT0;T=602m4A`80<dQ;00X0<DI90315
B00`ADP0<TM:03A9C00eBTd0=T]?03E:C`0dBDh0<dQ=0P0bAd`04P0dBDh0;dA903Q=DP0cB4d0=DY?
049GG010DeH0=4M805e_L@10DeD0>De>03aADP0fBd`0@5EF03iCE012EUL0?e=D03iBD`80?E5B02<0
?U9C049FE@13EeH0@5AC04AHEP19GE/0AEUG03mDC`11EU40?eA?045HDP14FeD0Bf9M04AJE`0lDTl0
AeeJ045GE@15FeT0@eUG041EEP15FU/0C65R04YOH01HKFh0A5UJ04]PH`1AIVT0G75d05=XJ@1AIVH0
CF=O04QOE`1@Ie`0GgI/07R?Q`0204iUG`0;051WH@1=I5h0C6=M051WH@1?IV00CFAN04aSG@1;HU`0
Bf9J04IMD`18H5<00P19HE@0C@16GU80@eY@04YQE`16GE@0@eYB04ELEP18GeT0BF1I04YOE`16Fe80
D6EL04=HC`0dBCh0<DLk03mEB@1aQg`0BEiE045FC@12Edh0A5UB04=IE`11Ee@0AEaF04AKE010Edd0
@eY@045HCP0oETh0@eYB045GE01;HEl0KXB107:;Q00kDTX0@5M?03aCB`10EDh0?eA=03eBB`0aA3h0
=dY404AGD@0jCDL0<DDm0393>P0`@CT0<D8j02@e;@0S=2h0<d@n02@e;`0Z>SL0:CTf03=3@00kBdX0
9SHc02`l<`0X=c008S4Z01d/9@0M;2L072/V01LV8@0V=C808C0]045@C@1SLG409S<a02@`;00Q;BT0
82`X01/W8`0L:2@08RhZ02<_:`0Q;BT07RXV00807BTU01T092lZ02D_9`0P:R807BHP01lX8`0P:B@0
8B/W02Pc;`0H8R409S0`02La<P0P:R`07B@W05QLG`12ATT061`O01lS9P0I7B006QhQ024U:00H71l0
7B4T01@H6`0J7R007AlN00806adJ00X061XG018D4@0F61D05ALD01TK600C5A809RPU03do?00V:2D0
6A/H0P0F61D201LI5P0:01TK600G6AH051HC01TK600M7a`03Q0=01@F4`0C4a406ATG01<C4@8061PF
00/04Q8@01HF500B4Q0051@B01<C4@0E5A<0410>01DE4`0C4a404A4?00l?3@02010@3P0L014A3`0@
40h04a<A01<C4@0A4@l04a<A01DD400A40d05A@B01LF500C4A404@l@01dK700@3Q004a4D01HD5`0B
41@03P`?010>4@0A3a004a4B01DC500C4A803`d>010>3`0?3@h03P`=00l=3P803@/<00@040hA00l=
400>30l03`d@0P0@3Q401P0?3A003P`?018@4`0>30l02@L:00/930803P`=00X02`T:00`:2`0=2``0
2PP900l=3P0>30d04@l@01DC500?3@h02PP91P0>3@/0900B4@l030/:014@3P0>3@/02PT801LE500?
2``040`=014=3P0B3Pl081`M01dI6P0@30d05A4B00h:2`0E4A8040`=00/92P1GEeL0C4a<00X:2P0C
4a<02PP900/92P0<2P/030P900h:2`0?2``03`T;01@?400F4Q<04Ph?00d92P0<20T03PX;010<3@80
3`/<01004`l@01@@4@0@30d03P/;00X91`0;1`H03`L800l61`0B20T03`D601892P0F3Pl04Pd<00l;
2P0=2`T02@D60P0?2``0600;1`P02@D600l;300810D05Q8C00h:2`0G4a@04Ph?00h92`0@2Pl03@H=
00/42`0=1Pd03`P?00h73P0=1`d05PlF0109400500D04@`A03hg?P0@2Ph03`T=00h8308040X>00l0
3PP<00h9300C3A406A<G01H@500=1`/0:bDY03<];`0=20T04@/=00L20`0A2`d02P@6010:300?2@/0
0P0>20X00`0=1`T030H8ooooo`0Cooooo`006oooool06@0:4100318B00dC4`0=4a<03A8C00dA4P0C
5aP02`h?00`=3`0>3a404Q8D01LH6P0>4Q406AdL00H:2@0@51<02Ph=01@H5`093@`05ATH00hB4@07
2`X06AdL03Di>00A4a800P0?4A002`0@4Q403Q0?00`>3@082PT06adL00T;2P0A4a805aTH00L9200?
4@h02`d:00802@/800l030h;00h@3@0>40d01@L4020R7`0@4Pl08B<P00d?30093@X0318>01TO6`03
20@041DA00`A3@0?4@h00P0>40d200l?3@0F01<D3`0C50h03a0;014B3@0E5Q405QHD018B400A4@l0
4Q8B00d=3@0:2PX03@d=010A3P0B50l08B<N018D3`0:30L01`T400lA300>40/0418=00lA30802`d8
00<03Pl:010A300>3`X0100=3PT00`0>3`X03a0;010A3002010A300300h?2P0?4@`01`T400803Q0;
00L03@l:010B3@0?4@`03Q0;00`>2@0=3`X03a4<00803Q0;0`0@4Pd0200?4@`03@l:00h@2`0;3@P0
3Q0;01@F4@0:30L0418?0P0A4a000`0>40d030h;00d?300300lA3P0700d?300<3P/02`d:00l@2`0;
30L0414<00P9100200l@2`0N010A300A4Pd04A8=014B3@0@4@`03Pl:01HH4`0?4@`030h900d?2P0?
4@`03@l:00h@2`0@4Pd030h900X<1`0<3PT03@l:01XL5`0Q8ah030h9018D3`0=3`X04A<>00X<1`0@
4Pd03@l:00lA300E5a80418=0P0=3`X0<P0?4@`04A<>010B3@0<3PT04Q@?010B3@0;3@P030h900d?
2P0;3@P04A8=00d>2@0<3@P0414<00d?2P082PD03@l:00hC300=4P/0314:00XA2@0;4PX041<<01<F
3`0B5@h02Pd6018E3P0?4P/04aH?00/>1`0=40T030l801PK500@4``03Q4:01HI4P0?4P/03Q4:010C
300;3PL04A@=00hA2P0=40T03Q4:010C300?4@/04A<>01<E400>40/03@l:0P0C5A002P0G6A@02`d8
01HH4`0@4Pd02P`7014B3@0A4PX03a0800h?1`0?40P2014B2P0<01<D300G6100414900T:0P0<3@D0
2P`500hA2P0D5a004A@<00/>1@0>4@P041<:0P0A50/0300<3`L04QD>010C300>4@X03a8;01@G3P0G
6Pl05AP=014E1`0D5``04aH;018E3P804aDB00<04A<A010B3@0@4``00P0A50d2018E3P0;00hA2P0E
61405QTB00hA2P0?4P/04aH?01HI4P0?4P/071lH01HI4P0C5Pl00`0D5a002P0E61405QTB01LJ4`0I
71D03A8<00`A2`0E6Q@07b@N01<H4P0@5@l201@I4`804aPB01@05AXD01HK500D6A8051X@018H3P0B
5a006QlH02@Y8P0E6Q@05Q/F01<H500c>3@051TE01TN6P0F71P04ALC01HL600I7a/05Q`H01DK5`80
5Q`H01T05A/G01HL600G7AT05adI0457A@1LHV006b4O01LM6`0P9R@04QPF01PN700R:2H08bTW028X
9P0Y;bd0;SLd01lZ:@0V<S005R8P01DQ7`0K9bD082`Z01l[:@0N:RP082`Z0080930^01X08bl]01hZ
:P0T<S807R`/01/Y:@0S<c<0:CTi03E4A`0Q<cD08cDg020b=P0S=CT0;d17028e?@0`@T`0;T1:02<e
?`0R=3h0:Sa603A6D00Z?4H0@E=M02Dg@@0Y>dD0;T980315B0<0<TM:00X0=4U<03I;CP0dBD`0<dQ;
0397BP0dBD`0=T]>03Y?D`0eBTl0<DI;0`0dBDh03`0gC540>e1E03mDF@0jCe@0=4U>03I;D00kD580
=de;03Q<B`0mDE00>dm>03eAD00nDU40>dm>03eAD00303mCDP80?U9A00<0?e=B03eAD00mDE000P10
E5804`0kCdd0@eQC04QMF00oE4l0@EI?03I=A`14FeD0AEaF05I]I`1>IEl0?UAA05ecL01?IF80A5YH
04QNG019Ged0AeeK05abL01NM7800P1?I6D0?@1=HV<0D6EV05=XJ@1@IV@0DVQT05=ZHP1?Ie/0DVYM
05U`J01:HE/0HGQb06V0NP1CJV@0CVEO05=ZI01;HU`0BF1J04ELEP1>IEl0AEaD04ALC`17Ge40BF5C
04QPD`14G4l0@5Q;04QOE@12FDl0@EQ>04UPF01@Iel0BV5I05AYH00oEDX0D6EL03M<@`1>HeX0Ni27
03aAB010ED`0@eQ?04AID017G580Bf1G04EKF017GEX0BF1J051WH015G580AUeC04ELDP15G5@0AeiF
04YPG@19Ged0B5iK04ENE`12FE40?UE=03M>AP11ETl00P0lDDX0@@0dAd40<TDo03A7@@0bACl0;d<j
0393>P0]?SH09SL_024b:P0U=S00:S/e02Pi<`0U=C80:c/h096QWP2Q/K00=dM402hm=@0_?SL08S4Z
02He;P0X=c807bhY01XY900L:bP09C@a02Xi=P0X=SH0:3Dc02`h=00Y=C407RXV01`X900P;2P08RhZ
01l[9`0N:RH06bLS01`X900P;2P08blY020[8`0N:B<07bXU01hY9@0Q;2P08bd[02</:`0U;Rd08b`[
01hW9P0L9B@06R4R01lS9P0V:Rd061`O01lS9P0J7R407B4T03a0@`0_<cH0:Rha01hR9@0J7R006adL
008061XG00D06A/H01HH5@0H6QL051HC01`N6`02020R7`0H03Li=P0S9B805ALD018D4@0C5A8071hK
01dO700D5Q<04A<@01PJ5`0D5Q<06A/H00d?300D5Q<0820N02<S8@0L71X05ADC01HF500B4Q005aLE
010@3P0>3P`04A4?0P0B4Q003P0=3@/05aLE01PH5P0B4Q003Ph<00l?3@0@40h05ADC010@3P0<30X0
3`l=00d=2`0>3@T040l<0P0A40h0700@3`h03P`=00h<3@0>30h04Q0C010>4@0=2`l04@lB01@B5@0G
5AH02`T:010>3`0F51D02PP900/92P0A3a004Q0A01DC500Q7b000`4201<A500>30l02PP;00`:3@0?
3A003P`?010>4@0J61/2014?4P0800X82`0C4A@030X;00/92P0E4a@03`d>00/92P071@H2014?4004
00h<3@0:20T02@L800X82@802@P601002`X8010?3@0?3P`03@`:00/:200O7Q`00@00010?3@0<2`T0
2`T801TE5P0=2@X040`=00P41@0R7Ql02@D61@0>2P/0200<2P/04Q8B01LG5`0@410020P800`:2`0?
3@h030X;0`0>2P/0=`0?2@/04Pd?014=3P0>2P/04@d>01<?400?2``03@T:00h:2`0;1`P04`l@018>
3`0;1`P0<2`/024M700F4100;B@U01H=3P0@1@H04PH801882@0J4A805a4A00`81`0;1`H02@D601@@
4@070`@0BdM802hZ:`0V8R<03@T:010<3@0n>S/06QHG00X61`091PH03`P?00/42`0=1Pd04P/B0109
400A2Q402@89014:4@090PT0204802TR:@36_lH04@/?010:3P0>20`030H:00d72`0>20`00P0@2Ph0
2`0?2@d04`dA00P31P0=1`/01@0100l92`0B30h01P0201@>40080P@03`T;008040X<00<03`T;00`6
200:10H05?ooool001_ooooo02402Q0@00/A4@0<4Q803A<C00lD5@0@51D0720Q018D5P0>3a403a0B
010A4`0E5QP03a4@00dA40072`X05QXI00hB4@062PT03Q8A01hR8@0L81l0310?00H:2@0E6AP03@l>
00h@3`0?4A00418A00`>3@0;3@`051HE0001000=3`h00P0>40l00`0;3@`03a4>00`>2`0200/=2P03
00d?300>40d061XG00801@L402H02@/801LI5P0320@02a4=01`R7P27SHT0724M00D:1P083@T0418?
00h@3@0=3``03`l=014A3`0C50l04A8<00h?2P0?40/04A8=00l?3@0;2`T020P600/;2`0=3@d030`<
010@400B4a0020X501dO6P0;3@P09bTT00L9100=3`X03a4<014C3P0@4Pd03@l:00`>2@803a0;00@0
3Pl:00d>2@0=3PT03@h90P0>3`X03@0?40/0414<010A300?40/03a4<00d?2P0<3PT04A<>00P:1@0;
3@P04A<>010B3@0>40/00P0<3PT01@0=3`X03Q0;00lA300?4@`0418=00<03a4<00/04Q@?014C3P0D
5Q4061XE018D3`0<3P/02P`900P:1`092`P03@l<01<E4P0200`>2`@03@l<00L04a@?014B3@0G61<0
30d800l@2`0<3@P04A8=00<04Q<>00L04A8=00l@2`0B50l03Q0;00`>2@0?4@`04A<>00803a4<0140
51HA01DG4P0B50l03a4<00`>2@0>40/051HA00X<1`0<3PT03Q0;010B3@0D5Q403a4<014C3P0N81/0
7b4L00X<1`0200d?2P0A00h@2`0@4Pd0418=00d?2P0C5A004Q@?00h@2`0?4@`04A<>00h@2`0?40/0
3Pl:010A300A4Pd0418=014C3P0>40/00P0>4``02@0=4P/02a8:00`C2`0<3`P02`h701@G400Q91d0
71lH00T<1@0200P;100501@G400@4``02`h700/>1`0=40T00P0;3PL2014D3@0400/>1`0@4``03a8;
00hA2P803a8;00L030l900X<1`0;3@P02`d800`>2@0>40/04A<>00803Q0;00D04Q@?00/=200B50l0
418<014B2P03010A2@804A8:00H06Q/C01DF3P0=3PH04a@<014B2P0B50`201@G4009010C2`0?4PT0
51L>01PK4P0E60l04QD<01<F3P0G6Q<04aH?008041<<00`03a89010C200?4PL03Q84014D2@0@4`P0
3Q4:00lA3P0@4Pl03Q0>010B3@0@4``2014D3@804QD>00`03A0901@G400D5a003Q4:014D3@0E6140
4A@=01<F3`0:3@H030l800X=1P0M81T201@G400C01DH4@0F6A805aXC01TL5@0F6aD061dG00X?2@0<
4@/061dG00L<1P0D6A<04QLA010E3`0A5Q0051TC01HK500G71D05Q`B01DK4@0201LL5@0=01DJ4`0=
4P`051TD014F4P0I7QX082DQ00hC3`0G7AT061hJ024W8`0S:BD061hJ00lE4@0201@J5P804aTE00T0
5A/G01LM6@0J81h0<3Hd01TO7@0J81h08BLU01lU8`0J81h00P0P9R@02@0O9B<08bTW02@]:P0H8b40
6BDS02di=`0f@T0062@R01DQ7`0201`X9P0M01dY9`0P;2X08Bd[024]:`0S;bl0938b024_;`0S<C40
:CTi02Xj>P0V=CP07S0b02Dg>@0R=3P07Blc02@e?00Z?D@08C<m028e?00^@4T0=DMA02m1BP0gBU40
<TA>055TK00oDUT0=dUC02m3B@0bAdX00P0dBD`01@0cB4/0=DY=03A9C00bAdX0<dQ;00<0=DY=01P0
=da@0397C00^@dP0=DY?03A9CP0`ADX0;dA903=8C@0fBe00=4U>0397C00cB4d0=da>03E;B@0hCT`0
?eAB03]?CP0jCTd0?E1?03a>CP0lCdh0?51?03eAD010E5<203mCDP0=03iBD@0lD4l0?51?03iBD011
EE<0?eA?045FD@12Ee80?E9=03mDC@1;HU`0CfIP045HDP0204eTGP0P04UOG013FEH0?eEB045GE017
GE/0AeeJ04QNG019Ged0CF=Q04MMG01=HV<0C65R04eRH`1CJFL0D6IS05=YI@1CJV80CVIJ04iVF@1F
KFD0Bf9L05U`JP1NMFl0D6MQ04iUG`1GKVP0DFQR04]RG018GeT0CfIP04UPF016GU4204QPDP1F04IN
D@13Fdh0@5Q;04MNE018GeD0@eY@04]RFP1GKVH0BV5G05I/H011ET`0>Di50356?@1`QG`0]<W0049G
D011ETd0@UM>04AID015Fdl0@eQ?049HEP15FeP0@eYD04MNE`15G580CFAJ049IC`13FU80A5]C04EK
F014FUP0@eUF03YCC00hCdL0>e9:03iEC@18GEH0@EI?03Y?B00fBD<0=DQ203A7@@0`@cd0;D4h0393
>@0a@SX0;Chf02Hg;`0T=Bl09CH`02Xk=@0W=c@0;cll06IfL`1_Ogh0:c/h02hm=@0^?CH09SD^02dl
=@0_?ST08c8]01d/9`0N;BX093<`02Lf<`0U<c<0:CLd030l>00/>3@08BdY01hZ9P0O:bL072PT01DQ
7@0O:bL0<Shj02Da;@0J9R807b/T028]9@0R;BL092lZ01lZ9P0M:2@201lX9`0E024Z:@0O:2L06b@Q
01XS800R9bH0310C02P/;`0^<SD0Q8R;02P/;`0K7b80Si>F07b0P`0<41<020`?01lS9@0H6QT05aTF
01/M6P0M7a`061XG00805QPE02409bTV02/]:P0B51407AlL01PJ5`0F61D051HC01HH5@0O8Ah08bDR
028T8@0I6aP02P`901DG500a<c005ALD01LI5P0K6aT07AdK01PH5P0C4a405QHD01<C4@0?3`d05aLE
00H6100J6QP0>CTg010@3P0E5A<03`l=014A3`0H61H00P0A4@l00`0h>3H05QHD010@3P0200h>3003
01<C4@0?3PX04A0=00804Q4?01D04@l?00l=3P0E4a@040h@01<A500F51L04Q0D014?4P0=2`h04Q0A
01@B4`0K6AX01P@504Q6A`0d<S<02@L8018@4@0>30d03@/<00P61`0A3a800`0D4QD03`0@3Q4030X=
00T72P0100804a4D00d;3P0I5aX03@/>00`:2`081PL03@/<00D3100@3Pl05Q@E00h<3@02014?4007
00h<3@0<2P/030X;00`;2@0;2PP030/900d<2P0200`;2@0900T81P0J6AL03@`:01DD4P040`405Q<C
00h:2`0?2``04`l@00800`0000<07ATJ00h:2`0>2P/00`0>2P/0200?3@h02PX:00H61P0=3@d03`l?
00`:2`0;2@X030X;0`0>2P/04P0?2@/03PT;00/720091@H03PX;010<3@0?2``030P900T51P050@80
30P900d92P0<20T06ADE00/71P0:1@D06a8C01H<3@8050P:01804`L901D<3@0A2`/02`D500`81`0K
5aP0920Q01LC5016@T<0;b//02HR8`0=2@X020@502LS900H51D03`/<00`82@0B310200h73P0<00l8
3`0=1Pd030D<00D01@0=1Pd04``C014:4@0;10/0@CY1010:3P0?2@d03PP<0`0=1`/03`080PH02`D9
00H0100=1`/030H:014;3`0I4aD020<400l92`0O6A/0<B/]00h82P0;1@L03@L900l92`02010:3003
00h82_oooooooooo01;ooooo000Kooooo`0800hD4P0=4a40318@00lC4P0C5aH05ATH01LI600>3`l3
00d=3@0?014B4@0F61L03A4@010D4`0?4a803Q8A00/?3P093@`05ATH01TM700A5A@01@T800`@3`0=
3`h0418A00804A<B0`0?4A001@0O8B002`d<01LI600;30/04a@C00803a4>0140418?00lA3P0=3``0
3@l<00/=2P0>40d0418?00lA3P0C5A803Q<?00T?2`0>51005QXG00`A3@083@T04AHB00dB3P0200d?
300800lA3P0B4Q004a<?018A300A40`040l;00l>2P0=30X2018A3`0>014?400E4a@03@/<00`:2`0A
4Q0020X5018D3`0=3`X0@T@o00`>2@0>40/0418=014C3P0@4Pd200h@2`03010A300?40/03Pl:0080
3@h90P0>3`X02`0=3PT03Pl:010A300@4@`03a0;018C3P0C5A002P`700/=200K7AP04Q@?0080418=
00@03a4<00h@2`0=3`X03@l:0P0@4Pd400lA300800T;1P0=3`X03a4<00lA300A4`h0418=01`N6`0G
6AH3014C400<00d?300D5Q<051HC018D4@0@4Pl03a4>00h@3@0@40h04Q8@01`L6P0@40h04a<A0P0B
4Q0201<C4@804Q8@00P0410>00h@2`0=3`X03a4<014C3P0B50l0418=00d?2P803Q0;0P0=3`X0200B
50l03@l:00d?2P0B50l02@/6010B3@0<3PT0418=0P0=3`X01P0B50l05QPC010B3@0>40/03@l:00h@
2`80418=01L03Q0;00lA300@4Pd03@l:00lA300B50l03a4<00l?3@0<30X04Q8@010@3P0;3@P04Q@?
010C300A5Pl041D>00lE2`0=5@X03QH;00lB2`0@4``02`h700hA2P0201<F3`0O014D3@0?4P/03a8;
010C300>4@X09RTR01lR6`0>4@X04A@=01@G400<3`P02@`500lB2`0@4``04A@=010C300?4P/0418<
00lA300>40/04Q@?014C3P0?4@`04Q@?00P:1@0@4Pd04A<>010B3@0?4@`03Q09014B2P0301<D3080
4A8:01@04Q<;014B2P0A4P/04a@<014B2P0?4@X03a4<010C3@0C5Ph051L>014D2@0@4`P030l400X=
100C5Ph04aH?01<E400H6a@05aXC01<F3@8041<800@04QH801DH3@0C5P/04QD>0P0C5A800`0A4a40
418=010C3002014D3@804QD>00d04aH?01PK500D5a003Q4:010C300C5Pl03A0901dP6@0B5@h05aXC
01XM5P0a=2d05APA008051L@00P05APA01HI4P0H6a@04aPB01HK5@0<4@/05a`F018G4@804aPB02<0
4QLA014F400B5a4051TC01DJ4`0G71D04QP>014G3@0D6A805AXC018G400C61805Q/F01HK5`0E6QH0
5a`H01hS7`0P9R805Q`H01@J5P0E6aL061hJ01lU8@0H7QX05adI01HL600G7AT0728N01lU8@0C6AL0
5adK02D[:@0M8b405A/I01`R800201TO7@0;01XP7P0N92807R@R01`U8P0N:RH062@P01dY9@0_>cL0
9S8^02Da;@0K9b<00P0N:RH0900O:bL08BdY02<_;00R;Rh082h^01d[:`0Q;bl08c<c028b<P0R<C@0
8C<e02Dg>@0U=c/08cDi02Hh?00R=C/0;d9902e0AP0Z?D<0<dI<0313BP0cAT`0<4=903=6C00Y?480
<DA;0314B00_A4L0<4E802m4A`0]@TD0;T=60315B00aATT0=4U<03M<C`80=T]>0180=T]?0397C00a
AT/0=DY?0397C00_A4T0<dQ=03M<D@0hCE80>e1E03eBE`0lDEH0>51A03E?C00jDe00@UQF03mCDP0m
Cdl203e>CP0>03a=C@0jCDd0?51?03iBD@0jCTd0>De<03Q<B`0jCT`0?51>03mCD@12Ee80B5eH04=H
DP0jCdP203iCC00K03M=B@14FUL0C69O04aRG`17GEX0AeiH04QOF@17GUP0C6=L04eTG`17GUL0AE]E
049HD`19H5X0BV5M05=YIP1BJ6H0D6EU055WI@1?IF80DFQS05=ZH`1?IU`0DVUO05=ZHP1BJF<0DFQR
0080D6MQ0P1?IV002@1AJ680BV5K04]RG01=I5h0Bf9J04EMC`14G4d0@UY<045IB`02041HB`0I049J
C@15G540@eY@04QOE@1>IE`0@eY@03eCA`15Fdl0?eA:03aAB@0nDdd0AEYD049GDP12Ee00A5U@04ML
D`17GE40AEY@04aRG`1;HEh0AUeG04QOF01=I5X0FW5W04QOE@0204QOE`0S04ILF@14FUP0A5YG059/
HP15G580@UU?03aCB@11ETd0>e1703Q=A00iCD@0>4a303A8?`0^@ST0;40g02dn=00]?SH0:S/c02@e
;@0O<2X07RlY02Xk=@0Y>CH0<d=002/k>00_?ch0:3Pe02Ti<00T<b`08C0Y02Lf;`0U=2l07bhY020_
:P0Q<2d00P0S<Rl0@@0Q;bl0934_02Pd<00U<Bd08RhZ02@`;00Q;BT07RXV01TU8@0T<2`0?4Q402/g
<`0M:BD07BXS01dZ8@0Q;RL0:3<_02<];00P:RX07bPZ01hV:00N9bH07BDR01dS7P0N91l08RLU024U
9@0^<S<06alP02/_;`0J7Qh051PI02/_;`0X;2d08RHW01lS8`0G6a/06Q`I01XL5`0Q8ah08bDP01dO
6P0H6QD04aD@01`N6@0O8A`0418=01`N6@0H6QD05ALD01HH5@0G6AH061XG01/M6P0R92408B<P01@F
4`0G6AH0;Bl/01PJ5`0@4Pl05ADC01HF500D51804Q8@00805ADC01@03@d;01XJ600=3@/05ADC02DU
8`0<30X04a<A00d=2`0@40h05QHD018B400@40h04A4@014A3`0F5Q@04Q8@01@D4P0<30X04Q4=018A
3P804Q4?01H04Q4@018@4@0F51D03`d?018@4`0G5AP04a4E00l=400C4A@04@l@00L51P0G5AH04Q0A
06QVI`0l>S/04a4B018@4@0D4Q<03`d>00d;300=2`h030X=0P0=2`h03`0?3A004@lB010?4@0<2Pd0
5Q@G01@B5@020@<05aDH00d;300I5aP08R0Q014?400=2``03`d>00d;3002018@4@0E010>3`0>30d0
3P`=00h=2`0?3P`03Pd;00d<2P0@3`d04Q4?014@3P0<2`T03Pd;00d<2P030P403``<020M7@1RGUl0
510A01XF5`0<2@T03`/<00D03PX;00P03P`=00T92@092@T03@d=00T92@0:20T03P`=00`:2`<03PX;
00D03`T;00l:300?2``03`/<00h:2`0200d92P0O00`82@0=2@X0510A01/G600B3Pl030P900/71`0A
3@`04`d=01482@0F30d05@T;01H:300C1`T040H700`41@0:10@03PT800`81`0B3Pd02`L601@@3`0?
2`X02PH5014=30091@@02`L6014=300>2PT030P8014;3P0200`62@0900l93@0<1PT03@L;014;3`0<
1PT02P@701<=4@0C3A0030L:00803PL>0P0@2A00400>1`h030D<01XC6P0P6B0030D<00d63@0?20l0
2P@800/5200B30h03`T;00P3100@2P`030H800d72@0>20X300l92`0300h82_oooooooooo01;ooooo
000Kooooo`0500dA400;3`h020`;00P<2`0;3Pd00P0>40l08`0=3Pd051@D01LG5`0D4a<04a<C00h@
3`0:3Pd0310?00L;2P0<40l02@d<014E500=4A0020`;00/?3P062PT03A4@00h@3`0?4A003@l>00`>
3@0@4Q4051HE01DG5P2=Shh08R@S010B4@0;3@`09bTX00lA3P0A4a004Q@A014C400>40d030h;0080
3Q0=01T0418?00h@3@0R92402@h:00hE4@0020<07BHQ00hD40073@T01P`800T>2P0<4@d03A8>010B
3`0>40d03`l;010?2P0@3`/03Pd900l>2P0A40h03Pd;00X91`0<2P/03P`=008030X;00H03@d;01DG
4P0210005aTD01/M600:30L200d?2P0600h@2`0=3`X030h900d?2P0?4@`03Pl:0P0=3PT01@0>3`X0
3a0;00h?2P0=3PT03Pl:00803a0;00L03Pl:00h@2`0?4@`06A/F00X<1`0F61<03a4<008030h900@0
3Q0;00lA300?4@`03a4<0P0A4`h00`0?4@`03Q0;00h@2`0200lA3003010B3@0C5A004A<>00803Q0;
00<0EUQE0494@@0L7Q/00P092`P01@0=3``061XG01HH5@0B51403a4>00803@l<00L03`l=00h>300F
5Q@02PX8014A3`0C4a403`l=00<0410>00<03`l=00d=2`0>40/00`0@4Pd200lA300?014C3P0>40/0
3a4<00h@2`0=3`X05ALB01@F4@0A4`h06adH00d?2P0B50l02`d800h@2`0B50l04aD@00804A<>01@0
5QPC00h@2`0=3`X03@l:00lA300@4Pd03Q0;00`>2@0>40/030h900lA300A4`h03Q0;01<C4P0;2`/0
4a<C01LG5@0@4Pd04Q@?010C30804AL=00L03aD;00hF2@0?5``03Q4:00T<1@0=40T06A`E00801@P1
00P02Pd601XM5P0A50d04A@=00P;100F6A804QD<00P;0P<03A0700d051L>00hA200@4`X04A@;010C
2P0>4@P03Q0:00`>2@0>40/03a4<00`>2@0B50l05ALB00802`d802@03Q0;01/M60051`8051H?014C
200C5@X051H;01<E2P0A4`P05AL<00D7000M7a@0:bdR00h@1@0E5``04Q@=010B3@0B50l06QdE01XM
500C5P/03A4300`?100?4PT04aH>010B3@0C5A403Q4:014D3@0D5`h04A@900lB1`0?4`D04A@9010C
200?4P/2010B3`0300h@3P0@4Pd041<<00804A@=0P0B5@h03@0930D03A09010C300B5@h06A`E01hQ
6P0M81T07R4J02X]9P0>4@X06ahG018E3P0E61400`0D5a007`0E61405QTB01<H4P082`L092TS00@9
0`0E6Q@04QLA010E3`0E6Q@061dG01TN600F6aD04aPA00dB2`0E6a4061hD01DJ4`0F6a@06b0I02DZ
900E6QD07B8N01XO6`0C61@08RLS00/A3@0@5Q806R0L01/Q7@0D6QH00`0C6AD0200B61@04aTE01PN
6P0K8Ad06AlM01HL6P0L8R005Q`J0P0G7A/09@0J81h05Q`J01TO7@0O9B<07R@R01TR7`0I9B40930/
01XV8P0O:bL07RXV01dY9@0L:2@07RXV01l[9`0P;2P08BdY02<_:`0Y=CD0;C/k02Hd=00O;Bd08C4a
02<c<`0S<SD093Hh028d=P0Q<cL08cDi02@f>P0W>Sh0;T5502`o@`0^@DD08C@h02Dh?00P<cL00P0_
@TH05@0Z?D40<TE903A8C00dBD`0=DY=03A9C00bAdX0<dQ;03A9C00cB4/0<TM:03=8B`0eBTd0=da?
03Q=D@0iCU<0>TmD03E:C`0^@dP0=DY?03iCF00203]@E@1l03eBE`0nDeP0?55F03IAD00fDdh0>EA?
03]CC`0nDU00?U5?03i=C00lC4/0?U1>03mBD00mD4h0>Ti<03U=B`0fBTP0<dM503M;B@0jCT`0?55<
03mDC`1>Heh0BUmH03eBB`12Ee00?E9:04QNF`10EU@0@eUG04iTHP1CJFH0B5mI05A[H`1:HET0AEaC
04]RFP1:HEL0B5mE049IC`19H5H0AeiF04mVH01?IF80CfES05U_K@1CJFL0CfIQ04iUG`1?IUh0EFaT
04iUG`1EK6H0DFQR04iUG`1AJ680CVEO04MNF01?IV00AUeG04mVH01;HU`0C6=K04=KC@12FTX0@5Q8
045IB`14G4h0AemA04YRE@12FTd0CFEH04mVG014Fe40AUiA04]QE00lDTH0?UA804aQFP17G5H0C65L
03Y?BP12Ee40AU]B04AID015Fdl0B5iB04YPG014FUL0@5MA04IMEP13FU00BF1F04ELDP16GED0AEaD
041FD`0nE580?UAA03YDBP10Edd0AeiD041GC@17G5<0BEiE03Y?AP0gBd80=DU003=7?P0bASd0<DDl
03=4>P0Y>S808c@/02@e;@0[?3H0;Sli02Tj=00V=S<0;cll028b;`0Y>CP0;Cdj02`l<`809C@]00@0
:3L`02@c;P0O;RT08C0[0P0R<Bh0;P0Q<2d08Bl_01l]:P0O:bL07RXV020/:00W<bl0930/01dY9@0O
:bL08RhZ01XV8P0I9B406bLS01/Y8P0J:R007R/T02@`;@0R;R`08bd^028[;@0N9RP082HV01hT8@0M
91d07b@N020U800M8Qh04QHE02P]:P0I7QX0720N01<G5P0J7a/09BTW01@H5`093PX06AhK01LI500E
5a8061XE01TK5P0E5a8051HA024S7P0G6A@201DG4P0@028T7`0B50l04Q@A01HH5@0H6QL04aDB014C
400F61D03@l<01@F4`0A4a004Q@A01DG500Z;2T05aLE01DE4`8051@B01004a<A01@D4P0>3P`04A4?
01/K6@0C4a4030`:024Q7`0?3`d061PF018B40092@L03@d;01HF500<30X06a/I0P0>3P`200l?3@0`
018A3@0B4@h04Q4?018A3`0B4A004Q0A00l=3P0>30h04Q0C014?4P0=2`l040hA00h<3`0A3a0061HG
014?400=2``00@0000D3100D4Q<01`D600d;300E4a@04@l@010>4@0D4QD06ALJ00l=40050`H01P@7
014?4P0R82<02@L:00P62@0H5QT02`T<018@4@0:20T04Q0A014?400J61T071XK010>3`0?3@h03@/<
00X82@0<2P/03P`=100>3@/03P0@3`d04A0>018A3`0?3P`05QDC01@C4@0:2@L04@h>01XF5`14@440
3@X:00L3100C3a002@D61@0>2P/01P0;2@X030`<00l?3`0820P0000000@20`8030X;0`0>2P/01`0?
2@/03@P900`82@0>2P/040`=01<?400G4a@00P0C3a003P0O6a`0920Q01DA4P0=2@X030L800h8200C
2P/050X;01D;300K3Q005PL:01@82P0A1`P040L80P0?2@T020091@@03`/:00X61@0300002PH500P4
0`0<20L04@d<0P0<20L040050@003@T801<=3@0=1`L030H700l92`0>20P04@/<00h82P0B30`03`T:
00H00P0D3Ph02P@600`62P0=1Pd20109400=00l83`0=1Pd030D<01TB6@090PT03PL>014:4@0:10P0
3`T=010:300;1@L03`T;014;3@0300l92`@03PP:5?ooool001_ooooo01d04ADD00lC4P0<40l0310?
00d@3`0?4A003Q0?00h?3P0E5AD05aLG018A4@0?3`l02`d<00lC4P0;3`h05QXI01/O7P093@`03Q8A
00/?3P093@`03A4@00H:2@0;3`h03@l>00h@3`0<3Pd02@/:00h@3`02018D4`0N02T[:P031@@03a4@
01XL6`000@003a4>010B3`0A4a00418?00h@3@0<3P/03@l<01DG500@4Pl08B<P02d_;0083@T03aLB
00070P0?61<01@T60004000@5Q802a0<00dB3P0>4`l0418?00d?300=3@P03Pd80P0?3PX01@0>3@T0
40l=00l>300D4a405aDF00<03P`=00L03Pd;01lQ70072@@07R0K00L9100>40/0418=00803@l:00D0
30h900/=200>40/03a4<00h?2P0200d>2@0500h?2P0?40/03Pl:00`=200=3PT00`0>3`X02@0?4@`0
3@l:03Li=00I6aH01PP300h@300;3@P030h900h@2`0300lA300301<E400A4`h03a4<00803@l:00<0
3a4<01<E400A4`h00P0C5A005@0>40/03@l:01DG500?4@h01`T600X<2@0?4@h051HC010B3`0?4@h0
3@l<00`>2`0=3``03a4>01DE4`0@40h04Q8@00P81P0>3P`03@d;00h>300300l?3@0300h>300<30X0
3Q0;0080418=0P0>40/2010B3@0800lA300E5a804aD@00P:1@0<3PT0418=00lA300G6A@3014C3P0I
010B3@0<3PT05aTD01hP6`0F61<020X500lA300=3`X030h900h@2`0@4Pd03a4<00h@2`0A4`h03a4<
018D3`0C5A003a4<00l?3`0;2`/03Ph>01@D4P0B50l03a4<010C3002014G3@0@00lE2`0=5@P03QH9
018E3P0=40T02Pd600/>1`0C5Pl0?d8k01hQ6P0I71D03A0900lB2`0;3PL041<<010C2P803Q4800<0
2`h500lB2@0F6A000P0?4PT04@0@4`X03a8900lB2@0A4``04A<>01@F4@0F61<051HA01lQ700L7QT0
418=02<U800H6QD06A/F00L9100K7AH04A<800<04Q@901`04A<801@F2`041P007AlD02`^8`0;3@80
4Q@901@F3`0A4a003Q0;014D300D5``051P:010D1P0B5PP051L<014D300A4`h03Q0=00`>2@0B5@h0
61/B01DH3@0A50T03a<501<F2`0A50T041<<0P0A4a000`0?4@l0418=010C3002014D3@804QD>00@0
3Q4:018E3P0C5Pl04aH?0P0G6Q<01P0A50d01PT201hQ6P072P<07b8K01LJ4`805APA0`0D5a002@0E
614051TC02`a:`0<4@/06QlI00X?2@0X;BL04AH@01DJ500201XO6@0C01LL5P0C61402a0901dS6@0V
;2807b@M01HK500G71D07B8L00`A300U:RH02a0<02X_:`0P9B404QPD01DK5`0K8Ad06R0L01<I5@03
01@J5P0401DK5`0F71P061hJ01TO6`806b4O01<05A/I01HL6P0O9B<06AlM01hT8P0J81h06b4O01hT
8P0L8R005b0M01dX900F8Qh07RXV024]:@0C7a/07BTU01/W8`0J9R8072PT008082`X00l07b/W02`h
>00b@400:SPh020^;P0R<S8093@d02Dd=`0^@480:S`n02Li?@0V>3`0838f02@g>`0eB4`00P0^@DD0
3`0X>cl0DfIZ02Hi?@0V>Cd0:ci20354B00^@DD0;T9503A9C00eBTd0=4U<03=8B`0dBD`0=T]>03A9
C0020397BP0903=8B`0fBdh0>4eA03Y?E00kD5D0=DY?02m4B@0iCU<0@EIK0080?U=H06`0?E9G03]@
E@0jCe@0=U1?03EDCP0dDD`0=Da903Y>C00oCdh0?4];03i<C012DU40@EAB03iAC`0iCD/0@5AB03]?
C@0fBTP0=d]903Y>C00jCdX0?eA?04aQG01<HEX0@5E>04=HD@0oE4`0?59@04EJF`1KLG00Bf5O049H
EP13FED0KhIn061gK`1AJ5h0CVEK04UQE010F4/0?UI904EMD014Fe00CVEM051WH@1DJVP0H7Id05U_
K@1BJ6D0CVAQ04aSG@1BJF<0C6=M059YH`1AJ680D6MQ055XHP1>IEl0F6mY05YaJ`17GUP0E6]U04iU
G`1?IUh0AemA04INCP15GDd0AUi@04UQD`1<I5H0BF5D045IC01<I5L0CVEK04=JD018H5<0Aee@03U?
@@19Ge<0CV=L03aAB`0aAT40?55<049GD@15FU40A5U@04=IC014FTh0AeeI045GE00oEU00AEaE03eD
BP0oET`0AEaB04QOE`16GED0@5IC03iDDP10EU<0?eU?04eTFP1EK680?UE;03A9@00bAch0?55803A8
?`0cAch203I:@@0B03A8?`0b@cT093D]01h_9`0R<b/0;Chh0352?00Y>S@08c<`02`l>@0Z>SL0;Cdl
02Ti=P0Y>C009SD^02Lf;`0Y>3409cHa0P0S<Rd0:@0T<c008S4^020_;00Q;bl08S0]02@`;00S;b/0
8RhZ02@`;00S;b/07RXV02Xf<P0^>SH07RXV020/:00U<Bd08BlX01h^900O:bL08BdZ01dY:@0O:B/0
7bPZ01`T9P0O9BD07B<P01/R6`0L8AX06AhG01HK5`0`=C4061dI01/P700B5a<09R/W014F4P0C61@0
6QlK01hS7`0F6aH071hI008061XE01H06A/F01HH4`0H6QD06adH01LI500K7AP051HA01XL5`0F61<0
51HC01PJ5`0K7AX061XG01LI5P0J71T06A/H01XL6@0L7Q/06A/H01LI5P0k?CX06ATG0`0E5A<05P0B
4Q0051@B01<C4@0C4a404Q8@01<C4@0F5Q@05aLE00`<2P0A4@l03`l=028R800820H05ADC014A3`0K
6aT020P601`L6P0=3@/051@B018A3@0B4@h2014@3P07018@400B414040h?014?4@0D4QD04Q0C00l=
4@0201<A500=00X82@0N71d030X;01XH6@0F51D02`T:01HD5@0A3a003P`=01@B4`0Y9bP03@/>00L5
200200X82`0Q01@B5@0R82<030X=00<1100D4QD07Q`O00l=400>30l040h?00L51P0B414040h?00T7
200100004@l@00h<3@0;2@X02@L800`:2`0?3@h03`h<00h=2`0?3P`040l=00h=2`0;2PP051<A00H5
0`0920H030/900d<2P0=2PX040`=00803PX;00<04Ph?01/G600C3a001@0>2P/0200;2@X03`l?018B
4P0>3Ph051@D01HD5@0?3@h030X;0`0>2P/02`0?2@/04@`=014=3P0?2``03PX;00l;300@30d03PX;
00l;300C3a005Q8C00803PX;01X04`h>00`61P0?1PL050X;01@82P0I2Pd05@H901L82`0C20X04PT:
01D<3@0?2@T04`l>01/G5P0C3`h020@301<?3P0>2PT01P8100h:2@0@30/03@T800L30P0A3@`0618B
018<30803PP800<030H600d71`0600000P0C3@d01@0400003@L700h92@0<1PX03@H=00<03`P?00d0
3PL>00D01@0A2Q402@8900l83`0@2A0030D<00d72`070P<01000010:300>20X01P0200802`D700@0
30H800h82P0A2`d04`d?5?ooool001_ooooo02403Q8A00lC4P0?4a8041@C014D4`0A4a8051DD00l?
3`0A4A4051<C018A4P0C4a<0418A03@i=`0<4@h03A4@01`P7P0[;bd04QHE010D4P0=4@l041@B00T=
300>4Q40418A01LI600F61L04A<B00h@3`0@4Q403a4@00h@3`0=3`h00P0?4A000`0>40l03a4>00lA
3P0200lA3P803@l<02003a4>014C40092`P03Q0>01<E4P1_M7008bXU014H500:3`/03AD@00`B3P0<
4@d051TE010E4@0=4Ph03a4>014C400@40`04a4<01/G500J5a@04a4=010<2`0>2`X09B<Q02`X:00C
41005a@D01XF5`0@3`d05ALB01HH4`804A<>00H03a4<010B3@0?4@`03a4<00h@2`0=3`X2010B3@<0
3@h900D03Pl:010A300>3`X030d800d>2@0300h?2P0600l@2`0=3`X08R@O00X;200G6A@03@l;0`0@
4Pd04@0?4@`03@l:00/=200D5Q404Q@?00h@2`0<3PT03@l:00lA300C5A0030h900h@2`0D5Q40418=
00`>2@0<3P/03@l<00804A<@00l03a4>00d?300C5A804Q@A00lA3P0=3``03Q0=014C400E5A<03Ph<
01<C4@0@40h051@B00X:200@40h00P0A4@l2010@3P0900h>300<3PT03a4<00h@2`0=3`X0418=01HH
4`0H6QD03@l:00<03Q0;01H07R0K00d?2P0@4Pd03a4<01HH4`0=3`X05aTD014C3P0=3`X04Q@?01<E
400?4@`04A<>010B3@0=3`X030h900h@2`0@4Pd03a4<00h@2`0A4`h03a4<0P0A4`h05`0=3`X06QXI
028R8P0E5A@03Ph<014C3P0=3`X03a8;010F3@0@5P`03Q@:00dD2@0>5@X04A@=018E3P0>4@X05APA
06]^I`3Si]l0CE19010C300H6a@06A`E00804A@=00D04QD<01<F3@0=40L03Q4801<F3@02014D2`0Q
00lB2@0>4@P03a89010C2P0C5Pl030h900X<1`0@4Pd02@/600/=200@4Pd06A/F07anN@1?DD`04A<>
00h@2`0D5Pl04A<8010A200?4@L04187014C2@0@4@L05QP=018C2P0D5P`05AL<00d?1@0B4`d03a4=
00lA300@4`/04A@:00804AD901<05QT>01<F300C5Ph0:2XU01HH500A50h05QTB01/N5@0D5`d03a87
00lB1P0D5``04QD;014D3@0B51004aDB014C400@4Pd041<<00804A@=0P0B5@h0300A50d05APA01HI
4P0F6A805aXB018E3P0I71D030l801TL5@0E61406QdF01<F3`805APA00X051L@01<F3`0D5a005APA
014F401HGEL041@@01HK5@0C5a805a`F100D6A<201HK5@0D01DJ4`0J81H06b0H01PM5P0E6Q<05Q/D
01XO6@0F6aH05a`H01XO6`1JGe/05adI01HL600G7AT06b4M01TO6`0H7QX07bDQ01HL600H7QX201/Q
7@0801XP700H7QX05alL01XQ7`0H7ad06R8O01dU8P0L8b4201XR7`0401/S800M92807B@R01`U8P80
6BDQ02P05b<O01`X900J9R808RhZ01l[:00I9B406bTT02Hb;P0T<2`07b/W02Ld<`0Y=cL09C<c02<a
<@0S<c<08C4a02Xj?@0_@D<09CLi02Dg>`0^@4@0:Sa002Lk?00bATL08CDf02m3A019GEh0Wk>d03]?
D00fBT/0>4a=03U=CP0dB4T0<dM90356B@0cB4/0=4U<03=8B`0eBTd0=T]>0P0eBTd0>P0fBdh0=4U<
03=8B`0eBTh0<dQ=0356B`0fBe00=daA03U>E00lDEH0?U=H045FF`0mDUL0>4eA03Y?D`0hDe40>EMA
03UED00gCd`0?U=?045BD00oCTd0@4m>049AD00oDU00?U5?03a@CP12EU@0?51>03Q<B`0nDU40A5QF
04EIEP11EE40B5eG04UNF00oE4`0?eA;04AID@18GE/0CVAT06YoP01FJfT0Bf5O04UOFP17GED0@eYA
04IMD@18Ge80@e]=03iEA`0lE4H0A5a>04IND01BJF00DfYS05I/J01IKfd305I/J@0@059XI@1DJfH0
EF]W04mWH@1BJV@0EVeW05A/IP1GKfT0PIRB06j6P014G5H0E6]U04aSGP1@Iel0BV9E04YRD`<0B61A
0300AemB03eEB01:HUD0@e]>04MNE01EK680BV9E04EKCP14FTd0Bf5E03eBBP1=HU`0@eMD04IKE`12
Ee40BEiF05=XG`1CJEd0B5iB04IMF@19Ge`0AEaF04IMEP11F4l0B5mE04AKD@19H5P0AUeE03mFD@0o
EE80@UQD03YDB00mE4T0AemB03aDA`0lDTL0?E=703Y@A@0cAcd0=TXo03mCB@0jCT@0<THk02ho=P0T
=Bd08C8Z02@e;@0V=c4202Lh<P0A02<c<00b@Sl0;Shk02Ti=`0Y>CH09cH^02He;P0V=Bl08C0Z020_
:`0U=300:STe02/h=P0U<S007bdZ020];00R;b`00P0V<Rh0C`0N:RH07BTU01hZ9P0M:BD06bLS01hZ
9P0P;2P07BTU020/:00Q;RP07B/S01dZ9P0P;BT07BPY01dW:00O9bX07bLY02<Y:@0R9b@07R<M01`Q
6P0Q9R006b0K01<H4`0P9B0061dH028W8P0Z;bX04aPC01dR7@0J7aX06b0K01DJ5@0K7AP061/D01TL
5@0I71H05QTB01PK500J71H04QD>01XL5P0G6Q@06ahG01HI4`0I6aL061XG01HH5@0D5Q<05aTF01/M
6P0>40d07R0M01DG500=3``061XG01DG500F5a<04Q8?01<D400E5Q804A8>01DE4`0B4Q004a<A01DE
4`0G5aD05ADC010@3P0D51803`l=03Xj>02UYJ<08R8P018B401NGU`0VIVG01/K6@0E5A<00P0@40h0
9P0B4@d04A0=00l>300?3P`04@l?018@4@0D4Q<03`d>01<A4`0F51L04Q0C010>4@0<2P`04a4B010?
3`0>30d04@l@00l=3P0>30d04@l@00h<3@0A3a001@<401LE5P0A3a803@/>014?4P0@3Q406QPK02XX
:`0?3A004Q0C03Pf>@15@dH06ALJ02h/;P0P7Ql02PP90P0>30d00`0B41403`d>00h<3@0200l=3P0>
00d;300?3@h04Q0@00l>300?3P/05QDB028Q7@0N7AX061LD014@3@0=30T09RDS024P7`0?3@d2018?
3`0301TE5P0A3@h04Ph?00803@T:1@0>2P/0200=2``03`l?00h=3P0D51@0>STi02l];P0>30d030X;
0`0>2P/04P0?2@/04`h@018>3`0<20T03PX;014=3P0@30d03PX;010<3@0?2``04@d>00/720091@H0
3`X;010:2P0@20P04PP901L<3@805@P:02<05PT;01061`0@1`P05@d>010:2P0<1`D05Q8?00/71@0;
1PD04Ph;00/71@0<1`H01`<100`81`0>2@L040`900h91`0F40l03`X700`6100=1`H02`H300h91P0;
1P@04@`900h81P0=20H040/8018<300>1`d03@H>00d63@0>1`h03`P@014:4@0201094@0900/4300A
2Q4030D<018;4P0@2Ph04P`?00`62@0G4A@03PT;00<03@L:00@030H900d72P0A2Pd04P`?5?ooool0
01_ooooo00D06QhO00`@4@0830d0KW9c01@H6@0200`@4@0A014D5@0?4180414C00/<3P0H6QT03@l<
00`>2P072@@04A<@03Li=@3inoH0IVQU018D400B50l04Q@@014C400<3P/00`0H6QT02P0C5A@030h=
00T;2P0=3`h030h=00d?3P0@4Q403a4@00h@3`0<3P/200lA3P0400`>2`0?4@h051HC00L91P80418?
00X02`d:01XL6@0R92405a`F02hc;@011P0041D?00hC3@0D5Q402`d80P0?4@`05@0>40/03a4<01DG
4P0=3PT030/7014A300H6A@06QTE018B3P0D5A004a8>014A3@0C50l06QTG01dN700D5Q<05QPE01DG
500210405ALD00d?300200lA3P0700h@3@0?4@h03a4>00h@300=3`X03a4<00h@2`0200`>2@0800h@
2`0<3PT02`d800d?2P092`H03@l:014C3P0@4Pd200d?2P05018D3`0?4@`03@l:00lA300A4`h00P0@
4Pd01@0B50l02``702LX8`0l?CP030d800803@h901H051D@00H70P0L7AP0=CHa01PI500?40/02@/8
018D4`0E5aH0418A014C4P0>40l04A<B00X<2`0B51<0418A00H81`0B51<04Q@A00lA3P0=3``03a4>
0P0B5140100<3P/03@l<00h@3@0>40d200lA3P0K00`>2`0>40d0418?010B3`0>40d030h;030b;`0>
40d02@/801DG500>40d061XG00D70P0c=C006Q`G0084000?4@`03@l:00lA300B50l030h901DG4P0O
8A`02`d800d?2P0>40/0418=008051HA00<03@l:01<E400@4Pd00`0?4@`01`0@4Pd07AlJ02X/:@0B
50l03@l:018D3`0210000P0=3`X0300C5Pl04QD?00P;100A50d03a8;01PK500F6A804QD>02/^9`13
ASl09BPQ01@G408030l802H02`h701LJ4`0;3PL041<<01DH4@0>4@X02Pd6010C300?4P/04A@=010C
30082`@02`h701LJ4`0E61403Q4:00d@2@0B5@h051L@01<F3`0@4``06A`E01@G400930D01PT201/N
5`0>4@P06QdF00d@200S9Qd04A@=010C2`0E60l06QdF01XM5@0=40L02Pd6010C2P804aH=00d04QD=
014C3P0A4`h0418>014C3P0C5A004aH>014D2`0C5Pd030l8010C300B5@h03Q4:00803A0700d03a89
018E3P0B5@h030l800`>2@0E5a80418=02LY900@4Pd051HA01<E400C5Pl04QD<00804aH=01D041<:
010C200C5Pd05Q/D01LL5@0;40T07B8K00lD3@0A5Pl051TB00/@2@0C6140314:01@I4P0I7QL02a0:
01@I4`0@5@l04aPB00lD3P0H7AL0100E6Q@0100D6A<04QLA014H4@0D6a@201HM5P0;01@K500A6140
3QD>01DL5@0C6Q<07B@M014H4@0M8al04ALC018K600F7a`00`0H8Ah0:`0C71T06B8O01HO700K9240
5AhK01PQ7P0C7QX05b8N01PS7`0G8Qh06bHR01hY9@10BdL05b8N00`G4`0Q;2P07RTU01lZ9P0T;bT0
41/E00lJ5P0R;R/0B5AB02Pd<P0K:RP06BPU02ho>@1AHEX0<3lh01LV7`0Z>3L0:CLg020`;`0Q<C40
:3Lj01PZ;00S=CL09cTm02Lj?P0V>Cd0:3/o02/n@P0Z?D400P0Y?4002P0[?T80;T550395B@0X>cl0
CV5U07jAU@18Fel0<DA803=7B`0cB4d203A9CP0403=8C@0eBTl0=T]@03A9CP80=DY?05`0=T]@03U>
D`0hCE<0<TI=0314B`0fBU40@5AK04=GH011EE`0?E9G03aAEP0mDU@0?E=A03Y@C@0jD4h0AE]H03iD
D@0mDdd0;T<l04QMEP0jCDL0?U5;03iAC00dBD@0<dM503Y>C00dB4H0@5AB03U=C@14Ee/0BUeQ09f`
]021U9P0F6a]04MKFP19GUT0@eQA04MLD`1=HU/0?eA=05Q/IP1SMfh0EFYQ049FC@10E4/0AUa@04=H
C@17Fe00@EM;03]@A00jDTD0>e=604QOE01CJV00E6]S05M^I`1GKVP0EVeW05M^J01IL6X0F6mZ05E[
J01AJVL0DVaX04YUH01=IV00EW1X04eXG`1FL6L0DVaU04aWH014GET0GGMc04aUH@1BJF40CfMJ04eU
F01<I5L0BF5D04AKD@1:HEL0CVEK05A[H@0jDDL0CfIL03E=@016GU00EViQ05eeJ018H5<0?UE;03aC
B`80AEaD0P14Fe<0?`16GE<0AUeE04YQG012F5D0@eYD04MNE`13FU80?UE=049ID@13FU00@UU?041G
C`0oET`0@EQ>03QBA`0fD4L0?eU>03iEC00lDd/0A5]A03I;@`0aASl0=4U003E8@@0aA3h0<THm02hn
>@0W=S407RdX01`[9P0Z>C@0=D@o02Xi=00]?3L0:3Lb02@c;P0U=2l093<^02`k=P0R<B`08c8_01XY
9P0N:RX09c<c02Xf=P0[=CH09Bl_024[:P0U;bh09S4/01hY8`0M9R407BPR01lZ900O:RH07BPT01PT
800H9b@082l/01l^:`0M;2T07bXW01/T8@0201XS800401HO7P0A6QT0:S0`01hT90807B<Q02<07B<O
01`R7P0S:2L09BTZ01/O800A5AH06AdN020T9@1DF5T09RX[01TM7P0P92D06QhO014E5@0K7AX06Q`G
01PJ5P0G6AH061XE01/M6@0I6aP07b4L01/M6@0C5A805QPC01TK5`0I6QD06Q/F01HG4P0K71L04A8=
01XK5P0K71L06AXE01HG4P0201DF4@0W01<E400D5a005APA010C300B5@h061/D014B3@0G61<04A4=
00d<200?3PX05A@@01LF4P0D4`l040l;01`K5`0[:RH06APD014@301DDdl0UIB@020O6`0:2@D08b8N
014@300>3@/05QDC00/:200E51804a8@00l>300C4Q004Q4?014@3P0B41404@l@00h<3@0?3@h04@l@
00804a4B00d04@l@00l=3P0A3a0040h?018@4@0C4A8040h?00h<3@0=2``04@l@00d;300B41400@00
00804Q0A00H03@/<00h<3@0A3a003P`=00/92P0B3Ph200d9200300l;2P0A3@`04@d<00804@d<0P0@
30/03`0?2`X03PX901PG4`0F5Ph02@T0051@@`1cM6H0BDXl02<T600K6QD08b8N00l=40091Pd03@X=
00d9200201DA400<00X61@0@30/05Q8A010<2`0?2`X030P700/71P0=2@P03`/;00`:2`0>2P/03@X;
0`0>2P/01P0H51D020@5010<3@0B3Pl03@T:01@@4@D03PX;00@03`/<00h:2`0=2@X02`L80P0:1PL0
9@0<20T02`L800h92`0?2@/02P@6010:300C3@l03PP:00/51`0F418030P900T41P0;1@L02`D500d5
1`0A20/040X:00l72@0D2`h04@/;01082P0?1PT03PP801492`0>20X03`T9010:2`0=1`T030H600h8
2@0A2`d030H600T310090`D02@<301<=3`0<1PP01@0<1PX0300:10P04`dA00@00P0E3a<02PD8018<
400>2@l050lE01<>50070PP05Q0G01<<4`8050XB00@04@L?00h4300@1@d04PP@5?ooool001_ooooo
00H04QHG00dA4P0E6AX0>Cdn014E5P0?4a@200hB4`0C010D5@0;3a004ADF04a@C`0G6AH04aDA01HH
50092`L07R0L05mQG@0_<Bd03Q0<01HH500;3@T04A<?01<E4P0F61L051HE018D4`03014C4P0700lA
400=3`h03a4@014C4P0@4Q403a4@018D4@0200h@3@03010B3`0>40d030h;00804Q@A00X01PP6018D
4@0?4@h03a4>01lQ700B50l0418=018D3`072@@04A<>0P0>40/05P0=3`X030h900d?2P0B4`h02``7
00h?2P0A4Pd04a@?01LH4`0A4Pd0414<00l@2`0<3@P02``700d>2@0>40`0:2XW01TK600:30T03a4>
01HH5@0>40d200lA3P0900h@3@0?4@h03a4>00lA3@0?4@`04A<>010B3@0>40/03a4<00804Q@?0P0C
5A001P0;3@P02P`700h@2`0B50l0418=00`>2@803a4<00<03Q0;00lA300?4@`00P0<3PT00`0?4@`0
51D@00/<1`02014B3@0;00h?2P0A4Pd04a@?00`=200@4@`05QLB00T:1@0B4`h03Q0?00d?3P0?4A00
0P0A4a802`0>40l04aDD00L9200=3`h04aDD00lA400B51<03a4>014C400C5A804A<@00803a4>00L0
418?014C400@4Pl0418?014C400@4Pl03Q0=00@03a4>01D03Q0=01DG500;3@X061XG00T:200>40d0
30h;00T;1P0Q8ah04aD@00T;1P0B50l030h9010B3@0A4`h030h900/=200@4Pd03a4<01<E400>40/0
0P0B50l0100<3PT04A<>01<E400@4Pd200lA30<0418=03805ALB01HH4`0>40/03Q0;01@F4@0B50l0
30h9018D3`0E5a802`d8014C3P0B5@h041<<014D3@0=40T04A@=01XM5P0>4@X030l801<F3`0A50d0
4QD>00d@2@0C5Pl03Q4:018E3P0C5Pl04A@=01<F3`0?4P/061/D01`O600A50d03Q4:018E3P0@4``0
3A09010C300E614051L@010C300A50d02@`501XM5P0B5@h04aH?02`_:00Y;2D04QD>01DH4@803Q4:
01X071lH01DH4@0?4P/041<<018E3P0D5a005QT?01<G2@0C5P/04QD=014C3P0A4a004aDC01<E4P0@
4Pd04A@<018E2P0A50P06QdD01HI4P0@4``04A@=01@G400C5Pl04A@=018E3P@051L@00h0:2XU030b
;@0E5a805ALB010B3@0D5a004QD<01@G3P0F6A005AP=01<F2`0D5``03a@=014F3`8051TB00`04QL@
00hC300K81T03A8;01LL5@0D6A806QlH01<H4@0C61804QLA00hC3@0F6aD201<H4P0801@I4`0E6Q@0
5AXD01@I4`0C61804QLA01XQ6P0G7QL201DL5@0801LN5`0J8AX051/D02/b:`0e?3D09bhW01PO600R
:B8201HO700_01DN6`0D7AX051dJ01<L6@0K924051dJ02@]:P14CDX0>44n01@O6`0C7QX05b<O01PT
800G8al062@P01TU8@0K9b<09S8^01PT800L:2@08RhZ01LT7@0E81T0:3<]02D`:P0iAD<0/Kfm04aH
F00S<C406b/X01`]9`0X>C80834W020a:@0O;R`08c<b02Ph=`0P<300:3Xk02`n?`0U=cT09cXm02Lk
?@0W>Sh0:3e002Xo@P0]@4@00P0[?T80400/?d<0;D1402m2AP0_@TH0<4=703U<D00aA4P0;3m303I:
C`0fBe00=daA03E:C`0cB4d0=4U>03I;D00gC54203Y?E00e03I;D00cB4d0<TM<03=7C@0dB4h0>TiE
03mCF`10E5d0?E5I03]?EP0lDEH0@5EG045GE00mDe00?55?03mCDP0oDe40?U==04=HD@10ED`0>Di5
03mDB`0kD4T0=DY503mCD@0lD4l0?51>03M;B@15FET0SJ2S08bOY01OLWL0CF1U03a?DP12EUD0BEiI
04QMEP14FU00?U9804]OE@1PM6X0C61F04QLDP14F4h0B5aB04eQE`17Fe40BEeC04EIC`11ED/0@EM;
03mGBP18GeD00P1?IU`00`1BJF40DfYR05A[H`0205E/IP0@05U`J`1LMG40EVm/059]J@1AK6L0DfiW
05A_I`1BKV<0DFeR051[H`1EL6T0D6]V069mN@1PNWH0DVUQ04mVG080CVEK0180Bf9H04QOE@1;HUP0
Bf9H04YQE`1]Q7X0BF1F04QPD`13Fdh0@UY=04IND@0mEDP0?EE903M>A015G580AEaC04IME@17GUH2
04UPF00404QNF`1:HE/0BF1J04MNF080AEaD03d0A5]C04AKD@12FDl0?eI<03iFB@0oEdX0BVAK03A>
A@0fD4L0?UE=03aCB`0oETh0>Di703M;A00jCTL0=TU302`o>@0[?SP0:STd02/j=@0Z>C@09cHa02Dd
;`0V=C009cHa02Xi=00U=2l093<^02Lf<@0V=C0093<]028a;@0Q<2d08S0`02Ha<`0Y<cD0:cDg02/e
=P0U;Rd082TV028[:00T;RL08B/S01lX8`0P:R@08B`V020[9`0O:RH06bLS01/Z9`0M;2T062LT01TW
9`0L9bD08bTW028X9P0/<S00728P02D[:@0S:BL082HT00807R@R0P0O9B<01P0P9B@06alQ01XN800O
8bD08RHX01TM7`8061`N00D06AdO01PL7P0<41806QhP01TK6P0501TK600701LI5P0J71T061XG01DG
500H6QL05aTF028S7P02034b;@0A02PY900G61<05AHA01LH4`0E5Q4051D@01HG4P0G61<05QPC018E
3P0A5Ph051L?01DH4@0D5a005aPB01hO6P0H61@00P0C4Ph05@0D4Ph0510=00l>2P0C4Ph04Q4=01/J
5P0D4`l04a8>01HE4@0e=30051<?01/J5P0?3PX05QDA01XI5`0=30/02PT701DD4P0D4a405aHD01<B
4002014@3P05018A3`0A40h03Pd;014?400C4A800P0E4a@02P0C4A804@l@00l=3P0@3Pl04Q0A01DC
500C4A804Q0A01<A4P091`P200`:2`0401XH6@0@3Pl03@/<00d;30803P`=0P0?3@h0100C3`h03`/:
00l;2P0A3@`5018>3@804@d<00h040`9020O6@0P81P0<S8V0;FfY`3oonh0k>gK08j?P@0H61005aHB
010=4P0;214030P>00d920802`L600T05A4@02`X9`0Y9B@04Ph=01<?3P0A3@`03`/:010<2`0@30`0
1@0>2P/01`0:1PL05Q8C00h:2`0>2P/00`0000l;300=2@X01@0>2P/200l;300500h:2`0=2@X030P9
00d92P0?2``00P0<20T02P0=2@X02PH700`82@0>2P/0510A00h:2`0@30d03`/<00`82@0B2@`20148
2`0301<:3@0D2`h04PT<00804PT<00l040L:00l62@0?1PT040L:00h82P0?2@/040X<00d72@0<1PP0
3PP:00P2100@2P`07aTK01/E5`0@2P`0200=1`T04@0;1@L04P`>01@>400A30d0JVAX0<W4bP0F4AL0
4PdD00h9400<1Pd04``C00l53@0>10`03P@=01863`0D21404PL@01Cooooo000Kooooo`8041@E00d0
3Q8C00010P0;3a005ATJ00hB4`072``041@E01LK70052@X04QHE01<E500G6AH07R0M008051HC00@0
1`T601<E4P0<3P/0418?0P0B51400`0:30T03a4@00`>3@0200/=300300d?3P0>40l04A<B00803a4@
00d04Q@C014C4P0?4A003a4>01PJ5`0C5A8030h;00lA3P0C5A802`d:00840@0K7AX0418?00805ALD
00h06Q`G01@F4@0C5A002`d8018D3`0?4@`05ALB01<E400@4Pd03@l:010B3@0D5A003@h900h?2P80
30d800D04A8=00l@2`0C50l051D@018C3P0200h?2P0>01HG4`19BdP09RPU00d?300C5A802@/800d?
300?4@h03Q0=00d?300>40d03a4>00h@300?4@`2010B3@803Q0;00@03a4<00d?2P0@4Pd051HA0P0@
4Pd0400A4`h03a4<00`>2@0>40/04Q@?010B3@0:30L02`d800lA300C5A006A/F028T7`0:2`H06AXE
01<D3`0?40/2018C3P04010A300F5a805AHA010A30804Q<>0180418A00/=300>40l04aDD014C4P0C
5A@02@/:00X<2`0H6QT030h=00H81`0F61L030h;014C400E5a@03a4>00d?300B514200lA3P803Q0=
00<03@l<00`>2`0>40d0100?4@h06P0>40d03a4>01DG500J71T09bTV014C400N81d03Q0;018D3`0A
4`h0418=00lA300>40/03a4<018D3`0H6QD05ALB00h@2`0A4`h03@l:018D3`0?4@`02`d800`>2@0=
3`X04A<>1P0@4Pd0900?4@`06A/F00lA300;3@P06A/F00`>2@0=3`X04aD@00lA30031@002`d800hA
2P0<3`P04QD>01HI4P0D5a005APA020S700C5Pl06A`E00hA2P0I71D01`X3018E3P0=40T03Q4:010C
300?4P/03Q4:00/>1`0=40T03a8;00T<1@0:3@H04aH?01@G40<041<<020030l8010C300=40T0:bhW
08jARP072P<00`H0028U7P0V:B8051L@014D3@0<3`P071lH014D3@0B5@h03a8;018E3P0>4@X02`h7
00lB200A50T04A@;014D300A4`h04A<@01LI5P0F61<0418=014D300E60l04QD:01@G3P804A@=0180
4aH?010C300>4@X04A@=00lB2`0@4``05APA01HI4P0@4``05aTD01dO6P0I6aH05QPC00X<1`0I71D0
4QD<01@G3P0F6A0201@G300:01HI3P0C61404aPA024V7`0?50d06b0I01DJ4`0Z;bP05a`E01hS7080
3Q<<00P041D>01LL5P0B5a4041D?01lT7P0K81X04QLA01<H4P@051TC00<04QLA01TP6@0F7AH00P0C
6Q<02@0F7AH06B0I01PO600X;bP0=chg01hU7P0I81T061lH01@M6P0201<L6@0X01@M6P0H8Ah06b@Q
01DN6`0J8b004AXG01<L6@0E7Q/08RdY01<N6P0F8Qh06BDQ01PT800E8Ad0520L01hZ9P0H92006BDQ
01XV8P0G8al06BHO01`W800E81X08bhX01hZ:00]>CT07b/[01`Z:P0L;2T06R/U024b:`0O<2H09cP`
02<b<00R<S409CDd02Hf=P0V>3P05BLW02Li>`809c/l00<0:3/o02Tn@@0Y?T400P0Z?D40BP0[?T80
;T550395B@0]@4@0<TE90313A`0cATX0>4]?02i1A@0_@dP0<dQ=03I;D00hCE80>DiC03]@E@0oE5T0
?55F03I;D00bAd`0<dQ=03E:C`0aATX0;dA703A9C00jCe@0>TiE03I:D`0gBe<0>TiE03iBF@14FEd0
A5UJ045GE@16FeX0?E5@03U=B`14FED0IGYc03eBB@0fBd80>4e403Q=A`0jCT`0?e=A03I:B@0iCTT0
@eQC03eAC`0oDe80?U9C03Y>C`1:GUl0AEUH04MKF010EDh0AEYA04AJCP0jCTD0?51704UME01;GeH0
EVYQ04YNE@15FE00BUiE04AHC`1:GUD0BEeD04YNE@17GE40A5a?04UPEP1>IE/0CFAJ0P1AJ600501E
K6@0FG1Z05U`JP1TNgH0LXR505YcL01AK6P0Eg9]05MbJ`1AK680Eg=W05=_H`1AK680FGA]05IaK01G
LFd0Hgah05=ZHP1@Ied0CVEK0P1?IU`08P1=I5X0BV5G05=ZH01DJf40TJRN04eTFP19HE@0D6QK04EM
D014G4l0?UI903iFBP0eC480@EQ>04=JD@15G5@0AeiF04QOE`19H5P0B5iK04MNF016GEL0AEaF04MN
EP18GeL0A5]C04AKD@12FDl0?EA:03aDA`0mEDP0A5iE02e7?P0_BD0303]BBP0<03E:@`0hBdD0?E1:
03Q;A@0/?cT0:c`f020_:P0M;2L07RdX02<b;@0V=C009cHa0P0X=c805`0T<bh09C@_02He<00T<bh0
93</02Lf;`0O;RX08c8_02@`<00S;Rl0:S@e02Tc<P0T;RX082TT024Z9@0R;2@082XR01hW8P0O:B@0
82/U01lZ9P0L9b<06RHR00806bXW00X05bHS01d[:`0[=S@04ALE02`b<02GWI/07B<Q01DK6@0R:2H0
7R@R0P0M8b40400O9B<08BLU024V9P0I7Ah061`M01lS900K7b005QXK01DI6P0I7Ah05ATJ01hR8`0<
414061`L01LI600H6QL201/M6P0=01XL6@0H6QL05QPE01DG500F61D06A/H01/M6P0E5a@05aPC02@U
800J6aH04A8=00h?2P0201XK5P0T01PI500E5Q405AHA01DF4@0B50l05QTB00lD3@0B5@h051L@00lB
2`0B4`d0414<00l?2`0@3`/04a8>01DC3`0E4@h02PT501DD400?3PX06APD01XI5@0A40`04Q4=01/J
5P0510005QDA01<B3P0>3@T02@P602LV900B4@l0;bh/08n>S0040`404Q4?0P0A40h01@0C4Q004Q4?
00l>300A3a004Q0A00804a4B01D04Q0A014?400A3a0040h?014?400D4Q<04a4B018@4@091`P01`D6
02LU9P0Q7b00JfUZ03<a<P0E4a@05aDF01@B4`0>30d03@/<00l=3P0C3`h00P0@30/201<?3PH04Ph=
01T04Ph;01<B3P0M7AD0>SX`0;>dY@3ooo40m_OW07AdI`0>3PH04Q4=00T72`0A3QL03PX>00h:2@0A
3@`03@T800H20@070`803@T8014=300D40l04`l>010<2`0?2`X03`/;00H03PX;00D04@d>00H20`0D
41401`<4018>3`0600h:2`803`/<0P0>2P/01@0?2``040`=014=3P0=2@X030P900803PX;00D03@T:
00P41@0:1PL02@D6014=3P0200`82@06010:300@1`X03PD801072P0A20/03`H90P0@1`X03`0?1PT0
3PD800h5200>1@P03PP:00l92`0@2P`03@L900`6200>20X030H800l92`0H4Q@050h@00`6200700h8
2P0?00P2100C3@l03`T;00l92`0:10H09AlQ02TT:P0F4AL01`8800P32@0=20h0100401<94@0@1Ph0
50XB00806a0H00<05@XBooooooooool04_ooool001_ooooo00T01@T:01TM7P0K7b00310A00lC500:
3Pl04QHG00T=3P011@H00P0>4Q<01P0<40l030h=01HH5@0E5a@06Q`I010B3`805ALD00D05aTF018D
4@0C5A803a4>00T;2003010B4@0400lA400>40l03@l>014C4P803a4@00l04A<B010B4@0?4A004A<@
01<E4P0>40d030h;00/=2P072@H03Q0=04=5@P25Qh@05QPE00h@3@0I6aP00P0A4`h02P0>40/03@l:
01DG4P0<3PT05QPC01<E400@4Pd03Q0;010B3@0F5a8200l@2`0300h?2P0A4Pd05AHA00803a0;00L0
4A8=010A300>3`X03Pl:00d?2`0_<Bh04A<@00803@l<00<01PP5018D4@0>40d00`0=3``01P0>40d0
3@l;00d?2P0?4@`03Q0;00`>2@803@l:00/02`d800`>2@0@4Pd03a4<01<E400F61<03a4<00/=200D
5Q406adH01@F4@02010B3@0700lA300>40/03a4<01DG4P092PD05AHA018C3P02010A300?01LH4`0<
3@P051D@014B3@0=3PT05QLB00`=200A4a803a4@014C4P0@4Q403@l>010B4@0C5A@020X900803Q0?
00P03a4@00`>3@0;3@X03a4>014C400=3``0418?01LI5P803a4>0P0>40d00`0=3``030h;010B3`04
00lA3P0<010B3`072@H051HC03Pj=`2JW9T0?d4n00lA3P0A4`h04Q@?01<E400@4Pd03@l:0P0@4Pd0
2`0>40/04aD@01<E400?4@`04Q@?00P:1@0J71L03a4<00`>2@0F61<03@l:00H0418=00<04Q@?01<E
400C5A000P0>40/00`0C5A0030h900lA300201<E400B01HH4`0X:RD04aH?00lB2`0A50d03a8;00`?
200?4P/09bXS01HI4P0I71D030l801LJ4`072P<03A09018E3P0A50d03Q4:0P0<3`P00`0@4``04A@=
01@G400200lB2`0301PK500G6Q<041<<00803A090P0;3PL05`0S9Ql041<<024T7@0@4``082<L00lB
2`0G6Q<010L001HI4P082`@06A`E01HI4P0E61405aXC01PK500?4P/03Q4:014D2P0A50T04A@;014D
300A50d04A<>008061XE01H04A<>01<F3P0G6Q404aH;014D2`0@4``04aH?014D3@0>4@X06QdF01PK
500C5Pl04A@=01LJ4`0J7AH05APA018D3`0>40/04A<>01`N6@0B50l02Pd60`0C5Pd05`0A50T04QD:
01LJ3`0A5Pl041D>01XO60083@H05AXC01<H4@0?50d04AH?01DJ4`0<4@X0:RlX01@I4P0K81X06AhH
00X?2@0;40X0314;01XO6@0C618051TC00<05AXD00<051TC01HM5P0F7AH0100F7AH01P0E71D04QTB
01/R6`0?5Pl05A`E00`C30804a`I02`051dJ01HO700K92407RLT01<L6@0E7Q/051dJ01hW900M9R<0
7BPT01PS7`0I9B4072PT01dY9@0I9B405b<O01dY9@0hA4007b/W020/:00T<2`06RLP01DP6@0M:280
5b8L02Hb<00H92@09C4a01l];@0J:RL072dW02Tj<`0Q<RP08S<[028a;`0S<c80=TI502`l>`0V>3P0
8S@d02Pj>P0W>c`0:3`m02Xn?`80:Ci100h0:ci202Xm@@0[?T80;T550354B00dAd/0;T5502`o@`0b
ADT0=4M;03=6BP0cAd`0=DY?03Q=DP80>TmD02h0?55F03mDF@0kD5D0=DY?03=8C@0fBe00=daA03A9
B`0dBTP0>Tm@03iCE`0lDEH0>DeD03U=E@0lD5L0@5AK04EJG`16Feh0@UMJ03iBDP0lD4l0AEUG03eB
CP1<HEX0<DHm03Y?AP0aASd0>Tm904AHEP0lD4h0?51?03M<A`0nDd`0>Di:03I:B00kCdh0?e=A049F
E011EU40@eQB03]@A`13FDd0AeeA049FC@0nDTT0CV9I0P1<H5L0:P1=HEP0E6QO05M[HP1=HEP0CV9I
04]OEP1:GUD0Bf5E04QPD`1=I5X0DFQN051WG@1DJf<0CfIN05=ZHP1FKFL0EFaV05ieL01[PGh0FG9_
05=/J@1ILVh0F75[055[H@1GLFH0CVQM04mYG`1HLF/0FgA`05M`K01VOg/0E6]S055XGP1?IU`0D6MM
055XGP1@Ied0EFaR04mVG012FDl0IGab04YQE`80AemB00T0A5a>04IND@0nETT0@5Q<03]BB013FU00
AUeD04UPF01:HET00P1;HUX02P1;HEh0@5MA03iEC`14FeD0B5mG04MNEP14Fe<0A5]A049IC`0mE4X2
03aDA`0D03]BBP0eC4@0=di603]BBP0iCTL0>4e603E:@`0hBdD0?E1:03M:A00/?CL0:3Tc02Dd;`0Q
<2/08S4/02Th<`0_?ST0<3lj02`k=P0[>SD202Lf<@0E02Dd;`0P;bP093@Z02Lf;`0O;RP08S4^028^
;00Q;2/09c4`02H`;`0T;R/08R/V02<]9@0Q:b<07RPP01dV8@0N:2<07bXT01dX900L9b<072PT0080
7B`Y01<06BPU01l];@0R;2/0;S@b02<Y9`0Z<2h06AlM03Dk>@0G7A/0728P01/Q7`0L8R007R@R020V
900T:BT07R8S01`P8@0Q9BH05a/L00806alP00L04aLH014E5P0L82404ADF01dQ8@0G6AP061XG0080
6adJ00D06Q`I01PJ5`0H6QL05ALD01LI5P0201/M6P0:01HH5@0;30L05aPC01DF4@0H6A@051D@01LH
4`0J6aH05aPC01DF4@8051D@01T04Q<>01LI500@5@l04Q@?01HH4`0E5a804a@?01LH4`0E5A0051<?
01DD400D4Ph04@d:03hm>@0[:RH02@P4010?2`0I61@05QDA00l>2P0B4@d020L300`;1`0G5Q803Pd9
00802`X800X061LE01XI5`0_;R`051<A014@3P0@3`d04A0>01<B400B4@l03`h<0P0@3Pl2014?4080
40h?01<0518C014?400@3Pl04@l@010>3`0>30d0518C004000050`@02PP901`J6`030@805A<D01LE
5P0D4Q<03P`=00d;300?3@h04`l>00804@d<0P0C3`h00`0A3@`04Ph=018>3@03018>3@0I018>2`0N
7AT04A4900`<0P0m?S40LG9T07EfJ00^;R803@d501<B3P0:20/04PlH00h:3P0?2`X03PX900`81`0A
3@`061@C01DA400@30/04Ph=014=300>2PT03@T800h:2P0500h:2`06010<3@060P<00`00018>3`0?
2``02@D61P0>2P/500l;300?010<3@0?2``030P900/7200<20T03PX;00l;30030000@Cdn034];P03
00003@T:018>3`0B30h040X<00803@L900<03PP:00d72@0>20X00P0>20X02P0=1`T030H800`6200>
20X03`T;010:300=1`T030H800h82P0A2`d200/51`0300h82P0=1`T040X<00H03PP:01803`T;018<
3P0400001P02014;3@0<1PP0100501<>500R7B<00`0400d73P0F3aH040H>00`22P0?1@d05@XB01@9
4@0=0PXDooooo`006oooool0100<41405a/L00X>3`0;3a0200hB4`0C00H:2`0B5QL0310A00hB4`0;
3a003a<D00/=300@4Q003@l=00lA3`0E5aD071hL018D4P0N81h051HD00h@3P082PP04aDC00h@3`02
00d?3P0400h@3`0?4A003a4@014C4P803a4@01D0418A00lA400=3`h03Q0=00T;200;3@X0828O01lQ
7P0>40d04aDB03Tk>01bM74061XG00h@3@0?4@h03Q0;024S7P0<3PT051HA00`>2@0:30L00P0A4`h0
2`0?4@`03@l:00d?2P0>40/03Pl:01LH4`0D5A003@h9018C3P0?40/0414<00804A8=00X0414<014B
3@0<3PX04Q@A00X<2@0B514020X700lA3P0A4a003Q0=0`0=3``00`0>40d03@l;00h@2`0200lA3080
3@l:00l03a4<00h@2`0=3`X03a4<00/=200>40/04aD@018D3`0?4@`051HA01XL5`0F61<03@l:00h@
2`0?4@`00P0=3`X05P0@4Pd0;BhY00d>2@0?40/06AXE00d>2@0B4`h0414<01DF4@0?40/020T401DF
4@0A4Pd04aDD01DG5P0A4a804Q@C01PJ6@0=3`h0418A01<E500Q8b8200d?3P0301LI600=3``03Q0=
00803a4>00@04Q@A01HH5@0@4Pl04A<@0P0@4Pl0100A4a00418?014C400@4Pl200lA3P0F010B3`0A
4a003a4>01<E4P0F61D0EUQE02DW900C5A804A<>018D3`0A4`h03a4<00h@2`0@4Pd03Q0;018D3`0<
3PT02@/600lA300B50l03a4<018D3`802`d800H04Q@?00d?2P0?4@`0418=014C3P0B50l3010B3@03
014C3P0>40/03Q0;00804A<>028051HA00lA300B50l071hI02PZ9@0l?ST04QD>010C300C5Pl04A@=
00lB2`0B5@h04aH?00hA2P0D5a004A@=018E3P0<3`P041<<01HI4P0C5Pl041<<00lB2`0=40T041<<
01<F3`0J7AH05APA014D3@0D5a004QD>00hA2P0@4``04aH?0P0B5@h02@0A50d01`X501<F3`0?4P/0
51L@00`?200@4``05aXC01DH4@02018E3P0W01@G400B5@h04A@=010C300=40T04aH?01HI4@0@4`T0
41<:014D300A50d04A@>01DG4@0F618051L@01@G3`0E60l051L=01LJ4`0B5@h04aH?014D3@0@4``0
9RTR01@G400B5@h04A@=01HI4P0G6Q<04aH?01TK5P0<3PT04aD@02la;00e=c805QTB014D2`0C5Pd0
5AP?008051L<00<05QT>018G400B5a000`0C61403P0D6A805AXC01dR6`0E6Q<03A8;04Y?B00g?3D0
6b0J010E3`0I7QP0=c`f02hc;@0?50h05AXD0P0G71H201PM5`0301LL5P0E71D061lH00806R4J00P0
61lH01DL5@0E71D051/D010G400F7AH07B@M01HM5PH05QlL03`06B8O01/T8@0D7AX06B8O01PQ7P0P
:bL07RTU01`X900N:RH08BdY020/:00N:RH05b<O020/:00e@Cd0?4Q401dY9@0K:2407BPQ02<^:00N
:B<07BTW01dY:@0S;bl0:SPh01d]:P0I:R@093D^024b:00V=bl0:3Ld02De<`12DU009cLf024c<P0_
@D00:cdm02Lk>`0X?3`0;41102Xo@@0X?Cl0<4=702`o@`0[?T80:Se102/n@P0_@TH0;T5503=6BP0n
DED0>4]?03A7B`0fBTl0>e1E03iCF00mDUL0>TmD03U>D`0jCe@203M<D@0U03]@E@0lDEH0=T]@0357
A`0fC4T0>U1=03aBD`0jCe@0>dmF03mCF`13Ef00@eMO04IJH@15FEl0@UIL041EE`0oDe80>Ti=03Y>
B`0oE4l0?55:03aAB@0nDd`0?E9=03iBD00dB4L0B5aK03iCC@0jCdL0?E9;03Y?B@0mDT`0@EI@04AI
D`10EDd0B5eD049HC002049HB`0D04]PE`10EDd0B5aD04aQF@1AIUh0B5eE04YOE`1@IEd0C61H059W
G`1CIel0E6UP051XF`1>IUT0DfYP05I]H`1CJV00E6]S05I]I@1HKfL205YaJ`0R05]aK@1MLg00EVm/
05YcK`1ILV`0Eg5X05A^I01EKf<0EW1T05UcJ@1FL6L0GWMa059[IP1HLF`0F6mW05A[H@1AJ5h0DVUO
05=ZH01BJEl0CfIL04iUF`1:HEL0D6MM04UPEP0kDdH0@5Q;049JC@1:HUD0AEe@04aSF01<HeT0B5mE
04]RF@<0CVEM00h0C6=K04aRG`11F580@5MA04ELEP16GED0AEaD049ID@13FU00@EQ>03eDBP0mEDP0
?UI903aCB@80?eI=00@0?59:03U>AP0gC4@0?5590P0iBd@01@0bA3d09SL`02<d;@0T<bh0:STd0080
;C`g03L0;Sdh02ln>@0_?ST0<D0k02ln>@0^?CP0:3Lb020_:00M;B807RhT020_:@0R<B`09C4_02D`
;P0S;B`08bhZ028/:00Q:b<082XQ01hX800M9al07BHQ01lY8`0O:R@07BPT01dY9@0N:RH07B`Y01l^
:`0K:RL072XZ01dX9P0S:BL06b4O01dS8@0K8Al09R`Z01`R800J81h0728P01lU8`0P9R@08BLU02DZ
:@0F6QX03a<C01hR8P0K7al09BTY01lS8`0C5aL06AdM010D500X;2`05ATH00H06A/H03<06Q`I01HH
5@0H6QL06A/H01DG500G6AH071dH01dN6@0K71L07b0K010A300G61<05QLB01@E400C50l05AHA01HG
4P0E5a803a4=01HK5P0E5a<03@l;018D400C4a004Q<>014A300A40`04a8>01DC3`0E4@h0<c8^02@S
7`0C4Ph06QTE018A3@0<2`L05aHB014@300o?SX06QTE018A3@0G5Q8040l=038a;`0G5QD05aHD00h=
300C4Q004A0>010?3@0A40h00P0C4Q000`0@3`d040h?010>3`0200l=3P8040h?00`04a4B010>3`0=
2``03`d>00d;300<2P/03P`=00/92P0C4A803@/<01XI6@071@H200d;30803P`=0P0?3@h01P0B3Pd0
40`;014=300C3`h04Ph=010<2`<04@d<0`0B3Pd0600>30P05A<>01<A2P0D4`P08R4E02TY700E4`X0
518=00l<2@0B3a402`L>00`8300A3@`04Ph=010<2`0A3@`03PX900d9200?2`X040`;00h:2@0<20L0
3@T800h:2PD03PX;00L040`=00l;3018A4D05Q8C01DA4P091@H03`/<00D03PX;0P0@30d08@0?2``0
3PX;00h:2`0>2P/03@T:00l;300>2P/020@500X61`0=2@X040`=02hZ:`0R7Ql02`L800h:2`0=2@X0
5a4C01@>400@2P`03`T;010:300?2@/03PP:00l92`0@2P`03`T;00h82P0=1`T03PP:00l92`0@2P`0
3@L900`6200200h82P0400X41P0<1PP04P`>010:30L03@L90P0;1@L0400B30h03`T;00`6200=1`T0
4PdA01dH7@2^ZJh0EU5F00/62`0<1`/040H=00h52`0>10/040D<01463@0>0`XDooooo`006oooool0
7`0=4A804aLH00`@4@0>4Q<03a<D00hB4`0@51D02`l@00lC500E6AX02@d>01HJ6`0;3@`01`T801LI
60082PT0<C<b010B4@0B51<03@l>00T;2P0H6QT020X900d?3P0@4Q403@l>00`>3@0@4Q4061XI01/M
700@4Q400P0=3`h05P0>40l03@l>00/=300>40d06A/H014C400>40d04A<@00`>2`0;3@X051HC00`>
2`0:30T030h;010B3`0B50l0HVAO00lA300=3`X04A<>00h@2`0@4Pd2018D3`09010B3@0?4@`0414<
01lP6`0e=S409RLR00X;1P0>3`X0414<00804A8=00X03a0;00h?2P0@4@`04A8>014C400J71T06adJ
00d?300M7a`02`d:0P0=3``01`0<3P/03@l<00d?300>40`03a4<014C3P0@4Pd00`0>40/0100=3`X0
418=01<E400=3`X200`>2@80418=024020X500T;1P0>40/02@/600/=200=3`X030h900/=200<3PT0
3a0;00<4000G61D04a@?01HG4P0B4`h01PL2010A300E5Q402@X5010A300?40/0418A01<E500=3`h0
7R0O03@f=@0K7A`03a4@00d?3P0I6aX03Q0?01@F5@0E5aH00P0>40d01P0@4Pl04aDB018D4@0=3``0
30h;00d?30803Q0=0P0?4@h0;P0B5140418?00h@3@0>40d0418?018D4@0D5Q<05QPE018D4@000@00
6A/H00`>2`0>40/03@l:00T;1P0>40/04aD@00`>2@051`8092HQ028T7`0F61<05ALB00h@2`0Z;2L0
3a4<01<E400D5Q4030h901dO6P0>40/0418=014C3P0B50l04A<>010B3@0F61<04A<>01@F4@0@4Pd0
3Q0;01DG4P0C5A0030h901<E400F61<200@60@07014D3@0=40T04aH?01@G400:3@H01`X301@G4002
00lB2`0601<F3`0>4@X05aXC01@G400@4``02`h70P0A50d01`0:3@H04A@=00X=1P0=40T03Q4:010C
300C5Pl00P0?4P/04P0D5a005aXC01@G400B5@h03Q4:01@G400F6A804QD>00L:0`0G6Q<03a8;03Dh
<@0[;RL00`H0028U7P1>DDX05QTB014D3@805APA00D04aH?018E3@0?4PT03a89010C2`02014D3@0:
010C300A50d04aH?01<F3P0A50/04aH=01@G400?4P/05APA01HI4P8030l801L04A@=018E3P0G6Q<0
6ahG01TL5@0C5Pl030h9018D3`0K7AP04Q@?01HH4`0?4P/030l6018E300K7QD071lD01TL4@0E60d0
41D>01@I4P0?50d092TR01@I4P0201<H4@09014F3`0oA3d092TR014F3`0E6Q<04aPB01@I4`0@5@l0
6QlI00805a`F00<05Q/E01PM5`0I7QP00`0I7QP03@0C6Q<051/D01DL5@0E71D051/D01<J4`0530D0
6b8K01<J4`0L8a`05ahG01`S700C71T00P0E7Q/0<@0D7AX04AXG00lH5@0G81d072DR01TR7`0O:2D0
72DR01lZ9P0I92005B4M01HR7P0L:2@07BTU01/W8`0Q;BT06RHR024]:@0L:2@05b<O01dZ8`0L9b00
8RdW00lJ500Z=S@07b/[028^;P0P;Rh093@a020a:`0S=2d0:c`b03a=A@0c@Sh09SHc02Ti=P11DE00
D6=Q02`o?@0[?Cd09c/j02Tm?00]@D80:Sm002Pm?P0]@4@0:Se102Tl@00Z?D400P0[?T80;00hBdl0
=TU=03A7B`0jCE40=DQ<03U=D@0jCe@0?U=H03mDF@0mDUL0?55F03iCF00kD5D0=T]@03M<D@0iCU<0
=T]@03E;B`0kDT`0?UAA03iCD`0mDUD0@5AK04MKH`17Ff@0AUYS04EIH@13Eeh0@5AK03a@E@14F5T0
?U9A03Y>C00/@C`0Bf1K03Y?B014FE80?U=?045EE01BIVD0Oi>C049GDP0gC4<0?U=:0P0fBd801015
FU00AU]B03U?@`0oEDT203mEB00:04MMC`1?I5/0IW]d06UnM`0oE4d0@eQA04QMEP1;H5T0DFIO04mT
G@80F6eV01/0FFiV05A[H@1CJeh0EfiT05Q_I@1BJEl0CfIN05A[H`1EK6@0Fg9/065hLP1OMG40FW1]
05E^JP1PNG@0FG=Z05I`I`1ILfL0E6iQ04iXF`1FL6@0CVQO05efL01EKVT0E6eW05]bJP1FKF<00P1B
JEl0401CJV00DVUO059YG`1;HUP0AUeC055XGP16GE<0BF5D04mWFP18H580B61C04=KCP18Ge@0@eY@
04IMD`19H5L204]RFP0H04UPF017GUH0BV1M04]RG019H5X0AEaF04=JDP14Fe<0@5M?045HCP10Edd0
?UE;03eEB00oEdX0?EA:03]BB00hCdD0>e1703eBB@0lDDP0>Ti503E6?P0dACd0;d0h0P0X>C40D00Q
<2/0:CPc02Xi=00/>cH0=4<n03]:A@0^?CP0<d8m03A3?P0eA3l0;3/f02<b:`0J:R0062PN024`:P0O
;RT08bl]02Lb<@0Q:bX07bXV01hX900L9Qh0628J01/U700N:2007RLR020Z9@0P:bD07RTU01/W8`0H
920062LT020_;00O;R/07B/[01`W9@0R:2H09B/Y024W9@0R:2H03aDC01PN700I7ad07R@R028X9P0S
:BL08RPV04M<B`0o@d806QhM01PL6`0B5QD06QhM01dQ800=4A0061`K01`P7`1ZKVd0720O01/M6P0J
71T061XG01LI5P0H6QL06adJ01TK600F61D05aTF01<E4P0>40d05ALD00l@2`0I6QD0=CHa03dn>@0I
6QD05QLB01TJ5@0G61<051D@0P0C50l08P0A4`l06A/J02lc<P0[;B/030h;010B3`0F5Q@08B4O01`L
600F5A405A@@01@B3P0B3P/05QDA014@300B4@d061LC00`;1`0D4`l02PT501@C3`1CDTh03`h:01<B
3P0G5Q8030/900d<2P0K6QP03@`:010?3@0C4Q0040l=00l>300A40h201<B4003010?3@0B41404@l@
008040h?00H04@l@018@4@0?3@h030X;00X82@0=2``200h<3@0B00/92P0A3a004@l@018@4@0<2P/0
5Q@E018@4@0=2``03P`=014?400>30d02`T:010<2`0?2`X040`;018>3@0@30/03PX90P0?2`X0400@
30/04@d<014=300A3@`03`/8018?2P0F4`h05A8:01DB2@0K60l040d501@A30091@8040`=00L21P0F
4Q@200l;2P0:00h:2@0C3`h03`/:00/71P0@30/03`/:00`81`0;1`H03@T800l;2`D03PX;00L03@T:
024M7P2VXZ<061@E00d92P0@30d030P900D03PX;0P0@30d01`0?2``03PX;00`82@0<20T03PX;01XF
5`0H51D00P091@H02`0?2``00`0001DA4P0>2P/02PH7018>3`0?2``05Q0B01<=3`0>20X030H80080
3@L90P0?2@/2014;3@0700l92`0>20X03PP:00l92`0@2P`03@L900`6200200h82P0400d72@0?2@/0
3@L900P210L030H800H03`T;00`6200>20X03@L901PB500>20X200/62P0:01TD600<1`/03@L;00d7
2`0>1@X03`H;00h52P0>0`T040D;01@93aCooooo000Kooooo`04010D5@0?4a@03A4B00dA4P803Q8C
01802Ph?03Lk?00F6Q/07B4R00hB4`0?4a@05ALF018D4`0E5aH0004003/m?00A4a8030h=010B4@0?
4A002P`;00/=300>40l200lA400500h@3`0@4Q403@l>00P:2@0=3`h00P0@4Q402`0H6QT0;Bl^03Tk
>P0?4@h0418?01XL6@0@4Pl030h;01@F4`0B514061XG00803a4>01X04aDB00h@3@0@4Pd03Q0;010B
3@0C5A00418=00`>2@0A4`h030h900d?2P0B50l04A<>00`>2@0N7aX0Q8F004Q9A00E5Q402@X5014B
3@0B4`h0414<00l@2`0@4@`04Q<>01<E4@804aDB00/03a4>00/=2P0;3@X0418?014C400>40d030h;
00d?300@4Pl0418>00d?2P0200/=200500`>2@0?4@`0418=00lA300>40/00P0=3`X0100>40/03@l:
00`>2@0?4@`2010B3@L03Q0;100>3`X0700?40/04A8=01@E400A4Pd03a0;018C3P0C50l04A8=00L9
200H6QT04A<B00`>3@2SYJ@08R@S00d?3P0I6aX02`d<00d?3P0F61L05ALF01HH5@082PL0418?00h@
3@0D5Q<0418?014C400@4Pl400h@3@<0418?00H03a4>00h@3@0=3``03@l<014C400@4Pl200/=2P03
010B3`0A4`h03Q0;0080418=02403Q0;014C3P082PD03Q0;01HH4`0?4@`09BLR01TK5P0H6QD04Q@?
00d?2P0;3@P05QPC02/]:00<3PT02`d800d?2P0@4Pd01`T400h@2`0@4Pd030h900/=200B50l05aTD
00D70P0?4@`030h900d?2P0@4Pd04A<>010B3@0<3`P00P0C5Pl0<P0?4P/04A@=01@G400A50d041<<
014D3@0C5Pl04A@=00lB2`0A50d03Q4:01DH4@0:3@H03a8;01HI4P0@4``03A0900hA2P0A50d04QD>
01HI4P0/;bP06ahG010C300A50d01@P1018E3P0?4P/03Q4:01<F3`0E61404QD>028U7P0F6A8020/4
01HI4P0<3`P04QD>01hQ6P0B5@h03Q4:00d@2@0?4P/041<<00lB2`0=40T03Q4:010C2`0B5@`04aH=
0P0A50/04P0D5`h051L?01TL5@0W:R<04aH?00hA2P0C5Pl03Q4:014D3@0F6A8051L@01LJ4`0J7AH0
61/D01LJ4`0J7AH03Q0;01<E40804Q@?00X06A/F01DH4@0;3PD03a8901DH3`0G6Pl05QT>01PK400?
50d051TB0P0C61403@0I7QL051TB01/P6@083@H0F5eF018G400E6Q<06b0I014F400C61804AH@010E
3`0B5a400P0A5Q009@0F6aD010T306]`JP0I7QP05a`F01LN5`0C6Q<06R4J02<Z8`0b>C805QdF01TP
6@0H7aP05ahG01HM5P0G7QL061lH01<L6@0F7a`04a`I01LP7@0A6QL05b0M02@]:P1ZLg007bPU02L`
;@0J8b007BPT01/V8P0H92005R8N01PT800K9b<07BTU020/:00M:BD00P0L:2@01P0M:BD07BXS01hY
8P0Z=Bl062<M028^;08082`/01L09S@d01h^:`0G:280:CXc03E6?00mCTH0Df9M0310?@0W=c@0<T8o
03=6A00]@3h0:chl02i2@@0/@3l0:3`k02Lm>`0Y?Sl0:ci20313A`0_@TH0<4=702`o@`0202e0A005
03U<D01@HfL0?U5E03U<D011EEX00P0oE5T06P0nDeP0>e1E03Y?E00kD5D0?E9G03]@E@0dBDh0<DI;
03I;D00iCTh0?5==041FD`0oE5@0?E9E049FG@13Eel0BUiW04EIHP1:GVH0Ae]R03U=E00oDeL0?U9C
03eAD00hC4X0>Di90P12Ee80500nDdh0?e=A049FE@0mDE00C61P041ED017G5D0>Tm604EKC`0oEDT0
?59503aBAP0oEDP0>e5403iDA`19Ge80B5iA04QME01GK6D0GW=/0P16Fe@02@1=HU/0CfAM059WH01G
K6D0FVmX05]`J@1JKfL0E6]Q05I^H@0205YaI`0O05I]H`1AJ600GGA/05ieK@1PMg40GgI`05abKP1I
Kf`0EVaY05Q^JP1OMVh0F6mW05YbIP1FKV40GWIY05UaI@1QN6h0GgI^05Q^JP1QN780G7=[05I]H`1C
JV00EFaR05I]H`1CJV00BF1F04MNE012FDl0EFaR04iUF`0204UQE00804QPDP17Ge80AemB04MND`15
G580AUeC04MNE@1?IUh204UPF01F049ID@1<HUl0A5]E04=JE016GEL0A5]C045HD016GED0?EA:03aC
B@0oET`0?EE803UAA00mDTT0?55803mDB`0kD4L0>Ti503iBB@0hBD40;Slg02`m=@0Y>34093</02Dd
;@0U=2l0;Sdh02/j=@0X=c80;C`g02ln>@0c@Sd0;C`g02He<00M;2L072/V01h]9P0/?380:STb02<b
;00Q<2/09S8`02@_;P0O:BP07bXV01lY9@0I8a/06bDM01lY8@0N:2007bPS01dW8@0J9Al06bHR020/
:00D81`09cHc020_;017EU<0938b01TS8P0M8b40728P01XP7P0K8Al07bDS01dS8@0K8Al08RPV02H/
:P0R:2H0:Bl]07^0OP1EFEP03Q8A01hR8@0B5QD05ATH00lC4P0B5QD0720O01XN7@0E6AP06AdL01lQ
7P0L7Q/401TK600301`N6`0J71T05aTF00805ALD00<05QPE01LH4`0G61<01@0G61<07`0F5a805AHA
01@E400F5a805aTE020R8@1lP840@dE500lA40082PT05QHE01HF500D4a004Q4=018A300C4@`04Pl:
010?2`0J6AD07ahJ01DD400@3`/01`H201TH500<2`L07A`H018A3@0920D07A`H018A3`0>3@/00P0H
5aD0500?3P`05A@B01DD4P0@3`d05A@B00/:200B4@l05A@B014?400C4A803`d>028P8@0c<C804@l@
01<A4P0B41403@/<010>3`0?3@h02PP90P0@3Pl08P0A3a004Q0A01<A4P0C4A803P`=00P61`0C4A80
30X;01/I6P0E4a@05a<B00H20@0K5aH02PH500P40`0G4a803PX900d9200>2PT040`;00h:2@0<20L0
40/8014<2@0B3@T050l:01@?2@0C3PP05Q4<00P3000=20D03PP:01D?4@0?2P/2018>3@0700l;2P0<
20L03`/:014=300=2@P02`L600`81`0200h:2@0E00/71`0K5aP020@501XF5`060P<06aLH00X61`09
1@H09b<T00d92P070`@061@E014=3P0<20T02`L8018>3`091@H06ADF00T51P0>2P/02`L800803`/<
00@02PH7014=3P0Q7Ah081`M0P0?2``00`0@30d03PX;00h:2`0200`82@0H00d92P0;1`P04@d>00l;
300>2P/00`0000/7200D41406ADF00P41@0U8B802`L800T51P0?2``08adO028L7P0C3@l030H801@>
400<1PP02P@600d72@0A2`d03`T;0P0=1`T2014;3@0<00L10`0?2@/03PP:00h82P04000050h@010:
300400004@/=00H00P0>2@d03@P<0P0<1`/01P0>20`03`T=0107300@1``03`H;01052`803`@:5?oo
ool001_ooooo0P0>4Q<0200<41402`l@00`@4@0<41403Q8C01PL7@0A5AH05a/L0P0;3a001@0<3@h0
3Q0@01LH6@0@4Q804Q<D00803a4A00<03a0A00h?400=3`l00P0=3Pl00`0>40l03a4@00lA400300lA
40803Q0?010030h=00/=300>40l04A<B00h@3@0A4a0020T703Hh=@1SIF805ALD010B3`0F61D03a4>
014C400F61D04A<@0P0>40/0600@4Pd04aD@014C3P0?4@`03@l:00lA300A4`h03@l;00d?2P0B50l0
1@H301PI500=3PX051D@01<D3`0=3PT04A8=010A300A4Pd04a@?01HG4P0E5Q80418?00h@3@803a4>
00<03@l<00h@3@0?4@h00P0>40d0100?4@h04A<@010B3P0>40/200d?2P0:00lA300B50l04A<>00lA
300>40/03a4<014C3P0B50l04A<>00h@2`803@l:00<03Q0;014C3P0>40/01@0>40/200l@2`803Pl:
01`03a0;014B3@0@4@`03Pl:00d>2@0?40/04A8=010A300@4Q402P`;00/=300B51<04aDD02PZ:@0?
4A003Q0?018D4`0:30/06adL00h@3`0?4@h02P`900h@3@0?4@h04Q@A00h@3@0A4a00418?0P0>40d2
00lA3P0800h@3@0@4Pl04Q@A018D4@0C5A804Q@A00lA3P0>40d200`>2`0400h@3@0@4Pl03a4<00d?
2P804A<>01P03@l:00lA300=3`X0418=014C3P092`H05ALB00T;1P0;3@P0418=01DG4P0B50l030h9
014C3P0?4@`030h900d?2P0@4Pd02@/6018D3`0=3`X02`d801<E400=3`X200lA3003018D3`0G6A@0
5ALB00803a4<00H04Q@?00lB2`0B5@h04QD>010C300?4P/2010C300G00lB2`0@4``04A@=010C300>
4@X041<<00/>1`0930D05aXC010C300?4P/06A`E014D3@0B5@h04aH?014D3@0=40T071lH018E3P0>
4@X04QD>00T<1@0C5Pl00P0A50d3018E3P0701XM5P0D5a003a8;01DH4@0<3`P03A0901@G400301<F
3`0J018E3P0A50d041<<010B300@4``041<;014D2`0B5@/041<9014D2P0C5Pd04A@<014D3@0I71H0
3A0900lB2`0A50d0:B`U02P[900B5@h03Q4:014D3@0C5Pl04QD>014D3@0C5Pl200lA300801<E400F
61<05ALB010C300B5@`051L>01LJ4@0E60d201<F2`05018G400D6A805AXC014F3`0>4``00P0?50d0
2P0L8AX04QL@020U7P0B5a004aPA018G4@0F6aD04AH@01TN600R9b43018G4@0<00lD3P0J7aT05AXD
01<H4P0<4``06R4J01<J4`0H7aP0HVUR01dT7@0>5@h04aXC0`0G7QL03`0I81T04AXG01PQ7P0@6AH0
5QlL01XS800R:bP09Bh[07b5PP0X<Bh04AXG01hW900E81`07bXV01/W8`0201TU8@0301XV8P0K9b<0
7BTU008072PT01H07RXV024]:@0R;bP08bhW02D`:P0X<bd0<Shl02<_;`0K9bL08S0`02<c<00[?3H0
:c`e049CB@1_P7H0d]kL09j^ZP1HJ6@0<T<n02Lj=`0aA440:chl0P0]@D004@0/@3l0:d4o02e3@@0`
@dL0;T5502Tl@00/?d<0<4=70395B@0`@dL0<TE903e@E00jCE40?E1D049FF`0nDeP0?55F0080>e1E
00D0?55F03I;D00aAT/0=DY?03]@E@0203eBE`0?03Y@D00lDTl0@5IC04=HF@11EU/0@5AK04EIH@1=
HFX0@eMO04UMI01<HFL0@5AJ03iBEP10DeL0@UIG0080@UID01`0AeaG04UNF@0oE4l0Cf=Q08nSXP1<
H640@UEH04EIE`1;H5X0@UM?04QME014FTh0?UA7041FB00oEDL0@5I904EKC`18GU40B5iB04iTG@13
FE<0AUaE04UOF@1EJfD0CfEN059XHP1DJV<0F6iW0P1JL6T02@1IKfP0EFaR05I^H@1IL6H0FW5W05U`
IP1HKfL0FW5Y05]bJP0205edKP0W05]bK@1HKV/0GWA`05ecK@1PMVl0F6iT05]bIP1IL6<0Jh9e05ie
J@1JL6H0FFmW05abK01^Q7h0G7=[05U`IP1FKF<0EfiT05I]H`1CJV00B5mE04]RF01:HEL0E6]Q04QO
E@0oEdX0AUiA04ALC`18H5<0CFEH04eTF@18GeD0BV5G05=ZH@1HKfL0B5mG04AKD`15G5@0BEmL0080
DFQR00D0BF1J03mFCP0lDd/0>e9:03iEB`02041GC@1903eEB00lE4L0?59704IJD011ET`0>Tm503e@
AP0nD4L0=TLn02dm=00/?C@0:CP`02De;00W=Rl08S4/02He<00W=S40<3lj03A3?P0b@C`0<D0k02Xi
=00S<Rd072/V01d/9`0Q<2/093</01l^:00T<bl0:cTh02`h=`0Z=CD082XZ01XT900P:BL082TT01/T
7`0J91d07BLO01hW8P0M9b8072LQ01dX900Q;2P07RXV02@c<00G9R<0=DA101PV9P0M:2H08BLU02@Z
:00S:BL07B<Q01/Q7`0I7ad05adK01XP7P0N92806b4O01dS8@0S:2H0720N01TN6`0A5Q<04aLE01LL
6@0D6AH051PF01TN6`0J7a`05QXH01LL6@0201/M6P0501XL6@0F61D05QPE01TK600E5a@00`0D5Q<0
0`0F61D06A/H01LH4`0501LH4`0301@E400C50l051D@00804a@?03804aDA010A4`0`=3H0414D01@E
5`0F61P04A4A01HF500D4a004Q4=01<B3@0D4Pd04a0;01HE4@0C4Pl05A@@018A3@0K6QL0:BPT05YI
E@0K6QH04Q4=01LF4P0E51003@`801<B400?3P`040l=00d<2P0C4Q00:bXX014@3P0@3`d030/900h=
2`0U92804Q4?01DC500D4Q<030X;010>3`0H5QL03@/<014?400>30d03`d>01/I6P0G5AH02`T:014?
408040h?01D03`d>00h<3@0>30d04@l@00h<3@0=2``04a4B00L51P0B41404`l>00l;2P0<20L040`<
01`H5`0?2`X040`;00l;2P0@30/04Ph=010<2`0>2PT00P0A30X03P0B3@X04@`800l:1P0>2@H050l;
01/E500Q6a/050h>01<=3P0>2@T040`;014=300@30/03PX90P0?2`X200d9208040`;01803PX900l;
2`0=2@X02PH703/g>00:1PL03@T:010<3@0A3@h0BDE600h:2`0C3a001`<400l;300>2P/03@T:02XV
9`0C3a03014=3P802`L800H030P900T51P0<20T040`=00h:2`0810D200l;300O01<?400=2@X03`/<
014=3P070`@03@X:00l<3@0F4a@0514B014>3`0:1`P04Pl@02TV9`0;20T03@X;01HC500J5aP040`=
01PB500I4aD03`T;00d72@0E3a4040X<00h82P0<1PP02`D700`6200>20X040X<00/51`02010:3004
00h82P0:10H03@L9014;3@802PD600D07aTK00/51`0?2@/02`L900d92`0200l;3@0600h92`0<1PT0
40L;01072`0?1PX040D:0P0?10TDooooo`006oooool00`0A5AH041@E00hB4`0200hB4`0>00lC500@
51D020`=018F5`0>4Q<05ATJ00hB4`0B4aD030d?00l@4P0I6Q`03@h@00`=3`0A4Q@200d>4003014B
500?418030d?00803a4@00@0418A00h@3`0?4A0051HE0P0>40l0100@4Q4051HE01<E500B51<2014C
400;00P:1`0G6AH0=SPe00X<2@0<3P/03a4>00/=2P0=3``0418?00d?300B50l00P0A4`h04@0?4@`0
30h900X<1`0<3PT05ALB00D70P0[;BP0=3Ha00T:1P0H6A@04Q<>01HG4P051P404A8=018C3P0C50l0
4Q<>00<0414<00<0:2TU02la;P0L7Q/00P0=3``0100>40d03@l<00`>2`0>40d3014C400700lA3@0=
3`X03@l:00h@2`0@4Pd04Q@?014C3P0200h@2`05010B3@0A4`h04Q@?014C3P0>40/00P0=3`X00`0>
40/0418=00lA300500lA3006010A300?40/03Pl:00h?2P0?40/0414<0`0=3PT05@0>3`X03a0;010A
30072@P08R@S00d?3P0>40l061XI00lA400@4Q404A<B00lA400=3`h0DE=B010B4@0?4@h06A/H010B
3`0C5A803a4>00/=2P02010B3`803Q0=01003a4>010B3`0C5A804aDB018D4@0A4a003a4>00d?300@
4Pl030h;00h@3@0B51404aDB00d?300A4`h0418=0P0F61<0200@4Pd04A<>00h@2`0@4Pd03Q0;00/=
200A4`h02`d80P0B50l07@0F61<05ALB018D3`0G6A@03a4<00h@2`0@4Pd04aD@00X<1`0A4`h03Q0;
00d?2P0B50l03@l:010B3@0=3`X04Q@?01PJ5@0G6A@0418=00h@2`0@4Pd041<<00hA2P0?4P/04A@=
010C300?4P/041<<00803a8;01@04A@=00lB2`0=40T05QTB00lB2`0D5a003a8;010C301<CdP04aH?
00/>1`0@4``05QTB01@G400@4``061/D01@G400C5Pl04A@=00/>1`804A@=00L04QD>010C300>4@X0
4QD>010C300>4@X04QD>00@04A@=00H04aH?01DH4@0E61404QD>014D3@0A50h2018D3`0:014D300@
4`X041<8014D2@0D5``05QT@01@G3`0@4``04Q@?01<F3`805QTB00H0EEQA059ECP0G6Q<04A@=018E
3P0D5a0201<F3`0[018E3P0I6aH051HA01`N6@0R91l06A/F01DH4@0A50/04aH=01HI400D5``04aH;
01DH3@0?50d0314:014F3`0F6a@04aPA01LL5@0I7QL051TB01TN5`0>4``02@h701TN5`0B5a404AH@
01DJ500K81X0724K014F400=4P`05a`F01<H4P0F6aD0;S<]01LL5P0E71D03aH?01@K500B6A804APA
028Y8P0201PO600B01TP6@0K8Q/06R4J01HM5P0?61D0624N010I5P0K92408BXW01XS800H8Ah03QLD
01DN6`0G81d05AhK01PS7`0O:RH07BTU0P0K9b<07P0L:2@07BTU01XV8P0J9R806bLS01dY9@0O:bL0
7b`U028]9P0L9b409C0Z04UED`0iADD082`/02dk>`0X>3D0;d0j02m0>@1DIE/0Sj2F0>WhlP2L[JL0
@55;0393?@0X>cL0;d8n02`o?@0/@3h0;D4o02a0?`80:d4o00<0:Si00313A`0`@dL00P0dAd/0300`
@dL0<TE90395B@0fBDd0A5MK04YMH@13Ee`0>DiC03E:C`0dBDh0>4eB03aAEP80@eQM0P0mDUL203mD
F@0Z045FF012F5H0?eAE041EF@14FEh0AEUP04UMI@18G6<0@5AK045FF`14FE`0@5EH03iBE011E5P0
AEUJ04EIF@10E580?U9@03aAC019GUT0A5QG061dM@1KKg00AEQL049FE@16FUP0AEYD04QME019Ge<0
@eU<03mFAP0jDD40@UQ;04UOD`12F4`0AEY@05I]I@1AJ680D6MQ04aSG@1RNG<0E6]U0P1FKFL305U`
JP0905Q_J01GKV@0EViQ05M^I01HKfD0FG1V05]bJP1JLFT0Fg9Z0080GGA^02d0G79^05]aKP1RMg80
GgA^06=hK`1LLVH0I7Y^06IlK`1CJE`0FFmS06EkK`1SN6l0EfaV05EZH`1LLf/0G7=Y05]bJ01JLFL0
EfiT05A[H@1:HEL0C6=I04YQE`1<HeT0BV5G04YRE@11FD`0@5Q:04EMD01<I5L0C6=H04=JD016GE<0
@EQ?04ELE012FE40BF1H04IME@16G5T0DFQR05=ZI01:HE/0?eI>03]BBP0mE4`00P14Fe40:`0lDdT0
>51303UAA010ETX0BEeB03a@A@0jCT<0@U=903a=@`0hBCl0;cle02`l<P0V=R`08C4W028b:00[>SD0
;C`g02/j=@0`?cX0<d8m0350>`0Z>C@08C0[01XY900H9b8072/V020_:P0X=c808S4/02Lf=00X=SL0
:3<e02D_<`0N:2X07BLY02Xc<`0X<Bh072DR01LP6P0K9Ad07BHQ01hX8P0M:2800P0O:RH01P0Q;BT0
6BPU01l^:`0lBdP06RPX028/:`808bTW01H082HT01/Q7`0J81h0728P01PN700G7A/07R@R01dS8@0K
8Al08RPU01@I5@0=4Ph05AXF01TN6P0G71P06QlK01HK5`0H7AT06QlK01LL600E6QH06A/H0P0L7Q/0
2@0E5a@04aDB01XL6@0K7AX06Q`I01LI5P0F61D05aTF01PJ5`0301LH4`@05QLB01d05aPC01PI500H
6A@05aPC01@F4P1lOH40hNCY02d^<`0e=SX07QlQ01DE5P0F5Q@051<@018A3@0C4Pd05A<>01@A300A
40`04Q4=01<B3P1SHUh0UIB@018A3@0A40`030/701TH500@3`/030/7018A3@02018A3`0G01@C4@0A
40h040l=01`K6@0B4@l051<A00h=2`0920H071/I00X91`0L6Q/05aDF01<A4P0?3@h03@/<018@4@0A
3a003`d>00h<3@0F51D04a4B00X82@0@3Pl00P0?3@h200h<3@0C00d;301PGUl03`d>01TG60091`P0
6QPI014?400T81l03@T800`81`0C3`h01@4001HB4@0>2PT03@T800h:2@0@30/03PX900`81`03014;
2`0=010:2@0>20P03@P501hI5P0O6AT07ALG00/61P0A2`/03`X900d9200?2`X040`;00l;2P0200h:
2@0B00d9200<20L03PX900l;2P0>2PT02@D501PD5@0:1PL030T9014=3P0H51D02PL700<0000U8B80
4`l@00h:2`0C3a00:BDV0P0H51D03`0l>3T061@E00X61`0>2P/05Q8C014=3P0>2P/04Ph?014=3P0C
3a003`/<00X61`0=2@X04`l@00`82@0201<?40803`/<010030P901/G600100003`d>00P61`0=2``0
2`T:04E3A02/ZZ/0:BLX01PF5`0?3@h040h?00@20`0<1PP03@L90P0:10H01@0@2P`03PP:00l92`0@
2P`03`T;00802`D700l03`T;01<=3`090`D0208400`6200B30h02`D7014;3@0I4aD091hP05A>D00I
4aD04`d?00/7200=2@X00P0?2``01P0>2@X030H801072P0@1`X03`H901052@803`@85?ooool001_o
oooo0P0A5AH04@0?4a@03Q8C00lC500?4a@041@E014E5P0G6a`02`l@020T9@0D61T02``>014B500B
4aD03@h@01<D5P061`T04A8D00803PlA00X04Q<E010A4`0=3Q0030h=00X<2`0?4A004A<B01DG5P0L
7Qd04Q@C0P0>40l01P0?4A003Q0?00d?3P0?4@h04Q@A00lA3P803Q0=00@07R0M00h@3@0>40d02`d:
0P0<3P/05P0:30T04A<>018D3`0A4`h03Q0;00/=200:30L02`d801LI50051`80:bdX03<e<0092PD0
5aPC0001000@4@`02P/601LH4`0C50l04A8=010A300?40/200d>2@0=01hO6`0Q8b004A<@00P:1`0=
3``04A<@00lA3P0<3P/03Q0=018D4@0A4a00418?00h@300200`>2@0500d?2P0>40/03a4<00lA300>
40/00P0?4@`400h@2`803a4<00<03Q0;00d?2P0?4@`01@0?4@`2010A300400l@2`0>3`X03Pl:010A
30@03a0;00P0414<018C3P0I6aX071hM01DG5P0210<051HE018D4`80418A00`04A<B00h@3`1?DE00
418A00P:1`0M7a`03Q0=01DG500A4a003a4>010B3`0?4@h200h@3@80418?0P0B51402P0A4a003a4>
00d?300;3@X03a4>00d?300B514061XG01DG500:30T200d?2P804Q@?0P0=3`X0<@0>40/04A<>00d?
2P0?4@`0418=00lA300C5A00418=014C3P0@4Pd03a4<01@F4@0A4`h04aD@01LI500H6QD030h9018D
3`0?4@`04A<>00h@2`0H6QD08R@O00lA300>40/0418=018D3`0C5A00418=00h@2`0>4@X03A0900hA
2P0C5Pl051L@01<F3`0B5@h041<<014D3@0B5@h03a8;00d@2@0@4``03Q4:018E3P0<3`T05QTB05YM
EP0L7aP00P0C5Pl00`0E61404QD>010C300201HI4P0W01DH4@0@4``030l8010C300A50d04QD>010C
300>4@X04QD>00lB2`0@4``04aH?00lB2`0C5Pl051L@014D3@0C5Pl051L@018E3P0?4P/041<<01<E
3`0C5A004Q@?018E3@0@4`X041<8014E1`0D5``05AP?01DH400B50l04Q@@014D3@0N8AX03A09024T
7@0K7QL041<<00805APA0`0F6A803P0E61405aTD014C3P0H6QD07AlJ01DG4P0C5Pl04QD<01@G3P0F
6A0051L<01<F2`0E60d05Q/D0P0@5@h07P0D6A804aPA010E3P0E6Q<07b@M00lD3@0L8AX03A8;01<H
4@0I7QP04QLA01hS7@0O91h04QLA01HK5@0L8A/061dG00L<1P0D6A<0=S/e024V800L8a`051/D00dD
3@0I81T07RDN01`S700K8Q/05QdF01DL5@806B0I00h04aXC010I5P0G81d051dJ028[:00Q:RL04a`I
01XS800T;BX08BXW00lH5@0L9B805b8N01/V8P806bLS00<07BTU01l[9`0O:bL00P0M:BD0600N:RH0
7b/W01l[9`0O;2D07BPQ03E0>P0P:bD09S8`02Hb<P0R;Rh0;cdm02lo?00a@S`0<T<l03I7?@1<GE<0
T9nH069cK@0U=S00=4Do02/n>P0^@Cd0;D0l02a0?P80:clm00P09cdj02Hl>P0Y?3l0<4=70354B00h
Bdl0>diB03I9C@80>4]?00D0>Da@03mBEP0mD5@0>TiC03aAEP0203Y?E00603iCF012Ee`0AEYO04=H
G@0oE5T0@UML0P16Ff00:P14FEd0@UMJ045FF@12Ee`0AEUP04EIHP16FV80A5QO04=GGP0nDeL0?55B
041FE011EUL0A5MK04UMGP1:GUh0AEUG045ED`10E580@EEC04eQH017Fe`0?51A04MJGP16FU/0B5aK
04YNF`17G5D0Bf5E04EKCP0oEDP0>e5404AJCP1:GeH0A5U@04IKD`1EK6H0CfIP04UPFP1JLF/0PYVC
05acK@80F6mY0`1IL6X00`1HKfP0FG1V05Q`H`0305M^I00I05U`J01LLf/0GGA/05ieK`1OMW00GgIa
05meLP1SN7<0GgA^069gKP1KLFD0HgU]06EkKP1OMFP0GG=W05idJ01LLFP0G75[065fK`1MM6`0GgI/
05ieJ`1LLfT0F6mU05E/HP03059YG`0A04iUF`1<HeT0B61C04=KCP12FTd0AemB04aTE`1:HEH0@UU?
04IMD`18GeH0CVEM04IME@19H5P0AUeE04QNF`17GUP00P19H5X07013FU80?eI>049ID@16GE<0@UU?
03U@AP0iDD@0?EE804EJC`13Ed`0=DTn03Y>@`13E4X0>T]103I6?00/?380:c/a02Pe;00T<BP09C8Y
02dl=`0b@C`0;C`g02/j=@0`?cX0<D0k02Pg<P0O;RT201XY900L01l^:@0R<B`09C@`02@c<00Y=cL0
9cDh02/f>P0[=CX08BX_028[<00Y<S@09Rl^028[:P0M9R806bDM01dV8@0N:2807RTS020[9`0N:RH0
:cLc024`;@0E924082l/020^;P0f@3l092XX020V90806R0N01@082HT024W9@0H7Q`05adK01lU8`0P
9R@07B<Q01/Q7P0>4`l05a`H01lT800=4Ph05Q/G01/P700H7AT06AhJ01`Q7@0H7AT05AXF01/M6P80
7R0M00T05aTF01DG500L7Q/071hK01XL6@0H6QL05QPE01LI5P0H6QL00`0G61<00`0F5a805AHA01DF
4@0201PI500N01XK5P0I6QD061TD01DG4`0N7b<0GV5V01@E6@1TIFT0=cPj00l?400F5Q@051<@01<B
3P0D4`h05Q@>01DB3@0=30P05aHB01/J5P0Y:2@0;RdY00h=2@0T8al04A0<01<B3P0@3`/04A0<00d<
200C4Q004A0>0P0D4a402P0@3`d03Pd;010?3@0D4a405A@B00D40P0:2@P03@`:01@B4`0=2``2014?
400900d;300?3@h040h?018@4@0=2``040h?01<A4P0A3a003P`=00803`d>0P0@3Pl0500A3a00HEmP
00l=3P0I5aP020H701TG600@3Pl0FUIE00L30P030000;BTX00<0000A3@`03PX900d9200>2PT040`;
00h:2@0<20L04@X:0`0C2P/00`0B2@`04PT:01hE5P0201H=3P0<00/40`0D30X03`X800d9200>2PT0
40`;00l;2P0=2@P03PX900d9200:1PD02`L60P0=2@P01`0?2`/03`/<00/7200M6AX04@d>00h:2`0C
3a000P0<20T05`0B3Pl00`0001LC500X92D071PI00d92P0D414020@5018>3`0?2``06QHG01@@4@0<
20T03PX;00`82@0?2``030P900/7200@30d05A4B00h:2`091@H05A4B00803`/<01007a/L030/;@0B
41405A<D00@20`0C4A80108300d<300Z:2T0108300<10P0B41403@/<00l>3P0?2@/040X<0P0?2@/0
5P0B30h040X<010:300G4A<06Q@F010:300;1@L040X<00h82P090`D04`d?00/51`0=1`T01`4300@0
000:10H0100002DO8@05004030H800h:2`0=2@X200`82@0600h92P0?2@/040L:01072P0?1PT040D9
0P0?10PDooooo`006oooool00`0@51D03a<D00dA4P0200dA4P0=00hB4`0:3Pl03A4B00lC50052@X0
4aLH00dA4P0>3a80414D02HW:P0a<SD05aPK01HG6P03010A500F014B5@0B4aH04Q<E01`N7@0>40l0
418A00lA400;3@`0418A00lA400@4Q403Q0?00d?3P0?4A004Q@C014C400@4Pl02P`:014C4@072@H0
4Q<A014C40803Q0=00H0418?00h@3@0<3P/02`d8010B3@0A4`h200lA300?010B3@0C5A005ALB00lA
300<3PX03Q0;00d>2@0E5Q4030d801LH4`0:2`H04Q<>00l@2`0=3PT03Pl:00803a0;00/03Pl:00l@
300=3``03@l<010B3`0?4@h030h;00/=2P0>40d03a4>014C4002010B3`0300h@300=3`X03@l:0080
3Q0;00H03@l:00h@2`0>40/03a4<010B3@0?4@`200h@2`0500lA300@4Pd03a4<00lA300=3`X01P0@
4Pd00`0A4Pd0414<00l@2`0200h?2P0I00l@2`0B4`h04a@?01<D3`0@4@`03a0;018C3P0G6AP020X9
01<E500=3`h06A/J00X<2`0=3`h02P`;01HH5`0>40l05QPG00h@3`0E5a@0=CLd01<E4P0I6aP03Q0=
00d?300200lA3P803Q0=00D0418?014C400?4@h0418?014C4002010B3`0900lA3P0@4Pl03a4>018D
4@0F61D04aDB00/=2P0A4`h03a4<00804Q@?00h03a4<014C3P0@4Pd04aD@00/=200B50l030h9010B
3@0E5a804Q@?01DG4P0D5Q403@l:00`>2@803@l:00d0418=01<E40082PD03Q0;00lA300C5A003a4<
01dO6P0Y:bH051HA00/=200<3PT03Q0;00804Q@?00T04A<>00lB2`0A50d04QD>01<F3`0F6A806A`E
01<F3`0A50d00P0B5@h0200?4P/03A0901@G400@4``02Pd6010C300=40T04QD@0P0?4P/02@0@4``0
4QD>01DH4@0C5Pl030l8010C300B5@h03A0900lB2`03014D3@@04QD>01004aH?018E3P0@4``051L@
018E3P0?4P/051L@01HI4P0C5Pl03a8;010C300C5A404aDB018D3`0B5@d04QD:0`0A5@L02`0A50T0
4QD=018D3`0B514051HA01HI4P0@4``06QdF01TL5@0B5@h05QTB00805APA0P0F6A804@0C5Pl05QPC
01@F4@0B50l051HA01HH4`0F6A805QT@01LJ4@0F6A004QD:014D2@0C5P/03a@=01HK500C61403Q<<
00<05AXC00T02Pl803i3?00I7QL051TB01<H4@0C61804QLA01LL5P0H7AL00P0E6Q@01P0C61805Q/E
01XO6@0A5Q007R<M00lD3P8051/D00d072<L00`C300H7aP07B@M010G400I81T072<L01PO600E71D0
5ahG01@M6P0G81d06R<P008092dZ00X0<CXg01DN6`0I8Ql08b`Y01<L6@0G81d062<O01TT800J9R80
6bLS0P0N:RH201l[9`0H020/:00R;RX08RhZ028^:P0R;bP082/T02Xe;`0K9R0082`Z01l[:`0T<300
;cdm02Lg=00R<bd0;Chg02ho=@0a@SP0?4]403a=AP0^?cP0<d@n02Lj=@0^@C`0;d8n0P0[?cd04`0/
@3h09cdj02@j>00]@D<0;D1402/n@P0dAd/0@5=G03a?D`0hBdl0>diB049EF@14Ee/0?E1D03Q<D@0i
CU<0>e1E03eBE`0nDeP00P0oE5T0;P11EU/0AEYO04QMHP14FEh0?eAI03iCF012Eed0AUYP04MKHP16
FV80Ae]T04MKH`11EE`0B5eR04AIFP10EU<0B5iK041EEP10DeT0@eIJ04MKF`17FeX0AEUG04=GE@16
FUP0H7Ac04=GF016FEd0CF1V04MJGP14F5T0B5aJ03mDCP17G5<0@eU=03iDA`12F4/0BV1D04aQF01=
HU/0CfAO04aSGP1BJVD0EfmZ05A/I`1VOWT405Q`J`80FG5/00<0FW9/05YaI`1JLVD00P1JLFL07@1K
LVP0G7=[05ieK@1OMVh0H7Ma069iL`1TNWH0I7Yg06EjM@1QMVh0HGI]05M]H@1LLVD0Fg5S05edI@1P
MVT0H7IZ05icJP1NLf/0H7E^05edJP1RNFl0HgY`05mfK01IL6H0EVeS05U`IP1CJV00EfiT0080CfIL
00<0A5a?04MODP1:HUD00P1<I5L0@01;HUL0BF1F04IMD`1AJ5l0EVeU04MNEP1:HET0DFQP04QNF`16
GEL0AeiH04QOF@15G5@0@UUA041GC`11F4h0?UE;03]BB010F4/0AEe@04IJCP0mDDH0=d]003]>@P0m
CT<0>4Xo02`l<P0V=R/0:3P^02/h;`0/>Bl0;S/b02/j=00`?cX0;3/f02/j=@0b@C`0=4<n02Xi=00R
<B`082lZ02@c;P0X=c80:STe02dl>`0V=3@09cDg01l/<P0T;SH0;CLo02Pa>@0R:c807RH[01dU9`0U
;Bl09Bh[01dW7`0O:2<07bTS01hY8`0P:bL08B`X020/:00E924201`[:00801TW9`0T;bd08bTW01hT
8P0H7Q`06R0N028X9P0Q9bD201HL6P0801dS8@0L8R006b4O01XP7@0D6A@05a`G01<H4`0G71L301TN
6@8082DP00P06QlJ01PM600N81d07b4N01dO700I6aP061XG01/M6P8061XG00@05QPE01DG500F61D0
61XG0P0G61<0100F5a805AHA01@E400D5A0201LH4`0V01HG4P0E5Q4051D@01<D4@0I6Ql02@/B024Q
:00D5AX07b0T018B500F5QH051<@01<B3P0E50l05aD?01LD3@0A40`04A0=01<B3P0?3PX04A0<01PG
4`0@3`d03Pd901DD400A40`05QDA014@300C4Q003`h<00h=2`0A40h04a8@010?3@0?3P`04A0>01LF
500=30X201@C4@803@/<00<040h?01<A4P0B41400P0@3Pl01@0B41403P`=014?400G5AH061HG0080
3P`=00<03`d>010>3`0@3Pl00P0A3a004P0>30d030X;014?40040P<03`d>01<?3P0B3Pd04`l?03/g
=`0H51<03@T8010<2`0?2`X040`;018>3@0@30/03PX901<:2`804`X<00/04`X=0148300A20/040L:
00d41@0E30d04@T701H>2`0A30X04@d<00l;2P02010<2`<03PX900H03@T800l;2P0@30/03PX900l;
2`0@30d200h:2`0G00d92P0<20T04@d>01/G600>2P/03@T:00`82@0F4Q<030T901@@4@0;1`P03@T:
00/7200I5AH040`=028N7`0M6AX03`/<00h:2`0:1PL03PX;010<3@0>2P/00P0<20T0:`0A3@h02PH7
01@@4@0=2@X02@D601@@4@0H51D02PP900l=3P0=2``03P`=00P61`0>30d030X;00X82@0?3Ph00`82
01LE5P0L6Q/02`D700`6200>20X03@L900`6200;1@L030H8010:300B30h030H800P2100:10H02`D7
014;3@0_:B/04@/=00d72@0;1@L03@L901<=3`0910D05a4C010:300B30h00P0>2P/200`82@0600h9
2`0?2@/040L:01072P0?1PT040D90P0?10PDooooo`006oooool0100B5QL04ADF010D5@0?4a@2010D
5@0[01HJ6`0:3Pl04aLH01<G600:3Pl041@E00l@4P0G61/0QhR:0=_Lh015ATT0414C00d>4P0B4aH0
4Q<E010A500B4aL05AHH01XL6`072@P03Q0?01<E500?4A004Q@C014C4P0G6AP051HE00`>3@0:30/0
30h=018D4@0A4a00418?00d?300G6AH02`d:00`>2`092`P030h;010B3`0>40d03@l<00d?2P02014C
3P803@l:00/03Q0;02@V8@0E5a801@L200lA2`0K7AP04Q@?00L80`082@@02``700d>2@0201<D3`80
4A8=00D0414<00d>2@0<3@P02P`800`>2`0200lA3P0400`>2`0;3@X03@l<010B3`@03a4>100@4Pd0
1@0>40/03@l:00`>2@0=3`X03a4<00@04Q@?00D0418=00d?2`0<3PT030h900lA3002010B3@04010C
3@0@4Pd041<<010C30804A8=01803a0;00h?2P0>3`X03Pl:01<D3`0E5Q4051D@00h>300=3PT0410>
01<E4P0>40l04aDD00X<2`0E5aH030h=00X<2`0D5QD2014C4P0800h@3`0D5QD00@<002T[:0041P<0
4aDB00h@3@0C5A8400h@3@0;010B3`0A4a005ALD01@F4`0C5A804A<@00h@3@0<3P/04Q@A00lA3P0<
3P/00`0=3``01@0?4@`030h900d?2P0=3`X030h900803a4<00X051HA00/=200G6A@03Q0;01LI500D
5Q403@l:00`>2@0=3`X03a4<0P0D5Q4200h@2`0F014C3P0=3`X05aTD00lA300@4Pd04Q@?00`>2@0A
4`h030h900/=200A4`h0418=00`>2@0A4`h05aTD01<F3`0G6Q<05APA014D3@0E61406ahG014D3@80
3a8;02X041<<00d@2@0;3PL030l800L:0`0E614051L@018E3P0A50d041<<01@G400A50d03a8;01@G
400F6A<02P`700lA300A4`h02P`700lA300A50d03a8;00hA2P0C5Pd05AP?018E300?4PX030h900/>
1`0B5@h05QT@018E300=40L051L>01XM500I71D04QD>014C3P0B51004Q@A018D3`0B5@d2018E2P0?
01@G2`0C5P/04A@9018E3@0B50l04Q@@01DG4P0A50d04aH?00/>1`0<3`P04QD>01LJ4`0E614051L@
00805QTB00X04QD>01@F4@0F61<03@l:00/=200F61<06A`E018E300C5Pd051L>0P0C5P/0<`0G6Pl0
5Q/D02`a:P0T:B802Pl8014F3`0E6Q<05a`E01/P6@0>4``07B8K01HK500D6A803A8<01PM5`0<4@/0
5a`F02db;00G71H05AXD01LL5P0B5a406AhH014F400S:2805A`E02Xa:P0A61405QdF01@K500>5@h0
4APA030g<00f?CH08BPQ01<K500N:2005b0K01TR7`0L9B807RLT02Xc<01OJ6D05QlL01PQ7P0W<2d0
82TV01XS800P:bL06BDQ01/W8`0201`X90806bLS00<05b<O01XV8P0M:BD00`0Q;BT0E`0P;BH08RhZ
02di=@0O;2X062HV03=1@@0U=3@09cLf02Pk=`0]?SX09STc02m2?00iBDH0:3Pe02/n>P0]?c/0:3/g
02i1?@0^@Cl0:Shl02a0?P0^@T40:d4o02Pn?00Z?D40;T5502m2AP0eB4`0>Da@03a?D`0hBdl0=TU=
03mBEP0jCE40=DQ<03I:C`0jCe@0?U=H049GG010EEX0?U=H03eBE`11EU/0@eQM049GG010EEX0@eQM
04]PI@1=HVL0B5eR045EF`16FV40DfM^05=WK@0kD5D0A5UL04MLG016G5T0Bf5N04=HE`18Fel0Ae]L
04UMG@1:GUd0BEeK04eQG`1KKfd0Cf=R04YNG`12EUL0C5mS04UMGP14F5T0CF5P04EJE@1EJV<0EV]R
03Y@A015Fdl0B5eD04MLE@1@IF00DVMU061iM@1AJVH0F75]05aeL@0205E^JP80FFm/03/0FG1[05Y`
K@1KLV`0GG=_05U`IP1JLFL0GWAZ065fK`1QN700HgUa05mdK`1NMFl0H7Ia069fM01UNWL0IWai06Ai
M01QMfl0HWU_05]`I`1OMVT0GGEW05idI`1PMf/0GWE[05ebJ@1OMFd0GgI^05edK01TNg80IGab065h
KP1IL6H0EVeS09J]X`1eS880GWE[04aSF@1?IU`0AUiA04ALC`1:HUD0Bf=F04MODP19H5H0CfIL07jE
R`1FKFD0@UUA045HD01>Iel0BV5K04MNF01@If40DFQP04UPF@11F500?eI>03aCB`0303aCB@0;03mG
BP11FD`0?eE803mEB010ETT0>4a00396>P0hBSh0:S/_02De:P0W=b`00P0[>2l06`0/?380<d<m02m0
>P0/?CL0<T<m03I5@00c@Sl0:CPe02<b;`0R<Bh0:3Ld02/j=`0[>CT0:SHg01/V:00T;c<09C0f02Ha
=`0]=Sl09c0g02@]=00Q:Bl072@W01dU:00O:2H07BPP01lX8`0201hY8`0801lZ9P0Q;2P062@P018N
6P0K9b@04QhL01XV900J8b4201/Q7`0G01LM6`0E6aT05adK01XP7P0G7A/061hL01`R800H7Q`05adK
01dR7P0C618061dI02@Y900P9Al06QlJ01DJ5P0J7aT09R/V02<X900J7aT06QlK01lQ7P0L7Q/00P0I
6aP01P0G6aX061/J024S8P0O8B006adK01HH5@805QHD0P0G61<01`0F5a8051D@01@E400C50l061TD
01LH4`0D5A000P0B4`h04P0C514030dA024T:@0C51T030dA00h?4`0F5QL05QHF01@C4@0C4Ph05A@@
01LE400G50l071/G00l>2P0;2PH030/701HE4@803`h:01l03Pd900l>2P0:2@D04Q4=00/:1P0<2`T0
5A@B01LF500D4a404A0>00h=2`0F5A<051<A010?3@0G5Q@0;Rd[00l>300:20T04a4B00d;300;2@X0
4@l@010>3`0C4A804@l@00d;300B41403`d>00P61`0?3@h03P`=00803@/<0P0;2@X0200?3@h020H7
014?40091`P05aDF010>3`091@@04`l>0P0?2`X05@0G4a803`/:00h:2@0=2@P03PX9010<2`0>2PT0
30P7014;2`0C2P/040X:00h72@0<0`H02@<501@=3P0A20T04P`<00/40`0D30T0510>01@@3`0200l;
2P0@010<2`0>2PT030P700h:2@0B3Pd061@C01DA400?2`X02PH6010<3@0C3a0020@500`82@091@H0
4`l@00L3108040`=02P05A4B00L3100=2@X04@d>00P41@0A3@h02@D6018>3`0=2@X061@E01LC500:
1PL030P900T51P0810D02@D600l;300A3@h06ADF03Da<P0:1PL01`<400h:2`0D41403PX;00/8200>
2P/01P@500T61`0;1`P040h?00T71`050@807A/L00h;300D41400@00024M7P090`D02P@60P0?2@/2
00`6200?01<=3`0=1`T02@<500l92`0B30h03`T;010:3004000050h@00L10`0A2`d0100001<=3`0;
1@L05@lA00803`T;00<030H800/51`0>20X00P0A2`d01P0>20X03@@701072P0@1`X03`H901052@80
3`@85?ooool001_ooooo00T05QLI01<D5P0:2`d05AHH00h?4@0E5QP04a@F01LH6P0A4Q@00P0=3Q00
3@0;30h04a@F014B4`0H6QT08B8T01`N7P0=3`h02``>01hO800_<C005AHG01<D5P0B51<00P0A4a82
010B4@803a4@00<04A<B01@F5@0C5A@00P0>40l0900@4Q405aTF00/=2P0A4a0030h;00h@3@0@4Pl0
3Q0=00/=2P0>40d03@l<00`>2`0?4@h0410>00d=2`0>3P`0410>00l@2`0>3`X0414;00l@2P0>3`T0
3Pl800l@2P0A4`d03a4<00/=200=3`X03a4<00h@2`0?4@`04Q@?014C3P0>40/02`d800d?2P803a0;
02P04A8=018C3P0A4Pd03a0;00d>2@0>3`X04Q<>01@E400B4`h03Pl:00lA30062@800`H000lB2`0<
3`P02`h700lB2`0<3`P03A09018E3P0;3PL02Pd600lA3@0210403a4?00h@3@0J71T02`d802<V7`0I
71D03Q49018E3P0E60l03a89018C3@020`009bPS024R7@092PD04Q8@0P0>3P`03P0@40h04A4A00l?
3@0;2`X04A<@00`>2`0A4a0071hK00X<2@0;3@X04A<@00lA3P0=3``03Q0=0P0@4Pl05@0=3`h03Q0?
00d?3P0=3`h04Q@C01<E500I6aX0418A01DG5P0C5A@030h=01TK6P0C5A803Q0=014C400B51403Q0=
01@F4`0>40d04A<@01<E4P02018D4@0701<E4P0B51403Q0=00lA3P0H6QL03a4>00d?3006010B3`80
30h;01<03Q0=00lA3P0>40d02`d:00lA3P0@4Pl03@l<00lA3P0A4a003Q0=01@F4@0B50l051HA00h@
2`0<3PT04A<>01<E400?4@`03Q0;0080418=01403a4<01DG4P0@4Pd02@/603@f<@000P0061XE010B
3@0B50l04A<>00h@2`0?4@`04A<>00d?2P0>40/03a4<014C3P0201<E400k01@F4@0?4@`04aD@014C
3P0@4Pd05ALD01dN800I6Q`03@l>01@F4`0F61D05APB00L:0`0B5@`04aH;00X=0P0G6`d03a49018D
4@0B50l03a8:01<F2`0B5@X041<800d@1@0>4@H051L?0001000W:BH02`d901DH4@0?4P/04aH=01LJ
4@0H6a802`h401<F3@0K7QD05QT@00L:0`0B5@h03Q4:018E3P0A50d041<<01DH4@0D5a004aH?02<V
7`0F6A8010L001<F3`0H6a@030h9010B3@0G6A@02P`701dO6P0?4P/00P0E60l0500D5`h04aH;01<F
2`0D5``03Q<<03Hk=00`=Bh03Q<<01dR6`0C614061dF01DJ4`0C61404QL@01<H4@0G71D05a`F01@I
4`0B5a4051TC0`0F6aD00`0D6A<04aPB01DJ500201HK5@0>01LL5P0I7QP06QlI01TN600G7AL05A`E
01lY8@22S8@0_lW102D_9`0E7aL05R0H01XS7P0G81/201@M600501LP6`0I8Qd06R<N01lX8`0E7QT0
0P0H8A`0?@0N:B<072PT01`[9P0B8A`072/V02He<00P;bX08c8]01/Z9@0C8Qd07B`W01h]:00O;RT0
8C0]028a;P0Z>CH0:3Lg020`<00W=cL0:CXj02Dg=`0S=cH0:Sdm02Di>00Z?Sl0BE]O03a>D00dB4T0
<DA502a0@@0Z?Sl09c/l0396A`0_@d80;T9202a0@@0U>CX09S/o03=8C@0^@dP0<DI;041EFP0hCE80
=T]@041EFP0nDeP0=DY?03aAEP11EU/0@UML03eBE`15FUl0Efaa055VJ`0nDeP0?55F03mDF@16Ff00
AeaQ04EJG`14FE`00`16Fe`02@17G5d0B5eN04AIFP11EUL0@eQI049HEP10EU@0@EME04AJF00204MM
F`0804AJF012F5D0A5YG04QNF`16G5T0BEmL04]QG`16G5X204MMF`1[04YPGP1;HEh0AUaI06ImM`1Q
N780@5MA04AKE@1:HE/0D6MQ05I/J@1DJVL0CfQU04iWI01GKFX0FW1]05M]JP1PMg40HgQc0725P01N
Lfd0FVmZ05U^I`1XOGL0GW=/05ebJ`1SMg00FVeY05ebK@1QMG00DfIT07b@SP1LKfd0Jgem06EhM`1Y
OG`0Igih069jM01NN6l0H7M_05igKP1KMF`0HGQ`061hL01LMVd0G7=[05eeK`1QN780Jh9l07:7P@1T
NG80G75Z05]`J@1DJF80G75X05Y`I@1KLFD0EfeQ04YPE016G500BV1D04eRF@16Fe80B5eD05AZHP1F
KFD0b>;I08fVX01:Hed0A5eG04QRG01BJfD0AeiF05I]I@1AJ5h0>e9904AKD@15G580?EA:03iEB`0m
E4X0@EQ>03aCB@13Fdh0?5A604ALCP0cBcd0=T`o03A:?@0`A3P0<D@h02Pi;`0T=B/09cH_02/j=@0/
>cH0:chh02Lj=00V>C<0;3lk03A4@@0dA4<09CDd02/i>P0R<340<3i1020^<@0^>Cd00P0S;Bh06@0Z
=3H082X/02`f>012BTd07RHY01XR9@0S:bh02Q8D01DM7`0P:RP0<Chg01TT7P0Q;2H06RDO02lj=00L
9b408B`V01/V800R;2L07bPU01HO700K8al06b0L01TN6P0H7AT00P0F6aL07P0G71P061dI01XO6`0K
81`061dI01HK5`0=4`l0A4Y601TO7@0[<Bh0JFm[01LM6P0P9R@05adI01/Q7P0E6aT05adI014G500L
7Q/06Q`I018G500O8b804ALG01<H6@0e>CX0_/;302h_<00Y:BT051<A01PG50H05ADC00`0410>00l?
3@0E5A<04A4?00h>300R8b40IFMV02/_;P0@4Q403a4@01@F5@0@40l201<C4@0601<B400B4@l04a4=
01@@3@0B4@l04A0>0P0@3`d0100A40h04Q4?01@C4@0D4a44014@3P0@018@4@0F51D01P@501XH6@0D
4Q<04a4B01HD5@0=2``03P`=01HD5@0G5AH03P`=00/:200?3P`04a8@00T81P803@`:00H02`X800d<
2P0@3`d040l=00h=2`0=30X6014=30803@T800P03PX9010<2`0A3@`04@d<00`81`0=2@P03PX900l;
2P8040`;1P0?2`X0300?2`P04@`900l;200=20P03PP800h:2@0;1PD040/800l;200=2@H03PT6010<
2P8030P700/04@d<010<2`0?2`X03`/:014=300810<08alN03Hb<@0I5A@02PH500`81`0200/71P0?
010<2`0>2PT03`/:00L30P0F4Q403`/:01@@3`0300003`/;014=3P050@803`/<01XF5`0?2``040`=
00807QXK0P0=2@X200l;300S00L3100A3@h02PH7014=3P0B3Pl02`L800h:2`0B3Pl02PH7010<3@0<
20T02`L800`82@0<1`T02P@600T51P0<1`P03PP:00d92P0>2@X03PP:00d92P0>20X02@<500h82P0:
10H04P`>014;3@0=1`T03`T;00h82P0<1PP03`T;01LA4`0U7b401P0=1`/01`090`L03PP<014;3`0@
2Ph03PP<00d72`0<0`H00P0?1PT0100=10L03PD801462P0>0`L201<8300301052@0B1`/050T=01Co
oooo000Kooooo`803PlA00H03@h@014B500D5AL02P/=00h?4@0A4Q@200h?4@0=014B500=3Q004Q@C
00h@3`0@4Q4051HE01DG5P0A4a803@l>00lA400F61L03Q0?01<E5002014C4P80418A0P0?4A002@0>
40l03a4@014C4P0@4Q403Q0?010B4@0A4a80@dE201@F4`02010B3`0?014C400;3@/03Q0=00`>2`0?
4@h03Q0=00`>2`0?4@h03Ph<00l?3@0A4@l04a<A00l@2`0;30L03a0:00803Pl900<04149014B2P0@
4P/00`0?4@`200h@2`09010B3@0B50l04A<>00h@2`0=3`X03a4<010B3@0?40/0414<00<04A8=02@0
4Q<>014B3@0?40/03Pl:00l@2`0A4Pd05ALA00lB2`0>4@X06A`E01<F3`0>4@X041<<00lB2`0>4@X0
30l800hA2P0K7QL0EUQD01lQ800A4a8020X700/=2P0?4@`05APA014D3@0=40L041<:018E300@4`P0
2@X701HG4@0?40/04Q<>020Q700;2`T2010@3P804Q8B01`04A4A010@400=3``05ALD018D4@072@H0
2P`9014C400>40d0418?01@F4`0B51404A<@010B3`0<3Pd03Q0?018D4`0C5A@04A<B00h@3`0@4Q40
3@l>00`>3@0E5aH04Q@C00D71P0C5A803a4>0P0A4a001@0?4@h04aDB00d?300@4Pl04Q@A0080418?
00D04A<@05UKF019BdP05QPE00d?300200h@3@H0418?00T03a4>00h@3@0@4Pl04A<@010B3`0=3``0
3Q0=018D4@0A4a000P0C5A804P0?4@h07R0K01HH4`0C5A003Q0;00lA300F61<03a4<014C3P0D5Q40
5QPC014C3P0>40/03a4=01DG4P0J71L0?d4l00lA30805ALB00`03Q0;00d?2P0A4`h04Q@?014C3P0K
7AP05ALB010B3@0=3`X03Q0;00lA300Z;2L2010B3@0h01@F4@0A4`h04Q@C01XK7P0F5aX03@l?01<E
4P0D5Q<041<=00X=1P0H6a804QD:00T=0@0D5`/03a4:01DG500E5a804A@<01<F2`0A5@L03Q8401TM
3`0E60d04A@<01`N6@1>D4d07R0K014D2`0@4`X04A@;010C2P0B5@`08bHM028U700A50`04A@;01DH
3`0C5Pd04QD>01DH4@0C5Pl04QD>01DH4@0C5Pl04A@=01<F3`0D5a006ahG018E3P0_<R/08B<N01DG
4P0@4Pd03a4=01XL5`0E614201HI400G01DH3`0E60d05AP=01HI3P0J7aP051TB01hS700Q9Ql04aPA
01LL5@0E6Q<04aPA01DJ4`0F6a@04aPA01@I4P0G71H061dG01HK5@0D6A<05AXD01PM5`0F6aD00P0C
61801@0E6Q@05Q/E01DJ500D6A<05Q/E008061dG00`061hG01HM5P0H8QX0=3hf04==A@0I91`06bHN
01`W7`0J8ah06B8M01PQ700I8Qd201XS7P0>01LP6`0M9R406B8M01lX8`0J8ah072LQ01hZ9P0R<B`0
6RTT01`[9P0P;bX06bXU01PW8P0S<Rd201h]:00V02@c;P0M;2L07R`/02hn?@0T=3<08S8a024c<`0b
A4@0:3Xl02Tm?P0U>CX09cXn02Hk?P0bAdX0;3m50313B@0cAT`0=DQ>02i1AP0Z?D80:ci302<f>`0_
@TD0;D5402Xm@P0dAd/0<TM:02e2AP0hCE40Bf1T0356BP0iCU80>e1D03iCE`0iCU80>e1D03iCE`0k
D5@203Y?E00A041EFP14FEh0@EIK03mDF@0nDeP0?eAI04EJG`17G640AU]P04EJG015FeT0A5YH049H
EP10EU@0?eEC03iDDP0mDe400P0oEE<00`10EU@0@UQF04EKF@0204ILF@0704QNF`1:H5d0B5iK04QN
F`16G5T0B5iK04UOG00304EKF00>04UOG01:H5d0FW1]06EkN01;HEh0@UQE04EKF019Ge`0CVAQ05E[
J01IKf`0EVm/05A]JP1JL6d205]aKP0406EjM@1QMW40IGYe05Q[I@<0Gg9/00h0HWI^05]^I`1PLfd0
FVeX05U/I`1NLFh0J7]h08RKV01WNWT0K7im069eM01SMgH0Igii06=kM@80HGUc05/0H7Qb05ifL01R
NW@0HWYd05ifL01LM6h0GWI`06=jM01QMW40HgQc065fL01NLf`0Fg1Y05aaJ@1KL6L0E6UO059XG01@
IUX0AeeA04AJCP1:GeH0EfaS05=XG`1=HUX0CfEM055XH01@JF80F75Z04QQF`19I5l0Af9M04QSG016
GE@0AUeC04=JD018GeD0AEaB03YAA`0nED/0>E1603YAA`11F4h0>e9804=KCP1:HeH0BF=D03E?@00c
BSd0;dDh02e3=P0V>Rl093D/02Df;P0[>SD0;chk02hn>`0/@3/0;T8m0314?`0cAT<0;d0o02`m?00S
<c<09cDg028`<P0a?d809S@h038m@P0]=SL082TY020X:@0[=3@0<3Ti020X:@0M9BH06b@T01@K700L
92D07bPX01LR7`0W=2d04QlH01`X8P0N:B<0=3li020Z900T;BP07bPS01`T7`0M8al05adI00806AhJ
00<061dI01LL600G71P00P0G71P0;00F6aL061dI01XO6`0I7QX061dI01HL6@0K8Al05Q`J01dS8@0B
61H06b4O01LM6`0E6aT0728P00hD4P0H7Q`0=C/h01`N6`0H6QD06b0M02L];@0H7Qh05AXM01PM8010
ADP07AhP014?400H5aD05aDA01/J600J6QP061PF01LG5@0H61H06QXH01@D4P0E5A<04Q8@01LG5@0Q
8Al071dK02d_;00@5A405QPE0P0@4Pl00`0A4@l05QHD01@D4P02018A3`0301DB4@0G4a804A0>00@0
4a8@00<04A0>01@C4@0C4Q000`0A40h0200B4@l03P`=010>3`0M6a`05Q@E01<A4P0?3@h04a4B0P0?
3@h02`0B41404a4B00d;300E51804a8@04M6A00m?3X03@`:010?3@0>3@/03`h<00@040l=1P0@30/0
1`0B3Pd03`/:00h:2@0A3@`05Q8A01TE500@30/00P0?2`X200h:2@0300d9200?2`X03`/:00@03`/:
00<03`/8010<2@0?2`P00P0=2@H0400>2PL03`/8014=2P0@30T03PX700l;200@30X03PX9010<2`0C
3`h03@T800`81`0?2`X02`L600`81`0A3@`200l;2P0500h:2@0D40l061@C010<2`0=2@P0100@30/0
300=2@P04@d<01<?3P0C3`l08AdN018>3`0?2``0510A00T51P0>2P/05A4B01PD5@803`/<00H03PX;
00`82@0>2P/03@T:00l;300E4A8200`82@0801PD5@0U8B803@T:00D10P0=2@X030H800d72@0>20X2
00`62003010:300>20X03PP:00@03PP:00D04P`>01D?4@0>20X04P`>010:300200d72@803PP:00<0
30H800d72@0@2P`01P0=1`/00`0>20`030H:00/52@0200d72`0400`62P0>0`L04@H:01052@803`@8
00L040D901<9300<0PD04@H:00l4200B1`/040L901Cooooo000Kooooo`0600d>400C51H05QLI00h?
4@0L7Al03a0B0P0C51H0100>3a40414C014B500;30h200h@3`0600`>3@0;3@`03Q0?018D4`0E5aH0
4A<B0`0=3`h00`082PT03a4@00h@3`0200h@3`803@l>0P0>40l0400=3`h03Q0?010B4@0B51<030h;
00lA3P0F61D0418?01DG500F61D03Q0=00`>2`0@4Pl03Q0=00`>2`0?4@h200h>3004010@3P0B4Q00
3a0;00`=20803@h801`03Pl9010A2@0B4`/03a0:00lA300B50l0418=00/=200<3PT06adH024S7P0H
6QD03@l:00h@2`0F61<05aPC00l@2`0>3`X03a0;010A300B4`h04a@?014B3@0>3`X030d800h?2P0A
4Pd04aD?0P0>4@X04@0E61404A@=00d@2@0=40T03a8;018E3P0A50d03Q4:01<F3`0Q8al01`T8010B
4@082PL03a4>00/=2@0;3PL030l800<03Q4800T03a8801TJ500C50h01PL203@e<0000@007QhL00d=
2`0>3P`00`0>3Ph03P0A4A4020X700d?300C5A807AlL01@F4`0@4Q002`d:014C400F61D04A<@00h@
3@0A4a004aDD0P0@4Q402`0A4a803a4@018D4`0G6AP04A<B00P:2@0G6AP04aDD00T;2P0C5A804A<@
00<0418?00@04A<@00`>2`0?4@h0418?0P0>40d01`0?4@h02P`900h@3@000@004A<@01<E4P0J71T0
1P0?4@h00`0A4a00418?00lA3P02010B3`0300d?300@4Pl04aDB00804A<@00<0418?00`>2`0>40/0
0P0;3@P04P0?4@`06Q`G024S7P0I6aH0418=00`>2@0=3`X03a4<010B3@0>3``05QPC01hP6`0A4`h0
0P@00001000A4`h03Q0;00d?2P803a4<00<03Q0;01<E400?4@`00P0=3`X0100?4@`0418=01DG4P0D
5Q42014C3P0>01lQ700P8R0051HE018D4`0=3``0418?018D3`0?4@/03Q4:01LJ4`0@4`X04A@901LJ
4@0?4P/201<E400H018E3@0B5@`04A@9014E1`0=40D020/201<F3P0620<071hK01@F400;3PD041<:
018E300D5`h041<:01<F3@0A50/05AP?018E300G6Q40?D0g01HI4P0G6Q<05APA0P0C5Pl02P0B5@h0
20/401lR6`0?4P/02Pd601PK5013ASl05QPC00T;1P0@4Pd200h@2`0N01<F3`0F6A005QT@01DH3`0E
60d05QT>01PK400F6a@04aPA01DJ4`0H7AH05Q/D01<H4@0B5a004AH?01/P6@0O91d05Q/D018G400G
71H0724K01XO6@0D6A<04aPB01PM5`0G71H05AXD01@I4`0F6aD061dG0P0G71H201PM5`0_01LL5P0G
7AH05A`E018L500F81P04adE01LR6P0E81P05R4I01PQ700I8Qd06R<N01/T7`0J8ah06B8M01XS7P0O
:2<072DP01lX8`0K91l09C0Z01/W8`0P;bX06bXU01`[9P0P;bX07bhY02Xi=00Y>3<08C0[01d/9`0`
?cX0:CPc02dk>`0Z>ST062PW02Ph=`0R=3@0:C/k02Hh>P0Y?Ch0:3`m02`o@`0Y?T40<DI90395B`0^
@DL00`0/?dD0700]@4H0<4=:03A7CP0X>d80=TU@03Y=E00V>Cl0=4U<0356B@0cB4/0>e1C024f>@0k
D5<0AeaO04=HF`0eBTd0=da?03E:C@0hCE40>4eB03]@E@15FUl0?eAI03iCF013F5d0@5EJ03mDF@13
F5d204IKH00404IKG@15FeT0@eUG041FE080?UAB00`0?E=A03iDDP0oEE<0?UAB041FE013FEL0AeeJ
04EKF014FUL0BV1M04eSH018GU/204=IEP0904EKF017GEX0AUaI04MMFP0mDe00C69O04UOG01?IF80
AUaI0080AeeJ00D0C69O04mUHP1AIf@0EfeZ05Y`K@0205A]JP0<05Q^J`1KLFh0Fg5^061eL01SN7<0
G75/05IYH`1PLfd0HGA^05a_J@1TN6l0GW9Y0P1JKVD02`1WNW@0HGA^059UH@1ZOGT0H7=`06YmN`1Y
O7X0KH5o06UnN@1UO7H0HgYd0080I7]e01@0HWUc06=jM01RNG<0GWE_05acK@1OMW00HgYd06MlM`1Q
MW00IW]d06AiLP1JKfL0GW=Z07Z?QP1QMf`0CVAH04UOD`16G500BEmC055VG@80FVmV04D0E6UP04mU
G@1>IEd0CfUP04QQFP1EKVP0Af9M04IQG00oFU<0BV5H05YaI`1EK680HWU_03YAA`0oET`0>4m5059Y
G`24Vi40MXf303A;@@0hD4<0>51203M?@@0]ACL0;dDi02]1=@0]@cL07S8X020a:@0T=Bd0;chi03M6
@`0hB4D0<4A00395@`0eB4H0;d9002@d<`0P<2l08S8b02@b<`0U<c<0<Cm002Le=P0]>3X08R`/02Xc
<P0U;Rd08BXY02@];00D7A`04a`K01XS8P0[=3<06b@S00`E500H8al08BhW01DR6`0M:B808B`V034l
=P0M9b408b`W024Z9@0E7AP07B<O01XP700G7AT00`0F6aL0<`0G71P061dI01PM6@0H7AT06AhJ01XO
6`0I7QX061dI01dR7`0K8Al01P`:01PN700G7A/07bDS01@J600;4@l06R0N01dS8@0L8R005A/H01hP
7@0H6QD04AHB01LM7@0S:BT06QlR01DJ7@062`h06a`M014?400P7ad06AHC01XI5`0G5aD04a<A018B
400D518061PF01DE4`0N7Q`092@R01@D4P092@L03a0>00h@3@0730P06A/H01LI5P0D5Q<05ADC010@
3P03018A3`04018?3P0A3@`04A0>01<B40805QDC00@04a8@014@3P0B4@l04Q4?0P0@3`d0500A40h0
4Q4?00h<3@0F51D0B4I702HT9@0L6Q/03P`=010>3`0A3a0040h?00l=3P0>30d03`d>00l>300B4@l0
8B0N01PG5@0>3@/020L50`0>3@/200l>3003010?3@0?2`X03`/:00@03`/:00L0510?014=300@30/0
4Ph=01DA400F4Q4040`;00<03`/:0P0>2PT600l;2P0300h:1`0@30T03`/800803@T602L03`/8014=
2P0@30T03`/800h:1`0?2`P03@T700/71P0?2`X040`;00`81`0A3@`08QhM00T5100400003PX900d9
200D40l03PX901HB4@0K5aH04@d<00/71P0?2`X05A4@02TU900E4A0040`;00/71P0J5QD01@4100d9
2P0@30d04`l@00l;30060P<02PH700l;300B3Pl00`0>2P/03P0?2``02PH700d92P0H51D030P904Y6
A`0N6Q/01P8300<0000>2P/06ADF014=3P0<1PP03@L90P0>20X00`0?2@/04`d?00h82P0500h82P0<
01H@4P0H4Q@03@L9010:300?2@/03@L900/51`0=1`T03`T;00h82P0<1PP03@L91P0=1`/02@0>20`0
2@<700`62P0D3Q806A<G01D?4`0?10P04PL;01462P0200l4200701052@0I3Q804`P<01dB5P0C20`0
30<501`A5@0Dooooo`006oooool01@082@/03a0B018C5@051PP051DG00804A8D00P04Q<E00h?4@0>
3a40414C00/<3P0;3@`03Q0?00lA40803@l>00P0418A00430P0F61L05QPG00lA400A4a8051HE00lA
40<03Q0?0P0=3`h0100:30/02@/:00X<2`0<3Pd200d?3P0@00lA3P0@4Pl03@l<0001000>40d05aTF
00h@3@0=3``04A<@00lA3P0<3P/03a4>014A3`0=3@/030`:00l?3@80414<0P0=3PP04@0>3`T04149
018C2`0?40X03a4<018D3`0@4Pd02`d800`>2@0A4`h04Q@?00h@2`0;3@P0418=01PJ5@0G6A@0414<
00803a0;00<0414<018C3P0A4Pd00P0?40/0100>3`X03a0;00l@2`0?4@/200/>1`<03Q4:03H041<<
014D3@0A50d04A@=010C300<3`P01@L301DG50092`P01`T600`>2`0@4Pd030l800hA2P0A50d03Q48
00d@1`0>4@P020T300<4000L7AP0LG9]01TJ5@0;2`X03@d;00h>300@41003@d=00h>3P0B4Q804Q@A
00lA3P092`T030h;0001000U9b@030h;010B3`0B514030h;00/=2P0A4a003@l>00/=300@4Q404Q@C
00/=300<3Pd03@l>00lA40092`X06A/J00d?3P0C5A@200lA3P8030h;00<03@l<00`>2`0<3P/00P0?
4@h01P0>40d03@l<00h@3@0I6aP03Q0=01@F4`803Q0=00<05QPE00lA3P0?4@h0100?4@h00`0A4a00
3a4>00h@3@0200lA3P0700`>2`0B51404Q@A00h@3@0B51405QPE01@F4`02018D3`03010B3@0A4`h0
5QPC008061XE00<03Q0;00X<1`0;3@P00P0>40/01`0F61<02`d800L9100D5Q405aTD01DG4P0?4@`0
0P0F61<01P0?4@`03Q0;010B3@0;3@P03@l:00lA30<04A<>02d03Q0;01DG4P0C5A003@l:01DG4P0H
6QH04A<@010B3`0=3`X0418=014C3P0?4@`03@l:00lA300@4``05AP?01LJ4`0?4P`03Q0;00lA300B
5@d04A@;014D2@0B5@X03a8700/>1@0H6a<03A09018D3`0C5Q002@`3014D2`0?4PT06A`C00hA200M
81L06A`C014D2`0@4`X03a8901@G3P0G6Q<05QTB01DH4@0D5a000P0B5@h03@0@4``04QD>018E3P0L
7aP04QD>0413?00A4`h03a4<02PZ9@0I6aH04Q@?01HI4P0F6A000P0E60l0700F6@h05aX?01PK400A
5Pl06AhG01LL5@0A5Pl05AXC01@I4P0K81T04QL@01<H4@0F6a@041D>01LL5@0F6aD0724K01XO6@0E
6Q@04aPB01PM5`0I7QP05a`F01HK5@0H7AL06QlI01TN600G71H201PM5`0<01TN600J81X06R4J01HP
600K9Ad08bdU01PS6`0D7aL03QTA01HO6P0H8A`06B8M0P0J8ah0@00I8Qd07BHQ01/T7`0O:2<0:C8]
01`U800G8Q`07b/W01d/9`0H9b806RTT020_:P0Q<2/09SD`01TX8`0O;RT0;Sdh02`k=P0M;2L07R`/
02/k>P0R<S409CDd01la<@0/?Sh09SPj02Hj>`0Y?Ch0<dI:02Tn@@0Z?d80;d9602Xm@@0X>cl0:ci4
03=6C@0gBU40<TE=02/mA`0_@D/0<dEA0312CP0^@4X0?eAF0:Fj^`1WO7d0<dQ902Tn?`0nDe@0D6EV
04AIFP0fBd`0?E9C049GF016Fel0>4eB03Y?E017G640@eQM041EFP13F5d0@EIK041EFP13F5d204IK
H00]04=HFP10EU@0?eEC03mED`0nE580?eEC041FE012F5H0@eUG049HEP11EeD0@eUG04QNF`17GEX0
AE]H04UOG01:H5d0A5YG03mEDP12F5D0AE]H04QNF`1:H5d0Bf5N04EKF@1@IV@0CF=Q059XIP17GE/0
DFMU04aRH01DJVP0FFm]05Q^K01JL6h0F6i/05I_K01HLFh0GWAa065gM01RN7D0H7E`06IkMP1KL6/0
G6mY0080GW5[00`0HGA^05eaJ01OLfP0Ef]P05mcJ020U8/0M8Qo05IYH`1VNG<0J7]f06f0O01ZOGT2
06UnN@0H06ElMP1TNgD0IWeg06MnN01UO7H0HgYd065hLP1MM6h0Fg9/05ieK`1SNW@0Jh1i06AiLP1X
OGH0IW]d05Y_I`1KL6L0IG]_05=YG@18GU80AUa?04MMD01<HUD0D6IJ0P1>I5P0<01>HeX0BV1G04IM
D`1=Ieh0B65J07^DSP1FLFX0BVEN04AOF01gSXD0BF1F04IMD`1RNFl0>E16041GC@13FU00=di404UP
EP1:HEL0=Te304EMD00jD4<0>Dm30398?00_A3X08cL^02Di<00W>3408S<]02<d;P0]?3T0=TE203Q8
A@0bAD<0<49203=5A@0^@4009CDd02@d<`0X=SH08S0`02<b;`0Z=SH07b/[01hZ:P0T;Rd09Bh]02Tb
<@805b0O01<04a`K010I600I8R40>D9102D^;@0M9RD0;3Lc02<`:@0K:2406RHO01<N600G8Q`051hH
02L`:`0S;2L05QdI01`R7P0I7a/05a`H00805Q/G00D05a`H01PM6@0I7QX06b0L01`Q7@0201/P700P
01TN6P0G71P05Q`I010F500Y;bd07B<Q020V900A5aD0;38`01dS8@0I7ad03A<A018H5P0Y;b`07R0M
01@F4@0C61@02@l?010F5P0@5AP04QLJ01XO8P0D5QH05Q@E01XI5`0C40d061LE01DE4`0B4Q004A4?
01<C4@0F5Q@2018B400<00d=2`0P81h0<C4_01TJ5`0G6AH051TE010B3`0E5a@03@l<01TI5`0>3P`0
4a<A0P0G5Q@0100C4@l03`/:014@3P0C4Q0201HE4`0401<B400A40h04A0>014@3P8040l=00/04A0>
018A3`0<2P/040h?03lm?P0M6a`05aDF00`:2`0A3a004a4B018@4@0200l=3P08010>3`0>3@/04Q4?
00X91`030P004a8@00X91`0<2`T200d<2P<03Pd;1P0?2`X301<?3P04018>3@0?2`X03`/:00h:2@80
3`/:0`0@30/600l;2P0700h:1`0?2`P03`/800d91P0>2PL03`/8010<2@0200h:1`803`/801l03PX8
00`81`0=2@P03@T800X61@0B3Pd0:BDT014=30091@@04@d<00`81`0>2PT02@D501<?3P0D40l03`/:
00h:2@0=2@P02PH501`H5`0<20L03@T800h:2@0O6aX06aLG014=3P050@804`l@02@P8@0N6Q/03PX;
00804@d>00`03@T:00h:2`0?2``03`/<00L310091@H0510A00P41@15@D804Ph?00/7200E4A82014=
3P0700T51P0<1PP03PP:00l92`0>20X03`T;01<=3`0600h82P04014;3@0D3Q002P@600l92`803PP:
00<02@<500X41P0:10H00P090`D00`0=1`T03@L;00d72`0400d72`0900`62P0;1@T04@/?01PB5P0J
51P050hB01052@0B1`/04@H:00803`@800L040D901@93@0900801`0001H;3`0A1PX04PL;01Cooooo
000Kooooo`0I00l@4P0>3a404Q<E014B500>3a404Q<E00/<3P0C51H03a0B00`=3`0?4180414C00d?
3`0?4A40418B010A4P0?41403Pl@018C500P8R806AXK01hO7`0D5AH03a0A014C4P02010B4@803a4@
01L03Q0?014C4P0@4Q404Q@C01@F5@0A4a803Q0?00h@3@0=3``0418?00lA3P0D5Q<030h;00d?300>
40d04aDB014C400<3P/03Q0=018B400=3@/030`:00l?3@02014B3@0600l@2P0>3`T03Pl9010A2@0A
4PX0418;0`0?4@`200h@2`0700`>2@0>40/04Q@?018D3`0>40/030h900l@2`02014B3@80414<00P0
3a0;00h?2P0>3`X03a0;010A300?40/03Pl:00d?2@803A090P0>4@X01@0@4``04aH?01<F3`0>4@X0
30l800804aH?00T03a4;01/M6@082PH06Q`H00`>2P0?4@`03a8<010B300@4``00P0>4@T05P0=40P0
3@h801DF400?40/05QLC01DF4@0B4Q003`l=01<C4@0E5AD04A4A00l?3`0C4a<04Q@A01HH5@0@4Pl0
4A<@01XL6@1jO7T03a4>010B3`0A4a0200h@3@0O014C400=3`h02`d<01TK6P0O8B004A<B00lA400[
;B`0>cdl00lA400H6QT02P`;00lA400C5A805QPE010B3`0?4@h04aDB00lA3P0>40d04A<@010B3`0>
40d03@l<00h@3@0<3P/03Q0=03Pj=`0>40d0418?00`>2`0600h@3@0301<E4P0@4Pl03Q0=00803a4>
01L03@l<010B3`0A4a003Q0=01DG500L7Q/06adJ00d?2P0A4`h03a4<010B3@0C5A004Q@?00d?2P0>
40/04A<>01<E400?4@`02`d800lA300F61<04A<>00lA3@0200h@2`0;010B3@0L7QT071hI01<E400@
4Pd04aD@00lA300A4`h04Q@?01<E400@4Pd00P0?4@`01@0:30L04aD@01@F4@0?4@`03Q0;00803a4;
01`0418<010C3@0A4`d041<=00d?2P0A4`l06A/G014C3@0?4@d04aD@00d?2@0>4@X04aH>014D2`0A
50X04QD;01XM4`0?4PT02Pd501XM5P0A50h04aH>018E300U:1l03A0701/N5@0930<04QD<0P0>4@P2
01DH3`0301@G3P0G6Q<04aH?008051L@00D04A@=018E3P0<3`P071lH01@G400201HI4P07014D3@0E
5a8061XE02la;00L7QT05QPC01<F3`0301@G3P0501DH3@0F6@h061/@01@I4P0A5Pl00P0H7AH02@0?
50d05Q/D01<H4@0A5Pl08bPQ02/`:@0K81T04QL@01DJ500201PM5`0401LL5P0E6Q@05AXD01TN6080
5Q/E00<061dG01TN600H7AL00P0G71H02P0H7AL06AhH01dS700N9Ah072HN01<M5@0L9Qh062<K01TT
700C7QH301PQ700O01TR7@0K91l072DP01DN6@0S;2L07BHQ01DN6@0P:B@0E5mI02Pd<00N;BP06RTT
01l^:@0Q<2/07bhY024`:`0S<Rd082lZ01d/9`0`?cX0JGQc07J4Q00Y>CP09CDd02Hf=@0U=cL09SPh
02Pj?00U>CX09c/l03=6BP0202Pm@00E02`o@P0]@D<0;D1302/nA00]@4L0;d9903M9E00eAe@0=dUG
03Y;FP0iBU/0>D]G03eCE02K/;00D6EU03A:B@10EUD0>Dm>049HE`0cB4P0>U1?0080AU]K00d0Bf1R
03aAEP0oE5T0@UML041EFP0mDUL0?eAI045FF`12Ee`0AU]P04MLH@15FUl0@5EG00<0>e5?00H0?59@
03eCD@10EU@0A5YH04MMF`18GU`204EKF@0:04QNG01:H5d0B5iK04QNF`17GEX0A5YG049HE@17GEX0
BEmL04YPG@80CfER00D0CVAR04QNG01=Hf40F6i/05I/JP02055WI@0N05Y`KP1PMW@0G79`05]aK`1J
L6h0FW=`05aeLP1MLg00GgEb06=iMP1QMW40IGYe05I[IP1QM6h0Gg9/05e`JP1RMVh0Gg=W05ibI`1D
J5d0DVIK06YnL`1TN6h0GW9X065eJ`1]PGT0Jgmg06aoNP1[OWT0JWmj0P1WOGP02`1YOgT0JX1k06Z0
NP1WOGL0I7Ye05meK`1MLfd0HGMb06MmN01UNW<0HgQ`0080HWM_01T0G75X05AZG`1<HUH0C69F04mU
F01;HE@0@eU<04EKCP1CJEd0Bf5E04eSE`1>I5T0B5mD04IMD`17HEL0BVAK06b6OP15H5T0A5mH051[
HP1JLFP0>E1603mFC010Edd0?EA:0080@eY@03@0AEaB03aCB@14Fe40?5=903E<@P0fBcl0<TLl0315
>`0]@3P072hY024b;P0]?ST09CDc02<c<00W=c@0;Cdj02hn?@0cADH0;Sm003A5AP0a@T80;C`l0350
@00/>cT06bTV01dZ9`0S<2/09c@^02Hb;@0]=S@05QlM01lX9P0I8R0051dK01<L6P0J8b407bPV020Y
9`0M9R@0:C8`02Lb;@0J9b007BXS01/W8@0I91h062<M01hX8`0Y<Rd08BXU01XR7@0J81`051XF0`0H
7AT201TN6P0h01XO6`0L8Ad0724M01/P700I7QX05a`H01HK5`0I7a`09B/Y01XP7P0O9B<0E5YH03a2
@00k@Cl07B<Q01DK6@0K8Al07B<Q01HL6@0?4@`07b8L01@I5@0L8R00JFm^03Tn@00=4Q@08BLW01<E
5@0E51806QTE01HC400I61D05QLC01DF4P0D5A405AHB01LH500@40d06a`H00l?300M7AX0?Slk02@U
8P0@4Pl061dI03Tk>02j_;T0TYBA01hN700A4@l05ADC01TH5P0H5aD05Q<B018>3@0A40h401<B400=
014@3P0@3`d040l=00l>300@3`d04A0>018A3`0C4A803`d>01LE5P0@3Pl04@l@01<A4P05010>3`09
014?400?3P`030/901HE4`0@3`d03Pd;00T81P0;2PP03`h<00804Q4?00<03`h<00d<2P0@30/01@0@
30/01P0A3@`04Ph=018>3@0B3Pd03`/:00d920803`/:00@040`;014=300A3@`04@d<1P0?2`X01P0=
2@H03`/800l;200=2@H03`/8010<2@803@T600/040`901<?300@30T04@d;010<2`0>2PT03@T800/7
1P0>2PT04@h=00d9200200h:2@0900T5100;1`H040`;00l;2P0>2PT03@T8014=300>2PT02`L60080
4@d<00/03`/:01@@3`0E4A00514@01@@4@0b;Rl0;b//010<3@0?2``03PX;014=3P0300l;300300h:
2`0?2``040`=00803PX;00<0510A00/7200@30d00P0=2@X0100400404`l@010=3@0>20X200l92`80
3PP:00<04@/=00h82P0>20X0100>20X01P0=1`T040X<00T31@0@2P`03PP:00`6208040X<00@03PP:
00/51`0<1PP040X<1P0=1`/04P0<1PX03@L;010:3P0A2`l03`T=00/52@0B1`/050T=01872`0@1@T0
3`@801052@0K4Q@0K65U01/B500;0@@03@<601H;3aCooooo000Kooooo`0901PI6`0;30h04Q<E02@U
9`0=3Q0030d?01<D5P0N7b4061TK00803PlA00d04a@F014B500>3a4030d?00h?4@0?41803@h@018C
5@0@4A<00@8401XK7@0B4aD01`P:00804A<B0P0@4Q4200lA400S00d?3P0>40l04A<B018D4`0;3@`0
1PP700/=2P0D5Q<05QPE00lA3P0@4Pl020X700h@3@0?4@h04aDB014C400=3``03Q0=010@3P0>3P`0
3`l=014A3`0?40/03@h9010A2`0?40X03Pl900h?1`0?40P04A<<00lA300;3@P03@l:00lA300>40/0
0P0=3`X01@0<3PT02P`700/=200>40/04A<>00<04Q<>00<03a0;00d>2@0=3PT01@0>3`X07@0=3`T0
3a8;018E3P0@4``03Q4:00`?200930D041<<018E3P0<3`P03a8;010C300?4@/04Q@?00d?2P092`H0
20X5014C3P0?4@`03@l:00/>1`0=40T03a8;00hA2P0N7aT01@H0014B3@0=3PT05aPC008030`:02@0
4A4?01HF5P0@410030`<00h>3P0:30T02`d:00`>2`0M7a`04A<@018D4@0?4@h0418?018D4@0E5a@0
51HC00lA3P0C5A@02P`;00`>3@0@4Q403@l>01PJ6@2;SH`0TI>B01PJ6@0B51<04A<B00H81`0?4@h0
4Q@A00/=2P0:30T03Q0=00X<2@0?4@h2014C400900lA3P0=3``03Q0=010B3`0D5Q<00P@100d?300=
3`d05ALD00H03Q0=00<05QPE018D4@0?4@h00P0@4Pl200lA3P0>014C400>40d03a4>010B3`0=3``0
4aD@01HH4`0@4Pd04Q@?01HH4`0D5Q404aD@00lA300>40/2010B3@<03a4<00D0008001LI500<3PT0
418=00lA3002018D3`05010B3@0>40/03Q0;014C3P0>40/00`0=3`X04`0>40/04A<>010B3@0?4@`0
2P`700h@2`0C5Pl03Q4800hA2P0A50d041<<014D3@0B50h05ALB024S800Z;2T030h;00T;200I71H0
0P0@4``0400E610041<:00lB2@0C5Pd03Q4800D8000G6Q806ahG00H90P0L7aL092LN0454>`0A50/0
6A`C00L:0@0B5@`2010C2P0E01<F3@0?4PT04QD<01DH4@0@4``04QD>01@G400?4P/04A@=01@G400G
6Q<03a8;014D3@0K7QL04QD>01HH4`0A4`h05QPC01@F4@0H6QD04aH?00804QD<00D04aH=01@G300E
60d05aX?018G400201LL5@805AXC00L041D>01XO600?50d051TB01TN5`0?50d05AXC008051TC0380
5Q/E01LL5P0F6aD04aPB01HK5@0D6A<04aPB01DJ500G71H05Q/E01hS7@0K81X05a`F01HK5@0E6a@0
51/D01HP600I8a/03aTA01hY8@0@6a<082/S01/T7`0J8ah0624L01TR7@0M9R4082TT028[9P0I8Qd0
72DP02H_:P0M9R408bhX02Hb;P0J:B@07RdX02Th<`0W=S408S4/024`:`0H9b807bhY02dl=`0`?cX0
Ohj907^9R@0M;B`0<D5002De=080:C/k01D0:S`n02Lk?00U>CX0:Se102Hk?P0]@T<0;T9202i2@`0/
@440:ci20354BP0fBE00>TaG03]=F`1bQ980FV]l03I7F@1KKG/0=DY;02Y0?P16G5X00P0eBdT02P11
EeD0?59@03A:B01FK6X0D6IT02m5@`0iCU00BUmT055VJ`13F5d303iCF006045FF`13F5d0B5eR04QM
HP14FEh0@5EG0P0nE5802P0mDe40?UAB03mED`0nE580@EME04ILFP19Ged0B5iL04MMF`18GU/204YP
G@0404QNF`17GEX0BEmL04UOG080CF=P0140Bf5N051VH`1>I640DfUW04eSH@1IKfd0Bf5O055WI@1M
Lg40DfUW05]aK`1OMG<0FFm]05]aK`1NM780IWml06EnN`0205meLP0E06QnN`1YOWT0HGIa04eRG@1P
Lfd0HWE_05mbK01KKfL0G71T05=XF@1FJUh0Cf=G055UF@1QMFX0Ig]`061dJ@1^PWT0J7ac06n2N`1c
QX00JWmj0080J7eh02L0JWmj06b1O01/PG`0Jh1k06QmN01RMg80H7E`06EjM@1[P7/0IGYc06QmM@1P
MF`0GW=Z05ebJ01<HUH0CF=G04iTE`1<HUD0AUa?04EKCP1BJ5/0CVAH04eSE`1AIe/0C69F045HC@13
FU00C6IK04YTFP12G5<0B6=L04iYHP0oFU40A5]A041GC@0iD4H0?5=904eTFP0oET`00P11F4h0=`1A
J5h0AUeC02]2>00lDDP0?5150393>`0`@CT0:CTe01LW9P0O;bl08S8b020`<00R<S40:3Pf02`l>@0]
?C`0=TQ902ln@@0eADD0;Shn02Hd=00[>SL0E6=O02di=@0R;bP06bPQ028_9P0R;BD072DR024Z9`0L
9B806b@Q01`U8P0G81d04a`I028[:00O:2D041TF028[:00Q;2L062DN01`Y8P0F8Q/05R4K01@O6@0O
:B<07bPS01HO6P0L91l0728N01HL600L8Qh06b0L01XO6`0I7QX00P0J7a/00`0I7QX05a`H01HK5`02
01DJ5P0J01HK5`0G7AX03A<A01lU8`0L8R004QPF02@Z:00W;B/051XH01XP7P0G7A/04aTG01DK600I
6aH041<<01LL5P052`L092XX02D[:`0>51@00`T901XL6P0:2@D07QdI01TG4P0F5A4501DF4@0D01`M
600?40/04Q<>01HG4P0:2`H04Q<>00X<2@0M8Qh0;S0]0<G7a02;SHX061PF018B400A4@l040l=00l>
300B3`h04`l>018A3`0A40h2010?3@03014@3P0B4@l03`h<00<03`h<01X04A0>018A3`0?3@h04a4B
00@20`0H5QL04Q0A010>3`0>30d030X;00d;300?3@h04@l@00h<3@0D4a404A0>00d<2P061@<03`h<
00L6100<2`T04Q4?01LF500F5A<04A0>00h=2`H04@d<0`0?2`X01@0A3@`0510?01DA400B3Pd04@d<
008040`;0P0>2PT600l;2P0<00`81@0?2`P03`/800d91P0?2`P04@d:00/7100>2PL04`l<01LC400C
3``03`/90P0<20L06@0B3Pd040`;00h:2@0>2PT06QHE014=300>2PT040`;00D1000<20L040`;014=
300@30/04`l>018>3@0?2`X00`00018>3@0<20L0510?00@0000?2`/01`<400h:2`0E4A800`0=2@X0
4P0;1`P03@T:018>3`0@30d03@T:00l;30050@803PX;00D10P0;1`P02PH700H20`0=2@X04@d>00H2
0`0L61T02PH700h82P803`T;0P0<1PP700h82P0900`6200A2`d02`D7014;3@0?2@/02P@600P2100:
10H03@L9008030H800<03`T;00d72`0=1`/0100=1`/04P0;1@T030H:00/52@0:10P030H:00l93@0B
1`/050T=01872`0@1@T03`@801052@0X7B40bl3402PM8@0700005``@01052ACooooo000Kooooo`0?
01<D5P0B4aD04a@F01@E5`0C51H03PlA014B500R8bD04a@F00l@4P0H6A/01`P:01DF600=3Q002``>
008030d?02h0414C014B500;30h03PlA00P92`0A4Q@051DG00h@3`0;3@`01@L601LI600=3`h03a4@
01@F5@0>40l02@/:00h@3`0A4a8030h=018D4@0?4@h0418?014C40051`@02`d:014C400620D05ALD
00h@3@0G6AH010H3014A3`0=3@/02@T700h>300B4`h03Pl:010A2`0B4`d04a@>01<D300@4@T03Q09
01LI500?4@`03@l<0P0:30L04`0D5Q403Q0;00lA300>40/03@l:00lA300B50l02``701XK5P082@@0
414<01HG4P0=3PT04Q<>010A300<3@P04Q<>01DF4@0?4@/00P0:3@H0100=40T041<<010C300>4@X3
00`?200400d@2@0>4@X03a8;00hA2P803A0901/03Q4:00lA300@4Pd03Q0;00X<1`0F61<00`D0010B
3@0?40X03@h800`=200>3`X03a0;00l?3@0>3P`05ADC01@D500>3Ph0410@00l?3`0B51402P`9010B
3`0F61D071hK00X<2@0@4Pl00P0?4@h02@0>40d03a4>010B3`0;3@`030h=00l@3`0F61L020X9010B
4@0202/];006014C4P0@4Q404Q@C010B4@0:30T03Q0=0P0<3P/00`0?4@h02`d:010B3`03010B3`03
00h@3@0=3``03a4>00D03a4>00D02`d:010B3`0@4Pl051HC00X<2@0201HH5@0Y00/=2P0<3P/06Q`I
00P91`0E5a@04aDB02<U8P0N81d051HC01HH5@0J71T0418=00h@2`0=3`X03Q0;014C3P0B50l03@l:
010B3@0?4@`04A<>010B3@0?4@`030h9014C3P0D5Q404aD@00d?2P0:30L0418=00d?2P0>40/04aD@
018D3`0?4@`04A<?018D3`092`H05ALB00h@2`092`H00P0>40/0400B50l0418=00h@2`0@4``030l6
00/>1`0E61404A@=00hA2P0>40X03@l:014C400C5A8030h;00h@3@0C5Q02010C2P0Z014D300B5@h0
4QD>018E3P0<3`P061/D00/>1P1?DTT0?T4h018E300J7A@07b8I01HI400C5Pd05AP?010C2P0?4PT0
4QD<010C2P0A50/04QD<010C300A50d05APA01LJ4`0F6A805APA00lB2`0G6Q<04QD>00X=1P0;3PL0
4QD>01XL5`0:30L05QPC01TK5P0A4`h05QTB01/N5@0J7A@05QT@0P0A50T04@0G6Pl03a@=01<H4@0G
71D051TB014F3`0B5a003Q<<01<H4@0D6A804AH?01<H4@0A5Pl03A8<01PM5`0M8Q`06AhH00805AXD
00P051TC01hS7@0N8ad06b0J01`Q6`0K81X06QlI01LL5P8061dG00`06R0J01DL5@0H8QX051hF02H`
:00/=bl07RTQ01HQ6@0N9b80624L01LP6`0K91l2024Z9@1;034j=@0P:B@06R<N01dV8@0O:2<08B`V
02<_:`0P;bX09C@_01`[9P0R<B`0<d8m02Xi=00M;2L093<^02He<00X=c80<D0k03A2@P0X>3L0;cln
02/k>P0U=cL0<49202Hh>P0Y?Ch09CTj02Dh?00T>C`08SLh02e1@@0^@T40<4A503=6BP0aA4X0<4=:
03I8D`0kCE/0[;k<07:3T`0dAEL0<TAB03aAE00/@D80<TM804IKG00iCTl0AU]L03Q=CP19GUl0>4e>
04eRH`0`ADH0=da>03aAEP11EU/0@UML03I;D016Ff00AEYO04MLH@1:Gf@0@EIK049GG016Ff00@5EG
03aBD011EeD0AE]I041FE014FUP0@EME04AJF017GE/0B5iL0080BV1N00<0BEmM055WI01CJFH00P1:
H5d204]QGP0704eSH01;HEh0BEmL04UOG01>I640CVAR059WJ00205I[K00305M/K@1MLW<0FFi_0080
FVm`01D0FFi_05Y_L01OM7D0K8F2061iMP1PMW<0GG=`069hM@1RMg80GgA_065fL@1OLV`0GG1Z065d
KP1QMFd0G71T05]`H@1GJel0DfMK05M[G`1SMf`00P1RMV/01`1VNW40Jgmf06f0N@1ZOGL0J7eh06Un
N@1ZOgX00`1[P7/03`1bQh80KH9m06UnN@1YOWT0JWmj06QmN01YOWL0GgA[06=hK`1TNVh0EVaP04eS
E`1=HeH0CVAG04]QE00204]RDP0?04MNCP1?IEP0BV1C04iTE`1>I5P0BF1C04eUF01;IEX0BVAI04MQ
EP14GeH0@UeD041KDP0mE4X0@EQ>0080?UE;0280@eY@04AKD@11F4h0@eY@051WG@1:HEL0<TTo02i3
>P0/?C<0:cXc028a;00T<c408c4b01PV:@0N;C006BP[02@d=00_?ch0;Shk03Y:B@1MKFh0:CTi03E5
A@0^?3`0938b02/j=`0R;R/082`X01l/9@0S;RL0:C@/02dh<00K92407bPU0`0L9B80400C71T05QlL
01/T8@0O:2D0624N01XS800J9B009C8[01LT7@0L:24072LQ01TT7P0L9R4072DP01XS7P0I81`201TO
6`0901dR7P0F6aL05AXF01LL600E6QH0>3di0415@@0J7a/06AhJ008061dI00<06AhJ01TN6`0H7Q`0
0P0I7ad05@0H7Q`05adK00/A3`0K8Al0728P010F500c>CL04aTF020R7@0B5@h05AXD01HL600C6AL0
318B01<I6@0A5aL04Q@B01PG4`0N7AT04@l:01PG4P0201@E3`0H01PI4`0I6Q@05aPB018C3@0V9b40
5aPB01<D3P0I6Q@04a@?00h@3@0J7a/04Q@A03@f<`0Y:bP03`l=010@3P0@3`d05A@B02<R800;20L0
510?00X91`0I61H03Pd;0P0A40h01@0B4@l03@`:018A3`0C4Q004Q4?008040l=0P0E4a@010071@H0
3@/<01HD5@0C4A82014?400601HD5@040P<03P`=00h<3@0B4@l02`X90P0920H02P0A40h01@@200/:
200>3@/03`h<00h=2`0?3P`040l=00d9200@30/2018>3@05010<2`0?2`X04@d<00d9200?2`X00P0F
4Q40200D40l08alN00d9200>2PT04`l>018>3@0C3`h04@d<0P0>2PT02P0@30/03PX900d9200H5140
2@D200d91P0B3P/02`L400X60`0A3@X200l;200300h:1`0C3``02`L500D03PX900d02`L6018>3@07
0`804`l>00X61@0>2PT04`l>014=300@30/0FUIE07YfM@0<20L04`l>00803PX900`03@T800h:2@0>
2PT03PX:00d92P0?2``040`=00l;300=2@X03PX;00/7200:1PL200h:2`0400/7200=2@X03`/<00d9
2P<030P91P0=2@X2014;3@0800l92`0<1PP030H8014;3@0@2P`03`T;00h82P0<1PP200/51`0300d7
2@0<1PP030H8008030H800/02`D7018<3P090`D03PP:00X41P0I4aD02@<500d72`0:10P0208600/5
2@0200d72`H030H:00`0304500d21P0?10P04PL;01462P0>0`L05``@02XO8`0J3a<03P<701<8300=
0PHDooooo`006oooool0500A4Q@0414C014B500B4aD0414C00d>400:2`d051DG010A4`0>3a404Q<E
00/<3P0C51L030d@00h?4P0@4A@03a0C014B5@0720/04a@G0P0?41<02P0;30l020T;00d?3P0H6QT0
418A00/=300620L0418A04M9B01HFUT200lA400600P:2@0>40l02`d:00lA3P0=3``0418?0P0>40d0
100=3``06Q`I00H81@0?4@h2010B3`0700l?3@0<30X0410>014A3`0<3@P03@h900l@2P02010A2`0<
010A2@0?40P03Q0900d?2P0:2`P051HA014C3P082PD04A<>010B3@0A4`h03Q0;0`0;3@P0500C50l0
2P/601<D3`092PD03a0;010A300A4Pd0414<00d>2@0A4Pd04Q<>010B300@4``03a8;014D3@0C5Pl0
4QD>00lB2`0=40T03Q4:0`0?4P/2010C2`0L00lB2P0>4@X03Q4:00lA2`0=3`X04Q@?00lA3@0:30T0
1`T5018D400@4@/03a0:00h?2P0@4@`04A8=014A3`0@40h05ADC01DE5@0@41004A4A010@400G6AH0
3a4>00h@3@0<3P/051HC010B3`804A<@01803a4>00h@3@0>40d03a4>00lA400J71/071hM01DG5P0=
3`h04Q@C00P:2@0C5A@02@/:00lA400@4Q402`d<00h@3@0A4a0200d?300700lA3P0;3@X04A<@014C
400B51404A<@010B3`0700lA3P0C00`>2`0B51405QPE00<50`0B514030h;00/=2P0=3``0I6IS02X/
:@0N81d092HS014C400C5A80418?018D4@0C5A803Q0=00h@2`0200lA30<0418=01404aD@00lA300?
4@`04A<>010B3@0>40/04Q@?00h@2`0<3PT03@l:014C3P0B50l03Q0;00`>2@0=3`X04A<>010B3@02
00h@2`0;01/M60082PD04aD@020R7@0A4`h051HA01<E400=3`X04A<>018D3`0@4`d00P0C5@l07P0@
4P`03Q4;014C3@0?4@`04Q@?01DG4`0A4`l0418<018D400A50`04A@:018E300B5@d04A@=010C3@0C
5Q003a4;00H90`0H6a<07b8I01DH3P0C5Pd05QT@01TL4`0A50/03a89010C2P0D5`h04QD<014D2`<0
5AP?01l04QD>01<F3`0F6A805QTB01DH4@0C5Pl04A@=018E3P0D5a0061/D03@g<00E614051HA01<E
400I6aH04Q@?01@F4@0D5a005AP?01<F3@0D5`h06ahC01dP5@0H6a003a@=018G400F6a@05AXC01<H
4@0E6Q<04AH?00805AXC05P051TB01LL5@0G71D04AH@01TN600L8A/06QlI01PM5`0J7aT051TC01TN
600G71H061dG01/P6P0H7AL03Q<=01TN600D6A<06QlI01/Q6`0C6Q<04adE01PR6P0V<2P08bhV01PS
6`0L9al072DP01XS7P0H8A`06B8M01dV8@0P:B@09c0[01lX8`0Q:RD092dX020Y900M:28082`X01`[
9P0S<Rd08S4/02Pg<P0eA3l09C@_020_:P0W=S409SD`024`:`0U=2l0:CLg02Hf=@0Y>CP0:c/j02Tk
>`0]?cl0:C/m02e1@P0Z?Sl0:Se102Xo@P0X?Ch0;41002a0?`0^@T40<DE60354B@0`@dT0<dE=0395
CP0iBeH0?U1M02`nC011Deh0<dQ;03eBEP0_A4H0=T]>05=XK017G5l0G75c08fRYP1:Gf80@eQJ04QM
H@19GV80>TmD0`11EU/02@0iCU<0AEYO03iCF00nDeP0AU]P041EFP0oE5T0@eQJ045GE@0204=IE`03
04YPGP1=Hf40AE]I0080B5iL0140AeeK04QNG01;HEl0BV1N04aRG`1>I640Bf5N04aRG`1>I640BV1M
04]QGP1AIf@0DVQU04mUHP1>I640CV=T059WJ00205U^K`0505Q]KP1IKVl0G75b05aaLP1NLg@00P1R
MgP03@1PMGH0I7ej05igM01UNgP0HGMd06=iMP1WO7L0I7Ud06EjM@1QM6h0GW5[069eK`1SMfl00P1M
LFD0101JKV<0FFeQ05]_I01TN6h206UmL`0706]nM`1^PWX0KH1k06YmN01YOGT0Jgmk06b0N`0206b0
O00J06b0N`1]PG`0K81k06b0O01]PG`0Jgmj06IjM01XOG@0Igeb06=iKP1PMVX0F6iR059XG015Fdh0
C69E04YPDP13FTX0A5];04iUE01?IUL0CVAF055WFP1@IUX0BV5D04YRE@18HUH204MQEP0704IQE`15
HEL0A5mF04MNE019H5H0A5]A04=JD00204ELDP0d04AKD@0hCdD0>e9803I=@`0^AC/0<DHm02hm=00c
@CX0;C/g02lk?@0/>Sh0934h02Le?00O;S<09C@g0351@@0_@3d0>4Q603E5A@0c@T80;3`j02Pg=00`
?C/09S<`02Hb;P0^>SD0;3Pb02<^:00S;BH09c4[024Z9@0M9R808R/W01HO6`0V;b/0>T<o01hW8`0G
81`072DQ01hW8`0M9R806bHQ01/X8@0F8a`07BTS02/f<01XLfd082XT01lX8`0L9B006B4L01LM6@80
5Q`H00T051TE01PM6@0M8Qh05a`H01hS7`0S:2@06b0L01XO6`0I7QX00P0H7AT0;00I7Q/06AlM01TO
7@0I7ad05Q`J01@J600Q9bD051XH00lE4`0P9R@03aDC018H5@0B5@l04QD=01@I4`0A5a<04aTE01HL
6P0G7A`020d;01HH5@0Q81`06QTD01DC3@0H5a805AH@01@E3`0F5a405aPB01DF400C50h07b0J01dN
600I6Q@03Pl9014C300D5Q<02Pl;01DG500@4Pl051HC01<C4@0?3`d051@B0P0@3`d08`0J61H04@d<
01LF500B4@l020L5020O7@0>3@/061LE01`K6@0C4Q0030/900d<2P0B4@l05A@B018@4@0=2``07Q`M
00h<3@0A3a004a4B07=aLP18ATL020L701/I6P0C4A801`H600H50`0B4@l02`X801TH5P0=30X051<A
00X91`0>3@/03`h<00803Pd;00<03`h<018>3@0D40l00P0F4Q401@0D40l04`l>01<?3P0B3Pd04@d<
00@040`;00<030P7014=300D40l00P0?2`X03@0A3@`03PX900h:2@0@30/03PX900d9200K5a@04Ph;
01@@3`0A3@/03@X8018>2`0=2@H00P0A3@X00`0=2@H04Ph;00/71@0500h:2@0<00l;2P0@30`0F5AC
01LC4P0?2`X04Ph=01@@3`0<20P03`/:04Y6A@1/J6L05A4A0`0>2PT01@0=2@P03PX900h:2@0?2`/0
3@T:00<030P90P0=2@X00`0?2``04@d>010<3@0200`82@0300l;300@30d03`/<00803PX;00<03`/<
00d92P0=2@X0100=2@X02`0>20X03`T;00l92`0=1`T030H800l92`0=1`T03PP:00l92`0>20X03@L9
00@030H80P0=1`T02`0>20X04`d?00X41P0?2P/05Q0B02@N800C3@l02P@800/52@0=1`/03PP<00P0
3@L;00X04PL;01462P0A1PX04PL;01052@0<0@D03@8601H;3`0C20`03`@80P0A1PXDooooo`006ooo
ool03@0D5AL04Q<E018C5@0C51H04Q<E00l@4P0=3Q003PlA01<D5P0B4aD03a0B01<D5P0F5a/00P0>
3a<0:00?41@03PlC014B5P061`/030dA00H72`0?41@030dA01DF600<3@h020X900`>3@0J71/04A<B
00T;2P0D5QD01PP7014C4P0=3`h04Q@C00h@3`0<3P/051HC00lA3P0A4a006A/H00lA3P0=3``01PP5
01TK600K7AX01`T6018D4@1:BTP0410>00X:200=3@/01@H100@5000>3`T200l@2P0M00l@200>3`L0
1`T400`>2@0L7QT0BTa703Pj=@0>40/020X500`>2@0>40/03@l:00`>2@0=3`X02`d802DV8@0=3PT0
71dH00P9100F5a803@h901@E400E5Q4051D@01<D3`0B4`h0418<00lB2`0=40T00P0>4@X02P0=40T0
30l800d@2@0@4``04QD>014D3@0?4P/04A@<018E300@4`X300hA2P0?00P:1@0E5a802P`900X<2@0U
9b@02P`9014B3@0?40X03Pl:010A300B4`h04Q8@00d=2`0?3`d03`l?00803@d=00X030`<00X<2@0:
30T04aDB00lA3P0D5Q<04aDB018D4@0A4a00418?0`0>40d03P0620L051HE01@F5@0<3Pd04A<B018D
4`0E5aH061XI00/=300?4A00418A014C4P0>40d0418?0P0<3P/01@0?4@h03@l<00`>2`0=3``03Q0=
00803@l<00<030h;00lA3P0?4@h0100?4@h03`092`P03@l<01dO700A4a004aDB01LI5P0E5a@04aDB
0001000<3P/06Q`I01@F4`0C5A803@l<00/=2P0201<E4P0300`>2`0=3`X03a4<00804A<>00h03a4<
00h@2`0@4Pd02`d800h@2`0B50l03a4<00h@2`0A4`h05QPC01TK5P0H6QD04Q@?00lA30<03Q0;0P0?
4@`09@0>40/051HA00@60@0C5A006Q`G01LI500620<061XE01TK5P0=3`X04aD@01DG4P0A4`l04A<@
00d?300=3`X05ALB014C3P0>40/07AlJ01hP6`0@4``05AP?01@G400<3`D03Q46010C2P0C5Ph04aH?
018D3`0L7QT0?d4l010B3@0>4@T03A0700T<0@0=40H00P0B5@`0100@4`X04A@;018E300D5`h200d@
1`0401HI400B5@`061/B01@G40805APA01L051L@018E3P0A50d06A`E00/>1`0F6A805aXC03/n=`0D
5a0061XE00lA300>40/03@l:01PJ5@0K7QL051L>01<F3@0G6Q4082<H028U6P0L7a@04QL@01<H4@02
01DJ4`8051TB02@05Q/D01LL5@0D6A804QL@01@I4P0A5Pl041D?01@I4`0F6aD05AXD01HK5@0I7QP0
61dG01LL5P0D6A<06AhH01hS7@0I7QP04QLA00`A2`0R9b4061dG01@J500F7AH082XR01dW7`0J91`0
51lG01<N5P0P:b<06R<N01`U800J8ah05b0K01TR7@0O:2<201PQ700<020Y900U;RT08BXU01lZ900[
=c<082lZ01h]:00L:bH06bXU01l^:@0Q<2/08S4/0P0Z>C@0;`0V=C00:3Lb02/i>@0_?ch0;3`k02dm
?00/?Sh0:C/k02Tk?@0^@T<0;41102/n@P0Z?d809c`m02Hj>P0kCdh0@EED03Y>C`0aADH0<4=70313
B00fBDl0=4M=03M:D@0_@TT0=4M>02i3B@0_@dX0>4eB04EIG`0lD5L0@5EK04QMHP1ZOXD0?e=I04ML
H@1<H6L0?eAI03A9CP1LLGH0?eAI04IKH00lDEH0AEYO04iSJ01BIf`0CF9W0080@eQM00`0AeaN045G
E@13FEL0AE]I05ecL@1RN7H0Bf5O04MMF`1<HV00CfES04YPGP1;HEl404eSH00304iTH@1@IV<0CVAQ
00<0C69O00<0CVAQ05E[J01GK6d00P1GK6d08P1HKFh0G75b06=hN@1YOWl0HWMh05Y_L01MLW<0HGIg
05mdM@1TOGX0GgQe06MmNP1RN7D0I7Yg06IkMP1TNG@0IGYe065dKP1OLV`0I7Ma06MjM01PM6/0H7AY
05mcJ01PM6T0HWI]06IjL@1YO7H0J7]e06YmN01]P7`0K7mk06UlN01[OWX406f0O00O06aoN`1[OWX0
JWei06]nNP1]P7`0Jgij06QkM@1OM6/0I7Y^05idJ01IKf<0EfeQ04iTE`1UNfh0DFMI04IMC@17GTh0
BV5@04]RD01?IUH0D6MH05=YG01AIeX0Bf9E04MODP13GE00AEmC04IPE@17HeL0BFAJ04UTF`0204EL
DP0M041GC@0oET`0@5M=03iEB`0mE4X0>4m503YAA`0dBd40:D0f02Xn=@0^>S80<Sdi02`h=P0/=c/0
;cU202/h@@0]>T<0<T5803=2A`0iBDX0<DA203I9A@0kBTH0;chk01h]:00fAD40B5A@02Hb;P0N:RH0
0P0Y=3005@0R;BP082TV024Z9@0W<2/072DP02D^:@0I8Qd092dX04=<A`0Q:RD0624L01/T7`0P:B@0
7RLR01hY8`0D8AX05B8K01PT7P0c?SP0JgI`01dW8@0201XS7P0301XQ7@0J81`06R0L00806QlK00h0
61dI01DJ5P0H7AT05Q/G01DJ5P0H7AT05a`H01TN6P0J7a/06b0L01PM6P0C6AL05A/I01LM6`8061hL
01@05Q`J01TO7@0^=380FEmM02D[:@0F71T05aXC01lR6@0F6a@03A@=00hD400J81h0728P01PN700J
71P03`h901dL5`0G5@h05aHA01DF408051D?0P0C50h0=`0I6Q@06a`F01LH4P0E5Q004Q<=01DG4@0C
5A001@X601@F4`0>40d05QPE014A3`0F5Q@040l=01PG5@0<2`T05Q@B01PD4`0@3`d05QDC00`;2@0G
5Q@020L501DD4P0C4Q0040l=018A3`0F5A<04Q4?00T81P0H5QL020H7018@4@0;2@X0518C00`:2`0k
>CX06QPI020N7`0610D0?C/l02@R8`0@3`d01PD301LF50071P@051<A00d<2P0:2@L03@`:00h=2`0=
30X030/900d<2P0>2PT00P0?2`X01P0@30/03PX900d9200A3@`0510?018>3@8030P700<03PX900l;
2P0=2@P00P0<20L00`0?2`X04`l>014=300200h:2@0?010<2`0>2PT03@T8014=2P0E4@h06aLD00P4
0P050@002PH300d91P0@30T03@T600`81@0K5a@0510>00D03PX900d03`/:01@@3`1oNgX0920O00/7
1P0@30/02PH500h:2@0F4Q401`@300d9200300004Ph=00803PX900@03@T800h:2@0>2PT03PX:1@0=
2@X01P0<20T03@T:00h:2`0;1`P030P900d92P<03`/<0P0>2P/00`0?2``03PX;00h:2`0300d92P0O
00`82@0:10H030H800h82P0=1`T030H800h82P0;1@L030H800l92`0@2P`03`T;00d72@0:10H02`D7
00`6200=1`T03PP:00l92`0400002@<501LA4`0F41805@lA018<3P0:10P02`D900X420070@D02P@8
010:3P0600h8300<00h31`0=0PH03@8600l4200@1@T03P<701@93@0>0`L04`P<01@93@0<0@D03`@8
5?ooool001_ooooo00h04A8D00h?4@0=3Q003PlA00l@4P0<3@l04A8D00l@4P0D5AL04Q<E00d>400C
51H07QlS01<D60<0414E0P0D5AT0900;31003a0D010A5@0<3A4061TK014B4`0:30/03a4@02DW9P0K
7A`03Q0?00X<2`0>40l0418A00L9200H6QT02`d<00lA3P092`P06A/H00`>2`0;3@X03Q0=00`>2`02
10406A/H00lA3P0620D04A<@01TI5`020P003Ph<01/K6@0G61<061TD010A2`803a0:00P03a08010A
2@0G61800040014C3P0@4Pl0004001TK5P803@l:00<03Q0;00d?2P0<3PT00P0>40/01P082@@0414<
05EFD@0A4Pd05QLB018C3P80414<00D04A8=00h?2P0=3PT03Q0:00d@2@0300`?20802`h702H03A09
010C300B5@h04A@=00lB2`0@4`/04QD:010C2P0>4@P03A0700d@2@0:30L02`d800/=2P1CEE@0O7im
00X<2P0A4Pd03a0:00h?2P0@4@`04Q<>018B400A4@l0410>014A4@0B4Q80410@00l?3`0:30T02`d:
014C40082PL03@l<010B3`0A4a00418?00lA3P803Q0=00l03a4>00d?3P0C5A@04A<B00h@3`0I6aX0
5ALF00h@3`0A4a802@/:010B4@0B51<05aTH00`>2`0>40d00P0;3@X00`0@4Pl03a4>00`>2`0200d?
300300h@3@0=3``030h;00H03a4>01@01PP501hO7@0;3@X05aTF00T;20072@H04A<@00lA3P0=3``0
71hK05EGE00c=C803a4>00d?30092`P03@l<010B3`0=3``03@l:00lA30804A<>00@03a4<00h@2`0?
4@`030h90P0A4`h0200;3@P030h900lA300H6QD071hI01XL5`0A4`h03@l:0`0@4Pd200lA300`010B
3@0c=C006A/F01@F4@092`H06A/F01dO6P0D5Q405aTD00h@2`0@4Pd04A<>018D4P0E5aH04A<B00`>
2`0@4Pl04Q@?010C3@0I71D06QdF00lB2@0F6@h05AP?00hA1P0@4`P04QD<01<F3P0B50l04A<@04i@
C@29RhH0:2XU00L:0P0E60l051L<01LJ400G6Q4051L>01<F3@0B5@`04aH=01@G3P0@4`X04aH=01LJ
4@0@4`X06A`C0`0E61402`0C5Pl04A@=010C300L7aP020/401LJ4`0@4``0:2/T01XM5P0n@3/0828M
00804Q@?00D04aD@01LJ4`0A50/04QD<01DH3`0201DH3@0301LJ3`0F6a@05AXC00805AXC00@051TB
01<H4@0F6a@05a`E0P0D6A800`0G71D04QL@018G4@0301@I4`0?01HK5@0H7AL051TC01<H4P0@5@l0
51TC01XO6@0D6A<061dG02P]9`0O91h06QlI01<I4P0G7QL072HN00805R0H0P0G8QX01P0I91`06R<N
01dV8@0K91l0624L01XS7P807bPS00H072DP020Y900S;2L08BXU028]9`0T<2`201`[9P0601l^:@0P
;bX08S4/028a;00S<Rd09cHa0P0X=c800`0[>SD0;3Xj0351@00202lo?P0302i0@00/?Sh09CLi0080
;D5202d0<4=70356B@0_A4D0<4A404QLF`1:GUd0>Ti=0396A@0dB4T0<DA702Dh?00gBTh0;D1405=V
JP0fBDl0<dM>03A8D@0oDeX0;41804EIHP19GFD0CV9Y04iRJ`18G6@0DFE/04AHH@0oE5X0AeaQ08>H
W@15FUl0@EIK04AIGP0mDUL0GG9g06AiOP11EU/0=DY?03Q=DP17G5h0B5iL04ILFP12F5H0DVQV05E[
J@1:H5h00P1@IV@01@1>I680AE]I04QNG01AIfD0DFMT00D0D6IS0P1?IF801`1@IV<0DVQU05Q^K01O
M7D0GG9e05]`L`1JKg800P1KL7<03P1UNWd0H7Eh05ebM@1RMgX0IGYm061eM`1UOW/0GGIc06AjM`1S
NGH0J7ik06UnN@1QMW40HWMb0P1QM6h0201WNW@0JWeg06=gKP1RMVd0HgM^06AhK`1VNG<0JGaf0P1/
Og/01@1_PWl0LhJ407>6Q01`Ph40KH1l00@0KX5m0280K7mk06j1O@1[OWX0JGah06YmN@1/Og/0Jgih
06IkLP1XOW80HWQ/05idI`1HKV40CVAG05A[F`14Fd/0@eY:04YQC`1?IU@0DfYH04iUE@1AJ5P0DVUI
051VF@1<HeD0AUi@049LC`14GU40AV1C04MSE`1:IUX0BfMK04QOE@17GU@0@eY@0P14Fe40:011F4h0
?eI<03=:@00_AS`0;D@j02i5>`0cAch0<Cdf038m>@0[=CH0:38h030jA00e?d/0=D5=04ECG00mC5<0
=TI702Lj>00[?SX0;C`f01/Z9@0G9Ql0=T8n04EAC@0[=c<07RTU01lY:00Q:bX08b`Z020Y:00N9b@0
8BXU01lX8`0X<B`06b@O00PA300M9R407bPS01hW8P0M9R4201hW8P07028]9`0K:24062DN014M5P0U
<2X082/U01DO6P0201XS7P0901/R7P0K8Ad06R0L01PN6P0I7QX05a`H014F4P0G71P06b0L00806QlK
00P06AhJ01PM6@0H7AT06AhJ01HL6@0C6AL05A/I01LM6`8061hL01<020h<01DK6@0C6AL0;38`01XP
7P0?5A8061/D01XM500@5@h06R4J01@J5P0:40h01P`:00P>300N81`020L2018A300J6A405QH>0080
5AH>00D04a@<018C2`0C50`061TA018C2`0201`M5@0700d>1P0@4P/03a4<018G4`0>40d02`d:010B
3`0201HF500M01<C4@0A40h03@`:01<A3`0I5A@040l=01LF500B4@l051<A01hM6`0>3@/04A0>018A
3`0I61H07ahL01TH5P0=30X05Q@E024O800D4Q<03`d>01@B4`0<2P/00@00018@4@0D4Q<05Q@E014?
40040P<00P0H5aD02`05108040l=00T81`0@3`d02`X800h=2`0?3P`03@`:00`;2@0=30X04@d<00<0
4Ph=0P0A3@`00`0>2PT04Ph=014=300200d920803`/:00H040`;00h:2@0>2PT04Ph=01@@3`0A3@`2
00h:2@0?010<2`0>2PT03@T8014=2P050@00510=014=2P0E4@h04@d:00/7100<20D02`L401<?300`
;2T08AdK00D03PX900d04Ph=00<0000L61L01`<200d9200E4A001`<300`81`0@30/04Ph=01lK6P0B
3Pd03`/:00803PX900l03@T800h:2@0>2PT03PX:00h:2`0@30d04Ph?010<3@0>2P/02`L800`82@0:
1PL01`<400h:2`0?2``01@0=2@X400h:2`0600d92P0<20T030P900T31@0<1PP03PP:0P0=1`T01`0>
20X030H800d72@0?2@/040X<00l92`0>20X00P0;1@L0100=1`T03PP:00l92`0@2P`2014;3@0:00d7
2@090`D0100000H00P0>20`03`T=010:3P0=1`/02P@800T31`H03PP<00`04@H:00l4200?10P040D9
01462P0?10P05``@00d21P0D2@d05@X>00`11@0>0`LDooooo`006oooool00`0D5AL0414C00l@4P02
010A4`803a0B02X0414C00l@4P0=3Q003@h@00l@4P0D5AT03@hB00`=4P0=3Q802``A00d>4`0E5QX0
30dA01HG6`0<3A805QLL00H72`0=3Pl05QPG00/=300A4a803Q0?00d?3P0N81l04A<B00H81`0D5QD0
2`d<018D4`0?4@h071hK00d?300O8Ah0>cdj00h@3@0:30T04aDB00P:1`0A4a003@l<00h@3@0=3@/2
014A3`0?00P81`0<3@X05AHA014B300?40X03Pl900l@200@4@T03@h8010B3@0;3@P04A<>018D3`09
2`H03a4<00804Q@?01P03a4<00`>2@0<3PT0414<00P91@0A4Pd0;RlZ00l@2`0@4@`03Pl:010A300?
40/04Q<>00l@2`0@4@`04Q@>00hA2P0=40T03Q4:00lB2`0=40T030l800d@2@0>4@X300lB2`0300lB
2@0?4PL03Q4800803A0700`03A0900lA300?4@`03Q0=0453@P1@DU403@l=010A300?40X03Pl:010A
300A4Pd2014A3`0;00d=2`0>3Ph04Q8B00l?3`0>3Ph0418?00d?300?4@h02P`901HH5@0V:2D0100?
4@h01`0@4Pl04A<@018D4`0@4Q405QPG01@F5@0C5A@00P0=3`h03`0A4a803Q0?01@F5@0>40l04A<B
014C400B51403@l<00`>2`0A4a00418?00lA3P0@4Pl04A<@018D4@02014C40H03a4>00L05aTF03Dg
=0092`T04aDB014C400E5a@04Q@A00803Q0=00X0418@01HH5P0I6aP04Q@A01<E4P0?4@h0418?01<E
4P0A4a003Q0;0P0?4@`3010B3@06014C3P0?4@`051HA00lA300=3`X05ALB1`0A4`h0500B50l04A<>
00lA300?4@`04A<>03Tk=P0];b/05ALB02@V8P0H6QD020T600d?2P0?4@`0418=00`>2@0@4Pd08R@S
01hO8P0D5AP051HE0P0>40d0500>4@/03Q4:00lB2@0?4PL04aL:01@G2`0C5`T05AT;01@G300C5Ph0
4aD@01<E4P0G6AL09BLT01<E400G6Q804QD:01XN4`0l?c@071lF0P0D5`h0100B5@`04A@;014D2`0C
5Pd201@G3P0601PK4P0E60l05APA01DH4@0D5a004QD>0P0A50d04`0F6A803Q4:01LJ4`0@4``06QdF
01hQ6P0c=C0061XE014C3P0C5A004Q@?01HI4P0H6a805aXA01HI400C5P/051L<01HI3P0F6a@00P0D
6A802`0F6a@05a`E01HK500B5a0051TB01HK500L8AX082DN01TN5`0G71H05Q/E00<05a`F0P0F6aD0
4P0J7aT061dG01PM5`0J7aT05Q/E01LL5P17C4H041D?024V800I7aP06B0I01LQ6@0K9Ad09c4Y02hi
<@0X<b/05b8J01/T7`8072DP00d07BHQ01lX8`0O:2<0;CHa02H_:P0S;2L08BXU01lX8`0T;bT09S8^
028a;00P;bX08C0[00808S4/01X09C@_02Lf<@0V=C009C@_02Lf<@0Y>3<09cDe02`l>`0`@3l0;Cdl
02`n?P0cADD0=4I803Q<C@0eBDX0<DA802a1A00X?Ch0=DU903M;BP0dB4L0;D5002e1?`0`A480<DE3
0396A@80>4a;03@0L8B303mCD`18G6@0A5QR03Q<EP1hS9H0F6af051TKP12EV00@5AN04]OJ@13Ef40
A5QR045EG@15FUl0J7f204IKH012Ee`0Bf1U04EJG`1cR8d0LXN<04UNH`12Ee`0@5EJ04aQH`19Ged0
BV1N04UOG@1?IF<0DFMU04aRH01;HEl0BEmM04YPGP19Ged0EVaZ069hM@1EJfP0DFMT05=YIP1@IV<0
CfER051VH`1BJ6D0FW1]05]aKP1IKf`0F6i/05aaLP1KL7<0GG9e0P1QMWT02P1NLgH0Fg1c05icMP1V
Ngh0K86406UnP@1RMgT0H7Qh05mhM@1^Q84206QnN`0306^0N`1SN7<0IW]f0080IgYd00L0Jgih06ao
N@1YOGD0IgYc06IiL`1XNgH0K7mj0080KH1m00H0K7ml06n1P01bQH@0LXB306n1P01_PWl20723O`0O
06n2OP1^PGd0KH1l07:5P@1^PGd0Jgij06aoN`1]P7`0Jgih06UnM@1UNfl0HgU]05Y`H`1DJU`0HgY[
08NNSP1RNFT0CVED04iUD`1=I580DFQF04aSD`1AJ5P0CVEE04eSE@1=I5H0AemA04EODP16H5<0Af5D
04MSE`0204YVFP0f04UPEP16GE<0@EQ>04=JD011F4h0?EA:03A;@@0gCT@0=Te30317?@0W?S@09CT`
02`g<00]=c<09c0b028[<P0^>4<0>T=A045=FP19Ef80=4=:0311@`0Y?3X0;3li028b:00S<bX09SH]
02Hc:`0[=S408bhY02@_:`0Q:RT08B/Z028Z:`0M9BH0624P01dW8@0G8AX05R0I01`V7`0H8Q/06B<L
020Y8`0T;RL07bTR01hX8@0P:R<07RTR01/X8@0L:B806RHP02<^:00<5a4082XT0P0L9B001@0L8al0
6AlK01LM6@0E6aL05Q/G00805a`H00T05Q/G01TN6P0M8Qh07B8N01`Q7@0I7QX05a`H01HK5`0H7AX0
0`0I7ad04@0F71X051XH01DK6@0N92804QPF014G5@0J81h051XG018E3@0N8AP05Q/D01HM5P0=50d0
?dE206]aKP0M8al04A<>00805QD@00@05aH>01DE3@0E5Ph05aP@0P0D5@d0600F5`l07b0H06i_I`1d
MFd04a@<010A2@0B50`06A/F01HK5`0D5Q<03a4>01HH5@0@40h02`/9018A3`0Q81h0CDa:01HC4P0>
2PT061LE01@C4@0@3`d05aHD02d/:P804A0>0P0@3`d05P0C4Q005A@B01@C4@0=2``0=38c02PV9`0@
3Pl03`d>01<A4P0>30d04@l@00H41@0E4a@04Q0A01hL7@1GEU@0Hf9P04m>C00B4@l05aHD00/:2@0>
3@/2014@3P0400l>300>3@/03Pd;018>3@804@d<0`0@30/01`0=2@P040`;014=300B3Pd040`;00l;
2P0;1`H00P0B3Pd0100D40l04`l>00l;2P0A3@`200h:2@0?010<2`0>2PT03@T8014=2P0c;b`0A40m
010<2@0A3P`03PX7010<2@0=2@H02`L400`81@0L61D0510>00D03PX900d03`/:014=30050P40510?
00d9200D40l02`P7014=300:1PH03`/:018>3@0<20L03`/:00803PX901003@T800h:2@0>2PT03PX:
00h:2`0B3Pl0510A018>3`0>2P/02`L801DA4P0K5aP04@d>010<3@0?2``030P90`0=2@X03@0>2P/0
3`/<00l;300?2``03PX;00d92P0<20T02`L800`6200=1`T03PP:00d72@0>20X00P0A2`d01@0@2P`0
3`T;00d72@0>20X03`T;00803@L90P0>20X200l92`0703D_<@0X8R@030L8014;3@0<1PP04@/=00h9
300200/52@03010:3P0A2`l03@L;00H03@L;00D06@hB01D:3P0B1`/04PL;01462P0200l4200500d2
1P0A1PX04@H:00h31`0@1@T05?ooool001_ooooo01<04Q<E00h?4@0<3@l03@h@00h?4@0=3Q0030d?
018C5@0=3Q002``>014B500?41@03@hB00`=4P0D5AT05aPM014B5`0?41@03a0E00803a0D02h051DI
04I7C00J6al03Pl@01HH5`031@@03a4@00`>3@0830/03Q8A018F5@0;3`h03a8A03e1@00L81l0414?
00H6100B4Q004A8?01/K6@010`003Q0=00P:1`0N81d0ATQ501@F4`0620D0410>00d=2`092@L03@d;
00/<1`041@003a0:00`=1`0;30H030d600h?2@0>40X03@l:03do>P0J71L0004001lQ700:30L0418=
0P0A4`h04`0?4@`04A<>01DG4P0720<01@H1010A300?40/01@H101DF4@0;30L02@X500h?2P0;30L0
3Pl:014C3@0<3`P02`h700d@2@0>4@X00P0=40T300`?200P00d@2@0>4@X03Q4900`?1P0;3PD02`h7
00`?200=40T030h900X<1`0?4@h05aTF00840@0B51803a0;00d>2@0<3@P03Pl:00l@2`0?3`d051@B
00h>300@41005QHF018B4P0@41005ALD014C400B51402P`9014C400E5a@200d?300H00h@3@0?4@h0
418?01<E4P0<3Pd02`d<024S8P0L7Qd03Q0?00d?3P0D5QD0418A00L9200>40l03a4@01/M700J71T0
6A/H014C400>40d04A<@00h@3@0=3``03Q0=100@4Pl600lA3P0?01DG500:30T04aDB00`>2`0C5A80
DeEB04Y<B@0A4a002@/800H81@0A4a003a4>010B3`0>40d030h;00804A<@00L02`d:010B3@0>40/0
3@l:00h@2`0A4`h04Q@?008030h900@04Q@?00lA300J71L0;2hY0P0A4`h2018D3`05014C3P0@4Pd0
3a4<014C3P0@4Pd00P0<3PT0:00?4@`030h901PJ5@0=3`X07R0K0043000E5a804aD@00h@2`0E5a80
3@l:01HH4`28RXP0QXN902DV:00<3Ph07R0M02<U8P0O8A`04QD>014D2`0E60h041<800hB100A5@L0
41@600lB1`0B5@d061XE01dO6P0I6aP02P`7010B3@0B5@d05aX?00X>000[<2D04QL@00X@1P0B5@`2
01@G3P0901DH3`0G7A<05Q`B01hT6P0e?C808RTQ01@G400C5Pl04QD>00804A@=00<04QD>00lB2`0I
71D00P0B5@h0>`0J7AH03Q4:00d?2P0?4@`061XE01<E400J71L061/D01TL5@0D5`h04A@<01HI400G
6Q404A@;018G400@5@h04AH?01LL5@0J7aP06b0I014F3`0C61405Q/D01`Q6P0O91d04aPA01DJ4`0E
6Q@05AXC01HK5@0C61803a@=01<H4P0L8AX06QlH01HK5@0F6a@04aPB01`Q6`0E6a@072<L01dR700J
8AX07bHO01hX800P:R808bdU02Ha:@0S;RH05b8J01dV8@0J8ah072DP020Y900S;2L082TT02D^:@0Q
:RD082TT00807bPS00T09C0Z024]:@0R<B`07bhY01h]:00Q<2/0830]028a;P0Y>CH00P0Z>SL02@0/
?3T0;Cdj02`l>`0/?3/0<TE302Xk>P0V>3P0<dE502`n@00203=7B00M0396A`0_A4L0;4520314@P0Z
?S`0<4A203iBD00kCdd0=4Q60355@`10E580;D8m03A9A@0lD4h0?E=A041DG01>HVd0Cf=/05M[M@15
FF@0E6Qb03mCG01=HF`0D6A^03]?F01?Hfh0Ae]S04AIGP0`ADX00P18GF803011EU/0@UML05Y_LP1>
HfH0A5UL04YOHP10EEP0Bf1R045FE`17G5d0CF9S04UNG`80CV=T00/0CF9S055VI`1EJV/0BEiO04iS
I01KLFl0DVQV04iTHP1BJ6H0D6IS04mUH`0305=YIP0X059XI@1CJFH0FFm]082EV01eRXl0HGIj05Q]
L01JKg80GgAg06MlO`1VNgh0HWMi05aaM01LLG80H7Ef05mgM`1[Q840PYRE06^1O`1PMW<0I7Qf06Um
N`1]PGl0KH9m06aoN`1]PWd0JWii06j1O@1YOWT0IWYe06YmN@1]PWd0L8>107>6Q01aQH<0LXJ407F8
QP1bQH@0KX5o0723O`80L8=m00@0L8=o06n2OP1]P7`0LHB00`1`Pgl05P1/Og/0IgYd06=hL@1RMfh0
Igea05Y^HP1MLV80TJJE0?;omP2:Whh0AEY904eTE01AJ5P0A5Y=04YPD`1?IEP0BV1C04UODP1>IEP0
B61C04UQE019HEH204QRE`80BF=H01l0C6=K04IME@10Edd0@5M=03aCB@0fCD<0?5=903M>A00`B3/0
:T4f02To<`0Y?C80:C@_030i>00]=cT09c4i03@nBP0oBeT0IgB104mMIP0Y>3l0:SXk02Hf<`0V=c40
8c<Z02<c:@0V=R`0:CH^034l=P0X<bd07bXU008092l[02407BLV01TR8@0H8Ah051dG024[8`0O:B40
51hF01XT700M9al092hV02H`:00O:B408B/S02<]9@0L9b006bHP020[9@0Q;2H05B0J02lh<`0L9B00
624L01XS7P0L91l0728N01/Q7@0Q9b<07B8N01LL600J7a/05Q/G01DJ5P0H7AT00P0G71P0DP0I7QX0
6QlK01`Q7@0K81d061hL01TO7`0I7ah061hL01LM700K8B404aTG01`R8@0K8B4061hL01TN700L7aP0
5AP?00`@2@0V:bD03a@>024V8P11AT802Pl;01HG4P0A4P`05A@?01TI4@0D50`05AH>01PI4P0E5Q00
5AH>01TJ4`0B4`d07AhF02d^9`0H6A<04Q<;00h?2@26R8<0=CLd014C400C4a40A4A203Ph=P0M7A/0
4Q4?07QgM@3Ddm40928P01/G5P0@3`d05QDC00/:20081`D02`X901`K6@0?3P`04Q4?01<B400A40h0
40l=014@3P0B414040h?01PF5`02004040h?01DC500I5aP020H701lM7P091`P040h?00l=3P0S8R00
Lg9`05UHEP0@3`d02`X801PG5@0@3`d2018A3`0400l>300>3@/03`h<018>3@8040`;0`0?2`X03@0@
30/03`/:014=300D40l03`/:00/71P0D40l03PX900H20@0:1PD03PX900X61@0A3@`00P0>2PT02`0@
30/03PX900d9200C3``04@d:02HR7`0:1P@04@d:00H2000:1P<040`90080510=00<04`l<00X61@0>
2PT0100>2PT03@0;1`H04`l>00P40`0810<02@D400h:2@0@30/06ADD00L30P0?2`X02@D400D1000C
3`h00P0>2PT0100=2@P03PX900h:2@0>2PX200h:2`0800l;300>2P/03PX;00/7200S7b00=30a024M
7P0>2P/200d92P<03PX;00P03P`=00l=3P0=2``03@/<00d:2`0=2@X030P900/720<03PP:00P030H8
00h82P0D3Q005@lA01<=3`0>20X02`D700`620<03`T;100>20X0300600804`d?014;3@0>20X01000
01D?4@1:A4P0=2hb010:3P0500<03PP<018<40H030H:00@04PL;00l4200=0PH03P<70P0?10P01P0>
0`L04`P<01462P0?10P040D900l421Cooooo000Kooooo`0800hB5@0:3Q403A4D00lC5P0<3a803@hB
00`=4@0@41@2018A5P0?01<B5`0D4aP03PdB01@C5`0o?d40BDQ=02<S9P0?3a403@`A014@50051@L0
6a/N07elP@0I6A/03`l?00803Q0?0P0<40l200/A3`0L00PA3P0=5Q<06b@Q0>kim@25RhT04Q0>014@
3P0@3`d03`l=00l>300>3P`03Q0=00D7100A4a00;C8^01/P70021`<03a0;018C3P0>3`X04Q<>01<D
3`0:2`H03Pl:010A300<3@P030d700d>2@802P/601H061TD00H70P0@4@`03Pl:01HG4P0=3PT04Q<>
00X;1P0A4Pd03Pl:01XK5P0=3PT01`P3010A300>3`X03@h9014B3@0>3`X02``700`=200?40/0414<
0P0?40/0:00@4@`04A8=014B3@0A4Pd0414<01hO6P0=3PT030d9010A30031000414<018C3@0?40X0
30d8018C3P0A4Pd0414<00/<1`0:2`H04a@?01DF4@0@4@d03@d;00l?3@0B4Q004a<A014A3`0>3P`0
30`:00h>300<30X03@d;014A3`0>3P`03a4>00d?300B51405aTF018D4@0<3P/300d?30802`d:00l0
3Q0=01<E500;3@`04aDD01HH5`0<3Pd06A/J03Xl>`072@P07b4P00L9200J71/07AlN00lA400>40l0
0P0=3`h06P0>40l03a4@01@F5@0C5A@0418A00lA400>40l03@l>01@F4`0<3P/01`T6018D4@0@4Pl0
1`T6014C400:30T04Q@A00`>2`0G6AH0C4i;04M7A@0G5aD02`/901<C4@0@40h051@B100C4a405P0A
4@l0410>018D4@0@4Pl04A<@01<E4P0A4a003a4>010B3`031@8051HC01DG500;3@X05aTF01DG500F
61D03a4>00/=2P0A4a0051HC018D4@0A4a02010B3`0A00h@3@0>40/04A@>010C300?4P/03Q4:00d@
2@0<3`P041<<00d@2@0C5Pl04QD>014D3@0l?SX0=cTf01HH5@0?4@h00P0C5A008@0>40/04A<>010C
300=40T030l800hA2P0@4`T04A@901<F2`0@4`T03A0700hA200B5@`04A@;010C2P0?4PP03a87010C
200=4`X01`h701DL500B5`l02a4701LM4@0=4`L05QhA01HP5@0a?380_L[007R6O@0K81T04A@=01<F
3`02010C30<04aH?00d05APA01@G400C5Pl04A@=00lA300C5A0051HA01HH4`0K7AP04aD@01TK5P0G
6Q<051H@00<041<<00T061dG01XO6@0A5Q0082DO01HK5@0l@C/061dG01LL5P0F6aD00P0H7AL06`0G
71D05aXC01TL500I71<05aXC01LJ4P0H6a8061/D01XM5@0H6a8061/D01`O5`0K81T07bHO01/S7027
THT0HfYS014K4`0Q:b<08bdU03<m=@2f`;P0@de502/e;@0B71@082/S01dX800202<^9P0?01dX800O
:R806bHN01lZ8P0M:2006bHN024/900]>38082`X02Hf<`0G9b@08S8_02@d<@0U>3H08c@c00809STg
04@09SPh02Pl>`0[?ch0:3Xj02Hh>00Y?C`0=dY902Xn?@0W>cX0<TI503A8A`0/@3l0=TY903Y>C`0/
@3l0<dI203A7@`0R=C40@eIC03U=B`0U>CL0;T900316@`0dBTL0<DM403I<BP11EUL0>DiD03eAFP10
E5/0@eMO04EIHP15FF40?51G04IJH`15FF40?U9I04AHH@0nDUT0BEeT04IJH@18G680DfQ]04aQI019
GV40Bf1Q04MLG@11EUH0AeeK04QNG016Fed0DVMZ04=HF`19GV40DfQ[04QMH01<HF@0CV=V059WJP1F
Jfh0Jh2304QMH01dR8`0K821059VI`1@I6D0E6QW05Q/K@80EFUX00h0E6QV05EYI`19GE/0F6a[0<CI
gP2P];/0HGIl05aaMP1PMGX0GgAg05Y_L01LLG80H7Ie06=hN@80I7Yh0380IW]l06MlO@1YOgh0JGio
06UoO@1[PGl0LXR606j4PP1YOgd0JWim06Z0OP1]PX00JGek06QnN`1ZOgd0KH5o06j4P@1`QX40L8F0
0727P@1bR880LXN20726P@1_Q7d0JGed07>4N`1eQWh0P96;08FETP1/O7/0M8B307>3P@1aPGh0Kh1j
06ioN@1[OWP0J7eh069fL@1PM6/0G6iR05QZF@1SM640UJJC07J8M@1@HU80CF5E04YOE@1=HUT0D6EL
04mTF`80CV=J0P1?I5/0<01<HEP0Bf5I04aSF`1>IEd0C6=K04QOE`18H5X0?eQB041JD@15G5@0?EA:
03M>A00fC400>U1403I<?`0aAc/0:clc02Hg;@0W<S0082X/02D`=00/>D<0:3I304EBHP15DV40:SQ1
02/j?`0]>c`07RXV02Db:`0V<Rl0;CTe02@`;00]>S@0=d@m02dj<`0S<2P07b`S020]900L:1l06bHN
020[8`0c?CD05R0H020Z8P0G8AT05R0H01dW7`8072HN00@07bTQ02D_9`0Q:b<07RLQ0P0R:bP0400O
:2D06b@Q01lU8`0P9R@092XX01@J600L8R005Q`J01LM6`0N92406QlK01dR7P0J7a/07B8N01DJ5P0M
8Qh201TN6P0K01XO6`0M8Qh08bPT02P/;0093@h07R8U01@H6P0F6Q/05QXL01LK7P0H71d0>Si008:6
R@0;3a004aLH01DG4P082@<05aPC014C3P0L7QT09bTT020R7@0F61<051D@01TJ5@0F5a805AD@0080
4a8=01H051<>01@C3`0E50l05A@@00l>2P0I61<051<>010?2`0L6aH03@`901TI5`0D51803Ph<010?
3@0B4@l051<A01LF500@3`d081lM03<b<00D4a4061LE0P0D4a42018A3`0A014@3P0@3`d030/900h=
2`0J6AL03Pd;01<B400F5A<02@D401<?3P0H51<04@d<01TE500D40l040`;01HB4@0B3Pd00P0A3@`0
1@091@@04`l>01PD4`0I5A@0510?00<04@d<0P0B3Pd0100@30/03@T800`81`0>2PT201<?3P03014=
300810<04`l>00<03@T80`0?2`X04P0@30T01P80014=2P0?2`P03@T6014=2P0B3P/03PX700l;200>
2PL0510=00d91P0>2PT02@D4010<2`0;1`H06QHE00L30P<02`L601D030P700H20@0:1`H03@T801LC
4P0:1PD03`/:020L6`0:1PD03@T800/71P0:1PD02`L600d9200?2`X040`;00l;2P0>2PT03@T800`8
1`0=2@P00P0>2PT0100=2@P03PX900h:2@0;1PH200h8200E00l92@0]9bL05@l?00h8200C3@d0618B
01H@400?2@T03PP8014;30050@805A8C00d;300;2`/05aLG02l_;`0000004Q4A0040000I5AH03@P:
00803@L70P0>20P200l92@06010:2P0P6QX01@0001@>3P090`<030H61P0=1`T600h82P030:ZTZ01Q
Fel040X>00802`D900<03`T=00/52@0<1PX00`0>20`00`0=1`/04@H<00h32@0201P=4`0800l42P0E
2Q004`P>01D:400<0@L02`0600X11@0G318Dooooo`006oooool02P0;41<02@hA00lC5P0B5QT03a8E
010A5@0?41@0410D010?500>3A8200d<4@0>014A4`0;2`d05QHH01XJ700@41803@d?018B500=3@l0
6ATK010@4P0e=CL030`>00l?3`0?40l200h@3`0900d@3`0<4@l02a8?018J5`053``02A<@049<B@0S
:BL04Pl>00804Ph=00`040l=00l>300>3P`03`l=00T;20082PL04AHB00`B3P0A5Q803a0;00d>2@0>
3`X2014B3@0E010A300=3PT03Pl:00l@2`0:2`H030d800l@2`0E5Q401PL301@E400>3``04Q<>00l@
2`0=3PT051D@00h?2P0D5A002``7010A300?40/03Pl:0080414<00X03@h900/<1`0=3PT0414<014B
3@0B4`h051D@018C3P0?40/0414<0P0A4Pd05@0@4@`03@h901<D3`0?40/03a0<00`=200e=S40DE9=
00T:1@0M7QT0>CXe01<D3`0=3PT030d801@E400A4Pd02``700l@2`0>3`X03`l=010@3P03014A3`09
010@3P0>3P`0410>00h>300?3`d051@B014A3`0<3P/02`d:00803a4>00@030h;00h@3@0A4a00418?
0`0>40d03`0;3@X03@l>00d?3P0>40l04Q@C01DG5P0?4A00EEMF018D4`0?4A003Q0?01@F5@0;3@`0
3a4@010B4@02014C4P0;010B4@0?4A004Q@C00lA400<3Pd03@l>018D4`0E5aH02P`901PJ5`0720H0
0P0>40d03@0C5A8051HC010B3`0C5A803a4>00P:1`0B5140410>00d=2`0A4@l04a<A018B400E5A<0
0P0B4Q00600C4a404Q8@010@3P0?3`d04A<@00lA3P0@4Pl04Q@A010B3`0>40d04A<@01LI5P0?4@h0
418?01PJ5`0C5A80418?01/M6P0I6aP04aDB00h@3@0:30T04Q@A014C4080418?00H03Q0=00h@2`0A
4`d041<<00lB2`0>4@X200d@2@0;01<F3`0?4P/04A@=010C300C5Pl05QPB01<E400H6QD03Q0;014C
3P0G6A@00`0B50l0100C5A0051HA01<E400C5Ph301@G30@04aH;01H04QD:010C200?4PL03a8700hC
300E7AH06b4J014F3P0@5@/051T=00dC1`0D70l05b4F041=@P32dLL0Kgif01PO600L7aP04aH?01LJ
4`0M81T051L@100F6A80100E614051L@01DG4P0F61<201<E400501PJ5@0E5a806A/F01PJ5@0F61<0
0P0E5a80200G6A@03a@>01XO6@0H7AL05Q/E00`A2`0M8Q`05AXD0P0D6A<0100F6aD05a`F01HK500K
7QL201dP5`1901`O5P0M81L07b8I01dP5`0I71<061/B01/N5@0M81L06R0F01PO600K9Ad0@Ta402/e
;@0J91`0628J01TS6`0nB400/K^c05IPF00O:B407BLO01dX8@0L9b008RdV02<^9`0Q;2D092lX01lZ
8`0R;BH08bhW028]9P0S;RL0934Z02Pd<00S<c00830]03];B00^@Cl07S4_02Li>@0Y?C`0:3`k02Lk
?00W?3d0:Cho02/o?P0/@3l0<4A302Tm?00fBTT0FVi]03M;BP0[?ch0<4A303=7AP0^@T40;d=10395
@@0jCDP0=4M202i1?@0[?cd0@5AB03A8AP0`AT@0>4i<03eCD@0gCdh0=Ti?045EF`13Eeh0@UIM04=G
GP0204EIH00Q04MKHP1:GVD0AUYQ04EIH012EUd0@5AK04=GGP18GF<0FFic04MLH@0oE5L0C65S04UN
G`16G5X0@eUG04UOG01:H5d0AeaM04YOI018GF80CfAY05AYKP1>HfP0CfAY04aQIP1DJFh0H7Ej07>8
S@1HKG80FFea04ePI01?HVH0Ffia0080FFe^00@0EFUY05Q/J`1EJFL0GG5_0P1GJfT03`1UNGl0I7R0
05iaN01WNh00HgMm069fN@1UNGX0IWYk06QmN`1ZOgd0Jh1o06f2P01WO7d0JGio06^0P@0206YoP00:
06f2P`1[P840KX>40766Q`1_Ph@0KH6206^0P@1[P7l0K86006n4PP80LHJ30240L8J00726P@1aQh80
LhV10767P01^Q7`0JWmf06b0M@1_P7D0KGif07J7P@1lSHT0Jg]j0761P01bPX00LX9o0721N`1]OWL0
J7]e06QkN01QM700GW9X05e]H@1EIE<0EVE@05ASCP1IJEH0E6IF05QZG@1<HEP0C65K04mTG@1>He`0
0P1=HU/01@1@IEh0DVMP04iSG01<HEX0Bf1I0080C65J01T0B5mG04ALEP14GEL0@5UC03aCB`0kDTP0
?EA:03mEB@0hCD40;d@h02a0=00X?Bl09CH/02@_;`0O:Rh08Bhd02@b>`0U=D80@51N0392C`0W=Ch0
:3Ll02/g=`0P:bH0:C@^00809c<a01/08bl]02@`;00T<BX08BhW02@a:00O;2<07R/R01PU6`0H9QX0
7R/Q02@^9`0G81X07BHP01`U7`0M9b0082TS01hW8@0L9Al05b0J01/T7P0L9Ql07bHS02<Y9`0R:2H0
7bDS01`R800M8b400P0K8Al02P0<4Q006R0N018H5P0I7ad07R<P01@I5@0O92006AhJ01LL600?5102
01TN6P0:01PM6@0G71P05a`H01TN6P0Z;Rh0720R02P/;P0G6ad04aLI01HJ70806QhP00D07R8T01PL
7P0@51H06alP01`L6P0201@E400701HG4P0G61<071dH01DF4@0C50l05QLB01TJ5@0201DF4@804a8>
0P0D4`l201DD400D01HE4@0I61@03Pd900d<200G5Q804a8>01<B400H5aD06aXH01HE4`0C4Q005QDC
00d<2P0K6QP0H5mM05eLFP0F5A<03Pd;010?3@0A40h2018A3`8051<A00L04a8@00l>300C4Q00R8N5
01PG5@0D4a405a<B00804Ph=00<04`l>00d9200E4A000P0E4A001P0?2`X040`;01@@3`0>2PT040`;
018>3@804`l>00<04@d<00h:2@0@30/00P0A3@`02`0@30/03@T800`81`0B3Pd05a<B00/71P0A3@`0
3PX9018>3@0>2PT03`/:00<040`;00d03`/:010<2@0B3P/02`L500l;200C3``02`L5018>2`0V8Ql0
;BTV01/G500D40d030P500803`/:01402`L602hZ:@0T8B0040d<01/G5P0A3@`03PX9010<2`0:1PD0
5A4@00`81`0B3Pd030P700`9200E4A0030T800d9200300`81`0700d9200?2`X040`;010<2`0?2`X0
3PX900d9200300h:2@0900d9200>2PT03PX9018=3@080P805a4A010:2P0?2@T03@L700803PP80100
4P`<010:2P0<1PH03@L7014;300<1PP02PL801<C4`0=3@d0Oh600<_=c011@d803`l?00X82@0A3@h0
3`T;0P0=1`L200h820803`T900H06A<C03Xd=00G4A403`T900h8200<1PH600d72@H03PP:01P05a8E
00h9300>20`03`T=00/52@0B310040X>00l93@0<1PX03@L;010:3P0B310091TO01873@0A1P`04`P>
00h32@0A1P`040D;00h42@0?10X040L;01@:3`0C20hDooooo`006oooool01@0;41<02`lB014E600D
61/0418F00803a0D00/03`lC00l>4`0A41D04Q4F014@5@0@41804a<E010@4P0>3Q00410B00h>4002
00d=3`0401XJ700=3@l01@D700`<3P<03`l?00d03a0?00h@3`0>40l02Pd<00lC4P083P`03aLD0088
1P0A5A@04@l=018>3@0A3@`03`h<00803@d;02403Ph<01`N6`092`P00@@103<h=01jOg/06a`G010A
300C50l03a0;00/<1`0A4Pd03Pl:00/<1`0H6A@05AHA00d>2@0E5Q404A8=01/L5`0I6QD00040014B
3@0D5A002``701<D3`0=3PT05AHA00/<1`0:2`H0414<018C3P0<3@P00P0?40/02@0=3PT04a@?01<D
3`0@4@`061TD02LX8`0P8A`03Pl:00l@2`04010A300F00X;1P092PD061TD00D60@0D5A00<c@_0042
000=3PT0:BXU00D60@082@@03Pl:014B3@0:2`H061TD02d^:@0M7QT04A4?010@3P0?3`d03Ph<00l?
3@804A4?01404Q8@00l?3@0>3P`04A4?00d=2`0@4Pl030h;00lA3P0E5a@04aDB018D4@0<3P/03Q0=
00lA3P0;3@X030h;01@F4`0200h@3`802P`;0P0@4Q4020010`803@l>01LI600B51<01PP701TK6P0=
3`h0418A0P0B51<06P0@4Q403@l>010B4@0>40l03@l>00h@3`0B51<05ALF01@F4`082PL00P@1020R
7`092`P05QPE00h@3@0=3``02`d:010B3`0G6AH04aDB00h>300J6QP04a<A00`<2P0A4@l051@B0P0@
40h2014A3`803`l=01803a4>00h@3@0?4@h04A<@00lA3P0=3``04Q@A0002000I6aP03@l<00`>2`0=
3``051HC01DG500?4@h03@l<010B3`0?4@h2014C4080418?00<03a4>00lA300B50h00P0A50d02@0@
4``03a8;00lB2`0D5a002Pd600hA2P0D5a006A`E01`N6002018D3`0B00d?2P0C5A0061XE01@F4@0C
5A003Q0;014C3P0E5a804Q@?00lB2P0=40D02`h300d@1@0?4PL03A0500hA1P0B5@X04A@90P0@4`P0
4`0A50T04aL@00L>1`000`003A4901LJ4@0?4PL04QD:014G2`0A6@h03AP>01/X7P0N:R803Q<=01PK
500@4``06A`E01XM5P0B5@h00P0F6A8301DH4@0701HI4P0G6A@05aTD01DG4P0D5Q405ALB01@F4@02
01HH4`0B01DG4P0G6A@06A/F01`N6@0C61807B8L01hS7@0E6Q@041D?01DJ500F6aD05AXD01HK5@0H
7AL06QlI01TN600G6Q<06QdD0P0K7QD05P0L7aH07b8I01dP5`0I71<07B0G024T6`0N8AP061dF024X
8@0D7QH072HN01PR6P0G8AT06bDM020Z8P0C7AD072HN01DO5`0U;bL082XR01hY8`0M:28201lZ9080
7RTS0P0Q;2H0200S;RP09C0Z02@_:@0P;BH07bh[02Dd<@0N;R/0:CTf0P0bAD<02@0V>3P09SXi02Hj
>@0V>S/09CXk02Hk?00/@3l0:3`k02e1@00202i2@@0D04=GEP0cAdH0;T910396A@0V>ST09c/j03I:
B00^@Ch09STe02Dh=00dAd<0RIfK0=CXiP11EE<0<TQ603=9A`0nE580@5QH03iFF010E5X204AHG`0M
049FG@13Eeh0AEUP051TJ`17Ff80@5AK04QLH`0oDeX0?U9I03Q<D`0nDeP0HGIk059WK00nDeH0AEYL
04EJF`13FEL0AE]I04YPGP1;HEh0Bf1Q04IKH01;H6D0BUmT04MLH@1?I6T0DFI[05=XK@1LLGH00P1?
I6T03`1HKG80FVib05EXK01OLWH0H7Af05IZJ`1KKg00F6a/05a`K`1HK6X0Gg=a061dLP1IKF/0FVec
06EhO`0206YmP`0;05mbN01QM7P0J7am06QlO@1WNgX0JGel06]oOP1^PX40JGel06]oP01]PH800P1/
P8401`1_Ph@0L8B50765QP1_Ph@0K82107:6Q`24V9T00P1cQhH307:6Q00<07:7PP1cR8<0LhR307:7
P01`QGh0KhAm06j3NP1eQW`0Kh1g06]lM01_P7X0MHF30P1`P7l04`1cPh40M8B107:3O@1]OWH0IWYa
06MjM01NLVX0F6aP05UZFP1CHe00CEa705]ZE@1NKUX0DfIC05EWF@1=HUL0DVMP05=XH@1@IEh00P1=
HU/0101?I5d0DVMP04mTG@1;H5T204QMEP0e04UNE`18GEH0@EUC04=LEP10FE<0?EA<041GC@15G580
@5I:03Q<@@0aACX0;T8f02Lk;`0P<BL09C0_01hY;@0P;C<08S0h02Pi@`0hB5D0?TiJ03M5CP0]?440
9c8b01`W8`0S;RP0930]028^;00W<c40930/020]9P0U<R/0934X01l/8`0N:b806RLM01`Y7`0R;bH0
9RlZ02L`;@0R:bL08b`W02@]:P0T;BT09c0[02H_;00M9R807RLR028[:00R:RL082HT01lU8`0L8R00
0P0I7ad03@0O9B<0<CLe01/Q7`0G7A/07R@R028X9P0G71T05AXF02<X900I7QX05a`H010E4@0I7QX0
0P0L8Ad06@0H7AT05a`H01LL600M8B004QHG01/O800G6a`08RHW03Tm?P0B5QL05QXK01TM7P0J7Ql0
51PI01DI6@0E5A<071dH014B3@0J6aH04a@?01HG4P0C50l061TD020Q700M7QT00P0G61<601@C3`0B
014@300D4`l061LC00l>2P0C4Ph04A0<00d<2P0C4Q0061LE01@C4@0A40h04Q4?010?3@0F5A<0Ogil
06i]J`0D4a403Pd;0P0D4a42018A3`0G014@3P0@3`d03Pd;018A3`0D4a409B@R014@3P0M71X04`l>
01@@3`0?2`X05A4@00d9200G4a8040`;014=300C3`h05a<B01<?3P0:1PD03`/:00d9200?2`X00P0B
3Pd01@0=2@P04`l>01<?3P0C3`h04Ph=00804@d<00P03`/:01LC4P0A3@`03`/:00X61@0K5aH03`/:
014=30804Ph=00T040`;00h:2@0A3@X02PH301@@3@0B3P/01P80010<2@091@800P0E4@h05@060P00
2PH300X60`0=2PT04Ph=010<2`0Q7A`081`K00d9200F4Q403PX900X61@0=2@P03`/:01<?3P0N6QT0
?c/j01<?3P0<20L05a<B00`81`0200d9200400`81`0=2@P03@T800h:2@803@T800@030P700/71P0;
1`H03@T80P0>2PT01P0=2@P03PX900h:2@0A30/01P0001@>3P8030H600@0208200d71`0?2@T040X:
0P0?2@T03@0C3@d03PP9010:30091PH03@/<00/;2`11@d80Kg5`01lQ800920T030P901@@4@0>20X0
1P0>20P01P090`<050h>00/51@0B30`01@0001<=3@H03@L91P0>20X0200G4AD05Q0D00l93@0=1`/0
3`T=00X4200=1`/030H:0P0:10P03P0=1`/03`T=01hC6@0B1`d04@H<01<83P0A1P`04`P>00l42P0=
0PP060dC01X?5@0R5ad04`P>5?ooool001_ooooo01P03a@G00dA500A5AP04QHI00h@500=3Q803PlC
00`<400;2Pl03@`A00l>4`0=314020P:018B500@41803Ph@014A4`0<30h03@d?01DE5`0<30h0410B
00X:300@4183010>3`0:010?3`0?3`l03Q0?00h@3`0;3@`03A4@00X?3P0@51<03@l>014?3@<03`h<
0P0=3@/0700:2PP05ALD00X<2@0J71T0N7ei0=?He00K71L0414<018C3P0>3`X030d8018C3P0;30L0
51D@02d^:@0/;BP03Pl:00L80`010P002P/600H7100j>cH04Q<>00L8100:2`H04a@?00T:1@0C50l2
00`=2004010A300A4Pd02P/600l@2`80414<00P051D@01<D3`0?40/05AHA028S7P0M7QT03Pl:00l@
2`80414<01/03a0;01@E400=3PT01PL201DF4@0D5A004Q<>01dN6@0?40/03Pl:01@E400>3`X04Q<>
010A300B4`h020T4014B3@0T9B004A8=014A3`0@40h03Ph<00d=2`0>3P`04A4?010@3P0B4Q000P0@
40h0700D51804A4?018D4@0;3@X03a4>01/M6P0J71T0418?00d?300C5A805ALD00d?300@4Pl09BLT
01DG5P0D5QD07b4P01hP7`0@4Q4061XI01`N7@0C5A@020X900lA40082PT04Q@C00`>3@0>40l2014C
4P0400h@3`0<3Pd03a4@010B4@<04A<B01D03a4@00h@3@0=3``06adJ01PJ5`0A4a003a4>00d?300?
4@h020X700T;200@4Pl03Q0=00T91`0D51802`/900T91`0C4a404A4?00l?3@0@40h00P0A4@l0200@
40h03`l=00lA3P0>40d03a4>014C400?4@h03@l<0P0@4Pl0200?4@h03Q0=01@F4`0=3``05ALD014C
400:30T02`d:0`0A4a03010B3`0300lA3P0?4@`04aH@00<04QD>0P0A50d03@0R9Ah03A0900hA2P0A
50d03a8;00X<1P010`003a4<01HH4`082PD04Q@?01dO6P0F61<00P0?4@`02@0C5A004A<>018E3@0A
50/03Q48014D2`0C5Pd041<:00lB2@02010C2P0C014D2`0B5@`04aH=01XN600<4@/04A<>02h`:@0R
8a/05aT>01PJ3`0=40D04A@;01PP5`0@718051lH018G4@0C5Pl051L@01PK5002018E3P8051L@100E
614201DG4P0501PJ5@0G6A@051HA018D3`0E5a800P0D5Q402P0F61<061XE01/M600H7AL07R<M024V
800M8Q`05Q/E01<H4P0G71H201HK5@0501PM5`0I7QP061dG01DH4@0H6a@00P0I71D06`0J7AH07B0I
01/N5`0I71D08bHO02HY8P0O8Q/06AhG01lV7`0I8a/05b4I01dW7`0H8QX06R@L018L500S;BD08B/S
01lY8@0P:R806R@L02D`:P0S<2T07b`U01dZ8`0L:B806BHO020]9P0201h[900=024^9`0T<BX0934Z
01d/:@0W=c@07bl/020`;@0bAD<0>4]902@f=P0T>3L09CTh02Pl?@0202Pm?P1=02/o?P0Z?Sd09c/j
0314@`0X?3/09c/j02e1@00_@d80<dM60355A00[?ch0;40n02<f<`0gBTH0>di:02m2@017FeT0HgMe
03eAD00dBTP0<TQ603Y?D00oEeL0@5QJ03Y?E@13Eeh0AEUP04IJH@1:GVD0BemV059VK@16FV40@EEL
04YNI@12EUd0AEYP04MLH@0oE5T0AEYN04QMH019GV40CF9T04=HF@12EeP0AeaL04YPGP1;HEl0CF9T
049GG017G640FFic05]`M@1FJg00CV=X04mTJ@1BIf`0Fg1e05mdN@1PMGX0DFEY05Q[K`1[OX80Jgn1
05U]KP1GJf`0E6QX05mcLP1KKfd0GG5_05ibL01MLG00GW5e06AgO@1SMW`0IgZ0069eN@1XNgl00P1W
Ng`01`1VNWT0Ig]j06UmO01/P7l0JWim06b0O`1^PX400P1]PH00301`Q8<0Kh>206n3PP1^PX40L8B3
07fAT02FZZT0N8b;07J:R@1bQX@0LHF307:6Q080MX^600X0M8V40766O`1`QGh0M8V207N<P`1fQgd0
Kh1g06ioM`1`PG/0LH5o0P1cPh80101eQH<0MHF207>4OP1]OWH206IjL@0C05eaI`1DJEX0EVME05IV
DP1AH4T0E6=<05QXE01EJ5D0G6iP05=XG@1AIUd0EV]T05=XH@1?I5d0CV=L04mTG@1@IEh0CfAM04YO
F00304MLE@0d04EJD`0kDTX0>U5903]BBP0nEDd0@EI=041EC00lDDP0<dLl02/o=00Z?S<0:S``02Hf
;00T;bh072L[024^=00U<S/0:CY402hoB@0iBU<0<d9902Pg>P0Y=C@08bhZ02Pc;@0S;b/08BdY02Te
<@0V<Rh08BhW02Pe;P0N:b@06bPO01`Y800K:1l07R/Q02@a:00R:bP09c0_020Y9`0P:BH07bPW02</
:P0^=c@0;CHe028[:@0M9R<072DT01dU8P0N9280728P01/Q7`806AlM01005Q`J01LM6`0;4@l08RPV
020V900K8Al04aTF014F4P0M8Qh051TE01PM6@0A5Q8061dI01`Q7@0N8al06AhJ0P0J7a/04@0E6AP0
2`l@01<G600A5AH041@E01lS901LH640S92A02L[;00D61T061`M010D500A4@l07QlJ01DF4@0I6QD0
4a@?00805AHA00D07AhI02@U800L7AP05aPC01HG4P0601@C3`08018A3@0F5A40;RdY01XI5@0K6QH0
4a8>014@3P0@3`d2014@3P08018A3`0A40h04Q4?010?3@0E51802@P601LF500>3@/201@C4@804Q4?
00`04A0>010?3@0B4@l03`h<01dL6P01000061LE00H50`0;1`H0510?00l;2P0A3@`201<?3P09014=
300?2`X04Ph=01@@3`0A3@`03@T8010<2`0>2PT03`/:00804`l>00<03`/:01<?3P0C3`h0100B3Pd0
5P091@@061@C00@0000E4A004Ph=00/71P0@30/04@d<018>3@0A3@`03`/:00h:2@0B3P/05A4>01/G
500=2@H00`0001<?300E4@h040`900h:1`091@<201PD4@04014=3@0E4A008QhM06]WIP800`0000`0
2`L600d9200<20L04@d<01/G5P0R7Qd00`0001LC4P0:1PD0100000/71P0A3@`200d9200300h:2@0=
2@P03@T800@03PX90P0=2@P300h:2@0:00d9200>2PT03PX900d81`0=1`L03`T900`61P0S7Ad03`T9
00d71`<040X:00h04P`<01D?3`0C3@h030H8014=3P091`P030`<00L9200H6QT010H5010?3`0<20T0
4@d>00X41PH03PP800H03`T9014;2`0:1@D050h>00L10@0?2@T600d72@H03PP:00@01@0300l93@0B
31002P@80P0=1`/00`0:10P02`D900`62P0300`62P0<00l42P0D2@l06@hD01H;4@0A1P`04`P>00h3
2@0A1P`02`0600L00P0@1P/050T?5?ooool001_ooooo00T04QLJ00dA500>4QD03a<F00`?4P0=3Q80
6AXN018B5`0?3Q<00P0A41D00`0=31403`lA00l?4@0200h>4008014A4`0B4Q@04Q8D01TI6`092@/0
3Ph@01TI6`0=3@l4010>408040l@00H03@d>018A4P0A4Q<03a4A01DF5P0<3@d200l>300;00h>300>
3@/03@d;00`<2P0B4Q002P/900d>2`0@4Pl03Q0=01hP7@0A4Pd00P0<3@P03P0?40/04A8=014B3@0B
4`h02``7014B3@0G61<0414<00d>2@0D5A001@H201/L5`2PXI`0ATM20P0A4Pd01@0O81/03@h9014B
3@0=3PT04A8=00803@h900`03a0;010A300?40/03@h900h?2P0?40/03Pl:00`=200=3PT03Pl:00d>
2@0>3`X300l@2`0:014B3@0?40/03Pl;00d>2@0>3`/04a@?010A3@0?40/04A8=010A30804A8=02@0
20T4014B3@0@4@`02``7014B3@0B4`h0410>00l?3@0>3P`03@d;00h>300@40h03Ph<010@3P0A4@l0
4a<A01PH5P0F5Q@03a4>00X<2@0?4@h05aTF01<E4P0<3P/02`d:010B3`0B51402`d:00h@3@0O8Ah0
3Q0?018D4`0X:RT09bTX00lA400@4Q42014C4P0500d?3P0@4Q40418A014C4P0>40l0100?4A000`0>
40l0418A014C4P02018D4`0:010B4@0=3`h02`d:014C400?4@h06adK010B3`0E5a@03@l<010B3`80
4Q@A00D03a4>00`>2`0>3P`04A4?010@3P02018B400500P81P0@40h04A4?018B400C4a400P0B4Q00
4P0A4a003a4>010B3`0B5140418?00h@3@0A4a003a4>00P:1`0M7a`04Q@A01PJ5`0@4Pl04A<@00lA
3P0B51404aDB00lA3PD0418?00<0418=018D3P0B5@h0100B5@h02`0H6a@03A09014D3@0B5@h04A@=
02PZ900K7AP03Q0;01DG4P0?4@`04Q@?00805aTD00H04aD@018D3`0C5A004aD@01<F3`0C5Pd2018E
3004014D2`0@4`X04QD<018E30804A@;0P0B5@`0600@50d051TC02DW8P0c=Bh05aP@00d<0P0F50/0
5aP>01LH400?4`/041P@01@L5P0D6A<030l801DH4@0=40T07B0I01/N5`0B5@h04aH?01LJ4`0H6a@0
5aXC01@G408051HA0P0I6aH0100D5Q405ALB01LI500F61<201DG4P0;01HH4`0I6aH04AH@014F400G
71H06AhH01HK5@0U:R@05a`F01HK5@0E6Q@00P0F6aD01`0D6A<05a/D01TM5P0I7AH061`E01TM5P0K
7aP00P0I7AH202<W800K01hR6`0V:b@07bHO024[8`0?6A407BLO01/U7@0]=bl082XR01PR6P0P:R80
7BLO01TS6`0T;bL0:3<]02Pd;`0P;BL07RXU020]9`0L:2<07RXU024]:00Q;RP082dW028_:@0U<Bd0
7RdZ00808S8_01408c<`02Xm>`0P<c40:3Xj02Hj>@0W>cX0;41102a1@P0Z?d00;40o0355A00W>cX0
:cln02e1@00bATD0<DE402a0?`020396A@0703A8A`0nDU40;T4n02Tl>@0aA440:chl03=7A@0202m3
@P0M03I;B`0gC4`0?55B03eEEP0jDU@0@EIL049FG@0oDeX0?51G04AHG`1;GfH0A5QO04=GGP1:GVD0
B5aS04=GGP13Eed0FFib05aaM@1<HFD0AeaO04]PH`1>HfD0@eQI049GF019GUl0BUmO04]PH01=HV@0
0`1DJFh204QMHP0Z05M/L@1WO840FVmd05AYKP1;H6D0FFic05Y^L`1FJFd0GG1d05M[K@1DJ6T0Gg=d
05ibLP1PM7<0HGEc06QlNP1SMgD0HWIe065dM`1UMgX0I7Ij06aoPP1WNWd0J7Ym06UlOP1ZOGh0Jgin
06aoO`1]P7l0KX6006f0O`1^PH40L8>306n2PP1`Ph80LXF507B7QP1dQhL0LhJ50764Q01cQXH0NHb;
0P1gRXT08P1eRHL0M8R607F8QP1gRhL0Mh^607F9Q01cQh40LhN007J:Q01iS8H0LX=k06n0N01hRH<0
MhN406moO@1cPh80MhN607J6Q01cQ7h0Kh1h06UjL01RMV/0HGEY05idI@1CJ5L0DfAB05EUD@1CHT`0
D5m904eMB@11E440AeU904AIC@1:H5D3055VGP05051UG@1?I5`0CV=K04eRFP1:GeL00P17G5@06P15
FU80@EI>03iEC00jDDP0?EA;04EKD`11ETd0>Tm603I;@P0`@cT09SP_02<f:`0/?C80;She02Td=00^
>Cd0=D9802llA00cA4d0;d1903A5C@0/>d008S4c02lk>P0U<2`07BPS0P0P;2L08`0T<2/08BdX01`Y
8P0N:b@062DN01PU7@0L:B406bPO01`Y7`0Q;RH07RLV024Y:P0R:R/08BTZ020X:@0K8b@072@U01lW
:00O:2P08BXZ020Y:@0N9B@0728P01XP7P0K8Al0728P01/Q7`0L8R005adK01<I5`10AT@082HT01@J
600K8Ah051TE0080724M00H0:c0/01hS7`0H7AT0724M01dR7P0E6QH201XO6`0:01@H5P0E6AT06QhN
01PL700?4a<07B4Q06Q/K02BUYH08bLW01/O7`805QXJ00L05aLE01`M600J6aH06AXE028S7P0D5A00
5AHA008071dH0P0D5A00100C50l05A@@01DD400E510201@C3`0@01<B3P0E51003`h:02XY9@0C4Ph0
5QDA010?2`0D4a404Q4?010?3@0A40h04a8@01@C4@0A40h03`h<014@3P8051<A00<04A0>010?3@0A
40h00P0B4@l301@C4@0<01DD4P0<2`T05QDC00T81P0K6QP0>SHe018>3@0E4A0030P701@@3`0=2@P0
5Q8A0P0C3`h00`0A3@`03PX901DA4004014=3006018>3@0C3`h040`;010<2`0>2PT03`/:0P0@30/0
200N6QT0EU9A01HB4@0<20L06ADD00h:2@0A3@`03`/:0P0>2PT200l;2P0L014=2P08104030P502hZ
9`0M6AH04@d:00h:1`0:1P<03@T600h:1`0C3``030P6010=300;20L03``;01PE500B3Pd04Ph>01<?
3P0@30/030P700/71P091PD04Ph=01HC4P0m>CP0510?018>3@803PX900H03@T800h:2@0?2`X03PX9
00d9200?2`X6010<2`803PX900T03@T800h:2@0>2PT03PT800l92@0A2`/040X:02PR8P0D3Ph00P0?
2@T0400>20P03`T9014;2`0B30`05@h?00H10P0>2PX02PP800L51P0C51804Q<B00P81`0:20P030P8
00T41@0C2`d300l92@803PP800L03@L700X4100F41003PP800/51@0>20P03`T900H03@L91P0>20X0
1`0R72005@lC00L11@0=1`/040X>00P21P0<1PX00`0>20`03P0?2@d03PP<00`11`0E2Q0060dC01<8
3P0>0`T03`@:01D:400A1``040H;03db>00e:S003P@95?ooool001_ooooo01P041DH00T>4@0:3Q40
310C00d?4`0A4QH05QLK00l?500=31404A0E01<B5`0@3a@04A4C00d=3`0D51H05ADG00h>400=3@l0
4A4C00d=3`0F5QP02PX<01/K7@0;2`d6010>4@08014?4P0K6A`01P@701HF6000008071`L00h>3@0>
3P`200d=2`8030`:00H03Ph<00@40P0D51809RHT01@D4P0820H2014B3@0>00X;1P0@4@`051D@00d>
2@0?40/05AHA014B3@0?40/03Pl:00l@2`0>3`X051D@00`=200B4`h200`=200D01TJ5@0/;BP051D@
014B3@0;30L0414<00P910092PD05aPC01<D3`0<3@P03Pl:00d>2@0;30L030d8010A300A4Pd03a0;
00d>2@0>3`X300l@2`0B010A300:2`H04a@?01DF4@0720<02P/600h?2P061`803Pl:01dN6@051P40
414<01DF4@0?40/030d8014B3@0B4`h030d81P0>3P`03P0@40h04A4?00h>300=3@/03`l=00/;2@0<
3P/03Q0=018D4@0=3``020X700lA3P0A4a00418?0P0?4@h200h@3@0>00h@3`0D5QD051HE010B4@0C
5A@03@l>00X<2`0>40l04A<B00X<2`0<3Pd00`D4014C4P0@4Q4200lA4004010B4@0A4a804A<B010B
4@803a4@01H04A<B018D4`0I6aP03Q0=02<U8P2k_KX08bDR018D4@0H6QL030h;00h@3@0A4a003Q0=
00lA3P0>3P`02PX800`<2P0?3`d0410>018B400A4@l04Q8@100C4a404P0B5140418?014C400C5A80
4A<@00lA3P12A4407b4N00`>2`1PHUl0CU1=00H81@0C5A804A<@00h@3@0D5Q<06A/H01LI5PD0418?
00<0418=00lA2`0?4P/0100?4P/06`0>4@X04aH?01<F3`0<3`P041<<01TK5@0B50l051HA018D3`0A
4`h05ALB00d?2P0>40/04Q@?01@F4@0B50l04A<>014D3P0D5`h05QT@018E300?4PT04A@;01DH3`0F
6A0051L>014D2`0200lB2@0Q00/?200M8Q`03a4<00h@2`0N7QH04Pl601XG3P0A3PD030`401`N5P0A
5Pl03a@?01PJ5@0@4``06ahG018E3P19C4D0?3lh014D3@0D5a006QdF01`O600J7AH05APA01HH4`0C
5A005aTD01HH4`0B50l06A/F01XL5`0I6aH05aTD00805ALB00T05aTD01/P6P0E6Q@05a`F01XO6@0`
=Bl0L7E_01/P6P0I7QP00`0G71H0100D6A<05AXC01LL5@0G71D201DJ4`0E01HK500K81T061dF01hS
700K81T07B8K038i<@0i@c/05R0H01<M5@0U;bL03aTA061ZHP0I8a/07BLO01hX800@6Q808B/S018M
5@0L:2@082`X00806RHR02`08BdY01l[9`0M:BD09S8^02Te<@0T<2`082`X028^:P0U=340;Shk02`l
>@0P<2d0:chl02Hi=`0Y>c/093Pg02Hj>@0Y?Ch09c`m02@i>P0_@d809CTh02a0?`0eBDP0;40o03=7
AP0[?ch0<4A303Q<B`0^@T40LXJ50<?GeP14EeD08cHd03=6A00bAD<0<dM602e1@00cAdH0=4U:03=8
B@10EEH0AemQ04ALGP80?E5H01<0?51G04MKHP1SMgh0HWIm041DF`1=HFP0H7Ak059VK@1>HVT0B5eQ
04QMH012EeX0B5eP04aQI012EeX0AEYL04=HF@12EeP0Bf1Q0080BEiO0240CfAX05EZK`1?I6T0QIZO
08fRY`1KL7D0D6EZ06^0Q@1BIf`0GG9g05Q]LP1GK740Ffmc05Y]L@1OLWH0FFa_05M[K01LL740GW9b
05ibL@1TN7H0NHf;06f1O`1RMW@0J7Yj06YlOP1UMgT0J7Yl069dMP1SMGL0JWan06]mO`1^P8000P1_
PH4206j0P00b0722PP1aPh<0LH>30763P`1dQXH0NH^;07N9R@1fR8P0NXb<07j@T021Ti<0LH>307>5
Q@1iS8X0NXf;07R;R@1dQh<0LhJ207B7P`1gRX@0MXV307>6P01`Pgd0LX=k07B5OP25UY00Pi>@07>3
P@1gQhH0N8R707F5PP1^OgL0JGY`06AfJP1NLf@0FVmP05meI01FJeP0DV=@055QC@1>GDP0>dXe051P
C@1CIED0DF=E03]@A00iCd<0AeaC04]PE`1?I5/2051UG00b04iSFP1;H5L0BUmF04QME017G5<0@eQ?
03eBB@0nED/0?5=903mFC011ETd0>4e40356?@0_@cX0?4e503Q9@@0^?cD0:CX`02Pg<00P:b`0=d96
03e;CP0X=Sd0;d1702/l@`0`@DL0:STl02Lg=`10C4/0<C`h01dX900K:2407b`U01h[900O;2D07BXS
01XW800K:2407R/T028_:00O;2<07BXQ024^9`0O:2P072@V02<[;@0N9RP06b<U01lW:@0P:2X201hV
:00E024Y:`0N9RP06R8Q01XP7P0H7Q`06b4O01hT8P0M8b4061hL02L]:`0M8b406AlM01DK6@0J81h0
61dJ010E4@0G71P08BHR03Pm>@0S:2@05a`H008082DQ00D05AXF01TN6P0J7a/061`J01/O7P02018F
5@0501dQ801;Cdh051PG02@X9`0H71/00P0I7A`03@0=4Pl06ATG010A300F5a8071dH03Pi=00I6QD0
5AHA01TJ5@0E5Q40414<01@E400E5Q400`0E51003`0D4`l04a8>01<B3P0Q81`030/701HE4@081`<0
3`h:01@C3`0;2PP040l=01@C4@0?3P`03@`:01@C4@0201DD4P0400X91`0D4a4030/901TH5P8051<A
0P0B4@l0100A40h040l=01@C4@0>3@/200l>30806aXH00X0Pgmn01@@3`0P71/040`;01<?3P0?2`X0
3@T801TE500U8B007QXI0P0>2PT0500?2`X04Ph=014=300>2PT03`/:01<?3P0A3@`040`;00h:2@0?
2`X04@d<018>3@0?2`X081`K00<0000A3@`03PX900`81`0B3Pd03@T80P0;1`H02`0>2PT040`;00/7
100C3``06QHC018?3@0300005Q8?00d91P0B3P/05Q8?008040`901P01`<000/81`0W8b800`0000d9
200H51<0510?014=30091@@030P701HB4@0<20L04`l>00<0000Q7A`03@T8018>3@0810<03`/:00d9
200?2`X040`;00l;2P0=2@P600`81`<03PX900X03@T800h:2@0>2PT04Pd<00@0000E3`l03PP800X4
100;1@D04@/;0P0?2@T03`0@2PX04P`<014;2`0>1PL07A@E00`61P0I5A@02`X800D5100000004A4?
014>3@0<1PH03PP800h61P0300l92@0900h8200=1`L03@L700h8200:10@050h>014;2`04000040X:
00H03@L91P0>20X020090`L02`D9018<400>20`0208601D?4`0=1`/02P@80P080PH01P0<1PX03`T=
0146300@1@/0304700d220804PL=00H03P<901H;4@070080:1dS02DL800L4ALDooooo`006oooool0
2P0<4A@03Q<F00hB5@0;3a802Pd@00/<400<3A40410D010?500>3A8200`;400801DE5`0=3@l030`>
00h>400?3a404a<E010@4P0C4aD200X:300D014A4`0C4aD03Ph@010@4P0H61X020H901DC5P0A3a80
61HI03Hd=`0D4QD02PP;01LE600>3Ph03`l>00d=2`0C4a40410>014A3`0;2`T200l?3@80410>01@0
3`l=00h>300C51000040014B3@0D5A0020T400`=200G61<01@H100T:1@0=3PT05AHA00h?2P0<3@P0
2``700`=200=3PT030d800/<1`803@h900l03Pl:00l@2`0?40/05AHA01<D3`000@004a@?00d>2@0I
6QD02``700l@2`061`805aPC00`=200?40/00P0>3`X0100A4Pd04Q<>00l@2`0>3`X2010A30803a0;
00@0414<018C3P0D5A003Pl:0P0=3PT01@0F5a804A8=014B3@0?40/03@h900<03Pl:1P0>3P`02`0E
5A<0410>00l?3@0?3`d03@d;014A3`0B51401`T600lA3P0B514030h;00@04A<@00D0418?00lA3P0?
4@h030h=00d?3P02010B4@0D00h@3`0<3Pd030h=01@F5@0=3`h02@/:00lA400B51<030h=00X<2`0;
3@`03a4@010B4@0<3Pd020X9018D4`0D5QD0418A00lA400B51<200/=2P0F01<E4P0[;BX04aDB00h@
3@0D5Q<04aDB018D4@0A4a00418?00lA3P0A4@l04a<A00d=2`0>3P`04Q8@00/;2@0=3@/04Q8@01<C
4@0<30X04Q8@00`<2PH03a4>00h06A/H00h@3@0=3``04aDB01DG500C5A80418?018D4@0@4Pl030h;
00h@3@0@4Pl0EUQE010B3`8030h;00H07b4N00/=200@4P`051L@00d@2@0C5Pl201DH4@803a8;00P0
41<<014D3@0A50d03@l9010B3@0F61<04Q@?010B3@803a4<1@0A4`h0:`0@4`d04A@=018E3P0A50d0
41<<018E3P0C5Pl06A`E0002000I71D051L@018E3P0=4@/05ahG0002000L7QH04a<;01@A200F4`X0
4@h5014A2@0E5`l041D>01<H4`0E5a804aH?014D3@0F6A806A`E01LJ4`0A50d04aH?01@G400C5Pl0
5QTB01hQ6P0E5a807AlJ01@F4@0G6A@06A/F04i@B`0H6QD00P0G6A@02P0F61<05aTD01PJ5@0B5a40
41D?01<H4P0J7aT0724K01DJ500@5@l201@I4`0301<H4P0D6A<041D?00<05ahG00/061lH01TP6@0J
8AX061lH01`S700940T06B0I01XQ6P0T:b@06B<K01XT700201/U7@0301`V7P0M9al072HN00806bDM
00H08R`T02<]9@0D7aL06RHR02He<00>7AP201l^:@0F024`:`0M;2L0:CPc02/j=@0U=2l093<^02`k
=P1PKf`0<T4n01l_;00V=S<09cXh02`o?@0]?cl0:Cdl02Di>00aADH0:Cho02@i>P0/@3l0<TI50314
@`80<dM600P0;D500314@`0`A4<0;d=20355A00iCD`0?U9A03A7A@80;d9002L0=4I60355A00^@T40
>4a=0315B00bAdX0CF9U03]CE@14G5h0@EEL041DF`0iCE@0BEeT082DV`1iSI@0Ae]R04EIH01BIVd0
EVYa04iRJ@19GV80AU]L04=HF@12EeP0AEYK04UNG`1;H680DFIY05AYK01=HVD0Bf1S04iSIP1AIVX0
D6EZ05AYKP1YOX<0L8F:069gO01CJ6d00P1AIV/0301DJFh0EFY_05Y_M01IKG40FFa`05e`M01JKW00
Ffm`065eMP1UNGT0HGEd069fM080IGUg01l0JWil06eoO`1KKFd0RifM07>5Q@1MKfl0IWQh06anOP1[
OGd0Kh610763Q@1`PX@0LH>407>5Q@1eR8H0MhZ807F8QP1dQhD0MHR608RKV@1jSH/0M8N507N:R01e
R8H0NXf;07B6QP1cQHD0MXV707R;R@1gRXP0N8^70080MhZ602P0MXV307N:Q01cQX00JGaf06]lMP1f
QX80NHV607F5Q01cPh80MHF407N7QP1cPh00KGif06UjL01RM6P0Fg1Q05EZF@1HKUX0EfaI05=TD@1;
FdP0BUU603i=>P18EdL0AeU;03i@@P0eBSh0?59604UNE@1?I5/0EfaS09V^Y@1JKfH0L8El04MLD`1>
HeX0BUmF045FC@0mDTT0@EI=0P1:H5@06P0nE4P0=DY102/o=P0O<bX0;Slg02dn=P0/?CD0:CPa02@c
;00S<Rd09S4b03M2AP0e@dH0:SPm02Hh?00[?D40:S`o02dl?`0U=CD0930_02@_:`0P:bL08RlW01`Y
800Q;RD08BhW0P0J9b0201l/9@0F020]9P0Q;RL062DN020/:00S:b`09bla01hV:00O9bT08RX/01lW
:@0P:2X08RX/020X:P0N9RP082PZ024X:00H7Q`05Q`J01XP7P0G7A/06R0N01`R808061hL00@05Q`J
01DK6@0E6aT06R0M0P0J7a/04@0N8al06AhJ01DJ5P0F6aL07B8N01TN6P0B5a<06b0L01TN6P0@5180
61`K01TM700@51<0HVIU0>7Ui00k?ch061`K008051PG00h05a/J01TN6`0J6QP06Q/F01HG4P0C50l0
5AHA01<D3`0H6A@03Pl:01@E400G61<06AXE01@E40804Q4=0P0G5Q80200D4`l05QDA01LF4P0A40`0
30/7018A3@0E510040l;1P0C4Q000`0H5aD040l=00P71@0201@C4@03014@3P0B4@l04A0>008040l=
00@04A0>018A3`0C4Q004Q4?0P0@3`d2014@3P0501PD4`0:1PD05A4@01`H5`0B3Pd00P0?2`X02@0E
4A004@d<014=300<20L07ATH020L6`0?2`X040`;00d9200301HB4@0401<?3P0;1`H02PH501TE5080
4@d<0180510?00d9200=2@P07ATH00X61@0B3Pd04@d<010<2`0?2`X030P700/71P0B3P/00`0000l;
200N6QL0VYJC02XV8`0?2`P300h:1`803@T600`03@T8010<2`0>2PT04@d<018>3@0?2`X03PX900d9
20091@@03PX900/71P0>2PT500`81`803PX900<030P700/71P0<20L00`0>2PT00`0A3@`03`/:00h:
2@02010<2`0700P40`0?2`X0<bl^01HB4@0300003@P700d71`02010:2P803@L700X030H600/51@0>
20P04`d=014;2`0=1`L03@D600l61`0>20P03@T80P0<2`T02P081`D030/900l;2P0:10@0208200l6
1`0E3`l0100001TC4`04000201LA4@0<014;2`0<1PH030H600d71`0;1@D03@L7010:300:10H04P`>
00`620090`D030H81P0=1`T03@0<1PX03@L;00h8300>20`03@L;00`62P0@2Ph03@L;00`62P0>20`0
3@L;00X4200700800P0F2a401@0700803@880146300@1@/04@H<00804PL=00<04@H<01052oooool0
4oooool001_ooooo00D02PlB00`A500=4A@02`lB00/=4@0200d>4P05010@5@0B4AH040lD00h=4P0?
3Q<00P0C4aD01P0=3@l030`>010@4P0@41803`lA00`<3P804A4C0P0<30h04`0>3a802@T<010@4`0=
3A005A@H010?4`0A41@07adQ00h<400?3A40518F00`<3P0?4Pl03a0>00/<2P0?40d051@B00`<2P0>
3P`00`0?3`d04`0@3@`03`h<00l@2`0B4`h05AHA00l@300K71L030d802h_:P0G61<04A8=00h?2P0A
4Pd02``800d>2@0>3`X04A8=018C3P0?40/01P0>3`X0300:2`L07AhI00`=200N7aX051D@00/<1`0C
50l051D@00D60P0?40/03Pl:01HG4P803Pl:00D0414<014B3@0>3`X03@h900h?2P0200l@2`80414<
00d04A8=00l@2`0;30L04A8=01<D3`061`8092DP01<D3`0A4Pd03a0;010A300A4Pd0414<00H03Ph<
00`03`l=014A3`0?3`d03Ph<01<C4@0E5A<04A<@024S800k?CX051HC01HH5@0?4@h2014C4080418?
0P0?4@h00`0=3`h03Q0?00lA400200lA400600d?3P092`X0418A00h@3`0=3`h0418A0P0>40l0400@
4Q404Q@C018D4`0A4a803a4@010B4@0B51<02`d<00lA400F61L02@/:00d?300F61D020T700`>2`0?
4@h3014C40803a4>00D03Q0=00d?300<30X03`l=010@3P0200l?3@0701<C4@0A4@l03`l=01<C4@0B
4Q0051@B00`<2P0600lA3P0601HH5@0>40d03@l<010B3`0?4@h03@l<0P0C5A803P0A4a003a4>010B
3`0B5140>3Xg01@F4`0E5a@03Q0=01/M6P0>40/04A<=01@G400=40T04QD>0P0D5a00300A50d05APA
01LJ4`0F6A804aH?01<E3`0C5A00418=00h@2`0E5a8051HA018D3`804aD@00D04Q@?010B3@0?4@`0
4Q@?014D3P0200h@2P0E018D3P0D5Q004QD?01PK5@0B50h0A4M101/M5`051`@04ALB018J4`0E7QH0
310801@E3@0I6Q0061L=01HF300C4`/04aD=018E3P0G71L04aD@00804aH?0P0D5a003P0E61405QTB
01LJ4`0G6Q<051L@01<F3`0F6A805QPC01XL5`0C5A006adH01@F4@0B50l061XE0P0G6A@00`0F61<0
5aTD01PJ5@0201LL5P0F01/P6P0P9Al07R<M01<H4P0H7AL06b0J01TN600H7AL07B8L01hS7@0H7QT0
5A`F01LM600F7AL05Q`G01`S7@0H7aT05A/F024W8P0K8Q`07bHP01`S7@H06bDM00/072HN020Z8P0M
9al07BLO01lY8@0L9b409C8^01HU8@0W=S805bLS01h^:P0201d/:00A02<b;P0U=C408c<_02@c;`0X
=c<0;chk03A3@00iBDH0:SXg028e<`0[?S`09cTi02a0?`0^@T40:3`m0315AP0^@d@00P0cAdH0100_
@d80<DE40396A@0_@d820396A@0O0314@`0^@T40<4A30396A@0eAdH0=dU803E8A`0cADD0=4Q803I:
BP0fBT`0>TmB03eBE@0mDUH0?5AG055YK@1>HVT0D6A[04iRJ@19GF@0B5aS04UMI016FV40B5aS04mS
JP1<H6L0BUiU04YOH`19GUh0BUmO04]PH00204]PH@0c04]PHP1AIVT0E6U/04mTI`1?I6P0DVM[05=X
K01EJVl0F6eb05aaMP1JKg@0EFY_059WK01YOX<0NHjC05icN01KL7D0HgQm05U]L@1ML7@0H7=g061d
MP1PM7D0HWIg06AhN01QMG@0IGUg06QlNP1WNgT0Jgmm06aoO@1[O7X0NHZ906UjNP1TMG@0HgAc06am
O@1^Ogl0LX>30761Q01`P8<0LX>40763P@1dQH<0MhR607J8Q@1fQhD0N8Z707R9Q`1jRhT0Nhf:0080
N8Z700T0OHj<07R9R@1hRHT0NX^:07Z<RP1jRhX0NXb807V:Q`1hRXH00P1iRhD06`1dQX00KGmi06]l
M`1hR8D0MHF307B4Q01iRHP0Lh>207F5Q01`P7`0IGI^05m`IP1MKf80GW=R05AYEP1IKe`0CfAA04aM
B`1;FTX0A59203]9>`0lBSh0=4Hk0353>00mDTP0DFIM059WGP0204mUFP0306MmLP15FU00D6IK0080
C65G02d0B5iC04AJC`12F4d0A5Y>041FBP0kD4@0=T/o02m3>@0[?SD0:Sdd02/l=00W=c409SH`02Lf
<00V=Bl093<_02df>@16DED0AUAG03M5B@0_@D@0<dE602m1@@0]?C`09cLf02Te<`0W<Bl08B`X020]
900V<bX0:cP_02@a:@0M:R<082dV02Db:`0P;2L08c0Z01h[9@0S;bX082`X02</;00T;Bd082TY028Z
:`0Q:BX00P0L9BD02`0N9RL07bPX01hW9`0M9BH07BDS01XP7P0H7Q`06R0N01HL6P0E6aT06AlM0080
61hL01l06b4O01dS8@0N92806AlL01LL600L8Ad07R<O01HK5`0H7AT07R<O01`Q7@0H7AT06QlK02P]
:@0U:RH061dI01XN700G6aT06b0M034e<`1iOG/08bLU01@I5P0G71T03a@A010E4P0G71P051D@01DF
4@0F5a8051D@00804a@?00L061TD018C3P0G61<0414<018C3P0D5A0061LC008051<?00D04a8>014@
300I61@06APD01HE4@0201<B3P0301@C3`0C4Ph04a8@00D04a8@00P03Pd;01HE4`0Y:2H061LE00/:
2@0E51804Q4?014@3P8040l=00<04A0>018A3`0A40h00`0B4@l0800A40h03`h<00`81`0G4a802@D4
01TE500`;2/03PX9010<2`0A3@`03@T801<?3P0G4a80:bLV06MSHP0@30/06ADD00X71P0F4Q404Ph=
06=OGP0G4a804`l>014=30091@@04@d<00l;2P0>2PT030P7010<2`0=2@P040`;0P0?2`X02P0>2PT0
3`/:01<?3P0G4a803PX700d91P0<2@L06aLD08f9QP0_:bP200h:1`803@T60P0<20D00`0?2`X04@d<
00h:2@02010<2`0700d9200?2`X03@T8010<2`0;1`L04@d<00h:2@0500`81`0500d9200>2PT03@T8
00`81`0=2@P00`0>2PT0300@30/03PX900d9200>2PT04@d<00T5100>2PT081`K010<2`091@@03PT9
00h8208040X:00@03@L700h8200G4A405@l?0P0;1@D2018<300N0108200@1PH03`P700d91`0>2PP0
30/800X91P0=30T040`:00`71@0<10<04@P800P10@0E3`l0@S`l01D?3`0A2`/040X:00`61P0:10@0
3`T9018<300?2@T03PP802lY:`0J5AH03`T;00d72@0@2P`04P`>1P0=1`T02@0<1PX03@L;00h8300>
20`03@L;00`62P0?2@d03@L;00`62P0200h8300900/52@0I3Q@03`@:00d2200H3A<03`D:01<83P0@
1@/04@H<00804PL=00<04@H<01052oooool04oooool001_ooooo00X0314D00lC5P0?4aH03Q8E010C
5P0D5AT04Q<G01@D600C4QL040lD0P0>3A80200B4Q@02PX<00d=3`0>3Q006ATK038b=00Y:B/03`lA
0P0=3@l04`0;2`d04A8D00`@4`072`h041@G00L93@0@4AD04a@H00d<4@0;2Pl03@/@00l=4P0=2a00
3@d?00d@3P0<3P/02P`900h@3@0;2`T00P0=3@/04`0>3@/03`h<00l>300@30/03@`:00`<1`0?40/0
414<00/<1`0L7AP0UiRC06UZI@061`804A8=01@E400>3`X05AHA00`=200>3`X00P0D5A001@0A4Pd0
3a0;00l@2`0?40/03Pl:00803@h9010030d800P910051P4030d800/<1`0<3@P010D101PI500;30L0
:2TT01HG4P051P40414<00h?2P0A4Pd0414<100>3`X0300?40/04A8=014B3@0?40/04Q<>01PI500?
40/06AXE00`=200o@3/04a@?014B3@803a0;00<0414<00l@2`0>3P`01@0>3P`0300F5Q@07QhL01@D
4P0:2PP04A4?00X:200A4a000P@101HH5@0>40d02@/800P:1`<0418?0P0?4@h00`0>40d03Q0?00h@
3`0600h@3`0F00lA400A4a804Q@C00lA400;3@`0418A014C4P0@4Q4051HE01XL6`0@4Q404aDD00d?
3P0H6QT0;2h]01hP7`0E5a@01@L401TK600H6QL02P`900lA3P804Q@A0P0A4a02010B3`0501<C4@0?
3`d051@B01<C4@0?3`d00P0D51801@0C4a406ATG01DE4`0C4a402`/900H03Q0=00H030h;00/=2P0=
3``04Q@A014C400?4@h2014C4080418?00d04A<@018D4@0=3``02@/8014C400<3P/051HC00d?2P0;
3@L04QD>00hA2P0B5@h04A@=00803Q4:00X04A@=01@G400B5@h04A@=014D3P0B50l03Q0;00/=200B
50l04aD@0`0B50l0900A4`h0418=010B3@0C5A00418=00/=200?4@`05ALB01@F4@0>40/04A<>01PJ
5@041P<04aD@02@V8@063@P02aH>03@o=`0D71<06QdD01PK400I6a0071hC01PI4@0F6A404aPA01XO
6P0B50l05APA01LJ4`0C5Pl04A@=01@G400C5Pl051L@01HI4P<05APA00L03@l:01HH4`0D5Q404A<>
01@F4@0I6aH061XE00805aTD01/05QPC01LI500H6QD05a`F01HK5@0H7AL06QlI01PM5`0@5@l061dG
01/P6P0I7QP061dG01dR700N8ad051XF020V8P1KHEd0EeeI01TO6`0B61@05adI02`b;P0;4@d0318>
02hd<00N92000P0L9Qh0400K9Ad06R@L01XT700I8a/05b4I01hX800L9Qh06R@L01`V7P0H8ad072/V
028b;`0Z>SL0:c/h024a;P0O;b`2024a;P0802<c<00V=S<0:3Pe02Lg=00^?CX0:CPe02hn>`0_?c`2
02Hi=`0802@f=P0X?3/07S8a04AHF@1WO7d0;T=403M;BP0fBTT303E9B00303A8A`0bATD0=d]:0080
>4a;00<0=d]:03Q<B`0bA4@00P0dATH03P0bA4@0=4Q903M;C013EUX0=da?03U>D@0oE5T0DVY^04EM
H@1?HfX0AUYQ04=GGP16FV40B5aS0P1:GVD01@1<H6L0D6A[04aPI`1;GfH0C65T0080BV1N00P0BEiN
04MLG@16Fe`0AeaN04eRI@1@IFP0CF9V051UJP80DVM/00`0EFY_05Q]LP1GK740EFY_05Q]LP1JKg@0
O96F09V^/`1YOX<0DFI[06EjO`1RMW/2065dN00706IiO01TN7T0HgMh06MkN`1YOG`0KH5o06n3P@02
06]oO@0M06alN@1fQX<0KGej06moOP1ZNWT0J7Qg06]kN`1bPX80MHF5071oPP1aP8<0MHB607>3PP1e
QH80MhN407J6P`1eQH80MhN407B4P@1kRhP0N8R507Z:Q`29VIH0UjNT07b<S01nSXh0O8b;07Z:R@1l
S8/00P1kRhP0<01iRHH0NX^507Z;Q@1eQX00LhAn07f=RP1hR8H0Nh^:07B4Q01[Ng/0NXZ90720O`1]
OWP0HW=Y05Y/H01JK5d0GW=R04YOC01=He00DFIE051QD@14DdH0?T]1034n=@0]>c<0;3de03Q9@`1<
H5T0E6UR04]PE`1:H5@0DVQL04AJCP1<HUH0CfEI04iTF017GE40@eU=04AJCP15Fdl0@eU=03eCAP0e
BCh0=TXo02m3>00/?CD0<T<k02Pi<@808C0[01009cHa02Pg<P0Y=C<09Rlc045<D012D5<0<3m102Tk
>`0_@T00<DA202Ti>00V=SD0:SHd02H`;`0P:bL082dT0`0O;2<0500V<b`0;3Tb034n=`0T<2`0:3@`
01dY9@0]>CD07b/W02@]:P0Q:RT08R/Y02</:@0O:2L07RLU024Z9`0Q:RT08b`Z028[:00L9B@06B4N
0`0K8Al0800G7A/05Q`J01LM6`0M8b408RPV020V900I7ad05adK01HK600F6aL06QlK01`Q7@0F6aL0
6AhJ01`Q7@0G71P051TE01PM6@0U:RH08bPT01PM6@0L8Ad041DA01PM6@0:3`/06QlK020U8@0G71P0
5AXF01lT800U:RH061dI0P0H6A@201XK5P805AHA018061TD01@E400E5Q403@h9018C3P0G61<061LC
01@C3`0B4@d04A0<010?2`0H5a<05aHB01TH500H5a<04a8>010?2`0B4@d601<B400800d<2P0E5180
5QDC00X91`0Z:BL030/9018A3`0A40h2010?3@04014@3P0B4@l03`h<014@3P804a8@00P040l=00d<
2P0C3`h030P700l;2P0I5A@06aLF010<2`80510?02<04@d<01@@3`0710<02@D400<0000A3@`03`/:
01hJ6@0=2PT06QHE00/71P070`<05A4@01<?3P0@30/020@3018>3@0?2`X03PX901DA40060P406ADD
00l;2P0B3Pd040`;00d9200@30/0510?01DA3P0H51404`l<01HB3`0:1P<00`00010<2@0200l;2080
3PX700<03@T6014=300B3Pd00P0?2`X0200>2PT02PH5010<2`0B3Pd02@D402/W9P1<B4L04Ph=2`0=
2@P300h:2@0Y00d9200;1`H02`L600h:2@060P402`L600X61@091@@040`;00d81`0@2PX04@/;00l9
2@0=1`L03PP801D?3`0D3Ph03`T9010:2P0B30`03`T900l61P0A1`H040P600h91P0=2@H030X600/:
1P0=30P040`901081P0?1`D04`T801/B4`0600002PD500@0000F41004P`<00`61P0;1@D00P0>20P0
1@0:10@02`D502`V:00G4A<04@/=00804P`>00<02@@500d72@0=1`T0100=1`T02@0<1PX03@L;00h8
300>20`03@L;00`62P0>20`03@L;00`62P0200h8300800`62P0A1P`04PL=00l42P0D2@l02P4500h3
2@0?10X40146300300l42_oooooooooo01;ooooo000Kooooo`0E00dB5@0?4aH03a<F00hB5@0A51L0
5QLK010A5@0B4QL04Q4F010?500A41D04Q4F01PH6P0=3@l05ADG00X:300B4Q@0CdmA02d];`0>3Q00
2PX<008030`>02@04a@F00D;3P0730l041DH01DJ7@0830l01`/>00d>4P0:2`l04A0E00/:3`0920d0
3`lA00`@3@083@T03a@@01@F4`092@L061PF00d=2`0>3@/03`h<014=300@30/03@`:00`<1`092PD0
4a@?00/<1`0U9R40^[^f07AeL00<3@P04A8=00X;1P000@0200/<1`0400d>2@0B4`h04a@?010A30<0
3a0;02L03Pl:00d>2@0=3PT04Q<>01HG4P0J6aH03a0;00/<1`0=3PT0414<00h?2P082@@0;2dX00/<
1`051P404a@?010A300A4Pd0414<00h?2P0?40/03Pl:00d>2@0?40/04A8=010A300?40/02``701LH
4`0?40/06a`G00d>2@0E5Q404A8=00l@2`0=3PT03Pl:00l@2`0>3`X01P0>3P`0300;2`T05ADC010@
3P0<30X05QHD01<C4@0L7Q/03a4>00d?300M7a`05QPE01TK6080418?0P0?4@h200h@3@H03Q0?00@0
418A00d?3P0=3`h03a4@0P0@4Q404P0=3`h03Q0?00d?3P0<3Pd04aDD01dO7P0A4a805ALF00/=300>
40l06adL018D4`0<3P/04A<@00h@3@000@004Q@A00`>2`804Q@A0`0A4a003@0@4Pl04Q8@00`<2P0@
40h051@B01<C4@0B4Q004A4?000000051@<0410>01LG5@0A4@l01P0>40d01`0;3@X03@l<00lA3P0C
5A804Q@A014C400@4Pl00P0>40d3010B3`0=01TK600D5Q<05aTF01@F4`0B51402`d800h@2P0I71D0
5QTB01XM5P0F6A804QD>00lB2`0200hA2P0900lB2`0@4``04Q@>01LI500H6QD04aD@01@F4@0F61<0
4Q@?0080418=00P04A<>018D3`0B50l04aD@00lA300=3`X04Q@?01HH4`804Q@?00/01@L201XL5`0E
5a80418=01/M600=5@l02aP?030m=00E81D04a/@00lE2@0201HI3P0C01@G3P0E610041D>01<H4`0C
5A005QTB01TL5@0E61404aH?01HI4P0C5Pl051L@01DH4@0F6A805aXC01HI4P0<3PT051HA01dO6P02
01HH4`0>01DG4P0H6QD05aTD01LI500F61<05aTD01PJ5@0E6Q@051TC01<H4P0D6A<05AXD01@I4`0E
6Q@201TN600?01PM5`0J7aT05a`F01HL600<5A007RLR01`U800=5Q408BXU020Y901:Ddh07BHQ030i
=00U;RT04Q/F00807BLO00L072HN01/U7@0J91`06R@L01/U7@0P:R808B/S008092hV01/06RDO028a
;00O;b`07Rh[06MgM00X>3D0;Cdj020`;@0N;R/07bl/02<c<00U=C808c<`03U8A@0X=c@093@a02dm
>P0X>cT09CPf0312@P0bATD0;D5005ibL`25VY/0BUmP02m3@P0aAD@00P0cAdH0500aAD@0<4A302/o
?P0bATD0=DU803I:B@0eBDP0=TY903=5A@0`@T80<TA403I8BP0fBT/0=DU:03iAE@0oE5T0D6EZ03Y?
E01?If/0?UIJ0`1<H6L0601:GVD0AEUP04QLH`17Ff80AUYQ04eQJ01;GfH0Ae]R04]PHP1=Hf00B5iL
04AJF013FEL0AEYK04YOH@1BIfX0E6U^059WK01FJg00F6ac05EZL01DJFh0EV]`05Y_M080G75f0P1M
LWL01@1UNWl0H7Ej05mdN@1VNh00HgMk0080HGAh00L0Ig]m06EiNP1TN7T0J7al06QlN`1]PGl0Kh>1
0080Jgmm01@0KGej07J7P@1_P7X0MXJ306IfL`1XN7L0K7al07>3P`1eQHD0LX6407J5R01gQhP0MhN6
07R8Q@1iRHH0MXJ307>3P01dQ840O8b907j>R`80MXJ300X0Pi>@08JFT`1nSXh0PI6A07f=S01iRHP0
O8b;07Z:Q`1kRhP0N8R50P1kS8H08`1dQGl0MhR208NGU01cPh80JGUh07R8R027UiL0OHf<06moOP1^
OgT0IWM]05maI@1KKEh0Fg1M051UDP1<HU00GgAS05i^H@12DDL0?T]2045>A`0fA3h0<T<m049BC`1E
JF@0D6EP04aQF01=HeL0F6iR03iDB01>I5P0B5iB04eSE`14FTh0?eE90080@EM;00P0?UA803E9?@0_
@cL0<dLk02i2=`0[?380<T<i02Lf;`808C0[0100:3@b02`h=P0/>3P0:S@g03m:CP0mBdh0;Sdn02do
?`0eB4H0<4=002Hf<`0T=340:3@b02<];00O:RH082dS0P0K:1h05@0T<BP0:cP_02`i<00[>34082`X
02Hb;P0M:BL0;SXh020/:00U;RX082TV028[9`0R:bH07RLT024Z9P0U;RT08b`Y02@]:@0Q:RD06R<P
01PO7@0301`R800901/Q7`0J81h06AlM02D[:@0`=S@0:Bl]01TO7@0G7A/06R0M00805a`H00@06b0L
01PM6@0H7AT061dI0`0F6aL01`0J7a/06b0L01DJ5P0O92004aPD01PM6@0L8Ad00P0P9B403`0K81`0
51TE01`Q7@0J7a/03a@@01@E400@4@`04a@?01PI500F5a806AXE020Q700I6QD061TD01HG4P02024R
7@0<01DD400C4Ph05A@@01@C3`0@3`/05A@@01@C3`0G5Q8061LC014@300>3@T04A0<1P0C4Q0201@C
4@06014@3P0=30X0<c8`014@3P0B4@l04A0>0P0@3`d02P0A40h04Q4?00h=2`0A40h04a8@018A3`0?
3P`030/901LC4P0:1PD201DA400K00P40`0A3@`040`;01<?3P0D40l06QHE010<2`0C3`h06QHE01HB
4@0810<061@C00`8200D40l04Ph=01/G5P0?2`X01P<201HB4@0B3Pd03@T801<?3P0B3Pd04`l>00X6
1@0A3@`03PX900804@d<0P0=2@P0200?2`X020D301TE4P08104020D3020L6@0300004@d:0`0@30T2
00l;20804Ph=0P0?2`X0200>2PT02PH5018>3@0G4a802@D401lK6P0n>ST030P72`0=2@P200h:2@80
3@T80P0<20L01`0>2PT030P7010<2`0;1`H03@T801@@3`0?2PX00P0A2`/01@0?2@T03@L700h8200>
20P03`T900804P`<00H03PP800d71`0@1`L04@L601081P0>2@H300d91P0G00h:1`0@2`P04@T70108
1P0C2@P05@`=00h8200D3Ph01@00018<300?2@T03PP800`61P0=1`L030H600X4100B30`04P`>00D0
0@0:10H03PP:010:300<1PP01P0=1`T01`0<1PX03@L;00h8300>20`03@L;00`62P0>20`00P0<1PX0
100>20`03`T=00`62P0;00H201@93`0501052`0K41H02@0400l42P0@1@/00P0A1P`00`0@1@/03`@:
ooooo`0Cooooo`006oooool0200<4A@03A4D00`@4`0:3Q403Q0D01<D600<3A403PhC0P0@3a@08@0C
4QL05aHK04Q8BP0B4Q@02PX<018B500;2`d04Q8D01@D5P0:2P`030`>014A4`0>3Q0030d?01DL7P0@
6A/05b0R03Lo@@0@5aX0314D00hA5@092a00418G00/;400:2@h03a0C00hC4@0=4Ph01@X6014C4006
1`@05ADC00h>3002010?3@0:018>3@0A30`04@d<00d=2@082@@03a0;014B3@0@4@`08R<N01`M6080
2``700<03Pl:01@E400<3@T00P0<3@P0100?40/0414<00h?2P0=3PT500h?2P0C010A300>3`X00P<0
01@E400e=S40414<018C3P082@@04Q<>038c;P0@4@`03a0;00/<1`0>3`X03a0;00h?2P0=3PT03Pl:
00l@2`0200h?2P<03a0;00T0414<01@E400;30L04A8=01<D3`0?40/04Q<>010A300>3`X00P0?40/0
0`0>3`X03Ph<00h>300400h>300900`<2P0@40h03`l=00l?3@0B4Q004A4?00T;200H6QL04A<@0080
3a4>00@03@l<00lA3P0?4@h03a4>0`0>40d200lA400<00h@3`0=3`h03a4@00lA400=3`h03a4@01<E
500A4a802`d<00h@3`0D5QD0418A0P0=3`h0100A4a8051HE00h@3`0>40l200`>3@0800h@3`0A4a80
3a4>01@F4`0i>cP04A<@00/=2P0D5Q<600lA3P0500/;2@0D51803Ph<00h>300E5A<00P0A4@l01@0/
;2X0<S8`010@3P0=3@/05QHD00H0418?0`0A4a001P0@4Pl03a4>00lA3P0@4Pl03@l<00h@3@804A<@
01D0418?00lA3P0=3``03Q0=014C400@4Pl0418=01DH4P0J7AH051L@01HI4P0C5Pl041<<018E3P0@
4``03a8;014D3@0B5@h041<=01<E400E5a800P0A4`h01@0B50l0418=00lA300@4Pd04Q@?00804aD@
00D04Q@?010B3@0@4Pd04aD@01@F4@02018D3`0K01@F4@0O8A`061XE01LI500:30L051lH02Lg;@0J
:R002aL<018L4@0=5@P05Q/@01@H3@0E6A005a`D014H400B61<04QLA01DH4@0H6a@06A`E01PK500G
6Q<061/D01HI4P0E614061/D00806A`E00L06adH00lA300H6QD051HA01DG4P0I6aH061XE00805aTD
00<05QPC01LI500H6QD00P0F6aD201@I4`0301DJ500I7QP05AXD00806AhH00l061dG01XO6@0F71H0
3Q@@01dV8@0G81/04a`G01TR7@0F7aX07RLR02/d;`0N9b80>T<n010I500Q:RD01P0N:200>00L9Qh0
8B/S024[8`0S;BD09c4Y028]9`0O;RX08c<a05EUH`38emH0AEEC028b<00V=S@09CDc02@d<P0U=C<0
9cLe02Ph=P0^?CX0;C`i02dm>P0_?c`0:Sdk02Lj>00]?cl0:Shm02e1@00^@T<0=da=0397B00`A4<0
<TI503M;BP0eBDP0<TI503A8A`0^@T40=4Q703I:B@0dB4L0<TI50355A00eAdL0<dE603E7B00kCDl0
>dmA03Y>D014Ee/0@eQM03mDF@1SN7d0^=3D06Z2QP1=HFP0B5aS0P15FF005019GF@0Cf=Z04iRJ@1<
H6L0D6A[04eQJ01;GfH0CfEV04iTH@18GU`0@eUG04MMF`1<HF80D6EW05=XJ`1DJFh0DfQ]05Q]L`1I
KG@0F6ab0P1HKG80701LLGH0GgAi05icN01MLWL0G75f05U^L`1VNh00GgAi05U^L`1XO800HWEi06=f
NP1ZOX00Ig]l06]oP01^PX80I7Qg06IjN01XO7X0IGUg06QkN01[O7H0L81j06inN01dQ800JGUe06Uh
MP1_OWh207F4Q00407R6R@20Si80O8^=07^:R@80O8b900<0N8N407F4P@1eQ8400P1gQX<0C@1kRhP0
PY6>08:ASP1lRhP0QIBD08VHV@22TI00NhZ9082?S`1nSHX0OHf:07V8Q@1mSHP0O8b707F5O`1lS8L0
Nh^:0761P01aPH40Y;Bd0<?Cd`1lS8/0M8B306n0N@1YNW00IGM[05i`H01DJEH0DfQF04iTDP1DJEX0
E6AI04=AB@0kAd<0FVIS05=PG`17EeH0CUiN05Q[JP1>Heh0AU]B04ILC`1@IUT0Aee@04mUF01;HE@0
Bf5E04EKC`10ETT0?UA703Y@A00fC3l0AEU=03a@A00cAc/0:Sdb02Df;00T=B/093</02@c;P0R<B`0
9C4_02Xf=@0^>SX0;CHj03E0A00a?d80:STi02m2@00gBTL0;d8n02Lg=00U=C808bl]020Z:@0Q;2P0
82dS00808c0V00h0:CH/02Pe;00Q;RD06BHO01TU8@0Q;BT082`Z02Hb<@0T<2h09c0Z024Z900Q:b@0
72HO01dV80<082XS00L07bTR01/U7P0I8Q`06R8N01lU8`0N92806R0N0080728P00`05Q`J01`R800U
:bT08BLU01HL6P0G7A/0724N01PM6@0G71P06QlK01LL600F6aL301TN6P0P01LL600E6QH05a`H01HK
5P0L8A`04aPC00lD3`0J7aX05AXE00`A300D6A@05a`G01TN6@0>4`h09R/V03<d;`0R8ah05QLB01TJ
5@0E5Q404a@?01XK5P0F5a8051D@018C3P0O81/07AhI01<B3P0B4@d05aHB01HE4@0A40`2018A3@05
01@C3`0F5A404Q4=010?2`0A40`01P0C4Q001@0?3P`03Pd;01PG5@0B4@l04a8@00804Q4?00L04A0>
010?3@0@3`d04A0>018A3`0@3`d04A0>008040l=00/03`h<00h=2`0?2`X0510?014=300@30/04`l>
018>3@0@30/04@d<00h:2@0201<?3P0602<O7P2ETI0081`K01DA400:1PH05a<B0P0?2`X060091PD0
510?00l;2P0>2PT030P800l;2P0F4Q403PX901@@3`1BCTd0>cLf01<?3P0?2`X03PX9014=300@30/0
3`/:00l;2@0=2PP030P5010<2@0;1`H05a<@010<2@<03`/80P0>2PL00`0A3@`04Ph=00l;2P0200l;
2P802`L600<04@d<01DA400:1PD00P0@30/500h:2@803@T80`0>2PT04P0=2@P03PX900h:2@0=2@P0
3PX9010<2`0>2PT030P700l;2P0<20L02`L600`81`0;1`H04@`;01<=3@0B30`03`T900d71`<03PP8
02803`T900d71`0;1@D03`T901<:2P0C20L04@P600h91P0>2@D030T500d91@0<2@D03PT501491P0B
20L04`P700d51@0>20P04P`<00X4100D3Ph03PP800l92@0>20P040X:00h8200=1`L06A<C020J700B
30h03`T;00X51P0;1@L040X<1P0=1`T01`0<1PX03@L;00h8300>20`03@L;00`62P0=1`/00P0<1PX0
2P0>20`03`T=00d72`0B1`d040H;0146300I3Q@0:QlU00X11@0?10X401052`0300l42_oooooooooo
01;ooooo000Kooooo`0B00lB5`0?4QH0310C00/?4P0?4AD04a@H018C5`0B4QL040lD00d<4@0>3A80
40lD01LG6@0B4Q@020P:00X:300A4A<03Ph@0P0@4180300<30h04A4C014A4`092Ph04ALK00082`03
2`h03ADH00052@0;41<03A0D00<72P803@hB02003PdB00`=3`0Z;b`09b`X0043000@4Pl02`d:00X:
200?3`d040l=014@3P0B3`h04Ph=014=300@4@d0410>01PJ5@1LGEX05QHD00H80`0B4a0010@200X<
1`0@4@d05QHD00l@2`0>3`X03@h900h?2P0?40/03Pl:00`=20803@h902@03Pl:00l@2`0?40/0414<
00P9100G5aD030d801`M600=3PT01`P501lP6`041@003Pl900`=1`031000414;00/<1P0<3@P02P/6
00T:100;30L03Pl:00h?2@0=3PT030d800h?2@0@4@`03a0;00X;1P0E5Q403Pl:00T:1@0:2`H04a@?
014B3@0?40/3010A30H03Ph<00`03`l=00/;2@0>3P`0410>00d=2`0>3P`05aTF00D7100?4@h051HC
00h@3@0<3P/300lA3P0=00h@3@0=3``03@l<010B4@0?4A003@l>00`>3@0>40l0418A00d?3P0F61L0
8B<R01/M700200d?3P0B00lA400>40l0418A01@F5@0E5aH0418A01HH5`0:30/04Q@C01@F5@0=3`h0
4aDD01DG50082PL08bDR00T;200M7a`01PP51@0A4a002P0B51403a4>02PZ9`0E5a@01`T6014C400>
40d03@l<00P:1`0D5Q<2014C400300lA3P0A4a004A<@00@04A<@00T03Q0=00lA3P0>40d03a4>014C
400C5A804A<@00d?300?4@h00P0C5A800`0A4a00418?01DG5002010B3`0400lA3P0F61<08bDO01dP
6@8041<<0P0A50d01`0>4@X041<<014D3@0A50d041<<014D3P0A4`h00P0>40/00`0D5Q404Q@?00lA
3008014C3P80418=00h04Q@?01XL5`072@@05aTD00h@2`0F61<03a4<014K4`1=GE<07BXP01@P5@0Z
=2T06R8G01<J3P8041H<01H04aT@00lF3P0A614041D?014D3@0D5a006A`E01XM5P0E614051L@014D
3@0B5@h06A`E01hQ6P0Q91d0418=01@F4@0o@C`0:bdX01@F4@0K7AP061XE0P0G6A@02`0F61<05aTD
01LJ5@0D6A<05AXD01HK5@0E6Q@051TC01DJ500D6A<05a`F008051TC00h06AhH01XP6P0M91d03aTA
01hX800O:B408bdU04UBC@0K91l05b0K01TR7@0R:bH06R@O02D^:@807RPP02X07bTQ020Z8P0P:b<0
82/S01lZ8P0W<RX08RdU01lZ8P0Y=2`0=44j01TX8`0Q<Bh0830]05UYIP0`@3h07Rh]02Hf=@0W=cH0
9CDd028b<@0T=3<09cLf02`l>@0U=C80:C`h03Y<B00cAT@09STg02/m?@0^@T409c/j02e1@00_A4D0
<dU703E9B00`A4<0<dM60314@`0^@T40<dM602e1@00bATD203=7AP0S0355A00bATD0<4A403I8BP0e
BDX0=4M903U<D00mD5@0?4mC03Y?E01NLgP0CV=X08NOX`1EKG40B61T04=GGP14FEh0C65W04eQJ01=
HFL0CfAY055UK01?HfT0AU]P04QLH`1=HVD0B5iL04EKF@14FUT0BUmP055VI`1FJfh0F6e`05Q]LP1G
K7800P1LL7L0:01JKg@0GG9g05ebM`1MLWL0H7Ej06AiOP1SN7d0Igb105aaMP1dRHh0MX^@05e`MP1W
Ngl0I7Qi06IjN`1]P7l0JG]k07B4Q01lS8/0KWim06QkM`1TMg<0GW9`05icK`1SM6h0JWUb06MfL@1_
OWT0OXf807F4P@1aOgl0MH>307B2P`1lRXd0R9JI082>T01jR8P0O8^807f<R@1jRHH207R7Q00[07N6
P`1dPh00O8^807j=RP1hQh@0PY2?08ZHV@2@WYl0QYBE07j<S024TY80PY2?07j=RP1iR8D0OXf907f<
Q`1eQ7l0Ohj;0;o?cP21TI00JWYj07j>SP27UiL0OHf<07^;R01_P7T0IWM]06IhK01NL680DfEE04eR
D@1BIeH0?e53041BAP1CHUX0AEA=04MFD@1MK6X0GFe/05MZJ01EJFL0BUmJ051XF`0204YRE00m05A/
G`1?IeX0D6IJ04]QE@19Ge<0@UQ<03eCAP0eBch0<DLj03iCA00gBCd0:3X^02Hh;00/?C<09cP`01l^
:00U=2l08c8_020/:`0V<S80;3Li02Pc=P0Y=cX0:3Hg02Hf=@0[?SX0<4<o02m2?P0Y>CH0:3Ld020]
:`0O:BP09C0/02Db:@0X=B`07b`S01`Y800P;B@07b`U01PU7P0N:RH08bl[02Da;`0K9bD08Rh/02Pa
:`0R:bH082TS01PR6P0L9B007bPR01/U7@0N9b8072HO01XT700M9R4082PT028X9P0N92805A/I01PN
700201TO7@0^01XP7P0H7Q`05adK01PN700I7ad05adJ01HL600J7a/06AhJ018G4`0F6aL07R<O01LL
600C61@05a`H01PM6@0F6aL05Q/F01@I4`0G71H07B8L01hS7@0G71H06AhH01@I4`0?50h07B8L00dB
300W;2H0=cTd01dO6P0<3PT05aPC01PI500G61<0414<01@E400E5Q402P/601@E400F5a8051<?01DA
3P0E510051<?00l>2P804Q4=00D04a8>01@C3`0E510051<?01@@3@0601<B4008018A3`0F5A<01PD3
010?3@0G5Q@030/9018A3`0A40h2010?3@04014@3P0B4@l04A0>010?3@<03Pd;00D03`h<018>3@0<
20L03PX9018>3@02010?3@0U00P61`0B4@l05A4@01LC4P0B3Pd08AdL01lK6P0=2@P030P700H20@0>
2PT040`;01HB4@0>2PT04@d<00l;2P0D40l03PX9010<2`0C3`h03@T804E1@03kmoH0i>3O02<O7P0@
30/02`L600l;2P0@30/03@T8010<2@0C3``05a<@00/71P0O6aP0100000d91P0300`81@802`L400<0
40`;014=300>2PT00P0?2`X01@0<20L03PX900T510091@@0510?00802PH51@0>2PT05`0=2@P030P7
00h:2@0?2`X03PX900`81`0>2PT03@T800`81`0?2`X04Ph=014=300>2PT0510?00X61@0=2@P030P7
00@0000D3`l04`d=018<300?2@T03@L700803PP801L030H600d71`0B30`04@/;00d71`0?1@D04PP6
01481P0>2@H03@P400`91@0;1`@02PL200`70`0@20H04PP601471P0<0`@04P`>014;2`0400002`H3
00`71002010;1`08014<2@0;1@D01@0000/51`0G4A<01`4300P210090`D200/51`H03@L900L030H:
00d72`0>20`03PP<00d72`0<1PX03@L;008030H:00/03PP<00l93@0=1`/03`@:0146300900@04PL=
00d4200B1`d03P<900l42P0201052`0300l42P0>0`Wooooo01?ooooo000Kooooo`0801LG7`0A4QP0
2``A00l@5@0C51T02P/@00h?4`0>3a8300h?4@0900d>400?3Q<030/@01TH7@0;2Pl07QdR00l>4`0H
5a`00`8700803`hC00<03PdB018A5P0@4AH00P0A4QH01@0@4AD03PlC00`=3`0O82<06AXL00802`/=
00P04Q8D00`<301;CDX09RPU0041000@40h04Q8@010@3P804A4?01004a<A00h=2`081`D06QXH01HI
5P051`H01P/704Y=B`0620L041DA00X=2`0I6aX06QlK00P;2@0@4Q402``90P0?3`d0400<30X02PX8
00`<2P0>3P`0410>00d=2`0;2`T06ATG01DE4`0?3`d01`L5034a<@0A4@l00P8001hO6P0;30L200h?
2@0d00l@2@0@4@T0414900`=1@0G61002``600l@2@0?40P05aPB00h?200:2`<02P/500d>1`0@4@T0
3a0:00/<1P0=3PT04Q<>00/<1`092PD04Q<>01HG4P092PD04A8=01@E400720<0414<00/;2@0A4@l0
3`l=00T91`0<30X04A4?00/;2@092@L09bLU00`<2P092@L04Q8@00h@3`0C5A@02`d<01@F5@0F61L0
2`d<00lA400>40l03@l>00h@3`0?4A004Q@C010@3P803`l=00D03Ph<00l?3@0@40h03`l=010@3P02
00l?3@0;018B400E5a@04Q@C00/?3P0J7Qd01PX900hB4@0<40l03A4@010D4`0A5A@00`0?4a806@0<
3P/04A<@00d?300<3P/061XG00/=2P092`P04Q@A010B3`0D5Q<0=SPe01LI5P083@T0>Slk00@91@0:
3`/06QlK01DJ5P0?51004QLC00D:1P0<4@d00PL301@I5@0D5Q<00P0>40d0100B514061XG00`>2`0@
4Pl200lA3P0G010B3`0A4a004Q@A00`>2@0;3@P04A<>018D3`0?4@`0418=00/=200B50l030h900h@
2`0G6A@03Q0;01dO6P0W:B@092HQ01DG4P0?4@`04Q@?014C3P0B50l00P0D5Q401@0B50l04A<>018D
3`0B50l04A<>00804Q@?02805aTD01DG4P0=3`X03Q0;02<U800@4Pd03a4;01<F3`0D5a004aH?018E
3P0C5Pl05APA00hA2P0N8AX05APA01TL5@072P<05adE00/E300=50`041L?01LN5P0F6a@03A8:010E
3P0I7QL061dF01<H4@0A5Pl041D?01@I4`0C61803a@>0P0B5a40>`0<4@/082DO00dB300G71H0=S/e
07YoN@0n@cl07R<O01`Q7@0F6aL051TE018G4`0?51004QLC01DJ5P0Q9R804QLC01XO6`0E6Q@05QdF
01DL5@0G7QL06R4J01LN5`0E71D04aXC01TP6@0F7AH07bHO01PO600I81P06R4I01@K4`0B71<06B<J
01TS6`0A71@05R4I01/V7P0L9b406RHO01PS7@0M:2006bHN01XU7@0L9al07BTP01`Y800I9Qd08c4X
01l_9@0K:b40=DDk05a/HP0O<2P07S4[024d;P0P<bd08SD`0080;D0l07<083<`02Hi=`0S=S@0:3/i
02`o?@0V>CL09CPf02Hj>00[?S`0:clm02Xn?00X?3X0;D4o02a0?P0]@Cl0;d=202e1@00_@D40=TQ8
03Q:BP0cADD0;d510394A00cADD0>4Y:03E7A`0fB4P0;T100314@`0hC4h0>4]?03I;CP0mDE@0=da?
03aAE00iCU40B5eP04aQI019GV40B5eP04UQH`16Gf40AEeQ045IF`1<I6L0CFEY04]QI@1;H6<0BEaR
04YMHP1;GV80BeiT04QLH016Feh0AEYM04YOHP1>HfH0D6EX05EZK`1NLgP0FVmd06AiOP1WO840GgAi
06AkO`1JLW@0FG5c06=iO01SN7/0L8F805mcMP1NLGD0HGAh06YmP@1TMg/0HgEi06QmOP1VO7T0KX:0
06YkN01bOWX0Mh9n09NPV`1cOWP0KWag06ioN@1TNG@0IGag06f0NP1YNW@0K7eg07>3P01bPWl0L81o
06moO`20T900L7n207b;SP1gQXT0Pi:F07Z:Q`1kS8H0N8V306n0NP1^OgT0MXJ307V9QP1fQX<0Nh^:
082@S`1lS8/0P92?086AT@21T9<0PI6B0080PI6A03/0PI6@07n?SP1nSX/0NHV607B4P@1gQh@0OHf:
0:bl^`1nSXd0NHV807n?SP1bPX00Lh>007B4P@1^OgT0MHIn05a]I@1?H5H0GFmS05EWE`1BIE80BE];
04EGA`13EDP0>Ta004mPEP1FJV00G71W05U^I`1BIf40Bf9J04QSE01;IUL0BfEH04]UFP1<IUd0D6MQ
059YH`11F500@UU?04EKC`0hCT40?55203Q:?P0hB3d0>d]002<c:@0T<b`07RdV02<b;P0U=3409cDe
01TW9`0S<C80:cTj02dm?@0/?3`08S8a01lb<00202Lg=00702Ti=P0X=c809SD`024`:`0M:BD06bLS
02Db:`0202<`:@0Y024^9`0O;2D082`X01DQ7@0^>SH05B4M020/:00M:BD062@P01/T800K924072DQ
020Y900U;R/08b`X01TR7@0H8Ah06B8N01@M600I8Ql082PU018H5P0L8R008BLU01dS8@0N92807B<Q
02<Y9`0L8R007B<Q01hT8P0H7Q`05Q`I01DN6@0J81`061hJ01dS7`0R:2@06AlK01TN6P0J71T00P0I
6aP09P0J71T071hK01@F4`0F61D07R0M00lA3P0H6QL06Q`I01@F4`0?4@h06A/H00T;200C5a<061dI
00/@300C61@06A/H00/=2P0F61D0418?018D4@0F5Q@05aLE01DE4`0D4a007ATF010;1`0A3P/07A`G
01@C3P0H6A<04a@>010A2`0C4Pd05a@?01@A300G4Ph05a<B0P0?3P`01@0E51804Q4?00h=2`0H5aD0
4Q4?00803`h<0P0B4@l02P0F4Q40510?018>3@0A3@`04`l>01@@3`0C3`h04Ph=010<2`0?2`X200h:
2@0B01@?300F4@h020@3010?3@0<30`02`/;00l?4@0D51@03@`:01DA400D3``03@P501XF5@0C3`h0
510?01HB4@0?2`X03@T80`0>2PT03`0?2`X04@d<014=300@30/02`L601HB4@0T81l0T8b;09:>S@0G
4a803`/:00d9200>2PT04@d<018>3@0200l:1`04010;200A30T04@`9014<2@H03PT60`0?2PL02@0A
30T04Pd:018=2P0B3@X040/800/60`0<1`@03PT600d81@0500d91P0500h:1`0@30T040`9014=2P0?
2`P00P0=2@H01P0D3``020<001D@3@2h/k00DDa900l:1`D030L400<03@P600h8200>20P0100>20P2
00d71`0L00h8200?2@T03`T900/51@0F3P`03PT701D?3`0400003`X900d71`0=20D03@P600d71`0?
1`D03`H700T31`0A2`l030L600@0000D40L03PX400/7000?2`003`/501<>2`0>20X030H:00h82P80
3@L900`030H800d72@0>20X0>38d02dW:@0H4Q@02P@600T31@0<1PP02P@600d72@0?2@/200`62007
00d72@0<1PP02P@600/51`0>20X03`T;00/51`0200h32@0801H;4@070080>2dc00`11`0A1P`04`P>
01873@0?10X200d221Cooooo000Kooooo`0800/;4`0A4AT03PhF00d>4`0?41D02``A00h?4`0>3a82
00l@4P80414C0P0@3a@0;P0E51T01`H;02TX;@0f=CX02@P=01LF6`0?3Q<05A@I00h=4P0=31402`X@
00h=4P0?3Q<040lD00d=3`0;2`d03`lA018B4P0;2`/03`l?018B4P0=3@d03`l>00X:200B4Q003@d;
01PH5P0=3@/04Q8@00/;2@0:2PP03@d;01HF500^;R`071lN01PK6P0930/04Q@C05=FE@062@P041<B
00L:2@0930/03A0?00`>3@0>3`d200l?3@0A00d=2`0;2`T03@d;010@3P0A4@l03Ph<018B400Q8Al0
71`J00`<2`0D51@0OWin01dM700B4Q0030d:01<D3`0?40X00`0?40P0200?4@H03a4700X;1@0F5a00
4A8;00X;100A4P/03a090P0A4P/01P0?40T03Pl8014B2`0C50l04A8=00l@2`80414<00D03@h900T:
1P0C50l0414<01<D3`02010A300J01HF500>3P`030`:01@D4P0C4a403Ph<014A3`0E5A<0<30^018B
400:2PP04A4?00h@3`0B51<030h=00d?3P0:30/05ALF014C4P0@4Q403a4@00h@3`0?4A00418A010@
3P0A4@l2018B400c014A3`0@40h0410>014A3`0@40h04A4?01<C4@0E5A<05ALF00d@3`0]<2l06ahM
00`?3P0@4a802`h=00d@3`0<3`h02`h=00`?3P0?4Q404Q@A00`>2`0G6AH051HC01<E4P0;3@X051HC
00lA3P0<3P/03a4>02@V8`0B51405Q/G00L<200G7AT03A8>08:7P`0^=3002Pl;01XP70052PH03Q<?
00`B3P052PH0418?01@F4`0C5A803Q0=01<E4P0:30T03a4>00803Q0=00H0418?014C400A4a0051HA
00h@2`0@4Pd2014C3P0<01@F4@0@4Pd04A<>014C3P0?4@`0418=00`>2@0@4Pd051HA01<E400?4@`0
418=0P0C5A000`0?4@`0418=018D3`02018D3`80418=02803a4<010B3@0@4Pd0418=01LI500>40/0
5ALB00T;1P0B50l04aH@01@G400E61404aH?014D3@0B5@h04aH?00hA2P0?4P/04aH?01hQ6P0l?cP0
5QXC01DJ4`0C61405Q/D028W800K81T04QL@010E3P0F6a@05AXC018G400D6A8041D?0P0C6180300D
6A<05a`F01<H4P0G71H03A8<020U7`0X;BL0HFIP0>7Uh012Ad<09b`X01/P70804AHB00h06QlK01LL
600b=c<06b0L01<H500E6QH0724M018I4P0I81T06b8K01HM5P0G7QL06R4J02dd;@805QdF00d06R4J
01/R6`0H7aP05ahF01dU6P0L91T06R@J01`V700G8AP07BPP01TT700H8a/06RLP00807R/T00T06RDN
01/V7`0L9b006bPP01`Y8@0K:2006RXQ01l_9P0M;RD00P0J:b803P0M;RD08SH]01X^9P0K;bL07S4[
01ha;00Q=2l0;3lk02<f<`0Z?C/09STg02Lj>00T=cD09c/i0P0X?3X0:P0W>cT0:Shl02e1?`0dB4H0
<4A202e1?`0aAD<0=4Q60355@`0a@d<0<TA40353@`0^@400<TA403M9B@0fB4P0>Ta<03Q:BP0iBd/0
=4I603]?CP13Ee/0?55D03M<C`0nDeH0?eAG04MLG`24VI`0A5UL041EF017G5l0@eQK04ALGP1:Hf@0
@UaM04=MGP1?IfT0@UYL04mUJ018GF00BEaP04aOH`80CV5U00D0Cf=W04iSJ01>HfP0D6EZ059WK002
05AYKP0S05Y_M01HKG80I7Un06QmPP1TNGh0IWf005eeM`1LM7H0W;>e07F:S@1HKG00JGf006QkO`1W
NWh0IgUm06QjOP1ZO800JGim06QnN`1bQh80Kgih07^4O`2>UHh0/[Na07=jL`1aO7H0L85k06QmN01T
NWH0IGQd0762O01eQX00L81m07:2O`1gQhH00P1hR8P01`1mS8l0M8>607V8R`1nSI40Nh^807f>R01o
T8X00P1nShT02020T8d0PY:?07n?S020T8l0PI6@07b<R`1mSHd0Q9>F0P23TYD01P21TI40P92@082@
T022TY40PI6@07f=RP80MhN402H0NHV607j>S@1aPH00M8B307N7Q01eQH40NXZ60721N`1cQ7d0IGI_
05i_I`1OL6P0D65G05AUE@1EIeD0CF1=04QJBP15F4T0?eA504UMD@1AIUX0EF]O05AYH01>I5/0Af5F
04]VE`19IED0BFEG04]VG@1<IUl0BfAO04eTG`1>IEh0B5mE04mTF`1aQgX0=4Tj0311=P80=DDj01<0
9CD[02/j<`0V=Bh07bh[02Pf=P0S<C40<T11028`<@0O;bl0:CXj02Pk>@0R=C<09CPf0351?P0c@d00
:3Pe02@c;P0P;bX07RdX00807b/W00`082`X02Da;@0T<2`07BTU01XV8P0L:2@07b/W02Hb;P0J9R80
8BdY02di=@0O:bL2020Y9P807bPU02008BXW020Y9P0J8b006R<P01/T8@0G81d06b@Q028Z9`0R:2H0
8BLU01dS8@0P9R@07bDS01hT8P0I7ad051XH01HL6P0I7ad05A/I01@L600A6QD05b0K01TP700D6QH0
6R0L01dS7`0O92007R0M01/M6P0J71T071hK01XL6@806A/H02L05QPE01PJ5`0G6AH06A/H018D4@0P
8Ql07AlL01HH5@0E61D05Q/G01XP700P9B40;C8^00X?2`0F61D04A<@018D4@0E5A<051@B01<C4@0A
40h061<@014<200F4`l05A@?010?2P0?40/05AHA018C3P0D4`h05A8>014>2P0D3`/05Q8A018A3`0F
5A<051<A00l>300@3`d00P0A40h0100C4Q005A@B01<B400?3P`201@@3`804`l>0P0B3Pd00`0C3`h0
4Ph=010<2`0200l;2P0A00l;200>2@H03PX601HE4@0@3Pl0@41101DF600;30h03`l@02l_;@0C3`h0
4`l=01PC3`0=2PT04Pl>01DA400@30/00P0T81l200l;2P0300h:2@0?2`X040`;00804@d<00P02PH5
01DA400<20L09B4P01DA400D40l03`/:00h:2@<03`/:0P0?2PL0100@2`P04@`9014<2@0A30T600h9
1P0400l:1`0A30T04Pd:01<>2`804@`900H030L4010;200@2`P050l<01D@3@0@2`P500d91P0=00`8
1@0=2@H040`9010<2@0=2@H03PX700l;200:1@@04Pd:00h91P1=B4D0:RDR00d81@0500h91P0300h9
1`0>20P03PP800@03PP800<03@L700h8200>20P00P0?2@T01P0B30`02`D5010:2P0400006A<C03La
<@D03@L700h03@L800h8300@2Pd04@`:00l;0`0@30808alB01@A0P0;1`406QH=010;1`0>20P050hB
00h82P803@L9018030H800d72@0>20X04@/=00h82P0:10H02`D700d72@0>20X030H8010:300C3@l0
3@L900/51`0@2P`030H800/51`0<1PP200h82P0:00/51`0900@040D;01L<4P0B1`d0;b@Z01P=4`0?
10X04@H<01<83P804@H<00<04PL=ooooooooool04_ooool001_ooooo00X03PhF00l?5`0821001`P=
00l@5@0A4QL03@hB00h?4P0?4180414C0P0B4aD0600=31403`hC01<B5`0<2a00:bX_04A3B00P7b@0
4a8G02DT:@1JFEh05aHK00@3200@3aD04A0E018A5P0@3a@030`>00X:300@41804a<C010@400A4A40
410@00/;2`80410>00`06ATG00`<2P0?3`d02`/900P81P0@40h051@B00l?3@010@002@T700`>3@01
0`82018D4`080001000?4A003Pl>028T8`0A4a803@l>00T;2P0A4Q4200l?3@0500d=2`0<30X03Ph<
00d=2`0>3P`00P0=3@/02P0B4Q003Ph<00d=300Q8B400P8201hN7@000000=cPc00h?2P0@4@/200l@
200;00d>1P0=3`@04Q<<0042000J6aH030d800H70@0C50l04A8=00l@2P0A4Pd00P0>3`T05@0E5Q40
6Q/F018C3P0>3`X04Q<>01<D3`0;30L04A8=010A30051P<08B8M00d>2@0?40/0Fe]I03Ph=P0C4a40
2@T700<30@0:2PP04a<A00H6100200P81P09014A3`0E5A<030h=00`>3@0>40l05QPG014C4P0[;B`0
4A<B0080418A0`0>40l01`0>3P`0410>01<C4@0C4a404A4?00h>300?3`d00P0>3P`00`0@40h04A4?
010@3P0200h@3`0L02X/:`0N81l03@l>00lA400A4a804Q@C010B4@0?4A004Q@C01LI600;3@X05QPE
00d?300A4a00;S0]00T;200=3``03Q0=01HH5@0B5140418?00`>2`0G71P051TE00X?2`0K81`04aPD
014F4P8041DA00X051TE00P=2@0<4@d05AXF00T;200>40d03a4>00d?300F61D03a4>0P0@4Pl01P0?
4@h04A<@018D4@0B51403a4<00h@2`804Q@?0P0>40/01`0D5Q405ALB01XL5`0H6QD03Q0;010B3@0E
5a800`0B50l01@0A4`h0418=014C3P0>40/03a4<00804A<>0`0B50l04P0A4`h04Q@?018D3`0D5Q40
JfeX01hP6`0<3PX07AlJ014C3P0G6A<04aH?01@G400B5@h03a8;010C300E61405aXC01<F3`8051L@
00T0:B`U00lC300E6Q<02a09018G400Y;RL07b@M01DJ4`0?50d00P0F6a@03`0D6A805a`E01<H4P0D
6A<05AXD01/P6P0O91h05Q/E01`Q6`0O91h02a0:01XO6@0N8ad0EU]E01lT800201LL600B01@I5@0A
5Q804aPD0003000Y;RX061dI01@I5@0F6aL02a0<018I4P0I81T06b8K01DL5@0F7AH06B0I01lV7`0D
6a@06B0I0P0C6Q<04@0H7aL05A`D01/S600K8aP06B<J01XT6`0E7aH082/S01lZ8P0R;BD0934Z01l/
9@0F8a`07BPR020[9@0Q;2H082dV00807b`U07T08C0Y01PX8@0D9Ad06BXR02<d;00W>3008CD/01/_
9`0N<B/08SD_02@g<P0V>CD093Lc020c<00X>cT09STg02i1?`0[?S`09c/i02a0?P0[?cd09c/i02e1
?`0cAdD0=4Q602e1?`0Z?S`0<TI403A8AP0^@T009cTi02@f=P0X>SX0=dU903Y<C00dATH0>4Y:03A6
AP0hBTX0@E=C03]=C@10E5<0?E5E03eBE@0lDE@0@EII03U>D@0mDUD0C65T03aAE016Feh0B5eP03]@
D`0jDU@0B65S05=]KP19Hf@0Bf=U059ZK014Fed0B5eP04YMH@1?HVH0D6=W04mRIP1?HfL0DVM/05]`
M@1HKG80FFic069gO01NLgP0G75f05Y_M01LLGH0EV]`05=XK@1RNG`0KhN905M_L@1aQhX0J7f006=h
N`1ZOX80J7]o06anPP1[OH40KX2406anPP1/Ogl0LHF307:5P@1dPgh0VjBO0=GLe@3Nh]d0O8=l07R3
O@1^OW/0K7mk06n3P@1iS8P0S9fG08RIT`1dQ840MhN407V9R020T900Jg]k08RGVP1fQHP0R9NJ07f<
T01kRhP0Nhb607f>R021TX`0PY>=086ASP22TXl0P92=0080PI6@02L0P92?08:BTP25U9L0QIBG08BC
UP21TI40P92@07n?S`20T8l0PI6@082@S@1kRhP0N8R507N7Q01hR8L0OHf<07R8Q`1cPh00LhAo07>4
OP1ZNgD0QYN@06enMP1VMfl0Gg1X05UZH01>Gdl0EVQE055TD@1<GTh0CV9B051UEP1:GU80CfAH059X
G01AIUd0CVAK04YTF@1>JEX00P17HeD0901<IUd0CFIO04IOF@1IL6X0?EA=04ELDP1KL6L0KhEh02]0
<@0dACX0=4@i02dm<P0Y>Bl0:CPa024`:@0L:bP0;C/k03E3@`1@GUl08c4b02@d=00V=cL09CPf02@g
=@0W>SP0;Shk02lo?00Z>SL09cHa02@c;P0S<Rd09C4]02Hb;P0M:BD08BdY01l[9`807BTU00h072PT
01dY9@0L:2@0<Cdi01dY9@0W<bl07BTU01dV8`0Q:RL08R/X024Z9`0R:bP082TV01`U8P<06b@Q01<0
7BHS01lV900F71X051XH02H/:P0;4@l06AlM03Y0?P0L8R0061hL01XP7P0L8R006AlM01LO6`0C71L0
8R/V02`c;`0G7AT05Q`H00807B8N00D071hK01TK600I6aP06adJ01XL6@0201PJ5`0?01`N6`0N81d0
5ALD00d?300>40d0DUAA038d<@0A4a008BDQ0:jc[`21Qh<04aPD020U8@0C61@0418?00804aDB01h0
51@B01<C4@0A4@l0410>01hJ5`0>2@H09R8O00d<200M7QT04aD@01HH4`0C5A005AD@01LC400C3``0
5A0=01TE500B4@l04A0>018A3`0@3`d05A@B01@C4@0F5A<06aXH01dL6P0J6AL05A@B018>3@0C3`h2
01@@3`04018>3@0?2`X04`l>018>3@<040`;01L040`900L2000H4a001PD101XH6@21PX<05QLI0000
0P0F5QL0DU9@01DA400=2@D0?STe05EAD00A3@`06aLF00<0000?2`X0D4a;010<2`0?2`X03PX900l;
2P02010<2`0701PD4`050@003@T8010<2`0B3Pd04`l>010<2`0200h:2@0300l;2P0=2@P02`L60080
3`X700@040/8014<2@0A30T04@`91P0?2PL00`0@2`P03`X700l:1`03010;2006014<2@0D3``04Pd:
01<>2`0B3@X03PX71@0=2@H0100A3@X061@A01XF4`0F4Pl200l;200600`81@060@004@`900h91P04
00004Pd:1P0>2@H00`0?2@P03`T900h8200200h8200300d71`0>20P03PP800@03PP800H02`D501lI
6@0>20P0618B01@>3P0;1PH600d71`0=010:300>20X03@P500l;0P0J5PX0QX=d06AQDP0J5`P06QH<
00h91@070P002`D700h82P0200d72@0900`6200=1`T03PP:00l92`0>20X040X<014;3@0?2@/02P@6
00802`D700@03@L900h82P0>20X03@L90P0<1PP01P0=1`T03PP:00h82P0<1PP03@8801@93`804@H<
00D030<700X01@0=0PP040D;0146300200l42P0301052ooooooooooo01;ooooo000Kooooo`03014A
6@0B4QX04Q8J00805aPM01@02P/@00`=4@0=3Q403PlA00l@4P0@4A<04A8D018A5P0A41D04Q4F00h=
4P0=31403PdB00X93P0A41D03`lC01LF6`071P/061LL00h=4`803PdB02403`hC010@4P0@41804A4C
010@400>3Ph03`l?010@400?3`l03`l=014A3`0820H04a<A00L71@0?3`d04A4?00h>300:2PP03@d;
00`<2P0F5Q@03@l>018D4`0?4A00418A00P:2@0@4Q409bTX03do?P0@4Q402``;014C4P0:2`X00P0?
3`d0200>3P`03@d;00l?3@0>3P`0410>01<C4@0?3`d03@d;0P0?3`d01P061P@0410>00X:2@0B4Q00
4Q<>010A2`803a0:01003Pl800d>1P0=3PH03@h9014A3P0@40h04A4>00/<200@40h03`l<010@3@0@
40h03@d:00/<200A4@l051@@0P0A4Pd200l@2`0I010A300D5A000`@001LH4`1IFUD09BHQ00l@300L
71X0410>00h>300C4a403@d;018B400=3@/04A4?01HF500?3`d030`:00h>300D5QD04A<B00h@3`0D
5QD02`d<014C4P04010B4@0400lA400>40l03@d;00h>30804A4?00D03`l=00d=2`0C4a404A4?018B
400201@D4P05010@3P0A4a803a4@00X<2`092`X00P0B51<0600>40l03a4@00d?3P0;3@`03Q0?018D
4`0@4Pl030d;00X<2@0B5140:R`Y01<E4P0>40d03@l<010B3`072@H0418?02LY9P0^<bl02a0<00dB
3P0B5a<03A4=014F4P80314=00D04QLC00/@300<4@d03Q<?01LI5P02010B3`0401DG500O8Ah05QPE
018D4@804A<@00T04Q@A01<E4P0D5Q<06adH014C3P0@4Pd03Q0;00d?2P0@4Pd00P0C5A001P082PD0
5ALB00h@2`0E5a804A<>010B3@804Q@?00H03@l:00X<1`0@4Pd0418=018D3`0C5A02010B3@804A<>
0100418=014C3P0A4`h04Q@?018D4@0W:B@0DUA?00h@2`0J71L04A@>01@G400E61404aH?014D3@0B
5@h051L@0P0C5Pl01@0?4P/061/D00X=1`0X;2D04aPA00<051TB01/04aPA00lD3@0@5@h06AhG01/P
6@0F6a@05AXC014F400B5a4051TC01PM5`0L8A/04aPB014F400I7QP0=CXd02@Y8`0F6aD0724K01PM
6@0K81`061dI01`Q7@0G71P05Q/G01LL600Q9R800P0G71P0100H7AT05Q/G01HM5P0H7aP201HM5P0E
01TP6@0E71D05ahG01DL5@0J8AX08RTR03<j<`0K8Q/06b8J01dT6`0H7aL05R0G01`V7P0K9Ad05B0H
01HQ6P0H8ad06RLP01`X8`0K9b<07BPR00808B`V01007BXS01h[900R;bP0<3lh02/k=00S=2`07c0X
01d^9P0N;bL07C0Z024d;P0V>C<08cH`020c;P0U>3@0:chl0P0U>3H02P0Q<c<0;3hn02Tk>`0X?3X0
;D4o02i2@00]@Cl0<DE303I:B00_@d4202i2@080=DU700H0;T9003Y<C01?HF40B5YJ03M9B@0fB4P2
03U;B`110312@P0kCDd0CEmO03i@D00lD4l0?51C03Y?DP0hCE00?U=F03Y?DP10EEP0AEYM04QMH011
EUT0@eQK04UNH@13Fed0A5eO04IPH@1=IfP0Rj>U0;G=c`1>IFL0Bf1S04ePI01?HVH0D6=W04mRIP1>
HVH0DfQ]06AiOP1IKW<0EFY_06=hO@1NLgP0FVmd05ebM`1PMGX0GW=h069gO01PMGT0HGIg069gN01W
O7d0HWMh0765QP1UNGX0J7am06YlOP1]Oh40KX22071oPP1^P840M8R607R:Q`1gQ800NXAn09ZRW02L
Xi`0NX=k07N2O@1fQH80MhV507^>S01dQH<00P1oSh`03P1iRHH0P92=07n?SP1lS8`0QYJF0:jn_P21
T9<0OHb?086@TP20T8d0OXn907f>R01nShT0Oi2:0P21THh03`23Ti00P92?082@S`23Ti80Q9BD08JE
V025U9L0Q9>F08:BTP21TI40P92@07f=S01nSXd0Ohn<07b<R@0207Z:Q`80MXJ303D0L81m06moO01d
QH00LX=m0721N@1[O7@0DfAL06MhKP1@HEL0G6iR04eNCP1AHe00BEa904EGA`1;Gdl0D6EF059VFP1E
JUh0E6YN059WGP1AIel0DFUO04mYG019I5H0BF=G04]UF`1<I5`0AeiG03]BC019GeP0@eQ?03aAB00e
BSh0:clc0352=P0Y>Bh0:3P]02lo=@0Q<2T07B`U028a;P0J:2P07bd]02Hd=@0E8b@0:c/k02Xk>`0Y
?3X0;3lm02Xm>`0V=S<09CDb02Lg=00202Pg<P0C02Dd;`0T<2`08bl[02Da;@0T<2`082`X02@`;00W
<bl08RhZ020/:00W<bl0Ce]G02Te<@0L:2@08BdY01lX9@0S;2T08R/X01hW900201dV8`0301`U8P0K
92406R<P00807RLT00P07bHT02<Y9`0O9B<07R@R02<Y9`1EFeT0GF=Q01/Q7`<061hL01805Q`J01PO
700B6aH06R<N01lV8P0A5a<05A/G01PN6P0E6QH05QPE01DG500G6AH06Q`I01/M6P0A4a005ALD02DW
900J71T201HH5@0;00lA3P0L7Q/02P`901/M6P0U:2D0Jg1/05iTH00J7a/03a@@00`A3@0B51400P0E
5a@07@0E5A<051@B01<C4@0C4Q003`/801`G501FDe005aLB01HG4P0A4`h04Q@?00lA300B4`h05Q<@
01@@3@0F4Pl05A<A00l>300F5A<092<Q024P7P0D4a404A0>010?3@0A40h04a8@01@C4@0A40h04Ph=
00<04`l>00@04@d<010<2`0C3`h04Ph=0P0A3@`05P0B3Pd04Ph;01XE4P0A3@X03Pd900/92P0F5QL0
EeQJ03/l?P0<30d05ADC010<2`0A3@T08A`H03`h=`0=2PT06ADD01PD4`0E4A009B4P014=300@30/2
00h:2@0>00l;2P0@30/030P700h:2@0D40l04`l>00d9200<20L03`/:00d9200>2PT040`;00h:2@0<
20L200l:1`04010;200A30T04@`9014<2@H040/800`04@`900d81@0;1P<030L400l:1`0A30T050l<
018=2P0=20D03PT6014<2@0>2@H500d91P0<00h:1`0?2`P04@d:010<2@0=2@H02`L400`81@0C3P/0
3@P501D@3@0A30T050l<1P0<1`@0100>2@L040X:00l92@0>20P200d71`0300h8200?2@T03PP800<0
3PP800H03`T900h92@0:10@03`T900T4100@2PX600d71`0=00l92@0A30X04`h801XF2`15@CD0jNSH
0=_Ha`1?C3d05A4500`80@0=20<06A<C00h82P0200d72@0400`6200=1`T03PP:00d72@8030H800@0
3@L900h82P0=1`T04@/=0P0<1PP0100F4180618D010:300<1PP200l92`0400h82P0=1`T03@L900`1
1`804@H<00L05P/A00h32@0D2@l04`P>01H;4@0E2Q004PL=008040D;5?ooool001_ooooo00P04a<K
01TI8@0J6R8071dR01TJ7`0<3A8030dA00`=40@03@h@00T04Q4F00l>4`0?3Q<051<H00`;400@3a@0
7A`Q00X93P0510T00P0<2a003@0A41D04Q4G00h=4P0<2a003@`A010@4P0B4Q@02`/=00X:2P0<30`0
3@d=00h>3P0@41000P0B4Q002`0C4a404A4?00/;2@0:2PP01`L500/;2@0<30X04Q8@00d=2`0A4@l0
4A4@00804a<A00X020P601TI5`0H61H05ADC01XJ600f=S@08R8P00h>300B4a403@l<0P0>40d0400=
3``03a4>014C400=3``02`d:00`>2`0>40d03a4>00P91`0K71L07AhI010A30020`001`P300X;1P0=
3PT300d>200;00h?2@0F5a<0BDU900L71`0B4Q8051@D01DE5@0C4a<04A4A010@400>3Ph00P0<30`0
0`0=3PX03a0;010A300200d>2@0K00l@2`0:2`H03a0;01LH4`0B4`h00@8000`=200=3@/02PX800T9
1`0<30X04A4?01LG5@0J6QP04Q8@00@40P0B4Q0061PF01<C4@0=3`h04Q@C00h@3`0D5QD04A<B00lA
400=3`h03Q0?00<0418A00<03a4@010@3P0@40h0100@40h01@0D51804A4?018B400F5Q@051@B0080
3Ph<02403@d;01<C4@0L71X04A4?0000000B4Q004a<A018B400@40h03`l=010@3P0I6aP04A<@01HH
5@0=3``02P`900d?30092`P0418?01PJ5`0<3P/01PP500D710000@0051HC00d?300E5a@030h;00X<
2@0?4@h02P`900L91P0U9b@00P0?4@h01`0B51403Q0=00`>2`0<3P/05QPE00d?300@4Pl00P0?4@h0
200@4Pl04A<@018D4@0L7QT04Q@?014C3P0?4@`03Q0;0P0A4`h01@0o@C`0<S@_04=5@00F61<01`T4
00<04aD@0P0B50l01`0C5A004Q@?010B3@0B50l04aD@018D3`0A4`h00P0@4Pd01`0?4@`0418=010B
3@0H6QD04A<>00X<1`0B50l00P0C5A000`0;3@L03A0900hA2P0200hA2P0400lB2`0C5Pl06A`E014D
3@803a8;00T030l802X^9`0A5Pl08RLP024V7`0:3`P0724J01DJ4`0@5@h00P0G71D0100C61404QL@
010E3`0D6A<201<H4P0E01DJ500C6180724K00lD3P0U:R@010T300`A2`0N8ad061dI01hS7`0?5100
5a`H01HK5`0D6AD041DA01HK5`0m@Sh0<cPd02/`;00D6AD05A`E00806B0I00T05A`E01LN5`0F7AH0
7RDN01@K500F7AH092/T03@k=00J8AX00P0N9Ad07P0H7aL05R0H01hX800N:2005b8L01`W8@0M:280
72PT028^:P0Z=S807BPT020[9`0M:2@06BDQ01`X900T<2`0;chi02@d;`0I:R@062TS01h_:@0S=2h0
8cH`02Lj=@0^@Cd0;D0l02@g=00R=C<0:3/i02Lj>@80:S`l00@0>Ta<03E7A`0Z?S`0;D4o0P0_@d40
D`0]@Cl0;40n0355@`0bAT@0;d=10396A00dB4H0<DE30353@`17FET0?4i>0312@P0kCDd0@E=C03M9
B@0hBTX0B5YJ05=UI@0nD500?U9A03iBEP0kD5<0>4e@041EF00oE5L0AeaO045FF@0oE5L0?U=F04=H
F`14FE`0?EEG04]TI@1LMWL0D6Y[04eUI`1WOh40CF=V04]PH`1;GV80CV5U055TJ01BIFT0DVI[06Un
P`2=XZL0KH:705EZK`1cR8d0KhB905U^L`1NLgP0GgAi05Y_M01RMg`0GgAg06^0P@1PMGH0I7Uj065e
MP1YOGh0JGam06IhNP1/Ngh0N8N:06]jO@1WMWT0Kgn107>6Q01`P7l0MH=o07V4OP2DWIP0PHZ50:2Y
Y01hPgl0NXV6082@S`1kSXd0OXj=086?S`22T900P8j>0080Ohf=00h0PY2@08FCT`1jR8T0NXR907f;
S024TY<0Ohj;08:AS025U8l0PY6<086@R`24Ti00PY6>08FDT@80PY2@00<0RING08ZHV@24TiH00P24
TiH0B023Ti<0PY:B08:BTP1mSH`0OXj=07f=RP1iRHH0MhN407R8Q@1mSHX0NXZ707N7Q01dQGl0L85k
07:3N`1UMVh0KGie06n0MP2IZZ00FV]Q045CA`1:Fd/0AeU603e@?@0oDD40Bem?051UEP1GJel0EV]O
05=YG@1@IE`0D6IM059YG`1=IeX0C6IJ04YTF@1;HUP0BF1F04MNE01@IEh0B5eD03=8?`0Y?C@0=d]0
02i2=`0c@cP0;cld03Q8?@0kBd409C@]0391>P0U=340<Clo02Hd=00R<3408Bl`024a<@0[?3`09STg
02Xm>`0Y?3X09CDb02Hf<`0/?3T0:STd02Pg<P0V=C009S8^02Da;@0T<2`0<3`h02Hb;P807b/W00L0
6bLS01dY9@0S;b/0<Shj02Da;@0I9B407BTU00808R/X01407RLT01TR7`0H8Ah06R<P01/T8@0J8b00
6B8O01lX9@0N9b@05AdJ01/Q7`0S:BL05Q`J028X9P0e>cT0:c4_01`R800401XP7P0801`S800E7QT0
5QlJ01@K5`0E6aL06b4M01LL600E6QH501PJ5`0A01@F4`0F61D06adJ01DG500I6aP0828O00T;200G
6AH06Q`I01TK602CUi<0ADY601`R7P0D6AD05a`H01PM6@0D5Q<00P0C5A8301<C4@0401@C4@0B3Pd0
510?01PF50803`l=01L04QDB01<H500B514051@B01HE4`0C4Q005a<B01DD4P0?3P`051<A01hM6`0K
6QP040l=01<B400A40h040l=014@3P0B4@l03`h<01<?3P0B3Pd04@d<010<2`02014=300J01<?3P0B
3Pd04@d<014=300B3Pd04`l<018=2P0G4Pl02`X600d;30051@H09BHX01TJ700=3Pl05ADC01<?3P0F
4Ph050l;010<2`0P71/0]k>b028N7@0:1PH0AT91014=300@30/300h:2@0=00l;2P0E4A00510?00/7
1P0810@04Ph=00H20@0?2`X03@T800h:2@0@30/03`/:00h:2@0200l:1`04010;200A30T04@`9014<
2@H040/80`0A30T00`0@2`P03`X700l:1`02010;200400d81@0?2PL04@`900h:1`D03@T600d03PX7
00d91P0<20D04@d:01@@3@0@30T03PX700T40@0;1P<03PT601<>2`0;1P<02PD300D03@P500L03`T8
010:2P0?2@T03PP800d71`0<1PH03PP800803`T900T03PP800d71`0=1`L040X:00P20P0M5aL040X:
00l92@0@2PX01P0=1`L03@0<1`@04@`801@?200C3`@0=30T092=OP1gM6D081d>00d9000D40L061<=
00h:200>20P00P0=1`T0200<1PP03@L900h82P0E3a404P`>00h82P0=1`T030H80P0:10H01P090`D0
2P@600h82P0>20X030H800d72@8040X<00X03@L900`6200>20X04PL=0146300>0`T03@8800h32@0<
0@L04`P>0P0E2Q000`0C20h04@H<01873@0Dooooo`006oooool0200>3QH0410H00T94@061``02``A
00`=4P0<3A4030d@0P0<3@l200/<3P0a018A5P0A41D040lD01@C600:2@h04Q4F01DD6@0@3a@030/@
00l>4`0G5Q/03PdB01dL8P0E51T03`hC00`;400>3Q003`lA00`<3P0=3@d03`l?00h>3P0<30`03@d=
014A3`092@L06ATG00P81P0G5aD0410>014A3`0?3`d02PX800h>300;2`T03`l=00/;2@0P81h02`/9
01<C4@0B4Q001PH400T91`0F5Q@06ATG00/;2@0E5A<030d:00d?300200h@3@0B00d?300?4@h05aTF
01<E4P0:30T03Q0=018D4@0?4@h04Q<?00P910061`8051D@01HG4P041@00414<00`=200<3@L03@h8
0P0>3`T03P0`<2d0Ph>301<C4`0=3@d02PX:00d=3@0>3Ph03`l?00h>3P0?3`l0410@00l?3`0?3`d0
3a0;0P0>3`X200d>2@0600P9100=3PT020T500@5000T9B00414<0P0C4a42010@3P0401<C4@0:2PP0
1PH401<C4@805QHD00@03Ph<00/;2@0:30/05ALF0`0?4A00100>40l030h=00d?3P0@4Q42014C4P0G
010B4@0B4Q004A4?014A3`0@40h04A4?018B400A4@l03@d;00h>300B4Q004A4?00X:200W9bD03Ph<
00d=2`0I6AL03Ph<00l?3@0A4@l04a<A018B400?3`d00P0=3@/01@000@005ALD018D4@0620D04A<@
00804Q@A01P03Q0=014C400=3``051HC014C400H6QL03Q0=010B3`0<3P/05ALD00/=2P0=3``06Q`I
03<e<P1GFEH02`d:00h@3@0=3``04A<@010B3`0=3``05aTF014C400>40d200d?300F00h@3@0?4@h0
418?00d?2P0@4Pd061XE01LI500=3`X02`d801XL5`0`<Rd02`d802PZ9@0E5a804Q@?01DG4P0C5A00
418=00d?2P0@4Pd04aD@01@F4@80418=0`0C5A02018D3`06014C3P0B50l04Q@?01<E4002100071hI
0P0A4`h00`0K7AP03Q4;014D3@0201<F3`0=01@G400F6A8041<<01HI4P0=40T05aXC00d@2@0N8AX0
2`l802X_:028SHH0O85j010E3P0201<H4@09010E3P0E6Q<04QL@00lD3@0B5a0051TC01PM5`0G71H0
51TC00805Q/E00T04AH@01/P6P0<4@/07b@N020U7`0B5a404AHB01/P700?51000P0M8Qh201HK5`08
014F4P0Y;RX0314=01TN6P0P9B404aXC01/R6`0M91d201DL5@0a01PO600I81T041L@01LN5`0D6a@0
5ahG01HM5P0J8AT072<K01LN5P0F81P06bDM01XT700E81X08B`V02Ha:`0Q;BT07RXV028^:P0P:bL0
8RdY01hY9@0I9B407RXV02Lc;`0L:bH07blY02Lh<P0/?CL09SLa01TZ900M<2X07S4/02Xm>@0^@Cd0
9CPe01d`;P0W>SP0:3Xi02Xl?00W>CT0<D=302Pj>P0]@Cl0;T9002m3@@0^@T00:3`j02Di=`020396
A080;40n0P0bAT@01@0fB4P0;d5102Pj>P0fB4P0?e5A0080=TQ80400@59B051RHP1CIFD0?U1@045E
E00iCE00?E9E03mDE`16Feh0?U=F049GFP17G5l0@EII04EJG@11EUT0AEYM04iVJ01=IVP0>59C03mI
FP1CJfd0BV9T051WJ@1:Gf80BUeQ04iQI@1CIVX0EFQ/05EYKP1AIV/0I7Un05icN01QMW/0KH:705eb
M`1FJg00GG9g061eNP1MLWL0Igb106MlOP2=XZ<0KH:306AhN@1aQHH0JWio06]nP01[OGl0NXV<092O
XP1eQ8L0IgIi06]jO01/OWh0JGUh07F2P@1gPgl0SYVC08N@R`3<em40OHV607N5Q@20T8l0O8b<0P1m
Rh/02023TI40PHn?07b:RP22T900MhF508fKV`23TI80RYRI0P1lRX/03@1iR8D0P8n:08RGTP25U8l0
PY6<08BCT01mS8T0PY6>08:@T025Ti<0SYbL09:PX@24TiH00P23TYD308>CT`80P92?0500OHf:07N7
Q01eQH80MXJ307:2O`1dQ840NX^507J7P@1_P7T0N8V10721N@1]OWD0BU]A06enM015ET`0BeeA04MH
B012E440>Tdj045C@`1BIUH0FVmP05M[G`1FJel0D6IJ04eRF@1=HeX0D6MO04aVF`1=Ie/0BfEJ04UP
EP17GU@0B5mE03iCBP0mDTT0C65H0355?00bAS`0<44g02De:P0W=b`0<T8g02`l<P0C8Q/0:cXc02<b
;`0c@D405R@T01`Z:`0a?d009CDe02Pi>@0O<S008cHd02Dh=P0V=S<0:SXg02Ti=P0U=2l08C0[01l^
:@0Q;BT08RhZ02Te<@10C4P0=40l028^:P0O:bL07RXV020/:00O:bL062@P028^:P0O:bL072PT01lX
9@0P:BH07BHS01XS80<06b@Q00X06B8O01PQ7P0O:2D07BHS028Y9`0J81h0728P020V900R:2H09R`Z
0P0H7Q`0200G7A/06AlM01XP7P0K8Al05ahK014J5@0G81/05ahJ0P0I7a/0600B61@061dI01/M6P0L
7Q/06Q`I01PJ5`0F61D06A/H01PJ5`0@4Pl05ALD01/M6P0?4@h04Q@A01`N6`0K7AX08bDR0;^o^`1M
HUh04ALC018G4`0J7a/06AhJ018D4@804A<@0P0A4@l0400B4Q004a<A018>3@0T81l04Q4?01`L6P06
20D04QLC01XO6`0F6aL06AXG01XI5`0F5A<06ADD01/J600A40h200T81P0300/:200B4@l04A0>0080
40l=00D04A0>010?3@0<2`T0510?018>3@0200l;2P04014=300B3Pd04Ph=018>3@804@d<01H04`l>
01<?300?2PL05Q4>00/:1P0<2P/04Q8C010A4`082@/030`=014A3`0300004Pd:010;1`0C3`h03``;
02@P7`060P405A4@00L30P0A3@`040`;100>2PT01`091PD05A4@01<?3P0F4Q409b<R00h:2@0@30/0
0P0=2@P2010<2`0400l;2P0?2PL03`X7010;20<04@`91P0@2`P0200A30T05A0=01HA3P0E40d03`X7
00d81@0@2`P04`h;0P0A30T00`0?2PL030P500d91P0400d91P0=010<2@0>2PL02`L4014=2P0D40d0
3PX700l:1`0400004@`900l:1`0@2`P03@P5014<2@0500h91P0700l:200@2PX03`T900h8200=1`L0
30H600h8200200l92@0900h8200=1`L03@L700X4100R71`03`X:014;2`0?2@T03@P800D03@L700h0
3@P601D@300I50h061@<00X6000C3`<08AhA03Lc9`0>2P003`/200d9000F4@/03@P700h820803@L9
00@030H800d72@0>20X02`D70P0:10H0600<1PP03@L900/51`0:10H03PP:014;3@0<1PP02P@600h8
2P0=1`T04@/=010:300=1`T030H800h82P0B1`d03`@:00h32@0;00H05P/A00l42P0=0PP040D;0146
308040D;00<04@H<ooooooooool04_ooool001_ooooo01H04A4I01TI8@0@41P03a0E01@E6P0:2a00
4a@H00d>4@0H6A/00@4301DF60082@/04A0E01<B5`081``030/@04E4B@0Q82D04a8G00`;400?3Q<0
4Q4F0P0>3A804`0@3aD040lD00`;400@3a@01`L900h>400@4180410@00/;2`0@41004Q8B00d=3@0@
40h03Ph=00l?3@0@40h05QHD00@40P0>3P`00P0A4@l00`0?3`d03Ph<00l?3@0200d=2`0700h>300?
3`d03`l=00l?3@0=3@/03Ph<00l?3@02010@3P0=00l@3P082PL0418?00`>2`0C5A803Q0=061RG`1J
G5T06A/H00h@3@082PL0418?00h@2`0400l@2P04010A300?40/03Pl:01DF4@803a0;01004a@?01DE
4`0@41003@d=014A4@0E5AD04Q8B01@D501IFET0Bd];014A4@0E5AD02`/;010A3P0=3PT03Pl:0`0?
40/01P0>3`X03a0;018C3P0B4`h04A8=00l@2`803Ph<00<0410>014A3`0@40h0100@40h0100>3P`0
3`l=014A3`0G6AP201<E500?00h@3`0?4A00418A00d?3P0C5A@03Q0?00lA400I6aX09BLV00l?3@0E
5A<03Ph<014A3`0B4Q004A4?00803`l=0P0>3P`200l?3@803Ph<0P0?3`d2010@3P0=00h>300@40h0
30`:01DE4`0L71X02PX800lA3P0A4a003a4>00h@3@0@4Pl051HC038d<@02014C400400`>2`0>40d0
4A<@00h@3@<03a4>01`0418?014C400B5140418?014C400D5Q<04aDB018D4@0@4Pl03Q0=00`>2`0=
3``03Q0=00d?300B514071hK01@F4`0A4a0051HC00h@3@0A4`h04aD@01@F4@0C5A00418=00h@2`0@
4Pd04Q@?0P0C5A02010B3@80>C/f00@030h901<E400?4@`05ALB0`0B50l201<E4003018D3`0A4`h0
4Q@?00<04aD@00L04Q@?010B3@0@4Pd0418=01DG4P0M7aX06adG00804aH?00H051L@01<F3`0B5@h0
41<<014D3@0C5Pl2014D3@0=01<F3`0H71D07B8K092ESP1dNG8051TB03Hk=00T:B8041D>01<H4@0F
6a@04QL@01@I4P0201<H4P8051TC0P0E6Q@00`0B5a404aPB01DJ500301DJ500>01XO6`0H7AT05a`H
01LL600;40`05a`H01HK5`0K81`06QlK01<H500F6aL061dI02L^9`0N9Ah201XQ6P0601PO600K8Q/0
5A`E01PO600K8Q/06R4J0P0G7QL0300M91d072<L01XQ6P0H8QX06R<M01XS7P0M:28062<N01/V8P0I
9B<06bLU024]:`8082/W02P07bXV01hZ9P0P;2P08BdY01l^:@0L;2L0DfAN01h_:@0O<2X08C8/02@g
<`0P<bl09cXf01ha;`0oDU009CPf02Hh>00]?cl09cTi02/m?`0eAdT0:C/l02Tm>`0^@T00<dM50314
@P0aAD<0>4a:0314@P0aAD<0=4Q603I:B00dB4H0<4A203Q:BP0bA4@0<D=303e?C`0_@D40?e5A0P0k
CDd0E00lCTh0?Dm?04EGE`0gBdX0?E5E049GFP13F5/0@EII04=HF`17G5l0B5eP04UNH@15FUd0AU]N
04aQI01:HV@0BV=T055[K01CKFh0I7an05ifN01;HV@0CF9U051SI`1DIf/0DfIZ05EXK01JKW<0Fg1e
05aaMP1OM7T0H7Ej065fN`1RMg`0HGIk05mdN@1RMg`0IW^006EjO`1TNG/0M8R706j2P@1XO7/0HgMf
06=eM@1bPh<0Lh>307N7Q`1gQXH0K7Yk06]iNP1ZNWX0IgMg06ajNP1fPh80Oh^808:=R01mR880NHF0
07^7Q@1lRXX0OHb<07n>SP21SXl0QI2B08RCU@26TI<0Q8nA08NCT`24T900QI6A08JBTP23Shl0P8b<
086=S025THh0PXj:08B@S027Thl0Q92<08JBT023Shd0RiNE08nKV`80RIFE0340RIFG08NFV@23TYD0
QIBG08NGU`22TY80Pi>C086AT01nSXd0OHf:07R8Q@1_Og`0Lh>007V:Q01gR880MHJ007B5OP1`PGT0
Jgad06MhKP1NKfD0F6UO05=UF@18FTh0A5I8045B@P0oDCh0>D`i04IHB01KKel0EfaM05M[G`1FJel0
EfeQ059WGP1;HEP0DfYR04aSFP1=I5X0CfIL051WG@1ZPGD0IWa`04QNDP0mDTL0>Ti503U:@P0^?cL0
:S/b00809CDZ0180:CT^02<c:@0Q<2T08c8[02He<P0T<S809S@d07N5QP0d@T<0:CTi02dn?P0R=C<0
>4]902Xm>`0^?S/0:c/h02Lg=00X=c8202Lf<@0302Te<@0X=3009c<_00808bl[00H08RhZ01dY9@0I
9B40930/02Da;@0S;b/201l[9`05020/:00N9b@072DR01`U8P0J8b000`0G81d0@`0H8Ah07bPU01`U
8P0J8b007B@R020V900O9B<0728P01PN700I7ad06R0N01LM6`0F71X0728P01hT8P0K8Al05QdJ01@M
600C71L05AdH01LM6@0H7QX05Q`H01TN6P0O8Ah071hK01LI5P0J71T07b4N014C400G6AH05QPE01PJ
5`0Q8b008R@Q01@F4`0E5a@071hK01PJ5`0[;R/0724M01LM6@0C61@04AHB018G4`0D5Q<06adJ02DW
900C4a4071`J010@3P0B4Q004Pl>01<A3`0C4a405AHD00/>2`0@5A403A8>00lD400C5A804a<A014@
3P0E4Q405A@B01@C4@0B4@l00P0?3P`00`0C4Q004A0>014@3P02010?3@803`h<00<04Ph=010<2`0A
3@`00P0D40l00`0@30/03`/:014=3003018>3@0F014=2P0B3@X03`/8018A3@0?3@h0H65R03/l?P0=
3Q003@d>00X:2@0B3Pd04`h<00l:1P0>2PT04@d<010<2`0C3`h05a<B00l;2P0=2@P04Ph=00l;2P80
4Ph=01l030P7010<2`0@30/04Ph=01DA400B3Pd03`/:014=300@30/03`/:014=300B3Pd04`l>02XU
8P0;1P@03@T7010;200C3P/06QDB018=2P0;1P<020<101@?300A30T04`h;00d81@0A30T050l<010;
200<1`@04@`9008040/80P0?2PL03P0>2@H030P501<?300;1`D03@T700h:2@0<20L05Q8?014=2P0@
30T03@T600X60`0<20D03`X70P0>2@H02P0=20D030L4010;200Y92406QDB00X5100?2PL030L400l:
1`0@2`T500l92@0400h8200=1`L03PP800h820803`T900D03PP803D_;`0?2@T040X:018<300600h8
200700h91`0910404Pd700h90`0@30804@d301@@1@0300h:0@0400h:0P0>2@<03PT400d71`D03@L9
1P0<1PP600l92`0601@>4024OX00MFma01H@4P0?2@/03@L90P0A1P`00`0@1@/04PL=00h32@020146
300500l42P0F2a405P/A00l42P0A1P`05?ooool001_ooooo01<04a<K01PH800A4AT0414F01@E6P0>
3a@0414E00`=400A4Q@01`P:00X;3@0<3@l051<H00/:3`0A41D030/@04i=DP0>3A805A@I00802`X?
01/040lD00h=4P0?3Q<030/A018A5P0E51T02`X?00l?4@0@41803@d?00l?3`0<30`03@d=00h>3P0;
2`/03@d;00L71@030`4030`:0000000H61H030`:00l?3@0@40h03`l=010@3P0A4@l00P0>3@T05P0?
3PX040l;010?2`0@3`/04A0<00d<200;2PH030/700h=2@0@4@d03a@@00/@300?51004AHB01lT802b
][<0XJJR02ld<0083@T03A8>014F4P0:30H200l@200F00l@2@0?40X03a0:018C3@0m?ST0820N01PH
5P0?3`d051@B01HF500?3`d030`:010@3P0B4Q00410>00/;2@0R8R00820N00P81P071`D02@T700l@
3080414<0`0?40/300h?2P<03@h90P0>3P`01@0?3`d03Ph<00h>300=3@/04Q8@00805ADC00/030`:
00X:200B4Q000@<201@F5@1HFUT051HE0001000G6AP030h=01hP7`0200`>3@0802d_;P0[;B`03`l=
01LG5@0@40h0000000T91`0G5aD2010@3P803`l=0P0@40h200l>2P8040l;0P0A40`0200;2PH04a8>
00l>2P0=30P04a8>00l@2`0?4@h0418?0`0?4@h01`0@4Pl02`d:00`>2`092`P0418?00h@3@0=3``0
0P0A4@l3010@3P0@00l?3@0B4Q00410>010@3P0B4Q004A4?00l?3@0C5A803Q0=010B3`0B51403Q0=
00/=2P0D5Q<06adJ01<E4P80418?00L030h;01<E400C5A004aD@014C3P0>40/030h900804A<>0P0B
50l04@0A4`h0418=00h@2`0210005QPC014C3P0I6aH030h9010B3@0A4`h04aD@01@F4@0E5a804aD@
00lA300@4Pd04Q@?00804A<>0P0@4Pd01`0A4`h0418=00h@2`0@4Pd05aTC01TL5@0F6A800P0B5@h0
300D5a004aH?00d@2@0?4P/05QTB00d@2@0;3PL04QH?00dB2`0S:24061dF014F3`803a@=00D04QL@
01DJ4`0@5@h05AXC01@I4P0201<H4P8051TC0P0E6Q@201<H4P@051TC00X05AXF01HK5`0G71P0724M
0456@P0J7a/061dI01DJ5P0F6aL06AhJ0P0H7AT0100H7aP051/D01@K500F7AH201<J4`0901HM5P0H
7aP06B0I01LN5`0H7aP06b8K01TP6@0J8AX06b8K00806B8M00L0624L014L600R;BX06B<R024]:`0H
92806RHT00807bTX01T07RPW01hZ:00P;2X082`Z02@c<00U=34062PU02De<P0Y>CH08C4^01lb<00Q
=3808SDc02<f=00^@3l0;Clo02Pj>P0Y>c`0:cdo02`n@00/?T40:S`n02i2@@0aAD<0=TY80080<TI4
04P0>4a:0396A00`A480<TI403I:B00hC4X0=d]902do?`0fB4P0>4Y:03e?C`12E5@0A5IF03I8B00k
CDd0>D];03mAD@0iBd/0=DU8049FF@0oE5L0BEiQ04MLG`10EEP0A5UL04QMH01;H6<0AeaO04QMH01>
HfH0Bf=U04URH`1;IFH0CFMX05I^L01=IFL0BV5S051UJ01BIFT0F6]_05MZKP1HJfl0FVic05U^L`1L
LGH0HGIk06AiOP1WO840J7f206EjO`1TNGh0IW^006MlP@1VNh00Jh2206f1P01]Ogl0MHN706IhN01j
RXX0S9bL0761P@1ePh@0MXB506mmOP1`OWl0M8:407>1PP1ePh@0NhZ807j=RP1oRhL207^7P`0A082=
R`21Shl0Ohf>07b:S@22SI40Q8nC08NBUP26TI<0QI2B08JAT`21SHd0PXj>08>?S@21SH/0P8b:08:>
S028U9000P25THd0H@23Sh/0PHf908ZFU02:UY@0T9bJ096MW@2;UiL0SIVI08jKW02:V9/0QiJI08RG
VP28V9P0QIFE08JFUP22TY40Ohn>07f=RP1iRHH0MXJ307Z:Q`1nShT0NHZ307>4O01`PGT0K7ed06Mh
KP1SM6X0GVmT05U[G`1AHeL0AEM:04AFB012Dd<0@eE2041C@01:G4`0F6aL059WF01=HED0DVMK04aR
EP19GUD0C69J04iUG@1BJF40BF1H04AKD@17G5<0K89f07J<O`0iCD40=DPm03E6?P0a@SX0:3Tc02Df
<00V=R`08S8W024a9P0^?S@07RdV02Lf;`0b@Ch0;cdm01HT900lBT/0@Dm@05YZJP0[?3`07C0^03]>
C00_@T00:SXg0310?@0U=C80:3Lb02Th<`0X=c809S8^02Da;@0Q;BT07b/W020/:00Q;BT07RXV01`X
900T<2`08BdY01l[9`0N:RH06bLS01TU8@0O:2D06b@Q01XS800I8Ql00`0G81d0200K924092dZ020Y
9P0K92406b8P01TO7@0H7Q`06AlM0P0K8Al02P0J81h05A/I018H5P0F71X06R0N01LM6`0G7Q/0624L
01LP6`0G7QX301HL600301LL600I6aP06A/H00806A/H02@06adJ014C400H6QL05aTF01`N6`0T9R<0
7AlL01DG500C5A805aTF01DG500B5A804aPD010F4P0A5Q804aPD01@I5@0E5a@03Q0=01TK600?3`d0
5aLE010@3P0E5A<040h?01`J6`092@T01`T801lS8P0;3P`04QPF00lE4`0C5QD05ADE00T92@0;2@X2
010?3@04014@3P0@3`d04A0>01HE4`804A0>0P0@3`d200l>300801@@3`0E4A004`l>014=300@30/0
4@d<00h:2@0?2`X2010<2`0H00l;2P0>2PL04`h;01@@30081`<00@0002LW:00G61X0BT]=028R8`0E
5A<00`0002@P70070P003PX9010<2`0?2`X040`;018>3@0<20L040`;01@@3`0>2PT030P70`0@30/0
2@0>2PT03`/:018>3@0B3Pd04@d<00`81`0=2@P03PX900l;2P0200h:2@0A01D@3@0<1`@04@`900l:
1`0910402`H300/61@0G4Pl05Q4>00d81P0400001`8000h91P0B3@X05a8?01<>2`0>2@H00`0@2`P2
00l:1`0J00h91P0>2PL07a/H00`81@070`800`00044m>P1eLFh061@A00d91P0<20D04@d:00h:1`0<
1`@03@P500/60`0?2PL04Pd:014<2@0G4Pl0100000`7100k=S<06A@A00D0000;1PD6010:2P0500l9
2@0>20P03PP800h8200=1`L00P0;1@D0100>2@T01`4100X4100=1`L500h8200700h91`0>2@D03PT5
00`70`0C3PP030L101<?1`0300h90`803PT500<03PT600d71`0=1`T0100=1`T600`620H03`T;00`0
2@<509jHVP2MUiT03`T;014<3@0D3Q003`@:0146300D2@l030470146300<0@L2014630805@X@0P0A
1P`Dooooo`006oooool0800821003@dE00X:4P0<3A8051DJ018C60082@d04a@G01LH6P0A4Q@010D7
00l@4P0:2@h030/@01@C600H5a`01`H;01LF6`0=314030/@014@5@0?3Q<030/@00h=4P0:2@l051<H
00l>4`0:2@h06ATK00P82P0?3a40410@0P0>3Ph02@0?3`l0410@00d=2`0G5aD0820N01@D4P0F5Q@0
1@D300d=2`02010@3P803Ph<00@03`l=00h=2@0>3@T03`h:0`0@3`/0;@0B4@d03`h:00d<200<2`L0
3@`800P91@0:3`/03A8>00D:1P0;40`06AhJ05MLF01BEe<05a`H00/@30093PX03Q<?00P;1@0<3@D0
3@h600l@2@0A4P`04Q<=04]<A`2GV9<0=3@b010@3P0;2`T03`l=010@3P0>3`X030`:00h?2`0@4@`0
3Ph<01PI5@0>3`X01PH401HF4`0I6QD04a<A00l@2`0B4`h04A8=010A300200l@2`03014B3@0@4@`0
3a0;00803Pl:02403a0;00l?3@0?3`d0410>00l?3@0>3P`03@d;00h>300B4Q005ADC010@3P0=3@/0
3Ph<00H81`0M7ah07b4P07EgMP0/;Rd01@H500T;2P0@4Q404A<B00X<2`082PT03a4@010@3P0=3@/0
6ATG01LG5@0?3`d030`:014A3`0@40h00P0?3`d0100@40h04A4?00l>2P0?3PX2010?2`804A0<00X0
3Pd901DD400@3`/03@`8018A3@0A4Pd04A4?01LI5P0H6QL04Q@A0P0<3P/020082PL061XG00/=2P0D
5Q<03Q0=00/=2P0B4Q004A4?0P0@40h00`0?3`d03Ph<018B4002010@3P0<014A3`0?3`d03@d;00/=
2P0B51405ALD010B3`0>40d04aDB018D4@0G6AH04Q@A0P0@4Pl01@0=3``03Q0;00lA300@4Pd04A<>
00803a4<1P0A4`h01P0B50l061XE01PJ5@0;3@P06A/F00H80`803a4<00L0418=014C3P0A4`h04A<>
00lA300@4Pd04A<>00<0418=00P04Q@?01DG4P0D5Q40418=00lA300D5Q005QTB01<F3`8041<<00P0
4QD>01PK500B5@h041<<01@G400<3`P05APA02@X8@803A8;00T04aPA02<X8@0G71D04aPA01XO600L
8AX04AH?01TN5`0F6a@00P0C618201@I4`805AXD0P0G71H201HK5@0E01LL5P0H7AL06QlK010E4@0F
6aL08RLS05MLF00Q9R805a`H01@I5@0G71P06AhJ01@I5@0F6aL05A`E01<J4`0E71D06B0I01/R6`0L
8a`05ahG008061lH00l05QdF01PO600N9Ah06B0I01/R6`0M91d06b@O01XS7P0H8A`051lK01TT8@0J
92<05b<Q020/:P0J9R@00`0N:2L07`0N:RP082`Z024]:`0N;BX09cLd00lO700^?S/09SHc01h^:`0D
9bD08cHd02Tl>P0aA4808S@c02@f=P0dATH0;Cm003A6B00gBD/0;Cm202Xl?P0^@T40;d=103=7A@0_
@d40;T9003=7A@0aAD<0;d=10314@P0fBTP00P0jCT`203Y<C00G03I8B00dATH0?e5A03U;B`0nD500
>de=03a>CP0nD500=DM704eQH016FUd0AU]N04QMH016Feh0@5EH03iCEP18GF00Bf1S04QMH01:Gf80
CfAW04aTIP18HF800P1;IFH01@1GKg40CVIX05=YK01AIVT0DfIZ00<0FVea02d0Ffmd05Y_M01LLGH0
H7Ej06AiOP1WO840IGYo069gO01SN7d0IW^006QmPP1YOX<0KH:406YnO@1/OWh0LhF506MiN@1kRh/0
Ri^K07F5Q@1gQHH0N8J707B2P`1fQ8D0NhV;07^9S01mRh`0P8j?082?S01oRhL0NhN307f9Q@22THl0
Q9:C082>S`1jR8/0OhZ>08:=T@29U9P0RIBF08NBU023SY00P8b<086=S@22SX`00P21SH/01P24T8h0
Qi>?08NCS`29UI40Q92<086=R@80RiNE00H0Si^I08fIV@29UID0S9RH08jIV`29UiX208JEV01508JF
UP25UID0QYJF086AT01oShh0OHf:07b<R@1nSX/0PY:?07j?R@1gR840L85i06enMP1ZNg80IWM]06Qi
K`1SMFX0GFmS05AVFP17FD`0AeU904=DA015Ed@0A5M404aNCP1DJ5P0CF9C04UMD@1@IET0B5iB04IK
DP1?IEd0CFAL05A[I@1GKVL0EfiT04eRF@19Ge<0=de003]?@`0kCD80>T]103E6@00]?ST0:CXd01LW
700[>c005bLL028b:00K:R<0;3/d01h]:P0jB4P0<Clo02Pf=`0W=CH08c<c02<d=00O<S00;T4o024d
<P0T=340;cll02<c<00X=c80:CPc02Pg<P0U<Bd08bl[00<07b/W00@08BdY020/:00P;2P08bl[0P0N
:RH01@0P;2P07BTU01XV8P0Q:RL06b@Q00806B8O0P0H8Ah00`0E7Q/051dJ01XS800201XS800801lV
900M8b406R0N01dS8@0P9R@07bDS01/Q7`0H7Q`201LM6`0M01TO7@0K8Al072<P01TR7@0H8A`061lK
01LM6@0H7QX07R@P01lT800K7AX06A/H01XL6@0I6aP05aTF014C400O8Ah0828O01dO700D5Q<04Q@A
01@F4`0C5A805QPE01XL6@0F6QH03a@@00hD400@5A400P0D6AD0500C5A804A<@01TK600B4Q005ADC
010@3P0B4Q0040h?00h<3@0I6QX041@C00T=300H7Q`07B<Q05QNG00I7A`03Q0?01@D500D4Q<04A0>
0P0B4@l200l>3003018A3`0A40h04A0>008040l=0P0?3P`01`0B3Pd05A4@01<?3P0?2`X03PX9018>
3@0A3@`00P0B3Pd2014=300?00l;200B3@X04Pd:01XI5@0G5AH00`<400h?4@1dMGL05aPI01HF500V
8R40HUiJ01TD400D40l040`;00802PH500T03`/:010<2`0C3`h06ADD01HB4@0?2`X04@d<01DA400?
2`X00P0<20L0100>2PT040`;014=300>2PT200d9200<00h:2@0?2`X040`;00P30@0?2PL05A0=014<
2@0?2PL05A0=00l:1`0@2`P03`X70P0B3@X01`0P6aP04@`900d81@0?2PL03@P500l:1`0D3``00P0@
2`P200l:1`0A00h91P091@<0510=00l;200E4@h01P8000<0000R7Q/04@d:00P40@0:1P<04Ph;00l;
20091@802`H300d81@0>2@H00P0B3@X01`0?2PL01`8000h91P0:1@@01000018=2P0F4@l01@0?2@T0
100@2PX03`T900l92@0>20P200d71`0601<=3@0L5QH040X:00T30`0<1PH02`D51P0>20P01P0?2PL0
30L300h91@0H4a003@P4014<20<03PT500@03PT600h91@0>2@H03@L72`0=1`T700h82P0=02hX:P11
>cd040X<020J700U7b404`P>00h32@0A1P`02P0501D:400?10X03P<900l42P020146300300l42P0>
0`Wooooo01?ooooo000Kooooo`0401<C6`0A4AT03@dE00`=4P80414F01T0414E00d>4@082@/04a@F
014B500?41805A@I00l>4`061PX030/@00d<4@0B4AH030/@00h=4P0@3a@03@`A01TH7@0V9BX03PdC
00X93P0D4aP030/@00l?4@0>3Q00410B00803`l?00l030`<00l?3`0D51@03@d;030`;P2XZ:H0:BTW
010@3P0>3P`0410>014A3`0@40h030`:00X:200;2`T00P0>3@T01@0?3PX040l;010?2`0@3`/04Q4=
00804a8>01404A0<00d<200?4@d01``800dB3P0@5A402Pl;01TN6P083@T04aPD00/@300?51001P/7
00hC3`0;3`P03a4600l@2002010A2@08010A2`0T9Al0DE9=018B400=3@`04Q8B010@400=3PX200h?
2@0300h?2P0?40X03Pl:008030d700D04Q<=00/<1`0A4P`061TC010A3002014B3@03010A300?40/0
3a0;0080414<00D03a0;00h?2P0=3PT03@h9010@3P03014A3`0F010@3P0?3`d09BDS01`L6P0?3`d0
3Ph<010@3P0?3`d03@l>00L81`0A4a80:B/Z00X<2`0@4Q404A<B00/=300=3`h04Q@C00d?3P0A4a80
6QXH00P81`804A4@00@03@d;010@3P0A4@l0410>0P0?3`d0100@40h04A4?00l>2P0?3PX2010?2`@0
4A0<01803Pd9010?2`0A40`03@d900/;2@0K7AX07b4N01DG500=3``0418?014C400L7Q/03@l<014C
400?4@h03@l<018B400A4@l3010@3P0800l?3@0B4Q003`l=00l?3@0A4@l0410>00h>300X:RL200X<
2@09010B3`0?4@h03Q0=00lA3P0A4a00418?014C400B51404A<@00<04aD@00@04Q@?014C3P0A4`h0
4Q@?100A4`h03@0B50l04aD@01<E40082PD04Q@?00/=200B50l04aD@018D3`0A4`h0418=00lA300@
4Pd00P0A4`h01@0B50l0418=00lA300?4@`04A<>008051HA00<04Q@?014C3P0B50h00`0B5@h201<F
3`0B01@G400B5@h05APA01LJ4`0@4``07B0I02lc;00>4@d05a`E01TN5`0D6A804aPA01@I4P0N8a`0
7B8K018G400G71D051TB0P0C618201@I4`805AXD00/06AhH01PM5`0G71H05AXD01HK5@0H7AL0724M
014F4P0L8Ad04aPD02P]:@0201@I5@0301LL600I7QX05a`H00805AXF00H06B0I01PO600D6a@05QdF
01/R6`0M91d301TP6@0?01LN5`0H7aP07RDN01/Q7@0M8al07R@P01dV8@0M9R8072DR02@_:`0nBDH0
7BLV01TU9@0N:RX09S8b00<082XY01/082`Z028^;00S;bd07bh[02Dd<@0N;R/0;cll02Hf<`0eAD80
:Sdk02@g=@0Y?3X0AeUI03Q:BP0Z?3`0BeeO0312A00[?Cl0<D=70312AP0bA4H0;d=202i2@00bAT@0
<4A202i2@00aAD<00P0`A480200bAT@0>4a:03Y>C00iCD/0<TA403=5A@0gBDT0>de=0P11De<204mQ
H@0L04=EE@18FUX0C5iN05EYJ01?HfH0C65T04=HF`15FUd0B5eP041EF01=HVD0D6EX04iSIP1@IFP0
E6U/055YJ`1>IfT0CfUZ04]UIP1?IfT0AemQ05AZK@1BIfX0E6M[05a_L`1ML7@0Ffib05eaMP80GW=h
00D0GgAi065fN`1SN7d0IW^006QmPP0206YoQ080J7f205T0Jgn006f0OP1bQH<0LHB207:5P`1jRXT0
NhZ907^9R@1jR8P0OHZ:07^7Q`1lR8P0Q8nB08F@U023TI80QI>C08BCT@21T8`0Ohj9086@S026U9@0
QYBE08>ATP20Rhl0QXnF08VBV@2@VIh0U9fR096JW`29TiD0QHn@08J@T@26T8l0Q8n;08F@S02:UI40
RIB@08ZET@2?VYH0S9NC08JAS@2;UI@0SINF092JV@2=UiP0RYBE08jHV@2?VI/0RYRK08ZIW027UYT0
QIFE08NGU`28V9P0Pi>B086AT01lS8T0NXZ707b<R@1jRXH0NX^507B5O@1]OWH0JW]a06IgK@1RLfT0
HWAX05QZGP1@HUH0Bee?045CA@10DT80A5E504MIAP1:GDX0CV1@04mSD`19GTl0BEeA04mTF01;HED0
C65H05=YH01@Iel0DVMR04mTGP1=HUT0@eQ?03mDB00203M<?@0L03A7>`0_@3H0;Sdh02Xi=@0Q<2/0
72`Q02Lg;00M;B80CemE03e<A@0S<R/0:3Ld02Hd=00J:2P0;C/l02@b<`0[>c/0:c`l02Xm>`0/?cd0
>Te;02hn>`0I:BH08S8_02Lf<@0Y>3<0:3Lb02@`;0<08BdY0P0P;2P0>P0R;RX08bl[01hZ9P0L:2@0
7RXV028^:P0Q;BT082`X024Z9`0L9B806b@Q01XS800I8Ql05b0M01<L6@0E7Q/072DR01TR7`0G81d0
6b8P01/Q7`0I7ad06R0N01`R800K8Al06AlM01hT8P0Q9bD0728P01TO7@0Q9bD08BPU01PQ700G81/0
620K01TO6`0J81`082DQ01hS7`0I6aP05QPE01XL6@0K7AX0828O01TK600M7a`05ALD01/M6P0H6QL0
4aDB01TK600H6QL04Q@A01@F4`0F6QH04AHB010F4P0B5a<201<H500F014C400B514051HC018B400C
4a4051@B010@3P0A3a005QDE010A400I7A`0BDe<02hd<P18CT`0^Knm02``;`0=3`h05AHE00d<3@0?
3P`040l=014@3P8040l=00<04Q4?014@3P0A40h00P0@3`d200l>3008010<2`0B3Pd04@d<00l;2P0@
30/0510?010<2`0A3@`2018>3@0I014=300@30T04Pd:014=2P0Z:BD04Q0A00d>3`0?41803PlA00l?
40092@L05A4@01TE4@0;1P<04Ph=01@@3`0H51<05Q8A014=300@30/04@d<01LC4P0J5QD04`l>00l;
2P02018>3@0M010<2`0?2`X03`/:01<?3P0E4A004Ph=00l;2P0>2PT03`/:01<?3P0E4A004@`900X5
0`0?2PL05A0=00d81@0910<03PT700`71@0@2`P040/900L20@0A30/04@`9010;200E40d050l<010;
200A30T00P0@2`P200l:1`0:00h91P0A3@X01`@200l;200=2@L02`P6018>2`0=2@L040`900l;20<0
3PX700d03PT601PC400M61D040/800`7100@2`P050l<00h91P0>2@L03@P501HA3P0G4Pl030L600D0
3@L70`0?2@T200h8200700d71`0B30`0<B/[00d71`0<1PH04`d=00l92@0600h820803@P500P04@`:
01dG5`0A30X03PP700h9200>2@L03PT800h820803PT700<03@L800d72@0=1`T00`0=1`T<00h82P0>
00l92`0A2`d04P`>01@>400910D05a4C00h32@0=0PP04PL=01D:400>10T04`P>00l42P0A1P`200l4
2P030146300?10[ooooo01?ooooo000Kooooo`0C00d=5@092A4020P@00X;400@4AH05QLL010A5@0J
6ah03PlA00H72@0@4A<02@X<00D42@0:2@h01`H;02`[<00=31404Q4F014@5@0200`;400N00d<4@0E
51T07QdR018A5`0F5AX04A0E00d<4@0<30h05aLI00d=3`0A4A405ADE00h>3P0<30`04Q8B01@D4P0O
7ad0CTi<00P81`0A4@l061PF00l?3@0@40h03`l=00`<2P0:2PP02`/900l=2@0@3@P04@h91P0B3`X0
6`0A3PT040d800P:1P0F71P01`d900P>2P052`L03aDA00`B3P0E6aL02@l;00P>2P093`/051XF00lC
300B50T04A8:00l@200=3PH030d701@E400T9B006a/I00l?3P0;2`/03`l?010A3@0300l@20803Pl7
00L05AH>00X;0`0720005AH>00L8000310003Pl900803Pl:100?40/2010A300300l@2`0>3`X030d8
00803Ph<0`0@40h06@0?3`d0<S8`02LW9@0D51802`/900`<2P0=3@/061XI0001000J71/0008100h@
3`0C51<04Q@C014C4P0620L02P`;018D4`072@P01PH402DU8`1@D4h03@d;018B4@0D51800P0?3`d2
00h>30803`l=00@03`h:014>2@0B3`X04Pl:0P0C40/201@A300A01HC3P0H5A005Q<>014@300<30X0
418?018D4@0?4@h030h;00d?300C5A803Q0=00d?30092`P03a4>00`>2`0?3`d00`0@40h3014A3`0>
00l?3@0@40h04Q8@014A3`0@40h0>C/h00h@3@0<3P/04Q@A00X<2@0620D03a4>00h@3@0?4@h3010B
3`0401HH4`0D5Q404Q@?014C3P80418=00@04Q@?010B3@0@4Pd0418=0P0B50l01`0C5A003a4<00h@
2`0E5a8010H101LI500C5A000P0B50l2010B3@09014C3P0B50l04Q@?01<E400A4`h0418=00lA300@
4Pd04A<>0080418=00@04Q@?01HH4P0E61404aH?0P0B5@h301@G400801LJ4`0D5a0030l800/>1`0D
61403Q<<01HK500;40T2018G400601HK500E6Q<05AXC018G400A5Pl051TB0P0C618201@I4`805AXD
01L06QlI01TN600F6aD051TC01DJ500G71H07R<O00`A3@0=4Ph082DQ01hS7`0I7QX05AXF01XO6`0F
6aL0724M02P]:@0K81`07RDN01lV7`0K8Q/06B0I01dT7@0401XQ6P8061lH00d072<L01`R7P0L8Qh0
728N01/T8@0M9R<07RLT00dG5P1aNgX0;cTh028^;P0T<3005b<S00808B//01P08R`]028^;P0U<C40
9S8b028`<00P;bh072`[02De=00Q<C00;Shm02Hi=`0]@3h08cHd02<e=@0S=CH0;Cm103e?D@0a@dH0
:C/o02Xl@00`@TH0=4I80355A00^@T0203=7A@0]0314@P0cAdD0<DE303I:B00kCdd0?U9@03Y>C00g
BdT0?U1@03Y<C00iBd/0=4I60312@P1=Gel0GFm_04YLG01=Gel0D69R04]MG@0nDU40G71c04EJG@1<
HF@0D6EX04AIG011EUT0B5eP04iSIP1<HF@0CV=V059WJP1>IVP0CFIX04QRH`1DKVl0DFU[05E]K`1I
L780EFY]05IYK@1PLgL0HGAh05iaM@1PM7P0HGIk0080H7Ej00l0HWMl06AiOP1XOH80KH:706n4R@1/
PHH0IGYo06AiOP1VNW/0IGQf06j1O`1aPh40OHf<08BDT`1iR8P00P1kRHT02022Shl0PXj>08>?S`27
TYD0R9>G08JAT`26Ti@0R9JF0P27Ui@02028V9D0RYRH08bGV@2;UYP0RYFJ08bEW02;U9/0S9FJ0P2@
VIh02@2<UYP0RiFF08^EUP2:U9<0R9>?08VDT02=V9@0SiZF08bGT`0208fHU00<08ZET@2<UYD0SYRG
092JV@2>V9T0S9JG092JV`2>VI/0RYRK08^JW@27UYT0Pi>C0P28V9P0@P25UI@0QYJE086ASP1nSX/0
P92=07R9P`1fQh40LH9j06]lM01WN6h0H75W05UZH01DIUX0@eE803i@@P10DT@0?e5303i@@019FTX0
BUa:04mRC`1AHe<0Cf=C04aQDP1<H5@0C65E059XG01DJF00DFMO055XH01DJF@0CfAN04]PE`10E4/0
>dm303I;?00jC3h0=4Hj0311=`0hAd80@4m;03I5@P0Z>S00:SX_020`9@0U=B/0;Sdf02ln=`0]?3T0
8Bl_02Xh>00T<S<0@Dm@01XZ:P0Y>SX0:3/i02e0?P17FUP0<D4n01XZ9`0Q<Bh09C@_02Lf<@0U=2l0
8bl[024]:@808RhZ00D082`X01`X900N:RH082`X01`X900201hZ9P0401dY9@0O:bL082`X020Y9P80
7BHS00X06b@Q01PQ7P0H8Ah0624N01/T8@0S;2T07BHS01LP7@0H7ad06R0N0`0K8Al02`0M8b40728P
01TO7@0I7ad05Q`J01DK6@0H7Q`06R4N01PQ700G81/05ahJ00<05adI00/05Q/G01LI5P0H6QL061XG
01LI5P0E5a@03a4>01TK600H6QL07R0M014C4002010B3`0701@F4`0F61D051HC01DI5@0C61@04ALC
018G4`0201<H500F018D4@0H6QL04Q@A01@D4P0H61H0820N01DE4`0F5QH02`/;01HH5`0;3`h0720O
01PO7@0740d06R0N00hB4@0Y:bX03@l>00l?3`0=30X03`h<014@3P8040l=00<04Q4?014@3P0A40h0
0P0@3`d200l>300401PD4`0D40l04@d<014=30804`l>00<03@T800l;2P0A3@`00P0C3`h08@0C3``0
100001XF4P010000518C00h>3`0F5aT020T;00d=3P0M7A/01`<201<?2`0K5Q802`L600l;2P0G4a80
510?00`81`0>2PT040`;00h:2@0C3`h040`;00`81`0@30/03@T800h:2@0=2@P02`L600h:2@0A3@`0
3@T800h:2@02010<2`803PX901804@`901D@3@0@2`P02PD201HA3P0P6aP03`X7014<2@0910402PD3
03Pc<01/If@040/801<>2`0L5a@06aHC010;200<1`@2010;20803`X701X03PT601<?300300000`00
018>2`0G4a005Q8?014=2P0F4Pl04`l<00l;200=2@H03PX7018=2P0O6QL081/H00l:1`0<1`@040/8
00d81@070P0040/8014<2@0500002`H300d81PL03@L70`0>20P01@0?2@T02`D501@>3P0@2PX02@<3
00802`D51P0>20P02P0;1@D03`T900`6200D3Q004P`>00`62@0>20`03PP:00h82`0>20X200h820H0
3@L91P0>20X600d72@0>00T31@0A2`d02@<500/51`0F41805a4C00T0100@1@/03P<901X?5@0;0PH0
AS]100l42P0B1`d200h32@0301873@0?10[ooooo01?ooooo000Kooooo`0U018B6P0=3AD02``A00`=
4P0@4AH05aPL00`=4@0l?Cl0<S<e00T:300<3@l0414C00D42@0E51T04A0E0000100=31403PdB014@
5@0;2Pl03`hC00h=4P040`P0000402l^=011@4D04A0E00l>4`0C4aD020P:00h>400F5QH071`L01@D
500=3@d04Q8B00X;200200/;2@0401LG5@0:2PP030`:00d=2`803`l=00H03@d;00`<2P0>3@T03`d9
010=200A3PT3018?2P0=01<@2`0@3@P03P/600l<1`0@3@P03@d9059GD`0_=300314=00lD40093PX0
1``801@I5@0200hC3`0300X?2`0B5a<030l90080414901L03a0900h?2@0>3`T03Pl:0083000@40h0
30`:00l?3@0@41003`l;00l@200@4@/0414:00h?1`0?40X030d601TJ4P0G618030d601<D300@4@/0
30d700`=200200h?2P803a0;00H04A8=018C3P0D5A004a@?014B3@0=3PT200`=200400h?2P0?40/0
3a0;00l?3@802@T70P0:2PP05P0<30X03`l=00h>3P0A4a802`d<01<E500=3`h03Q4@00X<2`0>40l0
51HE01<E500;3@`02@X:01lO7@051@<06a/I00`<2P0=3@/04Q8@00l?3@0>3P`200d=2`0A00h>300?
3`d03`h:010>2P0@3`X04Ph;018@300A40/03@T600l=2@0C4Pd0510=010=2@0?3PX07AdK01@F4`0@
4Pl00P0B51405@0?4@h05ALD00X;2@0@4Pl01PP500h@3@092`P03Ph<00l@300@4@`0410>014B3P0B
4`h0414=00l?3@0@4@`04a<@01<C4@0B4Q003@l<00L91P0200lA3P0400d?300E5a@04A<@00h@3@80
3a4>00<03@l<00h@3@0?4@`00P0>40/03`0?4@`0418=010B3@0C5A00418=00lA300@4Pd04Q@?01<E
400620D06Q`G01@F4@0<3PT04A<>01LI500500lA300X014C3P0C5Pl04aD@01<F400B5@h04A<>018D
3P0C5Pl04Q@?010B300@4``04aD@01TL5@0H6a@04QD>00hA2P0?4P/04aH?01DH4@0F6A8051L@01DH
4@0L7aP06A`E00lC300F6a@061dF00dB2`0Q9Ql03A8;014F3`0A5Q004QLA01DJ500A5Q0061dG01<H
4P0C614051TB01@I4`805AXD00<07B8L01/P6P0H7AP00P0G71P03`0J7a/03a<B018F5@0D61L0720O
00`A3@0M8Ql05a`H01/P700C61@08BHR03Hk=`0N91l05QdF01/R6`0201XQ6P0301hU7P0H7aP06R4J
00806b8K0P0H7aP03@0K8Q/06b4M01/Q7@0J81`06B8M01`U8@0N9b@08bhZ01dX900G8al09S8`028^
;00S;bd00P0Q;B/02P0R;R`08C0]02@c<@0V=3@09cDe02Ph=`0M;B`0;3`k02<c<P0I;2X202Dh=P1?
01lb<00U=cL0;T1102Tk?@0W>C/0<TA603E7B@0bA4P0<49502e1@P0_@d80;40n0355@`0bAT@0<4A2
0396A00cAdD0>De;03mCDP12EUD0>dm>03M;BP0eBDL0=4M503E9A`0oDe40D6=Q08VMW02[_[h0Cf5S
05U]KP1;GV00CEmQ05ibL`2DZJX0BEiQ04QMGP16Fed0?eAG04mTI@1;H680DFIY04mTI@1BIfT0EFY]
05AYK01?J6T0@UaM05QbL`1=IFL0EFe_05I]K`1FJfh0Efa_069fN@1SN7/0H7=g061eN@1RMg`0H7Ej
065fN`1TNGh0Igb106MlO`1XOH00KH2406YmP@1UN7`0I7Mk06UlO01SMW@0LX:107^;RP25UI@0Tj>S
08FDU@1lRX/0OXb=08NDU@0208VDUP0608^FVP27TYP0QI2D08NBU029UiP0RiVI0P2=Vi/02P2=VY/0
SYVK08jIW@2?VZ00UYnV096JW`2=UY/0T9VN09>LX@2DWZ0208jHV@0V08bFUP29Ti80RYBC08nIV02D
WYd0SYVE08^ET`2<UYD0RiFD08jHU`2<UYD0SYRG08bGU`2<UYL0SYZJ08bFV027UIP0RIRK08BCUP20
Si80QIFE08JFUP1kRh/0OHf<07b<RP1mSHX0PI6>07V9QP1gR800LX=k06]lLP1VMfd0G6eS05=UF@18
FTh0=TPj0353<`0hBSX203]=?@0P04YLC01<GTh0CfAC05=UE`1@IEH0Cf=G04eQE@19GU80E6YN05M/
H`1?IE/0DFQP04iUG`16FUL0@5E>03U=A00mD4@0@eE703e?@@0b@cP09cP`02dn>00b@T008c<`02hn
=@0R<RP0;cle02hm=P0]?3D0;3/f02Pg=00[>SL202Pf=P0=02dk>`0/?3/0:c`l02/n?00W>SP09STf
01DU8P0H:B<08S8]02@c;P0U=2l09C<^02<_:`02028^:P0<02<^:P0N:RH06RHR01`W8`0N:RH072LS
020[9`0M:BD06RHR01`W8`0O:RH082TV0P0N9b@02`0L9B80624N01LP7@0D7AX04AXG01DN6`0B6aP0
4AXG01<J600F71X06AlM008061hL00/07B<Q028X9P0M8b406AlM01XP7P0K8Al061hL01TO700J8ah0
6R0L01LM6@0201DK5`0C01DJ5P0G71P071hK01dO700G6AH04aDB01DH5@0C61@06QlK01LJ5`0Q8b00
5QPE01TK600B51405QPE01/M6P0E5A<03Pl=01<H5002014F4P0F01DG500F61D05ALD01PJ5`0?4@h0
410>01DE4`0N7Q`03`l=01@D50061PH05ALF00D71P0<40l041DC01TO7@000@004a@C014A4@0G5aL0
3@/<018A3`804a8@00<03`h<00d<2P0=30X00P0A40h2010?3@803`h<01T07QXI01LC4`0B3Pd04`l@
01@@400A3@`03`/<018>3P0D40l05Q8C01LC4`0H51<05a8?00h:1`0J5QD030/9014A4@0<30`0>CTk
00l?3`040`4040`;00h:200?2PL05Q8A008040`;0P0>2PT0500J5QD04`l>00/71P0?2`X040`;00h:
2@0B3Pd03`/:018>3@0A3@`03PX9014=300D40l040`;01HB4@0J5QD06ADD01<?3P0@30/040/80P09
1042010;200=00X50P0B3@X030L401<>2`0E40d02@@101<>2`0A30T03`X701D@3@0F4@h040/800l:
1`02010;20803`X700`03PT600X60`0E4@h03`/800P40P0<20D01@40014=2P0D40d03PX700`81@0>
2PL2010<2@0<01PC400G4Pl02PD200l:1`0B3@X03PT600d81@0A30T020@200`7100E40d040X91@0>
20P300d71`0800h8200?2@T03`T9018<300;1@D09R0P018<300<1PH700h8200600/51@0A2`/01`83
00d72`0@2Ph030H:0`0>20`200h82P0300h8200=1`T03@L900@03@L91P0>20X600d72@0>01@>400;
1@L0618D00X41P0@2P`0100000`11`0B20d01`0201H;4@0C2Ph0Mfab00`11`0@1@/200/01P030105
2`0<0@Oooooo01?ooooo000Kooooo`0=00d<4P0@3aD04Q4F010?500?3Q<03`lA00P82P0T92H08R8R
010@400;2`/051@D00d=3`02010@4P803Ph@00<04A4C010@4P0@41800P0?3a402`0>3Q003PdA018A
5`0M72406APM00/:3`0A4A<03@d?010@4P0?3`l03Ph>00803`l?00`0414@00X=301:CD`0CU5@018D
4`0A4a0030h;00h>300?40/0414<010?2`0?3PT200h=2@803`h:00`03@`800h=2@0?3PX040l;014@
300@3`/03Pd9010?2`0B4@d04A4<010@2`0?3`X200h>2P0700l?2P0@40/03`l;00d=2@0A4@d0410;
00h>2P02010A2`0<00l@2`0>3`X03Pl:00`=200@4@`05QLB010A300=3PT08b<P02TZ9@0C50h04A8=
0P0>3`X01P0?40/04A8=010A2`0>3`X03@h900h?2P80414<00H03Pl9014B300D5@l04a@>00l@2P0>
3`T2010A2`0E00`=1`0?40X04a@>018C300?40T04Q<<01<D3P0@4@/04A8<00h?2P0?40/03Ph<01@D
4P0L71X05aLE010?3@0<30X05aPE01<E4P0D6AD04aTE00803A8>00L03A4=00l@3P0@40h03@d;00l?
3@0<30X0410>00804A4?00<04Q8@00l?3@0C4a400P0@40h01@0C4a403`l=014A3`0@40d03a0<0080
4A0>01`03`l<014A3`0B4@l03Ph;010?3@0B4Pl030`:02<U8P0@4Pl04A<@01<E4P0>40d04A<@00lA
3P0];b`04Q@A01DG500>3`d03Q0=018D3`0@4`d03Q4:00d@2P0>4@X03a8;01DH4@0H6aD04QD>0P0@
4`d00`0=3`X04Q8@014A3`02010@3P0501<C4@0=3@/04Q8@014A3`0@40h00P0A4@l01P0B4Q004a@?
010A300A4Pd051D@018C3P80414<00T04Q<>01@E400C50l0414<00l@2`0@4@`051D@01DF4@0B4`h0
0P0@4@`00`0P8A`08B8M014B3@0201<D3`0801DG4@0B5@`03a8:018E3@0D5`h051L?018E3@0A50/2
018E3@0301<F3@0C5Ph04aH=00804QD<00@04A@;01<F3@0D5`h05AP?0P0@4`X0:00E60l05aXA01PK
4P0C5`h04QP>01@J4@0E6Q804aPA01<H4P0G71H05Q/G010D4`0F6QX06alO05AHF00D6a<04a/@018I
400B6A4051/C01LN5`0B61@05A/G01@J5`0C6AP05adL01PN7@0K82<05a`P01@I6`0G7Ad06R0O01/Q
800D6QL061hJ01DK5`0Q:2405ahG01TP6@0F7QP201PQ700301LP6`0J8ah06B8M00807BHQ02D09BhY
024Z9@0F7aX07RLR01dW7`0U;bL07RPP01TS6`0N:2407bXS01`W800N:R8082dU01l^9@0N;RD072`T
01l`:@0O<RX083<[024c;@0R=2h08C8^02@e<P0S=S<08cHd02@g=@0V>CL09cXh02@g=P0X?3/0:cln
02e1@00/@3l0:Shm0396A@0aAD@0;T910080;d=303X0;D500397B00bB4H0;TA203I<B@0gCDX0?E=@
03I<B@0^A4<0>4e>03E:CP0oDeT0>4e?03YAB00kDDL0>E1603U?A`1AIf40N8j;08nTY01;Gf<0CF9V
04QMH`1;GVH0DFA[051TI019GEd0B5aK04]OGP1<H600BemN05Q/J`1@I6@0DFET05M[J`1FJVX0DFIV
06ImO`1ILG<0E6a^05I^L01KLgD0EVi`05eeM`1KLgD0G7=f05YbM01IKg80H7Ij06j3R01JKg@0KX:6
06f0Q01[OX40K82006YmOP1/Ogh0KX1o0P1_PGh01P1aP800NHR806ilO@20SY00OXb>08^IW080PY2D
00D0PXnD08>@UP28UI`0RIJM08ZEW00208ZCVP0;08bEV`2>V9d0T9ZP092JW`2EWj@0TI^P09JOY@2C
W:<0TY^Q09ZSZ02?VI/00P2FX:8209BNX00<09:LWP26T980SINI08^EUP2DWZ00SINH08nGV@2?V9P0
TIVJ092JV`2AVi`0T9ZK0P2<V9P03@2=Vi/0SibL08fKV`2;V9T0RiVL08ZGW@29UY`0QiBJ08JCV024
TYD0P8jA07n=S`1mRh`00P1oSHd04@1lRhP0LhAl0762N01WNFd0H79V05]]H@1IJed0FVaM03e??P0d
Ac@0>4/g03Y=>@14F4D0I7U[05I[G`1<HUD0CF9F0080CfEI00<0DVQL055WF`1AIe/00P1CJEd03P1@
IUd0AEaF04EKEP12Ee00?e9903e=@`0mC440>4Ll02ho=@0/?SH0:Sdh02Hk>00/@Cl0<T=20`0c@d40
=@0[>cP093@a02/k>00W>3<0?Tm:0352?@0M;RT08S8_02Ph>00]?Cd09SHd028c;P0]?3D08C4X020]
9@0X=Bd08BhV02Da:`0N:BD0:cHb028/9`0W<2/0:38/02D_:P0P:B@07BLQ01/T7`0O:2<07bTS01`V
8@0M9R407RLR020W8`0P9R807bDQ01XP700O9B409B/W01`R7P0H7QX05adI01DK5`0H7QX072@O01XS
7P0I8Qd06b@O01dV8@0L9B006B8M020Y900K91l0624L00807BHQ00@07B@P01TN700I7A`06AdL0P0G
6aX0300l@3l06alN01/O7P0I7A`03a<B01@H5`0H7A/04APF01DK6@0F6aX05Q/I018F5@805QPG00P0
61PH01LF5P0E4a@04a4B01<C4@0C514051DB01@D4P805ADC02X06ATG01@D4P0@40h04a<A01HF500D
51806QXH00l?3@0C4a40410>014A3`0G5Q@07ahL01HE4`0C40l0518@018@3P0C3`h04Pl>014@3P0F
5A<05A@B010?3@0C4Q005aHD02DT8P0C4Q004A0>00h=2`0C4Q006QHG05=?DP0g<cD04@`@014<3`0=
2@/04@`@014=400A3@l04@`@014=400A3@h2010<2`0;014=300B3Pd04@l=014?3@0e<S804@l=014=
300G4a803`/:01<?3P0>20P00P0F41001@0B30`03`T900h8200@2PX04@/;00804`d=0P0@2PX01P0?
2`X02`L600l;2P0<20L06QHE00d920803`/:010040`;00l;2P0=2@P030P700l:1`0@2`P04@`9018=
2P0A30T040/801@?300J5A804`h;00h91P0E40d04`h;0P0A30T02`0@2`P03`X7010;200B3@X03@P6
00h91P0:1@<04@`900/60`0B3@X040/800@03`X700L040/800`7100F4@h04Pd;00h91P0G4Pl03@P6
00803@P500@040/8014<2@0?2PL03`X70P0@2`P05@0?2PL03PT600h91P0>2@H03`X700h91P0<1`@0
3`X7010;200?2PP02`H300d81P0A30T03PT701D@3@0L5aH04P`<010:2P0A2`/03@L700l92@0200d7
1`0801@>3P0E3`l03@L700`61P090`D06Q@F069LGP0`:R`200l92`0300h82P0;1@L02`D700803@L9
01<04P`>00d72@0;1@L03PP:00d72@0;1@L0618D00h82P0@2P`04P`>00T31@0E3a40618D00h82P06
008030L801@>400@2P`03@L900803`T;0P0>20X00`0=1`T030H801052@0501052@0601@93@0>0`L0
60dA00l6200B1`/03@<65?ooool001_ooooo00P040lE018A5P0A41D04A0E01@D5`0I6A/030`>010@
4@803Ph>00<04a<C018B4P0>3Q000P0@41800`0>3Q003`lA010@4P03010@4P<04A4C00T04Q4G02LV
:`0d<cP06APM010@4P0E5AL0410B00l?3`0>3Ph00P0?3`l02`0?4A004QDD01LK6P0K7ah03a4@00L7
1@0<30X03`l=00l>2P0>3@T03@`800803@`700D03`h:014@300@3`/03@`800`;1`0200d<2003018A
3@0C4Ph04Q4=00@040l;0`0?3PX0100@3`/04Q4=00l>2P0=30P201<B3P03010@300A4Pd04A8=0080
414<0P0?40/0300=3PT051D@01LH4`0>3`X0;RlZ03Hg<P0@4@`03Pl:00d>2@0>3`X03a0;00h?2P80
3@h900H03Pl:00l@2`0?40/04Q<>01<D3P0@4@/200`=1`03014B300=3PP02P/50080414;02802@X4
00l@2P0C50`0414901<D300E5Q004A8<018C3@0>3`X03a0;014A3`0F5Q@06ATG01<C4@0C4Q008R4O
01XK6@0G6AH03Q<?01LM6@052`L02Q0<010E4@0<30X02@T7010?3@0E5A<01PH404I6A00=3@/030`:
01hN700@40h051@B0P0B4Q00:@0D5180410>01<C4@0B4Q0030`:01PH5P0<30X04A4?00h>300@40h0
3@d;00l?3@0C4a403Ph<00<50P0:30T05QPE01<E4P082PL030h;00/=2P0H6QL0FUaI02X/:@0=3``0
3Q0=01/M600E5a803Q0;00`>2@0=3`X03a4<01<E400G6A@0418=00`>2@0@4Pd04Q@?018B400N7Q`0
5aLE00803@d;00@06a/I018B400A4@l0410>0P0A4@l01P0B4Q004a@?014B3@0A4Pd04a@?018C3P<0
4A8=0P0B4`h3014B3@0301@E400E5Q404a@?00804Q<>00<061TD01LH4`0<3@P00P0?40/01`0@4P/0
5QT@018E300B5@`0=CP_03<f;@0F6A000P0B5@`301<F3@03018E300A50/04QD<00<04aH=00P03A07
01DH3`0>4@P03Q4801LJ4@0?4PT04AD=018G408051TC00/04aPB01<H500F6aL05AXF014E500B5QD0
20`;01hR800E71D05A`D01DL5@0301HM5P0W01<I5@0F71P05A/G01@J600H7Q`061hM03@i?00X;C00
61dP01DK6`0D6QX02a4?020V900B61H05Q`H01`S700940T06R4J01HO6P0G81/0624L01dV8@0P:B@0
5QlJ01hW8P0K91l082TT024Z9@0I8Qd072DP01dV8@0R:bH07RLR01XU7`0M:2807bXT01dZ8`0O;2D0
82dV00807bhW01407RlW02<d;00U>C4093La024d;P0P<bh08cHb02@g<`0T=c@09CPf02Hi=`0Y?3X0
:chl02Pl>`0Z?Sd0:cln02a0?`0302i2@@0B02m3@P0aAD@0<TI503A8A`0eBDP0;d=402e1@@0bATD0
<TI404EJE@1ZOgX0=DU703A8B@0lD540>DaB03a?EP0dAd/0?EA<0P0iD4P02P12FE@0>e5>03eCD@16
Fe`0AEYO059WK01DJ6l0AEUP04aQIP18G5`204UMG00604YNG@1=HF00Cf=R059VI@1CIfH0E6QW0P1F
JVT02@1EJFP0FVmb05EZK@1GK6l0G75d05icMP1FJfh0G75d06^0P`0205ebM@0;06YoPP1TNGd0H7Ej
0766R@1YOH00Kh:606j0PP1YNg`0KGmo0761P01cPh400P1cPh00801gQXD0O8Z;075oP01oSHl0Pi6D
08ZHV`23TID0R9FK08ZGW@28UI`0QY>K08ZGW`2=V:00RY>J08^DV`2?V9l0TY^R09FNY@2GX:L0TibS
09FNY@2FWjH0RiBK0;S1a`2ka<T0V::T09FOX@2LYZP0U9jP09FOX@2FX:80RYBF0P23SHl0;@2AVid0
T9ZL096IV`2BVY`0UIfO09BNW`2BW9d0T9ZK09:NWP2AWId0S9ZJ08^IV@2AWil0X:j_09:PX`2@WJ<0
RiRN08FCUP23TI@0PY2C07j<S@1mRh`0O8Z;07j<S01oSHd0O8^807F6OP1bQ7T0Gg5U065cI`1PLVD0
?e530312<P0cAC@0>Tdj03Q;=`0mD3`0DFIC08>GR`1WO7<0CV=J04YOEP1>HeX0DFIM05EZH@0305AY
H00/051UG01;H5L0B5mG04=IDP0lDDP0>da203Q9?P0hB3d0>DTo0392>@0/?cT0:chj02Xo?@0_@d@0
<45102hn?@0dA4<0<40o02Ph=@0Z>SL0:c/h03]<AP1KK6H0?Tm901h_:@0/?3T0;3`l0310@00[>cP0
9CH`02dl=@0S<bT07b`S02Tf;@0W=2/0:C@^01lZ9P0R;BT08BXU02H_:P0X<B`09BhY01lX8`0L9B02
020Y900501lX8`0M9R407bPS020Y900M8al00P0N9200100L8Qh08BLS02H/:00K8Ad201TO6`0B01<I
5@0N92009RdY01PQ700G81/0624L01TR7@0H8A`07BHQ01hW8P0G81/072DP01@M600C71L0;S@a01dQ
800G6aX061`K0P0M8B00300I7A`051PG02<W9P0=3`h05ATH01`P7`0E6QT03Q@B018H5P0I7Q`061`K
01HJ6@805ALF00@05QHF01LE5P0F51D0518C0P0C4a4301@D4P0401DE4`0B4Q004a<A018B40803`l=
01l051@B018B400>3P`06ATG01@D4P0B4Q005aHD01PG5@0?3P`03@T801@@3`0G4a806QDE00`81`0?
3P`04Q4?010?3@0A40h040l=0040000D4a406APF00T81P0N7A/02PT700l;300M6AX061@E014=3P0?
2``02`L800H04@d>0P0B3Pd2014=308040`;00h02@D400l;2P0F4Q404`l>00l;2P0D40l07ALG00P3
0`0400002`D501@>3P0L5QH040X:014;2`804P`<00X04@/;010:2P0B3Pd0510?01TE500?2`X06aLF
00h:2@0@30/03`/:100>2PT300l:1`09010;200A30T04@`9018=2P0A30T07QTF034/:@0D3``03PT6
00804Pd:00P040/800h91P0>2@H040/801@?300>2@H04`h;00/60`<03@P50P0@2`P200h91P0=01@?
30050000100000`71@0>2@H04`h;01TD4@0C3P/03@P500X50P0<1`@03@P500l:1`02010;200E00l:
1`0>2@H03PT6010;200;1P<02PD2014<2@0<1`@02PD2018=2P0H4a004Pd:00H1000B3@X05A0=00l:
200;1@D030H600l92@0=1`L03PP8008040X:010050h>01<=3@0>20P03`T9014;3@0400005@lA01XD
5P0F41804@/=00`6200A2`d02`D700H00P0<1PP02`D70P0=1`T0200?2@/03PP:00/51`0B30h03PP:
00l92`0B30h01P020P0=1`T01P0>20X05a4C00P2100C3@l04P`>00l92`<03@L90`0<1PP601052@06
00L0000C20`01`0000h31`0X7B405``@5?ooool001_ooooo00`04A0F01<B600D4aP04a8G01DD600H
61X04Q8D00h>3`0<30`03`l?014A4@0>3Ph600l?4@0300h>400?3a403`lA00<04A4C00T040lE01TH
7@0O7R<03@`A00h>400A4A<0410B00l?3`0>3Ph00P0?3`l02`0@41001`X900T=300<40l030h=00T9
1`0W9bD04a<A014@300?3PX03Pd900803`h900<03@`8014@300B4@d00P0A40`00`0B4@d030/7010?
2`07014@308040l;00@051<?01LF4P0C4Ph03`h:0P0C4Ph0100A4@`04A8=010A300@4@`200l@2`07
018C3P082@@01@H1010A300=3PT03a0;01DF4@02010A300700l@2`0@4@`04A8=00l@2`0=3PT03Pl:
00l@2`0200h?2P0@014B300E5Q004Q<=00d>200>3`T05QLA01DF400;30H04A8<01TJ500?40X0414;
018C2`0@4@T04a@<01@E3`804A8<00l051D@01<D3`0@40h03`l=00h>300820H07QdK04Q7A@0?40h0
71hK010E4@0A5a<061hJ010F4P0:3`/00P0=3@/02@0B4@l03@d;010@3P2j^[P0:RXX010@3P0>3P`0
3`l=01@D4P02014A3`0M01@D4P0?3`d05QHD014A3`0=3@/04A4?02PX9P0T92804A4?018B400?3`d0
4A4?01@D4P0?3`d03a4>01PJ5`0S9B80828O01LI5P0J71T03a4>00/=2P1ZK6T0:2XW00d?300B5140
61XE01@F4@0?4@`00P0=3`X00`0>40/0418=018D3`02010B3@0;018D3`0D5Q403Ph<018B400K6aT0
5ADC01<C4@0c<c404Q8@014A3`0@40h00P0A4@l0100B4Q004Q<>014B3@0B4`h201<D3`03018C3P0C
50l04A8=00804A8=00<04Q<>01<D3`0A4Pd00P0E5Q402P0D5A004a@?01@E400@4@`051D@014B3@0F
5a805AHA01@F400F6A0201<F3@03038e;00a=2/05aXA00804QD<0P0C5Pd301@G3P0G01DH3`0G6Q40
5aXA01DH3`0D5`h0:RdT01`O5P0B5@`071lF00lB2@0C5a004QLA01@I5@0D6A@04QLC01<H500E6QH0
4aPD01@I5@0G71T041DA01DI5`0E71D00P0F7AH03`0F71P05QdF01DL5@0B61@05A/G01@J5P0C6AD0
5adI01PN700R:2P06b0S01<H6`0F71`06R0P01TO7@0201`R800601HL600;4P/05QdF01TP6@0E7QT0
624L0P0I8Qd01`0L9B00624L01dV8@0I8Qd072DP01lX8`0K91l00P0J8ah0600M9R4072DP01TT7P0J
9Al07BPR01l/9@0P;BH08BhW020_:00Q<2T0834Y01d^9P0R=Rh093La028e;`0U>3<0;D0l02Hi=@0W
>SL0:3/i02Tl>P0/?cd0;T4o02Tm?080:3`k00D0:Cdl02a0?`0_@d80;d=203A8A`0203a@C`0Q03I:
B@0dB4L0<dM803Y>CP0_@d80=4Q604EJE@1GK6L0=d]903A8A`0jCTl0AEQM04AGGP0jCE<0?UA@04=I
EP0jD4d0@5ID04EKF@1;H640CV=U05=XJ`1BIf`0EFU`04EIH01?I6T0C61P051TH`1?Hf80CF5P04iR
H@1AIF@0EFUX0080FFe/00H0EFUX05=WIP1DJ6L0Efa_05EZK@1KL7<205mdM`0@05icMP1IKW40FFia
05ebM@1XOH00LhR;0725R@1/PHH0VJja07:6RP1^PHD0MHN906j0P@1/OWh0Kgmn07:2P@80Lh>001`0
M8>307R6Q`1dPX<0NXR:08:@T`29UiX0QI>G08FBV02:Uid0SY^R08^HX02:Uil0SYRP08nHW`2@VJ00
TY^R09FNY@2FWjH0VJ:Y09>LX`2BVj80UIjU08nHW`2ka<X0^<7609^UY`2DWZ00UZ2R0P2CWIl05P2B
W9h0T9ZL09>MW`2DWZ00UInQ08jHVP2CVid0UIfO09RPXP2GXJ80U9jO092JV`2DX:00TinO08^IV@27
UID0TInO0:Vg]`2DXZD0TIjT08^HWP25TiH208BBU@0I07j<S@1mRh`0OH^<082>SP22T900P8n<07N8
P01]Og@0HG=W069dJ01GJE`0=dTk0394=00jC3/0@EA103e@?@11E400DfQG06AhK@1KL6L0CfAK04YO
EP19GUD0BUmF05EZH@0305I[HP10055VG@1:GeH0@eY@03eCBP0hCT80>T]103e=@`0nCT<0>TY003M7
@@0cAT80<DA202a0@00[?d009CHf02Hf=@0c@d80<40o02Lg=00^?S/08C4^02m0>P12Ddd0;d0j01l`
:P0[>cP0:3Ph02hn?P0[>cP09CH`02dl=@0T=2X082dT02@a:00O;2<092lY024/:00N:BD08BXU01dV
8@0K91l072DP01hW8P0O:2<07RLR01`U800K91l06R<N01`U800M9R408RPT024W8`0M8al06R0L01`R
7P0R:2@06R0L01PN6P0M8al05A/G01lU8@0V;BT0624L01HO6P805b0K00@05AhI01PQ700K91l05QlJ
0P0J8ah04`0L9B00KgAa059FE@0L81l05QXI018F5@0M8B0041@C01<G5P072`X06alN01DI600G6aX0
5a`K01hT8P0@5Q@09R/Y01@H5`0@51<00P0D5QD0100E5AD05Q@E01HD5@0E4a@601@D4P03018B400C
4a404a<A0080410>00T051@B010@3P0B4Q009BDS01dM6`0D51804A0>01@C4@0A40h00P0C3`h0700@
30/04Pd=018>3@0D4a404Q4?00h=2`0C4Q004Q4?01@C4@0F5A<010<102DT8P0R8Al0>cXh02<O7P0:
1PH04Ph=01hJ6`0C3`l040`;018>3`0B3Ph04Ph=018>3`0B3Ph04Ph=00l;2P0@30/2014=30804`l>
00`040`;01TE500D40l03@T8010<2`0G4a80T8Z:03hh>00A2`/04`d=010:2P0>20P6014;2`08018>
3@0>2PT03`/:00@0000G4a803`/:014=300?2`X200d920803`/:00d04@`900h91P0=20D03`X7010;
200A30T04Pd:00T40@0M61D0?3Ld00h91P0:1@803`X7008040/801T03`X7018=2P0D3``0;RTV00T4
0@0@2`P03`X701<>2`0<1`@03PT600l:1`0D3``05A0=018=2P091@<03`X702HQ7P1YI640?cXg00P3
000E40d05Q4>010;200=20D03`X700@040/801803`X700h91P0>2@H03`X700T40@0<1`@05A0=00d8
1@0B3@X0@Sdj03<^:`0@2`P06A@A01@?300<1`@04P`;010:2P0?2@T2010:2P0I00h8200<1PH03@L7
00h8200<1PH02P@400/51@0B30h01@0100L20`070@<01P0201<=3`090`D04P`>00d72@080P@04P`>
00l92`0<1PP03PP:010:300>20X030H800l92`0200d72@0:018<3P090`D03PP:00h82P0400004@/=
00X41P0F4180100001H@4P8030H8100;1@L601052@0601872`0C2P`05``@00X00`14>Cd01`005?oo
ool001_ooooo00d02`X@010?5@0C4QL04A0E00h=4@0<30h02`/=00h>3`0A4A40410@00d=3@0?3`l0
410B00803`lA0P0@4180100?3a403@d?00d=3`0>3Q0300l?4@09014@5P0@3a@02`X?00`;400F5QP0
20P:010@4P0?3`l03Ph>00803`l?00/0410@010B4@0>40l030h=010B4@0?3`d0;bl]018A3`0@3`/0
3`h:010<2@02010=2004014@300E51005QDA01<B3P<04Q4=0`0A40`201@C3`0<014@300B4@d051<?
01<B3P0B4@d05aHB01/J5P0F5A404A0<01<B3P0B4@d03`l:0`0?40/01P0>3`X03@h900T:1@0A4Pd0
61TD010A30804A8=1P0?40/3010A30803a0;0P0=3PT0800?40X04A8<010A2`0@4@/05AH@01hO6@0A
4P`04a@>024R700J6aD04Q<=014B2P0>3`L04A8:01<D3P0?40X0414;01HG4P0A4Pd03`l=010@3P0A
4@l05QHD018A3`0Y:2H08R<Q00/=2P0D6AD08bTU028X900A5a<02a0<0P0J6QP01P0A40h05QHD01<C
4@1ZJVP0@40n01XJ60803Ph<00`04Q8@010@3P0@40h04Q8@00h>300=3@/03Ph<01TI5`0=3@/0@D4o
01`L6P0=3@/2010@3P0I01@D4P0J6QP05aLE024S800J71T05ALD01@F4`0A4a003@l<01@F4`0B5140
418?00d?300C5A803Q0=00lA300A4`h04Q@?014C3P0?4@`03@l:018D3`0@4Pd04Q@?01<E4002018D
3`0901PH5P0B4Q005QHD01DE4`0C4a40410>018B400A4@l0410>00804A4?00<04Q8@014B3@0B4`h0
0P0B4`h01@0C50l05AHA01<D3`0C50l04Q<>00<04a@?00L04A8=01@E400D5A004a@?01@E400F5a80
4a@?00805aPC00H05AHA00d>2@0A4`d03a8;00hA2P0@4``2014D3@03018E3P0C5Pl04aH?00@051L@
01P04aH?01@G400E61405APA01@G400H6a@0;S4Z020S700D5a006ahG01<F3`0G6QH04aPE01@H5`0C
5aD04QLD01@I5@0E6QH04AHA01<H4`0F6aH06AhH01HK5P0D6QL301DK6@0401DK600E6aL04aTE01HL
608051/D00D061lH01PN6P0J82006R0Q01PN7P0201<I6@0>01TO7@0G7A/051XH01/Q7@0C6AD07R@P
01LN600G81/07RLR01dV8@0E7QT0624L020Y900O:2<201dV8@05020Y900O:2<07RLR01/T7`0K9B00
0P0N:B<0100L:2807R/T020]9P0O;BH201l^9`08024`:@0Q<RX072hX024d;P0R=Bl08C@^02Hi=00^
@Cd202Hi=`0402Lj>00X>SX0:S`l02/m?@80;40o00H0:cln02a0?`0`A4<0<dM603A8A`0bATD203E9
B00K03M;BP14F5L0Cf=T03M;B`0iCD`0?E9=0356@@0kD4/0>Di904MKFP0oDe<0@EAH04EHG`19G6<0
@EIJ04=HF`0kD5<0AeaO04]PH`1>HfH0D6EX04eRI@16Feh0CV=W04QMHP1=HVD0C61P0080D6AS00@0
DFET05AXI`1GJfX0DFET0P1FJVT205AXI`0W05M[JP1LLG@0F6e`05mdM`1RMgX0H7Eh069gNP1YOX40
LXN:08ZOXP1_Q8L0GgAg06n3QP1WNWh0QiZN06n2Q@1_Ph@0LXB606n0P@1bPX80M8B407N6QP1iQhL0
NXR807f9RP26TI<0T9^M08B?TP2;UYX0SYVM09bW[02DWjD0RiJL09:LY02BW:D0TI^T09FNYP2GWZH0
V9nW00<0VJ2X00L0UijV09bSZ`2KXZX0XZVa09nV[P2DVj80VJ2V0080UinR01P0TIVL09fUZ02NYZT0
UinR09:JW@2EWJ00Vj>V08jFV@2JXZD0UIfO09JNX02IXJ<0V::S09JPX@2BW9d0SYZJ096MW@2BX:00
SI^K08^IV@2?WId0T9jQ08jKX@2:V9/208JDU`0808JDU@25Ti@0PY2A07n=S@1nS8`0NhV907R7Q01e
QW`206MiK@0?05i`I013EDP0?e5304AFAP11Dd<0@EA204=EA01:GD/0DVMG04mSF01HKF@0FFiU05=X
G`1AIUd0EfaS00@0DVMN02L0CV=J04QME015GE40?EA703Q=@@0lCd<0@556041@A`0b@CX0>d]703iA
D00nD5<0=DU=02Xm@@0T=CH0:SXi03E5A00`@3l0:3Pe02dm>P0[>cP0<T<m02`m=`0]?SP0:c`f02De
<P0R<S80:3Ph02Xj=`0T=2l0:STb02@d:P0R;bH08c0W034n=@0]>3808B`X01TT800Q:RD01@0P:B@0
100L9B006B8M01TR7@0K91l201`U800302<Y9@0Q9b<0728N00806b4M00@07bDQ01`R7P0I7a/082HR
0P0K8Ad00`0M8al061hJ01LM6@0201PN6P0501LM6@0F71P08bTU01dS7`0D6QH00P0L8Qh04P0e>SL0
82@S01@H5`0L81l06AdL01dQ800H71/06QhM01@H5`0L81l051PG06]_KP0O92<03aDC01DI600I7A`0
Bdm>05IHE`805QPG100E5AD201DE4`@051@B00D05QHD01@D4P0C4a405ADC01HF500201@D4P0?014A
3`0N7Q`05QHD010@3P0E51804A0>01<B400G4a80510?01HB4@0[9RD06QHE01DD4P0A40h040l=0080
4A0>00`051<A00h=2`0C4Q00=C@b03hm>`0M71X04Ph<01DA3`0:1P<03PX901@A3P0E4@h201<?3@04
01<?300C3`d04`l=01<?3@<04Ph=0`0A3@`02P0>2PT04Ph=00l;2P0?2`X0510?01<?3P0]9bL04`d=
018<300G4A42014;2`03018<300A2`/04@/;00804@/;00T04P`<018>3@0<20L040`;01<?3P0g<c80
=S8a018>3@0@30/00`0?2`X00`0@30/04@`900l:1`0200h91P803`X700H04@`900/60`0;1P<05A0=
00L2000I5142014<2@08010;200?2PL040/8018=2P0O6QL02PD2014<2@0>2@H201<>2`0@014<2@0>
2@H05Q4>01`G500E40d040/801D@3@0C3P/07aXH01LB3`0>2@P04Pd:010;200?2PL040/8014<2@@0
40/800D03`X700h91P0>2@H03PT600d81@02014<2@0?00L20@0D3``0J6=P05]FD`0E40h02`H400h9
1P0;1P<040/9010:2P0?2@T040X:01<=3@0@2PX03@L7008040X:00X030H600d71`0>20P04@/=00h8
2P0H4Q@050h@00/51`0A2`d01`830`0?2@/201TC5@0300d72@0?2@/03`T;00803PP:00d030H8010:
300=1`T04P`>00P2100:10H02`D700d82@0910D06aHG04@n@00A30d081XL00<03PP:0`0?2@/60105
2@0600`31@0F30l0DTM;01/B500C2@`03PD75?ooool001_ooooo00d03@`B014@5P0B4AH04A0E010@
4`0A4A<03@d?010@4@0G5aL05ADE01<C4`0K6a/04A4C00803Ph@0P0@41800`0=3@l03`lA00l?4@02
00l?4@803Ph@00T03@`B00d<4@0>3A803PdB018B500820X0410B00l?3`0>3Ph00P0?3`l02`0@4100
51HE014C4P072@P01@D500T81P0J6AL03Pd;010<2@0A3@X040`900803``700@04A0<01DD400F5A40
4Q4=0P0>3@T0100=30P03Pd900h=2@0<2`L300h=2@0<010?2`0B4@d04A0<010?2`0B4@d05A@@01<B
3P0@3`/04Q4=010?2`0>3PX0414<0P0?40/200h?2P07010A300?40/02``700/<1`0C50l04A8=00d>
2@0300h?2P0900`=200;30L03@h900l@2`0>3`X03a0;014B3@0C50l04A8<00802``600H03Pl9010A
2`0@4@/04A8<00h?2@0=3PP2014B300500/<1P0A4PX03a08018C2`0C50h00P0@4@/06P0F5a804A8=
00l?3@0=3@/02PX800l?3@0G5Q@01PD301DF500:30T04AHB00lE4@0A5a<0318>00dB3P0;2`T010@2
018A3`0=3@/02`/901<C4@1iNGL092@R00D50`0>3P`04a<A0P0@40h02@0C4a403Ph<01<C4@0B4Q00
410>01<C4@0J6QP0000000/;2@0200h>3006018B400I6AL05ADC01TK600A4a002`d:0P0<3P/02@07
2@H04Q@A00X<2@0P8Ql04Q@A00lA3P0E5a@04aDB01@F4`0301DG500@01<E4P0>40d03a4>00lA3P0:
30T04Q@A01lQ7P0N7Q`03Ph<028R800C4a40820N01LG5@0B4Q004A4?010@3P804A4?00P04Q8@00l@
2`0C50l04a@?014B3@0D5A005QLB018C3P<051D@00<04Q<>014B3@0@4@`00`0A4Pd0100C50l05AHA
01<D3`0C50l201TJ5@08018C3P0D5Q0030l800hA2P0E61404A@=01@G400H6a@201<F3`8051L@00<0
5APA01<F3`0A50d00P0A50d00`0B5@h04aH?01HI4P0201/N5`0401PK500F6A8061/D01LJ5`804aLH
02P04QHG018F5@0D6AD05AXE010E3`0F6aD05Q/D020V700K81X05A/K01DJ7@0D6Q/051XJ01HL6P0I
7ad05A/G01PN6P0G7QL05QdE01XQ6@0K8QX04ALE01<I6@0G7A`061hL01XP7P0N92809B/Y010F500K
8Al06AlM018H500f?3P04a`G01XS7P0I8Qd04Q/F01@M600K91l06B8M0P0J8ah02P0I8Qd06R<N01`U
800L9b<06RDQ024/:00R;RX07b/W024]:@0N;BP201d/9`0501`]9`0O<2X08C8/02<f<00R=C000P0Q
=300100U>3D0:3/i02Pk>@0W>CP202Hh>00e02Li>@0X>SX0;D5002i2@@0_@d80<4A30396A@0dB4L0
>Ti=0396A@0eBDP0=4Q703Y>C@1@I6<0Nhf=041BDP0hBdT0<dI202Xm=`17FU@0>Te904IHF00lCTh0
BUaP04AEG011E5/0BEeV04EIHP18G6D0F6ac04iRJ@1;H6D0DFI[051UJ01BIfX0C65S04]PH`16Fe`0
CF5P04YNG@1<H5l0DFET05IZJ@1GJfX0DVIU05=WIP1DJ6L0EVYY05U]K01KKfh0HGAh05Q[K`1PLgL0
0P1RMGT0401PLgL0Jgj208bOX`2U^;`0M8N;05a_L`1WNWd0M8R906MkO01hRhd0OHnA07^;R`1hR8P0
NXZ:07f;S020SXl208:@T@0@08RDUP2BWIl0Xjj`092KWP2JYJT0UJ2T0:>^/`2IY:X0T9^Q09FPY`2D
WZL0UZ2Y09ZSZ`2JXJT0W:>[09jU[@80WJB/0180W:>[0:B[/`2IX:P0WZF]0:B[/`2SZ[40WjJ/09bT
Y`2OYjX0UIfP09RPX`2IXJ@0UinR09JNX@2maLP0g^KY0:fe^02DW9l209FMW`0U09NOX@2FX:40UZ2Q
09FOX02Q[Jd0W:RX08nMW@28UYH0RING08nMW@2<VYd0RiVL08VGVP27UIH0QI>D08BBT`2;VIT0R9JF
08>AT@1oSX/0NXV607F4O`1aPWP0JG]_069dJ01DIUX0@E=604AFB016F4X0@59403mA@`17FD/0E6IG
05EYG@1LL6L0Fg1Y05M/I@0205AYHP0]05Q]IP1JKfP0EfaU05AYHP1BIf00CV=L04UNE@1:H5<0@EM7
03Y?@00kCd<0?4m403U:@P0cA3h0@E5?04=EE`12E5P0>4]B02Tl@P0Y>S/0;cln0310?`0]?C`0;Cdj
02hn>`0W=c@0;Chh028c;@0U=S008C8/01XZ9`0V=SH0:SXj02dm>P0U=C009cH_02<c:@0U<RT08BhU
069_IP15D4X05R4M02<^:P0J8ah07RLR008082TT00D06b@O01PQ700J8ah06B8M01/T7`0201lX8`07
01`U800M8al07B<O01XP700O9B407R@P01XP700201dS7`805adI02805Q`H01<I5@0C6AD04QPD01<I
5@0E6aL051XF01PN6P0U:bL082HR01/Q7@0J81`05Q`H01hS8@0S9bH07R8Q00hB4@0C5aH07B4P01<G
5P0_<c8092PW01LK6P0K7ah0:bl^00hB4@0I7A`06QhM01dP7`2[[J`0Wj6P01PJ6@0G6AP051HE0P0B
51<01@0C5A@05ADC01DE4`0E5A<051@B00804a<A00T04Q8@01<C4@0E5A<04a<A018B400D51805QHD
00d=2`0B4Q000P0>3P`06@0D4a407QdK01TH5P0E4A0040`;00h:2@0H4a806ADD00h=2`0F5A<07QdK
01@C4@0B4@l030/901XI5`0A40h01PD301dL6P0A40h03`/800l<2P0P7AP0924L00P50P0300001@0C
40/0400C3``0510?01@@3`0B3Pd040`;00l;2P0>2PT05Q8A018>3@0C3`h0510?00l;2P0;1`H02P@4
018<300C3@d200h8200301@>3P0B30`04@/;008040X:0P0B30`01`060`803@T801TE500C3`h06ADD
00L30P0@30/00P0A3@`00`0@30/03`/:00h:2@0400l:1`0800d81@0<1`@03`X700`7100?2PL06QDB
00h91P040002018=2P0:010;200>2@H03PT6010;200810803`X700h91P0=20D02`H3014<2@8030L4
0P0=20D0300<1`@03PT600T40@0A30T03`X901@?300M61D02`H300d81@0<1`@03PT600l:1`803PT6
0P0@2`P02P0?2PL03PT600h91P0=20D03`X7014<2@0<1`@020<000`7100C3P/201/F4`0400l:1`0<
1`@04@`900l:20803@L700l03PP8018<300=1`L02@<300l92@0>20P02P@400`61P0;1@D07QPH01<=
3@0H4Q803@L700X4100A2`/00P0?2@T05@0>20P02`D500T30`070@403@L9010:300=1`T02`D700l9
2`0=1`T04P`>00d72@0A2`d02@<500X41P0?2@/06Q@F00P2100:10H06aDG00T31@0300X41P802`D7
0P0<1PP601052@0600X00`0A20X0?34e00/01008004091TM5?ooool001_ooooo00d02`X@00d<4@0=
314030/@00l>4P0C4aD03`lA00d=3P0B4Q804A4A00l?3`0G5aL04A4C00803Ph@0P0@41800`0=3@l0
4Q8D014A4`02010@4P0;00l?4@0>3Q003`hD00`;400D4aP030/@010@4P0E5AL0410B00l?3`0>3Ph0
0P0?3`l01@0@410020X901HH5`0B51<03`l?00802`X800X03`h<01<?300D40d0510=018?2P0A3PT0
30/7018A3@0D4`l04Q4=0P0@3`/02P0?3PX04a8>01<B3P0@3`/03Pd900d<200<2`L03Pd9014@300@
3`/200h=2@06010?2`0?3PX03Pd9018A3@0@3`/03Ph:0P0A4Pd02P0@4@`03a0;00l@2`0A4Pd030d8
00d>2@0C50l030d800h?2P0C50l2014B3@03010A300>3`X03@h900<03@h900L03a0;01<D3`0G61<0
5aPB00l@2P0;30H03Pl900804A8<00@03@h801<D3P0C50h03@h80P0?40X05@0C50`0414901<D300D
5@l04A8<018C3@0A4Pd03Pl:010@3P0A4@l03@d;014A3`081`D07A`J00`=2`0G6AH000D100hD401B
F5@0:c4]00T>2P0201HF500900/:20092@L07alM00`<2P0B4Q0020P701LG5@0@40h051@B00804A4?
01h051@B010@3P0G5aD04Q8@00D50`0S8b404a<A01LG5@0@40h04A4?00h>300?3`d04Q8@00d=2`0:
30T030h;00h@3@0A4a0051HC014C400;3@X05ALD0001000C5A8051HC00`>2`0A4a00418?00h@3@0=
3``300lA3P0>01HH5@0E5a@03Q0=024S800h>SL0RXZ80000000J6QP03@d;014A3`0<30X04Q8@014A
3`0@40h2014A3`0O018B400?40/04a@?01<D3`0A4Pd051D@01HG4P0A4Pd051D@01HG4P0E5Q404Q<>
010A300?40/04A8=010A300A4Pd04a@?01DF4@0C50l03Pl:014B3@0@4@`02``701DG4@0F6A8051L@
018E3P0@4``03a8;014D3@0201<F3`0M01@G400E61405APA01DH4@0C5Pl04QD>014D3@0C5Pl05APA
01@G400=40T05APA01LJ4`0>4@X04A@=014D4P0C5aX04aLH018F5`0B5QD051PG01LL5`0E6Q@06QlH
018G3`0H7Q@03Q@=01LM7@0F6al00P0E6Qd02P0H7Qh06b4P01LM6`0J81`06B0J01PO600M91`07B@M
01hT8P0L8R0201XP7P0901TO7@0E6aT06b4O010F500J81h09R`Z03Y0?P2?UI805QlJ00806b@O00@0
6B8M01`U800K91l06R<N0P0M9R402@0K91l07BHQ020Y900K9R8062<O020[9`0Q;BT07RXV020/:002
01d/9`0<01`[9P0L;BL07RlY024b;00T=c408C@_020c;`0S=S809cXg02Pk>@0/?cd0:cdl0P0Y>c/2
02Xl?00402/o?P0/@3l0;T9102m3@P80<DE401l0<dM60355A00iCD`0=TY90396A@11EE@0@eEE03E8
AP0fBDD0?4m;03]>B01:GEL0AUUE03a?C@0lCTh0JG]n05EVK@0kCUD0@eIP04EII01:GVT0E6Qa055U
K01JKWD0C65V051UJ01HKG00CF9S05EZJ`1>Hf@0DfMV0080C61O00L0DVIU05AXI`1DJ6L0Ffm^05Q/
J`1GJfX0FFe/0080Ffm^02L0H7=g05IYK@1NLGD0HGAh06=fNP1/Oh<0GW5e06EhO01/Oh<0IWUm06j1
Q@1[OX40P9BE06EiNP1lSi00M8J807J6QP1mSHd0Nh^;07j<S@21Si00Pi6B08BBT`23Si40Q8nA09NR
Y027TYD0Uj:V08fHW02EX:D0T9^Q09:MX`2MZ:l0Uj6Z09JPZ@2KXj/0VZ6Y09bSZ`2OYZh00P2PYjl0
6P2KXZX0XJR`09nV[P2OYZh0VZ6Y09bSZP2RZJl0UIfP09^SYP2JXZD0UinR09bTY`2h`<<0WZJY0:J^
/@36c]40W:BW09RPX`2DW9h0UIfO09JNX02EWj00UZ2Q09NQXP2BWYh0TIfM0P2AWil05@2@WYh0RiVI
08^IVP2;VI`0RYRK08NEUP24TY<0PHn@08:@T020SXh0OH^;07b;R01iR8D0MHAo06n0MP1^P7@0G6iR
04mQE@17FD`0A5I804EGB@02049DAP0T04YLCP1GJE/0F6aP06=gKP1KL6T0EfaU05Q]IP1EJV<0CfAM
05Y_J01EJV<0D6EN04eRF`18GEH0@eQ?04QOC`10EDD0>Tm003a@A00kCdD0=TU303e=BP16F5P0A5IJ
041AF00fAdl09CHm02Pg>@0/?3/09cLf02Xj>@0a@Ch0<T8o02lo?00b@cd0;3dg0P0[?3H03P0a@Ch0
;3`l02lo?`0a@Ch09SHa02Lf;`0R<RP0:SL^01dZ8@0T<BP09C0Z02Xe<@0I92007RLR0P0L9B000`0M
9R407RLR01lX8`0201LP6`0c01XS7P0P:B@07RLR01/T7`0M8al07R@P01XP700O9B407R@P01XP700W
;BT0:S0/01/Q7@0L8Qh07bDQ01/Q7@0I7a/061hJ01XP700M8al0728N01PN6P0E6aL051XF01hT800G
7AT051XF01lT8@0F6QT051PG02<W9P0J7Qd03Q8A01HJ6@0;3`h04QHE01TM700g>cX0;C4`01`P7`0M
8B001PX901dP7`0[;B`0>C/j01TK6P0H6QT051HE018D4`0A4a804Q@C00<05ADC02L051@B01<C4@0C
4a403@d;01<C4@0G5aD0410>00d=2`0D51805ADC00h>300I6AL05QHD014A3`0;2PP04a8@00h=2`0D
40l06aLF01LC4P0A30`05a<B00X91`0L6aT0:RTW01TH5P0E51803@`:01@C4@0@3`d04a8@00P71P0B
4@d040`901/H4`050P001P<001DB3@0F4`h01P0C40/6014=300301@@3`0:1PD030P700803PX902H0
5A4@01@>3P0A2`/02`D500l92@0C3@d02@<301<=3@0A2`/03`T9010:2P0B30`04`d=01@@3`0<20L0
40`;00`81`0I5A@02`L6010<2`0A3@`04Ph=014=300>2PT03@T800h91P0?2PL040/800l:1`0<1`@0
2`H300d81@0E40d03@P500P30P0D3``03@P500l:1`8040/801H03`X7018=2P0D3``050l<00h91P05
00004Pd:00T40@0>2@H04Pd:01@?300>2@H02@@100d81@0U81d04Pd:00T40@0D3``02@@100d81@0B
3@X040/80P0>2@H300l:1`8040/801@03`X700h91P0>2@H030L400h91P0?2PL03@P5010;200=20D0
30L500/60`060@003PT601@?300@2`P03@L6018<300?2@T03PP8014;2`802P@40P0A2`/07`0=1`L0
3`T900`61P0A2`/01000014;2`0>20P04@/;00l92@0=1`L02P@400l92@0B30`03`T9018<300=1`T0
40X<00`6200:10H040X<00h82P0B30h02`D7018<3P0=1`T040X<01PB500;1@L03`T;01@>40060080
0P0?2@/200d72@803PP:00<03`T;010:300@1@T01P0@1@T01@0B1`/03`@801462P0G31001`0001Co
oooo000Kooooo`0800h=4`0@3aD04a8G01<B5`0@41<03Ph@010@4P0@4144010@400600l?4@0A4A<0
3@d?00`<3P0@41804A4C1P0?3a40200=31803@`A00X93P0=31403`lA00d=3`0>3Q003`l?100>3Ph0
1`0?3`l04A4A00l?3`0@3Pl03`h<00d<2P0B3Pd00P0?2`P0100C3P/04Pd9014=2@0@3PX500l>2P04
01<B3P0?3PX03Pd900l>2P804Q4=0`0?3PX01@0@3`/04A0<010?2`0>3@T040l;00804Q4=00P040l;
00`<200I6QD020T4014B3@0=3PT0:R/V014B3@804Q<>01P02``700h?2P0J6aH06Q/F00l@2`0A4Pd0
4Q<>010A300>3`X03a0;00T:1@0<3@P03Pl;01HG4P0R8ah06Q/F018C3@0?40X04A8<018C3@0A4P`0
51D?018C3@0A4P`2018C3@04010A2`0B4`/04A8:014B2P80414;03803a0:00`=200D5A0051@B02/[
:@0C4a403Ph<014@3P0D4a404Q<A010B3`0?51003A<?01XP700=4`l02a0<01DE4`0A4@l040l>01@D
4P0A4@l03`l=010@3P0B4Q004A4?00h>300A4@l03Ph<00l?3@0B4Q003`l=00d=2`0C4a403`l=02LW
9@0D51802PX800d=2`0?3`d02`/901@D4P0L71X03@d;00/=2P0D5Q<03Q0=01<E4P0?4@h04Q@A00h@
3@803@l<02P03a4>00d?300A4a002@/8014C400:30T061XG01DF500G6AH03a4>00`>2`0?4@h04A<@
01<E4P0G6AH0;Rh/010@3P0A4@l04Q8@00h>300D51804a<A01@D4P0B4Q0051@B00h>300G5aD03a0;
03ho>P0[;2L03Pl:00/<1`0D5A004a@?00h?2P0E5Q4061TD01HG4P0C50l04Q<>0P0A4Pd01@0C50l0
51D@01DF4@0@4@`04A8=00<04Q<>00P04a@?018D3`0@4Pd0418=018D3`0D5Q405aTD00lA3@805ALB
02d02`d801hP6`0C5A003@l:01HH4`0B50l071hI010B3@0G6A@051HA018D3`0E5a805aTD01DG4P0E
61L0720R00hB4`0D61T05a/J01<G5@0G71L051TC01DJ4`0F71@04aT?01PM5P0B61P05Q/O01DJ7P0D
6A`05a`N01DK6P0G7A/0Ff5N02P^:P0B61<09bhW01LN5`0E6aL06b4N01hT8P0I7ad04aTG01/Q7`0L
8R000P0J81h01@0E6aT0:S0^02le=00C71P06R<N0080624L00H08BXU01hW8P0I8Qd06R<N01dV8@0N
9b8201lX8`0@01hY9@0K9b<07b/W01TU8@0Q;bX08c8]01d/9`0M;BP07RlY020a:`0Q<bd08SD_01lb
;P0R=C409CPd02Lj>080:Sdk0P0Z?3`09P0Y>c/0:3Xl02/m?`0_@D<0;40o02i2@@0bATD0=DU803A8
A`0bATD0>De<03Q<B`0oDe80@5AC03Y>C@0lD4l0=DQ603Q;B@0cAT80=dY403e@BP11E4h0>di904QK
F00nDE00LhF604MIG@12E5X0BUeY04iRK@1?Hfd0Cf=[055UK01CJ6h0CfAY051UJ01@IFL0CfAU0P1>
I682055UI00?04eQH01EJFP0DFET05]_KP1JKVd0FFe/05Q/J`1KKfh0Gg=b065eM01QM7P0Jgj2065d
N01/Oh<0JWf10080IgYn00P0JGb006f0Q01^PHD0KX650722Q01cQHD0MHN707V:RP80Nh^;0100NHR8
07R6Q`1jR8/0PHjA08RCU`2;UYX0SIRK08bFV02>V9X0TY^O092IWP2CW:40W:F[09^TZ`2HXJP0VZ>[
0P2LYJh0102OYJl0Y:Ra0:>W/02SYk020::V[`030:>W/02UZK80Y:Ra0080XZJ_00@0XJJ]09nTZP2O
Y:P0WjBX0`2NXjL01P2h_L40Y:V]09ZOX`2OY:P0Vj2T09VNXP80VJ6S00P0V:2R09RRX`2HXZ<0VJ>T
09BPX02CWil0T9jN08nMW@80SYbL0180SI^L08nMWP2>W9d0R9JG08FCU026U9@0PHn?082?S@20Sh`0
Ohj;07N6PP1^OGH0HgEY06anL01hRW`0IWQ/04EGB`18FTh204]MD@0l04eOD`1AHeL0FF]O05eaIP1L
L6P0GG9[05aaJP1KL6T0EV]T059WH01DJF80EFYS05=XH@1?I5d0BUmH04QLD`16FD`0@5=403U=@00c
Ac`0?E590396@`10De80B5YL04]MH@1BHfX0?DiE02hmA00U=3H09SHe02De=00W=cH0;Shk03A4@@0f
AT<0;3dg02/l=P0^?cT0:S/e02Hf<`0Z>SX0:c/k0310?@0Z>cD09SD^02/k<@0W=2/08c0W01`Y800P
:bD08bhZ028]:@0M9R406b@O01`U800P:B@07bPS01hW8P0I8Qd05b0K0P0M9R405`0I8Qd07bPS028X
900S:BD06b4M01XP700I7a/05A/G030f<P0nA4006b4M01TO6`0S:BD06QlK020U8@0K81`05a`H01HK
5`0J7a/082DQ01lT800M8Qh05a`H00806QlK00@06AhK01<G5P0E6AP07b<R0P0@51<0100H71/06AdL
01TM700E6AP201XN7@0301DH5`0F61L05QPG00@05QPG0P0E5aH01P0E6AP04aLF014D4`0C514051@B
01DE4`805aLE00H061PF01<C4@0I6AL04Q8@01dM6`0E5A<2018B400<00`<2P0A4@l0410>01/K6@0C
4Q005A@B00`;2@0J5QD0=c<b01DA400E41006ADD0P0@3`d04@0D4a404A0>014@3P0A40h08b8P020O
7@0Q81h040l=010?300B3P/06AHB01/H4`0/:B@04a0;00l<1`0D4@`04Pl:008040d800H04@h9018>
2P0D40l04`l>014=300@30/300l;2P0601DA400B3Pd040`;018>3@0?2`X040X:100A2`/7010:2P05
00l;2P0@30/03PX900`81`0>2PT00P0B3Pd2010<2`0400h:2@0?2`X04Ph=01@?30803PT601/02`H4
01TD4@0810804Pd:014<2@0@2`P03`X7010;200B3@X040/8018=2P0@2`P030L4018=2P0G4Pl040/9
00d81`0>2@H03PX701<>2`0;1PD040/8014<2P0A30T040/800d81P0>2@H00P0?2PL02P0@2`P03`X7
00l:1`0E40d04`h;014<2@0@2`P030L604Q3@00C3P/200l:1`0@00h91P0=20D03@P500l:1`0>2@H0
3@P500l:1`0@2`P03`X700d81@0>2@H03`X7010;200?2PL03PT600h91`803PP800X03@L700h8200?
2@T040X:00T30`0@2PX03PP8010:2P0A2`/03`T90P0>20P01`0=1`L03PP800l92@0F41004`d=00h8
200<1PH00P0>20P06P0b;2h0;RPZ00h92P0B30h040X<00d72@0<1PP02084014;3@0;1PL03PP:01<=
3`0?2P/04`d?00`7200:10H09b4S05A>D00@2P`030H800d72@0<1PP040X<014;3@0@1@T04@H:0P0C
20`01@0A1PX040D901882`0A1PX040D900803`@800<03P<7ooooooooool04_ooool001_ooooo0P0@
3aD2010?500>010@4`0@41803Ph@00l?400?3`l0410@014A4@0B4Q804A4C01<C5@0?3a40410B01<C
5@0>3Q0600l?4@0:010?5@0E51T03@`A00/:3`0?3a4030`>014A4`0@41003`l?00d=3@802`/;00d0
3`l?014?400B41404@l@014=300@30/03PX9018=2P0C3P/04@`901491P0@2`L040h:00D03`h:00<0
4A0<010?2`0?3PX00P0@3`/0200A40`03`h:00l>2P0?3PX040l;014@300@3`/03Pd90`0?3PX04P0@
3`/03Ph901HG4P0:2`H051D@01LH4`0d=C009BHQ02X[9P0X:B@061TD00X;1P0>3`X0414<00d>2@0>
3`X0414<00l@2`803Pl:00h04A8=00`=200=3PT03Pl:00X;1P0@4@`0414;00h?2@0?40X0414;00l@
2P0B4`d0414;00l@2P80414;00@03a0:00l@200?40P041490P0@4@/0600A4P`03Pl:00T:1@0?3`d0
6a/I010@3P0?3`d03@`:00`;2@0B4a404Q@A00X?2`0C6AD092XV02T_:`0C61@04a<A014A3`0@3`d0
4a<A014A3`0?3`d04A4?018B40804A4?01L051@B010@3P0@40h04a<A00l?3@0Y:BL07AdK01@D4P03
0`4030`:014A3`0<30X04Q8@010@3P0C4a405aLE00d=2`072@H03a4>00`>2`0A4a00418?00X<2@02
014C400D01@F4`0:30T06Q`I010B3`0I6aX05ALF00P:2@000@00A4I5034c<P0E5aH03@l>018D4`0A
4a803Q0?01<E500;2`T051@B01LG5@0E5A<201<C4@80410>00X03@d;010@3P0;2`T04Q8@010A300O
81/04A8=01@E400;30L051D@0P0C50l0100N7aX0;c0[01<D3`0A4Pd200l@2`06010A300C50l05QLB
01LH4`0@4@`04a@?0P0E5Q400`0C50l04aDA01<E4P02018D4@0?01<E4P0E5a@05ALD00`>2`0I6aP0
5ALD01HH5@0I6aP05QPE01DG500=3``04aDB018D4@0J71T05ALD008051HC01h04aDB018D4@0D5Q<0
>3/i08>7QP0c=cH061`K010D4`0E6QH051TE01HK5@0D6A<05Q/E01@I4P0E6QD03aDE01<H6`0D6A`0
5AXM01PM800H7Qh06AlO00X@3P0F71X03aDC01<I5@0K8Ad082HR00XA2P0G7AT2020V8P0T01LM6`0O
9B<07bDS01TO7`0J82005A/K01TO800M9R<08R/V01dV8@0H8A`07BHQ01/T7`0H8A`06B8M01/T7`0M
9R407RLR01hX8P0=61@0:CDc020/:P0L:bP06BPU024`;@0O;b`0830]01lb;P0P<bl08C@`028e<@0R
=C<093Le02Hi=`0W>SP0:3/j0P0X>SX0200]?d00;d5302do@@0Z?3l0:3Xl02e1@00aAD@0=DU80P0g
BdX0500fBTT0>Ti=03iBD@16FUT0AEUH03Y>C@0dB4L0>4]9045AC`0jBTL0@E9<03U:@P11DTX0@55;
04MGE00lC4/0@U5C03i=DP1>GfH0CV5Z0P1?Hf`0301=HFT0CV9Y051UJP1>HfL0C65T04aQHP1>I6<0
DFMU059XIP1AIF@0DfMV05AXI`<0Ef]Z00l0DfMV05IZJ@1IKF`0GW9a069fM@1SMgH0J7Yn06UkO`1V
N7`0O8jB07>5R@1YNgl0Jgf106eoP`1`PXH00P1bQ8P06@1eQhP0MhZ807Z:R@1jRXX0NHV907Z8R@1j
R8X0Ohf@08JAU@2:UIX0S9NM092IX02DWJ40TifO09FOX@2JXjL0VJ:W09bUZP2X/KL0Y:fd09VRZ@2L
YJd0Y:ff0:>/]@2SZK800P2VZK820:FX/@030:BW/02VZK80YjZc0080YjZc00L0YZVb0:JY/@2TYjh0
XjJ[0::UZP2PXjP0Wj:W0080WZ6V00/0VYfR09fPY@2LWj@0UYVN09^OX`2EWIl0UYjP09RPXP2GXJ80
UZ2Q09BNW`02096MW@@0SifM00@0SYbM08nMWP2=Vi`0R9JF0P26U9@0@P22THh0P8n<07j=R@1lRhH0
M8=n06YiLP1`PWH0H79T05U[G@1@HUH0AeU=05MYG@1=GU@0Cf1F059SF@1FIed0GFiU061dJ`1OLV`0
FFiY05M/I`1HKFP0EfaW059WHP1HKFP0EV]V055VH@1>Heh0Bf1K04YNE@1@HUH0?4i103Q<@@0fBT40
?U9>03iDDP12EeP0B5aO05i`M01TMWX0AUAI04EBF00V=SL09CDd02<c<P0W=cH0<40m03E5@P0[>cP0
:S/e02/l=P0]?SP0;Sli02lo?00]?Cd0;3`l02Lg=00U=C009cH_02Hf;00]>S4082dT049?AP0V<B/0
4ahJ02<^:P8072DP02h06b@O01XS7P0J8ah072DP04A=B00B6aH07BHQ02hg<P0N9b808BXU01lU8@0T
:RH06b4M01TO6`0N92008RPT01XP700B61@07bDQ028X900G7AT051TE01`N6`0G6AH08B<P01`N6`0E
5a@0828O01lQ7P0R92406adJ01TK600L7Q/06QdK018F5@0e>CP0If]Z02lc<P0>4Q4051PG01PL6`0K
7ah06AdL01HJ6@0B5QD04A@C100G5aL201HH5`0601@F5@0F6QT00`L600D9200F6aT04aDB1@0D5180
5P0G5aD07QhL01HF501cLg40Kfm]01HF500>3P`06ATG01HF500>3P`01`L5010?3@0?3P`020L5018>
3@0X92<03PX9010;2P0I5A@04Q4?014@3P0B4@l200l>300<014@3P0U92808B0N01LF500:2@L05A@B
01<?300A3@X0:RHS02TU8P0>2PL061@A0P0A3@X2010<2@05018>2`0C3``05A4@01@@3`0B3Pd00`0A
3@`01`0<20L04@d<01@@3`0@30/03@T801@@3`0A2`/0100B30`00`0A2`/040X:010:2P04010:2P03
00l;2P0A3@`04@d<00803`/:00l040`;01PD4`0C3`h02`L600l;2P0E4A0040`;04U4@@0M61D07aXG
00d81@0P6aP03`X701<>2`0@2`P00P0?2PL2010;200B014<2@0B3@X040/800`7100?2PL04`h;00l:
200F4@h01`8000l:1`0A30T071LD018=2P0@2`P01P8000l:1`0J5A802PD40P0@2`P0100A30T040/8
010;200?2PL200@00005010;200<1`@03@P500`7100?2PL0100@2`P01P0A30T03PT600d81@0?2PL0
40/800l:1`<03PT600P03@P500h91P0>2@H040X9010:2P0?2@T03PP800l92@@040X:0P0>20P01P0=
1`L03`X700h91P0>2@H03@P500h91P803`X70P0A30T0700<1`@02`H3014;2P0E3a405Q0B00X41P0A
2`d04P`>01D?4@0C3@l03PP:00/51`0F41803`T;00L20`0<1PP0100001dG6@0=1`T030H8014;3@0B
30h02`D701D?4@070@<030H8018<3P0@1@T401462P0701052@0V6al060dA00l4200A1PX04`P<00h3
1`0Dooooo`006oooool01@0A41H040lE00l>4`0?3Q<0410C00804A4C00/04A4B010@400?3`l03Ph>
00d=3@0=3@l04Q8D00X:300820X04Q8D01@D5P0600l?4@08010?5@0I61d07A`Q018A5P0;2`d03Ph@
010@4P0?3`l200h>3P8030`<00L04Q8B00h<3@0=2``03@/<014=300E4A0040`;008050l<00@04@`9
01<;200C3PX040h:1@0?3PX0100D4`l04a8>018A3@0A40`500l>2P04010?2`0A40`04A0<00l>2P<0
3Pd901003`h:00h>2P0A4Pd02@X500l@2`0@4@`092DP018C3P0I6QD09BHQ024R7@0@4@`02P/600/<
1`0<3@P03Pl:0P0@4@`02@0?40/03Pl:01PI500A4Pd04Q<>01@E400?40/05QLA00l@2P0300h?2@04
00d>200@4@/03a0:00h?2@80414;00T03Pl900h?1`0?40P04149010A2`0A4P`04Q<=01XK5P0;30L0
0P092@L05P0;2`T05ADC014@3P0:2@L03Pl=00lA3P0;40`08bTU0=GKe`2=Thl051TE00l?3@0:2PP0
3`h<01<C4@0A4@l0410>014A3`0B4Q00410>00l?3@0C4a42010@3P1101@D4P0A4@l0>CTg02/[:@0O
7ad02PX8010@3P0D5180410>01HF500A4@l03Ph<00`<2P0410803a4>01@F4`0<3P/02P`901@F4`0F
61D02P`900d?300E5a@02@/802LY9P0H6QL03Q0?00d?3P0>40l06Q`K09nQX02a/k805ALF01/M700C
5A@02`d<00lA400B51<05ADC01/K6@0C4a404Q8@01LG5@0E5A<05QHD01DE4`0@40h05ADC014A3`0E
5A<0414<01<D3`092PD05AHA00X;1P0D5A005aPC00l@2`0A4Pd08b@O00X;1P0E5Q405aPC01DF4@0D
5A000`0C50l01`0E5Q405aPC01PI500C50l0414<014B3P0C5A800`0B51408@0C5A8051HC01PJ5`0G
6AH03a4>01PJ5`051`@04Q@A01XL6@0:30T061XG01@F4`0W:BH05aTF01@F4`0H6QL05ALD014C400D
5Q<05APE03Pm>@0>4Q4020`:018G4`0P9B406AhJ01<H500B5a<05a`G01HK5@0F6aL04QPH01HL7002
01HK7P0Y01TN8@0H7Qh082HV01DK6`0N92<04ALG01TO7`0I7ah051XF014H4@0V;2P05Q`H02dc;`0O
9B<05A/I024W9@0H7Qh07B<S01HL700G7Ah0;CHc02df<@0P:B@05AhI01PQ700J8ah06B8M01XS7P0L
9B007RLR01lX8`0O:B<0<Cdk02Lc<@0?6aT07B`Y02/j=`0M;2T07Rh[01l`;@0N<Bd00`0O<Rh03`0T
=cD09STg02Lj>00X>cT0:3/j02Pj>P0U=cL0:cdn0312A00_@D<0;T1302do@@0_@d@0=4Q703U=C002
03Y>C@0X03]?CP0iCD`0?U9A04AHE`13EeH0>Ti=03=7AP0kBdX0=4A103]<AP0mCTP0CUmG04AEC@19
FU@0?De:04MGEP1AH680DV5V04mQI@1<GfH0C61W04eQJ01?HfT0DFI[059WJP1AIVP0CV=T04aQHP1=
Hf40CfES055WI@1EJFP0DVIU05IZJ@1CIfH0G71_05=WIP1IKF`0G71_05ibL@<0HGEd00h0HgEi07:4
R01[OH40L8:606n1Q@1`PXH0KGn306j0Q01aPhL0LhF907B6RP1gRHX0NHb:07b<R`80O8b<01@0O8Z;
07b:S023TI@0SIRL08nJW`2=V9h0TY^R09NPYP2FX:80Uj6S09VRYP2FWj@0V:6V0:>//P2RZk80VjB[
09jW[`2V[kP0Z;6j0:N]]PD0YjZc1@2XZk@05@2XZk<0Y:N^0:BW[02SYZ/0XZFZ0:6TZ@2PXjP0XZFZ
0:2SZ02RYJX0W9nT09FHW@2HW:00VIjQ09RPXP2KXjD0VJ>T09NQXP2DWYl0T9bL096MW@0308nMW@0e
092NWP2?WIh0SifN08bJV`29UiL0QiFE08FCT`26UI80PY6>07j=R01mS8L0MHAo06UhL@1]Og<0EfUK
04eOD@19Fdl0AEM;04mQE@1=GU@0Cf1F05=TFP1GJ600GFiV05iaJ`1DIf<0GG9]05aaK01DJF@0CV=N
055VH@1GK6L0DfQS04mTG`1@IF00DFIQ059UG`1BHeT0@51603mCBP0iC4H0?59>04EJF`12EeX0?E5E
045DF017EU/0<3m2034o@P0R<S809SHe02Ph=`0Y>CP00P0W=c@0300/?3T0;Sli02dn>00Z>cD0;3dg
02hn>`0b@T80<D5102Hf<`0V=S40:cXc02Lg;@80:cP_00/0F6EL03@o>@0B7AT08B`X024Z9@0R:bH0
7bPS01/T7`0L9B007bPS04M@B`0201LP6`0302`e<00O:2<08R/V008082HR00l06AlK01LM6@0K8Ad0
7B<O01`R7P0D6QH082HR01dS7`0D6QH0720L020R7`0G6AH08R@Q02HX9@0F61D00P0J71T0300K7AX0
6Q`I01TK600J71T071lM01TM700H71/06AdL018F5@0D61L06QhM01TM70806QhM00<05QXI01<G5P0E
5QH0100F5QH0200E5aH07R0O00lA400F6QT082@S02@X9`093P`04aDB0P0D51805P0C4a404Q8@018B
400@40h04A4?03De<`2][J/0YjNU018B400K6aT051@B00X:200P81h06QXH01LF500K6QP04A0>00X7
1P0H51<02`L601TD500C3`h400l>300E010?3@0C4Q003Pd;00h=2`0G5Q@051<A00/:200G4a804`l=
018>2`0:1PD04Ph<01DA3P0@30/040`:010<2@0A3@`04Ph<01<?3P0D40l04`l>00@04@d<00P04`l>
014=300E4A004`l>00d9200B3Pd04@/;018<30804`d=00<04P`<014;2`0@2PX01@0@2PX0100?2`X0
4@d<018>3@0A3@`200l;2P0701`H5`0X92<05Q8A00T5100C3`h0510?01`G500200@0000600/60`0A
30T03PT6018=2P0?2PL03@P50`0>2@H04P0A30T04Pd:00l:1`0=20D03PT6010;2008108081/H01TD
4@0@2`P05A0=04Q3@00F4@h0100000h91P0?2PL02`H300`710803PT600X03`X700h91P0>2@H03@P5
014<2@0O6QL02`H301HA3P0:1@8040/80P0A30T04@0B3@X04`h;01<>2`0C3P/04@`9010;200A30T0
4`h;018=2P0@2`P03`X700d81@0<1`@03@P500l:1`0@2`T03`T900<03PP800@040X:00d71`0C3@d0
3`T90P0>20P09@0=1`L03`X700h91P0>2@H03@P500h91P0?2PL0100000/60`0F4@h03@P500D0000>
2@H0100000X41P0=1`T040X<00h82P0<1PP02`D7014;3@0;1@L03`T;00D00@0M5aT05@lA014;3@0b
;2h030H800P3100H4Q@05Q0B00`6200F4180208400d82@0?2@/00P0@1@T201462P8040D900H07A8F
01<8300=0PH03`@801872`0@1@TDooooo`006oooool0200A41H040lE010?500@3a@0410C014A4`0?
3a403`l@100?3`l01P092@/06a/M01@D5P0<30h0410B00h>40H03`lA00L03`hD01PG700^;C807A`Q
00L72@0C4aD03Ph@00803Ph>0`0?3`l01`0@3Pl04Q0A01TG600G4a@03`/:014=300F41000P0E40d0
100G3`d05`l<01D@300@3PX500l>2P03014@300@3`/040l;00<040l;0`0?3PX05P0@3`/04A0<018A
3@0A40`040l;00l>2P0@3`/03`h:00l?2`0=3PT03a0;010A300>3`X05AHA00`=200@4@`04Q<>00l@
2`0<3@P03a0;014B3@0?40/2010A30804A8=00H0414<018C3P0=3PT0824L02PY900F5a8200l@2P05
010A2`0>3`T03@h800d>200@4@/00P0?40X00`0@4@/04A8<010A2`0200l@2004010A2@0@4@/04A8<
018C3@802P/601404A4?00h>300@40h03`l=00l>300;2PP04A8?014C400;40`06b4M07EkM`1EFeL0
3a@@01<C4@0E5A<03`h<018B4002014A3`0@01<C4@0B4Q003`l=00d=2`0A4@l03`l=010@3P0D5180
4Q8@00l?3@0C4a403Ph<01LG5@0?3`d03Ph<00d=2`804Q8@00X04A4?010@3P0@40h030h;018D4@0A
4a003a4>01dO700@4Pl04aDB0P0B51406@041P<05QPE00L91P0@4Q4051HE00/=300E5aH0;S0_02d_
;P0C5A@05aTH00X<2`0L7Qd092HU00lA400G5aD051@B00`<2P0B4Q005aLE014A3`0E5A<04Q8@00X:
200B4Q000P0?3`d0400A4Pd04a@?014B3@0C50l03@h901<D3`0B4`h03Pl:00/<1`0E5Q402P/601/L
5`0G61<051D@018C3P0A4Pd2010A300701@E400F5a805aPC01DF4@0B4`h04A<?018D4@04014C400>
010B3`0P8Ql05QPE010B3`0U9b@0:2XW01TK600K7AX0418?01LI5P0C5A808B<P01HH5@0D5Q<201/M
6P0Z01DG500F61D05aXF00/>2P0J7aX051TC018G4P0H7AT05a`H01DJ5P0F6aP06QhM01HJ600H71/0
5adK01XP7P0J81l05adM01XP800H7Qh041DH01/P8`0F6ad06b0S01LL7`0I7R407B<O01PO600F7AH0
6R0L055GD`0J81h04QPF02D[:@0L8R806b0S01lT9`0K8B805AhK01XS7P0O:2<06b@O0P0J8ah00`0L
9B007BHQ020Y9002028[9P0@028/9`0I9B<0:3Ld07f<R@0_?S/07Rh[02Hf<`0P<2d08C<_028e<@0S
=S808SHb024f<@0V>CL09cXh02Tl>P<0:C/k00T0;Cm102m1@`0^@480;Cm302m1A@0a@dD0;T9303I:
B@0iCD`00P0hC4/0100jCTd0=TY903Y>C@0jCTd203]?CP0D03Q;BP14E5<0>TY703m@BP1oT8T0cmgH
07>4O019FU<0B5QE04aLFP12DU80CUeP04]MH01@IFL0CF9U04aQH`1>I6D0CfAV04mTI01?IF@204iT
HP0<051VI01DJVP0EVaZ05U]K01BIVD0Ffm^05IZJ@1cQhH0H7Ac05a`K`1OLg80HWIe0`1SMgH0301W
NGd0LH>706UkO`1[OH40KX2407B6RP1_PHD0L8:607:4R01eQh/0MXR<07Z;S080OHf:01H0PI2>08>A
T@25Ti@0QY:E08ZEV@2AW:80TYbS09:KXP2DWJH0VJ6W09NOXP2IXJ@0Vj>W09VPYP2KXZP0X:N^0::Y
/@2TZk<0XjZc0::Y/`2TZkD0Z:jg102Z[KH20:^^]`80ZZff00D0ZJbe0:R[]02WZ[80Y:N^0:BW[004
0:FX[@030:BW[02OXZL0W9nT0080WZ6V00L0X:BY09^PX`2IXJ<0VZ:T09RRX`2FX:40TYbM0080TIfM
0`2?WId2092NWP0>08jLW02<VYX0RYRH08RFUP25U940Pi:?07f<R@1hQh80NHR307:1N`1UMF/0G6iR
04aND01;GDl304mQE@0G059SF@1FIeh0FV]S05a]I`1OL6X0GG1Z05iaK@1HKFP0EV]V05U^J@1JKfX0
EfaW04mTG`19GUT0AEYE04MLE`19GUT0BEaG041AB00jBd<0?e9=03M:A`0lD5400P16Feh03016FUh0
=d]=03a<C@0a@4009C<c02`l?00X>3L09SHe02De=00T=3408c<`02Xj=`80;Sli00<0:c`f02`m=`0_
?c`00P0eADD03`0]?CX0:S/e02dl=@0Y>Bl09c@[02<`9`0`?C@08bhX01`W8`0Z=C408b`W028[9P0O
:2<072DP01hW8P02024Z9@0<01hW8P0H8A`07RLR01lX8`0Q:RD082HR01LM6@0L8Qh07bDQ01dS7`0L
8Qh08BLS0P0J81`00`0O9B406R0L01TM6P0202@V8`0=01TK600L7Q/07R0M020R7`0J71T05ALD01`N
6`0P8Ql07AlL01LJ600J7Qd06alN01DI600201HJ6@0701LK6P0E6AP05ATH01`P7`0E6AP051PG01XK
6P0201LE5P0301LF5P0F5QH05ALF00804aLF00D03Q8A01LM6`0N92804QLE01@F4`0201@D4P0H01<C
4@0B4Q004Q8@01hN70092@L05QHD01/K6@0W9bD051@B00h>300D51805QHD014A3`0M7A/05A@B010?
3@0B4@l04`l>01`H5`0B3Pd04Pd=01HB4@0F5A<051<A0P0@3`d0400A40h04Q4?01@C4@0D4a4030/9
00h=2`0A40h04@d=00h:2`0C3`l04`l@018>3`0>2PX03`/<014=3@0B3Ph2018>3`05018>3P0B3Pd0
4@d<010<2`0?2`X00`0@30/01`0?2`X04@d<018>3@0B3Pd040`;014;2`0B30`00P0C3@d00`0B30`0
4@/;010:2P05010:2P0H010<2`0?2`X04@d<018>3@0@30/03PX901HB4@0O6aX05A4@00l;2P0A3@`0
30P700l:1`0I51403PT602@O700810803PT6010;200>2@H03`X7018=2P0?2PL030L40P0@2`P0400?
2PL03PT600h91P0>2@H050l=01dH5`0A30/04Pd;018=300=20D050l<00/60`0B3@/03PT600P40P0B
3@X200l:1`0:010;200?2PL03`X700`7100g<Rl0IV5N018=2P0<1`@04@`900h91`803PT60P0?2PL0
6P0@2`P04@`9010;200?2PL040/8018=2P0A30T040/800l:1`0>2@H03@P500h91P0?2PL03`X800h8
200=1`L030H600d71`0>20P02PD501XD500>20P040X:014;2`0@2PX03`X70P0>2@H06`0=20D03PT6
00l:1`0C3P/030L400/6100>2@H030L401@?300@2P/03@L9014;3@0;1@L03`T;01H@4P0910D03PP:
00`6200A2`d03@L902LQ8`0>2@X030H800l:2`0A2`d05Q4B00/51`0200h82P0400`6200:10H040/<
00h82P8040D90P0?10P201052@0300l4200B1`/04PL;00803`@800<040D9ooooooooool04_ooool0
01_ooooo00X03PdC010?5@0B4AH04Q4F010@4`0>3Q0030`>00d=3P0>3Ph03`l?0P0@41001@0A4A<0
7QhP01HF600D51H06a/M00L03`lA00L030/A014@5@0K6Ql061LL010@4P0C4aD03`lA00<03Ph>0P0=
3@d03@0>30d04@l@01/I6P0H51D030P700l;2P0@2PX04@T701H>300K4a404`/800T4000@3PX01@0?
3PX0100E51004Q4=00l>2P0>3@T2010?2`<03`h:00@040l;014@300B4@d04Q4=0P0C4Ph03P0A40`0
40l;014A30092PD04A8=010A300A4Pd04Q<>00d>2@0;30L03Pl:01DF4@0G61<04a@?0P0@4@`500l@
2`0<00`=200>3`X01`P400H70P0B4`h04A8=00l@2P0B4`d03a0:00d>200>3`T0414;0P0?40X00`0A
4P`04a@>018C3@02014B2P0N010A2@0@4@/0414;00l@2P0B4`h07b0K014A3`0>3P`06ATG02/[:@0>
3@/04A0>01<D4P0A4a003A8>00/A3@042PH061hJ01LL600:2PP03@d;00d<2P0A4@l0410>014A3`0C
4a404Q8@00h>300B4Q0051@B0P0@40h0300B4Q003`l=00h>300D518030`:01TI5`0<30X03@d;01TI
5`0E5A<04Q8@014A3`80410>00`07R0M00h@3@0K7AX0<C<`04A6@`0C5A804Q@A014C400@4Pl03a4>
018D4@0A4a0300d?3P0601@F5@0@4Q404aDD010B4@0:30/02`d<0P0N81l0100?4A004A4?014A3`0B
4Q0201HF500C01@D4P0U9B<08B4O01LG5@0Q8Al07alM01dM6`0@4@`03a0;01PI500=3PT06AXE01<D
3`0@4@`04a@?01PI500J6aH05QLB01TJ5@0300l@2`05010A300A4Pd04A8=014B3@0B4`h00`0E5Q40
100D5A404aDB01<E4P0C5A82014C400>02DW902SYJ80Bde:01lQ7P0B51400040018D4@0C5A806A/H
014C400B51403Q0=01<E4P0D5Q<201LI5P0;01DG500G6AH07R4K01PN500G71D07R<L018G400I7QP0
5Q/F01PM6@0H71/00P0H71d0;P0Y;Bh051XH01LM6@0G7AT05Q`J01TO7@0G7Ad06AhQ01PM800G7200
7b@X01<H7P0J7b@06R0L01/R6P0J8AX041HB00lE4@0B61D08BLU01`R8P0N92@06AhQ01/P8`0I7R40
6R<P024Z9@0[=2l09c0[01lX8`0J8ah072DP01dV8@0P:B@08BXU028[9P0R;2L0:cLe01d[:`1EHf<0
:SPh020_;`0A8B007S4_028e<`0U>3H202Hj>00:02@h=P0U>3H09cXh02Tl>P0Z?3`0:cdn02Xl?P0a
@dD0<D=602m1A@80;T1403L0<D=502m3A00gBdX0>Ti=03M;BP0eBDP0>4a;03A8A`0iCD`0=TY903M;
BP0jCTd0=dY803Y:B@0oCTX0=dI107b;Q02da;X0IgM]04IECP1;FUL0AeIC04mMGP1IIfX0CEaO05AY
I`1=Hf40Bf5O04eSH01=Hf40Bf5O04eSH@1?IF<0DFMU05E[J@1HKV`0FFm]05AXI`1@I6<0HgMf05mc
LP2;Wih0KH6005]_KP1OLg80HWIe06IjN@1YOG`0JWim06eoP`1^P8@0JWb007:4R01^P8@0LhF90080
LXB800@0M8J:07N9S@1iRhl0OXn@0P21THh04`24Ti40R9JF08^IVP2=VY`0SiZN09:KXP2EWZH0Uj2Y
09RQZP2KXjT0VZ:U09bTY`2OYj/0WJBZ0:2W[@2U[;<0YJbd0:N^]P2W[[L00P2U[;H00`2Y[[L0Zjjg
0:b_^0030:f`^@80[k:k00D0[K2i0:Z]]P2Y[;D0Z:^c0:NZ/@020:NZ[`<0YZV^00<0ZJba0:JY[P2P
XjP00P2MX:D02`2LX:@0WZ>V09^SY@2IXJ<0UZ2Q09BNW`2BW9d0TinO09:NWP2@WYh0SifM0080SYbL
01T0TInO08jLW02;VIT0RYRH08VGU`25U940OXf807N6P@1`OgX0M8=l06mnM`1RLVP0BeeA04=EA`18
FT`0DF=G05EWG01DIE/0EVMO05Y[I01NKfT0Gg1Z05i_JP1JKFT0G6m]00<0Ffm]01P0FFe[05AXIP1>
HV00Ae]I04EIE`18G5X0BEeK04IIE@16EE00?De803M:AP0a@d<0>4e?02m7B`0W?d<0=TY=03A8B@0d
A4@093<a02He<P0c@d809SHe024a<00R<S4202De<P0@02<c<00W>380:CXd02Xk=@0[?3H0;3`i02Xj
>P0]?Cd0;cll02Ti=00R<BX093@Z020]900S<2L09c@[02Ha:`808bhZ00@08R/V01dV8@0K91l072DP
0P0N9b80200P:B@07BHQ02lh<`0K91l082TT01/T7`0L8Qh05Q`H0P0N9200100L8Qh07R@P01XP700K
8Ad201TO6`0>01lU8@0X;2P05ALD01PJ5`0P8Ql06adJ02@V8`0L7Q/05QPE018D4@0M7a`092HS02LY
9P0S9R@201HJ6@0F01TM700D61L05a/J01LK6P0?4a807b<R03Di>00O8b803a<B01@D500H51D05Q@E
01HE5@0E5AD051HE01`P7`0E6AP06AlM08N=R`2:T8h02a0>01<E4P8051@B0`0C4a403P0@40h01PH4
014A3`0<30X03@d;00l?3@0L71X03@d;00X:2@18B4H0]kNe0491?`0H5aD071/I0P0C3`h01P0E4A00
6A@D01LC4P0I61H05QDC00d<2P803`h<00d040l=00T81P0@3`d02PT701<B400>3@/05Q8C01/F6P0:
1@T04@`@00d8300E41@040/?00<04PdA00@04@`@00l;300A3@`04@d<0P0@30/02@0A3@`04Ph=00d9
200N6QT04`l>00`81`0C3`h03`/:010:2P04014;2`L040X:01P040`;00`81`0=2@P040`;00l;2P0=
2@P03PX900/71P0=2@P04@d<00h:2@0:1PD03`X7010;200:1@804@`9018=2P0M61D040/8014<2@0E
40d06QDB01@?300>2@H200d81@0@00h91P0?2PL03`X700h91P0R7AX0ZZFR01hI5P0@30X01`8001TD
4@0:1@8061<@014<2P0=20D06QDB00d81@8040/800L04@`9010;200@2`P03@P501TD4@0^:BH03`X7
00804Pd:00@02`H5014<2@0A30T04@`90`0@2`P01P0=20D030L400h91P0?2PL03PT600d81@803PT6
00D03`X700h91P0>2@H03PT700h8200300d71`0800l92@0I4a<0;bTY01LA4@0D3Ph03`T900/51@0?
2PL200h91@0F00d8100>2@D03`X600X50@0>2@D05A0<00/60P080`00:B@Q01dG5`0>20X03`T;00@0
00090`D04@/=01D?4@0<1PP03@L900T31@0:10H01`8300l92`805Q0B00T04@/=01H@4P0C3@l03@L9
02HP8P0:10H030H800h82P0?2@/00P0@1@T200h31`8040D90P0B1`/201<8300301462P0=0PKooooo
01?ooooo000Kooooo`0800d<4P0@3a@04a8G01<B5`0@41<03@d?010@4P0@414200h>3P0800d=3@0<
30`03`lA00h>400000801@D701XJ700C4aD600l?4@803@`A00<020P:010@4`0G5aT00P0A4A<04P0@
41003`l?00d=3@0<30`02`/;00l>3@091`P03`h<00d92@0;1`H04`l>01<>3P0D3``071LD02<N6`0E
40`02@@0010>2PD03`h:00D08B0L01XI5@0D4`l03`h:00h=2@0400l>2P0H010?2`0A40`04Q4=018A
3@0D4`l05A@@018A3@0@3`/0410<00L80`0>3`X02P/600d>2@0>3`X05AHA01@E400?40/04Q<>01HG
4P0C50l03a0;010A300?40/03Pl:0P0=3PT03@0B4`h01@H100X;1P0A4Pd05QLB01LH4`092PD0414;
01<D3P0?40X03@h800h?2@0A4P`00P0@4@/01`0B4`d04a@>018C3@0B4`d04A8:014B300@4@/00P0?
40X06`0<3@P08b@O010@3P0A4@l07AdK038b<00B4Q805ADE014B4P0<40l041@C00lE4`0F71X03A<A
01DJ5`0J71T04a<A00d=2`0A4@l0410>014A3`0C4a404Q8@00h>300F5Q@061PF01<C4@02014A3`0C
00d=2`0B4Q004a<A00/;2@0?3`d030`:01<C4@0F5Q@0410>00h>300@40h04A4?018B40071`D0418?
018D4@072@H06adJ00/=2P0200`>2`0[00/=2P0B514030h;01@F4`0E5a@03Q0>010B3`0;3@`04A<A
00lA3P0<3P`03a4@01@F4`0;3@/02@/:01<E4P0C4a404A4?010@3P0<30X03Ph<018B400E5A80414<
00D60@0@4@`03a0;00/<1`0@4@`02P/601PI500;30L0824L01<D3`0@4@`02``7018C3P0A4Pd04Q<>
00`=200B4`h04A8=010A3002014B3@03018C3P0C50l04a@?00<04a@?020051DA01@F4`0D5Q<051HC
01<E4P0A4a005ALD08J8Q@0m?c`051HC00X<2@0L7Q/05QPE00`>2`0M7a`0418?01PJ5`0:30T05QPE
01@F4`0C5A804Q@A01@F4`0H6QL05APB02D[8@042P008BLN01PM5P0R9b405Q/E01DJ5P805QXI00@0
7B4P03Xn?P0@5Q@051XF0P0E6aT06@0H7Q`05adM01TN8@0E6Qd06AhQ01HK7`0N8bL08BH[02H/:P0A
5a<04QPE02P^;00630X08bTW02P^;00A5aD07B<Q01XP7P0E6a/061hM01PQ700K9Ad07RLR01XS7P0F
7aX00P0K91l05P0L9B007bPS020Y900Q:RD08B/T01XV8P1@Ge`09cHc020_;00Q<Bh09cLd01/^:P0O
<Rh08cHb02@h=P0U>CL08cLe02Dh=P0W>SP0:C`j02/m?@0/?Sl202`n@00V02m1A00a@dL0<4960394
B00dATX0<dM803a@C`0nDU40>De<03M;BP0jCT`0=4Q703Y>C@0hC4/0>4a=03Y>C`0dATP0?4a<04=A
DP0nC4`0BUUF04aME`18FE<0?De905QXI@1<G5/0BEUI04iMH013EEL0DFIT04]QG`1:H5h0CVAR051V
I01>I680D6IT059XIP1DJVP305E[J@0B05U]K01BIVD0H7Ac051TH`1eRHP0Cf=R065eM01SMgH0IGUh
06UmO01/P7l0KH6006YlP01fR8`0L8:606j0Q01[OH40MXR<0P1dQXX0101gQh`0NH^?07f<T@22TI<2
08>CTP0C08JEU029UiP0S9ZK092MW`2BWJ40TY^R09JOYP2JXjX0VjB]09fU[02NYJ/0WjJ/0:2W[@2L
XjT0WJB/0:F[/`2VZ[<0YJVb0:Z^^0020:jb_@0E0:f`^P2/[kP0[Zjh0:j`^@2^/KX0/;2j0;:c_@2b
]Kh0/;:k0:j^^02Z[KH0ZZ^e0:Z]]02Z[K80ZJbb0:NZ[`2VZJh0YJR]0:>VZ`2UZ:d0Y:N/0080X:>X
0240XJFY0::WZP2OYjT0WJ>V09RPXP2GWj40UYnP09FOX02CWil0TYjN092LW02>W9`0SY^K096OW`2>
W9`0RiVI08ZHV029V9D0QIBA07j=R01gQX40L7mj07F4O@1`OgP0I7AZ05][H019Fdd0A5I804aNDP1J
K640HgAZ05EVGP1IJV800P1MKVP0;`1KK6H0EVUU051UH01_Q800MX^6069fM01@IF40EV]V04MKF@13
Ee@0@eQC04UMF`1;H5`0AeaG04IGD@0jBTH0<DA003=7A@13F5P0=4U:0397BP0lDE40A5IF03i>C@0[
>CD0@U5>02`k>P0U=C@093@a02@d<P0Q<Bh07bl/02<c<00U=S009cPb02Pi<`0W>3809cLd02/k>`0_
?ch0=dM602ho>P0T<b`0:3L`02Hc;00P;BH09S</00<09S4]02L092dX01`U800K91l07bPS020Y900O
:2<08b`W05MPF`1nQh808BXU01HO6P0R:bH06R4K01TO6`0L8ad05A`E01@J5P0J8A/05ahG02@Z9P0N
91l03A@=01lU8@1MHUh0<cDb00d?300I6aP07R0M02/]:P0S9B80828O01XL6@0K7AX061XG01XL6@0G
6QP05ATH01TM700G6aX00`0H71/01P0B5QD05QXI02DY:00E6AP041@C01PH60805Q@E00X05QDE01DE
5@0D5QD030h=01HJ6@0D61L0Ngmn07f1P00E6QT04aDB1@0D5180600E5A<06ATG01<C4@0L71X04a<A
01@D4P0<30X061PF01TI5`0g=cD0`/;003He<`0?3P`05aHD018>3@0A3@`04`l>014=300?2`X04a8@
014@3P0:2@L03@`:00l>30804A0>00/05aHD00P71@0?3P`040l=014=3P0j=SL040`=01DA4P0F4Q<0
2@D6014<400201<>4P03018=4@0@2`l03PX;00804Ph=0P0A3@`301<?3P0702l[:P0K5aH02PH5014=
300>2PT03`T9010:2P02014;2`03010:2P0?2@T040X:00D040X:00<040`;00/71P0;1`H00P0?2`X0
4`0>2PT03`/:014=300A3@`020@300X61@0C3`h040/:01HA3P0U81d03PT601<>2`070P004@`901<>
2`0I51407aXG01LB3`0A30T00P0<1`@0400>2@H040/800l:1`0>2@H03@P501hI5P0?2PL05Q4>00l:
1`0D3``02PD204a7A015@3d0100001PC400:1@<200h91P0:00l:1`0>2@H03PT6010;200=20D03`X7
00h91`0400002`H300l:1`803PT600T03@P500`7100;1P<03PT600l:1`0>2@H03`X7010;200?2PL0
0P0=20D04@0?2PL040/800l:1`0=20D03PT700l92@0@20T040L800l92@0A2@X02`8302<M7@0>20P0
4PT:00l92@0>20H03`X700803PT502<03@P400h91@0?2PH04@`800X50@0>2@D03`X600L2000=20D0
4P`<00H00P0C2`h03@@7014;3@0C2`h04@P;00T31@0B2Pd01P0000d72@0E3A004@P;00X41P0=1PP0
2002014:300@2P`06A0C03lg>P0A2`d04@P;00`51`0@1`X04@H:00l4200200d21P0300l4200A1PX0
4`P<00803@@70P0C2Pd00`0=10Ooooooooooo`0Booooo`006oooool0100E5AP04A4C00h>400@4182
014A4`06018B500;2`d04a<E00X:300@41803@d?1P0@3Pl0100?3@h05Q@E00l=3P0A3a0201<A4P05
018@4P0=2`d03@/<01<A4`0C4A800P0A3a001@0>30d03@/<014?400D4Q<051<B00803`h;0P0?3PX0
4P0>3@T03`h:018A3@0B40`04a4=01@B3P0A3`/03P`8010?3@0A40h02@P6018A3`0:2@L040l=01@C
4@0A40h03`h<00h=2`803`h<00P03`l=010@3P0?3`d0410>01@D4P0D51<02`/:010@3P803@d;00T0
410>010?300=30P03Pd9010?2`0?3PX03@`801PG4`0I61@00`0@3`/01P0A40`05ADA01@E400@4@`0
3@h900h?2P<04A8=01<04a@?014B3@0@4@`04Q<>010A300G61<06Q/F00l@2`0>3`X04a@?00T:1@0E
5Q403Pl:01@E40092PD04a@?014B3@0A4P`0414<00803a0;00@0414<00`=200C50l05QLB0P0A4Pd0
6`0?40d03@hB01HH7P0R92/0Q8N=04]>D`0?4aH08BDW069VI`0F6QX041@C00hA400@4Q403Ph>014A
4@0@41003`l?014A4@0?3`l04a<C010@400<30`05ADE014A4@0@41004Q4?014@3P02010?3@09014@
3P0B4@l040l=018A3`0C4Q004A0>018A3`0C4a40410>00804Q8@01h0410>014A3`0C4a404A4?01<C
4@0?3`d0410>01@D4P0=3@/04Q<?010A3@14AD00DE9>018C3`0A4Pd051DA00l?300=3PT0410<014A
3P0@40d04aDB01@F4`0@4Pl0418>00X<1`0A4`h03@l:01<F3`0A50`2018E3@0E010C300B4`h04Q<>
010A300B4`h04a@?014B3@0B4`h04A8=010A300A4Pd04Q<>01<D3`0@4@`04Q<>01@E400C50l04A8=
00l@2`0B4`h04a@?00<051D@00P07R0L02HX9@0I6aP051HC01<E4P0>40d04Q@A01PJ5`804aDB00H0
5ALD00lA3P0C5A806Q`I01TK600H6QL201<E4P0901@F4`0`<Rl03Q0=01TK600Q8b006adJ01HI500K
81T06QlH00806AhG03d0:RlX0415?P0K81X0724K01LL5@0O91h051TC01@J600E6aX061hN024W9`0@
5QH06AlO014G5`0D6QX06R0P01<I6P0E6Q`07B<U01XR9P0G7R<05alR01/S9@0H82805b0N01dV8`0K
91l06B<K01XT6`0I8aT05b4G01dT6`0H7aL082LP01hT800Q9b<08BXW028[:01BFeP07bXT02/f;P0L
9al08RlU020]900T<RX093<[028a:@0R<b/09CH_01TZ8`0X>S@09CPb02Hi=00T=c<0:3/i02Lk>P0]
@D00:Cdl02m3A00/@440<4A50080;d9600H0;3m30354BP0eB4h0=DQ=0395B@0dB4X203M;BP0A03M;
B00eBTD0<TM303I:B@0hBdh0?U5F04QKHP0oD5X0@U1J04MDGP1<FV<0AEEL03e?D`14EUX0@UIG04=J
F@18Geh00P18H5d05@1<Hf<0C61T05MZK`1EJ6d0DFAY05=WJ@1GJVd0G71b05eaLP1CIfP0EVY[05]_
KP1DJ6L0EFMW05Y/K01iRh/0KX2005MYJ@1VN7P0I7If06IhN00206]mO@090722PP1hRXX0L8>706j1
Q@1aQ8P0LH>707>5R@1iRHh0NXV>0080NhV>00<0O8Z?07n<TP24TYH00P26U9H01P2:UiT0T9^O09>N
XP2HXZH0U9fR09FLXP80WjJ/00@0WZF/0::Y/@2PYk00XjNa0P2WZkD05P2XZkL0Zjfi0:na_@2a/[h0
[k2l0;6b_P2c/[l0];?00;:a_P2b/;d0][G10;Bc`02d/[l0]KC00;Je`P2d/[l0/Jnl0;>b_`2][;P0
[:nh0:V^]@2X[;D20:V^]0040:N//P2VZjl0XjR/0:6VZ@80XZNZ00@0XJJY0:6UZP2PY:T0WZ:V0P2L
X:D0702LXZH0Vj>V09VRY02FWj40TifO09BNX02FXJ80TYjN096MV`2>VYP0S9RF08VET`23Sh`0P8b8
07f9Q@1kQh<0Mh=o06mkM`1YMVl0E65G04mND@1DI5L0FFUL05QYG01IJel0DfAJ05U[H@1HK68205AX
G`0705U/I@1DJF80FG1X05=ZHP1>IEh0CVEM04]RFP0204AKE00/04AKD`13FU<0AEaD04IME@0nE4d0
?UA<03Y@B@0gC4H0=T]503Q<AP0iBdL0<D4m03a;A`0M:RL0;c/g02Th<`0Z>SD08C4]01l`:P0S=2l0
8c@^020a:`0W>380<T<m02Pi<`0dACl0;d0j02Tj=@0Z>3L0:3Hf02Le=@0W=C@0:3@c02Lc<P0W<C40
9S0`02<];@0Q:BX08RX[02@]:`0W<BT07BLO01lY8@0R;2@2024Z9@0803Q1?00_>3D0@T]801/T8@0O
:2D04a`G01`R6`0L8AX301dR6`0801/P6P0Q9Ql092TR01dR6`0Q9Ql051TB024V8@0K81`2024V8P04
01TN6P0O92006b0L01PM6@807B8N02<06b0L01<H500L8Ad05AXF01TN6P0H7AT051TE01PM6@0D6AD0
6b0L02DZ9P2FViL092TU01HK5`10@T005QHF00h>3P0F5QH0820P02@T900G5aL06AXI01/L6`0G61P0
5QLF01<D500C4a<051@D01HF5P0G5aL05QHF01DE5@0@410051@D01HF5P03018B4P0801@C4@0B4@l0
51<A01/J600L6aT05QDC01PG5@0B4@l301<B4008018@3P0C3`h04`l>018>3@0E4A00510?01HB4@0C
3`h2010<2`804`l>00<03`/9018>2`0B3P/00P0A3@/0100B3Pd04`l>018>3P0A3@h2010<3@03014=
3P0B3Pl040X:00804P`<00D040X:014;2`0B30`04@/;010:2P0200l92@0D010:2P0A2`/04`d=00l9
2@0G4A406Q@D01<=3@0B30`04`d=018<300@2PX03`T900h8200?2@T04P`<010:2P0?2@T040X:014;
2`0B30`6010:2P0600`7100C3P/071LD00/6100?2PL030L40P0?2PL2010;200300l:1`0>2@H03`X5
00803`X50`0?2PH00`0B3@X02@@4014;2`0200l92@0=00`71@0I514081/H01@?300<1`@03PT600l:
1`0<1`@02PD200h91P0B3@X03`X700d81@0200h91P0400l:1`0>2@H03PT600h91P803`X701h040/8
00l:1`0?2PL03`T800h8200=1`L03PP800l92@0>20P03`T9010:2P0>20P03`T9014;2`0D3Ph06A4A
024G600D2``04`T:01892P0@1`P050X;01<92P0A1`P03`D601061`0A20P030H300d8100@2`L200d8
1004010;1`0=20@030L300h91@804@`800L03`X600h41@0@1`P04`T:01061`0?1@H04@L8008040H7
0P0A1`P201882@0601<92P0A1`P03`D601061`0F3@h06a8C0P0A1`P201061`803`D600`040@80145
2@0?0`L03@<600l5200C2Pd030@700d82@0>2@X02`L800/82@0<2``Dooooo`006oooool00`0B4Q@0
410B00l?4@02010@4P0700d=3`0A4A<04A4C00<31@0?3a4051@F00D51`06014?400800H41@091`P0
1P@500`:2`0D4Q<020H701<A4P0A3a02010>3`<04@l@01X0518C018@4@0?3@h04a4B01PG5@0@3``0
3`h:018A3@0E510040l;00`;1`0B4@d040l;014@300B4@d040l;00d<200>3@/03`h<00`;2@0D4a40
2`X800d<2P0D4a404Q4?014@3P8040l=0`0?3`d200h>3008014A3`0I6AL04A4?014A3`0H61H02PX8
00`<2P0?3``200l>2P04010?2`0A40`04Q4=01PG4`806QTE00D06aXF010?2`0;2PH03@d800l@2`02
010A300h00l@2`0=3PT03@h900l@2`0>3`X03@h900l@2`0C50l04Q<>01DF4@0H6A@04Q<>010A300>
3`X08R<N00@5000J6aH02``701DF4@0<3@P04Q<>010A300?40/04a@?01@E400A4Pd030d801LH4`0J
6aH03Pl:00`=200@4@d051DI014B5`0?3aH0ZJZ_04Y;C`0A4QD09RLY09^LWP0D5QH01`T801<E4P0?
4@h051@D01DE5@0>3Ph05QHF00X:2P0L71`00P8201XJ6P0>3Ph05ADE00d=3@0A4A4201<B40804A0>
0P0C4Q000`0A40h051<A01@C4@0201<B400601DD4P0E5A<05QHD01@D4P0A4@l03`l=0P0@40h03`0D
51804a<A01@D4P0A4@l020P600L80`0C50l09bPS03Df<@0I6QD02P/600/<1`0720<02@X5018C3P02
01LH4`0B01@F500?4A002`d:014C400?4@h05aTD01HH4P0E61404A@=03Tl=@0k?SL05APA01HG4P0B
4`h051D@00l@2`0B4`h07AhI0P0?40/01P0A4Pd051D@01LH4`0H6A@04Q<>01<D3`8051D@00@04Q<>
014B3@0@4@`04A8=0P0C50l0100D5A00:2TU03<e<P0M7a`300h@3@0U018D4@0C5A80418?018D4@0D
5Q<04A<@01@F4`0G6AH01PP5010B3`0Q8b005ALD01hP7@0g>CH061XG01<E4P0G6AH05QPE014D400>
4`d04QLA01`Q6`0b=c40Ri2:0<[?b@0l@C/05AXD01LL5P0H7AL07B8M02@Z:00D6QX05Q`L014G5`0C
6AT05A/K01dS8`0201`R8P0B02<Y:@0F71`0@4E7020X:`0K8bH06B4T01/S9@0I8B<06R<Q01/T8@0I
8Qd06B<K01XT700K9A`06B<J02T`:00S:R809RdV0P0L8Qh0?@0K92806bDT030k=`0J9Al08BhU01PU
700U<RP08c0W024_:00R<BX09SD^02De;P0P<B/0<44k01d^:`0C9R808cHb02m2@00T=cD0:cln02e1
@00X?3/0<4A502a0@@0]@D808cHj03E8C013EUX0;d9803I9C`0gBU00<dI:03E9B`0hC4/0>dm>041D
DP12EU@0<4A203eAD00dAd/0>diD03I9D@0oD5X0AeEP05MUL01]NhH0Cf1X04MJH00nDEL0@eQK04EJ
F`1<HF80Bf=S04MPG@17Gel0BemT05MZL01_PXP0G6me04AGF`1BIFT00`1DJ6T0501DJ6L0EFUX05AX
I`1KKFd0EVQX05AVIP1KKFd0J7Yj06eoO`1YNg/0J7Yj06]mO@1]Ogl0LhF507Z<S01bQHT0LXB807F7
R`1fR8`0N8N<0P1jRHh05`1nRi40P8fC07n<TP20SI<0QY:G08ZEV@2;UYX0SiZN09:MX@2FWj@0VJ:W
09JOY02GWZ@0WZF[0::Y[`2VZk40XjR`0:FY]02X[;L0Y:Nb0:b^^P2b]<00/;6m0080]KG100<0/[6m
0;Zha@2h]/<00P2e/l001@2d/[l0]kG20;Fc`02g]L80][C100<0/[2m00D0];:o0:j]^P2^/KX0[K2i
0:^^]`020:^^]@050:R[/P2WZZl0YJR]0:FY[02X[:l00P2Z[[402@2QY:T0X:>X09nRY`2NXJH0Wj:W
09nTZ02JXZD0VJ6T09JNX@0209>MW`1G09FOX@2EXJ40TIfM08fIV@2=VIL0RYJD082<RP1lR8@0NXJ2
07J3O01aOWL0K7Ub06EbJ@1AGU@0FVUL05m_HP1HJ5d0DF9F05QZGP1KK680FF]Q05M[H01GJf80EVYQ
05AXG`1>He`0E6UR051UGP1=HU/0C65J04QMEP19GUL0A5UB03eBB`0lDDX0?U=<045FC`12Ee00>e19
0397@00aA3h0<TDo03E8@P0W>380>4Q202/j=@0g@cl09C4]02<b;@0T=2l0<44k02m0>P0V=c40:3Tc
02m0>P0S=2h0;Chh02`m=`0`@C/08c@^02Df<00W=S<0:STf02Pg=00T<c009S8`02Te<`0U;bh092h]
024[:P0O:2L082TX028[:00Y<b/07RPP01lY8@0R;2@08R/V02@]:00N9b8072DR02</:@0J8b009c0]
02Xc;P0R9b407B8L00807R<M01<06b0J01XO6@0E6Q@02Pl901LL5P0V:bD0GfAN02db;@0E6QH0:c0/
0497@`0O92003A8>01dR7P0I7QX06QlK01<H500I7QX08BHR00804aPD00d06AhJ01XO6`0H7AT06QlK
01<H500J7a/04QLC02@Y9@0>4`l051TE020R800N7Qh03`l?008051@D00L04A4A01@D500E5AD051@D
018B4P0C4a<07AdM00<05QHF00`05ADE01@D500B4Q805QHF010@400B4Q804A4A00X:2P0?3`l03`h<
014@3P0D4a42014@3P0H01DD4P0R8Al09bHT014@3P0?3P`03Pd;01TH5P0[9bH03PX9010<2`0=2@P0
2`L600l;2P0E4A004`l>018>3@0C3`h04Ph=010<2@0F4Pl05A4=01<?300B3P/04Ph<0P0B3Pd01P0A
3@d040`=010<3@0A3@h04Ph?010:2P804P`<00<040X:014;2`0B30`00P0A2`/2010:2P804@/;00`0
40X:00l92@0D3Ph05Q0@018<300@2PX03PP8010:2P0C3@d04P`<00l92@0=1`L2010:2P804@/;00<0
40X:00l92@0@2PX01@0@2PX00`0G4Pl03`X700X50P0200l:1`0301XE4P0?2PL03`X7008040/800<0
3`X700h91@0?2PD00P0?2P@300l:1P0800T40@0>20P02`D501<=3@0Q6a/04@/:010;200C3P/200d8
1@803`X700<03PT600d81@0<1`@00`0=20D200h91P0300l:1`0>2@H03PT600803PT60`0?2PL0200>
2@H03PT7010:2P0A2`/030H600X4100?2@T04P`<0`0?2@T0100A2`/04`d=01D=3P0M4a@201882@05
01<92P0@1PL04`T:01882@0A1`P00P0@1PL0100A1`P03PH400h91P0?2PL200d81@0300l:1`0:1@80
3PT600802`H300D04@`900T40`0@1PL04@L801882@0201061`0401882@0@1PL040H701061`<04@L8
00H03@<400h41@0?1@H03`D600d3100;0@820147208040H70P0?1@H0300@1@T03P<701072P0C2Pd0
3PD800H0000;1@L03PP:00d92P0;1`P030P900`:2aCooooo000Kooooo`09010@4P0?3a403`lA010@
4P0?3a4030`>00d=3`0A4A<03Ph@00803`lA00<02@T;010>3`0@3Pl01@0@3Pl01P0J61T02`T:034_
<00A3a0020H700h<3@<04@l@00l04a4B01DC500@3Pl04Q0A014?400?3@h04Q0A01DD4P0A40d040l;
01<B3P0H5a<04Q4=00/:1P0B4@d00P0@3`/0200A40`03`h:00h=2@0F5A<03Pd;00X91`0?3P`040l=
0P0A40h01`0@3`d03`h<00h=2`0>3@/03`h<00l?3@0>3P`00P0=3@/200h>300600D50`061P@01`L5
01<C4@0P81h020P60`0@3`/2014@300>00T81P0:2@D061LC01hM6@0@3`/030/700h>2P0?40/0414<
014B3@0@4@`03Pl:00l@2`0@4@`300l@2`03014B3@0?40/03Pl:00@0414<02X01`P300H70P0<3@P0
20T401HG4P0E5Q402P/600h?2P0F5a806Q/F01PI500C50l02@X5014B3@0D5A003@h900h?2P0A4Ph0
4A8D00l@500@4AD04a@H014B500A4Q<030d?01lQ800>40h02P`900lA3P0>40d051@D014A4@0@4100
3@d=018B4P0@41006a/K00D51@0W9bL06ATI01DE5@0;2`/2010?3@803Pd;0`0@3`d201<B400`018A
3`0C4Q005A@B018B400C4a404A4?00h>300=3@/03Ph<01<C4@0@40h030`:00d=2`0?3`d03@d;00T:
1@0>3`X02``701TJ5@0B4`h02P/6018C3P0C50l04A8=00X;1P061`801PH400lA400>40l04aDD024S
8@0E5a@04Q@A01DG4`0:30L01PT2034d;@0_<R/01`X301HG4P0A4Pd05QLB00l@2`0D5A009RLR01@E
400C50l04Q<>0P0C50l00`0D5A004a@?01@E400201@E400<01<D3`0B4`h03a0;010A300B4`h04a@?
01@E400H6AD06Q`I010B3`0?4@h04aDB0P0?4@h2014C400@01HH5@0A4a002`d:01HH5@0A4a007b4N
010B3`1_LFh09RPU01dO700T9R<06A/H01HH5@0H6QL05ALD01@G4`8051TC00D06QlI038g<@29SXP0
bLk803Tn>00201<H4P1Z018G4@0M8Qd0728P01<I6@0d>SX0318B01XP800I7al05adM01`R8P0A5aL0
7B<S014G5`0k@D408RX/01`T9P0I8B806R8T01TR8@0K92806R<P01PQ700I8Q`06b@O01`V7P0K9Ad0
82LO01TP600M91d05adI01`R800R:bX06R@S01dW9P0J9B007BXQ01HS6P0U<RP0934Z02Dc;00W=Rl0
:3Lb02Lg<@0T=3408S8_02Hh=00W>SP08cHd02e0?P0^@Cl0:3`k02m3@P0/@3l0<4A502e1@P0dB4T0
PYFI0395B@0U>3`09CPn03U<DP0/?dD0>4]?03U<C`0jCTl0?E5@04AHEP18G5X0=DU703a@D00cATX0
AEQN03Y<E@12E5h0AEIP065_NP1fQ8d0AUMO04iQI`1;GV@0AEYM04aQHP1BIfP0C6AT04QQGP1;Hf<0
F6]`06n2R02>XJL0N8^A05AWJ`1JKG40EFUZ05=WJ01GJf`0EFUX059VI@1EJFP0G6i^05e_K`1JK6`0
HG=c06YlO01YNg/0Jgem06UkN`80K7in00@0KX2007>5Q`1`PhL0M8J:0P1kSI409`1gQX/0NXV>07n>
T`23T9H0Q96G08FBV026TiT0RYJK08fHW02?VYh0TYfQ09JQY@2IXZL0VjBY09ZSZ02JXJL0WZF[0::Y
[`2W[;80Yj^e0;6e`02c]l80YjZe0;2b_P2g^LD0/kC00;:b_P2d]<00]KC10;Fc`02i]l@0`;k;0;Zh
a@2e/l00^[S50;^iaP2h]/<0][C10;Bb_`020;:`_@050;Bb_`2a/;`0/[:l0:ja^P2/[kP00P2/[kH0
1`2Y[;<0YZV^0:FX[@2TZ:/0Yj^^0:R/[`2Y[K00102PXjP07P2QY:T0X:FY09ZRY@2IXJ@0UinR09BN
X02CWIl0U9jP09BOX@2?Vi/0RiNG08fIV@2;UiD0PHf;07b8Q01jQh00L7ee06EbJ@1NJf80EF9H05ES
EP1CHUD0FVYM05i^H`1IJUh0EFMK05e^I01LKV@0F6aQ05EYH080E6QO00P0CfAM05=XH@1>He`0Bf1I
04YOF014FE80@EI?03aABP80>4e60P0kD4T01010EDh0>Tm803=8@@0bACl203A7@@0W03A5?`0R<Rd0
7RdX02Da;@0Q;BT09SD`02Hf<@0fAd40=DI002/l=P0`@C/0>4U30311>`0^?cT0:S/e02Hg<@0K;2H0
9CH`02Dd<@0Z>CH0:3Ld028a;P0U<Bl0:CDc02@^;@0S;B`082XY01hW9P0O:2L08BXW02@^9@0K9Ad0
7BLO024[8`0T;BP0:C8]020Y900U;R/082TV00807BHS02d08R/V024V8@0Q9R007R<M01`Q6`0K81X0
7R<M01lT7P0J7aT061dG010E3`0S:2805AXE01TN6P0P9B409BXV01DJ5P0H7AT08bPT01TN6P0J7a/0
61dI030e<@19CTX092TU01LL600K81`061dI01LL600J7a/05Q/G02/`;00/<Bd04AHB020U8@0N8al0
5APF01lO7`0F5QH05aLG01<C4`0@41006QXJ01<C4`0A4A400P0E5AD0100B4Q805ADE01DE5@0E5AD2
01@D500:01<C4`0U9BD05aLG01LG5`0O7al05aLG01TI6@0D4a405A@B01HE4`8051<A00l05aHD00<2
000:2@L02`X801TH5P0=30X0BTU705UEE00P71/04Ph=010<2`0C3`h0510?01HB4@0E4A000P0C3`h0
2P0B3Pd040`901HB3`0E4@d04Ph;014=2P0A3@/04@d<018>3@0A3@d2010<3@03014=3P0B3Pl040X:
00804P`<00D040X:014;2`0B30`04P`<014;2`02010:2P0@014;2`0B30`03`T900l92@0B30`04`d=
010:2P0>20P03@L700l92@0A2`/04P`<014;2`0@2PX03`T9014;2`804P`<00<03`T900h8200@2PX0
1@0@2PX01P0910801`8000@0000D3``01`8001@?30803`X70P0@2`P00`0?2PL03PT500l:1@0200l:
10<03`X601805A0=01PB4P0H4Q801`8200@0000@2PT03PT600d81@0:1@803PT600l:1`0>2@H03`X7
010;200>2@H02`H300X50P0<1`@200h91P0500l:1`0>2@H03PT600d81@0>2@H00`0?2PL02@0>2@H0
3@P600h8200?2@T03@L700/51@0=1`L03PP800`61P0200/51@0600d71`0>20P030D501061`0:0@80
40H70P0C2@X00`0B20T04@L8014720030147200300l71@0>2@H03PT600803PT600L03`X700L2000C
3P/04@`900@00009104040/800805@/<00@04PP900l51P0=0`@03@<41@0@1PL00`0A1`P03`D60106
1`020147200400h41@0<0P<04@L80147208040H70P0?1@H01`0?1PT03@@701072P0D2`h04PT<00`3
1P0<1PP00P0>20X00`0<1PP03@L900h82P0Dooooo`006oooool00`0A4A<0410B00l?4@02010@4P07
00d=3`0A4A<04A4C02`/;P0B4Q@02`/=01PH6P0600h<3@0701DC500Z:2T040h?030^;`0:20T04@l@
010>3`05018@4@0=010>3`0<2P/03@/<014?400@3Pl03@`:014@3@0@3`/04a8>01LF4P0A40`030/7
018A3@0200l>2P06010?2`0?3PX03Pd901LF500E51805aHD0P0?3P`00`0<2`T040l=014@3P02014@
3P04010?3@0?3`d03Ph<00d=2`@03Ph<00H05aLE00H61@0B4Q002`/901TI5`0B4Pl2014@300D018A
3@0@3`/03`h:018A3@0?3PX030/701LF4P0H5a<04a8>014A3@0B4`h0414<00l@2`0@4@`04a@?014B
3@0>3`X03a0;018C3P0D5A0201<D3`0@014B3@0@4@`03a0;00h?2P0@4@`06Q/F05AED00J6aH061TD
00/<1`0?40/0414<018C3P0E5Q404A8=010A30<04a@?01h0414<014B3@0E5Q40410<01<E4`0@4Q40
2``<01@F5P0D5Q@03Q0=01<E4`0@4@h030h901<E400>40/0418=01LG5@071`L0410@00d=3@0A4A40
30`<00/;2`0l?3`0a/K604];B`0A4A406ATI014@3P0@3`d200l>3003010?3@0A40h03`h<00804Q4?
00H04A0>018A3`0D4a403`l=014A3`0B4Q02014A3`0X01@D4P0>3P`03Ph<01<C4@0E5A<04Q8@014A
3`0I6QD03a0;00d>2`0I6QD03Pl:018C3P0?40/05AHA018C3P0A4Pd0824L02d]:`0A4Q<02``>01@E
5P0Z;2/06adL01<E4`0A4a005ALD014C3`0?4@`04Q@?01<E400B4`h03a0;01@E400A4Pd05aPC02HW
8P0F5a8051D@01<D3`<04Q<>1`0C50l07@0A4Pd04Q<>01<D3`0E5Q4051HB01DG500@4Pl05ALD01LI
5P0@4Pl051HC01HH5@0A4a004aDB014C400C5A806adJ018D4@0E5a@06Q`I04a>B`0N81d05QPE00d?
300I6aP04aDB01HH5@0H6QL04QDA00@05AXD01P08RLQ03Pm=`0A5Q005Q/E01/P6P0L8A/05a`G020V
900D6QX07R@T01lU9@0E6a/061hN018H600U:b/07B<S028X:00J820061hN01hW9@0I8R005b0N01TR
800H8Ah201XS80806B8O04d072DR01dV8P0L9B007bHO01TP600Q:28082TU028[:00M9RD08bd/01/U
900Q;BP08RlW024^9@0W=2X082`W02Hd<00W=S808c8_02<b<00X>3L0:CTh0393@P0fB4P08S@d02Tk
>`0X>SX08cLf0355A00`A4<0<TI70355AP0oDe@0UjZ^03a?D`0jCE40=dY@03=6C00fBDl0>4]?03I9
C00eBDX0=TY903]?CP0nDU40?51?03mCE01>HFH0J7^205=UKP1;GVH0E6E]055RJP1DIFd0@E9I059U
J`1;GV@0BUeQ05EZK@1HKG00CfAU04eUI@1EK6d0DFAY05IYK`1KKW@0EfY^05=VJP1GJfd0FFe^05Q/
J`1JKVd0FFe/05M[JP1IKF`0Ffe_05a^L00206EgN@0>061bM01UMgT0KGn106]mO`1`PX@0LXB60763
Q@1dQXP0O8jB07>5R@1eQh/0NH^?07j=TP23TIH208FBV00S08JBV02:UI/0SYVO09:MX`2BW:<0UIjU
09VRZ@2LYJ`0WjJ^0:>Z/P2X[kL0ZJff0:N[]02Z[[L0[[6j0;:d_`2o`Ld0_/3<0;6c_`2e]/80^KW5
0;Vha@2f]<40^KO40<2mbP2f//00`[k<0>?Ok@3Fe>40`;k;0;fkb031_l`0_[c90;bja`2i]l@00P2g
]L801@2f]<40];>o0;>c_@2`/k`0[[6j0080[k:i00<0[K2g0:^^/`2Y[;400`2WZjh00`2UZJ`0XZFZ
0::UZP030:>VZ`0R0:6VZP2LY:L0Vj>V09ZRY@2FX:80UInQ09BNX02@Vih0SYVL08bGV@2;UiP0RYJF
08>?S01iQX00N8Em06UfK01LJEh0F6IH04aJC01FI5L0EfIJ05][H01JJUl0EfQM05a]H`1KK680Gg9X
05Y^I@1AIE`0D6AL05Q[I@1EJV<0DfQQ04aQFP80BUmH00<0A5UB03mDC@0kD4T00P0hCDH03`0fBd@0
<DHo03U<AP0gBT@0>4]503a=A`0iBT@0<d@n03=2?@0Y>3<0HG1[02lk=`0X=300:STd02Tj=00202`m
=`0402dn>00b@cd0=TM102Hg<@80:CXd01409SLa01`]9`0X>C<08c8_02Th=@0X=c@08c8_02Da;`0W
<c4092h]028/:`0P:RT07RLV01lX9`0Q:RL082XQ01XT700201`V7P0401dV8@0R:bH0;3D`02/d<@80
7RLT02L07BHS02</:00N8ah092TS01hS7@0I7QP0724K024V800K81X06QlI028W8P0n@cd05Q/E01/P
6`0F6aL07b@P01HK5`0K81`09BXV01LL600P9B406QlK01TN6P0N8al0<cPd01<H500H7AT06QlK01<H
500J7a/08BHR01/P700A5Q807B8N01PM6@0B5a<03A8>01HI5`0A4A400P0G5aL0200N7Qh07AdM01@D
500E5AD05aLG01@D500G5aL0=cLg0`0C4a<201@D500:01HF5P0D51@04A4A01PH600F5QH03@d=01XJ
6P0F5A<051<A018A3`8051<A00P04Q4?00h=2`0H5aD04Q4?01HE4`0;2PT07A`J03Da<0804`l>0140
2@D400P4100F4Q40510?01DA400D40l04Ph=014=300B3P/0510=01<@300A3@X040`9010<2P0@30/0
4Ph=014=3@02010<3@03014=3P0B3Pl040X:00804P`<00<040X:014;2`0B30`00P0B30`2014;2`80
4P`<00h03PP8018<300A2`/03`T9010:2P0>20P04@/;00l92@0>20P040X:018<300D3Ph040X:014;
2`804P`<00<040X:00l92@0@2PX01@0@2PX01@0?2PL05a8?01dH5@0U81d03@P600<03`X70P0@2`P0
0`0?2PL03PT500l:1@0200l:10<03`X600/04`h;02/V9P0G4A40@cdm02HP800C3@`040/800l:1`0;
1P<03PT600l:1`0200`7100400h91P0@2`P03`X700l:1`<03PT600<03`X700h91P0>2@H00P0=20D0
1`0>2@H03`X700h91P0=20D03PT700h8200?2@T00P0D3Ph00`0?2@T03@L7010:2P04010:2P030149
2P0I3a004@L800804`T:00<03`D601061`0A1`P00`0B20T0100A1`P04PX800h91P0>2@H200l:1`09
00h91P0;1P@03`X7010;200>2@H03`X700/71@0H3Pl05@/<00@04PP9200@1PL0100?1@H040H70188
2@0C2@X20147208040H700h03`D600h51P0>2@/03PT:00d82P0=1`T03`T;010:300?1PT04@P;0107
2P0>1@P03`D801062QCooooo000Kooooo`0<01@D5P0A4A<03Ph@010@4P0A4A<0410B01HF600@4180
8B4S01<C5@0=3@l04a<E1P0>30d0500J61T03`h>01lM7P0100009B<T00H41@0B414040h?014?400D
4Q<040h?00d;300?3@h03P`=00l=3P0@3Pl03`d>00h=2`0?3P/03`h:0P0@3`/01@0?3PX03Pd9018A
3@0>3@T03@`800803`h:00P03Pd900d<2P0I61H08B0N00d<2P0?3P`02PT7010?3@804Q4?01`04a8@
014@3P0@3`d03Ph<00d=2`0?3`d04A4?00l?3@092@L06ATG01hN700<30X0JVYX0:6QW`0G5Q<04A0<
00l>2P0>3@T04A0<01DD400>3@X02`X601LF4P0I61@03@`800h=2@0C4`l0414<0P0>3`X0100@4@`0
4Q<>01DF4@0A4Pd200`=20803a0;0240414<00h?2P0C50l0414<00X;1P0;30L00@8002PY900;30L0
51D@00`=200C50l05QLB018C3P0?40/051D@01HG4P0B4`h05AHA01HG4P0B4`h0414<01<D3`0@4@`0
3a0;00X;1P0H61D04A4?010A300A4Pd0004001hO6@0<3@L00P0B4`d03@0@4@`05aLE04U9B@0K6a/0
5ADE00d=3@0A4A4071`L01HF5P1BDU808B4Q01<C4`0;2`/00P0D4a42018A3`8051<A00P040l=018A
3`0B4@l04A0>018A3`0D4a403`l=014A3`804Q8@02004a<A01HF500?3`d0410>01XJ600M7A/051@B
010@3P0B4`h03@h901@E400P8A`030d800d>2@0I6QD05AHA010A300B4`h07QlJ02LW9@0?41<02P/=
00/<3P0E5QP03a4@014C4P0C5A@020X700d?300C5A803@l:00T;1P80414<00D04A8=01<D3`0E5Q40
5aPC018C3P03014B3@03018C3P0C50l04Q<>00<04A8=0P0B4`h02`0G61<051D@018C3P0C50l05AHA
01@F4P0D5Q<030h;00lA3P0F61D04aDB00806A/H00d04Q@A01<E4P0@4Pl05QPE02PZ9`0R92402@/8
01LI5P041P<06adJ02HX9@0<3P/09BLT00805ALD00P06adJ01TM6@0K81`04aPD01HK5`0J7a/05a`H
01`Q7@807b@P03H04aPD01`Q7@0I7QX0318@020V9P1dNWX051XJ01LM7@0L8R8051XJ01XP800D6QX0
41HF01PN7P0N92@06B8O01DN6@0G81/06b@O01TR7@0J8b006b@Q01XS800J8b8072DT01dV9@0K9280
92dX01LQ6@0L9B00:C8_03@m>P0a>c/07bTZ01dY9`0O:bL082lX02De:`0O;bH08Rh/02<`<00P;Rh0
7bd]028a<@0V=SH052@T06YkO028VY`0?e5C028d=P0a@dD09SXi02e1@00/@3l203=7B00903U=CP1:
GF40<dI:045DF013EU`0>TeC04YMH`0lCe<0>dm@0080>De>0580>dm@03a@D@0kCe00?4mC051SJ@1F
JG00C5mV05MZL@1JKG@0D6=Y04EHGP1;GV@0D6=Y04YMH`1;GV@0Cf9V05AWJ`1CJ6/0DVMZ05I[KP1?
HVH0E6M[05Q[K`1GJVh0DfMX05AXJ@1DJ6P0Ef]Z059VI@1IKF/0Gg=a05]_KP1RM7H0HG=e06IhNP1X
NW`0JWan06n1P`1eQhT0K7j006j0PP1`PX@0LXB607F7R@2BY:P0P8nD07b;T01mS940PHjD08FBV026
TiT0RYFK08^FW02=V9h0TIbR09BNY@2GWZH0VZ6Y09nV[P2QZ;00Y:Ra0:JZ/`2^/[/0/KBm0:f`^@2`
/k`0];Bn0;2`^`2^[[X0/;2l0;Bd`02i]l@0_;[70;fja`2m^LL0_[[80;njb035_ld0b/CB0=KBh03A
cM/0`;c:0P2l^<H0202k]lD0^[K40;Jb`02n^/P0`[k<0;^ga@2d/Kh0/k>m0P2b/[`01P2c/k/0];Bl
0;>c^`2`/KH0[Jjc0:Z[[`80ZJZ^00<0YjR/0:BW[02UZ:d00P2UZ:d07@2SYZ/0XJJZ09jVZ@2NYZT0
WJFX09VSY@2GXJ<0UInQ092KW`2AW:00T9^N08RCU@22SXh0P8b907B1NP1ePWT0IG=W05UWF01KJEP0
DEm>05]YG01OKF<0Hg=X05i^I01GIed0FV]Q05a]I@1LKfH0EVYQ0080D6=M00H0EVUS05EXHP1@Hed0
AeYD04QKE@1>HE/204YME`0B049EC`0nDD/0?e9<03e@BP0gBT@0=DI003=4?P0fAd40>TU403E4?`0[
>SD0:3Lb02Lf<@0kBTD05bHQ020_:P0fAD00:SXg0P0W=c@04P0/?3T0;cll02lo?00]?CX0=TI302lo
?00Z>SL07BdZ02@d<@0R<B`093<^02He<00U=2l0930/02<_:`0T;b/08bhZ020[9`807bPU00/08BXU
01lY800L9Qh07BLO01TS6`0F7aX06R<N02D^:@0M9R<051dJ010I5P0201<L6@08020U8@0N8al07B8N
01/P700J7a/05AXF01XO6`0Q9R8201/P700W01HK5`0R9b<06b0L01PM6@0B5a<06QlK02@Y9@0I7QX0
9R/W010E4@0J7a/07b@P03m4@00S:2@05Q/G01TN6P0C61@07B8N02DZ9P0A5Q804aPD01XO6`0?5100
51TE01`Q7@0=40h05aLG01XJ6P0I6AT09RHV02<S8`0E5AD04Q8B014A4@0@41008R8R06IVIP0D51@0
4a<C00804Q8B01004a<C01DE5@0M7Ad04Q8B00d=3@0M7Ad08B4Q01<C4`0E51805QDC01PG5@0E5180
4a8@018A3`0G5Q@06QTG0P0D4a402@0E51801`H500l;2P0C3`h07ATH01LC4P0C3`h081`K010<2`02
01<?3P8040`;0P0C3``0100B3`/04@d:014=2P0B3P`2018>3@06014=3@0@30d040`=014=3P0B3Pl0
40X:0P0B30`01@0@2PX04@/;018<300C3@d04P`<00804@/;00P04P`<01<=3@0>20P05@l?010:2P0>
20P04@/;00l92@8040X:00<03`T9010:2P0A2`/00P0A2`/01@0@2PX03`T9010:2P0@2PX04@/;00H0
40X:00H06A@A00`7100>2@H02PD401<>2`0D3``200l:1`8040/800<03`X700h91@0?2PD00P0?2P@3
00l:1P0@00d81`0H4Q805@l?02PR8P0H4Q802P@3010;200A30T030L400h91P0@2`P05A0=01@?300=
20D02PD200d81@@03PT600<03`X700h91P0>2@H00`0=20D02@0>2@H03@P500d81@0=1`H03PP800l9
2@0B30`04@/;00h8200300d71`0B00h8200=1`L03@L700/3100C2@X03P@501882@0C2@X04@L800h4
1@0?1@H04PP901<92P0B20T04@L801<:2`0?2@T03@L70P0?2@T03@0<1PH050h>00d71`0<1PH02`D5
00L10@0E3`l04@L800h41@0;0@803P@501061`0A1`P00`0@1PL00`0?1@H03P@500h41@0201472004
01061`0A1`P04PP901<92P804@L80P0@1PL03P0?1@H03PD600T51P0:20T040h?01HB4`0@2`d01`43
00l62@0A1`/04@H:00l4200@10P04@D95?ooool001_ooooo00`05QHH014A4`0>3Q003`lA018B500A
4A<05QHH00h>40092@/04A4C00h>40071`T600l=3P0;00H41@0C4A800@0001DC50071@H05aDF00l=
3P0<2P/040h?01LE5P0D4Q<00P0?3@h0200D4Q<04a4B00h<3@0?3@h04A0>00h=2P0?3PX03Pd90P0=
30P0100?3PX04Q4=00h=2@0=30P200l>2P0500h=2@0;2PP05A@B01`K6@071P@00P0B4@l0100>3@/0
3`h<010?3@0A40h200l>300H00d=2`0<30X0410>018B400@40h04Q8@00l?3@0000004A4?01lO7@18
B4H05QDB014@300=30P02`X601<B3P0K6QH08b8N01LF4P0<2`L03Pd9018A3@0A40`0410<0`0>3`X0
1@0?40/04A8=01hO6P0Q8Qd05aPC0080414<01@04Q<>010A300?40/06Q/F01TJ5@0A4Pd04Q<>010A
300<3@P04a@?01DF4@0D5A004Q<>010A300<3@P04a@?02DV8@0W:2<04a@?00d>2@804A8=01d03@h9
010A300B4`h0414<010A2`0=3PT0414<00d>200F5a407AhH0083000G618000400083000A4Pd051@B
08j>SP0V9RH04Q8B01@D500;2`/03@d=01dM7@0E5AD051@D018B4P0:2PX051<A01<B4002018A3`09
01<B400D4a404A0>01<B400D4a404Q4?01<B400E51803@d;0080410>00h03`l=010@3P0B4Q005QHD
010@3P0D51805ADC014A3`0C4a403a0;01HG4P000@003@h901PI50803Pl:01T030d800h?2P0C50l0
4a@?014A3`0A4QD05aPJ01@E5`0C51H02`d<018D4`0C5A@061XG01DG500B51404A<>00lA300A4Pd0
4Q<>00l@2`0C50l04Q<>00d>2@0C50l04A8=00@0414<00<04Q<>014B3@0@4@`00P0A4Pd00`0B4`h0
6AXE01DF4@0201<D3`0^01@E400G61@061XG010B3`0B51405ALD00lA3P0C5A805QPE01DG500J71T0
3Q0=00`>2`0I6aP02`d:01/M6P0H6QL06Q`I00h@3@0K7AX01@L402HX9@0F61D04Q@A01@F4`0A5A40
5AXF018G4`0H7AT04QLC00hC3`0F6aL07B8N01XO6`0F6aL07R<O018G4`0M8b<041HF02D[:`0L8R80
5A/K01PN7P0C6AT051XJ01hT90805Q`L00X06AlN01PQ7P0D7AP0624L01dV8@0K91l06b@Q01`U8P0K
92406R<R0P0L9B@0800K9280FF9M03a6?P0P:B@06B8O020Z:@0N:2T07b/[02@`<00R;R/09C@_02dl
=@0R<RT0:3@b028_;`0N;2`08Bl_02Dd=00V=SH0<T9202m0@@0dATP06R`^02do@P0/?T00:Sho02Tm
?00W>cX0=4Q903=7B00aADH0<dI:0P0dAd/01@0jCE<0<DA:03Q;C`0lCe<0?51A0080>dm@00d0?E5B
03e@E014Ee/0?E1F04AGG@0hBe80@5=J06UlP`1;GV@0F6]a04]NI017FV00AUUO0080C5mU01T0AeYN
04mRIP1EJVd0DfQ[059WJP1GJVh0E6M[05a_L`1HJfh0EFUZ05a`L@1IKF`0GG5`05IZJ@1PM780K81n
06EiN01PLW@0I7Ih069dMP1ZO7h0L8:406eoP@27VI/0MXR:0080LXB601X0M8J807R:S01nT9@0N8N<
07f<T@23TYL0Q96G08FBV028UI/0SYVO096LXP2BWJ<0TijT09JNYP2HWjL0Vj:Z0:2W[`2SZ[80YJVb
0:>W/02[[[L0[k:k0:^^]`2a/K/0/k>m0;Ng`P80][K201d0_;_70;Vga02g]L80_;W60<S4dP36`]00
`K_90=G?g@3Bc=X0`Kc:0;nkb@31_L/0aL7?0;nkb@2k]lD0^[K40;^ga@39aM<0dLgK0<O3d@2k^<H0
/k6l0;6a^`2b/[`0];Bl0;Jf_P2e]Kd0[Jjc0:^//@020:RY[@030:VZ[P2WZ:`0YJR]0080YZV^00<0
YJR]0:>VZ`2PYJT00P2OYjX06@2NYZT0VZBV09RRY02FX:80TIbR09BOY@2BWJ40QY6C07j:RP1mRHD0
Lh1g07B1M`1TLV@0EVAC05YYEP1?GD`0Hg5T05YXGP1RLVL0JWY`065aI`1BHeT0GVmW05U/H`1CIeh0
0P1BIEl205=VH00404ePFP14Ee40AUUC04mRG080CV5K00X0AEQB03mBC013EU00AEQB04=FD00eAT00
<T8l0391?00eA3l0<3lj0P0V=C00=@0W=S4062LR02Xi=00a@3/0>4M202`l>@0[>cP0;3`i02hn>`0_
?c`0;Shk02dm>P0a@Ch09CDb02@d<@0R<Rl0:SXg024`:`0R<B`093<^02He<00U<Bd08RhZ02D`;00T
;b/08B`X01lX9@0P:BH08R/V01/U700K9Ad07RPP01XT700H8A`06b@O01dV8@0O:2D08b`Y024Z9`0T
;BX07RLT02<X900I7QX0724M01lT800H7AT05AXF01LL600E6QH082DQ01PM6@0`=C405Q/G008061dI
02008RLS01/P700D6AD05Q/G02`a;@0E6QH08RLS01DJ5P0W;2P061dI01TN6P0M8Qh05AXF01dR7P0Q
9R806AhJ01<H500@5A406b0L00P=2@0J7a/04A<A01lO7`0I6AT04a<C01dM7@0E5AD06QXJ018B4P0D
51@05ADE00h>3P805QHF00H05ADE01<C4`0A4A404A4A01<C4`0>3Ph2014A4@0F010@400C4a<03Ph>
00l>300F5A<06QTG018A3`0=30X040l=01HE4`081`D03Pd;00d<2P0:2@L05QDC014=300C3`h02PH5
018>3@0C3`h04@d<00h:2@804Ph=0P0@30/201<?300701<?2`0B3P/04Ph;01@@3P0D40l04Ph=014=
3@02010<3@03014=3P0B3Pl040X:00804P`<00D040X:014;2`0B30`04`d=018<3002014;2`0:018<
300C3@d03PP801H@400A2`/03@L7014;2`0?2@T03PP8010:2P804P`<00P03`T900h8200B30`03`T9
00h8200?2@T04@/;018<30H040X:0P0>2@H0100L5a@03@T701@?300;1P<200l:1`8040/800<03`X7
00h91@0?2PD00P0?2P@300l:1P0B01<>2`04000050h>00l92@0>20P03PT700h91P0B3@X03@P500h9
1P0A30T091lL02TT8@0I51403`X7010;200A30T03`X70P0>2@H00`0?2PL03PT600h91P0300d81@09
00h91P0=20D03@P500X50`0;1@D03PP800/51@080P802P@400803PP80P0?2@T01@0>20P03@L700h6
1P0G3@h04@L800804`T:00d03`D600h41@0?1@H04PP901<92P0B20T04@P901<:2`0?2@T03@L700l9
2@0@2PX030H600802`D500X040X:00H0000:10@0BD=301L=3P0C2@X03P@501061`0B20T04@L80`0@
1PL00`0?1@H03P@500h41@0201<92P0401D;300D2P/04`T:01882@804@L80P0@1PL02`0?1@H03PD6
00/92P0?3Pl081hO02`X:@0S7R003PP:00l62@0A1`/04@H:008040@800<04@D9ooooooooool04_oo
ool001_ooooo0P0?3a40100@418020P:00d=3`0=3@l2014A4`80410B0P0?3a40200>30d040h?018@
4@0B414040h?00h<3@0A3a0040h?0P0>30d03`0?3@h040h?01HD5@19AdP06aTJ014?40091`P04a4B
00h<3@0A3a004Q0A014?400=2``030/900h=2P0200h=2@0400l>2P0@3`/040l;010?2`804Q4=03P0
4A0<010?2`0A40`03`h=01PG5@0=30X040l=014@3P0:2@L040l=018A3`0D4a404a8@010?3@0?3P`0
3@d;00`<2P0=3@/03`l=00h>300?3`d04A4?010@3P0?3`d03Ph<00l?3@0=30T05QDA01/J5P0B4@d0
3`h:014@300C4Ph04A0<00h=2@0?3PX04A0<010?2`0>3PX03a0;014B3@0B4`h04A8=00l@2`0>3`X0
3a0;00/<1`0A4Pd04Q<>010A300Q8Qd04a@?01@E400<3@P03Pl:014B3@804a@?00d04Q<>014B3@0A
4Pd04A8=00d>2@0@4@`03a0;051AC01LGEP04a@?010A300A4Pd0414<00803@h900D0414;00l@2P0?
40P04149010A2P02014B2P0301@E3`0B4`d0414;00804A8<00T03Pl:01@D4P0C4a<05ADE018B4P0<
30`03`l?00d=3@0C4a<00P0A4A40200G5aL06QXJ018A3`0C4Q004A0>00l>300B4@l05A@B1P0@3`d0
300<30X03`l=00h>300=3@/03`l=00h>300F5Q@04a<A010@3P0?3`d0410>014A3`804Q<>00@051D@
018C3P0D5A007AhI0P0B4`h05P0@4@`04A8=014B3@0@40h09BLW02l`<P0C5AD051HE010B4@0G6AL0
5ALC00d?300L7QX03a4;014C3P0C5A004A8=01HG4P0F5a@04A8=010A300C50l2014B3@05018C3P0D
5A005AHA01DF4@0D5A000P0B4`h0500C50l051D@01DF4@0K71P0824L018C3P0A4Pd05QLB01DG4`0G
6AH05ALD014C400@4Pl051HC01HH5@0A4a003a4>01PJ5`16B4D07R0M0P0F61D08`0D5Q<04aDB01DG
500F61D05aTF010B3`0G6AH06adJ010B3`0H6QL061`H01@I5@0E6QH05Q/G01LL600F6aL06QlK018G
4`0F6aL0;C8^01lT800G71P061hN01<I6@0a=cL0ATa<01`R8P0F71`05adM01`R8P0K8B406AlO01hT
900P9RH051dJ0080624L01d05b0K01XS7P0I8Ql05b0M01`U8P0O:2L06R<R01/T8`0W<2h0QHj903]4
?P0P:bL072HU024[:P0M:BT07b/[01XV9P0N;BX0:CPc01/Z900U=Bd08bl]02Ld=01FI6@0EfEU02Pg
=`0S<c<09cLg02/l?@0202Li>`0D02/m@00W>C/0;4100314@`0_@d80;d=40396A`0]@D80<DA803M:
CP0jCE40>TeC03U<DP0jCE40>De?03U=CP0kCe00?E1D03mBE`0nDEL2045DF`0G04IIH01=H6L0@5=J
05AWK@1AIVX0CfAW04YOHP19G600B5]Q04YMH`1FJFl0Gg9h06AgO@1FJFl0DFAZ05a_M@1EJ6`0F6a]
05]_L01GJf`0EFUY05U]K01KKfh00P1FJVP01@1OLg40Jgmm061dL`1UMgX0JWb00080K7j200<0KGn3
06n1Q@1cQHT00P1cQHT06@1fR8`0NXb@07^=T@1lRi00PY6F08nNX`20SI<0SibR08NCV@2>VIl0TIbR
09FOY@2GX:L0VZ>Z09ZPZP2f^/D0_l?>0:Z^^@2TYk80ZJ^g0;6c_`2a/Kd0];C00;Rg``2j^<D00P2k
^LH0302n_<T0`;k;0<6nc031_L/0`[k<0<Foc@36`<h0b<7@0<_3dP3:`]40bL7@0<O1c`80a<3>0180
aL7?0<C0cP33_ld0`[k<0<6mb`30_<X0_KW70;bhaP2k^<H0^KO20;Rh`P2i^L<0^;S00;Ng_`2e]Kd0
/;6f0:j_]02[[;020:VZ[P040:^//02XZk00YJR]0:BW[080YZV^0340XZN[09nWZP2OYjX0VZ:U09NQ
X`2IXjD0U9jP09FPY@2;UY/0SIRL086<S@1kQhH0O8R3071mM01[N6h0JgU[065_GP1CHTl0G6YI05MU
F@1OKV@0HW9X06YjL01KK6<0KWmg08VJTP1LKVL0CV5K059UH@1<Ge/0D6=O05IYH`1;GUP0DVEO05EX
HP1>HE/0D6=M04IID`10Ddd0>Te703mBC011E4h0=TM103E3?P0T<Bd0<Shj02Te<@0[=c<09c<_00<0
93<^01D0:3Lb030o>P0`?cX0<D4n02@d<@0c@d009cLd02Ti=P0U=C80;cll02Xj=`0^?S/0;3`i02Lg
=00Y>CH0:3Lb028a;00S<Rd08S4/02Da;@0Z=S800P0Q;2P0500S;RX08BXW01dV8`0P:B@072HN01hX
800Q:b<07bTQ01dV8@0Q:RD06b@O024Z9`0M9R<06b@Q01lX9@0P:BH06AhJ02<X900K81`04QLC0`0J
7a/06P0L8Ad07B8N01/P700J7a/07b@P07AiM@1_M7008bPT01@I5@0N8al06AhJ01/P700J7a/05a`H
01<H500F6aL07B8N01@I5@0K81`061dI018G4`0J7a/051TE01<H500F6aL061dI0P0A5Q806`0G6AL0
5ADE01HF5P0H61P04a<C01DE5@0F5QH04Q8B01HF5P0];Bd071`L01DE5@0A4A4051@D01TI6@0>3Ph0
6a/K018B4P0F5QH04a<C01@D500>3Ph0410@018B4P0A40h04Q4?01<B4002014@3P08018A3`0C4Q00
4Q4?014@3P0@3`d04A0>01<B400F4Q43018>3@0400l;2P0C3`h04@d<014=30804Ph=01L04`l>01<?
300E4@h04Ph:014=2P0C3``04`l=00l;2P0A3@`05A4A00`82@0H51D0510A07=_L02?RHT06aHF01LA
4@0?2@T05@l?01<=3@0A2`/050h>01<=3@02010:2P0F018<300G4A406A<C018<300@2PX04`d=00h8
200Y8b<04P`<01LA4@0C3@d04P`<00l92@0B30`0208202lY:@0K5QH040/;00l92@0@2PX03`T900h8
20803`T900<040X:00l:1`0?2PL00P0@2`P0100?2PL03PT600l:1`0?2PL200h91P0>00l:1`0A30P0
4@`801<>2P0<1`@06aHB07IaK@1`JfL05a8?00d71`0<1PH040X:00h8200<1`D200l:1`0=00`7100@
2`P04@`901@?300P6aP0<bh[02<N6`0H4a003@P700h91P0=20D03PT6010;200300l:1`D03PT600L0
3@P600h8200@2PX03`T900d71`0>20P03`T900D03@L700@03`L70147200B20T04PP9200A1`P04P0D
2``030H600h8200;1@D030H600l92@0@2PX02@@401PB4P0A2`/020<305mIF@0L4Q<06@l@01882@0>
10D03`D601<92PH04PP91@0@1PL04`0?1@H060h?01892P0<0`@03P@50147200A20T02@H700h<3@2B
T940iN7R03Td=P0=1`T02@4301H<3`0B1`/03`D701862P0<0@@05?ooool001_ooooo00<0CdmA00X:
300G5aT00P0>3Q00100J6Q`04A4C010@4P0@418300l?4@0300h<3@0?3@h03`d>00803`d>100>30d0
400@3Pl04@l@018@4@0@3Pl0:2HW018@4@0D4Q<02PP9018@4@0<2P/03P`=010>3`0A3a0040h?00l>
300?3P/200l>2P<040l;00`04A0<00h=2@0;2PH02`X6010?2`0D4`l01PD300`;2@071P@03Pd;01<B
400?3P`5018A3`0600l>300:2PP02PX800h>300A4@l0410>0P0?3`d200h>300<00l?3@0@40h040l<
01<B3P0D4`l03`h:010?2`0A40`03`h:010?2`0A40`040l;0P0>3@T04P0?3`X03a0;014B3@0B4`h0
4A8=00l@2`0D5A003a0;00H70P0:2`H03Pl:00d>2@0C50l02``700h?2P0=3PT03a0;010A30<04Q<>
0`0A4Pd02@0K71L01`P301LH4`0:2`H07b0K01LH4`0>3`X03a0;010A300200h?2P03014B3@0A40/0
4A4900804Q8:00@04a<;01<B3@0G5Q4051<>0P0>3@T03`0@3`/04A0=01`L700E5AD0410@00l?3`0<
30`03Ph>01DE5@0A4A404a<C00h>3P0H61P0?Cdm010?3@0201LF500301<B400B4@l05aHD00H04Q4?
00H07alM01PH5P0G5aD04A4?00T91`0B4Q06014A3`0N01@E400?40/03Pl:00d>2@0?40/061TD014B
3@0>3`X04A8=01@E400>3`X02@X501HH5@0F61L04aDB01DG500C5A804Q@?010C3@0C5A0071lH018E
3@0D5a004A@=01@E400L7AP0GUmJ028S7P0C50l06AXE100D5A0201DF4@<04a@?00T04Q<>010A300?
40/0=cPc01<D3`0B4`h03@h901LH4`0A4`l00P0E5a@02`0B51403a4>014C400C5A8061XG010B3`0G
6AH0OX1m02LY9P0H6QL051HC00804A<@00D051HC01LI5P0J71T04aDB01HH5@0201PJ5`0601/M6P0E
61H04aLF014E500@51<04QHE0P0E6AP05@0C5aH061`K028V9@0M8B0041@C01XP800G7Ad08BLW02dc
<`0E6a/06AlO010F5P0I7al07R@T01/Q8@0M8b<08BLW01XS800L9B80624N01HO700301XS808072DR
01L0624N01LP7@0I8Ql092lY01HQ6`0G8Qh09c<a03<o?`0/=cT09C<d02Hd=00Q;bh07c0Z01h_:@0Z
>S80:cLc028_;@1DHf00DV5N024`;P0a@D00:SXi02dn?@0202Tk>`0302/m?@0W>CT0;40o0080<TI5
03h0<TI703A8B@0_@d@0>TeA03Q;C`0iC500>TeC03Q;D@0bADT0=TY;03Q<C00jCTl0>diB03a?EP0l
CUP0BE]U041BG00jC5H0>4]B05=VK01GJW00CV=V04YPH@17G5d0B5eP04aOH`1>HFD0DfI/05QYL01N
KgH0FFYb05MXL01OL7L0FVi`05Q/K@1LL740G71_05Q/J`1JKVd0EVYX06EiM`1WNgT0GgA_06EjM@1P
M780Jgf006j0Q01_PHD0KX2406n1Q@1`PXH0M8J:07F7R`1fR8`0N8Z>07^=T@1mSi<0PY2F092MX`2o
c=80RIJL086<TP80UZ6W0100VZ>Z09bU[02LYJ`0WjJ^09fR[02WZKH0ZJ^h0:RZ]`2b/Kl0`L3>0<O5
d`2f]<80]kG30;Zga@2n^/T0`;c;0P30_<X03033_ld0aKo=0<Bnc035_ld0b<3?0<[2d@3=`]80clCD
0<k3d`3=`]80bL;A0<S2d080bL?A00<0al7?0<K0cP35_ld00P34_/`00`33_L/0`[c:0<6lbP020;fk
aP070;^ia02i^<00^KS00;Vh`02i^;h0][Fk0:n^/`020:^Z[`0V0:j^/P2VZJh0Z:^`0:V//@2UZ:d0
Y:N/0:J[[`2LY:L0X:R[09jVZ@2FX:80UInQ096KW@2=V9X0RYFG08RCU01nRXP0PHf907B0N`1aOWD0
F6EK061^H01VM6<0BeU8061^G`1PKF<0H6iU05][H@1OKVL0GViW07R9P@2W^;80JWag05AWH`1NLFd0
EfYV04YMF@1GJ68204mPFP1204eNF01@HE/0Gg1Z049CC@10DD/0>T]503U:A00dACl0:3Lb030k=`0[
=S80:C@`02Pc;`0b?CT06bLS02Hb;P0Q;RX093<^02/j=@0_?ST0;3/f01l_;@0V=SD0:c/j0392@@0_
?ch0<T9102dm?00[>cX0;Shm02`l>`0V=SD09CDb02He;`0T<b`09cH_02Dd;@0T<BX09S</02<^:00Q
;2H08bhX028[9P0N9b8082TT01DO5`0F81P06B<K01LQ6@0H8A`07BHQ01XS7P0M9R<07bPU01`U8P0M
9R<08R/X01lS8P0?4a804ADD01XN7@0L81l06AdL01hR8@0K7ah06QhM0P0K7ah0200F6aP0?D8n030e
<@0H7AT051TE024V8P0L8Ad061dI0P0F6aL201PM6@0=01LL600C61@0;C8^02db;P0730P03Q<?01<H
500B5a<051TE01LL600B5a<04aPD01PK6@0201PH600F01/K6`0E5AD051@D01LG5`0@410061PH03/k
>`0^;Rh04Q8B01LG5`0T92@0;Bd]01XJ6P0H61P05aLG00L71`0J6QX02`/;01hN7P0@41004A4A014@
3P804Q4?0P0?3P`00`0B4@l040l=014@3P02018A3`804A0>00L03@T801<?3P0M6AP06ADD010<2`0B
3Pd04@d<00<04Ph=01D04`l>01<?300D40d04Pl;014=2P0C3``04Ph<010<2`0E4A00510@00T51P0:
1PL03`/<03Da<P0l=SH02P@401H@400E3`l08A/K00h8200?2@T00P0B30`0600@2PX04@/;01<=3@0=
1`L03`T900d71`0>20P04`d=018<300Y8b<04P`<01<=3@0A2`/05a4A01H@400?2@T040X:04@n?P0[
9BD07QPH01<=3@0@2PX03`T900h820803`T900<040X:00l:1`0?2PL00P0@2`P04@0?2PL03PT600h9
1P0<1`@03PT601<>2`0A30T03PT500h9100:1@007QTC01/F4P3RgMT0]:n[01dH5@0@2PX030H60080
3@L700@03`T801<>2`0B3@X03PT60P0@2`P01`0A30T03`X700D0000L5aD0AT4n020K600>2@H00P0=
20D0100>2@H03@P500`7100=20D500h91P0600l9200?2@T03`T9018<300A2`/03`T91P0=1`L0100?
1`L04@L801882@0B20T80147200B00/21@0H4Q@050h@01D?4@0:10H05Q0B00H00P0B30h03`T;00h8
2P0I4aD030L800d3100>10D04@L801882@0A1`P040H71`0B20T20147200E01061`0?1@H03`D600L0
000@1PL0718C00h41@0A1`P01P00014=3P0;1`P08alP04I0@P0G4A<04`d?01@;3P0=10L02`8500X1
100>0`L06@hB01Cooooo000Kooooo`0601LG6@0=3@l0DE5C01@D5P0A4A<000020P0@418300l?4@03
00h>400?3@h03P`=00803@/<00<03P`=00l=3P0>30d00P0>30d2010>3`09014?40081PL02@L800L5
1P0H5QL03@/<010>3`0=2``03`d>00<040h?00<03`h<010?300@3`/0100@3`/0200A40`03Pd900`;
1`0;2PH040l;01<B3P0E51804Q4?0P0>3@/02`0@3`d03@`:010?3@0?3P`03Pd;00l>300@3`d03`h<
00`<2P0;2`T03Ph<0080410>00X03`l=00h>300>3P`03`l=010@3P0A4@l04Q4>014@300@3`/03`h:
0P0@3`/0100>3@T04A0<01@C3`0B4@d200h=2@0A010@300@4@`04A8=014B3@0@4@`03a0;00h?2P0A
4Pd07QlJ01`M600<3@P03Pl:014B3@0<3@P03a0;010A300A4Pd01P0@4@`02P0?40/06Q/F0042000B
4`h04A8=02<T7`0<3@T03@h900h?2P0?40/200h?2P03018C3@0@3`X0410800<0410800/040l:01HE
400C4Ph03`h:00l>300A40h04A0?01DE5@0>3Ph03@d=018B4P02014A4@0<00l?3`0C4a<05QHF010@
400B4Q80:2PX00h=2`0G5Q@06APF01@C4@0A40h05QDC1P0A40h02019BDL08B4O01@D4P0E5A<030`:
00h>300?3`d04A4?0`0B4Q002`0A4@l030d8010A300H6A@05aPC00h?2P0<3@P0414<00h?2P0B4`h0
4a@?00804A8=0180418=00lA3P0J71L04Q@@00X<1`0520404QD=01`O600N8AP04QD;01LJ4@0D5`h0
51D?00h?2P18BD@061TD00/<1`0I6QD401@E40804a@?00`0414<018C3P0C50l051D@018C3P0A4Pd0
?Chi01@E400G61<03a0;01DF4@0@4Ph201@F4`0901<E4P0@4Pl03a4>01@F4`0;3@X06A/H01@F4`0a
<c0030h;00804Q@A00`04A<@01<E4P0A4a004aDB01HH5@0@4Pl05QPE01LI5P0H6QL06Q`I01<F500C
5aH2018F5@0<01<G5P0D61L06AdL01`P7`0G6aX04ADD01XN7@0M8B003A<C02H/;00A5aL020h>0P0J
82002P0C6AT0728R024W9`0J82005Q`L01XP800T;B`09Bh]01hW9@0H8B0201XS800O01TR7`0J8b00
6b@P01hW900N9b8072DP01/V800I91h09S0^02Xf=P0G8b<0BEAF0390@@0Q;c008S0`00lO700E9R00
8S<[01/W8`0Z>3<0;3/f02Th=@0X=c@093@c02Ti>00[?3/0:cdm02`n?P0^@400;Clo02/o?P020396
A@1;03=7B00dB4T0;d=403M:CP0iC500>4]?03M:D00fBDl0=4M;03I:B`0kCdl0?e9F041CF@12E5d0
A5IP04UKI@0lCUP0CEmY041CFP14Eeh0D6EX04aQHP17GEh0AEYK04UNH@1?HVH0D6=W051SJ@1BHfX0
EfQ_05MXL01EIVh0FV]b05]_L@1GJf`0Ffm`05eaL01JKVd0FFe/05M[J@1YOG/0KH5o061eL01TNG@0
HWId06QjO@1/OX80KX2406n1Q@1bQ8P0M8J:07J8S01gRHd0NH^?07^=T@1mSi<0OY2D08JCV@2CX:H0
^LK<08jKX@25T9H0Uj:X09JQY`2JXjX0W:F/09fV[@2PYjl0YZVd0:^]^P2Z[;T0/;6n0:f/^P2`[kd0
_Kc:0080^;K400<0^kS60;nkbP32_/d00P33_ld20<S2d0090<O1c`39`M00bl?B0<g5e03@aMD0dLKF
0=35e@3?a=@0cLCC00<0blGC00<0bL?A0<S2d036`<h00`35_ld01@34_/`0`kk<0<6nb@2n_<L0^kW4
0080^KS000P0^[W10;Zi_`2f]K/0[jjc0:b[/02][;40/K6f0:f^/`80Zjjc03l0Z:^`0:JY[P2UZZh0
WJFX0:>[[P2RZZd0Uj6S09BNX02AVid0RYJF08nKV@2=VIL0OXZ608FBR`1cP7P0FVMM04aIC`2MZih0
a]C506QfIP1KJEX0HVmU05m^I01OKfD0H6mX05][H`1RLf/0IGI`05QZI@1LKf/0GG1/05Q[I`1LKf/0
Gg1Z05AUG`1=GUP0BU]E04UJE01CI5h0@55;03a=A`0fAd40<d@n02ho>@0W=S40;3Lc02D^:`0[=S80
9c8^028]:@0Z=S807b/W01l]:00X=c80;C`g02`k=P0[>SD09cLf03a<B`0X>3L0=DE402<c<P0`@3l0
0P0/?3/08P0^?Sd0;Cdl02Hf=@0S<c0093<]028a:P0T<b`08S4Z024^9`0T<BX082/U01dX8P0P:bD0
82TT01`U800M9al06bDM01XT700M9al072HN01hW8P0T;BP07BHQ01hW900Q:RL07RLT01`U8P0S;2T0
720O02da<00S9bH04aLF01XN7@0M8B02024U900901dQ800J7Qd06alN020T8P083@T05AXF01hS7`0F
6aL03A8>008061dI0P0K81`02P0J7a/05Q/G018G4`0V:bL0E5UE04Q=B@0C61@0724M01XO6`0C61@2
01@I5@804QLC01005aTG01HF5P0F5QH06a/K01LG5`0E5AD0410@018B4P0D51@0820P01LG5`0C4a<0
4A4A01TI6@0Q8B40410@0P0?3`l02P1fMWH0KFe]00l?3`0K6a/03@d=01@D500@3`d04Q4?01DD4P0C
4Q02018A3`0<00l>300@3`d04a8@01<B400B4@l040l=010<2`0E4A007a/J01dI600D40l04`l>1@0B
3Pd00`0B3P/04`l<01<?2`02018>2`0?018>300A3@`030P7018>3P0<20T03@T:01LC500300001P00
018<300E3`l0100001XD500B30`03`T900<04@/;00@04P`<01<=3@0@2PX04@/;0P0>20P0200@2PX0
3`T900d71`080`<0618B01LA4@0D3Ph03@L70P0@2PX01`0E3`l05a4A03Xd=00C3@d040X:00l92@0>
20P00P0?2@T00`0@2PX03`X700l:1`02010;200F00l:1`0>2@H03`X700`7100?2PL05Q4>018=2P0=
20@020@101lJ500<1`4040/704E0?016@Cd05A0=00h8200<1PH03PP8010:2P0C3@`05a8?01D@3@80
3PT600h03@P500`7100400008ahK01<>3@0Q71T0;bXW014<2@0>2@H03`X700h91P0=20D030L400d8
1@D03PT600H04@/:014;2`0A2`/050h>01D?3`0A2`/600h8200400l7200A1`P04PP901882@P04@L8
01808APK02DO8@080`@04`d?00P2100:1@H04`d?01@>400<1PP0208400h82P0@2P`0308300d3100@
1PL04PP90147200@1PL80147200F01061`0?1@H03P@500d3100A1`P03`H702<I6P0>10D04PP901XA
4P0;1@L02P@600@0000;1@L02@<500/51`0B2@`02`8501@;3P0E30l03PD801P?4QCooooo000Koooo
o`0600h>400H61X0GEeO02DU9`0@418061PJ0P0@418200l?4@803Ph@00<03`d>00h<3@0>30d00P0>
30d03P0?3@h040h?014?400@3Pl03`d>00h<3@0=2``04Q0A014?400F51D040h?00X82@0C4A804@l@
0P0@3Pl0100?3@h03P`=00d<2P0@3``5010?2`0F00l>2P0B4@d04Q4=010?2`0?3PX040l;01<B4007
1P@02`X800d<2P0C4Q005A@B018A3`0?3P`03Pd;00l>300A40h04Q4?00l?3@0>3P`03`l=010@3P80
3Ph<00l03`l=00h>300?3`d0410>014A3`0C4Pl040l;00l>2P0A40`040l;00l>2P0@3`/04a8>01DD
400C4Ph00P0@3`/0100B4Pd04Q<>014B3@0A4Pd200l@2`0<01<D3`0:2`H04Q<>018C3P0<3@P04a@?
00l@2`0H6A@051D@01HG4P0E5Q40414<1@0>3`X200l@2`0401HG4P0?40/0414<018C3P803Pl:00H0
3a0;010A300>3`X03Pl:018C3@0B4@`2018B2P804A0;01P04A0<018A3P0A40h04A0?01<A4P0C4A<0
3`d?00h>3P0;2`/03`l?01DE5@0B4Q804A4A00d=3@0F5QH0410@00h>3P0D51@03@d=00d<2P0C4Q00
5QDC01<B400@3`d7014@3P0802LW9@0B4Q00410>014A3`0=3@/05ADC00l?3@0@40h3018B400301<C
4@0C50l051D@00807AhI01`051D@010A300A4Pd04a@?01DF4@0@4@`05QLB028S7P0O8A/030h801<F
3`0@4``071lG02lb:00K7Q@0>3/a03Xm<@0N8QD06A`@01/N4`0H6A@030d801<D3`0G61<030d801HG
4P0B4`h04a@?100B4`h201@E400601DF4@0C50l04A8=010A300D5A0030d80`0E5Q40F`0F5a<04aDB
01<E4P0D5Q<04aDB014C400?4@h04aDB00h@3@0G6AH01`T601TK600F61D04A<@01<E4P0F61D03a4>
014C400I6aP04A<@01@F4`0G6AH04aDB01HH5@0C5Q@051PG01HJ6@0H71/05a/J01HJ6@0B5QD06QhM
01dQ800E6AP0720O01XN7@0I7al0728R01DK6`0G7Ad04QPH01/Q8@0I7al07B<S02@Z:P0N92@05adM
01XO800P:2/08BT/01`U9P0H82806b@T01/T8P0I8Ql06B8M01`V7P0O:2807bTQ01`V7P0O:R@07RTT
01`X9P0S;bl0930`08:?T010CTl0938c04ADD`0R<Rl08C8]02<d;@0S<BX09C</02Xi<P0X=c409CD_
02ho>P0_?c/0;Sll02m2?`0`@d00;T4o02m2@00_@d80=4Q703=7AP0eBDX0>4a=03A8B@0cATX00P0n
DED203Q;D@0V049EF@0hC4d0@5AE04MJG`19G680C5iX051RKP1HJWL0C5iZ04EGH@1>H6T0AUUP051U
J01;HF80AUiM04EMG@1=HV<0CfAW04iSIP1HJg40FFYb05a]M@1MJgH0G6Ye05][L`1KKW40EVYY05U]
K01KKfh0FFe[05Y^K01IKF/0HGIa06IkMP1OM6l0J7eh06UmN`1aPXP307:3RP0607F6S@1gR8l0NX^B
07b=U01nSiH0P96H0P21TYT03`25TYP0RYNM08^HWP2@Vj40TYfS09:LX`2HXJP0W:F/0:2X/02SZ[80
YZfe0:^^^@2^[K/0[:^i0;Je``020;Fc`@0C0<2mc02m^LP0_KW80<2kbP35_/h0b<7A0<W3dP3;aM<0
cLOE0<k7eP3>a]D0clOF0=;8f03DbMT0e/WJ0=O:f`3Eb=T0e<OH0=;8f0020=3:f0040<o9e`3<a]@0
blGC0<W3d@80al7?0P36`<h01@35`<h0`Kk90;nmb02l^/D0^[W10080^KS000T0][Fk0;>b^02^[K80
[Jba0;2_]02d];T0][Nl0:nb]`2Z[K800P2[[[<08@2RYj/0X:R[0:F]/02RZZd0VJ>U09JPXP2BW9h0
RYJC09FQV`2EXI`0OHZ3082=Q@1bOgL0GFYP04mLDP1OKF00L7ia05e[GP1TLFH0JWM^05e[I01MK6D0
G6]T05i^J01FIf40F6US05IXH`1DIf<0CF1N051SH@1TMg<0H71/05=TGP0204aME`0L04IGD@0oD4X0
@E9<03M8@P0a@S`0<44k02ho>@0^?CP0:C8_02P`;P0Y<Rl0<3Tf02Ha;@0T;b/07RXV024_:P0/>cH0
;Sdh02Ph<`0[?3L0;cln03a<B`0^?Sd0;cln0310?`0V=SD0;cln0310?`80;cln00h0:SXi02De<P0W
=S008S4Z02<b:`0Q<2T08RlX02Hc;00Q;2H07BPR020[9@0R:bH072DP01dW7`806B<K00P06bDM01TS
6`0J8ah082TT01lX8`0O:2D07RLT01dV8`8072DR01808BDT01XN7@0J7Qd07B4P020T8`0I7A`08BDT
02P/:`0R9RD061`K01/O7P0N8R007B8N06Y_J`0L8Ad08BHR01@I5@0J7a/201hS7`0:01HK5`0I7QX0
6QlK01PM6@0B5a<06b0L01XO6`0Z;b/0<SLc01LL608051TE00H05Q/G01/P700K81`06adK01DE5@0B
4Q8301LG5`0301XJ6P0L71`04a<C00805ADE00l051@D01PH600@41005ADE00h>3P0J6QX05ADE05AD
E01EEED051@D01/K6`0;2`/03`l?00h=2`0B4@l00P0I61H0100E51804A0>010?3@0A40h201<B4008
018A3`0A40h05A4@018>3@0E4A0061@C01@@3`0A3@`201<?3P<04Ph=01@04Ph;01<?300D40`04`l<
018>2`0A3@/04Ph=01TE500<20P04Ph?00d92P0A3@h05A4B01PB4P0;1PH050h>014;2`0C3@d030H6
014;2`8040X:00@04P`<01<=3@0B30`050h>0`0A2`/04@0?2@T04@/;01XD500@2PX04P`<00l92@0D
3Ph03`T9014;2`0?2@T05Q0@00l92@0J51@01@00010:2P0?2@T03PP800803`T900<040X:00l:1`0?
2PL00P0@2`P05`0?2PL03PT6010;200=20D03`X701@?300A30T030L300h91@0B3@T02`H301@?2`0:
1P@05A0<00d81@0=1`L03PP800l92@0>20P03`T8018=2P0A30T03PT600804@`900L03`X7010;2@0D
3``03@T601TD4@0=2@L03PT600<040/800<03`X700h91P0>2@H01@0>2@H01@0?2PP03PP800d71`0@
2PX04P`<00L03`T900@040P80147200B20T04PP9200A1`P0100R6A`0:bDW014;3@0D3Q02018<3P09
00`6200B30h05@lA01LA4`0I4aD04@/=01<92P0B20T04@L8008040H71`0A1`P00`0@1PL03`D600l5
1P0200l51P0;00h41@0C2@X04PP904<i>P0a9bP04@P900`4100A1`/04@L:01482`0<1@H00P0@1`X0
1P0/9RP050h@00h92`0@2`d061<E02l[;1Cooooo000Kooooo`06020P8P0410H02PX<01@D5P0?3a40
2@T;0P0?3a4300h>400300d=3`0>30d040h?00804@l@00<040h?00h<3@0>30d00`0@3Pl02@0>30d0
3@/<00h<3@0100003`d>01DC500A3a002PP9010>3`0400l=3P0400l>300@3``03`h:00l>2P803Pd9
0P0=30P00`0A40`04Q4=00l>2P0200d<200703Th=P0M71X07A`J010?3@0<2`T03@`:014@3P03010?
3@0:014@3P0@40h03Ph<00d=2`0?3`d04A4?010@3P0?3`d0410>00l?3@803Ph<00X03`l=014A3P0@
3`/04A0<01DD400?3PX03Pd9018A3@0A40`03`h:0P0@3`/04P0?3PX04A4<018C3P0A4Pd0414<00l@
2`0>3`X01`P5024R7@1OH5/0A4E00042000>3`X051D@01dN6@0C50l05QLB01@E40<03Pl:00/03a0;
010A300@4@`04A8=00L80`0=3PT02``701XK5P0K71L0414<00l@2`02010A30803@h901l0414<01<B
3@0E4Pd05A8=01@@3@0C3``04`l>01@@4@0C3a004PdA01<>4P0D3aD04PlC010@400>3Ph04A4A010@
400=3@d0410@01@D500B4Q803@d=00l?3`0C4a<04Q8B010?3@0?3P`04A0>01<B400B4@l03@`:00H0
4Q4?01802`/901<C4@0E5A<03`l=00`<2P0A4@l04Q8@014A3`0?3`d0410>018B400C4a4051D@00`=
200=3PT0414<00l@2`0A4Pd201<D3`0B01LH4`0@4@`04a@?020Q700N8AT030l600lB2@0F6@l03Q46
02LZ7`0U:1`0Qh]m0:^_X01aMFH0<3@U02DY6`0E5Q004A8=0P0B4`h00`0D5A00414<014B3@02018C
3P<051D@00@06AXE01HG4P0D5A004a@?0`0A4Pd07@0D5A005aPC00l@2`0B4`h051HB018D4@0A4a00
51HC01HH5@0E5a@051HC01hP7@0>40d04aDB01XL6@0H6QL051HC018D4@0C5A805aTF018D4@0I6aP0
=3Hc01dO700?4@h061XG01@F4`0F61D05QTG00805QXI0`0G6aX0<P0J7Qd08bLV028V9@0F6QT061`K
020T8`0<4Q808BLW01lU9@0N92@07bDU01LM7@0D6QX04aTI01XP800K8B405Q`L01TN800E72806B0V
01PP900H82<06b<U01/T8P0J8b006b@O01`V7@0K9A`06bDJ01/U6`0H8ad0930/024]:`0K9bL0930`
04=AD`0/>Sd05bDV02De=00V>CD0;d8n01DW800K:R<0;Sdc02/k<@0/?380<T<j02<d;00cA3`0;d4k
0P0bACl02@0]@3`0<4=102m3@P0bATD0;d=20314A@0fBT/0=DU:03I9C@0203iAE@0`03U<DP0kCU@0
@eIJ03I:B`11EEH0B5]Q04MJH@19FfH0CEm]04aNK013EF80CEmY0:>e_`1/OhH0?E9E04aTI017HEh0
BF9O04iVIP1>HfH0BUmR05EXKP1LKGD0GFif05e[MP1LJ7@0FfUb05Y]KP1HK6/0FVi]05Q/J`1HK6X0
GG5_065eL`1VNgH0Jh1k06IkM01fRh@0OY:@07N9SP1gR8l0MXN>07B5S01gR8l0NHZA07b=U01nSiH0
PI:I0`23U9/05@2>Vj40RYNM08bIW`2EX:H0V:6X09^TZ`2MYZd0XZVa0:F/]02V[KD0ZK2h0;:e`02m
_<X0^;K40;Vga@2h]/@0]k?20<2lb`32_/d0a[o?0<W2dP020<c5e@0C0<k7eP3Bb]T0e<cK0=G=g03D
c=/0elcL0=S<g@3Ic=d0f/gN0=_=gP3Ibm`0elWJ0=K:fP3Dc=/0dl_J0=;:f@3@b=L0c/KE0<g5e002
0<c4d`0S0<[2d@39`M00al3?0<:obP31_lX0`;k90;fla02k^/80^KS00;Fd^P2c/[P0/:nd0:n^/`2a
/;D0/k>h0;:c^02]/;D0ZZfb0:^^/`2Z[K80YJZ^0:6Y[02RZZd0W:BW09JPXP2GXJ<0TI^M08VFS`2;
V8h0RYN>07J3NP1cP7H0Hg1V05YWG@1PKF<00`1QKV@03`1GI5X0IW=Z05aZH`1LJf@0DV5L05i^J@1K
K6H0H71]05Y/J01KKVX0GG1^05MZJ01BIF40DV9O055PF`0204iMF00J04]JE@13DTd0@U5<0391?00a
@3/0=D@o0350>`0`?3P08R/X02H/:P0L8R008BXW01hX9@0f@Cd0;3Pd01`Y9@0Q<2/0:STd02/k=P0_
?c`0;3`k0720P010D500AUIF01/[:`0Z>SX202Ph>00S02@d=00V=SH09CDe01h^;@0W=Rh093@Z02De
:`0R<RP08BhU02<`9`0R;BD072LO020[8`0S;BD07BLO01`V7P0Q:b808B/S02@^9P0P:R807RLR028[
9P0N9b808R/X01XS800P:BH09Bh[01/T8@0P92<0HfMV04eAD00F6QT05a/J01`P7`0K7ah00P0M8B00
5P0K7ah06QhM01`Q7P0F6aL0=S/g01/P700I7QX041DA01PM6@0I7QX04aPD018G4`0R9b<082DQ01DJ
5P0A5Q806QlK01DJ5P0I7QX082DQ018G4`0F6aL201@I5@807B8N01l07b4O01XJ6P0C4a<05ADE01HF
5P0G5aL06QXJ01/K6`0A4A4061PH01hN7P0>3Ph06QXJ010@400B4Q8030`<014A4@092@T0410@01@D
500?3`l02`/;00X:2P0H61P03Pd;014@3P0E518051<A018A3`0@3`d04Q4?00804A0>00T040l=014@
3P0B4@l04Ph=00l;2P0A3@`040`;00d9200?2`X00P0C3`h2018>3@0E014=300A3@X04@d:01@A3@0C
3``04@d:010<2P0C3`h03`/:018>3P0D4140:bLX03@`<@091@H03`T901hH60080P80100001XD500@
2PX04`d=008040X:0P0B30`00`0?2@T04`d=00h82002018<300=010:2P0E3`l02`D500`61P0C3@d0
40X:01<=3@0:10@04@/;01<=3@0:10@03`T901@>3P02010:2P0500l92@0>20P03`T900l92@0@2PX0
0P0?2PL2010;200400l:1`0>2@H04@`900l:1`803PT600T03@P500d8100A30L01`8001TD3P0;1P80
6A@@00@0000?2PL00P0?2@T200d71`0500d71P0?2PL03`X700d81@0A30T00P0B3@X0200C3P/01000
04<n>`1WHUl05Q4>00/60`0=20D03PT60P0?2PL700h91P0700d71P0<1PH030H600/51@0=1`L040X:
014;2`0500l92@040108200A1`P04PP901882@P04@L800`071<F00T31@0:10H0DD]=06]UI`0G4A<0
4@/=018<3P090`D040X<01hH6P0>2@X201882@040147200@1PL040H7014720H040H700@03`D60106
1`0A1`P04@L80P0C2@X04P0<0P<04@L800L0000700006Q0A00L0000900404@H901L<400B1`/03@D7
00`31P0>20X03PT:01PD5@0K5aP040h?00X:2QCooooo000Kooooo`06014A4`0B4Q@06ATK00L72@0;
2`d051@F0P0?3a4200h>40803@d?01803P`=010>3`0C4A804a4B010>3`0>30d030X;00h<3@0@3Pl0
4@l@010>3`0?3@h030X;00l=3P0H5QL02@L800l=3P0B414300h<3@05010>3`0A3a004Q4?00l>2`0?
3PX00P0>3@T00`0=30P030/700`;1`0200l>2P0900d<200<2`L03@`8020O7@081`D040l=00h=2`0B
4@l05aHD00H03Pd;0P0<30X00`0?3`d04Q8@018B4002014A3`0D010@3P0?3`d03Ph<00h>300@3``0
40l;01<B3P0G5Q803`h:00h=2@0C4Ph03`h:00/:1P0<2`L03`h:00h=2@0@40/04Q<>014B3@0@4@`2
00h?2P0<018C3P082@@06a`G01LH4`092PD05QLB00/<1`0M7QT0414<01@E400B4`h03@h90P0@4@`2
014B3@0O018C3P0C50l061TD01@E400B4`h01PL200X;1P0D5A00414<014B3@0@4@`03@h900`=200?
3`/04A0<01<@2`0C3``04Ph;014=2P0A3@`05a<D01@@4@0@2`h04@`@01<>4P0D4A@0410@00l?3`0@
41003@d=00/=300201@F5@0600d?3P0E5AD051@D00`<300D51@04a8@0P0?3P`00`0D4a404a8@00d<
2P0601<B4008014B3@0?40/02P/600l@2`0D5A403@d;01@D4P0A4@l200h>3006014A3`0C4a404A8=
00/<1`0?40/04Q<>0P0@4@`06`0D5A00414<01LH4`0B4`h03Pl:01LH4`0B5@d06A`E02X]900e>2h0
30l401PK4015BC`0e][<0?kol`2i_Jh0@4@e024U5`0G61<051D@02DV8@0;30P07QlJ01HG4P0B4`h0
4a@?01@E400201HG4P805aPC00h05AHA01@E400D5A005AHA01HG4P0E5Q404a@?01DF4@092PD04a@?
01<E4@0B5140418?01<E4P805aTF010061XG00lA3P0M7a`05QPE01@F4`0;3@X061XG01@F4`0B5140
5aTF01@F4`0P8Ql0ATQ502LY9P0<3P/06A/H0P0G6AH01@0I71X05QXI01DI600D61L05QXI008061`K
00P07b<R02<W9P0K7ah051PG01DI600E6Qd07R<V01<I6P804aTI0P0J81h0CP0F71X06b4O01hT900I
7al06R0Q01LO8P0K8RP06b<V01TQ8`0L92H06R<Q01TR7@0K91l07BLO01`V7@0K9a/07bXN01XW7P0J
9b008BdY02<_;@0O;Bd07bd_01`Z;@0R<S807Bd/01`_:`0/?cT09cTc02Pg<00Q<2T08C8Z02Dd;@0X
>C40;Slg0352>P0]?cP0<dI003A7@@0`@cd0=DQ402/o?P0]@D80:Cdn02Xn?`0bADP0<TE903M:CP0j
CE40>Da@03M:CP0hBe00?4mC03E8C010DeP0AEQN04=FG@13EEl0AeUS04EGH@14EV00EfUc0:^na@1?
HVT0DFAZ04eUI@19HF40Bf=S055VI`1=HVD0BEaP05AWK01OL7L0H75h05m]MP1OK7D0GVed05]^K`80
Ffm^00X0Ef]Z05U]J`1OLg40H7=a06QkM`1]P7`0IGQc07V<R025V9H0LhB90`1dQH`01@1iRY40NhbC
07j=U022TIP0Q9>J0080QYFL0200QYFJ092LXP2;UY`0WJR^09>MX`2?V9l0XJV`09nV[P2RZK40YJ^c
0:B[/`2X[;L0ZZ^h0;Jd`P2h]/@0_K_90<>ocP2o^lX0`ko>0<Joc`39`]80cLKF0<o8f03@amP0dLSI
0=C<f`3FcMh0elkN0=K>g@3Ic]l0f/kO0=[=gP80flkP00<0fLcM0=S9g03Gbm/00P3Gc=`04P3Eb]X0
dlSH0=76eP3@amH0clOF0<k6e@3;`m80b/;A0<W1d033`</0`/3;0<?0b`31_/T0_Kc40;Zi`@2g][h0
][Fk0;>b^080/K2e06l0/[:g0:b]/P2[[[D0[:nf0:V//`2XZk00ZJfc0:>X[02OYjX0V:2S09JNX@2G
XJ<0T9ZL09:MU`2<VHl0RIF;07V6O01ePWP0HW1S06MeJ01KJE`0I79V06YgK@1IIU`0Hg1V05YZH01K
JV<0Gg1Z04iMF01GIf@0EVIS06=cLP1KK6X0EFQT05AWH`1EJ6@0EfYV04iOF@1BHed0Cf1J04aME`1;
FUD0BEQC045@B`0b@3/0=40l03Y6A00c?cd0;CLf02Pa;P0V;b`0;CHc02`e<P0`>cL0T9ZI05=OG@0^
>cT09SDb02hm>P0[>SL0:3Pg02Lf=P17EED09CDd02@c<P0Z>3P0:3Pg02Xi>00Y=cL08c<b02Lf=@0W
=CD082l/02<a:@0U<RT0:3D/02@a:00M:R407bXR020[8`0I91`07BPP024[8`0K9Ad06B<K01`V7@0O
9Ql082XR01/T7P0G81/06R<P020Y9P0W<2l06R@S02D_;P0]=cH082TX02X_;@0e>CP0:Bd/01TM700N
8R407B4P01PL6`0C5aH061`K01dQ800K7ah05ATG01`Q7@0=4Ph00P0H7AT05@0M8Qh06b0L01TN6P0G
71P08bPT03Hk=`0X;BT06AhJ01DJ5P0J7a/061dI018G4`0K81`06A`I01/M6P0G6AH04Q@A01PJ5`0G
6AH07AhM01lO7`0301DE5@0:01HF5P0E5AD07AdM01DE5@0C4a<06QXJ01<C4`0?3`l030`<01DE5@80
61PH00X05aLG01@D500=3@d06QXJ01DE5@0H61P03`l?00l>300@3`d04A0>0P0>3@/03@0A40h04a8@
018A3`0@3`d03`h<010?3@0C4Q0040`;018>3@0F4Q404@d<00/71P0B3Pd00P0C3`h2018>3@804@d<
01l04@d:01@@3@0D40d040`9010<2P0C3`h05Q8A018>3P0T8240;b//01LC500E4A805Q0@00l92@0F
41005a4A00h8200A2`/05@l?014;2`0@2PX04P`<014;2`0=1`L050h>00l92@0B30`04@/;00d71`0B
30`05Q0@008040X:00`03@L701@>3P0>20P04@/;00d71`0@2PX03PP800@0000G4A4040X:00l92@0>
20P200l92@03010:2P0?2PL03`X7008040/801003`X700h91P0A30T040/800d81@0;1P<030L400h9
1P0E40/061<?00/60P0>2@H03PT5018=2@0?2PL03`T90P0=1`L0400@2PX04P`;018=2P0C2`T03@H4
00d81@0?1`D03PP500l:1`080000:bDR03Xe<P0<10804@`900/60`0<1`@900h91P0700h81`0>20P0
3`T900d71`0>20P050h>01D?3`0500l92@040108200A1`P04PP901882@P04@L800h01P0000H00P0A
2`d08A/M03H`<P0=20T04P`>00`6200=1`T050h@018<3P0>20X03P@500l51P<04@L8200@1PL00`0A
1`P04PP901@:2`0201H<3@0;03@Z:`0=1@D040H701/A4P0:0@406a4B00T00@0E2`d050P<00l4200=
0`H00P0@1`X01@090`D02`D700d92P0<2@X02@L801Cooooo000Kooooo`0400l=3P0B41404Q0A010>
3`803`d>00P020H7014?400=2``030X;014?400>30d040h?00l=3P803P`=0P0?3@h01`0>30d05aDF
06aZJ`0R82403@/<00h<3@0?3P`00P0<2`T02@0=30X03`h<014@3P0D4a4040l=01@C4@0?3P`04a8@
010?3@0500l>3007010?3@0=30X051<A00`;2@0L6aT05aHD014@3P0300d<2P0600l>300A40h04Q4?
00l>300>3@/03@`:0P0>3@/04`0A40h040l=00d<2P0A40h05A@B01<B400B4@l02`X801@C4@0A40h0
30/901@C4@0=30X01`L501@D4P0T92803`l=01@D4P0>3P`00P0@40h0600A4@l03Ph<00d=2`0?3``0
4Q<>01@E400A4Pd03Pl:010A300E5Q40H65L038c;P0@4@`02``701<D3`0?3`/05A@@028Q7@0A40`0
51<?014@300E510051<?01<B3P804A0<00D04Q4=00h=2@0C4Ph04A0<00d<2002018A3@<04a8>0P0@
3`/01@0A40`03`h;018A3P0B4@l051<A00804a8@0P0@3`d07@0@3`h040h>010>3P0@3Ph03`l=01/K
6@0D5Q<02`l;014F4P0?5a8031@?00`A3@0>4Ph03a4>00h?300C4a405QHD010@3P0?3`d0410>01@D
4P0>3P`04Q8@010@3P0>3P`0410>014A3`0?40/03a0:0080414:00/04A8<014B3@0B4`d03@h900h?
2`0E5A<02PX8010@3P0C4a40410>018B400201<C4@0K018B400@40h04a<A00l?3@0@40h05ADC00d=
2`0A4Ph04aD@018D3`0A50h04QD>01PK4`0K7Q@0@D@i09ZNT@3Lh=80PXIh01`P4@0D60X05AH@01<D
3`0D5A005AHA018C3P0@4@`04A8=0080414<01<05aPC010A300F5a8051D@018C3P0C50l05QLB01DF
4@0D5A005aPC01<D3`0F5a805aPC01DF4@0D5Q8051HC018D4@0C5A805ALD008051HC00L06A/H01HH
5@0F61D06A/H01HH5@0H6aP05a`H008061dI0`0F6aL0;`0C61@041DA01DJ5P0I7QX05a`H01DI5`0=
4A00=SXi04a@C`0K7ah061`K01DI600M8B00;S8a02``;`0I7A`061`L05QMHP25RY007R<W01<I6@0J
81d061lI01`S6`0I81T07R@O020V900L8R006R0P01lT9P0P9BL0728Q01`U8`0T;B/092dZ01`W8@0M
:2807BPQ01`X8@0N:b<07RXQ01`Z7P0M:al07blU024`:P0R<Bh08C0`00808C4a05/08C<a020c;`0P
<bd08cH_02<d<@0Y>SP0:Sdj02Tk>00X>cP0:chi02/n>00Z?CL0;T4k0314>`0cAch0=dY603=7B@0_
@TP0<4=902e0AP0gBTl0<dI;03U<D00mD5@0>diB03M:CP0gBdd0=4M=045BG@13E640@E9L049CF`17
F5h0A5II04IHF`11DUL0DV=Y07F6S@1LKGH0E6M^04eQI`1?HfL0DfM[05AWJ`1FJFd0Ffea05i`L`1Q
L7@0Y[Fi0:2_/@1PKW00IWEg061bL@1ML6h0GW5_065dLP1PLG00GFm]06MgMP1_OWd0LX6007:1P@1d
PH40Lh:207:3QP1gRHd0NH^?07^:S`1nS940OhfB08:?U@29UI/0QY:H08NCV@2=VIl0SiZP0:>]/P2I
XJL0UinU09fUZP2QYZl0Y:Va0:R/]@2Z[KT0[[2m0;6d`02c]L80^[W80;nkc030_<d0a;oA0080b<7C
00h0b/?E0<k5f03?a]T0dlWL0=G;gP3Gbml0f<cP0=W=h03Jc^80g<oS0=_@hP3Kcn<0gM7U0=oCiP80
g];V01@0gM7T0=kAi@3OdN<0g/kP0=c<gP3KcMh0fLcM0=O:f`3Eb=T0dlOH0=76eP3?a=@0cL;B0<_1
d@39`]40b<?A0<O2c`34_/X0`Kc80;fja@<0]kJn06P0]KJk0;Be^P2c/kT0/k>m0;2`^`2][KP0[:bf
0:Z[]02UZK00Z:fc09^PYP2PYZT0V:2S09:JW@2OYjT0S9FB08J@RP1hPgX0JgM]06IbIP1ULF<0H6iN
06AbHP1/OFh0JGU/061`I01RLfP0IGI/05IYH@1KKVP0G6e[061cLP1JK6d0HWAe05QZJP1HJfL0FFaX
05=VG`1BIeh0EV]T06=hLP1>HU`0AeYD04AED@16EE80?de:03]6A@0c?3`0?DA6030f>@0Z<S@09S0_
02<^:P0Y=3007bXX01l[:P15DE40>DA5030k?@0f@D@0<Ca0030k@00c?d<0;3Pf03I2?`0V<c00;CXg
038n>`0_?3T0:3Db02`h=@0/>CH0:SHc02Da;P0Q;BT09S0[02<]:00T;RT08bdW024[9@0L9B008BXU
020Y900Q:RD08b`W01hW8P0J8ad08RPR02L/:00M8Qh082HS01TR800L9B@0:S@d018M7P0V<S<06RLW
020];`0P:R`08bTV02P]:@0R9b<082DQ01hS7`80724M00D06QlK01/P700L8Ad06QlK01/N700201`N
7@0A01XL6`0M7ah07R0O01hP7`0I6aX05aTH01/M700L7Qd06adL01XM700H71/061XI01TK6P0J71/0
6Q/J01TJ6P0I6AT00P0G5QH03P0I61P071TJ01lM7@0E51804A0>01PG5@0F5A<061LE01DD4P0F5A<0
61LE01LF500E518051<A1@0C4Q003@0D4a404a8@01HE4`0F5A<040l=00l>300G5Q@0L6m]00l>300D
4a806APF018A3`0?3P`01P0A40h00`0B3P/04Pl;018>2`02018>2`804Ph=00L04@d=010<3@0B3Pl0
4Ph?010<300C3`h04Ph=00<040`;00T04@d<00/71P0B3Pd0FeMF061LF`0@30/03PX9018>3@0A3@`0
0P0@30/04@0A3@`04Ph=00`81`0A3@`03`/:010<2`0D40l02`L600d81@0>2@H03`X700h91P0@2`P0
5Q4>01D@3@0D3``03`X7008050l<00P03`X700l:1P0@2`P03@P500l:1`0B30`03`T9010:2P@040X<
00X040X:034/:P0?2PP03PT6010;200:1@8030L4010;200?2PL03PT60P0?2PL0200@2`P04@`902DP
7@0D3``03PT600`7100@2`P03`X70`0@2`P01P0>2@H03`P601481P0C2@P050X9018920804@L600H0
4@P601471P0A20H04@P601471P0@20L500h8200500l92@0>20P03@L700d71`0>20P00P0@2PX01@0B
30`04`d=010:2P0B30`040X:00803PP800/03`T9014;2`0;1@D030H600l71`0D2P/04@L801D;300B
20T03`D60147200301061`0A0147200C2@X04PT:00l92@0=1`L030H600h8200A2`/03`T900`61P0?
2@T040X:00h8200?2@T04`T:01882@0A1`P00P0@1PL02`0A1`P03@<401882@0B20T03`D601882@0C
2@X03P@500l51P0@1PL04@L800804`T:00<07A<D01<92P0D2P/00P0?1@H00`0E2``03`D601061`02
01882@0601061`0?1@H050X;01882@0@1PL03`D60P0@1`PDooooo`006oooool02@0@3Pl03P`=00d;
300?3@h040h?00l=3P0N71d03`d>00d;300201<A4P@03`d>00<040h?018@4@0C4A800P0=2``04P0^
;2d030X;01LE5P0>30d03@`:00h=2`0?3P`04A0>018A3`0C4Q0061LE01DD4P0G5Q@030/900l>300>
3@/04A0>010?3@803`h<00T03Pd;00d<2P0?3P`05A@B00h=2`0K6QP05QDC018A3`0?3P`00`0>3@/3
00l>30<03Pd;01@03`h<014@3P0>3@/030/901@C4@0I61H05A@B018A3`0;2PP04A0>01DD4P0?3P`0
4Q4?01<B400?3`d04A4?00d=2`0>3P`051@B014A3`<0410>01<03Ph<00/;2@0<3@T04Q<>00l@2`0=
3PT05aPC01DF4@061`<0@T<n02d^:@041@40;c0[0411?00=3@T030/700h=2@0?3PX04Q4=00<04a8>
00L04Q4=014@300A40`04Q4=00d<200A40`04Q4=00803Pd900d030/701DD400A40`03@`800l>2P0B
4@d04A0<01TH5P061@<04A0>01HE4`0R8Al02PT700H04A0>01`051<A01PH5P0=3``00PL300dB3P0A
5a<03A<?00/A3@0?51004A<@00d>300A40h071`J018B400N7Q`0410>00h>300@40h061PF01@D4P0A
4@l0410>00l?3@0<3@P03a0:00l@200@4@T0414;0P0A4P`01@0?40/03@d:01<C4@0=3@/05ADC0080
4Q8@02T04A4?010@3P0@40h04A4?018B400@40h04a<A018B400@40h04Q8@01@D4P0@4Pl04A<@014C
3P0B50h05APA01PK4P0I7180:RdR02P[8010A3L06Ad?00hA1P0B4`d04A8=018C3P0E5Q404a@?018C
3P0C50l04Q<>00l@2`0C50l030d8010A300E5Q404a@?01@E400G61<05QLB01DF4@0301<D3`0601@E
400F5a8061TE01DG500C5A805ALD0P0F61D03@0E5a@05aTF01@F4`0P8Ql08bDR01DG500E61D05a`H
01DJ5P0C61@051TE01HK5`0E6QH00P0B5a<301@I5@0G01/O7@0>4Q405ATH01lS8P0E6AP06QhM01PL
6`0@51<04ADD02HZ:@0Z;Rd06alO03Tn@P18CE<07b@X01@J6P0P9R805QdF01XQ6@0G7QH06B0I01XP
7P0G7A/00P0I7al0:00K8B406R0N01XS800N9b@072DR01dX900I920092lY02dj<`0U<R/07BXR01dZ
800N;1l07RhT020_:00P;b`07bl^020`<00Y>CT0;D0m02<f<P0N<B/09cXc02/n>P0X>cT0:C`j02`o
?@0^@Ch0:chj02Lj=P0^@C`0:chh0313?@0nDDX0?U5=02Lk?00lCe@0@eIJ03U<D016FEh204MJH00[
03E8CP19G680A5MM03Q;D00dAdh0@e=R04eMK01;G6H0AUMO049CF@0kCDl0A5IH04=EF00oDED0BEYQ
05=TK@1?HVT0B5]R05IZL01CIV`0DfIZ05i`M01OLGD0Gg5c05]ZK@2GYZT0Ri^K06AbL`1LK6`0GVm^
069eL`1KKV`0HWEc06MgMP1OKfh0JWYi071nOP1bP800M8:207V5Q@1iQhP0MhJ:07^:S`0207b;T00N
07j;T@20SI<0QY>I08jIW`2;UY`0RYFK096JX@2CW:<0U9^Q09VPYP2LXjT0XJR`0:b`^@2_/[d0[Jnk
0:na_@2d]<40^;O50;Zia`2l^/X0`[k?0<S1d`39`]@0b<7C0<_2e@3@amX0e<_N0=O;g`3Jc^80g=3T
0P3NdND07@3Od^H0hM;W0>;Dj03Qe>P0hM;W0>;Dj03ReNT0h]?X0>;Dj03PdnL0hM;W0>;BiP3Qd><0
glkQ0=k>h@3LcN00f/_N0=O9g03FbM/0e<OI0=35eP3?a=D0cL?D0<_3dP3:a=80bL?A0<Fob`33_LT0
_kc70080^KJo04D0^;No0;Nf_02f]K/0/kBj0;>c_@2a/K/0[Zjh0:f]]`2[ZkD0YZV`0:N//P2KX:@0
XjR/0:F][`2]]KL0YJj^08fFT`25SXT0L7Ya05eYG`1LJ5`0J7AV06UgIP1]NfX0KWm_06=cIP1VMV`0
NX^10762NP1KKfL0GG1Z05e`KP1RMGD0Gg5c061bM01IJf/0EfYV05EXI01CIUl0E6UP04aQFP1KLFX0
?U=<03U<AP0nD4/0>4Q5041<BP11C4/0F69S03U1@`0W;C00:C4c02H`;`0]>CL09C4_02Hb<P0^>SX0
82`/01/V:01gPX@0;3Li02/f>00/=c/09S4c034m>P0M:BD0>DE102Te<@11CDT00P0]>CD0300/>3@0
:cLc02Te<@0V<Rh09C4]02Xc;P0Q:RD092dX02/d;`0F7aX09RlZ02</9`8082TT00L08BXU01lX8`0M
9R408bPT02D[9`0L8Qh08bTW00806b@S00/0MX2103E1@@0L:2P0;3Li01HT9@0U<C408BHS02DZ9P0Q
9R8082DQ01lT800201dR7P0>01/P700M8Qh07B8N01`Q7@0L81d071hM01TK6P0G6AP061XI01XL6`0H
6QT05aTH01XL6`0K7A`201XL6`0501/N7@0D61L051HE01/M700G6AP00P0F5QH04P0E5AD061HG01LE
5P0H5QL07a/L051>C@0i>3H061LE01/J600Q81h06QTG01hM6`0J6AL051<A01DD4P0G5Q@05QDC01DD
4P8051<A00l04a8@018A3`0B4@l05A@B01@C4@0C4Q004Q4?01<B400E51807A`J00P71@061@@05QDC
01lN701KFUP01@0A40h00`0A40d04Ph;018?2P03018>2`804Ph=00L04@d=010<3@0B3Pl04Ph?010<
3@0C3`h04Ph=00<040`;00@04@d<010<2`0D40l01P810P0:1PD00`0G4a8040`;00l;2P0200h:2@0>
00l;2P0@30/04Ph=01@@3`0C3`h04Ph=00`81`0A3@`03`X701@?300:1@801P4000/60`080`0201LB
3`0;010;200A30T040/800`7100?2PH04@`900h91P0?2PL03`T900/51@0>20P0100>20X0200>20P0
5Q0?00D000080`003PT6010;200E40d03PT60P0=20D200h91P0>00l:1`0C3P/0<bh[020K600<1`@0
2@@101D@3@0=20D03PT600l:1`0A30T040/801491`0A1`H301881`L04@L600<040L700d71`0=1`L0
0`0=1`L02P0>20P03@L700d71`0=1`L03PP800l92@0A2`/050h>018<300>20P200l92@0<00/51@0>
20P05@l?01@>3P0:10@02`D50108200F30d03P@500P0000700005@/<0P0A1`P201061`040147200B
2@X03`H700d71`803PP800@03`T9010:2P0?2@T03@L70P0@2PX01@0;1@D02P@401<92P0B20T04@L8
008040H700L04@L801@:2`0A1`P03@<401D;300L4Q<04`T:00803@<400`03P@500l51P0@1PL04@L8
01H<3@0900401`0001882@0A20P04@L800l51P0@1PL20147200401061`0?1@H03P@5014720804`T:
00<040H700`20oooool04oooool001_ooooo00<030X;00l=3P0@3Pl00P0?3@h01`0@3Pl0<c4b01HD
5@0=2``040h?00h<3@0C4A800`0>30d02@0?3@h04Q0A01<A4P071@H03`d>00`:2`050`@06aTJ00D3
1002010?3@0;014@3P0@3`d03Pd;00h=2`0D4a404a8@01HE4`0>3@/04a8@01@C4@0B4@l00P0@3`d0
2`0>3@/03@`:00`;2@0@3`d04a8@00/:200B4@l02PT700L6100A40h03`h<00@03Pd;030040l=00h=
2`0>3@/03Pd;00l>300<2`T03Pd;01@C4@0@3`d030/9018A3`0D4a4030/901DD4P0Q81h04a8@00h=
2`0<2`T04A4?00@40P0:2PP05QHD0000000C4a40410>00h>300;2`T03Ph<01HF500E5Q8030d800X;
1P0>3`X04a@?014B3@0?40/030d800X;1P0K71L0@D8m059CCP0B4Pd02`X601<B3P0I61@051<?010?
2`0C4Ph2018A3@804A0<01<04Q4=01DD400E510040l;00X91@0=30P05QDA01XI5@0D4`l03Pd9018A
3@0F5A4051<?02@S8@0O7Q`05QDC01LF500U92806APF00H04Q4?01@05aHD01@C4@0<3@/03A8>01DJ
5P0<4Ph03aDA00/@300<4@d03Q0=00h=2`0A40h06QXH00/;2@0C4a402PX801@D4P0B4Q005aLE01<C
4@80410>01003`l=00`=200D5@l04a@<014B2P0?40X03Pl900`=1`0I6QD02PX7014A3`0H61H092@R
010@3P0C4a404A4?0P0?3`d0100A4@l04a<A010@3P0B4Q0200l?3@0?01DE4`0>3P`04Q@A01<E4P0B
5140418>010B3@0A50d04A@<01LJ4@0X:b804QD;024T6@0?4PT05QLA008051D@01P05AHA018C3P0?
40/06Q/F01/L5`0F5a806Q/F01@E400H6A@051D@018C3P0C50l05QLB01DF4@0D5A004a@?01TJ5@0G
61<04a@?01DF4@0H6AD051HC01<E4P0D5Q<201HH5@0901PJ5`0E5a@030h;01lQ7P0W:BH05ALD018F
4P0G71P05Q/G00805AXF0P0F6aL201PM6@0O01@I5@0@5A404AHB01LK6@0A5A@03a<B018F5@0G6aX0
720O01XN7@0K7ah05QXI01@H5`0C5aH082@T01lT:00I7R805adN00lE5@0Q9bD06R0K01HM5P0E71@0
6R4J01`R7P0I7ad0728R01HL700H7Qh0728P01hW9002020Y9P0601`W8`0H8al0:cH`03U6?`0Z=c00
7BXR0P0N:b40?00N;R@07bhY020_:P0O;bd0:3Ph02lo?`0cAT@0:3/g028e;`0W>S@0:Sdk02`o?@0^
@Cl0;d9002i1?P0/?c/09STe0313?P0Y?3H0;T4k041DC00lCd/0>Ti=03mCE@15F5`0=TU=03U<D@10
DeT0<4=903e@EP0gBU00A5MM041CF@10DU`0GVim06AdPP1LKGL0DfA^055RJ@1AHfL0A5IH04UKGP1C
IFT0C5eT05AUK@1AI6/0C5mU05U]L`1BIF/0EfY^069dN01MKg<0IgUk05e/K`1VMGP0G6a/06ilO@1N
KVh0Kh1o05a_K@80H7=a04T0HW9a06YjN@1[NgX0L7in07:0P01dPX80NXJ607^9RP1kRHd0OHbA07j=
TP1mS940P8fC086>U027U9X0RiJL08ZEV`2@Vj40UYnV09FNY@2FWJ<0W:>Y0:2W[@2TZk<0[;2i0:nb
_@2`/[h0/K>o0;Jga02k^/P0_;_90<2mc@33_m00al3B0<[3e@3<aML0dLSK0=G<g`3Gc^40floS0=kB
iP3Pe>P0hMCX0>;Dj03Se>T0i]CZ0>KEj`3Ue^/0i]CZ0>KFj`3Ue^/0imG[0>KEj`3TeNX0i]CZ0>KD
j@3Sd^D0hM3S0>3@h`3Ncn80g<gP0=W;gP3Gb]`0e/WK0=;7f03Aa]L0clCE0<g5e03;aM<0b/CB0<O1
c@35_l/0`;g80080^kS104P0^[W10;Rg_@2g][`0];Fj0;Bd_02b/[`0[jni0:f]]`2/[;@0YZV`0:>X
[02RYj/0XJJZ0;6i^`3Dg=h0U9bM08:;R01mQX40KGM_05iZH01PK600Kg]]075oKP1/NVT0J7UZ06Yj
K`1YNFh0K7ec05m`J01WNW<0L8=m05]^K01CIVD0Gg5c05QZK01JK6/0FfiZ05U/J01DIf00DVIM04=H
D@13FE40@5E>049EC`0hBTD0A5=@03a8AP13CTh0HVa]03Dm?`0d>Sd0<CTl03Do@00b?Sd08Rh^02Te
=@0lB4P0<Cdm03E0@P2R[Jl0@4a<03M2A00b?Cl0:SHf030l>@0R;RX0=T8n02Te<@0lB4@0:3@`02Hb
;P0W<bl202Xf<P0;02Hb;P0X=300:C8]020Y900U;RT0<CXe01DN6@0Y<Rd08BXU01hW8P0M9R400`0L
9B003P0P9B408bTU01dS7`0X;R`06b@S01PQ800X<S<03a/K010L700I92H0<Cm002@`<00O9B8092TU
0`0P9B400`0N8al0724M01/P700201`Q7@0801/P700L81d071hM01XL6`0K7A`06Q`K01/M700M7ah2
01/M700N01TK6P0K7A`06adL01XM700A5A@04A<B01XL6`0D5QD04Q8B01HF5P0I6AT071XK01LE5P0C
4A806QHG02TW9P0E51804Q4?00d<2P0100006aXH02/Z:00Q81h04a8@01DD4P0M71X08R4O01HE4`0E
518051<A0P0B4@l03@0A40h05QDC01<B400A40h04a8@01DD4P0C4Q002@P601TH5P0J6AL05QDC00D4
0P0Q81h01@0B4@l00`0B4@h04Ph;018?2P03018>2`804Ph=00L04@d=010<3@0B3Pl04Ph?010<3@0C
3`h04Ph=00<040`;00L04@d<01@@3`0F4Q404Ph=01dI600?2`X0510?008040`;0P0>2PT2010<2`04
018>3@0:1PD03PX901PD4`802@D400@07APE03<^:`0T7a`05A0=0P0H4a0201D@3@<03`X700<030L4
010;1`0B3@X00P0?2PL00`0>20P02P@400h8200400h82P0800h8200:10<03PT601HA3P0E40d03@P5
00`7100@2`P200l:1`05010;200A30T04Pd:00l:1`0M61D00P0C3P/0100<1`@03PT600h91P0?2PL3
010;200401091`0A1`H04@L601881`P04@L600<040L700d71`0=1`L01P0=1`L200h820803`T901<0
40X:00l92@0<1PH04@/;01<=3@0@2PX03`T9018<300D3Ph030H600d71`0@20T04@L800h41@0M4a@0
7Q@E01X@4@0B20T04@L8008040H700@04@L801882@0?1PL03PP80P0?2@T02`0>20P03@L7010:2P0=
1`L03PP800l92@0<1PH03PP801<92P0B20T04@L8008040H700L04@L801D;300B20T03`D601L=3P0M
4a@05@/<00803P@500X03`D601061`0@1PL04@L800X00@0G3@h060h?01dC500@20P04`T:1P0@1PL0
1P0B20T040H700h41@0=0`@040H7014721Cooooo000Kooooo`0700X82@0C4A805A<D010>3`0=2``0
40h?01HD5@0300d;300300/92P0A3a003@/<00803@/<00T03P`=010>3`0A3a005A<D00h<3@0?3@h0
3@/<010>3`0>30d00P0>3@/400l>300501<B400@3`d051<A00l>300D4a400P0B4@l2010?3@0800l>
300>3@/03@`:00`;2@0A40h02`X801@C4@0?3P`2018A3`03010?3@0?3P`03Pd;00803`h<00@040l=
00l>300?3P`03`h<0P0@3`d200l>300F010?3@0B4@l05A@B01@C4@0>3@/04A0>01`K6@0<2`T02`X8
028R8018B4H0DE5?00`<2P0H61H030`:00h>300@40h051@B00l?3@0>3P`061PF01/K60803@h900l0
4a@?00X;1P0:2`H04A8=01<D3`0;30P0414<00L80`0?40/05QHA01@C3`0F5A404a8>00d<200@3`/0
0P0?3PX200h=2@0;00l>2P0@3`/04A0<01<B3P0E51004Q4=01<B3P0N7AT092<O01dL600E51000P0C
4Ph01P0?3PX04Q4?01XI5`0T8b80>cXh00P71PL04Q4?01<02`X800l>300C4a4041<@038h=01GGET0
728N00lD400<3``03Pl=014A3`0G5Q@030`:01<C4@0D51803`l=010@3P0>3P`04A4?00803Ph<00@0
3`l=014A3`0?40/04Q<=0P0A4PX2010A2`0900l@2P0A4Pd04A4>01<C4@0>3P`06QXH010@3P0C4a40
4Q8@0080410>00<04Q8@01<C4@0A4@l00P0@40h0900J6QP0:BTW014A3`0@4Q404Q@C014C4P0@4Q40
4Q@B01<E4@0@4Ph06adI05QKE@0I6aH0418<01LJ500A4Pd0414<018C3P0C50l04Q<>010A300C50l0
61TD010A300D5A004A8=01@E400B4`h0414<014B3@0D5A004a@?018C3P0E5Q407QlJ01/L5`804a@?
00@05AHB018D4@0A4a004aDB0`0E5a@04P0G6AH05ALD01`N6`0H6QL04A<@01LJ5`0C61@051TE01DJ
5P0C61@04AHB01<H500H7AT06QlK01LL600C61@05AXF01LK6@807B4P01@061`K01HJ6@0D61L04aLF
024U900L81l061`K01hR8@0G6a/082DX018G6`0M8R@04aTI01/Q7`0I7a/05ahH01PO600M91d0728N
01LM6@806R0N05@06b4O020V900O:2D072DR01dV8`0O:RH062<O01lZ9P0U<Bd072PT01dY9@0Q;RD0
8BhT020`9P0P;bT08C0[024a;P0S<c8093@c02@g=@0W>SH09cXe02Dh<`0U>3H0<49203E7A`0`@d40
;3lm02e0?P0X>cL0<D@o02Xm=`0/?cT0>Da603A7@`25VIL0BEeL03a@D00mDE80@5=F041CE`1<GfD0
SJ2V03Q;DP0mD5P0@59K05U[MP15EF<0Cem]04iOJ@19FV<0B5UP04EGF`17FEd0A5IJ05]]L@1?H6L0
D65Y05MZL@1CIfd0Ef]`05=VK01RMGT0KGn306AfNP1QLgD0NXV<086@T`1QLG40IWAe05][J`1YNgT0
Ffi/05e`KP1/Ogd0L81o06]kNP1^OWd0Lh6107F3P`1fQ8@0NhN707b9RP1nSI42082?U00^086>U024
TIL0QY>I08^FW027TYP0RYFK09ZSZP2MYZd0UYjV0:2UZ`2QYJh0YZZc0:b`^@2^/;`0/;6m0;Fe`@2g
]/@0^k[80;nmb`31_ld0a/;B0<[3e@3<`mH0d<OJ0=G<g`3Jc^80g=3T0=gAi@3PdnL0hmKZ0>CGj`3U
f>`0imO/0>WGk@3/enh0k=W_0>_Ik`3]f>l0k=W_0>cJl03^fO00kMW_0>_Ik`3/f>h0j]S]0>OFj@80
iMCW00P0i=?V0>3Ai03Mc^40g<gP0=W<gP3FbM/0eLSJ0=?8f@80clOF00@0c/KE0<[4d037`Ld0aKo;
0P2n^l@0DP2m_<@0^k[00;Vh_P2h]kd0][Jn0;>c^`2`/;P0[jng0:j^]@2XZk40Y:V]0:2UZ02KX:<0
SiNI09nWZ027T8h0O8F107V3O01bO7<0JWI[06YfJP1_Nfd0IG=T06YhJ@1bPWH0KWic06=bJP1RLf/0
HG9Z06aoN020Thh0KX5n05]^K@1MKfl0G6i^05Q[JP1CIV80EFQT05Q[I@1EJF40BUmH04aPFP11E4h0
@eA>03I6@P0a@3d0=D4o03E0@00g@D807bLY04A<C`14CE00?DQ:030k?@0U<3809S4c02dh>@0c?cl0
;SXj03Y6A@0[=cD0>4A302<_;@0a?CX0;CTe03E1?@0T<2`0;3Pd02di=@0_>cL0:3@`02/g<`0b?SX0
;CTe02<_:`0T<2`08R/V01lX8`0N9b809RlZ02</9`0K91l2028[9P0H024Z9@0N9b807RLR01lX8`0R
:2H061hL01hT8P0oB4D0;SLf01/T8`0N:2L08bd^02H`<@0S;bl06RDW01`V9`0O9B808bPT01lT800P
9B408BHR01hS7`0K81`06QlK0P0K81`01@0J7a/06alL01TK6P0I6aX07b4P00806Q`K028071hM01/M
700I6aX05QPG01hP7`0O8B0061/J01HJ6@0J71/06adL01@F5@0D51@05aLG01XJ6P0M6a`061HG01<A
4P0G4a@05Q@C010?3@0E5180:2LU01lN700K6QP06APF01DD4P0B4@l05QDC01TH5P0H5aD05QDC01DD
4P0D4a404a8@0P0B4@l0300E51804Q4?014@3P0D4a405QDC01<B400B4@l05QDC00`;2@0B4@l03`h<
01HE50D04Q4?00<04Q4>018>2`0B3`X00`0B3P/2018>3@07014=3@0@30d04Ph?018>3`0@30d04`l>
018>3@03010<2`07014=300G4a804@d<00h:2P0V8R404Ph=00h:2@02018>3@8040`;0P0B3Pd0500E
4A004Ph=01<?3P0V8R404`l?00h:2@0;1`D050l<00h91P0=20H04`h;00P3000>2@H04@`900d81@0>
2@H04@`900l:1`0C3PX04`h;0P0?2PL00`0@2PX030H6010:2P04010:3003010:2P0@2PT03@P50080
3@P500<04@`901HA3P0?2PL00P0>2@H02`0@2`P04@`9018=2P0>2@H04Pd:00/60`0@2`P030L4014<
2@0@2`P04@`9008040/800D03PT600l81P0A1`H04@L601061@0801471P0301081`0>20P03PP800@0
3PP800<03@L700h8200?2@T00`0?2@T03P0@2PX03`T900`61P0@2PX04@/;01@>3P0@2PX02P@400l9
2@0A2`/03`T90108200>10D04PT:0P0b:2T0100B2@X04`T:01882@0A1`P201061`0:01482@0C2P/0
40X:010:2P0>20P03@L700`61P0B30`03PP800d71`8040X:00@05Q0@01<92P0B20T04@L80P0@1PL0
0`0A1`P03P@501061`0201061`0301<92P0B20T04@L800D04@L800L05P`=00l51P0=10D030<401<9
2P0?1@H04@L800@040H700L04@L800d3100@1PL04`T:01@:2`0A1`P03P@501Cooooo000Kooooo`03
01PF5`0B41403`d>00804@l@00L03P`=00l=3P0D4Q<04Q0A010>3`0?3@h02@L800803`d>0P0>30d0
500?3@h040h?00@20`0K6AX030X;01DC500@3Pl0108300h=2`0=30X03Pd;010?3@0C4Q0051<A01DD
4P0<2`T04A0>00l>300@3`d02@P61P0?3P`0200>3@/04A0>00X91`0=30X01PD300/:200A40h040l=
0P0?3P`2010?3@03014@3P0@3`d03`h<008040l=01D04a8@00h=2`0;2PP05A@B01/J600D4a403Pd;
00l>300;2PP051<A00H50`0A40h0A4=106a/JP2ATHl06ATG00L71@0B4Q004A4?00/;2@0=3@/00P0>
3P`01@0?3`d03a0<01<D3`0B4`h0414<008071dH00/0414<0001000E5Q40414<014B3@0F5a801PH4
01`K5`0?3PX020L300`;1`05018A3@0801<B3P0E51004A0<014@300E51003Pd900P70`0A40`300`;
1`0900h=2@0@3`/04Q4=00P71@0A40h0>3Le05EDDP0@3`d02`X800H04A0>01<05Q8A00l>300=3@/0
5aTF07b1O@3Wk>P0:Rl[01TM6@0?4@h03Ph<00/;2@0<2`T0;2`Z010@3P0E5A<0<30^01DE4`0A4@l0
410>00803Ph<00@0410>018B400A4Pd03@h80P0?40P02`0A4P`04Q<=01<D3P0:2`H04a<@01<C4@08
20H05QHD014A3`0@40h04A4?00804Q8@00<04A4?010@3P0>3P`00P0E5A<0100R8R00?Shl020P7P0?
414200l@4P09014B500F5aT06Q`K01XL6`0A4a808R@Q06Y/JP0B51400P@100803a0;00P04Q<>01DF
4@0E5Q404a@?02`]:00_<2/0824L01`M60805AHA00l04Q<>010A300A4Pd051D@01<D3`0B4`h04A8=
01@E400B4`h03a0;010A300C51004Q@A014C400C5A800P0F61D01`0E5a@051HC01HH5@0`<Rl0:B/X
010B3`0B5A800`0G71P201HK5`8051TE0P0F6aL0500G71P061dI010D4P0F6QT07B4P01hR8@0G6aX0
4aLF028V9@1GFeX0DUIE01TM700?4a806alO02@Y;00S:2/06b0S01HL700B61H07bDR0P0J81`02`0L
8Qh06AlK01LM6@0R:2@05Q`J01DK6@0L8R007BHS01/T8@0Q:RT08B/Z00808bd/01007BTW01/W9@0Q
;B`09C8[02@a:00Q<BL08C0Y028a:P0S=2h09SHc02De<P0T=c<0:Sdi02e0?00/?c/0:C`j0P0^@400
1@0/?Sh0:cdl02`o?@0[?S`0;D0l0080;d8n02/0<4<n02m2?00_A3l0=DU703]?C@0dB4L0?U9D04=F
FP0aA4X0EFQ`03Q:E01;GFT0AeUU03e?F`10DUh0BE]W04YLIP1:GF@0B5]R041CF@1@HfT0BUeS04eP
IP1:GF<0E6M]05MZL01JKg@0E6Q^059UJ`1GJVh0FVa`05QZKP1UMgT0HG1c06AcMP1JJVX0HFm`06Yj
NP1LKV`0HGAb05mbL01`Ph40O8b;0080Lh>200H0NHN707^9R@1kRHT0O8R807f8RP20SI8208:?U@04
08>@UP2:UI/0SIRN08bGW@80SYNN01P0Uj2W09bSZ`2IX:P0XjN`0:V/]@2/[kP0[k6m0;Bd`02h]l@0
^kW70;bjb031_/d0a<3A0<K2d`38`]@0e<_N0>3Dj03MdND0e<SL0=O:gP3NdND0hMCX0>CEjP3Wf>d2
0>WJk`0H0>kJl@3`f_40l][b0??Lm03cgO@0lm_c0??Ll`3bg?<0lm_c0?;KlP3afo80lMWa0>oJl@3[
f>h0jMK/0>SEj`3WeN/0iM?Y0>7AiP3Ncn@0g<gR0=W<h03Gb]h0eLWL0P3AbMP0B@3?amH0c<CA0<[2
c`37`Ld0`kg70<6na`30_LH0_K[10;^h_`2h]kd0][Nl0;Be^P2a/[L0/;6f0:j_]02Y[;00ZZnb09BJ
VP2JX:00UYnN08B=RP1jPh00QXn:07j8P01aNg<0K7Q/06eiK@1/N6X0GF]N06EcIP1]OG80IGE[06=b
K01aPW`0VJZT06aoN`1SMW80Gg9^05e`K@1QM780G6m]05IYI`1@Hel0EfYV05a_J`1AI5h0BEaF04]N
F00fBD<0>da603U9A@0^?CX0:SHd038n?@0_>c/0>TA504I@DP15Ce40;cXn02hi?@0/=c/0;CPj02lk
?00c?cl0;CTg03A0?P0W<bl08RhZ02<`:@0W=2d0>4A002Xf<P0N:RH00P0X=3003P11CDT0;c/g02di
=@0d@3`0:cLc020/:00T<2`08b`W02H_:P0M9R409RlZ05aUH00Y<Rd08b`W0P0V;bX0:`0Q:RD082TT
024Z9@0J8b409c0_01lX9`0T;B`09Bh]02`e=00e?ch0:38a02/e=00B71d0;CLh01hW9P0P9B808bPT
01dR7P0N8al07b@P01hS7`0K81`06QlK01/P700L8Ad06QlK020T8@0N81l06A/J01`N7@0E5aH05aTH
01XL6`0R92<0:2XY01/M700I6aX071hM01<F5@0K7ah08bDT01DG5P0B51<00P0E5AD03@0F5QH05aDF
01PF5`0G5AH06ADF01LE500F5A<06QTG010?3@0?3P`08R4O01@C4@0F5A<00P0I61H00`0G5Q@04a8@
01<B400501<B40<04Q4?0P0C4Q001`0B4@l06QTG0040000P7ad010<101/J600;2PT01@0A40h00`0A
40d04Ph;018?2P03018>2`804Ph=00L04@d=010<3@0B3Pl04Ph?010<3@0C3`h04Ph=00<040`;00L0
4@d<01<?3P0>2PT0:RHU04a8A`0@30/03`/:00804@d<0P0?2`X2014=300>01LC4P0k=cH0:2@S01hJ
6@0;20L0920O01<>2`0<1`@020<000/60`0A30T040/800d81@0C3P/200l:1`804`h;00L08QdI01`G
500D3``040/800l92@0<1PH03`T900@03`T;00L03`T901@?3@0G4Pl05Q4>01<>2`0=20D02PD20080
30L400/03@P500l:1`0@2`P04@`900l:1`0H4a004@`900h91P0:1@805A0=00l:1`03010;200600h9
1P0@20H04@L601061@0?1@@040H51`0A1`H00`0A20P03`T900l92@0300l92@0500h8200=1`L03PP8
010:2P0?2@T00P0>20P2010:2P0<00d71`0@2PX03`T9010:2P0>20P02P@400l92@0>20P03@L700d5
1P0H3Pl040H70P070000100D2P/04`T:01882@0A1`P201061`030107200A20T03PP800<03@L700X0
40X:00l92@0<1PH03`T9018<300@2PX04`d=01<92P0B20T04@L80P0@1PL20147200501@:2`0C2@X0
40H701882@0A1`P01P0@1PL020070000?cDf05eCE00J41402`8301882@0A1`P040H70P0?1@H0100@
1PL04@L800d3100E2``201dC500301L=3P0@1POooooo01?ooooo000Kooooo`0601`J6`0B41403@/<
010>3`0A3a003@/<0P0C4A806@0=2``03P`=01@B4`0@3Pl04a4B010>3`0>30d03`d>010>3`0?3@h0
40h?00h<3@0=2``040h?00H51@0F51D05A@B00T81`0E51803`h<010?3@0?3P`04Q4?00`;2@0?3P`0
0P0@3`d0100;2PP03`h<014@3P0@3`d200h=2`803`h<00L04A0>00h=2`0?3P`02`X800l>300A40h0
40l=00D03`h<01h04a8@018A3`0@3`d040l=00h=2`0F5A<02PT801LF500@3`d030/900h=2`0A40h0
3`h<01<B400;2PP04Q4?02DT8P0>3P`06a/I00h>300G5aD01`L5018B400820L0410>00d=2`0E5A<0
6ATG00l?300F5a8201@E400902h_:P0Z:bH04Q<>01@E400=3PT02``801@E400Q8Qd05QHA008051<?
00T03`h:00`;1`0B4@d04a8>00l>2P0>3@T030/701PG4`0@3`/00P0?3PX2010?2`03018A3@0I61@0
4A0<008040l;00P04Q4=01<B3P0B4@d05A@B01<B400A40h051<A00l>30@04Q4?01`04A0>018A3`0B
4@l05Q8A01<?3P0C4Q004Q8@020T800b=c<05Q/G00`?300@4@l06aXH01/I5`0@3`d0ATE301PH5P0B
4Q00;Rh/01`L6P0>3P`04A4?010@3P0?3`d04A4?01HF500E5Q403a0:0P0@4@T3010A2`0501LH4`0<
30T02PX8020P7P11@Cl00P0@40h0100A4@l04a<A01<C4@0B4Q02010@3P0901TI5`0?3`d03`l=020P
7P0=3@/04A8D01XK7@0@4A<04Q<E008051DG00T03Q0@01HH600O82404Q@D01lP8`0A4Q<051DA01HG
4P0A4Pd0100E5Q401P0J6aH05QLB010A300?40/04Q<>01@E40804Q<>00d04a@?018C3P0B4`h051D@
01PI500G61<04Q<>01HG4P0C51005ALD014C400C5A805QPE00804aDB0P0F61D0100E5a@051HC01DG
500O8Ql301LL600500hC3`0B5a<05AXF01<H500D6AD00`0F6aL00`0G6aT05QXI00hB4@0201XN7@0<
014E500E6AP0=c/j02hb<@0F6QT07b<R01@H5`0G7Ad06AlP01dR900T:RX05Q`L0P0K8Al06P0O9B80
6AlK01hU7`0K8Q`0=S`g01`R7`0Q9b@0:Bl]01hW900L9B8072DT01PR8P0S;Bd08bd^02Te=P0h@d@0
9c<c02Da;00T<BT08S8Y02<b:`0T<b`093D^02Ph=00X>C@0:3/g0P0[?S/0>00Z?C/0;d5102do@00/
?Sl0;3hn02do?`0/?Sd0<4=102i1?`0aA440<TE10313?P0_@Sd0=DY503a@C@0dB4H0;d=203Y>C`0f
BDd0A5MN041CF`1;GFL0BE]W04IHI@11Df40H79n05MYL`19FfD0AUUQ04UKI017FV40BeiT04mRJ@1;
GV@0BeiS059UJP1@HfP0DFI[05AXKP1EJ6h0FFa`05e_L`1LKW80G6i`05i]L01OKW40J7Qh06EcM01N
KVh0IGIe06AgM@1ZOG/0K7mm07B4P`1mSH`0N8R70`1kRHT00`1oRh/0PHb>08>AU@0208BAU`0Q08RD
VP2<Uid0SiZP096KX@2EWJD0U9bT09JNY@2LXj/0XJF^0:NY]02_/K/0/K:m0;:b_P2g]/<0_K_80;jk
bP31_/h0a/3B0<W4e@3<a]T0d<OJ0=kBiP3[go<0j=__0=c@i03OdNH0iMO/0>OGk03ZfNl0kMgb0?3N
m03`gO<0lmoe0080m]kf103ggoL20?KNmP1H0?GMm@3dg?@0lm_c0?;Kl`3_f_40kM[`0>_HkP3Yend0
imG[0>?Bi`3Pd>D0g/oT0=_=hP3Jc>00f<[N0=O<g@3Db]X0d<OF0<c4d@3;`m00b<7>0<:laP34_/P0
`[k70;fj`@2k^;l0^k[00;Be^@2b/kP0[Znd0;6b]`2][[40ZJf^0::XZ02LXZ40UYbK08RASP23S8P0
Q8f808F?Q`1mQgl0LG]b06ahK01]NFd0JgMZ06EcI`1SLFD0HW9X06EdKP1YN7@0K7aj07N7Q@1SMW<0
G6m[05U/J01JKFX0Ffi[059UHP1FJFH0FVeY0723O`1jSHX0A5MC04]ME`0oDD/0=4I003E5@00a@Cd0
<d8o02Le<P0Y=SD082`/034l?00e@440>dI803E0A00a?400:SDg02Pc=@0Z=SH0:cLe04IBD00Z=S80
9C8[02Xg<00S<2P09S<Z04EAC@80:cLc00L08RhZ02Da;@0d@3`0;CTe02/g<`0^>SH0:CDa00808RhZ
01/07RLR02@]:00P:B@09BhY04mHD`0]=S407bPS02L`:`0P:B@0;3D`01`U800Q:RL09Rl_04mHF00R
:b/08BXY020Y:00K92<082TX01XS8P0J92<08B/[01XS8`0N9bH07b@Q028W8`0N8al00P0L8Ad0200N
8al041DA024V8P0O92007R<O01DJ5P0T9bD08R@S0P0M7ah01P0H6QT06A/J01/M700Y:bX0=CLf02HX
9`805aTH00T061/J01/O7P0S9B@05QPG01<E500K6a/05aLG01HF5P0F51D00P0H5QL0100G4a@04a4@
014@3P0H5aD201<B400701@C4@0Q81h0=SDc01PG5@0D4a405aHD01@C4@0301<B408051<A00H04a8@
00h=2`0?3P`051<A01HE4`0C4Q02014@3P0I01@C4@0?3P`05A@B00h=2`0B4@l051<A00T81`0D4a40
4A0>00l>300@3``03PX701DB3@0@30T04Ph;014=2P0C3`h04@d<010<300A3@h04Ph?014=3P0@30d0
4`l>018>3@03010<2`0400l;2P0=2@P05A4@00X71P804@d<01D04`l>00h:2@0?2`X05A4@00h:2@0?
2`X0510?00h:2@0D40l02@D5018>3@0?2`X040`;00l:1`0C3P/04Pd:00h91P0E40d09b8O014<2@0D
3``00P0A30T2018=2P04018=2@0@2`P03@P500h91P804P`<00X040X:00/51`0;1@L03`T;014;3@0?
2@T03`T8010;200>2@H03`X70P0@2`P00`0B3@X04`h;014<2@0200l:1`08010;200>2@H040/800l:
1`0B3@X03@P500l:1`0=20D2010;20803`X700<050`:00d40`0=0`800P0A1`H02@0B20L05@/:0188
1`0A1`H04PP701<9200B20L04`X:00X51@0200l92@0500h8200C3@d030H600d71`0>20P00P0?2@T0
200>20P03@L700P30`0A2`/050h>00d71`0@2PX03@L70P0>20P02@0@2PX03@L700d71`0A2@T04PP9
00l51P0F30d05@/<0147200201<92P0701882@0A1`P040H701061`0D2``02@<300d71`0200`61P05
018<300?2@T03PP8010:2P0A2`/00P0?2@T201882@@04@L80`0@1PL06`0?1@H04@L800l51P0=0`@0
2`<30147200>10D040H701882@0F30d05@`=01hD5@0<0`@050X;00`3100@1PL03`D60147200@1PL0
3`D601H<3@0>10D04@L801/A4P1EBd`04@L801882@0Dooooo`006oooool01P0C4A804Q0A010>3`0?
3@h03P`=00d;30804Q0A0P0A3a005@0@3Pl03P`=018@4@0?3@h03@/<00h<3@0?3@h03P`=00L51P0I
5aP06QPI00/92P0I5aP00@0003@c<@0O7Q`02`X8014@3P0B4@l03Pd;010?3@02018A3`06014@3P0>
3@/03@`:00h=2`0A40h040l=0P0=30X00`0>3@/03`h<010?3@02010?3@803Pd;00@040l=00l>300?
3P`03`h<0P0>3@/2018A3`0:014@3P0@3`d03Pd;00l>30081`D051<A00d<2P0:2@L040l=00l>30<0
40l=00X04A0>018A3`0B4Q00410>01HF50051@<02@T701@D4P0o?cd061PF0P0A4@l200T91`0C01<C
400B4`h04Q<>018C3P0H6A@05AHA00d>2@0?40/06Q/F01DF4@0F5a80<34/01PH4`0920@02`X601@C
3`081`<03`h:01hM6@0201HE4@0@014@300P7a/03@`8018A3@0D4`l04Q4=014@300B4@d03@`801<B
3P0?3PX03Pd901<B3P0E51004A0<014@3P8040l=00@04A0>018A3`0B4@l04a8@0P0B4@l04P0A40h0
4Q4?01<B400F4Q40510?014>3@0>3P`04A8@018G4`0?51003Pl=01<C4@0L6aT06aPG010<2`0@3`d0
4A4?00l?3@804A4?00X020P6010@3P0K6aT03Ph<01<C4@092@P06AXE00h?2@0@4@T04A8:0P0A4P`0
200@4@/02@X501LG500820H03Ph<01hN700=3@/03Ph<0P0?3`d06P0@40h04Q8@018B400A4@l01PH4
00h>300D518030`:00P81P0D5QD03@h@018C5@0C51H020T;04m@DP0Y:R`02P/=010A4`0D5AT06a`P
00P92`0E5A805aPC01PI500B4`h01PL20P0B4`h01@051P404Q<>010A300=3PT05QLB00804A8=00`0
4Q<>01<D3`0D5A0051D@020Q700;30L03a0;01LH4`0B4`h051DA01XL6@0G6AH201`N6`0>014C400D
5Q<04aDB01`N6`0Y:bP07R0M01DG500Q92406QlK018G4`0C61@06AhJ01hS7`0F6aL201DJ5P0m01TN
6P0K81`06AhJ01DI5`0F6QT051PG01/O7P0H71/041@C01TM700/<2l05QXI01DI600R9RD07b<R01TO
7`0C6AT082HV02L];@0K8B406R0P02D[:`0S:BL051XG028Y8P0K8Q/051/D01XP700R:2@08BLU01DN
6`0G81d05QlN01/U9P0U;c007RPZ02Ha<`0lAd/0:SDh02<_;@0S<2T08S4Z02<b:`0T<b`093D]02@e
;`0U=S00:3/g02/n?00/?cd0:cdl02Tk?@0[?Cl0;Cm102do?`0^@400;Clo03I9A`0cAT@0<DA203=6
@P0203A7@`0=03A9A00gBdT0>4a:03Q<B`0nDE@0A5MK04QKH@13EUh0FF]e04eOJ`0nD5`0BUaX04YL
IP0204UKI@80BUaV00/0BE]U04YLIP1@HfX0D6=Y04ePI01>HFD0E6M[05Q]LP1GJg40EfY`05U/L002
05e_L`0;05maL`1SLWD0JWUl06YjNP1XMWL0JWYj06QiN01ZOG/0KH1n07:5P`1hR8L00P1iRHP09P1j
R8P0NHN707Z8R021SHd0Q8nA08JDV026TiT0R9FK08bGW@2?VZ00TIbR09FNY@2GWZH0V9nW09bSZ`2R
ZK40Z:be0:^[]`2`/;`0/k>o0;Rf``2m^lT0`;g<0<>ocP38`M<0blCF0<g6f03@b=d0eL[O0=_>hP3Q
e>P0i=O[0>CEjP3Ven`0j]W_0>gKl@3_gO<0ln7g0P3eh_P00`3hhOT0nN7i0?WQn@040?WQn@80n>3h
01H0mmog0?GMm@3egOD0m=gd0?;Ll`3_g?80k]_a0>_HkP3Ye^`0j=K/0>OEj`3RdnP0g/oT0=_<h@3J
bn00el[L0=G:fP3Cb=P0clOD0<g5dP3:`/l0a;k80P33_LL0<P30_L@0_K[10;Vf_@2c/[L0]kRl0:VZ
[@2XZJ/0ZJZ/0:FYZ@2PYZ@0VZ2N08Z@S@1oR8<0P8V408><Q`25ShL0OhV107AnM@1/N6`0JGEY06Mc
I`1aOW@0Kgab06]kLP1[NWL0JgUi06UiN01TM7<0GW5_05IYI@1GJVH0GW5]05mbK01EJ6@0FVeY05IY
I@1TMg<0Kh9o04=FE015EE80@55;03E6@00eA3l0=DA002hm>P0X=c@09C8a02Pd=00hA4@0=T930P0d
?d402`0^>C/0:SHf02Lc<`0W<c40;c/i02`h=00U<R`0:3D^02`i<P0/>C00<3df0080:SHb00`0:CDa
02Xf<P0]>CD0;c/g02Pd<00U<Bd0930/024]:@0K9b<062@P01/T7`0Q:RD202</9`<08BXU02007RLR
02Xc;P0T;BP06B8M01LP7@1?FET0n?oo075kO00J92<09Bl^01hX9`0O:2L07BHU01LP7`0R:bX092d/
01XP7P0O92009R/W02DZ9P0O92007B8N01HK5`0k@3`0HfQT01@I5@0X;BT07b@P01LJ600J71/06adL
01`N7@806adL024071hM01lQ800P8R406Q`K01HH5`0I6aX06A`K02@X9`0>40l07R0O02X/:`0=3@d0
5QHF01LG5`0I5aP061HG01XH6@0J5QL061DE01PG5@0G5Q@04a8@010?3@0D4a402@P602/Z:00=30X0
4A0>01TH5P0E518051<A018A3`0C4Q000P0D4a406`0B4@l07A`J00l>30030P0020L500d<2P0A40h0
40l=018A3`0C4Q004A0>010?3@0?3P`01PD302LV900;2PP02PT701<B400F5A80920M01DB3@0C3``0
7QXG00/7100>2PT03`/:01<?3`0201HB4`0301<?400?2``04@d<00803`/:00d04@d<018>3@0?2`X0
4`l>00d9200?2`X05Q8A014=300300005Q8A01<?3P0300005A4@008030P70P0?2`X200h:2@8040`;
00<05A0=018=2P0@2`P00P0@2`P00`0>2@H03`X700l:1`0200l:1`803@P501<04Pd9010;200?2PL0
3`X7010:2P0A2`/09R0P02<M7`0F41802`D700h82P0:10@03PT7014<2@0@2`P03@P500h91P0@2`P0
3PT600803`X700<03PT600l:1`0@2`P01`0=20D2014<2@0E00h91P0=20D02`D401/A400N51<04`X:
01471P0D2PT03@@401061@0?1@@04@L601<9200A1`H040P700T30`0E3`l040X:01dG5`0Z92@04@/;
00D03PP800L03`T900P20P0I4a<08adM01@>3P0F410040X:00803PP800T03`T900h8200>20P04@T:
00/10P0D2P/06a4B00l51P0D2P/00`0B20T03`0A1`P040H701061`0:0@8071HF010;2`1ZI6@0Dde=
00X4100A2`/040X:00l92@0=1`L03PP800l92@060147208040H70P0A1`P201882@0601dC500@1PL0
4@L800`20`0=0`@02`421P0@1PL01@0>10D04PP90147200B20T05@/<00804PP900D040L702HL7@1J
D5404PP900l51P0Dooooo`006oooool2014?4004010>3`0?3@h03`d>00h<3@@040h?0P0?3@h2010>
3`0?00l=3P0=2``03P`=010>3`0U8b@0C4Y;00/92P0=2``04@l@018@4@0h=cD09bHT0040000A40h0
2PT700803`h<00H04a8@01DD4P0D4a403Pd;00`;2@0=30X2010?3@0500l>300>3@/03`h<00h=2`0?
3P`00P0@3`d200l>300400h=2`0?3P`03`h<00l>308040l=01<04A0>00`;2@0>3@/05A@B01@C4@0C
4Q000@0002d/:P0;2PP03@`:01HE4`0=30X03Pd;00l>300F5A<06APF01DD4P0?3`d03Ph<00804A4?
0P0K6aT02`0^;R`03@d;01PH5P0A4@l03@d;00/;2@0B4Pl051D@01LH4`0A4Pd03Pl:0080414<01H0
4a@?02l`:`0K71L051D@01XK5P0B4Ph03Pd900/:1P0V9B405aHB014@300W9R805aHB01@C3`0A40`0
71/G018A3@0<2`L040l;00l>2P0=30P040l;0P0B4@d01@0?3PX03Pd9018A3@0D4`l04A0<00804Q4?
00<040l=00h=2`0?3P`00P0C4Q02018A3`0N014@3P0B4@l04a8@01@@3`0C3`h04Pl>010@3P0A4Q00
4A<@00lA3P0A4Pl04A4?014@3P0C3Pd04Ph=014@3P0A4@l06ATG01XJ600B4Q003@d;010@3P0<30X0
000001PH5P0T92803a0;00l@2P0A4PX04Q<;0P0B4`d02@0A4P`03Pl:018B3`0820H04A4?00P81P0?
3`d051@B018B4002010@3P0M018B400C4a4030`:01LG5@0A4@l03`l=018B400A4@l04A<@01<E500G
6AP04aDD03Xl>`3Adm80EEIH00`=3`0@4A<04Q<G00/<400F5aT051@A018C3P0P8A`061TD00l@2`0/
;BP05AHA01<D3`0@4@`00`0C50l2014B3@0=018C3P0C50l051D@01@E400<3@X06Q/F01PI50082@@0
004001TJ5P0G6AH02P`900T;200200lA3P0=01/M6P0B51407R0M03Li=P0L7Q/03a4>014D4@0?5100
6QlK01@I5@0H7AT07b@P01PM6@0201HK5`0H01TN6P0K81`06QlK01<G5@0I7A`061`K01TM700K7ah0
5QXI01@H5`0N8R405ATH028V9@0O8b804ADD01PN700G7A/0728R01lT9`0L8B@0728S018H600I7ad0
7R@Q0P0P9b00CP0N9Ad06b4M01lU8@0M8al05QlL01`U8P0S;2/072HW02D_<@0T;C807bX^02Ha=`0Q
;3008Rh/028^:P0R<BX08S8X02<c:@0S=2X09SL_02Lh<00W>SD0:C`j02/n?00/?Sh09cTk02Tk?P0]
?d40;T120312@`0a@d<0=TQ80395A00aA480<dI403M:B00hBdT0=DU703M;BP0lD4l0@EEF04IJG017
FUh0@EAJ04MJH@0aA4/0;T1:04mQJ`0oDE/0@eMP04MKHP1<H6L0BemX04MKI@12EUl0C61Y04mSJP1?
I6T0C65T04mTIP1EJVd0G75f05M[L@1JKG<0FFa`05U[K`1NL7@0G6i`061_LP1UM7L0IWIf06IdM@1W
MgL0JW]j06]nO01^PGl0LhJ407V9R080NXZ90P1lRXX09`1mRh/0PXj>08F@TP28TiP0RIBJ08^FW02?
VZ00TibS09FNY@2GWZH0VZ6Y09bSZ`2RYZl0ZJff0:fa^P2_[[/0]K?00;Ne`P2l^<L0`Kg<0<K0d@39
`]@0cLCI0<o6f`3Ab=d0dl[O0=W>h`3PdNH0hmCY0>OHk@3[fNl0k=[`0>oLlP3bgoD0ln3f0?KRn03i
hoX0n^Ck0?cUo@050?gUo@070?cTo03jh_X0nN7i0?SPn03ggoL0m]kf0?GMmP020??LmP0N0?7Jm03/
f?40j]K_0>[Gl03Zf?00i]C/0>3Aj03Od>L0g/oU0=K9f`3FbMX0eL[J0=76e03>`m40b<3=0<S0b`35
_LP0`kg70<G0a`32_L@0]k>j0:f//@2h^K/0[:f_0:Z[[@2`/[40ZJf/0:2VY02HWYX0Ri6<0P22S8@2
08F?Q`0_07j8P01bO7<0JWIZ06YfJP1/N6`0N8Ek07>0M`1[NW@0K7]h06ilO01[Ng/0IWIf05]^K01I
K6P0G6m[05iaJ`1PM6/0DfIP05Y]I`1AI600Cf9N04]NG@14EeD0AeMD03e<A`0jBD@0>dY503=2?P0]
?3T0=4=002Xh=`0fA4@0AeEE03U7B00hATL0;3Ph02Lc<`0U<Bl0930^02Da;`0^>SH0930/02Te<@0`
?CH0;CXc02Tf;`0^>c@00P0X=3008`0Y=C40;3Pd02Xf<P0Y=C40:SHb02@`;00Q;BT082`X01dY9@0K
9b<072DP020Y900Q:RD08R/V02</9`0T;BP082TT03i7@P1RJfH06B8M01`U800I8Ql09c8c07=oO`0n
BTX0:38c01TS8P0P:RT0>450059KF00`>CH04QPF028X9P0[<Bl082DQ00809b`X00/08RLS01hS7`0O
92005a`H02/`;00U:RH07B8N00L<200J7Q/061XI01TK6P0301XL6`0J01/M700G6AP04aDD01<E500G
6AP06A/J01HI600S9bH030h=01<E500T9RD03`l?01HF5P0J6QX071XK01DC500F51D05a<D01PE5@0K
6QP061LE01<B400A40h05A@B00X91`0H5aD2014@3P0301DD4P0C4Q0051<A00804Q4?00<04a8@01@C
4@0B4@l00P0D4a401@0J6AL06APF01<B400C4Q004A0>00<040l=0P0?3P`03P0T8b40M7=a01XI5`06
1@<04Q4?00L60`081040;2TT02hZ9`0@30T07QXG01@@3`0?2`X0510@0P0I5AH03@0D41403`/<00l;
2P0>2PT03`/:014=300C3`h04@d<00d9200D40l05Q8A018>3@0>2PT00P0?2`X01@0A3Pd0;2PW00P4
0`0J5QD01`<2008040`;0P0>2PT200l;2P0701@?300@2`P03`X7014<2@0>2@H02@@100h91P0200l:
1`0400h91P0=20D030L4010;1`803`X701@040/8014;2`0B30`05@l?00L10`0C3@l05a4C01@>400A
2`/04@/:014<2@0@2`P03PT600d81@0>2@H02`H300X50P0<1`@040/8014<2@L040/800<03@P5010;
200@2`P00P0>2@H04`0A2@L02P0000L0000A1`H06a4@01T?3P0?1@@040H500h40`0@1PD04@L60106
1@0?1PH03PP801H@400;1@D081XJ02`V9P0A2`/01P0>20P00`090`<0618B024K6`0201@>3P0400l9
2@0>20P03PP800l92@803PP800H03`L700h41@0e:b`0AC/l02DK700@1PL301882@0=0147200@1PL0
40H700H0000Q6a/030L706QRHP1=AdL030L7014;2`0@2PX03`T900d71`0200h820H04@L80P0@1PL2
014720804PP900H0;28S01T?400B20T040H701882@0:004601061`0<00h41@0E2``0308300h41@0F
30d0200000l51P0D2P/0D4I704<i>P0G3@h01`005?ooool001_ooooo1@0?3@h00`0@3Pl03`d>00l=
3P0200h<3@0F010>3`0A3a003P`=018@4@0A3a003P`=00d;300A3a00>cTj04a:B`0E4a@040h?01dK
700G5AH04a8@00`;2@0?3P`04Q4?00X91`0B4@l03`h<010?3@804A0>0P0>3@/0100=30X03`h<010?
3@0A40h2010?3@0300d<2P0>3@/03`h<00<040l=0P0>3@/00`0?3P`040l=010?3@02014@3P0300h=
2`0C4Q0051<A008040l=00H0:bXX030_;@0H5aD04a8@00l>300@3`d200h=2`0/01DD4P0I61H051<A
010?3@0?3`d04A4?01DE4`0820H04A4?06i^K00N7Q`03Ph<014A3`0820H05ADC018B3`0B4`h051D@
010A300=3PT03Pl:014B3@0<3@P09bPS01<D3`0F5a803Pl:010@2`0D4`l04A0<02l^:P0I61@03Pd9
03hm>@0Q81`04A0<00h=2@0B4@d03`h:01/J5P0N7AT061LC00h=2@0?3PX2014@3006010?2`0?3PX0
4A0<018A3@0@3`/04A0>0P0C4Q00100?3P`03@`:018A3`0C4Q02018A3`0A014@3P0B4@l04a8@01<=
3@0D3Ph0510?018A3`0@4@l03Q0=010B3`0@4@l03Pd;00h:2@0A30`05A4@01@C4@0A4@l00P0L71X0
2`0B4Q0051@B01<C4@0R8R003`l=01@D4P1EEE<05AHA00h?2@0@4@T04A8:00<04A8<02/05AHA01DF
4P0F5Q@05aLE01<C4@0?3`d07QhL01XJ600D51804Q8@014A3`0B4Q00410>00h>300C4a403`l=00d=
2`0C4a404A@?014C3`0?4@d05QPE00d>300Q8b406A/K01PI6`0:2`d05QLJ01<D600E5QP05QHC00h?
2P0C50l04A8=01@E400b<bh08B8M03Xk=P0E5Q404a@?01dN6@0=3PT05AHA008051D@00/04a@?018C
3P0A4Pd05aPC01DF4@0H6A@05AHA01TJ5@0E5Q805ALD00lA3P0201DG501600lA3P0J71T04aDB01DG
500O8Ah051HC018D4@0]<2d08bPT01<H500A5Q805Q/G01PM6@0C61@051TE01<H500E6QH05a`H01HK
5`0I7A/0:Bd/02@X9`0F6QT061`K01HJ6@0K7ah04ADD01DI600P92<05a/J01/O7P0H7Q/06b4N01PN
7P0G71l0724T01hS9P0S:2/061hN01`R7`0H7QX061lH01TP600K8Q/06b4M03Dk=`0C71T07RLT01/T
900N:2X082X/02</<P0N:C0072L^01lZ;`0R;Rh08RhZ028a:`0R<RP08c<Y02<e:P0Y>S40:S/c02Pk
=@0X>cT0:C`j02i0@@0]?d<0;d540353AP80<TA603<0<TA503=5A@0`@T80<49103=6A00hBdT0>Te<
03Y>CP0iCDh0@EAG04ULG`1:GF40@eIK045DFP1EJ6l0EfY`04IIH01:G6@0AEQN04aPIP1<HFL0BemV
04UMIP1:GVT0CF5/059VL@1BIVh0D6EZ04mTI`1CJ6T0F6e^05U^L@1OLgP0G6me05e`M01QLgL0Gg5e
05]]K`1OKW40HW5d06EeM@1WMGH0IWIf06YkNP1[OW`0KX5o07:5P`1gQhH0N8R707V9R01oSHd00P20
SXh08024T900QY6C08RCV029U9X0S9NM096KXP2FWjH0V:6X09VPZ02NY:`0XJN_0:N[]02]/KX0/[Fn
0;Bb`02j]lD0_;W70<6kb`35_m00blCE0<o7fP3CbMh0e<[O0=G;h03HcN@0gm;W0>CDj@3VeN/0k=[`
0?3Nm03ag_@0m>7g0P3ghoT08@3iho/0o>Gm0?kWo`3ojOl0o^Wo0?oXo`3ojOl0o^Wo0?oXo`3nj?h0
nnOm0?cUo03jiO/0n>Cj0?WRn@3ghOT0mmoi0?KOn@3dgOL0lM[d0>gIlP3/f?40jMK_0>GCj`3Rd^T0
hm?Z0>GFk03JcMl0fLcM0=G9f@3=`]00bl3>0<_2c`020<NobP0>0<Bmb031_<<0`;_20;jj`02c/kD0
/[>d0:j`[`2_/K00XZBR0:2UX@2LXYh0TYRC08R?R024SXD2086;P`0I07R2N@1dOWH0L7Ya071lL01d
P7@0N8Ah07F2N01aOWD0JGQc06UgM`1XMWP0Hg9e06]jO@1OLW40H7=_065dL01LKfP0FfmV05=WGP1G
Jf<0CV5K04mRH01DIVD0CemN04QGE00203Q5@@0>03Q6@@0^?3T0;C`i0391?P0nC4/0@e5A04UGE`0g
ADD0:cTi02di=P0Z=S80:SLa02Pd<@0X=30302lk=`0<02`h=@0Z=S<0;3Pd030l>00Z=S809c<_02Hb
;P0Y=C40:3@`02Lc;`0Z=S808bl[0`0O:bL01P0N:RH08R/V028[9P0Q:RD082TT024Z9@808b`W0140
<c`g04QAC00I8Qd07BHQ01hY9@0M:RX092l`01dX:@0R;Bd05b4Q02<];@0T;B`08bXX01hU8`0Q9b@0
9BXW02<Y9P0201lT800;020U8@0N8al07B8N01/P700P9B406b0L01dR7P1<DDd0;C8^01PK6@0K7A`0
0P0L7Qd05P0J71/061XI01LI600G6AP06A/J01`N7@0K7A`05QPG01HI600>4Q40;c4`01TK6P0=3`h0
:RXZ018B4P0F5QH05aDF01PF5`0M6a`06aLH01DC4P0G5Q@401DD4P0301PG5@0;2PP061LE008040l=
00D04a8@01@C4@0B4@l04A0>018A3`0201<B400J01PG5@0A40h04A0>01<B400<2`T03Pd;01DD4P0?
3P`03Pd;014@3P0?3P`04A0>01LF5016AD<04a8@00T81P0N7A/03`h;01TE4P1WI5l0LVi[00l;2@0@
30X04Ph=014=300C3`l201@@4@0501<?400A3@h04@d<010<2`0?2`X00P0A3@`03@0?2`X03@T800l;
2P0=2@P02`L600l;2P0G4a8030P801dJ6@1BCTd030T8018>3@0D40l00P0A3@`05@0?2`X03PX900h:
2@0>2PT04@`9018=2P0A30T040/8014<2@0C3P/040/8014<2@0B3@X04@`900h91P0=20D03`X600l:
1`0@2`P04@`9014;2`02018<300A018<3P0=20T0B494055;C@0H4Q804`h<018=2P0A30T03`X700h9
1P0=20D04@`900`7100=20D040/800h91P0:1@801P0>2@H500l:1`0701081P0X81l0OG=b020F5@0=
10<03@@401@:2@0501471P0701D=300B30`04@/;00`61P0?2@T050h>00d71`0600h8200600d71`0B
30`05@l?00`61P0;1@D030H60P0>20P0200?2@T03PP800h8200A2@X040H701<:2P0F3@d040H7100B
20T02@0A1`P040H701061`0F3@h02`D500l92@0@2PX03`T900h8200300l92@0300h8200=1`L03@L7
00H04@L80P0@1PL2014720804PP900D06a4B00l51P0B20T040H701<92P0701061`0<01882@0@1PL0
3`D600d3100=10D05`d>01<92P0G3Ph0H5IG05E;C00C2@X04@L85?ooool001_ooooo100>30d200l=
3P07018@4@0@3Pl03P`=00h<3@0@3Pl04@l@00h<3@02014?400:00l=3P0>30d03P`=00l=3P0@3Pl0
6QPI014?400I5aP03@/<00d<2P<03Pd;00<071/I00T81P0=30X00P0<2`T0200=30X03Pd;00l>300?
3P`03Pd;010?3@0B4@l040l=0P0>3@/00`0?3P`040l=010?3@0200l>300400h=2`0?3P`03`h<00l>
308040l=0P0;2PP07`0A40h03Pd;00`;2@0A40h0BdY801DD4P0?3P`03Pd;00L6100F5A<040l=00h=
2`0@3`d04Q4?010?3@0A4@l02PX8010@3P0F5Q@04Q8@02d]:`2EUI<0:BTW010@3P0F5Q@02PX801TI
5`0?3``03Pl:00d>2@0A4Pd00P0@4@`0600E5Q404a@?01HG4P0>3`X04Q<>00d>2@0C4`l051<?00/:
1`0G5Q801`H2010?2`0K6QH03Pd9018A3@0D4`l04a8>00d<200G5Q806APD01@C3`0=30P03`h:014@
30<040l;0`0?3PX00`0:2@L030/900l>300200l>300>014@3P0C4Q004Q4?018A3`0A40h04Q4?01@A
400C3@d050h>01<?3P0A40h03`l=00d?300@4Pl200l>300@01<?3P0F4A005A4@014@3P0@40h04a<A
018B400>3P`04Q8@00H6100D51800P8000/;2@0E5A<01`P300d>20803a080P0@4@/02@0?40X020T4
01TI5P0L71X01`L5018B400<30X051@B018B4002010@3P0N018B400C4a403`l=01lO7@0@40h06QXH
02DU8`0F5a803Q4:01XM5P0A50d010H301LI5P0D5Q<051HE010A4`0O82807AhP00H72`0:2`d05AHB
01DF4@0A4Pd0414<00/<1`0B4`h092DP01@E400<3@P04A8=0P0E5Q400`0B4`h04a@?01<D3`0201DF
4@0=01HG4P0E5Q40Gf1K04Y;AP0?40/09BHQ01TK5`0E5a@03a4>01TK600G6AH0418?01@F4`0201DG
5007014C400H6QL06A/H03Pk>00[<2`03a@@01HK5`0201TN6P0401LL600F6aL051TE01DJ5P805a`H
03006AdK028V9@0L81l05QXI01PL6`0F6QT05ATH00/?3P0/<2l0@TI502X^;@0E6AP061hJ01XP700H
7Q`061dP01`Q900M8RH06AhQ01hS9P0S:BL08BPQ01dT700P:1d09RdV02D[9`1=Ddl07bPU02/d<@0P
:2X07bT[01`U:P0N9bh08R`e02<]=P0T;SH08bl_02<_;@0S<R`093</02@d:P0T=RX0:CX`02/l<P0Z
?CL09cXh02Pj>P0^@4830312AP0>0312A00_@D<0;Cm103A6AP0cADD0=DM703U<BP0mD4h0?Dm?03U<
D00jCE80@UEI04YMH@1:GF8204=FG00H05=VK01dQhd0Gg9h045DF@18Ff40@EIK04YOI@1?HfX0CV9]
04iQKP1@Hg40E6Qc05AXL@1CJ6d0E6U/05I/J`1IKVl0Efa_05a`M@1EJ6h0EVU]061bMP1RM7P0H79d
0P1UM7L0201ZNWX0Kgen06alO01_P7l0L8>107:5P`1fRHL0Nh^:0P1lS8/0:@21Shl0PY2@08BBTP27
Ti<0RIBF08ZEVP2<Uid0SYVO09BMY02HXJP0VZ>Z09^RZP2SYk00YZZc0:^_^02`];d0];O00;Vfa02n
^/T0`;c;0<Bmc@39`]@0c/KH0=?:g@3Gbn40fLgS0=_?i@3Nd^X0i=G/0>WGk@3[fNl0kmgc0?;PmP3e
h_P0n>Cj0?_Uo03li_d0o^On0?oWo`3oj?l0o^[o00L0oN[o00T0o>Wo0?_XoP3jiod0nNKl0?WTo03j
h_`0nN;l0?OPnP3dgOL00P3`g?D03P3^f_<0jMO_0>CBjP3Rd>P0h=3V0=_<g`3Ic=d0eLSI0<o4dP3A
a]@0f/oM0<NobP38`</0a[k90P2m^;l02P34`LL0_Kfo0:V[ZP2RY:<0Z:ZW09NIUP2^/jl0YZfV096H
T@1iP7T2075kLP0a07Z4N`1cOG@0LWac07=mM01fPWH0N8Ah07N3N01dPGP0Lh1i06imN@1YMgP0IG=g
069aMP1VMGP0IgUi06=fLP1PLfl0GW5Z05M[HP1BIUd0BemG04ULEP12EE<0E6IV04=CD`0mC4T0=D4m
034m>@0_>cL0:cTe02`k>00[>SL0AUEC03i<C00iAdL0;C/l020^;P0_>cL0;S/c034n=`0^>c@0:CD`
02`h=00Z=S80:cLd02/g=@0`?3X0;c/i02@`;P0202Te<@809c<_00D0:SHb02di=@0T<2`07b/W01hZ
9P0201l[9`0H01hZ9P0U;RT09BhY028[9P0O:2<07RLR020Y900N9b80624L00lH4`0N9b806R<N01lZ
9P0S<34041/M02Lb=00O:b/06B<T01lY:P0Z<c80:2h/02`b<00O9B405a`H0P0Q9R801`0K81`06QlK
01dR7P0O92007R<O018G4`0>4`l00P0P9B401@0G71P06QdK01PJ6@0I6aX071hM00<07AlN02407R0O
01lQ800J71/05QPG01LI600H6aX04QHE020R8@0E5aH03@l>01lO7`0P82005aLG01@B4`0I5aP04a4B
010<3@0A3`h04Q4?01<B400F5A<061LE01DD4P0K6QP01@@201HE4`0>3@/040l=01DD4P0D4a404Q4?
00l>300@3`d00P0B4@l06P081`D02`X800l>30030P0030/9051?C@0L6aT04A0>00d<2P0B4@l03Pd;
014@3P0G5Q@03@`:018A3`0=30X051<A00P7100;1`@040d801hJ5`0A3@X01`<001@@3`0E4A00510@
0P0B3Pl0100D41405A4B01<?3P0A3@`2010<2`0>00l;2P0=2@P03PX901LC4P0I5A@05A4@00l;2P0=
2@P07a/J00h:2@0G4a807QXI00P5100?2`X2010<2`803PX90P0?2`X00`0@2`P04`h;014<2@0200h9
1P09010;200>2@H040/8018=2P0@2`P03@P500/60`0?2PH040/800804@`90P0@2PX01`0=20P04P`>
00`6200M61T07aTK00@0000@2`T00P0=20D0100>2@H03@P500/60`0>2@H200`7100300d81@0<1`@0
2`H300H040/800<04@`900h91P0>2@H00P0@2`P04`0@20H08QPG09J<R`0M4a803`D400L0000A1`H0
4PP701@:2@0B20L04@L601881`0E30`02P@400L10@0A2`/02`D500`61P0B30`01@0>20P00`0=1`L0
3PP800`61P0300d71`04010:2P0>20P03PP800l92@803PP800H02`@401@:2`0J41406@l@01X@4@0?
1@H301882@070147200@1PL040H701892P0A2`/03@L7010:2P0200l92@803PP800@03`T900h8200=
1`L030H61P0A1`P201061`804@L80P0B20T01P0?1@H0308301X@4@0C2@X04@L801882@H040H700`0
5@/<00l51P0L4Q<05`d>01<92P0e:b`03P@501061`0?1@H0:R0Q00T10@0A1`PDooooo`006oooool2
00l=3P@03P`=01X0518C018@4@0?3@h03P`=010>3`0A3a0040h?00l=3P0@3Pl04@l@00l=3P0<2P/0
2PP9014?40081PL0518C00D3100K6AX040l=01DD4P030P003@`:01<B400:2@L030/900h=2`803`h<
0P0>3@/01`0A40h03`h<010?3@0B4@l03`h<00d<2P0?3P`00`0@3`d200h=2`04010?3@0?3P`03`h<
00l>30803Pd;00<04a8@00P71@0?3P`00P0A40h01`0E5180;2/Y018A3`0920H040l=00T81P0D4a40
0P0@3`d2014@3P0S010?3@0E518030`:00l?3@092@L02PX800<30@0K6aT02@T701/K6@0H61H06QXH
01LG5@0=3@X03a0;00h?2P0A4Pd03Pl:00l@2`0F5a807AhI014B3@0B4`h02@X500/<1`0C4`h04A0<
00h=2@0C4Ph01`H201<B3P030P002@P401/J5P0E51000P0B4@d01P0920@02`X600T8100<2`L04Q4=
01<B3P<040l;00D03`h:00h=2@0>3@T04a8@014@3P0200l>3003010?3@0A40h04a8@00804Q4?00P0
4A0>018A3`0D4A005@l?01@>3P0C3`h040l=00l>30803Ph<01@04A0>01<B400D40l050l?01D?3`0@
3`d05ADC01<C4@0@40h04A4?00l?3@0E5A<02PX800P81P0O7ad03`l=014B3@0>3`T03a08010A2@80
4A8<00P0414;014B3@0?40`0410>018B400G5aD03`l=00h>30803`l=0280410>018B400B4Q005aLE
00X:20051@<0@T9003Xj>0000@0030l:00d@1`0G6Q4082<L01DG4P0:30L04aDB020R8@1eMgH0H65S
01TJ700O8B004a<@01<D3`0D5A006AXE00l@2`0D5A006a`G00<4000?40/04Q<>00l@2`0F5a804Q<>
0P0C50l201DF4@0@01HG4P0B4`h07AhI01PI50082@@05AHA00T:1P0D5Q<092HS03m1?P0];b`0418?
00h@3@0G6AH061XG01@F4`806Q`I00X06AdI01DJ5P0J7a/0724M01<H500H7AT06QlK01LL600E6QH0
5Q/G0P0H7AT02P0C61D04aLF01<G5P0M8B007b<R01XN7@0P92<06alN01dQ800T:2L201lS8P0U01TO
6`0H7QX06R0N01`Q900K82<0724U028W:`1<DE@0?dE301/R6`0F7AD06R8G01@K500F7AH0;38^01<L
6@0Q:RL07RHX020Z;00P:Bh07bP_028/=@0U;cP092lg02@`<00U<Bl093<]02Dd;@0V=R`09CL[02Pj
;P0[?380;3li02Pk>@0W>CT0;Cm20312AP020353A`0b0312AP0_@D@0;T1203A6B00eAdP0>4Y:03a?
C@0mD4h0>de=03e@E00nDEP0A5MM04QKH@16FEl0@EAJ03mBEP11E5P0@5=G045DF01>HV@0>diB049G
FP1;HVL0D6M]04eSKP1:H6`0Bf5^05=YM01CJW80E6a`05E]K`1FKfd0EVm/05Q]L01JKW@0KH26065d
N01FJ6`0HG=g061bM01VMGP0I7=f06YjNP1`OWl0KGem07>4P`1cQX@0MXV707V<RP1nSXd207n?SP0U
08BBTP25Ti<0QiFE08bHV02>VI/0SYVN092IX02BVj80Uj2W09bSZ`2MY:`0WjJ^0:N[]02Z[[L0[[:k
0;>g`02f^L80_[W80<>lc035_/h0al3@0<g4e`3Ab=`0eLcQ0=[>i03MdNP0gm?[0>?EkP3WfO00kM_a
0?7Om@3bgoD0m>7g0?SUn`3mj?l0o^So0?oXo`020?o[o`030?oZo`3ojol0o^co00D0o^co0P3mjol0
4P3lj_l0n^Sn0?[XoP3ki_h0o>Cn0?_So@3ihO/0mMkh0?CMm`3bgOH0l=ce0>_Il@3Ve>`0hm7Y0=o>
i@3Ib]d0f/gN0=O:f`80d<CB04H0elcJ0<c2c@3;`L`0a[k90<6l``30^l80`Kg30;2`/P2SYJ@0WInL
0:FWY02KWIX0]KZd0:>ZX`2=U8d0Mgif079lL`1aNg80NXAi07EoMP1dOWD0MGmf07J2MP1gPgL0MX9h
07N4N`1hQGh0LH1l06IdM@1TLWH0J7Ml06AcMP1`PX80I7Mc05a_J`1NLFX0DVIK04MKD01:GEH0I7Ma
04AGE@10DU80=DE50350?@0f@Sh0<3`h02`h=00/>CH0:STf02ln>`0kBTP0=4920392@@0X>3L0:CLg
02Ld;@0Y=Rd0;c`c02dj<@0U<RX09C8[02hj=P0`?3T0;SXh030l?00[=cL072PX02hj=`0b?SX0;c/g
0P0V<Rh0800Z=S80930/02<_:`0U<Bd09S8^02@`;00R;RX092dX02D^:@0S;2L082TT01lX8`0P:B@0
6B8M02Pa;00S;2L08R/V01lX8`0Q;2P06RHY028`<@0B8240;cXl06YdM@0jA4D06b@S00T?3@0D6QP0
:Rl[020U7`0C61807b@P0P0J7a/201hS7`0901lT800M8Qh06AhJ01hS7`0R9b<09BXV01LK600F61L0
61XI00806adL02<071hM01dO7P0L7Qd06A/J01DG5P0C5A@05QPG01PK6P0C5aH05ALF01PJ6@0A4a80
5aLG02HV9P0H61P0518C01TG60091`P04@d>01dK6P0E51804a8@01HE4`0H5aD05QDC01`K6@0;2PP0
5aHD018A3`0C4Q004Q4?01@C4@0B4@l03`h<010?3@02018A3`0J014@3P0D4a404a8@00T81P0];2X0
/[6_024P7P0C4Q003Pd;01<B400>3@/04A0>010?3@0J6AL051<A01LF500F5A<061LD01PD4@0E4Pd0
2@H401HB3`0I5A803`/:01<?3P0C3`l2018>3`804`l@00<04Ph=010<2`0?2`X00P0A3@`03@0>2PT0
2PH5024M700U8B005A4@00`81`0E4A006QHE00P5100>2PT03`/:01DA400;1`H00P0?2`X200h:2@80
40`;00d03`X700h91P0A30T05Q4>018=2P0910403PT6014<2@0C3P/04Pd:00h91P0<1`@040/700<0
4@`901403`T900h8200C3@d01P0201XD5P0?2@/0100001@>3P0A30X03PT600l:1`0B3@X040/800h9
1P0@2`P04@`9010;200200l:1`03010;200C3P/04`h;00@04`h;00<04Pd:00d81@0=20D00P0A30T0
4`0I4Q001`00028H5`0C2PT07A<B01471P0C2@P04PP701<9200A1`H03`D401471P0@20L030H600P2
0P0=1`L03PP800/51@0@2PX01@0>20P01`0;1@D03`T900/51@0;1@D03@L700X4100?2@T00P0>20P0
2@0?2@T03PP800h8200A2@X04@L800/10P0900003P@501H<3@0301882@090147200@1PL040H700H0
000F41002@@400d71`090`<04P`<00803@L700@03`T900h8200=1`L030H61P0A1`P201061`804@L8
0P0B20T01P0C2@X04@L801hD5@0E2``04PP901<92PH040H700`04`T:0147200J41405P`=01<92P0X
7Ql03@<401061`0700004@L800d41009000Dooooo`006oooool04P0@3Q806ALJ02HT9P0?3A404@lB
00`:300B41@06ALJ00h<3P0?3A403@/>018@4P0B414030X;01<A4P0@3Pl0518C00T720803`d>01P0
5Q@E00h<3@0@3Pl03@/<00h=3P0D4a@02`X;014@4P0:2@/051<E00d<3P0920X081lQ014@4P0<2`d0
2PP:014?3P0@3P`04@l=018@3P0@3P`03P`:014?3@0@3P`2014>3@0<00l<2`0>2`X04Q4?014@3P0=
30X03`h<010?3@0=30X07QdK010?3@0?3P`04Q4?0P0?3P`0;`0;2PP05QDC00d<2`0C4Q003Pd;00d<
2P0B4@l040l=01HE4`0C4Q002`X8014@3P0<30X05aLE00/;2@0?3`d05ADC010?3@0:2PP04A0>01LF
500E518030`:028S800I6QH03@d:014B3P0=3@X0=cLd028S7`0C4a003@d:014B3P0<30T051@A010@
300=30P04A0<01<B3P0=30P03`h:014@300I61@08R4M01<B3P0=30P051<?00<03`h:00H04Q4=01@C
3`0@3`/040l;018A3@0C4Ph200l>2P0801<B3P18B4D08b<P010@300E5A404Q8>010@3@0B4Pl2018B
3P0M014A3P0B4Ph04a8?01<?3@0D3`h04Pl=014@3@0@3``03`l<00/;200F5A804Q4>018@3@0A3@/0
50l=00l<2P0H5a@02@T8014?3@0C4Q4020L7010=3`0<2`X03Pd;01<@3`0?3@X051@?00h?2@0@4@`0
0P0C50h09P0B4Ph03a0<01HF4`0D514020P6010@3P0<30X04Q8@018A3`0D4a405A@B014@3P0C4a40
8B4O03Lg=@0B4a40:R/Y01dN700=3P/05ALC01@F4@0K7AP0F5YE01XK5`0>3``0:b`X018C400D5A80
;Rl^02LX9`0E5Q<03a0<01@E400?40/04Q<>01DF4@0@4@`051D@0P0C50l0100F5a804a@?018C3P0B
4`h201@F40804aD?0P0B50h201@F400I01HH4P0E5a405ALA01DH4`0=4Pl03aDB01DH5P0E5aD04Q@A
01PI5`0M71X07adK01PE4`0P7Q/08QlM01HF4`0D6AD05AXF01HK5`0E6QH05Q/G01LL600E6QH051TE
01DJ5P0201@I5@0@01HK600D6AL051TG01dR8P0G6ad04aLI01XN800H7Al09BX/02hc<P0L8B00724N
01PM6P0G71X0724P01lT9080724S07L06b0S03Ll?P0U;2`0620M024Y9@0O9b807RHP01`W800O:280
6R@M028/9P0R;2P08B/Y028];00R:bd08B``02@^=00T;SD08Rh`02<b<00W>3@0:CTd02Li<`0X>S80
9cX`02Xl<`0/?cL0:chh02/o>@0_@T00<4=403=6B00aADP0>4]?03]>DP0[?d@0;T1503U=DP0jCU80
>4]?03iAEP0iC5D0BE]Z04AGIP1:G6P0B5aU03mBF011EUL0@EIE03iCD@15FUT0@EIF03mDE@11EUL0
B65O04aSI01=HfP0CF=Z059WL01GK7L0E6Mb05IYL`1GJg40Ef]_05U]KP1KL6l0GG5c061cMP1jSI00
Kh:405a/L01RLg@0HgAe06imO`1WMWP0KGal07N3Q@1cPH80MHF707R9R`1iRX`0O8^>082>T@22T9<0
QY>F08NCU`27U9L0SINK096KX02DWZ<0U9jT09JOYP2HXJP0W:B/0::W/@2TZK<0YZVd0:n__02b/l00
][K30;Rha@2k^/L0`Ko=0<O2d@3:`m<0c/GF0=?8g@3GbN00f/_S0=k>i`3Sdnd0i]K`0>WHm03]foD0
l]of0?GRnP3fhoX0mnGk0?_YoP020?k/oP060?o]o`3ol?h0oo7n0?oaoP3olOl0o_;o1@3ol?l07`3o
kol0o^ko0?k]o`3mjoh0o>[m0?gYoP3ki_h0n^Gn0?[So@3hh?`0m]kj0?GMn@3bfoH0kmWd0>_Hl03X
eNh0i=;X0=c<gP3Ocn00flcL0=74d`3>`]00cl?@0<k4c`3:`</0a;c70<6la02o^/80^;Fl0:NWY`2U
Yj<00P2LWYX0BP2LWYT0Vj2J08^BRP23RX80MGac07=mL`1dOW@0N89h07N1N@1dOWL0MX5j079nMP1c
OgL0Mh=m07N4OP1fQH00KGaj06EdM01[NW/0Jg]l06IiN01ZOg`0IGUd05Y^J@1EJV<0C65I049EC`1J
KVP0UJRU05QZJ00mCTh0;3`j02Xf;`0hAC`0:cL_02/h<P0^>cL0<Sln030o?@0_?C`09C<b02Lg<`0R
<Rd09SLa020_:P0]>cH0:cTd030n>@0Y=c809C8_02dj=`0`?S/0;S`i02dj>00]>cT0;3Pg05QTH00c
?CT0=D4m02/f<P0S;BX0:CDa02Ha;@0U;b`09S8^02Pc;`0U;b/082XV02</9P0^=S00:S8/02<[9@0M
9Al082PR0P0N9R007@0R:R@07bLQ02<[9@0L9b<0<3m2014O8P0M;2d08Bl_034l>`0Q:bT0<c`i02@Z
9`0Q9b@07B4N01dP7P0P9B406R4L01/Q700L8Qd07B<N01dS7@0K8A`06AhI01dP700L7a/04QDA01`P
6`0I71X061/J00805aXI00@06QdL01TL6`0E61L05APG0P0F6AP201DH5`0I018F5@0G6aX08RDT03`o
?P0I71/05aXI01`N7@0?410061TH04M8A`0T9BD06a/K02XY:00D4a4071/I01HE4`0E51805QDC01<B
400=30X04a8@01@C4@0F5A<051<A01TF5@02014?3@803P`:01/04a0?01XH5P0@3P`05A8A010>300H
5A@08R0N02HT8@0I5Q@04@h<01<@3P0@3P/04a0>01PF4`0Y9b@04Pl=01LD4P0=2PP040d:00P40P0F
4Q004Ph<01dI5`091@<04Ph=00h:2@0A3@`00P0@30`0500B3Ph040`<014=300>2PT04Ph=01<?3P0A
3@`0510?01HB4@0B3Pd0510?01HB4@0<20L05a<B02LS8P0H51<03@T800H20@0C3`h02`L70P0>2PT0
4@0;1`H04@d<010<2`0A3@`04Ph;00d:1`0B3``071LD01PE4@0;2@D040`9014=2P0B3``04Pl;018=
2P0A3@X03PX600804@`900H03`/8010;2@0A30/06aHE01HA3`0C3Pd2014<300>00l:2P0C3@`04@/:
014<2@0C3P/04Pd:018=200C3PX050l;00l:200K5Q<03PT701D@3P0?2PP200d81P803`T800h03PT7
01LA400E3`h040X9018<2`0?2PP03`T70109200D2PX040P8014:2@0C2@T04PT900d61@804@P80380
2`@300l61P0@2@T05Q0@018<300=1`L04`d=00l92@0=1`L03PP800l92@0@2PX03`T900h8200?20P0
50`=01<92P0A20T040P900h41@0@1`P040P901482@0B2@X040P901482@0?1PL05@h>00l71`0M51D0
2P<401<;2`0?1PL03`P801482@0?1PL03PL701D<3@0A20T040P901892P0D2P/04P/;00l61`0C2@X0
3`L800d51@0A1`P04PX;01061`H04@L800X04PP900`3100B20T040H700h41@0C2@X04PP901061`0E
2``04PP90P0@1PL04P0D2P/03P@500d3100A1`P04PP90147200@1PH04@L701061P0>10@03`D50106
1P0G3@d03`D501D;2`0@1PH04@L700l51ACooooo000Kooooo`0901HD6@0D4QL05A<H01LE6P081P/0
4a4F010>4`0A3a@02PP=00804Q0E00T02`T<00d;300A3a005A<D00800@0@3Pl06ALH00h<3@0?3@h0
0P0@3Pl0400?3@h03P`=00d=400>3A804A0E00l>4`081``05QDJ00X93P0H5a`040lD00/:3`0>3A80
820R014=3@0A3@`2018>3@05014=300@30/03PX900h:2@0@30/00P0E4A002P0D40l020L5014@3P0C
4Q001@@3010?3@0W9R@04Q4?010?3@0>3@/2018A3`0300l>300@3`d040l=008040l=00D04A0>00d<
2P0J6AL04Q4?00D40P0200X91`0I018A3`0C4Q004a8@014@3P0C4Q003@`:014@3P0@3`d02`X8014@
3P0?3P`02PT7010?3@0@40h01PH400l?3@0[:bT0X:2N07EeL`0C4a40410>018B400=3@/02`/900/:
1`02014@3009010?2`0?3PX03`h:01@C3`0C4Ph040l;00h=2@0=30P02PT500803@`800<03`h:014@
300A40`00P0?3PX02`0C4Ph05aHB018A3@0@3`/04a8>01TJ5@0<3@P03a0;01<D3`0H6A@02``700H0
414<0P0>3@T01`0@3`/04A0<014@300A40`051<?01`K5`0@3`/00P0B4@d0500D4`l01`@001LC3`0M
6AH071PI018>400J5AT05A0D018=400A3@`04`l>018?2`0=30L04A4?01<C4@0D51804a<A010@3P0>
3P`0410>0P0?3`d05`0B4Q007AdK01TI5`0G4a805A8A01DD4P0C4Q0051@B024Q7`0j>SP03@l<01<E
4P0>40d04QLC014F4P0C4a<02PX:04i>CP0S8b<07QhL00d=2`0F5Q@051D@00804Q<>0P0B4`d01P0F
5a8051D@01DF4@0E5Q404a@?010A30804a@?0P0D5A000`0C50l04Q<>01<F3`0501<F3`0;01LJ4`0E
61405aXC01PK500G6Q<051TD01PQ7P1RJ6H06AhM01LK6P0S9B800P0H5aD01@0H514071DC01491`0B
20H06QLD00806b0L01L05a`H01@I5@0E6QH05Q/G018G4`0D6AD06AhJ01@I5@0B5a<05a`H01HL600D
6QP05Q`L01@I700D6Ad07B8V014F6P0K82<07R@T018H5P0S:BD06alN01dO7P0301`P7`0E01/Q8@0O
9BD082HV01hV:00K8bD06R8T01/S9@0L9b<072LQ03@o>00]>3007b/Q02@`9P0R;BD08bhV02@^;00U
;c009Bla02H`=00O;bl0838b008093Le03d09CPf02Xm>@0Z?CL0:Sdg02/o=P0/@3D0;D4f02i2>00d
B4L0;T=40315AP0hCE00>DiB02a1AP0dB4l0>dmH0396D@15FF@0@EEQ04MJJ`1CIGd0DF9j04ePL@16
FVD0?55E03]ACP0lDdd0@EQA03mEDP11EeD0AU]M04AIFP1?J6D0CfIS04iSI01@IFP0EFQ`05U[M@1U
Mh<0EFM`05Y[LP1PLGP0FVa_05AVJ01OLG40GW1`061bLP1TMWH0IWIf06EeM@1[Ng/0JGMh06mmOP1d
PX<0NHB607J1Q@1fQ8X0O8VA07f:TP1lRI40PXbE0080QY2I02T0RY>L08fFW`2@VJ80TY^T09>LY@2I
XZT0UYnV09jW[P2QZ;80XJF`0:NY]@2/ZkT0]K;30;Vfa`2m^LX0_[[;0;nkc034`]00bLGD0<g6eP3B
amX0fL[Q0=k;i@3QcNP0hlo[0>WDlP3/eoH0kM[h0?7Nn@3ehOX0mn?l0?[Wo@3ljoh0oNcn0?g^oP3m
ko`0oO3j0?kbn`3om?`0ooCj0?oeo0020?oeo@030?odo@3olod0oo7n0080oo7n0P3okol0;P3okOd0
o^cl0?k/oP3kj_d0nNKl0?[SoP3jhOh0nMkm0?OLn`3ef_T0lMWe0>kGl@3Zend0iMCV0=c9g03OcMd0
fLSH0<focP3<_/d0bko;0<k4c`3:`</0`;S30;^e_`2h/[`0/k6h0:FUX`2OXI`0W9jI09fOVP2NX9/0
WjBM08V@R031b<00[;BY06QbI`1/MV/0NXAj07n:Q01aO7P0MH1l07Z6PP1oRhL0NhN506mnN`1bPGh2
06alN`0c07F5Q01YO7X0HGIa05acK01TNgD0G75/05=XH`17G5L0?e9@04QKF@1HJfT0?4a;02dm?@0b
@C`0=dDh038n<@0L:1h09c8Z02hj=`0lB4P0<Cdm01HT8`0N;BP0:STd01l`9`0`@CT0>4I602Pf=`0c
@D80>TQ802<a<@0e@d<0;Sdj02dl>@0`?c`0;C`g02Xi=00e@Cd0>48o020Y9P0`>CH0:S<`01hW900L
9B8092dZ024Z9`0S;2T09Bh[02@]:P0O:2D08bXT0080VZ6J02X09bhW02/b:`0/<b`08bXS020W800O
9Ql082LP01lV7`0L9b<0YkNk04AFF00L;2`03ahM01dY9`0T;b/07bPS01HL600O9B408B<R01`N7@0R
9RD072@N018L500@61407RDN01lV7`0H7QL06AhH020R7@0S9B00828M02<U800M81h0720O01XN7@0L
81l082@S01/O7P0D61L05QXI01LK6P0F6QT201<G5P0F018F5@0A5A@0310?01DI600<40l04aLF04mC
DP0C5aH06AdL02@X9`0D61L06AdL00`=2`0B4@l08b8P014@3P061@<04Q4?01@C4@0B4@l03`h<014@
3P804Q4?00@01P8101HB4@0G4a803PX90P0H51<0800300004@d<01/G5P0300005A4@01LC4P0E4@h0
40`9018>2`0F4Pl0510=01<?300:1P<05Q8?01/G500@30T04Ph;01<?300P71/00`0001DA400B3Pd0
61@C01@@3`0F4Q405a<B00l;2P0=2@P03`/:00`81`0A3@`03PX90P0A3@`05@0>2PT04@d<00d9200E
4A00100001LC4P0J5QD04`l>024M700<20L00`0001/G5P0@30/05Q8A00`81`0@30/030P7010<2`0=
2@P04@d<00`;1`0200d<200700`;1`0>3@T040l;018A3@0@3`/03Pd900d<200200`;1`03018>2`0D
40d04`l<00804Ph;00@0510=01<?300A3@X03`/80`0>2PL0100A2`d040X:010;200?2PL200l:1004
00X5000L5a<06A@@02lY:@802P@601P04@/;00`61P0;1@D02`D500T30`080P8040X:01<=3@0;1@D0
3`T900`61P0=1`L03PP800`61P0D3Ph040X:00/51@0B30`0208200`61P0?2@T02@<300h8200=1`L2
00h8200300X4100;1@D03PP800803PP80`0@2PX01@0>20P040P901882@0B20T04@L8008040H700@0
4@L801882@0B20T04`T:0P0B20T03P0F3@h0AClo01LA4@0E3`l03@L700d8200=1`L03`T9010:2P0;
1@D030H601<=3@0@1PL04@L80P0B20T20147200400T0000?1@H050X;01882@8040H71P0A1`P01P0C
2@X040H701061`0=0`@05`d>01<92P8050X;00D04`T:0147200A1`P040H700T0000201@:2`0500T0
000?1`L0:b4R01061@0?1@@00P0>10<0200?1@@040H501H<2`0;0P804@L601881`0:0P4050X95?oo
ool001_ooooo00X02`T<010>4@0<2Pd0518E00d;3P0M6ah030X=01hL7`0Q7b8040hA0P0>30l0200;
2@X02@L800l=3P0<2P/03P`=00T7200>30d03`d>0P0@3Pl0400?3@h03P`=00X:300E5AL020P:00d=
3`0@41802PX<01/K7@1[Jfd02@T;010@4P0<30h00002014=3@0A3@`2018>3@0C014=300@30/03`/:
00l;2P0A3@`05A4@01HB4@0E4A006QTG01<B400J6AL05QDC03hm>`1`Kfd04Q4?014@3P0?3P`04Q4?
01<B400200l>30803Pd;02403`h<010?3@0@3`d03`h<00d<2P0B4@l06APF01LF500@3`d06QTG014@
3P0?3P`06QTG00d<2P0>3@/03`h<00h=2`0A40h03`h<018A3`0F5A<071`J014A3`0>3P`0000002LW
9@0L71X00`<100L71@0C4a403`l=01DE4`0D51400P0A40`00`0@3`/03`h:00l>2P02010?2`0400`;
1`0D4`l07QdI01DD40804A0<00h040l;00l>2P0?3PX03Pd900l>2P0D4`l061LC01@C3`0@3`/03`h:
00H70P0>3`X061TD00/<1`805QLB1P0@4@`200l>2P8040l;00D03`h:00h=2@0C4Ph05QDA00/:1P02
010?2`0=01<B3P0S8Qd03`h:01DD400D4Q<030X<00d;3P0@3Q403`d?00l>300<2`T05QD@00h=2002
01DE4`0T01<C4@0B4Q00410>00l?3@0A4@l030`:01LG5@0E5A<09bLU01`L6P0H51<04Pl>01@C4@0F
5A<04a8@014A3`0;2`T05QPE010B3`0;3@X041DA00@91@0A4A403`l?01DE5@0B4Q80820N00D50`0E
5A<04a@?018C3P0A4Pd04A8<018C3@0G61<05AHA0P0F5a80100D5A004A8=018C3P0D5A0201DF4@03
018C3P0A4Pd04A<>00D04A<>03/05QPC01@F4@0E5a805aTD01DG4P0A5Q4041TF06idLP0G71X07R8Q
02HX9@0D51806APF01XF4`0S7Q/07QTF02@L6@0Z9b@04aPD01TN6P0D6AD05Q/G01dR7P0G71P05AXF
01TN6P0N8al06AhJ01HK5`0G71P05adI01HL6P0G71d07B8U01`Q9@0K82@05Q/O01@I700H7Qh06R0N
01lU8@0P92<07b<R01`P7`0J7Qd06alN01dS8`0O9BD082HV01lW:@0J92D06B<T01/U9P0S;B`06RDO
03@o>00b?CD072LO024]8`0202Lb:P0502Lb;`0W<C809c4c02La=@0T=3@00P0R=3@00`0R=C<09CPf
02`o>`0202`o>@0f02a0=`0[?cH0:clf02/o=@0gBdX0;4520397B00gC4l0=DY>03Y?E00nDUT0@UIO
049FH@1XO8L0AeYW041CI01@HWX0EfV004ePL@17FfH0AEYN03Y@C@0lDdd0@EMC041FD`14FUP0CF9T
04iSIP1@JFH0D6QU055VI`1BIfX0EVYa05U[M@1MKgT0DF=/05UZL@1NKgH0F6Y]05IXJP1SMGD0Gg5a
05i`L01SMGD0J7Qh06UiN@1[Ng/0I79c07:0P@1_OGh0LGan07AoP`1iQXd0OX^C0P1oS9@09024SYL0
R9:K08NAVP2?V:40TibU09NNZ02EW:H0U9^U09BMY02EW:@0WjJ^0:FY]02TY[80ZJ^g0:n^_02h]LH0
_;W:0;nkc033_<h0`[k?0<K4dP3;amH0clSH0=C9g03Jbn80hm3Y0>KBk@3Xe>l0jmOc0>oKm`3`gOT0
mN7m0?STo@3hi_h0nnWo0?k]o`80o_3o00H0o_3m0?gan`3olo`0ooGm0?ofn`3omod20?ofoP1D0?oe
oP3om?h0oo?m0?ocoP3ol_l0oo7n0?o_oP3ok_h0ongm0?k]oP3kj_d0n^Om0?_To`3kh_l0n]on0?OL
n`3ef_T0lMWf0>oHlP3[f>h0iMCV0>3=h03Td^80gLcL0<k0c@3=_l`0cl??0<o5d03:`</0`;W10;Vd
^`2f/KP0/:jd0::RX02JW9L0Wj:K0::UWP2IW9D0XJJO08jES@32bL40YjnT06UcJ01dOW<0N89h07N2
O01fPGd0NhJ2075mN@1ePGd0MH5o06YiMP1_OW/0KWim0761P01dQ8@0IWQh05mcL@1OMG40HWQe05Y^
K01CIV<0?E1<04=FDP1@HEh0BEUF04iNF`0b@T00?di9049>@P0_>Rd082XQ02dg;`0_>CL0=T9002/g
=`0X=3<07bhY02<b;@0Y>C009SD^02hl?00/>S/0<Cm00P0gADD0<P0e@d<0@4m<02`k=`0Z>C@0;3/f
02dl=`0mBDD09S0]02Xc<00X<Bh07RLT02</:@0O:2D08R/X01dV8`0O:2D08b`Y02D^:`0R:bP0:Bl[
04mED@17CDT08bTU01lU8@0W;BT092XV01`R7P0K8Ad08BLS028X900M:2@0HW9f0391A00R<S807B/Z
01TU8`0E81`06R<N01dS7`0Q9b<0828Q01`M7`0M8B006R4M01<L5`0S:RH05adI01DK5`0H7AT051TE
0P0O8Ah201XL6@0601@F500H6QT06Q`K01hP7`0T9RD0828Q0`0I6aX06@0F61L04Q@C01<E500I6aX0
4aDD01`N7@0A4a806Q`K01lQ801gNGP05QPG018D4`0>40l030h=024S8P0I6QT040l=01@C4@0C4Q00
4A0>01PG5@0B4@l04A0>00l>300@3`d00P0A40h02P0L61L0510?00h:2@0I5A@03`/:00L30P0X92<0
AT91044m?00A3@`200l;2P0J018>2`0@30T0510=01@@3@0A3@X0510=010<2@0:1P<05a<@00/7100?
2`P061@A01`H5`0D40l03`/:00@0000A3@`03@T801/G5P0I5A@040`;00d9200>2PT02`L600l;2P0B
3Pd200l;2P0A014=300?2`X03@T8018>3@091@@03PX900H20P0=2@P0510?00h:2@0M6AP03`/:00H2
0P0F4Q404@d<01DA400B3Pd00P0@30/01`0D40l030/7010?2`0>3@T02PT500/:1P0B4@d00P0>3@T0
1@0?3PX04Q4=01@C3`0E51004`l<00<04Ph;00`03PX700/7100@30T030P500T50P0:1P<03@T600h:
1`0@2P`04@/;014<2@0@2`L200h90`0T00d80P0H4`l02PD101dG5`0<1PP03@L9014;2`0=1`L030H6
00d71`0<1PH02P@400d71`0@2PX02`D5010:2P0<1PH040X:00l92@0;1@D04@/;00T30`04000040X:
00T30`0=1`L03`T900/51@0?2@T030H600d71`0>20P030H600L10@090`<03PP80P0?2@T01@0@2PX0
3`T900l92@0@20T04PP900<04@L800<040H70147200A1`P00`0B20T03`0A1`P04PT:03hh>00E3`l0
3`T9014;2`0>2@T03`T9014;2`0B30`03@L700/51@0?2@T040H70147200201882@804@L800H050X;
01<92P0@1PL03P@501061`0F30d60147200600d3100C2@X03`D601882@0^92D08QPI0P0D2P/0300C
2@X04@L801061`0?1@H02@0001<92P0@1PL03@<403dc=024NW/040H500l510803P@300P03`D40106
1@0C2@P03`D4034W9P0_9B@0308201881aCooooo000Kooooo`0D024O8P0?3A005A<F00H41`0E4aH0
30X=00l=400D4aD07adP00d;3P0A3a803@/>01@B4`0@3Pl02`T:01LE5P0@3Pl0518C00h<3@0?3@h2
010>3`0@00l=3P0>30d0410B01lO8@1]KFl0=cLi00l?4@0A4A<07QhP06m_L@0T92H03@d?00/;3@0C
4a<04@d=014=30804Ph=01H04@d<010<2`0H51<0510?018>3@0C3`h04@d<00l;2P0C4Q0030/9018A
3`0@3`d03Pd;01DD4P0B4@l04a8@010?3@0B4@l04a8@01@C4@0F5A<04a8@0P0@3`d02`0A40h05A@B
00`;2@0C4Q0061LE00X91`0=30X04Q4?00`;2@0=30X04a8@00803@`:01<04A0>01LF500O7Q`05QDC
00X91`0J6AL071`J01TI5`092@L030`:014A3`0D51803Ph<010@3P0B4Q003Ph<01LG5@0J6QP03`l<
00804A0<00X040l;00l>2P0?3PX02`X6014@300>3@T04Q4=024P700I61@04A0<0P0B4@d03`0@3`/0
3`h:01<B3P0@3`/04Q4=01@C3`0B4@d04A0<018A3@0B4`h02@X5010A300A4Pd05QLB010A300600l@
2`804Q4=03D04a8>018A3@0@3`/03Pd900d<200B4@d03Pd901@C3`0A40`051<?00/;1P0@4@`04a@?
03@c=018B4X051@F01LF6@0?3a005AHC010?3@0@40/0414;01@D4P0B4Q00410>00l?3@0A4@l04Q8@
01DE4`0@40h02`/9014A3`0H61H04Q8@01DA400C4@l04Q4?01@C4@0B4@l03`l=010@3P0H6QL02@/9
014C400E6QH03a@@01PH600=3@d051@D00l?3`0B4Q005ADC014A3`02014B3@0?01<D3`0D5@l05AH@
01<D3`0B4`h051D@01LH4`0F5a8051D@01DF4@0C50l04Q<>01<D3`0D5A005AHA00H051HA01/05ALB
01<E400D5Q405ALB01@F4@0E6aL02a<@01LM6`0E6QP06AdL01HH5@0O81h0CTi<04E3?`0O71T08alL
01`E4P0T8al05a`H01DJ5P0L8Ad061dI01TN6P0F6aL051TE01DJ5P0H7AT00P0E6QH0300F6aL05adI
01DK6@0F71`08bP[020U:@0D6Ad07B8V01/P8`0J82007B<Q01HL60<07B4P01H07B8Q01lT8P0P9RH0
6R8Q01/T8`0M9RL072HW01dW:00P:R`08bh/01HR7P0P;2H08RhW020/8`0Q;B@0:cL_02Xf<00Z=C<0
:C@d02Pc=@0W<cH0:CTi0P0W>CT02P0Y?3X0:chl02i1?P0Z?CT0:chi02`o>@0/@3P0;D0i02e1>P0_
@d8203I;C00R03Q=D011EUX0@eQM049FG@0mDEX0@eMR05AXL`1IK7T0A5MV04=EJ`19Fg40CV5a04iR
K@1?HfP0D6IT045GE015FeL0A5YH04MLG@1BIf/0E6U/051YI`1CJFT0EFY]05I[L01HK780FFad05Q[
L`1dQXh0IgQo05EWJ`1IJfh0Gg5c061bLP80Gg5a0180HgEe06IfMP1VMWH0IgMg075oP01bP840NHN8
082;S@22SI40OhbB08BAV025TYT0QI6H08ZEW02>VJ00SYNO09BLY02GWjP209^RZ`0U09ZQZP2V[[D0
][_40:^`^@2Y[;L0[Znk0:VZ]P2d//00^kS90;jkc033_Ll0a[oA0<S1d`3:amD0d<[J0=?<g03Ic>00
g/oU0>ODk@3[eo40jmOb0>kJm@3bg_T0m>7l0?SUoP3jj?d0nnWn0?g]o`3nl?l0oo7o0?oco`3olod0
ooCn0?ogo`3on?h0ooWn0?oio`020?oho`040?ogo`3om_l0ooGo0?oeo`80oo?o0300oo7o0?o_oP3o
kol0onko0?g/o`3kj?h0o>Kn0?cSo`3kh?l0nMkm0?KKnP3bf_D0l=Wc0>_HkP3VeNL0iM;U0>SFiP3P
cmh0cl7>0<k0c@3AaM00bl7;0<Vob032^l<0^kJl0;B_]@2WYZX0V9RE09ZMU@2PXi/0WZ6I09NJTP2:
ShL0PhZ107j5O01YLFH0IW1U06UcJ01iPgT0NhJ007n:QP1iQ800PHf90::^ZP28U980K7]h06imNP1/
O7/206emO00g065cL`1TN7L0H7Ec05M/JP1>HV00Cf9O03]>BP18FUD0Cf1K04AECP15EE40:c/e030n
=P0h@cX0;SH/03<k<`0f?ST0;SDb02/d<P0L9RH092l]02Xf<P0U<2`0;c`f02lm=`0/>ST0<d5203e;
B`10CTh0>4M602ln?015E540;Sdi02He<00U=2l0;C`g04aHD`0]=c<0:c@a02L`;@0O:2D0:34^02L`
;@0^=c@092dZ028[:00S;2T092dZ024Z9`0L8Qh07R@P02<Y9@0R:2@09R`X01lU8@0201hT800j01lU
8@0R:2@09R`X02D^:`0V=3P03ahQ01l^;`0P;B`062<O02D`:`0S;2L07bDQ01TO6`0O8R8092DX020T
9@0G7a/08R/V01DM600C6AD06R0L01TN6P0H7AT08B<P01dO700K7AX07R0M01`N700S9B@0828Q01`N
7@0N81l06adL01PJ6@0I6aX061XI01HH5`0E5aH05aTH01DG5P0C5A@04Q@C01PJ6@0B51<04A<B034c
<P0F61L071hM01@F5@0N81l02`d<02DU900U92805aHD01TH5P0<2`T05QDC01<B40804Q4?0P0C4Q00
2`0B4@l03`/:01LC4P0B3Pd04@d<010=300F4Q4081`K01TE500D40l05A4@00804`l>0180510=014=
2P0?2`P03PX701<?300X9240EU9?01PD4@0B3P`0510=00h:1`0B3P/05a<B07EaL00M6AP05A4@00/7
1P0F4Q4201@@3`0?00h:2@0=2@P04Ph=014=300>2PT05A4@010<2`0A3@`06ADD01<?3P0@30/04@d=
010<2`0P71/0A40o00804Ph=01<05a<B069NG@0F4Q404`l?00T61@0D40l03PX9010<2`0:1PD04Ph=
014=300B4@d040l;00d<200<2`L03@`800h=2@0D4`l04a8>00804Q4=0P0C4Ph01`0B3P/04@d:01<?
300F4@h040`900/7100?2PL00P0>2@H01`0?2PL03`/8010<2@0>20X03`T900l:1`0?2PH00P0=2080
100A30H05A0<00L30@0=1`L200l92`0600l92@0=1`L040X:01H@400H4Q806A<C0P0>20P05@0=1`L0
4@/;00T30`0@2PX05Q0@00l92@0=1`L050h>00h8200@2PX03@L701@>3P0H4Q805@l?01<=3@0?2@T0
3PP800d71`0A2`/03PP800d71`0600l92@0301082@0A1`P04@L800D04@L80`0B20T03`0A1`P03`H7
01<=3@0;1@D04`d=00H10@0A2`/03PP8010:2P0B30`040X:00h8200=1`L040H70147200201882@80
4@L800H0CTA503D[;00E2``040H701882@0A1`P801061`040147200?1@H081HG01X@4@8040H70P0A
1`P0200B20T04`T:01061`0?1@H04PP9018:2P0A1`P050X;1P0?1@@01P0>10<04@P702@J6@0S6AP0
3`H500l511Cooooo000Kooooo`0=01HD5`0<2Pd030X=01PF6@0B41<0OWao02LU:00;2@`0108500H4
1`0@3Q403P`?00/92P0200h<3@0502XX:@0<2P/01`D600h<3@0?3@h00P0@3Pl03P0?3@h03P`=00/;
3@0k>cd0b/[<06i^L00>3Q001@D700X:300;2`d04A4C00X:300B4Q@07adN0P0A3@`2018>3@05014=
300@30/05Q8A014=300@30/00P0B3Pd02@0A3@`02@P701`K6@0F5A<05A@B01<B40061@<040l=01<B
400200l>3005014@3P0C4Q0051<A014@3P0>3@/00P0=30X07`0:2@L04A0>01<B400A40h06aXH01@C
4@0;2PP00@0001dL6P0g=S@04Q4?00d<2P0D4a404Q4?010?3@0A40h03@`:00l>300=3@/06a/I01lO
7@0G5aD04A4?00l?3@0E5A<05QHD014A3`0J6QP0CDe;04U9A`0H61D00P0A40`0400@3`/03`h:00l>
2P0<2`L04Q4=010?2`0:2@D03`h:00d<200<2`L03`h:014@300>3@T03@`8018A3@0A40`3010?2`08
018A3@0E51003a0;014B3@0B4`h07AhI03Lh<`0E5Q46010A300400h=2@0?3PX04Q4=01@C3`805QDA
01@040l;01DD400C4Ph05A@@00d<200E5Q406A`E014C3@0?4@`0FE]J08B6QP0@4A<0000200/=3@0C
5A806adJ00X=1`0<3`P0410>00l?3@803Ph<01h04A4?01<C4@0D518051@B00<30@0?3`d03Ph<018B
400@30/05A<A014@3P0?3P`04Q8@01@D4P0B4Q002P`900T;200N81d02a0<00`A3@0E5AD02@T900l?
3`0I6AT03@d;00l?3@0D51804Q<>014B3@0@4@`2010A2`0<01DF4@0C50l04a@?01@E400A4Pd03a0;
01DF4@0B4`h0414<014B3@0D5A005QLB1P0C5A00L@0E5a804aD@01@F4@0E5a8051HA010E4P0I7ad0
4QPF01TN7@0830/08bDR00h?3@0T92809B@P01XH500O6aP071TD02HV8P0M8Qh03Q<?01dR7P0K81`0
41DA01`Q7@0H7AT05Q/G01LL600D6AD05Q/G01/P700J81`05adK01DK6`0I7R405a`P01<H700K82@0
7b@W01LM7@0B61H05A/G01PL6`0I7A`07B4P01lU8`0P9R@08BLW01`U900N9bH07RPY01`V9`0K9BH0
7BLY01LS8`0L:2H09S8_01PT800J9b00934Y02Xg<00Y=Rl0:CDa02Pd=00W<c<09S<e02Lg=`0U=cL0
:3Xj02`o?@0]@3h0:Sdk02Pk>@0Y?3P0;3lk02m2?P0aA3h0<TI202e3@@0oE5D0=T]<03A9C010EET0
=T]@04EIH00oDe`0@eMR02m3CP1EJGD0@5=R04UKL@16F6d0CV5`04eQK017Ff00CfAU04EKF@18GU`0
AeaM04UNH@1AIVX0DFI[04mWJ@1CJF`0Efa_05Q]LP1IKG<0F6]b05]^M@1aPhT0FV]b051RIP1MKg80
DF=U0080GFm_03@0Gg5a06=eM@1TM7@0Hg=c07N7Q`1jR8T0NHN80:Jd]@2U/;80TIbN07n<TP24TIL0
QI:H08JAU`2:UI/0SYVO08nHW`2AV:00TiZR09NNYP2KXZX0W:>[0:R_]`30a<d0[;2i0:Z/^02h^<@0
/;2l0;Rfa02n^//0`Kg>0<Jod@39`]@0c<GG0=39f@3DcMd0elkO0=g?h`3SdNL0jMK]0>cHl@3]fO80
lMgh0?GQo03fi?h0n^Sn0?[/o@3kk?l0oNoo0?kbo`3olol0ooCo0P3omol01@3onOl0oo_o0?oko`3o
nol0oo[o0080ooWo00@0ooSo0?ogo`3om_l0ooGo0P3olol0;P3olOh0onoo0?o_o`3mk?l0o>Wo0?gW
o`3mi?l0o>7o0?WNo@3fg?T0l][f0?3Jl@3/fNd0i]GW0>;@h03SdN40f/[G0<k0c@3?`/`0cL7;0<Nm
aP36_<@0`K_00;Ze^`2b[K40Xj:R09NHTP2PXiX0WZ6H09RKTP2IW9<0PHMm07R0M@1eOG80J71U06af
J`1_NFh0NH=i07n:Q022SHT0Mh9n08NCS`2`_;P0T9bJ07F4P@1bPGh206alN`1P06YjNP1RM7@0HWAf
05]_L01CIfH0BEeL04mRG`19G5P0EVMQ055RFP1:Fe<0>4Pn03E5>`0f@cT0;cH^02T_9P0_=2d09b`V
02X`;@0[<Bl0?TA4028[:@0S;RX09S4]045<A`0e@3`0<Cdk04=AD@0_?Cd0=dE50391?`0d@d00:cXg
02dl=`0/>cH09SD`02He;`0d@CX082XV01TR7`0U;R/092dZ02D^:`0T;BX0=Chk02Tb;`0U;R/08R/X
01lX9@0K92408RPT01@J5P0M8al08bTU02dc;`0P9R808BLS02D[9`0T:RH07bDQ024W8`0R:bX062@W
01`Z:`0M:BT08Rh[01dX900I91h072DP01/Q7@0K8Al08bLX02@U:@0L824072@P01`U800c>SH092XV
01HL600D6QH04aPD01PJ5`0G6AH08bDR02X/:@0P8R008R@S01hP7`0G6AP06Q`K01`N7@0I6aX061XI
01TK6P0H6QT05aTH0P0I6aX04P0P8R402`d<01TK6P0C5A@08bDT014C4P092`X092HU01@F5@0F61L0
4aDD06a/J`2?SX`0:RTW01<B400G5Q@0<C0^014@3P8040l=0P0B4@l03@0?3P`05a<B00X61@0A3@`0
6aLF02HR8@0I5A@061@C020L6`0>2PT01`<201DA400C3`h00P0A3@X0@P0C3``04@d:010<2@0L61D0
;2PU01LC400D40d03PX701DA3P0C3``0:BDT01lK6P0E4A001000010<2`0;1`H04@d<01<?3P0>2PT0
3@T8010<2`0=2@P02`L600l;2P0>2PT040`;01DA400C3`h04@d<00d9200@30/081`K05MCDP091@@0
3PX9014=300J5QD0Ad=201LC4P0?2`X05A4@014=300L61L03PX901HB4@0?2`X03@`800X91@0<2`L0
4Q4=01@C3`0?3PX04Q4=010?2`0=30P02`X600X91@0<20D03`X7010;200B3@X050l<018=2P0@2`P0
3@P500l:1`8040/801803PT600d81@0<1PP030H600`7100>2@D03`X4010;1@0>2@<05a8>01<>2P0B
30`040X<00X41P0?2@T03@L700h8200C3@d201@>3P0B00`61P0;1@D03`T901H@400>20P03`T901PB
4P0F41003PP800l92@070@4020<300X4100B30`06A<C01hH600M5aL030H60P090`<0100;1@D04P`<
010:2P0>20P200l92@0500h8200?2@T03`T901082@0@1PL00`0A1`P00`0B20T04@L801061`030147
200401061`0@1`P040X:010:2P803@L700T040X:00d71`0>20P040X:014;2`0@2PX03`T901061`0A
1`P00P0B20T2014720801`0000@04`T:01H<3@0?1@H04`T:1P0?1@H01P0D2P/02P0101882@0;0@80
1`0000h41@803@<400H03`D60147200C2@X050X;01T?400>10D200T0000400/20P0A1`P03P@300l5
108040H500P03`D400h40`0<0P404PP700T0000<0P405P`;00d30QCooooo000Kooooo`0D00800@0A
3a004@l@01TG600F51D0SXb=02/Y:P0G5AH040h?01`J6`0H5QL0518C01`J6`0E4a@06QPI04a:B`0P
7Ql00`4200h<3@0?3@h2010>3`0>00l=3P0>30d040h?01HD5@0l>S/07A/L01@B4`0<2P/03@/<00l=
3P040P<04Q0A010>3`010002014=30804Ph=00H04@d<010<2`0C3`h03`/:00h:2@0B3Pd201<?3P0<
020O7@0S8R003@`:00L61@0D4a404A0>00h=2`0B4@l03Pd;00d<2P0@3`d03Pd;0P0=30X300`;2@0O
010?3@0F5A<02`X800/:20071P@020L501XI5`0>3@/07A`J03@c<@0I61H03@`:018A3`0:2@L020L5
014@3P0B4@l03`h<018A3`0?3P`030/900L6100?3P`040l=01<B400B4@l03@`:00T81P0T8b408B0N
00T81P02014@3005010?2`0?3PX03`h:00d<200>3@T00P0@3`/01`0B4@d04a8>00h=2@0C4Ph05QDA
014@300?3PX00P0A40`01@0@3`/04A0<018A3@0B4@d04A0<00803Pd900@02@P600L60P0O7QX03`h:
1P0A40`0100?3PX040l;018A3@0C4Ph201@C3`0B00h=2@0E51004Q4=018A3@0?3PX08B8M00<6000C
61802Pl900@81`0V:RX04ADF00D92P0P92@010T501@I5@0=4P`03a8;0P0B4Q02010@3P<04A4?01/0
51@B00`<2P0=3@/04A4?01@D4P0@30/05A<A014@3P0?3P`04Q4?00h>300H61H06adJ01lQ7P0e=c@0
4aPD018G4`0?3`l05QHF01<C4`0A4A403`l=01HF500D51804Q<>014B3@0@4@`00P0@4@/01P0F5a80
51D@01@E400E5Q404Q<>010A30H04a@?1P0A4a006`0E5a@04aDB01DG500F61D05ALD00dA3`0?5A<0
728P01DJ6@0<40l092HS01LH5P0H61H06AXE01`L5`0H5a<06APC01`M6@0Y;RX05AXF01<H500N8al0
41DA01lT800M8Qh06b0L01dR7P0201PM6@0<01`Q7@0H7QX05Q`J01LM7@0D6A`05AXN01LL800D6Ad0
8BHY024W9`0F71X05adI0`0J81h01P0K8Al07R@R01lX9`0L9B@07RLV01hX:@806bLW00L07BPZ030l
?00S;bd0930]01dY9@0K:2408RlX00809c@]02<09c<_02Lc<`0V<S809C8c02Li>@0U>CP09c/j02/o
?P0]@D00:Shm02Tm?00Z?S`0;40n02m3@@0aAT40=4Q603A:B00lDE80>4e>03I;CP0jCe<0=T]@049F
G@18G6D0Cf=^03eAG015FFD0>4]J04aNLP1>H7D0B5]Z04EHIP16FV40AU]N04=HF@0204QMGP0@04YO
HP1@IFX0CfAY04eUJ@1CJFh0Efaa05U^L`1HK780EfY`059UJ`1EIfh0Cf5U059TJ01MKg80FF]]061b
LP80GW1`00X0HWAd06IfMP1VMWH0JWYj06]iNP1cPH80Tj6R08ZEU`1iQ8H0PHbB0`27TYP0302<UI`0
SiRO092IX02CVZ80UIbT09^OZ02NXZ/0Wj>/0:2T[@2]/;T0ZJbe0:j^^P80^KO401P0_;S70<>lcP35
_]00bL3C0<k5f03@amX0dL[L0=O>h@3Kcn<0gm7U0>GCj@3[end0k]S_0>oLlP3dhOX0mnGm0?WWo`3k
jol0oNon0?g_o`3olol0ooCo0?oeo`3omol20?oho`030?oko`3ooOl0oogo0080oogo0680ooco0?ok
o`3on_l0ooWo0?oho`3omol0ooGo0?odo`3olol0oo7n0?o`o`3nkOl0oN[n0?kXo`3ni_l0o>;o0?WO
o03ggOX0l][f0?3Jl@3/fNd0imKX0>?Ah@3Rd=h0f/[G0=?6d03Dam40c/;;0<RnaP35_<40_[Rk0;Ja
]@2`[:d0Y:BR0:6RVP2QY9T0V9^@08b?Q028Rh00PhUo07b4N@1jPWL0KGEZ07V3NP1nR7l0NH=k07N2
O01mR8@0OXV5071lN01kQh<0NhN507>2O`1_OW/0K7ak06emO01YNGT0HWAd065cM@1MLG80Gg=b059T
I01=Ge`0CEeJ04QID`19FE80@E5703Y:?`0_?c@0;3T_02/b:P0Z;BH0:RlX020U7`0_=2l0:S0/02H/
:P0W;B/08R/X02H_;01PJFH0BEA@05EQG`22T900=dE503]:A`0fAD808S4^02Xi=00^?CP0:STb02Lf
;`0U=2d07R/T02H`;@0P:BH08R/X01hW90809c0]01`0;CHc02</:@0P:BH07RLT01/T8@0G81d07B<Q
024W9@0T:RP0;S@b01TO7@0Z<2h09B/Y028X9P0P9R@07bDS024W9@0Q:RT0:38e02D`<P0J92D07BPU
024Z9`0S;2L08BLS024W9@0S:BL08BDV0P0K7b80300M92<08R/X04aCD@0R:2H03aDC020U900N8R40
8R@S02<U900c=C@0>3Xi01lP7P805aLE00L05ADC01/K6@0N7Q`06QXH01TI5`0J6QP06ATG00805aLE
00<05QHD01PH5P0G5aD00P0>3P`03@0I6AL061PF01LG5@0G5aD0820N01DE4`0J6QP0RXV70:f/ZP0]
;2X05QDC01@C4@0G5Q@00P0A40h0400B4@l04a8@01<B400@3`d0100001/G5P0B3Ph061@C07UeM01B
CTd03PX9024M700C3`h03@T8010<2`0G4a8201DA3P0601PD4@0C3``030P500`81@0400002PH30P0?
2`P0400F4Pl0510=02/W9P0300005a<B014=300F4Q404`l>010<2`0D40l04@d<010<2`0A3@`030P7
010<2`0>2PT2014=300800l;2P0B3Pd040`;01<@3`0G4a803PX9010<2`0:1PD2014=2P0700<0000_
:bP02`L501LC400B3P/071PE02l[:00201HB3`803@T600D03`/8018>2`0D40d04`l<014=2P0300`8
1@0400l;200@30T04@d:00`710803PT600@03@P500h91P0?2PL040/81@0?2PL03@0>20X030H600`7
100?2PH050l901HA2`0A30H03PT5014<200=1`L04@/=010:300@2PX00P0=1`L02@0?2@T03PP800d7
1`0?2@T03PP801<=3@0J51@040X:018<300201<=3@0A00l92@0400003@L701`F5P0:10@03@L7010:
2P0J51@071HF00d71`0G4A406Q@D00`61P0?2@T040X:00d71`0@2PX00`0>20P01@0@2PX040P90106
1`0@1PL04@L800804PP900@04@L801061`0@1PL04@L80P0@1PL01P0=10D02`D5010:2P080P804`d=
018<30<03`T90P0@2PX00`0?2@T040H70147200201882@804@L800D050X;01T?400Y7b008QPI0106
1`0700l51P060147200900004`T:00l51P0<0P<05P`=0P0?1@H201061`804@L800P01`0000h41@0J
41406@l@01061`0=0`@03P@300l5108040H500P03`D400h40`0>10<05P`;01<9200J40l08ALF00h4
0aCooooo000Kooooo`0F010>3`0B414040h?018@4@0@3Pl05Q@E01XH6@0=2``04@l@02PV9`0Q7b00
40h?014?400>30d020L701/I6P0<2P/03`d>010>3`0?3@h03P`=00l=3P804@l@00<03P`=018@4@0?
3@h00P0A3a00200>30d03@/<01DC500;2@X03`d>00d;300>30d04Ph=0`0A3@`2018>3@0801DA400>
2PT03PX9010<2`0C3`h04Ph=00h=2`0F5A<3014@3P0=00D40P0?3P`04Q4?00l>300G5Q@08B0N018A
3`0;2PP06aXH01@C4@0?3P`040l=014@3P02018A3`0L01DD4P0<2`T0>STg055@CP0D4a403Pd;01<B
400B4@l03Pd;01<B400@3`d05aHD01DD4P0<2`T03`h<014@3P0?3P`051<A018A3`0?3P`03@`:01HE
4`0C4Q004Q4?014@3P0:2@L08B0N02PW90804Q4=00D04A0<010?2`0@3`/05A@@014@300200h=2@0;
00l>2P0D4`l04a8>01HE4@0H5a<06APD01XI5@0E510040l;00h=2@0C4Ph00P0A40`0200>3@T040l;
00d<200D4`l040l;00l>2P0C4Ph04A0<0P0@3`/00`0B4@d04a8>014@300201<B3P<051<?02404a8>
00h=2@0E51004Q4=01DD400D4`l09BHQ01<F3`0;40X051TC00`@3`0D61P041@E03Di>P1DF5P02@h:
00hC3`0>4`d03Q<<018B400F5Q@05ADC018B400A4@l030`:010@3P0A4@l04a<A00h>300C4a40410>
01@@3`0E4a400`0B4@l03P0<30X04a<A00h@3@0>40d04aDB00lD400B5a<051@D00h>3P0@410051@D
00/;2@0I6AL04Q8@0P0A4Pd00`0C50l04a@>01<D3P0201<D3`0601@E400H6A@06a`G01`M600B4`h0
4a@?0P0D5A0201<D3`0501DG500M7a`061XG03Pj=`0I6aP00P0C5A805`0B514061XG01LI5P0C5A80
61/I00lD4`0D6AL04AHD01PL6`0G6aL07B0M01TJ600G6A@05QLB01hN6P0Y:B@09bPT0497@`0]<Rh0
4aPD01dR7P0<4@d05Q/G00805a`H02/06QlK01TN6P0G71P05a`H01DK5`0E6aT05a`M01PM800L8BD0
8RL[01hS9`0G71l06AlO01@J600M8al07bDS01/Q7`0P9R@06b8P01LP7@0L9B@06b@S01`V9@0M:2P0
72PX01dY:@0P:bd0>4A602/h>00M:RX09C8`02<a;00X=S009C</02@b:`0W=3009c@d02Db<P0V<c@0
:cdm02Tm?00Z?Sh0;4100080:clo06<0:Shn02i2@P0`A4<0;d=30355A@0eBDT0>4e>03A9BP0kD540
?U=F03Y?D`0jCe@0?E5H045EGP11EF00?e=N045DH@1>HG00BEa^04ePL@16FFP0B5]Y04UMI@1:Gf@0
AU]O04MLG`17G600BEiS04eQI`1@IF/0CVEZ05E[L@1IKG<0FVme05IZL01IK740GG1e05Q[K`1LKW40
FVa_06=eN022U9H0HgEe061bLP1OLG40IGMg06emO@1_Ogl0NHV908BBT`2>W9d0SI^L08B?T@22SHl0
SYVM08RCV029U9T0S9JK08nGW@2BVZ00Ti^R09RNY@2JX:L0Wj>[0::V[P2SZ:l0[:nh0:b^]`2a/k`0
]KC00;Nd`P2l^LL0`kc<0<NodP3;`M@0clGH0=C8g03EbMd0e/_O0=[>hP3NdND0iMCZ0>[Gk@3_f_00
lmgc0?CQmP3ii_/0o>[o0?c[o`3mkol0o_?n0?odo`3omol0ooSo0?oio`3on_l0oo_o0?olo`3ooOl0
1@3oo_l01@3ooOl0ooco0?olo`3on_l0ooSo0080ooKo0140ooCo0?kcoP3olOl0onko0?k/o`3njOl0
o^Ko0?gSo`3lh_l0nMol0?CMmP3_fNh0j]O[0>CCi03Pc]h0g/cJ0=S8e@020=C7d@0D0<ZoaP37_/<0
`kZm0;Ze]02c[jd0[ZZX0:FUX02RXiX0VYj?08J9O@1/Kf<0JFeP08F;P02U[J80Ph^007InL`1lQWd0
MX1g07V3NP1lQh4207R3O`80LWij05H0M81n06akN01/NgP0K7ak06YjN@1/O7`0HG5a069dMP1QLgD0
Gg9d05=TI01:FeP0C5eG05=SG@12DTX0<T8g03Q7>P0T<bH0;3P/028W800V:280<S@^02db;00]<Rd0
;c@_02dc<00]<c40>Clm02H_;00d?C/0=Cln030l>P19F5H0=4=103e<B@0_?S/0<D0k03E4?`0b@C/0
9SD^01`/8`0V=Rd0934Z028/:@0`>CH0;SLd02D^:`0_>3D09Bh[024Z9`0P:BH05QlL01hW900O:2D0
5AhK02T_;@0J81h08BLU02D[:@0W;B/061hL01lU8`0W;B/07bDS02<Y9`0V;2X08RXY01dV:@0O:2X0
9Bh]024Z:00J8Ad08BPT01/Q7@0M8R407R<R01dQ8`0L7b@07b@X01/S8@0[=3406R4O01LM6`0L8R00
6AhL01HJ6@806Q`K00D08B<R028T8`0I6QP06QXH01`L6P0201XJ600501PH5P0G5aD061PF01TI5`0H
61H00`0F5Q@01`0I6AL0:2PV01PH5P0H61H051@B01<C4@0T92800P0B4Q002@0L71X03@d;020P7P0_
;R`04Q4?01TH5P0C4Q004A0>01@C4@0201<B40805QDC00L04Q4?01/G5P0:1PD061@C01DA400T81l0
?CTh00805A4@00H0510?01dI600A3@`05a<B010<2@0A3@X201<?3003010<2@0B3P/05Q8?00804Ph;
02L0510=01<?300B3P/040`;02`X9`0A3@`06QHE00`81`0@30/04@d<01DA400F4Q40510?014=300@
30/0510?010<2`0C3`h04Ph=00h:2@0A3@`030P701@@3`0?2`X04@d<018>3@0D40l040`9018?2`0D
4@d02`L400l<2@0G4`l02PH201LC3`0S7a/040`800h:1P0<2@H00P0F4@h08`0C3P/040/800l;200B
3P/040`900l;200B3@X040`900d91P0?2`P04@/8018<2@0A2`P040T7014:200B30T050h;01<<2P0A
2PP03`T6018;2@0C30X03`T;010:2P0810805Q4=04]6@01HDdd06aH@00X50`0E40`040X:01@>400=
1`T04@/;008040X:0P0?2@T01@0@2PX03`T900h8200>20P04P`<00803@L700L02P@400d71`0A2`/0
2@<302dW9`0m=cL03`T9008030H60P0C3@d01`0?2@T0:R@T02lY:@0A2`/03PP8018<300=1`L00P0k
=CD07@0@2PX03PP800h8200C2`/030<401@:2`0B20T04@L801L=3P0?1PL040H700l51P0C2@X05@/<
01@:2`0A20T02P@4014;2`0=1`L040X:014;2`0?2@T040X:018<300A2`/03`T900d71`0@1PL04@L8
00@04PP900X050X;00l51P0A1`P050X;01061`0B20T04@L801882@0@1PL03`D60P0@1PL00`0C2@X0
3P@501882@0201<92P0>01882@0D2P/03P@501/A4P0<0`@04PP900d3100D2P/03PD500h41@0@1PL0
4@L801882@0>10<401061@0700h40`0D2PT04@P700/20P0B20L06Q0?01471P0Dooooo`006oooool0
1P0L6Q/04@l@01HD5@0D4Q<03@/<00/92P803`d>00P03@/<00h<3@0@3Pl04Q0A01@B4`0@3Pl03@/<
00l=3P804Q0A00H040h?00h<3@0=2``03P`=014?400B414200l=3P0500d;300B41404a4B00h<3@0@
3Pl00P0?3@h200h<3@0300d;300C3`h04`l>00@04`l>01P030P802l[:P1fLW408alN00H20@0E4A00
51<A00L610020@003@`:01<B400A40h02@P702<R800L6aT0J6MU0<g<bP0C4Q008R4O00l>300@3`h0
1`H4055@CP05108300/:200=00X91`0@3`d06APF010?3@0?3P`040l=018A3`0C4Q005A@B010?3@0?
3P`02PT700`;2@0201@C4@0<014@3P0B4@l04Q4?00l>300>3@/051<A00l>300>3@/04a8@00P71@0J
6AL09RDR0P0A40`3010?2`804Q4=01<04A0<00h=2@0?3PX04a8>00d<200>3@T03@`8014@300G5Q80
4Q4=02<R7P0E51003`h:00`;1`0D4`l061LC010?2`0A40`04Q4=008040l;00@04a8>014@300@3`/0
3`h:0P0@3`/200h=2@0N00l>2P0@3`/04Q4=01<B3P0D4`l071/G01<B3P0510003@`8014@300I6QD0
3a8;00lD3@0?50h03a<B010D500A5AH00@D6020T900E6QH041DA00lD3@0:3@H05QHD00l?3@0J6QP0
5ADC01@D4P0E5A<04A4?0P0@40h01@0C4a404Q8@00h>300E4A00514@00804A0>0P0A4@l03@0@40h0
2@/8018D4@0E5a@01@X600H;1`051@D08B4Q01DE5@0;2`/0410>00h>300C4a400P0A4Pd0100C50l0
4Q<=014B300B4`h2014B3@0501@E400H6A@06AXE01LH4`0C50l00P0B4`h0800C50l051D@01<E4P0@
4Pl030h;03@f<`0>40d04A<@02@V8`0?4@h030h;018D4@0D5Q<04QDC00/?3P0B5QD061`K01TM700F
6aL051LD01HH5@0G6A@05QPC01LI500K7QL06alI02H[9`0J7a/04QLC01lT800G71P05Q/G0P0E6QH0
5@0H7AT06b0L01/P700F71P06AlK01`R800H7Ah061dP01`Q9@0C61`04AHJ01dR9@0H7Qh0728P03@j
=P0O9B<07R@R01`R800?61D07RLT01hX9`02020Z:@807b/[02h08Bd]028^<00Q;c807B/^01PV:00R
<30052<P01XY900L:b@07B`U024`:`0Y=cL0;C/k02`k>`0Z?3`0:Cdl02e1@P0^@T<0:Sho02a0@@0X
?3d0;T930396A`0bADT0>Da@03iAE@0`ADH0?U=D045FE`0kD5<0?55E04IKH010E5/0A5QQ04AHH`12
EV40AUYV04iQK`12EF@0@EAS049EH`1;GV`0BemY05M[LP1;GfH0B5aR0P19GF@05P1<H6L0EVYa06Ak
P`1OM7d0Ef]d05eaN01MLGL0HWEi05U/L01EJ6T0EfU[05AVJ01LKW00Nhf?065cL`1RM7@0HgEe06Uk
N`1aPH40M8B407F5Q@1nS8d208:@T@80PXf?01H0S9NK08B?T`29U9P0TibQ09:IW`2>UI/0UIbR09^P
YP2LXJL0WjBZ0:BY[`2XZk80[:bf0;2`^P2c/kd0^;K30;nkb@35_ld0a[k?0<c0e03?`mL0e<OK0P3G
b]h03`3Ic>00gM3T0>7Bi`3Yend0l=[a0?CNm03ghOH0mnCh0?_Yo@3mk?l0oNko0?gboP3nm?`0ooKo
0?oho`020?oko`<0oogo1`3oo_l20?omo`140?oko`3onOl0ooSo0?ogo`3omOh0o_Cm0?obo`3okol0
ongo0?oYo`3miOd0oN?n0?gSo`3lh_d0m]of0>oIkP3XeNP0h]7R0=g;f@3Jb=H0e/KB0=74cP3>`LX0
b;g20<>j_@2n]KH0]:n[0;2]Z02`[JH0Z:RQ09^MT028S7d0KW9S06mcI@1mPG<0Ri650:J^X`1lQ7T0
Mgmd07n9P01mQgh0NhEm07V4OP1mR8@0MX5m071lN01ePGd0Kg]i06akN01]O7T0L81o06YjN@1dQ8@0
IgMg05i`L01JK6`0Cf5Q04YJF@17Ee@0B5UC051OF014Dd/0;3`a02dj<00U<bH06RHJ02H[9@0o@C`2
02/`:P0L030e;`0V;BH0<SPd03<i=P0S;2T0<CXg03Ho?@0c?C`0>TI403Y9AP0kBTL0>TU603=2?@0_
?ST0;3/d02Lf;`0T<b`062PN02@d:P0T<BP082XW02hg=00_>3D0;CHc03Y3@00Z<c005QlL028[:080
72DR00<08R/X02</:@0R:2H00`0R:2H2020V900:02X`;P1>E580>3hl024W9@0F71X0:S0`020X:P0N
9bH07BHU01dV8`808BLS00d06b4M02<W:00O8b@08B@X01PK8P0K82@04a/I014J5`0F7Q/08BLU01hT
8P0F6aX061`K00806adL00T06Q`K01/M700J6aT061PF01XJ600K6aT06ATG01LG5@0F5Q@01@0E5A<3
01HF500?01LG5@0H61H061PF01PH5P0E5A<0410>00l?3@0=3@/03Ph<014@3P0E518040l=01PG5@0[
:RP071/I00803`h<00T04A0>01<B400B4@l03`h<01XF5@0E4A005Q8A014=300:1PD00P0F4Q403`0A
3@`04`l>01LC4P0E4A004`l>010<2@0B3P/04`l<014=2P0?2`P040`900<0000F4Pl04`l<00h:1`02
018>2`0<01lK6P0c;bh0510?01PD4`0>2PT03@T801HB4@0?2`X040`;014=300?2`X04@d<1P0@30/0
600A3@`040`;00h:2@0>2PT040`;014=2P0;1`@02PL200/80`0=2PD03``700h;1P0<2@@03``7010=
200?30L04Pl:01HC3P0F4@h04`h;00l:1`0>2@H040/8014<2@804Pd:00@06A@A01LB3`0B3@X050l<
1P0A2@L201<;2@10018:200@20H04PX801<;2@0=1`T07QPH014<2@0K5Q<0fmK@0?onn00S7QP050l;
01HA3@0C3@d0100000l92`0@2PX04P`<014;2`0=1`L03PP8010:2P0=1`L04@/;00T30`0X8R80=S0`
01/E5@0;1@D0208200l92@090`<03`T901PB4P0?2@T030H6010:2P0C3@d040X:00h8200K5AD07ALG
00d71`0?2@T04@/;00L20P0^:2P0:B<S00/51@0F41003`T900`4100P5QL02`4201892P0N51D0UH^<
01`B4`0?1@H03@<401<92P0H3Pl05P`=01892P8040X:0P0?2@T01`0>20P0208200`61P0B30`05Q0@
014;2`070@400P0@1PL2014720804PP90P0A1`P00`0B20T04@L80147200201061`0301<92P0@1PL0
3P@500<04@L800/03@<401<92P0L4Q<060h?0147200=0`@02P0104To@00Y7b003PD601@:2`060106
1`H03`D400H03@<201<9200?1@@0308101061@0B20LDooooo`006oooool01P0I61H020L500l>300;
2PP040l=018A3`803`h<0P0>3@/0200@3`d04A0>01LE5P0?3@h02`T:00l=3P0C4A804@l@0P0>30d2
00l=3P8040h?0P0B3Pd01@0A3@`05Q8A01LC4P0D40l04`l>00804Ph=0P0A3@`01`0@30/04Ph=01@@
3`0F4Q405A4@018>3@0A3@`00P0J5QD0201TH5l05a<B014=300I5A@04A0>00T81P0A40h09B@R0P0@
3`d04P0<2`T081lM02PW9@0c<S00HV5O01PG5@0<2`T020L5014@3P0I61H0T8n=01<B400F5A<04A0>
00l>300@3`d02PT700h=2`803`h<00X040l=014@3P0C4Q003@`:00/:200>3@/06aXH01`K6@0@3`d0
3``;0`0C3`h02@0A3@`040`;00h:2@0B3Pd05Q8A018>3@0?2`X04Ph=01@A3`02010?2`<03`h:00D0
3@`8010?2`0E51004a8>014@300200l>2P0=014@300>3@T03@`8014@300B4@d0;2/W01XI5@0?3PX0
3Pd901PG4`0K6QH040`9018>2`0201DA3P0301@@3@0F4Pl0510=0080510=0P0C3``00`0G4a003Pd9
00h=2@0200l>2P8040l;0180@T4m02`[9`0A40`04a8>00l>2P0?40/041<<010C3@0@4Pd04A<B014C
4`0A4Q@02``>00P92@0G6AH03@l<01@F400C5Pl201LG5@0<01`L6P0=3@/02PX801PH5P0B4Q004A4?
018B400C4a404Q8@010@3P0C3`h04Pl>0P0@3`d2014A3`0=01PH5P0A4a003a4>01DG500730P06QlK
00h>3P0h>3P0:b/[01LG5`0@40h06QXH01<C4@02014B3@0401<D3`0B4`d04A8<01<D3`D04Q<>00<0
6AXE01HG4P0C50l00P0B4`h0200C50l05QPF00/=300@4Q4061XI00`>3@0F61L02@X90P0G6AP00`0A
4a8030h=01<F5@0301@H5`0401<G5P0C61@04QLC01@I5@805Q/E02004QLA010E3P0F6aD06AhJ018G
4`0D6AD0724M01PM6@0E6QH05Q/G01@I5@0G71P06QlK01/P700G7AT06b4M020V900J82005a`O01PM
8@0J7b<07b@X02X_<P0J8200:2h/028X900L9B804Q/H030i=P0]=S<07RLT01XT8`806bLU03d072PX
01/Y:@0L:RX07R`]02@b=@0L:bh07Rd_02@d<`0O;b`0;Sli02@e;`0W>380:3Tc03=3@P0oCdh0>4U8
02Pl>`0W?3d0;45202i3A00[@440;dA702i3AP0`ADP0;dA70356B`0gC540=T]@03A9C00jCe00=4U:
03I;CP10EET0?55F045EG016FV<0Ae]V04IJI@18G6P0CF1^04ePK`1?HW40@eIT04QKJ@1;GfX0Cf=/
04]OJ019GFD0BemX04aPJ@1@I6`0FVig05=YM01MLWd0Ffmh05AXK`1CIf`0FVea05Y^K`1GJVX0G6i^
0080Ffe_03H0IWQj069dM01SMGD0IGMg06]mO@1cPh<0MHF507N7Q`1kRHX0OH^<07j<S@23SY00QI2B
08VBU`28TIH0RY>H09BMXP2GWZ@0TIRN09ZOY@2NXjT0WjBZ0:>V[@2XZk80Zjje0:f/]P2b/;/0]K>n
0;^ga@34_/`0b<;@0<Vod03>`]H0d/GI0=O9g@3Ib]l0f/_P0=c=i03RdnP0i]CZ0>WGk@3afo00mmoe
0?SRm`3ii_T0o>[m0?k]o`3mkol0o_?m0?ggn`3on?l0oo_o0?omoP3oo?l40?ono`H0oooo0P3oo_l0
103oo?l0oo[o0?ojo`3on?l20?gfoP050?oco`3okol0ongo0?oYo`3miOd00`3mhoh0C@3gh?P0l=[_
0>WFj@3Sd^<0g<[H0=W7e@3C`lh0cL3:0<^na`36^l00`KRi0;ng]@2c[Z/0[JZS0:j[XP2IVY40S8j0
07QlJ`1WJeX0NGe^08N;O021QgT0Ph]n07EmL01nQW/0OhV007j8O`1nR800NhJ007j9Q@1gPWh0L7ah
07B0O01]NGL0K7]h06]jM`1]OG`0IgMf06moOP1RLW80Ffe]05EWI@1>GUd0BUYG04EDD@10CdX0:CPa
034o=`0W=2X0:3D[02Tf:@0Q:b00;3</04E:A@0V:bD09BXS038i<@0S:R80<STb02li<P0J9B40<Sdi
03I0@00d?Sl0>DE303M6@P0d@ch0<T4l02ln>@0[>S<093</02Dd;00V=R`07blU02Lg;@0T<BP08B/W
0080:C8_00X09c0]02Xc<00K924082TV01XS800T;BX0:C8_02</:@0O:2D092XZ0P0S:BT3028X:00J
01dS8`0a=cL0;38b02H/;00K8B40;38b02@Y;00Q9bL07bDU01lU8P0P9R808BLS01`Q7@0W:b`07b<T
024U:@0C5Qd07B8X028Y:P0L9B@05QdM014G5`0K8B408BHV01PL7@0I6Q`201XK7@0701TJ700I6QP0
71/G01`K5`0M71P06QTE01PG4`0601LF4P<061LC0P0I61@03`0J6AD061LC01PG4`0=30P04Q4=01<B
3P0];2P061LD01HE4`0@3`d05A@B02<R800D4a403@`:00l>300201<B40804Q4?01d0510?01<?3P0A
3@`03`/:010<2`0C3`h0510?010<2`0B3Pd05A4@01<?3P0B3Pd040`9018>2`0D40d04@d:010<2@0A
3@X08AdJ01`H5@060`4081`I01HB3`0E4@h040`;014=30081@@0510?00l;2P0201PD4`0500l;2P0A
3@`0510?014=300>2PT01`0@30/03@0?2`X03PX900h:2@0?2`X040`900T50P0=2PD040d800l<1`0>
2`H03``700h;1P0B3`X00P0D4@`00`0E4Pd05a@?00l:1`02014<2@03010;200>2@H030L400803`X7
00@05A0=01@?300@2`P04@`91P0A2@L05@0B2PP04`/9018:200A2@L04`/901D=2`0D3Q002`D500@0
000H4`l0HEaF06aWH@0H4`d02`H200h91@0B30`0618D01@>400>20P03`T900h8200200`61P0D00h8
200A2`/03@L700@0000@2PX05@l?00d8200<1PH02082010:2P0?2@T02@<300/51@0>20P030H600l9
2@0B30`03`T900h8200?2@T200d71`0F014;2`0@2PX03PP800/51@0500003PP801@>3P0<1PH03@D6
00X00@0R61T03`D601T?400Q5aP03PD501061`0>10D04PP901D;300C2@X040L800h820803@L70P0<
1PH01P0H4Q804P`<00H10@0500002P@4014;2`8040H70`0A1`P01@0B20T03P@500l51P0@1PL04@L8
008040H700@03`D601882@0@1PL03P@50P0B20T0300@1PL03P@501D;300L4Q<05P`=00h41@0H3Pl0
4`T:01H<3@0700003P@501D;30H03`D61P0?1@@01P0;0@003`D400X0000:00004@L601@:2ACooooo
000Kooooo`0600`;2@0R8Al020L501<B400A40h061LE1P0?3P`0100>30d04@l@014?400?3@h200h<
3@0900d;300?3@h04@l@014?400?3@h03P`=018>3@0@30/04Ph=00805Q8A00<05A4@01<?3P0C3`h0
0P0B3Pd8014=300D00h:2@0H51<06QHE01TE500K5aH040`<00l>300=30X05aHD02TX9P081`D04a8@
01@C4@0<2`T01@@301<B400B4@l03`h<00/:2@0E518200l>300700h=300F5A<081lM01LF500=30X0
51<A010?3@0300l>300:010?3@0A40h04A0>010?3@0F5A<051<A02HU8`0Z:BL05A@B014?3@<04`l>
00H04@d<018>3@0D40l05Q8A01@@3`0B3Pd2014=3004014>300@3`/03`h:00l>2P803Pd900D030/7
010?2`0E510051<?014@3002010?2`0901<B3P0E510040l;00h=2@0@3`/05aHB010?2`0D4`l04A0<
008051<?00@04@d:01<?300F4Pl0510=0P0C3``01P0B3P/0510=01HB3`0E4@h05a<@020L6@<04Q4=
0`0A40`06@0E510051<?00`;1`0C4Ph040l;018A3@0C4`h04A8<010B3@0C4Q804Q8C010@4P0L6ad0
40l@00`=2P0E51804A8=01<D3P0<30X0>3Pf010@3`0E5A<06QXH00h>300B4Q00100C4a403P0B4Q00
510?018@3P0A40h04Q4?01<C4@0D51804a<A00T;200D5Q<0418?014F4P0;40`04A4A0P0D51@0100B
4Q803@d<01dM6`0C4a42014B3@0501<D3`0B4`d04A8<01DF4@0F5a800P0G61<0100D5A004a@?01LH
4`0F5a8401DF4@0A01<E500G6AP06A/J01DG5P0I6aX0418A02@V9@0H6QT05ALF01/M700C5A@04aHE
014E500@51<05ATH01<G5P0B5a<00P0E6QH05@0C6A<04QPB01@J4`0F71D06b4K01@I5@0F6aL06AhJ
01HK5`0J7a/06AhJ01LL600E6QH05Q/G01XO6`0K81`06R0L01TO6`0I7ad061dN01/P8`0201TN8P0;
01`Q9@0B5aX06R0P04eCD@0M8al04a`I01dV8`0i@Sl08R`Y020[9`0G8R400P0L:2H05P0L:BT072XZ
01h/;00P;S007Rdc02@c>@0N;C406BTY01d];00]?CT0834[02Pi<`0T=Bl08c<`02hn?00X>SP0:Sho
02Pm?P0/@D80;45302Tn@00^@dL20356BP0<0315B`0iCU@0@UIN03mCFP0gC4l0CF9S04=HF@0jCe80
@eQL04AIGP10E5/0AEUR0P18G6L0C@18FfP0BEaZ05AWM@1NLGl0Bei/04iQK`1@I740B5aX04]OJ`1:
GVP0Cf=]051TK@1DJ700GW9l069hQP1NLX00F6ag051TK@1JKW<0FFe^05IZJ@1LKfd0H79a061bL`1Q
Lg@0HWAf069dM01TMWH0J7Yj06eoO`1cPh<0MHF507V9R@1nS8d0Ohf>082>S`25T980R9>E08fFVP2B
W9l0SiRL096IW@2IWj@0VZ2U09fRY`2PY:X0XZJ/0:JY[`2[[[@0/;2h0;Bb_@2h]L00^[S30;njb036
_ld0b/;A0<k3e03BaMT0e/SM0=_<h@3Nc^<0glkT0>7Aj03[fNl0k=[`0>kIl03egO<0nnCi0?_Vn@3m
j?/0ongn0?o`o`3ol_l0ooGn0?ojnP3onoh0oogn00<0ookn1P3oool00`3oooh0oooo0?ooo`020?oo
o`0Q0?ono`3oo?l0oo[o0?oio`3nn?l0oOOn0?odoP3okol0ongo0?oYoP3miOd0oN?n0?cRo@3khO`0
mMke0>kIk03We>L0hM3P0=c:f03IamD0dL7<0<bob03:_L@0a[bo0<6i]`32^[L0][:[0:bYX02SX9H0
Nga`06e`GP1aMF<0N7eZ0080NGe]04L0NH1a07MoLP1mQGP0PXYo086;PP22S8<0NhEm07Z5P@1lQh<0
Mh9n07=oN`1dP7`0KGUg0760O@1]O7T0KGel06EeM01WMgL0Ff]Z05Y[J@1CI600Cf1I04mOF`18F540
?Te704=ABP0U<b/06RLN02<_9P0O:b807BLO028Y9@0T:bH09RlW02de;@0U;BD0;cX`02dh;`0/>300
E61J03@o?P0kAdH0?DY:03U8A@0iB4<0<3lj02`k=P0^?CL0:STb02Lf;P0W=bh08S8X02<c:@0T=2X0
82dT02H`:`0V;b`09Bh[02H_;00O:2D05QlL020Y9P0E7Q/082TV03Ho?00b>cP072DR02@Z:P0S:BT0
8RPX024W9`02028X:00O02H/;00O9BD09R`/01`R8P0b>3P09B/[02DZ;00S9BL07b@R01hT800P9B40
8BHR01lT8P0R9RL061`O01hR9`0G6R<092T_03Ho?`0F7ah07B@T01XP800E6a/061dN01HJ6`0E5QP0
6AXL01`M7`0K71h06QXI01/J5P0301`K5`806aXF1@0J6AD00`0I61@05aHB01LF4P0301LF4P0301@C
3`0I61@030/7008061LC00H0@D0l01DD4@0F5A<05aHD014@3P0@3`d2018A3`8051<A00L04A0>018A
3`0J6AL04@d<01XF5@0H51<040`;00805A4@01d0510?018>3@0D40l05Q8A018>3@0C3`h04@d:01<?
300E4@h04Ph;014=2P0B3P/0510=01TF500f<Rl0XIfJ05]GE00@30T04`l>010<2`0B3Pd05A4@024M
700X92<03`/:010<2`0D40l04Ph=00d9200<010<2`0>010<2@0?30L04Pl9010=1`0<2@<03@X4014>
200D4@/05A8<01HC3@0E4P`04Pl9010=200?2PL2014;2009014:200@2@L03PP500h71@0?2@H04P/9
018<2@0@2PL040T700L04PT70P0C2PP01@0B2@L050/901H>300?2@/03PP800803@P700P05a8<01<>
200U81X02PD100d8100B30`0C4I801H@4PH03PP800`030H600h8200G4A4030H6010:2P0I4a<04@/;
018<300:10@02`D5010:2P0A2`/200d71`0W00h8200@2PX03`T900l92@0<1PH02`D5014;2`0?2@T0
3PP801@>3P060@403PP801<=3@080P8040X:01@<3@0700004@P801<92P0B20T03@@501H=3@0A1`P0
40H70147200B20T04@L800l61`0>20P03`T9014;2`0B30`04`d=00X51@0A2`/04`d=00h92@0<1`L0
3`T900H04@L800X03`D601061`0B20T04PP901<92P0B20T040H701<92P0B20T040H70`0E2``02`0A
1`P04`T:01H<3@0B20T03`D601882@0D2P/040L8018:2P0B2@T07Q@E00H040H71P0?1@@01P0@1PD0
4@L700l61@0B20L05@/:00h40aCooooo000Kooooo`0700X91`0d<c402@P601PG5@0<2`T04A0>00l>
3003010?3@0E00l>300=30X02@L801LE5P0K6AX04a4B00d;300@3Pl03P`=010>3`0A3a0040h?00h<
3@0=2``04@d<00h:2@0B3Pd04`l>014=300B3Pd04`l>00804Ph=0P0A3@`0800@30/04@d<00h:2@0<
20L03@T8010<2`0A3@`06QHE00d9200:1PD040`;018>3@13?ch040l=00X91`071P@03`h<00T81P0H
5aD03@`;01<B400W9R@01PD400h=2`0;2PP07QdK018A3`0J6AP06QTG00/:200E51804a8@0`0B4@l0
0`0=30X03`h<00l>3003010?3@0;00l>300E518061LE00h=2`0@3`d05aHD01DD4P0E4a404`l>018>
3@0A3@`00P0B3Pd01`0E4A0040`;010<2`0I5A@04@d<00h:2@0B40d00P0@3`/300l>2P03010?2`0A
40`04Q4=008040l;0P0B4@d00`0C4Ph06APD01HE4@02010?2`0<00h=2@0<2`L051<?00/:1P0=30P0
5QDA018>2`0D40d05A4>014=2P0?2`P040`90P0D40d0100C3``04@d:014=2P0D40d6010?2`0S01TH
500K6QH04A0<014@300=30P051<?01DD3`0A40/040l;01<A4P0C4A<03P`?00400P0A3a400P4001dL
6P0?3PX040l:01<C4@25QH<0=cLe00l?3@061P@06a/I010@3P0B4Q004a<A018B400A4@l04Q8@01DA
400D4Q004Q4?01<B400C4a400P0D5180300D5Q<06A/H00T;2@0D6AD041DA01HF5P0B4Q806a/K01LG
5`1LG5X07AdK01<C4@804A8=00D04a@?018C3@0A4P`04Q<>01@E400201DF4@0301@E400C50l04a@?
008051D@0P0E5Q40:P0F5a803a4@01LI600;3@`05ALF01lQ800=3`h04A<B01HH5`0D5QD03a4@01DG
5P0U:2L061`K01DI600K7ah05ATH018G4`0D6AD051XF01DL5@0H7aP05ahG01<J4P0A5a4051TE01HK
5`0H7AT05AXF01LL600K81`05a`H01DJ5P0G71P06AhJ01XO6`0I7a/061hJ01DK6@0F6a`07B8U01`Q
9@806AhR00X092T/01LM7@0L8R0051XF01hW900M9R<05QlL00dH500Y=30072PV0P0M:BL05P0M:b/0
7R`/020^;P0S<C<07Rdd02Dc?00M;380<D1302Hf=@0T=3809SLa02ho>@0/?CL09cLd02dm>P0^@3h0
<4A502e2@`0_A4D0;dA702a1A00aAT/20397C01103=7CP0mDEX0Ae]T04IJHP0hCE00CfAU04YOH00n
DeH0?U=G049GG010E5/0@eMP04EII016FVD0AUYV04EHIP12EF<0D6=a04III`1;GV`0C5m]04AGI@1?
HW00Cf=_05AXL`1EJG@0F6ae065eP01IKgd0L8BD07:6T@1@I6d0E6Q/05EYJ01HK6/0H7Ab05e`KP1M
Kfl0I7Ig065cM@1TMWH0IgUi06]mO@1`PX80MHF507J6QP1hR8P0OXb=082>S`21Si00QI2B08JAT`28
TY@0TifO09VSY@2FWZ40UIZN09RMX@2OY:P0XjJ[0:FX[@2XZk00[K2e0;:c^02k^<<00P2n^lH05`32
_<X0ako>0<[2d@3Ba]L0elSM0=[;h03Ncn@0h]3V0>?Ai`3WeNd0k]_a0?3Ml`3cgO@0nN7g0?kVn`3o
j?`0on_l0?o_o`3ol_l0oo?o0?oho@3oo?/0oogl0080ookm00<0ooom0?oooP3oool00P3oool20?ko
o`030?kooP3nood0o_oo00<0oooo00@0ooko0?klo`3onol0oo[o0P3mn?h06`3om?l0onoo0?o]o`3o
jOh0oNGk0?gSo03jh?/0mmgf0?7Jl03ZeNP0hm3S0=g<g03Lb]P0fLOE0=?3cP3=`<T0bkk50<Jl_P33
^kT0^kB^0:bWX02RX9@0VIN:08>5MP1VJEH0KG9L07f2KP0208B8M`0l0827M`1iPG@0PXYm07^3N022
S8<0QY2707j8P01iQ800N8=o07N2OP1ePGd0M81l06ijN01[NWL0IGAa06QhM`1SLg80I7Ac05][JP1H
JF<0DV=J04mPF01?GUL0AeI?03a;A00S<2T0EfAL049?AP0R;BD07bXS024/9P0M9R<09c0/02H`:00]
=bl0:CDZ02Hd9`0_?380<Sle07>2N`0eA440=TA303U7A`0fAD80=dI102/j=@0X=c80;3/e02Lf;`0]
?C<0:SX`01h^900U=BX08S8W01l/8`0Y<bl09c0]02</:@0U;R/06B8O0P0K92401`0[=3407bPU020Y
9P0Y<Rl07BHS02@Z:P0Q9bL00P0P9RH0100Q9bL08RPX028X:00F71`202H/;00505EKF`0e>c/092DW
028T8`0Q8b800`0N8al04P0P92<0:2`_028V:@0I7R@07b</02<X;P1jPh<09Bh]014I600H7Qh0728R
01`Q8P0E6AX05QLI01PI6`0L7Al07AhP01/K6P806APD00@06aXF01`K5`0L6aL06QTE1P0G5Q8201HE
4@805A@@0P0D4`l02P0I61@040l;01<B3P0=30P08B0L00h=2P0@3`d02`X8018A3`0J6AL201@C4@0Y
018A3`0>3@/030/900l>300G5Q@04`l>01dI600J5QD03@T800h:2@0A3@`04`l>018>3@0F4Q405A4@
014=300D40l04Ph;01<?300E4@h04Ph;014=2P0B3P/02@D201DA3P0;1`@0?3Pe02XV8`0D40d02`L6
018>3@0<20L00`0000l;2P0A3Pd04Ph=014=300?2`X02PH501@@3`0/:2L01`0@30/4018>3@0?010<
2@0?30L03``500h;100?30D05A8;01/H4@0F4``04a09018?200A3PL03``500X7000D30X04`/90080
40P600P04PX801@<2P0@20H050`:018:200D30X05@d;018:20H04PP701h04`T801@:2@0C2@P04PP7
01@:2@0E3@/04``>00T30`0;1P<03`X700/6000?2P@03@P200l:1P0=20@02P@400l92`090`D040X:
00h8200?2@T04P`<014;2`0?2@T05a4A014;2`070@402P@400/51@080`<200`61P05014;2`0E3`l0
40X:00`61P0@2PX00P0?2@T400h82006010:2P0?2@T02P@400/51@0?2@T01@000P0=1`L02@0A2`/0
6Q@D0108200K4A805P`=00/10P0Q5aP040H700l51P0301882@804@L800@04@P9010:2P0?2@T03`T9
0`0>20P01@0@2PX020<300`61P0^:2P0O7If00804PP90`0A1`P00`0@1PL04@L80147200301<92P05
01882@0A1`P050X;01882@0A1`P00P0D2P/0300G3@h04PP90147200@1PL03P@501882@0E2``04PP9
00P0000;0@802P0101/A4PH04@L81P0?1@@01P0>10<09adL02<I600@1PD02P4101@:2ACooooo000K
ooooo`0400d<200I61@03@`800d<20<03`h:00/040l;014@300@3`/03Pd900`;2@0=2``05Q@E01TG
600C4A803P`=00l=3P03010>3`0:00l=3P0>30d03@/<01<?3@0?2PL050l<01<>2`0@2`P04Pd:01<>
2`804Pd:0P0A30T00`0@2`P03`/:00l;2P0500l;2P0800@0000F4Q405Q8A00T5100O6aX030/9014@
3P0?3P`2014@3P0=010?3@0A40h030/900<2000I61H030/900l>300B4@l03Pd;00d<2P081`D06APF
00H51002014@3P0801XI5`0G5Q@03Pd;014@3P0?3P`040l=014@3P0@3`d200h=2`0700`;2@0A40h0
40l=00d<2P0?3P`03`d;01<=3@02018<300901<=3@0D3Ph050h>014;2`0B30`05a4A018<300@2PX0
4@l<00804A0<100@3`/2018A3@0@010?2`0?3PX04Q4=01LF4P0D4`l061LC01LF4P0B4@d04a8>010?
2`0<2`L04Q4=00`;1`0>3@T051<?01<?30805A0=0P0B3@X0100D3``061<@01HA3P0D3``201<>2`03
010;200?3PX03`h:00@040l;01D020L300X91@061@403`h:014@300G5Q805a@?018>2P0A3@X05A4B
01D@4`0?2Ph04`hB01LB5@0>2PT05Q8A01<@300J6A@02`/902HV90092@L00P0E5A<010061P@03Ph<
018B400C4a42010@3P0=014A3`0F4Q40514@018A3`0A40h04Q4?014A3`0:2PP0418?00T;200J71T0
1@X601LL600200l?3`0501PH600@4100Bd]901@D4P0C4a400P0A4Pd0100C50l04Q<=014B300B4`h3
01<D3`03018C3P0A4Pd051D@00<051D@00l04a@?018C3P0C5A@05ALF00d?3P0G6AP06A/J01<E500D
5QD06A/J010B4@0<3Pd0<38a04a?CP0R9RD00P0E6AP02P0B5QD051TE01PN6P0F71P061lH01`U7@0J
91`051hE018H4P0N8al201HK5`0J01PM6@0?51005a`H01LL600F6aL061dI01XO6`0I7QX05a`H01/Q
7@0N92806R0P01/P8`0K82@05a`P01@I7@0N8bH06R0P00`B400Q9b<092dZ00lJ5P0I92008B`X01lZ
9P0J9R@201`X9P0^01/Y:@0M:b/07bd]024`<P0/>d80Gfef03M6C00V=CP08S8a02@d<P0R<bd08C8/
028c;@0U=C80:3Pe02Xk>P0_A4D0:d=302e5A@0^ATP0;4A6039:CP0cBU00=4]A03=:DP0fC5L0?59M
03Y@FP0nDeH0>4e>03Y?D010EEP0?U=G0356B`12EUd0@eMP04AHH`16FVD0AUYV04EHIP14F6<0BemZ
04=GHP17FVP0AEQW049EI080CV5_04<0DfMb05AXL`1EJG<0GW9m05=XN@1mTJ40R9bW05Y^M`1KKg@0
GW9a05mcLP1SMW@0GG1^06=eM@1^P840HWAf06MiN@1ZO7`0Kh6107B6QP1hR8P0NHV907^;R`20SXl0
PY2A08>ATP28TiD0RYFG09NPXP2>UYT0VZ:U09^SYP2FVil0VYnS0::WZ`2VZJh0Z:^`0:Z]/P2a/[L0
];Fj0;^h``31^lL0`[c80<Bnc03:`]40clCD0=C7f@3HbMh0g<gR0>;@iP3Td^P0iM?Y0>_Il@3^f_<0
lMgf0?OPn03khoT0o^Ol0?oZoP3okOh0oo7o0?oco`3om?l0ooWn0?omnP3oo_/0oool00@0ooom103n
ool09`3nooh0o_om0?koo@3nooh0o_oo0?ooo`3oo_l0oogo0?klo`3nn_l0o_Wo0?ghoP3om?l0onoo
0?o]o`3ojOh0oNGk0?gSo03jh?T0m]ce0?3Ik`3Ye>L0h/oR0=g<f`3Jb=H0elGC0=?3cP3>`LX0bkk5
0<Fj_@33^kT0]:fW0:JQVP2KVHd0SXao08>5MP1aM640LgQR07b1K00208>7MP1507V0L01fOW40OhMj
07InL`20RX40PXb407n9P@1kQX80NHB007R3O`1fPWh0LWij06ahMP1VMG80Gfi[06=cLP1NKVd0GVi^
05MWIP1EIUh0Cf5F04YKD@17Edd0?Ti403A4>P0iASl0OXZ406E`JP0a?3H07RTT01dX900O:RH0;STd
02@_9`0/=bl0;c`a02Dc9P0/>Rd0<d<h04EDC@0mC4T0<40n0351@00^?CX0<D0k02@c;P0R<BX09cH_
020_:00Y>Bl0:SX`01l_9@0[>c00:3P]02@a:00Y<bl09Rl/01lX9@0P:BH04Q/H01`U8P0T;BX0;CHc
020Y9P0K92407BHS01XS800U:b`08RLZ00808BHY01`08bP[02@Y;00[<3<06AhQ01hS9P0T:B`0;34d
018H600P8B80828Q024S8P0Q8b007B8N01`Q7@0M8B00>cm203Xn@@0H7B<08RH_01`P:@0S:bh07RHX
01hT9`0G71l05Q/N01TN8@0H71l06Q/O0P0I6Qh00`0L7B407AdL01/H4`0201/H4`8071TD00<06QLB
01PE400H5A000`0H5A0301TF4@0601PE400G50l05a@?01PE400G50l0514<0P0G50l03P0I5Q4061DC
01<B400<2`T04A0>01DD4P0?3P`04a8@014@3P0>3@/03`h<014@3P0B4@l03`/:0P0B3Pd00`0?2`X0
4@d<01@@3`02014=300L01DA400D40l03`/:01<?3P0B3P/0510=01DA3P0C3``04@d:018>2`0J5Q<0
6ADB01<?300;1`@05a<@018>2`0@30/061@C01<?3P0>2PT04`l>01PD4`0F4Q404`l>014=300?2`X0
61@C02/W9PH040`;00l03`/:014=300B3Pd04Ph=014=300?2`P040d800l<1@0A3PL05A8;01XG400L
6A80514:014>1`0>2`@00P0@3@H00`0=2P<04PX8018:200201491`08018:200C2`T03@D3018:200>
1P@04@T701<;2@0?1`D601881`8050X901D04`T801471P0C2@P04`/901<=3P0F41001P4001<>2P0K
5Q00IF1J00d81@0I51006aHB01H@400<1PP05a4C00l92@0=1`L03PP8018<300A2`/00`0?2@T01007
0@404`d=01LA4@0=1`L200X4100401H@400J51@04`d=010:2P804P`<00@040X:00d71`0=1`L03PP8
0P0A2`/200d71`0?00h8200@2PX03@L700l92@0>20P04P`<01D?3`0d;2`0Rh6200`20`0N51D01`00
01H<3@0D2P/04PP900804`T:00<04PP901<92P0A20T00`0=1`L200`61P0600L10@0A2`/04@/;00P2
0P0A2`/0>38b0`0B20T00`0A1`P040H701061`02014720804PP900T04@L801061`0A1`P04`T:0147
200>10D04PP90147200D2P/00`0A1`P0200>10D04PP900h41@0C2@X03P@501@:2`0L4Q<01`001P0@
1PL600l5100600/1000Q5aH07A<B00`20@0:0@404`T85?ooool001_ooooo00d05Q@D00/:2@0B4@h0
30/:010?3@0@3``04@l?014@3P0>3@X03P`<00l>300=30X04Q0>00@04@h>00<03``<01<@400C4100
0P0A3Ph03`0@3@d04@d<018>3@0?2`T04`l=018=2`0?2PP04Pd;01<>300@30X04Pd;01<?3@0?2`T0
510>010<2`0201<?3P0U01@@3`0B3Pd03`/:00l;2P0D40l040`;00h:2@0F4Q403`/:00d<2@0>2`T0
40d;01@?3`0L5QL030L701D?400H4a@01P8201TF5@0920H0518A00l<2`0=2PT030T801HC4P0?3@/0
40h<01<@3`081P@0518@00h<2P0C40l0514@01@B400C40l04Q0>014>3@02014?3@0U00h<2P0D4A00
4a4?010>300E4Q405A4@010>300B3@`0510?014>3@0C3Pd05Q8A014?3@0C3Pd03``;00h;2P0C3Ph0
5A4?01DC3`0B3``040d:014>2`0A3`/04Pl<018@300E4Pl04Q0<00l=2@0C40d040h:014>2`0E4Pl0
4Q0<00l=2@0F4a0040d:00h<200201@B3P0:01<A3@0@30T0510=01D@3@0E4@h050l<01<?300E4@h0
61<@01LB3`805a<@01h05Q4>01<>2`0@3`X04a<<00l>2@0@3`/04Q4<014A2P0E50l051<>018A2`0F
5A404A0;00d<1`0D4@h04@l<00l=2`0C40l05A<B010=3@0B3Q4040h=01TF5@0B3`h040h;018A3P0C
4Q003`h<018A3`0C4a42018A3`1;00l?3@0B4@l04Q8@014@3P0A4@l04a8@01<A4@0D4a803Ph=00l>
3@0B4a403Pl=010B400I71X05APF07MkN@0E6QL03a@A02TY:00@40l03Ph=014@3`0E518061LE01<C
4@0E5A404a<?01<C400D51404a<@01<D400F5a<04a<@018C3`0D51404a@@01LH500H61D04a@@01@E
4@0A4Ph04Q<>01DG4`0E5Q805QLC01LH5`0B4a4051DD01XK6P0=3Ph06AXI010A4@0D5AD07R0M01<G
4@0@50l05a/E018F4@0@5A005A/F01PN6P0M8b0072<P01HO6`0D7AT04aXF01/O7@0E6AL06QhL020U
8P0G6aT061`J01DI5`0G6aT06QlL00805AXG04<061dJ01`T7`0/=3408BPX01TO8P0E71l07bDZ01DK
800H7R<0728T01LN7P0M9B@06b@R01/U8P0N9bD0620M01PR7P0N:2H09S0^02@_;@0P;2d08Rd^02Db
=00[>3`0LH270<gLi01aPHP072``02Tj>`0W>3P0:3Th02Df=00U=SD0:S/i02`m?@0_@D00<DA302a1
?`0[@3l0;D5302m3A`0gBe00<dI>03U<E@0iC5H0>4]D03iBFP0oDU/0@5EG03Y?C`0nDe<0@5EG03iC
E`0oE5T0?e=J04AHHP14F6<0AeYW04ULJP10Df40Ae]U04AHH@1<H6X0B5aV04MKI@1@I6l0CF5[0080
Cf=]01<0D6A^05EYL@1HK7@0GWAm05M/L`1EJFl0CV9V05a`LP1FJFP0Gg9b061bL@1NL6l0IWMg06io
P01VMgP0JWal06eoO`1bQ8@0NHZ:0080OHb=02`0P8n@08>@T@24TI80Qi>E08^FV02>VI/0XJV/092H
V`2FWZ40WZJZ09RMXP2RYj`0YJV_0:JY/@2[[[H0/kBm0;Jf_`2g]l40_;W60<2kbP32_L`0b<7@0<g4
eP3Aa]P0e/WL0=_<h@3Ncn@0i=;X0>OEj`3Yend0l=[d0??Km03fgoH0nnCk0?gVn`3njod0ongn0?o`
o`3om?l0ooKo0?ogo`3oo?l0oool0?onoPD0ooon103oool01@3oooh0oool0?ooo03oood0ooon0080
oooo0600ooko0?omo`3oo?l0o_[o0?gio`3nmOl0onko0?o/o`3oj_l0o^Kn0?gSo@3jgoT0m=[c0?;J
k`3/e^H0i=7N0>3=f@3B`L`0e/O@0=?5b`38_<00ak^k0<:i]P2o^;80ZZJM0::OU02ASh<0OGa`07Ef
J027RGH0MGUT0823KP1dN6D0JVeK06ebHP1jOg00O8=e07ElL@1lPgX0NhAj07j7OP1nRHH0N8F407J3
PP1cP7l0KGaj06]iM`1XMg@0Hg=`06AdLP1PL6h0Ff]Y05=SG`1CHe/0BUYA04IFC@0gASd0=D<k03E1
>P10C4H0;cTd02D/:00U;BT0:2l/01`T7P0Q:B<0:c@]024/900c@3L0;S/c02Ph<00Z>c80=DI002Hg
<P0nCT/0=4=103M4@`0b?CP0>TDo02Te;@0U<2T0;SXb02D`:@0Q;B@0930W024/900S;bH0<Sdd02<^
9P0P:bH0:38^01lY9P0R:bP072DR02H_;00P9bD2028Y9`0W02<Z9`0/<Bl09bd[02D[:@0T:RT08RPW
01lU900S:BP09R`[01hT9@0T:R/08RLY020U9`0K82<082HV01hR8@0]<2l0=3Lf01lR800R9B<0720M
020S8P0g>SX0=cXl01hP8`0Q8bL061/O028V9`0E6A/05AXJ01LL6`0H6Qd06QdN01PK6`0M7R4061XK
01TK6`0M7R40>cXh00806ALC02@071XE01/I500M6aH06ALB01/I5@0H5Q8061HA01/I500H5Q806aLC
01XF4P0I5A<05Q@@01DE400T92409RHR01@D3`0C4a005a@A01XF4P0D3`d05A4>01<@3P0F51405A<@
010>2`0G51805Q@A01@B3`0=2`T0514?01LE4P0B40d0510>014=2`0B3P`201DA3`804Ph<01/04@d;
018>300B3P`040`:018>300@30T04`l<01DA3P0B3P/040`9018>2`0E4@h030P501HB3`0=2@H04@d:
010<2@0E4@l050l=014<2P0D40h03`/9014<2P0D40h040`:01<?3@0A3@/00P0C3`d0200A30X040`:
00l;2@0@2`T04@d;018=2`0A3@/04@`:0P0@30X01@0A30X04@d:00l;1`0A3@P04`l90080510<00H0
4`l:01<?2`0@30P03`/5010<200A3@T2014<2@0A00h71P0A2PT04P/:01<<2`0B2`X04@X9010:2@0@
2@P03PL600`61@0E3Pd04``;0148200>1`H050`;03`c<`0M5QD00P0C2PX0600A2PT040P80188200A
2@X04`d>010:2P0B30`04@/900/60`0@2`P06aHC00l:1`0?2PP030L701@>3`0;1@H040X:00`61P0=
1`L06Q@D00d71`0?2@T03@L7014;2`805@l?03L03`T9014:2P0?20P04@L801482@0<10D03@@501D=
3@0D3@d04PT:01082@0:10@03`D601492@0D30d07A@E00l61`0F3`l040L8018:2P0@20T04PT:0108
200=1PH04PP901hD5@0S6AX03PH60148200J414040H701071`0B20T05@/<01882@0H3Pl04`T:01<:
2`0A2`/04P`<014;2`0B30`04`d=010:2P0=20P05@l?00h820070P804Pd=01<92P0?1@H04@L801hD
5@0>10D03PD600@04@L80P0@1PL02P0>10D04@L80147200=0`@04@L801P>3`0B20T03`D60147200C
2@X201882@0601471`0;0`805@/;00`30`0?1PD060h>0P0@1PH0100>10@03@<300l51@0A1`L20106
1@803`D40P0A1`H01P0?1@D03@@301D;2P0>10<04@L600`20ACooooo000Kooooo`804Q0A00D03P`=
014?400<2P/03P`=00X82@02018@4@<03P`=00H04Ph=00l;2P0>2PT03`/:014=300@30/301<?3P<0
4Ph=00l04@d<00l;2P0B3Pd04@d<00l;2P0B3Pd040`;00`81`0:1PD03`/:00`81`0E4A004@d<01<?
3P0B3Pd00P0G4a807`0B3Pd04@d<018>3@0A3@`040`;018>3@0C3`h04A0<010<2@0A3@X05Ph?024F
6P0N4aL05`d@01@;3P0P6Q`030T901DD4P0<2PP0100000`81`0U8B0040`;00H20@0@30/04`l>00d9
200B3Pd03PX901DA400C3`h00P0D40l401<?3P0H01@@3`0E4A005A4@01<?3P0D40l04a4?00d<2P0>
3@/04Q4?014@3P0B4@l051<A01dL6P0920H03@`:028Q7`0A40h04@h<00/7100D40d071PE014=2P0=
2@H05Q8?0`0C3``03P0A3@X061@A01LC400J5Q<06ADB010<2@0>2PL05Q8?010<2@0A3@X0510=01DA
3P0C3``04@d:0P0C3``01`0B3P/040`9010<2@0?2`P04@d:018>2`0D40d00P0C3``0100D40`03`h9
01LG3`0?3`L201@D3003014A2@0B4PX04Q8:00804A4900P04108010?2P0B4@d03Pd;00d<2P0@3`d0
4a8@01@C4@@04Q4?00P04A0>010?3@0?3P`04A0>00l>300A40h05QDC018A3`804A0>0P0B4@l201<B
4004010@400B4Q804Q8B014C4P80418A00l05QXI00dA400g>cX0T9JD00hD4P0@51<04Q8A014@3P0Z
:BL09B@R00h=2`0<2`T051<A01PG5@0D4a400P0B4@l03@0A40h05ADC01TI5`0D51804Q8@01@D4P0B
4Q003Ph<01HF500J6QP05ADC01@D4P0S91l00P0D5A0201<D3`804Q8@00l05QHD01TI6@0?3`l07AdM
01@D500E5a804aH=01LJ4`0L7aP05aXC01<H4P0D6QD061hJ01hT8P0H81l00P0?61L01P0D6QT051PG
01DI600I7A`06alN01PL6`805a/J01l061`K01TM700E6AP05QXI01`R7`0>5a805QlL00hF5P0E7Al0
6b8X01hU;00H7bL08RT_01XQ9P0N9RT041PJ020U:00L8B@07B<S01lU8`0M8b407RLT024Z9`0R:bP0
8R`]02@]<P0W<3D09c<i02hmA01IJW40>DYA008093Hj06L08S@h02Dg>@0W>C/09cTk02Li>@0Y>c/0
;T0o051SH@18FeL0>Te<0353A@0`@TH0;d1803U:E00fAe40<45;03A5C@0lCED0?DmF03Q<C@0aAdD0
>4i<041EEP15FUh0AeaQ041DG@13Ef40AEUT04=FI018FfX0EFQf04QLI@18G6<0Cf=Z045EG019GF@0
DVI]051TJ`1CIfh0Cf=Z051TJ`1GJg80EFY_05U^K`1EJVT0E6QW05IZJ@1KKVd0G6i^05maL@1QLW80
Hg=c06EeM@1YN7T0K7Yk06emO@1^P800LXB407J6QP1iQhP0NXR908:@T@25T980Qi:D08ZEU`2=V9X0
SYRJ09RPX`2GWj80U9bO09ROY@2JWjD0XJJ/0:b_^02Y[;D0[[6j0;Ng``2e]L40/k>o0<2lc@32_/l0
a<3A0<_4eP3?a]T0d/KJ0=W<h03Ncn@0hM;W0>OEj`3[fNl0kmcb0?GLm`3igoP0nn?k0?kWo03mj_d0
o^gn0?gao`3nl_h0o_Ko0?oho`3onol0oogo00/0oooo00D0ooom0?oon`3ooo/0oool0?ooo@020?oo
o`1B0?kno`3ooOl0o__o0?gjo`3lnOl0o_Go0?o^o`3njol0o^Wo0?kVo`3lh_l0nMkh0??Jl03afN`0
jmGR0>3<e@3Kb=00c[o60=S9cP3CalT0aKVi0<Bk]P2m]Zd0ZZJJ09jJSP2GUHP0QhMk07moL`24Q7T0
RHYh06i`F`1mOfX0JVeJ061SD01cMVD0NWi_07YnL01hOW80NGmc07Z0M01jPWT0NHF30761P@1]OGd0
JWYi06EeM01WMgH0IgMd06AdL@1PL6d0FfaV05IWH@1AHU`0AeI?04=BB`10CdP09c@]03E1>`0oBT@0
?dQ302Ta;00N920092TU02/`;00P9Al0:2hT02`e:`0R;BD0;STc02hm>@0b@Sl0:3/i02e0?P0dAdD0
>DU603Q8A@0f@Sh0<c`g038i<P0W;RL09B`U02L^9`8082LP02809RdV020W800a>340HVUR03<m=@0G
8Ah05b8N020[9`0W<2d0;SLd02</:@0Q9bD082@S02<W9P0X;2/09b/Z01TN6P0S:B@08bTU020V8P0N
92007bDS028X9P0O9B<07B<S01hT900P9RH07b@W01dS8`0L8R40N7ak07f1P00R9RD05aTH0P0T9RD0
1`0V9RH092@T024Q8@0P82007alO02<U900I6aX00P0L7Qd201/M700>018D4`0H6QT05ALF01LI600H
6QT0O7aj02XY9@0<2`L051<?018A3@0S8Qh051<?01LF4P0E510201TH500I014@300E4Q004@/;010<
2`0B4@l07alM03m1?P0j?3T04A<@018B400E4a805a<B01H@400F4A00510=01<?300D40d04`l<01PD
4@0N6QL01@40014=2P0M6AH04Ph;00h:1`0200X60`0800d91P0B3P/05A4>01PD4@0E4@h04`l<018>
2`0C3``201@@3@0H018>2`0C3``05A4>01<?300A3@X04Ph;01HB3`0?2`P03@T6014=2P0C3``06QHC
018=2P0?2PL04@`901D@3@0B3@X04`h;01@?300@2`P04Pd:00`7100D3``04`h;0P0A30T01P0?2PL0
40/8018=2P0C3P/05A0=018=2P803`X700X04Pd:01D@3@0J5A805a8?01<>2`0B3@X03`X700X50P0C
3P/04Pd:0`0@2`P01`0A30T01@0001D?3`0;1@D050h>00P20P0=1`L00P0@2PX02@0I4a<07ALG00/5
1@0@2PX02P@401XD500F410040X:030Z:P0700l92@0K00X4100B30`03`T900T30`0D3Ph07QPH01`F
5P0@2PX03@L7014;2`0@2PX030H601@>3P0=1`L0618B03Tc<`0D3Ph02`D5014;2`0B30`03PP801<=
3@0A2`/04@T901H<3@0J41405P`=00803`D600<050X;00h41@0=0`@00P0D2P/0200M4a@081HG01X@
4@0R61T03P@500l51P0;0@803`D60P0B20T08P0A1`P040H701061`0@1PL06@l@01P>3`090@401`00
00P0000M4a@0308300d3100B20T01`0000P0000<0`@03`T900d71`0;1@D03PP800`61P0?2@T0618B
08EoO`0C3@d06aDE01<=3@0I3a004PP901T?4011=cP0;R@U01061`0C2@X201882@0=0147200@1PL0
40H701882@0C2@X04@L800`20`0>10D060h?01061`0?1@H040H70147200201882@0<01<9200>10<0
2@4000l5100=0`802P0001061@0C2@P05P`;01D;2P0C2@P04@L60P0@1PD02P0>10<03`D401471P0B
20L01`0001<9200700002P0001071`0K4A0Dooooo`006oooool03@0A3a004Q0A010>3`0A3a004Q0A
01<A4P0B41403P`=00d;300>30d040h?014?400A3@`00P0>2PT00`0?2`X040`;00l;2P03014=30<0
4Ph=01<04@d<00l;2P0B3Pd04@d<00l;2P0B3Pd04`l>01HB4@0A3@`05A4@018>3@0H51<04`l>018>
3@0@30/0510?01HB4@0B3Pd04@d<00804`l>01d04@d<010<2`0A3@`02`/6018A3`0I5A@08A/K01L>
4@0F3A004`X=01T@4`0N61X02`P9028P8@0F4a<02`L601TE500l>3L07ATH00d9200C3`h03@T801HB
4@0A3@`04Ph=00/71P0@30/04@d<018>3@0201@@3`0801<?3P0A3@`04`l>01@@3`0A3@`03PX9010<
2`0@3@`2010?3@0M00l>300C4Q0051<A00l>300G5Q@020L501PG5@0T8b402PT701DC400=2@H04@d:
01LC400A3@X09B4N01dI5P0F4Pl040`9018>2`0C3``06ADB01lK600N6QL05a<@00l;200>2PL04`l<
00l;200@30T00P0B3P/02@0A3@X040`901DA3P0C3``04@d:00l;200@30T04@d:01<?3003018>2`08
01<?300D4@d030/601@D300?3`L051@<014A2@0>3PH2018B2P804A4900P04108010?2P0C4Ph03Pd;
01LF500I61H04a8@01@C4@@04a8@100B4@l0100>3@/040l=01HE4`0C4Q02014@3P804Q4?0P0C4Q00
6P0B4Q80410@01@D500A4A403@h=01@F5@0=4A003a<B01dQ801>E5802Q0>00`@3`0C4a404Q4?028Q
7`0J6AL04Q4?01LF500I61H071/I01PG5@0D4a404a8@010?3@0F5Q@05aLE0P0E5A<02@0D51804A4?
01/K6@0A4@l0410>01DE4`0G5aD05aPC01HG4@0301LH4`0J01@D4P0C4a405ADC01hN7P0C4a<08B4Q
00h>3P0G61D051L@01LI500L7QT061XE01<H500D6QH05A/G01HL6P0B6QL03aPE014J5`0E71X05QXI
01DI600G6aX06AdL01LK6P0F6QT201TM700H01HJ6@0I7A`06AdL01`R7`0<5A004a`I028Z:P0W;c40
4QTO01PO9P0S:S806B0V01hU:P0L92L08BT[020U:00M8RD07R<U020V900N92807bPU020[9`0Q;2P0
92h_0P0V<CD01@0V<ST05B@[01h_=P0S=3/0;3i2008093Hj02H09cTk02Tk?@0[?Cl0:S`l02/m?@0^
@3l0B5]I049ED@0hBTT0<dE703=5B@0dADd0>4UC03E6D014EEl0Ffad05MXL00lCUD0@eMH03Q=C@0k
D540@eQK04EJGP13F5d0BUiW04IJI015FF@0?4mM049EH`1VNHL0AUYQ04aQIP17G640?eAI04iRJ01>
HVT0Cf=Z05=WK`80DVI_03h0EFUb059VK@1HKFh0EFYX05AXI`1FJVT0Ffi]05a^KP1OLG40HG9b06=c
L`1UMGD0JWUi06ajN`1^OWh0LX:207F5Q@1gQhL0NXR907^9RP24TY<0R9>E08ZEU`2=V9X0T9ZL096K
W@2FWZ40VZ:U09NOXP2PYJ/0][_10;Bi_`2/[kP0[[6j0;6d_@2j^/H0_;c80;ZjaP32_/l0a[oA0<W2
e03?a]T0e<SL0=G9g@3Kc^80hM;W0>CEjP3Zf>h0kmgc0??PmP3hgoX0nn7j0?gUo@3ojOl0onco0?o^
o`3mlOl0o_;n0?ofo`3onOl0oo_o0?ono`/0oooo00D0ooom0?oon`3ooo/0oool0?ooo@020?ono`1F
0?omo`3nnol0o__o0?cio`3mmol0ooCo0?o^o`3njol0o^Wo0?kVo`3lh_d0n=kh0??Jl03_enX0im7N
0=_7d03C`LP0cl370=G6b`3?`lD0a;Zi0<:i]02e[ZD0XIfA09jJSP2EThH0R8Ql08J6NP2:S800OWm]
071bG@1iO6L0I6MD06=VD`1fNVT0NGe^07YnL01jP7@0Nh5g07Z0MP1gOgH0MX:006inOP1[Ng/0IgMf
069bL@1SLg80JGUf06EeLP1MKVP0EfQR05AUG`1@HE/0@e9;03]9@P0gA3d09c@]03i:@`0h@cd0=d0k
02P`:`0J81`08RPT02`a;@0Q9R00:2lW02Pa9`0`>c<09C0Z02/j=P0c@d80?U5?03E8AP0cAT@0>TY7
03Q8A00_>cL0>D8m030g<00_=Rl0<CPa02`c;00X;bP09RdV01dT7@0P9b0202L^9`0>01/U7@0[=C80
5R4M01`W8`0K9240C5EB01LP7@0Y;bd09RXY020T8`0T:2L07R8Q01dR7P0U;2H3028X900V020V900N
92807bDS01lU9@0Q9bL08RPX020U:00M8b<09R`[034e=00`=3<07R8Q01LI600K7A`07b4P02@T900S
8b<0820P024Q8@0T92@06adL01XL6`0P8R407b4P020R8@0T9RD07AlN01lQ800P8R408R@S01lQ8020
P7h0<C0/01HE4@0P7a/08R4M03@c;`0F5A4201PG4`0F02<R7P0L6aL04Q4=01/H5P0M5aL07a/J01`K
6@0B4Q0061XG01/M6P0A4a004a<A01<A400D40l05Q0@01LB4@0B3P/04@d:01DA3P0C3``04Ph;014=
2P806QHC00<04@d:00l;200D40d00P0D40d0200E4@h061@A01dI5P0W8b005Q8?01@@3@0C3``0510=
0P0E4@h00`0C3``04Ph;018>2`02018>2`0700l;200B3P/03`/8010<2@0B3P/03@T600T50P0200l:
1`0401<>2`0B3@X03PT601<>2`804Pd:00@05A0=00d81@0C3P/05A0=0P0A30T2010;2004018=2P0C
3P/050l<018=2P803`X700D04Pd:01@?300E40d040/800l:1`0201<>2`0300d81@0B3@X04Pd:00@0
40/80P0?2@T04004000050h>01<=3@0D3Ph03`T9018<300H4Q809R0P018<300;1@D04P`<00L10@0A
2`/0<R`/02@N7P06000600l92@07018<300G4A4050h>014;2`0Q6a/0;bTY014;2`0200l92@0E010:
2P0>20P02`D500X51@090`<02P@401TC4`0:10@04@/;010:2P0E3`l02`D500`61P0?2@T040P801P>
3`0O5AH060h?00l51P0A1`P050X;00803@<400H04PP901061`0F30d060h?01<92P0D2P/201061`03
020F5`0@1PL04@L800804@L801P040H700l51P0?1@H0308301P>3`0G3@h0:AlP0147200G3@h02P01
00`20`0F30d0200002`R8`0C2P/040X:00h8200A2`/05Q0@018<30090`<0100006]UI@0;1@D200T3
0`0600L0000G3@h07Q@E01L=3P0=0`@040L80P0D2P/03@0C2@X040H700l51P0>10D050X;01882@0@
1PL03@<400h41@0@1PL03P@500l51P0A1`P00P0?1@H03P0A1`P0718A01/A400@20L0718A01071`0A
1`H0308100d30P0>10<040H500h40`09000040H50`0?1@@0200A1`H04PP701<9200?1@@04PP700T0
000H3Pd01`005?ooool001_ooooo00l03`d>00h<3@0?3@h02`T:01DC500A3a004a4B00d;300B4140
4@l@00/92P0A3a004`l>014=300@30/00P0B3Pd0100@30/03`/:010<2`0A3@`4018>3@0@010<2`0C
3`h04Ph=010<2`0C3`h03PX901@@3`0?2`X04Ph=00h:2@0B3Pd05A4@018>3@0=2@P04@d<01@@3`80
4@d<01T0510?01DA400B3Pd04@d<00l>300A4Q403@d<01DD4`0W8b<04Pd>01D@4@0B30h071LH00/8
2@0E51@04Q8C00h>3@0D40l05A4@01@@3`0H51<0510?00l;2P0C3`h0:bLV00806ADD00D03@T801XF
5@0D40l0510?01<?3P03018>3@0301<?3P0B3Pd04@d<00805A4@00@04a4?01/J600H5aD03@`:0P0B
4@l0500@3`d030/901`K6@0e=3805aHD00d<2P0D4Q00510=01hJ600B3P/05A4>03hj>00P71T061@A
018>2`0C3``04@d:018>2`0H51405A4>100B3P/401<?300:018>2`0A3@X061@A01HB3`0C3``04Ph;
01<?300F4Pl06aLD01PD4@80510=00P05A4>01@@3@0B4@`05QD?00l?200F5@l04Q4;01<C30804Q8;
0P0A4@X01P0@40T040l:018A3@0?3P`08B0N02<R80804Q4?0P0C4Q02014@3P04018A3`0C4Q006APF
01HE4`803`h<00@04a8@010?3@0A40h04A0>0P0B4@l201<B400D00h=3@0C4Q804A4A018B4P0D5AD0
3a4@018D4`0H71/03a<B00lD4P0D6AL05APG00l?3@0M71X06QTG01<B400J6AL04A0>01DD4P0G5Q@2
01DD4P0301@C4@0?3P`04a<A008051@B0`0E5A<0500D51805ADC01DE4`0D51806a/I018C3P0E5Q00
5aPC01TJ5@0H6A@05ADC01@D4P0J6QP03`l?01XJ6P0A4A407alO01`M700K7AT06A/I0P0I6aP201HK
5`0801HL600E6aL05AdH01HO6@0E7QX061hL01/O7P0I7A`201PL6`806AdL01h07b<R024U900M8B00
8bLV024U900K8Ah0624L01dV8`0b>cX0BE5C02H]<`0M92/05A`T02@[<@1AFEd07BDX01`T9P0Q9RT0
7R<V020U:00Q:2P07bHU020Y9P0S;R/082XY028/;@0S;S808bhd02Hb>P0V=C`202Df?@1301la=@0Z
?400:3Xn02Xl?P0/?T00;d5302i0@00]?cl0;d5002m2@00]@3`0;Cln0394AP0hBTh0?DiF03U:E00f
Ae40CEiX06AeO@1GJ700>TaC04]NH@0mDU<0?eAE04IKGP15FUh0@UML045EG016FV<0AEUS04EHI@1J
KG/0M8RC04YNI016Feh0BEiR04mTJ01AIV/0BemU04iRJ@1AIFd0EFUb05EYL`1DJ780DFE/05M/K@1E
JVP0EFUX05Q/J`1LKfl0GFm_061bLP1RLg<0IGEe06MgM`1/Ng`0Kgen07F5Q@1cPh<0N8R808>BT`25
Ti@0PHn@08NDU@29U9H0RiJH08nIV`0209:LWP0T09JNX@2PYZX0WJBW0:>X[P30a</0/kNn0:^^]`2`
/[/0[[2i0;Via@2n_LX0^;K30<>od037`=80blCF0=78f`3Fb]h0f<cP0=c?h`3RdnP0i]K[0>_Ik`3a
goD0m^7h0?WPn`3mho`0o^Kn0?oZo`3okOl0onoo0?kbo`3olol0ooOo0?ojo`3oo?l0ooko2`3oool0
1@3oood0oook0?ooo03oood0ooon0080ooko02<0ooco0?oko`3nnOl0oOKo0?ceo`3nlol0onko0?k[
o`3njOl0oNGn0?[PnP3efo@0lMS^0>_Di@3Rc]X0fLSB0=71b03?`<H0c/750<Rl_@2o]K<0^[6/0:RQ
V02FTXH0V9B809:BQ02OWi80Wj2C09>ER01hNVL0LgIQ079eH@1[KU`0MGQV07UmKP0207f2M00]07^1
M@1jPGH0NH1f07R0N01dPh00KWin06]kNP1XN7L0Hg=b06EeL`1VMW<0Hg=`05a]I`1FIf40CUmI04MH
D@16EDh0=T@m038o>00^>S<0@dm902D`:P0]=S40:30/01`T7`0[<Bd0:2dY01hT7@0[<RX0:34X04QC
B`0b?cP0<T8o02/k>P10De40=4M502dn?@0`@3d0<d4m038n=`0/=C00=C`e02/b:`0W;RL0:C0Y0080
8bXS00H09B`U01lV7`0/<b`0;SD^01hX800Q:bP201hY9@0>02@]:P1mQX<0?4E202dc<@0]<C007B4P
01hR8@0P92<0<cPd028Y8`0N92008BLS02L]:@0T:RP201lU8`0h020V9P0S:BT09B/[028W:P0O9BD0
7B<R02@X9`0Q9B@092PW01DG5P0R92<07b4P01/K6`0O7al0820P01lO7`0Q8B406adL01dO7P0N81l0
6Q`K01dO7P0R92<06A/J01HH5`0J71/07AlN01HH5`0h>CH071/G01PG4`0E510061LC01hM6@0E5140
61LC01@C3`0R8Ad061LC00l>2P0H5A<05Q0@01LC4P0H5aD04Q8@014C400C5A804Q@A01<C4@0A3`h0
4@d<01LA4@0G4Q405Q8?01`H5@0N6QL201@@3@0600l;200H51404`l=01<?300@30T061@A0P0D40d0
0`0B3P/03`/8010<2@0201DA3P0301<?300B3P/04`l<0080510=01405A4>01<?300D40d061@A01XF
4`0F4Pl04`l<014=2P0@30T04Ph;01XF4`0h=3406QDB01D@3@0D3``05A0=01<>2`02018=2P0601TD
4@0O6QL050l<01<>2`0@2`P03`X70`0@2`P2014<2@0;01<>2`0A30T03`X700l:1`0A30T04`h;010;
200A30T040/800l:1`0@2`P00P0B3@X00`0A30T040/800l:1`02010;2003010:2P0D3Ph0BdE50080
3PP800H03@L7010:2P0?2@T03`T901@>3P0;1@D4014;2`0300l92@0B30`04@/;00L03`T900H02`D5
00`61P0@2PX040X:00h8200=1`L2010:2P0300h8200=1`L03PP8008040X:01003PP8018<300;1@D0
3`T900d71`0B30`040X:014;2`0@2PX03@D60147200B20T04@L801061`0B20T04`T:0P0@1PL0800A
1`P03@<400h41@0C2@X03`D600/10P0E2``04PP9034W:00F30d050X;01882@0@1PL04@L801<92P0F
30d02`8301T?400N51D0AS`m01L=3P0@1PL05@/<01L=3P0D2P/060h?0557B00C2P/03`T900d71`0C
3@d06Q@D0P0E3`l02`0X8R804@/;01LA4@0K5AD03@L701061`0E2``05P`=01D;300Q5aP050X;00H0
4@L800h040H700h41@0>10D04`T:01@:2`0@1PL03P@50147200C2@X03P@500d3100A1`P030820106
1@804PP700T050/:00d30P0F30/04@L600d30P0>10<04@L601881`0?1@@00P0@1PD301471P0600d3
0`0>1@D06Q0?03P`;`10=SD0BCln5?ooool001_ooooo00l040h?00l=3P0F51D03@/<02@R8`0M6a`0
30X;014?400B4140108301hL7@1WIFH04`l>018>3@0C3`h00P0D40l4014=30@04Ph=018040`;01<?
3P0B3Pd040`;01<?3P0I5A@04@d<010<2`0E4A00510?01lK6P0C3`h04Ph=010<2`0G4a8071PG01XF
5@0A3@`201@@3`804`l>00h04Q0A00/=3`0=3Q00410@00`;300>2P/07a/L01TF5`0<2P/03@d=01lP
7`2k_l00?3`l01TE50805Q8A0P0H51<201@@3`09028N7@0E4A0040`;010<2`0L61L061@C01@@3`0A
3@`040`;00804Ph=01<04`l>014=300>2PT05Q8A01@@3`0E4a407QdK01TH5P0@3`d03`h<00h=2`07
1PD04Q4?00P71@0<2`T04Q4?00D40P0:20H040`9008061@A00T081`I01TE4P0D40d040`901<?300F
4Pl04`l<018>2`0C3``00P0B3P/00`0C3``04Ph;010<2@0201HB3`0F01DA3P0D40d04`l<01<?300D
40d04`l<018>2`0A3@X04Ph;01@@3@0E4@h04Ph;010<2@0D40d05Q8?01<?300A40/04a8=00l>2@0F
5A003`h901<B3@804Q4<0P0A40/2010?2P0<01PG5@0>3@/04A0>01<B400@3`d05QDC018A3`0A40h0
3`h<010?3@0B4@l051<A0P0B4@l0100>3@/040l=01HE4`0C4Q02014@3P804Q4?0P0C4Q008@0I5aP0
5A@E01HF5P0P82007QhN00L9200?4A0000@301HJ6@093@`03A4@00d?3P0E5A<04Q4?02LV900F5A<0
5aHD02HU8`0D4a405A@B01<B400I61H06aXH01LF500G5aD05QHD01DE4`0@40h04a<A01XJ601:BTP0
1`L501`L6P0201DE4`0301`M600E5Q005QLB008061TD0P0F5Q@04P0J6QP04A4A01PH600R8R80E5AD
01LH5`0C5A@05QPG01/M700P8R406QlK01<H500C6Q<05A`E01LO600E7aH04adE01@K5@805a/J01/0
5QXI01DI600H71/05a/J01XN7@0O8b807B4P01lS8P0Q9B@07R@Q01dV8@0I8Ql06B8Q038j?00N9B/0
8BP_01lV;P0F7B<082P/01PP8`0T;2h08BHZ01hS9`0Q9RT08R/Z01lX9`0O:BH00P0R;2/03@0^>C/0
=3m502/f?00T;cP082lf01//<`0U=Sd08cDi02Hh?00[?D40:cdo02`n@00^@4800P0^@400H@0aA4<0
=DQ60395@@0`@d80<TA603A6BP0dADd0>DYD03M8DP0iBU@0>daD03Q9D@0iBe80?U5E03M<C@0kD540
@EII04=HG015FUl0A5QO04]OI`15FF80CV9]06=fP`1NLW/0CfAW04YOH01CJ6T0GgAg055VJP1>HfP0
CF5X04iRJP1DJ740EVYe05=WLP1DJ6l0Efa_05I[J@1GJfX0Ffm^05iaL@1NL700HWAd06AeM@1XN7P0
JWYj071oO`1cPH80Nh^;07F5Q@1hR8P0Q9:C08:@T@1lRX/0R9>E08VDUP2;UYP0SiVK096KW@2BW9h0
V:2S0:6VZP2NXjL0WZ>Y0:R[/P2PXjX0[:nh0;Bd_P2b/[`0b<SD0=;@g@35`m00a[oA0<W2e03<aML0
dl[M0=S<h03Jc^80g]3T0>GCj@3WeN/0j]S^0?3Ml`3dg_D0nN3k0?cRn`3miOd0onSn0?k[oP3nk_l0
o_;o0?oco`3omol0oo[o0?olo`3oo_l02`3oool0103oooh0oook0?ooo@3oooh20?ono`0W0?omo`3o
nol0ooWo0?kgo`3lm?l0o?;m0?g`o`3mk?l0o>Wm0?_Vo03ihOT0mmgf0?7HkP3^enT0i]7O0=_:e03I
bM<0eLO>0<o3a`3<`<@0aKZk0;fc/@2d[JD0Y9jC09jJSP2GUHP0Rhan0:b^X02VZ9X0TI>507IiIP1e
N6<0L7=P07UlJ`21QG@0N7a]07^1L`1jP780N7ib0080MGeb0480MWif06mnN`1YNGP0IgMf06EeM01R
LW40I7Aa06=cL01QLV`0G6eW05AUG`18FE80?Te603U6?`0kB440>TM002@_:@0a?3H0:C@^02lh<`0V
;bX07BHQ038h=00R:2@09bdY02dd;@0W<BT0=d@m03I2?P0iBDL0=4A30313@@0eAdD0=TI303=2?@0]
>SH0:SD_034k<`17CTL0<3L`02<Z8`0/<b`08bXS02T`:@0^=Bh082LP024X8@0[<R/04Q`D01XT8@0M
:2@0=T4m020Y9P0]=S<06B8O020V900O8b80720O02DY:00O8b80724M01XQ6`0F71P06R0L028X900R
:2H201lU8`0e01lU9@0Q9bL092XZ028W:P0P9RH08BLV01/O7P0B5QD07b<R01PJ6@0Q8b80:B/Z020P
800S8b<0820P01/K6`0N7Qh07b4P01hP7`0L7Qd05ALF01PJ6@0J71/04aDD00`>3@0D5QD05QPG014C
4P0H61D04a8>00h=2@0U92005QDA00H50@0L6aL06APD01<B3P0I61@05A@@010?2`0L6AL071HF01TE
500D4a404A4?010B3`0C5A8051HC01@D4P0C4@l04`l>01LA4@0I51<00P0G4a002P0E4@h040`901TE
4P0K5a@0:BDR05YFD`0I5A804`l<014=2P0G4a0201HB3`805a<@0P0D40d02P0B3P/040`9018>2`0C
3``04Ph;014=2P0@30T04Ph;01DA3P0F4Pl201DA3P0:01@@3@0?2`P030P501TE4P14@3d08QdJ01PC
400C3P/061<@01HA3P804@`900L05Q4>01dH5@0C3P/03`X700P3000>2@H040/800<04@`900<040/8
014<2@0A30T00P0@2`P2014<2@0600/60`0C3P/04Pd:00/60`0=20D061<@0P0A30T04P0?2PL03PT6
00l:1`0?2PL06Q@D024K6`1kMGD04P`<01@>3P0C3@d02`D5014;2`0E3`l03@L700@0000A2`/03`T9
00D000805Q0@00<07QPH00D0000?2@T01@0?2@T03P0A2`/07aTI01hH600B30`03`T901<=3@0A2`/0
40X:00l92@0=1`L03PP8010:2P0:10@02`D50`0=1`L03P0;1@D03`T900D0000=1`L03PP800l92@0F
3Ph04`T:00h41@0?1@H04PP901061`0?1@H04PP90P0C2@X00`0A1`P04`T:01D;300200h41@0T0188
2@0?1@H07A<D01@:2`0F30d04`T:01061`0B20T05@/<01P>3`0C2@X06@l@00`30`0L4Q<02P0101T?
400>10D03@<401882@0700008aTJ00d41@0?2@T02`D500`61P0?2@T02@<300`61P0N61P04`d=00h8
200C3@d030H601@:2`0B20T06@l@0P070000200A1`P03P@500h41@0@1PL04PP901<92P0D2P/04`T:
0P0A1`P201@:2`0400h41@0A1`P04PP901<92P8040H700l04@L801D;2P0=0`804`T801lE500b:2L0
4@L600T0000A1`H05@/:01<9200<0P80200000h40`0@1PD00`0A1`H01`0@1PD07Q@C01L=300<0P40
=2XY06iTH`3Vg=/05?ooool001_ooooo00L04Q0A010>3`0H5QL03@/<02TW:00O7Ah05A<D00803`d>
00T01P@5028P8@1]Jf`04Ph=014=300C3`h0510?01<?3P0@30/00`0C3`h4018>3@0B010<2`0C3`h0
4Ph=010<2`0C3`h03PX900L30P0C3`h05a<B00L30P0@30/04`l>018>3@0@30/05Q8A01XF5@0G4a80
40`;0P0B3Pd06@0C3`h05A4@01HD5@0B5QT0310C01@E5`0;2`/03@`:010?3@0B4@l06QTG01DE4`0T
9bH0cm?D04=4A00?2`X03@T801<?3P0>2PT03@T8014=300E4A003@T8010<2`0<20L00P0E4A00700D
40l04`l>014=300A3@`04Ph=010<2`0I5A@06aLF00h:2@0?2`X04@d<01DB4@0F5A<04a8@018A3`0>
3@/040l=014@3P0N7A/03`h<00d<2P0N7A/051<A01TG500E4@h03@T601<?300J5Q<2018>2`05014=
2P0E4@h05Q8?018>2`0E4@h00P0D40d0100C3``04Ph;018>2`0E4@h201LC400301HB3`0D40d04`l<
00L04`l<00X0510=014=2P0@30T05Q8?01LC400B3P/03@`7010?2P0A40/06aXE0P0?3PT2018A3080
4A0;0P0@3`X01@0G5Q@04A0>00h=2`0@3`d04a8@008051<A00/04Q4?010?3@0A40h051<A01HE4`0?
3P`04A0>00l>300A40h05QDC018A3`02014@3P804Q4?0P0C4Q001`1>C4d071XK01HD5@0Q7b005aLG
010@400F61L00P0G6AP0400=4A008BDT01HH5`0@40h06APF040o?@0V9B<02PT700l>300H5aD05QDC
01@C4@0K6QP07ahL01/J600D518201HF5009014A3`0J6QP0:2PV05]KF@061P@051@B01DE4`0H61H0
414<008061TD01P06AXE01XK5P0J6QP06QXH01TI5`0E5AD06QXJ028R8P1:BTX07QhO01lP8P0J6ad0
5QLI01`N7@0G71P04QPB01DL5@0F7AH05QhF01<M4P0B71<04aXD01HJ6@0H71/201HJ6@8061`K0240
5QXI01TM700H71/05QXI020T8`0T:RL07BHQ01dV8`0O9bL06b<U00T@5P0V;C@06B0X01TP9P0M92T0
9Rha01`T9P0O9bX07BDX020X:`0S;2/07bPW01lY:00U;bh0930^03@o@@0iAT`0;CY002Hc>`0S<ST0
93Dl02Xk@P0/?T800P0Z?4003`0[?Cl0;3i002do@@0]?cl0;T1003A6A@0aA480<4<o0354@`0eAdT0
=dU=03Q9D@0cA4h0>T]E03m@FP0203]<E00403Y<D`0oDUH0>e1C03eBE@80?U=H04l0@eQM05IZL@1<
H6P0AEUR04YNJ@1?Hfh0B5aU04]PH@1HKV`0DFMU05I[K01=HV@0CF9W04eQJ01<H6P0E6Qa05EYM01C
Ig80Ef]b05M/K`1GK6X0FFe/05eaL01PLg80H79b06=eM@1VMgL0JWYj06emO@1bPH80MH>407N5QP1h
QXL0NhV:082>S`23SY00PXf?08VDUP2;UIL0SINI092JW02CVih0U9bO09RMX@2MXZH0WjBX0:NZ/@2V
ZK00[:nf0:j^^02d];h0/k>m0=?AgP3OgNX0cL_H0<S1d`3<`mH0clKI0=O;g`3Lcn<0g]7U0>7Bi`3W
eN/0j=K/0>_HkP3_g?80m=ke0?[Qo03mho`0o^Kn0?oYo`3njoh0o^ko0?kbo`3om?l0ooSo0?ojo`3o
o?l0ooko00/0oooo02d0ooon0?ooo@3oood0ooon0?ono`3ooOl0ooco0?ojo`3on?l0ooGo0?gbo`3m
lOl0o>oo0?c[oP3jio/0nNCi0?OOm@3cfo40k]O[0>gFj03QcM/0e/K@0=K9dP3Eb<l0cl?70<c0a034
^[X0^[2^0:nXX02TWY<0ZJFI09VGR01oP700W9j@08j@PP21QGH0LWET07EhI@1cN6@0Oh=b0824L`1e
NV/0LGMY079hK01bNVl00P1aN700>01_Mfl0KGUg06MeM@1VM7@0IWEb06=bK`1UM740IWE`069aK01J
JF<0DF1I04IECP0mC4D0=44j034l=P0d?cT07BPR02Td;P0/=c40;CHa02Tb;@0`>C@0Ae1;02@]:00/
=C00:cD]02lj<`0W=2d0=D4m03E4@P0eB4H0>4]903Q:A`0eAD80;chi02Pc;P0Q;2H09S0X034h<@0R
:B806R4J024X8@0N9Ah09bhW020W800f?CH08RTR01hU7P0b?3@0;CLd018M6@0Z=C409Bh[01LP7@0F
7a`07R@R0P0X;2/0600Q9B@082@S01LL600K8A`05adI01TO6`0O9B408BLU020V900O9B<07R@T01lU
9@0S:BT08bP[024W9`0F71/0;S8a02P/:`0P92<07AlN02LY:00U9bH092@T02LW9`807AdM01d0:BTY
01hP7@0N81d0828O01XL6@0I6aP071hK01hP7@0F61D07R0M020R7`0N81d07AdJ01HE4@0O7QX0>CPd
02PW8`0K6QH07QdI01lN6P0H5a<06APD01XI5@0D4`l04Ph<010:2P0F4Q406APF01TI5`0201LI5P08
01HH5@0D51805A<A01HB4@0G4A405a8A018>2`0@30T201HB3`0501DA3P0D40d0?c/h065MFP0>2PL0
0P0C3``0700?2`P02`L400/7100C3``05Q8?014=2P0E4@h04`l<014=2P0C3``0510=01<?300?2`P0
40`9018>2`0@30T03`/8010<2@0A3@X04Ph;01@@3@0>2PL02@D2014=2P0K5Q<050l<014<2@0C3P/2
018=2P0<01@?300B3@X05Q4>00l:1`0B3@X030L4010;200B3@X04`h;01@?300C3P/04Pd:1P0@2`P0
2P080`003`X700l:1`0=20D04`h;01dH5@0A30T040/800l:1`0>2@H200l:1`0B01@>3P050000:bDU
00@0000@2PX03@L700`61P0B30`04@/;01@>3P0;1@D03`T901LB4P0>20P04P`<00P20P0E3`l06Q@D
1P0?2@T01P0;1@D05Q0@01<=3@080P802P@4014;2`803`T90`0@2PX04`0?2@T050h>01PB4P0B30`0
1`4101H@400O6AT04@/;00L10@0F410030H600X4100G3`l050X;01<92P0D2P/04`T:01061`0A1`P0
0P0D2P/02`0@1PL03P@500h41@0@1PL02P0101882@0@1PL050X;01061`0E2``050X;00804`T:0`0B
20T07`0@1PL03P@501H<3@0I3a003`D601D;300;0@803@<401D;3009000040H701892P0A2`/03`T9
00d71`0?2@T03@L701@>3P0400004@/;018<30080P80618B04Y0@@0H3Pl0200001<92P0E2``040L8
00l51P0@1PL00P0A1`P00`0B20T04`T:01<92P0301882@050147200>10D05@/<01<92P0B20T00P0C
2@X06@0A1`P03P@300`20@090@0050X901lE500900004@L601lE500V71/081HE01H<2`0D2PT03P@3
01061@0A1`H04PP701471P0@1PD01`0000P0000L4Q404`T801L=300Y7ah05?ooool001_ooooo00l0
4@l@01DC500;2@X02@L8018@4@0E4a@0GeeN01<A4P0G5AH03`d>010>3`0J61T03`/:01<?3P0D40l0
100B3Pd00`0D40l04`l>014=3002010<2`0301<?3P0B3Pd04Ph=008040`;0P0B3Pd0200D40l0>cLf
048n?@0=2@P0510?018>3@0A3@`03`/:0P0@30/08@0=2@P040`;00d9200A3@`04`l>020L6`1>C4d0
L7Ah01@H6`0F6Q/04Q8A01PG500B4@`03@`902HW8@0R92004aHC020V900F5aH06ADD014=300?2`X0
5A4@01<?3P0a;B`07QXI01<?3P0A3@d05a<B01`H5`0B3Pd05Q8A01@@3`0201<?3P04014=300H51<0
:bLV02/W9P805A4@00@05a<B018@3P0@3`d03Pd;0P0@3`d00`0C4Q005QDC00D40`02010?3@0N018A
3`0F5A<04@h<01`H5@0A3@X05Q8?010<2@0E4@h05Q8?01DA3P0G4a005A4>01<?300F4Pl04@d:01TE
4P0M6AH04`l<014=2P0H51405a<@010<2@0E4@h040`901XF4`0C3``04@d:010<2@0E4@h04`l<0P0F
4Pl201DA3P805a<@01@05Q8?01<?300C4Pd04a8=01dL5`0K6QD051<?01LF4@0F5A406QTE01@C3P0@
3`/04Q4=014@300D4a4061LE018A3`0E51806APF00d<2P<04Q4?00T04a8@01@C4@0E518051<A018A
3`0@3`d04a8@01DD4P0A40h0100C4Q0201@C4@0I04i;C00M6Q/04@h?01HD5@0B41406a/K01@D500J
71/0J6YY03Pk>P0Z;B`030h=01@C4@0>3@/061LE01DD4P0G5Q@061LE01DD4P0C4Q004Q4?01<B400G
5Q@06QTG01HF500201TI5`0Q01HF500M7A/09bLU01`L6P0c<c407AdK01DE4`0J6QP051D@01@E3`0H
6A@05AHA01XK5P0H61H05QHD01@D4P0D51@071`L00d=3@0M7Ad0=SHh04I7B`0Y:R`05QLI01HH5`0I
7A`04QPC01LN5`0I81P05QhE018L4@0G8AH05A`F00805a/J02P06QhM01/O7P0J7Qd06QhM01TM700O
8b80720O01@H5`0Q9B@09R`Y01LP6`0I8Ql07RLV01LO8@0W;S@0H6M^01lV;P0P9bd07BDY01`T9`0L
92H08BT/01lW:`0P:B`08BX/020Z:P0R;B/09S8a024];@0W<cH0;CY002/h@00R;cP08S4h02/l@`0W
>3l09cTm02m1A@0Z?400:cdo0P0^@4805P0^@400<D=303A6A@0bAD<0<dI203M9B00hBT`0?e5E06am
Q@0hBE<0>T]E03Q9D`0`@DT0@U=K03a>EP0lCeD0?eAH045FFP10EEX0@5EK04QLHP1@I6/204MKH`80
BEeW01P0CF5X04IKG01CJFL0BV1N04QMGP17G5h0Bf1S05=XK@1<H6L0E6Q`05Q/M01DJ780F6ac05U^
K`1JKfd0G71_05ibL@1OLW80Gg5a06EgM`1XNGT0KGem0720P01cPX8207J4Q@0;07^9RP1nS8d0Ohb=
08JAT`29U9H0RiJH08fFV02>UiT0T9VK09BLW`2FWZ400P2JWZ<08P2LX:D0YJR_0:FW[P2^/;L0/[:l
0;Fd_`2c/[`0`l3>0<[7e02n^/P0b/?E0<o6f@3BbM`0f/kR0=kAi@3PdnL0iMGZ0>WFk03Zf>h0kMW_
0?7Ml`3egoH0nn;m0?kTo@3oiol0onWn0?o/o`3ol?l0oo?o0?odo`3on?l0oo[o0?omo`3oo_l;0?oo
o`1E0?oooP3oood0ookn0?ono`3ooOl0ooco0?oko`3on?l0ooKo0?oco`3ol?l0o^oo0?g]o`3kjOh0
n^Gj0?WRm`3fgo<0l]_^0>cFi`3Xe>40fl[F0=74c@3Cb=00d/S>0<^o``35^[`0`;Je0;J_Z@2XXIT0
XIfA0:FSU028RGP0Kg5O0823L`1mP740OX9c07AgIP1bMV@0MW]X07^1L01jOfl0M7]/06Q_H`1[LVH0
KgM/06efK@1[Lf/0J75Y06QdL@1WM7<0JGIe06MeLP1TLFl0IWA`06=aK01MJfD0EfEN04eKD`13DDT0
KGYb041;A@0T;RP09S0[02<]9`0U;bX0:C<^02La:`0^>380=d4l04QBC00/=S00;SPb034k=00jACl0
;c/g03M6@`0`@Cl0<4=103a?C@0/?C/08c8_02Te<@0Q;2H0:c@^02/b:`0302H]9P0`02D/9@0X;bP0
<CPa02H]9P0Y<2T07RDN02@[900T;RH0BUAA02Lb;P0b?CT09Rl/01TR7`0P:BH082HT030d<`0[;bh0
6QhM02<W9P0R9b<07RDO01dS7`0L8Qh07B<O020V900Q9bD08bTW01/Q8@0M8b<08RPX01lT9`0c>CT0
9R`[028V9@0P92<0720O01`N7@0N81l08B<R01hN7P0Q8B407AdM020P800Z:RX092HS01/M6P0Q8b00
7AlL0P0J71T0?@0I6aP05ALD01/M6P0J71T06A/H01TJ5P0I61@081lK01`K5`0I61@07A`H01HE4@0L
6aL06aXF01PG4`0I61@05QDA01PD4P0H4Q8061@C01PG5@0?3`d092HS05aNF`0U9b@06a/I01HD4P0J
5QD05@l?01TD4`0C3``05A4>02DQ7P0V8Ql04`l<01@@3@0K5a@061@A01DA3P0@30T04Ph;01HB3`0D
40d04`l<01LC400I5A805a<@01DA3P0C3``040`901DA3P0I5A805Q8?01@@3@0G4a005Q8?010<2@0?
2`P0510=018>2`0A3@X00`0@30T06@0B3P/03PT6010;200B3@X03`X700d81@0D3``04`h;014<2@0C
3P/04Pd:01D@3@0C3P/050l<018=2P0E40d06aHC01XE4P0C3P/061<@010;200B3@X04`h;010;200?
2PL00P0A30T2010;2003014<2@0B3@X05Q4>008040/801D04@`900l:1`0A30T04P`<00l92@0A2`/0
3`T901@>3P0@2PX04`d=018<300<1PH05@l?018<300@2PX0=S4a01`F5P0;1@D0:bDU01<=3@0=1`L0
0`0@2PX02@0?2@T03PP800h8200B30`03`T900h8200@2PX04@/;018<300200d71`0C014;2`0D3Ph0
3PP800h8200B30`02`D501<=3@0B30`030H600X51@0?2@T05a4A02<M7@0D3Ph02@@400l71`0A1`P0
5@/<01H<3@030147200`01D;300C2@X04PP90147200@1PL050X;01061`0F30d04PP901D;300<0`@0
60h?02/Q8P0J41404`T:01882@0C2@X04@L801D;300?1@H050X;00l61P0B20T04`T:01@:2`0F30d0
4@L801@:2`0?1@H03`H700d71`0E3`l02P@401<=3@0@2PX030H6014;2`0@2PX02P@400h8200A2`/0
81HG00d41@0@1PL060h?00l51P0C2@X03`D60P0B20T0700A1`P04`T:0147200?1@H040H701@:2`0A
1`P03@<401061`0E2``04`T:0147200B20T04`T:0147200<0P8060h=01<9200@1PD05@/;01@:2@0<
0P4050X901D;2P0@1PD03@<301471P0?1@@201061@804@L600L040H501881`0C2@P030<301D;2P0?
1PD04@L601Cooooo000Kooooo`0@00H41@0J61T06aTJ01`J6`091`P05aDF03Hd=@0<2P/04a4B00/9
2P0C4A804@l@02<O7P0L61L04Ph=014=30<04Ph=01403@T800`81`0C3`h05A4@01@@3`0F4Q405A4@
01<?3P0A3@`04Ph=01@@3`0E4A00100000d9200M6AP020@300l;2P06014=300O01LC4P0>2PT02`L6
00X61@0F4Q40BTQ905MJG`0@51L05AHH014B3P0H5a8051@<01/K4P0D50`020T3014E3P093PX03@l<
014=300>2PT06QHE014=300D40l0PWim03`h=`0A3@`061@C018>3@0810<061@C01TE500201PD4`0F
01LC4P0@30/0510?01dI600K5aH03@T801<?3P0E4A003``;01<B400D4a404A0>018A3`0A40h03`h<
00`;2@0F5A<04A0>01DD4P0F5A<04a0>02dY9P804`l<00<02@D201HB3`0A3@X01@0A3@X0100>2PL0
61@A01hJ5`0E4@h2018>2`0:01HB3`0;1`@04`l<00h:1`0300004@d:018>2`0@30T05A4>00l;2080
510=0P0C3``01`0@30T03`/8010<2@0F4Pl09B@P01PG4`020@000P0H5a<03`0F5A404a8>01XI5@0F
5A4040l;014@300B4@d04Q4?01PG5@0C4Q004Q4?01<B400I61H03`h<014@3P0301<B4007014@3P05
10805A@B01XI5`0C4Q003@`:010?3@0601@C4@0=01LC500E4A80510A018@4@0D4Q<05aDF01<C4`0I
6AT0ATQ703Tk>P19BdX0418A01DD4P0201<B400F01@C4@0E51805QDC01DD4P0C4Q0051<A01LF500U
9280<S4_01LG5@0I6AL061PF01@D4P0C4a4051@B01PH5P0g=cD05aLE01TI5`0@40h05aPC01LH4P80
61TD03`05QLB01LG5@0[:bT07AdK01TI6@0H61P07alO014A4@0I6AX08B8T01PI6`0N7b406A/J01/P
700A5a404aXC01@K500I8AT05AlD01hX7`0N9Al061`K01DI600K7ah0720O01XN7@0N8R406QhM00`@
3`0F6QT08BDT01lS8P0O9B804Q/F01DN6`0M9RD04a/M01TP9P0U;3<09bhf020W;@0N9RX0<c/n01/S
9@0S:S008RT_020Y;@0O:B/08B//02<_;P0[=cL0:C@f02Tg>P0R;cL07b`d02Pf?`0V=ch0:CY102Pi
@00W>Cd202/m@@0P02Xl?P0^@480;T1202i0@00cADD0<TA302i1?`0X>cL0=TU803a>D00cADT0G6ee
03M8DP0cA4h0=4E?03I7C`18FF40>TaD03]>E013F5d0AU]P04EJG`17Ff40C61W041DF`12EUd0AEUP
04MKI01:GVL0BemV04UNH@15FUX204IKG00D04QMG`1AIVT0FFic051UJP1JKg@0GW9i05EYL01DJFh0
F6e^05]`K`1OLg80H7Ac069eM01RM7@0IWQh06MhN01^OWh0LX:207B3Q01kRHX207f;S00A07b:R`22
SHl0QY6C08RCU@2=UiT0SiNJ08jFV@2?UiX0U9bO09ZOX`2JWJ80VijS09fPY@2TYjh0[:bd0:n_]`2_
[kT00P2h]/406`2n^/P0a<3>0<C0cP3<`mH0d<OJ0=?:g@3Jc^80g]7U0>3AiP3Ve>X0jMK/0>[Gk@3^
f>l0lmgd0?SPn03khO`0o^Cm0?kVoP3niod0o^_n0?o`o`3olol0ooCo0?ogo`3on_l0ooco0?ono`0;
0?ooo`0Z0?oooP3no_`0oogn0?omo`3onol0oo[o0?oio`3om_l0oo;o0?oao`3okol0ongo0?gZo`3j
iod0nN?h0?OQm@3dgNl0l=WY0>[Eh@3RdM/0elSB0<o4c03?aLd0c<;90<Jm`02l/[<0]JbZ0:jWX@2S
Wi@0ZJJH09RIQ`1lOF/0L7=P07YnK@22QWD0Oh=d07UmK01]LF00LGET06ieI@1`MfL0LGMY0P1]MFP0
1P1/M6T0JG=Z06UcJP1YLf`0IG5]06EaK`80Ig=a00l0IW9^069^JP1TLFX0EfAM04AABP17E4/0<d0g
04]FCP0c?3L07bPS02@]:00X<B`082TT02@]:00R;BL00P0X<bd05P0`>cD0;3La030k=@0Z=Bl0:SHa
02<b;@0P<2d09cTf0395@`0gBTP0;chl02@c;P0[=S00>dHn01DO5`0L8a`0:C0Y010G400M91d0?4<l
02`c;00W;RL202H]9P0D028Y8P0Q:2409c4Y024[9`0_>SH0DEaH02Xc<00P:BH07bPU01dS8@0V:RT0
92PW028V9@0Q9B@07B8N01lU800Q9b<082HR01hT800N9282020V900M02<Y:@0P9RH08RPX02db=@1M
Hf<0Be5@024U900H71/06QhM024S8P0W:BP09BLV01XJ6P0K6a/07QhN01lO7`0Q8B408bDR01DG500M
7a`06A/H01HH5@0K7AX061XG01LI5P0I6aP05ALD01HH5@0I6AH00P0H5a<0700I61@061LC01LF4P0I
61@05QDA01XI5@0I61@04A0<01HE4@0K5aD071HF01hJ6@0@3`d061PF06U[J03Zk>T0D59?01LG5@0@
3Pd061@C00H0000E40h05A4>01@@3@0F4Pl061@A01HB3`0E4@h201`H5@0601@@3@0C3``05A4>010<
2@0A3@X04Ph;0P0?2`P0500A3@X05A4>01HB3`0B3P/05Q8?01dI5P0I5A803PX700l;200B3P/061@A
01XF4`0D40d040`9014=2P0F4Pl0510=00d91P0@30T04`h;0P0D3``01@0A30T040/8014<2@0?2PL0
4@`9008050l<00l04`h;014<2@0B3@X030L4010;200G4Pl050l<00P3000=20D030L400l:1`0@2`P0
3`X7018=2P0@2`P00`0A30T06P0@2`P03PT601PC400?2PL04@`901<>2`0A30T050l<01<=3@0P6QX0
8adM00d71`0:1@D06aDE010:2P0C3@d04P`<00/51@0:10@03@L7010:2P0/9RH0618B02XT900D3Ph0
5@l?0`0?2@T3010:2P0400h8200?2@T03`T900l92@<040X:00T04`d=00h8200>20P03`T900d71`0B
30`030H600X4100=1`L00P0@2PX03@0>20P04`d=018<300>20P03@L7018:2P0?1@H02P0100l51P0E
2``050X;01882@0E2``00P0?1@H04P0@1PL03`D601D;300A1`P040H701882@0C2@X04PP901T?400b
:2T05P`=0147200@1PL05P`=01<92P0A1`P03`D601882@8050X;0P0B20T02P0C2@X04@L801061`0B
20T05@`=00l92@1_JFT0RhF501<=3@0E3`l200l92@0>00h8200=1`L03@L700h8200A1`P05`d>0106
1`0C2@X050X;01L=3P0?1@H04PP90147200?1@H201D;300601L=3P0;0@803`D601X@4@0E2``04PP9
100@1PL02`0B20T04`T:00h40`0B20L04@L600h40`0B20L04`T800l5100B20L04@L600803`D40P0A
1`H01@0@1PD03`D400l5100@1PD04@L600H040H55?ooool001_ooooo02@04Q0A00l=3P0J61T07A/L
00h<3@0:20T00`42014?400<2P/02`T:014?400?3@h0<2`[01`H5`0>2PT040`;01<?3P0?2`X0:RHU
01PD4`0>2PT05Q8A01DA400?2`X05Q8A01DA400D40l04Ph=01@@3`0G4a8061@C010<2`0<20L04Ph=
01<?3P0H51<3014=30<04Ph=01P040`;01<?3P0C3`h081`K03<_;P0o?Ch05aTN014B5P0<30`03`l:
01DB2@0B40@03@`1014A1`0J71403Q0900T>1`0@40d040`;00d9200E4A0030P700l;2P0e<C0200L3
0P09014=300E4A001@40014=300F4Q404`l>01HB4@0E4A0040`;00<0510?01D040`;018>3@0E4A00
4@h=014@3P0C4Q004Q4?01<B400A40h030/901TH5P0A40h03`h=00l>300B4@l04@l<020L6@0D40d0
6ADB00`81@0=2@H01P0C3``0=P0A3@X05A4>01@@3@0D40d05Q8?014=2P060P006aLD01DA3P0N6QL0
6ADB010<2@0E4@h04Ph;01DA3P0>2PL0510=01DA3P0D40d04Ph;010<2@0B3P/04`l<01@@3@010000
5A@B01@C4@0R8Al02PT701PG5@0>3@/04a8@01TH5P0E518040l=01<B400J6AL0@T4o018A3`030P00
71/I00<2000A40h04Q4?01<B400D4a404a8@018A3`0N7A/05QDC010?3@0A40h04Q4?00l>30H051<A
0P0F4Q<03@0E4A80510A01<@4@0B414061LG010@400I6AT02PX:01DG5P0H6QT061LE01DD4P0D4a40
0`0B4@l01`0H5aD051<A01@C4@0C4Q0071/I02LV900D51800P0H61H03P0D51804A4?014A3`0C4a40
7AdK01LG5@0N7Q`0410>01LH4`0F5a404Q<>01`M600G61<08b<Q0P1>CT`0500E5AD05QHF00T92@0M
7Ad05QLF01LI600C5A@05aTH01<E500M8Qh06b4M018I4P0@5a0051`E00/E300:50`061lI01PL6`0G
6aX0720O0P0K7ah0FP0M8B007b<R01HJ6@0^<S40=CTh01hR8@0P9R<06B8M01PQ7P0R:RX0620R01@K
8@0O9Rd08RTa01XQ9`0h@4@06B4T024Y:`0S;3408R/`024Z;P0O:R`082`/02<_;`0J:2T06BLX02@b
=@0Z>D009cHm045?F00X>D00:S]202Lh?`0U=c/0:C/o02Xl@00Z?3h0;Cm102i0@P0^@400<TA40395
A00^@Cl0;T4m03U;BP0lCU00>D]?0393B`0dADl0AeQR059SK@0lCED0=TM?03i@E`0jCE@0@5AK04EI
H014F5l0AUYQ04YNI@12EUd0@5AK04AHG`19GF@0BemV04QLH`19GV40AEYL04EJG@16Feh0Bf1S05I[
KP1IKW40E6U/05ebM@1PMGX0EV]^05=XJ@1EJV/0FFi]05ibL@1QMG@0I7Mg06IhN01[OGd0JGYj06in
OP1aPH40MHB407f;S0<0OhZ<00@0PXf?08NAT`29TiD0SiNJ0P2@V9/02P2CV9`0V9fQ09^PY02LWj@0
WZ6V0:2SZ02XZ;00[Zjf0;6a^@2c/K`20;^h``0K0<2lbP36`]00a/;@0<c3eP3Ba]X0e/[N0=_>hP3O
d>D0h=7V0>GCj@3Ye^`0jmS^0>oIl03egOD0n>3h0?_Qo03ni?d0o^Kn0?kWo@3njoh0onoo0?oco`3o
m?l0ooOo0?oio`3onol0ooko00/0oooo00D0ooko0?omoP3ooOh0oocn0?ojoP020?oho`1V0?oco`3o
l?l0onoo0?o]o`3ojoh0o>Sm0?WVo03hh_L0mMkc0?7Jk03]e^H0i]7M0=o>eP3Ealh0c<790<c2bP36
_lD0aKbo0;Za/P2bZjL0[:FM0:>OU02WY9H0QhQf07EfI01eN6D0OX9a08B8M`1jPFl0M7]Y06U`GP1]
M6@0KWEU06mfIP1_MfT0LGU^06eeJP1VL6L0J79Z06afKP1[MVl0Ig=_06A`KP1RKVX0I71/069^JP1H
IEl0D5eF05MTG@18ED`0A558034n=@0[=Rh092dX020V8P0W;BT0:S<^02L`:`0R:bH08bhX02Ha:`0^
>C<0=T<l02hk=00gA3d0=D4m03A0?00Z>C@08S8_02Hh=P0bAD<0;Cdl02Lf=013DTd0>D@n02D`:00[
<RX0<cXc03Dl=@0P9b00>D0i05mVG`0f?CH082LP02<Z8`0X;bP09B`U024X8@0U;bL09Bl[02Lb;P0i
A4008R/X02D^:`0S;2T08BLU02T];00W:bX09BTX024U900N8al08BPR0P0T:RH04@0P9R807bDS01lU
8`0e>cT09bd]01dS8`0Q9bL06QlR02dc<`0P9RD06AdL02<W9P0W:bX07R0O01XL6`0O8B006QXJ0080
71`L00l07AdM028R8P0J71P05QPC01hP6`0H6QD05QPC01/M600H6QD05QPC01LI500E5a805aTD01TI
5@0G5Q801@0H5a<04P0@3`/05QDA01PG4`0<2`L04A0<01PE4`0I4a<07QXI01TH5P0D5180;S0]0863
P00W:BH03@d;018@3`0M6AP050h>01/F5@805Q8?00H040`900h:1`0G4a005A4>01XF4`0K5a@601@@
3@804Ph;01H05Q8?014=2P0C3``04Ph;014=2P0E4@h0510=01LC400D40d04@d:01<?300F4Pl061@A
00h:1`0=2@H05Q8?01DA3P0<20D04Ph;01D@3@0C3P/040/80P0B3@X200l:1`04018=2P0D3``050l<
01<>2`804@`900P040/8018=2P0F4@h04`h;00`7100?2PL06A@A01D@3@803PT60P0A30T2018=2P06
014<2@0@2`P03PT601D@3@0?2PL040/80P0B3@X01@0D3``02@<3010:2P0G4A407ALG00<04@/;00@0
30H600d71`0F41004P`<0P0<1PH01@0O6AT05Q0@01<=3@0;1@D04P`<00<03PP800@04@/;01@>3P0F
410040X:0`0?2@T200h8200C00/51@0A2`/030H600T4100F41003PP800d71`0G4A4040X:01<=3@0D
3Ph02@<300h8200<1PH02`D500`61P0>20P04PX:01<92P0201@:2`<04`T:00H060h?01882@0A1`P0
4PP900l51P0C2@X201882@080147200B20T050X;01H<3@0M4a@03@<401882@0@1PL201@:2`050147
200@1PL04@L801@:2`0C2@X00`0B20T0300A1`P040H701882@0B2@X0208205E?C`1/IVH0100000l9
2@0A2`/040X:00l92@<03@L700L0308301P>3`0>1@D03@<401061`0D2P/03`D600804@L800X05@/<
01hD5@0V71d0;bDV01/A4P0D2P/05P`=00`20`0A1`P04PP90P0A1`P02@0@1PL04@L801882@0@1PD0
3`D401471P0@1PD03`D401D;2P0201881`0301061@0=0`803P@300804@L600D040H500l5100?1@@0
40H501471P0601061ACooooo000Kooooo`07010>3`0B41403`d>00H51@0B4140518C00h<3@0200l=
3P0?01LE5P0A3a003@/<01`H5`0B3Pd04@d<01DA400B3Pd040`;02LS8P0J5QD04@d<018>3@0@30/0
30P700804Ph=00X040`;00l;2P0B3Pd05A4@010<2`0A3@`05Q8A00l;2P0:1PD04Ph=0P0?2`X0:00@
30/04@d<014=300A3@`04Ph=01<?3P0F4Q403PX901XF5@0>30d03@dB01PH6@0=30T05Q<<010=0@0J
60T0;R/J01lL3@0R8A@04a@:01LJ400?3`T06QHE01HB4@0=2@P071PG01/G5P0<20P05Q8A01hJ6@0=
2@P061@C01DA400K5aH04`l>00h:2@0C3`h0510?014=300H51<301@@3`0300h:2@0@30/04a4?0080
4a8@00@03`h<018A3`0C4Q004A0>0P0D4a40100E51802@P601HE4`0H5Q<2014=2P0301/G500G4a00
5Q8?00H04Ph;01h061@A01XF4`0F4Pl04Ph;01DA3P0C3``06aLD00<0000k=c@03@T601TE4P0C3`d0
5A4>014=2P0D40d03@T601@@3@0F4Pl04@d:018>2`0G4a007ATF01/G500A3@X05A@B00l>300H5aD0
4Q4?01@C4@0G5Q@2010?3@0:01`K6@0K6QP040l=01<B400I61H04A0?01LF500I61H03Pd;01LF5080
51<A00X04a8@01@C4@0C4Q004a8@020O7@0W9R@08b8P01PG5@0B4@l05QDC1P0D4a40400E4A805a8D
01TD5@0H51D05Q<D01@A4P0L6Q/0GUiN010@400E5AD02P/:018B4P0G5Q@05QDC01DD4P0D4a43018A
3`0Y01DD4P0I61H05A@B014@3P0D4a405QHD01/K6@0L71X06ATG01DE4`0D51805ADC010@3P0M7A/0
7alM018B400L7AP05aPC018C3P0H6A@051D@01XJ600i>CL0:2PV01HF5P0K6a/03`l?01dM7@0F5aH0
8bDQ01TK6@0F61D0418?01/P700F6aL04ALC01LM6@0I81`07RLQ00dF4P0J81h00P0E6AP09`0O8b80
6alN01XN7@0N8R408BDT02``;`0b=SD09RXY01lS8P0R:2D07RLR01XS800L9B@07BDW01lV;00S:S40
6B0X04mFG02@V9`0:30c024Y;00P:Bh082T`024[<00R;Bl092la02Hc<`0[>CX08Bl`02Le>@0eA4/0
:3Ho02/i@`0W>400:CY102Hg?P0V>3`0:ce102i0A00202i0@P0C0312A00a@d<0<dE503I8A`0_@T00
>4]703Q;BP0/?T00AEMK03]<E00gB580AeQR05Y[M@16Eel0?e1H04AFGP10DeX0@UIM04AHG`0204=G
GP1904AHG`1@I6/0BEeT04YNI01?HfT0C65W049GG019GV@0Bf1V04aQI@1=HVH0DFIZ05I[KP1JKg40
EV]/05Q^K@1IKfh0EFYY05AZJ01FK6X0F6e[05a`K`1OLg80HgIe06EgM`1aPh<0KGin06moO`1aPH40
LX6207V7R020Rhd0PHb>08:=S`25Si40R9:D08VCU@2>UYT0TIRK09:IW02EVYh0VIjR09^PY02PXjP0
XjFZ0:JX[@2][KD0/[:j0;Bd_02k^L@0`;g80;jkaP32_L/0b<?A0<W3d@3?aMP0e<SL0=O;g`3Lcn<0
gm3U0>3AiP3Ud^P0j]K/0>gHk`3`fO40mMge0?OOm`3khO`0o^Cm0?kVoP3niod0o^_n0?o_o`020?oc
o`040?ogo`3onOl0oo_o0?omo`D0o_kn1P3oool0J@3oo_l0oogn0?kloP3onol0ooSo0?ogo`3om?l0
oo7n0?o^oP3ok?h0onWm0?gUnP3liO/0n>Gk0?KPm@3bg>l0kMKV0>OBgP3Mb]<0eLK<0<g1a`38_/H0
al370<6l`P30^[/0_;Bb0;F^Z@2YYI`0W9R<08n=O`1fMfD0Kg9N07b0J`20QG80PXQe07QoK@1aN6L0
J6mN07=jJP1gOVl0N7m`07InL@1[M6T0Ig1U06A^I@1[MFd0KWUa06]fL01VLFd0IG5^06=^JP1LIf<0
EV5M04mKE@1;Ee00D5aE04IBB@11CT@0=40g034l=00/<Rh0;C<_02X`;00]=300<CTd02Tb;@0T;bT0
9S4[02hj<`0f@c`0;CXc03E3?00d@Sd0<d8n0392?`0b@T40:chl02@g=@0Z>ST0<d8o07f:P`0g@SX0
;cP_03]2>P0U;2D09bhW04Q?B00Z<BX0:C0Y01lV7`0P9b008RTR02L^9`0U;2D092/T02Tc:`0Z=340
92l[028]:@0L9B8092dZ020Y9P0S:BL08RHU024U9002020T8`05020U8@0R:B<09R`X02D[9`0R:2@0
0`0N9280500P9RH07B<S02@Z:P0L8B@06R0P01XP7`0O8b808BDT01dQ800O8B009RPW01/M700Q8B40
92@T01dM7@0H61P06a/I01XL600K7AP07AlJ0P0G6A@02@0K7AP05aTD01PJ5@0K7AP05aTD01HH4`0G
61<05QDA01LF4P0401PG4`0301@C3`0G5Q805QDA00806QTE01405A8@01D?3`0E4A0051<A01LG5@0<
3P/07R0M018D4@0N7Q`0518@01XF5@0C3@d04@`;01HB3`0I5A8061@A01@@3@02018>2`805Q8?00<0
4@d:018>2`0A3@X00P0D40d01@0C3``04@d:01<?300I5A804@d:0080510=00<040`900l;200C3``0
0P0A3@X0400D40d04`l<00h:1`0B3P/03`/8018>2`0?2`P03PX701<?300D40d03`X7014<2@0B3@X0
4@`9010;200C3P/2018=2P<04`h;00@04@`900h91P0@2`P04`h;0P0E40d02`0D3``04@`901XE4P0B
3@X040/801@?300=20D03`X7010;200B3@X04`h;00804Pd:02004@`9010;200@2`P04@`901<>2`0D
3``03`T9010:2P0K5AD0=S0`02<M7@0A2`/020<301@>3P0B30`030L700h8200?2@T04@/;00P20P0@
2PX03`T9010:2P0=1`L04@/;00l92@0>20P04@/;01@>3P0G4A404@/;010:2P803`T900d03PP800d7
1`0B30`03`T901D?3`0?2@T040X:00`61P0?2@T03PP800/51@0=1`L040X:00803PP801403@L700l9
2@0B30`04@/;00d51@0L4Q<0;28S024G600;0@80308301061`0E2``04`T:01882@0E2``04@L80188
2@0201<92P0:01061`0A1`P05P`=01`B4`0@1PL0308301882@0@1PL04PP901H<3@<04PP90P0C2@X2
01D;300:01@:2`0A1`P03@<400h41@0D2``02@<300l92@0=1`L06aDE018<30804@/;00`03`T900d7
1`0<1PH030H600h51@0M4a@05@/<01061`0A1`P03P@501D;300D2P/201<92P0L01D;300G3@h05@/<
01061`0E2``03@<400P0000e:b`05P`=01D;300B20T03`D600h41@0=0`@04@L600`20@0B20L05@/:
01881`0L4Q405P`;01881`0>10<03@<200l5100@1PD04@L601061@803`D400<040H501471P0@1PD0
1@0@1PDDooooo`006oooool0400=2``04Q0A00d;300A3a0040h?004000040P<06ALH01LE5P0?3@h0
2@L801DC500>2PT04@d<01hJ6@0M6AP2010<2`0600l;2P0B3Pd04Ph=00l;2P0A3@`0510?0P0C3`h0
2`0A3@`040`;018>3@0D40l040`;018>3@0>2PT05A4@01hJ6@0<20L04@d<00804Ph=0P0D40l0?00E
4A0030P7010<2`0L61L040`;01/G5P0L61T03@/@00l=3P0B3P/06aH=01<=000X8a00N7=O07mjIP0d
<Ah09RDG0041000I5a4040`;01TE500C3`h030P701DA400C3`h030P700d9200O6aX061@C00d9200C
3`h04Ph=01<?3P0R7Qd07ATH014=300C3`h04@d<018>3@0C3`h03`/:010<2`0J5aH07ahL01XI5`0@
3`d04A0>018A3`0A40h06QTG04e<BP0Y:2H04A0>01TH5P0>30T040`902/W900A3@X02@D200`81@H0
4Ph;01006ADB01hJ5`0K5a@040`9014=2P0E4@h03`/802@P7@0A3@X0<2`Y00l;200I5A805a<@01@@
3@0F4Pl03PX70P0C3``0100E4@h04`l<014=2P0C3``201DA3P0B014@3P0I61H0FeYH02@S8@0J6AL0
5QDC00l>300@3`d05A@B01@C4@0?3P`03Pd;0040000J6AL01PD301TH5P0l>cT05QDC0P0D4a402P0B
4@l04A0>018A3`0C4Q0020L501dL6P0R8Al05QDC00l>300G5Q@601@C4@0301D?4@0G4A<06Q@F0080
6ADF00P05a<D01PF5`1@D50010@402DU9@0L71`051@D01@C4@<05A@B0`0C4Q002@0A40h05A@B01HE
4`0H5aD071/I01@D4P0H61H06ATG01HF500201@D4P0T01DE4`0B4Q006QXH01HF500B4Q005aPC01XK
5P0I6QD05AHA01PI500A4@l05ADC01`L6P0O7al071`L01PH600W9bL06a`H01/N5`0D5Q406Q`G01TK
5P0M8Qh051TE01DK5`0O9B<04APF01HO700:4a00;C@b01PL6`0D61L07b<R01/O7P0H71/08bLV0P0G
6aX0900I7A`06alN02@X9`0J81d06B8M01`U8P0I8R406B4S01/R:00K8RT092/c01XQ9`0`>3`09blb
020X:`0O:2d082T`024/<00T;c409S4c02Hd=00O;Bh082h_02Dd>@0X=Sl09C<l030nB00U=Sh0:3U0
02Lh?`0Y>cl0;d550394B00a@dD0;d530353A@80=4I600h0>Da;03Y=B`0bAD40?U1?0312A00cADT0
?e1H03Q9D`0gB580AUMQ03i?E`15EUh0@59I045DF`80?e=J0140@5AK04AHG`16FV40CF5X04QLHP1:
Gf@0D6EZ04eRI`13Eeh0CV9[05EYLP1EJG00E6Q_05I[K`1DJF`0Efa]05AZJ002055XHP0B05=ZHP1F
KFL0Fg5^05aaL01NLW40H7Ac06AgMP1VN7P0JG]k06]lO01dQ8@0MhN707N6Q`1kRHX0P8^=08:=S`23
SY00Qi6C0P29TiD0402<U9L0TYNK09BIW@2EVYh0VIjR09^PY02SY:T0YZN/0:Z[/02_[kL0];>k0;Je
_@2n_<L0`[o:0;nla`33_L/20<W3d@0H0=75f@3Db=`0el_O0=c?h`3Od>D0hLoU0>CAi`3[eN`0k]S_
0?;JlP3egOD0mmog0?_Qo03ni?d0o^Kn0?kWo@3njoh0onoo0?kbo`3olol0ooKo0?oho`3on_l0o_co
1@3moOd00`3no_h0oooo0?ooo`030?ooo`0Z0?ono`3no?d0oO_n0?khoP3mm_d0oo?m0?obo@3okO/0
on_l0?oXo03niOX0n^7g0?OPn03ch?H0lM_b0>cFj03Ucm`0g/[E0=?1b03=_/<0b;g10<:k`P32_L<0
^KFl0;F_[`2`Z:H0Y9fI09RDR`2?SH00PH5`06iaG01aM5l0OhA^07^3KP20R7<0OXEc07ElK01[LV80
LgYZ07AlK@1cNf`0L7Q[0P1VL6D01@1YLfX0KGQ`06ehL01VLF/0GfYV0080HfiZ02P0F6=O055LF01?
FU@0Ae9:045<A00g@SX0;CT_024]8`0b?3<0;cDa02hc;`0X;RX0:Bl[02`d;`0X<B`0:SD_030l=@0^
>c@0=T<l03=1>P0fACh0?di90351?@0]?CX0<TE30354@P0V>CL0:SXi02`j=P0[>3407bTQ03<l<P0@
60d0;3<[02T`:@1;DT/08RTR02he;P0N9Ah09RdV0P0T:b@04`0Q:2408bXS02/e;@0Y<c0092l[01TT
800N9b@09Bh[02L`;@0N92806AdL01XN7@0M8B007b<R028W8`0P9b408bTU028X900O9B400P0N9280
7P0X;R`08RPX01`R8P0J82006AhQ01DK6`0i?ch082@S01/O7P0R9RD08B<R01XL6`0O8B009bLW02XZ
:P0R8R806ATI01/K6@0K7AP06Q`G01LI500E5a805aTD01PJ5@0F61<06A/F01hP6`0H6QD051HA01HF
4P<05aHB01/05QDA01DD400H5a<04a8>010?2`0=30P06QTE01hM6@0>2`T04P`<028N7@0D4a40410>
00L91P0E5a@030h;00P81P0F51<05A4@01D?3`0L5aD04`l<010<2@0C3``05a<@018>2`0C3``00P0F
4Pl00`0C3``05A4>018>2`0301<?30804@d:00X05A4>01<?300B3P/0510=014=2P0>2PL0510=04M3
@00Z9R<04@d:0P0I5A80300?2`P03PX701DA3P0E4@h04`l<01LC400?2`P050l<01TD4@0K5Q<04@`9
00h91P<04`h;0P0B3@X3014<2@<040/800`03`X700d81@0G4Pl040/800/60`0@2`P04Pd:00P3000>
2@H040/8018=2P0C3P/201@?300O00d81@0B3@X040/800l:1`0B3@X04@`900/51@0?2@T03PP800l9
2@0:10@050h>014;2`0@2PX03PP801dG5`0J51@02`D5010:2P0?2@T050h>00d71`0B30`05@l?018<
300@2PX03`T9010:2P0A2`/04P`<010:2P0300l92@803PP801<02`D500L10@0>20P05Q0@00L10@0A
2`/03PP800/51@0G4A407aTI018<300:10@04P`<00`61P090`<02`D5014;2`0D30`04`T:008050X;
0P0C2@X04`0O5AH0;bDV020F5`0?1@H04`T:01882@0D2P/04`T:0147200@1PL04@L801D;300N51D0
3`D601D;300A1`P04`T:01882@0D2P/00`0B20T01P0A1`P04`T:01P>3`0J41406@l@01@:2`8040H7
00T02`@400d71`0=1`L06aDE00@0000C3@d04@/;010:2P0?2@T00`0=1`L0200I3a006a4B00l51P0?
1@H03@<400l51P0@1PL03P@50P0B20T01`0=0`@02`4201P>3`0E2``05`d>01882@0900000P0B20T2
0147200A01061`0A1`P04PP901471P0?1@@040H500l5100=0`804PP701@:2@0A1`H03P@300l5100@
1PD03`D401471P0@1PD00P0?1@@00`0@1PD04@L601061@0501061ACooooo000Kooooo`0<01<A4P09
1`P02@L801/I6P0B41407Q`M01LE5P1>C4d05A<D00L51P0?3@h05aDF0P0B3Pd02@0N6QT07ATH010<
2`0A3@`05A4@01LC4P0D40l04@d<018>3@0301DA400>018>3@0@30/04Ph=01@@3`0@30/01`<201<?
3P0B3Pd06QHE00D1000A3@`04Ph=01<?3P0D40l201DA400C00l;2P0A3@`05A4@00/71P0>2PT03PX;
00l=400C3`h04a0;01PC1`0Q6PX0>S<P0=?@^`3lmn40NGMR02d]700;30005aD>00/71P02018>3@05
01DA400J5QD04@d<01XF5@0D40l00P0:1PD02P0B3Pd04@d<01<?3P0B3Pd08QhM01`H5`0@30/0510?
01HB4@0G4a8301@@3`0401TF5@0N7A/06APF014@3P804Q4?00`04A0>03Lf=02:RHL09RDS014@3P0E
518040d;01XF4`0o>cP081`I01dI5P0E4@h701HB3`0[01XF4`0G4a0040`9014=2P0C3``03`/801dI
5P0W8b80[ZZW02PT8@0@3@/04`l<018>2`0H51404`l<01PD4@0I5A805A4>01@@3@0B3P/040`9018>
2`0H514081lM00X91`0K6QP030/9018A3`0510803`h<014@3P0?3P`040l=01<B400?3P`06QTG010?
3@0E51806QTG010?3P0@3`d051<A01<B4002010?3@08014@3P0B4@l05QDC00l>300<2`T040l=01@C
4@0B4@l601@C4@0I01LA4`0H4Q@0618D01LC500F4Q<05A4B01LE5P0?3@h07Q`M00l?3`0000006QXJ
01@C4@0E51805QDC01DD4P0B4@l04A0>01DD4P0B4@l05QDC01DD4P0C4Q005A@B01<C4@0201HF5080
51@B0P0E5A<01@0G5aD04Q8@01@D4P0G5aD04A8=00805QLB03005aPC01dN6@0G5aD07QhL02PX9P0[
:b/0AdM701PH600M7Ad061TE02DX7`0G6Q<05QTB01@G400O91h05AXE00`B3P0P9R@06b8R02L`;`0o
B4L0KWEd02<W9P0D61L07B4P01TM700G6aX07R8Q01PL6`0E6AP07b<R028V9@0L81l061hK01dV8@0P
:BH07BDU01lW:@0O9R`08BP_02<Z<P0K8RP08RX^02Ta=00N9RT08R/`028]<`0T;c<202D`<P0I02<a
<P0/>S/0<Cm00350A@0[?4@0;d1802Tj@`0V=cl0:S]202/l@`0/?T80<4960353A`0bA4H0;Cm10312
A00dATH0<dE503Y<B`0lCdd0>Da8045CDP0hBT`0>4Y>03e>EP02041AF`0Q04YKI@0hBE40?4eE041B
F@15Ef40?e=L03]?F00lD5L0@EEL04AHG`18G6<0AU]Q04YOI01?I6T0CV=X04IJH@1FJWD0G71k05M[
M01EJG00F6ea05EZK@1CJ6T0E6YX059YH`1BJF40E6]Q05E/I01KLFh0G75_05ibL@1PM7<0I7Mg0080
J7Yj00T0KGin07Z:RP1nSXh0NhZ;07b:R`20Rhd0Phf?08F?T@28TY@00P2:TYD0402=UIP0U9VM09JK
W`2HWJ40VYnS09fRYP2SY:T0YjR]0:^//@2a/;P0]KBl0;Je_@2m^/D0`;g80;jkaP34_/`20<c6e00H
0=;6fP3FbMd0f<_O0=c?h`3Od>D0hLoU0>?@iP3[eN`0k]S_0?;JlP3egOD0mmog0?_Qo03ni?d0o^Kn
0?kWo@3njoh0onoo0?gao`3nl_h0ooKo0?oho`3on_l0o_co1@3moOd00`3no_h0oooo0?ooo`030?oo
o`0`0?ono`3no?l0oo[n0?khoP3lmO`0o_;l0?o`o03nk?X0on[k0?oWo03lhoP0n]ke0?GLm03afo80
k=K]0>K@hP3ObMH0f<C?0=2ma@3=_/40a[bo0;nh_`2m^;h0/[2f0:RRXP2VWY`0W9NB09NCRP2?SH00
Ogi^07MjI@1kOVT0PhQb07InJ@1jPVd0OXEc07QoK`1[LV80KGAT06]cI01]MFH0KWU[06egK01^N6l0
KWUa06ehLP1YM6h0I6mY0P1PJfL06@1LIf<0DUeG04]FD014CdT0<Sde03M2>P0e@3P0:3@Z028^900b
?3<0:2hZ02X_:`0`=C40<3Hb02`c;`0Y<Rd0;CPb03M3?@0]>S<0=4<l03]:@`0jBD80BeYE03]:A`0`
@3d00P0bAD<0>P0[?S`0?De:02lm>P0L:B80<cde02H_9@0[<BL0<cXb024X8@0a>340;3</03U0>@0L
8a`09bhW02D/9@0T:b@082LP01lV7`0W<BT0:38_024/:00B7AT0624N01hW900Y<Rl06R0N01LK6P0N
8R408RHU024U900S:2@082LQ028X900Q9b<07bDQ01lU8`0Q9bD08bTW01<I6@0H7Qh08BLW02<X:`0I
7al0Ife/030d<`0I7A`06alN01lQ800J71/07b4P020P800S8b<07alO01XJ6P0M7A/06ahH01XM5P0I
71D201XM5P0701TL5@0F6A8061/D01`O600G6Q<05APA01LH4`0201PG4`0701LF4P0E51004a8>01HE
4@0=30P05QDA024P700201HE4@0501XG5@0C3@d061@C00l>300L71X00P0K7AX06@0A4a003@d;01TG
5@070`80208201LB4@0B3P/03`/8014=2P0F4Pl0510=018>2`0E4@h0510=01<?300E4@h04Ph;01@@
3@0E4@h05Q8?01@@3@0C3``05A4>018>2`0?2`P00P0A3@X03`0>2PL04Ph;059>B`0`;2T03PX7014=
2P0D40d05A4>014=2P0?2`P05a<@01HB3`0@30T081`I01LB3`0201PC4006018=2P0@2`P04@`901@?
300C3P/04Pd:0`0A30T03P0F4@h04`h;018=2P0C3P/04Pd:00l:1`0U81d05Q4>014<2@0C3P/03`X7
00/60`0A30T04Pd:0P0C3P/05`0B3@X04@`900d81@0D3``040/800d81@0A30T03`X701LA4@0<1PH0
4@/;010:2P0F41005a4A01PB4P0910@02@<302dW9`0U7al02@<300d71`0D3Ph03`T9008030H600<0
3`T9010:2P0@2PX00P0?2@T2010:2P0400h8200?2@T03`T900l92@8040X:01d04`h>01PB4P070@40
5@l?00L10@0E3`l02`D5018<300P6QX0=Bl_020J6P04000040X:00l92@0<1PH02@<300h8200D30`0
3`D600X00@0?1@H05@/<01@:2`0P5QL0=2X[02DK700B20T04`T:00l51P0201882@0@00l51P0@1PL0
4PP901<92P0I3a002P0101T?400@1PL05`d>01<92P0A1`P04PP901<92P0A1`P040H701<92P<05`d>
00T050X;0147200B20T03PD601XD500=1`L04@/;00@0000J51@00P0?2@T02@0>20P03@L700d71`0>
20P05P`=01882@0?1@H06a4B01<92P0200h41@0;00`20`0D2P/060h?01D;300F30d02`4200X00@0=
0`@05@/<01P>3`0B20T0100@1PL01P0B20T04`T:00h40`0B20L040H500`20@803`D400<04PP700l5
100?1@@00P0A1`H00`0>10<04@L601061@0200l5100301061@0A1`H040H500D040H55?ooool001_o
oooo00`040d=014>3P0F4a<0514A018?3`1<BDT07a`L04E2@P0J5aL0514A01XG5`0B3`l201@@3`0J
014=300G4a805A4@01DA400@30/04@d<00l;2P0B3Pd05Q8A01HB400C40X04Pl901<@2P0?2`H040`8
01DB3P0V8Ql030P701TE500<20L04`l?010<300A3@`05A4@010<2`0B3Pd201<?3P0Z010<2`0B3Pd0
4@d<018>3@0D40l04Ph>01D@4`0D3`d05A0;01PD200a;A/0A40]0;FaW03=bKL0C4Pi024N4`0g<b`0
5Q8>01@@3`0@30/06aLF07McLP1LF5L04`l>010<2`0A3@`05a<B01@@3`0F4Q40510@01D@4`0@30h0
6A@F01XF5@0F4`h06AH=02<Q5@0N70h04@l601PD3`0C3`h03``;0P0E4a404@0D4A00518@01<A3`0E
4Q40=C8a06ERH@0G5A<040h<01<A3`0C410030L901PD500H5AD0@3`j01@@3P0@30T04`l<0080510<
01005A4=01@@300B3P/05a<A01<?3@0F4Q004`l=018>300A3@/0510>018?3@0/:2H02`L501HB400<
20H040`:0P0F4Q00100G4a407ATG018>300B3P`201LC4@0I01DA3`0G4a4040h;01@B3`0F4a4040d;
01@A3`0F4a4030X701PE4`0;2@H0514?01PE4`0A3P`05A0=01HB3@0E40d05A0>01@?3P0F51<05Q4A
01HD4`0A3`d05A8A01@A3`0200l>2`805aHC00L04a8?014?300A3`/040h;01DC3P0=2`P061@@0080
6A@A01/05Q8@01PE5@0D4A406ALF018@3`0B3`l05QDD01DC4`0G5QD04Q4@01LF5@0H61L051<A01PH
5P0H5aD04a<A018A3`0D4a405A@B018A3`0I61H071/I01PH5P0G5Q@05QHD01TI5`0H61H00P0E5A<2
01PH5P2Y01LG5@0@40h05QHD01XJ600B4Q0051DA01<D400G61@04aDA01<D4P0K71X07QlM01<D4P0O
81l06a`J01@E500K7AT07R8M01TM5`0H71D05ATB01TN600J7aT06AhJ01TN700I7Qh05A`N05IJGP1Y
Kg006R8P01hS8P0Q9bH07BDS01PM700G7Q`08BTW01PM7@0K8B007BDS01DJ6@0N92@07B@T01dT9@0K
8R@092/`02D/<P0P9bh06b<Y02hf?00P:2d08bha02H`<`0T;c<09C0d02Hc=@0U<C<08c8b02Dd=00V
=cL09CHf02hoA01FJ700X[>g04=FH@0/?TD0;T1702m1B@0Z>d@0>4UB049CG00bADX0;d970313A`0c
ATH0=4M603U<C011E5H0B5]N03e?D`0eB4d0@eEL04=EG@18FF<0@UAN041AF`0oD5X0AUQQ04AFH@1>
H6d0B5]X04AGH@13EUh0@eMM04=GG019GF00BEiQ04YNHP1<H6D0CF5V04QKHP1FJW@0Ffmi05AXL01B
IVd0Efa`05I[K01DJVP0E6YW05I]I`1EK6@0E6]Q05Q^I@1JKVX0G6m]065dL@1TMG@0IGIe06QjM`1/
OGd0LH6007R8QP1jRXX0NHV807V7R02;UiP0R9BE08F@T@27TI80RI:E08^DUP2AVId0UYbQ09BJW`2J
Wj@0WjB[09jRZP2TYZh0Z:Ra0:b/]@2b/KX0][C00;Ne`@2l^LD0`;c90<2mb@36`Ll0cLOE0<o9e`3B
amP0e<OI0=S;g03Lcn40h<kS0=k=h@3Sd>D0jmG/0>oIl03cfo<0m]kf0?SPn03kh_`0oNCl0?gUo@3n
j?d0o^_n0?o^o`3nl?l0o_7o0?oeo`020?ogo`090?ojo`3mo?l0ooco0?omo`3noOl0ooco0?omo`3o
o_l0oogo0080ooko0P3oo?l0O`3on_l0ooOn0?kdo`3nl_h0o_7o0?o^oP3njod0o^Sl0?gVnP3ihOH0
mMga0?7Jk03/fNP0hLkL0=c9d`3B`<P0dl780<no``3<`<40a;Rj0;bd]02j/k@0/:ZY09nKU02MVI00
VYV<09VHRP2ATh80P89^08F8L`24RG80Q8Yc06mgG`1dO6D0OXE`07MoK`1XKf80IVeQ065YG@1fOW80
OHQl07EoMP1gPGP0LWie06]gKP1XLfX0HViW069^IP1MJF40Ef=K04iIDP12CDH0<Sdg03<m=`0_>C80
;SPa02/e;P0b>cD07RPR02L_;00[<c40=3`j03Do?@0b>cT0<3/f02Td<@0e@C`0:SHa034n>@0iAd40
>TU403U8@`0_?c/0:SXf03I7@P0`@3`0;Cdi02Ph=00W=2h0<Che02Lb:P0V<2H08R/Q02T_:P0X;BP0
:S0[02P]:P0T:RH09bdX02<Z9`0U;BP092lX024[9P0M9b407bTU02@/:@0Y<2h092/Y024X9P0F6aT0
7B8Q01TN7@0K7ah082@S028V9@0P92<08RLS02@[8`0R:R8082PR01lU8@0P9R@08BLV02<X:@0V:bd0
:2d_01hQ8P0L7b407b8S02DX9P0N8Al082<Q020Q800O81h061TG01hO7@0K6aX00P0L71/04@0M7A`0
7alM01/L5`0P81/07AhI01XL5P0K6aH07QlJ01`N600H61<06AXD01TK5@0H61<05QHA01PG4`0I61@0
5aHB008051<?01l06APD00`;1`0X9b<0C4]7024P700E51006ALD01<@3P0K61H05A@A01<C400A40d0
4a@@01/K600C4a004Q4>01TF500H5Q<0510=01@?300F40d05a8?01HA3P0E40d050d;018>2`0D3``0
5@l<018>2`0A30T04@d:00804`l<00L04Ph;014=2P0@30T09b<P01HB3`0B3P/061@A00<05A4>01X0
40`9018>2`0B3P/03`/8018>2`0H51402`L4010<2P0F4Pl0510=02<O7@0A30T05@l:01L@3@0@2`P0
3PT5018=2P0>2PL050l=01HC4@0<20H04@d;00l:200D3``03PT6014<2@805A0=00L04Pd:01LB3`0B
3@X04Pd:01@?300C3P/050l<00<04Pd:03X04@`9010;200?2PL03`X7018=2P0?2PL040/8018=2P0;
1P<050h>00l92@0A2`/040X:00/51@0<1PH03@L7018<300@2PX04P`<014;2`0<1PH04P`;01D?3P0<
1PD04Pd<00l:200A2`X03`T8010:2@0A30X03`T8010;2@0=1`H03`/:00h9200B3@d03`X900h8200B
30`091`M02LP800B2@X05Pd>00d51@0B20T05@h>00/51@060@40?3Hf04Do?`0>20P03@L701D?3`0K
5AD05@l?00`61P0?1`P04@L80P0C2@X05P0B20T04@L800l51P0D2P/04`T:0147200E2``04PP901@:
300B1`X03P<601472@0=1@D05P/>01462@0<0`D05P/>01472@0G3@l050X<01482@0@20T201892P0@
01082@0>1@D04`/<018;2`0?1@H04@P900X30`0B20T040L800l82@0@2@T06a4B00h8200=1@H040L8
00l7208040L800L040P901882@0?1@H04PP901hD5@0X7Ql07A<D00804PP900h04`T:0148200g;Bh0
GeEF01882@0D2PT04`T800l5100?1P@04PT701481`0B2@P040T800l81`<03`L800`03PD301471P0C
2@P040H501H<2`0Q5aH05P`;01471P0?1@@04@L601881`0?1@@501061@0401471P0@1PD03`D40106
1@804@L600<040H5ooooooooool04_ooool001_ooooo00D061@C014=300E4A00510?00h:2@0201HB
4@0S01TE500M6AP03@T801<?3P0;1`H040`;00T51@0A3@`05a<B014=300400004@d<01<?3P0@30/0
4Ph=01@@3`0A3@X0514901DB2@0C40L04a0801HC300H5A003@X6018>3@0A3@`04Ph=01`H6@0B3Pl0
40`;00h:2@0G4a804@d<00X61@0I5A@01P0@30/0500D3Q004`h;01<>200@30806AH501hK200W91D0
?SX^03@`9@0;1PD081XL01PC4`0:1PD03PX901DA400[9bH05Q8A018>3@0A3@`04Ph=0P0C3`h03@0B
3Pd0510@01@@4@0B3A405A4C01XF4`0H5@`06AP603lo9@14A2P08B4<01/I3@0K5a@00P0E4A0201HB
4@0301DA400D40l0510?00<0510?01404`l>018>3@0A3@l050lE018=4@0W8b@0BTI701HB4@0C3``0
5a<@01HC3P0D4@`05Q<>01@A2`0L61D06aLF00T51002014=300>01<?3P0@30/040`;020L6`1ACD`0
5A4@014=300W8b80:2@S010<2`0E4A007a/J00h:2@0B3Pd201<?3P0401@@3`0E4A005A4@014=2P80
5Q8?02L04Ph;01<?300A3@X03`/801LC400;1`@0920M00h:2@0C40/040/501`E4@0I510081PF028L
7@0?2@/030H801hI6`0B3Pd03@T8010=2@0P7aX05aPC00l@2`0?3PX04A0<01@B3P0G50l07a`G01HB
3@0N6A<05a8<01PC3@0G4P`06aLD010?3@010000<2l]00h=2`0I61H01@0F5A<06@0E51805QHD02<S
8@0T92806QXH01@D4P0E5A<04a<A02/[:@0O7ad03`l=010@3P0=3@/06QXH01`L6P0I6AL051@B01<C
4@0E5A<04Q8@01<C4@0F5Q@06ATG01DE4`0A4@l00P0F61D0100C5A808B<P03Pj=`0];b`201@F4`07
01DG500F61D05QPE01LJ600H71/05a`H01HK5P0201LL5P0F01@I4`0M8Q`06QhM02/_<00A5AP0:B`c
01dR9P0H8B00=Sln02D^;@0H8B008b`[038k>P0>5aH08BXY01/T8`0U;Rd0>45001TP8`0N8bT07b@Z
01dS:@808RT_00T07BD[02@]<P0K92T07BL/02Xe>@0Q;30092lc02Ha=@0V=3D00P0S<c805@0U=SD0
7c4a024e=00Z?D80?E5H096U[P0dBE<0;d5;03A7CP0bA4h0:Sa803I8E016F6@0;d5;02m2B@0`@dP0
<TI703E9B00hC4X0CV5W04ULH`0203a?EP0R04EHG`16F680@59L045CG@0nD5X0@E=O04aNJP1FJ7D0
B5UY04AEI012E600A5IP04QKH019GEh0AUYK04]OG`19GEh0BeiT059UK01DIfh0BUiW05=WK`1CIfh0
DfQ]05=XJ`1=HV<0DVQV059XI@1GKVP0FG1X05I]I01EJV<0GW5]069bK`80J7Qe00l0IgMd06alN@1_
Og`0L81m0761OP1dQ840MhN407V9QP24T900Phn?08:>SP27TI80S9JH08jHVP2<TiT00P2CVZ009`2H
W:D0W:2Y09bPZ@2UYk<0ZZZf0:f]^@2b/[h0]kG20;Rf``2l^/L0_k_90<:nc037`m40cLOE0<k8eP3B
amD0e<SF0=K:f03JcMh0g<kO0=g<gP3TdND0jmG/0>kHk`3bf_80m]kf0?SPn03jh_X0nn?k0?cTo03m
io`0o>Wm0?k/o`3ok_l0o_3o0?obo`3om?l0ooGo0?oho`020?ojo`80oo_o0P3oo?l30?oko`80oo[o
02d0ooSo0?oeo`3nl_h0o_7n0?g_o`3nk?l0oN_o0?cYo`3kiOX0n>7f0?CMl@3`fN/0k]SU0>SGg@3D
`lT0d/;80<Zk_P3=_/40a;Jh0<Fj^02o];80^:j/0;N^Z@2`Z:00XIn@09BEP`20PFl0MGQU07MjI`1m
P6/0Q8Uc08V>M`1oQfl0JW9K071hH01iPFX0Mgmb06=ZHP1YL6P0HFQP071gK`1eOgH0LWac07=mM01Z
MV`00P1SKfD03`1PKF<0I75W05]XGP1DHEP0CUUA04=>AP0g@S`0@DY504=<A`1:De00;C<a038h=P0a
>ST0<S`m030k?002030l?01202di>00X=380=40n03a8A@0c?c/0>4A003Y6@P10C4P07bhY03Q9@`0Q
<R`0:3Lb02hm=`0a@3T0:3D^02Db:P0Y=2`0:3<[024]900Q:b<0;34]02`^;@0X:RT09BTX02H[:P0W
;B/09Rl/02Pb;`0X<bl09C4]02<_:`0T;b/09BXX02DY:00R9RD082@S01@H5`0B5QD06AdL01hR8@0P
92<08bLV02HZ:@0X;RX08R/P01hX7`0M9al07R@Q01hT900O9BD07B4T024R9P0R8bL08R<U02HW:@0X
:RT09RHT01dM6`0Q8Al07AdK028R800M7A/071`J01/K6@0J6QP06a/I0P0L71X201XI5@0F01TH500G
5Q805aHB020O6`0R8Ad06QTE01lN6P0Y:2@08R4M01DD400G5Q8061LC01HE4@0D4`l05A@@024P700=
30P030/701LF4`0<2`L05A@@01/J5P8061LC00L05aHB01HE4@0F5A404a8>01LF4P0H5a<04Q4=0080
61LC00@05A0=01P@3P0H40h05`l=0P0F3P`02@0N5Q@06A4?01P@3P0H40h050`:018<2@0C3P/04Ph;
01<?3002018>2`07014=2P0P71T04Ph;00P40`0300004Ph;01HB3`02018>2`<04@d:01H040`900<0
000R7Q/03PX700P40@0=2@H05A4=01D=2P0G40X0614;014<200?2PH04Pd901XF4`0>2`T051<A00h=
2`0C4Q005QDC02<N6`0F4@h04Pd:0P0D3``01`0F4@h040/801<>2`0?2PL03PT6014<2@0=20D01P0?
2PL400d81@0:010;200E40d0100001H@40090`<01@0001XD500?2@T03PP800l92@8040X:01D03`T9
00h8200<1`@04Pd:02<N6`0L5a@02PD200/60`0?2PL04@`901@?300@2`P05A0=00h:1`0<2PT01`H4
014@3P0710<01`4101D?3`0A20T00P0C2@X01@0D20X04`L901882@0>1`L05Q0@00803`T900X06aDE
00h8200;1@D03@L701LA4@0C3@d02`D5018:2P0B20T04@L80P0B20T00`0A1`P040H7014720040147
200600`4100?10P03`@800l5200@1@T05@X>1@0A1PX0200@1@T02`<501H@400D3Ph01P4101H@400=
1`L01`820P0B30`02@0P6QX040X:018<300B2P/05`d>00l51P0>10D040H704Y0@@0201061`804@L8
0P0B20T03@0A1`P0308300/10P0C2@X06@l@01P>3`0C2@X06a4B01@:2`1:@440OWAe01D;2`0@1P@0
0P0B2@@01P0?208030D000/30@0?2PL03PT600d91P803@T800`03@P8018:200?1@@04`T801061@0>
10<07aDD01D;2P0B20L040H501881`0A1`H200h40`0;00d30P0@1PD04`T801D;2P0B20L040H500h4
0`0A1`H04`T801881`0@1PD05?ooool001_ooooo00<04Ph=00l;2P0?2`X00P0B3Pd0900?2`X030P7
014=300<20L00`0000l;2P0<20L020@301DA400/:2L04@d<00T61@0J5QD04`l>01HB4@0A3@`040`;
014=300=2@H0514;01<@2@0>2`@040d701@A300A3@X06ADB01`H5`0F4Q403PX9010<2`0300004Ph=
014=300810<02`L601@@3`L040`;018050h@01dG5`0J5A405Q8901XG200L6@P07Q/<00H2000h=2/0
:B@R01<=3`0?2P/01`<2014=300>2PT040`;00d9200D40l2014=30804Ph=01004`l>01DA3`0C3``0
4@d<018>300E4P/05Q@7024P2@1eMUL0YJJ706m^EP0b<2408QlH01LC400F4Q405A4@0`0D40l0500C
3`h04Ph=01<?3P0C3`h04Ph=014=300B3A0061<G00d8300J5QL081`M00l;2P0I5A806aLD01PD4@0C
40/05A8=01@A300400004@d<0P0D40l01P0A3@`05Q8A01HB4@0@30/05a<B04A0?`80510?00@07QXI
03Te=00P71/020@30P0F4Q401P0E4A006QHE01LC4P0C3`h061@C01DA40804`l<03d061@A01LC400B
3P/04`l<014=2P0D40d030P501TE4P0=2@L05a<@01@A300C3`/03`/:01H@400L61T04`hB00d8300K
5aT06ADD01/G5P0=2PH00`8001XJ600<3P/04Q8@01HF500E5A006APD00`;1`0I5a808AhI01<@2`0H
5A002`P300X91@0O7Q`0;2/Y07elNP0S8R002PT701<B400G5Q@06QTG01TH5P0D4a404Q4?00h>300H
61H06ATG018B400>3P`03`l=01XJ600>3P`02PX801LG5@0N7Q`07AdK01/K6@0H61H05QHD008051@B
00d05ADC01LG5@0F5Q@05aLE01PH5P0D51804Q8@01LI5P0K7AX04Q@A02h`;@17BDH0:bdZ00805aTF
0P0H6QL06P0I6aP061/I01LK6P0H7AT061dH01PM5`0G71H0724K01/P6P0F6QT09RX[024U:00F6B00
5Q/O01TR8@0R:bX072DT01dV9@0Q:RT0:34`02</:`0H8B004a`K02</:`0M9RD082LZ0P0R9b/0300N
9BP082P[024Y;00M9RT0<C/m020Z;00M9bT0=D1202Td=P0T<SD09C<f02Dc=08093@c03X08SDc02<e
=@0W>CT0;3m402@h?`0mDEX0:Ce702doB@0gBU40<TA>02i0C00/?TX0=DMC0312C00bAD`0=DQ>03U=
CP0jCTd0?51?04IIG`10DeX0>4]B03mBF@17FV40@UAN04=EG`12E5h0?4iH03mAF`1;GFL0F6Yg05=T
M01;G6/0@UAP049DGP16FEh0B5aM04MKG01=HF80BemP04]NI01DIfh0FFac04iQJ01BIF`0DfI]05EX
KP1FJFd0CV9S05AXI`1FJVP0EV]V05U^I`1JKfP0DVMP061cK`1SLg00J7Qe0P1YNGH02`1_Og`0L81m
0761OP1bPWl0M8B107R8Q@1jRXL0P8b<08:>SP24T900R9:C0080R9:D0P2CVZ004@2EW:80UYZS09^O
Z02RYZl0YjVe0:^[]`2^[[X0];C00;Rf``2i]l@0^kW60;nkb@32_/`0al?A0<g7e@3>b=H0e<WG0080
eL[H00T0el[K0=c>g`3Qd>80i]?W0>gGkP3_fO00l][b0?CLm03fg_H00P3jh_X02P3li?`0oNOl0?cY
o@3mjoh0o^go0?g_o`3olOl0oo?o0?odo`3omol20?oho`80ooWo0P3on_l30?oio`0k0?oho`3nmol0
ooKo0?oco@3nl?d0onon0?k]o`3ljOl0o>On0?[Tn`3hh?H0mMgb0?3Ik@3/dnH0im7O0=k=e@39^/40
d<760<joa03?`lD0`KFf0;nd/P2f[:T0[jJQ0:nVW`2[YI`0UI>408R9M`1bMF80JfiK079eHP22Qg<0
KG9N07f2K01dO6H0IfmJ06YbF`1RJED0NX9g06M^I`1dNg@0KWE^06]bJ`1[MFd0KgYb06iiL@1SKVH0
FfQO05i[HP1OK6<0GfaR055NE012CdH0?TU103Q3>`0`>cD0=3dh03<l=`0oB4D00P0/<S001P0b>cX0
>TA503<o@00a?Cd0<clo02hj>@808bl]02@0;c/h02`h=00b?SX0<3`h034m>@0eA3l0:STd03a;AP1J
IV80Hg1Z02<`:@0X<bd08bhW02D_9`0T;RH08R`S02P_:00[<2`0:bd/02X/:`0X;2/0:Rl]02/a;`0Y
<Rl0:S@`02Pc;`0V<Bd09S8^02Td<00P9B<07b<R01XN7@0P92<07b<R01LK6P0L81l2020T8`0F01lS
8P0P92<082HR01hW7@0L9Qd072HN01lU8P0P9RH082DX020T9`0M7R8071dQ020Q8`0W:BP09RPW02<S
8@0L71X08B4O01dM6`0Q8Al06a/I01dM6`<071`J0P0M7A/0300Q81`05aHB01/J5P0P7a/07QdI01dL
600H5a<04a8>01hM6@0[:RH081lK01DD40806APD00X05aHB01DD400F5A408R4M01`K5`0D4`l040l;
01PG4`0Q81`06aXF0P0H5a<02P0G5Q805A@@01@C3`0A40`051<?01LF4P0D4`l06APD01PG4`0E40d2
01P@3P0:01L?3@0F3P`05Ph<024I5`0J4Q005`l=01TA3`0G3`d05@h<018=2PD04Ph;00H04@d:00h:
1`0N6QL04`l<01DA3P0B3P/2010<2@<04@d:01004Ph;02LS801NFUL0:RHS01DA3P0>2PL05a<?01P@
3@0D3@L04P/501@?2`0F4@d04@`800L3000?30X06APF0P0^;B/00`0B4@l0:RDR01XE4P02014<2@04
01@?300I51404@`901<>2`803PT600<04`h;014<2@0?2PL01@0?2PL02`0A30T040/8018=2P0=20D0
4@`902LR7`17@D4040X:01D?3`0P6QX0208200803PP800X03`T9010:2P0@2PX03`T900h8200E40d0
6A@A03Pc<00]:2D04@`90P0>2@H0300B3@X05Q4>01<>2`0I51404`l<010>300:2@L04A0>01@@3`0:
10@03@L7010720<04PP900l04PH80147200?1`P03`T901@>3P060@402P@4010:2P0<1PH02P@4010:
2P0>20P02`D501<;2`0C2@X00P0@1PL3014720<04PP90P0A1`P07P0E2Pd081DI02<H700A20X04PL;
00/0100@1@T04PL;01462P0@1@T03`@800h31`0@1`T05@l?010:2P0D3Ph05@l?01<=3@0@2PX030H6
00L10@0A2`/01P0000l92@0=1@H02@0001H<3@0>10D04@L801D=3@8040H70P0A1`P201882@0?00l5
1P0B20T05P`=01H<3@0C2@X03@<400L0000900003P@501H<3@0T6Q/03P@400l50`0E30L04PT40080
30@100d05`l=00l:1`0?2PL03PX700d9200<20L03@P701<;2@0?1@@04PP701471P0;0@004PP70080
40H500L04@L601<9200A1`H03@<201471P0?1@@040H5008050X90P0A1`H01@0@1PD04@L601<9200D
2PT040H501Cooooo000Kooooo`0D018>3@0K5aH04Ph=00l;2P0C3`h030P701DA400C3`h0<2`[04U5
A00F4Q4040`;01DA400D41003@T800h:2@0A3@`030P7010<2`0D40l3014=300900d9200B3Pd03@T8
01<?3P0@30X03PX801HB400L61H02@D40080510?0P0D40h01P0D40l03`/:01DA400@30/05Q8A01<?
3PD04@d<01@04@d>018<400J51H04`d<010;1@0A3@<03`/101HB2@0I5@h06QD@04i9B@0C3Q405Q4D
01@@3`0J5QD05A4@01PD4`0F4Q4040`;018>3@8040`;01404Ph=01@@3`0D40/04Q0601DB2`0D4@X0
4a0501dL2`1:BRl0alRW0?oohP2`/ID0<S4N01hL3`0F4`h05Q8A01@@3`0201<?3P80510?00<04`l>
01@@3`0D40l00P0C3`h0C@0D41002PH801@?4P0D41405A4B01LC4P0H51806QHD01HB3`0B3PX05A4=
01@A300H51<04Ph=010<2`0O6aX0:RHU01<?3P0=2@P06ADD00h:2P0K5aH03PX9018>3@0N6aX0>SHe
02XV9@0=2@P03PX901DA400G4a8081`K01XF5@0B3Pd06QHE01@@3`0G4a004Ph;01LC400J5Q<05Q8?
024M6P0H51404Ph<014=2P0J5Q<05a<@01XG5@0D4a80410@01@C5@0C4QH040hB01PE6@0=2Ph0510B
01<?3P0K5QD05a8>01LE4@0B4a405APH01LJ600D5aL04Q<B01DF4P0I61D0K6]X04E3?`0N71L04a4=
01DB3`0F5A<04A0>014@3`0S8R005QDC008051<A00L05QDC01PG5@0G5Q@051<A01<B400D51805QHD
008051@B00`071`J024Q7`0n?Sd04A4?01dM6`0L71X02`/901HF500H61H051@B01<C4@0F5Q@201PH
5P0<02@T8P0K6aT05ADC01<C4@0G5aD06ATG01LI5P0P8Ql06adJ02<U8P0X:RL03a4>1@0H6QL0>P0G
6QP05QXI01PM6@0J7aX06QlI01TN600J7aT051TC02HZ:@0A5AH09RX]01`O9P0I7R408BXY01LP7`0H
8B006B8Q00hG5P0M9RD041TH01XS8P0R:bX06R<R01lX9`0L8b<08BHX024V:@0O9RP082PY02<[;P0S
;2d0;3Hf02/e=`0S;Bh07b/Z028^;`0S<C@0938e02Dd=P0V=SH09cLf02Hi=`0[?Cd0:S`l02Hi?@0^
@DP09SU002m3C00]@4L0>DaC02m2B`0eAe<0;3i:0394D00^@4/0<49<03M:D00kCU8203a@D@0R03mB
F010DU/0?e9J04EGH01;GFH0AeUS045CG@12E5h0?U1J03mAF`19FfD0DF=_05AVM01>H6h0B5YV04UK
I@1:GF<0BUeQ04YNH01?HVD0BUeQ04MJH01=H6L0D6=Z05AWK@1CIVd0E6M]05MZL01HJfh0EVY[05EY
J01IKF/0E6UT05=XH`80FVmX03h0Gfm/069bK`1[NgP0K7ai06YjM`1]OGX0L81m0761OP1bPWl0Lh>0
07J6P`1hR8D0Oh^;082<S022SXh0Qi6B08ZDUP2<UYP0Yjjd09BKX@2EW:80VYjW0:2T[@2Z[[L0Z:^e
0:f]^02`/;/0]KG00;Vg``2k^LD0_;[60;nkb032_//0al?@0<c6d`3=am@0dLWF0=C9e`3BamD0e<OH
0=c>g`3Re>D0imGX0>cHkP3^fO00l=Wa0??Kl`3dg?@0nN7j0?WRnP3jho/0o>Kl0?_Xo03mj_h0oNcn
0?k]o`3okol0oo3o0?oao`3om?l0o_Ko0?ofo`80ooOo0P3on?l0;`3omol0ooKo0?kfo`3nmOl0oOGn
0?oco@3ol?/0onkl0?o^o`3ojoh0o>Ol0?[TnP3hhOH0m=cb0?7IkP3[dnH0i/kO0=k:eP3Gb=00b;W1
0<bna@36^[h0bko10<6f]@2i/:/0YinG0:6IT@2SVi40V9:608B4LP1lOV/0MGQU07UlJP1mP6h0NWm]
07UoKP1mPg80I6YJ05aSE01]M6D0KgIX07AkL`1aN740NH1i079kL`1aNG80JgE]0080J7=[02@0HFeT
05YWGP1LJF00FfQO069_I@1BGeD0@e1704A?A`12CDD0>TDo03e6@@0a>SD0>44n03m5@`0m@d40>dA3
03e7B00`?3d0;3Ph034m?@0b?Sd0;3Pf02hj>00hA440<clk03Q4@00b?SX0;CTe02Te<@0Z=c80;STe
05QTH00`?3L0:C<]028/9`0P:282020Y8@0402D/9@0`=Rl0;34]02`_;P80:Rh]00l0:Rl^02X`;P0Q
:RL092h[02H`;00T;b/08bhZ02@^:P0S:2L092PW01dQ800K7ah09RXY01/O7P0O8b800P0S9bH2024U
9005028X900P:B007bTP01hX800P9R<00P0P9BP03`0g>ch0:2T]024R9P0O82408R@S01`N7@0P81h0
6a/I024Q7`0M7A/08B4O01/K6@0L71X06a/I01XJ600201/K6@0F01`L6P0L6aL061LC01`K5`0N7AT0
7A`H01PG4`0E510051<?01LF4P0O7QX06QTE01LF4P0J6AD06APD01LF4P0F5A405A@@01HE4@0E5100
6QTE01PG4`8051<?00D04a8>01DD400E510051<?018A3@02014@308051<?00@04A0<01@C3`0D4`l0
5A0=0P0G4@h0100F40d05@l<01D?300I4a0201<=2P0601PB3`0F40d050h;01<?300B3P/04@d:0P0B
3P/02@0C3``05Q8?014=2P0/:2D08alL00h:1`0A3@X03`/8010<2@02014=2P0E018>2`0C3``04Ph;
01hJ5`0<20D04Ph;014=2P0D40d05Ph;01<<1P0B2`D050l;01D@300B3@T061@A00`91`0W9R@0Ti:@
0::QW`0>3@/061<@00804@`900T04Pd:014<2@0D3``040/8018=2P0?2PL040/801PC400I51401P0@
2`P03P0E40d03@P501@?300@2`P03PT602@O700`:RX05Q0@014<300A2`/050h>010:2P0>20P03`T9
0P0@2PX05P0?2@T03PP800h91P0?2PL04`h;014<2P0=20D03`X7010;200B3@X05Q4>018=2P0G4Pl0
4@`905UFE@0S8Al02`T701hI600G4A4040X:0107200A1`P201882@0:0187200@1PL04`/<010:2P0;
1@D04@`<01`F5P0<1PH03`T900d71`8040X:00P03`T901<;300B20T03`D60147200E2``05`d>01@:
2`804@L80`0C2@X01`0G30l02@0201L<400B20/0304501@93@0C20`01@0A1PX03@0B2@/0;BLW01lI
6@0=1`L03@P801D?3`0>20P05a4A018<300H4Q803PP801D?3`0?1`P00P0B20T00`0D2P/05P`=01<9
2P0201061`804@L80P0B20T04P0=0`@06a4B02DK700C2@X0308301`B4`0h;Rl03@<401@:2`0<0`@0
50X;01<92@0@1P@060l:01071@090@004`/8030X9P8040/800/03PX800d9200<20L03@P801081P0>
10<04`T801L=300C2@P04@L600l5100200h40`0?00l5100A1`H04@L601<9200G3@`05@/:01471P0?
1@@04@L600l5100A1`H03`D401471P0D2PT03`D401Cooooo000Kooooo`0401@@3`0O6aX05Q8A00l;
2P804Ph=00l03PX900T5100b;Rd0GUYI014=300<20L01`<203lk>P0R7Qd02`L600X61@0S7ah030P7
014=300@30/00P0B3Pd04`0?2``03PT>00d83P0F4AD04@`@018>3`0P71d0=30`00d9200H51<040`;
00P40@0<20D04Ph=01<?3P0W8b806aLF01TE500<20L01@0B3Pd0500B3Pl05Q0E014;3`0@2P`05a8>
01TD3P0D3`T040/601/F4P0;1P<04@`>00h73P0<20T08alN01<?3P0D40l030P7014=300G4a804Ph=
0P0@30/04@0B3Pd0510?01DB300D4PH05Q<:01LD2`0D4PH081l=03Lg7@1hNET0/;6?06QYC00@3`00
5aD801PD3`0E4A00510?00<04`l>00<04@d<010<2`0A3@`00P0B3Pd0D`0A3@`05Q8B00@00@0H51D0
3PX;01HB4`0@30/04@d<01@@3`0B3P/04@d:01@@3@0D40`01`<200d9200H51<0510?028N7@0G4a80
4@d<01@@3`0H51<06ADD00L30P0C3`h06ADD01HB4@0@30/07QXI01XF5@0>2PT04Ph=01LC4P0C3`h0
3PX9018>3@0?2`X04Ph;00l;200@30T04Ph;01LC400R7Q/0510=01TE501:AT<0PGej01lK600920H0
1@T<01@I7@082a0010L<01<D6P0=318071/Q01LD600D40l07aXG01XE400J5a803a4@01@H6@0=4A80
8bLX03`o@00F61L08R@S010A3`0G5aD061PF024P700=30P04a8@01HE4`0N7A/00@0001PG5@0@3`d0
5A@B01@C4@0C4Q0051<A00805A@B00@03@d;01<C4@0D51804Q8@0P0?3`d0100J6QP08b<Q020P7P0K
6aT201PH5P0501TI5`0F5Q@051@B01<C4@0D51800P0E5A<201TI5`0701LG5@0F5Q@05aLE01PJ5`0J
71T07AlL01@F4`0401TK608061XG00D05aTF01LJ600G6aX061dI01XO6P0201XO6@0I01PM5`0`=Bl0
HfMV02L[;00D61/06QdT01/P900_>3L09Bh]01XS8P0B6aX072DT01DN7@0Z<c806b@S03m8A`0a>ST0
1Pl>02D];00M8b<07bDU024X:00R:bX0:S<b03@m?00202@^;@0602hi>00/>3H0;3Pg02<a=00U=3T0
:CPl0P0V=SH04@0Y?3X08S@d02`n?P0[?T40:Ca202@g?P0/?dP0=4M>03U<D`0bAD`0>4YF03U;E`0l
CUX0;d5=0353C`0gBE80>diD0080>diB02/0>diE03mAF`11Ded0@E=M04EGH@17FF<0B5YT04]MI`1:
G6H0BE]U04eOJ@1<GVP0BE]W04QJIP18FV@0BEaS04QKHP15F5`0B5]O04]NHP19G600BeiT055TJ`1?
HVT0BEaR055TJP1ML7H0G6mc05AWJP1AIFH0CV9Q059VI01IKF/0F6eX05I[IP1LKfT0GFeZ065aKP1[
NgP0K7ai06YjM`1^OW/0Kgml0080L81m03L0LX9o07B4P@1fQX<0Oh^;07b8R01kQhL0PH^<08RBU02<
UYP0VJ2V09:IW`2HWjD0XZJ_0:2T[@2OXj`0Z:^d0:b/]P2_[kT0]KFo0;Vg`P2j^<<0_K_60;nla`31
_/T0a<7<0<W3c`3:a=00c<CA0<k3d@3?a=80dlKG0=c>g`3Pd^<0i=?V0>WFk03[f>h0k]S_0?7Il@3b
f_80mmoi0?OQn03hh_T0n^Ck0?WVnP3kj?`0o>Wm0?cYo03nkOl0onko0?o_o`3olOl0oO?n0?oco`3o
m?l0ooGo0080ooCo03P0o_Co0?kboP3ml_h0o?;m0?gao@3nl?d0o^cj0?kYnP3njO/0o>Oj0?[Tn@3h
hOH0mMgc0?7JkP3/e>H0i/kN0>38eP3C_l`0c;o90<:e_`37^/80_K:f0<Bj^`2j/:h0/:VQ0:FOU02Q
Vhl0VI>507ahJ01mOfX0N7]V07MjI`1oPW40PHEd07]oL01lPW@0MG]_07EkL01OIe`0IfiV06YaJ@1f
OGH0Nh9k07ElM@1_NG40LWad06QcJ`1OJV80HFaT05i[HP1HIE`0EfAK055NE@16DdT0?4To03M4>`80
?DQ000@0>D@n03Dn>@0f?cX0>44n0P0d>SP0;00mATD0>dE602lk?00X=3@0:cLg02lk>P0]>CL0F6AR
04eIEP0b?SX0<Cdi02lk=`0`?3P09c8^02Td<00N:BD0;cXf02lh=00Q:RD09bdY02@[9@0S:R<082DO
020U7P0Y;RP0;34]02/_;P0Y;B`09bd[02D[:@0T:RP07bPU02D^:`0Y<Rl09S4]028]:@0P:BH07R<R
028V9@0X;2/07R8Q02HZ:@0I7A`08RHU0P0U:BP202<W9P0D02<Y9@0S;2@08R`T024Z9@0Q9bH07R<V
01dR9@0]<C@08R<W01lP8P0P8R408B<R01`N7@0O7ad06ATG01lO7@0M7A/08b<Q01dM6`0K6aT301XJ
60806a/I00H05QDA01`K5`0K6QH05aHB01HE4@0H5a<201`K5`0401DD400F5A4061LC01LF4P8051<?
00/05A@@01@C3`0B4@d05aHB01DD400I61@061LC00/:1P0D4`l06QTE01DD400201@C3`804a8>0P0D
4`l01@0A40`03Pd900l>2P0@3`/0514=00805Q4>01D05A0=01@?300D3``05A0=018=2P0C3P/050l<
010;200B3@X05A4>01@@3@0B3P/040`9014=2P0C3``030P502DQ7P0@30X02`L401DA3P0B3P/00P0@
30T3014=2P0K018>2`0O6aP01@4001LC40070`002PH300`91@0C2`P050d701D>200A30P040/7018=
2@091@804a0>018A3`0J6AL06APF00/:200?2PL040/801HA3P0E40d03`X700h91P0@2`P04Pd:0080
3@P500<04Pd:010;200A30T01@0A30T03P0D3``03@P5018=2P0D3``03PT6014<2@0F410030H605I@
D00L5QH05Q0@01LA4@0>20P03`T90P0@2PX01P0?2@T03PP801<>2`0L5a@02`H300l:1`8061<@00d0
4@`901<>2`0D3``03`X7014<2@0;1P<03@T900/71P0810<03PT9014;2`0K5AD040L800804@P900/0
4PP90147200@1`P03`T900h8200B30`02@<300d71`0>20P030H600h82002010:2P0800h8200@20T0
40H700l51P0B20T05`d>01T?400E2``20147200<01<92P0D2P/050X;01@:300>0`L02`0401X?4`0;
00@06@hB00l4200@1@T04@H:0P0C20`04`0D2@d03@D702LQ8@0G4A404@/;00L10@0B30`020<301H@
400?2@T04@/;00P20P0>20P040T901D;300c:BX0BT1101T?400?1PL00P0@1PL2014720804PP900l0
308300d3100?1@H04`T:01L=3P0L4Q<081HG00L0000@1PL01`0001@:2`0<0P803`D301D<1`0B20H0
0P0<10400`0G3`d03PT600h91P0300d9200I00h92@0A20T04@L601881`0C2@P04@L600h40`0@1PD0
3`D400`20@0;0@003`D401D;2P0<0P4050X901D;2P0@1PD03`D401D;2P0=0`804PP700d30P0?1@@0
5@/:00d30P0Dooooo`006oooool04`0@30/0510?018>3@0A3@`05A4@01PD4`0B3Pd05A4A00d9200O
6aX03PX9018>3@0D40l07a/J010<2`0<20L03``;00T5100;1`H00P0A3@`2018>3@0C00h:2`0E41H0
71LN01<>500=20h050lC01HB4`0I5AH02PH5018>3@0D40d06ADB01HB3`0<2@P05Q8A07mkNP18A4<0
0`0001LC4P05018>3@0D018>3`0H4aP01@0500`62P0H4Q405A0=00`70`0E40d020<000d71`0C3A80
9b0W020K7`1=BDP07QXI00h:2@0J5QD040`;00/71`0B3Pd2014=300?018>3@0C3`h071PB01HD200A
3PD05a@=01DB2@0H5PT061L6024Q1@1;C2d0>3PO014?000K60l0510<00<0510?00H04`l>018>3@0@
30/040`;014=300C3`h2018>3@0N01DA400@30/0510?014=300I5A@05a<B010<2`0D40l04`l>018>
2`0D40d04Ph;02@P7`0>2PT0510?03di>01IEE@06QHE01LC4P0D40l040`;00h:2@091@@06QHE00@0
000:1PD03@T801LC4P0D40l05A4@0`0A3@`2010<2`0U00l;2P0?2`P04Ph;014=2P0?2`P05a<@01XF
4`0O6aP030P5010<2@0e<Bh030P701LG5`0:3a<03A@J01/R:00P9B/05QTQ014A6@2DTiT0BDI:00`8
1`0B3@X04`d8018?2P0?4a804AHI01`Q901WK6l0UY^K02/_<00I7Ah04A@C01`N7@082PT01`L601/K
6@0201HE4`0401LF50071P@051<A01DD4PH051<A00l05QHD01/K6@0M7A/06a/I01HF500D5180:b/Y
01XJ600<30X04a<A01DE4`061P@05QHD01TI5`0G5aD00P0C4a40100F5Q@04A4?01PH5P0J6QP301PH
5P0501LI5P0I6aP071hK01@F4`0K7AX00`0L7Q/0600K7AX06Q`I01XL6@0I71X05a/J01LL600I7QT0
6QlI01/P6P0G71H08bPR03a0?`0L82402`lB01DH7`0O92P092d/01DN7@0G81l07BHU02`e=00F7ah0
4a`K01`U9080;SLf03<092d/01dU8`0O9B<082HT02@[:@0U;R/0;cPe04YDD@1@FeL0?4M302hi=@0/
>3@09c<a02Dc=P0[>Sl0;Ci102@f=P0Q<c<0:C`j02Dg=`0]?cl0<dE802Hg?P0[?T@0<TE<03E8C`0d
Add0<TE<03=5D@0nD5`0>D]I03E7D`0gBED0>diF03iAE`0oDUH0?e9G03e?F@0mCe/0>TaH03a>F013
EEl0@UAN04]MI`1>H6X0BUeT04IIH018Ff80AUQQ04]MI`18FV@00P17FV406P14Eed0?e9H04EHGP17
FV00BEaR04mRJ@1EJ6l0CV5X04]LH`1CIFT0GFmc05U[K`1CIFP0FF]]06]mO@1GJVT0FVe[05e`KP1F
JFD0GG1/069bL@1SLg80JGUh06YjN@1/O7/0Lh>20`1aPH00301cPh80MHF407N7QP22SXh0Oh^;07f9
R@21Rh`0QHnA08RBU02AV9h0VZ6W09bSZ@80XjN`00/0Wj>/0:NZ/`2/[;H0[jni0;Bd_P2h]/40^[S3
0;jla`30_LP0`[o:0<C1c0020<O1c@0<0<W1cP37_l`0b/;?0=C9f@3Kc]l0g]3Q0>;Ai03We>X0jMK/
0>gGkP3_fO00lM_b0P3fgoT03P3hhO/0n^Ck0?_Uo03li_`0nnSl0?cYo@3njoh0onco0?o]o`3okol0
oO7o0?oao`3ol_l0oo?o0P3ol_l0Q03mlOl0o_3o0?g`o`3ll?h0oNon0?k/nP3mj?L0nnCf0?[SmP3i
h_H0n>3f0?KNm03bf_00kMKZ0>S@h@3QbML0g<CB0=:oc03<_//0`KBn0<Nl``31][X0aK^l0;:ZYP2[
Y9`0Y9jC09REQ02?S7T0NGMT07AfH@1fNF@0Nh1/07n3LP21QG@0Q8Uj07j4N01mPgT0Z[6X08B;Q01g
OWL0LgYc07R1O01eOWT0KGIa07=lM`1_N7<0IG1Z061[I@1QKVL0GV]T05ETG@1DHe`0CUeE04QEB`10
CD<0?DY1049=A@11C4@0@Da603M0>`0mAT40>D8o03Dk>@0l@T00@T]:03U3A00c?d00<3`l034m?@0b
?Sd0<Cdk04QDDP0oBdP0:3@`02Te<@0W<bl09S8^01DP700Q:RL0>T=001HO700c>CH0;38^02L/:00X
;BP09b`V02@V8@0O8Q`09BXT02T^:P0X;R`09R`Z02D[:@0S:BL08BLU02H/:P0Y<2h0:C8_02L`;@0T
;BX08b`Y02T^;@0H71/08bLV01hR8@0/<2l082@S02HZ:@0W:bX092PW01lS8P0L81l06b4M024Z8P0Q
:RD082TT020V9@0M8RD0724T01dQ900J6ad06a`N01hP7`0M7a`06adJ020P7P0I6AL07alM01dM6`0U
9B<0820N01lO7@<07AdK00D07QhL01lO7@0K6QH07A`H01/J5P0201PG4`0901XI5@0L6aL06aXF01DD
400G5Q8061LC01HE4@0E51005QDA00806QTE00P05QDA018A3@0=30P04Q4=01<B3P0=30P040l;014@
30804a8>100D4`l01P0C4Ph04Q4=018A3@0A40`04Q4=01DB3P805Q4>00H05A0=01@?300D3``050l<
01<>2`0D3``2018=2P0401lJ5`0G4a005A4>018>2`803`/800L04@d:03Pd<@1EDDh0510=00h:1`0L
61D030P500804Ph;0`0A3@X02`0@30T04`l<00H2000F4Pl02`L402/W900c<2`05@d:01D>200D3@L0
4@`8008040/700h05Q8?00`91`0E51804A0>01TH5P0R8Al050l<014<2@0D3``04`h;010;200C3P/0
3`X7014<2@803@P500<03`X700`7100A30T01@0A30T03P0B3@X04`h;01@?300D3``04Pd:010;200@
2PX04`d=03D_;`0G4A40@cdm00`61P0>20P03`T90P0@2PX04P0?2@T03PP800`7100?2PL02`H300`7
100=20D030L4014<2@0C3P/050l<00l:1`0A30T02`H300d8200N61P091hN010:2P80100000@03`T9
01892P0B2@X04PT:0P0A20T00`0?2@T01P0001D?3`0301<=3@0300d71`0>20P03@L700803`T900@0
40P801061`0?1@H04PP91@0D2P/02P0C2@X04PP901882@0<10@0<bP/00L0000;00@03P<701L<400D
2@d401462P0C01872`0A20X03PP800@0000f<3003PP8014;2`0H4Q807aTI018<300=1`L030H601XD
500E3@d01`0001lE5P0Y7b0050X;0147200201061`804@L80P0B20T03@0?1@H03P@50147200H3Pl0
5P`=00/20`0D2P/0;R@U01P>3`0700003`D601T?3`0@1P@00P0B20H00`0?1`D030@200/30P0200`6
1P0900d9200=2@X03PX;010;2`0B2@X04`T801471P0?1@@040H500803`D400P04@L600l5100=0`80
3`D401<9200?1@@040H501471P804PP700L04@L600h40`0D2PT03P@301061@0G3@`03@<201Cooooo
000Kooooo`0f01<?3P0A3@`05A4@01DA400@30/04@d<02/W9P0e<C004Ph=00T51@0E4A003PX901/G
5P0B3Pd04`l>00d9200@30/04Ph=00/71P0B3Pd040`;014=300B3Pd040`=04M2BP1oNX407APO014<
4`0F4AL02`H:00d92P0H51<03`/:01@@3@0?2`P02`L4018>3@0@30/071PG01PD4`0C3`h03@T801<?
3P0B3Pd03@T8014=300J5QD04Ph?02LP:00I4QT071DK01hH6P0G4A803`X80P0C3@h08P0F41<04P`B
01D>5P0B31009B4P00h:2@0?2`X05Q8A00/71P0D40l04Ph=014=300?2`X0510?02DQ800Y9R408QlH
00h:1`0E4A404`l?010<200H5@T04a8401`K200M6`/05A<:01PE4P0D40l02`P701DA400F4Q403`/:
01LC4P0@30/2018>3@0<01@@3`0E4A004`l>00l;2P0J5Q@03PX801dI601>BTT0CDU8018>3@0D40l0
4`l>0P0B3P`02@0A3@/040`;01`H5`0@30/061@C01`H5`0A3@`03PX901DA4002014=300601TE500H
51<0510?01PD4`0C3`h04@d<0`0C3`h0<@0A3@`04`l>01@@3`0B3Pd04`l>00l;200D40d05A4>01@@
3@0G4a00510=014=2P0H51405A4>010<2@0F4Pl04A4A00`A5@0I8RT0VJ:Y0:nc^`0O8R/05APO02TX
<00J5a`05A4@01XE4P0F40/06AHA00lC500B61/0:2d`08jCUP35b//0=CTj01LK700A51@03Q0?01/M
700E5Q@04A4?01TH5P0D4a402PT701hM6`0@3`d05aHD01TH5P0C4Q000P0D4a4201<B400A01@D4P0A
4@l0410>01LG5@0L71X06a/I024Q7`0G5aD06QXH01LG5@0F5Q@04a<A01@D4P0G5aD05ADC01<C4@0E
5A<00P0G5aD0300H61H05QHD01DE4`0I6AL07AdK01DG500N81d06A/H02T[:00F61D03a4>01XL6@80
6A/H0P0H6QL03P0J7A/051PG038g<`0E6QD07b@N01LL5P0M8Q`05a`F00X<2`0P92D07R8U01XM900L
8BD0624P0P0G81l0A`0M9RD0:C8a01DN7@0N9bH07BHU01lX9`0R:bX0:c@c028Z:00V;2X092XX02Xb
;`0V;b`0>D8o09ZTX@3Fgmd0[;Nc04eHE00hA400:SLe02ho@`0cA4/0>4Y?02Xl?P0Q<c<09cTi02/n
?@0Z?C`0;d5202Xl@00b@dT0=4E=03=6C00^@DL0=4M>02m1C@0gBED0=DME03I8E@0gBED0>deH03e@
F00nDEL0?U5H04EGHP10DUl0@E=O04AFHP0mCeX0AUQR04IIH@0jC5D0?e9I04AGGP15F5h0AeYP04AG
GP15F5l0@eIM04EHG`18Ff80AUUP04AGGP16FF00BeiT051SJP1CIVd0DFAZ05EWJ`1EIfX0EfU/0080
E6IY03`0GFma07B6QP1MKfl0DfIU05Q[J@1LKfd0GW5^06QhM`1WMgL0J7Qh06YjN@1]OGd0M8B30761
P@1cPh80Lh>307B4P`1fQXH0NHV907b8R01nRXX0P8b<08RBT`2>V9X0TI^M09NNY02TZk40WjJ/0:2T
[@2UZK80XjN`0:JY/@2/[;D0[jnh0;>c_02h]/00^KS10;fla@32_lT0`l3:0<:ob@32_<L0`kg80<Fn
bP37_l`0c<CA0=G:fP3JcMh0g<oP0=o?hP3UdnT0imG[0>_Gk@3]fNl0km[a0?GNn@3fgoX0mn3j0?[S
o@3li_d20?cVo0090?gWo03njOd0o^[n0?o[o`3okOl0o^ko0?o]o`3okol0oo3o0080onoo06H0o^ko
0?o]oP3nkOh0nncl0?cZn`3mjOT0nnCd0?OPlP3fgo80mMkb0?CLlP3`fNh0kMOZ0>WCi03QbmX0f/G@
0=K0b`3Ea<l0dlSC0<RmaP38_/H0_kJi0;J][P2WXI`0Xj2D09RFR02<RWP0QHIa07n1J`1eN6<0OH5/
08:7M01iOfh0Mga]07QnL@1lPgP0KgI/08jESP1hP7/0L7Qc07MoN`1cO7L0JG9]06A^J@1]Mg80IW5[
065]IP1RKfP0IG9[05aZH`1FIEh0E6=L055PF01:Edh0@Di403M4>`0kASh0=T4i03Q3?@0oB4<0<3Td
02lh=@11AdD0>3hl03@m?00jA4D0<cm003I2@P0hA4@0=D50038n?00_>cT0=40m02lk=`0`?3P0;3Pd
02Te<@0lAD807RLT02H_;00_=C<0<3Hc02`b;P0Q9R809R/V02<X8P0W:B@092LQ02@Y8`0U:bL09Rh[
02D]:P0S:RP08BPV024W9@0Y;bd0:S4^02Xb;`0W;R`08RTW02<Y9`0`=3<201`P7`0@01dQ800T:2L0
8BDT024U900S9bH09RXY02DY:00S9bH08bTW024Y900O:2@07RLT020V9P0R9bX07B8U01hR9@807b0R
00d0828P01dO700Z;2P07alM01TI5`0K6aT07AdK024Q7`0N7Q`0820N01lO7@0K6aT06ATG00806QXH
00X06aXF01TH500H5a<061LC01LF4P0I61@06aXF01XI5@0I61@06aXF0P0I61@0100K6QH061LC01hM
6@0M71P201HE4@805A@@00D051<?01PG4`0I61@04a8>014@3002018A3@8051<?0`0C4Ph0:P0F5A40
51<?018A3@0E4Pl05Q8?01<?300G4Pl040/801HA3P0D40d040/801@?300I5A805A0=02HQ7P0J5Q<0
4`l<01@@3@0=2@H04`l<01@@3@1>BTL0EU9?018>2`0A3@X04Ph;00`81@0B3P/04@d:010<2@0B3P/0
5Q8?01<?300I5A807QXG018>2`0D40d0;BTV03@`;00G3``05@h801@=1`804Pd900l03`X600h:1`0@
3P/06APF00h=2`0C4Q002`X801D@3@0@2`P03PT6010;200E40d07APE00h91P0A30T00P0@2`P0=P0B
3@X040/802/V8`0M61D02`H501@?300A30T050l<00`7100C3P/04@`900h91P0@2`P04@`902HP800A
2`/050h>018<300E3`l02`D500h8200@2PX04`d=014;2`0?2@T04@/;01<>2`0:1@804Pd:00l:200@
2`P03`X7010;200A30T04Pd:00l:1`0A30T03PT6014:2P0<10D03@D601092@0A2`/03PP802DO7`0P
61T08ATJ01@=3@0@2@T030D500`61P0?2@T040X:00d71`8040X:00X03`T9010:2P0=1`L03`T9010:
2P0@20T04@L801061`0B20T04`T:0P0D2P/201D;300;01882@0A1`P04`T:030U:028OH40:1dQ01D:
3P0>1@L04@H:01<8300B1`/00P0A1PX201052@0D01482P0=1`L0100002XT900?2PX03@L700h92@0?
2@T03@L7014;2`0<1PH040X:00`41@0E2``09Q`M00d51@0A1`P04PP900l51P0A1`P201882@0301@:
2`0B20T04PP9008050X;0P0>10D02P0D2P/0:AlP03T_<00?1PH040H701@:2`0B20T050X901471P0@
1PD201081P0@018:2@0J51@02`D500h:2P0@2`h04Ph@014<3P0A20T04`T801471P0?1@@04@L601<9
200;0P404PP700l510804@L600@040H501471P0=0`803P@30P0B20L01`0=10@03`D401@:2@0;0`80
5`d<02/Q800A1`H05?ooool001_ooooo01003@T801`H5`0U8B007ATH01TE500Y9B@05Q8A01`H5`0<
20L040`;014=300?2`X03PX900T5100?2`X04Ph=0P0@30/06@0<20L04`l>010<2`0?2`X04Ph=014=
3P13?TD0FEAK00T42P0B3A<03@P<024M7P0G4a@06aLF01@@3`070`406QHC01@@3@17@d801P8101<?
3P0<20L08QhM020L6`0@30/00P0?2`X01`0K5aH0:BDT01TE5P0C31<04P/B018<400C3A400P0D3Q00
1P0@2P`03`T=00l93@0B2a805PlF01LB5P802`L601L040`;024M700@30/04@d<01<?3P0D40l06ADD
02<O7P12?Sd09B4O010<2@0810D05A0F01<>5@0B3A<05Q<A01DB2@0F4`X05Q<<01DA400D3aD05Q8E
00d92003010<2`0401PD4`0C3`h04Ph=010<2`804@d<00P040`;01PD4P0?2`P04Ph;00d9200D40l0
9b<R01<?3P804Ph=0P0A3@`02`0B3Pd02`L6010<2`0B3Pd0510?00<0000D40l04`l>018>3@0A3@`0
4`l>00805A4@0`0C3`h00`0O6aX06ADD00l;2P0301DA400:01@@3`0C3`h04`l>01<?300E4@h061@A
01TE4P0G4a005A4>01<?30804Ph;02X0510=01DA3P0@41008RL[00lF701bNGl0OX>901`O9`082100
4Q4G010=4@0E4A005A0=01@>2@0H5A001@T801XO8P0=4QD08BHY0497A`0F6Q/04ADF010C4P0A4a80
4aDD01DE4`0B4Q004A0>018A3`0O7Q`0:RTW01<B400D4a407A`J01@C4@0E518051<A018A3`0A40h0
5QHD01TI5`0E5A<201HF50804Q8@00/05ADC01PH5P0C4a405QHD010@3P0D51804A4?01@D4P0K6aT0
5QHD00h>300201LG5@0=01DE4`0D51805aLE01/K6@0B51408B<P020R7`10@Sl071hK01/M6P0H6QL0
5aTF01HH5@0201LI5P0Z01/N700n@T40Y:VU02<X8`0@5@l0:2dW01DJ500M8Q`0;30_01hR8`0C5aX0
;2lf01`Q9@0P:BP0624P01dV9@0I8R405QlN024Z:@1kQ8<0[kRg07R1P00b>cX0;cPg02P_;P0/<S00
728P02T`;P0d?CX0C5EB0;6k]`3`noL0/;^g03U5@@0/>3@0:cPf01//<`0gBU40AEIM02m1A@0R=3H0
;Clo0P0[?S`01`0]?cl0;T1202m1A@0b@DP0=DI=02i1A`0gBU400P0cAE403@0iBeT0>TaJ03]=F`0n
D5d0?e5M03i@FP0kCEL0@UAR03]=F`13EF<0CV1/049DH019FfD00P0kCUD0200oDUP0BUeS045DFP0m
D5H0?e9H04AGG@13EU`0A5MN0P1;GVD01`17FV40EFQ_05EXK`1EJ6l0F6]b051SJ@1FJ6`00`1FJ6X0
3`1EIfT0E6IX055SH`1GJFT0EFMW05a_K@1XNgT0H7=a06QhN01YNGT0JWYj06alO01^OWh0Kgmo0761
P@0307>3P`0T07N7Q`1kRh/0PHf=08>?S`26TY80SINH096KW@2CWIl0Vj:X0:B[/@2QZ:h0XJF^0:>W
/02QYJh0YZV`0:f]]@2`/;P0/k>k0;Nf_P2j^L40^k[20<6na`32_lP0_kc50<2ja031^lD0`kg90<[2
c`3>a]<0dlSH0=S;g03Kc]l0gm3S0>?Ai`3UdnT0j]O]0P3[f>h01`3`fOD0lmch0?GNnP3gh?X0n>7k
0?WSnP3kiO`00P3ni_`01@3miO/0onOm0?oZoP3mj_d0o^_n00@0onco0P3njoh06`3mj_d0n^Oj0?WV
n@3jiOL0nN;b0?GNl03cg>l0lM[^0>oGk@3ZeNP0i]7R0>7<f`3Ia]80d/790<jm``3:_<D0akg60<Bj
``2n]K/0][2b0;6/Z@2VXid0Ti6508Z:N`2BTh40U9J108>5L00207n4L01[07b0K`1`MfL0Jg9R06Q^
H@1]MFX0JW9W07AkL`1WLFT0HfaW06YcKP1aNWD0JW=^069]I`1SKVP0IG1Z065^I`1PKFH0JGI_06=b
J`1OKVL0EFAM04mNE`0f@cX0?T]103m<@`0/=bl0:C@/03<n>00j@ch0:34/03M0?@1DFUP0>Clm03<l
>`0a>c`0;STj03A0@00hA4@0=40o02lk>@0hA480<3`i02lk=`0d@3`0<clk02Pd<00[=S80:C8_02df
<`0W<2d0;38_028X900V:bL09b`W01dR700W:B@0:2/U02@Y8`0Z<2`0:c@a02Pa;P0T;BX08RXW02@Z
:00Q9bD0:2h/02`b<00T:RP06R0N020V900Q9B@092PW01TM700H71/05QXI01lS8P0R9RD08BDT02DY
:00T:2L08BDT028X9P0T:bL06R<P02H_;00[<C40=3Tl01PM800R9RT08B8T01lQ800O8Ad0D59=09fO
VP0S8b407QhL01dM6`0O7ad07AdK01/K6@0O7ad0820N01XJ600H61H06QXH01TI5`0H5a<00P0I61@2
01LF4P805QDA00/061LC01TH500H5a<05QDA014@300C4Ph04A0<018A3@0D4`l040l;01DD400201@C
3`0401DD400F5A405QDA01@C3`804a8>00<04Q4=01HE4@0F5A400`0A40`2018A3@07014@300@3@X0
40`901XF4`0Y9B8071PE00`81@0201@@3@0B020L6@0T81d05A4>01<?300>2PL02`L401TE4P0A3@X0
:2@Q01DA3P0F4Pl03PX701TE4P0@30T03PX701HB3`0?2`P04Ph;0P0?2`P02@0E4@h0510=00P40@0I
5A803PX7018>2`0>2PL04`l;01D=2P0201@=1`804Pd900d04@`800P40@0B3`d03Pd;00`;2@0I61H0
30/901@?300A30T03`X7010;200E40d06A@A00H040/800D02`H3014<2@0[9R<04Pd:00T50`0200h9
1P0G01@?300C3P/03`X700l:1`0D3``04`d=00l92@0:10@02`D5010:2P0A2`/03`T900/51@0>20P0
40X:00l92@0A2`/0?cXg02@O7004000040/800l:1`0A30T01P0>2@H401482@803`T900X04`d=059<
C01;ADD02`H600L10@0Q6a/040X:00l92@0>20P03`T90P0@2PX03P0>20P040X:00h8200@2PX04@/;
01492P0B20T04@L801061`0A1`P04`T:01882@0A1`P04PP90P0@1PL01`0D2P/05@/=03P]<@0B1`/0
4@P:00h31`0C20`01P0A1PX03`0H3a406A<C00l92@0>20P0>38b018<30040000208205I@D01`JVX0
40X:00T30`0?1`L040H701882@0201<92P0601882@0A1`P05@/<01D;300B20T04`T:0P0@1PL01P0C
2@X05P`=01061`0>10D04@L801<92P804PP90`0@1PL201881`0;01471P0=1@<03PH401892P050000
6aDE03<_<00d;c<06aHJ00X51`0?1PL00P0@1PD02@0A1`H04`T801@:2@0F30/05@/:00l5100>10<0
40H500d30P0300l510<040H500H04PP700h40`07000040H501T?3P07000Dooooo`006oooool03P0B
3Pd04@d<018>3@0@30/03@T800l;2P0=2@P04@d<010<2`0F4Q403`/:01<?3P0D40l04`l>0P0E4A00
100A3@`03`/:00l;2P0D40l2010<2`0N018>3@0@30`0?STl01`H6`0B3Q004`h@00T51@0G4a<0K6QW
05IBD@0:1PH05Q8A014=2P0=2@H0AD5000/81`0I5A@0:2@S00l;2P0A3Pd04Ph=00l;2P0C3`h05Q8A
01@@3`0>2PX04P`?014;3`0A2`h04`d?0P0E3a408`0I4aD050h@010:300?2@`04@/?010;300?2`X0
8QhM00l;2P0E4A004`l>018>3@0=2@P03`/:018>3@0?2`X07ATH014=2`0B3P`0510B01<>5P0B31P0
4`dG01D@4`0D40`04a0;01@@3P0E41@05a4J01@?4`0J5QD04@d<01@@3`0K5aH04@d<00<04`l>00`0
3`/:00h:2@0A3@`03`/801XG4P0F4Pl03PX701DA3P0P71/04`l>018>3@0B3Pl201<?400C01DA4P0H
51<03`/:01TE500B3Pd04`l>018>3@0E4A004`l>014=300C3`h0510?01<?3P0<20L06QHE01@@3`0B
3Pd03PX:044m?002014=3004018>3@0C3`h04`l>01@@3`805Q8?00D05a<@01HB3`0D40d04Ph;01@@
3@02018>2`1701@@3@0E4@h04A0>00l?4@0?4QD03a4D01lP9@0E5AX04Q4F01DD6@0C41<0510?01H@
3`0G4Pd06AHA01<E500@51D03Q8B00lC500C5AH05aTG01LH5P0B4a40410=018A3P0D4`l04a8>01PG
5@0J6AL020L601@C4@0C4Q005aHD01HE4`0@3`d051<A01HE4`0E51804a8@01DE4`0I6AL05ADC014A
3`0D51805QHD01LG5@0L71X05aLE01TI5`0U9B<06ATG01DE4`0G5aD061PF01DE4`0F5Q@06QXH01TI
5`0H61H05QHD01DE4`0F5Q@061PF01XL6@0I6aP071hK02DW900B51407AlL01XL6@0I6aP00P0H6QL0
E`0I6aP071lM00hB4@0X;BT05Q/F028W8@0C6180724K01dR700G6aX08bLX014E600L7bH0>Sm3045:
B@0K92<0<3Th02Tb<@0=5QD08BXY06mhM`1IHV40:S<b01hW9P0I8R409Bd/020V9P0T:R/0:2l_02hg
=P0i@D80CEIF07=mO01PJVX0<Sdl02`h=P0Z=cL0@5=J0;;6cP2HZk80:Ca102@h>@0/?Sl0:chl02`o
?@0`@400<T5403=2A@0e@dT0=TQ<02m2A`0hBe80=4IA03A6DP0jC5X0>T]K03a=G00oDEl0@E=P041B
G@0nD5/0<D9A03Q9F@0nD5l0@59P03i@G@0nD5/0>4]B069eO014Eed0A5ML03iAE@12EEP0?U9D04QK
GP18Ff00AeYP04ePJ01@HV`0BUaW05AVL@1>H6X0CV1Y05IYL01@HfT0Ff]^05UYJ@0205IVIP0?05QX
J01IJFT0EFEU05a/K01NKVh0IGEe06]kN`1QLG40IgMg06QhN01[Ng/0KGem0720P01aPH40LX:200<0
Lh>300H0N8R807j>SP1nRXX0PXj>08NCT`2<UYL208jHVP0;09JMX`2LXjT0VZ6W09bPZ@2NXZ/0X:B]
0:JY/02^[[H0/K6i0;>c^`2h]kl00P2k^/830;fj``1<0<6ka@33_LL0a;k:0<W3c`3<a]80dLWH0=K;
f`3HcMd0gLoR0>7@iP3Td^P0imG[0>[Gk@3Ze^h0kMWd0??Ln03fgo/0n>7l0?SPnP3ggoP0n^;j0?cR
n`3lhoX0o>?i0?kUn`3oio`0oNOl0?kWo03niod0o^Sm0?oXo@3oj?h0onWn0?oXo@3mio`0n^Ci0?WR
m`3gh_D0m=o`0?;MkP3`fnd0k=S[0>WEj03SdN<0fl[H0=K5d@3Ca<`0cL330<Rj_P33^Kd0`;Vo0;bf
^`2e[k40[j^Y0;2/Z02TXi/0U9B808j?P029RgX0PhIb07UmJ@1oQG80M7]Y07MnKP1nQGD0Mgi^07R0
L@1eOG00MGea06miK`1JI5X0G6IM061/I01XLfd0IG1/065/J080H6aX01D0Gf]W05]ZI@1OKVT0E6=N
055RG01CI5h0HW=/0:NdZ`1BGeD0=44h03Q3>`0Y=2`0;STc03Ho>P0/=C00;SLd03a2@00b>3H0:S<b
02Pb<`0]>CX00P0[=cL0600b?Sd0=40n03<o?@0^>SL0;CTe02lk=`0c?c/0>4A003U4@00a?3P0<3/g
02Pc;`0Z=2l09RlZ02P`:`0U;2H072<L02P^9`0Z;bT0:2lX02La;00V<Bd08bhZ024Z9`807RLT00l0
7B<Q02D[:@0X;R`082@S01PL6`0O8b8061`K024U900L81l07b<R01/O7P0U:BP08bLV024U900R9RD0
0P0Q9B@03P0T:RP07RHS01hW900P:BL07R<U02<X:`0O92L07b<V01`M7`0K7A/092HQ028T7P0V:280
7AdJ0P0K6aT02@0M7A/07QhL01hN700J6QP071`J01PH5P0I6AL071`J01XJ600301PG4`0;01LF4P0F
5A405A@@01HE4@0H5a<06QTE01PG4`0F5A406APD02/Z9P0U92000P0F5A40100B4@d04a8>01@C3`0D
4`l301DD400401@C3`0C4Ph04a8>018A3@805QDA0P0C4Ph0:@0B4@d04A0<010?2`0A40`05QDA01PG
4`0C4Ph0;B`X09BCS`0j>CD05aHB01HE4@0@3`/020L4010?2`0A40`03``:01XF4`0B3``07a/H06aX
I@0/:2D04@h<010<2@0?2`P0=C4^018>2`0A3@/03PX7014=2P0C3``04Ph;01<?300B3P/05a<@02/W
900F4Pl04`l<014=2P0C3`/04`/800804``60P0B3@T02@0C3PX05Q8?00`:1`0A40h05aHD03ln?00>
3@`04Pd:014<2@0200l:1`P040/800L04Pd:01D@3@12?CX05A0>014=2P0?2PT03`X700804`h;0P0@
2`P00`0C3P/03PP801<=3@0200/51@0401<=3@0?2@T06Q@D014;2`8040X:00P03@L700h8200W8Ql0
3`X903Lb;`0P6aP040/8014<2@D03PT600@03`T601882@0B20T04PP90`0A20T02P0?2PX05@l?00h9
2@0C3`h02PH500h:2@0A2`/040X:00l92@0@2PX2014;2`0>00l92@0@2PX030H600h8200?2@T04PX:
01H<3@0C2@X04PP901061`0A1`P04PP901<92P0B20T201061`070147200B2@X040D901D:3P0B1`/0
5@X>00`11@0601462P0=01482P0<1`L04`d=00h82014?Sh05Q4A010;2`0<1PH0=c4a051:BP0H4Q80
3@L700h71`020147200A01882@0E2``05`d>01L=3P0I3a005@/<0147200B20T040H701882@0D2P/0
5P`=0147200>10D040H700l51P0@1PL00`0A1`P0100B20T04PP701881`0B20L200h51P0801892P0<
1PP03@L903@_<`2:QHT0:RDY00l9300@1`P201471P0:01881`0D2PT05@/:01P>3@0?1`H04@L600X0
000@1PD050X901881`@04@L600L040H500h40`0;0@404`T801471P0;0P405P`;01Cooooo000Koooo
o`0b018>3@0<20L03`/:01TE500K5aH040`;01HB4@0D40l03`/:01@@3`0<20L04`l>00X61@0?2`X0
4@d<018>3@0D40l04`l>00h:2@0A3@`03`/:018>3@0E4A004Ph=01DA3P0R7Q/0510=018>2`0H5140
2PH301dI5P0D40l04Ph=00`81`0L61L06QHE01@@3`0B3Pd01`<201dI600300003PX9010<2`0A3@`0
510?014=300>2PT05Q8A01@>3P0B30h5014;3@0>018<3P0C3@l050h?01D?4@0B3@d07ATH03`h=`0E
4A002`L601@@3`0H51<03@T801<?3P0G4a8201@@3`0>01<@2`0C40T04Ph=00d83P0D3aH061<J01@@
4@0B3`X04@h7018?2`0E4A805a8I01D@500B3Pd201<?3P0301DA400B3Pd03`/:00804`l>00T03`/:
00d9200A3@`05Q8?01PE400@3@P06QHC01HB3`0>2PL00P0B3Pd01`0B3Pl04`hB01@?4`0F4A@03PX9
01@@3`0>2PT00P0I5A@03@0A3@`0510?018>3@0@30/04Ph=01<?3P0B3Pd061@C01XF5@0@30/04Ph=
00L30P0K5aH00`0B3Pd301<?3P<0510=00H04Ph;010<2@0?2`P0510=01<?300B3P/201@@3@0S018>
2`0C4Q005A<C01HD5@071@P0QhF802<N8P0D3a<04`hA018>3@0E4A005a<?014@300;2`T04A<B01PJ
5`0D5QD04A4?01HG4P0H5a<04a8>018?2P0C40/05A8=01DA3P0G5Q@08R4O018A3`0g=S@05aHD00h=
2`0H5aD03Pd;014@3P0D4a400P0G5Q@04`0D51804Q8@01<C4@0D51804a<A01@D4P0E5A<06ATG014A
3`0E5A<092@R01LG5@0E5A<03@d;01HF500O7ad071`J01/K6@0J6QP00`0G5aD201HF500e01TK600D
5Q<06Q`I01TK600K7AX0:R`Y01lQ7P0L7Q/06Q`I01PJ5`0G6AH05aXH018F5@0Y;RX04aPC00@90`0G
71H04aPB02L/9P0J7Qd05ATJ01@H6`0J7B@06AhR01@M700I8R4072DT01XS8P0Q:RT06b@S01XS8P0O
:2L0:34`01`U900U;Rd08bX[02@Y;00X;C40728U02`d=P0nATT0;CHh03@n?`0b?3h0:C<e02Pd=00^
>cd093Ln04iRJ`14FEl0=TU?02Di>P0a@d@00P0`@d40:P0b@T40=49303A2@`0d@TD0=TQ<02i1A@0h
Be40=4I@03A6DP0jC5/0>daN03a=G@11DV40@eES049DH011Del0=dQH03m@H00nCel0>deK04EGI@0o
DE`0M8N>0:Bg_P1TMgd0B5]O03]>DP0lD540?U9A04QLG019G600BEaR04iQJ@1?HFd0DF=a04aNJP1H
JW@0EfUc04aOI`1GJW00FVU/05MWI`80Df=S00d0EfMW05YZJP1OKW40Gfia05i]L01RLG@0IWEh061_
LP1VMGP0J7Mj06]jO@1]O7l0L7n20080LX640P1dPhH01`1eQ8L0NXV<07n?S`21SHd0QI6A08ZFUP2?
VIX00P2@VY`03@2CVZ00V9nU09ZQY`2LX:T0XJF^0:JZ/`2VZJl0[Jjc0;2a]P2b/kP0][Fk0;Rg_@2i
^;h00P2h]K`05P2l^L00`Kc30<>ma`33`</0b/C@0<c6dP3?amH0e<WI0=K;f`3JcMl0g/oT0>3AiP3U
dnT0i]CZ0>OEk@3/f?<0lMgi0?CPo03hhOd0mmoi0?KMn03ggOP30?_On00?0?cPn@3mh_/0nn?k0?cR
n`3lho/0nn?k0?_QnP3lho/0o>Cl0?gSo03jhOX0m]kf0?KLm@3af^l0jmWY0080j]OZ01D0imKX0>CC
i@3Lc]h0cl??0<^ob@3=`/L0aKbm0<6i]`30^[T0^[Je0;B`[`2a[JX0[JZU0:BSWP2HV8l0TI>608f@
P022QG@0OH5`07n3LP24RgT00P1dNf/0A@1lQ7D0M7a]07=kK021S7`0O8Mg06mjK01FHU@0FFEG05EQ
E01KIV00GfYV06=_J`1RKVX0GVYV05QWHP1GIV40H6mZ05UZI01BHed0B5UC04AECP1HIE`0>DHl03E2
>@0b?CD0@di603i9@`0f?cX0<CXe02Tb;`0]<c40<SPf02`e=00/=SL0;c/l02`h>00[=cL0=40o03U5
@`0nBTP0<cll02Xf<P0W<bl0;3Pd03i:AP1JIV809S<_02Hb;P0X=3009C4/02/f<00T;bT08b`V01lY
8@0Y<b/09RhV02@^9P0Y=2h09C4]028]:@0P:bL07bTV01hW900Q9bD082DT02<W9P0S9B@07AlN01`N
7@0201@H5`0G01PL6`0U:BP06alN01lS8P0Q9B@082@S028V9@0Q9B@09BTX02/a;`0P9bD04Q/J00PA
4013B4/04aPK02T^<@0O8bD08R<U01HH5@0R91h0;c8[024T7@0L7AT00P0M7A/01P0O7ad08R8P02<S
8@0J6QP06a/I01LG5@806ATG00H05ADC01TH500J6AD06QTE01PG4`0G5Q8201PG4`0;01HE4@0E5100
5QDA01PG4`0I61@08b8N01/J5P0B4@d07A`H01PG4`0C4Ph01@0D4`l301<B3P0a018A3@0F5A405QDA
018A3@0D4`l05A@@01<B3P0B4@d05A@@01PG4`0A40`02`X605ACC`3hmo<0Cdi:010?2`0C4Ph04Q4=
01<B3P0O7QX03@`800l;20060P003`/900l;200L61D05Q8?01hJ5`0J5Q<04Ph;08R4P@1NFUL05Q8?
014=2P0?2`P04@d:01DA3P0B3P/02`L4014=2P0T81d040`900h:1`0@30T05Q8>01491P0A2P@04P/5
014<2002018=2@0600l;200C4@h030/900/:200;2PT02@P60P0>2@H300l:1`0300h91P0@2`P040/8
00@040/80P0B3@X01@04000040/801<>2`0H4a003PT6008040/80P0?2PL04P0@2`P0208201<=3@0?
2@T03PP8018<300>20P0618B01XD500K5AD03`T900/51@0@2PX03`/900T40@1QG5T0?CPe01HA3PH0
3PT600<040P601<82@0B20T00P0B20T201482@0:00l92@0G4a802`L600l=2`061@<04Ph=00l92@0>
20P03@L700h820803`T900H03PP800l92@0<1PH03`T9018<300B2P/201<92P0301882@0C2@X04`T:
008050X;00/04`T:01882@0B20T04@L801P=4007000060dA00h31`0G31003`@801H;3`0501462P0=
01<:300C3@d07QPH01dG5`090`<04`d=018<300M5aL04P`<010;2`0D3Ph04P`<01@<3@0201472007
01882@0E2``060h?01<92P0F30d04`T:01061`0201<92P0500l51P0@1PL04PP90147200@1PL00P0A
1`P02`0B20T04`T:01<92P0B20T04@L801061`0A1`P04PP900l61`0>1@H04@P;008050h@00L02`L:
05IAE`0M61h030L<01892P0B20L04@L600803`D400/040H501T?3P0F30/060h=01471P0?1PD04PP7
00l5100@1PD04@L601881`0201<9200301061@0B20L040H500803@<200<03P@3ooooooooool04_oo
ool001_ooooo00H02@D4018>3@0A3@`03@T800h:2@0?2`X201<?3P0[00X61@0?2`X03PX901<?3P0@
30/05A4@018>3@0A3@`0510?01<?3P0>2PT040`;00l;2P0D40l05Q8A018>2`081@804@h7010=1P0C
40X06QLB00l;200C3``040`;01TE500H51<06ADD01LC4P0@30/05a<B014=30060P805A4@01LC4P0A
3@`04`l>014=300@30/02`L6014=300D3Ph04P`<014;2`03010:300b018<3P0C3@l050h>01D?3`0D
3Ph04`h=01DA400V8R404Ph=01@@3`0A3@`04Ph=00T5100@30/03`/:01<?3P0<20L04Pl8014?0`0C
40/050lA01HA5`0C3Q804@d;018?200B3`H04a0901DA400F4AD061@F00X61@0@30/03PX900X61@0E
4A004@d<01<?3P0B3Pd040`;00l;2P0A3@`04Ph:00d:1@0D4@`06aLD01HB3`0K5a@04`l>018>3@0B
3Pl2018=4@0?01@?4`0E4A806QHE01@@3`0G4a801P81018>3@0C3`h04@d<010<2`0A3@`04`l>018>
3@0D40l05A4@00<06QHE00P05a<B01TE500I5A@05a<B01DA400C3`h04Ph=01HB3`805A4>00H04`l<
018>2`0A3@X05A4>01<?300B3P/201@@3@0P014=2P0U8Qd01000028N7@0=1`L0;b//00<00P0G4QH0
510B010<2`0B3Pd05A8>00d<200=3@/04A<@00l?3@0=3@/0410<00l>2P0F5A404a4<018?2P0D4@`0
5A8=01@A300J6AD04a8@024P7P1:BDL04Q4?01LF500P7ad301@C4@805QDC00P04a<A01@D4P0I6AL0
5QHD00d=2`0<30X051@B01HF50804Q8@00T07QhL01DE4`0D51804Q8@010@3P0E5A<0@D4o06EUH`0I
6AL00P0G5aD01P0I6AL05aLE01HF500F61D07AlL024S80806Q`I00@07R0M01dO700J71T061XG0P0F
61D07`0E61H051PG010E4@0V:bH07B8L020U7`0N8ad051TC01PL6`0V:R/04QHI024T:`0M8RD04a`K
01LP7`0E7Qd072DT01lX9`0@6AP05b0O02D^;@0H8B003QLF030i>00Q:2/07B8V01hS9`0T:Rh0@DU<
04Q@D`0]=ST00P0^>3X02@0Y<cD09C0b02`h?00Y>dD0;D5<02PlA00eB4h093Pi02`n?`020395@`0i
03A4@`0e@d@0=D=403E3AP0gBDd0<4=703U<D`0eAe40=DMC03]<G010DF<0@E9T04AEI@13E6@0@E=Q
03i@GP12Df<0?DiP03Q9F@14EV@0E6Id049DG`0lCUP0HGAk04MJG`11E5P0@5=G04IJFP0mDDl0A5QG
04QLG@1=H6H0E6I_055SK`1IJgT0DfEb06eoR`1ZO8H0Cf5Z05QYL01GIVT0E6AT059RHP1CHf<0F6QX
05][J`1QL7<0GFa_05i]L01SLWD0J7Mj06MfN@1XMgX0JWUl06akOP1^OH00L7n20080LH2301/0M8>6
07J5R01gQXT0NhZ=07n?S`21S8h0Q92@08NCT`2<UYL0SYRJ08nIV`2@Uid0UYfS09^RZ02LX:T0Wj>/
0:FZ/02WZ[00[Jjc0:n`]@2`/KH0/k:h0;Fd^P2g][`0][>j0;Nd^`2l^L000P31_<<04`34`L`0b/C@
0<c6dP3?amH0dlSH0=C9f@3Ic=h0gLkS0=o@i@3Td^P0iM?Y0>KDk03Xe?00k=Sd0>oKm`3cg?P0lm_e
0??Jm@3fg?L00`3igOH00`3lg_P0o>3i0?[Pn@020?[Pn@80nMoh0`3jh?T0>@3ggOH0m=[c0?;Hl@3]
e^/0i]CT0>GBi@3TdnD0h=;S0=g?h03EbML0bKo80<RnaP3:`LD0_KRe0;bg]02n^[H0][:_0;2/Z@2]
ZZD0Z:FN09^KT`2DUH`0RXb107eoLP1oPg@0Oh=b07=gIP27SWh0O8=c07V0L01nQWL0NX9c07V1LP1Y
M6@0K7MW071kJ`1KJ5L0F6EC05UUE@1FHET0GFQT06A`K01QKFT0GFUU05QWHP1PKfX0Hg9]05EVH01<
GEL0@U==03Y;A00gAcd0=D8h041=A00c?SH0=D0h034l=P0202lh<`0N02df<`0`=S@0;S@b02H_;P0_
>CX0:SHg030l?00c?cl0<Cdl034m>`1JIV@0=d=002/g<`0b?SX0<clk034m>@1PKfX0:cXe02Xi=00^
>SH0:SHa02/h<@0V<B/09C0Y02@^9P0Z=2`08B/R028]9@0W=2d08bhZ0P0O:RH09P0O:BH07RLT02<Y
9`0N8b408BDT02@V9@0N81l06adL02@X9`0D61L05ATH02DY:00P92<09b/Z024U900R9RD092PW02<W
9P0X;2/0;cDc01`S8@0b>cX0EEiM0;>h^`0Z;c803Q<F01<G6@0O8B00:bdZ01/M5`0D5`h04QD>01hN
6`0N7Q`07AdK01XJ600K6aT07AdK0P0K6aT0100H61H06QXH01PH5P0C4a4301XI5@0?01TH500H5a<0
6APD01PG4`0F5A4051<?01HE4@0H5a<05A@@01LF4P0@3`/03`h:01XI5@0D4`l04a8>00<051<?1@0C
4Ph01@0B4@d05QDA01HE4@0@3`/04Q4=00805A@@00P05QDA01XI5@0O7QX08B0L01XI5@0F5A40Cdi:
02<R7P805QDA0P0A40`0400I61@030/7010<2@050@0071PE01DA3P0300003PX700P40@0300005A4>
02@P7@0<20D040`901@@3@0A3@X2010<2@803PX700L01@4001HB3`0>2PL04`l<00`81@0>2`L04PX7
00804P/50`0A30P01P0T81d06aTF0040000U92801`H401hM6`803PT600@03`X7010;200A30T04@`9
1P0@2`P01P0400005a8?00@0000A30T03@P501D@3@H03PT6018030H600h8200<1PH02P@400h8200E
3`l03PP801H@400J51@03PP800`61P0D3Ph04`h;01D@3@0P6aP0>3<`01@?300?2PL500h91P030108
1P0C20T04PP900804PP90P0A20T01`0=1`L0100000<0000A40h02@P600D40P0?2@T00`0=1`L0200>
20P03`T900`61P0>20P03@L701@>3P0K5AD05@d=0P0?1@H20147200401882@0D2P/050X;01<92P80
50X;00P04PP901@93007000060dA01462P0I3Q803`@801@93@D04@H:01<02`@500@0000;1@D03PT9
00@0000M5aL02P@400d71`0:10@02@<300H0000400003@D601061`0A1`P04PP901@:2`0F30d03`D6
00804PP900D04@L801@:2`0C2@X03P@500l51P04014720806Q0A00L06@l@01H<3@0C2@X03`D60106
1`0A1`P04PP900803`H700X04@P;01D?4@0K5AL05A0D01hI7`0300@02`D:01<:2`0C2@P04@L60`0>
10<04P0800005P`;00l5100D2PT040H501@:2@0=0`803`D401061@0A1`H04`T801@:2@0>10<04PP7
00X0000;0@004@L600L001Cooooo000Kooooo`0E01`H5`0M6AP04Ph=00d9200A3@`03`/:00h:2@0G
4a802@D400l;2P0D40l04@d<01HB4@0J5QD04Ph=00h:2@0C3`h0510?018>3@0C3`h03`/:0080510?
01003`/801HC2`0:1`0071T@010=1`091P803P/6010<2@0?2`X03`/;018>3@0M6AX03PX;010<2`0E
4A004Ph=0P0D40l01`0>2PT04`l>01@@3`0A3@`081`K01@@3`0<20L00P0A30T0<`0@2`P04P`<018<
300C3@d05@l?018<300A2`/04`h<01HA3P0F4Q0040`;018>3@0A3@`061@C00X61@0D40l04Ph=01XF
5@0>2PT06aLF00`81`0E4`X04Q0201@A200E4@h03PX:00l;2@0C40/04@l401<A1@0E4`P0514<01@@
3P0D410020@301PD4`0S7ah03PX901<?3P0D40l04Ph=010<2`0B3Pd04`l>010<2`0C3``02PL301DB
3@0<20H03``801<?300201<?3P0>018>3`0A30l04@`@014<4@0B3Pl05A4@014=300:1PD0=S8a03Lc
<P0A3@`040`;00l;2P0A3@`201@@3`0601TE500=2@P05a<B01LC4P0c;bh05A4@0P0B3Pd301<?3P05
01@@3`0E4Pl0518>01<A3@0B3``00P0C3``06`0F4Pl04`l<018>2`0D40h04`l=014=2@0A2`H07AHA
00l:200L51805Q0@01H@4@0_:B/091hP018>3@0B3P`06ADA01<A300C4`l03`l;018A3@0F5A405Q<@
01<@2`0D4@d04a0;01@@2`0201LB3@0]01D@2`0J5Q@05QDC01LF500T8R007adL01HE4`0I5aD04Pl>
01@C4@0F51805A<A01@C4@0B4Q004a<A01HF500G5aD092@R03<c<@0I6AL061PF01XJ600E5A<06ATG
01HF500E5A<04a<A01HF500D5180:BTW0451?`0H61H05QHD01LG5@0K6aT06QXH01HG5@0E5a@08R@Q
01XL6@0G6AH07AlL01HH5@0J71T06A/H00806Q`I01d06adJ01hR7`12AT@082DQ01XO6P0C61806QlI
01/P6`0G71L0720O04Y>D00R9RT05QTO01LK7`0T;2/07bHV01`T8`0N9bD06B8P01lX9P0P:BL05b0N
028[:P0L9B@092d/01hU:00Q9R/092T^02H/<@0203<j@01602H^<`0U;S<0:c@j02/f>`0Y=3T0:SHl
02Dg@00P=3l0:Ca302m1AP0X>cd0=4I60353@@0c@d80=4A403I5A`0hATP0>DI;03]=DP0dB4`0?E1H
03Y<E`0iBeP0@55P041AHP11DV<0A5EV04EFIP13E6<0@59P03a=G@0oD640AUMW049DHP17FFH0@59M
041BG00oDUT0@UEJ04=FFP13EeT0AEUJ04EIF@17Fe/0BUiP059UJ`1GJG80CV1[05AVLP1BI700Gg5k
05e`N01AI6/0FF]^05EUI@1EHf<0EVAT05QVI`1LJV/0Gfe^06AbM@1QKg80I79e06UgNP1/NWd0JgUl
06YiO01/Ngh0KGao06imP080L7n203T0Kgj107F4Q`1jR8/0NhV<07f;SP1nSHh0PHb>08:>S`24Si00
RI>D08fGV@2>V9/0UYfS09bSZ@2RZJl0Wj>/09fQZP2SZ:h0YjZ`0:f^/`2^[k@0[Jjc0:n^]02`[kD0
];>i0;Ba^02f/kX0_[_20<2la02o^l<0a<7=0<S5d@3:am<0cLOE0=38e`3BbMP0f<cM0=_=h@3Ncn<0
h];V0>?Ci`3UdnX0i]?]0>SDk`3Ze_00k]Sb0?3Hl`3afO@0lm[e0?OKm`3gfoH0n=_d0?WLmP3kgoT0
n=oj0?SNn@3gg_T00P3fgOP20?ONn0220?KMm`3cf_@0l=O`0>gDk@3XdnL0hM3P0=o>g`3Lc=d0e/SH
0<o2dP39_//0`kW20<Bk``33_L00];2^0;Jb[`2i][40[jjW0:bYX`2RXIX0UYN?092AQ`2;SH80PXEj
07]oLP1nPGD0Nh1c071dIP1aMfT0L7IX06meI`1bNV/0N81a07R3LP23SWd0KGQW069_G@1LJEL0FFIC
05=QC`1GI5`0G6UU065^JP1LJFD0FFIR05a[IP1KJVD0FFQR04QHDP15Ee00@E=<03a>AP0jBT00>DHl
03Y7?`0lAd00<chg03E0>`0kAD00=T0k038k>@0^=S@0:S4`02/c=01IHf@0<cm0030l?00e@D40;3Pg
030l>P1DH5h0=D4n038n>P0jAT80=D4m034m>@0^?CP0<d<n03E5?`0^?CP0<D0j02<a:P0Q;RL0934Y
02@_:00X<b`09C0X03<n=P0X=2h08bhZ01l[9`0R;2T09Bh[02@[:P0N92<07R<R024U900P8R406Q`K
01hP7P0_<c407B8O01XN700N8b0051PG01hR8@0O8b808BDT02<W9P0O8b808BDT02T^;@0L8b807RDU
020W9`15Bd`08BHX02DZ;00K7b0071hL02@V8`0L7QP08bHM01/N5P0K71P07AdK01XJ600H61H06ATG
01`L6P806a/I00@06ATG01dM6`0J6QP051@B0`0I61@0100H5a<05aHB01LF4P0H5a<301LF4P0801PG
4`0E510061LC01DD400G5Q804a8>00h=2@0E510201@C3`0401<B3P0B4@d04Q4=018A3@804a8>00h0
4Q4=01HE4@0F5A404A0<01DD400I61@05QDA018A3@0C4Ph051<?01<B3P0?3PX051<?01HE4@8051<?
0P0H5a<01`0D4`l030/6010?2`0E4@h03PX701dI5P0C3``00P0D40d01@0D4@l061@A014=2P0@30X0
3`/800804@d:00`04Ph;01<?300>2PL04Ph;034]:P0@30T05a<@010<2@0H51402@D2018?2`0C30T2
01<<1P<040/700`04`l<00l;2@0G5Q<08QlN010>300=2`T04`h;018=2P0A30T040/8018=2P0C3P/6
010;2006018=2P0@2`T07QTF00X5100D3``05A0=0P0@2`P0100?2PL040/8014<2@0?2PL200l92@04
01/E5@0H4Q803PP801TC4`804P`<00X04`d=00h8200>20P050h>010;2@0E3P`03`X901@>300?20H0
40/80P0?2@H0100>2@H03`T600l91P0@20H301<82@0?01882@0A20T04@P9014;2`0@30/05A4@00T7
1P0D4Q006AHE014;2`0@2@T03`T901092@0A2@X04@/;00803`P800D02`D5014:2P0F3`l04`X;0147
200501882@0:0147200@1PL04`T:01@:2`0B20T040D801D:3P0F2`l04PL;01H;3`L04@H:00l0718D
00d8200I4Q8030H601<=3@0<1PH04``<01H@400@20T040X:018<300<1@D040L801061`0B20T00P0C
2@X0200B20T0308301061`0B20T04@L801<92P0@1PL04PP9100A1`P00`0>10D04`T:01@:2`0201H<
3@0@01@:2`0A1`P03`D60147200C2@X040L:00l62@0A20/040T<00P31@0C3A40100403`g?00P6al0
4PT:01881`804@L60P0B20L01P0@20L0:b4P00T0000I3`h03PD401471P<03`D40`0@1PD301471P03
01881`0C2@P04@L601Cooooo000Kooooo`0401D?3`0D3Ph04P`<014;2`8040X:00@06A<C014;2`0D
3Ph03@L70P0?2@T0700@2PX04@/;00T30`0@2PX04@/;01XD500A2`/040X:00l92@0A2`/04`d=01@>
3P0W8b0040`901DA3P0B3P/04`l<014=2P0>2PP04`l>010<2`0?2`X02PH501HB4@0;1`H04@d<01<?
3P0B3Pd2014=300401<?3P0A3@`04@d<00l;2P803@T800@03PX901@@3`0E4A004@d<0P0=2@P01P0B
3Pd04`l>01@@3`0D40l04Ph=014=30<040`;00<04@d<01<?3P0C3`h00P0C3`h01`0B3Pd040`;00l;
2P0@30P04@h9014=2P0A3@/00P0A3@`0300G4a0040`900d:1@0Y9R800`0001<?3P0J5aL03@/<00`:
2`0Q7b003`d>00H41@804@l@0P0;2@X01@0>30d030X;018@3P0@30T04@d:00804`l>010040`;01@@
3`0@30/03@T8010<2`0B3Pl04@d>00P71@0I61H030/:01/J600;2PP07A`J01@C4@0B4@l04A0>0P0C
4Q00100?3P`04`l>01TE500J5QD201DA400P01@@3`0@30/04Ph=01DA400D40l04Ph=018?3P0@4@`0
2`h701TJ5@0;30L03@`9018A3`0B3Pd04Pd<018<300B30h050h?01L>3`0=1@<05`l<01P@3P0E3@/0
:20N04Dm>`0J4A806Q4A01TD4@0H40h0FeEB024L6@0D4`h301<B3P0Q01DD400F5A40;bh/02HU8`0K
6QP06aLF01<?3P0E4A008alP00l:300E4A806A<E01TD5@0G4a@04@`=01H@4P0T82404Pd>01`F600B
3Pl04A0A01PH600J6QX051@D07IfMP3Jf]X071`L00/;2`0E5AD04a<C01DE5@0F5QH05aHD008061LE
04X05aHD01TI5`0K6aT061PF01<E4P0G6AH06A/H01LI5P0I6aP05aTD014C3P0K7AP06A/F01lQ700K
7AP05ALB01`N6@0M7aX06A/F01LI500G6QD061dG01TN600J7aX06b0L01`Q7@0L81h06alN01dQ8P0O
8bD07R8U01dP9@0K7b<08BDX02@X:@0_=3@0IfeY02D[9`0M8al08RPT01dV8@0J8b408BXY028Z;00O
:2P08BXY024Y:`0S:bd09Rha02L`=@0S;380:c@k02dg@00/=T00:SM002Da?00T<CT08Rlg02/h?P0a
@4<0;Shn0310@00dA4@0;Cdm0350A00a@4L0>dYA03Y:DP1BIVl0@eUT03U?FP0nDEl0?e9P041CH@80
@eIT00/0?e1O03i@GP14EV@0@U9Q04AFI00nD5h0?U1M04=EH@10DUh0@eEP04EGH@0204EHG`0C04=F
G014Eed0CF1V059SK@1AHV`0C5eW04UJI01HJG40CUmV04IGGP19Feh0@eEE055THP1HJfP0E6MS04mO
GP1CHf<0EfMW05YZJP0205][J`80I7Ad0P1UMGD206IfMP080720P01/O7`0KWin06moO`1`Oh00MXB5
07F3Q01jQhP207n:S00K086<SP24Si40QI2D08:=T@2BWJ40UIjS08jGW02AVZ40V9nW09jU[@2W[[H0
Yj^d09nS[02PYJ/0YJZ^0:b`/`2]/K@0ZZfb0:f]]@2_[kL0/;2h0;:a^@2e];`0/k:k0;Fc_P2l^L@0
`ko>0080a/;A0280bL;B0<g7e@3?amH0e<[J0=O<g03FbMX0g]7R0>;EiP3Md>40g<kO0>CCiP3Ue>L0
jMOZ0>cIk@3]f>d0kmW`0>oGk`3^e^h0kmO_0?3Hl03bf_80lmgd0?GMm@3dgOH0l]_e0?7JmP3ag?L0
l=cg0>kJl`3[f?00imKY0>?Bi@3Qd>00elWF0P3A`m005`3:_/X0ak_50<Bi`P37_LD0][2d0;bf^@2i
/kD0/Zb/0:j/YP2b]:T0ZZZP08R:O`2:SH80SI2508J9O`1cNFl0L7M]07b2N01]MFX0OhIk08F=P021
RGX0N81a0080LGU/0P1dOg408P1XLfD0GFUM05]WF`1FHUH0CU]@05IWH@1FIV<0G6aY05a]I`1GIV40
EFAM05QWH01BHUP0CUiD04QHCP0oCdD0?De2045>A`0gA3d0>TI103I2?P0d@3`0>4A202lk>`0oBd/0
<S`n02Tb=`0b>d0092h`03Y6AP0b?S`0<3`j03]7A@0/>3H203<o?@04038n?00[=cD0:cLe02`h=P80
9C4]03T0;C/d038o>00_?3D0:SHa02Xe<@0h@cl08bdY02lh=@0Z<c00:S8_05mUH@0k@S/08bPS02P/
:`0n@T406alQ038f>@0Z;S40:b`_03@f=@0J71/08B<O01PJ5@0K81X0724K01hS7@0Q9R008bPT02@Y
9@0O9200:BhZ01hS7`0W:bX0;S8a02@X9`0U:BL09BTX02<W9P0P92<08R@S02@V9@0N81h05aTF01`N
6`0L7QX061XE01TK5P0J6QP05aLE01PH5P0K6aT06ATG01LG5@0M7A/06a/I01TI5`0H61H00P0F5Q@2
01HE4`0A01@C4@0C4Q008R4O02HU8`0E51805QDC01LF500E51806aXH02h[:P0@30/081`K01DA400I
5A@05Q8A01@@3`0G4a800P0F4Q40100G4a806ADD01PD4P0D40d201<?300J01DA3P0H51405Q8?01DA
3P0G4a005Q8?01<?300B3P/0510>01<?3P0I5A@040`;01PD4`0E4@h04a0;018?2P0C40/0514<01DB
2`0C40/09b8O01PC400B3@X04`h;00d81@0C3P/3014<2@08010;200?2PL03PT600T50P070`004a0>
01DA3P0@30T2018>2`0700h:1`0A3@X05A4>014=2P0@30T03`X6010;1`02014<200;018=2@0C3PX0
3`X6014<200B3`X06A@A010<200E40`04`h:018=2@0A30P00P0?2PH01@0=20@030L3010;1`0A30P0
40/700803PT500l04Ph;00X60`0:1P<03`/8014=2P0<20D06QHC00`81@0B3P/0510=00`81@081040
5A0=018=2P0@2`P00P0A30T0500?2PL05Q4>00T40P0=20D040/8014<2@0I51404`/901@:2@0D30X0
50/:01@:2@0B2PP03@@301061@0@20H04PT801<9200B2PP03@@50P0B2@X01`0A2@X030H600P20P0<
1PH03@L700h8200>2@T00P0@2PX01P0Y82404PP900H0000P5QL09adN00L000804PP90P0@1`P01@0@
1PL04@L901H;3`0E2Ph040D900804`P<00<03`@801052@0A1PX00P0B1`/0700@1@T03@8601052@0I
3Q803`D800l4200H3A4040D901dB5P0A1PX04@P:01@93@0700004@H900/20`0@1PL04@P900X10P0<
0P<04@L801482@0C2@X040H700h51P0D2P/05P`=01<92P0A1`P301061`804@L80P0@1PL00`0A1`P0
4PP901881`0201881`0301471P0@1PD040H500H04@L602@03P@500l51P0A1`P04PP901<92P0D2P/0
3P@501@;300?1PT04@P;05]BE@0j<C<03@<400h41@0@1PL03`D60147200D2P/0DDM801lE5P0e:b`0
2`4200`4100?1@H03`D401@:2@0@1PD03`D401881`0@1PD03`D400T1000E2`X01`0001881`0<0P4D
ooooo`006oooool02@0E3`l050h>018<300A2`/040X:014;2`0=1`L050h>01H@400201PB4P0701D?
3`0=1`L04P`<01LA4@0R71`0618B00h82002018<3007014;2`0B30`050h>01D?3`0X92<05A4@01TE
5002014=300800l;2P0>2PT04`l>00d9200A3@`02`L6010<2`0>2PT2014=3004010<2`0?2`X040`;
00T510804@d<0`0?2`X0200B3Pd040`;014=300C3`h04@d<00h:2@0?2`X04@d<0P0B3Pd00`0?2`X0
40`;010<2`02010<2`03014=300B3Pd04`l>00804`l>00@04Ph=010<2`0?2`X040`;1@0A3@`03P0<
20L03`/:02@P7`1;AdH06aLF01<?3P0;20P03@/<01hL7@0B41402`T:01/I6P0=2``0518C0P0C4A80
0`0G5AH03@/<00d:2P02014=30804`l>00`040`;01@@3`0A3@`03`/:014=300C3`h04Ph=01/J600C
4Q004Q4?00D40P0A40h201<B4009014@3P0@3`d04Q4?018A3`0?3P`03`/:01DA400G4a804`l>0080
510?00h04Ph=01@@3`0E4A004Ph=010<2`0@3@/03@l:00`A2P0;3@P04Q<>01DE4@0?3P`04`l>01<>
3`804`d?00l05PhA01L>3`0I41406Q8@01D=2`0B2PP0610>02@L6P0A2@L05Ph<01/C4@0;0`40:b<Q
00/60`0E4Pd00`0B4@d07P0D4a005A@B01LF500J61P040h?01DC500B41405Q@E01<?400G4A<050h@
01LA4`0P6Q`030H801@>400f<380AT1201lI6`0L5QP05Q8C014@400G5aL06QXJ01HF5P0d=3@0EUIF
01TI6@0C4a<06ATI01<C4`805QHF00P06ADD01TH5P0H5aD05aHD01LG5@0H61H05aLE01DG50806Q`I
014051TE01HK5`0J71L061XE01DG4P0G6A@07AlJ01PJ5@0M7aX08B<N028T7`0N81/07AlJ01/N6@0I
7QL06AhH01XO6P0201/P701Z01`P7`0L82407B4R01hR900N8RD07R4V02d_=00J6al051PI024U900X
;BT00`X302@[900Q:2407RLR01`U8P0R:bX08RX/01lX:00Q:RL08R/Z02@/;@0V;S009c0e02Tb>00U
;SD09S0j02Td?`0U<Cd0;SY7030j@`0]>3h0<3/o03=1@P0b@440>4I603M7A`0b@T80=dI;02m0B00f
Adl0=DMA04QNJ`10EV<0?59O041FH`0nE640?U5O049EH`0oDV00AEMU049DHP17EfH0Be]Z049DH00m
Ce/0@59N04QJIP19FfL0CV1Z055SK@10DU`0?U5H04=FG@0oDUT0CV5X06EeQ01AHG00G6ai04iOJ@1;
G6@0C5iR04mQI@1HJVX0Cf9N059UH@1?He/0CV5K051PG`1CHf<0EfMW05UYJ@1LK6`0GFe]06=cL`1T
M7@0IGEe06IfMP1WMgL0J7Qh06alO01YNGT0KGem06inOP1^OGh0Lh6207J1P`1kQXP0OXV;07n9R`21
Rhd0Q8j@08JAU`28TiT0W:N]09jW[P80TY^R00L0V9nW09ZQZ@2PYjl0XJF^09jRZ`2QYZ`0YZ^^0080
ZJf`00D0Z:^`0:^[/`2/[;@0[Zjf0;6_^P020;Jd_`060;Rf`@2m^lP0`Kg=0<K2d@37`m80b/?C0P3;
aM<02@3AbMP0elcJ0=C9e`3Gc=X0fLkL0=G:f03Mcmh0j]c[0>WKjP020>SGj@030>WGjP3[f>`0kMO^
00<0kMO^07P0k]S^0>oIkP3_fO00kmWa0>kJl`3^f_D0k]_f0>_Il@3Yenl0i]GZ0>;Di@3Nd>40g<kK
0=C7d@3>`L/0cL3:0<Fj`P32]kl0_kJk0<6h_@2c[K40]k6c0;6[[@2YXjD0YZBN0:RZW@2TYYT0Rhj2
08J9OP21Qg/0M7Y_06meJ`1gOg@0N7mg075hL01cNg40OXIi07R0L@1bNV/0Lg]^07InL@1dOg40K7I[
06I`I@1QKF<0Gf]Q05aXGP1MJf40FVYW05EXIP1HJfL0FV]U05IWH@1JJF80CemE04UIC`18ED/0@e16
03Y7?@0gA3T0:CH_03<o>`0mBDD09S8`02/g=@0`?3`0>4=503I1@`0b?D4082/a03a7C@0g@TH0@dm?
03]7A@0/>3H0:cLe03E1?`0/>3H0<Cdk030l>P0[=cD0;3Pf02hj>00W<bl08BdY02Db:`0[>340;STc
02/f<@0W<Rh0<CXg02Pa;`0Y<S409bd]02<Y:@0a=cD0:R`W034c;`0K7AX0:2T[024R9@0720d08b@Y
01dN8@0U9bH07AlN02HX900M81T06b0I020U7P0S:24092TS02<X8P0R9b408BHR020U8@0B5a<05QXI
02L[:P0T:2L2020R7`0601lQ7P0N81d0828O028T8@0N81d061XG0P0K7AX0300L7Q/0828O01/K6@0H
61H06ATG01`L6P0K6aT06ATG01dM6`0J6QP06ATG01LG5@805QHD00L061LE01HE4`0G5Q@05A@B01`K
6@0Q81h05aHD00804a8@00X05QDC020O7@1^K6X0<Bd/00<0000F4Q406QHE010<2`0I5A@05a<B0P0F
4Q401@0H51<06ADD01HB400B3P/04`l<0080510=0P0C3``201@@3@09018>2`0A3@X04Ph;01@@3P09
1@@03PX901<?3P0Q7A`0>CDb00803``700@04@h901<@2@0D4@X0514:0P0A30T0100@2`P04`h;01LB
3`0E40d200l:1`804Pd:0P0C3P/0300I5A8030P500l;200C3``05A4>010<2@0D40d04@d:01<?300G
4a00510=018>2`8040/70`0A30P01`0B3@T050l;01<>2P0B3@T03`X600d8100910000P0C3PX2014<
2005010;1`0?2PH03@P4010;1`0A30P00P0?2PH03P0@2`L030P500d91P0?2`P040`9014=2P0?2`P0
0`0002PT8@0e<Bh07ATF01@@3P0C3``03PT60P0=20D02@0>2@H03`X700l:1`09104040/801HA3P0>
2@H02@@100h91P0201@:2@805@/:00<050X901<9200A1`H00`0B20L0200A1`H03`L501H>3`0A2`/0
3PP8010:2P0E3`l05Q0@1P0>20P01P0A1`P03P@501L=3P0S6AX0DTQ901lE5P804PP90P0A1`P01@0@
1PL04@H901D:3P0E2Ph04@H:00805@X>0P0B1`/01`0C20`050T=01@93@0D2@d05``@01D:3P0F2`l0
0P0C20`03`0D2@d0304501<8300A1PX05P/?00L0000:00<0=2X/01D;300C2@X05@/<01061`0>10D0
40H70147200201<92P050147200B20T04`T:01882@0A1`P00P0@1PL0100A1`P04PP901882@0A1`P2
01061`050147200B20L04PP701881`0A1`H00P0@1PD601471P803`D601`040H70147200B20T04PP9
01D;300B20T030<300/10P0M4a@05@/<00h41@0@1PL04@L801061`0B20T05@/<0;F[[00e:b`060h?
01D;300K4A801`0000h40`0A1`H03P@300l5100B20L03`D40P0C2@P0100F30/03P@301061@0I3`hD
ooooo`006oooool00`0E3`l050h>018<3003014;2`0600`61P0D3Ph030H601XD500=1`L05@l?0P0A
2`/0100E3`l09AlO01/E5@0:10@201<=3@08018<300C3@d050h>01@>3P0A3@`03PX901DA400@30/2
01DA4006018>3@0M6AP04@d<01HB4@0B3Pd03`/:0P0B3Pd05`0@30/03PX9014=300B3Pd0510?01TE
500B3Pd040`;018>3@0@30/05A4@00d9200>2PT05A4@01@@3`0A3@`04Ph=01HB4@0H51<05a<B01<?
3P0B3Pd04@d<008040`;00<04@d<018>3@0C3`h00`0B3Pd00`0A3@`040`;010<2`05014=300J018>
3@0?2`X04@d<01PD4`0;1`H0510?010=3@0>30d0518C018@4@0;2@X03`d>014?400E4a@03@/<014?
400F51D03P`=010=3@0A3@`04Ph=01<?3P0D40l04@d<01@@3`0C3`h2018>3@0301@@3`0C3`h040l=
008051<A00<04Q4?010?3@0@3`h00`0@3`d01`0A40h040l=00h=2`0=2@P04Ph=01<?3P0A3@`00P0D
40l201HB4@0A01@@3`0A3@`040`;018?3@0>3`X0;c8[00h@300B4`h03@d9010?3@0D40l04`l?014=
3P0B30h04`d?01<=3@0F3@h00P0C2`T01@0G3`d06A4?01H>300C2`T050`:00808ATG00@06Q8@01<>
2`0E4Pd04a8=0P0B4@d08@0D4a005A@B00h=2`0O7Qd040h?01LE5P0C4A805A<D01DB4`0F4a@061DF
01DA4P0F4Q<061DF01LD5@0G4a@07Q/L01@A4P0K5aP05A8C01DD5@0H61P04A4A01@D500H61P04Q8B
01DE5@0J6QX06a/K01@D500J6QX05ADE01PD4`0201XI5`0E01LF500D518051@B01DE4`0G6AH06adJ
01PJ5`0C61@05a`H01PJ5`0J71T06A/H01XL6@0D5Q<07AlL01/M6P0M7a`071hK01XL6@0K7AX071lJ
00806QlI02d06QlJ01XO6`0J7Qd0720O01dQ800L8240720R01dQ900O8bH07R8U02P/;`0n@T<07B4P
02ld<00T:b@07RDN020X8@0O:2<082TV028/:`0P:R/082TY02</:`0T;B`09Bl_02La<P0Y<SL09S0f
02hi?`0Y<c`09c8m030lB00a?TP0>49;03@oA@0a?400<3ho0390@@0jB4P0<T9202hn?P0eAd/0<dA<
03Y;D`0fB5800P0mD5h0:014EfD0AEQV041BH010DV00@55O03E6E@18EfH0?diM04=@H01:F6L0@U=O
03i@G010DUh0AeUU04YLJ01>H6X0A5IP03a>F018Ff80AEQO04ULH`2<WjD0enOc06AdPP1MKGT0FFYd
05AUK@1?HFD0CV1S05a^KP1EJ6@0DFAP04YMEP1AI5h0Df=R05ATI01FIVH0F6QX05e]K@1PL70206Ad
M080IGEe0P1VMWH0701[Ng/0JWYj0720P01bPX80L7n007>1PP1eP880NXF707f8RP1nR8X0P8Z<08:<
SP25T9D0Q8nE08jIW`2BVj80T9VP09>LX`2HWjL0UijV09VPZ02MXJX0Wj>/0::W[@2RYj/0X:BW0:6U
Z02XZk020:j_]0060:b/]02b/KT0^KS00;Zh``2k^L@0_kg90P31_L`01`32_/d0aKk>0<W3d@3>b=H0
c/KD0=O?g03Fc]/00`3Db]D0<03Kc]d0jM_Z0>OIj03Pd^<0hM3R0>CCi@3We^T0jMK/0>_HkP3Ye^`0
j]C[0>[Dj@3ZeNP0j=GX0>SEjP3Ye^`0jMK]0>OEk03RdNH0gm3T0=k?h03KcM/0f<[H0=C7d@3<`LP0
b;g40<Nl`@2o]KT0^k:f0;bc]@2aZj`0[:JW0:nZZ02`[:X0YZ:P09fNUP2=TH<0QXYl07]oLP1bMFX0
KG=W06abI`1cNFl0O8Ai07ElM01gOWH0LG]b06ifJP80K7AW01d0MGe`07V1M01dOW<0Kg]a06]gK@1W
LfT0HFiU05i[HP1RL6P0IgMa061`K@1JJVL0EfQR05=TGP1FIEh0Be]A04UIC`1:Edh0A55703e:@00h
A3/0=d@m03U5@@0e@Cl0>TI406McL@0hA4@0>dI802Td=P0203M2AP0^05QSJ00^>Cd0D5aL04UED`0a
?C/0:SHd04EAC`0^>SP0:cLe02Xf=00X=380:cLe02di=`0S;b`08bl[028_:00U<R/0:SDa02Pc;`0Q
;2P0:S<`02Tb;`0O:2D09B/[02hd=00S:BL0:B/X02PZ9P0V:2D07b0R01lP8`0S92P06Q/O028S9P0T
9RD08bDT01hP700R91l0724J020U7P0R9b008RLQ01lT7P0M8Q`082DQ02HZ:@807b<R00T08BDT01lS
8P0T9R<092HS028T8@0O8Ah07R0M020R7`0M7a`00P0K7AX0100J71T07R0M02@V8`0L71X201/K6@06
01dM6`0L71X06a/I01`L6P0J6QP061PF0`0G5aD01P0J6AL05aHD01TH5P0G5Q@05A@B01LF50805A@B
00/05aHD01@C4@0G5Q@07a`K01@@3`0N6QT0510?01TE500K5aH05A4@01LC4P0201HB4@805a<B00T0
5Q8@01DA3P0F4Pl05a<@01@@3@0B3P/0510=01LC400H51400P0F4Pl0200I5A806ADC00d9200D40l0
71PG00l;2P0C3``04@h90P0B3`X0200A3PL040d6018?200D3``06A@A01<>2`0>2@H05A0=0P0A30T0
4P0B3@X04`h;01<>2`0C3P/04Pd:01TE4P0<20D04@d:018>2`0E4@h03@T601<?300?2`P04Ph;01HB
3`0B3P/040`901<>2P804Pd90P0A30P2010;1`06018=2@0G4Ph030L302@O6`0H4`l04@`8100B3@T0
500A30P040/7014<200?2PH03PT500l:1P0B3@T02PH300l;200A3@X040`900h:1`0?2`P0;RXW0:NS
X00M6AH05a<@00h:200?30X03`X70P0@2`P00`0A30T050l<01HA3P02018=2P0500`71@0D3``061<@
018=2P0C2@P00`0D2PT201<9208040H500`04@L601<9200D2PT050`:01082@0>20P040X:014;2`0B
30`050h>010:2P0?2@T200h820803@L700L06a4B01D;300?1`L05@/<02HL7@0>1@D04PP900@04@L8
01004@L901<8300D2@d04`P<01D:3P0F2`l050T=01872`0@1@T03`@801052@0B1`/04`T<01062@0A
1PX050T=0P0?10P201<8300800l4200@1PT03@@602/Q9013>3/04`T:00h41@0A1`P201882@0301@:
2`0B20T04PP9008050X;0P0A1`P01@0B20T04@L801061`0@1PL04PP9008050X;00@04PP901061`0@
1PL040H70`0B20L00`0A1`H040H501061@0601471PL040H700H03`D601<:2`0L4Q<03`D600h41@0=
0`@200l51P0?00h41@0@1PL04`T:01T?400@1`P04`T:01061`0=10@04@L800l5100>10<030810106
1@0E2`X03P@3008040H500@03`D4034W9P0H3Pd03P@35?ooool001_ooooo00@050h>01<=3@0A2`/0
4@/;0P0B30`03@0E3`l04`d=024K6`0f<3006A<C03H`<00E3`l04P`<00X4100D3Ph04`d=01H@400A
2`/00`0B30`2014;2`0>01DA400H51<06aLF014=300B3Pd03`/:018>3@0W8b805A4@01@@3`0C3`h0
510?01<?3P0B3Pd2014=300501HB4@0I5A@03PX900h:2@0?2`X00P0B3Pd01@0>2PT03`/:014=300B
3Pd04@d<008040`;00P03PX9014=300C3`h04Ph=00h:2@0@30/04Ph=014=308040`;00<04@d<018>
3@0A3@`00P0B3Pd00`0A3@`040`;010<2`05014=3003010<2`0>2PT06ADD00805Q8A00h05A4@01DB
4P0@3Pl01@<401@B4`0B41402PP9010>3`0:20T04@l@03@b<`0Q7b002@L8014>3P804Ph=0P0D40l3
014=30804Ph=00/04@d<018>3@040`403@`:00L61@0<2`T03`h<01TH5P0=30X03Pd;010?3@0300l>
300701<?3P0E4A004Ph=014=300C3`h04Ph=01@@3`0201DA400;01<?3P0D40l05aDB0=GFd@2d]Jl0
5QLB0042000B4Pl06QTG018A3`0B40l00P0B3Pl03`0C3Q0050h>01PB4P0G4Pl05A0=01@?300F4@h0
5a8?01PC400K5Q<06A@A02<N6`0H4a005A0=01LD3`0301@C3`0401HE4P0G5Q@061LE02LU9@806QPI
00l0518C018@4@0:20T05QDE01XJ6P0=2``02@P801PH600A414081hO020P800A41005Q@E01`L700A
4A400P0M7Ad201<C4`0301TI6@0E5AD05QHF00805ADE00H071`L018B4P0I5A@06QTG01/J600G5Q@2
01<C4@0<01HF500D5Q<05QPE01@F4`0C61@061dI01dO700N81d04aDB01LI5P0I6aP061XG0P0M7a`0
1@0L7Q/06adJ01dO700M8A`06QlI00<06QlK05D06QhM01`P7`0M8B00720Q01/O800M8B807b<V028V
:@0N8RD0;C4b01TN700P9R809bhW01`U7@0N:2007bPS028]:@0R;2/07bTZ024[:`0T;B`092h_02H`
<P0Y<cD0:C@h02Pc>00[=S`0;CY202llA00U<S/0;CU4030mA@0`?D<0;S`o02hl?@0`?Sl0<D5003M7
A`0_?cl0=dU=041AF@1;G6@0@59L03Y<FP0kCE/0@UAR045CH@0nCUd0A5AS04EBHP0oC5`0BEIV04EA
H@1:EVH0B5EU049BG`0oDEd0?U1L03mAG@13EF40@eEO05QZM017FF<0?E1G04EHG`1DIfh0HGAj09:S
[@1JJWL0H75k05EVL01?H6P0BeeQ04eOH@1@HV40BUeI04iQG@1;GUP0EFQT05EUI01EIFD0EVIV05UY
J@1NKVh0HG5a0080KWin01X0K7al06YjNP1YNGT0J7Qh06YjNP1[Ng/0LH6107>3P`1bPH40M8:307F0
PP1iQ8H0NhJ807b6R01nR8X0P8Z<08NBUP24Si<0QI2D08ZCV02AVYl0Uj2U09ROY@2JXJL0Vj:X0:2U
Z`80XZN]00@0Y:V/09jRY@2OXjH0YZZ]0P2/[K80LP2^[k@0];>k0;Zi`@2i^<00^;K10;bja@2o_L/0
a/;A0<g9f03;amD0bL?A0<c6e03>b=@0eloL0=O?fP3?am80c/C?0=77dP3Hc=X0f/kL0=W=f`3Md>40
gm7R0=k?h@3Sd^D0iM?Y0>ODjP3VdnT0i=7W0>?Ah`3Udn<0imGU0>OEj03RdN@0g/gP0=c<g`3Jc=d0
f<[I0=K:e@3Cb=00d<G=0<Zoa033^[d0`[Vl0<:i^P2k/[<0^[6b0;fh]@2]Z:D0ZjNT09VFT@2RWiX0
TY6<096BR@25RG/0OX9d07b1M01dNVh0LWQ/06ieJP1RJUl0IfmT06egKP1RK6<0IW1W06A/H@1YLFH0
LWY_075kL01`NVl0LWac06ahKP1ULFL0HVmV06UfK@1ZMfh0JGM`06UhL`1QLV`0FfaV05QWHP1AH5/0
C5]D04EBB`16Dd`0AE99045<A00lAcl0=40g041;A@0oBTH0<3Xi03@n?@1ZM7<0<S`m09bVY`17DE80
:38d03e7B@0Y<cH0?DM9030l?00_>cT0930^02lk>@0[=cD08Rh/02lk>@0]>CL0;3Pf030l>P0_>cT0
8Bd[024]:@809C4]01H08RdY020[9`0Q;2P0<CXg02Pa;P0O:2D07bDS020V900Q9bD0;2h[020R7P0Q
8b008R<U028S9P0:2`l09bP/024R9@0J71/07R0O01/M6@0W:B@07B8L0`0L8A/0500M8Qh07R<O01lT
800P92<05a/J02X^;@0P92D092PW02LY9P0V:2D08bDR01hP7@0M7a`07R0M01XL6@0N81d071hK01PJ
5`0I6aP06Q`I0`0K6aT201XJ600301/K6@0J6QP061PF00@05aLE00h061LE01/J600F5A<04a8@01HE
4`0G5Q@051<A01HE4`0J6AL04a8@00l>300J61H06aLF01@@3`806QHE00<061@C014=300D40l0100D
40l0100F4Q0061@A01HB3`0D40d201<?30804@d:0P0D40d201<?300901HB400H51<04`l>01DA400K
5aH06ADB014>2@0B3`X04a0;00804@h700D05Q<<01<>2`0@2`P05Q4>01PC4002018=2P0C014<2@0B
3@X04Pd:014<2@0@2`P03PT600d91P0H5140;2PU020L6@0A3@X0510=014=2P0=2@H040`901@@3@0@
30T03PX701<>2P02018=2@09014<200@2`L040/7014<200@2`L04`h:00@0000K5Q802PD100@03`X6
0P0@2`L2014<200N00l:1P0>2@D040/701<>2P0K5Q<04`h;00l:1`0B3@X04`h;00l:1`0;1P<0;RTV
00l:1`0400003PT600`7100=20D040/800h91P0<1`@03@P5014<2@0910403PT600X50P0D3``05a8?
00h91P0B20L04`T80P0D2PT201881`803`D400X040H501<9200F30/05`l=01@=3@0:10@02`D500d7
1`0C3@d071HF0P0=1`L02P0>20P03`T900l92@0?2@T05Pd=01<92P08000050X;00l51P0G3@h50147
200401882P0B1`/04@H:01872`8040D900<05``@01/@500F2`l00P0B1`/0400D2@d05P/?01872`07
00004PP;01T>4P0<0@D02P4301<8300B1`/05@X>028G6`0F2`l03`H701<92P0B20T201<92P0701X@
4@0M4a@04`T:01061`0A1`P04`T:01882@020147208040H700H04@L801882@0D2P/050X;01882@0@
1PL200l51P<04PP700<04@L601061@0@1PD01P0A1`H2014720@040H700L06@l@00h41@0B2@X02`42
00d3100B20T03P@5008040H701D03P@500l51P0B20T02P0100/30`0700004@L801<92P0E2``04@L6
00l5100>10<04`T801P>3@0@1PD050X901061@0A1`H0@3He01`B4@0?1@@05?ooool001_ooooo0P0C
3@d2014;2`0?018<300C3@d04`d=014;2`0Z92@0>38b01H@400Y8b<04@/;01D?3`0?2@T050h>014;
2`0G4A404@/;00<04P`<00h040X:00l92@0B3Pd05Q8A01TE500A3@`04Ph=00d9200@30/08AdL01<?
3P0?2`X03PX901<?3P804Ph=00@04@d<018>3@0G4a806QHE0P0B3Pd01@0I5A@05A4@00d9200?2`X0
40`;00804`l>00D03`/:00h:2@0?2`X040`;014=3002018>3@04010<2`0A3@`04Ph=014=308040`;
100A3@`00`0B3Pd04@d<010<2`06014=300E01@@3`0:1PD03`/:00D10@0?2`X04Ph=01HC4`071@H0
3`d>00P61`0:20T06ALH00`:2`081PL03P`=02l];P0L6Q/02@L801@A4@0B3Pd04`l>0080510?01P0
4Ph=00l;2P0A3@`04`l>018>3@0@30/04Ph=01`K6@0:2@L05A@B014@3P1>CD/0FeYH00d<2P0?3P`0
4A0>010?3@0?3P`04A0>01HB4@0G4a804Ph=014=300D40l2014=300=01<?3P0D40l0510?01DA400I
5A<0MWEa06AUG`0@4@`04Q<>01PH5@0?3P`051<A01@B4@0201DA4P0?01LB500I4a<05@l?01LB3`0D
3``04@`901@?300J5A8030L401`G500E40d04@`900l:1`0I5A8061D@00<05A@@00D05aHC01PG5@0F
5A<06ALG01/I6P0201DC500801@B4`0I6AT07AdM010@400X:2P0@D51014A4@0@410201HF5P0@010@
400;2`/03@d=01DE5@0C4a<061PH01<C4`0B4Q806a/K01PH600E5AD061PH01HF5P0J6QX04a<C01TE
50806aXH01H061LE01HF500F5Q@06ATG01<E4P0G6AH061XG01DJ5P0G71P09RPU02DW900Q8b007AlL
028T8@0>40d07AlL01hP7@0L7Q/06adJ01`N6`0L81`06QlI0`0J7a/0100J7Qd0720O01`P7`0L8242
01dQ8P1?01hR9@0T:2/05QXM01XN7`0K81l06b4M028Y8P0N9al07RPP01dX8P0R;BT08B/Z020Z:`0S
;Bd09Rl^02D_<00W<C<0:S@f02/f>P0_>Sl08bhd04QEG@1WM7d0;S]402hjA@0^>d<0<Ci4034o@P0`
?Sl0<d520351@00hB4P0;Clo03E7B`0mCUH0AUMO03]=E`0lCU`0>deK03m@GP0oCeh0?DeL04QEI@14
DF40Cea/04]GI`16DV80CEUY04QDI011DEh0@59N03i@G010DUh0AEMS04EGH@1<GVP0AeUS04AGGP1;
GVD0DfI]04IIG`1NKgT0EVMa05e^MP1KK7@0F6U_04mQH`1EIfL0D69Q04QKF@1>HEd0BUeG059UH@1E
IF@0EVIV05QXJ01KJf/0Gfm_065aL@0206]kN`0P06QhN01WMgL0IGEe06AdM01YNGT0J7Qh06inOP1`
P800Kgio07B2P`1fPH<0NXF707b7R@1mQhT0OXR:082:S020Rhl0QI2D08ZEV@2=UY/0SiRM096JW`2G
WZ@0Vj:X09bSZ@2RYjd0XjR^0:2UZ@2X[K00XjNZ0:2TY`2RYZT20:JW[00:0;2a]P2d/k/0^KS00;Nf
_P2e/kh0^KO20;^iaP3<b=L0f]KU0=GAg`80a/3>00L0cLOC0=79e03AbM@0b/;=0<Jla`39_lX0f<cJ
0080eLWG05L0gm;S0>;Di@3Ncn40hM3S0>;@iP3SdNL0hm3V0>;?i@3Rcn40i=;P0>GCh`3Sd^<0g/gO
0=W8fP3Fb=T0e/[H0=?7d`3AaLh0cL;80<Zoa@33^[`0_[Jd0;je]P2n][@0]:n[0;>^Z`2e/:`0ZZNP
0;Re[P2CT8T0WYjD09>CR`2=T8@0QHUk08:6N026Rgh0OhEi07IlL01^MFT0IViS06ifJ`1hPWT0Ig5X
06I`I`1SJf00Jg=X07EmLP1_NFh0K7I[06iiL01bOW@0JWE]06IcJP1]NW40JgQa06AbJ`1QL6/0FV]U
05MXHP1IJ6<0DV5L04]JD`11CTL0@e19045>A@0lAcl0>TDm03<n=@1ZMG40DeiJ03U3@P19De80LWak
03<m?P0X<S<0:C<d02hh>P0a>cd072HX02li>`0^>SX0;c/i038n?00oBdT0;3Pf02di=`0/>3H00P0Z
=S@0100^>SP0;3Pf01/W9@0L:2@2024]:@0`01lZ9P0P:bL09C0/02/d<@0U;R/0:34^02H/:P0K8Al0
82HR02H[9`0L7QX09bTX02<U900S92L0D55E05AEF@0V9bT05ALF01`N7@0Q8b00828M01lT7P0M8Q`0
6b0J01`Q6`0P9B408BHR01XO6`0_<c80<SHe04I:B@0O8b@0720O01hP7P0N81d07AlL01/M6P0L7Q/0
7R0M01TK600N81d071hK01TK600G6AH051HC01XJ600L71X06a/I0P0J6QP01@0L71X06ATG01PH5P0G
5aD05QHD00805aLE00P05aHD01/J600D4a4051<A01PG5@0K6QP05QDC01<B40805QDC00T05aHD018?
3P0>2PT03`/:020L6`0<20L0510?01PD4`0D40l00P0E4A00200D40l04`l>01DA3`0F4Pl04`l<014=
2P0@30T04Ph;0P0A3@X06@0D40d05A4>018>2`0A3@X04Ph<01PD4`0@30/03@T800l;2P070`0030T4
00l<1`0B3`X04@h701@A2P0L6A8061<@01HA3P0V8Ah0:B@Q01PC400B3@X03@P500h91P0@2`P00`0A
30T0300;1`@06QHC02l[:00O6aP02`L4014=2P0C3``03`/8018>2`0E4@h04Ph;010<2@804Pd90`0A
30P01`0@2`L04@`8010;1`0@2`L01@00018=2@070P000P0?2PH400h91@0O010;1`0B3@T04@`800l:
1P0@2`L04Pd9028M6P0F4@h040/801@?300G4Pl04`h;01@?300?2`T04@`900d81@0F4@h02@@1010;
200C3P/04@`900d81@0<1`@040/800d81@0E40d03PT601<>2`0b;BX0@chk01881`0301<920804PP7
01005@/:01881`0A1`H04@L601881`0B2PP02@4200h8200I4a<05@l?00X4100;1@D030H600d71`0>
20P03`T90P0@2PX01`0<10@050X;01T?400<0`@081HG01<92P0@1PL00`0A1`P08@0B20T04`T;0146
2P0@1@T04PL;00h31`0=0PH05P/?01T>4P0E2Ph04@H:01052@0A1PX03P@7024F6P0P5AT05@X>00h3
1`0=0PH07a@H01<8300:00<01`0000/0100?10P04@L901882@0C2@X04PP900h41@0D2P/06Q0A01<9
2P0201061`0401882@0C2@X04PP90147208040H700D04@L801<92P0D2P/04`T:01882@0301061`<0
4PP700<04@L601061@0@1PD01P0A1`H50147200801882@0<0P<01`0001D;300F30d01`0001L=3P0B
20T201<92P090147200B20T05@/<00T0000P5QL07aDF01P>3`0:0P803@<400804PP700X040H501<9
200G3@`04@L600`20@0=0`802P0001L=300700006a4@5?ooool001_ooooo00@04`d=018<300A2`/0
4@/;0`0C3@d0300A2`/05a4A01D?3`0A2`/040X:014;2`0D3Ph03PP801@>3P0A2`/05@l?01<=3@<0
50h>00d04@/;010:2P0>2PT04@d<01@@3`0A3@`0510?00/71P0C3`h05A4@010<2`0C3`h02`L60080
4@d<01D04Ph=014=300?2`X04@d<01@@3`0C3`h02`L601<?3P0;20L071PG03hj>@0H51<040`;00l;
2P0A3@`040`;00h:2@0D40l04`l>018>3@0C3`h00P0D40l00`0C3`h04@d<010<2`02010<2`<04@d<
0P0B3Pd7014=300E01<?3P050P405a<B018>3@0H51<03PX9018?3`071@H06aTJ02h/;@0B41403P`=
00d;300B41403`d>018@4@0D4Q<03P`=01<@400B3Pd04`l>00805A4@01<04Ph=010<2`0D40l05Q8A
01@@3`0B3Pd0510?01@C4@0=30X03`h<00T81`0P7ad07A`J00d<2P0@3`d04a8@014@3P0@3`d04a8@
0080510?01P040`;014=300F4Q40510?00l;2P0A3@`0510?01<?3P0B3Pd04`l=01/J5P0F5A005A@@
00h=2@0A40d04Q4?00l>300?3Pd040h?01@@4@0G4a@061@C01H@400F4@h301D@3@0801@?300M61D0
50l<01`G500H4a004`h;01XF4`0F50l301@C3`0Q01HE4P0G5Q@092<Q014?3`0T8R<040h?018@4@0?
3Pl04A4A018D4`0D5QD0@TA305iPG`0A4a805aTH018D4`0>40l051HE014C4P0E5aH051@B01LG5@0F
5Q@051@B01PH5P0M7A/061PF01dM6`0W9bD061PF01HF500I6AL06aLF00806QTG01806APF01XJ600L
71X06a/I01LI5P0O8Ah09BLT01PM6@0C61@07B4P01hR8@21QH@0Ce=B01LK6P0K7ah05QXI01TM700H
71/201HJ6@0301PL6P0I7A/06AdL00806alN0`0L81l0:`0M8B007b<R01hR8@0N8R80720R01lT9`0N
92@0728P01`S7`0Q:b<07RPP01lY8@0M:2808RdY020/:P0P;2`09C0`02H`<@0V<380:38d02Xe=`0/
=c/0:cLl02hk@@0nBe<0C5YR0350A`0/>d<0<3e403=0AP0a?d80;Shn03A4A00cA4<0<TA40312@P0i
C500=4M>03]>E@0jC5H0?dmN03a<F`0nC5`00P11CUh02@18E6@0Ce][07^7U`1NIgP0BeAU04aEIP16
Cf00A5AQ04EGH`02041BGP0H04MII@15Ef40AUQR049DGP16FF00BUeT04ULH`1@HfT0CEiV05]/M01;
G6<0DF9Y04mPI@1SMGL0BUaL04YLF`1:GE/0DFAP04aOFP1GJVH0E6AS05MWI`1KJf/0GVi^0P1PL702
06EeM@@0IWIf03@0K7al06UiN@1^OWh0L8200760P@1gQHH0Mh:407^6R01mR8X0OXR:07n9R`20RX`0
PHb@08JAU@27TYH0RY>H096JW`2DWJ80U9^Q09NNY02EW:80WJ:X0:6V[02NXjL0XJJX0::VY`2PY:D0
WZ:U0:BUZ@2WZ:`0/K:g0;:a]`2e];X0];>k0;Je_@2k^L<0^KO30;nmbP3;bMH0alCA0<2mb035`/d0
a;k:0<:laP38`/`0bL;:0<O0b03;`ld0d/OE0=O<fP3FbmT0fLkN0P3Kc]l0<03Mcn80gLkS0=g>h`3N
c^<0glkT0>3@h03Mc]T0flcI0=O9e`3Eb=L0eLSF0=C8e@3Aa]00cL;;0<W0a@34^kd0`;Rg0;Zc/02f
/Jd0]k:^0;>^Z@2WXid0YZ:L0:FSV`2c/jP0f][?09>DR@2EUhX0SY2408^?P@24RW`0OXAf07b2M@1n
Q7P0Lg]^06]cI`1eOW<0M7ic06afK@1^N6l0JWI/06A^I@1WLFP0KWQ_06miL01/MVh0JWE]06ijLP80
JgQa01/0IgI`05i]J01IJ6<0GfiW05MVG`1CHU/0E6=L04mNE`1:Ee00?da5049?B00nBD<0=d8j03U4
?00d?SL0=d8n034k>P0e?ch0<3Xi03<m?00]=cH0;3Hg038l?@0W<C80:cDf030j>P0Z=3@00P0^>SP0
100d@3h0;SXh02Xf=00Z=S@202Te<`0=02/g=@0b?S`0<3`j01hZ:00V<S008Rh/020/:P0R;2/08bh[
028]:@0S;2T08R/W02</9`0202L]:@0=02@Z9P0V:bL07B8P02<W9P0[;bh07B4P05QLG014B4T08RHV
02@X9`0H71/08BDS020U8@0201/P6P0I01`Q6`0N8al07R<O01hS7`0R9RD07B4R01PL7@0Y;Bh05QXK
02DY:@0P8R00828O01lQ7P0L7Q/07AlL01lQ7P0K7AX06Q`I01LI5P0M7a`07R0M01PJ5`0L71X07alM
01hN700201`L6P0301hN700I6AL05aLE00805QHD0P0G5aD201PG5@0?01LF500M71X06QTG01LF500F
5A<051<A01TH5P0H5aD05QDC01HD4P0S7ah04@d<01PD4`0A3@`071PG00805a<B0P0H51<01`0F4Q40
5A4@01DA3`0E4@h05Q8?01DA3P0D40d00P0C3``201DA3P0E01<?300A3@X04Ph;014=2`0C3`h03`/:
01PD4`0D40l0;2PU00h;1P0A3PT04Pl:00h;100?30D05a@=014<2@0I514071LD01LB3`0F4@h04`h;
00804@`90`0B3@X0100A30T04Ph;00`81@0E4@h2010<2@804@d:00D03PX7014=2P0D40d04@d:00l;
2002010;1`804@`800/04Pd901<>2P0?2PH040/701<>2P0E40`04@`801@?2`0B3@T04@`8010;1`02
00l:1P0900d8100?2PH04Pd901<>2P0B3@T040/7014<200C3P/04@`9008040/800/04Pd:01<>2`0A
30T040/801@@3P0<1`@04`l<01<>2`0@2`P050l<018=2P0200h91P0701<>2`0L5a@040/8014<2@0H
4a008ahK02`W900201881`804`T800@04PP701471P0F30/04`T80P0A1`H0200C2@P04`/900l8200E
3`l08Q`L01`F5P0=1`L03PP80P0?2@T200h820803@L700H04`X;01D;300D2P/04@P900d51@0D2P/2
01061`040147200B20T04PP901<82`803`@801H050T=01052@0@1@T050T=01872`0@1@T03`@80105
2@0A1PX05``@03`a=@0b9b/060hA01D:3P0:0@<04PP;01052@0I3Q805P/?00l4200C20`04PL:0P0>
10D0200C2@X040H700h41@0?1@H04@L801@:2`0C2@X04@L80P0C2@X301061`080147200C2@X04PP9
01882@0A1`P040H70147200B20T301881`0301471P0@1PD040H500H04@L60P0A1`P02`0C2@X050X;
01@:2`0E2``0N6i_071VI`0@1`P060h?00/20`0M4a@040H700804@L800L03P@500l51P0A1`P05@/<
00d41@0?1`L03`D600804PP900`040H501@:2@0@1PD040H501<9200A1`H050X901061@0K4A002P40
01H<2`0h;RdDooooo`006oooool601<=3@0800/51@0D3Ph030H602@N7P0E3`l05Q0@01@>3P0B30`2
010:2P03018<300D3Ph04P`<00@04@/;014040X:01<?3P0J5QD00`00010<2`0>2PT03@T801@@3`04
00004Ph=014=300G4a802@D4010<2`0A3@`04Ph=01<?3P0201@@3`0@00/71P0E4A003PX901DA400U
8B00[JVX02DQ800>2PT04@d<018>3@0A3@`05Q8A00h:2@0A3@`04Ph=01<?3P<04Ph=00`040`;00l;
2P0@30/04Ph=01DA40050@008AdL048n?@0A3@`02PH501PD4`0C3`h2010<2`804Ph=00d04`l>01@@
3`0C3`h04Ph=00l;2P0>2PT04a0@00<10P0c<C80LFm`01XH6@030@805A<D00803@/<00X040h?01@B
4`0E4a@04a0@014=300B3Pd05A4@01PD4`0K5aH04Ph=0P0D40l0;P0A3@`040`;014=300D4a404Q4?
00l>300=30X03Pd;014@3P0@3`d03`h<00d<2P0<2`T03@`:00l>300>2PT03@T8018>3@0E4A004Ph=
01@@3`0A3@`05A4@018>3@0A3@`05a<B01PD4P0A3@X04a0;01HB3`0B4@d040l<010?3@0D4a403`h=
00P61`0<2P/0518C00d<2P0B3Pd04@d:010<2@0G4a007QXG018>2`0C3``301DA3P0?01PD4@0L61D0
5A@?01DD400N7AT04a8>00h=2P0O7Q`0:BPV014@3`0B41405Q@E00h<3@0@410051@D008051HE01T0
5ALF01LI600H6QT03a4@01HH5`0D5QD0418A01DG5P0L7Qd051@B01<C4@0E5A<06QXH01PH5P0E5A<0
5aLE01XJ600H61H05ADC01HF500H61H05a<B01HE4`0G5Q@06APF00806ATG00/05ADC01DG500E5a@0
5QPE00`A3@0D6AD041HD02T_;@0H7Q`08RPV01DK6@0201HL6P0;01PN700J81h06AlM01TO7@0H7A`0
61`K01LK6P0I7A`06alN01hR8@0M8B000P0K7ah201`P7`0?01dQ800O92@0724T024W9`0R:BL07bPS
01lY8@0K9Qh07RTQ01hY8`0S<2/08Bd[01l[:`0N:BX08B`^00809C0d03h092lc02Le>00X=SX0:cPn
02/j?`0Z>Ch0=DA902`mA00eA4T0=4=803=2A@0b@T80=4A403A7A@0nD500<4A303I9C@0gBe80<TI=
04=FH00nCUd0?4aK045>GP1<FFT0=T=C04]GI`1AGFd0UJ6a05aUMP1;E6D0@daM04aDIP15EF80A5IR
03U;E`0kCET0B5YV04MIH`15Ef40@UAN04EHG`1>HFP0DFA[04aOI@1:Ff80FV]b059TJ01:G600CEmR
04UKG@19Fe/0CF1O04iQG`19G5P0AeYE05EXI01AHF00EFEU05][J`1MKFd0GVi^05e]K@80I7Ad00h0
IWIf06UiN@1[Ng/0JGUi06YjNP1[Ng/0K7al06inOP1cPX80MH>407Z5Q`1kQXP0O8N907n9R`80PH^=
02/0Q8nA08F@TP24Si40QHnA08ZDUP2=UiT0TYZM09JNX@2KXjH0VYnS09VNXP2NXjH0WJ>R09JJV`2O
Xj@0WJ6R09fNXP2WZ:`0/;6e0:n^]02`[kD0];>i0;^j`02n_LD0^;S30;^ka`2l_<P0_K_60<6nb@34
`LX0`;g60;Vc_@30^l80`kk50<[5c036`LP0clSE0=;:e`3Fc]/0dLWH0=35e@3Fbm/0e/_L0080fLcP
00`0e/WM0=?6fP3EamP0e<SD0=G9e@3Hc=T0c/;@0<c0cP3?aM40bl7:0<Voa`2o^K/20:nZY`0a0;6^
Z@2]ZZ<0clc50:bYX02=SH<0YjNM09RHS02FV8/0T9:508Z<OP28S7d0RXio08Z?P01nQ7H0NX1b07Mn
L01XL6<0IViQ07=lL01jQ7T0NHAi07J2N01bOW@0JWI/06miL@1/MVh0JWE]06QcJ`1UL6X0J7A]061/
J01SKf/0GVeX05]ZI`1MK6T0FfYV05e/I@1=GE<0Df=I04MDC@1GI5d0EF9K041;A@0jACl0A4e803Dn
>@0f?cX0?dQ302lh=@0203Dn?@030419B00lAD@0;SLf00<0;cPg01d09Bh]03Q1?`0mAdH0;3Pf030l
>P0X=380930^02Xf=00^>SP0=D4o02Te<`0^>SP0@Ti<04EAC`0U<Bl07BTY02Pd=00^>SX09c4`01lZ
9`0X<bl08b`Y024Z9P0S;2L08bXS020W800T:RH06AlM024W9@0201lU8`0J02@Z:00T:RH0<SPf01`R
800M8b406R0N02<Y9`0F71X06QlK010E4@0[<2`07b@P024U900M8B007R8S028V9`0G6a`092P[01/O
8P0K7b00828P02<U8P0[;BX07R0M014C400L7Q/601/M6P1701TI5`0M7A/071`J01dM6`0W9bD07alM
01LG5@0T928051@B01<C4@0Q8Al06ATG01PG5@0D4a4040l=014@3P0L6aT06QTG0081000F5A<05A@B
018A3`0920H05A8A01@@3`0F4Q4061@C01LC4P0F4Q405a<B01XF5@0C3`h05a<B01TE500B3Pd04Ph<
018>2`0D40d05A4>01@@3@0B3P/05a<@01<?300:1P<05a<@02<O700j=S<02`L501@@3`0A3@`03@T8
01HB4@0A3@X02`P301XG4P071080514:018?200C40T05Q4>00L2000B3@X0?STf018=2P0D3``03PT6
010;200E40d0<2/X01HA3P0C3P/00`0C3``01P0B3P/04@d:014=2P0D40d04Ph;014=2P804Ph;00P0
40`900T4000D3`/05A0<018=2@0:1@404Pd901<>2P803`X60P0A30P00`0=20@040/7010;1`0200h9
1@803`X600d04`h:01D@300F4@d05Q4=01D@300C3PX04@T7018:200A2@L03`L501081P0B2PP04@T7
00804`/900D04@T700l71@0@20H03@P500l:1`02014<2@0300l:1`0=20D03@P5008040/801P03PT6
010;200B3@X04@L601<9200D2PT03P@301061@0H3Pd040H501D;2P0G3@`05@/:00l5100;0`403PH7
00/51@0?2@T03@L700/51@0>20P03`T9010:2P0A2`/3018<30H04@L800/04PP901061`0>10D05`d>
01P>3`0@1@P05@X>01T>4P0E2Ph03`@801052@0201462P0801<8300E2Ph04`P<01462P0?10P04PL;
01H;3`0E2Ph201462P0>01872`0F2`l0GE9F01052@0K41@0304501472@0>10D05P`=02<I6P0=0`@0
200001@:2`0A1`P201061`0D0147200B20T04PP901/A4P0=0`@05`d>01D;300D2P/01`0001hD5@0B
20T060h?01061`0?1@H0308101D;2P0?1PH040H501D;2P0?1PH601471P0<00h41@0A1`P04`T:0147
200@1PL04@L803/a<P0Z82404PP900h41@0B20T04@L8300@1PL301061@0901471P0B20L04`T80106
1@0B20L04`T801471P0B20L050X901Cooooo000Kooooo`H04P`<00P0618B00h8200F4100Ad5103<]
;@0<1PH04`d=018<30804@/;00<04P`<01<=3@0A2`/01@0A2`/0300;1`H05a<B00X61@0D40l05a<B
01@@3`0F4Q403@T8014=300@30/04Ph=00d920D04Ph=00T04@d<02PT8`0A3@`00`0001HB4@030000
;b/Z01TE500<20L00P0A3@`01P0=2@P04`l>010<2`0A3@`04Ph=01<?3P804@d<1@0B3Pd0200?2`X0
5Q8A04I2@@1NFUT06ADD00H20@0@30/04Ph=0P0D40l0100A3@`03`/:010<2`0A3@`2018>3@804@d<
01h04a0@00`:2`0A3a008b4R018@4@091`P0518C01HD5@0B414030X;00T7200;2@X03``<014=300B
3Pd04`l>01@@3`0G4a8040`;018>3@0C3`h040`;00l;2P0A3@`04Q4?014@3P0?3P`03@`:00h=2`0A
40h2010?3@803`h<00<040l=014@3P0E4A000P0?2`X0700E4A00510?01@@3`0B3Pd05A4@01<?3P0B
3Pd05a<B01PD4P0>2PL04@h901@@3@0A40`04A0=018A3`030P004Q4@01@B4`0H5QL03@/<01DD4P0B
3Pd04`l<014=2P0E4@h06ADB010<2@0A3@X301<?300?01HB3`0J5Q<03@`7010?2`0A40`030/703Pg
=00A40h02`X801<A4@0M6a`081hO01/I6P0C4A8051@D00<05ALF00/051HE018D4`0@4Q4051HE01<E
500A4a805QPG01XL6`0J6QP05ADC01@D4P0201LG5@805ADC0P0H61H01`0F5Q@061PF01XJ600M6AP0
6QTG01TH5P0H5aD00P0F5Q@01`0Q8Al04Q@A01lQ7P0J71T041DA01@I5@0K8Al00P0D6QP0100J81h0
5Q`J018H5P0I7ad201PN700301XP7P0K8Al06QlO00806AdN02406QhM01dQ800O8b807R8Q01/O7P0M
8B007b<R01lT800N8al07B8Q02ld=`19Cdl0=Sdk01HO6P0N:B409C0X01lZ8P0O;2D09C8]02@`;P0R
;Rh08bh_02@_<@0V<CD0:3<g02Td>00Y=cX0:SLl02/j?`0Z>Ch0;ci3041?E00eATd00P0a@4D0<P0b
@D@0<d=30394A00dAdD0;D5003iBD@0nDED0=DU@049FG@0jCUL0;d5?04YJJ@14Df80?daL05MTM00m
BET0E61`07J2TP1>EfP0Dea]04QAHP17DV80@U9O04AFHP12E600BeeY05a^NP1OLG/0AeUS04IHHP18
Ff80CV5X04mRJ@1<GfD0A5EL05=UJ@1;GF40A5IJ04MIF`14EUH0B5YJ04EHE`1<Ged0CV5M05IYI01B
IF40EFET05QXJ01LK6`0GVi^0P1OKfl00`1RLW80I7Ad06IfMP0206MgM`0P06QhN01[Ng/0K7al06em
O@1_Ogl0M8>307J4Q@1iQ8H0NXF707b7R@1nR8X0PH^=08:<SP24Si40QI2B08B?T@26T980RYBF08jH
VP2;TiH0RI6D096IW02KX:@0W:6U09jSYP2KXJ00VinP09ZNW`2LX:40XjBX0:FVZP2a/[H20;2_]@07
0;:a]`2e];X0]kJn0;Jf`@2i^LD0_Kg90<;0b`020<:ob0090;Re_P2j]K`0`Kc30<6l``39a</0b<?:
0<[4c`3;aM40dLWF0080c/KE01P0e/_K0=G:f`3Gb]h0f<_O0=G8g03Ca]X0cl?C0<c0c03AaM40el_I
0<g2d038_L/0bl3=0<O0b036_lH0`;Zk0:n[Z02YYZ40[JZT0::OV02QWYD0UYJ<09NGS@2NWY8208nA
Q00h092BQ02>TX<0R8am08F9N01oQGD0NX1b07QnL01_MVP0I6aO06M_HP1dOW80NH=h07F1M@1bOW@0
KWY`06YfK01ZM6`0J79Z06YeK@1ZMFl0IG1Z06EbJ`1NJVH0HFeY05i]J@1KJVL0G6]X05YYI@0nCDH0
C5aB04UIC`1<FE80SIZC07b9PP1BGEL0AU5;03e6@@0g@3/0>T<n02lh=00/=C@0=Chm03@m?00g@3l0
<c`k030i>013C4/0<c`k038k>@0a>SL0>D8o041;A`0Z=3<0:cLe02Da;`0T<2h202Te<`0?02hj>00/
>3H0;SXh03E1?`0`?3X062@R024];@0W<c<0<Cdm038l?@0V<2l082/W02H_;00R:bH08B/S00808RTR
0200:c4]03<i=`0Q9bL09R`Z02X`;P0S:BD09R`X024W8`0N92408RPV02le<`0N92<06R0P02/`;@0A
5Q805a`H01XO6`0T:2L07B4P01hR8`0S9bP05ATJ01XN8@0S9bX051PI01lQ7`0R92404A<@020R7`0U
9b@03a4>01`N6`<06adJ0P0J71T0600P81h07alM01/K6@0F5Q@071`J01<C4@0B4Q003Ph<00T91`0I
6AL06a/I018B400E51807QdK01/J600S8R005aHD00h=2`0C4Q008R4O01HE4`0M71X04Q4?01PE5080
6ADD00H061@C01HB4@0E4A004`l>01PD4`0D40l201DA4003018>3@0F4Q00510=00@0510=01P03`/8
01<?300P71T071PE00l;200C3``0<2`Z00`81`0A3@`06aLF020L6`0A3@X03P/601DB3@0@3@P071TB
00h;100e<R/08A`I01@?300J5A80;2LT01PC400B3@X2014<2@0400`71@0O6QL03`X7014<2@<04`l<
00D04Ph;014=2P0A3@X04Ph;010<2@0200l;200500h:1`0<20D05a8>01D@300F4@d00P0<1`<0100A
30P04`h:010;1`0?2PH2014<200500d8100A30P040/700l:1P0@2`L00`0A30P01P0B3@T04`h:01<>
2P0B3@T04@`801491`804`/90`0B2PP0200@20H04`/901<;2@0A2@L040P601491`0>2@H03`X70P0@
2`P03`0?2PL03PT600X50P0<1`@03`X7010;200A30T04Pd:01471P0<0P402`4000l5100Q5aH0<2HU
01H<2`0201L=300?01H<2`0D2PT04@T701092@0=1`L03`T900h8200=1`L04@/;01@>3P0?2@T030H6
00X4100;1@D030H600804@L80P0B20T20147200601882@0@1PL03`D601H<3@0G3@h04@H90P0A1PX0
3P0B1`/040D900l4200?10P04@H:01<8300E2Ph04`P<01462P0>0`L040D901<8300B1`/03P<70P0?
10P030070000=BX^00`21@0C20`0200101882P0H3Pl040H701892P0K4A804`T:00l51P<040H700T0
4@L801882@0A1`P06Q0A01882@0J41405@/<01061`0Q5aP00P0800002@0?1@H04`T:00l61`0B20L0
8QPG02HL6`0E2`X060h=00h40`0601471P0;01D;300H3Pl05@/<01882@0E2``04@L802LM7P0M4a@0
40H700l51P0B20T03@0@1PL0100B20L04@L600h40`0>10<200l5100600d30P0@1PD04@L601061@0B
20L050X95?ooool001_ooooo1P0B30`01@0?2@T04`d=00d71`0J51@04P`<00804`d=100B30`04`0C
3@d03`T9010:2P0A2`/04P`<01<=3@0D3Ph04Ph=01<?3P0D40l02`L601DA400B3Pd04`l>01PD4`0?
2`X05A4@00l;2P0D40l00P0C3`h02P0B3Pd04@d<010<2`0@30/03@T801XF5@0:1PH05A4@00d9200B
3Pd200l;2P0401@@3`0A3@`03PX901<?3P@04Ph=00l040`;00l;2P0A3@`04Ph=01<?3P0B3Pd04@d<
01<?3P0:1PD03@T901PD4`0?2`X040`;018>3@0E4A000P0L61L01P0B3Pd03`/:00h:2@0?2`X04@d<
01<?3P80510?00h03``<01HD5@0@3Pl03@/<01<A4P0>30d04@l@018@4@0E4a@04Q0A00h<3@0@3Pl0
4@h>010<2`<04Ph=00@04@d<00h:2@0@30/04@d<0P0@30/00`0B3Pd03`h<00l>300200h=2`0500l>
300A40h03Pd;010?3@0B4@l00P0D4a402@0C4Q0061@C014=300?2`X05A4@01@@3`0A3@`04Ph=01<?
3P02014=300E01@@3`0F4Q004@`901@?2`0F4Pl05A4>01DC400F5A<040l=01@C4P0;2`/051@D010@
400F5Q@03`h<01<B3P0B4@d040l;018A3@0@3`/03@`800<040l;02L04Q4=01DD400D4`h05QDA01/J
5P0@3`/0?chk01HE4`0E51804Q4@00l=3P0D4Q<06QPI01<A4P0F5AD06APH01XJ6P0J6AX05QDE014A
4@0D4a@04a8B01<C4`0G5QH061LH01LG5P0J6QL051D@01<D3`0E5Q4061TD01XK5P0E5Q405aPC01PI
500I6QD06Q/F01/L5`0K5aH00P0I61H0300J6AL06ATG01TI5`0S8b40:R`Y04a>B`0K7AX04QLC01dR
7P0F71/04aTI01TO7`8061hN0P0K8B4201TO7`0N01XP800K8B40724S01/O8@0K7b007B4R01hR8`0O
8b807R8Q01`P7`0N8al082DQ024V8P0Q9R4082HT01`T9P0T;B`09Bh[024[9P0R;BD07b/R01l/8`0O
;2D0938]028a;P0Q;bl0934b02Ha=@0X<cL0:SLj0P0[>C`02@0/>Sh0;3]002Ph?@0]?d<0?4iB03A6
BP0^?D80;ci30312A00203=5A@0_03=6A00nDU40;d=203U>D@1bQXd0CF5X03eAFP15EfD0?U1N04AF
I014EF@0@E5P04UGI`1:EfL0EV=c05UVMP1?Ff/0>TIF04eIJ@16EV<0B5YV04MII@1;GFT0E6Ib05=U
K`1:G6H0BeeW04ePI`1;GVD0BUeT04ULH@1:G5l0DfEW04eOH@18FU/0BeeM04YLG01?HF00B5]I05=V
I01DIf<0Kh9n05U/J01MKF`0GFe]05i^KP1OKfl00P1RLW800`1SLg<0JGUi06YjNP0206MgM`0>06]k
N`1/O7`0KGem06inOP1`P800MHB407N5QP1hPhD0NHB607^6R01oRH/0PXb>08>=S`24Si4208JAT`04
08RBU02<UYP0SiVK0:R`/`80UYjQ0380Vj2T09FJWP2AUYT0WjFT0:BXY`2IWI`0VinN0:NXZP2TYJL0
Zjb`0:j]/P2`[k@0/[6g0;>b^02c/[T0];Bn0;Rh`P2k^lD0^k_40;Zi`@2i^<00/:fd0;Ba^02m^/40
_[Vo0<S3b@38a</0blSB0<W6d@3;a]80blGC0<g7e@3AbMT0d<OH0=?7f`3Db=`0dlOK0=;6fP3DbMX0
e<WH0=35e03>`m@0b/7@0<[0d039`Lh0`kk50<6l`P2o_;`0/K2/0:JUX080WYjF0700UiN=09^LTP2C
UHX0RH]o08N:O@1mPG<0Nh1a079iJ@1ZLF40JW5O06mfIP1fOVl0Lg]/065YF`1PJ5/0I6mQ06mjK@1b
OW80K7Q/06IcJ@1ULVP0J7E[06IaJP1TKfT0JGA^06YfLP1VLVh0I71/05e/J@1QL6d0Gfe/05UYJ01J
JVT0EFES04mNE00kB3h0@Tm604=@A`17E4/0B5==04E>B@16CdX0=Sll03Dk>@0l@T00=3Xh03]4A014
C4h0?4A6038k>P0[=3<0<3Tg04I?C00]=S<0;CHa034j=@0_>3<0<C/g02dh=@0]>CL0:SHd02di=`0a
?C/0;3Pf02Da;`0]>CL0;c/i02`h=P0Y=C<09C4`06agN014Ce40:C@e02Pb<`0X<S409c8^02hg=00W
<B/09BlW02L^9P0[<RX0=chg069XJ00T:R/06R0N028X9P0M91l0<3L`020W800S:B@05A/H024W9P0I
7R008bTY01lT8@0O8b807B4P02L[:P0R9RL082@U01`P8@0Q9BP0H6AW03/o@P0Q9BP082@U01hP7P0R
9240@D=001hP7@0G6AH05QPE0`0K7AX301XL6@0L01TI5`0L71X07AdK01PH5P0K6aT04a<A01TI5`0D
51808R8P01DE4`0l?3X0VIVG02h]:`0F5A<05aHD02HU8`0>3@/06APF01@C4@0I61H04A0?014@3P0@
3`d071XH01dI600K5aH05a<B01DA4080510?00h06aLF01TE500G4a80510?014=300H5180510=018>
2`0A3@X04Ph;01<?300E4@h05a<@01@@3@804@d:018081`I09B@SP0R7Qd020@301LC4P0C3`h05A4>
01@A300K61<04Pl:01LD3@0A3PL07a`E01hI5P0F4@h07QTF010;200K5Q<2018=2P0501LB3`0@30T0
5A0=01<>2`0B3@X00`0B3P/3014=2P0B00l;200>2PL03PX7010<2@0A3@X040`900d8100B3@T03PT5
01HA3@1KEU807QTE018=2@0A30P040/7014<200@2`L03`X60`0@2`L01@0A30P04`h:01@?2`0A30P0
40/700803`X600@040/7014<200?1`D040P60P0C2`T01@0B2PP03`L500l71@0B2PP04`/900804PX8
00<04`/9014<2@0@2`P00P0>2@H0400@2`P04@`900l:1`0>2@H03`X7010;200;1P<02@@100l5100A
1`H050X901471P0C2@P06@l>01H<2`0E2`X201@:2@0E01D;2P0D30X040P900d71`0@2PX03`T900d7
1`0@2PX0;RPX028L700H4Q8040X:00h8200?2@T04@L801<92P0D2P/04`T:0147200@1PL04PP90080
40H70P0E2``02`0D2@`04@H:00h31`0A1PX050T=01462P0?10P04@H:01<8300E2Ph04`P<00804@H:
0P0B1`/01P0A1PX040D901462P0D2@d03@@600`31@804`P<00P03@8601H;3P0E2``03@<401H<3@0A
2@T050X;024G60<03`D601@040H70147200A1`P04@L800d3100B20T050X;01`B4`0I3a005P`=02TO
800b:2T03`H701@:2`0J4A402P4001471P0<0`80718A01@:2@H04@L600H03P@501@:2`0@1PL050X;
028H6@0N51D201882@040147200@1PL040H700l51P`040H700L04`T801471P0?1@@040H501@:2@0G
3@`03P@300804@L600<040H501471P0B20L05?ooool001_ooooo1`0A2`/201@>3P0301PB4P0C3@d0
4@/;00H04P`<01003PP8010:2P0@2PX04P`<01<=3@0D3Ph04@d<00/71P0I5A@03@T801DA400A3@`0
40`;01XF5@0B3Pd08alN0P0G4a82010<2`804@d<0P0B3Pd02@0D40l05a<B010<2`0=2@P03`/:00D1
000A3@`04`l>01@@3`0200l;2P0601DA400D40l04`l>014=300@30/03`/:0P0@30/03P0?2`X03PX9
00l;2P0@30/03@T8018>3@0L61L06ADD00l;2P0@30/04@d<01DA400J5QD05a<B0P0?2`X00`0A3@`0
4Ph=018>3@0201<?3P0@018>3@0A3Ph030X;00/92P0>30d02PP900h<3@0@3Pl02PP900P61`0<2P/0
8AlP03Tg>00/:BT03PX9014=3080510?00@04`l>00l;2P0A3@`04Ph=0P0A3@`02P0D40l03Pd;00h=
2`0>3@/03`h<010?3@0A40h030/900h=2`0A40h201<B4009018A3`0C3`h05A4@01`H5`0J5QD04`l>
018>3@0D40l04Ph=00804@d<03<04Ph=01@@3P0E40d05Q4=01LB3`0D40d0510>01HB4@0?3P`0410?
01hN7P11@d80CDm>014A3`0>3@/04a8>01DD400C4Ph04Q4=01LF4P0>3@T04A0<018A3@0A40`04Q4=
01@C3`0=30L051<?01<B3P0F5A403@`901HE4`0K6QP040l>01@B4`0>30d03@/<02/Y:P0D4Q<05a@E
01TG600K5aP05a@E01<A4P0G51D0510A01<A4P0J5aP06aLH01HE4`0C51000P0D5A00100E5Q4061TD
01XK5P0I6QD201PI500d01TJ5@0H6A@061TD01`H5`0L6aT07ahL02<R800U9B<09RHT01PH5P0];b`0
E5IC01HH5@0@5A407R<O01DL700O:2L04Q/J028[:P0?61L05b0O01DN7@0H8B006B8Q01LP7`0E7Qd0
5a`N01XN8@0K7b80720R01dQ8P0M8B007R8Q01dQ800K81`06b0K01hS7@0Q9R009R`Z028Z;00T;B`0
6R@P01HQ6`0P:b<0934X028_9P0N;BH08S4/01l^:`0N;2`08Bla02Db>0<09c@j00<0:STn02hm@@0a
@4<00P0`@T@0400eAdT0=DU:0394B00cADT0=DM903E7A`0cADD0<DE303Q>C00N=380?U=F092W[@18
GfD0=TeE04III`0lCed2041CH@0P04YLJP0nD5h0D61_04IFI@1AGfl0C5UY04YGI`17E6@0@e=P04EG
H`17FFD0BE]W04aNJP1:G6H0BeeW04aNJ01>HFP0BUeT04MJH@15F5d0BUaN04iPH019Fe/0AUQH04UL
F`1;GU`0C5mM051SH@1CIV@0@eIB069eL@1JKFT4061`L005069bLP1SLg<0I7Ad06]kN`1/O7`00P1X
N7P0501/O7`0JWYj06]kN`1/O7`0Kgmo07>2PP1ePh@0MX6307V4QP1lQhT0P8Z<08>=S`25Si40Phn?
08JBTP28U9@0RYBE08fGV02@VY/0WZJX0P2CVid0302EVYd0V9fP09bRXP2GWIX0V9bK09VMW02KWih0
YZNY0:j_/@2XZJ/0[Jba0;2_]080/[6f01H0/[6g0;6c^`2g^/<0]KS10;6a^@2i^<00`L360;Bc^@2^
[;40];:g0;Vg_034`/L0`[o60<_8dP37a<l0a<7<0<K2d03<a]@0c<KE0<_4e03=a=L0c/GH0P3=a=L0
8@3Cb]`0d/WJ0<W0d@32^L/0a;_<0<JmcP36`<d0`[c60;^h_`2j^;X0]kJb0:f^Z02TYIh0VIZB09nP
V02c]:`0XZFJ08R;P01_LfH0IVaN069XFP1LHe@0GfQG06QaH01]MFD0Jg=T06A/G@1GHE80GfYL069]
G`1VLF@0K7Q/06EcIP0205i[H@0/06EbJ@1[MW00IG1/06EaK@1YMG<0Ig=a06EdL@1RL700IG=c05m_
KP1HJ6P0EfMW051PG`0lBD00>dPn04MDBP18Dd/0AE1804MBBP0kA3l0@DY503]1?`0c>CT0>T1003Lm
?@0_=3L0=3Tl02db=@0`=SH0;C<c02`b<00a=cD0;cDa03@j=P0]=2d0<CPa02L`:`0/=c<0:cLe02Te
<`0/>3H0<3`j02Xf=00/>3H302/g=@13030l>P0iADD0<3/m02@_<P0T;c40:S@e02Tc<`0X<bl08R/X
01lY8P0Q:b<08RTQ028Z800Z<BX09c0_01TQ8P0R:bP0:c@a02@^9`0O:B405R0H01lY8P0N9b8031DD
03@m?@0Y;bl07b<R01DI600U:BP0B4a;028V9`0Y;Bh08bLZ010D5`0c=cX07B0U01/N8`0B5QT07b4O
02`^:`1YJfP08B<P010B3`0U9b@05aTF01PJ5`0I6aP06adJ01`N6`0M7a`06a/I024Q7`0V9R@071`J
01LG5@0>3P`06a/I00D50`0C4a402@T701lO7@1eMG<09bHT01/J600P7ad0<S4_00d<2P0201@C4@0B
01dL6P0L6aT051<A01TH5P0D4Q006ADD01LC4P0E4A00510?01DA400G4a806QHE01@@3`0G4a806ADD
01<?3P0F4Q00510=0P0E4@h08@0D40d04Ph;014=2P0E4@h02PH3020L6@0810402`L401hJ600B3Pd0
71PG00X61P0@30/040`9010=200D4@`03P/601LD3@0M6Q<02`P4010;20080`006QDB010;200B3@X0
4`h;00l:1`0E40d05Q4>010;200I514050l<010<2@05014=2P0<010<2@0?2`P03`/8014=2P0B3P/0
4@d:00h91@0H4`l04@`802DP7025P7`0;2LS0P0A30P2010;1`803`X60P0=20@01P0>2@D03`X6014<
200C3PX04Pd9014<20803`X600L04@`8018=2@0?1`D04@L601@:2@0G3@`05@/:008040H500L04`T8
01D;2P0D2PT050X901@<2P0A30T03`X700803@P500D03`X7014<2@080`002PD200h91P03018=2P08
01H<2`0>10<03P@301061@0J40l091XI01061@0B20L201<9200601061@0>1P@03@H6014;2`0F4100
50h>0P0<1PH01`0>20P030H600/51@0<1PH03@L700h8200C2@X00P0D2P/02@0C2@X04@L800l51P0B
20T040H701882@0C2@X04PP901872P0601872`0501462P0C20`04`P<01<8300A1PX00P0B1`/20146
2P0@01872`0C20`040D901T>4P0700004`P<01@93@0@1@T02`4301X@4@0=0`@050X;05E;C019?d00
6@l@01061`803`D601@040H70147200?1@H0200001<92P0F30d03`D600X10@0;0@803`D605U?D021
MgP04PP901@:2`1?AD@07A<B01P>3@0E2`X06@l>01<920H04@L600`04`T:01L=3P0@1PL040H701X@
4@0A1`P040H701882@0D2P/04PP901<92P0G3@h<01061`0<01471P0@1PD040H501881`0G3@`06Q0?
01@:2@0E2`X04`T801061@0?1@@040H55?ooool001_ooooo1P0B30`0200H4Q805a4A014;2`0:10@0
30H601<=3@0A2`/04P`<0P0C3@d01@0B30`04@/;00l92@0@2PX04@/;00804P`<00d04`d=01<?3P07
0`80510?00l;2P0:1PD00`0000`81`0B3Pd03@T801XF5@0E4A003@T800803`/:00H040`;018>3@0B
3Pd04`l>00T51@0:1PD201@@3`0P01<?3P0?2`X040`;018>3@0@30/03@T800h:2@0B3Pd0510?018>
3@0A3@`040`;00l;2P0A3@`040`;00h:2@0=2@P03PX9010<2`0C3`h04@d<00l;2P0:1PD03@T8018>
3@0@30/04@d<018>3@0@30/030P700h:2@0B3Pd301@@3`0A018>3@0A3@`040d=00/92P091`P030X;
01XH6@0D4Q<03@`<01TG600F51D040h?00l=3P0D4Q<0514A00l;2P0B3Pd00P0D40l0200E4A0040`;
018>3@0C3`h04Ph=014=300C3`h03`h<0`0@3`d2014@3P0300d<2P0>3@/040l=00<040l=00@04@d<
01LC4P0S7ah07QXI0P0E4A006`0G4a80510?01@@3`0D40l04`l>01HB400D3``05A0<01@?300@30T0
4@d;01<?3P0P7ad03Ph=01LG5`1?DE00F5YI00/=2P0>3P`04Q4=01HE4@0D4`l04Q4=01PG4`0?3PX0
4a8>01@C3`0201<B3P0=01@C3`0?3PT06aXF00`;1`0Q81`05A@A01LF500D4a403`h=01XH6@0E4a@0
=cDf092>S`0501DA4P0401HB4`0I5AH05A4B01HB4`806QHG00P06ADD01HF4@0F5a805QLB01DF4@0G
61<06AXE01XK5P8061TD02006AXE01PI500F5a806aLF01XI5`0K6QP07QdK01hN700O7ad06ATG01DG
500^<2d05QPE01@I5@0F71X05AdL00PA400<5A@08b`[014J6@0C71/051dL01PQ800J8b805b0O01<L
6`0E71d06QhQ01/O8P0M8B<0720Q01`P7`807R8Q01`0724M01XO6P0M8Q`07b@N01lW900O9bT09c0_
01hX9@0G8Q`082dT02Ld:`0U<RT08C0Y02@c;P0R<Bh08Bl_02Le=`0Y=S`0:3Dk02Hc>@0X=C/0:STn
02`k?`0^?D00;T1202m1@`0a@dD0=TY;0P0eAd/0700eAdT0=4I603=5A@0aAD<0<dU703E;B@0Z?d80
=4]A0358CP0jDET0@EMT051SL@1ZOH/0@UES04]NK012E680@E=Q03i@GP19FFP0?DeL04ICH`17EFD0
A5IR04IHI019FfL0BUaX04]MJ@1:G6H204aNJ00;04ePI`1<GfH0BUeT04MJG`1<GV00C5iN04QJFP16
F5P0BEaK04ePGP1>HEl00P1FJFL01P13EU80EfYV05]^JP1NKVh0Gfm_061`L080HG5a0P1RLW80101W
MgL0J7Qh06IfMP1VMWH206UiN@0f06YjNP1/O7`0KWin07:1PP1ePh@0Mh:407V4QP1mR8X0PH^=08F?
T@28TY@0Phn?08NCT`29UID0RiFF08jHV@2@VY/0SiNI08fEU`2?UiT0TYNJ09fRY@2W[Jd0W::O09JJ
V@2GViX0V9bK09jOX@2TYJL0[:f_0:j]/P2_[[<0/:nd0:j]/P2/[K80[[2h0;Bg`02c][l0/k>k0;nn
a038ald0^;Nm0:bZ[`2a[k@0][Bi0<2n``2l^L00_Kc50;bia02j]l80`[k<0<_5d`3:a=<0b/?C1P3;
`]D05039`=<0b;oB0<_2e@36_m40`[c;0;nla@2j]kh0][Bf0;Je/@2_/:/0XjBM09BES@2TYId0Z:ZQ
09BGSP2;SX<0LgQ/071fJ01]LfD0JW5R0P1WL5l02@1UKEd0GVIG05YRD`1JHeD0HfiP06A_H@1WLVD0
K7Q/06MeJ00205m/HP0:06IcJP1^NG<0Ig9^06A`K01XM780Ig=a06EdL@1RL700I79b05e]K080EFEU
05<0D61P04ADBP16DdT0@4e304A?A`13CTH0;cXb03Ho>P0Z<bh0;C<a034g=`0k@D40;S@d04=8B`12
AdX0<cPk03<i>@0/<S808BLU02H/:00]<bl0=C`f02T`:@0`=c009c0[02lj=P0_>cT0:cLe02di=`0a
?C/0;CTg03A0?P0[=cD0:3@b02Te<`0[=cD0;c/k02hi>`0`>ch0=3m1038l?@0T;Rh07RTU020Y9P0O
:B808R`T024X800N9A`08RTR01<L6`0L92D08BXW02</:@0P:R<05AlG01XT700G8AX07bPS018K6P1]
MWH0Mgn101lS8`0N8R407b<R02<W9P052@X0<CDf01dQ900F6Qd09RX]020S:00H6b0061`O01LI5`0W
:BH0<38_01hP7@0O8Ah05ALD01LI5P0H6QL06A/H01/M6P0201`N6`0J01LG5@0N7Q`09bLU01lO7@0K
6aT051@B010@3P0O7ad08R8P02<S8@0A4@l05aLE00d<2P0K6QP061LE03ln?00X9bD05QDC01/J600E
518020L600h=2`0Q81h04Pl>01LC4P0F4Q4201DA400[01HB4@0E4A005Q8A00l;2P0F4Q406aLF01DA
400G4a405a<@01TE4P0J5Q<05a<@01@@3@0F4Pl06aLD00T50P0C3``030P502/W900U8Al04`l>01@@
3`0P71/06QHE018>2`0D4@`030T401<@2`0E4P/03@X301DB2`0@2`P02`H301LB3`0I51403PT6018=
2P0A30T040/8018=2P0400004Pd:01@?3003010<2@<04@d:00<04`l<014=2P0?2`P00P0?2`P02P0<
20D04`h:00h91@0;1P803PT503`g<`0E40`040/7018=2@0A30P200l:1P03010;1`0>2@D03PT50080
3PT500@040/7014<200B3@T04@`80P0@2`L01@0A30P04Pd901D;2P0C2@P05P`;00806@l>00@050X9
01471P0D2PT05@/:0P0D2PT00`0D30X04PX800l:1`0200h91P0500l:1`0@2`P04Pd:01<>2`0B3@X0
0P0?2PL02@0A30T04`T800l5100A1`H04PP701H<2`0L4Q4040H501<9200201D;2P0801881`0@20H0
40P901<=3@0J51@05a4A00l92@0>20P200l92@8040X:0P0>20P0100E2``050X;01<92P0B20T20147
200901882@0@1PL04`T:01882@0@1PL04@H901052@0B1`/04`P<00<04@H:0P0B1`/0600C20`04PL;
01872`0A1PX040D900l4200@1@T04@H:01052@0;0P@060dA00d21P0A1PX05``@01<8300>0`H05P`=
01882@0D2P/0?cDf03D[;00?1@H04@L801061`804@L801<04PP901hD5@0D2P/04PP90147200C2@X0
5`d>020F5`0700003PH601T?400C2@X05@/<02LM700:00004@L600`20@0700003PD500H04@L600H0
4@L801882@0@1PL04@L801@:2`0>10D20147200401882@0C2@X05P`=01dC50`040H70P0A1`H30106
1@0701471P0E2`X05P`;01@:2@0A1`H03`D401061@0Dooooo`006oooool00`0D30h04`d>01<=3@03
01<=3@0802@N7P0E3`l04Pd<018=300G4Q803PT8014;2`0B30`201@>3P03018<300A2`/04P`<00@0
4@`:00d04@/:03lk>P0A3@d02@D401@@3`0B3Pd04`l>01dI600J5QD05A4@00`81`0G4a803@T80080
4@d<0P0@30/0100?2`X040`;018>3@0=2@P201@@3`03014=300C3`h03PX900804@d<00D04Ph=014=
300?2`X0510?014=3002010<2`03014=300B3Pd04Ph=00<04`l>00D04Ph=01<?3P0<20L030P701<?
3P0201@@3`8040`;00<03`/:010<2`0B3Pd00`0C3`h301@@3`0701<?3P0@3@d04@l@00d;300A3a00
4a4B00`:2`0200h<3@0A00l=3P0B41404@l@00l=3P0A3Ph04Ph=014=300@30/04@d<01<?3P0A3@`0
4Ph=01<?3P0@30/03`/:010<2`0B4@l00`0C4Q00100B4@l04A0>014@3P0@3`d300l>3008014@3P0A
3@`04Ph=01TE500J5QD0510?018>3@0F4Q42014=300A018>3@0?2`X04`l=01D@3@0G4@d05Q4>01@@
3@0F4Q006QHD00X91`0F5A<02`/:03Hg=@0D5QD06Q`I01<C4@0A40`00P0E51001@0?3PX04Q4=00l>
2P0C4Ph05A@@00<04a8>01404A0;014@300G5Q8051<?00d<2P0@3`d051<A01HE500P7Ql06QPI014?
400M6a`081`M01/F5`0C3Q004Pd?01HA4`0201XE5`0D01TD5@0H4a@06QDF01/F5P0K5aH05aPB01HG
4P0E5Q005aPB020Q6`0V9b4061TD01HG4@0H6A<071dG01/L5`0I6QD061HD01LG5@0H61H201TI5`0;
01TJ5`0J6aP05ALD01<E4P0H6QL061dI01HL6@19DE008RX[05mXJ00N9RP00P0E7Al0:@0H82806B4S
01XR8`0G82005QlO01TN800L82<07b4T01lS900O8b<07R8R01hR8@0P9B008BHR028W8P0P9Al07R<L
01lW8`0I8b@06bDT01lY9P0S;RT09C8Z028_9`0Q;bP07RdW02@b;`0T<c4093@c03I4B00fA4/0:3Dk
02Xh?@0b@4D0;Ca102dm@@0_@D<0;Cm102m2A00aADH0<DE50080<dE801T0<TA60355A00aAD@0<dM5
03I;B@0fBd/0>De@03U?E00mDUT0?59J03U?F`0hCUX0IGZ604QMJP11EF<0>TeK04MJJ00oDV00AEMU
03i@GP10DF00BeaZ04=EHP14EV80BE]W0080BeeY00@0CV1Z051RK01=H6P0CF1W0P1BIF`01P1<Gf@0
DF=S04ePGP1;GU`0BUeK04ePGP80DfIT00P0E6MU05Q[J@1FJFH0EFQU05MZI`1JJVT0GFe]061`L080
HG5a00D0H71`06=cL`1TM7@0IWIf06QhN00206UiN@0Q06]kO01/O7d0KWeo0720P01dPh<0MhF507R4
Q@1kQXL0OhZ<08B>T029TiD0RiFG08>?T027Ti@0RiJG08fGV@2?VI/0TI^L092HVP2<U9H0SIFG092E
U`2GW9h0WjFU09JLV@2FViL0TIJB0:N[ZP2i^kX0/;:b0:RYZ`2ZZZh0ZZZ_0080[:^`01L0[:fb0:ja
^02/[kH0[[6h0;Bd_02f]k`0]KJk0;:a]`2^[K80/[:e0;2^/P2h][T0^;Jj0;Bc^`2c/K/0/K2i0;^i
a@32_//0a<3>0<W4d`39`]<0b<7B0<Nod@020<NodP0h0<S0dP35_M00`kc>0<O1dP32_Ld0^[G40;^i
`P2h][d0/;2a0:j^Z`2WZ:@0WYnJ09NHTP2MX9X0T9>;08R;P@27SH80MWa_07=iK01]MFL0KGEV06]c
I01SKUl0H6UK05mWF@1PJe`0JWEV06QcI@1YMFL0KWY/06mkK`1_OG00J7E[06EbJ01[N6h0JGM`06=`
K01TLFl0JGId06EcL01OKFd0FfUY05aZJP1EIFD0Cf1P05=TI01DI6@0BUU?04QEB@13CdD0A4m603E0
=`0d?CH0?4E002H_:P0nA48202hd=01402L/;`0X;Bl0:Bh`024V:00Z<300:c4`02X`;P0^=3009B/W
030g<@0Z<BX0:2lX02dg<00b?CT0=D4o02hj>00[=cD0<3`j038n?00^>SP0:cLf038n?@0c?ch0:cLf
02/g=`0X<cD09S4e02Lb=00W<C409S0^02`g<P0X<R`09BlW02D^9P0R:B407B@K020W800M9R@07BDU
01/T8@0J8al072DN01hX7`0K9Ad06b<M02H]:P0I81l08BPY01hT9`0P92<08bLV01TM700]<C40;30a
06IZJ`0o@dD0A4Q:01@H6P0L7b<04QDI024U9`0K7A/05QPE01/M6P0M7a`05aTF01TK600K7AX201XL
6@0801TK600H6QL061XG01PH5P0G5aD07QhL01LG5@0J6QP301TI5`804Q8@00<061PF01LG5@0I61H0
0P0G5Q@201HE4`804a8@00H051<A04E4@P0E51803Pd;01LE4`0H51<201TE500<01LC4P0F4Q406ADD
028N7@0M6AP06aLF01PD4`0D3`h06ADC01LC400F4Pl0510=0P0C3``0200D40d05Q8?01PD4@0@30T0
6QHC010<2@0d<2h07QXI0P0@30/0500@30`0510>01<@2`0C40/061D@00d:100>2`L05A8<00h91P0E
40d03PT601LB3`0D3``04`h;01D@3@0?2PL07QTF00d81P0D3``04@`90P0?2`P2010<2@<04@d:0P0@
30T00`0C3``05A4>01@@3@0201<>2P0501<=2@0C3PX04Pd901@?2`0?2PH00P0B3@T00`0?2PH03PT5
014<2002014<208040/70P0A30P09@0?2PH04@`8018=2@0B3@T04@`800l:1P0D2`X040L501071P0F
30/060h=01<:200D2PT05P`;01H=2`0D2PT04`T801<;2@0@20H040X8014<2@0B2`T040X800h91P0F
3`d06aDB01HA3P0>2@H050d;01/D4P0G3@`04PP701@:2@0B20L03P@401071P0C2@P00P0A1`H02@0B
20L050X901@<2P0@20P03PP8018<300@2PX03@L7010:2P0200l92@0600h8200=1`L030H600/61P0G
3@h04`T:0P0A1`P0200B20T050X;0147200@1PL050X;0147200?1@H04`T<0P0@1PT0100H3Q406a4D
01@:3@0@1@T601872`0D01062@0@1@T050T=01D:3P0A1PX03`@800h41`0D2@d040D901D:3P0=0`H0
5@/=00/10P0J41404`T:00d3100J414040H701<92P0B20T201<92P0501@:2`0Y7b006a4B01<:2`0@
1`L00P0B20T02`0=10@05`d>01D<300R61T09A/L01<:2P0D2PT05`d<0188200A1`H060h=00L04@L6
00`04PP900l51P0F30d060h?01061`0?1@H04PP901061`0?1@H040H701882@0C2@X<01061`0500l5
100A1`H04PP701881`0A1`H00P0?1@@01@0B20L04@L601061@0A1`H04PP701Cooooo000Kooooo`0K
01<83P0D2`l05@`?01@;3P0B2Pd03`T;014=30091@D07A`H01DD400@3`/01@@000d71`0E30d04`X;
01<;2@0H40h050`:01TA3`0C2`P0610=01491P0D30T06A@@024M6`0L61L04`l>008040`;01D02`L6
01DA400F4Q403@T800X61@0D40l06ADD010:2P0C3@d04@/;00h8200B30`05Q0@018<300C3@d04P`<
014;2`0C3@d05@l?00l;2P0A3@`00P0B3Pd05`0?2`X03PX900h:2@0=2@P03`/:01<?3P0B3Pd05A4@
00/71P0E4A007a/J00T5100?2`X05A4@010<2`0J5QD04@d<00`81`0C3`h030P700h:2@0@30/04Ph=
00804`l>01@04@d<00l;2P0A3@`04`l>010<2`0>2PT03`/:01<?3P0F4Q404Ph=00h:2@0A3@`05a<B
00P40`0P71/02@D4020L6`0?2`X0510?01<?3P803`/:00L040`;014=300O6aX020@3014=300:1PD0
5a<B008040`;00D04`l>014=300>2PT04Ph=01DA400200d9200400l;2P0@30/04@d<01<?3PD04`l@
0P0C3`h02P0M6AP0510=01@@3@060P003PX7014@300C4Ph051<?00l>2@0A3PT201<@2`0I014@2`0?
40/0414<01<D400E5A<04A0>02<O7P0O6aX05a<B01DA400C3`h04Ph=01@@3`0F4Q405a<B01PD4`0F
5A405A@?010A2@0W:2003a0:018C3@0K71L05AHA01<D3`02010@3P0L01LG5@0M7A/0[J^/024O800C
4A805A<D01<B4@0E51804a8@01HE4`0J6AD05QDB01DD400I6QD061TD01TK600C5A004Q@@02d_;01V
J6<06Q`H018D4@0G6A@05aTE014C400C5A0071hI01PJ5@805aTD01`06A/F01TN600Q9Al04aPB018G
4@0I7QP06b0J01TN600I7a/06AlM020V900I7al0724T01XO8P0H7B0061hN01LM700F71X06AlK01`P
700L7QT07QlJ01lQ700Q8ah082DO01dR700E6Q<08BPQ0P0P9al0600U;2@05alK02<];P0Q:b`072LV
02di=`1aOGd0934a02<a<P0M:b`0;3/m01TX:`0O;S40?diD03A5C00S<ST09cLm02Li?@0U=c/0:S`o
02i0@P0`@T@0<49302m1@@80<D=30100=DM703a?CP0aA480=4M50394A00cADL0@UIG04AFF@0lCe<0
>4]A03mBF00eB4l0<TA>03Y<EP11Del0?DmK0`0nD5`09@11E680AUUW04YMJ`1>HG00AeYY04MJJ015
F6L0BUe[055UL01HJW@0DVE/04ePI`1CI6/0FFYa059TJ01=Gf<0CEmO04]MG@1=Gel0DVAT05IXJ01E
IfL0CEmO05=UI@19Fe/0DfEU05U/J`1JKF/0Hg=b05m_KP1[NgX0GFe/05a/J`1XN7L0Hg=b06IfM@1Y
NGP00P1XN7L0>@1YNGT0IgIm06imQ01cPXL0Lh:507>2PP1dPh00NhN5075mN`20S8`0SiVK08>=T02B
Vj80R9>I08B>U`29U9X0RiBJ096JW`2KYJL0U9bN08VBT@2:Ti80UYbK09BJV02?UI<0TiNF09FIV02J
WYd0a/[;0?_oo`35bL`0X:BW0:BW[02WZZl0Zjfb0:b]/P2Z[K80ZZfe0:ja^P2a];d0/[Fl0;6b]`2_
/;D0/:nd0:f][`2][Jd0ZZRZ0:ZXZ@2_[Jh0/K2d0;2_]@2/Zk40/k:h0;bk``2l^l@0_K_60;nkb@02
0<2lbP060<6mc031_/X0^k[20;Vg`P2l^l@0]kJn0P2e];`01@2a/[L0/;6e0:n`/`2WZ:X0WIjP0080
U9BF01l0Ti>A096CS024R7X0MWe]075hIP1UK5X0I6eJ06E^GP1WKf80J71U06A/I01NJ600IFmV07Eo
M@1]N6X0JGEW06ikJP1ULF<0GfeP06MgK01]OG<0JWUb06QiL`1VMg40HgA^065aKP1NKV/0FFUV05IV
H`1IJFH0DV1P0080D5iN0240CU]J04E@BP1;EDd0?TQ003Dn>@0Y<Rd0=3di02H_;00b>cP0;CHe01hW
9P0_>3L09Bh^02D^:`0T;BP0:34^02df<`0/=C809Bh[02Xc<00V;b`09c0]02`e<P0^=cD0=Cln03Q4
@P0/>cP0BEQE030o?00V=C<0<3hn02Xh>00^?3`00P0b@440800_?Ch0;CPj01hY;@0Z=3D082XY02Xc
;P0I8aT0>D@f0459>P0f?S00:2hT024V7`0N8ah082HR01LP6`0J91l06B8M01LQ6@0K91`08RTR01LM
6@0Q9R807B4P01`N7@0O8B407R0O028T8P0S9B8092HS028T8@0N81l071hM0P0O8B001@0M7ah06adL
01`N7@0N81l06a/I008061PF02L07QhL01dM6`0I6AL05QHD02@T8P0F5Q@07QhL01@D4P0J6QP07A`J
01`K6@0:2@L07QdK01<B400I61H071/I00d<2P0@3`d06aXH01XI5`0F5A<061LC01DD400D4`l05A@@
01LF4P0E51003`h:01HE4@0d<bl08b8N00l>2P0E51406APF00/:200J6AL05A@B01LC4P0H4a800`0I
4a<01`0G4A4060l@01@?3P0B3P/0JFER024M6P0L61D00P0F4Pl2018>2`0K01LC400H5140510=018>
2`0D40d04@d:00`81@0>2PL04@d:018>2`0C3``04@d:00l;200@3@P040`901<>2`080P804`d=01TC
4`0B30`05A0=01<>2P0D3`/05A0<01@?2`0C3PP04@`800<04`h:00d04Pd9014<200A30P040/701<>
2P0?2PH040/701@?2`0=20@04`/901H>300D2`X07aLE00804PX800`03@P5018>2`0U8Ah08QhK00d9
200<20D06A@@00L2000@2`L050l;00`70`0C3PX6010;1`0F010;200A2`P040/8018:200A2`P040/8
01L?3@0F3`d04Pd:018:200@2@L050`:01H>300C2PP04@T701@:2@0C2PP03PH401D;2P0D2`X04PX8
01<:208050X900h06Q0?01@:2@0@1PD040H501@:2@0F30/050X901881`0>10<04@L601D;2P0B2PP0
4`d:014<2@8040/800D03`T900h8200?2@T03PP:00d72@0200h82P0R00l92`0B1`/04@H:01462P0B
1`/04`P<01@93@0?10P04@H:02HK7`0H3A40304500l72P0E4A8020@5081kO@28PX@06aDG01482`0>
1@P03`@801@8300A1@T040@800d41P0I4a<03PD601D<3@0V7Ah01P000107200B20T040H701051P80
40@601<04@H801<9200A1`H04PP701`B4@0I3`h04PP701<9200D2PT04`T801061@0=0`803P@300l5
100E2`X050X900d30P0>10<04PP700804`T80P0@1PD01`0C2@P04PP600d40009000040H401H<2P0A
1`D00P0A1`H02P0A1`P050X;01T?400A20P01`0001T?3P0]8b807A<B00l5100@1PD200l510050147
1P0@1PD03`D400d30P0A1`H00P0@1PD05@0?1@@040H501471P07000060h=00/1001;@D0040H601<9
200H3Pd030<201L=300A1`H030@300X0000F30/01`0001T?3P0A1`H06a4@00L0000Dooooo`006ooo
ool0800C20h050X@01D<3`0D2`h04P/=010:2P0;1`H06QPD00d<20041@002@X7020O6`0<1PH050/<
01482@0B2PP05Ph<01491`0E3@X040T401<<1P0G40X03`P200@0000G4Q005A4@00l;2P0@30/04Ph=
00l;2P0A3@`05A4@0`0C3`h0100@30/050h>014;2`0@2PX3014;2`8030H600@03@L700l92@0?2@T0
3`T90P0@30/2014=300C010<2`0?2`X04Ph=01<?3P0D40l04`l>010<2`0=2@P061@C01@@3`0e<C00
;2PW00L30P0B3Pd030P7010<2`0B3Pd01`<200`81`04018>3@0I014=300@30/04@d<010<2`0?2`X0
510?01DA400B3Pd040`;018>3@0D40l04Ph=00l;2P0A3@`030P802<O7P1RGUd0:bLV00/71P0810<0
8alN01`H5`0C3`h03`/:010<2`02014=300<00D1000E4A004Ph=01XF5@0>2PT040`;01@@3`0C3`h0
40`;01<?3P0E4A003`/:0P0@30/2014=3003018>3@0B3Pl04Ph?00<04Ph?01H04Ph=010<2`0A3@`0
4@d:00D1000L61D061D@00l>2P0@4@`04Q<>010?2P0A3`T05A8;01<@2@0B40X040l:014@300C50l0
5QDA00l;2P0G4a805Q8A0P0E4A00:`0=2@P04`l>01DA400E4A005Q8A01DA400C4Ph051<>01<D300T
9Ad051D=01<D3@0C50h03a0;01/L5`0H6A@05ADC01LG5@0B4Q00=3@d010@400Q8B407AdM01DE500?
3`d05aLE01LH4`0I6QD05QLB01HG4@0L7AL0418?00X<2@0A4a006Q`I014C400S9B804aDB01HH5@0E
5a@07AlL01hP7@0E5a@00P0D6A<0:`0E6Q@061dG01`Q6`0M8Q`05a`F01HK5@0D6A<04aPB01DJ500F
6aD05ahG00<91@0H7QX06AlO01TN8@0G71l061dP01PN7P0G7A/05adI01TP6@0M8A/07b0J020Q6`0Q
8ad08bHO028W800W;2D06AhG01/R6P0O9Qh06b8J02<Z8P0M9b<06bDV014K700W<S808bl_03Y5A`0O
;2h09S@g02Th>`0V=CT00P0d@dP0J@0iBDl0<T=:02Df?@0[?480;3i202/m@@0]?d80;Cm102m1@`0^
@440;Clo0312@P0kCT`0=DQ602m2@00bAD<0<4=103Y<C00a@dD0@UAF03mAD`0jC500?DmC03mAE@13
E5`0A5EM03e>F00kC5H0A5EO04MII@13EF40@UAP041CH@12EF<0AEQV04MMJ`12F6H0@EMU04QKJP1?
HW00DFE`05EWLP1CIVd0Cf9Y05=TJ`1HJVh0DVAX04eOHP19Fed0B5YJ04YLG01>H600DVAT055SH`1I
Jf/0G6i^059TI01HJVX0EfUY05U[J`1JJVT0IgMf08BDT`1gQhH0IGEd05i^K@1UMG@0Hg=b069bL@1Y
NGP0LH6006alO01XMgh0KGb40760Q@1aPH40LH5o07>2O`1dP7`0NXJ407N3P`21Rhd0PhbB08N@V@28
TY/0QY2J08^EWP2;U9X0SIJK09BNX02@VIT0RiBC08jGU02FW9T0TINC08bBSP2HW9/0TiNF09FIV02`
];D0dMGH0:Z^/@2RYZT0Y:N/0:NZ[`020:V//@0F0:V//`2XZk@0[:nh0:nb^`2`/kX0[k2e0:f^/`2W
YjX0YZJX0:RXZ02VY:D0Z:NU0:f/ZP2_[k40[jjc0:^Z[`2a/;D0^KRn0;Vh_`2j^L40^kW40;bjaP80
_;[700D0_[g70;Vj_`2e][/0]kRm0;>d^@020;:c^00N0:n`]@2][[80ZZ^_0::SY`2KW:00Ti>H0:2O
Y027QhL0Rhf608N;O@24RgT0JW9L06M_F01TKEX0JG5Q06mgK01_MVh0JG5[061YI01UKVT0LWac06Uc
J01ULF<0IG9Q05aXFP1MJeh0IWI/06]kL@1XN7<0GVmY0P1KKVP205a_J`1505][J01FIV<0EVIS059P
H01AGel0C5YJ049>C@0mAT40<cde03Y3?P0g@3/0;3D`02H_;00nAd@0@4U601PQ800V;bh0>T=202lg
>00[=2l0;3H^02hg<P0`>C@0;cPc02/d<@0b>cP0;SLd030i>00b>cX0<SXk03Do@00[=cD0;chk04YI
EP0eA440;3/i02<a<@0Z>3T0;3Xk02dk?00/>Sd0:SPk02Pf>@0_>3d0:38c020[9`0b?3<0:3<T04MB
@@2LYI80NH5a03m5>@0a=Rl07b<Q01HL6P0J91`06bHM01/U7@0J91`07BDO020V8P0N8al09BPV024S
8P0P82008R8R01hN7P0P8Ql07b4N00807R0M0P0M7a`00`0O8Ah0828O01lQ7P0201dO700W01hP7@0M
7A/06QXH01`L6P0P81h07QhL01XJ600R8R00I6AR05MGE@0G5aD07alM00T91`0N7A/081lM02<R800J
6AL081lM010?3@0J6AL05aHD04m>C00l>cT06APF018A3`0H5a<05A@@01@C3`0E51005aHB01PG4`0B
4@d040l;020O6`0H5a<040l;04i=BP1PGed08B0N008040l=02H05Q8A01<>3@0D3Ph05@l?01L@400G
3Pl05Pd>01<=300n>SL0W9RE01hK6@060P005A4>01XF4`0C3``05Q8?01LC400D40d04`l<010<2@0=
2@H03`/801LC400L61D05a<@01/G500G4a0040`900`81@0A3@X061@A00l92@0i<c<0A3hn010:2P0;
1@D03`X701<>2P8050l;00<04`h8018=1`0B3@L00P0B3@T2014<208040/701@04@`8018=2@0@2`L0
40/701@?2`0>2@D08aTH00L0000E2`X0>30^00H0000B2PP06A@A018>3@2FTXl0THf:00d:200U8Ah0
9b8N01D@30804`h:00<03@P4010;1`0@2`L01@0@2`L6010;200700X50P0A30T03@P501<>2`0H4a00
5a8?01D;2P0201881`8050X900@04@L601881`0B20L04PP70`0C2@P00`0G3@`050X901<920030188
1`0701`B4@0I3`h04`T801881`0C2@P03`L500l91@0300h91P803PP800<03`T900h82P0=1`T00P0>
20X02P0?2@/04PL;01462P0A1PX04PL;01<8300D2@d05@X>00/0100E2Ph201052@0:01D?4@0=2``0
2PP904E2@`10?3d04@/=018;3@0@1`X04@H:01@8308040@800H06a4C00@0000B30`03@H600H0000F
3@h201@:2`0=01<92P0C20T04`L901@82P0D2@T04`T801471P0B20L06Q0?01L=300@1PD04@L60188
1`0301<9200401471P0@1PD04@L601<9208050X901X03@<200h40`0?1@@03@<200h40`0A1`H03`D3
01<:1@0E30L03`D300d30@0?1@<06@l>01881`0A20T02@0000L0000o=CH03`D401H<2`0K4A004PP7
00d30P0B20L040H501471P804`T800<04@L600h40`0A1`H00P0@1PD02@0?1@@040H501471P0R61L0
3PD501471P0j<2l060h=01@:2@0201881`0:01471P0=0`806Q0?01061@0B20L0DTQ700`20@0@1PD0
1`0001/A41Cooooo000Kooooo`0K01@93@0D2Ph050/=01@;3@0C30`04P`;018>300>2`P07QdH01@E
3`0<3@L04A0;014;2`0D2``04`X;01@<2P0E3@/04PX801@<2@0H40d04PX701<<1P0G40X06QDA01<>
300C3`h04@d<00804Ph=00P040`;018>3@0B3Pd040`;01<?3P0B3Pd030P701LA4@804@/;01<050h>
018<300?2@T04@/;010:2P0C3@d06A<C01H@400B30`04Ph=010<2`0?2`X040`;014=300B3Pd05A4@
01XF5@0I5A@04Ph=00803`/:00`05a<B00d9200I5AD081`K00l;2P0C3`h05A4@01PD4`0T81l05A4@
00`81`0E4A03014=30<04Ph=00P040`;00d9200@30/0510?01<?3P0A3@`04Ph=014=30<04Ph=00l0
4`l>00`81`0P71/03`/:01TE500?2`X061@C01XF5@0A3@`03PX9010<2`0B3Pd0510?014=300C3`h0
0`0D40l0100?2`X0510?01HB4@0C3`h201DA40804Ph=0`0C3`h00`0D40l04@d>014=3P03014=3P0=
014=300G4a8040`;01@@3@0T81d03`/801@A3@0@3@X040l;018@300C40/0514<01HC3P0201<@2`07
018@2`0C40d0518?01HC400E4A00510?01LC4P0201dI6003018>3@0D40l05A4@00805A4@00`0510?
014@300@3`X07QlG010A2@0A4P`06Q/E01`M5`0E5Q405QLB01<D3`0A4@l201<C4@0<00X:2P0J6QX0
4A4A014A4@0I6AP051@B01DE4`0D5A005aPC01HG4P0F5a406a`F0P0D5Q<03P0I6aP05QPE010B3`0K
7AX04Q@A01XL6@0F61D08B<P02@V8`0E5a@05AXD01HK5@0G71H06AhH0P0J7aT00`0H7AL08RLQ024V
800201PM5`0=01dR700J8AX05adI01`R7P0F71`07B8U01@I700I7R406R0P01TO7@0I7a/06R4J01lS
7@02024S7P0:02<U800T9R408bPR02H[9@0I7QP06B0I028Y8P0K8Q/07RPP01hX9@809Bl`00d08Rd^
02Pd=00O:R`0@4a?01/Y;00Y>3/08S4e02Lf>`0N;C80:SY002Lh?`0U=Sd0;3e30080:Sa000H0;d54
0312A00a@dD0<49302m1@@0a@d<203=6A00803iAC`1WNWP0@eID03I8B00eAdT0@59D03a>D00kCE42
03i@E00W045BFP1;G6@0A5EO03e>F018FF<0A5IR04YLJ017FFD0AEQV04MJJ018FfT0@eUW041FI00n
E680CF1_05IYM`1@I6l0E6Ia05AWKP1AI6/0DfA[05=UJ@1?HFD0BUaO04QJG019Fe/0BeeM04mQH@1A
Hf<0D69R059TI01DIVH0EFMW05]]K@1DIVH0Ffe]05e]K01LK6/0JGUh0080GVi]02T0HW9a05m_KP1W
MgH0Gfm^06MgMP1kRhX0M8B406akO`1_OX<0Kgj006inO@1`P7h0M8>007R4PP23Shl0QI2C092IW`2;
U9`0QHjG08RBV`29U9/0S9NL08^DV@2;U9P0SYRI08bEU02?V9H0TY^G09>JU@2?UI00S9:>09BHV02>
TY<0UYZK09jRX`2VZZd0X:BW0:BXZ`2UZ:d0YZV^0:NZ[`020:JY/0080:JY/P2Y[;D0Zjjg0:b_]P2/
[K80Zjba0::SYP2SXjD20:JVYP0:0:VXYP2_[Zd0/[:d0;6`]@2_[[<0/[6f0;Je^`2f]K`0][Fm0;Jd
_`80]kG002P0]kG20;Nf`02a/[L0[Jjc0:j_]02[[;40ZZ^`0:b]/P2/[K40Z:V]09jOX`2EUYX0TiBH
0:2QY@3?d=80ZJ^Z0863O01^LV@0OHAb06A/E`1QJE<0HfaI06]cI01aNFh0LG]b07EoN@1aNWH0KWMb
06]fK@1NJUh0FVII05]XFP1KJE/0H6eQ065aI`1QLFP0H71Z05e^J01JKFL0FVeY0P1KKVX00`1JJVL0
FFUV05=SH002051NGP0P04aJFP11CD`0<CXe03Do=`0kA3l0?TM20419A00V;b`08R/X02Tb;`0c?3/0
8BXY02Xc<P0f?cl0<S/f03<m=@0c?3L0;SLb02df<@0`>CH0;CHc02`e<P0b>cX0=Sln03<l?00d?Sl0
=40n02ln>`0a@3d09SDb030n?@0Z>3P202hl?@0M02dk?00/>Sd0:3Hi02Lc=`0[=3T0:cDf02Pc;`0Z
=2`0<ch`07f8M`3cn^/0]Kb]03Pn=00[<2T07R8O01lU8@0M9al06bHM01dW7`0O:B407bLQ01`R7P0S
:2@08bLT024S8P0S8b<08R8R01`L700T9R<00`0R92400`0S9B8092HS01lQ7P02024S800O01hP7@0M
7a`07R0M01`L6P0I6AL07AdK01hN700I6AL05ADC028R8027QhD0LG5_01/K6@0C4a406QXH024P7P0V
9B<09B@R04U8AP1gMW@05aHD020O7@0D4a40?C`j02TX9P0N7A/061LE01PG4`0E510051<?01DD4002
01LF4P0K01TH500D4`l04a8>01<B3P0A40`0=3<`040o?@0H5aD05A@B014@3P0E4A004Pd<01<=3@0E
3`l06A8B01T@4@0G3Pl05a8@00H20@0X9240510=01PD4@0B3P/04`l<01DA3P0H51405Q8?00804Ph;
00D05A4>01@@3@0D40d03`/800X71@02014=2P0;010<2@0B3P/04`l<018>2`0C3``071HF02TS8`0S
7Ad02P@401LA4@0F4@h00P0D3`/0100C3PX04@`6018=1`0C3PP3014<208040/701T03`X6018=2@0B
3@T04@`8010;1`0B3@T040/701L=300:0@409ahM04e5@`0H40l04@T800h91P0C3P`09b<P028N6`0B
3P`08QhK01/F4P0E40`030L300d8100D3`/04Pd900H040/71P0@2`P01`0<1`@04`h;00d81@0C3P/0
40/800d81P0C2@P00P0B20L01@0D2PT05@/:01@:2@0A1`H050X900805`d<00<05P`;01D;2P0C2@P0
0P0E2`X01@0D2PT040H500h40`0J40l060h=00804PP700H04`T800l71@0>20@03PT600l:1`0A30T2
018<300300l92@0>20X03@L900803PP:00H03`T;01872`0A1PX04@H:01872`0C20`201@93@0G01<8
300D2@d04@H:01872`0I4Q@02@L800h<3@0?3@d02`L801H@4P0D30l04`X=01872`0C20`040D90145
2@0@1PP05a4A00h92@0B2``040L800l7200C2@X00P0?1@H02@0@1@L04PH80186200C20T04`T80106
1@0A1`H05@/:01<9200401061@0901471P0B20L04PP701P>3@0C2@P03@<201@:2@0B20L03`D40080
40H500H03`D400h40`0B20H04`T701480`0@1`<200l50`0801881P0C2@P03@@401882@0E30d05`d>
0557B00C2@P201881`804`T80P0@1PD01P0B20L05P`;01H<2`0D2PT040H501471P8040H501D03`D4
01061@0A1`H01`0001T?3P0C2@P040H501D;2P0K4A002P4101H<2`0?1@@04@L602hT8`0M4a8081HE
08b2P@0F30/02@000188200;0@405?ooool001_ooooo0P0C2P/06P0D2``04P`<01<>2`0D3`/03``7
030^:@2n_[H0EeM?01@D300C4Pd03`T900h82@0>20P03@L700h91`0B3@X050l<00X6100G4Ph081/G
00h90`0D3`/0510>01<?3P0D40l04Ph=0P0>2PT0100G4a806aLF01DA400?2`X2010<2`0E018<300E
3`l05@l?018<300C3@d05@l?010:2P0>20P04P`<01TC4`0D3Ph03`T9018>3@0?2`X03PX900l;2P0A
3@`04Ph=014=300H51<05a<B008040`;00L03`/:00T5100K5aH04Ph=00h:2@0J5QD02`L600807QXI
00@06QHE01PD4`0<20L03PX90P0?2`X0100@30/04Ph=01@@3`0D40l201LC4P08014=300C3`h0510?
018>3@0A3@`03`/:014=300B3Pd2014=300;010<2`0O6aX04`l>01<?3P0D40l04Ph=00h:2@0?2`X0
4@d<018>3@0A3@`00P0C3`h02P0:1`H061@C00L30P0@30/03`/:01@@3`0F4Q40510?01HB4@0E4A02
010<2`04018>3@0D40l05A4@01LC4PD04`l@00T04`l>00<0000k=cH020@202hZ9`0300003@X501DA
3P0D40d00`0D3``00`0B3@X050l<01D@3@0201D@3@0;01DA3P0D40d04`l>01@@3`0G4a8061@C01HB
4@0D40l04`l>01@@3`0F4Q400P0G4a808`0E51004A0;00/<1@0L7AL08b@N01lP702l_KP0@44l01XJ
5`0I6AL06QXH00`<2`0F5QH051@D01PH600>3Ph061PH01/K6P0?3`d051@B01DF4@0K71L071dH01TJ
500K71H061XG00P:1`0F61D05aTF01/M6P0L7Q/061XG01@F4`0H6QL071hK00806A/H00L06QlI01TN
600I7QP05Q/E01<H4P0B5a405a`F00806QlI0P0G71H03@0I7QP06R4J01HL600G7AT082HV020U:00G
71l06AhQ01/Q8@0K8Al06R0L01/R6`0N8ad00P0P8Qd0<`0Q91l082DO024V800L8Q`092/T02L^9`0N
9Ql07bTQ024[8`0R:bP08B//06afM`1_NW/06BDU024/;P2GY:H0=D=601d/;`0X=c/0<3m401/Z;`0Y
>Cl0:3U002dnA@0a@TP0;3i202do@`0`@TD0<D=50394AP0a@d@0;d510353@`0jCD/0<dI40395@`1O
LW00>Da:03A6AP0kCDl0=TQ:03a>D00kCE40=TQ<03U;C`0lCED0?e1H04QIH`19FV@0A5EO045CG`02
03mAG@0:04EHIP1>HFl0CV5_04=II`15FfT0@eUW04mRL@1DIgD0Cf=^05EWLP80DFA[00P0D65X04]M
H@19Fel0AeUL04]MG`1>H600DF=S059TI080DfEU00H0D69R05IXJ01GJFT0G6i^05AVIP1KKFd205a/
J`0X06MgMP1NKVd0HW9a06=cLP1XN7L0PI6@0720O`1PL6l0IgMf06IfM@1`P800LH6106moOP1^OWd0
LX9o07N6P`20S8`0P8^<0;k9c@3FgnH0W:B^08bDW`28TiT0RIBH08NBU02:U9D0T9ZK09>MW02>UiD0
T9VF08nHT`2?UI00T9N@09:ITP2AUID0Si>D09^OX02KWj80W:2S0:>WZP<0XjJ[0140XjJ]0:BW[P2T
Yjh0YJVb0:N[]02X[;D0ZJbc0:R[/02WZZl0Z:V/0:RXZP2YZJT0YjNW0:VYY`2_[jl0/K2d0;2_]002
0;:a]P030;:a]`2d/kT0/k:h00<0/k:j00L0/k6l0;2_^@2ZZ[80Zjba0:n`]@2YZZl0Y:FY0080XZ>W
0240XZ>U09jOX@2LWIl0XJ:T0:^/[P2NWj40Si6@075eKP1mPgD0IFaL05iVE01SK5T0LW]X07EoL01b
O740MGmf07Z3OP1`NGH0Ig9/061[H`1MJEl0H6eS06=`I@1PKF<0GFeS05QXGP1GIUl0F6QR061`K@1L
Kf/0FVeY05U/J01GJVH00P1EIF80@`1AHEh0CeiK04aKF016EE80?d]803i7@P17DDT0=Chi051IE00V
;bX0<c`i02Xc<00a>SL0CeQG03M0?`0c?3/0:c<d03Dn>@0e?cL0<S/f02/d;`0Z<bh0<3Tf02df<`0/
=C80<c`k03Q1@00f?cl0>493030l>P0Y=C<0=T90034m>`0Y=C@0:SHf030k?@0c?T00=3m1038m@@0Z
=CT092lc02Pb=00P:R/0<C`h03M1>@0V<B@0=d8b06]cI01TJed082HL02P]9P0O8b007B<O01hX800K
9Ad072HN020W800N9Al061hJ028W8`0O8b008B<R02@V9@0R92<07R0O01`N6`0P8Ql00P0R92400`0N
81d071hK01`N6`0201hP7@806adJ00D071hK01hN700H61H071`J01/K6@0201DE4`0b02<S8@0I6AL0
3Ph<01TI5`0F5Q@09bLU01`K6@0M71X06QTG01/J600Y:2H05QDC01LF500S8R004a8@01PG5@0B4@l0
4a8@01PG4`0E510051<?01DD400G5Q8051<?01`K5`0J6AD051<?01HE4@0B4@d03`h;01LF500?3P`0
5A@B00L6100@30/05a8A01PB4P0I4a<06a@D01XA4P0H3a004`d<01dI5P0V8Ql04Ph;01TE4P0J5Q<0
4`l<01DA3P0C3``201DA3P0I01<?300F4Pl03`/800X60`0I5A8071PE00/71@0;1`@02PH3014=2P0E
4@h03`/800d91P0<1PH01@0001LA4@0E3`l04@/;010;2@0C3PX04Pd9014<200@2`D04@`601@?2@02
01<>2P05018=2@0A30P04@`8014<200B3@T00P0A30P2010;1`0C01<>2P0:0000718A01H<2`0E3@/0
6a<A01@<2P0B3@X03@P501`H5@0M6AH03`/801HB3`0<1`<04`h:00h91@0B3@T07APD01LB3P06010;
1`H040/800L04Pd:00h91P0D3``03@P500/71@080`004@L600<04`T800X050X901D;2P0A1`H05@/:
01P>3@0I3`h05`d<01H<2`0C2@P04PP70`0A1`H02`0B20L04@L601881`0?1@@04@L601@:2@0@20H0
40T6010;200A30T04`h;008050h>00<03`T900h82P0=1`T00P0>20X07`0?2@/04PL;01462P0A1PX0
4PL;01<8300D2@d04PL;01D:3P0=0PH03`@801T>4P0F3a403@T:00`82@0?2P/05@lA018<3P0@20/0
40L:00l62@0B20/04@H:01@93@0@1`T071HF020J6P0N5aL040L801L>3`0<10D00P0B20T01P0C20T0
50P:01D92`0D2@X04@L601061@804@L602`040H501881`0C2@P04@L601061@0A1`H04PP701@:2@0T
6QT08QPG01881`0D2PT04`T801D;2P0F30/05@/:01471P0@1PD04PP601H<2P0A20<04PT401D;2@0A
1`D04`T700d30P0;0@0040H701L=3P0T6Q/05Ph>00d30P0?1@@05@/:01L=300E2`X040H500h40`0@
1PD050X901D;2P0C2@P040H501471P8040H500T03`D401061@0A1`H04@L600L0000_9B@0L6IU018:
2@0K4A000P0B20L02P0C2@P03@<201061@0700002`4000h61@0K4A005@/:01L=300K4A0Dooooo`00
6oooool0<`0D2``04`X;01<;2@0B3@X050l<01D@300>2`H0AdDo0?3`j01jNW806QXB00l<1`0D3Ph0
5@l@01<=3@0?2@T04Pd;020K600N6AH04`h;01D@300O6QH04@`601`G4`0@30X03`/:014=300@30/0
3`/:014=300F4Q408QhM01hJ6@0D40l03`/:00h:2@0@2PX05Q0@01D?3`0A2`/04P`<01H@400A2`/0
3`T9014;2`0E3`l04P`<00l92@0A3@`040`;00l;2P02010<2`05014=300@30/0510?01<?3P0@30/0
0P0A3@`00`0?2`X05A4@01DA400201HB4@0400l;2P0O6aX06aLF00T61@804Ph=00h04@d<018>3@0A
3@`03`/:010<2`0A3@`040`;01@@3`0E4A003`/:018>3@0C3`h03`/:010<2`804@d<0P0@30/05P0C
3`h02@D400X61@0A3@`05Q8A018>3@0;1`H040`;018>3@0E4A00510?00l;2P0E4A00510?00d9200]
:BP02`L601LC4P0?2`X0510?01DA400B3Pd201@@3`8040`;00@04Ph=01@@3`0E4A005Q8A1@0C3a00
2@0C3`h09R8Q085mO00S7a`07ATF01lK600C40/05a8?01HA3P0201@?300401<>2`0A30T050h>01D@
3@805Q4>01X05A0=01@?300B3Pd05A4@01PD4`0E4A004@d<01DA400B3Pd0510?01HB4@0H51<06ADD
01LF4P0K6QD0414:01lP6P19BT@0824K06m`J`0d=C004a<@01`L6P0R8R004A4@01PH60804a<C0P0H
61P02`0G5aH05ADC018B400A4Pd05QLB01LH4`0D5@l05AH@01hP7@0M7a`0<C<`00805aTF00/07b4N
01LI5P0@4Pl05aTF01XL6@0G6AH06adJ01TN600H7AL05a`F01HK5@0201DJ500301LL5P0E6Q@05AXD
00<061dG00l07B@M01dS7`0N92006R0P00`A500S:2/06AhQ01`R8P0M8b406b4M01/R6`0M8ad07b4L
020R7@0P8ah00P0O91h05P0Q9b40=Sdf030g<00J8a/08B/S02<]9@0]=S<02aDF03<m?P1=F5T09S8b
01TT9P15DU@07R`_01l^<@0S<SH0:3Ll01d/<@0U=C/0:CY102hoAP0_@DH202`n@P0H02m1A00a@dD0
<TA60312@`0^@400<49203a?C@0dAdD0;D0n04MJF00aA480=4I603]=C`0bA4H0>de?03Y<D00mCe<0
=TQ<04AEG@11DUX0AeQR04QIH`12Ded0BUaX0P11Del03@19G6X0EFQf05IYM`1:H6h0Aee[04]QK`1B
IG@0DFAb055UL01GJG@0Cf9Y059UK01?H6L00P18FUh06P18FUd0BUaN04mQH@1BI6@0DF=S059TI01C
IFD0CEmO05Y/K01EIfL0F6YZ05MYJ@1KKFd0FVYY05][JP1VMWD0Gfm^06AdL`1QLG00K7ak08RHU`1m
SH`0JWYi06emO01dQ8<0L81m0P1aPGh0701`P7d0Lh>007R6QP26TY80QY6D0=ORj03eo_l0Z[:n08nG
XP25T9@0R9>D08B@T029Ti<0TYbK09BOV`2?V9@0SIJA08^ES@2=U8d0T9N?09>JT`2GVi/0UIVJ09^O
X02FVYd0W:2S09>GVP2QY:T20:2SZ0030:6TZ`2RYJ`0XjJ]0080YJVb0140YZZc0:NZ/@2VZJh0YZV^
0:RY[02WYjT0Z:RX0:FUY@2VYZ@0Zj^[0:b[[`2/Zk00/:nd0:n^/`2][;80/K2f0;:a]`020;:a^@80
/K2h00X0[jng0:b/]02^[k@0];Fj0:b]/P2UYZX0XjBX0::SY@2OX:80VIZL0P2DUYD06@2=Shh0LG=b
08:4P@1dN700OhEi05MNCP1PJ5L0IVmN07EnK@1gP7<0LG]b07AnMP1jQ7h0Lgai06MbK01KIV00F6=K
05]XG`1NJf80GFYQ05][H@1HIf00EfIO05UYI01HJfL00P1FJFD0601GJVH0EVUU05EUHP1?Ge`0DF5N
051OG017EU<0@E1=04A@C@14CDP0OHMo04I?BP18DD`0<c`g03a5@P0f?c`05QlL09fVY@14CD`0B55@
04]CE00h@C`0=T0h038k=P80;CHa00h0<CXg030i=P0]=S<0;cPg038k>P0a>CX0<cdn03Q2@@0/>3H0
<Cdk02lk>@0V<S40<Cdm02dh>P80<3/m01T0;CPl02Lb=P0P:bl0;3Hh02@^;`0/=c<0:S@/02<]8`0_
>R`09BdP03Dl<00J7aP09BXT01hS7`0P9B4082LP01dW7P0L9Qh07RDN01`S7@0I7a/092TU024U8P0V
:2L09bTX008092HU00H07AlL028T8@0U9b@08bDR01dO700J71T201dO700P01/M6P0I6aP06Q`I01`N
6`0V9R@06QXH01dM6`0L71X05aLE01/K6@0D51803`l=024Q7`0K6aT08B4O00`<2P0F5A<061LE014@
3P0G5Q@06aXH02<R800D4a408b8P01HE4`0K6QP01`H401TH5P0H5a<05A@@01@C3`0E510201LF4P0<
01/J5P0D4`l04A0<01@C3`0A40`05QDB01hM6`0A40h071/I01@C4@0I5A@06A@D0P0H4Q803P0H4140
5`h?01H=3P0A2`X05A4>00T50P0D40d06QHC01TE4P0D40d05A4>014=2P0D40d05a<@0P0C3``04@0D
40d04`l<00`81@070`0081`I01DA3P0?2`P04`l<01HB3`0@30T04`l<00l92@0A2`/0618B00X4100F
41004@`900<04@`800<04@`6018=1`0C3PP00`0C3PX2018=2@03014<200C3PX04@`800804@`80100
3`X601@?2`0=0`806Q0?01<9200<10804`/9018:200<1`@050l<00D1000810405a<@00T50P0?2PH0
5A0<0P0@2`L00`0E40`03PT5010;1`05010;1`H040/800L061<@00h91P0G4Pl02@@1024L6@060@00
4@L6008050X900D04PP701<9200E2`X040H501881`0201D;2P8050X900H05@/:01881`0@1PD04@L6
01<9200E2`X201@:2@0501471P0B20L04`T800l71@0@2PH00P0?2PL01P0@2`P040X:010:2P0?2@T0
3PP:00d72@803PP:01<03`T;01872`0A1PX04@H:01872`0C20`050T=00d21P0D2@d05@X>01X?4`0F
2`l03@D801@@4@0A3@h040/=010:300;1@L04PX=00803PD800X04PP<01872`0D2@d05@d?018<300<
1PH09b0P01T@4@0Q61T030@50P0A1`P0100A1PP04PH801<72@0C20T200l5100301881`0@1PD040H5
00<04`T800H05@/:01H<2`0G3@`04PP701X@3`0M4a8301881`0601@:2@0E2`X04`T801061@0>10<0
40H50P0700002`0C2PD04`T700/1000E2`T03P@300`20@0A1`P03`D600d3100;0P<03`D4008040H5
0P0?1@@0200A1`H03P@300l5100A1`H04PP701471P0@1PD04@L60P0@1PD04@0?1@@040H501471P0F
30/05@/:04Pn?@2RV9L09adL01471P0@1PD02`4101dC4P0L4Q406Q0?01P>3@0<0P405`d<00801`00
00<03PD500L00?ooool04oooool001_ooooo0P0B3@X06@0A30T04Pd:01DA300F4`h06QLA01XG400h
=Bh0:BHM00h;0`0@3@H05Q0@01TC5@0F41803PP901@>3P0_:BT0;RTV01LB3`0V8Ah0Pgij05mJEP0V
8Ad0510>00l;2P0B3Pd00P0A3@`00`0F4Q404@d<01@@3`02014=3003010<2`0=2@P04`d=00804P`<
00<04`d=00l92@0=1`L00P0D3Ph01P0C3@d04P`<018<300B30`040`;014=30804Ph=00/040`;00l;
2P0D40l04@d<010<2`0A3@`04Ph=01@@3`0=2@P03`/:01@@3`02014=308040`;00T05a<B010<2`0=
2@P05A4@018>3@0A3@`040`;00l;2P0A3@`00P0C3`h03@0B3Pd03`/:01@@3`0T81l07ATH00d9200A
3@`0510?014=300=2@P040`;018>3@0A3@`00P0D40l00`0;1`H05Q8A01<?3P02014=30804`l>00`0
4@d<018?3P0B3Pd06QHE051<B`0A3@`03PX9010<2`0D40l04Ph=00l;2P0C3`h201DA4080510?00<0
4Ph=014=300A3@`01@0B3Pl05@0B3Pd05a<B01hJ6P0@30X04`l=01HB3`0@30L05`l<01H=2P0E3@/0
5Q0@01DA4@0A3Ph04`lA01DA4@0G4A406A4?01L?300E3@/05Q0@01@@3`0201TE500401@@3`0I5A@0
510?01DA40805Q8A00`05A4@018A3P0F5A407QlI08R9P`3`l>`0HF9M01`M600H61H05QHD01<C4@0C
4a<201HF5P0802DU9@0C4a<05QHF00X:2P0H61L04a<A01lO7@0D5A0201<D3`07018C3@0D5@l05ALD
028T8@19BdP06adJ00d?300201PJ5`0=01TK600F61D071hK01XL6@0?4@h06b0J01PM5`0F6aD05AXD
01LL5P0H7AL06AhH01/P6P0401`Q6`0=01HM5P0M8al05adI06=YJ@0f>ch041DH01XO8P0N92@07R@R
01`R7P0L8a`07R@N01hS7`0301lT800O01hT800U:bL0<CTd02D^:@0V;bX0:34/01/V800R;BX08bd^
01lY:P0R;Bh0:cLg02@_<@0P;2l09cDh02Lf>@0V=CT09cHk02Xi?P0Y>Cl0:S]202`mA00]?T@0;T14
0312AP0dATT0=dU;03Q:C00eAdP0<dE503E7A`0203A7A@0U03M:B00dAdD0=4M503M9B@0mCe40>Ta>
03]=C`0mCe<0I7Ij03mAE@0kC5@0A5EM045BG00jBeD0@55K04EGH`19FfL0AUQT04MJJ01@Hg40DfId
04UOK@17GF/0EF]i05Q[NP1@Hg40Ef]f05EWLP1@HfX0EFQ_055RJ@18FUh0BeeQ04eOHP1;GEl0DF=S
05EWI`0205=UI@0b05AVIP1NL700L8:205Y/K01GJFT0FF][05=UI@1KJfX0G6a[06AdL`1NKVd0IgMf
06=cLP1RLW40IgMf06IfM@1TM7<0JGUh06moO01/OGL0Kh1i0761O@1`P7d0M8>107R6QP1lQhX0OXV?
09:LY@2[/kd0VJ6]07n8T@1oRX`0QY:@08>?S@27TXl0SIRD08bGT`2;U900R96;08NAR@2;TX/0S9>;
08bCS02CVIX0V9fP09bQY02PYJP0^[o309NLX02MXZH209bQY`0309jSZ@2PY:d0XJF^00<0XZJ_00l0
XZN]0:>VZ`2RYJX0XZJX0::SY@2TYZD0XZBS0:BTXP2ZZZX0Z:V/0:VZ[P2_/;@0[Znc0:^//02_/;@0
0P2_/;D0:02^[k@0[Jjc0:f^/`2][[D0ZZfd0:^^]@2_/[P0ZJba0:>WZP2TZ:X0XZJV09bPX02DVIH0
RXn;0866PP1dNGD0M7Ud07j3OP1jOgL0M7Y_06=[G@1YLV80JgAV06mjJ`1dOW<0MGmf07=nMP1eP7X0
Lgij06agL`1RKVT0GfaU05m/IP1OKFH0GfiW069aJ`1TMFl0HW=]05i^J@1GJVL205MZJ080FFaZ00d0
F6QU051PG@1EIF80BEQD041?BP1BHE`0QY:>04E?B026T8P0DU]F03Y3?P0`>C@0:S<`00809Rl/00H0
>D9103a5A00f?ch0<c/l03M0>`0d?SH202lh<`0B030i=00a>SL0<CXg02`e<P0Z<c80;3Dd030i>@0h
@D<0=d5003Y6A00/>3H0:CDc02di>00b?Sh0<3/m02`g>@0W<S@09C0d0P0T;c<0:P0W<C<0:38c02Td
<00Q:RD0;3H]03Q2=`0U;B80:C0V02DZ8`0W;2H08bPT028W8`0S:R<092/S020W800M91d07B<M020U
8@0U:RH08bPU02L[:P0T:2L07B4P028V9@0P8Ql08B<P028T8@0P8Ql071hK01/M6P0P8Ql07AlL01XL
6@0I6aP07AlL020R7`0[:bT061PF01TI5`0H61H06ATG024Q7`806QXH00@06a/I01HF500L71X06QXH
0P0F5A<03P0K6QP04a8@01dL6P0B4@l061LE01HE4`0E518061LE01@C4@0I61H061LC01DD400D4`l0
5A@@0P0G5Q80<`0F5A404A0<01XI5@0I61@040l;018A3P0J6AL03`h<01/J600D4a407ATH01dH600F
41005@l?01D>3P0G3Pl06A0A01/E500g<c007ATF01/G500;1`H04`l<01DA3P0G4a005Q8?01@@3@0A
3@X04Ph;01<?300B3P/05Q8?01@@3@0?2`P0<BdZ03<_;00Q7AX03`/800d91P0@30T0:2@Q01@>3P0A
2`/04P`<00X51@0N61P04Pd:00l:1P0@2`L04Pd901<>2002018=1`<04Pd901/04@`8010;1`0@2`L0
4`h:010;1`0B3@T04@`800h91@0F4@d04PP701L=300D2PX06Q8@01<;2@0@20H05A0=00d81@0B3P/0
40`900`81@0K5a@04`h:018=2@0@2`L03`X6014<200D3`/01P0@2`L6010;2009014<2@0>2@H050l<
00h9201XHf005Q4@01<9200F30/05@/:00804PP70`0D2PT201<9208050X900T05@/:01@:2@0C2@P0
50X901D;2P0F30/050X901D;2P0B20L00P0C2@P01@0>1P@05Pl<01<>2`0B3@X040/800803PP800<0
3`T900h82P0=1`T00P0>20X05P0?2@/04PL;01462P0A1PX04PL;01<8300D2@d0=b``01462P0>1@L0
6@hB01<8300B2@`030H8010:300?2@/02`D7014;3@0@2P`030H800l62@0B2@`200l62@0:018:300A
30`02@<305UADP0Q61T04@T:01<:2`0B20T04@L801461`804@D700P04@H700h40`0?1@@050X90106
1@0B20L05@/:01<9208050X900D04`T801471P0B20L03`D401061@0201@:2@0I01<9200?1@@04@L6
01881`0@1PD04@L601D;2@1<@T00;2<N00l60P0C2@L04PP601071@0B20L0308101882@0?1@H03P@5
01<:2P0C2@P040H500h40`0A1`H04PP700l5100401061@0301471P0C2@P04@L6008040H501D03`D4
01061@0A1`H02P8101<9200@20L08ALF00l5100B20L050X900h40`0E2`X040H501071P0<0`<05P`;
01481`0A1`H040P701071P0H3Pd05?ooool001_ooooo01/040`;01@@3`0F4Pl020@1018>2`030000
3P/6014=1`0D3`T05A0:01<>200A30P0510A00l:3P0C3a003`/<018>3P0=2@P03PX901XF501<B4D0
l>gZ0:6MVP0^:RL0510?00l;2P0@30/00P0C3`h01@0A3@`03PX900l;2P0@30/04@d<00804Ph=00L0
4@/;00d71`0@2PX0618B01H@400B30`04@/;008040X:01h04P`<01@>3P0E3`l030P701<?3P0:1PD0
5A4@00L30P0H51<0B4A301DA400D40l04Ph=00L30P0@30/04Ph=010<2`0<20L04Ph=01DA400>2PT0
4@d<018>3@0C3`h02`L600T5100B3Pd05Q8A01PD4`0C3`h201@@3`07014=300B3Pd040`;00l;2P0@
30/04Ph=01<?3P03018>3@07010<2`0?2`X05A4@01DA400A3@`04`l>018>3@0201@@3`0C01DA400?
2`X030P700L30P0K61L04Ph=00l;2P0@30/04Ph=010<2`0C3`h03`/:00d9200B3Pd040`;00d9200B
3Pd04`l>010<2`0201<?3P0;00d9200A3@`05a<D00h:2`0G4a@08alP01/G600F4Q404@d<018>3@0C
3``00P0D40d03P0E4@`06A4>00l50`0K4a40>C<c01/H6P0@41804@lD010=3`0B30`0610>01D<2P0:
0P0050h>0`0E4A00;`0D40l04Ph=01dI600>2PT07QXI00l;2P0E4A004a8@01`K5`0E5Q40>c`g05mP
F`0d=C405QHD01/K6@0@40l07QhN00H6200H61X03Ph@01TI6@0E5AD04A4A01`L700<30/08R8P01/K
6@0E5Q404a@?01@E400I6Q@06a`F010B3`0F61D06Q`I014C400G6AH0:R`Y01PJ5`0F61D061XG01XL
6@0F61D04Q@A01LL5P0H7AL06QlI00806AhH02P02Pl901XO6@0M8Q`08bPR01dR700G71H06QlI01PO
600G7AT0:Bl[03Y0@00d>C`041DH01/P8`0O9BD0728P028X900Q:240728L02ld<00D6AD06AhJ01hT
800V;2P082PS02</9`0R:bH08B`V01lZ900N:B<08R`Z02@^;`0S;Bh08bh_02@`<00V<C<09C8d02Hd
=`0Y>3/0:cXn0P0[>Sl03P0_?dD0;Sm602hoAP0bA4T0<49603A6BP0iBdh0?U1B03e?D@0_@D80=4I6
03I8B00dAdD0>4]90P0fBDL06P0lCdd0?4i>03i@DP12E5H0?DmA03mAE@0jC500?4iB04]LI00mCUH0
AUMQ049CG@0oD5X0DF=_04iPK01CIG40@UES04aOK@1:GF/0Bf5_04UOK@1=Hg40DfIe055TLP1AIG00
EVQc0P1AI6/02`19FV40AeUM051RIP1DIVT0Cf5S04mQH@1@HV80DF=S05=UI@1EIfL0EVQX0080EFMW
00<0EVQX05U[J`1KKFd00P1MKF`04`1NKVd0H71_06AdL`1VMWD0H71_06MgMP1^OWd0M8B306UiN01_
Og`0KWmg06amM01cQ7h0LX9o06mnO01kRHX0PhjB07b7SP1oRI800P24S9L01`26SiH0PXj>07n;Q`22
SXX0R9>?09:MU`2KYZ000P21RXD07`1mQgl0S9><08R?R026S8P0TIZJ09:JW029TI<0Xj^^0:jf^@2G
Wj80UijT09JMY@2KXZX0VZ6Y09fT[02TZk<0WZF]0::Y/@2X[kL0WjBZ09fRYP2Z[k<0WJ6S09nSY02V
ZZT0XJ>R0::TX@2^/:l0Y:FX0:RY[@2[[;000P2^[k<07`2g^;`0/;6e0:BUZ@2ZZjl0Z:V[0:Z[[`2[
[K80Y:V_0:FZ/02W[;40YZ^_0::WZP2OY:H0WJ>Q09NMV`2;THd0QXf608>:P`1mPgd0MGYd07QmM`1m
PgX0LGU^07=kKP1mQWT0OhUn06miKP2:UX`0SIR@06ehLP1_NWD00P1`O7P04@1YMG40IG5]06QgM01Z
NGD0I7=^065bK@1RLfd0H75[05IYI01GJVP0E6IV05U[J`1GJVP0Cf9P05EUI01BHUl0B5QE0080AUE@
05/0BeYC04=@B@0f@3P0>D<k03a5@00nAd80;cPc02Pa;P0[=340:S<`02`e=00U;Rd0:34`02/c=00/
=C00;3H^02Xc;P0`>C@0=Slj02`e<P0Z<c00;CHc02`e=00[=3<0<S/k038j?00T;Rd0<3Xi03M1@00b
?3/0:cDe02Tc=00V<380;SPj02/e=`0Z<cP082T^02/d>@0P:R`08R`/02@_:`0V;bX092hV024[8P0U
;2@09R`U020U7`0N8ad092TT02P]:@0O91h08RLQ02<X8P0G71H07B8M024V8P0R9b<09BXW024W9@0J
81h0728P01HJ6@0H6QL0:2XW01LI5P0P8Ql0Gf5N01@F4`0K7AX09RPU01<E4P0N81d04aDB02PZ9`0L
71X07AdK01PH5P0C4a405aLE01dM6`0J6QP05QHD01LG5@0J6QP061PF01DE4`0G5Q@061LE01LF500F
5A<05aHD008061LE03d051<A01DD4P0J6AL061LE01DD4P0F5A4061LC01DD400F5A405A@@01HE4@0J
6AD06APD01HE4@0C4Ph04Q4=01<B3`0V9B<040l=01PG5@0S8R00L6a[01D@3`0D3Ph04`d=01/C500G
3Pl05@`=01LA400:1P<05Q8?01TE4P0>2PL061@A014=2P0M6AH04Ph;01@@3@0>2PL0510=01<?300B
3P/04`l<01TE4P0D40d040`901DA3P0<20D05A4>01@@3@0A3@X03`/801H@400E3`l02PD501PB4P0@
2PX05Q4>01<>2P0B3@T04`h:00805A0:00T04Pd7018=2@0C3PX04@`800h91@0@2`L03PT500l:1P0@
2`L00P0B3@T05P0@2`L03@P401dC4P0U6aX05P`;01491`0D30X05Ph<014<2@0@2`P01`<001<?300L
61D0al?0055<B00C3PX05A0<00d8100<1`@050l;014<200>2@H200d81008014<200E40`04`h;00`7
1P0N6AH0100001<>2`0k=S<600l:1`0601471P0B20L04`T801<9200B20L04@L60P0C2@P201881`80
4@L600H04`T801881`0A1`H04`T801D;2P0F30/201<920804PP701H04@L601081P0G4@d03PT600d8
1@0A30T03PP800X4100>20P03PP:00T31@0=20T06aDG00`6200=0PH03`@801872`0G310060dA01L<
400C20`04@H:0`0@1@T04`0?1@T050/>01<:3@0?1PT06Q4D01LA4`0A2`d03@L900`6200D3Q004@/=
00d72@0<1PL05@l?01@>3P0C2``040L800T00@0A20T00P0B20T0100A1PP050P:00/00@0E2PX20106
1@0901471P0B20L04PP700l5100@1PD04PP701061@0A1`H04PP700H040H500`06a4@00L0000C2@P0
5P`;01061@0W7A`0e/c:06]RG@0;0`4050X800l50`0;0P4201471P@04@L801@06a4@01@:2@0<0P40
4@L601D;2P0B20L040H500l5100>10<03`D401881`0F30/03@<201H<2`0C2@P05P`;00l5100A1`H0
4`T801881`804@L600@04PP701<9200>10<040H50P0B20L0100@1PD03P@300l5100A1`H201<92003
01471P0?1@Cooooo01?ooooo000Kooooo`0P018>3@0A3@`04Ph=00/71P0D40d06QHC00l;200C3`X0
5A0:01HA3@0D3`T04Pd9010<3@0F4AD03`X>00h:2`0A3@h04@d<00T5100J5Q@08QhK08=oO01KEe@0
3@T6014=300@30/04@d<01@@3`0A3@`03PX9018>3@0A3@`2010<2`803PX900@04`d=014;2`0A2`/0
4`d=0P0D3Ph301LA4@0N01H@400C3@d04P`<01<?3P0H51<03PX901<?3P060P404`l>01HB4@030000
2@D401DA400B3Pd061@C01<?3P0B3Pd03@T8018>3@0D40l04Ph=01<?3P0A3@`09R8Q02LS8P0C3`h0
3@T8018>3@0C3`h040`;0P0C3`h00`0A3@`04Ph=010<2`02010<2`03018>3@0C3`h04`l>0080510?
00L04`l>018>3@0D40l03`/:00`81`0?2`X03PX9008040`;03403`/:014=300K5aH081`K03lk>P0B
3Pd03`/:010<2`0B3Pd040`;01<?3P0D40l03@T801LC4P0D40l04@d<018>3@0E4A003`/:010<2`0D
40l04@d<01<?3P0H51D040`=01HB4`0O6a`061@E01<?3P0D40l04`l>018>2`0A3@X04`l<01HB3P0A
2@H04`T7014:2@0J5QL04a8F01TJ7P0?41@04a8F01dI6P0E3`l040L502<K600F4@h05A4@00804`l>
04`0510?01DA400B3Pd0510?01/G5P0:1PD061@C01<B400I61@03@h901hO6P0`<B`071`I010@3P0?
3`d0410?01@D500@41805aLI02@T9P1@D5004a<C020P800G5aL09bLV0041000I6AL05QLB01DF4@0F
5a8061TC01TJ500I6aP05QPE01TK600J71T0;Bl/04=5@P0H6QL05QPE01LI5P0I6aP05QPE01<E4P0H
7AL07b@N02DZ900Y;RP0:c0Z01dR700K81X07R<M02<X8P0P9Al07B8L024V800mA3d01`d902@Z9P0K
8B4041DH028W:P0D6A`051XJ01hT8P0E6aL07bHO07=iL`13B4@07R<O01hT800I7a/0BU1<01dV8@0P
:B@07bXT0P0N:B<03P0M:2808R`Z02H`<@0U;c009C0a02Hb<P0X<cD09S8e02Dc=P0W=ST0:CPl02Xi
?P0[>Sl0;Si40P0/?D@01`0`@TL0;T140394B00dATT0=TQ:03M9B`0a@d@00P0iBd/02@0aA480=TU7
03A7A@0aA480=4M503=5A@0eAdT0?DmA03U;C@0203i@E003049DF01WN800C5eU0080@55K00h0AeQR
059TL00oDEd0C5iZ04MJJ01;GV`0DVEc04AJJ019Gfd0Bf5_051SLP1@Hg40D6A_05=UL080D6=Z0140
B5UP04IHG01>H6@0D69U051RI01@HV80DF=S059TI01EIfL0EVQX05AVIP1EIfL0EfUY05U[J`1LKVh0
GW1`065aL003069bL@1f061`K`1NKVd0I7Ac06UiN01[NgX0L81o06QhM`1`P7d0KWmg06n0M`1bPgd0
LH5n07:1P@1iQhX0OXV?07b7SP23SIH0Qi2I086:T`1mQXd0Oh^;07n;Q`22SXX0Q8n;08RCS@2>VI<0
SIJA08><Q`20RH@0PhZ408:8Q02AUi<0SYNG09RPXP2CVid0Ti^N09FMX02@V9/0UIbR09FLY02IX:P0
V9nW09ZQZ@2QZ;00WjJ^09jU[@2RZK40WjBZ0:N//02g_<00_<3209jRX`2OXj80YjVX0:BVX`2VZ:L0
YZNZ0:NX[02YZZh0[:fa0:j_/`2h^Kd0/K:f0:BUZ@2RXjD0VibN09bMW`2TZJ`0YZ^a0:N//P2W[;40
XjR/0:2UZ02FW9/0SiFA08bBSP24Rh@0QHb408J=Q@1jP7P0L7E^092ESP2MXiX0LGU^06ifJ`1dOW<0
K7I]07V5N`3CgmH0]/6i07AoN@1^NWD0L7ah075mN@1]NGH0JGEc06UhM@1YMgH0Hg=`061`K@1MKFX0
FV]U05=VH@1GJVP0DfEU05EWI`1DIVH0CF1N059RH@1>GU/0CemL049AC00a@3T0<3lh03M4?@12C4@0
=T0h030i=080=d0k01T09c0]01lX9@0Y<Rl0>dA303M0?`0`>CP09Rh_02hg<P0^>300;CHa03@m>00k
A3l0=3dj02Xc<00]=S<0;3Dd02/d<`0a>CX0;cLi02@^;@0Z=3<0;SPg02dg=P0Z=3@0:S@e0080:38d
03H092h`02Pa=P0Q:Rl0:38d01lY:`0T;Rh09S0_02@]:P0P:B@07bTQ02D/9@0X;RP09b`V02DZ900R
9b807R<M02H[900T:B<0724K018G4@0N8ah06QlK01`Q7@0F6aP08bTW014G5@0P9R@06b4O02HZ9P0G
6AH05ALD01hP7@12A4409RPU01TK600W:BH05ALD01hP7@0E5a@051HC01HF500J6QP06a/I01PH5P0G
5aD061PF01HF500B4Q004a<A01DE4`0C4a404A4?01PG5@0G5Q@201DD4P0>01PG5@0K6QP05aHD01DD
4P0F5A<05aHD01HE4`0E51805A@@01LF4P0D4`l05QDA01DD400D4`l501DD400702@S801/JfT04a8@
00h=2`0A40h09R8Q018=300201H@400T01PA4@0F3@h060l@01H@3`0@30T04Ph;00h:1`0D40d061@A
01DA3P0;1`@08alL00/7100Q7AX01@4001`H5@0C3``040`9018>2`0C3``05a<@01dI5P0?2`P02@D2
00/7100B3P/05a<@00@0000V82007QPH010:2P0400004@`900/60P0=20@040/70P0A30H01P0@2`D0
3@P400h91@0B3@T04@`800l:1P804Pd900<04@`8010;1`0?2PH00P0?2PH00`0>10<06Q0?01H<2`02
01H>300=018:200E40d03`X801TE4P0D40d0920M0:fYYP0l=c<040/701D@300?2PH03@P4010;1`02
01@?2`8040/70P0C3PX01P0@2`P04@`900`7100g<Rl0Ddi;06eXI@H040/800H04@L601881`0C2@P0
4`T801881`0A1`H201<920804PP70P0A1`H301881`0401<9200D2PT05@/:01<920804PP70P0A1`H0
4P0@20H050d:00h91P0>2@H040/800l92@0>20P040X:00`6200:10H03PP:01XD5P0@2P`04@H:0105
2@0B1`/05P/?01D:3P804`P<00D04@H:01052@0@1@T040D901062@0201482`0@01P?4P0/8bH0:R@V
01LA4`0?2@/030H800/51`0>20X03@L9014;300=1`L0100002DN7P0i<3407aHG00h51P804PP900@0
5@X;01451`0A1@L03P<40P0@1PD0100A1`H04PP701881`0@1PD201471P0400h40`0@1PD03`D400l5
10D04PP700X0308101@:2@0F30/0308100l5100>10<081HD0189100F3@P07Q@B0P0A1`D201471P@0
4@L800H05`d<01881`0=0`8040H501881`0@1PD200h40`0:01061@0C2@P05P`;01X@3`0C2@P060h=
01H<2`0H3Pd050X901D;2P804@L60P0@1PD201471PL040H500D04@L601881`0B20L04@L601061@0D
ooooo`006oooool07P0A3a403P`>00P61`0C4A<040d=01HB4@0>20T04@/:018=2P0D30/050`9014<
2@0<20T09R@W00`:3@0?3A003P`>01LE5P0=30X04A0>00X91`0J6AH05QDC01DD400>2PT040`;018>
3@0C3`h03`/:00`81`H040`;00<04@/;01<=3@0B30`00P0@2PX04`0A2`/050h>01LA4@0I4a<0618B
01D?3`0C3@d0510?01HB4@0A3@`04Ph=014=300B3Pd07a/J02/W9P0I5A@03`/:00d9200?2`X00P0B
3Pd00`0A3@`04Ph=014=300200h:2@0400d9200M6AP07QXI014=3080510?00@03`/:010<2`0E4A00
510?1`0A3@`00`0@30/04Ph=01<?3P02018>3@8061@C00D04`l>01@@3`0A3@`04@d<01@@3`03018>
3@0A00T5100G4a804`l>010<2`0A3@`04Ph=010<2`0C3`h07ATH00`81`0D40l02`L600h:2@0C3`h0
5A4@014=300@30/00P0C3`h02@0E4A005a<D010<3@0B3Pl05a<D018>3`0@30/05A4@01@@3`02014=
2P0@01<?300G4`h05Pl901`D400D3Pd05A@E00lB5@0>51P02@dB00d?4P0>3@d04@`<01H>300F3P/0
5Q4>01@@3`804Ph=01`05A4@01LC4P091@@06aLF01HB4@0O6aX06aLF01@C4@0F5A404A8=01LH4`0>
3P`05aLE01HF500G5aL04a<D014A4`0];Bl06ATK01LG6@0E5AD061PH01LG5`0A4A404a<B018B400F
5Q@05aPC0P0H6A@02`0H6A<05aPB018D4@0D5Q<06Q`I01HH5@0C5A806A/H01XL6@0G6AH05QPE00<0
61XG00H051TC01XO6@0P9Al08bPR02P]9`0L8A/301dR700E01XO6@0K81X07R<M01`S700U:bL07R@P
01XP800I7R406QlR01/P8`0I7al08BLU020V8P0O9Ql0>D0k020V900Z<2h07bDS02D[:@1BFeP08R`Y
00807bXV0P0P;2P0500Q;BT08bh/02@^;`0T;Rl09C0`02Hb<P0W<S@09S8e02Dc=P0V=CP0:3Lk02Xi
?P0]?440;Si402/l@`0/?D@0;T1502i0A00a@dL0<dE80P0dATP0100dATL0?4i>03M9B@0fBDL203Y=
B`0K03E8AP0fBDL0>de=04=EE`1?HF<0@UAF03e?D`0nD5@0>deA04=DG00oD5P0AeQR04IGH@1;G6H0
B5YV055SK`17FFD0Bei/04AGI@18FfT0CfEc04aRL01;HFl0CF1_051SL@1AIG00Cf5/0080B5]R00D0
AeQO04UKG`1=Gf<0CV1S055SI@02059TI00705=UI@1FJ6P0F6YZ05=UI@1FJ6P0FVa/05a^KP0205i`
L00705i^K@1QLG00Hg=b06=cLP1PL6l0GFe/065aL00206EeM02206]kNP1YNGP0LX9o06enN01cQ7h0
Kh1k06moO@1gQXH0MH>7082:TP24SYL0SYRP08jGW`20RHl0Mh2307V5P`1nRXH0R9B@08JAS@22S8X0
Q8n;08ZCT02AVYP0VZ>Q096GU@1mPh80S9:A08fEU`2?UiX0TYZM08nGVP2>UI/0U9^Q09NNYP2HWjL0
VJ2X09NNZ02IX:X0WJB^09ZSZP2LXj/0X:N_09^RZ02QYZX0ZZnc0:Z`/@2FVY/0UYZI09^OWP2NXil0
XjNV0:6UZ@2OXZL0XJBY0:FY[02VZZd0YZZ[09fQXP2EVIX0TYJF08jBT@2DV9L0X:FX0:>W/02SZ:h0
WZ>X09JKW`2BUiX0T9JD08jDT028SXT0O8=j07Z2M`1kPgP0NH5f06eeJP2:TXL0WZFL07V0N01cOG@0
M7ie06mjLP1hPg/0ZKF]08fJT`1WM6d0KGUd06ijMP1]NGL0K7Ui06YhN@1YMgL0IgIg06EeM@1OLG00
EfYW05AWH`1EJ6<0G6i^05QZK01CIFL0DVAT055SH`1@H5l0BEUF04]KE`0oCTP0BUUB03m?AP1EHUT0
GFMO041:@P0lAD00;CHa02/d;`0V;b`0;cPe02`e<P0Z<c809c0_02Tb<@0^=cL0;SLb02`f;P0X<B`0
;3D`030i=00]=S<0:S<`02df<`80;CHe00<0<CTj02hf>00Y<c800P0V<2l09P0Z=3<0;3Hf02Xd=@0Q
:bd09S0b02Xd=P0a>Sl08b`a020Z;00L9RP08B/[02@^;@0T;B`08BXX01lX900Z<2d092TU024V8P0P
9B407b@O01hS7@0Z;BH07R4K01hP6`0M7aX082<O014F4P0N9200728O01TO7@1AFUL0<3Tf02hd<P0M
81d04A<@01lQ7P0K7AX07b4N0P0H6QL0200U9b@06A/H01`N6`0S9B805QPE028R800J6QP061PF0P0K
6aT201TI5`<05aLE00T05QHD01DE4`0I61H05aHD01DD4P0D4a4061LE01`K6@0E51800P0H5aD201DD
4P0401HE4`0C4Ph05QDA01@C3`805aHB0P0D4`l05`0C4Ph051<?01@C3`0E51009bHS06e/JP0J6AL0
6APF01DD4P0C3`h061<B01PB4P0I4a<05@h>01P?400I414061<A01dI5P0E4@h061@A01<?300=2@H0
5a<@008030T700`06ADB00P40P0X92403P/800h:1`0?2`P05Q8?01@@3@0B3P/03@T601<?300D40d2
014=2P0801@@3@0C3@d0<B/[01PB4P0B30`050h>014<2@0A30P201<>2P0B00d80P0<1`404Pd701@?
2`0>2@D04Pd901@?2`0=20@04Pd901<>2P0B3@T040/700h91@0?2PH04@`800`30`0F30/04PP70`0E
3@/0600C3P/03@P500l;200=2@L04`l<01@@3`0H4`l03`X601<>2P0@2`L04Pd900`70`0B3@T05A0<
00d8100<1`<04`h:00h91@0@2`P04@d:00l:200?2`T0D4]801LB3`H04@`900H04@L601881`0C2@P0
4`T801881`0A1`H201<920804PP70P0A1`H01@0B20L04`T801@:2@0D2PT04`T800<04PP70P0A1`H0
5P0@1PD03`L500l81@0@2`P03`X700`7100>20P04@/;010:2P0;1@L03`T;010:300K5AL081XL01@9
3@0B1`/04`P<01@93@0B1`/040D901<8300A1PX201052@0J01462P0D2@d050T=01052@0C2@d081LJ
01/B5@0B2`d08A/M01XD5P0?2``0510A010<3@0A30d04@/;00h8200F3Pl040L800/20`0C2@X05P`=
00d3100D2@X04@D7034U9`0A1PH201061@0301471P0B20L04PP700804PP700@040H501<9200I3`h0
5P`;1@0A1`H03@0B20L040L701@:2@0B2@P05Ph=018:2@0B20H050X801H=200>1@803@@30189200?
1P@00P0A1`H40147200:00l5100A1`H04PP701061@0?1@@040H500h40`0?1@@04@L601<9208050X9
00L04`T801061@0@1PD03P@301<9200B20L040H500@04@L600<040H501881`0@1PD00P0?1@@0100@
1PD04PP701471P0A1`H201881`804@L65?ooool001_ooooo01P04a8G02<R9`0<30h040hC010<400I
5AH03@L;00l72P0A20T04@P;01882@0A20T07aXN03/i?P0G5AX05A<F00X82P0@3Pl02`T:018@400C
4Q0020L6014@3P0C4Q0200l;2P803PX900H03`/:010<2`0>2PT03`/:010<2`0A3@`2018>3@0600l9
2@0A2`/05Q0@01/E5@0D3Ph03PP80`0A2`/0300C3@d050h>01@>3P0E4A004`l>014=300:1PD0510?
00P40`0@30/05a<B00d920803`/:00@04Ph=00h:2@0?2`X04@d<0P0@30/0200?2`X04`l>010<2`0=
2@P02`L6018>3@0S7ah061@C0P0@30/00`0B3Pd04@d<010<2`05014=300300l;2P0>2PT03`/:00<0
4@d<00D0510?018>3@0?2`X04@d<00h:2@0200d9200>00`81`0C3`h05Q8A014=300E4A00510?010<
2`0A3@`04Ph=00l;2P0B3Pd06aLF00l;2P0G4a82014=300401@@3`0B3Pd0510?01@@3`803PX900d0
4`l>010<3@0=2@X03`/<018>3`0A3@h04`l>010<2`0A3@`0510=01DA3P0D40d04a0;00803PT302T0
40h;018C5@052`l07bP]0499D@0O9BX05AHH01LF500E4@`061<?010<2@0C3`h05Q8A01LC4P0E4A00
4`l>01DA400G4a80510?04M3@P0J5QD05A@B00l>300B4Q006QXH00l?3@0M7A`05ADE01PH600L71d0
5QHH09nNX`1?CU<0410B01/K6`0@41004Q8B0000000G5aH051@B01PH5P0201DF4@0;01HG4P0I6Q@0
6Q/E01XL6@0C5A8051HC01HH5@0K7AX07b4N01TK600H6QL00P0G6AH0GP0I6aP06adJ01PM5`0H7AL0
5a`F01DJ500K81X04QLA01PM5`0K81X0724K028W8@0[<2X0;c@^01lV7`0F71P04QPD01XP800@5AP0
6b0S01DJ7@0R:2P06R0N01XP700M91d07bHQ028X9P0I7ad09Rd[01lX9@0<5A8082XV01lZ9P0O:bL0
8RhZ02@`;00U<Bd092l]028/;@0S;Bh09C0a02Hb<P0W<S@09c@f02Pf>@0Y>3/0:STm02`k@00`?d@0
;cm502dnA@0_@4L0;d560353A`0cADT0>4Y=03U;C@0eAdT0=4I703U;B`0gBDT0>di<03U<BP0eB4H0
<DA203A7A@0oDE40=TQ:045CE@0gBD/0=TQ<03]=D@0lCU80>4UA03]<E017F680@U=M04YKI@1AHfl0
Cf5]04QJIP1EJ7H0A5MU04EHIP1>I780D6Id04eSL@1>HG00D6=a051TK`1<GVT0BeiU04ULH`1=GVD2
059TJ00k059TI`1@HV@0D69R055SH`1BI6@0EFMW05IXJ01EIfL0EfUY05Y/K01KKFd0FVa/05QZJP1K
JfX0G6a[05e]K01NKVd0HG5`06=cLP1UMG@0KWim06alN`1bPX40Kgmn07:2P@1/O7T0LX9o06emO01_
Ogl0NHN<07B1R@1nR940P8ZB08F@UP22Ri00MX22079lN`1iQH<0P8b:08^GU@29Ti80PH^<086;RP2>
UYL0SYJH08VAT`2>TiH0RHjA08fBU@2;U9H0T9ZL08jHVP2=UY/0SYNL08bEVP2AVZ40TibU09:KY02A
VZ<00P2BVj@0H02FWjH0VZ>Z09^TZ`2FWJ<0TYZM09FMX02IWj00W::R09VOW@2@U9<0U9VE09jRX@2M
X:@0W9nT0:2SZ02UZJ`0X:BU09^OX02FVYT0T9BC08^?SP27S8P0Ri2<09ZNXP2QZ;00XJR^09ZQYP2@
V9X0S9BF08VBS`25SXT0OXR0079lLP1bOFl0Lgi`07AnL01eOG00MGeb071iK`1_NG00LG]c06UcK01d
OgT0MhAm06QeK`1WLfl0JGEa06]hM01VMG00I7=`06AbLP1ULgH0IGAg069aM@1QL7<0Ffe^05AWI@1C
IV80EfaV05MYJ`1GJFd0D69T04eOG`1@HV80Be]J04IFD`1:FeD0AEA=03i>A00b@SP0/l2g0>_ek@1o
RH40=Slj02hg<P0a>SD0<c`i02lh=@0Z<c00:34`03@m?00f?ch0;CDf038k=P0]=bl0:S<^02`e<00]
=S40;3Db02Tb;`0/=C80;CHe02hg=P0d?3d0<SXl02df=@809c0_03<0;3Dd02/c=00R:R`07RHY02Ta
=00]=CP0;SDk020W;@0T;2l08bd^01hX9`0O:BP09Bh]02</:`0J8b00:S0^024V900Q9B@08bPT02L/
9`0`=Bl0FEaE02HW8@0P8A`071hI01TL600S:2@07B<O02<Z9`16Cd`0bmCA06]eLP0E7Q/07R8N02@V
8`0l?S/05ALD02X/:@0M7a`0<C<`02T[:00N81d07AlL01/M6P0N81d0:BTW01TI5`0E5A<06QXH01`L
6P0J6QP00`0G5aD0100F5Q@05ADC01DE4`0F5A<201TH5P0401LF500F5A<05aHD01HE4`806aXH0P0G
5Q@01P0H5aD04Q4=01DD400C4Ph05aHB01HE4@H04a8>00h04A0=014@3P0>3@/06aXH01HE4`0^:RT0
71LG01H@400D3Ph05Ph?01XA4P0F3@h02@@401<?30804Ph;01/03`/800`81@0I5A805a<@01TE4P0@
3@/04Ph;00<0000A3@X04`l<01TE4P0S7a`06aLD00l;200H51405Q8?00L30@0C3``04Ph;00`81@04
00002@<301<=3@0I4a<03`T900h91`0>2@D00P0@2`L02`0?2P@05A0:02HQ6`0Q71P04`h:00`70`0B
3@T04@`8018=2@0>2@D03`X600<04@`801L040/701D;2P0I3`h04@L6018:200@20H050`:010;200D
40d06QHC01hJ5`060P40;2PU00T4000C3PX03PT5010;1`0B3@T03PT5010;1`0A30P03PT500l:1P02
01<>2P0601XE4P0;1P<07QTF01D@3@0<20H01P401P0A30T01P0A1`H04PP701<9200C2@P04PP70147
1P804`T80P0B20L301471P0501<9200D2PT04`T801471P0@1PD00P0B20L201471P0E01061@0?1`D0
4P/801HA3P0D3``03@P500h8200B30`03PP800l92`0B30h02P@600d72@0M5aT04PL;01462P0B1`/0
50T=01872`0@1@T04PL;008040D901/04@H:01872`0B1PX04`L;01872`0A1PX050T=01<:3@0>1PT0
71HH01<?400?2``02`T:00H41@0H4a@0208200D0000U7Ah07QDF00l61`0C2P/060h?00X00@0B1`P0
4@D703``<P0C20T00P0@1PD02`0A1`H04PP701881`0B20L04@L601061@0D2PT07A<B01X@3`0A1`H0
3`D4008040H50P0A1`H0300D2PT03P@301061@0E2`X03@<201L=2`07000030<00189100B20H04@L5
01881P804@L6100A1`P02@0=0`804@L601H<2`0B20L03`D401881`0?1@@040H501471P0201061@09
00l5100C2@P0308101<:2@0800004PP700l5100A1`H04PP700804`T800@04PP701471P0?1@@040H5
0P0A1`H00`0@1PD03`D401471P0501471QCooooo000Kooooo`0800001@0O7R@07QdR01<A5P0810X0
3PT=010:3P0A2Ph201<:3@0>01D;3P0D2`h040/?02@R9`0@3Q<040hA00`:300@3Pl03`d>00`:2P0P
7ad051<A02@S8@0F5A<2010<2`0300h:2@0=2@P03`/:00804Ph=00<04@d<010<2`0@30/00P0>2PT0
300B30`04`d=01TC4`0P6QX0618B010:2P0F41004`d=014;2`0@2PX04@/;018<30802`L600X04@d<
00/71P0T81l040`;01@@3`050@002@D401@@3`0:1PD04`l>0P0?2`X02`0A3@`03`/:00l;2P0B3Pd0
4`l>00`81`0A3@`04`l>014=300L61L05A4@00803`/:00<03PX900d9200?2`X00P0A3@`01@0B3Pd0
4@d<014=300@30/04@d<00@04Ph=00<040`;00X61@0:1PD00`0@30/201<?3P0500h:2@0810<030P7
00l;2P0D40l00P0A3@`02P0B3Pd03`/:014=300<20L03`/:01HB4@0I5A@04Ph=014=300@30/201DA
4003010<2`0A3@`04Ph=00803PX;03/040`=018>3`0C3a00510?00l;2P0A3@`05A4>01LC400E4@h0
4Pl:01<>200E4P/05QHC00X>3`0>5QX0D5]Q0>7Zl@18D5@03a<D01TI5`0<2PD07aXF00h:1`0C3`h0
61@C01TE500F4Q404Ph=01/G5P0C3`h05a<B04Q4@`0H51<05A@B01<B400A4@l04Q8@00h>300F5QD0
4Q8B00410@0H61T08R8T030_=00T8bP03Ph@00/;3@0F5QH03@d=02DU9@0E5A@06QXH01LG5@0E5Q40
51D@01HG4P0J6aD06a`F014C4002018D4@0901<E4P0D5Q<05QPE01PJ5`0I6aP061XG01LI5P0I6aP0
6adJ00806AhH00@05a`F01@I4`0L8A/051TC0P0N8ad0=P0K81X07B8L02@Y8`0V:bD04aXC02<Y9@0O
9B407bDU02`a=01CF5/0;C8e00dC4`0N928082HR01/R6`0M91l06b4O01hT8P0@61D08R/X01lX9@0N
:2D07BPT01hZ9P0P;2P08bl[02@`;00T;bh09Bl`02La<P0Z=CD0:SHf02/f>00Z=cT0:cTl02/j?@0/
>cl0;Ca1030oA00^?T@0;d170352B@0`@TL0<dE903E7B`0gBD`0=dU;03A6B00dATL0>D];03e?C`12
EE<0>di<03A7A@80<TE302H0>Ta<03A6B00jC4h0=DM903U;C`0kCE40@E=G03m@F00jBe<0BU]U05=T
KP1BHfd0?U1L04]MJ@1EIg<0DFAb045DHP1@Hg40DFMe051VM01>I780Cf9a04mRL01>HVd0BeeX04aO
IP19G6<0C5eT051RIP1?HFD0CV1S051RI01@HV80DF=S059TI01EIfL0EVQX05QZJP@0FF][00/0F6YZ
05m_KP1NKVd0G6a[05e]K01OKfh0HG5`06IfM@1`P7l0JWYi06inO@0206UiN00P06inN`1_Ogd0Kgmo
07>2Q@1jR8l0NHJ>086;U01nRI00OXV=07^5Q`1eOgl0N8:107j:R021SH/0R9BB08>=SP1lQXL0OXR9
08ZBU02<U9H0Ph^>08^@U027S900Q8b?08><S`2BW9h0SiVK08^DV@2?V9d0T9VN09BMY02HXJX209FN
Y`1<09JOZ02EWZL0VJ:Y09JOYP2DWJ@0U9^Q09NOXP2JXZD0VInP096GU`2?UI<0U9RG09ZOV`2MXJ00
WJ2T09fPY@2RYJX0Yj^^09jRX`2EVIT0Si>B08fAT02<THd0SI:>08nDT02CVY/0VJ2X09ZQY`2CVil0
RI6C08J>T025SXX0PXb407^5O01/MVX0J7=U06IaH@1QJe`0MGe`07b4N@1WL6H0H6YQ06=]I@1XLf`0
JWE_06]hL@1]NG@0J7A`06A`K01RKf/0HW5/069`L01QKg40HFmb065`M@1NKG80FVU^05EWJ01AHf<0
D6=O05=XH`1EIfT0G6ib05EWJ@1?HF<0EFMW04iNG012DTl0?Di804=BB`13DdT0?De30;W6_03Dg]H0
Lgee02df<@80:c@_00@0<c`i02Pa;P0U;R/0:34`0P0j@d802@0/=3D0;CHa02Tc:`0[=2l0<3Td02lh
<`0a>SL0:S<`02df<`0202`e=00k03<k?00c>cd0:C8a02H_;P0W<2l0:S<b02H_;`0M9BL092`_02L_
<P0Q:B`082L]01XQ9`0Z<SD0:C<d024[:P0N:2L08b`[028[:P0J8b807B<S01`Q800V:RT09R/W02DZ
9@0_=2h0@T<m01dN6@0Y:RD09RPS01XM6@0P9B40>Clk01@K600@6AH0<S/h02Xd<00H8Ah051LD02la
;P1OHEh08bDR01dO700B51407AlL018D4@0=3``0=CLd01HH5@0D5Q<06a/I01LG5@0I6AL07QhL01XJ
600E5A<06ATG01XJ600I6AL00P0G5aD01@0H61H05A@B01TH5P0J6AL061LE00805QDC03/05aHD01/J
600L6aT06QTG01PG5@0G5Q@04Q4=01DD400C4Ph05QDA01DD400A40`040l;014@300C4Ph05A@@01HE
4@0F5A806aXH01@C4@0A40h02@P600T5100E410050h>018<300H41406A0A01P?400O6AP0<Rh[02PT
8@0>2PL06ADB01PD4@0D40d00`0001TE4P0F4Pl06ADB051<B@0L61D04Ph;01<?300H51404`l<00l;
20091@8061@A01<?300F4Pl06ADB05=?C00o>CT05a4A018<300H4Q804@/;014<2@0201@?2`08010;
1`0=20804Pd701lJ500N6AD05Q4=00`70`0@2`L201D@300E00d8100>2@D04Pd901<>2P0A30P03`X6
01471P0F30/050X901H>300@20H03`L500@0000I51401`<001HB3`0=2@L040`900/60P0E40`02`H2
00<04@`80P0;1P802P0E40`05Q4=00h91@0@2`L020<001PC400400003`X701@?30091046010;2006
01471P0B20L04`T801<9200B20L04@L60P0C2@P201881`804@L6100B20L201061@804`T80P0B20L0
4`0A1`H040P601H?300J5A8061<@014<2@0A2`/050h>00l92@0A2`d040X<00/51`0400003PP:0105
2@0?10P04@H:01@93@0C20`00P0A1PX201052@0K01462P0B1`/04PL;01@8300E2Ph04`P<01462P0B
2@`03@H8018<3P0:1PL03@X;00H41@0H5QL0FEEE03H`<00D3Ph081TI01<:2`0800004PP901@:2`0?
1@H05@X<01041P0U6A/03P<3008040H500<04@L601881`0B20L00P0B20L01P0@1PD04@L601D;2P0B
20L03P@301471P804PP700h04`T801@:2@0@1PD02`4001L=300F30/04@L600X10@0H3P`04PT400d4
000800001`0000l510804@L6100A1`P0500>10<04@L601D;2P0C2@P04@L601<9200?1@@040H50147
1P0B20L04`T801@:2@0@1PD02P0001X@3`07000040H500`20@0A1`H04`T80P0D2PT0100C2@P04@L6
00h40`0@1PD201881`0401061@0>10<04PP701471P8040H500<04@L601881oooool04oooool001_o
oooo00P0MWAm02<Q:@0E4aT05Q<I018>5@0D3a@04@X@014:3`804PT>00l050/@01D<4@0A31803``A
00d;3`0;20/03``?00d;3P0<2@X0518C00X82@1=BdX04@h=00`:200?2`X00P0C3`h00`0@30/03`/:
010<2`06010<2`0701<=3@0D3Ph050h>01D?3`0C3@d04P`<010:2P02018<300D01<=3@0@2PX03`T9
014<2`0@2`/06A@D014=300c;Rh05Q8A02@P7`1<B4L04`l>00l;2P0L61L0510?01LC4P0D40l04`l>
00d9200>2PT2014=300@00d9200A3@`03PX900P40`0C3`h04Ph=014=300C3`h03PX900l;2P0C3`h0
40`;018>3@0C3`h04Ph=010<2`@04@d<010040`;00l;2P0A3@`040`;00l;2P0D40l04Ph=014=300@
30/05a<A018>3@0:1PD06QHD01@@3`0E4A004@d;0P0A3@`02@0>2PP04@d<01HB4@0T81l03`/:01PD
4`0D40l09b<R01<?3P02018>3@0;01`H5`0S7ah05Q8A010<3@0C3a005A4B01@@4@0C3a004`l>014=
300B3Pd00`0D40d0=00D4@`04a0:01dJ500I6AH041@D010H6`0Z=SX0OXN<02P`<`0730/04Q<A010>
2@0C40/040`:01<?3P0E4A005Q8A01LB4@0F4A0050l?01<?3P0N6QT06aLF01HC4`0F51@04Q4?01@D
4P0A4@l05aLG00h>3P0H61P071`M01@D5@0E5AL03`hB03Dd>00=3@l04a<D01hN7P0F5QH0OGem030`
;`0D51805ADC01LH4`0H6A@06AXE01TJ500H6A@05aTF01`N6`0J71T301DG500301LI5P0K7AX06adJ
00806A/H00L06adJ01HJ500L8A/07B8L01PM5`0K81X04QLA00807b@N0P0H7AL08`0L8A/06b0J02he
;P0O9B00;C<_01XP7`0L8B<0HFIX03<h>P0H7Qh06AlM01lU8@0O9B008RPT03@j>@1EGU`06b@R02H_
;@0`>SP07bTW01l[:00P;2T08bl/02@`;@0U<Bh09C0_02H`<@0X<S<0:cHg02`g>00/=cT0:SLj02/i
?00]?3l0;Ca00080;3]00340;3a102m1AP0b@dX0;d5603A6BP0fB4`0<dE803=5A`0fB4X0>4Y;03M9
B@0kCDd0@eIE03U<B`0gBDP0?E1>03]>C00jC4/0@59C03a>C`0iBdd0@E=G03U;C`13EEX0BeaT03a=
EP13Del0@eAO041@G014EV80BeeZ04QJI`1XNhT0Sj:`06j1S`1:Gfd0CF9`04mTLP1@Hg80Bei[04QK
IP19FfD0Cf9Y04]NI@1CI6/0G6ic05a^LP1PLWH0DVAV0080DfEU00<0E6IV05MYJ@1IJf/00`1IJf/0
1@1JK6`0G6i^05iaL01OKfh0HG5`0080Hg=b05L0HW9a061`K`1TM7<0KGem06AdM01YNGT0KGel0720
O`1cPh<0KWen07J5Q`1lRXl0OX^B08B?V021Ri@0OHN>07^5R01gPH80Mh5o07n:QP22SH/0PHb<08>>
SP21Rh`0P8Z<08F?T@26SY40R92C08ZAUP2:Si@0Ri2F09fUZ@2f_/80Q8fB08F>T`2?V9d0S9FL096J
X@2CW:<0VJ:[09FNY`2GX:T0V:6Z09FNY`2FWjH0V:2X09JOY@2FWj<0UYjQ09FMX02:Ti<0Ri6@08^A
SP2BUi@0VYnK09bQWP2JWj80UIZN09VNX@2OY:L0V9jN096GUP2=Ti40Ri6>08fCS`2AV980SiF@08N>
S`29T9L0S9BH08R?T`1oQhT0OhN80829Q@1nR800Mh5h06QbIP1QK5h0GVUJ069/G`1YLVH0KWU_06Yd
J`1UKfL0KWUb06iiM01VLFd00P1VLVh0:`1SKf/0HFeZ05IUH@1NKFT0IWAd06IdM@1OKG00G6]`05a/
LP1GJFd0DfEV055TH`1@I640CF5N04]MG`1JK700EfU/04eMH01DI6H0CE]K04]IE`0mBdH0>DI003E3
>`0b@3L0AE5805=LEP0nAd40:C8^02lh=00^=c<0:c@a02</:P0X<Bl0;CHe03U2@@0g@3l0=Sho02/d
<00W<BX0;3Da034j=P0]=S800`0_>3H01@0Y<S409Bh^02`d=@0]=CL0:C8a00809c0_03H0:34`02Pa
<@0U;Bl0:C4c02L_<@0Q:B`092``01/S9`0R:Rd082XZ028/:`0P:RT07bLX02@/;@0]=C@09B/[02<X
9`0X;2/08bPT024V8@0f>CD08b<O01lP700U9B80824M028U8@0J7Q`05a`I01hU8P0W<2d05b0M01dV
8`0I8Qh06QhJ01lQ7P0U9b@06adJ01dO700S9B8071hK020R7`0Y:bP0[:j[055CD00Q8b006QXH01LG
5@0H61H06ATG01PH5P0G5aD06ATG01/K6@0J6QP201LG5@0C01TI5`0G5Q@06APF01PG5@0F5A<05aHD
01TH5P0F5A<05aHD01XI5`0L6aT05aHD01<B400D4`l05QDA01<B3P0E510051<?018A3@0501@C3`1R
01<B3P0E514040h<01<A3`0R81d03@T801`G5P0C3P`04`d=01PA4@0B2@T08QTJ069LFP16@Sl06ADB
01HB3`0E4@h0510=018>2`0B3P`05A4?00l;2@0K5a@0M71]02TV8P0>2`P030T7010=2`0?3@T04Ph;
00`81@0F4Pl03PT6018>2`0G4Pl0OWUf05mIF@0F41004P/<00d51P0E3`l04@`9018<200A30P04P`9
01<=200C3PP04`d801D?2`0O6QH06A<?00d60`0B3@T04@/7014:1`0@2`L040X6014:1`0A30P050d:
01D;2P0F30/04@L601L?3@0D30X07ADC05I?C@0F4@h03@T801D@3@0Q7AX03@T700d8100E3`/02PD1
01L@3@0?2@D050l;01@>2P0D3P/0<bhZ03@]:P0C3@T04Pd900l91P0B3@/050l<01/D4P0I4a405a8?
014:200A2`P040/8014:200A2`P04@X801471P0B20L201<9200401881`0A1`H04`T801<920804PP7
0P0A1`H00`0D2PT04PP701471P0201061@0301471P0E2`X05@/:008050X900L04`T80189200?20H0
4`d:01<>2`0A2`X04@X:00804@/;00`040T;018<3P0T7R005@d@00d5200A1`/040D901462P0C20`0
4@H:00l5200A1PX201062@0E01472P0B20`04`T<0104200?10L04@H:01472P0?1PT03`P:01D?4@0;
1`P0514B010>3`1HEEH0j>KV09>=S@0_9bP07A@E01L>3`0:0`<050X;00804PP900@04`P:01<72@0>
0`@04PL80P0@1PD01`0A1`H04PP701881`0@1PD04@L601881`0?1@@00P0A1`H200l5100@01471P0B
20L04PP701<9200E2`X0>2h]0516A@0@20L04`T901@;2P0?1@<04PP601891@0D2PP05`d;01471@80
4@P6100A1`P00`0?1@@040H501471P0201471P0?01881`0C2@P04PP700l5100>10<03`D401881`0D
2PT04@L602`R8@0>1@@05@/;01061P0?1@@04@L600804`T800@04@L600l5100A1`H04@L60P0?1@@2
01471P0601<9200A1`H040H501061@0A1`H04`T85?ooool001_ooooo01L0BdI=01`G7@0A3100510A
014;300P6aP03@P5018<300<1PP06A<G018<4@0@2A0040X>014<3`0C3a005@lA018=3`0=2@X05a4C
03<^<00P71d04@`=01H@4P02010:300;00l92`0;1@L03`T;01@>400C3@l03PP:018<3P0A2`d040X<
01@>400H4Q@00P0?2@/05P0@2P`04@/=014;3@0A2`d05@lA018<3P0C3@l050h@01<=3`0A2`d050/>
0189300C2Pd04``>0189300>20X04`d?02LS900>2P/05A4B00<0000B3@h2010:2P05014;2`0B30`0
4P`<014;2`0B30`00P0D3Ph0100A2`/040X:010:2`0A2`d301<=3`03014;3@0@2P`04P`>008050h@
01h04P`>010:300@2P`050h@00l92`0D3Q003@L9024K7@0l=SP04P`>00d72@0D3Q007QPJ03La<`0I
518040d800h:1P0B3P/05Q<>01DA3@0@30T04a0;01HC3`0E4@h04Pl:014=2P0E4A004Ph=010<2`0A
3@`201<?3P0<02HR8@060P403@T802DQ800^:RT04Ph=01H@400C3@d0618B00@0000?2@T06A<C0P0F
41009@0E3`l050h>01<=3@0B3@/040/801@?300B3P/04@d<01HD500A4A404a4B010>3P0@3`d05A4>
01LC400E40d040`;014<3@0B30`050l<01TA3`0J4Q005@d;01PC4@0E4A006ALH01DE600>3Q005A<D
01TH5P0A40h03`h<01@C4@0A40h05aHD01DC4`0I5aP00P0O7Ah04`0G5AH05aHD01/J600M71X06aXH
01LG5@0F5Q@0820N03do?00B51405ALD02T[:00I6aP0ATM500d=2`0D51806QXH014A3`0J6QP00P0M
7A/301`L6P0301XL6@0H6QL05QPE00806adJ00h06Q`I020R7`0F61D08bDR01lQ7P0K7AX07b4N02hc
;@2j_kP0=c`e02T^:00K81/07R<O01DJ5P80720O01808bLV01lS8P0N8R408BLW01PP8P0M9BL0<3Tj
02La<P0K9BH072LW02Da<@0H92@0938b01l];@0S<C409S<e02Pc=`0Y=3P202Tg>P0A02Xh>`0/>d00
<3m403A3B00fB4`0;d5502do@`0`@TH0<dE703E7B`0bA4H0<49403A6B00gBD/0<dE70394AP0eAdT0
0P0iBdd0;01KJVl0AEAI03Y9C@11DE40AUIE03M7AP11DE00=TI503]:C00jBDh0?4]B03m?EP1>GV/0
A5IT04IHIP17FFL0?U1N04IHIP1EIWH0AUMW07N8V03Nkol0T:6a04MHI`1=Gf/0C5iX04QJI017F680
B5US04iOI`1AHVX0DfA/05Y[L`1;G6@0BeaS05Y[LP1JJF`0FFQ[05YYK01LJfh0Ff]/05MWI`1MKFd0
GVi]0P1OKfh2065aL00V06=cLP1TM7@0Jg]k06EeM@1WMgP0Hg9e05a[KP1[NWd0IgIi07j=TP1TLgP0
NHR=06]hOP1lR8h0PhjD07j9S`1oRY00R96F07n8S@1nQhX0OhN906aeM01jPX00NH9o0829R026Si00
QHf?07n7R@22RX`0R92B08fEU`25SHl0QXj@08>;SP2j`/D0];bo0:je_01nQHd208fDW080TIRP06H0
TYVQ09>JXP2@Uil0UIbT09NNYP2AV:00UIbT09NLXP2AV9h0TYNL09>HW02DVI`0QXb;08B:QP2<Th`0
OhIn09>JTP2KXY/0U9RH08b@T`2IWIh0U9RI09>GV02OXj@0Rhn@08>7R02<T8l0Si>B08b@S`29T940
Q8b>0869R`1oR8L0O8F207V2O`1hPG/0Lgee071jL@1[MFX0IFmT06YdJ@1/N6d0IG9Y06IcJP1YMVh0
KGYc071lN01]NgL0IGAa06=bK`1SLW00HW5^05e[J`1LJVX0IGEd06QhN01LK6`0FFUY05i]L01OKW40
EfIY059RHP1HJ6P0FF][05MXI`1?HF<0BUaP04YKG@1CHF@0EUmT04aBE@11ATT0?D=303<g=`0/<2l0
;c@`03Tn>`0a>ST0<3Xi02li>00[=C@0:S@c02`f=@0X<S<0;SPi03Q2@`0i@d@0=T1103<m?P0^>3T0
;cTj02@^;`0_>CX09Bl`02La<P0[=CH0;cTj02hh>@0Y<cD09S0b01hV:00T;B`201dS8`0R01XP800W
;Bd0;cDe03i4A00/<C<082DX02<X:`0U:Rd08BLW01lU9@0W;B/08bTW028X9P0U:RT08BDT02DY:00T
:2L07b<R01/O7P0N8R409bTX01PF6`0L6Ql081lT024P9@0O82<06alP028V9`0P9R@06R0L01LM6@0C
71L06R<N01PM6@806QlK01805Q/G01dR7P0H7AT05Q/G01hS7`14BDD0>Chj02hc;`0A4a006a/K01@D
500E5AD061PH01hN7P0O7al04Q8B01TI6@0K6a/201@D500?01/K6`0L6aT071/I01@C4@0A40h05QDC
01LF500F5A<05A@B01<B400@3`d05A@B00/:200C3`h0510?00<05Q8A01@03@T803<_;P0B3Pd0510?
01PD4`0U8B004`l<01@A300G4Pl061@@01TD400H4a005A0=01D@300F4@h061<@01LB3P0F4@h07APE
01/E5@804P`<05005Q0@01@>3P0B30`040X:018<300G4A404`d=010:2P0D4Q000P@101`N7@0<3@`0
410>01HD4P0B3Pd05Q0@01PB3`0D30X04PX801L=2`0G3@`04`/901@;2P0F30/04PX801D<2`0B20L0
4`/901071P0@1PD05@d:01D<2P0F30/04PX801H=2`0F30/03`L50189200F30/05@d;01<:2@0C2@P0
4PX801<9200I3`h05P`;01@:2@0C2@P04@L601H<2`0]8b804@T701D=2`0K4a404`/901L?3@0E3@/0
4PT8024I5`0?1@@04PT700X2000D2PT03PD301D=2`0C2@P04`X900`40P0900005`h<01<;2@0I3`h0
5Pd<01L?3@0?1@@05Pd;018:200G3@`04@P601D;2PL04PP700X03@@401T?3P0@1PD06@l>00`20@0?
1@H0710B01T=3`0?1@H06`lA0P0C1`T0;P0I3@l08QHH01`@4P0@10H03`D600l71`0G3@h04PT:0108
2@0Q5QX03`H901H<400A1PX04@P;01H<3`0@1@T02@0300h51P0E30d06A0A01892P0E30l03`T;01<;
3P0?2@d030H:01H@500300803@L:01/B5@0A20/04`X=014;3@0?2@/03PP:010:300=1`T05@lA00h:
2`0f<380WYNI06AKGP0I3Q805P/?01P=4@0?10P201462P0@01872`0C20`04@H:01052@0B1`P03002
01T=3`0C1`T03@4301T=3`0C1`T06`lA00P0000@1@H05PX<0186208040@601h05@T;01@8200B1PH0
4PL500T0000A1P@05@T90104100?0`<04PH801X<300C0`@04@@401<9200A1`H04``9014<200D3`/0
40/800h8200B30`030D601@:2@0A1`H02@4000/1000G3@`081HE01D;2P0D2PT201881`0>01D;2P0D
2PT05`/=01<72@0A1@L04`L90186200=0@<03P840186200C1`T04@D701041P0A1@L<018621Cooooo
000Kooooo`0=020I8@0C318081XL02DO8@0D3Pd03@P401XE4@0D3`d0618B01PB5P0910P04@XA01<=
4@03018<3P0=01<=3`0A2`d02`D701hH6P0F41804P`>01H@4P0@2P`05@lA01@>400?2@/04@/=01@>
4002018<3P8040X<0P0B30h0100A2`d03`T;00l92`0@2P`3014;3@0:01@>400B30h04P`>01<=3`0B
30h040X<01@93@0E2Ph050T=01<:3@8050/>00`0618D014=3P0810D040`=01/G600D3`l040X:00h8
200L5QH05Q0@014;2`0C3@d2010:2P804@/;00H04P`<014;300A2`d04P`>01<=3`0B30h2014;3@04
018<3P0C3@l04`d?01<=3`8050h@02/05Q0B00h82P0A2`d02P@601<=3`0X8R@03PP:00/51`0D3Q00
6aDG02lY:`0B3@/03``7014>2@0?30L030T400T60@0@3@P04a0;01HC3P0E4Pd0514<01DA3@0C3`h0
4@d<018>3@0C3`h0510?018>3@1EDE00;BTX01HB4@0D40l071PG010<2`0?2@T050h>014;2`0@2PX0
30H6018<300E3`l050h>00804`d=00T050h>01D?3`0D3``05a8?01@?300@2`P05A0=018=2P0F4@h0
0P0C3P/04`0E40d05a8?01D@3@0D40l050l?01<=3@0E3@/05`h<01P>300O5aD05a8@00T81P0B41<0
3@hA01DF6P0?3@h05aHD01<B400@3`d00P0D4a405`0B4@l04A0>01@C4@0H5aD06APF01DD4P0G4a80
6ALE01TH5P0G5Q@05A@B01@D4P1:BTP0OX1m02/]:P0=3``05a`H00H;1`0L71X04A4?02HV900Z:RP0
61PF00806ATG00L06QXH01/K6@0M7A/07AdK01hN700I6aP05aTF00806adJ00h06Q`I01lQ7P0L7Q/0
7b4N01/M6P0L7Q/06adJ02DW8P1PIEh05a`E020U7P0K81X07b@N01XO6@80724M01808BHS01dQ800M
8B008BHX01XR9@0M9BP0;3Dh02La<`0P:R`07BLY028];`0M:b`082h_01HT9@0S<C80934d02Td>P0W
=3X202Pe>`0:02Lf>`0Y>3d0:CPm02Xl@00_@DD0;3i202i0A00cADP0<TA60353A@<0<TA600<0>D]=
03e?D@0kCDl00P0jC4h0;00iBdh0>dYA03i=E00mC540?4]>03e=C@13De80A5AC03i>C@15EEH0AEAK
04ABF`14Ded0AEET04AEI@16EfL0B5UY04]LK019FVX0C5e]05=TM01AHW80M8FE05a]O@1:FfX0C5eW
04aMI@19FV80A5EM04MHH01@HFT0BU]S04]LI01>GfL0EVM_05QYL@1EIVh0G6]`05a[KP1JJF`0F6MZ
05MWJ01GIfL0GFe]0P1NKVd05P1OKfh0HG5_065aL01RLW80Gfm_065aL@1NKG00I7=f06IeN01^OH80
JWUn08JEVP35e=/0VZV`06QgOP1^N840NhF>08B>U`25SYD0QHjD08J?U01mQHP207b4QP0L07EkN`2A
UiH0WjFS08^CU@28T980P8R:07^3Q@1oQhT0Q8b>0828RP24S8h0S9BF08::S02JXZ@0RY:E08J=U02A
V:00QXfE08N>UP2CVZ80QXfE096HX02?UYh0SIBL09JMY@2HWjL0TYVQ09RLY@80VIjT04H0UibP092E
V02;TI40R8j=08B:QP1oQWl0PXV108ZAR@20Qgl0T9BD09:FU`2?Ti@0T9BE096EUP2:SXl0OX:30824
Q@2?Ti@0TIFF08b@T@28SXh0Q8f<08:;RP21RXP0P8V607j7PP1hPW/0L7Yb06ihK`1ZM6X0I6iS06Qb
I`1ZMfd0IGA]06AcK01VMFl0IgIa06UhL`1WMW80IGAa06YhN01^O7`0JGMg065_K`1MK6`0HG5a05m_
K`1HJ6P0FFUY05YZJP1IJFT0F6QX05MWI`1FIVH0EFEU059RHP1@HVH0BeeQ04aJG@1BGF40DEQN04A8
C015ATX0?d1403Lg>@0b=3<0=CLf03`o?P0T;2h09Bl`0P0Y<c@0>@0[=CH0;SPi02Pb<`0[=CH0=3ho
03Y4A@0h@T<0;SPi02dg>@0c?Cl0:C<e02hh>P0kADL0<C/m02li>`0b?3h0;cTk02Tc=@0U;c407BLX
02T_;`0T:RX0:S0`02le=@0T:RX07R@T02D[:`0R:2P07bDU020V9P0U:b/09bd]01lS8P0V:RT08bLV
028V9@0T:2L08BDT02P/:`0U:BP07b<R01`P7`0O8b809BHX02DR:@0U8BT08b0W024P9P0Q8BD0824U
02<W:0093Ph0:c4]01LM6@0P9b<06R0L01PM6@0202<X900O01HK5`0H7AT05Q/G020U8@0M8Qh0Ada8
02@Y9@0G71P07b4N01TI6@0K6a/07AdM03lo?`0c<c<04a<C01XJ6P0D51@05QHF01LG5`0I6AT07AdM
01PG5@0=30X04A0>02@S8@0N7A/03Pd;01PG5@0M71X05aHD00l>300201TH5P0=01@@3`0E4A005a<B
01LC4P0F4Q40=C4`08=oOP0^:RT03PX900X61@0810<071LE01LB3P0201PC3`0501LB3P0F4@d04`h:
018=2@0C3PX00`0D3`/0700<1`H07ALG03D_;`0V8200208200d71`0G4A4050h>01H@400E3`l04P`<
01XD500O7Qd061`K00L;2P0F6AP00`<3010?3P0S7Ad05@l?01D=2`0J40l04`T801P=2`0G3@`05@/:
01P>3@0J40l201H<2`0?01471P0E2`X050X901881`0D2PT03`D401D;2P0C2@P05@/:01P>3@0F30/0
7Q@C01H<2`0E2`X050X900804`T801L050X901<9200B20L05`d<01P>3@0A1`H03P@301dC4P0A1`H0
5P`;01P>3@0C2@P05P`;00l5100C2@P060h=00l5100K4A005P`;01@:2@0B20L05`d<01061@0201D;
2P0<01@:2@0K4A0040H501881`0>10<040H501881`0@1PD02P0001881`0A1`H04`T81P0B20L04P0I
3`h03`D401D;2P0B20L07Q@C01H<2`0B1`P050P:01<72@0=0@<06Ph@01@82P0B1PP05@T;01/?4@0H
30h04PH801@82P8040D902X05P/?01482P0@1@T03`@801052@0>0`L03`@801@93@0G310060h?01H=
3@0;0P<01`0001@;300D3Q0030H801<=3`0300802@@800H21@0I5a`04@/?00H00P0B30h04`d?00h8
2P0<1PP03PT:00l92`0G4A<0618D00T31@0B30h0=bha02LL800B1`/04`P<01462P0<0@D03`@80105
2@0A1PX201872`0@01462P0D2@`04`L900P0000E2@/05`/=00P0000A1@L02@0001/?4@0L41802000
01dA4`0B1PT04@D901<72@805`/;0P0B1`D05`0E2PP05@T90104100@10@050L901T9300I2@X060/;
01@:2@0@20H040/701DB3@1?C4L0?3Pe00<0000@2PX040X;00P0000L4Q406Q0?01`B4@0900003`L6
00<04PP700D04`T801@:2@0A1`H05PX<01@82P0201<72@080186200?0`D04PH801<72@0B1PP040@6
01451`0D20X60186200601<72@0B1PP04@D701451`0B1PP04`L95?ooool001_ooooo00h04@XA010:
3`0B30h05@lA01D?3P0B3@X04@`9010;2@0=1`L06Q@H03H`=@0G4AH04`dA01<=3`8040X<00l04P`>
01D?4@0<1PP03PP:010:300D3Q004`d?014;3@0G4A<05@lA010:300A2`d04P`>00l92`0E3a400P0@
2P`00`0B30h040X<00d72@06014;3@0O01<=3`0@2P`040X<018<3P0@2P`03`T;01D:3P0G31005@X>
0189300G3Q4071<F01D?4@0?2``040`=01PD5@1mNGX0B4=300l92@0=1`L07aTI01D?3`0=1`L06Q@D
01/E5@0C3@d04@/;01<=3@0B30`04@/<018<3P0301<=3`04018<3P0C3@l04`d?018<3P<04@/=0180
4P`>01H@4P0A2`d040X<014;3@0>20X05Q0B01<=3`0?2@/04`d?010:300M5aT02PD4010<2@0C3``0
510=01TE4P0U8Ah201@@3@0401<?300@30T040`901<?30804Ph=00L04`l>01DA400D40l040`;01PD
4`0<20L03`/:0080510?00T040`;018<300L5QH04P`<01dG5`0?2@T04`d=01D?3`0D3Ph00P0B30`0
1P0D3Ph0618B01<>2`0D3``04Pd:014<2@805A0=01@05Q4>01@?300C3P/05A0=01HA3P0E40d05a<B
01LB4@0E3`h05@d;01H=2P0F30X050`901LB400A40h06QPK01XJ7P0J6al0518C01HE4`804a8@0P0G
5Q@02`0C4Q005A@B01DD4P0E51805aHD01TH5P0I5A@06ALE01LF500E518051@B00805QHD00/06adJ
00d?300L7Q/03Q<?01TN6P0I6AL06a/I01`L6P0J6QP06ATG01dM6`0201/K6@@06QXH00D071hK01XL
6@0K7AX06adJ01XL6@0201`N6`0R01LI5P0F61D07b4N01XL6@0N81`07b@N01LL5@0S:2406b0J01XO
6@0N8ad07B8N01dQ800O8b807R8Q01dQ800N8bD06R8U01`T9`0S;2h07bT[024[;@0T;S007BPZ01d[
;00Y=cP0=TA504ABD`0U<SH0:3<i02Hc>@0W=3X0:3Dk02Lf>`80:STn00`0:C/o02`n@P0[?D40;T14
03A6B@0a@dD0<49403A6B00fB4X0<dE703I8BP0kCDl203U;C@0@03Y<CP0iBdh0?DaB04iMI013DUL0
AeII03m>D00oCe00?4]=03m>DP16EE`0BEMR049@G00oCUd0?dmN04MII`80AUQV00T0Cf5_04QJJ015
EfD0Cf5_04]MJ`16F6H0BE]Y04YLJ@1:FfD00`19FV802@1<GFD0DV=[059SJ`1GJ700CUmW06enQP1/
OHD0DfA/05IUJ`0205a[L00305UXJ`1JJF`0Gfm_0080GFe]02l0GVi]05m_KP1PL6l0HG5`05i^KP1O
Kfl0H71`06AcMP1UM7L0IgIi05m^L`1/Nh00RiZO0;O6c@2DXjX0LH2707R2R`1jQ8d0OXRA08:;TP23
S980PX^@07n7RP1iPH@0MGeo07IlO02;TI00TINE07b4QP1mQHL0NH6307j6R02=UIL0UYjP08fEU`25
SHl0R92B08::S02:TY@0Ph^>092GWP2=U9`0PXVA08ZAV@28SiL0S9>K08jEW@02092GW`0H096HX02B
VJ40T9NO092DW@2>TiT0TIJL09>HW02AUYT0TINH08fCTP25RhP0QXb708>:P`29T8P0Z[6Z09ZNWP29
SHh0SI6B08nCU02:SXl0Q8R907f1PP21QHH0RHf>0P2:SXl05P2:T900Qi2?08B=S022RhT0OXN407Z3
OP1cO7H0JgE]06YdK01ZM6/0IFmV06E_I@1YMF`0IgI_06IeL01UM6l0I7=^06AcL01UM740J7Md06Ug
M`1VM7@2065_K`0L069aL@1NKVh0EfMW05IVIP1LK6`0FFUY05EUI@1IJFT0FVYZ05ATI01?Gel0Be]K
04eOHP1=GV80D5iQ059LH01<DeT0?T9703Hg>`0`<CD0:R/]02`^;@0`<S40;S<b02L_<@0Y<c@0;3Hg
02Xd=@80:38c00<0;cTj02hh>@0d?Sl00P0mAdP03@0a>c`0:cDf028/;@0`>S/09S0a038l?@0e?d00
;cTj034k?00]=cP0:C<d02/e=P0W<3400P0V;2`01@0P9RH0;C<c02hd=01HGUh082HV0080:2h^00H0
8bTY028X:00W;Bd092PW02L[:P0R9RD201lS8P0F01hR8@0Y;B`08bLV01lS8P0P92<08RHU02@U9P0X
9b/09B<X020N8P0O7R<08R8V02DV:00J7Ql0JVi^02T];02?UI@09R`Z01/Q7P0O8Ah061XG01TK6080
7R0M01407b4N024S800M7a`07b4N01LI5P0O8Ah04Q@A01PH600F5QH05ADE03dm?@12@T80ATI6030`
<00I6AT05QHF01PH600201@D5006020O7@0g=S@0;Rd[01HE4`0C4Q006APF0P0E51801P0D4a407QdK
02HU8`0V9B<05Q8A01LC4P8061@C00P05a<B01@@3`0R7Qd04`l>01PD4`0@30/06QHE01@@3P<061<@
00@05Q4>01D@3@0F4@h05Q4>0P0E40d00`0G4Pl061<@01TC4P0201/E5@0N01D?3`0@2PX04`d=01D?
3`0D3Ph05a4A018<300?2@T07QPH05eLF`2e^KP0>S`k00d>3@0`<3004a4@03D_;`0K5AD04`/901/A
400B20L04`P601D;2P0C2@P060h=01X@3`0E2`X050X900h40`0C2@P060h=0P0I3`h201H<2`0801D;
2P0F30/05P`;01H<2`0M4a805P`;01D;2P0D2PT201<9200801D;2P0?1@@05`d<02@J6@0M4a804@L6
01061@0<0P4301<9200J01D;2P0A1`H04`T801L=300?1@@04PP701H<2`0G3@`04PP701<9200F30/0
40H501X@3`0L4Q407A<B01lE500@1PD04PP701471P0E2`X0@CLf02XP7`0=10<040H501@:2@0K4A06
01881`0f01471P0?1@@050X901<9200G3@`050X901D92`0B1PP06@d?0187200E2@/040@60186200A
1@L04PH801<72@0D20X05`/=01872`0D2@d03@@601@:3@0D2@d05@X>01`A5@0F2`l04@H:00`11@0?
10P04PP901<92@0A1`P060h?0107200b:bd0Qh6303La<`0@2`l061<G00l:3P0D3aD040X>00`7200<
1PP0618D02LQ8`0@2P`03PP:00l92`0C3@l02`H7018<3P0I4aD03PH80P0G3100100;0@@040D901H;
3`0B1`/201052@0@01462P0B1`/050T=01<72P0>0P@05@T;01051`0>0`@060`>01L;3@0:00405`/=
00h41@0V6Q`04`T:01L<3P804PH800H060`<01T=3@0C1`L050T70146100@1@<20146100L01@81`0D
1`L05`X901461@0:0@003PH3010;1`0?2`T04@d<01D@3@0A2PX03P@50107200B20L05@/:01071`0Q
5aH05`h=01@;2P0@1PD03`D401471P0D2PT04PP700l5100C1`T05@T;01H:30804PH800L04`L90186
200B1PP040@600h2100@10H050P:00H04PH800H050P:0186200@10H040@60186200D20XDooooo`00
6oooool04@0@2A005PlE018<3P0@2P`04Pd;00`7100A30T061<A00T30`0C3A40?CHl00d72`0?2@d0
4P`>01<=3`0A2`d04P`>00805@lA00D050h@01LA4`0B30h03`T;01D?4@02018<3P0;00l92`0A2`d0
4P`>010:300A2`d04`d?014;3@0?2@/04@/=01<=3`0B30h01P0A2`d200l92`0?010:300?2@/03@L9
01D:3P0H3A405@X>01482`0H3a807QDH014;3@0?2``01`<400d92P0c;c0040/<008050h>0`0?2@T0
1`0J51@07aTI01D?3`0B30`050h>018<300B30d01@0D3Q000`0B30h040X<018<3P0201H@4P0:018<
3P0@2P`050h@01LA4`0B30h05Q0B01TC5@0A2`d04`d?00d72@804`d?00l08A/M01PC4P0D40d03@T6
010<2@0G4a007QXG01@@3@0C3``04@d:00l;200@30T05Q8?01HB4@0C3`h00P0A3@`2018>3@0H01DA
400G4a805a<B01<?3P0=2@P04`l>014;2`0>20P04P`<00X4100F41007QPH01TC4`0F41004P`<010:
2P0B30`05@l?014<2@0@2`P04Pd:01@?300E40d05a8?0P0D3``201<>2`0F01@?300E40d05A4@01DA
3`0D3``05Ph;01P?2`0I40/05`l<01<>300:2@L071XM07enP@2HVI/0:bTZ01PG5@0@3`d05A@B01LF
500C4Q0040l=018A3`804A0>01P04a8@01HE4`0J5QD06QLF01LF500E51805ADC01LG5@0E5A<05ALD
01PJ5`0Q8b006b0L01TN6P0F5Q@07AdK01PH5P0I6AL06a/I01LG5@0L71X06a/I01XJ600I6AL201PH
5P8071hK03@06Q`I01/M6P0L7Q/06adJ01XL6@0I6aP05aTF01dO700J71T0828O01XO6@0Q9R007R<M
01`Q6`0M8Qh09BXV020U8@0P92<07b<R024U900Q9BH07R<U01/R:00O9R`07RH/01TR9`0L9BX09S0d
01lZ;P0M:bh0;ce004ABE@1?GF00930e02D`=P0T<CL09c@j02Xg?@0Z>Ch0;3]002dl@@0^@4@0<TA8
02i0A00_@DD0<D=70394B00fB4`0=dU=03I8C00gBDd0>D]?0P0gBDd0;P0kCE40?e5E041BEP0lBe00
BEQM03Y9CP1=G640AeIK03a;D010CeH0AeEN04ECG`1=FV/0AeAU04ECI`17EfL0AeUW04YLJP18FVP0
AeUW04iPKP1<GV`0?U1N04EGI@14EV@0AUQV04YLJ@1:FfD0AUMO04UJHP1FIfl0FFYb051QJ@1>GfL0
GFif051QJ@1RLg/0FV]c051QJ01AH6L0G6]`069aMP1PKg@0GVe`065`L`1LK6`205e]K@0905i^K@1P
L6l0H71_06inOP1/O7`0HW9b06YiO01TLgH0IWEh0080J7Ml0140IGAi07B3RP1`OhH0MHB;07AnQ`1h
PX/0O8J?08><T`2FWjD0Z;6f08^CUP1mQHP0KgMi07UoO`1kPH00KWAb07=kO@020828RP0F07Z2Q025
SHl0TIVK08ZBU024S8h0PXZ<0828RP1lQ8H0QhnB0:bc^@39d=H0W:>Y09:IW`2@Uid0R8nE09FLXP2S
Z[00XJR^096HWP2>UI/0U9^Q09JKX@80UIZP0140SI:F08bAU02BUiX0Ri6@08>9Q`2:T8`0QH^608jE
SP35blL0VinO07j2P`2<T940TIFF08F9RP27Rh`0R8b=08Z>S`0208R<S@0>08V=SP2;TI40R96@08F>
R`21RXL0NX>007AmN01^Mg80JG=[06QbJP1[MFd0Ig5Y06I`J01XM6`306IeL00<06EdK`1TLg00I79a
06=aL@1PKVh0GVa]06IdM@1bP840K7]k05e]K@1KJf/0EVIV0P1IJFT00`1GIfL0EFEU055QH@0205=S
H`0@04aLG018EeX0BUUL04mLG`1;EEL0@TY=03Hj?P0a<SH0;2da02PY:`0];S00;S8c02/`<00S:bd0
9bla02hf>080<3Pj00D0<SXl02/c=@0]=CL0<3Pj034i>`02030h>P0C02/c=@0^=SP0:C4c04Q@DP2^
][P0MWj002de=`0^=SP0:c<e02P`<P0]=CL0;3@f01HL700S:BT08RPX02le=@0R:2P0A4Y:020V9P02
024W9`06028X:00U:b/0:2h^02DY:00S9bH082@S0P0M8B008@0Q9B@092PW01lS8P0N8R408RHU02DY
:00V:2L08B4Q024Q8P0O7al07alQ020Q8`0Q8R@09BHX05aOH00k?d00:Rha02`a<`0T:RX07AlM01/M
6P0G6AH051HC00`>2`0K7AX06Q`I014C400L7Q/06Q`I01LI5P0I6aP051@D01DE5@0201lO7`0E01HF
5P0K6a/06QXJ010@400A4A404a<C01@D500G5aL04a8@024P7P0L6aT04Q4?014@3P0B4@l06aXH01@C
4@061@<03@`:01PG5@0X9bD05a<B008061@C0P0G4a801`0F4Q40:2@S014=300G4a806ADD01XF5@0S
7Q`00P0E40d201HA3P0301LB3`0F4@h04`h;00804Pd:00L04`h;01D@3@0E3`h05Q0@01TC4`0H4Q80
50h>00<04`d=01H05@l?01H@400@2PX04`d=02@R8P1BE5<051@D00X92P0>30d06aLF01@>3P0C3@d0
40P601H<2`0M4a807A8@01L=300C2@P04PP701<9200A1`H05@/:0P0G3@`0300E2`X040H500d30P0@
1PD04`T801H<2`0H3Pd050X901<9200B20L05@/:01@:2@804`T802H050X901D;2P0;0@004@L601@:
2@080000308103<Y:00D2PT05`d<00h40`0A1`H06@l>00h40`0H3Pd040H501D;2P0M4a804`T801X@
3`0G3@`04`T801881`0?1@@05@/:00L0000>10<050X900/1000B20L04`T801@:2@0E2`X07A<B01X@
3`0L4Q403`D500`20@H04PP700h0308101D;2P0E2`X04PP701061@0E2`X04PH801451`0I3@l04PH8
00d10`0C1`T05@T;01@82P<04`L900D04PH801<:300K41@02P0301@93@0201052@0N01H;3`0A1PX0
4PL;01L<400F2`l04`T:01@:2P0?1@H06Q0A00l61`1EC4l0gMCG04m9B`0G4AD04@/?00P41`0Q7280
4@/?01`C5P0<0`H06A0C01H=400O5QT050/>00T00`0C2Pd050/>01072P0E30l03@<70P0?10P0100D
2@d05@X>01052@0>0`L200l4200B01052@0B1`/050T=01H;3P0M4A<04@D701T=3`0B1PP020000146
1`0N4Q@060`>01/?4@3IcLl0>2`^00d3100B1PP04`L90P0B1PP03@0B1PH05P/90146100E2PP06@h:
01D:1P0D2@D05@X801<:1@0?1P4040P5018=2@0>2@D00P0@2`P04`0B20T050P:01D92`0C10L04`L7
01471P0g;B`0Q7Yi0<[0_`0Z81l04`T800h40`0?1@@04`T800l5100@1PD04@D701@82P0F2P`00P0A
1@L01`0E2@/03P8401<72@0E2@/050P:01451`0@10H01P0A1@L01P0C1`T04PH801451`0A1@L04PH8
01<72ACooooo000Kooooo`0?0109400B31003`T;00l92`0A2`/03PT600/60`0>20L03PP:00T31@0?
20h02`D900d72@0C3@l050h@00804P`>01<05@lA014;3@0E3a405Q0B010:300A2`d05a4C010:300B
30h040X<01<=3`0E3a404`d?00l92`0C3@l04P`>00h82P0B30h05Q0B00<04P`>0`0A2`d05P0B30h0
3`T;00l92`0A2`d03`T;00h82P0D2@d05P/?01D:3P0B2@`05Pd@01XA500=20T061@E00d92P0C3a00
71PI00`71`0H4Q806Q@D00`61P0@2PX201@>3P0301D?3`0@2PX040X:00804`d=00<050h?01@>400C
3@l00P0C3@l03`0D3Q004@/=00h82P0B30h06aDG01hH6P0I4aD050h@014;3@0G4A<04P`>014;3@0H
4Q@050h@01hH6P0201<=3`0300l92`0K5AL050l?00803PX70P0C3``00`0<20D04@d:018>2`0201<?
300401HB3`0M6AH061@C01@@3`8040`;01d04@d<018>3@091@@04@d<00h:2@0@30/02`L601HB4@0I
4a<04P`<01dG5`0@2PX09b4Q034[:`0H4Q805a4A01<=3@0A2`/04P`<01@>3P0D3``04`h;01HA3P0G
4Pl04Pd:01<>2`0D3``05A0=01@?3002018=2P0D01D@3@0D40l0510>01@?300G3``06A4=01/B3@0G
3``050l<01DD4P0Z:2T0YZJY0<c=c`0_;Bh06APF014@3P0F5A<05aHD018A3`0C4Q0201@C4@0K01DD
4P0F5A<05QDC01LC4P0H5Q@05aHD01DD4P0C4a4051@B01LG5@0B5140:R`Y01HH5@0K81`03a4>01PH
5P0I6AL05QHD01`L6P0N7Q`06ATG01PH5P0I6AL06QXH01`L6P0M7A/07QhL008071hK00@06A/H01`N
6`0N81d071hK0P0O8Ah0800K7AX071hK01PJ5`0P8Ql05Q/E02<X8P0I7QP082DO01dR7P0Q9R8082DQ
020T8`0O8b808bLV02@X:@0P9BT07bH/024X;P0P:2h07BH[01hW;00R;3009C0d02Dc=P0W=CP09C<f
03=1A00Q;S809S4g02Db>00X=C/0:cPn0P0[>Sl03`0Z>Ch0;3i20394B00_@DD0<D=70394B00dATX0
>4Y>03M9C@0eAd/0>D]?03]=D@0gBDd0=TQ<03Q:CP0203]=D@0?03U8C@18Ee`0@e9G04QGG012DEH0
@e9I03a:D`14DUd0>dQI04]HJ`15DFL0@e1W04aLK019FfT0C5i/0080CV1^01d0EfUg04IHIP18FVP0
B5YX03]=F`13EF<0BE]X04YKI@16Eel0BEYR05QYL@1KK7@0Cf1X04QIH@1GJ700DF9Z05AUK@1?H6P0
E6E]05MVK@1OKW<0Hg9g061_M01MK700G6]^05][J`1LK6`0GFe]05i^K@0205m_KP1D08FEU@1kRh/0
Hg=c06imP01WMWT0Kgj106QgO01_OX<0K7^006mnQ@1]O8<0MhB<07J0R@1jQ8d0O8J?0829T02@VIl0
XZ^`0:2XZ`2?UiX0MGeo07f3P`1gOG`0KG=a06mgN@20R8X0Q8b>07^3Q@21RH/0RY:D08F=S`20R8X0
NX:408F=S`2DW9h0^l?50:2W[@2RZJl0RY6G08>:T024Ri40PhZ@08nFW02MY:X0W:>Y08ZAU`29T9H0
U9^Q08fBV02@UI/0UIZP08nDV029SY40SiBG08N=S@1oQHD0OH>108N=RP2<TXh0U9ZF08Z>SP24R8T0
QXZ;08jBT`26RX/0Oh>408Z>S`2?Ti@0T9BE08jBT`2:SXl0QXf=08F>S@23S8T0PHZ707^4P@1eOWT0
KgQc06QaK01WL6/0JgE]06UcJ`1XLVX0J7=^0P1UM6l0101VMG00IGA_06EdL@1SLW02069`L00N065_
L01SLG80IgEf061_L01KJf/0GFe]05EUI@1BHV80DF5Q059RHP1?Gel0C5aL059RHP1CHf<0C5aL04iM
H01AH6<0E65T04]EE`0oAdX0=3Ll02l`=00/;C40:BX/02X^;`0/<340:c0`02L_<@0Z<S@0;SHh0P0]
=CL0500^=SP0:c<e02hf>00a>C/0;cLi02hf>00a>C/0;cLi02/c=@0U;Bl0@4Q:09NOX@1TK6h0;SHh
02lg>@0Z<S@09Rh`02Ta<`0V;S00;C<c0P0[<C402P0m@d<0;cDe02`b<P0/<S809R`/028X:00T:RX0
9R`/02@Z:P0Q9BH301lS8P06028V9@0Z;Rd08BDT01lS8P0N8R4082@S0P0T:2L0400R92<08b<S02<S
8`0R8R807b0Q01dN800D5AL07b8T01LK7P0T:2/05QXN01/O8P0Q8b402`d:01HH5@0c=C8201TK6003
01hP7@0];b`07b4N00805QPE00L05aTF024Q8@0M7Ad06ATI014A4@0R8R805aLG00805ADE00@061PH
01HF5P0E5AD06QXJ0P0I61H02P0H5aD07A`J01`K6@0G5Q@04a8@00/:200E5180>CPf01XI5`0<2`T3
01LC4P0901HB4@0E4A005a<B01/G5P0N6QT061@C00l;2P0>2PT03`X8008050l<00@05A0=01HA3P0H
4a005Q4>0`0D3``0100E40d05Q4>014<2P0B30`201LA4@0F014;2`0@2PX050h>01@>3P0E3`l06Q@D
01@>3P0?2@T04Q0?01TI6@0:2PX061LG00<10P0B3Pd03@L701D?3`0D30X04@L601X@3`0G30X06Q0?
01D;2P8050X900<04`T801P>3@0F30/00P0D2PT201<9200401lE500@1PD05P`;01X@3`805`d<0`0D
2PT201<9200@01@:2@0F30/0718A01T?3P0@1PD03P@302LM701]Hf806a4@01P>3@0?1@@04PP701T?
3P0@1PD06@l>00d30P805@/:00d03`H600T0000C2@P04@L601H<2`0J40l09A/J01881`0>10<050X9
00d30P0E2`X04`T800804@L600D04PP700T0000>10<04@L601hD4`0601881`0>00h40`0A1`H02`40
01471P0>10<05P`;01<72@0;004040@60186200;004060`>01H:300G2`d201@82P0N01<72@0@10H0
40H900l4200F2`l060dA00T00P0I3Q804@H:00h31`0C20`0714E01P=4@0C2@X04@L701882@0E2``0
4PP901482`0d:bh06A<E00H0100C3A40:RDY0:nZ/01?Ad`05Pd@01D<3`0?1PT01P000P0A20/0300;
0PD040L:01D<3`0:0@@030<601062@0<0@D040D901H;3`0=0PH03`@801@93@8040D903404@H:0187
2`0C20`05``?00X0000f:R`0FTi@01L;3@0<00805`/=00T0000<00804@D7024E5`0G2`d06`lA01<7
2@0D20X040@600l31@0B1PH05@T901050`0E2PL05P/700h3000=0P004@P100h5000B2P@04`h800d8
10060@00100000h6100@1@H03`0301X:3@0I2@`05@T900`20@0M51<0OWAc0?kdl`0i;bh05@/:00h4
0`0B20L05P`;00804@L600<04@D70186200C1`T00P0A1@L01`0C1`T040@601H:300J3Q0060`>01@8
2P0B1PP01P0@10H6018621Cooooo000Kooooo`0:01LA5@0?2@`040X<01<=3`0C3@h05Q0@01H@4@0B
30h04@/=01/E5`8040X=01D040X<01<=3`0A2`d03PP:018<3P0K5AL03PP:01<=3`0?2@/040X<01<=
3`0B30h03@L9010:300>20X04@/=018<3P0?2@/04P`>010:300?2@/00`0B30h201<=3`804P`>0P0A
2`d01`0C3@l040X<014;3@0B30h040X<00l92`0E2Ph00P0D2@d0100D2`h04`X=0189300C3@l2010<
3@0I00h:2`0@30d04Pd>014;2`0C3@d05a4A01@>3P0A2`/040X:00l92@0A2`/04P`<01<=3@0D3Ph0
4`d>014;3@0@2P`03`T;010:300A2`d04`d?014;3@0@2P`05a4C01TC5@0201D?4@0I00X41P0B30h0
5Q0B014;3@0H4Q@04@/=024K7@0E3a404`d?00`6200D3Q0040/;00h:2@0C3`h04Ph=010<2`0>2PT0
4@d<018>3@0C3`h04@d<018>3@0F4Q405A4@01@@3`0301<?3P0=00l;2P0C3`h071PG018>3@0E4A00
30P7010<2`0A2`/050h>00l92@0I4a<05Q0@01TC4`0501@>3P0:01H@400B3@X04@`901XE4P0M61D0
5A0=01@?300C3P/05Q4>01@?30804@`900l050l<01HB3`0F4@h05A0=01L@2`0I4@`06a8=01dF400G
4Ph06QTF01@B4`0c<cD0?Sm101`J6`0E51800P0G5Q@0600E51806QTG01PG5@0F5A<061LE01`K6@0K
6QP051<A01PD4`0K61L06aXH01TH5P0F5Q@05ADC01PH5P0N81d02`d:02HX9@2;T8`09BLT01dM6`0I
61H05aHD01XI5`806aXH02/06QTG01/J600M71X07ahL020O7@0O7ad06adJ01`N6`0I6aP071hK024S
800M7a`0828O01hP7@0L7Q/08R@Q01hP7@0T9R<061dG02T^:00C618082DQ01`Q7@0N8al07B4P01lS
900L824092PY02HZ:`0Q9RX07RD[01dT:P0L92X07bP]02</<@0S;C40:C@h01l]<00V=3L07R`_02Hd
=`0Y=CX0;3Lm00<0:SLm00T0:CPm02hm@P0`?d@0;T1402m1A@0]?d<0<D=703Q:CP0gBDd00P0eAd/2
03I8C080=dU=01H0=TQ<03Q:CP0kCE40>Ta@049AE013DUD0AUEJ04=BF@14DUX0AeEP04=AG`1<FFT0
?daQ05YVO`1EHG/0BeUb04eMK@1@HVh0BUaX051RKP1NL7`0D69^0P18FVH02P15Ef<0CEm[04aNJP12
E600AeQR04MHH019FV80CEiV051QJ@1AHVX2051QJ@0>05=TK01?H6P0DF9Z05MXL01KJW40FVU`05UX
K`1JJFh0GFa`05e/K`1KJVd0G6]]05e]K@1NKVh205m_K`0L06QfM`1[NGX0G6Y[071nP@1TLWD0JGMj
06UfO01cP8H0M867075nQP1cP8P0N8F=07f7T01nR940P8ZC086:T@1kQ8X0LGYo07b4Q`28T9<0N822
07f3P`1aMgH0LWQf06eeM`1fOX00P8R:08B<SP80QHf?0P29TI<0;01kPhD0Q8b>09RPXP3EgMl0VZ:W
08B;T@2:TIL0QHbB08^BV02<TiT0QHbB08J=T`29T9H0QhjD092GW@2MY:X0Yjbb08^@UP2<TIL0SY>G
08^@T`2?U9L0R8f?07n5Q@23RHP0QH^9096GUP2;TI00PXR808N=S@2:T900P8J608N=S@2BV9P0SiFE
08fCT`28SXh0S9:B08V?S`22RXP0OhR507f6P`1iPWl0LGYg0P1YLVl01`1WL6`0I6eY06UbK@1YLVd0
JG9^06McKP1TLfh00P1UM7401@1RLFh0HFm_065_K`1QKfl0Gfe^0080H6i_01X0GVa]05]ZJP1NKVh0
Gfm_05IVIP1>GUh0AeMG04ADE019FET0CEeM04iNGP1<G5`0B5QH04YHF@1>G5d0DEaN04E>D@0k@DD0
<SHi02//<00Z:bl09bT/02<W:P0T:2/09b`_02hf>080;cLi0P0/=3H0:00^=SP0;CDg02hf>00c>cd0
>41203Lo@@0^=SP0<CXi020Y:00X<C0082TX02Tb<@0Z<c80:34`02/d<`0X<C0092d/02L`;`0S;2/0
8bP[02T^<@0U:Rd092T/02`a=00W;2l0;34d02T^<@0V:bh09BX]02@Y;00R9bT09b//024U9P0P92D0
7b<T020T9@0[;c0082@U028V9`0P92D201dQ8P0I024U900O8Ah07b4N01lQ7P0P8Ql08B8R024R900X
:Bd071dQ01LH7@0U:2h07R4W02LZ;P0J6aX06ATG02/[:@12@T006ATG01/K6@0P81h0;Rh/010@3P0H
61H07AdK01HF500201PF5`0?01`J6`0Z:2T06ALH01HD5@0I5aP05aDF01/I6P0J61T05aDF01PF5`0E
51807QdK01PG5@0B4@l05A@B00805aHD00H04A0>01XI5`11@3h07A`J014@3P0F4Q4201LC4P0;01DA
400D40l05a<B00h:2@0O6aX040`;01<?3P0P71/04`h>01H@400E3`l00P0D3Ph201D?3`0401@>3P0F
41005a4A01LA4@805Q0@00<04P`<00l92@0A2`/00P0D3Ph0100E3`l04`d=018<300E3`l2018<300D
00l;2`0H5QL04@h?00l<3@0K5aP04`d=01LA4@0B30`04`/901H<2`0E2`X04`T701L=300C2@P050X9
01D;2P0C2@P05@/:01@:2@0B20L201D;2P0301@:2@0R61L04PP7008060h=00@050X901P>3@0H3Pd0
50X90`0C2@P0200D2PT05P`;01071`0@1PD05@/:01@:2@0A1`H060h=0P0E2`X0700D2PT04@L60147
1P0E2`X040H501881`0E2`X03`D4034X9`0D30/04`T801D;2P0D2PT04`T8028H5`0F30/050X901L=
300>10<05P`;01D;2P0B20L04`T801H<2`0D2PT0718A01@:2@0?1@@601881`0<01471P0B20L05`d<
034W9P0G3@`040H50186200?0`D06@d?02`P8P0?0`D04`L90P0E2@/02P0@10H04`L901L;3@0D20X0
CD=6028G6`0<0PD050T=01072@0A1PX201872`804`P<01H04PL;0147200D20T04PH801882@0D2P/0
5P`@01072P0C2Pd05@hB00`62P0[9BT0`[_205A=D@0F3A003`H901L?4@2GSY40>C0c01482`0F3A00
3`H90P0A20/01P0=10L050X=01<8300D2@d04`P<01462P804PL;02/04@H:01872`0C20`04PL;0146
2P0@1@P04`T:02dQ8`0j;S004PH80147200E2@/0308302PL7P0P5AH060d>01/A4P0f:R/05@T90186
200D20X05@T;0186200C1`L040D301L<200G3@D04@L101/A2@0L4`P04@/201<<0`0>2@8020<002@O
700C2`/04`T:01D92`0H20/060D801H41P0>0`<04`T8008050X901@0;R@T01@;2P0B20L03P@301T?
3P0P5QD05P`;00l5100B1PP040@600l31@0A1@L04PH800l31@0@10H050P:01D92`0C1`T04PH801<7
2@L040@600D04PH801D92`0E2@/04PH801041P0Dooooo`006oooool0300K5AL01P0202LQ8`0;1@L0
4@/=00l92`0C3A4030H8010:300D3Q0040X<00d72@H04P`>01l03`T;018<3P0E3a4050h@014;3@0?
2@/05a4C00h82P0600806Q@F00`6200F41804P`>00d72@0F418040X<01D?4@0X8R@0Ad5301D?4@0>
20X04@/=00P2100D3Q003`T;010:300A2`d050h@01D?4@0F418060dA00803P<700`050/>0189300>
1@P050h@00l;301DD5405Q8C00<0000H4a<03PP800l92@0C3@d2010:2P0>01<=3@0B30`04P`<01<=
3@0D3Ph05@l?01@>3`0;1@L05a4C00/51`0M5aT03@L9010:300A2`d3010:300B00l92`0I4aD01000
00`6200=1`T07ALI02TS9@0C3@l04@/=00P2100?2@/05@lA01@>400C3Pl03@T800`81`0K5aH02@D4
0P0E4A000`0D40l03`/:00h:2@02014=300601TE500?2`X05Q8A01@@3`0A3@`040`;0P0B3Pd0400J
5QD01`<200h:2@0F4Q404`d=00h8200B30`06aDE01TC4`0C3@d040X:01@>3P0G4A404P`<010:2P0C
3@d200l:1`05018=2P0E40d050l<010;200D3``00P0C3P/05`0E40d05Q4>01@?300H51405a8?01D@
300I4P`07aL@02<J4`0M5Q004Pd8018A3@0M6a`07b0Q01@E5`0C4A806aXH01@C4@0Q81h04A0>01DD
4P0D4a405A@B00805QDC02L05aHD01PG5@0G4a806ALE01/J600J6AL061LE01HF500H61H05ALD00h@
3@0M7a`0OhB00<C6``0S8b406QTG01LF500H5aD071/I01dL6P0L6aT06aXH01`K6@0N7A/081lM01lO
7@0L7AX04Q@A020R7`0I6aP05aTF01XL6@0T9R<05aTF03@f<`10@Sl08bDR01XL6@0O92000P0L8Ad0
4@0M8Qh0720O01/O7P0M8B807b<T01dQ8`0N8RD08RHY024V:P0M92`07RD]01dU;00N9bh082T`028/
<`0N:Bl0:3Dk0080;3To01408c0f02`h?P0/=cd0:SLm02`i?`0_?480<3m403A3B00fADX0;3i20353
A`0dATX0<4960394B@0lCE@0?e1G03U:D@0203Q9D00U03U:D@0cA4/0=TM>03a=E00gB4l0?U1E041?
DP11D5<0@4mD03e<D`0mBe@0@U1N04UFI`14DF@0BUI]059NN01=FG<0AU=/04EEI@10DUh0AeUU04QJ
IP0nD5`0AUQT04UKI`12E600@E=O04EGH`14EV80A5IQ04AEG`1>GfL0CEiV041AF@1<GFD0Cf1X059S
J`02055RJP0305=TK01EIVh0EVM_0080F6M^03@0GVed061_MP1MK740Gfic05IUJP1VMGP0IgIi05a/
K01OKfl0HW9b071nO`1^NG/0KgYl07=nPP1_NWh0IW5e07=nQ01dOhD0SIRN08B>U`1gPHX0NhF>07b6
S`27TIX0R9:K07j7SP1`NGl0JgAi06M_LP1iPH@0NX:407^1P@1mPh80LGMe071hNP1iPH<0P8R:08::
S024S8h0QhnA08F=S`22RX`0P8R:0869R`24S8h0QXj@08::S@27Si80R92C0869S027Si80Q8b?0P1o
QhX01P27Si80PHV<09VQY02maLP0bm3F08V>TP80SI:F01@0T9FI08N<T024RH`0PXN:07n4Q`29SY00
YJZ]0;Fk^`24SH`0QXn>08F>S@21RXT0OXN608><R`27T8l0QXn>08><R`1nQhH0NhB307b5P`80Mh1m
0100JgAa069[J01WL6d0J75^06M`K@1TKFX0IVm]06=/J@1QJVT0HFaZ06EdL@1XMg@0I79a06EcL`1T
LW80H6i^0P1NK6d02P1RL780HW1c05i/K`1LJfd0GVi^05e]K@1DI6@0B5QH049BDP13De<204QHF00?
04IFEP19FET0AUIF04aJFP18E5@0@D]<03i6B00k@4<0<CDh02h_<`0Z:bl0:2/`03Lj?`0_=3P0<3Hj
0080;c@g00X0:Rlb02H[;P0]<SD0>Sm203Dj?@0oA4L0@4E803@i?00a=ST0;S<f0`0Z<3003P0Y;bl0
:2h^02P^;P0`=SH0:S0`02@Z:P0V;2`09bd]02<Y:@0O92L0<SLk02T^<P0I7R80:Bhb0P0X;C401`0T
:Bd0<cPl02@Y;@0T:Bd07B8U02L[;00T:2T00P0P92D0800S9bP09RX[01`P8@0P92D09b//01hR8`0R
9RL08bLV01hS7`0O91l08RLS02PZ9`0N7al0:2T[02<T:00L7B807QlT020P:00N7RH07QlT01dM700K
6aT061PF01dM6`0L71X05aLE01<C4@0D51808b<Q01HF500M7A/030`:0`0E4a@0100L6Q/0:2HW02l]
;P0F51D201PF5`0601DC500D4Q<05A<D01PG5@0M71X061LE0P0F5A<0800B4@l05A@B01<B400E5180
4a8@01HE4`0L6aT06aLF01LC4P0@30/05a<B01HB4@0D40l061@C01LC4P0F4Q405a<B01PD4`0F4A40
6Q@D01dG5`0E3`l03PP801<=3@0B30`09R0P00X4100G4A403@L7020J6P0A2`/04`d=0P0D3Ph200h8
20804P`<0140618B01XD500<1PH05@l?024K700D41404`d?01LA4`0I4aD04P`<01P?400C2P/09AdK
01D;2P0L4Q404@L501D;2P0201@:2@0301<9200D2PT05@/:00H050X900H0308102HL6`10=SD02@00
02lU900C2@P201D;2P0501@:2@0@1PD04@L601L=300A1`H00P0D2PT02@0A1`H04`T801471P0F30/0
4`T801D;2P0>10<04@L600`20@0201H<2`8050X900@04`T801881`0B20L05P`;0P0I3`h0100E2`X0
4@L601471P0C2@P301@:2@804`T8020040H500l5100A1`H04PP701471P0;0@0050X901`B4@0B20L0
4`T900l5100K4A0030@3028H5`0<0P406Q0?01dC4P0D20X05PX<01T=3`0D20X04@D701D92`0I3@l0
50P:01451`0@10H04@D70186200O51P06a0D01H;3`804@H:1P0C20`0500C2@X04@D601451`0F2P`0
4`P901872`0G310060hA01893P0C2Pl050hB01@=500@2@d04`P<01@93@0I3Q80:AhR02DJ7P0E2Ph0
40D90P0>0`L00`0?10P04PL;01<8300201872`0H01462P0@1@T040D900`31@0K41@050T=01062@0G
31003`@801@9300F2P`03P8401D:2`0C1`T06Ph@0186200@10H060`>0147200B1PP0710B01451P0@
1@<04PH60P0C1`T07@0C1`X040@401`A3`0A1P807aD;0106000P5`P06141018;000D3P@01@4001D@
2P0=20@040L801462P0C1PP05@D601L41P0H1@H04`L701<9200<0`<05@/:00l5100K4A005@/:0106
1@0A1`H050X900804@L601P05@T;00X0000I3@l06Ph@00`20`0B1PP05@T;00h2100G2`d03P8401<7
2@0T61X05PX<01D92`0C1`T04@D700l31@0>0P@06@d?00h3100=0@<04@D70147200I3@lDooooo`00
6oooool0300E3`l0:bDV05UCE@0P6Q`03@L:06mYK@0E3a<05Q0D01LA4`0A2`d03`T901TC4`8040X<
0P0A2`d2018<3P0:00h82P0B30h050h@01@>400@2P`03PP:01TD5@0<1PP0;bT[01D?4@803@L902D0
4@/=00`6200?2@/03PP:01LA4`0V82809AlQ01<=3`0:10H071HH014;3@0B30h03`T;010:300A2`d0
4`d?01@>400E3a408QLK01T>4P0G31005`hA01@;3P0A20/02`H7010<3@0`;2d06QHG01<?400B3@d0
4@/;010:2P0C3@d040X:014;2`0D3Ph04`d=00804P`<00X04`d=01@>3P0E3a0030H801PB500J51H0
;2HX01/E5`0H4Q@04P`>0`0?2@/05`0>20X020<401/E5`0O6A/06A<E01`F600<1PP081XL01dG6@0D
3Q005@lA01@>400A2`d040/;010<2`0E4A004@d<00`81`0C3`h06ADD01LC4P0C3`h040`;00804@d<
01<05A4@00`81`0=2@P03`/:01HB4@0L61L02`L600l;2P0>2PT07QXI01lK6P0F4Q4071HF01D?3`0D
3Ph05a4A01@>3P0@2PX05Q0@00805@l?00<05Q0@01D?3`0C3@d00P0B3@X01@0D3``05a8?01HA3P0B
3@X050l<00804`h;01H05A0=01HA3P0D3``0510=01<?2P0B3@L05@h801XB300O5Pl0614;01<>2@0A
40`05A@B01DF5`0A4a801`H401PG5@0L6aT061LE01hM6`0>3@/05A@B100F5A<03P0G5Q@06QHE01DC
4@0D4a406APF01`K6@0I6AL05aLE01LI5P0C5A805QPE04U>BP1]Kf`06aXH0P0G5Q@00`0J6AL06aXH
01/J600301`K6@0;01hM6`0P7ad08B0N01TJ5`0Z;2T06A/H01/M6P0M7a`07b4N02DW900F61D00P0M
7a`0100I6aP08B<P01lT800O920201hS7`807B4P00d07b<T024U9P0O8bD0720S01dQ900Q9R/092/c
02D/=00U;C@08b`c020Y<00X<ST0=T5700807BX`03T07R/a02`i?`0U<CL0:cHl02Xg?@0/>Cl0;CY0
02`k@00Y>3d0;3]002/m@@0hBTh0>Ta@02m1A@0iBU00VJZa0:6b^@0jBe80?4eD045BF@0b@dX0=TM>
03U:D@0mCUD0>DYA03m@E`10Ce@0AEAG04MFG013DEX0AUAO05ERL@1DHG@0AeAW04eIL01ULHT0HVj8
04ABJ@1IJGP0F6Yf04IHI00mCe/0B5YV04EGH`12E600?e5M04=EH@17FFD0AEMS04EGHP1<GFD0D65Y
04aMI@16Eel0DV=[04iOI`1CI6`00P1BHf/0:@1EIVh0F6Ua05QYL@1JJG00FFQ_05i]M01OKWD0GFab
061_M01QL7D0G6]_05UXJ`1RLW80F6QX05m_K`1XLgD0IW5c06MbM01[MWX0KWUm06agN`1_NX00LGb2
086<TP1hPX/0LWb507J0R@1nR940P8ZC086;U01nQhh0LW^106M`M@1`N7/0Nh>507R0PP1jP800OH>2
075gM@1hP880OhN90080Q8b>02`0QHf?08J>T025SHl0PXZ<0869R`22RX`0Q8b>08F=S`25SI00QXjA
08B<S`2@V9/0Vj>V08ZBU@1nQXT0PHV<08ZBU@24S8l0R92C09VQY02OY:X0OX>708R=T@2:Si<0SiBH
08R=T@27S8l0RXnB08R=T026Rhh0SI:E09BIW023S8/0Q8f<08><R`1oR8L0OHJ5086:R@24SH`0Phb;
0829R01mQXD0NhB307^4PP80MGik00d0JgAa06E^J`1ZLg00JW=`06M`K@1SK6/0HV]Z05iWIP1LIF@0
GfYY06EdL@1VMG80H6m]0080H6i^00L0GF]/061^K`1QKg00H6i`05]YK01JJ6/0EVEW0080DV9R02@0
CemO04YJFP16EUH0@e=C04EEE@13De<0@E5A04ADE013DU80AE5A041<C00j@dD0>Sm203Hk?P0]<C@0
8b@X024R9P0U:Bh0<cPl02`d=`0^=ST0?454038g>P0R9bX08bP[030e>00oA4L0?4540456B@0k@4<0
;34d02X_<P0[<3<0:c4a02X`<00Y;bl202P^;P0>02T_;`0W;Bd09bd]02D[:`0R:2P092XZ02P^;P0c
>3/092T]02<X;00P9BT0:c0d02ld>00c>3`201hS9`0P02P]<@0W;3007B8V02da=00Y;Bh08RHW01hR
8`0L82406QhO028V9`0K7b00720Q02L[;00U:BX04QHG01dR7P0Q9R806AhJ01HH5@0J71`09BHX01`M
8@0K72407QlT01`M8P0I6B007QlS01dM700K6aT061PF01/K6@0J6QP201DE4`807QhL00@04a<A01hN
700E5A<05Q@E0`0G5AH02P0K6AX07Q`M01LE5P0I5aP061HG01HD5@0E4a@05Q@E01DD4P0K6QP201LF
500?01PG5@0E51805A@B01DD4P0G5Q@04a8@010?3@0D4a403@T801hJ6@0K5aH02PH501DA400J5QD0
5a<B00<05Q8A00l05a<B01D@400G4A406Q@D01H@400A2`/05Q0@01`F5P080P805@l?018<300Y8b<0
1@0001D?3`0G4A400`0F4100500C3@d0;bTY01dG5`070@406Q@D00X4100Z92@0@3Xk01D?4@0A2`d0
4`d?01LA4`0D3Ph03PD600X10P0I4@l05@/:01T?3P0E2`T05P`;0P0E2`X00`0D2PT05@/:01H<2`06
01@:2@0:02@J6@0;0@004PP802HL6`1AAdH05`d<01H<2`0D2PT04PP701@:2@805@/:00X04@L601D;
2P0D2PT04PP701@:2@0B20L03P@301881`0E2`X060h=0P0G3@`01P0A1`H04PP701881`0C2@P050X9
01D;2P804@L60P0@1PD01@0?1@@03P@301@:2@0D2PT04`T800<04PP700H04`T801471P0@1PD04@L6
01881`0@1PD201H<2`0J04To?P0n=3<04@L601881`0;0@0050X901P>3@0A1`H06a4@00/1000@10H0
3P840186200D20X05@T;01T=3`0A1@L040@601451`0C1`T05`/=01P<3P0B1`/03`@800d21P0>0`L2
01052@D04@H:01H04@L801861`0A1@L05@T;01<72@0A1PX05P/?01D:3P0C2Pl050/@01D?4`0B2a80
40H<01<8300A1PX03`@801T>4P0G31005@X>01/@500H3A4050T=0`0C20`201872`0W01462P0@1@T0
40D901052@0A1PX03P<701@93@0C20`03`@801051`0F2P`02P0000l51P0C1`T0200001@82P0<0080
710B01X>400:00004PH801861P0@1@<04`L701@82P0C1`T04@D801451`0W71X05@X501T?0`0R6@X0
6a<601TA000R6`T0>C8S01H?1@0=20803PL400804@H:00h04`H801D51P0G10H060D501hB4P070000
4PP701lE502l/[407A<B00d30P0>10<04@L601881`804`T80P0B1PP0200;0@80200002DI6`0<0080
4@D700l31@0A1@L030020P0G2`d201@82P804PH800P04@D701041P0C1`T03`@50186200M4A<05@T;
00`00QCooooo000Kooooo`0<028M6P0C3P`04@/<00X41`0H4QL04@XA024J8@0C3A803`T;01<=3`0H
4Q4071LE100@2P`2014;3@0:00h82P0A2`d04`d?01<=3`0?2@/03PP:028L7P0?2@/05Q0B00`72080
50h@00`04`d?01D?4@0@2P`03`T;01@>400E3a4050h@03Xd=P0F41803@L9010:300Q6ad3014;3@<0
4P`>01@06@hB01L<400E2Ph04PT<01<:3@0D2`h06A@E01<?400=2@X04a0@014=3P0E41404`d=014;
2`0C3@d04P`<01D?3`0G4A405@l?01<=3@<04P`<00T08A/L01LA4`0=1`T04P`>01XD5P0@2P`05@lA
01LA4`0C3@l00`0A2`d02P0D3Q003`T;014;3@0H4Q@02PD6010:300F41804P`>010:300B30h2010:
300901@?4@0=2@X05A4B018>3`0c;c00510A00l;300>2P/040`=00804@d>02005A4B00h:2@0A3@`0
40`;01@@3`0F4Q404@d=01<?3P0@30/03@T801PD4`0;1`H0<2`[01hH600H4Q805@l?01H@400C3@d0
4P`<01@>3P0A2`/040X:01<=3@0D3Ph03`T901<>2`0B3@X04`h;01HA3P0E40d04@`901@?30804`h;
01D05A0=01HA3P0D3``04a0;01<?2P0B3@L05@h701TA2P0M50d05@h601TD3P0D4`l040l=00d>3@0B
51<08b8P01HE4`0B4@l04a8@018A3`0?3P`00P0G5Q@05P0F5A<05A@B01DD4P0E5180<2`[02<P7`0H
5aD06APF01TI5`0F5Q@05aLE01@F4`0F61D05ALD01`Q7@0H6QL06aTG01`H5`0O6aX081`K01`H5`0H
51<301hJ6@0D01lK6P0P71/07ahL01TJ5`0O8Ah071hK030b;`0O8Ah0828O01LI5P0M7a`092HS02LY
9P0M7a`05QPE01XO6`0Q9B@082@S01/O7P0J7Ql201`P8@0j01lS9P0P92L07R8U01hR9@0Y;S@0:S4i
020W;`0O9bh092dd02L`=`0`>T00AU5G024^=00W=3X0:SLm049?E@0Y=C/0:SDk02Tf?00Z=cd0:cPn
02/j?`0c@TL0>dY?02i0A00]?d<0=DM;03A6BP0lCU<0RY^S09FV[P0oD5P0=TM?041AF@0jBe<0=dQ@
03U:DP0kC5@0>4UA03Y;D`0kBTl0?Da?03a;D@0mBe@0C5YU06ejR@1IIWP0EF9e055NLP1AGG80DEib
05ARM01PL7d0BeeW049DGP1;GFL0AUQR04AFH080@UAN0P18FV@02@14EV00AeUS04mPJ01<GFD0BEYR
04iOI`1FIfl0D65Y05AUK@0205=TK00^05QYL@1KK7@0G6ee05i/M@1KJG80GF]d05e/L`1LJg80H6mf
05QWK01SLWH0EfIY06UhN`1QL7<0GVa_06MbM01[MWP0KgYl06ehO01XLgL0I6mc06A_M@1_NX00Mh:8
071jP`1jQ8d0O8J?0;:la@2FX:T0OXRA07n8S`23S980PX^@0828R`1mQHL0M7an07UoO`1oQH@0Mgek
07MoP@1mQHL0PXZ<08F=S`26SY00QhnA08>;S@<0Q8b>0P23Rhd05@25SI00Q8b?08::S@2BVYd0Vj>V
08>;SP22RXd0Ph^>08F=T026SY40PXZ=0828R`2:Si<0QHZ>08B9S@22Qh/0RXnC08R=T@25RXh0R8fA
08N<T00208B9S@0V08F:SP22RXX0PX^:0829R01mQXD0O8F407n8Q`1nQhH0OHJ507^4P`1hPH00MGim
07=lN@1WL6/0IVm/06=/J@1TKFX0J75`06I_KP1TKF`0HFU[06=[K@1QJF/0H6QZ069]K@1RL700HFm_
05]YJ@1JJ6P0FfUZ05m]KP1TLW<0HW1c05]YK01DHVD0E65W05ETIP1AHF4204eMG@0B04]KF`14E5@0
A5AD04]KF`17EeL0A5AD04MGE`17EUH0?d]:03e7AP0h@D00=cdm03@i>@0^<3@0?d1503<e>P0_<cL0
;cDk0P0Z<SL02@0^<cL0;C4d02``<`0/<3<0;S8e03Pl?`0b=ST0=SXm03<g>P0202T]<00G030d=P0]
<C80:bl^02T];00X;2/0:Rh]02hb<@0U:BP0:Rh]02/_;P0S9bH09RXY034e=P1IGV409R/_02P]<@0[
<3@0:Bhb02`a=@0P9BT0<3Di01/P900d>Cd00P0W;300200Q9BP08RHY028V:@0R9RT08BDX020T9`0L
82<0;S8e0P0U:B`04@0N8RD0720R028X9`0M8R407b<R01PL700P8b@07b0R01/L7P0M7B008B4T01lN
8`0K6Qh081lS01lM7@0N7A/06aXH00807A`J00P061LE01/J600I61H04a8@01XI5`0L6aT061LE01PD
5@8071PI00/06QHG01LC500G4a@06QHG01/G600J5QL061@E01TE5P0J5QL051<A01PG5@0201LF5080
6APF00`05QDC01XI5`0N7A/06QTG01HE4`0H5aD0Ddm>01<?3P0Q7A`040`;01PD4`0D40l201DA4005
01@@3`0E4A005A4@01D@4@0D3Q000P0E3a408P0F4180618D01TC5@0>20X05@lA01HA4P0500406A<E
01<=3P0C3@d04@/;01D?3`0R71`071HF01TC4`0G4A404@/;01D?3`0>20P040X:01XB500F3A004@P;
0189300F3A005Pd>01L>3`0E30d05@d;01L?3@0=1@<04@T601L=300F30/301D;2P0301L=300D2PT0
50X900@050X900T04`T801061@0E2`X04`T801<:2@0C2@P05@/:01<9200D2PT00P0G3@`03P0C2@P0
4@L601@:2@0C2@P04PP701D;2P0D2PT03@<201H<2`0<0P406@l>01071P0J40l04@L61@0B20L03@0D
2PT04PP701471P0B20L05`d<01/A400G3@`05@/:01471P0@1PD04@L601881`0C2@P00P0A1`H201<9
200701061@0H3Pd03`D402/Q800R61L03P@301H<2`0201881`0:01061P0K4A005@/:01<9200I3@l0
4PH801H:300J3Q0050P:018620<050P:00@04`L90186200B1PP05P/?0P0@1@T00`0D2@d04`P<0105
2@0501872`0=01882@0G2@X05@H901P9300F2P`05@T=01H:3P0B1`/04`T?01@;400E31404@L?0147
3@0201P=4@0701052@0C20`050T=01@93@0F2`l050T=01872`0201052@0301462P0B1`/04@H:00<0
4@H:02@04`P<00l5200D2@d05P/?00/1100>0`L05`/>01@:2`0?1@H050T:01L;3@0L41803`@50186
200D20X040@601@82P0H30h04PP701<81P0D20P04`L:01862P0@10L050P:01<81`0F2`D040H002@L
2`28P6T0MVaG04U0:P0d:QX07aH=01P@2P0A2@L201462P0;01<62@0E1@L05PD601L51@0D20P04@L6
01481`0H3Pd0;B@T01<9200<0P800P0H3Pd02P0A1`H05P`;01D;2P0B20T04@D70147200K3a4040H7
01@82P0A1@L201D92`0301451`0K3a403@4300L04PH800D07a<E01@:2`0H30h03`<501041P0Doooo
o`006oooool04@0I5140100001@>3P0@2Ph0@C]00109400j<cX07QPM018<3P0F41804Pd;00X50P0E
3a4050h@018<3P0A2`d040X<00803`T;00<040X<014;3@0A2`d00P0?2@/04`21Ngd0E4i@00D00@0L
5QP0100000X41P0<1PP03@L900`6200`:R`0GeUK06YTIP0=1`T06A<E00@0000?2@/030H800l92`0B
30h00`0A2`d2010:300E01052@0E2Ph05@X>01<:3@0G3Q406a8E06aVJ00J5QL00`00018>3`0:1PL0
50l?014;2`0?2@T04P`<01<=3@0G4A406Q@D01D?3`0C3@d04@/;008040X:00<0:B<T02TS9@0@2P`0
0`0C3@l00`0E3a405Q0B01<=3`03014;3@0400X51P0S7Al02@<5014<3@805a4C02<03`T;01<=3`0D
3Q005@lA00d72@0>20X05A0A00X61`0@30d04Ph?03lk?00C3a00510A014=3P0B3Pl03`/<00X61`0?
2``020@3018>3@0A3@`05a<B00h:2@091@@06QHE01@@3`0C3`h00`0002LS8P0K5aH050h>018<300F
41006A<C01H@400201@>3P0601H@400H4Q805@l?01<=3@0E3`l04`h;0P0B3@X201<>2`0I010;200D
3``04`h;01<>2`0E40d05Q4>01@?300E4Pd05A4;01D@2P0G40P06Q8:01`C2P0G40P05a8<01@C3P0C
4Q004Q<B01<E500C4Q0051<A01LF500I61H05A@B01@C4@0201HE4`0901DD4P0D4a4051<A01<B400I
5A@06QLF01HE4`0C4Q005A@B00806QXH00H04aDB01LI5P0F61D06b0L01<E4P0N6aX201dI600401hJ
6@0L61L06QHE01`H5`806aLF010071PG01dI600L6aT071dK01PJ5`0P8Ql0=CLd01/M6P0L7Q/09BLT
024S800M7a`07b4N01XL6@0?4@h07B4P0P0U:BP0@00O8b807R8S024U9P0M8B@06alR01dP900P8bP0
8B@Y03Pm@`0l@dd0:S4k028Z<`0P:C808R/d02D_>00S;CH09S<k02dj@P0^>d<0:SLo02`h?`0[=S`0
9c@j02Pe>`0]>T00<D1502hm@P0`?d@0;3i203=5B@0nD5@0>D]?03e?E@0]?TH0<dA<041AF@0cA4`0
>T]C03m@F00nCeL0?4eE03Y;D`0kC5@0>T]B0350A@0hAdX0AUEK04aJH`19Ef80@TmO04eJJ`19EVL0
BeQY05ISL`1EHW80@4mL03a=E`1EIg40BE]U049DGP1NL7X0BUaV04MIH`16F68204QJI00704MIH`1@
HV`0CUmW04iOI`1AHVX0DV=[04mPJ002059SJ`07055RJP1BHf/0EfQ`05Y[L`1KK7@0Gfef05]YLP02
05aZL`0T05]ZLP1PKgH0FVU`06imPP1bPHH0Gfia05UXJ`1cPH@0G6MY06=]K`1XLW@0JG9g06QaMP1Y
LWL0G6E/079kPP1jPhX0Lgb5086:T`1nQi00QY2I08F?V026T9T0R96H08F>U01nQh`0PXZ=07MoPP1]
MGL0LgUi07b2P@1kPGl0Lg]m07R0PP1oQhT0Q8b>0P25SHl08@23Rhd0QHf?08J>T026SY00Ph^=08::
S01oQhT0R92B08nGV@22RX`0PHV;07j6R01oQhT0Q8b>0869R`23Rhd0R92B08J>T023R8`0PHJ:07Yo
P`22Qh/0RXnC08bAU@2<TIL0QHZ@0866S020QH/0OhB:07n4R01nQhP0OhV807j8Q`0307^5Q01I07V3
PP1hPX40M7im06miN01/MWD0Ig5^05YSGP1IHUd0FV=O05iWI01RJfX0H6QY061XJP1QJF`0J71c06I^
L@1SJfh0HVe^05e[J`1LJVX0FFMX05QVI`1KJFX0I79d069`L`1KJF`0FFI[05MTJP1BGfD0CE]N04UI
F@16EUH0C5aL051PH01=GEd0BEUI04]KF`18F5P0A5AD04IFEP14De<0=d=103I1?@0b>cP0;cDe02``
<@0X:Bd0<SDj028U:P0Z;cD0<CPn03M0A@0f?dD0<SLk02HZ;@0R9RT0;C4d02lc=P0[;c80<3@g03Di
?00i?D00;c<f02@X:`0P92H0;C4b02/_;P0Y;B`0:2`[02/_;P0_<c80;30_02/_;P0X;2/09RXY02P/
:`0[;c00=CXn02<X;P0W;3809BX`02T^=00W;380<SLm02<X;P1MHVP0T9FK02hc>@0P9BT00P0X;2l0
9@0V:Rd08bLZ01hR9@0I7B007b<V02@X:`0Q9BP04aLJ02@X:`0e>C`061dP01XP8@0V;2`07b<V03<g
>01ZKVl07b0R01LH6P0K6a/081hQ01`J700H5QL06QTG01`K6@0J6AL071/I01hM6`0L6aT061LE01DD
4P0J6AL08R4O01/J600R8Al061@E01/G600L61T00P0K5aP0200M6AX06ADF01XF5`0I5AH05a<D01TE
5P0L61T05QDC0P0G5Q@201DD4P0>01PG5@0A40h04a8@01HE4`0D4a404a8@01PG5@1SGeh07a/J02DQ
800B3Pd0<Rh]02/W9P0D40l301<?3P0501@@3`0F4A405@lA01<=3`0D3Q000`0F41804P0E3a406A<E
01<>3`0`:R`0100001`F5`0E3`l04`d=01PB4P0U7al081XJ01D?3`0>20P03@L701@>3P0@2PX05Q0@
01/D5@8050T=0P0F2`l00`0E2``04`T:01L=3P0201@<2P0300h6100E3@X050X900804`T800<04PP7
01<9200D2PT01P0D2PT0400F30/060h=00h4100K4A006Q0?01<92@0>10<050X901T?3P0E2`X04@L6
01<9200A1`H04`T801471P0?1@@301<9200500d5100J40l0CdE403H/:`0700000P0D2PT0300C2@P0
4PP701471P0A1`H03`D401061@0A1`H04`T801D;2P0F30/050X901881`803`D400d04PP701@:2@0B
20L04@L601<9200D2PT04`T801061@0?1@@060h=01<9200=0`806a4@00803P@300l04PP702DK6P0/
8R4040H501471P0>0P@040@601T=3`0M4A<050P:01451`0>0P@040@601<72@0F2P`00P0G2`d01P0H
3A4040D901052@0C20`03`@800X00`D04`P<01<04`T:01831@0@0@@0404401<41`0A1@T03P8601<7
2`0B1`d04@H<0107300A1`l03P@:01<72`0G2`l050P<01862P0C1`/04PH:00804@D900@04`L;01@8
300E2@d050P<1@0A1PX02@0>0`L06@hB00`11@0;00@06PlC00`11@0f;2d0/JFW02`P8P0201/?4@05
00P0000B1PP03@4300d10`0E2@/00P0D20X07@0J3`h060d;01<71`0@10P04@D901@73@0=0@<05PX:
01/A2@0]91D0Lf]F0>gXcP3oo^H0YYN003d_7@0C1P003@8001<92@0A1PX04@H<01862@0D1@P05@D6
01D51@0=0@404@L601@:2@0:00009Q`K00803`D400/07A<B01`B4@0@1PD05P`;01D;2P0900003`<5
024E5`080000710B00P0000201@82P03020D5P0F2P`04@D700<050P:0P0B1PP0200A1@L040@60186
200O4aD03P8401T=3`0=0P<050P:5?ooool001_ooooo00h03`/9018=2`0E3`l03PP<02hX;@0>1`l0
4``D01@=4`0D3Q003`T;00d81P0F4@h04`d=01<=3`804P`>00<04@/=010:300A2`d00`0B30h2014;
3@0B01D?4@0D3Q003PP:018<3P0:10H04@/=01PB500D3Q003PT:00l:2`0B30h04@/=00d72@0G4A<0
3PP:01<=3`0L5QP030H80P0A2`d2010:30804@/=00<04`P<01D:3P0E2Ph00P0C2Pd0400D2`h04@/=
01DA4P0@30d03@T:01DA4P0B3@d03`T900h8200B30`04@/;01<=3@0F410050h>018<300A2`/2010:
2P06014;300D3Q001`83014;3@0?2@/05a4C0`0?2@/2014;3@803PP:01004P`>010:300n>3X04P`>
01@>400?2@/030H800d72@0B30h04@/=01<=3`0D3a003`/<01DA4P0=2@X0510A0P0?2``0800;1`P0
4@d>01@@4@0B3Pl081`M01XF5@0K5aH03@T801HB4@0=2@P0;b`[04a8A`0F4a8071PG014=300E4A00
5Q8A01<=3@0B30`05Q0@01LA4@0B30`04@/;018<300D3Ph05Q0@018<300A2`/04`d=01LB3`0E40d0
4`h;0P0E40d06P0B3@X050l<01<>2`0C3P/05A0=01HA3P0D3``04Pl:01<?2@0C3PP05@h601L?1P0H
3`H05Pl701@@200B4@`04a8>018C4@0A4a804A0>01LF500920H06APF01HE4`0E518051<A0P0E5180
5P0D4a405A@B01DD4P0I5A@07A/I01XI5`0E518051<A01PH5P0V9R@0828O02`^:`0I6aP05AXF01HH
5@0H5A@061<B01TD500M61P07QTH01dH600N6AP201dH5`0601dH600N6AP07AXI01/L6@0b=34061XG
0P0M7a`0100K7AX071hK02DW900S9B8201XL6@0D01hP7@0I7A`0720O01dQ800L8200720Q01dQ8P0S
9bX07R8U01lR9P0Q92T082<X02<X;`0O9S0082La02Ta>`0S;3D08BXc02Pa>P0V<3T202Hc>`1002Db
>P0Q;SH0:3@k02/f?00Y=S`0;3To034nA00c@TL0>4M<045@E@0eAd/0<D=703mAE@0nD5@0>TaB03I7
C`10DET0=TM?04AEG@1@HFT0?DiF041AF@0iBU80<dA<03M8D00fAdh0=dI;03]:C@15E5`0CUaW04mM
JP1;F6P0AeAT04eJJP1<FVP0@e5L04=BF`14E5`0AUMP04UKI011E5`0?U1I04AGG`14EUl0B5YS04AG
G`15Ef00BUaU04]NIP1DIVl0DV=[05AUK@1IJW80EVM_04UJHP1CI6`0DV=[055RJP1BHf/0EFI^05QY
L@1IJW80G6Yd05UWL@80GVae01@0GF]c061_MP1TLgX0GVec07Z9SP1]O800Gfib09^Y[01`Ngd0JG=e
069/KP1SK740JgAi071iOP1[M7/0OXN>08RAV01mQXl0PHZC0829TP<0P8ZC00l0P8V@08:;T@24SI80
Ph^>07R0P`1`N7X0LgUi07QnO@1lPX00NX:407b4QP21RH/0QXj@08F=S`22RX`00P25SHl208J>T005
08F=S`24S8h0P8R:08VAT`2BVY`00P23Rhd03P26SY00Nh>508J>T028T980Q8b>0869R`22RX`0Qhb@
08F:SP23R8`0Ri2D0825RP26Ri00Q8V?0P1oQ8X01020QH`0NWn607=jO`1hPH8207f7QP0Y07Z4P`1g
PH00MX1o07AnO@1cOG`0LG]j06egMP1[MG@0J79_061YI01QJVD0GfQT061YIP1WL6l0IFe^069ZK01Q
JF`0IVib06A/L01RJFl0HFa^05]YJ@1JJ6P0FfUZ05MUIP1IIfT0Gfe`05UWJP1DHFH0EVAY05QUJ`1B
GfD0C5]N04YJFP18F5P0AUIF04EEE@12DU80A5AD04YJFP18F5P00P14E5@0M00oCTh0=D0o03I0?00g
?C/0=3Pi034e=P0`<CD0=STn02X]<P0g?D<0:C0f02hg?00d?T<0OhB805IJG@0W:bh0:2`_02``<`0Y
;C00:2`_02da=00f>Sd0<CDh02HZ;@0R9RP0;C4b02da<00[;bh0:Rh]02/_;P0^<S40;30_02HZ:@0Q
9B@09BTX02P/:`0T:2T09BX^02T^=00/<CL092T_02T^=00S:2h092T_02H[<@0U:S00<SLm02P]<`0P
9B/09RT^02DY;@0U:2`08bL[024T:00N8RH061`P03/o@`1lP8@0;C4e020S9`0I7B408BHY01dS9`0I
7R80<SHj02DZ;@0R9RP0;Bh`01lP8@0O7ah09B<S028P800N71X06ALE01dJ6@0I5aD06AHE01/I5`0J
5aH07Q`J02LU8`0O7A/05Q@B01lL6`0F4a806QDG01/F5`0J5AL061<E01TD5P0J5AL061<E01PC500G
4Q<05Q4C01TD5P0L61T05A@B01@C4@0G5Q@051<A01DD4P0J6AL05A@B01HE4`0I61H051<A014@3P0D
4a405A4@00h:2@0H51<03`/:028N7@0P71/05A4@0`0D40l03P0E4A005A0A01@>400C3@l050h@01D?
4@0F41806A<E018=3P0^:2X0EU1B01lI6`1@BT`0618C0P0A2`/01`0E3`l04P`<01<=3@0C3@d05Q0@
01D?3`0?2@T00P0H4Q803@0B2@/05@X>01H:3P0G2`l05P/?01H<3@0G3@h050X;01<;2@0>1P@08ATG
00d50P0D2PT00P0C2@P00`0B20L04`T801@:2@0601@:2@0@01071`0F30/05@/:01@:2@0H3Pd050X9
00h40`0D2PT06Q0?01<9200@1PD05@/:01H<2`0G3@`04`T800l510804`T800X04PP701@:2@0B20L0
7A@D01P?3P0E2`X040H501471P0B20L04`T80`0D2PT201D;2P0301@:2@0B20L03`D400804PP70P0A
1`H05@0B20L04`T801881`0B20L050X901H<2`0D2PT040H501`B4@0A1`L04PP700/20P0@1PD04PP7
01L=300B20P04PP701071`0D2PT03`D401451`0201<72@0601041P0G2`d08QHH01H:300D20X04`L9
0P0B1PP01`0C1`T04`P<01462P0B1`/04`P<01872`0@1@T01@0A1PX03P0B1PP05`P901D62@0D1@P0
70d@01/?4`0E2@d04`L;01<83P0B1`d040H;01473`0B1Pd04`L;0P0F2Ph00`0B1PX04@D901<72`03
01<72`804PH:00@04@D901052@0A1PX04@H:0P0B1`/0900I3Q809Q/O01472P0H3Q40=2T]01hC5`0?
1PL0@SHh00`20`0@1@L07A4C01@82P0C20T03P8401hB500m<C<04`P900/10P0R5QD05P/701861P0@
10P04@D901<6300C1`/060`<01lE3@0b:AP0DTXd0<S3Y`3XglD0PW5I02PH2@0L3PD070l900l41080
4@H<01/04@L90186200C1`D04`L401@9200?1@@04@P701@;2`0L4Q404PP801061@0C2@P04PP700l5
100B20L050X901061`0K3a4050T;08=gN@0O5AH05PX<01<72@0@1@H06`lA01041P0=0P@00`0C1`T3
0186200701451`0A1PL05PX<01/A4P0n<S@06`lA00h3100Dooooo`006oooool0;P0A2@L06Q<B00@0
000L4aH02P8801H?5P0B21003PH<01LA4`0N5AH06A8A018=2P0=1`T03PP;00l92`0A2`l04`d@01<=
3`0B31004P`?018<3P0B30l04P`@018<3P0@2P`04`X=02@N800=1PP07A@G01<=3`0[8bH06A0C00h8
2P0<1@L04PT<01H@4P0B2`d04PT<00P2100P61/0@cXm01D?4@0@2@/04@P;010:300B2Pd201<:3@0<
01@93@0E2Ph05P/?01D<3`0D2`h04`X=01L?4P0400004@/=00h82P0I4aD03`P80P0A20T01P0C2P/0
3PD600d41@0A2`/04P`>014;3@8040X<0P0A2`d0200P6Q`04@/=00d72@0600805Q0B00`6200@2P`0
4@/=0P0E3a40;P0B30h03@L901XD5P0800805@h@01LA4`0e;2l05`lB014;3@0?1PT04@T<00h82P0?
1PT04`d?010:300>20X06aDG00T31@0C3@l0618D018<3P0C3@l040X<00/51`0L5QP040`=01DA4P0C
3`l07ATJ00<0000T81l0>cLf02`X9`0G4a803PX901PD4`0?2`X04P`<00l92@0A2`/04P`<010:2P0E
3`l05Q0@01<=3@0B30`201H@4004014;2`0E3`l04`h;014<2@804Pd:00T040/801@?300C3P/04`h;
01D@3@0F4@h050l<014=2P0B3PX00P0C3PP201H?1`0>01L@2P0H50h05a@?018A3@0@40h051@D01XI
5`0C4Q4071/I08Z9Q`0G5Q@06aXH018A3`0C4Q0201@C4@0701DD4P0F5A<06aLF01LE4`0E51805QDC
01TH5P0201XJ600>014A3`0U9b@04Q<@018D4@0L71X06aPG01`H5`0M6AP07a/J01/G5P0H51<081`K
01lK6P0N6QT201lK6P0>020L6`0L71X07QhL01lQ7P0H6AH07AlL01`N6`0O8Ah05aTF01lQ7P0S9B80
6Q`I01LI5P0O8b8201dQ8003020T9@0Q9BH08BDV00807R8U00L08bL[02DZ;P0S9R/082H]01`S:`0Q
:300;3@l00809Bhe00<0:C<j03]6C00O;3@00P0^>d<01P11CUH08c0g02Tf?00/>Cl0<3e3034nA080
;Se20300>TU>03A6BP0bA4P0?DmC03I8C00bA4T0<D9:03Y;D`0fAdl0<45903a=E@16Eel0BU]U045B
G00gB580?TmI03e>F00jB540?deF04MEH@17EF80B5EU04iKJ`16E640BUQU04UGH@17EUd0BEQO03e<
DP0nCeH0?4mF03e?EP14EEd0B5YT04IGH@1>GfT0AeUS04MIH@1<GFD0BEaS04QIH018FF40B5UP055R
JP1FIfl0B5UP05=TK01DIFd205=TJ`0305EVKP1GJ6l0F6Ua0080F6I_02L0GVed061^M`1MK7<0Gfie
05]ZL@1UM7X0FfY_06akP01NKG80Gfe`06IaM@1SKFl0IW1b06efN`1_N7d0JW=h06UbN@1eOXD0PhbC
07IoR01gP8T0OXN@0869U01oR980PHZC08B=UP28TIP0R96F08bCV@26SY40OXJ807b2PP1lPX40PhV9
07InP01hP880OhN908R@TP27Si401`25SHl07P21RX/0OhN:07f7R024SHl0Ri>F07Z4Q@1oR8X0OhN:
08B>S`25SY00Q8b?08VAU025S980OXF;07f4RP24Ri40NX6708bCV@2DW:00PXZ=07Z2Q@1eOH00K7Ag
06I^L@1aO7T0N8=o07Z5P@1gPWh0LWei06mjMP80KWUe01<0KgUh06ihM`1]MgH0K7Md06IaJ`1YM700
HfiZ065/J01YLg80J79b069/K@1OJFX0Hfe_06MaL`1[MGL0J7Ae05]YJP1JJ6T0FfUZ0080Df5T02h0
E69U051NH@1AGV@0Df1V059OI@1?G680BeUL04QHF018EUL0AEAC04=AD@14DU80@Dm?041>CP11Cdl0
?D];03]9BP0d@D80;cXf034j=`0d>SP0<cTi03<g>P0d=c`0=3Ln02`a=`0m@T/09bhd03i7C01cO880
=c`o030d=@0/<3<092P[01dR9@0`=CP0;34d02/`<`0_=3L0:B`a01lR9`0T9b/0;S8c02`b<00]<C00
;30_0P0[;bh0500W:bX092PW028V9@0U:BP0:Bh]02T_;`0W;2l0724U02L/<00X;C40;34e02T^<P0c
>3`0724U030e>@0T:Bd08bP/02T^<P0P8bP082@W0P0Q9BP2028V:@0P03<d>00S92P0MGIj01<D600X
:Bd08b@X02d`=@1:CU<03a8G01`P8`0F61/071dO02TZ;00P81l06a/I01XI5`0J5aD07QXG024N7@0U
8B007A`J01XG5P0K5aH061LE01TG5@0O6aX05A@B03/i=`1RGUd0;BTX01LB500L5QP201dG6@0401`F
600M5aT05a4C01H@4P805@lA01806A<E01/G600C41404@l@01HE4`0E4a<05aHD01hM6`0=30X051<A
01XI5@0F5A4040l;018A3@0@30/06ADD00l;2P0B3Pd201PD4`805Q0@00D05@l?01H@400F41004`d>
014;3@0201<=3`0601@>400H4Q@05@lA01LA4`0Q6ad0H5YL0P0?2@/06@0H4Q<03`T901@>3P0L5QH0
3`T901PB4P0b;2`04Ph=00D1000K5aH02PH500D1000F3Q005`/?01H:3P0D20`05PX>01X@4@0N51D0
40H701D=2`0I4@l0Aclm01P@3P0E2`X00P0D2PT00`0C2@P050X901D;2P0601@:2@0901X?3@0B1`D0
6@l=01<9200D2PT050`:018:200C2`T050`900<04`/800@06a4@01`B4@0F30/04@L60P0D2PT01P0E
2`X04@L601H<2`0B20L04`T800/100804PP70P0@1PD0200?1@@03P@301061@0A1`H04PP701<9200F
30/05`d<0P0C2@P08`0B20L04@L600l5100=0`804PP701<9200E2`X05P`;01@:2@0?1@@04@L601<:
2@0E2`X04@L601P>3@0=0`80:R0O01P>3@0l<S405`d<00l5100C2@P04@D701<72@0?0`D050P:03da
<`1LD58050P:01451`0@10H04PH801D92`0F2P`040D900804PL;0P0?10P00`0@1@T04`P<01<83003
01<8300801@8300D1@P04P<601831P0L3A00710D01D93@0@10P201H;4@0301<83P0@1@/04@H;0080
3`<700H04PH:01<72`0D20`05@T=01862P0C1`/201@8300501<72`0B1PX040D901052@0A1PX00P0B
1`/0900@1@T04`P<01X?4`0D2@d02`0401872`0G30l0200001lC5@0?1@H04`L900P0000J3Q006@d?
00d10`0C1`T0710B01041P0@10<040D301861`0B1PP040@800h21P0;00408QHF01@:0`0K4@D05a00
03D/601KC3T09aH401L7000A0P003@0001H:2`804@H:00`04@L801861P0B1`D04PL400T0000B20L0
5P`;01881`0700004@L601/A400D2PT201061@0800h40`0A1`H07A4C01T=3`0>0P@0<RHX0186200I
3@l201@82P0600h2100:000060`>00`00P0@10H04@D70P0B1PP201@82P804PH800@0300202@H6P08
00007A4C5?ooool001_ooooo0P0C2@X01`0B2@X04`T:01<9300B2@`04`P<01<9300B2@X00P0C2@X0
8`0B2@X03`T=014<4@0>2@d03`X@018=4P0;1PX05A0F00`7300D3a<05A0E01<>500C3A403`H901@9
3@0F3A005`dA01D:3P0C2Pd040H901462P0@1`X05`d@01462P0E30l04PP901@:2`0G3Pl071<D01X@
4@0E30d050X;01D;300D2``05@`=00805P`=1P0C2@X0600H3Pl05@`=00X10P0D2``05Pd>0187200E
2@T050P801871`0D2PT05@/<00d51P0F3A803`T=01H@500?2Ph06QDK03dh>`0C3@d03@L701@>3P0B
30`050h>014;2`<040X:00l04@/;01<=3@0C2`d04`X=01<8300?1@T05@`?01T>4P0P5QT02`8501<8
300G3A005@`?01lD600?1PT0100D2`h0100C2Pd04PT<01<:3@0D2`h20189300E01@;3P0C3A404`dA
01@>4@0D3Q804`d?018<3P0@2P`050h@01LA4@0C3@d04@/;018<2`0;1@D05Q0B00l:2`0M5aT04P`>
014;3@0B30h04`d?00<05@lA00<04`d>01@>3P0D3Ph00`0D3Ph0800E3`l04@/;01D?3`0H4Q806A<C
01H@400C3@d05a<B00`81P0O6aP09b<P01hI5P0V8Ah07APE01TF500:1P<06aLF010?3@0A40h05Q8A
01DA400L61L07ATH01LC4P0D40l061@C01TE500F4Q404Ph=01<?3P0I5A@040l=0P0C4Q008`0M71X0
5QDC018A3`0K6QP06APF01PH5P0K6aT06ATG01PH5P0J6AL061LE01hM6`0O7Q`06APF01LF500J6AL0
5aHD014@3P0K6QP08R4O01/J600M71X0:BPV00T91`0M71X07alM01PH5P0T92803@l<028T8@0f>3D0
9BXV014F4P0O82406a`N00807b0R02007b<V02HZ;@0_=3P07R<W01`Q9P0K8RP09BX`01dT:@0Q:B`0
8RX]02@];`0V<380:34f02La=P16DED0>DI<02Ld>P0^>d408c0f02/h?P0Y>3d0:cXo02`k@00T<cP0
9cHk030oA01>GF80EVEZ03=2A`0eA4T0>dY?03E6BP80<dA;02d0>4U@03Q9D@0nCeT0AEIP03e=FP0j
BUL0A5AR03A4D`14E6<0=d=I04QDJP1BGW<0CEY]05ISM00oC5/0AeEP04aJH`1JJG00BeYO04ACF013
DUT0AUEL04=DF`15EEd0BUQS04YJI`1<FVX0CEYZ04MGIP15EF00BEMP04YKH`1=G680BeYQ04IEFP16
EE/0EfI]059QIP1IJ6h0Hg9i05QWK01GIV`0Gfie05YYKP1HIfh00P1]NX809P1IIV`0FfQ`05]XKP1L
JFl0GV]a05QUJ`1SL7H0GFY`05m/LP1RL7<0Ig9f06=^L@1LIf/0JGAh06UdN@1[MW`0JGAj07F0Q`1h
PX/0NhF>082:T`1lQ8l0MWj;08fDXP24RYP0PHNC0827T@2AV:00P8N=08N?TP21RH/0MWmn07f6Q@2B
ViX0MWj007b4QP23Rhd0QhnA0P26SY005P23Rhd0QXj@08B<SP1oQhT0P8R:08::S021S8h0PhbA08RC
U@20RXd0PX^@082;S@1oRH`0PX^@086<SP27TID0R96F08><T@23S9@0PX^B086:T@20RHl2086:S`0T
07b6R01hPX40N8:107R3P01XLfl0KWUe06ikM@1bOgP0Kgae079oMP1gQ7X0Hg1V06ikLP1OK6D0JWIc
06QdLP1ULG40I71^06IbKP1QKF/0GVYX06=_K@1ULFl0IW9`069^K01MJFL0GVYZ05m[J`1RKVh0HFma
065`L`1JJF`0EfIY05QWK01DHfP0EFAY0P1@Gf@0A@1CHVL0DV5V04]JG`17EEP0AE=D04eIF@17E580
@4a:04=?B`11CDT0@Ti:03e7AP0jA4<0>TA503Q0@`0c?3T0;CHa02Xc<@0lA4H0>d1603m3C00[;cX0
B4mI02/b?00j@DT0@dYB07^3Q`0_<c@0;C4`02X_;`0/<S80;SLf02/c=@1iPH@0CeMJ01dT9`0O92X0
:Rdd02`_=@0]<SD0:C8a02L];@0V:R/09b//02//;P0Q8R@08R<U024U9P0O9BD08RTY02@];00V;b`0
8b`Y028[:00Y<S40:c@c01/T8`0X<C009Rh_01/S9@0L92H09Rh`02H/;00R9RL07R0R02h_<@0b<cD0
92DW01lP8P04024Q8`05028Q900S8B@08R8R020P800M7Ad00P0L71`0=00M7Ad07alO01dL6P0G5Q@0
6APF01`K6@0E5180<2l_02/Y:P0A4A407ahN01hL7@0E5AD06QTI01`J6`0A4A40;2/[03dk?00M6a`0
5Q8A04I2@@1@C4/0920O051<B`1?BdX07a/J00X61@0N6QT06QHE01DA400?2``05a8F01TD600I5AH0
5a8E01HB4@0G4a804@d:01TE4P0H5A004Pl:01HC3P0L6A@051<@014@3P0C4@l05Q8A01LA4@0U7al0
;RDV020G600F3@h201`B4`0=01L>3`0E3`l06A<C01D?3`0A2`/050h>014;2`0I4a<071HF01TC4`0A
2`/02`D501@=3@0201H=3P0F01@=3@0B30`04@d<00l;2P0H5aD05A@B010?3@0E51807AdK00/61P0R
61T03P@501D<3@0O5AH060h?01D;300D2P/05@/<01P>3`0G3@h03`D501@:2@804`T800T05P`;01P>
3@0G3@`05@/:01`B4@0B20L06@l>01471P0E2`T00P0F20D02`0H3@`01`0000h60`0B3@X06AHA00d:
1@15@SX0:BDL01`H3@0F4PP04`T700804`L700L04PH601<71`0D20P03`<301H:2P0I3@d05`/;0080
5@T901404PH60104100=0@404`L701L;2`0900005@T901H:2P0D20P04PH601<71`0F2PX05@T;0104
1P0C1`T05@T;01<72@0201@82P804`L90P0D20X03@0B1PP04@D701H:300@10H03`<501L;3@0I3@l0
200001hB501<@480710B00T0000L41800`0A1@T00`0C1`/050P<01@8300601862P804@D900h04PH:
01@8300F2Ph05PX>01L=3`0A1@T05PX>00`2100R5QX03P8601862P0@10P07Q8F01882P803@4500`0
50P<01452@0@10P04@D901<72`0N4QH08aLK01`@500C1`/040@801862P0D20`20104200:01@8300@
10P040@801<72P0Q5AL04@D701061`0D20X02`0101H:308040@600@060d>02/O8@08000050P:1@0A
1@L00`0@10H04@D701lC5@0201<72@0300X0000A10D04`D500<04`@702D04@D700l51P0@1PL04PP7
01<91`0E3PP071<=01T<1P0H2`D05@L501<5100A1@D04PH601@8200B1PH050P701@91`0@1@4040D2
01<71`0B1PP04`L901@82P0C1`T040@60555A`1ODeD05P/<00T0000I3@l03@4301041P0E2@/03P<4
06eQH`0Z7R003@4300H03`<500D0:1`N01lC5@0B1PP05`/=01lC5@0301451`804PH80P0C1`TDoooo
o`006oooool;01<92P060189300>20`040/@00h93P0?2Pl04PdB0`0@2a001@0D3a@08alS01lJ7`0?
2Pd050X=00<050T=0P0C20`0300M4QH05``@01462P0E2Ph03`@801D:3P0D2P/05@/<01P>3`0K4A80
5`d>01D;30804PP90P0C2@X201@:2`H04`T:01L050X;00`20`0Q5aP040L801X@4@0E2@X050H70185
1P0D20T05PX;01D:3@0B2@/05@`@014;401?BDh071LL00d93@15@4<03PP800d71`0C3@d03`T9018<
3002014;2`8040X:00<04@/;018<300C2P`00P0D2@d02`0B1`/05``@01P=4@0E2Ph060dA01D:3P0a
9bX08AHJ00T00P0H3A405@X>00805P/?0P0G31000`0C20`050T=01D:3P0201<8300E01@:3P0J41P0
5PlF01@>4P0A2`l040X>010:300B30h050h@01H@400C3@d04@/;018=2P0M5aT0>C<e01<=3`0I4aD0
40X<014;3@0D3Q005@lA00805Q0B0P0E3a40200J51@05a4A01<=3@0@2PX04`d=01D?3`0B30`04`d=
0P0E3`l201@>3P80510?0P0?2`X0900G4a806QHE04M3@P0`;2/06ADD01<?3P0E4A0061@C01/G5P0E
4A005Q8A01PD4`0G4a806ADD01hJ6@0A3@`07QXI02@P7`0I5A@061@C01HE4`0G5Q@04A0>01PG5@0E
51805aHD01PG5@0F5A<05aHD01TH5P0H5aD05QDC01TI5`0H61H07AdK01hN70<061PF00l05QHD024Q
7`0K6aT06a/I02/[:@0O6aX05QDC01TH5P0O7Q`06QXH020P7P0J6QP071hK02DW900R92400P0M8Qh0
CP0S92H07AhP024R900T9BL08RHY02DY;010ADT06b0T02@Z;`0L8bT082L]024Y;00Q:B/08b/]02D^
<00W<C809c4c02<]<01OJVh0H6ia02@b=P0[>3h0;CY002`j?`0Y>3d0;3]002dl@@0X=c`0;3]00391
AP0hAd`0>dY?03M6B`0hAd`0>dY?03M8C00eAd/0>D]@03i?EP0hBE00=TM@03a<F00jBUL0=DED03i>
GP0iBET0FFUj05AON`18Dfl0CEUc082<X@1RKh00B5IR04ABF`12DEP0BUUN041?E011D5D0AEAK04ED
F@17EU/0BeUQ04iLI`1@GV/0D5e/051MKP1=FVT0BUQT04]IHP1<Ff80C5]O04]JG`1>GF80BeYO055P
I@1;FUl0EFAY05MVJ`80EVEZ0300FVU^05a[L01LJg00EV=Y05m/LP1HIF/0GV]a05aYK`1JIfd0IW=i
05m/LP1VLgT0H6ec06AaM`1VM7L0JWEi06E`LP27TYD0GVU]06]fNP1XLgP0KGQn07=mQ@1fP8T0NhF>
08>=UP21RiD0Vj6_0;[0c`23RIL0NX2<08jEX021R900PhZ@08:9SP1mQHL0Nh>507b5Q01oR8L0NX:4
07j6R023Rhd0QXj@08F=S`24S8h0QHf?08R@TP27Si4208::S00>08>=SP1oRHh0P8^?07j9S@2AW:00
P8^?07N2QP1mR8`0O8N;07f8S01kQXX0O8N;08:=T`1oRI<207n9TP0E07n:T01oRXh0OhZ<086=S02M
ZJL0QI6=06YgL01RKfL0KW]c06MdK@1/NG00L7ed06QeJ`1ULfH0GFYO05aYG`1LJF80GVYV05m[J@1`
O7`0FFMU00<0GVeZ00D0I7=`06=bK`1OKV/0FFQU05MVH`0205YYIP0^05]ZI`1LJf`0Gfic05YYKP1F
IFX0DV5V04aKH01BHFH0Df9W059QIP1:FEh0AeIK04aKH01MJVd0BeIH04A@D01>FUL0AU9>04YEC`15
CdX0>dE003Y3@00k@T80>3m103Dj?@0`>CD0=Chi02lh=P0`>3/0;C@j02he?P1<DUh0<CM303@kAP0`
=cl0>D16030f>`0^<S<0:bl^02P];00Y<S40:S<b02H`<@1NJ6X0AU1B02dd>P80;c@j0240:R/d02hd
=`0[=3<0:S0`02P/;@0W:b`0:R/]02DV:00W:2X09BTZ01lU9@0Q:BP09S0_024Z:00W<2d0:C8`028[
:@0N9bD09c0^02</:P0V;bl08b//028[:`0S;2`07RLV02DY:00P8b80;2h]02la<00U9RH08R8R020P
800Q82000P0Q7b00100R7b008alP024P7P0O7Q`201hM6`0>020O7@0Q81h07ahL01`K6@0N7A/07A`J
01PG5@0G5Q@071`L01LG5`0N7Qh061PH02DU9@0L71`301PH600I018B4P0K6a/061PH01PD4`0N6QT0
8alN01HB4@0Q7A`0510?018>3@0N6QT0510?01<?3`0N6QT0920P01XF600K5aT06ADG01DA4`0C3`h0
510?01HB3`0E4@h05Q8>01PD3`0201LD400A01@C4@0A40h04a4?01HB4@0F41006Q8C01/B4`0G3@h0
5P`=01dB500M4A<05@`=01PB4P0K5AD091hN01LA4@0>20P00P0D3Ph01@0B30`0618B01TC4`0@2PX0
50d=00805Pd>00h050d=01<=3@0B3@`05A4@00l>300<2`T07A`J06=SH@1kO7T09R4Q01P>3`0_9BH0
91XK00h41@805@/<0P0F30d01@0E2``050X;01882@0I3`h05`d<00<05@/:01@04`T801P>3@0H3Pd0
4`T801471P0E2`X050T801d?300:00005P/801TA3P0B3@X040`:014@301?CTT0f]SA04=0=P0A3P<0
4Pd301<91`804`L701404PH601<71`0D20P05@T901H:2P0C1`L04PH601D92@0J3Ph05@T901L;2`0B
1PH04@D501@8200B1PH05@T901<71`0201451@0801@8200E2@T050P:01H:300H30h050P:01041P0F
2P`201<72@060186200A1@L04PH80186200?0`D050P:0P0A1@L0300C1`T03P8404<g>@0L4A80710B
01D92`0@1@H040@601<72`0B1PX04@D901862P804`L;1P0B1PX04P0C1`/050P<01D93@0E2@d04PH:
01452@0G30l05P`>0104200?10L06`lC01452@1jKW808ADI00l51`0<0P@05`/?01@:30T04PH:00<0
4@D90104200B1PX00P0@10P0400C1`/040@80104200C20/04@D700/00@0E2@/02P0102`P8P1:?T00
4`L901041P0^8bD0B3`n01P<3P0A1PP501451`0701041P0P51H0;R8T00l51P0H30h04`L901851`04
01<41`0401451`0B20T04`T:01<92P8040L800@050/<01H:300E2@/04`L90P0A1@L02@0B1PH04PL5
00l40P0A1P@050T501870`0D2@H060`<01D92`0201041P804PH800`05@/<01@82P0C1`T06@d?00h4
1@0C20T02`4201H<3@0G30h0LFEW03<X:@0=0P<601451`0501L;3@0A1@L03P840186200D20X00`0A
1@L2018620804`L95?ooool001_ooooo2`0C2@X03P0B2@X07ALK018=4@0P6al07aXN014<400M61`0
50lC00h93@0?2Ph061<G01@?4`090`L04`T<0`0E2Ph03@0C20`04PL;01/@500F2`l04@H:01H;3`0B
1`/060dA01D;300F30d05`d>01P>3`0D2P/00P0C2@X201@:2`<05@/<1P0C2@X06@0A1`P03083028H
6@0K4A806@l@01H;3@0F1`X04PH:01L;3P0G2`l05@X>01/A5@0800805@lA01hH6`0F41806aHJ00/7
1`0:10@03`T9018<300<1PH04@/;018<300A2`/00P0@2PX05`0A2`/04P`<01882`0D2@d05@X>01@9
3@0G31005P/?01P=4@0=0PH040D9028G6`0E2Ph03`@801<8300D2@d05P/?01L<400H3A406@hB01<8
300D2@d05@X>00804`P<00L050X>01H<500C31<04@/?010:3P0A2`l05@lA00804`d?00X04`d=018<
300A2`/04@`905==C`1FD58050h@00P210090`D06Q@F0P0E3a4201H@4P805@lA00P0618B01H@400C
3@d04@/;01<=3@0E3`l050h>01<=3@804P`<00l050h>01H@400>2PT05A4@010<2`0>2PT061@C01dI
6024P7l0G5QG02LS8P0F4Q4061@C02@P7`0L61L00P0D40l02@0E4A005Q8A01XF5@0e<C00920O096=
S02FTY4081`K01DA4002028Q7`0S01PG5@0K6QP05A@B01TH5P0J6AL05aHD01PG5@0J6AL06APF01PG
5@0J6QP061PF01`L6P0K6aT061PF01XJ600L71X04Q8@01TI5`0F5Q@0;Rh/05=CD@0T81l0:BPV010?
3@0Q81h05QHD020P7P0N7Q`06adJ01lQ7P0S9B8082DQ01dR7P0U9RP00P0N7b401P0Q8R@0720S01XN
8@0C61`0:2da02<Y;P807bH/00l07BDX028Z;00U;Bl0:34c02Pb<`0W<C<09c8e01hY;@0F92L0;3Tn
028_=@0L:Bl0;3Y002Pg?00[>Sl00P0/>d008P0_?T<0=DA902hm@P0gAT/0DF1U03i=DP0c@TL0=TI;
03E7B`0fB4`0>4U?03Q9D00jBe<0?4eF03Y:E`0gAeH0?TiN03e=G@1PL840JWJ@04aGL`18E6d0IW>6
04UFIP0iAe80DEmX04IEG011D5D0>4M<03e<D@13DUP0AUEH04UHF`1=G68204iLI@0A04iLI`1=FfH0
C5YU04UGH@17EUd0AUEJ04IEF011D5D0CUeR04]JG`1?GV<0D5mT06MfN`1@Gf@0FFQ]05YYKP1GIV/0
0P1OKW<0FP1DHFL0GFY`05aYK`1RKgD0FVM]05QUJ`1SL7H0G6U_065^M01NJg40IG9h06AbM@1ZMGL0
JGAf096LWP1^NGd0JWEi06mjOP1^NGl0LWb407N1RP1lQXl0PXbE08:<UP1eNhT0QXbJ0826TP24RYH0
QHbE08N>UP29T9H0PhZ?0828R`21RH/0PHZ907b5Q01nQXP0PHV;08>;S@24S8h0PXZ<0869R`22RX`0
QXj@08F=S`20R8X0OhN9082:S025Si80SiZN07AoP`25T9@0Mh:608:=T@1kQXX0NXF908>>TP21S900
RYFI09bWZ`1kQXd0O8J?07b7S@1mR8d0OHR:07b7R@1mRHP0OHV506ijMP1ZMg00H6eV065^I`1SL6T0
FfQQ06IcJP1PKF<0GF]N05]XG@1@GE<0C5UB05]XH`1AGE/0Hfm_05aZJ01IJ6D0G6]X05m^J`1RLFh0
GVeZ05MVH`80Df9O00T0FFQU05QWI01FIF80FVUZ05e/L@1EI6T0DF1U04aKH01:FEh00P1CHVL0B01A
H6D0AeIK049AEP1:FEh0G6U/04]FF011CDd0AE5@03i:AP0oBT@0@D]503]4?`0]=S@0;34d03<h>`0n
@dL0>44n02Pa;P0T;B`0>d=603<j@00c>T<0<SU303DlAP0e?4D0SiJL0;c3b@0i@4<0:bl`02HZ:@0W
;2/0:c@c02Xc<P0W<C8072HX02H`<P0_=S`09R/a020U:`0];cL0:Rlb02Pa<00W;Bd09BTZ02DV:00T
92H0820R02@T9P0T9RP0728R01hV9@0W<2l0>T=2028[:`0U;Rd0:c<e02</;00U;Bl09Rh`02<[;@0M
9BL07bLY02Ta<`0e>Sd08BDV01dP7`0S9B@09BLV020Q800P82007alO01lN7`807adN00@081dN020L
7@0N7A/07A`J0P0K6QP04@0M71X07QdK03Th=P0O7Q`06QTG01/J600G5Q@08b8P01<C4`0?3`l06QXJ
01LG5`0N7Qh0820P01/K6`0D51@07AdM00806a/K02X05QHF01/G5P0K5aH06ADD01XF5@0K5aH081`K
01XF5@0A3@`08AdL028N7@0C3`h06aLF01DA400H51D061@C01LC4`0G4a8061@C01LC4P0D40l05A4>
01LC4@0E4A004`l>01<B400@3`d04a0?01DA400F41005Ph?01P?400H3Pl05`d>01/A4P0J3Q006Q4B
014;2`090`<040X:00H0000<1PH2020J6P0501D?3`0D3Ph05a4A018<300F3Pl00P0E30d0400D3@d0
4`d=01<=3@0@2`X06QHE00d<2P0Y:2H0i^KT0?Kfm00j=CD05P`=03X`<@0X7Ql02`4201D;300D2P/2
01H<3@0L0147200@1PL05@/<01T?3P0G3@`05@/:01@:2@0C2@P040H501X@3`0F30/07A<B01X@3`0_
9B@0;28Q01050`0H3@/060l=00d81@0810<03P/:00P71@0S8Qh0?cXg00d80P0F3`L04`/701@91`80
4`L701H04PH601<71`0D20P05`/;01D92@0A1@D040@401@8200I3@d03@4101451@0@10@03`<30145
1@0D20P05`/;01D92@0D20P05PX:01D92@0A1@D03P840P0B1PP00`0?0`D0710B03DY:`0201<72@08
0186200@10H04@D70186200G2`d04@D700d10`0@10H201H:300902TM7`0>0P@0200000/10P0D20X0
4PH801@8300C1`/04PH:00<04@D91P0B1PX601<72`0>01D;3@080000300401P<400<00@04`L;01`@
500900404`L;01H:3P0N4QH06`lC01452@0C1`/201@8300601452@0B1PX05@T=01H:3P0G2`l050P<
0P0B1PX201<72`0@01@8300C1`/04`L;01862@0B1PP0300201D92`0B1PP02@000186200K3a4060`>
01451`0@10H0300201H:30D04@D700L050P:00`00P0F2P`05PX<01D92`0:000050H900@04`@700P0
4@D70147200B20T04PP900h51P0=10D03`H701@82P804`L900d04PH801451`0A1@D05``:01<81P0B
1`D04PL300l4000A1P<05@T901<72@0@10H04@D700804`L900<09QXL028F600>10D00P0>0P@01`0F
2P`060`>01P<3P13=cT0300200`20`0Q5AL01P0A1@L01P0E2@/040@601P<3P0H30h04PH801T=3`80
4@D70P0B1PP201<72ACooooo000Kooooo`/04`T:00l04PT:00@00P0D3a80DD]?04m9C@0C3Q402`D9
04Y4B00I4aL02P@800P21P0600@03@L;00h41`0B1`/00P0E2Ph02@0A1PX03`@801@93@0C20`04PL;
01L<400A1PX05P/?01D;300201H<3@0301D;300C2@X04`T:00804`T:0P0D2P/201D;30L04`T:01H0
3`D602/Q8P0^92D03@<401T>400A1@T03`8901862`0>0`L03`@801D;3P0<0`H01P00014:2`0F4100
3@L901H?3`0=10D04`X;01@;300?1PL05@`=0P0D2``01@0C2P/04PT:01892P0C2P/04`T;00805@X>
018050T=01H;3`0F2`l060dA00d21P0C20`040L901052@0I3Q803`@801@93@0E2Ph05P/?01L<400I
3Q804`P<01@93@0E2Ph201<8300901@:3P0E2a<04P/B010:3P0?2@d04@/?01D?4@0D3Q004`d?00<0
4P`<00D04@`9030Z;00W8B<050h@01H@4P0201<=3`H05@lA0P0B30`401D?3`0A01H@400D3Ph04P`<
01<=3@0E3`l0618B01<?3P0D40l06QHE01LC4P0>2PT04@d<01TE500H51<01000014=300<20L00P0I
5A@00`0D40l05Q8A01PD4`0201HB4@0=01@@3`0J5QD0=S8a03Xf=@0O6aX03`/:01HE4`0I61H05A@B
01XI5`0C4Q004Q4?01XI5`0201PG5@0:01/J600I61H061LE01/K6@0I6AL06a/I01XJ600I6AL07AdK
01PH5P808R8P05T05aLE01`L6P0Y:BL07ATH02HU8`0H5aD081lM020P7P0T92806ATG02<U8P0N81d0
61XG01`Q7@0U:RH07QlQ01dN800P8B<0:BX/02X^<@0X;2l0:2da01DJ7P0[<CH08BP^01lV;00Y<C@0
9Bd_02L_<@0Z<cD0:S@e02Pb=00W<C@0<ci203A2A@0[>Cd0:3Dk02/h?P0/>T00:CPm02Xi?P0[>Sl0
;Se20350A@0eA4T0;Ca103Q7C01CHVL0>DQ=02hm@P0fAd/0=TQ<03Q:CP0gBDh0>DYA03]<E00gB540
=DI@03M7E013Df40A5AS05m_P01ULHT0Q92Z03a8G`1?G6l0AeAT04QFH@1DHV/0AeIM03m>D`0gATd0
?TeD04EDFP17EUT0BUUL04eLH01;FUl0BEQO04YHH@1?GFH0CUeT04eLHP1:FEh0BEQK04YIG01;FUl0
EfI[04eLH@0204]JG`0_065`M@1@Gf@0FFQ]05UXK@1FIFX0G6]`05YYKP1IIfX0GVa_05]YK01PKW40
F6IY05YXJ`1NK6l0FFMZ05i/K`1MJfh0IgEh069`L`1QK6h0I6ma06mjO01lQhT0HVe`079mP@1^NGl0
M7n507b7S@1nR940P8ZC08:<U@23RID0PHNC08bBWP2AUj<0Nh:;0868T024Ri40PHV=07j6R@1nQXP0
P8R908:;RP21RH/0Ph^>08B<S`23Rhh00P21RH`0:`22RXd0QhnB08J>T@21RH`0OhN:07n9R`26TI<0
TijP07N2Q027TY@0N8>508>>T01nRH/0NXF707n:S01hPhD0O8N908fHW01iQ8X0NXF;07^6S01kQX/0
NXF707V4QP1hQ8<0P8b807R4P01VLf`0JWM`08^HT@1iQX00GfaU06IcJP1PKF<0GFYP05aYG`1dPGL0
FfQQ05QUH01FHV00EV9R05]XI`1FIF800P1GIV<02`1JJFH0EVER059QGP1AH5d0Df9O05UXI@1GIV<0
E6=P05QWI`1DHfH0BEQK0080E6=V02P0AEAG04aKGP1BHF@0CeiQ04]JG@17EUT0AUEH04ICEP12CDl0
AE5A049=C013CTX0A4m903Y4?P0a>SD09R`[02P]<00e>Sd0AT]?03Hl?00g?C/0:S0`030e>@0d>Cd0
=SY203LkA00c=d00;c<l07b1Q`2Y[[@0;C8e02X^;`0T:2T0:2d^02hg=P0]=SD0:cDf02dg>@0Z=3H0
9Rha0P0[<3H07P0U9bd0:c0c02Tb<@0[<C40:2`]02LX:P0U9BL0820R02@T9P0V:BX08RPX02D];00/
=C@0GF9U02db=P0N8bH092T]02H[;P0]<SH07R<W02@Y;@0X;C409R/_024V:P0P9BP082@U01hQ800P
8R408B<R01hO7`807alO02`07ahO01lM7P0N71d07a`M01lK700Q81h07ahL01`K6@0K6QP071/I01dL
6P0j>CL06QTG01LF500M71X071/I02<R800L71`06QXJ00`<300M7Ad04A4A01lO7`0J6QX0;2`/02DU
9@0A4A405aLG01@D500J5QD06ADD018>3@0D40l03`/:01XF5@0H51<07a/J00`81`0E4A005a<B01HB
4@0E4@l061@C01PD4@805a<B00H06ADD01DA400F4Q405A4@01<?3`0D414201DA4008018>3@0D3`h0
5Q0@01D?3`0F3`l06Q4B01P?400E30d201T?400901@:2`0=1`L0:28R04@n?P0U7al04P`<00l92@0J
51@05@l?008050h>00D040X:01D>3P0E30d05@`=01@=3@0201<=3@0?018=3@0G4a804Ph=02<R801/
JfT0NGQf02<L700E2``07aDF01T?400>10D04@L801@:2`0F30d05@/<008040H700@05P`=01H<2`0E
2`X04`T80P0D2PT0500B20L04@L600`20@0?1@@01`0001P>3@0B2PT05`d<030X9P0T7A`0>cDg00l;
300A3Pl03`/<01<?3P0Q71X0610=01/B3@0?1P<050T70P0C1`L01`0B1PH04`L701@8200F2PX050P8
01861P0C1`L00P0D20P201861P0601D92@0G2`/050P801451@0D20P05@T90P0F2PX02@0B1PH03@41
01@82P0F2P`05@T;01041P0E2@/0:AdO01041P0200l31@0B01451`0@10H03P8401H:300B1PP04@D7
0186200D20X05@T;01X>400G2`d06@d?01P<3P0Q5AL07Q8D01@8300C1`/04PH:0`0A1@T601862P0D
01<72`0@10P03`<701862P0F2Ph060`@01/?4`0H31005@T=01<72`0=0@D05`/?00d31@0?0`L05@T=
00/10`0<00@03@4501452@0C1`/201@8300801452@0B1PX050P<01@8300C1`/040@800l31`0B1PX5
01D93@0400l51`0F2P`060`>00d10`8050P:00L03P<400d10`08000050P:01D92`0>0P@03@<400D0
4@D700L03`<502TM7`10=3H05@X;01<72@0A1@L04`H800@04`@700L04@D700h41@0?1@H04@L800h5
1P0=10D03`H700@04PH800<04@D701451@0F2`T00P0B1`D05@0C20@03`@001460`0?0`<03`<50104
1P0D20X05@T;01@82P090000710B01041P0d:2X07A4C00/10P080000710B02dQ8`0K3a4040H701T=
3`0601451`0601<72@0@10H060`>01D92`0=0@<05@T;0P0A1@L2018620804`L95?ooool001_ooooo
2`0C2@X03@0B2@X07A@G00/5200D3Q404P`?00d72P0Y8bH0M6ia020K7@080PD050hA00h82`0B30l0
0`0D2@d0300C20`040D900l4200D2@d04`P<01462P0E2Ph03`@801<8300C2@X05P`=01D;30804`T:
00@05@/<01061`0A1`P04@L80`0B20T601<92P805P`=018081HG01@;2`0J41404`L=01863P0C1`l0
5@T@00l42P0H3A<07Q@G01L?3`0F3@h04@X9018;2P0D3@`04`/;00l61`0C2P/201892P0401L>3`0D
2``050/<01<:2`804PT:00D04`X;01<9300F2`l05@X>01872`0201H;3`0301<8300L4AD06@hB0080
5@X>00<04PP;01H;3`0C20`00`0E2Ph0100F2`l04`P<01@93@0E2Ph201<8300401@:3P0F31@050dD
018<408040X>01H04@/=01D?4@0B30h040X:014;2`0B30`04@`901@>400>20X04@/=01@>400A2`d0
4P`>01D?4@0D3Q004`d?018<3P0C3@l05@lA010:2P0A2`/05@l?0P0F410301D?3`0S01<=3@0D3Ph0
5Q0@01LA4@0G4a404@d;01/G5@0T81h08AdK01PD4P0E4@l06QHD00h:200K5aD05a<A028N700G4a80
4`l>01PD4`0I5A@05A4@01@@3`0@30/061@C01`H5`0M6AP06QHE010<2`0G5Q@06APF01/J600X9bD0
8B0N01`K6@0J6AL00P0H5aD0300J6AL06APF01PG5@0K6aT06ATG01XJ600H61H06ATG01lO7@0M7A/0
92@R01hN70806a/I02D05aLE01hJ6@0B4@l08R4O038a;`2k^kT0;bl]02<S8@0J71T05ALD02@V8`0T
:BD07b@P028S9@0V9bT08R<U024R900Q9BP082@W024V:P0W;3007bDZ020W;@0S:S00:c<f02H^<00W
;c40:34c02Pb<`0X<S@0:C@g02Xe>@0Z>3/09cDi02Tf?00[>3h0:CLl0080;Ca10300;3]003=2A`0d
@dP0=4=802ln@`0b@DH0?TeB03A3B00b@DH0=dI;03Y;CP0oCe<0?TiC03e=D`0lC5<0?4]E049AG00o
CU/0AeIT04EDH`1BH740?DUP05]WO`17E6P0>TMH04eKJ@18EV00CUeT04EDF`16EEX0@e9I04YIH01D
HVT0AUIG04UIF@1:FU/0AUIG04IEF@1;FUh0AUEI04QGF`1:FE`0B5QI04QHF01:FUX0BeYM05=RI`1<
Ff0204mNH`0405MVJ`1FIFX0EVEZ05QWK080FVU^02D0EVEZ05YXJ`1IIfX0EVAW05aZK@1FI6L0GF]^
05i/K`1KJF`0H6ia05m]L01XMWT0GF]^065/KP1SKVl0GVUZ07R3Q@1WLWD0MH23071kP01iQ8X0PHbB
07n9T@23SYD0TijU08N=V022RI@0P8N@08ZAVP26SID0PXV?08B;T@26SY80QXjA08F=S`26SXl0RY:D
00<0Q8b?00@0Ph^>08::S@22RXd0Ph^>0P29TI@02023Rhh0PHV<086;S@1nRH/0QI2B08>>T02?VY`0
O8N90P1fPH<08`1eP880N8>507F0PP1gPX@0OHR:07R3R01iQ8T0NXF807R3QP1eP880M82006ijN01d
P7`0LWij06=`JP1ULV/0Q96:06ahM01KJ640H6eV05i[H@1PKF<0GFYQ09:OUP1dPGX0F6AQ06=_K`1N
JF/0GFUZ05]YJ01FIF<0Df5P05UWIP1KJVP0EfIT0080DV1O08<0F6IU05ARH@1AGeh0CEaL05=RI@1D
HVD0BEMJ045?DP1JJF`0LH2305UWJP1@GV40BeYM04QGFP13DUD0@DiA04MAD`1>FE/0A4m>041:B@11
BdL0=Slk03@k>@0`=SH0;c<f02hb=P0]<CD0<CLh05=IF00n@dH092T]03<h?00b=c`0=CXo030e>P1]
LWP0>d1502L/<@0_=3P0;c0d02DY:`0[<340<S/k02hf=`0/=SL09S0b02dg>@0^=ST092T^02DZ;`0/
;C<092T/02D/;00X;2d0:2T[02DV:00Q8B<071/N01hN800S92H09RX[02L];@0U;2h09R/`02DZ<00X
;C809R/b028W;00V:c0092T^028W;00S:2d08RL[02H[;`0c>3/08BDV028U900R92<08B<R020Q8@0P
82008B4Q024P8@0P7Ql07adN01lL7@0O6a`092<Q024P7P0N7A/07A`J01hM6`0O7Q`08B0N01HE4`0H
5aD07ahL01hM6`0K6QP09B@U02h];P0@3`l071/L00h=3@0M71`061LH024P800J6AX07QdM02HU9@0C
4A806ADD014=300B3Pd071PG01TE500G4a805A4@01/G5P0O6aX0?CTh01DA400G4a4061D@01XG4`0I
5Q805Q<?01DA3`0F4Q005A4@01HB4`0201HB500501LC5@0H4aH05A0@018=3@0D3Ph00P0E3`l02`0D
3@d05Pl?01L>3`0C2P/05`h?01P?400H4A403`T901D?3`0N6AT04P`<008050h>00T0618B01@>3P0E
3`l05@l?00l92@0D30d050/<01D<3@0D3@d00P0D3Ph0300A30/05a8A010;2P0J5AD05A<A01dH600D
3@h05P`=0147200D2P/060h?01H<3@805@/<00D050X;01<92P0D2P/05@/<01@:2@0201<9200501@:
2@0E2`X050X901<9200D2PT00P0C2@P03`0G3@`050X901@=300K5QL071PI07QcM`0D4AD03`dA01D@
5@03004091`N00h51@0<0P406`d;01@9200201<71`0401861P0C1`L050P801D92@8050P802/05@T9
01@8200@10@05@T901451@0C1`L050P801451@0D20P040@401@8200C1`L040@401861P0I3@d05@T;
01<72@0F2P`05`/=01<72@0D20X05PX<01<72@0H30h081@F01lC5@0B1PP03`<501<72@0H30h05@T;
01041P0F2P`08ADG01451`0>0`@04`P901H:300=0`@04`L;01862P0A1@T04PH:00804`L;1`0B1PX2
01452@0;01<72`0F2Ph05`/?01D;3@14>3`0Qg]o04Hj?P0900406`lC01D93@0=0PD00P0D20`00`0I
3A404PL:01862P0401862P804`L;00<04PH:01<72`0C1`/00P0D20`201L;3`0401<72`0G2`l05`/?
01@82`8040H700X04@D700h3100@10H050P:01P<3P0>10D050P:00h3100H30h04PL81@0A1@L01`0B
1`P040H701X?400D2@X04@D700T0000C1PP0100C10L01`0A1@L0308300l51P0B20T03`H700h51P0@
1`P00P0A1@L0700B1PP04`L90186200A1@D040D300h30@0C20H05P/701<8100C20D04@D501041P0A
1@L050P:01D92`0D20X04PH80147200F2``0:1`N00X00@0F2`d06@d?00X00@0E2P`02`0101P<3P0;
0@8601451`0301<72@0D20X04`L900804PH80`0A1@L2018620804`L95?ooool001_ooooo300C2@X0
7`0C2Pd06aDG00/51`0500404@/=00h82P0E3a403@P9010:300B30h040X<01L>4@0U6Qh07A8F01L<
400D2@d05P/?01P=4@0D2@d040D900d21P0C20`04PL;01X?4`0A1`P05@/<01@:2`0B20T04`T:01H<
3@0B20T00P0C2@X301@:2`H04`T:01X040L8024G602HSXl08ALH00l51P0B1`d03P8<01873`0D2A40
3P<;01lD6P0R61/05Pd>00T1000D3@`06A4?00d50P0F3@`03PD60107200?1PL04PT:01L>3`0B2@X0
5@`=01<:2`<04PT:00X050X<01L<400E2Ph040D901@93@0F2`l060dA01@93@0@1@T05``@0P0>0`L0
100H3A404`P<01<8300C20`201872`0301<8300D2@d05@X>00804`P<01l050X>01063P0?20l04@/?
018<400C3A404`d?01H@4P0B30h03`T9014;2`0B30`040/800@0000I4aD04@`=00/51`0:10H05@lA
01<=3`0B30h04@/=010:300A2`d04`d?01H@400E3`l050h>01<=3@0D3Ph05@l?00804P`<0P0C3@d2
01@>3P0U01dI5P0E4@h02@D201XF4`0/:2D04@d:00h:1`0A3@X06QHC01HB3`0H51404`l<01PD4`0C
3`h05A4@01LC4P0E4A005Q8A02PT8`0A3@`06aLF01hJ6@0D40l08AdL01LF500B4@l04A0>020O7@0J
6AL03`h<01dL6P0K6QP071/I01hM6`0M71X06aXH01`L6P0201XJ600I01HF500I6AL08B4O01dM6`0G
5aD05QHD01TI5`0G5aD051@B01lK6P0T8b4071/I024P7P0E5A<0:RXX01hN700O8Ah051HC01XL6@0P
9B4092TU02HW:@0_<3809bPZ01lP8P0201lS9P06028W:`0I7R808bT^01/R:00D6b409blb0P0T;2h0
1`0T;Bh092h_02H`<P0Z=CP09C0d02<a=00Y=c/00P0b?dD01`0[>Ch0<T560391AP0_?T<0=dI;03Q7
C00fADX00P0iB4d0:00mC540?TeB03M6B`0c@TH0?4]>03]:C@0gATX0@4mD04IEG013DUX0?TaG03M5
DP14DV00Cea/065^OP1<F6h0Ae=Y04AAH`19EVH0EF=^04]JHP0mC5<0>DQ?045@E@0oCUD0AEAK04iL
I014E5@0AeMF04QHF014E5@0AeMG055QH@13De<0AUIF04]KF`1:FUX0Be]K04mOGP1<Feh2059QIP0I
05YYKP1FIFX0C5]P05i]LP1EI6T0FVU^06EdN@1OKW<0G6]`05m]L01KJF`0F6IY05aZK@1CHF@0FfU/
05i/K`1MJfh0H6ia05i/K`1TLWD0Df5R069^KP1NJVX0KGUi05UTIP0206ehNP0B07=nPP1lQh`0PXfC
07f8SP29U9X0Z;>i08^BVP1mQ8`0Q8^C08nFWP22RHl0P8N=0869S023Rhh0QhnB08R@TP25SHl0OhN9
0P24S8l208>;SP80PXZ=00T0PHV<08N?TP27Si80PHV<07j6R@1nR8X0N8:4086<SP26TI<00P1dOh40
101fPH<0LWeo07F0PP1dOh4207V4QP0U07AoP@1hPhD0NHB607V4QP1fPX<0LGem06mkN`1`O7X0O8R4
079nNP1WLfl0FfQQ069_J01JIV80HViZ06EbJ`1HIEd0F6EL05MTFP1RKfP0G6QT06EaK`1JIVH0K7Mi
06QeMP1DHV80C5YJ04IDE01BH600FVQX05UWI`1AGel0D5iN05ARHP1@GUh0C5YJ04eKG00204mMH00c
055OHP14DUD0@e5D065_LP1RL7<0DV1S04ABE@11Ce80@e5D04MAEP0lADX0@4Y<049<C@0g@D00>dA3
03U0?P0d>SP0=3Xk03@g?00a=3T0:bhe02db=@0Z;c809b`_03Pm@@0d>Cd0;S<f03Hk?`0_=3L0;S<g
03Dj?P0`=CT0A4Q<03<d>00X;2l0;C4d038j?00Z<S@09c4b02D_<00Z=3D0:S8e02P]<@0Z;c<09BP/
02@X:@0U:b/0:Bd^02//;P0X:2X0928U00808AlR00H09RHX02``<@0Z;bl082DX02X_=@0Y;CH2028V
;`0F02T]=@0X;C<08RL]02DZ<00[<3@09b``024V:P0X;C007B4R024T8`0P8R407R0O01hO7`0M7Ad0
8R8R024P8@0Q7b0081hO020M7P0P71d071/I01/J60806APF01D071/I01dL6P0O7Q`08B0N01LF500B
4@l06APF01`K6@0T8R<0=S@e02@R8`0E4a@06ALH01dK700I5aP07adN01TG600A3a007A/L01PF5`0G
4a800P0L61L0600C3`h061@C01HB4@0D40l06ADD00L30P0S7ah05A4@01LC400D4@/05a@=01PE3P0G
50l061@A01XF4`0I5A@04PdA01HA5@0O6Qh07APN01LB5P0E3a004P`<01<=3@805@l?00T050h>01PB
4P0L4a@060l@01L>3`0F3@h04P/;01TC4`0E3`l00P0D3Ph0200A2`/0<R`/03`f=P0O6AT04@/;01D?
3`0C3@d05Ph?0P0D2``01P0D3@d050h>01@>3P0D3Ph06Q@D00T30`804`d=00H05a4A01@;300>10D0
6@l@01P>3`0C2@X201H<3@0N01<92P0B20T05P`=01L=3P0D2P/05@/:01@:2@0B20L04`T801@:2@0A
1`H03P@301L=300A1`H06Q0?01881`0A20P04@/=01DA4P0S7R80K6Y_02@R9`0V8bX020<901D@5P0@
1`/07a<E00l10@0C10@05PP80P0C1`L02@0B1PH04`L701@8200H30`04`L701451@0C1`L050P80145
1@0201861P0G01D92@0B1PH060`<02hR8P0C1`L05PX:01861P0>0P806`l?030T900]8B<05`/=00l3
1@0C1`T05@T;01<72@0D20X03@4301L;3@0U6A/08ADG00d10`0A1@L00P0@10H02@0=0@<06@d?03@X
:P0W6ad05@T;01451`0?0`D05@T;00l31@0301452@0301<72`0D20`050P<00H04PH:01H04@D901D9
3@0G2`l05PX>01452@0>0PH04`T;00X00P0H31004@H9028F6P0?0`L05`/?0104200D20`04PH:01P<
400@10P050P<01452@0@10P04@D90P0C1`/0100B1PX04`L;01@8300B1PX20104208050P<010040@8
01@8300D20`04PH901<72@0G2`d040@601451`0E2@/03@430186200:000050P:00h2100V6Q`05`/=
1P0A1@L01P0D20X06`lA00P0000E2@/04@D701851`@04`@700D04@D700h41@0@1PL04`T:01072002
00h51P0A00l31@0@10H04PH801<72@0B1PP04@D50146100@1@<05P/901L<200A1P803@8001P<300E
2@/040@600l31@0A1@L00P0B1PP02`0C1`T0Ed]=01X>400G2`d04`L900d10`0K3a403@8301L;3@0@
10H06Ph@00H04`L900H03@4301451`0:0000300201@82P0<008201451`804PH80P0C1`TDooooo`00
6oooool201<92P804PP90P0A1`P01P0B20T050X;01@:2`0B20T04`T:01@:2`H04`X=02/071<F00h5
200>1@P06A0C01<:3@0E30l0IeaP01/@500F2`l050T=01`A5@0@1@T03`@801D:3P0A1PX03@8601@9
3@0I3Q804PP900h41@0I3a0040H701D;300<0P<050X;0147200>10D03@<401882@0F30d04PP90147
200E2``050X;01882@0E2``06@l@01@:2`0F30d05@/<0147200A1`d04@L@00804PP@00d040H>0148
3@0A1`X04@L801<9200F30/05@/:01<91`0D2PT05@/<01@:2`0C2@X04PP900804@L801005@/<01H<
3@0D2P/06a4B01`B4`0G3@l05@X>01<8300B1`/04`P<01D:3P0D2@d04PL;01<8300D2@d05@X>0P0F
2`l01@0D2@d05P/?01L<400C20`040D900804`P<0P0D2@d03P0E2Ph05@/>01<94@0B2a804`dA018<
400A2`l03`T;01@>400E3a404@/;010:2P0B30`03PT60P0E3a40:`0A2`d05@lA01/E5`0=1`T05@lA
01@>400B30h04@/=018<3P0E3a407aTI07QbLP0N61P04P`<00/51@090`<05a4A00l92@0E3`l04P`<
01D?3`0?2@T04Ph;01LD3`0H5A005a@?01HC3P0G50l03``701<@2`0E4Pd0514<01<@2`0C3``0510?
01DA400L61L020@301XF5@0K5aH05a<B01HB4@0I5A@00P0M6AP0AP0H51<04A0>01@C4@0I61H05QDC
01LF500Q81h071/I01TH5P0H5aD06APF01XI5`0K6QP061PF01hN700P81h05aLE02d]:`0J6QP07QhL
01XJ600D51806a/I028R800J6QP0<Bd/02XY9`0P7ad071/I01hN700M7A/07alM01hP7@0L7Q/06adJ
01/P700M8Qh08B8T02@U9`0Q8R@09BHX02DY;00P92L092T]028W:`0S:Bh08BP^01dT:P0O9bX09Bd_
02@/;P0T;Bh09S0a02/e=`0]=cX0:SDi03=1A00W=3T0=D98038oA@0/>Sl0<T5603=2A`0b@DH0<d97
03Q7C00iB4d0<3m403A3B00mC54203I5BP0J03]:CP0kBd/0?Te@03U8C00iB4d0@e9I04ACF`19Ef00
AE=N04=AG@0nC5T0[K[;04QEJ00lBE`0Cea^03Q6D`16E5l0@U5I04IEG013DUL0@4mD04IEG01<Ff80
BeUQ04QGFP17EeL304EEE00Q04=CDP15EE@0AEED04MGEP1<G5/0CUiM04mOG`1<Feh0CEaQ051OI01C
HVL0EFAY05QWK01BHFH0Df9W05ASJ01JJFh0GVeb05IUJP1LJVd0E69S05ESI01FI6D0Df5R05MUIP1L
JV/0F6IW05UWJ01MJf`0Gfe^05e[K01QKFd0Hfm_0080J7Ad00/0JWIg07AoP@1fPH<0NHB707b7R`1o
RXh0PhjC08JAU`2<Ti/0QHbB08:9S`0208>:T0090828R`21RH`0PHV<09FMW`2SZjd0Ri>E08B<SP27
Si80PhZ@0080P8N=00T0OhJ<07f4RP24Ri40PhZ@0827S@22RHl0P8N=07Z4QP1lQhP00P1kQhL0;P1`
O7`0K7Qh07=oO`1dP800LGem07N3P`1cOgl0N8B4079nOP1iQHD0LGem07^7Q`1[MgH0Kg]i07B0OP1^
NWP0JgMc06YfLP1YMG40H6aX05UUH@1OJfP0Gf]W05YWH01IIUh0EfAK051ME@1GI5d0FVIR05]WI@1Z
MWH0KWUk05m[K@1=Fe`0AeEF04aJF`1FI6D0F6IW05UWJ01HIVL0EF=T059PH@1<FU/0AeEF04A@DP1;
EUP2059MG`80C5MI00@0CEQJ03e8BP0lAdT0BeIH0P11C4h0>018DUH0@DY?0459C00k@dH0<CXi03Dk
>`0i?cl0;S@d038f>@0]<3D0<SDj02X]=019C5409BP]02`_=00[;c806QhQ03Lk?@0m@D@0:bl`02lc
=P0W:bh0<3@g03m3AP0a<SL0;C0e02X^<P0V;S409blb02Tc=00/=SL0;SPi03Q0@P0X;C008RLZ02LZ
;@0W:b`0:2h^02P/;@0Y:R`0:BT[01lM800L6Qd07A/N02DU9`0V:R/092TZ02P]<00o@T/0;2hj02h`
?00]<3T07B0Y020S;00O8RT07b8X0P0S9R/02P0Q9BP09BT/01`P8@0M81l06A/J024S8P0O81l08B4Q
01XJ6P0L6a`201lM7P0:024N7`0Q7Ah05QDC01XI5`0K6QP06APF01XI5`0N7A/04a8@01lN70803@`:
00T07A`J014@3P0K6AX05Q@E01<A4P0N71d01083028P8@0H5QL00P0F51D00`0I5aP07Q`M020N7`02
01/G5P0W01PD4`0J5QD071PG01DA400H51<06aLF018>3@0I5A@05A4@01DA3P0B3`T061D>01lL5@0J
5a806QHC014=2P0=2@P04`hB00l:3P0E41@050lE01<>4P0G3a405Pd>01L>3`0H3a005@l?010:2P0N
61P06Q@D014;2`0B30`081XJ010:2P0H4Q8050h>018<300N61P06Q@D00<050h>00X04`d=014;2`0@
2PX04P`<01<=3@0B30`07ALG02/U9@0S6Q/05@`=1@0F3@h00`0D2``04PP901<92P0201<92P0801@:
2`0E2``04PP901L=3P0F30d04@L801P>3`0C2@P201@:2@804@L602L050X900h40`0=0`805@/:01X@
3`0G3@`050X:00l92`0I51P0K6M]0?olo`1PGF@0514H00T42`0A31804@L<020D5P0D1PH05PL801L9
2@0I3@d04PH601L;2`0E2@T04@D504<g=`0j;Rh04`L701T=3@0E2`/04`L701T=3@0E2@T07A4A01/?
3`0E2@T07a<C01@8200C1`L00P0B1PH01@0C1`L050P80186200@10H04@D700805@T;01P040@60186
200I3@l08ADG01X>400?0`D05@T;00h2100G2`d04@D700d10`0B1PP04`L901@82P0>0P@04@D700l3
1@0>0P@050P:01862P0A1@T02`030104200L41@201<72`0?01D93@0@10P04@D901@8300C1`/04@H9
00h21P0O4aL03@8500d11@0E2@d04PH:01<72`0E2@d05PX>00805@T=1P0B1PX01`0D20`04`L;01X>
4P0B1PX03P8601@8300K3a<00P0D20`01P0A1@T03@4501H:3P0F2Ph04`L;0104208050P<00<04@D8
01451`0C1`T00P0E2@/05@0D20X040@600`00P0N4Q@04PH804a0@P1PE5H06@d?01D92`0A1@L040H7
01hB500H30h03@<401D92`0A1@L04`L901@82P0>0P@04P@701831P0201@5200F01D62@0D20X03`D6
01T?400?1@H07A@E01@;300B2@X040@601D92`0L41803P8401041P0@10@03@8002<H5P0H3Pd0Q7Ue
01/@300>0`406Ph>00P0008050P:00T06Ph@01061`0=0@<05PX<01/?4@0H30h05PX<00`20`0B1PP0
0P0A1@L00`0@10H04@D70186200601451`0<00d10`0C1`T02`0101`@4P0?1@H0300201@82P0E2@/0
200001L;3@0@1PL0710B5?ooool001_ooooo0P0E2``301@:2`0701<92P0B20T050X;01@:2`0B20T0
4`T:01@:2`0601<:300;018;2`0E30h040L902lV:02BRH/0DTU;01P=4@0E2Ph02@0201P=4@0=0PH0
0`0D2@d02@0B1`/04@H:01<8300D2@d05@/<01`B4`0J414050/;01482@020147208050X;00P04PP9
0147200B20T04PP90147200E2``050X;01882@805@/<00d04PP901D;300E2``04`T:01H<4@0F3Q@0
610F01H=4`0A20d040L<01472P0B20T04`T:00805@X:00<050T:01<92P0B20T00P0C2@X201@:2`0<
01882@0D2P/05@/<01@:2`0H3Pl06@l@01H;3P0C20`04PL;01462P0B1`/04`P<100D2@d401D:3P80
5P/?00@05@X>01@93@0C20`04`P<0P0D2@d0500E2Ph05@/>01D;4`0A2Q403`T=00h8300?2@d04P`>
010:300A2`d04@/;01<=3@0G4A405Q4>01D?4@0O6A/03@P901TC5@0=1`T04`d?0P0D3Q004@0C3@l0
4P`>01<=3`0D3Q004P`<03`f=P0D3Ph05a4A01PB4P0`:RX0618B01<=3@0Z92@0:B<S01H@400D3``0
5A4>008061D@01805A8=01<@2`0B3`X04Pl:01DB3@0G50l05Q<>01DB3@0F4`h05A4@018>3@0H51<0
71PG01hJ6@0P71/05a<B01HB4@0H51<201/G5P0601PD4`0G5Q@07A`J02<R800P7ad061LE0`0K6QP0
4P0J6AL06aXH01XI5`0K6QP06a/I01TI5`0L71X06ATG01`L6P0D51805QHD01`L6P0J6QP07alM01hN
700L71X07a/J024P7P807QdK02407QhL01`L6P0P81h08B<P020R7`0O8Ah07B8N01lT800Q8R@0824S
01`M7`0P8B<08bLZ028V:@0V:bl082DY024W;00T:c409bhd02H^<@0V;S00:30b02Pa<P0Y<c@0;CLi
02H`<`0e@4@072X]02`j?P0/>Cl0:CHl03I4B@0a@4D00P0b@DH00`0c@TL0=dI;03U8C@0203Y9CP0Q
03I5BP0mC540?4]@03E4A`0eA4D0>4I803Y9C00kBDd0?4YA03m<E00lBU<0EF9]03a9EP0f@e40E65`
041=GP17E6D0>dUH03m=F013DEX0?diE04]JG`17EU/0AEAI04UHG`1;FV40AeEM04QGF`19F5X0B5QH
04ADD`13De80A5AB0080B5QF01X0BEUH04]KF`1<G5d0CEaO04eLH@1>GF80D5mT05=RI`1DHfP0EFAY
05MVJ`1IJ6d0FVU^05m^L`1TLgP0GVea05ITI`1BH640Df5R05ESI01KJFX0J7Ig05aZJ`1JJ6T0G6Y[
061^K`80I79c01T0HFe]06IbL@1_NgX0L7al06ahN@1`O7d0N8>507^6R01oRXd0PHb@08:=TP22SI40
QXfC08F=T@24S900Ph^?08>:SP22RXd0Q8b>08::S029TI<0Ti^M08B<SP25SHl0P8N=0080PhZ@0100
Q8^A08jEV`2EW:80P8N=0868SP1oQX`0PXV?0868SP1kQHL0M7mo07B0O`1cOgh0JgMf06QdL`1]NGP0
N8B30P1ePH00PP1dP7l0OHV807=oOP1bOW`0OHV809^WY01gPh00HFeZ06]gM01/N7D0J7A`06EaK@1P
K6P0GFUU05aXI01HI680FFEQ05MSG`1HIEh0F6EM05=PF@1IIUl0G6QT05UUI01RKFl0HVea05YVJ@1C
HF80CeeN05=QHP1HIVL0EfEV05ARH`1EHf@0EfEV059PH@19EeP0AE=D04EBD`19E5H0BeIH04IAD`10
Bdd0@Da>05UTIP1FHF<0A4mA04E@DP12CDl0AE1B04UCF011BE00?dI<03a4AP0d>Sd0<cTi03Dj>`0Y
;Rh0;30c034c>00h>T40:b`f02h`>00X:S00<38g038d>00^<3@0:B//02d`<00R9BD0:bh^02T[;P0]
<380=cTm02d^<`0/;cD0<3@i030h>`0a>C`0<S`m030j>`0[=CH0<CTj02T_<00Y;S00:b`_024U9P0X
;Bh0:bd_02@T9P0S8RD09B8U02LS9`0S8B@0:bX/03Df>00^<S<09b`_02HX<@0/;CT0:R/g02HX<@0W
:C809RP_02@V;00R92T09BLZ02@V:@0O8R<08B@T02X^;@0g>ST071hM01PJ6@0M7Qd06QXJ01lO7`0P
7al081hO01lM7P0O71d07QXK01`K6@0N7A/07A`J01/J600J6AL071/I01/J600L6aT202HU8`0901XI
5`0I61H06aPI03Pe=P0O71d061DF02<P8@0E4Q<06AHG00805a@E02/06AHG01`I6P0M6Q/05Q8A01`H
5`0N6QT05A4@02<O7P0C3`h061@C01hJ6@0I5A@05A4@01PD4`0F4Q005Q<>01/H500K5a<05Q<?01`H
5P0C3`d07ATH02XV9`0=2@/04`hA020K7P0C3A006@lA01L>3`0I41406a8C01TA4P0E3Pl05a4A01PB
4P0S7Qh04Pd=01/F5P0E40l0618B014;2`0G4A406aDE008040X:00D04P`<01<=3@0C3@d04`d=018<
300201@>3P05014;2`0C3@d06Q@D01H=3P0B2@X00P0F3@h01@0F30d05@/<01D:300F30d05@/<0080
50X;00T04`T:01882@0D2P/08aTJ04<i>P0C2@X060h?01892P0C2@P00P0D2PT201881`0L01@:2@0H
3Pd050X901<9200@1PD03@<201892@0;0`H06aHI02/U:P1NFEl07a/R00X73P0G4QP04PdC00l72`0J
3a004@@401P:2P0B1PH05`/;01861P0I3@d060`<01H:2P0;0@406@d=00d20P8050P800T04PH601H:
2P0B1PH06@d=01P<300B1PH06Ph>01@8200C1`L00P0B1PH00`0C1`L050P801D92`0201<72@0801D9
2`0F2P`050P:01041P0C1`T06@d?01L;3@0A1@L201@82P0301<72@0B1PP04PH800804@D700l05PX<
01<72@0E2@/04`L901041P0C1`T0710D04Tm@@0K3a<050P<00`2100F2Ph04PH:01<72`0B1PX00P0F
2Ph00`0@10P04`L;00X00P0201D93@030105200?0`L050P<008050P<00<04`L;01862P0A1@T01`0B
1PX0500F2Ph04`L;00/00`0U6Ad0;R8V00P0000O4aL03P<6020D600A1PT03P<601<72`0E2@d04@D9
01<72`0D20`04@D801451`0B1PP050P:0P0C1`T04`0H30h02@0001041P0D20X04@L801T=3`0A1@L0
5PX<01451`0E2@/05@/<00l51P0H30h04@D701L;3@0B20T03`<501H:300F20/00P0G20/08@0F1`X0
5@H901<72@0C2`/050X;0107200`:2P0J5mP06UPH@1DB4X081@F00d3100D20X0308301@92@0?10<0
2@0001T>300<0`404@P601L<2@1oLg<0;R8T01@92P0C2@X050P:03hc=@0E2@/0200002@H6P0d:2X0
4`P900l51P0201<72@0301451`0@10H04@D700L04@D700`0;B4S01882@0>10D050P:01@92P0E2@/0
4@H701872@0E2@/04`L901061`0C1`TDooooo`006oooool201D;300501@:2`0C2@X04`T:01<92P0B
20T00P0D2P/00`0B20T04`T:01@:2`0601892P0=0107200?1PL050/<00h61`11>3T03PD601482P0T
6Ad02`0401@93@0:00<05``@01<8300301052@0G01P=4@0O51P0>S0a00l51P0;0@806a4B00h41@0U
6a`04@L801H<3@0G3@h050X;01882@0A1`P04PP90147200E2``050X;01882@0E2``040H70147200E
2``00P0D2P/0100B2P`03PP:014;3`0B2Ph201482`070188300B1`/04PL;01<82P0D20X05@T=01D9
2`0201882@0501<92P0D2P/050X;01<92P0B20T00P0C2@X00`0D2P/05@/<01@9300501872`H050T=
00H04@H:01052@0?10P03`@801<8300D2@d201<8308050T=00@05@X>01D;3P0D2Q804@XA0P0@2Ph0
100A2`l05@lA01<=3`0D3Q02018<300801D?3`0B3@X0100003@^<00>20X0100001H@4P0J51H601<=
3`0>010:2P0>20P04P`<010:2P0B30`0:B<S00l92@0E3`l09AlO02TS8`0G4A4050l<00X70P0?30L2
018?2P0501<@2`0D4@`040d801<@2`0D4@`00P0C40/01`0E4Pd071PE01LC4P0?2`X061@C01dI600:
1PD00P0F4Q402@0G4a8061@C01PD4`0G4a804a8@01TH5P0Q81h081lM01PG5@0201TH5P0M01/J600L
6aT07A`J01/J600J6AL061PF01LG5@0J6QP06a/I018B400L71X07AdK01HF500G5aD07AdK01@D4P0U
9B<07QXI028Q7`0O7Q`07QdK01`L6P0I6AL07AdK01lQ7P0P8Ql07R0M01/P700L8Ad00P0O82805P0M
7R00824S024U:00Q9BP0724U01lT:00R:2d08bX`028Y;`0T;2l0:C4c02/c=@0[=3D0:38c02Pb=00Z
=CP0LGb002`j?@0/>Sh0=dA:02`i?`0`?T@202ln@`030350A@0c@TL0=TE:0080>DQ=0P0eA4T06`10
Ce@0?diC03E4AP0fA4D0>4I703Y8BP0iAdX0>4E;03a9D00hADd0C5UR03e9EP16DV00?TYH041=G@18
EFD0@DmK03=1BP0fAD`0AUEJ04UHG@16EEX0B5ML04]JH@18Eeh0@e5J04IEFP0204QGFP0903m?C`0m
CD`0@e=A04MGE018F5D0Be]J04]JG@1<Feh0CUeQ0080CUeR0100D5mT055PI@1BHFH0Df9W05]ZK`1L
Jg00FVU^05QWK01JJFh0E6=W051NG`1AGf00CUaM04]IFP1BH640Gfe^0P1NK6d0201PKVl0HW1a06Id
M@1WMGD0IG5_06UeL`1bOW`0M8200P1`O7`0@`1iQ8H0OHR:086<SP22SI40P8^?07f8S01oQhX0QHf?
08J>T@22RXd0PHV<08>;SP24S8h0QHf?0869R`26SY00OhN908>;SP1oQX`0PXV?0827S@1oQX`0QhjD
08fDVP20Qhd0OhJ<07f4RP1oQX`0OXF;07R2Q01dOgl0M81n07=oO@1^NWP0K7Qf06ijN01gPh40JgMe
07=oO@1`O7X0MX:007B0OP1`O7P0M81l08bHU01/N7@0GFUU06McK`1ZMW80JGEa06McK`1NJVH0G6QT
061/J01NJVP0H6aZ05eYI@1OJfH0GfaU05QUGP1JIV80GFUW05aXJ01QK6h0H6]_05YVJP1EHf@00P1C
HF80301EHf@0EVAU059PH@1DHV<0FFMX05=QHP18EUL0AE=D04QDEP1;EUP0BUEG04E@DP80?dY<00@0
Ae9D04=>D00mB4X0@4]=0P0oBT`0?P19DEH0@TUA03U0AP0g?D80<3Dh02X_<P0^<c@0:Rh_02X]<@0Y
:C40;Bde01lO:@0X:380;bli02X[<@0[;300;Bh`02h`;P0Y:bP092HS02T[:P0Y:R`0:2T[02`]<@0^
;SH0;c8i03<g?P0b>Sd0;cLj02Xd=P0/=SL09S0a02`e=00[<C40;cDe03Hg>@0^<S<09RX[020Q8`0/
:Rd0<c4d02LR9P0U82@08QdQ02DT9`0^;S00:2//02<W:P0Y:C<0<30l02h^>00Z:S@0:2P`02DV:`0S
92P07b0R02@V9@0U9bH08bDS02<U900N8R40;2l^0P0I6aX02`0P8B008B4Q01TI6@0K6Q/07A/L01hL
7@0O71d081`M01`K6@0M71X071/I00<06aXH00h071/I01LF500X9bD0:2LU01DD4P0J6AL07ATJ03Da
<P0O6a`040`=01`H6@0<20T06ADF01PD5@805a<D00/061@E01TE5P0F4Q40510?01DA400J5QD05A4@
01/G5P0H51<06aLF01hJ6@0201DA400@010<2`0E4@l06QHE01LC400D40l071PG018>3@0H51<07QXI
01XF5@0E4A404Ph?018<300G3Pl05P`=01T?40806Q4B00L05@h>020J6P0?2@T03`/;00X61@0A3@`0
5a8A0080618B00@0=Bl_034[:`0K5AD05a4A0`0B30`01@0C3@d050h>01<=3@0B30`04`d=00804P`<
00D050/<01@:2`0D2P/050X;01D:2`0201D92`0?01<82P0A1`P04PP901@:2`0E2``05`d>00L00008
0000:R0Q00d3100I3a005`d>01<9200D2PT05@/:00804PP702L05@/:01X@3`0D2PT050X901P>3@0E
2`X040H501@:2`0E30l030D900d63@0G4QP03PX@0<Boa@1KEUX03PT:01lG5@0O5A<04`P601@8200H
30`04@D501H:2P0D20P040@401H:2P0G2`/03@4100l30`0F2PX060`<01<71`0B1PH05@T901@8200@
10@05PX:01@8200C1`L00P0B1PH01P0C1`L050P801D92`0D20X04PH801<72@805@T;00h04`L90104
1P0A1@L04`L90186200@10H04PH800l31@0E2@/05PX<01<72@0H30h040@601451`805@T;01404`L9
01@82P0E2@d05PX>07Y^LP1REUX03@4501D93@0C1`/050P<01452@0C1`/050P<0104200B1PX0710D
01D93@0200l31`0301P<400B1PX04PH:00804PH:00<040@800l31`0B1PX01@0B1PX03`0D20`04@D9
01L;3`0E2@d03@4501@83008000050P<01D93@0I3A404@D901P<400K3a<07Q8F01H:3P0201452@03
0145200@10H04@D700<04@D701<03`<501<72@0B1PP04@D701@82P0E2@/04PH800P0000G2`d0=b/]
01@82P0=0@<050P:01041P0Z7R009ATK0186200I3@l03`<4008050D802@04`@701831P0@10H01`00
01L=3P0@1PL0ETe>0<Bk_00M51D05`/=0186200G2`d050P:01H:300A1@D02000020E4`0=10<05``8
00`1000A1P<0<bLW01D92`0C1`T04@D70186200F2P`04PH801451`0E2@/05`/=01D92`0C1`T050P:
01<72@0B1PP301041PH04@D700D03@4301P<3P0E2@/05`/=01H:300200P0000501L;3@0800002000
01<92P0H30h05?ooool001_ooooo0`0C2@X201882@070147200B20T050X;01@:2`0B20T04`T:01@:
2`0601<92P0K01H<3@0B20T05P`=01892P0D2P/07A<D01482P0H3A40304500d31P0F2`l05``@01D:
3P0G310060dA01052@0A1PX06@hB0148200T6Q/06@l@03T_<00L4Q<01`0001<92P0E2``050X;0080
4`T:01T050X;01882@0A1`P05@/<01@:2`0B20T05@/<00l51P0B20T05P`=01@:2`0C2@X04@X:00`8
1`0>20X03`T:00h82P0B2@`04`T=01872`0C1`/04`L<01@8300G20l05PX=00805@T;00@050P:01<7
2@0C1`T050P:0P0C1`T0100D20X04`L901@82P0D2@`;01@93@0601H;3`0L4AD060dA01@93@0G3100
5@X>0P0C20`201@93@0501D:3P0E2`h04`TA014:4@0C3A400P0D3Q8201@>400;01D?4@0B30`040X:
018<300>2@H0;RPZ08b6R00Y8bD05a4C01lI6`0500401P0C3@l04@0A2`/02`D501D?3`0>20P040X:
01D?3`0400005@l?00h8200G4A40618B01@?300F4`h06AH?01PE3P0E4P/04Pl800804@h70P0C40T0
2P0B3`P04a0901DB3@0F4Pl061@C01<?3P0D40l0=C4`018>3@0F4Q4201LC4P0301HB4@0H51<061@C
00805QDC00H071/I01/J600G5Q@06QTG01TH5P0K6QP201dL6P0301`K6@0K6QP061PF00807QhL05`0
6a/I01HF500R8R006a/I024Q7`0F5Q@08R8P01`L6P0H61H08QhM028Q7`0M71X071/I01dM6`0K6aT0
7AdK01lQ7P0P8Ql07b4N01`Q7@0M8Qh07b0R024R900S92H092DW020T9`0Q9BP08bP/02L/<00X;S<0
9bhd02H]<`0U;C009Rh`02Xb=00Z<cD0:38c02Pb=00e@4<0OHR<03I4A`0b?d@0=T=902Xg?@0]>d00
;Se202ln@`0a@4D0=4=803I5BP11D5D0@4mD03U8C@0mC540>4M<03A3B00eA4H0>dU903e;C00iAdT0
=D=603]8CP11CUD0@e1H03]8D@0nBUD0@TiJ03e9E`0nC5T0BUQU082>VP1DHV/0AEAK03m>D`14DeH0
@E1C04IEFP1;FV40AUAM04ABG014DeX0AUEJ04EDF00mCDd0>d]:049BD@14E5<0AeMF04]KF`1;FUd0
C5]P055PI@80CeiS0140DF1U059QIP1CHVL0E6=X05]ZK`1LJg00FFQ]05ETJ@1FIFX0DV5U04aJF`1A
Gel0CE]K04QFEP1<FUX0Df5Q065_K`03069`L00L06AbLP1VM7@0JWId06UeL`1`O7X0Lgmm079nO@1e
PH40NXJ607j9RP21S8h0PXf?07n:S@1lQhT0OXJ808B<S@25SHl0PXZ<0828RP22RX`0PHV;08N?T@21
RH/0QXjA0869S020R8/0PHR>0827S`80OhJ>00/0OXF=07f4S021R900P8N?07f4S01nQHd0O8>;07Io
Q01fPH40MX:007B0OP03079nO00;07=oO@1[MgD0QY:@07^7Q@1^NWP0LGek06eiM01TLFX0KGYc05m/
I@1QKFT00P1PK6P01`1SKf/0IG5]05aXI01GHf40G6QV05m[JP1PK6X00P1LJ6@07@1KJ640EfAN05]W
H`1LJ6H0GFQX05mZK01NJFd0GFY]05aZK@1GIFP0DV1S055OHP1DHVD0Df5T05ARI@1JJ6/0EF=V04YH
F`17EEP0B5AF04]EEP1<EUL0BUAE04I@D@14CTl0?DM803]5AP11Bd`0@Ta=0080?DM80380ATiC03i5
C@0e>T00<CHk02`a=00Y;C00:blb02P/;`0`<CH0:RXb030`>00];CP0=cM302TY<`0U9B`0=3Di02l`
<P0/;R`0:bdZ02T[9P0W:BH0:bd/02X/:`0_<3<0<C4i034d?@0d>3h0<3Lm02`c>@0V<380:C<d02H`
<@0/=C@09R`Z02P^;00d=SD0;C4b02@X:@0M7R00:RP[038`<`0U82@0:2<W02HQ9@0W9RT0:BT[02HY
:P0[;c80;blg02DU;`80;2`f01L07QlU01lP900S92P07b0Q02<U8P0U9b@08R@P024S800G6aX06A`K
01XL6`0S9B@07QlO02DU9@0G5aL06API01/I6P0L6Q/07AXK01hJ6`0J6AL06APF01XI5`0301/J600>
01XI5`0I61H06QTG01TH5P0G5Q@061LE03@`<@0[9bP0:RHW02@P8@0I5AH09B4R01TE5P0H51D401LC
500603Te=019AD@06ADD01`H5`0;1`H07ATH0P0G4a802@0M6AP061@C018>3@0C3`h05A4@01HB4`0G
4a805A4A01XF5@02018>3@0>00d9200F4Pl05a<A014=300D3Ph05``>01D;300G3@h06@l@01L>3`0E
3Ph06Q@D020L6`0`;2/200`;2@0>00`71`0=1`L05Q0@03hh>00f<3006Q@D01D?3`0D3Ph04`d=018<
300C3@d050h>014<300A3@`201H@400;014;2`0C2P/04`T:0147200C1`T05PP;01P9300I2Pd05@X;
01882@0C2@X00P0E2``0200F30d0F4i?02hT9@0>10D04`T:01L=3P0?1PL050X90P0E2`X0:@0C2@P0
4PP701D;2P0m<c80:1hM01061@0A1`H050X901D;2P0O4aD04PH801D;3P0;1@T04@`@01HA5`1XIV/0
6QPK01HA4@0I51401P0001@<2`0F2PX06Ph>01<71`0H30`05PX:01861P0C1`L04PP801D92@0J3Ph0
710@00h20P0C1`L050P801D92@0C1`L04PH601D92@0D20P04`L700804PH601H04`L701@8200C1`T0
4`L90186200A1@L04PH801<72@0G2`d04`L901041P0C1`T050P:00d10`0A1@L050P:01P<3P0F2P`0
50P:01T=3`0>0P@04@D70P0B1PP0600A1@L03`<501X@4P0>0PH060`@020E600K3a<0200001D93@0G
2`l040@800d11@0A1@T04PH:00d31@0B1PX0200001X>4P0E2@d04PH:00l31`0@10P04@D901862P80
4@D91P0B1PX02@0J3Q802P0200d11@0G2`l050P<00d21@0X7200300400d31@0200P0000401<72`0K
3a<07Q8F01H:3P804@D900<04@D801451`0A1@L00`0A1@L04`0?0`D06@d?0186200=0`@060`>0186
200C1`T04@D7038V:01<@4805PX<00P0000D20X03@4301dA4`0D2P/02@0001T=3`0A0`H00P0B0`H2
01<41`0R0186200700004@L801@:2`060000;RDV01<:2`0L41805PX<00`20`0800006@d?01H:2P0A
1P@05``:0146100I3PX0714=01L<2@0B1PH03P8400h3100A1@L06Ph@00/10P0A1@L060`>00d31008
000050P:0186200C1`T04PH801451`8040@61`0A1@L0300=0@<03P840186200W6ad05P`=0186200m
<C<0HeMI02@H6P0R5QP04PP900P001Cooooo000Kooooo`8050X;0P0C2@X301882@8050X;00<04PP9
01<92P0D2P/01P0B20P0200>1@H05`d=01492@0H3Ph02@4101P?3`0@1@T04@H:0`0E2Ph03@0?10P0
4`T<00h31`0E2Ph04PL;00`11@0A1PX040L701<92P0C2P/04PX:01L=3P0N51D00P0C2@X0600A1`P0
40H701<92P0E2``04PP90147200E2``050X;01882@0E2``04PP901L=3P0I3a0050X;0147200D3@`0
4@d;014<2P0?2PT04@/:01L>400F31004PL<01@73`805PP@00@05`L@01H83`0E2@/05@T;0P0D20X0
1@0C1`T05@T;01@82P0C1`T05PX<00804PH800<050T<01@93@0E2Ph00P0E2Ph00`0D2@d04`P<01@9
3@0201@93@805@X>00H06@hB024F6P0L4AD050T=01L<400@1PT201<8308050T=00D05@X>01D;3P0C
2A404@XA01<=4@02018<400?018<3P0A2`d04P`>010:2P0A2`/05@l?018=2P060@8081XL00h82P0>
2@X050h@01H@4P0B30h04`d?00<050h@00l04`d?00h8200A2`/04P`<01TC4`0D3Ph05@l?01`F5P0/
9RH030H601@>3P0B30`040/800h;1P0C40T00`0E4P/0600F4``0514:01HC300E4P/0514:01DB2`0I
5Q40510=01TE500G4a804`l>02hZ:@0D40l061@C01TE500H51<05Q8A01LC4P0K5aH07A`J01PG5@0J
6AL06APF01LF50806QTG00<06aXH01`K6@0M71X00P0N7A/0400L71X092@R020P7P0M7A/09bLU01hN
700K6aT08R8P02DU8`0F5Q@09BDS01XJ600N6QT07QdK01TH5P0J6AL201lO7@0N020P7P0Q8b008R@Q
024S800Q9R808RLS020Q8`0R8bD0:2T[02LX:P0Q9BP08bLZ02P]<@0W;3008bT^02@[<@0X;cD0:30c
02D];`0X<380:S<d02Xd=@0/=SP0;3Hi034l@00W=CP0>DI;02Tf?00^>d40=4970P0_?T<09P0d@dP0
=dI;03M6B`0iB4d0=DA903=2A`0hAd`0<d970350A@0gATP0?DY:03i:C00hA4H0=T=603i:D012CED0
@DaE03U5CP16DU`0CEQT04IBG`0hAU<0@DmL07^9T`1JJ740AeIM04mNHP13DUD0?diA04IEFP1:F640
A59K04IDG`15Ded0AEAL049AE`0oCU40@51@0P14E5<02P18F5L0CEaN04]JG`1<Ff80DV1X04mNI01?
GV<0DV5V05ASJ01EI6T205MVJ`0I05YYKP1HIf`0E6=X05MVJ`1EI6P0BUQI04mMG@1<FUX0CE]K05IT
I01IIfL0H6i^06=aL@1RL700H6i^065_K`1ULg<0KGUg06QdL@1]NGH0Lgmm07J2P@1kQhL0O8R807f9
RP02082;S@0>07n:S@1mR8X0Ph^=08><R`21RXT0PHV:0828R@1oQhT0OHF708N?T@20R8X0RY:E08VA
U01nQXT20827S`040868T022RI40PHR@07n6SP80P8N?00X0OHB<0827S`1oQXh0N86607AoO`1ePGl0
LGek07B0OP1ePGl0LWil0P1cOgd0:P2>VYP0Q92>071lNP1YMG40KGYc06AaJP1[N740HVmX06IcK@1R
KVT0H6aX05m[I`1VLVh0Hfm[05eYI`1QKF/0I71`06A`KP1OJfT0GVYV05]XH@1JIf40G6QT05]WI@1J
IVL0FVEY05]VK01KIf`0FFMZ05ESIP1:F5/0@e5D04MEF01?GF00Df5T05ITI`1DHVD0CE]N04YHF`18
E5H0Ae5B04QBD`80BE=D05@0Ae5B04E?D01:E5D0CEMH049<C@0mAdP0@4Y;04=;D00j@4X0<SHo034f
>`0/<CD0:Rha02/_<P0V:Rd0;Bhc02TX<00b<C/0=SE2051@G00];CL0?3a402d^<P0X:RT092HR02HX
8`0Y;2H09BLS034c<P0`<S40=cPk03@d?00b=Ch0<cLm02lf?00^=C/0;3Hh02Xd=@0U;c00:C8a024W
9@0R:2H0:B/Z024U9P0T:2T09BDW028P8`0U8bH09R4U02TT:00V8BD09B<V02DU9`0S9BL0:Bd`02/[
<P0P82T0:BTa02/[<`0R8bL09RLY02TZ:`0Q8b408bDP02DW8P0O8Q`071hH01`Q7@0K7Qd07AlN02@V
9@0I6QT0820P01`L700M71`07A/L01`J6`0L6AX06aLH01/J600I61H06QTG01`K6@0M71X201XI5`0<
01dL6P0D4a4051<A01/J600H5aD08ahP00l:2`0G4Q@06aHG01TD5P0Q71d06A@E100I51H0100I51D0
>3Dd05aHE`0K5aH201HB4@1201dI600G4a805Q8A01DA400H51<0510?03Te=@0S7b4040`>01XE600G
4aD05Q8A01DA400E4@h03`/801TF4P0M6QD06QLC01TD400I3Pl05``=01L<3P0G3@h05@`=01H>3`0>
20P0<Bd/05QFE00F5A<04Q4?020M700U7al040X:01D?3`0F41003PP801<=3@0B30`04@/;01<=3@0E
3`l0618B01HA400A3@`05@l?01LA4@0@2PX04@P901D;300D2P/05@T;01L9300H2@`06@T<01X<3`0H
3Pl05`d>01D;300C2@X04PP902@J6`0C2PX05@/<01@:2`0A20T060h?0P0E2`X01`0F30/04`T801<9
200F30/08ALF01D;2P0?1@@00P0F30/06P0A1PD05PL901H82@0G2`h040L;00X41`0^:Bd0UiFH02h/
;@0C4@l05A4=01<?2@0>2@@050X801X>3P0E2@T0710@01/?3`0I3@d09a/K01461P0@10@03P@401X>
3P0A1@D04`L70P0E2@T01@0C1`L04PH601<71`0D20P04`L700804PH600H04`L701@8200@10H05@T;
01H:300C1`T201451`0H01D92`0F2P`04PH801<72@0D20X03P8400d10`0B1PP03`<50186200H30h0
3@430186200E2@/04PH801@82P0E2@/04@D701882P0I3A402`4301L<3`09004060`@0P0E2@d03P0B
1PX050P<01@8300?0`L05@T=03HZ;P0E2@d04`L;00/00`0F2Ph040@801452@0B1PX04`L;200B1PX0
0`0A1PT050P<01@8300201452@0?01@9301?@dL09QXN01<82`0A1@T05PX>00h31P0C1`/05@T=0145
2@0C1`/050P<01<72P0D20X04`L900804@D701@04PH801H:300@10H02P0001@82P0A1@L03@830145
1`0C1`T04PH801<72@0;0@807Q8D02hR900?10D050P:01H:300D20X05PX<01441P8050D80P0E1PT0
2@0D20X04@P900`20`0@1PL04`X;00P10@0@1`P04@D700T0000202PL7P0D01451`0C1`L03@8100l4
0`0F2`T0XIJB0>;He00]8Ql04`L700l31@0B1`P05@T;00h2100@10H050P:01451`0A1`P050P:01D9
2`0@1@L401451`030186200C1`T04@D700D04@D700`050P:00l51P0m<C<0FdmA01`@4P0>0P@03@83
02`Q8P0D20X03P@501@92`0F2P`Dooooo`006oooool201D;308050X;0P0C2@X04`0B20T050X;01@:
2`0B20T04`T:01@:2`0B20T04PP801881`0B20T04PP801881`0K4A804PX:00d30P0D2P/060h?00`2
0`0B1`/00P0D2@d0400Q5QX04@H:01/@5017?40060dA01462P0C20`040D901<8300F30d040H701T?
400A1`P060h?00l51P0@1PL201882@8040H70P0B20T0100A1`P05@/<01@:2`0B20T201D;300601X@
4@0L4Q<04`P<00l4200A2PT03PT60P0=20D06@0F3P`07aHG01X@4`0A1P`050L>01L:4@0F2A005PH@
01<6300B1PP04`L901@82P0E2@/05PX<01P<3P0D20X050P<01P<400B1PX04@D901<82P0A1`P04`T:
01@:300C20`00P0A1PX09@0B1`/04`P<01@93@0E2Ph05P/?01872`0D2`h05@/>01<8300I41<050X=
01<8300B2@`04`T=01@93`0D2a005@/@01<<4`0A2Q403PP<00`62P0=1`/040X<01<=3`0D3Q004P`=
018<3P0F410050`=01D?4@0<1PP05a4C018<3P0C3@l04P`>014;3@0B30h00P0E3a40:`0D3Q004P`>
01@>3P0G4A402P@4024K6`0<1`L06A<C00`61P0K5AD030H601/E5@0@2PX071LD018?2P0F4`d05a@=
01DB3@0C40X04a09018?2P0C40X04Pl8014>2@0C40X05a@?018>2`0D40h06ADB01dI600F4Q406ADB
01TE500K5aD06ADB01HB4@0H518071PG01@C4@0B4@l05aHD01XI5`0I61H00P0K6QP201XI5`0c01`K
6@0O7Q`081lM01PH5P0M7A/06a/I028R800l?3X06a/I01XJ600[:bT0Rh^902l_;@0<30X07alM01dL
6P0P7ad071/I01/J6`0N7Qh071`L01hO7`0N81l07AlN01dP7`0O8b808RHU020T9@0P8B<08RHW028V
:00Q9BP09BX^01lU:`0W;3809bhd02@]<P0V;C<0:S8e02de=`0^=SP0:c@e02La<`0X<S@0;STl02Xe
>@1KIVX0AU=H02Xg?@0gA4X0;3Xo0080<3m400/0=DA903U8C@0hAd`0=DA903i=DP10Ce@0=TE:03Y9
CP0hAd`0=T=503Q4A00203M2A01003]6BP0nBDl0@diE03M1BP16D5T0@D]E05QRK01<F640?daE04=A
FP0nC5D0A5=J02hmA015E5T0AeIK045@E@17EU/0BUUP049AF017EEh0BEMP04ECG012DEL0@e9E04IE
F018F5P0AUIF04]KF`1>GF00BUUN04YIH01@GVH0CUeT04mNH`1BHFH0EFAY05MVJ`1JJFh0DV5V05ET
I`1@Gf80BUUL04]JG@1:FE`0CE]L04eKF`18EUH0CUaL05m]K@1QKfl0FfUY05m]K@1PKVh0GVa/065_
K`1VM7@0J7Md06EbKP1/NgP0MH5o07R4Q01jQHL0O8N907f8R`80OXV=00D0P8^?086;S@28T9<0PHV;
07f5Q`0207n7R@80O8B602T0Q8b>07^3Q@29TI@0SYJI07n7RP1nQH/0Ph^B0829T01lQ8/0PXVA08N@
U`1kPh/0OHB<07b5S022RY40Q8^C07j7S01cOgh0M81n071lNP1ePGl0Mh>1075mN`1fPX00JgMe06Yf
M01_NgT0Mh>106McK`1WLV/0GFQR06ehLP1HHed0FFAN06AaJP1NJVH0EV9N05m[I`1QKFT0Gf]Y06Ea
K`0206A`L00O061/JP1OJfT0GVYV05]WI01KIfD0FFEU05aWJ@1OJVh0Hfib05aYK01EHfH0EfEX051N
H@1:F5/0CUaO05=QI01AGf80D5iQ051NH01=Fe`0BUQK04UEE`19De@0AU1B04I@D@18E5@0BUAE04A?
C`14D500AE5A03a8B00203m;B`0K03m8C00mA4`0>cm803Ll@@0Z;c<08bH[02@W:`0P8BH09bL^034a
>`13@dd0BTYE03<c?@16ATh0YJJ[051AD`0c=C@07R0M02<U800[;BP092HS03<e=00_<380<S<f03Lg
?`0c=Sd0;S<i0080:S4g02L0:c@g02`d=P0R:R`09Rh_02P^;P0]<c<0:bd_02d^<00Y:R`092@V02/Y
;00_;C008R0S02TW:P0R82D08B0U02TZ;P0U:2/082@W01PK800S8b/07QlT01`M8P0S92L09BHX02DW
9P0N81d08B<N02DW8P0Q91h07R0K01LI5P0T9RD05QPG01LI600J6a/0820P01XJ6P0L6a`00P0O7Ah0
1`0Q7Ql08AdN020O7@0L6aT06aXH01dL6P0L6aT00P0H5aD03@0I61H071/I01`K6@0H5aD05QDC01LB
4`0P6Q`06A<E01`F6017@D<08A/M01TC5@0J51H00`0K5AL06P0J51H07ATH018>3@0O6aX061@C01DA
400@30/05A4@01TE500?2`X0510?01/G5P1VHV<0=C0d00d8300K5QX05Q8D01<?400J5QD04Ph<014=
2P0o>cP09b@O00H3000L5a<06a4B0P0H3Pl03P0G3Pl05@`=01082@0N61P040`;00d9200@3`d06QHE
01LB4@0C3@d02`D501D?3`0J51@040X:0`0=1`L0700B30`06A<C01dG5`0J51@03`T9010:2P0G4100
60l@01`C500N5AH060h?01P<3P0F2P`05PL:01D62@0G2@`05`d>01H<3@0E2``050X;01<92P0I3a00
1`0001P>3`0700007A<D01882@0E2`X201H<2`804`T800<05P`;01D;2P0B20L00P0A1`H07P0?1@@0
50X900h0000U5aL04P@701P=4@0@1`X03PP:02LS900300004@d;00D0000E40`03`T401@:2@0I3@d0
4PH601L;2`0E2@T04@D501H:2P0=0P806Ph>01451@0H30`03`<301861P0E2@T04PH6010410804@D5
00h050P801<71`0B1PH04PH601<71`0D20P03`<501L;3@0J3Q005`/=0186200@10H03@4301@82P80
4PH801T05@T;00l31@0D20X05`/=01451`0S5aT0=RX/01L;3@0?0`D050P:0186200K3a408aLI024E
5`0@10P060`@01862P0>10H05`/?01452@0B1PX03`<701D93@0T61`06PhB00802P0200D0;R8V00/0
0`0D20`02@010104200301<72`0301862P0@10P03`<700H04PH:00/04@D90104200?0`L04`L;01H:
3P0C1`/03P860104200E2@d040@800`0100201H:3P0301<72`0@10P050P<008050P<00l05@T=01<7
2`0B1PP04PH801<72@0E2@/04PH801@82P0@10D03`<301<71`0B1PL040@600d10`0B20T00P0E2@/0
1`0M4A<08QHH00l31@0=0`@05@T;0186200D1`T00P0C10L201421@0E00h2100C2@X060h?00h41@0G
3@h0200004@j>`13=cT05`/=0147200M4A<04PH801861P0C20H05``:01881`0e:RP0KF9N01/@3P0C
1`L05`/=00<03`<500L04`L900l31@0D20X050P:01P<3P0P51H05@T;00803`<500@040@601451`0C
1`T05@T;1P0A1@L0300;00405PX<01H:300>0P@03`@50186200F2P`050P:03da<`0?0`D04`L90186
21Cooooo000Kooooo`0F01P=4@0A1PX04`P<01<8300A1PX060dA01T>4P0D2@d02@0201872`0C2P`0
6PlC01872`0>1@L081HG01872`0A1`T04`T:01D:3P0D2@`04PP901882P804`P<00T050T=01052@0C
20`06a0D01X?4`0G3100>Rlc01D:3P0?10P00`0D2@d200h41@0400l51P0G3@h05@/<00d310804`T:
0P0D2P/06P0C2@X04PP901<9200E2``04`T:00l51P0A1PX04`P<01882`0F2`l06@hB01@93`0=0PP0
50X=01hE5P1gKVl05@`=01H<3@0H3Pl050X;00`11@0Q5QX030<500l4200G2`l05P/>0P0D2P/02P0C
2@/04PL;01872`0C20`03`@807mdNP12=cd050T?00T0100D2@`200l5100301471`0B20T04`T:0080
4@L801406@hB01@93@0I3Q804PL;01<93@0K5AL030@7038Y;00M5aT0;2DY05mFF`0=1`/03`P<01H<
500F3aH03@@<014:4@02010;3`<04@/?00/05@`A01T@5@0I41@0200401482`0F31001@0101`F600K
5AL06Q@F00H00P02014;3@03018<3P0C3@l04`d?00804P`>03D04`d?01XD5P0=1`T040X<01@>3`0<
1PH05@l?01LB400D3``040/800l:1`0B3@T07APE01@?2`0@2`L050l<01LB3P0C3PX061<@01HA3P0D
3`/050l<01HA3P0H4`l07a/H010<200O71L06aLD01@A3@0H5A0061@A01PD400G50l05a<@01PE4@0I
5A805A@B01@C4@0F5A<06QTG01/J600G5Q@061LE01dL6P0Q81h08R4O020O7@0O7Q`071`J01XJ600L
71X07alM01dM6`0201/K6@0_02LW9@0e=C<05aLE01LG5@0Q8Al061PH01/K6`0L71`06a/M01`L7P0M
7R007QlQ01`M8@0M8B@08RHY020S:00L8B@07bDT024U9P0R:2P092T]02H[<@0F7B<082P`02T`>00T
;C808bhb02Tc=@0Z<cD0<3Pk02de>00Z<SD0:C0f02Tb=`0/=C/0;3Lm04=>E00^>T40=T=;02llA00b
?dH0<Ci4038oA@0iAT`0?DY@03Q5B`0gA4X00P0jAdd0;P11CU@0A55G045>E00lBD/0=T9002`h>00g
@T@0BEAH049=D`0mAe00BE=L04]EGP1AG680DeiT04MDE`16E5L0@e9G045@E@11D5L0@U5H04ACFP0i
B4l0@E1G04]JH018Ee`0AEAI04]JG@1:G600@E=G03U;CP12E5H0AeUK04EGF00nD580AeUK04YLGP1<
GV00C5iR04QJGP1>GF80DV5V05IUJP1DHfH0Df9U05MVJ@1FIFP2051PH00L04QHF00oCdl0CUiN05MU
I@1>G5`0EVAT05UWI`1DHV80FfUY069`L01JJ6P0GVa/06=aL@1ULg<0IgEe06MfL`1TLg00J7Qg075o
O`1fQ8D0Lh6408>>TP1kQX/0NHB:07n8S`24SID0PhbC08N>UP80PXV?01L0O8B708::S@1mQHP0PHV<
0828R`1oQhT0P8R:08::S024S8l0OXN<09bV[02e`<H0PXbB08><T`1lQhd0NhF<07Z3RP1aO880OXR?
08RAV01nRHd0Mh>407N3P`0207J2PP80MX:004/0LWil075mN@1aOGT0L7ah06mkM`1`NgL0J79[06E_
I`1RK6@0GVMR05URG@1GHU`0GFMT05aWH`1QK6P0HF]Z061/JP1TL6h0I6i`069/KP1NJ6T0HVa]05MQ
HP1TKVl0GfUZ05USI@1MIfT0EEmQ04iHFP1=FUd0CEaQ04mNH`1=G600D5mR055PH`1=GEh0CUiN051P
H01<G5/0A5AC049BDP14DE80CeYL04mJGP13CU40AeEF04mJG015DU<0CE]L07F3P`18EUH0=D=303I4
A00mBDX0<3Tn04mFG00b=c/09bX_030a=P0Q8RP0;Rhf02XZ<P0h>480<cHo03m2BP0d=CT0;c0b03Xk
?@0o@D00;c4`024S8P0[;B`06adL02TZ;00a<S@00P0e=SX0800^<CH0<CHj03Hk?`0i?T80:c0d02hd
>00W;300;S<g024V:P0U:Rd06AhQ02HZ;@0L71h0:2HW02XX:@0S8bD07alQ02TX;@0O82@0;Bhc020S
:00V:Bh08BH[01lT:P0U:Rh082<X02``<`0I7B00;Blb024R900J6ad07QlO0P0R8R00400N7Q`061PF
00l?3`0R8R806ATI02h^;P0I61T09bDV01`J6`0K61T06aLH01dI6P0O6Q/07ATJ01XH6@0L6Q/201dK
700N01XH6@0H5QL05Q@E01XH6@0I5aP061HG01TG600D4Q<06QHG01LC500E4A805a<D01`H6@0N6Q/0
5a<D01PD5@0L61T061@E01HB4`0L61T06ADD01/G5P0M6AP06aLF01LC4P0D40l06ADD01/G5P0I5A@0
5A4@0P0D40l601LA4`0;01D?400I4a<0?SPh02DO7`0I4a<03`T901H=3P0B2@X04@P9010:2P0C3@d0
100E3`l02@0C3`h04`d=018<300O6AT071HF00`61P0L5QH08Q`L01D?3`02010:2P0M018<300C3@d0
5@l?01L@4@0F3A0030<601P>4@0A1PX0714E01052@0H3A405P/?01052@0C1`/04PH:01D:3@0B20T0
40H70147200C2@X05`d>01/A4P0E2``040H701@:2`0E2``03`D601H=3P0?1PL00P0A20T00`0:0@80
4`X;01482@0401482@0B01882@0@10H04PH801@82P0B1PP04@L801@:2`0C2@X040H701@:2`0I3`h0
5@/:01061@0>0P807A4A01<71`0=0@404PH60P0H30`06P0?10@04`L701861P0E2@T02`0000P0000M
4A<02`0101T=3`0B1PP03@4301@82P0=0P<03@430186200C1`T0300201041P0L4180=RX/01451`0H
3Pl0200001@82P0B1PP050P:0P0G2`d01P0B1PP02P0001/?4@0800009QXL05E9B`805PX<00L04@D7
01hB501MDE<06@d?00l31@0?0`L03@4500804`L;00@03@4500/00`0B1PX04PH:0P0C1`/03`0B1PX0
4@D901<72`0C1`/04PH:0104200B1PX050P<01X>4P08000050P<01472@0D20`06@dA00l52@0200h3
1`0:00l4200B1`/050T=01H:3P0>0PH03`<701`=4P0E1P/03@44010420804`L;0P0@10P601452@07
01L:400]82L07Q4H00d31@0G2`l040@601861`0201861P0S01461@0@1@<040D301461@0C1`T02`01
01D92`0A1@L06Ph@00l31@0=0@<04`L900d3100?0`D05@T;00l3100C1`L05PX:01@8200B1PH03`<3
00h20P0K3`l03`@400P0000?1@@08aLG01T=3@0F2PX040@400d10@0?0`<04`L700l30`0@10@00P0C
1`L04@0B1`D040@401T=3`08000050X;01451`0F2P`04PH801451`0@10H03`<501451`0B1PP040@6
01@82P0B1PP040@600804@D700<040@60186200B1PP0100B1PP0300D20X04PH801041P0@10H04PH8
01@82P0B1PP05@T;01/?4@0H30h040@601@82QCooooo000Kooooo`0C01D:3P0B1`/050T=01@93@0B
1`/05@X>02<H700O5AP06a0D01H;3`1:?d<040D900`21@11=SX0?34e01hC5`0A1PX040D901462P02
01872`0801D:3P0G310060dA01<8300?10P04@H:01L<400E2Ph201<8300601052@0C20`04`P<0146
2P0C20`05P`=0P0E2``0100K4A806@l@01882@0B20T301<92P804PP901P050X901@:2`0C2@X040H7
01462P0C20`05@X>01X?5@0:0@D06a4F02@I8@0F2a003@<402HL7@0A1`P0718C00h41@0B20T060h?
00X20P0J41404PP901061`0B20T201@:2`0;01<92`0C20/04PL;01P=4@080080<BH/01dB6@0J3aL0
50TA01472@0A1`D00P0A1`H0100B20L04`T:01@:2`0B20T201<830804PL;01h050/>01TC5@0?2@/0
5Q0B00`6200T7R80A3i201XD600D3A@03`T?0109400A2a403@H=00h8300A2Ph04``@01@=4@0E3a<0
6a<H01493P0@2@d07ADJ00d52P0F3A804Pd>01LA4`0D3Q009AlQ01H@4P0B30h2014;3@@04`d?01@0
40X<00h82P0E3a404`d?018<3@0D3Ph04@/;01@>3@0C3P/04Pd:01@?2`0H4`l04Pd:01XE4P0K5Q<0
5a8?01@?300F4@h061<@01HA3P8050l<00/05Q4>01PC400H51006ADA01XG4`0B3`/061@@018>2P0K
5a<06QLC01TF4P0201TE4@0401PD4@0I61H061LE01TH5P806aXH00D061LE01XI5`0K6QP071/I01dL
6P0201/J60<06QXH0P0K6aT201`L6P0701PH5P0K6aT06a/I01lO7@0J6QP06ATH01lO7P02024Q8P80
7b0S02007QlR01`O8`0L82@07R4U01lT9`0O92P08BLV02<Y:@0P9RH06b<V01XQ:@0Y<3P07bPa02</
<`0O:Bh07bX^02hi>`0V<3809blb02Xb=@0_=c/0<3Pn02lh?@0[=3X0?TQ>02Ha=`0e@DP0OX^C04QE
G@0_?4<0<Ci403A1A`80>4E;00@0=T=903M4BP0kB4h0?T]A0P0mBU00:00oC580@4e?03M4A00a?Sh0
>dM;03]7CP0g@T/0?TUB04MCG016DU/0Ae=J04MDE`0kB4/0?Ti>03m?C`10Ce<0@4mF03m>E@0oCEH0
@e5J04IDG@19F5l0A5=H045@D`13De<0?4i@03]=D016F5/0AEMJ04=EF018FUd0BE]N03mAE01:G5l0
AUQK051RI@1>H6<0D5mT055PI@1CHVL305ASIP0`059RHP19FET0BEUH04aLF`18F5L0D61O086?S`1L
JVX0CUaL05ARHP1HIVH0FVQX05QVIP1MJf/0IG=c06AbLP1RL700IWAd06EeM01ZNWT0KWin06moP01d
PhD0NHN;086<TP1lQXh0NhF>0869T`24S9H0P8VB07j5S`21R900QHbD0868SP22RHl0P8N=08::S@21
RH/0OhN90828RP21RH/0PH^=08F>T`2U/;H0[KRn07f8SP1hPhT0PXfC0P23SY@06P1oRY00O8N=07^6
S01gPXH0N8>607J2PP1dP800LGem06ijN01]NGL0KWYh06mkM`1^NWH0JgMc06QdL01WLV`0Hf]U065X
H@1OIUl0GVAP05aUH@1MIV80G6IR065/J@1NJ6H0GVUW0P1SKfd0<01QJfd0HVe_065[K@1ZMGL0H6]]
05eXJP1OJF/0F69T06=^L01JI6H0Ae5C045=D@16EEX0DF1U05=RIP1DHfH0DV5T04iNG`1>GUh0CUiM
04YJF@14E5<0@U9A049@D019E5L0B5=F03]7BP0lBT`0@4i?03i<C@0lBT/0A5=C03U8B013De<0=DE4
0390@@0_>S`0<3Pk02DZ;P0U:2d0<C4h04a;D`0c<SX0<30h03Hi@@0i?4@0?45702d^<08092HU02d0
:2XY028T8`0T9BL0:BX/02<T9P0/;C40>3Tm02h_<`0g>3d0<3@h03@i?00k@4<0@TI:03<h>`0]<SD0
<cLk03Pl@00Q9RT082@X02DY;@0m@4@0:BPZ024N7`0V92D0<30b02PX:P0U9RX0<cHk03e0A@0X;380
9b`b02<X<00S:Bl092T_01dR9@0^<SD06AdP028T9`0W:2X07QlQ02DV9`0W9bL08R8R01hN7P0L71`0
0P0Q8B400`0^;Rh06ATI020O800201lM7P0601dJ6`0M6AX07QXK01lJ6`0M6AX071PI0P0J61T02P0I
5aP061HG01PF5`0K6AX05Q@E01`J6`0P7Ql07A/L01XH6@0I5AH201PD5@0F01TE5P0J5QL06aLH01hJ
6`0K5aP030P903`h>@17@d@061@E01TE500G4a805A4@01LC4P0I5A@06QHE01@@3`0G4a805Q8A01DA
400F4Q405a<B01D?4@<05Q0B00d05@lA01@>400X8R@081XL01D?4@0B30h0;2HX01D?4@0E3`l04`d=
018<300C3@d050h>00@05@l?010050h>01<=3@0D3Ph04P`<01PB4P0X8R808A/K01H@400C3@d04P`<
014;2`0B30`04`d=01@>3P0C2P`06PlC0P0B1`/02`0M4QH04PL;01H;3`0F2`l06@hB01D:3P0A1PX0
5P/?01@:300F30d05@/<00805P`=00d060h?01D;300E2``05@/<01H<3@0E2``04PP901D;300@1PL0
6a4B02DK700K4Q<040L800H04PP90P0J3Q001@0I3@l04`L901451`0A1@L050P:00804PH801H040@6
00l31@0H30h081@D00l30`0F2`/06@d=01L;2`0B1`L04@D501<71`0G2`/03`D501D:2P0H3Ph04`L9
01451`0C20T06`lA01H:300P51H04@D70P0B1PP201451`060186200A1PL04`T:01D92`0D20X05P`=
0P0C1`T0100B1PP04`L901D92`0E2@/20186200A01<72@0D20X04`L901882@0A1@L03`<501D92`0;
0@807A4C00h2100D20X0:1`P01<72`0?0`L04PH:01<72`0D20`00P0B1PX201<72`0>01862P0A1@T0
4@D901862P0A1@T040@801452@0B1PX0>2``02PL800<0P@060`@01462@0=0@D201<8308050T=00h0
50P<01<8300B1`X04PL;01462P0B1PX03`@601H:3P0C1`/04PH:01@8300C1`/04@D9010420D04@D9
02@040@901T<500B1@`040@901@8300?0`D04`L801861P0B1`H04@H501050`0@1@804@D401<72@0I
3@l04@H8038V:01?@dD05@X<00d3100?0`D04`P90147200C2@X04@D601<71`0@10@03`<30104100D
20P05`/;0104100C1`L04PP800h20P0A1@D201<71`0401@8200B1PH04@D5010410H04@D501803P84
01X>400/82803`<50186200<0P<03`<501<72@0E2@/040@600h2100C1`T04PH801@82P0E2@/04PH8
01041P0A1@L60186200601@82P0B1PP040@601041P0B1PP050P:0P0A1@L201H:30804@D75?ooool0
01_ooooo0P0C20`201@93@804`P<00`081DI01`A5@0=0PH02`0401H;3`0J3a<0714E03DZ;P0B1`/0
40D901H;3`0H3A4201@93@0501D:3P0H3A406a0D01`A5@0B1`/00P0@1@T02@0C20`04PL;01052@0F
2`l05``@01D:3P0@1@T04@H:01D:3P0201882@0401061`0C2@X04@L800/10P804@L80P0B20T00`0A
1`P040H701<9200201882@0E0147200B1`/04`P<01lD600B1`d05@X@02/P9P0X7BD060dB01P>3`0C
2@X08aTJ01@:2`0=0`@050X;01X@4@0O5AH060h?00L0000E2``05P`=00@04`T:00T04`P<01462P0B
1`/04PL=01@9400B1`l060dE01872P0B20H00P0B20L05`0A1`H04@L801882@0H3Pl04@H:01@93@0B
1`/05``@01072P0<1PP03`T;018<3P0D3Q003`T=00X4200A2`l04P/B01D>5@0F3aH05a0G01<94@0C
2Pl050X?00804`X?01004P/?018<400H4QH05Q0D00@00P0400<09b4U02DO8@0@2P`05a4C00d72@0I
4aD030H800l92`0@2P`04P`>0`0C3@l0200K5AL04P`>01H@4P0=1`T04`d>00h8200D3Ph050l=0P0C
3P/01`0D3`/05A0<00d81@0J5A807APE01HA3P0B3@X00P0G4Pl02`0F4@h05A0=01D@3@0F4@h05a8?
01HB3`0C3``05a<@01DA3P0M6AH05A4>008071PE00@06aLD01XF4`0I5A8061@A100J6AL01@0I61H0
5aHD01`K6@0I61H061LE00805aHD00h061LE01PH5P0I6AL061PF01LG5@0J6QP071`J01/K6@0M7A/0
ADE301dM6`0D518092@R01hN70808B4O02P0820O01lQ800P8R408b@V028V9`0P92L07R8U028W:P0V
;2`07bDS01HL700U:b/0>d=601XQ:@0U;3@0:34j061YL00S;C<09C0d02/f>00X<C@0;SHi02/c=P0Y
<SH0;SLl03@m@P11Be4082/a030k@@1RKWD0EF9Z03m<E00^>d80=45703Y7C@0iAT`0=T=903Q5B`0j
Add0?4U?0P0oC5804@0nBe40@4eC03i<D00oCE00>dQ>03Y7CP0kB540?DUE04=?F`17Del0AE5M04MD
G01<FEl0AUAH03i=D010Ce80@U5F0080@E1G00@0@U1I04QFG`17EEh0AE=K0P13DUL01`14DeH0D69V
04=EF@11DeL0A5IJ04EGF`1<GV800P16F5`01`1>H6@0GFmc065cM`1AHfL0Df9W055PI@1@Gf@00P1E
I6L0101AH6<0CEeM04IFEP18F5L204iNG@0J059RH@1@GUh0E69R05e[J`1KJFT0EVAT05]YJ@1MJf/0
GVa/06=aL@1RL700Hg5a06]iN@1VMWH0K7am071oPP1_OX40Lh6507Z7S@1mR8h0O8N>07j8T@22RYD0
PHVD07j6T@1oQY0207b3R`0508>:T01nQH/0O8>90869S021RH/00P1oQhT08`1nQXP0OHN907f6R`1n
RHl0MX6707j9S`1oRY00TIbR08>>U01oRY00PhjD086<TP1kQX`0OHR<07N2Q01cOgl0LGem06ahN01X
M780Ig=a06ijN01_NgL0KWYf06UeL@1RKVX0H6]W05eUG`1KHU/0FF1I05YPG01LIF80GVMT05aWH`1_
NGP0Ig5`0080HFe[01d0F6AT05i[K01VLG<0G6Y[06=_L@1TKg40F6EV04aJF`2>VI/0Y[:d04mMGP12
CDl0;Se003Q7C018Ee`0CUeQ051OHP1AH6<0CUiO04]KF`1:FUT0AeMF04=CDP12DU40@4m>04A@D013
CU00>DI703U7B00203]9BP1?04ABD`0nC4d0?4Y=049AE00c@D@0<cm202Xe=`0/=3L0:c4e024T:@0V
9b`0BTYA02@S:`0[:c<0:Rdd038e?00j?d@09RLY028T8`0V:2L09bTX024S8P0O82808b@V02`];`0Y
:Rh0<34e028S9`10@DH0:Bd`02hb=@0b=ST0?413038f>@0X;2l0;S8e03Lk?P0X;2l07b<V02L[;P0a
<cL092@V01dK700W9BH09RHX03Xj?01aLWH0=3Ll03i1AP0V:C008RL]01hR:P0M8RP08bP/02DY;@0L
82<08BDX04E7BP0R8bD06AXL01/L7@0O7al08B4Q020P800M7Ad06ATI01hN7P0B4Q808B4Q01dL7@0X
9RL08AlP01lL7@0M6AX07QXK01hI6`0K5aP07ATJ01TG600201LE5P0:01PF5`0I5aP061HG014?400K
6AX07A/L01HD5@0J61T05a<D01TE5P806QHG00T061@E01LC500D4140510A00`82@0P71d0920Q00l;
300J5QD00P0H51<00`0M6AP0920O02LS8P0201PD4`0601HB4@0C3`h04`l>01DA400D3Q005Q0B0P0G
4A<0300D3Q004`d?010:300@2P`06Q@F01@>400I4aD04@/=01@>3P0E3`l05Q0@01D?3`8050h>0`0E
3`l02`0D3Ph04`d=01D?3`0<1PH03@L701lI6@0E3`l03`T901@>3P0C3@d04P`<00804@/;00P04P`<
01H>400M4QH04@H:00h41`0O51P02@0201dB5P801`0000@0714E028G6`0/8BD060d@0`0C2@X20188
2@0302<I6P0P5QL05`d>008040H70P0F30d01@0@1PL050X;01/A4P0G3@h04`T:00H04PP901404PH8
01@82P0E2@/04PH801451`0C1`T05@T;01<72@0G2`d05PX<01451`0B1PP050P802LK6`0_8b<02000
01lC4`0200l30`0=00d20P0A1@D05@T904<g=`1ZGUh0300200h3100M4A<060`>01<72@0L41804PH8
01@82P0401<72@0600P0000B1PP05PX<01dA4`1LD580D4A60P0A1@L0500B1PP04`L901<72@0B1PP0
3@4301041P0=0@<040@601P<3P0D20X04@D701<72@0M4A<05PX<01<72@0A1@L0RWj202`P90090040
3@<50P0E2@d201862P804`L;00D04PH:01452@0@10P04`L;01862P0201452@0901862P0>0`H02P02
01<72`0=0PD07A4E01D93@0C1`/04`@9008040@800h03`<70104200C1`/05``@01@93@0K4A@03`@8
01D93@0?0`L03@4501@8300I3A405`/?01862PD04@D900L04PD;01032P0A10/060`A0104200;0040
4PH700804PH600@04@H501050`0@1@<04PH60P0800009P0<0P<040@602@H6P0>10D03P8400X0000D
20X04PH801@82P0J3Pl040@401@8200F2PX04PH600d10@0@10@05@T901H:2P0K3`l05PX:01<8200@
10@04@D501@8200C1`L04@D500l30`0C1`L04PH60104100?0`<040@401<71`0I3@l060`>01T=3`0=
0@<06@d?0P0?0`D02`0B1PP05@T;01041P0>0P@04`L901041P0E2@/06Ph@01<72@0?0`D04@D700P0
4PH80P0@10H20186200601<72@0@10H050P:01P<3P0F2P`04@D75?ooool001_ooooo01804PL;01@9
3@0C20`04`P<01@93@0B1`/040D900`31@0<0@D08aPL00`21@0A1PX0714E01lD600>0`L06PlC0146
2P0<0@D201462P0501052@0B1`/04`P<01<8300D2@d00P0B1`/0300C20`04PL;01462P0A1PX03`@8
00h31`0B1`/05``@01P=4@0D2P/05@/<01882@804`T:00<03P@50147200A1`P00P0B20T00`0A1`P0
40H701<920020147200E01882@0C20`04`P<01`A5@0@1@/03@8801H;4@0R5al06Q0D01061`0>10D0
6Q0A00/10P0E2``040H701X@4@0m<c@050X;01`B4`0<0P<05P`<00804`T800`04`T901<92P0C2@X0
40D801dB5P0F2a405@X@00/01P0B1`d03`D601<91`0C2@P201881`804PP901D0718C00h31`0A1PX0
4@H:01dB5P0:0P@02`D701XD5P090`D02084018<400F41@07QPL00X42P0700L03`P?01XA6@0D2A40
50T?01D93`0D2@l00P0C2Pl02P0E3a<0100201/F6P0=20`05Q@G08f8S02ESi406A<E018<3P0@2P`2
018<3P03010:300A2`d04`d?00<04`d?00T02`D701LA4`0L5QP030H801@>3`0E3`l05Q0@01D?3P0C
3P/00P0D3``01`0D3`/04@`901D@3@0F4@h050l<01<>2`0E40d01P0F4@h03@0[9b@05A4>01hJ5`0N
6QL06aLD01LC400J5Q<06aLD01`H5@0K5a@06QHC01PD4@0I61H00P0J6AL02@0I61H05aHD01HE4`0M
71X06APF01PG5@0G5Q@061LE01TH5P0401dM6`1<01hN700O7ad06a/I02<S8@1;BdT07AdK014A3`0R
8R008R<N020Q700N7aX06a`H01dO700O8Ah092HU02<W9P0P92D07R8S028X:00V;2`092XX01TO7`0/
<S80ATiA01lV;P0T:c<0<CY30;o8c`0d?T<06bHZ02D`<P0`>C`0;3@g02H`<P0T;S40:34f02dh?00X
<cP0;3Lm02`i?`16DeX0@e1H030mA@0a?TH0>dQ@045>EP0oC5@0>dQ@03m<E00nBe<0>DI>03Y7C`0o
C5@0@4eE03e:DP0d@DP0@TmE04EBFP0oC5H0@4aH03U5D`0mBEL0BEES04A@GP13CeX0AeAL04=@E`0m
C4l0?4]>03a;D00oCUD0@DmH049@F`18EV40AUAM04=BFP80@E1E00X0@e9E03e?D`11DUT0@U=J04MH
G`0mCUD0AUMN04QIH01=GVD0CUmV0P2M[[D01`1@HFP0E6=X059QIP1AH6D0E6=V05ETI`1AH6<00P1:
FUX08P1=GE`0CUiM04eMG01DI6<0F6IV05UWI`1GIFD0DV1P05=QH@1OKFd0H6i^05i/K01VM7@0JgUi
06QfMP1WMGH0JGQk06]jOP1]O840L7n407B2R01ePXX0O8J?07f7T01oRI<0PHVD0828U01mQI00OHB>
07b3R`23RY80UYfS08J=T`1lPhT20828R`80OhN905d0OXJ807b6R020RHh0PXfA07j9S@25T9@0Lgj2
07Z5R@1nRHd0MX6507^6RP20Rhl0OHR<07b7R`1eP880LWin071lO01]NGT0JWId06UeL`1/N7H0KGUe
06ahM01VLVh0GVYV05aWH`1NIV40Ff5M05QNFP1GH5/0FV=P05aUHP1`NWT0NhN506ahMP1PK6`0G6QX
05APH01FIFH0GVa]059RHP1HIfL0EfEV05m^KP1=GEd0Df5R06YiNP1FIVH0BUQI049BE01;FUl0Df9W
051OH`1>GF00CEaO04aKG@19FET0AUIE04=CDP11DE00@51?03i=C@0nCDX0?Ta<03U7A`0kBDT0?4Y;
03e:C01;EUX0@TeA04A?E@0oC580=T57034l@@0_>S`0=Si1020U:@0f>Ch0<34f02/[<@0Y:2h0>3Tn
03Dh?@0m@4D0CeAH024R900R92<0:2XY02T[:P0S9B@07b0R028S9@0a<S@00P0W:2`00`0U9RX0BT]@
02@X:`0202P/;`0Y038f>@0/<3<09b/^02P/;`0^<SD0:Bd`01dQ900R9RT08bHY02LW:@0M7Al08R8T
01/K7@0];Bl0HF9V020Q9P0^;c@07R4V02<V;@0R9R`08BH/01dR9P0U:Bd061`O028V:@14AdT08R<U
02PY:`0Q8B80820P02<S8`0O7al05QHF02PX:00J6QX0:BTY038b<P0E51D0928S024O800N6a`00P0M
6AX0100M61X06aLH01hJ6`0J61T201PF5`0D01TG600J61T06ALH01LE5P0N71d071XK01DC500K6AX0
5a<D01TE5P0J5QL06ADF01LC500E4A807QXK024M7P0O6a`061@E01LC500I5AH201DA400401HB4@0H
51<06aLF01`H5`806ADD00H05a<B01@@3`0F4Q405a<B01H@4P0G4A<201PB500<01H@4P0E3a4071HH
010:300K5AL04P`>014;3@0J51H04`d=01D?3`0F41005@l?0P0C3@d301D?3`0401@>3P0C3@d04P`<
010:2P<03`T900@04@/;01@>3P0C3@d04P`<0P0A2`/03`0B30`05@`>01@93@0>0`L060dA01T>4P0=
0PH060dA02dR9P0Z7b<040L907Q]L@1gK7003`@70147200201882@090147200@1PL081HG01hD5@0H
3Pl04@L801061`0D2P/04`L900@04@D700<05@T;01<72@0C1`T0100C1`T00`0?0`D04@D701<72@02
01<72@0T01H:300E2@/03P8400l31@0F2P`05@T;0186200P51@0?C4a044e=@0@10@0=RXZ020D500G
2`/04PH601451@08000040H601451@0:00004`L901H:300<00803`D601<72@0F2P`04PH801451`0E
2@/05PX<01041P0J3Q0060h?01451`080000:1`N0P0A1@L20186200A01451`0C1`T050P:01041P0F
2P`02@0000d10`0I3@l02P0001041P0O4aD0?C4c01@82P0800004@D700h21P0?0`L00P0E2@d0100@
10P04@D901862P0B1PX201<72`0301862P0A1@T04@H:008050T=00/04PL;01462P0B1`/06Q4C01D:
3P0700006@hB00L0000@10P06@X?01H52`0201<42@0>01<72`0D20`04PL;01@93@0600006a@F0189
300A1`X03`<700d11@0C1`/06@dA01L;3`0C1`/501452@0T01@8300>0PH04PH:01X>4P0>0PH03002
01041P0B1PP04PH601451@0@10@040D301D92@0K3a40300201X>400800002@0000l31@0K3a404@D7
00d3100L41803P8400X0000800003@<301D92@0B1PH040@401H:2P08000050T9075UI@0Q5AD040@4
0P0B1PH04@0A1@D040@40104100A1@D04`L701861P0@10@03`<30104100C1`L0710B00h2100<0080
3`<501L;3@0B1PP04@D7008040@60P0A1@L01P0@10H03`<501D92`0I3@l04`L900l31@L04PH80P0A
1@L201041P804@D700H04PH801451`0B1PP05PX<01L;3@0@10HDooooo`006oooool03P0C20`05@X>
01462P0A1PX05@X>01<8300A20X060dA01872`0@1`T04PL;01L<400D2@d040D90P0E2Ph01P0G3100
9a`P01D:3P0D2@d04PL;01462P804PL;00<050T=01<8300C20`00P0C20`301@93@0401<8300G3100
5@X>00l4208050X;00D040H70147200C2@X040H701882@0301<92P804PP901`04PP701061`0@1PL0
50X;01@93@0C20`04@L:01X?5@0D2@l04`T>01873`0P5QX06Q0A00l51P0B20T050X;01L=3P0E2``0
3`D600l71`0O5AH0KF=T01hD5@0@1PH04PP701<9200C2@T050X:0P0D2P/0500C20/04@H;01D:400T
6Al09a`R01H;3@0B20H04PP701<9200D2PT050X;01H<3@0G3@h0308503@Y;@0E2Ph0714E01L>4@0=
1`T03@P90P0@2P`06P0C3A4040X>01LA5@0B2a8040T@01@=500J4aX04@@=01<5300D1`h05PT@01H;
4@0G3Q<04`dA00l;3P0F4aH06aTL01XI6`1/Jfh0GEUJ01dG6@0G4A<02P@600`6200D3Q004P`>0`0C
3@l04P0B30h04@/=01@>400I4aD02@@501`F600B30d07QPH01D?3`0C3@`04`h;01D@3@0G4Pl05Q4=
01@?300C3P/04Pd:01@?30805A0=0P0F4@h201LB3`805Q4>00P0;2PV01@@3P0I5A<05Q8@01LC4@0K
5aD05a<A01TE4`806aLE00<06QHD01PD4P0H5aD00P0K6QP0100I61H061LE01TH5P0I61H201PG5@09
01XI5`0K6QP071/I01/K6@0I6AL071`J020P7P0L71X061PF008071`J00/07alM01/K6@0K6aT05ADB
020Q6`0P8A`07b0J01`M600L7QX07R0L028T800201hS801;01hS8@0N92<07bDT02<Y9`0S:BT092XZ
02<[;P0L8b/09B`d030i@P2KY:/0<C]102<^<P0V<C<09c4c02Tb=00[=CL0<3Xm030j?`0_>Sh0;cXo
03I2B00[>3h0=45802Le?@0a?dL0<T1803E2BP0iATh0>4E=03I3B`0iATh0>dQ@03Q5C@0f@d/0>TM?
03a9D@0jAdl0>TM@041>F00lBED0AU=Q059NK`1AGFl0EF5c059OK`18E6D0@DiL04AAF`11CeL0@4mD
03a;CP0oCU@0CE]T055OJ01:F6<0A59M04IDG`15De`0?TeD03a;D010Ce<0GVmf06n0Q`14EEd0BeaU
04AEG01fQhl0DfA]05=TK01<GFD0KGj70721R01=GVH0DF1V0080DF1U01L0D5mR04mNH@1>GF00BEUI
04]KF`1>GUd0D61O059RH@1CHf80FfUY05ITI01CHF40EVAT05QVIP1EHf<0G6YZ061^KP1^O7`0LX20
06YhN01SLG80JgYn06imP`02071oQ@0507>1R01fPh`0O8J@07j8TP1oRI<00P1oQi802@1nQY40NX6;
08:9T@2=U9`0YZfc08fDVP27SY@0OHF807j6R00207n7R@0;07j6R01lQXL0NH:707b7R`1mR8`0NXF9
08B?T`2CWZ80OHR<07b7R`1gPXH00P1fPHD01P1bOH40Lgj0075mO@1_Ng/0K7Qh06YfM080JGEc0200
J7A`06IbKP1QKFT0FfMS05YUH@1NIV40G6=O05YRG@1IHUh0FV=Q05YTHP1SKF`0HVi]05]WIP1HIFD0
GV][05m]K@1IJFT0G6e]06=dM025UYH0EVMW05AUI@1[O7`0DV=S05Y[J`1_P800BU]K04YJG01?GF<0
CeeR04aKG`80D5iQ00@0BeYK04EDE010Cdh0?Da<0P0oCTd0800lBdT0>TU503Y9A@0kBDP0?4Y:03e:
B`0nBT`0@DaB03DoA`11BU@0>T=>03]4D00^>400>DA70459C00X;S80<cHk02//<@0/;380<C0e038c
=`0T:2`0720T02P]<@0X:B/0:R`[02`^;@0Z;2/0:bd/02h_<@0U9RP0;Rla0P0W:2`0=013A4P0@T=8
02@W:P0/;S40:2/]02/]<00X:Rd0:2/]02T/;P0T9RT0:B`^01lQ900P8bD08bDX02<T9`0I6Qd07AhQ
02LX:`0R8RD08B8V024R9`0_<3D08B<X02<V;00M82H061`R01XO8`0T:B`092P[01hR9@0N8B<09BHX
02<T9P0O82407alO020P800O7al06a/K01PH601KFe/0FEUI01@D500f=CD08b4R01hL7@0K61T06aLH
01dI6P0M61X06aLH01`H6@0J61T301TG600801PF5`0G5AH061HG01HD5@0I5aP06aTJ018@4@0H51D3
01TE5P0501HB4`0E4A806ADF01TE5P0E4A800P0K5aP01`0B3Pl06QHE01TE500H51<05Q8A01<?3P0B
3Pd00P0F4Q401@0E4A005Q8A01XF5@0M6AP0618C00<05Q0A00T05a4B01PB4`0B30d0618C018<3@0H
4Q<06Q@E01@>3`0C3@d00`0D3Ph201<=3@<05@l?00H050h>01<=3@0@2PX050h>01H@400A2`/201@>
3P07010:2P0B30`04@/;018<300C3@d050h>01D<3P0201@93@0:01P=4@070000:b0T01<8300B2@/0
5@`>01@93@0D2`d06@hB01@930<050X;01L05@/<01L=3P0E2``050X;01D;300G3@h05@/<01882@0A
10H04`H801L82`0H20/05PP;01P9300F1PT050L901D72@0F1PT050L901D72@0E2@/05PX<01L;3@02
01@82P0301H:300`92H08ADG00804PH801804`L90186200F2PX04PH601H;2`0C2@T06`l?00l51@0@
10@03`<301L;2`0C1`L05P/;0104100E2@/050P:01451`0I3@l201@82P0T01H:300A1@L04@D701D9
2`0F2P`040@600l51P0H3@h0308301T=3`0@1@H060`>0186200D20X04`L901451`0C1`T05`/=0104
1P0C1`T05`/=01<72@0>0P@05@T;01P<3P0E2@/0:AdO028F600E2@/050P:01@9300?10L050P<01H:
3P0@10P03P@60P0B1PX201<72`0301862P0A1@T04@H;00805@X?01L04`P=0187300B1``05@/?0105
2P0I3Q<04@H;01062P0D1`d05`D;01H42P0E10X05@D:01D62`0C1`/04@H:01<:3@0R71h0ZJFV089m
OP0N5AP050P<01452@0201862PL04@D901X04`L:00X00@0@10L04`L:00h21@0C1`T040@60186200B
1PL04@D60104100@1@@03P<401hB500>10D04`P900l31@0=0@<04@H701041P0>10D060`>00P0000I
3a00ACTj01/?3`804@D500h03P8201861P0B1PH03P@401<71`0k;bl05@T901451@0C1`L04PH600l3
0`0>0P803`<301861PH04@D500<04@D70186200E2@/00P0@10H0100@1@H04@D701041P0@10H30145
1`0301041P0B1PP050P:00T04PH80P0@10H201451`8040@600H03`<50186200?0`D040@60186200>
0P@Dooooo`006oooool04@0C20`05@X>00h31`0>0`L05@X>01<8300B1`/050T=01P=4@0T6Ad04`P<
00h31`0B1`/03@<601D:3P0:00<05@X>00804PL;00<04@H:01052@0@1@T00`0A1PX301872`0601<8
300D2@d05@X>01@93@0=0PH03P<70P0E2Ph01@0C2@X05@/<0147200B20T05@/<00<04`T:0P0D2P/0
400C2@X04PP901881`0>10D040H701@:2`0D2@d04PL;04@i?@0700804PL=02DJ800B1`l07a@I00d3
100;0@8201D;300800L0000C2@X04@L80147200?1@H08QPI01882@0B20P201881`0b01<9200D2PT0
50X;01L=3P0>10D07a@H01462`0M4QP05``B00d3100A1`D04PP701@:2@0E2`X05@/<01H<3@0;0@80
60dA07M/L00T6Ad050T=0189300?2@/05@lA01PB50090`D03PP<018<400?2@d04``C00P1200<1@`0
7QHN01L74@0H1`l05`P?01D83`0D2@l04`X?00h8300E41@0>cTl09NGV@0n?T006QXL01HB4`0I4aD0
2PD601hH6P090`D401@>400G018<3P0A2`d03`T;00P2100O6A/05a4C01TC5@0D3`l0ShV901/E5@0F
4@l050l<01D@3@0D3``040/7014<2@0E40d05a8?01HA3P0E40d05a8?01D@3@0F4@h00P0G4Pl03`0F
4@h05A0=014=300E4A005Q8A01<?3P0_:bX0>cLf018>3@0F4Q406QHE01/G5P0J5QD061@C01PG5@02
01dL6P0701/J600J6AL071/I01@C4@0F5A<05aHD01XI5`0201`K6@05024Q7`0M7A/08b<Q02/[:@0S
8b400P0J6QP0<@0E5A<09RHT01XJ600J6QP06a`G01TJ4`0Q8Q`092DO028S7@0N81/07AlJ02<U800N
8al07b@P02<X900O9B<06b4O02@Z:00Y;bl09B/[01lW:P0Y<3P092/c02@]=P0d?D@092hd01hY;@0a
?3h0;CLi02/e=`0Z=3H0:SDh02dh?00_>Sh0=415030m@`0S<3H0=TA;02`k@P0jBE00;Sa403A1B@0e
@TX0=T=;03M4C00hADd0?4UA03i;D`0mBU800P0gA4`0=`0nBe<0@e5L03Q5E@0oC5d0K7V;05MSN@0n
BV00Ae=Y04QEJ010CEh0?T]K04UGI01=Ff@0>dY?03M6B`10CeH0EfE^05]YLP17EF00?deH04ECGP1:
F680A5=J049AF01:FEh0/<790;31b`16Ef40DF9/03m@FP1EIW00CEiX03Y;E@1JJgD0A5EO051QJ`1C
I6d0BeYQ04iMHP1@Gf@0BUUL04QGFP19F5/0B5QH04EEE@17EeH0DV9Q05QXI`1BHV40EfEU05m]K@1G
IFD0CUaL05ESH`1VM7@00P1RL7003@1TLW80Hg5a06IdM01aOh00JGQm07B3RP1eQ8/0Kgj5075oQ`1l
RI80OHNA07j8TP1mQi400P1mQI009P1oR940PXVA08>:TP1iP8P0RY6G07V0QP2?UY`0NX:507b4Q`1n
QXP0OhN907j6R01lQXL0OhV;07AoP`1oRXh0OXV=08F@U01oRXh0OXV=08nJWP21S900MX6507N2QP1c
OX80Lgj0071lO01]NGT0JWIf06IbL01ULFl0JgMe06QdL01ULFd0HFeY05iZIP1MJFD0FfAO0P1LIF00
8@1MIf<0G6IU05aVI@1HI680FfMW065]K@1LJVX0EF=S05EUI01IJVX0EfUY07^=S@31dm<0FVa/05]]
K@0lCTh0BE]K055SH`17FET0Ffe]051NH@1@GF<0BUMM04UFF`1>G5l0BeUL04IDEP12D540?4Y:03Y8
B00lBTX0?D];03i=BP0203a;AP1O03i=B`0nC4`0?dY<03i9CP12C5D0?dMB03e5D@0V;S/0?TEE03Do
B02nbLd0b];E03Pm@@0f>Ch0<34f03<c>00j>Ch0<S<g02lc=P0Q9BH09R/]02DW9P0Z;2/0;S0_02T[
:P0W:BP092DW028S9@0S92H08b@X02d^<P1NGf<0:BX_02DV:P0`<C<0;2d_02PY:`0S92H092DW02LX
:P0L7Al0<34c02X[;@0P8B<071dO01/L800S92P08R<W01XK7`0G61`09BHZ01dN8P0[;3007b0U02<V
:`0Q92T07b8W024V:P0b=cX08RHY02<W:P0W:R`06Q/M02PY:`0];Rl0:2PX01hN7P0K6a/08R8R01XJ
6P0Q8B407AdM02<S8`0^;Bd06aTJ01XH6@0I5QL06ADF01/G600M61T06aLH01PD5@0H5QL06ALH01PF
5`0F51D0518C01`J6`0J61T04Q0A01lM7P0[:BX03`d>01TE5P0H51D00P0G4a@201HB4`0801PD5@0D
414071PI01TE5P0D41406QHG01TE500G4a8201HB4@<05a<B01405Q8A01<?3P0B3Pd05A4@01PD4`0G
4A4050h>018<300C3@d05Q0@01PB4P0G4A405Q0@00h8200C3@d050h>01H@4005018<300<01<=3@0E
3`l05@l?01D?3`0D3Ph04`d=01D?3`0B30`03PP801@>3P0G4A404`d=0`0@2PX02`0B30`04`d=01D?
3`0F3Q007Q<G01`A5@0G31007a@H08EjOP0[82@060dA008040D900@06a0D01@93@0C20/050X;0P0C
2@X03P0F30d06@l@02HL7@0M4a@03`D601061`0F30d06@h@01`=400G1`X04@4401H62@0M3A0070`?
1P0F1PT00`0C10L04`L901@82P020186200J01@82P0G2`d04@D701041P0A1@L040@601<72@0A1@D0
4PH601<71`0F2PX02P0001<71`0@10@04PH601X>3P0B1PH05@T901<71`0J3Q003@<4028F6014>3X0
7a<E01<72@0@10H201<72@804@D700d04`L901@82P1@A4H02P0001lC5@0H30h02@0001<72@0E2@/0
50P:01451`0D20X06@d?008040@600<03P8401@82P0F2P`00P0800002`0H30h03@4301041P0@10H0
3`<50104200D20`05@T=00l31`0D20`07A4E00804PH:0P0C1`/01P0B1PX04@D900l42P0C20h050T?
01873@8040D;0P0U6R005P0700805``B0146300?0PT060@:01h;4@0Q3Q@07`hD01T:3`0D20`04@L:
01/B5@0D3Q00[j^/08>1PP0@20/04PH:01452@0@10P03`<701452@0C1`/501452@0701D9300>0P@0
50P:00l51P0?0`D060`>00l31@020186200K01451P0@10@040@401<7200;0040200001<72@0<0080
6Ph@00/10P0K3a4040@601061`0C1`T02@0001dA4P0A1@D03P<301@8200?0`<04@D501H:2P080000
5@T900/0000B1PH05`d=00D040@400<04@D500l30`0@10@00P0C1`L03`0B1PH040@401451`0J3Q00
3@<400P0000J3Q0040@600h2100C1`T05PX<01041P0>0P@050P:01451`0200l31@0301451`0C1`T0
4`L900H04PH800D03`<501041P0A1@L04@D701041P0200l31@0501L;3@0B1PP03P840186200A1@L0
5?ooool001_ooooo0P0C20`201872`0401@93@0E2Ph05P/?01@93@804`P<00@04PL;01<8300A1PX0
4@H:0P0B1`/201<8300B01462P0F2`l04PL;01D:3P0G31004`P<01472P0E2Ph0304501@93@0?10P0
2P0301872`0H3A407Q<G01872`0O51P04@H:300C2@X0100B20L04PP901882@0B20T201872`0U01P?
4@0H3A<03P<902hS:@0O51`04PL<01T?400:00403P@501882@0K4A8040H701P>3`0B20T05`d>00L0
000Y7b003`H601881P0>10803P@301881`0D2PT04`T900d3100Y7b002P8201/@500800405@/;0188
1P0C2@P04PP701061@0B20T05@/<01H<3@0201D:3P804`P<01X040L:00l92`0C3@l04P`>014;3@0C
3A405@lC010:3P0C31<05a0G01@=502>QXh06PXD01T8400G20l05`XA01H;4@0@1``04@/?01<>4P0F
51L05ADG01<C5@0?41803PX;010:30<04P`>03@040X<01PB500B30h05Q0B00l92`0I4aD04P`>01/E
5`0?2@/06A<E00D00@0B30d05@l?01LA4@0I4a804`h;01D@3@0A30T07APD01@?300I51404Pd:01@?
300@2`P06QDB00h91P0H4a004`h;010;200F4@h05A0=014=300M6AP061@C014=300Q7A`05A4@00d9
200H51<05a<B01/G5P0F4Q407ATH01dL6P1MG5X051<A01TH5P0D4a408R4O01TH5P0E51805QDC0P0K
6QP0F@0I61H06QXH01/K6@0J6QP07QhL01dM6`0G5aD07alM01hN700I6AL08B4O020P7P0C50l08R<L
020Q6`0Q8Q`09BHP02DW8P0T9R407b4L02DZ9P0K81`08bPT024W9@0E6aT08RPV02T_;`0Z<30092`_
02@[<`0V;CD08BXc02@]=00V<3H0:SDi02lj?00R;Bl0<ci003e8BP0^>C`09S4e03M5B012Ce@0<d16
02He>P0eA4X0;ci502<d>`0c@DT0>4E>03a9DP0f@d`0=dA=03U6C`0kB540>TM@03Q5CP0jAe00@4eF
03i;E00nBUP0?DYK049?HP1GHgT0F6Al04YFKP14D6H0?T]N045>G`10CEd0?TaI05YXLP0nCE@0?TeB
03i=E010CUL0@DmJ04iLJ@19Ef@0A59M04=AF`12DEP0?diE045@EP1KK7@0BU]U04aMI`1:FfD0AUMQ
0080BEYT01H0BeaV04YKI@1=GVP0D65[04YKI017EUd0EfI[069aMP1HIfX0E6=V04iMH01?Gel0Be]K
04eMG01?Geh0C5aK05ATH`1KJFT0F6IV05ESH`1GIFD0G6YZ0P1QKfl0<P1VM7@0J7If06IdM01TLW80
IWAe06]jP@1/NX<0KWb5071oQP1ePh/0N8F=07f7T01kQHh0N8:;07Z3S01mQXl0P8VB08:9T@1oQXh0
O8>;0827S@24Ri40NX6707n7RP1jPXD0OHF707n7R@1mQHL0OXR907V3Q@1cOX00MH2207n:S024Si40
PXf?07R3Q@2?VY`0TYfO079mO`1fPH<0LWeo06iiN`1]NGT0KWYj06ahN01WLg40Hfm]06QdLP1QKFT0
GVYV0P1MJFD0201LJ6@0G6ER051KE`1QK6P0GFMV05QRH@1MJFL0E61P0P1JJ6P0601EHf@0EfEV05UY
J@1FIfL0DfEU05QZJP1PLW80HWAd05AVIP1>H600BUaL04eOG`1CIFD0DVAT059QI01@Ff40F6=Y09:M
XP19E5P0D5]O041;CP0mB4X0>dM703i:BP80@De=02T0?D]803i=B018Ee@0CU]J045=C@0nBD/0?TQ=
03HoB00oAE40@dUF03m5E@0m@e<0=Ce709RSY`2//kT0>Sm502@W;00e=SX0<c<h030_=00Z:bd08bLX
028V9@0R:2L092HU038d<`0a<c80:bd/038d<`0Y:R`08R<U02TZ;00[;300:2T]02//<00X:Bd0>CXn
04E6B00];S009RLY02DV:00202X[;@0C024R901QHV@0=cPj02l`<P0O82808bLZ01LJ7`0Z;C80<34f
02HW;00Z:bl0824U02<T:00M7R807QlS02//<00P92L08bP/02L[;`0201DI700I02<U:00J6ad061TK
028S900P82008B4Q02TY:@0R8R805aLG01/K6`0V9RH06a/K01`K6`0U8b@07Q`M01`I6P0M6AX07a/L
02@O800U8B8061@E01dK700>30d05Q@E01TG600201LE5P0B01HD5@0G5AH06ALH01PF5`0E4a@06ADF
01/G600O6a`05A4B01XF5`0Z9RL06ADF01DA4P0F4Q<04`l@01TE5P0D414061@C0P0I5A@0100J5QD0
Ee=B01DA400H51<201<?3P805a<B00d05A4@01LA4@0F41004`d=01PB4P0J51@05a4A01TC4`0<1PH0
3`T901LA4@0@2PX0618B00804`d=00@050h>01D?3`0E3`l05@l?0P0D3Ph02`0C3@d04P`<01D?3`0E
3`l01P0000h8201lMWH0618B010:2P0B30`06aDE00805@l?00@03@L7018<300E3@l05@X>0P0F2`l0
0`0G31006@hB01L<400200l4200401H;3`0C20`03P<701882PD05@/<02406Q0A01@:2`0B20T05P`=
01D;300C20X0404401D5200N3Q406PX=024A500H20/05@D801H62@0K2`h0400301D5200I2@`05PL:
00l31@0A1@L050P:01041P0D20X06Ph@02DI6`0G2`d07a<E01/?4@0=0@<05@T901861P0E2@T00P0N
4Q806@0C1`L05PX:0104100>0P804@D501861P0?0`<040@60186200G2`d06Ph@01L;3@0@10H04`L9
01L;3@0=0@<0300201H:300B1PP04`L901T=3`0J3Q0050P:0186200D20X01`0B1PP01`0E2@/04@D7
01hB500D2P/03P8401451`0C1`T00P0E2@/02`0B1PP04@D701<72`0B1PX091PL01D93@0?0`L050P<
01<72`0B1PX04@D900804PH:02804`L;01883P0C2Pl07QDJ00h52P0700<07A@I05M>D`0a:2d01P02
04PoA00B2@h06@`C01P42`0J1`d070T?01T83P0E1P/04PH:01872`0D2`h03PP:02@P8@0W9BH050`?
00/00`0?0`L03`@704Hj?P0H31003@4501452@0B1PX040@80P0C1`/01`0@10L03`<301@8200?0`@0
4`L901P<3P0?0`D00P0A1@L0400B1PP04@D701451`0?0`D06Ph@01D92`0>10D06Ph@00T0000>10D0
:alQ00l31@0>0P@040@600P0000G2``501451@0601L;2`0B1PH0304100l30`0H30`04PL71P0@10@6
01451@0>01P<3P0?0`D04PH800d10`0J3Q0040H701041P0A1@L040H701hB5009000050T:01<72@0B
1PP201041P0301<72@0F2P`03`<500804PH80P0@10H01`0C1`T06Ph@01451`0=0@<03P8401D92`0F
2P`00P0C1`T201451`0301041P0?0`Gooooo01?ooooo000Kooooo`0301H;3`0D2@d04PL;00<04@H:
00<05@X>01@93@0B1`/00P0B1`/00`0C20`04@H:01462P0201872`804`P<01804@H:01@93@0@1@T0
4PL;01H;3`0C20`050T=00h41`0A1PX040D901X?4`0i;S80F4eA02@I7@0>1@L050T=01P=4@0?1@P6
014720H04`T:02P04PP701<92P0D2P/050X;01872`0A1PX050X=01<:3P0@1@/05@X@00h32`0C2@d0
4@L801@:2`0e:b`06Q0A01<92P0>10D05P`=01L=3P0U6a`06@l@03H/;@0I3`h060h;01T?3@0G3@/0
4PP701471P0D2PT05@/;01061`0C20X05@`>01L<400D2PX050X801H<2`0D2PT04`T80P0D2P/00`0B
20T04PL;01@93@0201D:3P0301@;3P0C3@l04P`>00803PP:00<040X>01<=4@0A2`l00P0G41L0400;
10/0;bL_01D84@0F20l05`T@01X=500I3Q@050/@05A>DP0n>Cd061DH00X82`0=30h03@`?00h:2`0@
2P`2018<3P0H014;3@0@2P`0:28T0:ZTYP0S7Al06aDG00`7200@2``04@`=01hH6P0>20X06aDG01LA
4P0>20P03`T901LA400@2`P05Q4>01D@3@0D3`/06aHC020K600A30T050l<0P0G4Pl02P0D3``05Q4>
01@?300C3P/06aHC02HQ7P0K5aH05a<C01hJ6P0F4Q8301LC4`0A01TE5@0L61P0:2@T024M7@0I5AD0
61LE01dL6P0?3Pd06APF01`K6@0G5Q@07QdK01/J600L6aT07ahL01hM6`0L6aT00P0P81h00`0M7A/0
7alM01dM6`0201PH5P0901XJ600I6AL09BDS02PX9P0O81`07b0K01/L5`0L7AL07b0J00807b4M05<0
828N020U8P0M8Al09b`Z01/Q800Q9bH08RPV028X:00T:RX09blb02L^=P0U;3@092df02H_=P0W<CL0
9c8f02/f>00X<cD0;CPj02`g>@0]>3/0;CXm02dk?P0`?T80;Se2030oA00`@4H0;Ce402m0A`0eA4`0
=T==03E2C00e@D`0?T]E04EAG010CEL0B5AO04aIH`11CUP0?d]F03m<EP0mBET0?TaP04YHK@1ULhT0
IWB;05QUO@1:F6h0B5IY055OLP1:FFL0?dmI045@FP1:FF00B5MM04ABF`11CeX0?deH04]HIP15DV40
@e5N04ECGP16E5d0A5=J04IEG01cQ8`0EfQ_04MHH013E5d0AEIN04aMIP19FV<0BeaS04]LI01=GVL0
DV=Z04iOI`1AH6H0BeYO05QWK01QL7<0Df9U04UHF`0204eMG@0I051PG`1>GUd0Be]J05=SHP1KJFT0
FFMW05ITI01GIFD0G6YZ061^KP1SLG40IG=c06IdM01TLW80IG=c06QfM`1[NX00JWV106akPP1`OhH0
M8:807B1R01gPXT0NH>:07Z5RP0307^4RP0I07f4S021R900Q8^C07n6S01kPXP0PhZ@07Z2Q@1fOX00
NH6307b4QP1jPX@0NhF607j8RP1mR8X0NhJ807Z5Q`1lQhT0OXV;07J1P`1iQ8H0NXF706mjO01gPX@0
LGan06ehNP0306ahN00606McL@1TL6h0Hfm]05]WH`1HI600FVIR0P1LJ6@0>`1MJ6@0GfUW06=^J`1O
JVP0GFUX05aXI`1OK6`0GVa/05QVIP1LJf/0Gfi`05YYJ`1EIFD0DF9R05AUI@1CI6@0CUmO05=TI01=
GUh0BeaL04mPH01BHf<0Cf1P051OHP1=F5h0EV5W059MHP14Ce<0Ae9F03]6B@0oBT`0@De=03a8B00g
@d<0>TI603a9B@0jBDL0?Da:045>C`0lAdX0?4I;03m8D@0h@4T0?45=03i3D00l?dl0>Ca<02T`>P15
D5@0?dI<02L/<P0a=3T0;c0d038b=P0_;c40:R//02DY:00V:RP09bdZ0080:bd/00L0<38a034c<P0/
;Rd0:BX/02PY:`0^;c40;Rlc00809RL[03P09bP/024R900X:BX0:b//02HW:00Y:R/0;2`]02@T9@0S
92D0:b//01hO800/;Bh092DV01hQ9P0M8BL09BP^01/M8P0L7R<07QlS01XK7`0R8bL08R8U01dN8@0V
9RT092DY02@W;00M8RD07R8U020T9`0Q8bH092DW01lP8P0P8240820P01hN7P0K6a/06ATI020P800O
7al0:BTY01lO7`0J6AT05Q@E01XH6@0L6AX07QXK01dI6P0M61T06ADF01hJ6`0G5AH04a4B01PF5`0L
6Q/05A<D01PF5`805aDF02X06ALH01PF5`0E4a@06QHG01@@4@0G4a@05A4B01dI6P0[9bP06ADF01LC
500J5QL05a<D01`H6@0F4Q<05A4@01HB4@0I5A@05Q8A03Lc<P0?2`X05Q8A01@@3`0F4Q406ADD01HB
4@0B3Pd05Q4?01PB4@0F4@l06QDC01TD4P0D3Pd04`d<01D?3P0D3`d06A<B010;2@0E3`h04`d=01@>
3P0F410301D?3`0901LA4@0F410050h>018<300D3Ph04P`<01HA4@0G4A40;2HV00808A/K00T04@/;
00`61P0[9BD0PWal014;2`0G4A404`/=01@93@0C20`00P0E2Ph0200B1`/04`P<01H;3`0A1PX040D9
01<8300B1`/05@/=1@0D2P/0500B20T04@L801882@0D2P/05P`=01H;3@0L3a405`X<01`>4@0H20/0
408501L82`0O41<04@@601D72@0E1@P050H901<51`0E2@/050P:0P0C1`T02`0D20X05`/=01<72@0H
30h03`<5020D5P0T61X05PX<01<71`0B1PH04`L700805PX:00<04PH601@8200D20P00P0C1`L20186
1P080186200A1@L04`L901D92`0C1`T03`<50186200E2@/201P<3P0801L;3@0D20X04PH801D92`0D
20X040@600l31@0C1`T60186200501<72@0B1PP05`/=01@82P0]8B<00P0A1@L02P0C1`T05@T;01D9
2`0B1PP04@D704@h?00?1@L06PhB01/?4`0A1@T201<72`0901862P0A1@T04PH:01862P0B1`/050X@
01493P0D2a404PT?00804@P>02<081LM01D<4P0M4aX0>30e020G7@0C2@h05PD;01L52`0G1P`05PH<
01D62`0B1PX04@H:00d41`0<1PP04@`>00l:2`0>1PT03P<601P<400C2@/0<BDY01872P0?0`L04@D9
01<72`0B1PX04`L;01452@0@10D040D401861P0B1PL04@D601<72@0201451`0A0145200B1PT04@D8
0145200B1PP02`010147200g:bd06Q0A0187200D2@/0200001451`0E2@/04PP901051P0>0`@01@0A
1@D01P0C1`L04@D504Lk>`0H3Ph06@d=00l51@H040@41P0A1@D0300:000050P:01@82P0=0@<04@D7
0146200B1PP04@D70186200=0`@050P:00h41@804@D700L04PH801H:300L418081@F01<72@0@10H0
4@D700805@T;00P04PH801H:300@1@L05@T;00/10P0D20X04@H701041P<04@D70P0B1PPDooooo`00
6oooool00`0E2Ph050T=01462P0401052@0501872`0@1@T04@H:01D:3P0D2@d00P0A1PX201872`<0
4`P<01404PL;01052@0A1PX050T=01D:3P0P5AT050T=01X?4`0A1`X05``@03hc=`0F3@l06PlC028G
6`0<0`D05P/?00T00P0601<92PH04PP903804@L601<92P0D2P/050X;01462P0@1@T0Bd1401<83P0F
2a406PlE01873`0E2Pl03`D601H<3@0m<c@06Q0A00l51P0A1`P05P`=01061`0B20T02P01020F5`0C
2@P06A0;01hD4P0I3`d04@L501061@0D2PT0718A01L=3P0B20T05`d>01D:3P0=10<04PP601<9200B
20L040H501882@0D2P/04`T:01<8300B1`/04@H:01052@0?1PT03PP:010:30803`T;01<04P`@00l9
3@0>20`03`P?01<<4`0F3aH02`<;01463P0C20h05`/A01P=4`0F3A804`X?02LQ9@0H4QH01`8600h9
3@0E4aH05a8F00804@/=0`0B30h06P0A2`d03PP:08^5Q`1ECe408A/M010:300G4A<09b4S071ZK017
@D<05a4C018<3@0K5AD0:bDU02LR800=20D04@`901HA3@0B3@T02`H301lJ5`0=20D03PT601LB3`0C
3P/04@`90P0L5a@05P0C3P/09b8O05E@C@0V8R<04@d>01<?400E4A807ATJ01HB4`0H51D05A4B01LC
500V8R<081`M01@@4@0H5aD040l=01TH5P0G5Q@06aXH01dL6P0L6aT301/J600801TH5P0H5aD071`J
01/K6@0H61H06a/I01XJ600E5A<201hN700801/K6@0O7ad07alM01TI5`0R8ah07AhI01`M600O7a`2
020R7`07024S8P0D61L0;30a01`P8@0/<S80:2h^02P^;00202<Y:@0M02@/;`0R:C4082L_02Pa>P0X
<CP0:C<i02D`=00V<C<0:3<e02dh>P0`>cd0;S/m02/i?00]>ch0;Ca002Th?@0a@dL0;3i303A5C011
DUT0=TE>03I2CP0g@dl0?DUE049>FP0nBUH0>DEA04aHI01CGf/00P11CET07P15DEd0A59R04=BI`15
E6T0E6=i05QWOP1EI7/0CEab04QGJP19FFT0>daH03m@F014EE`0AUEL04EDF`16E5d0BEMR04]IIP1J
IgL0C5UY04QEI@16E600AE=L04=AFP17EUd0?DiE03=4B`13E5/0Cf1W051QJ080BU]R01L0CEiU04aM
I01:Ff80CEiU04]LH`1FIFX0BeYO055PI@1LJfh0E6=V04eLG`1>GUh0Df=S05MWIP1CHf80D61O05IV
I@1KJFT0F6IV05ITI01GIFD0FVQX05e[J`0206AbLP0Q069`L01SLG40IG=c06QfM`1[NWl0J7Mn06Yi
OP1_OX<0LX2506ilO`1dOh<0MH2207J1P`1gPH<0Mh6207N1P`2d^l40QHbD07MnQP1mQ8X0NX6707b3
R@1mQHP0NH6407j6R021RH/0OhN907n9RP2nb<X0SiZL075lOP1kQXP0NXF70080LGan00H0M7n107F0
PP1eP880LWeo06YeM`1[MWP206UeM@2706YfMP1VLW00I71^05eYI`1GHel0EF5M05UUH@1MJFD0GVYV
05aWH`1NJ6L0HF]Z05m[J@1NJVX0Gf][05aZJP1KJFX0Gfe^05a/K01EI6L0EVEX05MWI`1CHF80D61P
05QWJ01@GUl0D5mO04UIF@1<FU/0DF1P04mOG`1<FU/0Ae=G04mJH01:EE/0CeYO04E@E02Z]KT0DEaO
049=C`13Cdl0?TY:03Q4A00kAdL0@4e=03e<C`0lBTd0?da?041;D@10BE00?dM?034h@P0a=D40<CA0
034c@00`<T40:2lh030k?`0Q:2h0;S<i03<f>`0W:2`0<S8e02PX:00U9bD08bPT02DZ900W;RL0=3Hc
038d<`0e=cH0=SPg034c<P0];S007QlQ02TZ;00e=SX0<34e02LX;00P8BH0;Bd_028R8P0V9RH05aLG
01`L700V9RH08B4Q01`L700O7al0@D5103@d=00S92D0:B`a028W;@0U:2l082<X02DX;@0V9b`06AXN
020Q9@0R8R@07QhP028R900P8B<08BDX01dR9@0O8bH082@W01dO8P0L7Al09RLY01lP8@0S8b<08B4Q
01PH600M7Ad06a/K0451@@17AdL07alO01/J6`0j>3T071XK020M7P0P71d07QXK01`G600J5QL07ATJ
01/I6P0H5QL040h?01HD5@0K6AX061HG00805aDF00P061HG01LE5P0D4Q<06ADF01PD5@0M6AX06ADF
01<?4080510A02<05A4B01TE5P0G4a@06aLH01<?400K5aH04`l>01HB4@0B3Pd06QHE01TE500D40l0
5Q8A01/G5P0N6QT05Q8A014=300D3``05A0=01<>2`0G4Pl05Q4>014<2@0F4@h050l<00d81@0D3``0
4Pd:01@?300C3@d05@l?01H@400E3`l04`d=01D?3`0201PB4P0@01D?3`0B30`04`d=01XD500H4Q80
BD=301@>3P090`<08A/K00h8200O6AT05@l?02XT90090`<06aDE01072@804@H:00D06PlC020E6@0L
4AD04`P<01L<400301P=4@0301872`0C20/04`T:00@04`T:00@040H701@:2`0E2``05@/<0P0H3Pl0
6@0F2P`09a/M01P<3P0A1@L07A4C00l51P0;004050P:01/?4@0=0@<05PX<01D92`0<008050P:01L;
3@0F2P`060`>01451`0H30h06@d?0186200E2@/05PX<00/10P0B1PH00P0C1`L02`0?0`<03P820145
1@0?0`<05@T901H:2P0C1`L04@D501<71`0G2`d05@T;008050P:0`0C1`T02P0A1@L07A4C01hB500E
2@/060`>0186200C1`T040@600d10`0?0`D70186200801dA4`0:00006Ph@01`@4P0o<cD04`L90186
200C1`T201@82P0;01<72@0B1PP02@0101L;3`0B1PX02`4301L;3`0A1@T04`L;01862P0A1@T00P0B
1PX01@0B1`/02`<900H0100600@040H>00806@lG01L03@<;01L=5@0600@06@lG0516CP07008050D;
01@32@0B0`P04`@901452@0B1PX03`@801872`0?1PT03PH90189300B20`03P8601X>4P0D20`06`lC
00d11@0201862P0>01<72`0B1PX05@T=01D93@0B1PL040D300h20P0C1`L03`<300d10`0C1`T04@D7
01452@0B1PX201452@0=00l31P1SEeT06Ph@01@:2`0M4A<040@601L;3@0S5aT040@601@82P080000
7a<E01<7200501451@0600h20P0800007a<C00P0000900003082300A1@D0300C1`T05`/=00h2100D
20X0300200l51P0E2@/04PH801T=3`0A1@L02@0001H:30@03P8400D04@D70186200D20X04PH80145
1`020186200700l31@0@10H04PH801041P0H30h05@T;01@82P0201041P804@D70P0B1PPDooooo`00
6oooool0100C20`04PL;01462P0A1PX201<8300601872`0D2@d03@8600`11@0?10P02P030P0A1PX2
01872`804`P<018050T=01<8300C20`04`P<01D:3P0G31006PlC01@93@0E2Ph04@H:00X00`0K41@0
5@X>01dB5P0700004PP;00L0000A1PX601<92PH04PP900@04@L601<92P0C2@X04`T:0P0A1PX0:`1H
CE406PlE01T>500J3aD03@8:01@93P0D2P/02@0001H<3@0;0@805@/<01@:2`0A1`P0308300l51P0=
0`@06a4B01D;2P0F3@P06A0;01D;200@1P@04`T700l71P0P5QD0AS`k01<;2P0G3@h040H701P>3P0B
20H04`T801881`0@1PD04PP901@:2`0C2@X04`P<01872`0A1PX040D900h5200>20X00P0B30h03`0A
2`d04@/?00h8300?2@d03PL>0109400H4AP04``D01473`0B2@h05@/A01@;400B2@h03`L<01PB5P02
01H@500301LA5@0D3a<030H:00L04`d?01P0JVAV048m?P0I4aD03`T;014<3@0L5QP0@S`n02XT9P0C
3@l04@/<010:2P0/9RH09R0O00d81@0A30T05Q4=01@?2`0C3P/0;RTV01TD4@0B3@X04`h;00h91P0M
61D201@?300901TD4@0P6aP0:2<P00l;300I5AH05A4B00X61`0C3a002@D600805Q8C00/04`l@01dI
6P0J5QL061@E01TH5P0M71X05A@B01HE4`0G5Q@061LE01XI5`0201/J600:01TH5P0G5Q@05aHD01dM
6`0L71X06ATG01dM6`0N7Q`06QXH01LG5@806ATG00@0820N02<S8@0Q8Al08R8P0P0N7Q`0CP0Q8B00
8R@S024S8P0V9bT0:Rh_02da=00R9RT0;c@g02X`<00W;B/0:2h^02H/;00Q:B`08RTa02@[<`0Y<S/0
:34h02hh?@0Y=3P09C0b02Te=`0Z>3T0;3Xk02dk?@0_?D00<D1303=2AP0/>d00<TA80353B011DUT0
BUeS03Y9DP0f@Th0=D5=03i:EP0oBeL0>DEA03A0C00oBeL0@DeI03E1C@0lB5@0@DeI049@H010Cf@0
?TeR04ACJ@18Efh0BeYa04YIK`16EFP0BEUX041@G014EEd0@U=J04IEG017EUd0BUQQ04iLI`1@GV/0
Gfal04iKJ`18EFD0@e5M04=AFP14DU/0CEaS04QJGP11DeL0C5iR04eOH`1@HVH0EFM[04MIG@1;GF40
BUaP04UKG`80C5iR03d0BeYO04aKH01:FEh0BUUL04eLG`1<Feh0CemO05ATI01HJ6L0E6AS05=SHP1G
IfH0FFMW05QVIP1FI6@0EfEU05YXJ01MJf/0I79b069`L01QKfl0Hg5a06IdM01WMGH0JWUl06QgO01[
NWd0KWf0071nP@1/NW/0M7n1079nOP1`O7X0LWak07AnO@1gPH80bM3F08fDW01fOHD0OXF;07Z1Q`1d
Nh40OhN:07b4QP21RH/0Ph^=0869R`20RX/0cmWJ09ZVYP1cOgl0Mh>307B0P01/N7P0Lgmo07R4Q01c
Ogl0LWin06eiN@1[MgL0JGAf0080IW9b00L0Ig=c06A`KP1QKF/0G6QV05QTH01GHel0G6QT0080Gf]W
0200H6YY05YVI01PK6X0HFe]05i/K01ULg<0FfUZ061`L01bPX80HW5d051OHP1NKG00EVAU05]VJ01I
IfP0J7Af05eXJP1:EeP0BEMH04iIF`1AGEl0CUaM04]FF019E5P0BE9I049;DP1;E5X0>T=808ZCV012
Bdl0>dE703Y4A@<0>dE601T0?4Q;03e<D@0lBe00?d]A03m9DP0mATl0>d==034h@P0a=D00<34m038b
?P0c<T008BL`02<^=00O9R`0:c0e02ha=P0W:2`0;c0c02XZ:P0X:RP09b`X02X_:@0]=2d0:R`Y0080
<S@c02T0<cDd03do?P0f=cT092DW02DV:00V9b/08B8V020Q9@0W:2d08B4S01/K6`0_;bl0:2PX02LW
9`0U9BD07alO020P800S8b<0A4A403Ph>00S92D0@4=:02P/=@0V:c40:B`c02@W;P0Q92T07QlS01lP
900O7b408R0Q02<Q8P0L71h06alR02<W:`0L82<07B4T02@V:@0H6A/08R<U01`L7@02028R8P0o01`L
700S8b<04A4A01dM7@0P82003`l?01<B4`0K6AX07A/L01lL7@0N6Q/071PI01hI6`0Q7Ah04@d>01XH
6@0K6AX071XK01PF5`0;2@X06ALH01PF5`0G5AH061HG01LE5P0D4Q<04Ph?01@@4@0K5aP07ATJ01TE
5P0G4a@0510A01DA4P0I5AH05a<D01/G600C3a006aLF01HB4@0N6QT06ADD018>3@0N6QT05A4@01PD
4`0L61L081`K01TE500C3`h071LD01TD4@0E40d06A@A01`G500I514061<@01<>2`0?2PL06QDB01LB
3`0H4a0050h>00805@l?00H050h>01<=3@0D3Ph05a4A01PB4P0F4102018<300I01H@400k=CD0NWAd
01D?3`070@407QPH01D?3`0C3@d03`T9018=3@0B30`02@<301H=3`0E2Ph05P/?020E6@0X7B409AXN
01`A5@0G31004@H:00h31`0@1@T050T=01T?4@0501D;300C0147200E2``05@/<01@:2`0H3Pl05@/<
01H<3@0`9RL07Q@E00d3100D2P/060h?01lE5P0@1PL04PP90147200C2@X06@l@01041P0201<72@07
0186200D20X04@D701451`0D20X05PX<01041P0201<72@0A01861P0E2@T05@T900l30`0>0P804`L7
00d10@0C1`L05@T901861P0@10@04PH601L;3@0F2P`04`L90186200C1`T00P0D20X01@0?0`D060`>
01T=3`0C1`T06@d?00804`L900@040@600l31@0@10H04`L91P0B1PP0100:000040@601`@4P0?0`D2
01T=3`H04`L900T06@dA01/?4`0@10P040D801/?4`0;00<04`L;01862P0A1@T00P0B1PX03`0B1`/0
4`/B01PA600C31<03PL>01<<4`0X8BP0C4E<00@0100;10/03PL>00X32P0D2a004PD;018320020104
200:01452@0B1PX07a@H02@I7@0D2@d03P@801<8300A1PX02@0100d11@802P020140300401H:3P0B
1PX04PH:0104200H31006`lC01@82@0C20H03P<101871P0A1@D0300001<7200A1@L04@D901862`02
01442`0=0145200h;2h0200001H:300<00803@4300/10P0I3@l0200000h41@0e:B/02P0000d30`05
01451@0301T=3@0J3Ph03`D5008050P800<060`<01451@0A1@D02P0A1@D301451`0=01<72@0@10H0
6@d?00/00@0E2@/04PH8020D5P0>0P@05@T;01<72@0B1PP04@D701041P0200l31@0<01P<3P0L4180
6Ph@01@82P0B1PP05PX<00d10`0=0`@06@d?06EIF`10=3H02`010P0B1PP201451`8040@65?ooool0
01_ooooo00`05@X>01@93@0C20`04`P<01@93@0E2Ph03@8601D:3P0@1@T04`P<01hC5`0K41@20146
2P804PL;0`0C20`04@0B1`/05P/?01H;3`0C20`05@X>01<9300B1`/04`P<01P=4@0?10P04PL;01P=
4@0800406@hB01D;3P0D2@d04`T<00`04@L800@04`T801882@0A1`P04PP90P0C20`04P0F2`l05@X@
0146300B1`d03P<;0188300H3Pl04@L801H<3@0A1`P060h?01482@0C2@X050X;01L=3P0C2@X03@@4
01881`804`X50P0B2@D0300E2`T05P`;00l5100R61L040L702dS900C2@X04@P701@:200F30/050X9
01<9208050X;00<04PP901872`0D2@d00P0E2Ph0200E30l050h@01@>400@2P`03`T;014;3`0@2Ph0
4@/?0P0D3A@02P0:0`X05a0G0109400A2`l04`/@00l8300>1`/040X>00h72`0A2@h301@=4@0301H=
4P0C3@l04P`>00<04@/=02004`d?010;300F4A80618D00L20`0I4aD05A0A01<=3`0?2@/05@lA01XD
5P0L5aL03@L7018<300B30/04@`901PC400C3P/06aHB014<2@0R7AX061<@01HA3P0E40d05Q4>00l:
1`0T7a`09B0M01hI5P0L5a@050l<014=3P80=C4b0P0J5QL0900K5aP061@E01XF5`0F4Q<07ATJ01XF
5`0M6AX081lM028Q7`0F5A<08B0N01hM6`0E51806QTG01hM6`0O7Q`071/I01XI5`0K6QP071`J01XJ
600G5aD06a/I01dM6`0I6AL07AdK01`L6P0M7A/07alM020P7P0R8R007QhM01dM700O7b008R8S028S
9P80824T0200O824051DF00S9RX09b`_01TN8P0S:BP09bd]02P^;P0U;C00:2lg02Xa>@0X<CX09Bhe
03I0AP0d?d<0:3<e02lk?@0[>CX0:SPi030n@00d@TD0<3m202`l@00]?T80:ce102i0A@0iBe40>TeC
03U9DP0d@4`0<Ce903U5D@80>dMC0P0oBeL01`0mBED0>dMC03]7D`0mBED0?TaK03Y9G@0lBf000P12
DFL06P15E6X0EFAh04mOK`15EF@0>T]D03a=E015Ee/0AeIM04UHG`1:F680B5IS04ABG`1;F6P0AE9R
041=G@11Ce`0AUAO04UGH01DHfX0AeUM04EGFP1=Gf80B5YM04YLG`1=Gf80AeUL0P1<GV403`19Feh0
CEmR055SIP1<Ff00CeiS04eLH@1:FE`0CEaO05=RI@1?Gel0DV9R055QH01BHV40EfMV05QXI`0305IT
I00W05QVIP1LJVX0GVa/069`L01QKfl0HW1`06EcL`1WMGD0IG=d06MfN@1/Ngh0Kgj006elOP1]O7/0
KGaj071lN`1_NgP0K7Uc06iiM01aO7L0Lgik08>;S`1hOhL0MWf507V0QP1lPhT0OXF;07b4Q`1iPH<0
OXJ807n7R@1kPhD0N8:3082:R`1hQ8@0Kg]k06eiN@1bOWh0MX:20080OXZ:00T0Kg]k07=oO`1`O7`0
MX:206QcM@1SKfl0HVi^065]K@1NJVP00P1LJ6H0601KIf<0GFUU065]J@1PK6P0Gf]W05mZJ@1YMG<0
GVYX05aXJ01LJVX0FfUY05QVI`1MK6h0JWYk05]/KP1?H680G6]^05IPHP1RKFl0JWEg05IQH`1HHfD0
BeEG04eHFP80CUUK05H0C5MI04aFF01>F5`0?TM>04M@E`13C580FF9W03e6B`10BDd0?4I803]5AP0l
ATL0?dU:041:B`0oBdl0@e9J04ECF`10C5D0?TQA03a5CP0i@D/0<cM203<f@00/;SP0:BPd02l]>@0W
;3D092le02Xa=`0_=3T0<3<h02d^<P0V9bT0:2PX02LY9@0W;2H0:RlX02he;@0_<Bh0=CLf02h`;`0/
;Rd0<cDd02PY:`0S92H092DW02l`=00e=SX0;c0d02X[;`0[:bd09BDU02<S8`0R8R807alO028R8P0Q
8B40;2`/01dM7@0P8200;Bd]02@T9@0a=C`06b4Y020U:`0U:C008RH/02@W;00S92P0824U01lO8@0R
82408b0Q01lN800H71l08RHZ01dQ900Q9BP0:Rd_01lP8P0K71h06a`M01/K6`0L71`07QhN01lO7`80
7AdM00T07QhN01PH600Q82006aTJ01PF5`0L6AX071PI01TE5P0L5aP00P0R7Ql0:P0d<S<04@l@01TG
600K6AX05aDF01XH6@0H5QL05aDF01PF5`0G5AH04a4B01/G600H51D05Q8C01LC500I5AH06QHG01TE
5P0G4a@06QHG01LC500L61T05Q8C01DA400I5A@09b<R01hJ6@0?2`X05Q8A01LC4P0F4Q4061@C01dI
600J5QD05a<B01/F4`0F4@h04@`901HA3@0I51405a8>01XE4P805A0<00D04`h:00h91P0N6AH05Q0@
01@>3P0201<=3@0501@>3P0C3@d050h>01H@400E3`l00P0B30`00`0F410040X:01TD500201<=3@08
00T4100D3Ph030H601/E5@0?2@T07aTI018<300?1`T201<8300:01D:3P0G31005P/?01H;3`0A1PX0
6a0D02dR9P0J3a<04@H:01L<3`D05@/<02D04PP901D;300B20T05`d>01hD5@0D2P/030<301/A4P0G
3@h050X;00P0000d:b`0FDm@01lE5P0A2@X07A@E00`3100A1`P060`>01<72@0H30h06`lA01<72@0D
20X05PX<01D92`0L41803@4301451`0G2`d04PH601@8200E2@T04PH601451@0D20P040@400804@D5
0P0B1PH0100C1`L04@D701@82P0C1`T201451`0301@82P0B1PP04PH800804PH800<050P:01D92`0C
1`T00`0B1PP00`0C1`T04PH8018620050186200701<72@0B1PP04PH801451`0A1`P02`4201@82P04
01<72@0:01@82P0?1@L03@<501P<400@1@P03`@701452@0C1`/04PH:01452@804PH:00l04PL=00l8
3P0?21003PL?04Y4B`0U7bD04P/B02`U;028PHT050dD00l940080`T040L?01062P0A1PX00P0B1PX0
;00A1@T040D901/@4`0S5a/050T=01462P0F2@d03`@701472@0[7b<0@CDi01/A4`0A1PT04@D90186
2P0C1`/04PH:01L;3`0I3A4050P902<H5@0H3@/04PH601L<2`0<00004@D601451`0A1@T04PH;0144
2`0A10`050P=01P<3P0:00404`L901061`0H3Pl04@D700l51P0D20X0:AdO08]oP@0F2P`04PH71@0A
1@D01P0A1`L060`<00l4100J3Ph04`L701461PH04PH61P0A1@D03P0@10H04@D701D92`080000;20R
01051`0C1`T05PX<02<H6@0=0P<03P8401D92`0?0`D040@6100A1@L01P0C1`T06Ph@01L;3@0@10H0
3`<501D92`804@D700@04@L804@h>P0/8B804@D70P0B1PP301451`0301041_oooooooooo01;ooooo
000Kooooo`0401T>4P0G31005@X>01@93@804`P<00H040D901L<400>0`L03P<701L<400@1@T20146
2P804PL;0P0C20`04P0@1@T03`@801L<400E2Ph03`@801872`0@1@T02P0300h31`0D2@d04`P<02<H
700K4A@0;b@X00L0000B1`/06PlC01462PH04`T:1P0A1`P04`0D2PT04@L800l51P0@1PL04`P<01D:
3P0@1`T07Q<G00X00`0C20h03`@:01882@0G3@/0308001471P0:00005P`;01T?3P0G3@h00P0E2``0
5P0F30d03P@501P>3@0C2PD04`T701@;1`0E2`T050X801D;2P0D2PT03@<201L=3@0900004@L801@:
2@0B20L04`T80188200@1PL04PP901D;300F30d201D:3P804`P<08/05@/?01@>400@2@/03`H9010:
300K4aP04PT>00`62P0B2`l07aDM00P1200/8b/040X>014;3`0@2Ph03PP<00l93@0G3Q<06a8G01P?
500D2a0050T?01L<4P0K41H04PT<00l92`0?1`X03`H900h82P0A2@`07A@G00h82P0?20X07QDH01TC
5@0I4Q@030H801dG6@090`D06Q@F05aFE`0U7al071HF018=2`0C3P/05a8?00l:1`0X8b0071LD01HA
3P0>2@H05Q4>01<>2`0D3``04`h;024L6@0A30T03PT601TD4@090`<081`K01<?400H51D04`l@01PD
5@0L61T061@E01XF5`0I5AH08alP01`H6@0H51<06QHE01hM6P0U92006aXH01@C400L6aL05aHC01dL
6P0N7AT06aXG01/J600L6aT092@S020P800L71`07QhN01lO7`0K6a/08R8R020P800Q8B40820P024Q
8@0U9BD071`L01hN800R8R@09bLY02@U9`0R8bD0:b``03<g>P0V:Rd092P[08F:SP0U:Rd09R`[02D[
:`0Y;bl0:c<f02L^=00S:S009c0g024Z<@0lADX0?DQ<02`f>00^>C/0=dE604A?D@0gADL09S@g02Pf
>@0_?T80>D]?0394B00cA4X0<4=902dnA@0iBE80<Si:03I2CP10C5P0>dMC03M3C`12CUX0AE5M0080
AU9N0P0e@Dd05@10CE`0?DeM03a<G00mC5h0?4aL049AI01<G6/0?DeL03a<F@13E5d0?TmF03i@E01;
FV40CUeT059PJ@1BH6/0CE]V055OK010CU/0?TaI04ABG@0204YHH@0504mNI01EIf/0BeeO04MIF`14
EUP00P1;GEl00`1CIFL0EfU[05=UI`0204YLGP0704aNH01@Gf80AUEH04iMH@1EI6L0BeYM055PH`02
059RHP0=04iNG@1DI6<0GVi]05][JP1CHF40E69R05ITI01HIVH0GF][05m]K@1PKVh0Gfe^06=aLP02
06MeMP0S06=aLP1VM7L0L7j007:0P@1]Ng/0JWQh075mN`1ZMW@0K7Qe06ijMP1_NWH0KgYe06egMP1j
Q8H0Nh>907N0Q@1jPHL0O8B9079kP01iPH@0MWn107V3Q01kPhD0MGio079lO@1gPh<0L7am06ijNP1b
OWh0LGem06eiN@1_Ng/0Lgmo06UeM@1cOgl00P1TL700<`1WLg<0HVa]05iZJP1MJ6T0FVAS05MSH@1J
IF@0GVUU061/J01TKf/0HFaX05eYI`1XM7<0Si^K06QdM01PJfd0IgEf05ARH`1KJF`0EVEX04iMH01C
I6H0FVU/05=RI@1JI6L0Yk2e0=SRi022S8h0F69T04]EE`1?FE/0CUQJ04]EE`1:E5H0CEMI04aEF@1@
FEh0BE9G03a5BP0mAdT0<S]003Q2A00kADL0?TQ903Y4A@0g@D80>dE603i:C@11D5D0@U5H03I3C002
03<mA`0`03Q0B`0h?TX0>cm:02la>`0V9S00;2`d02/`=P0T;C80>41303<h>`0O8bH0:blb02T[:`0Z
;2/0:B`X02X_:@0]<R`0<SPa02`^:`0T9RD09bTX034c<P0^<2l0;2d_02LX:P0R8bD0:R/]03Df>P0_
<3@09bP/02LW9`0];Bd09bLW038b<P0W9bL08B4Q02XZ:P0U9BD0:RXZ02h^<00T92@0820R02@W;00S
:2h09RT_01XM900O8RL08bDZ0P0S92P04@0R8R@07Q`O01hL7P0V92L0824U01TM8@0P92L092DY01hO
8P0P8B<071dO024R8`0H61P05aLG01dM7@0G5aL07AdM00807QhN010061PH01dL7@0?3@h05A<D01hK
700P71d071PI01XF5`0M6AX0518C06m]KP10?Sl0:BLX00h<3@0M6a`06QPI0`0H5QL04@0F51D04a4B
018>3P0J5QL06aLF01`H600L61T071PG01TE5@0E4A805Q8A01<?3`0I5AH0510?01TE500A3@`06ADD
008040`;01X05A4@01HB4@0A3@`04Ph=01PD4`0I5A@061@C01XE4@0H4a005A0<01PC3`0H4a004`h:
014<2@0;1P<040/701<>2`0a;2T0HEaI01PB4`0C3@l04@/<018<300D3Ph04P`<014;2`8050h>0P0A
2`/03@0D3Ph03PP801lF5`0E3Ph02@<301dD5@0D3@d040X:00H0000H41402P@401P?400G3@l00P0G
31002P0D2@d04`P<01@93@0F2`l01`0001H;3`0d:Bd05@X>00T00P0C2@/501<92P0N01H<3@0G3@h0
50X;01lE5P0Z82406a4B0107200I41401`0001XA4P0D2``04@P901892P0<0`@040L800/20`0@1`P0
4PT:01451`0>0P@0;20R03P/;P0M4A<03@4301<72@0<00805@T;00X0000B1PP05PX<0P0@10@03@0B
1PH04`L701@8200C1`L05PX:01451@0?0`<04`L701H:2P0D20P040@601D92`0F2P`00P0D20X00`0G
2`d03`<501L;3@0201451`0801H:300>0P@040@601451`0B1PP04`L90186200?0`D60186200900d1
0`0F2P`040@600d10`0V6Q`05PX<01@82P0C1`T04PH800804`L900X050P:01862P0;00<0200000l5
1`0J3Q803P8601<72`0B1PX04@D90P0B1PX0800B1`/040L>044g?`0^92`0N6if03/a>@0B21004`/A
00d32`0D2Q803`H=01hD700600@03`H:01872`0D2@d04`P<01052@0?10P04@D901D93@0G2`l05@H;
0183200C1PX04`L;038V:P19?D403P8600`0100>0`H040@80`0D20`02`0A1@T04PH703DZ:00U6AT0
4`L701`@400<00003`<501451`0A1@T04PH;00804@@;01P04`L<00P0000A1@L03P@501<72@0D20X0
4@D701P<3P0;00404@L801P<3P0T61X04`L80146100A1PD04@D50146100A1PD05PX:00T0000C20L0
5@T901H;2@0E2@T601861PH04@D500d06Ph@01041P0=0P<05`/=08=gN@0N4Q@03`<500X0002CQhT0
?c<e01<72@0A1@L04PH800<04`L900<04PH801451`0A1@L00`0C1`T02P0D20X05@T;01L;3@0?1@H0
4`L900/00@0D20X040@600l31@0@10H201451`804`L95?ooool001_ooooo01<050T?01D:400C20h0
4@H<01873@0C20h02`0601H;4@0@1@/03@8801@93`0F2`l04@H:01061`0A1`P040H70147200E2``0
60h?00803@<400/03`D601<92P0J41404@L801882@0>10D06@l@01`B4`0@1PL04`T:01D;300201H<
3@0801<92P0B20T04`L901<72@0I3@l07Q8D01T=3`0C1`T201@82P804`L90P0B1PP201882@0501<9
2P0D2P/050X;01D;300C2@X00P0B20T0300C20`050T=01<91@0K4@P04PP001T>200D2@<04`P401<8
1@0E2@T05@T;01D930805@T=00@04`L801871@0C1`L050T80`0D20P201D92@0801@8200C1`L04`L7
01D:2`0@1PL05@/<01@9300A1PX201<8300b01/@500;00@040D901P=4@0900804@H:01482`0G3A00
60dA01<:3@0E2`h05P/?01D<3`0E2`l05@X@01@;400D2Pl03PD:00l62`0A20d04`X?01@;400E2Q00
6PlE01@93`0A1P`04`P>0146300k<3H04PL;0189300C2@d050T=01@;3P0E2`h03`@802TP8`0?1@P0
81DI01<:3@0F31003`T901H@400=1`L04@/;01PB4P0D3Ph0618B00h8200@2PX201<=3@0901TC4`0C
3@d05Q0@01TC4`0J51@0618B01H@400D3Ph05Q0@00<05a4A01805Q0@02XV9@0I5A@07QXI040l>`0T
81l040`;020L6`0I5A@081`K01LC4P0I5A@07a/J01HB3`0L6AD081dH01lK600K6AD201TH4`1702<T
7`0U9R0071dH010A300N7AT06aTK01PF6@0I5aX071XM01`L7P0K6ad07QhP028S9@0M7R009RLY02<T
9P0D5AL07AdM02PX:00Q8B4061PH024S8P0T9RD0824S020T9@0Y;Bh08RHW04aBDP0X;Rh08R/Z01dV
9@0a>ST0=3dm02@/;P0U;C00:c8h02`c>@0]=3X0;3Dj02dd>P0c?Cl0<Cdm02`f=`0a?3d0<Sdo02dh
?00/>Sh0;3]00350A`0^?DD0<T=;03Y8D@0gA4l0<cm=02hjB00iAE<0@DeK03i:F00mBEL0@dmM04QD
HP12CU`0@4aJ04UEH`1<FFD0B5IQ03e;EP17EF40;C]604=AGP13DE`00P12D5/01@13DEX0A59K04IE
G018Eeh0DV5V0080CUeT0380>dYA04IEG00jBE00?DaC05]ZL@1_OXD0BeYQ06]jO`1EI6T0C5]P04ED
F@1?GV<0EVEZ04iMHP1?GV<0C5]P04]JG`1?GV<0DV5V055PI01;FUd0C5aL051PH@1=GEd0AeMG04iN
GP1GIfL0Df=S059RHP1EIFD0EfMW05EUI01AHF00E6AQ05QXI@1KJfX0Gfm^061`L01NKVh0H6mb065`
L`1_OX<0I7=h06IcN@1kQXX0JWEg06mjO01fPH<0LGan07AnO`80JgEf0180L7Yk07J0P@1iPh@0MGn0
07Z4QP1fP8<0[[Vk07^5Q`1gPH<0KWUk07N1P`1gPX@0MX6307N1P`1dOh40Lgj007b7R@1cOX4206]f
N080KWUk05<0LWin06YfM01TL6h0JgMe065]J`1OJfT0Hfe/065ZJ@1QJfX0FF9Q05=LF`1FH5l0FF=R
05mXI`1SKF`0HV]Z05iWIP1MIfH0IG9b082>S`1^O7d0F6IY05YWK@1IIV`0EF9X05MTJP1FHfT0FfY]
05QVI`1@GV40I6mc0:bg_@3gool0P8^?04UDF01@Feh0CUUK04mKF`1>FUX0BUIF04IBDP1;EeP0B5=E
04MBE00e@480@Ti>034l?P0oBd/0>4A403]7A`0iADD0=T9203Y6AP0iADD0>TQ803A2@`0`?D@0>TIB
03a8EP0lB5P0?4ED03LoC00`=T40:Bhd02`_=00^<cH09Bh]02X`<00d>SX0:Bl_02L];@0/<2l0:Rh]
02hc<@0a=c<0<SPd03<h=00Q8b80:BTY034a<@0T92@09bLW02d];@0302XZ:P0902TY:`0W9bT09RHW
02h`;`0H6QL08bDR024S8P0R92<08B<R00807AhP02L09RLY01XK7`0L7Al09bP/02PY;@0W:2d092DY
02<T:@0U9RX0:RX^02HU:P0U92T081lT01TH7@0L71l09B@Y01XI7`0Q8RH092DY028Q9P0O7R807alQ
028R900P82407QhN01dM7@0O7al0820P01/I700P7R4071XM01XH6`0O7B009B<V01`J7@0P7R406QPK
01PF6@0K6A`00P0E4aH0@00P7R404@lB01/I700Q7b80518E01XH6`0M6ah0518E01<A500I5aX030X;
01XF500>2PT04@d:01PD4P0G4a805Q8?01DA3`0G4a8061@A01PD4P0E4A00510?01PD4`0J5QD05a<B
01`H5`0M6AP05Q8A01`H5`0K5aH05Q8A018>3@0F4Q4061@C01`F5@0G4A405A0=01@?3@0C3@d04`h;
01HA3`0I4a<08ahK014;2P15?cl0T8Z:01HA5@0H4aL03PT<01DA4P0C3a005a<D00<0000N6QT061@C
00T5100O6aP05a0?01T@4@0E2``04`T:01<:2`0D2P/201@;30805@/<00H050/<01D;300F30d05@/<
01882@0@1PL201L=3P0401D;300D2P/04`T:01@:2`804`T:00`050X;01D;300E2``03`D601882@0E
2``05`d>01`B4`0I3a004`T:01L=3P0F30d2014720804`T:00h050X;01D;300E2``04`T:00h41@0H
3Pl08aTJ01P>3`0G2`d04`L901041P0E2@/06@d?01@82PH04PH801@02`4001`B400B20H05@/900d3
0@0A1`D060h<00X20@0E2`T06Q0>01P>300I3`h05PX<00h2100D20X040@60186200@10H05@T;01<7
2@804PH800T04`L901D92`0E2@d060`@00X00P0800005@T=01H:3P0A1@T00P0C1`/0400A1@T04PH:
01<72`0:00804`L;01862P0G2`l07a<G01<72`0G2`l03`<70104200<0@@04`L;00d11@0A1@L20186
200301451`0C1`T05@T;00804`L901H03`<501<72@0L41803`<701D:3`2XWJ<0PWMm01P=4`0;00H0
714G01883@0700807Q<I00/11P0D2@l05``B01462P0>0PH05`/?01H:3P0>0PH04@D90P0B1PX02`0@
10P04`L;00l31`0H30l03@4301P<3P0A1@L040@601T=3`0>10D04`L9008050P:00T04@D700l31@0;
0@808QHH00h2100F2P`0300200h2100L41@00P0@10P0100A1@T04PH:01862P0B1PT201041P040145
1`0B1PP04PH8018620D04@D701P04@H501460P0A1P<04@H401460P0A1P<05P/900l4000?10807Q<A
028G4`0H3@/04@D500h20P0?1@D050P800h20P0B1PH02`0001L;2`0=0`<0300001861P0C1`L20104
1P803`<501@040@601451`0@10H060`>02DI6`0I3@l050P:00l51P0>0P@04@D701P<3P0@10H02`42
0186200<00805@T;01041P0800004PP901H:30H04@D700H050P:0186200=0@<050P:01H:300:000D
ooooo`006oooool0200A1P`04`P>01L<4P0I3Q@05@X@00h32@0B1`d04`P>0P0D2@l0100B1`d040D9
01872`0B20T201061`080147200C2@X03`D601H<3@0J414050X;01L=3P0P5QL201D;300401882@0J
41406a4B01882@H050X;00H04PH801041P0C1`T060`>01@82P0@10H201@82P804`L90P0B1PP00`0A
1`P04PP901882@0301<92P<04PP900`050X;01D;300Z81X091X?03dc:P0_9A/05@/301@90`0D2@L0
5@X801D92`0E2@`201D93@0301<72@0B1PH04`L700@050P80P0E2@T201@8200D01<71`0A1@L050T=
01D:3P0M4QH05P/?02XO8`0N4aL03@@601<8300P5AT06a0D01X?4`0F2`l04`P<01@93@0G31005P/?
01L<400F2`l201D:3P<050T=00d050T?01D:400F2a405P/A01D:400D2@l03`@:01P=4`0I3Q@060dC
01/@5P0C2@h050T=00805@X>0`0F2`l0300Z7b<0<bP/01/@500H3A404PL;01P>4@0U71d09R0P01D?
3`0B30`05@l?014;2`804P`<00H05@l?01@>3P0C3@d071HF01H@400G4A4201H@400301D?3`0D3Ph0
5a4A00806A<C0P0J51@0500I4a<06ADD01XF5@0L61L0510?01TE500f<S406aLF01HB4@0N6QT06QHE
02@P7`0]:BP06QDB01dI5@0N6aL07ATE01`I5@0K6QH07A`H0P0A4P`0200M7QT06Q/F01lO700P6al0
7adQ01dK7`0K6Ad06a/N0P0M72004P0I6Qd08b@W02//;`0Q9BL07b<T051@D00K6a/0:2PX01lO7`0c
=C@08bDT030b<@0T:2L07R8Q02@X9`0[<Bl082HT02D^;@8092d/00H0:c@c02/c=@0V;S00:c<f02`d
=`0]=CT202dd>P0B030i>`0_>CP0<3Xk03<m?`0`>cd0<Se103<oA00kB4h0<3m603I5C@0e@d`0?D]F
03E2CP10C5L0?TYG03m;F00nBUL0>DEC0P10C5X07@12CUd0A51O04A@G`15D640AE9O04]IHP18EUl0
?deF04=AFP15De`0@DmH03i<E@0oCEH0@e5J04IDG@19Eel0B5MN04eLH@15E5T0@e9G03M6B`10Ce@0
AEAI061_M01:FEh0CeiS04eLH@17EU/0C5]P0080CUeR00X0B5ML04MFF`1<Ff00CeiS051OI01?GV<0
BEQM04MFF`17EUX0BUUL0P1@H6000`1;Fe/0CUiN05=SH`02059RHP80Df=S02<0E6AT05EUI01EIF@0
EVIS05MWI01IJFP0GFe/05m_K`1OKW40G6]_061_M01RLGL0I7=i06]hOP2KYZX0Mh6306]eM`1bO7h0
L7Yl06egN@1YLgD0K7Ih06miN`1`NW`0KgUk06egN@1gPX@0LGan08>>T01`Ngd0N8>508:=S`1aO7h0
LWeo07=nP00207AoP@0907=nP01[MWX0KgYn075lP01_NW`0KGQj06agN@1ZMWH0JGEc0080I71^0240
HVi/065]J`1TKF`0I6e/06I_KP1PJFP0G6ET05iWIP1LIF@0HFYY061YJ01QJVT0HV]Z05eWIP1IIFL0
FFMZ05MUJ01JIfd0FfQ`05MTK01OK7@0FFI/05QUJ`1DHVD0D5iO05=QHP1DGfD0Hfid08jIW`1II6P0
AU5E04YEF018DeD00P19EED00`17De<0AE5A04MCD`02045=C@0W03]7A`0nBTX0;c/k03]7A`0d@400
?DU903m;B`0lB4P0>dM7038m?00e@Cl0>4A403Q7C00oCEP0@DiM03e:FP0lB5P0?DIE03<lAP0W;S@0
;34e03]0@00c>3L0:Rl^02db<@0V:bX08bPV02P];00]<S40<CHd02ld<`0/<C009b`[01lQ800/;2`0
;Rh^03dm?@13@d<0:RXZ00<09bLW01D09RHV02DU9@0U9BD05QPE02PZ9`0O8Al092HU01lQ800^;c00
:R/]020Q8`0S92P092DY02TZ;P0U9RX0:bX_02TX;@0U92T08B0U028Q9P0T8bP00P0Q82D201lN8`0:
024P9@0R8BH07A`R020O9@0R8BH08b8W020P8`0M7Al07alQ01hN7`807AdM010071`L01/K6`0H5QT0
6QPK01/I700I5aX061HI01LE600L6Qd07A/N01LE600F51L06ALJ01HD5`0E4aH06QPK0P0M6ah01@0D
4QD0;B/^06QVJ@0Q7b8071XM008061HI00H06aTJ01/G5@0J5Q@05A4?01TE4`0L61H201HB40<05a<A
00D05Q8@01DA3`0E4A006QHE01LC4P0201HB4@0401@@3`0B3Pd05a<B01PD4`805Q8A00<05a<B01TC
4`0F4100100E3`l04`0B30`03`T901@>3P0F41005@l?01PB500L5a`06QDI01<>4P0B3A404Ph?01XF
5`1:ATL04@d<01@@3`0=2@P06QHC014:2@0E2``00P0H3Pl301H<3@L05@/<0P0D2P/04P0L4Q<07A<D
01P>3`0E2``050X;01<92P0B20T04`T:01882@0E2``05`d>01@:2`0E2``050X;01H<3@0H3Pl050X;
01061`804`T:0`0D2P/201<92P0=01882@0=0`@06Q0A01<92P0?1@H081HG01P>3`0G2`d04@D701P<
3P0B1PP06Q0A01`@4P060186200@00/20P0I3`h03`D401<9200=0`804`T701881`0F30X040H401X@
3P0D2PP03`D401451`0@10H06@d?01451`8040@600P04PH801451`0@10H040@601451`0B1PP05PX>
01462@806`lC00<040D801862P0A1@T00P0C1`/00`0A1@T04PH:01<72`0201`@500:0104200?0`L0
5@T=00`0100@10P04@D901P<400A1@T050P<010620<050P:01804`L901D92`0G2`d08aLI00h41@0H
30h04@H701451`0D20X04@H901dB5@0D2P`04`P;01862P0@10P04@D901472@0@10P201D93@0D0104
200B1`X03`<701P<400T61`06PhB00l31`0C20/04PP:01D93@0D2@`02@0101862@0=0P<05@T;01<8
2@0:00403`<50186200C1`T201@82P0901451`0@10H04@D801452@0?1@L03P@602<G6`0l<3@050P<
008040@80P0A1@T01@0B1PX04@D801041P0@10H04@D700<04PH81@0A1@L00`0A1PD04@H201460P03
01460P0Z00l40@0A1P804PL301<8100D2@D05P/701@8200T61P081@D00d10@0=0P804`L700l4100D
20P040@401L;2`0E2@T04PH601041P0=0@<08aLI02dQ8`0I3@l03`D601<72@0A1@L060`>01D92`0<
0@804@H70186200G2`d07A4C01@82P0A1`P050P:01/?4@18?3h06Ph@01L=3P0A1`P03`D61P0A1@L0
1P0C1`T04PL801H:300;0@804`P901@82QCooooo000Kooooo`8050T?00H06@hD01lD6P0K41H040D;
0146300>0`T201<83P0>00l42P0D2@d04PL;01<92P0?1@H040H701882@0?1@H05`d>00l51P0B20T0
6@l@01472009000201<92P0;01061`0D2P/050X;00h41@0E2``04`T:01882@0C2@X050X;01D;300G
2`d00P0C1`T00`0F2P`050P:0186200601<72@P04@L800d04PP901@:2`0F30d060d:06]QE`3ooO<0
V8j501X?2@0K40`06@h;01@91`0D20X050P;008050P<00<04`L901861P0C1`L02@0D20P04P0C20X0
7a@H01D:3P0L4AD05``@03`a=@0Z7b<01`0000`11@0F3@l02P0301<8300E2Ph04@H:01/@500U6Qh0
7a@H01872`8050T=0P0C20`201872`0<01873@0C20h04`P>01<83P0B1`d04@H<01X?5@0@1@/03`D:
01X?5@0F2a40=R/a1P0F2`l0200@1@T04`P<01H;3`0<0@D03`@801L=4@0M51D081XJ0P0B30`0400E
3`l040X:014;2`0C3@d05@l?01<=3@0@2PX04@/;01LA4@0F41005@l?01@>3P0E3`l05Q0@01@>3P0E
3`l401H@401K01HB4@0H51<06QHE01HB4@0J5QD0;BTX01lK6P0I5A@06aLF01@@3`0I5A@061@C01`G
500M61D06aLD01XF4`0K6AD07QdI020O6`0S91l08B8M01<D3`0/;BP051@B01`G6P0P7R407adP01dK
7P0Q8B<09bLY02HV:00L7Al06AXL01dN800K7b008BDV01dM7@0B4Q80;Rh^020P800[;B`0;2h]02T[
:P0N8R40:Rh]02T];00J81h082HT02@];00V;bh082TX02@];00Z<S@0:C4c02`d=`0]=CP0;SDj02he
>`0]=3X0<CXl038l>`0b?3d0<cdo02hi>`0`>cl0=D5604iKH@0fAD`0>4I>02Xh@@0kBE@0=49<04=@
F00lBE80>4E>03m;E`10C5X0BeMU04A@GP16DV80BEAV04YEI`19E6P0C5UV04]IHP1CHFX0AUAM05IT
K@0oCEH0@e5J045?F003049@F@0N049AF@1:FF00B5ML041?E00oCU<0?DaA04=BE`19F5d0GVeb0;c;
d01QL7D0?diC04aKH019F5d0A5=H04MFF`1AH6D0Df9W04mNH`1;FUl0CEaQ04iMHP1;FUl0BEQM04UH
G01AH6<0GFe]05UYJ@1@H600EfMW0P1BHV80601EIFD0F6QX05IVIP1EIFD0FFUY05UYJ01GIf@0EFER
05IVI@1JJVT0GFe]06akOP1UM7P0JWUn05a[L01PKgD0IG9h061[K`1ZM7H0M7j0071jO01VL780JG=e
06YdMP80KgUk00/0JWAf06I`LP1VL780JgIh07J1P`1[MWP0N8>507=nP01hPhD0KgYl075lOP03079m
O`0/075lOP1eP8@0L7]o06ehO01_NW`0KWUk06ehNP1YMGD0JgMe06McL@1NJVP0Hfm]069^K01QJVT0
IFi]06I_KP1RJfX0GVMV05mXI`1KI6<0JgAc06=/J`1NIfH0HV]Z05mYJ01JIVP0JGMj06]iO01HIF/0
Gfad07>0R01FHf/0FVM]06EbN01HIVT0BeUJ05=QHP1?FV00?dY@04UDFP1CGV80C5MK04UDE`1:EEL2
04YFEP0/04MCD`16DU80A51@03e9B@0jATH0?TY:03A0@00Y=CD0>4A403U5A@12CTh0@dm?03]7A`0h
A4@0<Sdm03Q2@`0h@dD0=d=903]9E013DEh0?T]K034mB`0d?TX0<SU402X_=@0/;c@0>3`m03<g=P0Z
;Rd0:Bd/02L[:P0X;2/0;30_02hb<@0c=cH0<SHe02hb<@0V:RT0=CDe02@T900f=SH0clo?0>SXj013
@d<202LW9`<09RHV00X09bLW02la;P0K7AX0;c4`02HX9`0[;B`09bPZ030a<`0[;2h0:b``0P0J6al0
100R8bL0:RT^02TX;@0V9BX202@S:00L02HU:P0S8RL081lT01hM8P0Q82D08R4V01hM8P0P7bD07QdR
020O900S8RL08B4T01/K7@0P82808B4R024Q8@0O7al071`L01XJ6P0M6ah06ALJ01XH6`0L6Qd07Q`O
028P8`0K6A`071XM01XH6`806ALJ01005Q@G01LE600E4aH06aTL01`J7@0O7B00De5D0;Vg^P0V92L0
40hA00d;3P0L6Qd07Q`M018>3P0C3`h05Q8A0P0J5QD00`0G4a805Q8A01HB4@0401HB4@0301@@3`0G
4a8061@C00806ADD01l061@C01LC4P0D40l05A4@01@@3`0E4A0061@C01H@400G4A405Q0@01D?3`0F
41005a4A01XD500H4Q804P`<01LA4@0N61P06aDG09:=TP0X8bL06aHJ00T4200C3a006QHG06EQHP0B
3Pd05Q8A01@@3`0I5A805Pl>00806@l@00@050X;01L=3P0Q5aP081HG1@0E2``02P0D2P/05P`=01H<
3@0E2``0718C01hD5@0H3Pl05@/<01@:2`0A1`P201<92P050147200F30d060h?01@:2`0E2``00`0D
2P/201<92P0301@:2`0A1`P050X;008050X;00l04`T:01882@0B20T05P`=00d3100A1`P03`D600L0
000G3@h05`/=01041P0J3Q00200001041P0E2@/01P0B1PP01@0A1`H081HE01<9200G3@`040H500@0
4@L600H05P`;01@:2@0B20L05`/=0186200J3Q0201@82PL04`L900L04PH:020D602>PXH0TXJ:02<G
6`0900404@D900804`L;01T04@D901862P0C1`/07A4E01`@500A1@T03`<701D93@0B1PX07Q8F00h2
1P0;00<040D801hB5P0J3Q804`L901@82P0C1`T04@D701<72@0E2@/0Ge=E01@82P0@10H030830080
200000@060h@01@8300B1PX04@L90P0=0@D0600D20`0=b/_01862P0A1@T03`<701@8300A1@T060`@
0104200B1PX07Q8F01lC5`0H3100300400P0000L41@08ADI01H:3@0B1PP06@d?02LK7@0F2P`03002
01@82P<04`L90P0A1@L01`0C1`X02P0200l31`0C1`/0<bL[04m3A`0D20`00P0?0`L3010420040104
1`0@10H040@601451`<04PH81@0A1@L00`0A1PD04@H201460P0301460P0300l4000B1`<04`P40080
304000P04`P501861P0L41007Q8B00l30`0B1PH05PX:01@820804@D500d081@D01L;2`0@10@06Ph@
01<72@0L418081@F01<72@0A1@L050P:00h2100J3Q009ATK00804`L900P02`0101<72@0J3Q005@T;
01H:300H30h02P0005Q<CP804PH800<05P/<01041P0A1@L01@0A1@L01P0800008ADG00/00@0G2`d0
3P<400`00QCooooo000Kooooo`0601873@0>0`T040D;01H;4@0E2Q003P<90`0D2@l20146300=01T>
4P0>0`L040H700`20`0>10D04@L800X00@0?1@H05`d>01D;300?1@H040H701<92P0201882@0=0147
200C2@X04PP900h41@0D2P/04PP90147200B20T04`T:01@:2`0I3@l05@T;01@82P0201D92`0301@8
2P0C1`T04`L900@04`L9200A1`P02`0B20T050X;01D;300P5Q80IUaC0>gSfP20MVh06Pl901L<200B
1`@050T700<050P:00@050P<01<72@0B1PH04`L72@0D20P04P0E2P`05P/?00L0000?10P04@H:024F
6P0:0@<08QLK02TN8P1:?d<0;R<W00L0000G31003`@801T>4P0S61`07A8F01052@8050T=0P0C20`2
01872`0301@93`0E2Q005P/A00805``B00L05P/A01D:400A1P`091TO01`A5`0A1P`09AXP00H05P/?
00l09AXN01P=4@0E2Ph05P/?01lD600B20/040L801H@400?2@T04`d=01D?3`0>20P04`d=014;2`0C
3@d00P0H4Q802@0?2@T05@l?01D?3`0E3`l05Q0@01TC4`0J51@04P`<01@>3P0301D?3`0=01@>3P0E
4A0061@C014=300O6aX04`l>01LC4P0H51<05a<B01`H5`0H51<07QXI01XF5@0201dH5@0R01/G500I
5A806aPE01hM6@0Q81`0D55<02@U800O81/0824L01dM6`0M61/08AlR020N8@0N71l08R8T02LW:@0J
6Q`03a0B01DF600P8B<05ATJ024U9P0S8b<0<c<c03Lg=`0X:2P06A/J02`^;@1]Kfh05QXI02@X9`0X
;2/08RPV01DK6@808b`[00L09Rl^02</:`0T;2h0:c<e02`d=`0]=CP0;SHj0080;SDk03H0<S/m034k
>P0_>CX0<Sdn030k?@0`>cl0=415045>E00[>T40;3]302Xh@@0iAe80=D=;045>E00jAdl0>4E=049?
F011CET0A51N049>GP16DF<0Ae9U04MBIP1<Efd0C5UW03i<E@1GIFh0H6ig069`N@14DU/0@DmH03]9
DP0nC5D0A59K04MEGP19Eel0A5=J03i=DP0jBDh0?4]@049AEP13DUL0BeYO05i]LP3=g>40J7Ml03M6
B`1;FUl0CEaQ04MFF`19F5d0CUeR04]JG`19F5d204]JG`0504aKH01=G640CUeR04aKG`1?GV400P1L
K6`04P1EIFD0FVYZ04mOG`1>GUh0DV9R05IVIP1DI6@0Df=S05IVIP1IJFP0EfMV05EUI01EIFD0FFUY
05][J`1[NWd0IgIi06mnP@80Gfic01@0H6ec06UdN01/MgT0JgIh06A_L@1RKFl0KWUk06]fN01^NG/0
K7Mi06MbM01SKW00IG1b06IaL`1fPH<0JWEg07f8RP1aO7h0KgYl075lOP<0LWeo01P0LGan06mjO01f
PHD0KGQl06agN`1cOX00KWUk06MbM01YMGD0GVYX06mkN@1GHf40DemM061/JP1NJ6L0HVa[065[JP1M
IfH0FfET05YTH`1VL6l0NH>206ihM`1LIVD205YTH`0Q05IRI01AGf80BEMJ055NI02MZ[80fNK^061]
M@1QKW@0JGIl05QVJ@18EUL0CeeN05=NI015D5H0@diD05IQI@1>FEd0BUEH04eHFP1<F5P0BEEE04EA
D@13Cdl0@Da<049<C@0lATL0@D]<03Do@00`>S/0>D=403Do@00jA4D0>D=40080=3ho0300<cdn03U3
A00g@T@0<cm603<oB`0hAU<0?T]I03I2D00d?TX0=cm703@i?`0`<cP0<3@e02lc<P0]<C00:bl^02L[
:P0/<2l0<3@c02hb<@0a=C@0;c<b02X^;@0T:2L0@41002`/;00j>SX0clo?0>OWi`0o?cl092@T02<S
8`0R8R80820P024Q8@0R8R80828Q00d?3P0S9B@09BLV02h`;`0/;Bl0:b``02DV:P0X:Bd08b@Y02d^
<`0o@4D302@S:00G02DT:@0W9R/0:RT^02LV:`0S8RL07A`Q01hM8P0P7b@07QdR020O9@0N7B807ahS
028Q9P0Q82@06a/M01lO8@0P8240820P01lO7`0L71`06QXJ01HD5`0G5AP00P0N71l05P0I5aX06aTL
01XH6`0L6Qd07adP01hL7`0I5aX05Q@G01/I700J61/04a4D01DC5P0I5aX0=C<f04e;CP0?3A006QPK
00X82`0J61/07adN01XF5P0B3Pd201/G5P03014=300C3`h05Q8A00D05Q8A00H05a<B01<?3P0F4Q40
6QHE01LC4P0E4A0201<?3P0G01PD4`0F4Q404@d<01<?3P0E3`l0618B01LA4@0E3`l05Q0@01PB4P0C
3@d06aDE01lI6@0D3Ph03PP801@>400/9B/06Q@H00l93@0S7B405@lA00`6200S7Al00P0@2PX00`0B
30`061<@01H?3P0201T?400401@:2`0G3@h08ALH020F5`H05@/<0P0H3Pl00`0E2``060h?01T?4003
01D;300?01061`0E2``05@/<01D;300L4Q<06a4B01D;300G3@h06@l@01@:2`0C2@X05`d>01/A4P0H
3Pl04@L800804PP90P0C2@X201@:2`0<01H<3@0<0P<05@/<01T?400E2``0<RPY02TM7`0:000050T:
01dA4`0C1`T05@T;1P0B1PP04P0/8R40<BLV01881`0>10<02`4001H<2`0D2PT05P`;01dC4P0;0@00
2P4101dC4P0K3a4040@601D92`0C1`T05PX<018620H04`L900L07Q8F00d31@17>cl0Bcm30104200E
2@d04@D900804`L;00D04@D901862P0C1`/03`<701452@0200h21P804@D900H02`0301862P0I3A40
4PH:01hB5P0O4aL20186200601451`0?0`D04@D701<72@0B1PP03@430P0C1`T06P0N4Q@07a<E01<7
2`0>0PH02`0300h31P0C1`/03`<701@8300g:bl04PH:0104200?0`L04`L;01T=4@0?0`L02P0201X>
4P0P51P05@T=00h31P0C1`/05PX>01<72`08000050P;0P0?0`D01@0P51H05PX<00/00@0B1PP04`L9
00804PH800T04@D70186200A1@P040@800P0000?0`L05PX>01lC5`0<0P@01@0@10P0100@10L040@6
01041P0A1@L3018620D04@D700<04@H50146100A1P@00`0A1P@201<81P0J0146100?10803`@20187
1@0@10@020000188200B1PH03`<300h20P0<000040@401dA4@0_8b<07a<C00`0000A1@L040@600X0
0@0800003`<501H:300@10H02P0001<72@0O4aD201041P0<00P0000I3@l02`4200T0000P51H02000
01D92`0;0@802000020D5P0=0P<04`L91`0A1@L01@0F2P`06@d?00/00@0B20T03`<501Cooooo000K
ooooo`0G01D:400B1`d04@H<01<83P0D2@l04PL=01052`0C20h03P<90146300H3A<03@<601872`0F
30d04PP901H<3@0L4Q<04@L801P>3`0A1`P03`D601hD5@0M4a@00P0B20T201@:2`0501<92P0B20T0
4PP901<92P0B20T00`0C2@X01@0B20T050P:01@82P0C1`T04PH800804`L900<04PH801<72@0C1`T0
0`0D20X301<92P0@01882@0A1`P04@L801@:2`0C2@X04PP901<92P0D2P/05``90146000e:b<09Q/F
01<8100G30T050T701<71`<04`L900@04`L;0186200B1PH04`L70`0D20P201<71`8050P80P0E2@T0
4`0C20T07aDG03hc=P0N4aH03P@600`2100H3Q0030<500d31@0G3Pl040D801H;3P0E2Ph040D90146
2P0D2@d04`P<01@93@0F2`l00P0E2Ph301@93@0301873@0C20h050T?008050T?00L04`P>01L<4P0D
2@l0:b0V0146300K41H050T?00<05P/?0`0E2Ph02@0<0`D04@H:01H<3`0B1`/05``@01882`0@1`P0
5a4A018<300201D?3`0?00`61P0C3@d04P`<018<300J51@07aTI01D?3`0C3@d05@l?01LA4@0H4Q80
6Q@D01TC4`0F41005a4A00@0618B02h06ADD028N7@0D40l06aLF018>3@0N6QT06QHE01LC4P0I5A@0
5Q8A020L6`0I5A@071HE01dI5`0L61H06aLE01/I5P0N7AX05QDB01`L6@0O81`08B4N03/l>00T9280
8alP024O8@0P7R007Q`N01hN7`0P8240>3Pi07AfMP0];bl0828R02HZ:P0J7Qh08B4Q02<S8`0J6QX0
9RHV02<U900c=C@0GV1O02T];00X;2/092PW0P0Z<2h0;00U;Rd092d/02H_;P0U;Rd09Rh`02Ta<`0]
=CP0;SHi02lf>`0_=S`0;SDk030i>`0^>3L0;CLh034l?@0_>S`0<3/o02lk@011CU@0NHR?05UWK`0c
@DX0=49=03]9D00jB4`0?Ta@03e:D@19EUl0DEeY04]GI@1DH700Dei`04aGK015CfL0A4iV041=G00d
@d/0CUaT05m^MP1>GFD0AUEM03Q7C`11D5P0@e9J0P16EEd05015E5/0A5=H03a;D00oCU<0@e9G051O
I015E5T0?DaA04mNH`1IJ6d0CUeR04QGG017EU/0AEAI04YIGP1EI6T0D5mT04UHG@1LJg00D5mT0P1C
HVL0301=G640C5]P05=RIP1:FE`0D61P05ATI01EIFD0EVIV051PH01BHV80E6AT05QXJ080FVYZ01X0
FFUY05MWI`1GIfH0EfMV05MWI`1IJFT0FVYZ05i^K`1PKg40IgIi06UhO01SLWH0Hg9e06agN@1WLW@0
J7=e06agN@1]N7X0IW5c06agN@1ZMGL0IW5c06E`LP1WLW@0J7=e06YeM`80K7Mi00@0LGan079mO`1d
Oh40L7]m0P1aO7h04@1`Ngd0KgYl06ehNP1]N7`0LGb007V4R01lQhT0L7]m06MbM01VLW80KGUg05aX
IP1/N7H0R9BB05eYI`1LIVH0GfUY0080FfEU02L0GFMW05aVIP1JI6@0HF][06=]K@1KIFD0F69R05iZ
JP1JIfP0FVQ[05]YK01FHfT0GV]c06UfOP1DHFT0CeaR051MH`1>G5l0C5YK04mMGP1>FEl0B5=I04A?
E@1<Ee/0BUEI04QCEP18DeD0AU9B04=?C`0oBd/0?DU903a7A`19De@0>dE603Y4A@0b?3d0>49303Do
@00`>S/00P0b?3d06`0c?Ch0>D=403Y4A@0kADL0>dA903a8C`0e@T/0<d1;03a8E@0jA4l0<ca603Ln
A@0e>Sh0;c<f02`_;`0a=3<0<cHe02lb<@0Z;B`0;2l^02lb<@0]<2l0:B`[02@W9P0R9B@08B@S024Q
8@0202TY:@0603lo?`1:BTX0<C4a02PX:00V9RH08b<S0P0P82003@0R8R8061XI02la<00Q8R<0:b`]
02l`<@16AdX0@dA8030a=@0U9RX09BH[02`]<P0Y:Rl00P0R8BH202<R9`0902@S:00U92T092<X02<R
9`0P7b@07QdR01lN8`0P7b@07QdS00<07ahS00@07ahR01hN800K6ad071`M0`0K6a/02@0L71`07A/N
02LU:00f=3L0;bd`01/I700J61/071XM01/I700201hL7`0?01TG6P0J61/05Q@G01/I700F51L07A/N
01XH6`0I5aX07adP018@4`0L6Qd05Q@G01`J7@0=2`h05a<C00806ADE0P0G4a<01@0F4Q805a<C01HB
4P0E4A405Q8B00805a<C00l06ADD01DA400E4A004`l>01DA400J5QD05A4@01TE500U8B008alN01LC
4P0H51<05@l?01XD500I4a<00P0E3`l00`0H4Q805a4A00l92@0201PB4P0?018<300H4Q@0:bDZ02lY
;@0T7R8040/>01<=3`0H4Q@03@P902LQ8@0G4A405@l?018=2P0C2`X05@/<008060h?0`0F30d601D;
300601T?400J41405@/<01@:2`0E2``04PP90P0F30d0100A1`P06Q0A01/A4P0E2``201H<3@080106
1`0A1`P04PP901H<3@0A1`P05@/<01`B4`0H3Pl301882@804`T:0P0D2P/0300>10D05P`=00l61`0<
0`<06@l@024G600A1@L0BSi003DY:`0800005PX<01P=3`H04PH800T040H601dC4`0@1PH060h>0188
200A1`L05@/;01D<300:0P400P0D2PX0100A1`L050P:01451`0I3@l30186200801041P0A1@L04PH8
0186200A1@L040@601<72`0D2@`201862P0301<72`0>0PH04@D900804`L;01@04@D901862P0C1`/0
3`<701<72`0D20`04PH:01452@0C1`/03`D701@8300C2@/050T<04@h?01MDED04PH801<72@0A1@L0
3`<501041P804PH8018050P:01<72@0D20X05`/=00/10P0>10D06PhA01H:3@0@1@L03`D700l41P0C
1`X04PP:01041`0E2@`050P;00h21@0=0PD201H:3P0>00l41`0A1@T05PX>01452@0?0`L06`lC00l6
1`0V71h0@3@g0186200?0`D04@D701<72@0G2`d201<72@0;0186200A1@L04PH801<72@0A1PP05`/?
00`1100G2`l03P8601452@0B1PX00P0C1`/201862P0501452@0A1@P040@601041P0A1@L00`0B1PP5
01451`0301451@0A1P@04@H400<04@H401004`P601871@0B1`D04@H401871@0A1P@05`/;00l51@0R
5aL06Ph>0104100>0`<04@D501@8200=0P804PP80P0B1PH0600M4A<07a<E01D92`0=0`@04@D70146
1`0E2@/04`L900l41@0>0`@04@D701@82P0@10H03@<402@H6P0M4A<04@H7040d=P0K3a404PP900X0
000E2@/03`D6018620L04@D700D03P<501451`0<0P<0N6a^01lC5@0Dooooo`006oooool0800A1P`0
4`P>01873@0@1@/03`@:01052`0<0@L04`P>0146300S61h0<RL]00l4200=0PH04PP900h41@0D2P/0
718C00h41@0=0`@04@L801061`0E2``050X;00d3100>10D040H701882@0@1PL03`D601882@0A1`P0
4`T:0P0D2P/01@0A1`P040H70186200D20X05@T;00<04`L90P0B1PP01P0C1`T050P:01@82P0D20X0
5@/<01@:2`804`T:0P0B20T00`0F30d050X;01<92P0201882@0800d4100K40`05@X601870`0E2PH0
5``:0105100C1`L301<72@0401<72`0B1PL04PH601<71`<050P80`0C1`L0300D20P05@T901D92@0E
2P/01`0002PN7`0;0P<08QPI00P0000=0`@06a4B01@:2`805P`=00L0308301D;3@0B1`/05``@01P=
4@0D2@d05@X>00<05P/?0P0E2Ph03@0D2@d060dC01P=4`0G31805@X@01@93`0B1`d06PlE00L00P0D
2`l07A8H01873@0F2a400`0E2Ph07@0D2@d04`P<01<8300E2Ph04@H:01L<401?A4P0Fe1D01X@500D
2``06A<C010:2P0C3@d050h>00h8200C3@d05Q0@010:2P0A2`/05@l?00h8200B30`05@l?01LA4@0H
4Q805@l?01<=3@0F4100618B00<06A<C00T0618B01PD4`0I5A@06aLF01PD4`0L61L06ADD024M700K
5aH00P0I5A@06P0]:BP0:RHU01/E5@0M61L07ATH01`H5`0K6AL071/I024P7P0F5Q@0=SHd01HF500N
7Q`06QXH024M7P0L6Q/07A/L020N7`0P82007alO01hN7P0j?3/051HE01lQ800H71/09RXY0P0L71`0
2P0T92@07alO02PZ:@0S9B@09RPW02``;`0E6AP0:2`[01dS8@0Y;bd202Tb<@0701/T8`0V;bh0;cLi
02<[;@0]=CP0;SHi02lg>`0202lf?00R02lh>P0b?3/0=3ho02lj>`0U<380:C@h03A0A@0H9B/0EFA[
03I4C00mBe@0>4IA03Y8CP0/>S/0>4I903E3B01BGfL0MX:>05EQK`12CUh0A4mS04iHK`1BG7D0C5Ia
03m;G00c@TT0>TU@041?EP14DeX0KWf4049AF00oCUD0@U5H04QGGP80BUUP02H0@E1E03Q7C00oCU<0
@e9G05=RI`0nCE80CEaQ03]:C`19F5d0AeIK04IEFP18Ee`0CEaQ04IEFP1;FUl0CUeR04YIGP1DHfP0
DV5V05i]LP1RLGH0D5mT04eLH@1TLgL0E6=V04mOG`1@H600DV9R051PH01AHF40DV9R055QH@1DI6@0
Ff][05a/K01GIfL0E6AT05IVIP@0F6QX00L0GFe]05m^L01QL7<0LH2306UhN`1/Ngh0Gfe^0080JWEg
0180Ig9d06YeM`1_NW`0JgIh06=^L01OJV`0Hfi`06UdMP1ZMGL0K7Mi06A_L@1gPX@0JGAf06mjO01]
N7X0JWEg06agN@1]N7X306iiN`0I06MbMP1`Ngl0LGb006MbM01RKFl0Hfi`06=_K`1EHEl0FVIT061/
JP1^NWP0CEUG05aVI`1NJ6T0FF=T05eWJ01TKVl0Hfe^06E_L01BG5d0G6IW05eWJ01EGf00FVIV05=Q
HP0205=QI00B05ISJ@1BGfL0CEYR051MI@1?G680CEYP051NH@1:F5T0@Dm@04QCF@19E5X0DEaR04eH
G01<Ee/0Ae9E04A?D@13Cdl0@4a<0P0nBTX07015D500Hfe^04]EEP0mAdP0=Cm003i8B@0c?Ch0;CLh
02li>P0]=cP0;SPi03@n?`0g@480=3]102df?@0`>T80;S]3030mAP0f@T/0<Sa5030i@00d>Sl0=3Pk
03Df>00d=SH0<C<b030b<@0^<2l202la<00702d_;P0Z;2/092HU028T8`0T9RD0:R`[02HV9P0202DU
9@0601dM7@0S8b<09RHV02LW9`0U9BD0820P0P0L71`06P0M7Ad08R@S01dO7P0Y:R`06a`N03Lh>P1D
EET0:BX^02<T:00U9R/071dR020Q9P0W:2d0:bX_02XY;P0X9b`092<X028Q9P0P7b@06aXO01lN8`0S
8RL08B0U01lN8`0Q82D071/Q0P0P7b@03P0L6b0071`O020P8P0M7Al071`M01/K6`0L71`07alO024Q
8@0J61/07adP02LU:00M6ah04@lB0P0P7R40100G5AP061HI01LE600G5AP201hL7`0901LE600C4A@0
6aTL01HD5`0N71l05aDH01hL7`0L6Qd0518E008040hA00d0<Rh_04A0@@0S7b005Q8C01lK700B3Pl0
61@E01DA4P0D41405A4B01LC500H51D04`l>00806QHE00`04@d<01hJ6@0a;B`07QXI014=300F4Q40
5A4@018>3@0I5A@05@l?01/E5@0J51@201@>3P0301H@400C3@d05@l?00805a4A014050h>018<3P0F
41D07aTM01H@500E3a<08adO01dG6@0L5QP07ALG00l92@0E3`l030L401/B4P0J41405@/<01<92P02
01@:2`H05@/<00L050X;01T?400K4A805@/<01@:2`0E2``04@L800805P`=00l04PP901dC500O5AH0
5P`=01P>3`0J41405P`=01D;300B20T05`d>00h41@0=0`@050X;01882@0A1`P00P0E2``0400D2P/0
4`T:01882@0A1`P05`d>01061`0A1`P05P`=01<92P0@1PL04PH803L[;@0J3Q0060`>01D92`0?1@H6
0186200D038X:@0e:b`04`T:01061`0=0`@05P`=01061`1FC4d05P`=01T?400<10@06Q0A00`00P0J
3Q00:1`N01L;3@0A1@L060`>0186200C1`T201D92`0901<72@0B1PP060`@01862P0K3a<06@dA00l3
1`0H31004@D900804`L;00l04@D901862P0C1`/03`<70104200A1@T03`<70104200G2`l05@T=00P0
000@10P06PhB01`@500>0PH00P0D20X01@0B1PP040@601451`0C1`T03@4300805@T;02d02`0101@8
2P0D20X06@d?00P0000900005`/=01041P0C1`T05@T;00P0000O4aD02P010186200F2P`04`L;00/0
0`0A1@T04PH:01@8300L41@05PX>01@8300;00<04`L;01452@0C1`X03@4301T=3`0B1PP03`<501P<
3P0>10D04PH801451`0@10H04PH801<72@0D20/04`L;0104200B1PX03@4501dA5@0@1@P00P0D20`0
100C1`/04PH:01862P0A1@P201041P0401451`0B1PP04PH8018620D04@D700<04@D60146100A1P@0
0`0A1P@03`0<0@0040D301@91`0@1@<03P<101050`0;0000710@03HZ:P0A1@D02`0001451@080000
5@T901H:2P0201P<300I00h20P0F2P`03`<501451`0D20X03P840186200<00805PX<01D92`0;0040
5PX<00h2100C1`T05@T;01451`0:00004`L901H:300A1@L060`>00T0000E2@/03@4301D92`060145
1`0600P0000K3a4040@601H:300E2@/03P845?ooool001_ooooo100A1P`06`0C20h050T?01<83P0I
3Q@03P<902DJ800o=3X04`P<01H;3`0@1PL05P`=01<92P0>10D0718C01T?400@1PL06Q0A00l51P0A
1`P05@/<01061`0B20T04`T:01@:2`0B20T04@L801D;300201@:2`0A01D;300F30d05`d>00h2100A
1@L04`L901@82P0E2@/05PX<00h2100C1`T05`/=0186200@10H05@T;00h41@0A1`P00P0B20T00`0C
2@X050X;01061`020147200?01<92P0B20T040H401050`0?10804@H401D:200M4A407a<C01H:2P0D
20X05@T;01@82P0A1@L04PH7008050P800d04`L701@8200D20P060`<01T=3@0?0`<04@D501H:2P0B
1PH050T901H<3@0C2@X03P@500806a4B00/04`T:01`B4`0H3Pl05Ph>07meMP1hKVl04`P;00d21P0A
1PX060dA01462P0300l4200=01872`0@1@T0714E01T>4P0@1@/03047024F700D2@l01`0201/@5P0F
2a405@X@01@93`0201H;4@0>01D:400H3A405@X>01872`0D2@d05@X>01872`0F2`l06a0D00l6201i
KW80Uhb@03/a=00C2P/201<=3@03018<300E3`l050h>00804`d=0P0D3Ph201D?3`08018<300C3@d0
50h>01H@400J51@071HF014;2`0G4A4201/E5@806A<C0P0K5aH301XF5@0401TE500B3Pd07ATH01lK
6P808QhM02006QHE01/E5@0O6QT06ADD01XF5@0P7Q`071/I01dL6P0T92808R8P01/K6@0L71X051@B
020L7@0S8B807A/L01`J6`0N7Qh071`L02<S8`0O8B0071hM024S8P0J7Qd082@S01lO7`0T92@08b<S
01lO7`0S9B@0:2XY028T8`809BTX00D09b/Z02H/:P0Q9bD08R/Z02D^;@0202L`;`0_02P`<P0Z<S@0
:c<f02`d=`0a>Cd0<cY002lf?00Z<cD0=3hm02hh>@0S;Rl0<Sdo02`g>`0c?d@0;ca203m>E@0jB500
>DM@02lmB00gAD/0>DM803Q6B@0d@DL0?4UA041<F012CU`0?4QH049=H@1BGG<0EEmh059LM`1]NHX0
@4mD03a;D00mC540@U5F04=BE`12DEH0@e9G045@E@17EU/0?diC04QGG011D5D0?TeB03e<D@11D5D0
0P15E5T01P0oCU<0CUeR04QGG017EU/0AUEJ04]JG`80AeIK00/0C5]P04eLH@19F5d0BeYO05ETJ@2N
[K80]<?7051OI01<Ff00EFAX04mNH@0204mOG`06055QH@1DI6@0F6QX05EUI@1DI6@0EFEU0P1GIfL0
2`1DI6@0DV5T05MVJ@1CHVD0DV5T05QXJ@1JJVX0G6a/05e]K@1NKVh0H71`0080HW9b00@0IG=d06Qf
M`1ULg@0IWAe0P1/NW/03`1SLG80IWAe06AbL`1TLW<0J7Ig06IdM@1_NW`0Ig9d06ehNP1_NW`0JGAf
06iiN`1[MWP0JWEg06agN@0206mjO01?06YeM`1WLWH0JgIj06ehO01YM7H0IG1b06A_L@1MJFT0GFUW
05aXIP1KIfD0FFES05QTHP1KIVL0GVU[05YUI`1KIVP0HVe_06=^L01TKg40GFQZ05MRI01DGf40DeiP
05AOH@1FI6D0D5iQ05ESIP1>Ff40C5UQ05ISJ`1BGfL0CU]Q051MH`1>G5l0BUQI04]IFP1;EU`0CeYP
04aGG@1<Ee/0DUeQ04IAE012CDl0AU9B03i:BP0f@T80?DU904IAD@1BFU`0CEEG03e5A`0e?Cl0=3`n
03Dm?`0_=cT0:C4c02/c=@0]=CL0;cLi03Hm@P0k@TX0=d17038lA00i@d`0?4I?03]5CP0e@4H0<CY1
038h?@0/<3<0;c0b03Lh>@0e=cH0<38a02X/:`0Y:bX0:R`[02LY:00202HX9`0C01lQ800M7ah092HU
02PX:00S8b<09BDU02XZ:P0V9RH08R8R02HV9P0P82008B4Q01dM7@0V9RH0:2PX01dN800[;2h0824S
01/L8002038c=`08051AEP0T9BX0>CXo02HV;P0K6b<092@[02XY;P0X9b`202HU:P0F02DT:@0R8BH0
92<X02@S:00I61d08R4V024P9@0O7R<0:bX`01@C6@0N7B804A0E01HF6@0P828071`N01/K700J6QX0
6a/K01XJ6P0F5QH07A/N01`J7@806QPK0P0K6A`01P0J61/071XM01dK7P0M6ah071XM01XH6`805aDH
00@071XM01HD5`0K6A`02@L:0P0H5QT0400D4QD04@lB01HD5`0N71l07QXK01dI6P0E4A806QHG024M
7P0A3@h061@E01<?400O6a`0:bLX010<3@0/:2T201LC4P0501DA400F4Q4071PG020L6`0J5QD00P0G
4a802@0I5A@061@C01LC4P0V82005a4A01TC4`0G4A407ALG01@>3P0201LA4@0F01H@400D3Ph04`d=
01@>400J4AL0>2ld034X;@0O5Q/0;2<V0558B`0D2`h04`X;01@;300G3Pl06A4?01`C4`0J414050X;
01X@4@0=0`@060h?01D;30804PP901d05P`=00l51P0?1@H060h?01L=3P0D2P/03`D601061`0E2``0
5P`=01882@0@1PL04`T:01`B4`0H3Pl040H702dS9017?Ch07Q@E00`20`0J41406@l@01061`0I3a00
4@L801061`0K4A807A<D01T?400201@:2`0801<92P0?1@H03`D601882@0E2``04@L801061`0B20T2
01451`804`L901@050P:01D92`0?0`D04`L901D92`0A1@L04PH801D92`0F30d01`0001882@0=0`@0
2`420147200C2@X0DdU:024G600D2P/040H701@:2`H04PH80P0?0`D0200G2`d06@d?0186200>0P@0
5PX>01@8300B1PX04@D90P0@10P05P0F2Ph04`L;0104200D20`05PX>00X00P0<00@0GE5E01lC5`0D
20`040H801452@0G2`l040@800`0100E2@d03P8601@8300L41802000028F600?1@H201451`0701P<
3P0<00804`L900X00@0O4aD03`<501041P030186200401041P0?0`D04@D700h2108050P:00<04@D7
01<72@0C1`/01@0C1`/08`0?0`L03@4501@8300N4QH05`/?00l31P0C1`T040@600d20`0I3@l05PX<
00d10`0C1`T0300201P<3P0:00004`L90145200<00@03`<701T=4@0=0@D05PX>00h31P0D20`05PX>
01D93@0B1PX04@D901hB5@0H30h03@4301H:300D20X03P8400H040@600h03@8303@X:01<@4003000
00d10@0H30`04`L700P0000@10@04@D500l30`0>0P803`<3010410804@D50P0@10@04P0<00004`L7
00l30`0D20P0300000l51@0E2@/03P840186200C1`T0300201<72@0D20X04PH800l31@0@10H04@D7
018620804`L900L04PH801041P0A1@L050P:01041P0C1`T04PH800803`<500<04PH801451`0A1@L0
0P0B1PP201<72@0601H:300?0`D02`01024E5`0@10H06Ph@5?ooool001_ooooo0P0C20h01@0B1`d0
4`P>01D:400E2Q0050T?008040D;02T05@X@01@:3`0<0PD0714E01@:2`0G3@h05P`=0147200H3Pl0
?C<d01492@0<0`<050X;01L=3P0?1`L04@L801882@0C2@X050X;01<92P0B20T07aDF01/A4P0G3@h0
4`T:01061`0?1@H07Q8D02PL7P0H30h04PH801L;3@0?0`D04`L900l31@0C1`T050P:01451`0B1PP0
4PP901<92P0501@:2`0A01882@0A1`P04PP901<92P0C20T05`/:01451P0F2`/05@/<01T=3P0S5aP0
50P90186200C1`T05@T;01@82P0E2@X00P0E2@T0100D20P05@T901D92@0C1`L201L;2`0T020D500O
4a<04`L701@92@0@1PH03`D501H<300B20P040H601<92@0<0P<05P`<01@:2P0P5QL0:1hN01472@0J
3a<050T=01D:3P0S61`05P`?01@93@0B1`/04`P<01462P0O51P08AHJ01T>500L4AL04@H<01`A5`0I
3Q@0IeaR01H;4@0E2Q0050T?0P0F2a40400E2Q0060dA01H;3`0D2@d05@X>01H;3`0D2@d03@@601`A
5@0E2Ph0714E028G6`0F30l04`X;018<300C3@d201@>3P<04`d=0P0D3Ph201D?3`0:01<=3@0D3Ph0
50h>01H@400I4a<06aDE01TC4`0F410050h>01H@4080618B034061@C01XF5@0J5QD06aLF01XF5@0I
5A@0510?01PD4`0Q7A`06QHE01dI600K5aH06Q@E01hI6P0M6AT07QXJ020M7@0K6AT0:RPX01dM700G
5aH08B4P02h^;@1IFEP08AdM02<Q8@0O7Ad07QdL020P7`0N7Qd0820O01dO7@0K7A/08R@R01`P7P0R
9b@0;bl_02<S8`0P820092@T02<U900Q8b8092HU02DY:00S9bH09RXY02H/:P0S:BL09Rl^0080:C8a
00H0:34`02Xb=00[<cD0;CDh02/c=P0]=CT2030g?@0M03<l?P0oBDP0;cTj02hh>P0jADL0>4=7049>
D`0lBDl0B5MN03I4C00jB540<d5<03I3B`0fA4P0>4E:03]8C`10CEH0?DUE03]7E@1;EfL0EF1b04QC
J01JI7`0BUE/04ICH@0lBe00=dI;03Q7C00nCE800P0oCU<04010Ce@0?DaA04ACF013DUL0DV5V049A
EP10Ce@0@E1E04ACF015E5T0A5=H049AEP1=G640B5ML04IEFP18Ee`204]JG`0>04UHG@1:FEh0BEQM
04EDF@19F5d0E6=X065`M@1_OX<0DF1U05YYKP1@Gf<0E6=V05=SH`1BHV82055QH@0405ATI01AHF40
E6AT05IVIP80DF5Q01X0EfMW055PH`1GIVX0EfIZ05QWJP1HJ6X0DV5S05a/K01MKFd0GVi^05m_K`1Q
LG40HW9a061_K`1TLg@0HW5b06AcL`1YN7P0IWEf06]jN`1/Ng/0IWEe06EdM01YN7P0IgEf06]fN080
KGQj0P1[MWP03P1/MgT0JWEg06UdMP1ZMGL0K7Mi06]fN01WLW@0J7=g06UdN01XLgL0I6ma05mZK01N
JF/0Gf][0P1NJVP06@1MJFL0FfMU05YVI01OJV`0FFAV05YUI`1VLG<0I6ma05]VJ01OJV`0GFQZ05]V
J01FHF<0D5]M04iIF`1?GEh0CE]N04ABE@1JIfd0HVmg04eJHP1<FF40BUMM04eJH01<FUd00P16E5D0
3P16DEL0BUEK04YEF`16DED0B5=G03m:C@0mB4X0?TY:03U5A@12CTh0BeMG045;C00nATP0?DE70P0f
?T00700h@480=Cdo02/c=@0V;S00:30b02Ta<`0Z<S@0<CPm03U0B@0l@d`0<S]3030j@P0b?D@0=Cm5
038l?`0a>3d0<CHi02X];P0Y:B/0;2`/030a<00d=C@0<c@d02h_;P0[;2`0:BXZ02X[:P0Y:RX202<T
900602TZ:P0b<S80;Bd]02LW9`0Z:RX0:BTY0P0P82004P0M7Ad08B4Q01HF5P0L71`0;2`/02TZ;00Y
:Rd0;2d`024R9P0L7B40<S<g06AUJP0_<3D0:2P_020P:00X:3008b</02@S:@808b8W0P0T8bP00`0Q
82D071/P02HU:P02028Q9P0@02<R9`0P7b@07ahT02DT:P0H5a`05QDJ01`L7`0K6ad071`N01XJ6`0I
6AT06QXJ01/K6`0J6QX07Q`O01dK7P@06QPK00<05aDH01TG6P0I5aX00P0I5aX06@0G5AP06ALJ01/I
700P7R406ALJ01<A500F51L05aDH01HD5`0D4QD05A<F01LE600I5aX05a<E01HB500K5aT05a8E01DA
4`0E41<06aHI01D@4`0G4aD0920R01LC5@0[9bP00P0H51<01P0G4a805A4@01LC4P0I5A@05A4@01HB
4@8061@C02@0510?010<2`0F410071HF02PR8P0G4A4050h>01H@400G4A404P`<01D?3`0J51@06A<C
01D?4@0J41L05`hC01/B5`0G3Q<04PT<01L>4@0L4aH08QTJ01lF5`0F3@h04`/901D<2`0T6Q/05`d>
01X@4@0F30d06@l@01H<3@0K4A807Q@E01T?400D2P/201T?400<01@:2`0G3@h06@l@01D;300B20T0
40H701L=3P0M4a@060h?01@:2`0B20T03`H60P0D2P/05@0@1PL060h?01H<3@0D2P/03P@501882@0J
4140:b4R01X@4@0F30d050X;01882@0C2@X050X;01<92P0@1PL04PP901@:2`0B20T04@L801882@03
01@82P804`L901004PH801451`0C1`T050P:01451`0B1PP05@T;0106200@1@P04PT:01@:300>10H0
6@hA01/@4`0K4A<030840P0D2P`00`0B1`X04PH8018620040186200601T=3`0C1`T04`L901@82P0A
1@L04`L90P0C1`/08`0A1@T040@801452@0A1@T04`L;028F6P0J3Q80300400d21@0G2`l050T<04Pl
@00Q5aT03`<700h41P0F30h04@D901@8300J3Q807a<G00h21P0?0`L06@h?00h41@0E2@/06Ph@00h4
1@0L41806Pl@0147200I3@l050X;00d3100@10H04@D600<04`L80P0A1@H01P0@10D03`<401@82@0E
2@X040@501451`H04`L;0P0B1PX07@0E2@d06PhB01H:3P0C1`X05`/=01@82P0B1PP0710B01X>400H
30h05PX<01451`0?0`D03`D601041P0F2Pd04PH:00l51`0>0`H06`lC01<72`0B1PX050P<01D93@0C
1`/04@D901862P0Q5AP07Q8D00804PH80P0>0`@60186200901041P0S5aP0<bPY00h20`0>0`<04`P9
02DI6P0F2P/050P900803P<400<04`L80104100@10@00`0A1@D03@0@10@050P800T0000B1PH03@<3
01451@0E2PX03P@500h2100O4aD08aLI01H;300?10D00`0A1@L00`0B1PP04@D701451`0201041P80
4@D700T04`L901@82P0>0P@050P:01H:300D20X040@600l31@0@10H00P0A1@L30186200600h2100E
2@/0710B02hR900E2@/04PH85?ooool001_ooooo00@05@X@01@93`0C20h04`P>0P0E2Q004`0H3A<0
50T?01T>500E2Q003P<901`A5@0J3a<040H701882@0D2P/040H70147200900004`T:020F5`0=10@0
3`D601<92P0A1`P00P0B20T301<92P8040H700`04@L801@:2`0F30d05`d>01T=3`0Q5AL05@T;0186
200F2P`040@601H:300C1`T201L;3@0F0186200A1@L050X;01<92P0D2P/05@/<01<92P0A1`P04`T:
01882@0D2P/04@L801061`0B1`T07A4C01X>400K3a402P0000`00P0W6ad06@d?01D92`<04PH800d0
4PH701<71`0B1PH04@D501861P0C1`L060`<024E5@0K3`l0710@01/?3`0C1`L05P/:00804@L601h0
5P`;01881`0B20L05@/:00h40`0E2`X04@L601<9200I3`h03`D601D:3P0=0PH081DI03db=P0]8RH0
50T=01462P0D2@d04@H:01`A5@0Q5QX03P<901P=4`0G31806PlE00L00P0O51X05P/A01D:400D2@l2
01H;4@0301D:400H3A405``@00@05P/?00`0714E00l4200H3A4060dA01hC5`0I3a805@`=014;2`0D
3Ph05@l?018<300D3Ph201<=3@8050h>0P0E3`l201@>3P0A01D?3`0F4100618B01TC4`0L5QH06Q@D
01/E5@0N61P06A<C00h8200E4A0061@C01XF5@0K5aH06QHE01PD4`0Y9B@00P0O6aX02P0?2`X071PG
02LS8P0O6A/081/M020L7@0Q7Ah08QlP020N7`0W9BH201dM7@0401/K6`0N7Qh0:b/[024M708081lM
00X08B0N024Q7`0Q8Al0820N01dO700K7AX08R@Q01`Q7@0S:2@0:b/[0P0O7al02`0W9bL09RPW024S
8P0S9B@08RHU01lS8P0R9RD092XX024W9@0T;B`09Rl^00809c0_02/0:C4c02/c=@0/=3L0;3@g02de
>@0_=S`0<3Lm02hg>@0g@D009c4b03I0@P0_>S`0;CPl03A0A@0a?T@0>dYA02Xi@@0mBe@0=TA?038o
B00a?T@0;ca4030mA@0jAe00@dmK05UUL`1NJWX0GfYl05EPL`1AG700F6=i055MJ`0nCE80>DQ=03Y9
CP10Ce@0@E1E03m>D`0nCE80>dY?049AEP11D5D0D5mT0080AEAI01T0AeIK04UHG@18Ee`0AUEJ04MF
F`1>GF80B5ML04=BE`17EU/0AUEJ04eLH@1:FEh0B5ML04MFF`15E5T0BeYO051OI018Ee`0DV5V04]J
G`1GIV/0DV5U05IUJ01EIFD0DV9R0080D61P01@0DF5Q04mOG`1CHf<0EFEU051PH01?Gel0E6AU05IU
JP1GIV/0E6=X05MVJ@1LJfh0F6MZ05YZJP1LK6`0GFe/05i^K@1PL6l0HG5`05i^KP80I7Ad0100IWIf
06UiN@1UMGD0IgMg06YjNP1VMWH0IGEe06IfMP1QLG40KGQj07R3Q@1^NG/0Ig9d06]fN01XLgD0JWEg
101YM7H02@1WLW@0JWEi06MbMP1SKW80H6]]05]VJ01II6H0Gf][05eYI`0305aXIP0605aXJ01MJ6X0
HVe_05aWJ@1FHF<0FFAV0`1KIVP02`1JIFL0EF1R04iIF`1;EUP0AeEF05ESIP1RL7<0D5eS04]HH01N
Jg<0DEiV0080BUMM02L0AUAG045?D012D540@diD04A?E@15D5H0?4M;03m:CP0nBD`0?TU;041<C00h
A4@0?4Q8049>CP0kA4D0?DE703a4AP0g?d40>D5303Y2A00c>cd0:30b02H^<00W;c409Bd_02L_<@0`
=S`0>Ce803Y1B`0d?4D0;CHm02Xe>`0]=cX0;CLh02/c=@0Y;Rh09BHX02@T900Z:RX00P0b<S805`0/
;2`09RHV02LW9`0Z:RX0:BTY02PX:00T92@09BDU02/[:`0a<C40;Rh^02HV9P0S8b<09RHV02@T900L
71`06a/K02h^;P0X:2P07alO01hN7P0^;c<0;c0d0080:2T]02@0<S<g03dn@`0H6Ah06Q/P038b>P0K
6b<07alW02HV;`0S8RP08R4V024P9@0P7b@07ahS01XI7P0N7B807A`Q01hM8P0F5AX06aXO02LV:`0Q
82H07A`R02<R9`0/:c0051<G028R900L71h061PI01HF5P0I6AT071`L01dM7@0N71l07A/N01XH6`0I
5aX201PF6@0301HD5`0G5AP05aDH00805aDH00X05Q@G01<A500E4aH030X=01/I700G5AP04@lB01DC
5P0B41<04a4D0P0G5AP03P0B41<05A0D01lJ7P0?2Ph061<G014<400H4aL06aHJ01LB5P0>2@d04`hB
00d8300D4140510@0P0G4a800`0E4A00510?01DA400201LC4P0O01PD4`0I5A@05A4@01<?3P0J51@0
4@/;01D?3`0F410081XJ01XD500G4A404`d=01D?3`0I4a<0618B01H@4P0K4QP03PD:01dD6@0W7R<0
7A@G01P?4P0K4QD08aXK02HM7P0N5AH06Q8@01081`0S6AX0308300d51@0201@:2`0501`B4`0Y7b00
:AlP01L=3P0C2@X00P0D2P/05P0F30d05@/<01H<3@0F30d05@/<01882@0K4A808ALH01P>3`0A1`P0
4PP901L=3P0N51D050X;01D;300C2@X05@/<01T?400@1PL04PP901/A4P0Z824201882@070147200@
1PL04PP901<92P0D2P/04@L801882@0201<92P804PP90`0D20X0100C1`T04PH80186200C1`T20186
200?01<72@0A1@L050P:01L<400=0PH09a`P00h31`0@1@T081DI00d21P0?1PP08aPL01P=4@0@1@T0
4PL;00H04PH800<07A4C01@82P0B1PP00P0B1PP00`0F2P`04@D901452@020104200P01452@0B1PX0
3P8600/10`0:00804`L;01L;3`0:00804@D901H:3P0A1@T05@T=01/?4`0B1PX050P<01862P0A1@T0
5`/?00h21P0D20`03@<400d10`0A1@L02000030T9P3Fb/`0FdmA00d10`0K3a403P@501dA4`080006
0104100601<71`0D20P060`<01T=3@0E2@T04`L71P0B1PX00`0@10P04@D90104200200l31`0D00l3
1P0@10H03`<500h2100D20X04`L900`10P0:00006Ph@00l41@0<0080200001<72P0I3A403@4501dA
5@0800006@dA01862P0A1@T301862P0801@8300A1PP02P0000h2100G2`d050P:0186200C1`T50186
200301@82P0C1`T06@h?008050P:00L03`<501041P0<00805PX<01<72@0@10H03083008040@40P0B
1PH05@0A1@D040@400T0000C1`L07Q8B00h20P0K3`l040@401@82P0@10H03`<500h2100;00404`L9
00l31@0@10H04`L90186200A1@L040@60186200401451`0700h2100C1`T05PX<01T=3`0H30h050P:
01451`0401@82P805@T;00H05`/=00l41@0800004`L901041P0J3Q0Dooooo`006oooool201D:4080
4`P>00@050T?01D:400A1P`04`P>0P0A1P`02@0E2Q006@hB01D:3P0?1@H04@L801@:2`0B20T04@L8
02@J6`0201@:2`030147200E2``03`D600<04@L800@04PP901<92P0C2@X05`d>1@0E2``04@0B1PP0
40@601@82P0E2@/04PH801@82P0H30h07A4C028F600L41805@T;01L;3@0C2@X04@L801882@0D2P/0
4PP9008040H700h04PP901L=3P0A1`P03P@501<82`0E2@d04PH:01H:3@0800005PX<02lS9@0J3Q00
5PX<01<720@050P80`0C1`L03P0D20P05PX:01X>3P0B1PH04@D50104100;00005@X901dC4P0J40l0
4@L601D;2P0G3@`04PP70P0?1@@0600@1PD06a4@01`B4@0@1@L05``@01<8300:00<06@hB03`a=@0B
1`/03`@801H;3`0A1PX05``@01T>4P0B1`d03@8801H;4@0C20h04@H<01@93`0F2a405@X@01@93`80
5P/A01805@X@01H;3`0F2`l05P/?01D:3P0F2`l060dA01872`0700006PlC01052@0B1`/04PP;01D<
3@0?2@T040X:018<300>20P301<=3@8050h>1P0E3`l201PB4P0403`f=P0W8B405Q0@01D?3`806A<C
00<05A4@01LC4P0J5QD00P0K5aH01@0J5QD04Ph=01/G5P0Q7A`06ADD00806aLF05D08A/M01hI6`0N
6Q/07a/L020M7P0R82406aTJ01DE5@0N7Qh06QXJ034a<@071`L081`K01hM6`0P7ad08R4O024Q7`0R
8R0092@R020R7`0M7a`08R@Q01/P700Q9R808B4Q01lO7`0Q8B409BDU02@V9@0R92<09RPW02DY:00Q
9B@092PW02D[:@0S:BL0:34`02Tb<@0Z<c80:c@c02lg>@0b>S`0:c<f02lg>P0a>3d0<3Lm02lf?00[
=3H0=d50034k?012CDh0:C@f02Pc=`0/>3d0<d1603a;DP0c@DT0C5YS041>F@0gADl0>DI>03M4C@0d
@DX0>TIB04QDHP2DX:h0RiNU04]GI`1;EVP0Ef9d04aGJ`0lBED0@4mB03a;CP0nCE00@U5D04=BE@0o
CU40@4mB03e<C`12DE@0?4]>04IEF013DUL0AEAI0080B5ML00<0AeIK04IEFP16EEX00P1>GF801016
EEX0C5]P04YIGP1<Ff0204UHG@80B5ML00d0DF1U04aKH01?GV<0E6=X04QGG01GIV/0DF1T05ASIP1C
Hf<0DF5Q051PH01AHF40Df=S0080EFEU0140EfMW05QXJ01GIfL0E6AU059QIP1HIfd0FVU^05e/L@1P
Kg<0FVU/05UYJ@1KJfX0G6a[05e]K01OKf`0H71_05][J`02061`L004069bLP1UMGD0HG5a06EeM@80
KGem00/0K7al06]kN`1SLg<0Hfi`06mjO01WLW@0HFa^06E`LP1TKg40JGAf06YeM`0306UdMP0906Ye
M`1[MWX0IW5e069]L@1QK6h0GFQZ05YUI`1MJFT0FfMU0080FVIT02P0FfMU05aXJ01NK6h0HW1c05YX
J`1DHVD0FVQ[05i/K`1IIfX0EVAW05ARI@1@GV40C5YM04]IG016E5D0>4I904IDE`19EU`0OHZB0;g:
dP1?G6@0AE9H04=@EP11Ce80@Dm@04ABD`13CU@0BUEK059MH`14Ce<0?DQ<03]6B@0kATP0@De=03Y6
AP0d@400=d=303Ho@@0m@TD0>d130P0e>Sd0500c>3/0;S<f02X_<P0Z;c80;34d02T^<@0Z;c80=SY2
03/oB`0h?TX0>T9:03DnA@0^=c`0;cTk034k?00]=CL0:2d^02T[:P0/;2`0;Rh^0P0a<C403@0/;2`0
9bLW02PX:00Y:BT09RHV02<S8`0R8R8092@T02/[:`0V9RH0:2PX02`/;00[:b/00P0W9bL0;@0f=SH0
7AdM01PH600I6AT071`L02TY:@0[;3006Q/O02@U:@0Y:Rl08b@Y065RI`0`<3P0:2P`02LW;`0M7BL0
:b/e02HV;`0H5ad06APM01dL8@0R8BH092<X028Q9P0U92T06APM024P9@0H5a`06APM02<R9`0G5Q`0
6aXO00l>4`0C4QL06QXM01LG6@0L71h061PI01HF5P0I6AT071`L01dM7@0M6ah071XM01TG6P0401PF
6@@05aDH00X061HI01HD5`0I5aX0518E02HT9`0@3Q408R0S01XH6`0H5QT06QPK0P0M6ah04P0H5QT0
4`hB01TD600L5a/04PdA020K7`0H4aL05Q4E01/F6P0E41@061<G01LB5P0H51D04@d=01HB4@0G4a80
5Q8A01DA40805Q8A00<04Ph=014=300C3`h00P0C3`h0900Z92@09b4Q01`F5P0G4A407QPH00d71`0F
41006A<C01LA4@0C3@d050h>01H@4P0F31808AHL01`A5`1LDEL0;R<W01462P0D2@d05P`=01`B4`0M
4a@060h=02TO7`1DBT/0<RPY01dC500E2``03`D601@:2`0M4a@06a4B01@:2`0K4A806Q0A01<92P80
4@L800H04`T:01D;300C2@X04PP901T?400J414201D;300:01H<3@0B20T05P`=0147200F30d04PP9
01L=3P0H3Pl02`4201882@804`T:00@03P@501<92P0C2@X04PP90P0A1`P00`0C2@X04PP901882@03
01<92P0301882@0B1PP04PH800804`L90P0D20X04P0E2@/04@D701@82P0F2P`04PH801<72@0;00@0
6PlC08=hO00U6Qh02`0401D:3P07000060dA02/P900D2@d04@H:01052@H04PH800H060`>0186200C
1`T05@T;01@82P0F2P`201452@8040@80P0B1PX07P0A1@T09ATM028F6P0D20`040@801L;3`080000
5@T=01T=4@0;00<02`430104200D20`04@D900`0100B1PX03P8601L;3`0C1`T08ADG02dQ8`0U6A/0
200006MKG@0o<cD02@000186200M4A<04@D701@82P804PH600X04@D501861P0B1PH04PH601451@0B
1PH04`L701H:2P0C1`L040@41P0B1PX00`0C1`/050P<01<72`0201452@0401862@0B1PP04PH80186
20805@T;01T04`L90186200F2P`04@D701@82P0B1PP04@D801T=4@0B1PX0304401L;3`0;00<05PX>
01@8300B1PX03@8500/00`0<00@05@T<01D92`0A1@L040@600l31@0D20X05@T;00D040@600L04PH8
00X0000=0`@04@D70186200;0@80710B00805@T;00D0300201041P0D20X040@401451@0301861P0D
01451@0D20P040@400P0000Q5AD040@401471`0=0@<040@601P<3P0I3@l04`L901041P0>0P@04@D7
01@82P0B1PP040@601451`0B1PP201041P040186200C1`T040@601D92`@050P:00<04PH801D92`0E
2@/0100D20X01P0?0`D04`L901H:300K3a404`L9018621Cooooo000Kooooo`805@X@00/04`P>0187
3@0C20h04`P>0146300C20h03P<900l42P0F2a4040D901<8300501@:2`0701H<3@0B20T05P`=01<9
2P0G3@h040H701882@020147200701882@0C2@X050X;01<92P0B20T04@L801882@0201<92P0B01D9
2`0?0`D05PX<01L;3@0A1@L050P:01451`0E2@/06Ph@01D92`0@10H050P:01<92P0@1PL04PP901L=
3P0D2P/04@L80P0B20T03@0H3Pl04PP901882@0T6A/040@801H:3P0X71l04`T:0147200F2P`04`L9
0186200D20T0100G2`/301H:2P0401L;2`0B1PH05@T901861P8050P800L03`<301L<300Q5aD081HD
01D;2@0D2PT050X800804`T801T04PP601H<2P0>10803P@201L=3@0A1PX05``@01T>4P0B1`/05P`?
01<8300?10P05``@01462P0D2@d06@hB01P=4`0@1@/05P/A01D:400K41H04@L<01H;4@0E2Q0050T?
00805P/A00@05@X@01<8300E2Ph05P/?0P0D2@d00`0G31006@hB00l4200201H;3`08020E6@0K4AD0
8QTJ01LA4@0F41005a4A01@>3P0N61P201<=3@8050h>0P0E3`l201LA4@805@l?0P0G4A401P0M5aL0
6Q@D01LA4@0I4a<06Q@D01TC4`8061@C00L06ADD01/G5P0N6QT081`K051<B`1ACD`07a/J008081`K
01808AdL01lI6`0L5aT081`M024M7P0N6a`081hO028P8@0F5QH08R8R02DU9@1JFUX09RHV01hJ6@0J
6AH07ahK028Q7P0Q8Ah2028S7`0701lQ7@0L7QX08B<O01XO6P0P9B408B4Q02<S8`0202@T90808bDT
00H0:R`[02X^;@0X;2/0:Rh]02T_;@0U:bT202Tb<@0702Pa<00Y<S40;3@f030h>P0]=CP0<SXm03<k
?`02034h?P0V038k?@0c?C`0;CLh03M1@`0lAdT0NHB805MSJ00f@dT0?TeD03Q6CP16E5d0?4YE03U6
DP0jAU40?4QE03m;F00lB5D0?TYH041<FP1NJWP0EF5`049>G@0lB5L0B5=T04=@FP0oCU40?Da?045@
D`14DeH0@E1C03m>D@11D5<0?Da?045@D`0hAdX0@E1C041?E012DEH204ACF00604=BE`16EEX0?4]@
04QGG01CHVL0AEAI0`1;FUl03@19F5d0BUUN04YIGP1:FEh0DV5V04aKH01@Gf@0C5]P04eLH@1HIf`0
CEaP05ASIP1CHf<00P1AHF40701BHV80E6AT04iNGP1>GUh0D61P05=SH`1FIVH0EfMX04]JG`1LJg40
HW5g061_M01MK700EfIY05UYJ@1JJVT0Ff]Z05a/J@1NKV/0Gfm/061`L01TM7@0HW9b06=cL`1XN7P0
IWIf06=cL`1YNGT206QhN00906MgM`1PL700HVe_06A_L@1UL780I6ma06IaL`1XLgD0IW5c0080J7=e
0180Ig9d06UdMP1]N7X0JWEi069]L@1OJVh0HVe_061[K@1NJF/0GFUY05]WI@1JIV@0FfMU05aXIP1M
JFT0FfU[05QVJ@1EHfH205]YK00505ARI@1GIFP0Df5T051NH@1=Feh00P1<FUd0A`1?GEh0CUaO051N
H@1;F5h0AU=K04UFGP11CUH0>dQ>03e:D010CU40@U1A04IDE@12CE<0D5]Q061[L@1<Ee/0?TU=04QC
EP0lAdT0=d=303U5A@0`?3`0=41003M0@@0h?D00=CXm03<h>`0e>Sd0<SLj02/`<`0Z;c80;C8e030e
>00]<SD0;S<f03PlA00e>4L0<cQ403U1BP0d?D80;CHk02Tc=@0Y<c80:2h^02<W9P0Y:bX0;Rh^02`[
;00Y:BT0:b/[02l_;`0^;Rh0:RXZ02LW9`0V9RH08R8R02<S8`0W9bL0;Bd]02`/;00O7al09bLW02h^
;P0Q8B409RHV071`L011@D408b<S024Q8@0P820092@T00<08b@X0P0T9BX07`0R8bT08b<[020P:00P
82T0820Z02TY<`0L72D081lU01lN8`0Q82D08b8W028Q9P0L6b007QdR01HE6P0Q82D061LL03He>P0L
6b0071/Q01/J801QH6D0>STn01dL800J6Q`071`N01XJ6`0I6AT06QXJ01/K6`0J6QX00P0J61/0100I
5aX061HI01XH6`0J61/201TG6P805aDH0P0I5aX01`0H5QT0EE=F01HD5`0M6ah06QPK018@4`0E4aH0
0`0F51L201LE600b04@oA00S7R<061<H01hI7P0>2Ph06A@I01PC600N6Ah07APM01D@5@0D3a@04`hB
018>3P0F4Q405a<B01HB4@0G4a8061@C01/G5P0E4A00510?01HB4@0H51<05a<B01/E5@0M5aL06aDE
01D?3`0L5QH050h>01H@400J51@0618B018<300D3Ph0618D01H;4P0L4AL04`P>02LL8P0?1PP07a@H
01T>4P0E2``060h?01/A4P0H3Pd04`T901lE5P0?1@H201<92P0:01X@4@0I3a005P`=01882@0D2P/0
5`d>01H<3@0C2@X050X;01L=3P807Q@E00D05`d>01<92P0G3@h05@/<01<92P0201L=3P0=01H<3@0C
2@X040H701@:2`0F30d04@L801T?400?1@H05P`=01<92P0E2``05P`=01@:2`0201D;30804@L80P0C
2@X01@0A1`P04PP901@:2`0D2P/04@L800804PH80P0C1`T201@82P0B01P<3P0A1@L060`>01hB500E
2@/04PH800l5200=10H0I5UM02PM8@0G31003`@800d31P0@1`T05@X>00h31`0D2@d03`@81P0B1PP0
200F2P`04@D701<72@0E2@/04`L901@82P0E2@d050P<0`0B1PX0;00C1`/040@8020D600M4AD04PH:
01452@0F2Ph05@T=0105200D20`06`lC01D:3@0>0PH040@801<72`0D20`05PX>00d11@0D20`04`P:
01D;300?1@H0<bLY01P<3P0C1`T03`@601dA4`0<0080BCdo08YnP00P51H05PX:01D9200D20L05@T8
01D:2@0F2`X05@T801@9200B1PD05P/:01P<2`0D20P04@D81@0A1@T5010420030145200A1@L04PH8
00804PH800h04`L901051P0M4A<02@0001<72@0?1@H07a<E01872P0B1PX03`<7028F6P2FRXh0710D
01<72`<04PH:00D05`/?01dA5@0H30l03P8401041P0201<72@8040@61@0A1@L03P0B1PP04`L90188
2@0C1`T050P:01<82@0=0@<03@8301<72@0;004040@60186200A1@D04PH60P0C1`L201861P0701L;
2`0<0@4060d=069FEP0U6AT04`P801041P020186200@01061`0@1@H04PH800l31@0B1PP050P:00l3
1@0>0P@04`L901H:300B1PP03P8401<72@0G2`d05PX<01<72@8040@60P0A1@L0100>0P@04PH80186
200B1PP201451`0701041P0?1@H04PH801<72@0A1@L04PL90187200Dooooo`006oooool05`0D2A40
4`P?0146300A1Ph04@H=0146300A1Ph03P<:0146300B1`l040D<01873@0@1@T05@/<01<92P0?1@H0
3P@500l51P0>10D04`T:01P>3`0A1`P060h?00804`T:00d04@L801061`0B20T050X;01D;300H3Pl0
5@/<01<92P0A1`P040H700l51P0D20X06Ph@00804`L901X05PX<01451`0E2@/03P8401451`0F2P`0
5@T;01L;3@0D2P/040H701<92P0J414060h?01@:2`0G3@h04PP901H<3@0A1`P06@l@04<h>`0F2Ph0
200001X>4P0D20`0710D01041`804@D700<04`L901@8200B1PP00`0B1PH05`0A1@D04PH601861P0D
20P06Ph>01@8200A1@D04PH60104100E2PX040H401L=300P5Q@04PP601061@0C2@P05@/900h40`0=
10@060h<01@:2@0F30`05@X>008040D901404PL;01H;3`0G31004@H:01L<400B1`/05P/?028G700?
10X06@hD00`31`0I3Q@04`P>01P=4`0F2a405@X@01@93`0201H;4@0401D:400A1PX04`P<01D:3P80
4PL;01D05``@00/0100D2@d060dA01872`0I3Q805@X>02<J7@0E3`l04PX<01@;3P0B2P`07QPH01D<
3`0D3@h050h>01H=400F3a005@l?01PB4P0G4A400P0E3`l201H@400<01/E5@0J51@05Q0@01@>3P0G
4A406aDE01`F600I51@061@A01XF4`0P7AP0924L0P1iMW40C00P7AP0:BDR024M6P0L61L07ATJ020K
7`0[9bP0;2PY028O800O7Ah07ahM01LG5@0S8b406QXH02h^;00L6aT06QTF01HE4`0N7AT08R4O01lO
7@0R8R0071`J01TK600G6AH07R0M01/M6P0Q8b808b@V020Q8`0Q8R@09bPZ02X[;@0X;2d09RPZ02T]
;P0W:b`0:2`]02D[:`0Q9bL0<3Th02hg=P0[=3<0:C8a02/c=@0]=CL0<3Pk03<k?P0a>Cd0<3Lm03@k
@@0e?T00<Shn03Q2@`0`>cd09C0b06YeN@0oBe00;ca203Y9CP0`?dH0=4=:0390B@12CeP0>TA>03M1
C@14CUX0Ae5M04==F@10BUP0IW:004mKJ@19EF<0@dmM04A@GP10CUL2041?DP0L04IEF017EUT0@U5D
03m>D@10Ce80>TU<03i=D00jBD`0B5MJ04=BE@15E5L0AeIJ04EDF@16EEP0CEaP04MFF`1FIFP0I7=g
04aKH01>GF00C5]O04]JG@19F5/0BUUL04UHF`17EUT0C5]O051OI080DF1U01T0Df9W04aKH01CHVH0
EFAW05ATI01BHV80D61P051PG`1BHV40CEeL051PH01BHV80DF5Q05MVJ@1YN7/0EFAY05i]M01GIVd0
D5mT05ETJ@1MK6l0F6MZ05UYJ@1JJVT0G6a[0080GVi]00h0H71`06=bM01OKfl0HFmb06MfM`1VMWH0
KG]l06elO@1UMGD0I79c06IeM@1SLG80J7Ad05m[J`80I71`00<0G6QX05m[J`1QKFd00P1UL7804`1T
Kg40J7=e06iiN`1VLGD0GVU]05]VJP1QK6l0HVea061[K@1OJV`0G6QX05]WI`1LJ6P0GVYZ061/K01P
KVl0KG]n06MeMP1HIVT00P1CHF@08`1DHVD0DV1S051NH@1=Feh0BUQK04UGFP1:FE`0BeUL04aIG`16
DeT0@4]A03m:D010Be40?TU=04A?D`13DE@0@4i?045?DP15D5D0@diD04iIG@0mB4`0?TU=06IaL`1?
Fe/0<S`m03I0@@0[=CH0;cTj03Dm?@0c>CL0<SHe030e=@0b>3P0;c<f0080:2d`03@0;S8e038g>P0^
<cH0<CDh030c>P0W:CD0:R`h02hb>P0T;2l08BT[028[:`0U:bT092XX02<V9P0];Bl0;bla02l^;`0X
:2H0820P024Q800V9R@092@T02LW9P0Y:BL09BDT02LW9`0[:bT0<C4a05iNGP0`<C<06Q/M02LW:@0P
8B<0>3Tk07MfN`12@dD08R<U02<S9@0N7b408R8T020O900I6Qh0820T024P9@0H6Ad09RH[01hM8`0K
72408B4Y02`[<`0`<3P09bH^0P0Q82D05P0S8RL09B@Y02<R9`0M72407ahS028Q9P0O7R<05QDJ075`
M@0n?D8061LL028P9@1gMgT0928W01/J700E5AL07A/N01/J700J6QX071XK01/J6P0G5AH301PF6@05
01TG6P0K6A`071XM01TG6P0G5AP00P0E4aH07@0G5AP06ALJ014?4P0M6Qd03@/>03<^<P091PT07A/N
01<>4P0E4QD04a4D01<>4P0C41<06A@H01@?4`0]:2h06aHJ00h93P23OX805a8F018=4@0G4QH07QTM
01<>4P0H4aL071PI01LC4P0H51<05a<B00805A4@0P0G4a803P0E4A805Q8C01LC500E4A804`l@06eW
I`0K5AD0618B01LA4@0F41005@l?01H@400E3`l05Q0@0P0I4a<0=`0H4Q@05PdB0146300K4AL081LL
01`A5@0E2`h05`hA01P>3`0F3@h050/<01H<3@0G3@h05P`=01@:2`0N51D04@L801X@4@0D2P/04`T:
01@:2`0H3Pl040H701882@0I3a004PP900l51P0C2@X060h?01H<3@0B20T05P`=01T?400E2``050X;
01<92P0A1`P04PP901`B4`0?1@H03P@501P>3`0E2``04@L800l51P0@1PL081HG00h41@0B20T04`X;
01D<3@0B20T04@P901H=3P0C2@X00P0@1`P00`0D2P/050/<0147200201D92`0F01@82P0C1`T04PH8
01451`0H30h04PH801/?4@0S5aT060`>01451`0F2`l02`0401<8300G31004@H:01872`0A1PX03P<7
01L<400F2`l03P<701D:3PH04PH800X06Ph@0186200@10H04@D700l31@0B1PP060`@01H:3P0D20`0
4`L;0P0B1PX01@0I3A405PX>00l31`0B1PX060`@00805@T=00<040@800h21P0K3a<00P0D20`20186
2P060104200C1`/03@4501L;3@0a9BL020000P0F2P`0300800006@d?01H:3009000060`>01L;3@0Y
7Al05@T901871P0@1@<03`@201050`804PL500L04`P60146100<0@004@L501H;2@0A1`H04@H70080
4@D71@0A1@T08@0C1`/05@T=01<72`0@10L040@601451`0B1PP040@601451`0@10H0>2`^01H:300H
30h07Q8D08]oP@1LD5<07a<G00P0000D2P`040@800X00P0C1`/05PX>01<72`0>0PH03`<701@8300I
3A005@T;00h2100=0@<04`L901@82P060186200800l31@0I3@l05PX<00l31@0@10H04`L901041P0>
0P@200l31@0402HJ7010=3H04@D501861P804`L70P0B1PH03`0<00005@T901L;2`0A1@D03P8200l3
0`0A1@L04PH800h2100:00003@430186200@10H04PH801<72@0200d10`0301@82P0S5aT06`lA0080
40@600P04PH800l31@0B1PP04`L901H:300H30h050P:00`00P804`L90P0B1PP201451`0600d10`0@
1PL04@D700/00@0A1PL04@D75?ooool001_ooooo00d04`H@01L:5014=d005@PB01L:4`0B1@l04@H>
01L:500C1Q005@PB01853`0B1@h04PH:00<04`L900<050P:01D92`0C1`T01@0C1`T201862P0F0188
2P0m<SD0=2T/01T=4@0C1`/060`@01@8300A1@T04`L;01452@0G2`d04PH800d10`0O4aD05P`=03X^
<00g:bd04PH803HZ;00H30h04PH801P<3PL050P:00H04PH801D92`0C1`T040@601<72P0B1PX401<7
2`080105200C1`/05@T=01H;3P0B1PT04`L;01D:2`0D20X30186200301@82P0F2P`05@T;00<050P:
0P0E2@/01@0B1PL04`L901H:2`0B1PL04PH8008050P900X03`D601<7200@10D04@H702TM7P0D20T0
50T:01451`0A1`P05`/?0P0B1PX201<63@0501@73P0D1`l04PH<01D93@0G2`l00P0E2@d0200J3Q80
50P<01@8300B1PX0710D01lC5`0T61`06@dA0P0D20`00`0F2Ph050P<01X>4P0401H:3P0?01L;3`0H
3A406PlD00l52P0I3a@050T?01P=4P0G3A805@X@02<I7P0P5QX060dC01P>4`0L4aL050`?0080618D
00H05@lA01H@4P0L5QP05a4C01H@4P0I4aD201/E5`1e01D?4@0S6b40;2@V01/D4@0T81P09B4D03dj
:@2UXi80gmo?05aMC`0d=2T08b<K01hM6@0L6Qd071XO028P900Y9bX06aTK02<R8@0K6QL06QTD01/K
500O7aL08B4H020O6@0Q81l07alO01lO7P0R8R807QhO01XJ6`0Q8B809BDX024Q900S8RH09bH[02@U
:@0R9B/08bL]024U:P0Q9B/0:2`b02P]<P0T:2d092T^02DZ;`0a=S/0:2db02`a=@0W<2h092dZ02Pa
;P0[=3<0;SHh038j?00^=SP0;SHi03@l?`0e?D00<SXm034k?P0d@T@0@4a?03U7BP0`?T40=dE803I4
A`0d@TD0>DM:03Q6BP0kBDd0=dE903Y5BP0f?d<0=cm403e5B`0lA4d0>45:03m7D`12BeL0DEYY04eG
I`1:EVH0@4aM04aHI00oC580CEYP04EBF01:Eed0@DiD03e:D00nBe40@4eC049?E@13D5H0AE=G04ME
F013DE80AE=E03m=C`10CTl0MXB604QFF01=Fe`0JGMi06]iN`1AGf00B5IH04UGE`1;FET0AeEF04AB
D`1;FET0DEmQ059PH`1AGf80DV1S0080Df1V04d0DEiS05ARI@1IIfP0G6YZ05=QH@1DHf00BUUE04UH
E@1@GUh0EVAU051NHP1=FV00DEiU05=PJ01GI6`0F6E]05MTK01GI6/0FVM]05QUJ`1MJfl0HFma069`
LP1NK6h0FVQY05m[L01QKG80IG5f06=^M01TL7@0LWj2092KW`1^NWd0GVY/06=_K`1QKFd0GVYY065]
JP1QKVP0HVmY06A`K@1SKf`0Gf]X06=_K@1ULG00HVi^06=_K`1TL700GVU[05YXJ`1KJ6h0FFI/05MU
JP1MJW00FVQ/05e[K`1JIf`0FfQ]05UVJ`1GIFT0FfU/05ITI@1JJ6P0FFMW05]YJP1FI6D0CE]L055O
HP1?GF00C5YM04]HGP19EU`0AeIK05Y[LP11D5L0A59G04QDF00204=<CP1>04A=C`17D580ATmA045<
CP0oBTh0@4]?04QCE`19E5P0?dY>045:C@12C4h0?DI803U2@`0i@D80=Cdm03U1@00k@d80=3Td030d
:`0_<RX0;c8]02X];00Z:bd0:bda02LY;P0/;3<0=SPm030b=`0`<CH0=SLl02`/<@0X:2d0:R/^02XZ
:`0_<2h0:R/Y02PY:00W:2L0:RX]02HU:P0V9B`0:RT/02DV8@0S92009RLS02h_:P0W:2@0:b/W02<T
7`0Q8Qd08B4N04E6@@1=CD/07b0R02@X:`0V:2d08B<Y02@W;`0U9S00<c@o02DX<00N8BP092H[028V
:@0Q8bH081lT02DS:P0T8RL07adP020O800N7A`0:2LV028Q800N71l09R@Y02TW;@0S82L08R0U0P0R
82<00`0T8RD08b4T01lM800201lM800G01dK7P0P7R408R0S01lM800k>3X0920S01`I6P0M6A/061DF
01hK700K5aP06AHG01`I6P0Q7Ah081`M01PD5@0J5QL07ATJ01LC500L61T06QHG01`H6@0J5QL00`0K
5aP08@0J5QL06ADF01`G6@0J51H061<D01TC5@0I51H05a8D01`F600G4A<061<E01TC5@0H4Q@07ALI
02LQ8`0M5aX0618D01TC5@0J51D06aDF01LA4P0F40l061<A01`G5@0H4`l04`h:01PB4P0F41006Q@D
01TC5@0F41806A<E01`F6@0201TC5`0501XC6@0C3A8050hB028L7P0K5AL00P0H4Q@05`0G4A<06A<E
01TC5@0E3a405a4C01/E5`0F41804P`>01H@4P0G4180614C01PB500I4Q@05a0B02hX:P0@20/05a0B
018=3P0I4Q@04`T=02DJ7P0G31006PlC00<050T=00`05P/?01@93@0E2Ph05P/?01D:3P0G2`h04PH8
01P<3P0C20X040H701P<3P0F2P`201L;3@0O01H:300D20X050P:01<72@0D20X05`/=01H:300B1PP0
50P:01L;3@0D20X04`L901H:300G2`d050T:01<:2`0C3@d03`P800l7200C3@d04``=06QPH@2c[Jd0
>c@d02PQ8@0J51@040P901882@0B1PP04@D70186200401@82P0:01<72@0B1PP04@D701041P0B1PP0
3`<501@82P0H30h05PX<01D92`@04@D70P0C1`T03P0>0`H05@T=01D93@0J3Q804PH:01452@0B1PX0
50P<01452@0B1PX05PX>01452@0F1`X05@H90P0D1@P201H72P8050D8100C10L601451`0401@82P0C
1`T04PH8018620804@D701l08QHG01P<300C1`L04`L701@8200E2@T05P/;01<92@0C1`L04@H601/?
3`0`92@0?Bl_00l10@0L3Ph04`D501P<300A1@D05`d<02DK6P0K4A004@T70189200?1`D04PX800`3
0@0A20H0>2h^02PN7`0D2P/04@D700<050D:00<04`@901<4200C10L0100C10L0200G20/07PlB01h?
4P0D1PP06@X=02dN8@0Z6ah050D80P0E1PT0200C10L04P<601831P0E1`T03@0101P:300H2@`03001
0`0C10L0100D1@P04`@701<41`0C10L201831P0_01421@0B0`H04P<601441@0>10<04`L701871`0B
20P05`d>01D:2`0@10H04PH:00d31@0J3Q80;b<V01H72@0E1`L04`D50184100C1@D04PD501@61P0@
0P805@P801861P0?0`<0;b4Q01@82P0C1`T04@D700l31@0@10H04PH801061`0H3@h0@CDg01D;300B
1PP05`/=01l@4`0J2`h04`@701421@0D1@P05@H901@5200C10L00P0B0`H0100C10L050D801<41`0D
1@P201D62@0301@5200C10L04`@700D04`@75?ooool001_ooooo00h070lH00h12P0C1Pl0200401H9
4P0A10d040<<00h22P0A10d03@0901hA6P0K3QD050P<01@82P<04`L900<04PH801@82P0D20X0100D
20X02@0C1`/07A4E01@8300^8RH0:alS00h21P0E2@d08ADI01`@500201<72`0:01@8300C1`T07Q8D
00l31@0E2@/04@D702lS9@0/828040@601D92`80710B00<02P0001@82P0D20X0100D20X201862004
01<72@0@10H04PH801D930804`L;00X050P<01<72`0B1PX040@802XN8P0:00804`T;00P0000A1@T0
60`?0P0C1`T00`0B1PP04`L901<72@0301D92`8050P:0P0E2@/0500B1PP04@D701H:300C1`T04PH8
01L;3@0E2@/04PH801T=3`0C1`T09ATK08j2P`18?3`05@T;01<72@0A1@L04PP:01862P0C1`/04`H=
0P0D1`h01P0D1`l04PD<01@8300F2Ph050P<01<72`8050P<00/040@801T=4@0J3Q804PH:01`@500H
310050P<01L;3`0L41@06@dA01H:3P0401L;3`0801P<400I3A4050T?01L<4P0E2Q006@hD01D:400O
51X201L<4P0_01D:400G3180714G01H=4P0I41<04`d?01/E5`0V828091hP01H@4P0B30h06Q@F01/E
5`0G4A<05Q0B01`F600J41P07QDI01dE4`0N6A<0;b/N04=0;`2[ZYP0dm?204a=?`0R8QP07QdG01XI
5`0G5AX08AlU01TG700G5AP06aTK034`;P0O7Q/07ahI024Q6@0T91`08B4G01lO5`0L71/07QhN024Q
8@0R8R807QhP01/K7@0P82800P0X9b`01P0V9BX08b8X01hO900W:c4092T_02<X;P8092T_00`0<SLm
04U>E00Q9R`0:c0f02DZ<00R9bd0:Rlc03@m?@0U;Rd0:C8a03<l>`0a>C/202hf>00Q030h>`0e?D00
=cm203Hm@`0a>cl0;C/n05ARI@1PKW40;ce0030n@@0hATT0=dE803U7BP0mBdh0=TA70390@`0e?d80
:c<f0499C`0lA4X0@T]B03Y3C015CUT0?dUE075jR@1DGfh0@4aL04iIJ`12CeX0>dQ>04UFG014DEL0
AeAJ00<0@DiD0140A55G04UFG01=FV00CeaQ055OHP1:F5T0B5IG04aJF`17EEH0@Dm@04=ADP14DU<0
BeUJ04eKG018EUL0BEMH04ECD`0204UGE`0304MEE@1=Fe/0DEmP0080E69U01T0DEmR04iKH@1?G680
DUmU04mMH01^O7d0NXR904eKF`1;FUL0CeiK04mMG@1BH600EfEW05MTJP1EHVX0EF9[05ERJP1FHf/0
F6E]05]XL01JIfh0EfAZ06=aM01QKg80GF]^00<0FfUZ01T0GFQ^065/LP1YM7X0JWEi06E`M01TKg<0
Q8nA06ehNP1NJF/0GVYZ061/K01SKfd0GFUU06IbK@1XM700Hfm[05eYIP1MJFL0Gf]Y05iZJ@1JIVH0
G6QX065]K@1NJF/0G6Y]0080F6E[00@0EF9X06=`MP1BGfD0F6E[0P1MJW0205AQI`0I05aZK@1AGf00
E69R055OG`1@GUh0DV1Q051NG`1:F5/0CUaO04mMH01=FV00AeAJ04ACF01QLWX0A5=J045@E@14Ce<0
?4A703Y2A00kA4<0>D5303a4AP12C4h0@TeA045<D00204=>DP0@03]6BP0lATP0?TQ:03Q1@`0f?T00
>T=2038i>@0^=3@0<SPh030e;`0c=R/0<cH]038d;`0W:BP08b@V02//<080:RXb03@0<S8i02`]<P0[
;340<c<h01lN8`0k>Sl0;Bd_03Ti>@0c<c40<C4_02TY9`0V9RH0;2`_02/Z;`0V9B/08b8U020P7P0X
:2H0;bl]02/[:@0X:2H08b<Q02HV900Y:BL08B4O01TI5`0S8b40824S02DV:00V9b/08b<[02DU;@0U
9Bl09bLa02<S;@0T92d09bP]02DV:P0S92P071/Q02@Q:00P7R807A/N028P8@0/:bT08R4O020O7@0P
7Ql08R0U02@R9`0T8BL08b4V0P0Q7b803P0S8B@08R0S01/I700T8RD08AlR01TG6P0C4A@06aTL02HT
9`0_:b`081`M01dI6P0N6Q/06QHG0P0N6Q/201/G600301<?400G4a@08QhO00806QHG00H05A4B01`H
6@0N6Q/040`=01DA4P0G4a@201TE5P0:01XF5`0I5AH06Q@F01LA4`0F41805a4C01PB500F4180618D
01XD5P805Q0B00L06A<E01LA4`0F41805@lA01LA4`0J51H06A<C0080618B01d081/H01hI5P0F4@h0
5Q4=01XE4@0G4A409AlO040j>P0[9BD05@lA02PR900?2@/04`dA01`F6P0C31<0;2D/014;3`0K5AP0
4@/=020J701MEeT050h@01dG6@0E3a405Q0B01XD5P0M5aT05a4C018<3P0201TC5@80618D01X05a4C
04U3A@3CcLl0@cdo01/E5`0=1`T07QPJ0189300H3A406@hB01H;3`0B1`/0:b0T024F6P0F2`l050T=
01D:3P0F2`l05@X>01462@0K3a408ADG020D5P0K3a404PH801041P804PH800`05`/=01X>400H30h0
4PH801<72@0I3@l0710B01L;3@0B1PP04`L901@82P0H30h201/?4@0A01D:300J4A801@0000h8200D
3Ph03`T901LA4@1IDe<0ViFE03Pb<P0600002`D5018:2`0B20T04PH801451`0C1`T0100D20X02@0C
1`T04PH801451`0@10H04PH800`00P0H30h08ADG01H:30030186200@01451`0B1PP050P:01@82P0E
2@d03`<700P0000900404PH:01hB5P0@10P05@T=01452@0@10P04`L;01452@804`@700@050D801D6
2@0G20/06@X=0P0E1PT0100D1@P04`@701<41`0B0`H701451`<04PH80P0C1`T0900@10@05PX:01D9
2@0@10@04PH601H:2P0A1@D0Ac/k01dA4@0J3Ph03`<300P0000L3Ph04`D501/=3@0C1@D06`l?01<7
1`0E2`X06a4@01@:2@0A2@L04`/901081P0A2@H03PH401@<2P0I3`h03@<4020F5`0C1`T04P<80142
1`0B0`P050D:01@52@D04`@700P0408400l00`0C10L05PL:01@5200?00<03`8301831P804`@700L0
4P<601421@0F1`X03`0301/<3`0b8bH070d@00@04`@700<050D801<41`0C10L00P0C10L301831P0?
01<41`0C1PH06a0>00P0000L41003`<309N;S@1MDE<09a/M00l41`0I3A404PH:00l31P0B0`H04082
00805PP800P03@000184100=00005@L702XL700P4Q803@0001D71`<04`L901404PH801451`0A1@L0
60`>00h2100F2P`0200001H:300<0P<04`@701831P0C10L050D801<41`0>008050D801<41`020183
1P0401<41`0D1@P04`@701@520805@H900<050D801<41`0C10L01@0C10LDooooo`006oooool03P0G
2Q<04PD>00`0200A10d06PdF00d02@0F2A804@@=01<63`0800@05`XC00/01@0E2@d050P:0P0C1`T0
0`0B1PP04@D701@82P0501@82P0501H;3P0;00<06PhB0105200800000P0D20`00`0L41@05`/?0145
2@0201452@0<01P<3P0^8R@07A4C01L;3@0800003P8400h41@0D20X02@0001451`0=0@<04PH81P0E
2@/01`0B1PP050P:01@82P0@10H050P:01T=400D20`00P0C1`/02@0E2@d05PX>01L;3`0T61`03P86
024E6@0:00804PH:01<72P0601<72@804PH800X04`L901@82P0F2P`06@d?01@82P0A1@L050P:0145
1`0?0`D04@D70P0D20X02@0F2P`02`010186200b9RL02@0000l51P0<00803P8401X>4P0201<72`<0
50L>00H05@P@01P;4P0I3A406@dA01H:3P0C1`/201862P0502<G6`0_8bL0710D01/?4`0<00@00P0G
2`l01@0I3A406PhB01T=4@0H31006@dA008060`@03@05`/?01P<400I3A404PL=01X?5@0B1`d0714G
01T>500/8BL07a@J01`A5`0E2Q005``B01X?5@0B2@h06A0C018<3P0L5QP0:B<U02XT9P0K5AL04`d?
01TC5@0J51H05a4C01PB500M5a/050XB01XA5@0S6aT071LA02HR5`0Z9aP0?cd^05iNC`0S8aL08B4I
02@S7P0D4Q<05A<H01lM8P0L6Ql0928U028P8P0N7A/07QdI01lN6@0Q81/08R8J01hN500K6a<0820O
0P0K6a/05P0M7Ad0820R02@T9P0O7b409B@Y02LV:`0T8bP07ahT01`M8P0L82L092T_01LL8P0/<CL0
UIZP08R=T`16Be407b@Z02T^=00S:2h0;c@j03Dj?P10B4T202hg=P05038k>P0/=3H0:C4c038j?00b
>Sd00P0d?3l0:P0b>Cl0=Cm302hl?`0oCE00D5iQ03=1A00]>ch0<Cm203U7BP0hATT0>TQ;03M5B00i
AdX0=d5502`d=`14Be40=3a3049;DP0oB540A4iG06UcO`2RZkX0Hfem045=G@1<EfT0C5QS03Y7C@17
E5X0AU=I04MDFP10CE<0@e1F049?E@15DUP0BeQN051MH`1AGf<0?D]>049@D@15De@0A59C04MEEP80
BEMH00L0BUQI04MEEP15De@0B5IG04IDE@16E5@0BeUI0080C5YJ00`0D5iN05=QHP1GIFP0EfEX05=Q
I01>Ff40CeaR05ERJ01>Ff40MXB708BBU016E5D2059PH00705=QH@1DHV<0EV=X05ERJP1CH6T0D5eV
05aYL@0205QUK@0X05]XL01KJ6l0EfAZ05m]L01MJfh0FfU/05aZJ`1NK6d0H6i_069]L`1TKgD0JgIl
06iiO@1XLgL0H6]_06=^L01OJV`0GVU[05m[J`1QKFd0HVi/05eYI@1RKVT0Hfm[061/J01MJFH0G6QV
05m[J@1PK6/0G6QX05eYJ@1QKFd0FfIX05m]L01DHFL0HVme05ERJ01PKG<0EfAZ05YWK@80FFI/00X0
DUmU05AQI`1KJF`0CeeN055OG`1=Fe/0BeUI04mMGP1BH640CE]N0P1>G5l0@P1:Eed0A55G041?E00m
C5D0AeIM04UFG00kATT0=Cdo03a4AP10BDP0>41203Y2A011Bdd0@4]?03]6BP0iA4P0>dI:03Q3A`0m
AdT0@D]=03]4AP0d?3h0=d0o038j>@0d>SX0>Clo03Hk=P0a=2/0:RdV02T[9`0V9bT09BHZ02TZ<00X
:300:RXb02d]=00S92T09RL/030`=`0b<CL0<C0f02XY;P0];Bl092@T02DU8`0T92809RHV02XZ:`0W
9R/092<X01lO800Y:BL0<c<a030`;P0X:2H0<C4_028R800W9bD0:RXX02PX9P0I6AL08B4O02DU9@0U
9RP09bP[02LV;0809RH^00`0:2Ha02LW;`0Y:Bl09bH[02<T9P0T92H06QPM02<P9`0Q7b<08AlR02XX
:@0l>cT2020O7@0:020N7`0N72407Q`Q024N900U8bP09B<V028P8`0L6Qd06aTL01dK7P806aTL00L0
81hQ024O8P0J61/061HI01lK700H51D071PI008081`M00l08alP024M7P0L61T07ATJ01<?400Y9BH0
7QXK01TE5P0N6Q/07ATJ01TE5P0N6Q/04Ph?01DA4P0G4a@00`0H51D03@0G4a@06Q@F01LA4`0F4180
5a4C01PB500G4A<050h@01/E5`0J51H06A<E01/E5`0B30h00P0E3a409@0F4180618D01H@400D3Ph0
6A<C01lJ5`0M61D05A0=01D@300I5100618A028L700g<C409AlO01D?4@0U7b405a4C01PB5P0E3a<0
4P/B01TB6@0F41@07ALI01`F600c;Bl0CDM9010:300J51H05@lA01H@4P0I4aD071HH01PB500E3a40
6Q@F01TC5@0H4Q@00P0F41803P0Q6ad0N79d01dG6@0>20X040X<01LA4`0L4aH06PlC01D:3P0?10P0
=R/_08QmP@1QEUX05``@0P0E2Ph201H;3`0E01P<3`0D20X03P8401D:2`0D20X040@601@82P0B1PP0
40@601H:300I3@l050P:01451`0F2P`06`lA01dA4`0J3Q005@T;00l31@0A1@L050P:00805`/=00D0
50T;00l61`06000040X:00X41002014;2`0700L10@0R71`030H601<=3@0=1`L03@H601061`020104
1P0301<72@0F2P`05PX<00<04`L900T04PH801451`0A1@L04`L900/00@0G2`d081@F01<72@0A1@L0
0P0C1`T06@0B1PP04`L901@82P0E2@/050P<01862P0H31005`/?01D93@0:00803`<701D93@0A1@T0
3`<701862P0A1@T050D801<41`0D1@P05@H901L82`0H2@`05PL:01D62@0D1@P00P0C10L00`0B0`H0
4PH8018620040186200301041P0A1@L04PH800804`L901X050P:01H:2P0I3@d05`/;01<71`0@10@0
4@D502LK6`3Fb/X0G51@01dA4@0I3@d0:1`L01430`0D1PH05`T901@61P0K3`l04@D501061@0C2@P0
3`D4018:200E3@/04`/900h71P804@T700@02`4100L0000L4Q<04PH80`0B0`P00`0D1@X050D901@5
200501@520804P<600D060T<01`=400J2`h05@H901831P0201<41`804P<600L050D800h00P0@0@@0
7@hA01<41`0=00404P<600804`@700D050D801<41`0C10L04`@701@5200301D62@0I01@5200>0`<0
6@h<01<71`0T61P03`<308b0PP1NDU@09QXL00X00P0?0`L03@4501@82`0H2@`040820184100C1@D0
3`4102@F5P0K3@d0300000l30`0L3Ph05PP800`0000201041P804@D700P040@600l31@0D20X02000
01D92`0900006Ph@01L;3@804@8500H04P<601D62@0D1@P03`0301@5200C10L201831P0401<41`0D
1@P04`@701@520805@H900<050D801<41`0C10L01@0C10LDooooo`006oooool03P0C1Pl06PdF00d1
2@0I31D06PdF01D84@0=0PT05PXB01T<5@0>0`X070lH01452`0E2@d050P:0`0C1`T70186200H01@8
300H31006`lC00l51`0A1@T04`L;01L;3`0B1PX03P8601<72`0E2@d040@801@82P0J3Q0030830187
200A1@L050P:01<82P0A1@L06Pl@01@82P0L41803P<41P0E2@/0300C1`T05@T;01H:300B1PP05PX<
01X>4@0E2@d04PH:01<72`0G2`l06`lC02HJ7P80D4A800@0>Rlb01@8300@1@P05PX=0P0C1`T00`0D
20X04`L901<72@0201@82P0901<72@0B1PP04@D70186200D20X04PH801451`0D20X04`L9008050P:
00/06`lA01T=3`0C1`T05PX<01461`0A1@H06Ph>01D;300M4A<05PX<01<72`0201@8300A01@73P0E
20l05@P?01H94@0G2Q405PX>01D93@0F2Ph05`/?01H:3P0G2`l04@L901X>4P0>0PH05`/?01P<400B
1PX00P0F2Ph00`0B1PX04`L;01P<400201T=4@0E01P<400G2`l060`@01P<400E2Q006a0F01D:400I
3Q@05P/A02PM8`0N4aT08AHL01X?5@0H3A<06a0F01P?500I41<05@lA01PB500L5QP07ALI00806A<E
02l05a4C01XD5P0N61X07aTK01TC5`0M4a/07Q@K01hE5`0G4Pl06aL?01hJ400N6a009bDK02<S6P0V
9B009R@S028P8P0M6al07adQ01LE600O7B007Q`M01lN700N7AT07QdH01lN6@0Q81T07AdE01XI500O
7ah07alO02@T900Q8B407QhP02<S9@0T92H09B@Y02LV:`0T8bP08b8X02@U:P0T:2`082DY02<X;00e
>Sh0@TM;02L/<00202T^<P0A02/`=00V:bl0;S<g02DZ;P0`>CT0;CHe02hg=P0]=CL0;SHh038j?00_
=cX0<CTl038j?P0b>Cl0<cY003DoA@0nBe400P0d@DL09@0gA4X0;ca203I3B@0oC580;ca2034nA00^
>d40?T]A03DoA00j@DL0?dQ=03M0AP0mATd0>TA=049<EP1FH6X0BEEQ04QDH@1<F6H0@4aL07J3SP16
DeT0?daB03a9C`12CeD0@4eC04QEF`15DUP0@e1F04EBF016DeT0@TmD04=AE016E5D0AE=D04IDE@1:
F5T00P17EEH304YHF@0S04]IFP14DU<0AUAD04]IF@1<FUX0BeUI04iLG01@GUl0EF=V05=QI01AGf80
DEiT059OI@1CH6H0EV=Z04YGGP1HIF/0CU]P05YXJP1<FU/0Df5S05=PI@1CH6H0Df1X05APJ`1GHg00
IFmi05iXL@1IHf`0FVE[05aWK@1KIV/0FfIZ05eXJ`1OJV`00P1PJfd0;P1OJV`0GfY_05mZK`1NJFd0
HFa`069]L01JIFL0H6]]061[K01LJ6P0FfMW061/K01RKV`0I71/05iZIP1LJ6@0H6aX069^J`1PK6X0
G6QX065]K@1OJf/0GfY/05aWJ@1BGEl0FfQ]05ERJ01jQhd0L7f305ISJ@1EHVP0JGIl05aYK`1HIF/0
E65W059OI@1DHVD0Df5R059PH01AGel0CE]K04mMGP1DHV<0C5YM04UGFP17EEP204ICF@0>04MEFP1;
Ff80>dY@03a9CP13CU00?dM903U2@@1<DU80?TM603e5AP0oBD/0>D=7038m@@0kATX203a7B`0n041:
C013CDl0?dQ:03<k?@0`>CP0;cLf03Lm?@0j@400<3Da02HY8@0Q8ad0:B/X02`];`0X:Bd0:2T_02h^
=P0c<c/0<C4h02<T:@0Z:bl0ATI>07MeP@0^;CH0<2lf02<S9P0W9bP0:BTX038b<00j>SP0<C4`02LW
:00Y:BX0;2`[020P7P0U9B<0MWId04i>C00f=S@0:BTW02XZ:00U9B<08b<Q02DU8`0Q8Al0:RTW02LW
9P0Y9bX0:bT]02TW;@0X9B`0:2D]02XY;P0Z:2d09R@X02LV:00Z:2P08R0U02HS:P0R82@07Q`O01hL
7@0/:bT202@S8@0A02<Q8P0O7B807Q`Q020N900L6Ql08AlR028P8`0L6Qd07adP038`<`0Z:2/07Q`O
01`J7@0V92L08R0S01`J7@0O6a`00P0N6Q/00`0M6AX06QHG01TE5P0201TE5P807a/L01H0B4A501dI
6P0M6AX06aLH028N7`0C3a006QHG01hJ6`0H51D06ADF01PD5@0G4a@05Q8C01DA4P0J51H0618D01LA
4`0I4aD06Q@F01TC5@0L5QP06A<E0P0D3Q002@0F41806A<E01LA4`0D3Q004`d?01LA4`0I4a<0618B
01XD500301PC400A01HA3@0D3`/071LD01HA3P0A30T05@l?01PB4P0E3`l050h@01XD600B31007QPL
00P21P0K5AT06aDG01H@4P0b;2h00P0L5QP0300E3a406A<E01LA4`0F4180618D01XD5P0K5AL06A<E
01PB500G4A<05@lA01@>40805a4C01l071HH01LA4`0F4A804Pd>01P@4`0F2`l04`X<01/@500P5AT0
<BHZ01hC5`0H3A405@X>01H;3`0G31005P/?01@9300B20T09Q`M03lf=P0Q5aP05@/<01T?400D2P/0
4PP901P>3`0L4Q<06@l@01H;300E2@/050P:00805PX<00<05@T;01451`0B1PP00P0B1PP0400C1`T0
5P/<00l51P0K4Q<04@P900L0000G3Pl050/<01L>3`0D2``040L801<:2`0=10D04@P901L<3P0F2P`3
01<72@030186200C1`T04`L900@04PH800@050P:00h2100B1PP05`/=0P0A1@L201<72@0B0186200C
1`T050P:01D92`0h;30060d@0105200B20X081@H01P<400A1@T050P<01452@0B1PX05@T=01452@0G
20/05PL:0P0D1@P00`0E1PT05PL:01D62@0301D62@8050D81P0C1`T00`0A1@L04PH80186200201<7
2@0F01@82P0B1PH03@4100h20P0D20P05@T901<71`0D20P0?S8b020D500B1`L060`<01T=3@0F20P0
5@L701430`0G2@T060`<00l30`0I3`h05`d<01@:2@8050`:00T04`/9018:1`0H40h040P601061@0?
1@H04PP901041P0D1@X00P0E1P/00`0B0`P04`@801@5200401@5200301<41`0A0PD04@8500804044
00@04@8501<41`0C10L050D80`0E1PT01`0A0`D07PlB01<41`0@0`@06@X=0102100E1PT00P0C10L0
0`0D1@P04`@701<41`0201831P0L01<41`0D1@P04`@701831P0D1`L05P/901861P0G2`/04@D501P<
3P0H3@h040@601L;3`0C1`/04@D901D9300G20/040820184100C1@D04@<302@F5P0H2PX04`D501<7
1`0C1PH0408201D820@04PH801004@D701041P0f:R`040H701051`0=0`@040H70187200F1`X050D8
01831P0D1@P05PL:01D62@0D1@P04`@70P0B0`H0100C10L050D801<41`0D1@P201D62@0301@5200C
10L04`@700D04`@75?ooool001_ooooo00d05PT@01L:4@0<00H05@P?01@73P0J3A@07A0G03<V;@0P
4aX05PT@01442`0=00L04PH:00<04`L90P0D20X601<72@0H01@82P0<00806`lA01X>400H30h040@6
01@82P0A1@L03P8401<72@0F2P`04`L901451`0K3a4060`>01T=3`0B1PP040@601P<3P0=0@<02P00
01@:2`0800008aLI1P0D20X00`0B1PP04@D701@82P0201<72@0>01D92`0D20X050P:01@82P0E2@/0
5PX<01/?4@0`92H0THF701lC5@080000;b<U00d3100B1PP301@82P030186200C1`T050P:00<050P:
00D05@T;0186200D20X0710B01lC5@0201H:300<01@82P0C1`T03P8400h3100D20X04@D700l41@0H
30`07Q8D01dA4`0=0@<040H80P0D20`301D83`0401H94@0V6B008ADI01T=4@805PX>00`050P<02dQ
9@0C1`/081@H01/?4`0P51P05PX>01<72`0D20`04`L;01T=4@0O4aL201T=4@0301P<400G2`l05@T=
00805PX>0P0D2@l01P0Q5Q`060dC01<83P0E2Q0050T?01X?5@806@hD04D07A8H01XA5P0L4aH07ALI
01`F600I4aD0618D01TC5@0M5aT06aDG024K7@0Y8bD09b4S01/E6@0O5Ad08ALN01@;3P0L5QH06QDB
02LR700N6a@07Q`F01XI5@0C4Q0081hO01XH6`0P7R406ALJ01hL7`0/:R/081hN01dL6P0O7QX07A`H
01hM600P7aX07ahI01hM6@0N7Qd092@T02h^;P0U9BD06a/M020P8P0U9BL09RDZ02XY;P0W9R/09RD[
02//<@0Q9BX09b``02`a=@0W;3006b0T02`a=@0Z;c<09b``01dR9P0X;C40<SLk03Ll@00_=cT0<CTk
03@l?P0_=cT0;cLj03@l?`0_=cX00P0b>Cl0;00c>T00=Se503DoAP11CU@0=dA:03E2B00mBU00<d16
03M4BP0e@TP0;CY005UVK00^>d40>4E;038l@`1@FF00=Ci504A>EP0oBE80@D]D04A@F@12CeP0?DUE
04EBGP0nC5T0B5IS096NZ01=FV00=D9803i;D@1;F5h0?T]A041=D`12CeD0@DiD04QEF`1=FV00BEMK
049@D`0mBd`0@4i?04YHF@19EeP0@Dm@0P13DE805018EUL0BEMH04MEEP17EEH0BUQH04iLG01=Fe/0
BUQH04eKF`1@GUl0Df5T051NH@1BH6<0FVM]05]XKP1BGfD0BeQP05]XL01FHfX0@e1F0P1DHVD03@1@
GF<0DUmU059OI`1?FfL0Dem]065]N`1IHf`0FfI/05YUJ`1II6X0F6=X05UTJ01MJ6`00P1MJ6X02@1L
J6P0FfMW05YUI`1MJ6`0GVU]05UTJ01KIVP0H6]]05aWJ@0205YVIP0905=OG`1EHEl0H6aZ06A`KP1P
K6P0GFUV05aXIP1MJFL0GFUX0080GFUY00h0HFa]05mZK01OJV`0GFQZ05=NH01KJ6h0CEYP05i[L@2;
V9h0H6ec05=PIP1EHVP0Df1V05AQI`80Df1V05d0EfEX051NGP1<FUX0CeeM04aJFP17EEH0B5IG04QF
F@15DeH0A59E04EBF017E5X0BEIL03i=E00oC580?D]>03a7B@0k@dD0>d5103Y0?P0h?Sh0>T=2045:
C010BT`0?4I803a7B`0iA4P0>4=703I0@P0e?d40=Sm1038j?00f?ch0>40o03m5A@12B4P0;S8^028T
7`0T9R40;Bh^02`]<@0Z:c00;Bdd02/[<`0^;SH0;Rle024R9`0T9BT0>3M005]II`0[:CH0;2Xc02<R
9`0`<3808b<R02`]:00d=C00:R/V02<S8@0W9bD0;Rh]03Ti>@1@D500j^[Z09bLW013@d<0:b/[020P
800W9bL092@T02h^;P0Z:RT0:bXX02LS8P0Y9BD0;2L[02TT:00W8RP09B0V02TT:P0Z9BX0:BDV02`X
9`0X92<07adR01hK8P0R82@09B<V024O800X9bD07QdK01dL6P0L6Q/00P0M6b00100N72808R0U028P
8`0O7B0201TG6P0:024O8P0D4QD05aDH03Hd=`19AdX0:2HY00`:3@0I5AH071PI01dI6P<071PI00d0
5Q8C01`H6@0I5AH06aLH02LS900H51D0;b//00d92P0U8B807ATJ01`H6@0D41405a<D00@061@E00l0
5Q8C01PB500F41805Q0B01PB500I4aD0618D020J700I4aD09AlQ02@N800G4A<071HH01dG6@0G4A<0
0P0E3a400`0C3@d04P`<01TC4`0201HA3P0K01TD4@0H4`l05Q4=014<2@0N6AH081/H02`W900X8R80
5Q0@024K6`0A2`d0618D01<=4@0m=c/03@L;01H@4P0H4Q@05Q0B01@>400C3@l07aTK01XD5P0I4aD0
618D01LA4`0I4aD06Q@F0080618D01405a4C01H@4P0E3a4040X<02DO8@0E3a4081XL01@>400T7R00
40L:01lD600A1PX09AXN02XO8`0P5AT04`P<01P=4@0201H;3`805``@02L06@lA01X@4@0>10D08ALH
02/Q8P0H3Pl05P`=01D;300D2P/05@/<01T?400K4A806Pl@01<72@0A1@L04PH801D92`0C1`T04PH8
01@82P0F2P`04`L90186200E2P/04@L801892P0=10D0<BPY01482@0?1`P01P0001D<3@0G3Pl030<4
01<:2`0@1`P06@d?01L;3@0D20X00P0C1`T00`0A1@L04PH8018620050186200501@82P0A1@L04@D7
01D92`0B1PP0100A1@L201<72@0<01D93@0;0@<06@dA01452@0Q5AT04`L;01@8300A1@T040@801H:
3P0K3a<04PH:0P0E1PT201@520805PL:00H04`@701@5200E1PT05@H901H72P0G20/801<72@804PH8
0P0A1@L04P0I3@d05@T901<71`0C1`L04PH601451@0C1`L0300000l30`0J3Ph07A4A00P0000I2`/0
5PP801430`0F20P04`L701H:2P805`d<00D05P`;01081P0>1P@040P601L?300201@<2P0401<9200E
2``03P@501451`@04`@900<04`@801<41`0C10L00`0C10L02@0B0`H04@8501<41`0F1`X060T<01H7
2P0C10L04P<601<41`0301@5200700l3100D1@P0404400l00`0A0PD02`0001421@0201<41`0G01@5
200C10L04`@701421@0B0`H04`@701D62@0C10L04P<600`10@0B1`D060`<01861P0=0@404PH801H:
300=0@<03P8600P0000:00804@D801421@0B10@00P0D1PH01P0B10@04@<301@61P0=0000300001D7
1`8060X:01405@T;01@82P0B1PP040@601451`0C1`T0<bLY01041P0H30h04@D700d10`0@10H05`P;
01D62@0C10L05@H901H72P0201@5200701<41`0B0`H04P<601<41`0D1@P04`@701@5200201D62@03
01@5200C10L04`@700D04`@75?ooool001_ooooo00D05@P?01@73P0@0`X06@`C01<63@0201L:4@07
03DX;`0M41L06@`C01@73P0H31004@D90186200201<72@0301@82P0E2@/050P:00D050P:00P06@d?
01H:300>0P@040@6020D5P0=0@<03P<401<72@804@D700T04`L90186200@1@H05PX<01@82P0A1@L0
4PH801D92`0@10H00`0E2@/00`0H30h02P0001<72@0501<72@0:01041P0>0P@04PH801<72@0@10H0
4PH801@82P0E2@/05PX<01<72@8040@600/05PX<02dQ8`0D20X07Q8D00P0000G2`d04PH801@82P0E
2@/050P:0186200201041P0F01451`0F2P`06Ph@01dA4`0H30h06Ph@02LK7@0X71h05PX<01451`0E
2@/05PX<01@82P0K3a4050P:01041P0L414050P80186200<00806`lA01H:3P8050P<0P0E20l05`0F
2A005PTA01hA600H31004PH:01<72`0F2Ph05`/?01`@500=0@D04@D900d11@0_8bL08aLK01T=4@0G
2`l05PX>02@H700]8BD06`lC01P<400G2`l05PX>00<05@T=00l06PlE01P=4`0b9bd09Q/Q024F700J
3aD04`P>01L<4P0F2a4060dC01/@5P0C2Pl04`X=01H@4P0I4aD00`0H4Q@06`0E3a405a4C01hH6P0S
7Al081XL01H@4P0F3A808QTN01H=400U7al06A<B02<N6P0G4a006aTE01hM6`0U8b@0>cTk01@B5@0V
92L06aTL03Xh>@1HEUL0=SDd00l>300M71P06QTE01/J5P0201hM600N01hM6@0S8b8092@T02XZ:P0R
8R807AdO02HV:00R8R@09B@Y02/Z;`0X9b`09B@Z02TZ;`0S9b/0:2da01/P900V:bl0:c0d02L/<00X
;C409BX^028W:`0/<CD08RL[02/`=00W;c40:S8d030h>P0a>C/0<CTl0P0d?3l07P0f?D<0=3]1034h
?P0d>d<0>D=:03Q5B`0[>3h0=dA:049?E@0e@TP0<d16034nA00kB4h0SIZP04AAE`0nBe40@TiD075j
P@0j@dX0B55I03Q2B`0oBE80Ae9K045>E`1>FVH0B5EQ04MEHP14DUl0BEMP03A1A`80@TmE0100=T=9
03a9C`1?G680A55G045>E015DUP0BEIL04=@E@16E5L0A59C04UGF018EUL0@U1A04YHF@18EUL0A59C
0P17EEH07P12D540B5IG04MEE@1:F5P0B5IF04ABDP17EED0BUQI05ITI`1BH6<0EVAW069_M@1SL7H0
EV=Y05AQJP17E5d0AE9J05ERJ01;F5h0EVAW059OI@1DHFL0DUmX04YFI01>FVP0Gf]j04mIHP1GHVP0
G6M]05UTJP80Ef9V03@0G6MY05]VJ01JIFL0FVIV05]WI`1LJ6P0F6=U05eXK01HHfL0F6=U05iYJ`1J
IFL0FfMW05m[J`1KIfL0FfMU061/JP1IIF<0Ef=O05eYIP1LJ6H0F6AR05EQH01GHf<0HFe]06=^K`1O
JV`0H6]]069]K`1KIVX0C5UO05i[L@17E5X0H6ec04eJH01IIV`0EF9X05]XKP1LJFl0DUmU04mLHP1E
HfH0DV1Q04eKF`1BH600DEmO04MEEP16E5D0BUQK04MEF015DeH0A55G0P13D5H0EP18Eed0?daB03Y5
B@0lADL0@TQ80457A`0k@Cl0>Clo03]1@@0lA4H0=d5303@n@00oBTh0>dI:03Y5B@0h@T@0=Cm103Q1
@`0j@T@0@T]:03a3@`0f?3`0=C/k02T]:`0W:BH0:2XW02PY:`0U9RX0;Rld03Hf?@0/;3@0:RXb02h_
=@0T9BX08B8V02<R;00Z:3H0<Blm03<b>`0c<SL0>c/m01dM6`0Q8Qd0:2TT02<T7`0U9R40:BTW02TY
:011@D40?3`l0:j^[P1aLG40<C4a02h^;P0M7Ad0;2`/024Q8@0T92@0820O02`X9`0U8Ah09R8Q02/V
:P0V8BD091lU02DP9P0Z9B/0:bLY02XV9`0[9bH07a/I020N8`0L6B008b4U02HT9`0O7Ah081lM01lN
700M71X07A/L024O900S8BH0924W02PV:`0T8RD081hQ0P0O7B006`0L6Qd09bDX01`J7@0N71l09B<V
020N8@0V92L07ATJ020L7@0M6AX06aLH01XF5`0H51D04`l@01lK700K5aP081`M01PD5@0]:BX0NWIg
024M7P0J5QL04`l@01/G600I5AH05A4B01LC500401TE5P0<01H@4P0D3Q0050h@01H@4P0H4Q@05a4C
01`F600O6A/0?3Hh03/e=`0K5AL05a4C0P0B30h00`0E3a406A<E01XD500201TC4`0H01TD4@0H4a00
6A@A01XE4@0K5Q806QDB01LB3`0A30T05a8?01/E5@0E3`l06Q@D00@0000T7R00:28V0:^UZ@1=Ad/0
6aDG01lI6`05004091hP00@0000O6A/06A<E0P0K5AL00`0I4aD05a4C01LA4`0201TC5@80618D00T0
5a4C01dG6@0400008adO01LA4`2BS8h081XL01H>4@0U6Qh00P0C20`01@0B1`/06@hB01dB5P0H3A40
5P/?00<05``@00T040H802HL7@0G3@h04PT:020F5`0B20T060h?01H<3@0D2P/00P0A1`P02`0D2P/0
60d>01D92`0D20X05`/=01T=3`0E2@/03P8401<72@0G2`d050P:00804@D700d04PP900L0000F3@h0
HeYK01D<3@0=1PH03`H701892P0?1PL04PT:01L>3`0?1@H050P:00804PH800<050P:01H:300G2`d0
1P0B1PP01@0?0`D05`/=01<72@0A1@L06@d?00804@D70`0@10H03P0B1PP04`L901H:3P0?1@L07Q8F
00`0100G2`l03@4501D93@0@10P03`<701P<400M4AD04PH:0P0C10L0200D1@P05@H901L82`0I2Pd0
4P<601<41`0D1@P05PL:0P0H2@`601<72@0K01@82P0C1`T04PH80186200A1@L040@601861P0F2PX0
5@T901451@0B1PH05@T901871`0Y7Ad03@4101P<3008000060`<01D71`0G2@T050H601D71`0B1PH0
7A4A01@:2@0I3`h06Q0?00805Ph<00d06Q8@01L?300<108050`:00d40`0?1@H03P@501<72@0B0`P0
4@870183200D1@X050D900D04P<600T05`P;01H72P0A0PD04P<601@5200B0`H03`430101100A0PD0
0`0C10L01`0F1`X0404401831P0F2@X03@0101421@0E1PT00P0C10L05`0D1@P04`@701<41`0C10L0
5@H901L82`0I2Pd05`P;01D62@0D1`L05``:00P0000F2PX03`<302DI6`0]8B<05@T;01452@0E2@d0
50P<01041`0B0`H050H600804@<301`050H601430`0@0P804`D501L92@0D1PH03`410184100C1`T0
4PH800l31@0=0@<03P8401451`0D20X0200001@82P0?0`D05@T;01X>400E1PT050D801D62@0F1`X0
50D801421@0D1@P04`@70P0B0`H0100C10L050D801<41`0D1@P201D62@0301@5200C10L04`@700D0
4`@75?ooool001_ooooo00H04`H=01H9400@0`X040<:01H9400C1Pd201D83`0F01X=500I31<050L>
01P<400A1@P050P:01<72@0A1@L04PH801@82P0@1PL04`L901X>400E2@/02@00028F600D2@X05@T;
00l51P0I3@l03P8401D92`8050P:0P0C1`T20186200501L;3@0D20X04@D701P<3P0I3@l00P0A1@L0
2P0G2`d05PX<0186200E2@/06@d?01<72@0B1PP050P:01D92`0D20X201D92`804`L90P0B1PP00`0C
1`T050P:01@82P0201<72@030186200C1`T04`L900@04`L900P05PX<01061`0M4A<05PX<01P<3P0C
20T04PH800d3108060`>00T03`<501P<3P0F2P`05PX<01L;3@0F2P`04`L901D92`0F2P`01@0D20X0
4P0D20T060`<01P<3P0@10H03`@501P<400E2@d05`/?01D83`0D1`h06PdD01H94@0G2Q405@T=01@8
300F2Ph05`/?01@830805`/?00<05PX>01D93@0F2Ph00P0G2`l0100H31005@T=01L;3`0N4QH201P<
40805`/?0`0F2Ph201X?5@0?01T>500H3A<05``B01L<4P0J3aD06@hD01/@5P0J3aD060dC01`C600H
3a805Q0B01D?4@0F41806A<E00L06aDG01X08QTM01hE6@0O5QP06A<C01/E5@0K5A@07QXI01`J6@0O
7Ah0928T028P900I5aX08R0R02h/;@0k>CX08R4P024P7P0N7A/081lM02<R7P0U92007QdI01XI5@0P
7a`08B4Q02<S8`807alO01808R8T020P8P0T92H09B@Y02@S:00R8BH092<Y02DV:`0T:B`08BHY02DZ
;@0X;C008RLZ02`a=00V:bh09BX]02H[;P0/<C@202ld=`0g02de=`0^=SP0;cLi03@l?`0]=CP08b/^
030g?@0c>T80=3]3038i@@0f?DD0?4E=03U6CP0hADd0?4UA03Y7C`0iATh0?daD04EBFP0a?TH0?DYB
03M4C01nRi<0?d]C049<E@11Be@0>dE>03m9DP10CEH0@e1I03m<E@0nC5D0@U1J03m=F00kC5H0>dYB
03e:D014DEL0D5eS03M4BP12CeD0@DiD049?E@14DEL0AU=I04AAE`14DUH0B5II03e;C015De@0?4Y;
04ECE017EEH0@e5B04ECE00204ABD`0<04UGF01;FEX0AE=C04ABDP19EeL0AUAD04YHF01AGf00E69U
05MUJ01BH6<0CU]Q0P1BGfD0901CH6P0DUmW04mLI01=FV00CUaP05=QI01CH6H0DUmU04iKH`1EHFh0
HVil06YfQ01BFf@0EEiT05MPI@1JHfP0GVM[05eWJ@1QJfd0GFMX061ZJ`1SKFh0GFMX07f7R01cOX00
FVEW05AOH@1II6H0FFEV05YVIP1PK6`0G6QV05YVI01LJ6H0GFUV05]WH`80G6QV00D0FFES05aXJ01O
Jf/0Ef=S05mZK00205iYJ`0:05mZKP1MJ6`0FVEY04mLHP1QKW@0EV=Y05ERJ01DHFL0FVM]05ERJ0@0
Df1V00X0Df5T055OH01;FET0BeUI04iLG01:F5T0AE=D04UGFP13DE@0A59E0P13D5H03P16DeT0@E1E
03m;D00f@D@0@T]<04U?CP0k@Cl0?D5002lc<P0f>cX0FF5P03a5A`0kADL0>dI:0P0jADT01P0kADL0
=T1203<l?P0f?T00>D9103@l>`80:c4a03H0:Rh]02PZ:@0Y:b/0:BX^02d^<`0`<3P0<30i02l_>@0f
=Sh0:BX`030a=P0J6al0;B`e02d[>@0`;S/0=SDn03Lf>`0b<S@09RHU024R7@0U9R40:BXU02TY9P0/
;2X0<30_02TY:@0[:b/0>CTi03Ph>00`<300;bl_02/[:`0R8R809bLW02<S8`0S8b807Q/J028N700P
71`08ahR024L800P6b408ahT028M8`0T82<09b<T02DQ800N6QT08b4V02@Q:00R82@08b4T02HT9@0Q
81h201hM6`0801lM7P0P7R<08AlT02@Q9`0K6Ah09R@W01/I700T8RD201`J7@0=01hL7`0V92L07Q`O
01lM800K6A`071XM024M7P0K5aP07QXK01`H6@0M6AX0<Bd^02dY:P0201`H6@0C01hJ6`0J5QL071PI
02PT9@0O6a`061@E01`H6@0E4A80920Q01DA4P0S7b005a<D02<O800G4a@06aLH01H@4P0[9BL05a4C
028L7P0401H@4P0601PB500J51H06A<E01H@4P0I4aD050h@0P0E3a400`0G4A4071HF01PB4P0301PC
408061<?01L05Q4=01LB3P0H4`l05a8?01D@3@0D3``0618B01`F5P0A2`/091hP081jO00/9RP071HH
01@>400J51H05a4C04@n@00`:R`0=S0b04a6B00L5QP07QPJ014;3@0201LA4`0401D?4@0K5AL07ALI
01TC5@805a4C00`0618D01TC5@0L5QP07ALI01/B5@0I3Q806a0D01T>4P0F2`l05``@01X?4`0K41@2
01X?4`0901L<400F2`l05@/>01T@4@0K4Q<05Pd>01482@0H3a004@T9008050/<0P0C2P/0100B2@X0
50T;01D92`0F2P`201L;3@0501P<3P0F2P`05PX<01H:300E2@/00P0D20X0100>10D04PP901<92P0@
1PL201<92P0601@:2`0=0`@0>2h_05I<C@0E2``04@L80`0D20X201451`0J01D92`0D20X04`L901<7
2@0B1PP04`L901@82P0B1PP05@T;00l41@0D20X0@CDg02TM7`0E2@/04PH801@82P0C1`T040@601@8
2P0C20/04PL:01@8300E2@d04@D90105200B1PX301452@0401<72`0D20`05PL:01D62@804`@701/0
5@H901H72P0?0@<060T<01D62@0o<3<091DH01<41`0B1PP040@601H:300G2`d04`L901H:300?0`D0
4`L901D:2`0@1@L040H701H:300E2@T09QXJ028F5P0C1`L050P800d10@0E2@T00`0D20P0200C1`L0
4PH601L92@0I2`/05PP801L92@0H30`05PX:0P0B20L03@0C2PX05@d;01<;2@0B2PP04`/801D=2`0F
3P`05P`;01882@0A1`P04@D701@52P0C10T00P0D1@X00`0C10P04`@701<41`0301<41`0601@6200W
61/07PlB01841P0F1`X03P02100C10L301831P<04@8500<04P<601<41`0C10L00P0D1@P05P0B0`H0
5PL:01L82`0F1`X02P0001h?4P0Y6Qd06P/>01@6200@10@03`@201451@0?0`<03@4101P<3P0O4aD0
3`<501`A501oLgL081@H00l41P0B0`H201430`030184100C1@D050H600H04`D500H02`4201P<3P0B
1PP02`4201L;3@0>10D2018620@04@D700`04`@701831P0B0`H04@8501831P0C10L06@/=02@E600I
2Pd04`@701L82`0C10L201@520<04`@700L04P<601H82P0V61X02`0001T:3@0F20X05PL:01Cooooo
000Kooooo`0N01<72`0E2@d04@D901452@0E2@d04`L;0104200?0`L04@D90104200A1@T060`@0145
1`0D20X05@T;01<72@0A1@L040@601X>400F2P`040@60147200O4aD0BSi003T];@0F2PX07a<C01D9
2@0@10@06Ph>1P0B1PH02P0D20X040@60186200L418060`>00h2100B1PP04@D70186200E2@/201H:
30@050P:00<05@T;01@82P0D20X00`0C1`T0200B1PP04PH701451@0B1PH04`L701@8200E2@T050P8
1@0C1`L04P0>10@0<BDW0:JJW01XG5h0200001dA4`0O4aD06@d?01X>400B1PP040@601D92`0C1`T0
50P:01<72@0E2@/05PX<01D92`H050P:00d050P901861P0A1@L04`L901D92`0G2`l04PH:01D93@0F
2A006@`C01`?5P0I31@05PT@00805@T=00<05PX>01L;3`0E2@d00P0D20`02P0F2Ph05`/?01L;3`0G
2`l05@T=01T=4@0G2`l04@D901@8300H310301H:3P<05`/?00P05@X@01H;4@0G31806@hD01X?5@0K
41H050T?01H;4@806a0F00<060dC01/B5`0H3a800P0C3@l00`0H4Q@06Q@F01PB500201`F600_01dG
6@0N61X07aTK01lI6`0J4A807A@E01P@3P0O6QL07QTG014;2`0M6AP081dM01lM7P0L6Qd06aTL01`J
7@0>30d09bHT02<R800W9R@06QTG02PW9@0R8Al0FeYH02DT8P0V9B<07A`J028Q7`0T92@09BDU020P
800N7Qh0820R01hN800Q8B<081lT024P9@0U92T09RD[02DV:`0R9bP0;38b01/Q8@0N92@08BLW02`b
<P0_=CD00P0[<C404P0^=3@0;cDe02hc=P0_=cT0:C4d02H^<@0^=ST0>3m503LnA00c>T80>D1803Po
B00g?TP0?4==03a5C`0iATl0>4E>03I3C080@DiG00L0>dQA02`i@P0lBE80<3e603M4C@0jAe00=T5;
0080>dE?00H0=T9;03Y7D00nBe@0A55J045?F00kBE8203Q9D@0?03]<E00lBe<0?DY@03Q5B`13D5H0
>4E;04ICF@17E5X0@TmE03m<DP11CU@0AE9H04ABEP1XMWT0@4i?0080B5IG00H0>TQ903m=CP17EEH0
BEMH04IDE@13DE8204MEEP0/04]IF@19EeL0AeEE055OG`1>G5`0FfUZ04mMH01AGf80CeeP04eJH01A
GV@0Df1V05ISJ`1DHFT0DEiU04iKH@1=Feh0CUaN04aJG@1@GF<0E65X05QUKP1JIW80D5aY055JH`1C
G640EUmT05YTIP1OJF/0HVa^05EOH01LIVL0FF=T06=]K01OJFP0EV1Q05mZK01JIFL0DeiP05EQH@1H
I6@0DEeM05m[J@1IIF<205EQG@1c05IRGP1EHEd0F6AR061/K01LJ6P0F6AT05YVI`1LIfT0FFAV05QS
IP1HHfL0FFAX05QSJ01EH6H0BEIL059OI@1GI6X0E65W04EBF01;F5h0Df1V059OI@1AGV@0D5eS055N
I01AGf80CUaL04aJFP1?GEd0D5iN04UGF014DU<0@4iA04=AE01;FE`0C5UO049?E@0nBe40>DI<04A?
D`17DU@0@DU:03i4@P10A4<0>S`i02X^;@0]<C00=Shm03i6B011Bd`0?4M;04QCE`16DED0>TA603@n
@00g@480=Si003@m?00_=cH0:Bl_02D[:`0/;c00;Rla02d^<P0^;c@0:BTa02l_>@15ADl0ATI@03<c
>`0W9bh09BHZ03@e>@0Z:S80;2Xg02l]>00c<ST0<S4f02d];`0T92<0:BTW02d]:`0S8b4092@T02TY
:@0Z:R/0:2PZ02LW:@0/;2h0:RX/02PX:P0S8bD07QhP028R900M7Al061PJ01hN7`0T8b402`X801XH
6P0N71l09R@Y02DR:@0N6b808AlT02DS9`0T8RD08b4R028P800M6b007Q/R01`J7P0M6ah08R0Q024P
7P0201hM6`0N01hL7@0O7B8081hS028O9@0G5AX081hQ03/i?01EDeH0;B/^01XH6`0W9BP0928U024O
8P0Z:2/07A/N020N8@0O6a`061@E01/G600L61T06aLH02<O800Y9BH07QXK01lK700L61T05A4B01XF
5`0D41406ADF0P0J5QL06`0D4140:RHW02HR8`2c[k00:bLX010<3@0O6a`061@E01PB500/9RP03`T;
01H@4P0H4Q@040X<01PB500F41805@lA01LA4`0I4aD0618D01D?4@0F41806aDG01TC5@0C3@d05@l?
01H@400201D@3@0P01@?300C3PX04`h:01LB300G4Ph061<?01LB3P0E40d050l<00l:1`070@405Q0@
01TC4`0=1`T04`d?018<3P0C3@l071HH01LA4`0/9RP0<bd_020J700A2`d04P`>01lI6`0C3@l05a4C
01XD5P0F41806Q@F01dG6@0K5AL201XD5P0G01PB500G4A<05Q0B01H@4P0H3a8060dA01L<400I3Q80
60dA01H;3`0C20`05P/?01X?4`0H3A4050T=01D:3P0G3@l01P0001<:2`0K4Q<04PT:01dD5@0E30d0
0`0D2``201<:2`0701D;300H30h05`/=01H:300D20X04`L901H:300201D92`<050P:01804PP901D;
300C2@X04@L801@:2`0C2@X01`0001`B4`1`IVL0[ZBU01`B4`0?1PH04@D701<72@0E2@/04`L90186
200C1`T2018620<04@D700l04PH801L;3@0=0@<060`>00X0000;00409ATK01X>400D20X04`L90186
200@10H05@T;00P0000A1@T00P0800000`0I3A407Q8F01862P0301452@0301<72`0D20`050D800@0
5@H900T050D801H72P0H2@`04@8501T:3@0C10L05PL:01<72@0B1PP00P0F2P`03@0C1`T050P:00l3
1@0L41803P8401P<3P0N4Q@03P8400h30`0@10@060`<01D92@0H30`00P0C1`L04P0G2`/05PX:0186
1P0A1@D04`L700l20P0D1PH04@<301T;2`0I3@d04@D501H<2`0a9bH0KfET01TA3`0G3`d06A4?01@<
2@804`/900X04`T80147200@1PL040@601@52P0F1``05@H;0183200D1@T05PL:0P0E1PT02@0D1@P0
4`@701D62@0Q4QD06P/>00l10`0D1@P04P<601D62@0301@520H04`@700<050D801D62@0D1@P00P0E
1PT00`0B0`H050D801<41`0301<41`0501@5200;00004P<601T<300B1`D00P0E2@T0300@10@03`<5
00P0000J3Q00K61T08MkO`0H31008ADH01D62@0E1`L050H6018410P04`D500H05`/=0186200:0040
7A4C01lC5@0L418201<72@040186200A1@L04@D701041P804`@70P0B0`H201<41`0601@5200K30l0
4P<600d00@0?00<030000P0C10L201831P804@8500H060T<01@5200I2Pd070d@03<T9`0O41<Doooo
o`006oooool201@830804`L;0P0D20`0600B1PX050P<01@8300C1`/050P<01P<400B1PP05PX<01L;
3@0D20X040@600l31@0K3a404`L901D92`0C1`T0200001H:300=0@40200001/?3`0E2@T05PX:00l3
0`<04@D50`0B1PH0200>0P@040@601@82P0J3Q005PX<01041P0H30h05@T;0P0B1PP0100F2P`06@d?
01<72@0D20X201451`050186200A1@L04`L901<72@0D20X00P0C1`T0100B1PL04PH601861P0C1`L3
01@820D04`L701<04`L800P00018?3h0=RX/01<72@0H30h03@<401@82P0E2@/04PH801T=3`0L4180
5`/=01@82P0A1@L05@T;01L;3@0E2@/04`L900D050P:00<05PX;01L;2`0D20X00P0B1PP0200A1@T0
4`L;01862P0C1Pd05@P?01L:4@0F2A405@P?0P0E2@d01P0F2Ph05`/?01L;3`0B1PX04`L;01H:3P<0
60`@00H050P<01L;3`0I3A405PX>01L;3`0H310201D93@1K01H:3P0G2`l060`@01P<400E2Q005P/A
01L<4P0I3Q@06PlE01/@5P0H3A<06PlE020E6`0O51X06a0F01`C600H3a804P`>01@>400I4aD06aDG
01LA4`0H4Q@06A<E01XD5P0K5AL07ALI01dG5`0K4a407QHC01<;2@0M61D08A/J018<300M6AP07Q/K
01`J6`0J61/06aTL01hL7@0S8R006QTG014@3P0L6aT081lM024P7P0M71X0>CPf01@C4@0R8Al07A`J
01TH5P0T92@09BDU024Q8@0O7al08B4S020P8P0R8R@07QdR01lN8`0U92T09B@Z028S9`0O92D0:2h^
02dc<`0^=3@0=C/k05EKF`0b>3P0;S@d02dc<`0_=CD0<3Hf02le=@0`>3/0?4A703U1A00b>Sd0<3Lm
02lf?00f?DD0?DA<03PoB00g?TP0>T5;03M1BP0mBU<0?daE03I3C00203i;E00`03I3C00]>T<0?4UB
03M4C@0nBe@0<3e603]7D00lAU00?DMA03U5CP0mBU<0@DiG04=AFP10CUL0?DiF041AF@0lCED0>4UA
03I6C010CE<0>DI<04AAE`0mBU00A55G04QEF`15DUP0?T]A03m<DP12CeD0?daA041>D@14DU<0@U1A
03a:B`1=Fe`0B5IG04ECE017EEH0AE=D04=ADP17EEH0B5IG04IDE01;FET0?Ta<04eKF`1EHf<0DV1Q
0`1?GF00;`1?G680DUmU05ERJ01BGfD0D5eS04iKH01=Feh0CE]L04aJF`18EUL0CE]N051MHP1@GFD0
E65Z05EPJ`1BFf80E5eR05YSJ01LIVP0GVQZ06=]K`1GHF80IFm`05eWJ01NJ6L0FVAS05iXI`1JIVH0
GVU[05IQH`1FHV80G6QX05EQH@1IIF<0EV9O05=OF`1DH5`0Ef=O05UUH@1IIF<0IG5a061/K01HI6@0
FfMX069]K`1LIfT0FfIY0080FVEY06X0F6=X05AOI@1IIV`0D5eS04eJH01DHFL0Hg1f082=T`1GI6X0
Df1V051MH`1=FV00BeQN04YHF`1=Fe/0C5YJ04eKF`1>G5`0BEMH04IDE@10CU40AeEH059PH`1BGfD0
@TmE03]8CP0nBe00?dY>04E?D@11B4T0?T9104Q<B`0d=S<0;c<b03Xn?@0f?3`0@TY<03e7B00kADP0
AE1D04=>DP0h@T@0<cdo03U2A00g?d40<S/j030g=`0]<c<0:Bl_03Xn?`0e=SP09BHZ02l`=P0b<SX0
<S8l04E5C`11@D/0:BTa038c>00I6Qh0=SLi02@T:P0]:cH0;bhf034`=P0_;c40:b/[02/[:P0l?3X0
?Shl02LW9`0U9BL0:RX/02LW:@0U9BL092@V02HV:00W9bT0:BT[02HV:00M7Al0:RX/02PX:P0U9BL0
7AdO01@D500Q8B409bHZ030^<`0R8BL0928X01`I8P0P7bD09R@Z02HT:@0T92H0:2HW024O900S82L0
81hR01lM800S8B808b8P01lN700N7A/07Q`M0P0N72407P0P7B<07Q`Q01lM800X9RT0?S`o024O8P0O
7B007Q`O01/I700R82<0=38e020N8@0O7B007a/L01LC500K5aP07ATJ01XF5`0K5aP0;RX[01hJ6`0J
5QL06ADF01HB4`0N6Q/05a<D01DA4P0M6AX09b<T01XF5`8071PI00l0J6AU01LC500F4Q<05Q8C00h:
2`0:10H04@/=01LA4`0Q6ad050h@01XD5P0I4aD05Q0B01@>400F41800P0I4aD02P0G4A<04`d?01D?
4@0D3Q004`d=01LA4@0I4a<061<@01LB3`0F4@h201@?2`0=01PC3@0H4`l05a8>01LB3P0F4@h05A0=
01XE4P0F4100618B01dG5`0:10H07QPJ020J700201<=3`0<014;3@0U7b40@C/m02TS9@0@2P`06Q@F
01dG6@0E3a4050h@01TC5@0E3a405a4C0`0I4aD00`0J51H06A<E01PB500201PB500601P?4P0D2@d0
4`P<01P=4@0L4AD06PlC0P0G3100300H3A405P/?01<8300C20`06Q0B02PO800F3@h04`X;00H0000K
4Q<05Pd>01D<3@8050/<0P0C2P/00`0D2P/05@T;01D92`0201D92`0401H:300E2@/05@T;01D92`80
50P:01404`L901D;300G3@h05@/<01<92P0F30d04`T:00d3100H3Pl0:1hO02/Q8P0I3a0040H70104
1P0C1`T05PX<01@82P03018620804@D700<040@601451`0B1PP00P0?0`D02`0G2`d03`<501T=3`0J
3Q007A4C01D92`0C1`T04PH801041P0E2@/04`L;00806@dA00@060`@01862P0800004PH:0`0A1@T0
100C1`/050P<01<41`0E1PT201H72P0801D62@0C10L06P/>01T:3@0G20/04@8501D62@0I2Pd201@8
2P0<01D92`0D20X04`L901<72@0B1PP06@d?00P0000K3a40=2PZ02LK7@0F2PX02P000P0D20P0600G
2`/05@T901<71`0G2`/05@T901451@0E2@T06`l?01`>3P0?0@4050H601X<300A1@D03@4100h40`0c
:BP0L6IU01H>300A2@L05@d;01H>2`0C2`T04@T701471P804@L800H05PX<01421`0A0PL04@8701@5
2P0G20`201H72P0:01D62@0C10L04`@700l2100B0`H04@8500d00@0C10L05@H901H72P805@H90P0D
1@P501<41`0401@5200E1PT04P<601831P804`@701D05PL:01D62@0@0P@02P0001T:3@0H2@`02P00
01L82`0@1@D04@H401<71`0E2@T040@400h2100F2P`03002024E6@0`92P06PhB00`2100@0@@00P0@
0P800`0A0`<04`D501D71`0601<51@0701<72@0@10H05@T;01H:300U6A/03P@501@82P0201<72@80
4@D700<040@601@5200C10L00P0B0`H01P0C10L050D800`0000D1@P04P<601421@805PL:0P0E1PT3
01@5200701<41`0J2`h04`@701421@0C10L0814D00d00@0Dooooo`006oooool01`0E2@d050P<01H:
3P0F2Ph050P<01D93@0C1`/00P0I3A405@0F2Ph050P<01452@0C1`T05PX<01L;3@0D20X04PH80145
1`0C1`T04PH801T=3`0Q5AL0:1`N04/o@@1=@D403P8201061P0A1@D04`L701@8200401<71`804PH6
01405@T;01dA4`0O4aD05@T;01041P0D20X05PX<024E5`0P51H05@T;0186200D20X06@d?01dA4`0F
2P`04`L901D92`020186200801<72@0E2@/05@T;01<72@0D20T05@T901@8200C1`L201861PH04`L7
01<060`=01461`0F2P`04PL801X>400C2@X050T:01P<3P0F2P`05@T;01<72@0A1@L05@X;01<72@0B
1PP050P:01H:300D20X04`L900D050P:01D05`/<01`@400M4A<05@T;0186200F2Ph06@dA01D93@0C
1Pd05@P?01@73P0F2A4050L>01D93@0G2`l05PX>01L;3`0I3A404`L;01@8300F2Ph0100H31001@0F
2Ph06@dA01/?4`0G2`l04PH:00<05`/?0P0H3100100I3A406@hD01T>500I3Q@201P=4`0:01L<4P0L
4AL07A8H024F700N4aT06@hD01XA5P0J4A@05a4C01PB50806Q@F0P0H4Q@06`0I4aD06Q@F01/E5`0L
5QP07ALG024I5@0O614071D@01TD400Q71P071LD01hJ6@0J5aL06QPI01dK700P7Ql07adM01dL6@0Z
:BD0?chj01dL600Q81d06aXH01`K6@0D4a40:2LU02@S8@0202<Q8P07028R8P0U9BD08B4Q028R8P0U
9BL092@V02PX:P0202@S:00:02LV:`0V9B/08b@X03Pm?`0g?Cd0;S@d028X:00S:BT0;S@d02/a<@80
:2h^00`0;38b02hd=00^=3@0FV9U03Y2A@0Z<SD0<3Lm03Dl@P0_=S`0<SU103PoB@0g?TP203i5C`0g
03U2C015DU/0BUMP03a9DP0iATl0>4E>030mAP0hADh0:cQ103a9DP0iATl0>4E>03]8D@0mBU<0?daE
03e:D`11CUL0@e5J04ECG012D5T0?e1G04=DF`0oD5L0>TeC03e=D`1BGfD0@TmE045>E00nBe40A55G
04UFG015DUP0@DiD04AAE`17E5X0@e5E04aJG@1AGf00@Dm@04aJF`0jB4T0F6IW04QFE`1:F5T0AUAE
04=ADP15De@0AUAE04YHF016E5@0CUaL04UGE`13DE40CE]L04iLG`0204aJG@80CU]Q00l0DUmU04]I
G@1:F5X0BUQJ04iLG@1?GE`0C5YI051NGP1;FEX0B5II05MTJ`1RKgL0FVI_05MPI`1IHFD00P1QJF`0
2P1PJ6X0JG5c06Q`LP1TK6d0H6UX06E^K@1LIF@0H6YY05QSH`1IIFD2055MG@0b05QTH`1FHV00DemM
05EQGP1FHUh0F6AP05aYH`1QKFT0Ef=Q069^KP1MJFT0Ef9T05eXJP1SKW00GfY^05aWJ`1II6P0F6=Y
05EPIP1@Ff40BeQN055NI01EHVP0DEiT05]XKP1kR8h0Df1V051MH`1>Ff40C5UO04YGG@1:F5/0CUaM
04]IF@19EeL0B5IF04QFE`17EEH0B5II049@D`13DE@0@TmE045>E014DEL0?4U=03Y4A`0kADL0ADa<
03m3@P1>Ddl203Pj=`0703e1?@0f>cX0?DE403Dn@00i@dH0=T5503@o@`0203@n@00l03M0@P0d?3h0
;SLf02he=@0_=CD0;38b030c=@0Y:Rh09RL/030a>00/;3H0:RXf02h^>@16AU00;2`d069SJ00e=SX0
:2T[02h^<P0`;cD0<c8h03<b=P0_;c00;Bd/02TY9`0_;bd0<C4a024Q8`0T8bP0;2/`02d/<@0];Bl0
:BT[02HV:00Z:R`0:b/]02TY:`0J6Q`08b<U01`L7P0U9BL092@V04a=C`0Z:bd09BHY04=3BP1HF600
92@]024P:P0S8b`092@/024Q9P0N7b80820S02<R9`0W92/09B<W020N8@0R824081lM0P0O7Q`0700N
71d07A/P01dK800M6b406QPM02HT9`0K6A`0928U01hL7`0P7R407A/N01PF6@0F51L0928U01LE600L
6Qd07a/L01XF5`0K5aP07QXK01`H6@0H51D08AdN01LC500L61T07QXK01PD5@0I5AH301PD5@0>01/G
600H51D0;BTZ04M3A00O6a`05a<D01TE5P0X92D081`M01TC5@0L5QP06aDG01dG6@0L5QP201TC5@03
01H@4P0E3a405a4C00806A<E00X0618D01TC5@0N61X06aDG01@>3P0E3`l06A<C01PC400G4Pl05Q4>
0P0E40`00`0J5@l061<=01LB300301LB3P0;01D@3@0C3P/07QTF01<=3@0E3`l07ALG04@n@00J51H0
50h@01`F600D3Q000P0J51H201PB500601H@4P0P6Q`071HH01/E5`0I4aD06Q@F0P0I4aD201/E5`0F
01XD5P0H4Q@05a4C01H@4P0I41<06@hB01P=4@0J3a<06a0D01T>4P0J3a<06@hB01H;3`0L4AD08AHJ
01dB5P0]8bD0_;Jf04e7A`0D3Ph07ALG00`61P@04`d=0P0B30`0100E2``05PX<01H:300E2@/201@8
2P805@T;0P0D20X201<72@0B01D92`0F2P`04PH801<72@0G2`d04PH801H:300;0@806Pl@01hC500Q
5AL03`@501451`0C1`T05@T;01@82P0B1PP04`L90P0B1PP301451`0D0186200D20X040@601@82P0A
1@L05@T;01051P0L41805@T;01<72@0B1PP040@601D92`0E2@d03`D701D93@0@10P07Q<F04i2AP0B
1PX301452@0401<72`0D20`05@H901H72P805`P;00X05PL:01D62@0H2@`050D801X;3P0D1@P060T<
01431@0E2@/05PX<0P0C1`T03P0F2P`05@T;01L;3@0@10H06`lA00d3100K3a40?c<e02DI6@0C1`L0
50P801451@0D20P04@D50P0E2@T201451@0J01`@400S5aL0?Bl_00d0000C1@D05PP800l30`0K3`l0
5@/:01061@0J40l05@d;01L?3@0@20H06A4>01H>300E3@/05@/:01H<3@0G3@h050P:01@52P0H2@h0
50D:01421`0E1PX301@520804`@700L05@H901H72P0K30l060T<01<41`0D1@P04P<600805@H90P0D
1@P201<41`<04P<600<04`@701@5200C10L00P0D1@P05P0C10L05PL:01L82`0G20/05PL:00d10P0S
5AL04@@601/>400B1PH03`@201451@0C1`L040@401451`0C2@X04PP9024E6@0D20`05`d?01H:3@0E
1PT201@61P804`D500<050H601<51@0C1@D0100C1@D01P0?10D03`D601H;3@0X7Ah0OG5c01P>3`@0
4`L90P0B1PP201@520804`@70P0D1@P01P0C10L05@H901<41`0B0`H050D801<41`8050D80`0C10L2
01831P0501X;3P0<00405PL:01@6200H2P`05?ooool001_ooooo00d05@T=01<72`0H310060`@01<7
2`0E2@d040@801L;3`0C1`/04@D901<72`0?0`L04`L900805@T;0P0C1`T09`0E2@/02`0101L;3@0P
51H050P:00T0000W6ad08QPH02LL6P0900007A8@01L<2P0=0P005``:01H;2@0E2PP050T701871@0A
1@D040@601T=3`0M4A<05PX<01D92`0L41804PH801451`0?0`D04@D701lC5@0X71h0;20R02lS9@0Q
5AL05`/=01D92`0?0`D04@D701<72@0201D92`0301<72@0C1`P04`P600X04`P601804PH701@82P0I
3@l040@601D92`0>0P@06@d?01451`0;00405`/=01dA4`0/8280;b<U01<72@0D20X04`L90186200C
1`T601@82P0301<7200B1PH04`L900804`L900X04`L;01D93@0A1@T05@P?01X=500F2A0050L?01<6
3@0E2@d060`@0P0F2Ph00`0J3Q805PX>01H:3P0201D93@0901H:3P0G2`l06@dA01L;3`0J3Q806`lC
01L;3`0K3a<06@dA00@060`@00D05`/?01T>500I3Q@06@hD01P=4`0201L<4P0701/@5P0J3aD06a0F
01T>500E2Q006A0E01XA500201hH6P0401TC5@0G4A<06Q@F01/E5`@071HH00h071HF01TB300M5Pd0
=c0X01TD3P0I514071LD01dI600N71X07QdK01dL6P0N7A/081lM02h]:@807A`H00/05aHB02<R7`0M
71X08B0N020O7@0S8R007adN01PF5`0R824092@T02LW9`02028R8P0302DU9`0T92H08b<U00808b8W
00X08R4V02<R:00T9BT0:Rl`02dc<`0N92@0:Bl_030f=P0]<c<0;S@d0P0[<C404P0_=CD0<CLg034g
=`0k@dH0=ci403Dl@P0i@4H0=3]302Xa>@0b>D40=3]503Y1B`1:DE/0AdiH03Q1B`0d@DX0=D9;03Q5
CP80>dQA04@0=dA=03a9DP0^>d@0?DYC041=EP0hADh0=D5<03m;E`11CET0?daF04=@F@14DU/0AEAM
041AF@0lCE@0?U1G03a?E@0mD5H0B5QN06]hOP1DHFL0@e1F03a9C`0mBU00@4eC03e:D011CU@0AE9H
04AAE`11Ce<0Gfe`0;2n_`1EHf@0>TQ904=ADP0nC4d0CE]L04mMGP1:F5T0AUAE04QFE`17EEH0CUaL
04=AD@1=Fe/0@4i>05YXJ01GIFH0E69U04mMH01>G5l0CeaR04]HGP1?G680EfEX05ARH`1BH640Df5Q
051OG016EE40?di;04QFEP1<FU`0AU=I04YGG@1FHVT0GVM/05UQI080GVIY00T0I6a_07^3Q@2OYjT0
SiRH06]dL`1YLVl0I6eZ05USHP1NJ6T00P1FHV804@1GHf<0EV9Q05MSH@1MJFD0H6aX05eYI@1HIEh0
Df1I05=OF`1HI680FFEU05EQH@1HHfD0H6]^05iYK@1JIFT0F6=X0080Ef9X00/0E5mU051KH@1EHVP0
D5eS04=@EP1DHFL0P8fC0:Vf_01>Ff40C5UO04]HGP0204YGG@1I04]IG01<FU/0BeUI04UGE`15De<0
@U1A045?D00lBTd0@U1C04IDE`0nBe40>DI<03e:D01HHfL0GVQZ04A>C`0nA4@0;30_03m1?P11@ch0
@dE203Tk>00j?cd0?TA404I>D00jADP0=3m3034l@00b?3h0<cdo03@m?`0a>C/0;3Dd02T`<00Z<300
:c4a02HZ;00Y:Rl0<S8j038b>`0Y:C<0:2Pd02h^>P0P82X07AdU038c>00N7b<0<C8d020P900Y:2d0
;2/`02/[;@0W9bL09bLU02XZ:00^;R`0;bl_02d]<00c<SP0?3]303/j@00b<CH0;Rdb02/Z;`0`;c@0
;2/`02<R9`0Y:2d0@d97024P9@0];340EUEJ0=SIg@14B4/04aHK03Dh?`12ADh061XV02T[=`0W:S<0
9BP`02<V:`0Q9BP07b4U01hM8`0U8RT0:2HZ028P8`0R82400`0O7Q`0200M6a`06aTN01/I7P0K6Al0
5Q@I02DS9P0F51L07A/N0P0J61/01P0O7B008R0S01TG6P0L6Qd06ALJ01hL7`8071PI0P0K5aP02P0L
61T06ADF01`H6@0L61T081`M01XF5`0C3a007a/L01HB4`0K5aP201TE5P0>01lK7015@D80Z:BU01TE
5P0N6Q/07ATJ01HB4`0L61T05Q0B01LA4`0A2`d040X<01hH6P0D3Q0201H@4P0801LA4`0I4aD06A<E
01H@4P0G4A<06aDG024K7@0M5aT201<=3@0401D?3`0D3``050l<01@?308050l;00@06QD?01PC3@0G
4P`05a8<0P0H4`l04@0P6aP050l<028M6P0D3Ph04P`<01@>3P0I4aD05@lA018<3P0?2@/0618D01`F
600I4aD07QPJ01LA4`0I4aD07QPJ00806aDG0P0M5aT01P0J51H06A<E01XD5P0J51H06A<E01PB5080
5a4C00H06a8E01lD600O51P0714E01P=4@0G310201D:3P0901T>4P0U6Qh09Q/O01hC5`0H3a409b4Q
018<300H4Q8071HF00804`d=00<050h>01<=3@0C3@d00P0B30`0100D2``05@T;01D92`0D20X201<7
2@<050P:0P0C1`T0300B1PP060`>01L;3@0D20X060`>01`@4P0G2`d04`L901L;3@0:00403P8400`0
0P804`L90P0D20X00`0B1PP04@D701@82P0201<72@<04PH800<04`L901D92`0:00000P0F2P`0100>
0P@07Q8D01H:300B1PP201<72@0901041P0D20X0200001452@0K3a<040@80106200b9RX04PH:00<0
4@D900@04`L;01@8300G20/05PL:0P0E1PT03P0F1`X05`P;02<D5`0L3A005`P;01P9300D1@P03P02
01<72@0F2P`04@D70186200H30h05PX<0P0E2@/07@0:00005@T;01H:300800003`<301861P0A1@D0
3`<301P<300A1@D050P801861P0A1@D04`L701L;2`0I3@d05PP800h0000G2@T070h>01@8200E2@T0
3`D501`B4@0J40l03`L501@<2P0A2@L04@T6008040P600`04PP701<92P0C2@X04@D701D62`0O41D0
6@X?00d00`0B0`L04`@701@5200E1PT301H72P0500h00P0H2@`05`P;01831P0I2Pd0100C10L30183
1P<04`@701h050D801D62@0D1@P04`@701421@0>00804`@701H72P0@0`D060T<02dN8@1nKg8070d@
00X0000I30`04@H401L;2`0F2PX040@40186200K3a402@0001L;3`080000:AdQ02PN800I2Pd060X:
01H8200D1PH801<51@0601H:300>0P@02`4200`00P0A1@L050X;0P0A1@L201<72@0301@82P0E2@/0
5@H9008050D800L04`@701@5200E1PT05@H901@5200F1`X060T<00806@X=0P0C10L201831P804@85
00H03P0201431@0B0`H0404401X;3P0K30lDooooo`006oooool02`0F2P`04`L901T=3`0I3@l04`L9
01H:300@10H05@T;00l31@0>0P@050P:00804`L901l05@T:01@82P0B1PP050P:01L;3@0H30h04@D7
01D92`0E2@X0200001`@400T61L0ZIfM048g=@0>10@06Ph>020E4`0I3Pd05`/;01H;2@0D20L04PH6
01451@0D20X05PX<01T=3`0B1PP0300201041P0C1`T050P:00805PX<02`04`L90186200K3a408QHH
01L;3@0D20X05`/=01<72@0@10H04`L901D92`0F2P`04`L901861`0A1P@04PH601<81`0D2@L05@T9
01@9200C20H04`L701<81`0C20H04`L701D92P0>0P@0710B01L;3@0I3@l040@601451`0H30h07A4C
02`P8P0G2`d04PH801lC5@0D20X05PX<01<72@0@10H04PH801D92`D050P:00l05@T;0186200A1@L0
5`/=01T=3`0C1`/05PX>01@8300N4AP09APO01lB6@0I31<04`L;01D93@0H31000P0F2Ph01`0K3a<0
60`@01L;3`0E2@d050P<01D93@0G2`l00P0F2`l01@0L4AD06a0D01X?4`0[82@06@hB008060dA00@0
5``@01H;3`0F2`l060dC1@0G3Q<02`0I41D05`hC01T@5@0H3a@05PdB01`C600I4aL08A/M020J7P0I
4aL05Q0D00806aDI03006aDG01/E5@0K5AD06aDD01XE4@0J4`/091dC0519@@0V8A/07QTF024K6`0K
5aH0920O028Q7`0N6QT071TH024P700G4a0081hJ01PG4`0M71P061LD02DT8P0f=C<0<c8`018@4@0X
9RL06aTJ028R900W9bT0:2PZ028T8`0Q8R408b<U024R900S92H09bLY02DV:00T9BL0:2PZ02//;P0]
<S809bd]02@Z:P0[<C409B/[034g=`0]<c<202T_;`0Q02`b<P0]<c<0;C8e02hf>P1:DEL0A4]A02lf
?@0b>D40>T5903PoB00g?TP0?4E?04iGH018D5/0@DYD03]8D@0e?dT0>TE?03]8D00jA4d0=418034n
AP0h@T`0A51I05UUL@18DUh0?TYF04=?F`15DEd0@TiJ04EBF`16E5d0@e9K0080?4eE01T0@E9I03e@
EP0lCE@0>4Q>05]XKP1<FEl0A55G03m<DP0mBU00@DiD049?E@18EE/0BUMM04EBF010CE<0=dE8075o
P00gADH0D5iO03=1@P11Ce00@U1A04ABD`11Ce00@4i?0080A59C02P0BEMH04MEEP15De@0CE]L0:Bb
/`23TI80DEmP04]IFP1:F5T0BUQK04ECEP18EUT0AeEF04IDE@19EeL0DEmO059QGP1;FUL0CEaI04QF
EP0oCDh0AE=F059OI@1HI6X0HF]]05QPHP1JHV@0Ff=V06Y_LP28SI00k_?f0=kTi@29TY40Ig1]05mX
I@1HHV40G6QV055MG01GHf40FVIV0P1CGed0>@1EHEd0FfMS05eYI@1JIf00EfAM05QTH01KIfD0EV=S
05=QH@1KIVP0Hg1b05e[KP1II6P0EV9X05ERJP1IHf`0EV9Z059OI`15DUP0D5eS04eJH01?G640E69U
06EcMP1@GV40CE]N04]HGP19EU`0AeAJ04MEF01:F5T0C5YK04]IFP15De@0?Ta=03a:B`11Ce80@TeA
03m:CP0iA4P0@Da@04eHG02LYjT0D5YK01dU9`0i@Cl0;C4`02hc;`0f>cL0@TI503Di>00l@D40?D=3
04mGF@0lATP0>TA603I0@P02038j?@0i03Dm@00c>cd0<3Dh02X`<@0Y;bl0:Rlb02la=@0_<3D0:b`a
02LW;`0/;3@0:2Pb01hN:00W9c406ATQ024R9`0X:Bd0:BX/02DV:@0Y:Rh0;Bd_02//;@0W:BP0:BTY
02`];00Y:bX09bLY02LW:`0V9b`0;Rdc03@c>@0`;cD0;2/a02d/<P0f=CX0<C0f02PW;00N7B80<c8g
02LV:`0f=CX0>c/o04I7C00`<cX092H]02<S;@0T9c009bPd02DU<@0P8b`07b0Y02<T:@0R9BX08B8V
01`K8@0U8RT0:BL]00809B<V00D08R0Q020O7@0O7Q`07A/L01/I700201XH6`0>01dK7P0V92L05aDH
01lM800H5QT071XM00l=400L6Qd07A/N01lM800J61/05aDH01TE5P0K5aP201TE5P0W01/G600I5AH0
5A4B01TE5P0J5QL0510A01hJ6`11?Ch09b<T01lK700J5QL07QXK01DA4P0Q7Ah0<Bd^01@@4@0E4A80
2`L801PD5@0C3@l08A/M01D=400V828091/N01/C5P0I4aD05`hA01L?4P0H4Q@071<F01XB5@0E3a40
6A<E01D?4@0G4A<05@lA01<=3@0F41005@l?00<05A0=01@05Q4>01HA3@0K5Q4061<?01LB300G4Ph0
61<?01TD400L5a@03`X700`7100G4A4071HF01TC4`0J51H05@lA01PB500M5aT081XL00l92`805a4C
00D05@lA01hH6P0K5AL071HH01PB500201`F600301PB500F41805a4C00806A<E01H06aDG01dG6@0O
6A/07AHH01dD5`0Q5QX07A<F01P?4P0J3a<060hA01XA500V6al0;bDY02PO8P0M4QH06A0B01@>3P0Z
92@0=2h^04]5A@0J51@0618B0P0D3Ph02P0D3@d050/<01@;300B20P04@D501861P0D20X05PX<01L;
3@0D20`201@82P0?01<72@0B1PH04PH601@82P0C1`T04@D701D92`0J3Q0050P:01L;3@0@10H04`L9
00h2100A1@L03`@5008050P:00D04`L901041P0A1@L05@T;01@82P0201<72@0D0186200C1`T050P:
01D92`0@10H05@/<01<72@0A1@L040@601@82P0A1@L050P:01<72@0@10H04`L901L;3`0D20`04PH:
01<72`0D20`201862P<04@D900@04`L;01@8300H2@`05PL:0P0D1@P01P0F1`X060T<038S9P0Z6ah0
6@X=01/<3`805@H902P04PH801H:300A1@L04PH801T=3`0G2`d05@T;01041P0C1`T040@600l31@0G
2`d05PP8020D500K3`l04PL701D;2P0:00004PP701061@0B1PH04`L701<51@0A0`<050H601T;2`0A
0`<04`D501P<300D20P0718A01471P0N51<03`L601`B4@0@20H040P501491`0B2PP050X90P0E2``0
4`0E2@/04@D901P<400D1P/03`0501<62@0C10L050D801H72P0H2@`06@X=01`=400B0`H06P/>01H8
2`0>0P@05`/=01441P0C10L00P0B0`H201421@0N01<41`0E1PT050D801@5200E1PT05PL:01D82P0E
2@/04`L90186200K3a408ADG01d>4@0H2@`02P0001/>400:00007PlB00d20P0C1`L07A4A01X>3P0A
1@D04@D700l31@0G2`d03@<501H:3P0H31004PP90P0C1@D20184100301<51@0D1PH04`D500D04`D5
00H02`0001dA4`0@10H08ADG00P0000E2@/201041P050186200D20X050X;01H:300C1`T00P0D1@P0
100C10L050D801D62@0G20/301<41`040101100?00<05@H901D62@<050D800L04`@701d>4@0@0P@0
7a0C00X0000L3Q003@0001Cooooo000Kooooo`0<01P=300F2PT04`P701<71P0E2@P05`/:01D:2@0B
1`H03`@30145100G30/0710?0P0D2PT01`0F2PT04PH603da<P0R5QP040@601451P0B1PH00P0C20L0
0`0C1`L05Pd<05I<C@0201H<300=00d3100I3`l05P`<01892P0@1`L06a8B00/20`0E2``0<RHX0147
200@1@H050P:01X>400301@82P804`L90P0B1PP05P0E2@/050P:01@82P0E2@/04`L901451`0D2@X0
4PP901<82@0E2@/07Q8D00l51P0T6QX0<2HW01`B4`0@1PH04`T:01<92@0B20P050X;01D;300D2PX2
01<92P0H0147200@1PL04PP901@:2`0B20T04`T:00d3100G3@h07aDF01P>3`0F30d04PT:01H<3@0H
3Pl05@/<01@:2`0C2@X04PP901P>3`0J41405@/<01882@0C2@X050X<100C20`02P0D2@d05``@0146
2P0R5a/0:QlS01P=4@0C20`04PL;01@93@0F2`l201<8300a01P=4@0J3a<05``@01<8300A1PX050T=
01P>4P0G3Q<04@X>02/T:00B2`l0610E04i6B`0Y8RH02P<701P@5@0P6Ad04``@01H?4`0H4QT04`dC
01H@5P0F41L050hD01PB600G4AP05Q0G01TC6@0G4AP04`dD01LB5`0I51P07APL01TD6P0C3QD06QDM
01PC6P0M61h07APK01/G500K61806aT?01/I3@0M6@d07a/@03Te;00K5Q007QPG028L7P02020J7@0@
01lJ6@0P6QX07a/H01lK5`0Q71P08QhJ02<O6`0S7a`08alM02<O7P0N71d071XL01hL7`0R8R@08b<V
024Q9@80:2X^00L07b<U01hQ8`0X:b`082@T024U8`0S9b@092TV00809b/V03409R/V02H/:00S:BH0
7B<P02`b<00Z<2h0:c4_02/a<@0Y;S40;S<f02db=@0/<C@0<3Di030g?P0g?TH0=Ca403]2B`0d?DH0
<ca503Y2C@0g@4`0=d9=03U4C`0kAU80>TAA03U2C`0j@Td0?4I>03e7C@0lADX0>T=803Y4BP0h@DX0
>T=?04M?GP18Cf40@4YJ04ECH01:F6D0AUAQ04MEH@1;FF@0A59M04eKI@0mBe@0CeeV03e<E@0mC5<0
?diE0080@4mF00D0A5=J04EDF`13DUT0@e9I04ACFP0204EDF`0O04=BF@12DEL0?Ta?04ECE00lBT/0
A59C045?D00nC4d0@e5B04ECE012D540BeUJ03a:B`1;FE/0A5=H04aKH010Ce<0EfIZ07n>T@1RLW<0
D61P04eMG01<G5X0D61M051QG01:FUL0CUaM05ARH`1<FU/0AeEF04]IFP0204UGF00J04IDE@17EEH0
CeeN05ARI01CHF80E61P05MQH@1MIVD0HFMX075cM@2ZZjd0j>WZ0=CGf01mPh<0I6e/06]eL`1KIfD0
FfQU05MVHP1JJF@0FVUU05MVH@1IJ6<0DF1K05=RG@1EI5l305IUH020055QG01GIf<0EVIS059QH01A
H640EFAW059PIP1CHFP0E69[05ERK01AGVX0C5US04aIH@1=FUl0CUaO04iLG@1=Fe/0CE]J04]JF016
E5D0BEMI04YHF`19EU`0C5UO04UGF`10CE80AUAH04ECE`10Bdl0AE1D04YDF01BG5h0@D]=03]4AP13
C4h0A4e=03a6@`0c?3P0=Chj038k>00^=C<0;cLd03Lo?@0b>CX0<CPi0418B@10B4X0<3Pj03Pm?@13
B4P0@DI603Xo@00g?3l0<3Dh02X_<P0^<CD0<3@h02ha=@0h>d00>ce102`]<@0Y:Rh0:2T^02<T:@0R
8bP0:2T]02DV:P0a<SH09RL[02h_<`0Y:Rh0;Bla02X^;`0X:b`0:2`]02T];P0Z;Bh0:bl_02HZ:`0U
9bT0;C0b02L[;@0P8RD0<c@j04a<E@0`<3T0;Bde02TY<00X:300:BX_01lP9@0T9BT0<C8f03<d>00e
=SX08R4]03hlB`0X9c@09B<`02<R;`0Q82/0<2hh02HU;@0R8RP08R4W01dM8P0S8RL07Q/U02HS;P0R
7bT0A45903<`=`0Q7b@081hP020N7`0N7A`071/H01/J5P0K6QL07a/K01`H6@0P71d06QHG020L7@0R
7Ql06aLH01`H6@0O6a`2020L7@1401hJ6`0]:BX06aLH01@@4@0d<340>cLh020L7@0K5aP071PI01XF
5`0H51D07QXK02DQ8P0K5AL071HH01XD5P0O6A/05a4C01hH6P0M5aT07aTK01dG6@0I4aD071HH01H@
4P0J41L07A8I01D;400I3Q@07A8G01dC5P0N4aL06@lB01L>3`0I3a006A0@01L?3P0F41006Q@D010:
2P0G4A403PP801dG5`0J51@02PD501TC4`0H4Q8050h>01XE4`0I51406QDB01D@3@0G4Pl05Q4>01@?
300H4a005A0=01/F4`0J5A805A0=01`G500M51D07QDF01T@4@0L4a@07aHG01`C500O5QL401hE5P0c
01hE5`0K5AT07QPL01PB5P0P6Qh06A<G020J7P0@2Ph09AlS01/E6@0L5QX05@lC01/E600P6Q`08a/N
01XC5@0J51H07QHI01`E5`0J51H0:b<V02LP8`0B30h0614C01TA500N5AP05@lA01`G6@0;1`P05a<D
018>3`0D3a005PhA01L=4@0F2Ph05PP=01D92@0F3@L05P`:01H<300E2``050T=01<83P0N4aL081HF
01881`0@1`<05Pd901@9200D20P05`/;00806Ph>00h05PX:01<71`0B1PH04PH601451@0B1PH04`L7
01@5200@0@@05`P;01421@0G20/05PL:01D62@D05PL:00<040H701lC5@0P51H00P0@10H03P0A1@L0
6@d?01<72@0A1@L04PH801@82P0A1@L050P:01451`0F2P`040@601@82P0@10H050P:0P0C1`T02@0D
20X04`L901451`0B0`H05PL:01h?4P0F1`X05`P;01@5200201H72P805@H90P0D1@P01P0A1@D05@T9
00d20P0T61P0DTI601461PD04PH601/050H601H62@0D1@P04@D701X@4@0C30`05Pl?01D=3P0=10D0
50X;01P;3@0H20/05@P801<71P0E2PP05``:01@91`0J3`d08aPF09Z?S@1KD4h060d;01H;2@0N4a40
5@/901L=2`0E2`X00P0D2PT201D;300B01<92P0C20`04`P<01872`0A1PX04PL;0104200^8RH0VhjB
01T:3`0B0PL070`A01H7300E2@d04`T<00/51P0<1`T050/=0P0B1PP301451`0@0186200A1@L03P84
01451`0E2@/05PX<01X@4`1bJfd0Ng=f028I700>1@L0DTM;01D93@0C1`/05@H;01D52P8050<900D0
5@L:01@82P0@10H03P8401<72@0200h3100601451`0B1`P05`/=00l41@0@1@H050H60P0C1@D02P0B
10@04`D501@61P0N410060X:02DG5`0;00005`T901861P0E1`L201@61P0G01<51@0D1PH04`L901<9
2P0@1PL040H901H>3`0C2Pd03`D901X@4P0_8bL03`@701/?4`0G2`l03`D70104200A1@T04`L;00/1
0`0^8RH0O71d01D93@0C1`/00P0A1@T0100C1`X05@T;01451`0A1@H201451@0301461@0A1PCooooo
01?ooooo000Kooooo`0801@8200C1`L04PH601<71`0F2PX060`<01@8200C1`L201861P0<01D92@0G
2`/04@D500h30`08000060`>0186200K3a406Ph@01L;3@0D20P04`L70P0D20P04P0A2@T03@<400d3
100G3@h0308301<92P0F30d06@l@065GF01iKg003`D601061`0J3Q007Q8D00P0000M4A<04PH800P0
00805@T;0P0D20X301<72@050186200C1`T05@T;01@82P0B1PP00P0J3Q002@08000040H702TM7`0>
0`D06a4B024G600E2``04@L801<92P0201061`090147200C2@X04`T:01<92P0D2P/04`T:01882@0D
2P/05@/<008050X;01@05`d>01P>3`0C2@X02@0000l51P0I3a003@<401T?400?1@H08ALH0147200B
20T06Q0A01L=3P0C2@X03`D600h41@0D2P`04PL;01<8308050T=00H05@X>01462P0?10P04`P<01H;
3`0C20`201@93@0701D:3P0F2`l05P/?01H;3`0J3a<05@X>01H;3`0201P=4@1701L<400E2`l02P46
02TS9`0c;C403PP<00L11@0F41@03PP<01TC5`0C3A406Q@H01/E6@0C3A405A0F010;4@0A31804`hD
01`G7@0C3Q@06A@J01<>500H4aT071LM01PC6@0D3aD071LK03@_=00K5Q`081/R02@O9P0M61l06QDK
01XE600I5A806QLB01/H3P0L6Pd0:2HI024O4`0P7A@071TB038^;00J5QL081/O020K7P0O6aX07QXI
01dJ5P0L6A@07aXG020K600Q71T081`K020L700P71d07adP01dL8@0N7B808R4V02<R:00Q8RL0828V
024U:00G6ah07R8S02DY:00R9RD082@S024V8P0R9b<00P0S:2804@0R9b408bTU01hT8P0X;R`0:c4_
01PN7P0f?3`0;C<c02X_<P0/<C@0;C8e02ld=`0c>3`0<SU0038i@@0mA4`0:34j0080>45:01d0>D==
03Q2CP0h@dl0>DEA03Y6DP0kAE80?4AA03e5D00lADd0>45803Dn@`0e?T@0>T=:03a5CP0mAE40@TUI
04A;GP0nB5T0@U1M04MEHP15Df00AUAQ04MEH014DUd0AE=N03E3C011CeP0?deF041?EP0203m>E@06
045@E`16EE`0B5MN04IEG015E5/0AeIM0P18Eeh08@15E5/0@E1F03e;CP1SLG80@Dm@03]9BP0`?Sl0
@U1A03]9BP13DE80AUAE04aJF`14DU<0AE=D04]JG@1<Feh0BUUL049AE011D5<0D5mQ04]KF`19FEP0
BUYI04iNG@1>GU/0B5QG045?D01=Fe`0EfEV04=ADP1CHF80FFMX04QFE`0204ECE00G04aJF`1?GEh0
CeeM04YHF01JIV@0DE]J05]TH`1XKFd0IFUZ08N8RP26Rh`0H6UX05USHP1JIV@0Df9O05]ZI@1CHUd0
E6=N05MVH@1FIF00EfIQ059QG01DHeh00P1FIF009`1GIV40EVEP05IVH`1FIV<0Df=P05=SHP1CHf@0
E6=V055PI@1EI6/0E69[04iLI`1<FVD0D5iW04iKH`1>G600CUaO04eKF`1:F5P0BEQE04mNF`1=Fe`0
CUaM04UGFP16DeT0BUMM04QEF`11CU@0BEIL03m=D019E5P0@Da@03Q2A011Bdd0F69T03Y2A00d?3h0
=3dl03Y3?`02038k>00603@m>P0f?ch0>T=203M0?`0g?d40<c/m0P0j@T@06`0a>C/0=c/l03i2@`16
BT/0=SXk02/_<P0b=ST0:Bd`02HY;P0Z;C80;C0e03Hi@00k?D80:2T]02d^<P0V9b/07AhR02PY;@0P
8BD07b0T02DV:P0/;C40=3Di01TJ7P0[;C00:2`]02HZ:`0202DY:P0402@X:@0N8R<0;c<d01/O8080
<CDf01`0>3`m06]]LP18B580<30j02PX<@0L72@0:BTa0411A`0i>Sl0;2da02PY;@0T9BT0:b`a020N
:`0c<Cl0:bTg02TW=00S8Bh0<Blj028Q:@0N7BD09bH/02d/<P0T8bT07ahS02@Q:P0U8R/07AXR0P0I
5Qd03`0P7R<071XM02<Q8P0Z:2P08R4O01`K5`0M71P07ATH01LC500M6AX06ADF01/G600M6AX06QHG
01/G600301dI6P0801`H6@0J5QL08AdN01/G600P71d05A4B00h:2`0L61T201dI6P0701`H6@0N6Q/0
8AdN014;3@0H4Q@04`d?01TC5@0201LA4`0c01`F600A2`d03PP:01hH6P0J51H06A<E028H800E3180
60lD01H=4P0M51P07A@G01T@4`0G3Q005`h?01T@4@0J4A40610>01D?3`0K5AD03PP802DO7`0I4a<0
4P`<01@>3P0R71`08A/K01hH600M5aL0=2h^02HQ7P0K5Q<07aXG01LB3`0L5a@04Pd:01D@3@0?2PL0
7QTF01PC400J5A805A0=01P?400K4Q<06Q4B01dD5@0O5QL071<D02<J6`0P5aP07QDF00<07A@E00H0
7QPL024L800K5QX0:bHZ02lZ;P0^:Bd2024L800601/F6P0X8bL06aHJ01`F6@0H4Q@06Q@F0P0I4aD0
8P0F418050h@01/E5`0E3a404`d?01PB500G4A<06A4D01`C5P0=1`T040/<02/W:00@3Pl04Pl@01DA
4P0H3a806@hB01P<400H2@h05PX901@;100E2`T05@/:01@:2`0C20`03@8601hC5`0T6QX03P@300/2
000R6A@050T701@8200E2@T201P<300301@8200C1`L04`L700<04PH600H04`L701T:3@0@0@@05PL:
01P9300O41<701@5200401<72@0L41806Ph@0186208050P:00/05@T;01<72@0A1@L04`L901@82P0B
1PP05PX<0186200D20X03P8401@82P020186200;01L;3@0F2P`04@D700l31@0B1PP070d@01421@0B
0`H03`0301L82`0B0`H00P0F1`X201D62@8050D800H040@401D92@0C1`L05`/;01D92@0K3`l50186
1P0>01@61P0I2@`05@H900`00P0L4Q<05@l?00d71`1;ADD0;RDV01061`0C1@P091@G0141100C1PH2
01P<300:01861P0O4a<0;R8R0=O;b`24N7P05@T901T=3@0F2PX050P801@:20805@/:00@04PP700l5
1P0=0`@04@L80`0B1`/03P0@1@T04PL;00d21P0A1@T07A0D00X0000c8RP08a<I01<42@0900409adQ
02HP8P0;1`P030@60P0A1@L30186200@01D92`0C1`T04@D701P<3P0M4A<060`>02HL7P3KeML0ooKi
03P_<P0I41<01`0001872`0C1`/05@H;01D52P8050<900L0:1TM01`@4P0@10H06@d?00l31@0?10D0
5`/=00805@T;00@040@601P<3P0E2@/050H60P0C1@D06`0B10@04`D501@61P0:0000818B00l10@0K
3@d05`T901/=3@0E1`H050H501@61P0C1@D050H601<72@0C2@X040H700`31@0600005`hA00l62@2/
X:@0^Zjb01lC5`0@10P04PL:01lC5`0200h21P0601H:3P0C1`/060`@03DY;@0E2@d050P<0P0B1PX0
100D20/05@T;01451`0A1@H201451@0301461@0A1PCooooo01?ooooo000Kooooo`8050P80P0C1`L0
100E2@T05`/;01@8200D20P401<71`0O01hB4P0G2`/05PX:01D92`0B1PP04`L901lC5@0L418060`>
01L;2`0I3@d06Ph@01/A4P0=0`@07Q@E01061`0=0`@05`d>01H<3@0B20T0HEMH071VI`0?1@H05`d>
00d3100I3@l020000147200:0000:AdO01<72@03018620804@D70P0C1`T03@0D20X05`/=01H:300D
20X03`D60186200L41809a/M09>7R@0h;Bl050X;01H<3@0A1`P00P0B20T00`0@1PL04@L801882@03
01882@<04`T:0`0D2P/03P0@1PL04`T:01D;300=0`@03P@501D;300C2@X04PP901H<3@0C2@X04PP9
01@:2`0G3@h04`T:0P0J41403P0@1PL04PP901472@0B1`/04`P<01@93@0E2Ph05P/?01D:3P0G3100
5@X>01<8300G310060dA1@0F2`l00`0H3A405@X>01H;3`0201T>4P0701P=4@0E2`l08QTN01lI7@0F
41@06A<G030Z;P0201hH700W01TC5`0F41@06Q@H01XD600C3A405a8H01D@5P0O6R00100500h93`0?
2Q006QDK01@?5@0H4aT06aHL01TD6P0J5A/04@`@02@O900F4AL05Q4H01LB6@0E41H071LM01/G6@0J
5Q<06QLB01/H400L6Ph04a45055?A00o?3D0:BHQ03Te<`0I5AH06aHJ01`G6P0M6AX07ATH00807a/H
024081/H028L700S7Ad08QhM028N7`0Q72007adP01lN8`0P7b@08b8W02<R:00Q8RL08BDX01TM800f
>Sd082@U02DY:00M8B008bLV02@Y9@0U:RH09BXT02@Y8`0S:28092XV02@Z:00Z<2h0<SPf03a2@P0h
?Sh0;38b02`a=00_=3L00P0`=CP08`0a=SX0=Se402P_=`0g?TH0>T=<02/d?@1>Ef00=d5;03Q2CP0g
@Th0=T9>03Q4D00h@dl0>T9=03e6C`0lADd0=d1703Dn@`0f?dD0>T=:03a4C`0mA580@4MG04A;G@13
CEd0AE=P04QFH`13DEh0@4iK03m=F010CUT0AE=N03e;E010CUL0?deF0080@U5H00L0@E1G04=BF@17
EUd0B5MN04EDF`14DeX0AUEL0080AeIM0100@e9I03i=D`0lBTd0O8Z;04ABD`17EEH0@e5B04YHF@16
E5D0DEmP04=ADP0nC4d0CE]L04iLG@18F5P0@U5D0P16EEP07P13DUD0EfMW04]KF`1:FUX0Be]K04eM
G@1;Fe/0AEEE05ITI@10CTl0D5iO04UGF01<FU/0BEMH04QFE`17EEH0B5IG04iLG@1AGf00DV1Q04eK
F`1JJ6D0D5aJ05aVI@1RJFT0DeUI06E[J`1ZLG40G6IU05]WI@80Df9O00T0F6MR05ASGP1FIF00EVEP
05=RG@1FIF00DV5L05ASGP1FIF000`1GIV404@1BHUl0DF5N05=SH01GIfH0F6QY05ETI`1DHfP0EFAZ
055OJ01=FfH0C5YU04mMIP1;F600C5YN04eKGP1=Fe`0C5YJ0080C5]H0180C5YK04iLG@18EUT0AE9H
04UFG018EE/0@TmE04aIG`0oCE00DUeQ04=>DP12C4h0A4i@09:LWP1HH680=Cdo04YCDP0h@Cd203@m
>P0603Ho?00h@D00>T=203Dn?@0g?d40<SXl0P0a>C/0?00/=3H0<SHg03<g>00i?Ch0<SHg02da=00d
>3/0<CDh02LZ;`0Z;C80?D1503Tl@`0`<SL0:b``0411A@0g>3`0824U02X[;`0V9b/0IFIZ03@e>@0X
:Bd0<S<g01`M8@0];c80:Rh_02L[;00U:BX08bLX020T9@0M8B80LGEf02HZ:`0G6a`0:2`]01`P8@0h
>Sl06a/U02h^>00V9Rl0<C4i03Ph@014AD/0=CHk02PY;@0S92P08B8V02`]<@0R82d09bDc028P;P0[
:CH0;B/h04Y8D`0o?TH0<c8j02/Z<00Y:2h08b8X02DT:@8081dT00P09bD[01XG7P0Q7b@09B<X01XH
6`0O7B00928S01hL7@806QTG00L061@E01DA4P0U8B8081`M01/G600M6AX06QHG00D06aLH0P0L61T0
1@0C3a005a<D01LC500T824061@E00D06QHG00H05@lA01`F600E3a4071HH01dG6@0K5AL201LA4`0P
01`F602ARhd091hP020J700S6B4050/A01dD6@0J4AH07aHJ01dD5`0H3a805`h@01L>3`0H3a0060l?
01D=2`0I4a<04P`<010:2P12?3`0:28R00D0000H4Q803@L701H@400:10@0H5YJ0>kXj01>BDH02`H3
020K600E40d201LB3`0?018=2P0C3P/08ahK01LB3`0H4a003`X701XA4P0M51D07QDF020G600O5QL0
7A@E01hE5P0M51D071<D00806a8C00D06A<C01@?4`0Q72006aHJ024L800201dH700801XE6@0^:Bd0
91lS010;3`0C3Q807APK01hH6P0O6A/2024K7@0R01hH6P0J51H0:B<U020J700L5QP08Q`N01H@4P0I
4A@0:1lR018<3P0X8b@0GUYK01/I6P0H5AH05A4B01H@4P0G3A405`/?01T:3`0G2`X05`h901L=2`0G
3@`05P`=01D:3P0B1`/050X;01@:2P0A1`D04PP601P?2P0C20H04PH601<71`805@T900<04PH601@8
200C1`L00`0B1PH01P0D20P06P/>00l00`0F1`X0814D02TJ7@<06P/>00X05`P;01@5200B0`H04@85
00T0000>0P@03`<501041P0E2@/05PX<0P0C1`T0200B1PP04`L901@82P0C1`T05@T;01451`0E2@/0
4@D70P0J3Q002`0C1`T05`/=01L;3@0D20X04PH801@82P0M3Q406@X=01L82`0=00404`@700<05PL:
0P0E1PT201@5200401451@0?0`<060`<02`P80804@D51P0B1PH00`0H2@`050D801H:300200h51P08
02HP803DcLd0ShF602DK700?10D070`?01P9300C1`L201H:2P0A0104100F2PX08ADE04/o?`0a9BD0
3`<301T=3@0?0`<050P800l50`0@1PD04@L601<9200D2P/05@/<01@:2`0B1`/00P0A1PX04@0>0`L0
2P4301052@0A1@T03`@602XK801nKG<0?2`b00l01@0K3a<0UXb@07miN`0M6AX04@T;01041P0A1@L0
4PH800804`L90P0F2P`20186200<01H:300G2`d06Q4C05YDEP26OH006A0C01lF6@0A1PX040@801<7
2`0E1P/05@D:0P0D0`T0200S5QT05`/=00l41@0J3Q0040@60186200C1`T020000`0?0`D09@0@1PL0
50H601<51@0C1@D04P@401<51@0D1PH04@<301lA4@0J30`0;AlO02DG5`0<00005@L601@61@0D1PH0
4`D501@61P0C1`T04@L800L0000N4aL03`H900h5200O5QT060`@040d>00E2@d0710D0104200;00<0
6`lC00d21@0?0`L04PH:00/10`0800000P0B1PX20104200401862@0B1PP04@D701451P804@D500<0
4@H501461?ooool04oooool001_ooooo0P0D2PT0100C2@P04PP701881`0A1`H401881`0B01471P0A
1`L03`D601/?4P0D2P/040H701X>400>10D05@T;01@82P0B1PP04`L901D9300F2Pd050X;00h41@0L
4Q<03PD50P0C2@X01`0A1`P04@P901@:2`0H3Pl05P`=01061`0C1`T00P0E2@/00`0O51D0PWIh04Xn
@00201@82P804`L90P0B1PP04@0E2@/050P:01H:300H30h05`/=01D92`0G30h0308301/?4@0@1@H0
:1`N01H;300C2@X04PP901@:2`0G3@h05@/<008050X;00<04`T:01882@0B20T00P0B20T00`0C2@X0
50X;01<92P0201882@0;01<92P0A1`P05P`=0147200I3a007A<D01@;300F30d02P4201P>3`0<0`@0
0P0E2``01`0<0P<08ALH02PN7`0I3a007Q@E01472@0D2@d01@0E2Ph0200G31005P/?01<8300E2Ph0
4`P<01T>4P0G31005P/?0P0E2Ph0400D2@d060dA01L<400G31005P/?01L<400G3A405@`A00l93@0J
51P06A<G01XD600B31004@/?00l93@0J51P2010:3P0801/E6@0G4QP050lE01PC6@0@2a409b8X02TT
:P0J5A/201PC6@0E01D@5P0F4AL081/Q01XE6@0E41D08ahT01PC6@0I51X07APM01PC600J5AL06aLE
01hK5`0R7aP0924H04Y7?`3KfM40UY>=03Pd<00O6aT071PG00808AdN00/081`M024M700Q7AX08AdK
01lK6`0P71h08AdO024M800P7B407adR020O900302<R:00:024R9`0R8bP082@V03<g>022QXL08RHW
028V9@0N8R408RHU02@Y9@809BXV0P0T:B@03@0X;b`0CeQE04QACP0_>3D0F65P02`e=00Y<C<0;SHh
030h>P0b>Sd0<CTl02hf>@0e?4@00P0_>3l05`0nAe00GFM`03@nA`0i@dd0>dMC03Y6DP0iAE40>dMC
03e8D`0nB580?dUB03Y5C00c?T@0<Se303Q3B@0jAD`0>TA>03e7D`11BUT0ATmP04UEI01;FFH0C5YW
0080AeER00P0AUAO049@F`12D5/0CUaU045?F00nC5D0?TeD04ACF@80A5=H00<0AUEJ04EDF@13DUL0
0P11D5D05P12DEH0@E1E03i=DP0lBdl0@U1C04=ADP11Ce00?de>03M5AP1=Fe`0E69S03m=CP19EeP0
DV1Q04MEEP18EUL0CemN04YJFP18F5P0@e=C045AD@1AHF4204mNH@0:04iMH01<Fel0BEQL04EDF@17
EEL0EF=T05ARH`1GIFH0SifN07:0P@80AE=D01T0B5IG04aJF`1?GEh0DV1P051PG`1DHf00Df1N05UW
I01HHf80GVQW05eWIP1LIfH0F6ES05]XIP1?Ge`0EfMT05IUH01HIf80FVUT05IUH01@GeX0Df9M04mN
F@1@GeX0DV5L00<0Df9M04P0DF5N059RH01FIVD0FFUY05MVJ01?GV40EfI[051OI@1=G6<0CeeV051N
J01=Ff@0CU]S04iLH01=Feh0C5YJ04UGE`18Ee@0AEAA04IDE@1<FU/0BUQK04ICF@17E5X0AU=I045?
DP17EEP0?Ta?04iIF`10Bdd0=Cm1034k?01DGUl0>41203Dm?`0g@3l0=d0m03U2?`0h@Ch0=Sll03@m
?00b>cX0=Cdo03U1@`0g?d40=3`o03Dm@00f?T00=c/m02lc=00V:R/0;c<f03@h>`0V:Bd0<C@i03Lj
?`0c=S`0@TE<0454B`0`<SP0;Bhb04A5B@0f=c/06Q/O02HW:`0j>cl0a/O;05UJGP0Y:Rh0;2da02//
<00/;S4202P/;@0702X^;`0[;c00:Bd^02``<@1WJf`0<CDf02DY:P0202/_<00902`^=00W9c40<30j
02h^=`0c<c/0820X02d]=00V9b`0;c0d0080;Rlc01809BH[034_>P0Y9c<09R@`02LU<@0R82/0:RPc
02TX<00O7RH081lU02HU:`0P7bD071/Q01dK7`0H5QX08b4T01TG6`0S8B@201lM800301`J7@0J61/0
6QPK00806aTK00@06QHG01@@4@0Z9RL09b<T0P0I5AH201`H6@0:01/G600J5QL06aLH01/G600F4Q<0
61@E01hJ6`0T82406QHG02HR8`@06QHG02d06ADF01HB4`0E3a40618D01LA4`0P6Q`06A<E01LA4`0L
5QP05a4C01XD5P1LEUP08Q`N01hH6P0I4QT06A<I01LA5@0J51P05a4D01D@4P0O6A/06aDF01LB4@0H
4Q805a8@01@?300H4Q8071HF00l92@0M5aL04`d=01H@400B30`06A<C020J6P0M5aL0BdE508^5Q@0g
<Rl04@`901hI5P0E40d06A@A01@?300I51400P0G4Pl00`0D3``05A0=01dH5@0201XD500301`F5P0K
5AD0618B00<06A<C01006Q@D01/E5@0M5aL07QPH01`G6`0V8BD07APL01hI7@0G4QH07aXN01/F6P0f
<CD0?STm01LB5P0S7R806QHH0P0I5AH06P0L61T06aLH01XF5`0L61T0:bLX02LS900O6a`07QXK01PD
5@0N61T06a@F01dG6@0F4Q<08AlP00h<3@0D4Q<0514B01D?4@0F31005PX>01L:3P0F2`/05Pd801H<
2P0F30/05@/:0P0D2P/0200B20T05@/:01H<2P0C2@L04@L401P<2`0F2PX05@T90P0G2`/00`0E2@T0
50P801@8200301<71`0>01@8200J2`h0404401L82`0M3Q409AHI01P9300L3A006``?01T:3@0G20/0
5PL:01@5200C1`T201@82P0401<72@0D20X04PH80186208050P:0P0C1`T01P0D20X05PX<0186200E
2@/040@601L;3@805PX<00/04`L901D92`0I3@l06Ph@01D92`0@0@@0:Q/N03HW:P0O41<050D801D6
2@0201H72P805@H90P0D1@P01P0B1PH05@T901861P0Z7Qh05`/;00l30`H04PH600h04`@701@62@0D
20X04`T:01892P0S6Q/0UHf>06ILG@0@20P06@d?0101100D1@P04`L701451@805@T900l04PH601@8
200H30`05`/;01X>3P0A1PH08QHF01T=3@0E2`T04PP701471P0E2`X0718C01lE5P0D2P/00P0?10P2
01<8300=01872`0?10P03P@601T<400?0@D09QDK01/;400D1@X040H804a3AP0k=CL02@D601082P02
018620804`L900h050P:01051`0D20X06Ph@01D92`0=0@<040@601@:300O5QT0:R4T01D;3P0>0`L0
5@X>01@830804`L;01004`H:01<42@0C10T04PD801041P0A1PL04`L901451`0>0P@040@601D92`0D
20X04PH801@82P0K3a4050H60P0C1@D08@0B10@04`D501@61P0B1@D060`<07AVIP0E1`L04@D501P;
2`0E1`H050H501@61P0C1@D050H601<72@0<10@03@<401P?4@1HCe807QDH01D<3`0J3Q803P@601T=
4@0=0`D05``?0104200B1PX05@T=01<72`0A1@T04PH:01D;3@0401862P0401862@0B1PP04@D70145
1P804@D500<04@H501461?ooool04oooool001_ooooo00P04PP901<92P0C2@X04`T:01882@0A1`P0
4PP90147208040H700l04PP901<92P0P51P0C4140104200a9BL040H701L;2`0C1`L04`L801<72@0D
20`05@P?01D93@0H3Ph00P0B20L03`0C2@P03`D400`20@0D2PT05@/:01`B4@0@1PD04@L601L=300C
2@X04PH802dQ8`0:0040CD5302LK7@0201D92`8050P:0P0C1`T0300E2@/04`L901@82P0E2@/04`L9
01451`0D20X09a/M00h2100F2P`03`<501P=3`803`D60P0D2P/20147200N01<92P0B20T04`T:01D;
300G3@h05@/<01@:2`0F30d050X;01882@0C2@X04PP900/10P0H3Pl0:b8R01061`0=0`@05`d>00`2
0`0[8B8050X;02DK700<0P<050X;00h41@0B20T0718C01@:2`0@1PL05P/>0P0F2`l01`0E2Ph050T=
01<8300H3A405P/?01L<400H3A400P0F2`l01P0H3A405P/?01@93@0G31006@hB01P=4@805P/?0`0E
2Ph0600F30l06Q4F00`62P0B3A0050hB00d72`0G4AD06Q@H01H@500[9BT0L6Y^034[;`0J51P0BDA:
05aGG@0F4AL06QDK01dH7P0B3A<06A@J01LB600J5A/06A@J01D@5P806A@J01004PdC01HA5`0F4AD0
5a8F01HA5@0H4aL06ADE01/G5P0N6QL08QlJ02@Q6P0Z:B@0OGag04]:AP0_;RX08R4O0`0Q81h01`0P
7ad07ahL01hM6`0M6a`07QTM020K8@0Q72800`0O72<0:P0P7bD09B@Z02DV:`0R8RX08B4Y028S:00S
9bT0=c/l06EYJ00S9bH092PW02HZ:@0R9RD08bLV02@X9`0V:bP09R/W02D[9`0R:RL0<CXi04YCDP0R
:bX08b/]034i>`0/=3H0;cLj02de>00a>C`0=Ce0038j?@0i@TT0:c@k03@mA01HHV/0h>[c08B>U`0j
Ae00@4aH03i;E`0kBE@0?D]F045<E`80@TaE00h0>49;030j@`0b?4D0?4I?03e7D00mAe40ADmJ04A>
FP13C5/0AE5O04MEHP14DUl0?deJ045?G080@4iI00T0?deH05ESK013DEX0AUAM049AF015E5X0@e9G
045@E@12DEH00P13DUL06012DEH0@E1E041?E00oCU<0?TeB041?D`0d@TD0@e5B045?D01<FU/0B5IG
08ZHV@2AWj00EF=T04IDE@1<FU/0BEMH06ilO@1QLG00BEUF03m?CP1;Fe/0BUYJ05ETI`80D5mT00X0
CUeS04aKHP1<Ff80CUaT04mMH01DHV<0FVQY04]IFP10CTl0BUQI0P14DU<204ECE00704IDE@19EeP0
C5aK055TH01AHEh0EVIS05ASH00205]ZI`0>05YYIP1CHf00EfMT059UH@1OKf`0I7=`05QWI01DHf00
EFAQ059QGP1?GU/0Df9O05ETH@1GIV<305QWI00^05ATH`1CHf80DV9R059RHP1@H640CUeP055PI@1?
GV@0CUeT04mNI@1?GVH0CeeV055NIP1@GF80CE]N04YHF015De<0A5=@04QGE016E5D0CUaM05=QI01;
F5h0AeAJ05ARI@1:F5/0AE=F03i<C@0jADL0<C`n03Do@00a>c`0A4i?03e6A@0c?3/0>dA303Y3@00n
AdH0>D9103Ho?P0f?T00<c/m03Y2A00i@D@0=Si102lg>P80:S8e00d0<CDh02X^<@0T:2/09RX]02d`
=@0b=CX0<cHk03XmA00n@DP08bH]01/N9`0Q8bT08B8V00809bP/07H08R<W02X[;`0U9RX0EEIJ03Lh
?00[;300:R/_02TZ;P0R92L08BDV028V9`0V:R/0:2`]02L[;00T:2T07R8S024U9P0U:BX0720Q02@X
:@0V:2h0:b/e01hN:00];CH08B4Y01XJ8P0U9R`0:2T^02<T:00G61`0:R/_02HW:`0[:S80:RTa034`
>@0Z:C408b8Z01hM9@1LFf<0A4=;02HU:`0N7B<071/Q02@S:@0R82<071XK01lM7P0J61T07Q`M01hL
7`0M6ah071XM01/I7P0J61d071XO024O900_:Rh04`l@01TE5P0R7Ql06aLH01`H6@0N6Q/07ATJ01/G
600J5QL06aLH01`H6@0Q7Ah07a/L01@@4@0@30d0:bLX07McM00P71d071PI01/G600L61T06aLH01LC
500K5AL091hP03hh>P18@T@09AlQ01PB500@2P`06Q@F02HP8P0<1PP06aDG00P2100@2a409B4V00H4
1`0G4QH04PlA01TG600Q7Ah06AHF01<B400E4A005Q<A01LC400C3@d06Q@D01hH600K5AD04@/;034[
:`0H4Q805Q0@07ihN01OFET04@/;01TC4`0@2`P07APE0P0H4a003P0K5Q<04`h;01LB3`0D3``02`H3
02LR7`0@2`P08A`I01TC4`0F41006Q@D01TC4`0H4Q8071HF0`0J51@04P0L5QH07ALG01hH600H51P0
6ALJ01<A500K6A`05Q@G024O8P0`;S404a4D01HD5`0L6Qd09bDX028P8`0P7R40928U02PV:@808AlR
00L07adP018@4`0F51L061HI01LE600Q7b809b4T00803`T;00/09b@U01<A4P0I6AT05A@D01@B4`0E
3a405@d@01H;3`0G2`l05P/<01@:200201D;2P0?01@:2@0C2@P040H501061@0E2`X04@L600X0000A
1`D05@T901<71`0A1@D04PH601<71`0A1@D05@T9008050P800T04`L701@8200E2@T05@T;01041P0F
2P`04PH801L;3@0C1`T0100B1PP201451`0700`00P0?0`D05@T;01D92`0C1`T050P:0186200201H:
300901<72@0A1@L04PH801D92`0A1@L05@T;00h2100B1PP03P8400804`L900X05@T;01H:300G2`d0
5@T;01H:300J3Q006`lA00d10`0A1@L060`>0P0D20X201<72@804PH800H040@401D92@08000040@4
00/0000A1@D601861P0901H:300C1`T030020147200C2@X0718C02/Q8P0K4A805@/<00803P8400<0
5@T;0186200A1@L00P0E2@/0800D20X060`>00X00@0F2P`050P:0187200S5aT05PX:01@:200A1`H0
3`D401061@0D2P/05P`=01X@4@0?10P03@8601872`0E2Ph04@H:01hC5`0N4QH04@<801X;400R4AL0
3@0201D62`0H31004@P:018<3P0R7Ql08ATJ100C1`T03P0B1PP040@601P<3P0R5QP07Q8D01<72@0B
1PP040D701L=3P0<0P<03PD601<92P0800004@D70P0C1`T01P0B1PP04@D701451`0A1@L050P:01D9
2`804`L900P04PH800`00P0G2`d06@l@02HJ700800005PX<01@61P804`D502404P@401<51@0D1PH0
4@<301<51@0=0@4060X:01d?3`0C1`L05@L601@61@0D1PH04`D501@61P0C1`T04`T:014720070000
?cHi0189300@20X06`lC00/00`0B1PX03`<701L;3`0:00805`/?00d31@08000040@801`@500A1@T0
0P0B1PX201<72`0401862@0B1PP04@D701451P804@D500<04@H501461?ooool04oooool001_ooooo
00<03`D60147200B20T00`0C2@X09@0B20T04@L800l51P0?1@H04PP901@:2`0A10/06`hD01hB5008
000060`<01050`0B1`D04`L701@82P0D20/04PD<01862P0@1PH04`T800h40`0A1`H03P@301/A400F
30/05`d<00`20@0E2`X06Q0?00/1000B1`P05PX<00X0000F2P`060`>01451`0C1`T00`0B1PP20145
1`0B01@82P0B1PP04PH801<72@0@10H03P8401<72@1;?d405@T;01L;3@0?0`D04PL801<92P0D2P/0
6@l@01P>3`0D2P/04PP90P0A1`P05@0D2P/060h?01/A4P0H3Pl05P`=01L=3P0E2``04`T:01D;300J
41402`4201dC501jL740ETa=01L=3P0E2``08QPI06aRH`0K4A80<RPY00L0000201X@4@0A00X00@0E
2``050X;00T0000L4A@060dA01L<400D2@d04`P<01872`0F2`l040D901<8300F2`l04PL;01L<400F
2`l00P0D2@d00`0I3Q807A8F01`A5@0201@93@805P/?01d05@X>01@:3@0F3A802P@801H@500G4AD0
5Q0D01@>4P0J51P03@L;05I@E03ooOl0NG=g01/E6@15@4H0NWEk01<>500J5A/05a8H01/F700I51X0
5A0F01/F700N6Al05Q4G010;4@0J5A/07APN00d8300201XE6@0501@@4@0M6AX07ATI01/G5P0K5a@0
0P0L61D01`0L6aL0@D0l028Q7`0Y:2H06aXH01lN700J6AL00P0K6QP01P0L6aT07A`J01hL7@0Q7280
8ahU02@O9P808QlV01008B0V020O9@0U9R/09RL/028R:P0Q8BT08R<X02/_;`0O8b808RHU02DY:00Y
;B`09RXY02@X9`0V:RT09b/Z0P0Z;Rd06@0Y;bd0;3Db02L`;`0P:BP0<CXi02lg>@0`>3X0;cLi02hf
>@0Y<C@0;cLj03Q0@`0e?T<0EUmV02/d>`0h@DP0@TaE092JX`1:E5d0>4E>03m;E`0mBUH0>DMB03]9
E00nBe@00P10BU<0100h@T/0<ce603I0B@11Be@203m9D`0A04YDG`16D5`0?dQG03U6E00jB5D0>DMD
03]9EP15Df00BEMR04ECGP0fA4l0CE]T03a:D`16E5d0@4mF045@EP11D5D00P0oCU<09P13DUL0A5=H
04EDF@13DUL0@E1E041?E011D5D0A5=G04UGF00e@d@0@U1A0390@@1=Fe`0CeeN05aZJ`12D540AUAE
04MEEP1=Fe`0BUQI04YJF@10D4d0Be]J04]KF`13De<0MhJ9051OI01?GV<0CUeT04eKI01>G6D0Df5Y
05ARI@1FI6D0BEMH04iLG@1?GEh0@Dm@0`17EEH204ABD`0704IDE019FEP0EFQT051SG`1HJ6D0EfMT
051SG`0205EUHP0B04eMFP1?HUh0Cf9N05][J01_OW/0EVER04iMFP1EI640E6=P04eLF@1BHEh0E6=P
05ETH@1FIF80EfIS05IUHP1CHf80DF5Q0P1>GUh0J@1AH680E6=V04]JG`1AH6H0DF1W04iMI01>G6@0
DV5X04eJH01=Fel0C5YM04]IF@18EUH0AeIC04ACD00oCDh0B5IG04mMH014DEL0?T]A04QFF@11Ce80
>dU<03e;C00f@D<0=3m103]5AP0g@D80<S`m03i7AP0mATD0?TM603a5@P0oB4L0=d0o03Ho?P0i@D<0
=cm103Dm?`0e?D00=Si1038j?@0_=cX0<CTl02hb=@0]<C@0<CDh02T]<00^<CH0@DA902@W;00T9bh0
BdiE030c>P0R9Bh0;Ble02TZ;P0V9b/0:R/_02PY;@0S92P0;2da01hO8`0^;c<0:2T]02HW:`0W:2`0
:R`_02L[;00V:R/0:2`]02L[;00T:2T07R8S02da<P0Z;Rl07b<T02T];P0J7Ql09RP]034a>`0[:cD0
;Rhg024Q:@0e=Cd09bL^02d^<`0/;C407QlS038c=`0T9BT092<Y02LV;P0`;cL08R4Y024P:00T8b/0
>3Lo02HU;@0I61h07ahT024P9P0Y:2d06QPK01XH6@0201lM7P0501`J6`0N71l05aDH01/I700O7B80
0P0J61d02`0R82H0GEQL02l[;00M6AX09B4R01lK700K5aP07a/L01hJ6`0L61T06QHG008071PI0180
:bLX01HB4`0H51D08alP01DA4P0O6a`08AdN01`H6@0I5AH06aLH01XF5`0G4a@07QPJ01<=3`0P6Q`0
:R@V018<3P0H4Q@201`F600Z018<3P0S7Al05@lA01HB4`0^:Bl0A49600h<3`0L6Qd040h@01TG600K
6AX04a8A00d<2P0>3@/04a8?01DD400D3Ph05Q0@01/E5@0E3`l0:28R06QRHP0P6QX0618B044k>`0c
;Bd09b4Q010:2P0N6AH050l<018=2P0I51405A0=01/F4`0G4Pl07QTF01TD4@14?c`050l<020K600J
51@05a4A0P0K5AD0100L5QH08Q`L01XD500I4a<201PB4P0W01TC4`0H51<061HI01hL7`0L6Qd09B<V
01/I700T8RD0GUaO02d[;P0M6ah08b4T01DC5P0F51L05QHH01lM800S8R@05aLI01LE600R8B@05QHH
01dK7P0N7B004A4C01HD5`0A3Q007ATJ01TE5P1;BDX071XK00d=3@0I61T05A<D01HB4`0F3Q405``@
01T=4@0H3@h05`d;00805`d<00/05P`;01D;2P0J40l04PP701471P0F30/050X901H<2P0I3@d05PX:
01@8200201D92@0=01@8200E2@T050P801@8200C1`L050P801D92@0B1PP040@601P<3P0@10H05PX<
01P<3P0201/?4@0K01T=3`0G2`d05@T;01@82P0@10H050P:01X>400G2`d04`L901@82P0B1PP05`/=
01H:300C1`T040@601451`0C1`T04@D701L;3@0A1@L05@T;01451`0@10H05@T;01H:300B1PP04@D7
008050P:00D04@D701P<3P0E2@/060`>00l31@0201@82P804`L90P0B1PP01P0H30`04`L700l30`0H
30`04PL701<71`H04PH600d05@T;01451`0G2`d040H7024G601?ADH0Fe5B00d3100W7Ah040D601P<
3P0:00004`L9008050P:00D03`<50186200J3Q004`L901H:300201D92`0300`00P0H30`050X90080
4`T801D050X901D;300F30d08aTJ01<8300=0PH03`@801052@0>0`L0200101452@0E1``02`0101T8
3P0E1@X04P<80104200B2P/0100000<0000C2`d00P0D20X0400C1`T04PH80186200B1PP05PX<01T=
3`0E2@/03`<501041P0I3Q002@0001L=3P0?1@H050X;00d10`0G2`d201<72@0=0186200A1@L04@D7
0186200<0080304200l31@0=0@<04PH801041P0F2P`0Cd=507eaL`0201451`0K01@61P0C1@D04`D5
0184100C1@D050H600l10@0J30`03P4101L92@0>00004@<301D71P0D1PD050H601<51@0D1PH04`L9
00d3100?1@H05P/?00H0000D2`h03`L900T00@0Q5AT03`D700804@D900T05@T=00X00P0J3Q805PX>
00l31`0B1PX04@D900l31`0@10P00P0A1@T0100@10L03`<501451`0A1@H201451@0301461@0A1PCo
oooo01?ooooo000Kooooo`0401482@0C2`/05`h?00l61`805@`=01L05Pd>01@;300C2P/04PT:01@;
300I3a4050L=01@7300J3Pl06Ph=01D:1P0G3@H050X301P=2@0F2PT04PH801<7300E2@d050X801D;
2@0F30X05@/901<91`0201881P0601<91`0D2PP05@/901@:200D2PT04@D70P0D20X03P0C1`T050P:
01D92`0E2@/050P:01451`0E2@/04@D701L;3@0C1`T05`/=01451`0S5aT05PX<0P0A1@L0;`0E2@/0
5`/=01L;3@0D20X05@X<03hd=@0A1`P0CTA501lE5P0@1`P05@/<01<92P0F30d05@/<020F5`0T6Q/0
60h?01<92P0?1@H050X;01L=3P0D2P/04`T:01T?400<0`@07Q@E01T?400:0@804`T:01/B4P1OEEH0
5`d>02DK700>10D04PP901P>3`0F30d05@/<01P>3`0C2@X05P/>01D:3P0L4AD050T=01T>4P0E2Ph0
5``@00805P/?0P0H3A4201H;3`0601L<400C20`06a0D01H;3`0D2@d05P/?0P0D2@d02@0F2`l05``@
01H<400E314050hB01D?4`0A2`l05@lC01@?4P0201TC5`0402LQ9@1XHVH0>C<g01@>4P805a8H01/0
5Q4G01@?5@0E41H05A0F01XE6`0H4aT040/A03Td>P0H4aT05Q4G01PC6@0K5Q/06QDI01PC5P0O6a`0
71PH01/G5`0K5aH071PG01dI600P71`08A`N01/J6P0R8B408B0O01`J6P0L6aT00P0R8Al0CP0P7ad0
8b8P024P7P0O7Q`08b4R020M900R7bP08AhW01lL8`0O7R@08B0V02<S:00Q8RL08b@X028U:P0P8bL0
7B4S024U900P92<08BDT02<W9P0T:2L09BTX02L[:P0T:2L09b/Z02HZ:@0[;bl08bTY02D^;@0V<2l0
<3Xi02`f=`0[=CH0:38c038l?P0`>S`0;cTk034j?`0e?T<0=Sm403Q2B@0e@4H0;STo03Q2B`0f@d/0
>4E=03U6C`0iAe80>dUD03M5D00iBU@0@4mG04EBF011CU@0=T=:03E2BP0iATl0>TI@03]7D`0hA500
?TYF03U5D@0e@Dd0?T]H04=AGP15Df00@DmL04=AGP13DE`0?deH041>F@13DEX0AeEN04IDG@14DeX0
@U5G049AE080@e9E00<0@U5D04ACEP12DE@00P0oCU43041?DP80@4i?00@0?de>03e;C00oCDh0A59C
0P16E5D204MEEP0X04QFE`1;FEX0@E5@04=CDP15EED0B5QH04eLGP1BHF@0BeYO055PI@1<Ff80Df5Z
04]IHP1CHF/0CE]N04iLG@1@GUl0CE]L04UGF014DU<0BEMH04IDE@15De@0BUQI04]IFP16E5D0EVIU
04mPG01CIV80DVEQ05EYI01;H5/0E6QS059UH@1@Hel0DFAP05AUHP1FIV<0E6=P05]ZI`80D5mL02d0
GVeZ05QWI01BHEh0E6=P055PG@1>GEX0CEaI051OG@1@H5l0C5]M055PH`1BHF@0CeiQ059QI01PKg@0
CeiS04aKH01AH6D0CeiT04YIH01:Eed0BeUM04YHF`16E5@0@U1@045@C@14De00@U1A04ABD`13DE@0
A55G041>DP10CU00@4i?03e;C00jB4T0?4Q803e9B@0h@T<0=d5003U3@P0j@d80>T=003a5@P10BDP0
0P0a>ST06P0i@D<0=Si003a4AP0i@D@0=Si103Q0@`0c>T00:S4g02Ta=@0b=ST0;S8e02/_<P0a=3T0
<3<h038e>`0_<ST0;c8k030c?00_<S/0;C0i02X/<P0X:Bd0:R/_02<T:00];S80=CHj0P0Y:Rh202`]
<@80:BX^00H0:R`_02@X:@0V:R/0:Rh_08>7R00[;c0202<W:00_02X^;`0/<3409RX[02T];P0/;S@0
:2Pb02TY<`0Z:S<08b<[02@T;00Y:C008b@Y02PY;@0Y:Rh092DY03Hg>`0`;cD09B@Z01lN900[:S00
7QdS02@S:@0O7R@07QdS02/Z<00W9Rh08R4Y02DT:`0O7B008AlP03Hd=@1=Bd`05aDF01dK7P0K6A`0
7Q`O020N8`0L6Ql07A/P02DS:01:ADT0:RHW01TE5P0V8R<08AdN01hJ6`0S7b000P0M6AX00`0N6Q/0
6QHG01dI6P0601/G600601LC500N6Q/0Ad=402<O800K5aP05Q8C0P0I4aD201XD5P806aDG100J51H0
400I4aD05a8C03@_=@1THFH04@lB01DB5@0J61X0:2HW01DB4`0E4Q8051<A01DC4@0F5A8061DB01D?
3`0F410201LA4@805Q0@00<05a4A01H@400E3`l00P0F4100200G4A4061<@01PC400G4Pl05Q4>01PC
400I51406aHC0P0I51404`0J5A8061<@01HA3P0J5QD07QXI01PD4`0P71/0:RHU02HR8@0I5A@06QHE
01hJ6@0L61L061@C01PF500K6A`061HI024O8P0H5QT00P0Q7b802P0N71l07adP02@R9@0N71l071XM
01`L7P0K71h07QhP020P8P0N7b4201`M7`0F01HG6@0@4A<06a`N01XK7@0K71h0ATE6028N7`0D4A80
6QTI02XZ:P1TI6@0G5aL01/J6P0D4A805a0B01T@4`0>1@L05`d>01@:2@0K4A005@/:00h40P8060h<
00<050X801D;2P0F30/00P0B20L00`0D20P04`L701<71`0201861P0301@8200@10@04@D500@04`L7
00X03@<401<92P0D2P/04PP901D;300G3@h0718C01L=3P0A1`P04PP90P0E2``0100C1`T04@D701`@
4P0O4aD201<72@0401D92`0C1`T050P:01@82P804`L901P04@D701@82P0C1`T05PX<01<72@0@10H0
4PH801<72@0D20X04`L90186200@10H03`H701D;300?1@H050X;01071`0L4Q<08ALH00l51P0E2``0
4PP901482@0H3Pl201451@804PH60P0C1`L04P0A1@D04PH601861P0M4A406@d=00h30`0F30d050X;
01/A4P0H30h040D604Di>`0J3Q004`L901L;3@0@1PL03@<401D;30H04`L900<050P:01<72@0E2@/0
0P0C1`T06P0C2@T04`T701@:2@0C2@P04PP701D;300F30d03PD601872`0F2`l04`P<00l4200B1`/0
4@H:01452@0C1PX05PL<01D42P0B0PL04`@901862P0A1`X03PP:00`82@0>1PL04@D70P0B1PP201<7
2@0301D92`0F2P`05@T;008050P:00<05`/=01H:300B1PP0100B1PP01`0C1`T040@600d3100?1@H0
40H700l51P0@1@H01P0B1PP03@0C1`T05@T;01D92`0D20X04`L901430`0H2PX04`D500h10@0E1`L0
4`D50184100C1@D00P0F20P04`0E1`L04`D501@61@0F20L05@L701@61P0G2@T04@D701<92P0@1PL0
50T=00l62@0A20/050/>01@8300E2@d050P<01862P0D20`00P0C1`/02P0A1@T05PX>0105200C1`/0
3@<500d21@0A1PT05PX>00`1100E2Pd201D92`0501@82@0C1`L04PH60145100@1@<05?ooool001_o
oooo00<06A0C01D<3`0>1@P00P0C2Pd04`0G3Q40=2/^00`51P0<0`H050/>01H=400<0`H040@801X>
3`0D2@L0304001470@0L4PP06Q0601X@1`0A1P005@X901P<3P0C1`T00P0F30X201L=2`805P`:00@0
40H401471@0A1`D04PP60P0A1`D0100C1`T05`/=01L;3@0D20X20186200;01@82P0C1`T04@D701H:
300@10H05@T;00l31@0H30h04@D701@82P0@10H00P0C1`T201@82P805@T;02003`D602TO800:0040
3@D501hD5@0I3a005P`=01882@0C2@X0308301<92P0I3a0040H701@:2`0F30d050X;01882@0D2P/0
60h?01L=3P0>10D07aDF01061`0O5AH060h?00l51P0700005`d>01882@0J41405`d>01P>3`8040H7
01D06@l@01@:2`0D2@`05P/?01T>4P0H3A40:b0T01T>4P0K41@05``@01H;3`0L4AD07Q<G01T>4P0?
10P06@hB01D:3P0H3A405P/?01@93@0F2`l00P0D2@d03`0F2`l05``@01H<3`0@1``06A<G014;3`0;
1@T04@/?01TC5`0G4AD071HJ00l93@0G4AD04P`@01<=4@0401D@5P805Q4G04D06aHL01PC6@0B3A<0
6A@J01HA5`0I51X06QDK01TD6@0S7R805Q8C01/G5P0M6AH07a/H01`H5P0I5A@06ADF01hI7@0Q7280
7adR01dL8@0M7Al07QhN01hN700M7QT071dH01/L5`0Q8Qd08R8P01hN7@0O7b408AlT028P9`0Q82H0
7ahT020O9@0R8bL08b@X02DY;00V:R/08bLY01lS900O8b808RLR024V8P0R9b<092TU02DY:00V:RT0
8bLV02X^;`0]<C809b//02hb=@0Y;S40:C8d02<];P0M9bP092h_02dg>@0Z=3H0;CLi02hg?00_>3d0
<S]003<l@`0d?D@0B5=I04MBF00b?D<00P0iATh04`0a?TH0=TA=03Q6D@0nCeT0DF9/0352C00jBU00
=dI903Q7C00iB4h0?TaE03a:E@0e@dl0?4YG03Y8D`0hAU00?4YC03Y8D@10CUX00P12D5d05P15Df00
BEMT04ABG@0mBeH0@DmJ04ECG018EUl0AeEN04ACFP11D5D0?Te@03e<C`13DUD0AeII04ACEP17EUT0
?diA03U8B`1GIVT0IgIi049AE00nC4d203m=CP0303i<C@0oCDh0A59C0080B5IG0P17EEH04`18EUL0
BEMH04eMG@1?Gel0CeiQ04MFF@13DUL0AeIK06MfO@1KJW40D5mV059QJ01KJW40EfE]055OHP1AGf00
D5iO04eKG01;FEX00P18EUL08`16E5D0A59C049@D@12D540@e5B055OG`1AHEh0E6AQ055TH01?Heh0
BUmJ04mTG`1;Ge/0BUeI051PG@1CHUl0DV5N06=aL@1EHf<0CeeM059PH01=Fe/0C5YJ04mMG@1AGel0
D5iN04iLG01?GEd0DV1P051PH01:FE`0CEaO051OHP1>GF00CEaO0080CEaQ00/0CeiS04aKH018Ee`0
C5]P04mLHP1:F5`0A59E049@D011Cdl0@U5>04ACD00204ECE00404MEF01CH6H0?D]>03i<CP80=TA5
0100>4I603M3@`0c?cl0=T0o03Q2@@0`>cL0>T=0045:A`0i@Sl0=Sho03e5A`0e?Cl0@TY<038j?@0m
ADP0@TY=0P0j@DL0100c>T009bhf02@[<@0^<CH202d`=@0302HY;P0Q92/0:Rde0080;C0i00/0;c4l
02d_>`0W:CD092H]02DV:P0Z:bl09RL[02h_<`0d=CT09bP/02HW:`0202TZ;P0^02HW:`0U9RX092HY
02L[;00R9RL0:Bd^020T9@0X;2d07b<T02P/;@0[;c0092PY02/_<00Z;Rl09BL]02TY<`0Z:S@0;2`e
02LW;`0X:300:R/a02X[<00Z:bl09BHZ02@U:@0X:Bd092<X02/[;@0P7b@0<2ld020O900Z:Bh09B@Z
01/J800Y:2h0<C0h02`[<`0S8RT07A/P01lM801_KG00VINJ03/i?00K6A`06ALJ01`J7@8081hQ00h0
71XM01LE600B3Pl05Q8C01lK700L61T05a<D01lK7014@4409b<T01/G600S7b006ADF028N7`H06aLH
00H06QHG018>3`0Y9BH07ATJ01HB4`0P71d201PB50806A<E0P0J51H201TC5@0@01XD5P0I4aD0618D
01LA4`0F3aH050hC01/F6P0H4QH04@/>02@P8@0J51H06A@E01LC4P0H4Q8061@B01TD4@<05@l?00H0
50h>018<300A2`/05a4A01H@400E3`l201H@400301LA4@0H4a0061<@00806A@A00<061<@01LB3`0K
5Q<00P0J5A802`0L5a@06A@A01LB3`0@3@`04A0>01HE4`0W9R@09B@R01HE4`0J6AL06APF008071/I
00P06aXH01hM6`0N7B005QHH01DE5`0C4aD0:2PZ024Q8`809BDW00@08R8T02HV:00V9RP08R8U0`0M
8B@301`P8`0C01TM800N8RD0720S01PL7`0L82<08R4S020L7@0R82406APH06][J`3Adm80/K:b01dM
7@0@3Pl03PT;01P?4P0O51P05P`>01`B4`0201D;2P0501lE4`0C2PH05Pd801<:1@0B20H00P0A1`H0
0`0L4Q<05@T901D92@0201D92@0501H:2P0H30`04`L701<71`0D20P00P0C1`L04`0B1PH050X;01H<
3@0D2P/05@/<01T?400F30d03P@50147200E2``050X;0147200?1@H06Ph@01451`0?0`D04`L90104
1P0E2@/00P0D20X01@0C1`T05@T;01H:300C1`T07A4C00805PX<00@0300201@82P0C1`T04PH80`0C
1`T0100B1PP04@D701@:2`0@1PL201@:2`0801`C4`2KTI80]jf^02dS900E2``09A/L01T?400G3@h2
01451@804PH60P0C1`L04P0>0P804`L701D92@0J3Ph060`<01861P0:0P808QPI00h41@0=0`@05PL:
01D62@0D1@P06@d?028F600I3a003PD601<92PH04`L;01l091PL02/O8`0J3Q802`43020D600J3Q00
3`D301@:2@0E2`X04`T80147200B20T07aDF01H;3`0?10P0304501872`0E2Ph04PL;01452@0C1PX0
5@H;01@32@0C0`T04`@90104200?1@P030H800`82@0@20T04`L900<04PH800P04@D701041P0@10H0
4@D701041P0A1@L050P:01H92P8050H600L04`H601861P0B1PH040D400l5100A1`H040L600803`L5
00<04PL70186200B1PP00`0B1PP00`0?0`D040@601451`0201451`0301041P0C1@D04`D500804`D5
00@050H601D71`0D1PH05@L70`0F20P0500E1`L03P0001@61@0F20P04@<301<51@0B1PP060h?00L0
000@1@T01P0001H=400?1PT040@801@8300F2Ph040@800h21P0C1`/060`@0P0>0PH02`0;00<050P<
01452@0R5QX05`/?01hB5P0@10P04PH900P0000B1PP04PH700804PH600<04@H501461?ooool04ooo
ool001_ooooo01T060lB01482`0B2@`02`8501H=400Q61/0=Rd`01D<3`0H3a803`H901072P0G3Q40
40H701H;2P0A1P804@L001P>0`0G3P0060l001/A1P0E2`805``901H:2P0=0@405@/900805P`:0`0G
3@/0100C2@L050X801@:200D2PP201<91`0>01@82@0I3@l06@d?01D92`0A1@L040@601L;3@0@10H0
300201@82P0B1PP060`>01@82P0G2`d301<72@805@T;0P0C1`T04@0D20X05@T;01H;300:00404`T:
01P>3`0J41405P`=00l51P0D2P/06a4B00l51P0@1PL05`d>01061`0D2P/05`d>00804`T:0P0D2P/0
5P0J4140200001hD5@0?1@H0718C00d3100O5AH040H701@;300<0P<06a4B0147200H3Pl05P`=01L=
3P0J41404PP901@9300=0PH04`P<028G6`0c:2`201P=4@0701<8300A1PX060dA01/@500F2`l03P<7
01X?4`0201@93@0901D:3P0D2@d05@X>01@93@0E2Ph05``@01P=4@0F30l03PD:008050hB00T08A/O
02XT:01<ATX03@L;01LA5@0P6Qh06A<G01XD600G4AD00P0D3aD03`0F4AL05a8H01LB600G4QP05Q4G
01XE6`0O6R0050lE01TD6P0F4AL08QdS01PC600S7b005a<B01`H5P0201dI5P0I01`H5P0J5QL06aHJ
01dH7@0L6B007Q/R01dL8P0L6b0071`N01/K6@0J6aH07b0K01/L5`0M7QT07alM020P7`0S8bD08R0U
02<Q:00R8BL081lU028R9P0T9BT08B8U02L[;00202``;`03028V9@0L8Ad092TS008092TU02d09R/W
02P/:`0X;2/09RXY02P/;@0Z;Rl09RX[02hb=@0Y;S40:S<d02dg>00V<340=d5202li>`0Q:bd0:S@f
02df>`0_>3d0<S]003<l@`0b?D<0?DQ>041;D@0d?dD0>4E=03M4C00d@DT0>TQA04=DGP0jBeD0L86;
041AF`0lC5<0>dY=03]:C`0lBe40@4iG03a:E@0e@dl0?D]H03Q6D`0nC5H0D5iW04UGH015Ded00`18
EV<02@14DUl0?D]F03]9E012D5/0AUAM04UGH017EEh0@e9I049AE@02049AE00404EDE`14DeH0@4mB
03e<C`80>TU<00D0A5=F04UHF`10Ce80?de>041>C`02045?D003049@D@16E5D0B5IG0080AeEF0P16
E5D02017EEH0?Te@03]:C`0mC540@e9G04MFF`1AH6D0EFA[0P14DeX02@1FIF`0MXF<07b;TP1BH6<0
DEmP04iLG@1<FU/0BeUJ04YHF@0204ECE00F04=ADP11Ce00@e5B04QFEP1=Fe/0DV5N04mOG01AHEh0
C61K04iSGP1=HUd0B5aH04YJE`1?Ge`0Df9O051OG01EHf<0B5IF04eKF`1JJ6P0CeeM05ARHP80D5iN
01L0CeeM04iLG01?GEd0D5iO04iMH01:FE`0C5]N059QI01CHVD0D5mR04UHG@1:FEh0CEaQ04YIGP17
EU/0CUeR04aIG`1>G600@e5D03Q6AP11Cdl0C5]H03m>B`0204IDE@0<03M5B015DUP0>4I903e;C00g
ADH0=TA503I4A00e@D40<clo02Pb<@0jAD40?4M30`0kA4407`0d?Cd0?4A603<k?@1:DU@0@DU<034i
?00oAdX0>T5703U0AP0`=cd0:2lg02Xa=`0`<cT09BP]03Lj?`0[;S<092L^02X]=@0Z;CH0:bhg030b
?@0_<Cd0:B/g02HX;`0X:Bd0;2da02TZ;P0/;C40;c0d02HW:`0Y:Rh00P0/;C400`0Y:Rh0:2T]02DW
:P0202L[;00i02P/;@0B5QL0;C4b02DY:P0V:R/08RHW024U9P0X;2d0:Bd^02PZ;`0Y:C<0:RXd02d]
=P0Y:C40:b/c02//<P0/;C80;2da02TZ;P0/;C40:b``02PX:P0W9bT09RHX024P9@0K6Ql0>cXo02HU
:`0H5ad07ahT02@S:`0U92`08R4X01/I7P0R82D09B<W02XX;@0H5QT071XM01dK7P0K6A`06QPK01`J
7@0M6a`06aTJ02@P8@0S7b007QXK01/G600M6AX06aLH034];P0O6a`071PI02DQ8P0M6AX071PI00H0
6QHG00<05A4B01dI6P0@30d00P0O6a`00`0E4A806A<E01TC5@0401XD5P0>01PB500I4aD06A<E01TC
5@0H4Q@05a4C02@M900L5A/050hB01H@500D3Q405Q0B01XD5P0I4a@201LA4@0301LB400G4Pl05Q0@
00805a4A00H05Q0@01@>3P0D3Ph05a4A01H@400E3`l201H@400E01LA4@0G4Pl061<@01XE4P0K5Q<0
61<@01HA3P0J5A806A@A01XE4P0K5Q<06A@A01HB3`0H5Q@06aXH024P7P0];2X08R4O018A3`0J6AL0
61LE008071/I00<07A`J024P7P0I6A/00P0S8bD00`0G5aT0;Bd_01LG6@0201dM7`0501PH6P0R8R@0
9BDW01lR900O8bH00P0N8RD06P0O8bH082@W01lS9P0R9RT0;c<f01lS9P0F6Qd07B4T01`L7P0D4Q<0
7Q`M01`L700b<S80LG=b06a]K00?3`l04a4B01XE5P0H3a8060dA01H<3P0M4a@04@L801P>300_9B<0
6Q4<0P0D2`H02`0F30X05@/:01H<2`0U6a`04PH601451@0B1PH04`L701D92@0G2`/050P800805@T9
00<050P801<71`0B1PH00P0F30d0100C2@X050X;01L=3P0B20T201lE5P0E01T?400@1PL03`D601@:
2`0H30h04PH801@82P0J3Q005PX<01<72@0H30h05`/=01<72@0D20X05@T;00h2100V6Q`03`<50186
200G2`d040D600H04`L900d04PH801061`0D2P/040H701882@0]8b@0`[Ri0=_AdP0d:R/02@0001T?
400A1`P0308300804@D50P0B1PH201<71`0B00l30`0B1PH04@D501451@0B1PH04@L601492P0N51D0
4@L801451`0L3A003@0101D62@0Q4QD09a/M01dC500A20T04`X;1P0C1`/01`29OH40XiNK01lC5`0I
3A407a<G00P0000@1PD00P0D2PT01@0C2@P04PP901<92P0>1@H06PlC00803`@800h05@X>01052@0B
1`/04PH:01<62P0D1@X050<901D52P0C10T04@D901882`0=1`T030P901492`804`L900X04PH80145
1`0A1@L04@D701<72@0B1PP040@600h2100?0`D04`H70`0D1PH201861P0701871`0D2PT05@/:0148
1`0>1P@04@T701<:2@06018620D04`L900D05PP80184100C1@D050H601430`0201@61PD05@L70200
4P@301X<2`0K3@d04`D501@61P0D20X0718C01<92P0Q5QX06A0C01P?4P0?1PT05@T=01<72`0B1PX0
40@801452@0G2`l03P8601T=4@0M4AD03@4500l41`0G2`l03P860106200A1@T02@0101472@0E2@/0
4@D701451P804@D500<04PL601871Oooool04oooool001_ooooo00@03@L9010:300_:B/02P@60P0C
3@l0500H4Q@05@lA00`6200;1@L04P`>01082@0B20P050T701@:100H3PD0:R4@03`c800a:AL07QD5
01H<0@0K40X05`/:01871P0E2`L050/60P0C2PD301@;1P<05@`700<04`X501<91`0G2``00P0J3Q00
1`0F2P`04PH80186200C1`T050P:01H:300L41800P0@10H0200G2`d03@<401<72@0D20X05PX<0145
1`0F2P`050P:0P0C1`T01P0E2@/05@X<00`3100I3a006A0A01X@4@805@/<01X04@L801P>3`0G3@h0
718C01X@4@0<0`@05@/<01L=3P0B20T05@/<01@:2`0?1PL06@l@01061`0H3Pl04`T:01882@0F30d0
4PP901H<3@0A20T081HG01H<3@0D2P/07aDF01dC508050X;01<05@/<02HL7P0I3Q805P/?01<8300B
1`/05@X>01H;3`0C20`04@H:01@93@0F2`l05@X>01P=4@0M4QH06@hB01hC5`0K41@06@hB00805@X>
01805P/?01T>4P0I3Q805P`?01P?500B31005@lC01PB5P0<1`X071HJ01PB5P0B31005@lC00`62P0C
3A40618F01@?5@0E41H301PC6@1Z01LB600I51X05a8H01`G7@0K5Q`061<I01XE6`0M61h05A0E01DA
4P0F4Q407Q/H01hK5P0I5A806aLE01hJ6`0O6Qh07APN01PE7@0L6B<07ahV01dL8@0H61X05QHD01TJ
5@0L7AL071dH02HW8P0Y:BL08R8Q01`L7P0Q82D08b8W028Q9P0Q82D08R<V02DW9`0Q9R@07B8O020U
800V;BL09B/V024X8@0S:2808RLQ02<X8P0T:BD09RXY02L[:P0f>ST0:Bd^02L[;00W:bh0;S8e02H[
;P0X<c<0<3`l01dY:@0]>3X0:SDg034l?P0Z=CT0;3Lk02hi?@0`>d40<Ca2038m@`0`?480<Ci403I3
B@0gA4`0<3m603i=E00nC5D0>DYD03I7D@1KK7H0<dE?03];D00mCDd0>TU<03Q7C@0mBe@0?4YF03Q5
E016Df80@e5N03e;EP1;FF80EVE/05=QJ`15Df00BEMT04MEHP0mBeP0>TQC03m=F013DE`0AUAM04ME
GP14DU/0@U5H03m>DP13De<0AUIF04ADE080@51@00P0A5AD041@D00jBTX0?Ti>04ADE010D500?D]<
03m=CP80@Dm@00@0@U1A04ECE017EEH0AUAE0`15De@04016E5H0IgIl05=RJP13DEX0BEQP04aKH`1?
GVD0BUUP04mNI01FIFX0AUEJ04]JG`1CHVL0D5iP04mMGP1=Fe`404aJF`0?04]IFP18EUL0AUAE04ME
EP1:EeP0FVEU05eXIP1>FeT0E6=P04ULF01?I5l0CF9M04]NFP1<G5T0CeeJ0080DeiL00P0CeaL08VG
U`1LJVX0CE]K05=QH@1:F5P0E69R055OG`80CUaL00T0CE]K04]IFP1<Fel0CEaQ04]JG`1<Ff00CUeR
04]JG`1?GV400P18EeX08P1:FE`0BEQK04]JG@19EU`0AE=G04IDE`19EeP0A59B03m>B`10Cd`0?D]<
045?D00oCE00?daB03a:C@0jB4T0?4Y:03U7A`0c@D40=T9003Q4@P1DGUd0=3lk03U4@00h@Ch0<S/f
03U2?`0h@440<SXl03Q0@P0e?D00>4130418B`0c>T0203Dl@P0:02`c>`0^=Cd0=Se3030c>@0a=3T0
>Ca102X]=00^<CP0;c8j030c?080<C<o04X0;Blk02PZ=P0W:C009RL[02`]<@0[;300;2da030a=@0Y
:Rh0:b``02`]<@0Z:bl0:BX^02X[;`0X:Rd08RHW02da<P0P92D0;C4b02P/;@0S9bP07b<T020T9@0c
=cP0:Rh_02DY:P0[;C<0:2Pb02XZ=00];CH0:BTa02XZ<P0^;cD0;Bhc02X[;`0[;300;Bhb02TZ;P0[
:b`05ADE02PX:00N7R008b<U03He>P0P7bD07A`R028Q9`0K6R808b8Z01HE7@0S82P0:2D]02DR:@0R
7bH081dS02<Q9P0N71l07Q`N01hM7@0N71`07A`I01/J5`0I5AD071PI01/G600J5QL07ATJ01`H6@0H
51D07QXK01`H6@0I5AH081`M01/G60H06QHG00H07ATJ01PD5@0R7Ql0920Q01TE5P0F4Q<401/E5`80
6Q@F01D05a4C01PB500I4aD06A<E01PB500G4A<06a4I01dC6P0?1P/09QdR01D<400I41<06Q4D01T@
4P0H3a005`h?01L?3P0G3`d050h>01D?3`0F4100100G4A406@0F41005@l?01H@400F41005a4A01PC
400F4@h061<@01/F4`0H4a005A0=01PC400G4Pl061<@01XE4P0I51405Q8?01dJ6@0F5A<051<A01TH
5P0L6aT06aXH01TH5P0G5Q@00`0K6QP01@0O7Q`07AdO00`<3P0P82807alQ0080820R0P0U9BL0:00T
92H0;Rh`03<c=@0/;c409R/^02@Y;00P9BP07R<V01lT9`0L8B@09R/^03Dj?@0T:B`06QlR028W:P0N
82807A/L028Q8@0J6QX07AlN02DW9P0M7ah051DE01@B4`0I5AH06aDG00X1100F31006@lA01882@0G
3@/0:AlL01XA2`0D2`@050/501L=2`0D2PX040H701P=400C1`P201861P0301<71`0E2@T05`/;0080
5@T90P0F2PX00`0E2@T050P80147200201482@0:01@;300J4A8060l@01@;300E30d04`X;01482@0B
2@X06A0A01H:30804`L90P0F2P`03P0D20X05PX<01H:300A1@L05PX<01/?4@0B1PP05@T;03<W:@0<
0P<05PX<01451`0?0`D050P:0`0C1`T03P0E2@/050T;0147200D2``02P4201482@0C2`/0:R4R044h
>@0E3@h05@`=01<:2`0B2P/04`T:0P0A1@D201861P804`L701805@T901<71`0B1PH04`L701X>3P0O
5A@0F51@00h51P0;0@804@@601X:3@0G1`X05@D801P9300I3@l050X;00d51P0>1@H601<72`0N02dQ
9@0Q5AT02`4301@9300E2`d060`>01D;2@0D2PT04`T801881`0F30d060h?04@j>`0A20X03`@80187
2`0=0PH04`P<01872`0D20`050H;01<42@0D0`T05@D;01011P0?0`L050X=00/51`091@H04@T;0P0C
1`T2018620804@D700H04PH801<72@0A1@L040@601451`0D1`P201D51P0:01D61P0D1PH04PH601@9
2@0E2`X04@T700d50`0;0`403PT601<:2@D04PH80P0C1`T30186200301<72@0E1`L04`D500804`D5
00<04P@401<51@0D1PH0100C1@D0100D1PH05PP701`>3@0L3Ph201@61P0K0186200?1@H07Q@E00`3
1@0=10L08aXM0:NNX@0W6al060`@00h21P0B1PX04@D901<72`0A1`T06`lC02HJ7P0K3a<050P<00/0
0`0L41@0:QhR0105200D20`050T;0187200A1@L04@D600804@D500<04@H501461?ooool04oooool0
01_ooooo00<04`d?01LA4`0i<cD00P0C3@l05`0?2@/03PP:06IPHP0i<cD04`d?00d72@0Q61T02@00
02PM600V718030<0048j9`2m]Ih0Z:2;04Y1;P0J4@80718:01D:1P0G30P05Pd801<:1@0B2@@040L2
00804@P3100C2PD00`0A20<040H401L;300201T=3`0@01H:300E2@/05@T;01L;3@0J3Q007Q8D02DI
6`0E2@/04PH801@82P0800005@T;01<72@0G2`d03`<501H:308050P:0P0C1`T0:P0F2``05`d>01hD
5@0G3@h05P`=01T?400?1PL09adN03P^;`0P5QL03`D601P>3`0C2@X06a4B020F5`0D2P/04`T:01@:
2`0E2``03@<404To@00[8B805P`=01D;300?1@H01`0001T?400B20T02@000147200L4Q<09A/L01hD
5@0D2P/05P`=01X@4@0b9bX07a@H01462P0F2`l07A8F01872`806PlC00<060dA01@93@0C20`00P0H
3A401@0D2@d06PlC02`Q9@0N4aL04PL;00805@X>01805``@01X?4`0J3a<05P`?01483@0D3Q805a4E
018<400?2@d02P@801D?4`0K5AT06A<G01<=4@0L5QX050hB01D@5P0G4QP201TD6P0=01HA5`0D3aD0
71LM01<>500E41H0=S4g01HA5`0M61h05A0F02HQ9@0@30d061@C01LC3`0201LD3`0N01TE4`0L61T0
7QTM01dH7`0J5b007AXU01`K900L6b406aXO01/K6P0K71L07AhH01`M5`0U9R40:BTW020P7`0H61X0
7ahS024P9@0Q8B<07b0R024R900U9bH08bPU028W8`0N8ad072<K024X800V;BD08bPQ0P0S:280400U
:RH09b`X02L[:P0]<C409BTZ02HZ:`0X;2l0=CPm030e>@0V<C40=41003U5A@1LIfT0;3Lk020[;`0^
>Cd202dh?P0P02lj@00a?480<ci403A1A`0b?dD0<3e303A1B@0gATd0AUEL045BFP0gB580@59L03]=
E`0bA4h0>DY?03];B`0lBdh0=dI<03U7D00jB5D0>4ID049?G`12D5d0?D]F03Y8D@13DUT0BUQQ03U7
E00lBUL0@U1M03i<F@0oCEP204ABG@80@e5J00<0@4iG03m>E@0oCU801@0oCdl0300iBDT0?4a<04EE
E@0lC4`0<41003];B`0nC4d0@Dm@04ABD`15De@0AUAE04QFE`<0AUAE00l0AeEF04QFE`1:F5X0IgEn
051NJ@0nC5P0@e5L04ABF`19Eel0I7=j05e/L@1;FUh0CeiQ04iMH01?Gf00101?GEh204iLG@03059P
H@1?GEh0C5YK0080C5YK01H0BEIF05INH01JHf80BUID05UXI@17FED0B5]G04]NFP1?H5d0CUeJ04]G
E@1>EeH0E5eL05EQH@2>W9d0FVQY055OH01HIVL0CUaM05=QHP1?GEh0CE]L0P1>G5d02@1;FEX0CUeR
05ETJP1>GF80BEQM04YIGP19F5d0CeiQ04UHF`0204YIG00j04ADE@14DeH0B5EK03m=D@12D5<0CeeN
04]IF@13DTl0BUUF051NG`0e@d@0>DM:030m@`0c@D@0=D=403A2@P0c@D40<T1003A0?P0e@Cl0GFQT
030k=`0_>SH0=Slj034j=@0c?3T0<c`l0418BP0j@T@0D5QK03@k@@12BDl0>D16034h@00`=cl0:c8j
02T`>00/<cT0>Ca204I9D024Qhh0<C@k02LZ<`0l?dP0=CQ103HhA00`<Sh09RPd02DW<`0Y:c809BHZ
02X[;`0/;C40:b``030a=@0[;300:R/_02PY;@809BHZ03d0:BX^02X];`0P92D0;S8c01lS900]<C80
;c<d02<W:00Q9BH09BTZ038f=`0X;2d08bLX02PZ<00V9S00:2Pb02XZ<`0U9Bd09bL_038c>@0/;C80
9RL[02TZ;P0V9b/09RLZ020P800b<S00>CTi02DU9@0B4Q80820R01PG700N7B8081lU01XI8@0d<c/0
61LO01lL9`0W92l06QLQ00h;500O72<081hS01/I700M6a`07adM01/J5P0J6A@07ahI01XF5@0M6AX0
8QhO01hJ6`0H51D06ADF01XF5`0N6Q/071PI01HB4`0K5aP07QXK00H06ADF00H07ATJ01PD5@0_:b`0
IF5R01hJ6`0I5AH201TC5@80618D0P0G4A<00`0E3a405a4C01PB500301PB500801H<500D2A007A8H
02DJ800J3a@07Q<G01T>4P0I3Q4201P>3`0401X@400I4@l05Q0@01H@40805a4A0P0F41000`0G4A40
5Q0@01D?3`0201H@400?01LA4@0G4Pl04Pd:01<>2`0H4a005a8?01<>2`0H4a005a8?01TD4@0K5Q<0
6QDB01LC400D4Q006APF00807ahL00h061LE01DD4P0I61H06APF01dL6P0L6aT061LE01/J600G5aT0
=SHh05eMG`0`<380:b/]01`L7P807AdO0P0R8R@02@0U9BL0:B`^02P]<@0V:bl092T]028W:`0Q9RX0
82DY02H[;`0202DZ;P0L02@Y;@0P9BT0=3Hh024O800B4Q808b@T014C4P0?4a806QdL01HH5`0V92D0
5Q8C01TC5@0G3Q406@lD01H;3`0I3a0050X901480`0E30H04`X301480@0D2PP05`d>01H<3@0J3a<0
5PX<01H:2P805@T900`05PX:01L;2`0D20P05@T901H:2P0G2`/05PX:01H;2P0A1`P050/<01892P0>
1@H200l61`0601482@0@1`P04PT:01892P0@1`P030<40P0D20X00`0@10H03@4300l31@0201D92`0M
01L;3@0C1`T06`lA02DI6`0I3@l081@F04Tm?`0H30h05PX<01L;3@0A1@L050P:01<72@0B1PP04`L9
01D92`0E2``081HG00d51@0A20T0200001<:2`0N5AH05Pd>00`3100;0P<02P4201892P0600000P0A
1@D201861P804`L701805@T900l30`0B1PH04`L701@8200I3`h04P/<01H=3P0X7Ql05PP;00/0000A
00806@L;01<41`0B1PP05P`=018<300@1`P601<72`0O01872P0C1`/07a<G00h21P0K3a<05`/=01<9
1`0D2PT04`T801881`0D2P/05P`=01H>3P07000040D901T>4P0<0@D04@H:01872`0E2@d04`H:0142
1`0D0`T06@T?01<42@0>0PH04PP;00X41P0<20T04`/=01451`030186200301<72@0A1@L040@60080
4PH800<040@601451`0D1PL00P0E1@D01`0E1PD050H501871@0B20H040H400h60`0?2@D00P0@2`L0
0`0A20P04PH8018620040186200U01451`0@10H03`<501041P0B1PP0408201H8200D1PH04`D501/=
3@0J30`05@L701@61P0C1@D04P@401<51@0E1`L04P@301H81`0E1`L04`D501D71`0A1@L01`0001D;
300E2Ph050/>0189301TFeh08aLK01D93@0@10P050P<00l31`0B1PX07a<G00d21@0200P0000:01@8
300B1PX02P0204/o@`0[7b<04@D900l51P0?0`D04PH801861`8040@400<03`@300h30Oooool04ooo
ool001_ooooo01/060lB01492`0U71l030<600l82@0F3A004PT<07U`L`0n=CP06a8E01092P0B2@X0
5P`;01dB3`0T6Q409A/?081hIP3oonX0oo[U079YE`0Q5`/06a4:00l40P0B1`D060h<01@:2@0B20H0
0`0@1P@401@:200501881P0A1`D060`=01T=3`0H30h00P0F2P`01P0G2`d060`>01041P0?0`D06Ph@
0186208050P:00D02P0001T=3`0B1`P060`>01<72@0201D92`8050P:01804`L901872@0^92D02P01
01@;2`0C2@X03@<401T?400D2P/07Q@E01D;300C2@X06@l@00l51P0O5AH0:1hO01H<3@0@1PL201D;
300S030V9`3?aLH0OgEf0147200B20T04@L801L=3P0R61T0718C00l51P0M4a@03@@501X@4@0F30d0
4PP901@:2`0A1`P04`P;01462P0H3A004@L801X@4@0E2``06Q0A01`B4`0K41@04`P<01872`0I3Q80
6a0D01@93@0Q5QX0>Rlc02@I7@0B1`/00P0E2Ph0@@0G31006PlC01T@4`0E2`l050/@01dG6`0H41D0
3PD:01lI7@0J4QL02`8701dG6`0E3A803@@901`F6P0E3A805a0G01PA600K51/06Q<J01LA5`0C3Q@0
6A@J01@?5@0K5Q`0CdY@01PC6P0J5A`08A`R04<n@`0Q7Ah09B4P01TF4P0I5Q4061D@01TE4`0J5QL0
6aHL01hH8@0M6R<07a`W01TH8@0J6Al0820R028R800L7AP09bPR01/L5`0J6QP07QhN01hN800O7R<0
7QdR020O900P82807b0R024R900T9RD08RLT030e<@0]<R`07R@N01hS7@0T:B<0:2`V0080:B/V02d0
:RdZ02`^:`0[;bh08bLX02L[;00]<C80<CDh04A7C014BDd0;CLi02La<`0H8bD0=T5402Xe>@0oBTh0
<3/o02dh?P0/=cd0;STo034l@P0a?T@0=T=903E2B00X=C/0<Sm703m>E@19Ef00?DiG03m@FP0oCe`0
?4iJ04=CH00iBDl0@51@049AE00kBU00>4I?03Q6D@0hAU@0=dEB03I4D@15Ded0?deF0350A`0hAe00
0P0e@e006010CU/0@DmJ03m=F013DEX0A59K049@F@10CUL0?deF03m>E@12DEH0?diA03]:C@0lBdh0
?Ti>03]:C@0mCDd0>d];03I6AP0lC4`0@U9B03Y:BP0iAdP0?4Y;041>C`80@Dm@01D0A59C04MEEP17
EEP0B5II04UGFP1:F5/0CEYO07>1S01OKGX0CE]X04aJI@18EV40CE]T04ACFP1CHVT0Df9W05UXK@19
F5d0CeiQ04mMH01@GV400P1AGf809P1@GV40D5iP051NH@1<FU/0BUQI04mMGP1AGf00BeQH04I?CP1?
F5L0AE5?05UXI@18Ee@0AeMD04]KF01AH5d0CUeJ04UED`1:E5<0DeaK05MSH`1@GUh0@e5A05]YJ@1:
F5T0C5YK055OH01=Fe`0C5YK04iLG@1@GUl0CE]N04EDF@1@GfD0BUUN04=BE`16EEX0B5ML0P1;FUd0
9@1=G5l0BEQK045@DP10D500AUAG04QCE`10Bdl0@4]=059NGP1OJfT0Kg]k08^FV01@Fed0?dY>03Q3
A`13CU80=40o02hj>00_>cT0=40n03@n?@0a?3P0<Sdi03Ho?00g@3d0=Slk03@m>P0c?3T0=d1105eU
I`0mAdP0Ri>F051GG@0f?D<0<STo02H]=@0Z<CT00P0c>T803P0d>440=CPm01hO9015B4l08bH]02P[
=00_<S/0<SDn03Dg@`0]<C`092Pa02HZ<`0]<3H0:2T]0P0[;3004@0X:Bd0;Bhb02//<00[;300:2T]
02@U:@0V9b/0:b``02`_<@0R9RL0<3@e02P/;@0Q9BH0?d=402/_<00V:R/08bLX00808BDV034092PY
02LY;P0V9Rh09bLa02PX<00T92`09BD]03<d>P0Z:c0092DY02//<00U9RX0:BX^01TI6`0f=SH07AdO
030`<P0L71h06aXO01hM8P0S8RP07A`R01lN9P18Adl0;B`d020M:00H5B009B8[02HS:P0L6B006ALK
01/I700K6AX05aDE018A3@0H5a<0:RTU02LS900K5aP05a<D01lK700M6AX06aLH01TE5P0E4A8071PI
01lK700G4a@06aLH00H06ADF00H0<2`]01/G600I5AH0;BTZ01HB4`0L61T201LA4`0601H@4P0E3a40
5@lA01@>400E3a405Q0B100H4Q@02P0Q61d0718G01/B5`0;00H07Q@H01482`0I3Q806@lA01P?400J
414201/B4`0401/E5P0K5AL06Q@D01XD5@<05a4A01D05Q0@01D?3`0F41005Q0@01LA4@0H4Q4040/8
014<2@0G4Pl05Q4>01<>2P0I514061<@01TE4P0L5aL06aDE01PD4`0M71X05QDC01LF500L6aT00P0K
6QP0300J61T06aTJ01lM7P0M6a`061HG01TG600N7R003Ph@03`l?P0V9RP06a/M02XZ;P808b@X02X0
:R/_02@U:@0U9RX09bX^02<X;00T:Bl09R/`02L/<00X;C<0:Bhc02T^<P0L8BL092T^02H[;`0I7R@0
92DZ02@T9P0M7Al07QlQ01lQ800M7ah061TH024Q8@1ACe00:RDW01<:2`0M51L05Pd@01<:3@0N51D0
5P`<00T0000H3`X07A@?01L>2@0C2@P04`T:01061`0A1PX05PX<01H:2P0E2@T201@8200301D92@0D
20P050P800@05`/;00l03@<401892P0E30d04`T:01D<3@0J41405@/<01482@0?1PL050X;01D<3@0D
2P/03P@501882@0E2@/00P0@10H05`0C1`T04@D70186200<008050P:01hB500?0`D060`>01H<3@0<
00805`/=0187200E2@/050P:01<72@0B1PP04`L901D92`0G2`d0DdU:00l51P0K4A804PP900803`D6
00P02`4201H<3@0G3@h02`4201482@0F30/04@D501461@804PH60P0C1`L0500L410050P801L;2`0D
20P03P820104100>1@<040H501861P0E20X05PH901L72P0F1@X03`0300l31@0G3Ph05`l=01482@0C
1``04`H=100C1`/02P0@10P03P8600h21P0G2a002P0401@8300?1@@050X901D;2P0C2@P201882@0B
00h61P0L4AD04PL;00d21P0B1`/03`@901873@0E20l04`D<01422@0C10/07@hC01T:3`0@10P04PP;
00h5200C3@l060lA0P0A1@L00`0B1PP04`L901<72@0201<72@0A01@82P0A1@L03@4300d10`0A10D0
5@D501D51P0E1PH050H501861P0B1PD03`D301471P0H3`d06a<@01P@3P0C2@T01@0B1PP04`0C1`T0
4PH801041P0?0`D040@601<72@0=00005`T901D71`0D1PH08A<C020B4P0G2@T05PP801@61P0C1@D0
50H601L92@0@0P800P0C1@D04`0D1PH060X:01<72@0[7b405`d>01052@0C20`03P<701L<400E2@d0
3@4501452@0F2Ph040@801L;3`0=0@D04PH:01X>4P0A1@T00P0D20`0300G2`l0PGEi05]?D`0D20`0
308401X>400C1`T04PH80104100?0`D03P8200d10ACooooo000Kooooo`0T01461`0A1`P04@H70187
200D2@X0=b`^020E5P0F2`d05``=01H;300C2@X0:1dN05M:D00l<3806Pl<02HK501[HED0dLbl0<k5
]@0n=2P09AXC01461@0I3A003`@9038W;@0]92X060lD01072`0D2`l03PD901<:300=1PL060lA0108
1`0<1@@040L71P0E2@T01`0B1PH04`L701@8200B1PH04`L701D92@0C1`L00`0E2@T201<71`0601@8
200<0P8060`<01@8200A1@D050P80P0E2@T0100G30`081@D01H:2P0D20P201<71`0401861P0C1`L0
4`L701882@804`X=02D04PT<01<:3@090@<05Pd@01D<3`1=A4L0<BP[01<:3@0F3A004PL901P<3P0a
9BL05@T;01041P0D20X05PX<01041P0I3@l07A4C01@82P0F2P`05P/<01H<3@0G3@`05P`;01D;2P0C
2PH050X801@:2@0F30d05@X?01@93`0C20h05PX>01T=3`0H30h060h?00807A<D00P04@P901/B4`0D
2``0614A01H@400F3a005@/@01T?5`806@hF03T0718J01P=5@0C210091XR01P=5@13>400>Rlg01T>
5P0H3AL06@hG01/A6@0L4aP071@H01XC5P0K5AT06Q@I01PC6@0G4QX0618N01TC7P0J4AX08APO024J
700L5QL071LD020K5`0J5Q<06aPG01PF600G5AX06QLP01`I8P0M6R4071TN01XH6P0I5aP06aXG01lN
6@0K6QH08R0O01dK7@0M6al08b4Y020O9`0P7bH07QlS024R9P0N7b<0:R/]02DV:00/;Bh09RPW028T
8P0Q924092HT02DW9@0W9bD00P0T92803@0U9RD0:BTY02X[:`0Y:R`0:2`_02HZ;@0]<C@0<CDh02db
=P0[<SP0:c8i02/c>P0]=S`00P0]=Sd00`0a?480=D98038oA@02030m@`0U02hk@@0b@D@0<d9503A3
AP0hAdd0>4I>03e;E00nC5P0?TaJ03i;F`1:FFT0=T=E045>F00mBT`0>dU<03e:DP0kAe80>4IA03]9
E@0nC5T0>d]H04IGH@11DUX0>4UA03i>F@0fAUD0?TiK041@F`0jBe80AeIM03Y9CP0lBdl0?DY@03e:
D@0mBU80@DaF045=EP0203i;DP0M03m<D`10CE80?daB03i<D012D5<0@DmB03U7B@0kBDX0?de>04UG
E`16E5@0HW1a04aJF`0kBDX0@DmB041>DP15DUP0BEIM04MDG@19EUl0DUmY07F3SP1<FVD0AUAO04mM
J019Ef80CE]V04aJI01WMGl00P1EHfd01@1=FfD0BeUR05QVKP17EU`0CUeS0080CEaR02l0C5]O04iM
HP1>GF40C5]N04MFF@16EEP0B5MG04IAC`1;EU80BEA@04iJEP1:EU80DUiJ05AOF`1<F5@0CeYF055L
F01;EU80BEEA04YFDP19F5<0BEQE04YIEP1<FUT0C5YJ04]IFP1=Fed0CE]N04]IG01=Fel0DUmU059Q
J01;FV40BUUP04MFG@1?GV@0AUEJ04aKH01>GF40AUEH04EDE`1;Fe`0BEMH04A?D@18DE@0Ae1C04A=
C`0204=<CP0]04M@D`1<EEL0@DY<03]4A`0i@TD0<S/m03Dm>00j@S`0ADe703i6@P0b>SH0=chk03U1
?P0j@3h0>3hl03Dk>P0e>c/0=Chm03M2@`18DeD0=D1208bFV`0kA4T0;CHk02lh?`0b>D40<CQ003e4
CP15BE@0BDaE034b=@0a<3D09bL]030`>@0]<3T0;c8m038f@@0e>d@0=Ca402hf>`0Y<CL0:Blb02X^
;`0Y;Bh0:Rh_0080;C4b00@0:2`]02HZ:`0U:BX09BTZ0P0T:2T02P0V:R`07R8U024U:00R9RT0:2`_
02da=00T:2/09RX]02L[;P0X;2l202L[;P0502LZ;P0Z:c009bL^02DV:`0W:2d00P0Y:Rl0>@0Q8RL0
9RL/02X[<00N7b@0:BX_02DT:`0V9B`09B@[01PG7P0M72<0De9I02@S:P0o?TH06aXR01lN9P0/:c<0
8b8Y020L8`0W8RL061<H02<N8`0G4QL07APL01lJ7P0F4AD081/N01XE600H51H0KVY/02PT9@0R7Ql0
7a/L01hJ6`0I5AH06aLH01TE5P0M6AX06QHG01LC500M6AX06ADE01dI600K5aH081`K010<2`0G4a<0
5a<D01PD5@0H4aH09R4U02@O8`0N6Ad050lC01D?4P0J51H071HH01D?4@0201lI6`805a4C0P0F4182
01D?4@0701/E5`0H4A@06A<E01TB500E3Q405a4C01D>400201LA4`0801L@4P0G4A<06A<E01@=4`0B
3100618E01D?4P0F418201PB501<00l92@0F410071HF01XE4P0D3Pd04`X<01dD5@0D30/04`h<01PC
3P0I50h05Q<=01DC3`0D4a4061DH01XF700E4aL0518D020N7`0E4a@081hO01dK7@0J61X06aTL01`J
7P0Q7b<07Q`P01TF700J61h071/P01lN8`0Q8BD08B8V024S:00Q92T08RD[028V:`0R9Rd0:Bde02T/
=00S:2l08bXa02D/=00W;SD0:C0g02T`>00T:c80;3<j02L^=P0mA4/0GfI]02Xa>@0S9Rd071dS01hO
900P82H06a/N020O8P0N6ad07QTK024I6P0N5AD06Q0?01/A4@0I410071HF02<L700J4Q804@T801hE
5@0C2@T05`d=01/A4@0F2P`04`L901L;3@804`L901h04PH801T=3`0P51H0ACTk01041P0D20X04PH8
01T=3`0C1`T04PH801451`0K41409Q/M01@82P0B1`T04@H801D92`0?10D04PL901D92`0@1@L0714B
081eN@0_9RT040L:01hC5`0B1`/04@L801451`0B1@H401<51@0800l30`0C1`L03`<301H:2P0Q5AD0
5@T901861P0E2@T201H:2P805@T91P0D1`L201D8208050L70P0C1PH00`0E1`H05PP501<50`0201@6
1@0O0104100D1PH07@h@02XK7P0G20/05@H901@61P0D1P@05PL501L81`0G1`T05`L<01H7300@0`P0
5PX>00l31@0G3@`04PT501471P0C1Pl040<=01@73`0E2@h04PH901<72@0D20X05`/?01P<400C1Ph0
5@PA01853@0201L;3@0401D92`0C1`T050P:01H:30805@T;0P0D20X01@0C1`T04`H=01@74P0F21@0
50LB00804PD>00L05@P?00T00`0G2`l04@H801L<3P0]8R<05@X;00D04PH80P0C1`T401451`0M01D8
2P0H2@/05`P;01D62@0C1@H04P<601<41`0C1@L04`H801@62@0D1`P050L901<72@0B1PP04`L90186
200A1@L040@601882@0H3Pl050T:01051P0>0`@050T;04Tj?@0S51L050D80101100D1@P00P0F1`X0
3P0D1@P04`@701T:3@0J2`h050H801D62@0@0@@050H801831P0L3A0040<401@5200C1PP050H80`0C
1PP00`0A1@T050P<01L;3`0201H:3P0:01862P0:00805@T=00h31P0@10P0710D01H:3P0?10L06`lC
01L;3`804@D900L03P<601H:3P0A1@T04`L:01@8300B1PT05PX=01Cooooo000Kooooo`0T01D92`0@
10H03P8401`@4P0F2P`03@4302/O8@0K3a404@D701X>400P51H03`<5034T:`0d:2/03P<101X?2`0A
1`40;bDI044g:`0K4@H050T501<71`0H31003P<900X11`0900L01`0501P?500L4aH03`H900l72@0N
5AH07aHG01482@0B2@X05`h?1P0E2@T01P0A1@D05PX:01D92@0C1`L05@T901H:2P804`L70P0D20P0
3P0C1`L04PH601461P0N4Q804`L701P<300;000050P800h20P08000040@401dA4@0G2`/03`@40P0C
1`L04P0B1PH04`L701<71`0C2@X06a8E01P?4P0C2Pd03`H900h5200H3a801`0100l62@0<0`H05@`?
01072P0B1`X06Ph@02`P8P8060`>00d05PX<01051P0L41806Ph@01D92`0H30h050P:01P=3P0E2``0
5P`;01H<2P0E2`T050/600805@/900h05P`=01D:400D2@l04`P?01H:3P0K3a<06@dA01P=4@0M4QH0
4`P<01hE600F3A0060lB01H@4P806Q@F00D05``B01X?5`0J3aL060dE01X?5`0201P=5@05020E7@0K
41P08AHN01dB6P0J3aL00P0J3QP0:P0I3QH060lD01T@500J4A@06A<G02<M8P0T7bD071HP01H@700G
4Ad05`dF01dC6P0N5AP06A<E01TD4P0M61D08QhM01hK6`0O7B008b4V024N9`0K624081dT01`J7P0O
7Ah07Q`M01XI5P0Q81`09bHT02DS8`0V92L09B<X024N9`0Q82P08b8Z01LH700X:Bd08b@X02@U:01S
I6H0=CHh02PZ:@808B<R00<09bTX02`^;@0Y:2H00P0U9BD02P0V9RH09RLY02PY:`0[;2h09b/^02@X
:`0[;c80<3@g02`a=@0Z<3L202`c>`1`02Tb>@0[=3/0;SLn02`g?@0X=C/0<Ci402`i?`0Y=S`0<d16
03I5B00c@TL0=4=803A3BP0]>d@0B5IO03e;F00iAUH0FFIf04UFI`0d@E@0?d]G03e8C00e@TP0<3e6
03M3C`0gAE80?4UI04YGI`13Df80AEER04QIH`0nCeT0?DeI045AH010D5d0<dA>03U:D@0oCUD0>TU=
03]:C@0mBU00?4U@03a9D@11BeD0@diG03m<E00nBe<0@4eD041=D`0mBU00?4Y>041>D@0lBTd0=D=5
03U7B00oCDh0@Dm?03i<C01?GEh0?de>03E3A01<FUd0A55G04]HGP1=FV80A55J04=@F@1CH6T0D5iY
04ABG@0jB5<0CUaW059PJ`1GIG00FFMb08jLY`1MJgH0GVag05QVL@1BH6X0A59K049AF017EUd0CUeT
04mNI@1BHFH0CEaO04mNH@1@Gf80C5aL04YJFP1;FUX0BEEC05ANG@18DU40C5IE04mIF01@FUT0GFMV
051JF@18DU40BE=B04aFE@1CGed0Ef=Q04mNF`17EED0AE=C04QFEP1;FEX0BEMJ04UFF`80AeAJ00l0
CU]R05ISJ`1AH6L0BUUP04=BF@11D5L0CUeS04=BE`18EeX0AeII045@D`12DU80Be]K04mMGP12C4h0
0P15CE000`11BD`0@4Q;0459C00204=;CP0=03U1A00h@4<0?4A703Q0@P0d>cD0>d8k03m6?`0m@cl0
=C/i038h=P0i?cd0>Clo03Pn?P0203Dk>`0L03@m?00f@D<0;STk02dh>P0_>Sh0<3Tn02hg?00c>T80
>3m7034h@00]<C`0:blj03PkA00/;340=CHk02h_=00[:c@0:2Xf038e@P0`=3l0<SU303<j@P0^=C/0
:34f02P^<@0W:2X092DW02DV:0809bPZ00<0:R/]02//;P0Y:R`00P0W:2X0200Y:R`0:R/^02d^<P0Z
:bl08B8V01TJ7P0V9b/0=CHj100Y:Rh0100X:Bd09BHZ028S:00O82D202TZ;`8071dR03/0:b`a01/L
8@0P8BH08R<X02<T:@0X9bl07ahV01hM9@0S8RX092<[02h]=@1LFf<0F5MO02<R:P0E51`061LO01LF
7@0H4aT091lS01PC5`0F4AD0:RDY03@_<`0N6Ad07aXN01hI7@0J5AT061<G01D@500L61T06QHG01/G
600L61T06QHG01/G600G4a@06QHG01TE5P0G4a@06QHG01LC4P0B3Pd04Ph<01/G5P0Q7A`0EU9B08=o
P00F4Q<05Q8D038]<@0A31006A@I01`G6`0G4AD07aTK01D?4@0>20X09b4S02HP8P0201LA4`<05Q0B
00H05@lA01TC5@0F4180618D01LA4`0C3@l201D?4@0701H@4P0E3a404`d?01@>400F418050dD01@>
4P0201LA5@0Q00d72@0E3a405a4C01XD500M5aL08adM01TD4@0A30T06A0C01892P0A2@L091lK01dH
4P0400004a0;028Q7@0Q81h0=38e04m<D`0O7B804Q0B01DC500A3a006ALH01<A500F51L08R0S01`J
7`0M6b006aTN01XG7P0N6b807QhR00<0824U02D082<X028U:`0T9bh08RL]028V;P0Y;CH0:2lg02Xa
>@0U;3@08bXb030g?`0_=Sh0:S4i02lf?P11B5008BP`02P_=`0^=Cd09Rde03Pk@`0Z;C@092@/024Q
9`0P7b@08b4V01XG6@0I5AH06aDE01XC4P0I4@l06Q0?01`D4`0M5aL07aTI01dF5P0I41405Pd>0080
5`d>02@05P`=01H:300F2P`05PX<01D92`0D20X05`/=00l31@0800006Q0A01P<3P0K3a405@T;01T=
3`0F2P`06`lA01D92`0G2`d04@D701D92`0<00804`L9024E5`0F2P`04@D701<72@0A1@L060d?04a1
A@0A20/02`<501L<400I3Q8050X;01451`0B1@H301<51@0:01<5100A1@D05PX:01451@0C1`L0710@
01T=3@0@10@03`<301<71`805`/;00<04PH601D71`0E1`L0100E1`L00`0F20P05@L701D71`0201@6
1P0501@61@0B10<05`T601<50P0B10<00P0F20L0200H2PX03P0201@5200A0PD06@X=01L82`0E1@D0
5PH60P0G1`P201D62@0I01451`0L41803`<502@J6P0P5QD040D901D74`0E1a@05@PB01032@0?0`L0
50P<01H:300800003`<701452P0=00L03P4801D9300E2@/050P:01<72@0E2@/05`/=01D92`0201@8
2P804`L900d04`L>01D7500F2A<05@PB01853`0C1Pl050L?01442`0G2`l04@D800h2100A1@L03@<4
00H04PH80P0A1@L01@0B1PP04`L901D92`0F20/05PL:00805@H90`0D1@P01P0E1PT050D801<41`0B
0`H04@8501851`804`L90`0B1PP02`0H30h0200000h2100?0`D0300201hB500O41<04@8501H72P0B
0`H0404400805@H900/04`@701@5200J2`h06``?01P9300F1`X03@0101/<3`0@0@@04`@701831P06
01@5200H01D93@0@10P05PX>01X>4P0?0`L03P8600l31`0>0PH04PH:01L;3`0I3A405PX>00/00`0F
2Ph05`/?01<72`0A1@T03@4501862P0F2Ph04@D900d11@0@10P04PH:5?ooool001_ooooo02@03@43
01/?4@0D20X060`>01H:300C1`T05PX<01041P0D20X05PX<01X>400>0P@070lF01L;3P0I3P`04`P4
02TO5P0P5PX07aD901X@1P0@1@404PL701862P0F2A008QLO03T_=`0W7BD02`<701072P0H3a806Q4D
01<:2`0A20T02P8301892P0J414701@8200601T=3@0E2@T04@D501451@0@10@05@T90P0D20P03`0F
2PX05@T901<71`0G2`/0Ac/k01<71`0D20P04PH601L;2`0N4Q806`l?01<8200=0@40710@01H:2P02
01<71`0D01861P0C1`L04`L700l41P0F3A003@@701482`0@1`X04PT<01072P0F3A007QDH01P?4P0@
1`X02P4401@82`0C1`T07a<E01<72@0I3@l20186200801P<3P0G2`d050P:01451`0D20X06Pl@01D;
300E2`/201D;2@0D01D<1`0E2`T05P`:01H<3@0E2Q0050T?01@94@0L3aH05PX>01852`0?10X040D9
020E6P0I41D030<601L>4P0>20`03`T;010:3P0G31@201T>5P<05``D00H060dE01T>5P0N4a/05@XB
01@94@0J3aL201X>600801T>5P0H3a@06a8F01dD5`0L5QX08ahS02@O9@0O6B<201TC7`0V01T?600M
51X07A@I01TC5@0H4Q806QDB02<O7P0K61X0928W02h[<P0T8BX04PlH01lL8`0I5a/07Q`O020N7`0K
6QP07QdI03He<`0V92H08b4V028O9P0P7BH0:BP`01`K8`0b<cP06AXN028S9`0W:2/04Q<E02<T9P0S
9B@092HU02HX9`0W:BP0:2XY02TX9P0W9bL202HV9P809RLY00h0;2d_02L[;P0S9bX0:2`_02``<`0X
;C40:S4h030g?`0_=Sh0:S<j02df?@0b>d80:SDk02Hc>@<0;3To05/0<d1602`k?P0a@4D0@U5F04MF
G@1HIVl0UjF^08FCW`0lBET0A55R03i;G00b?e80=d=@03M2B00a?TH0<Ci8038nC00gA5@0AU=T05=P
L015EFD0@51O04YJI`11DEh0>d]I03];FP0oCe`0?DiH045BF@0fAD`0>DQ<03Y9C00lBDl0>dQ?03]8
D010BU@0AU9K04=@F00mBU80?DYA045>E010CE<0?deA041>D@0mBdh0>TQ:03a:B`10CTl0A59B03Q6
AP0kBDX0?de>03Y8B@14DUD0AE9H04UFG01:Eel0@TmH041=EP18EEh0=TA?04eKIP19Ef80A59M03m=
F01;FF@0B5IQ06ilQ`1>G6L0CE]V04UGHP1>G6H0D5iW05MVK@1?GVD0Df9Y04iMI01@Gf@0CeiQ055P
H`1CHVD0CemO04aLG01<Fe/0DEeM05iXI`1<EUD0CeUH05EOGP1BG5/0C5IE0080BUAC00X0C5IE04iH
E`1@G5X0EfEU055OG`19EeP0AeEF04QFE`1:F5/0CE]N0P1<FEl04@1=FV00DUmW05ISJ`18Eeh0AUEL
059QJ01<Ff80BEQN04EDF@1:FE`0AeII049AE011DE40AEEE04MEEP0lATP0@DU<0080@d]>00l0A4a?
04I>D@10B4/0?dM:03U1A00j@TD0?DE803Y2A00h?cT0=3/d02he;P0_=C40<3Hd02`b<00b>3H00P0e
>c/203@j>P0O03@l?P0^>3X0<3/m03m:C00Z=CT0<CXo02Tb=`0e?4@0<cY202lf?P0c=d809RXe02X]
=P0/:c80=SHn02h^=P0Y:C@0:R`i03DhA00]<Cd0;c<o02lf@00]=3`0:2le02P^<@0W:2X08b@V02@U
9`0U9RP09RLY02//;P0302`];`0902X[;@0Y:R`09bP[02h_<`0Z:bl0:b``038c=`1BDeL0FU]O0080
:BX^0P0Z:bl01`0X:Bd0;Rlc03Hg?00_<3D08B8W01TJ7`0Q8RL00P0Z:c00700N7b@0<c@i02LX;@0I
6Ql0:2L_01dL900J6B408B0X01hM9@0H5al06QTQ02<R:P0T8b/09B@/02<R:P0V9B`07APN02@O8`0N
6Ad05a8F02`W:`0g<SH08QdQ01lJ7P0I51P071LK02@O8`0N6Ad201TE5P0501/G600L61T06aLH01XF
5`0G4a@0100H51D04`0G4a805Q8A01/G5@0L61L05Q8A01hJ6P0Y9BH08QhO01XE601FDED09b8V01@?
500O6Qh06Q@H01PB500J51H050h@01`F600I4aD01P0F41801P0I4aD05Q0B01PB500G4A<04`d?01D?
4@805a4C02T05@lA01<=3`0C3@l05Q0B01L@5`0E3a<02P@801/E6@0E3a403@L901<=3`0J51@071HF
02@N7P0K5Q<05Q4>01P?400A20T040P605=>BP1MF5807aXD01LC3`0D4a404Q4?08n=T036a<T0?3Xo
01`J700J61T05aDF01XH6@0@3Q405aDH020N8@0K6Ah07A/P01/I7P0L6B007ahT028R9`0202<T:00b
028S9`0R9BX08bH/028U;00P9B/08BH]02/_>00/<c/0<3Lo02T`>00X;cL0=Se502lf?P0/<c/0ADaD
06E/M00k@TX0?4=;02T`>00^=Cd0>Cm602LZ<@0T92`081lV020O9@0T8RL071PM01XF5`0K5AL06Q<C
01TA3`0J40l0614@018<300>20P050d=01XA4P0@1`P06Q0A01H<3@0C2@X05PX<01L;3@0F2P`06`lA
01@82P0J3Q005@T;00/00@0C1`T20186200H00l31@0I3@l05@T;01451`0G2`d06Ph@01051P0K3a40
3P8401X>400T61X06Ph@0186200C1`T040@601461`0J3a<04`X=01XA500H3A407a@H00X10P0B1PP0
4`H70`0D1PH01@0D1PD050P801P<300?0`<02P0000803`<300H0710@01D92@0D20P060`<01T=3@0C
1`L801D71`<050H600l04`D401/=300=00006P`901H81`0B1PH0>bd/02TK6`0D1PL04P<601421@0E
1PT0404401D5200F1PT00P0G1`P0300E1`H050H50104100I3@l040@601hC5`0K41@04`P@01@6500D
1QD060XG01@73`80300400L06Ph@01451`0I3@l05PX=0104200K3a<04`L9008050P:00<04`L901H:
300H30h00P0D20X201<72@050186200C1Pd05@PB01L:500E21800P0C1Pl01`0B1@d05@P?01@8300C
1`X04@D700d10`0A1@L01@0B1PP00`0C1`T04PH801451`0301041P0301851`0D1@P050D800<050D8
01L05@H901@5200D1@P050D801<41`0B0`H05@P:01L;3@0E2@/04PH801041P0?0`D07Q8D00P0000N
51D07A4C02DI6`0?1@H05@H90101100G20/05@H90101100201421@80404400P050D801D62@0C10L0
4`@700X0000H2@`04@8501<41`L050D800X0710D01452@0B1PX050P<01452@0S5a/0710D00l31`0B
1PX05PX>0P0A1@T0100@10P05PX>01L;3`0E2@d201@8300600h21P0D20`03P8600`0100?0`L02`03
5?ooool001_ooooo01`05@X;01/?4@0<00804PH801H:300C1`T03`@501P=3P0^8R@06@d?01041P0I
3@l050L=01H;3@0=10<05``8024F3`0I3`L06@l601H<100F2`L05P/;00/00`0H2a8060dC01dB600F
2a404@L<0P0C20`01P1PEUL05`l?01@:2`0A20L04PP701<:2PH050P800L04PH601D92@0B1PH05PX:
01D92@0>0`<050P800804@D50P0D20P03@0A1@D050T903<W9`0C1`L05PX:00l30`0D2@T05`/;01<7
1`0E2@T04@L7038V9P0O4a<00P0C1`L01P0B1PH04`L701<71`0X7Ah0?C8f01H<3`804PL;01H06PlC
01872`0I3Q802P4301872`0F2`l060dA01L;3P0B1PP05`/=01D92`0Q5AL05@T;01X>400:0000710B
02`P8P0C1`T050P:01H;3P0E2`d05@/<0P0E2`T04`0G3@/060h<01L=2`0F30d05@X@01D:4@0E2Q<0
5`XC01853@0J3AD05P/C024F7@20MGd091XR01D;4P0G3AD03PL>00l83P0H4AP00P0F2a<02P0H3AD0
5@XB01@94@0H3AD05@XB01873`0M4QX06PlG01/@600J3aL201X>600;01X?5`0K4QL07QDI020G6P0K
5AT06A@I01PC6@0J51h06Q@P01PB7P0O5Ad00P0O5Q/02P0K5AL06A<D01PB4`0R7Ql06aPK01`J7`0J
5ah05a@L01`I8P0K6Ah201`J7@0A01lM7P0O7Ad061HF02/Y:P0P7R4081hS024N9@0N6b@081lW02<R
:@0c=3P06AXN02//<00M7R408R<U024R900R92<00P0S9B@0100Q8b80828Q02PX:00W9bL202PX:080
9bPZ00L0;c<f02``<`0X;2l0:Rlc02/`=00W;300:S4h0080;SDm06D0:S<j02`e?00`>D00;3Lm02dj
@00X=C/0<3e303I3B@0_?480<T5603A3B00_?T<0@e9I05ESK01JJ740CUaW04ABH00lBET0?T]K04AA
HP12CE/0>D=>03Q5C`0mBEL0<cm@03]8FP1GI7L0Gfan04aKKP10Cf40AUIU03m?G`0nCUd0<41?041@
G@11DU`0@U=J03=2B@10Ce<0?Te@041=D`0oC5<0?daD04A>F013CUL0?T]C03m<E012CeH0@DiD03m<
DP0mBdl0?D]>03a:C@11Ce40?de>03i<C@15De@0>DM8045?D00oCDh0@4i?04ABE@10CE<0@DiD04IC
F@19EUd0AeAK049?E`16E5h0CeeX04ECGP1AGfX0FFMb05ITK`1CHF`0CE]V05ARK@17EF00@4iI051N
J015E5`0GVed04MFG@1@Gf@0BUUN059QIP1?GV40DF1S05=SH`1@H600CUiN04iMGP1CGel0GVYZ04iJ
FP1AGEd0DemO04mKF`1@G5`0DEeM04]GE`0204QDE00^04IBD`12D580A59E04QEFP1:Ee`0C5YN04eJ
H@1:Eeh0BeQP04aIHP1=FV80BeQQ04QEGP1>GF@0D5mV0760Q`1RLGH0A5=H04QGF`14DeH0@e=D04AD
E013De<0?dm?041>C`0mAdT0@TY=04=;CP12BTd0@d]>04A<C`0j@TD0>D5403Lo@P0i@D@0=cm203@l
?P0g?CX0<SPd02le<@0b>3@0<CLe02dc<@0[<C40;cDe030f=P80<3Dh01h0;cLi03I0@P0/=cT0;3Li
03<l@@0d?D80=Ci303LnAP19CEH0>Ce6038f@@0W:cH0;2hj030`>P0d=3l09RDb02l^?00h>TP0?3i=
034d@P0^<Cl0;S8n02dc?00[<3P0:Rda02<T9P0P8B<09BHX02<T9P0U9RP202TZ;00U02//;P0/;Bl0
:2T[02@U9`0V9bX09RL[01dN8P0Y:Rh09bP/024R9P0[;30092DY02<T:00W:2`0:2T]02HW:`0R8bL0
9BH[02l`=@1;C540ADI;02//<@0Q8RL08b@Y030a=P1KG640=CHk020Q9P0Q82H07ahT024P9P0R8BL0
81lU01hM8`0L6b405aHL020O9@0201PG7@0901hM8P0Q72807QTM01`G6`0J5AT06A@H020K7`0L5a/0
6A@H00807QTM02006A@H01hI7@0M6AX07a/L01dI6P0K5aP071PI01XF5`0H51D05a<D01XF5`0K5aP0
61@E01PD500M5aL06Q@C014;2`0G4A40618C01dG6@0J51H08A/N03Tc=`0<1PX071HK06=MH@2VX:@0
>38d01@>400L5QP06aDG01LA4`@05Q0B0P0G4A<01P0N61X06Q@F01`F600K5AL05a4C01XD5P806A<E
03L05Q0B01@>400F41806A<E01PA600G4AD05Q0D018<400I4aD06aDG01H@4P0G4A405@l?01/E5@0H
4a005Q4>01T@4@0D2`/08a/I01XE4@0E40`07aXF01/G500H5aD05aHE04I4A`1ZJ6d0928V018@4P0J
61T05Q@E01XH6@0G5AP08AlR01PF6@0J61d07adR020N8`0N6b8081lU01hO8`0O82@07AlS01`P8`0O
8RL08RH/02@Y;`0U:S009bdd038i@@0f?DD0=Ce6034j@`0c?4D0>dA=0080<CY30340?4E>04A=EP0[
=3d0=Sm802L`>@0X<CX0;38k02HY<00Y;3<08R<Z01dN8`0Q82H07A`P01hL7P0M6AX071LG01TC4`0I
4@l05a0?01TC4`0J51@050d=0107200G3Pl06@l@01H<3@0B20T05PX<01P<3P0E2@/081@F0186200D
20X05@T;0186200C1`T06Ph@01T=3`0J3Q00;b<U02TM7`0E2@/03`<501L;3@0C20X05`/=01451`0H
30h05PX<00804PH800/05@T;01@82P0A1PP03P@704Hm@00S6ad04`P<00h31`0C2@X04`L901@72003
01D71`0=01D71P0@10@050P801451@0@10@050P801T=3@0V6QX06`l?01861P0C1`L050P801451@08
01D71`8050H602P04`D501<5100C1@D06@/801h@3@0E1`H06@`;03X/:`0U5aL050H701H72P0E1PT0
5`P;01021@0F1@h05`H=01L72P0G1`L050L201@60P0A1P@05@T901@8300B1`l03P8>01dA800O4280
3@0@00h13`0D1a404@@;01041`0E2`/050T901P<300E2PX0308201H:300C1`T050P:0P0C1`T00`0E
2@/05`/=01@82P0301<72@050186200C1P`05@PA01H94P0E21400P0B1@d00`0B1@`050L>01042002
01<72`0300l31@0D20X04PH800@04PH800<04`L901@82P0C1`T00P0B1PP0100C1`T04`H801<41`0C
10L601@520805PL:00@05`P;01L9300E2@/04`L90P0A1@L03`0C1`T05@/<00`20`0G2`d04PP90106
1`0G2`d05@H901H72P0C10L06P/>01L82`0D1@P05PL:01D62@0401@5200300h00P0I2Pd04`@700<0
5@H91P0D1@P01`0C1`/040@801D93@0D20`05PX>02lS9`0S5a/00P0C1`/0100E2@d04@D901D93@0B
1PX201452@0601862P0A1@T050P<0104200A1@T04`L;0`0D20`Dooooo`006oooool05P0W6ad07Q8D
01@82P0P51H0710B01D92`0C1`T05PX<02DI6`0@10H04`L900d10`0900405@T<00P0000O51004@H3
01T?1P0A1P004@H101H;1`0F2PX201<72`0<01H;4@0@1@/040D;01L<400D2@d03083020F5`070000
3P@301@:2@0<0P401`001P0C1`L201D92@0<01@8200S5aL08ADE01861P0F2PX040@401451@0F2PX0
5@T901861P0A1PH020000P0F2PX0200<00003P@400d10@0800006`l?01dA4@11=CD07A4A0P0C1`L0
400B1PH04`L701<71`12=cP0Jf5R02TO800@1PL02P0101lE5P0?1@H06Q0A01D;300J41402P0101@:
2`0A1PL301<72@0Z01hB500>0P@06`lA01451`0L4180<2@V01lC5@0G2`d05P/>01D:3P0D2P/050X9
01D;2P0H3P`060h=01L=300F2`h050T?01D:4P0F2Q@08aHP01T<5P0C1Q0040@>00`02P0E2A<060hG
00l53P0=10`07QLO01TB6P0B2a<05P/C01D:4P0I3QH05``D01@94@0M4QX05``D01H;4`0G31@0714I
0P0N4a/201/?6@0=01`A6@0K4QL06Q4E01T@4`0G4AD061<H01PC6@0G4A/06A<O01XD800L4QX071<H
01dD6@0201`F6P0J01XD6017@TH08AdS01PE700Q7RD07AXR01HC6P0G5AX0<c4d02DS9P0I5aX07adP
01PF6@0J61/06aTN01`I800Q7RD08b0X01TH800U92X09bP/0411A@1dMGT0;2d`01TJ700P8B<2020R
8@0802@V9@0W:BP0:B/Z02HV9P0V9bT09bPZ02PY:`0X:Bd202HZ;@0902L/<00V:bl0:Rlc02X_<`0U
:Rh0:C0h02Xa>@0[<SX0:c@k0080;3Dl00<0;CPn02`i?`0^>d400P0d@DL0;P0`?D<0=TE<03]:D@0e
A4/0AeEN05]YLP0_?DH0>4IA04MEHP0kB5L0AE9R04UFIP11C5X0@deI045=F`0nBU/0AU5U04MDI`1=
FFl0EF5g04MFJ`15E6L0@U9R03e=G@14E6<0?dmN061`O@0iBU@0?TmF03]:D@10Ce<0>dY=03a9C`0l
BE00?4UA045;E@0oBU<0?DYB049?E`12CeH0@DiD04AAE`15DUL0?4Y=03]9C012D582041>C`0>03Q6
A`12D540CeeN04eKG00lBT/0@DmB04QFF@19EeX0BUQK04IDE`10CU40>DI<038oB00jAe0304eJH`0I
04aIHP1;F640BEIO04QEGP13D5T0@4eF04MDG@1ULWX0R9FK05QUJ`1FHfT0AeAJ04eKGP19EeX0BUQI
04iLG@1>G5`0D5iN05ESH`1>FE/0E5mQ04mJG01AG5h0B5=E04YEE`0205UTIP0_04]FF014Ce40AU5C
04E@E014DEL0AeAL04YGG`1;F600BeQQ04YGH01<FF80BUMP04UEH@1;Ef<0BEEQ04AAFP13D5P0AE9H
05MTJP1AGV@0BEMK04QFF@11Ce80?Ta=049@D@12D500?Ta<04A@D00nB4X0@TY=0459C00oAdX0?TI9
03m7BP0mADP0=Si103Dm@00f?T40=3`o03<k?@0k@Ch0<CLc03Hl>00a=cD09R`/02D[:`0/<S800P0`
=CP0100/<C@0:Rlb02P`<P0[=CL203Q2A00H03Q1AP0/<cT0<CPn03m3C01JGVL0=c]4030b?P0c=D40
=cU503<c@00`;cd07A`/03hmCP1<Bed0@D5C03XlB`0_<D00:2Xg02LY=@0U:3409RP^028R900Q8B<0
:RX/0P0W9bT08@0^;S00;Bd_02`/;P0[:bd0:BT[02PX:P0Y:B`0:2L/02d/<@0U92T071/P024P9@0T
8bP09B@Y02@S:00Z:Bh0;Rdb02/Z;`0R8RL08B8W02DV:`0_<3D092DZ01dN8`0X:Bh07AhS02DV:`0b
<cP07QlT02TZ;`0Q82H09R<Z02@Q:00201/H7`0@02DR:@0O72<0<Bhe05YGGP0^:c806AHM010=4`0O
6R009R4U01/F6P0R7B406A@H01`G6`0N6Ad06aHJ01PC5`805a8F01l091lS01dH700P6al071LK01PC
5`0L5a/06aHJ01TD600G4QH06aHJ01hI7@0H4aL06ADF014;2`0N61L07ALG02PR8P0L5QL071HH01dG
6@0D3Q406aDI01TC5`0O6Ah0Qh650=WCe`1<ATP03@L9010:300F41806aDG00805@lA0P0F418201LA
4`0601PB500E3a405a4C01H@4P0B30h050h@0P0G4A<04`0D3Q004`d?01H@4P0K5AL081TP01/E6@0N
61`09R0T03dg>@0G4A<0618D01<=3@0D3Ph04`d=01<>2`0B3@X06Q8@01`D4P0B2PP00P0B3@X0500;
1P<05A4@00d;300G5AH0518C01PF6@0J61/071XK02d[;00N71d061HG01DC5P0K6A`05Q@G01PF6`0M
6b007Q`Q01`I800M72808B<W0P0P92L04@0R9RT09BX^02L/<@0X;C<09bhd02/b>@0e?4@0=Sm603Dn
AP0e?dP0=d5:03Y4C@0kADh0>TA=03M1BP0a>d@0<ce60080<Sa501<082Xc02H^=`0X;3D0:Rhg02<W
;@0Q92T092DZ01`M800M7Al06aTJ01/H600J5QD0618B01TC4`0F410040X:01D>3P0J4A804PT:00<0
5@/<0P0F2P`00`0D20X06@d?01451`0201D92`0L01L;3@0N4Q@040@601451`0@10H07A4C01P<3P0>
0P@04`L901D92`0F2P`03`<5020D5P0D20X05PX<01L;3@0E2@/040@600l31@0@1@H08QLK0<2g^P0i
<3<03@8601hC5`0E30d04`L901@720<05@L700d05@L601@8200D20P050P801861P0@10@04PH60145
1@0@10@04@D501<71`0H30`06Ph>00H05@L70P0D1PH301<51@0[01840`0@0P407a4>01H81@0A0`80
6@/:01P:2@0D1PH03`8301P9300C10L06@X=01L83@0G1A005`H>01L6300G1`H050L001<6000A1`40
5PX:01862P0B1Q803@0D01P:8@0_83H060TL01<55P0C1Q8040<:01041P0Z7Ql040D301<81P0g;2X0
91TG01D92@0D20X05@T;01<72@0A1@L04`L901@82P0201<72@804PH800D04@D701452P0B1@`050L>
0185300201032P0701<72`0>0PH04@D901P<400B1PX040@801041`070186200601451`0@10H040@6
01041P0B1@L050D8100C10L501@5200C01D62@0C1PP040@600l31@0@10H04PH801H:30080000<BDW
06iRI00D20X05PX<01451`0@0@@06@X=0102100I2Pd05`P;01@5200301831P090101100A0PD050D8
01831P12<cH07@hA01L82`0A0PD04`@700H050D800T040@801862P0C1`/040@800`1100;00<040@8
00h21P0?0`L00P0@10P00`0B1PX05@T=01<72`0201T=4@804`L;00H060`@01<72`0F2Ph03P8600`2
100U6AdDooooo`006oooool0900F2P`05`/=01D92`0J3Q004@D701<72@0J3Q005@T;01`@4P0F2P`0
;B4S0186200G2`l040H701T=3@0>0`405@X601<80P0F2`L05``801<81P0A1@H06`lA01<72`0@1@/0
5``B01H;3`0C20`04PP90147200D2P/03P@301061@0C2@P05`d<01@:2@H04`L700T050P80104100?
0`<07a<C01/?3`0900006`l?01@8200E2@T00P0J3Ph03@0G2`/05PX:0104100J3Ph04@D501D92@0D
20P07A4A01D92@0L4100200002LK6`0>10@00P0C1`L0;@0B1PH04`L701<71`0C20T0:R0Q00`20`0I
3a005@/<028H6@0A1`P05P`=00T0000D2P/03@<401hD5@0D2@X05`/=01H:300E2@/07Q8D00d10`0G
2`d04`L900`00P0F2P`06@d?01041P0F2Pd050T=01@9300D2P/05@/:01P>300I3`h060h?01H;3`0D
2A405@XB01L;5@0B1@l06`hH01`?6@0I3AL07a<M01X>600201P>5`0@020F7`15?TH0>C8j01PA6@0G
31@05P/C01/@600J3aL05P/C020E7@0J3aL0714I01<8400H3AD06a0H028G7`80710J01807A8J01XA
5P0G3Q804`X=01PB5P0O6Ql081/Q01/E7`0J52007aTU01T?5`0I41D071<H01`F6P0M5a/071DL02@O
9@0H51X201/H7`0F01DB6P0M6R405aDJ0490@`0]:bh05Q@G01hL7`0K6Ah07Q`Q01hK8@0G51/07Q/R
02/X<00S8RX08B0V028S9`0S92P0C4eA01DF6@0W:2X08R<U02@V9@809BLV00H08B<R020R8@0U9BD0
9RLY02LX:P0Y:R`202L[;P0902DY;00X;C40:Bhb02ld>00`=CT0:c0f02`c>`0[<SX0;3<k0080;SLn
08H0;CHm02`g?@0X=C/0<d1603E2B00_?480<d160350A`0eA4/0@E1G03E3C01?GFH0?4YC03m=F01K
JGH0AeAS03e:FP0jAeL0=3m=03m8E`11CEd0@diP06UdR01ZMX`0CEU`04=?I`0mC6<0AUEZ045@H`0n
CF00AEEU04iNK@1mSIX0>daF041AF011D5L0?diB03i=D010CE<0?daC03m<E014CUP0AE5J04AAF@13
D5P0?DYA041=D`1>Ff40DEiS03m=D00lBTd0@e5C049@D@15De@0@U1A03U7B011Ce00AE=D04IDE@0n
C4l0?de@04ABE@17EEP0@DmB03i<C`0oCE00AE9J03Y7D016De`0@TmH04]HH@1EHV/0>TM@04mLI@0k
B540AU=L04YGH01;F640?4U?06IcN@0kB4h0AE9H03i<C`1=Feh0A59C04IDE@1:F5T0CE]K059PH01I
IfL0CEQJ055LGP1@Fed0DeiP04IAD`19E5H0@Da>04UDEP14Ce40@4]=049=C`0oBTh0>TM?03i;E013
D5T0AeAM04aIHP1>Ff@0BeQQ04IBG@13Ce/0AE5M04IBGP13D5T0BeQP04ICF@0oC580?4U?04UGFP0k
BD`0A59C03e;C00oCDh0?de=03a:BP14D500>D=503i6B@0oAdX0?TI903m7BP10B4/0>d=6030h>`<0
;SHi02D0;cLi03Y0?@0[<Bd0<cTe03<i=`0a=cL0>Clo030f=P0c>3/0<CHi02/`<`0V:bh092`^02Pa
=012C4h0BE=E03HoA00b>Cl0>T5703Hj@`16BU<08RH_030b?P0j?4P0=3I203@c@@0_;Sh06aXZ04M6
F01BD6D0ADAH04A5E`0f>4L0;2hj02T/=@0X:380:BT_008092@V00H0<30b02/[;@0[:bd0<30b02/[
;@0W9bT202<S9@0C02DU9`0X9b/07A`Q02DT:@0];340=C@i03<b=`0O7R<081lT01lN8`0V9BX0:bX_
02TX;@0V9R/09RL/02X[<01:Be00A4E:02X[<00202<T:@0i03Pi?P0];S<07b0U024R9`0S82L07Q/R
01XG7P0P7B@08QlV01LD6`0K61l05A8I02PU;00@3A@071TP02DR:00H4aL0:RDY01HA5@0R7B407QTM
020K7`0G4QH071LK01dH700O6Qh08A`P01PC5`0L5a/07aXN01TD600F4AD071LK01dH700J5AT05a8F
01`G6`0O6Qh061<G01XF5`0R71`0:R@S01XD500N61P040X;01TC5@0B30h08A/N00D00`0N61`0614G
02@N8P0k=CT05Q0B01hH6P0R71h06aDG00<05@lA0P0F418201LA4`0501XD5P0F4180618D01LA4`0C
3@l00`0E3a40900B30h04@/=01D?4@0K5AL05a0G018<400=1`/0CDM;07QbM00D3Q005@lA010:2P0E
3`l04`d=01D@3@0D3``04`/901hF500C2`T06aHC020K600G4Pl05Q8A02<Q8P0:20T05Q@E028P8`0A
3a806QPI034_<00N71d05Q@E01DC5P0I5aX061HI01LE6P806aTN00<06QLN01`K8@0Q92L00P0Q9BP0
?`0S9bX09b``02L/<@0U;3809bhd02Xa>00a>400<3U0034k@`0f@4T0=Cm803U3C012C5D0?TQA03a6
C`0g@DX0?TQA02hh@@0i@d`0:38k02dg@00T:c<092Pa024U;@0W:S409RT^01`L8@0K6ad06ALJ01/H
6@0K5aH061@C014;2`0D3Ph07ALG01PA4@0A20T06Q4B01<92P0D2P/05P`=01H:300E2@/04`L901L;
3@0E2@/06@d?00l31@0=0@<05PX<01D92`0G2`d04`L901P<3P0D20X05`/=01D92`0@10H04@D700P0
000U6A/03`<501041P0201<72@0;01041P0C1`T06a0A03DZ;P3Sf]d0@STl00h31`07000050X;01<7
2@0D1`P00`0E1`L01@0E1`H050P801@8200F2PX05`/;00805PX:00@04`L701H:2P0F2PX050P80P0B
1PH601D71`8050H60P0C1@D04P0B10@04P@301h@3`0A0`804@<001840`0A0`805`T801H8200D1PL0
6P/>0101100E1PT05@H;01L54@0G1Q005`H<01L71P804`H001803`@001H:300=00L05PTH01436P0>
01T05`PN0183600E1aP05@PD01442`0A1@L0<2@U02TN700G30X06a4@01050`0A1P@201D92`0301<7
2@0A1@L04PH800<04`L90P0B1PP01@0A1@L04@D801862P0C1Pd04PH;00803`<700L04`L;00/00`0D
20`07A4E01D93@0D20`03`<600D04PH800L05`/=01/?4@0H30h05@T;0186200A1@L04PD7008050D8
01404`@701831P0B0`H050D801D62@0D1@P04`@701831P0A0PD04PD70186200?0`D03P8401041P0C
1`T0<2@V00l31@0201H:300800X0000G2`d03@0101`=400A0`D05PL:01421@0@0`D201831P0:01<4
1`0B0`H050D801P9300G20/0FDY=02HG6P0H2@`03@0101841PH050D800T04@D90104200>0PH04`L;
01T=4@0?0`L0300401<72`0E2@d00P0D20`03@0@10P04PH:01862P0L41@07A4E01862P0>0PH04@D9
00l31`0J3Q804@D901H;3P17>cl05?ooool001_ooooo00P06@d?01051P0G2`d0>Bd_01L;3@0D20X0
40@6018620805@T;00`04PH801041P0S5aT08QHH01451P0F2PT05P/901@91P0F2`T050T801<81`0J
3Pl201hB50804PH:00X04`L;01<72@0B1PP04PH801451@0D20P07a<C01X?3@0A1P@05P/90P0B1PH0
100K3`l04PH601/?3`0c9bL601861P0701H:2P0D20P04@D501<71`0E2@T04`L701P<300201T=3@0?
01L;2`0C1`L04`L701H:2P0?1@D05@T901@8200<0@4050P801L;2`0C1`L0;b<S04/o?`0L41005@X;
00805@T;00H050P:01<72@0C1`T04PH801<72@0D20X401L;3@805PX<01D060`>01T=3`0J3Q0060`>
034U9`0T61X04@D701P<3P0>0P@05P/>01D:3`0D2@`04`T:01@:2P0F30/04`T:01061`0G310060dE
04<g@00h;3P00P0I31H0=`0H2aD05PXD01H:500E2A<03`D>01T?600K4AX0ViBL04Q1B@0=1Ph04@H>
01/@600I3QH06PlG01P=5@0G31@081DM01053@0J3aL0;B8Z044f?P0H3AD06`lI01P<5P0H3AD07A@I
01lF6P0H3a8071HJ01PC600`:c40;BLa01D?6`0O6B@07Q@L01dD600K4QL06Q<J01`E700M5Qh07QTP
01DA6P0G51d061DN01XG800F4aX071XM01TG6@0J61/06aTN01XH7P0L6B008QlV020M9@0Q7RL00P0T
8BX0C`0Q82P07ahT01lP9@0N7b<07AhR020Q900S92H09BHX024S8P0S9B@0:B/Z02HX9`0R92<08R<U
02TZ;00X:B/092P[02P/;`0/<3<09BX^03<h?00/<CD0:c8h02L^=00g?T@0:C0h02/b>P0e?4@0:S<j
02`e?00a>T40<Se303E2B00f@dT0=45703=0AP0d@DP0=DA<03E3C00d@T/0>TQA03i<E`0kBE@0?D]F
04ABG@0nC5P0=TAA03Q6D`0oBUP0>T=B04=?G`1=FF/0IG2405EQM`1?Fg@0AE5Z03m>I@12DFH0AEAW
04YIK01>GVd0CEe/04QHI@0oD5X0?e1G049AF011D5@0>dY=03i;D@11CUD0AE9J08^EW`1CGfP0@DiF
03m<E010CE@0@e1F049?E@10CE800P10CU401P10CU00?de>03i<C@10CU40@U1C04ABE@80A59C00P0
@e5B04ABD`11Ce00?Ta=03m=CP11Cdl0@U1B04A?EP80Ae5J02/0BUAM04iHH@14CUL0ADmH03m9DP0m
Ae00?dUB03i8D@13CEH0BUEK049=D`11C500BUEI04aGF`1<EeX0CeYL04MBE01NJVX0CEUI055MG@1Q
KFd0B5IH04iLG`1<FUd0AE=F041>D@11Ce80AeEH04IDE`14DUD0@e5D041>D@0lBDl0AE9K045=F@13
Ce/0@TiJ04EAG@1BGVX0A51L041<F00oBeH0@TmH0080AU=L00D0Ae9I04IAEP18DeL0AE1D04UDE`02
03m:C00;03i9BP15DE40>TI604UEE@12CTh0?TM903i6B@0mADP0?4A703U1A00h@4<00P0e?D001`0m
ADP0=3`o03Hn@@0^=SP0<CLf03@j>00f?3X00P0e>c/0200f?3`0=CXm03<h>`0g?3l0<SLk02`a=@0_
=CT0:C8d0P0c>ch07@0/<cT0:c0f02db>00e>D80=CQ103Hi@P0f>4@0;S0l02T[=`0X9cL0;B`n038a
@`0k>Dh0Geeb04a;GP19B5T0=CA303/iAP0T92d0<C0i030_=00Y:B/08R8T034a<`0^;S008B4S02d]
;`0Y:B/09bLY00809RHX0180:2PZ02`[;`0M7240<C0e02XY;P0l>d0071/P02TX;@0T8bP0:2L/01hM
8P0_;S<0:BP]028R9`0Q8RL0824V028S:00T9BX202<T:@050452A`0Z:c00824V01/L8@0P8BH00P0P
7R<01@0Q7b@081hS01lM8P0M6b007Q`Q00807A/P00<07Q`Q01lM8P0P7R<00P0M61`201hI7@807aXN
00L071LK01hI7@0I51P06aHJ024L800O6Qh06QDI008071LK01h06QDI01dH700P6al06QDI02<N8P0K
5aX08A`P01`G6`0Y9BH07AHF01hE5@0L4a@06a8C01T@4P0H3a807A@G01/B5P0J4AH06a8G01T@5P0E
31406A<G01LA4`0E3a40618D03@^<00F418050h@01LA4`0H4Q@201TC5@0603D_<@0O6A/05@lA01`G
600H4Q@05@lA0P0D3Q00300a:bd050h@01TC5@0D3Q0071HH01dF7@0E3a<05a4E01hH700J51H050h@
01D?4@<05a4A03h05Q4>01D@3@0J4Pl05Ph;01lG500E40d04@/;01D?3`0C3a005Q@E00l=3P0B4140
6aTJ01LE5P0H5QL03P`=01/I6P0J61T061HI01dK7P0H5QT06aTN01XH7@0N72408AhU01dL8P0M82<0
8RHY024U:00O92L08bP/02H]<P0/<cT0:S8h02Xc>@0kA4/0>T=:03<mA@0gADh0>4E>03Y7D013D5T0
@4eF03M4C@0nC5D0<d1903e:D`0`?DH0=dA=02dh@@0]=Sl0:S8i02L^=@0T:S008RH[01lR9`0J6ah0
7alQ01/J6`0E4a@07A`J01PD4`80618B00T05`l@01D<3@0D2``04`T:01X@4@0I3a0050P:01H:300E
2@/00P0B1PP201D92`0301@82P0E2@/05@T;008050P:0`0C1`T0500F2P`06`lA01X>400E2@/05PX<
01<72@0@10H050P:01<72@0A1@L05@T;01<82P0I3Q80;B@W01H>400A1PX05``@01882@0B1PP050L8
0P0E1`L0100F20P05`T801dA4@0E2@T201<71`804PH601<050P801H:2P0F2PX05@T901@8200A1@D0
5PP80184100E1`L07@l?01L92@0E20P05`T901H8200E1`L050H601<51@0B10<050H500805@L402T0
5@L601@61@0C1@@05`T901D7200P4A@0B3/m024C5@0C1@T05`H@01X94P0J2@l05PL701@6100D1P<0
50T801@73P0C1Q404`HH01<57@0D1Ql0=BHl03<T>00G2AX04PHA01H:400=0`@04`L801<81P0D2@L0
4`P601@91`0E2@P05`/=01D92`0G2`d06Ph@01L;3@0B1PP04`L901@82P0201<72@0B01451`0N4Q@0
8ADG01D9300A1@P05@T<01@8300A1@T060h@01L;3`0A1PT05@T=00l31`0?0`H04`L901@82P0A1@L0
5`/=0P0J3Q001P0V6Q`06@d?00l41@0C1`T03@4301D82P805@H900@050D801<41`0C10L04`@70P0G
20/01@0C10L05PL:01D62@0B1@L04PH800805@X;00l04@L801L;3@10=3H07A4C00d3100J3Q004PH8
01461`0C10L050D801D72@0D1PP060T<01<41`0F1`X00P0D1@P201D62@0701831P0A0PD05@H901D6
2@0A0PD04`@701@5200601<41`804@D90P0D20`01P0B1PX04@D901L;3`0A1@T060`@00d31@8050P<
1P0A1@T01P0C1`/050P<01X>4P0G2`l04@D901H:3QCooooo000Kooooo`0600l31@0A1`P06@d?00/0
0@0B1`P07A4C0P0B1PP201<72@804PH800d03@4301<72@0?0`D05PX<01861P0>0P8040@401@8200H
30h050P:00d10`0;004050D:00<050D80P0D1PH02@0G2@T04`D401P:2@0F20L04`D201T;2P0A1@D0
50P801L;2`0201861P0301L;2`0B1PH04PH600@04PH600T06@d=02HJ6P0I3@d04@D501H:2P0D20P0
7a<C01T=3@0E2@T00P0B1PH03P0C1`L05`/;02DI6@0P51@03`<301@8200E2@T060`<01T=3@0F2PX0
91PH01<71`0M41005PP80P0G2@T201P:2P0701L92@0F20P05PP801L92@0H2PX06@/;01T<3@0201H:
300<01D92`0F2P`05`/=01<72@0P51H06@d?01@82P0E2@/03P8401L;3`0D2@l05@X>0P0E2``02P0D
2P/05`d>01D;300J3a@02P0701X>600F2aH05PTC01H94P0G2Q<201H;4`0l01L<500I3aL040H>02LM
9@0?20l050dD01TB6@0C21006a0H01X?5`0M4QX05P/C01<8400=0PX03`@<01`A6@0J3aL09AXR01L<
501JCUP0?C4k01T>5P0B2@h060lC020G6P0O6Ad05Q0E01D@5P0D3QP05Q0L02@N:00N51`07QDI01dD
6@0L5A`07QHP01hF8@0F41X08alZ00h;5P0=2Q<07AXR02d[<00O7B009R@V01dK7P0I5a`07Q/S01/H
8@0L6B808QlZ02DR;@0N6b@07Q/S02`[<@0P7bD0824V020Q9@0N7b<0824T0P0S92H01P0Q8b808bDT
02LY:00U9bH08R@S02DY:`80:2`_01`09BT/02DZ;P0X;C40:2da01lV;00M92X08RT_02D^=@0h@DP0
<3Lo0458D01<De/0>T=:03M0A`0i@TT0;cY0034nA00c@4H0=D9803Q5B`0jAdl0=D==03A2C@0e@dh0
?deH041>F@0iAe80?D]F0P10CUT0900mBeH0?TaG04EAG00lAE@0BeMW05aWN@1?FVh0?DUO04]GKP17
Df/0>dYQ04]JL01=G6l0AUEX059RL@1>GVd0Be]X04=DGP11DUT0@E1G041?D`0fADP0=45703e:D@1N
Jg<0^lG?055LI@0lBE40=dA<03a9D011CU@0@4eC045?D`13DE@0@DmB041>D080?Ta=0`12D5<04P11
Ce00@4i?03m=CP0mBd/0@Dm?04=AD@0oCDd0@4m<04QFEP16DEL0A4iG04I@F@15CeP0?dUB03a6C`0g
@DX0=3i703I0B@80>dE>00h0@TaE03Y5B`0lAd/0AE1D04IAD`12CDl0Ae9D04IBDP13Cdl0F6AT04mK
F@14D4h0A51?04MEF080BeYO00<0AUEJ049AEP12DEH00P16EEX02P13DUL0@U5F041?E00oCUD0@dmK
045=F`14D5h0A51L045=F@14D5`204MDG@0A04EBFP14DET0AU=K04UFGP17DUP0BUEI04aGF`15D580
>TE703@o@@0oBd/0B5AD03Y6AP1EHEl0Z;Bb049>CP0k@dH00P10B4/02P0i@D@0=Ce003Dm@00g?d80
>d=602Ta=00a>C`0<SXm03Dm?`0^=3<2038h>00B034g=`0b=cX0<cPk03<h>`0`=CT0<CHj02db=P0Y
;S@0:c0f02de>00g?d80=3`o02/`=P0_=3X0=ca203Hi@P0b=Ch0;C0i0P0Z:SH04`0[:cL092He03m1
D010@U40<C1203lnD00c<D<0=35202h/>P0i=T40:2D/02XX;@0S8BD0C4Y=02LU:00Q7b80:BLZ02XX
:`0X9RT00P0S8B@04P0T8RD09bDX02XX:`0R82@0>SPm03Le>P0d<SL0:bT^01/I7P0^;340928W01/I
7P0U8bP0518G03<a=P0R8RL08R<X024R9`808b@Y01<08R<X024R9`0o@4D0:2T^01XK800R8bP0:b/a
028P9@0T7b<09B0T028M8@0N6Ad06QDI01/F6P0O6Qh091lS028M8@0Q720091lS00807APL0`0N6Ad0
5@0O6Qh07QTM01hI7@0K5QX06QDI01dH700K5QX08ahT01LB600D3aD071LM01PC6@0E41H040/A014<
4P0F4AL04`hD01TD6P0E41@071<D01/B4P0201T@4@0;01`C5@0M51L06A0C01XA5@0M51T07aHK01/B
600F3A80618F01PB500M5aT00P0A2`d06`0?2@/0618D01LA4`0C3@l05Q0B01TC5@0d;S008A/M01<=
3`0400005@lA00h82P0M5aT0<B/]08b6R00M5aT09R0R018<3P0?2@/07AHM01H@500E3a<05a4E01LA
4`0F41806A<E01D?3`0201<=3@0>01@?300E40d0614<01dE4P0C2`P06A<B01PB500:10H06aHJ00X8
2@0<2P/06ALH00`;2@0H5aD201HD5@0;01@B4`0I5aP07A/N01XH6`0H5QT06aTN01TG700N72408AhU
01hM8`0O8bH00`0S:2/0500T;2l0:30d02Pa=P0Z<cP0;cTn03<nA00e@4H0>4A=03Q9D`0iAe80>TUD
03m@FP10CUT0>TYD03]<EP11CeX0EVE`03I7D@0c@D`0<3a50P0`>T<07@0W<3L07RD[01dT:P0P92T0
4aLJ034b=00P8B807QhN018B4P0G51@0618B01LA4@0E3Ph050/<01<:2`0E2``04`T:01061`0D20X0
6Ph@01H:300E2@/06@d?01H:300G2`d07A4C01L;3@0D20X05@T;00805PX<00<05@T;01<72@0D20X0
0P0H30h04@0C1`T050P:0186200D20X04@D70186200C1`T04@D70187200;00@050/>00d41`0A1PX0
4PL;01<92P0D20X05@P900805@L700X05@L601@61@0Z7Qh08ADE00l30`0>0P805`/;01<71`0B1PH0
50P80`0E2@T01`0D20P06P`<00d0000I2`/03@0001H:2P0I2`/01@0D1PH04@0D1PD05PP701H81@0E
1`@050H501840`0@0P4060X:01d?400G20/09AHI01X;3P0?00<06@P>01/:400J2Pd05`L:00805@H;
00@050L?01D7500G2AP05PTK0P0E21`01`13=4P0?2e000l1400F2A@0200202TM7`0B1PL00P0C1`L2
01D92@0C01D92`0G2`d060`>01L;3@0E2@/05PX<01P<3P0D20X04@D701041P0A1@L050P:01D92P0A
1@D03`<301D92@0H30`050P:01041P0200P0000A01@8300800007Q4H0145200B1PP040@601<72@0J
3Q005`/=00h3100C1`T040@600l41@0C1`T03P8401<6200E1PT00`0D1@P01@0C10L05@H901P9300H
2@`05@H900805`P;01D04`D802`P8P0Y7Al03P8401@82P0H30h0200001041P0A1@L03`<501D92`0B
1PP04`@700l00`0A1@H05@H900/0000D1@P05PL:01D62@0D1@P00P0E1PT201<41`0401P9300F1`X0
4P<601@520L04`@700`04@D901862P0C1`/04`L;01862P0A1@T040@801472@0800006PhB01D93@0:
008601862P0601452@0C1`/05`/?01D93@0A1@T050P<5?ooool001_ooooo00P05PX<01L;3@0I3@l0
200001L;3@0N4Q@050P:01<72@804@D701804`L901@82P0B1PP05PX<0186200H30h03`<500/0000D
20X05PX<01@82P0=0@<050P:01lC5@0E1P/05@H901@5200E1PT201D71`0801P:2P0D1PD05PP701@6
1@0B10405`T601451@0E2@T201861P0301451@0=0@404`L700D04`L701P05`/;02LK6`0H30`04@D5
01H:2P0B1PH050P801H:2P0G2`/05PX:01<71`0B1PH06@d=03@X:00/82003`<301L;2`0E2@T06@d=
01dA4@0=0@403`<300P0000I30`701L92@805PP800@05`T901T;2`0I30d05`/=0P0E2@/301@82P1B
01X>400F2P`06@d?01@82P0?0`D05``A01@93`0F2a005P/?01D;300D2P/060h?01H;3`0L4AL040@>
01H:500E2AD05@PA01D83`0G2Q805P/C01L<4P0H3A@040H>01H=4P0G3A@0614H02<M8@0E3QD04PL?
01L<500F2a<07A8J01P=5@0G31@0714I01hC6`0H3AD02P0701@94@0J3aL0;20Z01dA6`0J3aL07aHK
01L>4P0F3A00618F01XE6P0H4aT06A<M01dG8`0M5b40718J01dD600M4a/071DM01dE800N5R<071HR
01DA700L6B@04a0I01lL900B41D07A/N02/Y:`0N724061DL024N9`0L6B@08AhY01dJ9@0N6bH05A8K
03`i@@2GUY`081lU028S9`0Q8RH0824U020Q90808R<U00H0828Q028T8`0U9bH08bDT024S8P0R9RT2
02DY;00M02<W:P0S:2`09R/_02T^<P0^=C/09B`b02he>`0/=C`07bP_02he?@0e?4@0?4=;02lh?`0d
?D@0=Ci5030k@@0a?T@0<Sm503A1A`0hAD/0>dQ@03a:E00jB5<0=dE@03]9E00mBeH0>4IA045?FP0o
CEP00P10CUT09@0oCEP0@dmK03m9E@1AGF/0F6Ae04IAI@0hA5X0A51W04QDK010CfH0F6Mk059RLP0j
BUX0AUIV04MGIP16EV<0@U=M049CFP12DEP0@U5E04YIG014DEL0?DYA04EBFP0lAU00AU5J03]8D00h
ADd0>TM>03Y7C@0lBDl0?4U>03a:C@12D5<0AeEG04ABD`0mBd`00P10CU401`0oCE00?de>03i<C@0m
Bd`0@4i>045?C`11D4h00P0nCDX01@12D4l0AU5G041:D`13CEH0@4YC0080=Cm801<0<3Y302li@P0e
?dP0>TA=03]5CP12CE@0?4M;03i9C@16DED0AU5C049=C`18DeD0CUYJ04IBDP13Cdl0BeME03Q4@P17
De80B5II0080BUUN00h0AeIK049AEP11D5D0B5ML04MFF`13DUL0@4mD03i=DP0mC5<0>DEA03Y6E010
C5P0A51L04QDH080BeQQ01T0CEYR04QEG@12CeL0@4eD04=@EP13CU80?TU=03]6BP0nBD/0?4M904QC
E@10C4`0>TI603U5A@0oBdT0Gf]Y03<m?00h@4<0>T9503a4A`0j@TD0=Si103@l?`0nATT0;SHi0080
=3`o00@0<SXm034i>`0^=3<0<SPh0P0c>CT03`0e>Sd0=c`o038g>P0_=3P0;S<g02/`=00Z;cD0:c0f
02de>00d?3l0<CTl02`a=`0]<SP0<cPn02P[=00202lb>`0402/[=`0Z:SH0;2`h02`^?080BD]J0P0d
<dD03@0]:c/0:BLe02DQ;`0Y9Rl08b4V02DS9P0_;C00Y::U055?DP0W9BP0>cTl02<Q900N71l00P0Q
7b80500S8B@09R@W02PV:@0R82@0<c4f010>4`0Y9b`0:bT^028P9@0[:Bh09R@Y01TG700W9BX071XO
02DS:00R8BL08b@Y028S:00T9BX08b@Y0P0P8BH04@0W:2d07QlT01dN8`0C51T071`Q020N8`0S7R80
91lS028M8@0O6Qh06QDI01TD600N6Ad08ahR01dH700I51P06aHJ00H07QTM00T06aHJ01`G6`0L5a/0
71LK01hI7@0O6Qh0THbB05iIG`0R7B<00P0K5Q`0500M61h081/Q02<N900L5ad06aHL01PC6@0L5QX0
7QDF01dD500K4Q<06Q4B01XA4`0I41<060lB01T@500N5AX08QTN02@J8@0Q61d07aTM0`0I4aD0700H
4Q@04P`>01dG6@0?2@/04@/=02@N800F41801`4301@>400K5AL081XL02`V:00C3@l05a4C00@0000O
6A/02`D700h82P0J51H03`T;018;4P0C3A405@lC01LA5@0L5QP07QPJ014;3@0E3`l201PB4P0V01@?
300B3@T05a0:01hF4`0@20D06A<C01`F600C3@l071LK01TG6P0>30d071XJ00l>300M71X05A<D01PF
5`0F51D061HG01XH6`0I5aX07A/N01lM8P0L6Ql07Q`Q01lL8`0K6R007b@W02<X:`0T:B`09BX]02D]
<00Y<CD09c0e02`e>P0d?T@0<3]103E0AP0lBU8203Y;E@0F03i?F@11DU`0?e1J03Y;E@0hBE<0?TmI
04MHHP0`@D/0:3U302djA00a>d@0;cU202Pa>@0P:C0082L]024W;00[;S<0Rhb@05eNH00T92@05ADE
01@A4@805Q0@01H05Ph?01D<3@0E30d03@<401D;300J414050P:0186200F2P`05@T;01/?4@0H30h0
6`lA02PL7P0O4aD050P:01D92`0H30h05`/=01H:300C1`T040@60P0B1PP04@0?0`D03P8400l31@0E
2@/040@60186200D20X03`<501461`0E2Ph050/>01<:3@0E2Ph040D901061`0E2@/05@P900805@L7
00P050H601<5100G2`/08QHF01L;2`0D20P07A4A01D92@805PX:00/05@T901@8200C1`L04@D501/=
3@0J30`05PP800h0000J3Ph05@L701<51@0401@61P805@L60P0E1`@0700E1`H04`D401840`0J30`0
40@401X;3P0;00003P02024B5@0I2@X06PX;01T9300F1@`050@>01D5400B11805@LH01P:6`0G2Q`0
5@PJ01@76@0A11@06P`M00P02@0E21803`8901<72`0G2``201@8200<01@82@0B1PP040@60186200F
2P`05@T;01<72@0J3Q007a<E01H:300C1`T04PH80P0A1@L01@0B1PL04@D501451@0F2PX05`/;0080
4@D701808ADG0104200H31002000024D6`0B1PX04PH801451`0C1`T05`/=01T=3`0D20X04PH80145
1`0B1PP050P:0186200D1PT801@5200P01<41`0D1@P050D801851`0O4aD06@d?0186200N4Q@04PL8
01041P0J3Q005@T;00T0000>0P@040@601L82`0?00<060T<01l@4`0>008050D801L82`0E1PT04`@7
01@5200E1PT04`@701D62@0I2Pd060T<01831P0D1@P701<41`L04PH:00D03`<701`@500^8RH0?30d
01<72`0601862P0400d11@0>0PH040@800l31`803P865?ooool001_ooooo00P07Q8D01L;3@0@10H0
40D601L;3@0?0`D05@T;01@82P804PH801P050P:01D92`0@10H04@H80186200J3Q0050P:01H:3@0H
31004`L:01T=3`0F2P`03@8300l51P0G20/05@H901@5200E1`L05PP801L92@0E1`H05PP701P:2@0F
20D201<50P8050P800@04@D501<71`0E2@T04PH61P0D20P01P0B1PH060`<01861P0B1PH05@T90104
10804PH601H04`L701@8200E2@T05PX:00/0000A1@D060`<01D92@0H30`04`P800h20P0F2PX04`P8
01P<300?0`<060/;01P:2P0G2@T05PP801@61P0C1@D05PP80P0G2@T01P0F20P05`T901P:2P0H2``0
5`/=01D92`<050P:0P0E2@/0800D20X05`/=0186200A1@L05PX?01D:4@0G31405``@01H;3`0E2``0
5P/?01D:3P0F2a405`/E01X>6@0H31P050L?01D93@0F2Pl05``A01P=4@0I3Q806Q4E01<:3@0E3100
6A<F00`6200F41<05``C01L<500E2Q807Q<K0P0I3QH0:`0B20l06PlG01X?5`0O51`08AHN01/@600N
4Q`06`lI01X?5`0I41D06Q4E020G6P0C3A406A<H01HA5`0H4Q`07ALS01@>600I41H06a8F01`B6P0K
51`071@Q01`D8`0F41h0>CA107EbO@0V8b`05a@L01hL8@0J61/09R@V01dK800I5Qd08QhY01lK:@0K
5bD0920]01hK9P0R7bP0;b`d02DT:P0R8BL00P0T9BT0700R8bL08B8U028S9@0T9BL09BLV02HX9`0W
:BP09RPW02DW9P0R9RT092P[02DY;00V:bl09b``02P]<@0V;C<07bH/02/b>00[=3/0:S<j02Pa>00^
=Cd0;3<k038i@@0`>D00=3e402df?@0c?T@303=0AP0603E2B00hADd0>4IB03U7DP0e@dh0>4IA0P0n
C5L04@13DE`0?deF03i<E@0nC5D0?4YC041<E@1:E5l0EV9^04EAH014Cf40?4UL045=HP18EFT0>dYN
045AHP17EfH0?DeL0080AeMV01H0AUIS049CG@12DeX0@U5H041?D`12DE@0=D9804AAF011CUH0?4I@
049=EP0kB500?DYB041=E00lBDl0@e1F04ECE`0nC4l0@4iA04=AD`11Ce00?de>0P0oCE000`10CU40
@4i?045?D00204=AD@09041>C@0nCDX0@U5=04ACCP11D4`0@D]@03e6C@0oB4l0?4E<0080=3e400T0
>T=:03U2B@0lAD`0>dA;03Q1B010BE00Ae1E0419CP0nB4X00P13CDl06015Ce00A4i?04iHF@1DGUd0
@4Y908fGUP1?FUX0B5EK04MFG@14DeX0@U5H041?EP0oCUD0BeYQ04aKHP17EUd0@4mF03U8C`0hATh0
?4QD045=F@10C5P0@DeH04MDG@80BeQQ01d0C5UP04UGF`15DUL0@U1D04=AE017DEH0AU1C049<CP1:
E5H0BE=D06ihN@1DGUl0?TQ803Do?P14CTd0?DM603U3@P0lA4L0>D5403Lo@P0h@4<0<SXm02hf>@0f
?T40>41304I>D@0b>Sd0>T9502H^<002038h>008034g=`0`=CP0<CHi038g>P0c>3`0;c@h02/`=00/
<CL202ld>P0M02Ta=00]<SH0;S<g02ld>P0[;SD0:2/b02`_>00c<cd0<S8l02l_>`0e=D40>SY603Tk
B00h>TL0<SA102d/?00e<T<0=C9102TV<P0[:340:RH[02hY;00W8b<0:2@U03Hd=`0E4aH0:2HY02@R
9@0/:Rd01@0T8RD03`0U8bH0:RP/01XH7@0/:Rl0IfEZ02<Q9P0U8bP07A/P02LU:P0X9R/06aTN02@R
9`0M6b00@3i402DV:`03028S:008020Q9P0M7R<07b0U024R9`0V9b`09BH[01dM8P0P7R<2028M8@09
020K7`0O6Qh071LK01/F6P0O6Qh08ahR01lJ7P0L5a/07QTM00807aXN100N6Ad0500L5a/06aHJ01dH
700K5QX05a8F01PC5`0R7B<05a8H01XE6`0U82H07APN01PC6@0C3Q@08A`R01hI7`0D3aD06aHL01dG
6`0J4A807A<C0P0N51D0300L4A@06PlC01hC5`0J3a@06PlE01dB600R5ah08QTN01@<4@0M5aT04@/=
01<=3`80618D00X05@lA01TC5@0B30h05@lA018<3P0L5QP07ALI020J702UWj40:28T0P0G4A<02P0R
71h04@/=01LA4`0A2`d050h@01LA4`0B2a80618F01XD600G4AD201@>401E01PB500G4A405Q0@01D?
3`0E40d05A0<01PA2P0I4Pd04PX701D?3`0H4QD06A<G04Y5BP1hMWT0:bTZ01@C4P0J6AH02`X701HD
500C4A8061HG01HD5@0G5AP071XM01dK7P0O7B807A/P024O900T8BP081lU01hR9@0O92L08RP[02<[
;@0U;C009c0d02D^<`0Y=3P0<ci302lj@00d?dD0?D]C03a=E`0oD5X0AEIP04AEG`12Ded0A5EO049C
G@13E5h0=TMA03a=E`0fAe40=D==02hkA00[=Ch0:SDl02Tc>@0U;C<08bT^03i3A`31aLP0PH>501`M
7`0O8B005Q@D01PB4P0I4a<06a<D01`C500M51D0;B<T02HL7@0M4a@05`/=01@82P0E2@/04`L901L;
3@0D20X05@T;01hB500F2P`050P:01D92`0201L;3@0901H:300C1`T050P:01@82P0E2@/050P:0186
200E2@/04PH800@04`L900T04`P901@93@0;0PD04PT<01<8300A1PX04PP901D92`0E20T00P0E1`L0
1`0E1`H050H501451@0S5aL06@d=0104100C1`L01@0D20P0200E2@T05PX:00d0000b92@06@/;0143
0`0G2@T06P`<1@0D1PH01@0E1`H04@<201<50P0E1`@05@L600805PP702H03`8201L92P0@0P@060/=
01d>4@0<00005`P201L81P0F1PP05@@?01D45`0G1Q/04`@L01D67@0G21h05PTJ01@85@0B1Q<07a8O
0963T@0U62<03`<901T=4@0C2@/05@T;0186200C1`X05`/?01H93`0C1P`05`/=01X>400G2`d04`L9
01X>400P51H04PH801@82P805PX<01@04`L901861@0@1@803`@20146100B1`D04@D501041@1nLW@0
BCe101<8300G2Q403P4801862P0C1`T05@T;0186200A1@L06Ph@024E5`8050P:00@04PH800l31@0D
20X050H9100D1@P201D62@0A01<41`0A0PD04`@701831P0C10L050H901451`0B1PP05PX<01L;3@0B
1`T04`L900l41@0B1PP050P:01451`0D20X00P0B0`H01P0b8bH0>2T/024B5@0@0`D060T<01D62@80
4`@70`0D1@P0100I2Pd05`P;01831P0D1@P701<41`0301<72`0B1PX04PH:00804PH:0P0C1`/01@0E
2Pd04PH:030T:00]8RD03@8500H040@800H04PH:01<72`0A1@T04PH:01@8300@10PDooooo`006ooo
ool0200H30h03P@501D92`0I3@l081@F01`@4P0E2@/050P:0P0C1`T05P0D20X05@T;01<71`0B1`L0
4`L901T=4@0=0@D03`<701X>4P0G2`l03P8600`20`0h;2`0HeMG01P9300E1PT050D801D71`0G2@T0
60X:01@61@0F20D201L91P0801H81@0D1P<04PH601D92@0F2PX04`L701861P0E2@T601@820030186
1P0@10@04`L700804PH601<05`/;01H:2P0D20P04`L701@8200E2@T050P801T=3@0H30`04`L700h2
0P0I3@d0:1`L00d10@0E2@T06`l?020D500>0P8040D400805`T800@05PP701D71P0E1`H05@L60P0G
2@P0100H2PT05`T801L9200G2P/201H:30<05@T;05H05PX<0186200C1`T04PH801@82P0H30h05@X?
01H;4`0F2a405@X>01H;3`0G3@h050T=01/@500E2Q406@dG01hB7P0N4Ql05@P?01H:300G2`d05P`=
01L=3P0H3Pl060l@00H0000D2``06A<C01D?3`0B30d05@X@01@94@0H3AD09AXR01`A6@0H3AD08aPP
02@I8@0B1`l07A8J01lD700I3QH03@4;01L;5@0K41P06a8G01lF6P0E30l07ALK01XE6P0F4AL06A<M
01dG8`0J51h060lD01XA5@0M4a/07AHN01dE8P0M5B@0D4UI03Lb@00g=3l03``E01TF7P0]:bh07adN
01lM7`0N72407AXQ01lK9`0O6bT061@S02/W=@0Q7RT081dV02/X<00H5a`08R4W02@U:P0U9RX08b@X
024R9@0Q8R@0824S028T8`808bDT00<08R@S02<U900U:B`00P0U:B`04P0W;30092/a02@[<@0P9bd0
<3U006I_MP1BFf80;3Dl02Xc>P0/<c/0;cHn03<j@P0a>T40=3e402/d>`0b?D<0=45703E2B080=457
00X0=D9:03]9E@0iAe@0>TQE04ECGP13DE`0>TQC03m=F00lBU<0>TQA0P0iAe006@0kAe00@D]E04UE
H@0mBEP0Ce][04YGJ013D680B5EX04UHJ`0oCel0AUIU04EEI010D5h0AUIU04EEHP0oD5X0@55H041?
EP1:FEd0LX6403i;D@0nBe80>DI>03@nB013CeP00P0iATh04P14DEP0@TmE04=@EP15DeL0?de@03e;
CP0lBT`0?4Y;03m=CP0mBdh0?4Y=03]9C00kBDX0?4Y;03i<C010CTh0?di;041?B`80@E1;00L0@4m:
03i7C00nAdh0>dA;03a5C00oB4l0>T=:0080=3e400L0>T=:03a5C00nAdh0C5EL04QAEP0oBD/0>TA6
0080?4I802h0?TQ905=MGP0g@D80A4i=03E0?01PJfL0@4]904=@EP0nC5D0>dUB03a:D`10CUL0@U1I
04]IHP1@GVL0CE]T04ABF`0jB540>4I?03Q4D018E5l0B5EN04=@F@19EUh0CEYR04QEG@17E5X0AUAG
04MEF016E5D0@e5B03m9B`18DU@0>49403U3A@1NJ6T0d]cM075kO00kADD0A4i=04iIE@0^>CD0@D]:
03e5A`0oAdX0>T950P0a>C`0500e?D00<SXm03<k?P0f?T40CEEH03@l?`0h@480<CHh034g=`0`=SH0
;c@g034f>@0c>3/0<3Di02db>00W;380;34g03<h?P0a=S`0;C8f0P0^<cL06`0]<SP0;2lf02`_=P0b
=Ch0=3@n03<c?@0c<Ch0>SQ503dmB@0`<Sh0=CM303LiA@0k>TP0<Blm030]>`0T8BX0<2/b02XU:@0d
;Rh08ahK01hJ6@0L5a/06QDI020K7`0/9b/0;RT]02LR9P0202PS9`0C02TT:00X8bL0:2<W01lJ7`0]
:2h0:2<Y02hY;`0/9bd09R4W02/V;00N6Al091lU02dX;P0O6R00?cY0059@EP0W:2d08R<X01lP9@02
020Q9P0<024R9`0W:2d09BH[01TJ7`0O82D06QXO02DP9P0U7b<08A/O01hH700M5a/071HJ0P0M5a/3
01hH700501lI7@0O6Qh07aXN01lJ7P0N6Ad00P0M61`02P0S7R808A`P02<N8P0P6al061<G01TD600>
2@l05A0G020K8P0O6R4201`G7P0;04a7CP2i];/0=2lf030[<P0R7B@0@ca301hE5P0M4a<06Q0A01T?
400L4A@00P0N4aL05@0J3a@060dC01T>500J3aH06A0E01L>4`0L5QP06A<E020J700C3@l06aDG01@>
400H4Q@050h@01XD5P0A2`d02P@601D?4@0B30h030H8014;3@0201H@4P0U018<3P0L5QP03@L901H@
4P0B30h09b4S018;4P0E3a<0618F01TC5`0G4A<05@lA01lI6`0H4Q8050h>01<=3@0F4@h061<?01XC
2`0H4@/050`902@O7P0W8BD04``C014<4P0G5AP040h?01<A4@0F5A404Q4=03Dc<`0T8R<05A<D01HD
5@0P7R406ALJ01HD5`0201/I7P0W024O900V8bX08b8X01dR9@0L92H08BT[02@/;P0U;c409Rlc02L`
=@0Z=CT0<3]003@oA@0h@dT0?DaD03e?F@0nD5X0AEMQ04AFH017FF<0B5YT03I8DP0oDE/0>TaF03a>
F00V>480;Ce6034nA`0^>d<0:cHo02Lb>00U;S<082T]01XO8`0/<3<08RHX01<G600I6Q`04a4A0080
5@l?00T05Ph?01H=3P0F3@h08aTJ01D;300>10D06@d?01/?4@0J3Q000`0H30h00`0F2P`05@T;01<7
2@0301@82P@04`L901<040@601<72@0C1`T040@601D92`0<00805PX<01<72@0@10H06Ph@01H;3@0J
3a<03`H901@;3P0=0PH04`P<0147200B1PP050L800805@L70P0F20L01P0@10@04`L701451@0?0`<0
50P801`@40<04PH600/04`L701H:2P0H30`050H601L92@0@0P805@L701P:2P0=00005PP801D71`02
01@61P0501<51@0B10<04P@301<50P0D1P<00`0E1`H09`0S5AD03`<3020A500L3A00404402DG5P0E
1`005PL201H61`0F11<06@LO01/8900G1bD05`LR01H77P0D21L04`LA01<8400<00T0:A`V00P0100L
3aD0300400h2100E2@/04PH:01D93@0M41P07A0I01X=5P0E2@`05@T;01<72@0?0`D04@D701@82P0A
1@L04PH801@82P0201H:300>01D:2@0B1`<04PL301@91P0E2PP05@T901861`0B1PP04`L;01862`09
00<04`H=01L;3`0B1PP201@82P0900h2100C1`T0710B00d10`0@10H040D600d10`0F2P`04`H80080
4`@701d050D801D62@0E1PT05`P;01<41`0A0PD05@H901<41`0E1PT050L901041P0B1PP03@4300X0
000?0`D04`L900l31@0B1PP05PX<01451`0=0@<050D801421@0J2`h05`P;00d00@0A10D060T<01H7
2P0201831P8050D800H04@8501H72P0E1PT04@8501<41`0D1@P601<41`804`L;0P0A1@T0200B1PX0
4`L;01P<400G2`l03P8601<72`0>10H03@45200A1@T0100=0@D03`<701@8300>0PHDooooo`006ooo
ool0100N4Q8040@401`@400@10@201D92@H050P801h03P8201051@0E2@/07A4C0145200B1PP04PH:
01862@0I3@l03`@50104100O4a<060T<01D62@0D1@P05@L701L92@0H2PX05@L601H81`0E1`@05`T7
01P:2@0G2@P04@D501D92@0J3Ph04`L700h20P0E2@T701@8200=0186200H30`040@40104100L4100
4@D501L;2`0K40h06a0?01D:200C20L06@d=00l30`0201D92@0900h20P0L41803@4301P<3P0D20X0
4`L901451`0G2P/05PP700<05`T800P060X901L9200G2@P060X901T;2P0G2@P05PP701H92P805PX<
05P05@T;01H:300G2`d05`/=01@82P0F2P`04@D701T=3`0P51H05``A01L<4P0E2Q0050T=01D:3P0H
3Pl060dA02@I7@0H3A@04@D?01@84P0C1a805PT@01H:300G2`h05P/?01L=3P0G3@l05`hA02HM7P0B
2@/040L:014;2`0G3Q405@`A01L=5@0Q5Qh0=2Ta02TO9`0S6B404@H>024G7`0J41P06PlG01@:4P0J
3aL06a0H024F7P0H3AD06@lG02dS:`0Q6al071HJ01PC5`0I51X06aHM01XD7`0F41X05a4E01XD5`0M
5Qd07QLO01hG900M5bD0C4ID03Lb@00O72L07a`U01`J7`0L6Qd0928S01dK7@0O7B8081dT01dJ900N
72T0;BTg01dK:00V9340:2Ha01dL900X9bd08R<X02DV:`0V9b/092DY028S9P0Q8R@08b@V100V9bT0
5`0V9b/09RT]02@W;00T9b`08bP]028W;@0O9R`09Rdc01hU;@0h@DP0;CHm02`e?00]=Sd0<CY103@m
AP0c?4<0;CLo03U2B`0e@4H0<3Y203A1B@0f@dT0=D990080=D9:00H0=D=?03A2C`0oCEP0F6I`05ES
KP16E5l203]9E00T03Q6D@0gAE00>TQE041>F010CEH0Ae=O03m<F@1<FFT0AE9S04UFJ01EHWD0EFEe
03a<G016EVH0CUi]03i>G@10D5d0?dmL03]<E@0oD5P0@E1G03e<D@0iAT`0AeAJ03]8C`1AFf@0AU1I
06A`N00iAT`0<d18045>E00oC580>DI<03Q6B@0iAdX0?4Y=0P10CTl04`0nC4d0@e5D045?DP10C500
?dY>03e;C010C4h0@4a<045?C`13D4h0?DU703M6@`0kAdD0?4M903m8C@0j@dP0?TM<04M@E@0oB4l0
0P0i@TT0EP0lADd0>dA=03a5CP1:De/0Ae1E045;C@0mAdP0?4I803Y4A@0mAdP0>dE603e7AP0h@T00
AU5=02dh=011C4T0?de@03U8CP0fAD`0>DM@045?F@15Deh0BUQU055OJ`1@GVT0B5IQ03e;E00kBE80
?DYC055NI`1?G6@0A55J04=@F014DET0B5EK04AAEP13DE@0A59E049@DP0lBT/0@De=04=?C@14D500
DUaM03]5AP1OJFX0A4i?03e7B00^>3T0:S@e03Y4A@0_>CX0;SPj03U2A00d?3l09Rha02de>00g?d80
;cLj02hf>@1@EEP0Ri2D02L/<00m@TD0;C<d030e>00a=ST0=3Tl03Xo@P0m@TD0;S<g02`a=`0U:S00
;2lf03@g?P0c=Sd0<3Dk038g?@0_=3X0:blh02la?@0d=T80:2Xf030b?P0f=T80=cM30P0e=D40>00`
<ch0;C4l02/_>P0a<cl0;blk03Dd?P0T8b/0;BXa02DR900e<C009B4N02DP8P0b<3<09b8X02<O900Z
:2/04@`B02XW:`0V92L0:B@Z02TV:P0X9RT0:RD[02LR:00S7R@0;RT_02<N900G4QP07aXP02<N900/
9bd0:RD[01XE6`0h<cT0K6M]03<a=`0X:Bh08R<X01hO900O82D0824V024Q9`0G5Q`09B@Z02@S:@0R
8BL0>SPn02TT:P0W82L08AXQ01`E700K5AT06aDJ02DO8`0S7B4081XN0P0O6Ad0TP0M5a/07aXP01lJ
800O6R007QTO01dH700M61d07APL01/F6P0P6al07QTM01LB5P0J5AT081/Q01`G7@0D3aH06A@K01lJ
800E41L09R4X0:FPYP0X8bT03`XA01lJ8@0U7b<09ahO020F5@0F3@h050/<01L>4@0J51P06A0E01P?
500I41D06a8G01dB600I41D08APK00l92`0K5AL0<R`^01H@4P0E3a4050h@01TC5@0A2`d05Q0B01D?
4@0J51H050h@01D>400_:B/07A@G01`D5`0=1`T05@`?01H>4@0M5aT06a8E018:3@0B30h06Q@H01LA
5@0F41@05a4E01<=3`0@2P`0618D01TC4`0J51@06A<C01LA4@0F4@h06Q<=01XB3`0G3`d0=S0a03/e
>@0D3Q806aHK01TD600D4Q<04a4@01/G500B3P/0Ddm?03/g>00H51D06A@H02TT:P0D4QL061DJ01XH
7@0I5a`07Q`Q028O9P0O7R@07b8U01hS9P0S:2/09Rha02L_<P0X<CH0;3Dl02hi?`0c?DD0>DI>03]8
D00oCeP0?U1J03e?F`12E5l0@eEO04YLJ01RM7l0BeeW04AFHP0kCEP0?DmI02m1C@0jBU<0=45:03A1
B@0[=cl08bdf02</<`0O:2`0<3Di01/O8P0P92H071dO014B500K6A/06A<E01PB500G41405Pd>01D<
3@0C2@X050X;01`B4`0M4A<05@T;01H:300D2P/04PP90P0F30d01@0A1`P05@T:01D92`0D20X04`L9
00804PH800<04`L901D92`0A1@L00P0D20X0400A1@L060`>01<72@0Q5AL07A4C01P<3P0W6ad08QHH
01462P09008040D900T00P0E2Ph05PX<01451`0C1PL201D71`0601H8200G2@T05@T90104100D20P0
5`/;0P0A1`H03`0E2`X050X901<71`0B1PH050P801D92@0D1PH04PH6020B4P0A0`<050H6024C4`0G
2@T05PP801D71`0201<51@0301430`0D1PD05@L500805@L6024050H501<5100A0`<06`d>00/0000C
1PP050D801840`0D1`005@L401D62`0F1aL06@TS01/<:@0J2bT05`TS01H87`0D2AL04`TA01@93`0F
2A803P4801H9400<0@@0710B01D92`0A1@L03@4500l31`0F2A0050L@01442`0D20/00P0E2@/02P0D
20X05PX<01P<3P0F2P`04`L90186200C1`T05@T;01<81`0@1@<20146100E0104100?0`<050P90145
1`0<00@050P<01P<400900<05PX>01041P0B1PP05`/=00l31@0=0@<050P:00P0000?0`D04`L900l3
1@0J3Q0050L900804`@701d050D801D62@0E1PT05PL:01421@0@0@@050D801421@0D1@P05`X<01@8
2P0?0`D040@601D92`0@10H04PH801<72@0@10H03P840186200C1`T050D801L82`0L3A006``?00l0
0`0F1`X06@X=01H72P0201831P8050D800H0404401@5200D1@P04@8501<41`0D1@P601<41`0<01@8
300C1`/04@D90104200B1PX050P<01X>4P0?0`L0710D00d11@0D20`04@D91P0B1PX201<72`0400h2
1P0@10P05PX>00l31aCooooo000Kooooo`0301@91P0C20D05@X700805P/805D050T6020E4P0A1P@0
7Q<@020E4P0A1`D04@H301@8200?10@040D501451@0F2`/050P801/?400H30d050P80104100A1@D0
50P801D92@0D20P05`/;01T=3@0D20P05PX:01<71`0E2@T05`/:01H:2P0C1`L04@D501861P0F2PX0
40@401L;2`0M4A405`/;01@8200B1PH04`L701D92@0C1`L04@D501@92`0B20X060`?00l41P0U6AT0
M6QX01P=2`0D2@H050T501D:1`0D2@@04@L501881P0C2@P04PP801882@0C2@/04@H:01P=4P0:0@H0
6a0H00l4300A1@h0@CDi01/?3`0C1`L05@T901@8200C1`L050P801L;2`0/82008aLG0188200J3Ph0
60`=0104200Z7R806@dA01@83010=3P05P/>00804PH:00<05PX>01862P0B1PX00P0H31000`0F2Ph0
50P<01@8300301H:3P0501L;400J3A<06PhC01L;400E2Q000P0G3140B@0D2@l050T>01P=4P0F2a40
6PlD01D:3`0E2Q0050X>02HL8P0S6Ql05a4E018;3`0H4AD0618F01TB5P0K51P04`dA01XD600I4QH0
4`dA01PA5@0I418071<E01/A6P0I41h08ATW01lG8P0J51X06aPH01LF5@0J61X07AXQ01DB6`0I5Q/0
6aPL01XF7@0H51`06QHQ01hJ9`0M6RH06QLP01`J800L6Qh06QPH01dL6`0M7Al071/O01dL8@0P7bD0
8b8Z028R:`0P7bX0824/024R;P0P8Bh07R0/01XN:00R8Rd092@/02@T:`0T9BX08b@W028S9@0U9RP0
:2T^02TZ;`0X:Bl0;Bdf02DU;P0W9c008bH^02@W;`0Y;CD00P0Z;SL00`0/<CX0;SDm02he?@0202`c
>`0j02df?@0f@DX0:3@m02hj@`0`?DD0<Ca602llA00d@DX0=D9;03=0B@0c@4P0=D9;03M4C@0kBE@0
=dE?03m=EP10CeH0JGR004ECF`0lBUD0@e1O03Q5EP19EVP0>TML03m=G@0nCEP0@51J04EEH@17Ef@0
AeMV049BH@11DF40@U5T04ACIP1;FVh0AeIZ041?GP10CUT0?TaF03e;E00nC5D0?daD03m;D`0lAdh0
AU5G04]FG00j@dX0CEIM05IQI`0gADP0A59F05i/K`18EUT0?4Y<04=ADP0lBT/0>TQ8045?C`80?Ta<
03H0@deA04==E014CUD0A4eD04==DP12C580@T]A04E?E010BDl0ATmE05EOI@1FH6D0A51@041<BP11
CD`0@di?03i9B`0kAT/0=T57041:D`0g@DX0?4IB03m9E@11BUH0@4Q<03e6AP0lA4@0?dQ8045:B@0l
AD@0?dQ603Y3@00kA400?dQ403a5@00jA400>dM403e;BP12D5<0@DiG04=?GP1>FFd0DEaa04aGJ`1;
EfP0BEET045=F00b?dP0>49:03i9D012CE<0@diE03m:D011C58204IAE`80A4mE04l0@diC045=C`11
D4T0IWM/04EEC014DT`0?DY703m;B`10Bd`0>49603Y3B@0i@TX0<ca503<lA00g@4D0>495034k?@0/
=SP0<CTl03<k?P0j?d80<3@f038f=`0h>cd0;Rlc03Hg>`0`<SH0=CPm03@i?@0_=SX0=cm203<k?P0b
=c/0:bhc02X]<P0];380=C<i03dk@P0g>T<0<3@n02lc?`0d>4H0:Rdo02d_@P0b=DP0SI2P0412D00]
<3/0>3a5030d?@0/=3d0;3@n02de?`0_=cl0;S@k02lc>@1GFUl0?T14028S9P0S8b@092<T02@S9`0U
92X09bD[02DT:@0N7B<08b4W02/Z<00P7bD09bD/02DT:P0W9R`0<2hd02<Q:00[:2l09R<Z02@Q:00Z
9bh0924X00808b0W00T0924X028O9P0Q7RD08QlV024O9@0R8BH09bH[02@S:00M72400`0N7240?@0O
6b406QHL01XG700T7R@081XS01lI8P0R72D081/R01XE700K5Qd07aXP01hI7`0L5a/06aHJ01`G6`0N
6Ah08A`S01/E7P0J51d07QTP01XE700I51/071LM01/F700T7b<0:RDY02<N8P0M61`0618F01TC5`0J
4aP06A8H01/E6@0M5a`071HK01dG6`0Q6b005PlE01L@5@0I4aD081LD01/C3`0M61D05Q8A01/I700A
4AH05aHK01DB600H4aL06Q@H01/A4`0E30d07aHI01@>400O6A/0>C<e01XD5P0E3a406A<E01H@4P0E
3a400P0F41803P0D3Q006a4D01H<400Q5a/0:b0T02<I700F31005``@01H;3`0D2Ph05P/?01P>4@0I
41<05PlA1P0E3a40;@0B30h06Q@F01@>400=1`T071HG01LA4P1ECe00=2h_01@>400H4Q@06A<E01XD
5`0B30h06aHG01HA4P0L5QL05Q0A01dD5P0K4aH071DI01D=5@0Q6R<071DN01`E800T7RP06A<L02<N
9@0L5ad08AlT02DS:@0O7bD09bP^02`_=P0U:S40:2lh02`e?P0^>480<3e603E3C@0kBUH0?U1L04YL
J@1>H6h0AeUV04YLJ@0204YLJP0n04IHI@10DV00?e5O03mAGP0kCE/0=TQC03M7C`0d@T/0:cQ102/g
?`0Y<ST08b/`024V:P0W:bl0<C4e024Q8`0H5aT07ATM01H@5@0J4AH06a8G01P?4`0K41@04`P<01T>
4P0G2`d060`>00l31@0E2P/04`X=01@<400F3Q004PT:00h61@0G3P`050X901<9200D2PT05`/>01L;
3`0D20d04`@801L82`0M3Q4070d@01P9300D1@P04@8501X;3P0F1`X05`P;01<41`0F1`X050L901<6
200C1`T06@/>01851`0E1`T06P/>01L82`0E1PT201H72P0A01D7200B1PH04@H601H<2`0S6QT0>S<a
01@=2`0>20D04@X900`30P0A1`H05@X:01L;2`0L3Ph060X:01@61P0E1`L00P0F20P601@61P0601<5
1@0E1`L05@L701<51@0D1PH05@L70`0D1PH301D71`0=01D:2P0L41D040D>01465`0C2R805@hV014:
8P0@2Ql05a4Q01<<5P0H4AL04PT<01<62P0201@52@<050D801P05`P;01@5200C10L050D901H72`0G
20`05PX<00`10P0I3@l04PL902HJ700>10D04`L901D92`0B1PP04`L901451`0>0P@050P901<7200B
1PL07a<E020D5P0E2@/201451`040186200C1`T04`L:01<62PD04`@901004P<801@52P0D1@X04`@9
01T:3`0H2@h04PD801451`0@10H03`<501041P0C1`T04PH801451`0C1`T04PH80`0A1@L01@0B1PP0
50P:01@82P0C1`T04PH800H04@D701P060`@01472@0B1`X050X<04i2AP0F2`h06PhB00`2100F2Ph0
:AdQ01H:3P0B1PX050P<0104200C1`/060`@01D93@0A1@T05@T=0104200D20`03@4500d31@0D20`2
01862P0301@8300=0`D04`P;00<04`L;0P0B1PX201452@0<01H:3P0@10P050P<01D93@0F2Ph040D8
01452@0J3Q804@D90104200B1PX03P865?ooool001_ooooo02003P<001<8100C20@040D101<8100J
3`/0?34]020E4@16>cL0C44m01hC3`0O51004`L701D92@0L410040@400/10@0<00003@4100h30`0M
4A405`/;00h20P0E2@T0:alO00P0000C1`L050P801H:2P0I3@d04PH601<71`8050P800T04PH60145
1@0F2PX060`<01861P0E2@T06@d=01@8200E2@T00P0?0`<07`0A1@D04`L701<71`1QEET07a<G01H:
3P0J3Q00200001@8200C20H04PL301<8100F2`L050T301D:200I3a003P@501/A4P0J41402`0400l6
200K41@04@H<02hS:@0L4AL04`P@01@8300B1PH04@D501L;2`0F2PX00P0D20P0300E2@T09QXJ02`P
800P51@06@d=00T0000n<SH0`;Bh04e1A@0800003P8601dA5@804`L;00d05PX>01<72`0C1`/0710D
01dA5@0G2`l04`L;01@8300H31005`/?01D93@0D20`05PX>00805`/?03405``B01D:400E2Q0060dC
01/@5P0M4QP03@8801D:400S61h08AHL01H;4@0E2a407A@I01<=4@0@2Ph050hB01D?4`0H4QH06Q@H
018<400N61`050hB00l93@0J51L06Q4B01/B4`0I3aP05@dL01XA8@0I4A`06QDK01`J6@0H5aD05aDF
01LE700C41T06ALL01LE6@0F4aX061DN01TF800I5R4061DP01LD700L6Ql07Q`O01`K6@0O7Q`0820R
00807A`R00D07ahT020O9P0N7RH08B4[01lP:`0201dO:`0?01lR;P0P92l08b<_02@T;@0U9Bd09BH[
02@U:@0S92H07AhP01hO900T9BX0820X02LW<@0T92h0:2/d00<0:Rdf00<0:2`e02T]=P0[;cP00P0]
=3`202/d>`0902`e?00Q;CH0;ca503I3C00b?dP0=dA=02hkA00e@T/0<Sm80080<3e601`0=T=<03Y7
D010CUT0=TA=03Q6C`0fAD`0>dYA02hmA00nC5L0?DYJ04MDIP0jAeX0=41H03I4E@0kC5H0?TmI03i?
FP10D5d0AEET04MGIP19FFT0BEQ[04=BI@11D6<0@E1U03e;F`0jB540?4YC0P0oCEH06P0oC5@0AE1I
045;E00oBU00BeEJ04E>D`0kA4T0?TU=03=1A00iAdX0Df5T03e;CP0hATL0@4i?03Y8B@0nC4d0@U1A
03a:B`0oCDd0@DY?04=<D`17D5L0B55H04E>E@10BE00?4E<0P0kA4/0:00mATd0@4U@04A=D`18E5@0
@De=03e9B@0lAdT0>4=503Q3A`0e@4H0=3m503M1BP0c?DL0?4I@04E?F@0nATP0=d0m038k>00i@T40
?TM603a5A00oB4L0?4E403i7A@0kA4<0=Sll03M1@010C4X0@Dm@04ICF@14D5`0@DeO04QCJ@1KIW`0
Ef9g04IAH`15DEl0=D9<04MDG01=F5h203a7B`1603@o@`12CE40@4]?04IAE@15D5@0@diB045<D010
Bdl0?TU;041?BP2AX9P0@U5<03U8@`19Ee@0=d=303m:C00f@4D0?dQ?04YAF`14BeD0=3e403<m?`0g
@D80@DU;03Lo@@0`>3X0=Si003m4A`13B4/0=3Tl03@h>`0E61d0>3]003Dh?@0[;S<0;C8f03Hn@@0`
>3/0;cLj02`b=P0Y;3409bX_02DT:P0[:2l0<S4g030b>`0`<Sh0;2hk02h`@00/;D40<cA803DfBP11
@U@0;c5002d_?00i?4D0<SHo02lf@00X;cL0:S4i02le?@0Z;cD0:2/a059CF00n?d<0824T024Q8`0[
:bd0:RX^02HU:`809bH/00D092<Y02TX;P0];3808R4W02HU:`02024P9P0@02h]<`0W9B/0:2D/02DR
:@0S82L09b@[02PU;00Z9bh0924X028O9P0O72<07Q/R024N9@0T8RP08b8W028Q9P8092<X00d08AlT
01lM8P0N72407aXP01`G7@0J5A/06Q<J028L9P0N62807aTS020K8P0N6B008ahU00807QTO01D07QTM
01dH700M61`071LL01PC6P0S7BL08A/U01dH7`0]:2l05a8I01`G7@0J5A/07aXN02<N8P0O6Qh071LK
01lI7@0J51P05a4E01XD600L5QX00P0I4aL06P0G4AD06Q@H034[;`0O6Ad05Q0B020F500H40`05A0=
01/G5P0B41<06QTN01XI7`0C4QL03PT=024K7`0C2P`07aHG01L>4@0J51H05Q0B024K7@0E3a407ALI
01LA4`0E3a4050h@0P0E3a403`0C3@l06PlC01P=4@0H3A405P/?01L<400P5AT06a0D01H;3`0C20`0
5``@01X?4`0H3a8050`?01@>400201D?4@0A01<=3`0B30h06Q@F01<=3`0<1PP050h@014;3@0H4Q@0
6Q@F04<m?`0T7R005Q0B01D?4@0500406A<E014;3@0=1`T00P0W8B<03@0:10H05Q0@01XD5P0D3Q80
71DM01`D7`0<1Q007aTU01/E7`0H5Ah08b0W01/I7P0P7b@00P0V9B/0=P0X:2l0:2/b02@X<@0/<c`0
=T1903U3C@0b?dT0>DMB041@G@0nCed0BUaZ04AFI01;GF/0CV1^045CH@1<GV`0BE]Y04MII`18FVP0
AUQV041BH00iBeH0>4UA03M5CP0c@4T0<Sm7034j@@0Z<CP08bP/02@W;00Y:Bh07A`Q01PH6P0O6b00
50dD01<=4@0I4AH06a8G01XA500I3Q8050T=01T=3`0D20X06@d?01P=3P0A20/06Q@H01@>3`0G3Pl0
5`l=00P1000D2PP04`T701@:2@805PX>01@050P=01H7300G20/05`P;01D62@0D1@P05PL:01d>4@0>
00805PL:01L82`0B0`H04`@701421@0@0@@0814D00/0000I2Pd03P4201H72P<05@H901@04`@700h0
0P0M4A405P/:01881`11>CL0TX^901D@3@0;1P<05Pl=01/C4@0F30/04`P701L;2`0]7al070h>0102
0P0B10@05`T901D71`H050H601T04`D501D71`0E1`L04`D501@61P0E1`L060X:01L92@0F20P05@L7
01@61P0C1@D06Pd<01052@0F31@05P`K00h66`0B2R402PHK01<>8P0I5BH02`DA00l5400J3aL04`H9
00D050D800l05`P;01@5200C10L050D801H72P0G20/04@L800d10`0L41808QHH081dMP0k;c404`L9
01D92`0C1`T00P0D20X01`0@10H050P:01@82P0@10H05`/=01H:300@10H00P0A1@L0100B1PP04`L9
01<72@0C1PT601<42@0<01D62`0F1``05`P=01X;400F1``040<60186200E2@/04`L900l31@0@10H0
4PH80P0@10H01@0D20X05@T;01451`0@10H04@D700<04PH800<04@D701@82P0D20X0100D20X03008
00004`L;01H:3P080000@cLk01862P0G2`l03P8601D93@0O4aL04@D901<72`803`<700T040@801@8
300G2`l04@D900T00@0D20`03`D701862P0N4QH00P0@10P01@0;00<03`D702lS9`0B1PX020000080
4`L;0`0B1PX03@0A1@T04`L;01@8300@10P04@D9030T:00k;c<08ADI00h21P0D20`03`<701X>4P0F
2Ph05?ooool001_ooooo100E2PL07P0D2@H04`P501<81@0C20H04PL401D:1`0F2`T03P@301X>3P0A
1@D04`L70188200D2@T060`<01D;2`0F2PX0;R8R02DI6@0E2@T07A4A038V9P0@1@D07A4A01861P0H
30`03@4101<71`0D20P05@T901H:2P805@T901<050P801D92@0A1@D04`L701@8200B1PH05@T901<7
1`0D20P05PX:01D92@0C1`L0@cLj020D5`0D20/04`P901D;2`0I3@d050T700804`P502405@X60187
0P0F30X07Q@F02PM8P0D2`d03`@701lD600D2@d030<5024F6P2MTYH0;28T00/21@0F2``05@T901L;
2`0M4A406Ph>01H:2P0E2@T04`L701D92@0E2PX04`L701@8200D20X02`4303hb=P0H31006PhB01@8
300F2Ph01@0E2@d0100G2`l060`@01L;3`0F2Ph201L;3`0401T=4@0G2`l05@T=01L;3`806@dA00<0
6@hD01H;4@0F2a400P0J3aD0100E2Q0081DK01D:400I3Q@201@93`0Q01P>4`0J4AH05@lC01LA5@0H
4QH05@lC01LA5@0L5QX05@lC03D_<`0/9RX06A<G01LA500K4Q<06Q4C01T?600F3Q`06A4O01/C7@0F
4AD07A/I01/J600F51H08QlW03Pe?`0L6R0061HL01TF7@0L6B8071TS01PE7`0J5b0061DL008071XM
00<06APG01`J6P0N7R400P0L6b407P0N7B@08B0X01lO9`0M7BL07QlY01hQ:`0P8Rh082<_01lS;P0P
82X08R8[02<S:`0S92T08b@X02<T9P0V9bT092DZ03@e>P0V9Rh09RH`02TY<`0W:S<0;2lh02d`>@0Z
;CH0:Rhg02``>@0Y<3P0:S4i02/c>`80;3Dl00h0:cHl02dh@P0`?DH0:cQ107N4S@1?G6D0;CY303=0
B@0d@DX0<d1903A1BP0f@d`0>4E>03i<E`80>DM@00h0@U5H0391B00mC5<0?TaG03A1D@1@GFl0>TMJ
03e9H@0iB5T0?4eG045AG@10DEd0?dmL04ADH`80C5a/00h0AeMX04EEIP14E6D0@e9T041?G00nC5D0
?D]D03e<E00oCED0@DiF045=E@11C580?dY@03m9CP80@4U>00D0>dI:03U7BP0mBdh0?Ta?03m=D002
03e;C@0=041>D00nC4h0?de?041>D00oCDl0@diC04A>E@15CeD0A4iD049<D`10BU40@TaB041:D002
04==E00]03m9D014CU@0@4]>03e9BP10Bdh0@diA03i9C00iA4P0?TU>03Q3B012C5<0=T58049<E01>
F600BE=B041:AP0f@3/0>D=003]5@`0g@3l0?4E503U2@P0i@T<0>D9403Y3A@18DE@0AU5E04=@EP15
DUd0AE5P04IAI@1>FFl0D5]a04A?H`15DF80BEER04EBFP2]^kl0SIRL03]6B@0oBTd0>dI9041;CP13
CU40@Da?0080@4]>0P0oBTd0800nBD/0?4Y904MFE00nCD`0>DI703e9BP0iA4L0=d5503@m@P0i@DL0
@4M>03i5C@0d>d00@4M802lf=@0nADH0A4]<03@k?@0b>3/0CE=F05UPH`0a=c`0<SPm030f?@0Y;c@0
<SDk02X_=00^<cP0=Se202Ta=@0]=SX0;3<h0P0U:2h0<`0X9bh09R<[02HU;@0_<CX0<38n02la?@0k
?D/0=cQ903PiBP0`<D<0<39103DgA00T9S80;S4j02/^=`0^<S`0;S8k02d`>@0Y;3@09BL^028S:P0]
;C<08b<X02LV:`0K6Qd08b8U02XY;P0W9R`09B@Z02HU:`0T8bT0:2L]02XY;`0S8RP092<Y02PW;@0T
8bT08b8X02/Y;`0`;C@09b@[02HS:P0W92/07a`S02DR:@0W92/09R<Z02@Q:00U8RT0:BH]02PV;003
02@S:004028Q9P0Q7b@08b4V024O90<07QTO01L07QLN01lI8`0M5b4081XT01lJ8@0I51/06QDL01/F
700L5ad07aXN01hI7@0L5a/06A@I01lJ8@0K5Al08A/U02<N9@0>2A0081/R01/F700I51X061<G01XE
6@0201`G6`0K01XD600I4aL07QPL01hH700I4aL06aDI038/<00H4QH07aTM014;3`0L5QX060lB01X@
3P0P5Q@0;2@R03La<@0H51P061LL01DA5`0I51X03@H=02DL8@0O51P06Q0B01<:3@0J51H04P`>0080
5Q0B00h05a4C01D?4@0D3Q0050h@01H@4P0E3a404P`>01D:3P0G3100714E01/@500D2@d05P/?01T>
4P805@X>00D06PlC01hC5`0L4aH04PX=01<=3`0201D?4@<04`d?03405a4C018<3P0P6Q`05@lA014;
3@0A30d0618D01TC5@0F41807ALI02XT9P0J51H04P`>020J700R71h02`D7028L7P0I51<07APJ01<>
400G4QP040/E024L9P0F4ad08R0X024Q:@0L6b006a/O028R9P0X9bd0:BT_02LY;`0V:C0092Pa02`d
?@0i@d`0?T]D03U7D@0nCUP0@U9O04QII`0mCed0DVAb08>EX`1VN8H0DVAb05AVM01@HW00Cf5_0080
D69`0280Cf5_04IGHP0kC5D0>4M@03E2B`0_?4@0;3Lm02Ta=`0T:Bl08B@Y020R9`0M7B80820S028N
8`0F3aH06aDI01dF6P0E3Q805@`?01/@500@1@T06Pl@01451`0J3Q005@X;01<:3@0D3Q805Q0A01/B
4`0S6aT05`l=01@:200C2@L04`T80P0F2Ph0100C1``050D:01D62@0F1`X201@5200P01H72P0J2`h0
3P0201/<3`0C10L06@X=01H72P0E1PT05PX;03<T9`0C10L06P/>01@7200D1@P060T<01L82`0E1PT0
50D801P9300E2@T060d<01881`0C2`T07aTG00h91P0C3P/030L501H>300C2@P040H601<71`0E1`L2
01L92@0301H8200D1PH04P@400H050H600H04`D501D71`0E1`L04`D501@61P0E1`L501H8200>01H8
1`0H30P03`<301882P1IDEX0DdaK00`65`0I52T01`4G018:800D31h081@V00h3400C1@X501@52003
01H72P0E1PT05@H900805@H901<05PL:01<72@0A1@L05@T;01<92P0O4aD050X;0186200C1`T040@6
01<72@0D20X040@601<72@0D20X04`L901D92`0C1`T040@600804@D700@04PH801<72@0C1`T04`H9
1@0C10T301@52P805PL<00l04`@901<52@0F2P`05`/=01<72@0?0`D04PH801D92`0A1@L040@601<7
2@0@10H04@D701<72@0B1PP00`0C1`T00`0B1PP04`L901<72@0401<72@05020D600A1@T04`L;0186
2P0D20`00P0A1@T05`0@10P04PH:01862P0>0PH04PH:01<72`0G2`l04`L;00h21P0B1PX050P<00l3
1`0C1`/0?c@g075UJ@0I3a404PL:00/10`0G2`l0;20T0;jb]P0S5a/040@800H04PH:00`05@T=01H:
3P0?0`L08aLK09R<T03Sfml0Ge=G01hB5P0F2Ph03@4501`@500F2PhDooooo`006oooool02@0U6QP0
5``:00`1000>0`4050T701D:200?10804PL501<81P0201050`0301<81P0@10@060`<00806@d=00D0
714A0104100O4a<05@T901/?3`0201D92@07024E5@0<0P803`<301861P0?10@06`l?00h20P020104
100401451@0B1PH04`L701<71`805@T902P050P801D92@0F2PX05PX:01451@0B1PH050P801D92@0A
1@D03P8201061`0D20X05PX<01P<3P0K3`l05`/;01P=2`0D2@L04PL501<8100B1`<030<20<Fj`01[
H6H08QTM081eN@0H3A4050T=02@J6`0B20T050X;01`B4@0Z81l05@X:01@8200F2PX06Ph>01D92@0C
1`L04PH60P0G2`/0100D20P04PH601861P0L414200h21P0401X>4P0;00<02P0200h41P805`/?00<0
50P<01L;3`0G2`l00P0B1PX01@0F2Ph060`@01L;3`0E2@d06@dA00805`/?02`06@dA01X>4P0J3Q80
6@hD01D:400@1@/050T?01dB600Y7R@02@0401873@0k<3H09Q/Q01L<4P0F31806a8G01D?4`0B3100
4@/?01@>4P0V82@01`45018<400K5AT03PP<01/E6@0C3A407A@G01T@4`0I3aT06A4N01TA7@0N5al0
5A0D01/I5P0I61H04a4D01hK900j=d807AXQ01`J800L6B007AXS01`I8P806AHO00H05Q@J01XH7@0L
6Qd06aTJ020N7`0L6b0201/J800Y01hM9@0P82P07alW01dM9`0P8R/092L`02DW<`0S9S407b<^01`O
:00O7bP08B4Y024R9`0R8bL08B8T02HW:@0U9R/0?d1502LW;`0O7bT092L`02HY<P0Y;3D0:Rdf02X^
=`0[;cP0;30i02P_=`0W<3L0:C8i02df?@0/=C`0:C@j02hkA00[>440>dQA02Xg@00_?4D0@4eF034n
A`0gA4d00P0hADh203M4C@0D03M5D00iAe00<d5:041?EP0_?TD0@U5H03i<E`11CUh0@e1R038oDP14
D6P0CE]^03m@FP13Df00A5AQ049BG`13Df80C5a[04YJJ@13Df<204IFIP0M045AH@11D5d0@DmH03i<
E@0lBe<0?TeD045>EP1LJ6l0H6]a04]FFP13CE80ADiC0419CP10Bdl0=dE8030n@@0e@dH0<Cm203U7
BP18EUT0@U1C03a:C@0oCE00BUQK04UGFP14CeD0@diD045<DP0oBU000P0nBDl303a7C@0903e8CP0n
BDl0?TU?04A?D`0nBDd0>dI:03m:CP10Bdl0AU5E0080Ae9F06D0AE1D03@o@`0e@4@0>TE8041;A`0l
Ad40>4<m03Q3?`0iA400=T10049<C@0jA4H0<C/n02hg?00`>D00?TM?03e7D@0jAU<0@TiN04QCI`1>
FFh0F6=i051KL@1<EfT0?TYH04=@F@0nBe40EfEV05=NH00oBT/0>dM7034l?P0oBd`0?DU903e8BP0m
BDX0?4Q803a7B@0kAdP0>dI803]9C00mBU00HFid045<DP0lAd/0=D1402lh?@0c>d40<3Lm02lf?00a
>3d0<SLj034e=00_=300=SXi038g=`0^<cH0=3Tl03Dm@00d>d40;C@j02L_=P0b>d80<CY1030e>`0]
<SP0:c8h02he>`0W<3D0:S<h02he>`0V:c40:B`c02d/=00V8b`08R4Y02X/=@0X:SH09RPd03HhA@0`
<Sl0:R`i02la?`0X:SL09BLc02PZ=P0`<c`09bXc02T/=@0a<C/0;Rhh02@T;00S8RX09RD/034`=P0V
8bX07adS02`Z;`0k>Ch0;B/a02TX;P0302DT:P0802PW;@0[:S00:BP^02HU:`0b<CL0:bX`01dL8P0S
8BP202HS:P0503Pe?00f<cX08QlV01dJ8@0O72<00`0Q7RD02P0T8BP0928X02<R9`0T8bP08B0U01dL
8@0O7B8081hS01hL8@0N6Al201`G7@0901lH7`0L5R0071HP01`F800I51/06aHM030[<P0I51X06aHL
00807QTM00P07APL01/F6`0J5A`0;2H`02dW<@0>2A005Q4H020K8P806QDK0P0F4AD201/F6P0301`F
6P0J51P071HJ0080618F01@0<2X^0<_5b@18@TH02`D900P21P0G4AD040L:01X@3`0L4A409A/L02XQ
900H4QD05a8H01<<4`0F3aH06@lG00l42P0O4aT05P/?01@;3P805Q0B0P0G4A<02`0A2`d04`d?01<=
3`0E3a405a4C01H@4P0B30h07A8F01D:3P0F2`l06@hB008060dA00T05P/?01P=4@0H3A405``@01H;
3`0C2Pd04``>018<3P0C3@l00P0E3a401P0F418050h@014;3@0A2`d07QPJ01LA4`806A<E0P0@2P`0
:P0L5QP06aDG00l92`0G4A<07QPJ00d72@0J51H04@/=038/;00I5A<08alN00h<3@0K6Ad0924X05QG
G`0f=Cd08b<[01hO900K72407b0T01PI7@0W9R`09bP]02DW;@0T:Bl08RTa030i@@0c?DH0<Sm803A3
C@0kC5H0A5AQ049CH@1?HFl0CEm]05U[N@1KKG/0Bee[05U[N@1JK7X0EVQf051RL080CEm]0240B5UU
03a=E`0hBE40=dM?03=0B@0b?4D0;3Dl02H]<`0Y;S@0:B/`020Q9@0J6Ah06AHL01/D6`0V82@08Q`P
01<=4@0H3a8060dA01052@0H3Pl050P:01L;3@0Q5QL0<RT/00@00P0=1`P05@`=01dE4`0C2`P04`T7
01881P0B20L00P0E2@d0:00B1P/0404601<41`0H2@`05`P;01D62@0D1@P070d@0101100E1PT070d@
020A500C1PP070d@01<41`0H2@`04@8501/<3`0L3A0050D801D62@0D1@P04`@701831P0A0PD09ATI
030U900C2@P040P601XC4@0910401`8002<L6P1TG5X050X901D<300H30`050H601X<300G2@T20143
0`0301T;2`0D1PH050H600@050H600T04`D501D71`0E1`L04`D501@61P0E1`L04`D501@61P0E1`L0
0P0G2@T03P0H2PL04@H002<I400C2PD081HH02PP:`0B31X01`4C01<;8P0G3bH08AL`09V=Y@0^8C<0
4`D;1@0D1@P601D62@0601@82P0M4A<0200001L;3@0800005PX<0P0B1PP01@0>0P@040@60186200@
10H04@D700<04`L900D050P:01<72@0A1@L04@D70186200201<72@0301<62@0C10T04`@900<04`@9
0P0A0PL01P0H2@h08Q<H01/<4@0B0`P040<601451`@040@600@04PH800d10`0=0@<050P:0P0>0P@2
018620<04`L900<04PH801451`0A1@L0100A1@L01@0800006PhB01L;3`0800005`/?00804PH:00<0
5@T=01@8300>0PH00P0D20`0100@10P03@450104200D20`201862P0=00l31`0A1@T0>2d`06aPI00A
1@T050P<01dA5@0G2`l03@<5028F6P0C2@/081@H01452@0301862P804`L;00P040@801L;3`0A1@T0
5`/?06YNHP2aYJT0ASXn01<82`8040@800<050P<00T00Oooool04oooool001_ooooo00P07Q<A01L<
2P0@1@<03`@201871@0E2PP05P/901<81P806@h<00/04@H401@91`0I3@d03@<301T=3@1?@d<0GE5A
01@8200B1PH040@401861P0200h20P0801@8200h;2`07Q8B01@8200F2PX04`L700T0000?0`<20104
100Z01861P0C1`L050P801H:2P0D20P04`L70104100?0`<040@401861P0A1@D04PH601<71`0B1PH0
40@4020D500D20P0200001X>3P0800005@T901T=3@0C20H04@H401<81P0E2PP06PhA028G7`0?10`0
4PL=01`A5`0C20`05@/=0147200<0P<05`d<01H<2P0?1@<04@H501861P0C1`L05@T90`0B1PH0300F
2PX05@T901H:2P0D20P040@401T=3P0I3@l05PX<01<72@0@10H07a<E020D5P8060`>00l050P:01P<
3P0H30h050P;01<72`0E2@d05PX>01D93@0D20`05`/?01H:3P0G2`l06@dA01X>4P0G2`l00`0D2@l0
2`0I3Q@08AHL02lT:P0R5ad06@hD02/P9P0?10X03@8801lE6`0D2a004@/?00804`dA01D05a4E02XT
:00V82@07QPL01TC5`0H4QH091hR02dW:`0O5QT06Q4F01X@6P0I4Ah05`lK01/D6`0C3a0061DC01lN
700K6A`04PhI01DA7`0J5b000P0M6R409@0L6B006QLN01XG7P0L6B005aDK01PF6`0I5aX06aTJ024O
8P0N7B<071/S01/J8P0M72@07ahV01dM9@0N7RP07b4Z020S;00Q92d082</01hR:`0L7bP07R4Y01lR
:@0P8bP082@W020T9@0X;2d0;S4f059EFP0e>3l092L`02T/=@0[;SL0:2`e02T]=P0/<3T00P0Z<CT0
2P0X;cL09Rlf02Pa>00/=cd0:cHl02Td>P0_?4D08c0i03Y7D00]>T<2038oB00B03=0B@0gA4d0>4E>
03Q5CP0iATl0>dQA03Q6D@0nC5D0<Cm803a;DP0c@TT0@4mF03Y8D`11CUh0BEIW04]HJ`0nBV80AE=U
0`11DEh02@12DUl0@e=P04YJI`18F6D0@e=R04EEI00oCeh0>d]J03e<E`0303e<D`0>03m>E@11CU@0
GFU_05aWK@11C500?4I903e7B@0kADL0?DQ:03U7B00lBT/0AE=E03e;CP0jB4/2041>D@80?DY@0P16
DeT3045<DP0N03m:D00mB4h0>dI<04E@EP17DUP0@DaB041;D@16DEL0@4]A04A?E@0nBDl0>dI<03m:
CP11C500Ae9F03Y5A`16DE<0@Da>03Y5A`0h@dD0>dM803Q3?@0iA3`0>dI003Y5@@0h@cl0=d5104QB
E00oB4d0=3e30P0`>D80J00f@4T0>D9A03Q4E@13CV80BEAX04]FK01@Fg40@TeQ045<G00jAU80@4eE
04=@E@0e@d@0<Shn03i:B@0lB4H0>4A4041<B`11CD/0?d];03i:B@0kAdD0>TI603Q4@`0f@D<0=3m5
03e7D01JI6d0>TA=03a6C00h@DP0<3Tn03Ho@`0b>Sd0<cPl03Dj?P0b>3P0;2h[034c;P0`=C40;30_
02`b<P0^<cH0<CTl02lh?@0c?4<0;CM002Pb>`15CUL0=S]202/`=P0U;3809Bdc02Tb=`0S;340;3@j
02db>00_<ST0:RXb02DT;00V9Bd0;Bdg02XZ=00P82X0:RXe02PX=00U9C40;bll03XjAP0[:cD0;2`f
02h^>00f=T00:2P`02d/=00/:c<09RD]02DR:@0[:2l09b@[01hK8P0U8RT061DL02TV;@0[:C009B@Z
024P9P0S8RP092<Y02PW;@0[:S00:RT_02@S:@0];3809RD[01`K8@0U8bX08AhU020M900a;SD0<2dd
024N9@0O72<081dT0P0R7bH201lL8`0302<Q9`0S8RL08B0U00808R4V01008AlT01dK800N724091lU
020K8@0M61h07AHM024K9@0R72H07aTS01LB6@0M61l0@3]201/F700L5ad07aXN0P0P6al02@0O6Ql0
6QDL01hH8P1/IW00I5mV03Ha>00@31806A@J01XE6`0201D@500W01/F6P0J5AT07ALK01PB5P0J51P0
6A<G01H@500Y8bL0=S0d01LA5@0J51P08adQ01D?4`0M51L08QPI01L=3P0D2P/040L:01XA5@0J51P0
718J01/A6@0l<SX02`0801L<500N4aT05Pd@01H@4P0L5QP05a4C01D?4@0F41804`d?01@>400G4A<0
6A<E01LA4`0C3@l0714E00805@X>0P0G3100200K41@050T=01`A5@0M4QH06@hB01@93@0C2Pd05@d@
0P0B30h0EP0D3Q005a4C01TC5@0G4A<02`D7018<3P0H4Q@04P`>01`F600H4Q@05a4C01D?4@0?2@/0
6A<E024K7@0=1`T05@lA018<3P0<1PP0A3i00=C>cP0g=3801@@201/K6`0H61/092<Y0:n`]@11@DT0
6Q/P020S:00B5AT05a/N02<W:P0T9BX08b@Y02@V;00U:S008bXb034j@P0a>d@0<Sm8049AF`15EV00
B5YV04YLJ@1OLGl0FF]i04mQK`1MKgd0FVaj061bP01MKgd0FVaj05AVM01=Gfd0Bee[04MII@0mCeT0
>DYD03];E00jAe00?4I?03<l@`0W;S@0:Rle02LY;P0O82D05aPL01PE6P0G4QP07aXN01lI7@0E3a<0
6A<E01D<3`0B2@`05`d>01`B4`0M4a@0?S@d0=O>d@1<ATX040X;00H0000B2PP03`L40P0B20H0200B
20L05@T=01D93@0B1P/040@80186200F2P`05@T;0P0D20X02`0L418050P:01H:300H30h04PH803L[
;@19?Cl060`>01@:2`0Y7Al05@T;00804`L901L03@4301<72@0N4Q@0710B00`00P1EBDT0]:VY034W
9P0>1P@03PP601PC40091040<BXX07I^K00O5A@04PT901/?3`0H2PX06@/;01D71`0A0`<04`D501X<
300601@61P0601<51@0E1`L05@L701<51@0D1PH05@L70`0D1PH201D71`0>01D7100`8aP04`T001P?
1P0L4a402@8900X43P0E3Qh03`LL00`4701FBVH0XI:a02<E;00C1@/501@520805@H90P0F1`X0200E
1PT050D801D92`0J3Q002P0001@82P0@10H06@d?0P0D20X02P0?0`D04@D70186200A1@L04PH801<7
2@0B1PP040@60186200D20X201451`040186200C1`T04`L901<62@H04`@901<04@8701H7300P4AH0
6P/@01@52P0B10P03`<501041P0E2@/05`/=01451`0C1`T03P8400d10`0O4aD06`lA01451`0>0P@0
40@600804@D70P0@10H601451`0@00h21P0G2`l040H801@8300W6al04`L;0104200D20`04@D900/0
0`0F2Ph040@803DY;@0J3Q802`4301D93@804`L;00`0710D01<72`0C1`/0710D01L;3`0?1@L02@01
00d11@0I3A40200001<72`08000201452@804PH:0P0C1`/201H:3P0701452@0800006@hA02hR9P0H
31002`4300l31`0201@8300301862_oooooooooo01;ooooo000Kooooo`0F01861@0D20L05P/:01D9
200B1`H04PH501D9200B1`H04PH501461@0S61L04`P700h4100H30`04PH601P<300U6QX060`<0186
1P0D20P05@T901@820@04`L701404PH601451@0?0`<05@T901861P0D20P04@D501@8200C1`L05@T9
01861P0?0`<04PH601T=3@0G2`/050P801H:2P0201<71`<05@T900L05@/:02LL6`0O51<040D401X>
3P0A1@D060`<00804`P701405@T801L;2P0C20/03PD;01dB6@0D2@l050T=044f>P0l<S<06@l>00l5
100D2PP060h;00`3000D2PL050P801861P0201<71`0?01D92@0F2PX05`/;01<71`0D20P05PX:0186
1P0C1`P05@T;01X>400E2@/060`>01451`0F2P`05`/=00805@T;00<06@d?01L;3@0F2Pd00P0G2`l2
01H:3P805@T=02`05PX>01P<400H31005`/?01D93@0H3A<05@X@01/@5P0F2a4040D;01T>500L4AL0
4`X>01X?5@0E2Q00714G01X@5@0F3A805@lC01TC5`0F41@04`dA01H@500[9BT05a4E01D?4`0J51P0
4@/?01XD600O5QX07A<J01/A6`0D31T091dW01`E6`0I5AD04Q0<01LF4`0N71l09b@^01LC8P0H5Al0
6aPP01`I8@806aPO00`07AXP069PIP0_;C406QPL01hL7`0N71h08R0T01dL8`0N7BH071/T01TG8@0M
7BH2020P:@0B01hO:00M82P08RD]01TL900R9Rh08BD^01hR:P0P92X08bL/02<W:P0M8R808RLW01hR
9`0_<cL092P^02@W<00/;cP0:Rhg0P0T:3401P0W;CD09bhf02D]=00X<CP09c0g02Tc>P80;CPn0100
:cHl02dj@`0d@DX09c@m02llA@0f@d`0=D9;03A1BP0gA4d0>DI?03Q5CP0kB540@DiG03M5D00jB540
<T190P0gATd01`0lBe80?4YE041=G@13D680Df1c04IBJP14DV@00P14E6408@0oCe`0?4aI041@G@15
EF80@U9O04YJI`13E600=TMB03Y:F00iB580=dI=03U8C`0oCU@0@U5F04=@EP15DUH0AE1D049=D@15
Ce80?dU;03e7B@0mB4X0@Dm@04=ADP0kBD/0?D]>041>D@0nC500>dU=03m<D`0hAD`0>TM>03m<D`02
03m;D@80@4aB00/0?d]A03e9C`0lB4h0?TY@03Y6C00lB4h0A51F049>E011C540?TU>041;D00204IA
E@0404E@D`0kATP0AE1B04=>C`80?TU:04/0?TY903I2?@0nBT80@Te8049>B`0mB4H0>DA5045;D00m
Add0=d1903m8DP17D5`0ATmL03]6E`0mB5/0@TeQ05EPM@14Cf<0A4mQ04UEI@10C5T0?daD03]8C@0j
B4X0>TQ803i:B00lB4H0@De;04IBD011CD/0AE5?04A@CP0oBdT0>dM503Q4@P0b?S`0=D5104==EP0h
@T`0?dUC03HoB00c?4@0=Si603@l@@0e?400<cTl03@i?00c>CX0;C4a02h`;@0a<bh09RPS02``;`0]
<c<09bd]02de>00c?4<0=d1707^5SP0i@dd0CeQQ0415C@0]=3/092/b02L`=P0^>3h0=T1503Y3B@0[
<ST0<SHn02PZ<P0V9Bh09bH_055AFP0n?TL00P0V9Rl0600Y:C808R8[02XZ<`0];CH08B4Z02h^=`0J
6R<09bL_02TW;`0Z:2l0:BL^02/X<00Y9Rd0924X02DR:@0V8b/0:BL^024O9P0X9Rd08b8X01`K8@0M
72808B0V02<R:0<09bH/0P0Q82H201lN900402PV;00R7bH07Q/R01hK8P8071TP0P0R7bH202<P9`0c
024N9@0S82L09B<Y024P9@0L6b007A`Q02LV:`0U8bP07A/P01lM8P0T7bD08A`R01hI7`0M5Qd0618L
02dW<@1dKWP0:2<Z01LB6@0S7RD07APN01hI7`0O6Qh081/O01lJ7P0P6b009B0W024K9@0V82X07APO
01D@5`0L5ah07aXP01TD6P0L5a/091lS024L800M61`06Q@H01LA5@0J51P06aDI01H@500H4QH05a4E
05]EF@0O6Ad0618F01TC5`0D3Q805PlA00807aDG01H071<F01`C5`0G3Q<05PdC02<I8@1<@TX081DN
01/@6@0K4QX06A<G01PB500N61X06A<E01@>400G4A<03`T;01H@4P0J51H07ALI01H@4P0C3@l060dA
0P0G31004@0F2`l05``@01/@500F2`l0714E01hC5`0K41@06@hB01XA500D3@l0618D018<3P0C3@l0
@cdo06USI@0F41803`T;00805@lA03l04@/=01LA4`0E3a403PP:01/E5`0G4A<040X<01LA4`0E3a40
6aDG024K7@0T7R003@L902XV9@0I5a<06a/I00l?3@0F5QP051DI03@e>@0H6Al071lT01/N8`0E6A/0
7B4R01XN7`0R8bP08R@Y02@X;@0X;C<09Rde02df?P0^>d<0=D=<04UJH`17FF<0AEMS04aOK01=Gfd0
EfUg05a^O01NL7h0I7J4069dPP1QLh40H7:005]]N`1CIG<0D69`04]NJ`12EF00?DiI03Q9D`0b@4T0
;ca502hg?`0/<c/0:c0f02<W;@0N82D07QlT01hL8@0J5A/00P0H4aL05`0E41@05Q0B01XB5@0K4aH0
60l@01@;300G3Pl0<2HV07=ZK@0V82@05Q0A01<:2`0G3`d05Ph;01@:200C2@L04PP701@8300C1`/0
4`H<01<8300D2@X05@X;008050T:01005P/=01051`0C20X060d?00l41P0>1@D0CT=506mTI@0L4A<0
9a`N069GF@0F2``05@X<01/@4P0?10H06Pl@0P0_92H03P0D2@/0BShn085hM`0B2@T04`/901<<2P0C
3P/06QDB00l81`0L51805`d<01<8200D20P050H60P0E1`L201H8200501D71`0F20P04PD501D71`0D
1PH00P0E1`L00`0D1PH05@L701H8200601D71`0@01@61P0C1@D04`D201d?1@0O4`P04@L101480`0A
30/03`P=00`64@0L52D05P`S01/>:`0=0Ql03`<K01@530805@H90P0D1@P01@0E1PT050D801D62@0F
1`X05@H9008050D801P050P:01451`0H30h04`P901882@0T61X06`lA0186200A1@L04PH801@82P0B
1PP04@D70186200>0`D03P8401<72@0B1PP03P<401H:300c9bT05PX<0186200B10P201@52P0B0143
1`0L3A80408601H8300>0@@04P<801<52@0J2a0040@601L93@0E2@/05`/=01lC5@0M4A<04PH801@8
2P0B1PP04@D70P0O4aD00`0E2@/03`@501L;3@0201451`0=01X>400Z7R003`<501X>400S5aT03P<4
01451`0E2@/05PX>00h31P0B1PX06@dA00`2100201<72`0I01D93@0B1PX03`<701L;3`0A1@T0ACTm
02/O8`0C1`/050P<01862P0C1`/0@cLk0104200L41@05@T=01L;3`0A1PT05`/?01D93@0@1@P050P<
01H;3P0N4QH04@D901862P0201<72`0601862P0A1@T04`L;01452@0E2@d050P<0P0C1`/01P0H3100
5@T=01452@0D20`04@D9010521Cooooo000Kooooo`0301P<300D20P04`L7008050P800T04PH601D9
2@0K3`l02P0001P<300L41003P8201<71`0E2@T00P0F2PX02@0E2@T04`L701<71`0A1@D03`<30104
100A1@D04PH601<71`0201861P0301<71`0D20P050P800804PH600X03P8201P<300K3`l07a<C01H:
2P0B1PH05PX:01dA4@0I3@d04`L71P0D20P01@0M4Q00<bPV02DJ600A1P@06`l?00805@T901H04PH6
01@8200C1`L04`L701872`0E2Q004PL=01052@0@1PL04PP901L=3@0H3Pd04@L50147100E30L06a8=
01X?3P0D20P04`L701861P0C1`L050P80P0E2@T01@0D20P05PX:01T=3@0H30`05PX;00<05@T;0P0D
20X0200G2`d05PX<01<72@0G2`d06`lA01T=3`0F2Pd05PX>0P0G2`l301H:3P805`/?0`0F2Ph03@0B
1`d03P<9024F700L4AL04@H<01052`0E2Q005``B01D:400D2@l05``B01D;400F3A800`0D3Q8201D?
4`<05Q0D03`05@lC01H@500F41@04`X?01L=5@0M4ah04PXG02`U;P0M5aT05a<@01@B3@0I61@04Q0C
01`I9@0I5B@081dX01`I8P0J5b006aPO01XH7@0H5QT0<Blb01hL7`0K6A`07Q`O01/I700I5a`07A`T
01PF8@0Q7bX0;B/f024P:P0H628071`T01/M900G6R406QdT02DY;`0A5Q`0720Y02@Y<00T:Bl07R<W
01hS9P0V;2`09B/[02DZ;P0V:bl0:Bhd02``>@0]<CX0:Rhg02L[=00X;3D0:C0h02H_=P0T;C@0:C8i
02Pc>@0Y=3X202dh?P0502/f?00]>T<0<3e602dj@`0`?DH00P0e@T/07P0b?dP0>4E>03e:D`0jAe00
>DI?03e:D`0e@dh0=49;03E3C00hAdh0?4]B03i=E00lBUD0?DYJ03m<GP1?G6l0Ce]c045?H@0mCEX0
@51M045AGP0nCU/0>d]H03m?G010DE/0BEYT049CG@0kC5H0@E9L041@E`80?diE00L0?4]A03Y9CP0o
CE00?T]>045<D00nBD/0>dE70080>D=500h0?DQ:03Y8B@0e@d@0>TQ:049@D`0oCE00=45603A1A`0o
C5@0@4eF03i;E012CeP0?T]C03i;D@<0?daB00<0@4eC03Y7C@0kB4h00`0lBDl01@0kB4h0?dY>03e8
BP0mB4/0@Da@0080@di@0P0mB4X06P14D500@4a<04YFEP1AGEd0@4a804A@C00lB4H0?d];03i:BP11
C4l0@DaB03a6C`0b?4H0=T1<03e7D`0i@U40@diP04aGJ@16DF<0FVEg04E@H@0f@U00>TIB03U6CP0g
A4X0=dE60P0hATH0C00mBDT0?DU8041<BP12CTh0@De<03i:B010C4`0=T9103A0?P0jATH0@Ti=05YU
I`0oBU00=d5;03I0B@0f?dP0<SY1038i?`0d?3l0=C`n03Hl?00e>c/0;cDc02T^:P0K7AX0<S@_02L/
:00c=cH09B/[02H[;P0X<3<0>D9704]DF`2S[KH0=T19030i@P0Y<3P0<3Lo02/d>`0Z=3X0:SDk051K
H@0mATd0>D1802`c>`0T9c00:BTc020N:@0`<3P07alW04Q8D00Z:S406a`Q02<T:00W:2d0;2db02l_
=`0Q8BT0:BTa03He?@0V8bX09b@[02DR:@0X9B`09b@[02HS:P0N7B<05A8K01PG7`0X:300;Rde02PW
;P0M72808R4W024P9P0O7R@202<R:00;02DT:P0S8RP08R4W02<R:00T8bT0:2H/030]=00a;SD09R<Z
02<P9`0U8RT00`0S82L2024N9@0902@Q:00W9B/09RDZ028Q9P0Q82D0;bhc02d[<00T8RL081hS0080
71LM00H07APN01lH7`0X8R`0:B<]065KI@0Q72<201XE70807QTO01407QTM01dH700L5a/071LL020K
8P0I4ad07ALQ01`G7P0M61l05A0G01`G7@0F4AL06aHJ020K7`0H4aL05a8F01XD600201TC5`0G01PB
5P0I4aL06Q@H014;3`19@dL05a4E01D?4`0J51P06aDI01XD600@2P`04P`>01@;3P0J4AD06Q4F024H
7@0G3Q@06Q0H01hG7`0M5Al03@H>020J7P0G4A<00P0E3a401P0D3Q005a4C01H@4P0H4Q@05@lA01/E
5`8050h@01`06PlC01L<400D2@d050T=01L<400J3a<060dA01T>4P0H3A405``@01T>4P0J4A@05a0B
01LA4`0I4aD05@lA02XT9P14?T005@lA018<3P0A2`d04P`>01D?4@0G4A<05@lA01H@4P0G4A<0618D
0P0G4A<08P0C3@l05Q0B01lI6`0L5QP050h@01H@400G5A405aHB01@D4P0I6AX06APM01<D600F5a`0
61TN01LK7P0I7Ah07R8Q024U9P0T9RX082<X020U:P0Q:2h08b`c02Hb>@0]?4<0<Cm803a>E`10DU`0
?e=N04ePK01BI780FVaj06=eP`1XNXP206]mR`0V06UkR@1VN8H0H7:005Y/NP1FJ7H0DFAa04QLI`13
EF40@59M03a=E`0gA4d0;SU202`e?00[<SX09BT`01hQ9P0N7b@081lT01lJ800F4AD05a8F01<>4P0[
9BL0;bT[00D00@0J4A808aXK00h51P0A20P05a4C01H@500D3Pl05Pd>01TA3`0M5A805P`:01D;2@0D
2PT201<72`0401<7300D2@d050X;01@:2`@04`T:01H03`D60147200J41406a4B01@:2`0I3a005P`=
0147200N51D04@L801882@0700004PP901<92P0700006Q0A00`20`0<00008AHE01hD4`0D30X04@X8
0P0:1@801@0@2PL04@T701061@0B1`H05@T900H050H600P06@/;02<E5@0E1`L04@<301D71`0>0000
50H601D71`805PP800@05@L701@61P0C1@D050H60P0E1`L04@0D1PH04`D201P:0@0H2P405`X101D;
0`0C30H04@`901@=4`0h<3l0:b8e01<6800C12D05PHP01@5300F1`X05@H900804`@701L05@H901H7
2P0B0`H050D801P9300F1`X050D802TM7`0W6ad040@600/10P0l<380QGUk01<72@0H30h081@F01L;
3@0B1PP02P0101451`0K3a4060`>01451`020186200C01@82P0A1@L0<BDW01<72@0A1@L04@@70183
200E1P/07PlD00X0000F1``060T>01X;400N3a@06``A01H7300G20d03P<401P<3P0201D92`0301<7
2@0?0`D050P:00H04`L900h05PX<01041P0B1PP04`L902/O8@0H30h04@D7034U9`080000:1`N00d3
100C1`/04PH:01452@8040@800L04@D90104200<00@03@4501<72`0E2@d05PX>00H04@D900h08aLK
00T00@0J3Q805@T=0104200B1PX030040104200B1PX040@801D93@0=0@D040@801862P<04`L;00<0
4@D901862P0B1PX0100B1PX01P0M4AD04`L;00l31`0B1PX04`L;00d11ACooooo000Kooooo`0=01P<
3P0E2@/04PH80186200C1`T040@601H:30080000710B00l31@0E2@/040@601<71`0401@8200801<7
1`0E2@T05`/;01L;2`0F2PX04`L701861P0D20P201<71`0?01@8200E2@T05PX:01D92@0C1`L03P82
00l30`0>0P802`0001@8200C1`L05@T901L;2`0D20P04@D500H050P801h06a0=02PM6@0T6AD050T7
01X?3@0F2`T04`L701041P0C1`T04PH801451`0C20/06@hB01H;3`0B20T03P@500/10P0B20L050X9
01`B400F30X04@L50106100<0P804PH601D92@0D20P04`L701D92@0F2PX201@8200601P<300J3Ph0
60`<01D92@0C1`L050P80P0E2@T02@0D20P05PX:01D92@0C1`L05`/;01`@400K3`l06@d@01L;3`02
01H:3P0601L;3`0H31005`/?01H:3P0E2@d05PX>0P0G2`l03@0L4AL060dC030U:`0X7B<081DK01D:
400G318050T?01H;4@0G31805@X@01H<4P0H3a@00`0F41@201D?4`0a01LA5@0I4aL071HJ01dG6`0K
5AT0618F01H<500H3QH08aTU01D=6P0M5Ah050h@01lK600F50h06aXF010>4@0B3a/07a//02@P;P0N
6bD06QLP01XG7P0I5a`0518E014?4P0O7Al08AlR01hL8@0R82D08b0W02TW<P0H5R<0<Bll02@R;@0M
72H08b<]028R:P0O8BP0:B`c01/N8`0S9b/07B8X01TM9P0T:30092T_01`Q9@0N8bH0:S0`02@Z:P02
02@Y;@0C02H[<@0W:c@0:2`e02H]=@0W;SH0:S4i02dd?00Z<cX0:34h02dh?P0[=S`0;3Lm02hk@@0]
>T00;3To02dj@`0`?DH0;CY302llA@0303A1BP0303U6C`10CEH0?T]D0080=dA=0100=dE@03I4C@0f
A4d0>DQ?03a;DP0nCE@0?4YE041=G@0mBU`0AeAW04]GK`16E6L0?DeL03Q8E@0oCe`0@e=P0P0jBeD2
03i?F@0=03e>EP0kC5@0>DYB03Y:D@0jBDh0@4mD03e<D@0jBDh0@DmB045=D010Bdd0?DQ:03Y4AP02
03U3A00D03]7A`15De<0B5IG03i<CP0mBdh0@4eC041=E017E5`0@e1I045=F00jAU80?4UC03]:D@0n
CE80@E1E03i=DP0kBTl0?DaA03Q7C00jBDh203e<D@0603]:C`0iAd/0?TU;03a8B00kAdP0?DQ:0P0o
Bd/03`0lAdT0>dI8049=C`11C4h0C5MI05MSI013Cdl0AE5?03]7A`0nBD/0?dY>04=>D`12CE<0>TA=
03<mA`0203<mB@1L03M1CP11CEd0?4QH02Lc@`0^>TP0A51M04AAFP0f@d/0=T=803E3A00fA4D0=dE5
03Q6AP0mBDT0?4Q903i:BP10Bdd0?TY;03]7A`11C4h0?4Q902Xf=P0Y=3H0@De>07f8RP0g@4L0<ca4
03DnA@0f?dH0<SXo038j?@0_=3P0=3Tl03Dk>`0d>3T0;C4`02T^:P0/<Bd082DQ02L[:P1]LW80B4e@
030e>00]=CP07bH/01/R:01:DUX0;3Dl03M0A`0e?4@0:c8j028[<P0`>T409c8h041=D`0g@DP0>3m7
03@k@`0h>d@061PR030`>P0V9Bd08b8X04=2B00Z:Bh0<c8g02HV:00/:c0071/P02`[<@0K6R009B@/
01XI8@0W92X0:BL/02HT:@0X9B`09bH/02/Z<@0[:c<09bH^02TY<P0Y;3D09bLa02DT:`0R8BL09bH/
024P9P0K6R008B0V020O9@0S8RP302@S:@0602<R:00U8bT0<2dd030]=00P7B@07a`S0P0N6b8202DR
:@05028O9P0P7B@08AhU024O9@0R8BH00P0P7b@03P0Z:Bh09bDZ02<Q9P0Q7b@06QDK01dH7P0Q7280
8Q/R03Tc?@0W8B/07QPR01lJ8@0N6B0061<J0P0M61h0400M61`071LK01`G6`0L5a`05A0G01XD7P0O
6B<06aHM02PS:P0Q72<07aXP020K8@0N6Ad061<G01LB5P0J5AT201XD600401TC5`0H4QH06A<G01XD
60<05Q0D0P0N61`03`0T7R805A0D01<>4P0W8RH07QPJ01dF600<0`H0>2ld020H7P0J4aX08QdT028L
9`0I4ad08adQ01/E5`0201XD5P0:01PB500J51H05@lA01@>400>20X05Q0B01<=3`0B30h060dA01L<
40805P/?00<05``@01P=4@0E2Ph00P0H3A403P0F2`l060dA01/B5@0Q6A`03`T;01<=3`0D3Q003@L9
00`6200H4Q@050h@014;3@0B30h050h@1`0F4180BP0E3a4050h@01@>400E3a405a4C01PB4P0G4`l0
5a<@01HE4`0O7Al071XO01<B5`0D51T05QLK01PI7@0K71h0828Q02<T9P0U:2`07b8W01dR9`0P9bd0
92dd02Te?00_?TD0<3i703i?F015Ef40@eMR04mRKP1GJGL0GW1n06IhQP1/OX`0Kh6?0722T01]Ohd0
JWb:06EgQ@1OLGl0G6il05MYM`1:GF/0@UAP045CGP0oD5X0=dA=030kA00^=ch0:S4i02D[<@0Q9R`0
7b8W020P9@0K6Ah05A<F01XG6P0B3A40=c<d0<o9b`1=AdT02`H601L>3`0@1`P0610?018<3P0B3100
4`d>01L>3`0I4@l071@A01P>300G3@/05@/:0P0D20`0100D20d050T=01@:2`0C2@X201882@0;0147
200G3@h04`T:01882@0I3a004PP901D;300@1PL02@000107200@1PL00P0A1`P04P0S6AX06@l@00`2
0`0W7Ah030<302@J6`0:00004PL601D;2P0A2@L03`P6010;200?2PL07aPF01L?3@0=0`803`@30186
1PH04`D500L06P`<03PZ:P0D1PH050H601X<300?0@4050H600@05@L700<050H601<51@0D1PH00P0E
1`L0A00D1PH04`D401P90`0H2@805`X201D;0P0C30@04`/801@>400n=3l0;b@d01<57@0B0Ql04`@K
01D6300F1`X05@H901<41`0B0`H050D801P9300@0@@04@8501T:3@0H2@`04`@701@82P0@10H05@T;
028F600K3a405@T;01H:300W6ad0<2@V024E5`0K3a404`L90186200<00804@D701@82P0?0`D040@6
01/?4@0<008050P:0186200C1`T04`H901h?500<00804@@701P93P0]7R<02`0101X;400=00<040<6
00d00`0J2a0060X>01L;3@0D20X04@D700l31@0>0P@05@T;1@0C1`T0300E2@/040@60186200E2@/0
2`0101H:300@10H0200001<72@0H30h03@4301<82@804`L;00X04PH:0104200@10P04@D901lC5`0D
20`03`<701@8300@10P03P861P0@10P01P0?0`L02`0301862P0C1`/04@D901862P804`L;00H04@D9
0104200h;3008aLK0104200A1@T201<72`0301@8300C1`/04PH:00D04PH:00H060`@01<72`0@10P0
4@D901862P0A1@TDooooo`006oooool0300C1`T050P:01041P0B1PP05PX<01451`0F2P`0?S8d0188
2@0E2@/05`/=00h210L04`L700P060`<01dA4@0J3Ph04@D500d10@0H30`05PX:01D92@8050P800d0
5@T901861P0G2`/06@d=01P<300K3`l03`@401D92@0G2`/05PX:01<71`0B1PH04`L700D050P800l0
50T701D:1P0G30P07A8>01<81@0D2@L04`P601@8200B1PP050P:01<72P0B1PT050T:01T?3P0E2`T0
0P0D2PT0500C2@L0;28P01081`0>108050X901L=300E2`/050T801H:2P0L41006@d=01<71`0E2@T0
60`<01<71`0B1PH05PX:01<71`0B1PH050P80P0C1`L00`0E2@T05PX:01@8200201D92@0601@8200F
2PX060`<01P<300H30h05`/?0P0F2Ph01P0G2`l06PhB01H:3P0D20`04`L;01D93@805PX>00d060dC
0146300K41H05@X@01<83P0G318060dC01<83P0I3Q@06PlE01<83P0G3A<060lD00805Q0D0`0E3a<0
<@0G4AD06A<G01/E6@0K5AT06Q@H01PB5P0J41P04PPA01dC7`0J4Ql06A4J01LA4@0L6A@061L?018A
3@0E4aH071TW01TE9`0J5RD07Q/V01`I8P0I5Qd06QPL01dK700P7Ql06QPI01/I700M6b006QPM01XG
7`0@3QX09B<`07MePP0b<3`08B0[01hN:00H62007R0W01PK8@0R9BX08bL[01hS9`0O9B/082H]028X
;P0R:B`08BLZ01hU9@0T:b/00P0T:bh0300U:c409BXc02DZ<`0T:c<09Rde02P_=`0]=Sd0<ca303Do
AP0]>3h0:CDk02Xf?080:cPn00D0:SLm02dj@`0b?dP0<3e603A1BP0403Q5CP0T03i;E00mBU<0=T=<
03I3C00kBE@0>DM@03Q6C`0hAdh0>TU@03]:D@0oCEP0AE9R03m<GP11CV40Ae=[04eKKP15EF@0>DUG
03Y:E`0oCe`0>daF03M8DP0nCeL0@eAL04MHH00mCUD0=DI>03e=DP0kBTl0@4mD049AE@10Ce80@e5D
03i:C00oBT`0?4M80P0i@d@04`0kADH0?d];04]IF@1=Fe`0?de?03e;CP0nBe40>TM>03a9D@0f@Td0
?TYF04=?G00jAU80>DQ?03i=DP13DUL0?DaA03U8C@0lBe000`0kBTl0:00lBe00?TeB041?D`0oBdX0
?d]803i:A`0mBDP0?TY903i:BP0nBD/0>TE7045<C`0lAdX0?TU<049=D@0lB4`0@TiB045=DP18E5T0
A51G03a8C`0lB500=D1903<nA`0b?DH0;SY303e9D`15DUd0?TYE045=E`0a?TP0>DI=03A1A`0hATT0
>4I703Q6AP0iAdL0>dU703a:BP0lAdT203a7BP1:03e8B`0kATT0=d9503a7BP0c?T40;CPk04=>D@0c
?T40=d9403Ho@P0c?3l0=d5403Q1@`0c>c`0<CPi02X_<@0^=3<0;S<a02/_;P0Z;b`0;C<`02hf=00]
=3<09Rd^03m6A`0_=CP0:2la02L]<00W;S40;S@i02`b=`0_=C`0:c4h03m6CP1HHFT0=d1803<mA@0]
>T40;ca3069]M01>Eel0=3]402LZ=00[:cH07alY024P:00V9B/08R4W02HU:@0];Bh07QhM02@T9@0T
92H08B0U02`[<@0R8BT0:RT_02@S9`0X9bX09B@W02@S:00T92X09RH]02@U;@0R92`08bH_020U;P0U
:380:B/c02@S:@0Y:2h08b8X01dL8P0S8RP2024P9P8081lU01/07ahT020O9@0Q7bD0;2T`02h[<P0Q
7RD09R<Z02@Q:00M6R408QlV02<P9`0Q7RD08QlV01lL8`0M6b407ahS01hM8P0P7b@08b8W01lM8P0M
6b006aTN01TD6P0Q72809R4W028K8P0Z92h00P0N62800`0R7B@050lF01`G7P0201`G7@<071LK0100
71LL01`G7P0Q6bD07QPR014<4`0J5A`0;RT`01/F700P6b406aHJ01HA5@0K5QX06A@H01/E6@0J51P0
6A<G0P0H4QH05@0I4aL081XN010:3P0L5QX07QPL01/E6@0F4AD05QDJ01lO900@3a804`lC01LA500H
4A<050d@01TC600I5A`040hG01LF8@0>31@06QDI01XD5P0201lI6`0901LA4`0C3@l04@/=01XD5P0B
30h05Q0B01@>400E3a405P/?00@060dA00P05P/?01@93@0H3A405``@01D:3P0G31006a8E01/D5P80
5Q0B00/04P`>01<=3`0H4Q@07ALI01PB500E3a4050h@01H@4P0G4A<05@lA01<=3`02018<3P804`d?
04L05a4C01XD5P0G4A<06A<E01/E5`0G4A406ADA01@@3@0E4@h08AdN020L800H51T05Q@I01PG700I
6Ad06QXK01`M700N7b007b<W01lT:00S:Bh0:C8g02lh?`0`?4<0<T5802hoA`0nDET0C61Y04QLI`1@
Hfl0F6Yh05maO`1WNHL0KGn=0763T@1cQI<0LH>A06n1S`1[OH/0IGN5069dPP1JKG/0D6Ab04aNJ`15
Ef80?4eG03M5D00f@DX0;cU202P_=`0U:c8092T_020S:@0M7B80928W028P8`0N6ah0510D01/G600Y
92H05a8D01dG5`0=1PL05@h>01L?3P0B30h04P`@01<=3P0D2``04PX801491P0201L=2`0801D;2P0D
20`050P<01@83@0D2@d050X;01<92P0A1`P201061`0N0107200G3@h06a4B03L];P0[8b<060l@01<;
2`0K4Q<0610@01061`0?1@H04@L801D=3@0K4Q<07QDF00X20P0j<3404PP901L;2`0D2@P081HE020H
5P0A2PP03@P500h91P0N5aD05`l=01061@0C20L04@D51P0D1PH01`0B10@09aTI00`0000G2@T05PT9
01D71`0C1@D0100E1`L201<51@0D01@61P0E1`L05@L701@61P0C1@D06@L901L81`0F2@D050X3018;
0P0B2`@04`d:01/A5`0E2a@05PTK01H67P0=0A805PH=01H72P0E1PT201<41`0301@5200L3A006@X=
00804`@700`05PL:01<41`0F2`d0=b/]034U9`0C20T06`lA01<72@0A1@L05`/=01dA4`0A1@L201<7
2@0H01L;3@0D20X05PX<0186200?0`D05@T;01051P0B1PP04PL80186200D20X06Pd@01<42@0H2@h0
5`P=01H9300C1`T06P/@020A5P0E1P/06`dA01P93P0I2`l03`850`0F2P`00`0C1`T03P8401<72@05
0186208040@600d04@D70186200D20X04@H701<72@0E2``040@601@82P0?10D04PL801@8300C1`/0
4PH:00804@D900L04PH:02@H700G2`l04@D901D93@0?0`L03@<500H04PH:00D03`<7024E6@0F2Ph0
60`@01@830020105200501@8300C1`/05`/?02lS9`0R5QX00P0B1PX301452@030104200B1PX04PH:
00D04PH:00D04`L;01862P0A1@T04PH:01D93@0Dooooo`006oooool0300C1`T05`/=0186200E2@/0
7A4C01L;3@0M4A<0A3Pj00T0000O4aD02@0001L;3@8050P80P0C1`L201@8200501L;2`0C1`L03`<3
00l30`0B1PH00`0C1`L0400D20P05PX:01P<300I3@d060`<01H:2P0C1`L02P0001T=3@0?0`<05@T9
01H:2P0E2@T04`L701861P0C1`L501@8200Y01@91`0C20@04`P401P=2@0D2@D05P/901871@0D20P0
50P:01L;3@0F2Ph04`L;01L<300L4`h05@`701D;2@0H3P`05`d;040f=@0P5QD050X901H<300I3a00
200001P=3@0I3@d0710@01X>3P0E2@T050P801T=3@0D20P04@D501L;2`0D20P05PX:01/?3`0F2PX0
4`L701@8200G2`/00`0E2@T201@8200301<71`0D20P04`L800804PH:00/04`L;01@8300F2Ph05@T=
01L;3`0I3A405PX>01@8300E2@d05``B01D:400201/@5P0;01T>500P5A/05``B01P=4`0M4QP06PlE
01D:400G3A<05@`A01<=4@0D3Q800P0E3a<0=@0F41@06A<G01PB5P0F41@05@lC01H@500I4QP07aDN
01<9500D2AL05@dJ01H?5P0F410040d602XX800H5a<04a4D01TF900J5BT06ADT01lK:00M6R<05a@K
01LE600N71d07A`J01`K6P0X9RL0928W01/I7`0[:340;2Xg01XH9P0[:CH081h[02PW<`0a<C/09BD]
024S:@0O8RL092L/018F6P0V:bl07B@Z02Xa>00Z<CL08BT/01hV:00U;Rd08R/Z02<[;P0T;2l092/a
00808bXb00L0:S4i02L^=P0U;3@09c0g02hi?`0c?T@0;cY00080:SLm04H0;CY002ll@P0_?480;S]4
03A1BP0c@4T0=T=<03Y7D00iATl0>TM@03M4C@0iATl0=dA=03I3C00iATl0=D=>03E3C00fA4d0>TU@
03i=E00oCUD0@4iI04=@H013D680@e1S04A@J010CV40>d]J03e=G00oCed0?TiK03a=E`0jBe@0?TmG
04aMI01AHVT0?DiE03Y<D01;G600BEQM045@E@0mC500@E1C04IDE@11CDl0@4]=03a8B00iA4D0>dE6
03i8B@0nBTX0?D];03m=CP0kBD/0>DM:03i;D@16De/0?daE04MCG`0hA540@4aJ04UEI00iB4l0?DaA
041?E00lBe00>TU>03a;D00mC540>dY?0P0iB4d01@0mC540A5=F03a8A00mBT<0?DU40080>TI201X0
?DU803]6B00g@T@0A4mC045<D010Be40@TaD041=E@13D5P0?DYB04EBFP14DET0?daD03]8D00hADd0
=45902`i@@0Z=cl0=D9:04]HH00`?D<0=T=9030m@`1AGf40LX2003U7A`80>4I604`0>4M403Y9AP0j
B4P0>dI803Y5B@0kATX0?4M;03Y5B@0e@4@0<ci203i9C@0iA4P0CEQL03I1A@16DE<0=Cln034l>00c
?SX0<c`i02`c<@0Y;bd09bd[02H[:@0S9bH08bPT02T^:P0^=3808b/]028/;@0W;c40>T9403Q0@P0`
>3X0;34d02H[;P0Y;S408bLZ03Hi?P0b=CX0?4=<05eVK`0Z<c`07RPa045>EP0_?4@0>D=<045:D`0W
<3T082@_02<S;`0];CL08R0Z02@S:@0`;c@0=CDf01lO7@0];B/09BDS02`/;00A4A<0;2/a02d/=00Q
82H08R4U02PX:P0S92H08B8V02<T:@17BU00C55G02lc?00Z<CT0;3<k02D/=P0S9Bh08B0V0P0V9B/0
300U92X0:2L]02@S:@0U92X08R4W01lN900N7B<07ahT01/I800J5ah06aPO01XG7P807Q/R00L07AXQ
02<P9`0S82L081dT02LT:`0U8RT07A/Q00807A`Q00l07QdR01`K800I5a`05Q@I01@B5`0I51X08QdS
02@O9@0P6B006aDO010:500T7RP081/R01HA600Q72<00P0K5Q`04`0K5QX071LK01`G6`0L5a`05a8I
01TC7@0Q6bD09B0W03@_=P1PFf805Q4G01TD6P0H4aL06A@H01hI7@0G4QH071HJ01/E6@0J51P00`0H
4QH05@0C3A406aDI01LA5@0G4AD06aDI018=4`0:2a0051LL01@E6@0P82805a@F01TC5@0D3Q003``?
00d<4P0=3AD0F5]U03@d?P0O6R005Q0B01<=3`0201@>400901PB500J51H081XL00d72@0?2@/04`d?
01H@4P0F2`l05``@008060dA00@05``@01H;3`0I3Q8060dA0P0G31000`0H3A405`hA01D>4002010:
300c018<3P0@2P`03PP:018<3P0A2`d04P`>01D?4@0I4aD06Q@F014;3@0B30h04`d?01LA4`0K5AL0
7ALI01D?4@0B30h04@/=01<=3`0F4180618B024L5`0I510050l<01XD5@0J51P04`hB01dH7P0P6b40
7Q`O01dK700M71X07AdM01/O8`0O92P09B/`02Pa=P0Y=3X0:cPo0393BP0a@TX0?U5I04mSK019GfX0
DVIb05e_O@1SMH<0JWb:0763T@1eQiD0N8ZH0080MhVG02@0M8JD06anS01WNHL0GW5o05Q^N`1HJgT0
BUeZ03]=F@0kBE@0>DE@030j@`0Y<ST09bdd02DZ<00P8bX07QlU02d[<00T8RD05Q@G01XH6`0A3@h0
4`l@010<3@0=1`L04@/;01lI6@0D30/04P`>018<400C3@h05@`=01D=2`0D30T05P`:01D;2@0D2PT2
01<72`0401<7300D2@d04`X;01892P804@P901l040L800l61`0A20T0>C0a0<k5aP3Id=40@3Lh04Po
@02LTi@091/L01L>3`0I41403PH703Xa<P2IT9405@`=01XA4P0@20T02`8301451@0@1@D07aDD02<K
6@0I4a005A0=00`7100@2PL04`/901<9200B1`H03`<300H05@L700L05PP801D71`0>00006`d=0186
1P0F20P04`D500@050H60P0C1@D04P0D1PH05@L701D71`0D1PH050@701P43@0F1@/05@L701@80`0B
2@004@X001L@200=1@<040L:01454@0A0QD05PPG01@52P805@H900L04`@701@5200E1PT07a0C02@E
600I2Pd04P<600805`P;00H07a<E02dQ8`0X71h04PH801H:3008000201X>4004028F600M4A<06`lA
01P<3P80200001L03`<501041P0D20X05`/=00P0000E2@/04PH800d10`0B1PP050H:01H7300T5AX0
6`hA08enP`17>3d0:1TN0=C5bP0P4AH07A0C01L83@0:000070hB01H:300200l31@030186200@10H0
5@T;00D04@D700`040@601T=3`0B1PP02`0101/?4@0C1`T03P8402dQ8`0C1`T040@601451`0F2P`2
01@8300501<72`0B1PX04PH:01862P0@10P00P0>0PH00`0@10P04@D901452@0601@8300>00h21P0M
4AD050P<01L;3`0B1PX03`@701452@0G2`l04`L;01862P0>10H040@801<72`0B1PX3010420030145
2@0B1PX04PH:00@04PH:00H03`<701862P0B1PX04@D901862P0D20`Dooooo`006oooool03P0C1`T0
60`>01451`0C1`T0710B01@82P0M4A<02@0001T=3`0C1`T04@L801hB500F2PX05@T90P0C1`L0200E
2@T05PX:01L;2`0E2@T04PH601<71`0E2@T05`/;0P0B1PH03@0C1`L05@T901L;2`0H30`040@401dA
4@0R5QH0710@03/_;`0b9RH04`L701451@0@10@00`0A1@D501@8200J01@91`0D2@@05P/701L<200D
2@D06@h<0146100D20P050P:01P<3P0F2Ph04`L;01H<2P0L4``05Pd601L>2@0I40/05@/901/A4007
000050X;01X@4P0Z7b<040D901hC4`0E2@T201L;2`0?01H:2P0E2@T0710@01P<300C1`L060`<01@8
200G2`/07a@C01T>300C20H050T701L<2P0F2`T050T700805@X80P0D2@L0100F2`T050P901862P0D
20`301D93@0:01H:3P0L41@081@H01T=4@0D20`05`/?01873@0>0`T05@X@01873@805@X@04@060dC
01lD6P0Q5Q`06PlE01T>500H3Q@05@`A01<=4@0E3a<05Q0D01LA5@0I4aL06aDI01XD600I4aL0618F
01TC5`0K51X081HO01/A700I3Q`050`G01LA5`0K5AD061D>02TW7`0J6AD06ALJ01HB8@0M62h07QX[
01`I9@0J5b006QLN01XH6`0J61T06APF01dK6`0J61T0518G01LD6P0S82/061HS01PF900F52809B<`
02DT;`0I6B<08R8Z01DG7@0O8RL05QXM02lc=P0T:Bd08BP^02L^=@0U;3807bLZ020X:P0Y<S407RLV
020X:`0Q:B`08RT_024X<00P9bl0:34h02L`=`809Bhe00<0:SDk02hi?`0b?D<00P0/>Cl02@0a?T@0
<T5603=2A`0`?DH0=T=<03A1BP0e@T/0=dA=03E2B`0203Q5CP0d03U6C`0d@DX0=45:03Y7D00b@4/0
<d5:03E3C00iB4l0?TeD041?EP10CUT0?DYJ04AAHP17E6L0@dmW03Y8F`0iBEP0?TiM045AG`0oCe`0
?e1J03m@F@0eATh0@U=J04AEF`0dATX0>D]?049CEP10Ce80?Te@03a;CP11D5<0BUQI04IBE013CU00
?d];03e8B00oBDX0@de<03e9B00kBDT0AE=C03m=C`0`?T40@4eC04]HH00lBE80IG5m03m;F012CUh0
K7R703]:D@@0?4]@0P0mC540500kBTl0>DQ=03Q7C00jBDh0?Te@03Y7@00kB3l0?4U103U6?`0iAD40
?DU803e8BP0g@T@0@diB049=D`11Be@0AU1I04=@F@14DEX0>dQB0P14DEX03`11CUL0?DYB03m<E00h
ADd0;3To02dj@00b?dD0>DI<03I4A`0lBT/0=dE603e;B`10Cd`0>TU603U8A@0303Q7A01H03U7A`0j
ADT0>DA:03]6C00lAdd0>dI<03I1A`0e@4H0;cY0041;D@1iQ8X0CEQN028];`0d?c/0;cPc030i=00_
>3<0:30[02L]:@0T:RH08BLS020U8@0S:2@0:RdZ02/_;P0I8b@0<C`n02/e=`0N:2X06R8U02de>00]
<SD0=3Pi03Hj>`0e=SP0<C8f02/^<`0c>d<0=d1901lX<@0iADd0P8fE06=`N00`>d@0;cQ1034j@`0X
;3L06QXV02DU;`0V92h08R4W02d/<@0P82407alM01/L5`0P8Ad06a/K01hN8015A4T0SXfE03dl@P0U
92P0:R/]02HW:@0R92P08bH[02hc>00U;3806b8Z02`e?@0_>44092df028V;P0P7bD092<Y02TX;P0Z
:Bl0:BP^02<R:00U92X08b8X020O9@0M728071/Q020N900P7B@07a`S02@Q:0808AhU00L08QlV02@Q
:00S82L07a`S02LT:`0U8RT07A/Q00<071/P00T061LL01HD6@0F51T05aDJ01XE6`0N6Al081/Q020I
800N62800P0J51h00`0Q72<07QTP01lJ8@0201XE6`806aHJ00/071LK01`G700O6R407QPR01/E7`0C
3QD07QTP02TT:`0H4aT06aHL01`G6`0301XE6@0901`F6P0K5AT06Q@H01PB5P0G4AD0618F018<400I
4aL05a4E00806aDI00l05Q@I01@G700L82@0BDY>024Q8`0;20X08alN01/G600G51L07A`R02l_=`3;
c]@0Y:N`024O900I4aD00P0D3Q001@0F418071HH01PB500M5aT04P`>00806aDG00<040X<01L<400G
3100100G31000`0N4aL060dA01H;3`0201T>4P0;01@;3P0H41<030H800X41P0C3@l0618D01H@4P0@
2P`04@/=01<=3`0F41800P0G4A<01P0D3Q004`d?01@>400G4A<06aDG01dG6@804`d?04P06aDG01PB
500C3@l05a4A020H500M5A806A4?01TB4`0G4AD04P`@01XD6`0N6Ad07aXN01lK700O6aX07AdM01/O
8`0N8bL08bT^02D^<`0V<CL0:CHm03A5C00eATh0@5=K051TK@1<HVd0EFUf05maO`1UMhD0K7j<07>5
T`1hRYP0O8jL07j@WP20TZ00OHnM07B6U01/OX`0H7>105Q^N`1EJ7H0BE]X03]=F@0iAe80=d=>038l
A@0^=ch0:c0i02HZ<`0P9B/07b0V02DT:@0K6ad05QDG01TG6P0H51D07ATJ02LS900K5AD03`T900L1
0@0J5A<04P`>018<400B30d05@`=01H>300F3P/060h<01L=2`0E2`X201@8300401@83@0D2@d04`X;
01<:2`<04PT:01h04`X;01H=3P0e;2d0iMcM0?olo@1=A4D071<D05=:B`0=1@D01`0001hE5P0E30d0
6a8C03Xa<P0<0`@01P0000l8200M51D04`L700l51@0@1PD04`/901PB3`0K5Q<061<@01D>300L5180
6@l>00d20P0@10@601@61P0801H8200H2PX06P`<01X<300D1PH05PP80184100C1@D201@61P0401<5
1@0B10@04`D501@61P805@L700l050H601@41`0H11005PD=01D62@0D20@04PT0014;000F40H02@40
01XA4P0I3AH03P0?01L95P0B0`P00`0D1@P03P0E1PT05`P;01X;3P0P4A@05PL:01D62@0H2@`050D8
00/00@0D20X04`L900`20`0O4aD091PJ0P0@10H0500H30h05@T;01D92`0H30h0200001H:300J3Q00
3@4301L;3@0@1PL02@0001P<3P0@10H04`L900d10`0I2`l03002028C600D1@X09QLL0P0:0000300k
;3402P0001H:300E1P/0:1TN0185200G2`d03P840186200G2`d04`L901@82PH04@D700h06@d?0186
200<00805`/=01451`0C1`T0QGUk02DI6`0800007Q8D028H6@0E2@d050P<01<72`804PH:00L04`L;
00d11@0F2Ph050P<00d11@0A1@T03P<600H04`L;00`03`<701@8300C1`/05`/?01862P0A1@T06`lC
01X>4P0A1@T03@4501D93@0N4QH201862P0401452@0B1PX05@T=01L;3`H04PH:0P0@10P0100A1@T0
4PH:01862P0A1@TDooooo`006oooool0NP0A1PL05@/;00h30`0?10@05P/=0187200E2@/05`/=0104
1P0D1`X070hB01851`0E2@/05@T:01`@4@0?10@0;20Q038V9`0?0`@06@d>01dA4P0G2``06@d>00h2
0`0F2PX04@D501<71`0E2@T03P@401D92@0H30`0HUIF07a`L00V6QX06`l?01451@0F2P/05@T:01H:
2`0B1PL06@d>01@82@0C1`P03`@401T=3P0C20P04PH701L;2`0E2PP040H401<81@0E2@P05`/:02`Q
800D20P050P901/?400D20T04PH901<81`0D2PH04`T501@:1P0D2@P040D401<81`0D2@P07A8C01@9
2P0L4A8030<401/@400D20L04`L701D92@0F2PX050P901T=3P0H30d07Q8C01<82@0I3@h04PH901dA
4P0G30/04`L801H:2P0F2PT05@T:01P<300G2`X05@T:01H:2P0D2@P05`/<01T=400E2@h06@dC01P<
500L4AH05PX@01P<4`0K3a@07Q<I01/?5`0H31405`/B01/A5`0D31407A@I00h42P0E3A80610E01<9
3P0N5Q/06A0E01T?500F3Q<05PdB01@>4P0F41@05a4E0P0F41@00`0I4aL05a4E01PB5P0201LA5@0c
01TC5`0G4AD050dE01LA600K4a`05a4H02<M8P0b;Bd06QHD01/H5P0H5AD07AXM01PD7@0G4al081`V
01XF7`0H51`06aLM01/I7@0H5QP05aDG01/J6`0M6al07Q`Q02@R:00G51`07AXS020N:00M6R@07Q`V
020O:00O7bP0824Z020S:`0F6R807B4Y07b1R00O92`08RH_020T;@0N92/08bL^02L/<@0S:Bd09R/`
02HZ<00T:C408BH^02`_>00U:c<09B`d0080:30h01T0:C4h02/c>P0[=C`0;CHm02`f?@0[=C/0;CLn
034l@P0b?D<0=3e603E0B@0d?dP0=dA=03Q5CP0c@4T0=TA=03Q5CP0jAdh0>4A:03Q2B00iA4X0=45:
03I3CP0f@dd0?T]F0080?DYE04h0?T]G03]8F011CUh0@dmQ03m:GP0mBe/0@4mK049AG`11D5`0?TeH
04=BG@1:FV80>4Q@03M7CP0kBe40>T]?03i>D`0mCE40@4iB045?E00oCE40?D]?041=DP0oC4l0>dM:
03M3AP0hADL0?DY<045<CP11CU00>DM:03Q5B@0kBDd0>4E<03a9D011CUH0A55J06]hP@1=FF@0>4A@
04AAG00nBe80?D]?03i;C`0oBe00?Ta@03e:C`13Ce@0A59F041=D@0kAd`0>dU=03a9C00jBDD0?4Y3
03a:A@0iAd<0>TM503e:BP0oC4d0>dM903i:CP0lBDd0?TY?049?EP0oCEH0?TeH03m=F015DU`0@E1J
04UGH@0lBU@0@E5H03a;E00_?DD0;cm603A2B@0jB4h203M6BP1S03e;CP11Ce80>dU<03m=D00mBdh0
>TQ;03Q7B@0hATT0>4I803Q3A`0iA4P0>TE803Y4BP0jADT0>DA703M1AP0i@TL0;3Di03U1A`0b>Sl0
?4A703Ln?@0/<c00:c8_02ld<@0[<2l0:2d[02X_;`0N8R40:Bd[024U9@0[;bh0:Rh]02`c<`0W<C40
72DW02Xb=@0T:bl0:2lc02`a=P0_=3P0;30e034e>00[;C80;30e03<j@`0e>dD0:C4j02`e?@1:De/0
=3e502/d>`0P:300:2he02``>01LH6L0;Rlh02LY<@0U9bh0>3Xo02<V:00T9bH07B0O028U8`0V:BP0
9bXY024T9@1ZKFl09RT/02DW;00T9R`09RP]02@W;@0U:2h082@[01dP:`0Q9Bl0:Rdh02LZ=P0T9c<0
9bLb020N:00P7bP0:2L`02d/<`0Y:2l081lU01lN900N7B<081lU01lN8P0K6Ql071XO01`J800J5ad0
7A/Q01lL8`0N6b8081dT00808AhU04d081dT024N900N728071XO020N8`0Q82D08R0U01lM8P0L6Ql0
6QPM01TG700J5Q`07ATO01lK8@0N6R007APO02@N9`0F41T071LN01/F7@0G4QT09B0V02@O9P0N6Al0
61<J01XE6P0M61h06A<K01XD7@0K51d0618I020J8P0J51/06A<J01XD6`0L5Qd06A<J01H@5P0J51X0
6a<K01TA5`0K4AT06a0I01L?5@0K4AT06@hG01L?5@0I41L0714J01L=5@0I4AT06QLP05UHG`3Sh>D0
OW^001`J6`0H5A@0514A01PH6@0D5AT03a8H07EhP@1@DUX0618I01T@500I4AD06@lD01L>4P0F3a80
5`dA01/C5P0M5QT0:AlT02@K7`0C2@d060dB01L<4@0201H;400F01P=4P0I3Q<0714F01T>4`0F2a00
5``A01P=4P0F2a005PdA01@:3`0K51L060lC01L=4P0C30l05PdA01dC5`0D3A005`lB01D;3`0B2Pd0
61<B01H@3`805@l@07@04`h@018=3`0E3a<0618H01PD6@0/:2l061@K01`H700I4Q<05Pl@01PB500H
4A@071HK018=4P0H4QP06QDJ01/F6`0L61/07APK01/I7@0N82H07B4W02<X;P0R:S40:34i02`h@00`
?TL0=4A=03e?FP18FfH0C5m[05AXM01QLh40J7Z806alS01fQIH0P8fO08RDY`2>VZh0U:2b096N[`21
Sil0MhFE06YlRP1NL7l0EVQi04eNK@10DUl0>T]H03I5D00c?dP0;cY302/d?00V;3D08RH`01hP9`0N
7B<071/P01dK8@0G51T06A@I01H@5@0K5QP05@hA02LO8`0J41<060hA01L=400D31006@lC01X@4P0F
3@`05@`<01D;2`0F30`05`d>01D93@0D2@d05PX?01@93@0B20/04`T<01@:3@0C2@/050X<01882P0I
3a8050X=07E[KP2>Q8H09adP01XA4P0>1PL06a4B01882@0D2P/04@H801872@0[82405@`=01<82@0B
1`T05@X;00h20`0C1PL04`P801@92@0D2PX03`D501<92@0B1`P06Pl?01P=3@0A10D05`T;01L:2P80
4`H600T04@@401851@0M4100304101H92@0G2PX040<301D92@0C1PH00P0B1@D201<61P804PD51@0C
1PH0A00C1PP05`TA01<63P0I31407aHE02DN6@0A2PD0610;00d61P0G3Q007A<I01@8400B1Ph040<9
01<52`0D1`X05@P<01L93@0H2Ph04`H901X<3`0B10L05PP;01P:300@10H04PP900l31P0B1PT050P;
0145200>10H04PH901<52@0F2@`05PP<01/>4@0D20/06@dC04Tl@P0i;C802P0201H:3`0A1PP04@D7
01P<3P0B1PP060`=00h30`0C1`T03P0501H83@0@10L04P@901D8300H2Pl04`P:01/=4P0C1`X060X?
00l41P0F2Pd060`>00h41@0I3@l05@X;01L;3@0B1PP04@D70P0B1PP03P0A1@L04PH80186200A1@P0
5@X=00l31P0A1@P04PH901H:3@0S5aX04PH901<72P0@10L04PL:100C1`/201862P0Z00`2100F2Ph0
5PX>0104200D20`04PH:01<72`0@10P04`L;0104200A1@T04`L;01@8300C1`/040H801P<400G2`l0
50P<01D93P0C1``04PP=01863P0F2a40304601<73`0C1`h03P<701D9400G2a805PX?01853@0B1@`0
4@@:0144300D1`h05@P>01H94@0B1``04PH;00h32@0I3A<03P875?ooool001_ooooo00T03@D301@<
2P0H40h0718A0188200E2``04`L901D82P0F1`X00`0F1``201<72@0G01lC5@0>0P@0=2PZ03<W:@0N
4Q@02@0001D92`0B1`P0300201H:300A1@D05PX:01hB4P0?10@07a<C01@8200Y7Ad0flo?0?kblP17
>c/04PH601/?3`0P51H00P0C1`T05@0;00406@d?00`00P0B1PP07A4C00l31@0J3Q00=BT[01041P0B
20P081@D01H:2P0=0@40BShn0:fQX@0P51@03P8200/0000C1`L050P801P<300201D92@0301@8200C
1`L04`L700805`/;0P0D20P0>P0?0`<02@0001D9200G30X05`/;01H:2P0D20P05@T;01dA4`080000
3`<701T?4@0C1`/0300401D9300C1`T04PH801L;3@0D20X04`L901L;3@0C1`T050P:01X>400F2P`0
5@T;01D:3`0@1@d060dE01@94@0M4QX05@XB01L<500F2a<05``D01P=5@0I3QH05P`D01H=4P0H4QH0
5Q0D00h8300L5QX05a4E01<=4@0I4aL04P`@01@>4P0B310050hB01D?4`0G4AD0618F01@>4P0C3A40
5Q0D01LA5@0I4aL201LA5@0@01/E6@0H4QH06A@H01PC5`0F4AD05A0D01/F6P0Q72006QDI01D@500F
4AD06QDI01dH700J5AT081TP01hH7P806aHL02P071PN01/I7P0/:Rl08AlT01`K800F5AX07A`Q01TH
7@0J61d0920V01dK800K6R006aXQ02h^=P0W:S<08RH`01PL9`0B5R808BHb02<W<P0T9S80:B`e02@W
<00R9Bh09BPa02@W<00[;SL09BPa02P[=00V:C80<SDn02HZ<`0X;SH09B`d028Y<@0U;3@0:c8j02he
?@0/<c/0<CQ00P0^=Cd0>00c>T80=3]302hf?P0a>d@0<Sa503E2B`0hATl0=TA=0391B@0a?TH0<d54
03Q3AP0g@D80=3i003Y5CP0d@4`0=T9>03m;E`18E680G6Qf03e9E`0g@e<0>DEE03a8F00kAUP0>4ED
03a:E@17EF00CE]V041>F@0jB540?DaD03a;DP0hAdh0?4]A041?E00oCU<0?4Y@03i;D@10CE<0@e1F
049?E@11CU@0@4eC03a9C`0gA4X0=T=903]8CP0lBDl0?daC03a9D@0jAdl0>DI>03E2BP0hADd0>dQ@
0P0iATh0;@0kB500?4UA03e:D@0oBU00?dY>041;C`0oBTh0?DQ<03a7B`10Bdl0@TeA03i9C@0g@TH0
>DA803]6B@0oCDd0?Da903a:BP0kBDT0?4Y:03m=CP14DU<0?de>049@D`16E5L0@U1C04ABEP0kBE80
=dQB03a=E`0kC5H0=dQB04UJI02EY[00EVMa02dnB00mCUP0>T]E051QJP10CUL0>4M>03e<D`13DUT0
?TeD03a;DP0203Y9D00d03Q7CP0fAD`0=4=:0391AP0g@TH0>DA603M2A00e?d40=3i003Do@@0h@4<0
>D54034i?00b=c/0=3Tm02db=@0]<C@0:Bd^02hb<`0`=3D0;30a02T];P0e>CX0:bl`03e1@P0M8B80
7b<T038f=`0U:bT0:S0_02/a<@0^<cL0:Rhg028V;`0Y;CH0=c]403/oB00n@dP0<3Di02P]<`0b=T00
<SI102/_>P0_<c`0<CDn02T]=P0U:S007B8X020U:`0Z;c<0:2da028W:`809BX`01H08bP^02P]<@0W
;2l082DX024W9`0F71`06R0N01lU8P0P9R@09R`/02hc>P0S9Rl09BPa02<V;`0Z:S@092@_028R;P0T
8Rl0:BLe02/Y=`0W9C<08b4_0P0R82d08@0R82`08R0[020O9`0O7RD06QTO01DD6@0H61/07AdO01`L
7P0L6ah07adP01hL8@0O7280:2D/02LT:`0P7B@06aPO01`I800Q7bD071XO01XH6`0M6al07adR01hL
8@0K6Ah07adR024O900K6Ah05A<H01LE6P0K6Ah07Q`Q01dK800201TD6`0602<N9@0F4AP09b8Y01dH
7`0@2a805Q4H0P0K5Qd0100M61l06A@K01TB6P0J4a/201/D70<06Q<K00D06a@L01dF7P0M5Qh071DM
01/D700201/?6@0701X>600H31H05`/E01H:500I3AL06`lI01dA6`0201X>600@01`B6`0T6RD07aLR
05aEG014?dD07AXL01LF500E5A<03`l@01@E5`0H6Ah06QdT04i=E@0N5ah07Q<I01/@5P<06PlE00<0
7A8H01/@5P0H3A<00P0G318201H;4@1C01D:400D2@l050T?01H;4@0G318050T?01<83P0D2@l060dC
01/@5P0J3aD04@H<02XO9@0:00D04@L<01/@5P0C20h03`@:01D:400F2a406@hD01P=4`0U6Qh050d:
01<>2`0D3``05Q0@01<?400A3@h04@`B01`I800F4a`0;bdh0:bZ]@0h=Ch05Q4G01<>500N6Al06aHL
028M8`0G4QP061<I01TD6P0J5A/071LM01hI7`0M6b006a/S01XM900U:C409B`d02lf@00g@DX0<Sm8
03I4D@0mCEX0@59N04UKJ@1DIg<0HWB006alR`1cOi80PhjR09>K/P2NYKd0YJ_50:R^aP2QZ;d0RiJX
082;W@1bP980HW6405UZO01?H740@E9R03]=F`0hBED0<D9<02hkA00[=3h09B`f02<W<P0N82P00P0N
7BD09@0L6R8061DL01PC6@0E3QD071DL01L>500P5A/06@hD01/>5@0I3Q805``@01`A5@0O51P060dA
01H;3`0A1PX04PL;01@93@0E2Ph050T=01462P0F2`l04PL;01D:3P0I3Q805P/?01D:3P0@1@T06@hB
01062@0P5AT08AHJ01892`0I3@l04`L901P<3P0J3Q000P0A1@L01`0@10H060`>01dA4`0J3Q004`L9
00d10`0B0`H00P0F1`X301D62@0B01<41`0D1@P05@H901D62@0D1@P04`@701861P0A1@D06Ph>01/?
3`0M4A40;b<S00l30`0E2@T04PH600l30`0@10@03P821P0B1PH00`0C1`L04PH601451@0201861P0J
01881`0>1PP04@P;00L00@29P8<0[:>V01XA500B2@`04@P;00h5200I41<06a8E01482`0?0P/03P48
00d01`0>0@P05@T=01T=4@0@10P05PX<00h2100F2P`060`<01881`0A1`X201072P<04@H:00<04@D9
01@52P0F1``00P0H2@h01`0E1`l05PTC028E7P0L3aL040<:01D83`0C1`/00P0A1@L08@0A1@H04@D5
0146100H30d06@dA01@8300A1@T04PH:01452@0@10P03P8600/00`0@10P06@dA01L;3`0A1@P05@T;
00d10`0B1PP03@4301451`0>0`@04`L901@82P0A1@L03@4300h2100A1@P06@dA00h41P0<00@05`/?
01472@0901862P0<01452@0@10P040@800P0000:00803`<701@8300E2@d050P<00d11@0<00@050P<
0P0B1PX07`0A1@T03@4501D93@0C1`/060`@01H:3P0@10P04`P@00h32`0C210040D=00L0100@1@d0
4PL?00`22@0X7BD06PlG00d42P0F2a<04PD>01443@0?0P/040<<01<63`0F2A804@@=01L:4`0=00T0
5@PA01H94P0;00L05?ooool001_ooooo02D04`/901081P0?1`D06@l>00d51@0J41404`L901<6200E
1PT05PL:01P93@0I2Pl040@600l31@0C1`T03`<501hB500C1`T04PH801`@4P0F2P`04PH801451`0V
6Q`06@d=01451@0:00004PH601X>3P0:00009a/K06QLG01lL700:alO01451@0=0@40:AdO00804PH8
01D050P:02@H6P0C1`T05`/=02HJ700A1@L02`4201`@4P08000060`<00l30`0>0P804PH600P0000M
4A404PH600h20P0900009ATI00h20P0?1@D00P0E2@T00`0D20P04`L701<71`0201@8200:01<71`0F
2PX04`L701<71`0D2@P05@X801H:2P0C1`L040@401<72@804@D700D0710D024E6@0K3a<09QXN0146
200201@82P0401L;3@0D20X050P:01T=3`8060`>00`06Ph@01@82P0B1PP04@D:00l42P0H3A<04`P>
01/@5P0G31805@X@01H;4@0G318201H;4@0L01T?500H3a@02`D901PB5P1hLWH0SHN;01@>4P0E3a<0
4P`@01<=4@0?2@d04`dA01/E6@0D3Q805Q0D01PB5P0F41@05@lC01LA5@0F41@0618F01LA5@0H4QH0
71HJ01TC5`0I51P05a8F01HA5@8061<G03<04`hB03<^<P0K5QX061<G01dH700I51P05a8F01dF7@0N
61h07APN01hI7`0N6R007A/P01/I7P0D4QL05QDJ018A5P0K6Ql07A`Q01TG700Q7R@081dT02@S:@0K
6R4061PP018E7P0R9Bl08bDa02X^>@0O8bl0;c<n02d_>`0/;cP08RD^01hQ:P0S9Rl092L`02LZ<`0P
8b`09bXc02/^=`0]<3T08RH_02D[<`0X;cL0:c8j02`c>`0[<SX0:S4i02`c>`0b>D400P0_=Sh0=@0c
>T80=3]3038k@P0g@DX0<ce6030mAP0a?dX0;Ci80351B@0a?TH0<T1303M2A@0i@d@0=d9403a9DP0c
@D`0=dE@03Q6D@16E640JGN4049@G@0gA5@0>TMG03m<G00nBe`0?DYI03e;EP10CUT0AUAO041>F@0l
BU<0>DM?03U8C`0kBU40?4]A03]:C`0nCE80?4Y@03U6C00mBU00@DiD049?E@11CU@0@4eC03e:D00j
Add0=dA:03Q5B`0mBU00@DiE03U6CP0jAdl0@DiF0080=dA<00L0?T]C03U6CP0hADd0>4E=03Y7C`0m
BU40?T]A0080?Ta?00/0?D]>03a:C@0kBD`0?4Y=03Y8B`0kBD`0>DM:03M5B00mBdd0>dU903Y8B002
03Q6AP0L03Y8B00nC4d0@Dm@03]9BP11Ce80AU=I03m<DP0lBU40?TaE03Y;E@0oD5X0?DiH03M8DP13
E5h0bM[T07J7T@0jBeD0AeQR03E6D00^?dP0?deF03Y9D00kBU40>TU@03Q7CP0iB4l0=dI=03Q7CP80
=dI=01D0=DA;03=2A`0f@DD0=d9403E0@P0c?Cl0<S`n03<m?`0f?T40>D5403<k?P0a=SX0;c@h02/`
<`0Y;C00;30a038f=`0`=3D0:bl`030d=@0R9RL00P0T:2T0:@0L8240=3Pi02HZ:`0T:RP0:S0_02hd
=00`=CT0:Rhg02<W<00_<c`0=CU2034e?P0g?480<cPl02db>00^<C/0=CM3030b?P0_<S/0;C0i02LZ
<`0M82L07R4X028U;00X:c009BP]020S:00U:2d08bH[02@W;00[;S<0:Rha02<W:P0/<380<SHg01lS
900N8R80720Q02P/;`0N8RX06ahW00808RD^00@0;2`f02LW<P0S8bl09B<`0P0X9S<0:`0U8c008R0]
02DS<00W9C008AlZ01/I900O7RH09bH]02@S:@0M72406aXN01hN800O7b407A`P01/I7P0I5a`06aTN
028P9@0Q7RD07AXQ01/H7`0M6b0081hS01`J7`0J61d07A/P01hL8@0K6Ah05Q@I01`J7`0P7R<06aTN
01LE6P0J61d06aTN01`J7`0O7B809b8Y01@?5P0P6b8091lV04]6C@0M61l00P0P6b80100J5A`05A0G
01TD6`0I51/201XC6`<06a@L00<06Q<K01TB6P0I4QX00P0K51`0100J4a/06A8J01/@600N4a/201/@
6005020E7@0H3AD06@hF01/@600L4AT00P0J3aL06@0K4AX05P`G01L?6P0C31<07QTO01@A4`0I5aP0
4Q8B01@D5@0>3a405QLL04=4B`3PgnL091dT01hC6@0H3A<06@hD01X?5@0G31809AXP024F700J3aD0
5``B01T>500L4AL00P0F2a4201@93`0>01D:400F2a405P/A01<83P0F2a406a0F01dB600H3A<081DK
01<83P0U6R0081DK00L00P0I3Q@201lD6P1B01<83P0A1P`04PL=01T>4P0D30T04@`901<>2`0E3`l0
4`l@014=3P0G4QP02`P?01LD6`0M6R<0f]OR06eZL`0H4aT03PT?010;4@0=20h06A@J01LB600F4AL0
5a8H01TD6P0L5ad07aXP01lM8P0P82P07b8Y02HZ<P0S:S80;3<m03DoB00b?dP0=D=@03];F00oDEd0
BE]Y05EWM01OLGd0JGV807N3UP2=UJX0W::j0:^`b`2b]]<0/;K@0:J]a@2BWK40QY6U07J4U`1UM8L0
FV]m055RL`13E6@0?DmM03U:E`0b@dd0;ca502/d?P0U;3H08RHa01hP:00K72406aXP01TG7P0H5A`0
6QDL014:4@0Q6al06a8G01X?5@0L4AD06`lC01P=4@0G31006PlC01/@500G31005P/?01D:3P804`P<
0P0H3A402P0A1PX06@hB01872`0B1`/060dA01H;3`0C20`03P<701D:3P0C20`200`11@0E01482P0E
2@/040@601D92`0G2`d040@601451`0>0P@060`>01lC5@0M4A<050P:00d10`0A0PD05@H901H72P0C
10L04@8501@5200C10L050D800805@H900/050D801<41`0A1@D04`L701`@400K3`l05@T901dA4@0@
10@05PX:01@8200201861P0300h20P0B1PH04PH600@04PH600<04`L701861P0A1@D00P0B1PH08@0B
20L06Q0C00/21@0J4A@0@CPk04U0@`0<0`H03PD800l62@0A20/07aHI01dD5`0?1PT04PD>01H9400D
1`h03`8901862P0F2Ph04@D90186200=0@<05`/=01P<300B20L040H:01482`0B2@`04`P<01462P0@
1@T04@D901@52P0301D62`0:01@63P0F2A804`H?01853@0C1Pd04PH:01@8300@10P040@601451P80
4PH601<07Q8C020D600E2@d04@D901@8300B1PX06@dA01H:3P0=0@D05PX>01/?4`0D20`040@70104
1P0F2P`04@D701`@4P0@10H03P@5008050P:00T04PH800h2100>0P@03@8400P0000H3Q008QHJ0965
R@0H31001P0B1PX301452@080104200?0`L03`<701X>4P0F2Ph040@801452@0B1PX30104200H01<7
2`0B1PX04@D90104200>0PH05`/?01D93@0F2Ph040@800d21@0Z7bL09AXR03<X<00Y7RH05P/C030U
;@0_92`04`P@07mdO00m<SX050TA01<8400C1Pl04PD>0P0@0``0200C1Pl050L@04e0B@1;?TL04`H?
02@G800>0`X04PD>5?ooool001_ooooo03`04@T801<:2P0=1@D07A<C01@:2`0=1@D05@T;01D82P0F
1`X05@H901L82`0G20`04`L901H:300>0P@050P:01D92`0C1`T05PX<01<72@0?1@H05@T;00T0000A
1`P06@h>00d10@0D2PX06`l?04a0@00H30`03`@401dA4@0R5QH050P801T=3@0K3`l06@d?00l31@0F
2P`06@d?02TM7`0I3@l04`P902PL7P0M4A<04`L900h41@0O4aD05PX:01<71`0@10@05P`<01861P0F
2PX04PH601dA4@0B1`L0=b/[01X>3P0D20P201D92@0K01@8200C1`L04`L701<71`0F2PX04@D501@8
200A1@D07A4A01<9200F2`T050P801D92@0F2PX05@T;01<72@0L4180;R8V06YNHP0G2`l060`@01@8
2`0G2`d060`>01H:300D20X05@T;00805`/=01`05PX<01D92`0F2P`05`/=01H;3@0C20/060dA01@9
3P0M4QD05@X>01@93P0F30h05``@01<83@0D2@`06Q0D01<:3`0L5QX04`dA01hH700Q6al04`dA01LA
5@0?2@d05a4E014;3`0J51P09b4U0P0D3Q8301H@500;01D?4`0D3Q805Q0D01H@500G4AD071HJ01TC
5`0F4AD05a8F01TD600J5AT00P0K5QX0200`:bl06aHJ01`G6`0N6Ad05a8F01hI7@0L5A`07ALN0P0M
61h01@0L61h06ALL024O900J6Ah08b8W00807ahS0P0K6Ql08@0K6R008R0V028Q:00R8BT0C4aD05=E
GP12A4h0:2/e01PK9P0Q9C007b<^02DX<@0X:c@08B@]01lR:`0T9c009BPa02P[=00U:3409bXc02/^
=`0Y;3D09BTb02H]=P0S:c@0:30i02`d?@0]=Ch0<3Q002de?@0b>T<0<3Q002lg?`0203<k@`0C034j
@@0b?4D0<ce603Y7D@0iBU@0=4E?0311B@0a@4L0<Sm503I1A00jA4D0>dI803M5C@0iAe80>4IA03U7
DP0iAe@0AeER04ECH00304AAH@0@04AAHP10CE`0?D]F045?FP17EF00@DmJ041>E`0nCED0>dYA03e<
D`0mC580?4]@03e<D@0oCE80?T]A03e:D0<0>dQ>00`0>DI<03Q5B`0iAT`0=T=903Y7C@13D5H0C5UP
03U6CP0d@DT0AU=K03a9D@0gA4`503e:DP0K03m<E010CE<0?deA03i<D00mBTl0?4Y>03a9CP0lBTh0
=dA903]8C@0lBTh0=T=803a:C@0iAdP0>DM703Q6AP0iAdP0>dU:03i<C@0gADL0?D]=03a:CP0nBe40
AE9H03a:D@0mBe@0>T]E0080?TmI0100>T]E03e>F016Ef40@55K03Q9D`0nCeT0A5EO03i?F00iAe00
=dI=03U8C`0mC5<0?4]B03I5C00jBE00=dI=0P0eA4/01@0hAdh0>dY?03@o@`0g@T@0=T530080=T12
00P0>49402lg>P0c>ch0<SXm02ld>00[<3@0;34d02lc=P80;C4b00<0:bl`02L[;00[;c000P0Z;Rl0
4`0/<340:Rh_02T];P0_<c@0<3Hd02`b<@0V:bh09b`a02X^=`0/<3T0=3Q203Di@P0b=Sl0<SLm038g
>`0^<cT0:2/e030b?P0];c/00P0Y;3D0100W:S<08B@[02DX;`0Y;3<202/^<`0A02X]<P0V:B`071lS
01/O8`0S9RX09RX]02@X:`1?DeL0LWEi02hb=P0P8bL08bL[01hQ9`0S:300:2Xe02h`>`0S9S000P0Q
8B`0<@0W9c<0:2Hc02TW=00V93408b4^02<Q;@0T8Rh09B<^028P:P0P7bP092<[02XY<00X9bd08b8X
01lN8`0N7B407A`P01lN8`0O72806aTN01dK800N724071TO01/I7`0M6R007Q`Q01dK800L6Ql06aPN
01`J800P7B<07adS01/H7P0L6Al06aTO01XG7@0O72808QlU01`J800K61h081hT01lJ8@0N6B006aHM
01hI800k=Sd07APO01/F7@0L5ah00P0H4aX0100L5ah06aHM01XC6`0K51`301`E7@0301/D700H4AT0
614I00@0614I00H05`dE01lE6`0N51X08aTO02lU:`0T6R0501X@5P0@01T?5`0C2aH07QLP01D>5P0D
3aD04`lB01DC5@0F51H04Q4C00l>4`0G5Q`0@D5806m/M00O5Ad06@hD01H;4@806PlE00H050T?01`A
5`0L4AL06@hD01H;4@0G318401T>508060dC01@05``B01X?5@0M4QP0714G01X?5@0G31805@X@01P>
4`0E31006@hD048g?@0^8bT05``B03`a=`0m<SP06@hD01P=4`0P5A/04`P<01TA3`805@h=00@05@l?
01<>3`0A2`l040/A0P0C3aH02P0G51d09b@^01PE7P0D3aD04`hD01TD6P0H4aT06A@J01/F700I51X2
01PC6@0b01XE6`0M61h07A/P01lN9P0O8RT092P`02<Z<P0Z<C/0;cU302`i@P0a?d`0>d]H04AFHP1A
Hg40Ffej05m_O01XMHD0NhBH096G[`2PYL00];OD0<;3i032a>@0]K[G0:>Ya@2DV[H0OhVQ06YiS01N
Kh40EVMh04QIJ@10DV00>daH03=4CP0_?4D0:C<l02@[=@0Q9C008B<[01lP9@0K6b006APM01TH700K
5a/0618F01hH6`0O5QX060dA01L=3`0H3@l301L<400<01H;3`0E2Ph05@X>01L<400F2`l05@X>01H;
3`0H3A40714E02DJ7P0I3Q804@H:0P0F2`l0100D2@d04PL;00h31`0F2`l201@93@0301882`0F2P`0
4`L900805@T;0P0A1@L201H:300501@82P0B1PP04`L901H:300H2@`00P0G20/01@0C10L04@<501T:
3@0C10L050D800805@H900`050D801<41`0B1PH050P801P<300F2PX040D501861P0C1`L05@T90145
1@0B1PH201L;2`L04`L701804PH601451@0B1PH04PH601<71`0H3Q40E4Y>085gN`0]92H03`L801dC
5P0?1@P04@L;01472P0D2Ph04PP<00d21P0H2a@202HI800c01X=500C1`/050P<01<72`0G2`d04`L9
01@82P0F2PX04`T801472`0C2Pd050/>01@93@0@1@T03`@801@8300F1``05`P=01H7300C10T04P@;
01T<5@0?0PX040@:0185300=0@D05@T=0104200@10H04@D701861`0C1`L05PX<01D93@0A1@T03`<7
01452@0C1`/07Q8F01T=4@0A1@T060`@01@8300?0`L04@D800h2100N4Q@05@T;02hR900H30h04@D7
008040@60`0B1PP01P0D20/04@L901T=4@0@1PP050P<01D:3@H04PH:0P0@10P01P0A1@T04PH:01@8
300F2Ph0:1`P01lC5`8040@802H050P<01H:3P0E2@d05`/?00l31`0D20`04PH:01452@0E2@d05`/?
01<72`0J3Q8050P<01452@0D2A403P<;01T>5P0G31@02`8801/@600D2A4050XA01/B600<0`T06@lF
01463P0D1a004`H?01853P0A10d04PD>01<63`0R5ah09AXQ00`1200J3AH04@H=01H94QCooooo000K
ooooo`0801@;300A20T04@P901@:2`0E2``03`D601D92`0G2@`201L82`0501D62@0C10L04PH801L;
3@0A1@L00P0D20X0:`0M4A<08QHH01@92P0800004@H702`P8P0F2P`0300001X>3P0P51@03P@404e1
@@0`92@0710@00P0000:00004`L701X>3P0@10@040@60186200I3@l04@D701/?4@0<008060`>00P0
000;004060`>00d10`0J3Q0040@401<71`0I3@d08QHF01/?3`0@10@03`<301861P08000050T900l3
0`0D20P00P0E2@T0300D20P04`L701<71`0B1PH06@d=01451@0D20P04@D502dQ8@0A1PD04`P601<7
1`805PX:00l04PH801X>400:00007Q8F01472@0/82@0P7Ah01L;3P0J3Q00710B01D92`0D20X05PX<
0186200C1`T00P0G2`d02@0F2P`04PH800l41@0?1@H05@/<01882@0L4Q<060h?01D;300201H<3@80
50X;00@05P`=01482`0?2@d040X>0P0>20`02@0L5QX06A<G01H@500G4AD04P`@01D?4`0L5QX0618F
01H@500201@>4P<05@lC00H05a4E01D?4`0G4AD06aDI01PB5P0G4QH201TD600A01HA5@0G4QH06aHJ
01/F6P0H4aL07QTM01`G6`0H4aL08QdQ020I800O6B007QTO01dH7P0L6Ah06QPM02l]<P0G5AX00P0I
61d03`0P7b@08R4V01hM8`0H5ad081lU020O9`0U9Bd0I6A/020P:P0Z:cD0GF1Y03HhA00R9C005a/V
01XM9P03028U;P1602HY<P0U:3409RTb02/^=`0Q92d0:Rdf02LZ<`0T:3409Bdf02Xc?00h@DX0>dA=
02lh@@0^=d00<3U203<lA@0^=d00;CHo034j@`0b>d@0<Sa202`f?`0]>T<0>dUD03Q9D`0^?dT0<D9;
03A2B`0d@dP0=T9703Y4AP0kATP0>DM?03I4C`0_?DP0?D]F03]9EP0iAe@0>4IC04=@H012Cel0>dQH
03e:F`11Ced0@e5L04MEH016E5l0?4YE03e;E012D5P0?TeD03]:D@0mC580?TeB03]:C`0gAD/0>DI<
03i;D@12CeD0?DY@03M4BP0d@DL0=dA:03U6C00gA4X0>4E;03m<DP1CH6L0AE9J038oA`<0=dA<00<0
>dQ@03a9D@0lBE400P0mBU80100lBE40?4U?03]8CP0jAdd403Q5B`0803M4BP0iAT`0>4E;03A1A`0g
ADT0=dE603Q6AP0jB4P303]9BP0R03Q6B@11Ce80?DY@03m<DP1=FV00@TmF03a:D`0iBU@0>daF03e>
F00lCEL0>DYD03A5C`0fAe40>DYD03M8DP0fAe40>daE03=2B@0d@dX0>4M>041?EP11D5L0=4=:03I5
C00c@TT0;ci5030oAP0eA4/0>TM=03U4B00iA4H0=d9403@n@080<S`n0P0_=cX08P0`>3/0;c@h02/`
=00]<SH09b/^02T];P0_<c@0;C4b02<W:00P92D09b//03i2@`0N8R<0:Bd^03<g>00W:b`0<CLg02le
=00_=3L0;34f02/_>00_<c`0<cM2030d?@0f>T<0;C8i02P]<`0[<3H0;2hi02`^>P0Z;3P09bXc02HY
<P0W:S<202LZ<@0E02P[<P0[;S<0:bhc02/_<P0X;2d0720Q01/O800M8B@08bLZ02T]<01CEU/0BdiC
02DX;`0R9B`08RD^02<V;`0P92l06adY01lQ;@0N82`0:2Pd00809bLc01P0:BLd02LU<P0S8Bh08R0]
02DS;P0R82/07adX020N:00Q82P07ahV01/J8@0K6R007A`R01hM8`0M724071/P024O9@0P7B@071TP
01lM8P0N72406aTN01LE6P0F51T201LE6P0B01/I7P0L6B008AhU02PU;00S82L06aPO01hK8P0P7B@0
7AXQ01hK8P0P7B@06AHM01LD6`0L6B0061<J02PS:P0J5A`050lF0P0O6R401P0[9Rd0:B@[01lJ8@0L
5ah07aXQ01TD6`806a@L0`0L5Ad03P0K51`0614I01PA6@0G41P05PlG01L@600H4AT05@`A01XA5P0I
41D06a8G028I7P0K4QL06Q4F0P0H3a@04P0I41D06Q4F01L>4`0L5Ad030D=01PA6@0=20h05a8G01PC
5`0N71l01`D901LE6P0D4AP0;2/b02LT:`0H3QH060dC01X?5@807Q<I00P06@hD01D:400F2a406PlE
01`A5`0K41H05P/A01L<4P8060dC01405``B01H;4@0D2@l05@X@01lD6P0N4aT05P/A01@93`0L4AL0
2P0502XO9@0800<0;R<Y02dR:00H3A<050X?01@93`0201052`060146300N4aL05Ph=01@;300E30d0
5a4B0P0H4QH0D00E41H02PD<00X5300G51d0<2df02LT:`0M61h04PdC010;4@0E41H040/A01PC6@0K
5Q`061<I01LB600H4aT06aHL01/I7P0N7RH082<Z028U;@0Q:3009bhh02`f@00]>T<0<T1=03];F013
EF40CV1^05]]N01RL7/0JgN507f6VP2@U[00XjC20;bmg@3CdoL0f][n0<S:k@2^/]D0W:3308B>Y`1_
OY40HW>505UZN`1<GFd0@eES03]<F@0cA4h0;ca502Tb?00T:cD08bLb02@W;P0S92P071dQ01XJ7@0J
6Q`061HI01/G600D3Q006Q4D01@:2`0F30d060h?01D:3P0G31005P/?01@93@0F2`l05@X>01<8300D
2@d04`P<00l4200A1PX07Q<G028G6`0G31003`@80`0B1`/0500@1@T050T=01H;3`0=0PH02@0201L<
400H30h05`/=01H:300D20X04PH801451`0@10H04`L901@82P0C1`T04@D70186200H2@`04P<60P0F
1`X0100A0PD05PL:01<41`0D1@P201D62@0>01@5200C10L04PH601861P0C1`L050P801H:2P0H30`0
5PX:01<71`0<00003@4101<71`0@10@601861P0301<71`0B1PH04@D500804PH600h04`L701T>4@0V
6al081DI01H;3`0Q5QX02@0201052@0D2@d04@H:00h31`0A1PX05@X>01853@805`XA00X050L>01T=
4@0N4QH04PH:01D92`0G2`d04`L901861P0@1PD04`T=0P0C2Pd0100C20`040D900l4200E2@d201L8
3@0:01H7300C10T04P@:01L:4@0E20l04`H=01032P0>0PH04`L;01452@@04@D700L03`<60104200C
1`/04PH:00l31`0@10P04PH:00803`<701D040@800d11@0?0`L04PH900l31@0E2@/04@D701dA4`0A
1@L03@8300h2100=0@<03`<501041P0?0`D03P85028F6P2>PXH03P8602DI7@0<00@01P0B1PX30145
2@0301<72`0F2Ph06@dA008040@801@04PH:01P<400H31004`L;00P0000D20`04`L;02DI7@0N4QH0
40@801<72`0D20`06PhB02`P900Q5AT04PH:00l4300<0@T03PD;01<840804PL?00H06PlG00X11`0I
3QH05``D03/`>00A1Ph601853P0601D84@0D1a006`hG01<63`0D1a002`075?ooool001_ooooo00P0
5`hA00l62@0Y82<05`d>00l61P0L4Q<04PH801D82@806@/;02/05PP801<51@0=0@<04PH801L;3@0F
2P`04`L90186201>@T@0:1`N01862019?Cl0Og=e01X>400D2PX05`/;01451@0=0@4040@4028F5P0>
10@050P801lC4`0A1PH05PX:00h20P0F2P`050P:01T=3`0D20X08QHH01D92`1HC4h09QXL01hB500E
2``08aLI00/00@0G2`/06`l?01L;2`0900004@D500805PX:00D07A4A01L;2`0J3Ph05PX:01@82002
01D92@0X01@8200C1`L04`L701861P0I3@d040@401H:2P0I3@d0?S8b01<81`0B1`D06@d=01P<300A
1@D03`<500`20`0N4Q@04`L;01hB5P0A1@T07A4E01dA500K3a407A4C01D92`0D20X05PX<01L;3@0J
3Q006@d?01D92`0H30h06@d?01<82@0E2`X07Q@C01471P0H3Pd0718A01L=30<05P`;00H05@/:0189
2@0R6A`06A<G01XD600@2Ph2014;3`0801H@500L5QX050hB01@>4P0A2`l04P`@01lI7@0J51P201D?
4`805Q0D00L0618F01XD600H4QH0618F01`F6P0I4aL06A@H008061<G00@06A@H01PC5`0E41@06QDI
0P0M61`01@0J5AT06A@H01dH700N5ah07ALN00806aHL02H071TN01dK801GEEX0;bhc02DT:@0Q82D0
7QdR01LF6`0M7R<06ATQ01`L900W9bl08B4Y02HV;P0X:3809bLa03/kA@0Q92d06QdV02HY<P0L82T0
8RH_024U;P0P92d09BTb02@X<@0R9Rl0;30i01hR:`0c=d00;30i024U;P0T;3D0;SM0049;E014CEH0
<CY302`e?P80=3e601d0;CHo02/d?@0a>T<0<S]403I0B@0a>dD0;S]403I4C`0a@Dh09SQ403=5CP0i
Ae00>DQ=03M4B@0iA4H0>DM:03Y:DP0a@T`0<45;03]<EP0hB5D0?TiK03=3D00jBUT0>d]J03Y:F@0k
Be/0A5=Q04ABG@02041>F@0A03a:E@0oCEH0@U1H03i=E00kBU40>TU?03]:C`0jBDh0>4I;03U6C00o
C580@e1F03e:D00gA4X0=45703M4BP0iAT`00P0hAD/00`0kB4h0B5EL049?E`0203I3B`0;03Q5C@0i
ATh0?4UA03a9D@0kB500>DI>03Y7C`0mBU80?4]@03]:C`0iB4d00P0gAT/05P0hAd`0=dI;03]:C`0l
Be00>DQ=03Y9CP0kBTh0<d5203E3A00iAdP0>TQ903U7B00e@dH0?4Y=03U7BP0mBU00AeAL04ICF`0l
BE40?deF03i<E@0lBU<203m=EP0<03Y8D@0kBE80=dE>03]9DP0lBU<0=49;03=1BP0f@d/0>TM?03Q5
C@0jAdl0?DYB0`0d@DT0200c@4P0=45903E2BP0e@TP0=D1403I1@`0c?T00<C/m0P0^>3X0<P0g?d80
<3Pk030h>`0b=c/0;C8f02hc=`0V:Rd0;30c030d=`0[;c80:Rha03@h>`0Y;C00Oh>603Pl?`0K7b80
:blb03Lk?00]<c<0;C<d038g>P0^<cP0;C4j03<g@P0g>dH0;C4l03TmAP0[;cL09BX`034f?00f=d80
<c<o034a?@0];CL09bLa02DU;`0Z:S80:2P`02TY<@0[;340:BX_02HW:`0V9bP08B8T028S9@0P8B<0
9BHZ02h_<`0f=Sd092@/0P0R8R`0400T9300:B/g04M;E`0c=D80;S0m02@V<P0V9S808R8]02DU;`0W
9C00928]01lM:00P7RT08R0[020O9`0O7RH2024P:00I01lN900K6R0071/Q01hM8`0P7bD07ahT01hM
8`0O7BD06AHM01HC6P0M6b407A/P01/I700J61/06aTL01/I7P0G5A/06aPO01`I8P0M6R808b0W024N
9@0L6B007Q/R01lL8`0201/H7`0B01dJ8@0J5ah06QLN01dJ8@0T7bH07APO01PC6P0I51/0:bH]01`G
7P16@DP0?3Ln028M900F4AP06QDL01/F7@0K51`071DM0P0M5Qh201`E7@0901TB6P0H4AT05a0H01H?
5`0G41P06A8I01T@5@0I41<060lB00805`hA01L05Pd@01XA500H3a805`hA01T@4`0J4A@05PdB01@=
5@0G4QT08A`R01HA5`0A31806QDK00H11`0J5A/08b4V01PF6`0@3Q@07aXQ01L=5@0H3A<06@hD01/@
5P0201dB600301T>500G31806PlE008081DK01<05``B01P=4`0I3Q@06@hD01P=4`0E2Q004`P>01D:
400K41H06PlE01H;4@0G31807Q<I01P=4`0A1P`09AXP01L<4P0900@07Q<I00805P/A00D0714G01T>
500A1P`09Q/O01H<3@0201<:2`0@01P?4P0H4QH0618F01dF7@0T7bD061<I00l:4@0@2a802`H=03Td
>P0N6Al050lE01`G7@0H4aT08ahT01TD6P805Q4G02P061<I01dH7P0M6b009RH^02HY<00R9Rh07RD]
028Y<`0X<S/0;3U2034oC00jBUL0?e5M04UKJ@1GJ7<0H6ii06YfQ01lQ9P0Ri6[0:6R`02l_=h0emGl
0=oOo`3:bo40/;;H09nSb028TJd0LX6D06AeQ`1KK7d0CUm_04AFI00mCUX0=DI@030mAP0[=3h09bhh
02L[=P0T:2l07R8U0P0J6ad03P0L71h061HG01XF5`0E4A805a4A01892P0T6a`08aTI01@93@0H3A40
5``@01D:3P0G310050T=0P0E2Ph01@0D2@d04PL;01<8300G31005@X>00804@H:00D05@X>01<8300B
1`/03`@801/@500201D:3P0500h31`0Q5QX05@T;01H:300D20X00`0C1`T03P0?0`D050P:01L;3@0E
2@/04`L901451`0D1@P03P0201X;3P0N3a804`@70101100C10L050D80P0E1PT0100D1@P04`@701@8
200B1PH200l30`080104100?0`<050P801@8200@10@04PH601@8200=0@4601861P0301<71`0B1PH0
4@D500804PH600P04`L701<92P0800007Q@E018:2P0B20T04`T:014720804PP90P0A1`P0500D2@d0
40<;01032P0?0PT04@@;01P<400L41@04`L;01451`0I3@l07A4C01T=3@0@1PD05@/>01<:3@0B2@`0
4`P<01462P0@1@T050P<0P0F1``03`0E1P/04P<801@6300A10/050L>01<72`0A1@T050P<01862P0C
1`/04PH:01452@0@10H03`<50145200401862P8040@801L050P<01D93@0@10P040@801452@0@10L0
4`L900/00@0A1@L03P8401<72@0@10H04@D701041P0C1`T05PX<01D92`0D20/03P8603HZ;P0I3A40
200001/?4`0601862P0801<72`0B1PX04@D901452@0C1`/05`/?0104200B1PX201D93@0@01862P0>
0PH02`0301X>4P0B1PX09a/O01lC5`0A1@T04PH:01<72`0H31009ATM01X>4P0B1PX04`P@01@94@80
4PL?00/05P/C01P=5@0D2A407a@L01463P0700@0PgR0034V;P0@0``04@@=01853P0301<63`060185
3P0>0@X03P4:00d02@0E21406PdF5?ooool001_ooooo01@03PD901893@0j<C@09AXN01<:2`0D2P/0
4`L801H92P0J30`06@/:01H81`0B10@05PX<01872@0L4180F4a>02TM7`0:004040@601@92P806Ph@
00X0A3Pj02<G6@0G2`/04`L701H:2P0E2@T03P<301861P0K3`l02`410P0F2PX04@0G30`050P801L;
3@0A1@L05PX<01L;3@0P51H07A4C024F600H30h040H701dA4`1aIFL0?S8d01@8200@10@05@T90080
5PX:02404`L701461P0B1PH06Ph>0104100J3Ph05PX:01051@0F2PX050T901861P0J3Ph05@T901T=
3@0C1`L050T901D92@0Y7Ad050P701P=2`0Q5AD07Q8B00l4100D20X06Ph@01<92P0A1`T04PH:02<G
6`0H31004`L:01T=3`0J3Q000P0E2@/08@0F2P`05@T;01hB500C1`T04PH8024E5`1CAdT0<bPX01T?
3P0R61L0718A00h51@0M4a806@l>01<9200F30/04`T801P>3@0B2@T05@`?00h8300C3A404@/?01PB
5P0D3a803@L;01TC5`0@2Ph07ALK01D?4`0D3Q807QPL01/E6@0201PB5P0901TC5`0D3Q80618F01hH
700J51P091hR05UCE`0K5AT06aHJ008061<G01807APL01`G6`0E41@02`H:01/F6P0B3A4061<G01dH
700Q72006Q<J01XD6P0J5A/06aHL01dJ7`0O7B809bDZ01HE6P0K6Ql201lN8`0601hM8`0C4a/08R</
01XL900R8R/07QhW0P0O7bP02@0];CH07QhW01/M9@0Q8R/06QdU02<W<00T:C808bTa028X<002024W
;`0`02L/=@0[<3T09BXc03PmAP0c>D409bhf02/d?@0[=Ch092hg02li@P0^>440=3i703<lAP0a>T@0
;3Ho02/e?P0`>D<0<C]402hh@P0c@4X0=D5<03M6DP0cAE40>4YF03=5C`0eATh0=DA;03=1A@0e@4@0
=D9703Y:D@0_@4X0<dA>03Q9D`0eAE80?4aI03I6D`0iBEP0?dmN041@G`14E6@0?TeK03i<E`10CUT0
B5IQ04MEH00nC5D0>4I>0P0lBe802P0gAT`0>TU>03a;D00mBe40?4U?03]8CP0lBDl0>4E;03E2B00d
@DL203E2B00B03U6C00kB4h0>TM=03U6C@0gA4`0>4E=03e:DP0lBE40>TM?03a9D@0mBU80>dQ@03Y7
C`0oC5@0@TmG04=BF00mC580>TU?0P0kBU00M@0iB4h0?TeC05YYK`0oCU@0?TeC03Q7C@1;FUl0>DM:
03U7B00kBDX0?4Y<03]9B`0iAd/0?Ta@03Q5BP10CE@0BEIN041=E@0kB500>dYB03M5C@0gATh0>dYB
03Q6CP0d@d/0?4YB03M5C@0iB500;3]303a;D`0jB500=45903i9DP0f@TX0<Si603M3B`0e@DT0>4=<
03E1B@0hA4`0>DE=03A0B00b?T@0;STm03@o@@0^>C/0;CLi02hh>P0g@D<0>413034i?00e?D00<cPl
02`a=@0W;300;S8f02/^<P0_<SH0;C0d034d>017Bdl0<cHj03@g>`0W:Rh0=SXn02ha=@0g>ch0;S@d
02P^;`0X;C40;C8i02T]>00j?TT0=3Q303/oBP1JGVT0>cm802DZ<00]<SP0?cm;03@d@00[:cL0;2`f
02LW<@0V9S00:b/c02PX<00[:c<0:b`a02HW;00T9BT092DV01`M7`0Y:R`07QlR028S:00V9b`071`T
01TI8`0S8bd09bLc02PX=@0W:CD09RTg020R;`0T9S<09RPd02DU<@0Q8B`08R8/02PV<00f=Ch08R4Z
01LF7`0O7RH07ahU024P9`02028Q:003028Q9`0Q82H08B0V00807QdT00d06APO01PG7P0O7BD05a@M
01LD6`0T8RP09B<V02LU:00[:B/07Q`N01dK7`0I5Q`07AXQ00806AHO00l05Q<K01TF7P0P7BD07a`T
01TF7P0F4a/07AXR01`I8@0J5al081dU01hK8`0L5ah05A0G01hI800D3aH00P0N6B001`0f<CP0:bH]
01`G7P0K5Qd07APO01XE700I4QX00P0M5Qh0100J4a/06a@L01dF7P0F3aL201/D700M01<<500O6200
71DL02LO900N5aX06Q8F01L?4`0D3A006A4E01XB5P0H4A@0610D00l82`0J4aH030L:00h93`0K5Q`0
4PdC01LB600E41H06A@K01D?5P0E3aD050lD01D?5P0C3aD07aTO01P?500I3Q@00P0G3180400I3Q@0
714G01P=4`0D2@l04@H<01H;4@0I3Q@04`P>01/@5P0I3Q@0;b@Z034V;00J3aD05P/A01X?5@0I3Q@2
01H;4@0?01P=4`0I3Q@07A8H0146300E2Q004`P>01L<4P0H3A<050X?01H;4@0D2@l05@X@01<83P0G
318060d@00805@/>04D05`dB01P?500G3a@0=2dc07E_M@0D3aD061<I014<4`0N6Al06A@J01@?5@0J
5A/08A`R01<>500D3aD05a8H01HA5`0G4QP06aHL01dH7P0J61d092<[02lb>@0X:c<092/c02P_>@0X
<S`0;S]402/iAP0kBeP0?4iJ04UKJ@1CIG00Gfeh06McP@1eOY80QXbV09ZK^@2e]=L0cLcb0=GDnP38
bO00[[7G0:FYc`28TJh0Lh:E06MhRP1MKWl0D65a04IHIP0mCUX0=DI@03E2B`0_>480:c8l02/_>P0O
8RT08BDX01TL7P0F61X07AhP01LF600Q7Ql05Q8C01PB4`0M5QH081PI02LM7@0E2Ph00P0G3100100F
2`l05``@01H;3`0H3A4201H;3`8060dA0P0D2@d0100E2Ph06PlC01`A5@0I3Q8201L<400=01482P0F
30l04@P:01L<400B1`/04`L901H:300D20X040@601<72@0F2P`04PH801@82P020186200801L;3@0I
3@l05PL:01@5200N3a808Q<F01T:3@0B0`H601D62@0<01861P0C1`L04@D501861P0C1`L04PH600l3
0`0G2`/04@H601`@400H30`04@D51P0B1PH201<71`0P01861P0A1@D04PH601<71`0B1`T03P<400l4
1@0C20X07A8C01@92P0@1@L04PL801@92P0C20X04@H701052@0D1`l05PT@00l42@0D1`h05@T=0104
200E2@d04@D701T=3`0O4aD06`l?01@:2@0D2Ph04`X=0189300B1`/201462P0H01862P0F1``05PL<
01@52P0C10T05PT=00X00P0F2Ph050P<02HJ7P0J3Q8050P<00l41`0@10P05@T=00`2100B1PX040D8
01452@0@10P050P<01<72`0A1@T040@80P0A1@T03@0>0PH05PX>01L;3`0A1PP050P:0147200C20X0
5`/=01<82@0B1PP05`/=01T=3`0F2P`00P0J3Q000`0E2@`040@80105200301D93@0901862P0C1`/0
4`L;01862P0C1`/04PH:01H:3P0W6al040@800803`<70P0D20`0100C1`/04PH:0104200A1@T201@8
300702dQ9@0F2Ph06@dA01H:3P0B1PX04`L;01862P0201D93@0;00h21P0I3Q40Bd1801hC6`0B20l0
40H=00h32`0E2Q804PL?01053@0=0`X00P0G31@00`0D2A404@@=01853P0201<63`8050L@00H04@@=
01H94P0D1a005PTB00d02@0@0``Dooooo`006oooool0200800@05`hC00/21`0X7B409Q`N01lE5P0B
1PH050L70P0F20L02`0E1`H04`D40104100D20X02`0104Hj?00K3a404@D701<72@0F2P`040@60080
4PH800<03P8401@8200D20P00P0C1`L201861P0900h30`0S5aL04@D501<71`0E2@T05PX:0186200H
30h0710B008050P:00T06`lA01T=3`0A1@L06@d?00h2100R5QP0200001<71`0E2@T00P0H30`0400B
1PH03`<300l30`0X71`0=b/[01dA4@0D20P0300002XN7P1hK6`08QHF00h20P1BATH06@d=01861P0C
1`L201H:2P0:01L;2`0F2`X04@H401861P0D20P04PH602<G6@0n<S@05`/=01D93@8050P<00D02`03
01L;3P0E2@/05@T;01@82P0201D92`0l01/?4@090000300201D92`0F2P`081@F01461P0?1@@06@l>
02hT8`0?1@@06@l>01H<2`0H3Pd05`d<01061@0G3@`040L701P?4P0G4AD02P@801TC5`0?2@d050hB
01lI7@0T7R805@lC02DO8`070@D05a4E01PB5P0?2@d0618F00T31`0;1@T08adQ01TC5`0C3A403PP<
01XD600d;S806aDI01/F6P0H4aL05a8F01TD600J5AT05a8F02TT:00a;3007aXN024L800J5AT06A@H
01/D6`0K5A/06QDK01/F700L6Ah07A/P0P0J61d0500M724071/P01XI7P0O82D05APO01XM9P0I72D0
8R8/024Q:`0T92h07AdU02TY<@0T92`08R8Z02LW;`0O8RT09RXc02<Z<P0Y<3P0:S4i0P0V;CD2028Y
<@0:02@[<`0X;cL0:2lg02L`>@0T;CL092hh01lY<`0kADl0;cU303@nB0<0;CM101/0<3Y403<mA`0e
?dT0=T5;03A0C00Y=d80<T=?05a^NP0cAE40>deI03U:E00gB500=dE<03Q3A`0f@dT0=dM>03E6D00g
B580?DiH03Y:E`0dA540?DeJ03m?GP1UMH@0@U9Q03i>GP12DEl00P11CeX02P13DE`0AE=N03i<E@0i
Adl0@4mF03m>E@0hAdd0>DQ=03Q7C00gAD/203Y7C@80>DI<0140>4E;03E2B00b?dD0<Sm503Q5B`0k
B4h0>4E;03E2B@0d@DT0>DI>04QEG@15DUX0?4UA03]8D00oC5@0?T]C03m<E00204ICF`0=03Q7CP0g
ATd0>TU@041?EP0nCE@0>TU@03I5C01?GVD0>DQ?03M6C@0b@DP0A5=I03Q6B@0203Q6A`80=TA700@0
>DI<03a9C`0kB4h0>dQ@0P0lBE40800nBe<0EFA[04=BF@0eA4/0=TE<03A3BP0iB4l0=TE<03Q7CP1D
HfX0>4M>041?EP0c@DP0>TA=03a6C`0f@4T0=3i703M1BP0f@4T0>TA=03@nA`0h@T/0>TA=03DoB00d
?dD0=3m302dh>P0X<cD0=d53030j?00T;S00>D540P0^=ST07P0Y;S80;S<g02hc=`0Z;C80<cHk02P[
<00T9b`0;c8g030c>00[;S<0<3<h03<f>`0b=CX0;2ld02LZ;`0X;C0092T/02hc=`0a=Ch0WJ6/04U=
F00f>TH0<3A003@hA00K7bT09b/d02d`>@0e=D40;2`h02@T<0808R8/0100<C4k02HV;P0_;cL0>3Q0
03@e>P0X:Bh09bP]02<T9`0[;300=cPl02@U:P0[;3407QlT01hN9P0O7bT08R8/0P0U9C402P0T8c40
9RPg02<U=00T9S<09bTf02@T<00Q8B`06ATS01lN9P0Z:C42028Q:@04024P9P0M72807QdS01hM8`<0
7A`R00<07ahT01LF7P0K6R800P0Q82P0>P0U8b`09B8]02HS;00U8bT0=cDh03/i>P0X9RL05Q@E024O
8P0P7B<09B8[02dZ=@0b;cT06AHO01/H8@0N6b@06aPQ01`I8P0P7BH06AHO01LD7@0P7BH08AhW01dJ
8`0Q72<071LN01XE700K5Qd06QDL01dH7`0_:S409B0W01/F7@0J5A`061<J01XE700L5Ad07aPP01`E
7@0J4a/07QLO01/D700G41P030D=01@=5@0F3aL06A8J01PA6@0V7bH050hB01D?4`0@2Ph07aTM018<
400>20`04@/?01dG6`0Q6al201lI7@0<01TD6P0A3180Ee9H07UdNP0J5A`050lF01`E7@0Y8RX0=c0g
02DN9@0J4aX050XB0`0I3Q@301P=4`0?01873@0C20h06@hD01dB600J3aD04`P>01dB600C20h06PlE
01/@5P0E2Q007A8H01T>500H3A<05``B00805P/A00P05``B02PM8`0G318060dC01@93`0@1@/05@X@
01H;4@<050T?0P0F2a40A`0E2Ph050T=01<8300C20h04PT>01<:3`0B2`l0=2dd00/42`0>2@l01`88
01hI7`0D3aD05a8H01`G7@0J5A/05Q4G01TD6P0G4QP05Q4G01TD6P0M61h06QDK01HD6@0D51`0;S4h
020S:`0I82P0;cI002@^>00/>D807R`i03a<F@0gBED0AeUW05=UL01OL7X0I79o079lS`25RjD0TIFb
0:Z/c@2i^n40^k_Q0;>fg02QYLX0Yj_@08N@[01aP9<0IWN905]/O@1?H700AeUW03m@G@0cA4h0=45:
02`f?`0V;CL0:blj02DX;`0M8B@03Q4F028T:00M7R005QDI00L5200J61T06QDG01@>400H4Q808aXM
00805``@1@0F2`l01@0E2Ph050T=01H;3`0F2`l05@X>00@05P/?01005@X>01@93@0D2@d07A8F05=8
C00J3a<060dA01L<400K3a407a<E01/?4@0C1`T05@T;01P<3P0E2@/05PX<0P0A1@L02P0F2P`05@T;
01@5200D1@P05@H901L82`0F1`X04P<601L82`0F1`X201D62@0401H72P0G20/050P801@820804`L7
0P0B1PH01P0K3`l03@410104100<00003P@401@820H04`L70`0B1PH301<71`H04PH80P0C1`T201@8
2P0:0186200A1@T04@@<01T<4`0C1Pd05@P?01X>4P0K3a<04PH:018620804`L900D04`L701881`0A
1`/04@P;01072P0301052@0301452@0F1``05PL<008050D:01005PP<00T0000J3Q804PH:030T:00D
20`04@D901lC5`0>0PH03@<500l31`0G2Q4050L=0104200?0`L04@D90P0C1`/0100@10P050P<01T=
4@0C1`/200X00P0:01<72P0<0080200001T=3`14>3X08ADG0186200K3a407a<E01D92`805PX<0180
4`L:0104200=0@D04PH:01D93@0C1`/060`@01L;3`0C1`/04PH:01<72`0D20`03P8602<G6`0E2@d0
6@dA01862P0A1@T301<72`<04PH:00l04@D901lC5`0=0@D0710D01L;3`0B1PX06@dA020D600I3a40
5`/?01/?4`0L41@0U8VA03H[<`0>10/00P0@1@d00`0B1`l04@H>01463P0201053@804PL?1P0C1Pl0
100E214050L@01D84@0C1Pl201443ACooooo000Kooooo`0>01<94@0@1Pd01P0201T>500@1PP01`00
01P<300I30/060X901L9200D1P<04@<20104100K3a4200d10`0800l31@0I3@l04PH801@82P0A1@L0
4`L901D92`0C1`T201@820804`L70P0B1PH00`0a9BD0F4a<02<G5`0201D92@0C00X0000O4aD040@6
00P0000J3Q00ETY<07a`LP0<0@804PH801T=3`0E2@/06`lA0186200A1@D05`/;01X>3P0I3@d04PH6
00l30`0201X>3P0L01P<300D20P06Ph>01@92@0I3@d0Ac/k01`@400:0000:alO01451@0C1`L050P8
01H:2P0E2@T050P801L;2P0E2PP04`L701861P0A1@D081@F03X^<00F2P`04@D901X>4P0H31004PH:
01T=40805@T;01`050P:01D92`0E2@/0@SHh024E5`0N4Q@04`L902DI6`0B1PP06PlA00l51P0H3Pl0
<bTZ01T?400H3Pl04PP901hD5@0H3Pl050X;01<92P0B20T03PD801XD600A2`l0618F00P21P0M5a/0
2`D90P0@2Ph0500G4AD091hR03H`=00D3Q803PP<05E?D`0X8RH07aTM01XD600D3Q805@lC01XD600L
5QX030H:01hH700J5AT061<G01D@500G4QH06A@H0P0H4aL201LB5P0501XE6@0M61`06aHJ020I800N
61h00P0J5A/0100K61d071XO01/I7P0J61d201dL8@0F01/J7`0O82D06ahW01LJ9@0J72P05QTR01dN
:00M7BL08R8Z01lO9`0R8BT09bH/02TX;P0T92`08BD^01lV;P0U;3@09Rde02<Z<P0U;3@08RTa02H]
=@<09bhf02D09Rlh02/d?`1AFfL08R`h02D_>`0Y<cl08bdi02`f@P0]=d<0;SQ403<mB@0h@Th0>TA@
02llA@0d@4`0=dE@06YkR03OlOl0RYf[03]?FP0hBU@0>DYB03a;D@0hATT0<d9703E7CP0eAe40>TaF
03i@FP0iBeL0=4IB03mAG@10DV00JG^903i@GP0hBET0@E1N0080@DmJ00`0@4iI049@F`0lBU<0>4I>
03a;DP0kBU40>TU?03a;D00kBTl0>dU>049?E@10CE<203I3B@0A03E2B00a?T@0<Ci4034nA00gA4X0
>TM=03Q5B`0e@TT0=T=;03e:DP1:Eel0AU=K03e:DP0iATh0>TM?03U6CP0jAdl00P10CED01P0fA4d0
>T]C03Q9D@0fAdl0=dQ@03]<E080<4590180=dQ@0393B`0jBe<0=DE=03Q5B`0jB4/0>dU<03M5B00f
A4L0>dQ>03a9D@0jAdl0=T=;03E2B`0hADh0?DYC061]M@1:Eel303I3B`0<03U6CP0e@TX0>DI>04YG
G`0^>d<0>4E=038oA`13CEH0>dE>03Q2B`0g@DX0=3i70P0f@4T0200c?DH0=T1903Q2B`0d?TL0=3m5
02lj?P0^>C/09c8d0P0_>C/0:P0f@480<SXm03@l?`14C4l0?T=702db=P0L8BD08B@Y02ha=P0R9BX0
7B0U02/^<`0^<CH0<3<h03Dh?@0g>Sl0;C0e02/^<`0P8bP0:c0c02H[;P0Y;S80;C4j0;Bh``11AE40
>3]:02X^>P0]<Cd0:Rhh03Di@P0f>D80:bXg020N:`0U8c00:2Ha024O:P0`;ST08R4Y02l^=P0g=Sh0
;Rdc028Q9`808B0V00L0>CPn03Lf?00V9B`0<2lg01dL900Q82P09R@_00809bD`00<09R@_02DU<@0X
:cX00P0S9C@02`0T9S<08b<_01lO:P0L72H092<[01lN9@0T8bT0:2L]01`K8@0P7b@08B0U00808B0V
01/081lU020O9P0V9Bd08b8Z02HU;P0V92l06ALR01TF8P0W92l08b0Y030]<`2=Rhh0WI^L05MFE00^
;2d0<2ha01dK8@0F4a`05a@O02@Q:`0K62407Q/T01`I8P0H5Ah08QlX07IcO01bKgP00P0S82T01`0Q
7RL06AHO02LR:@0O6R407APO024L8`0O6R400P0M61l0:@0K5Qd07APO01dH7`0I51/071LN01dF7P0K
51`05a0H01XC6`0M5Qh05a0H028K8`0>1`l071DM02@M9@0D3AD07QLO02<L8`0H4AP07QLN00P1200E
3QD081TP02<L8`0J4aX040X@01H?5P0?2@l05PlF01LB5P0K5Q/0ZjJ/0<K1b00V82T03`LB02HN:@0d
;3@0:R0Y01D;4`0L4aT03P<900806@hD00h060dC01L<4P0G31805P/A01P=4`0C20h0714G01hC6@0D
2@l04@H<01@93`0K41H04@H<00h32@<05``B0P0H3A<201L<4P0:01D:400L4AL05@X@01T>500H3A<0
6a0F02<H7P0F2a405@X@01@93`805@X@04P05P/A01/>5@0H2a805PT@01@93`0B1`d04@P=01D<4@0C
3A403PP<01TC5`0D3Q8071HJ01@?5@0H4aT06QDK01@?5@0C3Q@06A@J01LB600F4AL061<I01/F700J
5A/05aDJ020O9`0I72<09b/c01<J8P0M92h0;CM102Tf?`0Z>4D0?dmL03U;E`15EfD0CEmZ05e^N01P
L7d0KWZ=07f4WP24RJH0V9bl0:^_dP2b]MP0][[M0:>Yb`2UZld0QI2Y0760T`1UMXP0FFYk04mPL017
FFL0@E9O0393C@0c@4T0<S]502D/=P0Y;CP09b/c02DZ;P0F6B007b8W03Xk?`0L6b407Q`Q02<Q900H
4aL04P`@01TC5@0b:Rh201P=4@0801L<400F2`l05P/?01D:3P0H3A405@X>01<8300D2@d301H;3`0C
01D:3P0D2@d04`P<01<8300D2@d03@8600l4200d:Bd02`0401052@0A1PX060`>01/?4@0G2`d04@D7
0186200D20X05@T;01H:300201041P0801@82P0B1PP05@H901D62@0F1`X060T<01L82`0C10L201H7
2P805@H90P0F1`X301<71`<04PH600H04`L701X>3P0G2`/0300001`@400F2PX601<71`0801861P0A
1@D04`L701P<300E2@T04PH601H8200E1`L201@61P804P@400d06`d=01@61P0B10@050H601<51@0A
0PD06PdE01<63@0B1@`05@P?01862P0:00804PH:00<04PH800<04@D501061@0@1PX00P0?1PT0100@
1@T03`@800l4200A1@T201D62`804`@901005@L;00/0000I3@l03P8402<G6@0?0`L0308401P<400<
00H060/B01D83`0F2A804`H<01862P0A1@T03@450P0E2@d0400A1@T03`<700d11@0B1PX060`@01X>
4P0F2Pd03P8400d10`0D20X0;B4S01P<3P0?0`D05PX<01X>400A1@L20186200700l31P0E2@d05`/?
01452@0=0@D02@0101D93@0201<72`0901D93@0F2Ph050P<01<72`0900403@850104200=0@D05`/?
00@04`L;0P0D20`04P0G2`l050P<00d31@0R5QX050P<01862P0;00<081@H01/A4`0@10P0200001hB
5P0V6b<02`0802DJ8P0Y7RH05``D00l430@040D=00<04PL?01<8400C1Pl01@0C1Pl01P0E214050L@
01@7400E21405PTB01<63aCooooo000Kooooo`0D01D;4`0E31<05PdC00`31`0G31406@l@01051@0B
1@D050H501@60`0E20@05PP601P<300@1@H060`>01@82P0H30h05@T;0186200C1`T20186200401D9
2`0G2`d050P801@820804`L70P0B1PH0300D2@T0;b<S01T=3@0C20P050P801H:2P0E2@/060`>01D9
2`0F2P`09ATK034U9`805@T;01L04@D70186200@10H0710B01P<300M4A405`/;01<71`0D20P04`L7
01D92@0@10@04@D501`@400@10@050P80104100C2@T04@L701861P0D2PX04PH601D92@0201H:2P0?
01@8200B1PH04PH501871@0D20P05PX:0104100C1`T06@d?01041P0B1PX05@T=01P<400K3a<05@T<
00805@T;02L050P:01D92`0E2@/07a<E00/10P0J3Q006`lA01hB500B20T06PlA01H;3P0F30l09a`Q
01L=3`0F2`l04@H;01X@4P0G31005@X?0106200G3A8040L<01<=4@0b;30050hB01TC5`0C3A4081XN
00P31P0H4QH03`T=01H@500H4QH0AT1402@N8P0j=3P04@/?01/E6@0N61`00P0I4aL03P0K5AT04P`@
01lI7@0D3Q8061<G01LB5P0F4AD05A0D01PC5`0J5AT06aHJ01PC5`0L5a/05A0D0P0J5AT01P0V7bH0
8A/R01`G7@0L5ad07AXO01lM8P806aTN01807QdR01dL8@0L6b00824V01PJ9@0L82/0:Rdi01`N:@0R
8bh07AlX02HV;P0M7B@08R4X02@R:00O7B<092DZ028W;@0N9Rd2028Z<@1:01lW;P0Q:C4092`d02/c
>P0/=3/0:30h02P`=`0Y<S/0=Cm:05YUL@0b?DT0:cI202hiA@0iA500;3M302dhA00^>DD0<ci:03Q3
C`0iA500>TMA030nBP0eAE40D65_0:6d`P1VNHL0=4QD0353C@0dAdh0?4]A03Q5B`0b@DH0=dU@03=5
C`0fB580>D]E03Q:EP0kCET0@UAP045CH@12E680?e5O04EFIP0lC5X0@e5L049@F`10CUT0@DmJ03e;
E00kBU80?4]B03Y9D00kBU00>dY?03Y9CP0iAd`0?T]A03]8CP0`?D<0=D9803Q5B`0c@4H0<Sm503A1
A`0hAD/0>TM=03U6C00jAdh0>TM?03Q5C@0iATh0>TM?03U6CP0gA4`203Q5C@0;03M4C00mBU80>TQ?
03I4C@0mCUH0=4E=0352BP0lCED0D65Y03Q9D@0a@TX00P0jBe<02P0iBU80=4E=03E2B00gADP0>DM:
03A2AP0c@4D0=T=:03Q5C@0f@d/203A1BP0303I3C00iATl0?T]C0080>DI=00l0>TM>03I3BP0d@DP0
=45803a9D00c@4L0:SLn03m<D`0d@DP0ADmH03M1BP0i@d`0>dA=03DoB00i@d`00P0e?dP01@0d?DH0
<ca5034j@`0_>Cl09c8f0080;cXl03T0<S`n02`f>00h@T@0?TI902Xb=@0]=CP0:c0d02`a=@0_=3P0
;c8h02P[<@0]<3H0<3<i02`_=@0a=3X0=cY002lb>00]<3H09RT_02`_=@0]<3D0;c@g02db=P0N8bT0
;c<m02hb?P0f>TH0;2ln02lc@00b=T809RXe01hR:`0Y;3D0;B`i02<Q;P0P7R/0;bdh02DS;P0O7BP0
9bH^02`[<`0Y:30081lU01hM8`0Q82L08b8[02h]=P0/:c@081lX02@R;00L6b@08b8Z02XY<P0[:S<0
9bH_02DT;@0U9C000P0T9SH0200U9cH09RPf02<S;`0O7bX08R8/01`K8`0K6R008b8W0P0Q82D0:00P
7b<07ahR024P900P7bD07QdS01`K8P0Q82P071XT01XH8P0N72L081hZ02DR;`0V8S00:BHa065OI03h
moP0oOgk07AcL00Z:BL09B<T01XH7@0P7BP06ADS01dJ9P0H5Al06aPR01`I8`0K62808b0Z05UFH01A
CUP06aPR01TF800J5b406QLP01dH7`0J5A`07APO01lJ8@0K5Qd201`G7P0501PC6P0I51/071LN01XE
700I51/00P0K51`08P0L5Ad07AHN01dF7P0N5al04``D018;4`0K51`06A8J028K8`0H4AT05@lG00d7
3P0J4a/0C4I?01/E700?2A4071DN06IPI`21Nh<071DN01TC6`0D3aH05A0D01dI7@1AC580=C0g010:
4`0K4al05@/H01hD7P0L4AX03`H<01X?5@0E2Pl201T>500:01L<4P0F2a405P/A01D:400M4QP05@X@
01`A5`0J3aD06a0F03<X;P80714G00H05@X@01H;4@0K41H05``B01H;4@0H3A<201T>500401H;4@0D
2@l050T?01D:40805``B00<07A8H02DJ800E2Q001@0E2Q00100K3QH060/C01L:4P0E2A4201@93`06
01L>4`0D3140<2P]01LA5@0=1`X0618F0`0D3aD0>@0F4AL05a8H01PC6@0F4AL05a8H01PC6@0I51X0
6QDK01TG700K6R807B0W02T]=@0O9Rh07RD_02Tc?00W=3d0<Cm<03U9EP0oDEd0AeUW04UKJ01GJWD0
Ffil06QgR@1bOI<0Lg^E08B<Z02EW;/0WJ?10:>/b02AW;H0Uj6l086?Y@1bPI@0IWN905UZN`1@HG40
BUaZ049CG`0`@D/0=dA=03i7D@0Y<3X09RXe02@X<P0T:3007R8/01@H800W:S004A0H01`J8@0G5A/0
5A0F01XD6`0H4aP05@hE01T>4`0201P=4@0501L<400F2`l05P/?01T>4P0F2`l00P0C20`03`0E2Ph0
5P/?01H;3`0E2Ph04`P<01462P0B1`/050T=01P=4@0@1PT05P/?00/2100F2`l050T=01<72@030186
200401<72@0E2@/04@D701@82P8040@600P050P:0186200F1`X05@H901L82`0I2Pd05`P;01<41`80
5PL:0P0D1@P201H72PH04PH600H06@l?01861P0I3@d05@T901D:2P0;0@4701861P050104100D20P0
6`l?01H:2P0A1@D01P0D1PH00`0L3Ph04@<300l10@0201D71`0801<41`0l<CL040H:01D83`0Y72<0
:AlQ01/?4`0E2@d201@82P0P01<72@0B1PH04@L601472`0?1PT040L:01<8300A1PX040D90104200E
1P/050D:01<42@0B0`P04`D800h20P0F2P/03@4301L;3@0?0`L05@T=00T00@0D1`h0@C@l024D700N
4AX04@D;01/?4`0Q5AT04PH:01<72`0E2@d201452@804`L;0P0=0`D02P0@1@P04`L901D92`0A1PL0
40D601461`0@10H04`L901D92`0@10H201451`0B01@82`0C1`/04@D901862P0A1@T050P<01452@0=
0PD04PH:01T=4@0E2@d04@D901X@4P0@10P05@T=01L;3`0A1@T04`L;0P0A1@T05`0B1PX04`L;01<7
2`0D20`04PH:01L;3`0B1PX05@T=00h31P0C1`/050X<01<72`0J3a807A4E01/?4`0B1`X05@`B00l6
300G31@04@H>01473P0@1@d04@H>008040D=00<04@H>01<8400D2A401`0B1@h01@0C1Pl03`8;0144
3@0E21404@@=01Cooooo000Kooooo`0H038X<@1XGVL06Q0H01H;4@0B1``04`T:01P<3P0H2`X05PP5
01D7100E20<05@L401P<300?1@H05@T;01`@4P0@1@H05`/=01451`0B1PP050P:0186200G2`d07a<E
0P0D20P201<71`804PH600X0710@01@8200M4A405`/;00T0000E2@T060`>01451`0<00804PH80P0L
4180:P0C1`T050P:01<72@0F2P`05@T;01`@4P0P51@0;20P02@H600G2`/04PH600h20P0E2@T05`/;
01P<300>0P805PX:01L=3@0@10@08QHF00l51@0=0@407Q8B0104100B1PH04`L701D92@0G2`/060`<
01L;2P0C20H04PH601<71`0D20P05`/=01P<3P0B1PP08QHJ04<g>`0F2Ph04PH:01@82`805@T;03/0
50P:01D92`0E2@/060`>01dA4`0800002`4200h2100N4Q@05`/@01/@5P0E2Q005P/A00l42P0D2@l0
5P/A01@93`0C20h03`@:02/P9P0E2a0030<802<M8@1/IVX04P`@01<=4@0D3Q8040X>01PB5P0F41@0
6A<G00P21P0?2@d06aDI00`62P0H4aH071HJ01lI7@0B31005@lC00X4200I4aL09b4U01LA5@0K5AT0
50lC01HA5@0H4aL05a8F01PC5`0J5AT03`X>01dH700D3a<04PdA01PC5`0K5QX081TP01hH7P0201XE
6`0401/H7@0L6Ql071XO01/J7`807QdR01H071/P020Q9P0M7b/07R8]02@X<`0O8Bd09BLb02@W<00R
8RX08R4X02HU:`0S82L081hT02`[<@0X;C<08R/b02@]=00S;3<082T`02</<`0R:c809Rlf0`0W<3L0
=P0V<3T0;CQ302/g@`0T<3`0?DUE030lB00g@dl0;SY602diA@0^>TH0<Ce903E1C@0g@dl0=D5=02hl
B@0eAE80<49@03E8EP0kCU`0<TIB0353C`0cATd0>DU@03U6C00fADX0=DM?03M9D`0oDE/0?DmI03M9
E@0jC5P0?e5M03]=F`0nD5h0>deK04=DI00lCE/0@e5L049@F`0nC5L0@4iI041>E`0nCED0?DaC03]:
D@0iB4h0=dI;03]:C`14DUL0@4eC03Q5B`0b?dD0<d1603A1A`80=D9800H0=dA:03U6C00iAT`0>4E;
03E2B@0f@d/203Q5C@0303]8D00jAdl0>DI>0080?4UA0100>dQ@03m<E00jB500;C]403I7C`0dADd0
<dA<03]<E00nCeL0<T=;03Q9D@0b@d/0>daD0352BP0kC5<0>DI<0P0iAdX01@0iAT`0>4E;03I3B`0f
@d/0=dA<00@0>DI?00P0<Sm703E2B00iAT`0=457034nA00e@TP0;3To03m<DP80<Ci403D0;3To03<o
A@0i@T/0=3e603HoB00h@DX0=Sm803M0B@0f?dP0>T=<03DnA`0a>T<0<3U202`e?00Z=CT0;cXl02/f
>00/=SP0<C/m05ANH011BD`0;SHi03Lo@P0e>Sh0;C8f02T^<P0M82L09BP_01lR:@0]<3L0@dI=02`_
=P0k?TD0BDaC02d`=`0[;SD0<3<j03@g?P0Y;S80;C8g03@i?`0U:C@0:Bdi034e@@0a=4<0N7^:04U<
F`0W:cL08bLb01lR:`0f=D80@T1=02PV<`02020N:@0o01hL9`0R8BT0:RTa02PW;`0U92X08b8X020O
9`0Q7b`08b4^034_?00]:cL07Q`W02<Q;00S8RX09bH^02PW;`0V9B`092<Y02<S:`0N8C4092Dg02LX
>P0V:3H08R4_01lO:P0U9Bd06aXR02DT:@0P7b@05A@I02DT:00N7R0071`N01hN8@0O7R<071/Q010?
5P0D4a/07A/V01lM:00G5B00;2Xg04U6E00Y9C<09R<^04A1AP2LViT0ZJRT059AC@0`;b/0=SDc020M
8P0J5b805Q8P028N;00J5b8061DP01XG8P0H5B005a@O01TF8@0N6bH07AXU00805a@O01<05Q<M01D?
6@0F4AP071LN01XE700F4AP071LN024L8`0I51/05Q4H01`G7P0M61l07QTP01H?5`0G41P071DM01XC
6`0G41P07QLO00807AHN01`05a0H02HO9`1@BE408AXR01TC7@0B31H07QPS07egP`0_:C<05Q0K00l9
5@1^J780OGN2014;5`0J51l071LN014?4P0P71l05Q4E02<N9@0H4Q`03`LD01dB800G31P08QLO01L<
500G3A007Q8F0P0J3aD00`0H3A<05``B01H;4@0201D:400601T>500N4aT05``B01L<4P0[82H091TO
0P0A1P`201H;4@0401X?5@0G318060dC01P=4`805``B00L05@X@01H;4@0G31805P/A01873@0C20h0
5P/A00805@X@0P0F2a400`0E2Q0050T?01P;500201L:4`0:01P;500H3A<060dC01dD6@0F3A80:1lT
01`F6P0J51H06aDG01LB608050lE00@07APN01lJ800J5A/05Q4G0`0G4QP0<`0I51X06QPM01dM9@0H
6b8082@/01<J8P0h?dT0QHnH03i;E00S<Ch0=4AA03I8E00jC5X0AeaX04mUL01CJGH0IGN707:1U01d
P9H0P8ZT08^E/02AVk@0VZJm08BCYP2:VJ`0NhZM0760T`1UMXP0FV]l055RLP1:G6X0A5EQ03=4CP0d
@DX0<S]502@[=@0W:cH06AdX01HJ9@0V:SD03a8M020S;00L72H0518M014@600R7RH06aHM00D01`0F
3aL05``B01L<400501P=4@0301D:3P0C20`050T=00805P/?00<05@X>01@93@0C20`00P0B1`/0200C
20`040D901L<400G31003P<700d21P0>0`L06`lA0P0F2P`02@0H30h05@T;01@82P0D20X05PX<0145
1`0@10H04PH800d10`0201D62@0401H72P0H2@`05`P;01<41`805@H90P0D1@P201D62@<04@D50`0B
1PH01P0h;2`06@d=00l30`0H30`0@SHf01`@40H04@D500X04PH601451@0C1`L060`<01D92@0B1PH0
4P@401<51@0D1PH05@L70P0F20P02P0G2@T04@<301430`0F20P05`T901H72P0F2A402P0400l22@0E
20l201T=4@0=01D93@0E2@/050P:01@82P0D20P04`T80188300>1@P040L:01D:3P0C20`04@H:0145
2@0201D62`804`@900X04P@60104100B1PH04@D60186200C1`/03`D701@8300800804@H<0P0<00P0
3`0=00P07A4E02LK7`0H31003`<701862P0T61`0710D00P0000@1@P06PhB01L;3`0E2@`04@D700X0
000201<72@0301`@4P0?0`D04@D700@04@D701803P8500`0100F2Ph03@4501<72`1REUX0:QhR01X>
4P0>0PH03`<700h21P0C1`/0200003T]<@0=0@D050P<01D93@0D20`2010420@04@D901@04PH:01H:
3P0<00@05PX>02/O8`0U6Ad0;20T01D93@0O4aL0Cd=709Z>TP0S5a/0200500h32`0C2100714I020E
7@0G31@04PL?01463P8040D=00<04@H>01873`0A10d01@0A10d01P0B1@h05`XC00h12P0;00L040<<
00h12QCooooo000Kooooo`0D01T?6019?dL03@<;00l42P0A1P/04@L802<G6@0P4a<06`d:01L91P0E
20804`D201@8200E2@/040@601D92`0A1@L05`/=00l31@0A1@L201H:300401hB500X71h050P801@8
20804`L70P0B1PH01P0=0`<040@401451@0E2@T03P8201H:2P805PX<0P0B1PP02`0@10H02P0002`P
8P0S5aT07A4C01@82P0A1@L02`0101/?3`0[7al08ADE008060`<00T05@T901061P0I3@d0;20P01H:
2P0D20P05PX:01@8200:00000P0L41000`0?0`<060`<01H:2P0201D92@0?01H:2P0H30`06a0?01T>
300E2@T04PH601D92@0F2P`04`L901041P0P51P0BSi201`@500H31005@T<00805@T;010050P:01D9
2`0E2@/06@d?02@H6P0B1PP06@d?01@82P0G2`d04@D:01/@600D2A404`P@01873`0D2A405@XB0P0D
2A40;@0C2100GU=K01`A6@0J4AH030H:02<M8@0D3Q8081XN018=400V82@04P`@010:3P0C3A409AlS
02`V:P0D3Q805@lC01@>4P0N61`0618F01dG6`0B3100:bDY01H@500R72003PP<01@>4P0B3A405Q4E
01/F6P0J5AT06A@H01XE6@0Z9BT0>SDi01`G6`0P6al07APL01HA5@0K51/06aDK01XE6`0K5Q`071TN
01dK800201`J7`0E01lN8`0N7B8071/P024R9`1?Deh0<SM301HJ9P0J7RT07B0Z01lR:`0O7bL08b<Z
02DT:P0S8BH09B8W02XY;`0U:S007bP_024Z<@0R:c8082T`00<08b`c00X092dd02Pa>00Y<ST09c4j
02Lb?@0g@dl06RHb02/g@`0U<Cd07RXf0P0_>dL05@0`?4P0=41<03Q4D00iAE40<cm;03M5DP0eAE80
<D=A02`oCP0gBUT0=DQE03A6DP0cATd0=DE=03M4BP0fADX0=4Q?03E9DP0mDEX0>TiG03E9E00203]?
FP0J03I9E`0oDV00=DQF03]>G@0iBUP0@DmJ041>F@0lBUD0?deH041>E`0lBe<0>4M>03U8C`0hAdd0
=dI;045@E@1@GV@0@DiD03A1A`0c@4H0;S]102dj@00c@4H0=T=903M4BP0hAD/203I3B@0703A1B00h
ADd0>dQ@03U6CP0lBE40>dQ@03M4C00203U6CP0B03Q5C@0kB500=TA<03=1BP0hBE40=DI>03A5C@0i
BU80<45903=4C00hBE40<dA<03Q9D@0gB500>DYB03m<DP0lBDl0>dQ>0P0nBe40100hADd0=T=;03I3
B`0gA4d203Q5CP1003Q5C`0i@d`0>TE;03Q3B@0c?T@0=3m503M2B00e@4H0>DA:03E0AP1?FV00:3<i
03E0AP0`>D80=Ci703@mAP0c?4D0=3e6038kA00a>T<0=d19034j@`0]=Sl0;SM002/d>`0X<cL0<3/m
02Pc=@0R;2h0<3Xl06QbM01IHF@0<SXm02Xb=@0V:bl0:Rlc03Hk?`0S9Rd0;S4h02T/<`0i?4<0F5]R
04U<D`1^LGP0V9^R0413BP0_<ST0<cHm02ha>00^<cL0:2db03<h?P0M8B`0<cM302DX=`1KGVd0h^Gd
08R;VP0Q9C409b/f0412CP0e=400?C]802TW=0808AlZ03P09bD`01dL900U92`09B@/02DT:P0Q82H0
6aXR028P;@0R82h0;2Xh02`Z=`0N72T09R@_028Q:@0Q82H08b8X02DT:P0T8bP08R8Z024S=00U9SP0
9RLi02<U<`0Q82h07QhY02@T;00[:S80<C0e028Q9P0D51H07QhP028R900O7b408R4U02<R9`0O7R@0
7ahU024P:00K6B@06aTU03Pf@`2:R9D0]K;0044mB`0U8Rd07adR02h]:`10?c/092<N01`K5`0Z:BL0
7Q/P01lL9`0L62H0920^01/H8`8061DP0P0D4A`0200N6bH06QLR00d:5@0E4Qd07a`W01dJ900M5b40
6QDL0P0M61l01@0J5A`07APO02<N9@0N6B0071LN00807APO00<08ahU01TB6P0F3aL00P0I4QX00`0E
3QH0614I01L@6002014:4P0`01/D700b:c<05PhH01<=6@0@2QH04`dJ034[>@0<1Q8050hK024K:@0i
<cl08Q`Y04m9E`0S7BX030H@01XH6`0D41<00`0201/F7@0D3AL06a<P028G9@0F2aL06@hF00h12P0D
20d07A4E01`A5`0K41H06@hD01P=4`0G31805@X@01L<4P0J3aD060dC01873@0?10X04PL=01H;4@0D
2@l0714G01lD6P0H3A<050T?01T>500H3A<05``B0P0F2a401@0G31804@H<01@93`0C20h050T?0080
5P/A00@050T?01H;4@0F2a405P/A0P0D2@l0100J3AH06@`E01P;500I31D201T>500=01P=4`0H3a@0
2`8701D=3`0E3a401@0101D@5P0G4QP050lE01TD6P0K5Q`05a8H01HA5`0201LB600d01HA5`0I51X0
6QPM01@D700K7RD0B4aD028Y<@0M92h0Mh6:03I3C00X=T<0<41=03E7D`0hBUP0A5UU04eUK`1@IW<0
HG>306mnT@1`Oi@0NhNN08JBZP2CWkD0XK3308JGY`24UJD0MHFF06imT01TMHL0FFYk04mPL018FVP0
@U=P03Q9D`0hADh0;cU202P_>@0/<3/0<SM202<Y=@0D62@092Ld08>5T@0[:cH07A/V01XH8`1@CEL0
E4iH020J900R6b@05P/A01H;3`8060dA00D06@hB01X?4`0F2`l05@X>01@93@0201H;3`0301D:3P0D
2@d050T=008050T=00H04`P<01872`0H3A406PlC00d21P0D2@d201T>4P0<01T=3`0C1`T050P:01P<
3P0D20X04PH801<72@0F2P`04PH801451`0C1`T03P840P0D1@P01P0E1PT05`P;01H72P0B0`H05@H9
01@520804`@700@050D801D62@0@10@040@40P0A1@D201861P0501P<300C1`L0200003<W9`11=CD0
1`0A1@D301861P<04`L71P0D1PD301D71P0:01H81`0E1`H050H60144300N4AP05PT@01L:4@0H3100
4@D901<72`804`L900X050P:01@8200C2@P04@L;00`31P0>1@P050T=01<8300@1@T04@D90P0F1``2
01@52P0Q01<51`0B1`D03`<301<7200@10H04`L901862P0Q51/040<:00h32@0@0``060/E01@73`0F
2Ph06PhB01@8300?0`L04@D903/_<`0e:Bd03P8600h41P0H31003`<700X00@0B1PP04@D701041P08
00005`/=01041P0>0P@03@4300<03`<501805@T<01862P0D20`0200001`@502fZZh0;20T01X>4P0>
0PH040@800h21P0B1PX0Ac/o0:6EV@0T61`04PH:01<72`0>10H401862P804@D900@05@T=01H:3P0?
0`L05@T=0P0]8BD03`0<00@0200000l51`0/82@0JUiR01L;3`0A1Ph06PlG01<8400<0@T040D=01X?
5`0D2A404`P@01463P0301053@H04@@=00@05PTB01lB6`0B1@h02P060P0@0``Dooooo`006oooool0
4`0B1`d040H<01D;400=10L04`T;0147200E2P`04PL701hC4P0F2@L05``:01061@0C20T05@/<044g
=`0E2P/05@/<00d20`0D2@/00P0B1`T01P0@1PL04PL901P=3P0E2@X050P901<720804PH702@04`L8
01451P0K3a004@D601861`0D20T060`=01D92`0H30h04`L901@82P0G2`d04`L901`@4P0M4A<050P:
01<72@0M4A<04`L901@82@0M4A8060`=01861`0I3@h081@E03L[;00?0`@05@T:00h30`0J3Pl05@T:
01X>3`0G2``060`=01H:2`0A1@H201/?400501<7200F2P/04PH700h4100H30d00P0E1`T06P0F20X0
60/<01L:300F20/05PT;0185200K3A404P@801X=400C1PT05PX<01P<3P0I3@l05`/=01@82P0F2P`0
5`/=01D92`0F2P`050P:0186200E2@d060dB01D:3`0C20d05@X?0P0G31403P0C20d05P/@01hC601D
BDh07A<H0107300E3Q@04``B014;400?2@h0@3Xo08IoQ@0F41D06a@J0P0D3Q<0D`0E3Q@040X?01dF
700H4AL06A8I00`62`0J4aX0ACi507=]LP0Q6R005a0G02LQ9P0N61h05Q4E01LB5@0J5AP06ADG01LC
5P0H4aL05a8F028M8@0H4aP0:bH[05]FF`0K5Q`071HM01`G700P6b008A`Q020L8@0Q7R<081dS01hK
8@0N72807a/Q01lL8`0K6B00FU]T03TlA@0F6R<07AhX01hQ:@0L7bL06ahV02@U;P0o@DP08R<[01lQ
:00R92`0720Z02@[=00L92d09Bdf028Z<`0V;SH09c0h02@]=@0V;cL0:C8j02`f?P0X<S/08Rdf02/g
@P0Y=T00<3a702Tf@00^>dH0<Ci903E2C@0/?4H0<T1=03]8E@0nBeL0=45@03]9F00d@e40=4A@03A6
D@0a@d`0>DYC03A5CP0c@dX0<d9:0080=49:01X0>D]D03=5C`0cAU00<dE?03M8D`0lCeT0@59M03a>
F@0kCET0>4]H03i?G@0iBUL0>T]F03e?FP10D5/0?diI03m>E`10D5P0?TiE03e<DP0hAdd0<d9703]:
CP18EU/0>4E;02dj@080<Ci400h0<Sm503]8CP0hAD/0C5UO04YGG@0`?D<0>4E;03E2B@0iAdh0>DM?
03E3B`0hATd0>DM>03U7C`80@U1H01T0>TQ@03]9D@0iAdh0>4M?03U9D@0iBE00>d]C041@F00nCUD0
=dM?03I6C@0dA4`0<d=:03Q8C`0eA4/0>dQ@03I3BP0lBE00>dQ?03M4B`0_?4@0<Ci603Y7C`0d@DX0
<d180080=D9;02d0<Sm70390A`0f@dX0=D5803<oAP0d@4L0?4M>03@nAP1GHFT0IFmf03a6C@0f@4P0
;SPo03<mA@0f@4L0;cQ0030i@@0^=cl0;3@l030h@00]=Ch0;3@l02dd?@0Y<CP0;3Dk02/e>P0/=SX0
;CDk02H_<`0d?400<STm02T_<`0^<SH0;C4e02/_<`0X;C409R`b01lU:`0R:2h0:C0d03@j?P0m@DH0
PhN=0;Vm`@13Ad/00P0_<cL02@0]<3H0<CDn024V<P0V:cL092Te024U<@0X;3T0;Blm04Q:F00202T/
>01i03Df@P1LGFP0;bdg02LS;@0P7RP09R<]028O:@0Z9c409R@]02HU;P0U8bd09B@]024Q:P0L6bL0
9B<b01XH9P0O7R`07ad[02@S<00n?DX08R4]020O:@0O7bT08b</02DT;@0T92l092He02DU=P0S8c80
8R8`02<R;P0O7RX071/V028P:@0P7RD07adS028P9P0N7B<07ahS01lN900Q82D08R4X020O9P0L6R@0
71XV01lM:`0R82l0:RPg05iKJ`1iMhH09b@a01HC7`0Q7RL08B0U02TX:`0T8bD06aXK01/J7@0M6b40
8b4Y01PF800K62<0510K01XF8@0H4ah05Q8L01TD7`0L5b806ADM028N9P0V8RX081`T01TE7@0N6B00
7QTO01PC6@0O6R406aHL01PC6P0F4AT08adV01/F7P0M5b0071HO01/E7`0S6b<060lH01lE7P0R5b00
7QDN01/A6P0M4Q/06Q4J01lF7`0J3aP04`XC01X@6P0N5b<05@lL01PB7`0D3Q/04P`I01<=6@0I4b00
5@lJ02LQ;02`Zk@0ACm9018<500D3a<04@`?01H@500L5Q/05a0H01TB6`0D31D05@`E01L=4`0>1@T0
5`dC0147300201T>500;01`A5`0K41H05P/A01D:400F2a405``B01D:400F2a4060dC01H;4@0?10T0
0P0H3A802@0E2Pl060dB01T>4`0G31406@hC01P=4P0F2a005``A01X?500201H;40805@X?00@050T>
01<83@0G31405``A0`0E2Pl04@0D2@h05PX@01863@0I3AD05@/C01<:4P0E31@04@TA01<;4`0H3aD0
5`hB00l52@0G3a@050dD01H@5`0C3A@04P`C00804`dD00<05Q0G01PB6@0I4aX00P0K5A`0<`0I5Q/0
71`P01PI7@0H6b408RH^020W;`0R;3D06RHb02dkB00/>dT0>DYI041AH011E6<0CF9`051TL`1KK7d0
I7F706UiS@1bPYL0N8RL07b<X@22TZH0N8VL07Z<WP1aPY@0J7V;061aP`1IJg`0CF9`04MII`0oDEd0
>daF04=AFP13CUL0;CDo02<Z=00Q9Bl06adX02<T;`0O82X0;2`f01LF7`0I5b0061HM01TE700C3Q@0
4@`C01TB6@0H4A@0610C01H?4@0201@<3`0401P@4P0G3A405P`@01D;3P805@X>0`0D2@d0200C20`0
50T=01D:3P0F2`l040D901H;3`0B1`/04`P<0P0A1PX01`0D20X040@60186200H30h05`/=01D92`0B
1PP00P0C1`T201@82P0901451`0C1@P04`D801@62@0D1`T050H901841`0E20X050L900804`D800d0
4`H801@62@0D20P05PX:01<71`0A1@D04`L701451@0E2@T03P@4024E5@1:?Sh050T900804`L701h0
4PH601451@0A1@D04@D501861P0E2@T04`L701861P0E2@T03@<302@H600H2`X050L80185100B1@D0
4`H701@71P0B1@D05@P901D8200D1`L04PD601041@0A1@T04@D;0148200B1P/06PlB01051`0B1`X3
01872@0:0187200B20T040H:00h21`0?0`T04PH<01452@0?0`L04@D901<62@8050H:01005@L;01@8
2@0G2``0304101@82`0A1@P050P;01452@0=0`H03@8601@73@0<0@L050L?01442`0@10P03`<70P0A
1@T09P0B1PX0710D01D93@0?10L04PH:00d31@0A1@T05PX=0145200B1PT04`L:00/10`0K3a804`L:
01041`0?0`H04`L:00d3100G2`h05@T<00l31P0R5AT07Q4E01X>4@0U6A`060/?0143200A10P06@/@
01H83@0@0`L081@H06AHG00G2`l050P<01H:3P0?10L050P<0P0F2Ph201452@0E01P<4@0O4aX04`L>
01863@0;0@H040@;01lC6P0=0PP06`lG01873P0E2A003@<90104300C20h050T>00l52P0E2Q404`P?
00h32P0F2a804@H>00804PL?00h03`<<00h3300B1@l04`D@00l2300@0`h060/E01T<5P0F2A@06`hI
01@74@0<00X050LA01853aCooooo000Kooooo`0J01@:2`0E2``05@/<01<92P0A1`P03`D60147200M
4a@0^:j_05=9BP0@20P0:AlP01dC500=0`@06@l@01lE5P0B20T0718C01X@4@0D2P/0308300l51P0>
10D02`4201L;3@0E2@/201<72@0S01@82P0E2@/08QHH00X0000>0P@06Ph@01<72@0;00404@D701<7
2@0?0`D04@D701@82P0A1@L05PX<020D5P0E2@/04`L901P<3P0B1PP05PX<01dA4`0Q5AL060`>01H:
300M4A<05@T;01041P0J3Q0050P:00h2100<0@803`<501451`0D20X00P0F2P`0100@1PL060`>01T=
3`0>0P@201@82P0301T;3P0E1PT05@H900<05@H900<05PL:01L82`0G20/00P0G20/02@0J2`h0:Q`O
01T=3`09000050X;01451`0E2@/06@d?01@82P0301H:300501@82P0@1@H040H70147200C2@X00P0J
41401`0B20T05P`=01H<3@0C2@X05`d>01`C5@0A20d00P0D3A@01@0N5ah04@XA01L@5`2<QH`0<2T`
008040T@00l05PlF01PA600K51`050dE014:4P0I4QX07aPP01hG7`0<1@d0;BH^00l8400E3QH08AXR
01TB6@0H4aL00`0I5AH02P0J5AP05a8F01TD600N6Ah061<I028M8`0d;cD071LM01hI7`0L5a/201lJ
7P0Y01`G700N6Al09b8Y01dH7`0G4QT081XT024K9@0L6B8081lU02<T:@0L7B8061PP01/L900K7RD0
6alX024U;P0f>T<06R4[01`S;@0Q:380ADUD04]?FP0W:cH0:c8l020W<@0S:S@09c0i02H_>00Z<c`0
:cDn02Pb>`0`>T<0:S@m02`i@@0^>d<0;S]402dkA00_?DH0;ce803A5C`0`@D/00P0`@4d02`0_?dh0
<d1C03I3EP0f@e<0<d5<0350A`0b@DH0=TE90391AP0a@4L0=D=<0080>DMB01<0>daF03a=E`0jBeD0
>T]E03i?F@11DU`0?4eG03Q9D`0jBeD0=dQB03Q9D`0lCUT0>4aG03Q:EP0jC5L0>D]E03]<E00nCeH0
>DYA0080>TU>00H0=4=803E3AP0mBTl0>TM=03=0AP0d@DL203U6C00;04QEF`0gA4X0@DiD04AAE`0e
@TP0?T]A034oA@0d@dX0=DA;03=2B@0fAD`00P0eA4/02@11D5L0@U5H03E4B`0gATd0>4M>03I5C00h
Adh0>dYA03U8C`0203Q7CP0K0391B00d@dX0>4M>03U8C`0gATd0<d9903a9D@0iATh0;S]303Q5C@0e
@TX0>DI>030mA@0hADd0<d1803M4C00c@4P0>4E=0391B00d@dX0>dYA03Q7CP0a@4L0=T=;03Q2B`0^
>440@deF0080;3Dn00@0<CY303E0AP0a?480>DA:0P0a>T40?@0c?4<0;C@l02`c>`0]=3`0<3@m02hb
>`0X;cL0;cHn02Xc>P0Y<ST0;SDm030g?P0/<cT0;C8h02lc>00Z;C80:2/`02/^<`0V:bl092/a01hW
;00S;340:30c02/c=P0`>3/0;c@g04=8B`0/<3<07B4R02X^;`0Y;S80:Bdi01hT=00V;3`08bTg02T]
>@0V:SH09bTf01/M:@0N82`0;blk028R;P19Ae80;BTa02/V;@0T7bH09B4X024N9`0^:c@09B<[02@R
;@0V92l09B@_02<S;`0Q8Bd09bHd02@S<@0/:cT0;B`j04I5D`1dLh400P0N7B/08P0O7R`08R4_028Q
;`0P7bd0828_02HU<`0S8S008R4_024O;00P7RX08AlZ020M:00N6bD06aPQ01`F800K624081lW028Q
:@0S8RX09RD]02@R;@0M6bP06QPV01hK;00Q7Rl07a`]028O<P0Z9cL09bDb02DS<00X9S80:BLb02DS
;P0L6b@201HE7@0;01XI800O7R@081lU01PE7P0W8Bd091hZ01lI900d;SP05@lI01TD700I51/00P0L
5ad0700J5A/05Q4G01hI7`0L5ad05A0F01PC6@0E41H06QDL02<M9`0E3aT06aDO010:5P0B31P06A8N
01P>6@0/82X06`lI01<74@0G2aD06@dG034U;`0]8B/091PR01dA6`0L41X06a0I01H>6`0H4Qh201<=
6@0D01TC7`0A2aD071HP01/E7`0@2a809R4W01<>500N6Al050hB01PB5P0C3A401P0401H@501;ADT0
50hB01dG6`0K5AT050hB018<400T7R8201@93`806PlE0P0D2@l00`0E2Q005``B01P=4`0201L<4P0=
01P=4`0O51P09Q/O020E6@0H3A405P/?01<8300E2Ph0714E01dB5P0H3A4050T=01D:3P0201H;3`80
5@X>0P0D2@d0100H3A405P/?01D:3P0F2`l201T>4P0=01X>4P0R5ad05`hC01L@600D3QP01`4;01<=
5`0B2a<05@hE01H<4`0E2@d05``B01H=5@0201<<500L01@=5@0E3QH05PlG01PA6@0I4QX06a@L01`E
7@0I4QX05Q4G01TH6`0I6Q`06Q`P01XO9@0N8R/07bLa01lY=@0Y=D<0;Ca<03I6EP0oD680@55R04UJ
JP1=GVh0E6Ef05]/OP1PLHD0J7V=0762UP80Lh>J0200MXJM07B4V`1_P9@0HgB605U/O@1CIgL0B5i/
045GI00oDel0=4I@03I4C@0g@d`08bdf020W<@0V:34092<[028Q:@0R8BP07ahT01`I800I5a`061HK
01HA5@0D3a<05A0D01TC5`0;1`P03PX;014=3P0B3Pl0510A01`F60<050/>00T05P/?01P=4@0J3a<0
5P/?01D:3P0B1`/04@H:01<8300G31000`0D2@d301<8300301451`0C1`T04`L9008040@600<05PX<
02@H6P0G2`d00P0:00000`0B1PP06@d?01862005018620<04`L901<050P:01H:300F2P`04@D501L;
2`0A1@D03`<301861P0@10@05PX:01051@0F2PX03@4101@8200F2PX050P801<71`0B1PH04@D50080
4PH600P04@D501D92@0D20P040D500P0000d:2P05`/=01<72@804@D700<04PH801@82P0C1`T00`0C
1`T201451`0701@:2`0@1PL06@l@00l51P0G3@h0308301<92P0301882@030147200A1PX04PD=0080
4@@;014040<:00l31`0?0`L03P8600l31@0@10H04@D701451@0@10H06`lC00l31`0F2Ph040@80186
2P0A1@T04PH:01452@03010420804@D90`0B1PX00`0C1`/08aLK024E6@0201<72`0G00h21P0=0@D0
4`L;00h21P0C1`/05@T=01<72`0E2@d03@4501862P09004040D801@8300=0@D0304301/<4@0F1``0
6``A04/l@@0K3A4060T>01H7300H2@h00P0N3a@0<@0G20d03`<701@8300;0@<03P860104200F2Ph0
4@D901@8300E2@d03`<70104200J3A<07Q<K00T01`0A1@l01`05028F800@10h05@TC00T01`0<00X0
4@D?01P<5P0@10d050T?01@93@0C20`04@H:01052P0>0`T05@X@00h32P0B1`l050TA00l3300>0P`0
3P0=0143400<00/03@0<01H85@0E1a@04P@A0143400B11403@0<01H85@0@0Pl05?ooool001_ooooo
00/04`T:01L=3P0G3@h050X;01<92P0E2``02P0101`B4`13>CX03P@501061`0200L0000601H>3P0=
0`@04`T:01492@0A1`P04`T:0P0B20T01@0M4a@0718C0147200E2@/050P:00<04`L900D050P:01`@
4P0@10H04PH801L;3@0201D92`0301L;3@0F2P`04PH800804PH801003`<501@82P0G2`d050P:01<7
2@0E2@/050P:0186200G2`d0710B01L;3@0B1PP050P:01041P0B1PP05@T;0P0C1`T01@0N4Q@04PH8
01D92`0D20X04`L900805`/=00H06`lA01X>400I3@l05@T;00l31@0A10H701D62@0;01@5200C10L0
5@H901T:3@0Q4aH02000040d=P1ODeD09ATK02LK7@0>10D00P0E2@/0:00F2P`05@T;01D92`0E2P/0
8ALH020F5`0D2P/060h?01H<3@0A1`P06a4B01@:2`0<0P<05P`=01T?4@0@1``04@/?00l93@0H4QH0
5@lC01XD601OFEd08A/O01<=4@0B31006A<G01H@500E3QD04@XA01TB6@0L5A`040T@00P120090PT0
7QLN01L@5`0F3aH07AHM01H?5P0A310201PD5@0;01HB4`0J5QP04`hB01dH700H4aP04PdC02@O9@0>
2A007APN01dK800J61/00P0K6A`0>P0H5QX06aTN02<P9`0J5ah05Q<J02/X<@0N6b@08QlX01lN900[
;3409BH[01/K8`0K72@08B@[01lS;00M8BX05QXS01/R;00P9c407B@^02@X<`0]<C`05a/V01lV<00Q
:380:S4k02H_>01;E5d0624Z030j@`14CUL09Blh02dg@00/>D40:cQ002Xg@00Z>440;3Y302/iA00Y
>DH0<T9?03A4D@0b@Tl0<d=B03A1E00f@eH0=45A034oBP0_?TD0;ci303A3B00c@TT0<T5803=1BP0g
AE00>TQC03=4CP0jBeD203a=E`0G03m@FP12Ded0>DYD03Q9D`0lCEL0=dQB03I7D@0kCEP0=TYE0394
D00fB5<0=TQB03M8D00iBU80=dQ?03Y9CP0mC540=dI;03=1A00f@dP0=D98034nA00c@4H00P0hAD/0
1`0oC580>DI<03U6C00c@4H0;ca203U6C00e@dX00P0eA4/0200b@DP0=DA;03I5C00b@DP0>4M>03Y9
D00b@DP0=4=:0P0fAD`03P0hAdh0>TU@03Q7CP0gATd0>4M>03=2B@0eA4/0>4M>03U8C`0gATd0=4=:
034nAP0gA4`0?4UA0P0]>T805`0_?4@0<Sm7038oA`0b?dL0>DI>02hk@`0hADd0<T5803=2B@0gATd0
=DA;02lnA@0c@4P0>49;038lA@0_>D80;3Dn03<lA@0b>d@0=3m502lj@00e@4H0;SLn0080;cPo02`0
;3<k02/b>P0[<SX0;S8k02da>P0X;cL09bhf02df?@0Z<cX0;3<k034h?`0X;cD0;c@j030d>P0Z;C@0
:B`c02`_=P0X;C<092/c01lX;P0T;C80:2le02H^<P0X<3<08bP/01lS9`0^<SD0;C4d02T];`0Z;c<0
:Bdh024W=@0Y;cd09BPg02DY=@0O8bl07b4^01lQ;@0W:CD0;Rhj01lO:@0Z:3<09b@/02/X<@809B8[
02008b0[02l]>00O7RT0820/024Q;@0R8bl08B<`028T<@0];3X0=SE300403P1NGF/0MgJ401hM:`0L
6bT07Qd[028Q;`0V9C<081l]01`K:@0Q8c00:RTg02LV=00R8Bl07adZ01dK9`0N72L07a`W020M9`0O
72D081XT01hK90807A/V01d07adX02@R;@0Q7b`06aTV01hL:@0P7R`07ad[020N;00K62T05Q@Q01PF
8`0L6RL07adY01hL9`0J62<06QTR01lN9P0P7bL071/R01XI7`0O7R@09R8[02LQ;@080Ph0:B<^06=M
I`0U7bT04`hF01PC6P0201XE6`0B01TD6P0G4QP071LM01LB600M61h05Q4G01@?5@0J5A`05Q0J028L
9P0F41X07aTU02LQ;@0J4ah0:AlZ05Y>F00e:C<09ATS0P0Y7BL0800a9Bl0:AdW01dA6`0J3QP06`lI
01P=5P0@21D06aDQ01H@700Q6bD0?3I002lY<`0500L04PdD01<>5@0A318061<I01@?5@0E3a<05a4E
01D?4`0<1PX04@/?02hX;00M5a/030L:014;3`0U7b<050hB00l93@0E2Q0050T?0P0G31800`0D2@l0
5@X@01H;4@0201H;4@0>01L<4P0I3Q@06@hD01X?4`0Q5QX0714E01L<400F2`l05@X>01L<400O51P0
8AHJ01dB5P0G310201H;3`<05@X>0P0D2@d05`0F2`l05@X>01D:3P0F2`l05``@01T>4P0G2`l03`@:
00H00P0E3QH0618L01LA6`0C3AL040TA018;4P0B20l04`L;01D:400D31@04P/C01<<500E3QH05PlG
00805a0H0P0J4a/0>`0H4AT05PlG01D@5P0J6A`06Q/O01TK800I7R@07B4Z024Y<`0T;SX0:SI402Xi
B@0b@U80?4]N03m?H@17F6P0BU][05AUMP1NKh40HG:406AeR01[O900KGjB06emT`1`P9L0KWjE06]l
T01SM8H0G6n005]_O`1@IW@0A5YW041DG`0^@4X0;C]402Hb>`0P:S<0:C0j02HX<@0V9Bd092<[02<R
:@0Q82H07AXQ01`J7`0I5a`05a8F01<>4P0D3a<06A<G01LC500H51D05a<D014=3P0=2@X03@L901P?
4P0F3A0050/>008050T=00T05@X>01P=4@0F2`l04`P<01462P0B1`/05@X>01@93@0E2Ph00P0F2`l0
3P0E2Ph04`P<01041P0I3@l07a<E01@82P0>0P@05@T;04@h>P0^8R@05@T;00h2100@10H050P:1P0B
1PP201D92`8050P:00h05@T;01H:300>0P804`L701861P0@10@04`L701451@0F2PX050P801P<300;
00005`/;01<71`8050P800<04PH601451@0B1PH00P0B1PH01`0?10@04@D501861P0900006`l?01H:
300D20X0100B1PP601<72@0701<92P0@1PL06@l@01<92P0O5AH04`T:0147200301882@0601<92P0C
20`050L?01<63@0B1@`04@@;0`0?0`L02@0A1@L04PH80186200?0`<0308201862P0:008050P<00h2
1P0201@8300301<72`0B1PX04@D900804@D900<04PH:01<72`0B1PX00P0B1PX05@0A1@T06@dA01H:
3P0@10P04PH:00d11@0>0PH03P@603P/<01`I6P0Ac/o00P0000=0@D06`lC01X>4P0C1`/050X<02LK
7`0A1@T040<701421`0201D62`0302TJ7`0G20d05@H;00804`@901`060T>01T:3`0E1P/04`L;01T=
4@0C1`/05`/?01P<400R5QX03`<701452@0B1PX040@801452@0E20h0PWMo02DJ8P0J3aL03P<;01H;
4`0J41L0;R<[00P01@0R5al03`@<02LL900900H04@H<0P0A1PX0400@1@T03`@900l42P0B1`d03`@;
01873`0C210040D>00l33@0>00d04`DB0143400B11404`DB00l13P0C1A8201844@0300X02@0@0Pl0
200701Cooooo000Kooooo`0900h41@0D2P/05P`=01<92P0E2``0718C01H=3@0?1PL05Pd>00805@/<
00d030<402PN7`0`9RL05`d>01H=3P0C2@X05@/<00`30`0C2@X05P`=02DK700P5QL030<400H04@D7
00D04`L901041P0D20X05@T;01451`0201<72@0301041P0A1@L050P:00805@T;01h04`L901451`0E
2@/050P:0186200E2@/04PH801451`0B1PP050P:0186200@10H05@T;01<72@0?0`D05@T;01L;3@0T
61X04PH801D92`0C1`T04PH801L;3@0B1PP03`D601D92`0C1`T04PH801P<3P0D1`T501@5200=01D6
2@0G20/060T<01P9300F1`X05`P;01P;3@0C2@X03P@502DI6`0F2P`0200001T=3`0501D92`0b01@9
2`0W7Ah0:1hO0147200B20T05@/<01`B4`0F30d050X;01D;300D2P/05`d>0107300D3Q805a4E010:
3P0>20`05@lC01@>4P0:10P06A<G00l93@0D3Q805Q0D01D>5@0C31<05PlF00l83`0J4aX0GeQO024J
8@0K51/06Q<J01<<4`0G41L0618G01@?4`0L61T061@E018>3`0I5AL05A0D01<>4P0J5AX081/Q01dH
7P0M61l061<I01`J7`0I5aX201/I700R01/I7@0Q7b@07a`S01dJ8@0O72<0>SM001/H8@0L6b<06aXP
02HW;00T9BX07AdU01dO9P0O8RT092Pa01TM9P0K7bP09B`f024X<P0J8B/06AdX02HZ=@0T:3<09bhh
028Y<`0P9c40?DI?071iPP0]=Sl09c4j03e7D00Q:c@0;CM102/h@080:CHo02/0;C]502lmA`0jB5<0
:CU603I6D`0gAe@0=TID03U9F00iAUP0>4EF03E2DP0a?d/0<3i70391B00iB4h0>DQ?03E4B`0_?DH0
<3i903A2C@0a@T`0=4E?03Y;E@11DU`0?TmI03Y;E@0kC5H0?DiH045BG00lCEL0>DYD03Y<EP0fBU@0
>TaG04EGHP12E5h0>T]C03Y;DP0kC5<0>dY@041?E00kBTl0=TA80080=dA:00<0=45703=0AP0d@DL0
0P0b?dD01P0lBDl0>DI<03I3B@0hAD/0<Ci40390A`80=DA;00<0=4=:03U8C`0lBe800P0hAdh01`0i
B4l0=DA;03M6C@0iB4l0=DA;03M6C@0hAdh00P0eA4/0700gATd0>TU@03Q7CP0d@dX0<d9903E4B`0h
Adh0?T]C04]HH01oS9@0>TM?03a9D@0`?DD0;ca403M4C00a?TH0=D9:03=0B00iATh0=TE<03E4B`0f
AD`0<d9902lnA@0c@4P0<3Y303]5CP0^>44203Y3C00:034j@`0d?dD0<ci403Q3B@0a>T40;cPo02L`
=`0^=Cd0;C@l02`c>`80;c<l00h0:S4i02H]=@10BE00=d1702Xa>@0]=3/0;3<j02`a>00`=3/0;2lg
02/^=P0/;cL09RXb02T`>0808BX`00@08bXa028Y;`0U;3409b`a0P0Z;S80?P15B4`09RX]034f>P0T
:3<08RPf02db@00/;cd0;S4m02DX=@0P8Rl08B8^02DV<P0Y:C@0;Rdg02HT;`0U8bd0<Rli02TY<P0X
9Rl08b8]02//=`0P8B`08B8_01lR;P0N8Bh08B@b02<U<`0Q82h0:RTg02@S<@0];3X0:bXh03@c@@0Q
82h07ah/02DT<P0W9S@08B0^020O;@0W:CH0;B`j02PW=@0S8S008R0]020N:P0P7RT08QlZ028O:@0R
7bP08adW028O:P0P7RX071XV01dK9`0S8Bd081h[01TG900P7RX07adY01HD800M6bL08Al[0`0L6RL0
4@0J62@071XU028P:`0T8R`07QdU01/J8P0F5A`05QDK01XI7`0P72D05@lK020J9P0O6B@07QPR01H@
6P0M5b006QDL00@06QDK038061<I01@?5@0[9R`07aXP01XE6`0J5A`06A<M01D?6@1cKGL0>C<o01TC
7`0P6BD03`D@02DJ900M4Q/05``E01hC700F2a@06@hG01P=5`0H3AH060dG01X?600M4Q/05`lL01/D
8@0C31P04P/F01hG8P0D3QL05a4H01D?5P0N61l02@<901D?5P0?2A006Q@H01@>4P0H4QH06aDI01@>
4P0>2@`03PP<01D?4`0N61`050hB01TC5`0@2Ph060dC01D:40805``B01405@X@01P=4`0J3aD05``B
01@93`0E2Q005P/A01D:400C20`060dA01D:3P0D2@d060dA01L<400C20`05P/?01L<400201H;3`03
01P=4@0E2Ph05@X>00@05@X>01<060dA01H;3`0I3Q805P/?01<8300E2Ph050T>01493P0F31@040XA
01`H801LF6405a<L018<500C31@04`X@01D:400I3Q@05@dE00H050dE01D06A8J01PA6@0E3QH05PlG
01PC6P0J6Ad06QXO01TK8@0I72<0720Y024X<`0S;CT0:CE502`iB@0gAUH0@U5T041@H@0oD600@eAT
059SL`1NKh000P1QLX@0801UMXT0J7V=06QhS@1ZNY00JGV@069cQ`1JJgd0FFam05mdP`1EJgT0AUaY
03]?F`0^@4X0>4I?02/g@00T;SL0;SDo024S;00S8RX08B0X020O9P0N7B<06aPO01XH7@0I5a`06QDI
01PC5`0F4AD05Q0D01HB4`0E4A80510A0P0C3a006P0G4A<06Q4D01P?4P0D2`h05@X>01T>4P0P5AT0
5P/?01D:3P0D2@d04`P<01@93@0F2`l050T=01D:3P0H3A405``@01H;3`0C20`040@601/?4@0Y7Al0
8ADG01D92`0>0P@050P:0P0B1PP00`0C1`T050P:01451`060186200F01P<3P0F2P`04`L901451`0@
10H03`<501451@0D20P05@T901<71`0B1PH04`L701861P0E2@T06@d=01@8200I3@d03`<301D92@0D
20P04`L701861P804`L700H03`<301D92@0G2`/04@D501@8200A1@D401@82P0>0186200A1@L04`L9
01<72@0B1PP04`L901@82P0E2@/05@/<0147200D2P/03`D601`B4`0?1@H20147200801882@0C2@X0
4`T:01@93@0E210050L>01<63@0B1@`20104200:00l31`0A1@L04PH801<72@0B1PH06`lA02TM8@0D
20`04`L;00d11@8050P<00D04`L;01862P0B1PX04@D901862P0301<72`0W01862P0A1@T04@D90104
200>0`H040@801@8300?0`L040@801H:3P0@10P04`L;01<82`0D20`060`@01<82`0<0P@05PX>00l4
1`0@1@P03`<701@72`0?0PD05@L;01421`0E2@/05@L;01<42@0A0PL040460183200C10T050D:00h3
1P0C1`/04@D901<72`0?0`L050P<00<040@80P0C1`/03P0A1@T0;b@/01873`0C2Q0040D=01@94@0D
2Q407a@L01H=4`0k<3P02`4801H;4`0D2Q003`@:0`0?10P0100?10T03`@:01052`0A1Pd201873`04
0187400A1@l0408>01443`804PD@00P04P@@01433`0A10l040<>01<64@0A0`l081<N020B7QCooooo
000Kooooo`0301882@0E2``04`T:008040H701@050X;00l51P0M4a@0718C00L0000G3@h07aDF01H<
3@0F3@h01`00020F5`0E2``050X;01H<3@0D2P/0200001L=3P0P5QL050X;01<72@8050P:00H05@T;
01@82P0D20X04`L901@82P0G2`d201D92`0C01/?4@0J3Q0040@60186200C1`T04@D70186200C1`T0
5PX<01P<3P0D20X04PH801@82P0F2P`04`L900l31@0C1`T05PX<01@82P0301041P0401@82P0?0`D0
50P:01`@4P805@T;00T05PX<01451`0P51H04PH800X0000K3a403`<500/00@0G2@`01@0E1PT03@0D
1@P05@H901L82`0F1`X050D801D62@0K3A003P84020D5P0C2@X0200001hB500D20X00P0E2@/0400D
20X05@T;01D92`0E2P`04PP901061`0H3Pl07A<D01<92P0E2``040H701T?400D2P/02`42038Y:P0U
71l200h8300501PB5P0M5a/05Q0D01PB5P0A2`l00P0C3A403`0L5QX04`dA00/42`0>1`h06Q<J01TB
6@0A2Q4071DL01L@5`0>1`h05@hE01XC6P0H4AP07QLM01@@4@0201HB4`0N018>3`0D3a806A@H01hI
7@0H4aP05Q4G01`G7@0C3Q@07QTO01HD6@0D4QD06ALJ01/I700K6Ad081hS02<P9`0L6B005Q<J02HS
;00G51d071/S01PI7P0N7b@07AhS01hN9P0O8BP06QdT02T]=P0F6R<08RH_0P0K8R`0>`0P9c4061`W
01`P:`0P92l07RD_02@[=@0W;SP0;cQ1034j@`0c?4D0:C<l02La>P0_>D80:S@n02Tf?`0X=Ch0:SM0
02hlA`0b@4/0=49=0351CP0lC5T0@E5N03a<F`0hB5L0?DYJ03Y7E`0fA540<d5<03A2B`0fA4d0=dI=
03I5C00eA4/0<d5:03=1C00d@Td0<T==0352C00fAe40?TmI03Y;E@0cA4h0>DYD03Y;E@0nCeT0>daF
03Y;E@0jC5H0=4QA03E7D@0mCeT0?4iH03U:DP0jBe<0=dQ?03M6C@0jBDl0=TE:0080=T=900<0=457
03=0AP0c@4H00P0d@DL00`0c@4H0>TM=03Q5B`0203=0AP0;030m@`0d@TP0=DA;03I5C00eA4/0>dYA
03e<D`0jBE00>DQ?03Q7CP0fAD`00P0gATd0200d@dX0=DA;03E4B`0c@TT0<T5803E4B`0d@dX0=DA;
0P0hAdh01P0eA4/0<D1703E2BP0b?dL0?daD02@a>@80;S]300P0:SLo03a9D@0b?dL0<d1803e:DP11
CUH0=dI=0391B080<D1700/0;Se403=0B00^>440>D=<02hh@@0e?TL0:c@m034j@`0b?D<0<ci403M2
B002038k@P0@02</<`0`=cl0;C@l02`c>`0_<c`0<3@m02`c>`0]=3`0<S]202df?@0^=Cd0<3Lo02D/
=00V:S<0:Rdf02LZ<`809RTb02807b</02`c>`0P:C007BH]01lV;P0Q:3009Rdc02<X;P0N8RP0;S4f
028U:P0b=CX09BP_02/_>P0Z;Sd0;S5002``?00`<Sl09BLd01`N:P0S8bl09BDa01hN:00U8bh08b4/
028Q:`0];CL092@^02<T;P0K7BT07b4]02HY=@0Y;CT09b/g0P0S9SD0>00V:CP092@b018A7`0C4R00
:2Le028Q;`0T8c408b8`01lN;00R8Bl07Qd[01/J:00Q82h08bDb02DT<P0P7bd08B0^02<Q;P0N72P0
6aTT01dJ9@0O72H08QlX02HP:P0W8Rl0928`01lM:`0L6RL081h[01lM:P0H5R4071XU01lM:00I6200
61LM01XI8@0K6B<07A/X01lM:P0L6RH061HQ01TG8P0R82X08B0X01TH800H5ah06aXP01XI7`0D3aT0
8A/W02/U<@0L5R40:B<]01TC7@0I51`061<J0P0G4QP03`0H4aT06aHL01`G7@0G4QP07aXP01TD6P0F
4AL06aHM01lI8`0@2Q@0IV1Z01D?6`0C3AT06aDP034W<P0201L=5P0H01D;500K4AX05`dF01L=5P0K
4AX07Q@M01P>5`0E2a@05`dF01@<5`0A2AH05`lJ01XB7@0F3QT08AXR01lH80080@T0614H01/D6`0H
4AP04``C014;3`0E3a<05a4E0P0D3Q802@0H4QH0=Blc01TC5`0U7b<0;BL[051:CP0>20`06@hD01H;
4@0201P=4`0501H;4@0I3Q@0714G01H;4@0D2@l00P0F2a400`0A1P`05P/?01T>4P0201@93@0901L<
400E2Ph06a0D01P=4@0C20`04PL;01@93@0E2Ph050T=00<05@X>0`0F2`l0600G31007a@H01dB5P0H
3A407A8F01X?5@0K4AT071DL01<>5@0;2140;2Tb01LD7@0C3AL04`hE01@<4`0G31806a8G01H>5P0F
3aL05@hF01@=5@0B2a<04@XB018;4`805@hF01H05PlG01PA6@0I51/061HM01XI7`0J6B006A`U01`P
:`0N93407RHc02D^?`0W<d@0<d1A03e<G`0lC5`0?e1P04=DI01=GVh0E6Ee05IWN@1HJG/0Gg220P1R
LhL0501TMHT0HW:9061aQ01HJG/0D6=d04aPL013FFL0?UAQ03a@F`0bA4h0>DM@02`h@@0S;CH0:S4k
02<U;`0T8b/08R4Y028Q:00O7R@071TP0P0H5Q/0400K5QX06QDI01PC5`0F41@0:BDV02<O800H51D0
40`=00d92P0=1`T05`hA01D<3`0B2@`050T=01P=4@0O51P301<8308050T=00<05P/?01@93@0E2Ph0
0P0F2`l03P0E2Ph04`P<01041P0B1PP05@T;01L;3@0F2P`05@T;02DI6`0P51H06`lA01P<3P0B1PP0
30021`0B1PP00`0A1@L040@601041P020186200501<71`0A1@D04`L701451@0?0`<00P0D20P01@0A
1@D02P0001hB4P0D20P06@d=00805@T9100C1`L01P0K3`l03`<300P0000B1PH07Q8B00l30`804`L9
0P0D20X20186200401dA4`0I3@l05PX<01<72@804PH800L060h?01@:2`0G3@h05`d>02/Q8P0M4a@0
4@L800<04PP900<04`T:01<8300B1@d00P0B1@`0100A10/04@D901452@0>0PH200h2100700l31@0@
10@09ATK03HZ;P0G2`l04PH:00h21P0201862P0301<72`0B1PX04@D900804@D900<04PH:01<72`0B
1PX00P0B1PX301452@0F01<72`0B1PX03`<700h21P0@10P03P8601@8300F2Ph03`<700X00P0;0@<0
2@0100P0000I3A4050P<01lC5`0?0`H0404601<42@0<00805PL<00l21@@050D:00P05@H;01H7300N
4QH06PhB01<72`0J3Q805`/?024E6@804@D901004PH:01<72`0C1`/04@D900d2200N4a/0GE9J04a1
B@0A1Ph04PT?00h32`0C21006PlG00L0100:00L06@hE100?10P0500?10T03`@:00l42P0D2A004PL?
01053@0B1a0040@>01853`0?0P`04@@>01853`0C1Q0060/E01T<5P0E21804PD?00h12`0K3QP06PdG
5?ooool001_ooooo00@05P`=01@:2`0B20T040H70P0A1`P0500F30d02`8300l51P0M4a@020000188
2@0A1`P0KF=T079XJ@0J41402P4202dS900C2@X050X;00L0000E2``08ALH01X@4@0C1`T050P:0P0F
2P`0300E2@/050P:01<72@0I3@l05`/=00l31@0K3a40;20R02@H6P0G2`d05PX<01@82P803`<500@0
50P:01dA4`0K3a405@T;0P0C1`T01`0B1PP050P:00l31@0A1@L050P:01451`0D20X00`0A1@L00`0I
3@l060`>02`P8P0201`@4P0901X>400900005`/=01/?4@0D20X05`/=01<72@0<00805`/=00D04`L9
0P0B1PP0300A1@L040@60186200G2`d05PX<0186200J3Q0091PJ028F600J3Q005@T;01H:30<050P:
03X05PX<01X?4@0D2P/04PP901`B4`0J414050X;01<92P0A1`P060h?01D;300A1`P0:R0Q04i5B00T
7R0050h@018<3P0A2`d02PD6014;3@0=1`T04`d?01/E5`0O6A/03`T;01/E6@0E3a<03`T=01<=4@0G
4AD0618F01LA5@0I4aL06aDI024K7`0G4AD09b4U014=3P0@30d06QHG01/G600D41807aXN028M8@0C
3Q<03`X@024L8P0H4aX07aXP01LE6P0E5AL06QXL01/K7@0J6Ad07A`Q024P9P0L6b405QDK0P0J6B40
6P0M72@071dR024R9`0O82D07QhV020R:@0M82L08BD^01dQ:P0O8b`06B0Z01dT;P0O9S00;30k02L[
=P0U:C@072<]024X<P0T:cD07RL`01`U;P0H8BX0:S@m03<mAP0Y<c`0:C<m0P0X=Ch01P0Y=D40;3Y5
02lmB00Y=d@0<41?03=3DP80?TiM00P0>DUH03e:F@0iAe@0=D=@03=1C00fA4d0>4I?03E3C080=49;
0P0gAE00:00fA4l0<45;0393C@0dADl0=DI@03I7D@0gB580>T]E03M8DP0jBeD0>DYD03Y;E@0kCEH0
<dM>03=6C@0fBE00<dI=03A5C@0fAdl0<dA<03M6C@0hAdh0<d9903A1B@0d@DP0<Sm5034nA00b?dD0
<d1603I3B@0d@DL0=T=903a9C`0b?dD0:3Dk03=0AP0jB4l0=DA;03I5C00eA4/203Q7CP0303M6C@0f
AD`0=DA;0080=dI=00@0>4M>03A3BP0d@dX0=4=:0P0a@4L06P0eA4/0<d9903A3BP0gATd0=TE<03A3
BP0_?TD0=D9:034nAP0oC5@0;CY2038oA`0f@d/0;ca403U6CP0a?TH0<Sm703=0B00jAdl0<d9902hm
A00/>d80;Ca302`k@P0`?DD0<C]40P0c?DH0700j@d`0:S<l03DnA`0^>Cl0;CPn02lj@00]=Sd0=3e4
02Pa>00`=cl0;3<k02Xa>@0]<CX0;S8k02/b>P0[<SP09Bhc02@]<P0Y<3P0:S4i02D/=00X;3L0:B`h
028T<00Q8bl09BLc028V<@0Y<3X2020Y<P0N028Y<`0R:C409Rde02T]=P0P92X0;c8i01hQ:00b=CX0
8RD/03@h@`0`=400;30l02PZ=`0/;SX08B<_01lO:`0W9c40:2Pb01dK9P0O7RH0;2/c01lP:P0X:c@0
7b8[028T<00K7BT06alZ02@X=00Z;C`09bdk0P0Q9cD00`0S:CL07Ql/01hM:`0202TX=P0c01`K:@0U
938092<a02<R<00V9C<06aXX01LF900Q82h07b4^020O;@0O7R`09B@b02@R;`0P7RX081hY020M:00P
7BL0924Z02TS;@0X8c409B4`024M;00J5RD071PV01dJ9@0N6bH07Q/T01lL9@0Q7RD071XO01XG7P0N
6b@0920^02LS<@0X93409B8]02<P:`0Y9S00:RL`028O:00N6b<07Q/R01/H7`0N6R<07QPT00d74`0U
7bX0Ee5K02LQ:`0D3aL06A@K00805a8H01@06A@J01`G7@0J5A/06QDK01D@5P0I51X05A0F01LB6@0>
21808Q`V01D?6@0A2aL09R0/01H@6`0n=3l0<2H_01/A6P0L4Q/06a4J01L=5P80718K00d06Q0I01H<
5@0D2Q<04`TB01dE800H41/05`lJ018;4`0;10`04@XB05YCFP0[92/03@H=00<04@/?00h04P`@01<=
4@0G4AD06aDI01@>4P0500<02P@801<=4@0M5a/02@<701lI7@0A2`l060dC01D:408060dC00D05@X@
01P=4`0J3aD05P/A01L<4P0201/@5P0901D:400A1PX04`P<01052@0B1`/060dA01H;3`0M4QH06PlC
00<05``@00@05P/?01@93@0D2@d05@X>0`0F2`l04`0D2@d05P/?020E6@0M4QH05``@01`A5@0G3180
2@0700/42`0F4AT030TD00<02`0A3QP03PPB010;4P0A2A0050T?01L>4`0E31D00`0E3QH00`0C31@0
4P/C01D>5P0201@=5@805a0H02d05Q4H01PE7@0I62006ATR01TL9@0L82/08BLd028Z=`0W<4409311
02TfA`0b?e00<d=C03i@GP14EV@0Bee/04mPL01BHg<0E6Ef05UZO01KK7h0Ffao05i_P`1LKH40G6f0
05Y[O@1CIWL0Bem_03mEH`0mDf00?U9M03=5C`0a?dP0;SY302La>P0V;CL09RPa02HU;@0T8b/08b8Y
024P9P0M6R406QPM01TG700H4aL00P0G4QH03@0J51P061@E01DA4P0B3Pl0510A01LC500H4Q@060lB
01L>4@0F3A0050T=01462P0?10P00P0E2Ph201@93@0301<8300D2@d050T=008050T=0`0C20`30145
1`0901041P0B1PP05`/=01<72@0?0`D03@4301041P0D20X05@T;00H04PH8100A1@L01@0C1`T050P:
01@8200@10@04PH600804@D500T06Ph>01<71`0C1`L03P8203L[:`0F2PX07Q8B01H:2P0E2@T00`0C
1`L01`0D20P07a<C01dA4@0B1PH05`/;01P<300:00001P0C1`T00`0K3a405PX<01@82P0301862007
01@:2`0C2@X05P`=01`B4`0e:b`09adN01<92P0301882@030147200A1PX040<;008040<:00D04@@;
01452@0A1@T05@T=0186200200l31@060104100E2@/07a<G00/00`0?0`L03@450P0C1`/00`0B1PX0
4@D901042002010420804@D90`0B1PX01@0C1`/03`@700/00`0<00@03P8600804@D901@04`L;00d1
1@0>0PH03P8601@8300O4aL04`T;02lS9`0800003P@600/00`0H3100308400h21P0D20`0200001L;
3`0>10H03`<7010420<04@D90P0B1PX01@0>0PH0308401/?4`0E2@d050P<00<04@D90P0@10P03@0A
1@T01`0201/@5P0c:2h03`@:01D:400B1`d05@X@01T>500A1P`02`060146300>10T00`0@1@T05@0?
10P03`@900l42P0?10X05P/B01873`0?10`04PH?00l33@0E21804@@>01D84P0F2A<050LA01P;5@0I
31H05PTC01853`0900H03`8<00P01@0Dooooo`006oooool06`0E2``04`T:01061`0A1`P04`T:01@:
2`0;0P<060h?01/A4P0L4Q<04`T:01882@0E2``08aTJ01lE5P0A1`P05@/<00d4100@1PL050X;00h4
1@0@1`L04@L800d4100B1PP04`L901@82P0301D92`0903T];`0;0@803@4301D92`0C1`T060`>01H:
300@10H04PH8008050P:00T05PX<01<82@0N4Q@06`lA048f>00E2@/05`/=01D92`0G2`d00P0D20X0
1@0C1`T04PH801451`0E2@/05PX<00805@T;02T040@601hB500D20X05`/=01lC5@0B20T05`/=075U
I`1lL78060d>01lC5@0K3a405P/=01<82P0@1@L05@X;01H;3@0?10D06@h?01@92`0C20T05P/=01T>
3`0L4A808ADG01T=3`0R5QP07a<E01D92`0G2`d06@d?01X>400G2`d04@D701@82P0G2`d05P/=01H<
3@0I3a005P`=0147200201P>3`0801D;300D2P/06@l@01T?400C2@X07aHI00h82P0E3a4201LA4`0?
01/E5`0D3Q005@lA01<=3`0@2P`05Q0B01D?4@0G4AD050hB03dg>`0J51P081XN01<=4@0@2Ph06A<G
0080618F02<04`dA028L800H51D0510A01lK700U8B807QTL02@O8`0@2`l07APM01D@5P0G4QP06QDK
01XH7@0L6Ql05aLI01hN800A4A<06a/N01hM8P0I61h08R4W02<R:00L6b<07QdU020O9`0N7b@0824V
01/L8@0I6B406a`T01XM900I7BH0:blh02L[=002020W<@0X02<Z=00Q9C008bLb02L[=P0R:C<09B`f
02L^>00/=Ch0:c@m02H_>00S;CH0:cDn02Xd?@0Z=3h0;3Q302/h@P0/>4@0<d5=03U7D`0e@U40<T9A
02dmC00a@E00<d=C03=3DP0kBE@0=TA@034oBP0d@Td0;ce703E3C@0kBE<0=49<03I4CP0jB5<0=D=>
03=1C00_@4X0=4E?03Y;E@80>DYD01D0?e1J03e>F00eAU00>DYD03Q9D`0lCEL0?e9J051UJ`2<WjD0
BEaS03=6C@0iBU80=dQ@03E6CP0iB500>TUA03E3B`0gA4`0BEIM049?E@0d@DL00P0iAT`03P0hAD/0
>dQ>034nA00a?T@0=dA:03E2B00gA4X0C5YP04MFG@0eA4/0=dI=03E4B`0c@TT0=TE<0P0eA4/01`0h
Adh0>DQ?03]:D@0c@TT0=4=:03I5C00b@DP00P0fAD`04`0eA4/0CeiU03m>E@0eA4/0>4M>030oAP0a
?TH0?4UA06]hP00lBE40>dQ@02llA00b?dL0<d1802llA00`?DD0:cQ0038oA`0c@TT00P0a@4L05P0b
@DP0<3m6030mA@0c?DH0;SQ102li@P0j@d`0:S<l03DnA`0`>d40<Se302/f?00X<CP0>D99034j@@0`
=cl0:C0h02Xa>@0]<CX0;30i02lf?P0[<SP202Tb=`809bhf02H0;3<l02/_>P0/;c/092Hb02T[=`0X
:SL08BDb02L]>P0T;3P08b`f02@Z=@0S:C@092/d028V<00R9Rl08RD]02T/=00R9Bd08bH^02X]>00W
:SL09bXf02/]>@0R8bl0=3E103loB@0K6R@08R4Z02HS;@0N72@06aXR02<U;P0V:C8082</02@V<@0O
8bh07B4/028V<@8092Xg030082Hc01`T<@0N93809BHc024P;P0U93807ah/01hM:`0S8S008R4_02HU
<`1;BUP09RDc01@C8@0U938071h[01dL:P0P7bd0:BPf028P;@0R82`0;2Xe02LT;`0T8B/0924Z024K
9@0U82d09b<c02DQ<00O6bX07QXX01lL9`0O72H06aPQ01/H7`0S82H071XO01TG6`0K62006aLU01`H
9P0L62D07Q/V01dJ9@0N6bD07a`U01hK900M6R8201hK8P0801lJ900I4al071HR024K9P0L5R0050hH
01dH800K5Qd201XE6`0301`G7@0N6Al05a8H00806A@J00d081/Q01PC6@0D3aH06Q@N01<=5`0G4A/0
7ALS014;5`0H4Qd05`lJ02LO9`0H3aP071@L00806Q8J01@071@L01<:4`0H41P06Q4J01L>5`0H41P0
6A0J01L>600F3AL05`hG01P?600K4QX07aHN01P@5`0H41H0610E01<<400H41@04`dA01LA5@<06A<G
00L05Q0D014;3`0F41@06aDI014;3`0B31005Q0D00805P/A00/05``B01P=4`0F2a405``B05A9C`0Y
7R@05P/A01dB600N4aT05@X@01T>4P0201L<400401lD600J3a<04PL;01<830805@X>0P0F2`l0100C
20`050T=01D:3P0E2Ph201H;3`0F01L<400B1`/050T=01/@500H3A404PL;01@93@0@1P`06Q<J01dF
7P0K5b008b0[01<@700B41/04@dF01@>600A2Q805P`D01L=5@0E3QH04``D018;4`805PlG03T030L=
01PA6@0E3QH05@hF01L@600E3QH050`F01LC7@0I5R806aTU01hM:P0P8Rl092Tg028Y>@0S;3d09Bm0
02`hB@0a?Tl0<41?03Q:E`0oDEl0A5ET04EGIP1:Ff/0Cf1a059SM01EIWP0EVMj05QYO01GJ7/0EFIh
05=TMP1AI7D0C65`041FI00kDEh0>DeI0394CP0`?TL0;c]402hh@@0/<cd09BLa02<R:P0Q82P081lV
01lN900N6b807A/P01HD6@0E41@06aHJ018=4@0_:Bd0IF5R03Da<P0G4a@00P0A3@h02`0D3Q005`hA
01P?4P0I41<06@hB01L<400E2Ph05P/?01D:3P0F2`l05@X>00804`P<01405P/?01D:3P0C20`04@H:
01872`0D2@d04`L901D92`0F2P`050P:0186200D20X06@d?01@82P0F2P`04`L90186200201451`07
01<72@0@10H040@601<72@0A1@L050P:01<72@040186200@01@8200B1PH04`L701<71`0D20P06Ph>
00l30`0L4100DdM7040d=00I3Ph07Q8B01<71`0E2@T04@D501X>3P804`L700h050P8040d=00`92@0
4`P801D92@0X71`04`L902LK7@0/82804@D701P<3P0?10D050P:01<72@804@D702d04`L901D92`0D
2P/040H701H<3@0=10@06@l@01H<3@0A20T04PP901L=3P0@1PL04`T:00`31@0B1Pd030460185300B
1P`04`L;00h31P0J3Q805@T;0186200C1`T040@400h41@0D20`03`<701862P0>0PH040@801452@0I
3A4030840105200>0PH03`<701<72`0G2`l04@D901862P0@10P04@D901@8300C1`/00P0B1PX201<7
2`0N01452@0?0`L050P<01@8300<0@@03P8601L<3`1ODeL0:alS01872P0<0P@05`/?01<72`0`9BT0
4PL;00d21P13>3`05`/?01<8300A1@T04`P<01@93@0@1@T04@H:00l31`0A1@T050P<024E6@0I3A40
40@80P0A1@T04@0B1PX040@80104200B1PX06@hD00d3200B1`d02@040146300@1@/030<701@93`0G
31804@H<01<83P0=0PP040D900804@H:01D040D901052P0@1@/04@H<069GGP0D2A4040D=0188400=
0@/04`H@01443P0E21405@PB01443@0@0`d04`H?01443P0B1@h040<=01D84P0A10d05?ooool001_o
oooo00@050X;01<92P0B20T04@L80P0B20T01@0?1@H05@/<01dC500I3a003`D600L04PP91P0A1`P0
200B1PP04@D701451`0B1PP05@T;01L;3@0S5aT04@D70P0E2@/00`0D20X06`lA01<72@020186200=
01<72@0D20X05@T;0186200H30h04PH804Lk?@0=0@<05`/=01H:300E2@/050P:01<72@0201862006
01H:300@10H06@d?01`@4P0C1`T060`>0P0F2P`02`0H30h09QXL02<G6@0H30h06Ph@01H:300<0P<0
4`L900l31@0V6ad03`D600804@L80100200001P>3`0=0`@05@/<01@:2`0:0@8050X;0147200?10H0
5PX<01@82P0E2@/05PX<01041P0?10D04@D70P0F2P`00`0J3Q005`/=01@92`0201L=3P0401H<3@0E
2``050X;01@:2`@05@/<01T050/<01<:3@0A2`d040X<014;3@0C3@l05Q0B014;3@0D3Q00618D01/E
5`0L5QP04`d?018<400C3A40=2hb01<=4@0I4aL05Q0D014;3`0G4AD05@lC010:3P0D3Q806A<G0080
5Q8C0P0K5aP08`0F4A@061<G014<400Q72405a8H01/F700G4QT08R0U00/:3`0T92H0:b/]030`<P0I
6A`071/P014@5P0M728081lU01`K8`0M72@09B@/01hO900M7R<071dR01dM9@0L7RD06ahU01`P:@0V
:S<09BTb01/R;00H7bT07bH`02@X<`0X;3L0:Bdh00809B`f00@09bhh02</=@0T;CH0:34j0P0U;cP0
2P0W<CX0:C<o02diA@0]>DD0;3Q40390C@0hAU<0=dAD0392D@0eAE@203E5E@0903Q8E`0d@T`0<T19
0390B@0d@Td0;C]603A2C@0mBeP0=TAA0080>TQC01D0<d5<0390B`0iBU@0=DI@03e>F00lCEL0=TMA
03]<EP11DU`0BEYT03I7D@0gB580>daF03Y=D`1CJ6d0X[Fk04mRJ00iC580?4eE03Q9D@0gB5000P0i
Ae004@0gADh0>4E>04eJH`16DeT0=45703]8CP0jAdd0>4E;03]8CP0d@DL0<d1603I3B@0e@TP0=dA:
05=QI`1>GF@0=DA;0080=4=:00`0=TE<03U8C`0eA4/0=DA;03I5C00gATd0>DQ?03I5C00a@4L0=dI=
03a;DP0b@DP203A3BP0<04UHG`0b@DP0;3]202Xi@00b@DP0?daD03E2BP0kB5008c0h02`i@@0f@d/0
<3e50P0^>d<01@0b?dL0=459038oA`0_?TD0<3m60080<T5801D0<D17030mA@0_>D8092hg030j@`1=
EUl0<ca502`e?P0/=cd0;cY003<nA00/=C`0;SLn02L`=`0[<SX09bhf02P_=`0/<3T0;c<l03@k@`0Z
<CL00P0Y<SL02P0Z<CT0:C0i02P_>@0[;cX0<CA002h`?@0_<D00:B/j02@W=P0Y;cd202H^>`0802X`
?P0Z<3`09R`h02T]>@0W:SD0:Rdf02LZ<`0O8R/2024S;`0>02la?P0Q8c009bTe01XJ9P0U9Bl0;Bdg
020O9`0T8b/07AXS02PU;P0c<SX08B8Z01lR:`0M82T202<V;`0;01dQ;00T:3<09BTd028X=00O9C40
6Al[01LM:@0L72X071/Y01lN;00K6RP00P0M72X08@0W9S@06aXX02h]>`0E52807ah/02d/>P0N82d0
?Ca:03`kB@0H5bD08R0]02<Q;@0W9C00924/028O:@0P7BH07aTS02<N:`0Q7B/07QXY01dI9`0N6bH0
81dX02@Q:P0P7BH07Q/R01hL8P0G5AX061HK01dJ8P0O6bT07QXX01/G900201hK9P0401`I8`0J5b00
61DN01LD70805a@K00/06A@N01PB7P0J52007aTT01`F800K5Al07QPQ01dH7`0L5ad06aHL01TD6P02
01PC6@0501D@5P0J5A/07QTO01TD6P0J5A`00P0F41X04@0E3aT04`dI01@>6P0D3QT07QHQ01D>5P0B
2a<06A8J01dF7P0E3QH091dU02TR:P0C31@07aPP01dF7P0H4AT05`dF008050XC00/05`dF01P>5`0I
3aL06a4I01XA5P0H3a@05PdB01P?4`0H3a805Q0D01LA5@0201XD600401H@500?2@d04P`@018<4080
4`dA0P0D3Q8301<83P<050T?00`0G55G02LL8P0A1P`06@hD01P=4`0D2@l06@hB01L<400J3a<09AXN
01X?4`0H3A4601H;3`0301D:3P0G31005P/?008050T=0P0F2`l201D:3P0E01H;3`0G31005``@01T@
600?21002@@;04i;E@2?SIX0G5YW028P;@0B3aX04a0I014;4`0G3AD04`TA00h73`0A2Q805a0H0109
4@0B2a<09AhV00804P/C01T04``D01D>5P0E3QH05PhI01TC800J5R@06QLU01TH9P0K6RX0828b020V
=P0N9CL09Bho02`hB00`>dd0<T5?03E7D`0iBeT0?e5O049DHP15EVH0BEYZ04aMK@1>Gg40DV=e0080
DfAf0240DF9d04eNL019G6d0A5UX03mEH`0kDEh0>DeI02doB@0_?DH0;SY302Xd?@0^=Cl0:2Xd02DT
;00S8RX081lV01`K8@0M6R407A/P024O900R7B4050lC00X52@1RG600n_Kg07IbL`0L61T06aLH01HB
4`0B30h060lB01L>4@0F3A000`0E2Ph0300H3A405``@01T>4P0E2Ph040D901D:3P0F2`l05@X>0187
2`0A1PX04PL;01@93@H050P:00<04PH800`00P0@10H00P0G2`d00`0?0`D05@T;01<72@0201/?4@03
01<72@0E2@/04PH800D04PH81P0B1PH02P0C1`L0200003da<@0P51@06Ph>00`0000B1PH050P800/0
000M4A4301<71`0;02XN7P0F2PX04PH601861P0N4Q8060`>03/_<@14>3X06Ph@01lC5@0@10H00P0F
2P`05`0E2@/04`L901<72@0E2@/040H701L=3P0E2``04`T:01L=3P0<0P<06Q0A00/10P0<0P<03`D6
00`20`0G31004@@<020C6P0G2Q402P0401T=4@0E2@d05`/?00804@D701L04PH800l30`0@10H04`L;
01862P0A1@T040@800l31`0D20`0200001/?4`0H31006`lC00P0000<0@@0200001452@0H310040@8
01lC5`0=0`D04@D90104200300l31`0C00d21@0C1`/05PX>00h21P0A1@T05@T=01452@0X72004`L;
00`1100;00<04PH:00/1100?10P02`8400d21P0R5a/03@@600L0000200T00P0900X00`0@1@T05@X>
00l31`0E2@d04@D901@8300@10P0304400H04@D900P02`0600`11`0A1P`04@H<01D:400B1`d040D;
014630<04PL=00h04@H<00l4200A1PX04PL;01052@0@1@X04PL=04Pm@`2ERY40:AhV01X?5`0B1Pl0
4@D?01D84@804PD>0P0C1Pl0100A10d03P4:00h12P0A10d201@7400300l22ooooooooooo01;ooooo
000Kooooo`@04`T:00P04PP901061`0B20T04@L801@:2`0C2@X040H7014720H04`T:0P0B20T40147
200=0186200@10H040@601451`0D20X05PX<00h41@0K3a405@T;01451`0D20X04PH801<72@020186
200901<72@0D20X05@T;0186200E2@/03`<501hB500<00805PX<00805@T;00H050P:01<72@0B1PP0
4PH801D92`0A1@L201H:300501451`0C1`T05PX<01H:300D20X00P0M4A<0400@1@H04PH801D92`0I
3@l0:AdO01L;3@0N4a@060h?01X@4@0C2@X01`0002LM7P0>10D05`d>01H<3@0>10D201L=3P0:0146
1`0D20X060`>01L;3@0B1PP04`L901T=3`0M4A<060`>01<72@8050P:00@050T;01H<3@0F30d05P`=
0P0E2``01`0A1`P04`T:01H<3@0F30d05@/<01882@0F3@h00`0D3Ph0>`0C3@d04P`<018<300A2`/0
5a4A01`F5P0H4Q8050h>010:300L5QP04@/=01PB500G4A<06A<E010:300E3a405Q0B018<3P0D3Q00
618D01HB4`0I5AH081`M01`H6@0E4A<06QDI01@?4`0K5Q/061<I01/F700F4AL081hS028Q9P0N7b40
<C8d01`M7`0H6A`04A8F01<D6@0I6Ql071dR01/K8`0M7BD08b<[01XK800L7B807QlT01lO9`0N82L0
7B0W028V;`0S9c008RH_01dT;P0K8R`06R4[028V<@0U:C@09RXe00808bXd00`092/e020Y<P0U;SL0
92df02Pb>`0S;CH0:38k02dg@`0_>dT0<3a:02lkB@0_?4`2034nCP0T0310D00eAED0=TIF03A4E00g
AeH0<3i602lnA@0gADh0<T1;03I4D@0gAE80?4UH03M5DP0kBEH0>dUD03=1C00a?dX0?TmI03M8DP0k
C5H0>DYD03I7D@0jBeD0=dQB04MHHP0hBE<0>T]E04AEG`0nDEL0<dQ;04ePI00eB4d0<TE;0352B@0a
@TX0=TM?0`0gAE00100g@dl0>dQA03Q5B`0c@4H303I3B@0903Q5B`0`?D<0;3To038oA@0d@DL0=T=9
03]9D00lBe80>4M>0080=4=:00T0=TE<03Q7CP0fAD`0=4=:03=2B@0eA4/0=dI=049AF01:FF000P10
CeH0100b@DP0;Se402hmA00gATd203=2B@0n02hmA00b@DP0:CHn034nAP0b?dL0<Ci603Q5C@0/>D40
<d1802llA00^>d<0=D9:03I3B`0^>d<0;3]202dl@`0_?TD0<3m60350A`0c@4P0>dE>02`f?`14CUL0
KWN004]DG@0f?dP0<Se302hi?`0lAdd0=3e402Xc>P0X<CP0:2lg02Xa>@0V;CD0:Bdf034e?P0_=Sh0
9bhd02`e>@0/=CX0:S4i02P_>00Z<C/0:Rhj02d`?P0^<3l09RLi02DV>00[;Sl0;39202@[>`0T;3T0
:S0n02P^?00O9C40:Bdi02X]>@0[;CT09RPd020R;P0S9C4205YLJ00;01XL:00N7RX0;2`f01lO:@0M
6bD08b0Y020M9P0M6R40:2D/03hk@P0O7b@00P0M7BD03P0W:3009bXa024T;@0S9Rl08RH_024U<00M
8B`061`W01HJ9P0I6RL081l]01lN;00N7B/07ah/0P0R8Bl0?@0];3X0:bXh02HU<`0R8Bl06aXX01TK
:01mO8X0Ogj<01lN;00X9S<0:RPd01`J9@0Q7RT08b0Z01TF7`0L5R008A/V024K9`0N62H071HR01hH
8P0Q6bD09b4[02<N9@0N6B007APO01XE6`0K5Q`07QTR024K:@0O6BL06aDR020J9P0R72P08adX020J
900K5Al06Q@M01/F7@0J5A`061<L01`F8P0N62@071HQ01hH8P0L5R006aDN01dH7`0M61h06aHL01XE
6`0H4aT06aHL01TD6P0K5Q`071LM01TD6P0J5A`06Q@N01TC7@0H4Q`00P0G4Ad07`0H4Qd06Q8M00l8
400S72@08AXR01dF7P0N5al0PGZ2089kP`0N5al04``D01094@0<1`d07A<L01X@6@0G3AH060hF01T?
5`0F31@05`hC01H=4P0D2`l04`X=01D<3`0F3A005Q0D01D?4`0F41@05a4E01D?4`0@2Ph00P0B3102
01<=4@8050hB0P0F2a4401D:400>02PM8`0E2Q004`P>01L<4P0E2Q005``B01H;3`0G31005P/?01dB
5P0F2`l0714E01L<400F2`l201D:3P0501H;3`0G31005``@01P=4@0F2`l00P0C20`06@0D2@d06a0D
01H;3`0D2@d05@X>01T>4P0K41@05@dD01H?5`0Q72<0X9fW0?omo`2g]l<0<C0m01<@6`0F4a`05Q4H
01PA600E3QD050dE01L@60090PX081TQ01@=5@0;10`00P0D3AD06@0E3QH06A8J01`E7@0N5R406aDT
01/G9P0J5RH05aHV01TH:00M7bl07R@d01lV>00U;Sl0:cM702hjBP0_?D`0;d5=0353C`0jC5P0@UAP
04=EH`13E6<0AUMW04UJJP1=GVl00P1@HG<07P1>Gg40BEY/04EHJ@12EfH0@5IT03iDH@0lD5`0:C]5
02/i@P0`?4D08bdf02H]=`0W:C<09bH^02HU;@0N7B@061LM01XG7P0G5AX05A<H01D@500D3a<04@`@
03Xd>02:QXL0>3@e00l;300C3a0040`=01@>40<05Pd@00<05P/?01D:3P0D2@d00P0F2`l02P0G3100
4@H:00d21P0D2@d05P/?01D:3P0B1`/04@H:01872`0D2@d601<72@0801T=3`0E2@/02P000186200D
20X05PX<01L;3@0B1PP202<G6@030186200G2`d04PH800D04PH81P0B1PH06`0G2`/06Q0@01H:2P0F
2PX050P801861P0C1`L050P800T0000L41004`L701D92@0=0@406`l?00l30`0D20P040@401861P0@
10H07a<E024E5`0?0`D040@600X0000E2@/05PX<01D92`0201<72@0P01D92`0>10D06Q0A00/10P0F
30d07aDF00X00@0>1@D0308300l51P0J414060h?04<h?00J3AD0QgZ1071SJP0K3QD03@4500X00P0C
1`/04@D701041P0A1@L04`L701@82P0C1`/04PH:01452@0@10P03`<700`2100E2@d200X00P0301/?
4`0D20`05`/?00806`lC00H040@800d11@0C1`/06`lC01@8300B1PX201452@0301862P0D20`04`L;
00<04PH:01T04@D900d21@0H3100300401452@0?0`L04`L;01872`0:00<04PL;01H;3`0D2@d02`84
01D:3P0N4aL05``@00h31`0D2@d03`@800l31`0F2Ph050P<01/?4`0H31005PX>00H04@D900/03@86
01462P0=0PH04`P<00d21P0=0`H0304500l4200B1`/03`@800d21P0201052@0?01872`0C20`04@H:
01462`0C20h08QLM034V;@0?10`05@XB00d32P0B1Q0050L@01442`0>0@P040<:00804`H=00H04@@;
01032P0@0`X04@@;01032P0=00LDooooo`006oooool01`0D2P/05@/<01D;300D2P/04PP900l51P0E
2``00P0B20T201D;300301061`0B20T04PP900@04PP900@050X;01<92P0B20T04PP90P0A1`P03@0A
1@L050P:01H:300F2P`04`L90186200F2P`04`L900l31@0D20X05@T;00l41@0C1`T00P0B1PP02`0C
1`T050P:01D92`0B1PP03P8401@82P0>0P@06Ph@01<72@0E2@/050P:00804`L90`0B1PP01@0J3Q00
5`/=0186200L41804`L900805PX<01l040@601451`0B1PP040@601dA4`0L418050X;01@82P0B1PP0
4PL901482@0<0P<04@P901/A4P0?1`P07A<D01@:2`0<0`@050/<00h41@0K4Q<05``>00l31@0D20X0
5PX<00d10`0C1`T050P:01451`0B1PP060`>00805@T;00H05P/=01@:2`0E2``05@/<01H<3@0G3@h6
01D;300301D<3@0C3@d04P`<00804@/;00`04P`<01/E5@0C3@d04`d=01H@400B30`06aDE01@>400G
4A<04`d?01/E5`0H4Q@2014;3@0601D?4@0K5AL0618D01H@4P0H4Q@071PI0P0G4a@04`0K5aP06ADG
01/F6P0O6Qh05Q4F01TD6P0M61h06QDL01PF6`0P7b@051DG01lP8P0D5AL07QlR01hO8`0O82D07QlT
01`M8P0K6b<00P0L72@02@0H6Ah06a`Q01`M8P0L72@07b0X024T:`0P92d08bL`028V;`0201lV<004
020W<@0Q9C008RHa02@X<`808RTc04008BPb02L`>@0T;CH092df02`f?`0X<S/0<3Y402hhA00[=dD0
;3Q602diA`0]>TX0;S];034nCP0b@U80>4QH03E5EP0_?e00<41?02hm@`0X=c`0<d99034oB@0oCEX0
>4ED03U6EP0hAED0?4YG03Y8E00b@4/0<Cm:03I7D@0b@dd0=TMA03Q9D`0fAe40>DYD03A5C`0^?dT0
?TmI03E6D00iBU@0AUUO03Y?D@0_@TH0=TU=03iAEP16Eeh0>T]B03M8D00iAe80=TA@03U7D`0hA540
<Ci703A1A`0gA4X0>TM=03i;D@0jAdd0>DI<03A1A`0]>T00<Ci40P0e@TP0800d@TT0<3m603A3BP0k
BU40<T5803A3BP0lBe80>DQ?03I5C00c@TT0=4=:03M6C@0`?dH0EFA[03]:D@0eA4/0>TU@02hmA00_
?TD0=TE<0350A`0_?TD0=4=:03=2B@0hADd0=459049?E`1LJG40>4E=034nAP0e@TX0=4590P0f@d/0
0`0e@TX0;ca402hmA00302dl@`1A02hmA00b?dL0<Sa502Xd?@0_>D80BE9K03HoB00]=Sl0=D1603@o
A@0f@DL0;SLn034j@@0^=ch0:S4i02lf?P0U;3@09b/d02lc?00W;S@092/a02/d>00/=CX0:2lg02L^
=`0[<S`0:2`h02P[>P0X:CX092Dh02//?`0c=TT0:2e002<Z>`0S:SX0:2hn02`b@@0^=480:2/j02/^
>`0X:SL08bDa020R;P0Q8c00J6Ue06EVLP0V9c<07alZ024P:`0P7bT0:2L_02HS:`0L6B409R8Y01hJ
8@0U8RT08R0U01lN8`0O7b@0:RT_02/[<00S9B/07b4W01lP:@0N8BT07B4Y01/O:@0K7RP06a/X02LV
=00O7R`08R4_01hM:`0R8Bl07A`Z02XY=`0Q82h09B@b02<R<00L6bT06adZ00808B0^00P07Qd[01XH
9@0O7BT04Q0K01hK9P0b;cT0:BH_02LQ:`808A/T01X07aXR01hH8@0L5Ql071LO01`G7P0K5Qd06aHN
01hI8@0P6R<07QPQ01XD7`0L5R@07ALU01`F8`0O6BD07QPT02@N:@0U7bT07QPR01`G7`0O6R4071LN
01hH8P0V82`08adY01TC7P807ALQ00<061<K01XE700L5ad00`0L5ad01P0Q72807aXP01/F700H4aT0
5a8H01PC6P806Q@N02806A<M01LA7@0G4Ad0618M04Y3CP0O6B4071HN01LA600K5Ad08A/S02LQ:00/
9Rh04`dD020J8@0D3QD050lE01@:4`0F31@05@XC01H;4`0J3aL05`dD01T?5@0H3Q@05`dA01H<400H
3Q406A0C018<400A2`l04P`@01@>4P0F41@050hB0P0B310201<=4@8050hB0P0F2a4401D:400701H;
4@0C20h05``B01P=4`0E2Q0060dC01@93@0201<8300501dB5P0E2Ph05P/?01D:3P0D2@d00P0C20`0
2P0D2@d05@X>01D:3P0G31005P/?01@93@0E2Ph05P/?01/@500G310201D:3P0E01L<400G3Q<050`D
020J8`0/9S00R8F@0=7Ae`2LVjP092@`00d;5P0C41/04P`E01H?5`0H4AP0GEIN01dF7P0N5al0EDiF
02@M9@0@2a405@hF00804``D01P05PlG01/D700L51l0610Q01/D9@0L5bT071T[01hM;P0P8S<082Hf
028W>P0U;Ch09c1102Hb@P0W=T@0:ce80312CP0fB5@0>deI03mAG`10DV00@E9Q04AEI@19FVX204aM
KP0=04aMK`19FV`0AEQY045FI@0oEF<0?UAQ03Q<F00]?dT0<3i702Pd?@0W<CX0:2li020R;00202DT
;00N01dL8`0G5Q`06aPO01`J7`0D4QL05Q4E01lJ7P0R7B405Q0D01LC500I5AH06aLH00h:2`0D4140
4`d?01D<3`0F3A005`hA01L<400F2`l04`P<01P=4@0E2Ph05``@01P=4@0D2@d05P/?01D:3P0D2@d0
4`P<0P0B1`/00`0C20`04`L901<72@0401<72@0800`10P0G2`d050P:01D92`0@10H05@T;01041P0A
1@L201L;3@0301451`0@10H04PH800D04PH81P0B1PH0700=0`<08aLG01@8200K3`l040@401T=3@0B
1PH05PX:00l30`0Q5AD05@T901<71`0B1PH05PX:01@8200G2`/06Ph>01L;2`0L41804PH800h2100E
2@/04`L901X>400E2@/060`>01L;3@0E2@/201@82P0H01@:2`0C2@X08QPI01882@0D2P/060h?01@:
2`0U6a`0:AlP0107200M4a@0@CHj01863@1@@dX0=RT`01452`0A1@T060`@01452@0@10H03P840104
1P0G2`/05`/=0P0B1PX201452@0@0104200L4A@0N6a`01/A4`0H31004`L;01862P0D2@`05`/?01X?
4P0B20X060`@00l51`0G2`l050P<01862P804@D900/04PH:01<72`0@1@P04@L901<72`0@10P03`<7
01@8300B1PX040@801@8300201862P0>01462@1?ADP050X=01<9300?1@P04PP<01L>4@0=0`L02`44
01<93@0D2Pd04@L:01P<400K3a<201452@0300h21P0=0PD04@D900D04@D900/04PL;01L<400;0P@0
50T=00/1100F2`l04@H:01D:3P0G31004@H:00d21P0201462P0G01872`0D2@d04@H:0187300C20h0
5@X@01<93`0F2a<03`H<01463`0?1@`04PD>01032P0A10/04`H=01@73P0B1@`05PT@0185300?0PT0
4`H=01hA600W6R405?ooool001_ooooo0P0F30d01@0E2``050X;01882@0@1PL03`D600804@L800<0
50X;01D;300<0P<01P0A1`P201@:2`0A01<92P0B20T04@L80147200A1@L05PX<01T=3`0H30h04PH8
01041P0C1`T050P:01T=3`0@10H03@4301H:300C1`T00P0B1PP02@0C1`T050P:01D92`0C1`T03@43
01D92`0C1`T05PX<00P0000201<72@@04PH801T050X;01041P0P51H03@<400l31@0@10H04`L901@8
2P0C1`T04PH801<72@0D20X030020186200j;S00710B01<72@0B20T06Q4B00d41@0E30d071<D00H0
000<10@060l@00803`H700P091/L04@k?00H3Pl03`<501P<3P0^8R@07A4C01041P805PX<00L06Ph@
01hB500A1@L04`L901T>400C2@X050X;00805@/<00d05P`=01T?400G3@h05@/<01@:2`0E2``060h?
01@;300A2`/040X:00l92@0B30`05@l?008040X:01D050h>01D?3`0C3@d05Q0@01XD5P0;1@L06aDG
00l92`0F41805@lA01PB500E3a4050h@01<=3`0G4A<09b4S02dY:P0P71d05Q8C01`H6@0L5aX00P0I
51P03`0O6Ql07QTO00l:400F4AP05A<H01TH7@0G61X071dO01PI6`0T9BP04a@H01LH7@0H6Ah06AXO
01TI8@0201XJ8P0701TJ7`0N7b@07QlT01`L900M7RH08B@[01PL9@02020T;@0601XQ:`0M92h09Rdg
02HZ=@0U:C@09RXe0P0V;CL02@0S:S@08b`e020Y<P0e?TL082Xc024[=00V<3X0:S=102Pd@P0202Lc
@@0I02XgA`0]>TX0?4UJ03a<G011DF40>dYM0391E00b@U40<41202ln@@0b@DP0=49<03a9F@0gA5@0
=D9C03E2DP0iAUH0=TAA030nB@0b@4/0=dQB03E6D00fAe40=dQB03I7D@0203E6D00I0352C00gB580
=TMA02dnB00lCe@0<TM80354B00gBTh0=TU=04AEG00dADd0?4eE041>F@0iAe<0>DMD03Y6E00e@D/0
=dA:03U6C00oC580@DiD03Y7C@0f@dT0=45702hk@@02034nA00:038oA@11CeH0>dYA030oAP0gATd0
<T5803]:D@13DUT0>DQ?03I5C080=DA;01L0=dI=02`k@P0eA4/0;Se403=2B@0[>T40;Ca303I5C00[
>T40<T5804UHG`0_?TD0=dI=03I3B`0lBE40<d1803U6CP0_?4@0?T]C03A1B@0gA4`0>DI>03A1B@02
034nAP030350A`0`?dH0;Se40080;3]202P0;ca402hh@@0c?DH0;3Ho03<lA@0]=Sl0;SM002Pc>@0`
>d40<Ca202Tb>@0`>D0092dd02D/=00Y<3P09bhf02X^=`0_<c`0;3<i02D/<P0X<SD0:34f02H]=@0W
;SL0:c8l02P[>P0d=TL08R<e02X[?`0`<DH0<SA902T^@@0Y<4809B`n02D[>`0Z<400<SQ802d`?`0]
<3h09RPe0P0T9S<03@0P8Rl06ATU02LW<`0W9c<08R8/010>6@0O7BP081lW02DR:@0M6R4071LN01/F
7@0R7B<00P0P7R40CP0N71l08R0S02<Q9P0N7B8071`Q01`M8P0N7b@07b4W01lR:@0P8b`07ah[02/Z
>00M72X0:bXh01lN;00P7bd09bHd02XY=`0E52808b8`03`kB@0F5B<03Q0M02XY=`0N7B/06aXX00D3
400a;c/0928]01lL9`0Z9c40:BH_02DO:@0L5ad06aHJ01dH7P0P6b407aXP01hI800M61l08A`S020J
900J51h071HP01hH8P0K5B807ALU020J:00P6RL08A/W01hH900O6B@08A/U01`F800K5Ah071LN01XE
700K5Ql07QPT01/E8@0F41/06A<M01`F800K5Qh071LN01`G7@0J5A/06A@J01LB600I51X06aHL01PC
6@0F4AL06QDK01XE700I4ad0618L01LA6`805Q0L01D05a4L03hh@P0I51/03PT@014<4`0G4QT050lF
01lJ8@0910/04`hE018=500?2Q408adT01P>5P0R5al081DM01L<500I3QH060dC01/@5P0J3aD00P0I
3Q80200K4A<071<D01L>4`0C3A404P`@01<=4@0B31003`T=0P0B310201<=4@8050hB00@050T?01D:
400E2Q005P/A0P0G31803@0I3Q@050T?01873@0D2@l05``B01P=4`0E2Ph050T=01P=4@0T6Ad06@hB
01<8300B1`/0100D2@d00`0B1`/04`P<01D:3P0201D:3P0301L<400H3A405@X>00<05P/?01D050T=
01<:3`0E3AD05a4K00d:4`0G5B40=CA202HU<`0@3ad03`dJ018@6`0?2a@06a@L01`E7@0h<CT03`P@
01@=5@0P6B401`0801PA6@0D3AD00P0B2a<0500C31@050dE01D=600G3R006A8T01TC9P0G52L06AHY
01PI:`0I72d0724d01lW>00R:c`08blo02@c@00Y>dD0<D=?03=5D@0dAU80>TaJ0P0nD5h08P11DV80
AEIV04MHJ018FFT0BEY[04IGJ@10Df@0>e1O03M=F`0dBUL0;D5<02i0BP0c@DX0930i03<mAP0h?dT0
9BLa02DT;00S8RX08B0W01lN900P7B@05A<H018@5@0K5QX04@`@01HA5@0D3Q806ADF00l;300<20T0
4@d>00d92P0G4A<301H=400401H;3`0E2Ph050T=01T>4P805@X>00<05P/?01<8300C20`00`0D2@d0
0`0C20`04PL;01872`0601@82P0803hb=00D20X04@D701041P0F2P`050P:00l31@0E2@/200d10`03
01D92`0?0`D04PH800D04PH81P0B1PH04`0<00003@<300h20P0E2@T04@D501861P0?0`<05`/;0186
1P0U6AT05@T901451@0I3@d05PX:01P<300@10@05PX:01451@0?0`D00P0=0@<0100D20X02`0100d1
0`0E2@/201P<3P0301D92`0D20X050P:00805@/<00@0Acdn01T?400700006Q0A0P0F30d0400Q5aP0
2`4201@:2`08004070lG0185300=00L06`hE00/00`0<00@06@dA0186200?0`D03P840104100B1PP5
01452@0=0104200=0@D0200001P<400D20`0200001P<400?0`L04@D901hB5P13=c/05`/?00l31`03
01862P804@D901h03P8603/_<`17>cl04`T;01452@0J3Q804PH:00P0000B1PX03P<601452@0?0`L0
6@hB08Z1Q00Q61/03`H901072P0<0`H0BD1302HM800@1`X05@`?00`31P0A20/0:QhR02/O8`0L41@0
60`@01@8300E2@d601452@0T00X00`0B1`/040H900l4200800404PT;01D:3P0G310060dA01872`0?
10P04@H:01052@0B1`/04`P<01462P0A1P/04`P>00T0100>1@X040D=00L0100D21407a@L01443@0B
1@`050L>01H9400D1`h040<:00d01`0A10/050L>01D83`0G2Q406@`C5?ooool001_ooooo00`060h?
01H<3@0D2P/04`T:01882@0A1`P03@<401882@0?1@H04@L801D;300>10D601882@805@/<00H04`T:
01882@0A1`P04@L80186200D20X201D92`090186200A1@L04`L901L;3@0I3@l040@600`00P0A1@L0
4`L900804PH800<04`L901@82P0E2@/00P0C1`T0100A1@L04`L900h2100?0`D60186200Z01<92P0?
0`D060`>01X>400U6A/03P8400l31@0A1@L050P:01<72@0B1PP05PX<01P<3P0900004PH800l31@0M
4A<03@<401@;300700002P8300P0000k<S<040P901XA4P0B2@X050/<02XQ8P1?ATL06@h@01H:300J
3Q00>bla02/O8@0A1@L05PX<00`00P0>0P@05PX<01L;3@0^8R@0<2DW100D2P/00`0E2``05P`=01D;
300301D;300301D<3@0F3P`050l<00<05A0=00h05Q4>00l:1`0D3``05A0=018=2P0F4@h06A<B01/E
5`0C3@l0618D01D?4@0H4Q@06aDG01TC5@805Q0B0P0E3a40:00S7Al0;BTZ028N7`0K5aP07ATJ01`G
6P0K5QX05Q4E01XE6P0I51X04PdC02HQ:00F51T06Q/O00lC500W:b`05QXK059FF00e>C`03a8G01@G
700H6b005aXQ01PK8P0J7B@06Q/P028S:00V9b`08R8Z01dO9P0M82L0720Y028V;`0Q9Bh072<]01lV
<00V;CL09RXe02@X<`0U:C@202H]=`04028Y<`0R:c@0<CY305YSK0808R`e03D09Bli02Pb?`0[=dD0
:SI402Da@@0V<d<0:SM703]8F@0kBe/0?TiN03U8F`0`?e80<41?0351@`12DE@0>TU>03Q6D00e@U80
>4EE03A1DP0c@540=T=C03=1CP0_?DP0<T1;03]<EP0eAU00<dA>03I7D@0hBE<0=dQB0393C@0cA4h0
=4E?03I7D@0nCeT0Kh:803]@D@0iC500>TeA03=6BP14EE`0=DI>041AF@16E5l0>dUE03Y8E@0lB5H0
>4A>03E2B00gA4X0?4U?03U6C00203A1A`0=034nA00`?D<0=457038oA@0d@DL0?deD03a;DP0c@TT0
=4=:03I5C00kBU40?DaC03I5C00303E4B`0303I5C00kBU40<d990080<d9900d0:CPo02/j@@0[>T40
;Ca303a;DP1QL7L0=TE<03=2B@0Q;SH0?4UA03A1B@0[>400>DI>0080=T=;00D0=D9:03A1B@0c@4P0
<Sm7030mA@02030oAP0402lnA@0^?D@0;Se402llA080;CM000L0:38k03<lA@0W<3T0;CHo03E0AP0a
?480=D160080;CHm00@0;3Dl02H]=@0U;3@0:C0h0P0]<CX0=@0_=S`0:C0f02La=00V;c@09bhf02Xa
>P0/<cd0;2ln04Y<G00T9CT0;c1502h_A00/;T<0;35402T`@P0V;Cl09b`o02H[?@0T:SX0;c9102`^
?@0S9C@092Hc02DW=00L7R/06QXV01/K9P0Q8B/071XU01hM9@0S8RX071TR020M900Q7RD06aHM02@O
9P0X8bT081`M02@P8@0P71d07a`M020N8@0O7B007A/O01`K800M72407alT020Q9P0Q8BT0820]02`[
>@0M72X0<S4o00808b8`01@0JfYh03@c@@0N7B/0:BPf061OK@0l>dT0828_01DD8P0<2aT06aXX01HD
8@0Y9c<09R@_01`I900M6R@081dV01`F800L5a`07ALI01hH708081XN014081TP020I8@0W7bX0:b<`
024I9P0M5B807QHS01dE900O5bH08ATX020H9P0P62D07QHS01dE8@0P62<07QHQ01dF7`0201dF7P04
01dF800I4al06A<O01`F8@80618L00`06aDN01/F7@0K5Q`06A@J01LB600F4AL05A0F01TD6P0G4QP0
5A0F01XE6`0J5A`201XD7P0801TC7@0H4Qh0618N01PB7@0=1a404PdD01/F7@0H4aX301D@5`0;00`7
3P0L5ah06QDL020K8P0?2A008ALO02lT;00/8BT06@hF01P=5@0H3A<00P0G31002P0F2`l05P`=01P>
3`0I41405`hC01@>4P0C3A4050hB018<400?2@d2018<40804`dA0P0D3Q80100G318060dC01T>500J
3aD201`A5`804`P>0P0B1`d201D:400401872`0F2`l06@hB024F6P805P/?00L04PL;01D:3P0H3A40
60dA01D:3P0B1`/050T=00805P/?00<050T=01D:3P0G31000P0E2Ph301H;3`0501D<4@0B2Q80618L
010=5P0A3a/00`0@3ad02`0E4b004a4L01@@6@0S72@07AHN01H?5`0N5al03`P@00d63P0A2Q803`P@
00<05@hF0P0F3aL05P0G3aX060lR01XB9`0I4RL05Q<V01LD9`0G62/06aha01dR=@0N9SP08BXk02D^
?`0V=4409cU302doB@0a@dh0<dEA03M9E@0kCEX0?4iL03m@H013E6@204AEI@0I04EFI`13E6H0?e9S
03Y?GP0dBUP0<4IC02a0B`0[?DL0;Sa502Da>P0_>D80=Se702PZ=00T8b/07ahV020O9P0Q82H07AXQ
02<Q9P0F51T08QdQ020K7`0U82@04`dA01XF5`0301PD5@0500X61`0@2P`060lB01L>4@0F3A000`0E
2Ph201<8300401D:3P0@1@T03P<701dB5P<050T=0P0C20`00`0B1`/05@T;01D92`0401D92`080555
A`0I3@l08aLI01041P0D20X05`/=01@82P0C1`T20186200301<72@0D20X04PH800D04PH81P0B1PH0
6@0C1`L08ADE01P<300?0`<03P<301D92@0?0`<050P800l30`0Q5AD050P80104100J3Ph04`L701dA
4@0E2@T06@d=00d10@0C1`T05@T;01L;3@0E2@/04`L90186200E2@/00P0I3@l06`0F2P`050P:01@8
2P0C2@X05`d>03`b<`0I3a00200001<92P0900402P0101061`0D2P/05@/<00d21P0@10/02`0500P0
0P0A10/05`/?034U:@0J3Q804@D700h2100@10H040@401041P0501452@0>01T=4@08000050P<00l5
1`0D20`0200001D93@0;00<0200005A8C02ZWZ80=2P/0104200D20`201H:3P0P01@8300B1PX04`L;
03/_<`13=c/050X<01862P0G2`l040D800P0000N4QH04@H901D93@0A1@T02`8402hU:00700402002
01482`0B2@`08APK00h5200700403@@700`31P0F3A0040@801@8300<0@@040@800h21P0?0`L60145
2@0I00d21P0A1PX04PL;00L0000<0@D07Q@G00l4200@1@T04@H:01052@0?10P03P<700l4200A1PX0
4PL;01052@0@1@X04PL=01<83P0A1Pd03`@<03/`>00E31<04@H>01<63`0201442`804PD<00L03`89
01442`0D1`h04`H=00l22@0:00@02@0301Cooooo000Kooooo`0l01/A5@0D2`h040P901<:2`0B2PT0
3@H401071@0B2PP03`P801482@0D2`l050X?01@9300E2Pd03PD601872P0C2@X050X;01H<3@0E2`/0
4`T901471`0B20P04`T901L<3@0B1`T04PL80146200A1PL04PL90146200C20X050T:01@92`0G30d0
4PL902dR8P0G30d05@X:01461`0A1PH0714B01461`0D2@T04@H601@92P0?10@060d=0187200D2@X0
4`P:01461`0D2@X040D601461`0G30h050T:02XO8@0j;c405P/=0P0C1`T0900F2P`05@T;01<72@0B
1PP05@T;00h2100E2P/0308301<72@0F2``05`d>01H<3@0E2``08ALH079YJP0`9bP040L700h41@0E
30d03`D602@K700?1PL0714B00d3100U6Q/07A8C01<82@0J3a005``=01P=3`0D2@X03@@501H;3@0L
4A<05@/=01H;3P805P`>00@05``?01882P0C20/05@/=0P0F30h0700F2`h04PP:01@;2`0H3Pl05`d?
01D<300D30`06Q0C028K6P0E3@h0614B01TB4@0e;c004`h@01PC500E41406QDF01HA4P0E41406A@F
01LB500L5aP05Q4B01<>400G4Q<07APK01PC5P0K5QP201D@4`3g01XE6@0N61`05a8G01XE6P0Q6b00
<2X_01dJ7`0G5a`07AhQ00`?4@0H61/08B8W01@E700E5A`06AXP01dO9`0L6bD06a/T028T:`0L7R<0
8B@Y02HZ;P0U:Bl0720V01/Q9`0N8b`07RD/01/S:`0J8R/072D^028Z<`0K8Rd08bPe02@Y=@0R:3D0
8RTe024Y<`0^=d80>T=?059LIP0X<S`09c8m02Pd?@0V<cd0;3U502/hA00X=D<0:3E502XgA`0b?e00
;Sa<03A3D@0b@Dl0;ci<02/jA@0_?dH0@51F03i>E@0kBU<0=4=>04EDG`0d@dl0<D1<0310BP0^?TP0
<T5;03I6C`0gB540=TM@03=4C@0b@d`0=dQA03Y;DP0iBU80>T]B03I7C`0`@DT0AUMM07F7S00jCU80
<DA903I9CP0]@4D0>TaB03U;DP10DUT0A5IM03a=EP0hB540=dM@03A4B@0oD540=dE:06=cMP0jBd`0
=dE903Q7BP0dADH0=TA903Q7BP0dA4H0>4I:03E6B`0c@d/0>DU@03A4C00c@d/0=4A<03=3BP0fATd0
<D5903=3BP0dA4`0<T990391B00a@4H0<T5702lnA00c@TP0<3m502He>`0a@4H0;ci403m>E00a@4H0
;ci403U6C@0`?D@0<Sm603A1B00`?D@0>TM>03I3BP0a?TD0;ca3038oAP0d@DP0<Ci502dk@@0^?D40
<Cm60390A`0a?dH0;ca3038mAP0[=Sl0:CDn03@oB00]>440=3m8041;E00a?D@0=417030j@P0_>400
>D9:02Ta>P0W;cL0;C@m02`a>`0W;CH0<3Lo02hh>P0X<c@09S0c02Xb=`0]=Cd0:c<l03<hAP13AeP0
;c55038dB@0_<4H0;C5501XS<`0Z=D80:CA103HoC@0_=dD0:2lk02P^>`0S9cD0>Sa:01TK:00W:3D0
6Q/W024Q;00O7bP09bL^01lO9`0Y:C007QhU028R:@0O7B<08b4W01lM8`0U8bT08b4V01hM700S8R<0
8B0Q01hM7`0P7R808b4W01hK8P0L6R<07A/S024N:00P7BT06aPU01lN:`0U9C805aLT02/[>00Q82d0
6ATV0450C@0O7R/09bLd020P;@0Z:CH051@Q01hK:@0P7B/08Ah/01lL:P0N6bT071PU020K:00O6RL0
8al[02@P:P0P6RL08A/U01`H7P0Y8bX08adU01HB6@0M5b00618L01hI900Y8Rl09Al[024M:00Q6RL0
61<Q020K:@0201`G9@10020K:00I520061<N01hI900J5Ql05A4I01lK8`0?2a806aLO01`G800P6bH0
81`T01/F7`0J5Ah06ADM01PD6`0J5Q`06ADK01LC6@0E4AP05Q4H01TD6`0H4aX04`hE01D@5`0H4aX0
5a8J01TD700E3aP050lG01<=5P0F41X0618I01/E700F3QH05`lG01TC6P0F3aH06A4I01PB6@0E3QD0
6A0H02LQ:00N5Qh040H?01hF7P0L4Q`06a0J01894@0J4AT05`dD01L?5@0G3A@05P/B01L>500J4QT0
5a0F01@=4`0?2@h05Q0E01D>4`0G4AD03PP<018<40804P`?03P050hA018<3`0E3A4050/?01D>4@0O
5AX081PL01@<400;0PH04`/>01D=4@0?1@T040P;01dC5`0B1`/05P/?01L<400H3A404`P<01L<400F
2`l05@X>01T>4P0J3a<05P/?01L<400C2`h05P`?01D>400@1`X04`T<018:3@0C2`h04@L:01H?4@0B
2P`05@/?01XB5`0M5Qd050hE014=5@0G4a`06ADO01@@6P0@3AL04PhG00l;500B3A@06a@L01D>5P0B
31<03`T@01D?5`0?2A004P`D01@>5P<04P`C01L050hE01D?5P0E3QT05Q4P01PC8`0I5RD06ALV01PG
9P0M7Bh06A/[02HX>00O8cD09B`m02@[?00V<D009cQ302LhA00/?DP0=DIB03I8E00hBUH0>D]H03Y=
FP02041CH00f041BH@12E6<0@U=R03U;G00kCE`0=TQE0353D00/?DP0;Ca7030lAP0X<S`09bli02hd
?`0/;ST08B0X020O9`0G5ah0820U01PF700L6Ql04A0E01LD5`0F4QH061@H01LB5P0E41<05A4C01@?
5@0M61d04@dC01L@600C2A407QDL01<9400F2a0040D901dB5@0F2`l06PlC01T>4P0E2Ph04PL;028G
6`0D2@d081DI01dB5P0@1@T04PL;01@93@0E2@/04PH801L;3@0L418060`>0P0F2P`01`0H3@l0?S8d
01lC5@0@1@H04`L901D92`0@10H00P0E2@/0600@10H05@T;0186200A1@L04PH801@82P0C1`T03`<5
01<71`0E2@P04@H50145100B1`H040@301<71P0N4a805``;01D:2@0D2@P03P8200l4100A1PH03@<3
01H;30804PL802<0714A01461`14>CT0;R<T01D;2`0F2`/04`P:01872@0A1PL03P@501@92P0D2@/0
4`P901H;3@0G30d05@X<01<82@0B1`T050X<01H;3@0H3A0050T<00`3100H3A005P/=01@92`0=0`D0
40D700h31@0H31005@T>00h3200H31403`@900h41P0201H:3P0k00d21@0?0`H050T<01<72P0?0`L0
4`L;0104200C1`/03@<50104200>0`H06`lC01P<400@1@P04`P<01X>4P0?10L03`@801X>4P0C20`0
81@H00h31`0@10P040D901D:3P0B1PX04PL;01<72`0>0PH040@801052@0A1`X05@T=00/2100Z7R80
3P<701L>400G30l05PX>03lc=`0E2`h02P8400l52@0@1PX040H900d31`0D2Ph0>c4d01L=4@0F30l0
30@601062@0A1@T050P<01862P0E2@d04`L;01862P0@10P00`0A1@T201862P8040D900@04@H:00d4
1P0M4QH0=2T]0P0?10P01@0A1PX04`P<01<8300C20`040D:00<04PL<01@03`@901H;4@0>0`T040D;
01<83`1MDUT07a@K01@9400D20l04`L=00l32P0B1Pd040@;01863@0C1`h050P>0186300@10/04@D<
01@83QCooooo000Kooooo`0K00l83`0>20/03`T900l92@0@2`L05Q4;00d80P0>2@D03`X7010:300A
2`h04P`@01462P0B1`/03P<701H;3`0A1PT040H701@:2`0D2PX04PP700l5100A1`D04`T701882@0>
10D04@L800804PP901l05P`=01lE5P0F30d03`D601D;300G3@h04`T:07U_KP17?C`091XI01H<2`0Z
81l01`0001881`0@1PD050X901<9200<0P402`4001@:2`0E2``04`T:00l51P0H3Pl04@L801H<3@0A
1`P03P@501061`0F30d05P/=00@04`L9024050P:01<72@0F2P`04PH801X>400K3a4060`>01/@4P0@
1PL04PP900d3100D2P/07Q@E01T?400B20T0718C00l51P0;0@805`d>00l51P0G3@h06a4B01hD5@0C
2@X060h?01<92P0=0`@03P@501H<3@0C2@X04@L800l41`0C20`00`0D2@d701D:3P0=01452@0C1`/0
50P<01<72`0B1PX04PL;01D:3P0H3A4071<F00d41`060000618D01DA4P0201<?40805Q8C00D04`l@
01DA4P0D41407ATJ01LC500201PD5@0601LA5@0A2`l071HJ01TC5`0G4AD05@lC0P0I4aL0=P0L5QX0
6aDI01TC5`0M61`03`dB024P9@0_;S<09bH/014@5`0S8RX061LO01XI8P0Q7bX081hY024O:P0];CD0
;2lf01hS9`0O92P08RT_01/R:00>5A/05b0W01/T:`0L9B`06B</01/U;P0O:C808RPf020V=00Q9cD0
92Xh02P_?00X<3d0:c=002@^>P0R;3P08Bdi02@`?00U<S/09SDm02lmAP0`?TT0:3I302PeA@0]>TX0
>DIF03m=FP0mBeP0@4iH04EDF`0a?dP0;3e702dnB080<45900T0:ca303]<D`0kC5<0>T]B03I7CP0c
A4/0=dQ@03Y;D`0`@DT00P0a@TX0300b@d/0<dA<03A5C00fAdh0?e1G03A6BP0_@DD0>D]?03U<D@0l
CeD0<4=902e0AP80?e9H0200=dY@03Y=D`0lCeD0>DaB03E8CP0fBDl0=dU<03I8B00hBTX0Z[bl049D
E00S=CD0=dU903=5A@0a@d<0=TQ803Y<C00hBTX0<T=80311B@0dADd0<dA<04AEG@17F600<4590352
BP0cA4`0=dQ@0352BP0jBe80=dI=03=2A`<0;Ca100P0:cXo02Th?@0[>Sl0;Se20350A@0b@DH0<d97
030m@`80<Sm501<0<d1603M4BP0d@DL0<Sm5030m@`0_?480<Ci403=0AP0b?dD0;S`o030n@@0e@dH0
=dA:03E2B00a?T@0;CY202/h@00Z=d00;3U20080;S]400P0<3e502/h@00/>D40;CM002`f?`0a>T<0
:C8k02L_>@80:c8l02<09bhh02Xc>P0U;c40930`02Lb=00[=3T0;CHn02`e?P0[<Cl09B/j034fB@0_
<DH0;S1702L^@@0[=d<08c@l04]IHP1PKGH09S4k03LoBP0^=400:Rlk08^?V`17AU@061LU020P;00S
8b/06Q/P02DV:`0W:2d08b@Y01hO900Q8RL07QlT01`M8P0201dN8`0501`M8@0J71X06adL01dO7P0P
82800P0O7R@0500V8b`09b<a02<O;@0U7Rh08Q/]01/G9P0H5b<07AdY02LW<`0K6bL05QHR02h^>P0P
82`08R8^02<S;`0Q8Bd07AdY01`J9`0P6bT081XX0`0O6BL0500Q6bT07ALU01dG9@0S7B/08Q`Z024K
:@0R7BX07Q/V02dZ=@0/:C@08AhY02dZ=@0a;ST0924/020M:00O72L06AHQ01hK9P0H5R804a4N0P0D
4Ql04@0N72T0928]01XH8`0Q7bX030/C01PG7`0>3AD07QdS01`J8@0K61l061DL01DB6@0J5ah061DL
01LD6`0B3aH03``C00<05Q<J01804`hE01HA600H4aX05Q4H01D@5`0H4aX0HeiU04E0A`0I51/081/R
01lJ8@0@2a805P`D01<94@0A1`l05@/C01T?5`0L4QX401L=5@0O01H<500E2a<04PXE01H>6@0L51l0
;RHa01XB7@0M5B0040PC01L?6P0M5B005`lJ01084`0>1Q403@H>01L@600N5ah04P/B00h73@0@2Ph0
5a4E01XD5`0D3Q004P`>01<=3`0A2`d04`d?018<3P0A2`d0618D01/E5`0200h82P0501<=3`0I4aD0
5Q0B01XD5P0c;Bl00P0G310201H;3`805@X>00L05P/?01872`0F2`l05``@01H;3`0J4A@04``>0080
4`d?01005@lA01LA4`0<1PP06A<E02hX:P12?3h050h@01D?4@0=1`T04``C00`5300I4QT04P/B01L@
5`0@2A0050dD0P0C31<02P0D3A@05@hE01D>5@0K5Qd01P4801D@5`0G4QT0:RD/014<4`0D3aH2014<
4`0<018=500E41L0514J014>6P0B41d05QDQ01HF8P0E52805ADS01@F8`0S9C@07b8b0P0W:S/02@0T
;C`09cE202LgA00Z>TL0<d=@03A6DP0eAe<0=TQD03E9E00203eAG00W03a@F`14Ef@0@eES03U;F@0i
BUL0<T9?03Q6D`0a?TX0;cU5030h@`0V;ST092`g02P^>P0S:3804A@K028R:P0N7RD0;Rld03Lf?00J
6Ah05aHK01/I700M6ah05aDH01D@500?2Ph07APN01lJ8@0H4Q`07QPT01H>7@0S62H0OWAo03D[=@0L
4AL06Q0A01D;2`0W72008aPL00804`P<01@04PL;01dB5P0C20`08aPL024F6P0?10P04`P<01P=4@0C
1`T03`<501<72@0H30h05PX<01<72@0D20X03P8400l31@0P51H04PL801041PH04@D700h0300202@H
6P0H30h02@0000/10P0=0@<04`L701D:200@1@<04PL501/@3P0J3`d04PL501@91`805@X801404`P6
0104100D2P/04`T:0147200@1PL03`D600h41@0900004@L801882@0D2``06a4B00L0000C2@X04PP9
0147200201882@0301<92P0D2P/05P`=00805`d>014050X;01<92P0E2@d0200000X00P0K3a<03`<7
00P0000B1PX04@D901@8300B1PX03P860104200<0`D05``@00T00P0300h31`0:00d41P0J3a<02001
00X10`0?10P060dA00d21P0O51P040D901L<408040D900P07a@H00/0100A20X050T=00P00@0G3100
4@H:01052@804PL;01D03`@801052@0A1PX05@X>00h41`0>0`L05P/?01872`0@1@T04`P<00l5200G
31002@0204i3A`0M4QH0714E00/2100;00@0@3Di01462P0@1@T00`0?10P01`0@1@T0;24U05]@E00H
3A405@X>01052@0^8bL00P0A1@T201862P804`L;0P0@10P301452@0;01862P0A1PX040D900h31`0?
10P04@H:01D:3P0>0`L03`@801462P0B1`/00P0A1PX0200A1P`03`@:0146300S61h060dC01873@0?
10X040D;0P0A1P`0200B1`d04`P>02@I7`0B1`d05P/A01T>500C20h05@X@0P0B1`d0100A1P`040D;
01052`0?10XDooooo`006oooool0:P0L5QX04`d@01<=3@0B30`03@P4018=1`0=20803@P400h91P0?
2@/040X=010:3P0E2Ph04`P<01X?4`0T6Ad05@/=01<92P0B20T050X:01<9200A1`H04@L501881P0E
2``04`T:01D;300B20T04@L801H<3@0O5AH08ALH01061`0F30d040H701@:2`0I41007aDD00L0000F
3@d04PP701P>3@803`D40P0E2`X201061@0<01882@0C2@X04`T:01H<3@0T6Q/07aDF01@:2`0B20T0
3@<400/10P0B20T05P/=0`0D20X0300C1`T04PH801041P0B1PP04@D701T=3`0J3Q0060`>01/@4@0I
3a005@/<00l51P804@L800/05P`=0147200I3a004`T:00l51P0G3@h040H701<92P0I3a006a8B02PN
7`0201X@4@0600d3100E2``07A<D01hD5@0Q5aP05P/>0P0G310301H;3`0401P=4@0G31005``@01@9
3@804`P<00<05PX>01D93@0E2@d00P0F2Ph05P0C20`06Q4D00T00`0K4QD05@lA01XD5P0B30h06ADF
01<?400@30d05Q8C01TE5P0C3a00510A014=3P0J5QL05Q8C01PD5@0L61T05Q4E00d8300G4QH201TD
600=01<>4P0H4aL061<G01/F6P0J5AT061<G01dH700`;S<01@@901DD6@0I61h04Q4G024P9P0201dL
900Z01hM9@0K6B@06ALR01lO9`0[;SD06QlS010E6@0?5Q`072<Y01PO9@0G82L072D/01lX;`0N:340
7bTb020Z<`12B5H09bdk028X=P0W;c`092`i024Y=P0X<Sh08bdi028/>00T<3`09S8n02Ld?@0^?DD0
;C]402/iA00U<d00>DIF051MK@16Df<0;ce:02Hd@@0[>D<0?4]B03Q7CP0`@DT0<D9:0P0]?TH0?@0Y
>T40<D9903Q:CP0iBdl0=dU=03=4B`0b@dX0<dA<02hoB@0[?4H0;Ci80393C00b@d/0<D9:03I7C`0m
CUD0>4U@02`mA00cA4/0;T1603mBF00mD5H0<TE;03M:D00dAdd0>DaB03Q;D@0fBDl0<DA:02m2B00d
Add0>Te@03Q:BP0[?Cd0E6IV0353@`0W>CT0=TQ803A6AP0cADD0=dU904=EE@0nD500=DI;0352BP0b
@d/0<dA<03Y;D`0lCED0<D9:03E6CP0dADd0<45902Xk@`1@HFT0A5=J03a;D00`?d@0;ci3030oA00^
?D800P0]?4401P0^?D80;ci3030oA00c@TL0;ca2038oA@80<d1600H0=D9802ll@P0a?T@0;ca202hk
@@0`?D<2038oA@0902dk?P0^?3l0<Cm2038oA@0a?T@0<3e3030mA@0^>d<0:cQ10080;3U20280:cQ1
02dj@`0Z=d00;3U202hh@P0Z=3h0;CM102Xb?@0U;CP0:30k02`b?P0Y;c/09Rlh024Z;`0T;c40:C@h
02`e>P0]=Sh0;3Dn02H/>P0T:ST0<SM:034dA`0_<DH08bXl02<_>`0]?DD0TInX0:Re_P0g@T`09Rhi
02`b?P0V:cL0ADUE0P0H5bD06`0[:cL07AdW01lO9`0U9Bd08R8Z01dM9@0N7RH08B4Y01XJ8P0K6b<0
7alW01dM9@0I6Ql06AXK01LI600K7A`08R<U020O9@0L6b408b8Z02HR<00P72X07aPX020I:@0M6BP0
9B@a028R;P02020P;00301/K9`0H62@07al[00807al[00<07QhZ01`L:00L6RL00`0M6BL201hJ:003
028N;00P72X07ATW00<081`Z00<07Q/W01HC7P0F4ah00P0H5B008`0O72L0=S<n02TV<@0O72L08QlZ
01HC7P0J5b807Q`X01XH9@0R82d07adZ01dK:00N72L06QPR01DD700[:S8081lV01lN900:2@l06aTO
01lL8`0N6b8071TP01hK8P0L6B005a@K01DB6@0K61l04PlF00d:4@0^:c807aXQ01`G7P0I51/061<J
00806A@K00`0B4=:038]=00B3A@04`hE010;4P0L5ah0;bD]020F7P0F31@060hF01H<500J41P201P>
5P0>01L=5@0E2a<05@/C01D;4`0K4ah04@TD018:5@0K4ah040PC01D=600@21<0610K020H8`0H41/2
01084`0H01PA6@0D3A@07aPO01<<4`0L5A/04`dA01XD600I4aH04@/=00l92`0B30h040X<014;3@0C
3@l040X<00l92`0B30h04@/=01H@4P0B30h03`T;018<3P0;1PL06Q@F0P0G310201H;3`805@X>01D0
5P/?01@93@0E2Ph05P/?01@93@0G3Q404P/=018<3P0<1PP04@/=01D?4@0<1PP04P`>03Xd=P1CCDl0
4`d?01`F600=1`T03PL>00P1200N5ah00P0A2Q400`0D3A@04P/B0109400301094008014:4@0?2Q40
1`8900h9400P6b80/jje030[<P0C3QD2014<4`05018=500D3aH04a0I010=600B41d00P0E4b003P0D
4b405QLT02PZ=`0R93<08bHe020S<P0T9cH08BXh02@b?`0X=T<0:cY70351CP0b@Tl0=4EA0P0dAU80
6`0kCUX0>TiI03Y>F@0lCe/0<49@0312CP0eAU80=DEB034oBP0X=D40;3I202Xb?@0T:cL08bTe020V
<P0P9Bh09bXa01hN9P0W:2h0XjBY075`MP0K6Ql06APM01lM800Q7b806aTL01LB5P0201LB600F01PC
6P0M5b40:bD_01H>6`0I3Q`0=2Xe01hD7@0@1@/05`d>01T?3`0H3A406PlC01D:3P0J3a<050T=01<8
300>0`L05P/?01P=4@0@1@T04@H:01@93@804`L90P0A1@L0200E2@/04`L901D92`0@10H02`0101dA
4`0E2@/040@61P0A1@L01P0E2@/0=BT[028F600?0`D05PX<01@82P8050P800D04@D501<71`0N4Q80
8ADE0104100501451@8050X;00/04`T:0147200?1@H03@<400l51P0D2P/0>Bl`01@:2`0I3a0050X;
01882@03014720804PP900`05@/<01H<3@0G3@h05`d>01D;300D2P/03P8601X>4P0H31002`43024E
6@0O4aL201862P0K01H:3P0B1PX0300400d11@0B1`/04@H:00`11@0C20`060dA00h31`0;0P@050T=
00`11@0H3A403`@801052@0>0`L03@8601052@0C20`050T=00d41P0?10P05``@01462P0?10P03P<7
00804PL;01@040D901462P0B1`/04@H:01052@0900803`@801@93@0@1@T04PL;01462P0=0PH04`P<
00h31`0B1`/03@8602LL800700007A8F00`11@805``@00<030<501462P0A1PX00`0A1PX01P0?10P0
91TM00`31@0<0@D03@8601X?4`804@D90P0B1PX201<72`804PH:0`0A1@T0100@10P04`P<01872`0?
10P300d21P803P<700T040D901462P0@1@T040D900l42P0@1@/04@H<02@I7`0I3Q@00`0@1@/40146
300601L<4P0L4AL02`0600l42P0j;cD050T?0`0B1`d3014631Cooooo000Kooooo`0H028L800B30l0
3`T901@>3P0@2`L02`H200d80`0=20D03PT600h82P0?2@`03`T=01L<400A1PX06a0D02HK7`0C2@/0
5@/<01061`0C2@T050X901881`0B20H04`T70P0@1PL04@0B20T040H70147200F30d0;B<T03hd=@0I
3a003`D601hD5@0o=CH04PP801L=300@1PD04PT801L=300F30/06a4@008050X900@04`T801061@0B
20L040H70`0B20T02P0I3a0040P801882@0M4a@07Q@E01H<3@0A1`P04`P901<72@0D20X401D92`80
4PH800H050P:01041P0B1PP05@X;024G600I3a0201@:2`0J00d3100C2@X05@`<01`B4`0D2P/030<3
01882@0C2@X06a4B01P>3`0`9RL0CdE601892P0I41004`T:01X@4@0@1`P040H701X@4@0C2@/05`dA
01L=400E2`l05@/>01@:3P0F310201H<3`0401@:3P0D2Pd050X=01L;3`805@T=00d06@hB01/?4`0G
31006Q4D018:300F3a404P`>01<=3`0F41805a<D01DA4P0C3a005A4B00805a<D00<061@E014=3P0J
5QL00P0F4Q<01@0L61T071LK01D@500N6Ad06A@H00@06QDI00H07APL01`G6`0J5AT07A/N06m]LP0U
92T201TH7@0M024P9P0N7B<06QTP01dL8`0M72@06aXS01`J900M7BD061/R02H[;`0R9b/072<Y01XQ
9`0I82H07RL^01lX;`0Q:S408R`e02H`>@0X<S/0B4iL02T_?@0W;S/0:c=0028Z=`0R:cL0:38n02<^
>P0T;c/00P0W<cl04@0T<CX0;C]302Xh@@0^?4D0:cU503A1D@13D600GFYj02Pf@`0d@Td0=TA=02ln
A@0d@dX0;T1603=4B`0Z?440<D980080;d1702@0;3i302i0A00`@TH0<TA903=4BP0cA4/0=DEB03E5
D`0dA500<T9?03A5D00gB540<D9;03M8D@0lCE@0;d1702m0B00fB4l0=DQ>02`oA@0jCE<0<DA:03mB
F01VNGl0AUUO03U<DP0cAT`0=4M=03=6C00aA4L0>Ta<03a>CP0a@d<0@59B03A6AP0cADD203a>CP0H
0394A00kCDd0>de=03E7B`0_@4P0<T=;03E6CP0dADd0>4UA03E6CP0b@d/0;Ci60352BP0Z>d<0?e1G
03a;DP0fADX0;ci30391AP0d@dP0<3m403=2A`0b@DH0;ci30P0]?4401`0_?T<0;ca2030m@`0_?480
<3e303A1A`0a?T@00P0_?480100^>d40;ca202ll@P0a?T@302lm@0<0;ca20300<3e502hk@`0/>D80
;3U202dj@`0[>440;CY302/h@@0^>d@0;cY402/f@00]=d40:S<m02Xb?@0W;cX09B`h02P^>P0[<cd0
:S<k02Pc>00/=ch0<S]302hg@00T;CH09bdi02H/>@0_=D@0;S51034dA00W;C`09C0k028`>@0/>T<0
>DA>02Tb?@0W;cX06b4]01lT<00K7b/051HS02HV=00J6RH07AdW024Q:P0O7bP08R8[01TI8P0N7RL2
01lO:0807QhW01<07AdV01dN900K7Qh07R4Q01dP800Q8RH092@Y020P9P0P7bL07a`W01dI9P0U82l0
:RDd02LS<@0O7RX071`X02@T<00Q8Bd09BDa00808R8^00<0820/01lO:`0P82`00P0P82`0100L62H0
7QXX01lK:@0P72X201lK:@0301XF900I5B<07QXX00807QXX00X0:2Da02/X<`0P7BP07a`W01`I900G
51l08AhY01TF8@0J5b807a`W0P0N6bH03@0Y9S80?C]801lM:P0E4b007Q`X01@B7@0/:c@0GUeU01dL
8`0J6B008R4W010?5@0I5ah00P0I5Qd03`0E4QT04PlF01DB6@0I5Qd0514H01XG7P0H5A`0514H034^
=@0V8BP07QTP01D@5`0F4AP06A@K01LB6@0201@?5P0<01LB6@0L5ah050lF02TT:`0e;SD08QTQ01P@
5`0M51`05@dD01H>5@0J4AT06A0H0P0H41L06P0J4AT07A@L01H?5`0G3aT05PhH01PA6P0L51h05`lI
01@=5P0H41X05a0I01094P0G3aT091dV01094@0J4aX050dD01L@5`0B2a403`T=01<=4@0E3a804`d?
01H@4P0K5AL05a4C1P0C3@l01P0@2P`050h@01@>400F41803`T;01XD5P805``@0P0F2`l201D:3P03
01P=4@0G31005@X>008050T=01H04`X=01<<3P0=20T040X<01LA4`0?2@/05Q0B018<3P0H4Q@08Q`N
00d72@0?2@/04`d?01@=500<1@`06a@K01<<4`0>1`h05PlF01D>5@0C31<04P/B0P0A2Q40200B2a80
3`XA018=500>2Q00:2<Z09:=U00b;C@04PdD0P0A31<0=@0B3A@050lF01@?5P0D4A`05aDQ01PF8P0G
5B805QHS02@S<@10@4h07Al]020R<00L7bh09BPg024Y=`0R;c`0934n02Le@P0Z>DH0;ci;03A4D@0b
@e00<dA@03U;E`0hBeH0=dYE03M9E@14EV<0EFIc02loC00]?4T0;ca702hiA@0[=D00:S8m02L^>@0Q
:3<07b@`01hQ:`0i?4<0:RXb028R:@0Z:c00<S4g01hM8P0I61d06QPK01/I700G5AP06A@H01/F700A
318061<J00805Q0J00`04`/G01X@700J4QX060lG01P=4`0B1`/06Q0A01@93@0F2`l050T=01`A5@0F
2`l301<830805@X>0P0D2@d0300A1@L060`>01D92`0A1@L05`/=01@82P0<00805PX<01lC5@0<0@80
40@601<72@L04PH800D04`P901041P0B1PP050P:00`20`0201@920804`P700X05@X901D:2P0A1PD0
40D500l40`0?10@04PL601@9200>10D03`D6100A1`P02P0?1@H05@/<044g>00D2`/05@/<00l61`0B
20T04@L801061`0A1`P201882@804@L80P0B20T0:@0A1`P040H701862P0A1@T05`/?01862P0B20X0
;bDW01P<400C1`/05@T=01452@0?0`L04PH:00l5200?1PP081DI00/2100D2@d030<501<8300O5QP0
BCi200l5200>0`L04`P<01P=4@0@1`T04`T<00/2100B20/05P`?00l4200=10H0FDiB040f>@0N5AL0
<RL[01<8300@1@T04@H:00804`P<00<0:1dQ01lD600?10P00P0@1@T02`0D2@d04@H:00d21P0D2@d0
4`P<01052@0C20`07A8F00h51`0N4aL03085008040D900<04`P<01052@0A1PX00P0A1PX01`0@1@T0
4@P:00T00P0F2`l04@H:01D:3P0?1@P00P0A1@T201862P<04`L;0P0B1PX00`0A1@T040@801042002
01462P804PL;0P0A1PX0100>0`L03`@801052@0@1@T200l4200800d2200F2a404`P>01873@0=0PP0
5@X@01873@0A1P`201052`803`@:00H03`D:01@:3`0A1``02`86038W;@0A1P`601873ACooooo000K
ooooo`0:00H0100A2`d02P@400D0000;1P<030L300h91@0>2@H03PP800l92@803`T;00d05P/?0187
2`0C20`06PlC00l51`0E2``040H701<92@0B20L04@L601881P0D2PP0718C00804`T:02D04@L800l5
1P0A1`P04`/;01`B4`0900002@0100d3100K4A80718A04Pn?@0B20L05P`;00L0000A1`H05P`;00d3
0P0>10<03`D401471P0E2`X03P@50147200D2P/05@/<01L=3P0:00404`T:01P>3`0G3@h04`T:0188
2@0C20T04PH801<72@0E2@/05PX<00805`/=01@040@601D92`0E2@/040@601H:300D2@X06@l@01L=
3P0D2P/05@/<01882@0D2P/0DdU:05iDE@0E2``040H701T?400K4A801`0001L=3P8060h?00P07Q@E
02<I6P0J4140308301dC500G3@h04PP901T@4P805@`?0`0D2`h05@0B2@`04`X=01@;3P0D2`h05@`?
01H=400F2`l05`/?01P<400J3a<06a0D01T?4P0G3Q407QDH02HP8P0M5aT08Q`N01<=3`0@30d04Ph?
01@@4@02014=3P0=01HB4`0G4a@04`l@02LS900U8B806aLH01HB4`0E41@05a8F02XU:@0R7B406A@H
01D@500201PC5`0G01/F6P0J5AT061<G01/I700S8RL09B@Y024P9@0E51T05QDJ010?5@0G5Q`071/R
01`K8`0M72@08B0Y01dM9@0V:Bh06b0T00`A5@0/<cT072<Y01/R:00O:2l00P0K92/07`0N:34092hg
02La>P0W;cX07bHc02<[>00U;CX08R/g02H`?00T;SX082`h02@`?00]>DD0;3Q402Tf?`0T<cX09cDn
02dkA00c@D`0:cU602@a@@0^?4X0<d5<03E3CP0`?dL0;3]201l^<`0^@4@0<D=702Xl@00`@TH00P0[
?4<0900Y>T40:ca30312AP0gBDd0>4Y>03Q9D00lC5X0?TiM03Y:F@0b@U40=TIE03e=FP0fAU80>DYD
04=DGP11DUX0>4UA041BF@0fBDl08C@j03A7C@12EE/0@EAJ051SJ@10DeT0=4M=03E8CP0jCE<0=4M=
03=6B@0/?Sh0;T1002do?`0`@T80<D=303a>CP80@UAD00l0<TA40312@P0dATH0=TQ<045BFP0oD5P0
>T]C06QiP@1TMGd0>4UA03I7C`0]?TH0=4E=0393B`0X>D400P0/>d00100_?T<0<d9703A3B00a@4D3
02hm@P0302ln@`0`?d@0<D150080<d1600D0;ca2030m@`0f@dT0=dA:02`i?`0202hk@@0302`i?`0]
>T00<3e300<0;ce00`0^>d40100]>T80:cQ002Xg@00/>D8202dj@`0]02hkA00[>440;CY302dj@`0Z
=Sl0;SQ202Tc?@0_>480:30k024Y=00W;SX0;cM202dg@@0[=Ch0;SQ103@mAP0`>D8092df02`c?@0X
;cX0:C0j02L[=P0`=3l09bhh01lY<`0S<3T07BLa01TS;@0R:cD08BTd02<Y=@0I7RX06al[01<E8P0E
5R<0<30l05=CG`0V9S00;Rhh05YJI00_;cT0:b/e01hN:00T92h08b<]00807QhX01H08R8Z028V9`0W
:b`07b<T01lP900U9R/092DZ02DT;00O72L07Q/V02XV=00/:3H09B<`01`K:00L72P0820/01PH900S
8bl05aLS020P;00O7b/07QhZ0P0O7b/09P0P82`07AXX020L:P0Q7B/08Qh/020L:P0L62H05a<Q01TE
8`0R7R`08Ad[01lK:@0N6bL06AHQ01XG8P0M6RD05Q<N018?6P0D4A`05A8M01TF8@0E4Qd07a`W02@Q
;00k>DD0HV1]02l]>P0H5R807Q`W00X84`0N7BD0GUeU00811`0B4AL08b8X01LF700h=S`0<c0g0P0G
51/0200R7bH07Q/R01`I800H5A`05Q<J01PE700F4aX061DL0P0G4QT02`0N6B009R4X02@O9P0I51/0
6aHM01HA600=20l061<J01D@5`0?2Q407AHM00804``C00<06a@K01L@5`0E3QD00P0D3A@08`0E3QD0
5PlF01PA600J4aX06Q<K02PQ:@0E3QH050dE00l8400>1`l050dE01L@600H4AT05@hF01L@600L5Ad0
5PlG01PA60080@P06A8I01/E6P0H4QH04P`@01D?4P0F41806Q@F01dG6@0D3Q005Q0B00l92`0B30h0
5a4C01@>400@2P`03`T;00805Q0B00<02P@601`F600E3a400P0G310201H;3`805@X>01X04PL;01D:
3P0C20`05@X>01X?4`0H3a807aLJ014;3@0R71h0?cTk01dG6@0H4Q@05Q0B00@000070@<07ALI00`6
200J51H03PL>01H?5P0;10/04@XA00l83`0B2a805@hE01@=50<04``C00D050dD01D@5`0I51/030L>
01<>5@0200`73P03010;4P0A31<04@`C00<04PdD01805Q<M01/I900J62@05aDR01PF8`0O7b`09RDc
010B7`0B52807R0_02LY>00T:ST07b/i020/>P0R;S`0938o02dkB00fA54202loC00G03I6D`0cAE40
<TA@03E7D`18FVH0F6Qe02dlB@0]>dH062@`02Pc?P0W<C/09blj02D/=`0M92h07R8]01TM9P0b=C`0
61PP01HF7@0L7B8061LM01lN8`0H5a`00P0C4A@07P0B41<061<G01D@5P0N6Al04PdD01hH8P1bK7H0
7QHP00`22`0M4a/04`X@01<8300K41@06a4B01T>4P0J3a<05P/?01lD600J3a<05@X>01@93@0E2Ph0
4PL;01462P0F2`l050T=00l31@0C1`T050P:01451`804`L900H06Ph@00`10P0<00808QHH01@82P0@
10H601<72@0601T=3`0E2@/07A4C01/?4@0C1`T07a<E0P0A1`H201L=30<04PP700L04@L600l5100@
1PD04PP701<9200A1`P040H700803`D600T040H70147200C2@X07aDF01882@0;0`<08ALH00d3100A
1`P00`0@1PL80147200701D93@0@10P0200000/10`0a9BT0TXJ:01T=4@0201862P0N0104200B1PX0
5`/?01H;3`0C20`01`0001H;3`0A1PX05@X>00h41`1<@DD0Vi2D01lD600<0@D0308502HK7`2SV9`0
6PlC00L0000<0@D06A0B01@93@0B1`/0JEiR05E:CP0=0PH0714E01462P0?10P04@H:0P0C20`0500P
5AT05@X>00/0100A1PX06PlC01/@500<0`D04PL;00d21P0B1`/03P<701D:3P0;0P@02@0200L0000F
2`l0304501L<400>0`L03`@80P0A1PX01`0@1@T03`@801<8300700003P<700P00@0>0`L00`0@1@T2
01462P804PL;0P0A1PX301052@0700l4200A1PX04@H:01462P0@1@T03`@800h31`0201052@0:0146
2P0@1@T03`@800h31`0>0`T04PL=00h32@0M4QP060dC00/01P804@H<00X040D;00l42P0?10X03P<9
01873@0=10P06@hD00d2200>0`T02@040`0A1P`301873ACooooo000Kooooo`0800`61`0C3@d02P@4
01TC4`0/9b@03`X7014<2@0@2`T3010:2P09010:2`0B1`/06PlC01872`0C20`03`D701@:2`0B20T0
4PP800804@L600H050X801L=2`0P5QL03`H701061`0E2``401<92P8050X;00h04`T:00`3100@1PD0
60h=01T?3P0D2PX050X901D;2P0@1PH03P@401<9200D2PT04@L601881`804PP900@050X;01L=3P0L
4Q<040H70`0A1`P201<92P0501@92P0E2@/05@T;01D92`0F2P`00P0E2@/0200?0`D0710B01lC5@0E
2@/060`>01<82@0@1PL05`d>0P0C2@X0500K4A804`T:03P^;`0h;Rl05Pd>01D;300C2@X05`d>01D<
3@0J4140;bDV01492@0H3Pl06@l@03/a<P0/8R<04PP901T?400A1`P05`d?0P0E30l201H=400301L>
4@0D2`h050/>008050/>0P0E30l06`0I3Q806a0D01`A5@0G310050X>01D<3`0>20T0@S`n075[K@0R
7Ql04`l@01@@4@0F4Q<05A4B01HB4`0K5aP071PI01PD5@0J5QL04Ph?024M7P0P71d05a<D01XF5`0H
5QT04@lB01/I700201PF6@0h01HD5`0G5AP05aDH01XH6`0I5aX05aDH01`K7@0D51H05aPJ01<D5P0M
7R8061TM01XK7`0I6Ql07b0U01`M8P0M7BD0820X01LI800G6Ql082DY02<X;01MI6X08RT_01dT:P0M
9Rd06b@[01dV;@0P:S<08bdf024[=00U;CP09Rhi028Z=@0Q:cD08bdg028/=P0U<S/08Rlh02Ld?@0^
?4D0:cU202Dc>`0S<SP0:CPo02Le?@0b@4/0<d5>02@b?`0^?4T0<d5<03=1B`0^?D@0>4M=0310A00^
@D8202i2@`0W03A7B`0[?T@0;d9902m2B@0cATd0>DaB03]>E00dAd`0;T5803M8E`0cA5@0<D9B0393
D`0eAeD0=dUG03]=FP0lCUX0A5IR04aNJ@0kCEL0=4M>03A7C@0fBDl0=DQ>03M:D00iC580=4M=03=6
C00dAdd0=dY@03I9C`0dAdd0<dE803M9B@0fB4P0=dU903=5A@0kCDd0<TA400<0=DM700H0<D=30312
@P0`@TD0;d1703E6C@0b@dX203U:D@0402dnA@0lCE@0=DI=02`mA080<T=:00X0;Ca10350A@0d@dP0
<D1502ln@`0b@DH0;Ca102hm@P0`?d@0<D150P0`?d@02@0`?D<0<Sm5030m@`0`?D<0<Sm502ll@P0[
>3h0;CY002hk@@0202/h?P0g030m@`0]>ch0;S`o02hl?`0^>d40;CY002/h?P0_?4@0;CY202/h@@0/
>D80;CY302`i@P0]>dH0:3I102Tg@P0Y=D40:3A002`hA00Z=400;cU502/e@@0Z<Sl0;3A102L_?00^
>4@0=Cm:03<mB00[<ch09Bdg02D^=`0Y<3T09bhg02H]=00S:2l0;30g020W;P0P:C408B/d024Z<`0I
8R/07BD_01TP:P0P92l07B4/020T;`0J72P092Hb02<U<@0[:cL07al[01dM:@0i>DD06ATU028R;P02
024Q;@0G02<S;`0T93008R8^020P:@0/<3809RX]01/O8P0N8RD09BH[01lP9@0L72@07A/V01XH8`0O
72L08QlZ01lM:00N7BX09BDa028R;P0[:cL0ATIB02DU<@0O7b/01@0P82`09P0Q7b`08b4^02@R;`0R
82d07adZ01dK:00H5R<06ALT01lM:P0M6bP06aTV01dK9`0F4ah0:2D`02LT;`0I5R408AhY01XG8P0D
4A`06aPS01lL9`0F4ah06aPS01`J9@0F51l06aTT01HD7`0H5R007QdU01XI8@0920h08R4W018A5`0O
7R<05A@I02`Z<00K61l04@hE0P0F4aX01`0D4AP05A8I01/H7`0I5Qd05Q<J01/H7`0F4aX00P0L5ah0
3`0O6R408QdT020K8P0J5A`050lF01lJ8@0F4AP05A0G01PC6P0F4AP0614H01TB6@0H4AP05a0G01TB
6@0301H?5P0;01L@5`0F3aH05@hE01<<4`0[92`0?SLo03Xc>`1:@d/05a0H01@=5@0H4AT00P0F3aL2
01L@608050dE00d0?3Hm059;DP0>20h05a0F01@>4P0E3a<04`d@014;3@0F418071HH01D?4@0O6A/0
50h@00804`d?00P04@/=01H@4P0B30h04@/=01PB500>20X0CdU;03Pb=0805``@0P0F2`l201D:3P0>
01T>4P0L4AD05@X>01D:3P0I3Q8050/>020I6`0V828030H801H@4P0<1PP04@/=01<=3`0?2@/301PB
500401D?4@0B2a80?3Dl014:4@805@hE00l04P/B014:4@0@2A0040T@018;4P0C31<050dD00h:400?
2Q403PT@010;4P0D3aH05a8I010;4P0A31<0100B3A@04P0B3aP06AHQ01HC7P0B3aX04a4N01/I9P0G
5b<0:bXh01hN;00T9S<0828_01lU<P0M9c<08B/g02D_>`0S;SX0:cI2038oB`80;3Y502L0<D1;02m0
BP0]?TP0;3e802XjA`0dADl0:SU402dkAP0U<S`0EV1Z02Ta?00R:C<09R`f02@X<`0O8bh08B@]01PK
8P0N7RH07AhT01XK800I61h07ahS01TH7@0G5AP061HI01HD5`0H4aL05Q4G01PC6@0N6B006aHM059=
D`0H4AP07Q@L01T?5P0D2a00714E01872`0F3@h00P0F2`l02`0C20`07Q<G01P=4@0?10P04PL;01`A
5@0D2@d03`@801dB5P0L4AD05`/=00<04`L900P040@601/?4@0F2P`05@T;03@X:P0f:R`05``=0186
20H04`L900P04PH801H:300B1PP03`<501451`0B1PP05@/<0147208050X;00D03`D601<92P0B20T0
4PP90147200301061`0?01882@0@1PL03`D60147200G3@h0718C00l51P0C2P/05@/<01lE5P0C2PX0
40H70147200@1PL03`D6008040H700<04@L801882@0@1PL00P0@1PL09P0A1`P04PP901452@0@1@P0
4PH:01462@0@1@P050P<01<72`0?0`L04@D90104200?0`L04`L;00h41`0c:2`0RWn301hC5`080040
4PL;01462P0@1@T07aDH01472P0A1PX040D900h51`0]8RH03`D801892`0@1`T040H901H;3`0>1@L0
5@/>01P=4@0?1PP04@H:0P0?10P04P0B1`/04`P<01872`0>10L03@@601462P0@1PT05P/?01/@500F
2`l0<BHZ01D:3P0B1`/02P0300l4200D2@d050X=00d21P8040D900<05``@01052@0A1PX00P0D2@d0
200C20`040D900T00P0F2`l04PL;01<8300>0`L04PL;0P0@1@T201462P804PL;0P0?10P201052@03
01462P0B1`/04@H:00804@H:00<040D901462P0A1PX0100B1`/0200A1PX040D901<83P0J3aD04@H<
01D:400F2a4050T?0P0@1@/400l42P804@L<00D04@H<01873@0@1P/04PL=00l42P0201052`030146
300B1`d04PL=01Cooooo000Kooooo`0Z01`G500C3P`02@<302LQ8@25Ogl050h>01/E5@0N61P02P@4
03<];@0E41003@L701@93@0B1`/07Q<G01@93@0D2P`02P0101D;300A1`L03`D401471P0A1`D040H4
00h41@0@1PL03P@50147200C2@X04@L801H<3@0700006a4B00l61`0K4A804PP901471P0D2PT04`T8
01@:2@0B20L03`D40P0B20L201<9200@01881`0A1`H04`T:01dC500:00405@/<01/A4P0=0`@050X;
01H<3@0K4A804@L801/A4P0C20X05@T;01<72@<04PH80P0C1`T01`0E2@/05PX<01D92`0C1`T04@H7
00l51P0B20T00P0G3@h201882@0;01P>3`0C2@X05@/<01L=3P0A1`P06@l@01X@4@0B20T07A<D01/A
4P0L4Q<00`0E2``01@0D2P/04`T:01882@0C2@/04P`>00<050h@00X04`d?01`F600600805@lA01@>
400I4aD0610C01X?4`0I3Q805Pd@0P0D2`h03@0E3A004@/=01lI6`0W8b@040`=01HB4`0I5AH04Ph?
01TE5P0B3Pl04`l@01HB4`0C3a000`0F4Q<02`0D41405Q8C01`H6@0C4A@06ALJ01@B5@0F51L09bDX
02<Q900J61/06ALJ00805Q@G01/061HI01PH6P0J6QX071hN024R900P8B<07AhQ01hO8`0B4aL071dR
024R9`0R8bP05AHK01hQ9P0L7b@07R<W01dR9P0N9B/08RT_01dT:P0N9bh07BH]028[<P0Q:c@06bD^
01TS;00V<3T00P0R;3D01`0U;cP09C0i024^=P0S<3P093<j02He?00W=Sd00P0T=C`0:00W=S/0;3]2
02Th?`0T<S/0;3Y5020^>@0^?4L0=D=>08FCW011D5L0<D150394AP0Y?3/0<TI703A8B@0/?d@0@eEO
059TKP0iBeD0?4iH0394CP0fBDl0=DQ>02Pk@P0dAUD0>T]K03]<G00iBUX0>4YH03Y<FP0iBeT0<TA@
03e?F`0a@dl0<dE?03M:D@0jCE<0>diD03Q;D@0bAD/20313B@0N03]>E00eB4h0;d98051SJ@1aQ8X0
?U1C03M9B@0bA4@0=4I603E7A`0a@d<0<TA403=5A@0`@T80<TA403E7A`0dATH0=DM:03M9C@0[?D40
;Cm303e?D`0eAd/0;T1402`n@P0[?D40;d550394B00cADT0<T560P0a@4D09P0eA4T0=4=802dl@@0Z
>Ch0;ci302hm@P0/>d00;ci302/j?`0^>d40<Ci4055NI011CU@0=45702`i?`0`?D<09c@j02Hc>@0a
?T@0@TmE03M4BP0d@TD0;ce002`j?@0[>3h09c@j02Xg?@0[>400;S]302hkA00[>440;3U202hkA00_
?DP0;3]602Tg@P0W=D00:3E10P0Z=T80>@0h@dl0EEm[04UCG`0V<3`0;CM302`eA00`>DL092hj02@/
=`0Z<S`07RL`028Y<@0V;C@092`_02<X;00R9bX082DY01dT;00Q:3007B@/01PO9`0J82P08RH_01dQ
:P0O8R/06ahW01dP:@0V:C809bXc028R;P0W9c<0:BTe02@T<00N7RX071`X02DU<@0Y:CD092@`01`L
:00Q8Bd0:2Pb01hR9P0R9bX06AhQ02T/<@0U:2d07b8W01/K8`0N7RH071`T01/J8P0N7BD08R0[020P
;00O7b/07QhZ01dM:@0201`L:00E01lO:`0P82`0820/01hN:P0K6bL06QXV02@R;`0E4b009R@a01dK
:00V93405A<P01`J9`0=2aP05A<P02DS<00I5b@07a`X01dJ9@0L6B@06aPS00<06QLR00h030TD02<P
:`0Y9S406QLR01@A700N72L07adX01dL900J6B405A@L01<B6P0H5ad06APN01PG70806QTN00@06APM
01LE6`0F4aX05a@K0P0H5A`201LD6`D05Q<J00H05a8I01TD6`0J5A`06A@K01LB6@0E41L601LB6@07
01PC6@0G4QP05Q4G01@?5@0C3Q@04PdC01@?5@02018=4`804`hD01D05a8H01L@5`0E3QD050dD01L@
5`0I4QT05PlF00`5300?20l050dD01H?5P0H4AP06A8I01094@0j<c/0D4U@01dF7@0E3a@08A/O014;
3`0B30l00P0C3@l0200B30h04@/=01XD5P0I4aD0618D01H@4P0C3@l04@/=0P0C3@l0100A2`d03`T;
01LA4`0@2P`401P=4@0@01D:3P0?10P06PlC01P=4@0E2Ph050T=01D:3P0D2`h04@T<01H@4P0A2`d0
5Q0B01LA4`0>20X05@lA01H@4P804@/=00T05@lA01<=3`0H4AP0=Bhe01<<4`0B2a804``C0109400F
3aH00`0C31<08@0A2Q403`P?014<4`0?2Q4050lF01<>5@0A31<05Q4H010;4P0B3A@050lF01D@5`0D
3aH04`hE01<=5`0A2aD04`lH01DB6`0D4A`04Q0L02LU<P1@D5`0G5]X02HU<`0K6RP09BTg01@L:@0L
9340;3A1028/>00V<3`0:C<o02/g@`02030lB00b02`jA@0]>dH0=49=030nB@0[>D@0:cQ202Ld?@0[
=Cl0;3Ho02</=@0Q:3808BL`024U;P0O8R/07B0X01/N9@0W9bl07AdT014B5`0K6R006aXO01dL8@0M
6ah05Q@G01DC5P0K5QX050lE01D@5`0E41H040/A010;3`0H4QH060lD01L>4@0D2`h04`P<01@93@0G
31004@H:01<8300N4aL06PlC01D:3P0j;c<05``@01<8300A1PX060dA01lD600T6Ad301@82P0d01<7
2@0B1PP04PH801<72@0G2`d060`>01D92`0B1PP040@600l31@0C1`T040@600d10`0>0P@04`L901@8
2P0T61X06Ph@02XN800@1PL03P8400h41@0H3a006a8C00/20`0A20T04PT:00h51P0A20T04PT:0107
200?1PL040L801<92P0@1PL0308301T?401WGEh0/jVZ01dC500>10D04`T:01D;300A1`P05P`=01<9
2P0<0P<04PP902TO800U6a`04`T:014720D040H700H05@T=01862P0@10P040@801862P0C1`/60145
2@0H00`31@0T6Ad0ACXn01`A5@0:00<04`P<00d41P0D2@d04`P<00l4200800404`P<00h31`0@1@T0
3@8601872`0E2Ph02@0201052@0E2Ph02`8400h31`0L4AD06@hB0P0?10P0100@1@T06a0D01P=4@0@
1@T201462P0E01052@0A1PX04@H:020E6@1[H6@05P/?01@93@0;00@05``@00`31@0F2`l0714E00h5
1`0=0PH04PL;00`21@0=0PH04@H:01T>4P0700003`@800<04@H:0`0?10P05@0>1@P04PT<01893007
00404@P;00l72@0>1@P07A@G01H=401HCe802P4401@;3P0C20`03`@801052@0A1PX040D901@93@0F
2`l050T=01<8300201@93@0801462P0C20h04`P>01873@0>0`T04@H<01D:400<0@L201@93`0?00`1
1`0D2@l02P0501<83P0O5QX06PlE01873@0?10X05P/A00h32@0B1`d040D;01@93`0E2Q0050T?01Co
oooo000Kooooo`0/00/60`0=1`L040X:00@0000U7al0208207egN@1KEED05@l?014;2`0@2`X030L4
00l51P0>1@L091TM08UnPP18?D005P`=01061`0C2@T050X901<9200C2@L050X801D;300F30d04`T:
01@:2`0E2``04PP901H<3@0A1`P050X;00l71`0k<C801`0001@:2@0?1@@0308100h40`0C2@P05@/:
01<9200D2PT201D;2P0?01<9200B20L060h?01X@4@0H3Pl04PP900d3100A1`P050X;01<92P0D2P/0
40H701`B4`0C20T050P:00804`L90`0B1PP03P0A1@L04`L901<72@0C1`T04@D701<82P0D2P/04`T:
0147200B20T050X;01<92P0?1@H04`T:0P0H3Pl01`0E2``04`T:01061`0G3@h04`T:00X00@0H3Pl0
0`0C2@X01@0E2``05P`=01H<3@0E30h04P`>00804`d?00/050h@01D?4@0A2`d07aTK01@>400I4aD0
2P@601XD5P0I41<06@hB01H=400201D<3`0601@>400C3@l040X<01@@4@0@30d07a/L0P0B3Pl01P06
0P<0510A01PD5@0F4Q<07a/L01HB4`805a<D00D05A4B01HB4`0J5QL04a4D01TG6P0201DC5P0401dK
7P0E4aH05aDH01LE60805A<F01/05aDH01LG6@0F61L06Q`L01dN800L7Al06Q/N01XK7`0P8BD07b0T
01/L8@0O82D05QLL01/N8`0I7R80724U01/P900L8bT082L]01/R:00N9bh072D/01dV;@0K9Bh08bdf
03<mAP0V<3T00P0R;3D0<00U;cP09C0i028_=`0R<3P093<j02Lf?@0Y>3l09cPo02Li?@0Y>3`0:cXo
02Xi@00W=Ch0<Cm:02Hd?`0/>TD08Blh05UWL00[>T00;3/n02Xl?00[?ch0;D520313A`0[?TD0@59N
04UKJ@0dAU@0<dEC03I8E00gBE80<dI=0353C@0iBeX0>daL03Y;F`0hBUT0>TaJ03e?G@0lCU/0<TA@
03M9E@0a@dd0=dUC03I9D00gBU00>DaB03Q;D@80=DQ>0P0fBDl03P0[?T@0;d9803mBF01EJ6h0>Ta?
03U;B`0fB4P0=4I60394A00_@D40<TA403=5A@0`@T80<TA40P0dATH02P0dATP0:C/o03e?D`11DeL0
:ce103E7B`0cADT0;Cm302`n@P0_@DD20394B080<3m401L0<D1503=2A`0c@TL0<3m402Xi?P0^?D80
<d9702`k@00Y>3d0=4=802ll@P0`?D<0@DiD038oA@0^>d40:cPn02Ld>P0c@4H0;ca2038oA@1FHfT0
B5EK030n@@0202dk?P0602dj@00Y=S`0:SLm02Xg?`0]>T80;S]40`0/>D80?@0V=3l09SE002Le@00W
=D00:cQ302hjAP0_>dL0;SU503]5D@0g@Dd09c4m02dg@`0_>DD0;CM302hh@P0^=T40:C8k02D^=@0S
:S809B`a028Z;@0R9bX08BHY024V:P0R:Bl08bXb020W;`0L8b/07B8[020T;@0R9Rl0:bhg02<V;`0J
7BH07B0Y02<V;`0O7b/08b<_02HV<P0T93008B4]020P;00N7RX08B4]02<S;`0T93008b<_024T;@0I
7R40;S<f01/P8`0M82D0=3Ll04U<D@0L72@07alW01hN9P0K6R8071/S01lN9P0P82/00P0P82`301lO
:`<08B4]0180820/01hN:P0M7BT09R@a01PF8`0F52407adZ02@R;`0H5R<05aDR01PF8`0S8Bh07Q`Y
01DC800H5R806QLR01TF8@0H5B0201LD7`0C02DR;@0O72L06AHQ018?6P0R7bX05Q<N01TG8P0N72L0
9RD]01DD700J6B406QTO01TH7P0H5ad05aHK01PG700I61d061LL01PF700301PE700301HC6P0E4QT0
5Q<J00805a@K00T05Q<J01DB6@0E4QT071LN01LB6@0C3QD05a8I01XE700K5Qd01P0G4QT02@0D3aD0
5A0F01TD6P0M61h081/Q02<N900G4QP05A0F01<>5002018=4`0601D@5P0I4QT05a0G01H?5P0H4AP0
5a0G0P0D3A@201D>5@0;018;4P0?20l03PL>01dF7P0E3QD07aPO01PA600L5A/030H:018<400C3A00
0`0C3@l07P0B30h05Q0B01H@4P0F41805@lA01@>400B30h04@/=018<3P0V82802@<5018<3P0J51H0
60dA01D:3P0D2@d05@X>01H;3`0D2@d05``@01H;3`0D2@d05@X>01L<400G3Q406A8D028L7P0I4aD0
4`d?01@>408040X<00`03`T;00d72@0?2@/04@/=010:300C31<04P/B01@=500M5Qd03`P?01PA600F
3aH301<<4`0:014:4@0@2A0050lF00l:4@0C3QD04@`C00d83`0?2Q406A@K01D@5`804PdD01<05A0G
01HA600C3AL04@/E01<?600E4Q/0514L01DB7P0G5B809B<`03Hf@`0U938071/Y01dQ;`0P:3D07RHc
02L_?00/=440:S8o0080;3I201`0;cU502diA@0[=d<0;3Q402lmB00Z>4<09S@o02Le?`0T<CX0:38l
02La>P0Q:S<08BPb028W<@0P92d07R4Z01lR:P0M82L0820X01`L8`0H6Ah06aXP01PG700J6Ah07A/N
01/I700J61/071LK0P0E41L05P0E41H04PdA01<>4P0G4A@06A0C01P?4P0E30l05@X>01H;3`0H3A40
7a@H01T>4P0B1`/04@H:01H;3`0W72005P/?01<8300A1PX05P/?01/@500N4aL301@82P804`L900H0
4PH801<72@0G2`d05`/=01D92`0B1PP201451`0B00d20`0K3a40710B01041P0C1`T03`<501L;3@0@
10H07A4C00h3100:00406@l@00X20`0600002`8301892P0>1@H04@P90P0D2``201892P0901@;300C
2@X040H700h41@0N51D0IUaM0:bRX`0O5AH040H700804PP901@03@<40147200@1PL03@<400h41@0H
3Pl05@/<00X00@0A1`P04PP901<92P0B20T040H700h41@0E2@d04PH:0104200A1@T04PH:01<72`H0
4@D900L04PL;01T>4P0S61`050T=01052@0D2@d06@hB00801`000`0E2Ph0200K41@0;24U01hC5`0<
0@D05@X>01T>4P0C20`040D90P0C20`01`0=0PH03`D801052@0?10P050T=00l4200=0PH00`0A1PX0
200@1@T04@H:01462P0=10H0<RL[00L0000C20`02P030P0D2@d02`0J3a<01`0001072@0M4QH02001
01@93@0?10P040D901L<400900804`P<00804@H:01D04PL;01462P0@1@T03`@801@;3P0?1PT040L:
00H0000D2`h05Pd@01/B5@060000ASe00;6XZ`0d:bh030<601<8300?10P040D901462P0@1@T00P0C
20`07@0A1PX040D901462P0B1`/040D900d2200>0`T04PL=01<83P0@1@/0304701/@5P0=10P07A8H
01lD6P0A1P`05``B06QMH`1TFEl03@8800h32@0>1@T081DK01T>5018?D<04PL=00h32@0B1`d040D;
01Cooooo000Kooooo`0J01PC3`0A30T050h=01<=3P0B30h03`T<00l93@0I51H05Q0@00T4100D40d0
30L400`3100h;C406@hB04Xo@`0R61X04`T:00l51P0B20P04PP701061@0?1@<040H401T?400H3Pl2
01@:2`0801<92P0?1@H04@L800d51@0F30d060h?04@j>`0C2P/201<9200301D;2P0D2PT04`T80080
4`T801405@/:01L=300F30/04`T801881`0F30d03PD501H<3@0Z8240:AlP01H<3@0E2``09A/L01lE
5P0@1PL050X;01882@0201@82P804`L91`0D20X04P0B1`T04`T:01D;300G3@h05P`=01@:2`0K4A80
5@/<01T?400D2`/050X;01hD5@0F30d04PP9020F5`0C2@X03`D601T?40H05P`=00@05@`>01<=3`0D
3Q0050h@0P0E3a401`0N61X02@@501dG6@0C3@l04@/=01<=3`0H3a800P0G3Q4201@>400@01D?4@0E
4A807ATJ028N7`0>30d09B<T01@B4`0I5AH04`l@01XF5`0H51D06ADF01LC500F4Q<061@E01XF5`80
61@E00<06ADF01<A500G5aT00P0G5aT0100H61X03Ph@01LG6@0G5aT201PH6P0;01XJ700K6ad06A/J
01`P7`0K7ah06AdL01TM7@0G6a`05a/N01hR9@0K7b800P0O8RL0400^<CH0724U01lT:00N8bL07bH/
02<Z<00N9B/07bP_028[<P0U;SD08R`e02Tc?00mAe0092hg02<]=P0T;SL302@a>@0302He?00V=Sd0
9SLn00809cPo03409cTm02Th?00X=c`0:cY002`j@`0e@dh0;3Y503A2C00V=3d0=D=;02Th?P0d@dH0
:3Xj02]0?P0Z?d40;dA90314CP13EVH0BUa^03Q;GP0cAUL0?E1P03U<FP0aADl0=d]E03e@GP0kCU`0
>DeI03Q;F@0jCEX0?51J05=WL012EUl0=DUA0396C@0gBe80<dM=03U<DP0kCU@0>TeC03M:D00fBDl0
=DQ>03Q;D@0bAD/0=TU?02i1A`0hBe40?4mB0080>D];00L0<dE502m1@@0a@d<0=4I603=5A@0bA4@0
<dE50080=4I60140=4I703=5B@0cADT0;Cm302i0A00cADT0<D=702m1A@0^@4@0<4960394B00a@dL0
<3m40350A@0b@DH0;ci3030oA00203E4B@0G02ln@`0Y>3d0<D1503E4B@0`?d@0<Sm503M4BP0_?480
934g02dj@00^>d40=45702@a=`0/>Cl0;ca202`i?`0_?480;C/n02/i?00/>Sd0;CY002Xg?@0/>Cl0
0P0]>T80;00^>d@0;CY302/h@@0]>d@0;Ca802dmBP0[>dP0:3Q502ThA@0]>dP0<Si<02/gA@0Y=D<0
;SM602lhA`0Z=400;SQ302La>`0^>480;cQ202@]=P0U;SD08RT`02@/<00U;C009BX]020U:00P9BT0
9R/a02<W<00R9Rl092Pa02<W<00N8R/0;2lh01hQ:P0K7RL0:Rdf02lb>`0L7bP07AdW01hN:00O7bT0
8R8/0P0S8bd0500`<3X08R8/01hN:00S8bd08R8/01dP:00T:Rh0@4E902hc=`0K82@06A`Q02@W;00P
8bP09bP]02HW;00R8bP08B0V02<R:P0N7RT07al[0P0P82`2024Q;@03028R;P0P82`07QhZ00807AdY
00h07QhZ01lO:`0Q8Bd07al[028R;P0Q8Bd0GUiZ01lO:`0A4Ad0820/01`L:00T93006aTU01dJ9@@0
71TT01005a@O01TF8@0Q7RT071TT01PE800R7bX0FeUS01`K8`0O7RH07A`S024P9P0F5A/06APN01XI
7P0K6Ql06QXM0P0J6Q`04@0K6Al06aPO01XG7P0H5A`05A8I01<@5`0F4aX06QLN01TF7@0F4aX05A8I
01@A600R7B@07APO01PC6P0K5Qd071LN00L05a8I0P0G5AX02P0F51T05A<H01DC600D4QL06ALL01PF
6`0C4AH040hC01<A5P0F4aT401PB5P0301H@500B31005@lC00805@lC00/05Q0D01PB5P0H4AL04``D
01@=500A2Q404``C018<4@0F41@050hB01D?4P0201H@4P0301D?4@0D3Q004`d?00@050h@00<04`d?
01D?4@0F41800P0C3@l01P0H4Q@03@L901X?4`0F2`l05@X>01L<40806PlC00l04`P<01@93@0E2Ph0
5P/?01T>4P0J4A@06A8D02DO8@0L5QP03`T;018<3P0E3a404P`>00l92`0B30h00P0C3@l0200E3a40
4P/B01lH7`0@2A004@XA01<<4`0@2A005@hE0P0C31<02P0D3A@04P/B0109400G4QT040/B018=500C
3QD03PT@00d83`0C3QD2014<4`0E018=500C3QD04`hE01<>5@0A31<050lG01LA6`0D4AX05A8L01HD
7`0D4Ql06QPU01lM:P0K6bL05aTV02DZ=P0M8bl08BLc02T`>`0L8bl09blj0080:34l00D0:38l02Pd
?@0X=3d0:3Dn02@b>`0202<`>@07020/=@0R;3D08RXc020W<@0T:3408RH_020S;002020S:P0S01hQ
:00G5al071`S020Q9P0G5Q`06aXO01TH7@0I5aX06QPK01PF6@0D3a@061<J01D@5`0E41H061<G01PD
5@0F4A006Q4A01T@400G3Pl05P/?01L<400I3Q803`@801X?4`0G3A005``@02XO8`0o=3P05@X>01@9
3@0C20`05@X>01H;3`0E2Ph00P0E2@/201@82P<04`L900T05PX<01L;3@0E2@/04PH801<72@0G2`d0
40@602DI6`0Y7Al00P0G2`d06P0C1`T04PH801@82P0B1PP05@T;01@:2`0A1`/03`L901T@4`0N5AP0
40L:00d41`0?1PT040L:00l62@0=10L03PD801482`0=0`@04`T:01061`0A1`P06@l@02TO800H3Pl0
3P@50P0A1`P01P0>10D04@L801882@0D2P/04@L801061`804PP900P04@L801<92P0D2P/04`T:00l5
1P0>10D05@T=01862P804@D900<04PH:01<72`0B1PX01@0B1PX0600D2@d04@H:00L0000F2`l04`P<
01462P0>10L05P/?01872`0A1PX0<2HY03`b=@0I3Q809Q/O02LL800=0PH03P@701H;3`0B2@/040L9
01872`0=10H03@<601<8308040D900@0308501462P0C20`04PL;0P0A1PX04@0@1@T04@H:01462P0B
20/03`@801072@0A1`X02@0201462P0B1`/03@@6038W:`0m<cH040D901472P0B20/040D900804@H:
00@04PL;01<8300@1@T04@H:0P0E2Ph05@0C20`040D901D<3`0=10L050/>00P00P0P5aX06A0C04e4
A`0G3Q4040L:020G6P0<10H04@T;01<8300?10P04@H:01872`0@1@T04`P<01872`0201462P0H0187
2`0D2@d04`P<01873@0A1P`03P<900d2200C20h060hC01D:400_92X060dC00l42P0F2a4050X?01X?
5@0K4QH081DK00T0100H3A<02P4500l42P0e:S001`020P0B1`d00`0G31;oooooooooo`0Booooo`00
6oooool09P0910005a8?00T40@0>20X03`T<00l93@0A2`l040/=00`61P0@2PX050l;02XU8@0B20T0
>2da01X?4`0800406@lA00`20`0H3Pl04PP801061@0D2PT05@/901<91`0D2P/05@/<0147200B20T0
4`T:00l51P0P5QL04PP901X@4@0H3Pl03@<401D;300E2`X030810P0=0`802`0A1`H060h=01471P0C
2@P05@/:01@:2@0A1`H040H501<92P0;0@802P0100808ALH00L01`0001`B4`0C2@X04@L801X@4@0F
30d04`P:008050P:00@04`L901@82P0E2@/05PX<1@0E2@/0200E2P`050X;01T?400X7Ql0:R0Q01dC
500I3a002`420P0A1`P02P0J4140;bDV01lE5P0@1PL03@<401H<3@0c:BX05P`=01D;300H3Pl201L=
3P805@/<00`04@X;014=3P0F4Q<05a<D01DA4P0A3@h0100102DQ8P0?2``02@D601HB4`0K5QL201L>
4@0K01D?4@0F41805Q0B01@@4@0L61T08AdN01TG600M6a`0C4Y;01`J6`0B3Pl0>SHg01TE5P0L61T0
=c<d01`H6@0G4a@06ADF01/G600J5QL06ADF01TF5`0F51L05aLI01HF600H61X06a/M00805aLI02@0
6ATK01XJ700K6ad07AdO01`M7`0L7Qd082@R01/O7P0I7A`0720P01TM7P0G6a`06QhP01TM800T:2/0
720S01@H6`0M8RH082DY01lT:00P9bd092/a01lV;00K92/07BH]02</<`0S;CH07bTb020Z<`0O;380
8Rle02@a=`0U<SP09C<h02@c>00U=3T202@f>P0/02Dg>`0U>3`09SPl02Th>`0T<cP0:STn02dl@`0b
@4T09cDn02lmAP0e@d`0:SU002`k@00`?d809CLg02Xo?P0`ADP0=DU@0395DP15Ef/0CEmg03a=I`0l
CVH0>deS03]=H00gBUT0<TEC03Y>FP0jCUT0>TiG03U=E`0eBE80=4Q?049FG@0jCUD0<TM<03I;D00l
DEH0=TY?03Y=D`0lCeD0>TeC03I9C`0eB4h203I9C`050313B@0cAT`0@EAJ03E8CP0dAdX00P0jC4`0
1@0bA4@0;3hn0312@P0dATH0<dE50080=4I60P0cADD01`0Z?3d0>D]=03Y<CP0]?d40;T1202m1@`0e
AdT00P0_@D<01P0a@dD0<TA602m1@`0d@dP0=DA90391AP80;3]003D0<T5602Lf>`17EU/0BEQM02Lf
>`0Z>Ch0<d9702dj@00kB4h0;CY002`i?`0b?dD0;S]102/h?P0^>d40<3e302Hc>@0a?T@0<Sm502hl
?`0Z>3/0:CLj02Xg?@0Y=S`0;S]103E2BP0_?4@0;CY302/h@@0Y=Sl0<d1902/kB00]?T/0:c]802Lg
A00Y>4D0<Cm<02/iAP0^>dT0:CE302Pd@P0Z=T@08Rhj02Pb>`0X<cX07RT_01lX;`0S;3<072D/02D/
<P0W;S@0;cLj02hc=`0202<X;00902DX;`0P8RT08B@[02P[<P0[;SD09RT`028U;00V:C007b8Y0080
6b0V01H061/R020P:00L72@071`T020P:00Q8BT0820X03Lg?`0W9bl07QhV01/K8`0O7bL082<Z01/Q
9`0L8bT05QdS028W;@0M8RP07b@Z01LJ7`0N8BH07b8W0P0N7b@02@0P82P07QhY01lO:`0P82`08R8^
02<S;`0T9300820/01dM:@0201/K9`8071`X00L07QhZ01/K9`0K6bL0820/03PhA02CTil0<S8n0080
5QHR00@04A4M028R;P0G5R406aPS0`0J5b802@0K62<08b0[01dJ9@0D4A`07Q/V028O:P0W92l0J6I`
024P:00201/J800901dL8P0K6Ql06QTN01XI7P0K6ad06ATK01PH6P0I6A/06APL00<061DL00h05a@K
01HC6P0H5A`06QLN01TF7@0F4aX05A8I01@A600N6B007aXQ01dH7`0I51/06QDL020K8PH05a8I00@0
4a4F01@B5`0D4QL05A<H0P0F51T06P0G5AX06ALL01DC600B41D06ALL01XH7@0D3Q805@lC01PB5P0G
4AD05Q0D01D?4`0F41@050hB018<400D3Q804`dA010:3P0F3aL050dE0109400I4QT04P`A00`62P0E
3a<05Q0C0`0F41803@0E3a405Q0B01H@4P0F41805@lA01<=3`0B30h040X<01D?4@040000<bd_00`6
200Q6ad00`0H3A401P0J3a<060dA01@93@0D2@d05@X>01H;3`805``@00T05Pd@01<<3P0G4A<050h@
014;3@0C3@l050h@010:300B30h0100A2`d01@0B2a801004018;4P0J4aX05@hE008050dD0P0B2a80
100D3A@04``C014:4@0A31<200l:4@8050lF01T04@`C01@?5P0A31<040/B018=500F4AP061<J01@=
5@0B2a<05@lF01LB6@0F41X050lJ020M:00R82/06aTU01/I9P0J62D071dZ01`P;00T:3@0=SY602L]
>@0M8bl08RPd00808RXe00<092`g02@^>00V<3X00P0V<c`04`0T<CX08Rdf020Z<`0O:34082P`024X
<00Q9Bh07b<[020S:P0U9Bd08B8Z02<V;@0Q8BT09RL]02DV:`0K6R009B@Y020O900I5aX00P0H5QT0
2P0G4QL061<J01D@5`0E41D06A@H01TE5P0F40l05`l=01H>2`0F3@d201H;3`0=01H;4@0>0`L081DI
01X?4`0;00@0304501D;3P0E2Ph05P/?01L<400D2@d04PL;01462P0301D92`8050P:0P0C1`T02@0F
2P`05@T;01@82P0C1`T050P:00l31@0E2@/04PH800l31@020186200O00d10`0B1PP0710B00T0000A
1@L04`T:01XA500I4aD03PP:00T31@0>20X040X<00l92`0A2`d040X<00h82P0?2@/050/>01P>3`0E
2``0308301061`0D2P/07Q@E0147200>10D03`D60147200@1PL04PP900l51P0200d3100:00l51P0A
1`P050X;01882@0@1PL03`D601061`0A1`P04PP901@830804PH:0`0A1@T601862P0I00l5200A1PX0
40D901T>4P0;00@050T=01D:3P0?10P0304501892`1bIf/0RGj201H;3`0700003P<701<8300H3A40
3`H800L0000=0PH04`P<01872`0/8BD0<RL[01@93@0201052@0301<8300B1`/04@H:00804@H:02`0
40D901462P0A1PX04`P<00L0000L4AD02@0201872`0J3a<030<501H;3`0>0`L06@hB01872`070000
50T=00h31`0B1`/03@8601X?4`0;0@@03`@801462P0D2@d05P/?01@93@0@1@T03PD8014;3@0=1`T0
208401`F600@2P`05Q0B00@0000E3a402P@601@>400G41804PL;01052@0B1`/04`P<00l420804@H:
01T040D901462P0C20`050T=01<8300@1@/04PL=0146300?10X091TO03ld>P0900@05`hB01873@08
00<01`0202<H7P0O51X060dC01D:400G31803P<901T>500H3A<0200300<04`P>00<03`@:oooooooo
ool04_ooool001_ooooo01H04@`601@?2`0C3P/05@lA00d72P0G4AD02`D901LA500>20P0618B00H1
000<1`<05`d>01482P070000714E01872P0<0P<04PP900l51@0?1@@050X90P0E2`T0400C2@X05@/<
01882@0D2P/05@/<01882@0>1PH0308300L0000E2``0200001P>3`0@1PD05`d<028H5`0M4a820106
1@D04PP700@04@L601P>3`0H3Pl07A<D0P0H3Pl01`0K4A8030@401<92P0B20T04@L801dC500Y7Ql0
0`0D20X0100E2@/05PX<01D92`0D20X301<72@0D01@82P0F2``04`T:01882@0L4Q<08QPI01`B4`0D
2P/02@000147200E2``06Q0A02<I6P0L4Q<05P`=0147200P5QL0C493020F5`0J414201@:2`0S01H<
3@0G3@h05`d>01<<3@0A3@h05Q8C01PD5@0F4Q<04Ph?04A0@@3?bl`0?3Pi02<O80070`@03`/<01@>
400G3Q405Q0B01LA4`0F41805A4B00h:2`0D41403@/<00L51P0[:BX030X;02LS9019ADH06ADF01<?
400Y9BH02`L801LC500I5AH00`0J5QL00`0L6AX06aTL01PH6P0201DE5`0501LG6@0F5QP05ADG01LG
6@0H61X00P0I6A/06`0H6QT05QXI01dR7`0G6aX05ATH01/O7`0G6a`092PY01dQ8`0U:B`0A4Q;0496
B@0V:Rd06QlS01dR9P0L8BD07B@Z024X;P0L8bT08R/b01hW;P0R:c808R`e020Z<`0S;CH07R/a02<`
=P0202Db>00W02Dc>00U=3T08c8g028d>00S=CT09CLk02Lj?P0X?3d0<D1202<b=@0Y>3d0;3]2030n
A`0V=3d0:SQ10391B00R<CP09C@h02Lg=`0Y>c/0;41003A9CP0hC5D0;d9B03e?I`14EFl0>daX03a=
I`0iBf<0?4iS03Y=GP0dAeH0>4aF03Q<E@0iCEH0>DeE03A8C`0aAD`0?51F0080=daA00@0=DY?03U>
D`0cAdd0=dY@0P0iC58203M:D00@03=6C00mD5H0Cf9X03I9C`0hBe40=TU?03Y=D00mCdl0>de=0394
A00[?Cd0;Clo0394A00cADD0=DM703A6AP80<TA400`0=DM802<e=`0dATP0DF=U03a>D00hBT`0<dE7
02i0@P0_@D<0<TA603A6B00`@T@203I5BP0G0391AP0]?440;Ca102ln@`0X=c`0AUEJ04MFF`0X=c`0
:STn02dl@@0W=3X0>DI<02dj@00b?dD0<3e302/h?P0W=3X08c0f02Tf?00T<CL0:3Dk02`i?`0^?3l0
0P0Y=cX06`0Z=cd0:3Dk02dj@00f@d/0;ca402`i@P0[>440:3Dn03=0B@0b@Tl0<dAA02loC00Z>TL0
<3m<03Y8E@0a?d`0<Ci<02XfA00W<d40:SI402/g@`0V<3T0:C@j01XU:`0K92/09Rlf01`U;002020W
;@0=02L^=00V:bl0724U01hS9`0V9Rh08R8Z02<S:`0Y;3<0;c8i02d`=`0/;cH0:Rdd028U;002020U
:`0401TN900Q8BT07AdU01`L9080820X01L07AdU028R:P0T92`08R8Z01hN9P0O7bL082<Z01XP9P0X
;cD09B`b028W;@0=4QP02a0F01HI7P0L7b@07B0U01hO900O82D08R8Z024Q;00R8Rh08b<_02DU<@02
02HV<P03024Q;@0O7b/07QhZ00<07AdY00`09bLc02<S;`0I6BD06a/W01TI9@0e=D403`lK00`<600D
52005ADQ02<S;`0M72P301`I900G01dJ9@0N6bH071TT01hK9P0P7BP09B8]03<`>`0I5R406QPR00d<
500H5ad07A`R01XI7`0V9BX06APM01LF6`0I6A/05aLI01@D5P0F5QP05aHJ01HC6P0G51/00`0H5A`0
300I5Qd06QLN01TF7@0G51/05Q<J01DB6@0G4QT06A@K01HA600B3A@06QDL02lZ<@H05a8I0P0C4AH0
200D4QL05A<H01HD6@0G5AX04a4F01PF6`0E4aP04a4F0P0J61d00`0D3Q805@lC01LA5@0201D?4`0?
01PB5P0D3Q804P`@01@>4P0J51P06A<G01@>4P0K51`04P/B00l83`0A2Q405@lD018<400D3Q805@lB
00805Q0B00<05@lA01@>400F41800P0F4180400E3a404`d?014;3@0G4A<04@/=030Z;02PVY`0;BLY
00L10`0E2Ph05P/?01L<400H3A405@X>01052@0F2`l301L<400301H;3`0D2`h05`lB00804`d?0100
50h@018<3P0A2`d05Q0B020J700E3a404@/=01D?4@0@2P`0614H01<<4`0B2a8050dD01`E700?20l0
50dD0P0B2a807`0D3A@04``C018;4P0>2A0040/B00h9400A31<04`hE014<4`0R7B@05Q4H010;4P0B
3A@071LN024L8`0D3AD04P/C01D?5P0G4QT05Q0J01HA700I5R40518M01HD800M6bP06ALT01/L:@0E
6BD082@`03LkA`0Y;CT00`0Q9c<08P0S:cH08RXe024Y=00S;CL09C0j02Db>`0S<3T07b/d020Z<`0O
:34082Pa020W;`0N8R/07R8Z024T:`0U9Bd07AhV01dP9`0R8RX08b@Z01dN8`0I61h071/P01PG700C
4A@04Q0C01@B5@0J5AX05a8I01D@5`0E41D05Q8C01LC4P0G4Ph201H>2`0701D=2`0F30d05@X>01D:
400C20`060dA01D:3P0201`A5@0501X?4`0E2Ph05``@01P=4@0D2@d00P0B1`/00`0F2P`05@T;01D9
2`0301@82P0301<72@0E2@/05@T;00804`L900D05@T;01451`0K3a403@4300P0000201D92`0I00d1
0`0D20X0710B00X0000?10D04@L800T00`0<1`P0100000L10`0W8B<01P0200d72@0@2P`04@/=010:
300?2@/040X<01T?400F30d0308300h41@0<0`@03@<401882@020147200501061`0>10D03P@50188
2@0=0`@00P0?1@H0200>10D040H701882@0?1@H03P@501061`0E2``05`d>0P0C1`/201862P804@D9
1P0C1`/0600?10P03P<701872`0@1@T02`0401X?4`0?10P02`0401@93@0B1`/07a@H02dR9P0:00<0
4@H:01hC5`0F2`l03P<701482P0E2Ph04`P<01462P0900803@8601D:3P801`0000@05@X>00T00P0:
00<05P/?0P0A1PX0500@1@T04@H:01462P0>10L02P0301X?4`0=0PH060dA01T>4P0B1`/0714E00T0
0P0?1PP0714E01462P0C20`0304501@93@0<0@D091TM0P0>0`L05P0@1@T04`P<01@93@0C20`040H:
00l62@0D3Q002@<501XD5P0A2`d03@L901lI6`0400003PP:00@0000>20X01P4201872`0@1@T04PL;
01<8300?10P201052@803P<701/040D901462P0@1@T03P<901<83P0E2Q0040D;01L<4P0V6b406@hD
0148300H3A<04PL=01T>500J3aD01`0201<83P0E2Q004`P>01P=4`0700805``B01873@0L4AL01`02
01L<4P0800<05?ooool001_ooooo02804@/5010:200?2PL040P:01@>400=1``0610F03H_<P0?2@T0
40T8014<2P0@2PP05@/<01<9300@1`T06a0D01`B4`0e:b`04PP901hE5@0P5aH050X901471@0E2`T0
50X;01D;300B20T04`T:01@:2`0A1`P05Pd=01`B4`0B20T04`T:0P0D2P/0600C2@P060h=02DK6P0O
5A@04@L601@:2@0E2`X04`T801881`0C2@P050X901H<2`0@1`H04`T:00/30`0C2PX06@l@01<92@0I
3`l04PT901H<300J4140;bDV03`a<P<050P:00@05PX<01L;3@0G2`d05PX<0`0D20X0500F2P`05@X;
01@:2`0E2``04PP901061`0B20T05P`=01L=3P0C2@X050X;01D;300C2@X05@/<01061`0P5QL04@P9
02`S900A1`P05`d>0`0D2P/0100D2``050X;01@=3P0D3a4201@?400;01D@4@0G4Q<061<E05=>D00I
51H04`h?01TD5@0F4A804`d?01@>400G4A<00P0H4Q@06`0F4Q<06ADF018>3`0I5aP03`h>014A4@0[
:BX0>SHg01PD5@0I5AH05a<D00l;300M6AX05a<D01PD5@0I5AH06ADG01`G6P0Q7Al071XM01PH6P0G
5aT061PJ01LG6@0F5QP05aLI01TI6P0201XJ6`0S01TI6P0F5aL04QHE01/P700C61D04QLE01XO7P0F
71/05Q/K01`R900F6ah07R<V01dR9P0I7R806QlS01dR9`0L8BH07B@Z024X;P0L8bT082T`02H_=P0[
=3/09S0i024[=00W<CX07BX`02<`=P0W=3X09S<i02Dc>@0V=CX0;3e102Ti?P0V>3`00P0T=SX0<`0T
=cX0AEAF02Lf>@0X=c`0:SU003A2BP0^?DD0;3]302hmA00X=cd0;Se1028a<`0`@T<0;4=50318C@0i
D5T0=T]M03a@J@0jCVX0@eId03a@J`15FG80?e=Y03A9FP0kDEh0>4iF03A9D00cBU00=TeC03E;D@0c
Bdl0>E1D0398C00hCe80;TI80357B@0dB4d0>DaB03Y=D`0hBe40=4M=03=6C00eB4h0<DA:05AWK@0l
CeD0=dY@03Q;D@0hBdh0=dU903E7A`020353@`80=4I600<0<dE503I8B00eAdL00P0bA4@0<@0cADH0
:C/m03U;C@1MKg40@E=E02do@@0_@D<0;Cm102m1@`0dATP0=TQ:0394AP0eADX0<T9702loA00a@4D0
<T56030oA00d@dP0;Se202ln@`0a@4D0:STn02Pg?00X=C/0>DI<02Xg?@0c@4H0:3Dk02dj@00^>d40
:3Dk02`i?`0W=3X0:cPn02dj@00Z=c/0:3Dj02hk?`0`?480:SLm02Pe?00`?DD0:CHn02dj@`0^>d@0
9c@l02dkA00U=D800P0Y>TH09P0Z>TL0>DUF04aLJ@0_?DX0:SQ502hkB@0`?4X0:cM602/g@`0S;CD0
7RP]024[<@0S;3<08R/b02@]=00X<3L07RH^020W;P0N92/06b0V02H[<@0R92/07QlW01dN9P0Q8R/0
:B/c02/_=P0X:c<07R4Y01PL8P0P92`09R/b01/P9P0O8BH071dR01dN8`0S92T08B8W0P0N7b@201lP
9@0B01hO900O7bH07B0V01XO9@0M8bT061hT01/Q9`0I7B<08BD/01dP9@0Q8bT0828W01lP900R8bL0
9BH[01lO:P0O7b/0820/0`0Q8Bd301lO:`0?01dM:@0K6bL06QXV01TK9`0C52006adY01XL9`0X:CD0
71dX01/M:00@4A`06a`W03<f@00W:3<07QdX00<07Q/V01D07a`W020M:00P7BP05Q<N01dJ9@0J5b80
9b@_01`I900J62807AdT01LF7@1=C5<04a<J01/J7`0I6Ah06QXO01dM800J6Qd05AHG01TH6`0J61d0
0P0G51/401PE70806AHM0`0H5A`301PC6P0301LB6@0I51/07APO00H05a8I00`05aDJ01HD6@0F51T0
518G01<A5P0B41D03`dB01LE6P0E4aP040hC01LE6P0C41D201TC5`0B01LA5@0B31004P`@01LA5@0H
4QH05a4E01/E6@0R72007QPL01D?4`0G41L06Q<J024J8@0:0`X05@hD01TC5`0D3Q805@lB0`0E3a40
100D3Q004@/=01<=3P0C3@h201@>400801<=3P0J51H040X;01D?400S7Al040X;01TC5@0H3Q4201H<
400;01T>4P0K4A@06Q0C01@93@0F2`l05`d@01P=4@0G31005@`?01@=3`0A2`d00P0B30h03`0A2`d0
4`d?01hH6P0b;2h06A<E014;3@0J51H03`T;02@L8P0X82H05PlE01<<4@0V7bD03@H<01@=4`02018;
4P0n01D>5@0D3A@04P/C01TD6`0N6B005Q4H00l:4@0A31<040/B01HA600D3aH04PdD01@?5P0E41L0
5Q4H01@>5@0B2a@05@lG01LB6P0F41X05Q4K01LD7@0I5R407Q/V01PF8@0F52407AdY028T<00H6BD0
71lZ028U<@0K7RT07b@_02DZ=@0Z<S/08b/e01XR:`0M9Bh07bTb01hZ<`0M:3806B</01hX<@0Q:C00
7bH^01dQ:P0J7B@08B<Z02HV;P0O7bL06Q/R01PJ800O7bL071`R01PH7P0J6Al05aHK01PG700G5AP0
4a4D018@4`0H4aP201D@5`0A01D@5@0A3@h04Ph=01PC400F3``05Q0;01P@3@0H3Pl05`d@01H<4P0I
3a8050X>01H<3`0E2Ph04PP;01/@500C20`00P0E2`h0100B1`/040H:01D:3P0F2``201H:300<01D9
2`0D20X050P:01<72@0E2@/050P:01<72@0D20X05PX<01D92`0A1PL04`L90P0E2@/06`0F2P`05@T;
01451`0B1PP04@D701@82P0A1`P06A0C014:300B30h0=blb085jO00F41803@D8018;3@0E3a4050d?
014:300?20X03PD601<92P0D2P/05P`=01<:2P0>10D03`D601882@04014720804`T:00X05P`=0106
1`0?1@H05@/<0147200B20T050X;01L=3P0J41406a4B100C1`/00`0A1@T040@801<72`0501<72`09
01872`0A1PX04`P<00h31`0G31004PL;01dB5P0Z7b<050T=00803`@800X04@H:01052@0D2@d03`D8
00h41`0D2@d03P<700l4200?1@P03`@80P0B1`/01`0A1PX09a`P02dR9P0B20/04PL;01H;3`0A1`X0
0P0A1PX0:`0@1@T04@H:01462P0B1`/06@hB00d41P0I3Q804PL;00h21P0C1`/03@@600l4200C2@d0
4@L<01883P0B2@`03P<701H;3`0>0`L0=BX^01dB5P0>0`L03`@801052@0A1PX04PL;01472P0>1@P0
4@/=024J701SFeh04@/=00d62@0>1PT02P@600l82`0>1PT04P`>00d6200B1`/040D901<8300D2@d0
0P0?10P00`0C20`04@H:01052@0201462P0I00l4200@1@/040D;01873@0F2a405@X@01052`0A1P`0
4`P>02hS:@0>1@T040H;0148300H3A<04@H<00l42P0D2`l04`T>0148300C20h050T?00d4200>1@T0
4`P>0146300Dooooo`006oooool07`0H3P`040L401081@0B20L04`X801H>300D2PT03PD401081P0L
4Q004`X801D=2P0:0P004``;00X50P0H3a006Q<A00@0000<10807ALD02<N6`0>1`H04PX801H>300D
2P/06@l@01061`0=10D06@l@00d3100H3Pl00P0D2P/00`0=0`@03`D601X@4@0201@:2`0500l51P0B
20T05@/<01<92P0B20T00P0A1`P03`0B20T04`T:01@:2@0F30X050X901<91`0B20H04@L601471@0G
3@`03P@300h40P0D2PP050X9018820020147200;01<92P0D2P/04PP901061`0C2@X05P`=01L=3P0D
2P/04`T:01`B4`0X7Ql00P0D2P/0500?1@H03@<402HL7@0B20T05`d>01H<3@0K4A804@L801L=3`06
00804@P;01/D5P0<1PP04`X=01@=3`0@2P`04`X=01D=400D3Q0050/>0P0F3A00600G3Q4060lB01D<
3`0H3a805@`?01P?4P0D2`h06A0C01@;3P0A20/06Q@F01DA4P0J5QL00`0002@P8@0E4A804Ph?01HB
4`0B3Pl04@d>01HD5@0J5QL05Q8C01LC50806ADF03X061@E01HA5@0P6al04@`@01/F6P0^:Bl091lU
01TD6P0K6A`06QPK01PF6@0F51D05aDF01PF5`0L6Q/071/J01dL6P0N7A/06aXH01@D4P0M7Ad06A/K
01LH6P0I6Q`06a`N01TM800R8bL07R4V01/N8`0L7b@07b<X024V;00O92X07R8Z01dQ:P0M92`07bH^
01hU;@0P:C00:C8i02`e?00V<CL08Rdc02D`=P0R;cD09C8h024^=00M:S008Rle02`i?`1KJFl0=T=9
02Dd>@0Q<3D0<T5601h]<P0T<cP09cHk0P0[>Sl08`0c@TL0;3]002hm@`0`?d@0;Se202ln@`0^?D80
:3Xn02i4BP0bB5<0<dUG03U>H`0fBVD0?4m]04QKN@1AIGh0Ig^C03M=G@0dBUL0<DMB03a@F@0lCUP0
>DeF03a?E`0lCeH0=TYA03=7C@0X>d40=4Q<0315B00_@TH0=dY?03a=E@0mCUH0>T]C0080=DI>00<0
=TM?03A5C@0dADd00P0gB500500dADd0<49503M:B00gBTP0;T4o03=6A00gBTP0<DA20395@`0gBTP0
=TU70395@`0dAdD0>T]<03Y9CP0gAT/0=TE:03=2A`0`?d@0<D150P0d@dP20350A@0@03=4B00U>3h0
<dI<03I9C`1=GVD093Dl0393BP0W>3l0;Ci502hmA00/>d80<D17030mA@0b@DH0;3]00350A@80:CPm
03h0:CHl02dh?P0^>Cl0<Ca2030k@@0_>T00;3Hm02`d?`0[=Cl0<S]4045:D`0/=Sl0:S@n02Tf?P0U
<SX082de02lnA@0]?440:CQ002lmBP0[>DL0:cU602dkAP0a?dX0>4IA02hoB@0^?TX0;3a902/hB00T
<d<08Rhn028Y<`0J82T08b/h02T`@00S;Ch08bi003Y5E`0V<40082Pc01lV<00P9BX07B8V038f?`0M
8B/0:Bdf01<G8P0Q9Bl05A`T01@H8`0N92d061lW00lF800O9Rl07B4Z02HY;P0Q8RH071dQ028S9`0S
92T07QlT01hN9P8071`T00/07alW020P:P0P82X07QhX028R;00Q8B/07AdW01@D7P0R8R`05aLP024O
:P0201hM9@0e024P:00N7BD071`V028R;00S8bd07QhX01/K9@0L72H0:2Pb014A6`0Y:C<08B4[01<C
7@0L72H06QXT01dK9P0N7RP09B@^02LU<00a<3P07QhV01TH7P0F5Q`06AXO01dL8P0P7RL06QPS01HD
7`0K6B@071XU01PF8@0G5B005Q@O01<A700E4ah06aTT01hL9`0P7bX04aHO01@D7P0I6R@09RTb01LG
8@0G6B804aHO01@D7P0I6b@051LN01XJ900H5ah05Q@I01DC600E4aT00P0D4AP00`0G51`061DN01LD
7@0201HC700@01LD7@0N6B006aHM01XE700N6B007APO01@?5P0J5A`05a8I01D@5`0H4aX06A@K01HA
600I51X061<I01HA5`8050lE00T05Q4G01@?5@0E41H05A0F01@?5@0C3Q@04PdC018<400C3A400P0F
41@01P0E3a<04`dA01D?4`0E3a<050hB01<=4@8050hB00<04P`@01XD600H4QH00P0F41@08`0B3100
50hB01@>4P0A2`l040X>01<=4@0G4A<04`d=01LA400H4a007ALG01<>300E40d06Q@D01PC4@0E40d0
50h>01<=300B30`04P`>01hG6@05004050/>01H?4@0@2P`071<F01L?4P0A2`d04`X=01H?4@0I4aD0
4@/?018<400C3A405Q0D00805a4E01@05Q0D00h8300?2@d04@/?01@>4P0K4QD05P/?01<8300F3A00
71<D01@;300K4Q<04@P;018<400C31<04`/E01084`0>1Q404@`B01@?5@8061<I00<04@`B00`73@0B
3A<00P0C3Q@0300A31804PdC01<>5@0L624050hJ01DB700=2QD040dH01TF8@0G51l061DP01XG8P80
6aPS00@06QPS01lO:@0D4Qd061PR0P0T92h0>@0L72H09RH`02XZ=00Z:S@09BD_024Q:`0M82T07b</
024U<00P92d06alX01TM9P0K7bP07B0Y01`O:00I72D06QdV01TL9@0K6b8071/P01XI7`0J61d05aDJ
01hL8@0I5a`05Q@I01DC600G5AX061HK01DC600H4aT040/A01LB5P0@2`l071PI01HB4`0D41404`l@
01<=3`0@2P`02@<701PB5P0J51H02@<501L?4P0D2`h08A/M01<<3P0A20/040X<018:3@0C2Pd040X<
0189300>10D040H701<92P0301D;300401H<3@0A1`P04`T:01D;30804`T:00<040H70147200C2@X0
0`0C2@X00`0@1PL04`T:01<92P020147200L01@:2`0900806Q0D00P00P0H3A4060hA00h5200F2`l0
50X>00d41`0>0`L04`T<00h31`0A1PX03@8602@I7@0;00@040D900/0100?10P05P/?01D:3P0F2`l0
=BX^02DJ7P0E2@d04@D9010420804PH:00<04@D901<72`0E2@d00P0G2`l06P0F2Ph05@T=00d21P0=
0PH03P<700l4200A1PX04PL;00l4200A1PX04`P<01D:3P0A1PX03`@800h31`0?10P04`P<00d31P0A
1PX0304500l4200C20`050T=01462P0>0`L03@860`0A1PX0100J3a<07Q<G01D:3P0@1@T201462P0P
01052@0?10P04@L<02dT:@0f;C805`dB0146300F2A004`H=01@73P0700804`T>00/21`0G3Q<030<8
01052`0B1@`05PP=01H72P0C10L0404401D93@0G31803PH>00L12`081A0040P@01872`0A1PX081DI
02XO8`0J3a<201462P0A00l4200<0@D03@8601052@0?10P040L:01@:3P0C20`040L:01472P0=0PH0
3@@701@:3@0D2@d040L:01052@0A1PX00P0?10P201872`0O00l4200B1`/04PL;01872`0A1PX040D9
01052P0=0PX04`P@01D:4P0A1Ph081DL00L00P0?10X04@H;01462P0N4aL02P4302@I7@0=0PP05@X@
01<83P0G31803P<900l42P0=0PP05@X@0146300=0PP040D;01@93`0Dooooo`006oooool09P0D2PP0
4`T701L=2`0F30X04@L501<91`0>108050X80106100<0P004@L500/3000B2PP02PD201PC400G4Pl0
4Pd:01XE4P0<1`@03PT800@0000D3``020<001D@3@0A1`P02`4200T0000E2``02`4201/A4P0O5AH0
2`4200l51P0I3a004`T:00l51P0B20T05@/<0P0F30d00`0C2@X04@L801@:2`0201<92P0?01@:2`0E
2``05P`=00/1000=0`4040H401H<2P0K4@l07A<A01<91`0F30X06a4?020F500H3P`04PP800804PP9
01`050X;01D;300D2P/04PP901@:2`0G3@h05P`=01<92P0B20T05P`=030V9`0Z82405`d>00T0000S
6AX0>2h_01T?400F30d04@L801@:2`0J41403PL701dG6@0L5QP01P42018<3P0?2@/040X<0P0D3Q02
01H@4P0I01@>400F3Q405P/?01H;3`0H3A405``@01T>4P0G31006a0D01T>4P0O51P06@hB01D;3`0D
3Q004`l@02/W:00H51D07a/L01<?400G4a@07ATJ01XF5`0C3a005A4B01LC500201HB4`<05a<D00/0
5Q4E01`G6`0C3Q8061<I02<N900M61h05a8I01PF6`0G5AP05Q@G01@B4`0201HD5@0C01/J600J6AL0
6aXH01`K5`0K6QH05aHD01/K6`0I6A/061PJ01XJ700L71l06a`P01hO900L7R<06QdR01/N9@0M8BL0
7R<Y01hR:`0201dQ:P0:01dT;00P9bl082L_01hW;P0U;SD0:34h02D`=P0S;S@092le01dZ<0808Rle
02X082dc024^=00U<SP0;ca2024^=00S<3H09c@j02dj@00U<SP0:3Ll02Th?@0[>Sl0:STn0350A@0Z
>Ch09cHk02He>P0Y>3d0:3Ll02Th?@0/?D@0>4eF049HI@17G6d0CF5h04AHL`18FgT0>dm[03a@J@1<
HGH0=DYI03Y@F`0fBU<0?4iH03U;E@0eAe40=dUC03Q;DP0dAdh0=4M=02m2B00fBDh203M:CP0703U;
D@0fAdl0<T=;0311B@0^?dL0;3e50393B`0303U:DP0/03Q9D@0iBU80=dQ<03E8AP0cAT@0;D0n0313
@@0cAT@0<TE303I9A`0jCD/0>Da:03Q;B@0kCT`0>T]<03A3B00c@TL0=TE:03E4B@0_?T<0;3]0030o
A00c@TL0=TE:03A3B00_?d@0:ci4051UJP0Z?D<0=TU?02Tl@P0a@TT0;d170393BP0b@DP0<3m60391
B00^>d<0;Ca102Lf>`0/>d009SDj02Pg?00Z=cd202dh?P0m02lj@00_>3l0;cPo02df?P0/=3l0<CU4
02Ta?00]=D00:S8m02Xd?P0S<3P0<3e503A1B@0Y>3l07Rdb02@b>P0^>TP0;c]:034mB`0a?dX0<Cm9
0390B@0[?4H0:SY602PhA@0V=TH08c=402@`@00R:3@082@`02H]?@0`=dT0=CiD03M3F@0/>4h07RPj
034kA`0P9c408BH/00X?4`0O8b`06B0Z01dT;P0T:cD0:2li01/R;00X;cT05ahX024X<P0M92h0<SU3
04a@F@0P8bP092DY028S9`0O82@071dR01TJ7`0O7bL07AdU01`L900201hN:00>01dM9`0R82/0518M
01LE8014@Td0>SQ301XH8`0L6RD08b4/020N:@0O7BP081hY01dK9P0N7RP2028R;00501lO:@0M7BL0
7QhX05EEG`0K6bD00P0P82X02@0D51h05aLQ014?6P0E4ah08AlZ028Q:@0H5al081lV01/J800201HE
6P0<01`K800O7R<081lV01dK9P0L6RD07Q`W01dK9P0L6RD06ALR01LE800K6B@07adX0P0P7RT03@0H
5b8030hJ00H8500L7RX04aDQ00/=6@0F62@0:2Xf01dO:`0C5B4051HR02<U<@0G5Qh00P0F51T01P0F
4aT05A8I01DB6@0G51`061DN01LD7@805Q<L00@05a@M01XE700H4aX06A@K0P0M61l201LB6@0;01HA
600G4QT06aHM01`G7P0I51/061<I01LB600F4AL050lE01D@5P0G4QP0100D3aD0100C3Q@04PdC01<=
4@0C3A4301D?4`0=01<=4@0I4aL0618F01@>4P0@2Ph03PP<00`62P0?2@d05a4E01H@500E3a<06A<G
01LA5@0201@>4P0:018<400@2Ph04`dA01H@4P0=1`L03`X700X50P0<1`@05a8?01TD4@<05A0=00/0
5Q4>01PC400J51@03PP:010;300O6A/071HH01dG6@0J51H03`T;018<3P0201D?4@0301<=3`0@2P`0
4@/?00804P`@0P0D3Q800`0E3a<050hB00l93@03014;3`0?01L>4`0D2@d05P/?01hE5P0E30/02@40
01491`0D2`d050hB01D>5@0E3AL04PXG0149500=20h03`X@008040/A00<03PT?00d83P0B3A<00P0C
3Q@01P0A31804PdC01<>5@1iMX007AXU00/84`805A8M00@0514L01HC7P0F4ah05a@O0P0H5B00400N
6bH06ALR01PF8@0S8B`020HA00h<5`0R82/0928]02DS;P0T8Rd08AlZ020N:@0O7RP07B0Y01lR:`0P
8b`201dP:@04020S;00N8BX071lX01/N9`806QdV00T07A`S01PF6`0E4aP061HK01LE6P0L6Ql06ALL
01LE6P0E4aP00P0G5AX04`0D4QL01P4501hI7@0N6Ad02`H:02@O8`0B3A40B4=701`G6`0?2Ph08QdQ
018=4@0D3a<0100001LA4`0K5AL02P@600@0000>20X01P0@2P`03P0F30d05@/<01D;300G3@h05P`=
0147200G3@h050X;01H<3@0D2P/040H701882@0@1PL04PP90`0C2@X0100B20T040H701<92P0C2@X2
0147200701@:2`0A1PX04@H:01@93@0B1`/05P/?01lD600201462P804PL;014050T=01D:3P0I3Q80
5P/?02XO8`0B1`/05@X>01052@0;00@04PL;01462P0=0PH08AHJ01052@0D20`040@800l31`030186
2P0601452@0B1PX04`L;01@8300C1`/04PH:0P0?10P01@0@1@T04@H:01<8300D2@d04@H:00<03`@8
00T03P<700d21P0G310060dA00T00P0D2`d01`0001lD600@1@T00P0C20`0200@1@T03`@801052@0D
2@d04`P<01052@0D2@d05@X>0P0A1PX201052@0K01462P0B1`/03@@801LA5@0N5AX03`D:01052`0C
1Pd05@P?01/>5@0G31802P4501H=4P0>20`040P>01052`0B1@`05@P;01L72P0D10D050D700h21P0:
00D030@=00X74P061140208;00803P<700<050T=01T>4P0B1`/00P0B1`/0100A1PX03`@800l4200A
1PX201052@<04@H:00P040D901872`0=0PH04@H:01H;3`0>0`L04PL;01052@803P<70P0B1`/07`0?
10P04PL;01872`0B1`/04@H:01052@0@1@X03`@<00X0200<0`T04@H>01883P0L4AL060dC01462`0;
00@05@X>01872`0800403`@:00/21P0800<04@H<01052`0B1`d03@8801<83P0?10X0304701052`0A
1P`05?ooool001_ooooo02/050X901<9200C2@P04@L601D;2P0R61L0ED]:01<92@0E2`X040H501D<
2`0I4@l05@`=018<300=1`L020<300l:2P0F4100618B00l92@0F41004@/;01PB4P0<1PH060l@04e3
A00k<C80718C03le=P0C2@X05`d>01D;300D2P/03`D601061`0D2P/04`T:01061`0I3a005@/<00l5
1P0F30d04`T:00804PP900L04`T:01@:2`0E2``050X901<9200B20L04`T8008050X900H04`T801D;
2P0J40l07aDD01`B4@0F30`201<92P0501H<3@0G3@h05P`=01882@0C2@X00P0F30d201@:2`0E01L=
3P0L4Q<04@L801H<3@0E2``03PD501H<3@0E2``081HG05aBD`0C2`/040H701XA4`16@480>C<e01<=
3`0D3Q002@@501@>400E3a404`d?008050h@00@04P`>01H>400F2`l050T=0`0H3A404`0E2Ph05``@
01T>4P0T6Ad0714E01H<3`0C3@l05Q8C01@@4@0C3a005Q8C01LC500=2@X04Ph?01HB4`0D41405Q8C
01XF5`0G4a@00P0F4Q<01P0E4A805Q8C01PC5`0F4AD07APL01dH7P805a8H00<05a8I01HD6@0F51L0
0P0F51L0;00H5QP061HG01TG600G5AD05aHD01TH500K6QH06QTG01XJ6P0H61X06ATK01`L7P0N7R40
7AhR01`M8P0L7R<07B0U01hQ:00N8RT07R<Y01dQ:P0N8R/07b</01dT;00P9bl08RTa01hW;P0O:2l0
8R/b028]<`0S;S@08B`b020]<`0S<3H0:3Dk02Tf?00X=C/0934g02Db>00X=C/09C8h02Xg?@0P;C<0
:SLm0P0Z>Ch09P0^?D80:CPm02ln@`0[>Sl09cHk02`k@00b@DH0;Se202dl@@0b@dX0<dI?041CH@16
FFX0C5if04=DK`17F7@0AUMb03M9HP0dAU`0=dYI049FH@0gBe@0>TaF03M9D`0cADl0=4I@03=6C@0_
@TT0<dI<03M:D00cAT/0?4mC03iAE@0kCE<0>DYB03E6CP0fAdl0=dQ@0P0eATh0200kC5@0?4eE03Q9
D@0fAdl0>DYB03mAE00eB4H0;T4o100bAD<08`0`@d40<DA20354@P0aA480=TU703M7B@0a@4D0<T56
03Q7C00iB4d0<T5603M6B`0lBe00=DA903=2A`0d@dP0<45503]>E01ZOh@0<TE;02m2B00eB4h0;d17
0311B00_@4L0<3m603=2B@0d@dX0;S]30391AP0[>Sl0;Ca102He>P0X=c`0;CY00080;3Lm00X0:cHl
02`e?00]=Sd0;cPo02/d?00[=3d0;3Dn03]5CP0_>D80:38k0P0]>T<0<@0Z=d009S@n02Xi@P0/>T@0
;SY903A0C`0f@U00=49=030nB00Y=d00:3Ho02Le@00T<Sl08c=202DeAP0Z=TH08BLc02@Y=00P9cH0
9bi003DnD`0c?U<0;3M<01LQ<P0Z<d005ahX02hc>@0V:bl06QhW01lV<00K8R`08RTc02<Z=00d>dD0
7RD_01`S;@0G7RP0:C0j07AkQ@1?De`071lT01lP900N7b<06AXN01`M8P0R8bP07QhV01dM9@0L72@0
0P0K6bD03@0L72H081lW024P:00R8BT0;B`d02DT;00K6R807ahV028Q:@0Q82P07ahV01hM9@0M72@0
0P0O7bT01`0M7BL071`V01dM9`0N7RP0JFUc020P:P0E5Al00P0N7RP03`0R8R`0EUAO07QfP@0S8B`0
8B0X01`K8`0b<CP07A`R01TH7@0H5a`06aXO01dL8@0M72<07Q`W020N:@0201hL9`03020N:@0J62<0
5aDP00<06QPS00h07adX024P;016AU807al[01`L:00A4Ad07AdY05=CG`3Gemh0Kfmk02d]>@0J6RH0
3PhJ01/J8`8061DL0P0G51/0100F4aX05a@L01PE7P0G51d301HC700301TD6`0H4aX061<J00806QDL
00@05Q4H01PC6P0G4QT061<J0P0I51/00`0H4aX05A0F01D@5P0201D@5P0401HA5`0G4QP050lE01@?
5@805A0F00@050lE01<>500D3Q8050hB0P0E3a<201@>4P<04`dA00L050hB01D?4`0F41@04`dA01LA
5@0B31003`T=00804`dA0P0D3Q802P0C3A404@/?018<400F41805a4B01HA4@0E3`l03PP801LA4@0@
2PX401<=3@0901D?3`0F41005@lA01<>3`0C3@l03PT:01@>400N61X04P`>00<04`d?00<04P`>014;
3@0B31000P0B3103014;3`0K018<400@2Ph04`dA018<400A2`l05@lC01D>500H4AH05@lC014;3@0H
4a@040X;014;3@0C3A4050dD01@<5@0A2AD04@TD018=500E41H04PdC010;4@0F4AL06aHL014<4P0C
3Q@04PdC00804@`B00L04`hE01lL9P0C41/05A8M010=600>2aH04PlJ0080514L0`0E4Qd01@0E4ah0
5Q@O020N:@0I5b807Q`W008081hY00H08AlZ020N:@0N72L07A/V020N:@0Q82/2020P:P0B01hN:00L
72H07AdW024Q:`0J6R@05aLQ01/K9@0H62807AdW02HU;00M6b005aDJ01XH7@0I5a`05aDJ01XH7@0H
5Q/05aDJ0P0F51T04`0D4QL05Q4E01dH700F4AD09B0T01<?4P0E41@0:RDY018=4@0D3a<04`hB00`7
2`0C3Q803@L902HP8P0<1PP06Q@F010:300D3Q000P0A2`d01@0@2P`03`T;010:300A2`d04`T:0080
4PP900D04`T:01@:2`0D2P/05P`=01061`030147200301D;300A1`P04PP900<04`T:0P0B20T201<9
2P804PP901d04`T:01@;3@0m<cH0YIZN01/B500C20`03@@601<8300@1@T05P/?01872`0;0@@060dA
00d21P0>10L06PlC00X10`0C20`050T=00d21P0C20`05@X>00h31`0G31002P4301862P0?0`L03P86
01452@0401862P<04`L;00D04PH:01872`0B1`/04PL;01<8300201D:3P0@01872`0@1@T03`@80105
2@0B1`/05@X>03P]<@0>0`L05P/?01472P0B20/05@X>01872`0C20`04@H:00l4208040D900@04@H:
01872`0A1PX04@H:0P0?10P201052@804@H:01X04`P<0148300=1`/03`H;01883P0C20h04PD<01<8
3@0@1@X03`D:01H<4@0=1PT05Q0D00d52P0@1PX04@D:01D82P0F20P05@H601D6200A1@P04@H;018;
4P0810h030TC01<=508050T=0P0@1@T00`0D2@d04PL;01872`0201<8300A01872`0@1@T05@X>0187
2`0A1PX05P/?01L<400A1PX050T=00X00`0F2`l0:AhR01872`0C20`060dA01H;3`0D2@d00P0C20`0
0`0A1PX04PL;01872`0301462P0I01462`0:0@L08QHP01053@0?10`04`T?01P?4`0A1P`040H:01H;
3`0;0@@04`X<01462P0A20`040H;01P=4`0E2Q003`@:01@93`0@1@/04`P>01052`0A1P`050T?00l4
2P0Dooooo`006oooool0:`0D2PT04@L601061@0>10<05P`;02TO7P1eJfX05`d=02@J6@0O5A@04@L6
01491`0G3Pl02@<300h8200O6AT030H600l92@0500004@/;028L702:Q8@07ALG00L10@0E3@d0=B//
05M=CP0<0`@09Q`M0147200C2@X02P0100`20`0E2``04PP900X00@0=0`@07A<D034W:00W7Ah03@<4
00`20`0B20T00P0A1`P0100B20T04`T:01@:2`0C2@P201881`0901<9200D2PT05@/:01H<2`0@1PD0
3P@301881`0F30/05P`<00804PP901d050X;01H<3@0E2``04`T:01D;300F30d05@/<01882@0C2@X0
6@l@01dC500D2P/04@L801L=3P0E2``05`d>028H6@07000060h?00L0000M4a@040L900`6200D3Q00
5@lA01@>400O6A/07ALI01@>4003018<3P0A010:300D3@l050/>01@;3P0I41<05`hA01H=400E30l0
50/>01T@4`0X7b807QDH01H=400D3Q006ADF01PD5@0K5aP00P0E4A800`0J5QL05a<D01@@4@0301DA
4P805Q8C0P0E4A80200F4Q<06A@H014<400Q72008ahT01HA5`0H4aT05a8I0P0E4aP09`0G5AX061HI
01PF6@0H5QT05aDF01DC4`0E518061LE01/J600J6AL06QXJ01XJ700L71h07alQ020P8`0N7b<071dR
01dO900M82D07R4X01lS:@0M8RP07b</024U<00P92l072<]01hU;`0Q:3808b`e024Z<`0P:C8082Xc
024[=00O:C807R/c01dZ<P0O;3@08Rlg02@a>@0202<`>00902llA00L:C409c@l02Hc>`0[>4009cHm
02Xi@00a@4L0:SU00080;ci500/0:SU00391B00[>T40;Se403A3BP0]?TD0;d9;0354DP0bAE@0>deR
03]<IP0204AEK`0703i@IP0dAUX0?U5P04YNJ@15FF80>TaF03]=E`0203U;E@2?03A7CP0]@4L0=DQ>
03a?E@0bADX0>diB03a?D`11DeT0DV=[05AUK@1:Ff<0?DiF03U:DP0eATh0=TM?03a=E@0jBe<0<dA<
03A5C@0lCE80<TA402Xl?00eAdL0=TQ803E7A`0fB4P0<dE50312@P0]?cl0;T100353@`0fAdP0=4=8
0391AP0eA4T0=dI;03=2A`0oCU<0A5=H03A3B00]?440<D1503A5B@0Q=3X08CHk02Tl@P0[?T@09cY0
03A5C00]?TD0:ca3030oAP0c@TT0<T5802dj@P0Y>3d093<h02/j?`0/>d00<d9703e:D00]>3h0;3Lm
02Td>P0Y<ST0:c@k02hg?P0e?TD07RL^03@oA@1WLWP0=T5702llA00H9Bh06bLc02lmB00T<Sl08Bll
02PhAP0a?Th0=D9B02lmBP0]>dH0;C]502Dc?00S<CX08c4k02@b?`0V<d<0:CI702`hB00N930092Te
01dS<@0O9SP0:314028Z?`0L93T07BDe01TQ;00O9S006R0U02DZ;P1fNh406alX01hR:`0X;3D0=SY3
02lc?00J7RL07b</02@X<@0E6B80?T9;014F700J7B805aPL01/L800L7B407QlT02<T:@0K6b<07AdU
01`L900J6R@07AdW01lO:@0L6b8071/Q01HE6`0Q82H06QTO020O9@0M728071/Q01hM8`0O7R@07QdS
01hM9@0P82X07AdW01/K9@0M7BL00`0N7RP03@0O7bT0:2Pb01hN:00>3QP04Q8L034_>P0i=d80:2Ha
01HE7@0Q82P07A`S020O9@0L6b000`0K6Ql02@0K6R4071XU01XH8`0L6RD0928]028P:`0J62<071XU
01dK9P0201TG8P0>024O:P0Y:3<0Fe]U028R;00B4Q`05ADO020P:P0/;3H0U9BN03loB@0a<C/0820Z
018B700H5R0201PE70805a@K00@05Q<J01LD6`0G51/05Q<J0P0E4QT0100F4aX05Q4H01D@5`0F4AP3
01PC6P0601TD6`0H4aX05Q4H01HA600H4aX07APO0P0C3Q@201D@5P805Q4G0P0E41H201LB60805Q4G
1P0D3Q80100F41@05@lC01<=4@0A2`l2010:3P8081XN00L05Q0D018<400D3Q8050hB018<400D3Q80
4`dA00804P`@00/05@lA02<M7`0?2@T03@L700X4100@2PX081XJ01D?3`0D3Ph04@/;010:2P0200l9
2@0501LA4`0<1PP071HH01/E5`0;1PL00P0H4Q@01@0E3a404@/=010:300A2`d04`d?008050hB00H0
4`dA018<400A2`l04@/?018<400@2Ph2018<400901PB5P0O6R005Q<M00/:4P0:2A403@/A010>4@0=
20`040/?00804@XA00X04`TB01<9500@21<03PT@01@?5@0C3Q@03`X@01<>500H4aT04@`B0P0B3A<0
1P0@2a404@`B018=500C41T04@hG01<@6@804PlH00@0514J01<@6@0D4AX0514J0P0E4Q/0200L6R<0
2PTA01lN9P0Q82P07QdU01/J8P0P7bL071/S0P0N7BD02@0L6b<07A`T01lN9P0P82P07alW01`L900I
6B406QXR01dM9@0201PH800901`L900K6b<08R8Z02`Z<P0Q7b@06aTN01dK800K6Ah05Q@I00<061HK
01H05A<H01@B5`0D4QL04`hB01`G6`0<1`/0=S4e01/F6P0B3A4050lC00T4200D3a<03PT=024L800D
3a<07QPJ02PR900G4A<07ALI028L7P0;1@L04@/=0P0@2P`0400?2@/040X<014;3@0B20T05@/<01H<
3@0A1`P050X;028H6@0a9bP06a4B01882@0D2P/04PP900h41@0A1`P301<92P0301882@0A1`P04PP9
00D04PP900T06@hB02LL800g;3004`P<00h31`0H3A4050T=00l4200G31000P0F2`l03P0/8BD0:AhR
02@I7@0K41@0304500l4200C20`03`@801052@0B1`/03P<701@93@0@1@T04`L;0P0?0`L0100A1@T0
4PH:01862P0D20`501<72`0301872`0A1PX04@H:00804PL;00@04`P<01462P0D2@d050T=0P0B1`/0
1`0D2@d02@0200`11@07000050T=00/0100B1`/00P0A1PX0<00?10P03@8600l4200?10P03@8600l4
200C20`04PL;01462P0?10P03@8600l4200B1`/04@H:01052@0@1`/030H:00d42@0B20h03@8800d0
1`0=0PL0300601D:400C2@l0;bH[00d72`0A2Pd040L:01052@0B1`P050P801871@0?10<03`<501<8
300?2@d01@0600`9400G41H040D900h31`0?10P040D901<8300A1PX040D901462P804`P<00d03P<7
01<8300B1`/05@X>01/@500J3a<040D901D:3P08004050T=02XO8`0@1@T04`P<00804PL;00<04@H:
00l4200?10P01P0A1PX06@0A1P/05@XB00L01@0S6200IEYR01463@0<0@L01`0201H;400;00@0>c0d
06EJGP070000=2T_01<83P0G31804@H<00h32@0A1P`040D;01873@0A1P`04PL=01@93`0>0`T05?oo
ool001_ooooo01T04@L601@:2@0H3Pd05P`;01<9200I3`h04@L600d4100X7Qd09Q`K020F5@0<1080
4@P900`61P0400003@L7020J6P0F41003@L701H@40060000@cdm00P20P0A2`/04`T:008050X;0100
4@L801<92P0:00404`T:01L=3P0D2P/04`T:01@:2`0B20T04@L801D;300O5AH06Q0A01061`0A1`P0
50X;0P0C2@X00`0D2P/05@/<01H<3@0301881`0301@:2@0E2`X05P`;00<050X900T04`T801881`0C
2@T04`T:01882@0D2P/05@/<01<92P0E2``00P0I3a00600D2P/03`D600l51P0D2P/060h?01@:2`0C
2@X06Q0A01H<3@0=0`@06Q0A00l51P0S6AX06@l@01lE5P0B2@/03PP:01D?4@0;1PL03@L901D?4@0>
2@X05Q0B01<=3`8050h@00D04`d?01D=400E30l06A0C01XA500201H=400B01<:3@0?1PT04`X=02DL
7`0I41<04@T<01TC5@0B3Pl06QHG01@@4@0;1`P0510A01DA4P0A3@h04Ph?01@@4@0B3Pl04`l@0`0F
4Q<02@0G4a@061@E01XE6@0?2Ph06aHJ01lJ800G4QP061<I01D@5`0201<A5P0:01DC600E4aH05A<F
01@B5@0F51D05A<D01LF500I61H06aXH01TH5P806QXL01H071`N01lO8@0O82<071dQ01`M8P0K7B80
6QdR01XM900K7bD06QlU01hR;@0R9S408BD`01`S;@0N9Bl08bXd02@]=P0S;3D082Tb01hX<@0P:S<0
8B/d0`0O;3@03P0P;CD0934i02Ld?00L:C40;S]301l/=00W=3`0:SLo02@a>@0U=3/0:cY103E4B`0[
>T40;Se40P0_?TD04`0`?dH0:SU00350A`0hAdh0<D9903=6C`0aA580;d9A03M:G00iBf<0@eE]045C
J`11DfL0>4]L03U=FP0kCeX0?E5J03Y<EP0lCUP00P0jC5H0700fBE00;d9903U<DP0lCeD0=4M<03]>
DP0iC500<49803M8D00nCeL0=TM?02Xk@`0[?4@0<45903E6CP0kC5@0?4eE03I7C`0dADd0=dQ=0312
@P0Z?3`0<TA403I8B00dATH0=DM703=5A@0`@T8202do?`0402m1@@0b@dD0<T560350A@80<T5606X0
<3m403I5BP0gAT/0<T560350A@0c@TL0<T97045DFP0S>3d0=dY@02i1A`0P<cT0<dA;0352B@0_@4L0
=DA;03A3BP0]?4<0:SLo02dl@@0W=S/0;Ca102Xi?P0^?D80=45702lj@00]>3h0:SDk02Tb>@0Z<cX0
;CHm03@m@P0J8bP09c8h05AOI@0Z=C/0;ca403M3C`0K9c<07bdj01`Z=`0Q;Sh0;cm?038oD00d@E40
:3I302Dc@00Z>480938k020^=`0S<C/09cE002Te@`0Y=DD0:S=201lU<@0T:CD08bTg02L]?@0^=DL0
;CE801/R=@0N9CD031@O02<Z=00Y;c@0CE9F08N<TP0T:3409BTb01lS;00X;3D0720Y01DI8P0J7RL0
5a/T02da>P1_Lg`08BH/01/L8@0H6Ad08R<W024R9P0J6b0071dR01/K8`0N7RH07AdU01/K9@0N7RP0
8R8Z01/J7`0T8bT02@P=02@S:@0W9R`07QdR01`K8@0I61h07A`Q01lN8`0M72807QdS02<S;00O7bT0
7QhX0`0P82X03`0I6B<06QXT01PH8P0>3QP05QHP02PX<P0I5b805A<N00L5400N7BD02`XB024P9`0L
6b406QTN01`K800201dL8@0801`K8P0M6bH06QPS01/I900W9C008b4/01LE800H5R4201dK9P0?01XH
8`0K6B@07QdW034a>`0>3QP071`V01PH8P0E5Al05QHP01lO:@0<31H07QhX01TI8`0d=3h05A8L00<0
5a@K0`0F4aX01@0G51/05Q<J01@A600D4AP05A8I00804PdD00D05A0G01PC6P0J5A`07APO01LB6@03
01PC6P0401/F7@0S7RD04`hD01<>50@05A0F00@050lE01D@5P0F4AL05a8H0P0F4AL01`0E3a<050hB
01@>4P0C3A4050hB01D?4`0G4AD00`0F41@01P0G4AD0618F01PB5P0J51P04`dA010:3P805@lC00`0
4P`@01@>4P0D3Q804P`@01<=4@0D3Q806Q@F01LA4@0E3`l06aDE00h8200F410201D?3`804`d=00l0
50h>01D?3`0<1PP06aDG01LA4`040000:bDW00`6200@2P`04P`>01@>400C3@l04@/=00l92`0D3Q80
0P0C3A401@0B31004@/?014;3`0B31004@/?00804P`@00T06Q@H028M8`0G62<05aTU01@D7P0?3aH0
1`H;01@B5@0A3Q400P0C31<0100E2a@05@/F01D;500=1`h2014<4P0600l:400@2a404PdC010;4@0B
3A<04@`B0P0@2a400`0B3A<020D>00/84@0201@A6P803@XC0P0C41T02`0E4Q/05Q<L01HC700F4a`0
3@`D02h]=@0A41P061LO01HE7@0E51`061LO008071/S00@061LO01LF7P0I62006a/S0P0L72@01@0J
6R8071`T01TI8@0G5al06ATQ008061PP02407AdU028P9P0J61d05Q@I01/I7P0J61d06ALL01HD6@0G
5AX061HK01DC600D4QL05Q@I028M8@030080>SDi0:bWZ`0I51P07aXN01dH70080`L05a8F00L21P0E
41@03PT=01/E5`0@2P`03`T;038/;P1<ATP0618D00l92`0@2P`00P0A2`d2010:300=01882@0E2``0
50X;00h41@0?1@H06Q0A02DK700B20T03@<401882@0C2@X04@L801882@0301<92P0501882@0@1PL0
4`T:01882@0A1`P00P0C2@X01@0A1`P01`0001@93@0C20`05``@00804@H:00<05``@01462P0B1`/0
0P0@1@T0200N4aL09Q/O02HK7`0H3A403@8601052@0F2`l05@X>0P0A1PX01P0>10L04@H:01872`0E
2@d04@D9010420804PH:00<04@D901<72`0B1PX0100A1@T0100A1PX040D900l4200@1@T201462P0?
01872`0E2Ph04`P<00h31`0=0PH03`@801@93@0<0@D0714E01D:3P0M4QH01`0001462P0B1`/04@H:
00803`@800P04@H:01052@0@1@T04`P<01052@0?10P04@H:00l420804@H:01d040D900l4200>1@T0
30H:00l62`0A1`d03P<901032P0I31<0200200T0100m<cT0j=oT02`V:P0?1`/040L:01061`0A1`L0
4PP701871@0C20L03`D400X10P0@2@`05Q4E01D@5P0A2Q003@8600`21@0201872`804`P<0P0@1@T0
0`0B1`/04`P<00h31`0200l4200@01<8300H3A405P/?00d31P0H3A402P0300`31@0H3A402@0201@9
3@0>0`L040D901872`0C20`05@X>01/@508040D90`0A1PX06@0B1``05@XB03<W<@0h;CD09a`T00`3
200L4AL03`@:01072P0@1@T0304501hE5`1eJVh0IEYP01`A5`0C20h03`@:01873@0<0@L03@880187
3@0A1P`040D;01873@0=0PP05?ooool001_ooooo00@04`T:01882@0G3@h060h?0P0B20T09@0E2``0
4PP900d41@0A2@T04@L801482@0E30l05Q4B07miN`1LEUP07ALI00h82P0D3Q0081XL01dG6@0=20T0
2`D700h82P0E2``04PT:0147200F30d04@L801<92P0H3Pl09adN01dC500@1PL04PP901H<3@0C2@X0
4PP901061`0A1`P04`T:01882@0C2@X00P0B20T00`0C2@X050X;01D;30020147200>01882@0D2P/0
5P`=01L=3P0D2P/05@/<01@:2`0C2@X04PP901H<3@0G3@h05P`=01L=3P0F30d201<92P805P`=01T0
50X;01882@0C2@X04PT:01hD5@0Z824060h?01@:2`0L4Q<05`d>0147200A20P05P`=01X@4@0F30d0
4@P:01LA4`0A2`d04`d?018<3P0<1`P05Q0B01@>400A2`d04P`>008050h@03004``>01H=400P5aX0
7A@G01D<3`0G3Q407A@G01H=400H3a80:R4T01hE600F3a405A0B01@@4@0F4Q<07a/L05QDE@0F4Q<0
3`/<01LC500T82407ATJ014=3P0H51D05A4B01HB4`0I5AH06QHG01/G600K5QX05Q4E01@?4`0E41H0
6A@J01XE6`0I51/05A<H01HD6@0G5AX05Q@I01DC5`0C4A@05aDH01PF5`0J61T071/J01/J600G5QD2
01TI6`3Q01/K7@0L71h071`O01PI7@0Q8RL07AlT01XM8P0I72<06QhU01/P9`0I7BP07b<^024U<00N
9Bl08RTc02T`>P0O:3408R/d020Y<P0K9Bh07bTb02La>P0M:S808c0h02Db>P0S<3P09S<k02/h@00W
=3`09S<k02/h@00R;cL0:cQ002Pe?@0V=C`0;ci503]:D@0/>d80:CPo02/j@@0V=C`0;3]204QGGP17
EUd0;ci50311B00a@dd0=4IC03=5E00gB5X0<T=F03M8G00oD6@0?4eP03m@H@0hBUP0<49=03U;E@0j
C5H0=TQB0394CP0eAe40=dYA03A7CP0fBDl0=4M=03A7C00hBdl0<dI:0312B00eATh0=TM?03=4C00b
@d/0=TM?03M8D00eATh0=TM?03U:DP0hBE40=DI>03A5BP0fB4P0<dE50353@`0gBDT0=4I602i0@00]
?cl0:cdm02Xl?00[?Cd0;3hn02`m@00`?d@0=DA903I5BP0b@DH0<d970391AP0a@4D0=4=803I5BP0c
@TL0<41502i1A`0Z?d@0;3m502Pk@@0/?dD0;d1702Tj@@0[?4<0=DA;0350A`0W=Sd0:SLo02ln@`0Y
>3d0;ci302Th?@0[>Sl0;3To034l@P0`>d40;CPn02`e?00Z<cX0:c@k02Xe>@0d?d409S4e028_=@0[
>3l0<Sm807Z8T`0lBUH0;ci<02dmC00X>4P0;Ca>02llCP0a?Th08S0m01l]>P0W=3h08Bhf01/X<00S
<3P0;3M202dg@`0W<Ch08BXh02P^>P0S9c8092Tf02<Y>00U:c`0<3M8024U=`0T:SP0:2lj028V<00L
8BH08BHZ028W;@0M8BX08BD^02<W<00Q9Bh07b</01HJ8`0L82T08BD^020T;@0M8BX061`S01hO900K
72007b0T01XK7`0Q8RL0<C8g01lO9`0R8RX0820X01/K9@0M7BL08B4Y01dN8@0X:B`05aPJ024R9@0O
82<07AhP024R900J6ah07QlQ01hO8P0K71l07AhR020P:@0L72H07AdW020P:P0M7BL06a/U01dM9`0I
6B<05ADO01dM9`0H62806ATS01LE800W9C00<c4l01`K8`0O7RH061LN01/J800I61d06QTN01TH7@0G
5Q/05A@K008071XU00<05Q@O01hL9`0N72L00P0I5b8401PF8@0=01TG8P0K6B@05Q@O01lM:00/:SD0
7adX020N:@0J62<0518M01LE800H5R40928]01@A6`0301HC70805A8K00<05Q<K01HC6P0E4QT00P0D
4QL0100E4aP06A@K01TD6`0I51/201LB6@0=01TD6`0D3aH05a8I01/F7@0G4QT05A0G01HA600D3aD0
5A0F01HA5`0E41H050lE01<>5002014<4P0601<>500D3aD050lE01@?5@0F41@05@lC0`0C3A402@0F
41@04P`@01<=4@0D3Q805@lC01PB5P0J51P04@/?01H@5002018<40805a4E00<04@/?01@>4P0E3a<0
0P0C3A401`0D3Q808QdN03H`<P0:10H071HH01<=3`0A2`d00P0D3Q0201<=3`0>01D?4@0F4180618D
018<3P0C3Pl05a4C040j?00E3a404@/=010:300?2@/04P`>01TC5@0N61X6014;3`0=01<=4@0D3Q80
5@lC014;3`0D3Q806AHM071cP@2CV:H08RLc014C700P8BL05QHK010>4`02018;4P0401@:4`0E2A<0
5@/D014;4P803`X@100@2a406P0B3A<04@`B00l:400@2a404@`B01<=5P0D3QP05Q0J01PB700G4A/0
4`dG018<5P0C3AL05Q0J01PB700I4ad05a@M02h[=01SH6T05a@M01/H8@0R7bP07Q/T01`I8P0M6R<0
71TR0P0H5Ah01@0I5al071/S01hM9@0M72@06QTQ00806APP00h092<[02PW;`0J6B4071/S01/J8P0G
5Q`05Q@I01LE6P0J61d05Q@I01PF6`0C4AH05Q@I01PF6`805A<H02D06ALL01D@500P6al04@`@01XE
6@0?2Ph071LK01D@500:1@T05a8F01D@5014?d<061<G01lI6`0R71h04`d?01LA4`0S7Al07aTK00d7
2@0?2@/04`d?01@>400B30h03PP:01D;300C2@X05@/<01X@4@0I3a004@L800h41@0@1PL05@/<01@:
2`0A1`P05@/<00@04`T:00<04PP901061`0D2P/00P0A1`P201<92P0301061`0D2`d04PL;00804PL;
0P0E2`h0500@1@T04@H:01052@0@1@T04PL;00l4200:0@<05`d@01462P0@1@T04`P<01L<400D2@d0
4@L:01<8300A1PX03P<701D:3P0I3A4050P<0P0C1`/0100B1PX04@D901L;3`0D20`201<72`8050P<
00@04PL;01462P0@1@T040D90P0A1PX05`0@1@T04PL;01052@0?10P05P/?01dB5P0V6al07Q<G01dB
5P0K41@03PD701T>4P0C20`05P/?01L<400D2@d04@H:01<8300?10P03P<701872`0>0`L03`@80080
5``@02T04`P<00l4200@1@T04`P<01<:3P0@2Ph03`H;00h42@0D2@l050L>00h3200I31<04@P<03L]
<`2@Qh`040X>01<<3`0@1`P03PD601071`0A2@L04@P800l71P0C2`X04@P900h7200L5QP06A<F0107
2`0>0`L04@H:01<8300@1@T04`P<01P=4@0C20`03`@801<8300E2Ph04PL;01462P0201872`804@H:
00d04PL;01052@0=0PH040H901<8300>0`L04@H:00l4200A1PX04PL;01052@0B1`/06@hB008040D9
0P0A1PX06P0B1`/04PL<01053@0H31H04@L>01@:4@0]8RT071<G01<83P0]8bL050T=01dB5P0S6A`0
4`X<02HK8@0B2@d0<RL]024F700C20h04@H<00l42P0I3Q@060dC01@93`0E2Q0050T?5?ooool001_o
oooo02/06@l@01<92P0B20T04@L800h41@0C2@X06a4B00d41@0P5QL03P@500l51P0C2P/04`X=01LA
4`10>S`0>C<e00`7200B30h02`D700h82P0P6Q`03PP:00X41P0;1@L04`T:00X00@0>10D04PP900d3
100A1`P040H700`20`0?1@H06@l@01L=3P0A1`P04PP901T?400B20T03`D601<92P0H3Pl040H70080
50X;01404@L800l51P0?1@H06Q0A00d3100@1PL0718C028H6@0800004PT:01<92P0L4Q<0308301X@
4@0>10D040H701882@0201L=3P0?01<92P0A1`P04`T:00P0000C2@X060h?00`20`0@1PL04PP901D;
300C2@X04@L801<92P0F30d05@/<00805P`=0P0G3@h04P0F3@l040X<01<=3`0F41802P@601@>400Q
6ad01`43020J700Z92H02`D701/E5`0H4Q@02`D701<=3`0E3a406aDG014;3@8040X<00X050h@024K
7@0H4Q@06A<E024M7P0:1PL061@E03Te=P1cKg007QXK0P0B3Pl0100O6a`05Q8C01<?400G4a@301PD
5@0:01HB4`0E4A804`hB01XE6@0I51P050lE028M8`0Q72805A0G01@A60806AHM00T05aDJ01/I7P0G
5AX030X=01LE600F51D07A/L01TG600F51D00P0M7Al02`0L71h06a/M01/L7`0K72007b0U01`N8`0N
8BH07B0W01XN900M8BX06alZ00807R8^01405Q`X03HlB02LXZh09blj02@/=`0I8B`0<3Y401dW<@0]
=d408c0i01l/=@0W=3d072Tb02Db>`0T<CX0:cQ103I3C00202Db>`0601l/=@0V<c`082hg028`>@0U
<c`0:3Ho0P0Y=d00BP0[>D80;Sa502`j@`0b@4T0;3Y30311B@0a@dd0=dUE03Y<FP0[?D`0=dQH041A
H@0lCEh0?e1P045CH@0fB5D0;d5;03E7D@0bA4h0;T1:03A6D00cADl0<DA;03A7CP0fBDl0;d9803A7
C00bADT0;d9602/m@`0`@DT0>DYB03M8D00`@DT0<D9:03U:DP0/?DD0<dA<03I7C`0_@4P0>4UA03Y<
D@0Q<cD0>D]=02do@@0mCe40;Cm10312A00bA4H0<dE702do@@0[?Cl0:3Xl02Hg>P0V=CX0>dY?03U8
C@0T<cP0;Ca103E4B@0fADX0;ci303=2A`0Z>Ch0<D5602Xm@`0R=c`0;d9802`oA@0`@dT09cPo0311
B00^?dH0;ci50P0a@4L0>P0/>D40;ci30350A@0c@TL0;Ca102Xi?P0/>Cl0;3Lm02Td>P0X<cT0:S<j
02`e?00c?4<0:3<g02Le>00^?3l08Rle038oA`0Z>440<3i902lmBP0]?D`0;ciA0311D`0a@UD0;Se@
02/iB@0Z>4D0:cU602Tf?`0S<3P0:cHl02@^=P0V;cP0:30k020X<`0E6bL06Al[01hS;`0M8Bd07b8a
028U=00N8C00:bdl02L[>00Q9C007b</02H/<P0T:Bd07b@Z01dP9`0P8bX07b8Y01/N9@0R9B`08bH]
01lR:@0N8BP2024T:`0^01`O9P0P8BH07QlS01TJ7P0H6Ad07AhS024R9`0S8b/08R8Z01lO9`0M7BL0
7alY024Q:@0Q8RD04Q<E024R900L7Al08R<U01PI6`0R8bD06a`N01dN800K71h05aPJ01TJ7P0K6b@0
6ATS01PH8P0I6B<06a/U01`L9P0I6B<05aLQ01/K9@0I6B<05aLQ01/K9@0L6RD0R8JA0?Oeo`0h=cl0
5QDM01LF7@0N7B<07A`Q01PG70805A@I00H06aXQ020N:@0G5B005Q@O02DS;P0@3QT201HD7`0<01DC
7P0G5B006ALR01/I900H5b008B0X01XI8@0L6b<05QDM01TH800P7bL06QTQ0`0H5al04`0F5Ad05A<M
01LD7`0B3aX06QLR00h;5P0K6240514I01PE700H5Q/05aDJ01HD6@0G5AT05A0G01PC6P0K5Qd061<J
01D@5`0D3aH00P0F4AP01P0B3A@050lF01TD6`0F4AP04`hD01HA5`806QDK01005a8H018=4`0@2a40
4`hD01HA5`0J5A/07aXP01hI7`0@2Ph05Q0D01LA5@0F41@0618F01<=4@0B31004`dA0P0F41@0100D
3Q804P`@01<=4@0C3A42018<400302<M8@10>Sh050hB00804@/?00h04`dA01D?4`0D3Q80GUQJ06eW
J@0B30h040X<00l92`0A2`d040X<01PB500J51H05Q0B01@>4080618D00/04`d?01TC5@0E3a405Q0B
00/51`0D3Q004P`>01<=3`0600805@lA01TC5@02014;3`0H018<400C3A404`dA01<=4@0E3a<03PP<
01LA5@0?2@d02`D901/H7`2KWjd0];[802L]>@0@4Q`08B4Y01<D6@0?3A804``C0109400L4Q/0?C4k
04m5CP0?2@l03PT?0P0?2Q02010;4@0D00l:400D3aD03`X@010;4@0M61h04@`B00d63P0B2a<0<BXb
05A=E@0P6B404@XB01<<500B2a<050dE01H?5`0E3QH04`lF01@A600E4QT401HC6P0S01LD6`0H5A`0
5a@K01@A600B3aH0518I018A5`0E51X06APN01HE6`0L6b405aHL01XI7`0L6b4051<I010?5@0I61h0
71/P01TG700G5AX04@lD01@B5`0B41D05Q@I01<A5P0B41D02PP=014?500F51T05a8F010;3`0E41@0
6A@H014<400C3Q800P0G4QH03@0@2`l061<G02@O8`0F4AD0JVAV03La<`0D3Q005a4C010:300H4Q@0
4P`>01<=3`0D3Q000P0A2`d0300D3Q003P@500l51P0G3@h0GeEF02PN7`0=0`@07aDF01@:2`0B20T0
6Q0A01061`804@L800H060h?01@:2`0D2P/04@T900l51P0D2P/201H<3@0700l51P0G3@h04`T:01P=
4@0F2`l050T=01<8300201872`0:01462P0F2`l05P/?00X00`0G31003P<701052@0>0`L05P/?00l4
20<04`P<00l050T=01D:3P0=0PH04`P<00h31`0D20`04@D901862P0E2@d05PX>01D93@0C1`/03`<7
01<72`0D20`00P0@10P0100A1PX05P/?01<8300@1@T200l4200=00h31`0B1`/08QLK00d31P0F2`l0
2`0401lD600T6Ad04@H:01/@500900804`P<00l4200201L<400301052@0=0PH040D900804@H:01l0
3`@800h31`0@1@T03`@800T00P0J3a<03PD702DJ7P0700005@`@018<400700<04`T?00l42P0G2Q40
4`H=01442`0<0@L06@lE01XA5P0E3a<020<400/51@0P6Q`02`D7018<300?2@/02`D600/51@0<1PH0
3@H600803PD600<03`D801052@0@1@T00`0@1@T03@0Y7R802`0400l4200;00@04`P<00l4200B1`/0
4@H:00l4200>0`L03`@801872`0H3A400P0@1@T0100B1`/0304501872`0@1@T200l4200;01462P0B
1`/04@H:01@93@0C20`040D900l4200@1@T04PL<01463P0A1@l00P0A1Ph01P0A1Pd04@H<00d2200C
20d040D900d21P8040D91P0B1`d601052aCooooo000Kooooo`0>01882@0A1`P04PP901D;300F30d0
4`T:00L0000H3Pl06a4B00`20`0J41401P0000h520080`@2028L7P0E00X41P0B30h030H801PB5008
0P@02`D701/E5`0=1`T040H701L=3P0R61T04PP901061`0G3@h05P`=02<I6P0O5AH040H700d3100A
1`P03`D600804`T:01`08QPI01@:2`0C2@X04`T:01D;300D2P/04PP90147200B20T04PX:01061`1R
F5T0B3ho00X00@0J41403`D60147200H3Pl04@L801L=3P0@1PL04`T:01882@0D2P/05@/<01@:2`0C
2@X0718C0P0E2``00`0I3a003`D601882@0201@:2`0601D;300G3@h05P`=01D;300D2P/05@/<0`0F
30d01`0D2`d02`D700T31@0<1PP050h@02XT9P0/9RP00P0<1PP030060@807QPJ04@n@00a:bd040X<
01@>400@2P`050h@00h82P0B30h05a4C018<3P803@L900X0=c4c00/7200?2``05a<D00D10P0T8240
3`/<01XF5`0E4A8071PI0P0F4Q<401LC500:01HB4`0E4A8050lC00l:3P0G4QH06aHL014<4P0B3A<0
5Q4H010=50805A8I02H04a4F01HD6@0C4AH05aDH01lM800I5aX07A/L01LE5P0D4Q<06ATK01/K7@0M
7Al07QhP01`M800K72008B8W01hP9@0O8RL07R4X01/O9@0N8R/07B4/01XN:P0S9c<09R`h01hT<00i
?d/08BTd01dU<00L92l08bdg01TS;@0W<C/07R/d02hkA00P;CH0:CHo030mAP808c0i00L0=T=<024^
=`0V<c`0:3Dn02Ld?@0U<c`09S@m00809cDn0P0X=Sl0500U<c`0<Cm802dkA00_?DH0;Sa503U7D00f
Ae40>deI03mAG@0a@e00>4YH03a>G00jC5/0>D]I03Y<F00iBeL0=dUC03U;E@0bA4h0;T1:0P0bA4h0
1@0bAD`0=TU@03E8CP0bAD/0<TE:0080;3m300T0<dE;03I7C`0eATh0<T=;03=4C00iBU80?e1H0311
B@0dADd00P0fAdl02`0mCUH0<D9802Xl?P12E5H0<TA602i0@P0W>C/0E6IX03Y<CP0[?Cl09cTk0080
9CLi01X093Dh02He>P0b@DH0=dI;02`k@00iB4d0;ci302hm@P0]?440=DA902hm@P0b@TL0<4=902Xo
A00]@4H0<DA:03Q;D@0lCE@0;d1702`mA00/>d80;ci50350A`0a?TH0:3Ll02Xi?P80:cXo00D0;Se2
02hk@@0/=cd0:SDk02Td>P0202`e?00:02dg?@0_>T009S@g02Ld>P0R;cL0<Sm703E3C@0a?d`0;Ce:
02hnCP80<D9D01/0;CiB02hmD00[>TX0;C]802lmBP0]>T<09c@l02Pc>@0S;C<09Bhg02/d?@0[<Cd0
8bTe01`R;P0P9C408BDa02HY>00[;C`09BLd02<U=00Z;3P08BD^01XN9`0N92X09BX^028U;00M82L0
0P0O8RT02P0K7RD07b8Y024T:`0O8RT07R4X01lR:@0P8bX07R4V01hO900N7b<201/L800F020Q9P0S
92T07alW01lO9`0N7RH07AdW01hN:00O7bL09RLZ01`M8@0P8B<07b0S024R9P0I6Q`07AhQ01XK7`0L
7Al06AXM01LH700J6al071`U01XJ90806ATS01/06QXT01/K9@0M7BL06QXT01`L9P0I6B<05ADO01TI
8`0J62<0BTQC09BBW@0`;cL061LO01`K8P0F5A/02PT>01dL8@0];3407QdR01DD6`0O7BP071XU01LE
800L6RD05aDP01lM:00H5R400P0G5B002P0H5R406ALR01XH8P0E51`05QDM01/J8P1GEUh0FEQP01DD
700J6B4301PG7`0>01HE7@0N72D03``G01HC7P0B3aX06aPS01`I8P0E4QX06QLN01`J7`0E4aP04a4D
01PF6@0J5A/201TD6`0301`G7P0K5Qd05a8I00805a8I01P05A0G01PC6P0M61l06aHM01D@5P0F4AL0
61<I01LB600F4AL05A0F01<>500F4AL05A0F01@?5@0G4QP04`hD01D?4`0I4aL05a4E01D?4`0I4aL0
5a4E018<400C3A4201H@500V01@>4P0B31005a4E01LA5@0H4QH05a4E020J7P0c;C4050hB018<400A
2`l04`dA01D?4`0D3Q804@/=01LA4`0S7Al0208401HA4P0V82803PP:00d72@0<1PP04P`>02dW:@16
@4803`T;018<3P0A2`d03PP:01@>40090`D0208401LA4`0R71h03`T;00h82P0;1@L2014;3`0G018<
400C3A404`dA01<=4@0A2`l03@L;01@>4P0E3a<03`T=01PE700/;c`0>Ca;01PL:00?41T061TN04A3
B00G51T04``C00l83`0C2A808aLQ02/Q:P0A2a400P0A3183018=4`07014<4P0G4QP050lE01LB600T
7bD06A@J00h73`0201D>5P0602HO9`0@2A404``D01<<500A2Q804``D0P0F3aL00`0F41L0514H01@A
600201HC6P<05A8I0P0F4aX0200E4QT0514H01PE700E51X06aXP01PG7@0J6Al05A@J0P0D4aT201PG
7@0F01/J800T8bT08R0V01XH7@0I5a`04a4F01HD6@0D4QL07A/P01LE6P0>31408R0U00`:3`0=3100
=2lc02<N8P0F4AD04`hB00d8300B3A404@`@01D@508040/?00D061<G014<400R71h04@/=018<3P02
014;3@05010:300;1@L03@L9010:300>20X00P0=1`T06`0L4Q<06a4B00d41@0`9RL060h?01D;3007
00005P`=01L=3P0700007Q@E00l51P0>10D02P4201/A4P07000060h?01T?400J41404PP900/10P0C
2@X0:1hO00/10P0E2Ph050T=01872`0401462P0700P00@0@1@T060dA01`A5@0@1@T08AHJ00d21P02
01D:3P0800l4200>0`L04@H:00h31`0?10P0308501L<400E2Ph201D93@8050P<00T05@T=01H:3P0B
1PX040@801<72`0A1@T040@801@8300@1@T00P0B1`/200l4200>01872`0K41@05@X>00L0000B1`/0
CT=701462P0J3a<01`0001hC5`0i;S806a0D00l4200@1@T201H;3`0301052@0?10P04@H:00804@H:
01`040D900h31`0@1@T0714E00T00P0700007Q<G0597B`0P5AT03@@8010:3P0?1P/060hC00P00`0A
10/02`4501L:4@0G318050X@00H00P0F41@04P`?00X41P0400005@lC00h93@0B3A402`H:0P0=1`T0
100>1`L03`H700l71@0@1PL501052@0602DJ7P0@1@T04`P<00X00`0?10P050T=0P0A1PX300l42003
01462P0D2@d04PL;008050T=00<04PL;01P=4@0A1PX00P0@1@T01P0B1`/04`P<01872`0D2@d04`P<
01872`804@H:00<04PL<01463P0A1@l00P0A1Ph0200A1Pd04@H<01<83P0H3A804PL;00h31`0?10P0
3P<71P0A1P`601873ACooooo000Kooooo`0U00h31`0G31004@H:01872`0G3100304501462P0B20/0
6a0D01D<3P0?10P04`X=01<:3`0>20`05a4E01TC5`0B31004@/?01D?4`0A2`l030L:02LQ9@0O6Ad0
30H801H;3@090@407Q@E00d4100C2@X04@L801882@0;0@8030830147200B20T04`T:01@:2`0201D;
30030516A`0a9bP06Q0A00805@/<00L050X;01882@0C2@X05@/<01H;3`0C20`04PT;0080714E00@0
200101@93@0C20`03`@80P0C20`04P0G30l05`d>01<92P0C2@X050X;01H<3@0A20P05@/<01@:2`0C
2@X05`d>01@:2`0E2``04`T:0147200E2``05`d>01H<3@<04`T:00@050X;01D;300E2``05@`>0P0F
41808`0@2P`03@L900h82P0@2P`05@lA01H@4P0H4Q@05@lA010:300A2`d040X<01D?4@0?2@/05@lA
01LA4`0B30h05Q0B01<=3`0F41806A<E03Pb=00G4a@06aLH01@@4@0F4Q<06QHG01dI6P0G4a@04Ph?
01HB4`0C3a0061@E01TE5P0E4A805Q8C00<05a<D03L05a8F01PC5`0E41@071LM00h93`0P6b408A`S
018?600F4a`061DL01DB6@0G51X05aDJ01@B5`0K6Ad0518E01XH6`0I5aT061HG01HF600J6Q`07AdO
01lO8@0M7R406a`P020Q9P0O8BH082<X01lR:@0M8BP08bL`02L[=`0Q93<07R4`02H/>P0N93807bDc
01hV<`0U;CX0?DEB02La?@0U;c/08bdi024]>@1KIg<0;SY602/g@`0T<3`0:SI202hjAP0W<cl08Bdi
04IBGP10C5P0930l00<09cE000L0:SQ302`jA@0]>dH0:SQ302`jA@0[>D@0?D]F0080>DMB0P0fAe40
2`0jBeD0=4E?03I6DP0a@Dd0=dMD03U9E@0fAe40>4UC03I7D@0`@D/0<D==0080;d5;00`0<49<03A7
CP0iC5<0=dY@03I9C`0dAd`0;T550395B@0gBDl0<T=;02hoA`0dADd203]<E01O03I7C`0b@d/0=dQ@
03Q9D@0jBe<0>4UA02hoA@0eAdT0>D]=0312A00cADL0>de?06eoP@0hBT`09cTk02i0@P0/?T00:S`n
02hn@P0hAd`0;ci303I5BP0X=c`0>TU>030oA00eA4T0;Se203=2A`0`?d@0?4eA02`oA@0`ADX0:Ca2
03A7C@0]@4H0<D9902dnA@0[?4<0:cY102hmA00a@4L0=T=;030oA00d@dP0<3m402dl@@0`?d@0:CHl
02Xe>`0Y=3X09c8h02/d>`0/=C`09Blf02Hb>@0P;CD0;3U202dlA00^?4H0<T1;02`lB@0^?T/0<45?
0352D@0_@500:ca>02/jC@0Z>DX0;CY902lmBP0]>T<09c8i02hg?@0Y<CL09B`c02T^=`0Z;SP08RHa
02P^>P0/<Cd0:2`h02HX=@0S93406a/W02<S<00S92l06ahW024V;@0R:2h082D[02HY<00O7bL07QhV
024Q:@0O7bL00P0K6b<01`0L72@06QXR01PH800K6b<07b0U01LH7@0J6al00P0K72000`0M7R<07b0U
01dM9@02024Q:@0C01lO:@0M7BL07AdV01hQ9P0Z;C806QhR01lR9`0J7B806QdQ01TM8@0J7B8071lS
01LJ7`0J7B808RD[01hN9`0L72H06a/U01XJ900201TI8`0I01lO:@0L72H06a/U01LG8@0D51h05ADO
01XH8`0F51l0928]028Q:@0K6R807A`S01dL8P0J6Ah0<c8g03`k@00R8BH061LN01`J9@0K6B@0:BLb
02<Q;00O7BP06ALR01XH8`0201PF8@805aDP00T06QLQ014>5`0R7bP0:RL`0<C1bP38aLh0924Z01XG
800H5Ah00P0I5Ql06@0G51d05A8M01HB800I5B<061@Q02@Q;00<2A8061DM01`I800N7200518E014?
4P0G5AL06QDK01HA600D3aH06QDL01`G7P0H4aX050lF01HA600E41L05Q4H01`G7P0K5Qd0100E41H0
200F4AL05a8H01LB600J5A/06A@J01D@5P0F4AL050lE0P0D3Q801P0C3A404@/?01@>4P0D3Q804`dA
01@>4P805Q0D00L05@lC01<=4@0F41@050hB01H@500E3a<04P`@00805@lC00X04P`@014;3`0C3A40
5@lC01<=4@0C3Q405Q0D01<=4@0<1PX05@lC0P0B310201H@508050hB00d05a4E018<3P0F41804`d?
018<3P0C3@l05@lA01TC5@0@2P`04@/=00l92`0F41805a4C00@04P`@0P0C3A4201@>4P0@014;3`0O
6Ad040X>00`73@0A41X05AHP010?600>31<04a4E01XG6P0E41@04P/B0109400A1a0040HA00l640<0
40/A00h04@`B018=4`0B3A<03PT?01@?5@0C3Q@04PdC01TD6P0?2Q005@hF01L@600>1`l04@XB01D>
5P804``D00L04P/C01@=5@0G41P0614I01H@5`0E41L05Q4H00<05a8I00<05Q4H01D@5`0F4AP00P0H
4aX0200G4QT05a@K01@A600O72<0514H028O9P0=2Q406aPO0`0H5A`201HC6P0401PF700J61d06ALL
01HD6@805aDJ01L04Q0E01dK800S8BH08R0U08V7S00a;c@0;RT]020K7`0D3a<04@`@00h93@0B3A40
3PT=01HA5@0E41@030L;00h93@0@2`l02`D7018<3P0V828050h@018<3P0200h82P0M010:300C3@l0
4P`>010:300A2`d03`D601H<3@0D2P/04@L801D;300@1PL04PP901D;300E3@d0:R0Q02HM7@0H3Pl0
3@D501<:2`0?1PL06Q0A01071`0G3@h03`D601@:2`0=0`@04PT902XP8@0C2@X00P0A1PX07P0@1@T0
3`@801462P0B1`/04@H:02`Q9@0E2Ph03P@701462P0@1@T04`P<01P=4@0A1PX040H901<8300A1PX0
5P/?01462P0F2`l04@H:01@93@0>0`L040@801<72`0A1@T03P8601452@0E2@d05PX>010420804@D9
00l04PH:01H:3P0E2Ph03`@801@93@0A1PX040D901T>4P0=0`H03@86028I6`0B2@/0AS/o01/@500?
1@P00P0B1`/01`0E2`h040L901<8300A1PX050T=01<8300A1PX00P0C20`0500A1PX04PL;01052@0?
10P04@H:01472P0;0P@060dA00l4200I3Q80200100l62P0@2Ph02`@701<93`0<0`L050L>01<73@0@
0`X03@@80P0B2@h03P0?2Pd03`T=01HA5P060PH04@dD014?5@0B41L03@/B00d9400>2@h040T;0148
2@0B1`L04@H81@0?10P01@0@1`T04@P:01L<400A1PX0308500804@H:100@1@T0100A1PX030<501H;
3`0H3A4200h41`0:00l4200B1`/04@H:01462P0C20`050T=01<8300B1`/04`P<01@93@804`P<00<0
4@H;01873`0B1Q000P0A1Ph0200A1Pd04@H<01<83P0H3A8050T=01872`0D2@d04PL;1P0@1@/60146
31Cooooo000Kooooo`0=01L<400U6Qh05``@00l4200G310050T=00L0000I3Q801`0001462P0D2@d0
3@@700d42@0201LA5@0D018<400>20`02`D901@>4P0;1@T05Q0D02@N8P0;1@T040X<0106200i;c00
DdU:01H<3@0B20T06@l@00X10P0F30d0718C01<92P0?1@H301H<3@0404<i>P3Ugn00WYBE02TO8080
50X;01404PP901061`0B20T050X;01D:3P0<0@D06PlC01H;3`0;00@04`P<01052@0D2@d04`P<0187
2`0?10P06@hA01H<3@0201D;300801H<3@0D2P/06Q0A01@:2`0B20T05`d>00h41@0@1PL201@:2`05
01D;300C2@X04@L801882@0C2@X00P0B20T201<92P0601@:2`0F3@l06A<E01PB500A2`d05@lA0P0I
4aD02@0F41804P`>01TC5@0@2P`04@/=01TD5P0?2``04`l@00X61`0200h:2`0;00/7200<20T02`L8
01XF5`0H51D03`/<00d92P0F4Q<04Ph?01`H6@050@800P0@30d0200D41407ATJ01<?400F4Q<05a<D
01<?400D41405Q8C0P0G4a@05@0G4QH07aXN018=4@0L5ad08ahT04I1A`11?4<03``E018?600F4a`0
4a0G018?5P0G51/09R@Y02PV:`0K6Ah071XM01LE600E4aH07AdO01/K7@0201TI6`0G01XK7P0K7200
6a`Q01/M8P0N8BH071lV01hR:00X;3D051PT02DX=`0Q93<07R@b01/Q;`0V;3X06B4^02<[>00oAe@0
82Xf02@^>P0N:3@09S8n02lkA`0M:CD00P0/>4@07`0R;SX08Bdi02Pd@00Z=T80:cM302Lc?`0/>4@0
9C<n02Hd?`0W=D00:cU402dkAP0_?DP0:3I102Xh@`0U<ch0=D=>034oBP0_?DP0=dQB0352C00dADl0
=dQ@03i?E`0eATh0>DYC03e>EP0gB500=DI@041AF`16Ef400P0bA4h01`0_@D/0<49<03I9D00iC5<0
=DQ>0354BP0gBTl00P0iC5003`0hBU00=4E=03E6CP11DUX0AEIN03i?E`0eATh0?4eE03e>EP0iBU80
=TM?0393B`0a@dP0:ce103M9C@020394B00K02do@`0[?D40:C/o02Pj?P0[?D40<49602do@`0/?440
=4=802Dd>@0d@dP09C@i03A3B00fADX0<d9702/j?`0d@dP0>4M<04aLH@0Z?D<0<dQ=02m2B00lCeD0
:Ca202m0A`0[?4<0;3e400<0<3m602X0<Ci602He>P0Z>Ch0;Ca102/j?`0Z>Ch0:CHl02Ha=`0W<SP0
8bhd02@]=00Y<ST09Blg02Pe?P0^?4L0AE=N03m=F00c@Dh0;Si;02De@P0/?4T0<49>02PlA`0W>TP0
<dED02hmD00Z>T/0:SY902dkB00Y=Ch08bhd028[<00T;3408bP^02LZ<@0[;SH08RHa01/Q;@0Z;c`0
9b/g01lQ;@0P7b/202<Q;00802HV<00J7B@09R/a020V;00K8RP092L/020Q9P0L7B8201lP9@0;01PI
7P0F5a`06AXO01LH7@0D5AX05QLL01/L8@0F5a/06Q/O01/L800I6Qh00P0H6Ah0600S8b/09bL_02LW
;`0Q8B/071`V01XJ900T9bh0?T5802LZ<@0R9B`06A`S01hQ:00L7bH06ahU01XM900G6R407b8Y02X]
=00N7RP07AdW01`L9P0K6bD06ATS01PH8P806ATS00`05aLQ01HF800F5R005ADO01dK9P0K6B@07A/V
01TH800P7bL06QTP01dL8P0F5AX200l>4`0701<B5`0J6B005A<N00l=600^;3L0;2Xe02d[=P0201LE
800M01PF8@0I5b806ALR01TG8P0K6B<03@XA02<P9`0G51/08b0W028O9P0J5ah061DL01LD6`0H5A`0
6AHM01LD6`0G51l07QXY01dI:00F4R000@0902h[=00F4a/061DL01HD600E4aH0518C014?4@0D3aD0
0`0E41L01P0F4AP061<J01<>5@0F4AP050lF014<4`8050lF00L04@`B01<>500F4AL05a8H01HA5`0E
41H03`X@00805A0F00<04@`B01<>500C3Q@00P0F41@0100I4aL06Q@H01PB5P0F41@601@>4P0401XD
600D3Q8050hB01D?4`804@/?01h05@lC018<400A2`l04`dA01@>4P0B31007aTM01H@500E3a<0:28V
00/62@0N61`05@lC01<=4@0@2Ph03`T=01<=4@0G4AD04P`>00`6200H4Q@07aTK00h82P0Y8bD03`T;
01H@4P0G4A<04@/=00P2100B30h7018<400B01D?4`0C3A40:B<W01hH700H4QH04@`C01<>500D3aD0
4@`?01PD5@0@2P`03@L9018<400B2a8040TA01<;5P0G3aX03`XA0P0@2a43014<4P0>018=4`0F4AL0
5Q4G014<4P0E41H030L=0148400B21006@lG01P>5P0O5Ad04@L?01@:4P0F31@201/A6@0401P>5P0C
3A@04`hD01@?5@805Q4G00<05A0F01HA5`0G4QP00P0F4AL201D@5P0>01HB600D4QL07adR01@B5`0Q
7b@04a4F01XH7@0G5AX05Q@I01XH7@0K6Ah06ALL01LE6P0F51T201DC600:01@B5`0F51T05A<H014?
500o?D801`D:04a:C`0M6b0030L;00d830804@`@00<03PT=014<400A31000P0D3a<0200A31004PdA
01<>4P0F41802P@6010:300?2@/020840P0C3@l04@0B30h040X<00h82P0A2`d0618D024G600D2P/0
4`X:00L0000D2P/05P`=01hD5@0@1`P07A<D06ILG@0H3Pl01`0000<05P`=00X03P@500h51P0L4Q<0
3@<401D;300I3a002`4200d3100@1PL04PL;0`0A1PX0;@0B1`/04`P<020E6@0T6Ad02P0301872`0D
2@d03@8601@93@0700005@X>02@I7@0<0`D06@hB01P=4@0:00<04@H:01052@0C20`03`@801862P0H
31005`/?01@8300I3A407Q8F01lC5`0>0PH040@801D93@0B1PX04@D901P=4@0?10P04PL;01052@0?
10P05P/?01/@500Z7b<0IU]O01L<400700006PlC01892`0200`11@0701<:300E2Ph0304501872`0A
1PX040D901462P0201@93@804PL;00@04@H:00l4200A1PX06@hB0P0?10P0500B1`/07a@H01P=4@1?
ATX0FeEI01`C600=0`P04@H<01T<4`0C1Pd05PT@01X?5@0<10P0DDQ=018<400R72403`XA00d83`0E
4Q`0BTQC0P11?dX01P0=2Q<03`XA01493P0B20T04PH8014520D03`@800D02@0201@93@0=0`H05@X>
00d21P0701052@0701462P0O51P08QLK01D:3P0D2@d04@H:01052@0200l4200501462P0B1`/04@H:
00l4200@1@T00P0B1`/01`0@1@T03P<801873`0B1Q004PL?01463P0@1@`00P0@1@/01@0C20d040D9
01462P0E2Ph04PL;00H04PL=1P0@1@/Dooooo`006oooool0:P0B1`/0714E01872`0<0@D04`P<01H;
3`0?10P04`P<00l4200U6Qh03P<701@;3P0C2Pl06A<G01D?4`0?2@d04`dA01TC5`0:10P06Q@H00D0
0`0;1@T0208601D?4`0A1`T0<RPY04Hl?@0G3@h040H701L=3P0J41402P0100`20`0?1@H04`T:01X@
4@0G3@h05P`=03T_<039_l00QWam01D;308050X;00X04`T:0147200B20T04`T:01882`0=0PH02@02
00l6200C20`060dA0P0@1@T0100K41@05@X>00l4200D2P`201@:2`0@01L=3P0F30d04`T:01@:2`0=
0`@04@L801<92P0:00404PP901H<3@0G3@h06@l@01D;300A1`P050X;01D;30804PP901T04`T:01@:
2`0D2P/06a8D028L7P0S7Al06aDG010:300?2@/03PP:01<=3`0J51H0618D018<3P0>20X03PT:010<
3@0E4A804Ph?01XF5`0O6a`0;2PY02dY:P0L61T0510A008030P900`05Q8C01/G600E4A8071PI00P4
1@0I5AH0510A01/G600T8240510A01HB4`0E4A8201@@4@<05a<D01D05a8F010;3`0>2@d05Q4G014<
4P0T7bD0:2<Z01<@6@0E4Q/06QLP01LD6`0D4AP071TP028P9@0V92T06QPM01dK7P0H5QT05aDH01lO
8@0L71h00P0G5aT0900I6Qd071dQ01/L8@0L7R<07R4V01/N9@0L82L0:2`e01dQ;@0S9SD082<b02@Z
>00Q9cD0:Blm01hV<`0P:3D09Bdj01HP;00N:3@092hj028^>P0K9c<07BTe02Pd@00/>4@09C4m02<_
>`0X=400:CE102Hb?P0P;3P0;CU502Pf@@0Y=d80:SQ302/iA080:SQ301@0:3I103a:E@0^?4L0:SQ3
02dkAP0gAE00<D9<02dnB00^?dT0=4E=03i?E`0eATh0?4eE03Y;D`0fAdl0=TMA04iOJ@1SM7h0=4I@
03I8DP80<D==00P0=TU@03Q;DP0aA4X0;D1603I9CP0iC500=dY>03M9C`80=DI>00D0>T]C03i?E`0l
CED0>T]C03a=E@0203A5C@0k0311B@0]?TH0=dQ?02do@`0cADT0:C/o03=5B@14EUX0<49602i0A00_
@DD0:C/o02m1A@0a@dL0<D56030oA00Z>Ch0;ci30350A@0[>Sl0<d9703A3B00a@4D0>4M<03=2A`0j
BTl0>4]A03I;D00aA4X0>4]A02Lj@00nCeH0:ca302dnA@0b@DP0<3m602hmA00_?4@0>TU>0391AP0_
?T<0;3]002Dd>@0V<cT09S4g02Xe>`0V<CL08b`c02Tb>@0X<CT0;c]703M5DP15DV40=dEB03A2C`0^
?T/093A102/kB00_@Dd00P0V>TD08P0dB5@0<d=C02hmC`0[>dX0;C]802Xf?`0U<3H08b`a02P^=00R
9bd092L^02/^=P0S9c807B<_02/a?P0X;3P08B4]028Q;00X9S409bD`03/jA00Y;3<0:bhe01/R:00V
;C<08B@Y020Q9P0K72407AhS01lP9@0I6Ql06Q/P01`M8P0K724301TJ7`0401XK7`0M7R807AhR01XK
7`806Q/P01809RH^02TY<@0W9bl08B4[01XJ900I6B<04QDL02DX;`0L7bH06QdT01/N9@0N8BP06ahU
01TL8`0J7B@061/R01`O9P0U:2l301dM9`0M01`L9P0J6R@06ATS01LG8@0H62805QHP01PH8P0I6B<0
5QHP028P:`0E4ah071XU01PG7`0R8BT051<J01`K8@0M72408b8W020O900G5Q/05A@K024O:P0@3QT0
61HQ00h<5`0N72L05A<N01HD7`0H5R400`0I5b80:@0E4a/061DL024N9@0K61l0:2D/00X73P0N6b80
5a@K01HC6P0H5A`06AHM01LD6`0J5R800@0<01hJ:@0/:3L0;R/f0;Fb_@18ADd05A<H018@500E4a@0
5Q@E010>400E41H05a8I01TD6`0G4QT05Q4H01TD6`0E41L06A@K01LB6@0B3A@050lF01D@5`0A3180
4`hD01HA5`0G4QP05Q4G008050lE0P0I51X2018=4`0701<>500E3a<050hB01TC5`0K5AT05a4E01D?
4`0601@>4P0301PB5P0A2`l04@/?00804P`@02005@lC01H@500C3A404P`@01<=4@0D3Q804P`@00d7
2`0G4AD07ALK00X4200D3Q804P`@020J7P0J51P04P`@010:3P0A2`l04`dA01TC5@0D3Q008A/M034[
;@0M5aT0>S@f02DO8@0@2P`030H801hH6P0K5AL06Q@F01<=4@<04P`@0P0A2`l0500C3A4040X>00l9
3@0J51P040X>014;3`0I41D060lD014;3@0;10D03`T900P20P0A2`d050hB018;4P0>1Q004@TF01D=
600B3A@04PdC0P0C3Q@201@?5@06014<4P0C3Q@05Q4G014<4P0F4AL040/A0P0D2Q801P0G3AD02`49
01X@600G3AD05@/C01L=5@806a4I00@05`dE01@;4`0C3Q@050lE0P0E41H01P0D3aD05Q4G01LB600F
4AL05A0F01@?5@805A0F00H04Q0E01HD6@0A3a@0518G01`J7`0A3a@201@B5`0?01LE6P0H5Q/05aDJ
01HD6@0C4AH04Q0E01@B5`0B41D05A<H010>4`0100@03P`A028P9@0O7B805A<H00804@`@00@04PdA
014<400@2`l040/?0P0A3100:P0@2`l04PdA01<>4P0A31007QPJ00`6200?2@/06Q@F01<=3`0L5QP0
5Q0B01D?4@0A2`d040X<01D?4@0O6A/0:AlP01P>3`0D2P/0308301<92P0D2P/03`D601T?400@1PL0
5`d>00T10@0R61T04PP900`30`0@1PL0=R`]01T?4007000060h?01061`0L4Q<05`d>01T?400L4Q<0
50T=01<830804PL;0P0C20`02@0P5AT03`@801462P0D2@d02@0201P=4@070000=BX^01T>4P020105
2@0501T>4P0d:Bd05@X>00h31`0<0@D00P0C20`0400B1PX05PX>01H:3P0E2@d06@dA01dA5@0P51P0
3`<70104200E2@d04PH:0104200E2Ph03`@800d21P0>0`L201052@0@00T00P0H3A409a`P01@93@07
00005``@01<8300;00@050T=01T@4P07000050T=01872`0@1@T03`@801052@<04PL;02<04`P<0146
2P0@1@T04PL;00h51`0<0@D06PlC00`21@0700004`P<07A[K`24OX80;2<X00P00`0>0`T070lF0144
2`0?0PT040D;02<I7P38_l@0NWAh03/e?00300L00P0805QFHP3hn?l0NGV501/J9P0=2aH03@XC0108
3P0A1PX04`@70145200501052@0801X?4`0X7B403P<701P=4@0=0PH03`D800l4200@1@T201462P80
40D900L0200101872`0G31004@H:00l4200<0@D040D900803`@800<04@H:01872`0A1PX0100@1@T0
3P0?10P03P<801<8400C1a404PL?01463P0@1@`03`@:01<83P0D2@h03`@801052@0B1`/03045300B
1`dDooooo`006oooool03P0C20`03P<701062P0D2@d04PP<00h4200C20`04`T<02/Q9@1@ADT04PT<
01@;3`0?1`d030D<0P0>1`h06`0=1Pd040T@00`5300E3QD03PP=030Z;`0E3a@03@L;01882P0;0@<0
4`T:01<92`0@1PP050X;03<Y:P0>10H03`D601D;3@0B1`X04PP90147200H3Pl050X;02dS900V71d0
4@L801D;300201L=3P0L01@:2`0C2@X04`T:01@93@0A1PX06PlC01L=400>0`L091TM03X_<`0=0PH0
714E01872`0F2`l050X<01482@0A1`P050X;01D<3@0E2``040H7028H6@0d:R/04`T:00`20`0I3a00
4`T:01@;308050X;00@050/<01<92P0C2@X04`T:0P0D2P/0:00D2``05@/<01<;3@0?2@`050hA01LB
5@0>20/05A4D02hZ;@0C3a4050lB01lI700A2`h06A<F020K7@0M6AX05Q8C01@@4@0Q7Ah0:2@U01<?
400I5AH04Ph?01HB500F4A@05A0C01HB4`0C3a0040`=01DA4P0?2``06ADF01<?400F4Q<06ADF014=
3P0K5aP061@E01DA4P0F4Q<301LC500301HA5@0D3a<06A@H008061<I00h06QDK01dH7`0G51`06AHN
020M9@0L6B405a@K028O9@0F51T07A/P01LE6P0M6ah06aTL01/J70<06ATK01l06QXL01/L7`0K7B40
8bDY02<V:`0Q9BT06QhT01TN900T:S808BHb01lS<P0P9C809B/h01dS;`0Y<C`08BXe02@]>00E7BT0
92hi01lY=00W<Cd08Bdi02Lc?`0R;SX0:CE102Hb?P0R;ST09c@n02Tf@00L:C<0;3Q30080:SM100T0
9cE002`jA@0_?DP0<Cm:02hlA`0/>TD0<3i903e;EP0_?DP00P0b@4/0:`0c@dd0;3e702hoA`0_@4P0
<T=;03]<D`0_@4L0=dQ?0393B`0kC5<0<T=:03=4C@15EUl0=dUB03a>F00fB580<dE>03I9D00fBDl0
<TE;03I9C`0jCE40=4M;03=6BP0bA4X0<dA<03Q9D@0gB4l0<dA;03E6CP0jBe<0=TM?0352BP1<GFD0
AEIN02hoA`0eATh0>deA02do@`0fB4`0;T1402<e>@0]?d<00P0Z?4008P0`@TH0:ce102`n@P0cA4P0
<T5603]:C`0^?D80HG1e03I5BP0`?d@0=DA90350A@0eA4T0;3]00352AP0`@dP093Pl0354B@0iBe00
<DA905Y/L@0]?T@0;T15030oA@0]?4<0;Ca203=0A`1WMW/0@E1E02Xi?P0_?T<08c8g02Db>00W<SP2
03<nA00e02Pb>00Z=3/0:C8j02PeA00_?Th0=dIF02`lC00mCE`09cM602LiAP0Y>dL0;Cm;02e0B`0]
@4X0;T5;0392DP0[>d/0:3M502XhA00[=cl0:C<i02<[<@0V:c006AdQ01/N9@0^;cL0;S4j02@Y=@0W
;3T092Pc02DV<P0];3L0;R`e02LU;P0`<3P07R4W02lc>@0N92/06b8X01`O900R8bP071dR01/L8@0P
8BH071dR01hO900M7R<07QlT01lP9@0K724051DJ01TJ7P0K72400P0K72005P0M7R<07alV024Q:@0S
8b/08B4Y01`L9P0H62805aPR02X^=P0D62406QlV01/N9`0P8b`05Q/R01/O9`0M82T08RH^01lS:`0I
72D06QdU01`L9@0M7BL201hN9`0K01`L9P0K6b@06a/U01dM9`0H62406QXT01`L9P0H6280:bTd01dK
9P0E4ah061LO01DD700G5Qd06aXP01HE6`0H5ad06QTN01LF6`0O7RD0@D1901dK9P0K6B@05aDP028P
:`0F51l06ALR00806QPS01/061HQ01HD7`0F51d06QHM01dH800f<CT0HEeT01/E7P0I5A`061@K01PB
6`0I51`06QHM01XE7@0J5R80510P01XF900H52405a@O04U6D00O72@05Q<I01DC5`0E4aD0518D01@B
4`0H4aT00P0F4AP0300J5A`06A@K01<>5@0C3QD061<J01LB6@0B3A@05A0G01LB6@0G4QP05Q4G01@?
5@804`hD00@05A0F01HA5`0L5ad07APN0P0D3aD01P0E41H05a0F018<4@0D3Q<05Q0E018<40805@lC
0P0D3Q801@0C3A4050hB01D?4`0E3a<04P`@00<050hB00@06aDI01H@500C3A404P`@0P0C3A406@0A
2`l06Q@I05eGG@13?D804@XA01H?5@0A2a003`P?014:4@0E3Q@05PlF01D>500A2`l03@L:01H@4P0<
1PP07aTK018<3P0G4A<05@lA020J700`:R`0>C<e01PB500>20X00P0C3A42018<40804@/?01D05Q0D
00d72`0B31003`T=00`72P0O5Q/060d@01D:3P0@1`P050/;01<;2P0E30`05@`>014;3`0C31<05@hG
01<;5`0@2A804@`C014<4P0B3A<0100C3Q@04`0A31804`hD00`73@0A31803@L>01T@600>1@d06a4I
00`42`0D2Q806Q4I01T@600G3AD05PdE01L?5@0H3aD05@dD01<<4`0D3A@01@0E3QD08P0D3A@05@hE
01L@5`0H4AP0618I01PC6@0F4AL08QdS01/F7016@DL06A@J01PC6@0G4QP05A0F01@?5@0E41H05a<I
018@500A3a@05A<H014?4`0E4aL040hC01TG6`0D4QL03@/@00h<400@3Q805Q4E01<>4P0F4AD08QdQ
02<N8P0A310201@?4`0:01D@500A31003PT=00l:3P0B30h03`T;018<3P0<1PP05@lA01<=3`803PP:
00T03`T;014;3@0E3a407QPJ0147200J414050X;00l51P0D2P/00P0@1PL0;00A20T05`d>00T00@0G
3@h04PP901061`0E2``050X;0516A`0Y7b0091XK01H<3@0D2P/03`D600X10P0P5QL09Q`M01H;3P0D
2@d04PP:01872`0A1PX04@L901872`0C2@`04@L901462P0R61/04PL;01482P15>Sh05@`>00`31@0C
20`05``@03L/<00F2`l04`P<01462P0C20`04@H:01@8300B1PX04@D90P0B1PX01`0A1@T05PX>01<7
2`0C1`/040@801452@0G2`l00P0C20`04@0<0@D05@X>01`A5@0B1`/050X=01882`0<0PD04PL;00h3
1`0@1@T050/=01<8300P5AT0A3Tm01072@0F2`l04@H:00803`@800<040D900l4200@1@T00P0C20`0
8P0A1PX040D901872`0E2Ph0308501052@0E2Ph03@8601P=4@0M4aL07QHK00/31`0C2@l040H;01H9
400@10X05`XA01<:3P0B2@h08a/O01@<4@0;1@/071HO00X7400/:3D0S8^G03XiAP0<31P03@XF00h9
4`0@1`h040D901441`0A1PT501872`0C030W:@10=CT04PL;01L<400;0P@05@X>00l4200?1@L04@L:
01872`0A1`T03`@801@93@0B20X06@hA01X?4`0A1`T040D901872`0201462P0E01<8300D2@d04`P<
01<8300B1`/040D900l4200@1@T04@H;01<8400C21404PL?01463P0@1@`03`@:01873@0B1``03`@8
01872`0E2Ph03`@900D040H<1`0A1P`Dooooo`006oooool0S00?1PT04@X<018<3P0C2Pd03`P:00/5
1`0G3Q403@D800H00P0>1@P05@d@014;3`0<1@d03PL?01094@0F3aL030D=01D>5@0E3a<03`T=00/5
1`0J51H07aTI01LA4@0G310060dC00`11@0C20d02@0402/P900D2@h04@H<01H;3`0E2Pl03`@:00l4
200B1`/040D901462P0G31007a@H01@93@0?1PP050T=01<8300H3A409a`P02PM8@0G31003`@801@9
3@0A1PX081DI01872`0E2Ph04PL;01<8300H3A405P/?01<9300@2P`04`X=018;3@0A2`d050/>018:
3@0B30h05Pd@018;3@0>20X04PT<01<;300A30T050`:010:1`0?2PL05@d;01D?300A30T04`/901<=
2P0C3P/05@d;01D>4P0=20l0514H01@C6@092Pl0;2ld0<74b@0i?440:R/`08:1Q`0H5A`01`8902PS
:00F4Q<040`=00h:2`0G4a@061<G01LB5P0<1`/06A@H03dh?P0L5ad06aHL00d;3P0E4a@03`d>018@
4@0C4A8040h?00X82@0K6AX04Q0A01LE5P0F51D05aDF018@4`0D4QD05aDH01DC5P0D4QD05Q@G01<A
500F51L06ALJ01PF6@0G5AP061HI01DC5P0E5AD05aLG01DE5`0F5QP061PJ01DE5`0H61/06QTN0P0K
6Ql06P0J6Q`05QPG01XM700H71/07R0O02@X:00N92@06AlO01`Q900K8bD06B4S01`T9`0P:Bh0624Z
01lW<@0R:c8082T^01hX:P0N:B/07BPZ020[;@0P:bl07BP^01hX<@0S;CT09S900P0R;S`0:P0W<cl0
:SM102Tf?P0Q;SD082dc020^<@0S<C<09cDf02Pf>@0W=ch09CHn02dnB00X>4@0;3a903A4D@0]?D/0
;Ce:02`mA`0[?4D0;Sm70311B@0/?TD0;3m60354B`0_@TP0<4=903I9C@0hBdh0<TI703I:B`0gBdX0
<TI503=7B00hBe80Zkk503iAF00cATd0@EAJ03=6BP0fBDd0>Da@0396A`80:cm00P0fBT/0=00gBd`0
>4]>03E8C00bADT0<dI<03E8CP0mD5L0Ffef04aNJ00bA4h0;T1703e?D`0W>Cd0;T140394B00V>3`0
<49602Hh?00^@4@09CLk02`n@P0^@4@0?e1F02`mA00]?TD0=dQ?03=4B`0eATd0;3e403E6C@0W>3l0
@eAK02dnA@0dAD/0:C/k02e0?P0dATH0>DU903E5A@0_?T40:cXm03M6B@0Z>C`08c8g0350@`0a@4@0
>DM:028`<`0/>Sd0:CLj01l]<00Y=cX202/i?00U02/h?P0W=3`0=dA<02Td?P0b@U8093E703=4EP0m
CV008S=30352DP0_?dl0:c]:02`lB`0^?Td0:c]802XkAP0gAE00<Cm802Pe?@0R;cD09Ble02/c=P0W
;c808RH[02@T;00K6bD0928]02PX=00O8Bd0:2`g02<W<00M8BX08B@[02<V;@0T9bh092L/024V:@02
01lT:003024V:P0L82<0720S008092P[00X06alS01/N8`0O8RT092L^01PK8P0C5Qd05aXR010C6P0J
7B@07B0W0P0P8bX0@`0L7bH06QdV01DH8@0G6R<061/T01LJ8`0E62404aHO02/^=00U9Bd07R4V01/L
8`0K6b<06A`Q020Q:00V9Rh082<X01DG7@0P82P071dR01`L8`0N7RH07AhS01/L8P0O7bL08R<X01/K
8P0F5Qh06Q/P01XJ8@0I6B407alW01lO:@0K6bD07alY01HF800?3aT06ATS014A6@0J6R808b<[024Q
:@0E5Ad06QTQ01`K8@0M72@061LO01DD700F5Ad08R0Z01hL9`0G5B006aTU01TG900E4b005aDP01TH
800H5B005Q@N01`K8`0O72L061HP00/:4P0O72L081hW065PJ00F4ah00P0G51d00`0F4a`05A8K01DB
6`0201DB6@0C01@A600G5A/0518G014?500D4QL06aHM010;4P0B3A@03@P?01D@5`0I51/04`hE00d8
3`0M61l03`XA00<01@0B3A@03@P>01<>5002014<4P0E01D@5P0Q72804@`B01<>500F4AL05a8H01D@
5P0C3Q@061<J00/63@0=20l05a8I010;4@0A31<03`X@010;4@0C3Q8050lC01<>4P0A31004P`@0080
3`T=01d04`dA01H@500D3Q805Q0D01@>4P0B31004@/?018<400C3A4040/?01PD5P0C3a003`X>01<?
4@0B3Pl05a8F01XF600K5aP06A@H01<>4@0=20`03@L;01@>4P0C3A405Q0D01TC5`0B31004@/?01@>
4P0201LA5@0P01@>4P0A2`l040X>014;3`0B310050hB01H@500G4AD04`dA00/52@0I4aL040X>03Tc
=`36`<@091/O01H=4P0>20X03`P:010:300?2@/05Q4C01PB5P0:10P071DL00D01@0J4aX04@/?00h8
300=1`/040X>01@>4P0G4AD5014;3`0=014:4@0L5B006A4L018;5@0>2A004@XB01PB6@0C3Q@07ALK
01@>4P0/:2T06aDG01@>4@05018<400501@>4P0G4AD0618F01PB5P0F41@00P0D3Q801P0F4AD061<G
01/F6P0J5AT06A@H01D@50805a8F03<050lC01XE6@0K5QX05Q4E01DA4P0E41@05Q8D01LC500G4aD0
71LK01DA4P0C3Q405A0D01<?400F4Q@03`T;010:300C3@l050h@01<=3`0B30h05@lA00X41P0D3Q00
3PP:01PB500B30h08A/M00@0000n>3X05a4C010:300H4Q@05@lA018<3P0?2@/04P`>01XD5P0V8280
5@/<01H<3@0?1@H03@<401D;300G3@h03`D601<92P070000718C01061`0K4A800P0C2@X201882@80
4@L803<040H700/20`0?1@H07aDF01@:2`0H3Pl06@l@00h4100G3@`04`T:01H<3011=cH0AC/l01<9
2@0G3@`05P`=01D;2`0>10D06@hB00l4200C20`0304500d21P0<0@D060dA01872`0M4QH0Bd1401hC
5`0<0@D03P<701052@0F2`l05@X>01462P0D2@d06PlC01D:3P0J3a<03`H801`A5@0700003`@80187
2`0M4QH03PD700d21P0D2@d040L901T>4P0?10P00`0D2@d07P0>0`L04@H:01462P0=0PH02`0400`1
1@0@1@T02`0401L<400J3a<0304500X00`0E2Ph04PL;00l4200D2@d040D901P=4@0J3a<050T=00d2
1P0>0`L040D900d31P0?10P04`P<01L<400C20`03P<701052@803P<700d050T=01<8300B1`/04PT=
00h52P0@1``05@/C00h73P0@2A004@XA00l53@0?1P/04@L;00804PL;00H04`P<01462P0A1PX040D9
01462P0B1`/601462P0B00d41@0D3``081TH01XA4P0@2`P03PL601T@4@0400006A8A00H0000=20D0
3`P801L<400G31805P/A01<83P0B1`d04@H<0`0B1`d02`0A1P`040D;01052`0G31803@8800l42P0E
2Q003P<901@93`0=0PP040D;00804PL=00/040D;00`3200;10/04``C00d63@0A2Q402@8800l62`0A
20d04@P<01482`0301872aCooooo000Kooooo`0O010:300A2`d04P`>018<3P0@2P`03PP:00H00P0E
3a406A<E014;3@090`D02086018;4`0E3AL040TA00l8400>1`h06Q<J00/52@0A2`h0:B<U01LA4@0:
1@801`4101P>4P0700806a0F01lD6P0B1`d03`@:01873@0301052`0J01/@5P0V6b406@hB01H;3`0G
31006@hB01462P0=0PH06PlC01H;3`07000030<5024F6P0F2`l03`@800/0100A1PX03P<701X?4`0:
00<05@X>01872`0D2@d05``@01H;3`0B2@`4010:300>014;3@0B30h040X<014;3@0F4180618D01@>
400@2P/04@`901@?300B3@X040/8018=2P0C3P/2014<2@0N018=2P0C3P/04`h;00l:3P0?2Q405a@M
018B6@082a004aPN07QoP`0Y;S802PdD020P9P040@P05@lI014<4P0<20T071PI00T51P0b;Rl03PT=
01LB5P0<1`/061<I03Pc>@0J5A/061<J00l=400H5QL040h?0P0C4A802@0@3Pl030X;01PF5`0A3a00
6QPI01TG600J61T05Q@G01DC5P0301@B5@0401<A500E4aH05A<F01PF6@806ALJ00T05aDG01@D500E
5A<05aLE01DE5@0F5QH061PH01LG6@0I6A`00`0L6b00200J6ad08B<R01dQ800G6aX06QhM01`Q8@0C
6AT0624P0P0K8bD0:P0I8b@06bDW01lX;@0I8b`07BL`01dX;00K9RP06RHV01/W9@0M:BL07RXY01hY
:`0M:2`07RTa024[=`0O:cT08Rhm02Pd@P0[=d<0:CHo028_=`0R<3@08S0c028`<@0U<c<09SDb02Hf
=@0`@4H0:CY203Y;D`0Z>TL0:3Q703Q8E`0^?Td0<41=0311B`0^?dP0;Ci502hoAP0[?TD0;D170395
C080<DA:0100=dY>03M:C@0bATL0=TY903U=B`0gBdT0>De<03A7CP1<GfH0=TU@03=6C00^@DD0>4]?
03I9C@0]@D80;d=40P0fBT/09P0hC4`0=DU803I:B@0fBTX0=4Q903=6BP0cAT/0>TeC03]>E@0eAe00
9CM102`nB00iBe80>4Y>02do@`0cADT0;3i202Pj?P0]?d<093Hj0394B00a@dL0>D]?0353A`1kSI80
MhR?03i?EP0W>3l0;Ci503Y;DP0oD5L0>DYA02Pi@00cA4/0<45802`m@`0/?3/0;Shk0P0a@D001@0_
?ch0;Cdm02`l?00]?Cd0<d950080<T5401H0;C`o03=1A00U<cH0<3i102/i?00T<SD09cDh02Pf>@0T
<SD09C8i04=@F00`?DH0:3I102dnCP0N<4@08SE603]<GP0dAEL0<45A0310D00Z>TX0:SY90P0e@U80
400fA500<T1902Pf?@0M:S007BP/02D^<P0/=3L092T]01PJ800L72@07A/V02TV<`0X9S<09bXc02/_
>00T:34201hS:@0701`Q9`0N8bL08BHY020U:00O92L082DX024V:@02020T9`809RX]00L07B4U01dP
9@0E61l06A`S01LJ8@0H6b@07B0Y00806QdV00D07R4Z024T;@0Q92d07R4Z01dP:@0401HI8P0501LJ
8`0G6R409BH[01lP9@0K72400P0I6Ql02P0J6b0092DZ00T:3`0F5a`09BH[02X[<0092Pl071dR020Q
9P0O82D201`M8P0701dN8`0L7B806AXO01`M8P0K72406AXO01hO900201TI8`0J01/K9@0G5b405ADO
01<C7@0P82X03`lI01HF800A4A/02@TC020P:00J6Al06aXP01PG7P0F5Ad061LO020N:00L6RD05aDP
01/I9@0I5b@061HS01PF8P0H5R405aDP01HD7`0I5b8201PF8@0;018@6`0J62<04@lJ03dkAP0>31L0
5Q@L01PE700G51/05Q<J01DB6@0F4aX0100G51/0500F4aX05A8I01<>5@0D3aH05a8I018=500R7B@0
5Q4H01D@5`0K5Qd040/B01dH7`0G4QT04@`C01/F700F4AL050lE01D@5P0C3Q@03PT?0P0B3A<02P0D
3aD05A0F01D@5P0B3A<05Q0J01D?6@0C3AL04@`C018=500@2a8201@?5@0<01@?4`0C3Q804PdA014<
400D3Q804@/?010:3P0C3A405@lC018<400F41@05@lC0P0C3A405P0D3Q805@lC014=3P0F4Q<04@d>
010<3@0C3a0040`=014=3P0D41405Q8C01DA4P0B3Pl03PX;00h8300C3A404@/?018<400E3a<03`T=
014;3`0C3A4201D?4`0601<=4@0A2`l050hB01<=4@0B31004`dA0P0D3Q8200`62P0F01<=4@0A2`l0
100203hh?00H4QH04@/?010:3P0B31004@/?010:3P0?2Pd01`45028L800;1@T0618F01XD600C3A40
40X>00l93@0@2Ph04P`@01<=4@D04@/?00d04@XA01D?6@0D3QX040XD00h9400A31<04@`B00d83P0J
5AT04@`@024M7P0A3@h040/=00D04P`@00<05@lC01LA5@0E3a<00P0D3Q801P0E3a<050hB01<>4P0E
41@05a8F01HA5@8050lC0P0G4QH0100D3a<06A@H01XE6@0F4Q@201DA4P805Q8C00L05a<D01HB4`0C
3a005Q8C01DA4P0@30d04`l@00804@/=0P0C3@l0400D3Q004`d?01<=3`0@2P`05@lA010:300I4aD0
4P`>00`6200V8280HE]M03D_<@0J51H04`d?018<3P0@2P`200d72@0@00l92`0D3Q00308301<92P0H
3Pl06@l@01/A4P0C2@X06a4B01P>3`0;0@806a4B00`20`0B20T050X;01<92P804PP900P04@L80106
1`0=0`@09A/L00L0000G3@h04@T901@:2`803`D40`0F30/06@0R61L06@l>00/20P0A1`H02`4000`2
0@0N51D01`0001X?4`0?10P050T=00l4200W720050T=01462P0I3Q80=b``01H;3`0E2Ph040D90146
2P0B1`/050T=01052@0=0PH00P0E2Ph03`07000040D901<8300K41@04PL;00/0100K41@05@X>0105
2@0?10P05P/?00P00@0<0@D03`@800P00@0201052@0301872`0C20`04`P<008050T=00T07a@H00L0
000K41@05`h@00X00`0C20`0304500L0000A1PX00P0?10P00`0D2`d02`0401462P0201T>4P8050T=
00X060dA00L0000=10H050T=00`11@0C20`04@H:01H;3`0N4aL060dA0P0A1PX01`0@1@T04@H:0187
2`0<0@D03@8601462P0@1@T00`0A1PX201872`804@H:00<040D901462P0B1`/01@0A1PX01@0A1`X0
2`8300l:1`0E40d04@`900<03@P500H04Pd:00l:1`0D3``04`h;014<2P0C20`301<83PD04PL=00/0
4@H<01052`0@1@/02P0501873@0c:2h0@3Dk01hC6@0800<03`@:0146300201873@0;0146300>1@X0
5@hF00X62`0J5A/02@@:01dG700>20`040L<01072`0@1`X00`0A1PXDooooo`006oooool00`0C3@l0
4P`>014;3@03014;3@804`d?00D04@/=00l92`0@2P`05Q0D014<4@02014:4P0@01<<4`0D3A@02088
014;3`0D3Q40<B/]018<300@2PX04@/<03P]<P1@AD/04@H<01883@0W728050T?01052`805@X@01P0
4@H<01/@5P0Y7R@08AHJ00`21@0900805``@01872`0Z7b<04PL;01H;3`0U6Qh05@X>01462P0>10L0
5P/?01872`0H3A404`P<01dB5P0<0PD050T=01<8300D2@d201H;3`0C01D<3`0C3@l04@/=018<3P0C
3@l050h@01D?4@0=1`T02`D701H@4P0L5QP050h@00h82@0B30`050h>01<=3@0A2`/03`T9014;2`04
018<300U01<=3@0@2Ph05A0E01@@5`0>3A403Q4C00@62`0D5QT030lA00lA5@0>3Q807ATN02LQ:00J
5AT06QHG01@@4@0h=3D0RhN801dH700E41@03`X>01HA5`0/9bd05A0F01@?5@0A3a806ALH01@B4`0I
5aP06aTJ01XH6@0H5QL06ALH01@B4`0F51D04Q0A01@B4`0301DC5P0A01@B5@0E4aH061HI01LE600E
4aH05Q@G01/I700L6Qd05Q@G01@D500E5A<05aLG01DE5@0F5QL061PJ01HF600H5a/00P0I61d08P0J
6Ah06AXN01DF6@0H71h06alQ01`P8P0N8RD06b0S01/S9@0L92P06b<W01XS9`0K92X07RL^01lY<P0N
:38072L/01/V:@0L9bP07RXZ01l[:`0L:2T072LZ01lZ;`0Q:c@07bTd028^?00S;cd09S8o02Lc?`0X
=Cd09C8j02@b=`0U<cH202Le=P0A02Hd=00U=CD0:3Pn02Tj@P0]?TH0:c]803M7EP0Z>TT0;cm>0310
C@0_@4X0;3e602/l@`0/?D@0:Sa602m1B`0cATh00P0dAdh0500gBTl0>4a?0395B00cAdT0<TI703=7
A`0fBT`0>4]A02Hi@00bAD`0?e9H03M:D00cAT`0<TE903=6BP0hBdh0>4a=03I:B`0dB4P0=DU80`0c
AdP0E`0eB4`0>4]@03mBF00lCeH0=TUA03=5C`0a@dd0=4I=0312AP0fB4`0<dE902`n@P0Y>cl0;Cm3
02m1A@0cADT0;3i203=5B@0Z?400FFY`04mPI`0iBU40>T]B02`mA00^?dH0?TmF02Pi@00iBU40<dA;
0352B@0bA4T0<d=30351@00_?ch0;3`k02dm?00^?Sh0=4A402@d=00eA4L0:CPm02dl@@0_?T80:STk
02Xj>P0a@D409cHi02Xi?00U=3L09cHk02Pg?@0X=Sh0BEMQ02Pf@@0a@4`0:S];02m2D`0aA5D0;d1@
02hoC`0c@e<0=TIE0310C`0`?Dd0<T1=02lmBP0]>dL0;3U202<`=`0O;3808bhb02D^<@0R:Rd08RL[
01HI7`0P82P0:RPc03Pf@P0Z:SH082</02HZ<`0R9Rl07R<Y020U:`0R9bd06QlS01lT9`02024V:@80
7b@W0P0M8B@2020T9`0:01`P900L7b@092L^01`O9P0P8bX08RD^01XM9P0F6B806A`S01/N9@807B0W
00X06QdT01TL8`0G6R405QTP01DH7`0G6R406QdT01`O9P0N7b@06a`Q0P0I6Ql02@0K724071dR01dN
8`0H6Ah0:b`a01lP9@0J6b008B8W01`M8P02020Q9P0701hO900J6b006AXO01hO900M7R<07QlT01`M
8P0201PI7P0<01dM9`0Q8B/06a/U01XJ900K6bD06ATS07=cO@15ADl0820Z01dM9`0D51h05ADM0P0I
61h0100H5ah061LO01XI8@0I5b4201DC7P0901LE8@0F52405aDR01LE8@0G5B005Q@O01DC7P0I5b80
5Q@O00805aDP01h06QPS01DC7P0F51l05A<N01LE7P0I5Qd061DL01LD6`0F4aX05a@K01DB6@0C41L0
4PlF01DB6@0G51/05A8I01PC6P0K5Qd05a8I010;4P0U82L04@`C01D@5`0K5Qd0IV5X01XE700H4aX0
6A@K01/F700:1@/201@?5@0501XE6`0D3aD061<I01D@5P0C3Q@00P0G4QP01`0D3aD030H@01H@6P0D
3QP04@`C01XE700G4QT00P0D3aD301<>4P04018=4@0G4AD050hB01<=4@8050hB01404`dA01@>4P0D
3Q8050hB01D?4`0F41@05a4E01<?400B3Pl040`=018>3`0C3a003PX;010<3@0B3Pl04`l@01@@4@02
01DA4P0501@>4P0F41@04`dA018<400D3Q800`0C3A42018<40804`dA00@05a4E01@>4P0C3A404P`@
0P0A2`l0100C3A4050hB014;3`0B3102014;3`0=00l93@0@2Ph04`dA01D?4`0C3A404@/?01<=4@0L
5QX050hB01LA5@1KEET06A<G01@>4P0201<=4@03018<400@2Ph03`T=00D04@/?00d04@/@00h93`0A
31@04@`C00l:4@0A31805Q4G01PC6@0J5A/03PT>01HA5@0D3a@050hB00D04P`@0P0E3a<0100C3A40
4@/?018<400E3a<301D@500701HA5@0D3a<04`hB01@?4`0G4QH05Q4E01@?4`0201LB5P0301HA500E
4A805A4B00805Q8C00D05a<D01<?400C3a0061@E01LC500201@@4@0B01D?4@0D3Q004`d?01<=3`0D
3Q005Q0B018<3P0O6A/050h@00l92`0E3a4040X<01`F600;1@L05A0A00d72@0F41803`T;0`0D3Q00
4P0B30h04@/=00l92`0I3a0060h?01882@0>10D04@L801D;300F30d04@P801<92P0I3a004PP901<9
2P0E2``050X;01<92P804@L800l03`D601<92P0C2@X0718C00`20`0E2``050X;01H<3@0D2P/04@L8
01D;300F30d03@<40147200G3@h00P0?1@H0200U6a`0HeUJ01`A5@0D2Pd040L901T>4P1UFUh07A@F
0P0A1PX0100D2@d06PlC00/1100Q5QX201<8300G00l4200K41@0714E00l4200C2@`0?34e04Ll@00E
2Ph02P4301/@500C20`03`@801`A5@0>10L04`P<01@93@0C2@`05@X>01872`0H3A407a@H01/@500B
1`/00P0?10P04P0B1`/04@H:01462P0A1`X040L901872`0F2`l040L901462P0B1`/05P/?01T>4P0A
1PX0?C8f04i3A`0F2`l04@H:01872`8050T=00L04PP;01H;3`0F2`l04PL;00d21P0=10H05@X>0080
40D900D05P/?01@93@0C20`04`P<01462P0201872`0300h31`0@1@T04`P<00804PL;0P0A1PX01`0@
1@T04@H:01462P0A1PX040D901462P0B1`/01@0A1PX01@0A1`X04@P900d71`0<1PH03@L700803`T9
00L081XJ0:ZTY01SGEd03PP801<=3@0<1`L04@H;00804@H<0P0B1`d01@0C20h04PL=01873@0B1`d0
4@H<008040D;00H05@X@00h32@0?10X04PL=00l42P0C20h501873@0:01483@0X8BT0N7=i0;2[/@0Z
9B/03@P=00d82`0@1``040L;01072P<04@H:5?ooool001_ooooo0P0A2`d06`0?2@/03PP:00l92`0?
2@/050h@00h82P0A2`d04P`>00`6200;1@T01@05018;4P0H4AP01`0701093`0D3Q805@lC014;3P0;
1@L03`T;01`F600<1PP040D;040e>`0?10X05``B00`11`0201873@0501D:400I3Q@050T?00l42P0A
1P`00P0A1PX0300L4AD0:AhR01872`0X7B406a0D01<8300Y7R803`@800d21P0N4aL050T=00h31`80
50T=00<08aPL01D:3P0C20`00`0D2@d01@0E2Ph050/>00l92`0<1PP03PP:00804@/=00T04`d?018<
3P0>20X040X<01<=3`0A2`d040X;014;2`0?2@T00`0>20P00`0A2`/04P`<018<3003018<300A01D=
3`0F41803`T=018?4@0?3`l03Ph@01HF5`0G5aL0410B00d:300@2P`05a4E01TD5@0[9bP04`l@020L
7@0X92D00P0B3A40600D3a<050lE01lJ800A31804@`C01dK7P0T8R<06QPI01PF5`0F51D040h?018@
4@0C4A805aDF01@B4`0G5AH06aTJ01@B5@0J61/07A/N01@B5@0B41<06QPK01PF6@805A<F00T06aTL
01`J7@0F51L051@D01DE5@0G5aL05ADE01HF5`0H61X00P0E51T0900F5AX05aHL01TH7P0H6Ah051DJ
02@W:`0X:c007B0U01<G700H7B<07RD[01dT:`0K8RX06b@[01/T;00K92d07bTc01`V<00K9R`072L[
024/;P0S;S008Rd_01hY;00N:Bd08Rdc02D_>00R;3H09S9002Hb?`0U<Cd09S8n02Pe?P0[>4009C8h
02Le>080:3Hg09X09S@e02@c=P0[>d40:ca403M8D00lC5T0CUi]03I6E@0c@e80;cm<02XkA@0Y>T<0
;Ci50352BP0[?DP0<49>0394D00cAE00=DMA03I9D00lCeH0=DQ?03E8CP0bAD/0<dI<03Q;D@0aA4/0
AUUP03E8C`12EE`0AUUO02`oA@0fBDl09CPl02m2AP10DeL0@eMH03E9BP0dB4T0<TI70395B00dAd/0
=dY>03I9CP0lCeD0>diD02e0A`0[?TD0<DA;03I8C`0[?D40=dU=02m1A@13EET0=dU=02Tk?`0U=c/0
=dU=03i@E00jC500:ce103=5BP0[?4<0;Ci50352B@0Y>T40A5EL08bMY01=GVD0=4E<02hoAP0dAD`0
;3e303A4A00dA4<0<d=20310@00^?Sh0;Cdm020_<P0V=CP0DF1U03I5BP13DUL0;Ca002Xj>P0]?C`0
9SHf020_<P0X=cX09SDk028a>00W=Ch0:3I202dkB016E640;Se<0352DP0X>DT0:CY:03Q9F@0lCEd0
=DED02LdA00Z>4D0<Cm<02lkB@0Y=D40:cM302dg@@0U<3L08bhd02L`=@0X<3@08RX]01lT:00P92T0
:B`c02h^>00f=D0092@`02T/=@0e>D80;30i01hS:@0K82H08RL]01dR9P0R9bX08bP[024V:@0N8bH0
7B8U01XN8@0K7b806QhQ01/O8P0M8BD07R4V024T:`0H6b808RD/02LZ<`0O8R/07B0Y01/N9@0K7R<0
6QdR01PK800D5a`04aHK01DH7@0H6b006A`Q0`0J7B800`0P8BH07AhS01/L8@0301/L8@0901PI7P0F
5a`09BH[05=DF@0[;3408b@Y01`M8P0J6b006a`Q00<07AhS0P0L7B801`0K72406AXO01DF6`0C51T0
8B4[02DU;`0L72H00P0J6R@0400@41X09BD_010@6P0`<3X02@TC01HF800N7BD06QTO01PG7@0G5Qd0
5aHN01HE7@0F5Ah06ALR01/I900K6BD201XH9@0?01dK9`0N72L06ALR01@B7@0H5R406ALR01DC7P0B
41/05aDP020N:@0?3AP081hY01PF7P0H5A`05a@K00<05Q<J02H05A8I01PE700H5A`05A8I01LD6`0E
4QT06A@K00l:4@0E41L05a8I01hI800H4aX07QTP01LB6@0Z9B`03@P?01lJ8@0@2a8071LM010;4@0I
51X01`8801XE6`0Z9B/06A@J01HA5`0C3Q@05A0F01HA5`0C3Q@06aDO01PB700G4A/06QDL01PC6P0C
3QD03`X@014<4P8050lC00<04@`@00h93@0B31000P0C3A40100D3Q805Q0D01PB5P0A2`l201<=4@04
01@>4P0E3a<05@lC01DA4P8040`=00<04`l@018>3`0>2P/00P0E4A8201<?400301DA4P0F4Q<050hB
00805Q0D00D050hB01D?4`0I4aL05Q0D01@>4P02018<400401@>4P0F41@050hB01<=4@804P`@0P0C
3A402P0>20`06aDI03Pb=P0<1PX04@/?01PB5P0E3a<050hB01<=4@0A2`l2010:3P0801XD60070@D0
1002018=400I4aL030H:014;3`0C3A4201@>4P03014;3`0@2Ph04@/?00D04@/?00`03`X>01<>500C
3Q@040/A00l:400R7B<0;RT_01dH7`0A31<03`X@014<4`0?2Pl7018<40@04`dA00D05@lC01LB5P0G
4QH05Q4E01D@500201@?4`<04`hB0P0B3A400`0D4180510A01@@4@0201DA4P0H01HB4`0D41404Ph?
014=3P0F4Q<06ADF01LC500F41805@lA01@>400B30h04`d?01H@4P0>20X081XL010:300<1PP03`T;
01D?4@0C3@l081XL01<=3`0Z92H01@010`0B30h02`0A2`d040X<010:300A2`d03P@501882@0H3Pl0
5`d>01882@0@1PL02@0000<04@L800@04PP90147200D2P/050X;0P0B20T02P0A1`P040H701X@4@0<
10@07aDF01882@0C2@X0:1hO01hE5P0A20T201<:2`0>00l61`0G3Pl0200001892P0:0@804PT:00h5
1P0O5QL06a0D01482P0G31001`0005iCE`0;00@201<8300401@93@0B1`/0200101dB5P804`P<0280
3P<701dB5P0Q5QX04PL;01@:3@2HSI40Y9VM01892`0X7B40L6EY024F6P0:00<04`P<00l4200T6Ad0
81DI01H;3`0C20`02`0401882`0S61`040D901H;3`0B1`/040D901462P0B1`/04@H:01P=4@0U6Qh0
<RL[04m4B007000040D90P0F2`l06`0M4QH04`P<00h31`0G310040D900l4200B1`/02`0400T00P0D
2@d03@8602dR9P0S61`03`@8024F6P0I41808AHJ01H;3`0@1@T0304500h31`0@1@T03`@801052@0?
10P03P<701052@0301872`0301462P0@1@T040D900<04@H:00<040D901462P0B1`/01@0A1PX03@0A
1`X05@`=010:2P0>20P04@/;018<300>20P02`D505I@D00b;2`030H600T30`0:10@00`0C20h60187
3@090146300@1@/040D;01<83P0B1`d05P/A01T>500D2@l04@H<00804`P>0P0A1P`02`0C20h04PT>
01TB6P1MF5l0O7Mm020K8@060PH04@/?00l62`0?1PX03`H900<040D95?ooool001_ooooo0P0@2P`2
00l92`803PP:01L030H8014;3@0D3Q003@L9010:300Z92P0:R<Z00`53@0C31<040T@01PB5`0600@0
4P`@01LA500<1PP05a4C01@>40090`D08AHL00/01P0F2a402`0601873@0201@93`0H00d2200@1@/0
4PL=01052`0A1P`03P@701462P0G3100714E00T00P0E2Ph04PL;01<8300G31004@H:01X?4`0G3100
6@hB01@93@0K41@07Q<G034V:P0U6Qh04PL;0P0D2@d02`0C20`050T=01H=400B30h040X<01@>400G
4A<05@lA01H@4P0G4A<04`d?00804@/=00<04P`>01<=3P0A2`/00P0=1`L0100?2@T040X:018<300C
3@d3018<300L014;2`0C2``05Pd>00l92`0I51D03@T801@@4@0>30/04`l>01LC500E41405Q0@01<:
3@060@80510A00T51P0O6a`01`<401PC5`0B3A405a8F01D@5P0I51X04PdC01<>500C4A@06aTJ01@B
4`805Q@E0`0B41402@0D4Q<03`d>01XH6@0A3a006QPK020N8@0R82<05Q@G014?4P0201HD5`0;01DC
5P0F51L06QPK01/I700F51L051@D01DE5@0G5aL05ADE01HF5`0H61X00`0H5a`06@0I61h06aXP01`M
8P0E61d09BP^02X]=00L7bH04ADK01XN9`0P9bl07B@/01/R;00K92d072D^01XR;@0L9S006B<]01PR
:`0L9bd082/_028]<@0Q;30082/_020[<@0S;CH00P0U;cT01`0Q;CT0:3A002diA@0/>D80:3Dn02Db
>P0U<SP00P0V=3L202Le=P0I02He>00^?T@08S<k02Lh@024U:40Z[[904IFI@0eAE@0;cm<02XkA@0Y
>T<0<45803E6CP0]?dX0<D=?02m1C@0a@dl0=DMC03E7D@0bA4h0<49<0395C00a@d`0=4M>03Y=E002
02`oAP0^03=6C@0gBU40=4M=03A7C@0`@dT0AeYN03iAE@0[?T80=4Q90396A`0dB4T0<dM803=6B@0f
BDd0>4]?03Y=DP0jCE<0=DQ>03Q;D@0iC5<0=4M>03=6B`0[?D40>4Y>02i0A01>H6@0@eEI04iPI00[
?D40;d5503E7B`0_@DD0:C/o03E7C00dAD`0:CY102Pi@00Y>T40?4eD07Z;TP1:Ff80;Ci50393BP0_
@4L0;3i30310@080<D5003/0<41002dm?@0Z>SX07B`_02/j?@19F5d0<D15045@E@0/>cl0:c/k02dm
?00S<c<0:3Lj02Th?@0X=Sh0;Sa502lmB00a?dd0?4UI06]hR00e@e<0:S];02HgA`0[?4`0<D9B0394
DP0^?T`0:cU602dkB00b@4`0;SY602Hb?P0W<ch0:38k01lY<@0I92X07RL/02P`=00/=3L06b0T024U
:`0V:C009BD_02`[=P0K6bL08B@]02hb>`0V:S<06AhT01PM8`0O92X07b@X028W:`0R9bX082DX01hS
9P0M8RD06QhQ01/O8P0201DI700H01XM8@0J7B806A`S01HI800L7bH082</01hQ:P0L7bH07R4V01hQ
9@0L82<06AdQ01HI7P0E6A`05QXN01TL8@0K7b8071lS01XM8P0H6b007QlT01`M8P0J6b006AXO0`0H
6Ah02@0P8BH07AhS02//<@2a/[L03PlD01/L8@0H6Ah06AXO01`M8P0201hO900901/L8@0L7B8061TN
01PI7P0F5a`04a@I01TI8`0L72H06ATS008061PR024071`V01DE7`0<31H0:BTc00X:500L72H07A`T
01XI7`0H5ad05aHM01LF7P0E51`051<L01LE800I5b806ALS01XH9@0H5R<07A/W02@R;@0L6RD04a4L
01DC7P0F51l05A<N014?6P0D4Qd05Q@O00d;5P0K6B@05Q@M01LD6`0F4aX00`0E4QT0600D4AP06AHM
01PE700E4QT061DL010=500H4aX02`H=01HA600G4QT03@P?010;4P0F4AP01@0701dH7`0@2a808A`S
01LB6@0C3Q@04PdC01`G7@0B3A<0;2L]04I1A`<04`hD01404@`B010;4@0@2a4040XD00d74@0A2aD0
5A0G018=500A31<04PdC01<>500E41@050lC010;3`0=20`040X>018<400201<=4@0401D?4`0I4aL0
4@/?01<=4@<050hB00D04`dA01DA4P0A3@h04Ph?01<?4002014=3P0301@@4@0C3a004Ph?00804Ph?
00T04`l@014;3`0C3A405Q0D01@>4P0B3100618F01H@500E3a<00P0C3A400`0E3a<05Q0D018<4002
018<400<01<=4@0E3a<05@lC01/E6@0M5a/0BTA801PB5P0>20`04P`@01PB5P0F41@04`dA0P0?2@d0
2@0A2`l03PP<00@00P0N61`04P`@020J7P0I4aL04P`@01<=4@0201@>4P03018<400A2`l04@/?00D0
4@/?00<04@`@01@?4`0C3Q<00P0?2Q001`0F4AL07APN010;4P0F4AP04PdD01H@6P0?2A001@0B3100
1P0A2`l04P`@01<=4@0E3a<050hB01<=4@D04`hB00P04PdA01<>4P0A31004@`@01<>4P0A31004PdA
01@@4P80510A0`0E4A801`0B3Pl04`l@010<3@0B3Pl05a<D01@@4@0E3a400P0D3Q0301<=3`0?00X4
1P0H4Q@050h@010:300?2@/06Q@F00T31@0=1`T02@@502@N800O6A/04`d?01H@4P0D3Q0040X<0080
3PP:00d040X<01061`0A1`P05`d>01P>3`0F30d0718C00L0000N51D03`D601061`0C2@X05@/<0080
4`T:0`0B20T06@0A1`P03`D603@Z:`1NE5D05`d>01@<300O5AH050/<00h51P0H3a005`h?00`3100E
30d04@P901892P0<0`@04`X;0108200:0@805@X>01872`0A1PX04`P<020E6@0E2Ph00P0D2@d00`0C
20`05@X>00`11@0201@93@0H01462P0>0`L05P/?01L<400>0`L03@8601lD600K41@05``@00`11@0L
4AD07Q<G00d21P0;00@050T=08AiO@2h[K40>Bhb00L0000B1`/050T=01H;3`0;00@03`@80P0A1PX0
300@1@T04PL;01D:3P0:0@<0DDI:0<Bi_@0A20X0:1dQ01462P0C20`02@0200X10`804`P<01<060dA
01@93@0A1PX040D900X00`0@1@T04PT;01D:3P1NDeL0A3Tm00L0000M4QH04`P<01H;3`0B1`/050T=
01052@0?10P04`P<00806@hB00D04`P<01872`0B1`/04@H:01872`0301462P0701052@0A1PX04@H:
01462P0@1@T04@H:01872`0501462P0401472P0C2P/03PP800h8208040X:00L030H600/51@0=1`L0
3PP801LA4@0C3@d05@l@008050T?00@04`P>01873@0B1`d04@H<0`0B1`d02P0A1P`040D;01052`0H
3A<04PL=00X01@0900@04@H<01H;4@0A1P`401873@0:0107300<1@d05A0F01PC6@0?2Q003`X?01@>
4P0@1``040L;01072P<04@H:5?ooool001_ooooo03`040X<018<3P0C3@l04P`>010:300=1`T04@/=
00h82P0B30h040X<01<=3`0Y8bH0DT]A01<>4`0B2a802`D901H@500?2@d02`H900l93@0A2`l03`T=
00h83019@dL09AXP01@:3`0H3A<04PP=00l62P0R5ad04`P>00d2200A1P`04PL=01052`0B1`d04PL;
01D:3P0D2@d04`P<01L<400D2@d09Q/O00l4200>0`L05``@01T>4P0@1@T05@X>01462P0G31004`P<
01hC5`0?1@P04PL;01D:3P0D2@d04PL;01@93@0E30l2014;3@0301H@4P0I4aD050h@00804P`>00D0
4@/=018<3P0D3Q004P`>014;3@02010:300401@>400E3a404`d?018<3P804`d?01P04P`>014;3@0A
2`d04@T:01TA3`0A20P050d;00l81P0O61L04@/900l81P0D3@`04``:01H>300M51@05a4A018>3`0D
41405a<D01<?400B3A404@`@01`G6`0G4QP201D@5P0801HA600@3Q406ALH01<A4P0H5QL06QPI01PF
5`0J61T201@B4`03020N7`10?Sl07adN00806ALJ00H071XM01hL7`0L6Qd05A<F01@B5@0F51L201TG
6P0G01PF6@0G5QP051@D01@F5@0F5aT051DG01DF6@0G61`06AXN01PI7@0G61d061TN01/L8@0M7B@0
61/S01XM9@0M82T06QdV01PL9@0S9c808bXd01hU;`0K8Bd00P0L92l0500I8Bd07bTc01`V<00L9Rl0
7bTb024/<`0O:C407RP`024[<`0Q:c@082Xc02<]=`0X<S`08blk02Pd?`0Z=d009c@m02Hc?00X=Cd0
8c0f0P0S<C@0:`0V=3L0:CLj02Th?00^?TD0;Sm702m0B01/O8T0UJFd03i>G@0^?Td0:SY702Lh@P0W
>440;Ci50352BP0`@Tl0<D=A02/mB`0]?dd0=4ID03=5DP0dAU80=DMC03Q:E@0eAe80=TQD03a>F@15
Ef40@UAN0312C00gBU40;d9903U<D`0dAdd0DVE[04QKH00`@dL0>TeA0354B00dAd/0=DQ<03I9C@0i
C5000P0kCU@0500iC580?4mE04mRJ012EE/0<4=903E7C00_@DD0?DmC02i0A00gBDd0>Ta@09Z//019
Fel0;3i20312AP0_@DD0=DM;02m1AP0eATd0;Ci50P0^?dH0800U=Sd0<45803I7CP0Y>T40=4E<02`m
A00b@dT0<3m20310@00_?cl0;Cdm02`l?00/>ch0:3Lj02Xi?00Z>Ch0;Se402/j@@0W=S`0:Sdk02/n
>`0Y>cX0@E=F0353B00W=d809CE302hnCP0W=dL0<D5A02loC`0Z>TX093I40P0dAU@0<00]?D/0?DeJ
034oC00hAU80;Sa702Pe@00Z=d40:3Dn02<_>@0K9Bh07RL_020Y<00Q:Rl08R/_02@/;`0R9b/08BD[
01lR:@0M82T0;Bhi01hO:`0L82T082@]01`P:@0K82H07B8X01/P9P0L8BD07b@W01hS9P0M8RD07R<V
020U:00/<3<0:Rha01hR9@0K7b807b<W01dP9@0G6R4071lV01LJ8@0G6R<071lX01TL8`0K7b806QhP
01/O80806QhP00P06QhO01/O800J7R006AdN01XN7`0J7R006alQ01`M8P806a`Q0`0J6b00300h>Ch0
5aPM01hO900G61d07b0U028S:00L7B806Q/P01`M8P0N7b@06a`Q01LH7@807AhS00X05aPM01PI7P0J
6b005aPM01@D7P0E5Al06QXT01PH8P0F5R0061PR0P0D51h07P0C4ad07AdW01XJ900I62005aHL01DD
6P0G5Qd06APP01PG7`0F51h06ALR01XH8`0L6RH08R0]01hL:@0H5R806aTT01LE800C4A`05aDP01HD
7`0C4A`05A<N028P:`0F51l05aDP01<A700F51`05Q<J01DB6@D0514H02l05a@K02TV;@0d<CP07a`S
01PC6P0C3QD05Q4H01D@5`0H4aX0?CPo03Ha>00M61l04`hE014<4`0C3QD05A4G01HA5`0J5A/04@`B
01<>500J5A/050lE018=4`0G4QP06QDK01@?5@0@2a404`hD00d84@0Q6bD08Q`V00h9400@2a804`hE
018=4`0A31804@`@01<>4P0K5QX07aXN014;3`0D3Q804`dA014;3`0B31005Q0D01@>4P0301H@500:
01@>4P0B310050lC01<>4P0F4AD050lC00l:3P0F4AD040/?014<40@04PdA00H050hB01LA5@0L5QX0
5a4E010:3P0F41@601<=4@0?01@>4P0C3A404P`@01<=4@0D3Q805@lC01<=4@0?2@d08adQ01<=4@0F
41@03@L;014;3`0C3A404P`@008040X>00/04P`@014;3`0C3A405Q0D010;3P0>2@`03`T=01H@500E
3a<050hB01<=4@02010:3PD04@/?00d04@/>010<3@0B3Pl04@d?00l:3P0@2a403`XA01LB6@0<1Q00
5Q0J00/5400K5B4050hF00D04P`@0P0D3Q8201<=4@0301@>4P0F41@050lC00804@`@0P0B3A402@0C
3Q805A0D018=4@0B3A405a8F01@?4`0E41@05a<E01<?400201@@4@805A4B00H04Ph?01hJ6`0Q7Ah0
510A014=3P0B3Pl201<=3`0@01@>400C3@l04P`>014;3@0C3@l05Q0B02DO8@0J51H030H8014;3@0>
20X040X<01<=3`0P6Q`0@cdo01<=3`8050h@01404`d?014;3@0A2`d04P`>01H<3@0E2``060h?01H<
3@0C2@X07A<D01L>3`17?Ch05P`=01D;300C2@X050X;0147200301882@8050X;01D04PX:0517B00j
<34040H701D;300>1PH03`H90189300@1`X04PT<01D<3`0>1@P04`X=01`C5P0J4A@02P840189300?
1PT040H901D:3P0>0`L00P0C2@`02P0=0`H040D901D:3P0=0PH04`P<01052@0<0@D04PL;00l4200A
1PX201872`0g01<8300G3A005@X>01072@0>10L05P/?01472P0@1PT03`@801<8300P5AT0VXnC0<:k
_`0`9BT0308501`A5@0A1PX05``@00l4200@1@T060dA01H;3`0?10P04@H:01H;3`0E2Ph040L901<9
300A1PX03PD701462P0H3A404`X<01<9300B1`/0304501052@0?1@P04PP;01@93@0>1@L06a0D028G
6`0C20`05P/?01D:3P0A1PX04`P<01062@0=0`H03P<701D:3P0C20`040D901872`0201T>4P050187
2`0C20`050T=01462P0@1@T00P0A1PX201872`0601<8300A1PX04@H:01052@0A1PX04PL;1@0A1PX0
3@0A1`X040L:00h82P0<1PP03PP:010:300B30h03`T;010:300=1`T030H801<=3`0:10H00P0?10X0
100@1@/04@H<01873@0C20h301873@0;0146300@1@/040D;00l42P0@1@/04`P>01D:400C20h03047
00h32@0A1P`00P0B1`d02`0A1P`03@@901@=5@0?2Q002PD;010;4@0@2Pl03PP<01483@0A20`04@P;
00<04PL;5?ooool001_ooooo00D050h@00l92`1WHF<0OGMi01@>400200l92`8040X<0P0A2`d01@0@
2P`05@lC01@>4P0B31004@/?008040X>01@05Q0D014;3`0600@050dD0109400C31<05``B01873@0A
1P`05@X@01@93`0C20h040D;0146300B1`d050T?00d2200F2a4050T=01872`@04@H:00<06PlC0146
2P0@1@T00P0D2@d0600A1PX04`P<00`11@0h;C404PL;01462P0@1@T05P/?01@93@0>0`L050T=00l4
200A20/04@/=01D?4@0B30h02P@600l92`0B30h07ALI00h82P0G4A<0MFma03li>`804P`>00@02`D7
01dG6@0<1PP03@L90P0@2P`03P0B30h04@/=00l92`0>20X04P/;01@<2P0C2`T050/901D;2P0F30/0
5`h<01H<2`0D2PT050/90P0F3P`01@0C3Pd04Ph?018>3`0@30d04@d>00805A0D01L07QTM00h93`0M
61h04@`B00l:400C4A@03P`=01TG600L6Q/03`d>014?400D4Q<05Q@E01hL7@0P7Ql0:RPY01lM7P0D
4QD05aDH01TG6P0D4QD04a4D01LE600301HD5`8061HI01T051<E01hN80082@/08R<U028S9`0F5a/0
4a@H014B5`0E5Q/05aPM01HF7P0G5al06ATQ01<F7`0G6R<061/T01TK9`0M82/07B4/01lU<@0L8Rl0
7bDc024Y=P0M9C805al/00808B/e01807bTc01hX<P0M9c806bD_01`V<P0P:SD0:S@n02/e?`0U;cT0
92hh01h[=00R;cP0:cQ102/h@00T<CT08c0h02<`=P0V<cT202Ld>P0O02Pe>`0X=c`0;3a303A5C@0i
BU80<D5>03Y:F@0]?D`0=4AC02dmBP0[?4H09cQ103=4B`0a@TX0=TQE0394DP0]?dd0<D=A03I8EP0d
AU@0>TaJ03=5D`0hBUP0;3i<02/lC00jC5X0B5YV051RK00bA4h0=DMA04AGGP020313BP0303E8CP0j
CE<0;d980080=4M=0200<dI<02m2B00iC580?E1F03=6C00gBU00>4]A03A7B`0^@DD0;d9603=6BP0g
BTh0;d550312AP0a@dL0=DM;03Q:CP0mCe<06B/_041BEP0a@dL0<TA802i0A00Z>d40=DI=02Xk@P0/
?D@08S<j02Tj@@0/?D@0;Ci502m0A`80<D9904@0:ca202`k?P0]?Cd0<D5102ln@@0[>Sd0<d9702dl
@@0_?T<0;3]202Pg?P0[>T409C@j02@f=P0[?S`0:C/l0311B010DET0=TID03=3D`0K:Sd07bi102dm
C@0^?Th0:c]:02loCP0dA540;cm<02`jA`0kBE@0=TA?03e9E@0K:3408Rlg02<]=P0R;3D0:C<l01lX
<@0O9Rl06B0X024X;P0M92T06R8U01DJ7P0L8BH06AhT01/N9`0V:3<09bTe01dQ:P0O8b`08RH_02@Y
;`0R9bd07R<Y020U:@0S:2`06AhQ02@Y;00J7b8051TL01hR9@1;Ce8092P[01`P8`0L7b<05QTN018E
70809BP_01H02`hG01DH8@0N8BP06QhQ01PL7@0F6Q/061`M01/O800M8B806alP01LK700L82405a/L
01lS900E6AX05aPM01HG700:2a005aPM024R9`0@4AH05aPM0P0J6b005@0H6Ah06Q/P01dN8`0F5a`0
71dR01/L8@0M7R<07b0U01dN8`0N7b@06a`Q01XK800K72407QlT01lP9@0I6B<04a<M018B700F5R00
5aLQ01PH8P0201TI8`0401PH8P0F5R0051@N01HF7P805QDK00@06APO01DD700E51`061HP0P0F51l0
4P0K6BD07Q`Y01/I9P0H5R806ALR01/I900M6bH06aTT01TG8P0G5B005Q@O01XH8`0K6B@04@lJ018@
6`0E4a`04PlF01<@5`<05A8I00L05a@K010=500W92/05A8I01<@5`0F4aX07APO008061<J00@06aHM
01XE701AC5<05a8I0P0F4AP0100E41L050lF01@?5P0A3182010;4@0E01@?5@0F4AL05Q4G00X52`0C
3Q@07QTO01PC6@0E41H061<I00l94`0_:C<0DTaF01D@5`0F4AP04PdD00h93`0K5Q`02PD902DP901G
DUH071LK00804`dA0P0D3Q800`0E3a<05Q0D01<=4@02018<400;01<=4@0B310040X>01@?4`0@2`l0
5A0D01LB5P0@2`l04@`@010;3`0B3A400P0E41@06@0D3a<04PdA01PB5P0@2Ph0618F01LA5@0I4aL0
5@lC018<400E3a<050hB014;3`0@2Ph04P`@00h8300@2Ph04@/?018<400@2Ph03`T=018<400Q6al0
=2hb03li?@0C3A400`0B310201<=4@1G018<400A2`l04@/?01TC5`090`L05@lC018<400D3Q805@lC
018<400A2`l040X>014;3`0B310050hB00l93@0@2Ph050hB01<=4@0A2`d04Ph>01dI6P0B3A0030L;
00h93`0@2a804`hE018<5P0B31L040XF065KI`0o>4401@0300d72`0B3100208601XD600B31004`dA
01LA5@0C3A4050hB01D?4`0A2`l030L;01LB5P0F4AD03PT=01LB5P0E41@05Q4E018=4@0A310030L;
02HQ9@0G4aD03@T:018>3`0F4Q<05a<D00h:2`0A3@h05Q8C01LC500E4A806QHG01PD5@0J51H03PP:
01LB4`0H4Q@05a4C010:300I4aD04P`>00d72@0K5AL02P@600d72@0H4Q@03`T;01H@4P0M5aT04@/=
01D?4@0>20X03`T;00804P`>00<04@/=00l92`0A1`P00P0F30d01@0C2@X05P`=01L=3P0F30d05@/<
008050X;00@04`T:01882@0C2@X04PP90P0@1PL00`0B20T04`T:00h41@0200l51P0701061`0A1`P0
4PP900l62@0F4180208400T31@02010:300<018<3P0H4Q@06aDG00h82P0:10H06a8E01P=4@0A1PX0
40D901462P0M4QH050T=0P0B1`/200h31`0701<8300F2`l04@H:00/0100@1@T03`@801462P0201/@
500400l4200700004`P<01872`804`P<01005@X>01872`0@1@T060dA01lD600C20`05P/?01D:3P0@
1@T03`@801872`0J3a<06@hB01L<400C20`04@H:0P0B1`/0100>0`L04`P<01H;3`0@1@T601462P04
01872`0F2`l060dA01H;3`804@H:00@04`P<01872`0B1`/04@H:0P0B1`/02P0C20`040D901462P0C
20`03@8600h31`0E2Ph05P/?01@93@0C20`201462P8040D901H050T=01L<400D2@d040D900X10`0@
1@T05P/?00d21P0N4aL04@H:01@93@0C20`05@X>00`11@0800409A/O01P?4P0<1PP04@/=00T31@0=
1`T02@<50P0>20X200l92`0D00h82P0=1`T04PL=0146300D2@l04`P>00l42P0A1P`04`P>0146300?
10X040D;01<83P0H3A<050T?00/01P0>0`T04PL=01L<4P0900@501873@0301483@0=1Ph03@P>0080
3PT?00P040/@014;3`0B2@h03PD900l62@0D2@d04`P<00d21QCooooo000Kooooo`0=00@0000>20X0
:B<U03H`<P0>20X0208401@>400A2`d03`T;00h82P0@2P`04P`>018<400301@>4P03010:3P0=1`/0
3PP<00804@/?00@04@XA00X32P0D3A@05``B0P0B1`d02P0E2Q0050T?01<83P0G31804@H<01052`0F
2a404PL=01`A5`0B1`/201462P0B01872`0C20`050T=01P=4@0E2Ph04`P<01462P0C20`050T=01P=
4@0G3100=R/_01T>4P0E2Ph05P/?01@93@0G31004PL;0P0G31009@0I41<03`T;010:300C3@l040X<
018<3P0D3Q0030H800L10`0;1@L0:bDW00l92`0A2`d050h@018<3P0C3@l091hP00X41P0D3Q005Q0B
01PB500F41804@/=010:300B30d05@d;01@<2P0D2`X050X901D;2P0J40l06a4@01P>3@0G3P`05Ph<
01D=2`0B3Pd00P0C3a005P0A3@h04Ph?01HA5@0=20`05Q4E01<>500S7R@07APN01LB6@0J61/0518C
01/I6P0R82406aTJ01LE5P0D4Q<05Q@E01TG600A3a005aDF014?400F51L201LE600R01<A500B41<0
4a4D01PF6@0F51L0518E01HD5`0G5AP05aHH01PI6`0@4A<051DG00l@500E5QX061TM01@E6P0H6Ah0
6Q/P01TI8@0J6R806a/S01<F7`0F6B804aHO018D800F6B@06alZ01TO:`0I7b`0728`01`T<@0J8Rl0
5al/01XT;P806bD_01T072Hb01dW<`0M9c<08b`k02H`?00`>TH0<ce902`f@00X<S`07b`e024^=`0Y
=Sl0:CHn02Hc>`0W=3`082dc02Db>00V<cT0:3Dk02Xg?@0[>Sl0;3a302hoA`0a@TX0;3a90080=4AC
01`0<D5@02dmBP0/?DL0:S]403A5C00b@d/0<dEA03A6E00bA580=TQF03Q:F00eAeD0EFMe02/mB`0Z
?4X0=DIF04=DI01AHg40<D=@02XlAP0cADl0>TaF03E7D@0_@TT0;D1702i1A`0cAT`0<4=90P0bAD/0
E00lCeD0>diD03iAE`0mD5H0=4M=03E8CP0fBDl0=dY>02m2AP0[?T80;d9603Y<D00cADT0=4I:0353
A`0[?D40;d5502do@`12E5P0O8jB02m1A@0R=3P0:ce103]=DP1FIfh0?e1G02Xk@P0U=Sd0;d1702`m
A00]?TD0;3e402/l@`0/?D@0;T150350@`0]?Cd0:c/k030o@P0nCE00I7=h02dl@@0_?T<0;Ca302/j
@@0^?D@0:CPn02@f>00Y>c/0:S`o0393B`0kC5H0<41?02PgBP0S<TD0<d9E03I6EP0dA5<0<d=A02Ph
A@0kBeP0>daG028`>`0/>TD0?D]E038oB00Y=Sh0;3U102<]=P0W<CX0=Ci703@kA@0/<c`0:2lg020W
;@0F7R8051`O01LL800O92T07B8X01hQ:P0S9S008R@`01dQ:P806QhW02P0724W01dR:00M8RP0:Bhb
024V:@0G71l092T/01`Q900H7B002@d@02<W:P0H71l05ATL02P[;`0U:2d0:B`c01@G7P0Z;C@09BPa
01/N9`0T9bh05a/N01DI6`0C5aP05ATK01PL7`0I7Ah05ATK01HJ7@0G6a`05ATK018F6@0I7B00824V
028S:00P8BH06AXO01DF6`0O82D05QLL0P0I6Ql0400G61d061TN01XK800M7R<0824V01dN8`0L7B80
6a`Q01TJ7`0N7b@06a`Q01TJ7`0J6b006a`Q01`M8P0J6R@201DE7`806ATS0P0H62804P0I6B<061PR
01DE7`0E5Al05aLO01DD6P0F5A/06QTP01LF7P0H5al06QPR01HD7`0E4ah05aDQ01PF8`0E4b005A<O
01PF8@<06ALR01T061HQ01LE800?3AP03@/F01LE800F51l04@lJ01<A6P0G51/05Q<J01DB6@0F4aX0
61DL01XG7P0P7B@0<2dd014>5@0;20l06QLN014<4`0:1@`07APO00h9400=20l08A`S00<050lF00L0
4`hE018=500B3A@05A0F01<>500B3A<04`hD008050lE01806A@J00X52`0F4AL04@`B00/6301IE5X0
B49<01<=5`0H4Q`061<J01<>5@0A3A<040/A01dH7P0A31003PT=02<N8P0910P2014;3`804P`@0P0C
3A40300B31004`dA01D?4`0F41@05@lC01<=4@0D3a<04`hB01HA5@0E41@040/?01@?4`<04PdA00l0
4`hB01@?4`0E41@06Q@H01hH700U7b<05Q0D018<400G4AD04@/?01<=4@0B310040X>018<400F41@0
0P0A2`l01@0B31004`dA018<400B31003PP<008050hB00<07QPL00`62P0>20`00P0B310201<=4@09
018<400A2`l03@L;01XD600F41@06Q@H00/52@0?2@d04@/?008040X>0P0A2`l2018<400<00h8300?
2@d04P`@014;3`0@2Ph0510A01TE5P0D41804`hB010;4@0;1Pd061<J0P0B31H02@0M5b40OgV508Z4
S00b;3004P`@014;3`0D3Q80618F00h9300201`F6P0401<=4@0>20`030H:01<>4P803`X>024050lC
00d8300<1`/04PdA02HQ9@2PVil0<B``010;3`0E41@04`lA01DA4P0C3a005Q8C01<?400?2``04@d>
01DA4P0D41404@d>01DA4P0C3a003@L901D?4@0K5AL071HH010:300C3@l0=S0b01dG6@0910D07QPJ
01PB500E3a400P0B30h01P0[9BL0=Bla028L7P0D3Q0040X<014;3@804`d?00T04P`>014;3@0C2@X0
5P`=01D;300C2@X05@/<0147200E2``0100D2P/201<92P0501D;300F30d05P`=01D;300C2@X00`0B
20T201<92P0/01892P0B2@`01`83034[;@070@<04@/=00X41P0>20X07ALI020J700>20X05@lA00@0
000C20`06@hB00h31`0F2`l07a@H00T00P0>0`L04@H:01@93@0E2Ph04PL;01052@0?10P05@X>00l4
200@1@T05@X>01872`0E2Ph040D900h31`0C20`02`0400h31`0A1PX04`P<01872`0?10P04PL;01D:
3P0@1@T301872`0301<8300E2Ph04@H:00<040D900P03`@800h31`0@1@T03`@801@93@0C20`03P<7
01052@D04@H:00@04`P<01L<400I3Q805``@0`0B1`/501462P0601<8300?10P03P<701@93@0B1`/0
4@H:0P0E2Ph0100C20`04PL;01462P0A1PX201052@0:01<8300F2`l04`P<01052@0?10P02@0200/0
100C20`04@H:00h51`80304500X050T=01872`0A1PX0:b4U020G6P0;1@L03`T;01LA4`0C3@l06Q@F
0P0>20X400l92`0:01<83P0@1@/04@H<01873@0?10X040D;00X01@0@1@/05P/A00l42P80200300H0
6@hD01X?5@0E2Q002@0400d3200G318501873@0301483@0?21003PT@00803PT?00D03`T>00h8300?
1P/04@P<01482`0301462QCooooo000Kooooo`0A00d72@0H4Q@03@L900h82P0E3a407ALI01D?4@0A
2`d03@L900`6200@2P`04`d?010:300C3@l05Q0B01D?4@0A2`h00P0=1`/01P0?2@h04P/B00d63@07
0@P0614H01H;4P@050T?00L04`P>01873@0?10X050T?01`A5`0?10X04PL=00<04PL;01D04`P<01@9
3@0E2Ph05@X>01L<400D2@d040D901872`0F2`l03P@701T>4P0L4AD050T=00h31`0C20`05P/?00l4
200@1@T060dA01<8300H3a800P0?2@/03P0D3Q004P`>010:300A2`d03@L901H@4P0B30h040X<00l9
2`0E3a807ALK00l93@0B31002`H90P0D3Q80500I4aL06Q@H01H@500A2`l040X>01<=3P0C3``04Ph<
01@<2`0E2`X05PX;01T=3P0H3@d05P`<01D=300E40d050l=01<?3P0D41405A4B0P0C3a00500F4AD0
5A0D01@?4`0E41H05Q4G01/F700G4QT04a4D018@4@0C4A806QPI01`J6`0C4A8040h?01DC500L6Q/0
3P`=018@4@0H5QL05aDH0P0E4aH05`0I5aX06QPK01PF6@0I5aX05Q@G01<A500E4aH061HI01XI6`0E
5QX03a<F014E600K7b804QDI01`O900D5a`05aXP01PK8P0G6R4061/S01TL9@0H6b@06A`U00806ahW
00H061`V01PL9`0H7bT07RD`020V<P0M9C4201lW=00>01XT;P0K9C007BLc01lX=`0R:c/092dm024Z
?00P:CT0:SA102hhA00X<Sd08B/e024^=P0N:c<202<`>00E01l/=00P;CD07b`d02<`>00V<c/0:3Dm
02/h@00/>d80:c]202Pi@@0Z>d<0;cm<0310C`16EVD0;Si=02dmBP0_@4X0:S]40352B@0/?DD0;d5:
0080=TQC00X0>D]F03U;E`0eAe<0@E=Q03]=F`0mCed0=4EE03Y;F`1:FfX0@UAQ0P0jC5P05P0fB5<0
=4I@03=5C`0_@TT0<TE<03A7C@0oDUP0A5MM03M:D00mD5L0>TeD03Y=D`0fBDl0<4=903A7C00eB4`0
>Da@0395B00[?d00;T9305=VJ017FEd302`n@P0J0353A`0cADT09CLk03=5B@0^@4@0>4Y>02Pj?P0a
@TP0AeQO03A5C00U=Sd0;3e403Q9D00a@TT0=4E<03Q9D00fAdh0;Ci502`n@`0/>cl0:cXm02dl?`0[
>Sd0:CPk03=2A`0Y>3l202Xi@01A02`j@`0_?DH0:cY302/m@P0W>Sl0;3m703E7E00cA5<0;3eA03M8
G@19FFl0FFYk03]=FP0a@dh0:ce60311BP0gB580<3i702<a>P0a?dP0<d1802Xg?`0Z=ch08B/b01TT
:P0L9bd0EEiU065VL@0]<C/0;C4j02@Y;`0U:Rl06b0T01`Q9@0R9b`08BH/01lS;00O8bd07B4/01lS
;00Q9Bh092Pa02H[<@0S:2h07R<Y024V:P0N8bL07R<V01`Q900F6ah0:2d`02/_<P0L82<082@W01LK
7P0Q9BT06QdR01LJ8@0T9bh07B0W01DH8@0P8b`05aXR01PK8@0G6Ql05QXN01LJ7`0I72406AdQ02DX
;@0D5a`051PL01HI7@0?4QL05QTN01PI7P0L7B805AHK02TZ;`0J6b006a`Q00806AXO00h061TN01LH
7@0F5a`05QLL01LH7@0K724061TN01TJ7`0K72406AXO01dN8`0J6b006AXO01LH7@8061TN0P0H6280
0`0I6B<071`V01`L9P0201PH8P0501XJ900H628051@N01LG8@0I62000P0E51X0600K6R406APP01TH
800N7BH071XU01XH8`0H5R805aDR01HD8@0G5B405Q@O01DC7P0D4Qd05A<N01HD7`0E4ah05Q@O01/I
900J62<04@lJ010>6@0G5Ad06AHM01HC6P80514H00d05a@K01dJ8@0R7bH05a@K01PE700G51/040dD
02@O9P0K5Qd0;bXa01HA600J5A`04`hE00805A0G100D3aH00`0G4QP05Q4G01@?5@0201@?5@0=010;
4@0H4aT03@P>01PC6@0E41H030L=03Ha=`0S7BL07aTS01<=5`0:1@`07QTP01<>5@0201@?5@0401<>
4P0A310040/?014<40@04`dA0P0D3Q801`0B31005Q0D01TC5`0H4QH05a4E01D?4`0E41H00P0D3aD0
300B3A<040/A01D@5P0B3A<04@`B010;4@0A31805A0F01PC6@27PHD0C4I:028L808050hB00<03PP<
00l93@0A2`l00P0B31000`0E3a<0618F01@>4P0201<=4@0901@>4P0E3a<05Q0D01LA5@0E3a<03PP<
010:3P0?2@d04`dA00804P`@0P0C3A40200B31004@/?014;3`0D3Q804@/?010:3P0<1PX04`dA0`0B
3100100@2Ph03PP<00d72`0B310200l93@804@/?02h040X>018=4@0<1``061<H02LR:00Q728050lE
01TD6P0;1Pd0>3<j01XF700Q6b@0=S0f018<400C3A405@lC00`62P0C3A404@/?01H@500H4QH05@lC
01LA5@0H4QH040X>01<>4P0J5AT03PT=00l:3P0G4QH04@`@00L31P11?4004PhA01D@500@2`l05A0C
01TE5P0=2@X04`l@00l;300M6AX05A4B01HB4`0C3a0040`=0P0B3Pl00`0O6A/0QGn101TC5@0201D?
4@0?018<3P0E3a404P`>01PB500I4aD03PP:014;3@0F41803PP:010:300D3Q003@L901@>400A2`d0
4P`>00<04`d?00L04P`>01882@0C2@X050X;01T?400M4a@05@/<00<04`T:00D050X;01D;300E2``0
4PP901D;300201L=3P0401D;300B20T050X;01@:2`804`T:00P04PP901482@0?20/08A/O08R2QP0O
6Ad03`T=01<=4@806A<G01`05@lC018<400<1PX050hB01H<400I3Q8040D901872`0E2`h0FDiB01H;
3`0A1PX040D901D:3P0D2@d04@H:01872`0:00<02001034V:P0`9BT0304501<8300=0PH04@H:01<8
300B1`/09AXN0`0B1`/0100C20`040D900l4200E2Ph200l420804`P<00d04PL;01<8300?10P04@H:
01P=4@0F2`l04`P<01462P0E2Ph06@hB01@93@0@1@T04PL;00D04@H:00@04PL;01@93@0E2Ph04`P<
0P0A1PX02@0@1@T03`@801462P0B1`/04@H:00l4200A1PX040D900l4200201<8300301872`0C20`0
4`P<00804@H:0P0@1@T201462P<04PL;0P0A1PX04@0I3Q8040D901T>4P0:0@<04@H:01872`0?10P0
4PL;01052@0;0@@04`T<00h52P0E3a<03@L;00/52@0A2`l030H:00803PP<00P03`T=010:3P0A2`l0
4P`@01/@5P0C20h040D;01@93`804`P>00`04PP=00l42P0C20h040D;01893@0B20d040D;01@93`0?
1PX05P/A01052`0C20h501873@0=01483@0@2A403`XA00h93`0=20h03@P=00d72`0?1P/04PT=0148
2`0?10P040D901D:3P0Dooooo`006oooool01P0A2`d03`T;01D?4@0C3@l050h@01TC5@803@L90P0>
20X00`0?2@/040X<014;2`02014;2`0:014;3@0@2Pd040X>018;4P0A2Q403`P?01`E7@0A2Q8040T@
01D:4@805@X@00<050T?01<83P0C20h00P0E2Q00200M4QP091TO01873@0B1`d05``@01@93@0C20`0
4PL;0P0A1PX01@0E2Ph04@H:01462P0D2@d04`P<00804@H:01/05``@01052@0E2Ph04`P<01L<400A
1PX05P/?01<8300>0`L0:QlS038Y;00=1`T03`T;014;3@0=1`T03PP:00l92`0A2`d06A<E00`7200=
1`T0618D00@00@0B31005a4E01<=4@0T7R800P0D3Q80500C3A4050hB018<400@2Ph04P`@010=3`0>
3@/040`=01@<3P0F3@h06@hB01P=400D2P/04`P<01@=3P0E4A004Q0A014>3`0B3Pl04`l@0P0B3Pl2
01@?4`0V014<400F4AL04PdC01TD6P0K5Q`03`d@01@B4`0E4a@04a4B01HD5@0E4a@0518C01TG600Q
7b003`d>00`:2`0@3Pl05Q@G01@B5@0E4aH06aTL01hL7`0L6Qd05A<F01@B5@0F51L06ALJ01XH6`0H
5aX06a`P01HJ7@0A5AP06ahS01PK800K7R<04aHM01HI800G6R4201HI8P0;01LJ8`0a=3/07R4X01XM
900N8BP06ahV01LK900C6R8072</01/R;00H8BX00P0N9S406@0I8bd06B<^01TS;`0I8S406B8d01TQ
=00R:Sl082Pj02H_?P0Z=40092hi024[=@0T<CT082dc02Db>00V<cT08Bhd01l/<P0Q;SH09C8j02Hc
>`0U<SX09c@l02Lf?@0]?D@00P0Z>d<05`0`@4d0:c]:045AH00/?4/0;Ce:02hoB@0W>440:S]202<d
>`0_@TP0=4M>0354B`0bA4d0=DMA03A6D00kCET0<49@03E7E@0gBEL0<T=C03=4E00lCU`0?e5M0080
:C]702D0>4YD02`nB00^@4X0=dYA0395C00kCUD0@eIM03M9DP0cADl0;3i80354B`0hBe80=4M=03M:
C`0bADT0;T9302a0@@0]@D80;D500395B00L;S806R``03E7B`0a@dL0:3Xn028d>00cADT0>4Y>02Dg
>`0Z?400:3Xn02hoA@0_@4L08c@k02dnA@0V=ch0;3e40080:ca30200=dQ?03m@E`0fAdh0>DY@03E4
B@0]?3l0:cXm0391AP0c@TL0=4=:02Th?`0W=Sd0:SQ102hlA@0_?DH0;Ca50352BP0W>D<0:ce:03=4
EP0^?e<0<41H0351FP13DfX0B5YZ02PjA00W>T409CPl024b>P0_?DH0;3Y301dZ<P80:3Dm02X06bH/
02`g?@0R;C80;SLl02Tb=`0d?D<0HVIa02L[=@0Y;CH07R<Y024V:`0I7R807RHY01dU:@0M92X06b8Z
01`S;00P9c407B4Z01lS;00R9Rl08bP^020U:`0J7bD09R/_01LL7`0N8bH08BHY01dR9@0I7R407b<V
01HJ7@0M8B@08RHY024T:00O8RL07b8Y014D6`0I72<09bXc02<V;`0J7BH201`O9P@06ahU01T04A@K
01HI800V:C0061/R01hQ:00B5A`06Q/P020Q9P0F5a`0?3e202l`=@0T9BX071dR01XK800I6Ql061TN
01HG700E5Q/061TN01/L8@0F5a`05AHK01HG700D5AX061TN00<05aPM0P0H6Ah00`0F5R0061PR01TI
8`0201XJ900701TI8`0G5b4061PR01HF800E5Al061PR01XI8@0201DD6P0F01PG7P0D4a/051<K01PF
800G5B005Q@O01@B7P0C4Ah0518O01PF8P0H5R405A<N01<A700E4ah061HQ014?6P0E4ah07adX01LE
800<2QD04@lJ01LE7P<05Q<J00@0514H01<@5`0A3QD08AhU0P0H5A`01`0?31<0514H01PC6P0L5ah0
4PdD014<4`0?2Q401`0E41L00`0E41H050lE01D@5P0201HA5`0C01<>500L5ad06A@J00l:400B3A<0
7QTO00/6300L5R006Q@N00/63`0@2a804PdD01D@5`0G4QP050lE010;3`0F4AD05a8F00h93@0601@>
4P0;018<400G4AD0618F01D?4`0C3A404P`@01LB600B3A<03PT?010;4@0B3A<00P0>2@l01P0@2a40
4`hD01@?5@0D3aD04`hD01LA5@805@lC00X01`4500d72`0K5AT040X>01<=4@0F41@05a4E01@>4P0@
2Ph04`dA0P0A2`l02@0B310050hB01D?4`0I4aL03PP<01/E6@0H4QH02P@8014;3`02018<40804`dA
00T04P`@014;3`0A2`l05Q0D018<400A2`l04`dA00T31`0A2`l00`0C3A40100A2`l040X>018<400B
3102014;3`0G018<400C3A40:2<Y00l:4@0F4AP08A`S01PC6@0?2Q004`hD03Lb>03Pfn40X9^O02@O
9@0E41@03PP<00/52@0D3Q804P`@014;3`0?2@d04P`@014;3`0=1`/00P0@2Ph04`0D3Q804`hB01<>
4P0E41@04`hB01@?4`0L5a/04`hB00<00P1:ADT0<B``02@O8`0<20X071PI00h:2`0G4a@05Q8C02`X
:@0D41400`0C3a000`0B3Pl0510A01XD5P0201TC5@0501@>400:10H05a4C01XD5P0:10H00P0=1`T0
2@0C3@l04P`>01LA4`0A2`d04P`>01@>400A2`d05Q0B014;3@04010:3008014;3@0@1PL04@L801@:
2`0K4A8081HG01L=3P0A1`P201882@0301<92P0D2P/050X;00804`T:0P0B20T201<92P0P01D;300D
2P/04`T:0147200@1PL03PD6014;3`050@@09b8V00h93@0<1`/06A@H07]fNP2RWJ402PD900d8300E
41@0208600`31P0>0`L050T=01P=4@0R5a/0Uhb@01dB5P0A1PX02`0401052@0B1`/040D901872`0F
2`l201<8300901D:3P0C20`04`P<00h31`0C20`050T=01P=4@0b9b/04PL;008040D900H04`P<01@9
3@0C20`05``@00l4200>0`L201872`0=01052@0B1`/03@8600l4200E2Ph04`P<00h31`0A1PX05``@
01X?4`0D2@d04@H:01<8300501462P804`P<100B1`/201462P0:01<8300D2@d04`P<01462P0?10P0
4`P<01D:3P0@1@T03@8600l420804@H:00@040D900l4200?10P03`@80`0A1PX05P0@1@T04@H:0146
2P0?10P050T=01462P0Y7R802P0301@93@0B1`/040D901<8300F2`l050T=01882`0<0`P04@/?00h8
30080PH04@/?00d82`0?2@d200h83006010:3P0A2`l050hB01dB600D2@l040D;0P0E2Q003@0D2@l0
6a0F00L00P0G31803@8801L<4P0F2a406@hD00l42P0900@050T?01<83P0D2@l01@0A1P`00`0@1``0
3@H>00`73P0200d83P0800h93P0?2@d04PT>00l62P0>1@P04PL;01<8300@1@TDooooo`006oooool0
200=1`T03`T;00l92`0;1@L0618D00`6200=1`T03PP:0`0?2@/03P0>20X04@/;014;2`0@2PX040X<
014;3P0A2`l03`P?01<<4`0F3aH0:24Y01@=5@090PX050T@0P0F2a40=00C20h04PL=01<83P0G3180
4@H<01<83P0K41H04`P>01T>500H3A405P/?01@93@0B1`/04@H:01052@0D2@d03`@801052@0E2Ph0
4`P<00l4200F2`l02P0300d21P0?10P04PL;00l4200B1`/04@H:01X?4`0G310040D901T@4`0;1@L0
3@L9010:300=1`T04@/=01@>400A2`d05@lA018<3P0600807aTK02LQ900A2`l0100202TS9`30^[h0
;RP/00/62@0B310301<=4@0O01D?4`0C41803Ph>00l=3P0B3@l05`hA01T>4P0J3a<060dA01L>4@0F
4A804a4B010@400>3@d04@d>01<?400B3Pl04@d>01<>4P0?2Ph04PdA01PC6@0F4AL040/A018=500C
4A@05A<D01HD5@0C4A804Q0A01DC500201<A4P0501dK700C4A804@l@01<A4P0F51L00P0E4aH00`0F
51L05aDH01HD5`0201DC5P0_01LE600J61/06aTL01LF6@0;310051PK01<G6P082a005aXO00H93P0E
61l061/R01TL8`0H6b@05aXS01PK8P14Adh09BP^01TL8`0M82L07R8Z024U;P0F7BD07RD^01XQ:`0I
8R/08BXd01hV<@0L9S0072Ha01/T<`0K93D06R8f01TQ=P0R:Sl08BTm02@]?P0U;Sd08R`g02D_>00R
;cL07BX`020]<`0T<CL08Bhd020]<`0S<3P00P0V<c/202@a>@0D02@c>P0^?TD0:ca402Pi@@0/?4T0
:SY90351D00/?4/0;3a902hoB@0W>440:CY1028c>P0_@TP0<TE;02e0AP0]@4L0<dE?03A6D00hBUH2
03E7E@040353D@0`@E40=DIF03M9E`80;T1<06D0=4IB0353C@0W>D<0<TA>03Y=E00dAdh0<dI=03Y=
E00fB540=DMA02i0BP0fBE40@5=J03]>E00iC540;T5502Lk?00X?3d0:cm002Xn?@0gBT/0=TQ<03E7
B`0_@DD07c4e02Li?@0X>Sh0838f01d_<`0[?D40=4I:02/m@@0/?D<0;d1701l`=`0/?D@0834h02Lh
?`0a@TT0;Sm60352B@0eATd0;Sm603E6C@0hAd`0;C`o02He>00Z>Ch0:CPm02He?00_?TD0;3]202hl
A@0c@DX0<Cm8030oB@0`@T`0:C]702XlB`0`@ED0;CeD0351FP0iBF80?dmV03i@H00W>D<0;3m502i2
@`0R<cX0:3Ho02@b>`0R;cL0<3e502@a>00nBDl0GVU_03<n@P0H8BH07bP]02D]<P0S9c0061`V02P/
=@0L8BL08RL/02ld>00N9RT06b8W01/R:00J8BT06b8[028Y<`0R9Rl0720Y01PL9@0I7R@0724W01hS
:@0A5QX06b0T020U:002018G6P0:01LL7`0O8bH07b<V01dQ900P92L07b<W014D6@0I72<08bH]01HI
80806ahW00@03a8K01/N9@0K7RD06ahU0P0J7B@0200I72<05QTP01PK8P0K7RD03Q4H01dP9`0O8RT0
4a@I0P0H6Ah0100N7b@04Q<H020Q9P0L7B8301TJ7`0601LH7@0F5a`051DJ01TJ7`0G61d06a`Q0P0R
8bP00`0F5a`05aPM01LH7@0301PI7P0?01HF800H628061PR01LG8@0H62806QXT01PH8P0F5R005ADO
01HF800G5b4061PP01DD6P0D4aT05aHM00804a8J02@05Q@N01HD7`0G5B005Q@P01DC800F52406ALS
01PF8@0F51l05A<N01HD7`0H5R405A<N018@6`0C4A`05Q@O01dK9P0K6B@05Q@L01HC6P0G51/061DL
01HC6P0E4QT04a0G01`I800C41L06AHM00l<4`0C41L05a8I028M900D3aH07aXQ01@?5P0K5Qd2018=
50<04`hE01T050lF01<>500B3A<050lE01LB600H4aT050lE01/F700C3Q@04@`B01HA5`0I51X050lE
01`F800D3QP03@LA01D@5`0>2A004`hE00l:400F4AL05A0D010;3`0C3Q804@`@00804`dA0P0B3103
014;3`805Q0D00/04P`@014;3`0D3Q805Q4G01D@5P0?2Q0040/A018=4`0=20h03PT?014<4P0201@?
5@0?018=4`0@2a40:28V010:3P0?2@d040X>01PB5P0C3A4050hB01D?4`0F41@05a4E01<=4@0=1`/0
4@/?008040X>0P0B31001`0C3A405Q0D00@00P0D3Q805a4E00T31`0C3A400P0B310201<=4@03018<
400A2`l04`dA0080208600L02`D901D?4`0<1PX03PP<010:3P0B31005@lC00805Q0D0P0C3A40:P0B
31004@/?018<400D3A@09b8Y010:500D3aH061<J01@?5P0A31808ahT069MH`3`kO00XijR02dX;00H
4aL0208600@00P0>20`05@lC010:3P0A2`l050hB018<400@2Ph050hB01<=4@0A31001@0400d8300I
51P02PD9010;3`0?2`h05A0D01`G6`0^:Bd081/O00T4200H51H05a<D00d92P804`l@00D081`M014=
3P0?2``04Ph?01<?4002010<3@0>010:300400005Q0B01dG6@0C3@l05@lA01<=3`0<1PP06aDG00X4
1P0>20X030H801H@4P0?2@/200X41P0400/51`0E3a404@/=010:30<03`T;00L04@/=0147200C2@X0
4`T:01D;300H3Pl04@L800<04PP90`0C2@X01@0F30d050X;01882@0B20T050X;00<05P`=01L050X;
01<92P0B20T040L:01H@500>2@d00`0201@?4`0B3A408QdQ0:JQY@2m^[d03PT=014<400<20/03`T=
00`31P0C20`02P0300`11@0;00@0;R<W01H;3`0201872`0@01@93@0A1PX03P<701052@0?10P04PL;
00X10`0:00<05@X>01462P0C20`05P/?01D:3P0?10P07Q<G01052@803`@800@040D901872`0D2@d0
4PL;0P0?10P03`0C20`050T=01@93@0B1`/03P<700l4200B1`/040D900d21P0@1@T04PL;01D:3P0B
1`/03`@801872`0501462P0?01@93@0E2Ph04`P<01@93@0F2`l05@X>01<8300B1`/04`P<01@93@0C
20`04PL;01052@0C20`05@X>008040D90P0A1PX201052@803`@800<040D901462P0@1@T0100@1@T0
4P0F2`l03@8601D:3P0k<3@050T=01L<400@1@T03`@801052@0C20`050T=0188300800@04P`@014;
3`0g<CD0OgUm01HA50803`T=0P0>20`01P0@2Ph04`dA01P=4`0A1P`03`@:01<83P804@H<00`05P/A
00L00P0c:2h04PL=01D:400=0`P0304700L00P0P5A/08aPN01P=4`0;00H501052`0=00l62`0;10`0
2`H=00`73@0=20h03`T>010:3P0B2@h03PD900l62@0D2@d04`P<00d21P0Dooooo`006oooool09`0B
30h03`X;01H@4P0:10H04`d?00l92`0H4Q@05@lA010:300>20X03`T;010:300>20P040/:01<=3P0C
3A004@/?00h83@0=1Pd03@L>014:4P0F3aL030@?01<<500C2A0060dC01L=4P0C2@h04PL=01<93P0B
20d03`@:00l52`0C20h03P<901L=4P0F2`l05@X>01<93@0201<8300401<9300A1`X050T=01<93080
4PL;00l04`P<034V:P0:0@<07a@H01<8300K41@03`@801H;3`0@1@T05``@01@93@0J4A<0;B@W01@>
400>20X00`0A2`d05`0@2P`04`d?00P3100C3@l030L801PB500=20X03`P>00l83`0F3aH0=c0f00h7
3P0C31804P/A01<<4`0B2a404P`A01D>5@0E4Q@04Q8B018@4@0C3a0050`?00805@/?05H05@/>01@<
3`0E4A80518C014A4@0?3Ph04`l@01HB4`0E4A80510A01D@500@2`l05Q4E014=4`0O6R005A4G03<_
=00O7Al04a8A01<A4P0H5QL04Q0A01<A4P0G5AH03P`=01@B4`0D4Q@05aDG01PF600C4A@05A<F01LE
600E4aL0518E01LE6@0K6Ad061HI01HD600G5AT06ALJ01PG6`0E6A`04QLJ04eBEP0g?4006QlT01@I
7`0C61h05QXR01HJ8`0E6B8051PQ01DJ800O8RP05aXO01dP9@0N8BH061`R01lT:P0K8RP082L^01TP
:00K92/092de01`U;P0J92h072Ha01hW=P0P:CX08b/o02@/@P0Q:Cl08RXn028Z?00N9cL07RPe02Xd
?P0iATh0:3Dl024^=00R;cH08c0f02Db>@0S<3P09S<k02Dc>`80934j04<0938k02Lh?`0X>D409CHo
02dmBP0oCeh0;cm>02/kBP0/?4T0;Sm:02XkA@0`@DP0:S]302Xm@P0aA4T0;T5602i1B00dAdh0=TU@
03A6D00dAU40<D=?02XlB@0bA540?4iK03e?G@0eAeD0=dUG03M9E@0jC5P0?4mK0395C`0dAdh0>diE
03M:D@0jCE@0=4I?03Q:E00iBeD0?e5J03a?EP0dAdd0<TE:02i1A@0^@T<0;D1102Xm?@0Y?3`0:C/m
02@e>@0Z>cl0:ca002Hh?00Z>Sl09SPl02Tk?`0Q<cL0;3i204mQI@1@HVL0;3e303A5C00U=Sd0:CY1
02Hf?@0Y>D00;Ce40080:ca304/0=4E<02/mA00]?dD0;cm502ho@`0_@4@0;Ci202Xj@00b@TT0<d=;
02hnAP0`@4T0=4==02loB00^?TX0=DME03A7E`0dAeP0=4IL03=5G@0a@U/0:ceD02TjC`0Y>dX06blf
01da=00M<C407bld02<a>@0N;3<07R/c02ll@`0X=3X07bX_02<^<P0M9RX0;CLi02D_<@0M9RT0:2`e
02<V<00L7bP06b0V01TO900O9RT072@W01XR9P0N9B/072<[01LN9`0L8b`06b0W01`P:00M8RT07b<X
01/P9@0F6b005AXN01HK7P0L8B@07R<V03<h>`0N8bH061`O01/O8P0Q9BP07R8U04A7B`0L7b@05APO
03Hi@00L7bH06A`U01/N9`0B5Ah00`0L7bP03P0K7RL06QdV01TL9@0J7BH05QTR02<V;`1KGVL05aXS
01LJ8P0L7B8071dS01HG700J6b007AhT0P0J6b002`0F5ad05aPM01TJ800G61h05AHK01HG7@0J6b40
61TN01dM8`0T92/092DZ00806AXP00@06AXO01PI7`0F5ad05QHM0P0I6B<02P0G5b405ADO01PH8P0N
7RP06ATS01<C7@0E5Al06ATS01LG8@0F5Ad201@C6@0301PG7P0F5Ad05aHN00805aHO00h06QPS01PF
8P0D4Qh05A<O01PF8@0G5Al05QDN01DD7@0F5Ah05aDO01HE7P0G5B005Q@O01<@6`806AHQ00D05A8J
01<@5`0B3aH04PlF01<@5`0201DB6@0501HC6P0C41L06aPO014>5@0T8BP00P0D3aH201HA6004018=
500D3aH04`hE01<>5@8050lF00D05A0G01HA5`0D3aD050lE01HA5`0201PC6@0301@?5@0B3A<04@`B
00805Q4G010050lE014<4P0A2a@05@lH01H@6@0:1@`06A@J014<4`0D3aD03PT?010;3`0G4QH04PdA
01<>4P0E3a<050hB0P0C3A42018<400<00h8300C3A404`dA014;3`0E3a<07AHL010;4@0N6B006A@K
010;4P0B3A<050lF0P0C3QD0100A318040/B010;4P0A318201<=4@0<01`F6P0C3A404@/?01<=4@0J
51P050hC014;400C31805@hD01<<4P0@2Ph04P`@0P0C3A43018<400300l93@0@2Ph06aDI008050hB
0P0B310201<=4@0W018<400A2`l04P`@00/62@0b;300:28V018<400=1`/04@/?010:3`0@2Ph04@X?
018<4@0B31004@/@01<<4P0B31003`P=014:400D3A@04`hG00h84`0B3AH03`XA010;4P0E41H02@@:
024L801GDUH0@cm001TE5P0D3a40618F01D?4`0C3A403PP<00`62P0C3A404P`@008040X>01X0618F
01TC5`0D3a<05@lC00X52@0J5QT0MW5e06IQI@0E41@05a8F00`72`0@2`h06QDH018<3`0B30h040`=
00l;3@0B3Pl04`l@014<3P0E41<04Ph?01LC500H51H04@d>00h:3080618D00@04@`=01PB500@2P`0
50h@0P0A2`d0600/9RP03`T;01<=3`0C3@l040X<014;3@0F41806A<E01D?4@0B30h04`d?018<3P0A
2`d040X<014;3@0C3@l040H701@:2`0C2P/04@L801<:2`0B20T050X;01<92P<04PP900<040L80106
1`0A20T00P0C2@X05P0B20T03`H701<92P0B20T04@P90147200@1`P03`H900d72`0@2Q002P@;010:
4@0>20l03`T>01XD6P0b;34030P<01TD6@0:1@X04`dA0189300@1PT201872`804`P<00/050T=01<8
300B1`/05P/?01`A5@0O51P040D900d41P0@1@T04`P<01462P0201872`0:01<8300>10L04PL;00h3
1`0D2@d04PP;01T>4P0G3A404@L;01052@804@L;00H050T=01<93@0A1``04@H;01@93P0A1PX40187
2`804`P<00D03P<701462P0C20`04@H:01872`0301462P804@L;00L04`T=0147300?1@T04@H:01@9
3@0C20`04PL;00804@H:040040D901462P0A1PX04`P<01872`0>0`L04`P<01lD600K41@04@L;0147
2P0@1PX040H901462P0B1`/04@H:01052@0A1PX04PL;01862P0@1@T03`@802lU:00d:Rh05P/?00/2
1@0A1`/040D901062@0>10L03@8600l5200A1`X0FE5G02@M900@2A00E4eD0;Zc^P0U7bD04@XA00l8
3`0=1Pd030D<00h73@0@2A004PP>0106300B20h04`P>00l52P0A1P`040D;02XP9P2j/;H0>Bhd00T0
1@0@1P/05@X@01D<4011=cd06a0F01<93P0=10T040D;0P0@1P/01@0@1@/040H;00l6300>1`l03PP?
00803@L=00P030H<00h62`0<0`P04@P<01@;3P0D2@d04@H:00l421Cooooo000Kooooo`@03`T;0P0@
2P`2018<3P07010:300?2@/04@/=01@>400@2Ph040T@01L@5`0200h73P0M018;4`0@2A4030H=01D>
5P0@2Q403@H>01D>5P0B2a405@`A01<=4@0C2a004@P=00h8300B2Pl050/@01TC5`0B2`l04PT>01`F
6P0>1`/050/@00`62P0?20`05PdB014;3`0B2Pl030<800h8300A2Ph00P0>1@X00`0D2@d04@H:01<8
300201872`0801H;3`0J3a<05``@00h31`0C20`0:AhR04e4A`0J51H200l92`1<01D?4@0C3@l0618D
01@>400<1PP05@lA01PB500A2`d03PP:010:300@2Ph04@/>018<3P0C3A405@lB00d72@0D3Q8040X=
01D?4@0;1@T050l@00X82@0>2P/0510A010<3@0B30h06A<E01PB500?2``04Ph?01@@4@0B41407QXL
01H@500B3A404`hB014<400C4A@03@/>01dK7P0D4aD030X=01<C5@0C4QD06QXH01PI500C4a404A4?
01<C4@0F5QH04A4C00`<3P0G5QX00`8702@S:00D4aP07A`Q01PG700C4QL00`8802d/<@0/:c404A0F
01HE6P0J6Ah04a8H00l>4`0A41H02`hC02LZ;`2HVj80PHB;01/N9@0D5ah04A@K01@G7P8061/R06<0
5QTP01<F7@0G6Ql05aXP01hQ:00D5ah0:Bde01`P:@0N9Bd07B@]01`S;@0M9Rl092df02Tb>`0K9Bl0
8B/f02<]>@0P:CP08BXj02Pa@P0b>Td0:C5401PP<`0T;3l082Pk07N0T@3Pj_H0<3]401/X<00D8BX0
934j020^=`0T<S/082hg01X[<`0U=Cd0938k02`mA@0W>D40;d5;02/mA`0R=3h0:Sa803E7D`0X>TH0
:C]902HhAP0/?TX0=DME02Dg@`0X>T@0<49<0353C@0_@D/0<TA>02Dg@@0bA4h0;d5;02`nB00bA4h0
>diE03a>F00hCE/0>DaK03Q>F`0fBeP0;D5<03I<E`0iCeL0=DU@0357C@0lE5P0?eAI0396C00hC5<0
=dYA03A7CP0aA4/0<D9902i0A@0jC500@E=G0310@`0T<cH09cHi02dl?`0O;C009C<f02Le>00lBdh0
C5UO02hm@P0]?440;Ca302hnA@0dAD`0=DI>0311A`0]?d<00P0]?440:00[>3h09c@l02Tf?P0_?TD0
;Sm702doAP0aAD`0<TM=02`oA@0W>T00:Se302m2B00]@4L0:Se503Y<EP0gBED0<dEC02/mB`0Y>dT0
:3Y;02XoDP0Z?e@0;T=G03=5F`0a@eL0:ca?02@eA@0V=TD0834k01/Y<P0Q<3L07R/`01dX;P0Z=C/0
6RD[02dh?P0I92X0:C8h02</<@0Z<cP202<];`0Q01dW:00T;Rl06b8X04E<DP0Z<CL06B0V01TQ9P0I
8RL05b0U01hW;00J8bP05b0U01/T:@0N9B/04QDJ02DX:`0O8bH07QlS02<W:P0I72406b0T014F6P0K
82@06B4T04=;C`0F7R4092T]01TN8P0D6Ad06b0T01hS:@0>4aT04aLP00806AdV05T05QXU01PL9`0N
8Rd07B0Y01`O:00H6b@05QTR01PK900K7RL082</03Hi@P0Y;3D0C4mH01dP:@0E62405APP01LJ8`0G
6R405QTQ01DH8@0F6B005APP01DH8@0H6b806QdU01PK900F6B007alX02PX<P0Q8BT05QHO01LG8@0I
6B4061PQ01`L9P0J6R805QHO01@D7P0C4ad07b8[020S;00F6B804QDN01XJ900I6B<051@N01DC7P0H
5R405A<N01HD7`0I620051<I01<B600F5A/05A@J01LF700F5A/06aXP01PG7`0G5Qh061LO018A6@0N
7B80;bla01dM7`0E51P061LL01lL8`0I5Qd05Q<L01DB6`0O6b@050hH01PB7P0E4AT04a4F00l=4P0B
41D040hC01HD6@0P7R<05Q@I01<A5P0G5AX05A<H014>500F4aX05A8K01@A6P03018?5P80518G00/0
518F014?500A3a80518G00d83P0H4aT03PT?014<4P0J5A/04`hD01@?5@0201<>500?018=4`0A3180
4@`B01XE6`0?2Q004@`B00h93`0;1PX0>C@i02LR9P0N6Ad04PdA014<400C3Q804PdA00804`hD03P0
;RT_01HA5`0A31805Q4G020K8@0>2Pl07QTO00<0100C3Q@050lE018=4`0?2Pl03PT=00l:400?2Pl0
3`X>01HA5`0E41D04`hB018=4`0B3A804PdA02<N8P0S7b004@d>00`72`0D3a@03PT?034/<P0?2Q40
40/B01`G7P0U82P02PD<01<>4`0A31004PdA00l:3P0A31005a8F00h93@0910P04PdA01D@500B3A40
4@`@018<400C3A4050hB01<=4@0A2`l03`T=010:3P0D3Q805Q0D01D?4`804`dA048040T@00l8400C
31<04PdC01L@600>1`h05@hE014:4P0700L050dD018;4`0B2a8040T?00l93@0A2`l04P`@01<=4@0B
31004@/?014:4@0B2a805@hE01@=500B2a404@/?00l93@0A2`l05Q0D01/E6@0F41@04P`@01D?4`0B
31003PP<010:3P0B2`h071<F00H0100R7200[ZV]08n=T00E4aD05A4B00/51`0A20T07a<E01h@400B
20/05@lC01@=500D3A<050hB01@=4`0;10/06A<G01PB5`0D3A@03PP<01@=4`0J51H0100001PC500P
6Q`07ALI00l92`0B30h2014;3@0Y010:300A2`d04P`>00d72@0>20X05@lA010:30080P@03@L901/E
5`0:10H03@L900X41P0?2@/04@/=018<30090`<04`/<01<:2`0@2PX04@T:01<:2`0B2`/04@/;01<:
2`0B2`/04@/;038Y;00C2`h02@<500/21@0D3@l03PP:01/B5@0?20X03@L901072P0>1`T05@`?01<:
3`0E2a800`0F3A803P0E30l030<801@;3P0B2@`05Pd@00h51`0@1`P060dA0146300J3aD04`P>00l5
2P0?10X04`P>0P0A1P`00`0C20h0;R<Y04Hk@@0601462P0H01H;3`0A1PX06@hB00`21@0/8BD03@86
014:300H3a8030H801TB500K4QL01P0401493P0=10T050hB01@;4`0>10`04`TA00/11@0B1`/05``@
01872`0<0@D03`@80P0>0`L04P0?10P04@H:01<8300D2@`01`0001<:3@0>1@T02P<:010;4@0>2@l0
5A0F01D>5@0@1`/04`X=00T0000F30h03`@800`11@805P/?00l04`P<01872`0A1PX05P/?01052@0E
2Ph06@hB00T21@0M5a/01@0100d5200E30l04`X=00l51`0A1`P00P0B1PP201@5200l00`3100H4Q@0
3@L80189300@2P`02`D600l62@0=1`T03PL900l62@0=1`T03PL900X32P0>1`h030D<00d63@0D3A@0
3PP<00X4200>20`04P`@014;3`0?2@/03@L;00H010090`L04@T>00`3200A2`l04@X>00l62`0=1`/0
9b0T01483@0=1`/03`P<01063P0>1`h060lG01/A6@0@20l040T@01063P0?1`h03PL>01063P0?1`h0
40H>01D;500@1Ph04@L?00P01P0F31<06a0F00P00`0H3A801`0001<8300H3A401`005?ooool001_o
oooo00T04`d?014;3@0>20X03@L9010:300B30h03PP:010:300?2@/00P0=1`T03`0@2Ph05@hE00P2
2@0400D030D=014:4P0C31@02P<;00d63P0L5Ad06Q<K014:4P0C31<03PP<00l93@02010:3P0;00d7
2`0<1PX03`T=010:3P0F41@03`T=00h8300I4aL05Q0D01D?4`0A2`l00P0?2@d08P0>20`030H:014;
3`0E3a<04P`@014;3`0G4AD04`P<01872`0E2Ph050T=01462P0D2@d05@X>00`11@0>0`L06@hB01L<
400[8RD050h@00`6200=1`T04`d?018<3P0=1`T03PP:01<=3`0A2`d02P@6014;3@0H4Q@04P`>014;
3@0@2P`200l92`0400X51P0D3Q0030H801LA4`803`T;01/061<D01<?400C3a004`l@00h:2`0<20T0
3PX;01DA4P0F4Q<061@E014=3P070`@03@P;00l93@0A31004`hB014<400B41<040hA00`:3@0F5QP0
4A4C01/K7@0E5AH05ADC01@E400C4a000P0B4Q00400B4Q8092@V00`<3P0C4QL07A`R00l>500@3aD0
@D1601TH7P0F5A/040lE01HE6`0K6R004A0F01DD6P0H5ad201DD6P0901/K800L72@010L>03`oAP0T
9bh03A0G024T:`0G6R4061/R00<06A`S02H06A`Q02d`=@0F6Al07B0W01@G7P0K7RH07b</01dT;00L
8b`06R4[01TR:`0L9Bh07RL`01TS;@0O:C@08B/g01hX=00P:CL09Bhm01<L;@0O9cT06b<f03<kD00^
=T/0>D5D05eWL`0M:C80:cQ102@a>P0^?4D09cDn02Hd?@0W>400;3e5020a>@0Z>d<06b`d02<f?@<0
9CM10800:ce902m1C@0Y>dL0:3Y802DgA@0a@e40AeQX041BH00]?d`0;Cm;02`nBP0]?d/0<dE?02Li
@`0a@dd0;d9902/nA@0aA4/0>DaB03Y=E00iCU`0<DME02m5DP0dBUL0=D]F04=II00jDET0>U5G03Q?
E00]ADT0<TY>03]AE`0hC5<0=TU@03E8C`0bAD`0<T=:02/m@P0^@4@0=4=802`k?`0Z>C`0;3Xm02`h
?00O:Rh09c8f02@`=00`?T40>dQ>02@b>00/>d00<D1703A4B`0eATh0;d1802Xl@@0/?T00;3]002dk
@00[>3h0:S@m02Pd?00]?4<0<3i702m2B@0_@dX0:D1602]0A@0X?D80:Ci302a0A`0Z?TD0;T9;02Tm
B00Y?4X0<dIE02i1D00Z?D`0;T5C02i3F00^A5/0<TML03=5F@0`@e@0;3e=02LgAP0R<cd08c4k02<`
>00L:C4082/a024Z<@0R:c808BXa01DN9@0S;3<0:C8g02D^<`0Y<SL07bT[01lY:P0K9BH09S0a038k
@02ma//0CEIK01@M8P0]=S/04AXO01TR9`0L9BX06R<X01`U:P0P:Bh07RHY01TM800U9RP0824S01hO
8@0N8B<05QXM010E6@0F6al07b@X01<J800U;38072<Y01TN8P8082DY01T07B8X01PM8`0>4aT04aLP
01LK900H72D05a/V01XN:@0M8B`07B0Y01`O:00I72D05QTR01PK900K7RL07B0Y024T;@0D5b00:Rdf
01<F7`0E62406QdV01`O:00K7RL061/T00805aXS00X061/T01HI8P0G6R<06A`U01LJ8`0E62406ATS
024Q:`0K6bD05ADO0P0F5R003`0I6B<06QXT01XJ900L72H07AdW01`O:00>4Q/06QdV02DX<@0O8R/0
4a<M01HF800E5Al05Q@O01TG8P0201HD7`0T01TH800E51X04a8H01DD6P0B4AL04a8H01PG7@0B4AL0
3`hD01XI7`0A41H061LM07elP02_[jl0?3`l01<C500B4Q@0928W01TG7@0>2a803PPB018<5P0D3QP0
81PU01LA6P0@3Q<061HK01HD6@0=2a0071XO02LU:P0E4aP04Q0E01HD6@0C4AH040hC0P0C41T0400B
3aP04PlF01<@5`0D4AP040hC018@5@0D4QD04Q0C014?4P0B41<06A@J00h93`0T7bD01@0601LB600C
3Q@2014<4P<04`hD01l04PdC018=4@0@2`l06A@H01@?4`0:1@T07APL01/F6P0E41@03`X>014<400B
3A403PT=01LB600A31806aHL00d83P0@2a405a8H00l:400K5Q`05a8H014<4P0@2a404@`B01TD600;
1PX04@`@01/F6P0I51P05Q4E00804PdA0P0A3100500B3A404`hB02@P8@0T82404`l@00l:3P0C3Q<0
3@P>01D@5`0B3AD04@/E00h84P0O6B@04`dG00l:3`0C3Q805a8F01<>4P0?2Ph04@`@0P0@2`l01@16
@DD02PD901LB5P0D3a<04P`@00<04`dA00<040X>00l93@0B31000`0C3A407`0D3Q805@lC018;4P0>
1`l02049028K8`0?210091dU00`63@0<1@d03`P@01XC6`0<1@d03@H=01<=400A2`d03`T;00h82P0>
20`03@L;00l93@0B2a805@hE01@=500A2Q803`P?010:3P0A2`l04P`@01<=4@0D3Q800P0F41@04@0C
3A4040X>00l93@0B31004`T>01<8300A20d05a8F034/<00R82<02`T;00`82@0<1PH06Q0A00X0000;
000060`@008040T@01004@XA01@=500E3QD0:b@[03</<`0<1P`030D<014:4@0B2a4040X<04Do@@1?
BD/04P`>02DO8@0K5AL04P`>0P0A2`d0100@2P`04@/=018<3P0D3Q0201dG6@0?01<=3`0B30h04@/=
014;3@090`D081XL01/E5`0600804P`>01PB4P0<1PH03`T900`61P0>20P04P`<00H04@/;02@04P`>
01<=3`0H4Q@03`T;00X41P080P@07aTK014;3@0=1`T03`T;01H@4P0Q6ad04PL?01L<4`0L4AL06a0F
01D:3`0>0`L050T=01@:300<0P<04@L800`20`0@1PL01`0001<83P0800<02P0502TN900A1P`03`@:
01873@0D2@l02`4601052`0L4AL201872`@04`P<01P02`4401052@0M4QH07Q<G04@i?@0[8RD03PH9
01<=3`0@2P`07aTK02@N8P0G4AD03PP<00h73P0D3A@03`P?01094@0K51/05@X?01T>4P0M4QH05``@
01872`0D2@d300l4200/01462P0B1`/05@X=00`20`0E30l04@T>014<4P0300D04@hE00401@0?20l0
2`@801@;3P0<0P<06Q0B01462P0>0`L05@X>01<8300@1@T04PL;00/0100=0PH03P<700d21P0C20`0
4`/?00<00P0F41804@/=018<3P0A20/040H80147200B1PP04`H801@5200E1@H050P;00P2100?2@/0
4@/=00`6200A2`d600d72@0N00l83`0B2a8040T@014:4@0G41L04P`@00l93@040080:28V03Pb=00C
3@l02`H701<=4@0@2Ph04`dA00/52@0>20`040X>014;3`040080618F01D?4`0=1`/040X>00`53009
0PT04``C01lH7`0F3aH030D<1P0>1`h0300@10h03P<<01<8400T6B40>Bhe00L00P0>0`T0<bP]01hC
5`0=0PH02`8401T>4QCooooo000Kooooo`0701H@4P0B30h03PP:00d72@0?2@/04P`>00h82P02014;
3@0A00l92`0<1PP03@L:00h83P0A2Q406A8I03D^=@0M5Qd02`D;00d63@0@2A004@XA01PA600A2Q40
3`P?00h8300?2@d0100@2Ph200h83006018<400>20`030H:01@>4P0B31003@L;0P0@2Ph0400>20`0
4@/?00h8300@2Ph04`dA014;3`0@2Ph050hB01@93@0B1`/050T=01<8300B1`/05@X>01872`0A1PX3
01@93@0>01072P0@2P`03`T;010:300A2`d04P`>04M1@`1?BD/07aTK00d72@0D3Q004P`>010:300A
2`d3010:3008014;3@0D3Q00618D010:300J51H030H801LA4`0@2``2018>3`04010<3@0D41404`l@
018>3`805A4B01L040`=018>3`0G4a@05Q4D01<=4@0B3A404@`@01@?4`0Q7b809R@W00X82`0D51H0
3`lA01LG6@0=3@l04a<B01@D4`0E5AD05ADF01@D5@0C4QD04Q4F01LF6`02018A5`0400d<4P0J6B40
?ci401XI7P805A@I05T04A0E01<B5`0D4aP05A@I01HE6P0D4aP05A@I01/K7`0T9BX06A`P01LJ7`0E
61d07B4U00lB5P0C5Q/04QHJ018E6@0B5AX051LK01DI7@0H6al06A`P01HI7P0N8BH0:Bdc01hS:@0J
8BL06b8Y01`S:`0J8bX06R<[01XS;00G8BX072H`01hX<P0L9S007BLb020Z=P0V<3d082Th01hW>00X
<D<09Bdo020Y>P10BUH0?dYD02Db>`0M:S<0:3Ho01l]=P0L:S<0D65Y05]/M00N;cL0=DI>02Hg?`0U
>3l07c4k024c?@0[?DL0;T1<02doB`0/?TX0;T1>02TkB@0V>4H0=TMG0394DP0bA540<TA@0353C`0/
?TX0<TA>02XlAP0a@dd0<4=:02e0A`0aA4/0=dY@03I9D00hBeP0=TUG03A8E00jCET0?51K04YNJ00k
CeP0HgMn03A8CP0203A9CP1F03U>E00gBe80=4M>03E8C`0dAdh0<45802m1AP0_@DD0;Ca102/j?P0/
>ch0:SPk02Pd>00V<CD0;cXn02/g?00]>T00=45702Le>`0]?4<0;Ci502m0B00cA4`0<45902Xk@@0V
>3`09SDj02Hd>P0X=C/09c@l02Hc?00]>d@0<d=;03E7D00bATl09Se502XnA00Y?4<0:Sa302Li@`0V
>480=4IB04mPKP0cAE@0<45A03=3E@0eAUP0<41E02m2F@0/@5P0:d1E02i0E00/?e009cQ802DeA00O
;ST08c0k02Ld?00K:3008B`b02H_=P0X<CP0A4eD01dV:`0O:2d0624V01hX:P0T;S0082X/02<];P0L
9RL07bTZ024Z;P1MIV/0:C8g01LP9@0B6b006B8W01PQ9P0K92T072DZ020Y;P0T;C8072@W02@X:`0O
828201`M7`0301LJ700D61/04QLK008061dQ00`05ahT010G7@0N9B/06QlS01dR9P0J7b<06b0V01XO
9@0B5ad06AdV01PL9@0J7RL201hR;@0701XN:@0K7RL06ahW01PK900F6B805aXS01TL9@0201LJ8`05
01dP:@0B5Ah051LP01TL9@0K7RL00P0L7bP301PK900901/N9`0G6R<05QTR01PK900G6R<05QTR01/K
9@0M7BL06QXT00806a/U00@061PR01LG8@0C4ad051@N0P0F5R00<@0D5b005ATR01LJ8`0U:3407b8[
01<C7@0I6B<05aLQ01TG8P0L6RD05Q@O01DC7P0J6B406APN01LF700H5ad04a8H01@C6@0I61h071/Q
01PG7@0D4aT040lE01hM8`1XIf/0VIVI030`<00H61T03@d?01XH7@0I5ad06aPO01dG8@0G4A/071HP
01TA7P0N6240518G00d;400F51T05aDJ01DC600H5Q/04a4F014?500D4QL04Q0E014?500C41T00P0B
3aP02@0C41L0514H01HC6P0>31404@lD01DC5P0C4A@04@lB018@4`0201LB600X00h93`0S7R@04@`B
01<>500@2a404@`B01@?5@0E41H050lE01<>500B3A405a8F01`G6`0G4QH04PdA00l:3P0@2`l03`X>
010;3`0D3a<04`hB00h93@0D3aD040/A00d83P0A318050lE00l:400M61h0=2le01XE6`0@2a4030L=
01/F700=20`04PdA01<>4P0>2@d03`X>01PC5`<040/?01`04@`@01<>4P0D3a<04`l@01HB4`0?2``0
3PT=018=4P0>2@l03PT@01D?600D3QP02P@>01H@6`0<1Q004`hC014<400B3A403`X>014<400F4AD0
4@`@018=4@0a;3004@`@01D@500>2@d04@/?0`0B31001P0@2Ph03`T=01@>4P0A2`l040X>018<4080
5@lC01<03PP>01D>5@0U7RD0BT=:00`7300m=Sd06A<I01H?5P0E3QD02`H;02<L8`1IDeP06Q@G01LA
4`0D3Q004`d?018<400D3Q804`dA00<04P/B00H050dE01<<4`0?2@d04P`@01<=4@0A2`l200h8300B
00l93@0@2Ph04P`@018<400@2Ph050X>01L<400F30l040X<00l;300D4A80518C00`92P0C3Q0040L9
01D:3@0H2Ph04`P<0`0@2Ph03@0A2`l04`dA04I0A01VH6@050lB00`62P13?D40<2X^01H@4P0I51D0
9AlQ01D?4@0@2P`01`0A2`d03`0<1PP06A<E01H@4P0=1`T05@lA010:300>20X04P`>014<3@0?2@/0
5@lA030Z;00J51@03`T901D?3`09014;2`05018<3P0=1`T03`T;014;3@0?2@/00P0D3Q007@0>20X0
3@L900l92`0@2P`04P`>01T>5P0H3A@05P/A01@93`0B1``040D901@93@0H3A0060h?028H6@0J4100
4`T:00l4200G31803`@:0146300Z7bD05``B00l42P0B1`d05P/A01<83P0B1`d050T?00@04@H:0P0@
1@T01`0B1`/04@H:01872`0;0P@07A8F00/21@0C2`h00P0>20X04@0A2`d040X>00d72`0<1PX04P/B
01@=500<1@`050dE028K8P0D2@h050T=01H;3`0B1`/03P<701462P0B1`/04@H:008040D901004@H:
01472@0;0P<04@P;00l8300=20h05Q4H01@A600W92/08Q/R00l8300E30l04PP901882P0@1@T03P<7
0P0C20`04@0A1PX04`P<00X10`0?10P050T=00d21P0A1PX08Q/N05iIG@0F41803PP:018<3P0:0`@0
50X=01462P0B1PP04`H8008050D800D04`T;00`6200@2P`0208400T31@0700h82P0N00h83@0>1`h0
3@H=00h73P0?20l03PP<01H@500910L05a4E01hH700;1@T04@/=01LA5@0<1PX040X>00`62P0;1@T0
3`T=00d72`0A2`l030H:00l93@0@2Ph030H:00X32P0K51/0;2D/01PA600:10X05PlF1P0>1`h0300?
0`d05@TB01L<500=10X05PdB01@93`0B1`d050/>00h51`0@1@T03`D801<831Cooooo000Kooooo`<0
40X<00l03PP:00`6200;1@L03@L9014;3@0B30h040X<00h82P0=1`T02P<:00h73P0400@06A8I00l8
3`0O61l00P0=1Pd010080@P05PlF01@=500K51/200l93@0H010:3P0A2`l04P`@018<400@2Ph03`T=
014;3`0?2@d03PP<014;3`0E3a<040X>014;3`0@2Ph03@L;00h8300F41@050hB00`62P070PD091hR
03li?@0F2`l040D90P0A1PX02`0C20`060dA01052@0H3A405``@00`31@0O51P04@P;014;3@0C3@l0
4P`>00803`T;00L06aDG01LA4`0<1PP040X<01@>400B30h04@/=00804P`>00`04`d?01@>400E3a40
6Q@F01lI6`2=QhT0GEMI01XD5P0O6A/061<E01PD5@0F4Q<2010<3@15014=3P0@30d020@5014=3P0F
4Q<0510A01LC500A30l04`dA018=4@0?2Ph040/?01dK7P0N71l05aDH010@4P0F5QP05aLI018B500E
5AL051@F01<C5@0C4QL051<H01DD6P0920h03@`B018A6@0A41P0BdYB01dL9@0B4AL051<H01<B5`0@
3a@06aXO01XI7P0E51T05QDJ01LF6`0E51T04a8G018B5P0F5a/07b<T01<G6@0K7b8041@F01dQ8P0C
5aX05QXL01PL7@0I7B005a/M01DI6P0J7Ql07R8S00<72P0J7R409b/_01XO8`0I8B@072@X01hU:`0N
9b`07BH[01/T:`0H8R/072H_00807RPa0P0M9c403@0T;SP08B/g02H_?P0S;3/06R<b02H_?P19Del0
AU5K024^=`0U<S/08Bhg018P:@0R<3T00`0L;CD00`0W>4009SLo02Hi@00202@f@00a02TkA@0]?d/0
;T1<02LiA@0`@U00;T1>02DgA@0_@500;Cm=02i0C@0mCe/0@59N02m1C@0_@D/0;Cm903=5C`0dAdh0
<DA;03A7CP0hBe40=TU@03I:E00mDE`0=d]F03=7D@0`A4d0>dmH05AXL02calh0BUmU03eBE`13F5d0
?E5G03E9D00cATd0<TE<0313BP0/?D@0:C]002Tk?`0[>Sl0;Ca002hm@00a?d80;3Xm02Dc=P0Y=S`0
9S<i02Tf?00202hmA00c0350A`0]?TH0;3e50311B@0]@4L0:3]102@g?@0R<cX093@k02Lf?@0X=Ch0
9c@n02`jA@0_@4X0<TA?03A8D`0]@dd0<D==0393C@0b@T`0;3Y702TiAP0kBET0D5e^02dmC@0/>Th0
;CU?03U8G@0jAel0BE]c03]?I`0bA5X0>4YN03M:F`0X>4T0:cQ802@b?@0B7bT0218K01lY<P0Y=3X0
82T`030g?`0X;cD08RT_03U0AP0R:Rd07bLZ02<[;P0N9RP08b/]00806b<U00L07BDX01LO8P0E7B00
4a/N01PP8`0I8B@051`O00807BDX01h06b<V01`T9`0K82@08BDX01PI6`0G61X06AXL01HI6`0G6ah0
5AXN01PM8@0A5QX05ahT01hU:`0R:Bl07B8V028W:`0L8BD061dS01/P9P0J7bD06AdV01DI8P0G6b@0
6alZ01LK9P0=4A`05QTR01LJ8`0E624201<F7`0901@G800H6b@08RD^03XmAP0I72D061/T01DH8@0F
6B806A`U00806QdV00<06ahW01`O:00I72D00P0E62402@0I72D06QdV01XM9P0L72H06ATS01DE7`0G
5b405QHP010@6P0200h>600H01DE7`0H628061PR01TL9@0D62405QTR014D7@0?4Q/05QHP01TI8`0G
5b406ALR01`J9@0F51l04a4L01DD700B4AL04A0F01<B600A41H04Q4G01<B600H5ad05QDK0P0C4QP0
3P0=318051@G01@D5P0O7b404a<E018B500H5Q/04a0F01DB6@0S7RD05A0H01/E7`0?1a807QPQ0P0E
4aP0100F51T03@/@014?500J61d201<A5P0601DC600B41D0518G01DB6`0D4AX04a0I0P0B3aH03P0C
41L0518G01@B5`0C4A@04@lB018@4`0H5QT050lE01HA5`0O6R000`0400`73@0B3A<050lE0P0E41H0
2P0D3aD04PdC010;4@0@2`l04PdA00h93@0<1`/04PdA010;3`0D3a<2018=4@804`hB00@04PdA010;
4@0@2a4030L=0P0E41H03`0:1@/03`X@00/7300300@0GEQN028M8`0>2@l05Q4E010;3`080`L08QdQ
03/f>P0G4QH05A0D01@?4`04018=4@0H00h93@0B3A404PdA01@?4`0H4aP05a8H01<>5@0@2a807aXQ
01LA6`0F41X05Q4H01hI7P0G4QH05Q4E01D@500J5AT08QdQ01D@500500@071LK010;3`0;1PX061<G
0P0B3102014;3`8040X>01H04@/?010:3P0B31005@lC018<400@2Ph06Q<J01/D6`0400@06A8I018;
4P0<1@`0;RL^00H01P0@2A006A8I00h73P0T7R803`T<00l92`0@2P`04P`>0P0C3A401P0>20`03`P?
0109400;10/03@H>018;4P8040X>0`0A2`l05`0@2Ph04P`@01H@500F41@04P`@01<=4@0M4aP05@T;
01061`0I4A808QhM065MGP1[J6T00`4201@?4`0J51P05@`A00h52P0E3A804P`@01<=4@0A2`l040X>
00804`dA00d0208601D?4`0M5a/05a4E00X4200H4Q@03@L9014;3@0B30h03`T;01@>400@2P`04@/=
00804P`>0P0A2`d0100@2P`03@L9010:300C3@l2014;3@09010:300?2@/06A<E00/51`0500407ALI
01dG5`0C3@d05a4A00804`d=00<050h>010:2P0@2PX0100@2PX01`0B30h03`T;018<3P0L5QP02PD6
00`6200@2P`00P0B30h01@0C3@l040X<00X41P0I3QH050T@00803`@:01404`P=01L<400900803`D7
01D;300Q5aP05`d=00d3100G310040D;01`A5`0A1P`02P4500/01P0D2@l04`P>01052`0201463004
01052`0@1@T03`@800l420803P<701D03@8601052@0C20`04@H:01872`0G310050/>014:300;1@L0
3PP:00l92`0>20`04`dA00`62P0?20l04@XA00l83`0?21004``C01462`0?10P00`0B1`/0100E2Ph0
50T=01872`0A1PX201052@0=0105200;0@804PT<01D=4P0Q7280ThjE06m/L`3XiN`0Mg1g01@=4@09
00<07aDF0105200200l4200@01462P0C20`04`P<01052@0B1`/05``@01462P0M4QH08aPL02HO8@2B
S8h03`T;00`6200C3@l01P0001@:3P804@H:0`0B1PX01P0<0`D05Q0B00d72@0B30h02P@600l92`H0
3PP:00l03PP<00X4200?2@d040X>00X4200<1PX01@03014;3`0@2Ph02P@8014;3`0=1`/04`dA00X4
200A2`l00P0@2Ph0300?2@d01@0301D?4`0B310030H:00T31`0C3A402`@;00d63@0B2a8050dD01<<
4`L03PL>00`04PH@00/1200O51`05P/C00l42`0F2a4050T?01@93P0G31003`@801052@0N4aLDoooo
o`006oooool02@0<1PP03`T;010:300?2@/030H800T31@0;1@L03PP:00l92`0200d72@0>00h82P0C
3A405@hE00P1200A2Q405PlF03</<`0@2A003`P?00d63@0A2Q4010040109400?2@d200h8300;00l9
3@0@2Ph04@/?014;3`0@2Ph04@/?010:3P0?2@d040X>00d72`0@2Ph00P0=1`/02@0A2`l040X>01@>
4P0K5AT04`dA01XD601TGV80ViFI01H;3`0301052@0G01<8300I3Q803`D800l4200D2@d04@H:01T>
4P0<10H040X<018<3P0A2`d03@L900`6200B30h05@lA01<=3`0>20X02P@6010:300I4aD05Q0B01D?
4@0D3Q000P0C3@l01`0O6A/0BD=50??]k`2HTY@05a4C00h82P0D3a400P0D41405`0A3@h03PX;01HB
4`0R7Ql02@D600/7200E4A804`l@01dI6P0E41804P`@01TD600J5AT050lC01@B5@0@3Q406ALJ014A
4`0D51H03@d?00h>400B4AH04A0E008040lE01`04A0F01@C6@0J6Al092<Y00T8400i>400d<oG0450
B@0@3aD04A0E01@C600E51T04a8G01PG700C4QL051<H01PG700I61d05aHK01DE600D5AL05QXK00dA
4P0>4Q<06ahO00P<3@0E6AX06AdN0P0L8240400J7Ql05a/L01DI6P0B5QL05ATJ03Hj?@0G6al04QLK
01`T9`0M92T07B@Z01/T:@0H8BH05QlT01TT:P0L9Rl201lY<P1i01hX<@0K9Bl09Bli02Tc?@0L9S00
9Blk02Pb?P0V<3`06bD_02D`>P0K:34082df01l/=@0O;CH0938k02`mA@0Y>T80;Ci601//=00Y>T80
9CPo02Dg@@0T=T009SQ202/mB@0^@4`0;Cm;02i0CP0/?T`093I40352DP0bA580:Sa903a>FP12E600
;d5=02m1B`0`@T`0<TA>03A7CP0cATd0=TU@03U<DP0gBU40=TYD03M;EP0_@d`0<4A=02m3C00fBU<0
<TI=06MkPP0hC580;T=802a1AP0`A4X0=DU@03I9D00cATd0;D1702/l@`0Y>T00:3Xn02`k@00]?400
9cHi02Xh>`0]>ch0:cTl02Pe>`0U<SP09c@j02Th?`0^?D@0<D9903A5C@0cA4`0<D9:02Pk@P0U>3l0
:3]102Lh?`0Y>D00:cY102/h@@0X=Cl0:SQ302/lAP0[?TT0;dE@02i5D00_?d`0<Cm:034oB`0Y=d@0
9S=303=0D00_?4d09C9503M3F@0P;480;CUA03E2F`13EFd0=DUQ0312F00mCf<0@eAV03Q7F00K:3P0
;C]604MCGP13CEH0C5IO02H`=P0L8b/0=Se502/b>00i@4H0JG1f01`T9`0202<[;P0501LO8@0L92H0
6R8T024Y:`0E7B000P0G7b80>`0L92L0>T9501PP8`0C6ah072@W01/S9P0F7R40620S01XO8P0I7B00
5aPJ01@E5`0F5aT06A`N01XN8@0A5QX06b0T024V:P0<4aT07bH/02H]<`0E6Qh0<3Di02db=P0J7bD0
4aPN01`Q9`0L82T06QhW01dQ:P0P92l06alZ010D7`0E62405aXS01DH8@0C5Ql04QDN01<F7`0J7BH0
7B0Y030c?00D5b004A@M00hA6P0F6B806QdV01`O:00M82T07b8[020S;00H6b@05QTR01LJ8`0J7BH0
6ahW01XM9P0P82X07AdW00805aLQ01X05QHP014A6`0C4ad04Q8L01LG8@0B4Q`04A4K01HI8P0?4Q/0
61/T01HI8P0I72D06a/U01HF800E5Al05aDP01XH8`0E4ah04a4L01LF7P0D4aT04a8H01LF700F5A/0
61LM01TH7P803@`B01<09RD[01PG7@0;2Q0071/P00@41P0S8bD04a<E01XJ700F51T061HL014>5@0C
3QD07aTR03`f@00N5R40:RD[01/I7P0E4aP05aDJ008040hC02005Q@I018@5@0C4AH0518G018@5@0E
4aP05Q<L01DB6`0D4AX04PlF014>5@0B3aH05Q@I01DC600B41<040hA01<A500J61/07APN00`73@0A
3180>cHl01TD6P0K5Q`061<I01LB600E41H04`hD014<4P0@2a404@`@018=4@804@`@00T04`hB00l:
3P0D3a<04`hB010;3`0?2Ph04@`@018=4@0C3Q@00P0>2@l04P0=20h04@`B010;4@0500H08QdS038]
<`1<Add04`hD018=4`0D3a<04PdA00H11@0M61`0=S4e018=4@0F4AD05A0D01<>4P<04PdA01X04@`@
018=4@0B3A404PdA01@?500D3aD03PT@018=500M61l030H@00X43P0>2A005A0E01LB5P0J5AT05a8F
01@?4`0G4QH04@`@01PC5`1iM7P07QTM00L21P0C3Q8050hB018<40804@/?0P0B31002`0@2Ph03`T=
018<400F41@04P`@00h8300=20d0100401@=500<1@`04P/B00807AHM01T04@XA01<<4`0=1Pd01004
01D?4`0=1`T03PP:010:300C3@l05Q0D018<400>20`05PlF01dF7@0@2A0030D=014:4@0@2Ph03`T=
010:3P0A2`l04`dA01H@500E3a<04P`@00803`T=00l04@/?00l62P0F30d08ALH01H>3`080P807QXK
02TV9`0100007aXN00/72P0@2A002P<:00/52P0@2Ph00`0B31001`0I4aL071HJ00@00P0A2`l030H:
00T31`0I4aL00P0>20X01P0B30h050h@014;3@0=1`T03`T;010:30804`d?01@04P`>010:300G4A<0
3PP:00l92`0E3a4040X<00l92`0A2`d050h@010:30070@<0@3Xl030Z;00R71`050h>018<300=1`L0
40X:01TC4`H03`T900h0208401<=3`0C3@l06A<E010:300d;S004@/=010:300;1@L03@L901@>400C
3@l03`@<01873P805@X@00l050T>01872`0A1PX040D800X00@0C2@X03`D501061`0B1`/07A8H020E
6`0D2@l05@X@0146300;00H00`0B1`d01P0>0`T02P0501@93@0C20`04PL;01462P8040D900P050T=
01H;3`0<0@D0304500L0000800804@T<00d72@803`T;020040X>01@>4P0>20`030D<00l83`0A2Q40
3PL?00X32P0?10T03@8601872`0D2@d04`P<01D:3P0D2@d04PL;01462P0@1@T04@H:01L<3`0B20T0
3PD800h62`0Y92X0/Zfd085nQ@3floX0OWMn01`E6@0700406Q0A00l41`8050T=01004@H:01872`0A
1PX04PL;01/@500L4AD03`@802PM8@0f:bl06a8E00h82P090`D02P@6014;3@0=10L04`T<100A1PX0
1`0B1@`04PP;018<3P0<1`P05@lA00L10`0>20X01P0?2@/07@0<1PX01`45010:3P0B31001`4500T4
1`0;1@T03@L;014;3`0?2@d03@L;00h8300=1`/02@<700h8300<1PX040X>00X5200A2`l030H:018<
40090`L0100200`72P0=1Pd03PL>00d63@0>1`h04P/B00L03PL>00`03P8<00h5300@1@d0304901L<
4`0<0@L03P<901H;400I3Q802@0200h31`0N4aLDooooo`006oooool600l92`0D00h82P0?2@/03`T;
00h82P0A2`d05@lA018<400<1PX040X>00l93@0>20`040X>01@>4P0=20/04@/?01LA5@0B3A00=2hb
01@>4P0B3102014;3`804P`@01804@/?010:3P0?2@d040X>00l93@0=1`/07ALK02HP900C3A4030H:
018<400;1@T040X>018=400B310030L:00h8300G4AD201872`0<01H;3`0D2@d04@H:01<8300?1@P0
4PL;01P=4@0D2@d04`P<01<:3@0A2`d040X<0P0C3@l0200A2`d040X<00d72@0=1`T050h@01<=3`0A
2`d04`d?0P0D3Q00<@0C3@l050h@01@>400G4A<06A<E05iHFP0o>C/04`d?014;3@0C3Pl03PX;018>
3`0E4A802PH701XF5`14@4406QHG00h:2`0F4Q<020@501<?400E41<050hB01D@500G4QH05Q4E01HD
5`0D4QD040hA01DE5`0<30h04Q8D03`l?`0?3Q@040lF01@C6`0E51`051<K018A6@0_;SH0<C0h01PF
8@081Q40:BLb01TG8@0G5Q/06QXL014A4`0D51H00P0G5aT03@0C4aD04Q8D018B500C4aD05ADG01DF
600B4a@08bLV018F5@0W:bX0;30_01`P7`0F6QT00`0G6aX201PL6`0901XN7`0I7Ah061`M04=7B00O
8bD0724T01XR9@0K8bH072@W00<06b@Y02P06B@Z01/V;00N:Bl07bTb01dW<00I8b`05b4Z01lY<P0P
:S<0=T1902La>P19Ded08bdf02Lb>`0S<3P082de02Xh@00R<CP0:SU0020a>00M;SD09SLn020a>00V
=ch09SU002@f@00U=d40;Cm90353C`0bA500;T1<03=5D`0fB5H0;d5?0393D`0^@4h0:ce:02/mB@0b
A500;Cm;0P0cADl0R`0^@4X0<dI=03=6C@0gBU40>DaB03I9D00bADd0<D==03I8D@1=H6P0@5=J03I9
D00jCE@0=4M>03Q;DP0dAdh0=dYA03E9D00iCE@0?E1G03I9D00/?dH0;3e402`n@`0W>Cd0:STn02ln
@P0X=cX09S@g02Xh?00^>d409c@j02Tg?@0Y>3l09SDl02`lA00`@DT0<D=:0353C00cADl0<49<02Tl
A00X>d80:CY202/j@`0[>D<0:CM202Pf@P0/>dP0;Ci:02/oC00^AE80;TEA02hnC00_?D/0<3e=02Xg
A`0S<4809S=6038oD`0/>4l0>dMO020/A@0jAV40>DEP03e=IP0gBF40<D=I03=4F00dAEL0<T9C02/h
B00V<ch092hi01hX<@0V<3T09c0g02L^=00K8RP0:2le01<K7P0/=3L06B4T01DM7`0J8R@06B4S02H_
;P0S;2/092d]01dU9`0A6A`04QXM02D]<00_=cX06b<V01DM800G7b805AdP01LO8P0L92L06QlR010D
5P0K71h04Q<E014B500L7b406QhQ02H[;`0H7B40A4U=00lF700K8RP061lU01PM8@0Q9RX07R<W01TN
900H7B<05Q/Q01PL9@0L82T08RH_02DY=00P92l061`W01LJ8`0I72D061/T01DH8@0D5b005APQ01HI
8P0B5Ah06ahW01PK900E624051LP01HI8P0I72D00P0J7BH02`0K7RL07B0Y01XM9P0I72D06QdV01/N
9`0H6b@05QTR028R;00Q8B/06QXT008061PR01005QHP01TI8`0G5b406ATS01<C7@0L72H0;2lh03<f
?`0C5Ql04A@M01@G800C4ad05ADO01<C7@0D4Qd05aDP0P0D4Qd0800H5al051<I01@C6@0G5Q`05A@J
01LF700M72806APN01<B600M72806APN010?5@0F5AX05A@I018A5P0G5Q/05A@I01DC600D4QL04Q0E
02<N9@0B3A@06A@K01TC6P12?D<06QPM018@5@0D4QL040hC014?500E4aP03`dB0P0B41D00`0@3Q<0
5A<H01<@6@0201<@6@804a0G01D05A8I018@5@0C4AH04a4D018@4`0C4A@061HI01<>500?2Q0061<I
05IAE`0V8BL04PdC01TD6P0G4QP04`hD014<4P0B3A<05A0F01LB5P0C3Q800P0D3a<0100A31004`hB
010;3`0A3103018=4@0601<>4P0@2a4040/A02HQ9`0C3Q@03PT?0P0B3A<01`0@3140GEQN02dX;P0B
3Q<0CDQ>01<>4P0B3A400P0A3104018=4@804@`@01<04`hB01@?4`0@2a403PT?00l:400@2a404PdC
01D@5P0>2@l061<I018=500D3aH0;BP_00h93`0A31404@`@01@?4`0A31003`X>00<050lC00H0D4]?
01PC5`0:1@T04@`@01LA5@0D3Q8201<=4@0701@>4P0E3a<04P`@00d72`0>20`050hB01<=4@02010:
3P0501dG6`0?2@d04@/?01H@500>2@`00P0A2`l0200;1@T04P`@00d72`0B31004`d?018<3P0A2`d0
4P`>0P0B31001P0@2Ph05@hE01XC6P0<1@`030D=01<<4`804@/?02T040X>014;3`0A2`l04P`@00l9
3@0>20`07QPL02LQ9@0K5AT04PX>01L=4P0F31004@/<01<=3@0A3@`04@d=01lL701?CE003`dA00d9
400?2a<03PT?014;3@0D3Q004P`>014;3@0H4Q@03@P901XD5P0E41402`D701`F600@2P`04@/=01@>
400A2`d05@lA01H@4P0E3a403`T;010:300201<=3`0B018<3P0@2P`04`d?01@>400?2@/04`d?01/E
5`0D3Q004@/=010:3014?T009AlQ04Y4AP0O6A/05@l?00/51@0C3@d04P`<0P0A2`/600l92@0>00`6
200@2P`02`D701XD5P0@2P`0=c4c00h82P0?2@/02P@600`6200A2`d030H801463P0B1`h201<83P0A
01<83@0B1`/04PL;01@9300=0`@04PP901471`0G3@h03PD701<83P0D2@l03@<801@93`0<0PL03`D:
01P=4`0D2@l00P0B1`d01@0?10X05@X>01<8300C20`04PL;008040D901H03`@801H;3`0=0PH060dA
00`31@0J4A@040T;014;3@0<1PP03@L900h8300<1PX04@/?00h73P0=1Pd04@XA018;4`0?20l04@H;
00h31`0C20`05@X>0P0@1@T00`0C20`04PL;01462P0201872`0I01472@0B20T04PT<01083@0C3Q@0
7ATO010=500/:C007aPO01P@5@0A20/03@D501<82`0E2Ph05P/?01462P0D2@d05@X>01872`0>0`L0
4PL;00h51`0D2@d06a0D01@:3@02014<3@0400l92`0D3Q005@`A01483@8040L<0P0@1`d01`0A1Ph0
4@X>00X41P0C3@l02P@604Q2A016@4801P0?2@/01P0A2`d030H801TC5@0M5a/03@L;00h830803@L;
00X03@H=00/42`0:10X03PL>00/42`0?20l03@H=00/42`0M5Qd05a4G0P0?20l02P0>1`h02`@;034Z
<@0e;cD040T@01<<4`0?20l030D<014:4@0<1@`600h73P0<00h2300B1a00:QlW01hD6`0A1`d04PL=
00h32@0?1@T04@H:00L0000D2@d03`@85?ooool001_ooooo1P0?2@/0700G4A<02P@601H@4P0=1`T0
618D065KG@0C3A404@/?00l93@0>20`03`T=010:3P080PH03PP<00P21P0B3100618F010:3P0B3100
3@L;010:3P0B31004`dA01H@500C3A4040X>00h8300=1`/200h8300C05I@E012?4003`T=01H@500I
4aL040X>00l93@0500<07aTM00h9300@2Ph03`T=01462P0B1`/040D901872`0A1PX03@8601872`02
01462P0301872`0C20`04@P;00803PP:00<03`T;010:300@2P`00`0@2P`01@0A2`d04P`>01<=3`0C
3@l04@/=008040X<00D04@/=018<3P0?2@/071HH00L10`0201@>400?01PB500@2`d03`/<00l;300C
3a002`L800`82@0C3a004@d>010<3@0?2``040`=018>3`0D3a805Q0D008061<G00@05a8F01<A500A
3a804Q0C0P0B4Q@01@0C4aD04a<F014@600C4A`05A<N0080518M00P05A@L08:1R@1OGVH08b8Z00l>
5P0D4a/061LN01@C60805QHH0P0?3a403`0G5aT061PJ01LG6@0G5aT03`lA00d=3`0P8B<071hM00lC
4P0I7A`0720O00lC4P0J7Qd08BDT01TM700201DI600R01HJ6@0H71/051PI01lS9@0H71l051PK01/O
8`0J7b<06R8U01XQ9P0Q:2h07bP]01LP9@0J8bP06B@Z01hX<@0P:S<07BL`01`V;`0N:3408B/d02@^
=`0]=d00;CPn02@_=@0Q;38092le03]7C@0^>d409C8h01TW;@0K:Rl08C0e02<e>@8093Hj02009CLk
02Hg?P0U>3l0:ce702<e?`0Z?4H0=4IB02i0C00X>TH0?U1N03a>G00eAeD0=TMG0312D00Z?4T0<TA@
02doB`0/?TX0=DMA03U;E@0]?dT0:Ca302/nA@0aA4/0<DA:0313B@0]@4H0<TE<03]>E014Eed0?e9H
03Q;D@80>TeD04/0;T5803E8C`0lCeH0;d=:02Lk@P0dAdh0=dYA02Tl@`0]?TD093Hk02@f>P0Z>Ch0
:STm02Th>`0]>ch0:3Hj02dl@`0U=3/09SDl03Y9D00V=cl0<T=;02m2B@0^@4X0=4MA03I:D`0`A4l0
:cm802@h@@0P<S`09cQ202XjA`0]>dP0<3m=02/kBP0fB5H0:Ci<03mFI00`AeD0;Si>03=0D@0b?e40
;CY=02`hCP0V<TT0:3A<02TeC`0_>UD0=D1L03E0GP0g@f40BEUc03e?I`0gAeh0:3M<02`kCP0hAEH0
@4aL02Da?@0X<Sd08b`e01@M9P0N9Bd08RL]028W:`0P9BT07B8V01`Q9@0L8B@04aPK00hC5P0D6QX0
7R@T03Pn?P0J81l00P0K82<201dR9@0b01PM800F6ah06b0S018G6P0C61/03Q<F01hS9P0[<3<04aLH
01@E5`0F5aT061TK01TL7P0G6ah09b``01XO8`0D6Ad03aHL01DL8P0B6Al05a`P01@I7@0H7B405a`R
01HK8@0O92X05a/T01`P:@0I7BH092Pc02lc?P0K7bX08RD^024T;@0H6b@07b8[02X]=P0F6B8071lX
01/N9`0H6b@05aXS01dP:@0R9Bh05QTR010C700B5Ah071lX01HI8P0I72D201PK900D01/N9`0G6R<0
51LP01TL9@0J6R@05QHP01hN:00I6B<04Q8L01PH8P0D51h05aLQ020P:P0G5b407alY03@g@01JGVL0
:Rdf01PK900C5Ql2018B700801@D7P0F51l05Q@O01DC7P0D4Qd061LO01/J800I61h201PG7@0301TH
7P0K6R006QTO00805QDK02d061LM01TH7P0D4aT0:BP^014@5P0P7bD04Q4G020N8`0B41D04a4F01D@
5P0F4AL05a8H01PA600E41H04a4F01@B5`0G5AX061HK01HD6@0E4aP040hC01LE6P0A3a@03P`A01LE
6P0=2Q<04@hG00d:4`0O72<03@XA01@A600>31401`D:010>4@0X9RT040hA00h<3`0A318040/A01HA
5`0B3A<030L=01<>500I51X00P0>2@l0300D3aD040/A01D@5P0E41@05a8F014=400<1`/05A0D04U4
B00F4AD03PT=01PC5`8030L;00P09R4U00/6300Q72805a8H00l:400E41H03PT?01<>508040/A00D0
50lE01D@5P0>2@l040/?014<4002018=4@0>014<400@2`l06aHJ00h93@080`L04PdA00d8300C3Q80
6aHL018=500I51/06QDL014<4`0E41H200l:400:00`73@0K5Q`0:RD[01@?5@0A310040/?00/62P0G
4QH06A@H00d830H04@`@00P04@/?01<=4@0E3a<050hB014;3`0@2Ph04@/?00h830804@/?00<040X>
01@>4P0@2Ph00P0>20`00`0@2Ph03`T=00h83006018<400<01<=3`0D3Q003PP:018<3P0C3A4071HJ
00@00P0H4AP03PT>00X32P0<1@d04P/B0`0B31006@0A2`l040X>00d72`0@2Ph04P`@014;3`0E3a<0
4@/?010:3`0?20l04``C014;3P0=1`T06aDE01@?3`0>2P/04`hB00T62P0>2a805A@L00P52P0@2P`0
4P`>01<=3`0B30h00P0@2P`00`0A2`d04P`>018<3P02014;3@0O00h82P0Q6ad03PP:014;3@060080
4`d?018<3P0G4A<03@L901<=3`0H4Q@05Q0B00T31@0B30h04`d?00`6200@2P`05@lA00/51`0@2P`0
5Q0B01@>400B30h04`d?00h8200:10@03PP800l92@0H4Q803`T901@>3P02010:2P803`T900<05a4A
010:300@2P`00P0?2@/300h82P0B00/51`0?2@/04@/=010:30080P@05P/C00l42`0;00H03P<90146
2`0?10P04PL;01462@0@1PL04PP90188200@1PL040D91@0@1@/01P0;00H0A3To01<83P0:0@D05P/A
014630803`@800L08QLK00d41P0C20`04PL;00h31`0@1@T04@H:00804`P<00P04@P;014:300<1PP0
2`D700`6200?2@d04@/?00h830<03PL>00/03PL?00h73P0A1P/04`P<01X?4`0?1PP05P/?00l4200B
1`/01`0001L<400201462P0/0106200A1`P03`H900h62`0;1P`02`H=00D32@0I5Qd03`P?014:3P06
00004`T:00d31@0A1PX07A8F00l5200>0`L05``@01462P0D2@d0304500/2100O51P08aPL01D;3P0=
10D030<600d6200>20X03@L;01<<4P0D3A@030D<00h73`0?2100100501H?5@0<1PP040X<00l92`0E
3a406Q@F00/51`0<1PP400h82P0301<=3@0?2@T02`D500803PP:01002P@80109400@2A003`P?00h7
3`0=1Ph030D=00X32`0?21001@0601<<500D3AD04P/C00`53@0>1`l03@H>0P0?2100100L5Ad040T@
00l83`0>1`h300d63@0>059;DP0Y8RT02@8900X32P0A2Q403PL>01L;5@0D2Q40ACY203hc>`0<0`P0
6PlE00l42P0@1@X201462P0301052@0?10Sooooo01?ooooo000Kooooo`H03`T;00P02`D7010:300B
30h040X<018<3P0K5AL04@/>010:3@803`T<0P0A2`h0200C3A0071HI018<3`0>20/04@/>00h82`0@
2Ph03PP<0P0C3A401@0?2@d04@/?01<=4@0@2Ph03`T=00<03PP<00d050lB00X5200C3A402`H901@>
4P0A2`l03PP<01dG6`0:1@P05Q0D00h9300?2@d050T=00804`P<00D06a0D01X?4`0D2@d05@X>0187
2`0201462P0401872`0A20/03`T;00l92`<040X<00@04@/=018<3P0B30h04@/=0P0?2@/00`0A2`d0
4`d?018<3P02018<3P0E01<=3`0G4A<0618D014;3@0F41802@@501D?4@0C3Pl0510A01HB4`0D4140
40`=014=3P0E4A805Q8C01DA4P0D41404`l@01@@4@0E41805@lC00805Q4E00D05A0D018@4`0C4A@0
518E01<C5@0201@D5P0@01@D5`0@3aL04Q0K01@B700C4A/04Q4I01@C6P0H5ah051<J014@5P0C4QT0
51<H014@5`0D51H05QHG01LG60804a<D00l06QXK01TI6P0F5QL04a<D014A4P0C4a@08R<T01@F5P0L
8200Jfm_02<W9`0E6AT051PH014E5@0I7Ad00P0J7Qh0600O8b<07R8S01HJ700L82@06alS01`O8`0M
8BL05a`Q01hU:P0J8BP07B@[01dV;00O:2l09Rlg01PR;00M9c8082Xc01lY=00P:S<08R`f01lY<`0O
:C809Blh02D`=`808B`c00L07bX`020/<P0N:c407R/a02Dc>@0D8bP08S4f00<08S@h00X09CLk02Pj
?P0^@DP08cDo02doB@0[?DL0;3i:03a>FP0hBUH0?4iL0P0`@U002@0iBUX0:ce;0353D00^@4`0;3i:
0353C`0bA4h0;Cm90312C0020354B`0@0313BP0_@TP0;T5702i0A@0Y>d00:ci303E7C00jC580>D]B
02m1B00fB500<TA<03U;DP0lCUH0;d9902a0A`80;d9904H09SU002Hg?P0U=c`08cDi02Lf>`0V=CT0
93<f02Pf>@0V=CX0;3]202Xj@@0X>3l0<D9902`mA@0]?dL0;D1802i1B`0bAE00<dMA0314C`0_@dh0
;41:02XlA`0W>4D093A202XiA`0[>dX0<TAC04QIJP0[@500:D1?03A<F`17FFT0@E5U030nD`0W=D/0
:CU@02LeC`0lBF@0;3YF03U7I00lB6L0<CmP03Y7IP12DV`0?DiW04mOMP0gAU/0<D1C03=0D@0Y=DD0
9S4m02H_>P0I8B/06b<]01`S:P0K82H07B4V020T:00N8RH06QhR01<H6`0I7R004AHF01DJ6P0J7al0
9b`[01HK6P0M8R806QlQ0P0H71h0100K7b407R8T01/P8P0@51H201/O8@0801TN800@51H06Q/M01LH
6P0E5QP061TK01TL7P0H71l201HK7`0J01LL800K8RP0D5MM05ELHP0O92P061dQ01XO8`0L8BL06QlU
01`Q9`0P92d06alX024U;P0[;cX0;30k01HJ9@0R9Bh07R4Z01XM9P0D5b007R4Z01LJ8`0K7RL07R4Z
01dP:@0I72D201LJ8`0602d`>@0a=3d05aXS01LJ8`0M82T06ahW0P0J7BH07P0S9Rl06ahW018E7P0J
7BH051@N01TI8`0E5Al06a/U020P:P0K6bD08B4[028R;00G5b404a<M01TI8`0F6B806A`U00d@6@0?
4Q/04aHO01LG8@0F5R0051@N01DC7P0F51l0518M01<A700F5Ad061LM01HE6`805A@J00<05QDK01PG
7@0H5ad00P0F5A/02`0H5ad05aHL030_=@15A4/05QDL01TH7`0>3A<07AXP01HD6@0E4aP05a8G0080
5Q4F00D05a0F01PC600@3Q<03`dB01LE6P02018@5@0K01DC600K6Ah04a4F03Tg?00@3Q<071XO00X8
400D4AX04@hG00d:4@0K61l04PlF010>4`0?3A8071XM034_<P0K6A`04a4D01LB600C3Q@040/A00h9
3`0A31808ahT03Pc>@0R7B<04@`B00804`hD00L05Q4G00l:3P0E41@04`hB00`72`0;1PX05a<F0080
50lC00H04`hB01HA5@0W8RH050lC018=4`0D3aD200l:400:01<>500B3A<04`hD01<>500A318040/A
01@?5@0I51X040/?014<40804PdA01X04@`@010;3`0;1PX04@`@01/F6P0U82@05Q4E00l:400B3A@0
4PdE010;4`0B3A@050lF00l:4@0@2a404`hC010;400B3A805A0E010;400I51P07QTM01D@500A3100
50lC014<40H03`X>0P0A2`l2018<400>014;3`0@2Ph04P`@010:3P0D3Q804`dA018<400E3a<04P`?
010:3@0A2`h04P`?010:3@0?2@`6010:3@805Q0B00X04@/=01<=3`0B31003`T=00T41`0H4AP030D<
01PA600C31@04@XA0`0B31006@0A2`l040X>01<=4@0F41@04P`@00`62P0@2Ph04P`@014<500B4A/0
30XC010<4P0C3A0071HG018=300=20L05A0@01hI7@0;1`h030LA010;4@0@2P/04P`=01<=3P0B30d0
0P0@2P/00`0A2``04P`=018<3@02014;300>01XD5P0S7Al08adO02`V:00>20X04@/=010:300D3Q00
4P`>01D?4@0@2P`05Q0B00d72@0@2P`200l92`0D018<3P0?2@/03`T;014;3@0B30h03`T;00h82P0A
2`d040X:014;2`0@2PX02P@400l92@0D3Ph03@L7018<300?2@T03PP8018<300A2`/2018<3P804@/=
0P0@2P`0200N61X04@/=00/61`0C3@l02P@601@>400D2A4050T@0P0D2@l02@0C20d04PL;01@93@0C
20/04PP901@:2`0D2PX04PP901462P050146300901@93`0k<3H03@8801X?5@0A20`04PT=01H;3`0@
1@T04@H:00803`@80P0C20`201872`0:01@93@0F2`l05Pd@018:3@0?2@/03PP:00l92`0@2Ph04@/?
00h830<03PL>02803PL?00h73P0H3A803`@801<8300F2`l05P`?01<8300n<cL0:AhR01072@0G3100
5P/?0106200B20T04@P;01083@0=20h03@P?00X73P0>2a801`4701493P0F3A0030<401882P0P5AT0
<RL[01L<400800405@X>01@93@0@1@T04@H:0P0D2@d05@0@1@T03P@600h51P0=10H03PH800h82P0>
20`03PP=00/5300;10d04`hF00l:5@0M5R403@H=00h82P0?2@/02PD601@>400?2@/02`D700`62004
00h82P0600X4100=1`H040X:00h82@0<1PP03PP<0P0=1Pd02@0>1`l03PL@00l74@0?214050dE00/6
300D3AD0208900X32`02014:4P05038[<`0D3AD04P/C01<>500>1`l00P0@2A004P0>1`h030D<00`5
300<1@`0<BXa01`E700=1Pd03`P?0109400<1@`040@>01X>5`0C2Q0040L=01D:4@0?10X04@H<0187
30<04PL;00<04@H:ooooooooool04_ooool001_ooooo1P0?2@/01P0>20X04@/=00X41P0=1`T04`d?
00D00@803PP:0P0?2@/2014;3@0400h82P0F41803`T;00`620803`T;00D030H:00X4200?2@d04@/?
010:3P02014;3`8040X>0`0?2@d01`0A2`l06A<G01LA5@0?2@d05a4E00H0100C3A400P0@2Ph0100;
1PT040X>01<=4@0G310201872`0501T>4P0F2`l03P<701L<400C20`00P0@1@T0100B1`/04PT<00l9
2`0?2@/2010:3004014;3@0?2@/03PP:00l92`<04@/=00<04`d?01@>400C3@l00P0B30h04@0C3@l0
40X<02PR900@2P`03`X;02LQ8`0J51H03`X<014=3P0C3a004@d>01TE5P0F4Q<040`=01<?400B3Pl0
4@d>008040`=00<04Pd@01D?4`0E41@00P0E41@00`0B41<05A<F01DC5P0301@D5P0@01@D5`0?3QH0
4A0H01@C6`0C4QX04Q4G01@C6@0J6Al06APM01@D5`0?3Q<0410B01LG6@0@41004Q8B01<C4`804Q8B
00@061PH01XJ6P0F5QH04Q8B0P0A4A406`0B4a<06a`N02lc=02<T9809RX]01@H6P0P92D05QXM01/O
8@0@51D03a<F01TM7`0E6A`07B0U01/N900I72<05aXQ01<G7`0C5b008RTa01/R;00G7RP05b0Y01TR
;00M9C006R<b01`U=00201dV=@0401hX=00N:3808R`f01hX<P807bTb07/072H_020Z<`0E82H09C4g
02/h?P0L:Bl08S0e01l^<`0R<CH0838f01la=@0P<SH09CLk02Pj?P0Y?4<0:C]5028d?P0V>480<dEA
03Q:EP0gBED07c4o03A6E01<GV`06R/k03M9E`0`@Tl0;Cm;02`nBP0dAU80<dE?02/mA`0Z?4H0<DA;
0395C00_@TT0;d980313A`0^@480;3i202do@`0`@TH0<45802hoAP0b@dX0<T=;02hoA`0hBE40@U=K
03U<D`0fBU40:Se402`oAP0]@4L09SLn02Hh?@0S=CT09cHk02@c=`0Q<3<0938e02<a=`0X=ch0:CY1
02Pi@00Y>T80=DQ?02XmA@0[?DL0;D5<02m3CP0`A4l0<DE@03I:E@0cAe80<49>02`mB`0[>dX0<D5@
03E5E@0W>4P08cI702ToD00lEVD0<4]I03aAI00lCV80<45G02XjD@0a@e/0>daV03Y9IP1cQ:00PI6_
03Y9JP0iBFX0<D1P01h^B00c@e`0Jg^B03e<H@0X=dX0<3e>049;G00X<Sh09Rhj024X<P0E72H061hU
01LJ7`0J7B808B@Y02<W:P0P92L06alR020T9@0G6a`06QhM01`P7`0I7A`06QhM01dQ8P0L82400P0F
6Q/01@0K7b00720Q010D5@0J7Ql092PY00805QXK00h07B4R01lP8P0I6Q`05AHH01HG6@0H6ad061`O
01DJ7P0L8BD06AhR01LN900Z<CL08bX`024V:P806QlS0P0O92X0<P0J7bD061`U01hR:`0T:3405a/V
018F8@0J7RT06ahW01HI8P0S9Rl06QdV01PK900G6R<05QTR01XM9P0L7bP06ahW01PK900G6R<06QdV
01LJ8`0L7bP07b8[014D7@0F6B8061/T01`O:00M82T06ahW01TL9@0H6b@061PR01TI8`0C4ad05aLQ
01`L9P0H62808R8/01@D7P0L72H05QHP00h>600G6R<04QHO018E7P0I72D06QdV01HF800E5Al061PR
0P0I5b80100H5R405aDP01HE7@0E51X401@C6@805QDK04h05A@J01HE6`0F5A/04a8H010?5P0E51`0
20L?01TH7`081`d05Q<J01`J800F51T061<G01HA5@0D3a<05@lC01HA5P0=2a004a4F02LU:P0I5a`0
4a4F03Le>P2<RXl06aTN01TG700A3a@06aTN02@Q:P0>2a@02PL@03`i@01iMWd06aPO014?500?3A80
3@/>01PF6@0@3Q404@lB014<4P0B3A<04`hD018=4`0A31805Q4G01lJ800D3aD03`X@01D@5P0D3aD0
4@`B01<>4P0F4AD04`hB014<400H4aL050lC00l:3P0C3Q804@`@01/F6P0e<3@05A0D01<>500@2a40
5a8H01HA5`0>2@l04PdC01@?5@0C3Q@05A0F01@?5@0?2Q003PT?010;3`0A3102018=4@0J014<400@
2`l030L;014<400D3a<07APL01HA5@0D3aD02@@;01@>600L5R007QTP01PC6P0:1@`03`X@00l:3`0C
3Q8040/?00h93@0F4AD040/?01XE6@0D3a<03@P<018=4@0E41@6014<400801<=4@0A2`l04@/?014;
3`0B31004`dA010:3P0?2@d201<=4@03014;3`0C3A404`d?008040X<00<04@/=00l92`0>20X0200@
2P`02`0A2`d050h@01D?4`0B31005Q0D018;4P090`T05@hE014:4P0B2a804P`@00804@/?0P0@2Ph2
00h8300B010:3P0A2`l040X>00l93@0<2aD04QDT0000300>3QH00@0200h:2`0A2`X03@P501TC4`0a
:bd05A0F00H1200A2`l040X:0`0A2`/2010:2P03014;2`0B30`04P`<00804@/;00H03PP:00l92`0?
2@/06Q@F00/51`0G4A<2014;3@08010:300C3@l04@/=038/;P0H4Q@05a4C01<=3`0B30h201<=3`80
40X<01004@/=010:300@2P`04@/=00l92@0>20P02P@401D?3`0F41002@<301<=3@0K5AD03@L700P2
0P0@2PX020821P0@2P`04`070@<040X<00H00P0>20X05Q0B00H00P0@1@d05@XA01@93`0A1P`040D:
01<8300D2@d04PL:01882@0C2@X050X:01882@0B1`/01@0B1`d0500?10X0DDI<01`A5`0@1@/05@X@
01L<4P0B1`/05P/?00d21P0L4AD02P0300`11@0E2Ph04PL;01462P0C20`05P/?01L>4@0A2@`04@/=
0P0B30h00`0@2Ph03`T=00h8300300h73P0i00h73`0>1`h04@H;01T>4P0C20`05`h@06iSI`0K41@0
7aDH01872`0>0`L02P4300d21P0A1PT04`T:0189300@20d03PT?00d83`0F4aX03@XA00H01P0_:2`0
GeII01hD5@0?1@L03@8600X00`0C20`08QLK01/@500@1@T03P<700l4200C20`03P<701<8300F30h0
3@@500h51P0=1PL03PP:014;3`0F41L04@`C048lAP1gM7h03``G02<P:`0:1``0@3Xl05MAD`0H4Q@0
100000`6200;1@L030H800<03PP:00@03PP900`7100>2@H040X:0P0<1PH01@0?2@`03@H=00d63@0>
1`l03PHA00803`LB00`05`lJ00d63P0B2a<04@XB018;4`0:10/01005020I8@0;10`03PL?00d63P09
0PX200l83`803PL>0P0?20l03P090PT02P<:00`5300?20l040T@00l83`0D218040@=00l4300A1Ph0
40D<00h32@0A1P`04PL<0P0C20`00`0B1`/04@H:ooooo`0Cooooo`006oooool600l92`04018<3P0>
20X03@L900l92`804@/=00@03@L900h82P0?2@/03`T;0P0@2P`0300;1@L03@L900/51`0?2@/04P`>
010:300E3a<03PP<00l93@0@2Ph04@/?01@>4P<04@/?00`040X>00l93@0?2@d030H:01PB5P0500<0
3`T=00d72`0<1PX040X>00l93@1QFel201H@500>00L11@0E2Ph04PL;01462P0G310050T=00d21P0G
310050T=01872`0A1PX04PL;0189300?2@/2010:30804@/=00<040X<00h82P0?2@/00`0A2`d0100C
3@l05@lA01@>400C3@l2018<3P0<010:300;1@L0618D01<=3`080P@03PP:01D@4@0C3a004@d>01HB
4`0U8B807a/L100A3@h0100@30d03`/<01<>400F41@301HA5@0301<A500E4aH05A<F00<051@F00l0
51@G014@5P0C4QX05A@K01@C6@0C4QP05A@I010?500@418051@E01LG6@0E5AD03`l?01@D500E5AD0
0P0F5QH0800G5aL06QXJ018B4P0C4a<05ADE01TI6@0L71`061TJ020Q9@0?4aH092P/00hA5P0@4aL0
6alR01LJ7`0H72004aLJ01LJ7`0P92P061/P01LJ8@0J7BD092L`028U;P0I7BL07B4/01lV<00L8Rh0
61hZ01PP:`0I8Bd05Qh[0P0M9SL01@0N9cP082Tj028[>P0R;3P09S0l00808B/e00H07bTc01/U;`0N
:3407BP^01l[;`0G9BP201PV:@0302dl?`0S<SD08C<e0080838d01D09CLi02Tk?`0V>D00=dUC0353
C@0[?DL0:C]702@f@P0_@Dd0;T1>03E7E@16F6H0C5e]03i@GP0]?d`0<D=?02i0C00`@Th0=4I@03=5
C`0/?TP00P0cATd01@0`@dX0;d980354B00a@d@0;T120080;Cm102T0:ce102Tk?`0cA4/0<45902dn
AP0dADd0?TmI03M:DP0dB4l09SU002Lj@@0^@DP093Dl02@f>`0U=c/0:CPm02He>@0R<C@09C<f02Hd
>P0_@4P0:ca402Pi@@0Q<SX0=4I@02PkA@0/@4T0;T9=02i3CP0_AE00<TQE03E;F00^A540:Ca:02do
CP0b@e<0=dMG03M7F00a@U@0:Sa@02]1D`0202e7F00K0315FP0iCV<0=dYR02XlE00X?5D0=DMR03a=
J`0iC6X0@E=c03U9J`0cAVL0?dm`0392G00kBf@0FfZ103Q4FP0a?U40AU5S034jB`0O:CD0<c]70417
D@0b>D<082@/01DH7@0F6Qd06AdP00806QhQ02h06AdN01/O800F6Q/05a/J01XN7@0A5A@06AdK01HJ
6`0J7Ql05a/L01PL7@0N8R<06QhO01LK700Z;Rl0V9bM08N;S00K7b0051PI020Q8`0J6ad05AHH01HG
6@0H6Qd05a/N00462P0F6al0:2da038i?`0L8bT04aXP01`Q9@0H7B406AhR01lT:P0Q9R`06QlU02L[
=00J7RL06alX01XN:@0L82/07B4/02DX<@0F6B808B@]0P0M82T0100K7RL061/T01PK900I72D201XM
9P0P01TL9@0H6b@09RTb02LZ<`0F6B802`hG01dP:@0L7bP092L`01PK900N8BX0:2/d01hQ:P0J6R@0
51@N01LG8@0E5Al04a<M01PH8P0O7bT04A4K01/K9@0J6R@04a<M01TL9@0D5b002`hG018E7P0H6b@0
5aLQ01DE7`0H628201TG8P0301PF8@0G5B005QDM00805A@J0P0F5A/0<00E51X05QDK01HE6`0E51X0
5QDK01DD6P0C4QP05A@K01PF8@0B4AT0<2lg024P:00@3A@03``B01LE6P0I51P05Q8D01<?400D3Q00
7QTN01<A5P0=2a0061HK010>4`0D4QL0LFmd0?[ho@1<BTl01@<800h<4@0=2a002PL@01<@6@0I5Ql0
3P/B03Ld>`0E4QT02`T>01@B5`0H5QT081hQ01XH6`0?3A003PT?014<4P0E41H04`hD014<4P803PT?
00D03@P>014<4P0D3aD04@`B010;4@0201PC5`05014<400?2Ph050lC00d8300D3a<00P0C3Q804@0=
20`061<G00l:3P0C3Q@04PdC01TD6P0E41H040/A020K8@0M61h03`X@014<4P0G4QP05A0F01@?5@0@
2`l04@`@00804PdA01H04@`@010;3`0A31004`hB00`72`0D3a<04`hB01LB600E3aT03@PB0:VS[@2[
YJl03`XB01HA600A318030L<00l:3P0@30d03`/<01@@4@0=20`04PdA0P0?2Ph00`0B3A404`hB014<
4005014<4004014;3`0@2Ph03`T=010:3P@04@/?00D05@lC01@>4P0B310050hB014;3@0200l92`03
010:300>20X03@L900H040X<00h03PP:00d72@0@2P`04@/=01<=4@0B31004`dA00/42`0B2a8050dD
01<<500E3QD04P`@014;3`8040X>0P0A2`l00`0C3A4050hB01<=4@0200d72`0=01<E7`11B5X0728b
00d?6@030PL04`l@014<2P0B2PL03PH401<;300@2Ph03PL>018;4006010:2P03014;2`0B30`04P`<
00804@/;00`05@lA01LA4`0<1PP02P@600/51`0C3@l05@lA01@>400>20X03@L900H00P0T7R02018<
3P0F014;3@0<1PP03PP:01XD5P0=1`T03PP:010:300B30h04@/=00l92`0?2@T04`d=00`61P0H4Q80
50h>00`61P0K5AD08A/K010:2P0;1@D050h>00h820H03PP:00@01@0101TC5@0K5AL02`D70P0A2`d0
3@0C210050T@01873@0>0`T040D:01H;3`0B1`/04@H90147200B20T04`T901061`0B1`/01@0B1`d0
500>0`T02`8601<83P0C20h04@H<01hC6@0D2@d06PlC01<8300S61`04@H:01<8300D2@d04@H:0105
2@0A1PX050T=01D<3`0@20/04@/=0P0B30h00`0?2@d03PP<00h8300300h73P0J00h73`0>1`h050T>
01`A5@0E2Ph06Q0C079WJ`0O51P04PT;01462P0700007Q<G00L0000N51H04`T:0189300@20d03PT?
00d83`0610X01P<:01PA600D3140:b8U00X00@0@1@P201L<40805@X>0P0B1`/200l4200=01872`0>
0`L05P/?01`B5@0D2``04`X;00h6200:10H030H:00X42`0U82L0RhRA0<K2b`02018@7@0801@@5P1L
EUP0LVa^02dW:@090`D050h@00/51`0<1PP300h82P0700h82@0E40d04@`800/60`0<1PH03PP800h8
2`0200l83`0@00l8400>1Q403@D@00d54@0800/06a<N00X33@0E3AP040PC01L?6P0C2aH03`LB01<=
5P0600T02P8=01PA6P<03PL>014040T@018;4P0D3A@04P/B01@=500C31<040T@00h73P0<1@`05PXD
00/02@0G31@06a0H00h32P0?10X04@H<0187300201<8300301872`0A1P[ooooo01?ooooo000Koooo
o`H03`T;00T03PP:00d72@0D3Q004P`>00/51`0@2P`03@L900l92`0@2P`00P0?2@/01@0=1`T040X<
00h82P0?2@/04@/=00804P`>00P07ALK01<=4@0B310040X>00l93@0B310040X>014;3`804P`@0P0@
2Ph04P0B310040X>00h8300B310020<601D?4`0C3A402P@805aFFP0J51P05a4E00d72`0A1PX05@X>
01<8300F2`l060dA01H;3`805@X>0P0D2@d0100C20`04PT<010:300@2P`2014;3@04018<3P0D3Q00
50h@018<3P8040X<00D04@/=01@>400D3Q004`d?018<3P02014;3@0?010:300F41801P4201D?4@1C
CDl09AlQ01<>3`0?2``03@T:01DA4P0K5aP05a<D018>3`0C3a00510A00805Q8C00<05A4B01HA4`0G
4AD00`0F4AD0100D4QD05A<F01DC5P0D51H201<C5@0401<B5P0A41H04a8I01HE6`8051<H00X05ADH
01LG6@0D51@04Q8A01HF5@0H61D05ADC01@D500C4a<051@D0`0E5AD01`0B4Q805QHF01LG5`0E5AD0
5aLG018C500H6Ah00P0E61h01@0I728051LM01/N900H6b405aXP008071lU02406QdS020S:P0L7bP0
51LQ02@V<P0X:SL07R4/020S<@0I7b`06R0^01/Q<00O9cD09Bdk01hU=P0L93L06R8f01XR=@0M9CP0
7bPi01hW=P0T;C`08bdi02H`>`0T;ST07RPb01dW<00R;C<07b`_03]9C02?WJ00@U5D028a=00S<SD0
0P0S=CL01`0T=SP09cTk02Tk?`0lCeD0;d5;02TkA@0]?dT00P0bA5003@0U=d<0:ce;02@fA01HJWP0
aMKV055SL@0dAU<0>4YF0312CP0Z?4P0<49<03A6D00cADl00P0cATd02P0aA4/0;T5702i1A@0`@T<0
:cdn02Pj>`0W>C/0:C/o02Xl@00]?TD302hoA`1A03=4CP0/?dL0;d=:02m2B@0W>T409CPo02Hg?P0T
=C/09cTm02`k@00Y>3`09SDh02Tg>P0V=C/0>DYB02@e?@0[?4@09cU003a>F00dAe40<DE?02m3CP0a
AU40=4YF03I<F@0eBeT0:d5?02LjB@0Z?4`0;Ci>0350DP0a@E<0;d9C02<eB@0/@eD0:D=D035<GP0U
?580=DaR03eCJ`0_A5`0;4=K03]@K01CIhD0BEmm03M<K013EgT0=Ta]03mBM00`?e`0<D1I0350E`0l
B5h0>TMJ02diB`0V;d0092hj02D]>@0V;CL0<CQ202<W;`0O8RL07R8U01`P8`0J7R406AdP01TM7P0L
820082@T01/O7P0O8b4051TF01dR7P0>4Q<06AdN01PL7@0J7Ql08BDV01TM7P0O8b@03Q8C0080=3Pi
01l061`M01HJ6`0L7Al061TK01HG6@0G61X05aXL01HJ7@0O92P061dQ00hC5`0P9bd05A/Q024X;P0H
7B406b0T01XO8`0M8RP08BH/01XO9@0K7bP0:2`e020T;@0B5R406QhY02P/=`0a=3d071lX01PK900G
6R<08B@]00807b8[01X06QdV01TL9@0I72D06A`U01LJ8`0K7RL071lX01DH8@0S9Rl07b8[01LJ8`0I
72D07R4Z01@G800I72D08B@]01/N9`0I6B<05QHP01XJ900G5b4051@N01TI8`0M7BL06ATS01<C7@80
6QXT00D041<L01XN9`0@4a`04QDN01DH8@0201<C7@0801DE7`0G5B005aDP01HD7`0E4ah051<K01DD
6P0F5A/201LF700301HE6`0I61h061LM00<05A@J00<051<I01<A6P0G5B000P0E51`04@0B4AT040dD
01LE6`0F51T06QDI01HB500B3Pl05Q0B01dH700H5Q/05aDJ01hL8@0E4aP04@lD02HT:@1KFEh0;B/`
00805aDJ01<040hC03Xg@00W92d04a0I01HC6P0J5ah03``C010>4`0G5AX030X=00/9300C4A@04@lB
014<4P0C3Q@04PdC014<4P0E41H05Q4G008061<I00D05A0F014<4P0@2a404PdC014<400201<>4P09
01D@500C3Q8040/?014<400@2`l05Q4E00T4200@2`l06A@H00804PdC00`04@`B00h93`0E41H09b8X
03Ha=`0J5A/03`X@018=4`0@2a404`hD010;3`0A3102018=4@0E014<400@2`l03`X>01LB5P0A3100
5Q4E01@?4`0B3A<040XD01D?6P0]9c40;bTc01LA6P0>2A006aHL01TD6@0C3Q80510A01PD5@0C3a00
4`hB00<04@`@00<040/?00l:3P0?2Ph01@0?2Ph0100?2@d040X>010:3P0@2Ph200l93@09018<400C
3A405a4E01H@500B31005@lC00l92`0=1`T03`T;00804@/=00<03`T;010:300@2P`0100@2P`04P0A
2`d03PP:014;3@0=1`T03PP<014;3`0@2Ph02@8901<<4`0?20l06Q<K00l83`0C3A404@/?00l93@0@
2Ph04@/?018<40803`T=010040X>014;3`0K5AT0HFAb0=gYmP1lQIL04AHR00d=4P0Q7b003@L40108
100G3@/04@L801@:3@0H3Q<03`P:100?2PP00`0@2PT040/9014<2P02018=2`0>014<2P0A2`X03@L9
010:300A2`d03`T;018<3P0?2@/02`D7014;3@0B30h05Q0B010:300D3Q02010:30804P`>00@04`d?
024K7@0E3a404P`>0P0?2@/01`0@2P`03`T;00P20P0F41003PP801TC4`0>20P00P0@2PX00`0C3@d0
3PP800`61P02010:2P803@L90P0>20X200l92`0401@>400G4A<02`D701@>40803`T;00d05``D01@9
400A1P`04@H<01<83@0E2Ph04`P<01462@0A1`P04`T:01<92@0A1`P04@H:00D04@H<00d06PlE0147
300E2Q0050X?01P=4`0?1PX04`P<01462P0D2@d04`P<01872`0E2Ph04PL;00<040D900<04@H:0107
2P0@20/00`0@2P`00`0?2@d03PP<00h8300300h73P0Q00h73`0>1`h04`P=00/1100@1@T04`P<01D<
3P0A1PX03@@6024F6P0A1PX060hA01P=4@0C2P/04PP901482`0@20d03@P>00d83`0<2A0040dD01D>
5@0?20`050`>01<92P0A1`T050T=00l4200B20/04`T<00`31@0?10P040D900804`P<0P0A1PX0500>
10L03PD50107200>1`P03`T;01D?5P0B3Q@040dF02h[=P15@dl040hK010>700=2A803`T;01D?4@0>
20X0618D00d72@0;1@L030H80`0>20X01`0>20T05A0=014<200=20D03PP800l92@0>20X00P0?20l0
900?21003PHB00h64P0=1A801`0:01D=600B2aD0EDeH04]3CP0@2A<03`TB014;500[8bh05Q0I018:
5@0<1Ph03PL?00d63@0>1`h03`P?014:4@0B2a803@H=00h73P0?20l03PL>00l83`0@2A004@D?0146
3`0>0`/040D=01@9400>0`T04@H<018730<04PL;00<04@H:ooooooooool04_ooool001_ooooo1P0?
2@/01`0<1PP040X<00h82P0>20X04P`>010:300>20X00P0@2P`04@0?2@/03@L900/51`0;1@L040X<
014;3@0<1PP03`T;01D?4@0@2Ph02`D900d72`0>20`03@L;00l93@0@2Ph04@/?00804`dA01X04@/?
010:3P0@2Pd03PP:01LA5@0@2Ph07ALK00@00P0A30l02P@800@00P0F3aH02`@;01@>4P0A20/06@hB
01<:3@0@1PT04PL;0189300B20/05@X>01D<3`0F30l04`P<0149308040X<00P04@/=018<3P0B30h0
50h@01<=3`0@2P`03`T;01<=3`805a4C00<04`d?018<3P0A2`d00P0?2@/01`0>20X03`T;01LA4`0A
2`d09b4S00d72@0D41800P0C3Q801`0F4A@030P900h:2`0C3a004Ph?01@@4@0G4QD00P0G4QH01P0F
4AL04Q0E018@5@0A3a@04Q0E01<A5080518E00L04a8C018B4P0A4A404A4A00l?4@0A41D04a8G0080
4Q8D00T04a<D01@D500D51@05QHD01DF4@0C50l04A4>01LG5`0F5QH00`0G5aL08@0E5AH0410B01LG
6@0F5QP04a<E01XJ700M7R403a8G01DH7@0L7bH01@P?01DH7`0H6b806QdT01DH8@0J7BH05QTR028U
;P1>DEX0DeEQ024S<00E5b@071h[01PK:00M8Bd061h/01TO;@0H7R`082Hd02Xa?`0S:S`0<CQ;02T`
@`02028Z?@0@01lX>@0J8c@072Dd01lY=P0X<Sh0:C<o024[=`0N:3808Rdc02Pe>01QKg80kogo069a
M00M;3408c8g02Dg>`809SPl01L09cTm02Tk?`0Y?480:Se401`_=P18FV@0DfE_02XlAP0W>D<09cU5
02i0C00[?DT0AeUW03E7D`10DUd0?4iJ02m1B`0V>4<0:3Y402XmA00]@4L0:3]202Tl@P0202e0AP0R
02/n@P0T>3T0;T120355AP0_@TD0:C/o02Hi?@0a@dX0:S]302Li@@0Y?4<0=4E=0313BP0fBE00B5]R
03=6C@0T=ch0<DA:02Tl@P0V>Cd0:C/o02Ti?P0W=ST0:cPn02loA@1CI6/0:ca302doA`0T=ch0<TA>
03E9D`0dB5<0;d=>0357DP80>DmJ02H0=TaJ0398EP0aA5<0;3i=02@eA@0V=dT0:ca>0313E00R=DH0
9ce>01/bA00Y@e@093eA02m8G00bBF009SaC02HnEP0dBfH0?E9_04eTP`0`AVH0?U9e03A;K@11EGH0
<d=L041?I00/>Th0>DII030mCP0X=4@09Bhm01TS;`0S:cD08BPb01/R;00R:2l07R<Y01hS9`807b@X
00l07R<V01lS9@0J7Ql09BTZ01/O7`0M8B0051TE01TN6`0G6a`07b<T01LK700F6Q/06alP014E5P0B
5QL00P0F6Q/06`0>4Q<05a/L01<G600F6Qd05ALK01@H6`0H6Ad05QTM01@G700D6Ad05AXO00`A5`0M
92X07RD[00lF700I7R@08BH/01dR9P0K82H07R<W01TN8P0U:Rh0<SLm02<X;P0J7bD06QhW00lC7002
01`O:00W01dP:@0G6R<082</01/N9`0K7RP061XV01XL:00N82`071hZ01XL:00D5b006QdV02P[=00W
:S<04aHO01hQ:P0H6b@05QTR01lR:`0G6R804A@M01/N9`0M7BL08B4[01TI8`0J6R@06ATS010@6P0H
62803PhJ01XJ9P0G5b<0410L01PJ9P0K7bX0720[01lS;P0I72L05ALS00805aLQ0P0H5R401@0H5B00
5a@O01@B6P0C4QP05A@J00805aHL00@05QDK01TH7P0J6Al05QDK0`0D4aT0400C4QT04a8J018A6@0B
4AT07ahV01<@5`0B3aD0518G01LE6P0E4QD04`hB01HA5@0F4aH04@lB010>4@0B41D201DC600D01@B
5`0610T04PlE01@A600A3QD07Q/R018?5P050PT05a@L04=0A`0L6B005a@K00`:3`0J61d04a4D00h<
3`0H5QT03`d@00d83P0B3A<201<>500R01HA5`0A31803PT?00h93`0@2a405Q4G01TD6P0B3A<06QDI
01PC5`0B3A403`X>00X52@0F4AD04PdA01<>4P0D3a<02PD901@?4`0>2@d03@P>01<>500E41H050lE
014<4P0:1@/07APN014<4P0F4AL05a8H010;4@0D3aD040/?014<40804PdA04H04@`@010;3`0;1PX0
5A0D00d8300B3A404`hB01<>500E41L05@lH00X5300<1@d05@hF014:4@0@2A006A<G00`62P091@H0
510A00h:2`0@2`l04@`B018=4@0>2@h03PT?014<400A31404@`B014<400A31404@`B014<400C3A40
5@lC01LA5@0F41@04`dA018<400<1PX03PP<018<400A2`l03@L;00l93@0?2@/03PP:010:300C3@l0
5Pd@01D<3`0@1`X040L<00h82P0>20/03PP<00h82P0@2P`03@L901<=3`0>2P/04@/?01@>4P0B3A<0
2PD;00`73@0X8bX0CdYA024K8P0C3A404@/?0P0?2@d0500A2`l04P`@010:3P0C3A404P`@00T31`0;
1@T07AlY07AmSP0Z<D4020/E00X93P0J5QL04P`900`2000J40h03`D500P0000L4AD050`=0P0?2PL0
1@0>2@H03`X7010;200@2`P04@`900804Pd:02@04@`9014;2P0E3`l02@<501D?4@0I4aD03`T;00`6
200>20X05@lA00d72@0D3Q005Q0B010:300F418040X<014;3@0D3Q003`T;00h82P0X8R@07aTK018<
3P0?2@/04@/=01D?4@0C3@d0618B01D?3`10>SX0=2h^00`61P0?2@T04P`<01TC4`0F410200d71`80
3PP:0P0?2@/3010:300S06mYJ`0L5QP04`d?00d72@0?2@/04@P=00l52P0?1P/04PL=01062`0:0@@0
50T=01892`0A20T050X;01<:2`0A20T040D901062`0?1P/040D;01062`0?1P/04PL=00l52P0G3Q<0
3`H;00d2200A1P`04`P<01D:3P0X7B4040D901462P0>0`L00P0A1PX201872`0301052@0?1PT03`P:
00<03PP:0`0>20`500h73P0`00h52@0B1`/060lB01082@0I3Q804@P;01T?4`0K41@05@`?01@;3@0I
3Q803P@70107200?1PT03PL:00`5300;1P`040`B00@01@0700L0=blc01L>4@0I41402`<501<:3@0;
00@04@P;0189300800403@<701<:3@0D2@d03@<701@;3P0E2Ph040L901D<3@0E30l03PL900/52@0?
2Ph03`XA00d:4@0<2A803@XC01<@6`0000T040`C0P0<1PP01@090`D03PP:01<=3`0;1@L030H800<0
3PP:01003PP900P3000=20D050h=014;2`0>20X03PP;00`5300<1@d03PHA00h64`0?1a@040PE018:
5@0A2A@03PHA0P0E3AP03@0>1Q401P0901dF7P0E3QH01P07014:4P0@2A403`P?00h73P0<1@`02`@;
00X32P0;10/00P0>1`h0400?20l040T@00l83`0=1Pd040H>00h4300F31@05``D00h42`0A20d03`@:
01062P0@1`X04@H:01062@0>1@PDooooo`006oooool0?00J5QL03PX;00`82@0?2``03PX;00d92P0;
1`P05A4B00l;300B3Pl02`L801DA4P0?2Ph030L;00/62P0=20`03PT=00d8300G4QH02`H:00X52@0>
2@d030L;01PC5`0?2Q004@`B00X52`0=2@h05A0F018=4`0@2a4050lE01D@5P0A318030L=00/62P0B
30d04`d=00d72@0?2@/04@/?00d72`0@2A004``C01TB6@16?dL02`@<01@=500@2P/060l@00d71`0A
2@X01P0001/E5@0F3Pl040L800l92@0@20T04@P901`F60<04P`@00D040X>00l93@0:1@P05Q0D01<=
4@0200d72`0800/52@0J5AP05A4B01HB4`0D41408AdN01LC500E4A82018>3`0X01<?400D4140510A
014<4@0B3aH01`@;04E3A`081PL05A<D010?3@0@3Pl0De5B01/I7@1NFf807AXQ018@6P0>3QP05QHO
00d<500A3QD04`lD01<>4P0?2``071XG00X;1P0B4`d04Q@>01DG500:30/03a4@010B4@0B51<0418@
00lA3P0E5a@04A<@010B3`0H6QL0418?01DG5P806adL010051DG01DF600G61/051DI01HG6`0J6b00
6a`Q01PI7P0D51/041<H01<G6P0G6Ql05QTN01LJ800K7RD06ahW0`0H6RH05P0P8Rl0;c4n02hb?@0G
6bH05QXU01/O:P0J7RT07b<^01TM:@0P93007R8^01dQ;@0O9300728`02<Y>@0R:3X061la02@[?@0N
9CD0;CA401PQ<00T;Sd201`X=P0E02Hb@00F8Rh072H_02Xf?00[>3h0BEIL06]iOP1CHVT0:CPo01h_
=P0U=Sd09CHn020a>@0U=Sh09CHm03I7CP0jBe80G6ee03E6CP0a@TX0:S]300<0;d180;D0=TM?03]<
E00gBU40;3i802`oAP0[?TH0<4=:02Pk@@0^@DL0<4=902`o@`0[?T80;D1402/n@P0[?d80<DA802m4
A`0R=SX0@UEK02Pm@P1aQH/0;d9802a0A@10EEX09cY002/mA@0Z>dD0:ca603M9DP0jCUD0<4A;02e1
B00X?D8083<i03E7CP0W>Cd07bhe02dm@P0Q=3P08SDi02Tl@P0X>d80;4190396DP0`AU<0;dE@0316
D@0fCeH0=e1G03I<F010Df80=dYI02i1D00R=D@08cI503Q;FP0_@U40:Ca;02LkB`0Y?Tl0;45B02Pn
C00lDf40>e5S02@iC00Y?e@0>4eU03E9I00`AF80>Te^0394J00nDWD0>da_06IeRP1SL800935001hZ
>00K9cD082Xf02<]=`0L9S005b0Y02L`>@0R:c806b<[01dT;00K8RX072<[01`S:@0J8BL08BH[01TN
8P0I7R406alQ01dQ8P0K7ah05a/J01TJ701=CU007b0R01dN800R8bD07b0R01/L7P0G61X06AXL01<D
5P0I6Q`051PK01<F6`0N8RT082D[01@G7P0b=cd041DK01DJ800I7BD07R8[01TM9P0R9Rl07R8[01DI
8P0O8b`06b0V01`Q9@0T:B/07R@T01dS8`0R:2P04QPH02<Y:@0L8B@04aPL01<H7P0L8BL06AhT01HJ
8`0O8bh06AdX01HJ9P0E6BD07b<_03@gAP0a=4<092Pd01LI9@0I6bL05aTU01XM9P0L7bP05aXS01HI
800G6R406QdT01XM8`0D5ah041<J01DH8@0D5b007R4Z01PJ9P0B5200418N01XL:00B5240=3I301<E
8P0F62D03Q0M028X=P0[<Cl0O8:@04M<F00L7R/04A4M01@B7`0E4Qd05Q<M01XD7P0F41X0510H00H0
5A@J02<03@`B01dL8P16AD/08B0V00L6300G5Q`03@`B01LF700O7R@061LM01TH7P0G5Q`02`X@01/J
800<2a004@lD02PV:`0<2Pd04@l@00T7200G5AP04@lB01DC600<2@l05a@K01LD700A3QL06QLP03ll
A@0D4AP05Q@I01TF700_;C802`T>01<A5P03018@5@0Y014?500@3Q<040hC00H41`0@3Q404Q0C00l=
400C4A@030X=00h<3`0;2@`04a4D00l=400A3a805A4E018=4@0C3A405@lC01LA5@0F41@04P`@00/5
2@0F41@04P`@01D?4`0H4QH06A<G00d83P0A31<04`hE014<4`0D3aH030L>01<>5@0E41L081/R00X5
300L5ah040/A01@?4`0B3A400P0@2`l09@0B3A4050lC014<400?2Ph040/?018=4@0C3Q804PdA01<>
4P0B3A404P`@01H=4P0F31805@X@01052`0B20`01`01014;3@0G4Q@03`X>014<4P0C3QD04PdC010;
4@0@2a804PdC014<4`0=20l04@`B00`73P0A31<04@`B01<=4@0F41@03PP<02@N8P0B31001P0@2Ph0
1P0@2P`04@d<014=300A2`/050`?01<83P803`@:01P040D=01L>4`0J4AL03PL>01@>4P0?2``05a<D
018=400K6A`05A0F01@@5P0100D04PlF00h;4`0W92d0c<WB02dY<@0<1@`02`@;01@=500>1`h03`T=
01<=4@0=1`/200h82P0;00/51`0>20X04PhC00`;4@0:2@h030X>014=3P0D3Ph04@`:01491`0B2PP0
0`0C2P/01P0B30`040X:00l92@0A2`/03@L700l92@8071HF00<06A<C01D?3`0C3@d01`0B30`200X4
100@01D?3`0@2PX04P`<01<=3@0A2`/050h>018<300F410071HF010:2P0/9RH08A/K01H@400?2@T0
2P@4014;2`<04Ph?0P0A3@h2010<3@1@014=3P0P71d05a<D00`82@0[9bP02P@6014;3@0?2@/0C4I8
01`F600@2P`071HH05E?D@0E3a4030H801D?4@090`D03@L901<;3P0A2`d02P4401082`0?2@/04@P;
00l72P0>20X04PT<018:3@0?2@/060lB00d5200?2@/04PT<00/41P0@2P`03`H90149300C3@l02P@5
01`C5P0B2@`03P<701lD600[82@050T=00d21P0@1@T040H901L<400<0@D03`@801@93@0900<04`/@
00l93@0:10P02`D900L11@0>20`03@L;00l93@0@2Ph04@/?010:3P0?2@d030L:01H=4P0>20`050dA
00l62`0<1PX03`P<0107300>20`03`P<0107300A2@`03`T;00d72@0>20X300h8300K00l93@0600@0
71HH04@n@00400005PhA00l92`0?1PT03@H800d72@0A20/03`P:00d72@0?1PT03`P:00d72@0?1PT0
20<501L@5`0K5AT02`D900X4200>20`03`P>00`73@0<1`/02`H:008030L=00D03PP;00l92`0?2@/0
3`T;00h82P0200d72@0F014;3@0@2P`03PP:00@0000E3a401`4100d71`0=1`P02`D7010:300@2@l0
4``C00l8400:0Pd02P8?00d54P0A2AH03`LB00d5400C2aH02@8:01<<50803`P@0P0?20l01@0>1`h0
3@H=00d63@0=1`/03`T=00804`dA01@03PP<00T31`0D3Q803`T=00`62P0>20`04@/?018<400=1`/0
3PL;00d72`0?1P/03PL;00d72`0F3A802`<800h8300A20d02`@801@>4QCooooo000Kooooo`0401dI
6P0A3@h03`/<010<3@803PX;01T05A4B00/7200>2P/06QHG00d92P0;1`P03PT=00`72`0;1PX030L;
00d8300<1`/040/?00h:3@0C3Q80HeiR03lj?P0;1PX03PT?00`73@0A31807APN010;4@0400D03PT?
00<040/A02X03`X@00l:3P0@2PX04@/;00h8200@2P`04P`@00l93@0A2Q4030L=01XC6P1@BE405@dG
00/4300<1PP040X;01PB4`0>20T04P`=00`61`0B30d02PD600`61`0S7Ah03`T:014;3P0?2@d040X>
014;3`0@2Ph03`T=018<400<1PX02P@801<=4@0B310040X>018=3`0X92D0HUiO00h:2`0H51D201<?
40804@d>0P0B3Pl0;P0C3a005Q8H018?600C41T0:RP]020N8@0<2P/03P`<010>3`0F51L02PP=01/H
7`0C41/03@dH01DI8`0O7bT04a8J018?5P0H4aP071LK01@@4@0F514030d701lR6P0>4@/04aDB018D
4P0G6AL03Q0>01@F500H6QP05ALE020R800N81h0418@014C4@0B51805QPG01LI600F61L05aPJ01TJ
700D5AT04A8G01<D6@0F5Qh201PH800901LG800E61d05aXN01TL8@0F6Al05APO01HI800K7RL061/U
00806adZ00P061XW01XL:@0O8bh05QXU01lS;P0T:3<06alZ01PL9`807B4/01T06AdX01dQ;00T:3<0
8BDa01hT<P0M8c8082He01hV=00O9cD09blm02/d@P0I8c405b<`028^>`0H9340:3A002Pb>`0L9bl0
;3U002Ld>`2:V9l0Z[S0030nB00R<c`09CHo008093A000P0:ca602`mA@0]?TD0B5UQ0<3Af00kC5@0
;d1802Xk@P80=DI>0P0^?dL0<@0b@d/0:Se403a?EP0kCUD09CPo02/nA00]@4H0:Se102`o@`0[?T80
<4A502m3A00Z?Sl0;T9702m3B@0`A4T0;D5704EIG`0aADX0;T9702m3B@0Y?D<0<dM<02Tm@`0lCUD0
<d5;0352B`0eB4l0<dM>02]2B00W?T@08cY002a1AP0oDUP0<dA;02Xi@00Z?4009c/l02Pk?`0^@DP0
<dE?03Y>F@0jCe/0<dUF0398D`0bBU<0=e1G03QAEP0fC5H00P0eB5H07`0eAeH0;3m=02XmB`0_@U00
<TAC0353DP0^@4l0;3i=02m1D00]@e40<4EE02i3E00/@E@0<dQK03Y>IP16FW<0>4aW0355HP0cAVH0
AEQh041BLP0[>TX0<Sm:020/>00T<3`072Pd01lY<`0@6R<07bTb01hW<00R:S400P0V;SH01P0Y<S/0
7BH_01dV;`0b>D40<3Lo01PO9@806AhR03d0720S020T9@0Q9BH07R8Q01PI6`0O82803a0B020Q8`0K
71h07AhP01lP8P0H6A/071dO01@E5`0E5QP05QXM01/N9@0C5b0051PQ01LK9019CEH07B4Z01`P:@0S
9c0092Pa01TM9P0Q9Bh08bL`02lc?P0I7BL08BH/02DZ;P0P9BL0:S0^06abL02RZ:D0ATa:02D[:P0M
8b<05a`O01TN8P0J7b@07R<X01HJ8P0I7BL061`V01TM:00N8Bl07R8_028U=00P8c<06Qd/01LI9P0E
5b<06adY01dP:@0H6b@05aXS01`O9P0S9Rd082<Z00805QTN01T06ahS02<V;P0I72@06QdU01DH8@0E
5b805QTS01DG900V:3D0Q8JC028T<P0?4Al06al/00hE8`0T:ST0OhJC04iCG`0;3AX05QHS01@B7@0E
4Qd05Q8K01TC700K4ad061@L00D051<I01X05QDK01LF700A41H05QDK01DD6P0A41H06APN00l>500E
51X05aHL014@5P0E51X040lE01HE6`0L6b405QDK00l>500B4AL06ALK010>400A3a405A<F018@500B
41D06QPM00`:40804PlG00P02@H>01LD7@0B41H04Q0E00`:3`0R82D05A<H014?50<04Q0E00D04@lD
010>4`0@3Q<030X=00h<3`02018@4`06014?4P0@3Q404@lB00`:3@0D4QD03`d@0P0@3Q42014<400H
01<>4P0F4AD05a4E01<=4@0F41@03PT=018=4@0A31005a8F00l:3P0B3A<0AD17024L8P0>2A007QTO
04U4BP0W8RP0G5MM02@O9P0D3aD04`hD01@?5@0B3A404@`@0P0?2Ph05@0A31004PdA014<400A3100
4PdA01<>4P0B3A403`X>010<3@0B3@l04`d?01<:3@0E2Ph05`/?00l51`0F2Ph05@`?00h82P0G4Q<0
DdiB01LB6002014<4`0501D@5P0@2a803@P>01HA5`0D3aH00P0F4AP0200;1Pd04`hD01<=4@0F41@0
1P0401@>4P0C3A405@lC1@0A2`l0:00@30h04@h>014=3@0C3`l05`hB01@93`0B1P`050L@01463@0I
3QD03PL<00d6300Z92P04`l@014=3P0?30h03P/>02DQ9`0@3A<07AXQ00h<500=2a<04Q0H01PG8@0P
6bD05a0H00h73P0D3A@04P/B010:3P0B31003`T=00l92`0B30h03PP:00`7200C3@h04`d=010:2P0?
2@T2014;2`803`T900D040X:014;2`0A2`/04@/;018<300200l92@03014;2`0?2@T04@/;00<040X:
0`0?2@T6014;2`0;01@>3P0>20P040X:00X4100A2`/071HF010:2P0B30`03`T900h8200C3@d00P0@
2PX01@0?2@T05@l?01LA4@0A2`/03`T900803`/<0P0>2P/200l;300I018>3`0=2@X04`l@018>3`0=
2@X05Q8C01<=3`0B30h05A0A03Tc=@0K5AL04P`>00/51`0X8R@05Q0B00/61`0<1PP04`d?014;3@0G
4A<03@L9014;3@0>20X03@L900l92`0200h82P04010:300A2`d03`T;00d72@803`T;00h03PP:00l9
2`0A2`d050h@010:300K5AL05@lA00/51`0A2`d05P`?00/1100D2@d04@H:01@93@804PL;00/04@H:
01872`0@1@T04@H:01@;3P0A2@h06A<G01XD600=1`/04@/?00h8300600l93@0601PB5P0D3Q806Q@H
01<>4@0J51P0=S0d1@0>20`00`0@2Pd03`T;00d72@0400h82P0:01PB500=1`T04P`>04M1@`0I4aD0
7ALI00l92`0>20X03@L900h82P<03`T;0`0@2P`02@0?2@/04P/A014:4P070PL0>c@k03@]=0060@@0
40X>00d72`0300h82P0400d72@0?2@/040X<014;3@8040X<01T03`T;00`7200?2@/03PP:01D?4@0>
20X03`T;00/51@0>20P030H800X41P0?2@/03PL>00h73`0?21005@dH01P@7@0E3AX03PHC00l74P0@
21<03PLA00d63P0>2@l04@XB00803`P?00<03`T=00h8300=1`/00P0=1`/02`0>20`04@/?014;3`0?
2@d03@L;01TC5`0E3a<04@/?010:3P0>20`030H:00H03PP<00H02P@8010:3P0C3A402`D901PB5P11
>clDooooo`006oooool00`0A3@h02PH700`82@0200h:2`0i010<3@1IEEH07ATJ00@00@0A3@h04Ph?
014=3P0?2Ph03@P<00`72`0=20`03`X>00d8300;1PX04@`@00P31`0e<3@09R4U00d8300?2Q001005
01@?5@0m>3h081/Q00h93`0A318040/A014<4P0B3A<040/A00h93@0E3a0050h>018<300A2`d03PP<
00d72`0>1`h030D<00H01P0;10`0100501D>5@0C3A003PP<018<3P080`D05Q0D01@>400<1PT0618F
00`6200I4aH03PP<01D?4`0>20`040X>00<04@/?00l05@lC00h8300E3a<03`T=00d72`0K5AT05A0B
00/7200f<S<03PX;00`82@050@803PX;010<3@0A3@h00`0B3Pl01P0F4QT061DN010=50040PP02`T<
00D31P805aDF01d020H901HC6@0:1`h05a@M010?6@0F5Qh04Q4G01TF7@0M6b006aHK01<>4P091`P0
61LF00h@3@0F6aL0314=010B4@0H6QT07AlN00/=300A4a805ALF010B4@0K7A`07R0O018D4`0C5A@0
61XI01@F5@0201LI600301PI6`0K71h05AHJ008051DJ00L051@L01DE7@0F5Qh061PQ010C6P0B5A`0
51LN00<05APO00<0:Rdf01`O:00G6R<00P0H6b@0?`0J7BH092Pc01TM:00K7bX07b<^024U<00S9c80
7R8]01dQ;00F6RD061`W024U<00R9S408RPd02H/>P0i?dd0:30m028Z=`0G7b`05b4]03<nBP0D82`0
7b/g01dY=@0H9Bh06R@^01dY<@0O;3@0:cQ002hkA00_?DH0938m02@e?`0/?DL0;3a902Hf@`0X>4D0
:CY303=4C00`@DT0@eAL02Lh@00^?dL0:S]30311B@0b@d/0;d1802Xk@`0Y>T80:ci502XmA00/?dH0
:3]202e0AP0W>T00:Ca002Xm@@0/?d<0<dM80314A@0W>c`0=TU?0354BP0202i1A`2S02e0AP0O<SP0
;3m502Pk@@0`@dT0?e9H01lb>00Z>d80<T190352BP0aA4/0;d=:02e4BP0`Add093]102Dj?`0T=cd0
:CY103=2B@0Z?4409cXn02Xm@`0_@DT0=DMA03]?FP0kD5`0=deJ03E;EP0bBE@0=DiE039;DP0_ADh0
9CM502doC@0/?T`09SQ602`nC00Y>dT0<TAB02m1C`0W>DL09CM50312D@0^@E80:d1A02]0D`0T>D`0
8CI;02e2F00W>e<0:cmH02a0F@0W>eH0<4AO03e?JP0e@U80<3a801XV<P0C7b/08Bdi01dW<@0L9Rl0
92hg01hW<00P9bl06b8Z00/B6P0C72D04Q/T01`U;P0T:c<07RD]01LN900K82@06QlS01XN8@0L8240
7B4R01/O7P0J6ad06AXL01PI6`0O828061TK02X[;@0O82805aPJ024R900K71h07AhP01lS9P0E61l0
4QHO01<G800Q9Bh03A0I01TM9P0E6B806AdV01XN9`0B5Ql07R8[024U;P0l@4/06QhX01/P9P0P9B/0
92T/0498B02]/k40jNk]05YPGP0Q9bL06AhP01DJ7@0H7B406QlS02db=P0Q9R`05Q/Q01@H8@0C5b40
6alZ01TM:00G6bL061`X01LK9`0T9S8071hZ024S;`0G6R<04QDN01hQ:P0M82L0;2lf02X]=00I7240
3a8G010C600A51T051LN01PK8P0G6R4051LN01<F7`0C5R00@dEA01LI9@0R93008bDb00D95@0H7bX0
6Al[010G8@0B5R805aTU01PJ8`0E51`05a@M01LC6P0D3aH05PlG01LC6P0501<B600T010?5@0H5ad0
5aHL01PG7@0K6R004Q4G01HE6`0J6Al061LM01@C6@0?3Q@04A0F018A5`030PP03@`B02HU:`0Q82H0
61LM010>500?3A0071XO01HD6@0G5AX03P`A02HT:@0I5a`04a0G01DB6@0C4AH04@hD00l=4P0;2@h0
518G01`J7`0D4QL061HK0`0B41D04P0A3a@040hC010>4`0<2Pd02`T<01<A500A3a8030X=01hL7`0I
5aX04@lB01<A500=2`h040hA014?4P0C3Q804PdA01<>4P8050lC01@04@`@01<>4P0@2`l04@`@01lJ
7P1IE5P06QDI01TD6P0K5Q`00`04018=4`0F4AL020<902/V;00:1P/05a8H01hI7`0A3A8061<I014<
40@040/?01@04@`@00l:3P0@2`l04PdA01@?4`0C3Q803PT=00h:2`0E41405@lA0189300C2@d06PhB
01L;3`0I3a809ahQ024K7@050@8061@E01D@5P8040/A00`050lE010;4@0<1`d03`/@06mZL03FdML0
;2L]00`73@0D3aD03`T=01TC5`0?2@d201@>4P0300d72`0B31004P`@00<04P`@01d04@`@014>4@0>
2@d040/?01@;400D2@l05@X@01@8400K41H03@@901LB5P0@2`l00`0200l;300=2@X07APK01@?4`18
@dT09R4W00/83`0500T030PA01LD7@0300T091hW01094@0:0`X040T@014:4@02014;3`0800l93@0A
2`d04`d?01PB500U7b408adN014;2`0?2@T3010:2P803`T900<040X:014;2`0A2`/00P0A2`/200d7
1`03014;2`0?2@T04P`<00804@/;00@04P`<01<=3@0C3@d050h>1P0?2@T04P0A2`/030H601LA4@0@
2PX030H600/51@0D3Ph04P`<010:2P0=1`L03PP801@>3P0I4a<05a4A01<=3@0?2@T03@L700`61P80
30P90P0=2@X200h:2`0I00d92P0<20T02`L8010<3@0F4Q<04@d>00h82P080P@040X<01<=3`0=1`T0
1`4300X41P0B30h08A/M014;3@0<1`P04P`>00l92`0:1@H040X<04M1@`0e;c401`4300h82P0200d7
2@0900l92`0@2P`03PP:00H00P0E3a4040X<00`6200A2`d03`T;00<03PP:00@050h@00L10`0J51H0
:R0T0P0A1PX06`0B1`/050T=00`11@0D2@d04@H:01052@0=0PH03P<70189300A2`l0?cTm048l@00?
2@d05@lC014;3`0B31003`T=00h8300=1`/03PP<00l93@070PD03`T=00T31`070PD05Q0D01TC5`05
00h83003010:3@0?2@/03@L900<03PP:00L02`D700`6200<1PP03@L9018<3P0400006aDG00L03PP:
00l03`T;010:300?2@/03PP:00T4200?2100100401L@5`0N5ah0100200T31`0=1`/03`T;010:300?
2@/00P0=1`T03@0?2@/040X<010:300?2@/03PP:01D?4@040000>S@f06MQH`0P6Q`030H800h8200=
1`L00P0<1PP03P0=1`T030D<014:4P0?21003@D@00l7500@21D03`LD0149500@21<02@<<01D>5P0A
2Q805@hF0P0?20l00`0?2@d03PP<00d72`0400d72`0900h8300@2Ph040X>00X4200;1@T040X>01<=
4@0E3a<04`dA00H03`T=00H04@/?00d72`0>20`03@L;00`62P0C3A4Dooooo`006oooool09@0>2P/0
2PH700`82@0>2P/03@T:010<3@1QGEh08QhO00H20`0>2P/04`l@00X61`0A31003PT=00d8300?2Ph0
40/?00h93@0;1PX04PdA00P31`070`H02`H:010;3`0:1@/05a8H01<>500K5Q`01`88018=4`0=20h0
3PT?014<4P0C3Q@040/A00d8300F41800P0E3a401`0C3@l03`T=00l93@090`L01`07014:4@0M5Qd0
0P0>1`l03P0A2Q0030D<00`62P0I4QP030D<014;3`0;10X07AHM00l93@0=1``02`@;014;3`0@2Ph0
4@/?0`0C3A40300B31003`T=01PB5P0A2`l06A<G02@N8P0F4A<02`L800D10P0G4a@0510A01DA4P<0
4Ph?0P0C3a00?`0D41404@dB01DB6`0<2A005aDK00`:3@0A3a804a4D010>4@0B41D04Q0F01HC6P0C
41T0518I01lN8`0@3Q<04@`B010;3`0C3A40:B@X00X82`0@4A803a<B01<I5`0L8b402`l>01@F5@0L
7Qd03@l>010B4@0B51<03a4@01@F5@0F61L051HE01HH5`0G6AP03a0B01DF600G61X051DG01HG6@0G
61`061TN01LH7@0F5a`05ADM01HF7P0H620051LN01@G800F6B805aXS01PK8`0F6B009BP_01TL8`0E
61l05aXQ01HI800H6b80;S8k024U;P0201TM9P0b01XN9`0M8BX0720Y020T;@0I7BH05ATR01dQ:P0R
9S406R0/01dS;`0a=d<08b/f028Z=@0K8bh05R0Z05QTK@0Z=d0072Tb01/X<@0N:c@05b4[02Da>P0U
<S/08Rlh01`Y=00X=T408Bll02@d@@0Z>TL0:SY902DeA00V=T<09SM002m0B00`@DT08C8j0393B`0X
>D40:ca402Lh@00Z>d<0;d1802dnAP0Y>T80:Ca3028e?00W>T40:Se402`oA@0Q=3X202`o@`0502e0
A00dB4T0<4A502Hj>`0Y?4800P0/?dD0=00bAD/0:3]102Lj@00U>3h0;D1602`oA@0`@dT07S4g02`m
A00a?dP0<45902i1B00/@4L0;DA:02m6C00Y@4H0<DE<03A6CP0dADd0=49;02Pi?`0^@DD0<dI<03M9
D@0kCEL0?51K03]?G@0hCU/0=TaI0358D`0aBU40;DI=02a2B`0W>DL0;Cm=02<e@`0Q<d40;T1>02Pj
B00Z?4X0:ce;02HhAP0R=480:S]:03=5F@0]?e<0;3iD02doE@0[?E<0<49H02<eB`0]?eL203=5G@0G
03A6GP0gBEl06bPh030lB00[=d<03QPT01`V<P0N:38082Tb01lX<@0P9c409B`d01XQ:@0V;CD05AhW
01HO:00I8R/061lW01@K8`0J8BL08RL[01lT:00K7b800P0I7Ah0100G6aX05aPJ01/L7P0G61X201TJ
700<020Q8`0S92H0414C01PI6`0O82808b@V010D5`0L7bH05QXS010D7@093AH092Pa0P0L82T201TM
9P0o01HJ8`0R9Rl07B4Z01XN:@0L82X08BH/020U:`0O92L09R`/05AJF026S8/0:c4a01HK7P0M8RD0
724U01TN8@0G71l0:Bha024V:P0I7R8061dS01@H800G6b@05ATR01PL9`0I7BP05QXU01@F8P0=3a/0
4aDQ01/N9`0m@4T0GF1Y02DX;`0M82L05QTP018E6P0G6Ql06ahS01`P900D5a`03Q4F00lB5`0F6Ah0
6A`S01HI8@0W:S<092L`00022`0Q8bl06alZ00/B700B6B<05ahV01<G8@021@h051DM01HE6`0H5A`0
71TP01HD6@0H4aT06ADL00L05A@J00T03PdC01<B600B4AL03PdC01LF700F5A/04Q4G010?5@0B4AL0
0P0A41H05`0V9B/06aXP07EdNP22PHL09B@Z01HD6`0D4QL0514H00P5300>2a804a4F024O900F51T0
3`dB00h<4@0L6Qd040hC02XX;@091``03P`A010>4`0610T030X?00<04Q0E01404@lD010>4`0@3Q<0
6ALJ01DC5P0B41<02`T<014?4P0l>Sd08AlR01LE600E4aH040hA01DC5P0I5aX05A0D01@?4`03018=
4@0D00h93@0E41@05A0D01<>4P0E41@0BDA800h93@0910X050lE01/F700H4aT05a8H01`G7@0N6Al0
5a8H01/F700:1@/05Q4G014<4P0A3104018=4@04014<400>2@d03`X>014<408050lC00d04@`@00d;
300D4A805Q0B01<:3@0D2Ph06PlC01H;3`0=10H02@03018<3P0A3@h061HG00D040/A00P04@`B00d8
3P0`:c40PWf3010<4@0J5A/061<I014;3`@050hB00<02P@8018<400B31000`0B3100:P0A31004@dC
00/6300>2@l04PP@01<83P0G31804`T>00l42P0=10T04@/?00/7200F4Q<02`H901H@500X8RH02`D9
02`U;00C31<02@@;00T22P0E3QL02P@>00L02P080`X030D=00h73P0@2A003PL>00l93@0B31005@lC
01LA4`0<1PP0100000L10`0C3@h03`T900h8200?2@T04P`<014;2`803`T900<040X:014;2`0A2`/0
0P0A2`/200d71`03014;2`0?2@T04P`<00@040X:200?2@T04P0B30`02@<3010:2P0;1@D030H601D?
3`0A2`/03@L700l92@0>20P02P@4010:2P0C3@d04P`<00h8200=1`L040X:01@>3P<03PX;0`0?2``0
4P0;1`P040`=00d92P0>2P/05A4B01<?400G4A<040X<01PB500>20X04P`>00l92`0@2P`03`T;01D?
4@090`D030L8010:30804`d?00<0;BLY06aVJ01@BT`00P0>20X200d72@0A00l92`0@2P`03PP:00`6
200J51H050h@00l92`0C3@l040X<00/51`0G4A<030H8014;3@070@<04@/=01P?4P0=10L00P0A20/0
100E30l03`H901/B5@0L4aH201072P0C01D<3`0?1PT04P`@03La=@0k=CT03`T=01H@500>20`04P`@
00l93@0>20`03@L;00h8300?2@d06A<G00d72`0N61`030L:00L11@0600h83003010:3@0?2@/03@L9
00<03PP:00L03@L901LA4`0?2@/0208402<M7`0=1`T02@@500D03PP:0P0=1`T300h82P0<00d72@0=
1P`05PlG01/D6`090`T03`P?01`F6P0?2@d03@L;00l92`0A2`d03`T;0P0=1`T300h82P0;00d72@0<
1PP03PP:00X41P0;1PL050h@00H00P0A2`d03`T900d71`0=1`T00P0?2@/03@0<1@`04P/C00h73`09
0@`02P8?00d54P0@21D02`<>018:5@0@21<02P<;00L0200=1Ph00P0?20l00`0?2@d03PP<00d72`03
00d72`0400`62P0=1`/03`T=014;3`803PP<00@03`T=014;3`0?2@d02P@81P0?2@d01P0@2Ph02@<7
00h8300D3Q8040X>00T31aCooooo000Kooooo`0A01<?400?2``040`=00h:2`0:1PL03@T:018>3`09
1@H030P901DA4P0U8B803@T:010;3`0=20`030L;00h93@0?2Ph00P0=20`01P0@2`l04`hB00d9300D
3a<030L;014<4P803`X@00/04`hD00X62`0@2a4040/A00/6300<1`d04PdC014<4P0?2Q003`T=014;
3P0201H@4`0M01<=4@0E3a<04`dA00`62`0F41D06A<I01@=5@0>1`l040TA02dV;P0L5Q`04@/B00P1
200D3A@040TA018;4`0A2Q804@XA02PQ:00D3A<04P`@01<=4@0D3Q804`dA018<400C3A404P`@014;
3`0B31000P0A2`l0200@30h06ADF00l<300@30d04@d>01hJ6`0@30d04Ph?0P0C3a0201@@4@0U014>
4`0=2Q405Q<J00l=4`0?3A806ALK014?4`0<2Ph0518G00h;4@0J5ad04@hF01<A5@0/9bL08A/N01/F
6@0H4QD09b8V03hi?P0I6A`05ALJ018I700A6Q`092h^01/O8@0A4a<051HG014B5@0B4a@05AHH01DF
6@0C51D04Q@E01HG6P0G61T04a@G00l@4`0201@E6003014B5@0E5QT06AXN00<05aPM0P0G5ah01`0G
61l07R4[01`O:@0K7RP071lX01XM9@0E61l00P0J7B<201lS9`0k01XN8@0J7R806AhT01PL9@0J7RL0
720Y01lS;00M8BX0720Y01lS;00N8R/082@]02@X<@0P92d09Rdg01dT;`0M8bh07BH`01`U;`0N9c40
82Xc02Hb>P0G92d082de020]=P0L:C40:cDo01LR;00W<ch05B4]038oB`0O;CT0:3I302De@`0R<T00
8C5002@dA00W=dD09SM102Pi@P0Y>T<0:3U202Lh@@0X>D80:CY302Df?`0V=d00:ca502dnA`0[?4D0
9SU002i1B00aA4/0:3]202Tl@P0T=cd0:ci202`o@`0[?T800P0_@d@0D@0Z?Sl0:C]203A6C@0^@4H0
<TA;02Li?`0mCeH0<dE;02Xl@P0]?dD0:Sa302Tk@P0]?D@0;ci602dnAP0/?dD0:cm502U0AP0X?dD0
93]102@h?`0^@DT0;Sm802Pf@00W>400;T5503A7C@0eB500>D]G03U<FP0fBeP0=deK03M=FP0bBED0
<TYD02i7CP0X?DL0:S]902HgA@0L;C/07Rlm028c@@0P<Cl08S=002PiA`0/?DX0:3U602<d@`0_@5@0
;3eE02TjD00a@UP0=TMN02hoE00_@5D0<49E02XkCP0mCV00=dUK024b@`0[>4D09S4m01/V<P0oBED0
>D=?01TR;@0K92d072D^01`S;@0I7bL04QPP03a2B`0_>4408b`e01/T;@0P9bl07bH^01`S:@0T:Bd0
82DY01XN8@0201TM7P1E01TM700I71d06Q`O01`O8@0L7R407B0R01<F600A51H0<38e02d`<P0F6A/0
7B0R01hQ9@0K82H04QDN01PL9@0S9c005a/T01dQ:P0P92d0720Y01/O:00H72D082@]01LK900K7bX0
92Pb01/P9P0E6Qh06b0S01/Q8@0F71/0:c0a01dS900M8RH092T^01XO900K82@05AXM01LL7`0F6ah0
724T01TN8@0I7R<05a`Q01@I7P0H7B<06AhU01@I800H6RD07Al[01hP;00I72D071lX02HY<P0G6R40
5APO01LJ8@0K7R<06A`Q01HI7P0F6Qd07R8T01`P8P0O8bL0720T01XN8P0G6R005QTO01DH800L7bL0
2@`D010C6`0F6b404QPO014G700D5ah05QTO01`N8`0C51P03`hD01LE6P0D4QL0510F01HE6P0601DD
6P0<01<B600@3aD07A`R01DD6P0=318051<I01HE6`0@3aD06APN02DT:P0M72805aHL0P0D4aT04P0b
<CL0<2le01PG7@0B41L06AHN01PE7`13@4P05Q<J01LD6`0A3Q@040hC01@B5@0=2`h071XL00h<3P1D
DUH071XO01XH7@805Q@I100B41D0200A3a@040hC010>4`0=2`h04Q0C01DC5P0?3A003P`?0P0F51L0
0`0=2`h040hA00l=400201DC5P0301<@4`0B3Q8040`@00804@dA01@03``?010=400=2Pd04a0C00`8
300A3Q403``?00l:3`0B3A805a8G01<>4`0B3Q8050lD014<4@0F4QH02PH:00l:3`0C3Q<061<H014<
40@04`hB01@04@`@01<>4P0@2`l03`X>014<400B3A404@`@00h<3P0B3Q404Ph@018<3`0D2Pl05P/@
01062P0L4QL03`T<018>400@3@l03@/>00l:3P<040/@00`04@`A018=4P0D3a@050lD00X62P0K5Q/0
61<H00X62P0D3Q803@L;01/E6@0?2@d2018<40D04@/?01h04@XA010;4`0=1a005@hF01H<500C20h0
5``B01P?4`0n=CT06A<F00l<3`0?3@l02PP:01D@5@0@2Pl04P/A00D0100C31<03`P?01/C6`0:0@X0
5PdG01484P0B2A<040PA014:4P0D3A@04P/B00h73P0?2@d2014;3`0500l92`0<1PP05a4C038/;P0]
9bP00P0>20P00`0@2PX04P`<014;2`0200l92@05010:2P0A2`/04@/;014;2`0B30`00P0?2@T00`0A
2`/03`T9014;2`03018<3003014;2`0@2PX040X:00H040X:01804P`<00`61P0L5QH0618B00l92@0<
1PH05@l?00d71`0H4Q8081XJ01@>3P0@2PX04P`<01D?3`0C3@d03`T9010:2P0<1PH2018>3`0>014=
3P0@30d03`/<00h:2`0?2``040`=00l;300<20T03@T:010<3@0A2`d040X<01D?4@0<1`P300h82P0<
00d72@0A2`d050h@00d72@0B30h040/<00h92P0:1@H06Q@F01/E5`0B30h03PP:0P0<1PP01P0>20X0
3`T;00d72@0>20X03`T;00h82P8030H800@03@L9018=3P0>20X02P@60P0?2@/03`0;1@L03`H901<:
3@0E30l040L:01@;3P0?1PT05Pd@01XA500>1@P03`H90189300;0PD040X>00`62P0200l93@0301<=
4@0:1@P03`T=00D03`T=00H02`H900d82`0>20`07ALK03La=@0J51P500h83003010:3@0?2@/03@L9
00<03PP:00P03PT:00`6200?2@/05@lA00h92P0<1PP04@/=00h82P<03`T;00d03PP:00d72@0=1`T0
3PP:00l92`0>20X03@L9010:3`070@P03@H=00h73P0:0`X05Q0D00803`T=00L03`T;010:300?2@/0
3`T;00h82P0=1`T03PP:00803@L901T030H800P3100D3Q0040X<00h82P0<1`P03PT:00l92@0;1@D0
40X<01LA4`0D3Q003@H=00h73`0=1Ph040PC018:5`0A2AH03@DB01@<5`0;1@h040TC01XC6`0k=3`0
614I00803`P?00@03`T=00h8300=1`/03@L;0`0>20`0100=1`/03PP<00h8300>20`200d72`0300l9
3@0>20`02P@800L03PP<00D040X>00h8300;1@T03@L;014;3`0Dooooo`006oooool04`0<20T02PH7
00d92P0<20T02@D600d92P0A3@h05a<D00h:2`091@H0920Q00l;300=20`02PD900T4200;1PX030L;
00X52@0?2Ph00P0;1PX03`0D3a<030L;010;3`0>2@l02@@:01<>50080`T03@P>00h93`0S7R@04`hD
00d83P0?2Q0040/A00l:400200h8300F01@>4P0B31003PP<014;3`0H4QH02@<701@>4P0>1`h04P/B
00/42`0>1`l0WIJN08R1R@0E3QH030D=01<<500H4AT040TA01<<500A2Q80FeAL030Y<0<04P`@00<0
40X>00l93@0?2@d00P0B31002@0F41@01@0302@N8P14?d403@T:02HR8`0C3a003@T:018>3`03010<
3@0U014=3P0B3Pl04Ph?018>4`0O72<0IVAY01XH7@0H5Q/04a4F010>4`0?3A803@/@01lM8P0@3Q<0
40dD010<3`0N61P030H6020J700O6A/05Q0D01/F700F5AX051LK014I7013CDl0]/3403Xm@P0L7B40
4A8F018C5`0?41@04a@H01DF6P0C51P05QLK01PI7@0201LH700C01XK7`0H6Ad04a@H01LH700O82@0
7QlS014B5P0B4aL05AHK01HG700G61d05aPN01TK9`0G6BH05aTU01XM9P0J7BD05QTP01PK800201HJ
7@0501@H6@0E6AX07b<V01lT:P0N8R/00P0I7BH201`P:@0601lS;00K7bP082@]02hb>`0b=Sl07b</
0P0H7bT08`0F7BL0:34j01dV;`0M9Rl051hW02@_>00R;cL06bP`024^=P0S<3P05AlY02/f@@0O:cL0
82`h02<`?00V=4408S0m02LgAP0V=TD093A302DeA@0U=D@09SI202XkA@0dADl08c@n02`mA`0K;3H0
9cQ202`mA`0Z>dD093Do02Lh@P0]?TP0<TE<0080:Se402L0:Ca30313B@0Z?D<093Lk02Tl@00W>Sh0
:Sho02m3A00^@T<0:S]203M8C`0Z>d80;d1702Xk@P1EIVd0?TmF02Tj@@0/?D@07c0g02/l@`0V=Sd0
9cHm02Hg?P0Z?D<0;T=802a3B@0W?T@09Se3020d>`0dAdl0=4E?02Hd?`0/?D@0;3m50313BP0_@T/0
=TQD03U<FP0eBEL00P0eBeT0F00eC5P0=dmI03A<EP0Z?TP0<41=02Hf@`0U=D80:c]801`/>@0Q<Ch0
9CE202<c@00U=D80:c]802hnC00]?540A5A[04EEK00X=dh08cA802TiC@0W=TT0;Sm?02@eA00_?dh0
9CM301`/>@0O:cL04adY02dg@`2MYk<0I6ij028Z=@0I8R/06R</014H8P0L82T07b</01hS;00Q:380
7BH_01hW<00N9Bd06B0X01LN900I7R805Q/O01<G6P0E6AX06AdN01dQ8@0F6Qd092P[038f>@0K7b80
3A4D01XN8@0D61/0;C4d02HZ;@0O8bH0;S8e014D6@0C61h06alX01lS;0072a@07R8[01dQ:P0I7BH0
7R8[024U;P0J7RL08RH_01hR:`0H72L06alW01`Q9`0L8BD06AhQ01@J6P0L8R806R0Q01/P900<4AD0
6alW01TN900E6Qh401TN8@0J00/@4`0F6al061dQ01@I7@0F6al06b0T01XO9@0J72L061XV01@F8P0J
7BH071lX01PK900K7RD05QTP01@G7P0E61d05QTN01HJ7@0M8B<07b<T01@H6@0F6Qd051PK01<G6P0B
5AX201dP9@803a8I00d04A@K01LL800?51P04AHJ018E6P0K7R<09RP]02DV:P0F5AX06ALL01DC600C
4AH05A@I00D04a8H02@051<I01LF700B4AL051<I01HE6`0A41H051<I01TH7P0@3aD071/Q02/Z<00I
61h04A0F018A5`0;2Q004a8H01HE6`0;2Q004Q0I01DB7@0=2QD0LVmi010=5P0C41L061DK01LE6P0J
61/02`T:018@4@0F51@05A<F0040100R82D02`T>018@5@0C4AH3018@5@0@014?500@3Q<040hC01<A
500B41<030X=01@B5@0U8bH0928U00d;3P081PT0518E01TG6P0L6Qd0518E00d;3P8030X=01L040hA
018@4`0B41<03`d@01<A50091`X04Q0C01<A500:20/03`X>018=4@0300807QTM01TD600300805a8F
01<>4P0;1PX050lC01D@500=20`03PT=010;3`02018=4@04010;3`0>2@d06QDI01@?4`803PT=0200
3`X>00h93@0=2`h030T<00d8300@2Ph04@T>0146300F2a404P/?00X4200B3A404@lB01DC5P0D3a<0
3@P<00l:3P0D3a<04@`@00`72`0=2@`01`8601@?4`0=20`02`H:00l:3P0A2`l05Q0D038/<00B3100
3`T=01H@50D040X>01X040T@00d74P0C2aH08AXR01lE7P0B1`d04PT>00h62@0R71h01`8600T8300@
3a@05QDJ00X7300@2a405@hE01@=500:0`X05PhE00/12@0F31D06A0H01P>5`0F31D050`D01094@80
30D<00/04@XA014;3`0=1`/02`D900l92`0E3a403`T;00`6200?2@X040X:00l92@02010:2P803@L7
00<03`T9010:2P0A2`/00P0A2`/01@0B30`040X:00l92@0A2`/03@L700<03`T90`0@2PX00`0A2`/0
40X:010:2P04010:2P0@01D?3`080P804P`<00l92@0;1@D05@l?018<30090`<06aDE02XT900H4Q80
2`D501`F5P0N61P05@l?00d71`804@/;0P0C3a007@0A3@h03PX;00d92P0<20T04@d>00/7200@30d0
4Ph?00l;300D41403@L901<=3`0D3Q002`D700l92`0@2P`02`D701PB500h<S@0B49401H@4P0@2P`0
1`4301<=3`0I4aD030H800d72@080P@03@L9008030H801003PP:00l92`0=1`T050h@00/51`0A2`d0
4`d?00l92`0F4180EDmA01XD5P0@2P`02`D701<=3`0>20X03`H90P0A20/02`0=10L05@`?01482`0@
1`X04@P;01D<3`0A20/03PD801@;3P0<1PX040X>00803PP<00X0208600h8300=1`/03`T=010:3P0A
2`l040X>00l93@0=1`/04@/?0P0F41@00`0S7B40100200h8300400h83003010:3@0?2@/03@L900<0
3PP:00/03`T;010:300=1`T02P@600l92`0L5QP030H800d72@0?2@/040X<00l92`0200d72@803`T;
00d040X<00l92`0?2@/02`@:01<<500?20l04@XA018;4P070@D03@L;00l93@0?2@/03PP:00H03`T;
00@03PP:00d72@0@2P`0618D0P0@2P`0500=1`T040X<00h820090`<04P`>01dG6@0G4A<03PL>00l8
400>1`l03@D@00h64`0?1a@03PHC00T1300E3AP0<RXe00`53@0e;SH07QLO0P0?20l0100?2@d03PP<
00d72`0=1`/400h8300500`62P0:10P04@/?00h8300=1`/00P0>20`00`0;1@T03@L;00d72`0500d7
2`0500`62P0=1`/04P`@018<40080PH05?ooool001_ooooo01805Q8C048n?`0D4140510A010<3@03
000020@500d92P0?2``02`L800`82@0H51D03PT=018=4@0I51P05a8F00`82`0<1`/200l:3P0D00<0
0P0C3Q8040/?00/62P0<1`d02PD;00/6300?2Q004PdC01<>500f<CL07APN00l:400910X06QDK00X5
2`0C31<04@XA0109400?2@d200h8300B01D?4`0?2@d03PP<018<400D3Q804``C01@=5@0R6b<07QLO
01094@0>1`l05@hF01@=5@0<1@d05@hF00d63P0A2Q8040T@0P0F41@200l93@14018<400C3A405a4E
01TC5`0>20`071HJ02hX;01:ADP05a<D01<?400<20T04Ph?01DA4P0A3@h03`/<00h:2`0@30d0510A
01LC500D4AD03@/@01/I7P0P7R<030X?00d:4@0B3aH0514H01HD6@0E4aP03P`A00l=4P0C3a005a8?
01PC400B30`040X:01D?4P0G4QP07ahS01DH700R:Bl0MGj30>K`m011A4T03PlD01/L8@0>3a@02``A
01DF6`0>3a@02``A01DF6`0D5AX0414F01XK800B4aP04a@I01PI7P0E5Q/0414F01LH700B4aL06a`P
01dN8P0D5AT06a`P01DF6`0H6b@201LI9@0:01HI8P0G6R8061/R01hQ9P0K7b80720Q00hB4`0M8B40
6alP01XO8`D06QlU03<061dS01TN900J7bD0<cPn05eRJ00J7bD05A`T01/R:P0P9bl08BXa01lX;`0K
92/05B0V01TU:`0J9bd072T_01dZ<00I9Rh08bdg02Ha>`0R;cP07RXf020]>@0W=D009SA1024a?P0O
;c`0830o02@d@`0U=D@0:3Q4020a>`0R<cd0:3U302<d?P0M;SP0:ca603=4CP0eAU00;Ci803=4CP0[
?4H0:ci502m2B@0Z?D@0:3]202Lj@00S=S`07c8f03Q;C`0Y?4000P0_@d@00`0X?3d0;Sm602`mA003
02Xk@P0U02/l@`0mCUD0;Ci502Pi@00R<cX08c@k02De>`0Z>Ch0<49602`oA00[@4D0<d]?03I=DP0U
?4809c]402XlA`1_Oh`0EfEb02XkA00Z?D<0EfYa02`nB00mCe/0>DaJ03U=G@0nE680=TaJ03Q?G00a
BE<0=DeG02XnB@0]?DX0;cm<02XjA`0R<Sl0830m028b?`0202<c@01/024a?P0S<d00;3a:03E4F@0_
?UD0=dEK04mKL@0]?4l0;Sa>03I3E00^?Td093<o01l]>00`@D/09S@o020/>00/=T807bTe03@lB@0W
;c`07B<_01lV<00C6R@06AdX02da>P0N8R/0JVmh02lf@00T;CH07RL`01lV;P0K8RX072<Y01lT:00N
8bL06QhQ01PL7@0L82406alO01HK7P0G72005Q/O01@I7@0C61`051TM01HK7`0J7b<0314E02X_<`0c
>3`05Q/O00X?5@0I7BH05a/T02@X<@0K7bP0RXjG01hR:`0G6b@08BD^02DY<P0M8BX07b</020T;@0N
8RX05AXP01HK7`0M8RH051TL010E600J7b<051TM01lT:P0H72D06AdV01DJ800I7R80724U01PM8@0B
5a/04AHJ01PM800F6ah06AhQ01LL7`0D6A`05a`P01LJ900H6RH05ALS01@G800N8BX05QTR01LJ8@0C
5Qd04QDL018E6P0D5a`05ATL01`P8P0>4Q<03A4B01/O8P0;3a8092P[01HI7P0B5AX010L<0P0I72<0
4`0@4aX061`P020T9`0G6ah03A4D00l@500K72003PlD01/L8@0I6Al04Q4G01PG7@0;2Q005QDK00X9
3`0D4aT05A@J01hM8`0B4AL00P0I61h02`0<2a4071/Q010?5@0G5Q`051<I018A5`0Y:2h03`hD010?
5@0D4aT05A@J00803`hD01d06QTO01LF700>31D06AHQ01PE800F4ad05a@M018?5P0C41H07A/P01LE
600B414061HG00`;2P0<2Pd05A<H010>4`0N72408R0U00h<4@0G5AX02PP=01DC600W9BX0;2X_00h<
4@0<2Pd03@/>00l=4003010>4@0300`:3@0=2`h03`d@00<040hA00h02@L:00h<3`0G5AP01@<601`J
7@0>30l030X=00l=400A3a8040hA01@B5@0K6A`04@`@01<>4P8050lC02h05A0D01@?4`0@2`l040/?
00l:3P0>2@d040/?01@?4`0I51P04@`@00T4200O6Qh02PD9010;3`0K5QX05a8F00X52@0J5AT07aXN
00d830071@P0410B01TD600<1PX06A4F01@;400A20d05@hB00h8300A31005A<F01HD5`0;1PX08ahR
014<400o>Sh02`H:01<>4P0@2`l03PT=01HA5@0>2@d050lC00/62P0C3A404@/?0`0@2Ph2014;3`80
4P`@02`040X>014;3`0B2a8040XF018:5@0C31@05@/D01D<4@0E30l04P/=01<=4@0B3A403@dB00l@
5@041@X02@H=01<@5`0A31<03@P?00X52`0H4QT07AHM00H01017?4@0;24Y06]PJ00E31@05@hF01<<
4`0A2Q40204800P21P0D3Q8030H:00d72@0D3Q003PP:00/51`0>20T04@/;018<300@2PX03PP800l9
2@804P`<00H03`T900d71`0=1`L03PP8014;2`0=1`L2010:2P04018<300H4Q802@<301<=3@<03`T9
01L03@L701<=3@0E3`l04@/;00h8200A2`/040X:00X4100A2`/04P`<00X4100<1PH04P`<010:2P0?
2@T03@L700`61P0=1`L040X:018<300?2@T03@L700h82002010:2P0D018>3`0K5aP02@D600P41@0A
3@h04Ph?00D10P0:1PL04@d>00`82@0A3@h020@501/E5`0@2P`03`T;018<3P0@2P`03@L900/51`0D
3Q0203Tc=@1501@>400;1@L04@/=00d72@0A2`d0100002dW:@0A2`d03`T;00h82P0@2P`03@L900T3
1@0=1`T03PP:018<3P0C3@l03PP:00X41P0C3@l081XL01@>400=1`T040X<00l92`0<1PP03`T;00L1
0`0>20X04P`>014;3@0H4Q@04P`>01TC5@080P@03@L9020J700;1@L02`H9018<400:10P03`T=00T3
1`0?2@d04@/?00H0100:10P02`D900d72`0D3Q803`T=00h8300?2@d04@/?00l93@0=1`/04@/?00`6
2P080PH06A<G01lI7@0@2Pd03`T;00@0000b;2h01000014;3@0?2@/03@L900803`T;0P0>20X02P0A
2`d01P0200P2100A2`d030H8010:300A2`d03`T;00h82P0=1`T200/51`0=00X32@0;10`03PL>0109
400?20l03`T=00h8300=1`/03`T;00d72@0:10H030H800h82P0200l92`0900d72@0>20X04P`>00/5
1`0:10H03@L901@>400C3@l03PP:00802P@40P0?2@/0400;1@L03@H=00h73`090PX06Q8M00@02@0@
21D04PXG00X23@0>1Q4050`G00X32`0600L0:B8Z01dF7@0H4AP2014;3`0:018<400A2`l02P@801/E
6@0<1PX04P`@024K7`0400803@L;00h830803`T=00P03PP<00d72`0>20`04P`@00T31`0<1PX05@lC
00d72`8030H:0P0=1`/200h831Cooooo000Kooooo`0I00h:2`0n>S/03`/<018>3`0>2P/04@d>00h:
2`0<20T03`/<01<?400?2``01P8300h93@0>2Pd03`/>00X52@0D3a<020<7010;3`0=20`061<G01@?
4`0C3Q804PhA014<4P0200d83P0I010;4@0?2Q003@P>010;4@0<1`d04PdC014<4P0I51X03`X@0109
4@0?20l03PL>00h83@0>20`03`T=014;3`0?2@`04@/>01<=400A2`h03`T=0109400B2a<04``C018;
4`0201094@06014:4@070PP07aPP00l84019@TX05a0F0P0D3Q803`0@2Ph04`dA018<400A2`l03PP<
014;3`0C3A405a4E00/62@0J5AP061@E01DA4P0@30d05A4B01HB4`0201DA4P1101@@4@0B3Pl04`l@
01@@4@0D4A<05Q@H00l=4P0?31805A8H010=5@0C41P040dD00h;4P0@3Q@040hC01@B5P0G5AD061@A
01TE4`0C3Pl04@`=01D?4`0D3aD04A0E01HH7@0?5AX08BX^04YCF00H6b805QHM01LG7P0G61h03`lF
01@D6`0U9B`0NWZ101HF7@0L7B<06Q/Q014B600F5Qd06ATP01HG7@0D5AX061TN01LH7@0H6Ad0824U
01lP8`0E5QT06a`O01@E6@0H6b<05aXR01LI8`0F6B405aXP01PK800L82<07b<U01LK7@0D61T06AdM
01XN800H7B400P0I7R@0300J7bD06b0V01/P9P0H7B<07R<Y028W;@0F6b407R<Y028W;@0J8BP07B@[
020W;P8082T_00l07bP^01hY;P0M:Bh06bT]01`Y;P0M:Rl07BX`01XU;00P;3@08Bhg01l/=00N:cD0
82hh028`>`0Q<Sd00P0R<Sh0L00P<3h07bll02@d@00R<ch0:3Q40352C@0_?d/0:CY502/kA`0S=3l0
9CE102hoBP10DE`0?TmI02XmA00]@4L0:Ca302Pk@P0W>T0093Lm024d>00]@4@083<g0314A@0T>3T0
<dM802Ph?`0Z>T40;3a302Xj@@0U=C`08c<j02Ph?`0Y>D00;3a302De?00S<cX09SDk04iMH@1UMgX0
AeYN02i3A`0]ADT0:T970358CP0/@4T0?e5L0;g=e`2AWZd0;Si802Dh?P15F5l0;d5<03E7E@0aA5<0
>DeN03aAHP0cBEP0=diK03YBGP0lE5h0:Ca702lnBP0b@Dd0;ci:02Lf@P0U=4008c8n024`?00P;c/0
7Rdi01l^>P0V=D80;3Q:02TeBP0_>dl0?d]N024^?P0S<400;3Q7024^>P0T<C/082df028`>00K:340
6R@`05YSL00lAE804QXW01hV<`0H7RX08BLa020U<00N8Rd09RTb08F9TP2RYZl0:S4k024Z<`0J8b`0
6R4Y01PO9`0I82H07B8V01lT:00K7b804aLH01@H6@0F6QX061dP01TN8P0H7B4501LL800901hS9`0T
:Bd04QLK01/P900J7RL06alX01<G800S9c005a/T00808bL`03405a/T01XN9`0K7bP05a/T01dQ:P0S
9c007B8Y06ebN00K82@06AhQ01dR9@0L8BD06b0U01hS:@0K7bP04aLS01@H8`0C61l0724W01HK800E
6R006b0U01XO8`0I7R405a`P01/P8`0H7B005AXM01PM8@0H6bD07R0/01/M:@0D5b007B0Y01LJ8`0I
72<05QTP01DH7`0E61d05aXO01PK800J7R4061`N00lC5@0@51P06QhR04A7B`0R9B/05QTO00<05QTQ
03T071lV014D600B5AP041<F01LJ7P0A4QL05ADK01DF700B4QT051@L01HE700@41T06APN00D42P0M
72804a8H014@5P0I61h05QDK00d<4P0E51X04a8H01LF700?3Q@05aHL01TH7P0E51X04Q4G00d<4P0M
72804A0F01@C6@0A41H061LM028Q9`0L6b404a4H028O9`0P7BL061DM01@A600?31<04a4F010>4`0B
41<02@L:01HD5P0A3a4040hB01<A5P0@3Q<03P`A00d;400C4AH03P`A01HD6@0A3a@00P0E4aP01`0>
31404a4D01<A500B41<04@lB010>4@0?3A000P0@3Q404@0A3a8040hA00l=400>30l02`X<01`K7@0;
2Pd04Q4D01DD5P0=30h04Q4D00l>400<2`d03Pd@010?4P0?3A003PX<008040/>02l040`>00l;3@0?
2Pd04`lA01@?4P0A30l03PT<00h:300@30h03PT=01@?4`0I51P02PD902@O8`0=20`01P8501<>4P0B
3A403@T<024L800C4A@051<G02TW:`0?3A405Q4F014;400E3A<03PH<010:3`0L5a`05A<G081oPP2<
S8h06aPJ00T51`060P@05A0C00T41`0M61/030P:01<?4@0B3Q003PX<010<3P0?2`d04`dA014;3`03
010:3P0`014;3`0C3A4050hB01@>4P0B31004`dA01@=500?2A@04@TD018;4`0E2a8050/>01@;3@0B
30h04PlC00X83P0<3QH02PhH03i2C00U9Rh030/B010?5P0A3aD02@L=018=500F41H03PH<01093@0I
3aH09adT018:4P080PT02`@;014:4@0=20d04`dA01@>4P0A2`l04@/=01H@4P0A2`d03PP:00l92P0A
2`/04P`<010:2P0>20P03`T90P0B30`0200?2@T03PP800d71`0>20P040X:00`61P0A2`/040X:0P0>
20P04P0E3`l03PP800h92@0;1@D04@/;00l92@0D3Ph03`T9010:2P0E3`l04P`<00h8200A2`/040X:
00d71`0A2`/05Q0@018<30804@/;00D040X:00l92@0@2PX04@/;010:2P0200l92@0@010:2P0A2`/0
3`T901<?400710@04`l@00/7200B3Pl0:BDV055=CP0T82402`L801<?400=2@X0510A01PB50804@/=
00D04P`>010:300A2`d050h@00d72@0201<=3`0H00d72@0D3Q002@@501XD5P0H4Q@030H801XD5P09
10D04@/=00l92`0A2`d03`T;00h82P0D3Q004`d?00`6200@2P`050h@018<3P0>20X04`d?00h82P0:
10H03@L90P0?2@/0500B30h040X<014;3@1:A4H0V9:D03D_<@0A2`d04@`=018<3P0=1`T06Q@F010;
301RG6006aDI018<400>20`02P@8014;3`0>20`04`dA0P0=1`/00`0A2`l03PT<00h8300200d72`0=
00l93@0>20`030H:010:3P0>20`02P@801@>4P0J51P04P`?00L10`0T7R00SXR:02dW:@0200`62003
00d72@0?2@/03`T;00803PP:00X03@L9010:300C3@l02`D701/E5`0P6Q`040X<014;3@0@2P`03`T;
0P0>20X0300<1P/03@H>00l83`0?20l03PL>00h8300?2@d03@L;00d72@0A2`d04`d?00l92`8030H8
00@03`T;010:300?2@/03PP:0P0@2P`06@0>20X020<4010:300?2@/06aDE018<300<1PP03`T;00h8
2P0>1`h040/A01<=500=1a0030DA01D=6P0=1A805@dH01L?6P0E3AP02`@<00T32P0@2A404@XA0109
400>20`0100=1`/01`0f<3@0;bT]00l93@1<ATX050hB00d72`0>20`00P0?2@d02@0>20`03@L;00l9
3@0Y8bL07ALK00H1100910L0618F00h8300300l93@8040X>5?ooool001_ooooo02D081`M00H20`0K
5aP0JVIW03Da<P0C3a002`L801<?400=2@X020@500h:2`0H51D02`H:018=4@0k=SX07QTM00P41`0;
1PX04PdA010;3`0X8bL0F5=G05iIG@0E41@03`X@00`73@0>2@l04PdC014<4P0?2Q0050lE00l:400C
3Q@040/A01<>500G4QP03`P@00803PL>00@03`P?010:3P0@2Ph03`T=0P0?2@/06`0@2P`03`T;00h8
2P0?2@d03@H=00l93@0C31804P/B010:3P0A2a00204801H@50090`P0=2dd018<400C3A404P`@014;
3`0D3Q8040X>00P21P0<1PX05@lC010:3P0;1@T01`4500d82`0201DA4P80510A03L05A4B01LC500F
4Q<0510A01<?400B3Pl04`l@00h;3@0C4A@08AlT05AAE`0a;SD01@8;00d:4`0;21404PlF01@B600;
2@`03`d@01DD500C4a405QDC01DA4P0D4140618F01/F700<2Pl04a<I01<F6`0D6Ad041LK01/N9@0G
5al030`D00L73`0H62005ADM01HF7P0a<CT05ADM01PH800A4AT06a/S01@D700I6B40410H014B5`0N
7b@061TN018C5`0H6Ad06AXL01<D5P0K71h05AHH00805aXO00/05QTN01DH7@0G6Ql05aXO01HJ7@0O
8bH04QHI01`P8`0I7Al07R8U01TN8P0301TN908061dS00H04QLM020U:`0M8RP09b`b01dR:00I7R@2
01`S:@0A01dT:P0M9R/07bP]020Y;P0T;c<06bL[01LU:00J:2/07R`_02<a=00J9BT07RX_01h[<@0M
:S006bT`01`[<P0R<3P00P0R<c/01P0R<c`07c0j01h_>@0S<d00830m02@d@@80:SY700/09SI301d]
>P0W=d@0:CU602PhA@0eAE80?DiH02XmA@0[?TD0:3]202<f?@02024d>P0=02<f>P0Q=3P09CPl02i2
@`0U>CX0:Cdn03=2B@0/>d80:CPo02Pg?P0/>d80;ci502Lf?@02020_=P11028a>00S<ST08c8f02Lf
>@0S=CL093Pj03M<C`0dC500;TI;02i5B`0^@T/0=DMB03i>F`0e@U80;Si901ha>00X>T@0838n02`n
C00^@E80?e=T03E:F`0fBe`0EF]j02e5D@0T?4P0:3a6034oBP0fA4l0=49=02`jA@0Z>4<09C<n020^
>@0N;3L072Xe01d[=P0P;SX08blo02Da@@0[=dL0=41@01dY=`0R;S/0;CU504UEH@18EEh06RL_02<`
>00R;SH08BTf01`T<@0B6RL07bLd01LO;00D6RH01PXE02@X<`0X;3L0:Rdf01XM9P0[;SL08bXd01dV
;`0G82T00P0E72@0200G7R@06b0T020U:@0M8B@04QHG01<G600H71`05Q/N0P0E6Qh01P0F6al05a`P
01DJ7P0K82@07B8V01PM8@80724U00P04aPN01HJ8`0M8BX06AdV01HJ8`0P92d061`U01dQ:P805QXS
01`05a/T01PL9@0O8b`051PQ01TM9@0_=3X01``@01@I700L8B@07b@X01DJ7`0P92d04aLR01<G900K
7Rd06AdX01/O:P0J7RL05ATS01HJ8`0K82H06AhS01PM8@0K82@06AhQ01HK7P0H7B405QTS0P0P8Rh0
1`0B5Ah05aXS01DH8@0I72<05aXQ01HI800F6Ah00P0G6Ql0A00H6al02PdB014D6@0Q92T02PdB00H9
400B5Ad03Q4J01<F7`0F6B8051HR01LJ8`0M7R<0@dA801@E6@0A4QL06AXO018B6P0J6R@0410J01<C
7P0D52003`lK01<C700R8BL06APN01@C6@0F5A/0LG1f020O9@0`;cD0BdY@01HE6`0D4aT06aXP01DD
6P0>3A<04Q4G01XI7`081`d06QTO00h=4`0D4aT06APN01@C6@0=318040lE01<A5`0I5a`05Q<J01<@
5`0E4QT04@lD01DC600=2a0081hS00X83@0E4aH05A<H01LE6P0<2Pl05A<H01`J7`0E4aP03@/@0040
100K6Ah01`D:0P0:20d01`0H5Q/03@/>00d;3P0>30l03`d@010>4@0A3a800P0@3Q403@0A3a8040hA
00l=400>30l05ADG01LG6@0;2`d020P:00D51`0>3Q0010@600`<3P0C4aD00P0>3Q00200E5AL05A4B
01DA4P0E4A80510A01<?400A3@h03`/<0P0A3@h0500@30d04@d>01<?400J5AT03@P<00l:3P0;1PX0
>C@h01PC5`0G4QH04`hB00l:3P0;1PX040/?010>4@0A41D0Bd]@00l=4P0=20h04P`B0P0D3A@02@0C
3A<06QDK00`:3`22PXL0UiNI01LD5P0B3Pl06QHG014=3P0200d92P0801LC50060P<0510A00h:2`0X
92D04`l@01<=4@0A2`l3010:3P0W014;3`0B31004`dA01<=4@0A2`l04P`@01<<4`0>218040TA014:
4@0C2Ph04PT:01482@0;1PP00@0500P8400I6bT0?dEE0=oUm@22QXl000D;00P;4@0000D01@H;01/I
7`0B3A<05Q4E01H@500b:Bh050/@01@<4P0?21007AHM00h83P0E3QD0:R@X01D?4`0>20`03PP:0080
4@/=00L03`T;00l92P0A2`/04P`<010:2P0>20P03`T900804@/;00H03`T900h8200>20P03PP8010:
2P0;1@D200l92@0?00h8200@2PX03@L700d71`0D3Ph01`4101H@400>20P0<2XZ01/E5@0@2PX05@l?
010:2P0D3Ph03@L700805Q0@0P090`<4010:2P0300l92@0@2PX040X:00803PP801P03`T9018<300A
2`/03PP801HB4`0300009B4R00h:2`0G4a@03PX;00H20`0@30d02PH701XF5`0B3Pl0<2`]018<3P0?
2@/040X<00h82P0=1`T04`d?00X41P0C3@l201D?4@0B01<=3`0:10H0C4I804Y4AP0M5aT03`T;00/6
1`0=1`T030H800/51`0@2P`04@/=01@>400M5aT09AlQ014;3@0;1@L040X<0P0B30h03`0>20X03`T;
00l92`0?2@/04P`>01@>400@2P`05Q0B010:3025Oh40ooWk05eGF@0@2``05@lA00L10`0200h82P05
00`6201fL7@07ALK01TC5`0=1`/00P0@2Ph01`070PD040X>014;3`0@2Ph02`D900H0100?2@d00P0=
1`/200l93@0>00d72`0?2@d04@/?00`62P0>20`04P`@00d72P0?2@/01@0101@?400<1PP04P`>00P3
100=1`T200l92`803PP:00T02`D7014;3@0F41803@L902@N800[9BL050h@010:300?2@/00`0>20X0
2@0?20h040TA018;4P0@2A003@H=00h8300@2Ph03PP<00`6200200/51`0400X41P0<1PP03@L900h8
2P8040X<00X03PP:014;3@0>20X040X<00X41P0;1@L05@lA01hH600D3Ph03@L90P0?2@/06`0?20l0
3`P@00@01@0J4Qd0100900/3400E3QX02P8=01084`0>1Q403@H>01@=5@0?21002`@;00h73P0B3100
3PP<00`62P0?2@d0100201H@500<1PX05Q0D00H1100E3a<03@L;00h8300200l93@0900h8300=1`/0
40X>00T31`0500<03`T=01D?4`0600@03PP<00D03`T=5?ooool001_ooooo01<01P83010<3@0A3@h0
BTI702PT9@0400404`l@00d92P060P<030P901<?400:1PL05a8F00@00`0Q72004`hB00l:3P0B3A40
1P4500802PD900<08AdP044l@00B3A400`0@2a42014<4P08010;4@0>2@l03@P>00d83P0>2@l04@`B
01/F700A2Q8201094@0E014:4@0B2a804P/B010:3P0>20X03@L900d71`0?2@T04@/=00l92`0B3100
4@/=00h82`0>20`040X<014;3P0?2@d02P@600l9300500<04P`@008050hB0100618F01lI7@0M5a/0
5a4E010:3P0:10P050hB01TC5`0G4AD030L900h:2`0@30d03`/<00h:2`0@30d04`l@0`0B3Pl201<?
400b01@A4P0>30d00@0201XG7@091Pd00@0702<P:`0C41T030T@01LE6`0E4aH040hA00h?3`0@4Q40
4a<C01@B5@0E4aH06QDI02HQ9@0E4aH03`hC01<D600P92L04QDI01/K8`0D51h0=SI001DE7`0V9S00
4A4K01`L9P0000T07QhX01`L9P0=3AL06ATS01<C7@0G5b40410H01<C6`0R8RX071dR018C5`0G61`0
5QLI018D4`0L7Qd05AHG01LK700F6Qd201DI700E01HJ7@0G6ah051PK01`P900@4aP071lT01LJ7P0I
7240724U01/P900J7b<06AhR01LL800F6al092T]059GF`0K82@05Q/O01LL800S:2`072@W00806b<V
01006R@V01dW:@0N:2X0@Da>01h[;00D8R<07bd^01d[;00@7Ql062<U01TV:00K:B`07B/^028a=@0W
=S/09C@j0P0R<cX3024b>P0=02<d?`0N;S/07Rhk02<c@00U=D8093A102LgA00X>4D09cM402@d@@0O
;c`0834k02Hi@@0202Hi@00o028e?00R=C/093Lm024d>00L;c<0;T5502e1@P0cAdP07c<d02lnA@0X
=ch093<j02<b>@0W=Sd0:CPo02Xi@00K:S4072/b02He?00U=3/09cHj0310@00gBD/0>Te@0315B00]
ADT0<DQ=03=:DP0^@Td0=TQE041@G`0kB5T0:ca802`oAP0_@D/09cU502m1C`0W>T/0;41B02m4E`0f
Be`0CfEe02DmB@0R>TH0:3a602hlA`0b@4/0<3i902Tg@P0W=D009C<n020^>@0N;3L07B/f01h/=`0P
;ST06bLe028[>P0V;ch0;cQ701lY=@0T;ST051hX0080:cDo05@02A<L01PR:`0G8BX06B4^01lW=00J
8Rl05ad[01HL:P0L82`09RXe02da?00E5b<05aXS020S;00E6B807RD_01`U;P0H8BX05A`T01HM9@0H
7bD061dQ01hS9`0L82<04QHG01<G600I7Ad05Q/O018I7`0C6R005A`R01LN900D6b4072<Y01dT:P0E
728051/Q01dT:P0D6b406QhW01`P:@0N8R/03Q8K01HJ8`0M8BX06AdV01PL9@0K7bP06QhW01TM9P0K
7bP05a`R01hS:@011P`05AXN01/P900S:2/0724U01@I7P0N8R/04QHQ01/O;00X:cX0GF1_02T]>@0E
6B@051PS018F8@0K7bP06AdU01LL8P0J7b<061dQ01DJ7P0H7B<05aTT024S;`0S9C4051LP01LJ8`0F
6B805aXQ01HI800E61l301DH7@0E01LJ7`0B5A`041<J018E700C5Qd071lX00lA700G6BD051HR02DW
<`0N82d04aDQ02<S:P1=CU<071dR018B6P0K6b<04a<M00l?6`0A4al06A/X00802`dJ01D05A@N024P
9P0F5A/03PdC00L6301LFf404a8H02`[<@17AT`04a8H014@5P0G5Q`051<I00D42P0[:S00NGQn028Q
9`0=31805aHL01<B600B4AL00P0A41H05`0E51X06aXO020N8@0G5AX04a4F01LE6P0@3Q<04a4F01DC
600`;C@04a0G01DC600E4aT08b4V00l=4P0D4QL04Q0E014?500G5AX0>CLl04]9CP0T8RL05aDJ0080
3@/@0P0>30l01P0=2`h03P`?00l=400B41<03P`?00l=40@04@lB00d07QhP00h>400Y:B/02`/=00d=
3`0E5AL051@F018B500<30h020P:00h>400D51H04@d>00804Ph?00@04@d>010<3@0>2P/03`/<0P0B
3Pl2014=3P0O01<?400@2`l05A0D00/62P0=20`04PdA01HA5@0B3A403`X>024L800j=CT05Q4E00l=
400F5AX04A4E00d;400J5A/030H=01D>5@0?20l05Q0F018=4`030@H07QhS024Q8`0C41805A4B00l;
300;1`P05Q8C00d92P02014=3P0600h:2`0A3@h03`/<00<0000C3A404@/?0`0@2Ph02`0A2`l040X>
014;3`0A2`l03`T=010:3P0A2Q4040TA0109400A2`l04`X<00804@P902<04P`?01DB6@0V9S809bTj
00hC9`1[LX@0;C<m00@;4@093Q@06QdT038e>P0R8RL05A<H020N8@0V8B@03@L900H00P0;1PX04``D
01`E700@2A00J65X07egN`0U7b<03@L;00h82P0A2`d050h@01<=3`0A2``04@/;018<300@2PX03PP8
00l92@02010:2P803`T901X03PP800l92@0C3@d03`T9010:2P0<1PH02`D500l92@090`<05@l?01<=
3@0400005Q0@01<=3@0Z92@05@l?00/51@0@2PX02`D5010:2P0G4A404P`<00/51@0A2`/05Q0@00`6
1P803PP80P0?2@T400h8200F00l92@0B30`04@/;00h820050@809B4R06UUIP0E4A8020@500l;300M
6AX0<2`]00/720091@H00`0001HB4`0C3@l040X<014;3@0@2P`03PP:01@>40804@/=0P080P@2014;
3@0600@0000B3@h01`4301<=3`0A2`d05@lA0P0<1PP01P0?2@/040X<014;3@0H4Q@06Q@F00h82P80
2`D700<02P@600d72@0?2@/00P0A2`d06P0@2P`04@/=01<=3`0>2P/02PH701@@4@0]:BX0IV9S02hZ
:`0A3@h0?c/l018>3`0D41400`0000l;300F4A@01002018<400A2`l04`dA00H0100I4aL02P@8014;
3`0@2Ph02`D90P0A2`l200h830804@/?00`040X>00h8300A2`l03PP<00d72`0?2@d040X=00h82P0=
1`T05Q0B00X41P0@2P`200d72@803`T;0P0>20X0200A2`d03`T;014;3@0=1`T040X<01<=3`0<1PP0
3PP:100=1`T0400@2@l04``D01<<4`0A2Q403PL>00l93@0B310050hB01@>400>20X03@L901@>400H
4Q@04@/=00d72@0>20X2014;3@0800`6200;1@L03@P9018<3P0400005@lA018<300?2@T2010:3005
00`6200?20l03@H>01H?5`0400L00P0A2AH05@0K4b003@D@01@<5`0@21<02P<;01094@0?21002P<:
00h73P0C3A4040X>00h8300@2Ph06aDI00d72`0J51P01`45010:3P0400803@L;00h8300200l93@04
00h8300=1`/04@/?014;3`803PP<00@040X>00/52@0>20`03PP<100=1`/Dooooo`006oooool02P0>
2P/03@X:00d92P0G4a@01`<401XF5`0810D081`M01`H6@0@30d200h:2`0A00X52@0Q72005a8F00@0
0`0@2`l03`X>014<400=2@`050lC00h:3@0@2`l03@P<01@?5@0J5A/05a8H00d83P0<1`d00P0@2a40
200M61h04PdC014<4P0:1@/03`X@01@<5@0B2a<04@XB0`0A2Q402@0A2`l040X<00h82P0=1`L040/9
01<>300E3a007ALH01/E5P02018<3@0I01H@4@0@2P/05@l@00`61`0J51D01P4101TC5P0J51P06A<G
01<=4@0D3Q804P`@00l93@0O6Ad06aDI02PR9P0@2Ph04P`@01D@4`0B3Pl04`l@01@@4@0@30d05Q8C
01LC5002014=3P0W01<?400D4140510A01<@400I5aP05A<F014?500E4QT05A8M05EBG@1DDEX06aPQ
00h<4@0D4QD04Q0A00lA400=4Q40418B01<C5@0E4aH061<G01dH700D3a<04Q0D01HF6@0Q8RD051DI
014A6@0D51h0?Si800l?6@0F5R0051@N01PH8P0A4A/05ADO01lO:@0B4Q`04a<M00805QHP00`051@L
01TI8@0O7bL071dR01PI7@0K72005aPJ01<E500L7Qd04aDD01HJ6@0F6QP201DI6@0801HJ6`0F6Q`0
5QXM01TL800G6Ql06A`R01`O9@0E61h201`Q9@806b0T0P0J7b<01P0B5a/0?D9601PM8@0K82@082DY
01TN8P<06b<V01T06bDW01`V:00L9RP06B@V01dY:`0P;Rl06BLX020^;`0oCDh09c<d02<`<@0O;Bh0
7R`]01h/;P0M;2h09SDi02<e>00S=3X08S<i020b=`0O<3P08C8m020`?@0R<Sl09CE200809cM403X0
<T9?024a?P0T=440=4AA02XjA`0V=d408C@l024d>`0S=Sd08SDl02<f?00X>d40;3m302<f>P0X>cl0
9c/l02/o@00R=3H09cHm02Tg?`0Z>3l09S@l024_=P0N;3@08S0h024_=P0S<CT0;3Y102Xh@00T<cL0
830`028d=@0/@440;45402i6BP18H6H0DfYb03E9E00eAe@0<T9A03M4E@0_@4`0;d99024c?@0S=D40
:ce;02e0D@0bAUP0BEia04IKK00`AUH0:3m=0318E00U>D<0<3e7034oB@0]>dD09S@n0P0V<cd02@0Q
;cT07b`f020]=`0R<3X08Rli024[=P0U;cP09Bli02hh@`0202Pb?00C02li@`0I8bd07RPb02@^>00S
;CL072H_020X=@0H7b`06b8`01XP;P0E6bT06al[01XN:@0T:3<0EUQT020S;00B5Ah07AlY01LN:002
01XS;00J01HM9@0G7RH05QdS01LL800J7b<05QXM010D5@0C5aP05AXI01PM8@0C6R005A`R01XQ9`0L
8bT061lU01XQ9`0H7bD07bH/01DL8P0I82H07B@Z01`P:@0J7RL07b</01`P:@0K7bP201XN9`807b</
02806alX01LK900E6B805a`R01TN900J7bD08bP/01@I7@0L8B@04QLK01TN9@0E6B@04QHR01PK:`0O
8S<05aX[01PK:`0H72T041@P01lS;`0e>D@05a/U01HJ8`0I7R@05a`R01@I7P0F6b4061/U01dO:`0R
93005aXS01XM9P0I72D05APO0P0D5ah0>`0D5a`04aHK01<F6`0E61l05aXR01DH800?4Q/051HQ01DH
8P0H6RH071hZ01@F8`0S9C<06Q`Z00h@7@0B4AT06QXP01LG7@0E5Ah03@dH01LG8`0C4Ql04aDS02LY
=`0D5BH09RPh04E5D00;2Q007QdS01XI7`0@3aD051<I01<B600>3A<061LM01LF700J6Al03`hD01<B
600T8bT071/Q01dL8P0?3Q@040lE02LV;00U92X04Q4G01DD6P0I61h04a8H01<A5@0N71h05Q@F010>
4@0D4QH040hC014?500A3aD081dU00803``D01003``E01HC6@081P/05Q@I00`:3`0A3a@04a4F018@
5@0G5AX030X?014?500C4AH040hC01DC5P0D4QD04@lB0P0?3A000`0A3a803`d@00l=4004018@4`0>
018B50061PP0;bla010@4P0E5AL04A4C051@DP0h>3X05QHH00l?4@0@41801`L9010<3@0A3@h2018>
3`03014=3P0@30d04Ph?00805A4B02T04Ph?00l;300?2``04PdA01@?4`0B3A40<Rda01HA5@0B3A40
6A@H010;3`0C3Q80<B``018=4@0B41<030/@014A5P0=31803`dC01@>500A2Q805@hF01@>5@091P`0
30/A00X:3P0K6Ql03P/=01LC500@30d05A4B01HB4`0=2@X04`l@06YVI`0i=CH04@d>00<0000e<C80
4`dA014;3`03010:3P0V014;3`0@2Ph04@/?014;3`0?2@d040X>014;3`0B2a804P`@01<=3`0D2`/0
4@X800l:1`0@3@h030/C00/<600O8SH0Uiff0=7GhP1XLWX03QPL010H7@052a404AHJ01DG700A4AD0
2`/=020N800>2``050l@01D?500?21003PL>00l93`0@2Q005@lC018=400C3A42018<3P805a4C00L0
4P`=014;2`0B30`040X:00h8200?2@T040X:00803`T900d040X:00l92@0?2@T04P`<00d71`0@2PX0
4P`<01TC4`0R71`02@<3018<300:1@D07QPH00803`T900h04@/;00`61P0>20P050h>018<300?2@T0
2@@400l92@0B30`03`T901@>3P0I4a<03@L700h8208040X:00<03`T900h8200@2PX00P0?2@T05@0@
2PX04@/;00l92@0A3@h03PX;00l<30060P<06QHG00h:2`0810D05A4B00P41@0=2@X04@d>00d:2P0I
4aD04`d?018<3P0C3@l04@/=01<=3`02014;3@803`T;100A2`d0400>20X05Q0B014<3@0>20X040X<
00l92`0B30h040X<00/51`0>20X02`D700d72@0D3Q004`d?00d72@0>20X200d72@0A00h82P0A2`d0
3PP:00`6200?2``02@D600/7200?2``05a<D00h;2`0@30d0Cd]<02HR8`0C3a001@82018?3`0A2`l0
0`0>20`03P0M5a/03`T=02XT:00;1@T03PP<00l93@0@2Ph07ALK01<=4@0?2@d03PP<014;3`0B3100
4@/?100?2@d02@0>20`03PP;00`6200@2P`030H800/61`0=1`T030H800d72@0200l92`803PP:00P0
4P`>00P2100:10H04@/=00d72@0A2`d040X<00h82P<03@L901403PP:01093`0B2a<04P/B00l83`0>
1`h040X>00l93@0@2Ph04`d?00l92`0>20X05a4C01`F600C3@l03@L900l92`02018<3P0J00T31@0V
828030H801H@4P05004040X<00`61P0;1@D040X<018<3P0>20X03`P?03Tb>P0J51/03`LB01085@0M
5b80<b/h00h64@0?1a8040PC00h73`0?21004P/C00d63@0>1`h300l93@0900h8300@2`h04`dA00`6
2P0H4QH02`H9014;3`0=1`/03PP<00803`T=00D03PP<00d72`0?2@d03PP<00l93@02014;3`803`T=
0`0>20`200d72aCooooo000Kooooo`0X00D10P0C3a002@D600T51P0D41400`0000D10P0F4Q<03`/<
00P41@0<20T02`L8018=4@0K5QX05A0D01<>4P0B3A405A0D00l:3P0F4AD01@0400X62@0;1PX03`X>
010;4@0M61h06A@J00`73@0>2@l05Q4G010;4@0Q72802`H<00l:400>2@l04PdC01<<500A2Q8040TA
00l840803PL>01h03`T=01<=4@0C3@l03`T;00l92@0A2`/03@L701D<3`0D3Ph03`T:00`6200=1`L0
4P`=01@>400E3`l03`T:028L7P0:10L04P`@01@>4P0?2@d04P`@01LA5@0A2`l05Q0D00D00`0Z92P0
50hB00/52@0A30l200l;3006010<3@0<20T0510A01TE5P0C3a00510A0P0E4A807`0D41405a@D00`;
2@0?3@h05aDI010>4`0D4AP071TR014>5@0;20l05aDI00h<3`0:20T04A8C00lC500@4A<04A4C018@
4`0@3Q406A@H00h<3`0H5QT05QHH00d>400B4aH02`/C018B700C4ad05ADO01<C7@0@41X00P0D51h0
200C4ad061PR00T94`0F5R0051@L010@600C4aX05QHN0P0B4aP0800B4aL051DI018C5@0@4A<071hM
01@F5P0F6QT05AXF01DI600D61L05ATI01HJ6`0F6Qd05QTM02<V:`0O8RT0;c8j02@W<00I7BH06QhV
01`Q9`0M8BX07b@Z020U:`0Y;S@06AhT01XO9@0K82H07b@Z01hS:@0K8RP07B@Z0P0N9B/05P0M9R/0
72DZ02df>`0H8bD05R@U01`W:@0J:2T08S0a01d[:`0N;2`08Bl_02<a<@0R<C407bl_024`<`0S=CL0
9CLi028d>00L;S806BXa020a>P0U=T0202Pi@`1l02<d?P0P<3d09cM402hnB`0[>dP09SI301XZ=`0U
=D809cQ102<d?00S=Sd07S0g01/^=00Q=3X0EVU]04EHG00X>cl0<4A501/_<00hC4d0:3Lm02Hc>`0R
<CH08Bld020]<`0O;S<08c4g02Tf?P0P;SH08c4j02Xg@00W=S`09cHi02Dg>@0W>Sd0<dQ;0397C00[
?dH0@eMP03=7D00]?T/09SI303E2DP0W=dD0:Sa602XjA`1:FfP0<45A028cA@0Z?4l0?E1Q03Q;G00/
@Tl0:T1=0357DP0S=3l09c@m02Hc?00O;3D06BH_01XW<00P;CD082df01h[=00Q;SL0934j028_>00P
;CH08bdf01lY<P0X<S/09c4j024[=@0K9Bl0628/020Z=00M9c408bdf01hW<P0L93406R0^028X=P0L
8S007R@b02DY=@0P92l04ADP02X/>00G6R<051LP01hP:@0@5b405b0Y01XS;00E72H05QdU01<J8@0N
8bT07B8V01LK7`0C5aX05ATL01<G6@0F6b4041LO018I8@0H7bL06R4W01HM8`0D6b4072<X01LO8P0O
9bX0?dM:014I700B6B4082La01<J900D6bD061lY01XQ:@0F6RD0720Y01/O:08061`U01T06AhT01LL
8P0I7R807b@X01<H700F6ah05a`O01LL800`=3`07B4/01hR;@0I72X04QDT014E8@0D62@02@dI02@X
<`0a=D007b<^01HJ8`0D62405a/T01DJ800B5ad051PQ00804aDQ00/06Q`X01@G800F6B805APQ01@G
7`0E62405APO01@G7P0C5Qd04QDL018E7P0201LJ8`10018D800L7RX06A/W01/M:@0?4Ah04aDR010B
7`0?4Ah061PT01PG800L6b<06QTQ01PH8@0C4ad08R8]024Q;@040a4061PV01LI9P17AUH0Lg=m028Q
9`0920h05A@J00h=4`0F5A/03`hD01HE6`0H5ad03@`B01/J800<2a405QDK0450A@0X9b`06APM01DD
6@0@3a@081lT01dL8@0F5AX04a8G00h>400B4AH07ahO02d[;00X9RL0518E00/9300<2Pl05Q@I01@A
600=2Q404@hG01LD7@0K6200@T1501XH7@0>314061HK03Hd>@0W9BX03`dB00P62`804Q0E00@05A<H
00/:3P0?3A003P`?0P0=2`h00`0?3A004Q0C018@4`02018@4`0j014?4P0@3Q403`d@00h<3`0?3a40
3PdA00`:3`0C4aD04a8F00h<4@0@418040lB00P62`0920`04@lB00l;300@2`d04@d>01<=3`0C3Pl0
4Ph?00l92`0C3Q00510A01@>400C3Pl04Ph?00`72`0B3A4040/?01dH700C3a804@`@00P31`0G4QP0
4PdC01LB600E41H03`dB018A5`061P/01`@;01TF7@0A31<03`P?014:4P0A31804Q0E00d;400=3140
1PD:01@A4`0810D02`L8018>3`0=2@X05Q8C01@@4@803@T:00D02`L801lK700=2@X04`dA014;3`03
010:3P804@/?0P0B3100:`0@2Ph04@/?018<400C31<04`dA01<=3`0C3@d04@`9010:2P0?30l01@@<
02PX=00U9cP0aLON0>_`o`1WKgH010/A00X@5@0731002`hC00H8300=3Q804Q8D00/9300A3a0030L;
00d73@0D3A@040T@00h73@0D3Q8030H:00d72`0E3a<04`d?00h82P0C3@l04P`>00h82@0A2`/04P`<
010:2P0>20P00P0?2@T0200>20P03`T9010:2P0@2PX03`T9014;2`0=1`L040X:0P0?2@T01P0B30`0
4`d=014;2`0M5aL0HE]K024K6`803PP800d040X:00h8200<1PH040X:014;2`0B30`04@/;00l92@0G
4A407QPH01XD500>20P03`T900804P`<00H04@/;00l92@0B30`03`T900d71`0>20P2010:2P0500P4
1@0E4A804@d>018>3`0>2P/00P0?2``03@0=2@X04Ph?00T51P0>2P/05Q8C01PC5`0=20`030L;00l:
3P0>20`02`D7018<400<1PP00P0A20/0100>1@P050/>00`6200:10H201@>40805@lA00T02P@600d7
2@0D3Q004`d?00h82P0@2P`05@lA00/51`090`D00P0;1@L02`0@2P`030H800X41P0=1`T050h@014;
3@0;1@L02@H600/7200A3@h02`L800804@d>01H030P900L3100:1PL02`L801LC500<1PP04P`@00T0
1@0:10P04@X>01lF6`0>20`030@900h52P0>20`04@T>01483@0=1`/04P`@00d72`0<1PX03PP<0P0@
2Ph02`0?2@d03@L;00l93@0B31003`T=01@>4@0500402`D701<=3`0>20X02@<500803@L90P0?2@/2
00h82P08010:30090`D030H800d72@0>20X04`d?00h82P0?2@/200h82P0:00l92`0@2P`03`T>00l8
400?20l03@H=00`5300>20`03`T=00h830803`T;00l030H800/51`0@2P`040X<00d72@0A2`d04P`>
00d72@0B30h0D4Y<018=3P0F41803@L900h82P0D3Q000P0<1PP07@0C3@l04P`@00d63@0;10`04``D
00h74@0<11400`0901`D8@0E3AX03@D@00l74P0D3AD030D=00P12@0C31<040X>00h8300@2Ph04@/?
00h830090`L01`45010:3P0600@05@lC00X4200=1`/03PP<00803`T=00P03PP<00d72`0:10P03`T=
010:3P0<1PX020<600d72`8040X>0P0?2@d200h831Cooooo000Kooooo`0600`6200D3Q006Q@F01TC
5@0C3@l03PP:0P0=1`T200h82P803`T;00@03`X>01D@500F4AD04@`@0`0>2@d01@0B3A405Q4E00`7
2`0A31004`hB00L03`X>01d03@P<00`72`0>2@d040/?014<4P0I51X02@@:014<4P0C3Q@02PD;00`7
3@0@2a404@`B018=4@0@2`l030L;00/52@0C2Ph050T?00`31P0F3A404PT>01072P0@2Pd061<G01@@
4@0=20/03@P<00l:3P0300h93@0P00l:3P0@2`l03PT=00d8300G4QH03@P<01TD600R7B403`X>018=
4@0A31003`X>018=4@0E41@04`hB01LB5P0I51P04PdA010;3`0E41@0514A014@300B4@l04Q0@018@
4@0C4A804Q0C010>4@0A3a804Q0C014?4P0@3Q4201<A500A010@4P0C4A@05A<F01DD5`0<2Pd0:RX/
02<S9@0J6ad03a0B01@G6@0=3Q<03PhF01HF7P0E5Ad0410H01XJ8P0H62000P0A4AT0:00Q8BT092@/
01@D700E5Q/05QLL01LH700C51T04A8F018C5`0>3a<05AHJ01`M8@0F5a/04a@F01/L7`0K7b007b<R
01DI6P0J7Ql051PJ01`P8`0M8B@051PL02<V:`0G6Ql06A`R01hQ:P0K7b/05adZ01@J9P0D6RP05adY
01TO:`0H7RX07R@_01hU;`0J8B/06B0Y01/R;00P92l201dQ;00J020T;`0N9Bh061lW02/b>P0R:c00
72L[01`V:00J9BL06BLX01TW9`0M;BX08c<`014Q800V=SH08S8b028a=00S<SL09SDj02Th?`0T<cX0
82lf02@e?00/?DD06b`d02/lA00X>D4202Df@0808c=00440<41?01l_?P0U=D@08Blk01l]>00R<cd0
7Rdf01d^=@0X>D00=4I:0314A@0^@T<09CTj02<i=`0bATL07Blc02<b=`0P<S@072d_01`[;P0K;Bl0
834d02Pg?P0W=Sh07c0j02lmBP0T=Ch09CHm02Pi@00W>3l0<DA:03Q;DP0[?TD0;d990313BP0V=d40
:CY402hoB@0X>4H08C51038oD01;FF/0>4MJ02hmDP0dAEP0;Ci@02LhB00Y?4T09CU2028f?@0P<3T0
:3I101PV<@0C8BX06BP_01l^=@0O;S@07bhe02Dd>`0X=Sl07B/f028`>`0T<Sd09S<l01/X<@02024^
=`0h028/=@0K9Bh07RPa01hW;`0I8R/072D/01/T;@0?5b@08BPh01dT=00T:SP0:Blm028X=00C5b80
6alZ01TL9@0H6b@08RD^01hQ:@0C72D041XT01DO:@0K92d05QlX01<J8`0H72D02a0F00hA5`0F5a`0
3a0E01LI7`0V:SD03A@O020W<@0M92h07B@[028Y;`0F7R40620S018J700C71/03aPF01hV:00H8BX0
6B4/014I900J8Rd072@_01/T;@1DFVH0:2li01TP:P0K8R`051TS01DJ800H71l301PL7@1G01PL7`0I
7B00:blb04U<D@0N8BP01PT@01@G7`0D5ah07R4V00`@50082a003a8G01hQ9P0G6Ql061/R01LJ8@0N
8BP05APQ01LJ8`0J72P05QPT01TK9`0H6RH05QPT01LI9@0J72P061XU01<E8@0C5Ql05aXS01DH8@0B
5Ah0820Z07IfP00I6B<051@N010@6P0G5b405ADO01LG8`0Q8Bd06QXV018B7P0I6B<061LN01dL8P0G
5Q`05A@K00d<500F5Ad05aHN01PG7`0E51`04a<K01TG8P0O7RD051<I01<B600S8RP051<I00l>500H
5ad040lE014@5P0R8BL051<I01XI7`0C4AD06ALJ01LE600@3Q006ALH00P61`0V92@05aHD01TH5P0E
51804a8>00h=2`0L71`08R4V01HE6P0B4AH05aHK014?4P0C4A@040hA00<04`hB00T050lC01PF6`0?
3A80518G014?500D4QL04a4F00l=4P0@3Q<00P0A3a@2010>4`804a4D00@04Q0C00l=400>30l03@/>
0P0C4A@0100B41<04@lB018@4`0C4A@2018@5@0T010=4`0J5A`05A<H00`93`0;1Pd030X?014>500:
1@`04@hD00L2200B31004P/=010:300B2@`04P/=018<3P0E30l04`/>010:300B2@`04@X<014;3@0@
30d04`l@01@@4@0C3Q804@`A014<4P0J5A/030P>02XU;00D3QP07ALQ010:500A3QD04Q0F0`0B3A<0
200?2Ph06QDK00h93@0A31004`hB014?4P0P7R4040`=0P0<20T00`0>2P/040`=018>3`06018>3`08
00l;300C3a001P8301PD5@0A3@h03@T:018>3`0?2``200d92P0P00h:2`0?2Ph050lE00h93`0E41@0
30L;03Td>00:1@T040/@01<@5`0D4AP05Q<M04A2C@1_KGP0=SDk010?5@0?3Q<04Q4F00/93P071@X0
40hC018@5@0>2@l03PT=014<4P0>2@d02PD901hI7@0:1@P040`=00H20`0B3Pl200h:2`0@00l;300@
30d040`=00l:2`0?2@/040X<00h82P0;1@L03PP:010:300;1@L03PP:00/51`0<1PP03PP:00X51@80
4P`<0P0@2PX01`0>20P050h>01<=3@0J51@0GeUI01<=3@0@2PX00P0?2`X0400=2@P02`L600`81`0A
3@`03PX900L30P0@30/0510?051<B`0D40l03@T8010<2`0B3Pd01@4000d9200C3`h200d9200:00l;
2P0@30/04@d<018>3@0:1PL0100101<?40030000510A014=3P805a<D01T04Ph?00h:2`0<20T02`T<
01@B5`17AT/02@L<00h<4@0?2Q004`dA0109400B2@h04PL=01<63@0D20d050T=01072P0>20X05a4C
00D00@0_:B/08adO00d72@0A2`d040X<008030H801003`T;00`6200?2P/03@L900T31@0B3@h01000
00d72@0?2@/040X<00l92`0<1PP02`D7018<3P0C3@l04P`>0P0@2P`0100B30h03@L900d72@0>20X3
00l92`0B01483@0G31806A0E01X@5@0F2a404`X?01<93`0E2Q004`X?01473@0B1`d04PT>014;3`0=
1`/02`D901H@500K5AT05a4E0P0;1@T300`62P0400d72`0?2@d030H:00/52@804@/?00<02@@7028L
800400800P0?2@d01@0400804`dA00l93@0?2@d03PP<00803@L;00/03`T=00d72`0:10P03PP<018<
400?2@d03`P>018;4`0A2Q403PL>00d63@02010:3P0W00h8300=1`T03PP:010:300B30h04`d@010;
3`0=20`02PD900d8300>2@d04PdA00L21P0:1@T04PdA00H11@0=20`030H:00/21`0@1``04@/?00h8
300@2A004@`C018=500?2a802`D?00X7400@2QD02P@@01<=6@080P`06A@K00`73@0>2@h02`H:018=
4@0A31002PD;00803@P>00`04`dA00@00P0I4aL03PP<014;3`0>20`04@/?00d72`0?2@d03PP<00/5
2@0B310<00d72aCooooo000Kooooo`0300d72@0?2@/040X<00803PP:00<03`T;00d72@0>20X00P0>
20X200l92`0<00h93@0@2`l04@`@014<400>2@d030L;01@?4`0=20`02`H:00l;3P0?2Ph040/?1P0?
2Ph02P0>2@d03@P<00d8300>2@d03`X>010;3`0C3Q@050lE00/6300@2a4202XU:`0=00d83P0?2Q00
4@`B018=4`0@2a4040T@01883P0B1`d040D;01L>4`0C2Pl03`L;010:3P0200P31`05010;3`0C3Q80
4PdA014<400@2`l00P0A31001P0B3A4050lC00T4200A31005Q4E00h93@8050lC02T04PdA014<400B
3A404`hB010;3`0A310050lC01<>4P0F4AD07APL01/F6P0D4A404Q4=014@300@3``04A0>018A400C
4Q804Q0A014?4@0?3A004@lB018@4`0F4QH05Q4F018@5@0D4AL05Q@H01DE6@0K6R007ahR01/L800G
61`04Q<F01HI7@0N7RD05aLO01DE7@0I6B405QHN018B6P0201DE7@0=01LG7`0I6B4061PP01@E6`0E
5Q/05aPL01XK7`0F5a/051DI01<D600S92P07b0T01TJ7P0201PI7@0?01HG6`0K7b4051PJ01/O8@0;
3a40:Rda01HJ7P0G6Qh0;C0f01<F700M82H07B0X01`P:P0K7Rd06Al_008061h^02X06Al^01TO;@0K
8Bl06b4^01XP;00K8Bd07RD`020W<@0K7Rd07b<`020T<00O8bl07B<^01hU;`0M9B`07bL]01dV:`0O
:Rd08bh`01/Y:P0J:2P0830^06moO@0gAdH072`/02<b=00R<CD08C0e02<b=`0V=C`08c8i024`=`0[
?D807c0g02Df?@0Z>d80:3U102Xk@`0V=d406b/h01`/>@0]?D`202<c@P0?02Lc@@0T<Sh0:cU402/i
A00^?dP0>4UA028c>@0Y?440:C`o02i2A00X?Cl09CXl02<e>@0S=CL08C<e00807S0`05L0838b02Hh
>P0T=C`0:3U102@e?`0O;ch09cM302@e?@0V=cl08S<k02Hg?`0Z>d<08c@l0352BP0fAdl0;d180311
B@0_@4P0;Ca9020]?`0K:3X09395024_@`0U=4T0:cY>020`@00O<4009CM2028e?00N<CP08S8k02Hd
@@0Q;cX09S@m01/Z<@0E92T07Rdb02Dd>@0O;SD093<l02/iA00P;S/07R/f02Hc?@0Q;SL08c0i01l/
=@0S;CH09c4j01LQ:P0N9bh0<SY101`T:`0I8BT051`Y02H]?@0R:CT09bdk02`b@00^=4006AdX018F
8@0I72D061/T018E7P0/<3P0@daE030jA00K92d051dV01<L900H7bL0720X01<H7P0Q92X0<C4h028S
:@0C51`05QXV02X`?@0Y;c/0/[W3065XL00J8BL06B4T01@L7P0M9RD00P0G81d03P0F82004a`T018L
9`0S;CP072Ha04mHHP1SK7H0HFUc03@kA00G7RL06QlY01LM900@5AX05a/M0P0G6a/0400G6a`05a/M
01LK7P0O8bH0<SDi01dP9@0=41D05QTN01@H700A5AL05ATI01LK700A5AL05QXN01LK7`0M82H201PK
8P0401dP:@0G6B@05aXT01TK9`8061XV00@05aTU01DG8`0D5R805aTU0P0E5b<06P0D5R805ALS01DG
8`0B4Q`09BD_00d=5`0S8bd06ATS01HF800E5Al05aLQ01hN:00I6B<04a<M01TI8@0I61l04a8H01TH
7P0D4aT07ahT01@C6@0E51X04a8H018A5`0C4QP05A@J0P0D4aT0700E51X061LM01DD6P0@3aD04Q4G
010?5@0A41H05aHL01DD6P071P`07QdQ01DC500H5QL04@l@01dL6`0@3`d04A0=03dl>027QX80IVEQ
02PW8P0H5a804Q4A01<B600B4AH040lD01DD6@0F51L201@B5@0:01DA4P0D41404`l@01@?400<1`d0
5Q@I010>4`0H5Q/03@/@01<A5P804@lD0`0B41D00`0A3a@040hA014?4P02018@4`804a4D01@04Q0C
014?4P0A3a8040hA014?4P0B41<050lE00l:400@2a4050lE00`83@0E41H050lE01PC6@0M61l02`H=
010;4@0A31805@`A01D<3`8050/>0`0E30l201@;3P804`X=01l04@/=010:300@30h03`X=00h93@0B
3A805Q4G03@`=P0L5al0DD]E01LA700F4A`05@lI00l94`0A31<04`hD01@?5@0C3Q<04PdA01LB5P0>
2P`04Ph?01<?400B3Pl06aLH01HB4`0A3@h040`=00l;300<20T02`L800H040`=00H03@T:010<3@0C
3a003`/<00d92P0@30d601<?400N018=4@0S7R<061<H01dH7@1NFEh050lD00l:3`0@2a005Q4F010;
400C3Q<07aXO01PC600D3a@03`X?010;400N6Ah07APM00`7300?2Pl04`hC00h93P0?2Pl04Pd@00d9
2P0<2@T0:2@U01LC500C3a0030P90P0>2P/0100?2``040`=010<3@0@2``2014;3@0<00l92`0>20X0
40X<018<3P0=1`T04@/=00h82P0A2`d05@lA00l92P0A2`/03`T90P0>20P01`0?2@T030H601D?3`0I
51@06Q@D014;2`0?2@T00P0?2`X0400>2PT02`L600`81`0@30/0Ddm>01@@3`0<20L040`;01@@3`0@
30/03``;01PD4`0@30`04`l>01TE500F4Q43010<2`0<00h:2@0=2@P030P701PD5@1GDe@08alP05=?
D00T82405A4B01<?400D41404@d>0P0>2P/04@0=2`h03`lD02PX;`0N7B@02@L?010=4`0=2@l04``C
0189400@1@`040@;01@63@0D2@h04`X=00`6200D3Q002P@6008040X<00P03`T;018<3P0A2`d03`T;
00h82P0@2P`05@lA00`620804P`>00T03`T;014;3@0>20X03`T;010:300?2@/03@L900`6200>20X0
0`0@2P`00`0B30h050h@00d72@0200h82P<03`T;00T04`P>01D:400E2Q0050T?0146300@1@/04@H<
01873@0A1P`00P0?10X00`0?1P/03PL;00l93@0201<=4@803@L;00H03`T=00h8300>20`03PP<00`6
2P0=1`/2010:3P0:00d72`0@2Ph04P`@010:3P070@D03@L;01D?4`0B310040X>00l93@8040X>0P0?
2@d02@0>20`03`T=00h8300=1`/03`T=010:3P0>20`03@L=01094@0201<<4`0400l83`0=1`/03@L;
00d72`803PP:0P0?2@/0100>20/02`L:00`82`0<1`/200d8300@00h93@0?2Ph04`hB00h93@0B3A40
3@T<00l62`0A20d040L<00`62P0@2Ph03`P?00h9400=20l03P/B00l<5@802`PA00X030HD014;5`0@
2a@0510F00`73@0@2`l02`L800l;300>2@d030L=0P0@2a402`0?20l06A<G010:3P0B31003PT<010:
3P0I4aL03PP<00l93@0C3A4040X>00L03`T=1P0>20`Dooooo`006oooool2010:300400h82P0<1PP0
3`T;018<3PH03PP:00<040/?00h93@0@2`l00P0C3Q801`0>2@d030L;00h93@0R7B4040/?014<4009
10P01P0?2Ph300d8300900h93@0?2Ph03`X>01D@5P0I51X05Q4G010;4@0f<CL0<2/a00803PT?00l0
3`X@00h93`0<1`d030D<01lE6`0F2a4050T?0107300C2Pl040L<00h8300@2`l04`hB010;3`0;1PX0
100>2@d01P0?2Ph040/?00l:3P0E41@05Q4E00P31`803@P<00d02@D800h93@0?2Ph04@`@00l:3P0@
2`l04`hB00l:3P0<1`/050lC02<N8P0Q72005Q<C00804A0<01X04Q4>014@3P0@3Pl04@l@018@4@0@
3Q403`d@010>4@0B41<05Q<I01HA600B3aH0514H01HC6P0F5A/07ahT00h=4`0F5a`04Q<H01<D6@0G
6Ql071`T01DE7@0B4QX06ATQ01/K8`804a<K0P0F5Qh07@0B4QX0410H01DE700C51T05QLK01XK7`0G
61`05AHJ01<D600N7b<05aPL014B5P0F5a/061TM01@E6@0C5aX041@G01hQ9P0H6b00=STo02<V;@0N
8BP0CE1H02<V;`0Q92d05QPS02<W<P0K7Rd06R0`00806b4a01d06R0_01TO;@0M8c406Al/01XP;00N
930082Ha01`S;@0J7RX07b8`020T<00O8bl07b@_020W<@0K92/092dd01XS:00F8BD07RT]01PV9`0Z
>3T07Rh]03e=C@096AT05bLX01h]<00P;c@07bhc020_=003024`=`0403m@E`0Q<ST09SLn01TZ<P80
834i05<06b`f01/[>00Q<Ch0;3a;02LgAP0S<d809C4o02Hd@@0]>dP0<3i:02m0BP0eAU00;3e603A7
CP0dAdd0L8>802Dj?`0S>3/08C<g01h`=00K;Bl07Bl`028d=00U=cL09CLi02Hg?P0/?DH0:CY401/[
>00W>4<07Rlg020a>@0O<3P08S<k02Hg?`0Q<SX0;Sm703E6CP0`@DT0<D9:02dnAP0X>4<08Bll01`Y
>@0S<D8093=602DdA`0U=4P072/n01XZ>P0L;CX06R`f01h`>P0U=Cl09S@o02Pf@@0V=3`09C@k01h]
<P0V=CX093<h01PW;P0/>d<0<T1;02Pf@P0O;3D0:SM002Ld?@0S<3T07R/d02<]=P0O:C8041/Q02@]
=011B4h08RT_01DL8`0?5b@082Lg01TP<00D6RP04ALU01@J9P0201<G8P0Y02@W<00G6R<02@`E0413
B`0h@DP09S4g01DN9P0E7RD05AhS01@K8@0H7B<03a@H01PK800U9R/07QlS01LI7`0Q9C00=ce902L^
>010Ae40=3]204U@EP0a>C`0620R01lX9`0@6AP07RLT01DO800`>D0082Xd01@N9`084Q/0=T1805EN
I@0;4QX04aXQ014H7P0B5ad05a`Q01PM8@0G6ah00`0F6Q/05@0E6A/05ATL00dA500@51P04QDJ00hA
5P0F6Al05aXO01TM800A5AH03A4B01DI700B5AX05QTN01<F7@0I72<08B@[00d@6@0X:c@03a8K01XL
:00201DG8`0O01PJ9P0E5b<04Q@P01HH900H6RH05QPT018D800D5R805aXS01LG8@0E5Al0820Z00d=
5`0@41X07QhX01DE7`0F5R006a/U01LG8@0D51h061PP014@5P0H5ad0SHbB02h]<`0;2Q0071/Q01@C
6@0@3aD04A0F01@C6@02018A5`0O014@5P0>3A<03`hD018A5`0E51X061LM014@5P0G5Q`04a8H01hM
8`0Q82H0L6mc01lM7P0I5aP04a4B01PF5`0M71X0:bXW08n>RP3ooo/0a<>o03Dd;`0L6aH051<D01@C
6@0O7R<051<H00d<4@0F51L04@lB018@4`0301<?400901@?400K5Q`0DDmD01PF6`0=2a005A<H01TG
700A3a@04Q0E00804a4F0P0B41D200l=4005014?4P0B41<04a4D01DC5P0@3Q400P0?3A001@0>30l0
3`d@010>4@0300@09b8X00803@P>00X00`0401LB600C3Q@03@P>01D@5P0?2Q0050lE018=4@0D3Q80
5@`?0P0D2`h0100E30l05Pd@01@;3P0E30l201@;3P0C01<:3@0@2P`03`/<010<3P0@2`l03`X>014<
4@0D3aD04`hE01D@600Q6bD01@0900d74P0:10h040/B00h9400@2a404@`B010;4002018=4@0800l:
3@0C3a004Ph?00h:2`0B3Pl040`=00l;300@30d201DA4P03014=3P0@30d040`=00@040`=00X04@d>
00L3100F4Q<03@T:00l;300A3@h03@T:010<3@0A3@h04Ph?0P0@30d01@0F4AD01P4500d8300A3A00
100300803`X>01L02@@8010;3`0F4AD04`hB01@?4`0@2`l02PD900l:3P0B3A4061<G020K7`0>2@d0
1P45018=4@0>2@d02`H:00l:3@0=2@X01`<401/G600?2``05a<D00d92P0200h:2`0400l;300@30d0
40`=010;3@8040X<0P0?2@/0500@2P`04@/=00h82P0C3@l03@L900X41P0=1`T02@@400`61P0=1`L0
40X:00d71`0<1PH040X:00H0000K5AD030H600P20P0A2`/03PX90P0?2`X200`81`0500l;2P0V8R40
2`L6010<2`0;1`H00P0<20L04`0L61L0LFe/048n?@0@30/0=30_01/G5P0A3@`040`;00l;2P0<20L0
2`L600X61@0B3Pl07a/L02dY:P0e<C8030P901@A4@0>2P/00P0?2``05`0=2@X03`/<010>4@0;3140
71dU0492BP071Ph06ALO00T63@0A31<03`P?01063P0B21006PlE020E6`0B2@`05@lA010:300E3a40
2`D7014;3@0?2@/040X<00@03`T;00H01@0100@000070@<03@L900`6200C3@l300l92`0400h82P0=
1`T03@L900`620<03PP:00<040X<014;3@0>20X01@0>20X00`0D2Q004`P>01<83P0301873@0301@9
3`0E2Q0050T?00804`P>00/04`X?00/52@080PH01P04018<400I4aL050hB018<400@2Ph03`T=00h8
300200d72`0<00h8300<1PX030H:018<400A2`l04P`@01TC5`0H4QH05a4E01XD600400804P`@0P0@
2Ph300l93@803PP<00T03`T=00h8300=1`/03PP<00d6300>1`l04``C01@=500?20l00P0<1PX0;P0=
1`/03PP:00l92`0=1`T030H8014;3P0B3A404@`@010;3`0>2@d03`X>00P31`0@2`l07aXN06YUJ@1?
BTh030L;00P0100B2@h04@P=010:3P0P6Qh08Q/R00T42`0J5A`04a0G00P53P0C41T03``E024K:@0<
1Q805@lI02lZ<@0@2a405a8F00h:2`0<20T02`H:00l:400A31803PT?00`5300N61`03PT<018<400<
1PX201<=4@803@L;00<040X>014;3`0@2Ph0300?2@dDooooo`006oooool00`0;1@L03PP:00h82P02
00`620L03PP:00`040/?00d8300>2@d04PdA01<>4P0?2Ph03@P<01`G6`2WXZH0D4]?00T4200D3a<6
00l:3P0300d8300>2@d03PT=00<03`X>00H06QDL010;4P0O6R402@@;01LB6@0=20l400l:4@0>00h9
400?20l02`4601P=4`0N4aT02P8601@;400K4QL08adQ00d8300<1`/04@`@01@?4`0C3Q8300h93@08
00l:3P0@2`l06QDI00l:3P0500@06QDI01TD600=20`200l:3P08018=4@0C3Q8040/?01PC5`0P6al0
6QDI01@?4`0?2Ph201@?4`03010>3@0?3P`04A0>00805A@B00D03`d>010>400E4aH05A<F01HD6002
01DC600L01LC6@0G4A/04a0I01DB6`0G51d05QDM01XI8@0?3QH071`T01<C6`0F5Qh06ahU01@E6P0C
51T04Q<H01DF6`0H6Ah05AHK01@E6P0C51T04Q<H01<D6@0D5AX05QLL018C600D5AX05aPM01HG70@0
4a@I00T051DJ01DF6`0E5Q/051DJ018E6P0F6Ah05aXQ020S:P0J7BD00P0I72D01P0R9Bl061XV02<U
<@0J72P05ATU01/N;@<06b4a01/06b4`01TO;@0L8S006b4^01`R;P0O9C407R@_01LN:00M8Bd0720/
01hR;P0P9S808BLb01dT;P0F7bP09c4g02@_=@0M:2h07bX^01/Y:P0P;Rl08C4a02/j?@0N;C00:CPl
010O900O;S<00P0O;SD2020_=P0;024`=`0Y>T40834i02<d?00K;3@093Do01//=P0M;SP07bll020`
?@0M;CX00P0R<Sl0M`0Q;Cd0935102/hB00/>DP09CE202@e?`0P<C/08S@n02@g?P0iC580:Ce401@Y
;P0Z?4408S@h01la<`0Q<cD09SPj02Pj?00V>3X0:ca302Lh@@0L;CL06RXg01d^>@0I:S8072de01l`
>00P<CT093Dm020a>@0[?4@0;Sm702Xk@`0]?TH0:S]3020a>P0M;SP0830m02TiA`0[>d/09SE8024`
@`0M;3l07blo01l_?P0H:3D06RXg020_>P0d@Td0A59M02Hd?00V=C`07bhc02@c>00^?D804R4X020_
=`1XMWl0=49=01TV;`0P;CH06bPa01/U;P0F82T0628[01hW;P0C72<04aXQ01XQ9`0F7B<06B0W00TA
700J8Rl06b<`01`R<00I7bd06b4]02<W<P0F6RD051HR01TL9@0G6R<08RD^02L^=P0I8RL04AXP01PO
9@0G7b803aLJ01DJ7P0@5AP04AHI01@H6`0@51D05a/O02T]=P2Z/K/082La02H]=`0F7B@0OHB:030h
>`0F7R407RLV010I600M9R@04adL00hG700I8b/02QDK01XS:P0H8BL08b`a020W;@0O9RX04aPL00lD
600E6Qh06AhQ00805a/L00D05QXK01HJ7@0E6A`05ATL024T:@0201PK800a018E700E61l05QTN01@H
6`0E6A`051PK01/N8`0A51T06ahS04E8C`0L7bH06A`S01TL9@0M82T04QDN01LJ8`0C5Ql051LP01PK
900F6B8051LP01HI8P0H6b@05QTR018E7P0D5b005aXS01`L9@0821006QXR01HF7P0I6B404a<K01DE
7@0F5Qh061PP01DE7@0D51`061PP01DD6P0:2@l0EEAJ01DD6P0[:S00:BP^01@C6@0A41H04a8H01DD
6P0201<B60802`X@01X05aHL00`;4@0=31805A@J00d<4P0D4aT04Q4G01dL8P12@DL0eM?G05YHF`0X
9RL06aTJ01HD5@0K6QP0:2LU06ASH@3=c<P0W9^G02@S7`0E51005A@E01LF700U92T05A@I00P73080
518E00d05A<F01HB4`0D41404`l@018=3`0O6R00EE=H01/I7P0>31405A<H01PF6`0A3a@04Q0E0080
4a4F0P0B41D4010>4@804@lB0P0?3A0300h<3`0?00l=400U82H0P7^1038]<`0D3aD05a8H010<4@07
0PP061<I03Lb>00L5ad03@P>01@?4`0D3Q804`d?00804P`>01`04`d?01@>400B30h04`d?01@>400C
3@l04P`>010:300?2``050lB01D@500C3Q8040/@00l:400B3A<03PX?024L8`0300D07ALP01TC7@0G
4QT04@`C01<>500B3A<040/@01D@500@2`l03`X=0P0B3Pl200h:2`06010<3@0>2P/030P9018>3`0A
3@h02@D61P0@30d05`0A3@h020@500`82@0?2``04@d>00d92P0<20T03PX;00l;300@30d03`/<00h:
2`0=20`05A0D01XE6@0B3A40:bHZ00l:3P0C3Q8030L;00h93@0@2`l04@`@00804`hB00H02`H:014<
400?2Ph02`H:02dX;00Z9BT200X52@0900d8300>2@d04Pd@01<?400V8R<02PH700/7200>2P/04`l@
00803PX;00H03`/<010<3@0@30d040/=00l92`0=1`T200h82P803`T;02<03@L900l92`0;1@L050h@
028L7P0G4A8030H6010:2P0H4Q804@/;00h8200@2PX0100000l92@0C3@d01@0001@>3P0=2@P03PX9
00l;2P0=2@P030P700l;2P03000020@301HB4@030000510?00d9200<20L0?c/j02DQ800:1PD030P7
00P40`0300h:2@0300d9200<20L030P7008040`=00D030P9014=3P0400404@d>00`82@0300h:2`0D
010<3@0A3a8030lF02DX<@2PXj`0CdmI00/:4P0K624040dF00l:4@0>1`l040TA01T?5`0N5AX05Q0B
02<M7`0;1@L04P`>00`6200:10H400d72@0800h82P0=1`T030H801XD5P090`D040X<014;3@0=1`T2
00l92`0700h82P0=1`T03@L900d72@0>20X03`T;00h82P0200d72@0300l92`0>20X03PP:00@03PP:
00L03PD:00`3200<0`P03PD:00l62`0@1``04`X?00805@`A01P04`X?01@;400E31405@lC01H@500@
2Ph0;bT]03hh?00/9RX04P`@014;3`0@2Ph03`T=00d72`0@2Ph03`T=00/52@0?2@d0618F01<=4@07
0PD0100200d72`0B310201H@500300X5200?2@d03`T=00<03`T=0P0>20`02@0?2@d03PP<00d72`0>
20`03PP>00l8400B2a804@XA00h73P0300d72`0I00h82P0?2@/03@L900`620070`D02@@801XE6@0@
2`l00`0200/62P070PH04PdA044l@03el?@0[JR/01PC5`0>1@X05PdB010730090`L05@lC01@=500=
20l040/B018?5P0201LD7@0I00P63P0<1Q@00`09010;500G4QT03@P>05eHG00A3@h03@T:00/62P0?
2Q003PT?00/63@0:0`X040X>00h8300?2@d04`dA01LA5@0>20`040X>00`62P080PH02@<700`62P06
00d72`H03`T=5?ooool001_ooooo00H03PP:014;3@0B30h04@/=00l92`0@2P`200l92`<03PP:00<0
3@L900d8300=20`00P0=20`0200>2@d03`X>00`72`0L5a/0LFa`03D`=00B3A404`hB1P0?2Ph07@0=
20`03PT=00l:3P0@2`l03`X>00h93@0A31<01`<901`G7P0E41L04@`C00d83`0>2A003`XA010;4P0C
3QD05A0G01H?5P0n=3/03`@:01D:400D2a007QDJ01893P1HDUH06QDI00d8300A310040/?00804@`@
01l040/?014<400A31004PdA014=400f<CD0>C@h01<>4P0@2`l04@`@01<>4P0=20`030L;010;3`0<
1`/04PdA01TD600E41@050lC00l:3P0A31004`hB018?400?3P`040l=01LE500I5aL0518D010>400A
3a804Q0D00804Q0E01404@lD01DA6@0G4A`04a0J01DB700G51h05aDO01DD7@0L6R@06ATR00h>5`0E
5Ah04aHM01<D6@0G61d05AHK018C600201DF6`0;01HG700D5AX04a@I01DF6`0F5a`05AHK01@E6P0E
5Q/05QLL01@E6P0C51T00P0E5Q/04`0H6Ah06Q/P01HG700E5Q/05aPN010C6`0B5Ad05APR01/O:@0B
5R0071l[01@G8`0G6RL082<a020R<00F62L06ah^01/Q<@0J83000P0I7bl0100J82l06b4_01/Q;`0K
8Bh201XP;01Z01/Q;00K8R`07b@`01dR;P0N8bl082Hb020W<P0K92h072D^01`V;P0S;SD0930g01dY
<00J9b`06bX^01h]<@0G9RX08c8h024`=P0K:S007B`b024`=`0R<CP082lg020^=P0Q;cL07Rlg02Lh
@00Y>T80;d1902Hg@@0G:3809CI002@e@00R<ch072dh03=4C`0gAe@0931002LdA00]>TX0<3e=02Xj
B00W=dD0:SY703=5DP0T=T40:ce7028f@00_@d/0<dE=02Tk@P0U=c`09SPl02Pk?@0Y?3h08SDi02Tk
@@0W>440;Cm905]/N00V=d4062Xb01/]=@0O<CT072he01la>00M;cL09cU102Tk@`0U=cl0:Sa402Li
@@0O<CP09SPn02Tk@P0W>D<0:ca902dmC@0W=TT0:3M:0350D@0a?e008C0o01h/?00W=D40:3E103A1
BP0e@TX0FFM/02hl@@0Q<3@09C<g01DS:P0M:S<0>4E>02<`?00H8bd06RH_01LR:`0T;SL08R`e01PQ
:@0C72<05b0W01PO9@805adR04X05QdS00hG8@0J8Rh0620/01`R;`0F72T05A/W01DI9@0F6RD06A/W
01PJ9@0G6R@06QdW02P_=@0L9BT04a`O01@L7`0B6Qd04ALJ01LL7`0F6ad06AhO01HK6`0A5QH05AXK
01TP9`0b>D8092/d01`S:`0E72<04QTO01TQ900B6Qd07BDW01/S900J8b804Q/J018L7P0L9R/02A@G
028/;`0G82@07BHX01TO8P0B61X051XK01PL7P0E6Q/051TI01TM7P0I7Al061`N01LK7P0F6Qd05ATM
01/N8`0F6Al05aXP01<F7@0H6b<06A`S01HI7`0D5a`030lE01XM8`0F6Al0<3<i0;Zma00f>D0061/R
024T;@041a007b8[01DH8@D05QTR00@05aXS01DH8@0E624051LP0P0E62401P0J6R805ADM01TI8@0D
51`04Q8J00l?5`805QHN00X051@L01<C6`0E5Ad05aLO01HE6`0A41H0=C@j02DT:P0N7B<071/Q0P0D
4aT0;@0E51X051<I01@C6@0F5A/040lE01TH7P0X9bd05A@J00h=4`0A41H05aHL018A5`0G5Q`06aXP
040oA@32`<D0G5YM01hL7P0H5QP06aTJ01DC500I61H05A@B03Lf<`0^;BX05aHB018A3@0A41805A@J
01PG700B4AH040lD018@4`0F51L06ALJ01TE5P0E4A804Ph?014<3P0B3A<06aTN01<A5P0I5a`030X?
010>4`02014?50<04Q0E00@04@lD018@4`0B41<04@lB0P0@3Q400`0?3A0040hA010>4@0300l=400=
010>4@0?2`l0:B@Y01@?500G4QL02@@901D@5@0D3a@03@P=01HA5P0@2a004PdB01@?4`0201<=3`80
4P`>0P0C3@l06P0B30h050h@01D?4@0E3a404P`>010:300@2`h05A0C01LB5P0D3a<040/?00d83@0B
3A<03PT?01PC6P0L5ah03PT?00l:4@0A31<03PT@01LB600F4AL03@P=00l:3P0>2@d040/>0P0A3@h0
200@30d03PX;010<3@0?2``03@T:01/G600O6a`05Q8C1`0@30d00`0e<C802@D6018>3`0200d92PH0
40`=00d04@`?00l:3@0B3Q004@d?00/72@0D3a803PT<014=3`0B3A0040`>010;3P0@30h03@P;0080
4`hA00l02@D700`72P0L5aX05Q8D00/72@0E4A<06QDH01<>4@0>2@/06aLH034];P0B3`l03@T:00X6
1`0@30d00P0>2P/0200?2``040`=010<3@0A30d03`T;00`6200>20X040X<0P0?2@/02P0<1PP03PP:
00d72@0Q6ad0>C<e02PR8`0>20P04P`<01/E5@0C3@d3018<300C00d71`0?2@T05Q0@01`F5P0=2@P0
3PX9010<2`0>2PT03@T800l;2P0B3Pd040`;01<?3P0710<040`<010<2`0=2@P04Ph=00`81`02010<
2`H03PX901`03`/:010<3@0810D040`=00`82@0E4A8040d=00d92P0?2``040`=00l;300B3Pl04a4D
018E701AE5h0loOn0=kPj@1KG6D05QDN01<A6P0@3QD03@TA00`83`0>2A0040XA00/52@0K5AL02`D7
0P0A2`d200d72@802`D700/03PP:00l92`0<1PP05Q0B02PR900<1`P04P`>00h82P0;1PL040X<00l9
2`0200d72@803PP:00<03`T;010:300?2@/00P0>20X300l92`803PP:0P0=1`T30107300401483@0B
2@h04PT>010730804@P=00T040L<01483@0C2Pl03PT<010:3P0<1PX0618F01H@50070@D00P0@2Ph2
00l93@0>00h8300A2`l04`dA018<400D3Q806Q@H01H@500K5AT0FeEI01LA5@0;1PT04`dA00/62@0A
2`l200d72`803PP<0P0?2@d03@0>20`03@L;00l93@0@2Ph03PP<00h73@0@2A4040T@00l83`0<1@`0
3@L;00h8300=1`/00P0>20X200l92`0`02HP8`0M61`01P85014<400E41@03`X>00X52@0D3a<08A`P
07agN`1<Ad/05Q4E0107300C2Pl040L<00`62P0?2@d03`P?00`73P0:1@`04PlF00`94P0=2Q<0BdQA
01D?7@0E3a/05A0I06AOIP0D41D04`lB010<3@0<20T03@P<00h93`0:1@/030L=014:4@0<1PX03PP<
00@00P0E3a<01@0301TC5`0N61`05@lC00d72`0>20`03`T=300>20`Dooooo`006oooool01@0=1`T0
3PP:00d72@0;1@L030H800<03`T;0P0>20X200d72@0<00h93@0A310040/?00d8300>2@d04PdA010;
3`0<1`/03@P<010;3`0?2Ph02PD91P0?2Ph03@0<1`/03PT=00l:3P0@2`l03PT=00d83P0?2Q4030L>
00T42`0F4AP04@`C01@?5P0=20l00P0<1`h02`0=20l03PT@00l8400G3Q<03P<9020E6`0A20d07QDJ
01XA5P0=1`/030L;00805A0D00<061<G01TD600>2@d00P0>2@d06P0?2Ph040/?010;3`0W8RH07aXN
00l:3P0I51P040/?01XE6@0G4QH040/?01TD600E41@03`X>014<400B3A404`hB01@?4`0F4AD04PdA
010=3`0A40h03Pd;01<B4@0J61T06ALJ0P0G5AP05`0D4QL04Q0E01@B5`0G5AX06ADM01PB7P0C41/0
5A8M01LD7`0G5B009B<^03Hd?`0L72H051@N020P:P0C5Qh051DJ01LH7@0D5AX05AHK01/L8@0G61d0
5QLL008061TN00<05AHK018C600B4aP00P0G61d0600E5Q/04a@I01@E6P0I6Ql061TN01HG700D5AX0
5AHK01LH7@0J72806alX00hB7@0O8bh00`LB01`P:`0E6BD061/Z01HI:00D5bH08bHg01XM;P0C5RL0
6b4a01TO;`805Q`/00T06Al^01/Q;`0J82h06Al/01@J9P0B62@06B0[02@[=@0K8Bd00P0Q9c<0700M
8bl06b<^01hV<@1EGfP09Blh01TS;00O;3@072Tb01l/=00M:c@0@e9J02@c>P0L:S<082lf024`=`0L
:c808c8i02Dd>`0Q;cP07bdf020^=`0N;cL04b@/01PY<@0a@T`08C8l028c?@0]?TP202/lAP0:01`]
=`0S=3h05bPb01/W=P0K:3P07b`l02XgA`0/?4/0:SY902dmC080<49@0380;d5=03Y>F@0O<ch09CM2
01`^>00K;SD08C@i02Hi?@0V>S/09STm028e>`0S=Sd0?U1J09:T/00/?TP06B`c01d`=`0S=Sd083<j
02<f?@0O<ST09SU002XmA00X>d80;3m602Lj@@0M<3D0:3`m02`o@`0Q=3X08SA002PhA`0X=dT0:CQ;
02`iC00U<T<06BHg01h[>`0T<Cd04QlX02Db>`0R;cH0=T=9018P8`0O;C007R`_01XW;@0E8RT07R/d
01dZ=080628[01d072H_03M1BP0g@TP07bP_01XS:P0J8bP05QdS01`Q9@0A5QX05Q`Q01`S;@0O9c80
5alZ01/Q;@0E6bL04aTU01dQ;@0E6BD06Q`X01lQ;@0F62@051LQ01/P9P0C6ah04QXM01@L7P0B6Q`0
51TL01LM7@02018H60805Q`J01<05adL01TP9P0G7RH092/c00T@600E72<061lU01`T9`0I8B@05alQ
01dU9`0F7al06b<U01PR900I8bD0628T01LQ8`0L9BH05QhP00807B<S01l0728R00lC4P0G6aX0ATY9
01/O8P0J7R406AdP01PL7`0G6Qh05QTN014D6@0G6R005APO014D6`0C5Qh03a8K01DH7`0A51/09RT`
04iAF00L7bH051LN034d>`0E61l0AdYA01<F7`0M82T03a8K01LJ8`0I72D05aXS00804QDN00d051LP
01PK900C5Ql04aHO01LJ8`0E62404QDL00h>5P0H62006ATQ01XJ8P0@41P06QXR00805ADM00H04Q8J
014A6@0E5Ad05aLO01<B600F5A/2010?5@0@00d<4P0D4aT04Q4G01DD6P0D4aT04Q4G01@C6@0A41H0
3PdC01<B600D4aT05QDK01TH7P0@3aD07ahT00X93`804a8H01<03`hD02XY;P0C4A@061HI01TG6P0D
4QD03P`=018@4@0C4Q0081lM014@3@0K6QH05QDA01HE5`0H5ad02`X?014@5@0L6b0040hA00803@/>
00`040`=014=3P0B3Pl04`h@01LB600<2Pl04Q0E00l=4P0B41D04@lD00l=4P0@3Q<2014?508040hC
1P0B41<03P0A3a8040hA010>4@0?3A0040hA014?4P0G4QH00`0201<>4P0300806A@H01D@500@2`l0
2`H:0P0H4aL0100@2`l01003018<3P0A2`d2010:3009014;3@0B30h04P`>01@>400F41805@lA018<
3P0@2P`03PT=00804@`@0P0@2`l03`0A31002PD;01LB600:1@/02@@:01LB5`0?2Q003`XA01@?5@0W
8RP0:2<Y01LB5`0C3Q803@P<010<3P02010<3@08018>3`0@30d04`l@00d92P070`@04`l@01LC500<
20T600h:2`0801<?401`K6d061@E01DA4P0;1`P05Q8C018>3`0?2``200d92P0800h:2`0?2``03P/;
00h:2`0S7b002@H601<?400?2``200h:2`8030P90P0>2P/0100D41403PX;018>3`0A3@h3010<3@0;
00l;300<20T04`l@01DA4P0?2``04Ph?00<0000E4A8020@501@@4@0<20T00P0>2P/02@0?2``040`=
010<3@0B3@h040X<00d72@0@2P`04P`>014;3@0200h82P0501D?4@0>20X03@L901@>400@2P/00P09
0`<0600A2`/02`D5010:2P0?2@T01`4101PB4P0>20P05Q0@00d8200<20L03PX9010<2`0>2PT03@T8
00h:2@0;1`H02@D400h:2@0I5A@0510?014=3@0=2@P01`<2010<2`802PH500D05a<B010<2`0@30/0
40`;00l;2P0200h:2@05018>3`060P<040`=00L3100H51D00P0>2P/05@0@30d04@d>010<3@0C3a00
518E01TL8`1VJWD0m?So0>obn`19BU@05QHP014@600@3aL03PdE00h;4P0=2Q403@/@01D@500H4Q@0
7QPJ01XD5P0200d72@0>00l92`0<1PP030H8010:300A2`d03@L900L10`0C3@l01@0101H@4P0>20X0
81XL014;3@0?2@/200d72@0300h82P0?2@/030H800<03`T;00@04@/=01<=3`0?2@/03`T;0P0>20X2
00d72@<040L<01003`H;00d42@0<0`P03PD:01483@0@1``03`H;01483@0C2Pl02`D900L11@0@2Ph0
2@@700X4200K5AT03@L;100>20`03@0;1@T04@/?01H@500@2Ph03PP<014;3`0;1PT0FE=G00P21P0?
2Pd05@lC018<40080PH00P0;1@T0@@0<1PX03@L;00d72`0?2@d03@L;00X4200>20`04P`@00l93@0<
1@/03PL?014:4@0@2A003@H=00`62P0=1`/03PP<00d72@0>20X040X<018<3P0F4A@030L;00X52@0<
1`/020<700l:3P0:1@T03PT=01D@50080`L06A@H00d8300B2@h03`H;01483@0@2Ph030H:00`5300C
3QD06QDL00X73P0C41T0>SM004a9DP0W8Bl01@0;01LA6`0300D06QDK00d8300:1PL02@D600d8300=
20h020<900l:400;10/040X>00l93@0C3A40?SPl02<M8@0@2Ph04@/?00802P@800<03`T=00X4200?
2@d01@0?2@d600d72aCooooo000Kooooo`0>010:300?2@/03PP:00h82P0?2@/040X<01`F600E3a40
3@L900/51`0>20X04@/=014<400?2Ph200d8300400l:3P0A310040/?010;3`803`X>0P0>2@d06@0A
31005Q4E010;3`0>2@d04PdA00/62P0@2`l03@P<01dH700D3a<01`8601<>500@2a<02`D?01TC7@0J
51h02`D?014;5@1=Ae407QPR01PB700E3aT0100801D>5P0C2A000P0B1`d01P0B2@h05@`A01H=4P0B
31003`X>00L21P805Q4E00@0I5mS018=4@0;1PX04`hB0P0:1@T02@0A310030L;00l:3P0C3Q8040/?
018=4@0J5AT06A@H01D@5002010;3`0I018=4@0;1`X05a8F01<>4P0E41@02PD9018=4@0G4aH05Q@E
01@B4`0C4A<04Q0C010>4@0?3A4040hC014?500C4AL05A8I01LD6`0I51d0618N01<@6`0B3aX0514L
01HD7`0201@B7@0B01<C7@0D51h05ADO01DH800C51T030dA01TJ7P0K72007QlS01LH700H6Ad07b0T
01XK7`0?41@05AHJ01XK800D5AX05ADM0P0H62008`0E5Ad04Q8J00X:4P0G5al06a/S01DE7@0G5al0
4Q@K014E7P0D6bD06Al[01<I9@0C6BH06Al]01@J:00H7Rd06Al_01LM;@0F72`06Al_01lU=@0R:3P0
8BLg01hT=00K8C006b4_02@Z>00C6BH06b4]01@J9P0L8bh0=Se701dS;`0Q:3<07bLb00806R8]01D0
7bTc03]5C`0Q;CH0:3Dn01`Y<P0Q;CP0934j02Dc?P0N;3H08Blh00dK9P0P;SL09C<l02<a>P0O;CH0
7B/d01`Z<`0N;3D07bdf020a>`0Q<S`00P0R<cd01@0Q<S`0834k02XkA@0a@T`08c@n0080;3e50140
5bPb02Te@`0B82d07bdj02Db@P0^?Td0;Ce<02/kBP0a@e40;d5?03=5D`0jCE/0:ci<02i0C@0W>D<0
9SU002/nA00202e0A01N0395B@0]@4H08SDk01d_>@0Q<cl093I002@g?P0`@dX0>4]B02<f?@0K;SD0
7S4h01lb>@0R=C`09CPo02Pk@P0[?TD08cLl024f=`0T>C`07c<i02Dg@`0]?D`0:CU802LgA`0[>4T0
9c=4028^?P0T<4008bhk02D_>@0K9Bl07BL_02Ha=`0M:2`082/]01hY;@0M:2h06RD/01LQ:P0T;SP0
?dUB02La>P0H8R/05b0W01<L8`0a>3l072<Y01lV;00R9b`07B8V01/P900K8BH0=ci601lX<@0C72D0
8RTc014H8P0F72P041@P01<G8`0F62D06Q`Y01lQ;P0K7BT04aPN020U:@0K82@03a@G00P=400D6A`0
6R0P00hD500D7A`03aPE01<L6@0@6AL051`O01@K8@0U;3805ahT01<J800L8bT041PK01dU:00S:bh0
6B4S01XR900O9bT05R0R01DN800>5QP08BT[014H6P805adM01P0724P01/O7P0G6aX06AdL020T8`0F
6Qd06alR00X>4@0Q92T05QTN01XM8P0>4AP04aHN018E7P0>4AX03a8K01DH8@0<3aP05aXS02T/=@1?
DU/071lX00/>5`0K7RL201HI8P0801dP9`0@4aX03a8I010C6P0B5A`06QdT01HI800@4aX201HI8009
00/>5@0C5Qd0CU5H02X]=00B5A`0=3@k02DV:`0@4AH04a@I00805QLL00<05aPM01@E6P0D5AX00`0C
51T0500G5Q`020L=01`K8@0C4QP06aXP010?5@0F5A/051<I01<B600D4aT05QDK01LF700I61h040lE
01LF700>3A<01`H<01XI7`0F5A/051<I0P0B4AL04P0D4aT04Q0F010>4`0B41D04a4E01@B5@0F51L0
518C018@4@0F5A<06QTG01TH5P0G5Q@051<F014@5P0A41D040lD014@5@804Q0C00P0518E014=3P0>
2P/04`l@01<>3`0I51X05Q@I01<A5P804@lD00L04Q0E00h<4@0>31404Q0E014?500<2Pl03P`A00H0
3P`?00X01@<601DC5P0C4A@02@L:01<A500A3a805A0D00l:3P0G4QH071LK0P0A31004`0E41@050lC
01@?4`0B3A404@`@010;3`0@30d04`l@00d92P0?2``0510A00l;300E4A8040`=014=3P0=2@X0510A
010<3@0@2`l00`0A3102018=4@805A0D00@04PdA00l:3P0>2@`03`X>0P0;1P`01P0B3A<06QDK00`7
300B3A404@`@014=3`@04@d>00H04Ph?00l;300>2P/03`/<014=3P0B3Pl2010<3@803`/<0P0>2P/0
3@0C3a00<Bd^01`H6@0C3a003PX;00X61`0<20T0510A01<?400=2@X03PX;00/7200@30d0100?2``0
2`0>2P/03@T:00d92P0=2@X04`l@00<0000B3Pl040`=00/7200>2P/040`=00803PX;00D04Ph?014=
3P0?2``05A4B01<?400200l;30803@T:00X040`=01@@4@0C3a0040`=018>3`0C3a0040`=00h:2`0<
1`T020840P0?2@/0100>20X04`d?010:300<1PP2014;3@0400l92`0A2`d03PP9010:2P803PP800h0
40X:01<=3@0B30`04@/;00l92@0=1`L03PP8010:2P091@@05A4@00h:2@0A3@`05A4@018>3@804@d<
00@030T800P40`0810<05a<C0P0>2PT200d9208030P700l03PX9014=300=2@P02@D400d9200<20L0
4@d>018>3`050@805Q8C018>3`0C3a002PH701DA4P0810D00P0>2P/01P0M6ah061PP02DX<@1cMWl0
MgN102TY<P80410H00L02PXA018A5`0000D05QDK0040100>2@d04@/=00804`d?00<03`T;00`6200>
20X01P0>20X01P0@2P`04`d?01D?4@0A2`d02`D700l92`8040X<0`0A2`d06`0;1@L03`T;00d72@0m
=cT03@L9014;3@0C3@l040X<00l92`0@2P`04P`>01@>400A2`l0100201`F6P0@2Ph0100201PB5P0>
20`03@L;00h8300@2Ph03PP<00`62P0C3A404@/?010:3P0300l93@0<00h8300<1PX03`T=010:3P0=
1`/03PP<014;3`0G4AD0HeeQ00l93@070@D05@lC0P0@2Ph00`0?2@d03PP<00h8300200d72`0@00l9
3@0C3A404`dA014;3`0?2@d040X>014;3`0C3A404P`@00l93@0?2@l02`@<00@0100Y8RT0100401@>
4P803`T=02X04P`>00h82P0:10H03@L901@?4P0=20`02`L:010;3`0?2Ph03PT=00L21P0M61`040/?
00l:3P060@D030L;01483@0B2@h04`X?010:3P0?2@d03@H=01<>5@0300D03``C024N9`2>Ri@0gmcU
04Q2D00A2aL050lH00L22@080`T03`X>00L3100810D040/?020K8@0=20h03@P?00l83`0?2@d200h8
308040X>00h02`D900h8300@2Ph04@/?00h8300<1PX05@lC00h8300:10P02`D901D?4`0500<03`T=
00h830<030H:00<03@L;ooooooooool04_ooool001_ooooo00X040X<00l92`0>20X03PP:00l92`0@
2P`03@L900h82P0?2@/040X<0P0A2`d01P0?2Ph03PT=00`72`0<1`/03PT=00l:3P804PdA0P0A3102
010;3`0C01/G6P1]J6`0HEaP01D@50080`L04PdA00l:3P0F4AD08QdQ01/F6P0=20`03@P>00h84@0@
2Q@02P@>00l94`0D3QP05Q0J05]EG`0201D?6@0700l94`0J51h03`P@01P=500E2Q0050T?01893P02
01<:3`0<00l93@080`L06aHJ02@O8`2?RXh06QDI010;3`0>2@d04`hB014<400@2`l04`hB0P0B3A40
1@0C3Q803@P<00h93@0D3a<05A0D00805Q4E00h04`hB014<400F4AD04PdA00`72`0E41@0H5]O02DQ
900S828061HG01`J700K6A/05A<F018@50804@lD00X04@lE01<@5`0D4AP0514I01LC700H4Qd04a0J
018?6@0D4A/05QDN0P0C4A/02P0C4a`051@M01DE7P0E61l06a`P018C5P0D5AP0@T=606]/K`0e=ST2
01TJ7@0701DF6@0F5aX06Q/N01@E600H6Ah05aLO01DE7@0201@D700@01HF7P0P82P06ATQ01`L900G
5al04Q8J03Dg?P0M8B`05QdW010G8P0F72L06b8^01/Q;P0C6BL061h/01TO;P8061h^02D06R0`01lU
=@0W;Cd08BLg01DK:`0A5bH06R0^01dS<@0X;S/06Al[01hT<00S:C@07bH`01hV<00M9C0072@^01XS
;P0J92h06bD_028]>00G8bh07b/f01PU<P0N:cL06bPd028`?00N;3T07R`h01PV<P0M:cL07R`f02@b
?00Q;cT082hh020^=`0Q;cP08S0i00808c@o018093A002<c?`0Q<S`08C8l028c?@0U=Sl0;Sm802`m
A@0V=ch0:CY202@a>`0J:3@07B/g028`?00[>dT09SI402LgA@0_@Dl203E7E@1503A7E@0`@e40<4=A
02TkB00W>T@0:ci702m3B00`A4P09c/o02Hj@00hBe409c]201ha>`0Q=Cd08SHm02`oAP0dAdh093Ln
01hb>@0U>3l0:3a302Pk@P0R=Sd08CDl02Lj@@0W?4009C`m02Lm@@0U>T00:3]502XkB@0U=DD09cE5
02TeAP0T;cl07RTf01lZ=`0N:CD0628/02@^=`0X<SX07RT]01lZ;00L9bT07RT[02<^<P0U<3L082Xc
02D_>@0P:C8072D]028/=00R:c80624X01DL8P0C6Ah05adR01`Q9@0J7b8061dP01LL800B6B405AhV
01<L900F7BL06R4[01LN:@0S9c<061`X00<05QPV01@0<39001dQ:00Q9BX05QXO01@I7@0A5QX04QLJ
01HM7`0C6Q/05QlN01DN7@0G81h0624P020X:`0Q:2d072<X010G700M9BT06R4V024Y;080620S00`0
4QXL02<[;@11BD`07BHX01DM800B6Qd082HY014G6P0F6ad05AXK01PL7@0F6QX2018E500:01LJ6`0M
8B@05a/O02DY;@0>4AH07B0U01LJ800C5Qh05aXR01DH8@8041<M01405ALR01HH8`0I6bH03Q4K01lQ
;00>41/05QTS018E7P0H6b@03a8K01@G7P0F6B006ahU01@G7P0H6b804A@K01@G7P0201dP9`0>01<F
7@0I72<02`hE01dP9`0B5A`04aHM01DF6`0F5a`04Q<H01LH7@0K72404A8G018C600C51T2014B5`0<
01@E6P0G61d04a8H01TH7P0=318071/Q00/:400J6Al05QDK01@C6@0B4AL04a8H0P0D4aT0200C4QP0
51<I01DD6P0D4aT04a8H01DD6P0F5A/051<I0P0B4AL02P0D4aT05A@I01HD6@0G5AX05A<H01<A5@0D
4QD0518D01<A4P0D4Q<201HD500601@C4@0C4QD04A0F014@5@0@3a@04A0E0P0B41<01P0D4QD05Q8C
01@@4@0G4a@05A0A01@?5@804Q0E00T04a4F01@B5`0G5AX08R0U01LE6P0=2a003`dB010>4`0C4AH0
1P0@3Q40500H5QT03@/>01HD5`0U8bH06aTL010>4@0B3A003PX<01LB5@0L5aX05A0C01HA500B3Q00
4Pd@014=3`0@2`h03`/=00h:300=2P/04@h?0P0>2``0300C41403``=01@A4P0E4Q<02PL800h;300B
3a004@h?014<400B3A804`hC01@?4`805A0D00h040/>01<>4@0B3Ph040`<00h:2P0>2P`05A0F02XU
:`0C3Q@03PT?018=4P0B3A4040/?010<3P@040`=00@04@d>010<3@0?2``040`=0P0A3@h3010<3@@0
3`/<00/0510A01<?400>2P/03`/<00l<300>2P/04@d>00L4100C3a002PH7014=3P0300l;2`<040`<
00H04@d=00H20P0B3Ph030P8010<300@3@d200h:2P0>00l;2`0>2PX03PX:00l;2`0@30`04@d=01DA
4@0J5QH0510@00d92@0?2``04@d>01<?400B3Pl3014=3P0=00h:2`0=2@X03@T:00l;300A30h03@L9
014;3@0>20X030H8018<3P0A2`d030H8010:3002018<3P0:01@>400=1`P030H600d71`0@2PX05@l?
01XD500A2`/040X:00l92@803PP800d03`T9014=300@30/03@T801@@3`0>2PT04Ph=00@1000K5aH0
4`l>00d9200Y9B@0;b/Z00<040`;0P0?2`X200h:2@03010<2`0?2`X03PX900804Ph=01X02`L8018>
3`0B3Pl071PI01<?400>2P/04@d>010<3@0D41405A4B01<?40081PT02PT@00d>5P0O7bP081lX00h>
5@092@h03PhE020P9@0820/071/Q01LG6P0D4QD03`/<010:30@03PP:1`0@2P`200l92`8040X<0P0>
20X200l92`8040X<00X04@/=00l92`0B30h02`D7024K7@0>20X040X<014;3@0@2P`03`T;0P0@2P`0
3@0A2`d03@L;01/E6@0910L040/>01dG6`060@@03PP<00d72`0>20`040X>00h8300<1PX00P0>20`0
1P0=1`/03PP<00h8300>20`040X>00h830803@L;00P03PP<00l93@0B31003@L;02PR9P0500<050hB
00h830D03`T=00X04@/?018<400A2`l040X>00h8300=1`/03`T=00h8300;1@T03PP<0P0B3100600B
2a405@hF01@=500d;C@03`X?01TC5`0=20/04`dA01D?4@0A2`d02`D700`6200?2@`020@7010;3`0<
1`/03`X>00d8300?2Ph040`?03dh?00E41@03@T<00h:3@804PT>01`050/@018<400A2`l040T@00h9
400D3aH0924X02/X<@2;R940c<WA04DoC@0@2QH03`TC01TD6`0>2@l03PX=01dI6P0D41403@P<01`G
7@0?2Q004@`B00d63@0=1`/03PP<00l93@0B310050hB0P0?2@d02P0@2Ph03`T=00h8300=1`/05@lC
00d72`0@2Ph0;2HZ02XT:00>20`2014;3`0400l93@0>20`03`T=00l93ACooooo000Kooooo`803`T;
0P0=1`T200l92`0700d72@0@2P`04P`>018<3P0?2@/030H800h93@0400d8300300h93@0@2`l040/?
00@040/?02@0@3/o01HA5@0=20`03`/>014<40080`L03@P<010;3`0>2@d03`X>00h93@0;1P`03@L@
01TC7@090`d03`TC01PB700<1Q00618L010:50070@/0M6ih00<01`0D3AD04@H=01873@0C20h05PdB
01XA5P0L4aP04`dA00T4200@2`l04PdA00l:3P0E41@2018=4@0300d8300C3Q804PdA00803@P<01P0
40/?01<>4P0=20`03@P<010;3`0A310050lC01LB5P0E41@04`hB00h93@0E41@05Q4E024L802MV9`0
?3Lk01<@4P0E4a@06QPK01LE600@3Q404@lD01<A5P0B41D3018?5P0:014>5`0E4AX0618L01@A6P0C
41T0514J01HE7@0I620061LO01HF7P805ADM00L051LM014B5P0J6ad08b@V09ZKW@3nool0N7Uk0080
7AhP04006AXL00h?4@0<3@l05aPK01PI7P0G5al05ADM01@D700E5Ad05aLO01@D700>3QH071`T01/K
8`0?3aL0;2hf02/_>00O9S005A`V01XQ:`0N92l06Al[01@J9P0F72X06Al]01XP;P0K8C40728b01XP
<00@5RH03aDU01LM;@0L8S405ad[03HlBP0m@e004QPT020V<P0Q:3<06B0Z02</=@0M9Rl072D^01lY
<`0P:S@06bD_01DQ;@0T<3`08blk01DS<00L:SL0;S];01HS<`0I9SH0524a01`Y>@0N;3T09cE2028`
?00Q;cX082hi024_>00R<3T08c4l0`0U=D80=P0T=4408S<m024b?00P<C/05bP`028c>`0N;cL09CHm
03a=E01oS9@08c4j024_>00L:S@06b`f02dnB00U=D809cU502HhAP0cAE<0;3m=02@gA@0`@e80;3m>
02/nC00Z?TP0:Si502Tn@`0Z?d<08cPm0314BP0X?4<09SY302a0B00V>T4093Po02Lk@P0Y?D@0<dM>
03I:D@0_@dX0;T9902Hj@@0Q=C`09c]202m5BP0/A4P0:41402ToAP0[?dX09cU702@c@P0W=4@0:3A4
02@_?0<082Xd01405b4Z02H`>@0c?T<08B``01lZ;00R;Bl07bX/01`W:`0I92T051hW01`V;`0S;3<0
8R/b01XS:P0H8BP072DZ01lV;00201/P901i01TN8P0F6Qd051PK01<G6`0I82H08BXa020Y<00?5R00
72<]01/R;00R9S80720/01/M;00H6RT051HU028T<P0J7BH06ahU00lB6P0E61l04QLK00lD600B6Qd0
72@V01DM7`0F82404Q`K01DO800A6A`05QhQ01DM80094A@05QhQ01DM800A6A`09Bd`06adM`0W;c80
72@W010H6`0C6ah05AdP02@/;`0S:2`05Q/O01@I700E6A`05a/L01DI6P0D5AL051HE01HG6@0C5aX0
3Q4F020S:00E61d06A`R00lB6@0?4Q/04QDN01<F7`0C5B405QPT01XL:0092aP07b4^020R;`0K7BX0
3@lK01HH900N8BX051LP014D7@0A51/010L>00X=500@4aX03a8I00d@5`0C5Qd05QTP01<F7@0E61l0
4A@K00`?5P082a806QdT01`O900K72405aPM01@E6P0B4aP06AXO00d>4`0B4aP051DJ014B5`0?41D0
51DJ01TJ7`0H5ad04A0F010?5@1NGF<051<I01/J800D4aT05A@J01HE6`0I61h06aXP01XI7`0D4aT0
6aXP014@5P0G5Q`07A`R00l>500D4aT04a8H018A5`0201<B600601DD6@0G5AX061HK01DC600B41D0
4Q0C0P0E4aH02P0D4Q<04Q0A018@4@0C4Q004a8E014@5P0A41D040lD014@5@0B41<2014?4P0@01@@
4@0E4A805Q8C01HA4`0?2Q003@/@00l=4P0A3a@04a4F01DC600e<cP09bDZ01DC600B41D0518G01TG
70H040hA00`020H900/9300`;S40>SPk01`J7@0?3A004Ph?00l;300B3Pl0510A00l;300@30d301<?
4007018>3`0A3@h04@d>00h<3@0@3Pl03P`=00d;300200h<3@0600/92P0F51D03@/<014?400@3Pl0
518C0P0B3A<04P0C3Q@04`hB01<>4P0C3a0030P9014=3@0C3`h04Ph=010<2`0?2``061<I030[<P0B
3A<02PD;018=4P0A310050lC01@@4P@0510A2`0@30d0200?2``061@E018>3`091@H040`=00l;300a
;Bh08AdN0P0G4a@0100>2P/01`<400d92P0=2@P200h:2@08010<2`0A3@`04Ph=014=300E4A001P81
00h:2@0K5aH200h:2@0X014=300?2`X030P700l;2P0A3@`03`/:00h:2@0<20L03@T800h:2@0=2@T0
30P900h:2`0@30d03@T:00/7200<20T04Ph?01HB4`0J5QL05Q8C014=3P0>2@/02P@6010:300?2@/0
3@L901<=3`0<1PP05Q0B02dW:@0V82803`T;010:300@2P/040X:00l92@0@2PX04P`<01@>3P8040X:
01003`T900h8200>20P03PP800d9200>2PT01`<200d9200:1PD03`/:01lK6P091@@04@d=01LC4P03
00004@d<0`0=2@P200`81`0300/71P0<20L03@T800803@T800L03`/:010<2`0D41404Ph?00`82@0=
2@X03PX;00804`l@01<05A4B00h:2`0D41402PH700h93@0300L04PlF01HC6P0C41L04@lD00X:3001
00@05QDH00H61P071`T0V9RI00h<3@0>2P/03`T;00<03PP:00<03`T;010:300@2P`0100@2P`01@0>
20X03@L900d72@0?2@/040X<00<03@L90P0>20X200l92`8030H800@02P@600X51P0E3a403@L90P0>
20X200l92`0A00h82P0=1`T03`T=00@00P0Y8bL01`8500P21P0G4AD03PP<00d72`0>20`040X>00h8
300<1PX03PP<00l93@0@2Ph00`0A2`l0300?2@d040X>00h8300B31006A<G018<400E3a<02`D900d7
2`0;1@T05a4E00T41`803PP<00D03`T=010:3P0@2Ph03`T=00h8300200l93@0P00h8300?2@d03PP<
00`62P0=1`/030H:00/52@0>20`050dC018;4`0600H030D<00D01@0F41@03PP<018<400C3@l040X<
00`6200=1`T04Pd@01@?4`0>2Pd02PD900@00`0@2`l06aHJ00<00P0Q72002PD901<>4P0B3A420148
3@0K01<:3`0A2`l04P`@018;4P0J5A`02PD<014>5@040@X03``E030]=P0@2QP06A<O01<>5`0>2A00
40/A014<400E4A804@d>00/62P0E41H02PD;010;4P0=1Pd03@L;00h8300?2@d04@/?00804P`@00<0
4@/?00h8300=1`/00P0=1`/01@0;1@T04`dA01TC5`0i<cL08A/O00<04@/?00@03`T=00h8300?2@d0
3`T=5?ooool001_ooooo00H03`T;00h82P0=1`T03@L900h82P0?2@/201<=3`05018<3P0A2`d03`T;
00d72@0>2@d0100?2Ph700h93@0d01LB5P080`L04@`@00d8300?2Ph06A@H010;3`0C3Q803`X>014<
400C3Q803PT?00`64@0D3QX02P@@00l95@0L5R803PPD00X5400C3AT06aDQ09fGX`0B31P04PXE0187
3P0C20h05P/A01XA5P0P5a`08QTN018=400C3Q8030L;00d830070PH05A0D01XE6@0H4aL03@P<01<>
4P0D3a<03`X>014<400F4AD06aHJ01@?4`0A31004PdA014<400B3A404`hB01@?4`805A0D00`061<G
01<>4P0A310091lS00P31`0A3A40518E01HD5`0A3a<03@/@014?500E4QP201<@5`05018?5`0B3aP0
4@hG01DA6@0H4aX00`0D4AP301DD6P0A01<D6@0D5AX05AHK01DH7@0>3a<07QlQ01`M7`1FEeT0XjBV
051AD`0G61X04a@F01DF600D5AL04A8D01XK7P0F5Qh00P0F5R0201LG8@0901HF800C4ad05QHP01dM
9`0H62803`lI00lA6P0R:C407BH]00806B8Y00H06B8Z01HO:00@6B804QXU01@L9`0F7RT201LO;00O
02D[>`0H7Rh051XZ01XP<00L8S4051XX01TO;@0U:cP05Q`X02`b?P0O9S406B0Z028[=00K92d06R@]
01lY<`0O:SD062@`01/W=@0K:3D06bTf024^?P0M:SX062De01DR<`0M:S/072Tj01l/?@0L:CT08Bll
020^>`02020^>@808Blh03d08S0k02De@`0U=D@09CE402De@P0S=3h08S<m01h_=`0H:C406BXb01X[
<P0U=Sd0<dA;06IcNP0O;SD0:3Ln02<a>@0F9bl08S<k02/lAP0`@T`0;Cm;02Dg@`0L<3/0;d9@02e0
C`0_@U40;d9@02XnB00T>3l08SLl02e2A`0[@4D08cPn02Lk@P0]@DX0;T9:02Di@00P=3/08CDl02Pl
@`0cAdh0<TI=02XnA@0/@4L0:3a302Di@00Y?D@0<TM>02i7C00Y@4H0:d5902e1C00Y>dT09CE302Le
@P0X=4809S4l02D_>00U;SL092df00807bPa05X0<CY002Pa=P0M9bT09c4b028/;P0O:2d07BH/01TR
:@0N9c007BH]020Y<00N9bh07RD[028Y;`0L8BH08RL[01hS9`0J7R405QXM01LK7P0H7B00:C0f01DN
8`0@6B002Q4I01/R:P0K8R`06AdY01hR;P0K7B`05aPZ01/L;P0F5bP05aLS01/K9@0B51h051LP01<F
7@0D6Al031<I028Z;@0C7Al06bDW01@N7`0K9BL041PK01LO8P0X<3<0620S01DM800K8bH041LM020W
;@1TJg408bX`01`S:@0B6Al072<Y01lU:`0X;C<05AXP01<G6`0<3a@04aHK01HH700G61`05QLK01HG
6@0G61X02`lB014D6@0>4AH0=3Ln01PK8P0C5Qd04aHO01DG8P0E5b<05QPT01PJ9P0K7BT04A<P01XL
:`0G6BH051HS018D800I6bL05aXS00/>5`0D5b0201<F7@0?034d>`0R9BX03A0E01@G700F6Ah03a8G
01<F6`0I72403Q4F01LJ7`0K7R<07B0U00hA5P0E5Q/051DI00804a@H01/06AXN01DF6P0F5a/05QLK
01<D600@4AD04a@H01LH700P7bD05QDK01/J800J6Al07A`R01LF700M72806QTO01LF700D4aT04Q4G
01<B600B4AL06APN01<B600S8RP0;Rdc01HE6`0C4QP00P0B4AL201<B600901<A600D4AP05A8I01<A
5`0B41D04a4F01HD600G5AP05A<D00804a4B00X0518C01@B5P0A41H04A0E010?500A41D04Q0C014?
4P0>30l04@d>0P0B3Pl0100E41405Q4G01@B5`0E4aP301HD6@0601/I7P0E4aP040hC010>4`0B41D0
7Q`Q1P0@3Q40300K6A`06ALJ01/I700E4aH03P`?01@B5@0B3Pl040`=014=3P0B3Pl03`/<010<3@<0
4`l@0P0B3Pl0100A3@h04@l@014?400@3Pl200d;3003014?40091`P03P`=00803P`=01H020H700l=
3P0C3Q@04`hD018=4`0A310040`>010<3@0=2@X04Ph=01DA400D40d04Ph;014=30060@L04PdC00/6
300?2Q004@`A01HA5@0@2`l040`>3`0@30d03P0A3@h030P900h:2`0J5QL03`/<034];P3@c<d0FEEF
00H20`0A3@h040`=01@@4@0300003@T80P0>2PT01`0@30/04@d<018>3@0810<03@T800P40`0/:2L0
0P0<20L0300>2PT04@d<00l;2P0=2@P040`;014=300@30/04@d<00l;2P0E4A00920O024M7@<040`=
0P0?2``200`82@06014=3P0D41404@d>00d92P0=20T03@L90P0D3Q00300@2P`050h@00l92`0B30h0
7QPJ01D?4@0;1@L05Q0B01D?400A2`/040X:00l92@803PP80`0@2PX200l92@0700h8200C3`h07QXI
00l;2P0;1`H04Ph=00h:2@02018>3@0400l;2P0=2@P02`L600h:2@804@d<0P0@30/300l;2P<03PX9
00h03@T800l;2P0;1`P02PH700l;300B3Pl04`l@00/7200:1PL04Ph?00`82@0S7b002PH700h93@80
3@P>00`03`X@00`73@0;20/04a4B01XE6@0>2``05A@B00`:2`0J6AP00@0000`82@0@2P`2018<3P03
010:300>20X03PP:00D03PP:00H02`D700`6200@2P`04P`>010:300;1@L200d72@803PP:0`0?2@/0
1`0<1PP04`d?018<3P0U7b404@/=00d72@0>20X00P0?2@/200d72@0@00h:3@0a;300P7]o01hI7@03
00804`hB00d8300<1`/03@P<00l:3P0=20`02`H:00X4200<1PX03@L;00h830<03@L;00X040X>00/5
2@0?2@d05Q0D014;3`0G4AD02@<7018<400C3A403`T=0`0>20`01@0?2@d040X>010:3P0>20`03@L;
00804@/?01003`T=010:3P0>20`04P`@01PB5P0A2`l02@<700d72`0A2Q0040TA0109400D3A@04@XA
01LA5@0;1@T03PP<0P0?2@/03P0>20X03`T;018<3`080`L03`X>010;3`0C3Q803PT=00l:3P030080
4PdA00<00P0B3A40@3/o0P0@1``06P0A20d03`T=010:3P0A2Q4061<J00T42`0A3QD04PlH00H3300B
3aP05a4O01XD800500T020<:01<>500?2Ph02`L801<?400E41@06A@J00T42P0?2Q0040T@010:3P0?
2@d03PP<0P0?2@d0100C3A404@/?00l93@0>20`200d72`0600l93@0F41@02`D901PB5P0:1@P06A<G
0P0@2Ph400h831Cooooo000Kooooo`803PP:0P0=1`T200h82P<040X<00@04@/=018<3P0C3@l03PT=
100@2`l0100>2@d03@P<00d8300>2@d300l:3P0I01<>4P070`H040/?010<3`0@2`l04@`@00`72`0B
3A405A0D01@?4`0?2Ph030L=00d84P0A2aL07aTU00`64P0I4al06aDQ010<5P0B31P05@lK00h8500H
4Qh03@D@01873P020146300D01893P0E31405PdB01@?4P0<1`/050lC010;3`0E41@05Q4E01dH700K
5QX04`hB018=4@0C3Q804@`@018=4@0F4AD06A@H014<400>2@d4014<400401<>4P0E41@04@`@01dH
70804`hB00<03PT=01dH700C3a<00P0D4QD01P0B41@04Q0E01DC600F51X0514H01@A6@<0514J01/0
5Q8I01LB5`0E4aP05A8H01DC5`0E51T03`hC00l?4P0@4AD04a@H01DF6@0F6Qd061TK00h?4@0F5aT0
8B8T02//;P0I6Q`07AhP010A4`0D5AL07QlQ01HG6@0E5QT05QHN01LG8@0F5R000P0G5b400`0I6B<0
5QHP01TI8`0201HF800401dM9`0I6b@05A`S01DN90805b0V01D05QlV01HO9`0I8R/0620Z01TR;00L
92l07BD`01XR;`0G7Bd07B<c01/Q<@0E6b/05A/Z01dS<@0I7bd05Q`Y01DK9`0Q9c<07RD`02<Z=00M
9Rl00P0G8BX0400J92h06bHa01LS;`0M:CL06bPf01@R<00H9SH093=305QWM`0Y=TT07R/n024^@00M
:S/08c1101XW=`0R<3d2028`>`2>024_>@0P;SL082hi02<c@@0T=4<09CE402De@P0U=T0093Do01LX
<00K;3@07Rlg024b>@0P<SL0838f028_=00M;3007Rda01/Z;`0Q<cP07Bhf059SJ`1cQHh0=TQA02@f
@@0X?4L09SU702XnCP0^@U40;T=@02XnBP0V?4@09S]202U0A00_ATX0:3i402a1B00^@d`0:Ci602Hk
@P0U>d4093Y002@i@00S>3l08CLm024f?@0R=ch09C]102ToA@0/@DP0;dM=02]4BP0Z@T/0<TMB02m3
C`0[?D/0:3Q602Le@P0V<Sh09S8j02H`=P0V;cD08b`c028[=00O:2l09c0f02D_<@0L9RL082X[01hX
:@0Q:bd09c0f028[<P0P:C808RXb01dU;00G7bH05ahT01PO9@0F6al06QlS01LL800E6A`061`O01/O
8P0M82<04a/N01/T:@17D5L082L_01<J8P0E72H05QXV01dQ;@0H6RT05AHX01lP<P0M7bl07A`Z028R
;`0K6RL06A/W01LI900I7BH06B0W03]2B00K9BT082X]00lI700D7b406B4T01`T9P0^=SP08b/^01dU
:00L92L07B@Z01PO9@0T:c407bH/01LN900F7B<06b0X01TN9@0M8BT02a0G02hb>@0I72804A@I01<E
6@0E5QX05QHJ01DE6@0B4aL04A@I01PK8@0@4aT0>ci501TL8`0N8BT071lX01/M:0806A/W02/061XV
01PJ9`0G6BP05QPX01TK:P0G6BH051HS00h@700D5R804QDN01@G800?4QT082<Y04Q;D@0Y;3403a8G
01<F6`0@4aP02`hC01@G700A51T04aHK024T:@0d=c`082<X018E6P0@4AD05AHJ00l@500F5a/02``@
01dN8P0E5QX04a@H01@E6@0E5QX04a@H014B5P0/:c4081lU01HE6`0C4QP04Q4G00@05A@J0P0D4aT0
1`0C4QP05QDK01@C6@0B4AL071/Q01XI7`0A41H00P0B4AL301<B600A018@5`0C41L0514H01@A5`0C
4AH0518G01LE6@0F51L0518D01<A4`0C4A80518C01<B5P0A41H04A0E010?500A41D00P0B41<0200?
3A005A4B01LC500C3a004`h?01@?5@0C4AH05A<H0P0D4QL00`0C4AH0518G014?5002014?500300l=
4P0C4AH040hA00D040hA00H0:2HY01lM800?3A003`d@01@B5@0@3Q43018>3`0301<?400E4A8061@E
00H040`=00`04a4B010>3`0@3Pl03@/<014?400M6a`0AdE6010>3`0E4a@03@/<00h<3@0?3@h2018=
4`0?014<4P0A31004@d?014=3P0A3@`0510?01@@3@0C3``04Ph:01<?3P0B3A<03`XA018=4`0H4aT0
3@P=00804PdA00<04Ph@018>3`0B3Pl00P0B3Pl01P0@30d04@d>014=3P0A3@h040`=00l;308040`=
01004@d>018>3`0B3Pl04Ph?02/W:00I5AH040`=014=3P0R7Ql0PGen03Lc=00;1`P061@E014=3P0>
2P/040`=0`0?2`T3010<2P0:014=2`0;20L06aLF03hj>@0:1PD040`:00h:200?2`T040`:014=2`80
4Ph<00d03PX800d91`0;1`D02`L501DA3`0H51@03PX;00`82@0=2@X03PX;00l;300@30d03PX;0080
30P900l03@T:00l;300@2`d02`D7010:300?2@/03@L901<=3`0B30h030H800d72@0?2@/04@/=01@>
400=1`P00P0>20P400l92@0A010:2P0A2`/040X:00l92@0>20P06aLF02TU900H51<04@d<01LC4P0?
2`X040`;01DA400B3Pd040`;014=300=2@P00`0>2PT300d9200D01<?3P0?2`X04@d<018>3@0@30/0
4`l>01@@4@0A3@h05Q8C00P41@0=2@X04Ph?01<?400?2``071PI00d92P0>2P/0510A010:3@0>1`X2
01H>4P0=00d82P0@2`/02`L7014=2`0@30X03P`900l=2P0A3@/03@L800l92`0B30h04`d?014;3@07
00l92`0700/51`0=1`T04@/=01@>400B30h03@L900h82P0200l92`8040X<00<04@/=00l92`080P@0
0P0C3@l00`0Q6ad030H800l92`0300h82P803`T;00h030L;00X52@0F4QD03@T<00l:3P0>2@d03@P<
00`72`0=20`03`X>00d8300;1PX040X>018<40804`dA00L040X>00l93@0E3a<06Q@H014;3`0?2@d0
4`dA00804@/?00D02086010:3P0B31002P@801@>4P0600l93@0P014;3`0C3A4040X>00h8300B3100
4`dA01H@500K5AT05@lC00h8300@2Ph04P/A00`53@0B2a803`P?00`5300A2`l03`T=00d72`0>20X0
3`T;010:300?2@/03`X=01LB5P1>BDd04`hB00h93@0A31004PdA00d8300?2Ph2018=4@0M00/72P0C
2Pl04PT>01483@0>20`03`T=0109400:1@`04PdD00d:4@0G51d04a0I00h;500@2QP04`dI02TT;@0Q
72<01P4700d8300;1`P06QHG01hI7@0L5ad02PD;00h9400A2Q404@/?010:3P0>20`00P0?2@d00`0@
2Ph04@/?014;3`02010:3P0700h8300G4AD03`T=014;3`0F41@02`D901PB5P02014;3`0400l93@0>
20`03`T=00l93ACooooo000Kooooo`0>00h8300=20X02`L800`62P0=20X03@T:00`62P0>2@/040`=
014;3`0@2`d03@P<00/62P0=20`200l:3P0600d8300;1PX03PT=00h93@0?2Ph040/?0P0A2`l02@0:
10D07A@G01H@500<1`X05@lC00`72`0@2a402@L<00h<4@0200`;400N01@A600?2A<091hX04]5C`0C
3AL02`D?01LA6`0D3QP05@lI00H02P0E3aT02@<=01094@0F3A4050/>01<:3@0D31005PdB01D?4`0B
31000`0400P32@0D3aD04PdC010;4@0B3A<05A0F01@?5@0;1P`02@@:0P0?2Q001@0A318050lE018=
4`0E41H05A0E00804@`@0`0C3Q803P0D3a<04`hB00/62P0G4aL02@L:00d8300C4A@040hA014?4P0D
4QD05Q@I01@B5`0C4AL0514H0P0E4Q/201HC700401LC6@0G4QP05Q<H01DC608051<H01@06QTN01TH
7@0G61X05QHH01HF5P0E5aL06Q/M01@E5`0E5QT04A8F01`M7`0D5AP03a0D00l@4P0I6Qd04a@H00h?
4@0i>Sh06QXR01PH8P804a<M03805QHP01`L9P0N7RP06a/U01HF800D51h061PR01`N9`0M92`06B8Y
01PP9`0I82P0620Y01DN9`0G7RP05A`W01DM:00I7b/061l[01@J:00O9C<06b4a01TO;@0L8S806b4_
01DK9`0A5bD06R0/02@[=@0Q9c<092/e01<L9@0J92d06B</01PR:`0J92h06bHa01TU<@0I9C<062Dd
01dZ>P0R;cl0528b04EBH`1AGVl08Bi0020]?P0Q;Sl0CU][04YGI`809C=002X0938o02<a?P0P;ST0
82hk020`@00R<T808c=202De@`0U=D809CI001TZ<`0D9Bd0834h02<d>`0O<CD09CLk01h]<00F9BP0
9C@g01l_=00N<3@07Blc02Xl@`0[?TD0:3]202PkA@0C9c80:d5<02LmB`0Z@4h0:Cm<02ToB@0^ADd0
<DQ>02Y1AP0T>d40<4M=02i5B`0]A4`0<DMA0316D@0]@dh202Y1B@0X02U0B00W?TH08STo01dd>P0T
>d40;dI<03A8C`0]A4/09Ce702e3CP0iCUT0<TIA02/mB@0X>DD09C<n028`>@0R;SD08B``01hY:`0N
:Bh082Xc02/f?00S;S<07BPZ028];`0R;2h09S0b02<];`0U;S<08b`c02H_=P0O:2d0624V01XS:00R
:Bl072@W01PM8@0A5QX041DI01<F6`805QTN024041@I010G7@063aH07RD]00894@0A62003aHP018I
8`0F6RD06al[01PK:P0D5bH07R4_028T<@0T9S8061XV01XL:00G6bH051PS00`C6`0h?dL05b0W028[
<P0@6b4072D[01/R:00J8RD072@W01dU:00^=ST072@W01dU:00E72800P0D6b40200J8BL05QdU01TM
:00I7BP092Pc01hR;@1>DEX05APQ0P0D5ah04P0F5Qh05QLL01<D6@0?41D05APO018E7@0O8R/05APQ
018E7P0K7RL05QPT01@F8P0C5B405ALS01HH900E5b@07Al/01<E8`805ALT01@071hZ01DG8`0F6B<0
4QDN00`?600K7RD04QDJ00X=4P0@4aP05aXO01TL8@0G6Ql04aHK018E6P0E61d03A0E018E6P0C5Q/0
1@P=00L:3`805AHJ01001`P<01/L800C51P0?d14010A5@0=3Q804A8F01TJ7P0C51P03@hB01<B600M
728010<901LF700>3A<061LM0`0F5A/02`0D4aT04a8H010?5@0I61h04a8H01`K8@0O7R@040lE014@
5P0@3aD04A0F00@04a8H00H05Q@I01LD6`0E4QT04a0G01DB6@0E4AP2018@5@04018@4P0B41404Q4?
018A50804A0E00`040lD014A4`0B41<04Q0C018@4@0O6a`08alP01TE5P0A3@h040hC014>5@0D4AP2
01DC600801@B5`0E4aP03P`A00h<4@0E4aP04a4F00h<4@0B41D5018@4`0600d;3P0>30d0518D01<A
4P0>30d0518C0P0D4140100A3@h03`/<014=3P0C3a05018>3`03014?400@3Q4030X=00803P`?01`0
5Q@F02XX:@2>S8d0518C01<A4P071@H04Q0A00h:2`0?2Ph040/@018=4@0D3a<05a8E01LC500B3Pd0
4`l>014=2P0?2`P040`9018>3@0=20`04@`B00d8300C3Q@040/?01D@500?2Ph03`/=1@0?2``0600A
31004Ph?018=400?2Ph03PX;010<3P0@2`l04@d>018=400B3A404Ph?059>C`0I5AH04`l@010<3@0>
2P/03`/<014=3P0@30d01P8301LC500300005Q8A010<2P@03`/800H03PX702LS800Z9R<04Ph;00D1
000O6aP200l;200500`81@0@30T0510=01<?300A3@X00P0;1`@01`0D40d04Ph;00d91P0=2@T03PX;
00l;300A3@h00P0B3Pl00`0?2``030P900h:2`02010<3@0?00h:2`0@2``030H800l92`0A2`d06A<E
02HP8P0L5QP040X<01H@4P0?2@/06A<E03Pb=00]9bP040X:00804@/;010040X:00l92@0>20P03`T9
014;2`0@2PX03`T900d71`0<20L04@d<00`81`0B3Pd03`/:00h:2@091@@040`;0P0>2PT00`0A3@`0
30P7010<2`02010<2`803`/:0P0>2PT08`091@@03@T8014=300?2`X0510?00d92P0H51D0;b//014=
3P0<20T03@T:00T51P0b;Rl0P7am010<3@0B3Pl030P901H@4P0D30l02`D701072P0D3Pl03PP800d7
1`0?2PP04Ph;01<?300=2@H030P500h8200=1`T030H800d72@0?2@/04@/=00H040X<00L03`T;00h8
2P0>20X04@/=01<=3`0B30h03`T;008040X<0`0A2`d0:P0C3@l02`D7018<3P0=1`T05Q0B00L10`0A
2`d03PP:00d72@0>20X040X<018<3P0?2Ph04`hB00d830080`L02@@801TD600=20`030L;00d8300?
2Ph03@P<00/62P0@2Ph04P`@01<=4@0A2`l03PP<00`62P0A2`l06A<G010:3P0=1`/040X>00l93@06
00@04@/?00l93@0B31003`T=00h8308040X>00d03`T=00h8300>20`03PP<010:3P0?2@d02`D900l9
3@0K5AT071HJ00l93@0;1@T030H:008040X>00P04@X@00`5300F3aH03PP>00L01`0:10P04`dA014;
3`<040X<01003`T;00`72P0<1`/03PT=014<400;1PX02`L:00/62P0400<05A0D00<00P0910P05A0D
01@>4P0E31404`X?0P0?2@d0500A2Q4040/B00d83`070`X06aDO00<02@0@2Q@03PPF00d74`0K5Ql0
2`H=00T42P0C3Q801P83010<3@0=2@`04PdC00P32@0>1`l03PL>0`0>20`0400@2Ph04@/?00d72`0@
2Ph04P`@01<=4@0@2Ph03PP<07QbMP0X8RH030H:00l93@0C3A404@/?01<=4@0B3102010:3P804@/?
5?ooool001_ooooo01H02`H<010=4@0?3A004PdC00X72`0:20/05Q4G00/8300=2`h03@P>00l;4002
00D030X?010>4`0A3a@0108700d93P0E41@03@L;00h82`0?2@/040X<0P0B2@`06@0C1PP050D80186
2P0B1``04`X?014:4@0>2Q402@P@00X:4P0F6B80000900T<5@0=2A004`hD01@?5@0C3Q@05a8H01XE
6`0N6Al020<900<0100J5A/02@@:01/F6P0C3P`00P0B30`01`0B3@d04@/=010;3`0C3Q<03`XA00d8
3`0=1a400`0@2Q@00`0?2A<03PPB01<=5`0201<=5`0:01/E7`0A2aD03PPB010:500<1Q004`dC01D?
4@0D41404Ph?01DA4P<04a4D03404@lD010>4`0@3a@04Q0E01DD5`0@41003Ph>01<C4`0@41804A4C
01DD600C4QL04Q4G014@5`0C4QX05A@L01LC6`0F4AP04`lF01XG800E51`07AdU01LH7@0E5Q/05ADH
018@4@0?3P`061DE01/L800B5QT051PL01/N8`0F6Qd04QDI00lB5`0B5QT04aHJ01PK800K7b8041<H
01HI8P0D5R80418N00lA7@0B52006adY01`N:P0A4al0418N00806adY02h05aTU01DI9@0D6RH05AXV
01@H900H7BT07bDa01LK9`0L8Bh07R@b01lR<@0K7bh061h/00X@7P0B62H0728^02@Z>00F72P07B@^
01HL:00E72H0;C@l05ELIP0]=3`0624X01`V;`0G92`0524Y01DR:`0L:C808Bhg028^>P0G8c006BDc
020/>P0Q;Sd0RiNU0<GAg`0Q;C/082`j02XfA00Q;S`0938o02@a@@0N;Sd07Bdl0P0N;Sd06P0N;Sh0
7bi102HeB00W=TT09CE502PhA`0[>dP07c0i018S:`0K;3<06b`b024c=`0_@DD093Hj024c=`0P<SH0
9cPo02Df?@0M<3H07C0g02XmA00Q=C`0<4A=02Di@P0S>T809Se70P0V?TP0?P0Y@TT0:dA;02]4B`0`
BDl0E6ed0319D00lEE`0:D9903=;E`0aB5P083M702e4DP0/A5009ce:03I;EP0R=Sl07S8i02Tm@`0/
@DH0;3m50315C@0_AE006Rhi02i2C@0X>T@09cU302<e?00O<3L07Bhe01`[;`0K:B`072X]024_<`0T
<cX08c8i01d[<P0J9bd07BX`01dY;@0U<3@0;CPl02<^<P0I92P062<W01TW:P0D8RD05R4S00lI6`0C
6ad051TL00X?4P0X;C404AHK01TM9P0<4a/05ahV01PO:@001@d05Q/T00@;4`0Z<CT05A`T0P0C6R80
5`0F7BD06B8Y01/T:`0K92/06B0X01`P:@0G6b@05ATR01PO9`0K8RX05ahX01TP:P0G7RP05A`V01PQ
:P0I82X072<]01XN:@0S9c009RXc04aAEP0M8RH06b0T00806AhR00D0724W01XO9P0D62<082@`01`P
;@0201LK9`0601PL:00@51l051PS01<G8@0P8b`041<L0P0E62403P0B5R404aLR00dA700<41/05QXU
01XN:@0K7b/06QhZ01/O:`0L82`06al[01HJ9@0I6bL061/T100F6B800`0H6b<05APO01<F7@0201DH
7`0901DH7@0E5QX06AXN01PI7@0B4aL051DI01/L800H6Ad05AHJ008051DI01L05AHJ01HG6`0F5a/0
4a@H014B5P0B4aL05AHJ01LH700B4aL051DI014B5P0B4aL04a@H00l@500C51P0414E014B5P0F5a/0
51DI014B5P0E5QX05QLK01<D600201TJ7P0301<C600A41H04Q4G00@04Q4G1@0A41H0<P0D51L04Q8D
01HE6P0A3QH040XF01LA7@0G41`05Q0J01`F800B41@02@T701HG4P0D51@05A<H01<A5P0A3a8040hA
014?4P0D4Q<03`d>01`K6P0S8R004a8@010>3P0B3aH05A8M00`:4P0I5Qd020H;010>4@091`X05aDH
00l=400?3A805aDJ018?5P0=2Q403`dB018@5@0D4QD04a4D014?4P0D4Q<03`h<00d;2`0E518061LE
00l>2`0<2P/02`T<0P0C4A@01P0=2`h06aTL01XH6`0C4A@040hA014?4P803P`?03/03P`A01<B5`0@
3a@02PT>01<B5P040PD03`d@010=400B3A404Ph?01<?400D41404`l@018@4P0B4140518C00/92P0J
61T040h?00l=3P0?3P`040l=00l>300<2P/040`=01D@500;1`P061<G00X61`0F4Q<0510A00h:2`0B
3Pl02`L800h:2`0<20T03PT=00T42P0<1`/030L<01HA5`0;1PX030L<01@?5@0A310040/@00d83P07
0PH05A4A00h:2@050@006ADD00d9200C3`h040d<01<?3P0D40l04@d<00/71P0200h:2@0@00`81`0=
2@P03`/:00h:2@0=2@P0?3Pg05mKFP0E4A003PX:01DA40070`803PX9018>3@0A3@`03PX900d920H0
3`/:00T040`<00T51P0;1`P04Ph?00h:2`0I5AH030P900X61`070`@00P0?2``03P0;1`P03PX:01@@
3`0G4a804`l>00d9200<20L03PX901LC4P0810<0510?01dI602MVIP0FEED0P0>2PT06@0<20L02`L6
00h:2@0;1`H02@D401LC4P070`803@T801@@3`0=2@P03`/:01@@3`0300009b<R01TE500?2`X03PX9
00`81`0;1`H030P700l;2P0;1`H020@301@@3`0H51<00P0=2@P0100@30/02`L600h:2@0C3`h200l;
2P<03PX900<03@T800`81`0<20L00P0@30/201TE508040`;01D0:BDV01lJ700C3a0040X<00l;300>
2P/04`l@00X61`0D40l0=30_018>3@0<20L04@d>018>3`091@H05a<D00H30`0D414030P900X61`0;
1`P00P0A3@h02`060P<03@T:00h:2`0:1PL04@d>00`82@0:1PL03PX;01TE5P0K5aP04@d>00803PX;
0P0>20X200l92`0500h82P0=1`T040X<014;3@0?2@/00P0B30h0100=1`T03PP:00h82P0?2@/3010:
3003014;3@0@2P`03PP:00<03PP:0P0A20/201072P803`H900H03PD80189300A20/03PD801072P0B
2@`401482`0801483@0C2Pl02`8701hD700=1@/02@07024G7`0=1@/;00l93@0=010:3P0?2Ph02`H:
010;3`080`L01`8601D@500B3A401`8600d8300>2@d04@`@00/62@0500h:2`0<014=3P0<20T030P9
01`H6@0;1`P03@T:018<401:A4P08A/O01D?4`0D3Q802@<90P0?21004P0?2A4040PC010:500A2Q@0
5@lM00P5400610`04@hE00D3200E41@040X<00/51`0<1PX03`P?00`5300A21003PL>00h93@803`X>
00@04PdA01D@500@2`l03PT=0P0<1`/03P0@2`l04`hB07E`M00U82@01@0400X52@0D3a<03PT=00<0
0P0D3a<01P4501D@500810L04PdA5?ooool001_ooooo00h05Q@J00T7300:20h04a4G00T7300?3A<0
20H<00h;4@0B41H02PP>00/93P0E4aT05a@K00`93`803`dB00D03P/?00`72`0@2Ph04@/>014;3@02
01@;3P0>01D:3P0E1PT05@H901@5200C20`04PP@014:4@0?31@03@dG00hA6P1hO8@0NGj:02HY<P0@
3A46014<400b02HQ9@0@2`l0:2<W01<>4P0@30d040d9010<2@0A3@X04Ph=018>3`0C3a005A0F018=
500A2a@04@/F018<600C3AP05@lH01@>6@0C3AL0618K01LA700A2aD04`hF01`F8@0M5b405Q0I01@>
6@0E41D05Q0B014=3P0D414071PI01HD5`0C4A@05aDH01DD6@0D4aP04Q4F014@5P0C4QD04Q8A018B
4`0C4a@03`l@014A500E51T051<I01@C6P0E51`201HD7P0I01PD7@0F41T06A@O01TG8`0>3QT0;Bdh
010B6`0?4AP051@I01HD5P0E4Q806aLG02h_<`0M82D03Q4F010C600B5AX05APM01XM8P0B5AX041<H
01@G700E61d05QTO01LJ8`0401LI9@0P01TK9`0A4al05QPT01HH900D5R805aTU01HH900G6bL06ah/
01lS<00M8Bh06al/01`O;@0D62D06AdZ01dQ;P0O8S0082@a02<W=00I7b`05A/W02H/>00D6RH05adX
01/R;00W;SP08BPa01<J8P0T:c8061lV01lX;`0I8b`201LT;00601LT;@0I9Rh06BH_01@Q:`0I9C40
6RHc0P0L:3D0B@0hA580@4YF02Lb?P0J9S805B4^024^>`0J:3D07b`k01`/>`0M;C`07blo01h^?P0M
;Cd09SE:024`A00Q<4<09SI602LgAP0V=T<0834l01d^=P0]?TH07Bhd02Li?@0V>3`09CLj024c>00N
;cD093Hk02Tl@P0X>d4093Ln024e?@0[?dL09c]501/b>`0W?DL0:45802M0A`0X@DP0;4E<035:D@0c
C5<09d1703I?EP0X@DP0>U=J02Y3BP0`B5D0:T5C02DlCP0dBUX0=TeK02ToC00Z?d/09c]402<g?P0X
>d80:3]102Tl@00Z?DD09CU302PlAP0V>D80:3Y302Li@@0U=Sd0:3U001l_=P0O;S@072/_01PW;@0Q
<CL00P0O;cH0C00O;SD07Rdd028_=@0O;C808Blc02Ha=@0P:bh06bHY01/U:00E8bL07bhb01HT9`0E
7b405b4R01PM800B5QT06QlR01PM8P0F7B@04aXS01PQ:@0>4Q`061`V01PL9@0G7RH09Rde01XQ:@0K
92T06R<X01/T:@0K9RX072L[01TT9`0M92X07bH/01`S:@0J8BT07B@/01hU;@0M92h06B0Z01TO:`0J
82`05adY01TO:`0H6bX08B@b01HJ9@0T:3<07R<Y01dR9P0I7R406QlR01TN8P0I7R@05Q/R01DI900D
62D06al/01hR;`0G6bP041@Q01HJ9P0@52005QXV01LK9`0A5B005QXV01PL9`0C5b<0720/01/O:`0I
7BT06QhZ01LK9`0J7RX201TM:@0401XN:P0I7BT05ATT01LJ8`805QTQ010061/S01TL900J7BD051LO
018E7@0C5Qh05QTQ01<F7P0@4aX061TM018C5`0D5AT05AHJ01LH700K72005QLK0`0E5QX301@E6@<0
4Q<G00D04a@H01@E6@0D5AT05QLK01<D600201DF6P804Q<G0P0C51P201@E6@0401<D600E5QX05AHJ
01<D608061TM00D05ADJ01DD6P0F5AX05QDJ01DD6@0701<B600W01DE6@0A4QD04a8G01@A600E3aT0
7ADP020H8P0K51d07QTO01DC5P0U9B<06adH01<C4P0D4QL0518E01<A500B41<04@l@018@4@0@3Pl0
4A0>018A3`0@3`d0518A01@A6@1<BE@071TR01HD6@0;2@`04Q4A018@400A40l05A@D00h<3P0=2`l0
4a0E014>500A3aD04Q0E00804Q0C00T04@l@01<A4P0E51<05QDC018A3@0@3`/04A0=01LE5P0@3Q40
0P0P7R407@0N71l0K6Y]01/I700D4QD03`d@010>4@0=2`h040hA00P83@0Z:Bl0=C@j01LF6`0:2@h0
518G00h<3`0?30l040`>010<3@0A30d040`=01TE5P0@3Pl020H7020N7`0T8R<02@L800l=3P0>30d0
3`d>00804Q0A00@040h?01<?400>2P/05a<D0P0A3@h0800>2P/040`=00l;300E4A8040`=01DA4P0A
3@h071LL014<4@0I51T0=2ld014<4@0:1PX04@`A00h93P0<1``050lD01/F6`0I51P04Ph>01<?3P0F
4Q402`L6010<2`0=2@P03`/:01DA400=2PT0:RHU00h:2@0I5A@0510?0`0A3@`03@0?2`X03@T801<?
3P0=2@T04Ph=01@@3`0:1PD05A4@00l;2P0B3Pd040`;00h:2@0=2@P01P0?2`X03@0>2`X02PH701HB
4`0B3Pl05Q8C00`82@0?2``08alP02TU9P0?2``04@d>01DA4P0@30`00P0@30/03P0?2`X03@T800d9
200?2`X03@T800X61@0A3@`01`@302`X9`0C3`h04@d<00l;2P0<20L03@T80P0E4A00300=2@P04`l>
01PD4`0?2`X04`l?020L6`060`804Ph=00h;2P0<20L03@T800h:2@<03`/:00d03PX900l;2P0=2@P0
2PH5018>3@0E4A003@T800h:2@0B3Pd03@T800l;2P0B3Pd03`/:00@03PX90`0=2@P01`0?2`X03PX9
01<?3P0C3`h03PX900l;2P0>2P/00P0=2@X04P0?2``04Ph?018>3`0>2P/03@T:00l;300A3@h030P9
010<3@0D414030P901TE5P0b;Rl05A4B014=3P0>2P/04@d>01<?40803`/<00/071PI010<3@0E4A80
6ADF00d92P0>2P/03`/<014=3P0h=3D0IF5R01LC500200h:2`0400l92`0@2P`040X<010:30<03`T;
00D04@/=00l92`0@2P`04@/=00d72@0200h82P0600l92`0@2P`040X<010:300B30h04@/=100@2P`3
01482`8040L:00D03`H901D<3`0A20/04@P;0189300200l62@@04@P;00P04@P=01893P0A20d040L>
01@:4P0<0PX0308;01<:4P/03`T=00d04PdA01HA5@0@2`l03PT=00/62P0G4QH0:bHZ00X52@0C3Q80
4@`@00`72`060@D03PX<00D03PX;00`02@H601@@4@0K5aP01@4201LC500>2P/02PD801TC5`0=1`/0
5Q0D014;3`0?20l200l8400:01094@0@21<04@TD014:500:11803P/F014>5`0B3aH030X?028M8@80
4P`>00D05a4E01T?5`0D2Q8050/C0109400200h93@<030L;01807APL01LB5P0@2`l03@P<00h93@0@
2`l03`X>00d8300C3Q802PD900d8300@2`l04@`@00/62P0K5QX0=c8f01LB5P0>2@dDooooo`006ooo
ool03P0B3aH02`P?018?5P0<2A002`P?00X73P0D4AP02PL>00/83`0B3aH04a0G02DR:@0B3aH04PlE
0P0B41D01@0:1`/05A0D00l93@0?2@`03`T;00804@P;00h04PL;01@82P0C1`T04`L90188300@2Ph0
4@XA00`83`0?3QH06a/U08:3S`1nP8`02@TC01DA5P804@`@00X050lC014<400>2@d05Q4E01LB5P0?
2Ph030L;00L21P0@30d04@h:0P0A3@X0100A3@`04@d>014<400@2a42010;4P0D00l94`0>21@03`XB
018=4`0A31<040/B01D@5P0D3aH04`hE01PC6@0[9Rd09b8X01LB600L5ah05A0E01D?4@0A3@h04`l@
01`H6@0F51L200d;3P0Y00l>4`0C4QL051<H01@C6@0B4AD04a<E01HF600B4QD03@`A014@5@0D4aT0
4a8H01DD700G5Al05Q@O01DC7P0B41X0>CHo03djA@0D52003@lK01lR;@0D5R804QDN01HH7P0H5a`0
5A<F01LE5`0:2`l02PdB01@G700K7R<06A`Q01<F6`0E61d03A0E01TL8@0R9BX05QTN018E6`0D5b00
0P0D5R800`0E5b<051HR018D800201TK9`0M01<E8@0S9C40<cE101lQ;@0D62@05a/W01`P;00M8Bd0
6AdY01HJ9P0G6bL061`X01LK9`0F6RH061`X01`P;00I7b/0=C]706E[M`0W;CT07bHa01TP:P0A6280
92/c01/R:P0O9R`06R4W01TR9`0G8RP00P0G92`08`0H9Bd06BH^01TV;`0K:3406RHa01/W<`0H9300
8Bdj01LS;`0P:SH092lk01dY=@0O:cL06RLc01TW=00T<Sl0:SY902PhA`0O;cl072`l01l_?`0V=DT0
7bi101d/?`0R<T809cM602LgA00L;CP0=DI>09^/]010DEP05bT]02`n@P0[?Cl0:3Xl00808C<g00T0
9cY002Pk@@0V>D00:3a502a0B@0/@4/0738m02Y0B`0V?dH00P0S?4<0E`0W@4L0:dA;02i7CP0/AD`0
:T=:02]4B`0bBe809d1702i6D`1ZPI40NY6Q02LnC00]@e00>e5N02HkA@0Y?DH09c]202Dh?`0U>3h0
:3/o02i1B00U>D00;D5:020d>`0S=Sd07Rlg028c>`0U=Sh06bXa02<b>@0R<CP06RPa02Lf?@0Q<3L0
8S4h024`=`0N;C@07R/a01h[<00N;2l07RT]01XU:00N:B/072LZ028_=`1IJ6l0=D58014J7`0L92L0
5AXM02<W:P0H71l092T]01@L7`0F7B<04Q/P028V;`0I7BH0;c<l02T`>0083aL08RTa01/T:@0I8RL0
624V01PS9`0G8RH051lS01HM8`0J8BL06B0V01TP:00M92`072<[01XQ:`0G7RP0:Blk02le@@0N9300
51XV00D85`0k?d`0T9BO01`P:`0E6R0082DY01@I700201PM8@0H01DJ800D6B005a/T014E800J7RT0
5a/V01PL9`0K7b/041@P00lC7`0F6RH06al[01LK9`0C5b@08RHb014E8@0/<3`0:Bdi01HJ9P0>4Qh0
5a/W01TM:@0H72P05a/W0P0H72P0100E6BD061XV01LJ8`0D5b0301<F7`0=01@G800C5Ql04A@M01<F
7`0I72D07R4X01<D6@0?41@04a@H010A5@0:2`l03PlC01@E6@0201HG6`0401DF6P0C51P04A8F01<D
60<051DI00h04a@H018C5`0A4QH04Q<G00l@500A4QH051DI014B5P0B4aL05AHJ01@E6@0B4aL04a@H
01@E6@<04a@H0P0E5QX01@0E5AX05QDJ01LF6`0H5a`051<H00804Q4F1@0C4QL09`0E5AX051DI018A
5P0L6A`07ATJ02HP800Y8b<0;RPX00H20@0G5Q@01@D301/M6P0B4Q804a4F01@B5@0E4aH04a4D014?
400>30d0518C01@C4@0C4Q005aHD01<A400C41L0CdaE02DR:00D4QD04Q0A01DD4@0R8Al05aHB028Q
7`0J6AL04@l@01<A4`0D4QL04a4F014?5002010>4@8040h?01T05A<D01PG5@0@3`/03@`8018A3P0C
4A803@/>00X82`0E4aH06QPK01<A500<2Pd02`T<014?4P0D4QD030X=00X82`0E51T020L=01@C6@0?
3Q<03`dB01LE6P0B41<04PlA00804Ph?00T04Pd>014=3P0@30d05A<D00/92P0J61T07adN00`:2`0?
3@h00P0=2``01P0>30d03`d>00h<3@0C3a00920Q04<o@0804Ph?03003`/<01<?400A3@h04Ph?00`8
2@0E4A804@d>01dH700>2@d030L;03<^<P0=20`050lC00d8300@2`l04@`@018=4@0A31003`/<00/7
1`0<20L03PX9018>3@0D40l04Ph=01<?3P0;1`H01@4001XF5@0300001P81014=300@30/04@d<01@@
3`0C3`h04Ph=01<?3P0L61L03PX900d9200F4Q400`00010<2`0A3@`03`/:00d9200>2PT600l;2P09
01TE5@050@803PX;03`h>@1_Jf`08alP010<3@0`;2d0=30a008040`=00D04`l@00d92@0=2@P02PH5
00`81`0200l;2P0?01@@3`0810<030P700d9200D40l05A4@00d9200@30/03`/:00h:2@0@30/05Q8A
01PD4`0K5aH04@d<00800`0000T0BDE406eYJ00S7ah01000010<2`050@006aLF00h:2@0?2`X00P0B
3Pd0100A3@`03`/:00l;2P0=2@P2010<2`0500`81`0A3@`03PX900`81`0>2PT00P0A3@`00`0?2`X0
3PX900h:2@0500h:2@@03@T800@03PX9018>3`0?2``03PX;0P0?2``04@0=2@X04@d>00l;30030000
30P901HB4`0810D03PX;018>3`0>2P/04`l@00X61`0C3a003`/<00T51P0G4a@07ATJ0080510A00`0
0`0005A@D@1fLW<09R8S00L4100O6a`06ADF085mOP3UhN80>3@e01PD5@0L61T2010:30804@/=00@0
40X<00l92`0A2`d050h@0`0A2`d0100?2@/03PP:00h82P0?2@/3010:300400h82P0=1`T030H800`6
20803@L900@04PT<01482`0A20/04@P;0P0@1`X0100G3Q404PT<0189300B2@`200l62@@04@P;00T0
4@P=01<:3`0F3A802`4901@:4P0B21002`4:01H=5@0>20`00`0?2@d2010:3PD03`T=00d03@L;014<
400@2`l03`X>00T4200;1PX061<G00@00`0E41@06A@H00P31`0Z9BT0;BT[00D03PX;00`05a<D00@0
0@1?Bd`0AD52024M7P0=2@X06aDI00d72`0A2`l050hB00h8300>1`h200l8400R01094@0@21<04@TD
014:500D3Q`05A8M00T63`0>2a803`dB00X52@0>20X04@/=01H@500D2Q8040H>01494@0D3A@04PdA
014<400@2`l03PT=00`72`0E41@050lC014<400@2`l03`X>00h93@03008020<701LB5P0B3A4040/?
00<00P8030L;00@061<G028M8@0=20`05a8F5?ooool001_ooooo01D03``E01<@6@0B3aP0104:010=
5P0=2Q<02@H?00P53P0=2Q<05A8K00h;500[:340Hf1W03Le>`0@3Q<06ALL014>4P0;1PX03`T=00l9
300?2@/00`0A20/03@0D2P/04`T:01482@0A2@`040X>014:4@0B3QD01P<<00P73`0M6bH0=C<n01HE
7@0C3a@00P0@2`l02`0D3a<04PdA00l:3P0C3Q80<2/_00d8300F4AD05a8F00X61`0B3P`04Ph=0080
4@d<00<040`=010;3`0D3aD00P0C3QD05P0C3AL04P`F014;4`0A310040/A00l:3`0D3a<04`hD014<
4@0A310081/Q01TD6@0=20`05a8H018=400E3a404`l@018>3`0F4Q<0518E014?4P0C4A@201<B5`0;
014@5@0?3Q@03PdB01<B5`0G5Q/04Q4G00h=4`0A41H04a8J018A6@0C4A`00P0E4ah201<A700>01dK
9P0>3AX051HS02T]>@0U:SH051PT014E800C5al05aPM01@C600C4QL061TN01TL8`0G6R42010C6P0[
01TL8`0H6b804QDL024T:`0Z;C@071lV01HI800I72D05aXS01@G800F6B805aXS01HI8P0J7BH06A`U
01@G800T9c00<cHo01lR:`0C5b8051PS01HJ9@0I7BP06QhY01TM:00K7bX06QhY01LK9P0D62<05ATT
01PL9`0G7BT082Hb04E;E`0>5Al04aXT018I8`0K8RX08bXb01DL8P0G7R@082L]020Y;P0301PS:@07
01XU:`0N:C008B/d024[=@0J92h082Xd01dW<`02020Z=P0H02@^>P0N:C<072Tb02Da?@0K:3<07B/f
02<a?P0_?dh0;3a;01h^?@0M;C`093A402<bA@0R<D@07bi101l_?`0U=D@0:SY70392CP0>7bL0D65Y
01h_=P0C92/0838f0P0R=3@0400N<3807Blb020c>@0O<SP0:3]302m3CP0S=d808CA2024gA00]@e00
;TA>02]2BP0Z@DT0:d9:02e4C00_ATh202i5C@0j0399D@0]A4`09ci602e4D00Z@E40=daM0357E@0M
<d00;T5?03I:E00X?4D0:3]202Dh?P0V>Cl0:ca302`oA@0S=S`09SU002e0AP0Y?4808c@l02Th@@0Y
=d007bdf020]=P0N:c@05B4]01l]=@0Q<3L082lf020^=@0O;3807BX`01hZ;`0O:Rh06bHX01PS9@0N
:2X072HY01TV;P12D5T08blf01@M8P0N9RT061dP01HJ6`0C5aP0724S010H6P0C6ah04A/M01LL8P0Z
;cD0UY^Q06ieN`0T:c406B0V01LP9`805QlV0P0F8BL09P0C7R@04APN01DL8P0F7B<061lW01`S:`0M
92`07RD_01/R;00/<Sh0<cU5028X=00H7RX08RDd01`P;@1VJWD05QXU01lT:P0>4aL04QLJ01HK7`0G
720051TO01HJ8P0J7RL04aLP02da>P0I7BH04QHO024U<00A5B002`lK01@H9@0/;ch08bHe00lB8P0B
5B@05a/W0P0I7BT01P0L82`07B4]01<G8`0K7b/06AdY01PL:0806AdY00D05a/W01TK9`0H6RH05ALS
01@F8P0201<E8@0D01HH900N82`06adY01<E8@0H6RH082</01@E6@0A4QH05QLK018C5`0H6Ad09RL[
01@E6@0E5QX05QLK01DF6P0B4aL04A8F01@E6@0F5a/201LH700>01@E6@0C51P05AHJ01DF6P0B4aL0
5AHJ01PI7@0F5a/04Q<G01DF6P0D5AT04Q<G01<D600D5AT2018C5`<04a@H00L05ADI01DD6@0E51T0
5A@I018A5P0@3a@04A0E00D04a8G02L0410E018C5`0G5aT09R@S01`I500L5a40A40f06APE`0h=Bh0
6aXF028R800I6aP04a<D01<A5P0D4QD05A<F01@B5@0B41403`d>01DC500C4Q003`h<01DD4P0?3P/0
1`D:01XH7@0F51P03`d>014@3P0E510051<?010?2P0D4`l05A@@01@C4@0B4A00518E01<A5P0A3a80
0P0@3Q42010>3`0I014?400B4@l04Q4?014@3P0A40d0108300`:3@0A3a804Q0C01DC5P0?3A0030X=
00/9300?3A004Q0C014?4P0E4aH04Q4F01dL8@0c<SL08B0U00h=4@0H5QT04Q0C018?4@02018>3`06
018=3@0A3@`03@T:010>3`0:20T03`d>0P0<2P/0100?3@h03@/<00d;300@3Pl201<A4P0C00X61`0J
5QL0>CDf00d92P0B3Pl04`l@014=3P0@30d04@d>00l;300S7b00920Q014<400>2@d00`0201D@5005
00@03`X>00`72`02018=4@0B00d8300;1PX03@T:040l?01ZIVD07a/J010<2`0?2`X04`l>01PD4`0K
5aH04@d<00h:2@0:1PD081`K00l;2P0>2PT03`/:0P0C3`h0300B3Pd03@T8014=300F4Q402`L600l;
2P0A3@`040`;014=300?2`X03@T800h:2@H03`/:00X02@H500D10P0N6Q/04`l@024M7P0300005A4B
01@@4@0E4A803PX;0P0B3Pl03`0?2`/03PX900/71P0=2@P04@d<010<2`0=2@P01@4001<?3P0@30/0
4`l>00H20@0:1PD03@T800l;2P02010<2`0?018>3@0;1`H04@d<024M700^:RT04@d<01XF5@0W8b80
2PH501DA400^:RT061@C00X71P0?2`X040`;00804Ph=00P04@d<010<2`0?2`X03PX900l;2P0>2PT0
3@T8018>3@803PX900@040`;01@@3`0F4Q40510?1@0>2PT300l;2P803@T80P0?2`X04P0A3@h03@T:
00d92P0@30d05A4B01LC500<20T06QHG00@00@0D41404@d>00<0000B3Pl0510A00L3100B3Pl05Q8C
00<000804@d>010040`=00P41@0?2``0;2PY02DQ8P0I5AH06aLH00<0000B3Pl04@d>00H20`1mNGX0
hMgN02dZ:P070`@03PX;0P0@2P`2014;3@05010:300?2@/03@L9014;3@0=1`T00P0<1PP0100;1@L0
3PP:00h82P0?2@/3010:300300d72@0<1PP030H800803@L900<03PP:010:300@2P`00P0?2@/200h8
2P06014;3@0C3@l04P`>00h82P0?2@/040X<100?2@/0200?2@d040X>018<400F3aH05a0G018;4P0:
0`/02@@90P0>20`0100?2@d040X>010:3P0@2Ph500l93@0800h8300A31003`X>01<>4P0?2Ph020<7
014<400B3A4200X52@0300@00`1ED5@0BdM900D03PX;00`05a<D00H20`0F4Q<00`0000P41@0?2``0
3`T=00T31`0A2`l02`D900l93@0B2a8200l8400=01094@0@21<04@TD014:500300/0514L01<@6@0:
1`h02@L<01@?4`0=1`T040X<010:3P0200h430090148400@2A003PT=00h93@0@2`l03`X>00/62P0>
2@d04PdA00805A0D00h04@`@00d8300R7B405A0D018=4@0;1PX04@`@00l:3P0:1@T04@`@00l:3P0=
20`02PD901<>4QCooooo000Kooooo`0500/84P0<2A<01P<=02PU;`0@3AL00P0<2A<07`0A3QP01`@>
00`94`0X9Bl0SX^D0>o]l@2/ZZl0<Bld01XH7@0?2a0040/?018<400B30l04@/=01<:3@0B2@`04@X<
018=3@0A30`040/;010;300@2Ph040/?03hi?`0B31D0510H00l:4`0>2Q@03PXB00l:3`0?2Ph0100@
2`l2018=4@0401D@500?2Ph04PdA018>3`<04@d<01X04@d>018=4@0B3A404`hD014<4P0?2Q403`TB
010;4`0B3A404`l?018=400A3@h05Q8B01HA500@2`d03`/;018>400A3@h040`<01HB500G4Q<05@lA
01@@4@0C3a005Q8C01@B5@804Q0C00d04Q4F01@C600E51T05QDK01<B600C4QT05QDL018A600C4QT0
4a8J018A6@0C4A/04a4L00<0518M00X05A<N01@F7`0E5b<061dY018I9@0S:cT05Qd[014H8`0@5b40
5QTQ0P0E5ad01`0@4aX05QTQ01HI8@0A51`051LO01HI8@0I72@00P0E6200200F6B405APP01TL900F
6B8051LP01<F7`0H6b@06A`U0P0E624201TL9@0401HI8P0G6R<05QTR01PL9P805QXT02X06QhX01dQ
:`0K7bT06QhX01/O:@0J7RP061`V01TM9`0L82X08bTd01@J9@0W;ST07RD_024X<P0J8BX092/c020W
;P0J8BL05alS01dT:@0E7b80624W01PS:00I92T06bH[01lZ<00R;3@06B@[01dW<@0Q:c@09Blh01LQ
;00M9c80628/01`W<@0N:c@06RHa028`>P0N;3L06bTe028b@00S<d4201l_?P0J028b@@0S<d@09CE6
02<c@`0P<400830o028b?`0[?4L0:CY4020a>@0O<3P0;3e401PY;`0M<2l0838a020b<P0V>3X09STo
028e>`0/?TP093Q303eAG@1KKWd0@eUX02@jA`0[@T/302]2BP80:D1803h0:3m702]2BP0`Adl0:T59
02]2BP0`AU80:T5>02m5D`15FVL0;T=?02m3CP0kCeT0:Ca602Pk@P0V>Cl0:ce302Xk@P0T=S`08SDh
020c>00Z?D808SDj04EEG@0W=Sh0:3Ho02/h@P0S<3/0<Si;03Q4D@0T<CX07R`c01`Z<00M:S407R/a
01hZ;`0M:Bd07RT/01`W:@0G8R@06bDV01/T:00Q;CH0930l01PR;00J8BT06B4T01/P8P0Q8bD0?T92
02<X:00O9B@05QlM01LO800P9BT06AhS02db>00J8BL05A`R01/R:00H8BP05b0W01PQ:0806B@Z01<0
5R4X01@K8@0G7R@05A`R01HM9@0L8b/07RD]01`S;@0I82X06Al[01XP;00F72P06Al[01XM;00G6bP0
3a<N01lS;P0B5ad05a`P00805a`O01h05AXN01HK8@0G6b<061dT01DJ7`0c>3`07b@Y00`A5P0G72@0
6QhY02T]>@0F6BL05aXY010C900c=TP06A`]01HJ9P0M8Bd061`X01<G8P0F6RD05a/W01`P:`0I7BP0
5QXV01PL9`0I7BP05a/V01TK9`0H6RH201LI9@0:01PJ9P0H6RL061XW02@V<`0T9S8061XV014C800B
51l04a@H010A5@8061TM00<08b@X03Hg>`0E5QX00P0D5AT301<D600601DF6P0F5a/05aPL01LH700E
5QX051DI0P0B4aL01@0?41@04Q<G01HG6`0E5QX04Q<G00804a@H0`0D5AT2010A5@0601<D600@4AD0
414E01@D600C4aH04Q8E0P0A41@00`0A4A@04a8F01<C5P0401<C5P0>01<C600E5Q/03@d?01TH4P0P
7Q00>cPW0;2_V`3YimH0^[RY0492>01LGEP06A/J01@D5`0D4QL301@B5@0C01@B4`0F51D06ALH01<B
400?3P`051<A01HE4P0H5QP03P`?018A4@0F5A803@`701`L5P1cLf`0PH5j03hm=`0G5Q806QTD018A
3`02014?4P<04Q0B00T04@l@018@4@0A3a004@l?01@B4P0D4a404A0>01@B4`0A3a800P0I5aX0400>
30l04a4D01PF6@0B41<03P`?00d;3P0E4aH08b4T01@C600C4QL08B0U01LG6P0?3A403P`?00h<3P0?
30d2010<300D014<300@30/06ADF01/I6P0=2``04@l@010>3`0?3@h040h?00h<3@0?3@h04a4B01PF
5`0J61T07ATJ00l;300C3a0040`=014=3P0;1`P2018>3`0=00h:2`091@H06QHG01HB4`0D3a805a<E
01@@4P0>2P`02`L900d92`0A30l03@T;014=3`0201<?4@0I01HB4`1dL6l0_k^j044m?00<20L040`;
01HB4@0S7ah03PX900P40`0E4A00510?00d9200A3@`03PX900l;2P0@30/03`/:00d9200B3Pd020@4
00/71P0E4A003PX901HB4@02014=300400h:2@0=2@P03PX9010<2`D03`/:00`040`<00/71`0C3`l0
3PX:01DA4@0<20P0510@00l;2`0=2@T0510@01<?3`0@30`6010<2`0300h:2@0E4A003`/:00803PX9
00<020D400l;2P0=2@P00P0@30/00`0>2PT040`;01@@3`02010<2`06018>3@0>2PT030P700T51@0A
3@`040`;0P0=2@P7010<2`<03`/:00@03@T800h:2@0B3Pd040`;0P0C3`h00`0D40l061@C01DA4002
00h:2@803`/:0P0@30/02P0>2PT04@d<00d9200=2@P04@d<00h:2@0B3Pl03PX;00`82@0>2P/2014=
3P0800d92P0/:2T05A4B01@@4@0<20T04Ph?01<?400B3Pl200d92P0301@@4@0=2@X040`=00803PX;
01005Q8C01/G600C3a004@d>018>3`0G4a@03PX;010<3@0=2@X0510A01DA4P0^:R/0510A01HB4`0<
20T03`T;0`0@2P`200l92`04018<3P0G4A<04`d?00l92`8040X<0P0>20X00`0?2@/040X<010:3004
010:3004014;3@0B30h04P`>014;3@<040X<0P0?2@/01P0>20X04@/=010:300>20X040X<014;3@@0
3`T;00h03`T=018<40070PD040T@010:400C31<08Q/S01@=500=1`/03PP<00l93@0@2Ph04@/?010:
3PD03`T=00d03@P<010;3`0;1PX03@P<010;3`0<1`/03`X>00d8300@2`l04@`@01PC5`0>2Pd04@`?
00D03PX;0P0:1PL02P0B3Pl030P9018>3`0@30d03`T=01@>4P0C3A402`D900l93@0?20l200l8400H
01094@0@21<04@TD014:500=2AD03``G00/84@0C41L040hC00X52@0?2@/04@/=00h8300B21005`dE
01@<500B2a803`X>010;3`0F4AD050lC00h93@0@2`l050lC0P0F4AD03P0A31003@P<00X52@0@30l0
71LK010;3`0`:bl0KFQ/01`G6`0B3A404@`@018=4@0C3Q803@P<5?ooool001_ooooo00H04@hI00d;
5@0H5B00P7f801hK9P0>2aH200`9500B00@1300@3AP09R<^08^8T@3RgnH0UiFK01<A5P0?3A804a0D
00H11@0@2Ph040X=00l92`0A20/040L:00d72@0A3`d04@d>0P0?2``200l:3P0Q010;4@0B2a802@8:
018;4`0C31@02P<;018=4P0E41@04`hB00h93@0?2Ph04PdA01D@500D3a<03PT=014<400G4QH03@P<
00`8200>2PT040`;01<?400F4AD05a8F01HA5`0A31803`X@010;4P0C3QD04`hB018>3@0A3@`040`;
00805A4@01X03`/:01DA400B3Pd05Q8A01LC4P0A3@`05a8C01D?4@0@30d0510A01dI6P0G5AP04Q0C
01DC5P0B4AH040lD00l>4`0?3Q@040lF01<B6P0D4a/04Q4I01HE7@0D4a/04Q0J01DC7P80518M00h0
5A@L01LE800A4Q`051PQ010F800L92l0>D5>06M`O`0V<3`07RPd01TQ;@0I82X061`U01PK8`8061/T
00d051LP01TL9@0O8R/05APQ01LJ8`0J7BH05QTR018E7P0H6b@06ahW01HI8P0E62406QdV00808RD^
00@061/T020S;00F6B804aHO0P0L7bP0500F6B8061`U01LK900G6b@06alX01XN9`0E6B806AdV01XN
9`0I7BH05a/T01HJ8`0G6b@092/e01hU;`0G7RP06b8/01LN9P0/<c/092/c0P0H7bD0200C6ah07bLZ
02D]<00D7R005b8V01/V:P0L9b/06bH[0P0I92X0:`0W<ST05b4Z02Pb>`0O:C808R`f04UCG@0S;cP0
;3U201l/=@0P;SP07R`g01l]>00F9S<06RXg02@d@`0O;ch05RHe02HfAP0T=4@09CE502<c@P0I:CH0
4R8_04YJI`0C92h08c@n020a>@0L;CD07c0g028d=00N<Bl07S0`02Li>`0W>T008C@j02PjA00P=3l0
:Se;02/nC@0M<T<0:3i<02@kA00W?TH00P0Y@4P0500W?TH09Ca402a3B`0X?dL0:d9:02Y1B@0]A4`0
:3m80357E00U>dP0;dA?0355D00Y?DP0=4M@02`nB00X>d809cU002`mA00V=ch07Rle0P0R=SL0:P0M
<380;T1409^Z/@10CeL0:3Ho034mB@0M:CH0=d=A04eIJ@0W=3l08Rle01`Y;`0I9R`06BLZ01TT:00I
92L07RT[01hX:P0G8B<05b4R01TR9@0N:380@TiJ03]5CP022A404QLK024U9`0=3`h0Bde<01<H500L
8R003Q@B01<L6@0:3a808BHZ01TN900T:c4020lE01HM8`0I8RT0624X01LP9`805b8X00/04adV01LN
9P0I82H051/Q014H800F7BD06B0X01/R;00N9Bl06b4]01TO:`0201hT<00X01TL:`0L82d06alZ0002
3@0J7bD05a`P01lT9`0I7R405AXN01HK8@0F6b804QLM01PM800=4a@041DH01HK7`0D6Ah051PQ028V
<@0G6bP05QTX01`O<01`LhH061//01PL:00I7BP05QXU01PL9`0L82/061`W01XN:@0F6RD051PS01DI
900F6RD05ATT01PJ9`0F62D04aDR014C80803a4N01406A/X018D8@0B52405ALT01LI9P0F62@06Q/O
01`M8@0/;C408b@X00h?4`0@4AD05QLK01<D600A4QH04Q<G01<D600801@E6@0;01<D600@4AD051DI
01TJ7P0H6Ad04a@H010A5@0A4QH05QLK01@E6@0C51P00P0?41@02P0C51P03PlC00h?4`0D5AP04a<E
010@4P0?3a404A4C01@D5P0F5QP501DE5`0Q014A5P0F5a`04A4C01hM5P0P7`d0?S`W0:n]U03oonX0
VIR404a<@00=3PT04aDD01LG6P0D4QL04a4D018@4`0D4QD05A<D018@4@0>30d05A@B01LF500D4a40
4A0=00h<3@0I5aP02`X7020O6`0F5A00?clf0>[Zh03oooH0N7Q`00806QTD00L051<?00d;300?3@h0
4Q0A01@B4`0C4A804@l@00<05A<D00H04a4B014?400@3Pl03@/>02DS9P0W9BP200l=400?00d;3P0@
3Q403`d@018@4`0A3a803`d@01HD5`0M72403PdB00l>4`0?3a404A0C00D3100?3@h040d=00804Ph=
04@050l>01@@3`0:1PL0:RPY00h<3@050`@04Q0A01DC500D4Q<040h?00`:2`0=2``03`d>00h<3@0;
1`P03`/<00`82@0O6a`040`=01<?400=2@X04Ph?010<3@0;1`P061@E00d92P0D41401@42010<3@0B
3Pl0510A01<?400@30d02PH701PD5@0R7Ql04Ph?00T51P0J5QD0:RHU01DA400@30/03PX9010<2`0@
30`05Q8A01LC4P0;1`H06aLF00l;2P0>2PT03@T800h:2@0B3Pd04`l>018>3@0?2`X02PH500`81`0C
3`h020@302`X9`0A3@`040`;00d9200<20L03`/:010<2`D03`/:00T04`l>010<2`0A3@`04Ph=00X6
1@0G4a801`<200d9200B3Pd00P0>2PT0300A3@`040`;010<2`0C3`h04@d<00`81`0=2@P030P701TE
500300005Q8A01LC4P803`/:01P04@d<010<2`0=2@P030P7014=300@30/03@T800l;2P050@005a<B
01<?3P0D40l06ADD00T5100=2@P07ATH00l;2P0A3@`040`;00h:2@0=2@P03PX9014=300=2@P200l;
2P0900d9200?2`X04@d<00d9200@30/03@T800`81`0?2`X02PH500803PX90P0?2`X2010<2`0900/7
1P0A3@`03@T800d9200A3@`02`L600/7200<20T03`/<00804@d>01l03@T:00l;300D41402`L800H2
0`0@30d04@d>08^7R00g<c@040`=00d92P0<20T040`=00H20`0A3@h01`<400X61`0H51D03@T:00H2
0`0?2``040`=01DA4P0>2P/040`=00D10P0H51D02`L8014=3P0=2@X03PX;00803PP:0P0?2@/01P0>
20X03@L901<=3`0I4aD050h@00l92`8040X<0P0>20X0100?2@/040X<010:300@2P`300h82P0300l9
2`0A2`d04@/=00804@/=0P0@2P`300l92`0500/51`0<1PP04@/=00l92`0=1`T0100?2@/03P0?2@d0
4@/?00H0100L5A`0<b`c01XC6P0H4AT04``C00d72`0>20`03`T=010:3P0A2`l040X>1@0?2@d03@0;
1PX04`hB01D@500C3Q8040/?00`72`0B3A400`0201PC5`0V8BD0S8N;020K7`0?2`d01@0>2P/0300=
2@X061@E018>3`0:1PL03PX;00T61P0>20`03`T=00/52@0C3A403`T=00h73P803`P@01H040TA0108
4`0A2A@04@XD00L13`0=2QD04PlH01<@5`081P/03@P<00d72@0>20X03`T=01P>5P0O5Ad04`XB0109
400<1`/03@P<018=4@0@2`l020<7100>2@d2010;3`0900h93@0:1PT04`hB00T42014?d<0[jZ^02LR
9P0>2@d050lC00802`H:00<081/Oooooooooool04_ooool001_ooooo00P03@XC00h;500>2a@08AhW
01LD7@0>2a@04a0I014>5`8040dF02H04a0I01HC701GE5/0@3i401TG700;2@h03`/@014<400C3A40
40X=00d72@0@1`X04`X=01<=3`0O7Ql0GE]L01TG600>30d06QDI00/62P0>20`02P@801hG7P0>10`0
3`D=01H?5P0F4AD02`H:01dH700A310071LK00H11@0A31003`X>00h93@0@2`l04PdA01<>4P<04Ph?
01404PdA01<>4P0C3Q803`X>00h93`0D3aD05a8H01HA5`0C3a40510?00P40`0E4A001@4000l;2P0B
3Pd030P700h:2@0201@@3`0>014=300C3Pl050h@014=3P0F4Q<06ADF01@B5@0B41<05A<F01<B5`0?
3Q<051<H01LF700D4aX501<B6P8061LO01L0>cY205MFGP0F5A/02@P@01/L900=4QP06R0Y01<K9P1^
MX40g>Kb09jW]P15Ce/0:30l02he?`0H7bL03Q8K01PJ9P072AD061XV018D800L7RX0418N018D8002
014C7`804aDQ00@051HQ01@G800D5ah05QTP0`0G6R40>00H6b805aXQ01LJ8@0I72<06QdT01TL8`0G
72806QlU01TN900J7bD07B8X01PM8`0F6b406AhT01`Q9`0E6R00724W01XN9`0E72H072<]01TP:P0D
6b<06b8Z02/b>00E72805ahT01LO8P0F7R405alR01/S9P0M9bT06R@V01dW:@0L9RP05b0T01TR9`0T
;C8082T_01/T:`0J8bX07BH]020Y<P1DGVL092lh01PU;@0R;cP0938k01/Y<P0M:cH08S<m01TZ=00K
:cP08c=001l_?00M;C`07bln0P0U=D@201l_?00301XZ=`0N;cT08C8l00808c@n01008S<j02Tk?00b
A4@09SPh020b=00W>T009STo02<e?`0Q=D009c]602/nC00Q=dD0738o02TmA`0V>T<08cM00P0hC5D0
400R=Sl0;d=<02e1BP0]@DX0:3a501``>@0U>D<0:Ce802/oBP0]@DX0:Si702PjA00U=d4093Ln02Tj
@P0[>d<202@b>`0@02@f>`0O<C<07Bla01l_<`0U=3T0:3Ln02Le?@0S<3T08blk02<^>`0T;C`08b`m
028]>00[>3h08c4d01PT:0806RDY01807bT[01hX:P0O9bT08RX/020X:P0H8B@072H`03I2CP1[M7h0
5QdU010E6@0J7Al06Q`K01XL6@0J7QX06R0L01dS7`0P9R<201/P8`1?01XO8`0G7b80620S01hU:`0I
8RT05QlV03U2B`002Q<06bD^01TS;00J8BT041LM01<J800I82P04QTQ01HM9@0N9Bl06R4[01TO:`0N
930082Hb01PN:P0M82l07B4^01hR;@0E6B@04AHL01LL800B5aX06b0S01/P900O92X04aPO01DJ800E
6Qd04ALG01PM800;41@03a@I00T=5P0M8B`07b8`010C8P0H6b`06A`^03LjB`1AEF007B4Z01@H8@0E
6B807R8[00dA6P0N8R/0720Y014E7P0G6b@04aLP01DI8P0?4Ad071hZ010B7P0A4al05QPT00T;5`0D
5R806A/W00/=6@0?4Ad0O7j:03Hi@P0m?T<02``@034b=P1LGF404Q<G01@E6@0C51P03a0D01XK7`02
01@E6@0:010A5@0C51P020T=02TZ;P092Ph06Q/O018C5`0G61`05AHJ01@E6@<04a@H0P0B4aL04P0E
5QX04Q<G00d>4P0?41@05QLK01/L800E5QX0414E01PI7@0M7R4061PJ01HF600C4aD04Q8D01@D5P0B
4Q@0410B018B50<04a<E02D04A4F018C600D51H04Q4:01XI1`0V90l0AdD/07ekI01AD3`0?d0d01dN
6@0<3Pd061PK00X83@0F51L04a4D00l=400L6Q/04Q0A01@B4`0?3P`03@`:00h=2`0B4@h03`d>014?
400B4@h04Q4=01/J5@0c<bX0Xj>I0=[JcP1GEdd03@d501PH400?3PT04Q4?00804Q0A00<04@l@010>
3`0@3Pl00P0I5aP03@0D4Q<03P`=01TG600@3Q003@/>010>4@0D4QD05A<F01<A500>30l04@lB00P6
2@0>30l00P0A3a804@0[:B`06ATK00/;3@0=3@l01@D7024P8@0;2@X030X;014>3@0C3`h061@A00h9
1P0@30/061@E014?400I5aP04Q0A008030X;00T03@/<00h<3@0100006QPI00h<3@040P<04`l@014=
3P0@30d00P0B3Pl00`0?2``04`l@018>3`02014=3P03018>3`0C3a004Ph?0080510A01/04`l@01@@
4@0E4A804Ph?01XF5`0G4a@07a/L00H20`0C3a005a<B00/71P0810<040`;018>3@0=2@P03PX900d9
200B3Pd03`/:01<?3P0>2PT030P700l;2P0>2PT030P700D1000C3`h00P0A3@`2010<2`803`/:0P0>
2PT0300?2`X040`;014=300F4Q402PH500<0000M6AP02PH501XF5@0:1PD030P700l;2P80510?0140
4@d<00h:2@0B3Pd0510?00d920070`802PH500d9200<20L03@T800l;2P0A3@`04Ph=014=300@30/0
3`/:00h:2@0200l;2P0901@@3`0C3`h03`/:014=300D40l02PL600/71P0B3Pd03PX900805A4@0100
3PX901`H5`0F4Q404Ph=014=300?2`X04`l>010<2`0810<040`;00d9200<20L03@T8010<2`0?2`X0
3PX90P0@30/00`0?2`X03@T800h:2@0200l;2P0@010<2`0A3@`03PX901<?3P0A3@`06ADD00<0000G
4a804@d<00l;2P0>2PT03`/:00d920091@@03@T:00h:2`@040`=01@030P900l;300B3Pl04Ph?00l;
300<20T0;BTZ01lK700?2``02@D600`82@0A3@h03`/<018>3`0>2P/03@T:010<3@0<20T02`L800d9
2P<03`/<00P03PX;01@@4@0<20T03PX;018>3`0?2``03PX;00d72@804P`>0P0>20X03P0?2@/04@/=
01XD5P0F41802P@600h82P0E3a403@L900l92`0=1`T04P`>01<=3`0<1PP04P`>0P0@2P`300l92`06
01<?400=2@X02`L800l;300B3Pl04`l@0`0@30d00`0=2@X02`L800d92P03010<3@0?00d92P0;1PX0
3PT=00T4200?2Q007aXP00P32@0500L04@/B018<400?2@d02`D9014;3`0H4QH02PD800802`D90240
3PP<00d72`0>20`040X>014<400@2`l02@@800`72`0@2`l02`H:01@?4`0@2`l06QDI08n:SP0F4AD0
3@P;00l;300<20T02PH700/7200>2P/05A4B00P41@0F4Q<01P8301lK700<2@T05@lC01@>4P0@2Ph0
3PP<00l93@0B2a800P0C31@04P0B2a<04@TD01084`0?218040XH02dZ=@1FDe`0L6ed01LE6P0C3Q80
1P0201PB500?2@d05@/C00l53@0<10`03PL>00d830803PT=0P0?2Ph01P0;1PX020<7014<400F4AD0
3`X>00L21P803PT=0P0<1`/0200E41@07aXN01PC5`0F4AD04`hB018=4@0A310040/?5?ooool001_o
oooo02H03@XB02LT:`0l>Cl05A8J010=500?3A<040dE00h<4`0=2a403@XB010=500B3aH061DL01HC
6@0<2Pl02`T>014>4P0A31004@/?014;3P0?2@/04PT<01<:3@0A2`d03@/;01PF5`050`@04@h?00h:
300;1`T040/>01TC5P0=1`X040P<01/C6@0=1`/040`?03`g>`804@`@00<02`H:01HA5@0@2`l00P0?
2Ph0100A31004PdA01<>4P0B3Q02018=4005014<400@2`l040/?01<>4P0?2Pl00P0C3Q<01@0?2Pl0
3@T;014=300G4a804@d<008061@C01@04Ph=01<?3P0A3@`04@d<01<?3P0D40l05Q4A01@>400B3Pl0
5a<D01/G600F51L0518E01LE600D4aP040lD01@C600E51X051<J01<B6P@04a8I01l051<I014@5P0I
61d06APN01LG6P0G5Q/0418G024V:`0_=C/0@daD09bT[P3Wl?D0WjRf03<mB@0k@dl0FV5[01`R;00E
6B8071hZ01XL:@0@4Ql06adY028T<00V:3@05ALT01@F8P0E5b<06Q`X01/M:P0H6RH05QTR00805aXQ
00@051LN01<F7@0F6B0061/R0P0G6R40900I72<06QdT01TL8`0D6Ah05AXO01HK800K82D082DZ01TN
8`0O92T06AhS01hS:00J7b@07R<X01DJ800C6R806R4Z01`S;00J8BT06b8Y01lV;00I8BD06R8V01TQ
900G7b80620S01/S9@0M9bP06B<S01hX:@0O:B/06R@U01LQ900L9BT072DZ01`U:`807BH/03807RL]
01lY<@0I9B`08c0h020]=@0S<3T05B</01l]=`0G:3804b@^02<c?`0Y>DH08C4n02HfA00T=4809CE3
028b@00T=440:CU6024a?P0S<cl093A002<d?`0Q<Cd07c0i02@f>P0W>C`0:3Xm02Pj?P0V>Cl09CPn
02Pj@P0K;cL09CU302PlA`0P=T809C]702LjA00Y?4D0:3]402/nB00/?dT0:3]402TlA@0Q=3h093M0
02XmA`0[?TP0:Ce602PlA080:Ce508@09SY202Dg@00X>T809SQ002Hf?P0X=cl09cDn02Tg@00V=Sd0
7Blb01d^<`0P;cD093<i02Le?@0U<S/07b`e020[=P0X<Sh09c4n01lX=P0H8R/082`a01`X;00H92L0
9c8e02D_<@0L9RP06b@V01`T9P0O9RP08BPY01`T9P0H8BT03ALQ01TR:`0N8bP051TL01@E5P0J6aP0
6AXH01TK600F6aP05AXG01@J600E6a/05A/L01DJ7P0C6ah05AdP01XQ9`0C72<07BH]03m8D@0K9Bl0
7BL`01HP:P0M92`061lU01XQ9`0I82P04QTQ01LN9P0a>4809B`f01TO:`0H7RX06Al[01lU<@0_<T40
5aXX01/O:P0A5B00724W01<H700C61/06AhQ010E6@0D6Al051TP01PM8`0?51L06AlP01PM800G7200
3Q<H01<H7P0A5Ah08RHa00X>6`0H6bT030lO01hQ<00J7RT04QHO01LK900M8BX06QhW01LK900F6R<0
61`U01<G800J7RL05QXS01LK900N8BX04A<M01LJ8P0B5Ah0828]018E7@0E5b4061XU010C6`0M82T0
JFaf04a?E`0F5a/071dQ01@E6@0E5QX07AhR00l@500B4aL06AXN010A5@0C51P04Q<G01DF6P0c=3P0
4a@H00/<400K720201DF6P<04A8F02h04a@H01DF6P0F5a/04a@H014B5P0D5AT04Q<G00h?4`0@4AD0
4a@H01DF6P0C51P04A8F01DF6P0G61/051@E018B4`0A4A804Q8C01@D5@0G5aP05ADF01<C500D51D0
5ADF01@D5@0C4aL051DI01DE5`0D4Pd04a4401HC0P0J5`<0<BhL01/J2P0L6a<0414<00h@3`0E5AP0
6ALL03@b=@0U8bH02`T<01PF5`0C4A804Q0A0`0C4Q005P0D4a004a4B01DC500D4a004A0<018A300F
5Pd0820G03Ph;@0K6a405QH>00`<1@0H5a<04Q4=018A3P0B41004A0?014?3`0@3Pl04Q0A01DC500A
3a4200d;3@0301@B5P0@3Q403`d@00803`d@02P040hA018@4`0F51L04a4D014?4P0?3A0040hA01TG
6P0B4Q@04A4C010@4@0A4A808B0Q01LE5@0G5Q@040h<00`81P0D40d03`/801<?300@30d05A<D00l=
3P0A3a003@/<01@B4`0B41403P`=014?400:20T03`d>00d;300@30d03`/<010<3@0A3@h04Ph?010<
3@0C3a004Ph?0P0A3@h00`0B3Pl04`l@00d92@02010<300400l;2`0A3@d04Ph>010<30803`/;00T0
5A4A07=_K`0F4Q8030P701TE500@30/02`L6014=300C3`h00P0@30/02`0D40l040`;01<?3P0;1`H0
510?00l;2P091@@04`l>00d9200?2`X040`;00<03`/:1@0>2PT0300?2`X040`;01DA400?30/081`K
01HC4P0:1PD071PG01LC4P0F4Q004@d;00l;2@8040`:00T04`l=00h:200:1P@06ADC028N700H5180
3@T800l;2P0@30/00`0?2`X00`0@30/03`/:00h:2@0200h:2@803`/:01@06QHE01HB4P0=2@P040`;
01<?3P0>2PT02`L600h:2P0L61L02@H500l;2`0A3@`03PX900l;2P0A3@`03`/:018>3@0H51<03`/:
00d9208030P700@040`;018>3@0A3@`03`/:0P0@30/00`0?2`X040`;010<2`04010<2`0601<?3P0<
20L03@T801`H5`0d<2l040`<0P0?2`X01P0B3Pd0510?01DA400C3`h03@T:00l;30<040`=00<03`/<
010<3@0@30d00P0>2P/2010<3@0>00`82@0?2``04Ph?014=3P0?2``03@T:00h:2`0A3@h030P900d9
2P0B3Pl03`/<014=3P0?2``200d92P0Q010<3@0C3a004@d>00`82@0B3Pl04`l@00`82@0:1PL04@/=
01<=3`0B30h040X<014;3@0B30h03`T;00d72@0?2@/04P`>010:300=1`T03PP:00l92`0;1@L03PP:
018<3P0@2P`04@/=00/51`0:10H04P`>01hH6P0T7R004Ph?00804@h?01L040d>00h;300>2``03@X;
010=3P0C41404Pl@00l<3@0>2``03``=018?400C41404@h?00h:3P0>2`h04`lC00l;4@0:1``05A4G
01<?5P0?2Q003`T=00X4200300l93@0:010:3P0=1`/03PP<018<400>20`03@L;014;3`0?2Ph040/?
01@?4`803`X>00L03PT=00T4200A31004@d@00H21@0=2@`03`/=00803`/<00l04Ph?01DA4P0I5AH0
4`l@00X61`0<2@T05A4B00T51P0@30d04P`@014;3`0?2@d03PP<00l93@0B2a800P0?21004P0@2A40
4@TD018:5@0C31H0?3I403llA`0V8b`08b0W00X83@0>2Pd0<B/]038/;P0@2Ph04@L?01063P0F3AD0
40T@00l:3P8040/?0P0A31002@0@2`l04@`@01D@500B3A403@P<010;3`0>2@d04@`@010;3`0200d8
300400l:3P0C3Q804PdA010;3`<03`X>5?ooool001_ooooo02L01P@900h<400K6A`00@0400L52@04
0PD03@/@00d;3`0;2@`030X?00d;3`0>314040dD01<@5P0B41D040hC00h:3`0:1@T03`T=010:3@0A
2`d04`X=0189300?2@/03``=00/7200D41403`/<00P41@0L61T03`/<01dG6@0D3Q003`T;01LA4`0>
20X09b8V0<:m`@12?D400P0D3a<01@0E41@040/?010;3`0@2`l04@`@00<04PdA02@04@`@010;3`0?
2Ph03PT=00d8300B3A403PT=014<400B3A404@`@01LC500:1PD06ADF01DA4@0F4Q404`l@01<?3`0?
2`X04@d>01DA4@0D40l03`/<00h92P0?2@/03PX;01<?400F4Q<04a4D018@4`0E4aH04a8G014@5@0E
51T05QDK01<B600B4AL201<B600J01<B5`0D4aP040lD00l?4@0>3Q0051@D00D51@0<30`0:2PY01hR
9@0I7B405A`R02D^=@1YLg`0AU1J01dW<@0?5b4061`W01TM9P0J7BH0418O02X/>@0N82d0008?04i@
G@1ADf0201`N:`0501XL:@0E5b@05ALT01PJ9P0H6b@00P0I72<201<F7@0701XM900H6b805aXQ01HI
800H6b806A`S01LJ800201`Q9@0801/P900T:Bd0:Rlc024V:P0O92P051TM01HK7`0@5AT201DJ7P07
01HM8`0H7bL06R4Y01/R:P0I82H05A`R01PP8`0201TQ900Q01LO8@0H82806b<U02@^;@0H8R405R0O
01XT9@0N:2T08bd^01/U9`0K9BP072DZ01dV:`0N9b`07bP]01hY;`0V<ST0;3U101h[<`0/>T808S0i
02<a>P0P<C/06BXd01X[=@0L;3T06RXg01h^>`0Q<Ch093A102De@P0`@4d0?4aI00<093A100/08c=0
024a?P0P<C/0:S]201`]=00V=ch09SLo01T/<P0J;C<08SDl020d>`02028f?@0501lf?00P=cd0:C]5
02TkA@0]?dT00P0W>D<00`0`@T`0?U1J02i0BP0202PjA00402doB@0Q=3d093Po02@h?`<09CPo00/0
;3i602/lA00U<c`09C<l02<a>P0Q;cP08S0i01l`=`0R<3T08S4h024`=`0202@a>P0<01l/=@0N:380
7BLa01hX<P0N9S<06B<[018M8@0I92P08B`_020[;@0S;Bl07BHX0P0G7b402@0I82406R0P01TP8@0B
6b009c8h01/S:@0A5QT041@E01/M700201LG5@0j01LI5P0E6AP051PI018H600@5QH04ALG01<H6`0A
6A`04QXM01LN900M9Rd04a`S00`E7P0G8B/0628/01HP:`0K8RX06b8X01hU:`0H7bL04QTQ01XQ:@0_
=T008bXd01PN:P0G7BT05Q`X028X=00P8c805APV01HJ9@0S9c8061dS00dB5P0I7R4041DH01/P900H
7B<0=S]20:jc^@0f>cl01PX>01<H700Q9RX082DZ01LL8P0N8R/0ADUC00dA700J7RT061`X00/?6`0A
5Ah06QhW014E7P0H72D03Q8K01/O:0806QhW02<04aLP01XN9`0F6R<05a`R01TL8`0E61h061/P020S
:@0B5A`04QDJ010C6@0O8RT082<X01`O9@0E61l04QDJ00l@500E5QX071dQ02DV:P0A4QH06AXN01@E
6@0000@07AhR010A5@0S92P08R<W0493A`0K720051DI01PI7@0720`0414E018C5`0201<D600901HG
6`0H6Ad06AXN01<D600A4QH051DI018C5`0?41@04Q<G0080414E00D04A8F01<D600C51P04a@F01<C
4`03018B4P0501<C4`0F5QH04a<C00h>3P0@41000P0C4a<0500?41<030dA00d=3`0E4a805a@?01PC
3@0J5P`07QXA01TF3`0E51003`l=014C400C4a@040hC01PF6@0D4QD03`d@01DC500B41404a4B0`0B
4@l03@0B4@h04a4B01<A500D4a805aHB01DD3`0=3@H05QH>024Q5`0I6A0040l:00l>2@0C4Ph00P0A
40`3014@3P0a014?400@3Pl04Q0A00h<3`0E4aH06ALJ04I4B@0@3Q403`d@00h<3`0?3A0040hA01<A
500@3Q40518E014?4P0@3Q405Q@G00l=400@41805aLH00d=3@0?3`l030`;00/:200B4@l04Pl=01PD
4@0U8Ah061<@00h:1`0<20L01@<401@B4`0d<S<05A<D01TG600>30d02@L801@B4`0C4A804@l@00L5
1P0B3Pl04@d>01<?400E4A805a<D01DA4P02018>3`8040`=0P0B3Pl07P0>2PT04@d<018>3@0B3Pd0
510?01HB4@0810<0510?01LC4P0L61L02`L601<?3P0H51<01P8101XF5@0T81l0CDU801@@3`0<20L0
3`/:018>3@0A3@`05A4@00/71P0?2`X0:2@S01HB4@0<20L040`;01`H5`<03`/:00@03PX900d9200=
2@P03PX90`0=2@P200h:2@0:010<2`11?C`071PG01@@3`0C3`h06ADC02@P7@0I5A8040`900d91P80
3PX700H040`901DA3P0G4a004`l<00l;200?2`T2010<2`0400l;2P0>2PT03PX900h:2@<03@T80240
3PX900l;2P091PD08AdL09VEU010?3/061@C01@@3`0A3@`03@T800`8200F4Q401P81014=300=2@P0
30P7014=300D40l04@d<018>3@0?2`X03PX900d9200F4Q405A4@01XF5@0E4A004`l>010<2`0?2`X0
40`;00l;2P0>2PT00P0=2@P00`0<20L02`L600/71P0200`81`0700X61@0D40l0?CTh01LC4P0?2`X0
3PX900l;2P02014=300300h:2@0>2P/03`/<00<040`=00<03PX;010<3@0?2``00P0>2P/0200?2``0
40`=00h:2`0=2@X030P900d92P0?2``040`=0P0H51D01P0?2``03@T:00l;300<20T04Ph?010<3@80
3PX;01L040`=01<?400C3a0040`=01DA4P0D41403@T:00`82@0B30h040X<00l92`0@2P`04@/=01<=
3`0B30h07ALI01TC5@0;1@L02P@6010:300A2`d04P`>00l92`0200/51`0@00`6200A2`d04P`>018<
3P0A2`d03PP:00/7200:1`P03P`=00l=3P0>30d040h?014?400Z:2T071XK018@4@802`T:00l030X;
00d;300A3a00518C018@4@0?3A0030X=00<110071@X04Q0E00H42@081@`091lU01H@50080PH00P0D
3Q801@0500<04@/?00`62P0<1PX03`T=00803@L;00d02PH9018=4@0F4AD01`<600`72`0C3Q804PdA
01TD600H4aL02PH902<N8P0C3Q802`L900803`/<00H03PX;00l;300A3@h00`0000`82@0?2``200P4
1@0300`82@0>20`03@L;00803@L;01H03PP<014:4@0<1@d03@H>00l8400A2A@04PXE01<<5`0:1180
:2D`02dZ<`081@`01@<800d8300[9BL0;RPZ018<400E2a<03P@<01494@0>1`h03@P<0P0>2@d200l:
3P0800X52@0=20`04@`@00h93@0:1@T040/?00X52@0=20`200l:3P0400h93@0=20`04@`@014<4080
40/?00<04@`@018=4Oooool04oooool001_ooooo00H02@L900l=3P0:20T04Q0B00h<3@0D4Q<200h<
3P0>00h<3@0=2`d03@/=00d;3P0>31402`T?00/93P0<2Pl03@T>014<400@2Ph040X=014;3@0C2Pd2
01893005014;3`0?2@/050h@014<3@091@H00P0B3Pl03`0G4a80;b/Z018>3@0<20L06aLG018=400W
8RH050lC018=4@0@2`l04PhA010;3`0A31004PdA01<>4P02018=4@08018=4`0A31804@`B010;4@0?
2Ph03PT=01HA5@0A310201<>4P0E014=3P0C3a40510B01<>4P0N6Qd05Q8D01<>4P0B3A0040/>010;
3`0D3a805Q4D01D@500C3Q004`d?01@@4@0F4Q<061@E01HD5`0C4A@04Q0C00804Q4F00<05aHK01PG
7@0D4aT00P0B4AH03`0C4aH051@F01DE5`0E5AH06QXI00/;2P0F5Q<05aLC024R7P0h>CH061/I010D
5@0G7B0051dQ01XS:P0201XS;00B01DL9@0@51h061/S01/K900F62D08bDd01DG9@0P8S40=3I503/m
C00@4R405QPW01/M;00G6BP06ad/030b@00G6R405aXO0P0H6b001@0I72407b8W01PK800G6Ql05QTN
008061/P01@05QTN01/P900L8B@0724T01lT9`0R9bX06b0S01TN8@0O92L0;C8e028W:P0K82<07R<W
01`S:@0H7bL05QdU01LN900H7bD05alR01@L7`805alQ00/05QhP01TQ8`0L92D07bPV01TR800J8b80
6b@S01PQ8@0J8R@08b/]020X:P0201`T9`0E01lW:P0R:bl07BL^020/<P0N:c407R/c028`>00H9bh0
82hg01TZ<P0S=3`0>4UC03E6D00Y>T@07c0j020a>`0Q<S`072`i01h^>`0U=D808S8o00808c=002X0
93A302DeA00U=D<0<dA@020a?00X>D80:CY4024d?00U>3l08cHl02]0A@0S>3`093Tm02@l?`0K<cH0
9cY2028d?P0Y>dD0:Sa602Hh@P0/?TP0:ce702Dg@@0X>T@0:Sa602doB@0Q=3/08C@j02<f?00U>3h0
9cY002Tj@@0X>D008C8j024_>00V<c`08Bhg01dZ<`0O;CL09C<m02Le@00T<S`2020]=P0H020[=@0U
;cP0:C<l02</=@0J8b/07BH`04E?E@0]>3`04ahP01dW:@0G8B<06bDV01`U9P0L92H07R@T01`R8P0I
7al061lP01<M7P0?6A/05AhO01PM700J7Q`06AXH0P0I6AL0E@0I6QX05aXK01LK7@0G6al04aTI01DK
6`0G7Ad05AdO01DM800H7bD05b0W01`U;00I8B/07BLc01LQ;@0K9C005ahV01TP9P0J8BL05ahV01@K
8`0K8RX06R4[01TP:P0F72P06Al[01dS;`0I7b/05QTX01HI9`0M8B`0HfMb03XoA@0D6Ad04AHI01PM
8@0J7b<04aPN02L[<`1lP8T0JFid01PM8`0[<3H061dS01DJ80083A<05a`R01LL8`0>4aX06alX00dA
6P0S9bl03a@K01LL8P0?51X061dS01DJ800H7B<09BX`01lT:P0B5ad05Q/Q01<H7P0G72405QTM01XM
8@0G6ah0F5aO01TL800@51L05ATM01@G6`0?4aH041@H00lB5P0I7B004a@H02DV:P092Ph0@45501<D
600E5QX0:BX^08Z;S`0W:2`00`0B4aL00`0L7B4061TM0452AP0201XK7`0301DF6P0D5AT04a@H0080
4A8F0P0B4aL0400D5AT04A8F01@E6@0B4aL04A8F01@E6@0B4aL04A8F01@E6@0E5QX04a@H01HF600I
6AT061PH01LG5`0E5AD201@D500C018B4P0@41004A4A01DE5@0F5QH06a/M01HG6`0C4QL05Q<H01<>
4P0E3a<06aDH01D?4P0I5AH04a8B01LG5@0B510051@D018@5@02018@4`0D01<A500E4a@05A<D01<A
4P0A40h04a8@01HE4`0L6aP04@lB00l=4@0?3@l04a8?01@C3P0?3`T03`l801<C2`0E50h04A0<00l>
2P0G5Q@3014@30804A0>01@04Q0A010>3`0D4Q<04@lB014?500@3Q<0;2X_00l=400A3a805A<F01HD
5`0D4QD04@lB00h<3`0D4QD04a4D010>4@0F51L03P`?00P820803`l?01X0410@018A400D4a403@`8
00l=2@0F4Pl08b0K01PD400B3P/04@d<02@R8`0C4A807A/L01@B4`0>30d04a4B02LU9P0;2@X05A<D
00P61`0F51D040`=00l;300@30d04Ph?01<?40804Ph?00H04@d>010<3@0@30d04@d>018>3`0@30/2
01<?3P08018>3@0D40l05A4@014>3@0B3Pd02`L603@`;`0<20L2010<2`0A018>3@0E4A00E51?04]7
AP0=2@P03`/:018>3@0@30/03`/:01@@3`070`8040`;00d:2@0;1`L09b<R01XF5@0;1`L00P0A3@`2
010<2`803`/:00d040`;00l;2P0>2PT03PX900l;2P0A3@`05a<B02@P7`0L61L08alN00h:2@0B3P`0
40`900803PX700T04@d:018>2`0@30T040`9018>2`0?2`P02`L400`81@0?2`T00P0>2PT0100?2`X0
40`;010<2`0?2`X200h:2@803`/:02004@d<01DA40060`80;b/Z01HB4P0@30/04@d<01`H5`050@00
8QhM04]7AP0E4A003@T800l;2P0=2@P04@d<018>3@0>2PT03@T800/71P0C3`h03PX901HB4@0A3@d0
4@d<01LC4P0D40l03`/:00d9200>2PT03@T8014=308040`;0P0?2`X03P0>2PT01P<201XF5@0Q7A`0
6ADD00H20@0?2`X03PX900d9200?2`X04@d<018>3@0@30/03`/<0`0@30d0100?2``03PX;00d92P0?
2``2018>3`0500l;300=2@X04@d>00l;300=2@X00P0<20T00`0=2@X030P900l;300200/7200300l;
300<20T040`=00<04@d>00@040`=00h:2`0A3@h03@T:0P0?2``01@0<20T03`/<014;3@0>20X03@L9
00<040X<00H03PP:018<3P0B30h03`T;014;3@0D3Q02014;3@0;01@>400C3@l040X<010:300=1`T0
4@/=01@>400E3a404@/=00h:2`0>2``00P0;2@X01@0<2P/03P`=00l=3P0A3a0030X;00802PP902P0
3P`=00d;300<2P/03P`=014?400@3Pl03`d@00d;3P0B41<04@lD00T7300A3a@04a0G01`G7@0;1PT0
3PP<00l93@0J51P02`D901PB5P0D3Q803`T=00h8300=1`/04@/?02LR9P0G4QH01`<601dH700D3a<0
2@@8010;3`1aK70091lS00d9300B3A4050lC01@@4P0>2P/03@T:0`0<20T01P0D414040`=010<3@0A
3@h0Ddm@01<?40803@L;0`0>20`0100@2A003`P@01094@0@2A4201084`0?01094`0H4R002`PC00h;
500=2Q4061HK00/62P0;1PL0618D010:3P0E2a<02`4901H>5P0?20l03PT=00803`X>0P0@2`l0300A
31003`X>018=4@0B3A4030L;00d8300B3A403`X>00`72`0>2@d04@`@018=4@803PT=0P0=20`00`0?
2Ph040/?ooooo`0Cooooo`006oooool0100<2`T03Pd;018A3`0>3@/200l>30<03Pd;02<03@`:00`;
2@0;2@X04Q0E00h<4P0A3a@040hC00/7300>2@d04P`@010:3@0>20X04@P;01<:3@0D2`h05@`A0148
2`0C2Pd05Q0B010:300F41804@d<014@3P0O7Q`04A0>010?2`0E51803PX<018=4@0<1`/04`hB00h9
3@03008040/?018=4@0201<>4P804PdA0`0B3A<05P0A31804@`@014<400G4QH040/?014<400A3@h0
40`=01<?4@0Q72804@`B07A_M@0i=3X06A@J01LB600C3Q@04@`B018=4`0E41H05Q4G01D?4P0C3@l3
01@@4@804Q0C03805A<F01@C600B4AH05A@I01DD6P0B4AH04A4C018B500C4aD051@D01DE5@0H61H0
6a`G01PI500D5@l05aP@01PI4`0D5A005aTF01@G5@0:3a8041PK01TP9P0=51`04aXR01TM9P0F6B80
5ADM00l?600G6BH02``N01dN<00>3b40;c1202d^@00F5bT061T[01LH:P0B4bD04a@V01/L;00H6b80
5APM01@G700J7B8071lT01XM8P0I72405aXO01HI7P805aXO00H05APM01<H6`0H7Qh06AlO01HL700I
7al301LM7@0_02D[:`0J82004QPH01LL7`0K8RP06R4W01LN900F7B<0620T01XR9@0I8B@06R8U01PP
8P0F7R005QlO01PQ800F7a`06B8O01dV8`0L9B807BHT02H_;P0O9bT07BDW01`T9P0L92L082P[024[
;@0M9Rd08Rhd02@a=`0hAD/08c4g01`[<P0Y=d006b`d024b>P0/?DL0834k01<T;P0M;SP06R/e01d^
>00N;cT07bll02@d@@0Q<Ch00P0Q<D004@0S<d8093A302DeA00U=D@07bln028b?`0S=3l08S@n02Lj
@@0aA4X0734d01ld=@0Y?ch09clo02Hn@00W>T809SQ20080:3Y400@09CM102@f@00V>4809CM10P0Y
>dD0:`0S=Cl08C@k020c=`0R=CT09CLl02@e?00S=3/07Rhf01/Y<P0N;3D08c0i01h[=00M:S<07R/g
020^>`0T<Sl08c0k01dY=@0M:S<07BTb028/=@0Z<c`092dd01TR9`0J8bX0;3Hj018M7`0@6Q`06bDW
01LQ8`0M9BL04a/M01XR900O9BD07R@S01TO7@0H81h07RPW01<M700K92806QhM00lD400I6AH00P0E
5A<0500H61T07AhR02@U:P0Y;3406AlO01XP7P0L8R80620R01LO8@0I82H07RL^01/T:`0K8bh08R`h
02La?@0D7B/06B0X01TP9P0H7bD05ahV0P0H7bL07P0>5Al05ahX01DK9`0P9S80=3Y602H/>00Q93<0
720]00lC7P0P92l05a`R02<X;00A5QT06QlR00P=4@0=4QP06AhU01lS;00X;3D05a/T01<G800?4a`0
5a/S01XO9@0B5ad07B8X010E6@0<4AL07B8W018G7@805Q/Q02d05a`R01<H7P0H7B<0314G01hS:@0J
7bD03a@J01HK8@0D6Al06AhR01<G6P0H71d020`=01<G60072``06AdN01@H6@0F6Q/04ADF00hB4`0F
6Q/01@T:020Q9@0000@07QlS00d>4P0J6al020T=01lP901nOh<05AHJ01lP900C51P02P/?01dN8P0_
<3@0][Nk038c=`0000@06a`P01PI7@0F5a/05AHJ01@E6@0C51P00P0D5AT01P0A4QH04a@H018C5`0B
4aL051DI01<D608051DI00<04a@H018C5`0B4aD00`0B4Q83010@400g01@D500G5aL051@D014A4@0D
51@05QLG010A4`0A41D05Q<K01<=6@0J4Ql08a/X01D=600I51/040hB01XJ60082PD03Ph=01HD6@0G
5AP0518E00h<3`0=2``0518C018@4@0B4@l04a8@01HE4`0J6AH05A<H01@B5`0C4A<051<A01@C3`0C
4Pd05aHA01TH4`0T8al0:RTW00h=2`0C4A4040l;010?2P0A40`04A0>018A3`0B4A001@<400`:3@0C
4A@04Q0E01<A5P0<2Q0040hA018@4`0201HD5`0301<A500>30l04@lB00805A<F0P0@3Q406P0A3a80
61PH010@400H61P03@d;01@C4@0>3@/04Q4=00l=2@0=2@H05A8=014=2@0G4a0030P7020N7`0>30d0
20H701LE5P0E4a@081hO03@b<`0?3@h04@l@01DC500?3@h04`l@0P0B3Pl01@0C3a00510A018>3`0A
3@h040`=00803`/<00D040`=014=3P0A3@/04Ph;014=2P0200l;200I010<2@0;1`D01@4001<?3008
10<0510=01LC400:1PH06aLF014=300i=C@05A4@00l;2P0B3Pd04`l>00h:2@0@30/06QHE00d9200@
30/04`l>00l;2P0>2PT0100000/71P02010<2`803`/:0P0>2PT0400B3Pd04@d<010<2`0?2`X040`;
014=30030000510?020L6`0400006aLF01DA3`0C40/04@h9018?2P0A3PT200l<1`0700d:1@0:1`80
3P/6018?2P0A3PT03`/9010<2`0300l;2P0E00h:2@0?2`X03`/:00l;2P0@30/04@d<01<?3P0E4A00
5Q8A00<0000D40l02`L600h:2@0;1`H05a<B00h:2@0B3Pd04`l>00d9200@30/03PX9008040`;0P0=
2@P02@0A3@`0510?01<?3P17@d80@3`k014=300N6QT06QHE01<?3P03014=30<03@T80`0>2PT01P0C
3`h0100000l;2P0W8b804`l>00/71P803`/:00D040`;01<?3P0D40l04@d<00l;3003010<3@0400l;
300=2@X03PX;00l;308040`=00@03`/<00h:2`0;1`P03@T:0P0@30d0200=2@X02`L8018>3`0F4Q<0
4Ph?010<3@0?2``02@D60P0@30d400h:2`804Ph?01@05a<D01DA4P0D41405a<D010:300>20X03`T;
018<3P0@2P`03@L901<=3`0=1`T030H800l92`0>20X03@L901<=3`080P@030H8014;3@803PP:00<0
4P`>00l92`0=1`T00P0<1PP02`0;1`P04a0A00/92P0=2``04Q0A00d;30071@H02PP900d;300>30d0
3`d>008030X;100=2``06@0>30l030X=00X82`0:20d04a4F020N8`0J5ah02PH<00P21P0k=CT040X>
00/52@0<1PX040X>00`62P0:10P03`T=01@>4P0L5QX0@Se102XU:@080`L06A@H00l:3P0:1@T00P0?
2Ph01`0G4QH040`?024L800300804`hA00d92P0?2``00`0@30d01P04004030P900l;30030000:RHW
00l;30@03`T=00<03PP<00h73P0?21000P0?210200l74P0?00l84P0:11800`0;00l<5@0?31<05A<H
014<40080P@04P`>00/52@0E2a<02`4901P@600@2A003`X>008040/?0P0A3100200?2Ph03@P<00`7
2`0:1@T03@P<01TD600H4aL04PdA0P0=20`0100>2@d03@P<01<>4P0B3A42014<40804PdA5?ooool0
01_ooooo00H06APF00@30P0@3`d00@0001DD4P061@<400d<2P0M00/:200:20T02`T>00/93P0D4QD0
518G00`9300=20`04PdA010:3@0=1`T03PP:014;3@0C3@l04P`>01H@4P0D3Q003@P900/51`0P71d0
3@T800l>30071P@03P`<01DE4`0920H02PP:024L800>2@d00P0B3A402`0I51P040/?018=4@0C3Q80
50lC018=4@0A31004PdA018=4`0B3A404PdB00804`hB01H04@`@00`72`0?2Ph04@d>018>3`0D3a80
71XM02XU:@3WiNL0IfEX01LB5P0B3Q803`d@01<>4P0E4AD04Q0C010;3`0A31005a8F01PC5`0H51P0
5A<F0P0E4aP09@0G5AX05QDJ01<B5`0C4QL04Q4G010?4`0@4Q404Q8B01<D4`0C5A@051HC01PJ5`07
2@@04aD@01@F400E6140=CPa02X]9`092`H06A`I02/_<00T:Bd051XQ00lC700L82T04aLQ018E7P0S
8b/07AdV01LI9P0K72h04Q<U01hO<@0R8cD05QLY01dN<00J6bd00P0H6RT0A@0F62D04A<P01TL8@0D
61/051HJ01XN8@0L82<051PK01TM800G6ah05ATL01HJ7@0G6ah051PK018G6`0J7b<07B8V01LL800K
82<07B8U02ld=`0M8RD07R<V01DJ7@0H7B008RX]01PO9@0J8RP06B8W01PO9@0H82D06R@V01hU:`0M
9RT06B<U01HN8@0E7R005QhP01PQ800G81l0624P01TR8@0Y<C80@TY<01PP8`0J8RD07BDX01hU:`0P
9bd082T^01`W:`0R;S<082ha03]8CP0L:S007bhe01TX;`0O<3L08S<k020a>@0S=3`0:CY202Hg?`0O
<3P0834i028c?00S=3h09cM4028b?`02024a@00l028b@@0S<d<08c=302@d@`0U=D@09SI302@d@@0T
=T809cU305U/M00S>3d0:Ci102a1@`0P=CH09S/n02XnAP0_@D/0:cm802PkA@0V>4808SHo028e?`0R
=3h09SU202Di@P0M;cT08SDk020d=@0R=CT093Lk024b>@0N;cH072/c01d[=00P;SL08Blj01TW<P0K
9c<06RPd01/Y=P0Q;cX08Bhi01`Y<P0M:S<07b/c01lZ<00O:2l0624U01@N800G8B806RDU01<O7`0Y
<c@07BLX01HP8@0/=SL06b@U01@L7P0I8B<06B8Q0P0E7Qd0@P0N9bH072HU00`E4P0A5aD061dI01<E
4P0I6aP05aTH01<D5P0A5AP051LL01TM8P0H82806R<R01`T9P0H8R@05b4S01PQ9`0B6b@0628[01hW
=00;52<05Ql^01dV=P0L9Bh06b@Y01PP:00H7bL0624X01HN9P0I82X08BXc018I9@0F72P0;3@o01TO
:`0T:3@051PT01PL9`0@51d05Q/P01@I7@0<4A@05AXM01LL800M8RP04QLM014F700@51d092T`0005
2`0D624051TO014F700I7R@04QLL020U:@0E6Qh061dQ01DJ7P0H7B<051TO01LL8P0>4aT082D[01PM
8`8051TO02@03a@J01LL8P0F6b406QlS01DI700B5QL082@U00lC500D61T05ATJ00lC500D61T04ADF
01LK700f>S/0720Q010A4`0G61`030d?01<D5`0=3Q8051DG01@E600E5QX07QlQ00/<3`0D5AT06a`P
00l@500P8BD0:BX^01HG6`0N7b<02``@01@E6@0B4aL4014B5P0401@E6@0A4QH04a@H018C5`804a@H
00<04Q<G01DF6P0D5AT00P0A4QH00`0C51D051@D01DE5@0301HF5P0I018B4P0D51@061PH01<C4`0<
30`03`l?01<C500>3a404A0E01HD6`0?2AD050hJ01lI9@0C3AL061<J018A4`0Q8Al02P`701HF5@0F
51T03P`?014?4P0E4aH04Q0A01DC500201<B400=014@3P0?3P`03Pd:00h<3`0?3A004@lA014?400A
40h040l=00H50@0G5Q807QdJ02@S8@0200l>308040l;03404A0=014@3P0B4@l04Q4@01DC500I5aX0
6QPK01LE600M6b003@/@010?500A4A<04a<E01<A500@3Q4030X=010>4@0B41<05A<E010>4@0?3@h0
5Q@E01PF5`0820P05ADE00H6100B4Q0020L501<B3P0C4@d04@d:01HB3`0?30P05A4>01`H5`071@D0
61LE01TG600@3`d03`h<00h:2@0G51<04Ph=01lK6P0m>CP03`/:010<3@0?2``03PX;00803`/<00<0
3@T:014=3P0@30d00P0?2``0800@30d04@d<01<?2`0D40d04Ph;010<2@0?2`P040`901@@3@0E4@h0
3`/801LC400>2PL030P501DA400810<0510?00d:2@0;1`H05Q8A00h:2@0@30/03@T801@@3`0S7ah0
5a<B00d9200C3`h04Ph=00l;2P0<20L07a/J0P0?2`X200h:2@803@T800<04`l>018>3@0A3@`00P0@
30/06@0C3`h06ADD00@0000b;Rd0510?00L30P0?2`T02`P300/60`0>2PH040d8014<2@0>2PH03P/6
018=2P0?2`L02`P300h91P0A3@X04Ph=014=300?2`X03@T800`81`0>2PT00P0?2`X07P0A3@`04Ph=
01@@3`0C3`h04@d<00d9200?2`X07ATH00T51@0;1`H05Q8A018>3@0?2`X030P700l;2P0C3`h040`;
018>3@0C3`h040`;018>3@060P40510?00P40`0K5aH040`;00/71`0I5A@05A4@00h:2@<02`L60P0@
30/0400A3@`04Ph=018>3@0C3`h06aLD00L3000H5140510=00T50P0B3Pd04`l>014=300@30d04@d>
00l;300;1`P4010<3@0400h:2`0=2@X040`=00l;30803PX;06d03`/<010<3@0B3Pl040`=00h:2`0=
2@X03`/<014=3P070`@03PX;010<3@0A3@h04`l@00d92P0B3Pl03`X=00/7200;1PX03@T;00l;300=
20`040`>01PD5@0F4Q@04PdA01DA4P0A2`d03`T;014;3@0D3Q004@/=00`82@0<1PP050h@014;3@0;
1@L05Q0B020J700S7Ql03`T;00h:2`0C3Q004@/=010<3@0?2P`04P`>018>3`0D3a004`d?014=3P0A
3Pl02`T:010>3`0H5QL040h?00L51P0=2``02PP900T7200;2@X03@/<010>3`0?3@h03@/<00`:2`0=
2``03P`?010>4@0G5AP02@L<034_=02HUY/0L6ed00l:4@0R6b80KFI]024J8@080PH040X>01@>4P0@
2Ph03@L;00h8300=1`T040X>018=400?2``03`X>00h9300A3@h04PdA01@@4P0=2@X00`02018?4003
00005Q4E00X6200?2``040/>010;3`0?2``03PX<018=4@0G4a@04`lA00d8300:1PL040/?00@040X>
00@03`T=00d63@0>1`h03PL>0P0?2100400@2A4040TB010=600=2QD03P/C00P5300A3a@03PT>00`7
2`0C3Q803@L<01TB6@0<1@`040T@00d83P0=20`200h93@803`X>00T03@P<00l:3P0>2@d02`H:01HA
5@0^:Bd05A0D010;3`0=20`00P0?2Ph00`0<1`/04@`@010;3`0300h93@0300l:3_oooooooooo01;o
oooo000Kooooo`0300d;30091`P03P`=00803`d>030030X;00/92P0;2@X02`T:00`:2`0>30d03`d>
00`:300@3Q003`d>01@B500A3a002@L800`:2`0>30d03``=00d:2`0>2``03``<018?3@0>30X03@/9
00h=2`0A3Pl03@/<01<A4P0;2@/05A<E00h<3`0C4AD02`X=010>4@0>30l030X=00h<3`0A3a804a4D
00l=400C4A@0518E01<A500B41<04a0C01@?4@0D3Q404`d?01<=400B30h201<=3`0<018<3P090`D0
71HH018<3P0E4Q802``902`/:@1GF5@0<S8_01PH5@0>3P/04A8>0P0B4Ph0G`0A4Ph04Q8>018@500B
3aT0514K01@B6`0C4QT04A0G00l>500E51X04A0F010?500E5AP04Q4F01@E5@0?50l041@@014E4@0@
5A4041@C00hC4P0I7Qd082HU00lF5@0H7ah0@T]:0498A00=4P/04aPC010D5@0M82D04QDN01PJ9`0N
82`08B<`01/N:00I72@06QdV01TK9`0G6BL05QPW01PI:`0I6R`061T/01PI:`0J72/061XU01@G7`0F
6Ah05APJ01DG5`0F5QL071`M01LH6@0C5AD05ATI01HJ6P0C5aL05Q`K01LM7@0B61P051XK01/P:P0J
82`06B0/03<iA@0L8bd05ahX024W<@0K8RX05QdT01DL8`0G7RD06B4W01PQ:00G8BL051lU01lY;`0G
8RP082/`01/U:`0G8BH06B@Y01/U:`0I92T072H[01XT9`0L9RT06bDX01dV;00F7bD082T_01TR:P0J
8b`07bLa00808RXd03D07RL_02@_<`0N:R`06bTZ01d[;@0N;Bl06bX^01d/<00S=CT08S@i01`]<`0N
;cH08cDj01la=@0S=3X07c4f01l`=`0N;cL062Tb02<c@00Q<D008310028aA00R<DD08S9202TkA@0V
>4808S@o07V;V@0]?Td06bdl028c@P0R=440;d5<02`nB00R=C/09c]102XoB00_A4d0;TE=02Dk@`0N
=3`07SDm02<j@P0M<S/083Hn02<j@P0O=Cd07c<h02Dg=`0V>3X08cDg020b=P02020a>00K01`]=`0N
;cX0<41=02HfA00F93@08S4l028a>@0P;cL07B`d01XX<@0J9c007BT`01lZ;P0X<cD082/Y01LR7@0_
>S<0520J02hj=`0R;R/072PV014M700K9bL06RHV018M7P0G8R<05b4S0080628T02T06R<S01XS8P0J
8b806B8Q01PP7P0G7ad05A`K01lW9P0G7Qh03aLF01lV9`0L92D051lQ01HR9@0M:Bh07b/b01dY<00I
92d05b8_01LS<00O:CX07RTl01TT=`0K9CT06bD`01HQ:00D7BH06B8[01/U;P0I8b`06R</01PR:`0I
8R/072H_01/U;P0F7bL04QTP01XO900B5a`061dR01LL800201HK7`0301<H700G720061dQ008051TM
01h05AXO01@I7@0H7B403Q<H01dR9P0?51P092T]01PM8@0P9BT0DEIJ01TN8P0G720051TO01LL8P0B
5ad051TO01hS:@0M8RP061dS01TN900G72805AXP01HK8@0H7B406QhQ01LK700M8B8051PI01<G600?
4a@601<G600601<E5@0F61P05aTH01HG5`0E5aL05aTH0P0D5QH01`0D5QD051HF01@F5P0D5QH03a<D
01HJ6`0?4a@00P0B5QL06@0@51D04QHG014E5P0C5aP04ADF018F5`0I7Ah05QLI01@E5`0:2`d05QLI
00d>400E5QP06Q/M01PI6`0B4aD05AHH01<D5P0E5QL030h=01LI600H6QT071hM00h@3`0E5aH00P0B
51<03@0A4a803a4@018D4`0I6A`05A@I01TH7@0F5AX04Q0E01LE6P0E51H05A@D01<B4P0A4Ph00P0A
4Pd06@0A4@l07alQ02<S9@0C4a@03`l?018B4P0B4Q404A4?014B3@0@4@`04A8=018C3P0@4@/03a0<
01DE4P0C4a<03`l?01LG601JFU/04a<D014A400>3P`06Q/F018C3P0A4@l00P0@40l03P0?3`l0410@
014A4@0?3`l04Q8B01PH600E5AD04Q8C014B4P0@4AD061/N00l@4P0@4A<05ADG0P0<30`01@0>3Ph0
51<B00/:2@0E4a404@l<00804A0>0P0?3P`2014@3P0>00/:2@0A40h051<A00h=2`0S8Ql02`T7010>
300D40d05Q8?00d91`0C3`d040`801@?300E3``201H@2`0801PA300G4@`040`:00d<2P0?3P`04A0>
018A3`0@3`d200l>300X00`;2@0@3`d051<A00T81@0>3@L02`/400`;1@0?3PT040l:00l>2@0=30P0
40l=018A3`0:2@L04A0>00l>300@3`d030/901@C4@0=30X04a8@00h=2`0?3P`0FEQF01TH5P0=30X0
1PD300h=2`0?2`T0510=00`91`0R7Q`03@T601`H5@0@30T04@d:00h:1`0A3@X0510=018>2`804Q4?
02803Pd;00X91`0;2PP03@`:00d<2`0?3P`051<B061OG@1fMG<05A0@01D>3@0E30d04PX:01/D4`0Q
61T0610@00l81`0A20T04PX:014:2@0B2@X04@`:01@C3`0U920071/G00X91`0A40`03@`901@C3`0@
3``040l;01<B3P0S8Qh03P/80`0B3@X00`0A30T040/8010;2005010;200300l=2@0>3@T03Pd900<0
3Pd900<03@`800h=2@0=30P00P0:2@D00`0<2`L040`9010<2@04010<2@804@d:01h040`9014=2P0A
3@X04`l;01@C3@17Ach030`400h>1`0E50l03`h;00`;2P0B41402`T<00h<400I5a`0N7Ij01XH6@0?
3P`04A0>028Q7`0E51802@P6014@3P0G5Q@04Q4?00h=2`0?3P`03@`:040o?@0F5A<200`;2@0500l>
300=30X030/900h=2`0?3P`00P0>3@/03P0<2P/04a4D018@50020@@05A<H00d;3`0?3A403P`A010>
4`0>31002`T>00`:3`0A31404PT>0P0=1`/05@0>2@d03PX>00d;3P0?2`l03PT=010;3`0=1`/07QDJ
03D/<@0X9BH0514B00H51@0>2``040d>00/92P0?3@h03P/<00d;300@3Pl04Pl@014>3`0600d92P80
3`/<0P0>2P/0F00=2@X02`L8010<3@0=2@X04@`?00P31`0D3a<07APM00`73@0?2Q00?3Pn0;Rc^P1]
J6l091hV01PB6`0P6b<04PdE00`83P0:1P/03@P=00/62P0<20T03`/;014=300?2`/02`L601PD4`0?
2`/03@T901<?3P0J5QH03@T800l;2P0?2`/03PX:00d9200=2@T03``>00L52@0C4AH01P@9034_<`13
@DH02`T>00/93@0;2@h03@/@00d;3`0;2@d040/?00l:3P0>2@d03@P<00h93@0@2`l03PT=018=4@0F
4AH040/@00d83@0A31403`dC00l<500?31<03P/B00d:4@0=2a403`dC00T73@0B3Q@03@T@014=500=
2A006ALK00h<3`0=2`h04@lB00/9300?3A0030X=018@4`0A3a802`T<00h<3`0H5QT02PP900d;300>
30d200d;300700l=3P0>30d03`d>018@4@0=2``04a4B00`:2`0Dooooo`006oooool04`0=2``061HG
00T7200A3a003`d>010>3`091`P02PP900/92P0=2``040h?018@4@0C4A803`d>00P61`091`P01P@5
00X82@0=2``00P0?3@h03`0=2``03P`=00l>300b<Bh0:BPV01<B400>3@/03`d>0040000N71d020H9
010>4@0D4QD04a4F00d;400200h<3`0500l=400@3Q4040hA010>4@0A3a800P0D4QD01@0A3a8040hA
014?4P0D41404@d>008040`=00h04@d>018>3`060P<0;RX[01`H6@1HE5D04`l@00X81`0H61H051@B
00X:200?3`d03@d;00l?3@D04A4?02@04A4D018@6`0B4AT04a8J018A6@0B4AL04A0F01PG700D4aP0
4Q8D01LG5`0D51H05aLF01@F4@0B5140418?00dB3P0>4Q4041@C02T_;@0j@4006R0P00L=3@0Y;S40
=3Xh01HK5@0C5aD06alR00`?500F62<05QPU02T[>00T9S<0418N01DH8@0G6R<201HH900;01PJ9`0K
7B`06ad/01TK:P0Q8c805QPU01PK900M82D05QXM01/O7`0R92400P0J71T07@0>40l08B<R028V9@0W
:b`05a/L020V9P0/<C@0724T01HN8P0221@0728b01XP;`0D6RP06R0^01`R;P0E6bL06B0Z01HM9`0I
82X072<]010I8P0D7B@06RD[06ehOP1TKgD062<Y01HQ9`0M:2h06B@Z00806RD[07l062<Y01`W;@0?
61d06B8W01@M8P0?61l04AXQ01LP9`0O:34072D_01`T;`0N9S407bLb01lX<@0U<3@07BX[01LU9P0I
9bP08C0b02He>00N;C807Blc01`^<P0L;C@07c0g028d>00O<C@08S@h020b=P0Q<ST0834i01`]=@0Q
<Ch08c=202DeA00T=4@08C13020`@00K;CH08cDo01HX<P0bA5806R/k02/lC00O<4007S0n02Dg@`0O
<C`08C@k02m2B@0]@DX0<dM@02XnA`0T>4408cM001hb>`0Q=Ch09CU2024e?P0N<S/08CDn02Lj@00Z
?3h0:C/o02@f>P0O<3L07Rlf01l`=`0E9Rh0;3e70;K7d@26UZ<0>d]H01HV;`0N;C807Rdd01`[<P0H
9bh05R<[01TU;00Z=CT09c8d030l>@0K9R007bXR01/V800Q;B/06BDS01LS8@0>6QP08Rh^020/;00K
9bL06bHX01LR900=61X062<V01TQ8`0J8b807RLV01dV9@0K92<05QlN02L`;`0Z<c804a`K01TR8@0M
9RD0628R01`W:@0I9bX06BH/01PU;@0I9Rh06RL`01XV=00I9C<072Ph01/V>00G8S@06BDg01dW<@0H
8bT04QdS01DP9P0I92X06bH/00806RD[02h06bH/01dX;P0L9bd06B<Y01TP9P0A5QX0724U02X_<`0G
72004QLK01<H700E6Qh06QlS01PM8@0A5QX04QLK01XO8`0P9BT0;S<g00H;3`0G72005Q/O03a1A@0K
82@03a@H01TN8P0@5AT051TM01LL8P0J7bD05Q/Q01DJ800H7B<05AXP01HK8@0H7B<05a`R01DJ800C
61h04aPL010D5`0;3a009b//01/O800<41402Ph?1P0D61T01P0D5QD05ALF01DG5P0C5A@05ALF01LI
60H051HE02D05ATJ00P<3@0=4A8041@E018F5`0>4Q<04ADF00hB4`0@51D04QHG01PL7@0P92D05AHH
01XK7@0E5QP03a0B01PI6`0K71h01@H800`=3`0N7b4051DG01HG6@0C5AD06adL01DG5P0C5A@03Q0?
01DG5P0@4Q4051HE01DG5P0B51<0418A01<E500C51D02`/=00803`lA00<0410B01@D5P0?3`l00`0@
40h02P0A4@l04Q8@018B4@0C4aD0410@00`<300E5AD051@B00l?3@0@40h300l@2`0>010A300A4P`0
4A8<01<D3`0?3`l02@T900`<3P0M7Al03Ph@01XJ6@0410804A8=00L80P0@40h5010@400D01HF5P0A
4A402@T900P8200=3@d02@X900h?4`021PT02P/=010A4`0B4aD05ADE00P8200<30`051<A00X91`0C
40h030P5018A3`0A40h2010?3@0=014@3P0B4@l08b8P00D40P0D4a406APF010?3@0M71X04Q4?00H5
0`0M71X02`X801dJ5`0201<?300301@@2`0D3`/05A0<00805A0<00<04@d:00h=2`0?3P`00P0A40h0
:@0>3@/051<A00l>300?3P`06APF01XI5`0:2@D05A@>01dM5@0>3PH03@`701<B3@0;2PD03`h:00`;
2@0=30X02PT701@C4@0@3`d03@`;00`;2@0:2@L04Q4?010?3@0?3P`02`X802/Z:00=30X030/9018A
3`0<2`T061@A00/7100M6AH0X9bI010<2@0300004@d:010<2@0>2PL0510=00806aLD00H02`X800`;
2@0<2`T02`X800d<2P0<2`T200l>300501LF500g=S@0@d9001<>300E3@/00P0B2PP01@0M5A<09AdK
01`D4P0A2@L04PX800<04`/900L030P500X91@0J6AD06aXF010?2`0=30P030/700804a8>00@00P40
00<200061@405Q@@0`0A3@X00`0@30T03`/8014=2P05014=2PH03Pd900H03@`800h=2@0>3@T02`X6
00X91@0=30P6010<2@@03`/801l040`9014>2P0:2P8092@J00X:0P0?3PT03Pd801DD400A3a002@L9
00X82`0E4aP01087028P9@0F51D03@`:00`;2@071P@03@`:01DD4P0:2@L051<A01DD4P0D4a404Q4?
00/:200G5Q@02@P600h=2`081`D02@P600@03@`:01003Pd;010?3@0A3a002@L:00h<3`0;2@`061HI
00h<3`0E4aH03P`?00l=400>30l030X=00d;3P0A31004P/?0P0A2`l05@0@2`l03P`?00h>400@3a40
40/?014<400B31003@@900L11@091PL040h?00l=3P0B41403@/<01/I6P0<2P/03@/<00h<3@0A3a00
518C01DC500600h:2`03014=3P0@30d040`=00803`/<01l04`l@00T51P0=2@X03PX;00X61`0=20`0
8A`Q00h93`0E41H030L=02DP9`0>2A005@lH00@0200>2A001`<901PC6P0n>Cl03@P=00`72`0>2P/0
3@T900`81`0?2`X0510?00d92003000030P700<0000?2`X0510?00803`/:00T03PX900d9200=2@P0
1`D600h<3`081`T00@0200X82`0X9RT00P0<2Pd0100=2`h02PP;00X82`0=2`h200l:3P<040/?00@0
3`X>00h93@0A31004PdA0P0>2@d00`0C3Q803@/@00d;400200h<4@803`dB00T0518G00H42@0C4AH0
40hC00d;400K6Ah09B<V01@B5@091`X00P0?3A00300A3a803`d@00l=400<2Pd02PP;00/9300?3A00
2PP900`:2`0=2``02`T:00`:2`803P`=0P0<2P/00`091`P07Q`M02DS900Dooooo`006oooool02@0E
4a@0:2HW00X82@0C4A8030X;00h<3@0B41404@l@00l=3P0300h<3@09010>3`0<2P/01@<400X82@0?
3@h07Q`M00d;300?3@h03P`=00803@/<01403`h<01<B3`0?3P`01`H400`;2@0C4A8030X;00d;3005
0`H03`d@00`:3@0;2@h05Q@I00h<3`0?3A0040hA014?4P0200l=400801@B5@0E4aH0518E018@4`0A
3a804Q0C01LC500D4142018>3`0?01@@4@0E4A807QXK00L3100300008QhO010<3@0H5QH03Ph<00T9
1`0O7ad03Ph<0041000F5Q@0410>00<04A4?00<04Q8@018B5@0B41/00P0B4AT2018A5`0Q014@5@0G
5aT04a<E018B4@0H61H05ADC01PH5@0F5a804a<A014B3`0A4a004Q@C010D4`0;3`h02Ph?014G5`0G
7Ad04aPK018H5P0=4Ph020`<010C600A51/05ALR01@F8`0G6BH04Q@Q01<E8@0L7RX05aTT01DG8`0F
62@06A/X00807Al/06X06Q`Z01LI9P0D5R805aXR01HJ7@0?4a@051PF02<U8P0>40d061XG018D4`0L
7Qd07R8Q01`P8@0D61/0724U02<X;00H7B4051/R02@Z>00T:SX061h^01TO;`0Q9cD082Hd01<I9`0M
8bl05QdW01DL9P0L8bd04a`U01XS:P0=61h0F6=Y04YEF`0E82H09S4g01@O9@0F8BL07BP^01hY;`0J
9B/072L]01LP9@0O:2d07BH[01HO9P0Q:S4092dd02</=@0P:C<07bLb020X<`0N9S406b@]01`W:`0M
:B/07R`]01l];P0O;S007B`_01d/<@0N<3@072hb01TZ<@0K;3<07c0g01h`<`0P<SH08C<g028c>P0Q
<SX0834i02<c?`0U=D@09SI502@dA00S<TD08c=302Li@P0^@4X08S@n01h`?P0H:CT0;Ci>01`]?@0Q
<d40:Sa802@f@@0M<3L093Ln02a0B@0cAe009c]402Di@P0Y?DH08SHo024e?P0T>4407c<l01T]=P0J
;SL07c8i028c>P0S=3/0834h0P0N;cH06P0T=C`07Bhf020a>@2R/k`0OHjH04UJI00F9Rh06RT^01/Z
<@0J:C005RD/01@Q:@0D82L06bHZ01XU9`0S;b`05R4K01dX800N:B@000T702`h=P0D81h07RXX024]
;@1]NGT09C4a0P0B7Al0100A71h06RDX01LQ8P0I8R4201XS8P0F01PQ800F7ah08R/Z02H_;P0B6aX0
7BHU01TR8@0I8R806bHX01TW:P0I9R`06RL_01`Y<@0O;3D06bLc01PT<P0I9CD06B@f01DP<P0G8cD0
7bTc01/V;0805R4W02D05b8X01HQ9`0E82H05B0V01HQ9`0G8RP05R4W01DO9@0D71l04QLK01/P900Y
;S806b0T01<H700B5a/051TM01XO8`0I7R805Q/O01XO8`0<4AD0@TM;079gN`0[<3@06QlS01@I7@0X
;C4061dQ01`Q9@0D6Ad06b0T018G6`0G72806AhT01PM8`0G72805AXP00804QLM00/05AXP01HK8@0D
6Al04aPN01<H700N8RD06QhO01DI6P0@51D061`M010D5@06018F5`805ALF00@04aDD018D4`0E5aH0
5aTH1P0F61L0200h?3d03a<D00hB4`0<41404aLH018F5`0D61T04ADF0P0B5QL0800C5aP061`M01HG
6@000@<03@h@01XK7@0I6Q`0EEIH02<T9P0720X04Q<E00`=3`0E5QP05ALG02/];00J71/05QPG00/=
300L7Qd04Q@C01DG5P0C5A@04A<B01<E500B51<04a@D00l?3`0@418051@E01/K6`0J6QX0410@0P0B
4Q802`0C4a8051@B01@D500I6AT071`N01HF5P0A4A4061PH01LG5@0B4Q004A4?00<04Q<>00h04A8=
00`=1`0>3`T051D@01HF5P0E5AD06ATK01HF60020P@051@C01LG5@0F5a804Q<>010@3PD0410@0P0>
3Ph0400A4A4061PH01dM7@0A4Q806Q/O010D5`0M7R003@h@00<41P0O7al07QhN00d=3@0@3`d03Pd;
00l=2P0@30T600l>300;00d<2P0G5Q@02PT701@C4@0;2PP02@P600X:2P0@41001@D303`j>`0B4@l0
0`0C3``301@?2`0@01@@3@0A40h040l=010?3@0A40h040l=00d<2P0B4@l03`h<018A3`0I61H061LE
00d<200P81T08R8J01@D308040l:01l02@P3018A3@061@<030/901@C4@0F5A<02@P601DD4P0A40h0
1PD301<B400?3P`040l=00T81P071P@00P4000d<2P0H5aD01PD300`81P0I5A802PH301LC400=2@H0
8QhK00`81@0C3``0510=01LC400F4Pl04Ph;00804a8@018040l=00d<2P0>3@/04a8@010?3@010000
2`X8014@3P0J6AL040`:01@<2P0A2@L03`L5018:200F3P`050`:018:200C2`T301@<2P0400h:1`09
20@03@`8010?2`804A0<00L03`h:00@3000;2PH06APD02PW8`040`004@h;00<04@d:00<040`900l;
200@30T01@0@30T600h=2@0600d<200>3@T03Pd900/:1P0:2@D03@`81P0@30T06`0?2`P03PX700h:
1`0>2PL03`/8014=2@071`003@d300P80@0=30L010<0014@300>3@/02PP:01XH6`0Y9b`04Q0F018@
5@0:20T02`X801<B40071P@04A0>01@C4@030P0030/900h=2`0200l>300700X91`0;2PP01PD300h=
2`0920H02`X800l>300200h=2`0:00d<2P0>3@/04A0>01@C4@0B41<03P`?010>4@0;2@`0:RP[01TG
6P<030X=00@03@/>00h<3`0A31004PX?0P0C3A403`0@3A003Ph@00l?4@0?3a4030X=00/62P0D3Q80
5PdB00d72`0B3a0030X;00<10P0>30d0108301/I6P0200l=3P803P`=00<040h?014?400?2``01@0?
2``00`0A3@h040`=010<3@0200l;300G014=3P0810D04Ph?00l;300=2@X01@04018=4P0500H04@`B
01@?5@0G4QT020<:00X6300K5Qd050lF010;4P0:1@/0>3<i00P4200;1PX03@T:014=3@0?2`X00P0>
2PT01P0?2`X02@D401HB4@070`8040`;014=30803`/:00P03PX900d9200=2@P04@h?01<A500610L0
9B<V00<1108030X=0P0=2`h200X82`0300h<3`0>2@d03`X>00804PdA00<04@`@00l:3P0?2Ph00P0@
2`l00`0>2@d03`X>01@?4`02010>4`0;00l=4P0>31403@/@00`:3`0F51T02PP=018@5@0>314040hC
01HD6@0E4aH00P0=2`h02P0B41<030X=00T72P0<2Pd02`T<00`:3@0>30l04Q0C01<A500:20T200`:
2`0900/92P0<2P/03P`=00/92P0E4a@02PP900<10P0I5aP04Q0A01Cooooo000Kooooo`0:00P61`0H
5QL0108300l=3P0=2``04@l@01DC500D4Q<04@l@010>3`803`d>00T04@l@01<A4P0:20T03`d>01<A
4P0=2``02`T:00h<3@0=2``00P0<2P/03`0=30X03`h;00P71P0B4@l040l=00d;300C4A8040h?00l=
400=2`h03`d@01XH7@091``03@/>00l=4002014?4P0:00l=400>30l04@lB014?4P0@3Q403P`?00l=
400@3Q405A4B01@@4@@04`l@00`04@d>01TE5P0J5QL03@T:01/G600>3@`061PF00L71@0;2`T05QHD
00/;2@0C4a42010@3P04014A3`0B4Q004a<A01<C5P804Q4I02404Q4G018B5@0B4QD05ADE01dN6P0G
61@04Q<=01<E300?40P051@>01DD400D4a4051@B01DE4`0H5aL05QLF01@F5@0E5QP051LH018F5`0A
5AP04ADF01lS8`0a=CP030lE01`O9`0D5R806Q`Y018D8@0G6BH06Q`Y018D800G6BD00P0F6B808`0I
6bL071hZ01`N:P0J72L04aHP024T;00S9R/051PI01DI600E6AH08B<N01dP6P0J71L041DA01HJ6@0D
61T05a`O028W:`0T:Bl05QdT01LN9P0H7RT0:2hn024V>@0L8C@04QPX01HL;00G7B`06Al]024W=@0J
82d04aTU01PN:P0L9Bh04Q/S00807RT_02h062<Y02/f?00L9bd062<Y01HQ9`0H8bT06B@Z024/<P0_
>T009C0d01LR9P0K9RX05R4W02Ha=`0T;cD06bD^01hX<P0S;CL09Bli02@^>00N:34072L[01hZ;00M
:b`07B/^01d/;`0N;C006RT^01h_=P0M;SD06BXa01//<`0O<3L07c4e01h`=00Q<cL08C8i020a>@0R
<c/08S<m02<c@00Q<Ch07Rhm028b@@0U=D@08S@m0P0Q<cd0@00Q<d407Rlo02@eA@0Q<T807Blm02@f
@P0S=D006Rdd01P[<P0Q=Ch0:Ce6024e?P0R=Sl0:3a502@h@@0Q=Ch07C4j01lc?00P=3d07C4j01`^
>00N;cT07c0j01h_>00M;SH07Rlg01d^=@0X>D007Bhe02Tk@@0G:Bh0:ca201TZ;P0L:bh072/`01`[
<@0H9bh05b@/01TU;00@6al06RDW01`W9P0V<B`0@Da501@P6`0N:RP06RHT01dY:01MJFT07RXZ01dY
:P0D7b405b8T01`W:P0?6Qh041/N01/U9P0I8b805R0O01DO7P0F81l06B<R01HP7`0I8b8201LQ800@
014K6P0H8b<062<W01LT:P0J9bd06RL_01TV;P0H9Bh06bLc01LS;`0H93806bLg01LS<`0F8S806B<[
01TT:0806RDY00D06B@X01HQ9@0A72004ahR01@O8`02018M8@0I01@N8`0C6ah08BHZ01DJ7P0J7b<0
6AhR01<H700F6al04aPL01HK7`0G72005AXN01PM8@0C61`05a`P03a1A@0F6al05a`P014F6P0I7R80
4QLK01@I7@0:3a<05a`P018G6`0201DJ7P8061dQ00<05AXN01@I7@0A5QX00P0D6Ad02@0C61`05AXN
01LL800X;2l04ADF01HJ6`0B5QL05QXK01LK700601<G60805ALF00<051HE018D4`0D5QD01`0E5aH0
7@0l@44061`M01@H6@0A5AH05a/L01HJ6`0C5aP04QHG01HJ6`0D61T041@E014E5P0>3a408b@V030a
<`1MGV004A8D03@e=`0B4aD03a0B02LX:P0G61X05AHH014C4`0O8B0051HE018D4`0=3`h06Q`K0080
4aDD02X03a4@01@F5@0Q8b8071hM010A400A4@l05aLF01<C4@0E5A@06ATI014A4@0C4a<04a<D01<C
5@0B4Q<04A4C01HF5`0K6a/06ATI01<C4`0C4a805QHD01@D4@0?40/04A8=014B300@4@/03a0:014B
300C50h04Q<>010@400A4A40410B00l?4@0T92H06ATH00T91`0G61<03a0:00l?3@0@4102018B4P0:
014A4@0@41003`l?014A4@0?3`l03Ph>00/;2`0?41004A8F014E6080414C00P0;c0b0;Jf]P1:BTX0
7AdM01@C4@0I61H030T701HB3`8040l=0P0A40h2010?3@0E01PG5@0?3P`04A0>00P71@0C4Q00:RTX
03<c=00m?T0030d>00h?4@0D51D0410?014@3`0A40h04Q0=018?3@0C3``04Ph;014@3P0@3`d04A0>
00804Q4?00h03`h<00/:200<2`T040l=00l>300<2`T03Pd9014@2P0:2P<03`l7018A300@3`X04A0;
01/J5P8081lM0P0B4@l01P0=30X081lM01HE4`0:2@L04A0>00l>308040l=00h03Pd;010?3@0A40h0
92<Q01/J600A3@/02`L601TE4P0=2@L06aLD00H20@0?2`P04Ph;00l;208040`9010030P5010?3@0@
3`d03Pd;00/:200=30X0?C`j04Q7A@0C4Q0030/900/:200C4Q003PX700`70`0?2PH050l;0P0B3@T0
0`0A30P040/7014<2003018=2@0=018>2P0@3`/02PT500`;1`0?3PX02`X601DD400<2`P02`X601lN
6P0];2P03@`8010=2P03014=2P03010<2@0?2`P040`900D040`91`0>3@T200l>2P0300`;1`0;2PH0
3Pd900H040`9100?2`P0800@30T04@h:01<C30092@40410801@C3P061@404A0<00d<2P0;2PX04a4D
01HD5`0<2`h03@/>00d;300>3@/04A0>00P71@0>3@/030/900l>300@3`d030/900d<2P0@3`d02`X8
014@3P0:2@L03`h<00d<2P0B4@l03`h<0P0>3@/0300=30X03Pd;014@3P0C4Q003@/=010>4@0;2@`0
6QPK09RFV@14@TD05aDH01@B5@8040hA01X03P`?00l:3P0@2@d04P`@014<400?31004Q8D01DE5`0C
4aD040hA00h:3P0A2`l05@`A014;3`0<2@X0518C01hL7@0e<c@03P`=014?400;2@X03P`=00d;300;
2@X03P`=014?40L040`=0P0?2``200h:2`0;00`8200=2@P030P901@@4@0B3Pl040/?00h93@0<1`/0
3PT?00`73@0@2a400P0>2@l0200I51X020<9014<4P0@2a003PT>03<^<P0J5AT03PX;0P0A3@h0200?
2`X03@T9010<2`0<20L06aLF00h:2@0B3Pd03PX90P0?2`X02@0>2PT03@T800d9200;20T061HI01lM
800:20/00`84010>4@0600h<3`803`X>0`0A310600l:3P04018=4@0>31403P`A00h<4@<03`dB00P0
3@/@00`:3`0=2a002`T>01/I7P0;2@h020H900/930803`d@01@03@/>010>4@0:20/02@L:00/9300?
3A004Q0C014?4P0<2P/03@/<00`:2`0;2@X03@/<010>3`0g=CH03`d>014?400>30d02@L8014?41Co
oooo000Kooooo`803`d>00D03P`=014?400?3@h03@/<00/92P0300X82@8030X;00L04a4B014?4003
0@806aTJ05=ADP1FE5D030X;00803P`=0P0<2P/03P0>3@/01PD30040000:2@L03@`:010>3`0D4Q<0
2@L800P62@0m>ch030X=010>4`0=2a003P`?0P0?3A02010>4@<03`d@01d03P`?00d;3P0@3Q404Q0C
014?400B41404a4B018@4@0?3@h03P`=00`:2`0610D09bDV00`:2`0;2@X051<C01<C4`0=3@d06ATI
014A4@071`L04a<C00l?3`0@41004A4A018B4P0C4a<04a<F01<B6002014@5P0J014A4`0C4a<061TE
02@U7`0M7QH05aT>01LI300A4`H04a@<01DA3P0E4A005Q8A01@C4@0D4Q<071XK01dM7@0F5QP03`lA
00d>400@4AD04aDI02HY;P0g>T005QTP01XM9P0G6BD200lA7P0501PJ9`0G6BH0418O01PJ9`0H6b@0
0P0G6R<201TL9@0d01PK8`0F6Ah061`O01HJ700A5A@041@C010E400@5@l04AH?01HK5@0Z;b/0310?
01PM7`0B5a/06b0V01lV;`0I7b/061hZ01LN;@2l`M@0C55U01hS=P0e>Td06Al`01TO;`0H7Rh05Q`[
020V=00Q9cD05Q`Y01HO:00U;SL062<Y02@_=@0c?T@092le020[<@0O:S006RD[01HQ9`0C7R@06bH/
02dh?P1FHFD08B``02<^<P0L9bd08Rdc01DP9P0I8b`06R@^01lY<`808bdg02H082Xc01`W;@0K:2/0
6RP[01d[;P0[>Cd0>4M<02@c>P0G:2l05BH]01PY<@0J:c<062T`01h`=00L;S80838f01l`=`0M;SH0
8S<k020a>@0T=Cl08S<m01h^>`0P<3d093A1028e?@0N<3X0838l02LiA`0G:3P03b0`02LhB00R=480
8SA0024c?P0P<cX08SDl01`_=P808SDl00T08C@k02<f?@0U>3l08C@k01`_=P0P<cX08cHm020c>P0N
;c/00P0Q<D00?00O;c`072dg01`]=`0L;CD04B8Y01LY;@0M;c40838d02Li>`0F9bL06BTY01PW:P0G
9RX05B@Y01DR:P0E8BP03aXN01@O8@0G8R4062<O02lj=00C7a/08Rh^00`H600C7al09c<c01<N800J
9BL051lQ01dX;00D7b<031LK01`W;00H8R@05b4R01HP8@0E7b005R0Q01TS900E7b0031HG01LQ8P0>
61T05b4R028];P0J9BT06BH/01XW;@0I9Rh05b@/01DR:`0L:C8062D^01`X=00Q;C/07BTg01XV<`0E
82H05R4S01TT9P806RDW00@06bHX01<N800E82805R4S0P0D7b406`0H8bD06b<V02<X;00I7R806QlS
01LL800L8BD061dQ01<H700J7b<07b@X01TN8P0A5QX051TM01/P900h?D40724U010E6@0G72004QLK
01LL800B5a/06AhR00lD600B5a/05a`P01<H700201LL800>018G6`0D6Ad061dQ01LL800C61`04AHJ
01<H700G71l0TYJI02``<@0>4Q<05ATJ01@H6@0E6AX601@H6@03014E500C5aH04aLF00T041@C00d0
20`=00/?40093@h041@E01DI6P0C5aP041@E00dA4P0B5QL051PI010D5@0A5AH061TK00803@h@00l0
6Q/M00d>400A4Q@04A8D01@E5`0H6A/02``>00d>400D5QH02P`;00lA400>40l04aDD00d?3P0A4a80
0`0C5A@02`0N81l071hM01HH500>40/030h901dO6P0i>cH0<cDb01<E500?4180414E00804A8F00@0
414E010A500@4100410>0P0?3`d00`0C4a404A8=00d>2@02010A2`0@00l@2P0=3PP02P/500l@2P0B
4`h071`L02TY:@0a<C<071`N01LG6@0;2`X05QHD00@5000A4Pd03Ph<00l?3`804Q8B01D04A4A00l?
3`0>3Ph04Q8B01@D500H61P07QhN05UJFP1BDeL0DUII01/L7P0?41805QLI079bLP0i>CT06a/K01LF
500H5aD040d;018>2`0@3`d0100B4@l03`0@3`d00@00038a;`0<2`T061LE018A3`0<30`04A8D01@F
6@031`X09b/^014D5@0I6Q`03a0B010@400200l?3`803`h<00<040l=00l>300A40h00P0C4Q002P0A
40h05aHD014@3P0C4Q004Q4?00l>300C4Ph04A4:010@200>3PH2010?2P0900l>2@0F5A4092<Q020O
7@0:2@L040l=01<B40071PD01PD300803@`:01005A@B018A3`0;2PP00P4000H50`0M71X09B@R01DD
4P0E4@h02@D200`81@0E4@h04Ph;01<?300D40d04`l<0P0?2`P00`0@30T03@T600d<2P0300l>3008
018A3`0E51806QTG01HE4`0E51803@`:014@3P0;20L2014<200301@?2`0=20@02PD100803PT50140
3`X6014<200@2`L040/700h;1`0A40`030/701<B3P0I61@04A0<01HE4@0C4Ph03Pd9010?2`081`<0
40l;00/:1P0300l>2P0300h=2@0=30P03`h:00D03`h:1P0>3@T300l>2P8030/700<03Pd9010<2@0@
30T0200@30T0400A3@X04Ph;010?2P071P403@`7014@300:2@D03Pd901TH5P0E4a<030X;00400P04
0`D03`d@00P61`0D4a4200d<2P0=00l>300D4a402@P600T81P081`D03@`:01DD4P0C4Q004A0>00h=
2`0@3`d02`X8014@3P0200`;2@@03Pd;00T03@`:00l=3P091`P04@l@01<A4P0Q7b004Q0A01XH6@0E
4a@00P0A3a006P0>30d03PX;00l93@0B310040/?00l=400H61X07AhP018C5@0;2@`040hA018=4@0A
2`l05@lC010=3P071@H03P`=01TG600:20T02@L800`:2`0?3@h03P`=00X82@0=2``04Q0A1`0A3@h2
010<3@803`/<01H040`<01PD4`0:1PD0?3Pg010<2`0G4a@01@4300`72`0A31005A0E00l:400@2a40
4`hC07MbMP0U82@05A0D00<00P0M61`0:2@U01TE5P0<20T040`=0P0>2P/01P0D41000`0001DA401M
FEP07a/J00L30P<03`/:00X03PX900d9200=2@P03``<01TG60071@H08AlP00l=3P0:2@T040h?0P0=
2``201@B4`0300/92P0?2Ph03`X>00<03PT=00<03`X>010;3`0?2Ph00`0@2`l0500>2@d02`T<00/9
300=2`h03`d@010>4@0A3a803P`?00d;3P0B41<04@lB01dK7P0?3A003@/>00h<3`0=2`h02`T<00l=
400C4A@030X=0`0=2`h200`:3@0<00h<3`0?3A003@/>00`:3@0?3A004a4D08n=T00X9RT03@/>018@
4`091`X01@<65?ooool001_ooooo00P030X;00D3100A3a004@l@01<A4P0?3@h040h?00l=3P803P`=
00T03`d>010>3`0<2P/040h?00800@0L6Q/0EUAE04Q6A`0=2``00P0?3@h03`0=2``03P`=00l>300B
4@h030/900L6100;2PP04@l@00h<3@0D4Q<0>3Hi0;Ne^00d<SD00@0401LE6P0200h<3`0400l=400@
3Q4040hA010>4@804Q0C0P0A3a801`0D4QD05Q@G018@4@0E4a@05aDF01DC500A3a000P0?3@h07P0I
5aP05aDF028P8@0=2``03Pd>01@D500B4Q8030`<00h>3P0=3@d04Q8B00l?3`0@41004A4A018B4P0C
4a<051<G01<B600A41H0410C014A4@0C4a4051D@01XK4`0E5Ph04Q@801DG2P0A4`D051@;01DA3P80
5A4@04/04`l>010>3`0?3@h04Q0A01DE5`0J6Q`05aLI018C5`0A4aL05APO010C6P0G6R<05APQ01XL
9`0L7RX06Q`X01HH9@0K7BX07Al/010B7`0I6bL05aXS01DH8@0G6R<061/R01LJ800V:Rd05a/N01<G
600J7Qd05ATH01LL600F6aD041D>04aAC01oQ8007B4P01<H700G72805A`T02D[=P0]<d409R`j02@[
?00e>Td08bPl02dbA@0P9CP07B<d01XP<00M8c<05Q`[02hd@P0e>dT082Hc01LP:@0H8BX06B@Z020[
<@0jAD/09c8h01<N900I92X06RD[01/V;00F8BL04ahT01/V;01II6P05R4U01hY;@0K9R`08Rdc01@O
9@0O:C800P0L9S009P0M9c407RPb01`V;`0N:Bl07BX]01XX:`0I9bX07bhb02Pg?00jBE007Rlf01PY
<00P<CT07c0h01PY<00O<3H06bda01la=@0M;SD072de024b>P0R<c/0:CY402Pi@`0S=3h08c=002Df
@00V>D00;Cm902@f@00R=480835102XkB`0N;cl08cE302@f@P0N<3/072lf0P0O<ST02`0T=ch0:3]2
02<f?@0Q=3/09cY1024d>`0N<CP07C0g01`_=P0J;C@06R/h00807Rhn02<07Bdl01/[>00L;CL08C8j
00LI7@0J;3008S@e01T[:`0M;bl07c0`01d];@0K:Rd06RT]01PW;00I9Rh05b<Z01dX;P0G8RH06bHW
00XD4`0D7a/072PU01<O7`0<61P06bLW038n?P0?6Q`05R4S01@O8@0I92P051lS01DP900D7b@04adO
01<M7P0401@N7`0701lY:P0>61T07BLX01DO800Z=3D0>49401XX:`0201XW;@0<01/X<00L:C407BXc
01dZ<`0J9c007b/g02Da?@0R;SX07BTe01XU:`0J9BL06B@V0P0G8R@0100J9BL04ahP01HQ8`0G8R@2
01@O8@0<01TT9P0D71l04QLK01@I7@0J7b<041DI01dR9P0F6al04aPL020U:@0Y;S808BHZ0`0D6Ad0
700[<3@06QlS00lD600K82@05AXN018G6`0010P04aPL00dB5P0S:2`06AhR01@I7@0G72005AXN010E
6@0C61`07B8V01TN8P0C61`03a@H014F6P0F6ah092PY01PL7@0I7Ah04aLH01HJ6`0A5AH6018F5`04
014E500D61L051PG014E50803a<B1P0A5A@00`0G6a`07b<T01<G600201<G600L010D5@0B5QL0310A
00lC500A5AH03a<D010D5@0@4A<04a@F02HW:@0=3Q004a@F01@E5`0C51H03@h@014B500E5QP04A8D
01XL700:30/05QPG01<E500H6QT01`T8010B4@0E5aH061XI00lA40804Q@C02H03Q0<00d@2@0@4Pd0
4Q@?020R7@0O8Ah030h=00l@4P0A4QH051DI01DF6P0D5AX05ADH014A4@0?3`d04A4?018B400C50l0
4A8=00l@2`0B4`d04a@>014B300?40X05AH@01HG4@0?40/030`<01@D500E5AL03Ph@01XJ700<30/0
6ATG010A300=3PT03Ph<00l?3`804Q8B01H04A4A00l?3`0B4Q805QHF01<C4`0;2`/02@T904m@D00H
6Ad0:2`_00P92`0I6Q`02@X<01dM7@0E5AD03@d=01@C4@0A40h0518?00h:1`0=30X03`h<0P0@3`d0
400?3P`03@`:014@3P0I61H05A@B010?3@0>3@/030`<00X;3@0=4A@0Ad]>0<gAe00R92L010D700l@
4P0@414200l?3`0900l>3@0?3P`03`h<00h=2`0A40h04a8@01@C4@0B4@l071/I00803`h<00h04Q4?
00l>300@3`/030`601DE3@0:2P803@`701HE400?3PT030/700/:200?3P`03@`:01<B40<03@`:00l0
6QTG00h=2`0B4@l02PT700h=2`0H5aD02`X800/:2@0@3`d03@`:010<2@0E4@h03@T600X6100=2@H0
0P0A3@X01P0H51405a<@01LC400A3@X02PH300`;2@803@`:00d030/900h=2`0A40h01`H400@30@0;
2PP01PD301hM6`0G51404`h:018=2@0F4@d04@`800804Pd901803PT500l:1P0@2`L040/700l:1P0?
3@T05A@@00T8100920H03@`800H50@0A40`05A@@00l>2P0F5A402PT5020O6`0;2PH300l>2P0300h=
2@0=30P040l;00D040l;1P0>3@T00`0?3PX040l;00l>2P0200`;1`0300h=2@0@30T040`900@040`9
0P0A3@X0>@0@30T04@d:014=2P0C3``030/600L60@0:2@@04Q4=00l>2P0A40`03Pd;00T81`0A3a00
3P`?014?4P050`@03@`:02<R800H5aD05A@B00T81P0;2PP04A0>010?3@0=30X040l=01@C4@0=30X0
2`X800h=2`0A40h020L500d<2P0:2@L030/900h=2`0?3P`03Pd;00d<2P0;2PP020H701<A4P0B4140
<2h_018@4@091`P04Q0A00h<3@0=2``04@l@010>3`0>30d040X>018=4@0A310040lA01XK7@02028S
9@0A00X:300>30l03PT=00d72`0C3Q805A8C00<10P091`P01`D600l=3P0C4A804@l@01@B4`0@3Pl0
2@L800X82@0>30d01P0A3@h2018>3`804@d>01@040`=00/71`0@30/01P8105iJF@0H51<07a/L014<
3`0A310020<7014<4@0>2@l04`hD00/72P0[9bP020<700l;3@0I5AH01@4201<?40802@D600X05A4B
00h:2`0;1`P04`l?014=300300004Ph=014=300E4A003PX90P0?2`X01P0>2PT03@T800d9200;20P0
0`4201LE5P802@L800@04Q0A010>3`0<2P/03@/<0P0G5AH01P0:20T040/?00l:3P0=20`030L;00d8
308040/?00D03`X>010;3`0A310040/?00`72`0600h<3`0600l=40071@P040hA00d;3P0?3A002`T<
0P0<2Pd01`0=2`h03`d@00l=40091`X030X=010>4@0A3a800P0?3A002`0@3Q403`d@010>4@0=2`h0
30X=00l=400D4QD04Q0C00l=400:20/00`4400804Q0C5?ooool001_ooooo00D02@L800h<3@0A3a00
2`T:00`;2`0700`:2`0K00h<3@0B41403`d>00/92P0>30d05A<D010>3`0>30d04@l@00d;300;2@X0
40l=00l>2`0>3@/03@`:00h=2`0>30d03`d>00h<3@0Q7b80EUAG01@B5@0C4AH020H;00h<3`0B41<0
4@lB00803`d@0P0B41<0:P0C4A@04@lB00l=400@3Q404Q0C01<A4P0D4Q<06aTJ01<A4P0<2P/04Q0A
01<A4P0?3@h0HEmP03dk?00;2@X03Pd>01<C4`0=3@d0410@01DE5@0A4A405QHF00`<300J6QX03`l?
01LG5`0=3@d05ADG01@C5`0G5aX04Q8C01HF5P0;2`T04a@?01@E3P0A4PX05AL<01LI3@0B50P05aL@
01HB3`805a<B00/05Q<B01@B4`0D4Q<05aHF014A4`0J6Q`061PJ014B5P0K7B<03Q4I01DH7`0301@G
7P0i01DH800C5Qh04A@N01@F8@0G6BD06A/X01HH900H6RH06QdV01XM9@0J7B@061/P01DI700M8B80
51PI01HJ6P0<40l05a`J01LL5`0J7aX0>3`i059HE`0H7Ql05a`Q01DL8`0C6R<051`W01/R<@0O9SH0
7RDg01PM<00M8S@08bPj01DK:`0Q9cL0CeET01@J:00G7B/07R@a028X=00M8bl051dV01`U;@0G8RP0
6RD[01HQ9`0M:2h062<Y01/V;00I92X07BP^01PS:@0L9bd062<Y01DS9P0F92L06BLZ00807BX`00`0
6BH/01h[<`0M:S<06RL`020]=P0L:C807b`d028]<`0N:Rl07BX`01l/<P0Q;cH2020_=P0701TZ<P0K
;3@0834i01l`>00L;C@07c4f01h_=P0201d^=@0=01`]=00K;3<0834i01l`>00T=Cd08c@l024b>`0U
=Sh0;D1702<e?`0T=T008cE3020a@@02028c@`0`020b@00R=4007c4l01ha>00R=C`06bhd01T/<P0O
<SP08cHl020c>@0R=C/072le020c>@0O<SP06bhd01X]<`0K;CP08310028b@P0P<3l07Bdj01l`>P0O
<3P072hb01d_<`0N<3406bh/01T/:P0I:RT07bl^01HV9P0E92L05RDZ01@Q:@0M:C005B0V01<N8P0M
:2X0628R01DO7@0L9bD04AdM020/;00I9BH04ahP01hY:`0/=cX0;CPl0P0P:c407`0I92X05R4V010K
7P0D7b405b8T01@O8@0B7Al051lQ01HQ8`0D7b405B0R01TT9P0J9BL062<V01h/<00>6b40;S]303Q5
C@0I9Rh06RL_01LT;@0E8R/0<Ci70<GBf`2^^l@0:cM101HQ9`0N:Bd06RDY01PS:00C7R800P0D7b@0
8`0@6al04ahS01LR9`0D7b<05AlT01LO8P0N8bL061dQ01DJ7P0H7B405Q/O01XO8`0H7B405AXN01<H
700F6al04QLK02P]<@0L8BD0<cPl02H[;`0F6al0:Rlc01LL800B5a/05Q/O01TN8P0D6Ad04AHJ01PM
800D6A`04aPK01@I700E6Qd04aPK00805AXM00L04aPK01XO8P0A5QT03A8E01@H6@0E6AX051PI00H0
4aLH00D04QHG01@H6@0F6Q/041HD01DK6@02014G5@0401<I5`0?5A<051XH00hD4P804ALE00h03aDC
01<I5`0F6Q/041@E01HJ6`0A5AH0?411038f=`0@51D03A4B00lC500D61T041@E00/?40804Q<E00@0
5QLI014B500F5aT04a@F1@0B4aD07P0B4a@0418A010B4@0@4Q404A<B01<E500B51<071hM03Tk>P0C
5A@05ALF01LI600G6AD04A<=010B3@0B50l04aD@018D4@0@4Q404a@F01@E6@0@4AD03PlC01<D6@0J
6Q`05QHD018B400A4@h04Q<>014B3@803a0:00T04A8<01<D300C50`04a@<01<D3P0E5Q003a0;01<C
4`0?3`l00P0A4A<07`0B4Q@03`l>01@D4P0A4Pd051D?018B400@41004Q8B01@D500@41004Q8B01PH
600820P05ADE00T92@0C4a<03a0@02X[;`0T:2/03PlA01PI6`0@4A<03`l?018B4P0A4A4040l=00l>
300A3P`04`l<00l>300A40h00P0C4Q005P0A40h03`h<01<B400Q81h01PD401<B400>3@/04a<C018C
5@0:3Q404aLJ05eQI00B51H03PlA00d>400<30d03Ph>010@400?3`d02`X800h=2`0@3`d300l>3080
3@`:00P051<A010?3@0B4@l02`X800l>2`0A4@X03Ph600l?1`804a8=01<04A0;00d<2@0=30X02`X8
00l>300:2@L040l=014@3P0@3`d04A0>00d<2P0<2`T040l=00h=2`0?3P`030/900h=2`0?3P`03@`:
00803`/800@040`9014=2P0A3@X04@d:1P0@30T500l>300L00`;2@0K6QP08B0N00h=2`0@3`h04a8@
014?300@3@P05a<?00l<1`0A3PT040d9014=2@0@3@P03`/7014>2@0B3`X04Ph:014>2P0?3PX03@`8
00h=2@0C4Ph05aHB01@C3`0@3`/03`h:010?2`804A0<01H03Pd900l>2P0J6AD05aHB00/:1`0@3`/0
3Pd9014@300E51004a8>010?2`0>3@T04Q4=00X91@0<2`L040l;00d<200F5A40;B`X01@C3`0=30P0
3Pd90P0=30P01`0E4@h06QHC01XF4`0@30T030P5018>2`0C3``00P0>2PL01P0@30T03PX700h:1`0=
30P051<?01HE4@803Pd900X03@`:00h=2`0>3@/03Pd;00h<3@0=2``02`T:00h=2`0a<2h03@`:0P0A
40h01P0;2PP03Pd;00d<2P0=30X03`h<010?3@L03Pd;00/02`X800T81`0B4@l03Pd;010?3@0:2@L0
30X;01HD5@0>30d030X;01@B4`0200h<3@0H00`;2`050`@040h?00`:2`0;2@X04P`@00h93@0<2@`0
5QHH02`];`0h>C/071dO00/;3@0>3@l04@dA00X5200B3A403P`=010>3`0E4a@061HG01<A4P0@3Pl0
3P`=0P0=2``01P0>30d03`d>010>3`0=2@X03PX;00l;30<04@d>02@04Ph?010<3@0?2``03PX;00`8
2@0=2@P03PX700l;200B3P`0510?01DA400B3Ph03`/<010;3`0?2Ph03PT=00l:3P0A3@h04Ph=018>
3P0B3Pd040`<00h:2`0<2@T03`/<01TE5P0?2``04@d>00T51P0<20P030P7014=300@30/02`L600d9
200=2@T200l;2P0C00d9200>2PT030P700T61P0F51D0518C00X82@0>30d02PP900d;300C4A803P`=
00P61`0@3Pl03@/<00/62P0@2`l04@`@00h93@02010;3`<03PT=0`0=20`200h<3`8040hA00h03`d@
00h<3`0?3A003@/>01<A500R82<05aDH00d;3P0:20/03`d@01DC5P0@3Q403@/>010>4@H03`d@1`0>
30l01@0U8bH05Q@G01<A500>30l04@lB01Cooooo000Kooooo`0601`J6`0=2``09B<T01XH6@091`P0
5A<D1P0?3@h01P0:20T03@/<00d;300;2@X03P`=01DC508040h?01404@l@00h<3@0=2``04A0>00l>
2`0>3@/03@`:00h=2`0>30d03`d>014?400=2`h03P`?00`:3@0M6b002`T>00d;3P0200l=400700h<
3`0?3A004@lB010>4@0E4aH05Q@G01<A500200l=40805ADE00/06QXJ01<C4`0=3@d04Q8B014A4@0=
3@d02PX:00h>3P0P82002PX;01<C5@0200l?4@0V00h>400<30h0410B01<C5@0G5aT03@d?01XJ700>
3Q00410B00T92@0=3@d04Q8@01hN70092@L02`/801HG4P0G618030d7028S6`0>3`L06a/F01@C3`0B
4@l04A0>018A3`0D4Q<05QHF01lQ800G61X02`/=00T=3P093A004QDK00d@6@0C5Qd04QDJ014D6@0C
5Q/201HI7P1@01HI7`0F6B005aXS01TL9P0Q8c008R@a02<U<@0Q92d07B0W01TL800F6Qd06alP01DI
6P0G6a`04QHG01PL7P0;4A40728P00lE500C61/03A8F00/B5P0A62004a`U01TQ;@0J8c806b@c01hV
=@0I7bl041HT01<I:00M8c404ALU00L=6@0G7BT05Q`W01LN:00I82X06R4Z01LP9`0N9bh062<Y01dX
;P0H8bT06RD[01@O9@0K9R`06B@Z01lZ<00I92X06RD[01<N900D8RD062LZ01/Z;@0J:Bh062L/01LV
:`0A82L08c4i01PV;`0_?DH06bTb01XW;`0R;C<082`b01h[<@0P;CD07R`c01XY<00H9Rl06BXb01`]
=@0N;cT072dg01X[<`0O<3L07Rlf01d^=@0L;C@201X[<P0T02Hg?P0N;cH08C8i02@e?00Q<ST0834h
024d>`0N<3X08S@n02<e@`0O<4008C920352DP0Q<d407Blk01`^>@0M<3L083<j01d^=@0K;3<07c0g
024b>@0O<3L0834h01l`=`0Q<ST07c0g01`]=00K;3<06b`g01h^?P0R<T808C5001`/>@0L;CL07c0h
0P0N<3@0900L;Rl06B/[01P[:@0I:RP05BDT01PX:00I:2X072/^02<`=P0K9bd06bH/049=D@0nBD`0
628S020Z:@0X<c<02A@F02@_<@0F8B<09C0b010K7`0H8bP04ahT01XU:`0W<ST07bTb01LQ:@0C7R80
5B0R01LR900E828051lQ01DP8P0D7b405R4S01TT9P8062<U01`06B@W01PU:`0A7RH0NXN?0;:oa`0b
?dL04b0X01`Y<@0E8RX08c0h07J3R`1]NX805b@/01/U;P0H8bT041/R00lI8P0B7B<05b4Y018L9@0A
728051lV01@N9`0@6b404Q`T01<J800A5QX04QLK0P0D6Ad03P0H7B405a`P010E6@0<4AD06QlS00dB
5P0D6Ad05a`P01<H70021`/04QLK01DJ7P17C5006b0T0`0F6al03P0B5a/051TM018G6P0A5aL04aTI
01HL700G7Ad05A/K010F5P0G7Ad06R0P01@J6P0A5aL041HF0P0D61T201<G60804QHG02@04aLH010D
5@0@51D04QHG014E5P0@51D04ALE01HL6P0C6AL04ALE010F500=4a404ALE00/A3`0>51804aTG01PN
700M8b404ADF018F5`0H71d03A4B018F5`011@H041@E018F5`0D61T0310A010D5@0L82405aPJ014B
500K71h04A8D01<D5P0E5QP5018C5@0A018D500A4a803a4@010B4@0E5aH06Q`K01PJ6@0?4A004Q@C
00/=300F61L02P`;018E4`0B5a<04AHB018G4`0A5Q800P0?4a802`0B5QD04aLH010D5@0>4Q<04QHG
01TI6@0G61<04a@?018C3P0C50l04a@>00804Q<=02@05AH>01HG3`0E5Ph04a@;014B300B4`d03a0;
01LG5`0@41003Ph@00d=3`0?3a403Ph=014A3`0D5A003Pl:01TI5`0G5aL06QXJ01TI6@0B4Q803Ph>
018B4P092@T051@D00/;2`0E5AD05QLF0<G6bP29SI005aPJ00H72@0<3@l06QXJ010@400?3`l2010?
3@04018?3@0D40d03@`:00l>308040l=01803`h<00d<2P0@3`d071/I00X91`0D4a403`h<014A4@07
20X03a0B00D6200L7Al03PlA00h>3P0:2PX03Pd;010?3@0?3P`2018>2`0401DD4P0C4Q004A0>010?
3@803`h<00L05A@B00/:200100002@P601LF500E51004Q8;008041080P0C4Pd0400B4@`071/G00/:
20020@0040l=018A3`0D4a4030/901@C4@0;2PP03@`:01@C4@0=30X03Pd;014@3P0?3P`2010?3@05
00`;2@0B3P/040`900h:1`0?2`P0200@30T00`0=30X040l=010?3@0300h=2`0A01LF500T8b4040l=
00`;2@0H5aD03Pd;014@300?3P`02PT801LF4P0L6aT030/9018A3@0@3`d04A0=014@300?3P`00P0>
3@T200d<200500h=2@0?3PX04A0<010?2`0=30P00P0:2@D01`0?3PX05QHB02l`:`2/[JP0KVmZ00/<
1`0B4`h00P0?40/0500=3PT02P/600X;1P0?40/071/G014@300;2PH03Pd9014@300R8Ad0AdI201LF
4P0920H05QDA00h=2@0;2PH04@d:01LC400M6AH05Q8?0P0@30T02P0F4Pl04@d:014=2P0B3P/03`/8
00h:1`0?3P`05A@B01HE4`0@3`d300l>300<00d<2P0<2`T03@`:014@3P0D4a404Q4?00H50`071P@0
40l=00d<2P0;2PP03`h<0P0>3@/01@0@3`d04A0>00l>300<2`T03@`:00803Pd;0P0@3`d08`0A40h0
3`h<01<B400<2`T03`h<00`;2@0F5A<06QTG00l>300;2PP04A0>00h=2`0=30X03`h<00`;2@0^;B/0
9bHT00h<3@0?2Ph04@`@00l=400A4Q@06a`N020T9@0G6a`010D7010@4P081PT07QTM00P31`0>30d0
3@/<00l=3P0B414040h?00803P`=0P0=2``00`0>30d03`d>010>3`0200h:2`803`/<0P0>2P/2010<
3@0400l;300>2P/03@T:00h:2@803PX70P0=2@H00`0<20L03@T8014=300201<?400300h:2`0=20`0
3@T900803PX702803`/800h:1`0=2@P04@d<01@@3`03000040`=018>3`0<1`/04@d=01HB4@050@00
3@X901hJ6@0E4A005Q8A00/71P091@@040`;00l;2P0B3Pd04Q0>00h=2`0[:RP040l=01XI5`0;2PP0
3`h<00T81P0C4Q005A@B020O7@061@@03`X>0P0D3a<02@0@2`l04PdA014<400B3A404@`@010;3`0>
2@d03@P<00`72`0200`:2`803P`=00<03@/<00`:2`0@3Pl00P0>30d0100K6AX0518C014?400<2Pd5
00d;3PH04@lB1P0>31401P030@H0=S@i00h<4@0=2a00518G00/93QCooooo000Kooooo`060040000B
4140JVQY02<Q8P0H5QL00`421P0@3Pl01`0;2@X03@/<00d;300<2P/03P`=01<A4P0?3@h00P0@3Pl2
00d;300>00l>300?3P/03Pd;00d<2P0>3@/03P`=00l=3P0=2``02`T<01DC5P0?3A002@L<018@5@0>
30l300l=4026010>4@0A3a8040hA01<A500D4QD04Q0C00l=400>30l0410@014A4@0D51@03Ph>00T9
2@0=3@d02PX:01DE5@0F5QH03Ph>01<C4`0;2``04A4C00d=3`0B4Q@0410B00T92`0>3Q004a<E014A
4`0C4aD061PJ00h>400D51D04Q8@01HF500D51807AdK00`<2P0?3`d05QHD010@3P0D51406a`G00l@
2`0D51005QDA01DD4P0D4a4051@B01DE5@0A4a802`d<01<D5P0G6a`06AdN01dQ900H6b403Q4H01DH
7P0A51T04ADH01@H6P0E6AX05QXK01HJ7P0F6Ah05QTP01PK900E5bH06A/Z028T<P0T9S807b8[01LJ
800E6A`061`M01@H6P0E6A`05APM01DI7@0N8bH05a`O01<H6`0Q9RX03a@J01<J8@0F7bP06b@]01lW
<`0H8C005Ah]01HP;@0D6RP04aTU01XP;@0L8S006Al[01lV<00H7bT05ahW01PO9`0I82P06b8Y01XS
:P0L9B`05B0V01dX;P0J9B/072L]01LR:00K9R`062<Y01`W;@0F8BL06RD[01@Q9`0@7R405bHY01/Z
;@0J:Bh06BP]01XY;P0J:C005bH^010N9`0[>D8072Xc01/Z<@0S;CH08Bdc028_=@0S<3P08Blg01d/
<`0L:S<201`]=@0401X[=@0I:S@06R/c01h_=`D07Rlf01009CHm02@e?00U=Sd093Dl020a>00O<3L0
8cHm02<e?`0W>D<09CM5020a@@0Q<T80?4eM02LiA`0R=400838m0P0N<CP0100P<CP07c0g020a>00P
<CP201d^=@<072dd00`07c0g02<d>`0O<3X072`k024a@00P<3d06b`f01X[=@0K;3@06R/b01T[;`0H
:R`201LY:@0K01LX9P0<71T05RHU01XZ:`0P;c80;S]1020/<P0?6R0092lc02Xe>00K9BL07RPY01PR
900951H07BPZ01XU9`0h@dD082/_01@O900C7R@05b8X01dX;`0H8R/06B<[01LR9P0G8R@062<U00<0
5b8T02T04A`N01DP8P0J9BL06RDW01/V:00P:bh082dc014N9P0Z=cl0?4UA00HC6`0E8RX07BXb01TV
;P0>6b<05B8Z01`Y<@0I9Rh07RPa01@N9`0E7bP072H`020Z<`0E7bT04adW01@N9`0E7bP041XT00`F
7`0>5b407B@Z018G6`0F6al07R<W01lT:00N8bL03A8F014F6P0I7R80<CHj01@I7@0201HK7`0L010E
6@093Q806AhR01<H700J7b<05a`P01@I7@0F6al05AXN014F6P0C61/05Q/N01HL700G7Ad06AlO01LM
7@0C6AT04ALG01HL700G7Ad04ALG01HL700D6QX05QXK01DI6P0D61T05ATJ01@H6@804aLH0P0=4A80
2P0B5QL05QXK01HJ6`0A5aD05Q`J01DK6@0A5aD03Q@B00`B400A5aD200dC4@0:014G5@0C6AL051XH
014E5P0>4Q<04QHG01@H6@0H71d04ADF018F5`805QXK00T02@d>01/O800f>S/06a`N01<D5P0O8280
4A8D00h?4@0D5AL01@0B4aD0<@0B4a@04A<B010B4@0A4a805QPG01TK6P0J71/051HE00T;2P0B51<0
71hM00lA400C5QD03a@@00lC4P0C5aD05ATH01@H5`0A5A@03a<B010D4`0>4Q803A4@00lC500C5A@0
4Q<>010A300?40/0414<010A2`0A4P`04a@>01HG3`0G61005AH>014C200<3@L04a@>01DF4@0B4Q80
20P801@D5P0O7b404Q8D01<C4P0A4@l03Pl:01HG4P0L71X00P0I6AT03`0F5QH0410@00d=3@0@4100
30`<018B4P0;2`/04a<C01HG5P0Y:Rh08BDX00`=3`0L7Al051DG00h>3P0200l?3`05010?3@0A40h0
4a4>01DA3P0>3@/0100@3`d0100>3@/010<1014@3P0920H2014@3P0>01@C4@0>3Ph04A8D00d?3P09
2@/04A4A018A3`0=30X04Q4?01DA3P0C3``05A4>01TE4P0D4a42014@3P0:010?3@0?3P`04A0>05IE
D`0M71X03@`:00X91`081`H04a8>010?2@803Ph600D03`h9010?2P0@3`X02PT500X91`02010?3@0:
00@30@0?3P`04Q4?00l>300920H03Pd;014@3P0<2`T04Q4?01DD4P804Q4?00@040l=00`;2@0E4@h0
4Ph;0P0?2`P00`0@30T04@d:010<2@05010<2@0H00h=2`0<2`T02`X800d<2P0A40h04Q4?010?3@01
000030/902LV900D4a402`X800L6100C4A802PT800h=2`0100004Q0@010?3@0>30d03`h=010?3@0>
30d03@`90P0=30P200h=2@0500d<200@3`/03@`800/:1P0?3PX00P0@3`/01P0F5Q80ADI10>?Tg`28
RH@01PL2014B3@80414<01L03Pl:00/<1`0<3@P0414<01TH500C4Ph04A0<010?2`0=30P04Q4=01PG
4`040`003`h:01<B3P0920@030/700L3000=2@H0510=014=2P0?2`P040`901HB3`02014=2P0901<?
300?2`P03@T600D40P0;2PP03Pd;00`;2@0@3`d04A0>00803`h<00/03Pd;00l>300A40h04a8@01DD
4P0?3P`06APF00`;2@0920H04A0>00l>300200h=2`03010?3@0A40h03`h<008040l=0P0>3@/0900=
30X030/900<2000C4Q003`h<00@30@0@3`d020L500d<2P0B4@l03@`:00/:200@3`d03`h<00X91`0>
3@/020L502d/:P0Z:BL04Q4?010;3`0@3Q403Ph@00h?4@0C5aP061`M014E5P010P@04Q<E00X82`0c
;S803PT=010>3`0>30d03@/<00h<3@803`d>00L03P`=00d;300=2``03P`=00l=3P0@3Pl04@d>00<0
4Ph?0P0@30d00`0?2``040`=010<3@02014=3P05014=2`0A3@X040`9010<2@0>2PL00P0>2PT01`0?
2`X04@d>010<3@0>2P/03PT=00h:2@0=2@H00`0>2PL09@0>2PT02@D501<?3P0=2@X030P900<0000>
2@d03PX;01LC4P0?2`X05A4@00X61@0300004`l>00D1000;1`H0<Bd/02/W9P0@30/02`T8014@3P0`
;bd05A@B01dL6P0@3`d02PT702HU8`0h=cD00@0000L6100@3`d040/?01D@500D3a<040/?014<400@
2`l00`0A31001@0@2`l03`X>00l:3P0<2P/03@/<00<03P`=00`03@/<010>3`0@3Pl030X;01HD5@0B
41404a4B01<A500@3Q403@/>00l=400A3a8700l=40H03P`A00H0108700`:3`0A3a@01P@9014?500@
3Q<Dooooo`006oooool200d;3004024O80030@804a4B014?40L03`d>01X040h?00l=3P0>30d03P`=
00l=3P0<2P/040h?00d;300<2P/03@/<00d<2P0?3P/03Pd;00d<2P0>3@/03P`=00l=3P0E4a@01P@7
018@4`0I5aX03P`A01PF6`0D4QD04@lB010>4@<04@lB00L040hA00h<3`0?3A0040hA00h<3`0=2`h0
4A4A00804a<C05P04A4A00l?3`0A4A403`l?01dM7@0Q8B404A4A00d=3@0D51D04A4C00d=3`0I6A/0
61PJ00l?4@0G5aT0410B00X:300F5QP030`>014A4`0>3`d03a0;01@E400>3`X07AhI00l?3@0@40h0
5aLH00d=3P0F5AP02@T;01@C5P0C4a804aD@01DF500F61D051LD018E500B5QD051TH03]0@@16C4`0
5Q`L01@I700I7B804QDL01LJ7`0B5QP04QHF01PL6@0C5aD05ATG01HJ6@0C5aT051LK01XN900M7S00
71db01XL;@0I6bL06A`U01XM8`0H72005a/N01TL800H6b408B@[01PK8`0E6R407R<X01HJ8P0F7B@0
7bH^01XQ:P0H8BX07BH_01hX<P0G8Bd04Q`X01@N:@0F72L06R4[01hU;`0G7BP05ahW028Y<00C6R40
5ahU0P0K8RL02@0J8BD05b4T02@]<`0I92X082/a01/V;00J9B/06B@Z01dX;P0201LR:00D01<N900N
:Bl07R/a01DS9P0K:Rd07Rd`01`[<00H9b`05bH[01TX;`0I:3006bTb01`Z<`0O;CH082lg020Z<`0O
:c808Bhf02<`>00S<CT2020^=`0901//=P0I:S@06R/e01l`>P0Q<S/06R/c01//<`0L;C@07c0g0080
834h01L08cDi02i0A00/?T8093Hj028d>00S=3X07S4h01la>`0R=3h08C=1024b@P0U=TH0;3e=020b
@00Q<cl08C<n01`_=P0L;cD06R/a01d_<`0L;S807Blc01h`=00201d_<`0T01X/<00H:Rh07Blc02Dg
>`0S=3`0830m02@d@@0R<Sh072dg01`]=P0J:c805RL^01LY;@0H:Rh06R`_01/]<00L;Bd052@Q01PX
9`0F9RL052<V01/X;P0E8BL06RD[01TT:P0H8RH04adO010J6`0D7b004ahP010K7@0I92L05b8V01hY
;@0G8RL05b8X0P0G8BX0:@0E7bP06B@[01DS9`0D8RD04b4T01@R9@0E8bH0528U010N8@0C8B@05bDX
01HT9`0E8bH062HY01<P9`0F8b/072Ta00hK8`0L:C40524Y01/X;P0H9B/06BH/01HS:@0I9R`04AhU
01/U;`0=5b805AlZ014K9`0G8B`05R0[018L:00D7RT05Al[01HP;00H8Rd05b4/01LN900I7R805Q/O
00804aPL01P051TM014F6P0F6al07B8V034f>P0G72005Q/O01`Q9@0?51P06QlS00`A5@0D6Ad03a@H
01@I7@0@5AT051TM01HK7`0C61`04QLJ01@I700C6AT05A/K01LM7@0F71`201<I6@0601DK6`0:4100
4QPH01HL700D6QX051PI0P0A5AH0100E6AX051PI014E5P0B5QL201DI6P0:01<G600@51D03Q<D014I
5P0A6QL04a`I00lH5@0<5A803QLD010I5P804AXG00`04a`I014J5`0>5Q<04aLH00lC500<41405ATJ
00`@4@0C5aP051PI00lC500A5AH201<G600701LK700@4A<06a`N030a<`0R8bD04Q<E014B5005018C
5@05014B4`0@4Q404Q@C01@F5@0C5A@00P0B51<00`0F61L02@/:01@F5@02018D4`0401@G5`0?4a<0
3A4B00hB4`8041@D00L04ADD014F4`0A5Q<041DB010E4@0@518041<>00804A8=01P04A8<00l@2P0A
4P`04A8;018C2`0D5@d051H;01<E2P0A4`P051D?014B300=3PT05ADE010@400N7R005QHH010@4P0G
5aH02@T700l@2`0E5Q404Q8@00l?3`0>3Ph2010@400C01DE5@0?3`l04a<C018B4P0;2`/03`l?01DF
5P0=3Q804aLJ00d>400H6A/03PlA018B4P0?3`l0410@018A3`0C4Q004a4>01@@3@06014@3P04010?
3@0E51804a8@014@3P8040l=01@04a<B00X9200G5Q@03`h=014?300A3@X040`901@@300D3`/04`h:
01D@300H510040h;00`;2@0B4@l04a8@00l>300D4a407QdK00/:20803Pd;01H071/I00`;2@0A40X0
4A49010@200?3PT040l:014@2`0@3`/01`H4018A3`0>3@/08R4O05=BD00Q81h02PT700h=2`0B4@l0
3Pd;014@3P0C4Q0051<A0P0@3`d0200>3@/02`X801PD4@0D40d04Ph;014=2P0B3P/04`l<1P0@30T0
6P0=30X030/9014@3P0C4Q0040l=00h=2`0F5A<061LE010?3@0?3P`040l=00h<3@0@3Q004a4D01`J
702a[k40G5YM018@4P0>30h03P`?010>4@0B41804Q0C00l=3@0=30P03`h:100@3`/02P081`<02@P4
01XI5@0J6AD04A0<010@300;30P0>S/f02@U800G61<200X;1P0300`=200?40/03Pl:00803@h902/0
40l;00h=2@0?3PX03`h:00h=2@0@3`/05A@@010?2`0?3PX01@@100`;1`0@3`/03`/8010<2@0A3@X0
3PX700l;200C3``04Ph;00l;200@30T04`l<00l;200=2@H040h>01<A4P0A40h03@`:00h=2`0=30X0
3`h<014@3@0C4Ph04Q4=014@300>3@T020L500l>300H5aD02PT7010?3@0:2@L03@`:008030/900<0
3Pd;00l>300=30X01P0>3@/01017AT@040l=01<B400G5Q@2010?3@0:00P71@0?3P`04A0>010?3@0>
3@/02`X8014@3P0?3P`010<2010?3@803`h<01<04PhA014?4P0>3Q003@h@01<G600I7Ah03Q8C00H7
2@0D5AL03`hA03<^<P0D3a<0518C014?400?3@h03@/<00l=3P0@3Pl03P`=00803@/<00@03P`=00l=
3P0@3Pl040`=0`0A3@h2010<3@0901HB4`0E4A804`l@014=3P0?2``03`/900l<1`0@3@P04@d90080
4@d:00P04@d;014=300A3@h03`/<018>3`0F4Q<05Q<@014>208040d801P04@h9014=2P0A3@/030P7
018>3`0<1`X04PdA010;3`0?2``0510?00`81`0@30/02PH602TU901?BdX06ADD00`8200D40l04Ph=
00d9200<2@P030/901<B400:2@L200/:200301/J600510<04A0?008051<A00l030/900h9300B3A40
4PdA00l:3P0@2`l03`X>00h93@0?2Ph040/?014<400B3A404`hB00h<3@0?3@h00`0@3Pl200l=3P0:
018@4@0;2@X04Q0A010>3`0B41405A<F010>4@0=2`h040hA018@4`L040hA1P0>3140100H5Q/03@/@
00h<4@0=2a0200l=4QCooooo000Kooooo`0600l=3P0B41401@<400X82@0A3a004Q0A1P0>30d300d;
300500h<3@0?3@h03@/<00`:2`0B41400P0=2``0700>30d030/900l>2`0>3@/03@`:00h=2`0>30d0
3`d>00T7200<2Pd03P`?01/I700=2a001P@901LE600A3a803`d@010>4@0?3A003@/>00l=400>30l0
40hA018@4`0=2`h02PP;00d=3@0@410200l?3`804A4A01l05ADE014A4@0:2PX03`l?014A4@0?3a00
3`hC00`;400C4QL04A0E01<B5`0M72403`hC00h=4P0@3a@05A@I030_=00D51804a@>01@E3`0_<2X0
Ce1;024Q7`0:2P/04a<E010?500J6Al0F5MM01/J800D5AH04AH@00<04AHB03h04ADD00lE4`0>5180
4QPH01PN7@084A005alQ02L^<P0A51/05a/O010D4`0@5A406AhG01LL5P0H7AL061dH01DI600H71d0
8bH/03DfBP0_;dL08B8e01HH9`0D5R805QTP01`O900I72407B0U01/N9@0[;SL06adY02X^>@0L82T0
5ahX01PO:@0I82X08b`e01@L9`0G7bX0628/01DO:@0D7RP05b4[01@K9@0G7RH06R4Y01/R:P0L8bT0
6b8X01HM8`0L92L07bLY01dU9`0L92H072HX034j?`0P:c409C0f01lZ<00M:2h07bX`02<^=08072L]
01`062<Y02<^=00R;cD07bd`020_<P0S<SD08c8g01d/<@0F9BX03ahU028a>@0>72D09cDn055OJ00`
?TL08R`e01l[<`0N:c<082de028_>00P;SL07bdf01LX<P0H:C<07Rhk024a?P0P<C/07Rlg0P0O<3L0
1P0P<CP0838f020b=P0]?d<0<TA802Xl@0808C<e01<0838f020c>@0N<3X07c4k01la?`0V=dL0;Sm?
01X[>`0I:cT07Blk01d_>P0J;C@07C0f02Lh?P0Y>cl08C<g01`^<P0J;3005RP/00807Blc02@06bda
01T[;`0K;C4072de01d^>00O<3X072dg01LX<00H:C405bP`01DV;@0G:2l06R/b01/]<@0J;3006BXY
01/[:00H:2L06BPY01TX:`0G92X06bL^01lY<P084aT05AlT02<];`0:51D04ahO01dX:P0F8BD04QdQ
03e8C00]>3h04QdS01@O9@0F82T201PR:`0801HP:00K:2h062HY01DS9P0H9RT06BLZ01PV:@0G9BP2
01HT9`0d01LU:00F92L04b4T01LT;00K:3007BXb01LT;00J9bl082dc00lL8P0E8RP04QlU00XH6`0B
82<0=D=704MAG@0L9C@051d/028[>P0g@4l09c0o01<L:`0D7B`04a`[01XS<P0Q:ST06b@a028Y;`0K
82@05Q/O02X_<`0e>Sh051TM018G6`0@5AT03Q<G014F6P0?51P03A8F01DJ7P0=4QH06b0T01XO8`0E
6Qh06AhR028W:`0C61`04QLK01PM8@0I7R805a`O018G6P8041HF01P04QPH01<I6@0B61P051XJ02@Z
:P0;4A40728R014G5`0C6AT05QXK014E5P0B5QL05a/L01HJ6`0B5QL05ATJ01HJ6`0C5aP04ADF01/O
800R:2P04APF00hG500A6QL200dF4`0401<L6@0@6AH04Q/H010I5P805AhK00T041TF00`@4@0D61T0
4ADF01dQ8P072``06AdN00`@4@0I7Ah00P0D61T0200G6a`04aLH00`=3`0I6Q`09RLY01dN800E5QP0
3a0B1@0B4aD00`0A4a<04A<B018D4`02018D4`0;014C4P0@4Q406A/J01<E500F61L02`d<01/M700J
7Al07B8U01DJ7@0?51L00P0?5AD02`0@5Q@04ALC010F4P0A614041L@00lF3`0?4`d04Q<>01DF4@0D
5A004Q<=008051D=01T04149010B1`0@4PL04Q@901@F2`0=3PP03Pl901<D3`0J6QX03Ph>01LG6@0[
:bd02@T;01dM700K6aT0414<01@E400G5aD04Q8B010@400?3`l030`<00l?3`092@T05ADE00804a<C
00X061PH02DV9P0G61`06AdP010A4`0O828051DG014A4@0@41004A4A0P0C4Q000`0C40h04Ph;014@
3P04010?3@0<014@3P0=30X030/9014@3P0<2`T040l=014@3P0C4Q0040`901<?300L61D05Q4>0P0D
3`/00`0B30P04P/501@=1`0201D>200K01DA3P0@3`d06QTG01/J600B4@l05QDC00/:200F5A<051<A
014@3P11@3h09RDQ018A2`0C4`/04A4900h=200?3PT04Q4<00X91@0:2@L03`h<00d<2P0;2PP08B0N
01@C4@0:2@L02`X800<03Pd;0P0@3`d0100<2`T040l=01DD4P0C4Q0201<?3003018>2`0A3@X040`9
00L040`901T051<A00X91`0D4a407A`J01LF500>3@/02@P6018A3`0?3P`03Pd;01HE4`0@3Q000`46
014?500`;S<0<S0e01hL8@0F51T03`dB00h<4@0@3Q<04@lD010>4`0@3Pl040l;00803`h:0P0>3@T0
400B4@d02`X600L60P0<2`L02PT500d<200A4@d05aPC01`M600C50l030d8014B3@082@@02``700l@
2`0>3`X200d>2@0401DD400D4`l040l;00`;1`803@`800<03`h:00L60P0@3`/00P0C4Ph04@0:2@H0
40`900l;200=2@H02PH300/7100>2PL040`900d91P0A3@X05A4>018>2`0@30T02PP900`:2`0;2@X0
30/9008040l=00@03@`:00l>2`0@3`/040l;0P0A40`01`0A40h03`h<01@C4@0@3`d03Pd;00D40P0>
3@/00P0=30X01@0?3P`040l=00h=2`0<2`T03@`:00803Pd;0P0@3`d02P1jNGL07ahL00l>300@3`d0
1PD3014@3P0=30P04A0<018A3@0@3`/200/:1P0I00`;1`0?3PX03`h:010?2`0=30P061LE01<?4@0C
4A@0410B00h?4@0A5AH05QXK00P<3@082@/02P/=00`;3P0B3A403@P<01DC500D4Q<040h?00/92P0<
2P/03`d>00h<3@0200d;300600h<3@0?3@h040h?00h:2`0?2``040`=0`0A3@h01P0E4A804`l@018>
3`0?2``03@T:00h:20803``700@040`8010<2@0@30T04@d;0P0A3@`04P0?2`/04@d>01DA4P0G4a00
514:018?200A3PP040d8014=2P0B3P`01`<201DA4P0@30h091lS00/62P0a;Bh03`/:00@000804@d<
01L03PX9010<2`0>2PT03`/:00d9200:1PD03PX9014?300=30P03`h:010?2`0B4@d040l;092?R`18
Ad<02`X600l>2P0A40`04Q4>00/7200@2`l04@`@00h93@02010;3`803PT=00H03`X>010;3`0@2`l0
4@`@00d;300>30d300l=3P0=00h<3@0<2P/04a4B00h<3@0A3a003P`=00d;300@3Q403P`?00d;3P0>
30l03`d@00h<3`06010>4@0300h<4@0>2a803P/B00<03P/B00H01`@;00l<4`0710/030T@01LD6`0>
2a8Dooooo`006oooool01P0:20/03P`=00`:2`0>30d02`T:00d;30H03`d>00D02@L800X82@0<2P/0
3P`=00l=3P0200d;300801<A4P0>30d03P`=010>3`0=2``03`h<00h=2`0=30X200h<3@1W00l=3P0@
3Pl061HI01@B5@0<2Pd02@L<01`J7`0H5QX040hA00d;3P0>30l03@/>00/9300>30h040hA01@B4`0E
4a@03@/<00P61`0=3Ph0418A00lA400@4Q804a@F01@E5`1VIfT0;Rla01<D5P0@4A<04A8D01<B5P0D
4aP04a8H01<B5`0>3A806QTN028Q9@0>3Q004a<E00h>400U9BD0Bd]=010@3@0@4@/04a@>010A2`0T
92804A4?01@D5@0<30h03PdB02HU:`2YZ:h081lU014A4`0D6AD04QHE014E500B5QD051PG01<H5`0H
7Q`020h>01TO7`0M8b<010d<01<G6`0A51T05QXL00lC4P0>4`l05a`G014F400C61804QLC00hB4@0B
5QL082@X01XL:`0J6bl06a`]01TK:00G6BD05QTQ01/N9@0G6Ql071lV01XM9P0/;cP06A/W01/O:P0J
7RT06b4[01LK9P0J8B/0620Z01HO:00G82T05QlY01<M9`0C7BH05R0Y01HM9@0201`S:@0V01<J800F
7B807BDX01<K7P0H82806B4S01LO8@0H828072@W02Xc>00H8RP07RT]01XS:00J92P07bX^01hW;00H
8RH06B@V01@N800K9RP06RDW01LU:00G9RT072/^01l^<`0K:Rl04R4V02Dd>@0eA4X05B@[06=bN@2f
`lH0NhR@02Hc>`0S;cL082de024^=P0R;cP2024_>00G01XX<`0J:cD0830j01h/>@0H:C<07Bhf01`]
=@0K;3@06R/c01TZ<@0I:bl072hb01d_<`0I:bl07S0b02Hh>P0U=c/08cHl01ha>00L;SP06R`g024c
@@0[?D/00P0O<Cl02`0R=4007S0k01`^>00P<cX07c0h02@e?@0N;cH06R/b01/]<@0H:Rh06B/_0080
7S0d02d06R/b01TZ<@0K;3@08C8j028c>`0N;cL06R/b01`]=@0H:C0052D/01HW;P0J:S405bP_01PW
;00E9BD07RlY01LV8@0F9B@05bDU00hL7@0B7b808B`b01DP9P0D7R@05QlT00`E6P0H8BH06B@X01lX
;@0J92T0XJb`06efN`0L9R/05R4U01DN9@0D7RD05b8X01DO9P0K9R`05B<V018P8`0E8bH05bDX01DS
9P0J:2/00P0G9BP0=@0L:Rd07B/^01TW:P0D8BL082dc01PT:P0L9bd03Q/Q02Hc=P0G8RH072X]01XV
:P0C7R802ALH01/V:`0`>T@03QLV00lG9@0@62D082Pe01XR;`0H82d05Qh[014K9`0G8Bd072Pd018M
:00<4a/05a`R00dB600D6Al082D[00H;3`0A5QX04aPL01@I7@0@5AT061dQ010E6@0<4AL0728X010G
7@0@5A/05Q`Q069ZK@0^<cL05QdP00lG6P0I7R80728V01/P8`0I7R405A/K00804ALG03804QPH010F
5P0G7Ad0<SPh01@J6P0V;2`04ALG01HL700I7al05AXJ01DK6`0L8B406QhO01HL700?51@03Q8C00`B
4P0P9BD0C51A06AZJP0B61H03aDC014G5@0=5Q@03QLF01DN7@0B6aX04AXI00`E4P0B61H051XH00lE
4`0@51D05a/L00hB4`0J7Ql00PH701XN7`0A5AH020`=00L;300Y;Bh0<cLh020T9@0E5QP04A8D00l@
4P0:2`d04Q<E010A4`D04Q<E0P0B51<2014C4P0I018D4`0C5A@04A<B01PJ6@0E5aH051HE00P:2@0M
7ah05aXK01hS9P0E6A`03A8E00`B4P0?4a@041DB00lF3`0?50h03aD?00hE3@0>4``03A4:018C3@0E
5Q4051D?018C3@0201@E3@0J014B2P0?4@H04187018D2@0F60h03@h801@E400C510020P600D51@10
@400N7Qj028R8P0d=3<0>SXh00T:1@0E5Q40410>00h>300A4@l051@D018B4P0D51@03Ph>01XJ6P0C
4a<200d=3@0?01PH60082@/0414C00P92P0B4aD01`T800d=3@0A4A404Q8B01@C4@0C4Q004A0=00l>
2P0@3`d03`h<00803Pd;01H03`h<010?3@0C4Q003`h<01<B400;2PP03Pd;00l>300?2`P04`l<00D1
000G4a00510=018?2P0I51404`h:014<200D3`/05a4<01<>2P0A3@X030/90P0G5Q@06@0;2PP03Pd;
00`;2@0@3`d06APF00d<2P0W9R@04Q4=00l?200A4@T03`l700/:1@0<2`H03`h901DD400A40h030/9
01DD4P0<2`T02@P600d<2P0D4a403@`:010?3@0F5A<00`0A40h01@0>3@/05A@B01dL6P0M71X040`9
00<04@d:01`03`/800h:1`0@30T040`900h=2@0?3@T040`900h=2@0_;R`04A0>00d<2P0D4a4040l=
00/:200F5A<03Pd;018A3`0G5Q@03@`:00h<300G5AP04Q0C014?4P040PD09bDX00T72P0>30l030X=
0P0=2`h04P0;2@`03`d<018A300@3`/03@`800`;1P0;2PH02`X500h=200J6AD08b8N00l>2@081`<0
3@d800h?2P051P40414<00l@2`8030d801403Pl:010A300?40/03a0;014B3@0:2@D03Pd9014@300B
4@d04A0<00d<200F5A402PT501DD400?3PX01PD100d<200400h:1`0K00l;200B3P/040`900h:1`0B
3P/05a<@01@@3@0B3P/03`h<014?400>30d03@`:014@3P0?3P`03@`:00`;200<2`L03Pd9018A3@0E
510020P600/;2@0C4a403Ph<00T9200G5Q@03`h<00803Pd;00<040l=014@3P0?3P`00P0@3`d200h=
2`0W00d<2P0<2`T03@`:00/:200@3`d03@`:014@3P0920H03@`:00h=2P0?3PX03@`:00/:1`0=30P0
2`X800l>2`0C4Ph03Pd:00<2000920H04PlA01@B5@0C4aD03a0B010A4`0C51H02``>00h?4@0<30h0
4a8D00P62@0D3a<05A<D01@B4`0@3Pl02PP900/92P0=2``03P`=00803@/<00H03P`=00l=3P0@3Pl0
40`=014=3P0B3Pl301@@4@0300d92P0>2P/03`/<008040`=00<04Ph<018>2`0B3P/00P0A3@X09@0A
3@`03`/:00h:2@0?2`X03PX:00d92P0>2P/04`l=01@A300B3`X040`800l;200@30T040`;01HB4@09
1@H04`lA0:2KW`0f<CD03PX:01@@3`0I5A@03PX900/71P0B3Pd04@d<018>3@0>2PT030P701@@3`0B
3Pd02`X700D4000>3@T03@`801<B3P0<2`L00P0J6AD0200:2@H02PT501DD400<2`P02`L8010;3`0A
31003`X>0P0A310600l:3P0400`:3@0=2``03P`=00h<3@803@/<00H02PP901<A4P0?3@h04@l@00h<
3@0;2@X600l=40D03@/>00d03@/@00h<4@0>31803P`A00h;4P0>31803P`A00l<4`0:1`d07adR014>
5@0R82H05A<H01Cooooo000Kooooo`09010?500;2`h05ADG00H6200<30d020P800h>3P0=3@`03Ph<
00803`l=00<02@X600`:2`0>30d00P0?3@h0200>30d030X;01@B4`0?3@h04@l@00h<3@0<2P/03`d>
0`0?3@l300l=400<00h<3`0F51L02PP;01<A500@3Q406QPL01LE6P0@3Q<04@lD010>4@0>30l040h@
0P0@3`h06@0@3`d03`h;00h=2@0=3PT03a8=01<H500A5Q@04ALI018I7P0V;c<0^/;903e3BP0A5Q`0
3a<I014D600@41H051<J01@C6`0C4QP05aHK01DE5`0A4A40410?010@3@0@4@d00P0@4@X0400A4P`0
3a0;010A300F5Q<0410>01hN700A4A0051@D01HF5`0H5aX05aHJ01DE600D5AP05QLK01<D600D5AT2
01@E600U014C5@0P8b@09BPY01@G5`0D5aH07R4P020Q900?41@0824U020Q900B4aH05aPK01TJ6`0G
61T051HF020Q8`0X:B/06ahO018E6P0B5ad05Q/Q01TN9@0I7BD05AXP01LL8`0E6R405a/T01HJ900B
5R405ATT01HI8P0I72D06QhW01HI8P0E6B806QlX01TP:00201PO9`0901LP:00I8RT072D/01<I7@0M
8RH05Q/N01dR9@0J7b<05AXM00806b0S01@05a`O01TN8@0N8bH05QdO01dU:00J8bH05b0S01XR9@0M
9RL072DU01PQ7`0J8b405AlJ01PQ7@0N:280628P024]<00K:2h0524W01h/;`806bT/00T06bT[02Pf
=`0P;Rl05R@T04iLG00e@dD06bP`01dZ<`0P;CH00`0R;cP02`0P;CH07R/d01d[=00P;CH08Rli028`
>P0N;SX0830l01l`>`0N;cP072de008072dd08008cDi028d>00U=c/093Hh01la<`0O<cH07C8f01`a
=@0M<SH07S8h01lc>@0K;cL07c<l02<g@@0L<3/05b/f01d_?00P;Sl082dn01d[>@0J:3806bXa01d/
<@0J:B`07B`a01h]=00I9c007bdg01d^=@0L;c@07c8g01la=P0L;S8072dc01TY;P0E92T05bD[01XW
;@0I9b`06BH/01LU8`0D8aT04b0G01@R6@0G91`05R<L01@P700G8R<06bHY01DP9`0@6R@051hY01dU
<@0V;SH08RTa01/S:00W<38092`^01XS900E7al07BDV01PQ8`0A6Q`07BHZ01`V;@0D7bD05B0V010K
8@0E82H06RD[01TT:P0O:S006bH/01@O9@0N:Bl05R4V01hY:`0K9RL06B<U01/U9P0J9BH05b8S01dW
:@0L9RP06B<T01LQ8`0H8b<06R@V02H_>@0Q:CD061l[01HI9@0G6RD05aXT01DI8@0D6b8051dS018P
900@8B@0428V01HO:00I7BT04ADP01LK9@0I7BL0314H01<H7P0E6Ql04AHJ018G6P0E6Qd04ALK018I
8@0Q:C804AXQ01PP:00D6b80IFic04M?E@0E7R404Q`N01TR900@6Q`092`^01DK700P9RH04QPH01XP
80804aTI0P0E6a/0<P0A5aL051XJ01`R8P0K8B405Q`O00hE5`0B6Q`04aXM010F6@0A6A/03QHH03@j
?@0F7R004QTL07AjO@1JH6005ALE00`?3P0>4Q405Q/M00TA4`0A6A/03ADH014F6@0D6QX05aTI01PI
5P0I6QP051HE00/=300g>CP0=3He01@F5@0@4Q405QPG00/=300D5QD07b4P01`N7@0@4Q404A<B01<E
500?4A004aDD00lA400C5A@04Q@C014C4P0B51<051HE0P0C5A@0900E5a@051HC010B3`0?4@h04A<@
01@F4`0K7AX05aTF01<E4P0@4Pl030h;01<E5P0B5AP04A8E010B4`0@4a804aDC020S7`0J7AP03@l9
00hB2`0@50d041<;018D2`0G6100414:01@E3@0<3@D05aP@02h_9`0E5Ph0414901<D300B4`/04A8:
01HG4P8051@B01L04Q8@00H6100];B/0De=B02@T8P0=3@/061PF00h>300O7a`0=cPc02X[9@0C50l0
3Ph;010A3@0>3P`06QXH04I6A00[:b/03`l?01@D500?3`l0410?014A4002018B4@07010@3P0?3`d0
4A4?00d=2`0B4Q003@d;018B400=014@3P0301<B400B4@l040l=008040l=00X04A0=01@B400A3P`0
514?01TF500E4Q002PP501DD4P0?3P`0@3lm0P0A40h02@0C4Q005A@B00l>300@3`d04a8@018A3`0?
3PX04Q8;018B2P02014A2@0E010?2P0?3PT03`h:01@C3`0=30P0;Rd[00H50`0C4Q005QDC024P7P0D
4a403Pd;00`;2@0C4Q005A@B02DT8P0=30X03`h<00P71P0A40h03PX700804`l<00h04@d:00h=2@0@
3`/04A0<00`<200=3PT02`/701DE4@0;30P07AdL018B4P092@T03Ph>014@3P8040l=01H040`901DA
3P0O6aP071PD014>2P0?3PX04A0<010?2`0?3PT040l;01<B3@0>3@T030/7010?2`0>3@T030/700h<
1`0?30D03``6010=1`0A3PL04@h80P0A3PL2014>2007014>1`0@3@L03Ph900h?2P0?40d061TD014B
3@0300d>2@<03Pl:03L03a0;00h;200B3P/04Ph;010<2@0C3``04Ph;014=2P0<20D03`/801DA3P0B
3P/040`901<B3P0>3@T03@`800P71@0@3`/04A0<00h=2@0=30P03Pd9010?2`0A40`03`h:010?3@0=
30X02`X800l>300B4@l03`h<00h=2`0?3P`040l=01PG5@0K6QP02`/900/=300:3@`03A0?00lA400<
3@d030d<00`<300>3Ph03`l?010>3`0?3@h03@/<00P61`0f=3D04@l@00/92P0?3@h03@/<00803P`=
0P0?3@h2014?400K00`:2`0>30`02PT8010>3`0>30`0518B00l=3P0?3@d040l>018@400>30d02`T:
00h<3@0;2@X030X;00h=3@0<2`/02@P900h=3@0<2`/030X;00l=3P0@3Pl03`d>010>3`0A3a000P41
00803P`=00<04a4B00l=3P0?3@h00P0>30d02@0=2``02PP900l;300D41402`L801PD5@0N6Q/04@d>
010<3@02014=3P08010<3@0>2P/03`/;00l;2`0A3@d03PX:014=3@0C3a0200d92P0G00h:2`0@30d0
4@d>014=3P0K61T0<2h^00h<3@0_;Bd04Q4@00h=300<2P/061HG00D3100B4140>3Hg01hL7@0;2@T0
3`h:014@300?3PX030/700h=2@0?3PX00P0>3@T0100?3PX040l;010?2`0=3@X200/;2@0F01PH5P0B
4Q003@d;014A3`092@P05ADC00h>300@40h02PX800l=3P0=2``03`d>014?400@3Pl03@/>010>4@0:
20/0;B/`018@5@0:20d0518G00l=4@D03`d@0P0>30l03`0=2`h040hA018@4`0@3Q403`d>018@4@0D
4Q<04@l@010>400<2Pd03`d@00d;3`0=2a003`dB014>5002010>4`05010>4@0=2`h02`T=010>4P0:
20/00P0?3A40100A3a8030X>01DC5P0@3Q4Dooooo`006oooool03P0<2a0020P;00/;3@0?3a405aLH
01HF5P0>3Ph05QHE0000000A4@l05ADB02`]:00=2``03`d>0P0@3Pl0200?3@h03@/<01LE5P0;2@X0
40h?00`:2`081PL0518C1P0?3A003@0>30l02@L:010>4@061@L06aTL010>4@0H5Q/040hC018@5@0A
3a8040h?01<A4P0@3Pl00P0@3`d3014@300700L80`0M7a`01PX900`C500<4aT03aHL01dT;00200<8
3P0S010B600?41D03`hE014@600@3aD030/A01DD6@0D51H03Ph>00l?3@0?40/0414<014B300A4PX0
6Q/E06AUH00D5A003`l<00`<2P0410@05aLG01<C4`0@41803`lA018B500E5AL061TL00`=4P0I6Ql0
5QLK02@U:@0A4QH04Q<F01TJ700O8B000P0G6AP0700I6aX05aTI00`=3`0T9BL0;2d_020Q8`0L7Al0
6AXL01TK6P0H6QT06adL01hP7`0G6QX051PK01@I7@0G72005a`R01DJ800B5ad061`U01HJ8`0H72D0
5a/V01@H8`0G6bH06ahW01`O:00K7RL201HI8P0;01/O:00I82P05ahV01<J8P0B6b805AhU01/T:P0L
8BD082DX01hS9P0H7B000P0J7b805P0K82<06QlR018G6P0S:2/04aPK01`Q900K8bH05alR01PP8`0K
8bD06R<S01HO7P0E7Q/0624N01PQ700J8ah072DP01HQ7@0@6ad08Rle00TF700O;C02028`<`0<01`Z
:`0M:b/06bTY01PV9P0K:BT05bDV01DR:P0K:3408Rlh02Db>`0T<CX08Bhg0`0S<3T0:00Q;SL07BXc
01/Y<P0M;3T072`i01l_?00R<cd07Bhf01TZ<P0M;SD07c4e01h`=00P<SH08C<e01h`<P0R=SL07S4e
01d`=00N<CD08C@j028e>`0O<ST07c4k024c?@0K;CT05RPd01T[>@0Q;d807R/n01h[>`0N;3L062L^
01DT:@0K:Rl06RT`02<a>@0H9Rl062Ha01//<`0J;C4201h`=00501T[;`0I:2d05bH[01HU:P0G92X0
0P0F8bT0100E8RP05b@T01PU7P0G91d201@Q6P0F01LT7@0H9Al05B4Q01<N800C7R@051hX01<M9`0E
7BP051/U01<J8P0G7R@072@W01`T9P0C6a`09Bh]01<L6`0@6AT04a/N049:D011BU409c8h01`W;@80
6B@Z03d05R4W01PS:@0K9R`07BP^01XU:`0F8BL06B@Y020Z;00M9bP06R@U01TS900G8B8051hO01LQ
8P0F82405AlP01@N7`0F8240628S01<L8`0B6b@05A`V01`N:P0M82T06QdU01`Q9`0I82H05QlT018O
9@0A82D04R8W034j@`0O8bh06QhY01@H8`0Q9Bl04ADN01DJ800;41D04aPL01@I7@0>4aL05alR00`C
6@0N9bh010dB00L@5@0D7B8051hP024[;@0D7R005AlP014K700:51D05QhP01XP8016BT/03a<D01hR
8`0A5AH02@d>008061`M02D05ATJ01HJ6`0I7Ah04QPH00TB4@0O:2L04a`K00`E500A6QT02a@C01TR
8@0740l072DT01LP7`0A6QT02Q0@01DF500G6AP03a<B00lD5`0=5AP03QHI010H6`0<4A@0318B01@F
5P0=3@/010@200lA400G6AP00@<200h@3`0D5QD03Q0?01DG5P0?4A005ALF0080418A00D051HE01hP
7`0M7ah03Q0?01<E500201@F5@0b018D4`0A4a804Q@C01<E500B51<04A<A014C400C5A804Q@A014C
400C5A804Q@A00h@3@0B514061XG00@60`0E5a@0:bd]01@E5`0B4aD0418B010B4@0A4a00418>00d?
2P0?4@`041<=00/>1`0=40T04A<<014B2P0=3PH04A8:00`=1@0B4`/08R<K018C2`0>3`L04A8:010A
2@0@4@X03Pl:01dM6`0G5aD04a<A018B400:2PP030`:00d=2`0@40h2018B400I00h>2`0B4`h0414;
00h?2P0@4@`04Q<>018B400?3`d0000001TI6@0=3@d06ATI01<C4`0A4@l04Q8@01<C4@0B4Q004A4?
010@3P0F5Q@04A4?00h>300?3`d04a<A014A3`06018A3`H04A0>04X03Pd;014@3P0C4Q004Q4?00l>
300<2`T040l=00h=2`0@3`d04Q4?014@3P0>3@/020L500X91`0=30X030/901<B400;2PP03Pd;014@
3P0=30X04Q4?01XI5`0A40`04Q4;01<C2`0D50`04a8=010?2P0?3PT03Pd900`;1`071P803@`:00/:
200H5aD04a8@00X91`0=30X040l=00P71@0B4@l0:RTW04Q7A@0T8b4030/900l>30061@<03PP8014=
300B3Pd04@d<010?3@0A40h03`h<00l?3@0<30X04Q8@00L71@0B4Q0030`<00h>3P0:2PX02`/;00d<
2P0920H03@`:01<?300?2`P03PX7018=2@0@30P03@`800l>2P804a8>00P03`h:018A3@0?3PX02PT5
010?2`0A40`03`h:00l=1`803``500l040d6014>1`0A3PL04a09018?200?30D04@h7018?200@3@H0
2@T300H70P0<3@P00`@002TZ9@0:2`H00P0;30L200`=20803@h901H04Ph;01@@3@0B3P/03PX700l;
200=2@H04@d:00l;200A3@X040`900h:1`0B3P/02PT500d<20071P8040l;00l>2P0;2PH04Q4=010?
2`0>3@T03`h:0P0@3`/050081`D03Pd;01@C4@0>3@/02PT700d<2P0?3P`040l=00h=2`0?3P`04A0>
00X:200H6QT02@`;00H:2@0C5A@05QLG00`<300;2`/030/<0P0>30d02P0=2``030X;00H41@081PL0
2`T:00h<3@0?3@h040h?00`:2`0>30d3010>3`803P`=01803`d>00`:2`0;2@X020H700H41@091`P0
7adN014?400<2P/04@l@00X82@0?3@h02`T:00X82@0<2P/03@/<00`:2`0?3@h200d;300?010>3`0A
3a0040h?00d;300C4A808AlP014?400=2``04@l@00l=3P0610D02PP900/92P0=2``0518C00803`/<
00@03@T:010<3@0A3@h030P90P0A3@h02P0B3Pl04@d>00l;300F4Q<01`<401TE5P0G4a@01P8301HB
4`0?2``2010<3@<04@d>00H06aPI02d[;00:20T061HG00`:2`0>30d300/92P0:00`:2`0100001083
01LE5@0G5Q@040l=00`;2@0;2PP020L500X91`803Pd;0`0?3P`06@0=30X03Ph<00d=2`0F5Q@04A4?
00d=2`0;2`T05QHD08n?S@0m?C/06ATG01DE4`0A3a003`d>00/92P0=2``040h?00h<3`091`X05Q@G
05IDF@0W9BX0ATA903Hc>@0?3A801@0?3A007P0H5QT03`d@00H41`040PD040hA03`j?@0O7Ah0518C
00l=3P0@3Pl030X<010>4@0<2Pd03@/?014?500C4AH04Q0F00h<4@0<2Pl03P`?00/9300A3a803P`?
01LE600=2`h03`d@01DC5P0C4A@08AlR01hL7aCooooo000Kooooo`0>00d<4@0@41<02`/=00d=3`0;
2``020P800d=3@0?3`h051@B01HF50030`8030d800h<3@0?3@h2014?400300l=3P0>30d05A<D0080
3P`=00<030X;00d;300B41401P0?3A002`0<2Pd04a4D02`Z;@0<2Pd071XM00P62@0C4AH030X?00h<
4@0>30l03P`=008040h?00<040l=014@3P0B4@d00P0C4Ph0;@0H5a@0CDe=00h@3`0@51L08BH/014H
7P0=4AX04QLM01@G7P0E5A/03`hD01HE700@3aL040lE01@C6@0?3Q<02`/=00`<300=3@/03Pl:010A
2`0A4P`04Q<;01DF401;C4L030d801HG4`0R8R001@D501PH600C4a<0410B00l?4@0A4A<051@F01PH
700<3A806AXO01<D6@1DEET0;Bhb010A500D5AL05aTH01DG5P0201HH5`0=00lA400A4a805QPH01LH
6P0Y:bX092HV01TK6P0J71/06A/J01DG5P0D5QD04QDE01/O8P0201/P900:01LL8P0D6Al04AHL01HJ
8`0E6B805a/T01HJ9@0B5R405QXU01LJ8`8061/T03005QTR01PK900M8BX05A`T01@K8`0B6B404AXQ
01<L8`0F7bD082DY01TN8@0H7B003Q<F01TN8@0J7b8051TL01XO8P0>4aH09b`_01HK7P0E6Qd05AdP
01PP8`0M9BP072@V01HO7`0G81l05QlN01HO700H8Ah06b@Q01hW8P0L9RD0;cXn08REV`0^>d4041hQ
01<Q900F92L0>4I7030n?P0I9bL06RPX01DS8`0R<3405b@/01/X<@0O;3D2024^=`0D020]=P0O;3D0
82df020]=P0Q;SL082df01l]=P0Q<3`07bll02@d@@0Z>dD08c@l01d^=P0N;cH0838f01la=@0N<3@0
72h`01T[;@0Q=CH3020c=`0K020c>@0Q=3X07C0g01d_>@0N<3X072hj01/]>@0L;S`08Rm201l/?@0M
:SX07B/g01l]=P0P;cH05bH/01l^=@0c@DT08c4j01/Y=00L;3@06Rda01d_<`0L;S805bT]01DT:@0D
8bP05B@Y00805b@Z01h0524W018O9@0B7b005B4O01PT8P0G8al05R8N01XV8P0I9B804alM018N7P0C
7R8051hW01DO:00H82/04QPT00lF800E72<04ATL010H6P0G7b00;SLf01`U900I8B<03QHI02Xa=`0d
?D@06bH/01DP9P0F8BL201@O9@0=01HQ9`0I92X07RT_01dX;P0A72806RDZ01`V:00K9BH06B<T01LQ
8P0F824051hO010J6`0200lI6P0M010J6`0B71d051hO018K800B6b805A`T01XN9`0K7RD061/R02DZ
<00R9bd06B4W010M8`0>7B803adR01LN:00J7RX051PS018F8@13Ae408bL`01DJ800F6b006b0T01LL
800B5aX0724U01dT:P0@6Ah00P0=5Q/00`0D7R004adO010J7002018L7@0g00hH6@0:51@03AHE00hD
500O8b@04ADF01hR8`0?4a@0720Q01<G600E6AX04aLH01@H6@0E6AX03Q8C00lE5@1<EE@09Rl^00dF
5@0N9bH04a`K04=<B`053Pd05b0O00dF5@0;51<04aTG00X;2P0=3`h06alN00lC5P0J8RD02Q8E00lG
6P093Q402@l?01@E5P0M7A/07QhL00d?3P0N81l04A<B01DG5P0;3@`051HE01DG5P0B51<06A/J018D
4`0>40l05QPG02PZ:@0P8R402P`;00lA400201DG5P07018D4`0A4a804Q@C01<E500B51<0418@014C
400201<E4P804Q@A02d04aDB01@F4`0D5Q<04A<@00H81@0V:2D0>S`j01@E5`0B4aD04A8C00lA400?
4@h04A<?01@F4@0H6QD05ALA00d@2@0<3`P04aD=01<D300@4@T04A8:00`=1@0=3PH05aP@010A2@0>
3`L0414900l@200?40T030d801XJ600B4Q0051@B01/K6@0I6AL05ADC01PH5P0C4a4030`:010@3P0A
4Ph03a0;014B300D5A000P0C50l01`0C4a405aLE010@3P0m?Cd05QHF00l?3`0H61P00P0B4Q00100C
4a404Q8@018B400B4Q0201DE4`0400h>300A4@l04A4?01@D4PH04Q4?1`0@3`d3018A3`03010?3@0>
3@/03`h<00803`h<00H040l=018A3`0B4@l03@`:02/Z:00<2`T2014@3P0P01DD4P0;2PP04a8@00/:
200?3P`06aXH00h=2@0@3`T04Q8:01<C2`0C4Pd040l:00l>2@0@3`/04Q4=01TH500?3P`04a8@01@C
4@0@3`d030/900/:200?3P`03Pd;01TH5P0?3Pd02@P6010?3@0>3@/04A0>01<B400A2`/3014=300:
00l>300@3`d02PT700d=2`0:2PP04Q8@0041000B4Q002`/;014A4@8030`<01@03Pd;00X91`0>3@/0
4`l<00d91P0<20D03`X6014=2@0?3PX03Pd901<B3P0E51004Q4=00d<200:2@D03@`801@C3`0A40`0
3Pd900l=2@803``500l040d6014>1`0A3PL04Pl8010=1P0<2@802PL000`90P0?30D04Q4<00h?2P0;
30L04Q<>04m@B`0I6QD00P0<3@P200d>2@803Pl:00T04Ph;01@@3@0A3@X03@T600l;200>2PL03`/8
010<2@0A3@X00P0>2PL02P0E4@h03@`801<B3P0;2PH05aHB01<B3P0@3`/06APD01DD400@3`/300d<
200D00d<2P0B4@l05QDC00l>300;2PP040l=00l>300@3`d03Pd;00d<2P0>3@/03Ph<028T8`0G6aX0
41@C00`>3@082@T04A4A00`<300=30`200h<3@803@/<00P04a4B00P61`0B41404Q0A01<A4P0?3@h0
2`T:00h<3@804@l@00d03P`=00`:2`0;2@X03`d>01<A4P0A3a00518C00l=3P0;2@X071XK018@4@0<
2P/040h?00@03@/<0`0@3Pl00`0=2``02`T:00/92P0300h<3@0B00P61`0J61T0>cTj01XH6@0<2P/0
2`T:05=ADP0E4a@030X;00l=3P0=2``040h?014=3P0?2``04Ph?014=3P0?2``04@d>0`0B3Pl02@0A
3@h040`=00`82@0=2@X02PH700P41@0I5AH0510A00/72002018>3`0A014=3P0@30d040`=00/82@0F
51D00P01014?400C4A804@l@010>3`081PL030X;010>3`0610D03P`=01TG5`0F5A<00P0<2`T00`0D
4a405aHD01<B400600h=2`0H014A3`0?3`d05QHD018B400>3P`02`/90000001>CT`06ATG00`<2P01
0@005A<D00P61`091`P040h?00/92P0A3a802`T<01<A500<2Pl03@/@092>T`0L6R003P`A1@0>30l0
4`0:20/030X=018@4`0>30l08AlR07]iO00c<C806aTJ00T720081PL01`D701HD5`0@3Q403`dA014?
500B41D04@lE00d;400;2@h00P0@3Q400`0F51L030X=01HD5`0200T72P0400`:3@081PT04a4D00h<
3aCooooo000Kooooo`0>00l>4`0H61/0410B00h>400M7Ah0:b/[07UiN@0F5QD06QXH00d=2`0A4@h0
3@h;00h<3@0?3@h2014?400800l=3P0>30d02PP9010>3`0=2``03`d>00h<3@091`P600l=400;01DC
5P0>30l0CD]>01DC5P0<2Pd0518E010>4`0=2`h040hA014?4P0>30d00P0@3Pl09P0@3`d04A0>018A
3`0B4@h04Q4=01@B400h=CH02@P9010A5@0J6b<03a<I01@F7P0I6R803`lF014>5@0L61h0;b`b01dL
8P0N7B<0;Rdb01DE600=3@l04a<C010@3P0A4@h04Q<>01<D3P0D5@l05AHA010@3P1XJ6H0A4A2018B
400F5QH051@E01<C5@0D51H05ADH0P0E51T0200E5AT0414E02<T:00B4aL0;Bhb01HG6@0E5QP05ALG
0P0C5A@06P0F61L05aTF01PJ5`0D5Q<05QPF018D4P0I6aP05QPF01DG500F61D06Q`I01TK600H6QL0
7B0N01HJ7@0G72006QlS01HK8@0D6Al05Q/Q01PL9@0F6R<06AdV01TM:00F6RD06AdX0P0G6R<05P0F
6B805APQ01HI8P0H72D05A`T01HM9@0H7bL0624X01LP9`0E7R@06QlS01<H6`0]<SD05a`O01hS9P0J
7b806b0S01PM800B5aX061dP020U:00F6ah301HN8@0[018J700K8bD0=3`m02D^;@0M9RD06B8P01XS
8@0L9B807bTX01HP900`>d4041/Q024/<00N:Bd07BP/01LR900X=3D05R8R01l[:`0N:RX08B`^020]
=@0O;3D07BXc01h[=00P;CH08Rlh01l/=@0L:C806bPa01`Y<P0P;CH08Blh01h]>00M;SP08C8l02Df
@00P<CT06R/c01//<`0N;cH08S<j028d>00201la=@0801lb=P0Q=3P08SDi028e>`0O<SP07S4g02Hi
@00S=Cl3020b?00L01h_>P0O;3`08c1001h/>P0K:C@0:3Ho03=1B@0I:2l07Rdd02Pg?`0O;CH06RPc
01PX<00E9b/05bT]01T[;`0J;3006BP]01HT:@0F8bT062D[01XV;00G8RP051lU010K800C7R805b8T
01HR90804alN01D0520N01HR800H92@05R4S01HQ9P0L9b`082Pb01HL:00D6bD06B0W014I7@0@61/0
5AhO00hG5P0>5QP0620R01HN8@0I82H072D/01@M900K92/00P0G82L03@0K92/05QlV01TR:@0L9B`0
6b@[01@M900J8bT0620S01PP8P0I8B<05QhP01DM7`0F7R000P0D71h0DP0E7Al05alQ01PP8P0I8B<0
4a/N014H700?5a/04aPM01DJ7`0F6B005QXS01DI8P0B6B404A/Q014M8`0F8BL06B0Y01LK9P0J7RT0
4QHO02HZ<`0>4Q/051TO02DZ<00N8bT05AXN01LL800C61`05alR00hF6@0E7B004ATK01DM7`0F7Ql0
4AXJ01<L6`0A6QP04Q/I01<L6@0@5aH07R<S00hB4`0J7Ql03Q8C01<G600?4a@04ADF01@H6@0C5aP0
5ATJ01LK700@51D04QPH01`R8P0G7Ad06b4Q01LM7@0>51@0:c4a01PN7P0V;2`041HF01HL700@51<0
7b0N010B4@0C5aH05a`O00XA501:DUD0=Si101TN8@0H7Qh05aTI01LG5@0P81h04aDD01PJ6@0D5QD0
5ALF00d?3P0F61L2014C4P0901LI600J71/04Q@C014C4P0D5QD05aTH00h@3`0C5A@0418A00804aDD
00`04Q@C01<E500C5A@04A<B014C4@0C5A8051HC01<E4P0@4Pl04A<@018D4@0G6AH2014C400701HH
5@0C5A805QPF01<E500B51<04A<B00lA400300lA3P0700h@2`0@4Pd051HA01<F3`0D5Q004Q<=01@E
3`0201<D3P0O01@E3`0@4@/03a0:00l@2P0A4P`03a0:014B300B4`l05QHD018B400C4a403Ph<01HF
500C4a403Ph<018B400G5aD04A4?00l@300?40/0414;014B3@0?40/03Pl:010@3P0A4@l051@B01lO
7`0C4a<03Ph>01HF5P05018B400701<C4@0;2`T05ADC00h>300F5Q@03Ph<01<C4@06018A3`H040l=
00D05A@B01<B400@3`d03`h<014@3P0201<B400B014@3P0@3`d04Q4?01@C4@0C4Q004Q4?030_;@08
1`H051<A00/:200920H03Pd;018A3`0;2PP03Pd;01HE4`0;2PH03Ph70P0?3PT08`0@3`X03`h:00l>
2P0?3PX02PT701TH5P0?3P`04@l@00/92P0I61H09RDS018A3`0=30X05QDC01lN700];2X03@`:018A
3`0@3`d02`X801<B400E3`l04Ph=014=300B3Pd03`h<00h=2`0B4@l03@d;00l?3@0<30X04A4?00`<
2P0?3`l04A4A00802`/;0P0?3P`0300A40h04@d:010<2@0D40d04Pd900l<200>3@T02PT500`;1`0?
3PX040l;014@30804Q4=00@03`h:00P70`0<2`L04@l;0P0?30L01@0@3@P04@h9014>2@0=2PH03P/6
00804a0;0P0?30L01P0A3`/00`@101`M600E5Q406Q/F00`=2@803a0;0`0@4@`02P0A4Pd040`9018>
2`0?2`P03PX7018>2`0C3``0510=01HB3`0D40d200h:1`04010<2@0<2`L02`X6018A3@803@`800D0
2PT501DD400B4@d03`h:00h=2@02010?2`0601<B400@3`d03@`:00d<2P0>3@/03`h<0P0>3@/2010?
3@08014@3P0E5A<0I6ET02<U900l?Sd0AdU8018C4`0<30`2010>3`0<00h<3@0@30d04Ph?018>3`0@
3Pl04Q0A00d;30091`P03`d>00P61`0=2``03P`=0P0@3Pl04P0>30d02`T:00/92P0=2``04a4B00X8
2@0E4a@02@L8010>3`0=2``04@l@00h<3@0=2``04@l@00d;300?3@h040h?00h<3@8030X;00H03P`=
00`:2`0<2P/03`d>010>3`0?3@h200h<3@07020N7`0:20T03@/<01DC500a;c003P`=00/92P0200d;
300:018@4@0?2``03`/<01<?400B3Pl04@d>01HB4`0C3a004Ph?014=3P<040`=00L05A8B01<?400F
4Q<04Ph?01PE5@0G4a@04`l@00804Ph?0P0@30d04`0=2P/05aDF00/92P0?3@h0518C00d;300<2P/0
2`T:01DC500=2``02PP901<A4P0:2@P04A0>01DD4P0>3@/04Q4?02LV900U92801@0>3@/01`0<2`T0
4Q8@00h>300@40h03Ph<00/;2@0>3Pd00P0?3`d0400;2`T04a<A010@3P0@3Pl061HG01<A4P0;2@X0
3`d>00`:3@0F51L020L901<A5P0;2@h061HK010>4`0>314500h<3`0>01@B5@0;2@`03@/>014?4P0<
2`d040hA01<A4P0:20T040h?01TG600@3Q004@lB01LE600B41@200h<4@0900l<4P0=2a002`T>00h<
3`0D4QD04@lB00l=40081PT040hA00803`d@00<020H9010>4@0:20/05?ooool001_ooooo00h02`T>
00l=4@091`X00@0201<A4`0H5QL0AdE600H41@0C4Q0040l=01DD4@061@4030X;00h<3@803`d>00P0
3P`=00`:2`0C4A802PP901HD5@0@3Pl02@L801<A4PH03`d@00@030X=010>4@0<2Pd04Q0C0P0<2Pd0
100?3A0040hA01HD5@0F51D2014?40<040h?01D03`h=00l>300A3@`04@/=01@?4`0?3A006APM010?
5`0C4a/051<K01<B6P060`X040`B01lH7`0R7R<04a8G01@C600J6Ah04A4C00/;3@0=3@d00P0=3@/3
00h?2P09014B3P0<30X07AdK01XJ6@0V9RH030`>014A4`0C4aD05A@I00805QDJ00X05A@I01DE6P0;
310030dA01<D5`0A4Q@02``>014B4`0@4Q403a4@0P0@4Pl06@0B51405QPD00/=200I6aH06Q`G010B
3@0G6AH06Q`I01LI5P0J71T06A/J01HH5`0K7Qh04aLJ01HK7`0I7R8051TO01<H7P0H7B<06AdV01PL
9@0K7bP06alZ01PL9`0L82/00P0G6R<301PK900d01@H8@0G7RH061lW01TP:00H8BP05b0W01HO9@0H
7B408RLZ05IKGP0G71l04aPK024V:@0O92L04QLJ03a1A00D6A`06QlR01HK7P0Q:B/05alQ01PP8P0G
7b407bLY03Hn@00V;S0072@V01/T8`0L9B@06b@S01hX:@0E7R<0=3m501dX;P0E82@05R4U01`W:`0T
;c40:SDf01DQ8@0C7al06BDU01lZ;00I9R`06BH^01PU;@0I9Rh06bP`01`Y<@0R;cL07b`d01dZ<P<0
72Ta00P072Xc01d[=00N;3D07R`e01/Y<P0I9c00938k020_=P808c8i00<09C@k02Pi@00Q<ST00`0O
<3L05P0P<CT08C8j02Hg?`0P<CT06BXb01//=00L;CD05RLa01d[>00_?DX0<3i;028`>`0E8b`04b4Z
01/Y<P0N;3D05R@^01HT;`0K:C@06b/c01/]<@0J:Bh201PW;0805R<Y01P05b@Z01PS:@0G8RP05R4W
01LR:00I92`06B<]01HP:@0E82D051lQ01<O7`0C7ah04QhL010L700@6a`04ahP01HQ8`0I8BX05adY
01DL9P0C6R803aHL00lG6P0F7R0201TQ8`0H01HN8@0J8BL051/S01HO9P0I8RT06b@[00/D6`0?61l0
3AHM01@M900I8RT0624X01<L8`0K92/05QlU01XR9@0K8bD072@V01LO8@0E7Al05alQ014I6`0B6Q`0
4a/M0`0D71h08@0G81l05AhM01HL7@0G71l061dQ01PM8`0N8R/07B4Z01XQ:@0G7R@051dR01<L8@0D
6b<041@M01hR:`0O8b`04QHO01DI8P0E6R004QLM014F700E6R0061dS018G6`0>5QT06b<U01XR900G
7b404Q/J00H?3P0?61L03aPE010I500200lH4`0h018H5P0?4a@051DG01HG6@0?41807b0R01TJ700E
5QP05aPJ01DF600G61X06Q/M018F5`0F71X04ALE01dS8@0G7A/03aDC01HL6P0C6AL051XH018H5P0?
5A<01@/900T=301?D4d092HU00lC4P0?4aH00PX=05ALG`2maLP08bP[00H<300?4A4051@B028R800@
4Q405QPG024S8P0F61L04Q@C00T;2P0C5A@06A/J01<E500L7Qd06A/J014C4P0F61L03a4@00d?3P0D
5QD061XI01lQ800D5QD3018D4`0?010B4@0A4a404Q@A018D4@0A4a00418?01<E4P0?4@h061XG01HH
5@0=3``04Q@A01DG500G6AH0418?00804A<@0P0@4Pl04`0B51405ALD01<E4P0?4@d04Q@?014C3P0@
4P`03a0:01LH4P0C50h05QLA01/L5P0?40X03Pl9014B300B4`d03a0:018C3@0?3`d00P0C4a40300I
6AL04Q8@01@D4P0N7Q`05aLE010@3P0=3@/02`/9010@3@0A4Pd04A8<010A30804A8=00T04A4?00/;
2@0I6AL0410@014A4@0410@05ADE014A3`0@40h00P0?3`d0200A4@l04a<A00h>300J6QP04A4?02/[
:@0J6QP04Q8@1P0@3`d600l>308040l=00L03`h<00h=2`0>3@/03Pd;01DD4P0@3`d03`h<00804a8@
00@03@`:00X91`0@3`d01@@20P0F5A<0200?3P`04a8@00l>300?3P`04Q4?01<B400>3@T040l:0P0=
30L01P0>3@T04A0<018A3@0D4a402@P600l>30803P`=00h0518C01LF500N7A/04A0>00d<2P0?3P`0
61LE00H5100H5aD04Q4?01DD4P071P@03Pd;01@>40803`/<01004`l@018@4@0A3a0040h?00<30`0C
4a<010@403Lg=`0=3@d03`l?00h>3P0<30`03`l?00l>300>3@/040l=0P0@30T00`0E4@h04`h:00d:
1P0200d<2P802`X800P03Pd;01DD4P0C4Q0040l=01<B400@3`d03Pd;00l=2@803``700l040d8014>
2@0A3PT05A8=01<@2`0>2`H040d801<@2`0@3@P03`d800<2000;2PH06QTG00l>2P0;2PH00P0?3PX2
010?2`804A0<01804@d:01<?300@30T03`/801@@3@0F4Pl04`l<01HB3`0C3``04@d:01@@3@0>2PL0
6APD00h=2@0c<Rh051<?01TH500A40`200/:1P0H00`;1`0@3`/04Q4=01<B3P0=30X02`X800X91`0<
2`T03Pd;00`;2@0?3P`030/9014@3P0C4Q004A0>01<C4@0>3Ph051HE00X<2`071`L03@`=00h<3@0@
3Pl040d>0P0?2``0200A3@h04Ph?00X82@0D4Q<01`D6010>3`0<2P/04Q0A0P0>30d200d;308030X;
00`01P@500`:2`0O7Ah06QPI03Pf=`0^;2d030X;00d;300<2P/03P`=00l=3P0>30d200l=3P803@/<
00<04@l@01DC500?3@h00P0=2``03@0@3Pl04@l@010>3`0=2``0518C00l=3P0C4A803@/<00l=3P0=
2``0518C01DC500>30d00P0:20T0100=2@X04Ph?010<3@0?2``3018>3`0;010<3@0>2P/03PX;00l;
300G4a@00`0001`H6@0=2@X0Og]l09jJV`0=2@X00`0@30d200l;300C00l<3@0C4A8030X;00h<3@0D
4Q<030X;01<A4P0?3@h05aDF00d;300:20T04@l@01<A4P0?3@h01P@500X82@0A3a003`d>00`:2`02
00h<3@0600d;300<2P/030X;00/:2@0E51803`h<0P0=30X0500;2PP04A0>01LF500;2PT030/900L6
100<2`T06ALH01lM7P0M6a`03`d>00`:2`0D4QD02@L:00P62@0:20d03@/@00P62`091P`03@/@1@0=
2`h0100B41<04@lB00l=400;2@`200T72P0C014?400@3Pl03P`=00h<3@0>30h03P`?014?4P0?3A40
3@/@00l=4P0?31803@/@00h<4@0:20/05A<F00T72P0U8bH02@L:00`:3@0200/9300300D31P0>30l0
20H901Cooooo000Kooooo`0>01HD6@0I5a/06QPK00D31P0B41800`4200`:2`0=30/05A@B010?3@0;
2PL03Pd900/92P0=2``200h<3@0800d;300;2@X03P`=014?4015@d@0<Bl`00H41@0?3@h600l=400<
01DC5P0<2Pd040hA028P8`0?3A004a4D00h<3P0@3Pl05aDF01PF5`0@3Pl03`d>0P0@3Pl200l=3P0G
00d;300?2``03PL901`F6P0C3Q@04a0G00d<500?3QH04A0H018?5P0710/04`hC01T@5@0D41@04Q4F
014@5@0=3A005ADG01@D500?3`l04A4A010@3P0@4@d00P0@4@`02P0:2`L05QHD01XJ600<30/04Q8B
01XJ700D51H04a<E01<B5`0D4aP201DD6@0E01<C600O82@06Q/O018C5P0A4Q@06AXL018D4`0C5A@0
4aDB01DG500C5A8051HC01LI500E5a8061XE00`>2@0B50l05aTF01TK600E5a@071hL00808R@S0100
:B`/01/O8P0M8RH07B8V01DJ800B5ad05AXP01LK900F6R<06AdV01TM:00F6RD06QhY01<F7`0D5b00
61/T0P0L7bP0100H72D05ahV01HM9@0E72@201<L8`0[01DN900O92P0314D03@i?00D6A`07R<V01<H
6`0R9bX06AhQ06Y_LP0X;C006QlR01PM800L92H04a/M01/S9@0L92H051`N01LO8@0M9BL05alQ01`T
9P0O9bT07BHV028Z;00U;S<06B@Z01LR:00P:bl072L[014L800F8B<06bHW01`X:00I9BD06bLW02@_
<@0G92X06RL_01dZ<P0N:c<07b`d01h[<`02020]=@05024^=P0P;CD07BXb01`Y<@0P;SL00P0Q;cP0
9@0N;3D07B/d01h/=@0^?4D08c8i028a>00P;cH08S4h02Xi@00R<cX07Bhe01X[<P0L;C@08C8j02<d
?00U=Sh07c0h01TZ<P0N;cL08C8j01//=00Q;cX082hk01h/=`0L:SD07bdf02<a>P0I9c00938k01TW
<@0M:cH08S0k01TY<@0F:2`05B@Y01PW;00L:c000P0L:Bl0:P0I9R`05b8X01@O9@0F8BL06B@Z020Z
=00N:3@05b4]01LQ:@0L9b/07BPZ01dY:@0E8Al03a/K014M7P0F8B<05B0R018K8`0D6RP05A/W01DL
9@0I82H06b<V018J7@0N9RP072@V01DM8@0L8bT05ahV018K8P0I8RT072D/01<L8`0Q:S407bP_01<L
8`0J8bX05QlV010I800O:2l051dS01@L7`805QhP00D03aLI00`D5P0>5QP04ATK018J700301@L7P07
01@L7@0G81d05QlL01HL6`0F6ah05AXM010E6`0201/O:01C01PO9P0F7B<051`O018J7@0:3aD05a/T
01@H8@0H72D051PQ010D7@0e>T005a`R01HK8@0O92X05a`R00lD6P0=5AP031@F00hF600C71/03AHE
01XS8P0@6AH04a`H01LP6`0C71L03aPC01TO6`0:3Pl05QLI014B500F5aT03@h@01/L7P0E5QP05QLI
01<D5P0D5AL05aPJ018C5@0;3`h051XH00`B400C6AL051XH00D;2@0D6QP03Q@B00X@3P0M8b400PP6
01LK6P0E5Q@03@l>020T8`0A5AP05QhQ01DM801<E5L03Q<F01lU9@0M7al020P601PH5P0C5A@01`T8
028T8`092`X03Q0?01DG5P0@4Q4061XI00X<2`0B51<05ALF00d?3P0@4Q404A<B01XL6`0I6aX03Q0?
01TK6P0D5QD00`0B51<00`0@4Q403a4?014C4002010B3`0;014C400F61D05aTF01<E4P0;3@X05QPE
020R7`0F61D04Q@A00lA3P0@4Pl00P0A4a003`0@4Pl03@l<00lA3P0A4a0030h:010B3@0A4`h04Q<>
014B300J6aD04Q<=01<D3P0J6aD03@h800h?2@02018C3@05010A2`0C50l04A4?01PH5P0>3P`00P0A
4@l07`0=3@/02@T7014A3`0D51803`l=010@3P0>3P/0414<00l@2P0>3`X0414<00l@2`0<30X03@d;
00h>300:2PX0820P00l?3`0=3@d0410>00l?3@0>3P`03`l=010@3P0C4a403`l=01PH5P0=3@/0<S8`
01hN700<30X0300?3P`01`0<2`T03Pd;00l>300?3P`030/900X91`0E51800P0>3@/03@0D4a404Q4?
00T81P0A40h040l=00d<2P0<2`T02PT700`;2@0E51803Pd;018A3`0F5A<00P0C4Q00900A40`03Pd8
00`;1P0>3@T04a8>01DD400A40h03@`:00l>300>30d02@L801HD5@0<2`T01`H400T81P0>3@/020L5
018A3`0?3P`040l=00D40P0<2`T00@0001TH5P0A2`d030P900h:2`0E4A805A<D01@B4`0?3@h00@41
01XJ6P0;2`/0EUIF01`L70803Ph>0180410@01DE5@0B4@l030/900h=2`0@30T03`/8018>2`0A30P0
3@X7010?3@0B4@l04A0>00h=2`0@3`d04Q4?00/:200>3@/201lN700501<B400<2PL03``700l<1`0@
3@P00P0A3PT0300T8A`08QlJ00`910091P<061D@01`I500>30T071/G00H50@0B4@d02`X600d<2P80
3Pd90P0?3PX2010?2`0701<?300E4@h04@d:010<2@0D40d05Q8?00`81@02010<2@0901@@3@0J5Q<0
510=00l>2P010000=3<_00X91@0A40`010<100802`X601P030/7010?2`0A40`03`h:00T81P0;2PP0
3Pd;00l>300>3@/03@`:010?3@0;2PP04A0>01@C4@0?3P`04A0>00/;2`0:30/03Q0?014A4@0?3Pl0
30X;00l=3P0>2``200d92P0:00l;300A3@h02`T:010>3`050`@05Q@E00L51P0G5AH03`d>00h<3@@0
30X;01<03`d>00h<3@0C4A800P0101HD5@040P<020H701@B4`091`P030X;01<A4P0;2@X03`d>00h<
3@0=2``04@l@01dK700U8b@03@/<00802`T:0`0>30d01@0@3Pl0518C0040000B41403P`=008040h?
00L02PP900L51P0>30d040h?00X82@0@30d05Q8C008040`=00h0510A014=3P0A3@h03`/<00d92P0>
2P/03`/<014=3P0?2``04Ph?00h:2`0J5QL08alP01DA4PD03`/<00<030T:00`:2`0:20T00P0?3@h0
1`020040518C00T720050`@03P`=018@4@0@3Pl00P0?3@h2010>3`0300d;300;2@X030X;00803P`=
00H03@/<00`:2`0<2P/03@`;01XI5`0C4Q02010?3@0D00l>300=30X00@0000h=2`0B4@l020L5010?
3@0<2P/01@<403<a<P0l>S/030X;00d<3P01008071XM00h<4@030@H04Q0E00h<4P0=2a0500d;3P0N
00/9300=2`h030X=00d;3P0C4A@04@lB00L51P0>30d040h?00h<3@0@3Q0030X=00/9300<2Ph03`dB
014?500@3Q@03@/@01<A5P0:20/061HI00P62@0f=3L0518E018@4`0A3a8040hA00X82`0B41<030X=
5?ooool001_ooooo00l081hS01DC5`0=2`h05aDH01/I6`091`P02PP900l=3@0?3P`03@`:018A3P0K
6QH05A<D00d;300@3Pl00P0?3@h200/92P0:00`:2`0C4A804Q0A014?400?3@h061HI01DC5P0>30l0
2`T<010>4@804Q0C00`04@lB00l=400?3A003`d@00l=3`0A3`l05Q@E01<A4P0G5AH030X;00l=3P0@
3Pl200d;300?00l=3P0@3Q004`hB01<<400A2Q403PT?01XG7P0E51`04a8J014@600A3QD040hD018<
400E31003`/>0080410B00L04A4C01HF600B4Q8061PH014A4@0A4@l0410>00804A4?01<04A4@014A
4@0A4A404a<D01<C5@0D51H0410C01PG700<2a005A@I01dL8P0@3aD04a<H01@E5`0E5QP04A8D014C
4`0E5aH04aDD008051HC01D0418>01DG4P0G6A@05ALA01LJ4`0C5A0061XE02T[9`0K7AX051HE00h@
400G61X061TL01DF6@0F61`05aXO01LL800E6Qh05a`R01`Q9`0I7R@00P0E6B806@0G6b@061`W01TM
:00J7RT05APQ01/N9`0B5Ah061/T01<F7`0H72D05QdU01DL900I82P06R<Z01LP9`0F7bD041DI01hS
9P0E6Qd0724T01PM800A5QT06b0S01TN8@0]<SD00P0K82<01`0F6ah05alQ01DM7`0E7Al0620R01TQ
8`0F7R000P0K8bH02P0J8RD06B4T01/S9@0K8bL05QlU01hW;P0P:C006b@Y01PQ9P0I8RL201XT9P0:
01hX:@0L9RL072HW02Lb=01[N7/0=T=901/X;P0N:c4072T_01XW;@8082dc00@07b`b01`Y;`0L:Bl0
7BX`0P0N;C@0100L:c806RT`01`Z<`0N;3D3024_>00;020^=`0M:c@072Xc01h_=`0J:c<072de020a
>@0N;cL06b`d01`]=@0M;SD0100N;cH0200I:3007B/e020^>00L:SD06RPc01h/=`0N;3P072Xf0P0K
:C@0B`0L:SD06BP`028a=P0E92T062H/01`Y;`0G92X062@Z01DP9P0I92X05b4W01HO9P0H8BP05Ah[
01lX>@0J8c<05b4/01/V;@0R;C80:3<e01HR8P0E8B807RTZ01DP8`0B7B405b0Y03Y0CP1oQI808BPb
01LN9@0M9BT04QXM01PP8`0L92L031<H01/R:00E72@06b8Z01HM9@0L8b/061lW028Y<@0Y<3P07bH^
014H800G7RH06b8Z01`S:`0B6B005a`P01TN8@0F6ah04aPK01HK7P0E6Qd02a0C01@I700B5aX05Q/N
01@I700F6ad05adI018H500D6QT06R8T01PP8P0C6R004APN01@K8@0E6Ql0<3@f01`Q8@0P92@05a`P
01@I7`0201HK8@0H01DJ800F6b40<cM001PL9@0I7BH082@]01DI8P0?51X04aPL01@I700C61/04AHH
010F5P0B61P09bd/010F500B61@0318>01<I5@0G71T05QPJ01DF600F5aT03a0B0P0H6A/0201/KFl0
7AhP014B500F5aT04a@F01PI6`0E61L04QHE0P0A5A@05P0C5aH051PG01HJ6@0=4A0061`K02hb<@0C
5aH03a8A014B400K7A`01`/:010E600P:2/06b<V014I700E6Qd051XJ018D500D51805QHD010B4@0B
51<2010B4@0601<E500D5QD04aDD01LI600H6QT05ALF0P0C5A@00`0A4a804Q@C01<E500201<E5007
014C4P0@4Q404Q@C01@F5@0B51<0418A010B4007014C400<010B3`0?4@h03Q0=00lA3P0A4`l04Q@?
014C3P0N81`0:R`Y01`N6`0=3``0418?0P0A4a02018D4@0>010B3P0=3PT03Pl:014B3@0C50l04A8=
018C3P0@4@`03a0;01@E400F5a804Q<>018B400=3@/3018B400C00d=2`0C4a403Ph<01LG5@0=3@/0
5QHD01@E4@0A4Pd04a@>010A300B4`h061TD01@D4P0A4@l02`/901<C4`0I6AT0410@00h>3P06014A
3`0@00l?3@0>3P`03`l=010@3P0B4Q004a<A00l>300@3`d03Pd;00d<2P0>3@/04A0>01HE4`0@3`d0
3@`:00l>30804A0>00`04Q4?01<B400A40h040l=014@3P0B4@l040l=00l>300=30X03Pd;014@3P0D
4a4200h=2`@03`h<028020L500l>300?3P`0?chl01PG5@0C4Q005aHB01<B3`0B4@d092<O01HE4`0@
3`d03`h<01DC500>30d03@/>01XH6`1_KFh051<B00h=2`0=30X03Pd;00l>300>3@/030/:01HE4`0;
2PP03Pd;018A3`0<2`T03`T;010<3@0A3@h04Ph?0P0?3@h0600:20T02`/;010@400K6a/0HV9R01DE
5@0?3`l0=CDe01XJ6P0R8R803@`:01XI5`0E518030P501@@3@0A3@X03`X6014=2P0=30X05QDC00d<
2P0;2PP05QDC010?3@804A0>00D0<c8`00L61@0E518030T8014=2P0300l;200500d91P0A3@X03@T6
00d91P0?2`P00P0<20D00`0>2`P03@`800`;1`0200/:1P0F00`;1`0?3PX03@`801PG4`0G5Q802@P4
00X91@0@30T03@T600`81@0?2`P04@d:010<2@0A3@X03`/8014=2P0B3P`03P/901TE4P0=30P03Pd9
00l>2P8030/701<04A0<00d<200D4`l030/700l>2P0@3`/030/7014@3P0B4@l040l=00d<2P0/:bT0
3`h<010?3@0H5aD02PT7014@3P0<2`T05aHD008030`<01l02`/;00`:2`0=2``03P`=014=3P0F4Q<0
>SHg00d72@0A2`d03PT;01<@4@0@3Pl020H700h<3@0<2P/0518C00T7200>30d02PP901<A4P0:20T0
518C018@4@0=2``02PP900d;300@3Pl03`d>01@B4`0?3@h0GE]L00804Q0A00P040h?00d<300Z:2T0
=38c010?3`0[:BX0=cDf00d;30803P`=00D030X;00h<3@0?3@h02PP900/92P0200d;300301HD5@0`
;Rl03P`=00803`d>00T03@/<00h<3@0?3@h02PH701<?40091@H040`=01HB4`0@30d00P0=2@X02`0?
2``05A4B00l;300B3Pl040`=00l;300@30d04@d>018>3`0@30d04@d>008040`=00<03`/<00h:2`0@
3@h00`0>30d200`:2`0d00l=3P0@3Pl02PT900X82@0R82403@/<00h<3@0610D02@L800d;300>30d0
3`d>00d;300>30d020H700X82@0@3Pl02`T:00d;2`0A40h061LE09:AS`16AD<040l=00/:200B4@l0
51<A028Q7`0E51803Pd;00h<3@0B41405aDF01XH6@091`P04a4D00`:3@0D4QD03`dB00H42@0E4aP0
30T?00T7300P7R402`T<00l=400D4QD030X=010>4@0>30l02`T<00`:3@803@/>0P0<2P/04@0>3@d0
30X;00`:300?3A004A0B00h<400>314030X?02LU:`1KFEh071XO00l=400C4A@0518E00d;3P0A3a80
518E00803`d@00<03P`?00d;3P0B41<05?ooool001_ooooo02005A0F00d83@0910P040/?01<>4@07
0`@02PH700h:2P0?2`X03PX901<?3@0I5A801`D6010>3`0R82404a4B00h<3@0;2@X04a4B02@R8`07
1@H03@/<00`:2`0?3@h0KF]^020N8@0=2`h0518E00h<3`0]:bh04@lB010>4@<03`d@020040h?01@C
400H5aD04Q4?01HE4`0:20T02`T:01<A4P0G5AP05Q@G018@4`0@3Q<04`hD01<:4P0@2A402PD<010=
5P0;2A@03P`G01@C6`0A3QD03P`A014<3`0G3Q406aLH00/;2`0L71`06ATI05]KF`1SHf<0De=C010@
40<03`l?00<0410@014A4@0B4Q800`0B4Q@02P0B4AH06APM00D42@0H5ad04Q8G01XI7`0;2Q804a<H
00l@4P0<3Pd201@F5@0701DG5P0F61D051HC01DG4P0B50l04aD@01@F4@0201<E400@01<E4P0A4a00
418?01PI6P0M7R007b0T018C5`0_<3D02``A01`N8`0G6Ql061dQ01LL800G72806AhT01@I7`8051PQ
01P05ATR01HJ9@0G6bH05a/V01dP:@0P8b`05QTR020S;00>4AX08RH_01/R:P0A6200>D180:2Y/00P
:C0072D[01<H700D6A`05a`O01TN8@0B5aX06b0S01@I700B5aX201DJ7@0301LL7`0K82<05QhP0080
620R01405alQ01PP8`0J8RD06b<V024X;@0Q:2h07B@Z01TP9P0I82P04Q/R01TR:@0K92/0624V01HO
900H8BH06bDW01PR900201XT9@0901LQ8P0H8bD0<Ca001LT:P0F8bT07R/a028_=@0U<SP07b`b0080
934g00@08Bhd01dZ<00L:Bl06bP^0P0L:Bl01@0L:C407b`d024^=P0N:c@07b/g00<082`h00L07bdh
01h/=`0V=3l09C<n01d[=P0L:S<07bdf00<07B`c0`0N;C808@0M;3807Rdd02<a>P0R<3/072Xg01/Y
=P0N;3X07R`i01d[=`0K:C@06RPc01/Y<@0B7bD04AhT02Pe>`0K:2h041/Q01`W;@0E82H0624X01<L
8`0B6b806R4Y01LP;@0G83405Ql`01@N:@0I8b`08Rdc02<^<P0F8B<05b8V01`W:`0201@O9@0J01LO
:P0I7bd0Q8ZH024W<P0d>d<02Q4G01PO900:4QD05A`R01`S:P0D6b<05QdW01/R:P0D6b<06b8Z01LN
9P0B6B403aHN010G7`0U;3@0;3<k018I8@0L8b/051/R00`A5@0A5AP201@H6`0j01LK7P0D61/03a<F
01LK7P0D61/05ATL018F6@0D61X04QHE01<H500L8R407bLY01XR9@0E728051/Q010H6`0N8bD0JF]X
03do>P0P8Q`0310C01XO8`0A5QX0314G020U:`0@5A/04aLP01dQ:P0L82T04aLR014E800I7BH04A@K
01@G700F6Qd05ATL01HJ7@0I7Ah0Oh>4028V9`0D61L061`K01HJ6@0E6AP06AXL014A4`0H61X04A4C
01<C5@0J6Q`092@V01lO8@0V9RP07QhP01DE5`0720X051HE01@F4`804aDB0P0D5Q<06@0F61D020X7
00T;200F61D051HC01`N6`0C4a4030h=00`@3`0B5aX03ADH01dU:00=5AP04AHI010F5P0A4Q<04Q8@
01@D4P0O8B003@l>018D4`0F61L04Q@C01<E500@4Q400P0C5A@00`0B51<04aDD01DG5P04014C4P04
010B4@0>40l03a4@014C4P804aDD00<04Q@C014C4@0A4a00100A4a000`0B51404A<@010B3`0200lA
3P0:010B3`0@4Ph041<<010B3@0?4@`04aD@01<E4P0?4@h03@l<00h@3`<03a4@00H03a0=00d=2`0=
3@/0410>018B400A4@l2010@3P<03`l=01T03Ph<01<C4@0;2`T05aLE00/;2@0d=3803Ph<014A3`0G
5aD03@d;01HF500E5A<08R<O01<D3`0D5@l04Q<>01<D3`0F5a8051@B020P7P0B4Q0061PH038b<P0_
;bl05aLG00H03`l=0`0>3P`01P0?3`d04A4?018B400>3@/04A0>018A3`8040l=00P04A0>00/:200A
40h04a8@010?3@0A40h05QDC00l>30804A0>0P0>3@/01`0?3P`03Pd;00h=2`0>3@/040l=01@C4@0G
5Q@01P0>3@/06P0D4a403@`:00/:200?3P`030/901XI5`0;2PH00@0001PG4`0U92803Pd;00D40P0A
3a004a4D00T72P0F51L00`44018@4@0>30`03@`:00h=2`0?3P`03Pd;00`;2@0B4@l061LE0P0@3`d0
0`0E51804a8@018<3`03014<408030X=02D09R@W00L72@0C4aD07AdO03De=`0>3Q005aLG0;Zj^P1E
EED0000001hM6`0D4a402`X8018>2`0Q7AX061@A00h91@0;1`D040h?01HD5@0B41401@<400T7200F
51D030X;00l=3P0920P02PP901PF5`091`D03`/:01@@3`0B3Pd03@T800h:2@0?2`X03PX900803@T8
00@06QHE01/G5P0C3`d04Ph;0P0A3@X0500B3P/04`l<01@@3@0?2`P04@d:018>2`0<20D03`/8014=
2P0?2`P03@T600l;200A3@X040`900<0000P71T02PH300L300060P003PX90P0@3`/0<P0?3PX030/7
00/:1P0=30P02`X601HE4@0@3`/03`h:00h=2@0@3`/03Pd;00l>300D4a402`X800l>30081`D01PD3
00h=2`0@3`d06QTG018A3`0?3P`02@T900X92@0;2@X030X;00l<3@0B3Pl02PH701/F601QFed04@/=
014;300H4Q@01@42010>3`0N71d02`T:01HD5@0100007A/L00X82@0E4a@05Q@E014?400;2@X040h?
00T7200A3a00518C0P0?3@h010040P<08R0Q0=7?d00/:R/200/92P0E00h<3@0Q7b00:2HW00X82@0B
4140518C014?400?3@h030X;00X82@0<2P/03`d>01LE5P0>30d030X;00l=3P0;2@X03`d>00d;300?
3@h03P`=00803@/<00H03`d>028N7`0=2@X02PH700`82@0C3a0200l;3004010<3@0>2P/02@D600X6
1`804Ph?01l04@d>010<3@0@30d04@d>01/G600c;c009B4R01<?400@30d02@D6018?400?3@h02`T:
00d;300@3Pl03`d>00L61P091`P08b4R01XH6@0610D00@0000l=3`0N71l061HI01TG6P0B41<00P03
00D31P0H5QT040hA00805aDH00L01@<600l<300P71/030P701TE500G4a80J6AS00805Q8A01T08QhM
059>C@0@30/05Q8A01PF5`0?3@h05aDF01<A4P0:20T04@lB00h<3`0A3a803P`A00/93P0G5AX04PlE
00@21`0H5QT03P`?01<A500B41<03`d@010>4@0?3A003@/>00803P`?01@030X=00/92P040P<0@d52
02TW:00F51H020H900h<3`050`L04Q0E00`:3`17A4X0dm7F02PV:`0E4aH0518E01LE600?3A002@L:
018@4`<03P`?00<03@/>014?4_ooool04oooool001_ooooo01d0100501HA5P0D3a<01`8600P51P0H
51D03`/<014=3@0?2`X03@T800h:200B3P/04@l@00P61`050`@02@L800L51P0B41401083018@4@0>
30d03`d>024O801NG5d0XInR00d;3P0@3Q4030X=00l=4002010>4@0T00l=400>30l03`d@00l=400@
3Pl030/801TH5P0?3P`02`X800H41@0=2``040h?01DC5P0D4QD03P`?00l=4P0E41H040T@01<>5@0<
2A002`TB00T74P0B41/051<J018?5P0A3a804`hA01D?3`0I5AD0410@01/K6`0<30`07QhN00h>3P0M
7Ad04Q8B0`0A4A400`0B4Q804a<C018B4P03018B500?018A5P0E51T020L<014@5P0H5ad06QTO01XI
8@0L72404a@F00lA400G6AP0418A01<E4P0K7AX05ALD0080418=01@04aD@014C3P0A4`h04Q@?01@F
4`0F61D02P`;01DF6@0>3a<06AXO03Xj@@1nOXH07alY01HH800C5Q/05Q/O01PM8@0H7B<06b0V01LL
8P805QXS00H05a/T01PL9`0H72L06AdX01/N9`0C5Ql201DH8@0c01TL9@0_<c`041LO00hE7@16CED0
^/?:02Tb>@0I8RP05a`P01LL7`0I7R4061dP01DJ7@0R9bX03A8E01HK7P0K82<08bP[01TN8@0E6Qd0
6R8T01dU9`0K8bD05alQ01DM7`0H82<072@W024Y;@0Q:2h07B@Z01XQ:00L8b/051dT01TR:@0L9B`0
6b@Y01XS:00L9BX06bDW01TS900J92D06bDV01PR8`0F828062<W01@Q9`0O;380934g01l/<P0M:S00
72T_008082dc00@07BX`01XW;@0J9bd07BX`0P0O;3801@0N:c<082de028_=`0P;CH08Bdi00808Rhj
0P0Q;CT01`0N;3L09S@o02Dc?P0M:cH06RPa01d[=00J:C000P0I:2l02@0I:2d06RT^01XY;P0L:c00
8C0e02/j@@0/>T@07bdj01XX=@0201TV=P0d01TW=00F92l0528]010N9P0N:c409S<i014N900Q;S@0
72L]01LR:00H8bT07bP_01TR:@0@6B0072<[01XR;`0A6R/051d/018L:00@6R<05R0Y01DP9@0D7b<0
5R4U01PS:@0A6b@04adV01dU<@0<4R80:S0n01dS;P0E72@05QdS01LN8`0I8B@02A0F01PO9P0B6B40
6R4[01/R:P0E72@072<[01dT;00F7BD04aXR00dD700X;cL0<SU100dD700D6b<05Q`S00lB5`<04QHI
0P0E6A`0800J7R404ADH00hB5@0N8RD05ATL01<G6@0K7ah06QhM01/Q8P0H82<04a/N01DL8P0I82H0
6R8U020T8`0_<R/0=SP]07moM@17Bd`08RL[02/`=00V:c407B8X01HK8@0?4a`04ADN00hB6`0C5b80
5a/V00T=600A51/051LL0P0E61d0100F6Qd06AdP04Y>D@0I7Ah200`@4@0601PL700;3a0051@F018B
500X:2X0820R0P0C4aD01`0A4A<05aLI00H62000008071`N01XJ6P0D5QD0100C5A804@0D5Q<04A<@
01DG500F61D0418?00`>2`0E5a@05QHD00L9200<40l05QXM00P@4`0D71l03QHI010E600@5QH04aDE
00805ADC00D0;2h]01@F5@0I6aX05aTH00lA400401<E500301@F5@0G6AP06A/J00<04A<B00@0418A
00h@3`0@4Q404Q@C0P0C5A@00`0@4Q403a4@00lA3`05010B3`0301<E4P0D5Q<04aDB00<04Q@A00P0
4Q@?018E3P0@4Pd03@l:00h@2`0A4a00418?00d?30803Q0?0P0?4A00200@4@l03`l=00l?3@0B4Q00
51@B01<C4@0?3`d03Ph<0P0@40h02P0A4@l04a<A00P81P0;2`T051@B0041000S8b403Ph<01@D4P0E
5A<2010@3P04014A3`0H6AD0414<010A2`<0414<00L03`l=01<C4@0<30X030`<01@D500B4Q803Ph>
00H03Ph<00@04a<A018B400@40h03Ph<0P0=3@/0100=30X04A0>018A3`0A40h200l>300@00d<2P0@
3`d03Pd;00`;2@0B4@l06QTG00/:200=30X04A0>01<B400?3P`02@P601<B400B4@l03`h<00h=2`80
3`h<0`0@3`d300l>300O01@C4@0>3@/06APF00P71@0?3P`05A@B00h=2@0I61@04A0<00d<2P0>3@/0
4Q4?018@4@0=2`h02@L:01/I700?3A003P`?00d<2`0;2PP030/9010?3@0?3P`03Pd;00L61@0920H0
2PT700d<2P0;2PP01PD3018<4002014<400c010;3`0=2`h03@/>065OHP1LG5h03@d?01dM7`071`T0
3`lA01PH600h>3P04a<C010@40081`D01`H500X91`0?2`P05a<@014=2P0?2PH03@T700d;300<2P/0
3`d>010>3`0=2``03`d>014?400=2``03P`=014?40020040514A00h:2@0C3`h04@d<00l;2P0C3`h0
3PX9010<2`0?2`X04@d<02PT8`0[9bH061@B00l;200>2PL03`/8010<2@0B3P/0510=00803@T600L0
40`900h:1`0@30T03`/800h:1`0=2@H03PX700803`/800L06aLD00d91P0E4@h02PH300l;200F4Pl0
40l;00803`h:02l03@`800`;1`0>3@T040l;01/J5P0D4`l03Pd900`;1`0>3@T02`X800h=2`0B4@l0
1@@200h=2`081`D06APF00`;2@0920H04A0>00`;2@030P002@T900T8200:20T02`T:00h;300@30d0
510A00T41P0S7Al04@/=00l82P0E3a402@D6040n?`1<BT/05Q@E00D3100B41400@0000l=3P0B4140
0@0001LE5P071@H05Q@E00d;3002018@4@0H00`:2`0D4Q<040h?01<A4P1HEUL030X;01<A4P0>30d0
3`d>0040000:20T04Q0A01DC50071@H02`T:014?400C4A8040h?00/92P0:20T03Pd=00l=3P0A3a00
518C0P0>30d01`0=2``03`d>00h<3@0<2P/03@/<00h<3@0g<c@00P0D414200l;300900X61`0A3@h0
4Ph?00P41@0?2``05Q8C00d92P0E4A80510A00<04`l@00P03@T:01`H6@0C3a002`L801<?400=2@X0
6AHG01@B4`803P`=02H040h?00h<3@0?3@h05Q@E071^K`1CDE8030X;01dK70091`T01`D800<1100>
30l00@0200P62@0c<C@040hA00<1100<2Pd0108500D31P0I5QL04@d<00P4100810<00`0003Te=00=
2@P04@d<00h:2@0Q7A`00`0001@@3`0E4a@0518C00`:2`0?3@h020H7018@4`803`d@00/03@/@00l=
4P0D4QL04@lE00/93P0C4A@02`T<01<A500B41<0518E00h<3`0200d;3P0G00h<3`0?3A0030X=01DC
500610D09bDV018@4@0<2P`05Q@G00`:3@0C4AD03`dB00H42@0K61h0AdE:01XH7@0>30l03`d@018@
4`0>30l03@/>014?4P0=2`h00P0>30l00`0<2Pd040hAooooo`0Cooooo`006oooool0200?2Q0030L<
00l:3P0A31003`/=00h:2`0=2@X03`/;0P0?2`X02P0@30X04@d:01<A4P0D4Q<04Q0A03lm?P0D4Q<0
2PP900`:2`0>30d200l=3P0701DC5015@d@0EE=F01<A500=30h05A<F00d;3P0200l=40803P`?0P0?
3A007`0@3Pl030/800l>2P0<2`L081lM01`J6`0H5QL03P`=010>4@0?3A003@/@01@B5`0I5a`06A@K
00T5300?3A@09RD]01HE7`0>3QP03a0F018A5`0D51H0518C018>300?3P/061PF00`<2P0?3`h02`/;
010@400C4a<00P0@41000`0?3a00410B010@4P03018B500W018B5@0B4AH04Q4F01@C6@061P/06APN
018A600_;SH0SXfE01lO8`0C5A@051HE01LI600?4A005QPE02HX900J71L03Q0;018E3`0H6a@051L@
01<E4@0B51405QPG01hO800C51L051DI01@D6`0M7BH092@^05=CGP0D52405QLS014D6`0E6Qh05Q/O
01@I7`0F6b404aPN00805ATR01l05QXS01HJ9@0F6RD05QXU01XM9P0C5Ql05APQ00hA6P1JGFH0B4aE
00`C6`0Q:3004APP02D^=@0F7bH051dS02@Y;@0P9BP0724T02P]<00F6ah06AhQ01XO8P0I7R404AHI
01<H6`0G71l061dP01TR8@0L92D06b<U0080620R00X06R8U01XQ9`0I82L061lW01LN9P0I82T07B@^
01LN9P0I82P072<[0P0L8bT00`0M92X06R8U01`T9`0201`T9P0401hV:00K9BH062<W01HT9`<06BLZ
00P06RP[01d[;P0M:bh06bT/01XX:`0L:Rd07R`_01/Y;0807R/a00@072T_01`Y<@0M:S807R/d0P0O
:cL02`0N:SP07BTg01`X=P0N:cT07R`i020^>`0O;CP06RPa01LU;P0K:S406BP]008062L/03@06BP[
01XY;00G9bP05RDY01`[<P0O;CL07BXi01h[>`0J9cP06bPh01/X=P0I9c@05bD`01d[<`0H9B/0934g
014M8`0R;C<06B@Z01DO9@0D7B@09c0g02L_=P0A62004aXR01DM:@0=5RH06B8a01XT;`0E7bT06B</
014L8P0E82H05R4X01HP:@0C7BP05AlZ01TQ<00O9CD08RPf01<I9@0I82P08BP_018I7`0E728061lU
0:6X[`0[<SX061lY01DI8P0F6R<04aLP0P0G6b@02`0C5b005ATR010D7@0F6R<051PQ01/O:00F6R80
9BP]02@X:`0J7R404QHI008051PK03<04aLJ02hb=@0P92L03a<F01PL7`0G6ad05a/K01HJ6P0J7b80
6B0U01@K8@0B6b406B0V01<K7@0/<2`0=SP/09:AP`3emNH0Y:NU03i3AP0V:bl06AhR01PM8P0@5A/0
4QHO01@H8P0E6B@07b<^02L[=`0G6bH04QDO01@G7`0D5ah04QDL018E6`0C5Q/03A0E01DH700H71l0
3a<F01PL7`0=4A<05aLI01HF600Y:B/08B4S01HF600D51H05aLI010@4P0I6A/00P0E5AL00`0?3`l0
4Q@B01<E4P0301<E4P03018D4@0D5Q<0418?00805aTF014051HC00d?300E5A<05aTH01<G5P0=4QD0
3ADH00H>4@0>5QT03Q<F00hD500C51D04a<A018B400F61L03Q0?01<E5002014C4P0701XL6`0?4A00
3a4@00h@3`0?4A004Q@C01DG5P04014C4P0500lA400@4Q404A<B014C4P0B51<00P0A4a800`0A4a40
418?010B3`04010B3`0300h@3@0=3``030h;008030h;00X0418<00lB2`0=40T04A<=010B3@0>40/0
3a4=010B3`0@4Q404A8C0P0A4Q@0200B4a<04A4?014A3`0D51805QHD01DE4`0A4@l03Ph<0`0?3`d0
100A4@l051@B018B400;2`T3010@3P0801@D4P0;2`T06QXH00T91`0E5A<03Ph;00h?2P0>3`T2014B
3@0500h?2P0>3P`06a/I01DE4`0?3`l00P0A4A400`0=3@d03Ph<00h>300400h>3003014A3`0@40h0
410>00<03Ph<00@030/900l>300@3`d03`h<0P0>3@/04P0@3`d04A0>014@3P0B4@l040l=00d<2P0B
4@l03Pd;00/:200>3@/04A0>010?3@0B4@l04A0>00l>300=30X030/900/:20H03Pd;01l04A0>00X9
1`0D4a401`H4010?3@0<2`T03@`:00D40`0E518040l=00l=3P0B414040h?00X82`0B41<03@/@00T7
300;2@`0518B00h=2`0=30X04Q4?01DD4P0F5A<092<Q00`;2@0=30X040l=014@3P0<2`X04@/?0080
3`X>00T040/?010>4@0@3Q40BDM:04A4AP0>3Q001PH801XJ700B4Q@00P0@4100600:2PX05QHF00D4
0P0B4@l03Pd;00l;200A3@X03`/8014<200@30X04@l@00d;30091`P04@l@010>3`0?3@h01`D601HD
5@091`P05A<D024O800?30`02PH500l;2P803PX900D05Q8A00h:2@0C3`h03`/:00/71P0201PD4`03
00l;2@0>2PL03PX700803`/801@04@d:00l;200>2PL03`/8014=2P0?2`P040`900`81@0=2@H03PX7
00d91P0>2PL040`901<?300a;BX09R8O00d9200I5A8030T600h=2@803@`801803Pd9010?2`0@3`/0
2PT501DD400>3@T030/700/:1P0=30P02@P600h=2`0A40h00`8101hM6`0?3Pd040l=00`;2@0D4a42
00h=2`0401<B400@3Pl03`d>00h<3@8040`=01P04@d>01TC5@0C3@l02`H70189300D2`h030H8014=
3P0=2``02@L801<A4P0<2P/0=C<d02TW:00n?3d030X;01LE5P091`P04Q0A01LE5P0@3Pl02`T:00T7
200:20T2018@4@0<00`;2`091`P0;B//00h<3@0;2@X040h?00`:2`0;2@X02PP900l=3P0B414030X;
0P0>30d02P0?3@h04@l@01<A4P1UHf@07A/L00h<3@0E4a@04@l@00/92P0=2``200h<3@0A00`:2`0=
2``03P`=01XF5`060P<03`/<014=3P0B3Pl03`/<00d92P0D41406aLH00h:2`0C3a003PX;00l;300>
2P/00`0=2@X02`0>2P/04`l@014=3P0@30d0510A00l;300@3@h03P`=00X82@0;2@X03P`=00803@/<
00d01@@402HT9@0M6a`02`T:014?400@3Q005aDH00d;3P0:20/01P@701XH6`0i=cX030X=00<03@/>
00H05Q@G00T6200J5QD07QXI01<?3P0=2@P201@@3`0F00P40`0C3`h01`@301HB4@0i=C@0f=OH0;^i
^P0L6Q/0518C03Dc=00Y9bX04@lB00/9300=2a005Q@I010>4`0=2Q004@lD00d;3P0;2@`03`d@00H4
1`804@lB00X03P`?00`:3@0=2`h03P`?00d;3P081PL03P`=00X82@0D4Q<02`T;0P0@3Q403@0?3A40
2`T>00d;400A3Q@030X?00X83@0;2@`030X=00X82`0<2Pd04a4D010>4@0=2`h00P0@3Q400`0>30l0
4@lBooooo`0Cooooo`006oooool07`0A2Q405@hD01TC5`0D3Q803`T<01LA4`0<1PP03@L8010:2P0B
30`050l=01<?300@3Pl030X;0040000a;c002@L800l=3P081PL030X;00L51P0@3Pl04Q0A00X82@09
1`X05aDH00`:3@0F51L03P`?01dK7P0>30l00P0=2`h02P0>30l03`d@010>3`0A40`03`h:00X91@0T
8b407ahL01@B4`0?3@l200l=400A010>4`0C41L05A8I01D@5`0>2a@081lW03He?`0D51h00PD>00d@
5P0@4AH04A8D014A400A3@X02@P500X:200B4Q000P0C4a401@071`L03`l?00h>3P0>3Q003@d?0080
3Ph@00@0410B014A4`0A4A<04Q8E0P0C4QL07`0B4AH0:RT_018A6@071`h06QTQ0450B00@41@0418A
018D4`0B51804aDB01PJ5`0N81`05QPC014C3P0H6Q@061/D01HI4P0E5a<04Q@C01<D5P0E5QX05aPL
01DF700@41P06QXT01HF8`0F5B<05QDU014A800B5A`00P0F6al00`0B5ad051TO01DJ800301@H8@<0
51PS00T05QTR00P;500E624030lH01@G800Q9Bh020lG010G7`0F7BD00P0J8bX05P0J8bT0;S<g02DZ
;@17C4l0QHZ=02db=@0L8B@06AhQ01/P8`0O92L04AHI01XO8P0B5aX05b0O01HO7`0G7b406R8T01/S
9P0J8RD08BP^01`S:P0K8RX201hU;`0D01XQ:`0G7RH05ahV01PO9`0I82H06R4W01TP9P0F7R407BDW
01PP8P0E7Al06b<U01/U9P0U<3@07R`_01DS9P0B82<05R@W01/Y;00L:Rd201h/;`807B/^00<07R`_
01PS9`0L9bd00P0L9bd00`0K9Bh072H_01/U;`0201`V<P0;01dV=@0L9C@06RHd01/W=@0J9S@06bLe
01dY=@0K:34062D^01h[<`0K:2h00P0I9R`0200K:B`072X]01/[:`0H9bX06BP]01PV<00J9cL082dm
0P0H9CH06@0H9S@06BLd01TW<P0I9bl0QY>I0;W6c00b?T@0Qi:H07V2R@0S;3<05QlV01<J8P0@5al0
2A0H01DL900L92l03QLV01/T<`0J92l051hX01XT;@0>62404adV014K9@0A6bH00P0C72/0?`0I8380
318R02H/>P0C6BD03QDM00XA6@0O9R`072<Y01TP9P1?EUd08RTc01PO:@0C5b008BD^01@H8@0F6R<0
7R8[014E7P0E6B8051PQ01dQ:P0>4Q/03a<L01DI8@0Q92T08BDX01TM800C5aX05ATL01HJ7@0M8B@0
@DE802``<`0;3a805a/N01<G6P0H71d051PI01HK7`0J8BL05QlV018K8@0G7R@07RHX030d;P0k?2h0
KFaJ0=;@_@2=ShX09R/^09JKWP22Qh/04AHK020U:`0D6240720Z01/O:P0D62@04QHR01DI9@0A4al0
4aDQ018E7P02010C700;014D6`062A002`hC00lB5`0^<CH0CE1E018F6@0E5AL04Q8D01@D5P0<30h0
0P0A4A<01`0E5AL06a/M014A4`0C4aD08R8T0000000A4a000`0C5A005@0B50l04A<>00lA300J71L0
7b4L00`>2@0E5a8051HA00h>30051`H06QhM038f>@11BD`041PK00lG6P0=4QD03Q@D01<D5@0A4@l0
3`l=01<E500201@F5@09014C4P0>40l03Q0?018D4`0C5A@04Q@C010B4@0B51<051HE00804A<B0`0B
51<01`0A4a80418A010B4@0A4a804Q@C01<E500A4a401@0?4@h2010B3`0A00lA3P0>40d03Q0=00h@
3@0@4`d03A0700hA2P0C5Pl03a8;00h@2`0A4`l0418?010B4@0A4a<04A8D018C5`0?41400P0<30X0
1P0?3`d04A4?010@3P0@40h03`l=00d=2`80410>01T03@d;00P81P071`D0410>01<C4@0;2`T03`l=
014A3`0<30X04a<A00/;2@0C4a404a<@00h?2P0>3`T051D@01DF4@0?40/04a<A010@3P0<30X03Ph>
01dM7@0S8b<06a/K00H03`l=00@03Ph<00d=2`0=3@/03Ph<0P0@40h03@0>3@/040l=00l>300=30X0
3Pd;014@3P0<2`T03`h<00h=2`0<2`T03`h<01DD4P0;2PP00P0J6AL0100>3@/020L500h=2`0<2`T2
00h=2`803`h<00X03Pd;00`;2@0=30X03Pd;010?3@0A40h04Q4?01LF500C4Q002PT70P0@3`d03P0B
4@l05aHD00d<2P0b<Bl04@l@00`:2`0I5aP03@/>00P62@0F51L030X?01DC600<2Pd03Pd<0P0:2@L0
100=30X03Pd;00h=2`0X9bD200`;2@0500@30P081`D030X;01<<4P0@2a400P0?2Q009P0>31403`dB
010>4`0<2a003@`A01DD6@061@X02@T;01@D500;2`/030`<00H61P0C4Q003`h<00/:200>2PL04Ph;
01@@3@0A30P030P600d;300<2P/0=cDf030^;`0<2P/03P`=010>3`0C4A803@/<01XH6@13@D804a0@
00/71P0L61L05A4@00`81`0I5A@03PX90P0=2@P01@0>2PT040`;010<2`0A3@/04@`900<040/800@0
4@`900l:1`0B3@X04`h;0P0>2@H09@0A30T02`L400h:1`0@30T03`/8010<2@0E4@h0:BDR01@@3@0B
3P/05A4>00<0000N6QL040l;00h=2@0<2`L03Pd9010?2`0?3PX02@P4018A3@0<2`L040l;018A3@0A
40`01`H400X91`0D4a403Pd;02@S8@0P7ad0C4]901PG5@0;2PP01PD300l>300;2PP00P0<2P/01`0;
2@X03@T:00l;300?2``030H801<;3P0J4A@00P0D2`h00`0D3Q005A4B00l=3P02010>3`0900L51P0H
5QL03P`=01@B4`0N71d02PP9018@4@0100002PP900801`D600P05A<D01dK70071@H03@/<00P61`05
0`@07Q`M00D310802`T:01/02PP900`:2`0C4A8010830040000@3Pl030X;00T7200;2@X04a4B01TG
602k^KX0>3Hg01LE5P0>30d02PP900d;300<2P/03P`=00d;300;2@X030X;00d;300=2@X03PX;00l;
300@30d00P0>2P/01`0B3Pl05A4B01PD5@0C3a0081`M00`82@0@30d00P0?2``00`0@30d04@d>01LC
500200<0000400P41@0>2P/06aLH00d:2`8020H701d02PP900`:2`0=2``02@L801DC500@3Pl02@L8
01@B4`0100003@/=00d;400B41D05Q@I01PF6`0=2a001@@800L52P0610T07Q`Q01<A5P071@X04PlA
02PR8P0R71`040X:014;2`0;1PH03@L700@00002010:2P0400l92@0X8b80W9ZK07EcM080518C00/0
0P01014?4P0C4A@02@L:018@5@0S8BH0518G014?5@0B41D02@L:00h<3`0200`:3@0404Q6B@0M6ah0
61HI00l=408030X=01D02`T<014?400?3@h01P@50040000@3Q003P`?01HD5`0?3A405A<H014?5006
10X040hC00h<4@0?3A0030X=00X82`0<2Pd03`d@01@B5@0B41<00P0F51L00`0C4A@05Q@Gooooo`0C
ooooo`006oooool07P0@2Ph03`T<01<?400B30h02`H800l;2P0@2P`03`X:010<2`0C3@d04Ph<010<
2@0@30/04@l@00h<3@0^;2d02`T:01LE600?3A004@lB00l=40091`/040hC00/9300F4AD00`0201DA
4P081@L05A0D00X82@<03@/<02403P`=010>3`0@3`d03Pd901XI5@0:2@L030X:00X82@0;2@X03P`@
00h<4@0?3A804@lE00l<4`0=2Q4040`C00T63`0921003PdE00/;4`0H62003a0F00h?4`0?3a403`h=
00l>2P0C4Pl020X701TK60051`@06ATG00<30`0G5aL00P0@41006@0@3Q404@lB014?4P0A3a<040lD
014@5@0B4AH04a8G01@C600E51T020L=00H52`0M72803`hD01HE6`0C4aD04A<B010B4@0>40h05ALD
01@F4`0A4a003a4>018D4@0I6aL00P0C5A00500D5Q@04A8D014B5P0<3A805AHK01LG800G5b40410L
01/J:00B4B406QTY01TH:00B5Ah05a`P01PL8@0F6B006QlU01lS:@0G6R405Q/Q0P0G6R<09`0F6R<0
5aXS01DH7`0H6b803a8I01TL8`0B5A`04aPN010E6`0L8bT03Q@J00`C6@0F7B<06R4W01XO8`0T:B`0
SI:F0?Olo`1BEe/05Q/O01`Q9@0H7B406QlS00@93@0J7b<04a/N01/S9P0F82805QhQ01TQ900J8BD0
5a`R028V;`0L82T07B4/01lV<00L8bd04QTS01TP:00201PO9`0C01XQ9`0K8RP06B0V01@K8@0M9BP0
5AdP010H6`0G7b806B<U018M8@0F8BD05b8V01PS9`0K9RX06RDY01/V:P0P:bl08Rda01lZ;00201dX
:P0>01LR9@0L9BX07BP/01lY;P0P:C0082Xc01XT;@0L92l07BLc01lX=@0P9cL07bTe01XU<P0J9S@2
01XV<P1401XW<00K:34072Ta01TV;P0G92X05b@[01TV;00J:2/062LW01h/;`0P;c@06BLa01@P;P0F
8c<06bPh01XU=`0J9cL072Xg01l[>@0S;ST0U9nU0<gHgP0S;C40Ae1E04eFF`0W;c@05A`R00`C6@0A
61h041LM01<J800F7BP01a0O01PO;`0L9C407RPb02/c?P0J8bh0628/01DM:00D7BX0624`01PO;`0D
6b/020hL00lE8@0N9C007B@/01PO9`0A62006B0X024X<00D6b@07bDa01@J9@0?4a`092Pa01HJ8`0G
6b@08bL`014E7P0B5Ql03A4J010D7@0B5Ql07b</018G7P0=41D2010D5`0R014E600G6ah06AdP01PL
7`0J6al04A8F01TJ7P0H6Ad05aPL02DY;00J7R404QLK01<J800D6b4051/R010H6`0H7B005ATE034c
:00P8A<0EUE705EGEP0U:Rh0@DI:02DZ<00F6b403a@J00dA6P0A5Ah051PQ014E800?4ah05ATT010C
70804aHO01L04A@K018E700C5Qd04aHM01PK800;3Q<0C4mD08^>T`0D5AT051DG01HF600E5AL03@d?
01DE5`0A4A<03`lA00d=3`0N7R005ADG00h>400E5AD0418?018D4@0201@F4`0M014C400@4Pl05aTF
00d?300F61D04A<@01@F4`051`@05QHF01PJ6@0C51H0QHZ=0<76bP0b=c/05AXN010E600A5AP05ALG
01<C4`0A4A403Q0?014C4P0@4Q404aDD010B4@092`X04A<B01<E500B51<00P0@4Q400`0A4a80418?
018D4`0301<E500401@E5P0C5A@04Q@C014C4@<0418?0`0?4@h200lA3080418=00`03a4<00h@3@0>
40d03Q0=014C3P0@4``04QD>01DG4@0>40/04A<>01@F4P0?4@h2010B4@804A8D01P04A8B014A3`0A
4@l051@B01HF500E5A<04a<A00h>300=3@/051@B01LG5@0C4a40410>01XJ600e=3804a8@00T91`0?
3`d04A0>01@D4P0:2@L03@`:00X:200E518200`=200601@E400E5Q403a0;01<C4@0@40h04A4?0P0?
3`l00`0C4a<05aLF00l?3@0500l?3@03014A3`0@40h03`l=00<03@d;0P0A40h04P0?3P`03Pd;00l>
300C4Q004Q4?01<B400<2`T02@P601`K6@0f=C<01@@202`[:@0h=cD08R4O00/:200=30X03Pd;00l>
308040l=00H03`h<00h=2`0>3Ph0410@018B4P0C4a<201HF5P0R010@400F5QH01`L701DE5@0:2PX0
3Ph>00`;2@0510805A@B00`;2`0A3a0040h?01@B5@0610L03@/>00/9300L6Ql01P@700l=3@0=30X0
3Pd;010?3@0>3@/030/902HU8`0J6AL081lM010?3@0?3P`05Q@E01@?4`0A31003`X>00h93@8030X=
02L01`H801TI6`0A4A<01@D700d=3`0B4Q@02PX:00T7200D4a@0108300d<2P0>3@/020L500P40@0=
2@H04`l<018=2P0@30X02`T:00`:2`1^K6d0I69S01DC500;2@X09B<T0040000A3a000`4200l=3P0A
3Pd040`;02XV9@0P71/03PX901hJ6@0C3`h03PX9010<2`0A3@`00P0;1`H00`0@30X040/800l:1`03
00h91P0Q014<2@0E40d04`h;00/60`0<1`@04`h;00`81@0?2`P04Ph;014=300B3Pd061@C04m;BP03
00003@T800/71P0I5A@0FeMF01<B3P0?3PX030/700h=2@0?3PX030/700T8100@3`/020L300`;1`0>
3@T02PT5010?3@0<2`T05A@B00802`X800L03`h<01LF500920H061LE00`;2@0>3@/040l=00803@/<
02L03P`=014=3P0D41405A4B02<O800>20X02@<501PB500=1`T050h@018>3`071PH04Q0A00T7200F
51D01P@500h<3@0i=cP04Q0A00L51P0A3a0040h?00`:2`0=2``0518C02h/;@0g=CH030X;00X82@0F
51D020H700<10P0H5QL020H7010>3`0=2``020H700h<3@0;2@X00P0?3@h0300@3Pl03`d>00h<3@0@
3Pl04Q0A03/i>P071@H04Q0A010>3`071@H04Q0A00`:2`803@/<00D02`T:00`:2`0=2``03PX;01DA
4P0200l;300800`82@0>2P/04@d>01<?40050@80=C4b05MCE00@30d300l;300<014=3P0B3Pl0=C4b
020L7@0F4Q<04@d>00P41@0H51D02`P900d;300?3@h03P`=0P0<2P/0BP0>30d02PP900`:2`091`P0
7A/L00d;300@3Q0020H900P62`0?3A402@L:00d;400@3Q802@L:018@5@2IUi/0LW1c00L52P0;20X0
40X:00d71`0C3@d04@/;01<=3@0A2`d0618D018<3P0G4A<02@<5014<3P0L6Q/08AlP00h<3P0G5AP0
20H900d;3P0;2@`00@0200`:3`0Q7b@040hC00d:400C4A@02@L:00d;3P0;2@`071XM08J4Q`0U8bH0
7adP01<A500<2Pd02`T<00X82`0A3a801`D601hL7P030@@05A<F00800`0A3a803@/?00X83@0;2@h0
4@lE01PF6`0@3Q403@/>00T72P0;2@`03P`?00/9300=2`h030X=0P0@3Q400`0=2`h040hAooooo`0C
ooooo`006oooool04P0>2`T03P`:00@30@0C40h051<@00/:1P0C4@l06aTF00d<200@3@X07Q`I01DC
400<20L04@d=010<300?2``04PdA010;4@8040/B01d04`dH00h8500>21D050hI014:3P0A2P/04@X:
010;2`0@2P/040/:010<2P0=30T030/800X91P0<2`H03@`800h=300?3@d030X;00X92`0>31004a4F
010=4`0?31@03@XB00/84@0>2aD04@hH010=5P0200l<4`0B00l=500@3a@04A0E010?4P0K6Q/01`H6
018A3`0>3@T0310:00XC2`0;4``03aD?00`?2`0;3@X0410>010?3@0A3`d050l@0P0F3a405`0E4AH0
3@`C01HE6`0U92X051<I00d<4@0A41@04Q8D018B4`0C4a<04Q8A018B400B4a004A<@018D4@0D5Q@0
4Q@C01/M700N82004Q@D014B5@0D5AP05AHI00804a@G01T04a@I01TJ800K6b@05aLQ01TI900H5b@0
61LU01DD900F5BD06aXZ01HE9@0S8b`06Q`Q01HH7@0G61d04aDJ01LH7@0C51T06A/P01HH7P0K7280
5aTO01PI7`0C5aX05ATK00804aLI01405a/M01HJ700I7Al061`N01HJ700C5aT05AXL01hR9@0H7B80
7R<X04I;D@2;T9L0:Bde02hc>P0E6R4061dU01TM9`0201LK9@0@01HM9P0C7bH04alX01HN:00F72L0
6a`Y01lN:`0R8Bh07Qh[01`N:`0L82`06b0/01LN:@0M92d07B@/01PO9`807B@/05d07bH^01dT;00J
8BP05ahU01HM900H7bH06R4X01/S:00L9BL082P]02@/<P0[<cX08RXa01/S:@0O9bd07RLY01/T900N
:2H08R`Z01lX:@0O9bT08b`^01lW:`0I82H07bL^01dU;@0O9S007bHa01lU<@0N93407BD`020Y=00N
:3<07RPb01lY<`0K9Bl06B<]020Z=00G8B/08R`e03Q2B`0G8BX07RPa01HQ9`0L9Rh072L`01TS;P0H
8Rd062<`045;F@0L9CD072Hf01PR<`0U;Sl06R8^02/a=`0]<cP05ahQ01LM800K8B@05ahN01PN7@0G
7A`05A/J01@J6@0F6ad0>3i7061WN00E6Rd05Q`/014H9`0C6BP05A/Z01@K:00G7B/061h/01@K:@0B
62H051`V01HO900D7B<05QlU01PQ:00F7bL04QXT01XR;00F7RX08BTe01<K:00H7bd061`W018F7`0D
62400P0c=d00200C5b006alX01@F7`0D62406QhW01HJ8`0D62005AXM0P0D6QX201DI6P0:01LH6P0E
5AL05ADG01HE5`0H51P06ADI01XH700K72406A`Q01LJ7`805QXN01l05QXO01PL8@0L7b@051PL01/M
7`0I71h08bHX0495D00k?DX04A<O01LI900B5Al04aHO01@G7P0B5A/082<Y01TL8P0D5a`051PL01HG
700C51T04Q<H018C5`0B4aP051DI01DF6P0B4aL03@hB01TJ7P0G61`06a`P00804A8D0P0B4aD08P0E
5QP05aPJ01@E5`0F5aT05AHH01@E5`0E5QP061TK010A4P0D5QH05AHG018C500A4a<04a@E00h@400M
7al020X:01@F5P0@4A804A8C018C5P0@4A@0824U05YLG`1jOH007b4U01DG6`0D5QX03PlC01<D600A
4QD02``?010A4@0A4a82018D4`1<010B4@0?4A004Q@C010B4@0L7Qd07AlN00h@3`0=3``05AHA018B
400A4A404A4B01HF6@0@3a@0410B014A4@0B4`l04Q<<018C2`0A4Pd0410A010@400@4@d04A8<018C
2`0A4PT04A8:01@E3`0E5Q804Q8B00l?400A4A003@h:01DE4P0@40d04a<A00X:200A4@l0410>014A
3`0B4Q004A4@010@3`0A4Pl03a0;00h?2P0D5A005aPC01@E400@4@`02@X500l@2`0C50l0>CXe02X[
9P0;2PP061DD028O7P0>2PT04Q0>01DB4@0C3`h040d<00l<2`0F4Q404@l=010=300T9280?clm02/[
:@0:2PT02`/9010@3P0D518030`:01TI5`8030`:00L051@B01DD4@0@3`/05A@@00L60`0l>cL0=SDa
008040l;0`0?3PX00`0=30P03`h<00`;2@0201@C4@0300h=2`0C4Q003`h<00803`h<00@03Pd;014@
3P0D4a403Pd;0P0C4Q00600A40h03`h<010?3@0;2PP03`h<010?3@0?3P`03@`:00d=3@0R8bD0:bh`
014C5P062@/02`d@01LI7017BT`0YJNY05AGF@0<3Q407R4S00T:300>3@h03P`=00d;30803P`=00/0
3`d>00d;300<2P/04a4B00`:2`0@3Q0030X;01<A4P0>30d03@/<00l=3P02010>3`0L01TG600F51D0
1P@500d<30091`P07A/L024P7`0>30`02@P7010>3P0>3@`02PT801<A4@071@D03Pd<00`:2P0E4a<0
2PT800d;2@0L61L05A8A01DA400@30/04Ph=010<2`0?2`X03PX900l;2P8040`;00D02`L600h:2@0C
3`h06aLF00/71P0200l;2P0700h:2@0?2`X040`;010<2`0=2@P05Q8?014=2P0201<?300900`81@0D
40d03PX700d91P0?2`P04@d:00l;200>2PL04@d:00<03PX701/03`/8018>2`0@30T03PX700d91P0?
2`P04`l<010=300C4Q0081lM00d;300>30d09R@V06MUI`0B418030X>00<11@0=2`l040hA00/:2@0A
40h03`h<00P71@0;2PP040l=00`;2@0=30X00P0?3P`01@0>3@/03@`:00d<2P0=30X03`h<00804Q4?
00<03Pd;00`;2@0<2`T0100<2`T0200=2``030X;00d;300>30d03`d>00d;300?3@h03P/<0P0<2@X0
1P0>2``040d>00l=400;2@`03P`?00l=40802@L:01@04a4D00`:3@071@P04Q0C00h<3`0A3a802@L8
00/92P0=2``03`d>014?40091`P03@/<00`:2`0=2``04@l@00h<3@0;2@X03@/<00h<3@803`d>00D0
3@/<00`:2`0A3a0030X;00h<3@0200l=3P0H01<A4P0?3@h04@l@010>3`0=2``030X;00d;300C4A80
4@l@00d;300;2@X030X;00h<3@0@30d01P<301TE5P0B3Pl020@5014=3P0@30d04@d>00h:2`0@30d0
4@d>0`0>2P/300l;300b010<3@0?2``040`=010<3@0>2P/03@T:00l;300>2P/03`/<01DA4P0A3@h0
3`/<018>3`0<20T02PH700h:2`0=2@X02`L800h;300;2@X030X<00X82P0B41401P@600l=3`0:20T0
5A<E06ITIP0g=CH05A<E02/X:@0I5AH03PX;014=3P0=2@X03`X=01<>4P0J5AT050lD00/62`0@2a00
3PT?01<A5P040PH0518F01DC600A3a@030X?00d;400>314200l=4P803P`A01403P`?010>4@0=2`h0
3P`?01DC5P0L6Qd030X=014?4P0?3A002`T<00l=400@3Q4040hB01LE6@0A3a<04Q0E00l=4P0201<A
5P0A00l=4P0:20d02PP=00d;400@3Q<0518E00d;3P0?3A0030X=01<A500<2Pd02@L:014?4P0>30l0
0`4400h<3`0<2Pd05?ooool001_ooooo01T04a8@00L6100E51803@`:00H50`0J6AL07A`J01lN700?
3P`02PT700l>30061@<02@D601@@4P0>2@d030L;010;400300@03PT@00h94@0C3AL03`TD00`64P0@
2a804@P;00804@P90`0?2@T0100>2PT03@`800d<200>3@T200d<200:00D40`081PL04@l@01XH6`0B
41D02@L<01<@5`0>2a@030TB00d:4`8030TD00@03P/C00h;4P0>2a803`dB0P0@3Q<0?@0<2`d03`d>
01XH6@0D4a402`X8014D4@0D7AP0?TA002db<0031`H04A<B00l?3`0@3Pl04Ph?01@>4P0E3a<05`hC
01`G7@0E51X03`hD018A5`0B4AH04A0E018A5@0C4aD04a<C01<C4P0A4@l0410>01LH5@0A4a002@/:
00H81`0M7ah0HfAV065RI00E5QP04a@H01@E6@0G61`061TM01PI7P0?3aL04A4I020P:P0O7bT04Q8L
01HF8P0D52005A@R01HE9@0D4b<05A@S04Y:DP0b<cP05aPM01PI7P0K72406AXO01@E6P0M7R<00P0I
6Ql01P0B4aP030dB014E600D61/04aLJ018F6@805ATL02H06QhQ01PL7`0G6ah06AdP01/O8P0L82<0
3A8H028V;`0?4a`05a/T01XN9`0<41T06AdX01DI900J7RT08RHa024U<00D6bD05b4[01LR;00F7RT0
51XV01XK:00Q82h07A`Z024Q;`0Q9C407b<_01TP:`0G7bX061lY01lV<01FGFL07RD_01@K9@0M92h0
72<]01/R;08061lY01006R4[01/R:P0K8RP061lT01`S:@0L8b/08RTa01DL900J8BP06R4W01/S9@0L
9BD07BHS01hW900P:BT041PK0P0M9BP0;P0K8RP061lU024X<00N9Bl07B@^01hU;`0P9S8082Pc02D^
>00O:C<07RPb01dW<@0J92h0628/01dW<@0?6B<06B<]02li@`0E7bT05R0Y01hY;P0H8bT05R4W01LR
:@0I8b`06B<]04iHH`0M9c<04a`[01@M;00L9C@05alY01LL8P0F6al061dQ01DJ7@0G71l06R0P01HL
700D6QX041HF014G5`0F71`0CUAL07=iQ`0P9SH200lE8`0F01@J:00E6bT05adY01PN:P0E6bL04QPT
01@J9P0J8RX06R<X01PQ9P0H8BL05b0W01DN9@0@6B407bPa00`D7`0E7BT04ATV018J9P0=4A`04QHO
01@H8@803Q8K01004aLP01`P:@052A808BD^00L;500>4Q/09b/c01TN8P0E6Qd04AHI018F6@0C5aX0
4a@H01PG700G5Q/05QDJ0`0F51T0100K724061/P01LJ7`0F6Ah201LJ7`0U024T:@0>4AH09BP]0495
BP0H6b005QTO01HH900E5b@06adZ00`>6P0E62805QTR01DH7`0G6R004QDJ00/>4`0H6al04QHI01TJ
7P0@4AD06AXN01LH700B4aL0:2T]01DF6P0C51P051DI00/<400@4AD04A8F01<D5P0D5AL03a0B00`=
3`0J6ad0;2d_014B5002018C5@0N014B500B4aD05AHH01@E5`0>3a403@h@018C5@0A4Q@03PlA00`=
3`0>3a405AHH01PI6`020`D07b0R01DF6`0F5a`061TN00X;400C51T0414F00D62`0A4QL08b@Y00l@
5@0L7B805aPL014B4`0@4Q403a4@0P0@4Q40600A4a803@l>00h@3`0G6AP05ALF00lA400B51<030`:
0000000;2`/04a<E01PG700>3A404A4A014A3`0B4`d04A8:010B1`0?40/03Ph@00h>3P0>3`/03a0:
010A2@804A8:00H04Q<=018C3`0A4A40410B010@40092@L200d=2`05028R800B4Q003@d;014A3`0?
3`d00`0>3P`01@0@40d03a0;00d>2@0@4@`04A8=00803Pl:02L0004001<D3`061`80004001@E400G
5Q@020L5014@3P0D4a403Pd;01DD4P0B4@l06QTG02<R800J6AL01@@201<B40020P006a/I00X:2@0D
5180<S8`01/K6@0;2`T03Ph<01<C4@0<30X061PF01<C4@0>3@T061LC00h=2@0C4Ph03`h:01@C3`0B
4@d040l;00h=2@0@3`/00P0D4`l02P0920H04Q4?010?3@0A40h04a8@00P71@0>3@/04A0>018A3`0@
3`d200h=2`0=00`;2@0?3P`040l=00l>300>3@/03`h<00`;2@0?3P`040l=00h=2`0=30X03@d=01hO
8@0202LX:P0<00X;3@0I6Q`06Q/M05]LGP2e][P07b0R07=dMP0U9RP09bPZ00h=3P0>30d03@/<0P0>
30d0200?3@h04a4B02@R8`0A3a0040h?00X82@040P<03`d>0P0<2P/06`0>30d040h?00l=3P071@H0
20H700`:2`0Z:2T04Q0A00@20`081`D03Pd;00l>300<2`T02PT700/:20071PD05A@B014@3P0<2`T0
0@0001dL6P0>2`X030P701dI600H51<040`;01@@3`0200l;2P0@010<2`0?2`X03`/:00`81`0S7ah0
3PX9010<2`0A3@`020@3014=300?2`X040`;018>3@0@30/03@T8010<2P807a/H02L06QHC01<?300C
3``061@A010<2@0?2`P040`9018>2`0@30T04@d:00d91P0?2`P03@T600`81@0B3P/03@T6014=2P0B
3P/03@T600/7100@30T030/700l>2P0G5Q<04A0>01@C4@071PH01P@500<10P0C4A@00@0200X82`0>
30l040h?00d<2P0>3@/03@`:00X91`0;2PP00P0=30X300`;2@0700d<2P0>3@/030/900d<2P0?3P`0
40l=00h=2`0600`;2@03010>3`0>30d03P`=00803`d>00@03@/<00l=3P0?3@h03@/<0P0<2P/0400;
2@X03`d@014?4P0;2@`02@L:00/9300610L00@0201DC5P0?3A000P0300X92`0<2Pd02PP901HD5@0?
3@h200`:2`0:00l=3P0=2``030X;00`:2`0=2``02`T:00T7200>30d03@/<00`:2`803@/<01l03P`=
00`:2`0=2``03`d>00`:2`0?3@h05aDF00/92P0>30d03@/<00/92P0:20T02`T:00`:2`0100003@/<
01DC500B41401@<4014=3P0D41401P8300/8200300006aLH00h:2`0@30d03@T:010<3@0B3Pl03`/<
00803PX;1@0?2``0200>2P/03@T:00`82@0=2@X020D500D10P060P<02`L80P0D4140900E4A805Q8C
01@@4@0A3@h02`L800h:2`0>2``03`d>00@20`0A3a002`T:00P61`081`L061HG00`:2`0:20T03P`=
01<A4P0D4A8030P900/7200:1PL03PX;00l:3P070PH03PT=00d83P0:1@/04@`B01<>5@081P/0D4iC
05aJG`0100@07Q`Q01TG70803@/@0`0>31400`0=2a004Q0C014?4P0200/9300@00l=400:20/030X=
00l=400>30l02PP;00`:3@0>30l00@0400P62`0=2a001@<8018@5@081P/03P`A00d;40802`T>0P0<
2Pl00`0>30l030X=01@B5@02010>4@0700P62@0C4A@02PP;01TG6P030@@030X=01@B5@0Dooooo`00
6oooool02@0;2PP08b8P0040000100004a8@00T81P0100003@`:00h=2`0200d<2P0>00D3100>2@d0
5a8G00`72`0=20h061<I00d83P0@2a803PT@014<4`0?2Q403@P?010;4@0C2P`201<:2`<04@/;01<0
40`;00l>2P0A40`04a8>014@300?3P`05A<D00/92P0P7Ql0@3i102d[<00B41D05Q<J014>5`0@3AH0
4a0I018?6P0?31D03@XA008030T@0P0>3140700?3A806aTL00P61`0B41403`h<00/:20031080624N
09:HUP1ZKfl0004001hO8@0?3a0040hA018=4@0D3Q805@lC01L>4`0I51/05QDK00l>500=314040lD
014@5@0@3a<0410B014A4@0C4a8201<C4@0P014B400?4@h05aTH01XL6`072@P02``>01PI6`0E5QP0
4a@H01@E6@0G61`06AXN01DE700A4AT06a/S01XJ900C4ad051@N01DE8@0B4Qh05A@R01HE9@0B4B40
5QDT024Q:@0O82D06AXO014B5`0@4AH061TN01dN8`0W:2d2020Q9P0G01`M8P0H6Ah04aHK01LK7P0G
6Qh051LL01LK7P0F6Qh05QTN01<G6P0B5QX05aXO01PL7`0F6Ah05a/T028V;`0J7RL05QXS024U;P0B
5Ql0720[01HJ9@0I7BP00P0Q9C00;@0E72H05AlY01@M:00D72L05adY01/N:`0L7R/05aTV01lR;P0P
9S807B<_01HO:P0E7bT04ATT01`S;P1LHfd07R@`01TP:`0K8R`06R0/01XP:`0H7bT061hZ01TO:P0J
8B/06b8X01@L800G7R@051/S020W;`0D6b<06R4Y01TP9P0K8bH07RHW01dV8`0L9B@072@V03Dm@00J
8RD07BDX01dT:P0P9bd08RTa01lV<00201hU;`0401lU<@0O9c8092dh01hX<P807BLa00D072H`01/U
;`0P:S@07RPb01HP:P02010J900E02La>P0M:2d06bHZ01dX;P0O:S006bH/01LQ:P0@6R@07BLa01PR
;@0=5b<05Al[01/R;00K82H07B8V01lT:00J7b<061dQ01HK7P0D6QX04aTI00804ALG02/05A/K01PN
9@0X;SX041HT00hD8@0631P04QPV01LM:@0F72P06Al[01DK9`0B62@05A/W01PP:00G82D05QlT01DN
900D7B@04a`S018K8`0G82T031@O024Y=@0B6RL051/W00X>6@0W:c@05ATR014E7P072a@05a/T0002
2`16BU<03Q8K01/O:00B5Ql0A4U@01dR9P0G71l041DH010D5`0A5AP03a0D00805QDJ01h05A@I01DC
600F51T05QDJ01LH7@0E61d051LL01<F6`0D5a`05APM01XM8P0L7b@04QDJ01LJ7`0E61d06QdS01PJ
9P0D5R<05aTU010B7P0B5Al06QdV01DH7`0E61h05QTN00hA5P0E61`04ADH01TJ7P0C51P201LH700C
01DF6P0O82@05QLK01<D600H6Ad02P/?01DF6P0?41@03a0B01@E5`0C51H04A8D01DF600L7Al0414C
018C5@0A4Q@0414C014B500201@E5`1c010A4`0?41804Q<E00h?4@0;30h04A8D00H72@0A4Q@03@h@
01lP8P0?41@05aPM01<D6@0:2a0061TN01XK800B4aP061TN014B5`0H6Ah03a0E01HG700S92P04Q<D
00lA400>40l03a4@014C4P0B51<03Q0?014C4P0E5aH0418A00h@3`0D5QD061PH01XJ6P0K6ad061PJ
05mNH`0<30h04A4A014A3`0A4P/0418700lA100?40/03`lA00l?3`0?3`d03a0;010A2`0A4PX04A8<
014B3@0@4@h04A4A014A4`0?3`l04Q8@01dM6`0?3`d07AdK01<C4@0A4@l04Q8@010@3P0>3P`03@d;
00h>300?40`03Pl:00d>2@0?40/0414<00h?2P0B4`h030d8010A300>3`X05aPC01PI500G5Q@03@`:
01HE4`0J6AL03Pd;00/:200C4Q006aXH08V8QP17AT@07A`J00d<2P0I6AL051@B00l?3@0G5aD02PX8
00@40`051@<02PX8018B400?3`d0410>00d=2`0510004Q4=00/:1P0D4`l04Q4=010?2`0510003@`8
01@C3`0200d<200301DD400>3@/04Q4?00803`h<00<05aHD01/J600?3P`00P0B4@l2010?3@03014@
3P0<2`T03Pd;00803`h<0P0@3`d00`0<2`T03`h<00l>300200h=2`0@00h>300820X02``>018C5@09
2P`04A8D00D6200J6ad0=cPj02X[;@1TIFL0=3Dg00000P0?3@h03P`=00d;30803P`=00P03`d>01@B
4`0A3a001@<402DS900L6Q/05Q@E00`:2`802PP901003@/<00l=3P0>30d04@l@00l=3P0J61T0KF]/
01HD5@091`P03`h<010?3@0=30X02PT700h=2`0B4@l02@P60P0>3@/05P0?3P`09bHT092?S@10?3/0
2`L601HB4@0G4a802PH500l;2P0>2PT040`;014=300@30/03PX900d9200o>cX08alN00`9200B3Pd0
40`;018>3@0@30/2014=300;00l;2P0=2@P03@T701DA3P0G4a004Ph;00d91P0?2`P04`l<010<2@0?
2`P00`0@30T0700C3``02`L400d91P0A3@X04`l<00d91P0:1P<030P5010<2@0?2`P03PX700l;200<
2`L02`X600L610030P004a8@00d<2P0<2`T04a4B00h<3@0<2Pd04Q0C00T72@0?3P`02PT700`;2@0@
3`d200/:200500h=2`0=30X030/900/:200<2`T00P0>3@/00`0<2`T02`X800d<2P0200h=2`H030/9
00P04Q0A010>3`0?3@h040h?00l=3P0<2P/02PP900`:2`@03P`=01803@/>014?4P0:20/01`D801<A
500O7B003@/>00H41`0200<09B<V00X82`0F51L04@l@018@4@0100001`D600`:2`0>30d200l=3P0A
00h<3@0?3@h03@/<00d;300?3@h030X;00/92P0<2P/03P`=00l=3P0<2P/03`d>010>3`0:20T03@/<
01DC500<2P/00P0?3@h05`0=2``030X;00d;300A3a004Q0A014?40030@804Q0A014?400F4Q<04Ph?
00L3100F4Q<05A4B010<3@0B3Pl04`l@010<3@0B3Pl04`l@010<3@0?2``03PX;00<040`=00H03`/<
00h:2`0=2@X03PX;014=3P0D414201TE5P04014=3P0=2@X0510A00h:2`801P8300T02PH701@@4@0A
3@h030P900D30`0A3a003P`=01XH6@071@H00P0;2@X06@0=2``02@L801TG600:20T03`d>018?400;
1`P03`/<00/7200A3@h04PdA00X52@0?2Ph03PT?00X52`0>2@l040/B01XH7@0<2Pl04Q0E00l=4P0T
8RL0108700`:3`0=2a000`0>3140500=2a002@L:00`:3@0<2Pd03P`?018@4`0?3A002`T<00d;3P0>
30l030X=00d;3P0@3Q404a4F00d;400@3Q<00P0501<A5P081P/030X?0`0=2a001@0<2Pl02`T>00l=
400;2@`04a4D00803P`?00L02`T<01@B5@081PT03P`?00T72P0>30l02@L:01Cooooo000Kooooo`0E
01<B400V9B<09bHT03hm>`0=30X03`h<00T81P0>3@/03`h<00h=2`0?3P`04a4B014<4P0B3A@03@P>
01D@5`0Y92X0:RD[01@?5@0>2@h03`X>00803`/>00@04Ph@01892`0B2@X04PT:0`0@2PX04`0A3@`0
3@`:00l>300C4Q0040l>00h<300>30l040hA00l=400<2Pd03`dB01<A5P0C41L04@hE018?5P0E4Q/0
514J01<@600@3A@00P0?3A804P0A3a@04Q0C018@4`17ADP08R0Q01HD5@0Y9bP0=38c014B500:4180
51XL01<G6P072`d03@hB014?500@3Q<04PdC01@>50805@hE00X040`C010?5@0E51T05QDJ00h=4P0=
3@l04A4C018B500B4Q804a<C0P0B4Q801`0C51@061XI01DG5P0?4A005aTH01LH6P0B4aH00P0C51P0
2P0B4aP04a@I01LH7@0F5ad05QHN01hN9P0M7BL05QHP01LG8@0F5R8201DE8@0L01PG900I6BH05aLT
010@600F5a`06Q/P01DF6`0F5a`06Q/P01@E6P0N7b@05AHK01@E6P0G61d061TN014D6P0G6R006A`S
01@G7`0E61h05APO01PK8`0F6Al05QTP01PK8`0I72805aXR01<G8@8061`W01<05ATT024U<00E6B@0
6alZ01PL9`0E6B@05QXU01TM:00I82X06R8]01@L9`0E7BP06b4]01/P;00C62@05Q/W01XQ;00J8bh0
5R8[00804QlX00L072@`01TO;00T:SL02Q0N01`R<00I7b`05Q`Z00805adZ01`05ad[01PN:`0H7RT0
82L^01TP9@0N9B/07RD]03<j@`0_=T006R4Y01/R:00M9BP07bPX01hW9@0M9RD07RHX06A/K`0O9bX0
82L]01HM8`0P9bd07bH^020W;`0Q:30082La01`S;@0J8b`07RLa0P0K9Bl07P0O:C<082Xd020Z=00K
9Bl07BLa020Z=00N:3805AlY01@N9`0I8RH051hP01DN8P0I8RL06b@Y01XS:@0L9B`06b@/01DN9P0H
8BX04QXS01DM900P9B/07b@Z01<H7P0I7R<07B8W01DJ7`0C61/05AXN01DJ7@804QPH00<05Q`Q01DL
9@0@5b800P0C6R@0200H7bX04QTS01<J900F7BL05ahX01DL9P0D6bD051/S0P0E72803P0E72<05A`T
01DL900I82T03A@N02<Z=01?EV0092Xe01XQ;00P92h0C51I014E7P0N8R/03A4J0P0K7bP2010D7@06
00`?600P92d0=c]301@I7P0B5a/041DI0P0B5AX02@0A51T04Q<H018C600C51T051<I01HE6`0H5ad0
5QPM01DH7@0301@G700I01HI7P0H6b0041<H0454B@1JGF807b8W01TL8P0C5Ql06A`W018D7`0[;CP0
61/T01TL9@0G6R404QDK02LZ;`0P8bP051LL01HI7P0A4QH05AHJ00l@500F5a/07b0T00h?4`02018C
5`0901@E6@0?41@06Q/O00d>4P0D5AL04Q<E014B500C51H051DG00804Q<E02@051DG01<D5P0B4aD0
4a@F01HG6@0>3a404a@F01HG6@0E5QP04a@F018C5@0@4A<05QLI00X;3@0T9BL0UIJH02HW:`0B4aT0
410H00h>5P0B4QX02PXB00l?5`0D51`07AdU014A6@10@4P03@dE018C600B4a@0418A00lA400@4Q40
4A<B018D4`0C5A@201DG5P0W00lA400@4Q404aDD014A4`0C4QH0MWEj02/Z;`0C4aD04Q8C014A3`0A
4P`04A8:00lA1@0?4@<04A8;018B500A4A404A4?010A300A4Pd04Q<=014B3@0@4@`0414?014A4@0B
4Q@04A4A01`L6P0^;R`04a<A014A3`0>3P`05ADC01@D4P0B4Q00410>00l?3@0@40h03a0<00803Pl:
01d0414<018C3P0C50l05QLB01<D3`0>3`X04Q<>01LH4`0@4@`020L501@C4@0A40h030/9010?3@0A
40h05aHD01TH5P17AT@07ahL00P71P0C4Q002`/:014A3`0:2PP03`l=014A3`0?3`d04A4?00h>3002
010@3P0400L71@0S8b40?C`h00`;1`803Pd900h03`h:014@300T8al06aXF00l>2P0@3`/04a8>00h=
2@0F5A<03@`:014@3P0>3@/05A@B03He<`804A0>00D040l=00l>300C4Q006APF010?3@0200l>3006
010?3@0A40h04A0>00h=2`0?3P`03Pd;0P0=30X0400@3`d03Ph?01<C5@092P`030d?00`<3P0@4A<0
1`P:018C5@0E5QP0EUMI01TJ700?3a403`d>00h<3@0=2``200h<3@0D00l=3P0[:BX04a4B00P61`0D
4Q<02@L8010>3`0?3@h03@/<00h<3@0A3a0040h?00l=3P0:20T0518C00`:2`0W9BH040h?01HD5@0>
3@/200/:200M00d<2P0>3@/03@`:010?3@0A40h03`h<010?3@0@3`h0BDQ602HR8P0;1`H040`;014=
300;1`H04@d<00l;2P0@30/04@d<010<2`0?2`X04`l>01TE500C3`h03`/:018>3@091@@040`;014=
300?2`X00P0>2PT0100?2`X04@d;00d91P0A3@X2018>2`0301DA3P0?2`P03PX700803`/800D03@T6
00h:1`0?2`P04@d:00l;200200`81@0F014=2P0@30T03@T600h:1`0G4a006QHC018>2`0<2`H040l:
00d<1`0;2PD04Q4<00/:1P0920@03`h;00L6100E4a<03@`;00/:2@0<2`T02`X800`;2@803Pd;0P0=
30X01P0<2`T02`X800/:200;2PP03@`:00h=2`8030/900<03Pd;00l>300?3P`01P0<2`T01@0A3a00
3`d>00l=3P0@3Pl03`d>00<03@/<01/03P`=00d;300=2``03@/<00`:3@0>30l08R0S01hL7`0C4A@0
;bd`01TG6P0:2@/06aTL06QVJ@0B41<02@L:00d;300G5AH02PT901@B4`0A3a001`D600`:2`0>30d0
3@/<00`:2`0>30d00P0?3@h01P0=2``030X;00d;300>30d03`d>00h<3@8040h?00@02@L800P61`0?
3@h02`T:0P0>30d03`0=2``030X;00h<3@0=2``02PP901LE5P22P84071XK01HD5@0=2@X081`M04U5
AP0@30d04@d>018>3`0201<?40<03`/<0P0>2P/00`0<20T03PX;010<3@0200h:2`<03`/<01<040`=
014=3P0F4Q<061@E01DA4P0>2P/02`L800l;300B3Pl04@d>01@@4@0A3@h05A4B02/W:00W92D02@P8
01HD5@0?3@h02`T:00803@/<01L03P`=00T7200V92D02PP900L51P0=2P/030P9018>3`0;1`P03`/<
00l:3P0>2@d040/?010;4@0=20h03PT?014<4`0<2Pl061HK018@5@0=2a001@<800l=4P0200`:3`80
3P`A00D03@/@00`:3`0610L03`d@01@B5@0200`:3@0400h<3`0<2Pd030X=00h<3`803`d@00T0518E
05UGG00G5AX020L;01DC60071@X04Q0E00d;400>31400`0?3A802@0>3140518E00`:3@0C4A@030X=
00h<3`0A3a803P`?02LU:00200l=400300X82`0<2Pgooooo01?ooooo000Kooooo`0700D3100^;2d0
81hO03Hd=@0E4a@0108300d;300200T7200=00P61`0>30d081hQ01XE700B31L05Q0J01TC7@0E41L0
4`hD018=4@0?2Pd0510?01DA400200l;20<04@P90`0?2@T04`0B3Pl02PP900/92P0?3@h03P`?00X8
2`050`L03@/@014?500@3Q<02`T>00P62`0?3A804@hE010=500?31<03P/B00l<4`0=2Q000P0<2Pl0
4P0=2`h03P`?00l=400K6A`030X=00<1100D4QD09bDX010@5@0C5Qd00`H=00X<4`0E5Q/05A@L01`K
8P0?3Q@040dD018>5@8050lF00@05Q8H010?500@3a@05QDI0P0;2`d0?@0E5AL04a<E01<C5@0C4aD0
4A4C010@4P0?41404aDD01DF600A4Q@04a@F01LH700E5QX04a@H01DF6`0C51T04A8G01<D6@0F5Qd0
410H018B6P0I6B<05QHP010@6P0H62806a/U01@D7P0I6B<09RH`01XJ9@0E5Ad05AHK00l@5@0>3a@0
51DJ014B5`0Z:c00=CHk02HW;00N7b@07b0U01XJ8@0?4Q/05aXS01XL9`0C5B404aHO01@F8@0E5b<0
5QTR01HH8`0C5B404aHO01HH900J7RT0720/018F8P0H72P06QhZ01`P;00E6B@00`0D62<05`0H72H0
6alZ01TO:`0H7RX05Q`X01LM:@0L8Rh082Pc01/S;P0G7bX04adW018O:00C8BX0524Z01DM:P0L8S80
7R@d01`R<P0M8c<03Q@T01DK:`0F72`05ad]008061h^01<061hZ01TP:00F7B@06R4Y01TP:P0X;cT0
8bXd01LN9`0N9B/07bLZ01`T9@0L9B@07BHU01`T:00J8BL072<Y02<Z<00J8BL06b8X00<07RD]01h0
7B@/01/R:P0I8R/0624[01PR;00K9Bl07bTc020Z=00O:C<07BLa020Z=00N:3805R0Z01hX<P0N:340
6R@U01LQ8P0E7b0051hP01TS9@0M9bT03QPJ01`U:P0E7R<06R<X00hG700F7B<05AXP018F7`0D6242
01TM9P0`01HJ8`0F6b405a`R01DJ7@0A5QT041HF00lE6P083aD06R4Y014H7`0:4AT051/S01<J8P0A
62003aHN01<J8`0F7BL051/U01<J8P0G7R@061lU01HM900D6b<05A`T01XQ:@0A62006R4Y030g?`0G
7RH07B@]00D94P0T:3404QHO02<W<00E6B804aLP01DI8P0A5Ah05QXS014E7P0?4a`02P`E00d@5`0B
5A`05QTP01<F7@0A51/04aHM0`0@4aX00`0C4a/051@L01DE7@0201@G700D01<F6`0D5a`05APM01HI
7P09314041<H02T/<@0d=c`051LL00d@5@0@4aX05aXR01HI800Y;3<09RT`01@G7P0C5Qd04QDK01lR
9`0I724201LJ7`0C01LH700H6Ad051DI01XK7`0O82@04a@H014B5P0N7b<04a@H01@E6@0C51P03@hB
01@E5`0C51H04A8D010A4`0C51H05QLI014B500201<D5P06014B500C51H05QLI01PI6`0C51H04A8D
0P0D5AL05@0B4aD05AHH00T:300?41802``>03Df>00A4QH0:b/d00P84P0N7RP06QXT00h>600C4ad0
8R8/0;Bd_P1aLG/0BTYD00l?6@0N7RH0414B010B4@02014C4P0J010B4@0?4A004Q@C01@F5@0B51<0
4A<B018D4`0A4Q@03`hC00d<4P0<2a409bH[01@D5P0>3Pd03Pl:00l@2P0@4PP0418500lA0`0@4PX0
4A<B010B4@0?4@l03Q0=00lA3P0?4@d200lA3P0;010B400A4a804A<B018C4P0410801`L500h>300P
81h04A4?00l?3@0@40h00P0A4@l2010@3P0300l@300?40/03a0;00803a0;05804Q<>010A300;30L0
4A8=01PI500=3PT051D@010@3P0O7ad03`l=00P81P0>3P`0410>00L71@0D51803@d;02DU8`0G5aD0
4Q8@010@3P0=3@/03Ph<01LG5@0<30X04Q8@00T91`0=3@/02@T7018B400>3P`0:b/Y04U8A00D4`l0
5A@@014@300?3PX04Q4=02XY9@0L6aL030/701<B3P0E510030/700/:200>3@/06APF01HE4`071P@0
0`8000h=2`0@3`d03`h<00h=2`0@3`d051<A018A3`0>3@/030/900h=2`0?3P`03@`:00h=2`0?3P`0
3@`:00`;2@0=30X04A0>010@400410@09BDU00410@0B4Q80000000T92@0@41000`<3018B4P0<30`0
3Ph>00l=3P0>30d03@/<0P0>30d09@0?3@h01@<401<A4P0G5AH02`T:00H41@030@8030X;00X82@0;
2@X030X;00/92P091`P04@l@01@B4`0F51D030X;01/I6P050`@030/900h=2`0A40h04a8@00l>300<
2`T03@`:00H50`071P@04A0>01XI5`0A40h04@d<02/W9P0K5aH04`l>00h:2@0@30/00P0?2`X02@0>
2PT03`/:00l;2P0D40l00`0004E1@00Q7A`04Ph=00`81`0200l;2P0/00h:2@0?2`X03`/:010<2`0>
2PP01P80018>2`0A3@X02PH3010<2@0:1P<03`/8014=2P0?2`P03@T600h:1`0?2`P06QHC00X60`0M
6AH09B4N00P40@0D40d040`900l;200E4@h05a<@018>2P0@40P02`/300H600071`002PX201<B3@07
1P404a8=014@300@3`/010<000`;200:2@L05A@B00l>3005108200d<2P0400X91`0;2PP030/900`;
2@802`X80P0=30X0100>3@/04A0>014@3P0>3@/600`;2@0A00h<3@0=2``03@/<00h<3@0?3@h03@/<
010>3`0>30d030X;00/92P0<2P/03@/<00T72P0C4A@0JfU/06UWJP0<2Pd00P010080300K6A`0518E
00400P0E4aH03P`?00`:2`0i=cP081hO01DC50050`@04a4B00T720<02`T:00@03P`=018@4@0=2``0
3@/<0P0>30d02`0=2``030X;00d;300;2@X03P`=00/92P081PL02`T:00X82@0=2``03P`=00803@/<
01X03P`=00T7200>30d00@0002/Y:P0100009bDV00d:2P0>2P/0=30a014=3P070`@00`0000d92P0>
2P/02`L800d92P0>2P/04@d>01<?400@30d04`l@01DA4P0B3Pl040`=014=3P8040`=01d03PX;00`8
2@0X92D09R8S010<3@0G4a@04Ph?00H20`0=2PX05a<D01<?40060`<00`0001`H6@0P7Ah00@0004I4
A@0B41404@l@018@4@0;2@X04a4B00800@071@H02PP901<A4P0A3Pl02PH700l;300200/720<03`X>
00`03`X@00h93`0=20h04@`C010>4`0=2a005A<H01`J7`0@3Q<04a4F00/93P0<2Pl200d;408030X?
00@040hA01PF6@0I5aX03`d@0P0=2`h0300?3A0030X=00l=400?3A002`T<010>4@0100@03P`A01@B
5`0H5Q/02`T>00@21`8030X?0P0=2a003P0>31403`dB00T72P0@3Q40:RP[028P8`0A3a8020H900l=
400U8bH04@lB00`:3@091`X06QPK5?ooool001_ooooo01T04a4B02HT9@040P<030X;00X82@0<2P/0
3@/<00/92P0?3@h02`T:00X82@0I5aX06aDO01D?6`0R72P09AlY01@?5P0>2@l040/?010<300I5A80
6ADA00l<1`0;20<04`/:00804`X;0`0A2`/04`0E4A802`T:00/92P0@3Q403`d@00`:3@0@3Q<03`dB
00`:3`091``03P`A01<A5P0@3Q<0514H018?5P0=2Q4030T@00h<4@0@3Q<00P0?3A804P0@3Q404@lB
018@4`0M6ah06aTL01HD5`0>30l05Q@G00d=4`000``09BPa01hO:@071`l08R4Y010?5`0?3QH040dD
018>5@8050lF00T04a4F014@5@0N7B80=SHi01hN80092@/03@d?010@4P0A4A<00`0C4aD0=P0E5QP0
3a4@00d>400E5QP04A8D00h?4`0B4aL051DI01LH7@0E5Q/04Q<H01<D6@0D51/04a<K01LG7`0F5R00
4A4K01<C7@0I6B<07alY01@D7P0I6B<0;2`f01/K900?41D061TN01XK800B4aP05AHK01TJ7`0C51T0
8B8W01PI7P0E5Q/061TN01<D6P0A51d06Q`X01`N:P0F62@05ALS01HH900G6BD06A/W01PJ9P0D5R80
4aDQ01TK:00D62@03a<O01XM:`0b=T802`lK014E8@804ADP01@051PS01PL9`0K7bT06AdV01<I9@0G
7BT05Q`X01@J9P0Q:3<0<c]6020X<`0G82X04A/U018O:00F8b`0628/01@K:`0G7Bd06Al_01HL;080
6Al_00<05Q`/01LM;@0H7Rh00P0I7bl05@0I7bd05ahV01HM900H7bL04APR01HM9`0<4ad05A`V01hU
;@0N9B/06B4T01XS8P0M9BL06b<W01dT:P1MI6X0:2le01DL8P0O9R`082L_01`S:`0201XQ:@0701/R
:P0J8bX05b0Z01PR;00K9Bl07bTc01hX<P0201`V<00601/U;`0M9c406R@^01XT;P0=5b0051hP0P0K
9BH0@@0E7b404Q`N01<M7`0H8R@06B<U01DO8@0R;2h03QPJ01HL8@0?51X04ADN02L[=00O8bh04aLR
01@H8`0H72D05a/T01<H7@0@5AP04ALG01PO8P0:4AL05ahT00`C6@0=51X061lW01DL900A62002a8J
00lF7`0G7RP05A`V01@K900H7bD06B0V01DL8`0A62004QTQ010G7`0D6b<05QdU020W;`0D6b<04QTQ
01DI8P0H72D051PQ014E7P0?4a`05a/T018F7`0I7BH0310I014E7P0H72D05ATR010C6P0F6B006ahU
01<F7@0=41L03a8I01<F7@0B5A`04A@K008041<J00<04Q@K014D6@0A51T00P0A51T08@0B5AX051LL
01dP9@0I72405aXO01dP9@0=41D051LL01HI800@4aX04A@K00d@5`0R9B`02PdD00d@5`0@4aT041<H
00X=4P0G6Ql04aHK01XK7`0D5AT04a@H018C5`0?41@04A8F01@E6@0Z:bl05aPL01PI7@0?41@0414E
00d>400201HG6@0H010A4`0=3Q003a0B014B500C51H04Q<E014B500B4aD05AHH02HW:@0E5QP02``>
018C5@0@4A<02``>01@E5`0E5QP0414C014B50082@/051DI03<c?00B4Q`06QXT0P0;2aD02@0=3AL0
61PR09jNZ00n?TP06ATS00h>600C4a/03a0A014C4P02018D4`0300lA400>40l03a4@00804A<B0P0C
5A@02P0A4Q@03`hD018A5`0B4AH0410C01dM7@0?40`03@h800h?2@0@4@P2010B1@09010B2P0@4Q40
3Q0?00d?3P0=3``03@l>00h@3P0>40d0418A00<04A<B01404A8A010@3P0L71X04Q8@00`<2P092@L0
51@B00h>300?3`d04A4?010@3P0?3`d0410=014B3@0@4@`03Pl:00d>2@0200l@2`0?01@E400@4@`0
5AHA01<D3`0=3PT01PH4018B400=3@`03`l=00h>300:2PP05ADC00H6100=3@/02@T700804A4?00X0
2@T701<C4@0>3P`04Q8@01@D4P0@40h02@T701LG5@0=3@/0410>0P092@L04@0D4`l03Pd9010?2`0>
3@T061LC00d<20071P803@`801DD400@3`/03@`800l>2P0B4@l03Pd;00L6100<2`T05A@B008030/9
00<03`h<010?3@0>3@/00P0=30X06`0B4@l03@`:00X91`0<2`T03Pd;00/:200>3@/03`h<00d<2P0<
2`T03@`:014@3P0?3`l03@d=0000000H61P0410@01LG5`061PH03Ph>01@D500;2`/03@d=00/;2`0?
3@h03P`=00d;300200h<3@0600l=3P0>30d03`d>00`:2`091`P07A/L0P0@3Pl200h<3@0900l=3P0=
2``02`T:00h<3@0;2@X01`D600d;30091`P02PP900803Pd;00l030/900X91`0;2PP03@`:00`;2@0;
2PP071/I00T81`0A40h01`H400l;2P0U8B003`/:01LC4P0E4A000P0@30/03@0>2PT03@T800h:2@0@
30/03@T801/G5P2=RHP0920O00`81`0B3Pd02`L600d9200?2`X00P0A3@`0300?2`X040`:010<2@0P
71T06QHC00h:1`0F4Pl03PX7014=2P0B3P/040`900h:1`8040`900L05A4>00<0000n>SL0GUYG01@@
3@0B3P/04@d:00803`/801803PX700d91@0F5Ph03`l5010@200D50`03@d500`;1P0920<04a8=00X9
1@0920@02PT5014@300E51809B@R01/J600:2@L201DD4P0600T81P0:2@L03@`:00d<2P0<2`T02PT7
0P0=30X0100@3`d04a8@018A3`0>3@/600`;2@0C00`:2`0;2@X030X;00h<3@0?3@h03@/<00h<3@0<
2P/02PP900/92P0?3@h04@l@00h<3`0;2@`0N7Ii085oPP0J61/02`T<01HD5`0200H41`0:01@B5@0A
3a801@<601HD5@0S8B80108301@B4`0A3a003@/<00X82@<03@/<00@04Q0A01HD5@0<2P/03P`=0P0?
3@h02`0<2P/02`T:00X82@081PL030X;00d;300:20T02`T:00d;300@3Pl04@l@008040h?03/04@l@
00/:2P0G5AH061HG00L51P0C4A801`D601@@4@0U8B8040`=00L4100H51D04`l@00/7200=2@X030P9
00l;300B3Pl04`l@010<3@0=2@X040`=01<?400@30d03@T:010<3@0B3Pl04`l@018>3`0A3@h06aLH
00h:2`0400403`/<00H20`0810D04`l@00X61`0810D040`=01<?400B3Pl04a0A01dK702>S8d0<2h_
00l=3P0>30d02`T:01LE5P0:20T040h?00/92P0=2``040d>00X61`0?2``03@T:00`82@02014<400=
010;3`0@2a403@P>00X52`0=20l02@L<010>4`0J61d030X?01dK80040PL02`T>00`:3`0200d;4080
30X?01802@L:00h<3`0?3A003@/>00l=400=2`h04@lB00d;3P0?3A003@/>00P62@0<2Pd020H;00d;
400G5AX0<S0e01DC600A3a@400/93P0>00d;400>31404Q0C00X82`0F51L03@/>00X82`0B41<04a4D
00T72P0610L02`T<00h<3`0H5QTDooooo`006oooool200/92P0500X82@0;2@X03P`=010>3`0B4140
0P0<2P/200d;300O01DC5`27PH/0:28_01LA700;1Pl03PX@00h93P0A3@l04@d<010<2@0@3@T040d7
00l<1P0K4a405@`=01P?400B30`0208401<=3`0?2Ph081hQ00h<400>31404a4F01LE6`0?31<03P/B
01TF7@0G51/03P`A014?500200h<4@<03`dB0P0?3A4200l=40803@/>02P03`d@01LE600@3Q404a4D
018@5@0@3Q<04A0I010@7@0F5R806ATU00h>6@0=2aH03`dG018A600C41L04PlF01DB600B41D04A0D
01@D5P071`T0CTi@00l?4@0H61X0410B01<C5@0G5aT04A4D01@C60051@T051@G018C5@0H6A/07QlR
018C5`0?41@09BHZ01lP9@0@4AH051@K0P0C4a/01P0H62404Q8L01@D7P0C4a/07AdU01lO9`805QHN
0P0G5al04P0F5ad05QHN01DF6`0L7B8061TN01<D6@0K7240;2db01LH7@0J6b005QLL01<D6@0G61d0
5QLM01`N:P0@4Ql07Al/00h@7@806A/X00<061XW01LI9P0F62D00P0H6RL01P0D5R<061/[01<F9P0N
8C808bHf01DH9P8061`X00T05a/V01XN:@0G6b@051PQ01hR:`0M8bl05Q`X01XP;00K8bh00P0F7RT0
9P0E7bT06R<^01DN:00C72L06B8/01PO:`0M8c806Al_01/Q<@0E6b/06Al_01HL;00G7Bd06R0`01dS
<`0Y;cl07B<c01@J:00N9Bd06B0W01/R:`0E6bH0728^01lU<@0K8Rd06R4Y01TP9P0I8B@072@U01hV
:00N9B`072<[01dT;00P9bl072<[01PO9`0N9B/05ahT0P0K8RP0200H7bD051dT01LQ:P0G8B/082Xd
01/U;`0I8bd05R0Z0P0I8bd03@0J92h06bD_01TS;@0H8R/07BDY01/S9P0E7B005alR01PP8P0B6Q`0
51`N01<K7@0E7Al00P0H82805@0F72007R<Y024U;P0g>dH0;C0n01HJ9`0J7R/05a/W01PL9P0H7B<0
5a`O01HL7@0D6Qd04QXM01HN8@0E72404APN01PO9@0E72<04aXS01@K9@0201@J9P0/01<I9P0E6RD0
5a/T01TM9P0J7bH061dS01LL8P0E6R007R<Y01DJ800G72804QLL01LL8P0D62405a/T01PL9@0k?dP0
7b</01@H8@0L82T020`E01PL9@0=4AX051PQ010D7@0D5b003Q4J01<F7`0>4AX04QDN01DH8@0H72D0
2@/D01<G800<41T05ATR00lB6`0D5ad05APM01LJ7`0F6Ah051LL014D6@0F6Ah201TL8@05014D6@0?
4QL04aHK01@G700B5AX00`0@4aP01`0>4AH02PdB014D6@082a006A`S00hA600A51T00P0E5QX0200D
5AT04a@H018C5`0@4AD061TM01HG6`0C51P04Q<G0P0C51P2014B500U00T:300G61X0414C02TZ;00H
6A/04Q<E014B500@4A<04Q<E01hO8@1LGEl03a0B01XK7@0A4Q@05AHH014B500C51H04Q<E01DF600A
4Q@05aPJ01@E6@0H6Al0410H010@5`0D51`04a<K010@5`0B4QT05ADM01@D6`0@41L03PhF00l@5@0A
4Q<0418A00h@3`02010B4@0W01<E500Q8b8092HU01LI600B51<051HE010A4`0A41D03PdB010?4`0D
4aH04Q8A01<D3`0>3`T04a@>00/<1@0F60h01`P202h_:P0f>3L02`d<014C4`0?4A4061TK00d>400E
5aL02@X<01<D500:30/04Q@C01`M6`0820L03Ph<00l?3@0E5A<04A4?01PH5P0E5A<03@d;00<03`l=
00@0414=00h?2P0>3`X03a0;0P0>3`X00`0?40/04A8=014B3@03014B3@0C00/;2@0I6AL030`:014A
3`0820H03`l=010@3P0:2PT04A4@01<C4@0D51804A4?01`L6P0D51803Ph<01@D4P0G5aD04A4?01<C
4@02018B400;010@3P0?3`d03`l=00X91P0K6QH03@`8014@300R8Ad0:bXV00h=2@0?3PX00P0@3`/0
3`0?3PX03Pd9014@3P0>3@/05aHD00l>300I61H02PT700d<2P0?3P`02PT7014@3P0?3P`03Pd;018A
3`0200h=2`0500d<2P0<2`T03@`:00`;2@0=30X00P0>3@/0700=30X030/900l?3`0?3`l0410@01@D
500?3`l04a<C00`<300?3`l03@d=00/;2`0=3@d04A4A014?400C4A8020H700d;300D4Q<03`d>00/9
2P0=2``030X;00h<3@0B41404a4B018@4@0;2@X200h<3@09028P8@0h=SL04@l@00d;300<2P/02`T:
00`:2`0=2``03Pd;00803@`:0`0>3@/200l>308030/90P0=30X08`0A3@`030P7010<2`0C3`h040`;
00h:2@0?2`X04Ph=00d92@0E4A008alN01TE500>2PT040`;00h:2@0<20L03PX9014=300@30/03`/:
00h:2@0?2`X040`;00l;2@0E4@h09R8O01`H5@0;1`@040`901/G501>BTL03`/801HB3`0810805Q8?
00803PX700@03`/8018>2`0D40d04Ph;0P0=2@H300h:1`0D00d:1P0=3@D04A4800l?1`0<30@03`l7
00`;1P0=30L04Q4<00d<200A40`02PT500l>2`0X9bD0W9^I02DT8P0:2@L02`X8014@3P0?3P`2010?
3@0600h=2`0=30X030/900d<2P0<2`T03Pd;0P0B4@l0200=30X01`H501/J600:2@L04Q4?00h=2`0?
3P`03@/<100>30d200l=3P0N00d;300@3Pl01`D600l=3P0;2@X03Pd?00d;3P0d<SD0:BLZ010>4@0C
4A@03P`?00`:3@0A3a80108500h<3`0@3Q403`d>00X82@0;2@X030X;00/92P0>30d02`T:010>3`0?
3@h03P`=02@R8`0j>3T03@/<0P0>30d01@0N71d040h?00X92@0>30d040h?00804@l@00<03`d>00h<
3@0D4Q<00P0;2@X200d;3004010>3`0<2P/04@l@010>3`<03@/<02/04`l@018>3`0>2P/030P9018>
3`0A3@h030P9010<3@0B3Pl03PX;00H20`0@30d030P900d92P0?2``040`=014=3P0@30d03PX;010<
3@0A3@h040`=00l;300C3a003@T:00l;300B3Pl04`l@01DA4P0=2@X040`=018>3`0A3@h040`=014=
3P0@3@h0@T110:n][P10?Sl03P`=00P61`0@3Pl030X;00802PP900D02`T:00d;300?30d03`/<018>
3`0200l;300=018=4@0?2Ph020@7014<4P0C3Q@04@dB018=50091``040hC08^9SP1kNGh09B<X01DC
600200h<4@0700d;400>31403P`A010>4`0F51L06QPK00l=400200h<3`0E01@B5@0E4aH040hA01<A
500H5QT0518E014?4P0B41D03P`A03@b=`0[:Bh04@lD00`:3`0E4aP02`T>010>4`0=2a0030X?014?
500@3Q404@lB00802`T<00@03`d@00`:3@081PT03P`?0P0<2Pd00`0@3Q402`T<ooooo`0Cooooo`00
6oooool0200=2`h02`T<00T72P0:20/03P`?010>4@0>30l02`T<0P0=2`h0300<2Pd040hC02DO:@0?
2AD07QPR01<=5`0@2a802PD901@@4@0C3`d04@d:010=20803P/400`050`:00h6100O5aD03@L700/5
1`0A2`d01`8602d[<00@3A@08b0W0<W6c@1VHf`2014>5`0<01XG800G51/03P/B00l<4`0;2@h03`d@
014?4P0B41<04@lB010>4@0?3@l03`d>0P0@3Pl00`0=2`h02PP;00d;3P0200h<4@0^01@B5`0F4aX0
5aDP018@7P0;2AL040hK018@7@0@3QT04@lI00/:400A41H03`hC01<C5@0N7R003`lA01TI6@0;2`/0
1`L700d=3@0K6ad05QHH00000P061@X05aHK01PG700?3Q@04a<G018C5`0N7b<08b@X018C5`0@4AH0
71dR01@E6P0?3aL04a<K00h>5P0;2aD0410J00l?6@0A4A/020P@00h>5P0C4a/051DJ01DF6`805QLL
07L05aPL01PI7P0@4AH04Q<H014B5`0:2a002@X?01`M8P0J6b006a`Q01PI7P0E5Q/05aPM01HG7@0H
6b@051HR00h@700/;SX03@lK01/M:@0D5R805QPT01PJ9P0G6BD05QPT01LI9@0D5bP05AP[01@G:@0A
52D04QDT01<F9@0A5B4061`X01HJ9@0D62406AdV01`P:@0M8Bd05Q/W01LM:@0H82/05alZ01XR;@0=
5B0061l[01/O:`0H72P07Qh/01lQ;P0F6BP07bDc01dS<@0@5R@06Al]01PN;00E6bT05ad[02<Y=`0M
8c406Al]01dS;`0M92h05A`U028Y<`0P9S8051XW020V<P0R:C@06b8Z01LN900I8BD082PZ02@/;`0K
8R/06b8/01`S;@0M92`06R4Y01LN9P0M92X051/Q024X;P0L92L07RHY01@M8P0P:C<06R@^00lI8`0A
6bD072H`01hX<P0J92h07BLa01`V<00H8R`05b4[01TS;00J8BP061lU01DL8P0J8BH072@W01TQ900G
7b804a/M01@L7P0H82806B8Q01TO8P0E6R007R8[028V<`0F6BX06A`]01PK;00E62T05a/W01TM9P02
01TN8@0701HM7P0G7b8051`O02<[;`0[<SP09Rde01lV;`0201TO:`0:01PN;00I7bd06Al_01/P;00I
72D05QTR01LJ8P0I72<05aXQ01<F70804QDJ01d05QTN01DI700R9BX082D[01PL9@0A5Ah06AdV00lC
701;CeP0ADUB018F7`0;3aP05ATR01HJ8`0<41T0418N00lA7@0B52003@lK01dO:`0[;cX01`/F01@H
8`0<4ad02a8L024X<P0N9Bh041DK018E6P0201@G700501<F6`0A51T04A@I01@G700E61d00P0A51T0
100F6Ah04aLJ01<G6@0A5AP2010D5`0800lC5P0A51T05aXO01@G700I72<03Q4H01@G700C51T201<D
6005018C5`0A4QH03a0D01@E6@0C51P0100@4AD0D00>3a40414C014B500@4A<06Q/M02TZ;00K71h0
414C00l@4P0B4aD04A8D010A4`051PP04a@F00h?4@0<3@l061TK00l@4P0B4aD0414C00h?4@0<3@l0
2P/=00P92`0H6Ad03a0E00h?4`0B4aP04a@I018C5`0F5a`05aPM01DF6P0@4AD03@hC00d>4P0>4100
6adL02PZ:@0C5A@07R0O00D71P0F61L06A/J010B4@0<3Pd03Q0?00/<3P0C4QL03PdB00d=3`0@40l0
4a@?018C3@0?40X051D?00/<1P0I6QD04A8=018D400D6AD00`L600hB4P072`h02PhA01DI7@0=4A@0
3Q8E00P;2`0;3`h082DQ0:NXYP0h>3H04Q8@00`<2`092@L07QhL01@D4P0B4Q003Ph<0P0C4a400`0B
4Q004A4>00h?2P0300l@2`L03Pl:018020X700D7100:30T02P`9018D4@0A4a001`T602X/:@0B5140
00400002000;3@X04A4?00l?3@0=3@/04A4?01<C4@0D518300h>30<03@d;00@05QDA00T8100C4Ph0
0@000P0h=c<03@0>3@T03`h:010?2`0@3`/03`h:00h=2@071P@04Q4?01XI5`0<2`T0BTU701LF500=
30X00P0;2PP02P0@3`d04A0>00h=2`0?3P`040l=01lN700K6QP02PT700l>300=30X400h=2`0;00d<
2P0>3@/02PT700P71@0A40h040l>0040000>3@/040l=00l>300=30X00P0;2PP04P0<2P/00@0001/I
6P0;2@X0518C01DC500J61T07A/L00`:2`0:20T03@/<00800@0:20T02`T:018@4@0>30d030X;01<A
4P803P`=100=2``300l>300500d<2P0;2PP02PT7018A3`0D4a400P0;2PP00`0C4Q004A0>00h:2@04
00h:2@0<00`81`0300003@T801@@3`0M6AP0:bLV01HB4@0A3@`040`;018>3@0C3`h04Ph=0`0?2`X0
1P0@30/03`/:00l;2P0?2`T02`L400l;20803PX700@0510=00`81@0J5Q<02`L40P0A3@X00`0@30T0
3PX7018>2`0200d91P04014=2P0D40d03PX700l;208040`90P0?2`P03P071P403@`7010?2P0<2`H0
3@`700h=2@0?3PX04a8>00d<2P01000030/903/j>0081`D010<10P0=30X00`0?3P`02PT700`;2@04
00d<2P8030/900<02`X800`;2@0@3`d00P0A40h00`0L6aT0BTU701DD4P0200l>300I00X91`0H5QL0
1083014?400H5QL02PP900/92P0<2P/03@/<00/92P0<2P/03`d>02/Y:P0N71l03`d@00D31P0?3A00
3P`?00H41`0100807A/N0:>QY01hMWT04a4D00P62@0200h<3@05010>3`0>30d03@/<01HD5@0A3a00
0P0C4A802`0>30d06aTJ02TW:00C4A800@0000P61`2DTY<0L6i_01`J6`0C4A803P`=008030X;01X0
3P`=010>3`0?3@h03@/<00l=3P0=2``030X;014?400<2P/04@l@00d;30071@H02`T:014?400:1`L0
5Q8C01<?400B3Pl00`00018>3`0C3a005Q8C00T51P0C3a002PH700l;30<03PX;0P0?2``02`0>2P/0
4Ph?01DA4P0>2P/02@D600d92P0^:R/09b<T01LC500F4Q<02PH700803@T:00h030P900h:2`0>2P/0
3@T:010<3@0B3a001P@501LE5P0;2@X03`d>00X82@0<2P/03`d>00h<3@8030X;00@03@/<00h;300?
2``040`=0P0?2``01`0A31003@P<00h93@0O6R000`0400L2200C3QD00P0?3A801P0d<SL09B<X0040
100:20d03P`A00d;40<030X?02403@/@00l=400C4A@02PP;00h<3`0A3a806QPK01LE600>30l02`T<
01<A500B41<03P`?00D3200=2a00<2hc00D3200D4QL04a4F00D3200@3Q<03`dB010>4`071@X02`T>
01<A500D4QD03P`?00`:3@0>30l02`T<00`:3@0?3A000P0<2Pd00`0@3Q403P`?ooooo`0Cooooo`00
6oooool01P0?3A003@/>00/9300<2Pd03`d@014?4P802`T<0P0=2`h0300<2Pd03@/@00H120060PX0
40/B00T42`0B3A804Ph?010<2`0?2`T03PX700h;1P803@X500@030@301081P0]9B<050h>0P0>20X0
3P0;1`/07a`S00L42`0N72<0cL[C04e:D`0C41T02`PA00d:4`0=2Q4030T@010=500<2Pl04@lB0P0C
4A@0700@3Q403P`=010>3`0?3@h03P`=018@4@0A3a803@/>00h<3`0C4AH03`dB01PF6`0L6B007A/V
01/I9`0B41h04Q0M01@B7@0B41/04Q4H00H52P0A41D0410B01TI6`0[:bd05ADE010@400I6AT201PH
600I014A4`1DE5H0@d=501/J7`0>3A803@`A00h=4`0D51T0414E01<D600D5AT03@hB014B5`0C51T0
2``A010@600J6R805QHN01<C7@0?3aT071`V034a>`0G5al0410H01`L900201@E6P0:01DF6P0F5a/0
5aPL01TJ7P0E5Q/06AXO03`m@P0`<CH020T>034b=`806a`Q04406AXO01LH7@0G61d05QHM01<F7`0G
6BD0:bdi0<;4d01NH6`02P`H014C7`0E5b<061XV01HH900D5R8061XV01LJ;@0J73405QT]01LJ;@0K
7Rl041<R01<G8`0N8Rd061`W01HJ8`0N8R/0720Y020T;`0K82`061hZ01PP:`0I8B`06b<^01PP:`0K
82`071/Y01`J:00Q7B`09B<a01@H900M8c006b4]018H9P0O9C806b4]018H9P0?5B8082Hb01HL:P0K
8Bh08BLc01TP:P0I82T07B@^020V<P0H7R/08BLe02L]>@0M92h06B0X01/R9`0O9bT08BT/01`S;002
01XQ:`<06R4Y00T06R4W00dD6P0K8RP07BDX02D]<00F7b@05AlX01hX<P0A6bD00P0G8B/0100C7BL0
6R@^020Z=00M9c4201HP:P0O01/T;@0H7bH05A`T01@K8@0G7R@06B0V01PP8`0D71l04ATL01<K7@0F
7R005QlN01DL7`0B5Ql05QXU01LK:@0A52L05AP[01PK;P0F6BX05aXY01TM9P0I7R8061dP01/R9@0?
5aX04ATL06=[K`2l`l/09Rde01hT;`0201/Q;`0Y01XP<00K8C406b0c01hR;`0I72D04aHO01DH800H
6b805QTP01<F700>4AH051LL01XN8@0L82<0;S4e01HK8@0I7BH06QhW018F7`0=4AX0@dM@0455CP0C
5b0020`E01dQ:P0S9c003A4J00T;5`0?4Ad05aTU00T;5`0C5B408BD`00lC7P0Q:3805ahX01hU;`0`
>D80=Ce600lD6P0A51T00`0C5Q/2018E6P0901<F6`0E61d04QDJ01<F6`0G6Qh04QHG01@H6@0C5aP0
4ADH008041@G00L04A@I018E6P0A51T0004801@G7P062@h051DJ00<051DI00@04a@H014B5P0B4aL0
4Q<G0P0@4AD200l@500900X;3@0>3a405QLI01<D5P0E5QP030d?01PI6`0C51H04A8D00804Q<E00L0
414C02<T9P0@4A<020T;01DF600@4A<04Q<E00804a@F0180414C01@E5`0A4Q@04A8D01/L7P0B4aL0
3a0B00l@4`0?41@03PlA01DF6@0E5QX04a@F010A500>3a<03@h@01<E500<3Pd200X<2`0R01<E5008
2PT02`d<010B4@0<3Pd03Q0?018D4`0A4a803`lA00d=3`0<30`03Ph;00h?2@0:2`D03a0:01PI4`0<
30T07AdK01TI6@072@L0314=018F5@0D61T02`lB00d@5@0520d01`X?00hB5@0@51D04ADD01<H5025
Qh@08b<Q00L71@804a<A00d05aLE00P81P0:2PP02@T700h>300B4Q00410>00l?300>3`X03a0;010A
300?40/03Pl:00H03a0;00`06A/H018D4@0F61D030h;01XL6@0A4a006A/H0001000L7Q/08B<P018D
4@0>40d2014A3`04010@3P0=3@/03@d;00l?3@D03@d;00T03Ph<00h=2@0I61@030/700X91@0>3@T0
5QDA00h=2@0?3PX00P0@3`/04P0?3PX03Pd901@C4@0?3P`051<A00L6100P7ad01PD300`;2@081`D0
51<A00`;2@061@<051<A00L6100C4Q00<C0^02`[:@8030/900h03@`:00h=2`0?3P`03`h<00h=2`0=
30X030/901TH5P01000040l=03He<`0A40h03@`:00l>30804Q4?01H04A0>010?3@0A3a008AlP0080
0@0=2``05Q@E0040000200402`T:01HD5@0=2``02PP901PF5`0=2``030X;014?400>30d020H700T7
200=2``03P`=0P0?3@h0100>30d03@/<00X91`0<2`T200d<2P8030/902P01PD4010?3@0=30X040l=
00X91`0100003PX9010<2`0?2`X03@T800h:2@0e<C00510?00@0000D40l03`/:01`H5`0D40l04`l>
010<2`0B3Pd04`l>010<2`0=2@P03PX9010<2`0A3@`040`;00h:2@0A3@/02`L400d91P0<20D040`9
01LC400D40d040`901<?300;1`@04`l<0P0@30T01`0B3P/03PX700d91P0@30T04Ph;00l;200@30T0
0P0A3@X2010<2@803Pd80P0;2PD0400?3PX051<?008100081`D040l=00D3100G5AH0;B//01HE4`03
0P0040l=00l>300E51803@`:00X91`0;2PP300d<2P0300`;2@0A40h03`h<00<03@`:0P0>3@/04P0N
7A/030/900`;2@0;2PT06aXH02`Z:`0<2P/02`T:01DC500?3@h02PP900D3100A3a0030X;00d;300F
51D0EUAE05ABE@803P`?00`0:BLZ00X82`0<2Pd03@/>01PF6@2OWJ00NgUl00l=400B41<03P`=010>
3`0B414200l=3P0Q01XH6@0@3Pl02@L800d;300@3Pl02@L800L51P0;2@X06aTJ010>3`0Q7b004a4B
00`:2`0A3a003@/<00/92P0<2P/03`d>014?400<2P/03`d>018@4@0=2``030X;018@4@0;2@X05A<D
00T7200Q7b009R@U00P61`0A3@h04Ph?00804@d>00L03@T:01@@4@0E4A80510A00D10P0C3a003PX;
00<040`=01T03`/<00h:2`0>2P/030P9010<3@0C3a003PX;00/7200=2@X061@E00d92P0;1`P04`l@
00h:2`0B3Pl0510A00l;300;1`P03@T:00l;300B3Pl0514B014?40091`P040h?00802`T:00<03@/<
010>3`0@3Pl00`0=2``00`0=2P/03`/<010<3@0200l;300=010;3`0300808QdQ04Y5B`0H4aT03@P>
010;4P050`P03`dB01/I7P0I5a`03@/@00l=4P0200d;400A00`:3`0;2@h02`T>00`:3`0610L03`d@
00h<3`0B41<03P`?00d;3P0C4A@04Q0C010>4@081PT01P@701DC5P0A3a@00P0<2Pl04@0Q7b@05aDJ
01DC600A3a@04a4F00L52P0>31407A/P03`j?`0@3Q404Q0C00d;3P0<2Pd03`d@00/9300A3a8040hA
00803@/>00<040hA014?4_ooool04oooool001_ooooo0`0;2@`300`:3@0@00T72P0=2`h030X=00d;
3P0>30l030X=010<4@0A31803PT>00/72`0>2@d030P900d9200>2PP03PX7010<2@804@h900/05`l<
01D=2`0Z8R004`d=00d72P0?2@d04@`B00`9400C41P040dH01HD7P02018?6P0300h;500@3AH040dF
00803P/B04P040hC018@4`0C4A@04@l@00d;300;2@X040l>014@3P0=30X04@l@01LE600D4QD04@lD
01<A5P0@3Q<05Q<J01TF7@0F4Qh06ADT01PD8P0B3a/040lH014?6@0B4AP02PT=018B5@0?41005ALE
02<U8`0D5A<03@d;018B400:2PT04Q8B00h>400Q8B@01PH:00X93P0F5AX05aHL00h=4`0E5AX04Q<G
010A5@0C51T05QLL01DF6`0F5ad051@L014A6@0A4AX04Q8L01HF800E5Al06QXT02`/=P0M7BD06QXR
01dM900E5Q/05AHJ01@E6@0E5QT05aPJ01XK7@0C51T03PlD018C600A4QL06a`Q071aMP0J6b0301TJ
7`2701LH7@0G5ad06QdU018E7P0A4a`0;c8k02LZ<`0K7RL04aHO01DH8@0H6b@05QTR01DH8@0G6RD0
6A`_01/M<`0L7c@09bXn02LZ>`0<3ah051PU01hR;@0I7BP05QXS01XN9P0H72D07B@^01dS;`0G7BT0
4a/V01DM:00F7BP07B8^01hN;00T7Rh09ah_02HJ;00S6R/09RLc01PO:P0F7BL051/V01dS;P0B6B<0
6b8]01XQ:`0L8bd051/V01dT;P0J8B/06b8Z02Xa>P0E72L0728_01/Q;`0I7bd0728^01PO:@0I82P0
7RD[01hV:@0M9BP07bD`01dT;P0K8R`06R4[01`S:`0N9Bd07RD[01hV:@0A6A`06b<V028Z;00C7Al0
6B8/01`V<0094ad07RPb01`V<00Q:cD06B<]01dW<@0K9Bl05R0Z01DO:@0I8B`0724[01XN:@0L82X0
6alX01LK8`0G72805AXP01LL800K82<06QlR01LL7`0D6Ad05a/T01<G8P0I72/06Qda01DG;@0J7380
6Qd`01XM;P0J7RP061dQ01LL7`0R:2/0:S4g024X;P0Y<3L0ADaE00dB7@0J82d06Al^01XO<@0K83@0
6Qlb01TN<P0J7Rd05aXS018E7P0C5Qh05QTP01DH7`0D5ad04QHJ01@H6`0F6Qd05ATJ028V:00I7R@0
5a/T00804ADN00/05a/T018F7`0=4AX03a<L018F7`0A5Ah05ATR00dA6P0E5R<040lM01DG9002010B
7`04010C7`0D6RH05Q`X010H8`803aLR00@04a`U014F700B5AX04aHK0`0B5AX00`0F6Ah05APM01DH
7@0201<F6`0>01@H700B5QL05QXI01HJ6@0C5aP041@F018F6@0?4QL05QTN01<F6`0^<CP03a8I01@G
700B4aP301<D6003018C5`0@4AD04Q<G00<04a@H00l04Q<G014B5P0B4aD04a@F00T:300G61X030d?
01LH6P0?41805AHH01@E5`0B4aD05AHH01PI6`0;30h00P0B4aD02`0C51H03PlA018C5@0D5AL04Q<E
00P92`0C51H030d?014B500F61P04Q@D0080418A02h04A8C014C4P0C5A@0418B00lA400@4Q80414B
00lA400@4Q406Q`K014C4P0g>CP030h=018D4`0A4a804Q@C010B4@0?4A003@l>00`>3@0>3P`04Q8?
01@E3`0A4P`03@h7010A2P082@@02@X601<C500>3Q8071/P01@F5`0:3P/05ATH00`?4@0;3A404A@J
00d@5`0C5Q`02PdA00/?400?4a80314=01LJ5`0=3@`04A4?0P0?3`d02@0:2PP05ADC014A3`0@40h0
4Q8@01@D4P0@40h03@d:00l@2`03010A300300l@2`0@4@`0414<00@0414<018010H301hP7@0:30T0
0@<101HH5@0?4@h01@L402HX9@1:C4T04A<@018D4@0;3@X04A4?018B400A4@l03@d;00`<2P0=3@/3
00l?3@80410>00T03`l=00T8100H5a<03`h:01/J5P0?3PX04Q4>00h=2@0?3PX00P0@3`/02P0?3PX0
3Pd900X9200E518020L5014@3P0<2`X05QDC00`;2@0@3`d200`;2@0902TX9P0<2`T04Q4?00d<2P0H
5aD051<A00P71@0G5Q@03Pd;00@03`h<00L03Pd;00T81P0@3`d01`H401HE4`0/:bT051<A00803`h<
014040l=018A3`0A40h03Pd;014@40081`L03`d>04Q6A`0d<S<05aDF00d;300@3Pl0<c4b01`J6`0<
2P/0<2h_01<A4P0300l=3P0300d;300=30`03P`=00<03`d>0P0>30d0100B4@l04A0>010?3@0?3P`2
00h=2`0E010?3@0A40h0?3/i02h]:`081`H04A0>010<2`0A3@`040`;00l;2P0@30/0;b/Z01PD4`0=
2@P04@d<00`81`0I5A@03P/:00d9200<20L04@d<0080510?01L040`;00l;2P0@30/04@d<010<2`0?
2`X040`:00d91P0B3P/03`/800d91P0D40d04@d:00H2000A3@X030P601@@3@0B3P/04@d:00l;200>
2PL040`9014=2P03010<2@<04@d:01D040`9018A3@0=30P030/800l>2`0=30X02PP700d;2`0@3Pl0
2@L9014?4P0B41<02`T<00X8200A40h02@P601`K6@0920H04Q4?00/:200<2`T00`0=30X03@0<2`T0
3`h<00h=2`0>3@/030/900d<2P0A40h092<Q018A3`0@3`d02`X8010?3@0<2`X00P0@3Pl03`081PL0
2`T:010>3`0>30d03`d>00d;300;2@X040h?00d;300X9RL08b4T00h<3`091`X06ALJ014?4P0200l=
400<00`:3@0F51L040hA00d;3P0<2Pd02PP900/92P0=2``02`T:00X82@0D4Q<040h?0P0=2``0300:
20T030X;018@4@0A3a002@L800l=3P0A3a005aDF00h<3@0;2@X030X;00h<3@8040h?00X04@l@00d;
300?3@h04Q0A00h<3@0<2P/040h?00h<3@030@801P@50P0X9RL01P0>30d04@d>01PD5@1`K6d0Ad=4
01<?408040`=00<02@D601<?400<20T00P0@30d0500A3@h040`=010<3@0?2``03PX;00d92P0@30d0
4@d>00l;300C3a0040`=00d92P0B3Pl06ADF014=3P0@30d0510A01dI6P0L61T03@T:0P0>2P/03P0<
20T01`@501@B4`0=2``03P`=00T7200>30d040h?01@B4`0B41403@/<010>3`0?3@h03@X;100?2``0
3P0>2@d040/?014<400@2a40=2le01@?5@0<1`h030X?018@5@0<2Pl02`T>00l=4P0:20d03@/@100<
2Pl0400>31402PP;014?4P0<2Pd03`d@00d;3P0?3A0040hA00/9300>30l04@lB00d;3P0:20/02@P<
018@5@0;2@h200d;4003018@5@0S8BH03P`A00803@/@00T05aDJ02/Y;P0:20/03P`?00`:3@0=2`h0
40hA00`:3@0@3Q400`0=2`h00`0<2Pd03`d@ooooo`0Cooooo`006oooool030071@X02`T>00h<4@0>
31402`T>00L52P0;2@h03`dB00/93P0<2Pl040hC00d;408050lC00@03PT=00l:3P0<20T04@d>0P0>
2PT05`0?2`X040`9014=2P0A3@X040P500T1000A2@L03PP800/52@0G4AD03`X@01<@5`0E4Q/02PPB
01TE8`0811802PLB00d:4`0@3AH04PlH00d:4@081@`040hC008040hA01P03`d>00d;300<2P/030/8
01LF500@3`d03@/<010>4@0<2Pd040hC00`9400>2a804@hE014>5`0C3a/061@R01XF900D4A`05A8K
01DD700B4AH04Q8D018D4`0>40d200lA300A00`=200E5Q404Q8@018B4@0H61P05aLI00T9300<2a00
61LM01LF700P7bD03`hF010@5@0@4AD04Q<G01DF6`0D5AX00P0?3aL09P0D51`05QHP01/K9@0M7BL0
6QXT01XJ9@0E5B404a<M01<C6`0L72@05aPM01PI7P0G61`05AHI01@E5`0E5QP061XJ014B5P0J6b00
5AHK01<D6@0I6Ql04a@I01HG700C51T061TN01XK800F5a`05aPM01LJ8@0520l0<cHm01PK8P0?4QT0
5aXQ01XM900I72<06QdT0P0K7RD06P0H6b@05aT^01LI<00L7S@09BLl02<V>00H6bX04aHU01LK9P0K
7bX061`U01@H800I7BH05QdW01/R;P0D72L04ATT01<J9P0B62@05aTV01hJ:@0U72d09APZ02/I;@0i
:Sd0?cm;0P0M92`06@0K8RX06R4Y01DL900A62009Rde01<J8P0B6B407B@/01TP:00N9Bl0;cE001/Q
;@0V;3X06R0^01/Q;`0P9S<072<]01hU;@0T:c808b/^020W;@0M92l092Xf02D[=`0Q:3800P0M92`0
3@0K8RP0AdmB01HN8@0Q:B/08RX/01hX:P0A6b@08bdg020Z=00f@4X04Q`V01<M9`0F82X00P0G8B/0
2`0F82X05AlY01HN:@0K82`06al[024U<00N8R`05ATR01@H8@0G728061dQ00806b0T02h05a`O01HK
7`0B5Ql06AdX01TL;@0G6Bh06add01DG;P0I6c006A`_01XN:P0I7R8061dP01<I7@0C6R805QdU01/R
:`063AL08BLc010F9@0D6B`061d`01/P=@0H7C<051T_01<G9`0D5R804aHO018E7@0C5Qd051LL01<F
6`0J7R404aLJ018F5`0<41404QHF00P=4`0?4a`07B4Z01@H8@0?4a`05QXS01XN9`0G6b@04QHO0P0H
72D04@0E6B<05QDS018A8@0S9C@05QPW018D8`14AeH04aTW00hD8P0G7b`02aDQ010J9P0=5R405AXP
01DH7@0D5a`04aHK00804QDJ01@04aHK018E6P0A51T041<H014D6@0A51P04ADD01LL6@0H71/051PG
010D500B5QL00PH900lB5P0D5a`0@DA;01dP9`031P/03a0E010A5@804A8F00@0414E00l@500@4AD0
4Q<G0P0C51P03P0B4aL04A8F01@E5`0;30h02P/=05YKG@0N7b4030d?00l@4P0C51H03a0B010A4`0H
6A/05aPJ0P0D5AL030092P`03a0B01/L7P0720X0;Rla02@U9`0?418061TK00T:300A4Q@03a4?014C
40<04Q@A02/04aDB01DG500@4Pl03a4>014C400?4@h03Q0=00d?3P0>40l0004001hP7`0<3Pd061XI
018D4`0C5A@05ALF01LI600F61L05ALF010A3@0E5Q405QLA018C2P0?4@H03@h701@E400D51804Q4E
02<R:P0n?4L05aTN0088100E6aT0:S0a01TN8P052Q00;C4j00D:400N8bL03Q@E00H<2P0:40`03A4=
00803`l=00X02`/901`L6P0:2PP02`/900l?3@0@40h04a<A01dM6`0K6aT04Q<?0P0@4@`0100A4Pd0
414<010A300?40/500h?2P0602LY9P1]LVh08BHR00/@300?51001``80P0D6AD010083@T0314=00D:
1P0A514200h>300400l?3@0@40h0410>00l?3@<04A4?0P0?3`d02@0>3P`04A0<00T8100A40`02PT5
01@C3`0<2`L03Pd900l>2P02010?2`0@00l>2P0>3@T02`X801HE4`071P@02`X800P71P061@<02`X8
014@3P0>3@/04Q4?040o?@0E51803`h<00h=2`8051<A00@03Pd;00l>300>3@/03`h<0P0@3`d02@0?
3P`03Pd;01XF4`0C3``061@A01TE4P0810402@D2018>2`0200l;200i014=2P0C3``04@d<01LF5P0B
4140:bTZ05YHF@0B41404a4B01DC500D4Q<00@0000h<3@0J61T02`T:00d;300:20T02@L800d;300F
51D06QPI018@4@0?3@h03P`=00d;300>30d03`d>01HE4`0A40h03Pd;00d<2P0>3@/03`h<010?3@05
108071/I014@3P061@<07QdK010<2`0=2@P040`;018>3@0@30/03@T800T5100@30/03PX9010<2`0I
5A@04@d<010<2`0B3Pd0510?01DA400G4a805A4@00803`/:00H03PX900l;2P0?2`X040`:00/7100@
30T200l;200801@@3@0A3@X0510=018>2`0D40d03PX700l;200>2PL200d91P03010<2@0B3P/040`9
00803`/80`0@30T02@0?2`P03@`:00`;2@0@3Ph03@/<00P61`0B418030X=02TW:P02018@5@0900@2
1`0H5QX03@/<00T81P0>3@/061LE00@30@0;2PP03Pd;00803`h<00H03Pd;00d<2P0<2`T02PT700`;
2@0>3@/200d<2P0C018A3`0;2PP03`h<00/:20061@<05aHD00X91`0O7Ah02PP901TG600d<S<0;bd^
00/92P0A3a002@L8010>3`0B41404a4B00H41@0200X82`0<01LE600=2`h01P@701@B5@0F51L01@<6
01DC5P081PT02PP;018@4`0A3a003@/<0P0>30d04@0=2``04Q0A00H41@091`P04@l@00l=3P0<2P/0
3P`=00X82@081PL02@L800d;300@3Pl00`4200X82@0<2P/03P`=00<03`d>00D040h?00`:2`0?3@h0
3`d>00/92P0200d;300A01@B4`0B41400`4200800@0B41404`l@03Pd=@3Ccm00RXJ700`82@0K5aP0
4Ph?00d92P13?d004@d>01HB4`0?2``0100@30d01@0?2``04Ph?01/G600I5AH03PX;00804Ph?00X0
2`L800D10P0:1PL02`L800`82@0D41405Q8C00d92P0810D04@d>0P0?2``03`0E4Q<04Q0A01@B4`0?
3@h03P`=00/92P0F51D08AlP01`J6`0>30d03`d>00h<3@0<2@X03`/<00d92P0200l;300=00d8300C
3Q804PdA00L2200I51X02PD;00`83P0B41D01P@900X83@0610T03@/@01<A5P0200/93P0X00`:3`0=
2a003`dB014?500>30l04Q0C00X82`0=2`h03P`?01DC5P0e<cH081hQ00`:3@0B41<05A<F00h<3`07
1@X071XO00H52@0l>Sl06ALL01dK801jN7d081hS01PF6`0:20d040hC00h<4@0:20/03`d@00d;3P0>
30l040hA00`:3@0C4A@040hA01@B5@0C4A@03`d@014?4QCooooo000Kooooo`1I010;2`0A3@h04Pl@
01<>400@2`d030T;010:3@0?2`d01`D601<>4`0A3A404@/>00/62@0?2Pd03P/>00l=4P0;2Q003PlF
00H5300B4aT030/@00l=4@0>2`d02@H701DA400<20H04Pd=018>3`0;1PL04@h@00h;3P0;2@d02PL<
01HD6P0<2@l03P/B010<4`0A2a804`lF018=500E3aH02PL;018=4P0B3A4040d@014=3`0A30l040`?
00l=400O7B006APK00d<400C4QH04@lE00h=4P0?3A<03`dD018@5P0?3A@05a@K01HB6@0E4AL04PhD
01@@5P0D41D040hA01@C500C4Q<04a8A01<C400@3`l04A4>01<C400@40h061PG010@3`0C4a804Q8C
01TI6P0G5QT05ADG02LW:@0H61/04A4D01`M800O82<08b<V01TI7P0>3Q<00P0H61d03@0B4QP040lF
01@C6P0F5A`05AHL00l@600D5A`03Q0F01PJ7P0A4aL06Q`P01@G6P0B5AL00P0E5aX01`0E61X05aTN
01DG7@0C5A/04aDJ01@F6`0F61d00P0D5QX02P0G6Ad06Q`P01XL7`0G6Qh051LL01XM8`0D5Q`0<cHl
024T:P0C5Q`201@G7@1`01DH7P0F6Al05APN01@G7P0G6RP05QTY01dQ<00L7bl08BDc02<V=00F6RD0
5a/W01/O:`0L82`06AdW01dQ:`0H7bT05AdV01DM9@0G7RT05ahX01DK900K7RX08b@`02HU<00Q72X0
;RLf03ljB00_<Cd06b4/01dT;@0K8R/06B0X01XQ:@0I82L0<SU0024X;@0G7RD0620T01PP9@0F7BD0
6B0Y01LM:00Q:3<061hY01XP:`0U:cP07bDa01dT;`0Q:3407RD^01PP:@0H8Rh07RTf020[>00[=D80
7BHb01/U;`0O:340?TM>01/V:P0M9bP06B8T01XU9P0E8BL06BD^01PT;@0S;SL041/T01DQ:P0F82X0
5AlY01@N:00G8B`05b0/01@L9`0F72L0724/01`R;00P9Bl03Q<L01PM9P0G7B<05A/P01HL8@0C6Ad0
4QPK01HL8@0B5ah06AdW01DI9@0B5BH06aha01LJ;@0D5bP06ah]01LK9@0N8bT0724V01DM800C7B40
6B4W01<L900F7bT05A`Z01TQ<00B6R/07bDf01`S<`0Z<d405Qd/00hC80804aHO06404QHM018F6`0C
5a/051TK01PL7`0B5QT061dP01LK7`0E6Ad05a/S014E7P0E62405QTQ00lC6`0B5Qh041<K010D6P0A
5A/051PN01DI7P0/<3L0BdiJ01TL:`0B5R<05APV01<H9@0a=T<05adZ01DK9P0L92h04aXU01TR;00B
6R@05AXP01PL8P0J7R<04ADK00dA5`0J7R<04QHJ014E6@0>4QH03a<G018G6@0B5QX04ADG01<G600K
7b403a<E018F600C5aT061`N014E5`0=4A@04ADH03/o@P0Q92L04A8E018C5@0C5AD04a@G01<D5P0B
51@04A8E01<D5P0D5AH051DH01<D5P0A4a<030d>018D500C5AD0@49201LH6@0D5AH0418B01<E5@0<
3Ph03Pl@01DG5`0>41002``=020R8P0F5aP04A<C00d?3`0C5AD05AHG014B4`092PX04A<C00d>3`0B
51<051DC01@E500D5A<04Q<A0080414?01D051DC010A400@4A004Q<A00l@3P0=3P/04aDA01@F500=
3`/03a4>010B400?4@d03a4>00h@3P0A4`l051HC00lA3`0<3P/0414>018C3`0A4`d00P0=3PP07`0B
50h030h:01HG5@1<C4`051@G01HF6`0=41003a@?00P<1`0D61H0Ada;038e=`19CDl08bLY02<V9P0@
51803aD@00`?2`0@4`l03Pl<01DF4P0?40d04a@A010A3@0>3`/03a0<00l@3@0@4@h04a@@010A3P0>
3`X00P0@4@`05`0A4P`0414<010A300@4@/04Q<>00l@2`0;30H030d700h?2P0>3P/0?d0l01<C400;
30P03a0<018B3`0<3@T03a0<010A3@0E5A8051@A00l@3@0<30X0414?0080414@00H03@h=00`=2`0<
3@`04a@B00l@3`0?40h200X;2P0?01<B400=30T04Q8?00l>2`0=30T03@d:014@3@0F5A805ADB00d=
2P0>3@X03`h;01<C3`0>3PX05QHB00804Q8>0100410<018B3P0=3@T05ADB00`<2@0B4Ph04A0=018A
3`0A3`d03`d;00l<2`0@3@`03P`:01<@3`0?3@/04@h=0P0E4Q40;@0@30/03PT6014=2P0>2PL03`/8
014=2P0F4Pl05A4>010=2@0?30T05Q@@01dK5`0O7a/05aLD00L7100I6AD061PD00d=2P0>3PX0<c8`
01LF5P0C4Q803Pd=00X92@0B4A403P`;00l>3@0?3P/03Pd;00`:2P0;2PL0>SPg01`K6P0=30T04A0>
00X8200@3``03`h;00d<2@0;2PL03@`900l>2`0=30T03Pd:01DD4@0200h=2P0=01<B3`0=30T040d;
00`91`0=2`P040d;00l=2P0@3@/02`T600X81@0B40d03``:00d:200200h;2@07014?300=2`P030X7
010>2`0?3@X040d;00h<2@0200`:1`1_00l<2P0B3``03@/700d;1`0?3@T04Pl<01<@3@0>30P04@l;
00X7100>2`P02`P5010>2P0A3@X03PX700`81@0C3``050l<00d91P0=20D04Pd:018>2`0>2@H03PX7
018>2`0;2PP030`:00l>3P071PH03Pd<01/J6@1dLg@0JFQY01@C500>3@l06QTJ04i=CP0<2`/02PT7
00l>300<2`T04Q4?00X:200<30X03Ph<014@3P0@40h03Ph<00d<2P0?3P/040h;014>300>2`T03@X8
00l<2`0;20L03`d<01DB4P0?30`04Q0?018A400_;Bd04a8B00@30`0>3@d030/:01<B4P0>3@`03`h=
010?3`081`L040l>00l>3@061@H061LI01@C5@0:2@X04Q4C00L61`0:2@X03`h?01<B4`061PL08B0R
034`<@0>3@d02`X:00`;2`0>3@`03Pd=010?3P1NGE`06aXJ00@30`0P7ah06QTH00T8200>3@`030/;
00h=3@0?3Ph02PT900l>3P0=30`030/;01HE500D4a<02`X900d<300A410030/<00803Pd>01D03@`<
00h=3@0?3Pl03Pd=00/:2P0];2`0<C0a00l>3P0?30d05A8C02PU9P0S7b004Ph?00l;300A30d03`X<
03@_<@0A2`d04``>00h92P0>2`/00`0=2`X05@0>2`/04Pl?01PF5@0G5A@03@/:00h<2`0A3Ph040h<
00X71@0=2PP04Pl>00l=300H5AD07A/J00d:2P0>2``03``=00P51P0>2``040h?00L51`0200h<3P0W
00/92`081PL03@/<01<A4P0A3`l01`D5010?3P0B41002PP8010?400=2`/02@H8018A4`0<2@`02`P<
00l>4P0@3A802`L>00X93P0>2a80518K01XH800B41L02`T>00d<3`0920X030/?00`;3P0>3A402@P=
010>5P0A3aL02`X?00l>4@0>3@l03@`?00X92`0?3Q003Pd@00802`X=01/03`hA00l>400>3A005QDG
00P7200?3Q0040lC01@C5P081`/06APK01HE6@1:B4d06aTN00`;400C4AH02`T>01<?500?2a004`lD
010=4@0@31403P/?00l<400@3A404PhC014=4P0>2`l05?ooool001_ooooo02X030L300d81@0=20D0
3PT600h91`0>20P02P@401@>3`0B30h06A<E00P2100C3@l04`X;018<3`0?3A803@`B00X;5P072aL0
BdmK03i2CP0:3AH01@@=01@A600I5a`040h@01<A4P0@3Pl0518C014?400?3@h04Q0A00d;300;2@X0
5A<D00X82@091`P05Q4E01@>4P0;1@T03PP<010:3P0S7B4201@>4P804`dA00@04P`@014<400<2a00
3`hD0P0D4aT02`071P`0<2le01LF70061@/04Q4G00/:400?3Q@040hB01<?400A3@h04Ph?0080510A
00@05Q8C01PD5@0G4a@05Q8C0P0E4A80100D4a<06QXH01hN700J6QP401@D4P0:01DE4`0A4@l04Q8@
018B400C4a@05aLI01DE5`0M7Al061PJ014A4`805aLI00P05QHH01DE5`0F5QP05aLI01DF6@0U:B`0
:Bd`01<G6P804ADH04X06AdP018F6@0B5QT061`O01HJ7@0C5aX05aXQ01HI800C5Qd04QDJ01<F6`0E
61d03a<F018F6@0C5aP05ATJ01XN7`0D61T08B@Y018E6P0?4QL04A@I01/N8`0H6b005QTN01LJ7`0F
6Ah04aHK01@G700I72404aPN02@X<@1:CUL0?d=<02L[=@0<41/04ADP01lS;`0B5R805QXV00dA7P0L
82`041LQ01HM9@0G7RH04aXR02/b>P1EG6@082L_01TP:00L8b/05ahV01/R:P0H7bT061hZ01TO;00I
7b/06B0Z01PO:00F7BD05QdS01lV:`0K8bH05QhQ01LO8P0H82<06R4W01TP:00J8BT072<[01lV;`0O
9S006R4[01`R;P806Al[00`06b4_01PP;@0K:SL0?dmN020`?`2O[;`0Ef=c01l[>@0H9C006R@^01TT
:P0H8bD201LS8`0<01PV:P0E8RP05B8X018O9P0D8BT072H_01LQ:`0J92h05R0Z01LQ;@0H82d051`W
0P0G7RP01`0=51h08RTa01hU;@0L8b/05QdS01DL8P0C6Ql00P0B6Qd01@0D6al05Q/Q01@H8@0C5b40
4aLR00804aHU024051PT02HZ=P0G6bD061`U01LL8P0L9BP04alO01@O8@0F8BH07bTc02@^>P0M9SD0
HFYi00TC7`0=5b405R0Y01PS:@0E7BD04aLP01<H7P0B5a`04QLJ01<H6`0C6AT041HF018G6`0H7B80
51TO01@H8@0@4a`04A@M01<F7`0E61l00P0F6B00:`0E61d051LL018F6@0A5AP04QHI01DI7@0R9S40
3aDS010F8P083QX04ALS01TP:P0E72H04aXT014H800C6R8051/S01<J8P0F6b406AhT01dR:00C61h0
3A8H01XO8`0B5aX04aPK00lD5`0=4a<04ALG018H600C5Q/04A@I01TL8@062Pd04ADH018F6@0A5AH0
4aLH014E5P0@51<04ADD018F5@0@4Q400`0A4a82018D4`0?010B4@0A4a804Q@C018D4`0A4a80418A
01LI600C5A@010H500D71P0A4a80418A01PJ6@0E5aH04aDD00804A<B00L05ALF018D4`0@4Q4010H5
02<U900A4a804aDD00H04A<B1P0C4a<0200N7Qh04a<C00h>3P0?3`l04Q8B01@D4P0B51004A<>0P0@
4Pd200h@2`0G00X<1`0<3PT04A<>01LI500F61<04aD@010B3`0B5140418?00lA3P0D5Q<04aDB01DG
500620D08bDR00@60`0E5a@04A<?00h@2`0=3`X03Q0;00lA300A4`h00`0@4Pd0100>40/03@l:010B
3@0B50l200lA30<0418=0P0A4`h01@0@4Pd03a4<00h@2`0>40/03a0;00H03a0:00/010D000<4000=
3PP06AXD00T:100@3`/04`l<01@@3@0E4@h05Q8?01@@3@0201<?300M01@@3@0E4@h0510=014?2`0;
2`/04aDD00d?3P072@P020X9014C4P0=3`h04aDD00T;2P0:30/03Q0?02LY:0092@L03`l=010@3P04
108092@R03Ti=`0@40h06ATG01LG5@0;2`T03Ph<018B400>3`X00P0?40/200h?2P0900l@2`0<3@P0
3@h9010A300>3`X03a0;01PI500=30X040`;00804@d<0`0C3`h08@0>2PT03`/:01@@3`0D40l03@T8
014<2@0B3@X04@`9010;200@30T04`l<00H2000?3PX02PT500L60P0>3`X051D?00h?200<3@D05AH>
014B300>3`T02P/5010A300:2PP020P6014A3`0@40h02PX801<B3P0=30P030/700h=2@0200l>2P07
02<R7P0<2`L0;2/W00X91@0E51003@`800l>2P0200d<20803`h:00<03Pd900d<200>3@T00P0?3PX2
00d<200600l>2P0=30P03@`800d<200?3PX03Pd90`0?3PX02`0A40`03Pd900`;1`0<2`L020L300d<
200@3`/02@P400X91@0?3PX03Pd900803@`80P0?3PX00`0=30P030/700/:1P0200X91@0300`;1`0>
3@T03Pd900<03Pd900L03@X7018=2P0?2PL03PT600d81@0L5a@050l<00803PT60P0F4@h01P0;1`@0
30/900h>300>3P`02PX8010@3P804Q8@00`04a<A00`<2P010@001PH401LG5P0F5Q@0000000L71@08
20H0000001@D4P0?3`d200h>300G00d=2`0?3`d05ADB00h=2@0?30L03`/800h:1`0?2`P040`;00<0
000;1`L02@D6010<3@0E4A800`4200L71@0820H030`:01<C4@0=3@/04a<A00/;2@0<30X00P0=3@/2
00l?3@0=00X:2P0A4A403`l?00T92@0820P02`/;010@400A4A403Ph>00d=3@0I6AT0:2PX00/;2@05
00`<2P0601/K6@0:2PP01@D300T91`0<30X0410>1P0;2`T01`0A4@l0000000@40P17AdD0>c/i00`<
2P0<30`00P0;2`/200`<300>00h>3P0<30`01`L700P8200T92@09bLW00X:2P091`P02PP900h<3@0C
3a003`/<00/7200@2P`401893003010;2`0=30X03@`:00<03@`:00T030/900d<2P0=30X03@`:00h=
2`0B4@l04A0<00l>2@0B4@d00P0>3@T02@0F5A<06QTG00P71@091`P03@/<01lM7P0o?Ch0;R`_00h<
4@0200`:3@1400d;3P0=2``02@L800d;300=30X02PT701<B400E51003`l=01dM7@0<30`02`/=00D5
1`0:2P`04Q4F01TH7@0A41D03@`B00T83P0:2A004@lJ02LU<00=31<030/@00h>400:2PX061PH02<S
8`0I61`020L=01@C6`0610l03PdB00h>400A4A<03Ph@00`<3P0F5QP0820R01DE5`0;2`d04A4C01@D
5P0:2P`05aLG010@400A4A406ATI01DE5P0@41804A4C00`;3`0Y:2d02PT>00h=4`0D4aT04a4F014<
4P0E41H04@`B010;4@0C3Q@03PT?010;4@0=20h040/A01@?5@0?2Q0Dooooo`006oooool0700=2PD0
3PX6010<2@0A3@X0510>01@@3`0;1`H02@H500D10P0d<340510A00d72@0C2Pd04@/>00`:3`0;2Q00
2P/D00T;5`0;3AT05aTT014A6@0A3aD03P`A00l:3P081`L020H700L51P0>30d200L51P0;00l=3P04
0P<03P`=01hL7@0B414030X;00X62@0H4aL020<701HA5@0300800P0C3Q83018=4@804@`@01804a8G
00X93P071P/071/P03dl@@2n_L80@T5600X93P0J6Ah030/@01dL8@0D4QH04@l@00l=3P0@3Pl04Q0A
014?400D4Q<201LE5P0401DC500C4A804Q0A01@C508061PH00<04a<C00h>3P0@41000P0C4a<01@0F
5QH05ADE00d=3@0=3@d051@E008030`>01D0410B018B500E5AL05QHH01PH6P0G5aT05QHH01LG6@0H
61X04Q<F018F6@0@4QD082@W01TM800C5aX05a/N01<G6P0E6A`06QhQ01PL7`0D61/00`0E61l0;P0D
5a`04aHK01<F6`0A5AP051PK01DI6P0G6a`06AdN01DI6P031P/05QTN01TL8@0G6Ql00@@901<F6`0J
7B806A`Q01@G700@4aP04QDJ01TL8@0H7B<0724W02L/<P0E6B8061`V01`P:`0B5R406AdY01HJ9P0[
;c/0720/01TM:@0D6bD08RTa01lV;P0F7BD0=Se5071gO`0f?DD072<[01dT;00J8BT06b8Z01PO:@0F
72P201LM:@0c01HM9`0F7BH051/S01PO9@0F7B8041PK01<K7P0J8R@05alR01PO9@0K8RP06R4W01PO
9`0J8BX07RD_01HM9`0L8Rh06Al[01PN:P0L8Rh07BDb02djA`1^O8T0>dUF0;O4d01^NXX0;CU701/W
<`0P:S@07RT_01PS9@0F82405b<S01`W:P0I92P06RDY01HQ9P0E82H06b@[01HO:00K92d05b0Y01@L
9`0E7BP051`W01XQ:`0E72H072<]02P_=`0M92`06B0X008061lU01l04QXN01TQ900J8RD05A/P01@I
7`0F6R<05a/U01HJ9@0E62L071l^01/O:`0L82`06AdW01XN9`0:3aD05QlQ018N7P0E828031LL00lI
8`0O:CD0Ae5N0;O0c`0_>DD07BLa01<M9P0:5A/03aLO01HJ8`0D6Al04aPM00804aPK00X04ALG018H
600G720061dR00lD6P0E6B804A@M018E7P0E62405QTP0P0G6R4201@G700L01@H6`0B5QT03a<F00`@
500=4A`05Q`X01PN:P0<4Qh03aDQ014H8P0F7BL04aXT00lF7P0@5ad04QTO01<J800D6Al04aPN01HK
8@0F6al04QLK01@I7@0B5aX05AXM018G6P0=4a<041HF018H60803Q4F00P06ahS00/?4P0>4QD02PhA
00lC500A5AD04QHE010D4`803A4@00L04Q@C014C4P0@4Q40418A018D4`0D5QD0418A00@04A<B01<0
418A00/=300B51<03a4@01<E500L7Qd05QPG01XL6`0?4A004aDD014C4P0<3Pd06adL01dO7P0H6QT0
6Q`K024S8P0;3@`010H500H04A<B00@0410@014A4@0B4Q8051@D0P0E5AD01`0T92@05QHF00l?3`0@
410051@D01LG5@0@4Ph01P0@4Pd01@0A4`h04Q@?01<E400A4`h0418=00805ALD00X03@l<00h@3@0A
4a002`d:01`N6`082PL01PP500L91P0O8Ah0418>1@0?4@`03`0@4Pd04Q@?01<E400A4`h03a4<010B
3@0B50l0418=00h@2`0<3PT03@l:00lA300D5Q405ALB010B3@0200d?2P0300lA300@4@`03Pl900@0
3Pl902D0414;01<D3P0Q8Q`03Pl9018C3@0>3`T04Q4=014@300C4Ph051<?018A3@0=30P04A0<010?
2`0A40`04Q4=014@300=30P01PH600/=300:30/05QPG01TK6P082PT04aDD00`>3@0@4Q405aTH00h@
3`000P403`l=04I6A00E5A<03Ph<00<30@0=3@/02PX80080410>00<020P600d=2`0B4Q001P0>3`X0
0`0<3@P03a0;010A300200/<1`0801PI500;2PP030/900h=2`0@3`d04Q4?01<B400?3P`200h=2`08
00l>300>3@/03@T8018>2`0C3``04Ph;010<2@0A3@X2018A3@0?01`K5`0E5Q40414<01@F4@0B5@h0
3@h700T:0P07200030d700X;1@0@4@/03@h:00H6100E5A<02@T70080410>01@061LC00h=2@0;2PH0
3@`8014@300B4@d02@P600H50@0f=C402@P401HE4@0920@03`h:00T8100?3PX03Pd900/:1P0@3`/0
30/700d<20803Pd90P0<2`L00`0?3PX03Pd900d<200200h=2@0900l>2P0@3`/040l;00l>2P0B4@d0
3`h:00`;1`0@3`/01`H200803Pd900D02`X601LF4P0?3PX03@`800h=2@02010?2`803Pd900D03`h:
00h=2@0=30P03`h:010?2`0500l>2P0A00h;200I5A806aLD00l;20081040;2PU020L6@0B3P/03PX7
01HB3`0A3@X02`L400/:200>3P`02PX800d=2`092@L00P0=3@/04`061P@05aLE00`<2P0D51802`/9
014A3`010@0071`J010@3P0?3`d04A4?00h>300=3@/02`/900`<2P0@40h051DA00d<200=30L00P0<
2`L0400=30P03`h<018A3`0D4Q801P@500/92P081`L08AlP01<C4@051@<04Q8@014A3`0>3P`0410>
00/;2@0<30X200d=2`803`l=00T051@D00L71`0C4a<05ADE00X:2P0C4a<030`<00/;2`0<30`00P0>
3Ph03@0:2PX03`l=00h>300<30X02`/900X:20092@L01PH400h>300F5Q@04A4?00d=2`0@40h01P0;
2`T200`<2P0400h>300A4@l02`/900h>30<02`/;00l030`<00h>3P0>3Ph02`/;00`<300?3`l03Ph>
00d=3@0:2PX04a4B01HD5@0L6Q/08alP01/G600D41400`0@2P`20189300N010;300>3@/040l=014@
3P0@3`d03Pd;00`;2@0=30X03`h<00d<2P0>3@/05A@B01HE4@0A40/04Q4=010?2`0>3@T03Pd;00l>
30081`D03P`=00X82@091`P07Q`M01hL7`0@3Q<03P`?00l=400@3Q403`d>0P0>30d200d<2P0[00h=
2`0?3PX020P600l?3`0:2PX07QhN00X:2P0?3a403PdB010?500=31404A0F018A5`0:2A002PPC01TG
8P0:2A003`hC00d=3`0=3@d00`<300d=3@0;2`h051<I01<B6P0>3AH03`hC00h>400A4A<0410B00h>
400F5QP07AdO01DE5`0;2`d03@d?00l?4@0;2`d04Q8B00d=3@0?3`l051@D018B4`02018B500300H6
2@0>3A8020L<00803`hD00H05aDJ00X83@0F51T03@/@00l=4P0:20d2014?500400h<4@0@3Q<0518G
010>4aCooooo000Kooooo`0Y010=200A3@T04@d:018>2`0C3`d04`l>00l;2P0@30`05a<D051<C@0M
6AX03@X:00h9300=20d02`T>00/:400>3QD03a4I010?600@3aL04@hC018=4@0B2`l05A0A00l<3@0B
41405A<D018@4@0>30d03`d>00h<3@0J61T03@/<01PF5`0D4Q<03P`=01<>4P0G4QH06A@H014<400E
41@01P0B3A404@0@3Q4040lD018A5P0I61d06aXO010@501FEEX09RDZ00T83@0@3a@03`hC00`;400@
3a40518C018@4@0C4A80518C00L04a4B01h04Q4B01<C500D51L04a<E010@4@0A41@05A@G01DE5P0H
61/06a/M00h>3`0=31005QHH00`<3P0I6A/05ADG010@4P0K6ad04a<E01LG6@0F5QP05ADG01HF600G
5aT05AHI01HJ7@0I7B005ATL02<W:P0B5QT201<G6P0401HJ7@0I7B0061`O01@H6`8051LN00H05QTP
01HI7P0D5a`04aHK018F6@0C5aX401DI6P0V010B5`0F6Ah06ahS014D6@0P8bP05APM01XM8P0I7240
5APM01<F6`0D5a`05aXO01HK8@0E6R007b@Z01HK8P0L8BT0720Z020T;`0S9c80<SI101@H900H72P0
6alZ01PO:@0G7RH05A`T01@K8`0H7bL072<[034h@00H7bL07bH^01/R:P0G7RH06R4Y01LN:00I7bX2
01TP:P1K01TP:00G7RH06B0V01PO900B6Qd051`O01XR9@0H82<08RT_01hU:`0J8BL06b8Y01XQ:@0G
7RL061lY01XQ;00H7RT06b4]01hT<00J8Rd05b@`02<a?@0I9c<0;3Q702TeA00I9C<07BPc02<]=`0Q
;3806B<V01HP8@0H8R805b4S01TR9P0L9RT06B4U01HN8P0I8BP06R8Z01`T;@0J8RX05alW01hU<00U
;CH05ahX01/R;00A62806R4Y02<Z<P0G7RH061lU01`S:@0D6b007bLZ028Z;@0E72404QPN01@I8P0D
6R<051XT01HJ:@0I7B`05AXV018G8`0@5Al051TR00/A5`0O:2/04A`M01PS9@0kADX0:38k014J9@0L
9C40=Ci904QAG@0B6bD06b@]010J8@0H82L05adU01HL8P0D6Ql04aTL018I6`0D6a/051`K01LN8@0H
7R<04QPN01HK900301PK900B01LJ8@0E61l051LN01@G700E61d05QXM01DI700D61/04QLJ01LK9P0B
62@04ALS028Y=00N92l061lY01<J8`0B6B404aXQ0P0E72806`0B6Al03Q<I00hC6@0@5AX04AHJ018G
6`0E6Qh04QLJ01DJ7@0C6AX03aDE014G5`0B61P05ATL00lB5P0_<SH0;S8e01XN8@0D61X041@E00lC
4`0B5QD041@C00lC4@0D6AH05ALF01<E5002014C4P0301@F5@0G6AP04Q@C00@04aDD0P0B51<04@0?
4A005QPG018D4`0>40l092HU01DG5P0G6AP051HE014C4P0B51<05aTH01TK6P0A4a803a4@018D4`0F
61L02P`;00H04A<B00@04A4A018B4P0B4Q804a<C0P0D51@2018B4P0801<C4`0E5AD04Q8B00l?3@0?
4@d03a4<010B3@0A4`h2018D3`0C014C3P0B50l04Q@?010B3@0A4`h04Q@?01<E4P0F61D0418?01<E
4P0D5Q<03Q0=01DG500?4@h05QPE00`>2`0D5Q<04A<?014C3P02018D3`03014C3P0@4Pd04A<>00<0
4A<>0`0?4@`00`0@4Pd03a4<00d?2P0200d?2P07010B3@0A4`h03a4<00d?2P0>40/03a4<014B3@06
010A2`0501DF400^;bT03a0:014B300@4@/00P0@3`/04`0C4Ph03Pd900T8100A40`05QDA018A3@0=
30P03Pd9010?2`0=3@P04Q8B01hP7`0M7ah04A<B00`>3@0I6aX0:2XY00`>3@0C5A@00P0=3`h03P0I
6aX0DU9@01lO7@0820L051@B014A3`0=3@`03Ph<00l?3@0@40h03Ph<00l?3@0B4Q003a0;0P0>3`X0
0`0@4@`04A8=00l@2`0200l@2`8051D@0P0?40/2010?3@<03`h<00D03Pd;014@3P0D4a404a8@014@
3P02010?3@0L010>2P0B3``04@h;010=2P0@40/04A<>01@D3`0;30P02@d700lB3@0A5@l02`h701DF
3`0P8AT06Q/C01LH4P061`404A8<018C3`0[:bT0Hf=Q01LG5@030`804A4?01LF4P0?3PX03@`800h=
2@803`h:0P0B4@d02`0;2PP051<?00D40@0E51003Pd900X91@0F5A404Q4=00T8100@3`/03Pd900<0
3`h:00<03Pd900d<200>3@T01@0>3@T200l>2P0<010?2`0E510051<?00/:1P0F5A403Pd900d<2009
20@061LC02l^:P0@3`/03Pd90`0?3PX400h=2@0300l>2P0B4@d04A0<00D03Pd901D03@/701TE4P0M
6AH05a<@00X60`0F4Pl0510=014=2P0D40d030P500L3000V8b0051<A014A3`0;2`T04a<A00d=2`0:
2PP03`l=00X:200;2`T00P0A4@l01`0=3@/03`l=018B40071`D05ADD01HF500<30X00P0;2`T01`0=
3@/03`l=00h>300:2PL03`h:00l>2@0>3@T00P0<2`L0300<2`T03`h<00X92@0<2P/04@l@018@4@1i
MgP0:b/Y00`<2P0B4Q0020P600X:208030`:0`0=3@/200h>300:00h>3P0;2`/05aLG01TI6@0>3Ph0
30`<00h>3P0<30`02`/;00d=3@803Ph>0P0A4@l01`0?3`d03Ph<00d=2`0<30X04A4?00h>300<30X0
0P0=3@/00`0<30X03Ph<00h>300400h>300?00d=2`0>3P`02`/900h>300=3@`02@T700h>3P0?3`l0
30`<00l?3`0B4Q803`l?00`<300>3Ph030`<00803Ph>00P02`/;00`;300:20T03@/<01@A4P0@30d0
2PH7010;308040X<01H04@X<0189300@2`/03`h<014@3P0B4@l04A0>00l>300=30X04a8@01LF500B
4@l030/9010?3@0B4@d03@`700d<200>3@T040l;00l>300=30X030/90P0>30d01`0:20T040h?01HD
5`0A3a@03P`?00l=400@3Q400P0?3@h0>00<2P/02`X800h=2`0:2@L02`X600l>2`0A4A005QHF00L7
1`0>3Ph0820R01PH6`0;2Ph04a8G01LF6`0<2a403`hD00/:4P0=31@030/@01<B5`0=3@l03Ph>00l?
3`0>3Ph02PX<02LV;0040`T03@`C00l>4`0=3@l03Ph@00d=3`092@/03Ph@00T92`0@41804A4C00P8
2P0:2P`06a/M00h>3P0<30`03`l?010@400?3a005ADG010@4P0B4QD01`H;01@C600>3A<01@@:010>
4`0>31403@/@0P0B41D01`0;2@h04Q0E00l=4P0>31403`dB010>4`0>31405?ooool001_ooooo00l0
3P/600h:1P0=2@H030P500/71@0:1PD03PX9010<300N6Q/04@d>010<3@0>2P/04`hB014=4P0>3140
0P0<2a406P0<2a000@0500X62`0C3a00614B01H<3@0?1PL0514B00h<3@0F51D0F5IG05YHF@0@3Pl0
3@/<02TW:00<2P/03@/<010>3`0B414040/?03<^<P1^JFd08QdQ01HA5@0I51P04@`@0`0B3A403`0C
3Q804@lB018A5P0<2a002`X?01LF6`0B4AH05aHK01PG700K6Ql030/@01DD6@0?3Q<05aHH01LE5P03
01DC500<01@B4`0A3a003`d>00l=3P0B41404a4B01@B4`0A41@040lD01<B5`0F5AX05A@I0P0D4aP2
01<B5`0;01LF6`0B4AH040lD01@D5`0?3a407AdO018B500?3a408R8T01PH6P0E5AL00`0D51H02@0E
5AL07b4T01LK7P0I7B00;C4d096EV00U:B`041@G01<G6P0201DI700:01LK7P0E6A`04aHM01@G7P0F
6B005APM01@G700B5AX051PK01<G6P805ATJ00P04QHG01DI6P0/;c@061/P01@G700A51T06ahS01TL
8@805QTN01h05aXO01TL8@0H6b0051LL024V;00F6b404aPN00dB600J7bH06alX01`P:`0i?DP0KW9m
02lc?`0Q9C404ADP01HM9@0L8b/07RD]020W;`0O9Rh05ahV01`S:`0F7BD082L_01TP:00F7BD061lW
01DL900G7RL301PO9`0501LN9P0D6b406R8V01HN8@0C6ah00P0E7B00800V;C<072<Y01PO9@0L8bT0
6R4X014H800M92h06R4[01PO:@0O9C407R@`01LO:P0G92h05B<^00lM:00I9C<05b<a01XV<P0G8B`0
6bD^01XU:`0F7b<051hO01LP7`0J82<05AXM01<K7@0H7b809BX^02de>00H7bD05A`R0P0E72@0:@0M
92`09bhf01XQ:`0H7bT0>3m901PO9`0G7RH03QDM01<J800G7R@04aXO01TQ900J8RD05ahS01XQ9`0J
8BT051/T00hE7`0@5R@04ALU014G8`0J82`041LP01<J8P0E72809Rhb01DO800C7Al0Ae1D02lh?`0;
51d0620[00dE800^=T4041PR00hG800J8bX04a/S01DL900D6b404aXO00804QXL00T051dL014J6@0>
5QT051/P018I7`0A62004aLP01DH8@0G6R<00`0G6R400`0G6Ql05QTN01<G6P02018F6@0E01<G6`06
3AL04ALS01<I9@0D6bD082La01PO:@0A62004QTQ01LN900I82H05ahT014H7P0E6R006AhT01DJ7P0?
51P04AHJ01DJ7@0?51L04AHI00803aDE00X04aTI010F500E6A`02`lB01PL7`0L82<04QHH01HJ6`0C
5aP03A4@0P0A5A@0100A5A<07B8N01@F5@0C5A@2018D4`0301DG5P0F61L03Q0?00@0418A00<03Q0?
01LI600:30/00P0G6AP03P0R92<0EeUH01<E500Q8b805QPG00lA400E5aH03Q0?01DG5P0F61L03a4@
01LI600I6aX02`d<1P0A4a80100C4a<04Q8B018B4P0A4A42010@400301<C4`0?3`l03`l?00804A4A
00@0410>00lA3@0?4@`0418=0`0A4`h04P0C5A00418=00lA300@4Pd04A<>018D3`0@4Pl04aDB014C
400>40d0418?014C400F61D04aDB00X<2@0>40d04A<@00h@30D03a4<00D04Q@?01<E400A4`h0418=
00lA300200d?2P<03a4<0P0>40/00`0=3`X030h900h@2`0200lA300300h@2`0@4P`04Q<=00@04Q<=
00H04A8<00D6000>3`T0414;01`M5`092P@200d<200;018A3@0@3`/03@`8020O6`0L6aL05A@@00l>
2P0B4@d05A@@018B3P0J71T00P0@4Q408`0J71/04A<B01`N7@1=Cdh01`T800T;2P0?4A0061XI01@F
501EEE<01PH401@D4P0000007alM01@D4P0@40h03@d;00l?3@0B4Q003Ph<00`<2P0A4Pd03@h900h?
2P0B4`h04a@?010A300<3@P02@X501@E400L7AP061TD010A300=30X03Pd;00803`h<00<040l=014@
3P0?3P`00P0B4@l01@0@3`d03`h<010?3@0=30P03`h:00803Pl:01D0418=01<E400D5Q4061dG00H;
1@021`40:2dW04E:@`0O8AT0824I02@U7@0L7AL02P/5010A2`0H6A@05QHD01/K6@04108061PF02LW
9@0A40`00P0?3PX0400@3`/030/700T8100:2@H03@`8010?2`0>3@T03@`801@C3`0B4@d04A0<01XI
5@0H5a<03`h:014@300?3PX3010?2`0500l>2P0>3@T03Pd900h=2@0?3PX00P0>3@T02P0?3PX04Q4=
014@300?3PX04Q4=014@300=30P04A0<00X91@0?3PX200`;1`0301TH500A40`040l;00803Pd900@0
4Q4=01LF4P0E510040l;2@0=30P0800?3@T04Ph;00`81@0B3P/03PX700X60`0A3@X03PX701<?300A
3@X03@T601PF4P0G5aD030`:00l?3@0410804A4?01@D4P0=3@/05QHD00X:200K6aT0410>01@D4P0=
3@/01@D301hN701dM7806QXH014A3`0J6QP04a<A0P0;2`T01@0=3@/03Ph;010?2`0?3PT03Pd90080
30/700X030/901<B400F51@020H700/92P081PL07A/L01@D4P0:2PP03`l=0P0<30X00`0820H03@d;
00d=2`0400d=2`0:00X:2P0B4Q802@T900D51@0=3@d02`/;00P8200?3`l04Q8B00l?3`803@d=1P0<
30X01P092@L04a<A010@3P0<30X04Q8@01HF50H030`:01T03@d;01<C4@0<30X00`<200X:20010@00
3@d=00h>3P0820P02`/;00l?3`0:2PX03`l?00h>3P020P804a<C01DE5@030`<04a<C00l=3P0>30d0
4@l@01DA4P0F4Q<03`/<00<040X<01/04PT<00l:2`0=30X03Pd;00l>300>3@/03@`:00h=2`0D4a40
6APF01DD4P0<2`T02`X800l>2P0?3PT030/700/:1P0=30P03@`:00h=2`0@3`d02PP9010>3`0<2P/0
0`4200d;3P0?3A800P0=2`h0400>30l03P`=00d;300=2``03@`:00`;2@0=30X03@`800T81@0J6QP0
?clo00d=3@0>3Ph03`lA014A4`00008200`;400`00P7300P7b@03`hD00`;4@0>3A<04A4C00h>400<
30`0000002<S8`0410H051<H00/:400@3aD030/@00T92`0<30h03`lA00d=3`0@41805QHH014A4`0<
30h03@d?014A4`0B4Q@0410@00l?3`0B4Q804a<C014A4P0F5QP03Ph@01@D5`020@H04a8G00`;400C
4QP01`D:00l=4P0W9BX04@lD00P62`0=2a004Q0E00l=4P0C4AH0518G0P0A3a@Dooooo`006oooool0
6`0?3PT03Pd900d<200<2`L02`X700X91`0G5Q@03`d=00`:2`0100003P`=00`:2`0B41<04Q0E014?
500?3A803@/@00/9300E4aH04Ph?00P20P0@1`L06Q0?01<:2`0>2``00P0100X82@02055?D00=00/9
2P091`P05aDF00h<3@0?3@h03P`=01LE5P0:20`04a4F02LU:P020@D02PP=018@5@0200l=4P06010>
4`0A3a@04@lD014?50092@/06QXL0P0@41801P0820X04Q8D01XJ700E5AL01@D700H6208051@F00T0
5QHH01@D5P0D51H051@F01<C5@0@41803`lA010@4P0A4A<00P0B4Q@0100C4QH0414F010A5P0A4QL4
018C600<010A5P0B4aP061TN01HG700D5AP04Q<E01TJ700?41804A8D01dN800F5aT05AHH0`0D5AL0
200E5QP041<E00hB5@0G6ah01@T<03Xn@@062Pd04ADH0P0F6Qd0100D61/061`O01PL7`0D5ah201DH
7`8051LL01004aHK01PL7`0F6Qd06AdN01PL7@0C5aP06AdN0:6TZ@0Y;3405aXO00001@0X:c00DEAI
01DH7@0D5a`05APM0P0I72405P0E61d04QLK014F6P0N8bL0724W01hR:P0F6R<09BTb01LK9@0S9c80
4ADP02<W<P0f>TD02Q4I01<J8P0B6B404aXR01LN9P0D6b<072<[01/R:P0Q:30201XQ:@805A`T0240
5QdT01LN900H7bD061lU01LN900F7B<06B4U01DM800C6ah05alR01HN8@0M9BP0620S01HN8@0G7R@0
5ahU01@K8`0M92`07B@^01/R;00N9Bl082La01/T;@0D82T09S<l01@Q:P0F8Rh04A/W01LQ;@0F82/0
5b0Y01LP9`0G8B@00P0I8B<0200N8R<061`M01LM7@0H71l082@W02P]<00F6al04AHJ0P0D6Al0:@0D
6b406R4Y01TP:P0I82X0C5=M02H]=@0M92`04APP01<J800F7B<05QhR01HN8@0D71l05ahS01lV;00Q
:3006b8[01@K9@0D6RP06R0^01/Q;@0/<Sh07bH_01dT;00F7B<051`P01DO8@0?6A/07BLZ00hG7P0<
5A`0:C8k01DN9`0<5Ah05QlX01lX<@0J8b`03aLP01<J8P0B6Al04QXN00804QXL00H05AhM014J6@0?
5aX04a/O014H7P0A620201<G800701DI8P0E6R005AXP01DJ800E6Qh051TM01<H6`02018G6P07018G
6`0E72@03A@N018I8`0A62809B`f02Xa>@02018I8@0D01@K8@0G7b805QhQ014I700F6al06QlS01LL
800B5aX051TL014F6@0B61P04ALG00hD500D6QP06AlM018H5P0>4QD07B4T00T=40031`P200dA4P06
01<G5P0>4Q4051TE01@I5@0@5A406QlK0`0?4a801@0@51<04ADD014E500<40l03A4@00803Q8A01@0
3A4@00`@3`0C5aH041@C014E500;3`h01@T801<G5P0>4Q405QXI01<G5P0>4Q404QHE01PL6`0i>cX0
9RPW00/=300C5A@051HE01<E50P04A<B0P0@4Q4200lA400701DG5P0?4A003@l>00lA400@4Q40418?
010B3P04010B3@0P014C3P0J71L04A<>00h@2`0?4@`03@l:00/=200B5140418?018D4@0:30T04A<@
01PJ5`0D5Q<06Q`I018D4@0G6AH04aDB00lA3@0>40/03@l:00h@2`0?4@`04A<>01TK5P0K7AP05QPC
01<E400@4Pd03@l:00h@2`0@4Pd200h@2`0300lA300A4`h04A<>00@03a4<00<03Q0;00lB300@4``0
100@4``0;`0B5@h04aH?014D3@0<3`P04QD>00/>1`0B4`h02``700l@2`0C50l03a0;01PI500G61<0
4Q<>00l@2`0F5a805aPC014B3@051`@02P`9018D4@041P<01`T607IhM@2CUI809RPU00H81@092`P0
6A/H00/=2P051@<03a0;01<D3`0<3@P03a0;00X;200=3PT02@X500l@2`0E5Q403Pl:00T:1@0@4@`0
30d800d>2@0B4`h04a@?00803a0;00d02``7018C3P0G61<05AHA01<D3`0:2PP030`:00d=2`0?3`d0
4A4?018B400=3@/03Ph<00<03`l=01@03Ph<00/<1`0>3`X03Q0;00lA300C5A005AXD04U>B01@EDl0
3aH?01LN5`2>UHh0d=O?034c;00;30@0414900h?2@0=3PP04A8<00<40@803@d;01H03`l=00d=2`0:
2PP040l;00h=2@0?3PX040l;00d<200;2PH03Pd900d<200N7AT02`X601<B3P0>3@T04A0<010?2`0A
40`04a8>014@300?3PX03Pd90`0?3PX00`0>3@T03@`800d<200300l>2P0800d<200?3PX04Q4=010?
2`0>3@T04Q4=014@300=30P200h=2@0;00l>2P0>3@T02PT500/:1P0@3`/04Q4=00l>2P0@3`/06APD
024P700H5a<00P0@3`/00`0C4Ph04A0<00h=2@0500h=2@03010?2`0B4@d030/7008040l;02403`h:
01<B3P0B4@d040l;00h=2@0=30P030/700d=2`0:2PP09RHT0000000B4Q003`l=00L71@0?3`d030`:
00l?3@0<30X03Ph<01DE4`020P002@T80451?`0410805ADC01/K6@0D51802`/900`<2P0?3`d0410=
00/<1`0;30H00P0;30L03P0<3@P03Ph<00D50`0:2PT010@400`<300G5aL02`/;00/;2@0B4Q002`/9
00l?3@0=3@/02@T71P0=3@/0200>3P`04Q8@00/;2@092@L03`l=00h>30061P@030`:0P0@40h0100?
3`d03Ph<00d=2`0=3@/200`<2P802`/900H030`:00l?3@0=3@/03Ph<00X:20020P0600d=2`0B01<C
4@00000051@B018B400E5A<04A4?00h>3P0@410020P800/;2`0>3Ph01`L700l?3`0A4A401@D5010@
400B4Q802@T90P0;2`/0100:2PX030X;018@4@0F51D300l;308040X<00<040/<00h=2`0>3@/0100>
3@/00`0@3`d04a8@018A3`0200l>300A014@300@3`X03`h:00d<200<2`L03@`:00T81P0>3@/03P`=
01hL7@0M6a`03P`=01<A500?3A803@/>00h<3`0?3A000P0>30d0@@0D4Q<04a8@00`;2@0A40h04A0<
00X:1`071`D02@T701PH5P0410803Ph>01@D5P0>3Q005QHH01`K800c<SL0E5=H010?500<2a003PdB
00`<3P0?3a402`/=02@T9P1DE5H05aLI01<B5`0@3a@03`hC00d=3`0:2P`03@d?014A4`0?3a40410B
01DE5`0?3a402@T;00`<3P0>3Q002`/=00l?3`0<30`0410@018B4P0>3Pl03`lA00h>400A41@01@@9
01@C600<2a406APN00X93P0H5a`0Ogj302/Z;`0:2@h02@P=018A5P0?3Q<05aHK01TH7@0D4aP04a8G
01Cooooo000Kooooo`0<00l>2@0=30L030/700`;1`0<2`P02`X801@C4@0j>CP061HG018@4@0=2``0
518C0P0B41D03@0A3a<040hB010=400?30h04Ph?01<>3`0A30`05Q0@01092P0=20T03@X;01<A4P0@
3Pl00P0?3@h08@0@3Pl04Q0A00l=3P0A3a003`d>00X82@0@3Q4040hC01PE6`0:20h040hD01LE6`0L
6R005aDK00h<4P0C41H040hD014?5@0K6Ah06a/M010@4P0=3@l04a<E00P82P0I6A/03@d?01HF600A
4A<04Q8D01LG6@0A4A<04a<E01LG6@02018B500401@D5P0@4180410B01<C5@80410B02D05ADG01HG
6P0E5Q/04a@I01@E6P0E5Q/05QLL01@E6P0C51T04Q<H01<D6@0I6Ql061TN01DF6P0J6ad05aPJ01HG
6@0Q8R@05AHH01<D5P0=3Q006a`N010@4P0L7Al051DG01@G6@0@51L051PK01HJ7@0B5QT061`O01@H
6`0G6ah05ATL01<G6P0G6ah06QhQ00<051LN00`04aHK01@G700G6Ql05ATL01@H6`0G6a`05QXK01<G
600E6AX07b8W05ULH@0O8RL201/N8`0E02T/<@0D5a`051LL01DH7@0H6b006A`Q01LJ7`0F6al05AXN
01PM8@0D6Ah05Q/Q01@I800G72<06QhW01TM9`0L82/08BD`03LkAP0J8BT05A`T00806R4Y00X06B0X
01<J8P0I82P06B0X01XQ:@0H7bL06R4Y01@K8`0G7R@0620T0P0I8BD201XQ9P1^01PP900I82@05QhQ
01HM8P0I8BD06B0U01DM800K8bH072@W01XR9P0J8BL06b8Y01LN9@0O9Rl07RD^01LN:00I82X06B8[
01TU;00J9bh062D^01LR;00K9C00628]01TR;@0I8B/06B4Y01/S9`0L92H07B8U01dO8@0P8B<071lP
01dO8`0C5aX06AdP01dR9P0F7B005A/O01HL8P0B6Al04ATN01HM9`0c>T@05ahX028Y<@1@Eel0@4M?
01PO9@0F7B<06B0U01/S9P0F7R404a/O01LO9@0K8bX06B4Y01@L9@0D6bP04aXX01`S;`0_=T808BTa
01TQ:00G7b@051dQ018K7@0?61/05AhQ01HO8`0E7R80620W018J8P0J8RX06b</01lW<@0C6bD06B4Y
01@L8`0B6R0051dQ014J700B6ad06B8Q01/U900D7B00624T01XR:00E7BD06AlW01TN9`0G7BD041HL
01@J800C6Al04APK01<I7@0I82806AlR01<I700A61/0@dYB02H]=`0L8bd04QTR01HM9@0F7B@04aXQ
018I7`0B6Ah201@L7`0F01<K7P0D6A`041DI01TN8P0F6ah04aPK00hD5@0F71`02a4A01@J6@0@5Q@0
:Bl/01LM6P0E6AX0:Bd_01@H6P0;3a005QXJ01<G5P0A5A@05AXF01<H50804AHA01l04AHB00hC4@0=
4Q404aPG014F500?51<03A8A00lD4P0@5A<04AHE00hC4P0A5QD0314?018G5P0A5Q@04QLE00hC4@0?
51<03A8A010E500>4a805AXH01@I600K81h0?D500<c>c@1VJ6L030h=01HH5`0@4Q404Q@C00@04aDD
00<04Q@C014C4P0C5A@00P0B51<0100A4a80418A00lA400B51<2014C4P0?018D4`0A4a80418?014C
3`0A4`h04aD@018D3`0@4Pd04Q@?01hP6`0<3PT0418=014C3P0B50l04A<>00803a4>00H051HC01<E
4P0L7Q/07b4N00d?300?4@h2014C4007010B3`0F61@020X701DG4P0@4Pd04aD@01XL5`03010B3@0C
01<E400B50l0418=018D3`0D5Q404A<>00d?2P0?4@`08R@O018D3`0C5A003@l:01@F4@0@4Pd03Q0;
00`?2@0A50d04QD>00lB2`02018E3P0300hA2P0?4P/03a4<00<04A@=00T05QLB00h?2P0>3`X051D@
018C3P0>3`X04Q<>00h?2P0?40/00P0D5A006P0?40/04Q@A00lA3P0O8Ah05ALD00d?300Q8b00=3Hc
00`>2`0B51403a4>010B3`0<3P/04A8=00h?2@0@4@`04Q<=010A300>3`X0414;00h?2P0C50h061TC
01<D3P0?40/03Pl:0P0=3PT0100@4@`04A8=010A300C50l3014B3@0300l@2`0@4@`0410>0080410>
0`0?3`d01`0=3@/05aLE01<C4@0>3P`04Q8@00`<2P0>3`X00`0?4@`0700B5Q005Q/E08bAR`1lPW/0
51/D01<J4`21RH80]Kbd02la:@082@404149014B300<3@L020T301<D3`0B4Q00410>00h>30061P@0
5aLE018A3@0D4`l03`h:00h=2@0?3PX03@`8010?300=30P2010?2`09018A3@0A40`0>cXf01<B3P0:
2@D030/7014@300;2PH03Pd900804A0<0`0>3@T0100?3PX03@`800l>2P0@3`/300l>2P0:00h=2@0=
30P040l;014@300>3@T040l;01@C3`0@3`/03Pd9018A3@803`h:00X04A0<010?2`0B4@d06APD01/J
5P0A40`030/700h=2@0B4@d040l;0P0>3@T0:P0?3PX04A0<00d<200>3@T04A0<01<B3P0<2`L040l;
01<B3P0>3@T010<1014@300?3PX02PT5018A3@0G5Q802PX8014A3`0Z:RP02`/901@D4P0<30X06a/I
00/;2@0E5A<01PH400l?3@0>3P`030`:00l?3@0>3P`0410>00/;2@0@40h051@B01DE4`0=3@/06ATG
00d=2`0=3PX030d800`=1`8030d800/03Pl:018B400=3@/03`l>00`<300>3Ph0>SXj01PH600A4@l0
5QHD00T91`0300`<2P0>00d=2`0?3`d03Ph<00d=2`0>3P`0410>00h>300:2PP05aLE00h>300?3`d0
2PX801DE4`0@40h300d=2`0300/;2@0@40h030`:0080410>00P03@d;01<C4@0:2PP05ADC010@3P0;
2`T03@d;00/;2@H03Ph<0P0G5aD0<00D51802@T8018B400=3@/04A4A01DE5@0@41003Ph>018B4P0:
2PX02@T900h>3P0=3@d02`/;00X:2P0>3Ph02P/;010A4@0=3Pd03@`<01DC500A3a003@X;00l;300A
3@h04@`=00h92`0>30/03@`:00l>300Y:2H04Q4?00d<2P0<2`T03@`:00l>300A40h040l=014@3P0A
40`040l:010?2`0?3PX03@`800d<2P0A40h05A@B00h<3@803@/<02H02PP9018@4`0?3A803P`?014?
4P081`T040h?00d;300A3a004Q4?00l>300F5A<05aHB018B3P0;2`P03Ph;04Y:B00W9bD03`l>00`<
3@0A4A8030`>014A500X9b/0=cLj00h>4@0=3A003PhA00`<3P0?3a4030`>01PH6P0X:2X030`>00X:
3@0Y:2`05aLJ00l?4@803Ph@00H03`lA00d=3`0=3@l030`>00l?4@0@418200`<3P0G018B500?3`l0
3Ph>010@400B4Q803`l@00d=3`0@41803`hB010?500D4aP04Q4G02d/<P0C4QL07QdR08>2Q`0m?440
51<H014@5@0@3a@02PT>01<B5`0B4AH00P0?3Q<Dooooo`006oooool01@0?3PT030/700/:1P0<2`L0
3@`900802`X8014061LF00`:2`071@H03P`=00l=3P0?3a403P`@00`:3@0;2@`030T:00h:2`091@H0
4@d>01@B5@0=2`h03`d@01@B5@0200h<3@<03@/<0P0<2P/03P0@3Pl030X;00h<3@0D4Q<05A<F028P
9P0D4AP02`P?00h;4P0Q7RD0B4E<01dJ8@0?31<04a0G0P0>2a806`0J61d061PJ00/;3@0C4aD0410B
00/;3@0C4aD05aLI00/;3@0@41805QHH00000P0C4aD03@d?01HF600G5aT030`>014A4`0F5QP04A4C
01@D5P0@41803`lA01@D5P0A4QH051DJ01DF6`0201HG700301DF6`0C51T04Q<H008051DJ01404a@I
01@E6P0C51L061TK01/L7P0H6A/09RLY020Q8`0I6Q`092DW05AEE`0U9RP05QLI014B500M82805a/N
01HJ7@0201@H6`0501DI700H71l061`O01LK7P0F6Qd00P0E6A`0200K7RD05APO01PK8P0P8bP06ahS
010C600C5aX051PK0`0F6Q/05`0E6AX05aXO01dP9@0F6Ah05aXO01XM8P0I72404QDJ01<F6`0F6Ah0
6A`Q01XM8P0K7R<06AhR01LL800F6al061dQ01TN8`0F6b406QlU01XO9P0J7RL06alZ0080720[00P0
:c8j01/R:P0P9bl061lW014H800@5al05ahV01PO9`806B0X00@06R4Y01/R:00H82<0620S0P0I8B@2
01XR9@0E01HN8@0H82<0620S01HM8`0G7R@061lU01@L7`0K8bH07RHY01`T9`0J8BH06R4W028Y;`0A
62003A@L01DL9P0M92h06R<Z01HR9P0F8bT04b0V00805R0Z01L04adW01TQ;00I82X06B0X01PO9P0H
82<06QlR028R9@0Y:R`0:2T[00X<400]<C@0Ri2C02X`=00E7B009bhd00lG7@0G82D06B8Y028Y<`17
CUP0:S4k02H]=@0202<Z<P0D01`S:@0F7B<05QhR020X:`0N9RT05alS01PQ9P0I8RT05b0X01@M9P0D
72T05Qh[01DM:00G7bX05QlW01<L8`0F7b@051dQ018J7@0D71l201HN8@0;01DM800C6ah04aXP01DL
8P0F7BH05QdW01LN:00@62402a@K014J7`0C7B000P0=5aP06P0:51<08R`[038l?P0W<3@03QLL018K
8P063AD031<K01/R:P0G7R@06B0V010G7@0I8B@05AdP01PP8P0I8B<04QXL00hF6@0B6B404QTS01DL
9P0C6R8082L_024X;P0D6b405A`R0P0G7b802@0E7B0051`O00/@4`0K82<051TL00P=400N8bH0318B
01@J6P0201XP7P0^00L=2@0:40`04QPD018F5`0A5AH05ATJ01HJ6`0@51<04ADD01LL600F6aL05a`H
01HK5@0A5Q003A8<01`R800>51801P`:00X@3P0L8R0051XH00lE4`0<4Q003A<A00L=2`0@5Q@03A<A
024W9@0C6AL03Q@B00`B400F71X0318@00D;2@0A5aD07B<Q014G5@0G7A/08BLU038d<`0F61L00040
01TK6P0K7A`0418A014C4P804Q@C00T04A<B010B4@0?4A005QPG018D4`0@4Q403a4@014C4P0B51<0
1@0A4a802@0A4a004A<?010B3@0D5Q404Q@?010B3@0C5A0061XE00h@2`02014C3P03018D3`092`H0
4A<@00804A<@00H0418?00lA3P0B51404aDB014C400B514201@F4`0I014C3`0=3`X01`T400T;1P0C
5A006Q`G01<E400>40/04A<>01HH4`0A4`h03Q0;00lA300B50l05aTD018D3`0J71L0;BlZ01<E400;
3@P08bDP00T;1P0A4`h03Q0;00d?2@0201XM5P09010C300C5Pl04aH?014D3@0@4``03Q4:00d@2@08
2`@02Pd60080414<00D04A8=01<D3`0D5A004Q<>00d>2@0200`=200900l@2`0@4@`04A8=018D4@0;
3@X05ALD00X<2@092`P04A<@00D03a4>00<03a4=00h?2@0>3`T00P0?40X2010A2`0=018C3@0A4P`0
3a0:00d>200>3`T03a0:00h?2P0@4@`03a0;00h?2P0?40/04Q<>00l@2`02014B3@0300h?2P0=3PT0
3@h900803@d;0`0>3P`01`0?3`d071`J00h>300;2`T03@d;00T91`0D51800P0A4Pd06`0>40/03@l:
010B3@0B5a403Q<=01hS7@083`P010/400lD3`0I81P04Q@<00@500092P803Pl901<D3P0M7QP04a@?
00P81P0;2`T0410>01HF500_;bd05QDA01dL600D4`l04A0<01DD4003014@300H018A3@0A40`03Pd9
00d<200`;b/03@`801lN6P0C4Ph03Pd901LF4P0?3PX02@P400/:1P0<2`L03`h:01@C3`040`005QDA
010?2`0<2`L06QTE01@C3`0?3PX03Pd90`0=30P900l>2P<040l;02H03`h:00h=2@0>3@T03`h:010?
2`0A40`06QTE018A3@061@403`h:01DD400A40`03@`8010?2`0:2@D04a8>01/J5P0>3@T03@`801@C
3`0>3@T06APD024P700920@03@d;014A3`0@40h03Ph<010@3P0=3@/06ATG00L71@0L71X03`l=01<C
4@0<30X01`L500`<2P802`/901@030`:03lo?@1?Cdd07alM00`<2P1ADDl0;Bd[00H70`0;30L030d7
00h?2P0?40/04A8=01PH5P0M7A/04a<B01<C4`0E5AD071`L010@40D03@d;00H03Ph<00/;2@0>3P`0
3Ph<00`<2P0=3@/2014A3`0500`<2P0B4Q003`l=020P7P0B4Q00100=3@/200h>300<00d=2`092@L0
3`l=00h>300;2`T05ADC00h>300C4a4030`:00/;2@0?3`d03Ph<1P0=3@/0200B4Q008b<Q01lO7@0;
2`T051@B02PX9P1aLG403@d=0P0:2PX0:@051@D02PX:02h^;P1FEUH010@4014A4@0;2`/0;bl_02HX
9`082PT04A<B00T92@0A3a0081hO00`:2`0=2@X04@d>018>3`0C3a004a4@010?3@0I61H06aXH00D4
0P0E518040l=00d<2P0>3@/040l=00/:200<2`T04A0<014@2`0A40`03`h:00d<200=30X03Pd;00l>
300?3@h03P`=00803`d>00T0518E00L52P0K6A`02PP;018@4`0M6a`03`d>014?400A40h00P0@3`d0
3`0@3`/02`/600l@2`0>3`X04A4?01@D4P0=3@/02`/;010@400:2P`03@d?00/;3@0:2P`03Ph>00l?
3`0200l?4@0800h>400=3@l03Ph@00h>400L71h05QHH030`<00;2`/300l?4@@03Ph@0P0?3a406`0=
3@l03Ph@018B500B4Q804A4A010@400?3`l04A4B018B500C4aD03`lB018A5P0=31401`H<01@C6@0@
3a@03PdB01dL8@0K6Ql03PdB01HE6P0?3Q<040lD01DD6@0>3A804Q4F00/:3`0Dooooo`006oooool0
3`0=3PP02P/600X;1P0<3@P03@h:00`<2P0B4Q000`<2014A4@020P803`l?01DE5@0@41803`hA00h<
3`0200l;300800l;2P0C4A804a4C018A5P0=3Q<03a8I00011P0@3a4200l=3P09010>3`0B41404a4B
018@4@0E4a@03`d>00h<3@0C4A80518E008030/A0P0?3Q@00`0;2Q006aXP01HE6`02010?5@0F00d<
4P0>3A<04Q4F00d=3P0>3Ph04a<C014A4@0=3@d03Ph>00d=3@0O7al0000000l?3`0:2PX04A8D00X;
3`0A4QH071dQ00T:3P0:2`l05aPL00l@50804Q<G00P0414E018C5`0>3a<04ADH01@H6`0C5aX041@G
018F6@804aLJ01805ATL01<G6P0A5AP051PK01@H6P0?4a@05a/L00lC500=4A806AdN00dA4P0B5QL0
=c/l01TM7P0A5AH01`/<01<G6@0E6A`301@H6`0301HJ7@0G6ah061`O00806AdP00P05a/N01DI700A
51/051LN01LJ8@0>4AH01@P=01TL8@804aLJ100F6Q/01P0G6Ql05APM01HI7P0A51T061/P01`O9080
5APM00L05QTN01PK800I724071lT01TN8@0H7B005a`O00806AhR00<05a`P01@I7`0H72@00P0K7bP0
1@0I7BH05QXS01HM9@0B6B407RD]00805ahV00<06B0X01PO9`0H7bL00`0I82P00`0I82H0620R01TQ
8P0201TQ8`806R8T00<05QhQ01TQ900H82<00P0G7R@0100I82H0620S01/S9@0L92H201/S9P0401`T
9`1=E5X09bhf01XQ:@809Rde03@06R<Z01TT9`0K9RX062<Y01TS;00J8Rd05QhY01PN:P0H7bT061lW
01TN9@0H7B4061dP01HG6`0H6Ad05QLK01dP9@0D5a`09R/_01PN90032Q006b@[00LA5`0?6R002QDK
00P@6P0S:S@09Rdg034h@00N9Bd07B@/01LN900D6b404aXO01TQ900J8RD05b0T01PQ9P0I8RT05b0X
01@M9P0D72T05Qh[00hF8@0C6bH05AhV00`E700A6Ql051`Q01@K8@0E7B005QhQ0P0E7Al06`0A6A/0
3aLJ014H7P0F7BH061lY01HL:00D72@06b@[01lX;@0I8bH051hO01<M7P0D7Qd05R0O018L7P0M9bX0
82T^018K8P0A620041LO01PO9`0A61h051/Q01<J800K8bH051`O014I6`0201HN800;01@L7P0A61h0
41LO01<J8P0?5Qh061lW01HM8`0>5QT04QXM01LO8P0D71h00P0A6A/07@0@5AP08bP[018G6P0@5QH0
5A/K01XP800220H0:Bl]00X@3@0@5Q804aTE04A:AP0D61T03Q8B014E500D61L041@C00hC3`0E6QH0
2Pl:01@I4`0G71H03Q<=01<H4P0E6aT0318@01DK6@0B61H010X800802Q0>01P02@l=014G5@0=4a40
51XH01DK6@0A5aD041HD00T?3@0630X05adK00X@3P0<4Q004aTG00dC4@0:40h041HD00T?3@0=3`h0
5ALF02@V9@0:30/05aTH00h@3`0A4a82018D4`05014C4P0@4Q403a4@01@H5`0?4a800P0<40l00`0@
51<04aLF00hB4@0400hB4@0300hC3`0>40`03a4<00804Q@?00@0418=01<E400E5a805aTD0P0D5Q40
0`0K7AP03Q0;018D4@02014C400>010B3`0?4@h04A<@010B3`0>40d03a4>010B3`0?4@h03Q0<02`^
:@0;3@P05QPC010B3@0:30L200h@2`0C010B3@0E5a80418=00h@2`0<3PT02P`701DG4P0>40/07R0K
01/M600B50l0828M075cKP0S9B004A<>01DG4P0E61807B8K01`Q6P0200lD3@0=010E3P0=4P/020d6
00/@2@0A5Pl04QL@01DJ4`0=3`X03a4<014C3P0@4Pd03a4<010B3@02018D3`0:010B3@0>40/03Q0;
00d?2P0B50l02`d800X<1`082PD061XE014C3PH03a4<0`0?40X3010A2`0=01HG4@0C50h03a0:00`=
1`0=3PP0414;00l@2`0@4@`03a0;00d>2@0>3`X0414<00l@2`02018C3P0300h?2P0<3@P03Pl:0080
30h;0P0=3``200h@3@0T00`>2`0B51403Q0=01@F4`082PL04a<A010A300B4@d03a0;00h?2P0@4Pd0
51HA00L9100:3`T0314;00hC3@052@@051TB010B2`0<3@D03Pl700l@2P0K71H0:b`V00l@2`061P@0
5aLE01@D4P0C4a407QhL014@300G5Q8040l;00h=2@0B4@d03`h:0`0B4@d05`0@3`/03@`800`;1`0;
2PP040l;028Q7@0B4@d02PT501DD400c<Rh05aHB01@C3`0:2@D010<000/:1P0A40`07A`H00l>2P0C
4Ph0<2l[01/J5P0?3PX03Pd900803@`800<03Pd9010?2`0B4@d00`0A40`2018A3@@03`h:100>3@T0
5P0?3PX040l;014@300L6aL05aHB00`;1`0B4@d05QDA010?2`0>3PX04a@?00L80`082@@030d800X;
1P0?40/04A8=00/<1`0310003a0;01TJ5@0<30X2014A3`80410>00L030`:00d=2`051@<061PF00h>
300?3`d03Ph<00806ATG00d03Ph<014A3`0@40h06QXH018B400H61H05ADC028R800<30X02PX7014C
3P0B5@h0418=00803Q0;00L04A<@010B3`0210<00@<200/=300B51<02@/:00D03`l=00`03Ph<00/;
2@0=3@/03@d;00`<2P0=3@/03`l=00H70P0@4@`020T400`=200L7AP200d>2@80414<00H03@h900`=
200@4@`03Ph<00l?3@0>3P`200`<2P0300l?3@0=3@/0410>008030`:0P0?3`d300d=2`<03Ph<02l0
3`l=01hN700J6QP020P601@D4P0Y:BL0E5AD00410@0;2`/02PX:00l?3`0S8b<06a/K00410@0820P0
61PH00X:2P2UYJD0DE=B000100092`X051HE00D51@00000061HG010>3`0?3@h03PX;00l;300D4Q40
8R4O0450?P0D4a402PT701PG5@0>3@/03@`:00h=2`0?3P`02`X800d<2P0A40`040l:010?2`0?3PX0
3Pd900h=2`0200l>308040h?00X03`d>00h<3@0@3Q400@0401HD5`0610L06QPK01PF5`0>30d03`d>
0`0?3P`0400?3PX04A4=00`=200;30L06AXE01`M600?3`d04A4?01HF500B4Q805QHF01<C4`0A4A<0
410@00l?3@0?3`l200h>400700d<4@0:2@h02@P=00L72@061PH02`/;01DE5@03010@4P0600l?4@0>
3Q003Ph@00l?4@0@41804A4C0P0?3a404`0B4Q@0410@00l?3`0=3@d030`<00l?400@41804a<E00l?
4P0A41D05A@I010?5@0510X03a0D00d>4P0?41@03PlC00d>4P0C51P00P0A4QH0100>3a<010D900h?
4`0>3a<Dooooo`006oooool09P0=3PP02``600X;1P0=3PT03Pl;00d=2`0@40h03Ph=01HF5P071`L0
3Ph>01LG5`0>3Q003`h@00h<3@0@30d03``<00d;300920X0414F00/@5P0P:34021@O00P@6@0?3a40
3`d>010>3`0E4a@06QPI01`J6`0<2P/05aDF01@B4`0A3a004Q0A018@4`0H5ad03PdD0P0?3QD0500=
31<03PdD00d<4`0A41L03`hE018A600D4aX040lD010@4@0B4Q803Ph>00l?3`0B4Q804A4A00l?3`0=
3@d04Q8B01@D500:2PX04Q<E0P0A4QH08`0L7B4051DI00X;3`0@4AD02@X>010A5@0D5AT0414E01DF
6P0@4aH04ADE01DI6`0B5QL03Q8B014E5`0C5aP051PH01DI6`0B5QL041@D01@H6P0H71d03a<D018F
5`0Y;Bh02`l@01DI6P0H71d041@E01HJ6`0?4a@06alP01<G600E6A/05ATL008051PK00<05ATL01LK
7P0E6A`00P0E6A`02@0F6Qd05a/N01TM800G6R404aHM01LJ8@0P8bP06A`Q014D6@0201@H6`0801DI
6P0F6Q/05QXK01LK700G6Ql041<H01XM8P0@4aP201LJ7`0301/N8`0I72405QTN008051LL00@05APM
01LL7`0G71l05a`O0`0G72001P0E6Ql05a`R01TN9@0J7RL06AdV01LK90806B0X00@08BP`01TP:00K
8RX07bH^0P0I82P301PO9`0801PO9@0I8R806B8P01TR800I8R806B8S01TQ8`0G7b8201TQ900<01LN
900H7bD06B4T01TQ900I8B<0620R01PP8`0K8bD06b<V01XR9P0G7RD061lV0P0K8RX0<P0F7b@06B@V
01/V:@0H8bL06B<Z01XR;00F7RP06R0[01XO:P0J7bP06QlV01XO8`0I7R807b0U01lQ9`0E61h07b<X
01HL8@0R:S404QXQ00hH800;5ah0B5EL014O9`0?72@04QXT018I8`0?5R007bH^020W;`0Y<3P05ahT
01PO9@0F7R8051`O01DM800E7R805AlT01LQ:00F82P04adV01<L:00F7b/051dX01@M9`0O:C405b4X
00hH7@0D72405A/Q0P0D6ah201@K701P01<J6`0@5aT04APK01PN9@0I7bT05AXV010H8P0C7B@04Q`Q
00hH700B7Ad04ahO018M6`0?6QP041/M01HP8`0E7b<05AlV01`T:`0@61l04QXR00lG7@0A6Ah05AdS
010I6`0?61/03aPJ014J6`0C71h05QlQ01@K8@0A62005A`T010G7P0E72804aXO00dE600C6ah06b<U
01HN800B6Q`04a/M01lU9P0:3Pl092T[07MmO@0U:b/04QLF01XP7P0oAD<04QPD014G4P0F71L05A/F
02HZ:@0F6QT03a<B018F5@0C61D05AXF01DJ5@0@5A004AH@010E3P0=4P/041D?00hD400B6QL01@/8
00dD4P0C6aP0318@01HM6`0<51405QhK00lG500<4a403A@B010H5@0=5A8051`I00`D4@0>5Q<04ATF
010H5@0?5Q<041PE018J5`0=51803aDC01/O7P1hNWT03a4@01TK6P082@P07b4P100D5QD00`0B51<0
4A<B00lC4P0300lC4P03010D4`0A5A@03a<B00@03a<B00@03a@@00h@300?4@`04A<>100B50l01P0F
61<06A/F00d?2P0@4Pd03a4<014C4080418?00D04Q@A01<E4P0D5Q<04Q@A014C4002018D4@0R010B
3`0=3`/06adH00L9100C5A003a4<03Xl=`0P8Qd03Q0;00lA300B50l03a4<00h@2`0A4`h03Q0;01@F
4@0;3@P06adH00@60P0<3PX04Q@?0412?@0F61<01`T401PJ5@0>4P`051TB01DJ4`0>4``0314:00dB
2`0>4``041D>00lD3@802@h700/04aPA00`>2@0?4@`04Q@?00h@2`0=3`X0418=00/=200@4Pd04A<>
00h@2`02010B3@0600X<1`0D5Q404aD@00L9100^<2/030h91P0>40/00`0@4@/0414:010A2P03010A
2P804A8;00L0414:00l@2@0@4@X04A8<010A300A4Pd03a0;00803@h900L03a0;010A300?40/0414<
018C3P0A4Pd03a0;00804A<@02@0418?00lA3P0>40d03Q0=03@f<`1QHf007R0M00`>2`0@4Pl02@T7
010?2`0C40d04Q0<014>2`0A4@`04a@?01<C3P0=3`X01`/500lB3@0>4P`07B0I01HG400D5@d04a@<
00d>200@4@/05aPB010A300A4@l03Ph<00l?3@0@40h03`l=00d<200A40`200d<2003010?2`0>3@T0
4A0<00804A0<00/040l;00l>2P0?3PX030/801XI5@081`D040l;01TH500?3PX07QdI00h=2@0201LF
4P0<01dL600`;b/04A0<00d<200<2`L04a8>01PG4`0<2`P03`h:00h=2@0=30P03Pd90`0?3PX00`0>
3@T03`h:010?2`02014@308040l;00L03`h:00h=2@0>3@T040l;014@300@3`/03`h:00<03Pd900l0
61LC020O6`0H5a<02`X600`;1`0?3`/04Q<>00l@2`0C50l03Pl:018C3`0@4@`03a0;018C3P0C50l0
0P0?40/06`0=3@/0410>00h>300=3@/04A4?018B400C4a40410>00`<2P0=3@/03`l=014A3`0:2PP0
4Q8@00`<2P0@40h04A4?00/;2@0>3Pd04A4?00`<2P0B4Q003Ph<018B3`0A4`h04A@=010B3@0200d?
2P0700lA3P0C5A803a0>01XL6`0620L03Q0?01<E500300l?3@803Ph<00<03@d;00/;2@0=3@/0100>
3P`0500<3@P051D@00d>2@0A4Pd03a0;010A300C50l05aPC01DF4@0>3`X030d8014B3@0@40h051@B
00l?3@0<30X03Ph<00/;2@092@L03@d;0P0B4Q001@0>3P`030`:00d=2`0=3@/03Ph<00803`l=00D0
410>00h>30071`D030`:014A3`0200l?3@0E00h>3P0B4Q804a<C00X:2P0>3Ph02`/;00h>3P0C4a<0
3`l?00/;2`0?3`l06ATI01hP7`0J7A`041<B00T;2P0F5QH0410@01DD500?3@h040h?00803``=00L0
40h>01`K6@0h=cD03`h<01LF500@3`d04A0>008040l=00D04Q4?00l>300A40h04a8>00l>2@0300l>
2P04010?3@0>3@/030/900l=3P<04@l@00P03Pd?02<Q9P0>30l040hA00h<3`0<2P/040h?00d;3080
3Pd;00h03`h<00l>2P0B4Pd03Pl9018C3P092PL01@H300h?2`0;2`T04Q8@00h>3P0C4a<0410@00`<
3@80414=00/03`l>00h>400?3a403`hC01lN8`0R8BH03Ph@00h>3P0<30X04A4>010@4002010@4P80
3`lA00@03Ph@00d=3`0?3a40410B0P0?3a400`0A4A<0410@014A4@0201<C4`0:018B4`0@41804Q8D
014A500<2a0051<H01lN900C4QP03PlC00l@50802@X>00P03a0D00h?4`0>3a<051DI02l`=00S92P0
3a0D00`=4ACooooo000Kooooo`0J00h?2@0<3@L02``700d>2@0>3`/03@d;00/;2@0<30/00P82018B
4P0C4a<010@400d=3`0>3@h040h?018>3@0@3@d03@d?00D62P0J7bH0DU]T0:Jd`@1<GFd03adZ00l?
4P0?3@h200h<3@0@00l=3P0@3Pl0518C020N7`0L6Q/04a4B010>3`0?3A002PT@00d<500D4a/04A0H
010?5`0510`04Q4I01<B6P804A0H00H040lG00d<4P0D51D0410@00/;2`0=3@d2018B4P0H01XJ6P1?
Cdl030`<00d=3@0U9BD030`?01PI7@0A4QH05QLK01`M8@0E5QX07b0T014B5P0B4aL04a@H00`=4@0B
4aL04ADF01@H5`0G6aX05ATH01<G5P0D61L05ATH0P0B5QD201<G5P0901@H5`0C5aL04ADF014E5P0m
@D804aLH018F5`0<41404QHG008041@E01@04ADF00dA4P0J7R007b<V01`P8`0H71l05QXM01DI700J
7R4061`O01<G6P0A5AP04QHI01HJ7@0G6R404aHM014D6`0V:Bh0=cXo01/N8`805QXM00@05ATJ01@H
6@0E6AX05QXK0P0G6Ql0100K7R<051LL01HI7P0B5AX301<F6`0A01@G700E61d05QTN01DJ7@0F6ah0
5a`O01DJ7@0E6Qh05a`P01/P900J7b@061dS01TM9P0K7bP07B4Z01LN9P0@5al00P0D6b<00`0]=3`0
>d9:01LN9P0301LN9P0;01PO9`0H7bD06R<R01XS800I8Ql06B8Q01TQ8P0H82805alR01XR9@0I8B@0
0P0H7bD0200J8RD0620R01HN800E7Al05alQ01TQ900H82<06b<V0P0R:Bl03@0@5al04aXR01LP9@0I
92D06RDW01LR900I8RP06B8[01DN9`0J8B/06alZ01/O:00J7bD00P0J7b<0A00D5ah08RD/028W;@0B
61l0DEYQ0<3;d@0P;3@06RL_01XY<01aPXX02Q/S02Le?P0T;3D09Rdg01LN:00F7BD04aXR01LN9P0J
8BL06B0V01TP9@0C6ah04QXM01@M8@0F8BD06B@Z01TT:`0F82T05Al[01<M:@0I8bd07RPb024[<`0H
8bT041/O014I7P0C61h04aPL018G6P0C6AT051XH01DK6P0F71`05a`O01TN9@0I7BP05QXV01<K9@0B
7B<04ahR01PS9P0C7al041`L01@P7P0:5Q@02QDG01<N8@0H8bL092le0419D00S;3<05AhU01<L8@0A
6Ql051dR00dG6@0C7Al051hO0P0<5QL06P0@6Q/06B0V018I8@0E72@04APN01@K8@0C6ah051`O01PP
8`0K8bD05AdO014I6`0?5aT08bTY01DK6`0A5aL0<SPh01`R8P0I7ad051XH010F500A5a<020l800T@
2@0:4@X0720O0P0E6AP0:00F6QT041@B00`A3@0:3`T041D?014F400B5a004aPA00XA2P083PX041TF
014J5`0B6aP02Q<@04=<B@0]=S<02a@A00hG500=5Q<04a`I020Y9P10BDH03AHC010I5P0B6aP02a@A
00XC401BFeP0?4E2051IEP0E7Q/05b0M01lU8`0>4Q40?Cln00H81`0S9B@05ALF01@F5@0A4a82018D
4`05014C4P0@4Q403a4@00`@3`0?4a800P0A5A@00`0>4Q40310?010D4`04010D4`0>010E4@0?4@d0
4A<>010B3@0B50l04aD@010B3@0J71L092HQ03Dg<P0N81/04A<>01DG4P0@4Pl200lA3P05014C400E
5a@05ALD01<E4P0B51400P0D5Q<0200B51405ALC00X<1`0E5a805aTD01/M601LGUT0:bdX0P0>40/0
400@4Pd03Q0;00h@2`0A4`h0418=00d?2P0A4`h05QPC00D70P0F61<04Q@?00L9100C5A003a4<01`N
6@0=4@/200/@2@0>00`A2P0=4P/03A8;00`A2P0?50d03A8;00lD3@0Q9Ql0@TM000lA300@4Pd04A<>
010B3@0>40/200lA308061XE00T0418=018D3`0@4Pd05ALB00L9100<3PT03@l:00L9100A4`h01@0=
3`X0100=40X04A8:014B2P0A4PX3010A2@0300`=1@0=3PH04A8:00804a@<00X04Q<;00l@2`0@4@`0
3a0;00d>2@0>3`X0414<00d>2@0<3@P03@h90P0@4@`03P0=3PT02P`900/=2P0<3P/03@l<00lA3P0@
4Pl02P`901`N6`000@001PP501@F4`0F5Q@040`90P0C3``05@0B3P/04`l<01<B3P0920@05QDA00l@
2`0E5Q404A<>00H90P0>3`P03a08014B2P0B4`d03a0:00d>200>3`X05QHD00@40P0F5Q@03@d;00h>
3003010?2`<04A0<01<040l;00l>2P0?3PX040l;014@300B4@d051<?00`;1`071P8051<?014@300?
3PX05A@@010?2`0D4`l02@P500P70`0F5A4040l;00804A0<00@020L300X91@0C4Ph03Pd90P0=30P0
1@0>3@T03`h:00l>2P0?3PX040l;00@04Q4=00<04A0<010?2`0@3`/00P0@3`/0?00?3PX03Pd900h=
2@0?3PX040l;014@300B4@d04a8>018A3@0<2`L03`h:018A3@0C4`h04Q<>00`=200:2`H01`P302<T
7`0?40/05QLB02PY901GF5<0@D8m01`M600B4Q004a<A00l?3@0=3@/051@B01PH5P0B4Q006ATG00L7
1@0D5180410>00P81P0E5A<06ATG00/;2@0=3@/03Ph<00d=2`030`403@d;01DE4`092@L02PX800T:
1P0=3`X03a8;010B3@0=3`X030h900h@3@0?4@h04aDC00H81`0F61L05ALF00L920803`l=00@03Ph<
00d=2`0<30X030`:0P0=3@/04@0?3`d04A4?010@3P0<30X05QLB00@50P061`803@h9010A300D5A00
2``700l@2`0@4@`03@h900h?2P0B4`h03Ph<0080410>00D03@d;00/;2@0<30X030`:010@3P0201XJ
6003010@3P0=3@/03@d;00803Ph<0`0@40h02`0;2`T03@d;014A3`0=3@/02`/900l?3@0?3`l02@T9
010@400<30`04a<C00805ADE00d05QHF00L71`0@41002`/;00h@3`0C5QD01@T800X>3@0B51<03`l?
0000000;2`/030X;008040h?00l03@/<00l=3@0>3@/030/900L6100D4a402`X8018A3`0=30X03Pd;
014@3P0=30X040l=018A3@0?3PT00`0?3PX0;@0?3P`03@`:00/:200=2``040h?014?400B41408R0S
08B2Q`0f=3L05A<F00T72P0?3@h02@L800l=3P0?3P`03Pd;00d<2P0=30P030`701<D3P0<3@P01PL2
03@e<00[;2L07AdK024Q7`0J6QX06a/K01HF5P0A4A003a0;00l@2P0>3P/03Ph>010@4P0C4QL0TI2E
07YiOP0U9BH0000000h?2P0@4@`03`l?00l?4@0200h>40803@d?01802`/=00d=3`0?3a403Ph@00d=
3`0?3a40410@014A4@0E5AD05QHF01<C500@41802`/=018B5@0?3Q<040lD01<B600<2a4200l@500:
00`=4@0>3a<0414E00/<400C51P03a0D02`]<@0R8bL030dA010A5ACooooo000Kooooo`0[010A2`0=
3PP02``700d>2@0>3P/030`:00h>300<30/01PH601DE5@0C4a<01`L7014?400C4A8051<A01HB4@0D
4A40410B00`=4@0I82L0Lh290?7oo`2dbM`0<dEC010A500@3Pl03`d>00h<3@0<2P/02`T:01/I6P0T
8R<07A/L014?400@3Pl04@lB01PG7P0@3aL03@`D00X94@0R8BT08B0X01<B6P02010?5`0M00h=5@0=
31@040lE01<C500@410051@D01HF5P0C4a<04A4A02<S8`21PH4030`<01HF5P18B4P04Q<F01HI7P0=
41D04aHK01DH7@0M82D0>Se201LJ7`0?4QL04QDJ00lB5`0B5AX04ADF014G4`0B61@00`0C6AD05P0D
6QH04QPD010F4P0D6QH061hJ01DK5`0@5QD04QPH00hD500T:RX0318B02<Y:@0<4Q8051XJ00L=3@0G
7Ad07bDU01HL700J7b007B4T01XN8@0G6ah201HJ7@0301TM800H71l05QXM008051PK00X05ATL024T
:`0A51/071lV06EXK@26RHh04aHK01PL7`0G6ah05ATJ0P0C5aP00`0D61T061/P01hQ9P0301HI7P05
01@G700B5AX04aHK01DH7@0F6Ah00P0G6Ql00`0E6Qd05adM01TN8@0201HK7P0301PM8@0K82@06b0U
00806QlU00X0724W01dR:00T:c<06R4Y01LN9P0A62006b8Z01TP:00E72@05QdU0P0G7RH0100I82P0
6B0V01XS8P0J8al201TR7`0501PQ7`0H8B00620R01XR900J8RD00P0H7bD01P0J8RD0620R01HO7`0G
7b406B4S01XR9@805alR00`051/Q01HM8`0K8RP092/a02@^<00K9RH07RPY01/U9`0K92X072<]01TP
:P0H7bT201XN9`0[01TN900H7B4061dQ02@W;`0T9c0061`U01PN9`0H8BX0=3i701LR;00?7BH04B8Z
041AF`0:72H05bP`01`T;P0L8bd06R4[020W;`0K8RX07bH^01/R:00C6R0051`P014I700C6ah05AlR
01HQ9@0J9B/06RD/01LQ:P0F82`04adY01DO:@0^>4806B<[00XE6`0I92P03aLL01<H7P0B5a/04aPK
01@J6P0201HL6P0/01LM7@0I7R406QhV01TM:00J7RX05alY00hI7`0?6Qh04A`O00@@400;5aL0520N
00dI5`0L9bT02aHI00093@0g@TP0GfQ_03<l@`0E7RD04AXO010I7P0F7b@04A/M01@N800A6a`03ALH
018L7@0B71h06R4W014H7P0C6R003A@J00hE6`0>5QT041PK014I700B6Q`04ATK00lG6@0>5aH00082
018H600N92@2010F500;00dC4@0K8Ad04QPD014G4`032P<041L@01LN5`0?4a803Q8A018F5@0B5a<0
0P0<4@d00`0W;2H041D?00`A2`0201<H4@0>018I4P0F71P01Pl<018K600D7AX06B8O09nXY@1AFUL0
7bPU01DN6`0>5a@01@h;00TB3`0`>CH200XC400@00dF4`0<5A80214>04M@C@0Y<Rl0:c@a00081@0;
51402a4?020T8`082PT0;2h]00d?3P0L7Qd020X9014C4P804Q@C00@04A<B010B4@0?4A003Q<A0`0>
518200`B40D03Q@B01<03a@@014C3`0C5A00418=018D3`0C5A003a4<00`>2@0F61<07b4L014C3P0=
3`X02`d801@F4`0A4a00418?014C400C5A804A<@00803Q0=0P0A4a006`0?4@h03@l;00X<1`0B50l0
3@l:00/=200H6QD0418=00h@2`0=3`X03a4<00d?2P0>40/03a4<014C3P092`H06Q`G018D3`0=3`X0
3Q0;00/=200L7QT051HA00T;1P0:30L04aH@018I4@0200/B2P0900hE3@0?5Ph03aH>010G3`063@D0
0`X200`C2`0G7QH041D?00803a@>00l041D?00lD3P0<4@/04aPB01hS7@0K81X03Q<=00lD3P0;40X0
6A`E0085000I71D092LP00D80@0E61401P0=40T3018C2`03014B2P0@4@T0414900<0414900X04A8:
018C2`0C50`03Pl:010A300?40/03Pl:00l@2`0B4`h03@h90P0C50l01`0>3`X03@h9014B3@0:30T0
2@h:00X?2`0;40`00P0>4`l05@0<4@d03Q<?01@I5@0G71P0314=00/;2@0?2`P04`h;01@?300C3P/0
4`l<01@@3@0;1`@04A0<00/:1P0B4@d04Q<>018C3@0>3`P04A8:018C2`0201<D3P09018C3@0=3PT0
4A4?01HF500b<S004A4?01PH5P0?3PX03Pd900803`h:0P0>3@T0300B4@d040l;00l>2P0?3PX040l;
014@300E51003Pd9010?2`0A40`02`X600T810803Pd900X04A0<00l>2P0>3@T04Q4=00P7100<2`L0
5A@B004000071P804a8>0`0=30P02@0>3@T03`h:00l>2P0@3`/04a8>01LF4P0F5A4051<?018A3@03
014@30804Q4=01d040l;00h=2@0>3@T03`h:010?2`0A40`04a8>014@300;2PH020L301<B3P0D4`l0
3`l;00`=200720<04A8=02<T7`1MGUT06AXE014B3@10@C`0j>WT0<c=b00[;2T04Q8@01@D4P0?3`d0
3@d;014A3`0201<C4@0M028R80092@L05ADC00h>300=3@/02`/900P81P051@@06a/I01`L6P0>3P`0
0P8001@D4P0@40h020P602PX9P0@40d04Q@?014F3`0@5@l0314;00T>20083@T01P/704Y>C00M8B00
10P700T=300D5QD00P0A4@l0100?3`d03Ph<00d=2`0<30X200h>300H010@3P0C4a404Q8@00`<2P0:
2`H05AHB01hO6@082@<030d700l@2P0:2`D030d700d>200>3`T0414;010A300@40h03Ph<01DE4`0C
4a4030`:01<C4@0@40h03`l=0P0H61H00`0?3`d03Ph<00d=2`0200h>300?010@3P0A4@l04A4?00T9
1`0>3P`0410>00T91`0<30X05QHD01<C4`0<30`05QHF00T92@051@D03@d=00802PX:01d04Q8B02TY
:@020P802P`;00@71P0=4A0051PG00L9200A4a806adL014A4@0>3Ph0410@00d;30091`P03`d=01@C
4@0A40h05aHD00l>300B4@l02PT700`;2@0?3P`04Q4?00h=2`0@3`d04Q4=00l>2@0300l>2P<03`h<
0P0>30d0100?3@h040h?00T82P0c<CH200X82`0S00h<3`0H5QL03`d>014?400@3`d03`h<00d<2P0<
2`L04A4<00/<1P092P@05aPC04M8@`0a<Rd04A4?01DE4`0=3@/03`l?00`<300:2PT03Pl:00d>200=
3PX03`l?014A4`0E51X08b8X02DT:@0?3a001PH401@E400A4P`03Ph>00h>400=3@l00`0<30h01P0;
2`d03Ph@014A4`0@41803`lA010@4P803`l?0P0>3Ph0100?3a003`lA00/;3@0A41@201<B5`0901<B
600B4AL04Q<G00/?4P0=4A@03Q8E00`@4`0:3Q405ATL00802PhA00<010P;00`@4`0@51L05?ooool0
01_ooooo01T03a0:00d=2@0<30T03Ph;00l?3@0<30/03`l>00h>3P0@414030`=00/;300<30d03`dA
018A4`0=3@`03@`=014@4@0>3Pl05QHI010C5`0[<CH0H6Y`05aXL00D7B804Q8A00804Q4>01L04A0>
00l>3P0?3Ph03@`=00d<3P0C4aH03PdA01dN8@0?41<03@`B01@C6P0F5A/040lE01@C600>3A<051<I
01HF6P0C4QH03`hB014@500C4QH04A8C01<D5@0201`L7@0Y014B4@0C51<03a0@01LH5P0B4a403Pl=
018C4@0>40l04A@E00h?4@0E5QX051HK01hP9P0c=3d05aPQ00hA6@0B5A/051LL01@H700?4a@04QLG
01@F5`0@51<04QLE010E4`0E6QP051XG01PN6P0F7AT06B4L01<K5@0C5aD05aTK01TK7@0A5aL0;C<c
09VPX00Y<C405QhM00hD500B61P00P0E5aT07P0G6ad04ALJ02P^<@0O92D0<STj01@J6`0F6ad041PF
01LM700I7Qd04aXI01XO7`0H7Ad06b0Q01TN7`0Q9RL0;S<d01<H600G71`05a`K01HK6P0C61P061dK
01HK6P0J7R406b8U01@J7@0H72005adP01@H70805ATM00`061`O01XM8@0H71h061`O01DJ7@0H7B40
6QlS01HM800E71l05adQ01TP8`0J8RD201`T:00;01XR9P0K92P05b0V01TS:00K9BX06B<X01/U:`0F
7R806R8X01PQ9@0H82@00P0G7R<03`0J8RD06R<R01XS8@0K92807RHW01`T9@0F7al05alQ01/S9@0I
8B@0620S01/R9P0H82<06B4S01XR900201/S9@0501TQ900G7b807bL[018I7`0F7B<00P0J8BP0FP0E
7R<0524R01HS8`0G8bD05R0S01HP9@0I8bT0620V01<K8P0@6Ad05AdQ01/R9@0D71l06R4U028Z;P0F
7R805AhS01@O900K9R/0520W01@R:@0B82L05bH^01l_=P0F92`09Bhg01TQ:P0G8BX0624Y014I800C
7B<07RL]01`T:P0H8BD05B0R01HO8P0J9BP04ahS01DP9P0G8BP04adU01DO:00F7bT0624[02lg?`0D
72D02A4H01HN900P:Bh041TK00lH6P0A6Q`04AXK01HO800C71d05QlS01TR:00G7RL05QhX01dT<00O
:3804QdS014L800C7B003APH028];00]>CL03aXI00lI6@0B6ad04ATM01`T:00g?d<07BHZ01HN8P0K
8bP051`R014I7`0F7R<04AXM00lH6P0D7Ad05b0N01`V900F7Ad041LG01@K700D6Qd051/N01LN8@80
3A@G00L03aHH01<J6`0E71/05A`J01DJ6P0>51403a@B008041DB00P051TF01<I5@0D6QH051XF00lE
3`0J81/0318=014E50804aLF02P03Q8@014F4`0B5a<0>Slj01XO6P0@5@l04aPA00lD3@0C61802@l;
00lE4P0<4a005Q/H00lF4`0J8Qh07R<P00lF4P0>5Q8051TF01<I5P0D71P03Q@A010G500C6QL03A<@
01<I5P0>5A805Q/H00`C3`0<51005adJ01PN6`0?5A803Q<@018F4`0;3P`03Q8?014E4P0C5Q@041@A
0P0D5aD02@0B5Q<04ADB014F4`0@5Q@0318@00T?3@0=4a40318@01DK6@0500hD4P0400dC4@0A5A40
4aHB010D3`804AD@00T03a8>010C3`0C5a804QDA010D3`0F6AD04aHB01DH500^<Rd00P0<40/00`0B
5A403a8>010C3`02014D400j018F4@0A51003A0;01PL5P0@4`d06ahH02DY8`0;3PP04QH@00lC3@0=
4@/03Q4;00d@2P0>4P`041@>01@H4P0?4P`071lI018E3`0C5Q0041@>00H91@0D5a402@d701@H4P0@
50h0=CXc02hd;00X;RH03Q@<018H4@0A5`l04AL@00hD3@0<4P/041H?018H40093`P041@>018F400:
3PL05ATC014E3P0>4P/0310:018F400B5Pl020`6010D3@0G6aD05AL@00/=1P0e=c00B4Y401XL5@0A
4``03@l800h@2@<0418;00h03a4:00h?200@4@X04Q<<010A2P0?40T04A8;01<D3@0B4``03a0900d>
1`0@4@X04a@>00h@2@80418<00/03Q0:00lA2`0B50h04Q@>020R700E5a4030h8014C3@0B50h061XF
014D400200lB3P0800hA3@0?4Ph030l;00hB3@0A5A003Q4=00d@300?4@d2014?3@0>01@B400A3``0
3Pd:018B3`0<30T04Q8?018C3`0E5A80:B/W010B3@0@4@/04A8=010A2`0>3`T200l@2P07018C3P0:
2`L05aLD02l_;00Q8Qh0;BhY014A3002010@2`803@d800P0410;00l?2P0@40/04A4<00l?2P0=3@P0
3`l:014A2`804Q8=01804A4<018B3@0<30L03@d:018B3`0>3P/07alL00/;200=3@X03Ph:01PH4`0_
;b/05aLB01HF4@0:2PL04Q8=00h>2P0A4@`2010@300300l?2P0>3PT0410;00804A4=00P0410;00l?
2`0?3`/0410;010@300?3`X0410;014A30<03`l:01P03Ph900d=200A4@`0410;00T91`0D50l03Ph9
01`L5`0<3@P04Q<=01@E3`0B4`d030d8024R7@0;30H04A8=02d^:@2>ShX0OGii02//9`0=3P/03Pl<
00d>2P0;30P200`=2P0D01PI5@0P8Ad03a0<01HG4`0D5A806Q/G010A3P0A4Q003a0=00h?3@092PP0
30d;00d>2`0?40d04Q<@00L81P0<3@/04A8@00d?2P0=40X200lA300P00hA300@4`l051DA010C3`0?
4`h030d;00`?2`0<3PX09bLT034b;P0>3P/04A8>00`=2@0@4@d03Pl;00h>2`0?40`04A4>010A3@0=
3PT030d8059CCP0f=c403a0:00h?2P0A4Pd030d800h?2@0=3PP03Pl:010A300>3`X2010A3`0=01TJ
600F5a@03Pl=01PI5`0?40h030d;010A3P0A4Q003a0=010A3P0=3P/02``800l@300200l@3@0>00h?
300<3@T01`P5010A3@0=3PX05AHB00l@3@0C4a802`/:00`<2`0B4Q403@d<00`<2`0>3Pd2010@3`0K
00h>3@0E5A@02PX9010B400?40h030d<00/<2`0A4Q000P<100h>3@0?3`h03Ph=010?3P0@3`l03`h=
00h>300<2`T03`l=00X:200G5Q@02PX800d=2`0<2`T061LE00/;2@0<2`T08b<P00803Ph901h03Ph:
00d=200A4@h03@d:014A3@0@40`0410=00l?300>3@`03Pd=00l>3`0@3a407QdN01<B4@0>3@d040l>
010?3`0?3P`04A0>00d=2`0=30T04A0;00/9100C4@/030X400h>2@0B4@`03@`9010?300>3P/2018B
4@0=01<C4@0@40d03`l<00d>2`0>3Pd0410A01@D5P0?3a404a8E018B4P0;2`T030`9010@3@0200l?
3P0600h>3@0>3Pl03@d>00d=3P0>3Pl0410A0P0B4Q@06P0@4180410C018B4P0?3`l0410@00h>3P0@
41404a<E018B500A41@03`hC00h=4P0?3Q@051<I018B5`0<3Q403A0C014A5@0>3a<03A0C00/;3`0?
41@03a8E00h>4`0C51P020/>5?ooool001_ooooo00h030d800`=2@0;2`T03@d;00l?3P0>3Ph03@d=
00P82@0A4A<03Ph@018A5@0>3A806aXO01dM80804a<E00T05QHG00P8200;2`/02`/:00l?3@0E5A<0
4a@?010A300B3`X00P0?3PT0IP0?3PX03@d;00d=2`0>3Q003a0D00X;3`0?41D0000500lB5`0A41H0
40lD00l>4`0@3a@0410B014A4`0G5aT07alO01DE5@0@410051@D014A4@0O82@0>S/m018C5@0E5QP0
10H501XL6`0>40l04A<@00lA3P0C5A805ALB018D3`0?40/03Ph>01<C5P0H5ad061PR01DE800B4Q`0
41<L010C6@0@4aP04AHI014E5`0O82@071dO018C5@0F5aT04QHE018G5@0Q9bD0?TA001hU8@0?61<0
41XB01TL6P0=3@l071dO018F5`0C71/0I6e/01`V9@0C7A`051XJ01@G600F5aT061PJ018D5`0V;S00
4a/M00H>400K92<04Q/J01LP7`0@6AH05QlK018K5P0@6A@0624L00hD400@5Q804QPD01DK5`0G7AT0
6AlK018H500@5Q802a4=00hD400G7AT06R0M00P@4P0=5AP051`O01@L7P0E7Al03ADG01PM800E6Qd0
61hN01XN7`805QXK0P0H7B40300F6al041PK01DM800L92L0628T01DO8@0H8R@062<U01HQ8`0I92H0
6RP[01@R9@8062HY00/062DW02D`<P0I8bD05R0R01PR8`0H8280620Q01lX9`0K8bD06B4S01/S9@02
01lW:@0801PP8P0F7R006B4S01DM7`0F7R0072@V01XR900H828201/S9@0601TQ8`0G7b405alR01dT
:P0K8RP08bX`0P0J8BT04`0I8RL052<U01LU9P0H9RL04b4R01LR900M:2X062<U00/E5`0`>S`04Q`N
010J700E7b403a/K018N7P0S;bl07BTY00XE5`0<5aT00`0B7B401P0D7bD05b8X01TT:P0I8b`0628[
01LQ:P<05b8X03/062<W01dX;00G8RD062<U01LR900O:Rh07BP^01PS:@0J92/06R<Z01TR:@0E7BD0
3QDM018I8@0C6B405ATR02/_>01MIFT07b/[01HR8P0G8b@051lQ01PS9`0A724041XS00lI8`0?6B@0
41XV018L:00B72H02QDK00hI7`0N:2X051hO00PB4@0A6aT05QlL018K6P0D6a`05Q/N01lT:00b>S`0
7bLY014I700C6R003aHL010G7`0i@4H09Rha01LP8@0D7A`041TF01DN6@0F71P04aTE01DK6@0F6ah0
4QLJ018G6`0200lD600I014F600A5aL04QPF01<I5@0H7AT05Q/G014F4P0;40`02Pl;00lD400F6aL0
2a0<018G4`0A5Q8041DA018G4`0?4a804aLF01@H5`0<40l05AXG014F4P0@5A404AHA014F4002018G
4@03018G400@5A4041DA00@041DA01H07B8N00dB3P0B5a<05a`H010E4@0?51004QLC014F4P0@5A40
2Pl;01@I5@0?51004QLC00lD400A5Q803Q<?00P=2@0;40`04AHB018G4`0=4Ph03Q<?1P0A5Q80200>
4`l0314=00dC4@0J81h05Q`J018H5P0F71X020h<0P0>518200lE4`0400hD4P0=4a4041DA010E4@80
3a@@0`0>4`l300lD40803Q<?01@020d801XO6@0:3`T0724K01@I4`0>4`d04QLA01<H4P0@5@l04QLA
014F400?50h06AhG00X?200H7AH082DN00T>1`0>4``03a@=00hC30803A8;00<03Q<<010E3P0@5@h0
100@5@h06P0>4``0314:00`A2P0;40T0314:00dB2`0?50d02Pl803Hk=00H7AH00@H000D:0`0B5a00
3Q<<00lD3@0C614041D>00dB2`0<3`P05QTB018E3P0L7aP051L@00lB2`0E61404QD>0`0A50d02@0K
7QL04A8<01PI4`0D5@l06AXD00`=1`0B4`d03a0:00h?2@0200l@2P06010A2`0A4P`03a0:010A2`0B
4`d0414;0P0?40X00`0=3PP03Pl900h?2@0200/<1P0B00d>200;3PL03A0900d@2@0;3PL030l800d@
2@0?4P/06A`E00`?200930D04aH?00`?200D5Q403@l:00lA300B50l0418=0P0A4`h04@0B50l03a4<
00d?2P0?4@`04Q@?00@60`092`P02`d:018D4@0=3`d02`d:01HH5@0D5Q<01`T600/=2P0b=3402P`9
00803a0;0P0@4@`00`0?40/03Pl:010A3005014B3@<0414;01X04A8<01@E3`0G6180414;01<D3P0G
61804Q<=00d>200@4@/04A8:00h?1`0A4PX0414;00d>200@4@/03a0;00L71@0H61H0Ti>A01PH5P0@
40h04a@?00L80`0H6A@04a@?00T:1@803Pl:00H01`P300X;1P0@4@`02@X500h?2P0@4@`300l@2`0F
010A300A4Pd0414<00l@2`0A4Pd0414<00l@2`0?40X03@h800h?2@0?40X0414;014B300;30H030d7
02TZ9025QX006Q/E00@5000<3@P04Q<=01PI4`805QLA00@04Q<=00`=1`0>3`T03@h80P0N7aT02P0B
4`d03@l:00d?2P0<3PT03@l:00h@2`0?4@`04Q@?010B3@0>40/2010B3@0400d?2P0?4@h03Q0=00d?
308030h;0`0=3``01@0>40d02`d:00/=2P0>40d03a0;00803Pl:01003@h900h?2P0?40/04A8=00h?
2P0?40/03Pl:00`=200?40/02P/602LX8`051P404A8=00d>2@0@4@`03Pl:0P0=3PT02`0>3`X0414<
014B3@092PD0?Chi014B3@0>3`X05QLB00<4000:2`H03Pl:008030d800P04A8=00h?2P0<3P/03Q0=
01@F4`0@4Pl02`d:018D4@803Q0=00H03@l<00h@3@0?4@h03a4>00d?2P0:30L2018D3`0L00d?2P0:
30L05ALB00H80`0?4@`02P`701LI50092`H04Q8@014A3`0;2`T03@d;00X:200<30X04a<A00d=2`07
1`D06QXH00/;2@0410803Ph<01DE4`0D518030`:00H6100J6QP0410>018B40<03Ph<01<03`l=014A
3`0@40h0410>00l?3@0=3@/030`:014A3`04108010@300<30@0U9B<0Ngah02DV8@000@0051D@00D6
0@0=3PT04a@?00803@h900D0414<018C3P0A4Pd0414=00l?3@0200d=2`0>00l?3@0B4Q004a<A00d=
2`0<30X0410>00/;2@0:2PP040h:01<>200D3`T04Pl8014>1`0A3PT200l>2P04018A3@0B4Q004Q8@
018B40<03Ph<00T03`l=010@3P0A4@l03`l=014A3`0B4Q003Ph<00d=2`0>3P`00P0A4Pd0100A4@l0
410>00l?3@0?3`l200h>3P80410B00l03`lA00h=4@0F5QP03Ph>014A4@0=3@d04A4B01@D5P0:2P`0
410C01@C600C4QL03`hC00`;4@0B4AH00P0A41D01@0C4QL051<H018A5P0A41D040lD00804a8G00<0
3`hC010?5?ooool04oooool001_ooooo01H030d800d=2P0<30X02`/900`<2`0?3`l04A4A00P82@0B
4Q@03@d?00`;3`0:2@h020L<00d<400>3Q005aLI01lO800B4Q802PX:00d=300>3P`03@d;0P0=3PT0
100A3PT03`h900l>2@0>3@T200d=2`1A00P82P0?41@01`P<01TJ7`0110T07B0U014@5P0@3a@03`hC
010?500@41804A4C01DE5`0L71`051@D014A4@0D51@04a<C071aM@31`/@0;2d_01@E5`0;3@`04Q@C
010B4@0B51403a4>010B3`0@4Pd03a0;00h?2P0>3Ph04Q4E01HE6`0F5R0051@N018B700?4Q/03a8H
010C600@5AP05APK02@U:@0O828051DG01LH6P0E6AP061dL05AJF02DVYH0F5mK028[9P0H8QX06QhL
00/;3@0N7b405ATJ00XC4P0@6AP05AlN01<M700D6QX051PI01HG6@0H61X05aXM01HN8@0C6ah07BDW
00/C5@0I8B804a`K014J6@0E7Q`02a@A014J5`0B6aP061hL01DK6@0D6QP02Q0>008041HD01D04QPF
01@J600B61H06R0N01HL6P0B61L09Rh`01XR9@0F7R40=cm104M?D@0K8bD05AXM01<H6`0F6ah05adM
01<I6@0B61P0;34e02X_<`0T:Bd00P0J8RD0100N9RT072HX01<M7`0E7b4201LR900>01TT9P0J:2/0
3a`R01PU:`0H9RT04alR02D`<P0G8B<05AlQ01PR8`0H82806B4S020X:P0K8bD201PP8P0301`T9P0O
9bT072@V00805alQ01@04QXL01<K7@0K8bD072@V01LO8@0I8B<0620R01HN800G7b806B4T01`S:@0N
9B/09bhd01hU;@0K8RX05b0U01TV:00M:b`062HW01HT9@806RDW00d02A@F01@N800jA4H06B4T01DM
800G8B<07BTY010L700C7al05B4Q00`G6@0R;Bl04ahR00804QdQ00H051lU01DP9P0F8BL05b4Z01DO
:00D7RL201@O9@0@01DP9P0B7B405B0T01DP8`0I92H07BPZ01HQ9@0I92X041/Q014K8@0F7bH03aPO
01LO9P0F7BD03aHN00lD7@802`lH02T0<c/o018N7P074a<031LH00lJ700A720041/P010K8@0=5b00
4Q`U01HP:P0A6bL0;SQ202lj@00B7B<04adO01/U9P0H8R406R<Q01PQ7P0C71/05A`M01HK7P0M8RH0
=Cdo020X:P0?5aX04aXP018I7`0A6200<STo01lW:P0@6AX04a`K014J5`0@6A@051XF014G4`0D6QP0
5AXM014F6@03014F6P0@014G600A5aL04ALE014G4`0F6aL05AXF014F4P0?510051TE01lT800G71P0
3Q<?01@I5@0C61@04QLC01<H50804ADD00P04QHE00`@3`0F6QP051TE010E4@0A5Q404AH@018G4@80
4aPA00`04aPD018G4`0A5Q803a@@00hC3`0=4Ph05Q/G00D:1P0A5Q804QLC01<H500A5Q8200`A3@0>
01@I5@0F6aL0;34]034f<P0=4Ph04QLC01LL600D6AD04QLC01TN6P0B5a<05Q/G01<H500?5102010E
4@0<01<H500>4`l03a@@01<H500?51002Pl;018H5P032@L0>3hl00X>30093`d06b4O0P0>518200lE
4`0300hD4P0=4a4041DA00<03a@@0P0>4`l00`0?51003Q<?00dB3P0200hC3`0700lD400B5a404AH@
010E3`19CTP0Ada601@I4`02018G4@0;010E3`0A5Q0041D?018G400I7QL02@h700dB2`0C61401P/4
00dB2`0>4``00P0=4P/00`0>4``03a@=010E3P03010E3P803a@=00`03Q<<00lD3@0A5Pl03a@=00/@
2@0<4@X051TB00/@2@0B5a0041D>01@I4P0H7AH2010E3P0N01<H4@0D6A803Q<<00`A2P072P<03a8;
01@G400B5@h04A@=00lB2`0D5a003a8;00/>1`0B5@h02`h7018E3P082@<061TC00/<1P061`403Pl9
00l@2P0A4P`0414;00h?2@0=3PP03a0:018C3@0D5@l04Q<=0`0@4@/02P0?40X03Pl9014B300D5@l0
4Q<=00l@2P0>3`T03A09010C300?4P/200hA2P0O010C300=40T03a8;00`?200>4@X04A@=00d@2@0<
3PT02@/600lA300B50l0418=014C3P0<3PT04A<>018D3`0>40/03a4<01HH4`0>40d051HC00X<2@0L
7Q/0;c4^03<e<P0C5A801@L400d?300H6QL04A<@0043000200l@2`80414<00<03a0;00h?2P0A4Pd0
0`0B4`h0600?40/03Pl:00l@2P0;30H02P/500`=1`0=3PP030d701<D3P0E5Q0061TC018C3@0=3PP0
3a0:00l@200;30@03@h600h?2@0@4@/051D?010A300>3P`030`:03@d<P8030`:00d01`P300d>2@0=
3PT01PL201lP6`0C50l01PL201LH4`0>3`X05AHA00/<1`0C50l03a0;00<03Pl:00<03a0;010A300@
4@`00`0?40/06@0>3`X03@h900d>200=3PP03a0:01<D3P0E5Q005QLA010A2`0B4`d0Ce1:00d>2007
20804a@>01XK5@0F5a402``600h?2@0?40X03Pl901@E3`0<3@L03@h800`=1`0A4P`00P0>40/01P0=
3`X03Q0;00h@2`0@4Pd04A<>00lA30<03@l:00D02P`700lA3P0>40d03Q0=00`>2`0200d?300700`>
2`0=3``03@l<00/=2P0:30T03@l<00l@2`0200h?2P0500d>2@0>3`X03a0;014B3@0=3PT00P0?40/0
5P0<3@P0414<0001000A4Pd02P/6014B3@0=3PT02``700l@2`0>3`X030d800d>2@0B4`h05AHA00X;
1P0G61<02@X500`=200@4@`02``700d>2@0@4@`200d>2@0:010A300=3PT03Q0=00d?300@4Pl03a4>
00`>2`0>40d0418?00lA3P@03@l<00`03Q0;00`>2@0F61<04aD@00d?2P0;3@P02@/6018D3`0G6A@0
10H300h@2`0:30L2014A3`0C00h>300=3@/04a<A00d=2`051@<06ATG01/K6@1@D4h0410>014A3`0:
2PP0000000@40P0M7A/00P80010@3P0?3`d0410>00d=2`0200h>300F00`<2P0:2PP030`:018B400=
3@/03Ph<018B400G5aD04a<A01XJ600?3`d020P602DU8P051P4010D001HG4P0=3PT03a0;00d>2@0?
40/030d800/<1`8030d801D03Ph;00h>300<30X030`:00h>300A4@l05ADC014A3`0?3`d04Q8@00l?
3@0=3@/04@l:01D@2P0F4@/05A8=01@A300B3`X03`h:010?2`0@4@`00P0@40h0100?3`d02`/900`<
2P0?3`d2018B4007014A3`0=3@/03`l=014A3`0?3`d03Ph<00l?3@02014B3@06014A3`0@40h0410>
00l?3`0=3@d03Ph>0`0?3a406@0>3Q406QXL00h>3P0<30`02PX:014A4P0C4aD03@d?00l?4P0B4AH0
4a8G010?5@0;2Q0040lD00h=4P0?3Q<04A0E018A5P0?3Q<05A@I014@5@0B4AH04A0E00h=4P0A41D0
5?ooool001_ooooo01H0414<00h>2`0>3P`030`:00X:2@0@41003`l?00d=3P0E5AL03@d?00d<400?
3Q<04Q4F014@500:2P`02`/=01<C500D51@03`l?00d=300=3@/03`l=0P0>3`X0100C40/04A0;010?
2P0@3`/200l?3@0@014A4`0B4aL051DI00X;4010@dP0BTeB014@5P0@3a@03`hC010?500@41804A4C
01@D5P0H61P04a<C010@408051@D00@0>S/o0821P`0C51H03PlA0P0C5A@0FP0A4a804A<@00h@3@0D
5Q<06adH01HG4`0A4@l04A4A01<B5P0E51X05AHL01DE7P0B4Q/03Q4H00lB600A51T041DH01@G6`0Q
8RH06a`N01<D5P0G61X05a/J03Dj>02W[J/0noom0:jf/@13C4L08B/S01DJ5`0F5aT061TK00dB4`0J
82004a`K018K6P0?61L04ALG018G600E5aT05aPJ01HJ7P0C6Ql04QTN01/R9`0=5AP0620R01<K7@0F
7al07RLW014J6P0K92804QXJ01TO800<4Q404AHG01@I6`0E6aX051XJ01@J6`0B61L04ALG01TN800B
61L05a`N010E600A61/03aHI01hT9`0^=CL04QTK014F6@0@5AP05Q/O01TN8P0F71d05Q/N01LL800H
7B806QlT01LO8`0D72004ATM01lY;00G8B@06R@W01hY;00M:2/06RDY01HS:@806BH/00l05bDY01LT
9`0I92L072HX01XT9P0J92D05alQ01@L7P0H82805QhP01DM800H82806R8U01/S9P0I8B<00P0H82<2
01HN8@805alR0P0I8B<01`0G7b405QhP01XR900O9bX06B0V01/R:00Q:2h00P0J8BT0F@0E7R<062DW
01`Z:`0D8R<05B8S01PS9@0B7Al05b8T02H_<P0=5QT05AdP01/S9P0H82<03aXK01PS900F8B80<cho
01LQ8`0D7R00628V01HP900F82D0628Y01LQ9`0E7bD0628[01XT;@0L9Bh06R@[01LQ:00E7bH04Q`P
01@N8P0F8B@05b4S01/U9`0?6Qd06RDZ01TT:@0H8RP072D[01HO9@0C6b407bH]01/R:@0B61l06AhU
01DI8@0K8bH072LV01DP8@0F8B8051lQ01<M8P0F82D04adT014J8`0D7RL0624/01LP:`0f?dT0>dI<
01hY;`0@6Q`04adN01HP7`0I8R004a`I010I600B6AX041DH01DJ7P0I8B<04a/M01@L7`0H7bD05A`R
014H800B6Al03ADH00lG600E7Qd04a`I014J5@0D6QH04ALC01@J600F6ah04QLJ00<04aPL00@04QLI
014G5`0@5Q@041HB0`0A5Q804P0B5a<05a`H020U8@0H7AT04AHB01DJ5P0@5A404AHB00lD400D61L0
4ADD01DI600>4Q404QLD00hC3`0E6QH051TD018G4@804AH@00D04QL@018G4`0A5Q804AHB010E4@02
00lD4004014F4P0B5a<04aPD00/@30804AHB01405Q/G010E4@0@5A402Pl;010E4@0?51008RLS01XO
6`0?51002a0<00hC3`0C61@05a`H00lD400H7AT04QLC00X?2`0300lD4008010E4@0A5Q804QLC018G
4`0A5aD09B/Y08jDTP0h?S`400hD4P803aDC00<03Q@B00dC4@0?51001@0?5100300@5A403A8>00`A
3@0=4Ph03a@@010E4@0B5a402a0:00`A2`0Z;bT0:BhX00hC3@803a@>0P0>4`d01`0=4P`03A8;014F
3`0>4``04AH?018G400;40T01@0>4``0100?50d041D>010E3P0@5@h300lD3@0500hC300C61405a`E
01<H4@0=4P/00P0?50d0400@5@h0314:010E3P0G71D08BHO010E3P0<4@X03Q<<00dB2`0:3`P03a@=
00d@2@0<3`P03a8;00T<1@0?4P/2010C300;01@G400<3`P041<<010C300B5@h04a@>00h?2@0@4@/0
4Q<=00d>200@4@/00`0B4`d3014B300J01@E3`0?40X030d700l@2P0A4P`03a0:00h?2@0A4P`05QLA
01@E3`0@4@/03Pl900d@2@0@4``03a8;00d@2@0>4@X03a8;01<F3`0=40T04A@=01DH4@0A50d03a8;
00lA300;3@P300h@2`0;01@F4@0@4Pd030h9014C3P0B50l03Q0;00d?2P0>40d0418?00/=2P0=3``0
0P0S9B801P0A4a002@/803<e<P19BdP03Q0=014C40803a0;0P0@4@`0;@0?40/03Pl:010A300B4`h0
4a@?014B3@0>3`X030d8014B300>3`T030d701DF400H6A<051D?00l@2P0A4P`04a@>00l@2P0<3@L0
3a0:00h?1`0?40P03Pl700d>200?40X04A8<014B3P0=3@/05QHD00d=300E5A<03`l=014B3@0B4`h0
3a0;00d>2@0^;bX05aPC01@E4@11@Sd061TD01LH4`082@H03a0;010A300300l@2`09010A300B4`h0
6Q/F01/L5`0B4`h03@h900l@2`0@4@/03a0:00803Pl900<04A8<01<D3P0H6A<00P0?40X03`0H6A<0
30d701`M5`0@4@/02P/701`M5`0V9b404A8<00l@2P0>3`T05QLA014B300B4`d03Pl9014B300200h@
2`0;00d?2P0<3PT03@l:00h@2`0:30L02`d800`>2@0>40/03a4<010B3@0?4@h00P0>40d0100=3``0
3Q0=00lA3P0>40d200lA3P8030h;00P03a4>00l@2`0>3`X03Pl:00d>2@0>3`X03a0;01@E4080414<
00/03Pl:00X;1P0=3PT05QLB00`=200A4Pd03@h900l@2`0>3`X04Q<>00l@2`0200/<1`0400h?2P0B
4`h030d8014B3@804a@?00T01`P3014B3@0@4@`04Q<>00h?2P0=3PT0414<00`=200A4a000P0=3``0
100?4@h0418?00/=2P0>40d300d?30803Q0=00`03Q0;00T;1P0C5A003@l:00X<1`0>40/03a4<00/=
200<3PX02P`701@F4@0@4Pd2010@3P0?018B400=3@/06a/I00d=2`0>3P`0410>00P81`0P81h01@D3
00l?3@0K6aT03@d;014A3`0820H02`/900@030`:00/03`l=018B400A4@l03@d;01<C4@0J6QP03`l=
00h>300A4@l04Q8@00l?3@02010@3P0D00`<2P0?3`d04A8=01TJ5@0;30P03@h901TJ5@0A4Pd03@h9
00/<1`0>3`X05AHA01XK5P0E5A803Ph<010@3P0A4@l03Ph<00/;2@0=3@/200h>3009018B400D5180
4A4?014?2P0D40X05Q8<01DB3@0C40/04@l:008040l;00D03a0<00l?3@0>3P`030d<014A3`04010@
3P07014A3`0?3`d03`l=00h>300<30X03Ph<01<C4@0200l@2`<03`l=0`0?3`l01@0@41804A4C014A
4`0B4AD06ATK00<03@d=00T0410A00h>400F5QP03`hB00`;400?3Q<04Q4G014@5P0@3a@00P0?3Q<0
2@0A41D04Q4F010?500A41D040lD01@C600E51T040lD014@5@0Dooooo`006oooool06@0H6A@03@h:
00l?3@0?3`d02`/:010@400:2PX03@d>00`<3P051@L03PdA00@320071P/02`/>00/;3@0<30h07alP
03@d=00>3Ph02`/:00d=2`0C4a40414<00`=200?30L00P0=30L0RP0>3@T03@d;00d=2`0@418010D9
00d>4P0E5Q/01@P=00P;400A41H040lD00l>4`0@3a@0410B014A4`0D51H04a<C014A4@0@41004Q8B
01@D500@4AD06Q/M00h?4@0@4A<03a4@00X<2`0@4Q40418?00d?300D5Q<07AlJ01PI5P0C4a4051@D
01<C500C4QL051DJ01LH7@0D51`03a8I014D6P0C5Q/041DH010C5P0I6Qh05AHH018C5@0D5AL051PG
02<X9`1PIV@0X:JR06M^JP0W<2/06R@L01dR7`0C51H01PX;01HK6`0<4Q806b4Q00XC4P0@6AP04aTI
01DJ6`0G6a`06AXL01<H700941P061lV01LN900K8RP03QHJ00lG6P0A6A`07BDX01DM7`0G7b404ATK
01DJ7@0G71l03a@G01HK7P0>4aH02@hA01<H6`0?51L08BHY01XO8P0E6Qd04AHI00P=400G71l06b0S
00lD5`0D6A`05Q/N01XO8`0I7R807R<W020U:@0K82@06AhR01hS:@0K82H05a`R01PO9@0N9B/082L]
01XS:00F7b@072DZ01hY;@0I92P05R4U010M8`0P;C<05R<Y01@Q9`0L:2d03aXN01XT9P0H8R@06B<U
01PP8P0C6ad05alQ01<K7P0F7R40620S01TQ900G7b805AdP01TQ900H82<06b<V01XR9@805AdP0P0J
8R@0100H82805alQ01/S9@0O9bX201XQ9`1M01`S:@0G7RH07B@/01PQ9P0C8280528S018P8@0C7R00
4A`N00dH6P0=5aT03ADH02/c=P0J8RD03aLJ01dU:00A6a`04Q`M02Pb<`0A6a`02A<E01`V:00J8bP0
5b0U01TR9`0L9B`06B8Y01HO9P0H8BX072D^01hW<00M9Rd0624X01DN9@0F7b@0624V01PQ9@0B71h0
5b4S01LQ900<5a/04QdQ01@N8`0@6Ah05QlT01PP9P0H7bD03QDK01PN900731803a@J00lG6@0F81l0
5AlP01<M7P0=5aP02A<E01DN900H8BP0624Z01<K9@0@62<04a/V018K9@0E82H07RT_01`W:@0?6AX0
218A00hG5@0B6aP041TH018I6P0@5AP04aPL010H6P0B6Q`04a/N00lF700>5A/04QTQ01DL8P0C6ah0
4ATJ00hG5P0?61D051dH01<I5@0A5a<051XH01HK7P0C61/051TM00804QLK00h04QLI014G5`0@5Q@0
41HB018G4`0D6AD05AXF014F4P0@5A404QLC01DJ5P0A5Q805AXF018G4`806AhJ00X05ATH00dA400D
61L041@C01<G5@0@5A405a`H01DJ5@0A5Q0041D?0P0A5Pl0:P0>4`l03a@@010E4@0@5A404AHB018G
4`0C61@02@h:00dB3P0J7a/03A8>01LL600;40`02Pl;01LL600D6AD06AhJ01PM6@12Ad<0;c@`01LL
600C61@05AXF018G4`0>4`l02a0<01<H500@5A402a0<010E4@0B5a<051TE018G4`0<4@d03Q<?018G
4`0F71X051XH02/a;`083P`061hL00dC4@803Q@B0P0?5A<00`0>51803A<A00hC3`0300lD40<041DA
00h03a@@00hC3`0?51003a@@010E4@0C61806QlI018G4@072`H03A8<018G4@0@5@l03a@>014F4080
3Q<=00<04AH@00hC300<4@X00P0;40T00`0=4P/03Q<<00lD3@0200lD3@0400hC300=4P/03Q<<010E
3P803a@=0`0=4P/04@0?50d04AH?00lD3@0;40T0314:014F3`0=4P/041D>00H;100H7AH07B8K00dB
2`0<4@X02Pl800`A2P0=4P/051TB00803a8;01804A@=018E3P0>4@X03Q4:01PK500<3`P04QD>01@G
400H6a@03a8;01DF400A4P`0414;00P90`0C50h03a0:010A2`0A4P`201@E3`05018C3@0?40X04A8<
010A2`0>3`T00`0?40X02@0@4@/04Q<=01<D3P0@4@/03a0:010A2`0<3`P03a8;00hA2P0200d@2@05
00lB2`0B5@h03Q4:00lB2`0@4``00P0=40T0600?4@`02`d800`>2@0=3`X0418=01/M600[;BP04A<>
00P:1@0<3PT02P`700d?2P0K7AX03a4>01<E4P0A4a002P`9018D4@072@H03a4>00D7100G6AH03a4>
00P:1`803a0;0P0@4@`0100?40/03Pl:00l@2`0@4@`2014B3@0W00h?2P0=3PT04a@>014B300:2`D0
3Pl9014B300:2`D03Pl900l@2P0C50h0414;00l@2P0C50h0414901@E3@0@4@T030d700d>200<3@L0
5AHC00d=2`00000010@2018B400E5A<02P/600d>2@0F5a801PL2010A300:2`L04a@?02HW8P092PD0
6a`G00/<1`082@H0414<00<03a0;00X0414<014B3@0L7AP07b0K014B3@0=3PT0414<014B300@4@/0
3Pl90P0=3PP03@0>3`T0414;010A2`051P002``900/<1P0<3@L05aPB0001000K71H0=3D_01DF400?
40X00P0A4P`0100720803a0:014B300A4P`200d?2P0300`>2@0;3@P02`d8008030h900H03@l:00lA
300>40/03Q0;010B3@0?4@h300h@3@0500lA3P0@4Pl03a4>010B3`0A4a000P0>40d0200A4a003a0;
00h?2P0>3`X03@h900h?2P0?40/05AHA0P0@4@`03P0>3`X02@X500/<1`0?40/020T601<D3`0@4@`0
3a0;00h?2P0B4`h03a0;00/<1`0:2`H02``70P0<3@P01`0@4@`00@800001000B4`h01@H100h?2P0A
4Pd00P0=3PT0200?40/02``700lA3P0>40d02`d:00h@3@0C5A803@l<0P0<3P/0400;3@X03@l<00h@
3@0?4@h03@l:00P:1@0C5A002P`700H80`0>40/02P`7028T7`0L7QT020X500D70P0<3PT200/;2@0A
00`<2P0?3`d04a<A00T91`0E5A<03@d;00T91`092@P0;Bd[03`l>P2OWid020P600l?3@071`D06a/I
00h>300C4a400`0=3@/200h>300400`<2P0A4@l05ADC01<C4@804Q8@01<04a<A01DE4`0C4a403`l=
00T91`051P<000400083000G61<04a@?00d>2@0@4@`030d800/<1`0>3`X04a@?01HG4P0C51003Ph<
008030`:00<03Ph<014A3`0A4@l00P0>3P`01P0E5A<071`J01PH5P0B4@`04Pl8018?2P804@h900`0
3Pd9010?2`0?40/03`l=00h>300=3@/02`d<01LG5@0D5180410>00d=2`0>3P`3010@3P0400d=2`0;
2`T03@d;01@D4P803Pl:0`0?3`d00`0@41004A4A014A4@02014A4`07018B500E51P05aLI00l?3`0D
51@04a<C018B4`0200d=3`06010@4`0E51T05QDJ018A5P0;2Q004A0E0P0?3Q<01@0A41D04Q4F010?
500@3a@04A0E00806QTN00<05A@I01@C6?ooool04oooool001_ooooo01`07QlJ00d=2P0?3`d04a<A
00d=300?3`l03Ph>00h>3`071`T02`/=01hN8@0100D04Q4F014@500>3Q002`/=00l?400G5aL03Ph>
014A400C4a4051@B014B3@0?40/03P/600`;1P0=30L03Pd90P0=3@/0:`0];Bl0:2T]028S9`1<CE80
6QdR01<F6`0A41H040lD00l>4`0@3a@0410B014A4`0D51H04Q8B010@400?3`l0410@01<C4`0:2`l0
824S00l@4P0=3Q005QPG01<E500A4a804A<@00d?300>40d03a4<00l@300B4Q0051@D018B4`0@4180
4Q<G01LH700E5Q/03a8G018E6P0E61d04AHI00hA5@0F5a/00P0D5AL04P0B4aD03a<B014F5@0G7A/0
>3hj02D/:00B6aH04adE01/P7@0B5QL03a<D01XN7`0@5QH05adM01<I6@0D6QX05ATJ01HJ6`805ATJ
01D08BD[00XA6`0mA4d0ADaD03Y1B@0R:C003aHL00XB5@0E7B004QXM00dE600B6Qd00@H:02L/<00B
5a/05AXN01PM8@0I7R805AXN00lD600`=CT00P0L8BD01`0A5QX06AdP01<G6P0A5AP06AhQ020U:00A
5QX00P0G7b807`0L8bT07RD[01PO9@0F7B<08RL]01dR:00E6R004APN01<J800B6Al0624V01HO900I
8RL06B@X01HQ9@0H8bL03Q/Q01LT;00A7RH041dS01HR9`0C7R80624V01LP900I8bD0620S01@L7`0G
7b80620S01TQ900H82<00`0G7b805P0I8B@05QhQ01XR9@0J8RD0620S01`T9`0I8B<06R8T01PP8P0G
7b406B4T01`T9`0I82H06R4W01`S:@0H7bL07RD]01LP9@0D7b804ahP01LR900E8282014K7@0B01/U
9`0H82<0@TY=01TN8P17C500?TI901lY:P0i@d@0FF=T01dW:00B71h072HX01TR9`0F7b@0624V01dV
;@0J8bX05AhU0`0D7BH00`0D7B@04Q/R018K8P0201PQ9P0W01DN8P0A6ad06bDW03I1A00F8BD062<W
01`V:`0E7R<08R/`01`T:@0A61h010/A02H/<P0H7B<07B8X00dE600F81l04adL01HP800H8R<04adO
01/T:00I8RL06R<Z01PQ:@0E7RL05QhY01LP:P0G8RP05R4W014L7P0C7Ah06R@S01XS8@0@6AH041TH
01<J6`0A5QT051TM00804a/M01P041PK00lF700@5ad04QTQ018I7`0@61/03QLH014J6@0D7AX04a`G
018H500?5A404QPF01DJ7@0B5aX04aPL018G6`0A5QX04ALH014G5`0A5aD04ALC010E4@0B5a<301@I
5@0<01LL600F6aL04QLC01DJ5P0A5Q80724M01hS7`0N8R4041@C018F5@0?4a804aPE0P0E6QH01@0C
61<04AH@014F400C61805AXC00803a@@0P0@5A42014F4P0A00X?2`0X;BT02@h:01HK5`0B5a<061dI
01<H500;40`04QLC00X?2`062`L00`P401TN6P0F6aL02a0<00T>2P0?51000P0<4@d03P0T:BD04aPD
00`A3@0C61@03A8>01<H500A5Q803a@@00hC3`0?510041DA010F500=4a405Q`J0P0:40h00`0@5Q@0
3Q@B00hD4P0200lE4`0500hD4P0=4a403Q<?00hC3`0?5100100@5A43014F4P8041DA01802@h801LL
5P083@L020d701XO6@0?50h041D?00hC3@0A5Q003A8<00hC3@0C61803A8;00`A2P0:3`P02a0900lD
3@0>4``3010E3P0400dB2`0;40T03A8;010E3P803a@=00<03A8;00`A2P0<4@X00P0<4@X02@0;40T0
314:00dB2`083@H05a`E04mDC@0N8a`02Pl800/@2@0200dB2`0F00/@2@0?50d041D>018G400<3`P0
4A@=00d@2@0D5a002Pd6020S701<CdP04A@=010C300B5@h04A@=00/>1`0B4`d051D?01TJ500?40X0
7AhH00`=1`<04A8<00T0414;00l@2P0?40X04aH?01@G400C5Pl03a8;00d@2@0<3`P00P0D5a001@0A
50d03Q4:010C300D5a003a8;00804A@=00`03a8;010C300A50d03Q4:010C300<3`P02`h700d@2@0>
4@X03Q0;00d?2P0?4@`200h@2`0C01LI500V:2<03a4<00/=200=3`X02P`7014C3P0E5a802@/601XL
5`0f>3<01PP501<E400E5a806A/F0084000<3PT05ALB00lA300200l@2`80414<00<03a0;00h?2P0?
40/00P0?40/3010A300302<T7P0R8ad05QLA00804Q<=00/030d7014B300A4P`051D?010A2`0>3`T0
4a@>018C2`0E5Ph03Pl700/<1P02010A2`0@00d>2@0?3`d06QXH03`l>P2?Shd071`J018C3P0N7aX0
:R/V00/<1`0O81/04A8=00`=20082@@02``701LH4`80414<00H03a0;00h?2P0>3`X03Pl:00l@2`0=
3PT201<D3`0400/<1`0@4@`0414<00d>2@803a0:0P0>3`T01P0=3PP030d701@E3`0?40X02``601hO
6@803a0:0P0A4P`00`0F5a403@h800`=1`0201<D3P0700T:100C50h051D?018C3@0?4@`03Q0;00d?
2P0300`>2@0600d?2P0?4@`0418=00d?2P0<3PT03Q0;100>40d00`0?4@h04A<@00lA3P02010B3`04
00h@3@0=3``0418?00l@2`803Pl:00T03@h900h?2P0?40/04Q<>00h?2P0?40/03Pl:00/<1`0>3`X0
0P0?40/0200A4Pd0414<00`=200=3PT0414<00l@2`0=3PT030d80P0=3PT0200@4@`030d803Hg<P09
2PD04a@?00`=200=3PT0414<0P0<3@P02P0?40/02``700/=2P0=3``02@/800/=2P0B51403a4>00h@
3@0=3``200/=2P8030h;01l03Q0;00d?2P0L7QT03a4<00L9100>40/03a4<04A6@@0m?cX05aTD00X<
1`0G6A@03@d;00/;2@0:2PP051@B00h>300;2`T04A4?01DE4`0I6AL02PX800h>300C4a40=SHd00X:
200Q8Al03Ph<010@3P0=3@/05QHD00803Ph<01`030`:00h>300@40h0410>00l?3@0<30X05QHD01PH
5P0G5aD02@T7000000071`D05QHD01PH5P0C4a007AhI01HG4P092PD02``700`=200@4@`03Pl:00d>
2@0<3@P02``700P9100<30T03`l=0P0=3@/00`0?3`d04Q8@018B4002010@3P0<01DE4`0N7Q`06ATG
018A300C40/040d800d<200>3@T040l;00h>300?3`d03a0>0P0>40l0100=3`h051@B01<C4@0A4@l2
00l?3@04014A3`0>3P`03`l=010@3P803Ph<00<0410>010A300@4@`00P0A4@l05@0B4Q004Q8B010@
400@41003`lA010@4P0B4Q@05A@H01DE5`0?3`l05ADE014A4@0@41403Ph@00T92`0B4AD061LL01LF
6`0A41D02`X@00h=4P0200d<4@0500l>4`0@3a@03PdB018A5P0A41D00P0F5AX00`0B4AH04a8Goooo
o`0Cooooo`006oooool05P1[K6L051DA00X:200D51802`/:00l?3`0=3@d030`=00`<3P0H61X0:BT/
01@C60081``0410C00h>400G5aT030`=00l?3`0820P04a<B018B400>3P`200l@2`0D014>2@0@3`X0
40l:00l>2P0?3`d04A4?05EEE`1?D5@07QlS01DF6`0>4AH030lD018A5`0F5AX03PdB01LF6`0N7R00
3Ph@01@D5P0@410200l?3`0K010@400B4Q80414E00l@4P0@4A<05QLI010B4@0E5aH03a4@014C400@
4Pl04Q@A01<E400A4Ph04A4@010@400@41404A4B018C500F5aX05aPK018F600C5QX061`P01@I700@
4aL051DI00804a@F02<04Q<E00hB4@0H7A`04ALE01TO6`0J8Qd03AHA018L500=51404aPI01DI6P0>
4Q<04QHG00lD5@0F6a/05AXK01DI6P0D61T04aLH018G600C6Al072<]018I8`0E72@07B@/01LN9P0G
7R@031<I018J7@0H82<04QXM01LO8P0Q9RX0GV=W02H[;`0201DJ7P0i014F6P0E6Qh02PlC01/P900:
3a<06AhR020U:@0D61/05APK01LK7P0G6al05QXN01@I7@0E7B405QhR01XR:@0I8BP05QhU01LN9@0O
8b/0ADYA03e2B@0D6b8082L^01HM900G82H05QlU01LP9P0H8bP06B@Y01`W;@0D8BT04b0X014N9P0D
8BP05R8X024/<@0I8RP05b0U01/T:00I8B@05QhQ01hV:@0J8RH072@X01@K800I82D07B@Y01XR9P0J
8BH05QhR01PP900I8BD06R4V01`T9`0I8B<06R8T00805QhP01806R8T01PP8`0D6b405ahT01/R:00I
82P06R4Y01DN8`0D7R805R4S01hY:`0C7R005QlR010I700B6ad05Q`P01`S9P0S:2`209RMX@0<01DM
7`0C71h07RLY01HO8@0K92L041TL01TQ9`0?5a`0620U01XR:@0I8BP05AdU0P0E7BH0>@0D72H051`T
01<K8`0C6b<05QhS01HN900C6b004Q/N01XS9P0`>cd062<V01<N8@0E7b804adP01PQ9@0A6Qh041LL
034i?@0C6Ah02PlD01@I7P0E71h05R0N018K6@0B71/05AhN014J700D72004QXO01<K8P0H82P06B4[
01LO:@0C72H051lU01<N900@6ad04adN018L6`0A6QP03QLD00dF5@0D6a`05a`O01DJ7P0C6ad03QHH
00lG6P0;4QP051/Q01LN9P0A61h051`O01<L7@0G81l04AXG014J5@02014G4`0301<I5`0E6Qd04QLJ
00804AHJ00L04QLK00dB4`0I7al05A/I01<I5@0D6AD04AHB008041DA01@04QLC020U8@0D6AD04QLC
014F4P0=4Ph04QLC01<H500M8B004aLF018F5@0?4a804QHD01<H500B5a<03a@?01HK5@0?50h0;34[
028W80<041DA01404AHB018G4`0B5a<03A8>03m4@00=4Ph0314=01HK5`0>4`l03a@@00dB3P0F6aL0
3Q<?010E4@0E6QH02@h:01DJ5P0200hC3`08010E4@0=4Ph03a@@02L/:00C61@03A8>01@I5@0;40`2
010E4@803a@@00/03Q<?00lD400<4Q003Q@B00X@3P0?5A<02Q0>00dC4@0D6QP0318@00hD4P0200lE
4`03014G5@0>4`l041DA008041DA00<051TE01PM6@0@5A400`0A5Q801@0@5A403a@@010E3`0:3`T0
4aPB00<04AH@00T041D?00lD3P0@5@l03A8<00`A2`0?50d02Pl800`A2P0?50d00P0A5Pl200lD3@05
018G400@5@h020d600/@2@0>4``00`0?50d200dB2`0<010E3P0>4``01``500hC300;40T04AH?010E
3P083@H07R<L00`@2`0B5a004AH?0P0?50d07@0>4``041D>00hC300<4@X04A@=01@G400>4@X04QD>
00d@2@0V:B80CE19024T7@0_<R/05APA00hA2P0?4P/05QLA018C3@0E5Q003Pl9018C3@0@4@/04Q<=
014B300@4@/03a0:014B300C50h04aH?008051L@00@041<<00`?200;3PL04QD>0P0@4``03`0930D0
41<<00hA2P0<3`P03a8;00d@2@0<3`P03a8;00hA2P0<3`P04QD>00hA2P0;3PL03a8;018E3P02010B
3@0G014C3P0?4@`03@l:00lA300B50l02`d800lA300D5Q402`d8018D3`0<3PP04aD?02X/9P14Ad40
3Q0:00P:100B5@l03A0:020R700Q8ad02`d700lA2`0B4`h00P0C50l01@0A4Pd03@h900/<1`0@4@`0
2P/600<0414<01h03Pl:00h?2@0B4`d02``600/<1`0;30H030d7014B300;30H0414;00l@2P0>3`T0
4Q<=01<D300A4PX03Pl700d>200@4@/04Q<=010A300>3P`04a<A038b<021PGl0:RXX018C3P051P<0
5aPC00`=20092PD200l@2`0500/<1`0B4`h020T400T:1@0@4@`00`0=3PT02@0>3`X03a0;00l@2`0@
4@`03a0;00d>2@0C50l04Q<>00`=200200h?2@0S00l@2P0>3`T03@h800l@2P0<3@L05QLA014B300=
3PP03a0:00`=1`0D5@l03Pl9014B300G61803a0:014B300C50h0414;01DF400C50h03Pl901@F4@0>
40/03a4<010B3@0;3@P03a4<00`>2@0C5A002P`8014C3P092`H03Q0<010B3`0>40d00P0?4@h02@0>
40d03a4>00lA3P0<3P/0<S@a010B3`0;3@X04A<@010A300200l@2`<03Pl:00L03a0;00/<1`0@4@`0
51D@00d>2P0j>cH05aPC00803@h901X03Pl:00d>2@0@4@`030d800l@2`0A4Pd0414<00h?2P0=3PT0
2``701@E401hNG@0@d@o010A3@0D5A003@h900l@2`0<3@P02``700d>2@0<3@P02@/800d?300<3P/0
2P`900d?3080418?02H03a4>00`>2`072@H02`d:010B3`0<3PT04A<>01XL5`0@4Pd03a4<00/=200?
4@`051HA014C3P0?4@`02P`700/=200?3`d030`:00d=2`0E5A<030`:00h>300<30X02PX800`<2P0B
4Q0030`:018B400C4a403Ph<00`<2P0?3`d0410>00X:200B4Q002`/900h>30803@d;00L05aLE01PH
5P0L71X04A4?018B400?3`d0=3@b00805QHD01403Ph<018B400;2`T04a<@01LH4`0:2`H04a@@00/<
1`0=3PT02``700l@2`0n?cX0414=01dN6@0>3`X03a0<010@3P02018B40804A4?01D0410>00d=2`0<
30X04A4?01HF500A4@l03@d:018@300A3`/03`h:010?2`0A4@h02PX800l@3@0:30X06A`L00d@400>
41003@d;00h>300A4@l00P0C4a400`0B4Q003@d;00h>3002014A3`0V010@3P0?3`d05AHA01@E400C
4a404Q8@014A3`0B4Q804A4A00d=3@0>3Q00410B00h>400C4QH051@F00l?3`0@41003@d=00d=3P0<
30h03`lA010@4`0E51T051<H00`;400D4aT030/@01PG701<Be0051<H010?500>3A804A0E010?500A
41D040lD00h=4P0@3a@Dooooo`006oooool0200b<bh0004001<C4@0A4@l09bLV018B4P0:2PX03@d>
0P0=3@l08@0B4AD061LL01TH7@0/;2l0410B01HF60092@X01`L701<C4`0A4A004A4?00l?3@0<3@P0
3@h9010=200?3PT03Pd800d<200>3P`04A4?010@4P0=3Q805AHJ01dN8`0@4aP010L<00l>500:2@h0
30/@024P9@0_;c4071`N018B500200d=3@0Z00l?3`0A4A404A4A00l@500<3@l03a0B01HG6@0F61L0
4aDD00lA400?4@h03Q0=010B3`0B50l06AXG01TI6@0D51@04Q8B01<C4`0C5A@05QPG01XK7@0E6AX0
4QHH01HJ7@0C61`04A@H01<D600A4Q@04Q<E01<D5P0A5A@03A8A010F500F71P04QXE018K5P0Q:b<0
2a8?010F5P0A5AH051PI0P0A5AH201DI6P804aLH01404aTI01@J6P0A5a`000LA01XQ:P0^=Cd0_<?;
01hU;00;4QP04ATL01@L7`0@61/04QXM01DM80093Q80;34e00dB5P0201@I7@0701LL800D6Ad01``@
01PM8@0O92P0PXN;01TM8@0201PI7@0801LJ7@0F6Ah05QTN01DJ7P0F7B<05A`R01@M900E7RD201LP
:@0K01HM9@10A4d0=3Q100hE7@0T:c<05ahV020Y<00O:2l07BH]01`W;@0K9R`06RD[028_=`0N:c<0
3a`T00XG7`0H92/07RT_01HO9P0F7bD0624V01LO8P0F7R4072@W01@K8@0L8bT092/a008051/Q0240
8BP^01/R:00I82H061lU01TP9P0H7bD05AdP01PP8`0I8B<051`N01HN800K8bH05alR01TP9P0L8bT0
61lU01TP:00J8BT05ahT01/U:0064A<02QDG010J700H82<07RHY014I700C61`04QLK00dB5P0O92P0
8RL[018J700F7R000P0I8B<0800G7b805AdP010G7@0L8bT031<I01XQ:@0C6R803aHN018I8`0E72H0
5ahX01LN9P0E72@051/S01DL8P0G7R@06R4V01PP8`0F7R4051hP01@O8@0;5QP041/M01dW:@0F8280
214C05=KGP2V[[405Q`P01LL800N8bL02a8C0P0?61D01`0?61H041TH014I6`0A6A/04QTO01@K8`0E
72D00P0E72H0600D7BH05R4W01DP9P0?6Q`04adN018L6`0?61H03aPE00lH5`0A61T04QLJ018G6`0=
5AL02a<E01PP8`0?5Q`05QdS01DL900I82H03aLJ01@L7@0I8R40624N00`E40804ALC00X04QPF01<H
6`0D6A`05AXN01/P900:3a<05adN01TO7`0<4Q0041HB0P0@5A40100F6aL04aPD00`A3@0@5A4201@I
5@0501<H500B5a<04AHB014F4P0A5A@00`0B5QD02`0B5a@04AHB01HK5`0@5A005Q/E00H;1@0P9Ah0
20d601<H500B5a<03a@@00<03Q<?01<02Pl;01@I5@0@5A404AHB00lD400N8al0<SLc01hS7`0E6QH0
2@h:00dB3P0@5A405AXF01hS7`0>4`l041DA00lD400<4@d03Q<?008041DA00D03a@@00`A3@0;40`0
3a@@010E4@0200hC3`0D01LL600N8al0728P01@J600C6AL03aDC00/A3`0=4a404aTG00P>300?5A<0
41HD00`B400@5Q@041DA018G4`0@5A403A8>014F4P0F6aL600hC3`0300lD3P0=4P`03A8<008041D?
100A5Q007`0?50h03Q<=00dB300<4@X02a0900dB2`0?50d03Q<<00L<1P083@H02Pl800T>1`0D6A80
5a`E01<H4@0;40T02Pl800`A2P0:3`P02a0900L;1P093PL07b@M00d@3017C4D0008000hC300;40T0
3A8;01@I4P0A5Pl00P0<4@X00`0=4P/03Q<<00`A2P0200`A2P8041<<0`0?4P/200hA2P0600P;100P
8a`02`h701@G400>4@X04A8<0`0@4@/02`0A4P`0414;00d>200@4@/05aPB01PI4`0E5Q003a0:00`?
200=40T03a8;00<041<<00/03Q4:01@G400>4@X05aXC00T<1P0D5a0030l800lB2`0;3PL030l8014D
3@0200hA2P8041<<0P0?4P/00`0@4``03a4<00lA300200h@2`803a4<01H06A/F020R7@0A4`h03Q0;
00X<1`0C5A0051L@01DH4@0A50d03A0900hA2P0C5Pl03Q4:01@G400J7AH0;S4Z03Hi<P0D5a002P/6
00/<1`0=3PT0414<0P0B4`h05@0A4Ph0824L01LH4`0?40/02``700P9100A4P`03Pl900`=1`0B4`d0
2``600l@2P0@4@/04a@>01@E3`0;30H02@X400d>200@4@T02P/300`=1@0200d>200=010A2`0?40/0
2`/900l?3@0C4a405aLE00d=2`0>3`X020T4010A300;30L02P/6010A3002014B3@0600h?2P0;30L0
3@h900l@2`0>3`X03@h90P0>3`X600l@2`0300h?2P0@4@/04A8<00@0414;00@03Pl900X;1@0:2`D0
3@h80`0@4@/06`0?40X03@h8010A2`0B4`d0414;01HG4@0C50h0414;00l@2P0@4@/03a0:00/=2007
2@@0>S`g00@60@0H6QD02`d800P:1@0E5a803@l:014C3P0K7AP020X500d?300Q8b007R0M00T;2002
00lA3P0600<50P0A4a007R0M00@60`0?4@h01@L40P0?40/04@0>3`X03@h900d>2@0=3PT020T4018C
3P0<3@P03@h90411?03Mg]T0:b`W01<D3`0H6A@05QLB01<D3`0<3@P051D@008061TD00X05AHA010A
300>3`X0414<00/<1`0N7aX03a0;00T:1@0H6A@03a0;0P0B4`h02@0?40/03@h900d>2@0;3@X03@l<
018D4@0@4Pl02`d:00lA3P0200h@3@05014C400H6QL0;S0]03m1?P0J71L00P0=3`X01P0I6aH03Q0;
00h@2`0?4@`03@l:00/=20<02P`700`04a<A00l?3@0C4a4051@B010@3P0C4a404A4?00`<2P0=3@/0
410>00l?3@0=3@/200l?3@803Ph<0P0=3@/01`092@L02PX800X:200>3P`04A4?01<C4@071`D00P0A
4@l08@0E5A<05aLE07inO01>CT`04A4?01@D4P071`D0410>01PI5@0@4@`07QlJ05MHD`0M7QT02``7
00d>2@0/;BP0QXN2020Q70092PD00040010@3@0>3P`04A4?018B400@40h04A4?018B400>3P`03@d;
014A3`0D5180410>00`;200200d<200<00h=2@0=3PT03@d;01HH5@092`P04aDD00hB4`0J7Ql02Ph>
00`<300=3@/03`l=0P0A4@l4018B4006010@3P0?3`d03`l=018C3P0A4Pd03`l=0P0>3P`0700?3`l0
4Q8B01<C4`0B4Q@04A4C01<C5@0D4aL04Q8D014A4@0@41004A4A00l?400;2`d04a<E01@C5`0510T0
61LL01@C6@0@3aD040lD01TH7@18Ad`04A0E01@C600?3Q<03PdB014@5@0B4AH2010?5003014@5Ooo
oooooooo01;ooooo000Kooooo`0D00l@2`0>3P/071`J00d=2`0T92<030`<00/;2`0@41403Ph@00X:
300@41<07A`Q018A5P0X:2/020P:00`<3P0>3Pl02`/;00`<300:2PT2010@3P0N00d>2@0?40/04Pl:
00l>2@0>3@P03@`8010@3P0C4a4051@F00831`0720`01@H;00d@5@0R9BX0;2/a00l>4`0B4AH04a8G
010@4P0820X04A4C00d=3@0<30`03`l?010@400?3`l03@hB00d>400>3a40414C0P0A4a80=@0>40l0
3Q0=00h@3@0@4Pl04A<>01TJ5`0J6QX04a<C00l?3P0@40h0418?01DG500K7A`061`K018F600A5AP0
4AHJ01<F6P0D5AT04Q<E01<D5P0E5QP04aLF018G5P0G7A/05Q`H018J5@0F7aX0:S@/01<L600A6QT0
4aTI01HK6`0A5AH04Q<E01DF600D5AL04ADF014F5`0B61P051XJ01PP900I82P051/R00893`16CE<0
5A`Q00XB5@0F7R4051`N00TA4`0?5aT041PJ00<03a@G00`05Q/N01@I700B5aX04QLJ00hC5P0D6A`0
7B8U07IkOP0F6Qd061TM01PI6`0H6Ad201HI7P0;01DJ800D6b<041LO00hG800D7RL06B<]01TR;00D
6b<06alX01PL9@0E72@00P0N9Bd06P0C72<05AhU01@M900B7B<051lU01HQ9`0C82P04b0Y01HS;00?
72@08B`e01@N9`0E7RD06B8X01HO900F7B<05ahT01<J800X;cD09bhd02/b>00C6R00:2le00T@5P0M
92X06R4W0P0I82H0:P0H7bD05AdP01LO8P0G7b4051`N01HN800K8bH0620S01PO9@0M92X051/Q01@K
8`0J8BT05ahT01<M800J92H09c4c03m9B`0J8RD051`O01XO8`0I7R80724U01HI7P0E61d02PlC01DM
7`0G7b406B4S01PP8P0E7B0051`O01@K8@1FGF<072<Y01HM9@0@5al06b8Z018I8`0C6R@05A`V01LN
9P8061lW0P0E7280@00I8BD0620S018J7@0;5AL04A`N01DP8P0A71h03QPJ00dG6@0B6ad04a/N02`d
=`0J8B@05AXN010E6@0@5aL041TD010I5P0@6AL04AXI018J700A6A`051`O01LN900E72<04APP01<J
900D7BH051lU018M8`0>6A/04A/L018L6`0=5aD03aPE01<L6`0@5aP0314D018G6`0=5AL02Q8D00hF
6@05318031<I014H800`=cd06B4T018K70084A004Q/H01@M600C6AD04QPD014G5@0@5AP04aPK01HK
7`0731006QlS014F600=4a<02Q0>01DK5`0B5a<2014F4P0300lD400=4Ph05a`H00H04aPD100A5A@0
300A5Q<04AHB010E4@0A5Q405a`F00hC3@0B5a401P/401<H500A5Q803a@@00dB3P80314=00D03A8>
018G4`0C61@041DA00lD400203Ll>00;01TN6P0?51002Pl;00lD400<4@d061dI01lT800@5A404QLC
014F4P0@5A400P0A5Q804P0@5A403Q<?00/@300:3`/03A8>00lD400>4`l04AHB01/P700Q9R80728P
014G5@0>5180318@00/A3`0>51803A<A00P>308041HD00P02Q0>00`B400>4`l04AHB00lD400<4@d0
3A8>010E4@H03Q<?00<03a@>00dB300=4P`01`0@5@l08`0?50h03Q<=00dB2`0<4@X03Q<<00lD3@0>
4``05AXC00dB2`0320406QlH00`A2P0?50d09BXS00`A2P093PL03A8;00`A2P0:3`P05a`E00@90P03
2040724J0:>XX@0V:b@03a@=00`A2P0=4P/051TB010E3P0<4@X03A8;00hC300=4P/03a@=008041D>
0P0>4@X300lB2`0F010C300E614020/400d@2@082`@05APA00hA2P0C50h03a0:00d>200B4`d051D?
00l@2P0B4`d05AH@01XK5@0I6Q@051D?00`=1`0=40T0314:00hC30<03a@=00P03Q<<010E3P0F6a@0
=CXc00P=1`0<4@X03A0900lB2`8030l800<041<<00hA2P0A50d00P0@4``2014D3@0300lB2`0?4@`0
3Q0;008030h902D03Q0;00lA300210004aD@00L9100=3`X05ALB01HH4`0A50d04QD>00hA2P0:3@H0
2`h7010C300:3@H04QD>00P;100R9Ah0@4<l01<F3`0D5A00414<00d>2@0>3`X0414<018C3P0>3`X0
3a0;00H70P0<3@P0414<01LH4`0D5@l03@h800X;1@0B4`d03@h80080414;01@02P/5014B300R8ad0
6Q/E00/<1P0>3`L02``4010A2@0A4P`03@h800h?2@0>3`X03@d;00l?3@0;2`T03@d;00D50`0>3`X0
20T400l@2`802``700<04a@?01DF4@0A4Pd00P0<3@P00`0A4Pd04Q<>00l@2`0300h?2P803@h90P0>
3`X200l@2`07010A300B4`d04Q<=014B300@4@/04A8<018C3@0201HG4@06018C3@0?40X03@h800`=
1`0>3`T0414;0P0=3PP200l@2P0401DF400B4`d03Pl900d>20803a0:00D030h900T;1P0d=S400040
01PJ5@0200d?2P0A010B3@0<3PT0008001DG4P0;3@P071hK02T[:00M7a`020X700h@3@0?4@h020X7
01DG50072@H01PP503Dg=00M7a`00P0>3`X200d>2@8030d802/01PL201@E400B4`h04A8=01lP6`1d
MG00:2TT010A300D5A004a@?018C3P0<3@P04a@?01DF4@0D5A004A8=00h?2P0=3PT01`P300X;1P0;
30L010D000h?2P0=3PT02P/600l@2`0A4Pd03a0;00d>2@0;30L03Q0=00/=2P0@4Pl04A<@00d?300<
3P/04aDB00lA3P092`P01@L400h@3@0I6aP030d:0080004000D051HA00H80`0G6A@03@l:00/=2002
00X<1`802`d800`0410>00d=2`0@40h0410>00h>300?3`d04a<A00l?3@0>3P`03`l=00h>300=3@/2
010@3P803`l=0P0>3P`0;`0D51805aLE00h>300;2`T03Ph<00d=2`0:2PP051@B00l?3@0>3P`01PH4
024Q7`21PGl06QXH0000000N7Q`0PH5o00X;1`0=3PT03a0;02//9`0<3@P02``7018C3P061`808b@O
00`=200L7AP04Q<>00X;1`0>3P`04Q8@01@D4P0A4@l0410>014A3`0>3P`030`:00l?3@0A4@l03`l=
00h=2P0?3PX03@h900h>300?3`d0414>00801PP700D061`M000310072``02`l?00h>3P0300h>3003
00l?3@0@40h051@B00805QHD00<03`l=00`<2P0>3P`00P0<3@P08P0<30X03@d;00h>300@41003`l?
01PH600D51H03`lA01PH6P0B4QD03`lA018B4P0D51@04Q8B00l?400=3@l030`>00X93@0K6Ql06QTN
00l>4`0100H04a8G01/J7`0B4AH03PdB01@C600C4QL03PdB014@5@0B4AH040lD00l>4`0@3a@Doooo
o`006oooool01@0:2`H03Pl;00L71@0=3@/03@d<00803`l?01l0410A00h>400<30h03@d@010?500=
3140410C00P82P0@41804A4B014A4@092@T09bLV01lO7@0@40h04Q<>00l@2`0F4`h04A0;00l>2@0A
40`051@B01HF500A4A<0414E018C5`0?41D04A@I01TL8@0J6Al030/@00803`hC00D051@F014A4`0@
41803@d=00h>3P02010@400A00l?3`0>3a<04A8D010A4`0=3Q003a4@018D4`0A4a803a4>010B3`0C
5A804aD@01<D4P0B4Q<0410@014A400C50l00P0C5A00600G6AH061`K01@H6@0>4QD04AHJ01HI7@0E
5QX051DG01HG6@0G61X04aLF01<H5P0C6AL03aDA01@K5`0:4`h06B<K018L600?61L041HF01<H600B
5AH05ADG01LG6@804Q<E03@041DF018H600B6aX05QlQ00hE6P0@61`092/`010E5`0G7b8051`N01<K
700D7Ad04a/L00lH5P0D7A`07B8T00L=300F71`04ALH01`R8@0B61P04aPJ01dS8P0J7b00D5IG00dC
4P0I7Al05aPJ01PH6P0H6Ad061TN01LJ7`0F6b406B0X01PO9`0E7bP05AlZ01DP:`0I8bh061lY01XN
:00N8R`05QdV01@K900Q:3406b@/01dV;P0L9Bd06R@/01dW;`0P:S<0E65Z0P0N:c@04P0H9Bd08blh
018L9@0G82P07BH]01@M8`0E728072<Y01HM8`0J8BP072<Z01hU;00h?dH0W:>Z02`c>P0N9B`06b8Y
01PO9P806B0W01405ahT01LO8P0F7R005QhP01TQ8`0J8R@0620S01LN900J8BL07B@Z01PO9`0G7RH0
7B@Z01<L800A6ad04adO02H_<P0201HM800701DJ7P0C5a/05ATM01DH7@0M82D061/P01LM800201LN
800701HL7`0C6Ad04ALK018H7P15Be406R0V01LL9@0201XP:00b01LL9`0E6RD051XT01HK900H7BH0
6AlW01XP9P0G7B<05A/P01@K7P0E71l05QlR014M7P0D824041/L00lI6P0G8B<04Q/M01LO8@0A6A`0
5A/N00hC5`0C61`041LF014H500A61D04QTG01<K6@0D6a`05A`O01DK7`0E6b4051XQ01@I8P0D6B<0
4a/T014L8P0@6b403aTK010J6`0B71/041TG010I5P0B6aX04QTJ018G6P0H7B403aLI018J700E7B02
014H7P0701DL900B6Al06b<V03]3A00Q:RT03aPE010I500201DK5`0:01@J600B5aX04AHI010E6@0P
9BT0MGYn020V9`0E6a/051XH00lE4@8041DA0P0A5Q801@0D6AD06QlK014F4P0A5Q804QLC00804aPD
00<051TE014E500@51<00P0?4a80300@5A804AHB00dB3P0B5a805AXD01XO6@0A5Pl05a`E018G4`0A
5Q8041DA00lD408041DA01804AHB018G4`0<4@d041DA01@I5@0[<2`082DQ010E4@0D6AD04aPD01@I
5@0;40`0314=01<H500;40`041DA014F4P0E6QH3010E4@803a@@00l03Q<?00dB3P0B5a<04aPD014F
4P0>4`l03A8>014G5@083P`02@l=00dC4@0D6QP06AlM00dC4@0:40h00P0?5A<0200<4Q003A<A00`A
3@0@5A404AHB00lD400=4Ph03Q<?1P0@5A400`0?50h03A8<00dB3002010E3`0300lD3P0>4`d03a@>
008041D?00D03a@>00hC3@0<4@X02a0900lD3@02014F3`0900`A2P0E6Q<0314:00`@2P0>4``0<SL`
04Q=AP0A5Pl0314:00804QL@0P0>4``04`0B5a002a09014F3`093@P04AH?00hC300=4P/03Q<<018G
400=4P/02a0900hC300=4P/02a0900`A2P0=4P/0314:00d@2@0>4@X00P0?4P/0200@4``04A@=00P;
1@0>4@X03a8;00`?200>4@X041<<1P0@4@/02`0R8ad07b0J01HG4@0@4@/04A8<01@F3`0A50d03a@=
010E3P0?50d03A8;0080314:00D02a09030e;P1FFe@061dF00/@2@0200lB2`803Q4:0P0?4P/0200C
5Pl03a8;00hA2P0A50d041<<00`?200?4@`03@l:0P0;3@P03`0=3`X03a4<014C3P0=3`X02@/6018D
3`0=3`X04Q@?01LJ4`0@4`/03A08010C2`0?4PX020/300hA2@0200d@200;010C2`0B5@d03a8;01DF
4@0A4Pd03a0;00d>2@0<3@P03@h906=TG`0O81/00P0C50l07@092PD04Q<>01<D3P0?40X02``6014B
300=3PP04a@>00`=1`0=3PP03Pl901`M5`0K71H03a0:00d>1P0@4@T061TA01PI4`0@4@/03Pl900`=
200A4@l04a<A00d=2`0A4@l02`/9014B3@0<3@P0414<00803a0;00D04Q<>010A300>3`X03@h9010A
300201<D3`<03a0;00<03Pl:00`=200>3`X00P0?40/200h?2P0300d>2@0>3`X03Pl9008030d700D0
3Pl9010A2`0G618061TC01<D3P02010A2`0600l@2P0@4@/04A8<014B300B4`d0414;0P0>3`T07@0=
3PP03Pl9010A2`0B4`d04A8<014C3P0<3PT03a4<02PZ9@0E5a803Q0;018D3`0D5Q403a4<01@F4@0@
4Pd051HA02`^:`0E5a@020X700lA3P0=3``03a4>01HH5@082PL05ALD00D7100e=c@0828P00H03@h9
02<0414<00`=20061`803@h900/<1`0E5Q405aPC00d>2@0A4Pd02``7014B3@0C50l030d800h?2P0=
3PT030d800d>2@0@4@`030d800h?2P0=3PT0414<018C3P082@@02``700d>2@0?40/0414<01<D3`0H
6A@06A/H00`>2`0:30T03Q0=00`>2`0200X<2@0500h@3@0D5Q<03a4>00d?300B51400P0I6aH0100>
40/02P`801LI50082PL200`>2@0>00h@2`0@4Pd04aD@01DG4P0>3P`02`/900`<2P0>3P`03@d;00`<
2P0A4@l0410>00l?3@0@40h2014A3`<03`l=01P03Ph<00d=2`0=3@/061PF01lO7@0A4@l03@d;018B
400>3P`04A4?01DE4`0;2`T05QHD02<S8@0K6aT02@T700l?3@0B4Q005QHD01LG5@0C510030d8014B
3@0D5A0200P9100800h?2P0A4Pd03@h901@E40082@D03Pl:00h>2`0?3`d2018B4006010@3P0A4@l0
4Q8@010@3P0=3@/03`l=0P0@40h0600?3``03Ph;00d>2P0=3@/03Ph<00lA3`0A51<03a8A00lC500>
4aD01``>05YNH00?4A003`l=00d=2`0<30X03@d;00l?3@0@40h051@B01DE4`0=3@/02PX800h>3080
3Pl:0`0>3P`0600?3`l0410@014A4@0B4Q@04A4C010@4P0>3A404Q8D01@D500E5AD0410@010@4@0D
51H05QHH00l?4P1=C54092<X01@D6@0E51X03PdB01`K800C4QL04Q4F00`;40803`hC0P0B4AH00`0@
3a@03`hC010?500Dooooo`006oooool06@0;30L04A4>00l?3@020P003`l>00D51@0<30`02PX;00`<
3P0?3a403PhA00/:3`0H5a`02`X>01<C5@0E5AL02PX;00/;2`0:2PX0=3@c02DU8`0>3P`04Q<>00l@
2`0C40/00P0<2`H0400?3PX0410>014A3`0>3Q0071dQ00`=4@0720d030lD00H93P0C4QP061LL010?
500920d0410B00H6200A4A<200l?3`04018B4P0@41003`l?010A5@804a@F07X0414C014C4P0D5QD0
4aDD010B3`0B51405QPE01<E400A4Q00410B010@400C4a004Q<=00lB2`0=40X04A<>01DJ5P0G6a/0
41@G010E6`0E61d051DI01@E5`0F5aT05aPJ01<G5P0@5A@06b4O014G4`0<4`l03AHA01`V7P0B71P0
31HE00hD500B5QL04a@F01LG6@0H61X051@F018C5@0A5AH03aPG014J6@0@6AX03aLJ01PP8P000P@0
6B4S00lH600;51<03QLF028[:@0I8Ql0214>02/d<@0G7A/03Q@B018H5P0;4@l05adK014G5@0C6AL0
51XH01PN700f?3X04QPF01LL6`0F5aT05aLI01TI6`0H6Ah05aXO01PL8P0H7bL06b@]01/T;`0B7RX0
3a/W01@O;00K8Bd07R8]01/O:P0E72H05ahX01<J900E7RL04a`U01@M9P0H8R/07bTb028/=@1NJg@0
7R/d01HS;00E8R/06RH_01DO:00D7BH06b@/01LP9`0D6b4061lU01TP9P0A620061lW01@K8`0A6200
ADaD00hE7@0L8b/061lW01HM9@0G7RH061lW01PO9@0H82<05AdO01PP8P0I8B<05QhQ01DM80805ahT
01007RD[01XQ:@0B6B405QdS01HO8`0K9BL0BE=E02H^<@0G720051TM01/P900M82D071lT01<F6`0I
72405aXO0P0F6ah03P0E6Qd04aPK010E6@0@5AT04QLM01DJ800>4aT05ATR01dQ:P0A5Ah06QhY01LK
9P0F6RD05QXS0P0G6b@03`0G72804QLM018G700E6Qh061dQ010I6`0F8R80?4Q802hi>@0641403QPI
010I6P0:4Q@00@T;01HL7`0201<H6`0=014G5P0A5a<04ALC01<I5P0E6aT05Q`L01PM7`0D6Ad041DK
01@H800H72D05QXS01<K8`02010K8@0W01<M7`0@6Q/03aTH01<M6`0A6QL03AHE00lF5`0B5aX041DI
00L?4@0?5aT03ADH010G7@0<4aT051/S01hU:`0B6Qd06B8S00XC4P0@6AH0624L00lE4@0@5Q804aTG
01@I700B5aX041DI00H;3`0L8BD051TK00`B4P0630X051XF010E4@0A5Q803a@@00dB3P0A5Q804QLC
00803a@@00H041DA014F4P0A5Q804QLC01DI600D61L2018F5@0P01@H5P0E6QH05Q/G01<H4`0=4P`0
4AH@00`A2`0B5a005Q/G01@I5@0A5Q8041DA00lD400>4`l02a0<018G4`0>4`l05Q/G010E4@052PH0
7B8N010E4@0A5Q802a0<00lD400>4`l02Pl;010E4@0<4@d041DA00dB3P0A5Q8200lD400300hC3`0@
5A404AHB00804QLC00H03a@@00hC3`0?51004AHB018G4`0G7A/200dC4@0400hD4P0?5A<04aTG010F
50<03A<A00<03Q@B010F500B5a<00P0B5a<00`0?51002a0<00T>2P06014F4P0300lD3P0=4P`03A8<
008041D?00<03a@>00hC3@0?50h00P0?50h08`0>4`d03A8<00`A2P0;40T03a@=018G400A5Pl03A8;
01lT7@0I7QL020d600L<1@0;40T05a`E00hC300<4@X04AH?00lD3@0<4@X01P/500T>1`0;40T02@h7
00hC300C61404QL@00dB2`0?50d04AH?00X?20093PL03a@=014F3`0B5a003Q<<0080314:0P0>4@X3
00lB2`04010C300K7QL08B@M00X=1P804aH?010051L@00d>200A4P`04a@>00h?2@0<3@L04A8<01LH
4P0E5Q004a@>010A2`0?40X03a4:00/@2@0<4@X03Q<<0`0?50d200P=1P0<010E3P0M8Q/04AH?01<H
4@0A50d03Q4:00lB2`0>4@X030l800lB2`0A50d03a8;0P0>4@X00`0=40T02`h700d?2P0400h@2`0=
00d?2P092`H02@/6010B3@0?4@`04aD@04U<A@0^<BX05aXA00T<0`0=40L04A@;00`?1P02010C2P0<
00/>1@0?4PT04aH=00L:0@0;30L03Pl:00l@2`0@4@`03a0;00h?2P0K71L061TD0`0;30L02`0@4@`0
3a0:00l@2P0?40X05QLA00l@2P0B4`d03a0:01<D3P0>3`T02``6008030d701@04A8:00T:0P0;30@0
3@h800l@2P0C50h03Pl:014A3`0C4a4030`:010@3P0;2`T03Pl:00/<1`0<3@P03Pl:00d>2@0?40/0
414<00h?2P803a0;01D03@h900`=200>3`X03a0;010A300>3`X03@h900l@2`0@4@`03a0;00h?2P0<
3@P02``700d>200>3`T03@h800h?2@0?40X04A8<018C3@0?40X00P0=3PP200l@2P0T00h?2@0A4P`0
51D?01DF400A4P`03a0:00h?2@0=3PP03Pl9014B300C50h04A8<01<E40072@@07AlJ010B3@0?4@`0
3Q0;00T;1P0>40/010H300`>2@0H6QD0418=00L91P0A4a004Q@A00d?300A4a00418?00@60`0F61D0
2@/800/=2P0=3``01`T60P0=3PT200h?2P803a0;00l020T4014B3@0D5A00414<00`=20061`80414<
00l@2`0A4Pd01`P300`=200>3`X0414<014B3@0?40/00P0<3@P01@0>3`X05AHA00`=200:2`H04a@?
00802``70P0>3`X01`0=3PT03Pl:01HG4P0N7aX07b4N010B3`0;3@X00`0=3``03@0D5Q<03a4>00`>
2`051`@00`D200L91P0=3`X030h901HH4`0U9b80DE=>01`N6@0?4@`00P0>40/01P0?4@`0418=010B
3@0@40h03`l=00d=2`80410>00<030`:00h>300?3`d00P0?3`d00`0A4@l051@B00h>300300d=2`80
30`:00D02`/9014A3`0;2`T03@d;01@D4P03018B400=00d=2`0J6QP0>c/i01`L6P0M7A/0000001HF
500000007alM00`=2@082@@04A8=00<4000200l@2`07010A300D5A00004001<D3`0G61<03Pl:00L8
1@0200`<2P802PX800<030`:010@3P0@40h0100@40h00`0>3P`03@d;010@3P02010@3P0900h@3`03
1`H0310?07UmOP0U:Rd00PL:01/O8@0?4A003`l=00<03Ph<02T03`l=00d=2`0@40h04A4?00d=2`0<
30X03`l=014B3@0B4`h04Q8@010@3P0?3`d03@d=01DE5@0=3@d04Q8D01HF600<30h0410C01HF600D
51@04A4A00d=3@0A4A805aLI018B500L71l07QdR01LF6`0Q82D081lU01@C60061@X06APM014@5@0@
3a@02PT>010?500C4QL04Q4F010?500200h=4QCooooo000Kooooo`0V01HG4P0:2`L06a/I01<C4@0=
3@`02`/;00d=3@0=3@h030`>00/;3@0=3A003`hC00d<4@0;2`h04A4C00/;3@0;2``03@d=00T92@0G
5aH05ADC00`<2P0?40/04a@?014>2@0;2PD030/6010?2`0?3`d03Ph<014A4`14ADT0>3Tm01LH7@0;
3Q<020/@00T83P0?3Q<2010?500901PH6P0@41804Q8D010@400A4A404a<C014A4@0@41004A8F00<0
4Q<E01H04aDD01@F5@0C5A@03a4>018D4@0F61D04Q@?010A400A4A<03`l?00l@300?40X030l800`?
1`0@4Pd051TE01TM7@0@51L03A8H01<F6P0D5AT051DG0P0F5aT08@0B5QD03A8@00hD4P0D6QH0<cXf
014J5@0=5`l04A/G00dG5P0B61P061/L01DF600E5AL061HI01HF600D5AL04ADF00lH5`0A6QT041TJ
01<K7@0C6A/072@V01`U900>5aH02a@C010I5P0N9b<05AhI00`E400W<2/06R0L01`R7P0201DK5`1;
00hD400?5A405A/G00dC3`0B61@000H200hD400B5aD05aLI01PF6@0I6A/061TN01LJ7`0H72805QdU
01LP:@0I8Rd05R8^01DQ;`0C82d06b4]01dQ;00K7bX05A`V01XQ:`0N9Bl07bPa01PQ:P0J8b`08B/d
02Tc?00X<S/06RL`01PU;`0H9Bh05b@]01TU;P0F82T051dV01dV;P0Q:S406R4Y01<J8P0I82P06R4Y
01/R:P0L8b/04aXR01TP:00M92`06B0X01HM9@0D6b<05A`T01TP:00H7bD06R8U01DM7`0I8B<06R8T
01@L7P0D71l05A`R01LN900C6R007B@/01lV;P0C6R0061lT00dE600e?D0051`O03Hk?`0N8bL04QLK
008051LL00L03A0E01DF6`0?4QL05a`O01HK7P0E6Qd051TL00804AHJ00L07b@Z02T^=00I7R@04aLP
01@H8@0H72D05a/V00805QXU01805a/T01PL9@0H72D04aPN00hC6@0K82D08RL[01/P900@6A/0:3@d
05aXJ016DE402aDF01HP8@0I8R<07BDW024Y:`0=51H201PM800K010F5@0B61@04QPD01@J5`0F71X0
61hN01LL7P0C61`04QLM01<H7P0E6R005QXS01DM9P0A72804QdS01HQ8`0@6Q/03ALF018L6P0A6QL0
3AHE00dD5@0@5AP041DI01TQ8`0N9RP041PK008051/Q00L0:c8j00dD6P063Q403aLH01@M700C71T0
214<00804ALC00X04QPF018G6P0A5QT04AHJ01TN8P0<4AD06b0R01HL700630X03aDA0P0B5a<0100:
3`/02@h:018G4`0H7AT200hC3`@03a@@00l05ATH018F5@0@51<041@C018G500E6QH061dI01<H4`0=
4P`041D?01HK5@0D6A804aPD018G4`0@5A40100?5102014F4P0A01DJ5P0?51007R<O01XO6`0:3`/0
3A8>00/@300B5a<04aPD00/@300B5a<03a@@01<H500;40`03Q<?018G4`0A5Q800P0?51000`0@5A40
4AHB010E4@0200hC3`09018G4`0D6AD05AXF01<I5`0<4Q003A<A00/A3`083P`02Q0>008041HD00X0
3A<A00`B400=4a403A<A018G4`0A5Q8041DA00lD400<4@d02Pl;1P0?51000`0?50h03A8<00dB3003
010E3`<03a@>01h03Q<=00`A2`0>4`d03a@=00hC300?50d041D>00lD3@0<4@X00@H000@90P0I7QL0
3Q<<00D:0`0<4@X02a0900`A2P0@5@h0314:00X?200<4@X051TB01TN5`0:3`P061dF00D:0`0;40T0
3A8;00lD3@0@5@h200T>1`0600dB2`0D6A806AhG01<H4@0>4``04AH?0P0@4``300lB2`0?00hA2P0Y
;2D0<SD^010C300H6a@04A@=018E3P0?40X0414;014B300@4@/03a0:014B300=3PP03Pl900804A8<
00D0414;00d?2@0:3`P02Q4900`C2`0300dD300800hE3@0R:B401`h60007000;4PX03A8;018E3P0=
40T200lB2`0600/>1`0@4``041<<014D3@0@4``03Q4:0P0=40T03P0<3PT03a4<014C3P0A4`h03a4<
00`>2@0B50l051HA010B3@0:30L01@L402P[900R9Ah05AP?0P0;3PD02@0=40L030l600`?1P0?4PT0
20/200`?1P0D5`h02@`3014B3@02018C3P06014B3@0>3`X03@h900/<2@0I6QD04Q<>0P0=3PT06P0;
30L03a0:00`=1`0B4`d08B8L01<D3P0>3`T04A8<00L80P0>3`T05QLA014B300=3PP04A8:00T:0P0;
30@030d700d>200A4P`03a0;00h>300@40h02`/9010@3P0:2PP03Pl:0P0<3@P200h?2P0;00l@2`0@
4@`03@h900h?2P0?40/03@h900/<1`0=3PT03a0;010A300?40/0100>3`X03P0=3PT030d800`=200=
3PT03Pl900l@2P0@4@/04A8<018C3@0D5@l04a@>014B300@4@/03Pl90P0<3@L01`0@4@/04Q<=018C
3@0?40X04A8<01LH4P0C50h00P0>3`T01`0?40X04A8<014C3P0B50l05aTD0001000:30L00P0@4Pd0
4@041P40;c4/00H80`0>40/030h900D7100@4Pl051HC00h@3@0@4Pl04A<@00D7100L7Q/04aDB01HH
5@0@4Pl05ALD00803Pl:01<03a0;010A300@4@`04A8=01/L5`0=3PT02P/600/<1`0F5a805AHA010A
300<3@P0414<00/<1`0@4@`02@X500h?2P0@4@`03a0;008030d80P0=3PT01`0A4Pd03a0;01/L5`0@
4@`020T400/<1`0<3@P00P0;30L00`0?40/05AHA01HH5@0200d?300500h@3@0<3P/030h;00h@3@0;
3@X00P0>40d02P0A4a005QPE014C3P051`80418=01@F4@0V:2<01`T400lA300>40/200d?2P0?00h@
2`0?4@`03@d;00d=2`092@L03@d;00h>30092@L03Ph<010@3P0?3`d03@d;00l?3@0B4Q003`l=00<0
3Ph<0P0=3@/01@0?3`d03Ph<00d=2`0=3@/03Ph<00803`l=01X0410>01@D4P0?3`d092@R00L71@0E
5A<08b<Q00X:200<30X00`<100P81P0=3PT08R<N00d>2@0S91l051D@014B3@0g>3<06Q/F00h?2P0<
3@P02``700l@300<30X03@d;00`<2P802`/900@03@d;00h>300@40h0410>0`0>3P`03@0@40h051@B
01DG5P0C5A@04A<B00lC500/<340]KVj0497BP0F6ah01`X<00d?3P0?3`d0100@40h3014A3`<03`l=
00h0414<014B3@0A4@l04A4?00l?3@0=3@d04a<C014A4@0A4A<04Q8D014A4`0C4aH05ADG018B4P80
3`l?01804a<D01<C5@071`T04A4D00@3200F5AX051<I00d<4P0?3Q<020L<01@C600?3Q<04A0E00h=
4P0@3a@04a8G018A5P0@3a@200h=4QCooooo000Kooooo`0I09>AU@0Z:B`0:RX[03`m?0093@T03Q4=
00`@2`0@51003@h=00L7200>3@l03`dA00h=4P0W9RX05ADH00811@0>3Q003@d>00l?400<30d04Q8A
00`<2`0>3Pd03Ph;014@300200h=2P0I010@3@0?3`d03Ph<00d=3@0H6AX061PI01HG6@0?418051@F
01@C5`0@3a<04A4B010@4P0B4Q@0410B018B500?3a404A4B01DD600C4QH0410C014B5P0A4Q@04Q<E
01<D5@0201<E500f010B400>40d03Q0=01<E4@0C5A0041<A014D4`0?4Q404A8@018C3`0C4`l051@A
00l@3@0D5A@07b8R01<G6@0<4A<03a@F010C5P0G6Ad061XM018E5P0A5AH04AHF01HK6@1>De40a<S6
038j=P0A5Q<04QXG010H5`0G71`06QhO01@G600B4aD05ADG01PH6P0G6A/05ATJ01<H6@0C6QX05QdN
01DL7@0F7Ah06b<R01<K6P0D6a/05QdL018J600B6AL051/J01@K600F7A/041DC0P0H7A/0E@0L8Ah0
3Q<@010E4P0K81l04QLF010E5@0N8b<05AXJ01LL7P0J7B<05aXP01HI7P0H6al06AdQ01PL7`0H7B40
4APN01HO:00R;S`08bln01LT=@0I8Bh072<^01hV<@0F7BX0620Z02Pb>`0T;CH072D^01HP:@0F8BP0
5b4Y01DO:00H8b`0:3<l01dY<P0F8BX0624Y01/U;@0I8BX072@[024Y<00S:C0051XP01LM8P0N92T0
6AhS01HL8@0K7bD05Q/Q01XP9@0G6b005a`R01TO900L82H0724V01XP9@0J82<05adP01`R9@0K8R@0
5Q`O01PN8P0G7B<082H/01@J800X;CH0A4YB01/Q9`0G7B8041LJ01PO8P0C6Qd0>d1301hS9P0O92H0
6AdQ01LL7@0C61T05Q/L01<H6P0H7B005AXM01@I700C6Qd00P0D6Ql0B`0j@DL07bD/010H7P0F7RD0
5alW00lG7`0F6b<05ATS01DI8@0G72806b0W01hS:00J7b<05Q/O02<X;00W;2h07b@W01HN7P0;5a@0
72DU01<L7P0:4aD04a`P01PP90053A805QdS01hU:P0R:2d051XO018I6`0A61P041LF00lF500@61D0
51/I01@K6P0A61P04QTJ018H700B61h04aTQ01<J8@0B6Ql051dQ01HP8@0@6AL03QHD00lF4`0>5Q80
3aLE014G6@0@5AP04QLK00TA5@0=5AT04QTN01PO9@0>5A/05QdS01<J800G7b802A4C00`D5@0E7Q`0
4a`J03To?P0?5A@061dN00dB5@0730l04AHJ00hC5`0B5aX03Q8E01LL7P02018H5`0D00`A3P0>4a00
4ADC014F4`0@5A80314>00lC4@0?514041@B00lC4@0>4Q0041@B014F4`0?4a403A8?00lC4@0@5A80
3a@@01<H500A5Q4200lD3`0401@I500>4`h03a@@00lD408041DA00<04AHB018G4`0D6AD00`0?5100
4P0A5Q80;C8^01LL600@5A404QLC01<H500F6aL03a@@00L<200?4`l04QLC01<H500A5Q802@h:00dB
3P0A5Q803A8>010E4@<03Q<?01T03a@@014F4P0I7QX05a`H010E4`0E7Ah03QDF00lH5P0:4@d041P@
00/F2`0?6@h031@=00TC300=5Q003ADB00TA3P0@5A803Q8@00`A3P0A5A<03Q<?00lD400>4`l03a@?
008041D@00X03Q<>00hC3@0>4`d03A8<01PM5`0=4P`04QLA00hC3@0A5Q004aPB0P0>4`d0200A5Q00
41D?018G400@5@h03a@=00hC300=4P/03Q<<0P0B5a00100:3`P03a@=01<H4@0>4``200`A2P1300lD
3@0=4P/02a0900hC300=4P/01@X3010E3P0=4P/04QL@00`@2@0@50d04aL@00lC300;3`P03A4:00`@
2@0=4@X04QH?00lC300=4@X041@=00`?200>4@X04A@=00lB2`0>4@X04A@=00d@2@0I71D03A09014D
3@0:3@H03Q4:018D3@0>40T0418<01DG400?4@X04Q@>00h@2P0?4@X03a4;010B2`0@4P`04A<<00dA
2P0<4P/03Q<;00hB2`0;4@X02a0901@H4@0`=Rh061dF014E3P0>4`/03109018E3P0?4P/04QD>00lB
2`0;3PL04A@=01DH4@0F6A8051L@010C300200`?200I00hA2`0?4@`04aH@01@G4@0?4@/02`d700P;
1@0<3`T03A0:01<E3`0?4@/030l800lC301PI5d07B4I018F3`0<40T03a8:010C3@0>40T03Q0800h@
2P0>40T04Q@>00h?2@0200d>200500h?2P0@4@/04A8<018C3@082@@00P0B4`h0:P0F5a404a@>018C
3@0;30H051D?01hO6@0C50h02@X400`=1`0>3`T051D?00d>200:2`D04Q<=00h?200B4``061TB010A
2`0<3@L02@X400h?2P0<3@P03Pl:010@300C51003a0;010B3@0<3PT0414<01DG4P0C5A004A8=010B
3@0:2`H03Pl:010A300;3@P02``700h?2P0B4`h0414<00h?2P80414;01<03Pl900d>2@0=3PP03@h9
00l@2P0@4@`02`d700/<1`0?4@/051H@00/<1`0A4`d03Q0:00d?2@0?40/0418<010A300?4@X0418;
00804Q@<0280418;014C300M7aT061TD018D3P0;30P030d8010A3@0;3@P06A/F00d>2P0B50l04A<>
00h@2`0D5Q402`d8055CCP0V:2<04A<>00/=200H6QH03@l;02<U8@0=3`/030h:018D400@4Ph030h:
01TK5`0<3PX03a4=01@F4P0B4`l04A8>0`0?4@d08`0>40`020T500d?2`0?40`02@X600`>2P0=3`/0
4A<>00d?2P0=3PT061TD02LX8`0B4`h03a0;00lA300H6QD04A8=010A3@0a<Rd0824L01<D3`082@D0
4Q<>00l@2`0;30L04A8=010A300>3`X030d800h?2P0@4@`03Q0<00X<200<3PX02P`800802`d900d0
3Q0<01<E4@0B51003a4=00D71@0<3PX03Q0<00T;1`0B51003@h;00h@300A4`l03Q0<00803@l;0100
3a4=010B3P0@4Ph051DA020P7@0E5A804A4>018B3`0:2PL0410=01<D400B4Pl03@d:00H71@0>3`/0
3Ph<0`0?3`d200d=2`0]00/;2@0>3P`051@B00l?3@0>3P`05ADB00/<200:2`L04A4>014B3P0Q8Qh0
4A4>00d=2P0720@0414=00d=2P0:2`L04a<?00D60`0<3@P0414<00`=20061`<0414<024R7@0H6A@0
3a0;014B3@0<3@P03Ph;00h>3@0@40l04A4@00l?3P0>3Pd030`;014A400C4a80410?00d=300;2`X0
3Ph=00`=2P0C51804A<A00803a4?03402Pd;00d@3P0V:BT02`h>00X?3P0@4a<03Q0?00l@3P0@4A00
4Q<A014B4@0>3`h04Q<A014B4@0@4A003a0?010A3`0A4Q0051DE00l@4@0;2`d03a0B01@E5`0=3Pl0
30d@01dM800=3A003PlA018B500@41<05QHH00l?400@41403@d>010A4P0D5AL04Q<E00h>400@41@0
4Q8F010@4`0;2`l02PX>01@D6@0A4AH03`lD014A5P0D51T03`lD00804A4F00<02`/@00d=4P0>3Q<0
5?ooool001_ooooo01T0E55L00H42`041@T06AXL00L=20083`L04QTA01HL5@0=4P`01@D500X92P0I
5aX01PD:00l>4`0920d03PdB01HF6@061PP03`lA00H6200E5AL04a<C00d=3@0>3Ph04A4?00803`l=
0P0>3P`0500?3`d03Ph<01HF500N7Q`09bLU010@3P0B4Q005QHF01<C4`0B4Q804a<C01@D5P0E5AL0
3@d?00h=4P0A41D05aHK01TH7P0I61d04A8E0P0A4Q@3014C4P0O00lA3P0>40d03@l<010B3@0B50l0
3Q<?00dC4@0>4Q40418A014A4@0C4A805A<D00l=3P0@41007AlN01DI600=4a405Q/L00lB5`0;3a80
310C014E600G6a`04QHG01dQ8P0/<2l0OX:101TM700@51<05ATI00lC5002010D5@0600hB4`0?4a@0
4ADF01<G600D61T04QHG0P0?4a@01`0D6AX05A/K01HL700F71`04ALG01DK6`0I7al00P0E6a/0=`0D
6QX041HF018H600@51<04ADD01DI600D61L04QHE00dA4P0A5AH03Q8C01XN8@0B5QT07b<V018F6`0L
8bd05AhW014H800F6al061dP01HJ6P0G7Ad07BDW01TQ:@0I8S409C1201@Q=@0N9cH06bDa01TS;`0F
82`05AlZ01hX<P0Q:c@06bD^01LQ:P0I92X06RD[01LR:00D7RL05AlX01XT;@0J8bX05QlV01TR:@0I
82H05ahT014H7P0Q9RX0724U01PM8@0I7B0061`O01LK7P0H71l00P0I7B006@0F6Qd06AdP01`P8`0M
8B@07R8U01dQ900H7B005a`O01`Q900J7b805AXN01XO8`0G7280724W01/P9P0H72D0<3@m00hB6`0E
6Ql04aPL01HK7`0G71l05AXM01LL7`0E6Q`00P0A5aL00`0G7A`06AlM01TO7`0201<H6`1;01@I700F
7R406b8X01dT:P1FGf@08BXa01hW;P0A72806RD[00PA600D6R004AHL01<H7P0J7b<0724U01/P900E
6Qd03Q@D014G5`0F71`04aTI00hE4`0>5a805AhM018J6`0?5aX051/S00D<5@0>5Al072<]00P?600=
51`0>D16020X;00@61/03QHH014J6@0F7a`051dH014J5@0>5a@03AHE018J700D6b404aXT014G7P0B
5a/04aPK01@J6P0B61H041HB014G4`0@5Q803Q@B00lD5@0>4aH061dQ014H800=51`04QTQ01DL8P0B
6Al06R4W01HN8@0D71l02a<E01PP8P022P`03ADG01PM800I7R40314D01DJ7@0O92L04AHI00803Q<F
0P0?51L01`0@5AP041HG010D5@0=4A003a<B014E500?4a800P0A5A@200hB4@<04ADD00<041DA00lD
400@5A400P0A5Q800`0>4`l03a@@00hC3`0200dB3P0300lD400@5A404AHB00D04AHB01P041DA00lD
400>4`l03Q<?00lD400@5A402Pl;010E4@0>4`l03a@@01TN6P0N8al02Pl;018G4`0K81`02Pl;00dB
3P0H7AT03Q<?01XO6`0C61@02a0<010E4@0C61@200lD400900`A3@0C61@05a`H018H5P1[M7H0P8Z;
018M6@0A71804Qh@008031P:00l031P<010K4`0A6aT02Q@E00L?4@0@5A@03a<B00X>3@0>4Q404AHB
00T>2P0@5A4041D?00lD3P0@5@l00P0@5@h03@0I7QP04AH@00H;1@0>4`d06QlI00`A2`0E6Q@05Q/E
018G4@0?50h02Pl9010E3P0?50d00P0=4P/00`0?50d041D>00lD3@02010E3P0F00`A2P0?50d03a@=
00dB2`0<4@X02a0900dB2`0>4``0314:00X?200<4@X04QL@01<H4@0:3`P02a0901hR6`0W:R<0:2/T
01TL5@0B5@h04aH?010C30803Q4:00@03a8;010C300B5@h04QD>0P0C5Pl04@0D5a0071lH02ha:P0=
40T030l800d@2@0?4P/041<<00hA2P0B5@h05aXC01@G400<3`P02@`500/>1`0>4@X03a8;008041<<
0P0?4P/0100=40T03Q4:00lB2`0?4P/200hA2P803A0900X03Q4:014D3@0?4P/02Pd600`?20072P<0
2@`500lB2`0B5@h030l8100?4P/02`0>4@X03A090002000B5@h071lH00D80@0B5@h051L@00/>1`0=
40T03Q4:00803a8;01003A8;020U7`2V[:H0:BhX018G4@0A50l03Q0;00d?2P0>3`X071dH02PY900S
91l04A8=010A2`0?40X03Pl90P0?40X03`0@4@/04Q<=000100051P00@T<m0;jo^@0/;BL02@X401<D
3P0310002``600h?2@0@4@/03Pl900l@2P0201@E3`0;018C3@0G6180414;00H70@051P0020T500h?
2@0A4P`03Pl900d>200>3`T00P0A4P`0400@4@/030h900P:1@0=3`X04Q@?010B3@0?4@`02@/601@F
4@0>40/03a4<01XL5`0;3@L0414;014B300=3PP300h?2@0B010A2`0>3`T03@h800d>200>3`T02``7
00h@2`0N81/02P`700h@2`0?4@`04aD@00h@2`0=3`X03a4<010B3@0>40/03a8;0P0@4`X02`0@4`/0
3a8;00hA2P0?4@`03@l:00/=2P0A4a004Q@A00lA3P0=3`X03Q0;00803a4<00@03@l:00`>2@0=3`X0
3@l:0P0A4`h03P0=3`X03Q0;00H80`010`0071hI014C3P092`H03Q0;01@F4@0@4Pd03a4<00`>2@0F
61<04A<>0`0;3@X300X<2@803Q0=014030h;00h@3@0@4Pl02`d:00T;1P0;3@P010H100d?2P0K7AP0
2`d800X<1`0@4Pd05aTD00d?2P0<3PT0:2XU024R7@0200/<1`0^014B3@0=3PT03@h900h?2P0=3PT0
2``700`=200@4@`04Q<>00lA300@4Pd05aTD014C3P0C5A0030h900lA300:30P01@L200/<2@0@4Pd0
3@l:00X<2@0J71T0:B/X07eoO00:30T0004000lA3P0;3@X03Q0=01@F4`0A4a0030h;014B3@0O81/0
4A8=00X;1P0A4Pd0414<00X;1P0<3@P01@H1014B3@0L7AP03@h9010@3P@03`l=00d0410>00d=2`0?
3`d04Q8@00X:200D5180=3Da01dN6@0;30L0414<014B3@0?40/02``700H03@h900H02``700d>2@0A
4Pd03@h900/<1`0>3`X200d>2@0400`=200=3PT03@h900h>30803@d=00H03Ph>00l?3`0?3`l03Ph>
010@400;2`/200d=3@0E00P8200A4Q004Q@A01@F4`0620D01`T600lA3P082PL02`d:00d?300?4@h0
5ALD01LI5P0E5aH03Q0?00T;2P0?4A004Q@C00`>3@0?4A003Q0?00803@l>01403Q0?010A4P041@T0
2@X?01/L8@0?41D04A8G014B5P0D5AT0FeaP01PI7@0@4A<04a@F00d>400720X01PL901<D5P0201@E
5`0C018C5@0@4A<03@h@014B500<3@l04A8D00/<3P0?41@051DJ00l@5@0;314030dB00/<4@0C51T0
2P/@01DF6`0I6Ql07AhS01/L8@0Dooooo`006oooool04P0;21403@/B018C5`0H6A/03aD@00/B2`07
3PH03aD>010E3`0B4Q802@P:01LE600B4AH040lD00l>4`0=31402@T<00T92`803Ph@00H03`lA014A
4`092@T030`<014A3`0@40h300l?3@07010@3P0=3@/04Q8@01@D4P0M7A/030`:00l?3@02018B4P0;
01<C4`0D51@05ADG01DE5`0B4Q@051<H01<B5`0B4AH04a8H01@C600A4QD00`0A4Q@2014C4P0:018D
4`0@4Pl04A<@014C3P0@4Pd03a@@00`B400>4Q40418B018B4P80518C01/04Q0A014A4@0H6QT06QhM
014G5@0>4a@03A0E01TM800U:B`061`O00hB4`062P/07R8S00`@3`0U:BP05QXI00T=300G6a/06AdN
01<G600@51D04QHG01@H6@0F6Q/05a/L01PL7@0F6Q/00P0B5QL01@0E6Q/05adM01DK6`0@5QH03Q@D
00806AlO00L05A/K01@J6P0D6QX041HF018H600E6AP04aLF008041@C01d04ADD014E5P0;3a003a<D
01LK7P0J7R406AdP01@H7@0J8B/051dV014H800D6Ad05Q/N01@H6@0<4A@04QXM010I8P0>5bH062<e
01<P<`0S;3/07BLc01LQ;@0C7BT05AlZ01lY<`0S;CH06B</01HP:@0201/V;00?01@O9@0D7RL05AlX
01XT;@0K92/06B8Y01lX;`0E72806B0V00`C6@0I7R806QlS01HK7`0I7B0061`O00@05QXM0P0G6ah0
100H71l06AdP01`P8`0M8B@201XO8P0C01`Q900I7R405AXN01PM8@0J7bD06b0V020U:`0B5Ql05QXS
01<G800>4aT04AHL01XO8`0K82@041DI00`A500F6ah041DH010F5P0201@J6P0f01<I6@0@5AP04AHI
01<H6`0G7b807BDX01lW:P0J8bP00``A00dF6`0?6R007RT_018K8P0B61h041DK01DJ800N8bL06QlS
01@I7@0F6ah03A<C018H600S:BT07B<S01<K600F7aX01Pl>02/c=00H82<05ahV01@K900J8B/05A`V
00dD7@0R:C40K7=i03Y1AP0@61/03QHH01TR8@0P:BH0624L010I5@0@6AH041TH018J7@0D6b404QTS
018H7`0A5QX03a@G018H600C6AL041HB0P0A5a<02P0@5Q@04ALG018G6P0L8BD03QDM010G7`0E72@0
51/Q00dD6P063A<200/C5P0:02H^<017Ce403ADG01<K7@0:3a801P/>01XO8P000@@06b0S00X?4P80
3Q<F0`0?51L01@0@5QL03a<D00dA400A5A@051PG00<041@C00H03A4@00/?3P0A5A@04aLF00lC4P0>
4`l2014F4P05010E4@0?510041DA018G4`0?51000P0;40`00`0>4`l04AHB014F4P05014F4P0G00hC
3`0?510041DA010E4@0?51003Q<?00dB3P0D6AD03a@@00dB3P0J7a/09R/W01dR7P041`@0314=00lD
400D6AD05AXF01<H500G71P05Q/G00`A3@0A5Q800P0=4Ph04P0@5A40314=00dB3P0B5a<04QPF065[
JP1SKVX01Q4;01DQ60033`<03QX@00TE300;5Q804A/L00dE7P0841d03Q@P00P<3@807B4P01D041@C
01XO6`0>4`l04QLC00lD3P0=4P`03Q<=014F3`0B5a002Pl901DJ50011P0061dG00dB30042@@05AXD
00X?2@0=4P`04QLA00D:100A5Pl00`0<4@X00`0>4``041D>00hC300200hC300400dB2`0@5@h041D>
00dB2`802a0901403A8;00hC300=4P/02a0900T>1`052P<00PL102T^9`062`@020`601HI4P0H6a@0
3a8;00X=1P0;3PL03Q4:00lB2`0200hA2P0D00lB2`0@4``041<<00hA2P0930D01PT200`?200L7aP0
3Q4:00d@2@0>4@X041<<014D3@0>4@X000<001<F3`0H6a@05APA01dP6@0E614600lB2`0400d@2@0>
4@X03a8;00lB2`803Q4:00`020/400T<1@0=40T04A@=010C300;3PL05QTB01LJ4`0>4@X03a8;018E
3P072P<200/>1`0:00`?200=40T041<<014D3@0J7AH01`X401<F3`0V:B80Bdi700T<1@803a8;0P0>
4@X03`0?4P/03A8;0046000Z<2X00`P2010E3`062@@030h900T;1P0;3@P071dH02X[9P0S91l030d8
00h?2@0300l@2P803Pl901804Q<=00d>200D5@l0?3dg0;Ff/00P8A/04a@>020Q6`03100051D?01<D
3P0@4@/03Pl900d>200A4P`04Q<=010A2`0A4P`200`=1`0:00h?2@0P8A/03@h800h?2@0?40X03@h8
00h?2@0A4P`0414;00h?2@802P`701002`d800`>2@0<3PT03Q0;00X<1`0H6QD03Q0;06EWHP1cMG00
3a0;014B300>3`T03a0:01@E3`0A4P`03@h80`0?40X02@0>3`T03@h8018D3P072@@04A<>00X<2@0F
61<03a4<00L81@0200`>2@0G00h@2`0?4@`03@l:00hA2P0?4PT03A0700`?1`0<3`P03Q4:00@60@0>
40/04A<@02X/:@0T9R<02`d:00X<1`0<3PT03a4<010B3@0=3`X02@/600`>2@0:30L00P0;3@P0;009
2`H03a4<00`>2@0O8A`01@L200H80`0E5a80418=00d?2P0<3PT0418=00/=200C5A003@l:00d?300?
4@h04A<@00h@3@0<3P/0418?018D4@0:30T03a4>01HH5@0C5A802P`900`>2@0?4@`02P`700T;1P0=
3`X02`d800P:1@0@4Pd02P`700P:1@0?4@`02@/601<D3`092PD03@h9014B3@0>3`X0414<100=3PT0
=@0@4@`04A8=00/=200A4`h07R0K01TK5P0F61<02`d800T;1P0I6aH03Q0;00/=20092`H030h901<E
4P051`@04aDB03i0?@072@H061XG00h@3@0:30T0418?01XL6@0C5A802`d:00h?2P0H6A@04Q<>00/<
1`0B4`h05QLB01@E40010P002P/600P91@0A4Pd00@80014A3`0>3P`03@d;00h>300@40h04Q8@014A
3`0>3P`03`l=00/;2@0F5Q@0<c@`01DF4@020`004A8=0080414<1`0?40/01P0<3@P03Pl:018C3P0>
3`X030d800h?2P803@h900D030d800d>2@0=3PT03Ph<00d=3@0300h>3P0a00l?3`0A4A403Ph>00T9
2@0I6AT061PH00/;2`0:2`X03Q0=01LI5P0;3@X0418?01@F4`092`P03@l<00lA3P0C5A806Q`I01dO
700S9B@06A/J014C4P0I6aX07R0O01LI600@4Q403@l>00/=300=3`h03a4@00`>3P0J6al01`P=014B
5`061``04a@I01@E6@010PH01PL;04E6BP0=3Q804Q<G00h?4`0D5AL04A8D00/<3P082@/02``>00D6
200200d>400401<D5P0=3Q004A8D00l@4P803a0D00@04A8F01TJ7P0L7B404A8F0P0>3a<0100G61`0
4a@H00T:3P0<3A4Dooooo`006oooool01@091Ph03`dC00P92`0>3a403Q<@00802a8;01D02a4:00<7
0P0?3`d04A0A00h<3P0<30l03PhA00h=4@0<30l03@d@010@4P092@/0;2`^00l?4@0=3@l0410A00h>
3P0?3`d03Ph<00d=2`0>3P`00P0?3`d0200A4@l03Ph<00<30@0?3`d03@d;018B400?3`l04A4A0P0B
4Q802@0@41803Ph@010@4P0C4QL04Q4F00h=4P0?3Q@04Q4G010A5@02010A5006010A4`0@4Q80418B
018D4`0A4a0051HC0P0A4`l0700B5Q@03A<A00hB4@0A4a804a<C01@B4`0E4a@05aDF01@D500E5aH0
7b<R01XP7P0=4Q@02`hC01LK7P0H71l0310C01LK700S9bP061`M018F5@0<40l06QhM018F5@0J7Qh0
720Q01HJ6`0C5aP201@H6@0c01DI6P0G6a`06AdN01TM7P0F6Q/05a/L01PM7@0E6a/051XJ01<I6@0E
6a/061hN01@J6P0A5aL04QPH01@J6P0B61P05A/K01DI600F6QT051PG00lC4P0>4Q4051PI01LK700@
51D07b<V05YNH@0Z;S40?d=901<J8`0A6R<041LN01@I7@0E6Qd05QXK01`Q900@5a`051dV01dV=@0H
8cD0524d02@]?00L9S8051hZ018L:00G8B`08R`f01dW<00J92d05b4Z00805b8X01005B0V01HP:@0H
8R/07BL`01dV;@0I8RT07BH]01HM8`0Z<CL061lU01PM8@0G72005AXN01/O8P0J7R4061`O0`0G6ah0
0`0D61/05QXM01PL7`0201TM800401PL7`0E6Qd06AhQ01XO8P806AhQ01<06QlS01TN900H7B<061dS
01LK900>4Q/061`U01LK8`0N8R`0:Rlf02X_=@0J7b@051TN01DJ7P0G72005AXM014G6@0C61/05Q/N
00<04aPK00X04a/M01@L7`0E7B005AlR00lH7@0F7b@04A`Q01DP9P0@6B005adS0P0J7bD0?P0J7b<0
5a`P01HK7`0F6ah05Q`L01DK6`0W;Bd09B/[00lG5@0L9B8072DT08RATP11BD`04QTQ01LN9P0>5Ah0
2a8K02L^=P0i@4H061lU01HN8P0=5AP03ADG01@L7@0H8Al04a`J018K6@0E7Qd05AdO01@K800A6200
3aHP018H7`0@5AT03A8E014G5`0E6aT04QPD00lE4@0>51003aDC01<H6@0>4aH04AHJ018I8@0C6R80
4QTQ010G7@0A61h05A`R01PP8`0;4aH031@F00XB500X<3808RX/00hC5P0L8B@03A8E018G6P0:3A00
5AXM1@0?51L0400?5AH03a<D00hB4@0C5aH05ATH014E500@51<03a<B01@H5`0C5aH03Q8A00lC4P0>
4Q402a0<010E4@0A5Q8200dB3P04010E4@0B5a<04AHB00lD40<03Q<?1P0@5A405@0=4Ph03a@@014F
4P0A5Q803a@@00dB3P0G71P061dI00lD400<4@d041DA014F4P0E6QH03a@@01<H500B5a<092TU020U
8@0E6QH0314=014F4P0201<H500300T>2P0>4`l041DA00804AHB01D03a@@00dC3`0>5a802Q@=014L
4`0640L03AP?00LA300>5aP02Q8J00`C8@093RD05QXg02T]@`0b=cX010P700hB4@0@51<06QlK00L;
200?51000`0?50h200lD3@803a@>00X061dG00T>200=4P`04QLA00X?2@0A5Q003a@>00X?2P0>4`d0
314;0P0>4``0100<4@X02a0900dB2`0?50d300hC300900dB2`0<4@X0314:00`A2P0=4P/03Q<<00lD
3@0>4``0314;00803a@=00`0314;05iSG00[<2T04QH?010C300B5@h04A@=00lB2`0B5@h04aH?010C
300?4P/200hA2P0500lB2`0=40T041<<018E3P0@4``00P0?4P/00`0@4``03a8;00lB2`02014D3@03
00hA2P0B5@h04A@=00803A0900<03a8;00/>200@4``0100?4P/00`0@4``03A0900hA2P0200lB2`80
3Q4:02`02@`500/>1`0@4``04QD>010C300<3`P03a8;02<V7`0F6A802@`500hA2P0?4P/04QD>010C
300>4@X03A0900lB2`0@4``02Pd600hA2P0<3`P051L@020S7@0;3PL04aH?014D3@0>4@X03A0900lB
2`0>4``0314;00T?2@0;40X03a<?00d@2`0>40/0418=00`>2@0=3PT0414<018C3P0>3`X03Pl900l@
2P80414;00/03Pl900d>200A4P`051D?014B300A4Pd04A8?018C3@0?40X02``600X;1@0201<D3P06
00L81@0@4@/03Pl900l@2P0A4P`03a0:0P0=3PP0100D5@l04Q<=02LX8P092P@2010A2`803Pl90180
414;00l@2P0=3PP03@l:010B3@0=3`X02P`700`>2@0@4Pd03@l:00`>2@0@4@d0F5YE05MIE00;30L0
30d700h?2@0=3PP2010A2`8030d701403a0:018C3@0B4`d04A8<00h@2P0=3`X061XE00`>2@0B50l0
2`d800lA3@0<3PT02@/600X<1`0=3`X03Q0;00hA2P0200hA200:00lB2P0?4P/03Q4:01HH4`0Q8ah0
3a4>020R7`0J71T0418?00`>2@<03@l:00@030h900/=200@4Pd03Q0;0P0A4`h09P0<3PT03a4<018D
4@0?4@`030h9018D3`0A4`h0;S0[02PZ9@0B50l04A<>00lA30082PD02`d8010B3`0D5Q<05ALD00h@
3@0;3@X03a4>00d?300;3@X04aDB01LI5P0A4a0030h;010B3@0>40/0418=00h@2`0;3@P04A<>00lA
300=3`X01`T400/=200A4`h030h90P0>3`X0100B4`h04A8=00/<1`0>3`X2010A30803Pl:02H03@h9
00`=200:30L02`d801@F4@0?4@`04Q@?00`>2@0@4Pd020X600h@2`1KGEP09bTT00`>2@0?4@h02P`9
00d?300A4a003Q0=00L91P0?4@h03@l<00h@3@0@4Pl03Q0=00`>2`0?40/05aPC01XK5P0A4Pd02``7
010A300<3@P03a0<014B3@0B4`h020T5014B3PH03@d;00L030`:010@3P0C4a403Ph<00/;2@0A4@h0
2P/60080414<00<02``7014B3@0@4@`01@0>3`X01`0?40/030d800d>2@0A4Pd03@h900`=200@4@`0
0P0?40/0100>3`X03a0;00l@2`0?40d500h>3P1200l?3`0<30`030`<024Q8@0H61P02`/;02PY9`1K
GEX0Gf5N01LI5P0720H03a4>00`>2`0?4@h03Q0=00d?300B51404aDB014C4P0=3`h02`d<00h@3`0@
4Q403Q0?01<E500?4A0030h=010B4@0A4a8030d>00`=4@0D5AT0A4E:01HG700;31003a0D01DF6P0K
7200C4eA01hO8`1lOH406Q/O00h?4@0C51H02@X<010A4`0C51H04Q<E014B500=3Q005AHH00l@4P0A
4Q@04a@F01TJ7P0;2`l02``@01hO8`0U9RX03a0D01<D600@4AD02@X>01DF6P0D5AT0414E5?ooool0
01_ooooo00d05A8I00l=4`0D5AT06a`N010E500?5A402Q0<00hD3P0?50h010@200h=3@0<2P/04Q8D
00809BDW00X05QHH00/;3@0=3@l051@F014A4`0?3a404A4C00X:300>3Q0030`;0P0;2`T0400<30X0
3@d;00h>300?3`d05QHD00T91`0D51803`l=00d=2`0A4A404Q8B01<C4`0B4Q803`lA00h>400A4A<2
018A5P03014@5@0B4AL04a8H00<03a0D0`0?41802P0@4Q4051HE00lA3P0=3``0418?010D4P0?5A<0
41@C018D4`0B4Q8201<A4P0J01@B4`0B4Q804A<B01TM700H7Q`07b@U01DH7@0@51L061`O01<G6P0E
6AX07R8S00<7200A5A@05a/J00dA400E6AP04aLG010D5@0?4a@04QHG01<G600B5QL041@E014E5P0D
61T201DI6P0601HJ6`0E6Q/04aTI018H600G7Ad0728R0P0F71`2018H600401<I6@0@5QH04QPH010D
4`804aLF0P0?4a80<`0F6Q/0<3@e00lC500N8RD041@G01@H6`0=41H041LO00lH7`0B6Al051TM01DJ
7@0G6ah06b0T02@[<@0L92d08R/j03M3D`0J9cP08BXi01TS;`0C7BT05Al[01TS;P0Q:cD06bD^01hX
<@0L9Rl062<Y01LR:00I92X04Q`U01hX<@0^>440;3Dl01/T:`0A6R403aHL02H]<`0K8RP06b0T01DJ
7P0H7B405QXM01LK7P0I7B006alR01hR9@0P92L04QHI01DI700201PL7`0301LK7P0E6A`0314D00<0
4aPK0P0G72004P0Q9R`06AhT00lD6P0E6B804ADN00lC700L82/06QhY01`P:`0K7bT06QhW01hS:@0A
5Q`06AhT01PM8@0D6Ad05a`P01dR9P<05AXM02D051`N01@L7`0D71l0218D00`E6P0>5a`041/O01@O
9@0F7bH06AlU01lT:P0K82H04aPL01DJ7P0J7b<05AXM01TO7`0A5aL051XJ01<I6@0B6AP05b0M00L@
3`0Q:BX02a<F01DL8P0A62003QDM01PO9`20Qhd0inob04I>D@0E7B004ATL01<K7@0A6QX03aPG0080
4AXI02<041PJ018J7@0C6R404APP018I8`0C6B004AHJ010E600C6AT05A/I01<I5@0G7AT061hJ01<I
5`0@5AH03Q<F01PM8@0=51`03QDM01DL900?5Q`01@`B00hE6`0;4aH051`O02Xb=00V;S00PHV;05aT
IP0?51L00`P;01HK7P0A5QT08bP[05QMH002010E60<03a@G00D03Q@E00lC500=4A004ADD01@H5`02
010D4`03014E500M8B007R8Q008041@C00@04aLF00`A3@0>4`l03a@@0`0=4Ph01P0?510041DA014F
4P0A5Q803a@@00dB3PH03a@@04803Q<?00lD400@5A4041DA00lD400>4`l03A8>00hC3`0<4@d03a@@
014F4P0:3`/03a@@028W8`0J7a/03Q<?02DZ9P0L8Ad03Q<?010E4@083@T02a0<00T>2P0H7AT0314=
00/@300@5A404QLC00`A3@093`/031D=01XT700?6A003QP?01DN6@043@X02A0E00lE8@0=4RD02@dX
01DH>@0O8c`0<C@h00040`0=4A002Ph=00/@300:3`/03A8>00lD3P0A5Q0041D?00dB2`0<4@X01@X5
01lT7P1BEe406b0J00X?2@0>4`d07R<M05IKE@14BD<04AH@024V800@5@h2014F3`0;00`A2P093PL0
314:010E3P0>4``03A8;00hC30093PL020d600/@2@0=4P/00P0?50d02@0=4P/03Q<<01<H4@0>4``0
4aPA010E3P0D6A80008000lC300200`?200500d@2@082`@02@`500hA2P0?4P/00P0>4@X02@0?4P/0
41<<00P;10082`@02@`500X=1P0;3PL03A09010C300200lB2`8041<<0P0=40T03@072P<04aH?01PK
500930D03a8;014D3@0@4``03Q4:00d@2@0>4@X04A@=00d@2@0>4@X00P0?4P/300hA2P0;010C300B
5@h041<<00hA2P0=40T02`h700hA2P0:3@H03A0901@G400<3`P00P0?4P/400d@2@0I01PK500=40T0
1PT201dP6@0<3`P03A09014D3@0@4``03Q4:00d@2@0>4@X0314:00L<1P0>50d05AXD00D:100F6A@0
5ALB00/=200A4Pd0414<00`=200>3`X05AHA00d>200300h?2@803@h80280824K01@E3`16Ad404Q<=
01<D3P0B4`d05AH@00d>200F5a4020T4010A2`0H6A<030d7014B300?40X0414;01<D3P0B4`d03a0:
00`=1`041@003@h800H70@0C50h03a0:00d>200>3`T04A8<010A2`0>3`T030h900lA300=3`X02@/6
0P0;3@P02P0F61<03a4<00`>2@021000004000l@2`0F5a406a`F010A2`092P@200`=1`0300/<1P0>
3`T04Q<=00804a@>00P0418<014C3P02100061XE079dK`1?DD`06A/F00`>2@8020X501403@l:00lA
300?4P/03Q48014D2`0C5Ph04QD>00hA2P0?4@`06Q`G00lA3P0A4a0030h;00h@3@0?4@`03Q0;00`>
2@0200/=200300d?2P0B50l03@l:00802`d801d030h901LI500c=C002`d800d?2P0;3@P03@l:06U[
IP1ZK6L0;BlZ00X<1`0D5Q40418=00/=20082PL02`d:00d?300;3@X02P`900lA3P0>40d06A/H01PJ
5`0A4a003Q0=00/=2P0>40/02P`700d?2P0200lA300:014C3P0?4@`030h901DG4P0D5Q4020X500X<
1`0720<030d800d>2@802``700<03Pl:00d>2@0=3PT00P0=3PT01P0@4@`04A8=010B3@0:30L02`d8
00H80`803a4<01<02P`7024S7P0O8A`06adH01@F4@0C5A0030h;00<50P0a<c001PP601HH5@0E5a@0
3Q0=010B3`0<3P/01PP500P:1`0=3``0414<00803Pl:00h030d800h?2P0C50l09BHQ09^LU`0P8A`0
20T6014B3@0T9B003Ph<010@3P0B4Q004A4?00h>30<03@d;00@03Ph<00l?3@0@40h04Q8?0P0B4`h0
10061`<03a0;01@E400:2`H500d>2@0400h?2P0<3@P030d800l@2`8030d800@03a0;00d>2@0=3PT0
30d80P0=3PT00`0?3`d03`l?00h>3P0200h>3P0A00d=3@0?3`l03`l?00T92@0=3@d02`/;00`<300E
5QD08R@Q02la;P0>40d020X701<E4P0;3@X03Q0=00d?300<3P/00P0@4Pl0<00=3`h0418A01@F5@0B
51<0418A018D4`0A4a803a4@00h@3`0A4a804Q@C00h@3`0I6Q`03@hB02@U:@0A4QH0414E01HG6`00
00@061TM02PY;@010PH0ATM;01LH700>3a405aPJ00T:300@4A<030d?028S9@0K71h03@h@01@E5`0?
4180414C018C5@0@4AD04a@H00`=4@092Ph03@hB00l@50041@T04a@H014B5P0B4aL01PL;02PY;ACo
oooo000Kooooo`0?00l=4P0A3a@0414E010A4`0/<Bl0GVAP03<i=@0@5A407b@P00/;2@0>3@/02PT7
00410@0K6a/0:b/[00806ATK00P0AdM9018B50061PT04A0E00h=4P0:2@h030`>00`<2`8030`:00/0
3@d;00h>300?3`d02`/901HF500820H04a<A00l?3@0:2PP03`l?010@4002014A4@804A4C00H05ADG
018A5P0A41D04A0E00h=4`0<2a4400l@50803a0B00X061TJ01hP7`0A4a803a4>01@F4`0?514041HD
014E500B51<04Q8B0P0B4140200C4A804Q8B014C4P0D61L05adK038g>00U:2d03a<F0P0=4A@02@0G
6a`05ATJ00X>3`0@51<0720O00dA400?4a8041@D018F5`0201@H6@<04aLH00`051PI01HJ6`0G6a`0
5ATJ01HJ6`0D6AT051XJ01<I6@0E6a/06R0P01PN7P0E6a/2018H600501<I6@0@5QH04QPH01lS8P0J
7Qd00P0C5aH0;00E6AP05ATJ01`P8@0?4a@04aLJ00<72P0O8bH07B4V01<J8P0C72<051/Q01DJ7P0C
61/051PK01lT:00a>3h09blh02`f@P1=FFT0;S]<020Y>00I8bl05Al[01PR;P0I8bh072H`01dW<00L
9Rl06bD^01XU:`0H8bT05R4W01HP:@0N:340:C<l02Pa>00J8bX05AhU014H7P0G7R@04QTO01/P900E
6Qh061dQ0P0G71l0100H7B006AhQ01`Q900N8bH201@I70805AXM0P0F6ah04`0=4QD05AXM01<H6`0C
61/05a`O01DJ7P0R9bd06AhT01DJ800G6b@07B4Z01lS;00G6bL06QhZ01/O:P0D62<04aLR01PL9@0H
7B@00P0G72801`0F6b404aPN018G6`0E6Q`05A/K01HL700D71h00P0C6ad0;`0G8B<0628T01DO8@0D
7b<041/O018K800E6b406AhT01PM8`0C61`051TM01LL800G71l061hN01HL700B61P04ALG014I5`0D
7AX06B8Q018K700@61/06B0V018I800F7BD01PdC05AKH02_]kT0=Cdo01@L7P0E7Al05alQ01DM7`0B
6Q`04a/M010H6P0>5QT04ATL018I800@5al04QTQ018H7`0A5QX04aPK01HL700E6aT04aTE00806AlK
01@05A/I018H600A5QT0724U024X<00C6R803A@L00`C6@0B6Al0B4mE01XR9@0I8B@04QXL00H>400/
=3H0:C4c00dB5@0X;C001PX=00hC5P803a@G0`0@5AP03`0?51L03Q<F00hD5@0@51D03A4@00lC4P0A
5A@03a<B014E500=4A006AdL01XN7@0@51<04aLF018F5@0300lD4004014F4P0@5A403A8>010E4@80
3a@@00<041DA014F4P0A5Q801P0?51001`0@5A403a@@00hC3`0>4`l03a@@010E4@093PX00`0>4`l0
100B5a<03a@@01/P700B5a<200`A3@08020U8@0@5A4020d9010E4@0<4@d08RLS00L<200G71P200dB
3P0H014F4P0?51003Q<?01<I5@0?5a400P`400<=1@0@6Q801a0;00XC400;51D05A`T00`B7P073200
310Y00/@8`0?4aH061`K01`P7`0=4A002Pl;01@I5@0>4`l03Q<=0P0?50h200hC300B00lD3P0C6180
7b@N00hC3@0@5@l0314;00lD3P0i?SP0;34[00870@0>4`d02a0:010E3P0A5Pl03A8;00X?200>4``0
4QL@0P0;40T0500>4``02@h700T>1`0=4P/03Q<<014F3`0?50d0314:00dB2`0>4``00`P10087000C
614051TB00lD3@0G6a@041<<014D3@0E61404A@=0P0B5@h200hA2P0600lB2`0@4``04QD>01DH4@0C
5Pl041<<0P0?4P/0100@4``03a8;00hA2P0>4@X200lB2`0?00/>1`0<3`P03Q4:01<F3`082`@00080
020S700A50d041<<00hA2P0=40T03Q4:014D3@0=40T03Q4:00803a8;0`0>4@X2010C308030l800@0
3a8;01DH4@0>4@X03A090P0B5@h00`0:3@H041<<010C300200lB2`0300d@2@0<3`P01@P1008020/4
00@04A@=00T<1@0G6Q<03A090`0>4@X02`0=40T02Pl801dR6`052P@061dF00hC30072`D01PT200L:
0`0>40T04A8<00803a0:00@0414;00h?2@0=3PP030d70P0=3PP01P0>3`T07AhH024R701EEU003@h8
00`=1`802P/500T03@h800X;1@0H6A@00`@000T:100>3`T05QLA014B300<3@L00P0?40X0100=3PP0
3a0:018C3@0@4@/200`=1`0300h?2@0=3PP03Pl900804A8<01D0414;00/=200<3PT030h900/=200<
3PT02@/601TK5P0@4Pd02`d801TK5P0@4Pd04A<=01/L5P0P8A/04a@>00/<1P0>3`T03a0:00h?2@0?
40X00P0B4`d02`0A4P`03@l901@F4@0J71L020X5024S7P0B50l020X500/=200:30L030h900803a4<
00P03Q4:00hA200@4`X04A@<014D3@0@4``010H100d?2P805QPE00<0418?00X<2@0>40/00`0>40/0
0`0=3`X030h900lA300300`>2@0400/=200D5Q40008000T;1P8051HA00/0418=02DW8P1?DD`0:2XU
00d?2P0?4@`04aD@00h@2`0<3P/03@l<00h@3@0200lA3P0;014C400:30T06adJ01<E4P0=3``04Q@A
00T;200>40/04A<>00h@2`0=3`X00P0A4`h0100@4Pd03@l:014C3P0A4`h200X<1`0Q00X;1P0<3@P0
2P/600T:1@0=3PT0414<00h?2P0=3PT02``700`=200@4@`04Q<>00lA300;3@P03Q0;00P:1@0>40/0
30h900L910072@D020X500lA300D5Q403a4<01/M6P0Q8b00Ngej018D4@082PL00P@100h@3@0?4@h0
3Q0=00802`d:00D030h;014B3@0?40/030d800h?2P0201<D3`0300`=200n?cX0004000805QLB00<0
004000l?3@0?3`d00P0@40h200l?3@0<010@3P0<30X02`/9010@3P0B4Q004A8>00X;1P092PD01`P3
00l@2`0D5A003Pl:1@0?40/0100@4@`03@h900d>2@0@4@`200d>2@04010A300=3PT03@h900`=2080
3@h900@03`l=00l?3`0?3`l03Ph>0P0=3@d0400@410051@D00`<300:2PX03Ph>010@400F5aH02P`9
018D4@0E5a@05aTF00`>2`0>40d0418?00lA3P0>40d2018D4@8020X90P092`X07@0:30/02`d<00`>
3@0=3`h03a4@010B4@0?4A003Q0?00<41P0720X05AHH00831`0C51P0FeaP02LX;00;3100EUML01<D
6@010PL051DJ00l@4P0G61X02``>01`M7`0X:B/0HfAV02DV:00>3a404A8D00803a0B00d0414C00T:
300A4Q@03PlA00/<3P0?41804Q<E01HG6@0A4Q@06a`N01lP8P0J6ad0P86301Cooooo000Kooooo`0I
014?4`0E51P04Q<F01LH6P21QXH0l_Of08jDTP0I7a/05a`H00X;1`0>3P/04A0=010@3`0:2PT03`l>
00h>3`0C4aD0;Bd_00l?4P0D4aL051<H00d<4@0B4AH03PdA014A400200/;2@0=00l?3@0@40h03@d;
00l?3@0D518020P6014A3`0B4Q003@d;00`<300>3Ph03`l?010@4002010@4P0600l?4@0:2@h03PdB
01DD6@0A41H05A@J0P0@4AH0:@0?41D0414E014B5@0B4aH07b0R01lQ8@0M7ah04A<A01@F500@5180
3aDC010D4`0B51@04A4A014?400D4Q<05Q@E01HF5P0G6AP061`K01/Q7`0L8B<03a8G014E600J7R40
5ATL01DI6P0B5QL07B4R01<G5P0A5A@03Q8A010D4`0B5QH05QXK01<G600D61T03Q8C01@H6@0A5AH0
4aLH00<05ATJ02L051PI018G600E6a/04ALG01PN7P0D6QX092XZ01/Q8@0;4A404aTI01PN7P093@d0
61hN034e=00W:bX05a/J01@H5`0F6QT04aLH01/O800B5QL04aLJ01TM80093A005ATN01lV;00L9B/0
82L]01DJ7P0C61`05QTN01DJ800J8BT06R8/01LQ;@0N:SP05R<c01lX=`0M9c<00P0I8bl05`0K9C00
7BLa01/U;P0O:C8051hW01PS:@0K9R`04QdS01PR:`0I8b`051hW010I800C72<06R<Z01XQ9`0F7B<0
31<I01XO8`0G7200<cPl030g>@0L8bD05ahP00805A/N04T051XM01DL7P0C6Q`04QTK010G6@0B61X0
41LI01DJ7@0G71l051TL01DJ7@0I7R405Q/O01DJ800@5A/05Q/Q01/O:00W:c@0;C4j028V<P0[;c/0
;30l01`P:`0G6bH07R8]01LK900C61h05AXP01PM8`0C61h03Q<G01LL7@0I7al05adM018J6`0@61X0
3aLI01DO800>61X07bT[03Q3AP0;5QT05b0T014G7@0D6Al05Q/Q01LL800D6Ad04aPL01@I700B61P0
5A/K01TO7`0L8R804ATG00lH5@0E7Qd03aLJ01@L7`0C6R0041LN01LN900B6Qh06B4S02</:`0N9bD0
8b`[01dU9`0P:2X04a/M00lG6@0B6Qd03A@I00804APO02T041LN010G7`0A620041HL018G6`0F6ah0
5Q`L018H5P0A5a<04QPD010F4P0@5Q@04aPI00hC5P0E6Qh04APP00lF7P0K8RX06b8X00hE6`0J8BL0
1`lB00lG6P0@61X072@V00T?4@0@61X03a@G00T>4@0A5QT041DH01TN8@0B5aX03A8E01@I700A5QT0
<CHi01LL7`0=4Q@03A4B00hB4@02010D4`0400hB4@0A5A@03Q8A00lC4P8041@C00@04ADD00dA400B
5a<04AHB0`0@5A40200?51003A8>010E4@0;40`03a@@014F4P0@5A404aPD0P0>4`l00`0?51004aPD
00T>2P0200hC3`803A8>00L041DA018G4`0@5A405AXF014F4P0<4@d03A8>00804AHB00/04QLC00hC
3`093PX04AHB01/P700=4Ph03a@@01DJ5P0`=C404AHB00hC3`02018G4`08014F4P0?51004aPD01XN
700M92804ATF014I5@0:4P/200hF3`0I01DM600F7Q/04a/I00`B50073A402PlC014E5@0<40l02@d<
018F5@0@5A40314=010E4@0=4P`0314;00dB300=4P/03Q<<00dB300A5Q0020/700lD3P0>4`d03a@>
00hC3@0200lD3P0300`A2`0?50h041D?00803a@=00@03A8;00`A2P0?50d041D>0P0;40T04`0=4P/0
2a0900/@2@0<4@X04AH?00hC300A5Pl02@h700hC300@5@h04aPA00lD3@0:3`P02a09018G400D6140
4aH?00hA2P0?4P/00P0<3`P01P0?4P/041<<00hA2P0>4@X051L@01<F3`803A0900L03Q4:014D3@0C
5Pl04QD>010C300?4P/03Q4:008030l800T03A0901DH4@0D5a003a8<00`?2@0M81T0NGae018E3P0?
4P/00`0>4@X01`0?4P/02Pd600d@2@0>4@X020/600d@2@0>4@X00`0?4P/02`0=40T03Q4:010C300=
40T030l800hA2P0?4P/03A09010C300D5a004QD>00803A0900<041<<00lB2`0A50d00P0>4@X03P0?
4P/041<<00hA2P0?4P/04QD>00`?200=40T04QD?00D:10083@D03aD<01<H400:40L04AD=0P0>4@T0
1@0?4@T0414:010A2P0@4@X03Pl800803Pl901<030d700l@2P0<3@L03@h800h?2@0A4P`04Q<=014B
3@0B4`d03a0:00`=2@0G61803a0:03`m=`0L7AL04A8<01DF400I6Q@051D?00<03a0:00L04A8<00h?
2@0A4P`03a0:014B300=3PP03a0:00803@h800H03a0:014B300@4@/03Q0;00/=200=3`X200lA300=
00h@2`0=3`X02P`700lA300=3`X02P`700h?2P0C50h051D?00l@2P0<3@L03@h800h?2@0200l@2P08
014B300B4`d04A8<00h@2P0<3P/03@l:014C3P092`H200d?2P0M00X<1`0=3`X03a4<014C3P0@4Pd0
3Q4:00T<100@4`X03a8:010C300?4P/03a4<00h@2`0];b`00`D2010B3`0A4a003Q0;00`>2@0=3`X0
418=00h@2`0<3PT02`d8010B3@0D5Q403a4<00`>2@0@4Pd00P0A4`h03@0=3`X05QPC00`>2@0@4Pd0
3Q0;01`N6@0P8Qd02`d800`>2@0@4Pd04Q@A010B3`0>40d00P0=3``00`0?4@h020X701DG500200/=
2P0601<E4P0D5Q<03a4<014C3P0<3PT02P`70P0<3PT0?00A4`h03a4<00X<1`0:30L0418=018D3`0?
40/03Pl:00d>2@0;30L03@h9014B3@0F5a803Pl:00X;1P0A4Pd0414<00h?2P082PD0418=00/=200G
6A@03a4<00T;1P0<3PT03Q0;00`>2@0D5Q404Q@?01LI501EEe@03@l<00`>2`0@4Pl051HC00`>2`0=
3``03Q0=010B3`0A4a003a4>00d?300>3`X02P/701<D3`0>3`X04A8=00T:1@0=3PT0414<00l@2`0=
3PT02``700l@2`0@40h03`l=00d=2`0<30X03Ph<014A3`<03`l=00h0410>00h>300@40d06AXE01@E
400@4@`030d800/<1`0E5Q402P/6010A300C50l04A8=00l@2`80414<0P0?40/02P0@4@`04A8=014B
3@0?40/03Pl:00d>2@0>3`X03a0;00l?3@0>3Ph200l?3`0400h>3P0=3@d03@d=018B4P803`l?00D0
4Q8B00h>3P0>3`h02@/800`>2`0200X<2@0g00h@3@0=3``05ALD00/=2P0:30T030h;00h@3@0C5A@0
4Q@C00d?3P0>40l02`d<010B4@0>40l030h=02@V9@0@4Q402P`;00lA400@4A803a0A018C500A4QD0
414D00l@500:2a005QLL01@E6P0B4aT05AHL00l@5P0<3A404a@F00h?4@0B4aD03a0B02PY:`0O8280
414C01HG6@0<3@l0414C00X;3@0@4A<03PlA00d>400A4Q@04Q<E00X;3@0B4aD03a0B03Df>010@D<0
4Q<E020Q8`0Dooooo`006oooool04P0?3A003@`?014B500:2`d0B4e=08bBTP1?EED05Q/J00X?2`02
0`004a<?00l>2P0<30X03`l=00/;2@0<30`04a<D014A4`8040lD00H03PdB00d<4P0<2a402`X?02l_
;P0G5aD200h>300<018B400?3`d03`l=01DE4`0A4@l0410>01@D4P0C4a403Ph>00l?3`0@41004A4A
0P0?3a40FP0D51H04Q4F014@5@0C4QL03@`B01LF700A4QL04Q<H010A5P0>3a<03@hB00`=4@0S92H0
?d1205AEE`0F61L03@l>01TM700<4Q003Q8A01<E500A4A404@l@01@B4`0E4a@051@D01DG5P0E6AP0
5Q`J01HK700A51T03a<F01@H6`0H71l05ATJ018F5`0?4a@03Q8A010D4`0A5A@041@C01DI6@0F6Q/0
4aLH00lC500:3Pl05a/L01@H6@0B5QL04aLH01DI6P0F6Q/05ATJ01DJ6P0I7al03Q@D01@J6P042PX0
82HV00X@400D6QX06b4Q01@J6P0S:BT0728R024U900M8B005ATH014E500D61L06alP00X>3`0K7b00
5QXM01<G6P0S9bX06QhS01PO9@0B6b007B@Z01dR9P0P9BT09bXa01DI8P0F7BL06B4/01PR;P0F8S00
62Hd01HP;08051hZ01d05R0/01`V<@0S;CL072H_024[=00E7bP06RD[01TT:P0E82H04A/T01LQ:P0A
6b@03AHM010I800B6b8072<Y01LN900?5Q`06b0T01DJ7P0X;C408b/]00dE5`0D71h05AdO01HN800D
71h04QXL01@L7P0301LO8@0;014I6`0B5aX051TL01@I700C61/051TM01LL800F6b405AXP01HK8@0H
72D00P0J7RL0@00N8Rh06AdY028V<@0W:cH06alZ01DI8P0G72<05Q/Q01LL8P0H7B<04aPN010E6@0C
6AP061hN01HL700D7A`05AdO01<K7@0@6Q/051hP01DO8@0nBD/08bh`01XT9P0D6R005AXP01HK8@0E
6Qh04QLK014F6P0B5aX041HF01<I6@0B61P051XJ00lF5@0D7A`05alQ014I6`0>5QT041LM018I7`0C
6ah051`N014J6@0>5a@04AXE00`E4P0`>3X0IVi`0459B`022@l01PdC01dT;00;4QX04APP01`S:`0>
5Ad02A0H00lE6P0B5a/05AXM01DK6`0E6aT201DK5`0A014G4`0@5Q@04QLH00lD5`0G72008RTa01XQ
:@0C6R803QDK00/B600A61h0;CDh008:3@0J8R@01@d?008:300C6Q`00P0>4aH03@0?51L041DH010E
600@5AP02@hA00@9300B5aX0Q8V<06M/K`0D6Q/03A4B00hB4@0@51<00P0?4a80200@51<04QHE00hB
4@0@51<051PG010D4`0?4a803Q<?0P0A5Q802P0?510041DA01<H500=4Ph04QLC010E4@0G71P04QLC
014F4P0B5a<2010E4@0500D:1P0<4@d04QLC018G4`0A5Q800P0?5102010E4@0:00hC3`0A5Q804aPD
018G4`0A5Q804QLC00dB3P0@5A40314=01@I5@804AHB00L0314=00lD400A5Q804AHB00lD400>4`l0
4AHB00803a@@01`041DA018G4`0C5aH05Q/M018G6P0@5QH03aHA00lF3P0>5P/05alA00`D1@0A6@X0
4AX900PA000@60/03a<@02<W9P10A4<0720O00H;1`0V:bL05AXF00dB300>4`d04QLA010E3P0;40T0
3A8<0P0@5@l00`0<4@/02Pl900dB300500hC3@8041D>00<03Q<<00dB2`0=4P/00P0>4``300dB2`80
314:01003A8;01<H4@0;40T03A8;00D:0`0?50d03A8;014F3`0?50d0314:00/@2@0?50d05ATB014D
3@0>4@X041<<0P0=40T01`0>4@X04QD>010C300C5Pl07b8K01hQ6P0A50d00P0?4P/00`0A50d04QD>
018E3P02010C300;00lB2`0<3`P030l800lB2`0930D04A@=00/>1`000P004A@=01XM5P0B5@h00P0=
40T05`0@4``03Q4:00lB2`0L7aP010L001@G400U:24051L@00`?200o@S/0<C@]01TL5@0?4P/04A@=
010C300B5@h03A0900hA2P0B5@h04aH?00hA2P0:3@H03a8;00804A@=010030l800D80@0=40T03A09
014D3@0D5a004QD>00`?200;3PL0H6=L05QKE00I71D020X601PM5P0:40H02a880P0=4`T0100=4@P0
30l600d@1`0?4@P2010A2@0500l@200>3`L0:b`V01/L5P0<3@L00P0=3PP03@0C50h01PL4014B3001
0P003@h800L80P0>3`T02``601@E3`0:2`D05QLA00/<1P0720801P0>3`T04P0C50h04Q<=014B300A
4P`0414;00l@2P0A4P`03Pl900`=1`0=3PP03a0:010A2`0Y:bH01`T400lA300:30L03a4<018D3`D0
3Q0;00<03a0;00l@2P0?40X00`0@4@/0400?40X03@h800d>200?40X0414;00l@2P0C50l00040018D
3`0D5Q4071hI00h@2`0<3PT03a4<00h@2`0;3@P200h@2`0H01@G40072P4041<:010C2`0F6A8041<<
00X<1`0F61<0>S`i00X<2@0B514020X700h@2`0<3PT03a4<00h@2`0:30L030h900lA300>40/030h9
00/=200<3PT03a4<0`0=3`X01P0>40/03a4<014C3P092`H051HA01LI50802@/600<03a4<018D4@0=
3``00P0?4@h02@082PL03@l<00L91P0>40d02P`900lA3P0D5Q<08bDR010B3@0200lA3003010B3@0?
4@`02`d800803a4<00@03Q0;00`>2@0=3`X0418=0P0?40/03@0C50l04A8=00d>2@0A4Pd03Pl:00d>
2@041@002``7018C3P0G61<0828M00@60`0X:RD00`051`80300D5Q403a4<00d?2P0A4`h0418=00`>
2@0<3P/03@l<010B3`0E5a@051HC00X<2@803@l<00L03Q0=00lA3P0?4@h03a4>010A30051P404a@?
00802``700<03a0;01<D3`0B4`h00P0A4Pd200l@2`06010@3P0A4@l0410>00d=2`0>3P`0410>0`0>
3P`200l?3@0900l?300N7aX0414<00X;1P0?40/01`P3010A300I6QD061TD008030d800L01`P300l@
2`0@4@`0414<00`=200A4Pd04Q<>00803a0;00/03Pl:00d>2@0>3`X03a0;00l?3@0>3Ph03`l?010@
400?3`l03Ph>00l?3`03010@40803`l?00<03@h=00/=2P0;3@X00P0<3P/08@0=3``04aDB0001000?
4@h00`D2028T8@0@4Pl030h=00L9200<3Pd051HE014C4P0>40l03@l>01HH5`1;CD`0:R`[01`N7@0A
4a8071hM00lA400:30/04a@F00D6200F5a/03a0E014B5`0D5AX04a<K014A6@0@4AL04A8F01<D5P02
00l@4P0701@E5`0?41803a0B00h?4@0D5AL04A8D01LH6P03010A4`804A8D0P0B4aD01P0;30h03a0B
010A4`0?41803@h@00h?4ACooooo000Kooooo`0B00h<3@0=30h04A8D00D62P0@51L08bTY00dC4`0:
3`h02a0<00X;1P0E5A0020L200`=200?3``030`:00d=2`0B4Q<0410B0P0?3Q<04P0=31803@`D00/:
4P0;2Q00;2`[01DE4`0=3@/03Ph<01@D4P0C4a4051@B01/K6@0D51803@d;00l?3@0A4@l03Ph>00l?
3`80410@00T0410B00l?4@0B4Q@05aHK00l>4`0=31402`X@018A5`0B4QX00P0C51T09@0A4QL03@hB
00`=4@0@4AD07QlQ03ho@@0D5AL01@L601<G5P0=4a403A4@018D4`0@41004Q0A01DC500D4Q<04a<C
014C4P0?4a803aDC01<H6@0B5AX03a<F018F6@0E6A`051PI01<G600@51D03A4@01HJ6@0L81l05a/J
01<G5`0830d0720Q01/O800@51D00P0A5AH04@0B5QL04aLH01DI6P0F6Q/05ATJ01<H6@0I7al05adM
020V9P0G7Ad0>3hn018H600P9RH061hN01@J6P0C6AT02a4A00805ATH03L04aLF014E500E6AP082@U
01DI6P0F6Q/04QHI01`P8`0<41<05ATN01LO8P0=5aT04QXM01TN900J7bD07R4Z01HJ9@0B6B<051`W
01/U<@0M:CD06BLd01dW<`0D7RX04adY01HP;00C7BP06B<]01LQ:P0F82T051hW01XU:`0A728051lU
00lI8P0C7BH041XS010I800B6b803QLN01LN900F7B<05A`R01TN8P0F6al04QLK020X:P0A6A/06B4S
01LO8@0F7R005AdO00hF600A6A/03ADG00803aLI00@01@d?00lD5`0H7B0061dP0P0C61/0=00I7R80
4QLM01HK8@0H7B<061`U01TM9P0J7RL061`W010D7`0L82/0;30j01lS;00D6Al06AhT01LL8P0G7200
61dQ01HK7`0D6A`04QPG01<I5`0B61H05AhK01HO7P0A6QT051hO02@^;`0A6a`06bHX02D`<P0=5aT0
5adS01HK8@0D6Al04aPL018G6`0A5QX0314D00lE5@0F71`04QPH00lE5@0D71/04a`K01HN800D71h0
2a<F00dD6P0A61d03aLJ00lG6@0@6AL2010I500W01DN6`0?61L09bla02L_<P0I82H000H>00`C7@0=
51h05QdW02L^=`0?5Qh02A0F01<I7P0@5AT03a@G014G5`0C6AL051XF018H500?5A403aDC014G5`0@
5AP05Q/O01dT;00F7BD03QDM00`C6@0=51X05QdS0418B`053A0041PJ01XR90063Q003QHH00`A500>
4aH03a@G00803Q<F00P041DH018G6P0G71l04QLJ02L/;`0I7R403a@F010D5@803a<B0P0@51<00`0>
4Q404ADD010D4`02018F5@0300hB4@0@51<03a@@00804AHB00@041DA014F4P0C61@03a@@0P0@5A40
300B5a<020d901DJ5P0<4@d02a0<01HK5`0;40`02@h:010E4@0D6AD041DA00hC3`804AHB01@03Q<?
00/@300?510051TE01LL600F6aL04AHB00lD400@5A403A8>01HK5`0B5a<04AHB00/@300B5a<04aPD
00hC3`0=4Ph041DA00lD40803Q<?00<03a@@010E4@0A5A@00P0@51L05`0?4a@03a@@00lD3@0@5P`0
5A`=00`C0@0;4`004AT400/C000<4`401PT500X>3@0T:2L04aLF038g<`1fNgL05Q/G00`A2`0=4P`0
5AXD014F3`0;40T0314;00803a@>00<0314;00X?2@0<4@/01@0>4`d2010E3P0500lD3@0>4``03Q<<
00hC300?50d00`0>4``200dB2`0700hC300?50d02a0900X?200;40T06b0I00X?200200lD3@0B00`A
2P0;40T03A8;00lC300>4@X04A@=01@G400=40T030l800lB2`0C5Pl041<<00lB2`0F6A804aH?018E
3P0@4``03a8;0P0@4``0200<3`P03a8;010C300A50d03Q4:00d@2@0?4P/04QD>0P0E6140100<3`P0
9BPQ00T<1`0A50d200d@2@0=014D3@0@4``04A@=01<F3`000`008B@M03m2>`0R9Ah03a8;03m2>`0^
<BX04QD>00d@2@02018E3P0301<F3`0?4P/041<<008051L@01D04A@=00lB2`0=40T030l800d@2@0A
50d051L@00`?200;3PL04QD>01TL5@0F6A802@`501PK500U:24061/D010C300C5Pl03A8;00/A1`0;
4PL00P0;4@L0100<4@L03A0700`?1P0?4@P2014B2P0D00l@200=3PH0<34[01/L5P0720802@X400d>
200E5Q0051D?028S7@0A4P`0414;00@500092P@03@h801HG4@0?40X03@h800H70@0<3@L600h?2@@0
3a0:0P0>3`T0300B4`d0414;00h?2@0>3`T03a0:010A2`0P8Qd01@L2018D3`0A4`h01`T400d?2PD0
3Q0;00L03Q0:00h?2@0?40X0414;014B300B4`d0414;00803@h802D03a0:00h?2@0;30H02@X501XL
5`0?4@`020X7010B3@010`0030h901XL5`0C5A003@l:00h@2`0:30L08RDN01TL4`0J7A@051L?01PK
500=40T02P`701TK5P0@4Pl07R0M00H81@0>40d02`d800d?2P0A4`h03Q0;00T;1P0>40/05aTD00/=
200:30L04aD@00804Q@?0P0>40/200d?2P0A00h@2`0?4@`03@l:00X<1`0;3@P030h900/=200A4`h0
30h;00T;200>40d03a4>00L91P0:30T03a4>01@F4`0;3@X00P0>40d01`0H6QL03Q0;00lA300A4`h0
4Q@?010B3@0:30L00P0@4Pd0100>40/030h900`>2@0>40/2010A300?01@E400B4`h03Pl:018C3P0>
3`X06AXE01HG4P0A4Pd03@h900X;1P0?4@`07R0K020R7@000@007b4L00803Q0;00<03@l:00h@2`0>
40/00P0;3@P01`0I6aP04Q@A00@60`0<3P/02P`901TK600=3``00`0>40d200lA3P07014B3@0;30L0
3a0;00h?2P051P4061TD010A300200l@2`0400h?2P0<3@P030d800l?3@804A4?0`0>3P`300d=2`80
3Ph<00L03@d:01HG4P0;30L02P/7010A30082@@04A8=00804Q<>00@02``700T:1@0>3`X030d80P0?
40/01@0=3PT0414<010A300?40/0414<00<03a0;00<0414<00l@3@0?3`l00`0@41002@0?3`l0410@
010@400?3`l03Ph>00l?3`0A4A403a0?00`>2`0300d?300C00h@3@000@006Q`I010B3`0>40d0>3Xg
02`^:`0B51<02@/:01PJ6@0G6AP04Q@C00@61@082PT02P`;02HX9`0>40l02`d<00X<2`0201@F4`0<
00d?3P0C51H03PlA01<D600?41D04A8G01<C6`0A4A/03`lI00h>5`0C51P04Q<E0P0=3Q00200C51H0
414C00X;3@0?41804Q<E028S9@0K71h05AHH0`0@4Q43014C4P0400/=300?4A00418A00lA40803@l>
5?ooool001_ooooo01803`d=00/:2P0=3Q003a0D00/?4P0<4A@03a@G00T>3@0=4Ph03`l=00/;1P0=
3@H03@h900h?2P0>3P/03`l=00l?3P0?3a4200h=4P0<00d<4P0=31@030/D00`;4@0C4a803Ph<00l?
3@0B4Q004A4?00`<2P0?3`d03Ph<0P0=3@/00`0>3P`03`l=00h>3P0200l?3`0R010@400@4180410B
01TI6`0L6b004A0E01@C600C4QP051<I01<C6`0=3A@03PlE010A5P0@4AD04a@H01DF6P0:2Pd061TL
010A4`0C51D04QHF00dC4@0=4A004Q@C010@400B41405aDF01HD5@0D51@04Q@C014E500@5Q@04aPJ
01@G70804ADH00`04QHI018F5`0B5QL041@E014E500F6QT061`K01@H5`0E6AT02`l@024U9P0P92D3
01@H6@0:018F5`0C5aP05ATJ01HJ6`0E6AX05AXJ01LM7@0C6AT051XJ00`B4P805Q`L00H05A/K010E
5@0G7Ad02a4A01TO7`0D61L201LK6P8041@C02`06AdN018F5`0D61T061`O02<W:P0=4A@0FUiR01hV
:00D7Ql041PK01HK8@0?51X06A`V01LK9P0E6bH05QhZ01XT<00I9C4062Hb01hX=00E7b/05R0/01TS
;`0B72L05R0Z018L9@0T;SL0628[01HQ9`0C7R@05B0V01HP:@0D7RL041XS01@M900I8RT051dT010G
7@0F7B<061lU01@I7@0N8bL06b0T02@/;P805b0R00X041TK01@M7`0G82404Q/L01XS9@0C71d06R<T
02D^<00M9BL05AXM0P0K82<01`0G71l051TM01HK7`0F6b406QlU01/P9P0I7BH00P0H72D0EP0I7BD0
61`V01DI8@0D6Al06QlT020U:P0H7B4051TM01@I700F71h05a`P01LM7P0D6QP04QPF010F500C71T0
4a`K00dF5@0=5aL04A/L01DO800?6a`02aLH01@N800F728051TO018G7@0B5a/051TM01HK7`0M8RD0
8bTY01@J6P0G7Ad041HF01PO7`0@6AP031@F01<K7P0@61/041LL01DM800A6A/03QLF00lH500@6Q80
4A/C01<L5`0@6AP03QHH00`C600C6R808RTc00`C7P0B62<05A/V01LN9`0@5al04APN01LM8P0D6Ad0
4QLJ01@J6P0D6QP03aDA00/A3@0>51004QPF01@I6P0B5aX04QLK01<J8P0@5al04QTQ01@K8@0A61h0
51/Q018J7@0@5aX0HVY/06=[K@0C6ad02a8D00`A500>4aH041DH0P0?51L0200@5AP03Q<F018G6P0@
5AP02PlB010E600;4A804QHG0P0?4a82014E500700`@3`0=4A0041@C01<G5P0>4Q40310?00lC4P03
014F4P03010E4@0=4Ph0314=0080314=00H04AHB018G4`0B5a<0?44m03i3?`0C61@300hC3`0:00`A
3@0A5Q802a0<00X?2`0@5A404QLC00dB3P0>4`l03A8>010E4@8051TE00L03a@@014F4P0@5A403Q<?
01DJ5P0>4`l04QLC008041DA00<04AHB010E4@0>4`l00`0=4Ph05`0>4`l03a@@00lD400?4a403Q8C
014E5`0A5AD03a@@00hC300?50`03aD:01@K3@0<4`<04AP600dD0`0<4PD041@A010D4`0?4a803A4@
00lD400B5a<041DA00803A8<00D03Q<=00hC300=4P/041D?00hC3@0200dB30803a@>1@0>4`d00`0>
4``03A8;00dB2`0300dB2`0300hC300?50d03a@=00803Q<<0P0=4P/020083@H02Pl800X?200E6Q<0
;C8[00/@2@0:3`P0314:0P0=4P/01`0>4``03Q8;00d@2@0A50d04aH?00`?200=40T00P0?4P/00`0>
4@X03A09010C300200lB2`0L00hA2P0?4P/041<<00lB2`0;3PL030l800hA2P0@4``03Q4:00d@2@0?
4P/05aXC00P;100?4P/02@`5014D3@0F61<04A@=00`?200>4@X04QD>014D3@0C5Pl030l801PK500B
5@l04QD>01@G40803a8;0P0=40T200lB2`0600d@2@0?4P/03Q4:00hA2P0@4``04A@=0P0?4P/02P0>
4@X03a8;00d@2@0:3@H03a8;00`?200>4@X04A@=01@G400A50d200`?200701@G400?4P/03a8;014D
3P0?4`h03A<900`C200200/A1P0400hB200?4PP030l500lA1`804Q<:00h03a4700d>1P0D5@l04A8<
00X;1@0@4@/03@h8014B300G61<02``601<D3P0<3@L071dG00/<1P803@h800@0414;00h?2@0=3PP0
4Q<=1P0=3PP300l@2P<0414;00<04a@>014B300@4@/00`0?40X01P0?4@`02`d800`>2@0O8A`02P`7
010B3@D03Q0;00<03Q0:00h?2@0>3`T0100>3`T200d>2080414;02D03Pl901HG4P2DUY40<38]01HH
4`0:30L01PP3018D3`0X:RD06adH014C3P0@4Pd01`T401hQ6P0A50/06QdD01<F3P0B5@h030l800`>
2@072@H0418?00@50`0W:BH0E5IC01<E400>40/03@l:00h@2`0=3`X04aD@028T7`0C5A003a4<018D
3`092`H02`d800803a4<00P03Q0;00d?2P0=3`X03Q0;01@F4@0=3`X05QPC01/M60803a4<00l03@l<
01LI5P0@4Pl01`T600lA3P0<3P/0418?01@F4`0<3P/03a4>00/=2P0B51405ALB014C3P0?4@`00P0>
40/0100;3@P03@l:00lA300?4@`200h@2`0D00lA300?40/03@h900d>2@0>3`X0414<01TJ5@0l?CP0
30d900`=200@4@`04A8=01HG4P0O8A`0EEMB00`>2@0E5a803Q0<00/=200>40/200d?2P0900T;1P0=
3`X051HA01hP7@051`@04aDB018D4@0<3P/02P`900H03Q0=00L0414<018C3P0?40/04Q<>00L80`0F
5a80414<00803a0;00@03Pl:00d>2@0=3PT03`l=0`0A4@l0100>3P`03@d;00`<2P0<30X200d=2`0>
00h>300@40d04a@?00`=200?40/04Q<>00/<1`0E5Q403a0=00P9100C50l03a0;01TJ5@092PD200h?
2P0500l@2`0>3`X03Pl:00h?2P0@4@`00`0A4Pd00`0@4@`03`l=00h>3P0400h>3P0900l?3`0>3Ph0
30`<00`<300>3Ph04A4A010A3`0=3``03Q0=00<03a4>02<04Q@A08^=RP0K7AX04aDB00T;200<3P`0
3a4@01<E500a<S4051HE00/=300A4a806A/J00H81`0>40l05QPG00/=300A4a801`T601DG4`0:30X0
51HF014B4`0=3Q403a0E010A5P0B4QX03`lI00d=5`0>3QP03PlC00d>400>3a40414C00l@4P0200`=
3`804Q<E00<09RLY018C5@0?41801P0@4Q40100?4A004Q@C01<E500A4a8200lA41Cooooo000Koooo
o`0C00l>300?3Pd02@/:010A5@052Pd02PlC0001100830h03A8>00D60@0?40T030`400h?2@0<3@P0
414<010@3P0=3@`03Ph>00h=4P0200h=4`0@00h=5@0>31L03PdC010@400=3@/03Ph<010@3P0C4a40
4A4?01DE4`0:2PP030`:010@3P0;2`T02@T700l?3`803Ph>01X03`l?010@4P0A4A<07AdO01LF6`0>
3A804Q4F00l>500D4aT07QhV00h>5P0?3aL03a0E010A5P0F5a`03a0D01LH700E5QX02``>010A4`0;
3`l0318@00hB4@0D5QD04A4A014?4080518C05D04Q8B014C4P0@51<041HD01<H6P0D5a`04aLJ018F
6@0A5AP04QHG010D5@0B5QL05QXI01<G5P0=4A003Q8A00dA4@0C5aP02@d>01<G600>4Q<06QhO01DI
6P0B5QL04aLH01DI6P0F6Q/05ATJ01DJ6P0A5aL051XJ01XP800K8B406AlO01HL700630`05Q`L01<I
6@0O9BD03aDE018F5@0E6AP05a/J01<G5P0B5QD05ATJ00hB4`0N8R<051PK00dA50072`h06AdQ01@L
7P0@6Q/041PK020U:`0B5ad0828^01HJ9P0I7b/072@a01HP;00B7RX05R@_01HP;00G8Bd06B<_01DO
:`0C7BP04adW01LQ:P0c?DH06B</010K8@0C7R@041/Q01TS;00E7bP03QPQ018K8P0I8RT05b0W01LN
900C6R004QTO00806QlS01@051`O014I6`0?6AX05b4R01<M7P0F824041XK02D_<00`>S/06R@U01@N
7`0J92D0218C01HK7P0H7B005a`O01HK7P0E6Qd051TM01TN90805Q/Q00H05a/T01DI8P0D62405AXP
01HK8@0D6Ad201LL801K01<H6`0D6A`04AHI014G5`0D6QX05Q`L01HL6P0B61@04ALE00lE4`0C71T0
5AhM018K6P0/=SD06B<T00lI6P0C7al01Q8B018L7@0D6R004QLM014F700C61`05Q/O01PM8@0Q9RT0
9bd]00lE5@0F71`04aTI01TP800H8B003QHH010H6`0A6A`03QHI00dE600?61L03QLF00dF4@0>6100
3aT@010I500>5aH00PX<014I7@0>5Al04QPT00T?6`0A5b<051XV00hE7`0E72@04aXP00`B5`0@5AT0
4aPK01LM7@0E6aT04ALC00`B3P0A5a<05A/I01@I6P0C61/04AHJ01@K8`0@5al03QDM00`C6@0941H0
2a8H00L?4P0D71l0<c/m04A<CP022P`05QhP00dB5@0>4aH04QLJ01DJ7@0D6A`03a@G018G6P0J7b80
4AHI000110062`h03a@F010D5@0200lC4P8041@C00L03Q8A00P<2`0=4A004ADD018F5@0F6QT061`K
0080314=00/03Q<?010E4@0?51002a0<00lD400<4@d03Q<?00lD400<4@d0;c@`02@Y9@02010E4@06
00/@300=4Ph041DA01HK5`0A5Q803Q<?0P0@5A401@0<4@d04QLC00hC3`0;40`0314=00<03a@@00d0
41DA00lD400B5a<0314=01dR7P0C61@03Q<?00dB3P0B5a<03a@@00/@300=4Ph03Q<?00803a@@0P0>
4`l06P0B5a<051TE018G4`0<4@d03A4@00lC4P0>4Q0041DA00@91@0;40/03A8<01<H4P0C5aH0310?
00/?3P093@`02a0<014F4P0?51004QLA010E3`0<4@/03Q<<01<H4@0H7AL041D?100=4P`500hC3@03
00`A2P0:3`P02a0900<0314:00@03A8;00hC300>4``03Q<<0P0=4P/03@0>4``03a@=00/@2@0:3`P0
2a0901/P6@093PL03A8;00hC300=4P/02Pl800/@2@0=4@X00P0=40T00`0?4P/030l800d@2@0200lB
2`05014D3@0@4``041<<014D3@0>4@X00P0=40T2010C300400hA2P0;3PL030l800hA2P8030l800P0
3Q4:00D80@0G6Q<04aH?00hA2P0K7QL0?T4j014D3@803A0901004A@=010C300A50d041<<01@G400:
3@H092LP024T7@0;3PL02Pd600lB2`0C5Pl03a8;00hA2P0B5@h03Q4:0P0?4P/3010C300D00hA2P0<
3`P04aH?014D3@0?4P/06ahG00hA2P0@4``03Q4:00/>1`0<3`P041<<018E3P0620@0008000/>1`0F
6A806b4G00hD2P0>5@P200hD200400lD200@4`P03A0500lA1P80418701003a4600h@1@0@4@/03a0:
00T:100?40X02``600d>201HFE<0@d@n010A2`0A4Pd02P/500T:100?40X01PL10P0=3PP00`0A4P`0
20T300h?2@0500h?2@80414;1P0?40X4010A2`0600lA300:30L04A<>0084000620<03@l:1@0>40/0
2P0?40/03a0:00l@2P0>3`T030d700/<1P0>3`T03a0:00h?2@0@4@/2018C3@0E00d?2@0E5a801`T4
00h@2`0T9R404aD@01@F4@0O8A`05aTD00h@2`0=3`X01`T400lB2`0520005QT@014D300@4``04A@=
018D3`0A4`h03a4>0080004000T071dK01lQ700D5Q402`d800`>2@0;3@P03@l:014C3P0<3PT00P0>
40/0100;3@P061XE00h@2`0>40/200d?2P0F00h@2`0?4@`02@/600P:1@0G6A@06Q`G00`>2@0:30L0
6adJ02X/:@0I6aP01PP501@F4`0<3P/01`T600`>2`0:30T04Q@A010B3`0D5Q<07AlJ01DG4P803Q0;
00@0418=014C3P0:30L03Q0;0`0?4@`02`0@4Pd04A8=00`=200<3@P03@h901<D3`0O81/0LgA_01hO
6P0E5Q404Q<>00803Pl:01<03Q0;01DG4P0>40/06adH00/<2@0J71L04Q@?00/=200=3`X02`d8018D
3`0N81/0GV1M00h@3@0B51400`D201LI5P0@4Pl03a4>00<03Q0=0P0=3``2010A300400l@2`0=3PT0
7QlJ00D60@803@h90P0>3`X200l@2`06010@3P0?3`d03`l=010@3P0>3P`030`:0`0=3@/200h>3004
00h?2`092PD02P/600l@2`80414<00h04a@?05UJE@0N7aX03a0=014B3@020`00414<00h?2P0?40/0
4Q<>00h?2P0<3@P03a0;010A30<03a0;00<0414<00l@3@0=3@d00`0<30`00`0=3@d03Ph>00d=3@02
00`<300400d=3@0>3Ph03Pl>00d?30803Q0=0P0?4@h06`0A4a005aTF00lA3P0;3@X051HC00P:1`0>
40l02@/:01PJ6@0A4a80418A01DG5P0>40l00@<2018D4`0[;B`030h=00d?3@0F61D00P@0020R7`1O
HF000`D401<D5P0>3a@03a0E010@600200h>600=010@6`0@4AD03PlA01<D5P0H6A/04A8D00d>400?
41802``>014B500<3@l02``>01<D5P03010B4@<03a4@00@03@l>010B4@0A4a803Q0?0P0<3PdDoooo
o`006oooool05@0>3@/04a<B00X<2`0?41@01@X=01HK7`0/<CD01`/=00hC3`092PD04a<<00H6000>
3`T030d7010A300@40h030`;00h>3P0?3Q<03`hD00l>5P0200l=6008010?5@0;2`/02@T700X:200?
3`d051@B01<C4@0K6aT200l?3@0A00`<2P061P@01`L500l?3`0>3Ph03@d=00l?3`0@41804A4C01<C
5@0@3a@02`X?00`;400>3A<07QdS01lO9`0?3aL00P0B4QX05@0A4QL05QLL024R9P0B4aL051DI01PI
6`0I6Q`03A4A00/A3`0?4a805ALF018B4P0@3Pl0518C01DC500C4a<04Q@C010D4`0?5A<04QLH01@G
700201DI700G01<G6P0C5aP04QHG01DI6P0H71/051PG00lC4P0B5QD041@D030d=@0;3a006QhO00hB
4`0K7b003a<D018F5`0C5aP05ATJ01HJ6`0E6AX06AhO01PN7P0F71`00P0=4a<01@0;4A403A<C03a2
@P0B61P07B<S0080728R00<04QHE01<G5P0F6QT00P0F6QT0700E6AX04QHG00`@4@0C5aX07b<V01TM
800@51T04a/M00lI6P0A6A`0:Rle01@I7`0D5R805a/W01TO:`0K8c005R0/01<O:`0F92l05R0/028/
>00P:SH04adY01@N:@0@6R@05AlX02@^=`0B72D3010K8@805b4Z01d04A/T01<L8`0H8BP05QlV01HM
8`0J8BL04APN01PM8@0F6al0=Ce001dU9`0G8B806B<T018L7@0C7Ah0218C008<3@0K9BH041XK00hH
6@0O:BX04A/L01<H6`0I7R406QlR01HK7P0I7R4082DY01`Q9`02014F700C01PL9@0I7BH05a/T01HK
800K82@06AhR01/P8`0F6ah03a@G018H6@0@5QH04ALG01DK6P0F71X05A/I01<I5@0E6aL04ALC010I
5P0201@M6P0D03M1@00V<34051hO010L700:5QH02A<D01DK8@0D6Al04aPN01<H700D6Ad05AXN014F
6@0H7Qh05Q`L01DK6`0I7al0620O01`U900G7b42014I700j00dE6008418031DD014J6@0C71L04A/C
018L4`0A6a@051dL00hF600H82@0ADaF00/A7@0K8Bl051XX01<I9@0D6bD05ahV014H7P0;4AH041DI
018G6P0B61P03aDC00lE4@0@5Q805Q`H01HL6P0?5AD04QLJ01@I7@0:4AT02A0H00hE7@0A61h03A@J
00`C6@0430l05QhQ014I6`1EGEl0;3@f00`D5P0?51L03Q<F01<H6`0K82<06QlR00hC5P093Q404AHI
00hC5P0J7b807b@W014G600=4A803Q8A010D4`803a<B01d041@C00X>3@0>4Q4041@C01<G5P0I7A`0
5a/J00dB3P0<4@d03a@@014F4P0@5A402a0<014F4P0<4@d041DA01TN6P0:3`/0314=000300083@T0
5a`H014F4P0@5A402a0<01@I5@0B5a<041DA00lD400200hC3`8041DA00d03A8>00`A3@0?51004QLC
00`A3@0@5A404AHB018G4`0@5A40:c0/010E4@0?51003Q<?00<041DA01l03A8>00lD400@5A4041DA
00lD400>4`d04AH?01<H4@0@5@l02`l=00dA4P0A5AP030lC00`?500931<05QTP00/>5@0=41D03A4A
010D4`0I7A`041@C00T>2P0B5a<041DA014F400@5@l03Q<=010E3P0B5a004QLA00803a@>00<041D?
00dB300<4@/01@0>4`d00`0<4@X02Pl800`A2P0200dB2`0300`A2P0=4P/03A8;00803A8;0P0<4@X0
1`0=4P/04aPA00/@2@0=4P/01@X300lD3@0;40T00P0>4``05P0<4@X02a0900`A2P0?4``03A0900`?
200@4``03Q4:00`?200>4@X041<<018E3P0>4@X02Pd600/>1`0A50d03a8;00d@2@0?4P/041<<00lB
2`0=40T200hA2P8030l800P04A@=00X=1P0S9Ql02Pd6010C300L7aP0=CPa018E3P803A0900P041<<
00hA2P0?4P/010L000/>1`0@4``0>3/d02`_:0803a8;0P0@4``02`0>4@X041<<01<F3`0>4@X03a8;
010C300?4P/041<<014D3@0D5a002`h700803A0900H061/D034d;@0@4``03Q4:00d@2@0>4@X2010C
300800`?200>4@X05APA01XM5P0:3@H010X000hD2P0?5PX2014G2`04014E2P0@4`P03a8700lA1P80
3Q0501003a46010B1`0B4`d03Pl900L80P0>3`T02``600h?2@0e=S00;RlY00L80P0?40X04A8<01@E
3`0B4`d030d70P0?40X00`0G61801`P200h?2@0500h?2@0400l@2P0>3`T03@h800d>20802``600<0
3@h800h?2@0?40X00`0@4@/01P072@@02P`701@F4@000@00<38]00P:1PD03Q0;00<03a4;010A2`0?
40X00`0?40X2018C3@803a0:0P0A4P`02P0E5a40004000h@2`0?4@`05QPC00D70P082PD04A<>010B
3@0=3`X200lA300H018E3P0:3@@05QT@010C2`0@4``03a8;00D70P0C5A0020T702/]:P041P<05aTF
01PJ5@0B50l03Q0;00d?2P0:30L030h900T;1P0:30L030h9010B3@0G6A@092HQ0`0=3`X01`0>40/0
3a4<014C3P0<3PT02P`700lA300A4`h00P0;3@P01@0H6QL07R0M01HH5@0<3P/03a4>008030h;00l0
3a4>00/=2P0A4a002`d:00`>2`0F61<04A<>00h@2`0?4@`04A<>010B3@0;3@P03a4<010B3@0?4@`0
0P0>40/06`0@4@`03@h900l@2`0>3`X0414<01PI500N7aX01@H301@E400:2`H03a0;00T:1@0:30L0
4A<>00lA300620<03Q0;0043000@4Pd02@/600h@2`0?4@`051HA01lQ700L7Q/01`T6018D4@0200d?
300300L91P0?4@h03a4>00803Q0=0P0=3``02P0@4@`02P/6010A300@4@`0@d@o00X;1P082@@02@X5
00X;1P0=3PT200h?2P06014A3`0=3@/03@d;010@3P0?3`d03@d;0`0>3P`200l?3@0N00l@30082@@0
30d800l@2`0;30L04A8=02`]:01TIF0061TD00d>2`082@@01PL2018C3P0?40/0414<01DF4@0?40/0
3@h9010A300?40/03Pl:00d>2@0>3`X03a0;010@3P0>3Ph03@d=00`<300=3@d03Ph>0`0@410300l?
3`0300h?3@0=3``03@l<00<03Q0=00T05ALD0001000?4@h02@/801XL6@092`P05QPG00/=30082PT0
0P0?4A0040092`X04aDD01<E500?4A006adL010B4@0e=cD03Q0=00L9100S9B80Gf5P00`>3@0@4A<0
3@hC00l@5@0@41T200l?6`0=018B7@0C51P03a0B01<D5P0H6A/04Q<E014B500>3a403@h@02TZ;008
2@/03@h@00l@4P02010B4@803a4@0P0>40l01P0=3`h0418A014C4P0>40l030h=00/=31Cooooo000K
ooooo`0V00X:1`0C51402@/:00h?4@0<3Q<08bL[07YlP@0D5aX02P`=00/<300<3@X06QXF00l@2P0=
3PL03a0;010A2`0=3@X03@d<01DE5@0@41<02`X>010?5@0?3QD04Q4G00h>4@0>3a404A8D00d>400>
3Q002P/=010@4P0?4180410B00l?4@0720X05ADG014A4P0?3a0200/;300400h?4@0?3a40410B014A
50804Q8F02l04Q8E01dO900@51h03A4K00P;5@0E6B801`XB01TK8@1GFEh05aPL00`=4@0B4QH05ADH
018D5P0?4A80418E01@F5`0A4Q<04A4D01DD5`0B4a@05QHI01LH6P0C5AH051HI014E600D5a`05QXN
01DI7@0D61/05AXM01DJ700A61T04AHH00lF5@0>5Q@03aLE02@Z:P1<D5808RHX01TM7`0@51H06alQ
018F600D61X05ATK01HJ700201DI6`1G01DJ700?51P04aPK00/A4@0I7al051XH01hT8`2DVYT07R@T
01@I6`0E6Qh051XM01<G600C5aH06QhM01<G5`0D61P051PJ01LK7@0;3Q8061/P00T<4P0I728061/Q
010G6`0E6b0051TO02T]=@0J7BL05ATT01HI9`0F72/06B0`01PP<00E82l05b4a014I;P0X;dH092]1
024Y?P0I8SD062@c01PS<@0E7b`051hY01DN:00I8bX06bD[01HN9@0J8bT06B4X01PP9P0I8RL06R8V
01@K800S:Rl072@X01LN8@0P9bX0FF5T02@];@0C71X03aTG010G600B6QX041XJ01HL7`0T;2h08BX/
01lV:@0R:Rd05alS01<K8@0P9Rl082L`01TO9P0K8RP0:30f028Y;`0G7B805QlS01HN8P0C6Qh051/O
01TN8@0R9RX07R8V008051TL05405QXM01<H6P0B5aT051TK01DJ6P0F6a`05a`L01HK6@0H7A/05AXG
014G5P0C61P04QTJ01DK7@0B61/05QdP018J7P0H7b<051XP01HI8P0D61l051PM01@I6`0B61L04APD
010H500@61<05alM01@M7@0@5aX05AhR018K800G82D04QXO00lG6`0;4QL03QHH01<J6P0H7al061lL
018K4`0A5a004QPC018J6@0@51L07b@X05mUJ`0G6R<05a`V01@I900B5B004QHQ014G800@4ah04QHK
01DJ7@0F6ah04aPH010E4@0@5Q4051XE01PM6@0F6aT03Q<D00hB5P0C5ah04ADJ01@J7`0N8bP092P[
01DL7@0A5aL05a`K00XA400>5A@04aLI01LN7`0<41<041@G00hC5P0A5AL00P0F6Q`09P0>4a@03A8D
01DJ6@0@5A@03a@C00dB4@0>4a403A8@00lD4P0A5Q<041DC00lD4`0A5QD02@h=01HK7@0@51H03Q8E
014F600>4a@04QHE00hC3`0D6AD05AXF00hC3`0<4@d04AHB010E4@0J7a/09b`X01`Q7@0>4`l04aPD
010E4@0>4`l02a0<018G4`0A5Q803a@@0P0@5A401P0?51003Q<?00lD400=4Ph03a@@010E4@803a@@
00P041DA00dB3P0>4`l02Pl;01PM6@0A5Q809b`X00dB3P<03Q<?02H041DA014F4P0<4@d03A8>00lD
400@5A403Q<?010E400@5@h041D?00hC3P0;40d03a<C01<G600>4Q<04ADI01TM8@0P92P03Q4F00X>
4@0>4a002a0>00dC3P0>4a002a4<00T?2P0>50h02a4;00dC300?5@l03A<<00/A2P0<4@X02Pl800hC
3@0I7QL051TC00dB2`D03Q<<01803A4;00d@2P0?4P`041<=00lC3@0@50h03a8<01@G4@062@D030l9
00/?2@0@4`d02`l9014F3`0;40T03Q<=010E3`0B5a4300dB2`0;00`A2`0>4``03a@>010D3P0;3`P0
310901<G400>4P/02Ph700/?200<40T00`0?4``0200B5Pl03a8;00lB2`0>4@X03a8;010C300=40T0
3Q4:100?4P/0200A50d09RTR02ha:P0<3`T04A@=00L:0`0A50d041<<0`0?4P/01@0=40T03Q4:00`?
200D5a002Pd700804A@=00L041<<01<F3`0B5@h041<<00lB2`0>4@X030l800803Q4:0P0=40T04@0>
4@X041<<00lB2`0>4@X041<<00lB2`0<3`P051L@010C3@0>40/030h801<E3`0C5Pl03Q4:01@G3`0A
50`03a8800804A@:01P06R0E00dE2P0=5P/05AhB00lF3@0>5@/041L;00T@1`0J81H06QlD00hC2`0:
3`D03Q8:00`>200?40`03Q0:01@F4@0D5Q805QPB02X/9`0;3@T061TD00/<200/;BT300d?2@0_00h@
2P0>40T051H?00X<1@0>40X03@l900h@2@0A4``03Q0:00/=1P0E5`d02P`601@F300=3`L03a4:00h@
200<3PP01PP400T:1@0B50h03a0<01DG4P0D5Q4041<=00d@2P0G6Q@0C4i801HH4P0>40X03A0:00lA
2`0?4P`03a4;00h@2P0C5@l071hG01<E3P0C5@l04A<<01@F400A4``03@l800h@2P0A4`d0418<00`>
200D5Q400P0@4Pd0100;3@P04A<>00d?2P0:30L200h@2`1A010B3@0C5A00418=00P;1P0:30H030l9
00lB300<3`T04aD@00h@2`0A4`l01`T500T;1`0A4`l03`l;00l?2P0@40`03a0;00`>2@0?4@`03Q4<
00lB3@0<4@X030l:00hD3@0@5Pl02`l900h@2P0?4@/03@l900`?2@0?4@/04QD?01TK5@0;3@T02`d7
014C3@0<3`T03@l;00/=2@0=3`/03a4=00`>2P0>40`03a4=014C3`0=3`/0418>00/=2@0:30P03a0=
00d>2`0>3``03a0<00h?2`0?40d03Pl;010A3P0A4Ph03a0=00d>2`0;30T02`d900`>2P0?40`03Q0<
00d>2P0?40`03Q0<01@E4@0H6QH01`T501<D400@4Ph030h900lA3@0F61<05ALB01LI50092`H04Q@?
00803Q0;00D03a4<00P:1@0D5Q405ALC01<E4@02014C3`0M00`>2P0C5A403a4=014C3`0<3PX03Q0<
010B3P0<3PX0414=00H70`0E5A80410=03`m>@0E5Q803@d:00d>2P0>3P/03a0<010@3@0@4@d04A4>
00`=2@0=3PX04A8>010@3@0>3P/03@h:00h?2`0?3``00P0?40`0300A4@h03@d:010@3@0?40`020P5
00h?2`0g=c@0:b`X00P91`0@40d01@H401TI5P80418=02L0414<018D3`0?4@`03Q0;00lA300=3PT0
3Pl:00l@2`0;30L03Q0;01HG500;30/05AHE01HG5@0:2`T04A8@00h?3P0<3@`07QlM00h?3@0E5Q@0
30d<00l@3P072@H030h;00h@3@0?4@h030h;00/=2P0F61D03@l<00/=2P0=3``030h;00l@400A4Q40
2``<01dN7@0>3`l00P0?4100700G61L03a0@00d>3P0A4Q80;c0`00X<2P0E5aD02@/:01<D5@0D5AP0
30d@00`=4P0>3a@04A4J00h>5`0?3aP0820Y01/L7`0F5aP04A<C010A4P0@4Q805AHG00l@4@0B4a@0
;Bh_01<D5@0A4Q<200`>3@0601<E4`0E5aD07AlM00h@3P0?4@l04aDC0P0D5Q@00`0B51803a4?00h@
3P0Dooooo`006oooool03`0:30L02`d900<50P0<3@l01`L;00/<4@0K72401`P=00H7300;310030d@
01HH5`0>3`T03@h700`=1`0200d>200700`=200K6aT0000000d=3@0G5aT02@P=01LF6`02014B5`80
30dB0240414F018C60030`P051DJ00T:3`0A4QL03@hC00@52@0;30h03a0B00h?4@0?41803PlA00T:
300<3@l0414C00l@4P0B4aD05AHH02X]<P0J8Bd02Q0L01HL:00W;SP03a<L00dA6P0N8BP04a@I018C
600920h040lD01HF6P0E5QX00P0A4QH02P0C51P03a0D00/<400<3A403a0D01@E6@0>3a<03@hB00lA
5P0@4aP3014D6@05018G6P0C6Q`041PJ00hF600?61P00P0A6aX02P0D6a`06AdP01DI700?4aH051PK
01LK7P0E6A`051PK01DI700F6Qd201DI700b01<G700@5A/06b0T00`A50052`/041HC00T?2`0R:2H0
5A/K014F6P083A405a`S01<G600>4Q403a<B00lC500P92D02`lB00`?500A51T010L>05mRJ`1iO8D0
4aHO018E7P0G6R<04QDN028T<00L7RX041@P01HL:P0H7Rh06R0a01PO<@0H7c806b8f01lR@@1>DG80
7R=2018I=@0L9Sl04Aha024^@@0^>DX082Xf02@/>@0G7RT05A`T01/R:00J8RD201TQ900]01PP8`0F
7R405AdP01DM800H82<05QhQ01TQ900Y<C<0:c4_01<I5P0=4a403Q@B00/A400?5AD05AXM01LL800P
9BT08BH/01`Q9`0I82P06R0^01XQ<@0F7R/04QXU018K9@0F7bH05b0U014K7@0F82404A/K00dG5P0E
7Qd061dP01PL7`0D61/03Q8E00lC5P0A5AP03A4D00`@4`0A5AP04aLJ01@H6`0G6a`05ATI00805a/J
04X051PI01<G6P0D61/041<H010C6P0D5ah03A0G00hA6P0B5Ah04aDQ014D6`0A51T04aPF014H4@0@
5`l04A/A02H`:00<5A801a4C00@=500>5b002Q8M01<L9@0A6B4051/S00dD6P0E6ah04ALG01<G600D
61H051TE01@I4`0C61D04aLH01DI700F6Qd05ATL01<F6`0A51X05APO01DH8@0B51l051HR01<E8@0?
4QT041@G014E5P0B5QD04aPD01@I4`0B5a004QLC01@H5`0A5AL03Q4F01@G7`0:3A804aLJ01DI6@0B
5QD01@X600dB300A5Q003a@>00dB3P0?4a@041@E00dA500?4aH03Q8E00hB4`0=4A803Q8C00lC4P80
41@C00@04AHB018G4`0B5a<04QLA0`0?5A401P0?5A<041HD010F5P0F6ah09BX]01<H70803A8H00d0
5Q/P00hB4@0?51007b@P020U8@0>4`l01``800lD400>4`l03a@@014F4P0?51002@h:00804AHB00D0
41DA00lD400C61@061dI010E4@03014F4P03010E4@0>4`l03Q<?00@03a@@00P03Q<?00870`0U:RH0
00D100L<20093PX02a0<00lD40803A8>018041DA00lD400>4`l03a@@00`A3@0?51003Q<?00dB3P0@
5A403a@@00hC3`0<4@d02a0<00hC3`0A5Q804QLC010E4@0?510200L<200B00lD400>5@h02Q4:00dD
3@0>5@h031<<00hE3P0=50d031<<00dD3@0?5Pl031<<00XA2P0>4``0314:00dB2`0D6A804QL@1P0<
4@X00`0<40X03Q0;010B3@02010B3@0F018D3`0?4@`0418=010B3@0C5A0010H1010B3@0A50l03Q<=
018G4@0H7AL05Q/E01<H4P0?50h02a0:00`A2`0>4`d04AH@018G4@0@5@h03Q<<00lD3@8041D>00<0
3Q<<00/@2@0;40T00P0;40T200`A2P0701HI4P0930D06A`E00d@2@0;3PL04A@=010C3002014D3@0@
010C300>4@X030l800hA2P072P<06QdF014D3@0I71D030l800hA2P0@4``04A@=00lB2`0=40T03Q4:
00lB2`803Q4:00<03A0900hA2P0?4P/00P0>4@X0100=40T02`h700d@2@0?4P/600hA2P0I00d@2@0<
3`P02`h700/>1`0:3@H02@`500H81@1NH5d06adJ00T;1P0520805QTB00lB2@0=40H02`h300`@0P0>
4P@03aD903e5>P0P:R405b4H01PR6@0S;B@02aD<004;0P0201DO5P0500/E30094`X03A@<01LJ5`06
20D00P0;3@X02@082PL03Q0=01PJ5`092`P02P`900h@3@0?4@h071hI00h@2P0300lB2`0400hA2P0=
40T04aH?00lB2`802`h702P030l800`?1P0;3`<000<000lC1@0;3P<04QD<010C2P0A50d05ALB01XL
5`0G6AH02@/800lA300?4@/020/400/>1`0A50d041<<00hA2P0=40T030l800hA2P0@4``03a8;00`?
200@4``071lH00d@2@0E61403a8;01<F3`0?4P/030l800d@2@0>4@X030l800X=1`0<3PT03@l:0`0>
40/0600=3`X04aD@01@F4@0?4@`04aD@018D3`0=3`X04Q@?00h@2`0:30L03a4<01DG4P0>40/030h9
00lA300@4Pd03@l:010A300B4@d04Ph;00h=2@0>3`X03a0;00d?2P803A8<0P0<4``01@0;4P/02149
00X?200<3`P03A0900803Q4:00P03A0900X=1P0<3`P04QD>00lB2`0L7aP02`h700`>2@@03@l:01<0
2`d8018D3`0A4`h03a4<00d?2P0;3@P02P`7014A3`0?3`d04A4?00l?3@0<30X04A4?00l?3@0A4@l0
3`l=00`<2P0;2`T030`:00803Q0=100=3``0900;3@X04A<@00h@3@010`002P`9010B3`0>40/02`d8
014C3P0I6aH05ALB00P:1@0A4`h04aD@00/=200B50l05QPC02d_:P2WZJ@08R@O00P:1@0B50l030h9
00/=200D5Q405aTD010B3@0D5Q405aTD010B3@0>3P`00P8000`<2P0B4Q005ADC00/;2@804A4?0P0@
40h200l?3@803Pl:00H03a0;014B3@0@4@`03Pl:00d>2@0>3`X300l@2`0300/;20071`D02`/90080
410>00D05aLE01dM6`0@40h04a<A01DE4`0200h>300>00`=2@0;3@P02P`700d?2P0@4Pd04A<>010B
3@0:30L030h9014C3P092`H03@l:01/M6@0D5Q<2018D4@0>00X<2@0?4@h04A<@01@F4`1OHEh07AlL
0001000<3P/03@l<00T;200G6AH04A<@00`>2`0B514200h@3@803a4>00X03Q0=00d?300@41006ATI
03<c<`1IFET06ATI00h>3P0<30`03@d=0`0@41008P0?3`l04Q<E00/<3P0<3@l04Q<G00h?4`0A4QH0
3a0E00d>4`0=3AD02PXB00P8400E5A`051DG01@F5@0E5aH04aDD010B4@0=3`h02`d<00h@3`0?4A00
3@l>00lA400A4a805aTF00X<2@031@807AlL00lA3P0=3``0418?00h@3@0?4@h2014C400300lA3_oo
oooooooo01;ooooo000Kooooo`0500`>2@0:30P01PP500l@4P0@4A@00P0<3A80=@0E5Q/02``A00H7
2`0<3A002@/:014B3@0A4P`03a0:00d>2@0;30L02P/600/;2P0D51<04a<C014A4`071`T0410B00h?
4`092Ph01`P<01DF6P0=3Q807QlS01TI7@0B4aL06AXN00h?4`0=3Q8030dA00d>400<3@l03@h@01DF
600G61X04A8D00l@4P0B4aD02``>010A4`0H6A/0D5=G07MnR00@5R803QDP00`C7@0B5Ql02PhG00hA
600K7240824V014@5P0H5a`030`A0080414E01T051DI024R9P0K7200414E01DF6P0@4AD04a@H014B
5P0?41@05aTN018E6P0@4aP04QDJ01<F6`0A5QT041HI00hF600=5AL041TK01<M7P0D7Ql04QPK01<G
6P0D61/05ATL00805a/N03T05QXM01@H6`0A5AP05QXM01PL7`0E6A`04QHL00X?5@0R9b/06QlR00dC
4`0E6aX07B<Q00@:200F71d0314E01dR9P1LHFP03a<D01TM700N8R<0310A01TM7P0B5QT01@P=020S
:00@4aX0A4M>061SJP0F6B4051LN01@G7@0D5ah07b8Z01lR:`0Y;CP06R4/01XP;@0G7B/051`Z01LN
;`0N9CP0;S5?05=FMP0T:DP082M301HQ>@0B7c80AE9T04iIJ@0M9c<072@`018J900L8b/06R4W01HN
8@0G7b800P0J8RD08@0F7R406b<V01DM800G7b806R8U01TQ900E7Al0=3Xj020V900H7Q`061hN01DK
700H7B005Q/O01DJ7P0H7B4061dS01DJ800G72D08bTf01PO;@0C6bL05AdX01HN9`0A6R405b0U010J
700B71h03aTI00lI600F7ah04QLJ01@H6`0201DI701<014E600?4aH05a/N010D5`0D61/05QXM014E
600A5AL05ATI01LK6P0F6QT051PI01<G6P0D61/04aHK01/N9@0@4aX05QTP01DH8@0B5Ah05QTQ01<F
700C5aT05AXG01@K4`0C6Q804adD01TS700C71/041PK00lH800D7BH041TR01PQ:P0=5Ad061lV00`D
600?5AP04QPH018F5P0B5a@04aPD01@I5@0C61H04QHG01<G6P0D61/04QHI014D6@0B5A/05APO01HI
8P0D5b005APQ01@F8P0D5ah04aLJ014E5P0@51@04AHB014F4@0B5a804aLE01@H600A5AP03a8G01<F
7P0=41D03A4D010D500W:bX09R/W00`A2`0C61804QLA014F4P804ADF0P0@51L01`0?4aH03Q8C00hB
4`0>4Q<041@C00dA400>4Q400`0@5A40500@5@l0318>00`B3P0>51003Q@B00lE4`0@5QH02@hA01XO
8P0<4AD02a0D00lD600F6b003Q8A00hC3`0J7a/07B8N01@I5@0B5a<03a@@100>4`l0200;40`03A8>
00lD400>4`l03A8>00lD400C61@041DA0`0A5Q80100@5A403a@@014F4P0@5A4200lD4006010E4@0A
5Q803Q<?028W8`0=4Ph04QLC0P0?5100300A5Q803a@@00lD400@5A403a@@00dB3P0?51003A8>010E
4@0=4Ph02a0<00dB3P803Q<?00D03A8>00/@300>4`l041DA00lD400200hC3`0600dB3P0M8Qh0;34]
018I4P0;4P/03A@=0P0?5Pl03@0B6A803aH?00hE3P0?5Pl041L@00lF3`0=50d03A8;014F3`0=4P/0
2a0900lD3@0>4``01@0=4P/05P0=4@/03Q0;010B3@0@4Pd03a4<014C3P0D5Q406A/F03m1?00G6A@0
3@l:01HH4`0A5100314;00dB300G71H0314;00X?2@0C61803Q<=00X?2@0;40X200dB300800dB2`0;
40T02a0900hC300@5@h03A8;00/@2@0=4P/200lD3@0:00dB2`0;40T071lH05IIDP0G6Q<03a8<01DH
4@0A50d03A0900hA2P@041<<00d05APA018E3P0=40X0OH1i09VLU@0G6Q@03Q4:010C300A50d03a8;
00d@2@0>4@X03a8;00803Q4:00/03A0900hA2P0?4P/03a8;018E3P0C5Pl03Q4:00d@2@0@4``03A09
00hA2P02010C300@00hA2P0=40T041<<00lB2`0=40T030l800/>1`0:3@H04Q@@04M9AP0J71P03@l:
00h@2P092`L03a8900hA1`803A0501/041<700lE2@0A6@h04Q`C020Z8@1NJ5l0Qi6801lY800>60l0
2aD<00LA20094`X03QP?00hE3@0U:2D01`T600d?300@4Pl02P`9010B3`0;3@X04A<@00d?300?4@h0
414?014C3P0?4@/00`0@4``05P0?4P/03Q4:00`?200=40T03a8;00hA2P0=40T03a89018E2@082`<0
41<800lB1`0@4`X02Pd400hA2P0J71L07R0K00d?300C5A804A<>010C300>4@X2010C308030l800@0
3A0900`?200>4@X041<<0`0?4P/0100H6a@02`h701DH4@0<3`P200lB2`07010C300?4P/041<<018E
3P0?4P`02`d800`>2@0200d?2P8030h90P0>40/04P0:30L02`d800lA300A4`h030h900d?2P0@4Pd0
3@l:00X<1`0@4Pd03@l:00h@2`0@4Pd03@l:00d>2@0B4Ph04A0<00l>2P803a0;01L03@l:00hC3@0>
4`d03Q<=00/B2`0:4@X02A09010D3@0>4@X030l8010C300A50d03Q4:01DH4@0@4``03Q4:00`?2@0?
4P/041<=014C3P0@4Pd04A<>010B3@0200h@2`803a4<0`0>40/0200=3`X0410>00l?3@0A4@l03`l=
00`<2P0@40h03`l=0P0@40h01@0?3`d04A4?01@D4P0C5A80418?00803@l<01003Q0=00lA3P0:30T0
3Q0=010B3`0A4a00BD]807=eLP0>40/03@l:00lA300@4Pd03a4<00/=20092`H03a4<0P0;3@P04`0@
4Pd07R0K05]MF00B50l03a4<014C3P092`H04A<>00lA300A4`h030h900lA300A4`h030h900/;2@0P
81h030`:00l?3@0<30X00`0@40h200l?3@803Ph<00<03@h9014B3@0A4Pd00P0?40/00`0A4Pd03Pl:
00l@2`03010A300@00l?300?3`d04Q8@014A3`0<30X03@d;018B400D51802`/9010@3P0A4@l030`:
01<D4@0=3`X02`d800`>2@803Q0;00@03a4<00T;1P092`H03a4<0P0<3PT0500B51007AlL010B3`0@
4Pl04Q@A00P:1`0@4Pl030h;01`N6`092`P05aTF00d?300>40d030h<01/M6`0H6QL03@l<014B400=
3``03Q0=100@4Pl0200D51@06a/K020P800X:2P020P800l?3`0=3@d03Ph>100?3`l0900>3a402@X<
014B500F5a/020T=01@E6@0G61d04a@I014B5`0C4a/04A4I00d>500<3@l03Q0?014C4P0B51<0418A
00h@3`0B51<07b4P01@F5@0<3Pd04A<B00lA400<3P/0418?00d?300K7AX0418?00d?300C5A80418?
00d?300?4@h04Q@A00d?31Cooooo000Kooooo`0=00P:1@0?4@d02P`900@51`0?41@05AHK010A5P0=
3Q<02``A00/<400=3Q403a4@00/<1`0200d>2@1:00/<1`0;2`P03@d;00`<2P0G5aH030`<00X:2P07
1`L02PX<01<D600B4aL03a0D00/<400W:2`0M7Ei08:3Q`0:2`l04Q<G014B5P0:2`l04A8F014B500<
3@l02``>01DF600G61X04A8D01<D5P0D5AL030d?00l@4P061`T0=CTl04U?F00941X000<=00/?6@0@
51d0720Y00/>5@0D5AX05QLL00X;400G61d04a@H01HG6`0G61`051DI01PI7@0E5QX03@hB014B5P0@
4AD03a0D00`=4@0B4aL06ahQ01@H6`0B5QT05ATL01HJ7@0A5QT03aDH00lG6@0>5QP03aPJ010J6`0?
6AX04QPK01DI700D61/04aLJ010D5`0?4aH201<G6P0e010D5`0E6A`061`O01@H6`0B5Q/082D[055F
FP0?51L03aDE018H600=4a<03Q@D01XO8P0>4aL082DY030e>P0L82404aLF01dQ8P0F6Q/061`M01LK
7P0V:Rd04aLJ01HI7P0520d04QDJ01hQ:00K7b804ADH01TM8@0Q92T07R4X020T;00J8BT061lY01DK
9P0A6B@05AdZ01dT=01=DF`0NGfJ03DjE`0L8cd0<CaB01l/?`0G93D08Rdm024[=`0=5B007RD`01LN
9P0C6R000P0G7b802P0F7R405alR01XR9@0H82<05AdP01<K7P0E7B00620S01LO8@0F71`2010F5P06
014F6@0?51L03Q<F01@I7@0@5AT04aPL0P0D6Al0200J7RL04QPT018H900C6BD051XV01<J8`0?5Qh0
5ahT0P0A6A`03@0@61X04AXI01DN7@0L8B@06AdP01PL7`0E6A`03a<F00`@4`0C5aX02`lB00lC5P0D
61/00P0B5QT0100B5QL051PI01@H6@0B5QL2014E600N01/N8`11A4T041<H01<F7@0J7B@03a8I014E
6@0?4a@03a<B014F4@0@5`l03aH>01DO5`0D7AX04Q/M01hW;P0?5b804a`V00hG7P0D7B@04QXR02he
>`0P:2/051/N01<I6@0B5QD04AHC018G4`0C61@051PH0`0C5aX06P0B5QT04A@I01@G700D5a`04QDL
014D6`0B5A`05APQ01PK800D61T041@E00lC4`0@5A403a@@014F4`0D61L051PI018E6@0@4aP04QDM
01@G700>4QD04ADE03Hj>@0j?c/04AH@0P0C6180100C61@04QHG014E5P0B5QT2010D5`0=00lC500>
4Q<03a<D010D4`0<40l03a<B014F4P0@5A403a@@014F400;4@d0318>00`B400200dC4@0@00hD500?
5AD0;38b01<H6`0730l051TL00/@4`0A5A@02a0<00dB3P0A5Q805Q/G01/P700@5A404AHB010E4@@0
3a@@0P0A5Q801@0?510041DA01<H500?510041DA00<04AHB00<03a@@010E4@0?51000P0=4Ph09`0?
510041DA01/P700:3`/04QLC024V8P0C61@05AXF010E4@0>4`l03A8>00hC3`0<4@d02a0<00X?2`0?
51005AXF01<H500<4@d03A8>00lD400@5A403a@@00dB3P0?510041DA00lD400;40`03A8>00`A3@0>
4`l051TE00T@2@073PL02a8;00`C30083`P02A0900hE3P0200`C300300lF3`0>5@h03A@=00803Q<<
00@0314:00lD3@0B5a0041D>1@0?50d0500>4P`03Q0;010B3@0?4@`03Q0;00lA300D5Q401PP3028T
7`0620<04Q@?00d?2P0930T03A8<00X?2@0G71H08RLQ01TN600J7aT06AhH0P0?50h200dB300B014F
400730D02@h701/P6@0B5a003A8;014F3`0@5@h04aPA018G400@5@h03A8;00/>1`1ZKFH02P`800T<
1@0C5Pl01PT40P0<3`P04@0>4@X03a8;014D3@0C5Pl020/40085000A50d041<<02T/9@0L7aP03Q4:
010C300A50d03a8;00d@2@0>4@X03a8;00803Q4:00P03A0900hA2P0?4P/02@`500hA2P0D5a004QD>
010C30803a8;01403Q4:00d@2@0=40T03Q4:00lB2`0A50d041<<00lB2`0>4@X03A0900`?200B50l0
1@L301dO6P0A4`h04aH?01TL5@03010C2P0<014D2@0B5@X041H:00dE2P0L8a/0TIR@0?Kmm@3=e<`0
?D@l01TP600A610031<;0P0;4PX0100:4@T0310<00X<2@082PL200lA3P0800T;200>40h02`d:01<E
4P0A4a00=SPe010B3@0=3`T300hA2P0F00d@2@0<3`P05QTB00X=1P0?4P/04aH?00lB2`0=40L020/1
00lB1`09304041<:014D2`0=40L03A0900hA2P0?4P/03@l:02HX8`0T9R403Q4:00`?20803A0900X0
30l800d@2@0>4@X03A0900hA2P0?4P/03Q4:014D3@0F6A8092LP0P0H6a@0200?4P/041<<00`?200>
4@X04A@=01@G400H6a@051LA0P0>40/07@0?4@`03Q0;00d?2P0@4Pd020X500/=200B50l00`D001@F
4@15Ad807R0K0084000<3PT02@/601<E400A4`h03@l:014C3P0E5a804A<>00d?2P0B4`h0414<00h?
2P0?40/0414<00h@2`0=3`X03Q0;00803A8<00/0314;00/B2`0>4@X041<<018E3P0?4P/041<<01DH
4@1?DT/0UiZC02d`:@0201PK500700hA2P0A4`h03Q0;010B3@0?4@`030h901<E400200d?2P803Q0;
0P0?4@`02@0@40h03`l=01<C4@0A4@l030`:010@3P0B4Q003@d;00l?3@0201DE4`0=00h>300@4Pl0
3Q0=00`>2`0=3``0418?01<E4P092`P03Q0=01<E4P0;3@X06adJ01dO700200lA300M00h@2`0=3`X0
3Q0;00lA300:30L030h9014C3P0?4@`030h900H80`0:30L03a4<018D3`0C5A0030h900H80`0@4Pd0
4A<>00h@2`0@4Pd04A<>00h@2`0C4a40?3`j01/K6@0<30X02@T701/K6@0?3`d00`0>3P`200d=2`08
00d>2@0A4Pd04A8=00h?2P0?40/04Q<>00`=200=3PT300h?2P0400`<2@0<30X03`l=010@3P803`l=
00<030`:018B400@40h00P0W9bD02P0?3`d04a@@01@F4@0@4Pd03@l:00`>2@0;3@P030h900X<1`08
2PD300`>2@0D00lA3@0H6QL05aTF00X<2@072@H030h;00d?300620D09BLT014C40092`P04aDB00`>
2`0?4@h061XG01XL6@0?4@h02@/800/=2P0<3P/200h@3@0500lA3P0>40d03@d=018B4P0@41000P0=
3@d03`0<30`051@D01<C4`0A4A403`l?00d=3@0<30`020X9018D4`0N7b405QLI01<D5P0<3A403PlC
00l@500200l@5@04010A5P0B4aT03a0B00h@3`803@l>01@04A<B01@F5@0F61L09BLV01LI600=3`h0
4Q@C00h@3`0N81d08B<P00d?30092`P03a4>01LI5P0D5Q<05QPE00lA3P0>40d04A<@00/=2QCooooo
000Kooooo`0o00`>2@0D5Q803a4>00@51`0A4QH04a@I00l@5@061``03a0E018C5`092Pd02P`;00@5
000:2`D02``700X;1P0<3@T04A4?00h>301SHf8071`L00P8200Q8B403@d=018C5P061`/0414E00l@
500E5QX0ADI:02X[;`020`L03a0D01DF6P0;31002P/?00h?4@0A4Q@04Q<E01HG6@0A4Q@020T;014B
500B4aD02``>00l@4P0000805ATL018H7`0E72H04APP01PL9@0000T000<<014D6`0?41D05aPM01PI
7P0=3Q<0414F018C5`0C51P04Q<G00804A8F00L0414E00d>4P0K72005QLK00X;3`0G61`05aTM0080
4QHI04d051PK01<G6P0?51L03aDH010H6P0?5aT03aPJ00hH6@0<5QL041HI01<G6P0B5QT04aLJ010D
5`0A5AP051PK01<G6P0A5AP05ATL01HJ7@0D61/051TL02<X;01<DED04QLJ01lT9`0D6QX04ALG01HL
700L8B@0724U01HK7`0?51T07B4R01@H5`0P92D04ADF010D5@0W:bh05ATL00X>4@0:3A80:B`a018E
6P0P8bP0C51A02@X:@0A5AL06AdP01`O900F6b006B0V01TP:00G7RL05AhW01LO:P0M93807B4j03Pl
E`0D6SD01`lV01<N<P0=6R/0:CI6028^>P0/=T802Q8M01dT;`0@5al05A`R01TQ900H82<04a/N018J
7@0G7b8072@W01/S9P0201@L7`806R8U050061dP01LM7P0I7R406QlR01LL7`0B5aX05AXN018G6`0E
6Qh05Q/Q01LL8P0L82T02Q4K00lE8@0D6bD04aXT014H800@5ad04aXP010H6`0>5QT03QHH010I600B
6aX06AdP018F6@0?4aH04ADH01TM800M8B@07R8U01<G6P0B5QT04ADH00lC5P0A5AP04QHG01DI6P0D
61T04QHG014E600B5QT0:B`a06MZK`0R9BX05APO01lR:@0P8bP051PJ01<G5P0D6AD05Q/E01<J4P0A
61005AlH00H?3P0J8RH0GVM`03<kAP0>5R003QLN018K8P0A6Ah0;3@g01dU:00C6Q/04aTI01<G5P0B
5a@04QLC01<H500D61P05ATL01@H6`0C5aX04QHI018E6P0C5Q/041<H00hA60803a8I00D04A@K01DH
7@0?4a@0310A00lC4`0201<G5P0;014E500A5AH04ADH018E6@0D5a`05QTP00lB5`0?4aH0310@01XN
7@0H7AT00P0?50h01@0@5@l04AHB00hB4`0=4A803a<F008041@G0`0?4a@01`0@51<03Q8A018F5@0E
6QH04QLC014F4P0D6A<00P0=4`l300dC4@0<00dC4`0F71`0<3Hf014F6@062`h05a`O01<I6P0?4a80
3Q<?014F4P0B5a<04AHB0P0>4`l01P0@5A404AHB00lD400=4Ph03Q<?00dB3P8041DA00D03Q<?00lD
400@5A403Q<?010E4@03014F4P03010E4@0?51003a@@00803Q<?0P0?51005@0<4@d051TE00T>2P0:
3`/04QLC00T>2P0?51003A8>00`A3@0>4`l03A8>00/@300=4Ph04QLC01TN6P0H7AT04AHB010E4@0?
51004AHB010E4@0200lD4007010E4@0>4`l02a0<00hC3`0;40`01P/700L<200200`C3007018I4P0A
61402a8;00XA2P0=50d02Q4:00/B2`0200dD3@0600`C300?50d03A8;00`A2P0C614051TB1P0?50d0
800>4P`03Q0;010B3@0?4@`03@l:00h@2`0B50l02@/601@F4@0B50l02@/600/=200F6Q@03A8<00/@
2P0A5Q0061dG00hC3@0?50h041D?00T>200@5@l03Q<=00`A2`0?50d01@X300H;100H7AH04QL@00dB
2`0?50d03A8;0P0?50d02`0>4``0314:0085000L7aP03A0:00hA2P0D5a005APA014D3@0@4``03a8;
00803Q4:00@03a8;014D3@0?4P/04aH?0P0E614020092`L03Q4:010C300A50d03a8;00d@2@0>4@X0
3a8;0P0>4@X02`0=40T03Q4:00lB2`072P<02@`500hA2P0@4``04A@=00lB2`0@4``03Q4:008030l8
00<03Q4:010C300=40T00P0=40T300`?200700/=200?4@`01PP300hA2P0:30P03a8;00hA200200lB
2@0M00lB1`0@4`P03Q@:02L/9@0O9Qh0H6MO0=;Id@32al405A`D014H400>5@d03A@<00/B2P083`L0
3QD=00h@300H6QL04Q@A01DG500G6AH03@l<00h@3@0<3P/020X700lA3P0H6QL051HA00`?200=40T0
0P0>4@X200`?200C02X]9P0=40T02`h700lB2`0<3`P03A0900`?1@0N8AH030l4014D2`0>4@P03A07
00`?200;3PL030l8014C3P0M7aX061XE00hA2P0200`?200?00d@2@0>4@X041<<00hA2P0=40T03Q4:
00lB2`0>4@X02`h700`?200L7aP051L@01<F3`0;3PL04A@=008030l800@03Q4:010C300A50d04A<=
0`0@4Pd03P0?4@`03Q0;014C3P092`H03@l:01@F4@031@005ALB04mAC00V:2<02P`7010B3@031@00
20X50P0:30L0300E5a807R0K01PJ5@0>40/04a@?014B3@0>3`X03a0;010A300>40/030h900d?2P<0
3A8<00l0318<00X=1P0>4@X04A@=00lB2`0A50d06QdF09^NU`3en?40?3lh0085000I71D061/D00h@
2`0:30L00P0>40/010092`H04Q@?00d?2P0=3`X200h@2`803a4<00T0410>014A3`0E5A<04a<A00h>
300A4@l051@B00d=2`0<30X00P0A4@l00`0:2PP03Q0=00d?300200d?300<010B3`0B51405QPE00`>
2`051`@0008001HH5@0K7AX0418=00lA300>40/03a4<0P0@4Pd02`0B50l02`d800d?2P0A4`h06A/F
00h@2`0I6aH06adH00d?2P0<3PT051HA00L0418=00H03`l=028R800C4a403Ph<00/;2@0?3`d2014A
3`80410>0P0?3`d00`0=3PT0414<010A300200l@2`0:010A300<3@P03@h900d>2@0>3`X03@h900`<
2@0>3P`0410>014A3`8051@B00T03`l=00`<2P0;2`T07AdK01lO7@0@40h0414>018D3`0?4@`00`0>
40/00`0=3`X030h900`>2@0200/=200500`>2@082PH02`d:024S800M7a`00P092`P040082PL051HC
01lQ7P0?4@h01@L400d?300;3@X07b4N03<e<P0E5a@01PP501XL6@0;3@X030h;00d?300>40d200d?
3006010@400:2PX051@D01hN7P0<30`03@d=0P0B4Q802@0A4A403`l?00l?3`0@41002`d<01LI600Q
8R@05QLI01PI6`0200`=4@0M014B5P0?41D02P/@00d>4`0A4QP030d?00h@3`0A4a804Q@C014C4P0>
40l030h=01LI600?4A002P`;00lA400>40l010H300`>2`041P<01PP501@F4`0A4a0030h;01HH5@0@
4Pl030h;010B3`0=3``05?ooool001_ooooo01403@l:00T;200?4@h051DG02@U:00:2a00414F00h?
500<3A802``@00/<3`0<3Pd05ADC01TJ5@0F5a803`l=00d=2`03010@3P0B00h>300@40h020P600d=
300=3Pl02P/=00h?4@0;30h030d?00d>400>3a404A8D00X;3@0?41802P/=01@E5`0>3a404Q<E0P0@
4A<0=@0?41802``>00h?4@0D5AL03PlA01DF600@4A<03Q0D00/?5@093QD02PlE00dB600?4QT04aHM
010C6P0:3A803Q4F01@G700?4QL0<C<h01@E6@0<3A405AHJ014B5P0@4AD05QLK00l@500e=SX0;Bhb
00d>4P0M7R803a4D010D5@0D61T04aLI010D5`0?51L04ALJ014I6`0A6A`04Q/M010J700>61X041HI
014E600C5aX06AdP01DI700D61/05ATL01<G6P0D61/05ATL00804aLJ00H041@H010E6@0D6A`051TL
01DJ7@0@5AP201LL7`0701HK7P0E6Qd06AhQ01LL800>41405ATJ02T];P0301LK700O01LK7P0C5aX0
61`O04mCEP0F6Q`07b<V03/o?`0H71/04QHF014E5P0B5QP06QlR01<K7P0D720061lV01HO9P0E7RH0
5b0Z01HK<00J7cH07bDm01/S>@0L:3X082hl01/X=`0A7BT072Ha018J9@0D6bH05A`T01LN900201DM
80805QhQ00L051`O01TQ900G7b804a/N01PP8`0O9bX05QhQ00805a`P0P0E6Qh04@0D6Ad04AHJ01DJ
7P0B5a/04aPL01<H7P0B5ad05AXQ010G800?5Ql04APP01<J8P0D6b804QTO01<K7`0C6ah04ATL0080
4QXL01804QTK01<G6P0G6ah05a/N01DI700I7B007R8U01lS9P0F6Qd04aLJ014E600F6Qd07B4T01DI
700H71l05a/N01DI700D61/201DI700H0413B00=41D051LL00lB5`0B5QT04QLE01@I500F6aD061dG
014H4@0>50l04AXF01`T9P0@61h05AhW00lG8P0@6B802aDH018L7`0<5AL0620R00lG6@0B6AX04aTI
0P0E6AP01P0C5aH04QLC01@H600E6A`051PK01<G6P804ADH02/04QDI010C600B5AX061/P01<F6P0B
5AX04aPK00dC4`0;4A4041HF01@J6P0A5aL041HG014F6@0@5AT04QLK01<H700D6Al04A@I010D5`0<
41004aLF00/@300B5a403a@>014F400B5a<03Q8C00dA4P0?4aH04ADH010D5`0@51D03a<D010D5@0A
5A@02`l>00lC4P0C61@03a@@00dB3P0B5a4041HC008041HD0P0=4a4200`B400601HL6P0;4A004ALG
010F5@0B61P03a@A0P0A5Q801`0B5a<04AHB00/@300<4@d04QLC01@I5@0A5Q800P0>4`l01@0<4@d0
3a@@00lD400>4`l03A8>00803Q<?00<041DA014F4P0A5Q800P0A5Q801@0?51004AHB018G4`0B5a<0
4AHB00803a@@01807b@P00dB3P0=4Ph0:BhZ01@I5@0?51003A8>00hC3`0A5Q8041DA00hC3`0A5Q80
41DA01<H500A5Q803Q<?010E4@0=4Ph2010E4@0;00hC3`0=4Ph03Q<?00dB3P0?510041DA00`A3@0?
510061dI010G400?5Pl00P0D6a@03@0?5Pl03QD>00lF3`0;4P/02Q4:00dD3@0>5@h03A@=00lD3@0C
614041D>014F3`0?50d01`0<4@X03@0=4P`03Q<=00`A2`0;40X0314;00lD3P0k@3X06QlJ00dB300@
5@l02@h8010E3`0<4@/00P0=4P`0400;40X092TS02/`:P093PP02a0:01`Q6`0E6Q@0314;00/@2P0C
61403a@=00X?200N8a`07B8K00dB2`0;40T300`A2P0J00dB2`0E61402`h700lB300>4@X041<<00`?
200B5@h04A@=00lB2`0=40T03Q4:010C300?4P/051L@00`?2@0G6Q<03Q4:00d?2P0>4@X041<<014D
3@0?4P/03A0900hA2P0?4P/200hA2P0:00d@2@0>4@X03a8;028U7P0I71D03A0900`?200>4@X02Pd6
00d@2@@03a8;0`0=40T03@0>4@X03a8;00lB2`0@4``04aH?03Lj<`072P<06QdF018E3`0930D03A09
00lB2P0?4PT00P0@4`X02@0>4`T010T303Y1>@0Y<2P0;SD]03Hm=@0F7AD03aH>00XA2@0300`C2`07
01DK500<3PT02`d800d?2P0;3@P02P`700`>2@0200h@2`0600T;1P0?4@`01`T501<E400>4@X03a8;
0P0@4``200hA2P0E01PK500930D03A0900hA2P0;3PL041<<014D2`0_<RT041<:014D2`0<3`P03Q4:
01<F3`0D5a0030l801<F3`0;3PL03Q4:014D3@0B5@h041<<00803a8;01@041<<00lB2`0=40T03Q4:
00lB2`0=40T03a8;00X=1P0B5@h03Q4:018E3P082`@04A@=010C300<3`P03Q4:014D3@0>4@X03A0:
010B3@804A<>00<03a4<00h@2`0>40/00P0@4Pd04P0;3@P02P`7010B3@0F61<00`D100d?2P0>40`0
2P`7018D3`0L7QT051HA014C3P0D5Q404Q@?00h@2`0B50l0418=00h@2`D03a4<00h0418=00dB300<
4@/02Pl901<F3`0@4``03A0900lB2`0@4``04QD>02X]9P1<CdP06ahG010C30803a8;00H03Q0;00d?
2P0H6QD05aTD00`>2@0?4@`400h@2`803a4<00D04A<@01<E4P0G6AH05ALD010B3`02014C4005010B
3`0<3P/02P`901<E4P0O8Ah00`0>40d200d?300E00`>2`092`P03a4>014C400:30T03Q0=00P:1`0?
4@`030h900d?2P0@4Pd04Q@?00lA300=3`X02`d800h@2`0;3@P07R0K01<E400;3@P030h900803@l:
00h03a4<018D3`0>40/03@l:00lA300>40/03@l:00lA300>40d020X701DG500=3``04A<@00/=2P80
3a4>0P0>40d200d?300500l@2`0=3PT03a0;018C3P0@4@`00`0>3`X0100?40/0414<00l@2`0>3`/2
010@3P0=00h>300C4a404Q8@010@3P071`D02`/900d=2`0;2`T04a<A014B3P0?4@`030h900d?2P02
00h@2`0;00d?2P0?4@`04A<>00`>2@0:30L03@l:00lA3@0=3``07AlL02HX9@0A4a000P0=3``00`0C
5A802``:00h@3P0200lA3P0600d?30092`P04A<@010B3`0E5a@02P`90P0?4@h07@0@4Pl03a4>00h@
3@0=3``03Q0?00`>3@0@4Q402P`;010B4@0B51<0418A00lA400=3`h030h=00d?3P0?4A00418A00d?
3P0@4Q404A8D00T:300@4A<030dA014B5P0?41@03@hC010A5P0=3Q<0414C0080418A00<03a4@00h@
3`0<3Pd00P0=3`h200lA400;00h@3`0@4Q405aTF010B3`0?4@h0828O034c<00>40d030h;020R7`0I
6aP00P0=3``00`0<3P_oooooooooo`0Booooo`006oooool0300=3`X02@/700H81@0J6ad0@D9600d>
4`082@h030dB00d>4`041@T03a0C00h@3`804a<A00D04Q8@010@3P0<30X020P600d=2`0200`<2P0:
00d>2@0>3`X03`l=00T;2`041@L04a@F00P92`0Z:bd0HfAV00l@4P803@h@00l03a0B00h?4@0=3Q00
3@h@00/<3P0?4180414C00d>400?41804A8D01TJ700P8B<08b@V03Hg>@0I6Qh01P0?4QL02P0@4aP0
2PlC00hC5`0;41H07B8X02`^<`0I6Qh05AHJ01<D600B4aL2014B5P0301<D600E5QX04a@H0080414E
00l04A<F018F5@0C5aH04QHF01<G600D6A`04APK00/C5P0@61/0620T00hG70094QL041HI01DI700D
61/00P0E6A`0200C5aX04ADH018F6@0D61/05QXM01@H6`0B5QT051TL0P0E6Qd01`0C61/04AHI01LL
800T:Bd05AXN010E600G71l00P0C61/01P0D61T04aLH018F5`0A5AH04QHG01DI6P<041@E00D04QHG
01DI600I7Ad05a/J01@I5@02018F5@0I01<G600C61/06R8U01XR9@0?5Q`05AhU00083`0J8R/07R<f
01/P=00L8SL07BDh01l[>`0X=T<062Hc01TU<@0J92h06b<^01`T;@0M92`072<Y01HN8@0J8RD08BT/
01dU:00200hF6@0>01DM800D71l03aLJ018J7@0M9BP07B8X01HK8@0>4aT06AhT00lD6P0T:Bl07b@Z
014F6`0J7b<201@I7@0E01PM8`0F6b405Q/Q00lD6P0>4aT04AHL00lD600H7B403A8E01<H6`0>4aH0
6b0S014F6@0F6Qd09RX]02<W:P0>4QD05ATL01TM800E6A`051PK00804aLJ0P0B5QT01`0E61d05aXO
01XM8P0F6Ah01`/>01lS9P0S9bX00P0D61/07P0J7R405ATL00dA4P0A5Q409R/U07UnN00K81X03A<?
02/a;@0=5Q@05AdO01@L8`0F7bP08b/f00hG7P0B71d041XK014J700A6QT041TH00lF5P0?5AD04ADD
01<G5P0E6AP05QXI01HJ6P0E6A`051PK01<G6P8051PK02L04QHI01DI700L82<03Q8E01HJ6`0>4QD0
5Q/K00/D4@0:4a8031DE00P@4P0;4aD03aLJ01LO8P0941H03QDK00dD6P0=4aP041<H00lC5P0?4a<0
4ADD018G4`0A5Q004aPB00lD3P0=4Ph051PI00/?400G6ah04QHI01XN8@072``05ATJ00`@4@0D61L0
4QHE014E500@5A400P0>4`l01P0=4P`03Q@B00dC4@0=4a403aDC010F50803Q@B01403A<A00dC400=
4a403Q@@010F4`0A5Q803a@@00X?2`0>4`l02Ph:00hC3`0A5Q805AXF028W8`0M8Qh03a@@01DJ5P06
00lD40804AHB0P0@5A4200lD400=00L<200A5Q804AHB014F4P0<4@d00`P400hC3`19CTX04AHB00/@
300A5Q805AXF010E4@0500lD400600hC3`0@5A404AHB00lD400;40`02@h:0P0@5A4200lD40@03Q<?
01@03a@@010E4@0@5A4041DA01/R6`0H7aP041L@014H4@0H7aP09bhW00hE3P0:4@X02a8;00hE3P0<
4``02A0900`A2P0C61405Q/D01<H4@803Q<<0P0?50d09`0>4``03A8;00dB2`0<4P/03aH?014H4@0>
5@h01@`501HM5P0@5a00U9^D05=JD`0C6Q<01@`501PO600=4`d04AH@00lD3P0<4@/02Pl902T^:00c
>38000D002P]9`0Y;RP02@h801LL5P0<4@/08BHO00/@2@0@5@h0IfaU051ECP0=4P/01``500/@2@0D
6A803a@=00L<1@03010C300300lB2`0>4@X03Q4:00H03A0900H04A@=010C300>4@X03A0900hA2P0A
50d3010C30803A0901<041<<018E3P0A50d03Q4:01PK500m@3T061/D02HY8P0J7AH030l800lB2`0B
5@h03Q4:00/>1`0@4``03a8;00T<1@0:3@H041<<00803A090P0<3`P200hA2P803A070P0>4@P01P0?
4PX03a8;01PK500:3@H04A@=00P;10802`h70P0>4``0200@5@h03a@=01DJ4`0U:R<07b@M00X?200=
4P/04aPA0P0=4P/06@0j?CH04QD>00P;100@4``02Pd600lB2`0;3PL04aH?018E3P0=40T03a8;01<F
3`0=40T03a8;01DH4@0<3`P03Q4:00/>1`0@4``03A0900`?200=40T03a8;010C300:3@H00P0C5Pl0
3`0=40T030l800hA2P0`<b`0?D0g01<F3@0A50/03A07018E300a=2d03A0900/>1`0?4P/03A09010C
300200d@2@0G01LJ4`0C5Pl03Q4:00`?200B5@h05QTB014D3@0@4``03a8;014D3@0D5a005APA00`?
200930D03Q4:00lA2`0A4`h03a4<00T;1P0?4@`051HA018D3`0?4@`00P0>40/04`0?4@`04A<>010B
3@0B50l030h9018D3`082PD0418=01/M600<3PT0418=014C3P031@0051HA00L<1P0:3`T01P/601<E
400I6aH00`0@4Pd01@0?4@`0418=018D3`0E5a803Q4:00803A0900H041<<018E3P0A50d04A@=010C
300>4@X300/>1`80418=00H03a4<00h@2`0=3`X030h900lA300<3PT200X<1`0?00h@2`0A4`h051HC
00T;200E5a@02`d:00`>2`0G6AH030h;00d?300?4@h03Q0=01DG500V:2D03a4>008030h;00<0418?
00lA3P051`@00P0@4Pl200h@3@0=00d?300<3P/0418=010B3@0?4@`03Q0;00`>2@0:30L0418=00lA
300<3PT02P`700`>2@0200h@2`<030h90P0>40/0100=3`X02`d800/=200=3`X200h@2`0<00h@3@0;
3@X04Q@A00d?300>40d030h;018D4@0G6AH03a4>00d?30031@803@l<0`0>3`X03@0@4@`04A8=014B
3@0A4Pd051D@010A300>3`X0414<00`=2@0=3@/03`l=010@3P0>3P`00P0=3@/0600A4@l04Q8@00/;
2@0;2`T03@d;00l@3@0?4@`030h900X<1`0;3@P03a4<014C3P0D5Q4061XE00P:1@0=3`X01PP3014C
3`0=3``03a4>014C400@4Pl03a4>01@F4`802P`901L03Q0=00L91P0=3``051HC00T;200C5A802P`9
014C400>40d030h;014C400?4@h03@l<010B3`0<3P/03a4@00P:2@0;3@`0418A00D71P0A4a8030h=
00h@3`0200lA400:010B4@0D5QD06adJ018D4@0C5A8051HE00`>3@0@4A<03PlA01DF60803a0D00@0
3@hB01HG6`0E5QP04Q@C0P0=3`h0100E5aH071hM00d?3P0A4a8200lA4008010B4@0;3@`01`T601<E
4P0=3``02@/8010B3`0?4@h2018D4@04010B3`0>40d03@l<00`>2aCooooo000Kooooo`0=014C3P0:
30P03a4>00X;3@0F5aX03a0E01hO90061``05AHK01DF6P0>3a802@X<00l?3`02010@3P803`l=00D0
3@d;00/;2@0;2`T02`/900`=200200d>2@0700d?3`0B4aD03PlA00H72@0B4aD08B8T00l@4P0200d>
400300l@4P0>3a403@h@00803a0B00/051DG01DF600@4A<0414C00`=3`0E5QP05aPJ014B500Q8R@0
2P/=00hB5@0500hA5P0600lB5`07310051TM01@I7`0=4QP0310E0P0;3100100@4AD04a@H01<D600B
4aL2014B5P0D01<D600D5AT05AHJ01<E5P0A5A@04QHE018F5P0C5aP051TL01DK7P0B6Qd05alR01hV
:P0F7b@04Q/P01<I7P0A5AP03Q8E00lC5P0C5aX201@H6`0401DI700G6ah06AdP01LK7P805ATL01L0
4aPK01@I700B5aX03a@G01DJ7P0V:bl06b0T01TN8P0N8bH05a`O01HK7P0E6AX051PI01<G600A5AH0
4QHG01<G600B5QL04ADF010D500A5A@04QHE01DI600200hC3`0`010D4`0B5QD04QHG010E600A6A`0
4a/N014H7P0H8BP00``C028Z<`0I7bl04AHY01/R=@0P:CX04Ad[01`Z=@0B82/05B4[01LQ:`0G82T0
5AdV018I8@0J8BL0620S01/S9P0N9RT06R8U010H6`0E7B00620S01TQ900H82<06b<V01lW:P0l@DL0
5QXR02@Y;`0R9bd0724W09:GW@15BU005a`Q010E6@0N8bL04AHJ01TN8P0A5Q`05AXP0P0B5ad04@0E
6Ql04AHJ00dB5P0>4aH06AhQ010E600F6ah020d@01DI700B5QT06AdP01dQ900F6Qd02@d@00lC5P0@
51L04ADH00804aLJ00H051PK01DH7@0;3Q<06QdR0454B@0W:bh201TM800J01@H6`0C5aX051PK018F
6@0@51D05a`G028W8@1GG5H05a`F00`B3P0H7Q`04AXI00041`14C58010dF018K900D7B803QPG00hH
6@0A6QT04a`K014J6@0@5aL041HF018F5@0C5aH201@H5`0301DI6`0C5aX04aLJ00804aLJ0P0D61/0
5P0@51L04ADH018F5`0T:2T051PI010F5@0:4a002a@C00hF5`0B6Q`041PK00`D5`0Q:2h02Q4G01@K
8@083aD061lT01@H6`0B5QT04ADE018F5@0B5a<200lD3P04018G4@0=4Ph05a/L01@H6@80310C00/0
9b/^01HJ6`0=4A8020`=00L9200A5A@041@C010E4@0?51003Q<?00hC3P0200`B400300lE4`0B61H0
4ALE00803A<A0P0=4`l200hD4007010F4P0C61@0314=01@I5@0A5Q803A8>01dR7P0200dB3P0401HK
5`0B5a<020d9014F4PH03a@@0P0@5A4200lD40803Q<?00l04AHB00@91@0O920041DA00hC3`0C61@0
3Q<?03Ll>00N8al06QlK00hC3`093PX02Pl;00/@300<4@d00P0=4Ph00`0>4`l03a@@00lD400200lD
40803Q<?00<041DA00lD400?51000P0>4`l0100=4Ph03Q<?00hC3`0?5103010E4@07010G400?5Pl0
2A0900/B2`0<4``05ahG00hE3P0200/B2`0:00dD3@0<4``02A0900dB2`0C614051TB018G400=4P/0
3Q<<00lD3@803Q<<0P0=4P/00`083PL02a8;01DL5@02010G400O00dD3@052`D0<CPa00/B2`0940T0
00@0010G400F71D010T30002000J7aT04QLA00P=1`0@5@l00PL101TN600N8ad02a0:01HK5@0@5@h0
3A8;0087000;40T05Q/D010E3P0=4P/04aPA018G40052P<00@H0010E3P03010C300300lB2`0>4@X0
3Q4:00H03a8;01/06A`E01LJ4`0B5@h03Q4:00d@2@0>4@X030l800lB2`0A50d03a8;00hA2P0@4``0
2@`500`?200>4@X020/401hQ6P041`404A@=00hA2P0B5@h06ahG01HI4P082`@03A09010C300>4@X0
0P0;3PL0100?4P/041<<00lB2`0=40T200`?200300d@2@0=40L03A0700803Q4800P03a8:00lB2`01
100061/D00`?200D5a005APA010C30803a@=0100314:00X?200@5@h05Q/D01DJ4`0:3`P041D>01<H
4@0<4@X03a@=02lb:`0@4``03a8;018E3P0?4P/041<<0P0=40T200`?200?00hA2P0?4P/04A@=00lB
2`0930D03a8;01HI4P041`0041<<00d@2@0<3`P03A0900lB2`0@4``03A0900804aH?00H03a8;00hA
2P0?4P/05APA01/N5@0;3PD2010C2P0601TL4`0h>c@06A`E01@G400B5@h03Q4:0P0=40T01`0@4``0
5APA00hA2P0<3`P03Q4:018E3P0E61400P0B5@h03`0C5Pl030l800<6000Q91d07B0I00`?200F6A80
20X400lA300C5A004Q@?00`>2@0;3@P030h900d?2P0200`>2@0D00d?2P0>40/03a4<00H80`0:30L0
30h9010B3@0;3@P01`T400lA300>40/02`d801TK5P0^<2/00@H0028W8@062PD02P`701@F4@0?4@d2
00h@2`803a4<00P04A<>01<E400>4@X03A0900hA2P0@4``04A@=010C30803Q4:100=40T2010B3@05
00lA300=3`X03@l:00`>2@0;3@P00P0<3PT0200=3`X03a4<010B3@000P004aDB00L91P0H6QL0418?
0P0B5140300?4@h03Q0=00`>2`0=3``05aTF010B3`0=3``02`d:00h@3@0?4@h02P`900d?30D03Q0=
1P0=3`X0200;3@P03@l:00h@2`0>40/02`d800X<1`0<3PT03Q0;0P0?4@`01@0<3PT02`d8018D3`0=
3`X030h900803a4<00h03@l:014C400:30T010H300h@3@0D5Q<0418?00lA3`0?4@h061XG00lA3P0H
6QL0;S0]00l@2`803Pl:00D03a0;010A300@4@`0414<01<D3`0200l@2`05014B3@0?3``0410>014A
3`0?3`d00P0=3@/200h>300C01@D4P0J6QP0410>018B400F5a@05QPC01TK5P0C5A0030h900d?2P0>
40/01`T400/=200F61<0:B/V00d?2P092`L03Q0=00lA3P04010B3`0?00`>2`0E5a@06A/H01<E4P0@
4Pl02P`902HX9@0A4a00004000`>2`0A4a003a4>018D4@0?4@h02`d:00803a4>00T020X901lQ800L
7Qd00P@300L9200C5A@03a4@010B4@0A4a800P0?4A005@0B51<0=CLd01lQ7P082PL02@/:01DG5P0j
>cd08b@V03Lh>P0Q8RH03@hB018C5`082@`04Q<E010B4@0?4A003Q0?014C4P0C5A@03@l>018D4`02
010B4@08018D4`0=3`h04A<@00`>2`0?4@h04aDB014C400?4@h2010B3`0400lA3P0>40d03Q0=00d?
31Cooooo000Kooooo`0<00D70`0;3@T0418?00X;3@0;30l02P/@01/L8@0>3a@01PL<00H62P0F5aX0
51DG0`0<30`0400?3`l04Q8A01@D4P0;2`T030`900`=200=3PT03@h800d>2@0<3P`03@l>00lA400C
5A@03a4@00/=300?4A0200d?3P0300lA400>40l03@l>00803PlA0P0E5QP200l@4P0700h?4@0D5AL0
4Q<E00T:300F5aT02P/=00l@4P0200l@4`0900l@500=4A@03A4D01@I7@0@5AT04AHJ00XA5`0=51X0
4ADJ008051DI00L05QLK01DF6P0A4QH04A8F01<D600D5AT04a@H00804Q<G02@04Q@E010E4@0@51<0
4QHF01DI6P0E6Qd04aXM010H6`0B6Al05AdT01<L8`0B6b805A/P01<G6P0@51L04aLJ01TM800L82<0
6AdP01@H6`0F6Qd05a/N01HJ7@0D61/051TJ018H600D6A`04QLK00hC5`0B5ad05a`R01<H7@0E6Qh0
51TL00hD5@0A5aL201@H6`0701<G6P0C5aP04aLH01<G600F6QT05ATH018G5002010E4@04014F4P0C
5aH04aLF01<G5P804aLH02004aPL01TQ900A61d04aXQ020Y<00D7BD07bPb028X=`0I7bh0;3=303Ho
C@0P;3P0:CM101HT;P0I9Bh06bD^01/T;@0F7RP04aXR01@K8@0I8B@06b<V01PP8`0D71l04a/N00hF
6@0?5aX04ATL018J7@0C6ah04aXP010D7@805a/U00X061`V01XN9`0b=Sl0;34g01<H7@0I7R80D5EI
02<X;00G72003a8G0P0E61d0400F6Ah06A`Q01DH7@0E6A`0310C01<G6P0K7b80ATY=04]?DP0L82<0
61`O01<G6P0B5QT051PK01PL7`0B5QT301<G6P09018F6@0A5AT04aHL01`O9P0H6b8082<X01DH7@0A
51T04ADH00805QXK01H04ADF018F5`0E6AT041@A018G4`0K81`05Q/H01@J600C6AP041TI01TQ902;
U9L09S0d00hG700B6ad04A`H014K6@0C7AX04a`I010I5P0@61D04QPF0P0C5aH2018F5@0W018F600A
51T04A@I018E6@0C5aX051PK01@H6@0>4Q<04aLH02DY:@0i?C`06AdL00hE4`0B6aP05AhM00lH6@09
41@02a8H03HmA01>EEd05QdU014H7`0>5A/03aLJ01DI700D61/04QHF018F5@0A5Q803Q<=00dB300G
71H03a@@00/?400<41404ADH01DI700C5aX0310A00803a<D00<051PG00lC4P0?4a800`0?51002P0@
5A00318@00dC4`0A5aD051XH01<I5`0>51003A<?00dD3P0>5@l300lF3`0<00T<2@0D6AD02@h:00hC
3`13B4@05AXF01<H500@5A404QLC00lD400<4@d05AXF2@0?510200hC3`0800dB3P0G71P05Q/G00/@
300A5Q803A8>00lD400B5a<200dB3P802a0<00D03a@@00hC3`0?51003a@@014F4P02018G4`04010E
4@0?51003a@@010E4@804QLC00<03a@@00hC3`0>4`l00P0=4Ph0100<4@d03Q<?00hC3`0>4`l300lD
400700lF3`0=50d02a8;014H4@0940T031<<00hE3P0200`C300800dD3@0;4P/02a8;010E3P0B5a00
4AH?00hC300=4P/400hC30803A8;01X03A<<0005000I81T02A09018I4P042`@041L@00D<1@0940T0
4QTB00`C300G7QL0AD]4034f<00=4P`04AH@00/@2P0A5Q0041D?00X?2@093PP03a@>00dB300>4`d0
3A8<00hC30805a`E00@02Pl800T>1`0>4``04AH?0P0=4P/00`0A5Pl0314:010C3002010C300300lB
2`0>4@X03Q4:00H03Q4:00P061/D01LJ4`0C5Pl041<<00lB2`0@4``02Pd600d@2@804A@=010041<<
014D3@0:3@H02@`501LJ4`0@4``05QTB018E3P0930D02Pd6014D3@0H6a@04aH?00T<1@0A50d041<<
0P0>4@X0300?4P/03Q4:018E3P0A50d03a8;00hA2P0=40T03A0800d@1P0=40D03Q4600hA20803a89
00@03A0906IYHP0K7QL04A<>0P0=3`X04`0=40T04A@=00P;100;3PL051L@00X=1P0>4@X030l801<F
3`0B5@h03A09014D3@0D5a001`X301<F3`0<3`P041<<00X=1P0C5Pl00P0>4@X300lB2`0K014D3@0B
5@h01`X3020S700c=Rl05APA010C300>4@X03A0900hA2P0?4P/041<<00lA300>40/03a4<00lB2`0>
4@X03A0900lB2@082`8041<:00hA1P0=40D04A@:01<F3P0:3@H030l800803Q4:00@03A0900hA2P0B
5@h04aH?0P0=40T200hA2P0A010C300>4@X04QD>01@G400A50d02@`702d`:@0V:B803a8<01`O600A
4`d03Q0;00`>2@0B50l02@/600X<1`0@4Pd00P0=3`X0600>40/03a4<00lA300@4Pd02P`7034c;P0<
3PX03a4<00d?2P0:30L03@l:00lA30072@@03Q0;01/N600K81X07B@M01@I4`083@L04QLA010B3@0<
3PT03@l:010A30<04A8=00H041<<00hA2P0>4@X03a8;010C300>4@X200`?20<03a8;00D03Q4:010B
3@0?4@`03a4<00d?2P0200`>2@0300/=200>40/03a4<00803a4<00h03Q0;018G4`0<4@d03Q<?00`A
3@1HGET0EEYF01DJ5P0?51003Q<?00dB3P0:3`/0314=00lA3P803@l<00@030h;00h@3@0B514030h;
0P0=3``0:`0>40d03a4>00lA3P0F61<04aD@00lA300>40/03a4<010B3@0Q8ah05QPC00h@2`0?4@`0
418=00h@2`0:30L03a4<018D3`0A4`h02`d800T;1P0>40/03a4<010B3@0?4@`03@l:00`>2@0?5100
2@h:01<H500;40`07R<O06Y_J`1HGET05AXF01<H500<4@d03a@@02lc;`0A4Pd0414<00l@2`0>3`X0
0`0?40/03P0C50l03a0;010A300C50l04a<@01@D4P0C4a40410>00d=2`0>3P`0410>00l?3@0H61H0
7alM0P0=3@/03P0B4a004Q@?01PJ5@0E5a803Q0;010B3@0A4`h03a4<01@F4@0M7aX0;BlZ01@F4@0?
4@d03a4>0P0>40d01`0?4@h04A<@018D4@092`P03Q0=014C400<3P/00P0@4Pl0500=3``03a0>01dO
700V:2D030h;018D4@0C5A803a4>00`>2`0?4@h04Q@A03i2@@2KWih07B4P00`@3`0B5QD09BPW00lC
4P0@51<03a<B0P0<40l05@0>4Q403Q0=00/=2P0?4@h04Q@A00d?300?4A0030d?01PI6`0A4Q@03PlC
00l@500?41<03@l?00h@3`0@4Q403a4@00d?3P0;3@`03Q0?014C4P0200h@3`09010B4@0<3Pd0418?
00h@3@0D5Q<04Q@A00/=2P0B51403@l<00<03Q0=0P0?4@hDooooo`006oooool030092`H02`d900P:
1`0?41804Q<G00X;40020`P03PlD00`=4P0:2`l07b0S01<D5P8030`>00d02`/=00d=3@0@40l04a<A
00`=200>3`X03a0;00l@2P0>3`T03Pl:010B400;3@`02P`;00<03@l>00d03a4@00d?3P0=3`h03a4@
00h@3`0=3`h03PlA00T:300=3Q003PlA00d>400?41803PlA00803@h@00<03a0B01<D5P0=3Q000`0B
4Q802@0A4Q@03a<F00lC5P0A5QX03QHI00082`042@l00P/@00/A5@0200d>4P07014B5P0H6Ad06Q/O
01LH700K72008R<W01dN8P0201<D600=01@G5P0?50h03Q<?014F4`0E6AP051XJ01<I700B6Qd04aXP
018J8@0E7RD05QlX01@J8002010D5`0E01@H6`0G6ah05a/N01<G6P0@51L04ADH018F6@0A5AP041@G
018G600C6AL05a`N01HK7`0A5QX04QLN01HJ8`0F6b405a`P01@I700C6AT07B<S008041@G02T04aLJ
01@H6@0E6AX05ATH01HJ6@0E6QH04aPD018G4@0C61805AXE01`P7`0I7Ah04ADF00dA500B5QT07R<W
014H7P0G7RH08BPa018K900=5B006B4/01HL:00J82`07RHb01lY<`0O;3D082hg01<Q:P0C82P04Q`U
01<L9@0E7BH05ahV00hE6`0F7R405alR018J7@0@61/04a/N010H6`0201LO8P0A014I700B6Qd06B0V
00hB7@0D62@08RHa01lS;P0J7RP06AdV014F700H7B800`P<038g>`0G72005AXM01<G6P0E6A/00P0@
51L02@0E6A`051PK01lS9P0I7B00720S00d@5@0M82D061/P01TM800201HJ7@0Q01hR9@0=4A@03A4D
00/?4P0<41<03Q8E014E600E6A`05QTN01PK8`0C5Qd05APO01<F7@0A51T06A`Q01DI700E6AX05QXK
01HJ6@0C5aH04ADD01@H5`0A5A@02`l>01@H6@0;4A404QLJ00`D5P0H828082TZ01XT9@094a@04adK
00803aXD00X04A/F014J5@0>5a@041LE018H5P0C5aH04QHE014E500@51D041@F0P0@4aP0800@51P0
4ADH018F5`0@51D03A4@01DI600J7Qd07b@P00X?2`0?5a<031LC010J6@0A6a`03QLL03M0A`13C5D0
6R</02lh?`0E7R@04a`Q00dF6@0?51L03a<F00hB4P0@51<04AHB00lD3P0E6Q@0314;00dB3P0M8B80
3Q8C0P0:3Q401`0A5AP06AdN00@82@0@51D03a<B00hB4@0?4a800`0?51002@0@5A0041HD00hD500=
4a<03aDC014G5@0@5Q8031<<00dD3@0300lF3P0400hE3@0R9b401P/701lT80806AhJ00H01``8010E
4@0?51004AHB00lD400<4@d700lD40804AHB010041DA00lD400?51003a@@028W8`0;3``03A8>00lD
400D6AD01P/700lD400@5A405Q/G00/@300>4`l00PL30P0?51002`0>4`l03A8>00`A3@0<4@d03A8>
010E4@0B5a<04aPD014F4P0@5A403Q<?00<03A8>0P0<4@d500hC3`0700dB3P0@5a002Q4:00T@2@0A
61402A0900/B2`0200dD3@8031<<0P0;4P/00`0?50d041D>00hC300200`A2P803Q<<0P0=4P/200`A
2P0Q00/A2P0i@c/0P8Z2014K4`0>61004A/C00<;10074@T03aTA004;0`0;5@d01@l701/Q6`0F6aD0
8BHP01@I4`042@<051TC00`A2`0A5Q003A8<010E3`0<4@/01@X401LL5P0;40T061dF02ld;@0E6Q<0
41D>00X=2@083@H04AH?00802a0900D03a@=010C300@4``041<<00lB2`0200hA2PH03A0900H03Q4:
00d@2@0>4@X03Q4:00lB2`0@4``300hA2P0D00`?200>4@X051L@01lR6`0:3@H030l800lB2`0<3`P0
20/501<F3`0@4``02`h700X=1P0=40T03a8;018E3P0?4P/03Q4:00lB2`0@4``400hA2P0500lB2`0A
50d04A@;00d@1@0=4@@00P0>4@H04@0?4PP03a8903<f;`3;c/P0MgUd024S80061`D051HA010C300F
6A804QD>01/N5`0Y;2D06ahG01@G400<3`P02`h700<03Q4:00D041<:00`?1P0E60l030l601DH3`02
00hA200;01@G3P0C5Pd030l600X=100<3`H041<<018E3P0@4``04aH?01XM5P0;3PL01P0>4@X0400B
51003a4>00lA300A4`h03a8;00hA2P0>4@P041<8018E2P0@4`P05a/=018E2P0B5@d05APA01<F3`0A
50d4010C300H018E3P0D5a004A@=00d@2@0?4P/03Q4:00`?200@4``04A@=00`?200?4P/03A09014D
3@0>4@X04A@=02X]9`0K7AP02P`700d?2P072@@010H100`>2@0>40/03a4<0`0@4Pd0400A4`h0418=
04=5@00@4Pd03@l:014C3P0H6QD03@l:01<E400@4Pd03Q0;014E3`052P@082LP00XA2P042@<200dB
300300d?2P0>40/04Q<>00804a8>00L0410<010C300>4@X03A0900hA2P0?4P/03A0900@03a8;00D0
3Q4:00d@2@0?4@`03a4<00h@2`0200`>2@0500/=200D5Q404A<>00d?2P0;3@P00P0=3`X02P0;40`0
51TE0002000>4`l041DA01DJ5P0A5Q803A8>00lD400A5Q8200dB3P8030h;00@04Q@A014C400=3``0
4A<@0P0>40d200d?308030h;00`06A/F01HH4`0A4`h03a4<010B3@0A4`h0:2XU01LI50092`H030h9
00lA300>40/200d?2P803Q0;00<03@l:00`>2@0B50l00P0Q8ah04P0D5Q403a4<014C3P0F6aL04QLC
00@91@0D6AD02Pl;01DJ5P0@5A4051TE00X?2`0@5A40314=04iCC`0A4Pd0414<00l@2`@03Pl:00D0
4Q<>00l@2`0@4@`04a@?018B3`02018B400R010@3P0?3`d04Q8@01@D4P0O7ad08R8P01DE4`0B4Q00
4a<A01HG4`0G6A@04A<>00d?2P0?4@`04A<>00lA300E5a807AlJ00T;1P0:30L01@L201@F4P0?4@h0
3Q0=00d?300?4@h04A<@018D4@0620D06A/H038d<@0E5a@03@l<00T;2@805aTF00D0BD]80=3Bc`0T
9R<0418?00lA3P02014C4080418?00T041@C03Tm?00=4A001PX900lC4P0C5aH03A4@00hB4@0?4a80
0P0=4A003@0@51<06A/H01@F4@0?4@`03a4>010B3`0I6aX06Q`K01PJ6@0A4Q@04a@F00T:300=3Q00
100>40l0400?4A00418A01@F5@0E5aH03a4@00d?3P0>40l02@/:00L91P0B51403@l<010B3`0J71T0
3Q0=00`>2`0=3``200h@3@80418?5?ooool001_ooooo00L04A<>00T;1`0<3P/04a@F018C5`0`<CH0
>CXo00803PlD00<03a0D00`=400<3@l00`0=3@l0400=3@d03`l>00l?3@0<3@P03Pl:010A300A4P`0
3a0:00h?2P0?4@l06A/J00P:2@0<3Pd04Q@C00840`0?4A0200d?3P0:00lA400>40l03@l>010A4`0:
2`d030d?00h?4@0?41804Q<E014B50803PlA00<04Q<E00l@4P0=3Q000`0B4Q80:00A4Q@03a<F00lC
5P0;41@04QXM00P@4`0U;3804AXO01DK7`0D5AT04a@H01TJ7P0Q8RH092DY01TJ7P0D5AT071dQ01TJ
7P0@4AD04Q<G01DH5`0@5@l03A8>014F4`0E6AP04aTI00hE5P0=5AP03A@J00XB6@0=5Qd03aPQ010F
700A5AP04QHI01DI700G6ah05QXM01<G6P0A5AP3018F6@0e014E600B5aL04aTG01PN7P0I7R8051TM
01DI8P0D624051TO01<H700@5AP04QPH01`R800?4a@041@G01<G6P0D61T05ATJ01DI600F6aL05AXF
01@I500C61805AXD01LL5`0N8R40720Q01HJ6`0B5QT06AdP02T^<`0R:C406B0X01TP:P0N9S40<SY5
01`T;`0L8Rh08RPd01hV<@0G8B/07BXc01XX<@0B8BP041dU00hH8@0?62404a/T01LN900?5Q`04a/N
01DM800D71l00P0C6ah0=`0>5QT05QhQ01DM800?5aX04QXM01dT:P0W:cH04QHR00lC7`0@51l061`V
00D94P0A5Q`08RL/00D:3P0K82@04QLJ01DJ7@0E6AX05QXK00lC500>4QD04aLJ018F6@0:3Q403Q8E
01TM800?4QL06A`Q00lB5`0I7B005ATL00/?4P0A5AP04QHI02L[;P0L82<05a/N01@H6`0B5QT04aLJ
01@G700C5Qh03A0G01PK8P0I72<04aHK01LJ7`0F6Qd04ADF018F5`0F6QT04ADD00`@3`0C5aL00P0B
5QL0400D61T03A8E01PM800@61X072@V00P>3@0H8R403QPG01LR7@0>6A<031LA00hH4`0@6A@03aPE
010H5@0B61H2018F5@03014E500@51D04ADH00804A@I01X041@H014E600A5AH04aLG018F5@0E6AP0
2Pl;00dB3P093PX06b<O00XE4@0640l02Q@E01lX;@1LIFh0F65Z00`E7P0/=Ch03QLM018K80094QD0
3A8E00dA500=4A403a<B010E4@803a@>00/03A8<01<H500C5aP01PX;038f>@1DF5/04QHI00lC500F
6Q/04QHG014E500200lC4P<03a@@01T03a@?014G5@0>51@02a4A00`B400?5A<041HB00/B2`0<4``0
3aH>010G3`0?5Ph03QD<00870@0B5a<05a`H00P=2@0G71P04AHB00hC3`0@5A404AHB010E4@0>4`l0
314=00H03a@@0P0A5Q83010E4@0=00lD40052PH03a@@01hS7`0730P0LgQd02@Y9@093PX03a@@00hC
3`062`L06AhJ01DJ5P02018G4`0;010E4@0>4`l03A8>00`A3@0=4Ph041DA01<H500B5a<03a@@00dB
3P0?51000P0>4`l200dB3P0400`A3@0>4`l03Q<?00hC3`<03A8>00T04APA00/B2`0940T04APA00/B
2`0>5@h03A@=00hE3P0=50d00P0;4P/01`0<4``0314:00hC300>4``0314:00dB2`0>4``00`0=4P/2
00`A2P0D00P?20074@T0<cde00D<1P033@D05AlG01<M5@0>610010h600/E3@0@6Q800@/300XA2`07
30H07B8L01HK5@0<4@/04AH@00H;1@0A5Q02018G4@0>00`A2`062`D02a0:00D:0`0B5a003a@=00L<
1@0B5a004AH?00lD3@0@5@h04aPA00lD3@093PL3010C300300lB2`0>4@X03Q4:00H03a8;0`0>4@X0
0`0=40T030l800`?2002010C300;00d@2@0:3@H03A0901@G400]<2T04aH?014D3@0I71D05QTB010C
300<3`P00P0=40T00`0;3PL03A09010C3002010C300400hA2P0=40T03Q4:00hA2P8030l800H03A09
00hA2P0A50d04QD<00d@1@0=4@@200hA1P0900lB200?4PT0=STb06i`JP0n@3/05QPE01TK60041P40
3@l:00804A@=01006QdF02HY8P0N8AX05QTB00d@2@0930D03A0900lB2`0=40T03a89018E300?4PT0
30l601<F3@0=40L04A@;0P0K7QD02@0A50/03Q48014D2`0;3PL03Q4:01@G400;3PL03A0900X=1P06
00hA2P<05ALD02<051HA018E3P0A50d03Q4801<F2`0;3P<03Q46018F200=40D03A08010C300<3`P0
2Pd600T<1@0<3`P04A@=00lB2`0A50d05QTB01<F3`0>4@X04A@=010C300?4P/051L@01<F3`0?4P/0
61/D00L:0`0?4P/03A090044000N8A/051HA00T;1P02010B3@802`d801L030h900d?2P0>40/03Q0;
00d?2P0@4Pd020X502@V8@0>40/051HA00h@2`0?4@`03Q0;00d?2P031@003Q0;010D3P0B6A80LGQa
020W800@5@l0314;00T=2@0200lA3005014B3@0B4@d04Q4=018A3@0?40X00P0=40T01P0>4@X03a8;
00hA2P0A50d041<<00lB2`803A0900D03Q4:00h@2`0>40/03Q0;00`>2@0200/=200>01HH4`0A4`h0
30h900/=200<3PT03Q0;00870`0>4`l041DA01HK5`0>4`l04AHB00hC3`0<4@d200hC3`0400X?2`0=
4Ph03Q0=00/=2P8051HC00P030h;00lA3P0?4@h03Q0=00d?300<3P/02`d:00X<2@803a4<00<03@l:
00h@2`0@4Pd00P0A4`h07`0<3PT02P`700`>2@0:30L020X500lA300<3PT02`d800`>2@0>40/03a4<
01DG4P0S9B008B<N014C3P0:30L03@l:01@I5@0=4Ph000D100lD400=4Ph04aPD00dB3P0H7AT01P/7
00`A3@001000<3Da010A300?40/00P0>3`X300l@2`0M01<D3`0?40/03a0;018C3P0@40d04A4?018B
400A4@l0410>018B400A4@l06a/I01`L6P0;2`T04a<A01DE4`0M7Q/08bDP01HH4`0>40/03a4<00h@
2`0A4`h06Q`G020R7@0C5A0061XE00h@2`0E5a<00P0>40d200lA3P0A010B3`0B51401@L401DG500Z
;2T03Q0=00X<2@0<3P/09bTV00L81P031@80>C/h00`>2`0>40d03@l<010B3`0C5A800P0?4@h02@00
0@003Q8A014E500J7Qd041@C00T=300<40l03A4@00hB4@0200dA400?010E4P082PL02P`7014C3P0C
5A803a4>00/=300620L05ALF00`=3`0?41806AXL01LH6P0@4Q403a4@00803Q0?00P0418A018D4`0H
6QT06A/J018D4`0?4A004A<B00d?3P803@l<00@01PP501XL6@0/;R/02@/80P0>40d200lA3P03010B
3`0A4a3ooooo01?ooooo000Kooooo`0O00`=2@0?40h01@H5018E5`0I6b007b8W02ha=`0;3Q803a4E
00h?4P0;30d04A4A00/;3P0=30l03Ph@00l?3`0>3Pd03@d;00/;200=3PT0414;010A300>3`P03@h8
00/=2`0@4Q403@l>00lA400@4Q403@l>00lA400200d?3`0?00lA4@0>41003@l?00h?4@0;30h03a0B
010A4`0>3a40414C00d>400B4aD04A8D010A4`0;30h04a@F00<04A4A00T0418A00hB4`0>4Q<03Q<F
00lF6@0?4aL0DEML018J7P0=4AD00P0>3a<00`0B4aL04a@H018C5`0201<D6080414E00`04A8F00l@
500C5A@04AHA00dB3P0@5A<051TH014F600?5QP051`P01@K8P0@620201<L9007018H7P0A5AT03a<G
018E6@0F6Qh06A`P01HI7@03018E6@0G018F6@0B5AT04AHF014G5@0I7al06QlS01HK7`0F6b8051TP
01DJ800D6Ad04aPK01@J6P0E6aT051PI01@H6`0E6A`051PI01<G600A5A@05Q/H01DJ5`0D6A@00P0B
5a40800E6Q@04aLH01LK7P0J7R4051PL018E6P0F6b0061lW01DL9@0A5b805QdY0418E00N9S405ahZ
01DL:00K92h06bD^014N9`0C8RT0528Y01@P:00C7BD04a`S01<K8@0C6R005QhR014I700C6ah06b<V
01`T9`0E7B004a/N0P0D71l03@0F7R4082P[02T`=P1<D5/05a/W01XN:P0B5R404aLQ024U;@0B5ad0
61dQ01`Q900I7R800P0F6ah03`0C5aT05a/M01@H6@0D61X05QXM018F6@0G6ah03a<F01HJ7@0?4QH0
720T018F6P0Q9BL07R8T014E5`0201PL7`0@03Di?00V:Rd0720S01DI700B5QT051LK01HI7P0D5al0
5APO018E700E61l06A`Q00lB5P0G6ad04QHG018F5P8051PG04T04QHE01<H6P0B5QT05ATL018G6P0F
6ah04QPK010H6P0@6AP04Q/J010K5`0K9R806bHP01lZ8`0I91h04ahH014J500?6A803aLC014G500A
5Q<04AHD014E5@0A5AH04aLJ01DH7@0C5Q/04QDI010D5`0@51D04QHF00lC4P0C61@03Q<?01@I4`0@
5@l06R8K010K5P0A6QP03aPJ01LP9@0J8RX05QhX018K900;4a`03QHL01/U:00a>C/04QLI014E5`0?
4a<041DB010E4@0>4`d03A8=010E400>4a003a<D00`@4@0]<C@0CU9F018F6P0B5QP03a<D01dQ8@0F
6aT04QHD014E4`0@5A403a@@00hC3`0>4`h03A<B00802a4A00`03Q@C00hD4P0=4`l02a8<00`C300?
5Pl04AP?010H3@0>5@`051TD01DJ5P0>4`l200/@300301DJ5P0A5Q804AHB00803a@@00<04AHB00hC
3`0?51001@0?5102010E4@803a@@0P0>4`l0300G71P03A8>01@I5@0:3`/07B8N00L;200D6AD03a@@
00dB3P0A5Q808BHR02hc;`804AHB0P0@5Q800`0@5A403aDA00lE4@0200hD400300hC3`0=4Ph03A<?
008041DA0P0?510400hC3`803A8>0P0<4@d03`0=5@d03QD>00`E3@0B6Q<031<<00lG400<50`03aH?
00dE3P0:4PX02a8;00dD3@093PL03A8;00hC300200dB2`0300hC300=4P/03A8;0080314:01`02a09
01lV7P0M9al02Q8;00hG3`084PX0210900dF3`0<5Ph0210900`F3P0640P03QL?00/B2`0>4`d0314;
00hC3@0;40X0314;010E3`0<4@/03Q<=00dB300>4`d04AH@00lD3@0:3`P05a`E0P0>4``01`0M8Q/0
;c@]02`a:P0E6Q<06AhG010E3P0>4``00`0@4``00`0?4P/03Q4:00hA2P0600hA2P@04A@=00<041<<
00hA2P0@4``00P0@4``200d@2@0X014D3@0?4``01@T200lC300C5a003a<<014E3P093@H0310900lC
300;3`P03109010D3@0<3`P041<<00lB2`0:3@H02`h7010C300>4@X03A0900`?200=40T03Q4:00lB
2@0=40D03A4300hB100>4@H03a8800lB2@0>4@X04A@=01TK5P041P<0418>018E3`0A4`d030l800d@
2@803a8;014041<<00/>1`0@4``03a8;00hA2P0@4``04QD>00d@200I71@01`X1018E3@0?4PX02Pd4
01<F3@0D5`l051L>01<F3@02010C2`0600lB2`0@4``04A@=00d@2@0D5a0041<<0P0>4@X200lB2`0A
00hA2P0=40T04A<?01PJ5`0G6AD0418=00hA2P0@4``04QD<00`?1@072P005AT<00H:000?4PL03Q49
014D3@0>4@X00P0B5@h03@0>4@X04QD>01<F3`0>4@/04A@=018D3P0=40T03Q4:00lA2`0B5@h061/D
01HH4P0C5Pl00P0=40X02@0E61403A0900/>200@4Pd03a4<00d?2P0<3PT03a4<010B3@0200d?2P0F
00h@2`0@4Pd03a4<00h@2`0>4@d03A0=00/>2`0?4`h0310:00hA300>4@/02Ph802HY8`0L7QT02`d8
014D3`083`P0:c@/01`S700C6Q<01@`500dA30803a4<00`03Pl:00h>2P0?3`X04@l<00d?2@0;3PL0
30l800hA2P0@4``03a8;014D3@0?4P/200`?200800lB2`0D5a003Q0;00h@2`0=3`X030h900/=200:
30L400lA300D010B3@0?4Pd04aTE01TN6`0G7AT01PX700`B3P083PX02Q0<00`B3P0?5A403Q<?00hD
400H7AT05aXG00/=2P0@4Pl051HC00d?300@4Pl400`>2`0400d?300=3`/030h900d?2P803Q0;0P0?
4@`0100<3PT03Q0;00h@2`0?4@`2010B3@0400h@2`0=3`X030h900d?2P803Q0;0P0A4`h04@0@4Pd0
3a4<00h@2`0=4@/02Pl;00hD400?5A402@l;014G4`0K8Ad061hJ00/A3@0<4Ph02a0<01<I5@0?5100
3a0;00803Pl:00h0414<014B3@0A4Pd04A8=01@E400@4@`03a0;014B3@0@40d04Q8@01<C4@0B4Q00
3`l=00h>3080410>0P0>3P`2010@3P05010A3@0B50l0418=00h@2`0=3`X00P0>40/02@0?4@`051HA
00`>2@0F61<02P`7010B3P0>40d03a4>014C4003010B3`09018D4@0K7AX05QPE010B3`0C5A80418?
00/=2P0@4Pl06A/H00803a4>00`04A<@00`>2`0=3``03a4>00`>2`0@4a003Q8A00X@3P0B61H02Q0>
00lE4`12B4H300lE4`0400/A3`0:40h03A8?010D3`804Q@?00@04A<@018D4@0A4a003Q0?0P0D5QD0
0`0K71h05AHH00d>400300lB4@0500hA400=40l030l>014D4`0C5QD00P0=40l0200A51<03Q4@01<E
4P0B51404A<@01PJ5`0J71T02P`91P0A4a0Dooooo`006oooool09P0E4aP030/@00<63@0010l0GVMa
04aFH00G8BX02aHI00L=3@0:3`/0414900h>1P0=3@/03a4@020R8@031@@03Q0?00X<2`0>40l03@h?
00l@4P0A4Q@030d?010A4`092`X0418A00d?3P0:2`d030d?00/<3P0<3@l03PlC00d>4P0A4QH02``@
010A5@0?41803@h@0P0>3a402@0:2`d020T;00d>400G61X05AHH01<D5P0>3a401`P:014B5002018C
5@0>014B500>3a403@h@01@G600E6AX03Q8E00T=400F6Qd0;C0d00hA5P0=41D061/P00lB5`0;3Q<2
01hQ9P0N010C600<3a@04A@I018E6P0F61T071hM00/?400C5a/05AdP00dD6P0<5A/04a`S014J8@0=
5A`04QTO00lF700A5Qd04QHQ01LK9P0@51l0720[00lC700?4a/04AHL010E6`0A5Q`04AHJ014F700B
5aX04QPH0P0C61/0=@0D6A`051TM010E6@0J7b<09R/^01TN8@0=4QD051XJ01@I700J7b804aPK00hC
5P0E6Qd03a@F014G5`0B61P05A/K01@J6P0B61P03Q@D018H600I7al04QPH01<I6@0L8B@051TL010E
6@0L8BL0314G01DI8P0F7BD04aPR01LP<@0I93H05b8c01DQ;`0L:3D07R/d01/U;P0F8BP04a`Q018L
7P0C7Ah05AdO014I700C61`041DI01<H700J7b<061dQ01LL800H7B405AXN008051TM00<04AHJ014E
7P0F6R<00P0G72803P0E6R003a@H01DJ7P0C61/06AlO01XO8P0E6a/051TL014D6@0B5AX04QHI01@G
700Q9BP0;S8e0P0E6AX0300B5QD05ATH01@I5@0?5100318@01HL6P0630X06R0O01<I6@0F71`05AXM
00X?4`8041DI03l04AHL01XO9@0D5ah051LN01DH7@0G6Ql06A`Q01XN8@0D61X05a/L014E500?4a40
6QlK010F4P0?61D06b@S01`U900C71/031DD00/E500>61L051hO018L7@0C7A`06R@S05QSH@0jAd00
62DN01LT6P0?6a402QH:010L4@0>60l03aTA00`C400:410041DH014F6P0>4aL04AHI01@I700B61P0
3aDE018H5`0D6QH04QPD00dD3P0=50d04AP@00lF3P0?6A004APA00hF4`0U;Bl041DK010F7P0=51`0
2@dF00T?500B6Q`041DF00lD400?50h00P0?510200hC3`803Q8A01H03Q8B010D5@0B5QT051LL01DJ
800>4aT041DI01DK6`0;4@l04aTD014H4@0=50d02Q4:00hD400A5a<04ALD00P=400;41<03aDF00lE
5@042PX04QPG0P0:40`05P0:40/02a8;00dD300@5`l04ALC010F500E6aT04aTG00dC4@0A5aD03Q@B
00/A3`0<4Q003A<A00`B400?5A<0318@00X@3P0L8R00?TA201XP7P0B61H200lE4`0;00hD4P0=4a40
41HD01<I5`0I7ad03Q@B014G5@0X;R`0;C<a00H<2P0<4Q000P0@5Q@0400=4a40318@00dC4@0C71L0
3AHA00<<1`0>5a8031D@014J5@0@6A@01a0;00/D3`0=5Q404AXE00TB3@0?5@l200hC3@03010E3`0?
50h03Q<=008041D?0P0?50h03P0>4`d03A@=00hI4@0>61002aH>00LA2@0;5@d02aH>00HA2@0@6Q80
5b8J00TC2`0640P01@l70P0>5@h200dD3@0700`C300=50d04QTB01@K500?5Pl03A@=00/B2`0200XA
2P0;00dB300?5@h02A0900/@2P0>50h051/D00D:100@5Pl02a8;00/@2P0@5@h00`0=4P/02P0?50d0
41D>018G400E6Q<03Q<<00H;100E6Q<04aPA00H;0`093`<300/A1`0a00hD2P0@5@d03Q<<00`A2`0;
40X03Q<=018G4@0;40T020d6010E3P0:3`P03A8;010E3P062`@04AH?00lD3@0<4@X02@h700X?200?
4P/04QD>014D3@0>4@X04A@=010C300A50d03Q4:00lB2`0@4``03A0900lC30001`008BPQ00XA2P0?
5Pl04APA03Pm>00]=2d04APA00L>1`0B6A8020l800hE3P0D6A805QTB00T<1@0G6Q<05APA00/>1`02
00lB2`803Q4:010041<<010C2P0:4080318300dC1@0=4`L03A8:00`A2P0?50d04AH?00X@1P042P00
4aT=00T?0`0A50/041<<0P0?4P/06@0>4@X03A0900hA2P0<3`P04QD>010C300<3`P04A@=00d@2@0?
4@`02@`500T;1@0>40/041<<00T;1@0@4Pd06QdF00d@2P072@@051L@014F3P0>50X03A<900`B200=
4`T00`0>50X0@00@5P`04aT?018H3P0A5Pl03Q4:00h@2`0A50d03A0900hA2P0F6A803Q4:014D3@0A
50/03a8900hA200?4PT0318800/A1`0B60l041D>00dB2`0?50h05Q/E00870@0I7QT061dG00460P0I
7QT00080028W8`093@T04aPB010E4@0;40/02Pl900P=2@0>4`h03a@>00hC3`0=4Ph02@h:01<H500?
51000080020U8@0g?3P061dI00/@300@5A402@h:014F4P0E6Q/06b8X05EMH00>51<04a`G00`C2`0<
50T02a<801dT6P0L8AX02Pl801dR700=4P`3010E3`08018G4@083@L05Q/E010E3`0?4Pd03@l:00@6
0@0C5A0200X?200700`A2P0=4P/03a@=014F3`0>4``03A8;00`A2P0300/@2@`0314;05D03A@=00TB
2P084PX031<<00XA2P001P004QLA014F400<4@/0418=01<F4@0;40X04QLA00dB300A5Q0041D?00/@
2P0@5@l01@X4010E3`0730H02a0:00hC3@0C61802a0:00hC300G71D041D>00P=1P000`004QL@00@9
0P0:3`P05AXC00H;100L8AX02Pl:00lD3P0<4@/02a0:01<H4P0@5@l0314;00/@2P0>4`d0314;00dB
300B5a403Q<=010B3@0=4P`0310:00lA300>4`d04AD?00d?2P0;40X03a8=00h@2`0<3PT0:R`W00L9
100E5a8030h901XL5`0C5A0030h900T;1P0<3PT05aTD01<E400<3PT06A/F00`>2@082PD02`d801hP
6`0d=S406A/F03Tk=P0/;RT01PP301@F4@0@4Pd03a4<00803Q0;0P0=3`X03@0C5A002@/600h@2`0;
3@P03@l:00`>2@0A4`h06Q`G00`>2@0D5Q401@L201<E400>40/00P0?4@`0100A4`h04Q@?010B3@0=
4@/500`A2`0=01DJ50062`D00@H001`Q6`042@<04aPB010E4@0>4`l0314=00/@300<4@d03Q<?00P=
2@0200lD400=01@I5@0?5100314=018G4@0=4P/02Pl900`A2`0;40X03a@@00hC3`0<4@d041@C00L;
2P0200hB4@@03aDC00D03A<A00`B400>51804ALE00/A3`02010F500=00P>2P093PP03A8<00lD3P0;
40X02a0;01<H500=4Ph03Q8@00hB4@0=4A00310?00X>3@0Dooooo`006oooool03@0>2A005A<K00L:
4`0O9C40[;O20;;0b`0A7bP02QHJ00H?3P0<4@/04A8800l?1@0=3PT00P0>40l0600I6aX05AHG014B
500C51H030d@014B5P0720`03PlD00/<400<3Ph020X9010B4@0@4A<030d?01HG6@0D5AT05AHJ01PI
7@0=3Q<010D:01HG700B4aH03@h@00`=3`803@h@00@030d?00d>400C51H04A8D0P0@4A<00`0=3Q00
414C014B5002014B50803a0B00H02P/=00/<3P0C51H05QLI00l@4P0I6ah2010C600501TL8@0D5a`0
4QDJ01@G700C5Q/00P0B5AX0600@4aP030lD00/>400B4aD04QHI01<I7P0H8BP03QLN01DO:00B72D0
4a`S00lG7P0B6Al05Q/O02DZ<P0T:3@03Q8N00dA7@0>4Qd051PS01TM9P0B5Ql04ADN018G7@804aPN
0P0C61/0>`0E6Qd061dP01TN8@0K82<03a@G018G6P0K82<061dP014F6@0C61/05a`O01DJ7@0J7b80
5Q/N00X?4P0B5aX051TL01<H6`0B5aX04aPK01@I700G71l06AlO00`B4P0G7Ad08RPX01@J6P0F6ah0
5Q/O01lT:00B5a/061dS01LL8P0D6R804ah`01PU>00J9CP062@d020Z>@0T;SP04adW01@N900C7Al0
4A/M010J6P0B6Q`04QLK01DJ7P0D6Ad05Q/O01/P900F6al05AXN01<H700B5a/051TM01HK7`0D6Ad0
5AXP008051TO00/05a`P01HK7`0@5AT04QLJ01<I6P0nA4@0A4Y:02<Y:@0T:B`051LL01@G7@0201<F
6`0H01`P900W:bh05QXK01TM700G6aX05a`H01HK5@0C61804QPD038h=00K8Al03Q@B00D;2`0?5AD0
5Q/N00hC5`0C61`03a@J00X?5@0?51X06QdT01LJ7`0F6Ah051LL0P0C5aX02P0C5aP05QXI01HJ6@0C
61@06AhH010F4P0>61D05R4M01LR7P0B71/200`F5@0b00hH5`0=5aP04A/L01HP8@0H8R<0:3<b014N
5`0>6a@05R<I01HT5`074`L03AT<00XF30053`L04Q/G01hW9P0E6Qh020dA00dB5P0@5AP04QPI010F
5P0<4Q803Q@B014G4`0@5Q803A@>00dD3@0A61005QhD00H>0`0940T041HC01HK7P062`l02@dE00<8
3P0G7280724T00dB5@0C6AP041D?010E3P0A5Q004QLC014F4P0A5Q<04ADD014E5P0@51D2010D5`07
00lB5`0O8b`0HfM`00P=4@083Ph03Q@@014G4P0200hE3@0;00lF3P0@5Q803aDA00`B4@0W;2l00086
02<X:`0/<S804ALG00lE500>51800P0=4`l03@0=50d03aH?014H400?5A403Q@B018H5P0@5Q@0318@
014G5@0@5Q@05A/I00hD4P0:40h01@0<4Q001@0O9B<05A/I018H5P0;4@l0318@00802a4?00L03A<A
00hD4P0<4Q004aTG010F500C6AL06AlM00803A<A01803aDC01<I5`0E6aT05A/I00lH5@063`X03aXD
010K5@0C7QP01Q4;00LB300;50h0?DQ203a7@@0=61800Pd700L@2`0>50d2010E3`0400lD3P0A5Q00
4QLA00lD3P<03Q<=00<03A8<00`C300B71@00`0:5@d0500A71@00Pd500hI4@0=610021<;00XE3@0M
:20062<K00lF3`0>5@h031<<00XA2P083`P02Q4:010G400A61403QD>00`C30083`P01`d70P093PP0
2P0;40X02@h800hC3@0<4@/01P/500lD3P0730H04AH@018G4@083@L300`A2P0400dB2`0>4``0314:
00D:0`803a@=00X00PL000/@2@0D6Q0051X>014G2`0=4`P02a4700`B200>50/03Q<<0`0@5@l03`0?
50h03Q<<00X?200=4P/01@X300X?200C614051TB00lD3@062PD061dF01@I4P0<4@X03A09010C3002
00lB2`804QD>01P04A@=00hA2P0?4P/041<<00d@2@0>4P/072<L05QRFP0?6A401@l700`F3P0X<RX0
8B/S00dG3`053`L03QP@00PB2P0>5@h000D008B7P00e>3401`X300@60P0A50d200lB2`803A090100
3Q4:00hA200;4@<02a8300/A1@0;4@L02a4800/@2@0@5@h04QL?018H3P093`<03Q@500H<000@4`X0
41<<0`0?4P/03@0>4@X03A0900`?200@4``03a8;00/>1`0@4``0:2XU01DG4P0@4Pd06A/F018D3`0;
3@P00P0?4@`01`0D5Q403a4<00/=200A50d04aP@010F300>50X00P0=4`T03P0>50X03aD;00hD2P0@
5P`04aT?018H3P0@5P`02`h700d@2@0A50d03a8;00`?200@4``03Q4:0P0A50d0<P0?4P/03Q4:00lB
2`0;4@L02@l500lE300<4@X020d600T>200>4`d02Pl;014F4P052PH08bPT08^@S00O9200008000lD
400E6QH020d901@I5@0<4@d02Pl;00hC3`0=4Ph02a0<00dB3P0C61@09b`X02db;P0@5A406AhJ024V
8P0H7AT041DA00X?2`0?51006QlK01LM803Rjo80W:FZ02@^;P0010000``400TC200540804QX>01DJ
4`0:3`P04aPB0P052P@020062`D02a0:00hC3@0C61801``6018G4@093PP04AH@0P0;40X01`0>4``0
3A8;00dB2`0<4@X03A8;00hC300?50d0100>4``00`0@5@h0314;00`A2`0900`A2`0]00/B2`0530D0
2Q@<008<100;4P/031<<01PO600>4`d03Q8<00/=200=3`X04A<>00/=200=4P`02@h800dB300<4@/0
20d700/@2P042@<03A8<01<H4P0U:R@082DO00lD3P011P0041D>00T>1`052P<04QL@01<H4@083@H0
5Q/D00@90P0;40T0008000T>1`0=4@d041D?01DJ500930P02Pl900dB30093PP02Pl900802@h800D0
314;00dB300C5A004aD@014C3P0200h@2`0400lA300>40/030h900d?2P804A<>00P0418=04mAC00[
;BP04aD@00/=200K7AP020X5014C3P803a4<00l061XE01DG4P0;3@P02@/601DG4P0F61<020X501<E
400J71L0418=01XL5`0>40/03@l:01PJ5@0<3PT00`0?4@`200h@2`0=010B3@0E5a804aD@01HH4`0C
5A00418=00X<1`0>40/04Q@?014C3P0:30L03Q0;014C3P0200lA3004014C3P0B50l0418=00dA2`D0
314;01l02@h801HK5@0B5a4061dG00dB300>4`d02@h:00`A3@0>4`l0314=00/@300@5A406AhJ014F
4P0>4`l041DA01DJ5P0A5Q404aPB010E3P0B5a404aPB00lD3P0=4Ph05AXF00T>2P0J7Qd04QHE00P<
2`0>4a803Q@B00@03AHC01<031DB00D>2`0A6QL05b0M03i7A00L9B808R/V01LL5P0I7QP020d700H;
1@0F6aH06AhJ01HK5`0E6AL04aLF014E500@51<03a<B01Cooooo000Kooooo`0D00l:3`0@3a@00PD=
018F800lADl0>TMA00PE7@064AD020h>00/@300?40T03@d600h>300;3@`02P`;04M9B00];Rl03a0B
00d>400>3Q4200d>4P0K00d>4`0@4AH03a0C00X;3P082@`03a0D00X;3`0;310030dB00X;400?3aH0
30`D01PH8@0l?D<05aPK010A4`0=3Q00414C01<D5P0D5AL03PlA00l@4P0<3@l03@h@014B500B4aD0
414C00803a0B00h0414C018C5@0B4aD0414C01HG6@0N7b404Q<E01@E5`0@4QD03Q4F00lB5`0@4aP0
4aHK018E6P803Q4F01T04QDJ01<F6`0@4aP041<H01<G700<4QL06b8W01HN9P0T<3T03APQ01DR:`0=
6B804Q/S010H7`0:4QH051TM01@H7`0K7bT03A4L03<g@@0?51/051PQ014F7@0?51T041DJ00804AHJ
00@04QLK018G6P0B5aX04QLJ0P0C61/01P0D6A`061dP01<H6`0C61/05a`O01@I70804AHI00L03Q<F
01TN8@0I7R403A8E01<H6`0A5QT04QLJ008051TL02<04aPK018G6P0H7Qh07B<S01LM7@0?5AD09B/[
02P]<00E6Qh05Q/O01<H700F6b404aPN01PN9P0S;3d0:3=602PcA@0N:SX07bXh024[=@0B72D05b4W
01LP900D71l04ATK01<K7@0D6Ad05a`P01DJ7P0F6al05a`P00lD600F6al04QLK01@I7@0201LL800=
01DJ7P0F6b404QLM01<H7P0G72005AXN018G6`0G71l04ALH01XP800L8R804QPH01<H6P0201HI7P07
01@G700D61/05QXM01TM800B5QL06QhM01LK6P0201<H500A018F500C61L05adL01DK6`0>4aD07R<V
00`A500@5AT04AHL01/P9P0N8bT0720Y01hS:P0I72805QTN01DH7@0D61/00P0C5aX0>00D61T03a<B
01LK6P0D6AD04aPD00dC3`0?6AD03aTH010J6@0A6aX03aTH00hH5`0nB4L072HW00dG600@6Q/04Q`M
00lJ600E8Q/072TQ01@Q5`0K:1d021@900dH3@0A6a<041XC00dD4@0F71`06b0T01HK7`0D6A`05AXM
01DJ700B61P041HD00lE4`0@5Q@041HB00lF400>5@h03aH?018I40083`L06B0I014G500>51D03a@G
01DJ7`0E6R005Q/P02<X:`0E6Qd03Q@C00lD400A5Q004aPB0P0E6QH06@0D61L03Q8A00lC4P0B5QL0
4QHI014E600@4aL0=CU106aaN00F6al05A/K01DK600@5A004AP@01DL500J8AX05Q`H018H500>5180
20/>00`A501ZKg808bTY01HL700<4Q000P0?5A<03P0>51003A@=00dD3@0>5@h041HC00lE4`0@5Q@0
3aDC00hD4P0C6AL02Q0>014G5@0<4Q002@l=0P0>51802`093`d03aDC00/A3`073@/041HD00`B400>
51803aDC010F500A5aD041HD00803Q@B00H04ALE00T?3@093`d03aDC00/A3`0@5Q@200hD4P0B010F
500>518020l=00TB3@0<5a40218<00`G4@0950h041/E00`E3`14CdT0>dI000lI4`084`d03QLB010F
400B5a4041D?0P0>4`d04`0?50h03Q<=00hC3@0>4`d03A8<00`A2`0;4P/031L?00PC2`0=61006B@L
038m=@0;5Ph031L?00lJ4P0950`03QTA01HQ6@033PH0100>5@h0500?5Pl031<<00XA2P0;4P/041L@
01PO600F7AH041H@00dB300;40X03A8<00lD3P0F6aD05AXD01PM5`1>Ddd03A8<00P=1`0A5Q003A8;
100<4@X0800=4P/041D>00D:0`0@5@h04QL@00X?200A5Pl02Q0600X@10093`<0318700hD2P0<4PP0
318900lD3@0C618051TC014F400<4@/03Q<<00X?200@5@h0314:01LL5@0]<R/02a0:010E3P0:3`P0
2a0900`A2P0=4P/030l80`0?4P/0100C5Pl04QD>014D3@0?4P/2014D3@0:00d@2@0<40T03A@=02Pb
:P0?6A4010h601PR6P094P/03QP@00/E3@80218:01P02aD=00dD3@0>4``08RDO00/>1`0A50d041<<
00hA2P0A50d041<<00hA2P0=40T030l800`?1P0<4P@02a4300T?0`0:40H0318900lD3@0@5@h01P/4
014G3@0<4PH200X@0P0700hA200?4P/03a8;00lB2`0@4``04A@=010C3002014D3@0<010C300>4@X0
4QD>01TK5P0K7AP051HA00P:1@0;3@P05aTD01@F4@0@4Pd03@l:0P0A4`h00`0>4@/03aD<00dC2@02
00`B20803Q@:00H03A<900`B200=4`T03aD;00dC2@0;4@L200d@2@05018E3P0C5Pl03Q4:00`?200>
4@X00P0A50d200lB2`0[010C300@5P`03Q@:01<H400?50d02a0900dB2`0:3`T0314=00dB3P0L8Ad0
>Chj059GD`0F6aL04AHB00X?2`0A5Q803A8>010E4@0?5100314=00hC3`0:3`/02@h:00`A3@0=4Ph0
41DA00lD40093PX02Pl;014F4P0<4@d02Ph;01@I5@0:3P/05Q/G018I6P1^Mgd0BE9F00P@40063`X0
2Q@<00`D2P0200XB1`803a@=01402Pl901DJ500:3`T02`l:00lD3P0:3`T03A8<00lD3P0;40X0314<
014F400@5@l03Q<=014F3`0@5@h03Q<<00`A2P0200/@2@80314:0P0;40T00`0=4P/03Q<<00dB3005
00dB30D0314;00D02a8;01LN5`0?6A4031H>00hE3P0200dD3@0700/@2P0?4`d03@l:00h@2`0B50l0
3@l:00hC3@0300dB300S00/@2P0<4@/03A8<010E3`093PP03a@>00`A2`0;40X02Pl800`A2`0<4@X0
51TB00T>1`083@H04AH?00hC300:3`P02a09028W801nPg`0;S<]059GD@17C4H041D?01<H4P0730H0
5Q/E01TN600?50h03Q<=014F400;40X051HA01<E400A4`h00P0>40/03@0?4@`0418=00lA300?4@`0
418=00lA300>40/0418=00/=200B50l04A<>00H8100F61<00P0@4Pd0400=3`X03a4<014C3P0D5Q40
1PP500/=200=3`/06Q`G03`n>@0/;RT02@/600d?2P0H6QD03a4<00X<1`0=3`X2014C3P80418=00h0
3a4<00h@300/;RT02`d800lA300:30L04aD@00`>2@0>40/02`d8014C3P0E5a804Q@?00d?2P803a4<
00@04A<>018D3`0@4Pd03Q4<1@0=4P`07`0;40X0314;00`A2`0H7AL05Q/E00dB30093PX03A8>010E
4@0=4Ph02a0<00hC3`0=4Ph0314=02`a;@0E6QH05Q/G00dB3@0A5Q003Q<<00hC3@0?50h0314;014F
4P0=4Ph03Q<?00X>3@0B5QD04aLF00/@3P0?5A<01@0<5A804P094Pl02Q<@059KF03:dm00HfaY00D:
1P0E6Q@02a0:028W8@0U:R@0314<00hC3`0B5a<04ADC010D4`0A5A@051PG01HJ6ACooooo000Koooo
o`0U010<3@0:2@X02@X>01@I7`053aL03aTR00@>5`053a@02@hA00d?3P0?3``03Pd900h>300@4Q40
1@L600L9200310D030d?00/<3P0>3a80414E04e>DP0A4QL0414F00h?4`0>3a@05AHK014B5`0F5a`0
4A4I01@D700L72@05ADO00h>60030`l01@D=00h?4P0200/<3P803@h@00@02``>00l@4P0@4A<0414C
0P0<3@l03@0>3a40414C00h?4@0>3a40414C018C5@0C51H05aPJ03Hg>@0o@4808B8T01dN800C5AT0
0P0C5Q/01@0@4aP04aHK01<F6`0D5a`04aHK008041<H0P0D5a`01@0>5A`02aDN028_>00K:C<08c4l
00805B<^01403a`U01<M9P0D72<04QLK01HI7P0I7B80>Ci402X^=`0j?dD04QLK01`Q9`0@5AT04AHI
01<H6`0C6AX04ALG018G6P0201DJ7@0O01@I700B5aX04AHI014F6@0K82<05a`O01HK7P0E6Qd04QLJ
01@I7013B4/07b@W01@I700J7b805Q/N01@I700E6Qd05Q/N01PM800G71l05AXM01<H6`0F71`03A<C
01DK6`0F71`0:Bl_02@Y;00J7b<05AXN01LL800201HK8@0E01`R:P0=5RD051la01XU=P0J8c@082Xg
02@^>00L9Bh072@[01LN900B6Qd04ATL01DM7`0C61`051TM014F6P0D6Ad06b0T01PM8@0K82@06AhR
00807B8V0P0E6Qh03P0B5ad04aPN01PM8`0F6al03a@H018G6`0@5AP05adN018H600D6QX0728R018H
600C5Q/04aLK0P0D61/01@0D61X04QHG01LK700P92<0720O00<05a/J00P02PlB010E600730l0CU=G
02L/<00:3aD06b0V01HJ8`805a/T00<051PS01@H8@0B5A/00P0B5QT04@0D61/05QXK01HJ6`0N8R<0
4ADD01PL6`0E6AP05QXI01<I5`0?61L03AHE00hG5P0A6QT04Q/J014J6@063`h03QLF00805b0O00`0
3aPG00XE4P0=6Q<02aP?00D?1`0>6Q000Ph4018M500=5`l041HB010F500@5QH200/@4`0e014F6@0@
5QH03aDE00dC4`0<4Q003aDC01<I5`0D6QH04QPD00hD400>5@h04APA01HM5P083`P04ALD05YPH00f
>ch02PlB01<H70042@d041DH02H[;P0D6QT03A8>00lD3P0B5a<04aPD01@I5@0C5aH0310?00hB4@0A
5AH04aLH018F5`0@51L0724U00462P0H7B4041HF00X@3P0=50h02A0900dD3@0@5a003A<?00/A3@0<
4Q0092T/00T>4@073@d00`T900T?3`0>51800P0?5A<0500>51003A<?00`B3P0;4P/03Q@B00lE4`0=
4a402a4?00hD4P0A5aD06b4O00lE4`0B61H04ALE00L=2`0<4Q003A<A00T?3@0C6AL03Q@B0P0=4a40
2`0<4Q002a4?00dC4@0?5A<03Q@B00T?3@0B61H0318@00X@3P0A5aD051XH008020h<01P03Q@B010F
500@5Q@06R0N02H/:P0=5Q401@d800060@0=5Q4031D@010I500D7AP0=Slj02Xc;P0;50l02A8=00PA
300>50h02a0:00`A2`0@5@l03A8<00X?2@0@5@l200lD3P803Q<=00<03A@=01@N5P0E7aL00P0E7aL0
800b?3@02A<;00TC2`053`L02Q@<00/E3@0D7QH04A/C00`C300=50d03aH?014H4@0B6A806B0I01XQ
6P0C6Q<03aH?01DL5@0B6A80318;00X?2@0;40X03A8<00X?2@0=4P`04QLA00870@0U:R@01``701HK
5@093PP03Q<=0P0>4``200dB2`1A00hC300D6A804QL@01HK500>4``02@h7018G400<4PP03Q@8018H
300G7A8051X@00hD2P0<4@T03Q<<00lD3P0>4`d03A8<00/@2P0@5@h0314:010E3P062`@02a0901PM
5P000P007B8K01LL5@0730D03Q<<00lD3@0?4P/04QD>010C300=40T03a8;00hA2P0A50d03Q4:010C
300A50d03A0900dA2P0J8AX00`X300lF3`0530D05A`E00hE3P083`P03QD>00dD3@073PL02a8;00T@
2@0;40T05aXC01dP6@0?4P/02Pd600lB2`0C5Pl04QD>010C300?4P/03Q4:00hA200;4@D02a4400/A
1@0=4`T04QLA01HK5@0k@3X05AXC018H3P0>50P020h100H<000=40L03Q4:00803a8;00`041<<014D
3@0A50d04QD>00lB2`0=40T03Q4:010C300;3@P0418=014C3P0D5Q42018D3`0C00lA300C5A003a4<
00lA300A4`h03a4<00/@2@0:3`P02a0900hC300B5a0051TB00dB2`0;40T0314:00hC300<4@X02Pl8
010C300200`?2009010C300?4P/030l800lB2`0@4``03a8;00hA2P0?4P/04A@=00802Q06010041H=
00hC300;40T01``5010E3`0X;BT05a`H01<H500H7AT02@d900050@0>4`l03a@@00`A3@0>4`l041DA
0P0<4@d09`0>4`l02a0<00`A3@0;40`03A8>014F4P0>4`l04QLC010E4@0<4@d04aPD00H;1`0B5Q<0
1``801<H500>5AH04Q/P00062@0@6AT03AHA018I4@0<4`/04AP@00lE2`0;40T03Q<<00`A2P1PIEl0
?44k01HK5@0@5@l02a0:00lD3P0>4`d00@H001XO6@011P0051TC00X?2@0200hC300700dB2`0<4@X0
314:00dB2`0D6A804aPA014F3`0300lD3@H03A8<1@0<4@/02@0;4P/07bHO00XD300J91`00`X300lF
3`083`P02a0:014D3`02010B3@0A018D3`0>40/02Pl900X?2@093PP020d700T>20083@L0008000`A
2`0A5Q004aPB00dB300F6aD03A8;00/@2@083@H00P0;40T06P0B5a003Q<<01`Q6P0730D02Pl800lD
3@0j?cP08RLQ0;Jk]@2PYIl03Q<=004600042@<04AH@01HK5@0:3`T02a0:010E3`0730H03Q0;00lA
300>40/03@l:00lA300A4`h0418=0P0A4`h06`0?4@`03@l:00`>2@0D5Q406adH00<5000@4Pd04A<>
01<E400D5Q405QPC014C3P0?4@`04Q@?00`>2@0B50l0418=01LI500D5Q402@/6014C3P0G6A@0418=
00D70P0C5A005ALB010B3@02014C3P80418=00h03a4<01lQ701=CdX06adH01DG4P0;3@P05aTD00X<
1`0P8Qd03Q0;018D3`000@006adH010B3@803a4<00@04A<>018D3`0@4Pd03Q4<1@0=4P`02P0:3`T0
3A8<01<H4P0>4`d04QLA00X?2@0?51003A8>00`A3@0?5102014F4P0Z010E4@0>4`l0=S/g01`Q7@0M
8Qh03a@?014F400?50d041D?00hC3@0<4@/04QLC01/P700i?SX06alN00lC4P062PT03Q8A010F500?
5A<03A<A00/A3`0:40h02a4?018H5P0A5aD051XH02le<`0J81h06b4M01LL5P0=4P`0@4Do04I;A@0D
6A@04QLC014F4P0@518041@C018F5@0G6aX06alN5?ooool001_ooooo03401`<0018A400310H02@hB
00L?5@002a40214H00TA600<4AD0414C018A400C4Q005QHF00X<2`0G6AP06A/J01DG5`0000801`P:
00D5200G61`0NW]o01dN8`020`P03@hC00421`0J6b0020P=00h>5P092A404Q8K00`<5P0000T02PXF
01@D800G5b403PlC00h?4@0@4A<04Q<E00h?4@0<3@l03a0B014B500C51H03PlA00X;3@0=3Q00414C
00803a0B00T0414C014B500A4Q@03@h@01HG6@0K71h04Q<E00l@4P0=3a<00P0A51T00`0@4aP03Q4F
010C600201<F6`0M018E6P0E61d051LL010C600A62002aTT018P;@10D5d0GVik04ADH@0B8Bh06BLb
01<P:@0A6B005AXN018F6@0F6ah0;C8f01dR:00D6Ad00PL:00lD600=4QD05A/K01PN7P0G7Ad04aTG
01@J6P0C6AX01@0A5QT02@0B5aX04AHI01<H6`0B5aX03a@G01LL7`1[L7<082DX00L<3`0201`Q900S
00/@4`0E6Qd04aPK010E600?51L04QLJ01LL7`0O9BD06b4Q010F5P0C6AT0DeUI059GFP0L8BD05Q/O
01LL800@5A/061dS01LM9@0H8C006RHf01PT<`0D7B`05AlZ01<M9`0L9Bh0620V018I7`0@61/041PJ
014I6`0A5QX04aPL018G6`0H7B400P0S:2`0;00K82@06QlS01lT:00K82@05AXN01hS9`0H7B<051TO
01TN900G72003a@H01<H700>4aH020d?014G5`0D6QX03aDE01<I6@0B5QT04ADI01<G6P0E6A`05ATK
018F5`0G6a`0720O01PL6`0F6QT05a/J01HJ6`0E6Qh061dS01@I7@2k`<H0AdaB01hS:@0P9B/061`U
01DI8P0D62404QHQ014E7P0D5ad04aLJ0P0B5QT02@0B5QL04aLH01XN7`0@51<04QHE010D4`0F6QT0
4aTG014I6002010I600G014J6@0B6aX04a`K01XS8P0F7ah041TH00hG5P0@6AP04A/G00PE3P0?71<0
4alG01LR6P084`/04QdE00dG3`0?5A403aDD00hD500M8RD08RLZ018H600A5aL00P0?5AD01@0?5A<0
41HD01<I5`0D6QH04QPD00803aDA00h031<<01PN6P0<4Ph05adL06meM@1;D5<05Q/N01<H700G7200
4aPK028W:P0G7A`03a@@00lD3P8041DA01404AHB018F5@0A5A@04QHE018F5`0A5AH03a<D00dA5009
3Q400PL:01@I6`083P`051XH02D[9`093`/02Q4:00`C300200`B3P0A00lE4`011`L06b4Q01@J6P08
3Ph06R0P00`B400@5Q@04ALE014G4`0@5Q803aDA00hD400<4Q003aDC00/A3`093`d00P0<4Q003@0B
61H02Q0>00lE4`0?5A<02@l=00lE4`0D6QP02Q0>00`B400?5A<0318@01@J600@5Q@00P0=4a401P0@
5Q@03aDC00X@3P083P`03aDC014G5@803aDC00l041HD00X@3P0B61H04aTG00lE4`0H7Q`0:2h/075j
M@11BTD02Q<>00PA300740/03QLB00T?2`0@6A@00P0A6QD01@0H8A`04AXE00X?2@093PP02a0:0080
4AH@0`0@5@l200lD3P0>00hC3@0=50d041PA01@N5P0B71@031H>02@^9P0;5@d01a4900dG3`0F81P0
218:00LA2@094`/200dD3@<031<<00X04aXC01PO600A614031<<010G400?5Pl0318;00/@2P0=4P`0
41D?0P0:3`T0200>4`d000@000hC3@083@L04aPB00P=1`0C61803a@=0P0>4``0300=4P/03Q<<01@I
4P0E6Q<03A8;00lD3@0@5@h02Pl800L=0`083P803A<700lE2P803aD;00<03aD<00dB2`0<4@/00P0;
40X0500=4P`0314:00L<1@0<4@X01@X300P=1P0=4P/0:2dV075fK`1TJF805Q/D0002000A5Pl041<<
018E3P0@4``030l800hA2P0<3`P04A@=0P0>4@X03@0@4``03A0900lC300=4P`05A`E00hE3P0<4``0
1`h7018I4P0940T03QD>00dD3@073PL00P0940T0200B5@h030l:0002000G6Q<04aH?00`?200C5Pl0
4QD>0`0@4``03P0@4`X02a4500`B1@0=4`T03a@=01@I4P0G71H0?44k01@I4`0>4``02a4700/A1008
3P803Q480`0?4P/2010C300900hA2P0A50d02`h700T<1@0<3`P03A0900`>2@0O8A`05ALB00803@l:
01T02`d8010B3@0B50l04A<>00d?2P0>40/04A<>00`A2P0=4P/03Q<<018G400F6a@05a`E00lD3@0>
4``03a@=014F3`0@5@h03Q<<00lB2`0=40T02@`500`?200>4@X02`h7008041<<00@03a8;00d@2@0?
4P/04A@=0P0;4@L0>@0B60l041D>00hC300>4``02Pl901dR7P0I7QX01P/700hC3`0J7a/04QLC00T>
2P0=4Ph03Q<?00lD400=4Ph02Pl;00/@300>4`l02a0<00hC3`0<4@d03A8>014F4P0<4@d03Q<?00dB
3P093PX010T501dR7P1/LFd07R<O0004000<4a<07bT[05ALGP042`T03QLD00P>2@0:4@X03QD=00lE
300:3`P02a0900dB2`0N8ad02Pl900450@0>4`d04QLA010E3`0D6A<03A8<00hC3@000P004QLA01<H
4P0400`A2P0600hC300?50d051TB01<H4@0@5@h03A8;0P0<4@X600hC3@D0314;00l02a8;00hE3P07
4@T05b4I00<:0`022@800@P100X?2@0A5@l0418=00h@2`0?4@`030h900/@2P0=4P`00P0:3`T08@0<
4@/02@h801PM5`0>4`d010T300/@2P052P@020d70002000C61403Q<<0003000=4P/010T2014F3`0;
40T01P/401HK50083@H01``500lD3P0Q9R0092TS00X?2@0F6aD051TC00P=1`0<4@/01``600/@2P0A
5Q003A8<00`>2@0300d?2P0500lA300A4`h030h9010B3@0A4`h00`0@4Pd0600;3@P04aD@00D70P0=
3`X0418=00h@2`0A4`h051HA010B3@0?4@`0418=014C3P0O8A`02`d800L91P082PD0008001DG4P08
2PD03Q0;024S7P0?4@`02`d8018D3`<0418=0P0?4@`03@0@4Pd0:2XU00d?2P0?4@`02P`7010B3@0<
3PT06Q`G00H80`0?4@`03@l:01/M600;3@P00P0?4@`0100A4`h04Q@?010B3@0>4P`500hC3@0600L<
1P0=4P`02a0:01XO6@14BD<03Q<=0P0;40`0700>4`l04QLC01@I5@0E6QH061dI00D:1P0=40d01@X6
014F4P083@P02@h800/@2@0B5a403a@>00P=1`093PX051TE018G4`093@`05QXI00X>3@0@51<041HD
00lE4`0<4Q002Q0>00/A3`0<4Q0200hD4P0<00lE4`0@5Q@04QPF00D;1`0;40X02a0901HK5@0K81X0
4QLB00T>2P0B5a<041DB0P0>4Q42010D4aCooooo000Kooooo`0]00l>2P0>3PP02P`800T<30083@l0
1a0D00X@5P0;41H030hC00d=4P0?3Q804Q4B00d=3@0?4A001PP700P:2@0=3Pl06Q/M00l@4P0A4QD0
3a0D01@E6@082@h0414F00l?5`071`h04Q8J01LG7`1BDU`06QXT010@6`0@41`03`lK014@7P0:2AL0
4A4L00l@500>3a<03a0D014B5P0?41@03@hB010A5@0?41@04a@H00803a0D03<051DI014B500B4aD0
4Q<E014B500?41803PlA01DF600@4A<02@X<018C5@0C51H05aTM00/>4`0=41D04aHK00`?500?4QL0
5aXO01HI7P0I72405APM00lB5`0A51T03aTS01PZ=`0W>TP0Zkc70>Cdn`3Ahnh0DF9_04YHH`0]>T<0
4a/R01XO8`0<3Q805QXM01HK7P0E6Qh04aPJ01PN7P0D6A/04QPG01DK6@0I7ad05Q`I00lE4@0?5A80
51XI01DJ7@0D6A`00P0B5aX0300A5QT051TL014F6@0A5QT04QLJ010E600C61/07R<V018G6P0E6Qd0
51TL03Pm@0804QLJ01X05AXM01/P8`0L8B@06AhQ01@I700Q9bL0:Bl_024W9`0oADD0/;Jf0:jc]@0M
8RH06AhR01XO8`0F6b40;34g02H/<`0J8C00624a01<M:`0F82d07BHa01PQ:`0F7bL041PO010G7@80
5Q/O01X03a@G018G6`0E6Qh05AXN01LL800L8BD05Q/O01DJ7P0D6Ad061dQ01<H700I7R80=CXn02hc
>@0E6R0051TO01/P900F6al05AXN01DJ7@0G71h03aDE014G5`0J820051XJ01@H6`804QHI0P0E6AX0
300B5QL05QXK01DI6P0@51D04aLH01DI6P0C5aX04AHL01PL9@0H72@0@TI?01PL9@805QXS00P04aLR
014E800D62<05QXU01@H8@0E61`04aLJ018F6@804ADF0P0B5QL0>P0E6AX04QHG01<G600O8b@05a`M
018I6`0E7Al051`N010H6P0B6aX05AhM00XC4P0=5QD041TG014J5`0?61D03aTD00HA2`0E81X02aH@
018M5`0?61<041LC00X@3@0=4a406QlN00hB4`0L82<09b`]01@J6@0B61L04ALE018H5P0D6QP04ALE
00hD4P0?5A<041HD010F4`0B61D04aTF00hD4P0G7A`03A<C01dS8`0D6A`02a0C01TN8@0<4A@03A8D
014G5`0@5QH051PF018G500?4a803Q8A010D4`0C5aH2018F5@0=014E500@51<03a<B00lC4`0<4Q80
5adL00dB4P0;4@l06AlM01lU8P0=4a00318>00hD4@02018H5P0400lE4`0>51<041HE00lD4`80318@
0P0>51807@0?5A<041HD014G5@0@5Q<03Q@A00lE500F71`04ALG00hD500@5QH02a4A00dC4`0U:b/0
4QPH00H<300B61P03Q@D00dC4@0M8b4020h<018H5P0?5A<04aTG01@J600>5180318@00lE4`0@5Q@0
318@00803aDC00D041HD00lE4`0>51804ALE00hD4P02014G5@0E00hD4P0=4a403aDC01LP6`0@6A@0
1Pl:00hG4P0740/02Q<>00/D3`0<5A003QLB00TB3@0>5a8031@?00lD3P0H7AL051TC00/@2P0>4`d0
5Q/E00803a@>0P0>4`d03P0=4P`0318<00hG3`0=5`l031H>00TC2`0A6a<03AL?018L500Y<b/08B/S
00XD300>61002A<;0P0<4``200dD3@8031<<01@03aH?014H4@0>5@h041L@00lF3`0=4`d03A8<00hC
3@0@5@l0314;00dB300@5@l03Q<=010E3`0=4P`020d7010E3`0>4`d03a@=00dB2`<0314:02L04QL@
0866O`2@UHh0:BhW01PM5P0D6A8041H<014G2`0@5PX03A<801TO5@0]<bT09BXR00`A2P0>4`d03a@>
00hC3@0?50h03a@=00P=1P0<4@X02a09010E3P0>4``02a09020U7P0M8Q`051TB00P=1P0@5@h03A09
010C300?4P/03A09010C300>4@X04QD>00d@2@0<3`P00P0>4@X00`0D5a0061dF00hE3@0200`C2`0;
00XA2@0<4``03A@<00XA2@0<4`/02a8:00T@200?5@h04QD>014D3P0?4P/00P0>4@X00`0:3@P041<<
010C300200lB2`06010C300A50/03A<700hD200?5@/03a@=0P0@5@l0200G71H02Pl900dB2`093`D0
3Q@800`B1P0A50/041<<0`0?4P/01@0>4@X04QD>01DH4@0>4@X02`h7008041<<00d05QPC03@f<@0J
71L03Q0;01PJ5@0B50l071hI00`>2@0@4Pd03Q0;00/=200A4`h03Q<<0080314:00l03A8;010E3P0A
5Pl0314:00/@2@0=4P/04AH?00lD3@0>4``04A@=01LJ4`0B5@h04A@=018E3P0>4@X00P0@4``03P0>
4@X03A0900lB2`0B5@h041H<00hD2P0D6A4041D>00dB2`0?50d03Q<=00hC3`0:3`/02a0<0P0@5A40
300B5a<03A8>00lD400:3`/03Q<?00`A3@0;40`03A8>00hC3`0:3`/03A8>018G4`8041DA0P0A5Q80
500@5A40314=018G4`0?51004aPD00`A3@0E6QH03A<C01lX:02IXJ80:2l^00hD4P0>5A003A8=00T>
1`0;40T041<<00d@2@0A50d03A8<0P0<4@/02P0A5Q004QLA00/@2P0>4`d020d701PM5`1bMg405Q/E
00`A2`0>4``200dB2`0600`A2P0=4P/03a@=00hC300=4P/0314:0P0:3`P00`0;40T03Q<=00hC3@04
00hC3@D0314;03402a8;01DL5@0;50`01`h804A;A00L8a`03aH?00hC3@0G6QD05ALB014C3P0@4Pd0
30h900dB300@5@l0314;00/@2P0?50h02a0:02<X8P0G71H01``600T>200<4@/08bPR061UGP0A5A00
61dF00T>1`0B5a003Q<<010E3P0K81T05AXC01@I4`0Q9Ql03Q<<00lD3P0;40X0314;00X?2@0?50h0
3Q<=00T>200:3`T0314;00/@2P0=4P`04AH@0080418=02803a4<00d?2P0>40/0418=00d?2P0B50l0
4aD@00lA300>40/03a4<01@F4@0H6QD0418=01DG4P0T9R404aD@00lA300A4`h0418=018D3`0@4Pd0
3@l:00h@2`0D5Q404aD@014C3P0F61<04aD@03Xl=`1VJ6<0@T@o010B3@0D5Q403Q0;0`0?4@`200h@
2`0=00lA300;3@P03a4<018D3`0C5A003a4<010B3@0A4`h0>C/f018D3`0L7QT01PP501<E400200lA
3004014C3P0B50l0418=00hB30D03Q<=01D03a@>00dB300<4@/061dG04I;A@0B5a401P/701<H500N
8al05AXF00dB3P0A5Q803a@@010E4@0>4`l03a@@00hC3`0@5A0041D?00hC300?50h00P0=4P`04`0L
8Ad09BXV020U8@15BDP04QHE00hB4@0=4A003aDA00hD400=4`l03Q@@018H500E6aL03A<?00lE4@0;
4@d03aDA00dC3`0A61800P0@5@l01P0<4@/03Q<=014F4@0;40`03a@@010D4P803Q8A00<0310?00/?
3_ooool04oooool001_ooooo00d07AdE014B2`0C50l0004000`@4@052Pd030lD00/>4`0W:2d03PdC
00T73P0A41D03`lA00<03Q0?02<03Q0@00h?4@0=3Q0061TL00L8300;3100414F00L83@0A4AT02PXB
02PX<00c<c/0aLG?02d]=`0A4Ad01`LC01DE8@0A41h02PTG00P8500?3aH00P<8018C600<3A805QLL
02LX;@0C51T00`@900h?500X:Bh061TN00d>4P0?4180414C00h?4@02018C5@0T00h?4@0=3Q003@h@
00L82P0F5aT02``>00h@50062@h04aHK03Tl@@0M82D02`hC01@G700;3Q<02PdB01LJ7`0F6Ah05APM
01LR:`0@8S00=4MF09ja`03`ool0dN?a041AG`0C8B`04AhW01HN900E6Qd061TM014E5`0C61/05A/K
01LM7@0E6a/04aTG0P0B61H0300D6QH04QPD00`B3P0A614061hL01<H6`0G71l05Q/N00lD5`0@5AP0
6AhQ01HK7P804AHI00@051TL01LL7`0E6Qd05AXM0P0D6A`0>P0E6Qd05a`O01dR9@0/<C@06QlR02P]
<00N8bH04QLJ01dS8`0C6AT06R0P01HL700e>c/0>Sm201PM8@0F6al061dQ020U:`0Q9R`041HM01HN
:@0D7RX04Q`X01<K:00F7BT06B0Z014H800B61l05AXP01LL800H7B405AXN028W:`0T:Bd04aPL01@I
7@0G720041DI01<H700F6al051TM014F6P0B5a/05Q/O01HK8@0H7B<04AHL02<X;00:3a<06AhR024V
:@0:3Q004ALG00L=3@0E6a/04aTI01DI6P0D61T201<G600E01LK700J7Ql05ATJ01/O800A5AH04ADH
01TM800G6Ql05ATS01dQ;00C5b80310K00L;500D624041@M01TM9P0@51d0<3@m00/?600H7B<04aLI
00804ADF00d04aLH018F5`0A5AH04QHG01PL7@0J7Ql05ATL01TM800B5QT051TM01lT:00P9BT05Q/N
008041DH00h05adM00lE4`0?5A<05Q`H00hD400D7QP02A@<00lH4`0:4`l04a`I00lE4`0>51<041HF
018F5`804aLH02T04QHG01@I6@0E6aT03aDC010F500N92808BLU01XP7P0G7A/0318@00dC4@0M8b40
10X801@J6P0B61P04AHI00/A4@0D6QX04aTI00hD50052`/02Q0@018H60093`l02a4A00T=3P0@51<0
1`/:00`@3`0C5aH041@C00lC4P0@51<04ADD00hB4@0=4A003a<A00lE4`0?5A403aDC00hD4P0200dC
4@0501LM6`0=4a4041HE014G5@052`T00P083P`08`0B61H03aDC00`B40073@/061hL00H<2P0H7Q`0
2@l=01TO7@0=4a403Q@C01TO7`062PX02Q0@00/A4@0=4a<041HF00X@400E6a/0318B00@:2P0?5AD0
3Q@D01LM6`1SJFL041HD01lU8`0630X07B<Q020V900?5A<04ALE00D;2@0:40h04ALE00803aDC0P0>
518200dC4@0600H<2P0F71X03A<A00T?3@0@5Q@02@l=0P0>510200dC3`80318>00X04ALC00lE4@0>
51002@l;01LM6@0Y;b/051TC010E3`0=4P`0314;0P0=4P`0900<4@/092TS0003000;40X03Q<=00T>
200@5a003QD>00XA2P0>5@h04QTB00lF3`0H7aP0<CPa010G400>5@h041L@00/B2`0@5a004QTB00hE
3P093`T05A`E00dD3@0@5a003aH?00dD3@0<4``03A@=00lE3P0=4P`0314;014F400B5a403A8<00X?
2@80314;01/03A8<00hC3@0>4`d041D>00hC300:3`P01``5014F3`0Q9Ql0>d0i0<gBb`3[l>T0=S/d
00dB2`0320404AL=010F2P0=4`L03aD:014G3@0?5@/03aD<00X?200@5@l03Q<=014F400>4`d00P0<
4@X200dB2`<03Q<<0P0=4P/05@0<4@X03A8;00hC300;3PL03a8;018E3P0>4@X030l8010C300F6A80
30l800/>1`0F6A801`X30495?P2TZZ007R@J00P>10052`405adC00/A1`0600hD2P18014D3@0@4``0
3A0900d@2@0?4P/041<<00d@2@0B5@h041<<00/>1`0B5@h04A@;00T?0`0A5``02a47018G400;40/0
0PL301hS7`0b=c4041D>00/A1`093`@041H:01DH3`0?4P/04QD>014D3@0=40T04A@=01@G400;3PL0
30l801DH4@0>4@X05aXC01/M600:30L03@l:010B3@0=3`X04A<>02h`:`0A4`h030h900d?2P0<3PT0
3@l:00/@2P0=4P`03Q<=00lD3P0=4P`0314;00X?2@0E6Q@01P/501DJ500D6A<02@h800lB2`0C5Pl0
3Q4:00d@2@0>4@X02Pd6018E3P0H6a@051L@00`?200C5Pl030l80P0B60h04P0:3`L02a0900`A2P0<
4@X02Pl900P=2@0<4@d041DA00hC3`0;40`03A8>00/@30083@T0314=018G4`0>4`l020d900X?2`80
3A8>00@02a0<00`A3@0=4Ph03a@@0`0@5A401`0?510020d901XO6`0;40`0314=00/@300=4Pl00P0=
4a4200`B400400dB3`083@T02Pl;010B3P804A<>00d04Q@>00hC3@0=4P`02a0:00dB300?50h02Pl9
018G4@0<4@/06b0J02T^:00L8A/02@h800802@h700<03Q<<00D:0`0;40T00P0@5@h00`0G71D03Q<<
00hC3002010E3P0D00P=1`0;40X03Q<=00X?2@0;40X04aPB00dB300<4@/04aPB00hC3@0@5@l01`h7
00T@2@094`/05AlG01`S700E71D03aH?00/@2P0<3`X200d?2P0P010B3@0A4`h03Q<=00H;1@0N8ad0
3A8<00`A2`0320803A8<01@I4`0C61803Q<=00lD3P0G71H0?d@m018G400<4@X041D>00D:0`0<4@X0
20d601PM5P0@5@h0314:00lD3@0<4@X041D?00dB30052P@03a@>00H;1@0=4P`200X?2@0G00dB300A
5Q003a@>00hC3@0E5a802P`700T;1P0>40/03@l:00X<1`0>40/03a4<010B3@0?4@`030h900/=200M
7aX0CU1;01DG4P0K7AP0OGmj01<E400A4`h00P0H6QD00`0@4Pd020X500X<1`0200`>2@05010B3@0C
5A004A<>018D3`0C5A000`0A4`h200lA3003010B3@0?4@`0418=00804A<>00@0418=00lA300?4@`0
3Q0;0P0?4@`3018D3`0c014C3P0@4Pd0418=010B3@0B50l051HA00h@2`072@@030h900lB3@0=4P`0
3a@>00`A2`0;40X03Q<=00dB300@5@l04AH@00X?2@0730H02a0:018G4`0320@0314=00hC3`001@40
41DA018G4`083@T03a@@00`A3@0@5A404AHA018G4@0>4``02a0:01TN60000P008RLS01DJ5P0H7AT0
7B4P00X>3@0F6QT03Q8A01<H500>4`l02Pl;00`A3@0@5A404AHB00802a0<00`04AHB01LL600E6QH0
3A8<00`A2`0;40T06b0J00hC3@0?50l08RLS00lD400>4Q0200lC4P803A4@5?ooool001_ooooo00d0
1@D000X;100J6aH030h;01LH6@0A5AP0310C01HH7@0l?D809bH/01HD6`0>3A803PlA00<03Q0?02<0
3Q0@00h?4@0:2`d03@hA00h?4`082@d0414F01lP9@0C4a/0000700/;4`0=3AD0@T9<00412`0>3QT0
5aLS01HF8P071Q@02@PF01PH900B4aT051DJ014B5`0D5AX061TN024R9`0>3Q<0:BX_06m`M@1YJVl0
30dB01DF6P0?41<03a0B00h?4@02018C5@0=00d>400?41803PlA00`=3`0F5aT04a@F01<E600>4AH0
7R4V0413B00W:Rl04aHK01@G700200lB5`804QDJ020061/P01TS;@086RH04bDc03U;F@1cQI<0J7Z8
024b?`0?7BP031TR00hF7@0@5AT05QXM018G6@0C61/05A/K01LM7@0E6a/04aTG01HL6P0N928082HR
01TO6`0B61@04aXC01HL6P0C61/05AXM01@I700@5AP051TL01<H6`804AHI00<04QLJ01<H6`0B5aX0
100C61/02@0D6A`05Q/N018G6P0O92L04QLJ024V:@0J7b8041DH01hT900201PN7P0G010F5P0P9RH0
7B8U01<H700A5QX041DI01@I7`0F6b4041HM01DM:00C7BL04Q`W01@L9`0H82T06b8Z01<J8P0C6B00
51TO01HK7`0G72005AXN014F6P0S:2`00`0E6Qh0100<4AD05Q/O01PM8@0G720201DJ7P0C01TN8P0E
6R004aPN01hS:@0731006AhR00P=4@0>4aH0FEmP02H/;00A5aL08bTY00X@400?4a@03Q8C00dA4P0>
4Q<04ADF01@H6@0300lC500@024U:00U:B`06A`Q018F800G6bH04QHQ01@H8P0<41T04QHO028V;`0J
7RL05AXP03m3B`0J7RL06b0V01<G6@804ADF00@04aLH018F5`0A5AH04QHG0P0C5aP05P0>4QD051PK
00hB5@0@5AT051TM01DJ7P0C61`03a@G00hC5P0C6AT02Q0>01@J5`0A5a<02@l;00`D3P084`/01@h9
00XC3`0C71T05A/K010F5P0A5aL201<G600B018F5`0A5AH03a@A00lE4@0?5A<04ALE01PN700E6aT0
318@01`R800G7A/061hL0006100K8B405a`O00lD5`0@5AP04QPI0P0A5aL04P0C6AL04QPF010F5P0>
51@03A<C00X@400F6Q/05a/L01XN7P0A5A@02`l>018F5@0?4a8041@C014E500>4Q403A8>00lD4080
3aDA00`03Q@@00hD4P0=4a403A<A018H600;4A401P`<00lE5@0B61H0318@00lE4@0;4@d200`B4080
20h<01h05Q`J01<I5`0>5180318@01PN700;4A406AlO01XP800H7Qh05Q`L00/A4@083Ph041HF00T>
3P0B61P041HF014G5`0?5AD03aDC01@J600I7ad051XH01<I5`042PP02Q0>01@J600>5180318@01@J
60093`d200lE4`803Q@B0P0=4a401P0<4Q00728P00P>300U:bT0C59@00dC4@803Q@@0P0=4`l200`B
3P0U00lE4@0B61@04aTE00`B3P0>510061hJ010E3`0>4`d03A8<00hC3@0A5Q004aPB00hC3@052P@0
2@h801HK5@0L8A/04QLA00hE3P083`P00`X300T@2@0<4``020l800T@2@0P9b002A0900dD3@0?5Pl0
3QD>00P?200120403A@=00L>1`0D6a@03A@=00`C300200/B2`0:00`C300=50d04ALA01DJ500D6A<0
314;00T>200A5Q004QLA00`A2`<03A8<01L03Q<=014F3`0F6a@061dF01DJ4`0B5a0051TB014F3`12
Ad00Jg1Y01dQ700@5@h04AH?00dC2@0<4PH02@l300X@1@0<4PP02a4700P=1@0730D02@h800L<1P02
01PM5`80314:0P0=4P/300hC30803A8;00<0314:00dB2`0>4``00P0=40T0400>4@X03a8;010C300?
4P/030l801/N5`0;3@T03a8;01`O600F6A80?D<i0003000B60h020h401@J40073@<600hD2P803a8;
0P0>4@X2010C300D00H90P0A50d03Q4:00P;100930D06A`E00X@1P0E6a00008002H[9@0Y;RT051TE
00P=2@0E6QD02a0:00hC300A5`d03Q@:014D3@0>4@X2018E3P0600hA2P0B5@h02`h701<F3`062@80
30l80P0?4P/03`0C5A002P`700lA300E5a803Q0;00X<1`0B50l020X500h@2`0C5A003a4<00h@2`05
2P@01``600`A2`02014F400H00lD3P0@5@l03a@>01XO6@1RIf40<3D_00T>200A50d03a8;00X=1P0>
4@X04aH?010C300:3@H03Q4:01@G400B5@h05aXC014D3@0D6Q005A/A00hC2`0?50d041D>0P0;40X0
0`0?51004aPD00lD400200/@3006010E4@0B5a<04AHB00hC3`0=4Ph03Q<?0P0=4Ph300hC3`@03A8>
0P0>4`l02@0E6QH0<CHb04mDD00K81`01``800hC3`0@5Q802Q0<00P>2P0200L=2`0800X>3@0P92<0
3a@@00`>2`0E5a803a4<00`>200;3@P200T>200F00dB300?50h03A8<018G4@0;40X04AH@01PM5`0@
5@l03Q<=024V7`0=4P/02a09018G400A5Pl020d600dB2`062`@041D>018G40083@H03a@=014F4080
4aPB00<0314;00X?2@0@5@l00P0@5@l03@0H7AL03A8<00H;1@0120404aXC00lI4@0C7AD04aXC00T@
2@042`@03Q<=00hA300=3`X00`0<3PT06`0<4@/02Pl900lD3P001@0041D?00lD3P0;40X03Q<=00dB
30093PP02Pl900lD3P0G71D01P/400hC300C61402a09010E3P093PL05a`E010E3P0<4@X03a@=00`A
2P0>4`d03A8<00L<1P0200hC3@03014F400B5a403A8<0080314;00<02a0:00X?2@0A4`h00P0>40/0
0`0@4Pd04Q@?018D3`0300lA300B00h@2`0=3`X030h900`>2@0I6aH071hI01HG500[;BP030h900lA
300E5a805QPC010B3@0<3PT03@l:00`>2@0:30L03@l:0`0@4Pd01@0?4@`03Q0;010B3@0B50l04A<>
0080418=00D03a4<00d?2P0;3@P02@/600`>2@02010B3@0400lA300@4Pd0418=014C3P80418=0`0?
4@`2014C3P0^010B3@0?4@`03Q0;00lA300@4`h03a@>010E3`0=4P`0314;00lD3P0A5Q0051TC01HK
5@0@5@l03Q<=018G4@0C61@02@h:01HK5`0G71P02a0<010E4@0E6QH04aPD010E4@0;40`08bPT00D:
1@093PP0314:00X?2@0=4P`06AhH06ebKP0H7AT06b0L020T8`0<40l04aLF00T=300B5a<03a@@00dB
3P0>4`l0314=00T>2P8041DA00d05AXF01/P700I7QX04AH@014F3`0H7AH020d701TN6015BTD03a@@
010E4@0=4Pl0310?00803A4@00<03Q8Aooooooooool04_ooool001_ooooo00d04Q<=00/<200>3`X0
3Ph<00d>3@082@X06AXK00X:3@0F5AX02`X?00d<4@0B4AH03PlA00<03Q0?02<03Q0@00h?4@092P`0
3PlB02TZ;P0A4QH02``A02X[<00J6al04a@I00L83@0C51T00P8901LG7`0I6B405ADN00@43@0?3aX0
2PXF018B700?41H05AHK00001@0B4aP03PlD01@E6P0A4QL01@H;01HG700J6b004A8G010A5@0>3a80
3a0B00d>4002014B500:00`=3`0B4aD03PlA01<D5P0>3a405AHH018D5`0:3A8030lD01@G70804A@I
02T041<H01PK800N8BH05aXO01@G700E61d04aXQ00XF800?72L03QdX01l^>P0V=D404B0/00TF800B
7BH05alV018G6`0D5a/04ADH01<H6`0E6Qd05Q/N01DK6`0C6AT03aDE01/Q7`0O9B<051XG01DK5`0G
7AT04ALF00lD5`0@5AP04QLJ01<H6`0L8B@03a@G010E600D6A`05a`O01HK7P05018G6P0U01<H6`0D
6A`02PlB01DJ7@0?51L06QlR01LL7`0A5QT051XJ01PN7P0G7Ad06AlO01PN7P0D6A`0724U01PM8@0E
6Qh051TO01<H7P0D6R406B4Y01LP:@0F7RP051dV01HN9`0H7bL06QlV01HK8@0C61h05APM01HI7P0E
61d03Q<G02`a=@0D6Ad041DI01PM8@0301LL80805Q/O00/05a`P01TN8P0G72805AXP01@I7`0m@TH0
51TM018G6`0B5aX0;C8d01hT900201@J6P0J014G5`0C5aH04QHE014E500B5QD05ATI01HJ6`0A5AH0
51PK014E600F6Qd05QTN00hA600?4ad04aLP00`@6@0B5Qh03Q<J01@I7`0C61d061dR00`A5@0F6al0
20dB01DJ7P0C5aH2014E501d01<G5P0B5QL04ADF010D5@0E6A`0720S01HJ7@0F6Ah03a8G010C6P0?
4QT041<I01@G700C5aX04QHI01@H6@0@5A80314=01HK5P0D6A<06B4J03]5?@0C71L04APE00hD500I
7R404ADI01<F6P0C5a/051LJ01@E6@0C51H04aPE01@K500A5a<041HB01<I5@0B61H03aDC01HL6P08
3Ph07R@T079hN00Z;c8041DI00dB5`0@5AX051TL00X@400<4Q00<cTf05=IE@0Z<2h01P/:01HL700>
51@020`?01LK7@0D61T04aLH04U=CP0e>CP03a<B010D4`0A5Q803Q<?00dB3P0?50h03aH>00hE3P0>
5@l03A<@00dC4@0=4a<020d@00`A500>51H03aDE014G5`0=4a40;C<_00dD3@0@5Q803aDA01LM6@0@
5Q@04QPF00881P0E6a/04QPH03i4A00c>3/010T<018G6P093Q4051TL00dB5@0>4aH02a0C010E600F
6ah03a@G01HJ7@0=4a<03A<B018H5P0C6AL05Q`J00/A3`0B61H010X8018G5@0K8Al020h<01@J6009
3`d200lE4`803Q@B0P0=4a401P0:40h0:Bl]01TO7@0I7ad0;38`00dC4@803a@@100>4`l00`0?5100
3A8>00hC3`0200hC3`0O014F4P0@5@l03a@>00lD3P0@5@l04QLA01@I4`0C61803A8<01TN600@50l0
4AH@018G4@0G71H051TC00lD3P0@5@l04AH@00hC3@0=4P`051TC00`A2`0?50h02@h800`A2`0>5@h0
20l801/R6`0<4``04APA00P?200200T@2@0600XA2P0;4P/031<<00`B300<4@/03Q<=0P0?50h2010E
3`803Q<=0P0=4P`06@0<4@/03a@>00lD3@0;40T02@h700dB2`0B5a005AXC00`A2P0F6a@03A4;018G
400A5Pl03A<900hD200=4`L03A<800hD2P0=4`T03149010E3P0>4`d020d701dR700P9Al01@0=4P/0
0`0>4``03A8;00dB2`0300`A2P0:00dB2`0H6a@05APA014D3@0C5Pl04QD>00hA2P0E61402Pd600d@
2@803Q4:00L0Gf9K01DH3`0<3`P051L>00H90@0B5@`03A0700H041<:00<030l800hA2P0@4``00P0A
50d0>@0@4``03a8;00hA2P0C5Pl09BPQ010C300B5@h03A<900lE300K81T0UY^E09fRW@0j?c/08BHR
00`A300>4`d0314:010F300630803A0900hA2P0B5@h04aH?014D3@0@4``04QD?02/^9`0A50d030l8
01DH4@0A50d030h9018D3`0=3`X030h9010B3@0>40/030h900/=200=3`X030h900/=200<3PT08RLS
010E4@093PX03Q<?010E4@0>4`l041DA00T>2P0=4Ph05ATE014F4P0=4@`03A09010C300300hA2P0?
00`?200`<b`04QD>01<F3`0=40T041<<00lB2`0>50X03aD;00`A2@0<4@X03A8;00lD3@0?50h03Q<?
00802a0<00<03A8>00lD400?51000P0@5A4200`A3@0600lD400=4Ph0314=00hC3`0?51003Q<?0P0=
4Ph00`0;40`02Pl;00X?2`0200/@300D01/P700d>CD03a@@00hC3`0@5A403Q<=00lF3`0>5@h03Q@?
00hB4@0?4a@0C4e?02X[;00A4A0051@A00h?2P0C5@h0418=00`A2`0=4P`300lD3P07014F400<4@/0
314;00dB30093PP03Q<=00@90`0200lD3@0:00P=1P0<4@X04QL@06Y_J00U:R<02a0900`A2P093PL0
3Q<<018G4@8051TC00P041D?00hC3@0B5a40<cPb00`A2`0@5@l04aPB010E3`802Q4:00L02A<;00dG
3`0>5@h03A@=01@K500=4P`03A4;00803@l:00X03Q0;00lA30083@L041D?00`A2`0730H03a@>00/@
2P0A5Q003Q<=0P0<4@/00`0=4P`02a0:00T>1`0200`A2P0C00X?20093PL0314:00P=1P0B5a003A8;
00T>1`0<4@X02Pl800/@2P0<4@/02a0:00P=1`0B5a402@h801<H4P0<4@/02Pl900/@2P0200`A2`08
00lA300A4`h04A<>00lA300>40/03a4<014C3P0>40/200d?2P0;00h@2`0?4@`051HA00`>2@0=3`X0
7AlJ00lA300;3@P03Q0;010B3@0A4`h00P0@4Pd02@0B50l04A<>00h@2`0>40/0418=014C3P0B50l0
3a4<00h@2`0200lA300500h@2`0=3`X03a4<010B3@0A4`h00P0@4Pd2014C3P<0418=00D04A<>010B
3@0=3`X03@l:00h@2`0300lA300800h@2`0=3`X03@l:014C3P0@4Pd03Q8<00lD3P0@5@l200hC3@0;
010E3`0;40X03Q<=00lD3P0=4P`02a0:00lD3P0A5Q80314=010E4@0>4`l00P0?51006`0;40`03Q<?
00hC3`0F6aL0?44m01LL5`0E6Q@02a0900hC3@0K81X0=CXd01XO6`0@5A405Q/G01XN7@0?4a804ADD
00/?3@0A4a004A<>01@F4@0E5a804Q@?00d?2P0>40/03@l:010B3@0201@F4@0=00h@2`0=4P/0314;
01LL5P0=4P`041DA00lD400@5A403Q<@00dA400?4a804QHE00lC4P0Dooooo`006oooool020000000
3`l=00X:20092@L00`<201`L6P0I61H02@T90P0@41800`0?3a403@d?00d?3P0300d?3P0K00d?3`0=
3Q001PL900l@4`0P8BD03a0D00<42@0;31403PlB01HG6`0:2`l0414E00h?4`0I6Ql0>3Tn03`m@P0H
620051@L00h>600K6b<02PXB01TI8@0F5Qh0<30h00X:4P0;2a<03`lG00802@TA00H03PhE00l?5`0I
6Ql03PlB00l@4P0=3Q02014B500f00d>400A4Q@04a@F01TJ700>3a405QLI00`>4P0<3a@051LL01HI
7P0E61d051LL00/>4`0F6Ah06QdR01@G700F6Ah04QDJ014F6`0A61h03aPO00`E7@0>6b@05b@]018O
:0095Ql05b4Z01dU:`0B6Qd04QLK00hC5`0B5a/04aPL01@I7@0C61/04QLJ01HL700V;2`09B/[014G
5@0@5Q@04QPF00dC4P0?51L04AHI010E600B5aX05AXM018G6P0A5QT04QLJ01@I700E6Qd051TL100C
61/09`0D6A`05AXM01@I700H7B005AXM01HK7P0E6Qd051TL01DK6`0H7Qh04aTI01DK6`0B61P041DH
01<H700?51P051TM01/P9P0H7B<05Q`R01HM9@0E7RD051dT01DL900G7BD06AhT01`Q9`0G6b404aHM
01@G7P0E61h051LL02T^<P0oA4P0724U018G6`0D6Ad04aPL01HK7`0201DJ7P0@01HK7`0H7B4061dQ
00/@5P0M8RP09BX`07EjOP0D6Ad041DI01@I700E6a`03A<C00T?3`0?5AD05adM014E50804AHB01H0
4ADD018F5P0C5aP04QHI01LK7P0C5aX04QDJ01PK800K7RD04QHO02``>@0N8bT041DK00`A5`0G7200
7R<W01DJ7@0A5aL06AlP01DK6`0B61H04aLE0P0A5Q80A00C5aH04QHG014E5P0C5aX04QHI01XN8@0D
5a`04QDJ00d@5@0A51`061/R01LJ8@0B5AX04aLJ01DI700>4Q804AHB01HK5P0C618041D?018I4@0h
@SX03Q@@010F500;4A406QhQ018E6`0@4aP051DJ01DF6`0E5QX05AHH01@H5P0@5a0031<<00`C3@0=
4`l03Q@B00/A3`000P009R`/01DK701JGf808BHY014F700F6R<061dS00`A5@0;4A403A<A010F4P12
BD80?48n01<I5P0A5aD04aTI00dA50000@@05ATL00dA4P0E6AX0;c<b00lC4P0@51<04AHB00hC3@0=
4P`03a@=0P0>5P/0;P0=50d03A<?00`B400<4Q<061dQ00P=4@093Q4041HF00L=3@0@5Q<09bdY00T@
2@0?5Pl01`d9018H500>518041HD00dC4@0?5AD020d@018G6P0=4QD082DX018G6P093Q406AhQ010E
600=4QD07R<V00P=400]<SD0004401LL7`073@d05A/K00D;2@0:40h010X801LM6`0>518092XX00T=
2`29Shd0BU1>00@:200I7ad200lE4`803Q@B0P0=4a42018H5P0401HL6P0A5aD020h<00`B40H03Q<?
00H03a@@00/@300;40`03a@@014F4P0?510300lD3P0<010E3`0A5Q004AH@00<70P0Z;bT00@H000hC
3@042@<00`P2010E3`0K81X05AXD0P0;40X03@0=4P`02Pl900H;1@093PP041D?00/@2P0B5a404QTB
01PO600@5a001Pd601XQ6P0>5@h00`0<4``00`0;4P/02Q4:00`B300200hC3@803A8<00D03a@>014F
400>4`d03Q<=00dB300200`A2`0=00/@2P0;40T03A8;018G400C61403a@=00P=1P0>4``02a09024V
7`0A5Pl01@X3014G3@0200dC1`0900`B1`0;4@L02a4700hC2`062`@0314;00P=1`0730H0314;00L0
3A8;01@0314:00/@2@0;40T02a0900dB2`0F6A805aXC01HI4P0@4``03a8;018E3P0930D01`X301XM
5P0F6A803A0901HI4P0C5Pd03a8700/>0`805QT>00<02Pd300lB1`0?4PL00`0?4PL0100?4PT02`h7
00d@2@0@4``2014D3@0E010C300M81T03a8;01<F3`0`<b`051L@00/>1`0>50X051TA00`A2P0G71H0
:Rl/02HZ:@0P92<01P/700hC3@052P<02a4800`B200=40T041<<00804A@=00@03a8;00/>1`011000
5aXC0P0C5Pl0GP0H6a@09bXS018D3`051`801PP301hP6`0K7AP01`T400lA300=3`X02P`700`>2@0D
5Q406A/F01`Q7@093PX01@X600hC3`0C61@04QLC00H:1`0=4Ph01``801DJ5P000`00314;00/>200C
5Pl04QD>00/>1`0?4P/05aXC02/^9`0520401PT200D80@0=40T041<<00`B200=4`T03Q<;00/@2@0=
4P/03A8<00P=1`0730P041DA01@I5@0=4Ph02Pl;00/@300<4@d03Q<?00T>2P0;40`03Q<?00T>2P0:
3`/041DA01<H500?51003Q<?00lD400<4@d02Pl;00/@300<4@d02Pl;00P=2@0Q9R802Pl;00050@07
30P03a@>00`B200@5@h04QLB00hB4@0<3@l0000400P92`0@40l0410>010A300>3PP03a4<00T>200:
3`T02a0:00P=1`0<4@/07b@N01DJ500?50h201<H4P0?010E3`0A5Pl00`P100H:1@0H7AH010T200`@
2`0U:R<02a0901@I4P03204010T201<H4@093PP02a0:00<03Q<=00l04AH@04I;A@0B5a403A8<00hC
3@0:3`T01`h700XA2P094`/02aD=00/B2`0<4``05QdF00dB300>4@`00P0?4@`02`0B50l04aD@01HK
5@062`H00`P201<H4P052P@03Q<=014F400;40X020d700802a0:00<01P/500`A2P0=4P/00P052P<0
;00?50d03Q<<00T>1`0>4``02a0900T>1`0;40T0314:00X?2@0A5Q0051TC00`A2`0E6Q@01``600dB
300;40X03A8<00lD3P0>4`d0314;00lA300<3PT03Q0;018D3`0<3PT01`T4014C3P0>40/030h900d?
2P0>40/03a4<010B3@010`003@l:00T;1P0;3@P05aTD014C3P0>40/03@l:00h@2`0?4@`0418=0`0B
50l0100A4`h0418=01<E400B50l2010B3@0800lA300=3`X03@l:010B3@0A4`h03@l:00X<1`0;3@P3
00h@2`0700d?2P0>40/03Q0;00lA300>40/03a4<010B3@02014C3P0700lA300C5A005ALB00d?2P0<
3PT03Q0;00hA300200dB30803Q<=00l03A8<00`A2`0=4P`03a@>00hC3@0?50h04AH@00dB3P0:3`/0
3Q<?00P=2@0B5a<04AHB01TN6P0:3`/00P0=4Ph040052PH01P/6014F400<4@X02@h80005000R9b40
2a0<00P=2@0>4`l03A4@00/?3P0<40l04QHD00d?300>40/400lA3003010B3@0?4@`0418=00804A<>
00d0418=00T>1`0D6A805a`F00/@2P0E6QD03a@@00dB3P0A5A<04ADD01HJ6@0H71/03A4@01Cooooo
000Kooooo`0<01HF5P0=3@/00`<101dM6`0:2PP03@`:00h=2`0510@02@T900h>400820X00P84100<
3Pd03P0<3Ph030d?00`=3`0?41<02``@00`=4@0=3Q<020T=00/<3P092P`04a@F00@4200:2`l02``@
0P0D5AX03@0000D02@TA00L73`051@d03@dE00`<500A4AT09BD]00`<500C4a/02PXB01DE7@0@41P0
0P0B4QX010082@h03a0C010A4`0>3a42018C5@0N00h?4@0<3@l04A8D014B500=3Q004a@F00/=4009
314041<H00d@5@0<3a@03a8G00`?500>4AH03a8G00`?500A51T04aHK01<G6`0I7R80724U014I7`0:
51d03QPQ018O:00<5Ql03aPO014I800>5A/051TM0P0B5a/301<H700;018G6`0F6ah08BLW024W9`0A
5aL041HD01<I5`0B61T05AXM01<H6`0?51L00P0@5AP0100C61/04AHI00hC5P0?51L2014F6@@04aPK
00P051TL01DJ7@0I7R4061dP01HK7P0B5aX04aPK01PM80805A/K0P0B61P06`0I7al061dP01`Q9@0G
72006QlS01XO9@0B5ad04aPN00lF7P0?61l04AXQ01DL900I7bH06b0V01XO9@0F6R4051LN01DH7`0E
61h051LL01<H700W;3005a`P01HK7`0C61`03Q<G01PM8@0201HK7`0?01PM8@0J7b<06AhR018G7@0C
61h08BH/02@Y;@0M8RH020dA00lD5`0H7Al02@l?02P^;P0>51@01`d;00804AHB01L04QLC018F5@0B
5QH04QHG01DI700:3Q40310C01PK800I724051LN01DI8@0k@4H0;c@j01/P9@0>4aL05AXM01DJ700C
6AT04QPH00dC4P0C6AL03Q@@01<H5002014F4P1Z01<G5P0B5QL04ADF028V:@0B5QT051PK00hA5P0C
5Q/04aHM014D7@0I72<061/R018E6`0C5aX05a/L010D500E6QH0=3Td01<H4P0:3`P02a4:01XT6`09
3`/051XI00dB5@0D5a`041<I014D6`0D51`05AHK01DF600D5AL04QDA00dD3@0A61405A`F014G4`0=
4a407bDS01TO7@052`/051XK01DJ7@0?51L03Q<I01XN:@0K7bP03A8E010F500A5aD01`d801XQ6P0F
71P041HC01`R800B61P041@G00lC5P0B5QT000@500dA4P0G6aX03a<B010D4`0A5Q803Q<=00dB300?
50d03AD:00dE200=5@`0318>00`B400<4A@0Ada@01`Q9@062`h05A/K00`B4P0=4a0020l80006000=
50d02Q0<01<I5@0B61H02@l=014G5@0?5AD051TL00hC5P0C61/020d@00X?4P021`X05AXM00lD5`0;
41<00`P;03@i?02UZZd08bP[00dB5@0730l04aTI00`B40804QPF00P02@l=014G5@093`d09B/Y061V
I00S:BL07R@R00L=2`803aDC0P0>518300dC4@06014G5@0<4Q003A<A01<I5`0@5Q@03A8>0`0>4`l2
00lD400:00hC3`0B5a<04QLC018G4`0<4@d01@X600/@2P0<4@/03Q<=014F40804aPB01P07b@N07Ai
L`0U:R@03a@>00P=1`0Q9R004QLA020U7`0K81X04AH@01<H4P0E6Q@06AhH00lD3P0=4P`041D?00/@
2P0A5Q000@L100hE3P073PL072<L04mFC`0]=2d300hE3P0:00`C300;4P/04ALA01@I4`093PP00@D1
02<X8P1GG5H0Ada600hC3@<03A8<00h0314;014F3`0?50d02Pl800`A2P0@5@h03Q<<010E3P0A5Pl0
6b0I04Y?B00F6a@00`P100hD2P803aD900T03A<800`B200=4`T04QL?00P=1P0E6Q@04QLA00T>200?
50h00P0>4``300dB2`<0314:0`0;40T0100<4@X030l800lB2`0A50d200d@2@805APA0P0>4@X0100=
40T071lH01@G3`0?4PT200d@1@0301<F2`0;3P<03a8700H03Q4600<03A0900hA2P0?4P/00`0@4``0
5@0F6A804QD>00`?200E61402@`501DH4@0D6Q001``501TN5`0D6AD04ADC0001000<40l020d:01<H
4P0=4P`02a0800hD2P0>4@X04QD>00lB2`0200hA2P0<00T<1@0D5a005aXC01DH4@0B5@h010L101<F
3`092`H03Q0;00lA300C5A004Q@?0P0=3`X06@0@4Pd03@l:00lA300B50l04A<>00lD400;40`03Q<?
01DJ5P0B5a<03Q<?014F4P0J7a/07B8N00hB3P083@T03a@>010C3@0@4``03A0900X=1P0H6a@09bXS
01dP6@0>4@X00P0D5a004`0G6Q<05APA00X@1P0;4@L03Q<;00T>1`0:3`P08RLQ02L/9P0D6AD03A8>
014F4P0>4`l02a0<00`A3@0B5a<06AhJ00`A3@0730P00P0=4Ph0100<4@d04aPD01LL600B5a<200lD
400X00dB3P0<4@d03A8>00hC3`0B5a<0008000P=2@0?51006AhJ01DJ5P0D6A<051X@01PM5P0K81/0
5a/J01@E5`0D5AT07b0T01HF5`051@<030d801DE400?4@`020d700`A2`0@5@l0314;01DJ500V:bD0
6AhH00`A2`0?50h05AXD01@I4`03204082DN00hC30093PL041D>00/@2@800PL000@051TB00T>1`0<
4@X03Q<<0P0:3`T200`A2`802a0:00l03a@>00D:100A5Q002a0:00`A2`0H7aP02A0900H@20094`/0
2a8;00XA2P0@5a0041D?010D3P0?4@`00P0>40/02P0?4@`041D?00T>200F6aD0=3Tc00hC3@0=4P`0
4AH@00dB300;40X200dB300D00X?2@093PL02Pl800T>1`0<4@X03A8;00D:0`0>4``041D>00hC300=
4P/03Q<<010E3P0730H03A8<00hC3@0=4P`04AH@00T>200?50h200hC3@0:00lD3P0:3`T020d700h@
2`0:30L03Q0;01HH4`0C5A003@l:010B3@803Q0;0P0=3`X02P0>40/04A<>014C3P0J71L02`d8010B
3@0F61<04Q@?00d?2P0<3PT200h@2`0400`>2@0>40/0418=010B3@803Q0;0P0?4@`0100>40/0418=
018D3`0A4`h200d?2P0;00lA300>40/0418=01HH4`0E5a803Q0;00d?2P0<3PT03@l:00h@2`0@4Pd0
0`0A4`h2018D3`09010B3@0G6A@06adH010B3@0>40/0418=00lB3@0=4P`0314;00803Q<=0P0=4P`0
0`0>4`d03a@>00lD3P02010E3`0D00<810042@D05AXF00lD400A5Q802Pl;00hC3`000`003a@@01LL
60062`L082DP000200093PL05a`F00hC3@0I7QP04QLC00X?2`0@5A4200X>3@0700H:2@0A5A<05QPC
01HH4`0D5Q403a4<010B3@03018D3`80418=0P0A4`h030021`00314;00T>200320805AXE00@91@0=
4Ph04ADC010D4`0F6QT06alN00dA41Cooooo000Kooooo`0<00H72@0<3@d04A4A03`k>@0F5A@03Pd;
014@3P0<2`T02`X8014A4@0<3@d02@/:100<3Ph0700<3Pl030d@00l@4`0>3a<01@H:00d>4`0B4aP0
2``A00/<3P0A4Q<02``=00d>40082@/03a0B00l@4`0:2`h02@X=01hO900Q8RL030dA00/;4P0<3A<0
414G010@5`0?41H03PlE010@5`0@41P200d=5@08018B6P0C51T04A8E018C5@0A4Q@051DH01DF6@0@
4A@201hO8P0900X;3P0A4Q@0414C00lA500>4A@04ADH00lC5P0:3A4041<G008041@H01406QhR01`O
8`0=41D030lD01<E600F5aX03Q8E01@I7P0P:2l05alV018K90084Q/0210H00hE700B61h061dR01@I
7P03018G7@0@018G700B5a/04AHI018G6P0F6al05AXL00lD5P0B5aT05AXL01HK7P0B5aX03Q<F01HK
7P0K82<05AXM01<H6`<04AHI00<03a@G018G6P0A5QT00P0A5QT0500B5aX051TL01PM800C61/051TL
00lD5`0F6ah092T/018G6@0=4a<061dN01@J6`0[<C809b`_01<H700E6Qh06QlS018G7@0@5A/0<3Dk
0P0B6B4201<J800`01@J800D6Al05a`R01HJ8@0F6B005aXQ01LI800C5Qd051TM018G6`0@5AT06QlS
01TN8@0E6Qh05Q/O01<H700C61/05Q/O01TN8@0G72004aPM018G700D6Ah05APL018G6`0C61/06b0S
01DK700A5aL0;C<c01<I6@0C6AP05AXG01HK5`0F6aP05QXJ01DI6P0E6A/05ATL01<F6`0D5a`05APM
018E700A51/04QLL020U:P0C61d05Q/N0P0B5aX01`0B61P05A/J01/Q7`0=4a006b4N00lE4@0C6A80
0P0A5Q806P0C61L04QHG014E5`0L82<041<I01LK800C5Q`051LO01<F7P0E62004aHN01<F7@0F6Al0
720S01hR8`0D61P06b0L024V8P0F6aD05AXC010F3P0;4P/041HB01DK6P0?51L041<H0P0F6B00F00G
61h05QHK01<C5@0A4Q@04ADA010G3`0A5a8051XF00dC3`0;4@h03a@B00X@400E6a/07B<S010E5`0B
5a/04ADM00lC7@0>4aX04QLK00lE4`0>51805A/F00`C30083PP03aDB018H5P0=4a<03Q8E00hB5P0?
4aD04QHG010D5@0@51@03a<B010E4@0A5Q803Q<>00dB300?50d03QD900dE2@0=50`03A8>00`B400<
41<0:Bda01HK7`0=4QD04AHG00dC4`0>4a003aH?01HM5@0<4P`02Q0<018H500J81d04ALE00/A4@0=
4a<02a4B00dB5@0;41<06QlS04mDF00?51P04AHJ00dB5P0D6Ad03Q<G02DZ;`0S:2d03A8G01<H7@0D
6A`04ALG00X@3P0D6QP03A<A03<i=`0;4@l03Q@B018H5P0A6AH03aLD014H5P0mAD4200lE4P803Q@A
0P0=4a00100A5a@051XG00hD4P0;4@l200dC4@803A8>00h03Q<?00lD400?51003a@@00`A3@0A5Q80
3A8>00hC3`0@5A403A8>00`A2`0=4P`03Q<=00lD3P803Q<=01h02@h801lT7P0;40X041D?00L<1P0<
4@/03Q<=00lD3P0<4@/03a@>01<H4P0B5a40:c0Z01/P6P0@5@l03A8<00/@2P0=4P`04QTA00T@2@0?
5Pl03QD>020W800>5@h031<;00dD3@0>5@h03QD=00dD3@0@5Pl2014F400501<H4P0B5a403a@>00dB
300<4@/00P0=4P`200hC3@0401lT7P0Q9Ql04AH?00/@2@803a@=01802a0900lD3@0=4P/08bPQ00X?
200C61403Q@;00lE2@0@5P/03A<800X@1P0<4PP0318900P=1P0?50h01P/500P=1`0;40X300hC3004
00dB2`0<4@X0314:00`A2P802a0900D02Pl800/@2@0<4@X04aH?010C300200d@2@0>00hA2P0?4P/0
3A0900D80@0B5@h02`h7018E3P0<3`P04QD<018E2`0@4`T03Q4700d@1`0A50X600hA1`8041<<0P0>
4@X2010C300G00lB2`0B5@h04A@=00lB2`0A50h041<=00T?1P0>4`/0314:018G4P0=4Ph041DB00X>
300C61D03A8<014F400:3`L041H<00`?200@4``02`h700`?200A50d0100=40T08P0E61403Q4:018E
3P0];bX04A<>00h@2`0@4Pd03@l:00lA300D5Q404A<>00`>2@0>40/03a4<00/=200=4Ph0314=00dB
3P0?51003Q<?00dB3P0@5A403A4>00P=2@0=4@d04aPD00X?2P0B50h02`h700hA2`0@4P`03a8<01@F
400>40X2018E3P0J00/>1`0?4P/020/300`B200>50X04AH>00X?20093PL06QlI01`Q6`0@5A002a0;
00dB3@0>4`l0314=00P=2@0=4Ph05a`H00`A3@093PX05Q/G01<H500;40`03A8>018G4`0@5A4200`A
3@0X00dB3P0>4`l03Q<?00hC3`0=4Ph02a0<01hS7`0:3`/02`l<00/@300=4P/03Q@:00dB2`0=4Pd0
310?00h?4P0=3Q402@T=00l?400G5Q@05QDB010A2`0A4`h02Pl800dB300?50h02Pl901DJ500?50h0
3Q<<00`A2`0=4P`041D>00lD3P0=4P/0>Chg01dR6`0<4@X04aPA00`A2P803a@=00@0314:010E3P0?
50d02a090P0<4@/04P0=4P`03Q<=00hC3@0:3`T03A8<00P=1`0?50h0314;010E3`0:40X02Q4:00L@
200>5Pl04QTB00hE3P0<4``0314;00d@2`8030h90P0>40/01@0<4@/04aPA00dA3@0/<B/03A8<0080
3Q<=00<03A8<00`A2`0=4P`00P0>4`d0200<4@/02Pl800hC300>4``02Pl800`A2P0>4``03A8;0P0<
4@X02P0=4P/041D>01XO6@0D6A<02Pl900lD3P093PP03Q<=01<H4P0=4P`200`A2`0300/@2P093PP0
3Q0;00803a4<0`0@4Pd200lA3003010B3@0?4@`03@l:008030h900H06A/F00D70P0B50l03@l:00lA
300@4Pd200`>2@05010B3@0?4@`03@l:00h@2`0?4@`00P0=3`X0300A4`h04Q@?00h@2`0=3`X03Q0;
00lA300=3`X03a4<01<E400B50l03Q0;010B3@8061XE0P0?4@`01@0>40/03a4<00lA300B50l04aD@
00804Q@?0P0A4`h0100>40/04Q@?01<E400=3`X2018D3`0600dA2`0>4`d03Q<=010E3`0A5Q003Q<=
0P0=4P`07`0<4@/03Q<=00hC3@0=4P`04AHB00lD400T:BD061dI018G4`0@5A404AHB010E4@0F6AH0
41@@01<G4`0>4@d04aPB01HK500?50h051TC00870P0@5A402Pl;01<H500<40l04ADD00H:2@0@5180
4Q@?01@F400E5a400P0A4`d04`0D5Q004aD?014D3P0?4@/03@l900hA2`0A4`d04aPA00`A2`0E6QD0
3A8=010E4@0B5Q@03a<A00hC4@072`X03a<C01/O7P0@51<05?ooool001_ooooo00<030`<00d=3@0>
3Ph00P0>3Ph00`0=3@d02`/;00d=3@0200l?3`0G00d=3@0;2`d051DI00@52P0K72403@hC00/<4@0B
4aP03a0E014B5`0@4AH02@TA00l?5`061``030dB018C5`0?41@03PlC00l@4P0=3Q002P`<00L9200:
30/00`0>40d0@`082PT03a0B01@E5`0>3a402P/?00h?4`0@4AH020T>00L83@0<31@0=cLo0083200D
5AP02@X>018C5`0>3a@05aLO00d=5@0K6b<02``A00h?500G61`00`@600d?3@051`8010H101LI500=
3``02@/8010B400=3`h0414C01HG6@0D5AT05QLK02DV:`0<3aH010L>02HY<@2]/KX092Pa014E7P0B
5Ql04ADN01@H8@0F6B805APQ01DH7`0D5ah041<J014D6`0D5ah05APO00lB6@0H6b005APO01TL8@0C
5Q/02@`A01HJ7P0D61/04QHI010D5`0G6ah0>3`o01hR9@0F6Qd00P0G6ah00`0?4aH04QHI018F5`04
018F5`0K01<G600=4A803Q8C014E5P0C5aP051PI01DI6`0F6ah0:2d`028W:P0B5a/0724U01LL800?
51P05a`P01`Q9@1BEe/0Zk2d04aAE@0G72803a@J018G7@0K82H05Q/Q01<H7P0E6R005Q/Q00805AXP
05`04aPN014F6P0A5QT05Q`M01DK6`0H7B007B8T01HL700D6A`05AXL01LM7@0H7B005Q/M014G5`0G
6a`03a<B01@H5`0F6QT04ADE01DI6P0H71d051PI01XN7`0G6ah041@G01XN8@0;3a8051LL01HI7P0@
4aP07B0U00L:3`0A51X05QTP014D6`0>4AP03A0G01/N8`0H71l020`?00hB5@0A5AL03Q8C01TM7P0B
5QL020`=01`P8@0=4A40=CTj01DK6@0C6aD051XF01@M600D6aX041DH00hF6@0D6R404ADP01@K9@0B
5b@030lN00lC7P0H6b4020/@01TM800?4aH02`l@014E5P0e>CP061`K010D4`0B5a<051TE00lG4`0@
6AH051dJ014G5`0E6AX061TM01<D600I6Qh082@W01TN800<4Q802Q<B00lE5@0I7Ah02@d>00lC5007
2`X04ADF018F5@<041@C00H04ADD01<G5P0D61X03a<F00H:3@0N8R@201HJ6@803A8>02003Q<?00lD
400@5A404AHB018F5@0A5AH020`<010D4`0F6QT0310?01/O7P0;3`h0310?00D9200D6AD04aPD00X?
2`0<4@d03A0=014C4P0C5aH03Q4A018C5@0J7Ql03a8C01TK6P0C5aH03a8A00dC3`0?5A4041HC00dC
4@802Q0>100>51801`0=4a<02a4A02<X:`0d>C`0314D01DJ7P0@5AX00P0;41H08@0]<CX000@=02@X
<`1YKGP04QHO00hF600740h02Q<@00`B400V:bT061`K00T?2`0D6aL000H000lL5@0A6a@03AXA00dD
3@0C61801``600hC3@0>50h02Q4:02D/9@0G7aT01@h901HO6P0<5A002a4=00hC3`0A5Q804QLC00lD
400400dB3P07010E4@0>4`l02@h:00/@300>4`d03A8<00`A2`0200dB300R00hC3@0@5@l03Q<=00hC
3@0A5Q005a`F00`A2`0J7a/01P/700@91@0A5Q80QHZ6055FDP0>4`l06b0L0004000@5A402Pl;00/@
2P093`H04aPA00/A1`1@EDd092TR00hD2`06308020d6010F3@0F71804aPA00lD3@0A5Q8041DA00lD
40803Q<?01H04AHB00/@300;40`02Pl;00`A3@0A5Q80314;00dB300?50h041D?00lD3P0=4P`0314;
00dB300>4`d03a@>00dB300<4@/03Q<<01DK4@0D6A803A8;0P0>4``300T>1`0I018G40093PL0314:
014F40011P004AH@00X?2@0E6Q@041D?00X?2@0L8A/02Pd900X?2@0A5Q003A8<014F40062`D03Q<=
00X?2@0<4@/02@h800/@2P0=4P`041D?00hC3@0200`A2`0P00dB2`0@5@h01P/400/@2@0=4P/0314:
00P=1P093PL0314:014F3`0G71D06QlH00lA300=40X01PT2010C2P0>4@P02Pd4010C2P0G6Q802Pd6
06AVH@0>40h030h;00h@2`0>4@X03a8;014D3@0?4@`020X500`>2@0=3`X200hA2P0900d@2@0<3`P0
4A<>00T;1P000@006A/F00P:1P0L7QT061XE00802P`700<05ALB00d?300E5a800P0A4`h0300@4Pd0
3a4<00`>2@0;3@P03Q0;01DG4P082PD04aD@00@60@0A4`h02a0<00lD40803A8>0280314=00L<200@
5A4020d900`A3@0=4Ph0314=014F4P0=3`X00`D000lA3P0@4Pl0@D=201DG5P0;3@X03@l:0044000>
4@T061/B00d@1`0A5Ph06QlH01<H4@083@H02a0900dB2`0;40T03a@=018G400?50d02a0:00hC3P0?
4a803Q8A0P0=4A00200>4Q40310?00hB4@0:3Pd041@C00lC4P0:3Pd03Q<?0P0<4@/02P0=4P`03Q<=
00hC3@0<4@/02@h8010E3`0:3PT010T301XO6@052@D200X?2@0M00/@300=4Ph041@C00lC4P0:3Pd0
5QPF00P:1`0@4Pl03@l;00dB2`0>50X03A<:00hC300B60h03aD<00`A2P0<4PP02a4800/@2@0<4PP0
3A8:010F300F718051X@00T?1@0;4@L051X@00/A1`0=4`T00P0@5P`02`0?5@/03A8:00lD3P000P00
3a@>00hC3@0:3`T03A8<00P=1`0C618041D?00802Pl900L02a0:00<80P0C6A803Q<=000400083@L0
2a0:00803a@>01003A8<00`A2`0<4@/03A8<02ld;@13BD003A8;01dR6`0@4`l0314:024V800;40/0
41DA00/@30062`L04AH@100=4P`00`0;40X02@h800/@2P0500/@2P0900lD3P0;40X01@X400X?2@0>
4`d051TC010E3`0;40X02Pl900802a0:01<02Pl9014F4P000`00314=00dB3P0A4a003@l<00h@3@0?
3`d04A4?01@D4P0?3`d02`/900d?2P0A4`h051HA01<E400>40/030h900804A<>00P03a4<00d?2P0?
4@`04A@?018G4@0A5Q002a0:00lD3P804A<>00<04Q@?010A300@4@`00P0A4Pd07@0@4Pd01``601PM
5`0=4P`05AXD01@I4`093PP0314;014F400=4P`041D?00dB300<4@`051TE010E4@0B5a<02a0<01<H
500=4Ph020d900870`0L8Ad03A8>01TN6P052PH02a0<00dB3P0>4`l03A8>0080314=01L01P/700`A
3@0?51001@X600P=2@0:3`T04QLA00/@2P0=4P`03Q<=00h@3@0E5a@06adJ01PH600?3`l04A4A010@
400:30T03A8>018G4`0<4@d04aPD00X?2`0200dB3P0<010E4@0C61@02a0<018G4`0<4@d03A8>010E
4@0A5Q8041DA00lD40083@T0314=0P0@5A403P0>4`l02`l>014E500A5AH03Q8C00`@4@0=4A804ADF
00dA4P0?4a@01PX;00dA500=4A<03Q8C5?ooool001_ooooo00<02`/;00`<300<30`00`0<30`00`0;
2`/030`<00`<300200`<300@00/;3@082@h030`D01DE7@0;2a<03`lG01DE7@0C4a/030`D00d=5@0:
2Q804A4I00h>5P0@4AH04a@I00l@5@802``@00P02@X<018D500?4A003a4>00h@300<3PT03@l:018D
4@803Q0?02P02`d<00`=3`0B4aD0414E01LH7@0A4QL0:2P`065QJ@0Y:Rl03a0C00T:3P0I6Ql04Q8J
01DE7`0D51h02@TC00h>600[:c<05aPM00421P0L7Q/06ahG01`O600930D051HA01dO6P0F61D04Q@A
01@F5@0G61T04Q<E01<D600@4QL03a8K01XM9P0N8BX0A4M@00lB6`0E62404QDN0P0A51d01P0B5Ah0
4aHO01DH800B5A`03a8I010C6P804aHM00d04QDL01`O9P0F6B005QTP018E700;3QD04QDJ00dA500C
5aX04QHI00lC5P0L82<05QXM00<04aLJ00@041@G018F6@0A5AH04QHG0P0E6AX06`0D61T04QHG010D
5@0A5AH04aLH01@H6@0E6AX05QXK01XO8`0S:2`07B8V01<H700J7b<05AXN010E6@062`l07R<W0825
R@35b/h0:Rlc01@I7`0E6R0092T_02db>00M8RP04AHL01<H7P0301@I7`0E01<H7P0B5a/04AHI01LL
7P0D6QX051TL01TO800F71`05a`O01HL7@0F71`05a`O01<I6P0>51@04ADD01/P700H7AT04QLC014E
500C5aH04aLH008051PI03`051PK01<G6P0C5Q/05QTP01XM900B5A`061/R00hA600;3QD04QDL01<F
7@0G6R408bH]010C6P072Pl05ATK02hb<`0H71d04ADF00hB4`0;3a0051PI00dA4P0R9RL06AdN03m3
A00R:2H01`h:00D>2@094Pl041PI01<K7P0B6Qd03A@K01/R;00A5b<0318P01@J:P0J82`07R4U00dA
500E6A`01`/<03/o@00D61T07B4P014E500D61L04aLF014E500>5A@03aTH00lH5`0;41403a<D01<D
5P0A4Q@05AHH01PI6`0D6AX200dF5@04014H6@0D61/03a<F014E60<03A4B00<041@C014E500B5a<0
0P0B5a<04P0?4a<05QXK01TM7P0`=3@092PW01/O7P0<40h03a@@010E4@0A5Q404QLA01<H4P0830/0
4QHE01PL6`0<40l02`l>00lC4P801PX900`0720O00T=30093@`0310?010B4@0A4a80418A014C4P0D
5QD03Q0?01TK6P082PT201<E5009014C4P0D5aH03A4@00lE4`0B61H041HD00lE4`0@5Q@03A<A00<0
3Q@B02L03A<A00`B400630`05Q/N00H;3P0A5QX05AXO01@I7`052A8020`F01lS;P0B5R40SY:N01DL
900@61X04Q/I00dF4`093`d041DC0045100=4`l00@X501LT7@085@h03alF00/K4@0;4P/04aPA00`A
2P0B5a0041H?01@K500?5Pl02a<<02@^9P14CDP09c0[010I500>4`l00P0A5Q80300>4`l03A8>00hC
3`0?51005Q/G01TN6P0A5Q803A8>014F4P0>4`d03A8<00`A2`803A8<01l03Q<=010E3`0B5a403a@>
00P=1`052P@020d700860`0=4Ph04AHB00L;200n@cl0:2dY00lD400>4`l01``802H[9`0730P02@h8
03To=P011`001`d301HL4P000`004AL=00P>100L8QP03Q8<0003000B60h03a@=00803Q<?100?5100
1P083@T0314=00dB3P0?51004aPD00dB3@803Q<=00H03A8<00hC3@0>4`d03A8<00/@2P0<4@/300hC
3@0300/@2P0?50d04AH?0080314:0P0=4P/02P0M8Q/05AXC00dB2`0<4@X02a0901HK5@0730H04aPB
00T>200A5Q0200/@2P0>00L<1P0?50h0<cPb04M<AP0:3`T00@H0020U7`0=4P`02@h800dB300>4`d0
2a0:00T>200:3`T200dB300;00X?2@0;40X041D?00X?2@0>4`d03A8<00`A2`0=4P`03Q<=00lD3P0@
5@l00P0A5Q004@0<3PT03a8<00X=1P0B5@`04QD;01@G300C5P/03Q4800d@2@1LGUT051HD00P:1`0:
30L03A0900P;100930D041<<00803A09100?4P/03@0=40T04A<>01DG4P0N81/02@/605]MF00<3PT0
2`d800`>2@0?4@`06A/F00h@2`092`H00P0=3`X200h@2`<03@l:00D04A<>00X<1`0B50l04Q@?014C
3P0200hC3`0400/@300<4@d03A8>00X?2`803A8>01L04AHB00hC3`083@T02Pl;00lA30072@H05QPE
018D4`0g>3X0414C010B4@0?4@h03Q0;014D300@4`P01`X1010E3P0D6A803Q<<00P=1P0;40T03Q<<
00dB2`0200hC300?00dB2`0<4@X020d800H:2@0>4Q4051PG014E500<40l02Ph=01<G5P0=4A00310?
014E500=4A0041@B00<041D?0P0A5Q001`0D6A<041D?0005000U:R@03a@>00L<1P0B5a800P0;40`0
100<4@d03A8>00lD400?510200D:1P0;00X?2`0B5a<02a0;00X?200<4PP02Q0600/A1`0?5@/03188
00hD2P0=4`T00P0<4PP01`0>50X04AL=00dC2@0B60h041H<00T?1@0;4@L00P0@5P`06@0A5`d04aT?
018H3P0A5`d03Q@:01XO6@0?50h01@T501hS7@0G71H03Q<=010E3`0;40X03a@>00dB300;40X061dG
01LL5P042@<01``6024V800E6Q@02a0:00dB300<4@/00`0:3`T03@0:3`P02@h701hT6P042P005a`E
00dB2`0;40T01``600dB3@0@5A404QLC01DJ5P001000100>4`d800dB300>00H;1@0D6A<05a`F01LL
5P021`404aPB010E3`0;40X02Pl900`A2`0;40X02Pl900lE4@0E6QH200dB3P0M018D4@0@4Pl03a4>
00l?3@0@40h04a<A010@3P0=3@/03Q0;01HH4`0J71L061XE010B3@0<3PT02`d800`>2@0620<04Q@?
01XL5`0<4@/03A@=00lD3P0<4@/03a@>014C3P0>40/03@l:00d>2@0?40/00P0B4`h07P0C5A001@X4
0005000A5Q00008000hC3@0?50h010T3018G4@0=4P`04AH@00D:100B5a802@h:00hC3`0;40`01``8
00X?2`083@T04aPD02ld<013B4@02a0<00T>2P0?51002a0<00dB3P0>4`l03A8>00`A3@803A8>02@0
5a`H01@I5@093PX03A8>00L<200@5A40314=014F4P0C61@04Q@A010@3P0F5Q@051@D00l=3P0A3a00
4A0A01`N6`0@5A404QLC01dR7P0?51003Q<?00dB3P0;40`0314=00/@30062`L0314=00`@3`0=4A00
41@C014E500@51<03a<B00/?3P0?4a82018F5@0;00lC4P0<40l041@E00hB5@0?4aH04QHI01<G6P0@
51L05ATL020T9`0=4A@00P0@51L00`062Pgoooooooooo`0Booooo`006oooool300`<300300/;2`0<
30`030`<008030`<0P0:2PX02`0<30`030`>00d>4`0;2a<07AdU010@600J6R80ShnG02`/=00D51`0
5ADM00<03@dE00X04Q8J01@D6`0?41D03PlD00l@5@0=3Q402``>00d>3`0:30/02P/;0P0=3`d0100=
3`h030h=014C4P0B4aD200d>4P0T010A5P0>3a@04Q<H00/;4`0Q8BT020P>018C5`0:2a0051DK00h>
600@41`051@P00l?6`0>3QT06a/T00h?5@0F5a/0:2X[00h@3@0=3``04A<@00d?3@0<3P`04A<C010A
4P0A4Q@051DG00l@4P0A4Q@04Q@I01HI800:2a80<SDl02T/<`0E61l041<J0P0D5ah01@0B5A`041<J
018E700D5ah04QDL008041<J00@04A@K018E700B5A`05QTP0P0B5A`0100G6R406A`S01PK800A5AP2
01HJ7@0>018F6@0@51L02`lB010D5`0?4aH03Q8E01<G6P0B5QT04ADF01<G600G6a`061`M01HJ6`0A
5AH301@H6@805ATJ00d05QXK01LL800F6al05AXN01HK7`0G720061dQ01LL800F6al051TM018G6`0_
=3P04AHJ00804aPL0P0D6Ad01@0A5QX04QLK010E6@0B5a/04aPL008051TM00L04aPL014F6P0G71l0
4aPL010E6@0E6Qh06b0S00804AHJ00H04aPL01DJ7P0D6Ad04AHJ014E5@0F6QX2014E5@0801@H6@0:
3Q0051PK01PL7`0F6Qh051LL01DH7@0B5A/201@G7P0700d@5`0L7bH04A@K01/N9@0A51/05aXQ00hA
6002010C6P0R01DH7@0D61X04ADF00hB4`0G6a`02Ph?01XN7`0D61T03Q8C01PL7@0<41407b<T00P=
3P0T:bX051dK00lG600@61T04QXM00`D5`0A61h04APQ00H=5`0A62<05A/W00P>5`0C5QP05a/L01dQ
8P0C5aP0J6a]024U9P0B5QL03a<D01@H6P804QHH02`061lO01TP800C6AT041@E01HF600H61X05A@G
018B500A4A<03a<D00lF5P0@5aL04QLJ00P;400B5AX02`lC01<G6P0A5AP03a<E010D5@0B5QL051PH
01<G5P0B5QH03a<D014E5P0;3a005a/L00dA4P0D61L041@C00hB4@0?510041D@014F400A5Q4041@C
00P<2`0G6aX02@d<01@H5`0C5aH0:Bd/00`@3`803Q8A01@051PG00dA400A4a8051HE018D4`0A4a80
4aDD00lA400D5QD01PP701HH5`0620L05ALF00d@3`0>4Q403aDC014G5@0@5Q@03aDC014G5@803A<A
0P0>51808`0=4a40318@00/A4@0;4A403A<C00`B4`0>4aH02PlC010E6P0D6Al0HfQ_01/P9`0_=3d0
3A@K00L=3`0A6QP01a0=00lE4`0@5A@051PG00T?3@0A6QH04b0I00TF3`0<6Q<01A0900`D3P0?5@l0
3A<>014H4P0;4Pd05A/G00lE4P0=4a001@h:00803aPE01001Pl<00hC3`0A5Q804AHB00lD400>4`l0
3a@@00hC3`0H7AT06b0L010E4@0=4Ph04aPD00hC3`0=4Ph0314=0P0=4Ph0300>4`l02a0<00hC3`0;
40`03Q<?018G4`0g?3P09R/W00T>2P0@5A403a@@00T>2P803Q<?01<03A8>018G4`0@5A402Pl;018G
4@0Q9ah04QP>00T?1@0?5@`05adC00`B200=4`T0=3X`02X`9`0<4PX06R0F00T>200:3`/0314=0080
3a@@0P0>4`l04P093PX03A8>00hC3`0=4Ph03a@@00`A300?50h03A8<00`A2`0=4P`03a@>00hC3@0<
4@/02a0:00dB300?50h041D?00lD3P803a@=00d03A8;00hC300?50d03Q<<02L/9@0G71D01``5014F
3`0>4``03Q<=00H;1@0>4`d020d700804AH@00d051TC00<80P0A5Q00<cPb04aAB`0@5@l061dG05AI
D`0R9b4041D?00lD3P0:3PT041D?0080314;00P04aPB01DJ500@5@l02Pl9010E3`0<4@/041D?00/@
2P80314;01P03A8<00lD3P0?50h03A8<00X?2@0=3``04Q@?00lB2`0E60l03a8701<G2@0A5@L041@7
01hQ5`0j?CD04Q@>00lB300:3@H06QdF014D3@0<3`P04QD>00/>1`0>4@X4010C300A00hA2P072@@0
3a4<00P:1P0F61<08R@P01DG4P0?4@`0418=05]MF01TIV40418=00h@2`0C5A004Q@?014C3P0?4@`0
0P0>40/01P0@4Pd03Q0;018D3`0;3@P09BLR00P:1@8041DA00<02a0<00`A3@0?51000P0=4Ph00`0C
61@05a`H014F4P0200X?2`0C00`>2@051`@05ALD00`>3@0L7Al01PL900lA400B5140418=00hA2P0>
4@L03a8900hC300<4@/02Pl900/@2P0<4@/03Q<=00dB300200`A2`0700dB300>4`d03a<?00dA400?
4a803A4@00X>3@0200T=300600hB4@0:3Pd041@C00lC4P0830/03a<A0`0@5A402P0?51003Q<?00dA
3P0?510041DA03Xo>`0F6aL02@`9010E4@0?510200hC3`0>00dB3P0>4`l02@h:01@I5@0>4`l03A8>
00T<2@0F6aH02a0900dC2@0;4@L03188010F300=4`T200X@1P0900T?1@0:40H02a4700hD2P0:40H0
318800/A1`0<4PP03aD;00803A<90P0>50X05`0=4`T0318800T?1P0<4@/04AH@014E401NHed0C55;
00`@2`0=4P`01``600lD3P0@5@l04AH@02L/9P0oA3h05Q/E028W8@0B5a402@h900`A2`0>4`d03A8<
00802a0:00h0314;00dB2`0>4``0318800X@1P0A5Pl03a@=00/@2@0<4@/03a<?00hC3`0;40`03a@@
00X?2`802a0:00<02Pl900/@2P0=4P`01`0>4`d01`0?50h02Pl900T>200A5Q0020d701HK5@0?50h0
0P0;40X02P0<4@/02a0:00X?2@0=4`l0=3Te02@Y9@0B5Q<04Q@A00T;2@0@4Pl200l?3@03014A3`0@
40h0410>00803a4<0P0@4Pd06@0?4@`03Q0;014C3P0A4`h02P`701XL5`0S9B004AH@010G400C6180
51TC01DJ500F61<04Q@?00h@2`0>3`X03a0;010A300?40/03@l:00dB300B5a40BDi800/?2`0?50h0
0P0=4P`04@0>4`h03a@>00dB3@0>4`d03Q<>014F4P083@T041DA00lD400>4`l0314=00T>2P0>4`l0
41DA01/P70042@D03Q<?00@03A8>0240314=00lD400B5a<06b0L01HK5`0;40`03a@A02HZ:P0Y;Bh0
5ATJ00lC500?4a<04A<C00h@3`0A4a804Q8B014A4@0C4a<051<D00X<2@0E6QH02a0<00lD400730P0
4QLC00lD400A5Q806AhJ01LL600B5a<02Pl;00hB4@0?4a800`0@51<00`0?4a8041@C018F5@0201<G
5P05010D4`0>4Q403Q8C00/?400@51D00P0G6a`01`0@51D02Ph?00dA4P0@51D05a/L00dA4P0D61T0
5?ooool001_ooooo00D0410@00l?3`0=3@d030`<00d=3@0200h>3P0L00d=3@0;2`/02`/;00d=3@0>
3Q0030dA01@E6P051P/03@hC01TJ7`0^;c@06AXO00D62`0A4QL03@hC00`=4P0=3AD0410H00d=5@09
2A402`/B00h?500;31403a0E014B5P0;30h02``?00d>40802``>02l04A8D01/L7P0M7R804Q<G00d>
4P061``01@H;01/L8@0=3AD02PXB00d=5@0?41D04A4I00d=5@0E5B005A@R014@7P0:2QL05ADQ00d=
5`0@41L04a@I00X;3`0K72006Q/O00`=4@0G61`04A8F00P82`0=3Q003PlA010A4`0>3a40414C01PJ
7`0H6b006ahS010C60062@h041<H01PK800D5a`05aXO01HI7P0B5AX03a8G014D6@0201<F6`804QDJ
0P0C5Q/2018E6P0?00d@5@0A51T04aHK010D600C5aX04ADH01<G6P0D61/04ADH00/?4P0C5aX04ADH
00hB5@0E6A`04ADH00<04aLH0P0B5QL02@0A5AH051PI01@H6@0C5aP04QHG01<G600E6AX04QLK010E
6@0201DJ7P0E014F6P0H7B407B8V018G6`0A5QX03Q<G01XO8`0I7R804AHI01HK7P0J7b8061dP01@I
700@5AP03Q<F010E600B5aX04aPK01@I700D6Ad04AHJ008051TO00l04AHL01HK8@0R9bd06AhT01HK
8@0C61h04QLM00hC6@093Q805QXM00`@4P0C5aX05ATL01<G6P0R9BX00P0G6Ql0500N8BP06A`S00lB
6@0G6R406A`S01<F6`0G6Ql01`X?020S:00>4AH05QTN01<F6`0A51T05aXO00P;40031P/01`/=01`P
8@0;3a0041@E0P0=4A8201<G600[01LK700D61T0720Q014E5P0P9BP041DH00`A5@0@5AT05Q/O00lD
600M8RH000D;01XO9@0oA4X0<cPn018G6`0320H03A4@01<G5P0=4A004aLH00P<3@0@51L02`lB00`?
500;3Q<03Q4F01@H700A5AH03Q8C018C5@0E5AL0518E01@@500F51L061PJ01<D5P0=4A803Q8C014E
6P0C5Qd06QdT00lB6@02014D6@0?010C600@51L04QHI01<G6P0B5QL03a<F00/?4P0=4A@06alR0455
A`0H71d03A4B00dA4@0=4A003A8>00<03Q<?01002`l>01TM701:CTd06alN01HJ6@0;3`h061`K00H:
2@0E6AP041@C014E500;3`h03@l>010B4@0?4A003@l>0P0A4a802P0:30/04A<B014C4P0G6AP071hM
00hA400F6QT05A/I01<I5`0=4a4200X@3P80318@0`0>5180;P0=4a405Q`J00X@3P0@5Q@03A<A010F
5P0@5AP02@hA00hC5P021`/0314E00hC600=5AP051dL01LQ7@084@h051XH00dB400>4Q403aDC00D>
2`0>6QH04alK00PH4P0>7AP041/G00dF4`0:4a004a`I00dF500?61D01Pl>00D>300:4a801a0?00XC
4P0E7Q/03Q<?010E4@0?51003Q<?00lD400A5Q803A8>00/@300=4Ph200/@3004010E4@0>4`l03A8>
00`A3@803A8>02<03Q<?01<H50093PX01``800dB3P083@T0;34]01<H500730P06b0L00/@300<4@d0
5Q/G010E4@0<4@d010T500/@300A5Q806QlI00`A2P0=4P/02a0900`A2P0:3`P02a0900hC300<4@X0
5AXC01HK500;40T02Pl800/@300=4Ph03Q<?00dB3P0200/@300]00L<200;40`04AHB01TN6P0Q9R80
51TD00`A2`0=4P`03Q<=00dB300<4@/03A8<00hC3@0<4@/02a0:00`A2`0>4`d06AhG01HK500;40T0
3A8;018G400?50d0314:018G40093PL03A8;014F3`0?50d04QLA010E3`0>4`d010T300L<1P093PP0
20d7010E3`042@<00@H00005000:3`T000<000hC3@093PP01P/500803a@>0P0:3`T200`A2`0O00dB
300@5@l03A8<00hC3@093PP03Q<=00T>200=4P`01``600T>200=4P`03Q<=00dB300;40X020X700/=
2@0C5Pl08B@K01`O4`0P91D03a<401@H2@0F6P/04QH800/?0P0?4PL03Q4:020S700E614030l8010C
300200`?20@03Q4:014030l8014C3P0A4`h03a4<00@60@0?4@`0418=00L9100@4Pd07R0K02DW8P0>
40/02@/601HH4`0C5A004A<>00lA300200h@2`803@l:01X06adH01LI500l?ST06adH00hC3`0A5Q80
3Q<?00lD400>4`l02Pl;00P=2@093PX020d900T>2P0=4Ph03Q<?010B3`092`X051HE00l@4P0D5AL0
414C00lA4@0P8Ql03@l:00`>2@8041<:00H0314:00/@2P0>4`d03a@>00dB300;40X200`A2`0@00dB
300>4`d03Q<=00`A3@072`X01PX900P:2@0<40l061`K01HJ6@072`X03A4@02/_;P0E6AP01`/:01<H
5@803A8>00d0314=00/@300;40`020d900L<200=4Ph02a0<0004000B5a<02@d9010E4@0?51003Q<?
00803A8>00/000D1018G4`093PX03a@@028W8`1bMg80314:00dB2`0;40T0314:010E3P0200hC300:
00lD3@0B5a004QL@010E3P0>4``0314:00dB2`0<4@X04AH?01@I4P<03A8;0P0?50d2010E3P09014F
400;40X041D?018G4@0730H02a0:00X?2@0N8ad05Q/E00802@h800T02a0:00L<1P0K81X0?D8l00hC
3@0@5@l04AH@00hC3@0=4P`00P0<4@/03P0>4`d03Q<<01@I4P0630804QP>010E3P0C61403Q<<0005
000A5Q4041DA000200000`004AHB10093PP00`0;40X0314;00`A2`0500`A2`0D00X?2@042@<08RLQ
020U7`0;40X00`P200dB300;40X0314;00dB300<4@/02Pl900X@300B5a<07B8N00D:1P0];b`0:2XW
00lA3P0@40h200l?3@03010@3P0A4@l04A<>00<0418=0P0A4`h0200=3`X02P`700d?2P0;3@P03@l:
014F400@5a003Q<=0P0=4P`00`0@4Pd051HA018D3`02014B3@0K010A300>3`X03a4<00hC3@0=4P`0
41D?018G4@0;40X01``600hC3@0I7QP0PhR201LL5P0?50h0;C8]08J;Q`0]<Rh05Q/G00460P083@T0
41DA014F4P0?5100=3Te071eL@0^<bl0314=00803Q<?01403A8>00`A3@0<4@d051TE010E4@0>4`l0
3a@@00dB3P0=4Pl04aPL01LL8P083A4020/@00/>4`0>4Q@04Q<E014B5003018B4P0>014A3`0?4@h0
7B8N00dB3P062`L04QLC00hC3`0;40`0314=01PM6@0F6aL04aPD00/@300@51<500lC4P06010D4`0A
5A@04ADD010D4`0?4a803A4@100>4Q<0100A5AH051PI01<G600D61T200X>3`0300861`072`cooooo
01?ooooo000Kooooo`06018B4P0@41003@d=00d=3@0>3Ph03`l?0P0>3Ph200d=3@0;00h>3P0>3Q00
20T=00l@5@092Pl030dB00/;400000D04A8G00H7300@4AH00P0<3A803`092Pl06ATS018B6P0<31@0
3@dE00l?5`0;31401`P=00T:3`0720`04A8G01LH7@0B4aL03a0C00d>4P02014B5P0E00h?4`0?41@0
4Q<H01LH7@0I6Ql051@L00d=5@071`l030dB01PH800?3aT03@dI00H54`081aD061LU01LG8`0?3a/0
20PA01PH800D51/0410H00804a<K00<04Q<H01@E6P0F5a/00P0B4aL0500B4aD03PlA014B500H6ad0
004401PK800D5a/06QhQ01DH7@092`l04QHI018E6P0D5a/04ADH00`?500=41D04aHK01DH7@0D5a`0
4QDJ0P0C5Q/0200@4aP05APM01<F6`0L7b@08B@Y01<G6`0E6A`05QXM0P0E6A`03`0=4A@041@G01@H
6`0D61/04aLJ01@H6`0A5AP05ATJ01@H6@0B5QL04ADF010D5@0A5AH051PI01<G6002018F5`0G01<G
600F6Q`05AXN01@I7@0G72005Q/O01<H700D6Ad05AXN018G6`0D6Ad000<700H;3`0M8RH03a@G014F
6@0>4aH0314D010E600>4aH03a@G014F6@0C61/00`0D6A`02@0D6Al04aPN01@I7`0C61h05Q/Q020U
:`0C61h04QLM014F700201<H7P0;014F700D5a`051PK020T9`0E6A`041<G03Tl@@0E61d04aHM01XM
900K7RD00P0F6B803@0E61l04A@I028U:P0<3a@0>Se2028U:P0<3a@02`hC00hA5P0A51T051LL02LZ
;`0I7Al00P0;3a00100A5AH04aLH01@H6@0830d200/?400?00lC500A5AH03a<F010E6@083A<020dA
00lD600E6Qh04AHJ00H93@0320`051TL01XO8`0F6ah0318B00805AXF02P05Q/G01LK6P000@805a/L
00hB5@0=41D05APO01<F7@0@4a`03a8G00/?400>3a4051@F018@4`0B3A405A0D01/F6P0L6Qd05ADG
00d>400>3a402`hC01dP:@0@4a`04A@K00hA600D5ah041<H00lB5`0@4aP04ADH00lC5P0>4QD04ADH
00X>4@0420/0720R00861`0:3Pl04aLG0P0?4a83010E4@0=00X>3@0B5QD0<CDd00lC4P0B5QD03A4@
00hB4@021PD03Q8A00T=300B5QD03A4@00/=300200lA400700`>3@0@4Q404Q@C01LI600C5A@03@l>
01XL6`0200P:2@8061hL00<051XH00dC4@0:40h00P0;4@l03P0<4Q003Q@B00hD4P0>51803A<A010F
50093`d020h<00hD4P0@5Q@04QPH038h>00E6a/00PP80P0E6Qd0:0063Q0031DD00dG500<5A805A/I
00lD4`0;3`h04ALE010I5P0F8Qh000P40310?0034Pl02Q@C00hF60053@l03ADG00dE5P0;51<0EemQ
010I600?61L041TH01/T8`1:D5003Q8A010E4@0?51003Q<?010E4@0B5a<03a@@00T>2P0:3`/0314=
00hC3`0B5a<03Q<?00dB3P0<4@d200dB3P0b00hC3`0D6AD03A8>00dB3P0@5A4000D100hC3`0@5A40
0@H201DJ5P0;40`041DA00`A3@0<3``0;c@`08^@S00:3`/051TE01@I4`0E6Q@04AH?00lD3@0A5Pl0
1P/400hC300D6A801P/400T>200<4@X00@H000lD3`0<4@d03A8>00hC3`0<4@d02a0<00lD400:3`/0
314=00dB3P0A5Q8061dI00lD3`0;40X03A8<00lD3P0=4P`02a0:00dB300>4`d200dB3080314;01@0
61dG01@I4P0730D02Pl800hC300;40T03A8;00`A2P0730D04aPA00hC300=4P/03A8<014F400<4@/0
1P/500T>200@5@l0314;01XO6@804AH@00L00`P200lD3P0E6Q@01P/5018G4@093PP03Q<=00802Pl9
00T0314;00hC3@0;40X02a0:010E3`0?50h03A8<00T>200C61800P0<4@/02`0;40X0314;00dB300=
4P`02a0:00T>200=3``030h:010C300I71<051P:00807b<B00d08bLF00/?000A5@@06al@01PL3P0>
4@P051L@00`?20062@8030l801<F3`0<3`P03A0900803Q4:01`03A0900`?200B50l01PL401HH4`03
1@0061XE0001000B50l03@l:004300072@@02P`701HH4`0?4@`03@l:00`>2@0>40/0418=014C3P0?
4@`0418=01PJ5@0D5Q409BLR01<E400=4Ph04AHB0P0?51005P0=4Ph020d900`A3@093PX01``800lD
400E6QH04aPD00lA3P0<3Pd03Q0?00l@4P0@4A<051DG00X:300C5A@02P`900lA300B5@`03Q4:00`A
2`0=4P`2010E3`0D00dB300;40X02a0:00`A2`0=4P`03Q<=00lD3P0C5aD051PG01<G5P0?4a804aLF
01lS8P0K7ah01PX900/?3P0Z;Rd04aLF00H:2@0C61D200hC3`<03A8>01l04AHB01DJ5P083@T04aPD
00dB3P0D6AD04AHB00lD400>4`l03A8>00`A3@0=4Ph082DQ01hS7`093PX00@H200D:1P0R9b802@h8
00/@2@093PL02Pl800hC300;40T03A8;00hC300A5Pl04QL@010E3P0>4``03A8;00803Q<<00<041D>
01<H4@0=4P/00P0;40T05P0=4P/03Q<<010E3P0A5Pl051TC000200011P002a0:018G4@0>4`d00@H0
01dR700D6A<020d700/@2P062`D07b@N028W8@0B5a401P/500X=2@062`D200/@2P802Pl90100314;
00dB2`0=4P/02Q0601HL4P0C614041D>00H;10093PP05AXE00lD400Q9R80=3Te00X?2`0;40X03A8<
0P0>4`d00`0=4P`0314;00/@2P0500/@2P0C014F400[<2X0>Sli02H[9@093PP03A8<00`A2`0;40X0
314;00hC3@0<4@/02Pl900X@300C61@0;c@`01PM6@0W:BH05aTF00lA3P02014A3`0b00l?3@0@40h0
4A4?00/=200@4Pd051HA018D3`0<3PT02@/6018D3`0?4@`05QPC010B3@0?4@`061dG014H4@0>4`d0
3A8<00/@2P0@4Pd04aD@010B3@0@4@`04Q<>01<D3`0A4Pd03@l:014F400B5a4010P401`Q6`093PP0
0`P201TN60021`40?T<m0005000J7aT010T40415@@021`<020`900@91@0E6QH03a@@00H;1`093PX0
6QlK01dR7P083@T2010E4@0O00hC3`0<4@d0314=00dB3P0F6aL041DA00X?2`0=4Ph041DA00lD4P09
3Q@04aLP018F7`0I72D061/R01<F6P0B4aL03PlA00l?400@41003Ph>00`=2`0@4Pl010T500X>2`0?
51005AXF00X?2`0@5A403A8>00hC3`0200`A3@05014F4P0A5A@041@C00lC4P0>4Q400P0?4a804P0>
4Q403a<B00lC4P0?4a803Q8A00dA400?4a@041@E00dA4P0;3a003Q8C01@H6@0X;2d0?D5201TM7P0E
6AX07b<T00lC51Cooooo000Kooooo`0801<C5@0@418030`>00/;3@0=3@l03Ph@00/;3@0<30h200d=
3`0800`<3P0;2`d03PlC00/<4@0C51T01@D:00d>4`0D5AX200`=4P0A00h?500:2a00414F00X;400I
6B80410J00X:500>3QL0410H00d=5@0>3QH030`D00X:4@0K6b807alW01@E6`0?41D00P0=3Q<02P0<
3A804A8G01TJ7`0>3a@020T>00d>4`0?3aL01`L?00l?5`0<31@201HF800?00X:5P0J6BL0D4mO01PG
9@0B4Qh03PhJ010@6@0L72@04Q8L00X95P0:2QD03`lJ00/;5P0S8b`0;Bhd00803a0E01l04Q<F010A
4`0D5AL05QTJ00/?400E6A/05a/L00dA4P0F6Q`07b<T01DI6P0>4Q@03a<E01<G600?4aD03A4D018E
6P0E61d04aHK010C600A51T051LL00lB5`0E61d041<H01XM8P0S9R/04QDI01LK7P0E6A`041@G0080
51PK00@04QHI010D5`0E6A`061`O0P0C5aX05P0D61/05ATL01HJ7@0E6A`04aLJ010D5`0E6A`051PK
01<G6P0D61/05QXM01XN8@0F6al04QLK014F6P0O92P09BX^01DJ7P0>4aL0314E01@I7@0?51P201`Q
9@0801LL7`0G7Ad051XJ01LM7@0L8R804aTI018H600D6QX301DK6`0301@I700J7bD04QHO008051PQ
00<04QHO01HJ8`0E6B800P0B5Ql0B00C5b0051PQ018G7@0F6Al051LL01DH7@0A51T04A@J01lR:@0A
51`05QTR00`?600Q92h0>3Y6010C700J7B@041<H01DH7@0;3Q<05aXO014D6@0C5Q/041<H01HI7P0?
4QL07b8W04]>D`17Bdh0310C01PL7`0?4aH051PK00dA500B5QT051PK00`@4`0C5aX03Q8E018F6P0A
5Q`041@M014F7@0B5ad041DI00lD600C61X061hO00/A4@0N92@06b4P00H<2@0A5Q004QLA00dB300A
5A<04QHG010D5P0D5a/03Q4H01LJ8`0G6B@04A<O010B600@4A<04a<E01LE600A31004`dA01dG6`0K
5QX05A0D014@4P804A8D00T0:bdd06=UL@0D5R8041<M00D84@0E62403a8I00lB600>4AH00`0=41D0
2P0=41@04aLJ00T=400>4QD02PhA01<G600<41403Q8B00hB4@0>4a4200hC3`0300X>3@0?4a803A4@
00803a<B01H03A4@00`@3`0H71/0:Rh]00hB4@0C5aH041@C00dA4P0B5QL041@E00X>3`0=4A8041@E
014E5P0@51D03Q8C00@7200M8B80<CDf00lE4`0@5Q@03aDC0P0<4Q000`0?5A<02a4?00`B400400hD
4P0V00`B3P0C6AD01P`801TO6`0B61@04ALD00/A3`0<4@l03A<A01LM700=4a804a`J01@M6P0<5Q<0
3aPE00T?3@0K81l09b//00/?3`0<5A@06bLV00`F5@0/>cX06bTZ014L7`0V<3@03aPL00PB5@0;51H0
2A4D02/c=P0>5QP041PJ00L<3`0?51L04QPH00hB4@0?510200hC3`0;014F4P0C61@03Q<?010E4@0A
5Q80314=00lD400G71P03Q8A00dA400<40l00P0=4A007`0>4Q403a<B00/?3P0:3Pd03A4@010D4`0;
3`h061dI00P=2@0<4@d03Q<?00H;1`0@5A404ADB034f<P1lPGd06AhJ00hC3`093PT02a0:00hC3008
3@H03Q<<00dB2`0:3`P03A8;00lD3@0A5Pl03a@=00dB2`0;40/00P0;40`02`0=4Ph03a@@010E4@0B
5a<0314=00lD400>4`l03A8>00lD400;40/03A8<00<0314;00@03A8<00`A2`0;40X03A8<0P0?50h0
1`0>4`d03a@>00/@2@0:3`P03Q<<00/@2@0<4@X00P0=4P/01P0;40T041D>00/@2@0;40T01``6014F
4080314;01X04QLA01hS7@0?50h01``600dB300;40X03Q<=00/@2P0:3`T02`l:018G4@0730H0314;
00hC3@0A5Q003A8<00X?2@0=4P`03a@>00dB300A5Q003A8<00lD3P0P9Al05AXD00X?2@803Q<=01P0
3A8<00/@2P0<4@/02a0:018D4P0B51403a8;00hA200C5`T0>3`[09JKR02UZID0?T<^024V4P0A5PD0
4QH600lB2@0B5@h071lH01LJ4`0<3`P041<<00hA2P0?4P/2010C300J00lB2`0>4@X051HA01@E4@0?
4@`030h;00d?2`0E5a803a4<018D3`0=3`X04Q@?00h@2`0D5Q403a4<00d?2P0<3PT03Q0;014C3P0B
50l03Q0;014C3P0@4Pd04aD@00<50@0?4@`200hC3`0S00X?2`0<4@d03A8>00/@300>4`l03A8>00hC
3`0I7QX05AXF00X?2`0=4Ph04ADD00T=300?4a@02PhA00lC5P17Bdd020`;018G4`0=4P`03A8:00dB
2`0>4`h03Q<?00`A3@0;40`0314=00lD400=4Ph02Pl;00T>2P0=4Ph04AHB014F4`0F6QT00P0Q9B@0
2@0D61L03Q8A00dA400@51<02Ph=00hB4@0=4A0020`;00hB4@0200dA40803Q8A00T03a<B00X>3@0F
6QT020`;00X>3@093@`03Q8A00hB400=4Ph00`0<4@d00`0=4Ph03a@@00H;1`0200dB3P0D01DJ5P0<
4@`02Pl900/@2@0:3`P02a0900lD3@0<4@X02a0900X?20093PL0314:00lD3@0E6Q<02Pl800dB2`0;
40T02@h700`A2P093PL400hC300@00lD3@0@5@h051TC00870@0C61803Q<=00T>200=4P`02a0:00dB
300:3`T02@h800`A2`0=4P`01@X400lD3P803Q<=00<0314;00T>2@0<4@/00P0;40X05@0<4@/03Q<=
00hC30093PL03aD;00P>1P0;40T03a@=010E3P0B5a402`l;01HK5`12Ad<0DEEB00hB3P0;40X03Q<=
014F400@5@l03A8<00P=1`0600/@2P0[038g<@2[/:X0:RlY014F400:3`T03Q<=00`A2`0;40X03A8<
00hC3@0<4@/02Pl900/A3@0@5A402@h:01PM6@0C5A8030h;00d?300C4a4051@B010@3P0?3`d0410>
00lA300<3PT02`d800`>2@0>40/03a4<018D3`0<3PT02P`700d?2P0<3PT03A8<00hE3P0>4`d04QLA
00lD3P0B50l051HA010B3@03014B3@0L00h?2P0;3@P07R<M00/>2P0E6Q@03Q4=010E3`0=4P`04QLA
00hC3@0?50h0314;01<H4P0C61<02Ph;01PM6@0@5A403Q<?01TN6P0Y;RX092TU00/@300@5A401``8
014F4P0<4@d04AHB00hC3`80314=0P0=4Ph05P0>4`l03A8>00dB3P0?51004AHD00/?6@0D62D03a<O
018F8@0A5Ah03Q4G014D600:3Q003@h?018D4`0?4@h03Pl=01DI5@0X;BT0?D8n014F4P0=4Ph300hC
3`804AHB00H02@h:00hC3`0B5QD04ADD00lC4P0=4A0200lC4P0400dA400>4Q403a<B00lC4P<041@C
00/03Q8A010D4`0C5aH051PG00lC4P0:3Pd04aLF00lC4P0@51<02Ph=014E500Dooooo`006oooool0
100D51H01`L901PH6P0;2`d200T92`0I00h>400@418010@600/;3@0?3a4051@F010A5@0720`0QhR<
03Pi?@082@d03PlC01<D600;310020T=00X;3`061`/05QLL00h>5P061Ph04A4I010@600>3QH02@TA
00l?5`0200d=5`0d00h>600<31H02PXB01<C6`0>3QH04A4I00d=5@1:BU80W9bT00h>5P0K724051DJ
00`=4P0I6Ql010D:00`=4P092A4020PB00/;5`0d<d40ZjZh02TX=P0D520071`X00h>5`0J6R803`lI
01<B800B4Al03PhK018B7P0C4ad04Q8J01<D6@0D5AX05AHJ018C5`0?41@03Q4C00H:2`0F6Q/09b//
01<G600?4a@051PI010D5@0E6AX0310A01<G600@51D0310B014E60804aLJ0P0E6A`01`0B5QT041@G
00hB5@0D61/05a/N01<G6P0?4aH00P0E6A`05`0=4A@0310C01@H6`0>4QD03A4D01<G6P0F6Qd04QHI
014E600D5a`07B0U00lB5`0J7B803a8G01@G700?4QL041<H01DH7@0I724061/P01@G700H7B406AhR
00806QlS00D061dQ01HK7`0E6Qh04QLK01LL800202DZ;P0W01LL800M8RD03Q<F01@I700;41<04QLJ
01@I700A5QT02a0C01XO8P0H7B005a`O01PM8@0>4aT061`U00hB6`0@51d03a<L01HJ8`0J7RL04aLP
010D7@0C5b0051PQ00lD6P0@4aX04aHK018E6P0?4QL041<I01@G7P0@4a`051LP014D7@0B52005QPT
01<F7`0=41D04ADH00803A4D00<051PK010D5`0A5AP01@0A5AP01@0B5AX051LL01<F6`0A51T04QDJ
00804aHK0P0@4aP07`0A51T051LL01HI7P0G6R806QdV01LJ8`0B5A`04aHK01DH7@0?4aD04ADF00/?
3P0>4Q004AHB00`A2`0A5Q003A8>018G4`0C5aH041@E014E600`<cP03a8I010C7@0:31P00@<@01@F
7@0C51H051@F01HC5P0G4QH00P0I4aL03`0G4AD05Q4E01<A500?3a404a@F01/M8`0I6bL04Q@P00P:
5@0?4Q/04aHO00d@600L7bH000<801@G700200P;400H01@G700@4aP03Q4F00dA5@0>4QD041@G010D
5P0=4A802`l@00/?3P0<40l041@C00T=300830/04ADD00X>3@0J7Qd01`/:00`@3`0@51<02`l>00lC
4P052@P06alN0P0:4100300;4A403A<C00hD500A5aL010X:01/Q8@0220P07bDU01<I6@0>51@020h<
00X@3P<03A<A05D03aDC00`B400=4a403Q@B010F500A5aD04QPF010F4P0:40`05adI01dS7`0C6AD0
3Q@@018H500?5A40318>00/A3@0:4@/0214<00/D3`0<5Q803QLD00dC4@0I7Qd0=CTj00D:3@0?5aT0
3APJ00@?4@0:6AT06RT/02Hd=`1`O8804A`R018M8`0<5Q/01a0E01XR9@0>5AL000L901LL7`0@5AL0
20h>00P<2`0C61@01``800hC3`0E6QH00@H200lD400@5A40314=00dB3P0?51003Q<?00dA400830/0
2@d<00lC4P0@51<03a<B00X=300A5A@06AdL00dA400830/03A4@00X?2`0=4Ph041DA00P=2@0B5a<0
5AXF00lD400<4@d02a0<00`A3@0>4`l03a@@00`A2`1;D4X00PL101`Q6`000P003A8<00<02a0:00`0
314;00hC3@0<4@`03A8>00lD400=4Ph02a0<014F4P0I7QX03Q<?00L<200=4Ph200`A3@0700`A300S
:2801``600P=1`0B5a403a@>010E3`03014F400500hC3@0=4P`0314;00`A2P0;40T00P093PL0200;
40T0314:00/@2@0@5@h03A8;00hC30042@80314;0P0;40X01P0>4`d04AH@01<H4P0@5@l03A8<00/@
2P80314;0P0;40X01@093PP03A8<014F400>4`d02a0:0080314;02@02Pl9014F400:3`T041D?00H;
1@083@L041D?00L<1P0>4`d02@h800/@2P0=4P`03a@>00/@2P0=4P`04aPB00P:2@0A4a004QD>01LJ
4@0^<R<0PhMf0?7fhP3ZkMX0B4dg02hc7`0A5PD051P700H9000m@3T0RHb501lR6`0=40T05APA00X=
1P0<3`P200lB2`0300d@2@0;3PL030h900804aD@0P0>40/00`0C5A00418=00lA300400d?2P0]00`>
2@0=3`X0418=00d?2P0>40/051HA00/=200A4`h06Q`G01LI500@4Pd04aD@010E4@0A5Q80314=0046
0P0E6QH04AHB00`A3@0:3`/02a0<010E4@0?5100314=00D;2@0>51@02Q0@00hC5P0@5AT01``?01<H
6P0?5A<0318>014G4P0010004AP@00X?2P0=4Ph03a@@00dB3P0<4@d02@h:00dB3P093PX02Pl;0080
4AHB02L03a<A00lC4P0@51<02@d<00`@3`0>4Q403A4@00/?3P0A5A@05a/J00T=300830/02`l>00dA
400D61L020`;00dA400D61L03a<B00P<2`0I7A`01PT801PL6`000@003Q8@01HK5`0C61@04AHB0002
000H7AT02Pl;00/@300<4@d051TE01TN6P0@5A4051TC00dB30093PP00P0=4P`0800>4`d020d7010E
3`0?50h0314;00T>200C61803Q<=00/@2P0:3`T0314;00X?2@0C61803A8<00T>200;40X0314;00T>
200>4`d0IFYT030e;`042@<020d700lD3P0:3`T020d700lD3P0730H03Q<=00dB30093PP03Q<=0P0;
40X04@0>4`d03a@>00`A2`083@L02@h800`A2`0>4`d04AH@018G40062`@02`l901HL4P0=4P/03a@=
00/@2@0=4P`03a@?00803a@@00`03A8>00D:1P0=4P`02@h800X?2@0?50h03Q<=00H;1@0@5@l03a@>
00hC3@0=4P`200hC3@0Y01DJ500N8ad0724K00X?2@0@5@l01``600hC3@0M8Q`000<0010E3`042@<0
4aPB00L;200Q9R8010T500lD400B514061XG01LI5P0@40h03`l=01dM6`0;2`T03`l=00/=200>40/0
2P`700`>2@092`H03a4<01/M600C5A004Q@?00T;1P0;3@P04AH@00T@2@0<4@/020d701@I4`0@4Pd0
0P0B50l03P0?40/03Pl:010A300>3`X04A<>00lD3P0320803a@>00@90`0V:bD04AH@02db;00W;2H0
2a0:0P0?50h04P093PT04AHB00hC3`0;40`05Q/G01dR7P0I7QX03Q<?00X?2`0=4Ph02Pl;00T>2P0=
4Ph04QLC01DJ5P0?5100314=00hC3`803A8>0`0@5A404P0@5A<02`lJ00lE8`0A5b<03A4L00T=5P0D
61l020/@00T=400;3`l03Q0?010B3`0A4a0041DA01XO6`0K81`03A8>00X?2`803a@@00T04QLC01LL
600=4Ph02Pl;010E4@0;3`h0310?00dA400>4Q400P0@51<01`0B5QD0310?00`@3`0B5QD05ATH010D
4`0<40l00P0?4a801@0E6AP082@S01lS8P0?4a803Q8A00803A4@00<03Q8A00lC4_ooool04oooool0
01_ooooo00P04Q8D00@41P0410H00P8401<C5@061PP020P:018B50803Ph@01802PX<00`<3P010PH0
5AHJ07enPP13A4P051DI00011@0:2`l020T=01<D600I6Qh01`P<00X;3`0=3Q<01PH>00d>4`0e=Cd2
00l?5`0g00d=5@0<31H02`/E00h>600C4ad05QHP00/;500A4A/02PXB00h>5P0J6R805QHN00d=5@0E
5Q/02``A00<42@0B4aP0414F00d>4`061``03@dE00l?6P0L72P0IfMc01`L:@0@41`06QXT00h>5@0G
61d03PlG01<C7`0B4Al03PhJ018B700C4ad03`lH00h>5P0A4QL04a@I01<D600A4QH04A<G00L;300>
4QD051PJ00/?400?4aH03a<E00/?400>4QD03Q8D01DI6P0D61/041@G00lC5P02014E60805ATL0P0D
61/01@0B5QT051PK01@H6`0A5AP041@G008051PK0P0>4QD03@0C5aX05ATL018F6@0D61/05ATL018F
6@0C5aX00005024T:@0?4QL05APM01dP9@0=3a@00P0B5AX01P0E61d061/P01PK800E61d04aPL01@I
7@805a`P02405Q/O01@I7@0?51P03a@H01DJ7P0L8BD06b0T01<H700<4A@020d@01@I700P9BP0724T
00L<3`0H7B005a`O01HK7P0>4aH05AXM014F6P0G72806alX00lC700B5Ql041@M018F7`0R9Rl06AdV
01<G800D62404ADN00/@5P0?4QL00P0B5AX01@0@4aP04QDK01HI800@4aX04aHO008041<L00@051HR
014D7@0@4aP04aLJ0P0>4QD01P0D61/04QHI00lC5P0?4aH041@G014E60804QHI00<04A@I01<F6`0B
5AX00P0A51T0100C5Q/041<H010C600A51T2018E6P0;014D6@0C5Qh04aHO018E700?4QP03a8G010D
5`0=4A804QHE014E500A5Q800P0C6180900@5A002a0<014E500C5aL03A4D00`@4`0<3aD041<L01@G
8@0F62@03a4N01XL8P0D5AL051@F01@C5P0J5AT07APL02XT:00R7B404`hB01<B5@0F5aT04Q<E00X<
4P0:31P04Q@P01/N9`0I72D04A@M00lB6@0;3Q<07B0U04Y=DP0K7R<05aXO00`?50803a8G01D03a<G
00lC5P0?4aH05a/M01`P8@0H71d041@D00/?3P0:3Pd061`K00L;2P0>4Q403a<B01@H5`0B5QD01PX9
00/?3P0>4Q404aLF00L;2P0B5QD00P0>51@300dC4`0900lE5@032@T03aDE01@J6P000P800`T900dB
4P0:40h02a4?0080318@00@03A<A00hD4P0=4a403A<A100>5180500G7A/0318?00@:1P0;4@d04QPD
00X@300>51003A<?00`B3P0>5@h051/D01LQ6@0:4`h02A<?00`E4P0<4Q005Q/K02``<@0D6A`02A4D
0P084aD060075AP0;C`o071mP`1BGfD03Q/Q02Td>P0@6R00628T08N?TP1BFU`04QXL01<H6`0>51@0
4QPF01<H500=4Ph02Pl;00H;1`052PH03A8>00hC3`0B5a<03Q<?00/@30803A8>00<03a<B00`@3`0<
40l00P0?4a802@0>4Q404ADD00lC4P0=4A003a<B00/?3P0<40l0314=00D:1P0200`A3@0300dB3P06
2`L03Q<?00<0314=0P0>4`l0400<4@/020d70002000B5a408BHP014F400=4P`0314;00dB300>4`d0
3a@>00`A300<4@d03a@@00`A3@0:3`/200hC3`0<00T>2P0730P02@h:00lD400;40`020d80005000A
5Q003A8<018G4@0D6A<03Q<=0P0:3`T05`0;40X02Pl900T>20093PP0314:00dB2`0<4@X02Pl800/@
2@0?50d04aPA010E3P0010003A8;01<H4@0?50h03A8<00/@2P0:3`T02a0:00`A2`0@5@l03Q<=0080
314;00D03A8<00`A2`0:3`T0314;00dB300300X?2@0>00L<1P0>4`d020d700X?2@0=4P`010T300lD
3P0N8ad0;S<]01LL5P042@<04aPB00P=1`0:3`T200lD3P0E00dB300<4@/030h;018D400@4``05QT@
01lS501CEdH0/[JU0;BiY@0h?BT03A8001DI200>4P<02`h501/N5`1FFE8061/D010C30072P<03a8;
008041<<00H03a8;00hA2P0<3`P03Q0;00d?2P0>40/2010B3@0300d?2P0@4Pd03a4<00<03@l:01H0
3Q0;00lA300?4@`0418=00`>2@0=3`X04Q@?00h@2`0@4Pd05QPC018D3`0=3`X0418=01DJ5P021`<0
82DQ01<H500=4Ph00`P400`A3@093PX02Pl;0P0=4Ph03P0;40`05adK00@:2P0@5QH03Q<F00T>4P0E
6Qh04AHI03To?`0d>SP04QTC01dT700;4P/0314=0P0>4`l03@0<4@d02Pl;01@I5@0:3`/03Q<?018G
4`0E6QH092TU01<H5@0>4Q403a<B00T=300<40l00P0=4A006@0:3Pd03A4@01@H5`0:3Pd020`;00`@
3`000`802`l>01<G5P0;3`h0310?00D81`0F6QT00040014E500010<06QhM00lD4@0<4@d051TE00T>
2P0E6QH02Pl;00P=2@0;40`00P0:3`/0400>4`l0314=00X?2@062`D02@h800hC3@0;40X02@h800L<
1P0:3`T010T3014F40001@004QLA00lD3P0<4@/200/@2P0M00L<1P0>4`d06b0J00/@2P0:3`T041D?
00@90`0;40X06AhH00T>200@5@l04QLA00hC3@0<4@/02Pl9010E3`083@L03a@>00hC3@0;40X03A8<
00`A2`0=4P`041D?018G4@0?50h03Q<=00dB300;40X00P0:3`T04`0:3`P010T201HL4P0010003A8;
00/@2@0@5@h0724K01<H4`1CF5@0DUMC00dB3P0?51003a@>00X?2@083@L02a0:00dB300:3`T0100;
40X200X?2@0700@9100=4P`0314;00X?2@0D6A<02a0:00L<1P02010E3`0:00hC3@062`D010T300P>
2P093PX03A8>01HK5`0Z;2T04Q@A01@F4`804A4?01P05aLE00l?3@0?3`d04A<>01<E400?4@`04Q@?
01HH4`0>40/0418=00H80`0D5Q406adH01<E400=4P`01@`501<H4P0=4P`04aPB00h@2`0C5A006Q`G
01<D3`0A4Pd201DF4@0>01@F4@0=4P`01@X401PM5`0T:B<0FEiH02ld;P0O91h0724K00/@2P0?50h0
4AH@00P=200;40`200dB3P804QLC00<03Q<?00lD400@5A400P0@5A401`0A5Q803a@@010E4@0C61@0
3A8>00/@300>4`l00P0<4@d0500>4`l03a@@00lD400>4a405A`T0088500=51l000<>00D94P073140
51PK01<G600B5QH04A<B010B3`0?4@h03Q<?01@I5@0C61@0314=0P0=4Ph01P0<4@d041DA01DJ5P0G
71P03A8>00hC3`80310?00X03Q8A00lC4P0@51<041@C00hB4@0@51<03Q8A00`@3`093@`020`;0P0A
5A@01P0:3Pd02`l>01XN7@0R9RD03A4@00`@3`802`l>00<0310?00dA4?ooool04oooool001_ooooo
020020L<014@5@0920d01`H;01TH7@0<2a0061LL00`;400:2@h030/@00h=4P0@3a@030d?00l@4P0C
51H01@H800X;3@0;30h03PlA00X;3@0D5AL08b@V00h?4@0<3A002``?018C5P0L7B00?3e100X;3`0;
31403a0E00l?5`8030`D01d05QHP01dM9`0D51l03`lK010@6`0=3AL071`V00/;5@0>3QH02@X?00`=
4P0F5a`02@X?00h?500<3A0051DI01@D6`0=3AD0<30i05eMIP0<31H03@dF01LG7P0=3A<04Q<F00h?
500B4Q/04Q8L00h>5`02018B6`0C010@600?3aL04A8G018C600A4QL0414F018D6@0C5a/05aXO018E
6P0B5QX05aXO00lC5`0G6Qh041<H01@H700?4aL03a8G01<G6`0201<G6005010D5@0B5QL04ADF00hB
4`0@51D0100A5AH0100D61X051PK014E600A5AP2018F6@0?01HJ7@0C5aX04QHI01<G6P0?4aH04QHI
01DH7@0G6Ql041<H01dP9@0<3a@05aXO01HI7P0D5a`04aHK00<05APM00P04aPL01@I7@0F6al05Q/O
01DJ7P0C61`041DI014F6P8051TM0P0B5a/03`0B5a`06QlT01DJ7`0F6b00314F028W;00B5a`051TN
01<H7@0@5AX0724V01<H7@0D6Al05a`R00`A5`02018G7@0:01<H7P0E6R004QLM018G7@0D6Al05Q/Q
01<H7@0C5a/051PJ018F6@8041@G0P0A51T02@0C5Q`03a8I00lB6@0B5Ad03Q4H01@H6`0C5aP03Q8C
00lC500201@H6@07014E5P0B5QL04QHG01@H6@0E6AX05ATL010C6002014D6@0500lB5`0@4aP04A@I
00lB5`0A51T00P0B5AX0:@0@4aP03a8G01<D6P0@41P0414G018C6@0@4AH03PlC00l@4P0>40l04aDD
018D4@0@4Pl04aDC00lC4P0>4Q804QHH014E5`0?4QH04QDJ00hA600G6R<03A0I00`?60082QD04aLL
010D5@0?4A<04A4C01DD5`0J5aX091lS01lK7`0D4aD0414C010C500E61T0:bhc02HY<@0E62004A@K
00802@`B00`04QDJ00/>4P0E6Ad09BT/00hB500B5QT030lD00hA600@4aP04A@I010C600>4QD2010D
5`0<00lC500=4A80310A00`@3`0:3Pd0310?010D4`0?4a8061`K00hB4@0?4a80310?0P0@51<01P0;
3`h041@C01<H6P0B5aX041DH00hC5P803A8E00P02PlB01LL7`093Q4051TL00P=400<4A<03Q@C00dC
4@80318@00@03A<A00hD4P0>51803Q@B100=4a40<`0:40l04QPH00`B4@0>4Q4041HD00X@3P0=4a00
2a4=00X@300=50d05A`E01TS6`0@6A@02aD?00XC3P0=4a403a@D01@H6P093Q403ADI018M8@0@6b00
8S0e08fLX@3ao_l0/L3402@c>00H9B/07RX^00TE5P0C7Ah03ADE00H>300C6AP03A8@00D:1`0E6QH0
4AHB00hC3`0W;2P05a`H014F4P0=4Ph04QLC00lD400@5A403a@@00/@300>4Q<041@E00lC500200dA
4P803a<D00P0310A00<61`0C5aP041@E00lC4P0C61@06AhJ01dR7P803a@@00<03A8>00hC3`0=4Ph0
0`0=4Ph02@0>4`l0314=01HK5`0D6AD02a0<00P=2@0=4Ph03Q<?00dB3P0200hC3`0F00lD400=4Ph0
3A8>010E4@0>4`l02Pl;00/@300<4@d03a@@00dB3P0;40`051TE01<H500A5Q400`L301`Q6`0>4`d0
2@h800lD3P0<4@/03A8<00hC3@<03a@>00@0314;00dB2`0?50d03a@=0P0<4@X01P0?50d00@H001/P
6@0730D02a0:00lD3@803A8<0P0<4@/01P0=4P`041D?00lD3P0=4P`02a0:00`A2`803A8<00@01``6
00lD3P0=4P`02@h80P0?50h0300A5Q002@h800X?2@0>4`d03A8<00`A2`0730H07B8L02H[9@0:3`T0
3a@>00dB30803a@>01P03A8<00/@2P0A5Q0061dG00d?300A4`l03a8;01@G3P0C5`T05a/;01lS4`0d
>2P08RHF00dA1`0>4PH03A4401@G3`0;3PL071lH018E3P0@4``030l800lB2`0>4@X200d@2@0:010C
300A50d04aD@00`>2@0=3`X05ALB01HH4`0<3PT0418=00lA30803@l:00L03Q0;00lA300B50l0418=
014C3P0>40/03@l:00804Q@?100=3`X02P0?4@`0@DI204=8A00420@04AHB00460P0E6QH03Q<?00X?
2`093PX300/@300:01XP7P0A5aL04QPI07f2QP1[L7@04AHJ00hC5P0=4Q@04QPF00hD40803QD>02l0
3Q8@00lC4P0>4Q402`l>00X>3@0830/020X9014E500K7ah04QHE00dA40093@`0310?00dA400:3Pd0
2`l>00`@3`0?4a802`l>00T=300?4a80310?00X>3@0<41004aLH00/?400>4A804ADF00X>3`0>4Q<0
41@E01dQ8P0=4A803a<D00/?400A51800PL300dB3P0?5100DUMC01<H500=4Ph04AHB00lD40093PX0
314=00dB3P0200`A3@0R01@I5@0H7AT04QLC00dB3P0>4`l03a@@00dB3P0=40d03a@@00`A3@0:3`/0
2a0<00`A3@0>4`l03A8>01<H50082`P0724M00`A3@0;40`0;C8^030d<@0=4P`01@X500dB30093PP0
1P/500lD3P083@L03A8<00P=1`0?50h0314;00/@2P803A8<00L03Q<=010E3`0B5a404QLA01<H4P0@
5@l03A8<0080314;0P0=4P/03@0A5Ph05Q`B010E3P0;40X02`h:01<H4P0?50l04AHB018G4`0?5100
314=00hC3@0<4@/00P093PP0100<4@/03a@>00/@2P0>4`d2010E3`0W00hC3@0=4P`03a@>010E3`07
30H03Q<=00X?2@0520@03Q8=00T>200G71H01``700`A2`0A5Q002Q0<00lD40093PX02a0<01@F4`0A
4a003Q0=018B400D51803@d;01DE4`0?3`d030h900h@2`1>D4/0;c4/00/=200@4Pd03@l;01DG4P08
2PD04A<>00h@2`0_=2h06R4J00803Q<=00h01``600H80`0?4@`03Q0;00d>2@0A4Pd0414<00X;1P0=
3`X03Q<=00/@2P0?50h010T301lT7P<041D?00@03Q<=00`A2`0<4@/03Q<>0P0@5A402P0>4`l03a@@
00lD40093PX04aPD01PM6@0?510041DA00lD400;40`200lD40802a0<00<041DA00`A3@0=4Ph00`0>
4`l0300=4Q0020`A00XC6@0=4aP05QhS00hE6P0<4A<05A/L01@J6P0C5aL041@C00hB4@803A8>00@0
41DA00lD400?51004AHB0P0>4`l01`0?510020d9020U8@0=4Ph04AHB00dA400>4Q400P0?4a82010D
4`0800hB4@0C5aH041@C00dA400H71/0:Rh]00`A3@0?510200/@3004018G4`0F6aL03a@@00hC3`80
3A8>00<03Q<?00lD4?ooool04oooool001_ooooo03`05aHK00L62`0510T03`hC00/:3`0510T010<8
00`;400K6Ql02PT>00/:3`0N7B8020T;010A4`0720X051DG00/<3P0720X03@h@00P92`051PP03PlA
00T:300>3a405ALF00T;2P0C5A@01`L901LH6P0@4AD02``@010A5P0>3a@02``A014A6@0F5R001`LD
00/:60071a<0=SI2061PJP0Z:S@03PhF00h?500J6b008b@Y00P93@0?41@051HE00X<2`0<3@l0414E
01TJ7`0@4AH03@dD00l@5@0B4aL030h>00lA400?4A82014B5`0400l@5@0A4QL04A8G014B5`804a@I
01L04a<J014A6@0@41P03a0H01<F7@0K7RD04aHM01DH7`0G6R402`hE01PK8P0;3QD041<J00L:4@0@
4aX02PdA00dA4P0?4a@04ADF01TM7P0L82405ATJ010D5@03018F5`0A01@H6@0F6Q`04aLJ00lC5P0B
5QT051PK014E600?4aH03A4D018F6@0E6A`04ADH010D5`0H6b0061/R02T/<`0T9bh00P0C5Qd01P0F
6B004aHM010C6P0A51/04QDL01<F7@<05Q/O010051TM018G6`0?51P05a`P01@I7@0A5QX051TM01HK
7`0B5a`08bL`01PL9@0@51d06alX00lC701@E5d0=SY30`0E6B802P0B5Ql041@M00hC6@0H7B404AHJ
01DJ7P0F6al0724U01HK7`0D6Ad2018G6`04010E6@0=4QH04ADF010D50803Q8C00@03a<D00lC5P0B
5QT051PK0P0@4aP01`0B5AX03Q4F01<G6P0@51D03a<D00hB4`0@51D01@0C5aP01@0B5QL04QHI00hA
5`0@4aX03a8I00803Q4H010041<J01<F7@0A51/041<J014D6`0B5A`04aHK01@E6@0@4AH04A8F01DF
6P0B4aL03a0B01DF600;3@`03Q0?0P0C5A@03@0D5QD03a<F01HJ7@0E61d030lD01LJ7`0V:Bh092L^
00X=500@4aX061/R01TL8`0N8RL00P0<4Q807`0?4A<0410B00l?4@0<2`d03`lA01HF600@4a@020h>
01DK6`2<T9@0TIBI02/^<`082a0041@G014E600@51L06QhO014E5P093@h04QHE00L;300?4aH03A0G
014D6`0C5Q`04A@I00d@5@0>4QH041@G00lC5P0>4Q@00P0=4A80;00<40l051PG00P<2`0420L03Q8A
00dA400A5A@01`/:010D4`0830/02@d<00X>3@0@5AP03QHH00dE5`0<51H03ADG00hF600G7b400@T;
00dE5`0@61X0210B01DM7P0@5QH03Q@B00`B400>51803aDC00dC4@0<4Q003A<A00hD4P0?5A<041HD
014G5P0C61/010T<00lD5`0G71l04QPH01@J600=4a403A<@0P0<4Ph0>00;4P`02A<;014J5@0;5A00
2Q<>00lE4`0@5A@02@d@00hC5`063Q801Q4G01<M9P0R<3L0D5mV0;C6bP1]Oh<062X^018Q900=71h0
00`<010J6`0740h010d800/A3@0F71H06AhJ00X?2`0A5Q802Pl;02T^:P0G71P020d900hC3`0;40`0
3A8>01XO6`0F6aL02a0<00/?400>4Q<03A4B00/?400=4A8041@E00/?400D61T05ATJ018F5`093@h0
3Q8A00`A3P0L8Ad07R<O00T>2P0<4@d041DA1P0=4Ph01@0;40`000D1010E4@021P<09BXV00803A8>
100<4@d04`0=4Ph03a@@010E4@0@5A40314=00/@300?51002@h:00X?2`0E6QH02a0<00P=2@093PT0
<CH`00@90`021`400@H000/@2P0=4P`00`0>4`d00`0;40X02Pl900/@2P0200hC300C00`A2P0;40T0
3A8;00T>1`0H7AH0I6UR02/`:@0H7AH01P/500L<1P093PP0314;00dB300?50h05Q/E00`A2`0:3`T0
20d700X?2@0200/@2P0500T>200=4P`02a0:00hC3@0D6A<00P0=4P`08P062`D041D?00/@2P0>4`d0
3a@>00/@2P0:3`T0314;00<80P0I7QP020d700X?2@0@5@l04aPB010E3`0P9Al0>3dg00`>2`0>40`0
3A0900`?1P0D60/03Q8401/O4@0@50P020/000@7000B5@d010L000X=1P0B5@h02@`5018E3P0930D2
01<F3`08014D3@0=40T03A09010C300B5@h04A<>00lA300@4Pd201<E4003010B3@0?4@`03Q0;0080
3@l:0P0?4@`00`0@4Pd03@l:010B3@02010B3@0401<E400M7aX04A<>00/=20802P`701`02@/600L;
200B5a<04AHB00X?2`0L8Ad03A8>00lD400=4Ph0314=00/@300<4@d03A8>00TA3`0:4Q@00`/=0459
C00_=S`02Q4G010H6`0;4aD051dJ00T?300230@02Q4:00`@3P0<40l03A4@0P0<40l0200=4A006QhM
01<G5P072`X03a<B010D4`0>4Q402Ph=0P0;3`h06@0:3Pd0310?014E500<40l02@d<00hB4@0?4a80
3Q8A00X>3P0=4A802@d>018F5`0;3a000@D601LK700B5QL00042014E5P000@803a<D010D4`0;40`0
51TE00T>2P0>4`l00P0:3`/200/@300500lD400B5a<02Pl;00hC3`0=4Ph00P0@5A402`0:3`/02@h:
00L<20052PH041DA00D:1P1JGe/05AXF00`A3@0?51002a0<00801``801802Pl;01TN6P0E6QH02Pl;
00<810000P003a8?010E3`0730H03Q<=010E3`0A5Q00314;00T>200;40X02@h8014F400<4@/200dB
30803Q<=0`0=4P`200lD3P803Q<=01404AH@018G400?50d06QlH01@J40083@H061dF01<H4@0@5@l0
2Pl:01HK5`0G71P0314=00lD400:3`T03A8<00hC3@0200`A2`0600dB30083@L02a0:00hC3@0=4P`0
2Pl90P093PP0=@0=4P`00PL1014F400320804AH@00dB30011P0000<001dR700;40X05a`F00/A3@0C
61@0314=01@I5@082PL04A<@00/=2P0B4Q005ADC00P81P0E5A<03`l=01@F4@0=3`X06adH01@F4@0Q
8ah01`T4014C3P0F61<020X501@F4@031@0082DO00T@2@0D6A<02a0:01HK5@0E5a80418=01DG4P0:
2`H03@h9014B3@0B4`h061XE00lD3P083@L03Q<=00lD3P0M8Q`05Q/E0080314;00D04AH@00X?2@08
3@L03A8=00dB3P0300`A3@0@00dB3P0<4@d06QlK020U8@0D6AD05AXF01<H500=4Ph03a@@00hC3`0<
4@d03A8>014F4P0>4`l03a@@010E4@803a@@00L03Q<@01`U900B71d05b4R00H>40084A0051dK00<0
3Q@B0`0>4Q403@0<4@d04QLC01<H500<4@d03A8>00hC3`0730P03A8>01LL600m@Sh0724M00dB3P0>
4Q400`0?4a82010D4`0<01@H5`0A5A@0310?00X>3@0B5QD06alN00T>2P0;40`0314=010E4@0C61@0
2a0<0P0@5A4200lD408041DA5?ooool001_ooooo03H040lD01@C600I61d04a8G00L62`0a<3D0=3<h
00T83@0@3a@030/@01PG700O7R<051DG00X;3@00008010D700H72@0C51H02P/=00l@4P0;30h03@h@
00L82P0>40l01PL500H81@0L7Qd03@l>01LH6P0000801`P<00d>4`0>3a@03@hC010@600B4Q`03PhK
00l>70081aD03PhJ01TI8`0000T03PhF01XK800L7B804A8G00/<400K71h03Q0>01DG5P0C5A@01`P;
00`=4P092Pl2010A5@0400l@4P0>40h03Q0=00lA40804A8D00@03a0B014B5P0A4QH03a0E0P0A4QL0
400C4aX04a<K01@D700C5A`04QDL01HI800>4AP04A@K01LJ8@0C5Qd07b8Y010C6P0B5A`03Q4H02<V
;@0<41@201@H6@07018F5`0F6Q/05a/L01PL7@0I7Ah05a/L01HJ6`0201@H6@0I01HJ700C5aX03a<F
018F6@0C5aX04ADH00lC5P0>4QD05ATL01PL7`0D61/04aLJ00L:4@082a80FUeT06IYL00]<3L01PP?
01DH7`0B5A`041<J018E700C5Qd051LN01<H700201@I7@0L018G6`0@5AT03A8F01LL800C61`041DI
01@I7@0F6al04QLL00P<5@093AP051PS00X>6@0[;cX0]KW404I:E@0E6B@04aLR018F8@0@51l06AdV
00`A5@0E6Qh03a@G01DJ7P0D6Ad051TL01@I7@805AXM00L051TM01<H6`0A5QT03A4@00`@3`0=4A00
41@C00804aLH00`04ADH01@H6`0@51L041<H01<F6`0?4aH04QHG00lC500A5AH041@E00hB4`0A5AH5
010D5@13010D5`0?4QP041<J010C6P0>4AP03a8I010C6P0E61l04QDL010C6P0A51/04aHM01@G700A
4QD03a0D010A5@0A4QH0414C00l@4P0@4A<03Q0?00X<2`0>40l051HE018C5@0@4aP061/R01HI7P0;
3Q@061/P02T/<@0c=Sd041<J01DH7`0?4QT01@P?018H6`0<5A@03aDE010E5P0@4A<03`lA010@4P0?
41804A8D018G5`0=5QD041TH03@k?00Z;C802PdB010D5`0A5AP02@d@018F5`052@X02@d>010D4`0?
4a800`L600/?4P0>4AP041<J018E6`0@4aP03Q4F00hB5P02010D5`0L00lC5@0>4Q<03Q8C00hB4@09
3@`05ATH028V9@0830/01@T8010D4`0830/07b<R018F5@0A5A@02Pl?00hC5P0<51H02a<E00`D5P0=
5AL03aLI014I6`0X<3804a/M00`D5P022P`01Ph@00hD5080318@00<041HD014G5@0=4a400P0<4Q00
300>518041HD014G5@0B61L0OX>602T^<P052Ph02PlC00D:3@0;4A40318B00hD4P803aDA03P03A@>
00TC2`0:4`h02A<>00XC3P0B61H05Q/L00hB5@0=4QH041LN01DP9P0@6R<03adU00`M900W>Cd08C<g
01<U9`0=71l000d=01<Q8@0=5aH03QPC01@N5P0B6A803aD>00H;1@0C61@04QLC00lD400=4Ph00`P4
014F4P0?51002@h:00`A3@0J7a/061dI00dA400>4Q<03A4B00`@4@0;3a003Q8C010D5@0<41402@d>
01DI6P0=4A802@d>01DI6P0>4Q00314=01<H500?51003Q<?00P=2@803A8>0P0>4`l0100=4Ph0314=
00lD400B5a<200lD400401TN6P0<4@d03A8>00`A3@<02a0<01<03Q<?00lD400?51003a@@00hC3`0=
4Ph04AHB00dB3P0E6QH0:2dY018G4`0:3`/07B8M06mdKP0P9Al061dG00dB300B5a403a@>00803Q<=
00H03A8<00X?2@083@L02a0900hC300=4P/200X?200A00dB2`0;40T03Q<<01XO60000P004AH?00`A
2P083@L02a0:00`A2`093PP02Pl9014F400;40X02Pl900T>200:3`T00P0<4@/00`0=4P`0314;00/@
2P0200dB300S00X?2@001@001P/501<H4P0<4@/08RLQ01TN600E6Q@020d7010E3`0?50h02@h800/@
2P0730H03a@>01HK5@0>4`d041D?01`Q6`0?4@h03A0:00d@2@0520004A@:014E1`0G6`d04aH;01@G
3P0>4@X0CU1;01/M600930D04A@=00@7000K7QL00P0@4``01`0K7QL05aXC014D3@0?4P/03Q4:00lB
2`0<3PT00P0?4@`00`0>40/03@l:00h@2`0200h@2`803@l:01403a4<010B3@0?4@`02`d800lA300A
4`h0418=01<E400A4`h02`d800T;1P0B50l05aTD01DG4P0G71P010T501PM6@0200hC3`0C00P=2@0>
4`l03a@@00hC3`0=4Ph0314=00dC3`0<51<04QXL00`D5P0@61/010/A014H7P0;4A@01@d?01/T8@0@
6AD0D5YB00`F3P0200/?3P0600`@3`0=4A003A4@00/?3P0420L051PG0P0@51<02`0E6AP01PP700X>
3@0;3`h03A4@00X>3@0<40l041@C00dA400;3`h03A4@00803a<B01805ATI00041@0B5QL0?D5201`P
8@0<41401`T:01TM7P0P92D04ADF02HZ:`0F6Q/07b<S01@I5@062`L04aPD014F4P0>4`l300/@3004
01<H500G71P0314=00lD4080314=00l02Pl;00H;1`0:3`/082DQ00T>2P0;40`05Q/G07^0O00D6AD0
2Pl;00hC3`0;40`0314=014F4P0H7AT00`0=4Ph01P0<4@d020d901PM6@083@L01P/5010E3`8020d7
00d03Q<=00`A2`0<4@/0314;01DJ500>4`d04AH@00hC3@0?50h03Q<=00`A2`0;40X0314;00<03A8<
0P0<4@/02@0<4@X0J6eV07QnM00?5@/0314:00T>20001@008RLQ00/@2`0200`A3@0400L;1`0G71P0
2a0:00dB30803Q<=00<03A8<00/@2P0<4@/00`0>4`d0400;40X02Pl9018G4@0E6Q@01P/500X?2@00
0P0092TS00dB300D6A<082DO05MLEP0?50h0008004aBCP0320@200P=2@0301@F4`041P<03Q0=0080
4a<A00T030`:014A3`0@40h04A<>00D70P0L7QT03a4<00h@2`0<3PT00P0@4Pd01P0:30L01@H301<E
4024RH<09B`U00D:108041D?0P0@4Pd07P0=3`X030d801XK5P0D5A002P/6018D3`0?50h02Pl900dB
30093PP01P/500/@2P0<4@/02a0:010E3`0>4`d0314;00`A300;40`041DA01HK5`0A5Q80314=00/@
300C61@061dI018G4`0D6AD04aPD010E4@803a@@0P0>4`l200lD40<041DA00T03a@@00hC3`002@H0
3aXF09bWX`0j@d006B8O004:1`0A5aD00P0@5Q@01P0?4a803Q8A00dA40093PX041DA014F4P802Pl;
00L0314=00lD400<4@d03A8>02P]:@0B5a<041DA00803a<B100@51<0300;3`h03A4@00lC4P0?4a80
2Ph=00D9200@5A403Q<?00T>2P0<4@d04aPD014F4P803Q<?0P0=4Ph200hC3aCooooo000Kooooo`0O
00`;4@0;2Q001`H<00/;400@3aD0BTU?04I5B`0=3A804A0F00L62`0<2a002`X?00P9300>3a405aPJ
00d>4@0?41801`P:00X;3P0A4Q@030d?010A500:2`h03@l?00lA3P041@<02@/800`>300B51<03a4@
00l@4P0200d>4@0E00d>4P0<3A402`/B00`<6@0;2QH03PhJ00d=5`082140418J010@600E5Q/05QLL
00d>4`0D5AT03PlB010A40082PX02P/<018C5P0?41@0414E00803@hB00X02``>014C4@0;3@X030h;
010B400A4a403a4@014C4`0@4A<03a0C0P0A4QL0<@0@4AL04A4H014A6P0B4a`03A0H014D700@4a/0
3Q4I01DH800@4a/04aHN00`?5`0@4a/08RD]04]>EP0D5ad061/N01HI700@51L04QHH01<G6@0G6ad0
6AdO01@H6P0D61T05QXK01@H6@0C5aT051PJ018F600A5AP04ADG01<G6@0E6A`04ADG01<G6@0D61/0
41@F018F6@0B5Q/07B0V01LJ80082a408RD[01PK8@0E61h051LM01@G700G6Ql00P0H6b002@0A5QT0
4QLK01@I7@0E6Qh051TM01<H700B5a/051TM01HK7`0201<H701E01HK800O8bd03a<O01XN:@0B5R40
3Q8N024U<00L82/041@N01DI8`0@51l04QHQ018G7P0?51P03aDE010F5@0S:BX08RPX01<I600A5aP0
4aTI01@J6@0C6AX04QLH010F5@0F6QT04QLC014F4P0C61@051PF014E500=4A804ADF00hB4`0?4aD0
4QHI00lC5@0C5aP04ADF01HJ6`0E6AX03a<D010D5P0?4aD04ADG01<G6@0F6Q`061`N01TL800@4aP0
4A@K014D6P0?4QT041<J014D6P0A51/04QDL018E6`0A51/03a8I00lB5`0@4Q804a@E018C500@4A<0
4A8D01<D5`0H6A`0;Bha01/L7`0;30l04Q<F00lA5P0>4AX04QDO01@G7`0>4AT041<J01PK8@0A51X0
4ADI018E6@0F6Ad04aLK01PO800200`E500700lD500@51D04Q<E01<D5P0@4A<03A0A014F5P0200dF
5@0F014H6@0>4QD03a<F014E5`0:3Pl03Q8C01`P8@0;3`h05a/J01<H5@0U:RL05a`I00hB500>4AL0
41<I014D6P0@4aT03Q4F00`@500<41<03A4D00dA4`803A4B00d04aLF010D4`0K7ah0:bl^00dA400@
51<04QHE00X>3@0U:BP041@C01<G5P0@5AD03Q<F00802a<F00`0318F00/C5P0=51L02Q4D07=kOP0f
?D001`dA00XB5@0<4QD02a4A00X@3P0=4a4201@J600300dC4@0>51803Q@B00<03Q@B00@03Q@C01lT
:00=4QL02a0D0P0@5AP07`0A5aL03Q@D00dC4P0=4a403A<?00lE4@0?5Q802Q<=00`F400:4`l041HD
01HK6`0>4QD03a@H00`A5`0M9b`00`/C00`I800<6b802a/O00`M7`0141404b4S00/G5`074A001Q4>
00L@300@61402Q4:018G400@5@l00P0B5a<07P0<4@d04AHB01<H500;40`03a@@010E4@0=4Ph03a@@
014F4P0>4Q006QhO010D5`0<41803A4D00hB5@0>4Q@0DEEG00lC5P0C5aT02PhA00/?4P0F6Q/04aPE
00lD400B5a<0314=010E4@0=4Ph0314=00hC3`803a@@0P0<4@d0200N8al03a@@00`A3@0_<c00314=
00dB3P0?51003Q<?0`0=4Ph0100>4`l03A8>00`A3@0<4@d200dB3P0=00`A3@093PX0314=014F4P0;
40`02Pl;00T>2P0T:B<04QLA00dB30021`4041D?00dB300200hC3@0B00lD3P0>4`d03A8<00`A2P0;
40T03A8;00`A2P0:3`P02a0900hC30093PL03A8;01<H4@0F6a@04aPA00`A2`0>4`d03a@>0P093PP0
1@0@5@l03Q<=00`A2`0;40X03A8<00803a@>00d03Q<=00X?2@0?50h03A8<00L<1P0M8Q`0@DI000hC
3@0;40X02Pl:00X?2@0?50h03Q<=00803A8<00<02Pl9024V800:3`T00`0<4@/08P0;40X02Pl900P=
1`0E5a802`d701@G400930@04A@:00lB200<3`D03a8:018E3`0;3@P092HT00h@3@092`H051L@0085
000F6A8041<<014D3@0B5@h04A@=00hA2P0=40T03Q4:00lB2`0@4P`03a8<00hA2`0>40/030h900X<
1`0>40/300d?2P0E00lA3@0@4Pd041<>00X=200=4@/03Q8<00d?2P0>40/04A<>00d?2P0;3@P051HA
01HH4`0?4@`03Q<?00D:1P0;3P/03a@@00T>2P0C61@020d900803a@@0180314=00/@300<4@h02A4@
00L>3`0;4aD031<F00hD6@0941D02A0C00lF5`0<5A80>40l09bTWP0K8ad03a<B00dA4@0<410200/?
3`0;010D4`031PD04ADD02<W9P0=4A002`l>00dA400:3Pd0310?010D4`0<40l00P0>4Q40600<40l0
3Q8A00`@3`0;3`h03A4@014E5P0K7b402@`?02T];`0l@4805ATL00lC5P0830h02`lB01DI6`1oPhD0
92P[00d@400?51005Q/G00dB3P0>4`l03A8>00X?2`803A8>0140314=010E4@0?51003A8?00`@3P0=
4Pl0310>00X?2`0B5a<01P/700`A3@0@5A402Ph:01LL600=4Ph02a0<010E4@0200/@300E01@I5@0N
8al02a0<00`A3@093PX02Pl;00hC3`093@T04AH@00/@2@0<4@/020d700dB300?50h02Pl900P=1`0;
40X04aPB00/@2`0A5Q403A8<008041D?00D03A8<00hC3@0A5Q002@h800`A2`0200lD3P0H00dB300:
3`T09b`U034g;P0>50`01P/400lD3@093PP04AH@01@I500=4Ph03Q<?010E4@062`L04AH@00/@2P0:
3`T03A8<010E3`0<4@/04QLA014F400>4`d0314;0P0;40X04@0730H04AH@00D:100=4P`04QLA06M/
IP0f>cD03Q<=00`?2`0D6A<03a@>01DJ500k@Cd02a0<00hC3`0;40`03Q0=00804aDB01H04a@A010A
3`0D5A<02PX8010A3`0G6A@03a4<00/=20092`H02`d8014C3P0>40/04aD@00L91@0D5Q406adJ08:7
P@0O9Ah01@T500hC3@083@L03@l:0P0@4Pd01P0A4Pd08R<N01/L5`0=3PT0418=00hC3@<041D?0140
3A8<01HK5@0?50h03A8<00`A2`0A5Q0041D?00dB3@0=4Ph041DA01HK5`0?5100314=00lD400=4Ph0
314=00dB3P0200`A3@@03Q<?00<03A8>00X?2`0?51000`0?5100200=4Ph0314=00hG4@0C7QL0?dY3
01HP6@0950d03aPC0P0=5Q401@0?5A<03a<B00hB4@0=4A40314=00803Q<?00X041DA01@I5@0@5A40
4aPD00L<200:3`/04AHB00L<200?510041DB1@0@51<04P0=4A003a<B014E500@51<03a<B00hB4@0=
4Pl06b0K01LL5`0>4`h03a@?01<H4`0@5A003a@?00hC3@0>4`h03a@?010E3aCooooo000Kooooo`0C
010?5`0:2A002`X@010?5@0<2a003PdB00L62`0;2`d020P:014A4@0<30/01`L701lN8`0:2@h061LL
00811`0>3A801@@900H52`0200l>4`0300/:400=31803`hC00<03PdB0`0>3Q0200`<300J00d=3@0>
3P`03Ph<00l?3`0A4A@020L<01<D600=41<00`H;014F6P0>4AH02`hE00l?5`0>3QH030/C00h=5@0<
31H0410H014A6@0@41P03@dE00`=4P0;314030dA00l@4P0C51D2014C4P804aDD00L04Q@C01@F5@0C
5A@03@l>01LH6P0>3a40414C00803@h@0100418F014D6@0H6b002@`A01<F6`0>4AH051LL00d@5@0;
3Q<061/P01DH7@0@4aP04QDM00h@70092aL03@lJ0P0F6B800`0B5A`05APM01TL8@0200lC5P0K00/?
4P0C5aP041@C00lC4`0@51D04QHE01DI6@0@51D041@C014E5@0A5AH04QHE018F5P0=4a404ALE00hD
500C61/06AhQ018G6P0H7Qh000<301PN6`0J8AX04AP@01HM5P0A5aL04QLJ00805AXM00<051TL018G
6P0E6Qd00P0F6ah0800E6Qd04aPK014F6P052Q005QXS00lD6P0E6Qh041DI010E600E6Qd03a@F01/Q
8@0T:RP06R0N00hD4P0A5A@06AhK01LL600830/03a@A01@I5@0M8B005a`I02@Y9@0Q9B@03a@A01HJ
6@0@51<08BDT02<W9P0B5QD04ADD0P0;3`h0CP0J7Qd0310?024U9011ADD051PI01PL7@0G6a`051PI
018F6@0@51L03Q4F00`?500B5A`04aHM010C700=41T030lH01<F6P0520d03A4D01<F6P0?4QL02@d@
01DI7@0>4AH04ADH01<G6`0@4aP04ADH010D5@0<41403A4B01<G6P0=4A@05APM03e0A@2GVZ407R4X
014D7@0F6B801PPD01DJ:00111<05ATT00lD6`0B5aX051XJ00`@400A4a80418B00h?4@0K71h07B4R
00/A4@0D6QX010P901TM7P0F6Q/03a<D00861`0E6AX04aLH00hD500C6AT061dO00lC5P0A5AP04aLJ
00X>4@0<41<06QhQ01TM7P093@h03Q8C00/?400D61T03Q8D010D5`803a<F00<03Q8E00`@4`0D61T0
0P0:3Pl02P0R9RL00PH7014E5P093@h041@E00`@4@0?4a@0310A00dA4P0I7Ah200X>3`0@01@H6@29
SHh09b//01<G600A5aL03a@F00hB5@0=4a<03a@F00hB5@0F71`0314B00hB5@000P804aHH00hB4`80
3a<D0P0=4A806`0>4Q<02Ph?00L;300830d04ADF01<G600>4Q<04QPH01<I6@052`/00PP8010F5P0D
6QP04QPF00X@3P0D6QP02@l=010F50052`T05adK00P>300J8200318B00dC4`0;4A403a@G00dB5@02
00XB500@00dE5`0@61X03aTJ00lI600>61L03QLF00dF5@0=5Q<03aPE00/A3`0A5a<05A/G00@:1P0A
5a<03A<?014H4@802Q4:00<03aH?00hE3P0@5a00100@5a005`0@5Q807B<Q00lE5@0:40h03A<B010F
5P0@5Q@03aDD00lE5@0>51803Q@C00dC4`0=4a4051XH00881P0L8R0051XH018H5P0=4a403aDC00L=
2`0220H03aDC00803Q@B00H02Ph=01LK6P0E6AP02Ph=00hB4@0;3`h201<G5P0<00P<2`072`X0=SXi
010D4`093@`04ADD00/?3P0A5A@020`;00hB4@0830/01`/:0P0@51<00`0;3`h03A8>00lD400200lD
40803A8>00L041DA00hC3`093PX02a0<00dB3P0F6aL02@h800803A<900<02Q0700dB2`0=4P/00P0?
50h0:P0@5@l041DA00lD3P0<4@`01`T400`>2@0B50l02@/601HH4`0@4Pd03a4<00h@2`0<3PT02`d8
00`>2@0?4@`03Q<<01HK500E6Q@01P/500T>200X;BT0JVm[028W8`093PX02`l>00050@0<40h06QlK
00<8100?51008RLS06icK`0@5A400PL301dR7P0320@02a0<00`A3@001@402`d800`>2@803@l:0P0<
3`P0200C5Pl04A<>00X<1`0:30L030h:00D70P0:30L03@l:0P0:30L0200>40/02`d800h@2`0<3PT0
3@l:010B3@0>40/02@`50`0?4PT300lB2`07010B3@0D5Q802`d:00P:1`0?40l000@0010F4P0200`B
3P1S00/A3@0>4`l02Pl;01lT800E5a@04A<@010B3`0?4@h03@l<00dA40052@P0310?01dQ800420L0
5ATH00dA400D61L02@d<00P<2`0F6QT02Ph=00hC4@052@P04QPH00H;300=4A803aDE00lD500<40l0
1P`:00P=300E6AP02Ph=00d@500830l0310C00X>4@093A003A4B00hB4`0=4A003A8?00hC3`0?5100
3Q8@018F5`072``041@E00lC50031`P02Ph?010D5@093@h03Q8C00041@0=4A804QHG00`@3`0830d0
4QHF07YnO@0P92D020`<04U=C01>DU<02@`<00lC4P0D61T02Pl<01LL600N8al04AHB00dB3P0;40`0
2@h:01TN6P0>4`l000D100dB3P0@5A80310A00hB4`0<41408BDV09jRX@0W:b/02Ph=00/?3P0>4Q40
3Q<?00dB3P0:3`/0314;014F400;40X03Q<=00T>200;40X01``600803Q<=01D02Pl901DJ50083@L0
318800/A1`0>50X03A<900T>1`0<4@X01@X400X?2P0>4`l02a0<00T=300C5aH04AHB00X?2@0>4`d0
3A8<00/@2P093PP0100:3`T02@0<4@/03A8<00/@2P0?50d0314;00dB300A5Q003Q<=00`A2`0200dB
300<00T>200=4P`0724K04=8A00@5A403a@@014F4P0<4@d010T500lD400=4Ph02a0<0`093PX01`0@
4Pd04Q@?00h@2`0@4Pd04Q@?00h@2`0?4@`00P0:30L200h@2`0500X?2@093PX02Pl;00/@300>4`l0
0`0?51001`0=4Ph0314=00`?300<3P/02Pl;00hC3`0<4@d00P0:3`/0100=4Ph03a@@00P=2@0=4Ph3
00lD4004018G4P0A4`h03Q0;014C3P803a4<00l0418=00X<1`082PD02`d800lA300>40/0418=00P:
1@092`H03a4<01LI500H6QD0418=00lA300=3`X00P0>40/07@0=3`X02@`800hC3`0A5Q8041DA00/@
300F6aL0<3Da00lD400S:2@02@h:01@I5@0=4Ph02Pl;014F4P0;40`041DA00H;1`0C61@05AXF00/@
300730P051TE02L/:00=4Ph03Q@@00XC3P0A61@06AlK008061hJ00P08RPT018H500630P03aDA014G
4`0;4@d03A8>00`A3@<02a0<00@03A8>00/@300<4@d03A8>0P0?51006@0A5Q802a0<00T>2P0>4`l0
6AhJ01DJ5`0830/03Q8A00dA4@0;3a00310A00lC500B5QT0724T02@Z:`0V;2`03aDE00hD4`0A5aD0
4aTG00H<2P0:40`04ALE05AJE`0=4`l05?ooool001_ooooo01P02@P@01HF70061@/05aHL00l>4`00
00@01PH800h>3`071`L02PX800X;1`0D5180000400`;4@0920h0000500/:400G5Q`051<I00d<4P08
1`d03PdC014@5P0?3Q@300h=4`0400h=4P0>3Q003Ph@00X:2P802PX804402``800/<1`0;2`T04@l@
00L71`0B51<0418D00L<3`0F6ah0>Sm300D83`082a805QDM00d:5@0:21<040lL00d=6@0?3aT04a<M
018B6P0?3aL03PlD00h?4`0?41@04A8E00l@4P0>3a403a4@00h@3`0?4A005ALF01<E500<3Pd03Q0?
014C4P0B51<03Q0?01LI600A51H02@d@01HJ7@0<41<051PK00`@4`0D61/04ADH00hB5@0@51L0310C
00T=400<3QL05QPU01/M:P0A4b001@LC00P:5P0=41P03a8I01HI7P0I72404aLJ018F6@0K7b404aLF
014E500200lC4P03010D4`0A5A@04ADD00804QHE0P0C5aH03P0?5A<05A/G01@J600E6a/06AlO01@J
6P0F71`05A/I01XP6`0E7A804AT<01DM4@0D6QP051TL100C61/00`0H7B005a`O01DJ7@0201<H6`0U
01@I700N8bL0<SLk01@I7@0J7b804ALH00hD500C6AL0318@01@J5P0K8Ad05A`F010F4P0T:BD06QlK
018G4`0<4@d061dI01DJ5P0D6AD041DA01LL600E6QH03A8>01@I5@0;3`h09b/Z02X^;@0>4Q403a<B
01/O7P093@`03a<B00X>3@0E6AP092PW00dA4002010D5@8041@G010041@H010C600@4aX030lH00hA
6P0C5B403a4M00/>5`0>4AD0310C00hB5@0?4aH0720S01HJ7@0@51L03A4D0P0@51L0:P0=4A@03a<F
00hB4`0<41403Q8C01<G6P0=41D05APM00d@5`0O8R/02@`E018D80000Ph07b<_03DiB@001Q@03aHP
01DJ7`0:41000080018G4`0B51404aDC00h@3`0C51H05QTJ00L;300E6AX04ADF01@H6@0=4A804ADF
00lC500<414010L800hB4`052@X05ATK010D5`0<41<04ADH018F6@8041@G00H07B4T00L;3P0E6A`0
2`lB00D9300>4Q@200`@4@0F00dA4P0<41402`l@01/O800T:2T0:2`]03/o@00D61T02@`=01<G600I
7Ah04QHG014E5P0<41402`l@00P<3@0A5AH0;C4b01`P8@0j?Sl04QHG010D5@803a<D0P0>4Q<0200?
4a@01PX;00hB4`0D61T082@U01XN7`0A5AH03Q8C0P0?4a@07@0=4A80310A00dA4P0<41402Ph?00`@
4@0A5AH04QHG00hB4`0<4Q002@l=00`B400>51802Q0>00T?3@0?5A<02Q0>01@J600;4@l04QPF00X@
3P073@d03Q@D00020P0@5QH0318B014G5`0<4Q803A<C00@03Q@D0P0@5Q@0400?5A<03Q@B00dC4@0<
4Q002Q0>00dC4@0;4@l04aTG00`B400=4a402a4=00`C300>5@h03A@=00XA2P083`P500hE3P0800hD
400B61H0318@00X@3P0;4@l0318@00dC4@0>518300dC4@80318@00L041HD014G5@052`T02a4?00L=
2`000P001@T700806AlM01P01`d;00H<2P0<4Q002`l>00T=30052@P03a<B02hb<@0a=C@01`/:00/?
3P0G6aX041@C02@X9`0R9RD020`;010D4`072`X0310?00H:2@0G6aX051PG00`@3`0=4A0200hB4@0=
00hC400<4@d0314=00`A3@0;40`02Pl;00`A3@0?51004QLC00hC3`0;40`04aPD00`A2P02010F300@
00dC2P0@5@h041D>00P=1`0A5Q004aPD00dB3P093PX01``800lA300C5A006Q`G018D3`0K7AP03a4<
00h@2`803@l:01L030h900d?2P0>40/04AH?01<H4@0@5@l020d700T>200G71P082DQ00P=2@0<40l0
61`K00lC4P093@`03Q<?00P=2@0=4Ph00@H2038g<`093PX05AXF00P=2@02014F4P0300T>2P0A5Q80
30h900@03Q0;00/03@l:00/=200<3PT02P`700T;1P0?4@`06Q`G00T;1P0?4@`030h900X<1`0200h@
2`0300X<1`0;3@P03@l:0080418=00<03Q4:00hA200>4@L00P0>4@P02@0>4@T03Q4:00`>2@000P00
418?01<E500=3`h04ADD00H>2@0200@=200600`B3P0=4`l03aDA018G4`0>40d030h;0P0>40d0;@0<
3P/03Q8A00P<2`0:3Pd04aLF00D9200B5QD020`;00lC4P0B5QD04aLF028V9@0Q9B@0720O018F5@0E
6AP03A4@00P<2`062PT0310?00lC4P0K7ah06AdL00`@3`0A5AH041<I00X=4P0<3a@02@`A00P<3`0<
41803Q8C00hB4@0=4Pl03A8>00hC3@0;3`d03a<D00hB4`0F6Q/04aLH00L;300>4Q<05a/L06mcM002
014E5P0R00T=3P093@d01`/:01hR8@0830/0:Bd/00D9200B5QD0>cln03i2@@0F6QT04aLF010D4`0<
4@h082DQ02db;P0D6AD01@X6014F4P0:3`/041DA00/@300730P0314=00dB3`0>4Q<02`lB00`@4`0C
5aP0HfMX01LK700830/02Ph=00dA40803Q<?00l0314=00T>200?50h0314;010E3`0<4@/03A8<01XO
6@0?50h01@X400P=1`0@5@l05AXD00hD2P0>50P00P0B60h03P0>50X03a@=01DJ500@5A003A8>00dA
400D61L092PW01lT800<4@/02Pl9010E3`0=4P`000@0100:3`T0100;40X0314;00/@2P0>4`d200`A
2`0A010E3`0=4P`02Pl900L<1P0:3`T02a0:00`A2`0B5a40:Rl[00D:1P0010001``800lD400I7QX0
41DA00lD400=4Ph00`0<4@d0400?4@`04A<>00d?2P0?4@`04A<>00d?2P0>40/030h900d?2P0?4@`0
3@l:00X<1`0:3`/02a0<00`A3@0=4Ph200hC3`03010E4@0>4`l03A8>00<0314=01403a@@018G4`0?
51002Pl;00lD400E6QH03A8>00hC3`0=4Ph0314=00dB3P0C5Q80418=00d?2P0?4@`030h900/=2002
010B3@0400d?2P0>40/03a4<00d?2P802`d80P0I6aH04`0:30L03Q0;010B3@0@4Pd03Q0;00lA300@
4Pd03a4<00/>2P0<4@d02Pl;00`A3@083@T02a0<01HK5`0D6AD06AhJ01PM6@000`000P0=4Ph03`0B
5a<0314=014F4P083@T0314=018G4`0[<2`07R<O01`Q7@1KH5`03a@@00lE4@0:40`02a4=00lE4@02
00dC3`04010F4P0?5A404QPD00lE4@802@l;0P0=4Ph300`A3@0300dB3P0<4@d03A8>00803Q<?00X0
3a@@010E4@0:3`T02a0:00lD400B5a<03a@A00T=300>4Q403a<C0P0?4a@03P0>4Q@03A4D00T>4P1Z
Kg<06b0S00021@0>4aD01@/;00/A4@0A5aH06b4O00471@0I7ad03A<A5?ooool001_ooooo00l04A0F
040oA@0K6R0030/@00X:3P0A4AD030`>00/;300820P0410>00/;2@0<30`030`>010?500510T00P0@
3a@0100?3Q<02`X?00`;400>3A8200/:3`0500h=4P0>3A<03PdC00h=4`0>3A800P0>3Q00100A4A80
4A4A010@3`0?3`h200l?3@0C014?40092@T03a4@018D5P0;41<05a`O05MLH00=41L01`T@00`;4`0;
21<04a4L018A6`0;2a@030`E014A6P0A4AT03@dE010A5P0200l@5@0^010A5P0>3a@030d@00h?4@0>
3a803PlA018C5@0B4aH04A8D00<41P0E5QT04a@G00l@4P0R8bH07R4T00dA500D61/0310C01<G6P09
3A00310C00lC5P0@51L03A4D01@H6`0G6ah061/R018E7`0:3AL0418M01HI8P0E62404A@L010C6P0A
51/071lV010C6@0F6Al06QhQ018F5`0A5AH041@F010D5@0A5AL04QHH018F5`804aLI040051PI01@I
6@0>5A@04Q/I010I600>5QP041PK01@L7P0G7b003QLE02H`:P2<UXh0KGM]01dW7@0H7Qd05a`O01@I
700B5aX04aPK01DJ7@0H7B005Q/N01<H6`0A5QT04QLJ01DJ7@0Q9RT0A4U;014F6@0L8B@04ALH00lE
5@0B61P041HE014G5@0C6AP04aTG01DK6P0A5AD04QHF01DI600@51@05a/J00hB4@0?4a<04QHF00hB
4@0=4A404aLG01DI6@0A5AH041@E018F5`0=4A<04QHH00`@4@0C5aT03Q8D01@H6@0D61X041@F01HJ
700A5AP04QDI0P0B5AX201<F6`0C01XM900L7bH05QTP00hA6@0D5al06ahV014D600H71l03a<F01DI
7019CE00@DE800dA500A5AP05ATL014E600?4aH04aLJ01@H6@02010D5@0^010D5`072Pl03a8G018E
700?4Q/03Q4J01<F7`0;3AT09BTd06aaO00F7BH02a8I00/@4P0F71/051XH01<H500B51404aDC010B
4@0?41804A@E00/?400A5AH03A4B01<G60093@h03Q8C018F5`0C5aP03Q8C01XN7`093@h05a/M00lC
5P0;3a803Q8E01PL7`0C5aX03A4D00lC5P0>4QD02Pd@01PL7`0b=ST04ADG00lC50@041@E0P0B5QL0
1P0;3a004QHG00X>3`0?4a@04ADF01PL7@804ADF00/03A4B00`@4@0A5AH041@E00lB4`0=4A802Ph?
014E5P0;3a00310A00hB4`0200lC500700hB4`0E6AX03Q8C014E5P0=4A8051PI010C500200hB4`04
00lC500B5QL051PI01@H6@803a<D01@041@E00lC500>4Q<03A4B00lE4`0@5Q@05Q`J010F50073@/0
41HD00T?3@0<4Q004QPF00dC4@0A5aD041HD00T?3`0R:2P0GVAT01DK6`8041HF01H02Q0@00`B4P0>
51@03Q@D00dC4`0;4A402@l=00X@3P0;4@l0318@00hD4P0?5A<03A<A01@J60093`d03Q@B00lE4`0@
5Q@04ALC00`B3P0I7a/05adI0P0:40`600`B3P0300X@3P0>51803Q@B0080318@00D03Q@B00dC4@0=
4a403A<A00`B400200/A3`0T01@J600g?C/06R0N00P>300A5aD0:c4_02dc<@083P`03Q@B00`B400C
6AL02Ph<00`@3`0=4A002`l>00T=300;3`h04ADD00H:2@0?4a8030l>01<G5P0Y:bX0Bdm>01HJ6@0O
8b804ADD00lC4P0830/05a/J018F5@0>4Q4041@C00lC4P0>4Q403Q8@0`0<4@d200/@300700dB3P08
3@T03Q<?00T>2P0?510041DA00/@2@0200hD2P0A00/A200>4``03Q<<014F400=4P`07b@P00X?2`0=
4Ph03a@@00lA300@4Pd06Q`G01TK5P0P8Qd03Q0;00`>2@0=3`X00P0?4@`02`0>40/03@l:018G400=
4P/02Pl900lD3P0@5@l02a0<00P=2@0G71P03Q8A00803a<B00H03A4@00/@300@5A403a@@00L:1`08
3@T200`A3@0600dB3P0<4@d02Pd:00hC3`0;40`03Q0;100?4@`03P0>40/03a4<00d?2P0A4`h03@l:
010B3@0[;BP04A<>01PJ5@0C5A002`d800h@2`0A4`h02`d80P0?4@`200d?2P0300lB2`0>4@P03Q47
00803Q4801@03Q4900hA2P072@@0CDm;01TK6@0?4A00418A00L;2P0<4Ph02a@?00PA300<4Ph020h:
00dC3`0:3`/03Q0=00lA3P0@4Pl03@l<00X<2@<03A4@01h02Ph=00`@3`0;3`h03Q8A00`@3`0@51<0
2@d<00lC4P0@51<08bLV014E50051`H041@C014E500>4Q4041@C01dQ800?4a8061`K00lC4P0O8b@0
5QXN010C600A5AT03A4D00/?4P0?4aD041@E00lC4P0=4@l200`A3@0500dB400<41403a<D00/?400<
41400P0>4Q<02`0H71d0E5QI00lC500:3Pl01@T:00lC4`062PT04aLF010D4`072`X041@C00803A4@
01T03a<B01DI600>4Q401PX900dB3`0A5Q8041DA00`A3@0A5Q80314=014F4P0730P0314=018G4`09
3PX0314>00`@4@0:3Q40310C00X>3`0A5AH03A4@00P<2`0:3Pd03A8>00<03Q<?00h01P/5010E3`0>
4`d04aPB014F400@5@l03Q<=00dB300F6aD0GfAN08:7P@0k@3X02a0:00X@1`803a@=00<02Pl800`A
2`0C61800P0;40X02@0;40/03A8=018G4P0<4@/02Pl900T>200=4P`051TC00dB300300`A2`802a0:
0P0:3`T02@0=4P`02Pl900/@2P0>4`d02a0:00hC3@0;40X03a@>014F4002010E3`0800dB3P0>4`l0
2a0<018G4`0;40`0314=00lD400>4`l300`A3@0900dB3P0>40/03a4<00d?2P0>40/03a4<00d?2P0>
40/03a4<0080418=00@030h900X<1`0=4Ph03A8>100<4@d00`0@5A403Q<?00dB3P0400dB3P0D018G
4`0?51002@h:00dB3P0C61@04AHB00lD400=4Ph02Pl;00/@300A5A003a4<00`>2@0@4Pd03Q0;00d?
2P0A4`h04Q@?014C3P0B50l201<E400:01XL5`0<3PT030h901<E40092`H03@l:018D3`0?4@`03Q0;
00lA30804Q@?02D041@?010E4@093PX03Q<?00lD400:3`/0314=04eBCP13B4@04QLC00lD400I7QX0
2@h:014F4P0?51004QLC00lD400>4`l05Q/G01@I5@0B5a<04AHB00`A3@0H7AT061hJ014G4`0=4`l0
3Q@@00/A3@0>510051XF00dC3`0:40`03Q@@00lE4@0C6AD041DA00803a@@00@03Q<?00lD400@5A40
3a@@1@0>4`l0600=4P`03a@>010E4@0<4@d0310>00hB4@0?4a8041@D014E5P0@51D03Q8D00/?4P0E
6Qh05ATM01@I701MHVD0=C/l018H600?5AD03aDD00lE4`0B61H061hL00/A3aCooooo000Kooooo`0H
00L6300C4QP03PdB00401@0A4A@05aLI010@4P0=3@h02`/;01<C4`0>3Ph05QHF030`<P071P/04Q4F
00D42@0=31404a8G00T83@0510T02`X?00d<4@0<2a0040lD0`0=318200d<4@0500d=3`0?3a403`lA
00h>3P0=3@d00P0<30`0=00D4QD03@d?00/<3P0@4a@01P/>00/@4`0A5QX04QDJ014D6@0B4AT04PlH
014@600@41H051DJ018C600<3A802@X?00X;400?41D03@dE00h>5P0A4AT0410H00d>4`0E5QX06a`Q
014B5`0<3A40414F010A5@0M7R80GUmT03hoA00720`020T>01HH7@072Pl030lD00lB5`0L7b@04A@I
00hA5P0B5AX051LL00hA5P0D5a`05APM00X=4`082a804QDL01TL8`0?4QT200d@5`0O01HI800;3QL0
4aHO00/>5`0E624041<I014E600A5AT04QDJ018F6@0B5QX041<H010D5`0A5AT04QDJ018F6@0B5QX0
3aLI018L7@0B71h03QPJ00`E6P0B6b0051dR00`F601GHF40n?oo0<;=a`0Y<bd05AXM01HK7`0201LL
800501DJ7P0D6Ad04AHJ014F6P0B5a/00P0A5QX02`0@5AT00`T902L]:`0;4A405adM00dC4`0A5aL0
41DH01DJ7@0E6a/04aPK008051TL01T07b<V00dA4`0<41404QHI01hR900>4Q<03A4D01LK7@0?4a@0
3A4D01@H6P0>4QD0310C010D600C5aX01PT>00d@500G6ah05QTN018E6@0>4QD03a8G010C5`0@4aP0
5APM00<05APO04/05APN01DH7@0S9R/082<X01PK800>4AH04aHK01/N8`0@4aP04aHK00@730051P/0
:bhc01DH7@0?4QL051LL01PK800C5Q/04A@I01HJ7@0:3Q402`lB00hB5@0D5a`04QDJ01hQ9P0?4QT0
2`hE01TL8`0B5Ah01`XC00/?600F72802A4D01LO8@0>51<0318@00P>2P0?51004aDD00l@4@0>3a40
4Q<G00lB50093@h04aLH010D5@0?4a@09BTZ05QLG@0>4Q<02@d>00dA4P0<41403A4B00P<3P0=4A@0
4aLJ010D5`0?4aH04ADH010D5`031`X02PhA00`?4P0?4aH092P[00L:300?4a@03Q8C00/?400830d0
2Ph?00/?400?4a@00P0D61T0;@0A5AH04QHG00T=3P0@51D0310A010D5@0=4A803a<D00X>3`0A5AH0
4aLH00X>3`0A5AH03Q8C00/?400<41403a<D014E5P0@51D03a<D00hB4`093@h05QXK00451P000P<0
92PY00lC500=4A803Q8C018F5`0D61T04aLH00lC500@51D03a<D00`@4@0;3a003A4B00hD4P0?5A<0
1P`:00dC4@0J81h03A<A00P>300200dC4@0;00lE4`0<4Q003A<A010F5P0N92@0Q8Z:00`B4P0=4a<0
20h>00hD500<4Q800P0:41002`0<4Q803A<C00X@3P0;4@l0318@00dC4@0>51803aDC00P>300;4@l0
3Q@B00803aDC00<0<3Hd018H50052`L00P0A5a<00`052`L020h:00`B3P0500`B3P0700hD4P0@5Q@0
3Q@B00/A3`0=4a4041HD00lE4`0200hD4P<03A<A01003Q@B00L=2`0=4a4041HD028X9P0O9B<03aDC
00D;2@0F71X0318@01TO7@0A5aD0310?00/?3P0<40l03Q8A0P0@51<03`0J7Qd01`/:00hB4@0I7A`0
2`l>01HJ6@0@51<07b<R01<G5P0=4A0010P700/?3P072`X020`;00hB4@0200`@3`0300dA3`0<4@d0
314=00<0314=00L01``800@91@0M8Qh02@h:00@91@000P001P/40080318800/02@l600`A2P0<4@X0
4AH?01lT7P2`]K40DUMC01dR7P0@5A403Q0;00X<1`02014C3P0401TK5P0<3PT02`d800`>2@803a4<
01/03Q0;00`>2@0=4P/02a0900X?2@0>4`d04AH@00lD40011P803a@@00/?3P0D61L03A4@00P<2`0:
3`/0314=00P=2@0D6AD0314=00hC3`0320@0CU=?01HK5`0B5a<01P/701/P700>40/00P0?4@`05@0>
40/03@l:00/=200C5A002@/600lA300=3`X01`T401LI500?4@`05aTD010B3@092`H030h9018D3`0>
40/04Q@?010B3@0<3PT02`d800lB2`0300d@1`<03A0902H00`D004a>BP2ATi008B<P00d?300@5A40
1Ph900PA300740/01P`800/A3@052`L0314=01<E4P0F61D05ALD010B3`0>40d02Ph=00`@3`0?4a80
2@d<00/?3P0420L03A4@010D4`0;3`h03Q8A01/O7P0?4a805ATH00X>3@0830/04ADD01<G5P0@51<0
51PG02hb<@803a<B00/020`;01TM7P0C5QX03Q8E018F6@0@51L03a<D018F5`0@51D03a<B00`@3`02
00X>3@0C00lC4`093@h02`l@00L;30052@X03Q8C00/?400A5AH00042010D5@052@X04ADF00/?3`0>
4Q40310?014E500830/061`K01<G5P0300lC4P0D00dA400<40l01``900dB3P0A5Q802a0<00X?2`0C
61@05AXF00H;1`0?51003Q<?00L<200=4@l02@d>00hB4`0<41404ADF00@82@0?4a8300dB3P0G00`A
2`0;40X02a0:00T>200E6Q@04AH@018G4@0A5Q00314;01`Q6`0>4`d04AH@09JKU@3Sj>80PHJ0010E
3`0=4P`03A8=00/@2P093PP03a@>00hC3@0<4@X00P0@5@h02@093PP01P/500T>200B5a403A8<010E
3`0E6Q@020d700hC3@0300lD3P0400dB300;40X02@h800`A2`802@h800h0314;00T>200;40X0314;
00dB30093PP020d7018G4@093PX020d900870`062`L02Pl;014F4P80314=00H02a0<00`A3@0=4Ph0
3A8>00d?2P0<3PT200d?2P0400`>2@0=3`X04A<>00h@2`8030h900@03Q0;010B3@0>4`l03A8>0P0<
4@d200X?2`0400dB3P0;40`02Pl;00X?2`<02a0<0P093PX0100;40`02Pl;00X?2`0<4@d200lD400H
00dB3P0<4@d06QdI024S7P0L7QT06Q`G010B3@0;3@P03@l:00lA300@4Pd04A<>01<E400E5a80<S@_
024S7P082PD03@l:00`>2@0>40/03a4<00d?2P0<3PT03Q0;0P0@4Pd06`0@50l05AXF00hC3`0;40`0
314=00X?2`0A5Q808RLS01dR7P0<4@d04QLC00050@0B5a<03a@@010E4@093PX03a@@014F4P083@T0
6b0L00/@30093PX07R<O00X?2`0@5Q802Q0<00P>2P0200`B3P07010F4P0c>CD08RPT00hD400=4`l0
3aDA018H5002010E4@<03a@@00<041DA00lD400>4`l0100>4`l0200?50h03A8<00`A3@0>4`l03a@A
00hB4@0?4a803a<C0P0>4Q<03P0@51H04QHI00/@500G72002PlB03Ll?`0Z;S004QPH00hD500H7Qd0
2@l=014G5@0D6QP05Q`J5?ooool001_ooooo00D02`X@00P7300H5a`03@`@010@4`0200/;3@0A014A
4`0>3Pl02`/<00/;300/;2h0EeMI00/:3P0A4A@04A0D01<C5P0<30l0B4M;01XI7@071PX03`lB00d<
400<2`l00`0<2a4300`;408040lC0P0@4182010@4@04010>4P0@41<02@X=01@G6@<020d@00`01`X?
00H93P0>3A@040dE00X93`0A4Q@05aPK01DF6@0>3a8030dA00h?4`0@4AH200d=5@80410I02X03PhG
01HG7@0J6R404Q8I00d=500@4AL04Q<I00d=500/;3<051@K01HG7@092Q004Q@J00/>4`0D5a`04A@I
01<F6`0:3A804QDJ00`?500:3A802`hC00lB5`0@4aP08BDY01dQ8`0=41@041<G014D6P0@4aT03Q4G
01TL8`0A51d0>Se701lQ;00K7BP04aHN01LJ800F6Al051LM018E6`0@4aT2014D6P<04QDK01<04aLL
00TB500@6Q`04QdQ00lI7`0O:C40GVM_02hh@00L9Rd08B`_04iHF@0nBDL05B0O018J7@0E6Qh061dQ
01TN8P0H7B405a`P00804AHJ0`0B5a/07@0B5aX0728Q014G500C6AH04QPG00dC4`0A5aL03A8E018G
6`0A5QX04AHK018G700=4QL02`hD030d>@0j?T8071lU014D6@0C5a/05APN01/O900I7B405aXP01LJ
7`0B5A/06ahT00d@5P0@4aT03A0F00804A@J02405aXP01@G7@0>4AL03Q4G00lB600:3A@03a8J010C
6`0A51`04QDL01@G7@0E61d07B4T00`@4`0<41805QXK014E5`093@l0310D018E6P0D5a`04aHK01`O
900931403a8G00hA5P0A51T041<H00d@5@0@4aP051PL014E6@0?4QH00P0@4aP06P0N8BH03A0F01lR
:@0M82L03A0H01XM9@0D6Ah02a8C00D>300B6aT03A8?018H500>510041@B01DG5`0@4A<04A8D018C
5`0C5QP02Ph?00/?400>4Q<051PI05IJF`2a]KH0:Rh_0P0=4A803`0A5AH051PI018F600C5aX041@G
01<G6P0<41<03A4D00lC5P0K7b804ADH03Hj?@0K7b802PhA01XN800201@H6@0700lC500<41403a<D
020T9@0=4A804ADF00lC5002010D5@0400hB4`0E6AX041@E018F5`@03Q8C00<02`h?018F5`0;3a00
1`0>4Q<02@0<41403Q8C00lC500>4Q<04aLH04I:B`0B5QL03a<D00`@4@0200lC500500X>3`0@51D0
3Q8C00`@4@0>4Q<00P0@51D0500D6QT02a4@00P>3@0Q9bH0;cDd00P>3@0;4A003A<B00X@3`0F71/0
41HE00lE50083Ph041HF00X@400A5QH03A<C00hD500@5QH03Q@D0P0<4Q80200=4a<03Q@D014G5@0@
5Q@03Q@B00`B400;4@l02Q0>0`0@5Q@01@0>51801@/901lU8`0B61D02a4>00803A<@00<02a4>00dC
400=4a001@0=4a001P0?5A<0318@00X@3P0;4@l0318@00dC4@803aDC0P0>518200dC4@0=00hD4P0=
4a4020h<00`B400O9B<03aDC00`B400=4a404QPF00X?3@0<4Q002Q0>00dA400200hB4@0500`@3`0;
3`h02Ph=00T=300F6QT00P0@51<040072`X02@d<00D9200D61L03Q8A010D4`0830/04ADD00dA400;
3`h0310?00X>3@0<40l03Q8@00X?2`0;40`300`A3@0700/@300E6QH0@TM3020U8@0>4`l01PT600lD
3P0200hD2P0?00/A200>4``03Q<<00hC30042@<0F5eI024V8P083@T03A8>01DG4P0>40/04aD@00d?
2P0B50l02`d800H03@l:01D02Pl800`A2P0>4`d02a0:00X?2@0<4@d03A8>00X?2`0;3`h03Q8A00dA
400;3`h0314=01@I5@0=4Ph010P4014F4P0@5A407b@P08B9Q@0k@3`00P0;40`02`0:3@X03a4<010B
3@0@4Pd03a4<00d?2P0<3PT051HA00h@2`0@4Pd04aD@00804A<>00H02P`7010B3@0:30L020X500lA
300C5A0200lA30803Q0;00<0418=014C3P0>4@X00P0>4@T04P0>4@X03Q4;00hA2`0D5Q4030h903Xl
>00K7AT030h:00D:1@0<4`l02A8=00lH4`0;4@d0>3hj01`R7P0:3`/04A<@01<E4P804Q@A00<04aDB
00`@3`0830/00P0;3`h07@0A5A@0;30_00hB4@0@51<0310?018F5@0O8b804QHE00lC4P0E6AP0FEeL
02<W9P041`H04ADD00`@3`0?4a803Q8A018F5@0Q9B@0@4A500d@50093A003Q8E00hB500>4Q<04ADF
010D5@0>4Q80310@00802Ph>00l0310A00/?400H71d0;30a01HJ6`093@h0310A00X>3`0E6AX03Q8C
014E5P0?4a@0310@00hB4@0=4A000P0<40l06@0>4Q402`l>00X>3@0?4a802`l>01PL6`0R9RD04aLE
00`A3@093PX0314=010E4@0<4@d03a@@00H;1`0@5A402Pl;01lT800<4@d0310A014E5P0?4a@03a<C
01<G5P0;3`d00P0?51002P0>4`h02a0:00/@2P0:3`T0314;01TN600A5Q003Q<=00lD3P0:3`T200/@
2P0<00lD3P0L8A/092TS01/P6`0<4@h02`l=00`A3P0<4@d02@h900dB300@5@l0314:0P0<4@T02P0@
5@`06b0H00hC300C61802@h801@I4`0P9Al02@h800`A2`0>4`d2010E3`0400hC3@0<4@/02a0:00hC
3@802Pl900h0314;00T>200?50h041D?014F400<4@/02Pl901<H4P0<4@d041DA02L/:00C61@0314=
00T>2P<03Q<?00/041DA014F4P0B5a<03Q0;00`>2@0?4@`03Q0;00`>2@0?4@`0418=00lA300200`>
2@04014C3P0E5a803A8>00dB3P<0314=00@02a0<00`A3@0:3`/02Pl;0P0;40`01P0<4@d03Q<?00/@
300<4@d041DA00hC3`802a0<0P0?51000`0>4`l03A8>010C3`0200d?2P04014C3P0?4@`030h900h@
2`804A<>00d0418=00lA300@4Pd06A`G00hA300;3PT03A0;00T<1`0?4Pd041@>00dA2`0<3`X03A0;
00803Q8<00<04AHA01hS7`0H7AT00P0?51001`0<4@d03A8>01XO6`0?4Pl041DA01TN6P0?51000P0>
4`l05`0B5a<03Q<?01XO6`0>4`l03a@@00T=2@0D6AD0>3di00X?2`0=4Ph03A<?00X@300>51004aTE
014G4`0B61@0318>00dC3`0@5Q802Q0<00D;1`0@5Q8041DA00803a@@00@03Q<?00lD400@5A403A8>
0`0>4`l200lD400H00`A2`0>4`d041DA014F4P0?5140310?010D4`0?4a<03Q8C00lC500A5AL04aLJ
00lD600>4aL05a`O03@i?00=4Q@082HV01LM7@0=4a8041HD018H5P0;4@l061hL5?ooool001_ooooo
01P03`hC00h=4P081``02@T;00P82P0000803@d?00H6200=3@l05aLI00P82P092@/03Ph@00/;3@0@
41807QhP00`<3P0A4A<051@F00`<3P0C4aD03@d?00P82P0@418600`;400400/:3`0<2a0030/@00h=
4@803PdB00d020H;00l>4`0:2`l06ahQ010E600>4aH01P/>00H93P0@4aP03@`B00X73P0D4aP03a0@
008030h=00T03PlA00l@500@4AD051DJ00l?5`0=3AD03PhH00d=6@0=3AH00P0>3QH04@0=3AD04Q8J
010@600=3AD071`T03Ph@00?3aL06ATQ00H63P0C5A/020/@01@G70082a003A0E01hQ9P0g>Sl07B0U
00803a8G010030lD00d@5@0C5QT02`l@00`@4@0F6Q`04ADH010C600G6R0051LN00L:4`1?DU`06Q`X
014C800D5R405APO0P0G6R40100F6B0051LN018E700B5A`201<F7@0n01@G7P0D61h03aTK01HQ8`0@
6b0051hW04mIHP3Wl?D0J79l024[=@0E82L082/_01HQ8`0@6Q`051`O01DJ7P0D6Ad05Q/O01PM8@0L
8BD05a`P01DJ7P0B5a/04AHJ01<H700G71l0Ade;00T?2`0G7AT03A<A014G5P0B5aX041DI018G700=
4QP03Q<I01<H7`0<41T08RD^028U;00M82L041<J018E700;3QD051LN01DH7`0F6B005APO018E700E
61l061/R01HI800I72<02PdD00/>5@0G6R404A@K00hA600F6B0051LN00d@5`0H6b8201<F7`0D014D
7@0A51/041<I00lB5`0@51H04aLH018F5@0?4a8041@C01<G600D5a/03A0E018E6P0A51T05APM01LJ
7`0A51T02PdB00d@5@0?4QL200`?500o010C600>4AH03A0E018E6P0I7240:Rdb02HY;P0:3A@03A0G
01<F7@0N8BP02PlC00hF4P0Z<bh0=d0k01HL600=4`l02a4?00`@3`0@4A<051DG01`M7`0F5a/01PT;
01DI6P0I7Ah03a<D018F5`072``0:2`]00/?400<41404QHG01<G60093@h0:Rh`01`P8`0420/04aLJ
018F6@0;3a805a/N028V:@0N8RD0310C00862@0M8B@04QHH01<G600D61T041@E00hB4`0C5aP0=CTj
00dA4P093@h0310A01DI6P0?4a@0310A01<G600?4a@04ADF00803Q8C00D02`l@034e=P0?4a@05ATJ
00<7200200lC500I00hB4`0<41402Ph?00X>3`0<41403A4B01LK70093@h05a/L01PL7@0<3a0041@E
00dA4P0<41404aLH01HJ6`0B5QL04ADF00`@4@0:3Pl04QHG01HJ6`0D61T041HF00dC4`0200`B4P0F
00lE5@0A5aL0318B00dC4`083Ph07R@T01HL700C6AT04QPH00P>3P0H7Qh00`T900L=3@0A5aL03A<C
00lE5@0A5aL041HF00dC4`0;4A402Q0>00/A3`80318@0P0>518020032@L03A<A00L=2`0>51803A<A
00T?3@0:40h03Q@B0P093`d00`0<4Q002Q0>00`B400500`B400600dC4@0:40h0318@010F500>5180
2a4?0P0=4a4200`B40802a4?00`03A8@00X@3P0=4a4051XH0006100C6AL03aDC010F500:40h03Q@B
00D;2@032@L2010D4`0F00dA400;3`h04ADD01<G5P0A5A@0FUiM00`?3P0@51<01PX9010D4`0830/0
3a<B00P<2`0=4A001PX900/?3P0:3Pd03a<B01DI600>4Q402Ph=00`A3P803A8>0`0?51001`0B5a<0
00D101TN6P0730P06b0L00T>2P0<4@/00P0;4@L05`083PD02a0900/@2@083@L04aPB00/>2`0A5Q80
3A8>00/@300=3`X02P`701@F4@0>40/0418=00d?2P0?4@`03Q0;00`>2@0;3@P030h900lA300730D0
2a09008041D?01003Q<=00dB3P083@T01``8018F5@062PT03a<B00X=300;40`04QLC00lD40011P80
9R/W00T>2P0?51001``80P093PX04P0D6AD01``8018D3`0B50l04A<>010B3@0?4@`03@l:00h@2`0?
4@`020X500T;1P0?4@`030h901LI500F61<03Q0;00d?2P804A<>00<05QPC010B3@0=3`X00P0>40/0
0`0;3@P03a8;00lB2`0200lB2`0A00lB300?4@`01@L201LI500:30L03@l:00l@3@0H7AL08RXU014J
5@0C71L01@/7051FDP0Q9b<04AHB01@F4`0A4a000P0=3``0300@4Pl03A4@00H:2@0830/04ADD02X^
;@1^LW4041@C00T=300?4a802`l>00hB4@80310?00h04ADD06EYJ00H71/03Q8A024U900>4Q403A4@
00X>3@0?4a8061`K00`@3`0?4aD02`lB010D5P803a<D00@04ADF00hB4`0=4A80310A0P0;3a00:P0>
4Q<01PX;00D92P0Q8b@01`/<00010P0D61T04ADF00H:2`0@51D0310A010D5@0?4a<0008101DI600>
4Q402Ph=018F5@0I7A`01@T800/?3P0830/04QHE01/O7P072`T02@h:00lD400>4`l02@h:014F4P0<
4@d020d9018G4`0C61@0@DI2014F4P0<40l0310A018F5P0830/061`K00dB3P80314=0P0;40X0>00<
4@/03A8<00`A2`0I7QP03Q<=00/@2P0?50h02a0:00L<1P0=4P`02a0:00P=1`0F6aD03Q<>00`@3`0=
4A805ATH01HK5`0?51003Q<=00hC300>4`/03Q@:00/A1@0>50P06b4G00L<1@0S:2802a0:0003000<
4@/04AH@00L<1P0:3`T03A8<00hC3@0<4@/02Pl900`A2`0?50h02a0:00X?2@0=4P`02@h800hC3@0;
40X041D?014F400:3`T01``6010E4@0A5Q80>Chj00dB3P093PX041DA0P0;40`0400<4@d03Q<?010E
4@0A5Q803Q0;00`>2@0@4Pd03Q0;00`>2@0@4Pd030h9010B3@0?4@`03Q0;014C3P0D5Q4700`A3@80
2a0<00@0314=00dB3P0=4Ph03A8>0P0@5A4200dB3P0;00lD400>4`l03Q<?00`A3@0;40`03A8>018E
4@0?4@`03Q0;018D3`0>40/00P0;3@P03P0=3`X03a4<00lA300@4Pd04aD@01HJ500<4@/03A8<00lD
3P0A5Q003a@>00/@2P0?50h03A8<0P0>4`d09P0=4P`02a0;01<H500?51003Q<?01<H500<4@d041DA
00L<200;40`03a@@018G4`0730P061dI00dB3P0G71P08BHR03@i=@0F6aL02a0<01LL600C61@08bPT
00lD400E6QH041HB00hD400D6QH061hJ01<I5@0=4`l051XF00dC3`0<4Ph04QPD014G4`0?5A403a@@
0P0>4`l01P0=4Ph03Q<?00lD400;40`0314=00dB3P803a@@01804AHB00hC3@0G71H07b@P01PM6@0@
5A804ADD010D4`0B5QH04aLH018F5`0?4aD0310C00462P0E6Qd04QLJ00dB5@093Q0200P>3P0501@J
6@0:40h00`T701<I5`0630X05?ooool001_ooooo01/020P:00/;3@0>3Q003Ph@00/;3@0820X02PX<
00h>400A4A<010<8018A5P0<2a002PX<00d=3`0E5AL06QXL01HF600<30h02PX<00l?4@0<30h03Ph@
00l?4@0;2`d02PT>00`;400=31400`0?3Q<03@0:2@l04Q4G00d<4P081`d051<I00h=4`0=2Q402PT?
01HG700>41D041DH00462@0;41<00P0?4aH05`0@3a@040hC010@4P0>3`d04aDB00<50P0B51<02``>
01HG6`0I6Ql0410H00d=5@0<31@030`F00`<5@0=3AD03PhF010@600B4QX04a<K014A6@0?3aL0410H
00804Q8J00l04a<K010A6@0E61l01@P?01<F7@0G6R404QDL06EXK`0S9Rd02PdD00lB6@0:3A@02`hE
018F6@0>4Q400P0>4Q<01P0?4a@041@G010C6@0?4QT03a8K00lB70803a4M00H03a4L01<F7@0A51/0
41<J01DH7`0D5ah2018E70804A@K02/04QDL01@H7`084Q@02aHH01<N8`0M9c00@4YC09^U/00^>4@0
6B<]014K9@0@6R<04QdS014K8@0E72805a`R01PM8`0D6Al09R/a04A9C`0K82H05Q/Q01DJ800_=3X0
3a@J014F6`0M8b<01P`:01@J60032@T061hO00/@4`0Q9RX02PlD02X_=@0<41T051PR01dQ:P0P8b`0
>ci7014D7@1cMWl06ahW00<04QDN00`041<L00lB6`0C5Ql05aXS00/>5@0G6R404aHM00`?5P0@4aX0
4A@K010C6P0A51/2018E708051LN01<06A`U010C700B5A`03a8I00`?5@0K7R<04ADG014E5P0A5A@0
4AHC014F4P0A5A@041<I01HI800I72<051LN01<F7@0J7B@041<J00803Q4H0P0A51/06@0@4aX04A<J
00`?5P0C5Qd04QDL00X=4P0<3a@071lT01<F6`031P/0A4M<00d@5@0N8bH04QXF0419A012BdH04aTG
018H5P0G7Ad04ADF00/<400C51P04Q<G00l@4P0A4aD00P0A5AH04P0?4a@03Q8C014E5P0B5QL01@T:
01@H6@21QHH06AdN020T9@0>4Q@04aLJ01@H6`0B5QT041@G014E600L82<07R8U01DI70803a<F00`0
41@G00dA4`0=4A8051PI00X>3`0<41404aLH00hB4`0H71d0<CDf024U9P062P/200hB4`0A00/?400>
4Q<02Ph?00@82@0:3Pl02`l@018F5`0=4A801PX;00dA4P0@51D03A4B018F5`0?4a@02@d>00`@4@0:
3Pl00P0<414200dA4P803Q8C0`0=4A80600<41402`l@00/?400@51D04ADF01@H6@0=4A8061`M00X>
3`0630`03A<C00hD500C6AT02@h>01DK6`0630`041HF00T?3`0630`020`<01HL700B61P0318B00X@
4080318B00L020h>00lE5@0<4Q801`d=00P>3P093@d05Q`L00804aTG00H041HD00T?3@0D6QP04QPF
00hD4P0<4Q0200X@3P0300`B400>518041HD00803aDC00l02@l=00lE4`073@/03Q@B00lE4`0=4a40
2a4?00X@3P0;4@l03aDC01<I5`0B61H02a4?00X@3P0=4a400`0>51801P0=4a402a4?00X@3P093`d0
3A<A010F5080318@02D04aTG00hD4P0=4a4041HD00dC4@0B61H02Q0>00lC4P000@002Ph=01<G5P07
2`X02Ph=00L;2P0@51<04ADD00@81`093@`03Q8A00lC4P0:3Pd041@C01DI600=4A002`l>00hB4@0@
51<03Q8A00X>3@0<40l04ADC00P=2@0A5Q805AXF00`A3@001@402Pl;0080314=00@03A8>00/@3009
3PX020d70P093`D02P0:40L02a0900/@2@093PP04QLA01LL600A5Q801P/700X?2`0?4@`2010B3@03
00h@2`0=3`X030h900802`d80P0=3`X200`>2@0J00/@2@0D6A805Q/E00T>200730H0314=00T>2P0:
3`/020`;018F5@000`80@4A300/@300=4Ph02a0<01DJ5P0320@020d900H;1`0A5Q802@h:01TN6P0C
61@02@h:018D3`0A4`h200lA3080418=02P03Q0;00lA300=3`X02P`700/=200@4Pd02P`700d?300E
5a80418=01HH5@0_<B`0;S0[010B3@0>40/04A<>00T;1P0@4Pd01`T401TK5P0620<06Q`G00X<1`0>
40/04Q@?014C3@0<3`P02@`500/>1`0=4P`0:C0/08bET0084@`03A<?0002000C6AD03Q<?00lA3P0>
40d030h;0P0:30T02`0=4A001PX900P<2`0?4a801PX900`@3`0>4Q403A4@00`@3`0;3`h03A4@0080
3a<B00D03A4@00hB4@0E6AP06alN01dQ800600hB4@0<010D5@0=4A802@d>00P<3@0>4Q<02`l@00hB
4`0;3a0041@F00`@4`062Pd041@F0P0=4A80600C5aP02`l@00X>3`0;3a002Ph?00P<3@0?4a@03Q8C
00T=3P0=4A401`/:00/?3P0D61L03a<B00hB4@0@51<03A4@00`@3`0;3`h03A4@00hB4@0>4Q002Pl;
00/@30803a@@03T02@h:00P=2@0@5A403Q<?00P=2@0<4@d020d901<G5P072`X02`l>00L;2P0730P0
5Q/G00hC3@0;40X03A8<00lD3@0<4@X03Q<<00/@2P1AEU00>3dg0004000<4@/03A8<00lD3P0=4P`0
5Q/E00X?2@052P@03Q<>00/?3P0?4a@0CE5@07YoN`0730P03A8<01XO60052`804AL=01<I3@0=4`L0
10X000`A2P0?50h01``6018G4@0A5Q001``600X?2@083@L041D?00H;1@0D6A<0314;010E3`0<4@/0
0P0730H00`0;40X03Q<=00dB300200dB300800`A2`0;40X02Pl900lD400@5A403Q<?00X?2`083@T2
00T>2P0300hC3`0?5100314=00802Pl;00H03Q0;00@60@0R91l02``901<E400<3PT2010B3@0N00/=
200<3PT0418=010B3@0D6AD0008001/P70093PX09BXV00@91@0<4@d04aPD01/P700>4`l041DA028W
8`0=4Ph02Pl;00T>2P0:3`/02a0<00dB3P0:3`/02a0<00`A3@0;40`020d901LJ5P0E5a804Q@?0P0>
40/2010B3@0N018D3`0D5Q403@l:00L9100:30L03Q8<00hE3P0;4P/04QTB014H4@001`005A`E00P?
200:4@X03QD>00L>1`0=50d0318<01HK5`062`L041DA01hS7`083@T02@h:014F4P0>4`l07B8N05YO
F`0C61@03Q<?0P0@5A400`0C61@04QLC00dB3P0201<H500D010E4@0L8Ad05AXF00P=2@0i?c/0:Bl[
00P>2P0M8al03Q@@00lE4@0=4`l051XF014G4`073@T020h:00X@300=4Ph041DA00hC3`0=4Ph2014F
4P0N00/@300<4@d03Q<?00lD400>4`l03A8>01TN600:3`T041DA00D:1P0D61H02@d<00X>3@0H71`0
1PX;01LK700=4A<05ATL00@93@0@5AP03a@G00dB5@0E6a`02a4A00L=3@0A5aH02Q0>02dc<@0S:BL0
1@/95?ooool001_ooooo00d03Ph?00d=3P0<30d030`=00d=3P0>3Q0030`>02PW:P1KFUh06QTN00d<
4@0<2a002`/=00803Ph?00/02`/<00X:2`0<30d03Ph?010@4@0;2``03@d>00h>3`0;2`d030/@00d<
4@0300h=4P0I00d<4P0<2a402@P?00l>5@0@3aH03PdD00/:4@0B3aL010<:01LG7P0=3a@0DeQL01XO
8P0;41<0310B00/?4@0<30l040hB018B500>3`h03a4?01dO7@1MGUl0LgAf01TJ700200h?4`0500d>
4P0=3A@03`lF014B600A4AP00P0@4AL400l@5P0;010A5`0A4QP04Q<I01<C6P0C51/03A0G00lB6@0=
41L07B0W00/>5@0@4aX00P0<3aH01P0E61l03A0G00/>5@0>4QD03a<C010D5@804ADG00@04ADH014D
600A51X04A@J0P0A51`0>P0A4ah041<K018E6`0A51X03a8H018E6`0A51X04aHL014D6P0?4QP04A@J
01<F700B5Q/04a`N018L7P0C7B803aPQ00lI8P0Q:SL07RLd010I9@0?62<031HO00dG800@6B404APN
01`Q9`0H7B<0;34g07f2R03Oi>L0LWMm02`a=`0N8bT0B4eC01lT:P0I7R<051XK00dC4P0E6Q`04AHH
00lD5`0?51P020dA020U:P1RIfd06QlV00hC6P0N8RX04aHN010C6`0?4QX07R4Y01<F7P0A51`04QDM
01@G7`0B5Ad2014D708051LN00D051LM01DH7P0B5A/03Q4G018E6`02014D6P@041<I03D02`hD01dP
9P0H720041<I014D600A5AP04ADF014E5@0A5A@04AHD014F4`0A5AD04A@J00lB6@0A51/041<J00lB
6@0C5Qd03Q4H018E700C5Qd041<J00hA600=41L08bH^018E7@0C5Qh04A@K018E6`0C5Q`051LL01dP
9@0E61d0HVIZ00lC5`083A004a/I030i=`0S;2X03a@F00`A500>4aH041@H00`=4P0C51P04a@F018C
5@0A51D03a<D00hB4`0?4a@041@E00lC5002010D5@0K00P<3@0a=CH02@d>010D5@0>4Q@03a<F010D
5`0>4QD0310C00dA500@51L03a<F00dA500?4aH04ADH010D5`0A5AL01PX;00P<3@0?4a@02`l@014E
5P0@51D0310A01PL7@0C5aP02Ph?00803a<D00L02Ph?00lC500J7Ql061`M010D5@0;3a00310A0080
3a<D00P03Q8C00`@4@0A5AH03a<D00dA4P0C5aP06AdN00lC5080310A0P0=4A8200hB4`803a<D01P0
3Q8C00dA4P0=4A803A4B014E5P0:3Pl0310A01PL7@0Y;Bh051PI010F5`083Pl03Q<E00/@4P0B5aT0
2@l@01@I6`0?4aD03aDF00X@4@0L8B<01@/<00lE5@0>51@400`B4P0>01<I6@0;4A405A/K00H:2P0A
5QH04aLG00lE4`0:40h04aTG00lE4`0>51802@l=010F500>518200`B400600hD4P0@5Q@03Q@C00/A
400B61L02@l>0P0?5A@01`0<4Q403Q@C00H<2`0>51<041HE00/A400<4Q000P0=4a400`0<4Q003A<A
00lE4`0200hD4P803aDC01D03Q@B00dC4@0>51802a4?00`B400=4a404ALE01PN702:T8h07R@R01DK
6@0A5Q@04ALE00L<2P0=40l02`l>010D4`0<40l06AdL00dA400:3Pd00P0;3`h02@0<40l03a<B00dA
400=4A002@d<00lC4P0B5QD02`l>00`@3`0200dA4080310?00P03A4@010D4P0F6aL02Pl;00`@3@09
3PX05AXF00dB3P80314=0P0=4Ph03@0<4@d02a0900/A1`0;4@L0314900`A2P0=4P/02a0:00lD3P0<
4@d02Pl;014F4P0>4`l00P0A4`h03@0@4Pd03Q0;00`>2@0;3@P03Q0;00lA300@4Pd03a4<00h@2`0;
3@P02@h7010E3P0B5a400P0;40X04`0;40`03a@@00dB3P0;3`h0310?034e=01KGeh03A8>00hC3`0K
7a`041DA014F4P083@T04aPD00H91P0U:RH0DUMC00hB3`0@5A400`0>40/01P0@4Pd04Q@?01@F4@0@
4Pd04A<>00lA30803@l:01d0418=01LI500<3PT06adH00D60`0o@C`05QPC01hP6`0=3`X020X500d?
2P0A4`h051HA01DG4`0<3PX03a4=00T;1`0?4@`04Q@?01LI4`0C5Q004QD>018E3@0@4`/02a0900dE
3`0B6aH02a@?00/A3@0200P>2P0300`A3@0>40d03a4>00<0418?00D05ATH00`@3`031`H0310?00/?
3P0200hB4@0600dA400<40l03A4@00dA400?4a803Q8A0P0<40l00`0>4Q4041@C010D4`0600dA400<
00`@400A5AD051PH01<G5`0E6AX03A4B00X>3`0=4A<02@d@014E600D5a/02Ph@0P0=4A803P0>4Q<0
310A00/?40093@h02`l@00X>3`0=4A801`/<00/?400H71`041@C018F5@0F6QT04ADD0P0>4Q4200`@
3`<03A4@01h03Q8@00`A3@0;40`03A8>00hC3`0;40`04AHB00dB3P0:3`/03A8>00lD400@5A403Q8A
00`@3`0>4Q0020d9014F4P0?4`l04AH@00dB300<4@/03A8;00X?200>4``051TC010D3`0?4`h04AH@
010E3`0;40X200dB300J00X?2@0I7QP05AXD00dB300=4@l03Q<@03Di=P1>Ddl03a@?00hC3@0d>C80
5AXC00dB2P073@@02a47010F3@0730H03Q<=00H;1@0;40X0314;00lD3P0C61802@h800hC3@0B5a48
00dB300300`A2`0=4P`03A8<00803A8<00H0314;00dB3P0?51003A8>00/@300:3`/200/@30803Q<?
00H03A8>00hC3`0?51003a4<01DG4P0B50l200`>2@0:00h@2`0@4Pd03Q0;018D3`0>40/03@l:01DG
4P0F6aL04AHB00P=2@@0314=00H04AHB01<H500:3`/02Pl;010E4@0;40`200`A3@0900dB3P0<4@d0
314=01DJ5P0@5A40724M01@I5@0>4`l03a8>00<03a4<00D0418=014C3P0A4`h0418=00lA3002010B
3@0L00lA300:3`T02a8;00lF3`0=50d03QD>00dD3@0<4``01`h700XA2P0;4P/031<<014H4@0=4`d0
3Q<?01DJ5P0<4@d02@h:01<H500?51003A8>014F4P0?51009R/W00<7100C61@03a@@00hC3`803a@@
01/03A8>00hC3`0L8Ad03a@@00/@300@5A40314=01HL600C6AD051XF04I<B00j@3`0318>014G4`0F
71P04aTE00/A3@0=4`l041HB014F4P0C61@041DA00dB3P0?51003Q<?00dB3P0>4`l00`0?51004P0>
4`l02a0:00hC3@0@5A402@h:02T]:`0I7A`051PG00`?3`0C5aP0310A010D5P0;3a804aPL00lD5`0B
5aX03a@G00dC50803aDE00D02a4@01<I5`0P9R@04aTG00lE4`0Dooooo`006oooool04P0?3`l03@d=
00/;2`0;2`/03@d>00l?4@0K6ad03@d@028Q9P0000@020L<01<B5`0B4Q@04a<C00l?3`0;2`/030`<
010@40804A4A00D02@T900X:2P0=3@d02`/;00h=4@0300h=4P0E00`;4@0;2Q002@P>00h=5@0510`0
2PTA00`:5@0:21<04PlI00/:4P0C4a/02P`A03a1A@0731002a0C00`@4@0;3a003@d?00l=400@4180
4Q<D00804a@F00/0NW]m09RIV`0;30h0414E00h?4`0?41804A8F00d>4P0<3A403@hB00h?5002010A
5@09014B5`0@4AH03a0D00l@5@0@4AH04A8F014B5`0E5ad02@`C008041<J00D04aHM01PK8P0>4AP0
41<J01@G7P02010C6P0801<F7@0A51T03a<D018F6@0D61/04aLJ014E600A51P6014D6@0[018F6@0A
5AT041<H010D5`0?4QH04QDJ00hB5@0=41@04QDJ01@H6`0?4aL04a/M010J6`0@6Qd04Q/R014J8`0;
4al04QXW00`D8@0A6BD02a@M00`E7P0@628041@M01/P9P0R9bd0=3To07AiO`35b]00CU=I028W;@0D
6Al061dS010E6`0B5ad03Q<G01HK7`0?51P06QlS018G6`0H7B406QlS00@93P0200lD6P0;01@I7`0A
5Q`030lF01PK8P0D5ah05APO00X=500J7B@03a8I018E700D5ah00P0B5A`04`0C5Q/02@`A00/?4`09
3A003Q4F01DI7@0@51L03a8G00lC5`0?4aH041<H010D600@51L02PhA01HJ7@0>4Q<020`?00hB5@0B
5QT00`0@51D02`0A5AD04ADF014E5P0I72803Q4H00lB6@0B5A`041<J014D6`0B5A`04A@K00803A0G
00<06QdT02<V;@0H6b@00P0=41T0900<3aH051LN010C6P0R9BX0Wj:W01lS9P0>4QD01@T<01LL7`05
30h051`O00lG6P0G728010PA00L;500B5Ad03`lG014B5`0B4aD04Q@C010C4`0<41402Ph?00lC500B
5QL03A4B00P<3@093@h03A4B00T=3P0?4a@0310A00lC5@0A5AP04QHI010D5`803Q8E0P0?4aH01P0@
51L04ADH010D5`0>4QD02`lA00`@4@8061`M01X041@E00hB4`093@h02`l@00dA4P0<41403A4B010D
5@0G6a`04ADF018F5`0M8B80720Q00`@4@0@51D02Ph?014E5P0H71d041@E00`@4@0?4a@0310A00hB
4`0H71d0720Q01@H6@H03A4B1P0?4a@2010D5@0T01DI6P0;3a004QHG00`@4@0<4A@051TL01<H6`0=
4QD04AHI00`A50000@@051TL010E600A5QT0B4e@00lD5`0;4A403Q@D00dC4`0;4A40318B010F5P0=
4a<04ALG00/A4@0?5AD0318B0826QP0h?S`04QPF00X@3P042PP01`d;018H5P0?5A<03Q@B0P0=4a40
4@0>51803aDC00/A4@0<4Q802Q0@00dC4`0H7Qh02a4A00dC4`0D6QX01@/;00hD500B61P03A<C01HL
6P0C6AL03Q@B00803A<A00D02Q0>00dC4@0>51803aDC010F500200lE4`0300`B400?5A<04ALE0080
2a4?00D04QPF0498AP073@/051XH00lE4`0201@J60804ADD00@06QhM02/_;P0j?Sd05QXI0P0>4Q40
3@0=4A004ADD00dA400;3`h0310?00@81`093@`03A4@00T=300@51<03A4@00T=300;3`h00P0>4Q40
100C5aD08RLS01`Q7@1;D4`2010E4@0300L<200<4@d0314=00<03Q<?00@03Q<<00dC2@0=4`T03A<:
0P0=4P/01P0>4`d05AXD00dB3P042@D05AXF00`A3@803Q0;0P0?4@`02P0>40/03@l:00`>2@0>40/0
4A<>010B3@0>40/02P`700L<1@0;40T200dB300H00lD3P093PX00080018G4`0:3Pd041@C00hB4@0<
40l041DA00@91@0F6aL041DA00<8100=4Ph00PL300lD400320@03A8>00X?2`0320@04A<>010B3@0?
4@`03Q0;0P0?4@`2010B3@0_00lA300>40/03Q0;00h@2`000@00DeE@000100082PD061XE010B3@0E
5a804aD@00P:1@092`H0418=00T;1P051`@02P`900`>2`092`P04aDA00d?2P0/;bP06A`E00T<1@0:
3@@03Q4800`A2P094@/0@DY501LP6`0C6AD00@L300`B3P0:3`/03@l<00h@3@0@4Pl04A<@018D4@0Y
;B`07b<R00X>3@0=4A002Ph=00L;2P0>4Q400P0<40l0100>4Q403A4@00dA400>4Q42010D4`0300hB
4@0<40l0310?00H0310?00`020`;00lC4P0C5aH04QHE01@H6@0@51D061`M01/O8P0A5AP0D5AG05II
GP0A5AP201<G600:00dA4P0C5aP04QHG010D5@0E6AX041@E018F5`0830d0310A01TM7@8041@C00H0
4ADD00`@3`0:3Pd02Ph=00`@3`0>4Q4200lC4P0300hB4@0=4Pl0314=00802a0<0P0<4@d0100:3`/0
1P/700lD400E6QH200dB3P0b00@81`072`X04AHB00H;1`052PH00`H201dR700F6aD041D>00`A2P08
3@H02Q0600hC3@083@L041D?00H;1@0>4`d03A8<00H;1@0A5Q0041D?03<h<P0W;2H01``600@90`0@
5@l02@d:0004000D6A<02a0:00T>200730D05AXC00lD3@0;40T010T300L<1P0>4`d02Pl900lD3P0;
40X03A8<00@90`0;40X01``601DJ500:3`T0314;00/@2P0=4P`300hC3@0400`A2`0:3`T02a0:00`A
2`<03A8<00H02a0<00hC3`0>4`l0314=00dB3P0>4`l200dB3P0@00`A3@0=4Ph04AHB01@I5@0;3@P0
1@L200X<1`0<3PT020X501LI500A4`h03@l:00X<1`092`H0418=01DG4P806b0L00L010T500<71006
2`L01@X600/@300@5A403Q<?00803a@@00D02a0<00X?2`0;40`0314=00hC3`0200lD400806EZIP0C
61@03Q<?00T>2P0G71P030l;00`>2@0=3`X2010B3@0F00lA300A4`h0418=00d?2P0<3PT03Q0;00lA
300B614082LP00/B2`0G7QL02A0900890P0D6a@03aH?018I4P0940T051/D028Y8P0I7aT00PL300lD
40804QLC00@06QlK00P=2@062`L05AXF0P0>4`l00`052PH04aPD00lD400200dB3P0J00hC3`0?5100
1``801`Q7@0J7a/04AHB010E4@0C61@04aTE01DK5`073@T04aTE01LM6@0?5A402@l;00dC3`0@5Q80
3A<?00`B3P0;4@d02@h:00dB3P0?51004QLC01PM6@0K81`3010E4@803a@@01T03Q<?010E3`0D6A<0
3a@@00L<200D6AH00`L600H:2@0>4Q807R8S01XN7`0;3a404aLJ04eBEP1RIfX03a@G00H;3P0?51H0
:c4a09:HV00Z<2l0318@014G5@0?5A<05Q`J01Cooooo000Kooooo`802`/900/030`:00`<300;2``0
2`/=00h=4P0<2a0040lD01HE6`0G5Q`02PT>00d=3`0200X:2P8030`<00P02@T9014A4@0A4A402@T9
00X:2P0=3@d02`/;00h>40803PdB03l03@`A00/:400:2@l03PdE00T74P0=2aH04@lJ00h<6@0S8B`0
3``G00h=5@071`l02P`C00462P000`L02PlB00lC500@51D0410@00l=3P0>3Q002PX<00l@500=3Q80
824U01TJ70061`T04A8D00d>400C5A@07QlQ01/L7P0A4Q@03@h@00h?4`0?41<0414C010A5@0@4A@0
3a0B00l@500@4A@0414C010A5@0?4AL05QTR014D7@0D5b003Q4J00`?600A51d04QDN00hA6P082a@0
3Q4J010C700>4AL03a<F018E6P0D5a`04aHK014E600@51L01@0?4aH0>00B5QT04aLH018F600B5QT0
41@E014E5`0@51L03Q8C00hB500B5QT04aLH010E5P0@6AP03aLI00`D5P0:4AT02a8L00dC7`0@5R@0
3A<Q01@J9P0<4ad03A@N010G8@0L82T05ATR01<G800G6b@0;c<l05QLI@0T:3406QhW01LK900:3QL0
51PQ01PL9@0;41H051TO00X?5@0@5A/05AXP01@I7`0B5a/05Q/O00`A5@0>4aL05a`P00dB5P0I7240
3A0E014D6@031P/041<H01PK800=41D04A@I0`0C5Q/05`0E61d0310C01XN800B5QL0720S03@h>P0V
:R/04aLJ018F600A5AH041@G00lC5@0>4Q<03a<D00X>3`0>4Q403a<D00`@4@0C5aP03a<D00lC5P0@
51L04ADG00804ADH00@071lW00lB6`0@4a`04aHO0P0A51d0;@0B5Ah04A@M00d@6@0>4AX06ahW02@W
<0092aL03Q4J018E7P0<3aP04aHM00P;4P031P/06QhQ0001100A5AL051PI00H;3P0A5a`01PdE0089
4@0F6RD041@O01dQ;00=41X03PhF010A5@0F5aT061XI01@G5`0;3a002@d>00lC500A5AH03A4B00X>
3`011@H05QXK018F5`0E6AX041@E00lC5@0B5QT04aLJ014E600200lC5P04010D5`0>4QD03Q8E00dA
50802`lB00@04ADG00020`000@803A4B0P0?4a@02@0=4A804QHG014E5P0>4Q<02Ph?00dA4P0A5AH0
3a<D00dA4P02010D5@0=00P<3@0B5QL02`l@00lC500D61T03A4B00hB4`0A5AH041@E014E5P0?4a@0
2`l@00T=3P0600dA4P@03a<D0P0@51D08P093@h02Ph?01<G60093@h041@E00lC500;41<041DH00X?
4P0>4aH041DH01<H6`0D6A`020d@00T>4@052Pd03Q<F01PM800;4A403aDE00hD500;4A40318B014G
5`001PH02a4A00020P083Ph02Q0@02/a<@0M8b4020h<018H5P0?5A<200X@3P803A<A0P0<4Q0200dC
4@0E00/A4@0B61P01`d=01`R8P0]<c<04ALG00/A4@0D6QX02Q0@00/A4@0=4a<0318B00`B400>5180
2Q0>00`B400@5Q@03A<A00`B400=4a403Q@B00<03aDC01d02a4?01TO7@0L8R003A<A00H<2P0<4Q00
5adK00dC4@0C6AL01@X800X@3P0>518041<B00T=30000P4061`K00/?3P0:3Pd04ADD00`@3`0:3Pd0
310?00L;2P0830/02@d<00L;2P0A5A@03Q8A00D9200200`@3`0;00P<2`0;3`h03Q8A00dA400=4@l0
4aPD00P=2@0g?3P020d9018G4`0=4Ph00P0<4@d0100=4Ph03Q<?00lD400?50d200hD2P0<00dC2P0=
4P/03A8;00`A2P0B5a403a@@00@91@0@5A402Pl;00/=200<3PT03Q0;0`0?4@`07P092`H02P`700d?
2P0?4@`03Q0;00d?2P083@H02Pl800/@2P0=4P`03a@>00T>2P0P9B403a@@00hB4@031`H051PG00/>
3@0=4Ph020d900T>2P052PH000D100lD40062`L04AHB00dB3P0E6QH020d900lD4080418=0`0>40/0
0`0?4@`03Q0;00h@2`0200h@2`0Q00d?2P0<3PT04A<>018D3`0>40/0418=00X;200C5A002`d801@F
4@0>40/0418=01TK5P0B50l03@l<02<U90041PD04A<@018D400;3@P0:B`U01LJ4P072P4020/200`?
1@0;4@L031@>02L`:`012PD0=cdi00`B3P0@5Q802a0<00803@l<0`0>40d201@H5`0;00D9200=4A00
3Q8A00/?3P0=4A002`l>00`@3`0?4a803A4@00/?3P0=4A000P0A5A@00`0>4Q403A4@00hB4@0600`@
3`0<00/@300=4Ph03a<A00hB4@0A5AH03Q8D00hB5@0A5AP01PX>030c>00e>3d020`?0P0D61T00`0?
4a@05ATJ01@H6@0200dA4P0900P<3@0=4A802`l@00T=3P0A5AD03A4@00hB4@0=4A00310?00802Ph=
00H03A4@00lC4P0A5A@041@C00lC4P0=4Pl200`A3@802a0<00<03A8>00`A3@0:3`/00P0C61@0:@0:
3`/041DA02@Y9@0;40`0314=018G4@0@5@l04AH@00hC300:3`P020d600T?1@083P@03Q@:00X?2@0A
5Q0061dG0046000=4P`03a@>00`A2`0C61800`P201/P6P0E6Q@02Pl9010E3`0320404aPB01PM5P0D
6A802Pl901<H4P0=4P`04AH@00T>200<4@`02a0:01<H4P0:3`T000D000802@h800L03Q<=00<80P0G
71H02@h8014F400;40X01``60080314;0P0:3`T01@0<4@/03A8<00X?2@0;40X0314;00<03A8<00<0
2a0<00hC3`0>4`l00P0=4Ph00`0?51003A8>00dB3P0200`A3@04014F4P0E6QH07b4L00`>2@803Q0;
01405aTD00lA300@4Pd05ALB00`>2@0>40/051HA00h@2`1_M700P8F101DJ5P0G71P01P/701HK5`0<
4@d041DA00hC3`02014F4P0X00`A3@0>4`l02a0<00X?2`0=4Ph04AHB01<H500A5Q8041DA01lT8006
2`L03a@@00d@300>40/03a4<010B3@0>40/030h9010B3@0E5a804aD@00h@2`0?4@`061XE010F3`0D
7QH02Q@<00@>1P0c?CD0BeE=018L500C7AD07BLO00lI4@0A6a<07bTQ01XP6P0;40`03A8>01<H5080
5AXF00D0314=00T>2P0B5a<03A8>01<H500200lD4007010E4@0?51003Q<?00lD400B5a<03Q<?014F
4P0200dB3P0E00`A3@0/<Bd03Q@@01HL600?5A402Q0<00/A3@0<4Ph02a4=00lE4@0G7AT061hJ01<I
5@0=4`l04AHB01<H500@5A403Q<?014F4P0@5A404AHB008041DA00<03a@@00hC3`0>4`l00P093PP0
0`0<4@d041DA00`@3P0200H:2@0A010D500=4A801`/<01PL7P031`X0?T=705]PH`0?51L02@hA01@J
6`0b>3P0aL_;03Pn?@093`d05Q`J014G5@093`d05?ooool001_ooooo00l030`900/<2@0;2`T02`/;
00/;300<30h01`L;00h=4P071P`030/A00`<4P0@3aD02`/=00X:2P0<30`00P0?3`l0200:2PX03Ph>
010@400;2`/03@d=00h>3P0;2`/03Ph@0`0>3A8200`;4@0L00`;4`0?3AP06QPS00l=6@10?T/0ZZRe
01PE800@3aL02`/C01<E70000`L04aPL00T>4@0@51D04ADF018B4P0?3@h03Ph@00X:3`0@4AH020T>
014B5P041@L07b0R01@F5@0?4A00418@01<E4P803Q0>00H04A<C010B4P0?4A403@h?00`=3P0>3a03
00lA4@80414B00H03Q0E01XM9P051a003Q4J010C700?4Q/300hA6P0:010C700B5Ah03a8K00hA6@0?
4QP041<I014D6P0A51T04ADH010D5`8041@E05/041@D010D4P0@51@04QHF010D500B5QH04aLG014E
5@0B5QH03A4A010D500C5aL04QHF010D500B5QH04ALF01HN700F7Ah03aDK010E7P0@5R003a@Q00hC
800C62@03Q<N01<I8`0D6B<051PQ00dA6P0E6B806AdV01XN9`0G6b@061`U018F7`0@51d05QXS01PL
9@0B5Ql051PR01LK9@0_<c`04QHO01LL8`0D6Al02PlC014F6P0C61/02@hB01TN800E6a`04A@H01XN
8P0>4QH0=cXn01HI7@0E61`04QDI01<G6`0B5QX041@H018E6@0D61/041@E01DI6@093@d02`l?01DI
6@0;3`l05ATI01@H600A5AD03a<C00dA4@0;3`h04AHC00dB3P0F6QP05a`I00lC4P0@51@03Q8C00hB
5@0?4aH041@H014E6@0A51X06A`T00lB6`0@4a`04A@M00803a8K04003Q4J01<F7`0D5b004QDN010C
700A51d03a4M00lB700=41X06A`U05AGGP1MH6L04aHK014E600F6Qd020`=00dA4P083A00314J00hE
800<4Ql07b8b01dP<00>4B006Q`Y01PH8P0?41@03a4@010B3`0?4Q003A4B00`@4@0>4Q<03a<D00hB
4`0@51D02`l@00lC500E6AX041@E00hB4`0>4Q@03a<F010D5`0>4QD0310C00dA500>4QD03a<F010D
5`0?4aH03Q8E014E600n@T@09b//00L92P0C5aP0310A00T=3P0>4Q<05a/L014E5P0=4A802`l@0P0=
4A800`0?4a@03Q8C00hB4`0201<G600<00/?400>4Q<03a<D00/?400:3Pl03a<D00`@4@0>4Q<051PI
010D5@0=4A806AdN0`0>4Q<200dA4P0300`@4@0>4Q<03Q8C00803a<D0P0@51D0500E6AX02`l@00lC
500?4a@05ATJ00dA4P0A5QT04AHJ03Ll@00;41@051TM00hC5`0E6Qd0:2d`00/@500?51P03Q<F00hA
500@5QH03aDE0`0=4a<03P0>51@041HF00hD500D6QX03Q@D010F5P0:3Ph04QPF00X@3P0A5aD03A<A
00hD4P0;4@l0318@100=4a405`0<4Q0020h>00dB50062`d05adN02T_<00C61X02a4B00T?400E6a`0
4QPI00/A4P0<4Q804QPF01/Q7`0B61H0318@00dC4@0:40h0318@00dC4@0>51803A<A0080318@00D0
3A<A01PN700L8R0041HD00P>300200`B400Y014E4`0T:RP06R0N00hD4P083P`03Q4@00`@3`0B5QD0
CE5@01@H5`0:3Pd04QHE00L;2P0H71/05a/J00D9200=4A003a<B01<G5P0T:2L06AdL00T=300<40l0
2`l>00`@3`0=4A00310?00/?3P093@/04AHB00/@300A5Q80314=018G4`0;40`03A8>00`A3@0;40`0
314=00dB3P0>4``00P0>50X02`0=4`X03A8;00`A2P0<4@/02a0:00/@300:3`/02a0<00hC3`0<3PT0
3@l:00@03a4<01h02P`700/=200<3PT03@l:00h@2`0?4@`02Pl800dB2`0;40X02Pl900dB300<4@d0
1PX702L/:00@51<03A4@00/?3P0<40l01P/701@I5@083@T05Q/G010E4@0<4@d00PD2014F4P0:3P/0
41@@00/@300:3`/200`>2@0500d?2P0>40/04A<>018D3`0?4@`00P0>40/08P0?4@`03Q0;00X<1`0B
50l03Q0<018D3`0=3`X04aD@014C3P0>40/04Q@?00d?2P0;3@P04A<>01@F4@0U9bH0;Bl^00X<2`0D
5Q<03Q0<010B3@0A50d03a8:00hA200?4PT03a8800X@1P094@/03aDA03Ho>P1DFUH04ALC00L=2@0=
4Ph200h@3@0E00d?300<3P/030h;00dA400@51<02Ph=00hB4@0;3`h03a<B00hB4@0;3`h0310?014E
500=4A002Ph=00/?3P0@51<03a<B00/?3P0<40l03Q8A00H03A4@0P0>4`l01@0=4Pl03A4@014E5P0@
51H03A4D00804QHJ00D020/@00hA5`0>4QH03A4B00hB4`0200lC500400hB4`0D61T092PY01hR8`80
4ADF00D02`l@00/?3`0?4a8041@C00`@3`0200hB4@0400`@3`0=4A003A4@00hB4@803a<B00L03A4?
00`A3@0>4`l03A8>00/@300=4Ph02a0<00802Pl;03D03A8>00lD400?5100C55=01hS7`0:3PX04AH@
010E3`0:3`T051TB00lD3@0>50/0318800T?1@0;4@L03A8<00T>200<4@/04AH@00hC3@0?50h02Pl9
00dB300;40X04aPB00dB30093PP041D=00lE2P0=4`X02a0800hC2`0=4P`03Q<=00/@2`0A5Q403A4?
018G500=4@l02Pl:00lD3P0G71H08BHP014F400:3`T04aPB00`A2`093PP02a0:00hC3@0?50h03Q<=
00dB300200/@2P802Pl900<0314;00dB300=4P`00P0=4P`0100<4@/03A8>010E4@0?510200dB3P03
00lD400=4Ph03A8>0080314=01<03a@@018G4`0X:RD06adH00X<1`0?4@`05aTD00X;200>40/03a4<
010B3@0>40/03@l:00lA300f>cL0>Chj018G4`0:3`/04aPD00803a@@01403A8>00hC3`0<4@d02a0<
010E4@0A5Q80314=00X?2`0=4Ph04QLC01@I5@0H7AT02@d:00/@300=4Ph04QLC00lB3P02014C3P0:
010B3@0=3`X02`d800`>2@0>40/03a4<00`>2@0?4@`061XE01LM5`802aD=01P051hF09nYX@3?fM40
6B<K00lI4@0M9al0628J00/E3@0>61002a<=018G4`0>4`l041DA00/@300730P051TE018G4`0@5A40
51TE014F4P0?51003A8>00lD400A5Q8200lD400=018G4`0>4`l03a@@010E4@0D6AD02Pl;01HK5`0A
5a<02a4=00`B3P0>51004ALC00lE4@0200dC3`0=01DK5`0H7QX04ALC00/A3@0=4Ph041DA00dB3P0:
3`/03A8>00`A3@0A5Q8041DA00lD400200dB3P0E00hC3`0=4P`041D?00lD400I7QX03Q8@00hB4@0@
51<04ADE05YNG`0L82402`h@01TM800=4AD041DI01LL7`0@5AP03A8C00lE5@0P9RH04aTH00803Q@B
00<03A<A03@j>?ooool04oooool001_ooooo01X04Q8@00d=300820P020P800d=3`0B4Q@03@`A00<2
200K6R000`8800P73@0D4aT030`>00l?400>3Ph02PX<00/;300A4A402PX<00l?400<30`03Ph?00l?
4@0;2`d03@d?00d<4@803PdB03003@`B00`;4@092@l02PTA00<22P081Q4030XE03Hd?`0B4AP01PD;
01LH7@0520d05APM00462P0;3a80310C00h?4`0=3@l03`d@00l>4`0=3A@020T>01TJ7`0@4AH01@H:
01TJ7P0A4Q@05ALF01<E500<3P`03Q0?010B4@0>40l03PlA00h@400>40l03PlA00l@4@0?4A003a0B
00lA4@0?4A003a0B014C5P082a805aXQ04E8C`0<3aH2014D6`803Q4H00X04A@K00/>5@0<3aH04A@L
00hA6P0>4AP03Q4G00lB5`0@4aP04ADI0P0A5AP4014E5P0E00`@4@0@51D04aLH00lC4P0B5QD02`l>
018F5@0G71P04AHB00hC3`0D6AD04ALE01LM6`0E6a/041DH01<H700C5al04QHO010D7@0F6R<051PQ
00807R<Y00`04AHL01<H7P0>4QX020`E01HK8@0B5ah03a<L024V;00?4a/04QHO01XO9@0A5Ah201PL
9@0/05YNIP0H7B<02a0E00dB5P0J7b804AHI00X@400L8R8010T901LK700D61/01`P<01HJ7@0_<c@0
;S8c01TM7P0H71d05QXK014E5P0>4QD0414E01<D600C5aP01`/;014E500B5QL0310@01XN7@0;3a00
310@00dA400?4a@041@D014E500D61L06b0L00`@3`062PT041@F014E600=41D03Q4F00hA600@4aX2
014D6`1Q01LJ8P0C4ad04QDN014D7@0?4Q/04A@M010C700>4AX03a<N01@G8P0E6B@051PQ00`?5`0N
8BP06QdT00d@5`0a=3/0;S4f00d@5@072Pl051PK010D5`0830l03Q4F00H;5@0K7bX020`H020T<@0h
>dX02@dI01@G8P0F5Qh03PlC018D4`0E5a@04QDD00lC500?4aH03A4C00`@4@0?4aH02`lA01PL7@01
1@P041@F010D5@0:3Q403Q8E00lC5P0@51L03Q8E00`@4`0=4A@02`lB00`@4`0?4aH03A4D00X>4@0;
3a803Q8D01HJ6`0I7Ah02@d>018F5`0F6Q/02`l@01PL7@0<41403A4B01@H6@0F6Q/020`?00/?4P09
3A003A4D01@H6@0?4a@01`/<01DI6P0G6a`02`l@00hB4@0C5aL04QHG010D4`0@51@02`l@00H:2@0A
5AD03Q8C00hB4@0>4Q803A4B00`@3`0<4100310A00dA4P0200hB4`803a<F01D020`?00T=400D61X0
20`=00X>3`0A5QL03A8E03<k?@2PZ:X03ADH00lG6@032`d010T=00lD60001@P061dQ010E6@093Q40
51XJ00hD500<4Q800P0>51@03`0:410061hN04mEE@052`/06R0P010F5P0=4a<02Q0>00dC4@0?5A<0
20h<014G5@0<4Q003A<A00hD4P0200lE4`0C00hD4P0=4a4051XJ00`B4`0@5QH01``>00hC5P0@5QH0
4AHH0005200S:BT09BX/01DJ7@0B61P02@l=01`R800C6AL02a4?00dC4@0400`B400700XA3`093`d0
1Pl<00`B40052`T02@l=00dC400200`A3@0601@I5@000P006QhM00/@3`093`d04aTG0P0>4Q402@07
2`X010P700/?3P0@51<03a<B00dA4010A4<0=c/j00P<2`0200`@3`0600D9200A51<02`l>00D9200<
40l02Ph=0P0?4a803`0:3Pd02@d<00dA3`0320@02a0<00lD400:3`/00PL300hC3`0=4Ph02a0<00X?
2`093PX02Pl;00`B2P0200dC2@0900`B2@0;40T02a0901HK5@0A5Q802@h:01<H500;40`041D@00<0
418=02<03Q0;00d?2P0;3@P04A<>00lA300=3`X02`d800d?2P0@4Pd03A8;010E3P0<4@/01``600X?
2@0=4Ph051TE00T>2P0:3`/041@C0002000?514020d900/@300E6QH0EU]G00hC3`0<4@d02a0<00lD
40052@D05a`H014F4P0<4@d0418=00lA300200d?2P803Q0;00T04A<>00lA300?4@`04Q@?010B3@0:
30L04Q@?00h@2`0@4Pd00P0A4`h00`0B50l04aD@010B3@0200h@2`0801/M600];bX03a4>00@50`0K
7AX051D@00`>2@0>40/200lB2`0;00/>1@0:3@H03A07010F300=5@l05A/G00P>2P093`/020h:00`B
3P0=4Ph01@0?4@h04@0@51<03Q8A00hB4@0>4Q402Ph=01HJ6@0>4Q402Ph=00`@3`0A5A@03A4@00P<
2`0>4Q404QHE010D4`093@`02`l>00L03Q8A00l02@h:00`A3@0=4Pl0310?010D5@0:3Pl05ATL00dA
500830l06QhQ00lB5`072`h020`=00T=3P0A5AH00P0;3a001`0:3Pl0720Q01XN7`031`P03A4B00lC
500<41000P0@51<02`0:3Pd03A4@00`@3`093@`02`l>00X>3@093@`02`l>00`@3`0;3`d02a0<0080
3a@@0P0;40`03P083@T0314=01@I5@0U:RH0:c0/014F4P0>4`l03A8>01DJ5P083@L01``600dB300@
5@l0314:0P0>4``0;00;40T0314:00X?2@0K81X041D?018G4@0?50h02a0:01HK5@0:3`T02a0:00L<
1P0:3`T051TC00lD3@0=4`T041H<01LL5@001@002a09018G4@093PP020d900D:1P0?51402@d<00/A
3@083PX01@`500/B2`0<4``07RDM051GD00B6A8061lH018I4P093`/041HB00dB3P0@5A004QLA010E
4@0:3`T01@X40`0=4P`01P0<4@/02a0:00X?2@0>4`d041D?00lD3P803A8>02403Q<?00`A3@0=4Ph0
314=00X?300;3`h03A8>010B3P0=3`X04A<>01HH4`021000<S@_02DW8P082PD04aD@00`>2@0E5a80
=SPc018G4`0?5100314=00dB3P093PX03Q<?00`A30093PP041D?00`A2`0>4`d07B8L014F4P0?5100
0P0>4`l08P0?510041DA010E4@0A5Q802Pl;014F4P0;40`03A0<014C3P0@4Pd03a4<00h@2`0=3`X0
418=014C3P0?4@`0418=014C3P0?4@`020h701<M5@042`@04Q/C00LA2@0Z<BX0624I00H@200;4P/0
4ATB00TC2`0?5Pl03aH@00hC3`0A5Q8202`a;@0A01PM6@0=4Ph03a@@01LL600_=3003A8>00H;1`0?
51003A8>014F4P0?51003A8>00lD400:3`/04QLC00/@300@5A400P0B5a<0400A5a<0318>01LM6@0=
4`l01P`800hD400@5Q80318>00lE4@0A5a<02a4=00T?2`0?51004AHB00lD400=4Ph2010E4@03014F
4P0@5A403A8>00802a0<01T0314=00/@2P0K81X02Pl;010E4@0A5Q<0310?018F5@0>4Q808RHW00D9
2P0E6A/01@T<00@93@0D6Ad04AHI00/@4`0J7b406b4Q00/A4@0A5aH01@/901XP7P0<51404AXG01Co
oooo000Kooooo`0J00L72@0:2P`030`>00h>400510T05QDJ00T83@071P/0000400T83@0B4AH00P46
018A5P0<2`l03`lA00d<4@081`/04Q8D018A5P0:2Pd03Ph@00`<3`0:2@h040lD00d<4@0?3Q<4010?
508040lE01403PdC00/:400;2Q002``@00T;3@0>4Q<02`l@00T=400;3a800@D800d>4`0;314030/A
00l>5P0@3aL03`hF00`<500200h>5P1C00l?5P0<3A802``A01HG700:2a003PlD00l@500;31404A8F
01<D5P082@d030d@02DV:00H6Ad03PlB00d>400=3Q803PlB00l@4P0?41@04A<G00P<3`0F6Qd0<3@g
00`@4`0010L05ATL00041`0:3Q4061`O00/?4P0>4QD05APN00X=500C5Qd04A@K01@G7P0N8BP04A@L
014D7@0B5Ah05APQ01<F7`0@4a`05APO00852P0D5a`051PK01<G600B5QH03a<B01HK5`0B5a405a`E
01PM5P0<4PT04ALC00`B400:40h03aDE018H600?51H0:c0c01XO8P0:3a8061dP00P>3P0H7Al04QLK
01@I7@0A5Q/04AHL01DJ7P0B5a`04QLM018G6`0A5Q/03Q<I00hC5`0@5AX03A4D010D5`0E6A/00P0I
7Ah0;`0G6a`0EUYK01@H6@0=4A003Q8A018F5@0010D05aHK01DD6@0>3a405aTH024V8P0F7AH04APA
010E4@0@4Q40414C014@5@0?3Q<0414E02DY:`1=DE80720S018F600D61T04QHI01@H6P0A5AH04aLJ
01PL7P0E6A`00`L:018E6009314082<Z00lB70092aL03Q0L00L95@0O8Bd02@XF01DG8`0]<3T06ATP
01TH800D51`04Q8J00804QDN00T04ADP00hB7@0N930020dI03ToB`0?5R005AXL00L;30072`h00P0@
51L09@0<3a@04A@I00hA5P0@4aX03Q4H00d@5`0@4aX05ATN01HI7P062@h02`hC01HI7P0?4QL041<G
00T=400E6A/00PH7014E500=4A<03A4D014D6@0>4QH051PK00852P0;3a<03A4D00lB5`0@51P03a<F
00d@5@0=4A@020`=00`@4@0E6AX0004201@H6@0A5AH00P0@51D2014E5P03010D5@0B5QL041@E0080
41@E02D01`/<01/O800N8R<05QXK00lC500=4A80310A01PL7P0:3A803Q4H01PK800@4aP03a<F00/?
4P093@h04ADF00lC4P0:3Pd041DA00lC4@0@4Q403a4>00lA3`0>40l03a4>010B400C5A@01@L400lA
3`0F61L04Q@A00lC400>4Q4041HD018H600E6Qd03a@H00803A8H01l041DK010E6@0<4Q803A<C01DK
6@0:51<05AlO01XT8`0D7Ql02aDE00TC4P0;4aD05AdN00L@3`063Q004API00D;2`0;4A404aTG00lE
4`083P`02a4?00lE4`0A5aD07bDS00X@3P0;4@l03aDC00D;2@0;4@l03Q@B00802Q0>00@03Q@B00/A
3`0D6QP03A<A0P093`d03P0:40h03A<A00L=2`0>51<02Q0>00X@3`0?5AD04ALE00hD4`0A5aL03Q@B
014G5P0B61P0318@0P0=4Ph05P0B5a<03a@@014G5@0?5A<02A8?01<L6`0=5QD01Pl>00TB4@084Q40
31DD00050P0?5A<020`700`>2@0I6aH0414<00lA300?4@h041<B00dA4P0?4a@600dA400601LK6P08
30/0=SXi01dQ800010<03A4?0`0=4Ph00`0<4@d03Q<?00hC3`0200`A3@0L00lD400@5A404AHB018G
4`083@T04aPD00X?2`0320@04AHB00`A3@0:3`/0314=00X?2`0M8Qh0?dA000H<10093`<0318800lD
300>4`d03A8<00X?2`0M8Qh020d900P=1`0D6A<04AH@00H;10804aPA00D02@h700hC300=4P/02a09
00`A2P0200hC300400`A2P0:3`P02a0:00`A2`803A8<0P0<4@/020062`D04QLA00T>200>4`l02Pl9
00dB3P093PX02Pl;0P0<4@d01@0:3`/01``800hC3`0>4`l03a8?00<02a0<02X02@h800hC3@0C6180
3Q<=00T>200@5@l020d700hC3@0?50h02Pl900`A2`0C61806b0J00hC3@0E6Q@02a0:014F401HGEL0
SY>=02DZ900E6Q@0314;014F400B50l05aPB00X:1`0H6A<08R4L00d>200F5a402Pd600`?200>4@X0
3a4<00dA2P0;40T02Q0900D:10093PP041D?00`A2`083@L200T>200700X?2@0?50h04aPB01DJ5P0<
40l03A4@00/?3P02010D4`0900X>3@0<40l03Q8A00X>3@0<40l03Q8A00T=300830/02Ph=00802`l>
00D02Ph=00T=300>4Q403a<B00hB4@0200`@3`0Q00dA400?4a801`/:00`@3`0?4a801PX900`@3`0>
4Q<05a/L010D5@0?4a@04ADF00P<3@0A5AH04QHG00/?400=4A803Q8C00T=3P0@51D00042018F5`09
3@h02`l@00/?3`0<40l03Q8A00lC4P0>4Q40310?00X>3@0;3`h03A4@00804ADD00@041@C00lC4P0>
4Q403A4@0P0>4Q402P0;3`h03a<B00030P0>4Q40DEED06mcLP0B5QD02@h:00X?2`0<4@d300dB3P0<
00hC3`0>4`d03Q<=00hC3@0=4P`02a0:00X?2`0=4Ph041DA00dB3P0;40`03A8>0P0:3`/300`A3@0V
00/@300=50d06B0I00<:0`0[<R/051/D00`C300:4@T02a8:00dD30001`0041L?00hE3P084@h01a0>
00L@2`084PX02A<:00LA1P0D7QD02A<;01<M5@0740/02a@B01XS8P0U:bT010P601DK5`0<4Q0041HB
00@:1P083PX02A0:00/B2`0=50d041L?014H400<4@X200hC300R00dB300:3`T020d700P=2@0;40d0
3Q8A00dA4@0:3Pl020`=00lD40083@T03A8>00`A3@0:3`/0:BhZ020U8@052PH07R<O024V8P0<4@d0
51TE010D4`0C5aH06AdL00870`0M8Q`010T300hC300=4P/03a@=018G400=4`T02@h700hC3@802a0:
00@0314;00lD3P0A5Q004AH@0P0;40X00`0?50h03Q<=00dB300600dB3080314;01X03A8<00lD3P0A
5Q0041D?00/B2`0=4P`03aD?010G400B5a4041H@00hE3P0?50h03Q@>00`C300<4@/03A<>00/A3@09
3`/03Q@@018H500?5A402Q0<00D;1`0O9B406AlK01@J5P803aDA00L03a@@00`A3@0<4@d03A8>00`A
3@0A5Q8041DA00<03Q<?00d02a0<010E3`0F6aD06AhH01PM5`0C6180314;018G4@0>4`d03a@>01@I
4`0F6aD07R<M00803a@@0P0@5A401P0A5Q804QLC01<H50000`002a0<01/P7080314=00D02A0901`S
700>51000`T500/A3P0200hD4P0A010F5@0J820041HF00/A4P0B5aX03a8G01@G6`0@51L041DH01PM
7`0J82004AXI00`E4`094Pl02a@A00XD400540`05?ooool001_ooooo00<03`hC00`;400:2@h00P0?
3Q<01`0>3A802`X?024P9@0I61d02`X?00X93P0>3A800P0:2@h0300;2Pl030/@00h=4P0=31402`X?
014@5@0:2@h030/@010?500<2a003@`A00h=4P803`hC00<03PdB00d<4@0;2Pl00`0<2a002@0>3A80
3a0C02P];@0<41005a/K00d@4P0;310030dA00d>4`0200`;4P0600l>5@0?3QL03`hE00`<4`0>3aD0
4A4H0P0C51X03P0D51/04a@J00/;4P0>3QD0410G00d=500?41@030dA01`M8@0H6Ad0<34e00l@500@
4AD03a0D0P0@4AD2014B5P0400hA4`0<41403A4B010D5@<03a<D00X01`/<00lC500<41405a/L010D
5@0F6Qh02PdC00lB600F6Al03Q4G0P0E62005P0B51l04A@N010B7P0@4Ql04aDR01@F8P0H6bD03a8L
01<F7@0E61l04QDJ014D5`0=4A803A8@018G500=4Ph04aPD00hD4@0?5A@05Q`K01dS8P0K8B0200lE
500=01HL6`0?5A@02`l>01HL6`0=4a804aTJ01@J6`0@5AP03a@H01@J6`0C61/03a@H010F5`02014F
6@0O018G6@0D6A`05a/L01DI6@0B5QH041@D018F5P0D61P05ATI00/?3`0B5QH02Ph>014E5@0B4aD0
6APN010>500C4aD04Q@C00`B3@0A614051/E014F4P0E5aH071`N01/I7`0@3aD051DI00dA500P92L0
3a<F010D5`02014E600B01<G6P0>4QD03Q8E014E600=4A@051PL01LJ8018Be80EUQT00d?700E5bD0
4A<R00H85`0C5B@04A<P00d?6`0>4AX05QDL0P0E51/0<`0C4a/04A@M014D7@0@51l05adY01HJ9P0S
:CL0YJfj07b3S@0L82804QHF010D500@51H03A4D00T=400A51P03Q4G010C6@0?4QP03A0H010C6@0?
4aD03A4B01<G600<41403Q8C01`P8@0=4A802Ph?00/?400@51D02Ph?00dA4`0<41@04QHJ00/?4`0F
6Qh030lC00hB5P0=4AD03a<G010D600?4aL03A4E00lC5@0T:2T07B4R00dA4P0@51D02Ph?00lC5002
00dA4P0700hB4`0=4A803A4B00lC500;3a007B4R010D5@0200`@4@0[01HJ6`0B5QL02`l@010D5@0A
5AH03Q8D00lB600I7280FemT01/N8P093A404QHI014E5P0?4a@03A4A00lC4P0A5A<04AHC00hC400=
4a003A8?00hA3`0=4Pl03a<@010C4@0>51403Q<@00/>300E6aP03A4?00X@3@0B61H03Q@D00L:3P0E
6Qh0Ad]D00X>5`0<4AL03A8G00T>4@0:410041PE00dG5P02014M6`0@00/G5@0951<02aDD02hg=P0F
7ah04AXI014I600:410041HF01<I5`073@/04aTG00dC4@0>5180318@00dC4@802@l=00D06R0N03Hl
>P0A5aD02a4?00hD4P0200X@3P0=00hD4P0;4@l03aDC00`B40093`d02Q0>00dC4@0?5A<020h<00`B
400>518051XH014G5@0200X@3P0M00hD4P0;4@l02a4?00dC4@0<4Ph041D@014F4P0<4@d041DA00lE
4`0=4a403AHC00<<2`084A006B<R01<M7P033@h02aHE00/E500;51403Q<?010B3@0;3@L03a0;00/;
20092`T03A0@01HJ700;41001P0<40l01`052@P02@d<014E50031`H05QXI00X>300=4Ph00P0?5100
0`0=4Ph03a@@00hC3`0200/@300Q00`A3@0=4Ph03A8>00dB3P0;40`05Q/G02H[9`0@5A401``800hC
3`0;40`02Pl;00`A3@0F6aL0;34]00`A200:4080318800lD300>4`d03A8>02lc<@1fNWT04aPD01<H
4P072PH03a@=010E3P0I7QP05a`F00dB2`0?50h03Q<<00803A8<00<03A8;00`A2P0<4@X00P0;40X0
0`0<4@/03A8<00dB300200`A2`0900dB300;40X03A8<00hC3@0A5Q002`l:00dB3P0<4@d02Pl;0080
2@h:00P02a0<00P;200B5a<03A8>00/>2`0A5Q803a@@00hC3@801``601d04aPB01`Q6`0B5a4041D?
00`A2`093PP02Pl900hC3@0A5Q00EeaF010D400@5@l02@h801PM5`2FViD0b/o902/`:P0G71H07B8L
00dB300<40X0418<00h@2@092`L03Q0:010B30051`<03Q0:00lA3002010B3@0500lB3@0=40/02a0:
00/@2P0<4@/00`0>4`d02`0=4P`03a@>01<H4P0F6aD03Q<=00L<1P0A5A@041@C00/?3P0<40l03a<B
00803A4@00L03a<B00`@3`0>4Q403Q8A00/?3P0>4Q403a<B008041@C0P0?4a8200hB4@0F00dA400:
3Pd02Ph=00/?3P0<40l09BTX03Di>00D61L041@C00hA400:3Pd01`/:00dA400:3Pd0310?00dA4@0?
4a@041@E00`@4@0=4A803a<D00X>3`804ADF00P0310A00H92P0E6AX02`l?00hB4@0=4A00310?00dA
40<03Q8A100=4A00300>4Q403A4@00`@3`0>4Q403a<B00`@3`0;3`h05QXI00dA400F6QT07R8Q00hB
4@803A8>00<03Q<?00dB3P0<4@d00`0;40`02P0<4@d02a0<00/@300;40`02@h:00`A3@0>4`l03A8>
00/@300=4Ph200/@30<0314=02D02a0<00`B3P083PX0=C/g0:>YY@0M8al041L@00H=1@0A61003QD=
00`D2@0<50X02a8:00XC400;5A<02aD?00TC3@0950/02QD:00TD2@0=5Pd02Q<;00dG4`0=5Q@0R96@
05eSH@0E6aT03A<A00lE4`0L8Ql03Q@@00lE4@0>50l031<<00/B2`0940T020l7008041D=02@03Q<<
00dB300=4P/0314;00/@300<40h03A4@00dA4P0;3a402`l@00dA3`0C61@01`/702db;P1>Ddl03Q<?
014F4P0<4@d03Q<?014F4P0>4`l02a0<00lC4P0>4Q402@d<02``;00<4@/02a0:010E3P0>50X03aD;
018H3P0A5`/03aD;00dB2`0>4`d200lD3P80314;0P0?50h200hC3@L03A8<0P0?50h0100>4`d03A8<
00dB300>4`d200lD3PH03Q<=0P0?50h200hC3@0@00hC3P0;4@d02Q0<00lE4@0B61@03Q@@00`B3P09
3`/0:Bl[01TO6`0<4Ph03Q@@00lE4@0?5100314=00lD40804AHB00`051TE018G4`0@5A403a@@010E
4@0?51004AH@02<X8P0C618020d701DJ500<4@/200/@2P0501DJ500H7AL04QLA00dB300<4@d00`0=
4Ph300hC3`0301HK5`0=4Ph03A8>00804AHB01P06B0I00hE3P0A5a<01P`800lE4P0D6QP0@DM5014F
5@0A5aL03Q@D00lD5P0B5aX03A8F010F6@0;4A@02A0B00lE5`0A5aL041LG00`C4P094@h02a8@00`E
4@0:510Dooooo`006oooool02@0<2a0010<801<B5`0:2@h00`8701@C600A41D061LL01<B5`0200h=
4P0=00T83@0?3Q<05QDJ00X93P061@X030/@00T83@081``030/@00h=4P0B4AH03@`A00D42@0300d<
4@0300`;400:2@h02PT>00803`hC00/03PdB00`;400=31403@hB00L<3@0@51L0004403a0@`1ZJfl0
4Q<G00`=4@0200/:400E00h=4`0?3Q@03PdC00l@5@0A4QL04a@I01HG700H6Ah06AXO014B5`0>3a@0
414F01<D6@0A4QL02P/@02LX;00000@06a`P01<D600o@4@07QlS00803a0D0P0@4AD0>@0A4QH03Q4C
014E5P0@51D0310A01DI6P0A5AH02`l@00`@4@0H71d03a<D00T=3P000@8061`N00/?4P0;3Q<03a8G
00/>4`0@4aP04QDL00d@5`0<3aH04QDN01DH8@0B52009bTe05aNJ`0Q8c0051HS01<E8@0;3QP030lH
02P[=00;3QD03Q4F00442@0@4aL03a@G018H600J82407b@W01/Q8@0@5AL041DH018H600G7Ah04aPK
014G5`0@5QL03A<C00lE5@0>51@03aDE018H600?5AD04aTI018H6002014G5`0R010F5P0>51@03a<D
00hB4`0>4Q@04ADH01XN800P92D0720S01<G6@0;3a002`lB014E5`0;310051<K018@5`0B4aL03a<D
00dB4@0B61H03Q@B00/@3`0<41404a@H018@600:2A406AXO00/?4P0A5AP0720S01@H6`0830l02`lB
014E60803Q8E01804ADH00lC5P0830l07B4U00P;4P0=41T04Q@Q00P:5`0<3Qd02`dL00`>6`0A4al0
30lH01DH8@0C4QT04a8J01HE7@0F5Qh2010C700B00hB7@0<4Qh0/kW503HlBP0G7b`03aHP00`@4`0?
4aH04ADH018F6@0C5aX051PK00lC5P0=41D041<H00lB5P0<3a@03a<F0P0?4a@0400A5AH00PH7024U
9P1?De@04QHG00`@4@0;3a00<CDf00`@4@0A5AL03Q8E01LK7P0:3Q4051PK00dA500<41<200hB5@0;
00lC5P0>4QD03Q8E00/?4@0d>3T0=CTj018F5`0G6a`010P901LK700?4a@00P0>4Q<0B@0=4A803Q8C
014E5P0Y;Bh0EEUJ00lC500E6AX0310A010D5@0<41402Ph?01<G600I7Ah051PI00X>4@0C5aX03Q8D
00lC5P0<41<06AdP01LK700:3Pl020`=010D5@0>4Q403a<C00hD500=4a40318A00`B4P0<4Q003Q@C
00dC4`0F71X041HE00061P0:40h02Ph=00hD4P0D6QP0318C00021P042@d092P`00X>5`0<4AL0314E
00X?4P0:41003QDD00<=30074a402aLE00hJ600E81l07BLV0>_dl`1HHF0000T800H<300?5AD05A/K
01@J600@5Q@05Q`J00881P0A5aD061hL00P>300C6AL02@l=014G5@18CT`00P0:40h0<00>51802a4?
00/A3`0>51802Q0>00lE4`0@5Q@02a4?00T?3@0;4@l02Q0>00H<2P0<4Q003aDC01@J600A5aD02@l=
00hD4P0C6AL04ALE00hD4P0A5aD051XF018G4P0:3`/01``801HK5`0=4a40318@00TB3`084A002a@C
010J6@0=5aP0218C00<<300A7Ad031HE00L?3@0:3`/0418=00h@3@0>40l02Ph?018F600Y;S406AhQ
00`@40@0310?00@02`l>01@H5`021PD03Q8A0P011@@0100<4@h0314=00hC3`0>4`l200`A3@@03Q<?
00P03A8>00`A3@0>4`l02a0<010E4@0J7a/0314=00T>2P8041DA01402@h:00X?2`052PH020d900/A
200:4080318800dC2`0=4P`03A8>00X>300a=C@02@h:024V800C618010T200H;1@0200dB300;00T>
200<4@/03A8<00lD3P0>4`d02a0:00X?2@0;40X03A8<00/@2P0<4@/00P0=4P`300`A2`0E01@I4`0?
50h02Pl900H;1@0;40X03A8>00`A3@0:3`/02@h:00X?2`0<4@d0008001@I5@083@T0008000/@3005
2PH01``601PM5`0<4@/00`P200803A8<01T051TC010E3`0<4@/0314;00dB300>4`d03a@>02ld;P0:
3`T000@001hS7@062`D07b@N00`A2`0C61803A8<00hC3@0<4@/0318>00H<200<4Ph03A<?018H500=
4P`0314;00803@l:00P030h900/=200:30L01``600hC3@0:3`T01``600`A2`803a@>00D0314;00dB
300@5@l041D?00lD3P02010D4`0300dA400:3Pd0310?00803Q8A0`0?4a80100>4Q403A4@00dA400=
4A0400hB4@0300dA400>4Q403A4@00802`l>00L03A4@00/?3P0W:bX0F5aK014E50000@004ADD0080
1`/:0P0@51<0100<40l03A4A00`@4@0>4Q<200dA4P0900lC500C5aP04QHG01<G600A5AH01@T:00X>
3`093@d03Q8A00<0310?100>4Q4300lC4P0=00hB4@0;3`h02`l>00hB4@0@51<03Q8A00H:2@0E6AP0
1`/:01lS8P0I7A`03A4@00`A3@0300dB3P0300`A3@0;40`0314=0080314=00@03A8>00hC3`0?5100
2Pl;1@0;40`200`A3@0E00dB3P0<4@d0314=00/@300:40`04aTE00/A3@0D6QH041HB00P>200:4@T0
3QD=010G3`001`002Q8701@K4`063``031DC00`E40084@`0218:00803QP=00h02Q@<010J4P012PL0
31DC01HO7P0L8R001@/900lE4`0=4a403Q@A00T?2`0;4@d02a8<00/B2`802Q4:02H02Q4900lD3@0=
4P/02Pl800T>200:3`T02a0:00dB3P0<40h02`l>00/?400<41403A4@00@91@0;40`01P/7014F4P0V
:bL0008000X?2`0A5Q802@h:00/@300A5Q803A8>00D9200<40l000@3038g<`052P@04aPB00`A2P0:
40H02@l500`B200@5PX04AL=00hC30803a@>00T03Q<=00/@2P0:3`T0314;018G4@0A5Q003A8<00`A
2`0>4`d01@0=4P`300`A2`0500hC3@0@5@l04AH@010E3`0>4`d00P0=4P`200`A2`<03A8<00H03Q<=
00lD3P0@5@l03Q<>00/A3@0<4Ph2010F4P0:00`B3P0B61@05A/G03Lm>@0P9R803aDA01TO6`0G71P0
41DA00`A3@802a0<00<02Pl;01DJ5P0B5a<00P0?5102010E4@0<01DJ500U:R@041D?00L<1P0D6A<0
3a@>010E3`0=4P`041D?018G4@0@5@l04aPB1P0<4@d07P0320@0008002DZ9P1_M7008RLS00D91@0>
5@h00@P100hD400?5A404ALD018H5P0@5Q@05adL00020P0A5aL05Q`M010E600<51L041TK00`D5P0:
4Q@03aHG00lE5@0@5QH03A<B00/A3`0<4Q0041DD018H5QCooooo000Kooooo`0F018A5P0=31404A0E
00T83@0B4AH02`X?018A5P0=314020L<00X93P0=31401`H;01LF6`0P7b@040lD00L62`0>3A804a8G
024P9@0:2@h03`hC01<B5`802PT>0`0=31401P0<2a002PT>00T83@0?3Q<03PdB00d<4@802`X?00d0
30dA014E600D5a`03a8G01dP9@0`<CD02``@00`=4@0:2@h02`X?00h=4@0>3A803@`A00802``@0180
30dA00h?4`0?41@03a0D00h?4`0?41@0414E018C5`0@4AD06AXN04e>DP0P8BD0=3Di00P93@0X:Bd0
2``@00d>4P0>3a<300l@5003010B5@0>4Q<03Q8C00804aLH00/03a<D00X>3`0?4a@041@E01hR8`1N
HV<07b<T00/?400G6a`04QHI00X>4@02010D5`0>01dP9@0P8bP05APM01@G7P0F6B003Q4J00H84`0Z
;3/00P@C00`>7@0E5b@05QPU01dO;01JG6P2020R;P0E010B7P0H6RD03Q<G00hC5P0@5AP04AHJ010E
600=4QH06AhR00X?4P093Q40314E01PM800C61`02a4A00lE5@0B61P051XJ01HL700?5AD04QPH0080
41HF0P0A5aL0@@0=4a<04aLJ01<G6P0B5QX04QDJ01@G6`0D61/02PdB01DI7@0=4A@020/@00`@500H
6Ah02`XB020N9`0D5AX020/@010E600D6QX04QPH018G600>4AH03PlD00l=5P0A41P04a@I00dA500?
4aH0720S018F6@093A002PhA014E600?4aH03A4D00lC5P0>4QD02`lB01@H700>4AP041<L00lA7P0>
41d02P`K01`N:`0=3a`08bDa01/N9`0:3AH051@L014A6@0G5al061PR014D7@0B5Ah04QHQ00`@6`0_
<ch01`dI04Q>FP0941X05ATN01PK800G6Ql04aHK00804ADH0P0=4A@00`0@51L03a<E00`@4`0200hB
4`0@00/?400A5AH04QHG018F5`0G6a`04aLH00010P0D61T0DEEF01lS900@51H000@700dA50093A00
5ATL018F6@H03Q8E00T02`lA01LK700B5QL02Ph?01PL7@062P/02Ph?010D5@0>4Q<00`0=4A80900A
5AH06QhO0455AP0<41403a<D00H:2`0B5QL04aLH014E5P0@51D04ADF010D5@052@X05a/L014E5@0C
5aP02@d>01/O800V:R/061`M014E600C5aX03A4B00/?4@0>4aH031DD00/C500:4Q@02a@C00`E5@09
4A<03aPG00hF5`073a405b0O03Lo@0802a4A00d0314D01@I7@0C61`041DK00dB600>4aT03Q<G00dB
5@0=4a<03aHF00XD4`0<61H03QXH00803aTH01D041XI03Y3@P0L8b<04ALG01DK6`0>51@010X:00L=
2`0?5A<03Q@B00<91`0D6QP03Q@B01DK6@073@/05Q`J00H<2P0=4a400PP600T?3@0>51800P0<4Q00
2P0>51802@l=00D;2@0<4Q0020h<00H<2P0;4@l02Q0>00H<2P0>518200`B400300lE4`0>51802a4?
00803Q@B01`02a4?00`B400@5Q80314<00dB3P0;40`03A8>00/A3`0=4a4031DB00hG5P0=5QD0218A
00H@4@064Q80@e5B010K7@0=5aP04ATG00T?3@0:3`/0310?010D4`0;3a002a4D01/S9P0@61/03Q<B
100>4Q402P0;3`h05ATH0045100<40l0720O01XN7@0:3``02a0<00dB3P0<4@d200X?2`0Q00dB3P0>
4`l03Q<?00dB3P0<4@d02a0<00hC3`093PX03a@@00L<20083@T04aPD00X?2`0=4Ph02a0<00hC3`0<
4@d01``8018G3P0;4@<0318800dB2P0=4P`0314=01<H5@0D61L02Pl;00H;1@0J7aT03Q<<018G4@0D
6A<04AH@00802a0:00T02Pl900lD3P0>4`d02a0:00X?2@0;40X03A8<00/@2P0<4@/00P0=4P`200`A
2`0800X?2@0J7aT010T300`A2`0730H02@h800T>2P0:3`/200dB3P0h00`A3@0;40`02Pl;00`A3@06
2`L04QLC00dB3P0@5A401``6024V800E6Q@01P/500X?2@0>4`d04QLA01HK5@0D6A<03Q<=00X?2@0<
4@/000@005QME`1;D4X03Q<=00@90`0K81X020d700lD3P042@<00PL101@I4`073@T01a0=00TC4P0>
5aH0214>01DN6`0@5Q803aDA010D3`0@4Pd03a8;010B2`0>4@X041D?01PM5`0?50h01``600`A2`0?
50h04AH@010E3`0<4@/02@h800/@2P0=4P`200dA400400hB4@0;3`h02`l>00`@3`803Q8A0P0?4a80
0`0=4A003Q8A00`@3`0200`@3`803A4@00<03Q8A00`@3`0>4Q400P0>4Q406`0?4a804ADD014E500H
71/051PG00H:2@0A5A@02@d<01dQ800K7ah03a<B014E500<40l0310@00/?400=4A803Q8C00`@4@0>
4Q<02@d>00hB4`0=4A803Q8C028V9`0I7Ah041@D00`@3`0300hB4@80310?00@03A4@00lC4P0A5A@0
3Q8A100;3`h02`0>4Q4041@C00hB4@0A5A@092PW00hB4@0;3`h00081014E500:3`/02a0<00D03A8>
0`0<4@d01@0>4`l041DA00`A3@0;40`02Pl;00<02a0<100=4Ph0400<4@d02a0<0088100<4Ph041HB
00`B3P0C6AD02@l901LN5P0940P072<K00XB1`0F7Q<01@`400L=2`0@5QD201DK5`0@01XQ6P0S:R80
5A`D00D:1@0?5Pl020h<00X@3`0=4a<05Q`J00`B400=4a401`d;00P>2`0A5a<02a4=00/B30<02a8;
00<031<;01<H4@0@5@l00P0=4P`01P0>4`h03Q<?00dB3P0=4@l02`l>00`@3`803A4@00L05AXF010E
4@0A5Q803A8>00D:1P0>4`l03A8>0080314=01H03Q<?00lD400A5Q80314=01XO6`0730P041DA01DJ
500b=c403a@=00dB2`0<4@X03Q@:01<I3`0E6a4041D>00dB300<4@/02a0:00`A2`0=4P`0314;0P0A
5Q0200dB300300hC3@0=4P`03A8<00<03A8<00@0314;00/@2P0<4@/03a@>0P0@5@l00`0?50h0314;
00`A2`0200dB30803Q<=0`0=4P`03P0>4`d041D?00lD3`0<4Ph03A<?010F4P0?5A40318>00X@3006
30P08bTU00lE4@042PH02Q0<0P0C61@0200?51003Q<?00lD400>4`l04aPD010E4@0>4`l03a@@0P0@
5A40100A5Q004aPB00/@2P0?50h200/@2P06014F400<4@/02a0:00`A2`0;40X041D?0`0>4`l300dB
3P0J024V8P0320@01PX604E:AP0=4Ph05a`H018I4P0E71D03A<?00lE4@0>51403Q@B01@J600@5QD0
92XZ01<I6@093a005alQ00/E5`0?6Q/031HG00/E5P0@6AT03aPG010F5P0@5A@200lC4P0301<F5@0F
6QWooooo01?ooooo000Kooooo`0600d<4@0>3A8020L<00l>4`0j>Ch030/@0P0>3A804@0:2@h01`H;
00P7300=31403PdB00l>4`0;2Pl020L<00X93P0C4QL0;Rdb00d<4@0<2a003PdB00X93P0C4QL030/@
00803@`A00<03PdB00`;400;2Pl00P0=31403@0<2a002PT>00`;400=3Q80>Si4014D7009318030lD
00T:3`0:2a0030dA00X:3@0;2`d00P0>3Pl00`0=3@h03@hA00`=400200/<3`0;00`=400=3Q402``?
014B5@0?41<0414D00h?4P092Ph04a@H018C5`0@4AD00P0;31000`0A4QH03PlC00h?4`0200l@5007
010A5@0A4aH02`lA00T=3`0?4aD0310B00hB500200lC5@0e018F600J7R00CU9D010C5@0D61T08RHV
01XN7P0?4a@05ATK00dA4`0H71l06AdQ00`?4`0<3a@051LM01<F700=41T051LR018D800H6RH05aTU
00h@70051a<0;2hj00h@700=3a`03a4N01HH900B5ah04QLL014F700@5A`041DJ014F70062A00724V
0497C@0@4a/05AXO00T>500?51P04aPL01HK7`0H7B406QlT01@I7P0@5AX03Q<H010E6P0F6al05Q/P
014F6P0?4QP0100@4aT0500?4QP03Q4G00d@5P0D5ad09bX`01LJ800>3QH061HQ014@6`0;2a@07R4Y
030e>P0A5aX04QPM01<H7@0?4QX030`E00d<5`0C4A/04a@I0P0A5AP0=00C5aX05QXM01HJ7@0C5aX0
6alR01PL7`0C5aX04QHI010D5`0@51H03a<G00d@5@0<3aP051HQ00lA7P0>41h03a4N010B7`0O8B`0
41<L01TL900F62003Q0H01DG7`0F62403a8L01<E800D5b<03a<N028V<@0B5b80:2di00X>6@0C5Qd0
4QDM014D6P0@4aP03Q4F00hB5P0;3a80310B014E5P0?4a@0310@00hB4P0>4Q<051PI014E5P0?4a@0
3A4B00/?400>4Q<200lC500901HI6P0@51D0:2`]00lC5@0B5QP04ADG01<G6@0B5QP041@F00D03Q8D
02H03A4C00X>3`0F6Q/03Q8C01XN7`1LH64082@U010D5@0>4Q<0310A00/?400<41404QHG00441@0?
4a@04QHG00X>3`0830d03a<D00dA4P0<41402`l@014E5P0B5QH04QHD00850@0>4`l02Ph<00P=2P0C
5aL04QHG00lC500=4A@03Q8F010C5`0@51P03ADG00`E5`<02a@F00h031DG00dF600=5QP02Q<E00TB
500M9RP0?4E700`A500:3a402@hA01<H700A5QX03A4F00hC60803Q<G0P0>4aH03@0=51D02A<B00XE
500<5aH03ALF00/E50084Q404APH01<J6P0=4a<02a0@010E5P0D6AX00P0?5A<01@083P`04QPF00/A
3`0?4a403a@B00803Q@B00D01``:00hD4P0;4@l02@l=00hD4P0200dC4@0500hD4P093`d051XH01dS
8@0C6AL00P0;4@l00`052`T0318@010F500200X@3P0Q00dC4@0>51802a4?00X@3P0@5Q@04ALE00/A
3`0<4Ph020d801HK5`0<4@d08RLS03m5@`0C6AL04a`I00PA400;51<031HE00PB4`084aD0DF1S00@B
5@0<5aT0218B00P?3`0A61L02a0?00/@4P083a403QHJ00@=4`043A403a@C00@03a<B00T041@C00X>
3@0?4a802@`;02hb<@1;Cdh0310>00lD400>4`l00P0:3`/00`0<4@d03Q<?00/@300200/@30802Pl;
01X0314=00P=2@0?510020`900/@300D6AD02Pl;00L<200>4`l02@h:00/@300110403A8900`B100<
4PP0318:00`A2`0<4@d03a<A00P:2@0?51001@T401`Q6`0>4``03Q<=00dB3@80314<00<03A8=00lD
3`0=4Pd00P0=4Pd200`A300300/@2`0;40X0314;00803A8<0P0<4@/09`0:3`T0<CH`038g<@0<4@/0
41D?00`A30093PX02a0<00dB3P0>4`l03A8>00`A3@0D6AD0GF9N04I;A`072`P03a@@00P=2@083@L0
3Q<=00`A2`0=4P`03a@>00`A2`0>4`d05AXD01@I4`0?50h0314;00hC3@0?50h04QLA00hC3@0<4@/0
3a@>010E3`0=4P`041D?00dB300200`A2`0A01LN6`095QL03Q`N02<`<P0>6Q/02aHF00dF500<4Q00
2a4<00`>2@0<3`P03a0900lB2`0L7aX08BHP01@I4`0;40X00`0@5@l04P0>4`d041D?01DJ500C6180
41D?01HJ6@0;3`h0310?00dA400:3Pd02`l>00dA400<40l041@C00hB4@0;3`h03Q8A00hB4P80310@
02803Q8B00lC4`0@51@03Q8B010D500?4a<03Q8B00lC4`0@51@041@C00T<2`0=4A002@d<00H:2@0G
6aX0<3@c02<W9P0:3Pd03A4@00P<2`0>4Q80310A00dA4P0?4a@02Ph?00/?400?4Q<04aLH01@G600A
5AH0A4Q902P/;@0<41003A4@0`0>4Q4200dA40<03Q8A01003A4@00`@3`0=4A003A4@00`@3`0>4Q40
3a<B00`@3`0H71/06alN018F5@0>4Q401`/:00lC4P0:3`/02a0<0P0=4Ph03P0>4`l03A8>00dB3P0<
4@d02Pl;00T>2P0;40`03A8>00lD400=4Ph02Pl;00`A3@0>4`l03A8>0`0>4`l0;`0=4Ph0314=00/@
30093`/04QPD00@:1P0C6AD000@0014H4@0:4@T03A@<00/B2P0F7Q@02a<9014H400;40`03Q8@00dC
3`0=4@d03A8<00hD3@0520@0;S<]00T=2P0=40d0310>01@I5`0>51802@l=00/A3`0A5aD03A<@00dC
3`0B61@04ALB00hE3P0<4``02Q4900P?1`0>4`d03Q<<00dB300<4@`02a0<00X?2`0<4@d03Q8?0080
3Q8@00H03A4?00`@3P0A5Q8020d900H;1`0@5A4200X?2`06010E4@0;40`03Q<?00`A3@0;40`04AHB
0P0<4@`0100A5Q408RLR01<H4P0;40X200dB2`0500`A2P0;40P03Q@;014F3`0?50h00P0<4@/0100=
4P`03Q<=00lD3P0=4P`200hC3@803a@>00<03Q<=00dB300=4P`00`0=4P`200hC3@0300lD3P0@5@l0
3Q<=00803A8<100>4`d0200?50h041D?00lD3P0=4P`0314;00hC3@0?50h03aD@0P0>51002P0=4`l0
318>00`B3P0=4`l0318>01LM6@0>51004ALC00P>2P0A5Q8200/@300600dB3P0@5A404AHB014F4P0?
510041DA0P0B5a<02@0?510051TC00`A2`0?50h07b@N00/@2P0?50h04aPB018G4@0201HK5@04010E
3`0>4`d041DA010E4@803a@@0P0>4`l07P0:3`/051TE00dB3P0>4`l04AHB00hC3`0P9b00:C0Y00lE
4@0G7AT07R@Q00lE4`0=4a40=3Xi00lE5@0D6QX02a4B018J700951H03Q/K00/H600:5AH03QLG00dF
5@0=4a<04QHE01<F5@0C51<04a@D01HG5QCooooo000Kooooo`0G01LF6`081``05aHK00D42@0>3A80
2@P=00h=4P061@X020L<00l>4`0>3A8020L<00h=4P040`P03PdB01<B5`0<2a002PT>00811P0920d0
3PdB00l>4`0<2a000P0;2Pl00`0=31403PdB00h=4P0200h=4P0:01LF6`0F5AX04a8G00h=4P0<2a00
30dB061SJ`0l?dP020/D00P;4P803@hC00L02``@00X:300:2P`03@d=00d=2`0=3@d02``>00802@X<
00l02P/=00`=3`0=3Q003a0B01LH6P0D5AL04a@F014B500;30l08B8V00<4200B4aL00@8601dN8P0E
5QX00P0?41@0>P0@4AD04A8F014B5P0>4A@04ADH01@H6`0>4QD02`lB00X>4@0;3a80310C00D9300h
?3l0Zjnb03Di?0093@l05QXI010D4`0G6a/051PI00X>3`0@51H0310C014E600D5a/04QDJ014D6@0I
72401`X?01HI800E61l04QDL014D6`0T9c0010L@01HH90051a<0418N01@F8P0:3QL03A4J018F7`0A
5Ah03A4J00X>5`0F6R<01PXC02<W<00=4AX02PhG01HJ8`0A5B004QHQ00lC7P0@51l05QXU01DI900G
6bH201@H8`8061`W00@041@O01DH8@0D5ah04A@K0P0?4QT07@0@4aX02@`C014D6`0L7bH0:B`c014D
6`0J7B@03PhH01DE800C5Ql03A4J00/@6@0@5ad04APP00lE7@0@51d04aHO01@C7P0?3aT03a8G018F
6@0G6ah03a<F010D5`0830l01`/>018F6@0A5AP0310C00803A4D01D07b<T00H:300@4aP03a8I00h@
6`0D5R804A<P01<E8P0H6RH0X:>/08J9T00H6b805QTR00X=5P0A51d04QDN00`>6P0A4al0418N010D
7`0>4Qd00P0A5B007`0C5b805QTR014D7@0@4a`041<J00lB5`0=41D02PhA00`@4@0A5AH03a<B00`A
3@0=4Ph04aLH00L;300<41404ADF00/?400830d04QHG00861`0@51D020`=01dQ8P0f>S/04ADF00X>
3`0=4A80310A014E5P0B5QL00P0>4Q<0300=4A803Q8C00hB4`0A5AH010P901@H6@0=4A80>3`m0<C8
b@0l@4404aLH014E5P803Q8C01X03a<D00`@4@0N8R<09RX[010D5@062P/05QXK00`@4@0@51D03A4B
00lC500G6a`02`l?00`A2`0G71D01PX601lT800>4`l020`;00dA4P0D61T04ADH00T<4@0>4AH02`lC
00dE60802aDG00l02Q@F00/E5`0<5QP010h@00/E5`0?6A/02A<E01XT9P012`d02@hA018G6P0C61/0
1@X=00@9300>4aL00P0:3a<01P0:3a802a0C00/@4`083Q4041TH00dG5P<031HE01D02a@C010F5P0=
4a<041HF00lC500;3a004ADF00T?3@0<4Q002Q0>01TO7@0B61H0IVaZ02H/:P0;4@l020h<01PN700>
51801`d;00P>300>51800P0=4a406`0>518020h<00D;2@0D6QP03Q@B00X@3P0@5Q@0318@01<I5`0@
5Q@02a4?00lE4`0=4a401`d;00/A3`073@/04ALE01DK6@0;4@l01`d901@I500;40`00`P406I[I`2G
WI/061hL00`E4P0200/D4`0@00D?3P0<5QL05b8T0;k>dP0[>C`04AlP00L=3`0=5QD02a@C00L=3@03
2`d041PJ030i?P0F8BL07RL/00dB4@@03A4@00T03Q8A00dA40062PT04QHE00@81`0;3`h03Q<@018G
4`0@5A400P0;40`00`0?510041DA00`A3@0400`A3@0400hC3`0:3`/01@X600`A3@802Pl;01@041DA
0002000=4Ph01P/701<H50093PX03A8900dC1@0<4PP02a4900/@2P0<4@d02Pl<024U900>4`l061dG
010E3`083@H04QLC00hC3`802a0<0P0:3`/0200;40`0314=00hC3`0>4`l0314=00X?2`0;40X0314;
0P0=4P`200`A2`0800/@2P0>4`d0;c@^020U7`1JGeT041D?00dB3P0<4@d200X?2`0900`A3@0?5100
20d9038g<`0/<Bd03a@@00D:1P0?51004AH@00803a@>00@02a0:00P=1`0A5Q003A8<0P0:3`T07@0=
4P`041D?00lD3P0V:bD0=S/e01DJ50093PP03a@>0005000;40X02@h800D:100B5a404AH@00dF4`06
51D0:3Tm0<?Be@2T/[D07RX[00/E500<4Q80314=00/@2P0?40X04A8;018E300;3`T04aPB00802@h8
0P0C6180600_=2h04QLA00`A2`0E6Q@041D?00L<1P0T:2L02`l>00T=300<40l02`l>00dA400;3`h0
2Ph=00lC4P0=4A002@d<00dA400<41402`l@00X>3`0;3a003A4B00hB4`804ADF02X03a<D00X>3`09
3@h02Ph?00/?3P0C5aH02`l>018F5@0J7Qd00PH501@H5`093@`03A4@010D4`0420L04aLG00`@4@0=
4A803a<D00P<3@093@h061`M00010P0:3Pl08RHW02X^;`0B5QL03Q8B00hB4@0<40l02`l>00`@3`0>
4Q403a<B00dA400;3`h03A4@01DI600M8B0061`K00hB4@0=4A0200hB4@0700/?3P0B5QD01`/:00/?
3P0830/03A4@014E500300dB3P0?00`A3@0;40`02Pl;014F4P0?5100314=00X?2`0;40`03Q<?014F
4P0=4Ph02Pl;00dB3P0?51003Q<?00<03a@@02P03A8>00`A3@0;40`051XF0002000E6aL01P`801DK
5`0/<b`02Q49010G3`0B6A40R92503U1=P0120003Q0;00d?300@4Pl04aDB01DG4`0E5a80828M00/=
2`0?4@h02@/800lA3P011P802`l>010F500:40h03A<A010F4`0Q9b<04aTE018H4`0?5Pl03A@=00/B
2P0940P03a@>0P0@5@l08`0?51003A8>00X?2`0:3`/03A8>010E4@0?5100314=00X?2`093@X03A8>
01LL600:3`/06b0L00H;1`0C61@05AXF00hC3`093PX0314=00hC3`0=4P`03a@>00D:100K81X000D0
01DJ500>4`d04AH?00lD3@0<4@X03A8;010E3P0:3`T03A8<00803a@>00<03A8<00`A2`0?50h00P0:
3`T2010E3`0300hC3@0=4P`03A8<00<03A8<0P0;40X03@0=4P`041D?010E3`0@5@l04AH@018G4@0A
5Q0041D?00dB300<4@/03a@>010E3`0>4`d00P0<4@/02@0>4`d041D@00lE4@0>51002a4=00X@300=
4`l041HB01@J5P0200hD400601XP70042PH04aPD00lD400=4Ph03a@@0P0A5Q82010E4@0501@I5@0F
6aL05AXF010E4@0C61800P0>4`d02P0O91h03A8<00lD3P0A5Q003a@>018G4@0E6Q@04QLA01@I4`0@
5A4200lD400Q00hC3`0=4Ph03A8>01LL60001@402a0<01/P700=4Ph03a@@00L>1`0<4``04aTE02hd
<00k@3d04aTG00L=2`0?5A@000D501@J6P0>4aD0210B00dK700A820031XJ00/G5`0<5QH02A8A00T=
3P0@4a<051HE018B4P0@3`l04@l@01Cooooo000Kooooo`0600L62`0;2Pl040lD010?500>3A802PT>
1P0;2Pl050020@H05A@I03Lf>`0C4QL030/@010?50061@X02`X?00h=4P0=314030/@00d<4@0920d0
40lD00H52P0C4QL0?Se202`[<00>3A803@`A0P0>3A800`0<2a002@X?00`@600200d@6@0K00/>5@0:
2a002@X?010A5@0820X04Q8D00`<30051@<03`l?00T:3@0:2`l01`P<010A5@0E5QX03PlC010A5@07
20`04Q<G0411A@0:2`l051DI00h?4`0<3A405aPL00421P0>3a<0:R/_00D0414E00D030hB01HI7P0D
5a`02PdB00D83@0200lB5`0i00011P0>4AH0<cHk0:2SZ00L7b@03a<E01/O7P1RIVD0310@00P<3@00
0@804aLI00/?4P0?4aH041@H00`?500?4QL05a/N02@X:@0;3a007R8S01PL7@0>4QD04QHI00dA500@
4aP05APM01HI7P0B5A/041@M00`@6`0?4ah051PS018F8@0@51l01`/F00lC7P0J7RT0310K00P<5`0>
4Qd02PdL06Q[O00f>DX02`hO024T=@0E62T051LX00X=7P0b=DH061//01`O<00F6BT05QTR01@G7P0A
51/03Q4H008041<J01@030lF01<F7@0D5ah041<J00lB6@0C5Qd02`/E01DE7`0B5Ah07b<^00lD7`0:
4aX01a0I00hD7P0H72L03Q4J00d>600=3AD04QDJ018F6@805ATL0P0A5AP03@0<41<03a<F00lC5P0=
4A@03a<F01@H6`0@51D03A4C010C600A51/0418M01@F8P082QH00P0F62@0<P2=T9T0GV5X01HI800=
4A/04ADP00X>6@0>4Qd04aDQ00`>6P0@4Qh03A0I00`?600=41T03Q4J00lB6`0C5Ql041<L00X=5P0@
4aX051LL010C600C5aX051PI01<G600A5A@0314=00X?2`0?4a@00`L8010D5@0:3Pl04ADF00lC500>
4Q<041@E00hB4`0A5AH04QHG010D5@0M8B80=3Pi00lC500D61T01`/<01PL7@0<41401@T:01`P8@0C
5aP02@d>0`0>4Q<01P0@51D05ATJ01PL7@0H71d04QHG00lC50803Q8C01H03A4B00T=3P0F6Q/0R8b=
02/_<0072``07R8S03Tm?P021PL06alP00P:2`0@51D02Ph>00P=1`0;40T02@h700/@2P0A5Q002Pl;
00/?3P0<40l03Q8C0P0>4QD03@0;3a@03ADH00TC5@0;4aD01@lA00/E5`0B71h010h@014K7@043Q00
4adO04QBE0043Q000P0>4aL0100?51L03Q<F00`A500:3a8200hC5P05010E600D6A`051TL00hE600;
51<00P0=5QD01@0;51<02Q8A00`B4P0;4A403Q<C008041@E00X03Q8C00`@4@0>51804aTG014G5@0?
5A<04QPF01DK6@0G7A/02a4?0P0<4Q003`0;4@l05adK00`B40083P`04ALE010F500;4@l05adK00T?
3@0A5aD02a4?00D;2@0E6aT01`d;014G5@0200`B400Y014G5@0?5A<02a4?00dC4@0>51803aDC00hD
4P0<4Q00318>01<H4`0>4`l0314=01@I5@0G7A/04QPF00PA3P0330/02a@C018L6`0<5QL02QDG06Ig
NP0M:bh00@l@00LA4P0<5A@010d<00T?3`0841800PX<01@M8P2Y];X0UYnT01@I6@0B5QD01`/:018F
5@0;3`h02Ph=00P<2`062PT00P0=4A002@0;3`h03A8?00T>2P083@T0314=00X?2`093PX02Pl;00T>
2P0200X?2`0500/@300>4`l0314=00T>2P0@5A400P0;40`08@0=4Ph01P/700D:1P0B5a<02a0<0005
0@0@5A404aT@00H<000220003Q<;00/@2P093PX0:2`Z08:6Q@0C61@0314;018G4@0H7AL051TE00hC
3`0=4Ph01@X601lT80062`L01``8010E4@0:3`/082DQ00T>2P0S9b@0>Sli00/@2P0200dB300A00hC
3@0A5Q0010T300`A2`0?50h03A8<00lD3P0<4@/0314=00/@300;3P/061dI00P=2@0?5100314=00hC
3`0?51000P0<4@d01`0>4`l02a0:00dB300:3`T01``600/@2P0B5a400P0;40X0300?50h03A8<00/@
2P0D6A<05a`F02<X8P0A5Q003a@>00`A2`083@L07B8L018G4@803Q<=01/02Pl900L@3@0651D0=DI:
0=k]l030c]405b<T00lI600630`06AhJ014F400D5@l0>c`e014D2`0;3`T061dG01@I4`0<4@/06QlI
05eRG037c<H08RLQ00X?2@0B5a403A8<00T>200>4Q400P0;3`h02@0=4A003Q8A00hB4@0;3`h03Q8A
01TM700@51<03Q8A010D4`0300lC500300dA4P0:3Pl020`=00<03Q8C02L041@E01@H6@0E6AX02`l>
00dA400<40l04QHE010D4`0>4Q403A4@00D9200A5A@02`l>00hB4@0=4A402`l@01DI6P0@51D01PX;
01DI6P093@h04QHG014E5P0C5aP04ADF00dA4P0D61P04QHE00hB4@0:3Pd02`l>00dA400@51<03A4@
01HJ6@062PT082@S075eM00G6aX00P0=4A001`0;3`h02Ph=00dA40072`X02`l>01DI60093@`00P0<
40l01@0B5a<03A8>00T>2P0;40`0314=00803Q<?00L02Pl;00P=2@0>4`l04AHB00dB3P0:3`/02a0<
00803Q<?00D03A8>00/@30062`L020d900`A3@0300dB3P0A014G4`0=4`l02@l;00@:1P0;4@d0;SD^
00dD300940P05ahF03Y2=`0L91T02A08010B3@0A4`l06Q`I01<E4P0=3``00P0B51403@0=3``04A<@
010B3`0;3@T0314=00H:2@0;4@l02Q0>00dC4@083P/061hJ00hD400>5@l00P0530D01@0<4``02Q49
018G4@0:3@X02a0<00802Pl;00P03Q<?010E4@0>4`l04AHB00hC3@083@L02Pl900dB3P80314=00X0
3A8>00hC3`0>4`l04AHB00/@300=4Ph04aPD018G4`0?51003Q<<0P0=4P/0400?50d041D?010E3`0<
4@/02@h800P=1`0D6A<01``600lD3P0A5Q0041D?018G4@0;40X020d700hC3@0A5Q0200/@2P0K00hC
3@0?50h03A8<00hC3@0?50h02a0:00P=1`0;40X04aPB01TN600F6aD041D?018G4@0C61804AH@00`A
2`0:3`T0314;00L<1P0:3`T041D?00lD3P0>4`d0314;00/@2P0<4@/02Q0;00803Q@@02T02@l;018H
500@5Q803aDA01LM6@0D6QH03A<?00hD400E6aL06R0L00<8100C61@0008001DJ5P0D6AD03Q<?018G
4`0:3`/02a0<01DJ5P0>4`l041D?014F400B5a403a@>00hC3@0@5@l03A8<00/@2P0>4`d04AH@00hC
3@0?50h020d901DJ5P0A5Q804aPD01@I5@0B5a<04AHB00lD400200hC3`0J00dB3P0A5Q803A@=00`C
300<4Ph03aDA00lE4P0<4Q005Q`J00`B4@0D6QX02a4A00`A4`0E7Al01aDF02He=@0@7Qh0>DE501XT
900E7Qd04QHG01DH600C5A@04a<C01DD500A3a0Dooooo`006oooool01P0?3Q<03@`A00`;400;2Pl0
3@`A00h=4PH02`X?00T03`hC00T83@0;2Pl05A@I00`;400A41D03`hC00`;400;2Pl00`0<2a005@0>
3A802@P=01TH7@0920d04Q4F014@5@0;2Pl01`H;00`;400E51T051<H00h?4`0;3a@02PdE00X=4`09
31402P/@00T:3`0:2`l030`?010@4P0200l?400C01@D5@1@DED01@H;00`=4@0?41D00`@800h?500>
3a<05AHJ01DF6`0<3A804a@I00T:3P0C51P03@hB00`=4@0@4AD03@hB018C5`05010A5@0K010B5`0<
3a@03A0E00lB5`0G6Ql020/@00d@5@0E61d02`hC00hA5P0V:Bh030lD018F600;3`l04aLG010D5@0C
5aT01`/=00d@4`0<3a<05a/O01LJ7`0=41H04aHL02da=00k?ch061`K00803a@A00X05ATG01@H600:
3Ph04ADE00dA4@093@d0>Cdn028W;P0F6R@03A4K0P0D62805@0>4Q`041@N00dA6`0J7BL0HVI`02@X
<P0V:S@09BPh03m2E00Q93H04aHX01DH:P0B5BL06ah`09:EY`22QIL05aX/018E9`0B5BD03Q4J00hA
5`02014D6P04010C6@0>4AL04A@J010C6@803A0F00P06ahT02X]<`0D51/05ALO01@G800H72L041PR
00XC7@8031@N00D020`G00lB6`0E5al051DK010C5`05010D5`0L018F6@0C5aX04QHI00lC5P0@51L0
4QHI01@H6@0A5AH04QHI018E6P0?4QX04aDP014C7`0:31L04QDN01TL900I72<05QTP01<H8`0G72L0
4QLR01PL9`0M82/05aXU00d?6P0?4AX0414K018D70804aDM02403Q4H00lB6P0=41H04A@I00lB5`0:
3Q803a<F010D5P0A5AH03a<C00/?3`0:3Ph03Q8C00dA4P0D61T020`=00X>3`0?4a@05ATJ01LK700>
4Q<02`l@00`@4@0>4Q809RXZ01hR8P0C5aL02`l?01TM7@0L82006AdM00`@400>4Q800P0<41002P0?
4a@03A4B00`@4@0<41403A4B00lC500@51D03A4B00`@4@0=4A8300lC500C01@H6@0?4a@041@E00hB
4`0G6a`0N7am00lC500;3a003Q8C01dQ8P0>4Q803a@?018G400?50d0314;010E3`0@5A403A4?00hB
400200lC4`0800hB500=4Q@02PlA018K7@0>5aT09Bh`09FNX00c?3h200hG6@0400hF600f?d40FV=U
00lH6P804AHJ00L04QLK018G6P0A5QT03aDF00hC5@0=4Q@03a@G00804QLK00@03Q<H00XB500<5QD0
31DD0P0<4a<0200>51@03A8B00hC500?4a@041<D010B500=4A803Q@B0P0;4@l01@0>51803aDC00/A
3`0;4@l041HD00801`d;00`041HD00/A3`0@5Q@03A<A00hD4P0:40h04QPF02hd<P0@5Q@02Q0>00hD
4P093`d200dC4@803aDC0P0>518200dC4@0800lE4`0<4Q002Q0>00X@3P0<4Q003A<?00dB3@0@5A42
00`A3@0Q014G5@0B61H03A@A00H?3P0<5A@0@de<00/E5P0E82804R0S008@4`033Q0031HF00lF5P07
3`d02@h>01@I6`0@5QT03aLJ03m8CP0W;c<041DD020T8`0A5A@01`/:00H:2@0@51<02Ph=00P<2`0>
4Q403A4@00`@3`0>4a003a@@0080314=00L041DA00`A3@0<4@d03Q<?00/@300>4`l04AHB00803Q<?
00L02Pl;00dB3P0<4@d020d900lD400>4`l03A8>00802Pl;02l05AXF01@I5@0=4`X020h100`B200J
81P051TC00/@300;3`d0=3Pg00X>2P0F6aD04QLA01LL5@0=40d02`l=00lC4@0B5Q@010T600hB400=
4@l041@B00dA3`0=4Pl02Pl<038f<`17C4H061dG00X?2@052P@02@h800dA30083@L03Q<=00lD3P0<
4@/03A8<00`A2`0@5A402Pl;00lD400J7a/02@h:00X?2`0<4@d03A8>00lD400200hC3`03010E4@0=
4P`03Q<=00803a@>00@03Q<=00dB300>4`d041D?0P0;40X0;`0=4P`02a0:00T>200B5a401``600`A
2`0>4`d02Pl900dB300G71H04AH@00/@2P0?50h02Q8>00LD5@0@7Al0=45202Hc=00:5AD02a@B00/A
3`0`=C008R@O010C300C50d02@/700lB3@0;40X0314;00hC3@0T:B<0Be1:09FJU00J7aT04AH@01LL
5P0<4@/04QLA014E500=4A002`l>00dA400<40l02`l>00X>3@0D61L0720O00802`l>00T03a<B00hB
4`0>4Q@03a<E00hB500<41802`lA014E5`0?4aD00P0>4Q@02`0@51H041@E018F5@0>4Q402Ph=014E
500C5aH041@C00dA400;3`h041@C00803A4@00P03Q8B00X>3`0h?3d01PX;01@H6@0:3Pl0310A014E
5P803Q8C00@03A4B00T=3P0?4a<0310?0P0;3`h01P0=4A003Q8A018F5@0;3`h041@C018F5@80310?
00d03a<B00dA400>4Q403A4@00`@3`0?4a804QHE00/?3P0<40l03Q8A00`@3`0>4Q4061dI00803Q<?
00<04aPD00dB3P0<4@d00P0;40`0100=4Ph041DA014F4P0>4`l200`A3@<03A8>03P0314=00hC3`0;
40`020d900/@300>4`l03A8>00T?2`0:40`041HB00hD400;4@d05QdF07AkL`0H7aL02A0800lG300C
6a003QH;01<I4P0;3`X03Q<?00H:1P0B5Q@020h;00X=3@0;3`d04QLC01DH5@0?50h03aD>00/A3@0:
40h04aTG01hT8P0<4Pl020h:00dC3`0=50h04APA01TP6@0L8a`03aH?01`Q7@0<4@h02`l=00dB3`0>
4Ph02Pl;00hC3`0;40`03A8=00/@2P093PP0314;00hC3`80314=0P0;40`200`A3@0600X?2`0<4@d0
4AHB00hC3`0;40X03A8;0P0=4PX02@0>4``03Q<=00hC3@0=4P`02@h901XO6P0;40/061dH01<H4`02
010E3`08014F400<4@/02Pl900lD3P0G71H03a@>00`A2`0=4P`200hC3@8041D?00H03Q<=00dB300?
50h04aPB01LL5P0E6Q@300lD3P80314;00D03a@>018G4@0=4P`03a@>014F400200lD3P8041D?01L0
4AH@00lD3`0D6QH05Q`H00hD400?5A403Q@@00/A3@0B61@05A/G01<I5@0?5A4041HB02T^:P0K81`0
7R<O00X?2`0:3P/041DA01DJ5P0@5A402a0<00lD4002018G4`0>014F400B5a404QLA00lD3P0=4P`0
3a@>018G4@0@5@l04QLA010E3`0<4@/04AH@00X>2`0H7AT2010E4@0:00hC3`0<4@d03A8>00hC3`0@
5A403A8>00/@300=4Ph01`h700XA2P803aDA01@03Q@A00lE4`0A5aD03Q@C01@J6P0630`05adN01@L
7P18DeD0cm_L05MTI00Q;2d07RPX00dF5@0D6QX03a<C018E500B4a<04a@C01lP7aCooooo000Koooo
o`06010?500=31402@P=00P7300:2@h03@`A1P0;2Pl01`0920d02`/?014@5@0/:c004a8G00D42@09
20d00P0<2a004@0:2@h030/@00h=4P020PH06aXO04i=DP0_;S<01PD:0000100>3A802PT>00`;400B
4AH03`hC00T:3P0=4QD02`hC00802PdB0P0=3Q801`0>3a<05aHK00l>4`0<2`l040lD00h=4P0Q8RP0
0P0<31@0300A4AT0410H010@600;2a<0>c]304=3B`0>3QH0000700l@5@0:2`l010D900l@50803@hB
00<04a@H00l@500?41@00`0?41@0EP0=3a@041<H01<F6`0=41D0CE1E01/N8`0B5AX05APM00021`0I
72405APM01@G700?4aL04ADF00L;3P0:3Q406AdP01/O8P0H6b002@`A00X=4P0?4QT041<J018E7P0:
3Q<01`/<00lC500<414041@C014E500:3Pd041@C014E4`0=4Ph04QLC00P=2`0C61`03a<L01DI8P0O
8b`06AdV00/?600K7bP0310I01PL9@1GFf@00@D>04]?F00`=4005a/W018F8`0F6BP0310L00lB800M
82l08RHb03DiAP0E62L051PT01hQ;P0=41L03Q8E010C5`0@4aP03a8F00dA500F6Ah05a/O01DI700C
5Q/04aLK01HJ7@0H6Ah041<H010E6`0>5Ad04aXU01LO:P0>5R402Q8K01HM9@0Q9R`02`dB01DF6P0?
4aH041@G0P0<41<01@0A5AP041@G014E600@51L03a<F00803Q8E01@03a<D014E5P0>4Q804QHI01@G
700C5Qh061/T03@f@P0D5b0041<L01<F7@0R9BX03A8H00hE800A5b<03A<O01<G8P0E6B@04QHQ018E
7P805ADO028051@L014A6@0@4AH03a<G010C600A51T04aHK010D5`0=4A@03a<F010D5`0A5AP04ADG
010D5`0?4a@041@E00P<3@0C5aP07B4R00hB4`093@h05QXK01dQ8P0B5QL0310A00hB4`0B5QH07R8Q
014E500=4A001@T800lC4P0830/03a<B0P0@51<00`0D61L05QXI014E5@0200`@4@0500dA4P0@51D0
4QHG01<G600@51D00`0>4Q<04`0=4A802@d>01TM7P0E6AX04aLH018F5`0:3Pl00PH700L;300S9bP0
4ADF01DI6P0>4Q802a0<00/@2P0;40/03A8<010E3`0?51000P0>4`l0400?51003a<B00hC3`0>4a00
0PP800L@3`053@h03ADG06I_KP0Q:RX031@F018K6P0@61P031@F010I600B6Q`200dB600400hC5`0>
4aH03Q@D00hD5080318B00D03Q<F00lD600>4aL03A8G00TA4`0200/D4`0300`B4P0=4a<041HF00<0
3Q8C0P0@4A<01@0>4Q<03Q8A00/A3`0?5A<04ALE00803aDC01D03A<A00X@3P0?5A<03aDC00X@3P0=
4a402Q0>00hD4P0B61H03A<A00`B400J81h04ALE00P>300;4@l010X800X@3P0;4@l03A<A014G5@0@
5Q@00P0:40h200hD4P802a4?00L03A<A010F500B61@02Pl:00hC3`093PX02Pl;00803A<A01P03QLD
00dF5@0?61L0FVAS00<=3P064Q804AlP00LB50033@h01`l=018H5P0F6aL041@C00dA400420T01`d@
00D=400<51L041DD018F5@0:3Pd03Q8A00/?3P0@51<200/?3P0500lC4P0<40l0310?00/?3@0=4Ph0
0P0<4@d0<`0J7a/05Q/G00`A3@0>4`l0314=010E4@0B5a<03Q<?00T>2P001@40314=01XO6`0:3`/0
2@h:00X?2`0B5a<02a0<00`A3@0=4Ph01``800dB2@0:408041H<01/P600D6A<0314=00X>300A5A@0
2Pl;00`A2`0;40X02Pl90002000:3Pd02`l>014E501FFUT082@S00/?3P0010<0310?00/?3P0@51<0
1P/800@91@011P005Q/E00dB30062`D02a0:00`A2`0200hC3@802Pl901002a0:00P=2@0>4`l01@X6
00hC3`0A5Q801``800/@300<4@d03a@@00hC3`0?51004QLC00dB300:3`T0314;0P0@5@l02P0<4@/0
41D?00X?2@0A5Q005AXD010E3`0>4`d04AH@01@I4`0<4@/201DJ500R010E3`0730H03a@>00lD3P0;
40X0314;00lE4@0:4a001a0?014J6@0@6AH04AXG00P>2P0<4Ph02`h:0001000E61404A<=00/>1`0I
7QP03A8<010E3`0;40X0314;00@90`0B5a403a@>02@Y8`0/<B/041D?00P=1`0@51<0310?00/?3P80
3A4@00L0310?01DI600M8B008RHU01@H5`0C5aH04QHE0080310C00D03A4D00hB5@0>4QD03Q8E00lC
5P0200hB5@803A4D01H03A4B014E5@0:3Pd020`;00/?3P0=4A003Q8A00/?3P0A5A@03Q8A014E500<
40l02Ph>00hB4`093@h020`=01LK700i?Ch04aLH010D5@0;3a002Ph?0P0;3a00100?4a<02Ph=00/?
3P0=4A0200hB4@0E00L:2@0G6aX02Ph=00D9200E6AP010P700`@3`0:3Pd0310?00dA400<40l03Q8A
01@H5`0K7ah04ADD00<71P0=4A0051PG09nTX01QIV8051TE00801@X600P03A8>00X?2`0<4@d03A8>
00`A3@0=4Ph041DA00`A3@D03A8>0P0>4`l0600<4@d02Pl;00X?2`0<4@d03aDA00dC3`0<4Ph02Q0<
00T?2`0;4P/08BPP00H=1P0I81P051`A00hF2`0=5@X041L?00`C30063@H03Q@B00X@3`093`l02a4A
00dC4P8041HB01H03A@=00/B2`0:40`020h<00hD4P0F71X020h;00X@300?5A402Q4;00XA2P0A6140
61lG01HM5P0Y;RX04QHE00P<2`0?4a804QLD00/@300@5A40314<0P0=4P`01P0>4``04QL@01<H500@
5A403a@@00hC3`803A8>0P0;40`01@0>4`l041DA00dB3P0:3`T02a48008031880`0<4@X01P0F6aD0
2a0<0002000S:2@0X:FQ09JKU`803Q<=00d03a@>00hC3@0>4`d03a@>01@I4`0A5Q003a@>00dB300<
4@/04AH@01HK5@0D6A<03a@>00<02a0:00<03Q<=00lD3P0>4`d00P0@5@l200X?2@0B00hC3@0?50h0
314;00dB300>4`d0314;00dB300>4`d03a@>00hC3@0=4`h05A/G01TO6`0A5a<03A<?00`B3P0;4@d0
3aDA0P0D6QH04@0:40`01`d9018H50042@D04QLC01<H500D6AD05AXF01hS7`0B5a<04AHB01@I5@0;
40`03A8>00lD3P0@5@l04AH@00803a@>00d04AH@00dB300=4P`041D?00lD3P0=4P`061dG02H[9`2R
Yj<0=c`h01dR7P0>4`l03A8>00803a@@00H03A8>00hC3`0A5Q803a@@00`C300?5Pl201@J5P0D010F
4`0<4Q001`d;00lE500M8b<00PP801DK700P:2X0:cDg09NRX`12C4d031HG00lH600>5aH02a4A018G
5P0F6QT04aLF01DH5`0I7A`Dooooo`006oooool200`;40802PT>0P0920d600/:3`0J00l>4`0;2Pl0
2`X?014@5@0>3A803`hC00P7300D4aP05QDJ00`;400:2@h03PdB01HE6P0;2Pl05QDJ00T83@0;2Pl0
5A@I00h=4P0?3Q<03PdB00/:3`0:2@h02@X>00dB4`0;3a8200X>4@0J00d>4P0>3a<0414E01XI7`0@
3aD02`X@00h=4`0920h01@D?01<C7@0=3AL030`F00l?6@0:2Q@07QhX0;nob@39bM<0820Z01dM9`0?
3aH02@X>00`=4@0@4AD01PL;00X;3`0A4QH500l@5008018D6@0931<00`H=01DH7`1ZKG@0:B`c01PK
8P0E61l400`?5P0601LJ7`000@@06A`Q01@G700:3A8000870P0=41L0@P0E61l05QTR00d@6@0?4Ad0
4QDM01HI800D5ad02@`A00lB5`0D61/01`/<01<G600C5aL0310?01DI600?4a<051TM010E6`0?51X0
4AHL010E6`0D6Al00@H<00X?5@0>4aT07B8X00/@5P0?51X08bP^00lD6P0D6B004QHO00dB600?51/0
8BD^00011`0G6b<051PQ00L<4P0D62004aLJ018F5`0?4aD03Q8E00hB500?4a@0310C014E5`0D61T0
51PK018F600B5QL06QhQ00X>4P0?51X05A`T00P@6@074AX02aDN01<K901oQXh0PXN=01<G6`0C5aX0
2`lB00hB5@802@d@00<041@G00hB5@0?4aH00P0>4QD05P0?4aH041@G014E5P0A5AH03a<C018F6@0C
5Q/04aHN01PK901<CeP051LP00/>5`0?4QT03A0E014F700>5B403Q@R00/A7@0<4Qh03Q8M00/?6P0C
5Ql201DE7@0701DD700B4AL03a0E014E5`0>4QD03a<F014E6002010D5`0N00/?4P0<3a@030lD00dA
5@0=41D0310C014E5P0=4A801`/<00T=3P0420T04aLH00`@4@0D61T0310A00X>3`0>4Q<03Q8B00@8
1`0?4a802Ph=01DI60093@`0310?018F5@0G6aX04ADD010D4`0?4a803A4A0P0>4Q<01P0@51D04ADF
018F5`0C5aP04ADF010D5@804ADF01003a<D01<G60011@H020`=00lC500830d09b//01<G60052@X0
310A01<G60093@h03a<D014E500=4Ph03A8?0P0D6AD01@0=4Ph03Q<=00hC3@0>4`d03Q<?00803Q<=
00`04aTG01LM6`0B61L010X:00dC4@0<4Q4010X:00881P093`h05adM014G5@0;4A8200`A5`0B00`A
5@0<4A@0318B00dC4P0<4Q003A<A00hC5@0=4QH0314E00`A5`094A<031<C00`B4P0;4A403Q<D018F
5`0>4Q<03a8C0`0@4A<02@0>4Q<03a<B010F500A5aD02a4?00D;2@0<4Q001@/900`B4002014G5@04
00`B40052`T02Q0>00/A3`803aDC0P093`d0300:40h03A<A00P>30032@L05Q`J00lE4`0<4Q004QPF
010F50093`d02Q0>00hD4P80318@0`0=4a407`0=4`l03A8=00/@30093PX03Q<?00hD4P093`d031DB
00dF5@0<5A@04Q`K00092P094a@01Q8B00@@400640l02a8A00hC3`0<3PT04A<@01HH5`0?4a@03a@F
00031P0?51L00@<301DI600D61L03Q8A00H:2@0@51<00P0<40l02`0?4a802`l>00/?3P0<40h041DA
014F4P0?51007B8N01XO6`0<4@d03A8>00@03Q<?00H04QLC00dB3P0I7QX09BXV018G4`0>4`l200lD
400R00L<200B5a<03Q<?00D:1P0@5@`02a4300`B200A5Ph03a@>00dB3P093@/020`;00dB3P062`D0
3a@>00/@2P0J7a/0720O010D4`17BdX0hNGT038f=@0;3`h01PX901<G5P000`802`l>01PM6P0F6aL0
2Pl900T>200<4@/03a@>00X?2@803A8<00`03Q<=00/@2P093PP02a0:00hC3`0;40`02@h:02H[9`0J
7a/041DA00X?2`0<4@d200hC3`0300lD400B5a<03Q<=00802Pl902/03a@>01DJ500D6A<03A8<00/@
2P0Z;bT0;C8/00lD3P093PP03a@>010E3`093PP04AH@00lD3P0;40X04aPB00`A2`0A5Q0041D?00/@
2P0F6aD03A<?00D:1P093`/01P`800`B3P0:3`T01``601<E400<3PT05ALB00P:1@0G6A@07R<M00L<
1P062`D02a0:01DJ500:3`T05AXD01HK5@0>4`d03a@>00804AH@00@03A4@00X>3@0:3Pd03Q8A0P0?
4a8201PL6`0401dQ800F6QT051PG00hB4@<0310C00<03Q8E00lC5P0?4aH00P0=4A@05`0>4QD03a<F
00lC5P0>4Q<03a<C00X>3@0<40l02`l>00X>3@0;3`h01@T8010D4`093@`04aLF00L;2P0?4a<04QHG
00D92P0@51D02`l@02da<P0=4A803a<D00802`l@0P0>4Q<05P0B5QH03Q8A00lC4P0?4a803Q8A00`@
3`0E6AP04QHE0001000Z;Rd0008100X>3@0D61L03A4@00lC4P0@51<03Q8A00lC4P031`H01PX900P<
2`0I7A`200X>3@0602db;P0D6AD02@h:01XO6`0D6AD01@X60P0<4@d01@0;40`02@h:00/@300A5Q80
3Q<?00@03A8>01/03Q<?00T>2P0>4`l04QLC00/@300730P02a0<010F4P0>51002a4=00T?2`0;4@d0
3A@=0003000:4@T01Pd500hF2`0840H04QX?00LA1P0>60l00@/301HO70012PP01Pl>00`E500<5A<0
0P094Pd07P0;5@`02Q@;0088100@5Q@03aDC010F50083P/041HB00hD400;4P`02A0900P?200;4P/0
4QTB00/?3P082P/01`/<018F5@0B5a@01@X6010E3`0<4@/03Q<=00hC300?50d04aPA01<H500@5A40
3a@@00hC3`<03A8>00L03a@@014F4P0C61@03a@@00dB300<4PL0318800803A<900T02a0900X?2008
3@L04aPD00`A3@0C5aH0CE5@024V8P0>4`d00P0=4P`200lD3P0@00hC3@0<4@/03a@>010E3`0>4`d0
2a0:010E3`0D6A<04AH@00hC3@0;40X02Pl900T>200=4P`03Q<=00dB308041D?00<03Q<=010E3`0@
5@l00P0?50h00`0@5@l03a@>00lD3P0200lD3P0800hC3@0=4P`02a0;010F4P0E6aL041HB00`B3P0=
4`l200hD400>018H500D6QH0318>00`B3P0B5a<01P/700dB3P083@T05Q/G00`A3@0J7a/03a@@01<H
500G71P200/@300300`A2`0>4`d041D?008041D?00<04aPB00dB300<4@/00P0>4`d01P0=4P`05Q/E
03@i=@2d^KD0ADY601dR7P802a0<00H04aPD018G4`0<4@d041DA01PM6@0E6QH200`C300F010F4P0F
71P04aTF00/A3`0E6aT03A<B01/Q8@083Ph0314C01@I700=5AP0:S<e01XR900A6A/03QDF01LM7@09
3`l051XI00dC4@0;4@l051TG00lE4aCooooo000Kooooo`0600X93P0<2a003@`A00d<4@0<2a002PT>
1P0;2Pl200h=4P08014@5@071P/03PdB010?500?3Q<05aHK01PG700?3Q<200X93P0500T83@0B4AH0
30/@00d<4@0<2a000P0:2@h200h=4P802`X?00D03@hA00T>3@093@d02@d=00T=3`0200/<400H00d>
4P0C4QT03`hE00h=500=31D02PTB00d=6@0821D03`hK00h>6`0<31T04Q4N018B7`17Ae@0Bd]H00d<
6@0G5R<030`D00T:3P0?41@03@hB00l@500F5a/03@hB1@0>3a<09P0?4AH02`hE00d@5`0B5A`06A`S
00D83`0@4aX02`hE00`?5P0;3QD061/R00T<4`0m@4L07b8X00hA5`0B5A/05aXP01<F7P0>4AT04aDP
02T/=P0S9C402P`I00lA7@0A4R006AXY00h@7`0>41d04Q@O00hA6`0A51/01`XA00lC5`0V:Rd09b/]
010D5P0?51P03a@I0P0E6Ql0600=4QL02a0E01HK800?51T04AHK00H;400@5AX041DI00dC4P0D6QL0
5ahJ00lE4P0B61D04APD00P?2`0H7Q/03aDB01HL6@0G7AX020d:01<G5`0B5QH03a<C00dA4@803Q8B
01@05ATI014E5@0=4A40310@00hB4P0@51@02@d=01@I6`0@5AT03aHL01TS:`2FX:T0CeUR01<L900U
;3808BHZ018F600;3a003Q8E01DI708041@G01/061`O018F6@0B5QT041@G00lC5P0B5QT04aLJ018F
5`0G6aX04QHF01<G600A51T03Q4H014D7@0B5Ah07R4Z00T<5@0>4AL051LL00lD6P0B6BD04ALU010F
900>52003Q8M00dA700@4a`00P0C4a/02P0E51/05A@J01@E6@0?4Q802`l?010D500@51H03A4D00hB
5@0?4QH300hA5`0D00hA6@0?4QP02Ph@00/?400@51D0;30a00hB4`0?4a@02`l@014E5P0=4A803a<D
01<G600D61P02@d<01@H5`0?4a804aLF00L;2P0@51<200lC4P80310?00P03a<B018F5P0A5AH04ADF
00lC500=4A80310A00dA4P803Q8C01004QHG01@H6@0C5aP03a<D01@H6@0@51D041<D00lC500=4A80
2Ph?01@H6@0B5QL02Ph?018F5`0@51D04ADE0P0=4A406P0?4a80310>00dB3P0>4`d03A8<00`A2`0;
40X0318900hC2`0:3`X02a4>018F500=40h02Q0=010E4P0A51802a0=00hC400B5A<020d:00lC4P0@
5A/03a@J00hC5`0<4A@03A<C0P0>51403`0?5A<03aDE00`A5@0;41@03A8I00dD5P0>5A@0318B00/A
4@0=4Q<04QHG00lC500@4Q@03a0B010@4P02014B500300X>3@0;4@l04QPF00803aDC00<08BLU00lE
4`0?5A<00P0A5aD200lE4`0400hD4P0;4@l02Q0>00/A3`803Q@B00L020h<00lE4`0<4Q002@l=01`R
800D6QP02a4?00803aDC00@02Q0>00/A3`0>5180318@0`0=4a40:@0<4Q002a4=00lD3`0>4`l0314=
010E4@0?5A<02@l=00/B3`0<5A@03AHE00hF5@094a@02Q@E00`G5@084Q40214>00hB3`0C5A004Q@>
00l?2P0?3``03@l=00hA4@0B5QP07b@T02L[:P0?4a801@T800hB4@072`X03A4@00`@3`0=4A003Q8A
00P<2`0:3Pd0310>00dB3P0>4`l02a0<00803A8>00<0314=00dB3P0<4@d00P0;40`01`0=4Ph051TE
010E4@0B5a<03a@@00P=2@0=4Ph01@0>4`l06`0;40`02a0700dC1@0<4PP0318:00dB300>4`l03A8?
00/?3P0J7a/041D?01<H4P0<4@X0314=00861@0>4Q404ADD02hb<@0?4a804ADD00H:2@0<3Pd020`;
014E500;40d01``800hC3@0200`A2`0400dB300<4@/02a0:00X?2@803a@>00/02Pl900`A2`0?5100
0PH3010E4@0f>cL05AXF00lD400:3`/0314=00dB3P0200`A3@0C00lD400?50h03Q<=00hC3@0?50h0
51TC01LL5P0F6aD0314;014F400@5@l01P/500hC3@093PP0314;00P=1`0?50h02a0:00hC3@0201@I
4`0I00hC3@0:3`T02Pl900hA300A4`d04Q@>00d?1`082@D05aPC00h@2P0<3PP0418=01<E400F61<0
3A0<00dA2`0=4P`0314;00X?2@0C61802a0:00T>200?50h05AXD01@I4`0200`A2`0500dB300=4A00
2Ph=00X>3@0>4Q400P0@51<01`0A5A@03A4@00lC4P0<40l03a<B00L;300=4A@00P0<41@05`0=4AD0
3a8F00lC5`0?4QH03a<G010D600A51P03a8F00hB5@0=4A402`l>014E500>4Q402`l>014E50072`X0
5QXI00`@3`0Q9B@0310?00dA4@011@H06AdN00802Ph?00<03a<D00X>3`0A5AH00P0=4A807@0?4a@0
3Q8C01@H600A5A@041@C00hB4@0<40l02`l>00hB4@093@`03A4@03i2@@0<40l051PG00hA400B5QD0
51PG01<G5P0A5A@041@C014E50031`H04aHE04iBD@0K7ah04QHE00`A3@0>4`l03a@@00803Q<?00T0
4AHB010E4@0>4`l0314=00lD400A5Q804QLC00lD400>4`l00`0=4Ph0400?51002a0<00hC3`0@5A40
3A8>00/@300<4@d01`d900dC3`0@5Q803Q@@010F4P0>5@h031<;018I4@052P@200lG300?00hF2`07
4@H03AL=00@?1`0@6QL0?TM501lX:00:51@031HD00LA30084P`03AP?00`F3@0@5Q8092XX008051XH
01D04aTF00D91P0>51003A<>00hE3P0;4P/020l800lF3`15BDT0<3@e014E5P0<40l03Q<@00dB3P0=
4P`02a0900hC3@0>4``0318900lD3@0>4`h00P0<4@d200/@300400`A3@0?510041DA014F4P8041DA
00<041D?00hD2@0?5@/00P0?5@/02`0<4@X02Pl800hC3@042@D05Q/G00`@3`0E6AP02a0<00lD3`0>
4`d0314;008041D?00X02a0:00T>200>4`d03a@>00hC3@0=4P`03a@>00`A2`0:3`T03A8<0P0@5@l0
100A5Q0051TC018G4@0=4P`300lD3P07010E3`0=4P`03Q<=01DJ500A5Q003A8<014F400201<H4P04
014F400?50h03A8=00dC3`803Q@@00d03A<?00hD400?5A402Q0<00dC3`0C6AD03aDA01@J5P0L8Qh0
4QLC00dB3P0:3P/05AXF00803a@@00P02@h:00hC3`0B5a<03A8>018G4`0=4P`03Q<=014F408041D?
02/04aPB01DJ500@5@l03a@>018G4@0?50h041D?00/@300S:2@05Q/G00/@300=4Ph03a@@00L<200B
5a<04AHB00T>2P0?51004QLC00P?200;4P/041HB014G4`0A5a@041HD014G5@0C6AP03Q@D010F5P0D
6A/03Q<F01HK7`0>51L04ALJ00/B500>51D03aDE014I600=5A<03ADB00lG500>5a@031HB01Cooooo
000Kooooo`<03@`A00<03PdB010?500@3a@01P0;2Pl0=@0>3A802@P=00H52P0920d03PdB00`;4009
20d01@@900P7300?3Q<03@`A00P7300;2`l06aXO00h=4P0A41D020L<00L62`0>3A8030/@00d<4@0?
3Q<03@`A00T:30093P`0310?00dA400=4A803@hB00`=4@0=3Q<03@`D010?5`0?3AP02@LB00P64@0:
2AL040lM01<B800@3ad02@PF00H54`0B4Al08B0^06MVM00A41h05aHT03Hg?`0N7b<020T=01@E6@07
20`030dA00H03PlC02P030hD010C6P062A001PT@010C6P0I72<020/B020S:P0C5Qd02`hE00H94007
2Q405APO02<V;@0000L04A@K04M:D@1FFF806A`V00/=6@0@4Qh05ALS010B7`0B52405QPY030aAP0A
4RH051DY01@E9`0<3Q`0000=01@G800F6B402PdB01TL8@0@51L06AhR014F6P0<4AD041DI0P0?51P0
2P0=4QH04aPL00/@500<4AD04AHJ00hD5P073PL0620E01@L4@0?5``2018J3`0=01DM4P001@004a/@
00D=0P0840D05A`C00X?2`0;3`h03Q8A00lC4P0>4Q40310?014E5002010D4`804QHE0P0@51<0500@
51D02Q8D01lV;00K9B`0[[S10>7[m00Z=3/03QPJ00H;3`0?51D05a/J00H:3@0@51L02`lB00`@4`0D
61/02`lB01@H6`0?4aH03A4D0P0?4aH05P0<41404aLF010D4`0A5AH041<H00hA600A51d051LP0044
3@0H6b806A`R01XM8P0@5A/031<P00/A7`0=4b402a4M00`@6`0=4A`051LP01<C6`0A4AT2014@5P0:
010A5@0?4Q003Q8A01HJ6@0E6AX0310C00dA500>4AH030lF00/>5@802`hG00X02`hE01DI6`0<4140
00@501@H6@021PL04ADF00dA4P0>4Q<02`l@0P0>4Q<03P0@51@061`K00D9200D61L00`L601HJ6@0A
5A@02@d<00/?3P0@51<02Ph=00T=300?4a<041@E0`0A5AH2010D5@0500hB4`0?4a@04ADF014E5P0>
4Q<00P0?4a@0200:3Pl03A4B01HJ6`000P<04QHG01HJ6`0830d03Q8C0P0:3Pl0:@0;3a003A4B010D
5@0:3Pd02@d<020U8@0<4@/02a0:00X?20093`D02Q0600`B1`0K7AP0008000lA3P082PL09bTV00h@
3@0B51403a4>018D4@0<3P/01@L400lB400B5A`041DK00dB5`0;41<02a4?00`B3`0>510041HB010F
5P0<4AD02a0D00hC6P0@5AP03aDE00`B4P093`l0314A008041@E00L03a8C00h?4@0?3a404A4C018C
5@0C5aH020h<00803A<A00@02a4?01PN700F71X04aTG0P1bN7H0300C6AL05Q`J00T?3@0A5aD041HD
00`B400;4@l0318@01<I5`0;4@l04ALE00X@3P8020h<00H02Q0>00dC4@0<4Q002a4?00`B400=4a42
00/A3`0800dC4@0C6AL06R0N01hT800=4Pd04aPD00lD400=4Ph200dC4@0:00/D4@063`h01@h=00/D
4`0230d031HG00PB4@0>5a@03aDA00X>2@802``600H04A0;00/<1`0@4@`030h=01DI6P0:3Pl201<G
5P05010D4`0>4Q4010P700dA400;3`h00P0=4A002P062PT020`;00dA3`0<4@d03a@@014F4P0;40`0
3a@@01PM6@0@5A4200T>2P0P00hC3`0=4Ph03Q<?00lD400B5a<03A8>01DJ5P0P9B404QLC02db;P14
BDD03a@@00870`0G71P0318900dC1@0B60h04aP@014F400?510041@B00D9200@5A403A8<00<80P0<
4@X01``801`P7`0=4A004aLF00H:2@0=4A0200`@3`0I010D4`0;3`h02Ph=00lC4@0>4`l041D?00D:
100I7QP092TS01@I4`083@L01``600lD3P0A5Q002a0:00`A2`093PX051TE00dB3P0A5Q8061dI018G
4`0:3`/0314=00dB3P0200X?2`0M00/@30083@L03Q<=00lD3P0<4@/02a0:00dB30001@005AXD00hC
3@0;40X04AH@00@90`0<4@/04AH@00dB300?50h020d7010E3`0A5Q00<CH`01LL5P0:3`T06AhH00`?
200>3`T010@001LG3`0E5@d00P0;30H04`0D5a002`d900/=200;3@P05QXD018G4@0?50h04aPB00D:
100B5a402@h801`Q6`0S:2801@X401DJ500<4@/02@h801PM5`0?4a800P0;3`h00`0=4A003Q8A00dA
4002010D4`0800hB4@072`X04ADD00hB4`0?4QH030lD00/>4`0<3a@200hA5P0Q018E6P0C5Q/04QDJ
010C600=41D02`lB00X>3P062PT03Q8A00/?3P0:3Pd041@C00040`0A5A@01PX902<W9P0830/02`l?
01hR8`031`P03a<D01LK7013AdP03a<D01@H6@0@51D03Q8C00`@4@093@h041@D00hB4@0=4A002`l>
00<02Ph=01X01`/:014E500=4A004ADD00P<2`0;3`h041@C018F5@0A5A@0310?00X>3@0A5A@06alN
00dA400J7Qd0310?00/=300D6AD04AHB00<8100:3`/06QlK01<H500@5A403Q<?014F4P806AhJ0P0@
5A40?00?51003A8>00`A3@0=4Ph041DA01@I5@0=4Ph01``800hC3`0B5a<03A8>00T?2`0?5A403Q@@
00L=2@0<4Ph04APA01<J4P0;4@X061lG00D=0P094@H01Q05014K400;5P`051lG00TD402S[J`0D5YK
00dG600B71/031LA00XE3`0;5`d0110600D;1`0?5A<0008001PN700k@Ch082HR01PN6P083PT010/4
00L>1`0>5@d06R4J01/O800N8R@041@E00`@3`0<40h02Pl;00lD3P0>4``04QL@010E3P0=4`T03a@=
00dB3@80314=00<03A8>00hC3`0>4`l00P0<4@d200/@300A00dB3P0?50h03Q@9010F300A5`d03aD;
00`A2P0:3`P0314;00hC3`083@T03A4@00H:2@0F6aL041D@00lD3P0;40X00P0@5@l0;P093PP03Q<=
00hC3@0<4@/02a0:010E3`0B5a40314;00X?2@0=4P`04AH@010E3`0A5Q0051TC018G4@0=4P`04QLA
01@I4`0B5a404AH@00hC3@0G71H08bPR01TN600:3`T0314;00lD3P0B5a404AH@00lD3P0@5Q403Q@@
00/A3@0<4Ph03Q@@00lE4@0>51001`d900P>2P0=4`l01@/700P>2P0B5a<020d9010E4@0K81`200lD
400700hC3`0;40`020d900L<20093PX04aPD014F4002018G4@0400lD3P0=4P`03a@>01HK5@803Q<=
00D061dG01LL5P0A5Q004aPD020U8@0200hC3`0N01XO6`0<4@d01``8024V8P0/<Bd04QLC00hC3`0H
7AT041L@01XQ6P0N92003A<?00X@3@0E6aT01`d;04A:B@0H7Qh01P`<00hC5@0E6Qd06ahS01<F6P0G
6ah01@X=00hD5@0A5aL051dL00H?3@0Z<c00<3/g0P0=61@Dooooo`00oooooooooooooooooooo;Ooo
ool00?ooooooooooooooooooobgooooo003oooooooooooooooooool]ooooo`00oooooooooooooooo
oooo;Oooool00?ooooooooooooooooooobgooooo003oooooooooooooooooool]ooooo`00oooooooo
oooooooooooo;Oooool00?ooooooooooooooooooobgooooo003oooooooooooooooooool]ooooo`00
oooooooooooooooooooo;Oooool00?ooooooooooooooooooobgooooo003oooooooooooooooooool]
ooooo`00oooooooooooooooooooo;Oooool00?ooooooooooooooooooobgooooo003ooooooooooooo
ooooool]ooooo`00oooooooooooooooooooo;Oooool00?ooooooooooooooooooobgooooo003ooooo
ooooooooooooool]ooooo`00oooooooooooooooooooo;Oooool00?ooooooooooooooooooobgooooo
003oooooooooooooooooool]ooooo`00oooooooooooooooooooo;Oooool00?oooooooooooooooooo
obgooooo0000\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{270.188, 270.188},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Fig. 7.9 The Andromeda galaxy, at a distance of roughly 2 million \
light years, is the nearest galaxy to our own milky way. Photo Credit:  Bill \
Schoening, Vanessa Harvey/REU program/NOAO/AURA/NSF.\
\>", "Caption",
  CellTags->"Fig. 7.9"],

Cell["\<\
\tHowever, stars interact with many other stars at the same time, \
and the net effect of all these weak interactions is that the galaxy is \
gravitationally bound together. We cannot completely neglect gravity in any \
model of galactic  dynamics; without it,  the galaxy would simply fly apart. \
\
\>", "Text"],

Cell[TextData[{
  "\tWe could, of course, try to keep all of the binary interactions between \
the stars, using a molecular dynamics code to model the  evolution. However, \
the number ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " of stars that can be handled with such a code is at most a few thousand, \
even on very fast  computers. This is because the number of interacting pairs \
equals ",
  Cell[BoxData[
      \(TraditionalForm\`N\ \((N - 1)\)/2\)]],
  ". Taking ",
  Cell[BoxData[
      \(TraditionalForm\`N = 10\^3 - 10\^5\)]],
  " is insufficient to handle many problems in galactic dynamics, considering \
that the galaxy contains roughly ",
  Cell[BoxData[
      \(TraditionalForm\`10\^11\)]],
  " stars (not to mention dust, gas, and other material such as \"dark matter\
\")."
}], "Text"],

Cell[TextData[{
  "\t One approach to modeling large collections of self-gravitating material \
is to go back to the picture of a collisionless gas. For simplicity, we \
consider here a system of identical particles  of mass ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  ", and with phase-space density ",
  Cell[BoxData[
      FormBox[
        RowBox[{"f", "(", 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["p",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["t",
              FontWeight->"Plain"]}], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  ". The evolution of this density is determined by the collisionless \
Boltzmann equation,"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[PartialD]f\/\[PartialD]t\), "+", 
            RowBox[{
              FractionBox[
                StyleBox["p",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox["m",
                  FontWeight->"Plain"]], "\[CenterDot]", \(\[Del]f\)}], "-", 
            RowBox[{"m", " ", 
              RowBox[{\(\[Del]\[Phi]\), "\[CenterDot]", 
                FractionBox[\(\[PartialD]f\), 
                  RowBox[{"\[PartialD]", 
                    StyleBox["p",
                      FontWeight->"Bold",
                      FontSlant->"Plain"]}]]}]}]}], "=", "0"}], 
        TraditionalForm]]],
  "."
}], "NE3",
  CellTags->{"i:54", "(7.3.1)"}],

Cell[TextData[{
  "However,  the gravitational potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " is not imposed from some external source; rather,  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " is created by the mean density itself via Newton's law of gravitation [in \
differential form, Poissons equation ",
  ButtonBox["(4.3.78)",
    ButtonData:>{"Chapter4.nb", "(4.3.78)"},
    ButtonStyle->"Hyperlink"],
  " ]:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2 \[Phi] = 4  \[Pi]\ G\ \[Rho]\)]],
  ","
}], "NE3",
  CellTags->"(7.3.2)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\  = 
        m\ \(\[Integral]f \(\(\[DifferentialD]\^3 p\)\(\ \)\)\)\)]],
  " is the mass density."
}], "Text"],

Cell[TextData[{
  "\tWe should think of  the mass density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " as a reasonably  smooth function of position. This density does not \
contain information concerning the position of individual stars, but rather \
is the mean density of matter  at any given point, averaged over a \"small\" \
volume element (but one that is much larger than the mean distance between \
stars, so that many stars are contained in an element). Thus, the \
gravitational potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " does not tell us about the interaction between individual pairs of stars. \
 Rather, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " is the mean potential due to the smooth \"fluid\" of stars (and anything \
else that contributes to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  ")."
}], "Text"],

Cell[TextData[{
  "\tThis is, in part,  why it is acceptable to take the mass of all the \
stars to be the same: in our model only the mean mass density of the matter \
is important to the mean potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  ".  Also, the gravitational acceleration of a particle is independent of \
that particle's mass: a heavy and a light star will behave identically in a \
given mean potential.  Therefore, we can safely assume our system consists of \
a distribution of like-mass stars."
}], "Text"],

Cell[TextData[{
  "\tIt is worthwhile to note that Eqs. ",
  ButtonBox["(7.3.1)",
    ButtonData:>{"Chapter7.nb", "(7.3.1)"},
    ButtonStyle->"Hyperlink"],
  "  and ",
  ButtonBox["(7.3.2)",
    ButtonData:>{"Chapter7.nb", "(7.3.2)"},
    ButtonStyle->"Hyperlink"],
  "  can also be applied to high-temperature plasmas, which are also nearly \
collisionless. Now ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " is the phase-space density of some species of charged particle, and the \
Coulomb interaction replaces the gravitational interaction. (However, it is \
now important to follow distributions for each species separately because \
particle acceleration now depends on both mass and charge.) In fact, \
equations of this general form appear in several area of physics. Some \
examples will be discussed in the exercises."
}], "Text"],

Cell[TextData[{
  "\tAlthough Eqs. ",
  ButtonBox["(7.3.1)",
    ButtonData:>{"Chapter7.nb", "(7.3.1)"},
    ButtonStyle->"Hyperlink"],
  "  and ",
  ButtonBox["(7.3.2)",
    ButtonData:>{"Chapter7.nb", "(7.3.2)"},
    ButtonStyle->"Hyperlink"],
  "  are much easier to deal with than Newton's equations for all ",
  Cell[BoxData[
      \(TraditionalForm\`10\^11\)]],
  " stars in the galaxy, these equations are still difficult to solve. The \
problem is that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " depends on  the momentum integral over ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  ", so Eq. ",
  ButtonBox["(7.3.1)",
    ButtonData:>{"Chapter7.nb", "(7.3.1)"},
    ButtonStyle->"Hyperlink"],
  "  is  really a nonlinear equation for ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  ". Analytic  solutions of these equations can only be obtained in certain \
highly simplified cases. "
}], "Text"],

Cell[TextData[{
  "\tIn this section, we will discuss one method for solving this nonlinear \
system numerically, called the particle-in-cell (PIC) method. We will then \
consider a few examples, focusing on the phenomenon of gravitational \
collapse. Our examination of this complex process is necessarily limited in \
scope [for more detail see, for example,  ",
  ButtonBox["Binney and Tremaine (1987)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  "], but  it is hoped that the simulation results give some flavor of what \
can be accomplished using the PIC method. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["7.3.2 Strategy of the PIC Method", "Subsubtitle",
  CellTags->"c:29"],

Cell[TextData[{
  "\tWe will solve Eqs. ",
  ButtonBox["(7.3.1)",
    ButtonData:>{"Chapter7.nb", "(7.3.1)"},
    ButtonStyle->"Hyperlink"],
  "   and ",
  ButtonBox["(7.3.2)",
    ButtonData:>{"Chapter7.nb", "(7.3.2)"},
    ButtonStyle->"Hyperlink"],
  "  in periodic boundary conditions in two spatial dimensions. (The \
following code can be easily modified for three spatial dimensions, but runs \
too slowly to be of much utility, unless it is adapted for use with a \
compiled language such a Fortran or C, and run on a fast computer. Modifying \
the code to run in one dimension is left to the exercises.) The simulation \
box contains the ranges  ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < L\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`0 < y < L\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\t The strategy  for solving Eqs. ",
  ButtonBox["(7.3.1)",
    ButtonData:>{"Chapter7.nb", "(7.3.1)"},
    ButtonStyle->"Hyperlink"],
  "  and ",
  ButtonBox["(7.3.2)",
    ButtonData:>{"Chapter7.nb", "(7.3.2)"},
    ButtonStyle->"Hyperlink"],
  "  in this periodic 2D domain is similar to that used previously in solving \
the collisionless Boltzmann equation: basically, we solve for the dynamics of \
a large number of particles, and determine the density using histograms of \
the particle positions. These particles should not be thought of as \
individual stars. Rather, a single particle  represents  a whole cloud of \
stars, and is located at this cloud's center of mass. The mean density is a \
superposition of these clouds. Thus, we can still model a galaxy or other \
large stellar system using far fewer than ",
  Cell[BoxData[
      \(TraditionalForm\`10\^11\)]],
  " particles."
}], "Text"],

Cell["\t  Broken down into individual steps,  at each time step, ", "Text"],

Cell[TextData[{
  "(1) We make a histogram of the particle positions on an ",
  Cell[BoxData[
      \(TraditionalForm\`M\ by\ M\)]],
  " spatial grid in order to determine the mass density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " on  the grid."
}], "Text"],

Cell[TextData[{
  "(2) We use this density in Poissons equation to solve for the potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " on the grid using Eq. ",
  ButtonBox["(7.3.2)",
    ButtonData:>{"Chapter7.nb", "(7.3.2)"},
    ButtonStyle->"Hyperlink"],
  " . We also determine  the gradient of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " (i.e. the force field), evaluated at the grid positions. "
}], "Text"],

Cell["\<\
(3) We then interpolate the force field  from the values at the \
grid positions back to the particle positions, and update the positions and \
velocities of the particles to the next time step using Newtons second law.\
\
\>", "Text"],

Cell[TextData[{
  " These three tasks are shown schematically in Fig. ",
  ButtonBox["7.10",
    ButtonData:>"Fig. 7.10",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .65625 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.015625 0.31746 [
[ 0 0 0 0 ]
[ 1 .65625 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .65625 L
0 .65625 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
% Start of sub-graphic
p
0.0238095 0.015625 0.321429 0.313244 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.5 .82364 -10.625 0 ]
[.5 .82364 10.625 12.9375 ]
[.15237 .19707 -5.94882 -9 ]
[.15237 .19707 .05118 0 ]
[.31741 .13214 -11.2392 -9 ]
[.31741 .13214 .76076 0 ]
[.49342 .06293 -10.5808 -9 ]
[.49342 .06293 1.41915 0 ]
[.68156 -0.01098 -9.92245 -9 ]
[.68156 -0.01098 2.07755 0 ]
[.77078 .10213 0 -6.15691 ]
[.77078 .10213 6 2.84309 ]
[.84915 .22213 0 -6.0419 ]
[.84915 .22213 12 2.9581 ]
[.9191 .32925 0 -5.94182 ]
[.9191 .32925 12 3.05818 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 12 3.14607 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -71.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.9375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(i) show
75.000 14.562 moveto
(j) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.16157 .20642 m
.16617 .2111 L
s
[(5)] .15237 .19707 .98294 1 Mshowa
.32604 .14202 m
.33035 .14696 L
s
[(10)] .31741 .13214 .87321 1 Mshowa
.50139 .07336 m
.50537 .07857 L
s
[(15)] .49342 .06293 .76347 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(20)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.19364 .19386 m
.19637 .1967 L
s
.22611 .18115 m
.22881 .18402 L
s
.259 .16827 m
.26166 .17117 L
s
.29231 .15523 m
.29493 .15816 L
s
.3602 .12864 m
.36275 .13164 L
s
.39481 .11509 m
.39732 .11812 L
s
.42987 .10136 m
.43235 .10443 L
s
.4654 .08745 m
.46783 .09055 L
s
.53786 .05908 m
.5402 .06224 L
s
.57482 .04461 m
.57712 .0478 L
s
.61228 .02994 m
.61453 .03317 L
s
.65025 .01507 m
.65245 .01833 L
s
.12989 .21883 m
.13268 .2216 L
s
.0986 .23108 m
.10142 .23383 L
s
.06769 .24318 m
.07054 .2459 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.75847 .10666 m
.75231 .10893 L
s
[(5)] .77078 .10213 -1 .3682 Mshowa
.83673 .22638 m
.83053 .22851 L
s
[(10)] .84915 .22213 -1 .34264 Mshowa
.9066 .33325 m
.90035 .33526 L
s
[(15)] .9191 .32925 -1 .3204 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(20)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.77486 .13175 m
.77116 .13309 L
s
.79088 .15624 m
.78717 .15756 L
s
.80652 .18016 m
.8028 .18147 L
s
.8218 .20354 m
.81808 .20483 L
s
.85133 .24872 m
.8476 .24998 L
s
.86561 .27055 m
.86188 .2718 L
s
.87957 .29191 m
.87583 .29314 L
s
.89323 .31281 m
.88949 .31402 L
s
.91968 .35327 m
.91593 .35445 L
s
.93249 .37286 m
.92873 .37403 L
s
.94503 .39204 m
.94127 .3932 L
s
.95731 .41083 m
.95355 .41198 L
s
.74167 .08097 m
.73798 .08235 L
s
.72446 .05465 m
.72078 .05604 L
s
.70682 .02766 m
.70315 .02908 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.664 .741 .908 r
.38897 .58867 .40512 .60371 .43216 .5956 .41618 .58041 Metetra
.664 .741 .908 r
.41618 .58041 .43216 .5956 .45948 .58741 .44367 .57206 Metetra
.664 .741 .908 r
.44367 .57206 .45948 .58741 .48707 .57913 .47145 .56362 Metetra
.664 .741 .908 r
.47145 .56362 .48707 .57913 .51495 .57077 .4995 .5551 Metetra
.664 .741 .908 r
.4995 .5551 .51495 .57077 .54311 .56232 .52785 .54649 Metetra
.664 .741 .908 r
.52785 .54649 .54311 .56232 .57156 .55378 .5565 .53779 Metetra
.664 .741 .908 r
.5565 .53779 .57156 .55378 .6003 .54516 .58544 .529 Metetra
.664 .741 .908 r
.58544 .529 .6003 .54516 .62935 .53645 .61469 .52012 Metetra
.664 .741 .908 r
.61469 .52012 .62935 .53645 .6587 .52764 .64425 .51114 Metetra
.664 .741 .908 r
.64425 .51114 .6587 .52764 .68836 .51874 .67412 .50207 Metetra
.664 .741 .908 r
.67412 .50207 .68836 .51874 .71833 .50975 .70431 .4929 Metetra
.664 .741 .908 r
.70431 .4929 .71833 .50975 .74862 .50066 .73483 .48363 Metetra
.664 .741 .908 r
.73483 .48363 .74862 .50066 .77923 .49148 .76568 .47426 Metetra
.664 .741 .908 r
.76568 .47426 .77923 .49148 .81018 .4822 .79686 .46479 Metetra
.664 .741 .908 r
.79686 .46479 .81018 .4822 .84146 .47281 .82838 .45522 Metetra
.664 .741 .908 r
.82838 .45522 .84146 .47281 .87308 .46333 .86025 .44554 Metetra
.664 .741 .908 r
.86025 .44554 .87308 .46333 .90504 .45374 .89247 .43576 Metetra
.664 .741 .908 r
.89247 .43576 .90504 .45374 .93736 .44404 .92505 .42586 Metetra
.664 .741 .908 r
.92505 .42586 .93736 .44404 .97003 .43424 .95799 .41586 Metetra
.664 .741 .908 r
.37251 .57335 .38897 .58867 .41618 .58041 .3999 .56493 Metetra
.664 .741 .908 r
.3999 .56493 .41618 .58041 .44367 .57206 .42757 .55642 Metetra
.664 .741 .908 r
.42757 .55642 .44367 .57206 .47145 .56362 .45552 .54782 Metetra
.664 .741 .908 r
.45552 .54782 .47145 .56362 .4995 .5551 .48377 .53914 Metetra
.664 .741 .908 r
.48377 .53914 .4995 .5551 .52785 .54649 .51231 .53036 Metetra
.664 .741 .908 r
.51231 .53036 .52785 .54649 .5565 .53779 .54115 .52149 Metetra
.544 .699 .941 r
.54115 .52149 .5565 .53779 .58544 .529 .57039 .51998 Metetra
.689 .855 .962 r
.57039 .51998 .58544 .529 .61469 .52012 .59985 .50821 Metetra
.357 .681 .978 r
.59985 .50821 .61469 .52012 .64425 .51114 .63006 .51134 Metetra
.039 .608 .724 r
.63006 .51134 .64425 .51114 .67412 .50207 .66064 .51029 Metetra
.793 .98 .706 r
.66064 .51029 .67412 .50207 .70431 .4929 .69002 .47571 Metetra
.664 .741 .908 r
.69002 .47571 .70431 .4929 .73483 .48363 .72077 .46626 Metetra
.664 .741 .908 r
.72077 .46626 .73483 .48363 .76568 .47426 .75185 .4567 Metetra
.664 .741 .908 r
.75185 .4567 .76568 .47426 .79686 .46479 .78327 .44704 Metetra
.664 .741 .908 r
.78327 .44704 .79686 .46479 .82838 .45522 .81504 .43727 Metetra
.664 .741 .908 r
.81504 .43727 .82838 .45522 .86025 .44554 .84716 .42739 Metetra
.664 .741 .908 r
.84716 .42739 .86025 .44554 .89247 .43576 .87963 .4174 Metetra
.664 .741 .908 r
.87963 .4174 .89247 .43576 .92505 .42586 .91248 .4073 Metetra
.664 .741 .908 r
.91248 .4073 .92505 .42586 .95799 .41586 .94569 .39709 Metetra
.664 .741 .908 r
.35574 .55773 .37251 .57335 .3999 .56493 .3833 .54915 Metetra
.664 .741 .908 r
.3833 .54915 .3999 .56493 .42757 .55642 .41115 .54048 Metetra
.664 .741 .908 r
.41115 .54048 .42757 .55642 .45552 .54782 .43929 .53172 Metetra
.664 .741 .908 r
.43929 .53172 .45552 .54782 .48377 .53914 .46772 .52286 Metetra
.664 .741 .908 r
.46772 .52286 .48377 .53914 .51231 .53036 .49646 .51391 Metetra
.578 .713 .935 r
.49646 .51391 .51231 .53036 .54115 .52149 .5255 .51049 Metetra
.754 .248 0 r
.5255 .51049 .54115 .52149 .57039 .51998 .55532 .54882 Metetra
.55532 .54882 .57039 .51998 .59985 .50821 .58481 .50329 Metetra
.75 .231 0 r
.58481 .50329 .59985 .50821 .63006 .51134 .61614 .53782 Metetra
.255 0 .09 r
.61614 .53782 .63006 .51134 .66064 .51029 .64678 .52206 Metetra
.64678 .52206 .66064 .51029 .69002 .47571 .6777 .50739 Metetra
.128 0 .098 r
.6777 .50739 .69002 .47571 .72077 .46626 .70812 .47929 Metetra
.015 0 0 r
.70812 .47929 .72077 .46626 .75185 .4567 .73945 .46501 Metetra
.7 .946 .659 r
.73945 .46501 .75185 .4567 .78327 .44704 .76967 .43249 Metetra
.706 .802 .924 r
.76967 .43249 .78327 .44704 .81504 .43727 .80142 .41895 Metetra
.664 .741 .908 r
.80142 .41895 .81504 .43727 .84716 .42739 .83379 .40887 Metetra
.664 .741 .908 r
.83379 .40887 .84716 .42739 .87963 .4174 .86653 .39867 Metetra
.664 .741 .908 r
.86653 .39867 .87963 .4174 .91248 .4073 .89965 .38836 Metetra
.664 .741 .908 r
.89965 .38836 .91248 .4073 .94569 .39709 .93314 .37793 Metetra
.664 .741 .908 r
.33865 .54182 .35574 .55773 .3833 .54915 .36639 .53307 Metetra
.664 .741 .908 r
.36639 .53307 .3833 .54915 .41115 .54048 .39441 .52423 Metetra
.664 .741 .908 r
.39441 .52423 .41115 .54048 .43929 .53172 .42274 .5153 Metetra
.664 .741 .908 r
.42274 .5153 .43929 .53172 .46772 .52286 .45136 .50627 Metetra
.664 .741 .908 r
.45136 .50627 .46772 .52286 .49646 .51391 .48029 .49714 Metetra
.468 .667 .949 r
.48029 .49714 .49646 .51391 .5255 .51049 .50948 .49878 Metetra
0 .464 .861 r
.50948 .49878 .5255 .51049 .55532 .54882 .53922 .51022 Metetra
.667 .591 .761 r
.53922 .51022 .55532 .54882 .58481 .50329 .56933 .49653 Metetra
0 .431 .76 r
.56933 .49653 .58481 .50329 .61614 .53782 .60022 .50631 Metetra
.656 .623 .805 r
.60022 .50631 .61614 .53782 .64678 .52206 .63116 .49586 Metetra
.604 .637 .856 r
.63116 .49586 .64678 .52206 .6777 .50739 .66269 .49133 Metetra
.692 .776 .916 r
.66269 .49133 .6777 .50739 .70812 .47929 .69426 .47898 Metetra
0 .574 .714 r
.69426 .47898 .70812 .47929 .73945 .46501 .72694 .47941 Metetra
.407 0 0 r
.72694 .47941 .73945 .46501 .76967 .43249 .76023 .48035 Metetra
0 0 .069 r
.76023 .48035 .76967 .43249 .80142 .41895 .78784 .40419 Metetra
.71 .808 .926 r
.78784 .40419 .80142 .41895 .83379 .40887 .82015 .38995 Metetra
.664 .741 .908 r
.82015 .38995 .83379 .40887 .86653 .39867 .85316 .37954 Metetra
.664 .741 .908 r
.85316 .37954 .86653 .39867 .89965 .38836 .88654 .36901 Metetra
.664 .741 .908 r
.88654 .36901 .89965 .38836 .93314 .37793 .92032 .35836 Metetra
.664 .741 .908 r
.32123 .5256 .33865 .54182 .36639 .53307 .34914 .51668 Metetra
.664 .741 .908 r
.34914 .51668 .36639 .53307 .39441 .52423 .37735 .50766 Metetra
.664 .741 .908 r
.37735 .50766 .39441 .52423 .42274 .5153 .40586 .49855 Metetra
.452 .663 .952 r
.40586 .49855 .42274 .5153 .45136 .50627 .43438 .50055 Metetra
.126 .641 .892 r
.43438 .50055 .45136 .50627 .48029 .49714 .46338 .50321 Metetra
.46338 .50321 .48029 .49714 .50948 .49878 .49301 .49622 Metetra
.562 .911 .968 r
.49301 .49622 .50948 .49878 .53922 .51022 .523 .48572 Metetra
.386 .541 .888 r
.523 .48572 .53922 .51022 .56933 .49653 .55348 .4945 Metetra
.223 0 0 r
.55348 .4945 .56933 .49653 .60022 .50631 .5846 .50166 Metetra
.929 .889 .77 r
.5846 .50166 .60022 .50631 .63116 .49586 .61492 .45518 Metetra
.122 .259 .733 r
.61492 .45518 .63116 .49586 .66269 .49133 .64791 .49006 Metetra
.842 .98 .872 r
.64791 .49006 .66269 .49133 .69426 .47898 .67915 .46146 Metetra
.673 .759 .915 r
.67915 .46146 .69426 .47898 .72694 .47941 .7114 .45034 Metetra
.078 .311 .792 r
.7114 .45034 .72694 .47941 .76023 .48035 .74666 .47888 Metetra
.987 .867 .628 r
.74666 .47888 .76023 .48035 .78784 .40419 .7746 .39764 Metetra
.838 .943 .892 r
.7746 .39764 .78784 .40419 .82015 .38995 .80622 .37064 Metetra
.664 .741 .908 r
.80622 .37064 .82015 .38995 .85316 .37954 .8395 .36001 Metetra
.664 .741 .908 r
.8395 .36001 .85316 .37954 .88654 .36901 .87316 .34925 Metetra
.664 .741 .908 r
.87316 .34925 .88654 .36901 .92032 .35836 .90722 .33837 Metetra
.664 .741 .908 r
.30346 .50906 .32123 .5256 .34914 .51668 .33156 .49996 Metetra
.664 .741 .908 r
.33156 .49996 .34914 .51668 .37735 .50766 .35995 .49077 Metetra
.664 .741 .908 r
.35995 .49077 .37735 .50766 .40586 .49855 .38865 .48148 Metetra
.533 .697 .944 r
.38865 .48148 .40586 .49855 .43438 .50055 .41741 .47991 Metetra
.814 .366 0 r
.41741 .47991 .43438 .50055 .46338 .50321 .44533 .53284 Metetra
.747 .383 .365 r
.44533 .53284 .46338 .50321 .49301 .49622 .47481 .57722 Metetra
.013 0 .217 r
.47481 .57722 .49301 .49622 .523 .48572 .50628 .50429 Metetra
.194 0 0 r
.50628 .50429 .523 .48572 .55348 .4945 .53715 .49369 Metetra
.544 0 0 r
.53715 .49369 .55348 .4945 .5846 .50166 .56871 .51083 Metetra
.926 .972 .697 r
.56871 .51083 .5846 .50166 .61492 .45518 .59962 .46047 Metetra
.856 .434 .224 r
.59962 .46047 .61492 .45518 .64791 .49006 .63388 .52601 Metetra
.63388 .52601 .64791 .49006 .67915 .46146 .66405 .45132 Metetra
.878 .876 .829 r
.66405 .45132 .67915 .46146 .7114 .45034 .69538 .41623 Metetra
.199 .355 .796 r
.69538 .41623 .7114 .45034 .74666 .47888 .73044 .44219 Metetra
.553 .555 .81 r
.73044 .44219 .74666 .47888 .7746 .39764 .76479 .44279 Metetra
.76479 .44279 .7746 .39764 .80622 .37064 .79292 .36191 Metetra
.786 .921 .928 r
.79292 .36191 .80622 .37064 .8395 .36001 .82554 .34005 Metetra
.664 .741 .908 r
.82554 .34005 .8395 .36001 .87316 .34925 .85949 .32906 Metetra
.664 .741 .908 r
.85949 .32906 .87316 .34925 .90722 .33837 .89384 .31795 Metetra
.664 .741 .908 r
.28535 .49219 .30346 .50906 .33156 .49996 .31362 .48291 Metetra
.664 .741 .908 r
.31362 .48291 .33156 .49996 .35995 .49077 .34221 .47354 Metetra
.612 .726 .927 r
.34221 .47354 .35995 .49077 .38865 .48148 .37093 .46761 Metetra
.034 .476 .881 r
.37093 .46761 .38865 .48148 .41741 .47991 .3994 .47844 Metetra
.742 .233 .001 r
.3994 .47844 .41741 .47991 .44533 .53284 .42801 .5076 Metetra
.526 .615 .884 r
.42801 .5076 .44533 .53284 .47481 .57722 .45823 .50822 Metetra
.658 .519 .683 r
.45823 .50822 .47481 .57722 .50628 .50429 .48922 .48666 Metetra
.768 .775 .859 r
.48922 .48666 .50628 .50429 .53715 .49369 .52034 .46548 Metetra
.741 .685 .797 r
.52034 .46548 .53715 .49369 .56871 .51083 .55159 .443 Metetra
.492 .416 .698 r
.55159 .443 .56871 .51083 .59962 .46047 .58358 .45538 Metetra
.729 .2 0 r
.58358 .45538 .59962 .46047 .63388 .52601 .61703 .49121 Metetra
.806 .683 .728 r
.61703 .49121 .63388 .52601 .66405 .45132 .64878 .44747 Metetra
.245 .742 .908 r
.64878 .44747 .66405 .45132 .69538 .41623 .68224 .44525 Metetra
.68224 .44525 .69538 .41623 .73044 .44219 .71406 .40538 Metetra
.42 .48 .816 r
.71406 .40538 .73044 .44219 .76479 .44279 .74928 .41776 Metetra
.842 .753 .765 r
.74928 .41776 .76479 .44279 .79292 .36191 .78112 .37644 Metetra
.723 .881 .481 r
.78112 .37644 .79292 .36191 .82554 .34005 .81189 .3263 Metetra
.74 .851 .932 r
.81189 .3263 .82554 .34005 .85949 .32906 .84552 .30844 Metetra
.664 .741 .908 r
.84552 .30844 .85949 .32906 .89384 .31795 .88016 .29707 Metetra
.664 .741 .908 r
.26687 .47499 .28535 .49219 .31362 .48291 .29533 .46553 Metetra
.664 .741 .908 r
.29533 .46553 .31362 .48291 .34221 .47354 .3241 .45596 Metetra
.454 .665 .953 r
.3241 .45596 .34221 .47354 .37093 .46761 .35261 .45739 Metetra
.427 .76 .996 r
.35261 .45739 .37093 .46761 .3994 .47844 .38175 .45597 Metetra
.51 .635 .909 r
.38175 .45597 .3994 .47844 .42801 .5076 .41129 .45655 Metetra
.168 .246 .701 r
.41129 .45655 .42801 .5076 .45823 .50822 .44052 .4902 Metetra
.035 .427 .867 r
.44052 .4902 .45823 .50822 .48922 .48666 .47121 .50489 Metetra
.47121 .50489 .48922 .48666 .52034 .46548 .50302 .475 Metetra
.744 .282 .152 r
.50302 .475 .52034 .46548 .55159 .443 .53502 .50877 Metetra
.489 .173 .357 r
.53502 .50877 .55159 .443 .58358 .45538 .56774 .50349 Metetra
0 0 .098 r
.56774 .50349 .58358 .45538 .61703 .49121 .60003 .45758 Metetra
.814 .692 .73 r
.60003 .45758 .61703 .49121 .64878 .44747 .63202 .41264 Metetra
.527 .555 .827 r
.63202 .41264 .64878 .44747 .68224 .44525 .66574 .41468 Metetra
.398 .515 .86 r
.66574 .41468 .68224 .44525 .71406 .40538 .70058 .42508 Metetra
.70058 .42508 .71406 .40538 .74928 .41776 .73287 .38268 Metetra
.404 .487 .831 r
.73287 .38268 .74928 .41776 .78112 .37644 .76905 .39511 Metetra
.816 .872 .432 r
.76905 .39511 .78112 .37644 .81189 .3263 .79904 .32549 Metetra
.882 .991 .795 r
.79904 .32549 .81189 .3263 .84552 .30844 .83124 .28735 Metetra
.664 .741 .908 r
.83124 .28735 .84552 .30844 .88016 .29707 .86618 .27574 Metetra
.664 .741 .908 r
.24802 .45744 .26687 .47499 .29533 .46553 .27667 .44778 Metetra
.664 .741 .908 r
.27667 .44778 .29533 .46553 .3241 .45596 .30563 .43802 Metetra
.819 .352 0 r
.30563 .43802 .3241 .45596 .35261 .45739 .33167 .48364 Metetra
.134 0 0 r
.33167 .48364 .35261 .45739 .38175 .45597 .36207 .46768 Metetra
.842 .994 .748 r
.36207 .46768 .38175 .45597 .41129 .45655 .39357 .43019 Metetra
.138 .394 .845 r
.39357 .43019 .41129 .45655 .44052 .4902 .4232 .44751 Metetra
0 .173 .691 r
.4232 .44751 .44052 .4902 .47121 .50489 .45327 .48387 Metetra
.891 .754 .703 r
.45327 .48387 .47121 .50489 .50302 .475 .48583 .41873 Metetra
0 0 .378 r
.48583 .41873 .50302 .475 .53502 .50877 .51735 .5012 Metetra
.88 .447 .136 r
.51735 .5012 .53502 .50877 .56774 .50349 .55102 .57409 Metetra
.55102 .57409 .56774 .50349 .60003 .45758 .58361 .46901 Metetra
.991 .888 .588 r
.58361 .46901 .60003 .45758 .63202 .41264 .61502 .37628 Metetra
.633 .604 .803 r
.61502 .37628 .63202 .41264 .66574 .41468 .64833 .36665 Metetra
.631 .556 .751 r
.64833 .36665 .66574 .41468 .70058 .42508 .68198 .35528 Metetra
.606 .49 .695 r
.68198 .35528 .70058 .42508 .73287 .38268 .71612 .34514 Metetra
.258 .384 .8 r
.71612 .34514 .73287 .38268 .76905 .39511 .75311 .36865 Metetra
.918 .76 .671 r
.75311 .36865 .76905 .39511 .79904 .32549 .7831 .29293 Metetra
.755 .688 .788 r
.7831 .29293 .79904 .32549 .83124 .28735 .81664 .2658 Metetra
.664 .741 .908 r
.81664 .2658 .83124 .28735 .86618 .27574 .85189 .25392 Metetra
.664 .741 .908 r
.22879 .43953 .24802 .45744 .27667 .44778 .25763 .42968 Metetra
.664 .741 .908 r
.25763 .42968 .27667 .44778 .30563 .43802 .28678 .41972 Metetra
.367 .624 .951 r
.28678 .41972 .30563 .43802 .33167 .48364 .31534 .42392 Metetra
.495 .432 .715 r
.31534 .42392 .33167 .48364 .36207 .46768 .34428 .43174 Metetra
.285 .406 .81 r
.34428 .43174 .36207 .46768 .39357 .43019 .37349 .44811 Metetra
.923 .964 .657 r
.37349 .44811 .39357 .43019 .4232 .44751 .40627 .3907 Metetra
.244 .28 .701 r
.40627 .3907 .4232 .44751 .45327 .48387 .4361 .42136 Metetra
.377 .354 .707 r
.4361 .42136 .45327 .48387 .48583 .41873 .46723 .4436 Metetra
.46723 .4436 .48583 .41873 .51735 .5012 .49976 .41703 Metetra
.613 .473 .668 r
.49976 .41703 .51735 .5012 .55102 .57409 .53239 .40279 Metetra
.545 .376 .603 r
.53239 .40279 .55102 .57409 .58361 .46901 .56555 .40485 Metetra
.771 .598 .664 r
.56555 .40485 .58361 .46901 .61502 .37628 .59797 .34589 Metetra
.749 .692 .797 r
.59797 .34589 .61502 .37628 .64833 .36665 .63092 .32091 Metetra
.362 .406 .772 r
.63092 .32091 .64833 .36665 .68198 .35528 .66593 .33966 Metetra
0 .187 .672 r
.66593 .33966 .68198 .35528 .71612 .34514 .70248 .3665 Metetra
.70248 .3665 .71612 .34514 .75311 .36865 .7361 .33017 Metetra
.823 .689 .716 r
.7361 .33017 .75311 .36865 .7831 .29293 .76852 .28018 Metetra
.88 .89 .835 r
.76852 .28018 .7831 .29293 .81664 .2658 .80172 .24376 Metetra
.664 .741 .908 r
.80172 .24376 .81664 .2658 .85189 .25392 .83727 .23161 Metetra
.664 .741 .908 r
.20917 .42126 .22879 .43953 .25763 .42968 .23819 .4112 Metetra
.664 .741 .908 r
.23819 .4112 .25763 .42968 .28678 .41972 .26753 .40103 Metetra
.655 .739 .911 r
.26753 .40103 .28678 .41972 .31534 .42392 .29716 .39141 Metetra
.407 .503 .845 r
.29716 .39141 .31534 .42392 .34428 .43174 .32605 .39948 Metetra
.311 .453 .842 r
.32605 .39948 .34428 .43174 .37349 .44811 .35536 .41225 Metetra
.678 .624 .788 r
.35536 .41225 .37349 .44811 .40627 .3907 .38668 .39674 Metetra
.175 0 0 r
.38668 .39674 .40627 .3907 .4361 .42136 .41777 .39634 Metetra
0 .114 .654 r
.41777 .39634 .4361 .42136 .46723 .4436 .44871 .42641 Metetra
.327 .633 .962 r
.44871 .42641 .46723 .4436 .49976 .41703 .48118 .43109 Metetra
.973 .926 .628 r
.48118 .43109 .49976 .41703 .53239 .40279 .51463 .35536 Metetra
.705 .598 .734 r
.51463 .35536 .53239 .40279 .56555 .40485 .54749 .32984 Metetra
.452 .381 .686 r
.54749 .32984 .56555 .40485 .59797 .34589 .58121 .34659 Metetra
.739 .99 .881 r
.58121 .34659 .59797 .34589 .63092 .32091 .61475 .32194 Metetra
.861 .994 .821 r
.61475 .32194 .63092 .32091 .66593 .33966 .64799 .2864 Metetra
.659 .559 .73 r
.64799 .2864 .66593 .33966 .70248 .3665 .682 .268 Metetra
.576 .435 .653 r
.682 .268 .70248 .3665 .7361 .33017 .71699 .26096 Metetra
.632 .509 .695 r
.71699 .26096 .7361 .33017 .76852 .28018 .7518 .24389 Metetra
.718 .658 .79 r
.7518 .24389 .76852 .28018 .80172 .24376 .78645 .22121 Metetra
.664 .741 .908 r
.78645 .22121 .80172 .24376 .83727 .23161 .82231 .20878 Metetra
.664 .741 .908 r
.18913 .4026 .20917 .42126 .23819 .4112 .21834 .39234 Metetra
.664 .741 .908 r
.21834 .39234 .23819 .4112 .26753 .40103 .24788 .38195 Metetra
.659 .74 .91 r
.24788 .38195 .26753 .40103 .29716 .39141 .27774 .37178 Metetra
.762 .281 0 r
.27774 .37178 .29716 .39141 .32605 .39948 .3044 .4135 Metetra
.485 0 0 r
.3044 .4135 .32605 .39948 .35536 .41225 .3344 .42092 Metetra
.3344 .42092 .35536 .41225 .38668 .39674 .36601 .40999 Metetra
.59 .915 .676 r
.36601 .40999 .38668 .39674 .41777 .39634 .39864 .38252 Metetra
0 .451 .849 r
.39864 .38252 .41777 .39634 .44871 .42641 .43016 .39432 Metetra
.382 .508 .861 r
.43016 .39432 .44871 .42641 .48118 .43109 .46259 .40352 Metetra
.897 .736 .674 r
.46259 .40352 .48118 .43109 .51463 .35536 .49662 .32401 Metetra
.681 .662 .825 r
.49662 .32401 .51463 .35536 .54749 .32984 .52974 .30886 Metetra
.286 .564 .932 r
.52974 .30886 .54749 .32984 .58121 .34659 .56346 .31724 Metetra
.151 .391 .84 r
.56346 .31724 .58121 .34659 .61475 .32194 .5983 .33707 Metetra
.722 .923 .58 r
.5983 .33707 .61475 .32194 .64799 .2864 .63207 .29282 Metetra
.776 .987 .744 r
.63207 .29282 .64799 .2864 .682 .268 .66594 .25715 Metetra
.859 .908 .866 r
.66594 .25715 .682 .268 .71699 .26096 .6999 .22483 Metetra
.653 .629 .814 r
.6999 .22483 .71699 .26096 .7518 .24389 .73517 .21175 Metetra
.663 .661 .838 r
.73517 .21175 .7518 .24389 .78645 .22121 .77083 .19815 Metetra
.664 .741 .908 r
.77083 .19815 .78645 .22121 .82231 .20878 .80701 .18543 Metetra
.664 .741 .908 r
.16868 .38356 .18913 .4026 .21834 .39234 .19808 .37308 Metetra
.664 .741 .908 r
.19808 .37308 .21834 .39234 .24788 .38195 .22782 .36247 Metetra
.664 .741 .908 r
.22782 .36247 .24788 .38195 .27774 .37178 .2579 .35174 Metetra
0 .322 .796 r
.2579 .35174 .27774 .37178 .3044 .4135 .28626 .36856 Metetra
.277 .357 .766 r
.28626 .36856 .3044 .4135 .3344 .42092 .31535 .38764 Metetra
.646 .631 .821 r
.31535 .38764 .3344 .42092 .36601 .40999 .34706 .37661 Metetra
.559 .592 .843 r
.34706 .37661 .36601 .40999 .39864 .38252 .37876 .37394 Metetra
.868 .887 .847 r
.37876 .37394 .39864 .38252 .43016 .39432 .41213 .33982 Metetra
.043 .164 .666 r
.41213 .33982 .43016 .39432 .46259 .40352 .44354 .38021 Metetra
.878 .763 .732 r
.44354 .38021 .46259 .40352 .49662 .32401 .47785 .32475 Metetra
.82 .992 .868 r
.47785 .32475 .49662 .32401 .52974 .30886 .51155 .29488 Metetra
.591 .81 .983 r
.51155 .29488 .52974 .30886 .56346 .31724 .5454 .28648 Metetra
.639 .657 .851 r
.5454 .28648 .56346 .31724 .5983 .33707 .57971 .27588 Metetra
0 .058 .599 r
.57971 .27588 .5983 .33707 .63207 .29282 .61659 .33753 Metetra
.006 0 .046 r
.61659 .33753 .63207 .29282 .66594 .25715 .65145 .29668 Metetra
.724 .766 .267 r
.65145 .29668 .66594 .25715 .6999 .22483 .68325 .20115 Metetra
.675 .739 .899 r
.68325 .20115 .6999 .22483 .73517 .21175 .71879 .18739 Metetra
.663 .731 .9 r
.71879 .18739 .73517 .21175 .77083 .19815 .75484 .17454 Metetra
.664 .741 .908 r
.75484 .17454 .77083 .19815 .80701 .18543 .79135 .16152 Metetra
.664 .741 .908 r
.14779 .36411 .16868 .38356 .19808 .37308 .17739 .3534 Metetra
.664 .741 .908 r
.17739 .3534 .19808 .37308 .22782 .36247 .20732 .34257 Metetra
.664 .741 .908 r
.20732 .34257 .22782 .36247 .2579 .35174 .23761 .33161 Metetra
.631 .732 .92 r
.23761 .33161 .2579 .35174 .28626 .36856 .26806 .32292 Metetra
.603 .548 .765 r
.26806 .32292 .28626 .36856 .31535 .38764 .29884 .31514 Metetra
.575 .462 .687 r
.29884 .31514 .31535 .38764 .34706 .37661 .32995 .30891 Metetra
.238 .25 .67 r
.32995 .30891 .34706 .37661 .37876 .37394 .35953 .34112 Metetra
.818 .702 .736 r
.35953 .34112 .37876 .37394 .41213 .33982 .39363 .29581 Metetra
.55 .531 .788 r
.39363 .29581 .41213 .33982 .44354 .38021 .42605 .29406 Metetra
.374 .31 .656 r
.42605 .29406 .44354 .38021 .47785 .32475 .45848 .32081 Metetra
.548 .907 .965 r
.45848 .32081 .47785 .32475 .51155 .29488 .49256 .30873 Metetra
.664 .93 .643 r
.49256 .30873 .51155 .29488 .5454 .28648 .52704 .27309 Metetra
.432 .756 .995 r
.52704 .27309 .5454 .28648 .57971 .27588 .56183 .27078 Metetra
.776 .965 .925 r
.56183 .27078 .57971 .27588 .61659 .33753 .59677 .24632 Metetra
.659 .497 .654 r
.59677 .24632 .61659 .33753 .65145 .29668 .63162 .21401 Metetra
.683 .522 .662 r
.63162 .21401 .65145 .29668 .68325 .20115 .66625 .17744 Metetra
.673 .744 .903 r
.66625 .17744 .68325 .20115 .71879 .18739 .70211 .16354 Metetra
.664 .741 .908 r
.70211 .16354 .71879 .18739 .75484 .17454 .73848 .15038 Metetra
.664 .741 .908 r
.73848 .15038 .75484 .17454 .79135 .16152 .77531 .13705 Metetra
.664 .741 .908 r
.12646 .34425 .14779 .36411 .17739 .3534 .15624 .33331 Metetra
.664 .741 .908 r
.15624 .33331 .17739 .3534 .20732 .34257 .18638 .32224 Metetra
.664 .741 .908 r
.18638 .32224 .20732 .34257 .23761 .33161 .21688 .31104 Metetra
.664 .741 .908 r
.21688 .31104 .23761 .33161 .26806 .32292 .24773 .29971 Metetra
.662 .717 .89 r
.24773 .29971 .26806 .32292 .29884 .31514 .27896 .28824 Metetra
.657 .686 .865 r
.27896 .28824 .29884 .31514 .32995 .30891 .31056 .27663 Metetra
.385 .514 .865 r
.31056 .27663 .32995 .30891 .35953 .34112 .34141 .28404 Metetra
.533 .475 .736 r
.34141 .28404 .35953 .34112 .39363 .29581 .3734 .28397 Metetra
.433 .773 .997 r
.3734 .28397 .39363 .29581 .42605 .29406 .40615 .28092 Metetra
.013 .501 .871 r
.40615 .28092 .42605 .29406 .45848 .32081 .43915 .2906 Metetra
.806 .724 .774 r
.43915 .2906 .45848 .32081 .49256 .30873 .47383 .25342 Metetra
.691 .577 .721 r
.47383 .25342 .49256 .30873 .52704 .27309 .50832 .22707 Metetra
.753 .636 .731 r
.50832 .22707 .52704 .27309 .56183 .27078 .54287 .19132 Metetra
.591 .467 .679 r
.54287 .19132 .56183 .27078 .59677 .24632 .57776 .17988 Metetra
.613 .505 .707 r
.57776 .17988 .59677 .24632 .63162 .21401 .61306 .16606 Metetra
.634 .572 .767 r
.61306 .16606 .63162 .21401 .66625 .17744 .64881 .15241 Metetra
.663 .732 .901 r
.64881 .15241 .66625 .17744 .70211 .16354 .68503 .13911 Metetra
.664 .741 .908 r
.68503 .13911 .70211 .16354 .73848 .15038 .72172 .12564 Metetra
.664 .741 .908 r
.72172 .12564 .73848 .15038 .77531 .13705 .75889 .11199 Metetra
.664 .741 .908 r
.10466 .32395 .12646 .34425 .15624 .33331 .13464 .31277 Metetra
.664 .741 .908 r
.13464 .31277 .15624 .33331 .18638 .32224 .16498 .30146 Metetra
.664 .741 .908 r
.16498 .30146 .18638 .32224 .21688 .31104 .19568 .29001 Metetra
.664 .741 .908 r
.19568 .29001 .21688 .31104 .24773 .29971 .22676 .27843 Metetra
.664 .741 .908 r
.22676 .27843 .24773 .29971 .27896 .28824 .2582 .26671 Metetra
.664 .741 .908 r
.2582 .26671 .27896 .28824 .31056 .27663 .29003 .25484 Metetra
.664 .741 .908 r
.29003 .25484 .31056 .27663 .34141 .28404 .32225 .24283 Metetra
.586 .568 .801 r
.32225 .24283 .34141 .28404 .3734 .28397 .35454 .23655 Metetra
.614 .557 .767 r
.35454 .23655 .3734 .28397 .40615 .28092 .38753 .22618 Metetra
.649 .553 .733 r
.38753 .22618 .40615 .28092 .43915 .2906 .42122 .20865 Metetra
.565 .445 .675 r
.42122 .20865 .43915 .2906 .47383 .25342 .45497 .20191 Metetra
.652 .567 .746 r
.45497 .20191 .47383 .25342 .50832 .22707 .4894 .18458 Metetra
.666 .611 .783 r
.4894 .18458 .50832 .22707 .54287 .19132 .52416 .16755 Metetra
.664 .741 .908 r
.52416 .16755 .54287 .19132 .57776 .17988 .55932 .15444 Metetra
.662 .728 .898 r
.55932 .15444 .57776 .17988 .61306 .16606 .59493 .14117 Metetra
.663 .736 .904 r
.59493 .14117 .61306 .16606 .64881 .15241 .631 .12772 Metetra
.664 .741 .908 r
.631 .12772 .64881 .15241 .68503 .13911 .66754 .1141 Metetra
.664 .741 .908 r
.66754 .1141 .68503 .13911 .72172 .12564 .70456 .10029 Metetra
.664 .741 .908 r
.70456 .10029 .72172 .12564 .75889 .11199 .74207 .08631 Metetra
.664 .741 .908 r
.08238 .30321 .10466 .32395 .13464 .31277 .11256 .29178 Metetra
.664 .741 .908 r
.11256 .29178 .13464 .31277 .16498 .30146 .14311 .28022 Metetra
.664 .741 .908 r
.14311 .28022 .16498 .30146 .19568 .29001 .17402 .26852 Metetra
.664 .741 .908 r
.17402 .26852 .19568 .29001 .22676 .27843 .20531 .25667 Metetra
.664 .741 .908 r
.20531 .25667 .22676 .27843 .2582 .26671 .23698 .24468 Metetra
.664 .741 .908 r
.23698 .24468 .2582 .26671 .29003 .25484 .26904 .23255 Metetra
.664 .741 .908 r
.26904 .23255 .29003 .25484 .32225 .24283 .3015 .22026 Metetra
.664 .741 .908 r
.3015 .22026 .32225 .24283 .35454 .23655 .33436 .20782 Metetra
.657 .687 .866 r
.33436 .20782 .35454 .23655 .38753 .22618 .36763 .19522 Metetra
.654 .671 .854 r
.36763 .19522 .38753 .22618 .42122 .20865 .40132 .18247 Metetra
.661 .715 .888 r
.40132 .18247 .42122 .20865 .45497 .20191 .43544 .16955 Metetra
.653 .665 .849 r
.43544 .16955 .45497 .20191 .4894 .18458 .47 .15647 Metetra
.659 .703 .879 r
.47 .15647 .4894 .18458 .52416 .16755 .505 .14322 Metetra
.664 .741 .908 r
.505 .14322 .52416 .16755 .55932 .15444 .54045 .1298 Metetra
.664 .741 .908 r
.54045 .1298 .55932 .15444 .59493 .14117 .57637 .1162 Metetra
.664 .741 .908 r
.57637 .1162 .59493 .14117 .631 .12772 .61276 .10243 Metetra
.664 .741 .908 r
.61276 .10243 .631 .12772 .66754 .1141 .64962 .08847 Metetra
.664 .741 .908 r
.64962 .08847 .66754 .1141 .70456 .10029 .68698 .07433 Metetra
.664 .741 .908 r
.68698 .07433 .70456 .10029 .74207 .08631 .72483 .06 Metetra
.664 .741 .908 r
.05962 .28201 .08238 .30321 .11256 .29178 .08999 .27033 Metetra
.664 .741 .908 r
.08999 .27033 .11256 .29178 .14311 .28022 .12074 .25851 Metetra
.664 .741 .908 r
.12074 .25851 .14311 .28022 .17402 .26852 .15187 .24654 Metetra
.664 .741 .908 r
.15187 .24654 .17402 .26852 .20531 .25667 .18337 .23442 Metetra
.664 .741 .908 r
.18337 .23442 .20531 .25667 .23698 .24468 .21527 .22216 Metetra
.664 .741 .908 r
.21527 .22216 .23698 .24468 .26904 .23255 .24756 .20974 Metetra
.664 .741 .908 r
.24756 .20974 .26904 .23255 .3015 .22026 .28026 .19717 Metetra
.664 .741 .908 r
.28026 .19717 .3015 .22026 .33436 .20782 .31337 .18444 Metetra
.664 .741 .908 r
.31337 .18444 .33436 .20782 .36763 .19522 .3469 .17155 Metetra
.664 .741 .908 r
.3469 .17155 .36763 .19522 .40132 .18247 .38086 .1585 Metetra
.664 .741 .908 r
.38086 .1585 .40132 .18247 .43544 .16955 .41525 .14527 Metetra
.664 .741 .908 r
.41525 .14527 .43544 .16955 .47 .15647 .45009 .13188 Metetra
.664 .741 .908 r
.45009 .13188 .47 .15647 .505 .14322 .48538 .11831 Metetra
.664 .741 .908 r
.48538 .11831 .505 .14322 .54045 .1298 .52114 .10456 Metetra
.664 .741 .908 r
.52114 .10456 .54045 .1298 .57637 .1162 .55736 .09063 Metetra
.664 .741 .908 r
.55736 .09063 .57637 .1162 .61276 .10243 .59407 .07652 Metetra
.664 .741 .908 r
.59407 .07652 .61276 .10243 .64962 .08847 .63126 .06222 Metetra
.664 .741 .908 r
.63126 .06222 .64962 .08847 .68698 .07433 .66896 .04773 Metetra
.664 .741 .908 r
.66896 .04773 .68698 .07433 .72483 .06 .70716 .03304 Metetra
.664 .741 .908 r
.03634 .26033 .05962 .28201 .08999 .27033 .06692 .24839 Metetra
.664 .741 .908 r
.06692 .24839 .08999 .27033 .12074 .25851 .09787 .2363 Metetra
.664 .741 .908 r
.09787 .2363 .12074 .25851 .15187 .24654 .12921 .22406 Metetra
.664 .741 .908 r
.12921 .22406 .15187 .24654 .18337 .23442 .16094 .21167 Metetra
.664 .741 .908 r
.16094 .21167 .18337 .23442 .21527 .22216 .19306 .19912 Metetra
.664 .741 .908 r
.19306 .19912 .21527 .22216 .24756 .20974 .22559 .18641 Metetra
.664 .741 .908 r
.22559 .18641 .24756 .20974 .28026 .19717 .25853 .17355 Metetra
.664 .741 .908 r
.25853 .17355 .28026 .19717 .31337 .18444 .29189 .16051 Metetra
.664 .741 .908 r
.29189 .16051 .31337 .18444 .3469 .17155 .32568 .14732 Metetra
.664 .741 .908 r
.32568 .14732 .3469 .17155 .38086 .1585 .35991 .13395 Metetra
.664 .741 .908 r
.35991 .13395 .38086 .1585 .41525 .14527 .39458 .12041 Metetra
.664 .741 .908 r
.39458 .12041 .41525 .14527 .45009 .13188 .4297 .10669 Metetra
.664 .741 .908 r
.4297 .10669 .45009 .13188 .48538 .11831 .46529 .09279 Metetra
.664 .741 .908 r
.46529 .09279 .48538 .11831 .52114 .10456 .50134 .0787 Metetra
.664 .741 .908 r
.50134 .0787 .52114 .10456 .55736 .09063 .53788 .06443 Metetra
.664 .741 .908 r
.53788 .06443 .55736 .09063 .59407 .07652 .57491 .04997 Metetra
.664 .741 .908 r
.57491 .04997 .59407 .07652 .63126 .06222 .61244 .03531 Metetra
.664 .741 .908 r
.61244 .03531 .63126 .06222 .66896 .04773 .65049 .02045 Metetra
.664 .741 .908 r
.65049 .02045 .66896 .04773 .70716 .03304 .68905 .00539 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.16157 .20642 m
.16617 .2111 L
s
[(5)] .15237 .19707 .98294 1 Mshowa
.32604 .14202 m
.33035 .14696 L
s
[(10)] .31741 .13214 .87321 1 Mshowa
.50139 .07336 m
.50537 .07857 L
s
[(15)] .49342 .06293 .76347 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(20)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.19364 .19386 m
.19637 .1967 L
s
.22611 .18115 m
.22881 .18402 L
s
.259 .16827 m
.26166 .17117 L
s
.29231 .15523 m
.29493 .15816 L
s
.3602 .12864 m
.36275 .13164 L
s
.39481 .11509 m
.39732 .11812 L
s
.42987 .10136 m
.43235 .10443 L
s
.4654 .08745 m
.46783 .09055 L
s
.53786 .05908 m
.5402 .06224 L
s
.57482 .04461 m
.57712 .0478 L
s
.61228 .02994 m
.61453 .03317 L
s
.65025 .01507 m
.65245 .01833 L
s
.12989 .21883 m
.13268 .2216 L
s
.0986 .23108 m
.10142 .23383 L
s
.06769 .24318 m
.07054 .2459 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.015625 0.64881 0.313244 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.5 .82364 -10.625 0 ]
[.5 .82364 10.625 12.9375 ]
[.15237 .19707 -5.94882 -9 ]
[.15237 .19707 .05118 0 ]
[.31741 .13214 -11.2392 -9 ]
[.31741 .13214 .76076 0 ]
[.49342 .06293 -10.5808 -9 ]
[.49342 .06293 1.41915 0 ]
[.68156 -0.01098 -9.92245 -9 ]
[.68156 -0.01098 2.07755 0 ]
[.77078 .10213 0 -6.15691 ]
[.77078 .10213 6 2.84309 ]
[.84915 .22213 0 -6.0419 ]
[.84915 .22213 12 2.9581 ]
[.9191 .32925 0 -5.94182 ]
[.9191 .32925 12 3.05818 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 12 3.14607 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -71.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.9375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(i) show
75.000 14.562 moveto
(j) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.16157 .20642 m
.16617 .2111 L
s
[(5)] .15237 .19707 .98294 1 Mshowa
.32604 .14202 m
.33035 .14696 L
s
[(10)] .31741 .13214 .87321 1 Mshowa
.50139 .07336 m
.50537 .07857 L
s
[(15)] .49342 .06293 .76347 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(20)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.19364 .19386 m
.19637 .1967 L
s
.22611 .18115 m
.22881 .18402 L
s
.259 .16827 m
.26166 .17117 L
s
.29231 .15523 m
.29493 .15816 L
s
.3602 .12864 m
.36275 .13164 L
s
.39481 .11509 m
.39732 .11812 L
s
.42987 .10136 m
.43235 .10443 L
s
.4654 .08745 m
.46783 .09055 L
s
.53786 .05908 m
.5402 .06224 L
s
.57482 .04461 m
.57712 .0478 L
s
.61228 .02994 m
.61453 .03317 L
s
.65025 .01507 m
.65245 .01833 L
s
.12989 .21883 m
.13268 .2216 L
s
.0986 .23108 m
.10142 .23383 L
s
.06769 .24318 m
.07054 .2459 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.75847 .10666 m
.75231 .10893 L
s
[(5)] .77078 .10213 -1 .3682 Mshowa
.83673 .22638 m
.83053 .22851 L
s
[(10)] .84915 .22213 -1 .34264 Mshowa
.9066 .33325 m
.90035 .33526 L
s
[(15)] .9191 .32925 -1 .3204 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(20)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.77486 .13175 m
.77116 .13309 L
s
.79088 .15624 m
.78717 .15756 L
s
.80652 .18016 m
.8028 .18147 L
s
.8218 .20354 m
.81808 .20483 L
s
.85133 .24872 m
.8476 .24998 L
s
.86561 .27055 m
.86188 .2718 L
s
.87957 .29191 m
.87583 .29314 L
s
.89323 .31281 m
.88949 .31402 L
s
.91968 .35327 m
.91593 .35445 L
s
.93249 .37286 m
.92873 .37403 L
s
.94503 .39204 m
.94127 .3932 L
s
.95731 .41083 m
.95355 .41198 L
s
.74167 .08097 m
.73798 .08235 L
s
.72446 .05465 m
.72078 .05604 L
s
.70682 .02766 m
.70315 .02908 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.663 .722 .893 r
.38107 .78681 .39811 .80437 .42673 .79589 .40987 .77812 Metetra
.69 .729 .88 r
.40987 .77812 .42673 .79589 .45569 .78513 .43901 .76687 Metetra
.71 .73 .866 r
.43901 .76687 .45569 .78513 .48492 .77233 .46845 .75328 Metetra
.724 .728 .853 r
.46845 .75328 .48492 .77233 .5144 .75787 .49813 .73777 Metetra
.731 .722 .842 r
.49813 .73777 .5144 .75787 .54408 .74229 .52801 .72087 Metetra
.732 .712 .832 r
.52801 .72087 .54408 .74229 .57394 .72628 .55806 .7033 Metetra
.726 .699 .825 r
.55806 .7033 .57394 .72628 .60401 .71063 .58828 .68599 Metetra
.71 .683 .822 r
.58828 .68599 .60401 .71063 .63432 .69624 .61873 .67024 Metetra
.693 .668 .822 r
.61873 .67024 .63432 .69624 .66493 .68375 .64945 .65649 Metetra
.666 .65 .825 r
.64945 .65649 .66493 .68375 .69594 .67377 .68058 .64588 Metetra
.634 .633 .832 r
.68058 .64588 .69594 .67377 .72743 .66656 .71222 .63889 Metetra
.608 .624 .841 r
.71222 .63889 .72743 .66656 .75947 .66177 .74442 .63461 Metetra
.584 .618 .851 r
.74442 .63461 .75947 .66177 .79209 .65896 .77724 .63255 Metetra
.564 .615 .862 r
.77724 .63255 .79209 .65896 .82532 .65754 .8107 .63215 Metetra
.551 .619 .873 r
.8107 .63215 .82532 .65754 .85913 .65677 .8448 .63254 Metetra
.55 .63 .884 r
.8448 .63254 .85913 .65677 .89348 .65583 .87945 .63269 Metetra
.56 .648 .894 r
.87945 .63269 .89348 .65583 .92827 .65395 .91457 .63168 Metetra
.579 .668 .9 r
.91457 .63168 .92827 .65395 .96342 .65048 .95005 .62882 Metetra
.605 .689 .902 r
.95005 .62882 .96342 .65048 .99883 .64493 .98577 .62359 Metetra
.664 .702 .875 r
.36382 .76701 .38107 .78681 .40987 .77812 .39277 .75802 Metetra
.692 .709 .861 r
.39277 .75802 .40987 .77812 .43901 .76687 .4221 .74603 Metetra
.713 .71 .845 r
.4221 .74603 .43901 .76687 .46845 .75328 .45174 .73126 Metetra
.727 .705 .83 r
.45174 .73126 .46845 .75328 .49813 .73777 .48162 .71413 Metetra
.734 .696 .815 r
.48162 .71413 .49813 .73777 .52801 .72087 .51169 .6952 Metetra
.734 .684 .802 r
.51169 .6952 .52801 .72087 .55806 .7033 .54189 .67516 Metetra
.728 .668 .791 r
.54189 .67516 .55806 .7033 .58828 .68599 .57223 .65489 Metetra
.705 .643 .785 r
.57223 .65489 .58828 .68599 .61873 .67024 .60276 .63735 Metetra
.693 .63 .781 r
.60276 .63735 .61873 .67024 .64945 .65649 .63352 .62118 Metetra
.661 .604 .781 r
.63352 .62118 .64945 .65649 .68058 .64588 .66467 .60947 Metetra
.619 .579 .787 r
.66467 .60947 .68058 .64588 .71222 .63889 .69643 .60361 Metetra
.598 .575 .799 r
.69643 .60361 .71222 .63889 .74442 .63461 .72875 .60033 Metetra
.576 .57 .809 r
.72875 .60033 .74442 .63461 .77724 .63255 .76173 .59954 Metetra
.553 .566 .821 r
.76173 .59954 .77724 .63255 .8107 .63215 .79543 .601 Metetra
.538 .572 .836 r
.79543 .601 .8107 .63215 .8448 .63254 .82984 .60356 Metetra
.538 .588 .853 r
.82984 .60356 .8448 .63254 .87945 .63269 .86483 .60563 Metetra
.55 .611 .867 r
.86483 .60563 .87945 .63269 .91457 .63168 .9003 .60615 Metetra
.571 .637 .878 r
.9003 .60615 .91457 .63168 .95005 .62882 .93612 .60433 Metetra
.6 .663 .883 r
.93612 .60433 .95005 .62882 .98577 .62359 .97217 .59968 Metetra
.664 .688 .862 r
.34635 .74537 .36382 .76701 .39277 .75802 .37545 .736 Metetra
.696 .696 .846 r
.37545 .736 .39277 .75802 .4221 .74603 .40497 .72303 Metetra
.719 .696 .828 r
.40497 .72303 .4221 .74603 .45174 .73126 .43482 .70667 Metetra
.733 .691 .81 r
.43482 .70667 .45174 .73126 .48162 .71413 .46491 .68735 Metetra
.739 .68 .793 r
.46491 .68735 .48162 .71413 .51169 .6952 .49516 .66573 Metetra
.74 .666 .777 r
.49516 .66573 .51169 .6952 .54189 .67516 .52552 .64236 Metetra
.736 .649 .763 r
.52552 .64236 .54189 .67516 .57223 .65489 .55595 .61788 Metetra
.697 .614 .76 r
.55595 .61788 .57223 .65489 .60276 .63735 .58654 .59931 Metetra
.697 .611 .757 r
.58654 .59931 .60276 .63735 .63352 .62118 .6173 .58037 Metetra
.656 .58 .758 r
.6173 .58037 .63352 .62118 .66467 .60947 .64846 .56801 Metetra
.622 .561 .765 r
.64846 .56801 .66467 .60947 .69643 .60361 .68016 .56095 Metetra
.588 .539 .767 r
.68016 .56095 .69643 .60361 .72875 .60033 .71253 .55875 Metetra
.566 .532 .776 r
.71253 .55875 .72875 .60033 .76173 .59954 .74561 .55944 Metetra
.534 .521 .787 r
.74561 .55944 .76173 .59954 .79543 .601 .77955 .56389 Metetra
.512 .525 .806 r
.77955 .56389 .79543 .601 .82984 .60356 .81431 .57008 Metetra
.514 .548 .828 r
.81431 .57008 .82984 .60356 .86483 .60563 .84968 .57511 Metetra
.531 .578 .848 r
.84968 .57511 .86483 .60563 .9003 .60615 .88553 .57781 Metetra
.558 .611 .862 r
.88553 .57781 .9003 .60615 .93612 .60433 .92172 .57748 Metetra
.591 .642 .87 r
.92172 .57748 .93612 .60433 .97217 .59968 .9581 .57365 Metetra
.666 .681 .854 r
.32865 .72247 .34635 .74537 .37545 .736 .3579 .71264 Metetra
.702 .69 .835 r
.3579 .71264 .37545 .736 .40497 .72303 .38762 .69845 Metetra
.727 .69 .814 r
.38762 .69845 .40497 .72303 .43482 .70667 .4177 .68008 Metetra
.743 .683 .793 r
.4177 .68008 .43482 .70667 .46491 .68735 .44801 .65794 Metetra
.747 .669 .775 r
.44801 .65794 .46491 .68735 .49516 .66573 .47847 .63316 Metetra
.744 .654 .761 r
.47847 .63316 .49516 .66573 .52552 .64236 .50898 .60709 Metetra
.733 .639 .754 r
.50898 .60709 .52552 .64236 .55595 .61788 .53953 .5818 Metetra
.713 .627 .76 r
.53953 .5818 .55595 .61788 .58654 .59931 .57019 .56055 Metetra
.696 .609 .755 r
.57019 .56055 .58654 .59931 .6173 .58037 .60101 .54136 Metetra
.662 .591 .766 r
.60101 .54136 .6173 .58037 .64846 .56801 .6322 .52826 Metetra
.634 .575 .771 r
.6322 .52826 .64846 .56801 .68016 .56095 .66385 .51939 Metetra
.592 .546 .772 r
.66385 .51939 .68016 .56095 .71253 .55875 .69618 .51633 Metetra
.567 .53 .773 r
.69618 .51633 .71253 .55875 .74561 .55944 .72922 .51666 Metetra
.534 .511 .776 r
.72922 .51666 .74561 .55944 .77955 .56389 .76313 .52111 Metetra
.47 .475 .781 r
.76313 .52111 .77955 .56389 .81431 .57008 .79833 .53293 Metetra
.48 .51 .811 r
.79833 .53293 .81431 .57008 .84968 .57511 .83412 .54194 Metetra
.504 .549 .835 r
.83412 .54194 .84968 .57511 .88553 .57781 .87037 .5474 Metetra
.539 .589 .852 r
.87037 .5474 .88553 .57781 .92172 .57748 .90693 .54893 Metetra
.58 .626 .862 r
.90693 .54893 .92172 .57748 .9581 .57365 .94366 .54612 Metetra
.669 .68 .852 r
.31068 .69901 .32865 .72247 .3579 .71264 .34009 .68867 Metetra
.71 .691 .829 r
.34009 .68867 .3579 .71264 .38762 .69845 .37002 .6731 Metetra
.739 .691 .804 r
.37002 .6731 .38762 .69845 .4177 .68008 .40035 .65231 Metetra
.758 .683 .779 r
.40035 .65231 .4177 .68008 .44801 .65794 .43095 .62628 Metetra
.759 .665 .757 r
.43095 .62628 .44801 .65794 .47847 .63316 .46165 .59706 Metetra
.744 .64 .746 r
.46165 .59706 .47847 .63316 .50898 .60709 .49231 .56872 Metetra
.724 .624 .746 r
.49231 .56872 .50898 .60709 .53953 .5818 .52297 .54382 Metetra
.716 .622 .751 r
.52297 .54382 .53953 .5818 .57019 .56055 .5537 .52093 Metetra
.695 .606 .753 r
.5537 .52093 .57019 .56055 .60101 .54136 .5846 .50152 Metetra
.654 .585 .765 r
.5846 .50152 .60101 .54136 .6322 .52826 .61586 .48934 Metetra
.648 .587 .772 r
.61586 .48934 .6322 .52826 .66385 .51939 .64747 .47823 Metetra
.581 .543 .777 r
.64747 .47823 .66385 .51939 .69618 .51633 .67985 .47626 Metetra
.552 .532 .787 r
.67985 .47626 .69618 .51633 .72922 .51666 .71296 .47778 Metetra
.53 .527 .797 r
.71296 .47778 .72922 .51666 .76313 .52111 .74684 .48154 Metetra
.437 .472 .798 r
.74684 .48154 .76313 .52111 .79833 .53293 .78213 .4948 Metetra
.439 .482 .807 r
.78213 .4948 .79833 .53293 .83412 .54194 .81827 .50742 Metetra
.471 .524 .831 r
.81827 .50742 .83412 .54194 .87037 .5474 .85491 .51589 Metetra
.515 .571 .85 r
.85491 .51589 .87037 .5474 .90693 .54893 .89186 .51951 Metetra
.566 .616 .862 r
.89186 .51951 .90693 .54893 .94366 .54612 .92893 .51787 Metetra
.673 .687 .855 r
.29238 .67583 .31068 .69901 .34009 .68867 .32196 .66494 Metetra
.72 .698 .828 r
.32196 .66494 .34009 .68867 .37002 .6731 .35213 .64798 Metetra
.752 .698 .8 r
.35213 .64798 .37002 .6731 .40035 .65231 .38274 .62488 Metetra
.774 .691 .772 r
.38274 .62488 .40035 .65231 .43095 .62628 .41365 .5955 Metetra
.784 .678 .748 r
.41365 .5955 .43095 .62628 .46165 .59706 .44467 .56046 Metetra
.759 .646 .737 r
.44467 .56046 .46165 .59706 .49231 .56872 .47554 .52782 Metetra
.711 .61 .742 r
.47554 .52782 .49231 .56872 .52297 .54382 .50627 .50445 Metetra
.709 .615 .749 r
.50627 .50445 .52297 .54382 .5537 .52093 .5371 .48228 Metetra
.7 .613 .757 r
.5371 .48228 .5537 .52093 .5846 .50152 .56808 .46238 Metetra
.658 .592 .769 r
.56808 .46238 .5846 .50152 .61586 .48934 .59937 .44954 Metetra
.652 .586 .769 r
.59937 .44954 .61586 .48934 .64747 .47823 .631 .43755 Metetra
.554 .531 .784 r
.631 .43755 .64747 .47823 .67985 .47626 .6635 .43852 Metetra
.524 .529 .803 r
.6635 .43852 .67985 .47626 .71296 .47778 .69676 .44233 Metetra
.515 .539 .819 r
.69676 .44233 .71296 .47778 .74684 .48154 .73071 .44649 Metetra
.449 .506 .825 r
.73071 .44649 .74684 .48154 .78213 .4948 .76578 .45637 Metetra
.396 .457 .806 r
.76578 .45637 .78213 .4948 .81827 .50742 .80221 .47228 Metetra
.427 .497 .829 r
.80221 .47228 .81827 .50742 .85491 .51589 .83925 .48424 Metetra
.483 .555 .854 r
.83925 .48424 .85491 .51589 .89186 .51951 .8766 .4902 Metetra
.548 .611 .868 r
.8766 .4902 .89186 .51951 .92893 .51787 .91402 .48979 Metetra
.678 .701 .864 r
.27367 .65373 .29238 .67583 .32196 .66494 .30344 .6423 Metetra
.732 .712 .833 r
.30344 .6423 .32196 .66494 .35213 .64798 .33387 .62403 Metetra
.767 .712 .801 r
.33387 .62403 .35213 .64798 .38274 .62488 .36479 .59883 Metetra
.787 .705 .773 r
.36479 .59883 .38274 .62488 .41365 .5955 .39602 .56736 Metetra
.795 .696 .756 r
.39602 .56736 .41365 .5955 .44467 .56046 .4273 .53194 Metetra
.786 .693 .761 r
.4273 .53194 .44467 .56046 .47554 .52782 .45842 .49892 Metetra
.761 .684 .778 r
.45842 .49892 .47554 .52782 .50627 .50445 .48938 .47201 Metetra
.73 .655 .775 r
.48938 .47201 .50627 .50445 .5371 .48228 .52036 .44926 Metetra
.712 .646 .781 r
.52036 .44926 .5371 .48228 .56808 .46238 .55148 .42948 Metetra
.686 .636 .794 r
.55148 .42948 .56808 .46238 .59937 .44954 .58284 .41396 Metetra
.64 .602 .795 r
.58284 .41396 .59937 .44954 .631 .43755 .61461 .40421 Metetra
.538 .563 .828 r
.61461 .40421 .631 .43755 .6635 .43852 .64719 .40547 Metetra
.512 .553 .834 r
.64719 .40547 .6635 .43852 .69676 .44233 .68049 .40895 Metetra
.471 .53 .836 r
.68049 .40895 .69676 .44233 .73071 .44649 .71467 .41586 Metetra
.431 .529 .857 r
.71467 .41586 .73071 .44649 .76578 .45637 .74977 .42474 Metetra
.363 .484 .848 r
.74977 .42474 .76578 .45637 .80221 .47228 .78612 .4389 Metetra
.371 .478 .839 r
.78612 .4389 .80221 .47228 .83925 .48424 .8235 .4537 Metetra
.44 .543 .865 r
.8235 .4537 .83925 .48424 .8766 .4902 .86126 .46212 Metetra
.527 .614 .882 r
.86126 .46212 .8766 .4902 .91402 .48979 .89904 .46286 Metetra
.685 .724 .879 r
.25447 .6335 .27367 .65373 .30344 .6423 .28444 .62149 Metetra
.744 .733 .841 r
.28444 .62149 .30344 .6423 .33387 .62403 .31516 .60202 Metetra
.783 .732 .805 r
.31516 .60202 .33387 .62403 .36479 .59883 .34643 .57499 Metetra
.795 .722 .784 r
.34643 .57499 .36479 .59883 .39602 .56736 .37792 .54373 Metetra
.806 .727 .777 r
.37792 .54373 .39602 .56736 .4273 .53194 .40945 .50983 Metetra
.818 .74 .778 r
.40945 .50983 .4273 .53194 .45842 .49892 .44092 .47463 Metetra
.796 .724 .785 r
.44092 .47463 .45842 .49892 .48938 .47201 .4722 .44357 Metetra
.752 .687 .79 r
.4722 .44357 .48938 .47201 .52036 .44926 .5034 .419 Metetra
.741 .674 .786 r
.5034 .419 .52036 .44926 .55148 .42948 .53467 .39547 Metetra
.681 .63 .792 r
.53467 .39547 .55148 .42948 .58284 .41396 .56615 .38032 Metetra
.585 .587 .821 r
.56615 .38032 .58284 .41396 .61461 .40421 .59818 .3768 Metetra
.479 .58 .878 r
.59818 .3768 .61461 .40421 .64719 .40547 .63096 .3807 Metetra
.465 .6 .901 r
.63096 .3807 .64719 .40547 .68049 .40895 .66442 .38449 Metetra
.437 .59 .906 r
.66442 .38449 .68049 .40895 .71467 .41586 .69867 .38977 Metetra
.376 .541 .891 r
.69867 .38977 .71467 .41586 .74977 .42474 .73395 .39937 Metetra
.347 .534 .896 r
.73395 .39937 .74977 .42474 .78612 .4389 .7702 .41024 Metetra
.299 .475 .866 r
.7702 .41024 .78612 .4389 .8235 .4537 .80781 .42618 Metetra
.381 .538 .887 r
.80781 .42618 .8235 .4537 .86126 .46212 .84594 .43661 Metetra
.502 .628 .907 r
.84594 .43661 .86126 .46212 .89904 .46286 .88406 .43803 Metetra
.692 .754 .899 r
.23466 .61571 .25447 .6335 .28444 .62149 .26488 .60314 Metetra
.758 .761 .854 r
.26488 .60314 .28444 .62149 .31516 .60202 .29591 .58262 Metetra
.804 .757 .809 r
.29591 .58262 .31516 .60202 .34643 .57499 .32762 .55298 Metetra
.8 .738 .795 r
.32762 .55298 .34643 .57499 .37792 .54373 .35937 .52223 Metetra
.806 .745 .796 r
.35937 .52223 .37792 .54373 .40945 .50983 .39112 .49082 Metetra
.826 .767 .797 r
.39112 .49082 .40945 .50983 .44092 .47463 .4229 .45702 Metetra
.83 .782 .807 r
.4229 .45702 .44092 .47463 .4722 .44357 .45457 .42415 Metetra
.786 .766 .835 r
.45457 .42415 .4722 .44357 .5034 .419 .48607 .39909 Metetra
.791 .765 .83 r
.48607 .39909 .5034 .419 .53467 .39547 .51764 .37299 Metetra
.722 .729 .856 r
.51764 .37299 .53467 .39547 .56615 .38032 .54934 .35589 Metetra
.518 .63 .901 r
.54934 .35589 .56615 .38032 .59818 .3768 .5816 .35607 Metetra
.341 .581 .931 r
.5816 .35607 .59818 .3768 .63096 .3807 .61466 .36348 Metetra
.343 .629 .959 r
.61466 .36348 .63096 .3807 .66442 .38449 .6484 .36868 Metetra
.315 .635 .964 r
.6484 .36868 .66442 .38449 .69867 .38977 .68291 .37399 Metetra
.266 .607 .955 r
.68291 .37399 .69867 .38977 .73395 .39937 .71829 .38114 Metetra
.272 .578 .942 r
.71829 .38114 .73395 .39937 .7702 .41024 .75464 .39008 Metetra
.162 .485 .9 r
.75464 .39008 .7702 .41024 .80781 .42618 .79242 .40534 Metetra
.305 .57 .932 r
.79242 .40534 .80781 .42618 .84594 .43661 .83074 .41502 Metetra
.477 .662 .943 r
.83074 .41502 .84594 .43661 .88406 .43803 .86912 .41606 Metetra
.695 .788 .922 r
.21418 .60056 .23466 .61571 .26488 .60314 .24464 .58771 Metetra
.765 .794 .877 r
.24464 .58771 .26488 .60314 .29591 .58262 .27593 .5674 Metetra
.812 .798 .838 r
.27593 .5674 .29591 .58262 .32762 .55298 .30788 .53942 Metetra
.838 .814 .827 r
.30788 .53942 .32762 .55298 .35937 .52223 .34008 .50737 Metetra
.838 .804 .818 r
.34008 .50737 .35937 .52223 .39112 .49082 .37228 .47427 Metetra
.82 .793 .827 r
.37228 .47427 .39112 .49082 .4229 .45702 .40429 .44437 Metetra
.847 .833 .833 r
.40429 .44437 .4229 .45702 .45457 .42415 .43635 .41208 Metetra
.829 .847 .861 r
.43635 .41208 .45457 .42415 .48607 .39909 .46828 .38415 Metetra
.768 .818 .892 r
.46828 .38415 .48607 .39909 .51764 .37299 .50018 .36371 Metetra
.65 .873 .982 r
.50018 .36371 .51764 .37299 .54934 .35589 .53227 .35187 Metetra
.291 .771 .924 r
.53227 .35187 .54934 .35589 .5816 .35607 .56484 .34848 Metetra
.112 .619 .897 r
.56484 .34848 .5816 .35607 .61466 .36348 .59812 .35268 Metetra
.202 .641 .948 r
.59812 .35268 .61466 .36348 .6484 .36868 .63215 .35731 Metetra
.253 .666 .964 r
.63215 .35731 .6484 .36868 .68291 .37399 .66688 .36092 Metetra
.253 .643 .963 r
.66688 .36092 .68291 .37399 .71829 .38114 .70245 .36596 Metetra
.16 .555 .929 r
.70245 .36596 .71829 .38114 .75464 .39008 .73917 .37607 Metetra
.063 .503 .895 r
.73917 .37607 .75464 .39008 .79242 .40534 .77704 .38873 Metetra
.251 .597 .95 r
.77704 .38873 .79242 .40534 .83074 .41502 .81555 .39701 Metetra
.456 .701 .973 r
.81555 .39701 .83074 .41502 .86912 .41606 .85418 .39699 Metetra
.694 .82 .943 r
.19297 .58772 .21418 .60056 .24464 .58771 .22369 .57471 Metetra
.766 .825 .899 r
.22369 .57471 .24464 .58771 .27593 .5674 .25525 .55489 Metetra
.813 .829 .862 r
.25525 .55489 .27593 .5674 .30788 .53942 .28747 .5283 Metetra
.847 .84 .838 r
.28747 .5283 .30788 .53942 .34008 .50737 .3201 .49591 Metetra
.852 .839 .832 r
.3201 .49591 .34008 .50737 .37228 .47427 .35273 .46244 Metetra
.839 .843 .848 r
.35273 .46244 .37228 .47427 .40429 .44437 .38517 .43199 Metetra
.836 .842 .851 r
.38517 .43199 .40429 .44437 .43635 .41208 .41757 .40218 Metetra
.831 .876 .877 r
.41757 .40218 .43635 .41208 .46828 .38415 .44992 .37468 Metetra
.758 .889 .937 r
.44992 .37468 .46828 .38415 .50018 .36371 .4822 .35556 Metetra
.515 .844 .998 r
.4822 .35556 .50018 .36371 .53227 .35187 .51465 .34861 Metetra
.257 .755 .899 r
.51465 .34861 .53227 .35187 .56484 .34848 .5476 .34523 Metetra
.18 .705 .867 r
.5476 .34523 .56484 .34848 .59812 .35268 .58115 .34366 Metetra
.211 .673 .944 r
.58115 .34366 .59812 .35268 .63215 .35731 .61544 .34624 Metetra
.159 .614 .933 r
.61544 .34624 .63215 .35731 .66688 .36092 .6506 .3521 Metetra
.038 .554 .87 r
.6506 .3521 .66688 .36092 .70245 .36596 .68666 .3596 Metetra
0 .483 .78 r
.68666 .3596 .70245 .36596 .73917 .37607 .72369 .36848 Metetra
0 .517 .827 r
.72369 .36848 .73917 .37607 .77704 .38873 .76166 .37715 Metetra
.209 .644 .951 r
.76166 .37715 .77704 .38873 .81555 .39701 .80028 .38218 Metetra
.443 .743 .992 r
.80028 .38218 .81555 .39701 .85418 .39699 .83915 .38043 Metetra
.689 .844 .957 r
.17102 .57657 .19297 .58772 .22369 .57471 .20202 .56348 Metetra
.762 .849 .916 r
.20202 .56348 .22369 .57471 .25525 .55489 .23386 .54416 Metetra
.813 .853 .878 r
.23386 .54416 .25525 .55489 .28747 .5283 .2664 .51827 Metetra
.854 .853 .84 r
.2664 .51827 .28747 .5283 .3201 .49591 .29953 .48499 Metetra
.851 .849 .84 r
.29953 .48499 .3201 .49591 .35273 .46244 .33257 .45205 Metetra
.839 .863 .861 r
.33257 .45205 .35273 .46244 .38517 .43199 .3654 .42231 Metetra
.825 .879 .883 r
.3654 .42231 .38517 .43199 .41757 .40218 .39813 .39542 Metetra
.813 .919 .909 r
.39813 .39542 .41757 .40218 .44992 .37468 .43087 .37053 Metetra
.722 .948 .953 r
.43087 .37053 .44992 .37468 .4822 .35556 .46358 .35195 Metetra
.381 .827 .942 r
.46358 .35195 .4822 .35556 .51465 .34861 .49643 .34559 Metetra
.288 .777 .904 r
.49643 .34559 .51465 .34861 .5476 .34523 .52979 .34104 Metetra
.293 .773 .922 r
.52979 .34104 .5476 .34523 .58115 .34366 .56371 .33718 Metetra
.265 .738 .94 r
.56371 .33718 .58115 .34366 .61544 .34624 .59828 .33588 Metetra
.165 .63 .932 r
.59828 .33588 .61544 .34624 .6506 .3521 .63372 .34065 Metetra
.066 .548 .894 r
.63372 .34065 .6506 .3521 .68666 .3596 .67017 .34949 Metetra
0 .503 .85 r
.67017 .34949 .68666 .3596 .72369 .36848 .70766 .35981 Metetra
.058 .574 .877 r
.70766 .35981 .72369 .36848 .76166 .37715 .7459 .36664 Metetra
.248 .688 .959 r
.7459 .36664 .76166 .37715 .80028 .38218 .78474 .36896 Metetra
.448 .773 .997 r
.78474 .36896 .80028 .38218 .83915 .38043 .8239 .3655 Metetra
.68 .858 .967 r
.14837 .56641 .17102 .57657 .20202 .56348 .17964 .55343 Metetra
.751 .866 .933 r
.17964 .55343 .20202 .56348 .23386 .54416 .21173 .53498 Metetra
.802 .876 .9 r
.21173 .53498 .23386 .54416 .2664 .51827 .24452 .51086 Metetra
.846 .888 .87 r
.24452 .51086 .2664 .51827 .29953 .48499 .27789 .4806 Metetra
.858 .92 .87 r
.27789 .4806 .29953 .48499 .33257 .45205 .31134 .44906 Metetra
.84 .945 .889 r
.31134 .44906 .33257 .45205 .3654 .42231 .34463 .42022 Metetra
.818 .962 .903 r
.34463 .42022 .3654 .42231 .39813 .39542 .37786 .39353 Metetra
.753 .968 .93 r
.37786 .39353 .39813 .39542 .43087 .37053 .41099 .37166 Metetra
.671 .971 .908 r
.41099 .37166 .43087 .37053 .46358 .35195 .44426 .35174 Metetra
.381 .843 .885 r
.44426 .35174 .46358 .35195 .49643 .34559 .47759 .3424 Metetra
.318 .795 .915 r
.47759 .3424 .49643 .34559 .52979 .34104 .51136 .33701 Metetra
.277 .765 .912 r
.51136 .33701 .52979 .34104 .56371 .33718 .54571 .33324 Metetra
.206 .72 .884 r
.54571 .33324 .56371 .33718 .59828 .33588 .58069 .3312 Metetra
.188 .703 .887 r
.58069 .3312 .59828 .33588 .63372 .34065 .61638 .33021 Metetra
.061 .56 .887 r
.61638 .33021 .63372 .34065 .67017 .34949 .65313 .33798 Metetra
0 .471 .841 r
.65313 .33798 .67017 .34949 .70766 .35981 .69106 .3502 Metetra
.113 .608 .906 r
.69106 .3502 .70766 .35981 .7459 .36664 .72965 .35585 Metetra
.299 .721 .973 r
.72965 .35585 .7459 .36664 .78474 .36896 .76878 .35623 Metetra
.463 .793 .999 r
.76878 .35623 .78474 .36896 .8239 .3655 .8083 .35132 Metetra
.67 .862 .972 r
.12503 .55647 .14837 .56641 .17964 .55343 .15656 .54373 Metetra
.734 .874 .946 r
.15656 .54373 .17964 .55343 .21173 .53498 .18888 .52642 Metetra
.78 .888 .923 r
.18888 .52642 .21173 .53498 .24452 .51086 .22185 .50466 Metetra
.814 .912 .906 r
.22185 .50466 .24452 .51086 .27789 .4806 .25532 .47894 Metetra
.823 .958 .901 r
.25532 .47894 .27789 .4806 .31134 .44906 .28902 .45143 Metetra
.798 .989 .887 r
.28902 .45143 .31134 .44906 .34463 .42022 .32279 .42392 Metetra
.779 .994 .873 r
.32279 .42392 .34463 .42022 .37786 .39353 .35663 .39647 Metetra
.66 .971 .887 r
.35663 .39647 .37786 .39353 .41099 .37166 .39027 .37565 Metetra
.585 .946 .856 r
.39027 .37565 .41099 .37166 .44426 .35174 .42407 .35646 Metetra
.418 .862 .795 r
.42407 .35646 .44426 .35174 .47759 .3424 .45804 .34161 Metetra
.325 .809 .875 r
.45804 .34161 .47759 .3424 .51136 .33701 .4923 .33386 Metetra
.214 .729 .874 r
.4923 .33386 .51136 .33701 .54571 .33324 .52708 .33087 Metetra
.139 .681 .827 r
.52708 .33087 .54571 .33324 .58069 .3312 .56253 .32911 Metetra
.021 .592 .762 r
.56253 .32911 .58069 .3312 .61638 .33021 .59874 .33033 Metetra
.174 0 0 r
.59874 .33033 .61638 .33021 .65313 .33798 .63589 .33572 Metetra
.148 0 0 r
.63589 .33572 .65313 .33798 .69106 .3502 .67403 .34257 Metetra
.143 .652 .9 r
.67403 .34257 .69106 .3502 .72965 .35585 .71289 .34518 Metetra
.344 .753 .981 r
.71289 .34518 .72965 .35585 .76878 .35623 .75235 .34341 Metetra
.485 .808 1 r
.75235 .34341 .76878 .35623 .8083 .35132 .79224 .3371 Metetra
.663 .857 .974 r
.10108 .54591 .12503 .55647 .15656 .54373 .13287 .53342 Metetra
.717 .869 .953 r
.13287 .53342 .15656 .54373 .18888 .52642 .1654 .51715 Metetra
.756 .885 .937 r
.1654 .51715 .18888 .52642 .22185 .50466 .19856 .49738 Metetra
.783 .908 .927 r
.19856 .49738 .22185 .50466 .25532 .47894 .23219 .47474 Metetra
.794 .941 .923 r
.23219 .47474 .25532 .47894 .28902 .45143 .26614 .45041 Metetra
.785 .97 .917 r
.26614 .45041 .28902 .45143 .32279 .42392 .30027 .42542 Metetra
.765 .986 .901 r
.30027 .42542 .32279 .42392 .35663 .39647 .33455 .4001 Metetra
.669 .975 .879 r
.33455 .4001 .35663 .39647 .39027 .37565 .36882 .378 Metetra
.61 .955 .89 r
.36882 .378 .39027 .37565 .42407 .35646 .40317 .359 Metetra
.482 .9 .861 r
.40317 .359 .42407 .35646 .45804 .34161 .43768 .34396 Metetra
.221 .743 .771 r
.43768 .34396 .45804 .34161 .4923 .33386 .47245 .33625 Metetra
.47245 .33625 .4923 .33386 .52708 .33087 .50774 .33263 Metetra
.017 0 0 r
.50774 .33263 .52708 .33087 .56253 .32911 .54371 .33168 Metetra
.064 0 0 r
.54371 .33168 .56253 .32911 .59874 .33033 .58043 .33146 Metetra
.075 0 0 r
.58043 .33146 .59874 .33033 .63589 .33572 .61798 .33283 Metetra
.034 .6 .782 r
.61798 .33283 .63589 .33572 .67403 .34257 .65639 .33433 Metetra
.251 .723 .942 r
.65639 .33433 .67403 .34257 .71289 .34518 .69555 .33359 Metetra
.406 .783 .992 r
.69555 .33359 .71289 .34518 .75235 .34341 .73534 .32965 Metetra
.514 .816 1 r
.73534 .32965 .75235 .34341 .79224 .3371 .77564 .322 Metetra
.661 .844 .971 r
.07661 .53394 .10108 .54591 .13287 .53342 .10865 .52162 Metetra
.705 .855 .954 r
.10865 .52162 .13287 .53342 .1654 .51715 .1414 .50613 Metetra
.738 .869 .942 r
.1414 .50613 .1654 .51715 .19856 .49738 .17477 .48779 Metetra
.76 .888 .935 r
.17477 .48779 .19856 .49738 .23219 .47474 .20861 .46715 Metetra
.772 .912 .934 r
.20861 .46715 .23219 .47474 .26614 .45041 .2428 .44506 Metetra
.771 .937 .937 r
.2428 .44506 .26614 .45041 .30027 .42542 .27724 .42241 Metetra
.753 .959 .937 r
.27724 .42241 .30027 .42542 .33455 .4001 .31186 .40006 Metetra
.69 .97 .926 r
.31186 .40006 .33455 .4001 .36882 .378 .34659 .37936 Metetra
.591 .946 .904 r
.34659 .37936 .36882 .378 .40317 .359 .38143 .36165 Metetra
.435 .875 .848 r
.38143 .36165 .40317 .359 .43768 .34396 .41646 .34782 Metetra
.251 .761 .754 r
.41646 .34782 .43768 .34396 .47245 .33625 .45182 .33799 Metetra
.162 .701 .756 r
.45182 .33799 .47245 .33625 .50774 .33263 .48766 .33213 Metetra
.134 .681 .787 r
.48766 .33213 .50774 .33263 .54371 .33168 .52412 .32873 Metetra
.163 .696 .843 r
.52412 .32873 .54371 .33168 .58043 .33146 .56131 .32641 Metetra
.191 .707 .885 r
.56131 .32641 .58043 .33146 .61798 .33283 .59927 .32486 Metetra
.27 .739 .944 r
.59927 .32486 .61798 .33283 .65639 .33433 .63802 .32308 Metetra
.378 .773 .987 r
.63802 .32308 .65639 .33433 .69555 .33359 .67753 .31975 Metetra
.471 .796 .999 r
.67753 .31975 .69555 .33359 .73534 .32965 .7177 .31398 Metetra
.546 .814 .996 r
.7177 .31398 .73534 .32965 .77564 .322 .75841 .30516 Metetra
.66 .825 .963 r
.05171 .51988 .07661 .53394 .10865 .52162 .08399 .50763 Metetra
.697 .834 .948 r
.08399 .50763 .10865 .52162 .1414 .50613 .11697 .49262 Metetra
.725 .845 .938 r
.11697 .49262 .1414 .50613 .17477 .48779 .15056 .47516 Metetra
.744 .859 .933 r
.15056 .47516 .17477 .48779 .20861 .46715 .18465 .45574 Metetra
.756 .875 .933 r
.18465 .45574 .20861 .46715 .2428 .44506 .21911 .43508 Metetra
.758 .894 .938 r
.21911 .43508 .2428 .44506 .27724 .42241 .25385 .41398 Metetra
.748 .913 .948 r
.25385 .41398 .27724 .42241 .31186 .40006 .28879 .3933 Metetra
.719 .929 .96 r
.28879 .3933 .31186 .40006 .34659 .37936 .3239 .37407 Metetra
.662 .934 .969 r
.3239 .37407 .34659 .37936 .38143 .36165 .35919 .35722 Metetra
.578 .917 .968 r
.35919 .35722 .38143 .36165 .41646 .34782 .39471 .34338 Metetra
.485 .88 .961 r
.39471 .34338 .41646 .34782 .45182 .33799 .43057 .33273 Metetra
.405 .836 .954 r
.43057 .33273 .45182 .33799 .48766 .33213 .46689 .32505 Metetra
.369 .804 .963 r
.46689 .32505 .48766 .33213 .52412 .32873 .50382 .31957 Metetra
.367 .787 .976 r
.50382 .31957 .52412 .32873 .56131 .32641 .54143 .31537 Metetra
.381 .777 .987 r
.54143 .31537 .56131 .32641 .59927 .32486 .5798 .31176 Metetra
.417 .776 .995 r
.5798 .31176 .59927 .32486 .63802 .32308 .61893 .30786 Metetra
.468 .781 .998 r
.61893 .30786 .63802 .32308 .67753 .31975 .6588 .30274 Metetra
.522 .79 .994 r
.6588 .30274 .67753 .31975 .7177 .31398 .69936 .29559 Metetra
.572 .801 .986 r
.69936 .29559 .7177 .31398 .75841 .30516 .7405 .28585 Metetra
.661 .801 .95 r
.02646 .50322 .05171 .51988 .08399 .50763 .05898 .49092 Metetra
.692 .809 .937 r
.05898 .49092 .08399 .50763 .11697 .49262 .0922 .47609 Metetra
.716 .817 .928 r
.0922 .47609 .11697 .49262 .15056 .47516 .12604 .45901 Metetra
.734 .826 .922 r
.12604 .45901 .15056 .47516 .18465 .45574 .16039 .44015 Metetra
.744 .835 .921 r
.16039 .44015 .18465 .45574 .21911 .43508 .19514 .42014 Metetra
.747 .846 .924 r
.19514 .42014 .21911 .43508 .25385 .41398 .23019 .39974 Metetra
.742 .856 .933 r
.23019 .39974 .25385 .41398 .28879 .3933 .26547 .37977 Metetra
.725 .865 .947 r
.26547 .37977 .28879 .3933 .3239 .37407 .30095 .3611 Metetra
.695 .87 .964 r
.30095 .3611 .3239 .37407 .35919 .35722 .33662 .34449 Metetra
.651 .865 .98 r
.33662 .34449 .35919 .35722 .39471 .34338 .37255 .33045 Metetra
.598 .85 .992 r
.37255 .33045 .39471 .34338 .43057 .33273 .40883 .31916 Metetra
.546 .827 .998 r
.40883 .31916 .43057 .33273 .46689 .32505 .44557 .31042 Metetra
.507 .801 .998 r
.44557 .31042 .46689 .32505 .50382 .31957 .48289 .30368 Metetra
.486 .78 .997 r
.48289 .30368 .50382 .31957 .54143 .31537 .52089 .29824 Metetra
.482 .766 .994 r
.52089 .29824 .54143 .31537 .5798 .31176 .55962 .29335 Metetra
.494 .76 .99 r
.55962 .29335 .5798 .31176 .61893 .30786 .59912 .28819 Metetra
.52 .762 .985 r
.59912 .28819 .61893 .30786 .6588 .30274 .63936 .28194 Metetra
.554 .768 .978 r
.63936 .28194 .6588 .30274 .69936 .29559 .68031 .27389 Metetra
.59 .778 .97 r
.68031 .27389 .69936 .29559 .7405 .28585 .72188 .26349 Metetra
.661 .776 .934 r
.00095 .48363 .02646 .50322 .05898 .49092 .03369 .47117 Metetra
.689 .782 .922 r
.03369 .47117 .05898 .49092 .0922 .47609 .06717 .45623 Metetra
.711 .788 .912 r
.06717 .45623 .0922 .47609 .12604 .45901 .10129 .43907 Metetra
.727 .792 .904 r
.10129 .43907 .12604 .45901 .16039 .44015 .13593 .42013 Metetra
.736 .796 .9 r
.13593 .42013 .16039 .44015 .19514 .42014 .171 .40003 Metetra
.739 .799 .9 r
.171 .40003 .19514 .42014 .23019 .39974 .20638 .37951 Metetra
.734 .8 .904 r
.20638 .37951 .23019 .39974 .26547 .37977 .24201 .35939 Metetra
.721 .8 .913 r
.24201 .35939 .26547 .37977 .30095 .3611 .27783 .34053 Metetra
.699 .796 .925 r
.27783 .34053 .30095 .3611 .33662 .34449 .31386 .32362 Metetra
.668 .789 .938 r
.31386 .32362 .33662 .34449 .37255 .33045 .35013 .3092 Metetra
.631 .776 .951 r
.35013 .3092 .37255 .33045 .40883 .31916 .38674 .29745 Metetra
.592 .761 .959 r
.38674 .29745 .40883 .31916 .44557 .31042 .4238 .28816 Metetra
.559 .744 .963 r
.4238 .28816 .44557 .31042 .48289 .30368 .46144 .28084 Metetra
.535 .731 .965 r
.46144 .28084 .48289 .30368 .52089 .29824 .49975 .27485 Metetra
.525 .724 .964 r
.49975 .27485 .52089 .29824 .55962 .29335 .53881 .26943 Metetra
.528 .723 .962 r
.53881 .26943 .55962 .29335 .59912 .28819 .57864 .26375 Metetra
.544 .728 .96 r
.57864 .26375 .59912 .28819 .63936 .28194 .61924 .25702 Metetra
.569 .738 .956 r
.61924 .25702 .63936 .28194 .68031 .27389 .66056 .24852 Metetra
.598 .751 .95 r
.66056 .24852 .68031 .27389 .72188 .26349 .70254 .23773 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.16157 .20642 m
.16617 .2111 L
s
[(5)] .15237 .19707 .98294 1 Mshowa
.32604 .14202 m
.33035 .14696 L
s
[(10)] .31741 .13214 .87321 1 Mshowa
.50139 .07336 m
.50537 .07857 L
s
[(15)] .49342 .06293 .76347 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(20)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.19364 .19386 m
.19637 .1967 L
s
.22611 .18115 m
.22881 .18402 L
s
.259 .16827 m
.26166 .17117 L
s
.29231 .15523 m
.29493 .15816 L
s
.3602 .12864 m
.36275 .13164 L
s
.39481 .11509 m
.39732 .11812 L
s
.42987 .10136 m
.43235 .10443 L
s
.4654 .08745 m
.46783 .09055 L
s
.53786 .05908 m
.5402 .06224 L
s
.57482 .04461 m
.57712 .0478 L
s
.61228 .02994 m
.61453 .03317 L
s
.65025 .01507 m
.65245 .01833 L
s
.12989 .21883 m
.13268 .2216 L
s
.0986 .23108 m
.10142 .23383 L
s
.06769 .24318 m
.07054 .2459 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.015625 0.97619 0.313244 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[0 1.025 -5 0 ]
[0 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
0 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.0001 w
.76704 .46948 m
.71545 .47993 L
s
% Start of user PostScript
0.76704 0.46948 0.715445 0.479928 MAarrowhead1
% End of user PostScript
.51511 .50359 m
.51761 .49714 L
s
% Start of user PostScript
0.515112 0.503592 0.517615 0.497136 MAarrowhead1
% End of user PostScript
.67112 .56246 m
.62536 .54887 L
s
% Start of user PostScript
0.671121 0.56246 0.625365 0.548873 MAarrowhead1
% End of user PostScript
.64281 .47418 m
.60064 .48496 L
s
% Start of user PostScript
0.64281 0.474181 0.600638 0.484956 MAarrowhead1
% End of user PostScript
.62936 .33058 m
.59457 .36765 L
s
% Start of user PostScript
0.629358 0.330578 0.594572 0.36765 MAarrowhead1
% End of user PostScript
.66175 .745 m
.62506 .69447 L
s
% Start of user PostScript
0.661746 0.744997 0.625062 0.69447 MAarrowhead1
% End of user PostScript
.76889 .46261 m
.7172 .47476 L
s
% Start of user PostScript
0.768889 0.462608 0.717195 0.474763 MAarrowhead1
% End of user PostScript
.3357 .2376 m
.3669 .28333 L
s
% Start of user PostScript
0.335704 0.237599 0.366905 0.283335 MAarrowhead1
% End of user PostScript
.82982 .48202 m
.77829 .48682 L
s
% Start of user PostScript
0.829824 0.482023 0.77829 0.48682 MAarrowhead1
% End of user PostScript
.30921 .4263 m
.35936 .44003 L
s
% Start of user PostScript
0.309205 0.426297 0.359364 0.440033 MAarrowhead1
% End of user PostScript
.27372 .6541 m
.31817 .62934 L
s
% Start of user PostScript
0.273721 0.654104 0.31817 0.62934 MAarrowhead1
% End of user PostScript
.75811 .61384 m
.70491 .59253 L
s
% Start of user PostScript
0.758111 0.613843 0.704915 0.592527 MAarrowhead1
% End of user PostScript
.48847 .47807 m
.50463 .48478 L
s
% Start of user PostScript
0.488469 0.478071 0.50463 0.484776 MAarrowhead1
% End of user PostScript
.44937 .77505 m
.47204 .72945 L
s
% Start of user PostScript
0.449368 0.775045 0.472043 0.729451 MAarrowhead1
% End of user PostScript
.67112 .31136 m
.62594 .35069 L
s
% Start of user PostScript
0.671121 0.311356 0.625937 0.350695 MAarrowhead1
% End of user PostScript
.30849 .42772 m
.35878 .44103 L
s
% Start of user PostScript
0.30849 0.427717 0.358782 0.441029 MAarrowhead1
% End of user PostScript
.49182 .59647 m
.5077 .55783 L
s
% Start of user PostScript
0.491817 0.596465 0.507697 0.557831 MAarrowhead1
% End of user PostScript
.34502 .28582 m
.37666 .32672 L
s
% Start of user PostScript
0.34502 0.285818 0.376663 0.326719 MAarrowhead1
% End of user PostScript
.3026 .45528 m
.3531 .46048 L
s
% Start of user PostScript
0.302599 0.455276 0.353097 0.46048 MAarrowhead1
% End of user PostScript
.52022 .80144 m
.52139 .74947 L
s
% Start of user PostScript
0.520219 0.801438 0.521391 0.749466 MAarrowhead1
% End of user PostScript
.56038 .28783 m
.55145 .34113 L
s
% Start of user PostScript
0.560379 0.287834 0.551449 0.341134 MAarrowhead1
% End of user PostScript
.65916 .42592 m
.61595 .44647 L
s
% Start of user PostScript
0.659159 0.425923 0.615947 0.446468 MAarrowhead1
% End of user PostScript
.30896 .27118 m
.35027 .31182 L
s
% Start of user PostScript
0.308961 0.271181 0.350272 0.311821 MAarrowhead1
% End of user PostScript
.68909 .66578 m
.6486 .63248 L
s
% Start of user PostScript
0.689095 0.665779 0.648596 0.632482 MAarrowhead1
% End of user PostScript
.56159 .78676 m
.55045 .73444 L
s
% Start of user PostScript
0.561592 0.786763 0.550454 0.734441 MAarrowhead1
% End of user PostScript
.77441 .66365 m
.72241 .63391 L
s
% Start of user PostScript
0.774409 0.663647 0.722415 0.633907 MAarrowhead1
% End of user PostScript
.42102 .44332 m
.45055 .45417 L
s
% Start of user PostScript
0.421025 0.443321 0.450554 0.454166 MAarrowhead1
% End of user PostScript
.5348 .30527 m
.53247 .3576 L
s
% Start of user PostScript
0.534799 0.305266 0.532468 0.357597 MAarrowhead1
% End of user PostScript
.4972 .49833 m
.5115 .49391 L
s
% Start of user PostScript
0.497203 0.498332 0.511499 0.493915 MAarrowhead1
% End of user PostScript
.29286 .69988 m
.33124 .66685 L
s
% Start of user PostScript
0.292864 0.699882 0.331235 0.666855 MAarrowhead1
% End of user PostScript
.42821 .72027 m
.45233 .68104 L
s
% Start of user PostScript
0.428209 0.720272 0.45233 0.681041 MAarrowhead1
% End of user PostScript
.24667 .71364 m
.29358 .67972 L
s
% Start of user PostScript
0.246672 0.713636 0.293582 0.679718 MAarrowhead1
% End of user PostScript
.5015 .46034 m
.51008 .47968 L
s
% Start of user PostScript
0.5015 0.460339 0.510077 0.479675 MAarrowhead1
% End of user PostScript
.43727 .26886 m
.45083 .31647 L
s
% Start of user PostScript
0.437274 0.268859 0.450827 0.316465 MAarrowhead1
% End of user PostScript
.41214 .5975 m
.44107 .56902 L
s
% Start of user PostScript
0.412138 0.597497 0.441065 0.569019 MAarrowhead1
% End of user PostScript
.68501 .22129 m
.64887 .26777 L
s
% Start of user PostScript
0.68501 0.221285 0.64887 0.267773 MAarrowhead1
% End of user PostScript
.33591 .61857 m
.37184 .59585 L
s
% Start of user PostScript
0.335915 0.618574 0.371845 0.595848 MAarrowhead1
% End of user PostScript
.55492 .50265 m
.53139 .49958 L
s
% Start of user PostScript
0.554917 0.502653 0.531392 0.499575 MAarrowhead1
% End of user PostScript
.64661 .549 m
.60487 .53841 L
s
% Start of user PostScript
0.646615 0.549001 0.604869 0.538407 MAarrowhead1
% End of user PostScript
.24904 .53244 m
.29669 .52292 L
s
% Start of user PostScript
0.249039 0.532443 0.296688 0.522916 MAarrowhead1
% End of user PostScript
.46704 .34929 m
.48226 .39388 L
s
% Start of user PostScript
0.467038 0.349291 0.482264 0.393884 MAarrowhead1
% End of user PostScript
.31323 .75137 m
.34364 .70483 L
s
% Start of user PostScript
0.313232 0.751365 0.343641 0.704827 MAarrowhead1
% End of user PostScript
.35626 .25489 m
.3834 .30054 L
s
% Start of user PostScript
0.356258 0.254889 0.383396 0.300536 MAarrowhead1
% End of user PostScript
.57489 .81816 m
.55929 .76518 L
s
% Start of user PostScript
0.57489 0.818157 0.559286 0.765178 MAarrowhead1
% End of user PostScript
.64754 .73109 m
.61466 .684 L
s
% Start of user PostScript
0.647536 0.731093 0.61466 0.684001 MAarrowhead1
% End of user PostScript
.50572 .33081 m
.51141 .37786 L
s
% Start of user PostScript
0.505723 0.330805 0.511409 0.377863 MAarrowhead1
% End of user PostScript
.70213 .55575 m
.64999 .54644 L
s
% Start of user PostScript
0.702131 0.555752 0.649988 0.546436 MAarrowhead1
% End of user PostScript
.59621 .65616 m
.5763 .61939 L
s
% Start of user PostScript
0.596214 0.656158 0.576301 0.61939 MAarrowhead1
% End of user PostScript
.52258 .48189 m
.51878 .48785 L
s
% Start of user PostScript
0.522585 0.481889 0.518776 0.487852 MAarrowhead1
% End of user PostScript
.36571 .59196 m
.40042 .5706 L
s
% Start of user PostScript
0.365714 0.591963 0.400421 0.570603 MAarrowhead1
% End of user PostScript
.73365 .65054 m
.68507 .62253 L
s
% Start of user PostScript
0.733648 0.650535 0.685071 0.62253 MAarrowhead1
% End of user PostScript
.623 .74101 m
.5966 .69217 L
s
% Start of user PostScript
0.623005 0.741011 0.596602 0.692166 MAarrowhead1
% End of user PostScript
.36261 .36198 m
.39724 .39504 L
s
% Start of user PostScript
0.36261 0.361984 0.397238 0.395044 MAarrowhead1
% End of user PostScript
.77272 .63508 m
.71966 .61027 L
s
% Start of user PostScript
0.772722 0.635077 0.719663 0.610271 MAarrowhead1
% End of user PostScript
.56641 .75713 m
.55685 .70825 L
s
% Start of user PostScript
0.566407 0.757132 0.556852 0.708253 MAarrowhead1
% End of user PostScript
.74876 .70575 m
.69852 .66512 L
s
% Start of user PostScript
0.748756 0.705749 0.698523 0.665119 MAarrowhead1
% End of user PostScript
.39543 .82042 m
.42184 .77863 L
s
% Start of user PostScript
0.395428 0.820422 0.421836 0.778625 MAarrowhead1
% End of user PostScript
.31413 .35656 m
.35821 .38592 L
s
% Start of user PostScript
0.314128 0.356564 0.35821 0.385918 MAarrowhead1
% End of user PostScript
.28526 .49004 m
.33156 .48627 L
s
% Start of user PostScript
0.285265 0.490044 0.331561 0.486267 MAarrowhead1
% End of user PostScript
.46202 .39951 m
.47621 .43198 L
s
% Start of user PostScript
0.462021 0.399515 0.47621 0.431977 MAarrowhead1
% End of user PostScript
.63738 .34406 m
.59905 .37718 L
s
% Start of user PostScript
0.637385 0.344064 0.599045 0.377183 MAarrowhead1
% End of user PostScript
.1996 .42677 m
.25069 .4415 L
s
% Start of user PostScript
0.199597 0.426769 0.250692 0.441503 MAarrowhead1
% End of user PostScript
.77988 .54227 m
.72467 .53441 L
s
% Start of user PostScript
0.779884 0.542269 0.724665 0.534407 MAarrowhead1
% End of user PostScript
.42494 .43535 m
.45292 .45016 L
s
% Start of user PostScript
0.424939 0.43535 0.452919 0.450163 MAarrowhead1
% End of user PostScript
.40408 .37057 m
.43109 .40669 L
s
% Start of user PostScript
0.404083 0.370574 0.43109 0.40669 MAarrowhead1
% End of user PostScript
.54045 .34233 m
.53258 .38589 L
s
% Start of user PostScript
0.540451 0.342335 0.532584 0.385893 MAarrowhead1
% End of user PostScript
.40352 .26194 m
.42114 .30933 L
s
% Start of user PostScript
0.40352 0.261939 0.421137 0.309329 MAarrowhead1
% End of user PostScript
.67442 .41791 m
.62859 .44032 L
s
% Start of user PostScript
0.67442 0.417906 0.628592 0.440319 MAarrowhead1
% End of user PostScript
.32879 .29693 m
.36592 .33561 L
s
% Start of user PostScript
0.328785 0.296934 0.365915 0.335611 MAarrowhead1
% End of user PostScript
.22342 .35824 m
.27409 .38378 L
s
% Start of user PostScript
0.223422 0.358236 0.274093 0.383778 MAarrowhead1
% End of user PostScript
.41819 .57573 m
.45057 .54953 L
s
% Start of user PostScript
0.418188 0.575733 0.450568 0.549526 MAarrowhead1
% End of user PostScript
.67928 .69801 m
.64175 .6577 L
s
% Start of user PostScript
0.679281 0.698014 0.641755 0.657703 MAarrowhead1
% End of user PostScript
.52801 .22559 m
.52344 .27796 L
s
% Start of user PostScript
0.528012 0.225593 0.523441 0.277958 MAarrowhead1
% End of user PostScript
.67123 .2475 m
.63244 .29863 L
s
% Start of user PostScript
0.671226 0.247502 0.632445 0.298633 MAarrowhead1
% End of user PostScript
.83778 .48372 m
.78672 .48775 L
s
% Start of user PostScript
0.837782 0.48372 0.786722 0.487747 MAarrowhead1
% End of user PostScript
.23558 .53058 m
.28469 .52158 L
s
% Start of user PostScript
0.235584 0.530576 0.28469 0.521583 MAarrowhead1
% End of user PostScript
.28453 .35585 m
.33321 .38364 L
s
% Start of user PostScript
0.284526 0.355846 0.333214 0.383637 MAarrowhead1
% End of user PostScript
.66108 .43821 m
.61751 .45593 L
s
% Start of user PostScript
0.661077 0.438214 0.617513 0.455933 MAarrowhead1
% End of user PostScript
.50835 .51231 m
.51601 .5006 L
s
% Start of user PostScript
0.508349 0.512305 0.516014 0.500597 MAarrowhead1
% End of user PostScript
.47574 .82891 m
.48788 .77932 L
s
% Start of user PostScript
0.475736 0.828913 0.487875 0.779321 MAarrowhead1
% End of user PostScript
.51724 .33543 m
.51859 .38124 L
s
% Start of user PostScript
0.517239 0.335434 0.518592 0.381236 MAarrowhead1
% End of user PostScript
.55883 .47513 m
.53428 .48472 L
s
% Start of user PostScript
0.558826 0.475128 0.534282 0.484721 MAarrowhead1
% End of user PostScript
.43625 .42725 m
.46106 .44678 L
s
% Start of user PostScript
0.436247 0.427252 0.461064 0.446779 MAarrowhead1
% End of user PostScript
.67598 .56142 m
.62919 .54856 L
s
% Start of user PostScript
0.675983 0.561416 0.629186 0.548563 MAarrowhead1
% End of user PostScript
.6444 .63438 m
.60975 .60254 L
s
% Start of user PostScript
0.644395 0.634376 0.609752 0.602537 MAarrowhead1
% End of user PostScript
.27234 .56059 m
.31606 .54464 L
s
% Start of user PostScript
0.272336 0.560593 0.316059 0.544637 MAarrowhead1
% End of user PostScript
.35274 .6437 m
.38391 .61506 L
s
% Start of user PostScript
0.352739 0.643701 0.383914 0.615058 MAarrowhead1
% End of user PostScript
.54596 .81476 m
.53858 .76175 L
s
% Start of user PostScript
0.545961 0.814759 0.538583 0.761752 MAarrowhead1
% End of user PostScript
.79282 .5618 m
.73672 .54936 L
s
% Start of user PostScript
0.792819 0.561803 0.736724 0.549356 MAarrowhead1
% End of user PostScript
.27909 .4503 m
.33213 .45931 L
s
% Start of user PostScript
0.279086 0.450303 0.332131 0.45931 MAarrowhead1
% End of user PostScript
.70608 .71395 m
.66292 .66994 L
s
% Start of user PostScript
0.706077 0.713951 0.662916 0.669945 MAarrowhead1
% End of user PostScript
.25838 .46407 m
.31089 .47131 L
s
% Start of user PostScript
0.258382 0.464066 0.310889 0.471311 MAarrowhead1
% End of user PostScript
.34118 .36629 m
.38082 .39618 L
s
% Start of user PostScript
0.34118 0.36629 0.380824 0.396178 MAarrowhead1
% End of user PostScript
.61559 .31048 m
.58782 .35355 L
s
% Start of user PostScript
0.615586 0.310479 0.587816 0.353551 MAarrowhead1
% End of user PostScript
.52427 .65901 m
.53159 .62217 L
s
% Start of user PostScript
0.524265 0.659011 0.531592 0.62217 MAarrowhead1
% End of user PostScript
.58161 .51756 m
.55383 .51278 L
s
% Start of user PostScript
0.581611 0.517555 0.553827 0.512782 MAarrowhead1
% End of user PostScript
.30258 .74925 m
.33498 .70266 L
s
% Start of user PostScript
0.302576 0.749248 0.334979 0.702657 MAarrowhead1
% End of user PostScript
.60574 .29286 m
.58365 .3407 L
s
% Start of user PostScript
0.605741 0.292863 0.583655 0.340696 MAarrowhead1
% End of user PostScript
.52481 .69319 m
.5309 .65357 L
s
% Start of user PostScript
0.524813 0.693191 0.530902 0.653575 MAarrowhead1
% End of user PostScript
.65236 .28522 m
.6131 .33167 L
s
% Start of user PostScript
0.652363 0.285218 0.613098 0.33167 MAarrowhead1
% End of user PostScript
.26442 .58221 m
.30949 .56388 L
s
% Start of user PostScript
0.264424 0.582207 0.309487 0.563878 MAarrowhead1
% End of user PostScript
.41617 .46498 m
.44965 .4665 L
s
% Start of user PostScript
0.416169 0.464979 0.449654 0.466497 MAarrowhead1
% End of user PostScript
.22655 .37429 m
.27767 .39729 L
s
% Start of user PostScript
0.226545 0.374288 0.277674 0.39729 MAarrowhead1
% End of user PostScript
.44396 .72125 m
.46683 .68304 L
s
% Start of user PostScript
0.443958 0.72125 0.466825 0.683042 MAarrowhead1
% End of user PostScript
.54534 .66455 m
.54584 .62754 L
s
% Start of user PostScript
0.545339 0.66455 0.545839 0.627538 MAarrowhead1
% End of user PostScript
.49202 .47416 m
.50617 .48368 L
s
% Start of user PostScript
0.492018 0.474157 0.506172 0.483678 MAarrowhead1
% End of user PostScript
.50387 .5328 m
.51507 .50911 L
s
% Start of user PostScript
0.50387 0.532804 0.515073 0.509106 MAarrowhead1
% End of user PostScript
.78079 .3424 m
.73521 .37344 L
s
% Start of user PostScript
0.78079 0.3424 0.735208 0.373442 MAarrowhead1
% End of user PostScript
.56702 .56676 m
.55324 .54158 L
s
% Start of user PostScript
0.567018 0.566761 0.553242 0.541584 MAarrowhead1
% End of user PostScript
.40538 .64214 m
.42944 .60838 L
s
% Start of user PostScript
0.405377 0.642139 0.429442 0.60838 MAarrowhead1
% End of user PostScript
.66953 .71863 m
.63312 .67416 L
s
% Start of user PostScript
0.669533 0.718629 0.633117 0.674161 MAarrowhead1
% End of user PostScript
.49209 .23331 m
.49437 .28344 L
s
% Start of user PostScript
0.492088 0.233314 0.494366 0.283437 MAarrowhead1
% End of user PostScript
.5719 .47587 m
.54375 .48583 L
s
% Start of user PostScript
0.571901 0.475866 0.54375 0.485831 MAarrowhead1
% End of user PostScript
.29034 .59498 m
.33224 .5757 L
s
% Start of user PostScript
0.29034 0.594984 0.332236 0.575698 MAarrowhead1
% End of user PostScript
.39716 .39065 m
.42736 .42122 L
s
% Start of user PostScript
0.397157 0.39065 0.427359 0.421217 MAarrowhead1
% End of user PostScript
.49027 .50776 m
.5082 .49783 L
s
% Start of user PostScript
0.490268 0.507765 0.508203 0.497828 MAarrowhead1
% End of user PostScript
.34565 .20772 m
.37211 .25645 L
s
% Start of user PostScript
0.345646 0.207719 0.372114 0.256454 MAarrowhead1
% End of user PostScript
.81765 .37537 m
.77168 .3992 L
s
% Start of user PostScript
0.817654 0.375374 0.771678 0.399203 MAarrowhead1
% End of user PostScript
.38347 .19818 m
.4029 .24808 L
s
% Start of user PostScript
0.383474 0.198177 0.402902 0.248082 MAarrowhead1
% End of user PostScript
.49107 .56449 m
.50798 .52993 L
s
% Start of user PostScript
0.491071 0.564489 0.507982 0.529928 MAarrowhead1
% End of user PostScript
.61733 .23647 m
.59383 .29212 L
s
% Start of user PostScript
0.61733 0.236472 0.593833 0.292121 MAarrowhead1
% End of user PostScript
.62188 .75247 m
.59543 .7017 L
s
% Start of user PostScript
0.621881 0.752466 0.595433 0.701695 MAarrowhead1
% End of user PostScript
.53929 .47892 m
.52422 .48637 L
s
% Start of user PostScript
0.539295 0.478923 0.524218 0.486374 MAarrowhead1
% End of user PostScript
.48029 .45587 m
.4967 .4733 L
s
% Start of user PostScript
0.480288 0.455871 0.496697 0.473299 MAarrowhead1
% End of user PostScript
.5556 .82686 m
.54567 .7741 L
s
% Start of user PostScript
0.555603 0.826862 0.545674 0.774101 MAarrowhead1
% End of user PostScript
.28086 .49884 m
.32628 .49308 L
s
% Start of user PostScript
0.280865 0.498845 0.326279 0.493084 MAarrowhead1
% End of user PostScript
.64397 .28322 m
.60774 .3308 L
s
% Start of user PostScript
0.64397 0.283218 0.607742 0.330801 MAarrowhead1
% End of user PostScript
.36367 .66903 m
.39064 .63446 L
s
% Start of user PostScript
0.363669 0.669028 0.390644 0.634464 MAarrowhead1
% End of user PostScript
.25749 .63207 m
.30426 .6087 L
s
% Start of user PostScript
0.257491 0.632068 0.304262 0.608703 MAarrowhead1
% End of user PostScript
.39028 .30757 m
.41254 .3503 L
s
% Start of user PostScript
0.390285 0.30757 0.412536 0.350298 MAarrowhead1
% End of user PostScript
.79643 .46117 m
.74354 .47312 L
s
% Start of user PostScript
0.796432 0.461175 0.743544 0.473117 MAarrowhead1
% End of user PostScript
.37969 .34362 m
.40874 .38215 L
s
% Start of user PostScript
0.37969 0.343619 0.408742 0.382147 MAarrowhead1
% End of user PostScript
.46438 .52179 m
.49438 .50538 L
s
% Start of user PostScript
0.464383 0.521793 0.494384 0.50538 MAarrowhead1
% End of user PostScript
.44443 .23409 m
.45584 .28302 L
s
% Start of user PostScript
0.444433 0.234086 0.45584 0.283016 MAarrowhead1
% End of user PostScript
.48049 .15685 m
.4852 .20278 L
s
% Start of user PostScript
0.480495 0.156848 0.485198 0.202779 MAarrowhead1
% End of user PostScript
.44521 .752 m
.46843 .70988 L
s
% Start of user PostScript
0.445206 0.752002 0.468427 0.709875 MAarrowhead1
% End of user PostScript
.50538 .45208 m
.5109 .47619 L
s
% Start of user PostScript
0.505375 0.452084 0.510899 0.476189 MAarrowhead1
% End of user PostScript
.59102 .51929 m
.56084 .51555 L
s
% Start of user PostScript
0.591022 0.519289 0.560844 0.515554 MAarrowhead1
% End of user PostScript
.58499 .66545 m
.5699 .62779 L
s
% Start of user PostScript
0.584987 0.665452 0.569897 0.627785 MAarrowhead1
% End of user PostScript
.72831 .38406 m
.67868 .41226 L
s
% Start of user PostScript
0.728307 0.384057 0.67868 0.412265 MAarrowhead1
% End of user PostScript
.76632 .50643 m
.71438 .50764 L
s
% Start of user PostScript
0.766319 0.506435 0.714384 0.507644 MAarrowhead1
% End of user PostScript
.41388 .49584 m
.4527 .48541 L
s
% Start of user PostScript
0.413875 0.495838 0.4527 0.485408 MAarrowhead1
% End of user PostScript
.45163 .81081 m
.47222 .76178 L
s
% Start of user PostScript
0.451628 0.810811 0.472224 0.761779 MAarrowhead1
% End of user PostScript
.70557 .67458 m
.6623 .63958 L
s
% Start of user PostScript
0.705573 0.674581 0.662299 0.63958 MAarrowhead1
% End of user PostScript
.73207 .69687 m
.684 .65701 L
s
% Start of user PostScript
0.732074 0.696868 0.683999 0.657011 MAarrowhead1
% End of user PostScript
.28952 .22921 m
.32935 .27049 L
s
% Start of user PostScript
0.289516 0.229209 0.329352 0.270493 MAarrowhead1
% End of user PostScript
.2787 .28954 m
.32541 .32648 L
s
% Start of user PostScript
0.278699 0.289544 0.32541 0.326479 MAarrowhead1
% End of user PostScript
.36978 .39122 m
.40653 .41896 L
s
% Start of user PostScript
0.369781 0.391216 0.406528 0.418959 MAarrowhead1
% End of user PostScript
.7331 .67667 m
.68474 .642 L
s
% Start of user PostScript
0.733096 0.676674 0.684737 0.641996 MAarrowhead1
% End of user PostScript
.55612 .39405 m
.53978 .42683 L
s
% Start of user PostScript
0.55612 0.394053 0.539778 0.426835 MAarrowhead1
% End of user PostScript
.579 .66451 m
.56631 .62706 L
s
% Start of user PostScript
0.579002 0.66451 0.566314 0.62706 MAarrowhead1
% End of user PostScript
.63567 .69256 m
.60733 .65348 L
s
% Start of user PostScript
0.635671 0.692564 0.60733 0.653483 MAarrowhead1
% End of user PostScript
.25659 .62421 m
.30334 .60149 L
s
% Start of user PostScript
0.256595 0.624213 0.303337 0.601494 MAarrowhead1
% End of user PostScript
.65723 .37745 m
.61421 .40595 L
s
% Start of user PostScript
0.657233 0.37745 0.614207 0.405952 MAarrowhead1
% End of user PostScript
.25251 .67903 m
.30077 .6494 L
s
% Start of user PostScript
0.252512 0.679032 0.30077 0.649397 MAarrowhead1
% End of user PostScript
.77805 .55772 m
.72256 .54663 L
s
% Start of user PostScript
0.778049 0.557719 0.722561 0.546634 MAarrowhead1
% End of user PostScript
.49072 .49772 m
.50821 .4933 L
s
% Start of user PostScript
0.490721 0.497719 0.50821 0.493303 MAarrowhead1
% End of user PostScript
.31466 .28234 m
.35505 .32204 L
s
% Start of user PostScript
0.314656 0.282338 0.355046 0.322038 MAarrowhead1
% End of user PostScript
.55264 .5921 m
.54751 .55995 L
s
% Start of user PostScript
0.552641 0.5921 0.547515 0.559954 MAarrowhead1
% End of user PostScript
.46792 .68749 m
.48707 .65137 L
s
% Start of user PostScript
0.467918 0.687493 0.487071 0.651375 MAarrowhead1
% End of user PostScript
.42795 .66902 m
.45061 .63334 L
s
% Start of user PostScript
0.427947 0.669016 0.450609 0.633337 MAarrowhead1
% End of user PostScript
.46259 .38622 m
.47724 .422 L
s
% Start of user PostScript
0.462592 0.386225 0.477242 0.422001 MAarrowhead1
% End of user PostScript
.49355 .50566 m
.50986 .49693 L
s
% Start of user PostScript
0.493552 0.505657 0.509863 0.496933 MAarrowhead1
% End of user PostScript
.5747 .25517 m
.56277 .31111 L
s
% Start of user PostScript
0.574696 0.255167 0.562767 0.311108 MAarrowhead1
% End of user PostScript
.5378 .64911 m
.54108 .61352 L
s
% Start of user PostScript
0.537795 0.649108 0.541076 0.613523 MAarrowhead1
% End of user PostScript
.56781 .59649 m
.55753 .56492 L
s
% Start of user PostScript
0.567813 0.596487 0.557533 0.564917 MAarrowhead1
% End of user PostScript
.692 .57624 m
.64368 .56011 L
s
% Start of user PostScript
0.692001 0.576244 0.643677 0.560115 MAarrowhead1
% End of user PostScript
.36101 .64815 m
.39048 .61776 L
s
% Start of user PostScript
0.361013 0.648148 0.390481 0.617763 MAarrowhead1
% End of user PostScript
.52802 .29671 m
.52791 .35028 L
s
% Start of user PostScript
0.528021 0.296708 0.527914 0.350284 MAarrowhead1
% End of user PostScript
.76932 .46973 m
.71761 .48006 L
s
% Start of user PostScript
0.769316 0.469732 0.717609 0.480055 MAarrowhead1
% End of user PostScript
.59185 .38072 m
.56445 .41144 L
s
% Start of user PostScript
0.591852 0.380723 0.564451 0.411439 MAarrowhead1
% End of user PostScript
.64415 .45833 m
.6028 .47219 L
s
% Start of user PostScript
0.644149 0.458333 0.602799 0.472189 MAarrowhead1
% End of user PostScript
.58048 .18904 m
.56428 .24037 L
s
% Start of user PostScript
0.580476 0.189042 0.564281 0.240372 MAarrowhead1
% End of user PostScript
.43477 .49763 m
.47319 .48906 L
s
% Start of user PostScript
0.434772 0.497633 0.473192 0.48906 MAarrowhead1
% End of user PostScript
.31984 .23521 m
.355 .27974 L
s
% Start of user PostScript
0.31984 0.235209 0.355 0.279739 MAarrowhead1
% End of user PostScript
.69345 .44857 m
.64413 .46339 L
s
% Start of user PostScript
0.693446 0.448571 0.644127 0.463388 MAarrowhead1
% End of user PostScript
.41634 .27023 m
.43259 .3173 L
s
% Start of user PostScript
0.416338 0.270232 0.432589 0.317296 MAarrowhead1
% End of user PostScript
.62575 .5463 m
.59046 .53521 L
s
% Start of user PostScript
0.625752 0.546298 0.590464 0.535207 MAarrowhead1
% End of user PostScript
.56727 .44014 m
.54236 .46215 L
s
% Start of user PostScript
0.567266 0.440141 0.542361 0.462154 MAarrowhead1
% End of user PostScript
.77124 .38509 m
.72209 .41113 L
s
% Start of user PostScript
0.771241 0.385086 0.722086 0.411132 MAarrowhead1
% End of user PostScript
.32792 .70157 m
.3572 .6641 L
s
% Start of user PostScript
0.327922 0.701573 0.357198 0.664096 MAarrowhead1
% End of user PostScript
.52014 .56777 m
.5252 .53479 L
s
% Start of user PostScript
0.520136 0.56777 0.525202 0.534795 MAarrowhead1
% End of user PostScript
.5092 .31763 m
.51408 .36736 L
s
% Start of user PostScript
0.5092 0.317627 0.51408 0.367361 MAarrowhead1
% End of user PostScript
.20154 .50222 m
.2552 .5004 L
s
% Start of user PostScript
0.20154 0.502218 0.255202 0.500398 MAarrowhead1
% End of user PostScript
.54293 .70874 m
.54279 .6667 L
s
% Start of user PostScript
0.542931 0.708735 0.542787 0.666702 MAarrowhead1
% End of user PostScript
.51214 .77749 m
.51691 .72945 L
s
% Start of user PostScript
0.512135 0.777491 0.516912 0.729446 MAarrowhead1
% End of user PostScript
.59328 .27601 m
.576 .32799 L
s
% Start of user PostScript
0.593277 0.276014 0.576003 0.32799 MAarrowhead1
% End of user PostScript
.35562 .4683 m
.39666 .46538 L
s
% Start of user PostScript
0.355623 0.468299 0.396662 0.46538 MAarrowhead1
% End of user PostScript
.26768 .7525 m
.30618 .7112 L
s
% Start of user PostScript
0.267682 0.752502 0.30618 0.711202 MAarrowhead1
% End of user PostScript
.49465 .46111 m
.5063 .47889 L
s
% Start of user PostScript
0.494654 0.461114 0.506303 0.478888 MAarrowhead1
% End of user PostScript
.46895 .18992 m
.47615 .23858 L
s
% Start of user PostScript
0.468949 0.18992 0.476154 0.238576 MAarrowhead1
% End of user PostScript
.6315 .53556 m
.59326 .52865 L
s
% Start of user PostScript
0.631501 0.535562 0.59326 0.52865 MAarrowhead1
% End of user PostScript
.4191 .42243 m
.44678 .44219 L
s
% Start of user PostScript
0.4191 0.422433 0.446775 0.442188 MAarrowhead1
% End of user PostScript
.58484 .55236 m
.56353 .53411 L
s
% Start of user PostScript
0.584844 0.552361 0.563528 0.534113 MAarrowhead1
% End of user PostScript
.72448 .6945 m
.67782 .65499 L
s
% Start of user PostScript
0.724481 0.6945 0.677823 0.654991 MAarrowhead1
% End of user PostScript
.59097 .35502 m
.56504 .39025 L
s
% Start of user PostScript
0.590966 0.355024 0.565035 0.390255 MAarrowhead1
% End of user PostScript
.59683 .62632 m
.57612 .59312 L
s
% Start of user PostScript
0.59683 0.626324 0.576121 0.593116 MAarrowhead1
% End of user PostScript
.64336 .29226 m
.60652 .33756 L
s
% Start of user PostScript
0.643364 0.292263 0.60652 0.337562 MAarrowhead1
% End of user PostScript
.25928 .36147 m
.31085 .38751 L
s
% Start of user PostScript
0.259278 0.361466 0.31085 0.387507 MAarrowhead1
% End of user PostScript
.34281 .43577 m
.38676 .44502 L
s
% Start of user PostScript
0.342805 0.435766 0.386755 0.445016 MAarrowhead1
% End of user PostScript
.22732 .56143 m
.2762 .5459 L
s
% Start of user PostScript
0.227325 0.56143 0.276201 0.545895 MAarrowhead1
% End of user PostScript
.63588 .57862 m
.60022 .55684 L
s
% Start of user PostScript
0.635879 0.578622 0.600219 0.556843 MAarrowhead1
% End of user PostScript
.81196 .46182 m
.75973 .4728 L
s
% Start of user PostScript
0.81196 0.461821 0.759727 0.472799 MAarrowhead1
% End of user PostScript
.48656 .55043 m
.50574 .51832 L
s
% Start of user PostScript
0.486562 0.550426 0.505736 0.518324 MAarrowhead1
% End of user PostScript
.29246 .33057 m
.33946 .36255 L
s
% Start of user PostScript
0.292464 0.330571 0.339459 0.362554 MAarrowhead1
% End of user PostScript
.19156 .59288 m
.23958 .57369 L
s
% Start of user PostScript
0.191556 0.592884 0.239583 0.573691 MAarrowhead1
% End of user PostScript
.49069 .1823 m
.49264 .22976 L
s
% Start of user PostScript
0.490686 0.182305 0.492636 0.229762 MAarrowhead1
% End of user PostScript
.65287 .32498 m
.61111 .36166 L
s
% Start of user PostScript
0.652866 0.324979 0.611113 0.361663 MAarrowhead1
% End of user PostScript
.63885 .30742 m
.60259 .3493 L
s
% Start of user PostScript
0.638851 0.307419 0.602586 0.349304 MAarrowhead1
% End of user PostScript
.46277 .82559 m
.47851 .77665 L
s
% Start of user PostScript
0.462766 0.825586 0.478511 0.776648 MAarrowhead1
% End of user PostScript
.1927 .4684 m
.24448 .47467 L
s
% Start of user PostScript
0.192703 0.468399 0.244481 0.47467 MAarrowhead1
% End of user PostScript
.7311 .43503 m
.68034 .4534 L
s
% Start of user PostScript
0.731104 0.435029 0.680341 0.453399 MAarrowhead1
% End of user PostScript
.47356 .57871 m
.49526 .54438 L
s
% Start of user PostScript
0.473562 0.578708 0.495258 0.544384 MAarrowhead1
% End of user PostScript
.60414 .60142 m
.58053 .57151 L
s
% Start of user PostScript
0.604136 0.601421 0.580525 0.571514 MAarrowhead1
% End of user PostScript
.37736 .44138 m
.41455 .44915 L
s
% Start of user PostScript
0.377356 0.441384 0.414552 0.44915 MAarrowhead1
% End of user PostScript
.60784 .56057 m
.57978 .54348 L
s
% Start of user PostScript
0.607843 0.560572 0.57978 0.543477 MAarrowhead1
% End of user PostScript
.55556 .72821 m
.55081 .68333 L
s
% Start of user PostScript
0.555559 0.728209 0.55081 0.683331 MAarrowhead1
% End of user PostScript
.61412 .39011 m
.58045 .41796 L
s
% Start of user PostScript
0.61412 0.390106 0.580451 0.417956 MAarrowhead1
% End of user PostScript
.44472 .24002 m
.45595 .28867 L
s
% Start of user PostScript
0.444722 0.240015 0.45595 0.288674 MAarrowhead1
% End of user PostScript
.47529 .78553 m
.49064 .73763 L
s
% Start of user PostScript
0.47529 0.785526 0.490644 0.737626 MAarrowhead1
% End of user PostScript
.55701 .5517 m
.5445 .52765 L
s
% Start of user PostScript
0.557008 0.551701 0.544497 0.527646 MAarrowhead1
% End of user PostScript
.50839 .80461 m
.51339 .75324 L
s
% Start of user PostScript
0.50839 0.804608 0.513393 0.753244 MAarrowhead1
% End of user PostScript
.58258 .38771 m
.55788 .41837 L
s
% Start of user PostScript
0.582583 0.387714 0.557883 0.41837 MAarrowhead1
% End of user PostScript
.36735 .46662 m
.40694 .4645 L
s
% Start of user PostScript
0.367348 0.46662 0.40694 0.464502 MAarrowhead1
% End of user PostScript
.52821 .41195 m
.52138 .44319 L
s
% Start of user PostScript
0.528212 0.411951 0.521375 0.443186 MAarrowhead1
% End of user PostScript
.32979 .2066 m
.35965 .25364 L
s
% Start of user PostScript
0.329791 0.206595 0.359648 0.253643 MAarrowhead1
% End of user PostScript
.18369 .54321 m
.23337 .53243 L
s
% Start of user PostScript
0.183688 0.54321 0.23337 0.532435 MAarrowhead1
% End of user PostScript
.64611 .25254 m
.61203 .30799 L
s
% Start of user PostScript
0.646111 0.252542 0.612027 0.307991 MAarrowhead1
% End of user PostScript
.33664 .48311 m
.37898 .47639 L
s
% Start of user PostScript
0.336643 0.483107 0.378978 0.47639 MAarrowhead1
% End of user PostScript
.55414 .69493 m
.55078 .6541 L
s
% Start of user PostScript
0.554135 0.694927 0.55078 0.6541 MAarrowhead1
% End of user PostScript
.74657 .57968 m
.69313 .56497 L
s
% Start of user PostScript
0.746572 0.579677 0.693135 0.564968 MAarrowhead1
% End of user PostScript
.59426 .75254 m
.57628 .70296 L
s
% Start of user PostScript
0.594257 0.752543 0.576285 0.702957 MAarrowhead1
% End of user PostScript
.59478 .70995 m
.57682 .66657 L
s
% Start of user PostScript
0.594782 0.709947 0.576821 0.666573 MAarrowhead1
% End of user PostScript
.60095 .79503 m
.57679 .74026 L
s
% Start of user PostScript
0.600951 0.795031 0.576788 0.740264 MAarrowhead1
% End of user PostScript
.36864 .42608 m
.40726 .44025 L
s
% Start of user PostScript
0.368644 0.426077 0.407261 0.440253 MAarrowhead1
% End of user PostScript
.70799 .36485 m
.6587 .39624 L
s
% Start of user PostScript
0.707994 0.364855 0.658702 0.396237 MAarrowhead1
% End of user PostScript
.59542 .51959 m
.56401 .51656 L
s
% Start of user PostScript
0.595424 0.519594 0.56401 0.51656 MAarrowhead1
% End of user PostScript
.24585 .51285 m
.2947 .50846 L
s
% Start of user PostScript
0.245854 0.512853 0.294704 0.508465 MAarrowhead1
% End of user PostScript
.54648 .36789 m
.53462 .40624 L
s
% Start of user PostScript
0.546476 0.367894 0.53462 0.406241 MAarrowhead1
% End of user PostScript
.76272 .32641 m
.71718 .36056 L
s
% Start of user PostScript
0.762719 0.326408 0.717185 0.360556 MAarrowhead1
% End of user PostScript
.18059 .42345 m
.2286 .43738 L
s
% Start of user PostScript
0.180592 0.423447 0.2286 0.437384 MAarrowhead1
% End of user PostScript
.68495 .44014 m
.63718 .45715 L
s
% Start of user PostScript
0.684947 0.440143 0.637182 0.457155 MAarrowhead1
% End of user PostScript
.48865 .35349 m
.49862 .39658 L
s
% Start of user PostScript
0.48865 0.353487 0.498619 0.396584 MAarrowhead1
% End of user PostScript
.7797 .51238 m
.72646 .51156 L
s
% Start of user PostScript
0.779698 0.512375 0.726459 0.511559 MAarrowhead1
% End of user PostScript
.59516 .23667 m
.57797 .2926 L
s
% Start of user PostScript
0.595158 0.236665 0.577971 0.292596 MAarrowhead1
% End of user PostScript
.7928 .61488 m
.73806 .5932 L
s
% Start of user PostScript
0.792801 0.614882 0.73806 0.593202 MAarrowhead1
% End of user PostScript
.30245 .53307 m
.3431 .51949 L
s
% Start of user PostScript
0.302448 0.533065 0.343097 0.519491 MAarrowhead1
% End of user PostScript
.38542 .58192 m
.41955 .55929 L
s
% Start of user PostScript
0.385419 0.581921 0.419547 0.559292 MAarrowhead1
% End of user PostScript
.44528 .35823 m
.46496 .40072 L
s
% Start of user PostScript
0.44528 0.358229 0.464961 0.400724 MAarrowhead1
% End of user PostScript
.63629 .71256 m
.60762 .66974 L
s
% Start of user PostScript
0.636293 0.71256 0.60762 0.669736 MAarrowhead1
% End of user PostScript
.52338 .52739 m
.52296 .50911 L
s
% Start of user PostScript
0.523379 0.527386 0.522957 0.509109 MAarrowhead1
% End of user PostScript
.2145 .49608 m
.26702 .49586 L
s
% Start of user PostScript
0.214505 0.496079 0.267025 0.495862 MAarrowhead1
% End of user PostScript
.54475 .43849 m
.52775 .4627 L
s
% Start of user PostScript
0.544748 0.438488 0.52775 0.462697 MAarrowhead1
% End of user PostScript
.55287 .34398 m
.54024 .38646 L
s
% Start of user PostScript
0.552871 0.343984 0.540237 0.386456 MAarrowhead1
% End of user PostScript
.30317 .73075 m
.33676 .68906 L
s
% Start of user PostScript
0.303169 0.730751 0.336762 0.689062 MAarrowhead1
% End of user PostScript
.73508 .56824 m
.68209 .55584 L
s
% Start of user PostScript
0.735076 0.568239 0.682087 0.55584 MAarrowhead1
% End of user PostScript
.52493 .43365 m
.51896 .46058 L
s
% Start of user PostScript
0.524934 0.433653 0.518956 0.460583 MAarrowhead1
% End of user PostScript
.52543 .77749 m
.52624 .72851 L
s
% Start of user PostScript
0.525427 0.777488 0.526242 0.728511 MAarrowhead1
% End of user PostScript
.27615 .37025 m
.32664 .39535 L
s
% Start of user PostScript
0.276148 0.370246 0.32664 0.395355 MAarrowhead1
% End of user PostScript
.67873 .60456 m
.63566 .57888 L
s
% Start of user PostScript
0.678735 0.60456 0.635656 0.578883 MAarrowhead1
% End of user PostScript
.60881 .63535 m
.5844 .60155 L
s
% Start of user PostScript
0.60881 0.63535 0.5844 0.601551 MAarrowhead1
% End of user PostScript
.63919 .77313 m
.60786 .72059 L
s
% Start of user PostScript
0.639195 0.773134 0.607864 0.720586 MAarrowhead1
% End of user PostScript
.4952 .66248 m
.51074 .62523 L
s
% Start of user PostScript
0.495204 0.662483 0.510736 0.62523 MAarrowhead1
% End of user PostScript
.55887 .46897 m
.53449 .48125 L
s
% Start of user PostScript
0.55887 0.468973 0.534493 0.481248 MAarrowhead1
% End of user PostScript
.42909 .39622 m
.45179 .4274 L
s
% Start of user PostScript
0.429092 0.396224 0.45179 0.427403 MAarrowhead1
% End of user PostScript
.30339 .70727 m
.33858 .67176 L
s
% Start of user PostScript
0.303395 0.707265 0.338577 0.671762 MAarrowhead1
% End of user PostScript
.32095 .45138 m
.36877 .45629 L
s
% Start of user PostScript
0.320954 0.451382 0.368774 0.456294 MAarrowhead1
% End of user PostScript
.41121 .45417 m
.4435 .45902 L
s
% Start of user PostScript
0.411206 0.454168 0.443503 0.459019 MAarrowhead1
% End of user PostScript
.65434 .4854 m
.60983 .49375 L
s
% Start of user PostScript
0.654345 0.485397 0.609833 0.493754 MAarrowhead1
% End of user PostScript
.33462 .3945 m
.3794 .41878 L
s
% Start of user PostScript
0.334625 0.394497 0.379399 0.418775 MAarrowhead1
% End of user PostScript
.34958 .28914 m
.38006 .32984 L
s
% Start of user PostScript
0.34958 0.289144 0.380059 0.329839 MAarrowhead1
% End of user PostScript
.51296 .16393 m
.50959 .21039 L
s
% Start of user PostScript
0.512961 0.163935 0.509592 0.210386 MAarrowhead1
% End of user PostScript
.50875 .34793 m
.51282 .39135 L
s
% Start of user PostScript
0.50875 0.347932 0.512817 0.391351 MAarrowhead1
% End of user PostScript
.54207 .42477 m
.52794 .45224 L
s
% Start of user PostScript
0.542067 0.42477 0.527944 0.452239 MAarrowhead1
% End of user PostScript
.50944 .16237 m
.50691 .20873 L
s
% Start of user PostScript
0.509444 0.162374 0.506907 0.208735 MAarrowhead1
% End of user PostScript
.52203 .53394 m
.52315 .51208 L
s
% Start of user PostScript
0.522034 0.533935 0.523148 0.512082 MAarrowhead1
% End of user PostScript
.333 .73031 m
.36037 .68732 L
s
% Start of user PostScript
0.333001 0.730309 0.360366 0.687319 MAarrowhead1
% End of user PostScript
.64541 .53495 m
.60323 .52896 L
s
% Start of user PostScript
0.645405 0.534952 0.603225 0.52896 MAarrowhead1
% End of user PostScript
.66157 .56123 m
.61754 .54731 L
s
% Start of user PostScript
0.661572 0.561228 0.61754 0.547311 MAarrowhead1
% End of user PostScript
.47896 .41423 m
.4905 .4441 L
s
% Start of user PostScript
0.478957 0.41423 0.490499 0.444104 MAarrowhead1
% End of user PostScript
.47849 .5438 m
.50124 .51604 L
s
% Start of user PostScript
0.478489 0.543796 0.50124 0.51604 MAarrowhead1
% End of user PostScript
.31225 .69662 m
.34596 .66245 L
s
% Start of user PostScript
0.312247 0.696615 0.345957 0.662446 MAarrowhead1
% End of user PostScript
.66524 .41089 m
.62101 .43491 L
s
% Start of user PostScript
0.665242 0.410886 0.621009 0.434907 MAarrowhead1
% End of user PostScript
.6862 .28932 m
.63893 .33154 L
s
% Start of user PostScript
0.686205 0.289315 0.63893 0.331536 MAarrowhead1
% End of user PostScript
.43336 .54105 m
.46984 .51943 L
s
% Start of user PostScript
0.433356 0.541049 0.469837 0.519426 MAarrowhead1
% End of user PostScript
.44727 .74272 m
.47014 .7019 L
s
% Start of user PostScript
0.447266 0.742724 0.470138 0.701902 MAarrowhead1
% End of user PostScript
.57711 .44948 m
.5485 .46886 L
s
% Start of user PostScript
0.577108 0.449478 0.5485 0.46886 MAarrowhead1
% End of user PostScript
.33141 .66711 m
.36381 .63648 L
s
% Start of user PostScript
0.331409 0.667108 0.363809 0.636475 MAarrowhead1
% End of user PostScript
.56524 .32843 m
.55084 .37308 L
s
% Start of user PostScript
0.565243 0.328433 0.550841 0.373085 MAarrowhead1
% End of user PostScript
.37283 .42134 m
.41043 .4379 L
s
% Start of user PostScript
0.37283 0.421345 0.410426 0.4379 MAarrowhead1
% End of user PostScript
.53596 .50004 m
.52325 .49658 L
s
% Start of user PostScript
0.535957 0.500042 0.523245 0.496579 MAarrowhead1
% End of user PostScript
.57 .57128 m
.55577 .5456 L
s
% Start of user PostScript
0.569996 0.571282 0.555766 0.545598 MAarrowhead1
% End of user PostScript
.80553 .35037 m
.76009 .37851 L
s
% Start of user PostScript
0.805527 0.350373 0.760094 0.378506 MAarrowhead1
% End of user PostScript
.704 .50656 m
.65389 .50935 L
s
% Start of user PostScript
0.704003 0.506562 0.653892 0.509347 MAarrowhead1
% End of user PostScript
.49062 .73914 m
.50282 .69761 L
s
% Start of user PostScript
0.490625 0.739142 0.502818 0.697614 MAarrowhead1
% End of user PostScript
.28693 .67644 m
.32802 .648 L
s
% Start of user PostScript
0.286933 0.67644 0.328022 0.647997 MAarrowhead1
% End of user PostScript
.67308 .6162 m
.63188 .58864 L
s
% Start of user PostScript
0.673079 0.616198 0.63188 0.588638 MAarrowhead1
% End of user PostScript
.45197 .56123 m
.48346 .53254 L
s
% Start of user PostScript
0.451965 0.561229 0.48346 0.532537 MAarrowhead1
% End of user PostScript
.34774 .56429 m
.3854 .54699 L
s
% Start of user PostScript
0.347738 0.56429 0.385398 0.546986 MAarrowhead1
% End of user PostScript
.52826 .72564 m
.53152 .68279 L
s
% Start of user PostScript
0.52826 0.725642 0.531515 0.682788 MAarrowhead1
% End of user PostScript
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.343006 0.64881 0.640625 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[0 1.025 -5 0 ]
[0 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
0 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.76704 .46948 Mdot
.51511 .50359 Mdot
.67112 .56246 Mdot
.64281 .47418 Mdot
.62936 .33058 Mdot
.66175 .745 Mdot
.76889 .46261 Mdot
.3357 .2376 Mdot
.82982 .48202 Mdot
.30921 .4263 Mdot
.27372 .6541 Mdot
.75811 .61384 Mdot
.48847 .47807 Mdot
.44937 .77505 Mdot
.67112 .31136 Mdot
.30849 .42772 Mdot
.49182 .59647 Mdot
.34502 .28582 Mdot
.3026 .45528 Mdot
.52022 .80144 Mdot
.56038 .28783 Mdot
.65916 .42592 Mdot
.30896 .27118 Mdot
.68909 .66578 Mdot
.56159 .78676 Mdot
.77441 .66365 Mdot
.42102 .44332 Mdot
.5348 .30527 Mdot
.4972 .49833 Mdot
.29286 .69988 Mdot
.42821 .72027 Mdot
.24667 .71364 Mdot
.5015 .46034 Mdot
.43727 .26886 Mdot
.41214 .5975 Mdot
.68501 .22129 Mdot
.33591 .61857 Mdot
.55492 .50265 Mdot
.64661 .549 Mdot
.24904 .53244 Mdot
.46704 .34929 Mdot
.31323 .75137 Mdot
.35626 .25489 Mdot
.57489 .81816 Mdot
.64754 .73109 Mdot
.50572 .33081 Mdot
.70213 .55575 Mdot
.59621 .65616 Mdot
.52258 .48189 Mdot
.36571 .59196 Mdot
.73365 .65054 Mdot
.623 .74101 Mdot
.36261 .36198 Mdot
.77272 .63508 Mdot
.56641 .75713 Mdot
.74876 .70575 Mdot
.39543 .82042 Mdot
.31413 .35656 Mdot
.28526 .49004 Mdot
.46202 .39951 Mdot
.63738 .34406 Mdot
.1996 .42677 Mdot
.77988 .54227 Mdot
.42494 .43535 Mdot
.40408 .37057 Mdot
.54045 .34233 Mdot
.40352 .26194 Mdot
.67442 .41791 Mdot
.32879 .29693 Mdot
.22342 .35824 Mdot
.41819 .57573 Mdot
.67928 .69801 Mdot
.52801 .22559 Mdot
.67123 .2475 Mdot
.83778 .48372 Mdot
.23558 .53058 Mdot
.28453 .35585 Mdot
.66108 .43821 Mdot
.50835 .51231 Mdot
.47574 .82891 Mdot
.51724 .33543 Mdot
.55883 .47513 Mdot
.43625 .42725 Mdot
.67598 .56142 Mdot
.6444 .63438 Mdot
.27234 .56059 Mdot
.35274 .6437 Mdot
.54596 .81476 Mdot
.79282 .5618 Mdot
.27909 .4503 Mdot
.70608 .71395 Mdot
.25838 .46407 Mdot
.34118 .36629 Mdot
.61559 .31048 Mdot
.52427 .65901 Mdot
.58161 .51756 Mdot
.30258 .74925 Mdot
.60574 .29286 Mdot
.52481 .69319 Mdot
.65236 .28522 Mdot
.26442 .58221 Mdot
.41617 .46498 Mdot
.22655 .37429 Mdot
.44396 .72125 Mdot
.54534 .66455 Mdot
.49202 .47416 Mdot
.50387 .5328 Mdot
.78079 .3424 Mdot
.56702 .56676 Mdot
.40538 .64214 Mdot
.66953 .71863 Mdot
.49209 .23331 Mdot
.5719 .47587 Mdot
.29034 .59498 Mdot
.39716 .39065 Mdot
.49027 .50776 Mdot
.34565 .20772 Mdot
.81765 .37537 Mdot
.38347 .19818 Mdot
.49107 .56449 Mdot
.61733 .23647 Mdot
.62188 .75247 Mdot
.53929 .47892 Mdot
.48029 .45587 Mdot
.5556 .82686 Mdot
.28086 .49884 Mdot
.64397 .28322 Mdot
.36367 .66903 Mdot
.25749 .63207 Mdot
.39028 .30757 Mdot
.79643 .46117 Mdot
.37969 .34362 Mdot
.46438 .52179 Mdot
.44443 .23409 Mdot
.48049 .15685 Mdot
.44521 .752 Mdot
.50538 .45208 Mdot
.59102 .51929 Mdot
.58499 .66545 Mdot
.72831 .38406 Mdot
.76632 .50643 Mdot
.41388 .49584 Mdot
.45163 .81081 Mdot
.70557 .67458 Mdot
.73207 .69687 Mdot
.28952 .22921 Mdot
.2787 .28954 Mdot
.36978 .39122 Mdot
.7331 .67667 Mdot
.55612 .39405 Mdot
.579 .66451 Mdot
.63567 .69256 Mdot
.25659 .62421 Mdot
.65723 .37745 Mdot
.25251 .67903 Mdot
.77805 .55772 Mdot
.49072 .49772 Mdot
.31466 .28234 Mdot
.55264 .5921 Mdot
.46792 .68749 Mdot
.42795 .66902 Mdot
.46259 .38622 Mdot
.49355 .50566 Mdot
.5747 .25517 Mdot
.5378 .64911 Mdot
.56781 .59649 Mdot
.692 .57624 Mdot
.36101 .64815 Mdot
.52802 .29671 Mdot
.76932 .46973 Mdot
.59185 .38072 Mdot
.64415 .45833 Mdot
.58048 .18904 Mdot
.43477 .49763 Mdot
.31984 .23521 Mdot
.69345 .44857 Mdot
.41634 .27023 Mdot
.62575 .5463 Mdot
.56727 .44014 Mdot
.77124 .38509 Mdot
.32792 .70157 Mdot
.52014 .56777 Mdot
.5092 .31763 Mdot
.20154 .50222 Mdot
.54293 .70874 Mdot
.51214 .77749 Mdot
.59328 .27601 Mdot
.35562 .4683 Mdot
.26768 .7525 Mdot
.49465 .46111 Mdot
.46895 .18992 Mdot
.6315 .53556 Mdot
.4191 .42243 Mdot
.58484 .55236 Mdot
.72448 .6945 Mdot
.59097 .35502 Mdot
.59683 .62632 Mdot
.64336 .29226 Mdot
.25928 .36147 Mdot
.34281 .43577 Mdot
.22732 .56143 Mdot
.63588 .57862 Mdot
.81196 .46182 Mdot
.48656 .55043 Mdot
.29246 .33057 Mdot
.19156 .59288 Mdot
.49069 .1823 Mdot
.65287 .32498 Mdot
.63885 .30742 Mdot
.46277 .82559 Mdot
.1927 .4684 Mdot
.7311 .43503 Mdot
.47356 .57871 Mdot
.60414 .60142 Mdot
.37736 .44138 Mdot
.60784 .56057 Mdot
.55556 .72821 Mdot
.61412 .39011 Mdot
.44472 .24002 Mdot
.47529 .78553 Mdot
.55701 .5517 Mdot
.50839 .80461 Mdot
.58258 .38771 Mdot
.36735 .46662 Mdot
.52821 .41195 Mdot
.32979 .2066 Mdot
.18369 .54321 Mdot
.64611 .25254 Mdot
.33664 .48311 Mdot
.55414 .69493 Mdot
.74657 .57968 Mdot
.59426 .75254 Mdot
.59478 .70995 Mdot
.60095 .79503 Mdot
.36864 .42608 Mdot
.70799 .36485 Mdot
.59542 .51959 Mdot
.24585 .51285 Mdot
.54648 .36789 Mdot
.76272 .32641 Mdot
.18059 .42345 Mdot
.68495 .44014 Mdot
.48865 .35349 Mdot
.7797 .51238 Mdot
.59516 .23667 Mdot
.7928 .61488 Mdot
.30245 .53307 Mdot
.38542 .58192 Mdot
.44528 .35823 Mdot
.63629 .71256 Mdot
.52338 .52739 Mdot
.2145 .49608 Mdot
.54475 .43849 Mdot
.55287 .34398 Mdot
.30317 .73075 Mdot
.73508 .56824 Mdot
.52493 .43365 Mdot
.52543 .77749 Mdot
.27615 .37025 Mdot
.67873 .60456 Mdot
.60881 .63535 Mdot
.63919 .77313 Mdot
.4952 .66248 Mdot
.55887 .46897 Mdot
.42909 .39622 Mdot
.30339 .70727 Mdot
.32095 .45138 Mdot
.41121 .45417 Mdot
.65434 .4854 Mdot
.33462 .3945 Mdot
.34958 .28914 Mdot
.51296 .16393 Mdot
.50875 .34793 Mdot
.54207 .42477 Mdot
.50944 .16237 Mdot
.52203 .53394 Mdot
.333 .73031 Mdot
.64541 .53495 Mdot
.66157 .56123 Mdot
.47896 .41423 Mdot
.47849 .5438 Mdot
.31225 .69662 Mdot
.66524 .41089 Mdot
.6862 .28932 Mdot
.43336 .54105 Mdot
.44727 .74272 Mdot
.57711 .44948 Mdot
.33141 .66711 Mdot
.56524 .32843 Mdot
.37283 .42134 Mdot
.53596 .50004 Mdot
.57 .57128 Mdot
.80553 .35037 Mdot
.704 .50656 Mdot
.49062 .73914 Mdot
.28693 .67644 Mdot
.67308 .6162 Mdot
.45197 .56123 Mdot
.34774 .56429 Mdot
.52826 .72564 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{520.688, 341.688},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000::0001Zb000`400?l00000o`00003ooooooooo
ooooohcooooo003oooooooooooooS?ooool00?oooooooooooon<ooooo`00ooooooooooooohcooooo
003oooooooooooooS?ooool00?oooooooooooon<ooooo`00ooooooooooooohcooooo003ooooooooo
ooooS?ooool00?oooooooooooon<ooooo`00ooooooooooooohcooooo003oooooooooooooS?ooool0
0?oooooooooooon<ooooo`00ooooooooooooohcooooo003oooooooooooooS?ooool00?oooooooooo
oon<ooooo`00ooooooooooooohcooooo003oooooooooooooS?ooool00?ooooooiOooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00002_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`02_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`04_ooool4o`00
0003oa0@4?oooooooooo01cooooo003oooooonGooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400[ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`08ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@0:ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@0Dooooo`03o`000?oooooo
oooo01kooooo003oooooonGooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7o
k^k^00_ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00002Oooool01Ol@413ooooooooo
oooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000:ooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol0003ooooooooooooooooo000001Cooooo00?o0000ooooooooool07_ooool0
07oooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0aoooool5o`0000?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP24ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Q
onk^kP0:ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool0000:oooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00[ooooo00Go
0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S805?ooool00ol0003o
ooooooooo`0Nooooo`00Ooooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`37ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg08Cooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Wooooo
00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000[ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`02_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00Dooooo`03o`000?oooooooooo01ko
oooo0020ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4038ooooo`03
oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4024ooooo`05oa0@4?oooooooooo
ooooool@41003oooool00ol0003oooooooooo`08ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00omgMgOoc<c<o`00000:ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7
ooooo`0<ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@
01Cooooo00?o0000ooooooooool07_ooool0087ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003o
oooooooooooooooo00000<Wooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo
000008Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
2_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000002_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P03?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000Dooooo`03o`000?oooooooooo01kooooo0022
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00003:ooooo`03ogMgMomV
IVKooooo00;ooooo00Go0000ooooooooooooooooo`000024ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=
ooooo`03ogMgMol0003ooooo00Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4
A4Co0000oa0@40[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@
4?nYZJT04_ooool00omEEEGoIVIVo`00000Pooooo`00Poooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool0bOooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@
ooooooooool0ooooool@ooooo`;o00000_ooool2o`0001?ooooo001oooooo`05o`000?nj^[[ooooo
oiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg0<Oooooo00Go0000okZj^_ooooooV9RH
oa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0oooooolBooooo`06onk^k_lQ8B7oQhN7okZj
^_l0003ogMgM4oooool007oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h0aoooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP3ooooooa?ooooo00CogMgMo`000?l@413oc<c<5?ooool00?ooooood_oooonIo`0000So
oooo00Cok^k^ob4Q8Ol@413ok^k^5?ooool00?ooooood_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool01?lQ8B7oMgMgogMgMolb<S8Doooo
o`00oooooooBooooo`03o`000?oooooooooo09gooooo0_l00002ooooo`;o00004oooool008_ooooo
0_l0003Cooooo`;o0000Koooool00ol0003oooooooooo`2fooooo`00R?ooool6o`000<oooooo0ol0
00000ooooooo0000ooooo`1^ooooo`03o`000?oooooooooo0;Kooooo001Mooooo`Co000000Go410@
ooooooooooooooooodA4A002o`000003oc8b<_oMgMgooooo01_ooooo1Ol000000onY_NSo0000o`00
002Sooooo`Co000000Go410@ooooooooooooooooodA4A002o`000003oc8b<_oMgMgooooo01cooooo
0_l00004ooooo`;o0000K_ooool00ol0003oooooooooo`2fooooo`00Goooool00ol0003ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo01Sooooo1Ol00004ojVmj0?o0000Y?ooool00ol0003ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo01Wooooo0ol00006ooooo`03o`000?oooooo000006gooooo00?o
0000ooooooooool0]_ooool005oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0D
ooooo`Ko00001_nY_NP00ol0003oZKgXo`00002Tooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool05Oooool3o`0000Wooooo00?o0000ooooool00000KOooool00ol0003oooooooooo`2f
ooooo`00Goooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo01?ooooo1Ol00002ojVm
j003o`000?nY_NSoZKgX00CoZKgX00?o0000ojVmj?nY_NP00_l0002Rooooo`03o`000?oooooooooo
00Kooooo00?oMgMgoc8b<_ooool05?ooool2o`0000cooooo00Co0000ooooool0003o0000K?ooool0
0ol0003oooooooooo`2fooooo`00Goooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`04Oooool5o`0000KoZKgX00?o0000ojVmj?nY_NP00onY_NP00ol0003oZKgXojVmj002
o`000:;ooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01;ooooo1?l0
000=ooooo`05o`000?ooooooooooooooool00000Joooool00ol0003oooooooooo`2fooooo`00Gooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo1?l000000onY_NSo0000ojVm
j007ojVmj003o`000?nY_NSoZKgX00;oZKgX0ol000000onY_NSo0000ooooo`2Qooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool04_ooool2o`00017ooooo00Go0000oooooooooooooooo
o`00001[ooooo`03o`000?oooooooooo0;Kooooo001Oooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool03_ooool5o`0000CoZKgX00?o0000ojVmj?nY_NP01_nY_NP01_l0003oZKgXo`00
0?l0003oZKgXo`0000?oZKgX00?o0000ooooooooool0Woooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00oooooo0ol0000Cooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0J?ooool00ol0003oooooooooo`2fooooo`00GOooool00omEEEGoIVIVo`000005ooooo`Co0000
2oooool2o`000003ooooool0003o000000OoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000?oZKgX
00?o0000ojVmj?nY_NP00_nY_NP00ol0003oooooooooo`2Looooo`03oeEEEOmVIVKo000000Gooooo
1?l0000;ooooo`?o00000_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0Ioooool00ol0003oooooooooo`2fooooo`00LOooool6o`000003ojVmj?l0
003oZKgX00OoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj005o`000?nY_NSoZKgXojVmj?l00000
1?nY_NP2o`000;;ooooo0_l0000Iooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
Ioooool00ol0003oooooooooo`2fooooo`00K_ooool6o`0000GoZKgX00?o0000ojVmj?nY_NP01OnY
_NP3o`0000KoZKgX00Co0000ojVmj?nY_NSo00001?nY_NP2o`000:oooooo1?l0000Jooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`2fooooo`00K?oo
ool2o`000004ooooool0003o0000o`0000SoZKgX00Co0000ojVmj?nY_NSoZKgX0ol000000onY_NSo
0000ojVmj007ojVmj004o`000?nY_NSo0000ojVmj0?o000000?oZKgXo`000?l00000[?ooool2o`00
01oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo
0;Kooooo001Yooooo`Ko00000_nY_NP00ol0003oZKgXojVmj006ojVmj004o`000?nY_NSo0000o`00
00GoZKgX00?o0000ojVmj?nY_NP01OnY_NP01?l0003oZKgXo`000?l00005ojVmj003o`000?oooooo
oooo0:Oooooo0ol0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0IOooool0
0ol0003oooooooooo`2fooooo`00Ioooool5o`0000KoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`00
00SoZKgX00?o0000ojVmj?nY_NP00onY_NP4o`0000OoZKgX00?o0000ooooooooool01Oooool01Om4
A4Co0000o`000?lb<S;ogMgM09Wooooo0ol000000ooooooo0000ooooo`0Qooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool01Om4A4Co0000o`000?lb<S;ogMgM05[ooooo00?o
0000ooooooooool0]_ooool003cooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;o
k^k^7?ooool5o`000003ojVmj?l0003oZKgX00OoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003
o`000?nY_NSoZKgX00KoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj0;o00001onY_NP2o`0000Wo
oooo00?oMgMgoc8b<_ooool0KOooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^hMooooo`;o00009oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o
MgMgoc8b<_ooool0FOooool00ol0003oooooooooo`2fooooo`00?_ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool5o`0000CoZKgX00?o0000ojVmj?nY_NP01OnY
_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP01OnY_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP01?nY
_NP3o`0000[ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL06_ooool4o`0002Sooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0]_ooool003kooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01Oooooo1_l00007ojVmj003o`00
0?nY_NSoZKgX00;oZKgX0_l000000onY_NSo0000ojVmj007ojVmj004o`000?nY_NSoZKgXojVmj0?o
000000?oZKgXo`000?nY_NP01_nY_NP2o`0000;oZKgX0ol00002ojVmj0;o00002?ooool00omgMgOo
<S8booooo`1_ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Hoooo
o`;o0000;?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b
<_ooool0FOooool00ol0003oooooooooo`2fooooo`00?_ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000005Oooool5o`0000;oZKgX00?o0000ojVmj?nY_NP01_nY_NP01?l0
003oZKgXo`000?l00004ojVmj003o`000?nY_NSoZKgX00GoZKgX00Co0000ojVmj?l0003o00001OnY
_NP00ol0003oZKgXojVmj004ojVmj0Co00001_nY_NP00ol0003oooooooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`0L?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00005Oooool3o`0002kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`0F_ooool00ol0003oooooooooo`2fooooo`00?_ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000004_ooool5o`0000KoZKgX00?o0000ojVm
j?nY_NP01?nY_NP3o`0000OoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000SoZKgX00Co0000ojVm
j?nY_NSoZKgX0ol000000onY_NSo0000ojVmj007ojVmj0;o00000oooool00ol0003oooooooooo`1b
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`;o000000?o
ooooo`000?ooool0;_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0G?ooool00ol0003oooooooooo`2fooooo`00?_ooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41003oooool5o`000003ojVmj?l0003oZKgX00OoZKgX00?o
0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX00KoZKgX00?o0000ojVmj?nY_NP00ol0
0002ojVmj003o`000?nY_NSoZKgX00GoZKgX00Co0000ojVmj?l0003o00000_nY_NP01?l0003oZKgX
ojVmj?l00007ojVmj0;o00000oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@400@ooooo`?o0000<oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooo000000?ooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`2foooo
o`00?_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03Oooool5o`00
00CoZKgX00?o0000ojVmj?nY_NP01OnY_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP01OnY_NP3o`00
00KoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000CoZKgX00Go0000ojVmj?nY_NSoZKgXo`000003
ojVmj0?o000000?oZKgXo`000?ooool00_ooool4o`00077ooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00gooooo1?l0000eooooo`03o`000?oooooooooo00Wooooo00Co
0000oooooooooooooooo1?l0001Kooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0
KOooool003cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00[ooooo
0ol000000ooooooo0000o`000007ojVmj003o`000?nY_NSoZKgX00;oZKgX0_l000000onY_NSo0000
ojVmj007ojVmj004o`000?nY_NSoZKgXojVmj0?o000000?oZKgXo`000?nY_NP01onY_NP00ol0003o
ZKgXojVmj003o`0000;oZKgX00Go0000ojVmj?nY_NSoZKgXo`000003ojVmj004o`000?nY_NSo0000
o`0000GoZKgX00?o0000ooooooooool0Loooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool2o`0003Wooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`1Oooooo`03o`000?oooooooooo04Kooooo00Co0000oooooooooooooooo0_l0001Zooooo`00D?oo
ool2o`000004ooooool0003o0000o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP01?l0003oZKgX
o`000?l00004ojVmj003o`000?nY_NSoZKgX00GoZKgX00Co0000ojVmj?l0003o00001OnY_NP00ol0
003oZKgXojVmj005ojVmj0?o00001_nY_NP01Ol0003oZKgXojVmj?nY_NSo000000;oZKgX0_l00008
ojVmj003o`000?oooooooooo08Kooooo0ol0000kooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0G_ooool00ol0003oooooooooo`16ooooo`04o`000?ooooooooooooooo`;o0000J_oo
ool004gooooo1_l00006ojVmj003o`000?nY_NSoZKgX00CoZKgX0_l00007ojVmj003o`000?nY_NSo
ZKgX00CoZKgX0_l00008ojVmj004o`000?nY_NSoZKgXojVmj0?o000000?oZKcWo`000?nY_NP01onY
_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00OoZKgX0_l00025ooooo`;o00000_oo
ool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0G_oo
ool00ol0003oooooooooo`16ooooo`04o`000?ooooooooooooooo`;o0000J_ooool004_ooooo1Ol0
00000onY_NSo0000ojVmj007ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP00ol0003oZKgXojVm
j005ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP00ol0003oZKgXojVmj005ojVmj004o`000?nY
_NSo0000o`0000GoZKcW00?o0000ojVmj?nY_NP01OnY_NP4o`0000CoZKgX00?o0000ojVmj?nY_NP0
1?nY_NP3o`0008;ooooo0ol00010ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
A?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool00ol0003o
ooooooooo`16ooooo`?o000000?oooooo`000?l00000J_ooool004Sooooo1Ol00005ojVmj003o`00
0?nY_NSoZKgX00GoZKgX0ol00006ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00006ojVmj003o`00
0?nY_NSoZKgX00CoZKgX0_l00008ojVli`04o`000?nY_NSoZKgXojVmj0?o000000CoZK_Vo`000?nY
_NSo00001OnY_NP00ol0003oZKgXojVmj003o`0000;oZKgX0_l0001nooooo`Co0000@_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo04?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Cooooo00?o0000ooooooooool0A?oo
ool00ol0003oooooo`000005o`0000Wooooo00?o0000ooooooooool0G_ooool002Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@0Kooooo`?o000000Coooooo`000?l0003o00001onY_NP01?l0003oZKgX
ojVmj?nY_NP3o`000003ojVmj?l0003oZKgX00OoZKgX00?o0000ojVmj?nY_NP00ol000000onX/n7o
0000ojVmj007ojVmj003o`000?nY_NSoZKgX00?o00000_nY^^D00ol0003oZKcWojVli`05ojVli`04
o`000?nY_NSo0000o`0000GoZK_V0_l00005ojVmj0?o00001_nY_NP00ol0003oooooooooo`1Ioooo
o`05odA4A?l0003o0000oc8b<_oMgMd07?ooool2o`0000Cooooo00?o0000ooooooooool0?oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04?ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?o0000ooooooooool0=oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Go00002Oooool00ol0003oooooooooo`1Nooooo`00:?ooool0
0omgMgOo<S8booooo`0Hooooo`;o000000Coooooo`000?l0003o00000_nY_NP00ol0003oZKgXojVm
j005ojVmj004o`000?nY_NSo0000o`0000GoZKgX00?o0000ojVmj?nY_NP01OnY_NP3o`0000GoZ;?Q
00?o0000ojVmj?nY_NP01?nY_NP4o`0000KoZK[U00?o0000ojVlionY_>L01?nY_>L2o`0000SoZK_V
00Co0000ojVmj?nY_NSoZKgX0_l000000onY_NSo0000ojVmj007ojVmj0;o0000G?ooool00omgMgOo
<S8booooo`0Hooooo`?o0000B?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04;o
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Cooooo0_l0000hoooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_l000000ooooooo0000ooooo`09oooo
o`03o`000?oooooooooo05kooooo000Yooooo`03o`000?oooooooooo01Cooooo1_l00006ojVmj003
o`000?nY_NSoZKgX00CoZKgX0_l00008ojVmj004o`000?nY_NSoZKgXojVmj0?o000000?oYj[Io`00
0?nX/n401_nX/n400ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVjiOnY^^D01_nY^^D00ol0
003oZKcWojVli`03o`000003oj:Ba?l0003oZK_V00OoZK_V00Co0000ojVmj?l0003o00001?nY_NP0
0ol0003oZKgXojVmj005ojVmj0;o0000GOooool00ol0003oooooooooo`0Eooooo`;o00000_ooool0
0ol0003oooooooooo`16ooooo`03o`000?oooooooooo00kooooo0_l00013ooooo`05o`000?oooooo
ooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`03o`000?oooooooooo02oooooo00?o
0000ooooool000001_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;o000000?o
ooooo`000?ooool02?ooool00ol0003oooooooooo`1Oooooo`00:?ooool00omgMgOo<S8booooo`0C
ooooo`;o000000?oooooo`000?l000000_nY_NP00ol0003oZKgXojVmj005ojVmj003o`000?nY_NSo
ZKgX00?o00000_nY_NP00ol0003oZKgXojVmj005ojVmj004o`000?nY_NSo0000o`0000GoYj[I00?o
0000ojRchOnX/n401?nX/n43o`0000KoZKgX00?o0000ojVjiOnY^^D01OnY^^D3o`0000GoXY;400?o
0000ojVki_nY^nH01?nY^nH3o`0000OoZKgX00Co0000ojVmj?nY_NSoZKgX0ol000000onY_NSo0000
ooooo`1Kooooo`03ogMgMolb<S;ooooo01?ooooo0ol0001=ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0@Oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo000000Kooooo00?o0000oooooooo
ool02Oooool5o`0000_ooooo00?o0000ooooooooool0Goooool002Gooooo00Go0000ob4Q8Ol0003o
<S8bolc<c00Aooooo`Ko00001OnY_NP00ol0003oZKgXojVmj004ojVmj0?o00001_nY_NP00ol0003o
ZKgXojVmj004ojVmj0;o00001onWZ]T00ol0003oZ;?QojRch@03ojRch@03o`000?nZW<So000000So
ZKgX00Co0000ojVjiOnY^^GoZK[U0ol000000onLPKCo0000oj:Ba006oj:Ba003o`000?nY^nKoZK_V
00?o000000?o[;kWo`000?l000001onY_NP01?l0003oZKgXo`000?l00005ojVmj003o`000?oooooo
oooo05Kooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Booooo`;o000000?oooooo`000?ooool0COoo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo043ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooo000000Gooooo00?o0000ooooooooool02Oooool3o`000003ooooool0003ooooo00Wo
oooo0_l0000@ooooo`03o`000?oooooooooo04kooooo000Uooooo`03o`000?oooooooooo017ooooo
0_l00002ooooo`;o00002?nY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP0
1OnY_NP00ol0003oZKgXojVmj003o`000003ojVghol0003oYj[I00OoYj[I00?o0000ojRchOnX/n40
0_l00003ojZLb003o`000?nY_NSoZKgX00GoZKgX00Co0000ojVjiOl0003o00001OnLPK@00ol0003o
XY;4oj:Ba005oj:Ba0;o00001?n/_^L00ol0003o[;kWo`000006ojVmj0;o00002?nY_NP00ol0003o
ooooooooo`1Eooooo`03o`000?oooooooooo017ooooo0ol0001Booooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool0?oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c004ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01Oooool2
o`0000Gooooo0ol00009ooooo`?o000000?oooooo`000?ooool00oooool00ol0003oooooooooo`03
ooooo`;o00004?ooool00ol0003oooooooooo`1>ooooo`009Oooool00ol0003oooooooooo`0>oooo
o`Oo00000_nY_NP00ol0003oZKgXojVmj005ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj004ojVm
j0?o00001OnY]n<00ol0003oYj[IojNZf@05ojNZf@03o`000?nX/n7o000000KoZYc800?o0000ojVm
j?nY_NP01?nY_NP2o`0000OoW86d00?o0000oj:Ba?nRT/@01OnRT/@00ol0003o[;kWojbni`03ojbn
i`04o`000?n/_^Oo[;kWo`0000;oZKgX0ol000000onY^nKo0000ojVmj007ojVmj0;o0000E_ooool0
0ol0003oooooooooo`0>ooooo`Co0000E?ooool00ol0003oooooooooo`0@ooooo`;o0000F_ooool0
0ol0003oooooooooo`0Zooooo`08o`000?ooooooooooooooool0003oooooo`000?ooool4o`0000;o
oooo0ol00006ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00008
ooooo`03o`000?oooooooooo04oooooo000Uooooo`Co00002_ooool3o`000004ooooool0003o0000
o`0000KoZKgX00?o0000ojVmj?nY_NP00_nY_NP2o`000003ojVmj?l0003oZKgX00OoZKgX00?o0000
ojVmj?nY_NP00ol000000onWZm[o0000ojVgh`06ojVgh`03o`000?nWZ]WoYj[I00CoYj[I0_l00008
ojZLb003o`000?nY_NSoZKgX00?o000000?oUgN]o`000?nLPK@01_nLPK@00ol0003oXY;4oj:Ba004
oj:Ba003o`000?n^QJWo000000Co[;kW00?o0000ojbnion/_^L00ol00005ojVkiP03o`000?nY_NSo
ZKgX00CoZKgX0ol0001Fooooo`Co00002oooool2o`0005Sooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`1Gooooo`03o`000?oooooooooo02_ooooo00Go0000oooooooooooo0000oooo
o`06o`0000?ooooo0_l00006ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00007ooooo`03o`000?oooooooooo053ooooo000aooooo`;o000000Coooooo`000?l0003o
00000_nY_NP00ol0003oZKgXojVmj005ojVmj004o`000?nY_NSo0000o`0000CoZKgX00?o0000ojVm
j?nY_NP01OnY_NP3o`0000GoYj_J00?o0000ojVghonY]n<01?nY]n<00ol0003oYj[IojNZf@02ojNZ
f@;o000000?oYY6no`000?nZW<P01onZW<P3o`0000GoUgN]00?o0000oib1]?nLPK@01OnLPK@00ol0
003oXY;4oj:Ba002oj:Ba005o`000?n^QJWo[XFYojj5ZOl000000on/_^L3o`000003ojbmi_l0003o
ZK_V00KoZK_V00?o0000ojVmj?nY_NP00ol00002ojVmj0;o0000HOooool3o`0005_ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo02cooooo00Oo0000
oooooooooooo0000ooooool0003ooooo00?o00001?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`04o`00
0?ooooooooooo`0000Kooooo0ol0001Booooo`00;_ooool6o`0000KoZKgX00?o0000ojVmj?nY_NP0
1?nY_NP2o`0000OoZKgX00?o0000ojVmj?nY_NP00_nY_NP2o`000003ojR_gOl0003oYj_J00KoYj_J
00?o0000ojVghonY]n<01?nY]n<01?l0003oYj[Io`000?l00004ojJA_P03o`000?nZW<SoZYc800Co
ZYc800?o0000ol2R^ol000001_nGMjd00ol0003oW86doib1]005oib1]005o`000?nRT/CoXY;4oj:B
a?l000001?n^QJT00ol0003o[;kWo`000002o`0000Co[;gV00?o0000ojVki_nY^nH01?nY^nH3o`00
00KoZKgX00?o0000ooooooooool01Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b
<_o^k^i<ooooo`;o00000_ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool01Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^i5
ooooo`03o`000?oooooooooo02gooooo00Go0000oooooooooooo0000ooooo`04o`0000_ooooo00?o
0000ooooooooool01?ooool01?l0003oooooooooooooool2o`0000Kooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000;o0000D_ooool002cooooo
1Ol00002ojVmj003o`000?nY_NSoZKgX00GoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003o`00
0?nY_NSoZKgX00GoZKgX00Co0000ojVmj?l0003o00001?nX[md00ol0003oYj_JojN[fP05ojN[fP04
o`000?nY]n?oZKOSojVgh`Co00001_nVTKh00ol0003oZYc8ojZLb003ojZLb004o`000?o0X[_o`::k
o`0000KoUgN]00?o0000oib1]?nLPK@01OnLPK@01?l0003oXY;4oj:Ba?l00006ojj5Z@04o`000?n/
_NKo[;gVo`0000Go[;gV00?o0000ojVki_nY^nH00ol000000onYZMKo0000ojVmj006ojVmj0;o0000
2?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool3o`00063o
oooo00?o0000ooooooooool04_ooool2o`0000Sooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg04Gooooo00?o0000ooooooooool0;?ooool3o`0000;ooooo1?l00005oooo
o`03o`000?oooooooooo00Cooooo0_l00004ooooo`?o00000_ooool3o`0000Gooooo00Ko0000oooo
oooooooo0000ooooool00005ooooo`Co0000Doooool002Wooooo1Ol00006ojVmj003o`000?nY_NSo
ZKgX00CoZKgX0ol00006ojVmj003o`000?nY_NSoZKgX00CoZKgX0_l00007ojR_g@03o`000?nWZm[o
Yj_J00CoYj_J1?l00003oi1a[003o`000?nVTKkoYY6n00GoYY6n00Go0000ojZLb?nZW<SoZYc8o`00
0004ol2R^`03o`000?nGMjgoUgN]00CoUgN]00?o0000oib1]?nLPK@01OnLPK@2o`0000Oo[XFY00Go
0000ojbmi_n/_NKo[;gVo`000004ojbmiP?o00001OnYZMH00ol0003oZKgXojVmj004ojVmj0?o0000
1oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100A_ooool3o`0000;o
oooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@04Gooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`06o`0000Gooooo00?o0000ooooool000000_ooool01?l0
003oooooo`000?l00004ooooo`?o00000_ooool3o`0000Gooooo00?o0000ooooool000000_ooool0
0ol0003oooooooooo`02ooooo`04o`000?oooooo0000o`0005Cooooo000Wooooo`Co00000_nY_NP0
0ol0003oZKgXojVmj005ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP00ol0003oZKgXojVmj005
ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?nX[md01_nX[md00ol0003oYj_JojN[fP02
ojN[fP;o000000?oYXfko`000?n@LJ`01On@LJ`00ol0003oYY6nojJA_P04ojJA_P04o`000?nZW<So
ZYc8o`0000Go`::k00?o0000oiMg[OnGMjd01?nGMjd00ol0003oW86doib1]005oib1]003o`000?n^
QJWo[XFY00Go[XFY00?o0000okW4A?l000000_n/_NH00ol0003o[;gVo`000002o`000003ojNQd?l0
003oZJWF00KoZJWF00?o0000ojVmj?nY_NP00ol000000onY_NSo0000o`000007ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000014ooooo`;o0000I_ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000004Gooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`03ooooo`Co
00001Oooool2o`0000;ooooo00Co0000ooooool0003o00001Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo1_l00003ooooo`04o`000?ooooooooooo`0005Gooooo000Toooo
o`Go00001OnY_NP00ol0003oZKgXojVmj004ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj004ojVm
j0?o00001OnY_NP00ol0003oZ:oMojR_g@05ojR_g@04o`000?nWZm[o0000o`0000?oYXfk00?o0000
oi1a[?n@LJ`01?n@LJ`00ol0003oYY6nojJA_P04ojJA_P03o`000?nZW<So000000Ko`::k00?o0000
oiMg[OnGMjd01?nGMjd00ol0003oW86doib1]004oib1]0;o00001on^QJT01Ol0003o^LA4okW4A?l0
003o[;gV00;o00001OnWXM000ol0003oZJWFojVYeP04ojVYeP?o00001OnY_NP2o`0000Kooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000047ooooo1Ol0001Vooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000AOooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00?o
oooo00Co0000ooooool0003o00001?ooool01Ol0003oooooo`000?oooooo000000;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo1_l00003
ooooo`Co0000EOooool002;ooooo0_l00002ooooo`;o00001onY_NP01?l0003oZKgXojVmj?nY_NP2
o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000
ojVmj?nY_NP01?nY_NP00ol0003oZ:oMojR_g@04ojR_g@;o00001_nVSK/00ol0003oT76/oi1a[003
oi1a[003o`000?nVTKkoYY6n00CoYY6n0_l00007ol2R^`03o`000?nGMjgoUgN]00GoUgN]00?o0000
oib1]?nLPK@00_nLPK@00ol0003oZ7nWo`000007ojj5Z@04o`000?nia4Co^LA4okW4A0;o00001_nW
XM000ol0003oZJWFojVYeP03ojVYeP03o`000?ngZ<[o000000OoZKgX0_l00005ooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@400oooooo`;o0000Joooool00ol0003ooooo
ooooo`0Eooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
4100AOooool00ol0003oooooooooo`0Wooooo`;o00001Oooool00ol0003oooooooooo`02o`0000;o
oooo0_l00005ooooo`;o00000_ooool00ol0003oooooo`00000?ooooo`;o000000?oooooo`000?l0
00000_l00002ooooo`;o000000Coooooo`000?l0003o00001?ooool00ol0003oooooooooo`1>oooo
o`007oooool7o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP00ol0003oZKgXo`000005ojVmj003
o`000?nY_NSoZKgX00CoZKgX0ol00006ojVmj003o`000?nY_NSoZKgX00CoZKgX00?o0000ojR_gOnX
[md00ol000000onMS/Co0000ojJ=^`05ojJ=^`03o`000?n@LJcoT76/00CoT76/00?o0000ojJA__nV
TKh00_nVTKh00ol0003o/9>ho`000007ol2R^`03o`000?nGMjgoUgN]00GoUgN]00Go0000oib1]?nL
PKCoW86do`000003ojQoY`03o`000?n^QJWo[XFY00?o[XFY00Co0000okW4A?nia4Co^LA40ol00007
ojNQd003o`000?nYZMKoZJWF00;o00000ongZ<X00ol0003oZKgXojVmj004ojVmj0;o00001Oooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0??ooool4o`0006cooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`15ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
0oooool4o`0000?ooooo0_l00003ooooo`Co000000?oooooo`000?l000002oooool00ol0003ooooo
ooooo`02ooooo`Ko000000?oooooo`000?ooool01_l00003ooooo`03o`000?oooooooooo04oooooo
000Looooo`?o000000Coooooo`000?l0003o00001_nY_NP00ol0003oZKgXojVmj004ojVmj0;o0000
1onY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP01?l0003oZKgX
ojVmj?nY_NP5o`0000CoWHk400?o0000ojJ=^onVSK/01?nVSK/00ol0003oT76/oi1a[004oi1a[005
o`000?nVTKkoYY6nojJA__l000000on`TkP00ol0003o`::kol2R^`05ol2R^`03o`000?nGMjgoUgN]
00CoUgN]00Co0000oib1]?nLPKCo00001?nXOjL00ol0003o[XFYojj5Z@03ojj5Z@04o`000?nia4Co
^LA4o`0000;ofnSM00?o0000ojNQd?nWXM001OnWXM000ol0003oZJWFo`000006okNXbP03o`000?nY
_NSoZKgX00?o000000?oZKgXo`000?l000000_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h0>Oooool3o`0006kooooo0ol0000Iooooo`06o`000?oooooooooooeEEEOmV
IVKo00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^04Gooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`02ooooo`;o000000?oooooo`000?l000000oooool00ol0003oooooooooo`02
ooooo`?o000000?oooooo`000?l000002oooool00ol0003oooooooooo`02ooooo`?o000000Cooooo
o`000?oooooooooo0ol000001?oooooo0000ooooool00003ooooo`03o`000?oooooooooo053ooooo
000Jooooo`Ko00000_nY_NP00ol0003oZKgXojVmj005ojVmj003o`000?nY_NSoZKgX00?o00000_nY
_NP00ol0003oZKgXojVmj004ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj004ojVmj0Co00000onF
TLd00ol0003oWHk4oif>a004oif>a003o`000?nVSK_oYXfk00?oYXfk00?o0000oi1a[?n@LJ`01?n@
LJ`01?l0003oYY6nojJA__l00004ok2C^003o`000?o0X[_o`::k00Go`::k00?o0000oiMg[OnGMjd0
1OnGMjd2o`0000GoZ7nW00?o0000ojj5ZOn^QJT00on^QJT00ol0003o^LA4o`000003om_Xg@03o`00
0?nWXM3oYj7@00GoYj7@0_l00008okNXbP;o00001OnY_NP00ol0003oooooooooo`13ooooo`?o0000
KOooool3o`0000;oVL3c00?o0000ooooooooool05oooool00ol0003oooooooooo`1Aooooo`03o`00
0?oooooooooo02_ooooo0_l00004ooooo`03o`000?oooooo000000;o00000_ooool00ol0003ooooo
ooooo`02ooooo`;o000000?oooooo`000?l000002oooool2o`0000?ooooo0_l000001_oooooo0000
o`000?oooooo0000ooooo`?o000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`1Aoooo
o`005oooool6o`0000KoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000KoZKgX00Co0000ojVmj?nY
_NSoZKgX0_l00002ojVmj003o`000?nY_NSoZKgX00GoZKgX00?o0000ojVmj?nY_NP00ol000000onY
_NSo0000oiJAc@05oiJAc@03o`000?nMS/CoWHk400?oWHk400?o0000ojJ=^onVSK/00onVSK/00ol0
003oT76/oi1a[005oi1a[0;o00001_n`TkP00ol0003o`::kol2R^`04ol2R^`03o`000?nGMjgoUgN]
00CoUgN]0_l00006ojQoY`03o`000?n^QJWo[XFY00;o[XFY00?o0000okW4A?l000000ooKj=d3o`00
00?oYj7@0ol000000onQP[7o0000okNXbP07okNXbP03o`000?nY_NSoZKgX00GoZKgX0_l00010oooo
o`?o00000oooool00ol0003oooooooooo`1Vooooo`Co00001?nI`?<3o`0001Wooooo00?o0000oooo
ooooool0D?ooool00ol0003oooooooooo`0/ooooo`04o`000?ooooooooooooooo`?o000000?ooooo
o`000?l000000_ooool00ol0003oooooooooo`03ooooo`;o000000?oooooo`000?ooool02_ooool2
o`0000?ooooo0_l000001Ooooooo0000o`000?oooooo000000;ooooo1?l000000ooooooo0000o`00
0002o`0005;ooooo000Fooooo`Co00000onY_NP00ol0003oZKgXojVmj004ojVmj003o`000?nY_NSo
ZKgX00?o00000_nY_NP00ol0003oZKgXojVmj005ojVmj003o`000?nY_NSo000000GoZKgX00?o0000
ojVmj?nY_NP01?nY_NP3o`0000GoZKgX00?o0000oiJAcOnFTLd00onFTLd00ol0003oWHk4oif>a003
oif>a003o`000?nVSK_oYXfk00CoYXfk00?o0000oi1a[?n@LJ`01?n@LJ`00ol0003o/9>hok2C^005
ok2C^003o`000?o0X[_o`::k00Co`::k00?o0000oiMg[OnGMjd00_nGMjd2o`000003olKgk?l0003o
Z7nW00GoZ7nW00?o0000ojj5ZOn^QJT00_n^QJT2o`000005om_XgOl0003o0000o`000?oKj=d00_l0
00000onWXM3o0000o`000005oj62/@03o`000?ngZ<[o]jS:00Co]jS:00?o0000on7SeOl000001OnY
_NP3o`0003oooooo0_l0001Zooooo`Co00000_nA_?@00ol0003oVL3coiW0l`03o`000004oiW0lol0
003oVL3co`0001Wooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0[ooooo`?o0000
1Oooool01?l0003oooooo`000?l00002ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`02o`0000;ooooo0_l00002ooooo`?o00000_ooool4o`0000;o
oooo0_l0001Dooooo`005_ooool00ol0003oZKgXojVmj005ojVmj003o`000?nY_NSoZKgX00?oZKgX
0ol00006ojVmj003o`000?nY_NSoZKgX00CoZKgX0_l00007ojVmj003o`000?nY_NSoZKgX00?o0000
0_nY_NP00ol0003oZKgXojVmj003ojVmj003o`000?nFTLgoUY7=00?oUY7=00?o0000oif>a?nMS/@0
1?nMS/@00ol0003oYXfkojJ=^`03ojJ=^`03o`000?n@LJcoT76/00CoT76/00?o0000ok2C^?n`TkP0
1On`TkP00ol0003o`::kol2R^`04ol2R^`05o`000?nGMjgoUgN]oiMg[Ol000000oo6mn`00ol0003o
Z7nWojQoY`05ojQoY`04o`000?n^QJWo[XFYojj5Z@?o00001OoKj=d2o`0000OoXH:a00?o0000okNX
b_ngZ<X00ongZ<X01?l0003ohN?Eon7SeOl00002ojVmj0?o00000_nY_NP00ol0003oooooooooo`0m
ooooo`03o`000?oooooo000006Cooooo1Ol00006oi6lm0?o00001OnI`?<00ol0003oVL3co`00000H
ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0;_ooool01?l0003ooooooooooooo
ool3o`000005ooooool0003o0000ooooool000004?ooool00ol0003oooooooooo`02o`0000;ooooo
0ol000000ooooooo0000o`000006o`0000;ooooo0_l0000?ooooo`;o0000A?ooool001Kooooo0_l0
0007ojVmj003o`000?nY_NSo000000;o00000_nY_NP00ol0003oZKgXojVmj005ojVmj003o`000?nY
_NSoZKgX00?o000000?oZKgXo`000?nY_NP01_nY_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP00_nY
_NP00ol0003oUY7=oiJAc@04oiJAc@03o`000?nMS/CoWHk400?oWHk400?o0000ojJ=^onVSK/00onV
SK/00ol0003oT76/oi1a[003oi1a[003o`000?o>^LKo000000Oo/9>h00?o0000ol2R^oo0X[/01?o0
X[/3o`0000Coa_O/00?o0000ojQoYonXOjL01OnXOjL5o`000004olKl__l0003ofnSMom_Xg@?o0000
00?oTfnWo`000?nQP[401onQP[401Ol0003o]jS:okNXb_ngZ<[o000000?ohN?E0ol00006ojVmj003
o`000?oooooooooo03cooooo00Co0000oooooooooooo0000G?ooool7o`0000CoRk[e00Co0000oi6l
m?nA_?CoTKcd0ol00002oi6lm003o`000?nI`??oVL3c00CoVL3c0ol0000Hooooo`03o`000?oooooo
oooo04kooooo00?o0000ooooooooool0:Oooool2o`0000[ooooo00?o0000ooooooooool00_ooool2
o`0000kooooo00?o0000ooooool000000_l00002ooooo`03o`000?oooooo000000;ooooo2_l0000?
ooooo`03o`000?oooooooooo04Cooooo000Fooooo`03o`000?oooooo000000KoZKgX0_l00006ojVm
j003o`000?nY_NSoZKgX00CoZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00;oZKgX0_l00002ojVm
j003o`000?nY_NSoZKgX00GoZKgX00?o0000ojVmj?nY_NP00_nY_NP00ol0003oUY7=oiJAc@03oiJA
c@03o`000?nMS/CoWHk400?oWHk400?o0000ojJ=^onVSK/00onVSK/00ol0003oT76/oi1a[002oi1a
[004o`000?o>^LKoc[W6o`0000Oo/9>h00Co0000ol2R^oo0X[_o`::k1_l00005olKgk003o`000?nX
OjOoZ7nW00;oZ7nW0ol00002ojj5Z@03o`000?o6o;koa_bn00?o00001?nCKjL2o`0000OoXH:a00Co
0000okNXb_ngZ<[o00000ooQhmD00ol0003o`K39o`000007ojVmj0;o0000?Oooool01Ol0003ooooo
oooooooooooo000005?ooooo2?l00004ohNimP03o`000?n;^_GoRk[e00GoRk[e0ol00005oi6lm003
o`000?nI`??oVL3c00Co000000?oUlOho`000?l000006?ooool2o`0004oooooo00?o0000oooooooo
ool0:oooool2o`0000gooooo0_l0000>ooooo`03o`000?oooooo000000?o000000Coooooo`000?oo
oooo00000_ooool6o`000004ooooool0003o0000o`0000gooooo0_l00004ooooo`;o0000@Oooool0
01Gooooo00Go0000ooooooooooooooooo`000002ojVmj0?o00000_nY_NP00ol0003oZKgXojVmj004
ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP00ol0003oZKgXojVmj004ojVmj004o`000?nY_NSo
0000o`0000GoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000;oZKgX00?o0000oiJAcOnFTLd00onF
TLd00ol0003oWHk4oif>a004oif>a003o`000?nVSK_oYXfk00;oYXfk00Go0000oi1a[?n@LJcoT76/
o`000003oljiaP03o`000?n`TkSo/9>h00Ko/9>h0ol00005ofk1oP;o00001?o6mn`00ol0003oZ7nW
o`000002o`0000;oZ7nW00?o0000ojj5ZOn^QJT00ol000000onXSk[o0000oi=_Y`05oi=_Y`03o`00
0?nQP[7oXH:a00GoXH:a00?o0000okNXb_l000000ooQhmD01Ol0003o`K39ol6`bOo1/<Wo000000Ko
ZKgX0_l0000mooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0BOooool7o`0000Co
Q[Wf00?o0000ohNim_n7^OH01_n7^OH01?l0003oRk[eoh^jmOn;^_D3o`000003oh^jmOl0003oTKcd
00?oTKcd1Ol00005oiO7n003o`000?nGaoSo000001Sooooo00?o0000ooooooooool0COooool00ol0
003oooooooooo`0]ooooo`;o00002?ooool01?l0003oooooooooooooool2o`0000Oooooo00?o0000
ooooooooool00oooool6o`000003ooooool0003o000000?ooooo0_l000001?oooooo0000o`000?oo
ool3o`0000gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`11ooooo`005Oooool0
0ol0003oooooooooo`02ooooo`;o00001_nY_NP00ol0003oZKgXojVmj003ojVmj0?o00001_nY_NP0
0ol0003oZKgXojVmj003ojVmj0?o00001onY_NP00ol0003oZKgXojVmj003o`000003ojR_gOl0003o
HX?M00?o00001_nFTLd00ol0003oWHk4oif>a006o`0000?oYXfk00?o0000oi1a[?l000001Oo>^LH0
0ol0003o/9>hok2C^004ok2C^004o`000?nYkZCoZNjTo`0000;oK/7n0ol000000onSZ=Wo0000olKg
k002olKgk0?o00001OnXOjL01?l0003o[XFYo`000?l00003ojR?^P03o`000?nCKjOoTfnW00CoTfnW
0_l00007oj62/@05o`000?oQhmGohN?Eon7SeOl000001Oo1/<T00ol0003oZKgXojVmj003o`000003
ojVmj?l0003o000003_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`12ooooo`Ko
00001?n8^oL00ol0003oQ[WfohJimP05ohJimP03o`000?n7^OKoQkWf00KoQkWf0ol00002oh^jm@Oo
00001?n=a?X00ol0003oUlOhoiO7n004oiO7n003o`000?nGaoSo000001Sooooo00?o0000oooooooo
ool0C?ooool00ol0003oooooooooo`0Xooooo`;o00000oooool3o`0000Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000;ooooo1_l000000ooo
oooo0000o`000003ooooo`;o000000?oooooo`000?ooool00ol0000=ooooo`?o00000_ooool2o`00
00Gooooo0_l0000mooooo`005Oooool00ol0003oooooooooo`03ooooo`03o`000?nY_NSoZKgX00Go
ZKgX00?o0000ojVmj?l000000_l00002ojVmj003o`000?nY_NSoZKgX00GoZKgX00?o0000ojVmj?l0
00000_l00003ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00005ojR_g@04o`000?mRPmgoHX?Mof:3
g@Wo00001Om^aOl6o`0000Koc[W600?o0000ok2C^?n`TkP00on`TkP01?l0003oZNjTojW^Y?nYkZ@3
o`0000GoXjSI0ol000000oo6mnco0000ojQoY`06ojQoY`;o00001OnXSkX00ol0003oTfnWoi=_Y`03
oi=_Y`03o`000?nQP[7o000000KoXH:a0_l000000ooQhmGo0000ol6`b@06ol6`b@;o00001OnY_NP2
o`0003[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0kooooo`Ko00000on?__H0
0ol0003oR;_gohRkm`05ohRkm`03o`000?n6^OKoQ[Wf00GoQ[Wf00?o0000ohNim_n7^OH00_n7^OH8
o`0000?oQL?l00?o0000ohg4n_n=a?X01_n=a?X00ol0003oUlOhoiO7n004oiO7n0?o00006?ooool0
0ol0003oooooooooo`1;ooooo`03o`000?oooooooooo01oooooo0_l00003ooooo`;o00001?ooool0
0ol0003oooooooooo`02o`000003ooooool0003ooooo00;ooooo00Go0000ooooooooooooooooo`00
0008ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00ol000000ooooooo0000
o`000003o`0000Cooooo1Ol0000>ooooo`;o00000oooool00ol0003oooooooooo`03ooooo`;o0000
?oooool001Gooooo00?o0000ooooooooool01?ooool00ol0003oZKgXojVmj004ojVmj0;o00001_nY
_NP00ol0003oZKgXojVmj004ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj003o`000003ojVghol0
003oZ:oM00GoZ:oM00Go0000of:3gOmRPmgoHX?Mo`000007ohQi_0;o00000om^aOl4o`000003o`>0
g_l0003oc[W600Ooc[W600Ko0000ok2C^?n`TkSo/9>ho`000?nYkZ@3o`000003oiO?nol0003oXjSI
00;oXjSI1Ol00002olKgk003o`000?nXOjOoZ7nW00GoZ7nW0_l00005ojR?^P03o`000?nCKjOoTfnW
00CoTfnW0_l00005oj62/@04o`000?oB/;Ood[2go`0000So`K3900?o0000ojVmj?nY_NP01OnY_NP2
o`0003Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0gooooo`?o00000onG`_D0
0ol0003oSkkfohnnmP04ohnnmP03o`000?n8^oOoR;_g00GoR;_g00?o0000ohJim_n6^OH00_n6^OH7
o`0000CoO/;m00?o0000ohG3o?n5`o`01On5`o`00ol0003oSLCjohg4nP06ohg4nP03o`000?nGaoSo
UlOh00Co00000_nBcO`00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04_ooooo00?o0000
ooooooooool08Oooool2o`0000?ooooo0_l00003ooooo`;o00000_ooool01?l0003oooooo`000?l0
0002ooooo`04o`000?ooooooooooooooo`;o00001_ooool01ol0003ooooooooooooooooo0000oooo
ool000000_ooool3o`000003ooooool0003o000000;o00001?ooool3o`000003ooooool0003o0000
00cooooo0_l00004ooooo`?o00000_ooool2o`00047ooooo000Eooooo`03o`000?oooooooooo00Go
oooo00?o0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX00CoZKgX00?o0000ojVmj?nY
_NP00ol00003ojVmj003o`000?nY_NSoZKgX00?oZKgX0ol00005ojVgh`03o`000?nX[mgoZ:oM00Co
Z:oM00Co0000of:3gOmRPmgo00002On8NK`3o`0000?oS8O90ol00008oljiaP03o`000?n`TkSo/9>h
00?o00001OnGco/3o`0000?oXjSI0_l00003olKgk003o`000?nXOjOoZ7nW00CoZ7nW00?o0000ojR?
^_nXSkX01?nXSkX00ol0003oTfnWoi=_Y`04oi=_Y`03o`000?nQP[7o000000?oXH:a00Go0000om:`
]ooB/;Ood[2go`000007ol6`b@03o`000?oQoL_o000000KoZKgX0_l0000iooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0<_ooool4o`0000OoUl;e00?o0000ohnnm_n?__H01?n?__H0
0ol0003oR;_gohRkm`02ohRkm`Oo00000_mka?h3o`0000OoO/;m00?o0000ohG3o?n5`o`01On5`o`0
0ol0003oSLCjohg4nP02ohg4nPKo00001?nBcO`01?l0003oT/gloi;=o?l0000Gooooo`03o`000?oo
oooooooo04[ooooo00?o0000ooooooooool07oooool2o`0000;ooooo0ol000000ooooooo0000o`00
0002o`0000;ooooo0_l000001Ooooooo0000o`000?oooooo000000;ooooo00Go0000oooooooooooo
ooooo`000007ooooo`03o`000?oooooooooo00;o000000?oooooo`000?l000000ol000000ooooooo
0000o`000002o`0000;ooooo0_l00003ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool00oooool2o`0000?ooooo0ol00003ooooo`;o0000??ooool001Gooooo00?o0000ooooooooool0
1_ooool2o`0000KoZKgX00?o0000ojVmj?nY_NP00onY_NP3o`0000OoZKgX00?o0000ojVmj?l00000
0_l000000onY_NSo0000ojVgh`06ojVgh`03o`000?nX[mgoZ:oM00?oZ:oM00Go0000of:3gOmRPmgo
HX?Mo`000008ohQi_003o`000?n<QlWoS8O900?oS8O900Co0000oem?Yol0003o00001oo>^LH00ol0
003o/9>ho`000003om7mgP03o`000?nGco_o000000;o000000?oUloko`000?nSZ=T01?nSZ=T2o`00
00;oa_O/00?o0000ojQoYonXOjL01?nXOjL2o`0000GoZ8nj00?o0000oi=_YonCKjL01?nCKjL01?l0
003oXH:aoj62/Ol00002oj62/@06o`000?oB/;Ood[2go`000?o[`Z_o00001Oo1/<T01Ol0003ohOg;
on7mbooQoL_o000000;oZKgX0ol000000onY_NSo0000o`000007ooooo`Co000000Go410@oooooooo
ooooooooodA4A002o`000003oc8b<_oMgMgooooo02?ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0^ooooo`?o00000onQa_<00ol0003oUl;eoiO2m@06oiO2m@04o`000?n?__KoSkkf
ohnnmPOo00001Omlaol4o`0000?oNlCn00?o0000ogk2oOmn`_d01Omn`_d00ol0003oQL?lohG3o002
ohG3o0Oo00001On5b_h00ol0003oT/gloi;=o003oi;=o0Go00005_ooool00ol0003oooooooooo`05
ooooo`Co000000Go410@ooooooooooooooooodA4A002o`000003oc8b<_oMgMgooooo03Kooooo00?o
0000ooooooooool08Oooool6o`0000;ooooo2_l000001?oooooo0000o`000?ooool2o`000003oooo
ool0003o000000Kooooo0_l000000ooooooo0000o`000006o`000004ooooool0003o0000o`0000?o
oooo0_l000000ooooooo0000o`000007ooooo`;o000000?oooooo`000?ooool00_l0000:ooooo`;o
00000oooool2o`0003kooooo000Dooooo`03o`000?oooooooooo00Sooooo00?o0000ojVmj?nY_NP0
1OnY_NP00ol0003oZKgXo`000002o`0000?oZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000GoZKgX
00?o0000ojVghonY]n<01?nY]n<01?l0003oZ:oMojR_gOnX[md4o`0000;oHX?M00?o0000ohQi_?n8
NK`01On8NK`00ol0003odK>lo`000004ohb7b@03o`000?mOCjOoGdnW00;o00001Oo>^LH3o`0000Co
dOgN1?l00002oiO?n`03o`000?nSZ=WoXjSI00?oXjSI00Go0000o`0>VOl0003oa_O/o`000005ojQo
Y`03o`000?oLo];o000000GoZ8nj00?o0000oi=_YonCKjL01OnCKjL00ol0003oXH:aoj62/@02o`00
00?od[2g00?o0000on_2Zol000001?o1/<T00ol0003ohOg;on7mb`02on7mb`?o00001OnY_NP00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool08oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo02[ooooo0ol00007oj76l`03o`000?nG`_GoUl;e
00CoUl;e1Ol00005oh7=o`03o`000?mlaoooO<Oo00;oO<Oo1?l00006og_4oP03o`000?mn`_goO/;m
00;oO/;m1ol00005ogO7o`03o`000?n5b_koQL[n00GoQL[n00?o0000oi;=o?nBcO`01?l00003oh_@
oP03o`000?oooooooooo01?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo01gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2
o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool08oooool5o`000003ooooool0003o
000000Ko00000_ooool3o`000003ooooool0003o000000;ooooo00?o0000ooooool000001?ooool2
o`000003ooooool0003o000000?o000000Coooooo`000?oooooooooo0ol00002ooooo`;o000000?o
ooooo`000?l000001_ooool2o`0000?ooooo0_l00006ooooo`;o00001?ooool2o`000003ooooool0
003o0000043ooooo000Dooooo`03o`000?oooooooooo00Wooooo00?o0000ojVmj?nY_NP01?nY_NP2
o`0000OoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj005ojVmj003o`000?nY]n?o
ZKOS00?oZKOS1?l00003oi=f[`04o`000?mRPmgoHX?Mo`0000KoR7Vl00Co0000om6c_?oA/kco0000
1On<QlT01?l0003oGdnWoem?Yol00002oljiaP?o000000CoS>Sgo`000?oAoMkodOgN0ol00002ojjY
d`03o`000?m9T>ko000000?o00001?nSZ=T01Ol0003o00jIo`000?o6mnco000000CoZ7nW00Co0000
omcnd_oLo];o00001_nXSkX00ol0003oTfnWoi=_Y`04oi=_Y`04o`000?nQP[7oXH:ao`0000Cod[2g
00Co0000on_2Zoo[`Z_o00000_o1/<T01?l0003ohOg;on7mbooQoL/2o`000003okgIk_l0003oZKgX
00GoZKgX0_l00008ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo02Oooooo0_l00002oj_9l003o`000?nQa_?oXLKc
00KoXLKc00?o0000oiO2mOnG`_D00ol00004oh_Co`03o`000?n1cOooPLgo00CoPLgo1?l000000oml
aooo0000o`00000<o`0000GoJ/Kn00?o0000ogO7oomgaol01Omgaol00ol0003oQL[nohG:oP02ohG:
oPGo00000on;d?h00ol0003oRm3noh_@oP02oh_@oP03o`000?oooooooooo01;ooooo0_l00008oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09?ooool3
o`0000Cooooo1ol00003ooooo`;o00000_ooool2o`000003ooooool0003o000000Gooooo0_l00000
0ooooooo0000ooooo`02o`000004ooooool0003oooooooooo`?o000000Koooooo`000?l0003o0000
ooooool00002ooooo`;o000000?oooooo`000?l000001?ooool3o`0000Cooooo0_l00004ooooo`;o
00000_ooool3o`00043ooooo000Dooooo`03o`000?oooooooooo00[ooooo00?o0000ojVmj?nY_NP0
0ol00002ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00CoZKgX
00?o0000ojVghol000000_l000000onJS<?o0000oi=f[`04oi=f[`;o00000_mRPmd00ol0003oR7Vl
ohQi_002ohQi_005o`000?oA/kcodK>lom6c_?l000001On<QlT01?l0003oGdnWoem?YomOCjL3o`00
00;oS>Sg1Ol00005ojjYd`04o`000?m9T>koBI3^odV@kP?o00000onSZ=T01?l0003o00jIo`000?l0
0003ojQoY`;o00000ooLo]800ol0003oZ8njojR?^P03ojR?^P03o`000?nCKjOoTfnW00CoTfnW00?o
0000oj62/OnQP[400_l00002om:`]`07o`000?o[`Z_ojl:[on_2Zol0003o`K39o`000002on7mb`;o
00001?nmfNh00ol0003oZKgXojVmj003ojVmj0?o00001oooool00ol0003oooooooooo`06ooooo`03
ogMgMolb<S;ooooo02;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Tooooo`;o
00001On[bO000ol0003oXLKcoj76l`04oj76l`Co00002?n;dol01?l0003oPLgooh7=oon1cOl7o`00
00GoGLWi0_l00005of76o0;o00001_mZa_h00ol0003oMlOoogO7o`02ogO7o`Oo00001?mhbol00ol0
003oRm3noh_@oP02oh_@oP03o`000?n;d?koRm3n00?o00005Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool07Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol00004ooooo`;o0000:?ooool00ol0003oooooooooo`08ooooo`;o00000oooool0
1_l0003ooooooooooooooooo0000ooooo`;o00001?ooool3o`0000?ooooo00?o0000ooooooooool0
0_ooool2o`0000;ooooo1?l000000ooooooo0000o`000002ooooo`?o00000oooool2o`0000?ooooo
0ol00004ooooo`;o00000oooool2o`0004;ooooo000Dooooo`03o`000?oooooooooo00_ooooo0_l0
0006ojVmj004o`000?nY_NSoZKgXojVmj0;o00000_nY_NP00ol0003oZKgXojVmj004ojVmj004o`00
0?nY_NSoZKgXojVmj0Co00001?nJS<<00ol0003oTgJ_oi=f[`04oi=f[`;o000000?oHX?Mo`000?n8
NK`00_n8NK`00ol0003odK>lom6c_003om6c_003o`000?n<QlWoS8O900;oS8O900?o0000oem?YomO
CjL01?mOCjL5o`0000So[ZWC00Ko0000odV@k_m9T>koBI3^o`000?lVI=L2o`000007oj>XfOl0003o
00jIo`000?o6mnco0000ojQoY`02o`000005oeaWaOl0003og?kBomcnd_l000001OnXSkX00ol0003o
TfnWoi=_Y`05oi=_Y`;o00000_oB/;L00ol0003od[2go`000004on_2Z`Co00001_nmfNh00ol0003o
ZKgXojVmj003o`0000;oZKgX00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`08oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
027ooooo0_l00008oj_9l003o`000?nQa_?oXLKc00?o00001?nIfOd2o`0000CoRm?o1_l00005oek=
mP;o00001?mMbOTEo`0000CoH<Gl00?o0000ogS;oomhbol01Omhbol00ol0003oRm3noh_@oP04o`00
00?oPm3o00?o0000ooooooooool04_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Nooooo`05o`000?ooooooooooooooool000002ooo
ool01?m4A4CogMgMooooool00005ooooo`03o`000?oooooooooo03Cooooo0_l00002ooooo`;o0000
0_ooool00ol0003oooooo`000002o`0000;ooooo0ol00008ooooo`05o`000?oooooo0000o`000?oo
ool00_l00002ooooo`03o`000?oooooooooo00;o00002Oooool3o`0000Cooooo0ol00017ooooo`00
5?ooool00ol0003oooooooooo`0=ooooo`03o`000?nY_NSoZKgX00CoZKgX00?o0000ojVmj?l00000
1OnY_NP00ol0003oZKgXojVmj003ojVmj0Co00000onQ^n/00ol0003oVXc3oiZ<``03oiZ<``03o`00
0?nCMZooTgJ_00?oTgJ_00Co0000oc`oZol0003o00000_n8NK`00ol0003odK>lom6c_004om6c_003
o`000?n<QlWoS8O900;oS8O900Co0000oem?YomOCjOoGdnW0ol000001OmOCjOo0000on33^ooP`k_o
000000So[ZWC0ol00002odV@kP03o`000?lVI=Oo9VCG00;o000000?o00jIo`000?l000000_l00002
oknac003o`000?mLIlGo000000;o00001OnXSkX00ol0003oTfnWoi=_Y`05oi=_Y`03o`000?oB/;Oo
d[2g00;od[2g0_l00004on_2Z`04o`000?o@gfkod=m^o`0000Ko_MW^0ol00006ojVmj0;o00001Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0Mooooo`?o00000_nbbn`00ol0003oZlW`oj_9l005oj_9l0?o00001onI
fOdYo`000003odFmlOl0003oH<Gl00GoH<Gl00?o0000ogS;oomhbol00_mhbol5o`0000?oPm3o00?o
0000oh?@oon3d?l00_n3d?l00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Pooooo`05o`000?ooooooooooooooool00000
2oooool01?oMgMgoEEEEooooool00005ooooo`03o`000?oooooooooo03Cooooo0ol000000ooooooo
0000o`000004o`000003ooooool0003o000000?ooooo0ol00006ooooo`03o`000?oooooooooo00Co
00000_ooool3o`0000Sooooo0_l000000ooooooo0000o`000005ooooo`;o0000BOooool001Cooooo
00?o0000ooooooooool03_ooool01?l0003oZKgXojVmj?nY_NP4o`0000OoZKgX00?o0000ojVmj?l0
00000_l00002ojVmj003o`000?nQ^n_oXK_[00?oXK_[00?o0000oiZ<`onJS<<00_nJS<<00ol0003o
TgJ_oi=f[`03oi=f[`03o`000?ll?j_o?3n[00?o00001ooA/k`00ol0003oS8O9ohb7b@02ohb7b@Co
00000omOCjL01_l0003oh<>kon33^ol0003oiKb/o`0000Ko[ZWC00Co0000okBI^ol0003oLf6_0_l0
00001?m9T>ko0000obITeolVI=L2o`000003okgmhOl0003o000000?o_k7<00Co0000oeaWaOmLIlGo
G6O50_l00005ojR?^P03o`000?nCKjOoTfnW00CoTfnW00?o0000om:`]ooB/;L00_oB/;L00ol0003o
jl:[on_2Z`02on_2Z`06o`000?o@gfkod=m^o`000?nihG_o00000_nmfNh3o`0000;oZKgX00?o0000
ojVmj?nY_NP01?nY_NP2o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06_ooool2o`0000Ko//_/00?o0000
oj_9l?n[bO000_n[bO02o`0000?oY]gj0_l00002oiWIo@?o00000omlhOHAo`0000?oA/?Y7ol00005
ofO8o@05o`000?n3d?ooPm3oo`000?n3d?l01Ol0000Booooo`03o`000?oooooo000000Gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Pooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00omgMgOoc<c<o`000005ooooo`03o`000?oooooooooo03Kooooo0_l00003ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooool000000ol00006ooooo`06o`000?oooooo0000o`00
0?oooooo00000_ooool2o`0000Kooooo1?l00002ooooo`;o0000DOooool001?ooooo00?o0000oooo
ooooool04?ooool3o`0000CoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000KoZKgX00?o0000oj6k
jonQ^n/00_nQ^n/00ol0003oVXc3oiZ<``02oiZ<``03o`000?nCMZooTgJ_00?oTgJ_00Go0000oc`o
Zoll?j_o?3n[o`000009om6c_003o`000?n<QlWo000000?o00001?mOCjL01Ol0003oh<>kon33^ooP
`k_o000000;oiKb/00?o0000ojjYdon^ZM<00_n^ZM<01?l0003o]9VkokBI^ol00003og=Q[`;o0000
00Go9VCGo`000?nmoN7o_OgQo`000005oknac003o`000?mLIlGoG6O500;oG6O50_l00004ojR?^P03
o`000?nCKjOoTfnW00?oTfnW0ol00003om:`]`;o00000oo[`Z/00ol0003od=m^o`000002okWQN`?o
00001_nY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003ooooo00;ooooo00?oEEEEofIVI_l0
00001Oooool4o`0002Cooooo00?o0000ooooooooool04?ooool2o`0001Sooooo0_l00009ok;;k004
o`000?n[bO3o0000o`0000KoY]gj1?l00002ogcQmPko00000omAbnX6o`0000?oBlG/1ol000001?m3
_?3o0000obZQk_lZXNh6o`000003o`n?hol0003o000000Go000000?o@;Wao`000?mWb?d00omWb?d7
o`0000CoO<ko00?o0000ooooooooool04_ooool01ol0003oooooooooooooooooEEEEofIVI_l00000
1Oooool4o`0001oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Go
oooo00?o0000ooooooooool06?ooool7o`0000gooooo0ol00006ooooo`Go00000oooool4o`000003
ooooool0003ooooo00Co00001?ooool4o`0000cooooo1ol0001Cooooo`004oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?nY_NSoZKgX00CoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003o`00
0?nY_NSoZKgX00CoZKgX00Go0000oj6kjonQ^n_oXK_[o`000004oiZ<``03o`000?nCMZooTgJ_00Co
TgJ_00Co0000oc`oZoll?j_o00002?oA/k`3o`0000?oS8O900?o0000oem?YomOCjL00_mOCjL01?l0
003oh<>kon33^ol00003onFl[005o`000?n^ZM?o[ZWCojjYdol000001?ndVK/00ol0003oLf6_og=Q
[`02og=Q[`Co00001ono/L`00ol0003oG6O5oeaWa@03oeaWa@05o`000?nXSk[oZ8njojR?^_l00000
1?nCKjL4o`0000?od[2g00?o0000on_2Zol000000_o[`Z/01Ol0003od=m^o`000?nihG_o000000;o
bN_]00?o0000ojVmj?nY_NP01?nY_NP3o`0000GoZKgX00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo01?ooooo0_l00002okS<j@03o`000?nbbnco//_/00Ko
//_/0ol00005ojKMnP;o00001?nCj_L4o`0000;oNnKL1Ol00002of7GhQ?o000000?o;[CMo`000?lf
[?401ol000000olZXNko0000oa2<i006o`0000;o9:KV1_l00004oeS0n`04o`000?mlc_ooO<koo`00
00CoO<ko00?o0000ooooooooool04_ooool00ol0003oooooooooo`0[ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`04ooooo`03o`000?oooooooooo01_ooooo2?l0000<
ooooo`Go00001?ooool3o`0000?ooooo0_l000000ooooooo0000ooooo`02ooooo`?o00001?ooool4
o`0000_ooooo1Ol0000;ooooo`;o0000BOooool001?ooooo00?o0000ooooooooool04_ooool00ol0
003oZKgXojVmj003ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj003ojVmj0?o00000_nQ^n/00ol0
003oVXc3oiZ<``02oiZ<``03o`000?nCMZooTgJ_00?oTgJ_00Go0000oc`oZoll?j_o?3n[o`000004
om6c_0?o000000?og^?Ho`000?l000000on<QlT01Ol0003oGdnWoem?YomOCjOo000000?oh<>k00?o
0000onFl[?oU_:`00_oU_:`00ol0003o[ZWCo`000005okBI^`03o`000?mcHJooLf6_00GoLf6_00?o
0000oknac?no/L`01Ono/L`00ol0003oG6O5oeaWa@03oeaWa@?o000000?oZ8njo`000?nCKjL00_nC
KjL6o`000003om:`]ol0003ojl:[00;ojl:[0_l000001?o@gfko0000o`000?l00004olW[k@03o`00
0?nY_NSoZKgX00?o000000?oZKgXo`000?nY_NP01OnY_NP2o`00037ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0@ooooo`;o00001Onhc>T00ol0003o//_/ok;;k002ok;;k0?o0000
0onag_H2o`000003ojKMn_l0003o000000?oTn[g1Ol00002og_Vg0Wo00000_mQdo43o`0000?oPmSo
1?l00005od[5k003o`000?lLW^Go000000So000000?o:9g^o`000?l000001?l000000ol@S>Co0000
o`000005o`000003obBVi_l0003oF<3k00GoF<3k00Go0000ogc>oomlc_oo0000ogc>o`05o`0001;o
oooo0_l00015ooooo`03o`000?oooooooooo01cooooo2?l0000<ooooo`co00000_ooool5o`0000Co
oooo0_l00003ooooo`Go00000_ooool00ol0003oooooooooo`06ooooo`Oo000000?oooooo`000?l0
00000_ooool3o`0004_ooooo000Cooooo`03o`000?oooooooooo01?ooooo00?o0000ojVmj?l00000
0_l00002ojVmj003o`000?nY_NSoZKgX00GoZKgX00?o0000ojVmj?l000000_l00003ojVmj0?o0000
1?nJS<<00ol0003oTgJ_oi=f[`03oi=f[`03o`000?ll?j_o?3n[00;o?3n[1?l000000ooA/kco0000
omkSf002omkSf0;o00000_n<QlT01Ol0003oGdnWoem?YomOCjOo000000?oh<>k00?o0000onFl[?oU
_:`00ooU_:`00ol0003o]9VkokBI^`04okBI^`03o`000?mcHJooLf6_00CoLf6_00?o0000olFIZOl0
00001_no/L`01?l0003oG6O5oeaWaOmLIlD2o`000003oj6>`?l0003oVgfa00;o00000_nCKjL2o`00
00;o@V;<0ol000000ooB/;Oo0000on_2Z`02on_2Z`Co00001_o9jnd3o`0000GoZKgX00?o0000ojVm
j?nY_NP00onY_NP2o`00033ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0=oooo
o`;o00002?nhc>T01?l0003o//_/o`000?l00007ok7NmPoo00000_n[n>P2o`0000?o^?;c1?l00002
oh?Ho`?o00000onVgo/;o`000004oabNiOl0003o<jCboc>TlPKo000000?o:9g^o`000?l9SMh05Ol0
0005ogK;o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`0eooooo`Oo000000?oooooo`000?l000000ol000000ooooooo0000ooooo`03ooooo`04o`000?oo
ooooooooooooo`Oo00002?ooool9o`000004ooooool0003o0000o`0004kooooo000Cooooo`03o`00
0?oooooooooo01Cooooo00?o0000ojVmj?nY_NP01?nY_NP00ol0003oZKgXojVmj004ojVmj0;o0000
1onY_NP2o`0000CoVXc300?o0000oi=f[onCMZl00onCMZl00ol0003o?3n[oc`oZ`03o`0000?odK>l
00?o0000omkSf?oNhmP00_oNhmP01Ol0003o2bVZo`000?n<QlWo000000;oGdnW00Go0000on33^ooP
`k_oh<>ko`000006onFl[003o`000?ndVK_o]9Vk00Co]9Vk00?o0000og=Q[omcHJl00omcHJl01Ol0
003oaIVYolFIZOo5VJWo000000Ko_k7<0ol00003oj6>`003o`000?nKOK7oVgfa00?o000000?oVgfa
o`000?m2H/`00_m2H/`2o`000003om:`]ol0003ojl:[00;ojl:[1Ol00002olW[k@?o000000?oZKgX
o`000?nY_NP01OnY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003o000002oooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0:ooooo`;o00000_nkc>L00ol0003o^<cYokS<j@05
okS<j@?o00001_nag_H2o`000003ojW_n?l0003o000000Go00000_nLm><3o`0000;oZoSX0_l00003
okSbl`;o00001?o2hnl3o`0000?oY]ok0_l00002okRjf`03o`000?n4XNKoQ:7V00?oQ:7V00?o0000
oeNDk_mGU>h01_l000001?lcY?;o0000od2Zm_m0Z_H@o`0000KoC;Si0_l00003ogK;o`Co00004_oo
ool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo02Oooooo3_l00004ooooo`[o00001ooo
ool00ol0003oooooo`000006o`000003ooooool0003o000000Kooooo1ol000000ooooooo0000o`00
0003o`0004gooooo000Cooooo`03o`000?oooooooooo01Gooooo00?o0000ojVmj?nY_NP01?nY_NP0
0ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY_NP4o`0000;oVXc300?o0000
oi=f[onCMZl01?nCMZl2o`0000?o?3n[00?o0000om6c_?l000001OoNhmP01Ol0003o2bVZo`/YZ_l0
003oS8O900;o00001?oP`k/00ol0003oiKb/onFl[003onFl[003o`000?oikJ3o000000Ko]9Vk00?o
0000og=Q[omcHJl00_mcHJl01Ol0003oaIVYolFIZOo5VJWo000000?o_k7<1?l00006oj6>`004o`00
0?nKOK7oVgfao`0000?oVgfa00?o0000od9Rc?m2H/`00_m2H/`00ol0003ojl:[on_2Z`02on_2Z`Oo
00001OnY_NP00ol0003oZKgXojVmj003ojVmj0?o00001OnY_NP00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool02?ooool00ol0003o^lcWok_<i`03ok_<i`03
o`000?nhc>Wo^<cY00;o^<cY0_l00003okWMlP?o000000?o/Mkfo`000?l000000ol000001?nYkoSo
0000o`000?nGl^L2o`000003oicdhol0003o000000Oo000000?o^?;co`000?l000001Oo2hnl01ol0
003oa=7TolCAi?o4dNCo0000ojKOnol000001Onh^]/00ol0003oQ:7VohBQiP03ohBQiP03o`000?mG
U>koEiC^00;oEiC^00?o0000oeNQmOmGXOD01ol000000om0Z_Ko0000od2TmP03od2TmP03o`000?lX
S^go000000oo00001?mbaOl00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04;ooooo00?o
0000ooooooooool0:oooool;o`0000;ooooo0ol00002ooooo`Co00001Oooool9o`000003ooooool0
003ooooo00;o00001oooool2o`000003ooooool0003o000000Co00004?ooool3o`0003oooooo000B
ooooo`03o`000?oooooooooo01Oooooo00?o0000ojVmj?nY_NP00onY_NP3o`0000KoZKgX00?o0000
ojVmj?nY_NP00ol000001?nX_NSo0000o`000?m6Fl@3o`0000?oTgJ_3?l00005omkSf003o`000?l;
:J[o2bVZ00?o00000ooP`k/00ol0003oiKb/onFl[004onFl[003o`000?oikJ3o000000Ko]9Vk00Go
0000og=Q[omcHJooLf6_o`000005olFIZ@?o00000onRV/d00ol0003oXHk0oj6>`004oj6>`003o`00
0?nKOK7oVgfa00CoVgfa00?o0000od9Rc?m2H/`00_m2H/`00ol0003ojl:[on_2Z`02on_2Z`Co0000
00?oe_7To`000?nY_NP01OnY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP0
1?nY_NP00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
1Oooool2o`0000Oo^lcW00Co0000okS<jOl0003o00001onigO84o`0000;oZNoh0_l00002oiObi`Go
00000oo0mnh00ol0003od>_Xom3[j002om3[j0;o00001?o2hnl2o`0000Coa=7T0_l00007okRjf`04
o`000?n4XNKoQ:7VohBQiPKo000000?oEiC^o`000?mGXOD00omGXOD01?l0003oD:;foe2Rm_m@X_H6
o`000003od2Tm_l0003o:8k]00;o:8k]3?l00006og;5o`03o`000?oooooooooo00kooooo0_l00013
ooooo`03o`000?oooooooooo01oooooo0_l00003ooooo`So00000oooool2o`0000Cooooo3Ol00004
ooooo`Ko000000Goooooo`000?oooooo0000ooooo`03o`0000Kooooo1?l000000ooooooo0000o`00
0002o`0000Wooooo0_l00002ooooo`Co000000?oooooo`000?l000000ol0000looooo`004_ooool0
0ol0003oooooooooo`0Hooooo`03o`000?nY_NSo000000;o00000onY_NP00ol0003oZKgXojVmj003
ojVmj0?o00001OnX_NP2o`0000;oAU_41_l000000onUXM;o0000ohnGe`07ohnGe`?o00000_oNhmP0
1Ol0003o2bVZo`/YZ_l;:J[o000000Coh<>k00?o0000onFl[?oU_:`00ooU_:`01?l0003onNfPooW]
X?l00006okBI^`05o`000?mcHJooLf6_og=Q[ol000001Oo5VJT00ol0003oXY[=oj:Jc@04oj:Jc@03
o`000?nQS/3oXHk000?oXHk000?o0000oi]m/OnKOK401OnKOK42o`0000?o@V;<00?o0000on_2Zoo[
`Z/01Ol00002omKai003o`000?nY_NSoZKgX00?oZKgX0ol00006ojVmj004o`000?nY_NSoZKgXojVm
j0Co0000;Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00;ooooo0ol00008ok_<
i`?o00001OnigO84o`0000?o^>ge2_l00003ol3gkP03o`000?o@jnSod>_X00;od>_X00?o0000omCP
h?oDh>000_l000000oo2hnoo0000olCAi004olCAi003o`000?o:`mCo000000Oo^;[K1?l00002oiFF
dP04o`000?mjU>3oNYCPogZDh0Ko000000?oEj7eo`000?m@X_H01?m@X_H00ol0003oA9_dodBKm005
o`0000;o:8k]1Ol00003ocFTl`[o00004Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooo
oooo01[ooooo2?l00007ooooo`Co00001_ooool7o`0000Cooooo0_l00007ooooo`Go000000?ooooo
o`000?l000001?l00006ooooo`Oo00002oooool:o`00047ooooo000Booooo`03o`000?oooooooooo
01Wooooo0_l00006ojVmj003o`000?nY_NSo000000;o00000_nY_NP00ol0003oZ;gXojRmj003ojRm
j0Oo00001OnUXM800ol0003oSiOGohnGe`04ohnGe`03o`000?nGjZgoUnZ]00Co00000ol;:JX01Ol0
003oh<>kon33^ooP`k_o000000KoiKb/00Go0000ooW]X?oikJ3onNfPo`000005okBI^`04o`000?mc
HJooLf6_o`0000GoaIVY00?o0000oogSU_l000001OnRV/d00ol0003oXHk0oj6>`003oj6>`003o`00
0?nKOK7oVgfa00GoVgfa00?o0000ofMle?l000000_l000001_m2H/co0000on_2Zol0003oel33o`00
00;oe_7T00?o0000omKai?l000000_nY_NP3o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY_NP4o`00
00?oZKgX00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Jooooo`04o`000?oooooooooo
o`0000?o_LcV00?o0000ok_<ionkc>L01?nkc>L01?l0003o_M_^okgKk_nmfnh2o`000004okWMl_l0
003o0000o`0000Co^>ge0_l00002ok3hk@;o000000CoZoWQo`000?nXn>?o00001?o0mnh00ol0003o
d>_Xom3[j002om3[j003o`000?oDh>3oe>3P00;oe>3P0ol00003olCAi0;o00000oo:`m@00ol0003o
^;[KokRjf`02okRjf`;o000000?o[Z7:o`000?nEU]801?nEU]800ol0003oNYCPogZDh002ogZDh004
o`000?mgVNKoMiWVogNIiPOo000000?oD:;fo`000?m4Vo@00om4Vo@00ol0003oAI?ao`000003o`00
00;o483U0_l00004ocFTl`;o00001_ma__d00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
043ooooo00?o0000ooooooooool07oooool4o`00013ooooo1Ol0000?ooooo`Go000000?oooooo`00
0?l000001_l00005ooooo`?o00003Oooool4o`0000Oooooo0_l0000oooooo`004_ooool00ol0003o
ooooooooo`0Kooooo`03o`000?nY_NSoZKgX00?oZKgX0_l00006ojVmj004o`000?nX_NSoZ;gXojRm
j0?o00000om6Fl@00ol0003oYJ7BojFQdP05ojFQdP03o`000?n?UmOoSiOG00;oSiOG00?o0000oiOZ
[OnGjZd00_nGjZd01?l0003o07?Io`000?l00003o`/YZP04o`000?oP`k_oh<>ko`0000GoiKb/00?o
0000ooW]X?oikJ000_oikJ000ol0003o]9VkokBI^`03okBI^`03o`000?mcHJoo000000KoaIVY00?o
0000oogSU_l000001OnRV/d00ol0003oXHk0oj6>`004oj6>`003o`000?nKOK7oVgfa00?oVgfa0ol0
0003ofMle0;o000000?ojl:[o`000?l000001?oFlN@4o`0000KoZKgX00?o0000ojVmj?nY_NP00ol0
00000onY_NSo0000ojVmj005ojVmj0;o0000:oooool00ol0003oooooooooo`0Kooooo`;o00001Onm
c>H01?l0003o^lcWok_<ionkc>L2o`0000Go_M_^0ol00005okS]m@06o`000?n`n>go/?S]ok3hkOl0
003oZoWQ1_l00002ol3gkP03o`000?o@jnSod>_X00;od>_X00?o0000omCPh?oDh>000_oDh>001ol0
003oe=SLomCHg?oDf=co0000olCAi?l000001_o:`m@01?l0003o^;[Ko`000?l00004ojjQbP03o`00
0?nEU];oUIKB00?oUIKB00?o0000ogZDh?mjU>000_mjU>000ol0003oMiWVogNIiP02ogNIiP03o`00
0?m_UnOoKiOW00;oKiOW1_l000000om4VoCo0000odFCl@02odFCl@?o00000_l@P>D7o`0000KoLKkm
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo02cooooo
2_l00009ooooo`Co00001?ooool4o`000003ooooool0003o000000Ko00001?ooool:o`0000_ooooo
00?o0000ooooooooool00oooool;o`0003Sooooo000Booooo`03o`000?oooooooooo01cooooo00?o
0000ojVmj?l000000_l000000onY_NSo0000ojVmj006ojVmj0Oo00000om6Fl@00ol0003oYJ7BojFQ
dP04ojFQdP04o`000?n?UmOoSiOGohnGe`go000000Co2bVZo`000?oP`k_o00001OoU_:`00ol0003o
nNfPooW]X002ooW]X003o`000?ndVK_o]9Vk00Co]9Vk0_l00006olFIZ@04o`000?omhiKooN>Fo`00
00GoXY[=00?o0000oj6>`?nQS/000onQS/000ol0003oVgfaoi]m/@02oi]m/@Co00001?mWO=@2o`00
0004omO0`ol0003oe_7TomKai0?o00000_nec^d00ol0003oZKgXojVmj004ojVmj0?o00001OnY_NP0
0ol0003oZKgXojVmj003ojVmj0;o0000:_ooool00ol0003oooooooooo`0Kooooo`03o`000?nmc>Ko
_LcV00Ko_LcV00?o0000ok_<iol000001?nmfnh3o`0000?o_nWb0_l000000onhkOGo0000o`000002
ok3hk@Ko00001?oAm^L4o`0000;od>_X00?o0000omCPh?oDh>000_oDh>000ol0003oe=SLomCHg002
omCHg0;o00001oo:`m@2o`0000Ko[Z7:00?o0000oiFFd_nEU]800onEU]800ol0003oNYCPogZDh003
ogZDh003o`000?mgVNKoMiWV00;oMiWV00?o0000ofnGiom_UnL00om_UnL01?l0003oH8[Tof2:i?mP
R^@5o`0000;oAI?a1Ol00003od2Hl`[o00004?ooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo02;ooooo0ol00003ooooo`Oo00003oooool3o`000003ooooool0003o000000;o000000?o
ooooo`000?l000001?l0000=ooooo`Co00005oooool4o`0003gooooo000Booooo`03o`000?oooooo
oooo01gooooo00?o0000ojVmj?nY_NP00onY_NP01?l0003oZKgXojVmj?nY_NP5o`0000CoYkgY00?o
0000odIKa?m6Fl@00_m6Fl@00ol0003oYJ7BojFQdP04ojFQdP03o`000?n?UmOo000000Co[Io90_l0
00001?lnAk?o0000o`0MYol00003of62g0?o00001_oU_:`00ol0003onNfPooW]X002ooW]X0So0000
1_o5VJT01Ol0003ooN>FoogSU_omhiKo000000GoXY[=00?o0000oj6>`?nQS/000onQS/001?l0003o
Vgfaoi]m/OnKOK46o`0000?oIgcD00?o0000omO0`ooG`<<00ol00003okG>k@04o`000?nec^go]Lk]
o`0000;oZKgX0ol000000onY_NSo0000ojVmj005ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgX
o`000?ooool01Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Gooooo`03o`000?oo
oooooooo01Wooooo0ol00008okg<iP?o000000?o_M_^o`000?l000000ol00005okoYlPSo00000_o7
o]l00ol0003odOKWom7fi`02om7fi`03o`000?oChN;odn7R00;odn7R0ol00003omCPh003o`000?oD
f=coe=SL00;oe=SL00?o0000olW4eOl000001_o:`m@00ol0003o_Jc9o`000007ojjQbP03o`000?nE
U];oUIKB00;oUIKB1Ol000000omjU>3o0000ogNIiP04ogNIiP03o`000?m_UnOoKiOW00?oKiOW00?o
0000of2:i?mPR^@00_mPR^@00ol0003oF8SUoeR8i@04o`0000;o:GcV0_l00003od2Hl`03o`000?m0
V??o000000GoM;?i00?o0000ooooooooool03_ooool00ol0003oooooooooo`04ooooo`Go00000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^02gooooo00?o0000ooooooooool07Oooool9o`0000;ooooo
1_l0000>ooooo`;o000000?oooooo`000?l000000ol00003ooooo`_o00002oooool00ol0003ooooo
ooooo`1Fooooo`004_ooool00ol0003oooooooooo`0Nooooo`03o`000?nY_NSoZKgX00?oZKgX1_l0
0002ojVmj005o`000?nW_NWoYkgYojNmjOl000001?m6Fl@00ol0003oYJ7BojFQdP04ojFQdP;o0000
1?n]WlT02?l0003ok?JXoncfZ?l0003o?TNco`000?l07JOo00001?mQP]`00ol0003oiKb/onFl[003
onFl[004o`000?oikJ3onNfPooW]X0;o000000?oW7V[o`000?n;H9X01?n;H9X00ol0003oaIVYolFI
Z@04olFIZ@05o`000?omhiKooN>FoogSU_l000001OnRV/d00ol0003oXHk0oj6>`003oj6>`004o`00
0?nKOK7oVgfaoi]m/@Ko00000_mWO=@01Ol0003oel33omO0`ol0003oo=fP00;o00001?nec^d00ol0
003o]Lk]o`000002o`0000GoZKgX00?o0000ojVmj?nY_NP00onY_NP3o`0000GoZKgX00?o0000oooo
ooooool00oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Gooooo`03o`000?oooooooooo01Kooooo0ol00003okc;iP03o`000?nmc>Ko_LcV00;o_LcV0ol0
00000onof>co0000o`000002o`000003okgKk_l0003o_nWb00Go_nWb00Go0000ol3ekoo0mNoo`?G_
o`000002ol?liP04o`000?o7o]ooaokOo`0000CodOKW00?o0000om?Qh_oChN800_oChN801ol0003o
e]OIomKGfOoFemWo0000omCPh?l000001?oDf=`01Ol0003obLCEolW4eOo9a=Go000000?ob/?D0_l0
0003okf/b@03o`000?n^XL[o[Z7:00Co[Z7:00?o0000oiFFd_l000000_l000000onSV/_o0000ohV@
d`02ohV@d`co000000?oKiOWo`000?mPR^@01?mPR^@00ol0003oF8SUoeR8i@02oeR8i@?o00000_lY
O>H5o`000003od2Hlol0003oM;?i00CoM;?i00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`03ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg02go
oooo00?o0000ooooooooool06oooool5o`000004ooooool0003o0000o`0000?ooooo0ol00002oooo
o`03o`000?oooooooooo01Sooooo0ol000000ooooooo0000o`000002ooooo`?o00004?ooool7o`00
00?ooooo1ol00013ooooo`004Oooool00ol0003oooooooooo`0Pooooo`03o`000?nY_NSo000000Go
00001_nY_NP01?l0003oYkgYojNmjOnW_NT4o`000004odIKa?l0003oYJ7BojFQdP?o00001_n]WlT0
1?l0003ok?JXoncfZ?l00002oci7/`03o`000?l07JOo000000CoHH;L00?o0000onFl[?oU_:`00_oU
_:`01?l0003onNfPo`000?l00003oiaiZ`03o`000?n;H9[oRf2J00?oRf2J00?o0000olFIZOo5VJT0
1?o5VJT00ol0003ooN>FoogSUP02oogSUPWo00000_nQS/000ol0003oVgfaoi]m/@02o`0000;oJg[@
0ol000000omWO=Co0000omO0``02omO0``;o00000_l001400ol0003o]Lk]okG>k@03o`000003ojVm
j?l0003oZKgX00GoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj005ojVmj0;o0000
1Oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41005oooool00ol0003o
ooooooooo`0Dooooo`;o00001onlbnH01Ol0003o_LcVo`000?l0003o_mS/00?o00000onof>`3o`00
00Co_nWb0_l00002ol3ek`;o00000_o3o>H01?l0003oaokOolOngol00004om7fi`03o`000?oChN;o
dn7R00;odn7R00?o0000omKGfOoFemT00ooFemT2o`0000?oe=SL00?o0000olW4eOo9a=D00oo9a=D0
0ol0003ob/?Do`000005okf/b@03o`000?n^XL[o[Z7:00Co[Z7:0_l00005oj>Jb`03o`000?n9T=?o
RI3C00;oRI3C00?o0000oh>=eOn3SMD00on3SMD01?l0003oN8OFogR7e_mhQmH5o`0000?oH8[T00?o
0000oeR8iOmHR>D00_mHR>D00ol0003oC7WMo`000002o`0000CoCY7^1ol000000omd/oWo0000oooo
o`0>ooooo`;o00001Oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@4100
;Oooool00ol0003oooooooooo`0Rooooo`Wo00006_ooool4o`000003ooooool0003o000000;o0000
0oooool6o`0000Wooooo1Ol00005ooooo`_o0000@Oooool0017ooooo00?o0000ooooooooool07ooo
ool5o`0000CoZKgX00?o0000ojVmj?nY_NP00onY_NP6o`0000;oJ83H1?l00002odmce`03o`000?n]
WlWo[Io900?o[Io900Go0000oncfZ?o/mZSok?JXo`000003oci7/`?o00001?mQP]`00ol0003oiKb/
onFl[003o`0000GoW7V[00?o0000oh]PV_n;H9X01?n;H9X00ol0003oaIVYolFIZ@02olFIZ@03o`00
0?omhiKooN>F00?ooN>F00?o0000ohJ>don6S]<00on6S]<00ol0003oIH?LofF3g008o`0000CoJg[@
00?o0000omO0`ooG`<<00_oG`<<2o`0000;o000A0ol00002ojVmj004o`000?nY_NSoZKgXo`0000Go
ZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?ooool01Oooool00onHV9So
8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000005oooool00ol0003oooooooooo`0Boooo
o`?o00002?nlbnH5o`0000Go_mS/00Co0000ol;Tl?o2i?3o`^C`0_l000000onojO;o0000ol3ek`02
ol3ek`04o`000?o3o>Ko`ocVol?liPKo00000_oAm^L00ol0003odn7Rom?QhP02om?QhP03o`000?oF
emWoe]OI00?oe]OI00Ko0000omSEeOoHeMGo0000omCHg?l00006olW4e@;o00001onm[<T01?l0003o
[Z7:ojjQb_n^XLX2o`000003ojnRbol0003oXi[;00CoXi[;00?o0000ohV@don9T=<00on9T=<00ol0
003oPhgEoh>=e@03oh>=e@03o`000?mhQmKoN8OF00;oN8OF00?o0000ofj7fom^Qm/01?l00005oeR8
i@03o`000?m<NMgoC7WM00;o00000om>TNh00ol0003oCY7^o`000004ogZYl@?o00003oooool00ol0
003oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000]
ooooo`03o`000?oooooooooo02Gooooo1?l00007ooooo`;o00004Oooool4o`0000;ooooo1Ol00004
ooooo`Oo00005_ooool00ol0003oooooooooo`14ooooo`004Oooool00ol0003oooooooooo`0Loooo
o`?o00000oooool00ol0003oZKgXojVmj004ojVmj003o`000?nY_NSo000000;o00000_nY_NP00ol0
003oGIocoefOl`05o`000003ofR0f?l0003oCg?G00;oCg?G00?o0000ojfObOn]WlT00_n]WlT00ol0
003ok?JXoncfZ002oncfZ005o`000?lnAk?o?TNco`000?mPF[@01Ol000000omQP]co0000onFl[003
o`0000GoW7V[00?o0000oh]PV_n;H9X01?n;H9X00ol0003oaIVYolFIZ@02olFIZ@03o`000?omhiKo
oN>F00;ooN>F00?o0000om2a^_l000001On6S]<00ol0003oIH?LofF3g002ofF3g0Go00001?m[N]00
1_l0003oel33omO0`ooG`<?o0000oocMX0?o000000?o]<g/o`000?nY_NP00onY_NP00ol0003oZKgX
o`000002ojVmj0?o000000?oZKgXo`000?nY_NP01OnY_NP3o`0000GoZKgX00?o0000ooooooooool0
1?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000005oooool00ol0003o
ooooooooo`0Aooooo`05o`000?njb^Oo^/[Wok[:iol000001_nlbnH3o`000003okkEjol0003o0000
00?o_mS/0_l00005ol;Tl0_o000000?oc?gSo`000?oGlN<00_oGlN<4o`0000;odn7R00?o0000omKG
fOoFemT00ooFemT00ol0003of=GEomSEe@02omSEe@03o`000?o9a=GobLCE00CobLCE00?o0000ol2_
b_l000001onm[<T01?l0003o[Z7:o`000?l00004ojnRb`03o`000?nSV/_oXi[;00?oXi[;00?o0000
ohV@don9T=<00_n9T=<00ol0003oPhgEoh>=e@03oh>=e@03o`000?mhQmKoN8OF00?oN8OF00?o0000
ofj7fom^Qm/00_m^Qm/3o`0000?oF8SU00?o0000odaigOm<NMd00_m<NMd3o`000004odjAk_l0003o
CY7^o`0000GoNZWa00?o0000ooooooooool03_ooool00ol0003oooooooooo`04ooooo`03ogMgMomV
IVKooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo02Gooooo
1_l00002ooooo`?o00004Oooool4o`0000?ooooo1_l00006ooooo`?o00001?ooool2o`0005Wooooo
000Aooooo`03o`000?oooooooooo01[ooooo0_l00007ooooo`03o`000?nY_NSoZKgX00?oZKgX0_l0
0006ojVmj004o`000?mMWo?oGIoco`0000?oOVjg1?l000000om?LmOo0000ojfOb@02ojfOb@Co0000
0_o/mZP01ol0003o?TNcoci7/olnAk?o0000of1J]?l000000omCX_H6o`0000GoW7V[00?o0000oh]P
V_n;H9X01?n;H9X00ol0003oaIVYolFIZ@02olFIZ@05o`000?omhiKooN>FoogSU_l000000_o@/KX0
0ol0003oQXkCohJ>d`03ohJ>d`03o`000?mUPmcoIH?L00;oIH?L00?o0000oc9JbolbF//00ol00004
of]jd003o`000?oG`<?oel3300?o00001?ndcN`01?l0003oZKgXojVmj?nY_NP5o`0000GoZKgX00?o
0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj005ojVmj0;o00001_ooool01Ol0003ooooooooo
oooooooo410@00?ooooo00?o410@ooooooooool05Oooool00ol0003oooooooooo`0?ooooo`;o0000
1Onjb^L00ol0003o_<_Vokc;iP03o`0000Ko_]G[00?o0000okoHk?l000001_o2i?001Ol0003oaNo_
olG_koo5knoo000000?ob?SZ00Go0000olcmhoo<oN?oc?gSo`000003omOah`03o`000?oFg=coe]cL
00;oe]cL0_l00005omKGf@03o`000?oHeMGof=GE00?of=GE00?o0000olW4eOo9a=D00oo9a=D01Ol0
003o`:o:ol2_b_o0[l[o000000Ko_Jc90_l00006ojnRb`03o`000?nSV/_oXi[;00?oXi[;00?o0000
ohV@don9T=<00on9T=<00ol0003oPhgEoh>=e@03oh>=e@03o`000?mhQmKoN8OF00;oN8OF00?o0000
ofj7fom^Qm/00om^Qm/01_l0003oG7_Io`000?l0003oF8SUo`0000CoC7WM00?o0000of69homQRN<0
1?l00006ogZYl@03o`000?oooooooooo00cooooo0ol00006ooooo`05o`000?ooooooooooooooool@
41000oooool00ol@413oooooooooo`0[ooooo`03o`000?oooooooooo01gooooo3?l00002ooooo`;o
000000?oooooo`000?ooool04Oooool3o`0000;ooooo2?l00002ooooo`03o`000?oooooooooo00Co
oooo1_l0000@ooooo`;o0000Aoooool0017ooooo00?o0000ooooooooool05oooool3o`0000[ooooo
00?o0000ojVmj?l000000_l00002ojVmj003o`000?nY_NSoZKgX00CoZKgX00?o0000oefOlol00000
1OmnK[L00ol0003oB6O?o`000002o`000006ojfObOl0003o0000odQWcol0003o8fCH0ol00003oci7
/`04o`000?mPF[CoH5Zdo`0000?oDj;f00?o0000onC1/ol000000ol00005oiaiZ`03o`000?n;H9[o
Rf2J00?oRf2J00Go0000olFIZOo5VJWoaIVYo`000003oogSUP03o`000?o@/K[od;6j00;od;6j00?o
0000ohJ>don6S]<00on6S]<00ol0003oIH?LofF3g002o`0000?o<U[;0_l00005of]jd004o`000?oG
`<?o0000o`0000Go]<g/1?l000001?nY_NSo0000ojVmj?l00006ojVmj0?o00001OnY_NP00ol0003o
ZKgXojVmj003ojVmj0;o00000_ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Fooooo`03o`000?oooooooooo00oooooo00?o0000ok[:ionjb^L01Onjb^L4
o`0000So_]G[0ol00004ol;Tl0;o00000oo5knl01Ol0003ob?SZolShj_o8n>[o000000?oc?gS00Go
0000omOahooGlN?oeo7So`000005omKLg003o`000?oFemWo000000?oe]OI00?o0000omSEeOoHeMD0
0ooHeMD00ol0003oe<S>o`000003olW4e@03o`000?o0[l[o`:o:00;o`:o:00?o0000okf/bOnm[<T0
0onm[<T00ol0003o]ZG7o`000007ojnRb`03o`000?nSV/_oXi[;00;oXi[;1Ol000000on9T=?o0000
oh>=e@04oh>=e@03o`000?mhQmKoN8OF00?oN8OF00?o0000ofj7fom^Qm/00om^Qm/00ol0003oG7_I
oeakf@03o`0000CoC7WM00Co0000of69homQRN?oHHWS1ol000000omjZO7o0000ooooo`0:ooooo`?o
00000_ooool02?l0003oooooooooool0003o^[ZjoooooonHV9So410@0oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg02gooooo00?o0000ooooooooool06oooool4o`00027ooooo00?o0000ooooool00000
0_ooool6o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000002ooooo`Wo0000
2oooool6o`0004Gooooo000Aooooo`03o`000?oooooooooo01Cooooo0ol0000>ooooo`03o`000?nY
_NSoZKgX00CoZKgX00Co0000ojVmj?nY_NSoZKgX1?l000000omMWo?o0000ogi^]`04ogi^]`0:o`00
0?m8IlooB6O?o`000?n]WlWo0000odQWcol0003oeojoo`0000;o8fCH0_l00002oci7/`06o`000?mP
F[CoH5Zdof1J]?l0003oDj;f0_l000000ooT`K?o0000o`000002o`0000GoW7V[00?o0000oh]PV_n;
H9X01?n;H9X01?l0003oaIVYolFIZOl00003oogSUP03o`000?o@/K[od;6j00;od;6j00?o0000ohJ>
don6S]<00on6S]<00ol0003oIH?Lo`000002on3Pe003o`000?lbF/_o<U[;00;o<U[;1ol000001?ol
gJ3o0000okC=k?ndcN`3o`000003ojVmj?l0003oZKgX00?oZKgX00?o0000ojVmj?l000000_nY_NP3
o`000003ojVmj?l0003oZKgX00GoZKgX00?o0000ojVmj?nY_NP00ol000002Ooooooo0000oooooooo
ooooV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h05_ooool00ol0
003oooooooooo`0=ooooo`?o00001Onjb^L2o`000004ok[:iol0003o0000o`0000Ko_]G[0_l00003
ol7OkP;o000000?o`^C`o`000?o5knl00oo5knl01Ol0003ob?SZolShj_o8n>[o000000?oc?gS00Go
0000omOahooGlN?oeo7So`000005omKLg007o`000?oFemWoe]OIomKGfOl0003oe]OIo`000005omSE
e@07o`000?oDb<koe<S>omC8c_l0003obLCEo`000006ol2_bP03o`000?nm[<Wo_Jc900;o00000onf
YLL00ol0003o[j;;ojnRb`04ojnRb`03o`000?nSV/_oXi[;00;o000000?oYYK4o`000?n=QlP00_n=
QlP<o`000003ogR7e_l0003oKXOK00CoKXOK00?o0000oeakfOmLNmT00_mLNmT3o`0000?oC7WM00Co
0000of69homQRN?oHHWS0_l00004oh2Pj0?o00001oooool3o`0000Gooooo00So0000oooooooooooo
V9RHoa0@4?l0003o8B4Qolc<c0?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0]ooooo`03o`000?oo
oooooooo01Wooooo0_l00002ooooo`03o`000?oooooooooo00Kooooo0_l00004ooooo`;o00004Ooo
ool00ol0003oooooooooo`02ooooo`?o000000Coooooo`000?l0003o00000_ooool00ol0003ooooo
ooooo`08o`000003ooooool0003ooooo00Co000000?oooooo`000?l000000_l00009ooooo`;o0000
0_ooool4o`00047ooooo000@ooooo`03o`000?oooooooooo01;ooooo0ol0000Booooo`03o`000?nY
_NSoZKgX00?oZKgX1?l00003ojVmj003o`000?mMWo?o000000GoOVjg00Oo0000odQWcom8IlooB6O?
o`000?m8Iloo000000?oeojo00Co0000ob=Tf?lSI=So00000olnAk<01?l0003oH5Zdof1J]?mPF[@2
o`0000?oi<6c0ol00005oiaiZ`03o`000?n;H9[oRf2J00CoRf2J00Co0000olFIZOo5VJWo00000_om
hiH00ol0003od;6jom2a^P04om2a^POo00000ooPh=@00ol0003o<U[;oc9Jb`02oc9Jb`03o`000?n=
S/ooSHk?00;oSHk?00?o0000oocMX?l000000ol00005ojVmj003o`000?nY_NSoZKgX00;oZKgX1?l0
0005ojVmj004o`000?nY_NSoZKgXojVmj0Go00001?ooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo00_ooooo0_l00003okK9j@Go000000?o^/[Wo`000?l000000onkdn`00ol0003o_]G[
okkEj`02okkEj`03o`000?o1gnko`Mo^00Co`Mo^1?l00002olG_k`05o`000?o8n>[ob?SZolShj_l0
00000oo<oN<01Ol0003oeo7SomOahooGlN?o000000Goe]cL00?o0000omKGfOoFemT00_oFemT3o`00
00Cof=GE00?o0000omC8c_oDb<h00ooDb<h00ol0003o`:o:ol2_bP05ol2_bP03o`000?nm[<Wo0000
00Go]ZG700?o0000ojnRbon_X//01?n_X//00ol0003oXi[;o`000004ojJFa003o`000?n=QlSoSHO8
00;oSHO800?o0000ohJ7cOn6Qld00on6Qld01?l0003oPhWAoh>9dOn3RM45o`0000?oKXOK00Go0000
oeakfOmLNmWoG7_Io`000002oeijePCo00001?mQRN<2o`0000GoP:3X00Co0000oooooooooooooooo
1?l00008ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool08oooool3o`0000?ooooo
0ol00008ooooo`Go00001oooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`000003oooo
ool0003o000000;ooooo0ol000000ooooooo0000ooooo`03o`0000;ooooo1_l000000ooooooo0000
o`000003o`0000Cooooo1_l00015ooooo`004?ooool00ol0003oooooooooo`0?ooooo`?o00005_oo
ool00ol0003oZKgXo`000002o`0000?oZKgX00?o0000ojVmj?nY_NP00_nY_NP2o`0000KoOVjg00Go
0000odQWcom8IlooB6O?o`000004omOn_`04o`000?lSI=So8fCHo`0000?o?TNc00?o0000of1J]?mP
F[@00_mPF[@01?l0003oi<6conC1/ooT`K<3o`0000GoW7V[00?o0000oh]PV_n;H9X01?n;H9X00ol0
003oaIVYo`000002oogSUP03o`000?o@/K[od;6j00God;6j00Co0000olj^^_o>[[[o00001_oPh=@3
o`0000?o<U[;00Oo0000ohf>con=S/ooSHk?o`000?olgJ3o000000;oZKgX00?o0000ojVmj?nY_NP0
1?nY_NP00ol0003oZKgXo`000003o`000003ojVmj?l0003oZKgX00CoZKgX1?l0000:ooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool02Oooool2o`0000Co]/WY1?l000000onjb^Oo0000
o`000006ok_Ck004o`000?nneN_o0000o`0000Ko`Mo^00?o0000olGYkoo5jNl00_o5jNl?o`0000Co
e]cL00?o0000omKGfOoFemT00_oFemT01?l0003odL_Com7;dooAbm<2o`000003omSEeOl0003oe<S>
00Coe<S>0_l00007ol2_bP;o00001onfYLL00ol0003o[j;;ojnRb`03ojnRb`;o00001OnVU/@00ol0
003oSHO8ohf7b003ohf7b003o`000?n6QlgoQXO=00?oQXO=00?o0000oh>9dOn3RM400_n3RM400ol0
003oLX7Cog:1d`04o`0000CoG7_I00?o0000oeije_mNN]H00_mNN]H4o`0000;oHHWS0_l00005oh2P
j0?o00003?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo023ooooo0ol000001?oo
oooo0000ooooooooool2o`000003ooooool0003ooooo00Sooooo0ol00005ooooo`;o000000Kooooo
o`000?l0003o0000ooooool00002ooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o
00000oooool4o`0000?ooooo1_l000000ooooooo0000o`000002o`0000Gooooo00?o0000ooooool0
00001?l00011ooooo`004?ooool00ol0003oooooooooo`0<ooooo`?o00006_ooool2o`0000KoZKgX
00Oo0000ojVmj?nY_NSoZKgXo`000?mMWo?o000000GoOVjg00?o0000odQWcom8Ill02?l00002ob=T
f004o`000?lnAk?o?TNco`0000?oH5Zd00?o0000onC1/ooT`K<00ooT`K<2o`0000GoW7V[00?o0000
oh]PV_n;H9X01?n;H9X00ol0003oaIVYo`000002o`0000Ood;6j00Co0000olj^^_o>[[[ocZjj0_l0
0002on3Pe0?o000000Co[<;Zo`000?lCCl[o00000_lbF//01?l0003oSHk?ohf>col00002oocMX005
o`000?nY_NSoZKgXojVmj?l000000onY_NP4o`0000?oZKgX00Go0000ojVmj?nY_NSo0000ojVmj003
o`0000kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`07ooooo`?o00000_nfbNT3
o`0000?o]/WY0ol00007ok_Ck0?o00001Oo1gnh2o`0000CoaNW_00Go0000ol_`k?o;l>cobo3/o`00
0003om;eiP03o`000?oKjmkofn_N00;ofn_N00?o0000omWIeooIfML00_l000000ooFg=co0000omKG
f@03omKGf@03o`000?oAbm?odL_C00CodL_C00?o0000omC8c_oDb<h00ooDb<h01?l0003obkW8ol^i
b?l00005ol2_bP03o`000?njYlKo000000Oo]ZG700?o0000ojnRbon_X//00ol000000onXUlCo0000
ojJFa004ojJFa003o`000?n=QlSoSHO800?oSHO800?o0000ohJ7cOn6Qld00on6Qld00ol0003oPhWA
oh>9d@03oh>9d@03o`000?mbPM?oLX7C00;oLX7C0ol00002oeakf@03o`000?mNN]KoGW[F00?oGW[F
00?o0000og2;gOm`Rmd01?l00006oh2Pj003o`000?oooooooooo00cooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool2o`0000Gooooo0_l000000ooooooo0000ooooo`04ooooo`?o000000Goooooo`000?l0003o
ooooo`000003ooooo`?o000000Coooooo`000?oooooo00000oooool00ol0003oooooo`000002o`00
00Cooooo0ol00003ooooo`Ko000000?oooooo`000?l000001?l00009ooooo`;o0000?oooool0013o
oooo00?o0000ooooooooool02Oooool3o`0001oooooo00?o0000ojVmj?nY_NP00onY_NP4o`000003
ojVmj?l0003o000000GoOVjg00Ko0000odQWcol0003o0000ofg2o_l00004oh:Rj003o`000?lSI=So
8fCH00;o00000_lnAk<01?l0003oH5Zdof1J]?l00005onC1/`?o00001?nLNJ/00ol0003oRf2Joh]P
VP05oh]PVPCo00001_o@/KX01?l0003ocZjjolj^^_o>[[X5o`0000Go[<;Z00[o0000oa=?b_l0003o
0000oc9Jbol0003oSHk?o`000?olgJ3o00001?nY_NP4o`0000?oZKgX00?o0000ojVmj?nY_NP00_nY
_NP01?l0003oZKgXo`000?l0000Aooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
1Oooool2o`0000;o/<S/0ol00003okK9j@?o00000ongdNd00ol0003o^m?/ok_Ck002ok_Ck0;o0000
0onnfnh3o`000003ol7Ok_l0003oaNW_00?oaNW_0_l00003ol_`k005o`000?oBmNKod_GVom;ei_l0
00001?oKjmh00ol0003ofMWGomWIe`03omWIe`;o00000ooFemT00ol0003odL_Com7;d`04om7;d`03
o`000?oCa<co000000?oe<S>00?o0000ol^ib?o;^LP00_o;^LP01Ol0003o`:o:ol2_b_o0[l[o0000
00?o^ZO600?o0000okJUaonfYLL01?nfYLL3o`0000GoZ9O400?o0000ojJFa?nVU/@00onVU/@00ol0
003oSHO8ohf7b003ohf7b003o`000?n6QlgoQXO=00?oQXO=00?o0000oh>9dOn3RM400_n3RM400ol0
003oLX7Cog:1d`03og:1d`06o`000?mUM<ko0000o`000?mLNmWo00001OmNN]H00ol0003oL8_Mog2;
g@02og2;g@Wo00003Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02Sooooo0ol0
000>ooooo`Co000000Coooooo`000?l0003o00001Oooool00ol0003oooooooooo`02o`000003oooo
ool0003ooooo00;ooooo00?o0000ooooool000001?l00003ooooo`04o`000?oooooo0000o`0000Co
oooo0ol00003ooooo`Ko0000B?ooool0013ooooo00?o0000ooooooooool01_ooool3o`0002?ooooo
00?o0000ojVmj?l000000_l000000onY_NSo0000ojVmj002ojVmj0;o00001OmnK[L5o`000003ofg2
o_l0003oPZ;X00?oPZ;X00Wo0000ob=Tf?l0003o02b`o`000?lnAk?o0000of1J]?l000001_oT`K<3
o`0000CoW7V[00?o0000oh]PV_n;H9X01On;H9X3o`000003o`006Ol0003od;6j00?od;6j00?o0000
olj^^_o>[[X00_o>[[X3o`000003omOjgol0003o[<;Z00Go[<;Z00?o0000oa=?b_lCClX00_l00000
1On=S/oo0000oocMX?l0003oZKgX00?o000000?oZKgXo`000?nY_NP01OnY_NP00ol0003oZKgXojVm
j003o`0001?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`03ooooo`;o000000Co
/<S/o`000?l0003o00000_n`b>`01?l0003o]/WYo`000?l00007okOAk@04o`000?nkdnco0000o`00
00Oo_]_^1?l00002olGYk`03o`000?o;l>cobo3/00;obo3/00Go0000om;ei_oBmNKod_GVo`000004
om_[gP03o`000?oIfMOofMWG00?ofMWG00Ko0000om[Fe?oJe]Co0000omKGfOl00006om7;d`07o`00
0?oCa<codlC<om?4c?l0003oe<S>o`000006ol^ib003o`000?o0[l[o000000Co^ZO600?o0000okJU
aonfYLL00onfYLL00ol0003o/ic1o`000006ojRGa003o`000?nVU/CoYYK400?oYYK400?o0000ohf7
b?n=QlP00on=QlP00ol0003oQXO=ohJ7c@03ohJ7c@03o`000?n3RM7oPhWA00?oPhWA00?o0000og:1
dombPM<00ombPM<00ol0003oIGC>ofEdcP02o`0000GoGW[F00?o0000og2;gOm`Rmd00om`Rmd00ol0
003oQYgQohJMh@04ohJMh@03o`000?oooooooooo00_ooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`0Nooooo`Co00001?ooool2o`000003ooooool0003ooooo00?ooooo0_l00007oooo
o`?o000000?oooooo`000?ooool01?l00004ooooo`03o`000?oooooooooo00?o00001Oooool4o`00
0004ooooool0003o0000o`0000Kooooo0ol00004ooooo`;o00000_ooool00ol0003oooooooooo`03
o`0004Oooooo000@ooooo`03o`000?oooooooooo00?ooooo0ol0000Wooooo`03o`000?nY_NSoZKgX
00?oZKgX00Go0000ojVmj?nY_NSoZKgXo`000003ogi^]`;o00001OnL^Nd3o`0000?oPZ;X0_l00000
0olSI=So0000o`0//002o`000003of1J]?l0003oi<6c00Koi<6c0_l00004oiaiZ`03o`000?n;H9[o
Rf2J00GoRf2J1Ol00004om2a^P04o`000?o>[[[ocZjjolj^^P?o00000ooGn]l00ol0003o[<;Zojc2
jP03ojc2jP04o`000?lCCl[o4do:oa=?bP;o00000_olgJ02o`0000GoZKgX00?o0000ojVmj?nY_NP0
0onY_NP3o`0000?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo00;ooooo1Ol00005ok38k0?o00002?ngdNd3o`0000Ko_]_^0_l00004ol;Sk`Co0000
0_o;l>`01Ol0003od_GVom;ei_oBmNKo000000Cofn_N00?o0000omWIeooIfML00ooIfML00ol0003o
f]KDom[Fe002om[Fe0;o00001OoAbm<00ol0003odlC<om?4c003om?4c003o`000?o;^LSobkW800Go
bkW80_l00006okZWaP03o`000?nfYLOo]ZG700;o00000oncW<400ol0003oZ9O4ojRGa004ojRGa003
o`000?nVU/CoYYK400;oYYK400Co0000ohf7b?n=QlSoSHO81ol000000on6Qlgo0000oh>9d@04oh>9
d@03o`000?mbPM?oLX7C00?oLX7C00?o0000ofEdc_mUM<h00_mUM<h3o`0000?oGW[F00?o0000og2;
gOm`Rmd00om`Rmd00ol0003oQYgQohJMh@04ohJMh@03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool08?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o
0000oa0@4?o<c<`01?ooool00ol0003oooooooooo`0Mooooo`Co00001?ooool00ol0003ooooooooo
o`04ooooo`?o00001oooool00ol0003oooooo`000004ooooo`?o00002Oooool00ol0003ooooooooo
o`04ooooo`Co00000_ooool3o`0000Gooooo1?l0000=ooooo`03o`000?oooooooooo04Cooooo000?
ooooo`04o`000?ooooooooooooooo`?o0000:oooool00ol0003oZKgXojVmj003ojVmj003o`000?nY
_NSo000000Co000000?oZKgXo`000?nL^Nd01?nL^Nd4o`0000;oPZ;X00Co0000ob/n/ol0003o0000
0_l0;;03o`0000Koi<6c0ol00004oiaiZ`03o`000?n;H9[oRf2J00GoRf2J0_l000001?o]n;;o0000
o`000?l00002om2a^P03o`000?o>[[[ocZjj00;ocZjj0_l00004omOjg`ko000000?oZKgXo`000?nY
_NP01?nY_NP00ol0003oZKgXojVmj003o`0000Kooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooo000000Co000000?oZLK_o`000?n`b>`00on`b>`2o`0000?o
/Lo_0_l00004okOAk@;o00000onif?000ol0003o_]_^okkKkP02okkKkP03o`000?o2hnoo`^?_00?o
`^?_00?o0000olSXkOo8j>d00_o8j>d8o`0000;ofn_N00?o0000omWIeooIfML00ooIfML00ol0003o
f]KDom[Fe002om[Fe004o`000?oFcM7oe/gAo`0000?odL_C00?o0000om?4c?oCa<`01?oCa<`00ol0
003obkW8ol^ib004ol^ib003o`000?o2[lOo000000Ko^ZO600?o0000okJUaol000001OncW<400ol0
003oZ9O4ojRGa004ojRGa003o`000?nVU/CoYYK400;oYYK41?l00003oiB;aP04o`000?n=R<WoSHS9
ohf8b@[o00001?mbPM<01Ol0003oIGC>ofEdc_mUM<ko000000;oKGoD1?l00005og2;g@;o00001_n6
WN400ol0003oooooooooo`09ooooo`03o`000?oooooooooo023ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Cooooo00?o0000oooooooo
ool06oooool2o`0000;ooooo00?o0000ooooooooool02?ooool2o`000003ooooool0003ooooo00Ko
oooo00?o0000ooooooooool01Oooool2o`0000Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooo`000003ooooo`03o`000?oooooooooo00?ooooo1_l0001Cooooo`003oooool4o`0002oooooo
00Co0000ojVmj?nY_NSoZKgX0ol00002ojVmj003o`000?nY_NSoZKgX00;oZKgX00?o0000oibikOl0
00000_l00002ojVmj003o`000?n8/_7o000000;oPZ;X00?o0000ob/n/ol000000ol0;;000ol0003o
i<6conC1/`04onC1/`04o`000?o4a]_oa<KKo`0000CoW7V[00?o0000oh]PV_n;H9X01?n;H9X3o`00
0006ongh/_l0003okN?5o`000?o@/K[o00001?o>[[X2o`0000;oeo[O0ol00002ok76jP04o`000?nY
_NSoZKgXojVmj0Co00001_nY_NP01?l0003oZKgXojVmj?nY_NP4o`0000[ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Qooooo`Co00001OnYa^l01?l0003o/<S/o`000?l00007ok7?
k`04o`000?ngdNgo0000o`0000Ko^MS`00Co0000okkKk_l0003o00001?o2hnl2o`0000Cob>S]00?o
0000om3Yioo@jNL00_o@jNL01?l0003of>?NomSSg_oHhmh3o`0000CofMWG00?o0000om[Fe?oJe]@0
0_oJe]@00ol0003oe/gAomK=d@02omK=d@03o`000?oAbm?o000000KodlC<00?o0000om6maol00000
1?o;^LP01Ol0003o`Zo7ol:_aoo2[lOo000000Go^ZO60_l00007ok>L`@03o`000?nXUlCoZ9O400?o
Z9O400?o0000ojJFa?l000000_l000000onUU/Go0000oiB;aP05oiB;aP03o`000?n=R<WoSHS900;o
SHS900?o0000ohN6c?n7Q/`00on7Q/`00ol0003oKgS<o`000002o`000003og:1dol0003oIGC>00?o
IGC>00?o0000ofeoe?m]Om@00_m]Om@6o`000003og2;gOl0003oQYgQ00GoQYgQ00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Pooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Sooooo0_l00006ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02?ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00?ooooo0ol00002
ooooo`03o`000?oooooooooo00;ooooo1?l000000ooooooo0000o`000002o`0004Gooooo000?oooo
o`;o0000<_ooool3o`0000?oZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000KoZKgX00Go0000ohRb
lOl0003oPZ;Xo`000002ob/n/`;o000000?o02b`o`000?oT`K<01?oT`K<01?l0003oa<KKolC6foo4
a]/2o`0000CoW7V[00?o0000oh]PV_n;H9X00on;H9X2o`000004ongh/_l0003okN?5ongSa@;o0000
1Oo>[[X4o`0000Co/LKZ1Ol00003ojVmj003o`000?nY_NSoZKgX00CoZKgX1?l0000?ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool08?ooool4o`0000GoZLK_0ol00008ok7?k`?o0000
1onif?05o`0000;o`^?_00?o0000olSXkOo8j>d00oo8j>d00ol0003od>WWom3Yi`02om3Yi`03o`00
0?oHhmkof>?N00;of>?N00?o0000om[JeooJf]L00_l000000ooIfMOo0000om[Fe003om[Fe003o`00
0?oFcM7oe/gA00Coe/gA00?o0000om?4c?oCa<`01?oCa<`01Ol0003odKg7om6maooA_LOo000000;o
bkW800?o0000ol:_aoo2[lL00_o2[lL00ol0003o^ZO6okZWaP02okZWaP03o`000?neWKoo000000Oo
/ic100?o0000ojRGa?nXUl@00onXUl@2o`0000GoYIK500?o0000oiB;a_nDRlH00onDRlH00ol0003o
SHS9ohf8b@03ohf8b@03o`000?n7Q/coQhK<00?oQhK<00Co0000ofmhc?m_N<coKgS<0_l00004ofEd
cP03o`000?m]OmCoKGoD00?oKGoD00?o0000og^>f_mkS]X00_mkS]X:o`0000[ooooo00?o0000oooo
ooooool08?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q
8@04ooooo`;o0000:oooool2o`0000Kooooo0ol0000Pooooo`;o00000_ooool2o`0000Cooooo0ol0
0002ooooo`03o`000?oooooooooo00?ooooo0ol00003ooooo`?o0000@oooool0017ooooo00?o0000
ooooooooool0<?ooool00ol0003oZKgXojVmj003ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP0
0ol0003oZKgXojVmj003ojVmj0Go00000ol[?[<4o`0000?oi<6c00?o0000ojR4[_l000000_o4a]/2
o`0000CoW7V[00?o0000oh]PV_n;H9X00on;H9X00ol0003okORbo`000004ongSa@03o`000?o>[[[o
cZjj00?ocZjj00Co0000oiZSfonJXm_o00000onaa^X2o`000003ojVmj?l0003oZKgX00GoZKgX00?o
0000ojVmj?nY_NP00ol0000Cooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08_oo
ool01?l0003oooooo`000?nYa^l3o`0000?oZLgc0_l00004ok7?k`;o00000onbeO800ol0003o^MS`
okWHl002okWHl0;o00001Onlg_43o`0000Cob>S]00?o0000om3Yioo@jNL00_o@jNL00ol0003of>?N
omSSgP02omSSgP03o`000?oJf]Oof][G00?of][G0_l00003om[Fe003o`000?oFcM7oe/gA00Coe/gA
0_l00005om?4c003o`000?oA_LOodKg700;odKg700?o0000ol^ib?l000001_o2[lL01?l0003o^ZO6
okZWa_l00003okFM_`03o`000?ncW<7o/ic100Co/ic100?o0000ojRGa?nXUl@00ol000000onWUL?o
0000ojFFa@04ojFFa@03o`000?nDRlKoU8_600?oU8_600?o0000ohf8bOn=R<T00on=R<T00ol0003o
QhK<ohN6c003ohN6c003o`000?m_N<coKgS<00?oKgS<0ol00002ofEdcP03o`000?m]OmCoKGoD00?o
KGoD00?o0000og^>f_mkS]X00omkS]X00ol0003oS9cNohbLgP04ohbLgP03o`000?oooooooooo00So
oooo00?o0000ooooooooool08?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEE
EOl0003o410@olc<c004ooooo`03o`000?oooooooooo02Oooooo1Ol00005ooooo`03o`000?oooooo
000000[ooooo00?o0000ooooooooool05Oooool2o`0000;ooooo0_l00006ooooo`03o`000?oooooo
oooo00Gooooo1_l00003ooooo`?o0000@?ooool001;ooooo00?o0000ooooooooool0<?ooool01?l0
003oZKgXojVmj?nY_NP4o`0000KoZKgX00?o0000ojVmj?l000000_l000001?nY_NSo0000og>Ylomc
ZO<2o`0000?o:cjc00Ko0000o`Q]gOl0003o0000onC1/ol00003ojR4[P04o`000?o4a]_oa<KKo`00
00CoW7V[00?o0000oh]PV_n;H9X00_n;H9X5o`0000;okN?50ol00003olj^^P03o`000?nJXm_oVZ?K
00;oVZ?K00?o0000ok76j_l000001?nY_NP00ol0003oZKgXojVmj003ojVmj0?o00005oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo02?ooooo00Co0000ooooool0003o00001onYcO<0
1?l0003o/Lo_o`000?l00006ok;ElP04o`000?nif?3o0000o`0000Ko_=ka00Co0000ol7Rkoo1h^oo
`N;_0_l000000oo8j>go0000om3Yi`03om3Yi`03o`000?oHhmkof>?N00;of>?N00?o0000om[JeooJ
f]L00ooJf]L01_l0003of=OFomSGe_l0003of]KDo`0000Koe/gA00Co0000oljnboo>_/_o00000ooC
a<`00ol0003odKg7om6ma`04om6ma`03o`000?o2[lOo`Zo700Go`Zo700?o0000okZWa_l000001?ne
WKl00ol0003o/ic1ok>L`@04ok>L`@?o00001OnWUL<00ol0003oYIK5ojFFa@03ojFFa@03o`000?nD
RlKoU8_600?oU8_600?o0000ohf8bOn=R<T00on=R<T00ol0003oQhK<ohN6c002ohN6c003o`000?m_
N<coKgS<00?oKgS<00?o0000og1kc_m`Nlh00ol00005ofeoe003o`000?mkS][oNhkJ00CoNhkJ00?o
0000ohbLg_n<W=h01?n<W=h00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01oooooo00Go
410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Kooooo00?o0000ooooooooool0
9Oooool2o`000004ooooool0003o0000o`0000Gooooo00?o0000ooooooooool00oooool3o`0000Co
oooo0_l0000@ooooo`03o`000?oooooooooo00Cooooo0ol00002ooooo`;o00001_ooool00ol0003o
ooooooooo`06ooooo`?o000000?oooooo`000?ooool01?ooool00ol0003oooooooooo`0mooooo`00
4oooool00ol0003oooooooooo`0`ooooo`?o00001?nY_NP00ol0003oZKgXojVmj003ojVmj0;o0000
1OnY_NP00ol0003oLjWcog>Yl`06o`0000;oZ8B^00?o0000ojR4[_nXQ:h00onXQ:h3o`0000CoW7V[
00?o0000oh]PV_n;H9X00_n;H9X00ol0003oZYO2o`000002o`1^`P;o00000_nWWlh01Ol0003ocZjj
olj^^_o>[[[o000000CoVZ?K0_l00006ojVmj003o`000?nY_NSo000000;o00006oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo02Cooooo00Co0000oooooooooooo00001_nYcO<3o`00
00Oo/]Gb0ol00005okcNl@;o00001Oo1h^l4o`0000;od>WW00?o0000omSSg_oHhmh00_oHhmh00ol0
003of][Gom[Je`03om[Je`03o`000?oHemKof=OF00;of=OF0_l00005omK=d@03o`000?o>_/_oc[k;
00;oc[k;00?o0000om?4c?l000001_oA_LL2o`0000Oo`Zo70_l00006okFM_`03o`000?ncW<7o/ic1
00;o/ic100?o0000ok6K`?l000001_nWUL<00ol0003oYIK5ojFFa@03ojFFa@03o`000?nDRlKoU8_6
00?oU8_600?o0000ohf8bOn=R<T00on=R<T00ol0003oQhK<ohN6c003ohN6c003o`000?m_N<coKgS<
00?oKgS<00?o0000og1kc_m`Nlh00_m`Nlh3o`0000?oKGoD00?o0000og^>f_mkS]X01?mkS]X00ol0
003oS9cNohbLgP03ohbLgP03o`000?oooooooooo00Sooooo00?o0000ooooooooool07oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P01_ooool00ol0003oooooooooo`0T
ooooo`06o`000?ooooooooooo`000?oooooo00002_ooool5o`0000?ooooo0_l0000=ooooo`03o`00
0?oooooooooo00;o00001Oooool01?l0003oooooo`000?l00002ooooo`03o`000?oooooo000000Oo
oooo0ol00005ooooo`Co0000AOooool001Cooooo0_l0000booooo`03o`000?nY_NSoZKgX00?oZKgX
00?o0000ojVmj?l000000_l00002ojVmj003o`000?nY_NSoZKgX00?oZKgX00?o0000og>Ylol00000
1?n6WN800ol0003oZ8B^ojR4[P06ojR4[PCo00000onLNJ/00ol0003oRf2Joh]PVP02oh]PVPCo0000
00?o06k2o`000?nWWlh00onWWlh01?l0003ocZjjo`000?l00002oiZSf`;o00000_nY_NP01?l0003o
ZKgXojVmj?nY_NP4o`0001oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Uoooo
o`;o000000Coooooo`000?nYcO?oZLgc0ol00003ojSCmP03o`000?nbeO;o/]Gb00;o/]Gb0_l00003
okCJm0?o000000?o_=kao`000?o1h^l01Oo1h^l00ol0003oan?/olOSk002olOSk0Co00000_oHhmh0
0ol0003of][Gom[Je`03om[Je`03o`000?oHemKof=OF00?of=OF00?o0000omK@dol000000ooFcM40
0ol0003oc[k;oljnb`04oljnb`03o`000?oA_LOodKg700CodKg700Co0000olVa`_o9/L;o00001Oo2
[lL00ol0003o]Ybmo`000006okFM_`03o`000?ncW<7o/ic100;o00000onaVl000ol0003oYiG3ojNE
``04ojNE``03o`000?nUU/GoYIK500;oYIK500?o0000oiB;a_nDRlH00onDRlH00ol0003oSHS9ohf8
b@03ohf8b@03o`000?n7Q/coQhK<00?oQhK<00?o0000ofmhc?m_N<`00om_N<`00ol0003oL7_>og1k
cP02og1kcP03o`000?mhQ]CoN8KD00Co00001_mkS]X2o`0000CoS9cN00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Oooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4
o`000?l@4104ooooo`03o`000?oooooooooo02Gooooo0_l00005ooooo`;o00001oooool3o`0000Co
oooo0_l0000=ooooo`03o`000?oooooooooo00?o00000_ooool4o`000003ooooool0003o000000Co
oooo00?o0000ooooooooool01Oooool3o`0000Sooooo0_l00013ooooo`005_ooool00ol0003ooooo
ooooo`0`ooooo`04o`000?nY_NSoZKgXojVmj0?o00001_nY_NP01?l0003oZKgXojVmj?nY_NP3o`00
0003ojVmj?l0003oQYgR00;oQYgR00?o0000ojR4[_nXQ:h01OnXQ:h01Ol0003oTkK_oi>fkonC]^oo
000000?oW7V[00Oo0000oh]PV_n;H9[oRf2Jo`000?nZUl;o000000;o/=[f00?o0000o`1^`_l00000
0onWWlh01_l0003ocZjjo`000?l0003oVZ?Ko`0000CoZKgX1?l0000Sooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool09oooool01?l0003oooooo`000?l00007ojSCmP04o`000?nbeO;o
0000o`0000Oo]=[d0ol00004ol7Rk`;o00001?o7hn`00ol0003ocN3VolgPiP02olgPiP?o00001?oJ
f]L00ol0003of=OFomSGeP03omSGeP07o`000?oFd=?oe]3ComK@dol0003oe/gAo`000006oljnb`;o
00001OoA_LL00ol0003obK72olVa`P02olVa`P03o`000?o2[lOo`Zo700;o00000onfW;d00ol0003o
]IfookFM_`03okFM_`03o`000?ncW<7o000000Go/I_000?o0000ojNE`onWUL<01?nWUL<00ol0003o
YIK5ojFFa@02ojFFaA7o000000?oQhK<o`000?m_N<`01Om_N<`00ol0003oL7_>og1kcP02og1kcP03
o`000?mhQ]CoN8KD00;oN8KD3ol00009ooooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`03ooooo`?o00001_ooool2o`000004ooooool0003o0000o`00
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`;o000000?oooooo`00
0?l000000_l00002ooooo`Go00000_ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0
003oooooo`000004o`0000Gooooo00?o0000ooooooooool0@?ooool001Oooooo00?o0000oooooooo
ool0<?ooool3o`0000?oZKgX00?o0000ojVmj?nY_NP00onY_NP4o`0000?oZKgX00?o0000ojVmj?l0
00000on6WN800ol0003oZ8B^ojR4[P04ojR4[P;o00000onC]^l01?l0003oW7V[oiaiZol00003oh]P
VP?o00000_n`f_H3o`0000CoYio>00?o0000ojNOc_l000000_l000001?nY_NSo0000o`000?l0000X
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`02
o`0000GoZ=?f0ol00006okCJm0;o00000ongg_<2o`000003ol7Rkol0003oan?/00?oan?/0_l00004
olgPiP04o`000?o@f^3od=[Pom3Jh0;o000000?of][Go`000?oHemH01?oHemH00ol0003oe]3ComK@
d`02omK@d`;o00001_o>_//01?l0003oc[[6oljja_l00003om6ma`03o`000?o9/L;obK7200?obK72
00?o0000ol:_aol000001OnfW;d00ol0003o]IfookFM_`03okFM_`;o00001onaVl000ol0003oYiG3
ojNE``03ojNE``03o`000?nUU/Go000000;o000000?oXY?5o`000?nGRlD01?nGRlD00ol0003oTHO5
oi67a@03oi67a@04o`000?n8P/KoR8;6ohR2aPGo00000om_N<`00ol0003oL7_>og1kcP02og1kcP03
o`000?mhQ]CoN8KD00?oN8KD00?o0000oh>BfOn3T]T01?n3T]T2o`0000CoT9gL00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Wooooo00?o0000ooooool0
00001_ooool4o`000003ooooool0003o000000;ooooo00?o0000ooooooooool00_ooool2o`0000Oo
oooo0_l000000ooooooo0000o`000004o`000006ooooool0003o0000o`000?oooooo00002Oooool7
o`0000?ooooo1?l00017ooooo`006?ooool00ol0003oooooooooo`0`ooooo`03o`000?nY_NSoZKgX
00?oZKgX00?o0000ojVmj?l000000_l00002ojVmj003o`000?nY_NSoZKgX00?oZKgX0_l00003ohJM
hP03o`000?nXQ:koZ8B^00?oZ8B^00?o0000ojVmj?l000001?l00002oiaiZ`06o`000?n;H9[oRf2J
oh]PV_l0003oRk;`0ol00002ojVmj0;o00000onWWlh6o`0002cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Xooooo`06o`000?ooooooooooooooool0003oZ=?f0ol00003ojWHn0?o
000000?o]=[do`000?l000001_ngg_<4o`0000;oan?/00?o0000olgPi_o=h>H00oo=h>H00ol0003o
d=[Pom3Jh003om3Jh0?o00001?oHemH00ol0003oe]3ComK@d`02omK@d`03o`000?o<_<_o000000Go
c[k;00?o0000oljja_o>^/H00_o>^/H00ol0003odKg7o`000007olVa`P03o`000?nfW;go]Ybm00Go
]Ybm00Oo0000okFM_oneWKoo]Ifoo`000?ngWl3o000000Oo/I_000?o0000ojNE`onWUL<00onWUL<2
o`0000GoXY?500?o0000oiN;aOnGRlD00onGRlD00ol0003oTHO5oi67a@03oi67a@03o`000?n8P/Ko
R8;600;oR8;600?o0000ogQiaomhNLL01?l00005og1kcP03o`000?mhQ]CoN8KD00?oN8KD00?o0000
oh>BfOn3T]T01?n3T]T2o`0000CoT9gL00?o0000ooooooooool01_ooool00ol0003oooooooooo`0h
ooooo`03o`000?oooooooooo02Oooooo0_l000000ooooooo0000o`000002ooooo`;o000000?ooooo
o`000?l000000_l000000ooooooo0000o`000007ooooo`;o00001_ooool01?l0003oooooo`000?l0
0002ooooo`03o`000?oooooo000000;o000000Koooooo`000?l0003o0000ooooool0000:ooooo`Oo
00001?ooool01?l0003oooooo`000?l00015ooooo`006Oooool2o`00037ooooo00Co0000ojVmj?nY
_NSoZKgX0ol00006ojVmj004o`000?nY_NSoZKgXojVmj0Co00000_n6WN800ol0003oZ8B^ojR4[P03
ojR4[P;o00000_nY_NP01_l0003oZKgXojVmj?l0003oW7V[o`0000;oRf2J0ol00002ojVmj006o`00
0?nY_NSoZKgXojVmj?l0003oYio>1?l0000aooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0:Oooool2o`0000;ooooo0_l00007ojWHn0?o00001Ongg_<2o`0000Co^mob0ol00004olgP
iP03o`000?o@f^3od=[P00?od=[P00Co0000om3Dg?o@e=cod=CL0_l000000ooHemKo0000omK@d`03
omK@d`05o`000?o<_<_oc;c;olblbol000000oo>_//00ol0003oc[[6oljjaP04oljjaP03o`000?o9
/L;obK7200GobK720_l00007okJL_@04o`000?neWKoo]Ifoo`0000?o]io000?o0000ok6K`?naVl00
1?naVl000ol0003oYiG3ojNE``03o`000003ojVGa?l0003oXY?500CoXY?500?o0000oiN;aOnGRlD0
0onGRlD00ol0003oTHO5oi67a@03oi67a@03o`000?n8P/KoR8;600?oR8;600?o0000ogQiaomhNLL0
0_mhNLL5o`000003og1kc_l0003oN8KD00GoN8KD00?o0000oh>BfOn3T]T00on3T]T00ol0003oT9gL
o`000004oi2Mg003o`000?oooooooooo00Gooooo00?o0000ooooooooool0>?ooool00ol0003ooooo
ooooo`0Vooooo`04o`000?oooooo0000o`0000;ooooo0ol00002ooooo`03o`000?oooooo000000;o
oooo0_l00007ooooo`;o00001_ooool00ol0003oooooo`000003ooooo`;o000000?oooooo`000?l0
00000_ooool2o`0000;ooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo1_l00007ooooo`;o
0000@oooool001_ooooo00?o0000ooooooooool0;oooool3o`0000?oZKgX00?o0000ojVmj?nY_NP0
0onY_NP4o`0000?oZKgX00Co0000ohJMh_n6WN;o00001?nXQ:h00ol0003oZKgXojVmj003ojVmj005
o`000?nY_NSo0000oiaiZol000000_n;H9X00ol0003oZKgXojVmj003ojVmj003o`000?nY_NSo0000
00;o0000=Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02_ooooo00Co0000oooo
oooooooooooo0_l00002ojWHn0?o00000onYfoT2o`000003okONlol0003o000000Co^mob0_l00003
ol3MkP;o000000?ocN3Vo`000?o@f^001?o@f^000ol0003od=CLom3Dg003om3Dg0?o00000ooFd=<0
0ol0003oc;c;olblb`03olblb`03o`000?o>_/_o000000Ooc[[600?o0000olVa`_o9/L801?o9/L80
1?l0003o`ZFlol:U_?l00006okJL_@03o`000?neWKoo000000Co]io000?o0000ok6K`?naVl001?na
Vl03o`0000CoZIO400?o0000oj:CaOnRTlD00onRTlD00ol0003oUh_5oiN;a@04oiN;a@03o`000?nA
QlGoTHO500;oTHO500?o0000ohR2a_n8P/H00on8P/H00ol0003oN7W7ogQia`03ogQia`04o`000?mj
P/ooNX;?ogZ2c`Oo000000?oN8KDo`000?n3T]T01?n3T]T00ol0003oT9gLo`000004oi2Mg003o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Wooooo`;o0000
0_ooool00ol0003oooooo`000002ooooo`;o000000Coooooo`000?oooooo00002Oooool00ol0003o
ooooooooo`04ooooo`?o00001?ooool2o`000003ooooool0003o000000?ooooo0_l00002ooooo`?o
00000oooool2o`0000?ooooo1?l00002ooooo`;o00001oooool00ol0003oooooooooo`10ooooo`00
7?ooool00ol0003oooooooooo`0_ooooo`03o`000?nY_NSoZKgX00?oZKgX00?o0000ojVmj?l00000
0_l00002ojVmj003o`000?nY_NSoZKgX00?oZKgX00Co0000ohJMh_n6WN;o00000onXQ:h00ol0003o
ZKgXojVmj003ojVmj0?o000000GoW7V[o`000?n;H9[oRf2Jo`000005ojVmj0;o0000>Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool00_ooool2o`00
00OoZM_i1?l00002ok_OlP;o00001_o0gNh3o`0000Cod=[P00?o0000om3Dg?o@e=`00oo@e=`01ol0
003oclcFolo<e_o?c=Ko0000omK@dol000001oo<_</00ol0003oc[[6oljjaP05oljjaP03o`000?o;
//7o000000CobK7200Go0000ol:U_?o2YKco`ZFlo`000006okJL_@;o00001_ngWl000ol0003o/I_0
ok6K`002ok6K`003o`000?nbVl7o000000KoZIO400?o0000oj:CaOnRTlD00onRTlD00ol0003oUh_5
oiN;a@03oiN;a@03o`000?nAQlGoTHO500?oTHO500?o0000ohR2a_n8P/H00on8P/H00ol0003oN7W7
ogQia`03ogQia`03o`000?mjP/ooNX;?00;oNX;?00?o0000oh6<eOn1S=D00_n1S=D6o`0000;oPi;I
00Co0000oi2Mg?l0003oT9gL1?l00007ooooo`03o`000?oooooooooo03Oooooo00?o0000oooooooo
ool09Oooool2o`0000;ooooo0_l00003ooooo`Oo00002Oooool00ol0003oooooooooo`04ooooo`;o
00001_ooool2o`000004ooooool0003o0000o`0000;ooooo0_l00002ooooo`Co00000oooool3o`00
00;ooooo1Ol00002ooooo`03o`000?oooooooooo04Oooooo000Mooooo`03o`000?oooooooooo02oo
oooo00Co0000ojVmj?nY_NSoZKgX0ol00006ojVmj003o`000?nY_NSo000000;o000000CoZKgXo`00
0?n6WN;o00000onXQ:h2o`000004ojVmj?l0003o0000o`0000;oZKgX0_l000001_nLNJ_o0000o`00
0?nY_NSo0000ojVmj0?o0000??ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool00oooool2o`0000;oZM_i0ol00004oj_Ln0?o00001Oo0gNh2o`0000?o
`mWZ0_l000000oo@f^3o0000om3Dg004om3Dg003o`000?o?c=KoclcF00?oclcF00?o0000olblboo<
_</01Oo<_</00ol0003obkS8o`000005oljjaP05o`000?o;//7obk;1ol^b`Ol000000_o9/L800ol0
003o`ZFlol:U_003ol:U_003o`000?nfW;go]Ybm00;o]Ybm00?o0000okVO__l000001_ngWl000ol0
003o/I_0ok6K`002o`0000?o/Y_100?o0000ojVGa?nYUl@00onYUl@00ol0003oXY?5oj:Ca@03oj:C
a@03o`000?nGRlGoUh_500?oUh_500?o0000oi67aOnAQlD00onAQlD00ol0003oR8;6ohR2aP03ohR2
aP03o`000?mhNLOoN7W700?oN7W700?o0000ogZ2comjP/l00omjP/l00ol0003oPHcEoh6<e@03oh6<
e@04o`000?n9U][oRIKJohVFfPKo00000onDX=`00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo03Oooooo00?o0000ooooooooool09?ooool01Ol0003ooooooooooooooooo000000?ooooo1ol0
000Booooo`;o00001Oooool3o`000004ooooool0003o0000o`0000;ooooo0_l00002ooooo`?o0000
00Coooooo`000?l0003ooooo1?l00002ooooo`Go00000_ooool00ol0003oooooooooo`16ooooo`00
7_ooool2o`00033ooooo0ol00003ojVmj003o`000?nY_NSoZKgX00?oZKgX0_l00004ojVmj003o`00
0?n6WN;o000000;oZ8B^1?l00006ojVmj003o`000?nLNJ_o000000Co0000@?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo02kooooo0_l00005ooooo`;o00001On[g?P2o`0000?o[]_g
0_l000000oo0gNko0000o`000006ol?IjP?o00001?o@e=`00ol0003oclcFolo<eP03olo<eP03o`00
0?o=`Loo000000Goc;c;00Go0000ol^hb?o;^<SobkS8o`000003oljjaP03o`000?o;//7obk;100;o
bk;100?o0000olVa`_l000001_o2YK`00ol0003o]YbmokJL_@02o`0000?o^Inn00?o0000okNO`?ng
Wl000ongWl000ol0003o/I_0o`000005ok:K`@03o`000?nYUlCoZIO400?oZIO400?o0000oj:CaOnR
TlD00onRTlD01?l0003oUh_5oiN;aOnGRlD7o`000003oi67aOl0003oR8;600CoR8;600?o0000ogQi
aomhNLL01?mhNLL00ol0003oNX;?ogZ2c`02ogZ2c`03o`000?n1S=GoPHcE00CoPHcE00?o0000ohVF
f_n9U]X00_n9U]X01Ol0003oU:3LoiBPg?nDX=co000000?oU:3L00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool00oooool2
o`000003ooooool0003o000000Go00003_ooool2o`000003ooooool0003o000000Oooooo1Ol00003
ooooo`?o00000_ooool6o`0000;ooooo0ol00004ooooo`;o0000Boooool0023ooooo00?o0000oooo
ooooool0;_ooool00ol0003oZKgXojVmj003ojVmj003o`000?nY_NSo000000;o00000_nY_NP00ol0
003oZKgXojVmj002ojVmj0;o00000_nXQ:h01Ol0003oZKgXojVmj?nY_NSo000000GoZKgX1?l00013
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`04
ooooo`?o000000?oZmcho`000?n^foL01On^foL3o`0000Go`mWZ0_l00003olCCiP;o000000?od=CL
o`000?o?c=H01?o?c=H01Ol0003ocL7?olg1coo=`Loo000000?oc;c;00?o0000ol^hb?o;^<P00oo;
^<P00ol0003oc[[6o`000006ol^b`@03o`000?o2YKco`ZFl00Go`ZFl00?o0000okJL_Ol000001Oni
Wkh00ol0003o]io0okNO`003okNO`0;o00001onbVl400ol0003oZIO4ojVGa003ojVGa003o`000?nR
TlGoXY?500Ko00000onFRL@01?l0003oT8S6oi28a_n@R<H=o`000003ogQiaol0003oNX;?00CoNX;?
00?o0000oh6<eOn1S=D00on1S=D00ol0003oRIKJohVFfP03ohVFfP04o`000?nDX=coU:3Lo`0000Co
U:3L00?o0000ooooooooool00oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Oo
oooo0_l00002ooooo`03o`000?oooooo000000Co000000?oooooo`000?l000002oooool3o`000003
ooooool0003ooooo00Oooooo1Ol00003ooooo`;o00000oooool2o`000003ooooool0003o000000;o
000000Coooooo`000?l0003o00001Oooool3o`0004Wooooo000Qooooo`03o`000?oooooooooo02ko
oooo00Co0000ojVmj?nY_NSoZKgX1?l00005ojVmj003o`000?nY_NSo000000?o000000?oZ8B^o`00
0?nY_NP01?nY_NP00ol0003oZKgXo`000002o`000003ooooool0003o000004Gooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Kooooo0_l00004ojkK
m`;o00000on`f?@2o`000003ol?Ij_l0003o000000Koa=?V0_l00005olo<eP03o`000?o=`LoocL7?
00?ocL7?00?o0000olblbol000001oo;^<P00ol0003obk;1ol^b`@05ol^b`@03o`000?o2YKco`ZFl
00Ko`ZFl00?o0000okVO__niWkh01OniWkh01ol0003o]io0okNO`?ngWl3o0000okJP`_l000001onb
Vl400ol0003oZIO4ojVGa002ojVGa0Co00000onOSl<00ol0003oUXW4oiJ9a004oiJ9a003o`000?n@
R<KoT8S600;oT8S600?o0000ohR5bOn8QLT00on8QLT00ol0003oPhK>oh>6cP02oh>6cPKo000000?o
NX;?o`000?n1S=D01On1S=D00ol0003oRIKJohVFfP03ohVFfP04o`000?nDX=coU:3Lo`0000?oU:3L
00?o0000ooooooooool00oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Kooooo
0_l00002ooooo`05o`000?oooooo0000o`000?ooool00_l000001?oooooo0000o`000?l0000:oooo
o`?o000000?oooooo`000?ooool02?ooool2o`000004ooooool0003o0000o`0000?ooooo00?o0000
ooooool000000_ooool2o`000003ooooool0003o000000?ooooo00?o0000ooooool000001Oooool3
o`0004Sooooo000Rooooo`03o`000?oooooooooo02kooooo0ol00004ojVmj004o`000?nY_NSoZKgX
ojVmj0?o00000onY_NP4o`0000?oZKgX0ol00005ooooo`03o`000?oooooooooo04Cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo0_l00000
0on^foOo0000ok3Hm005ok3Hm0?o00001_o4dnH01?l0003o`l_Pol?;h?l00003olo<eP03o`000?o=
`LoocL7?00CocL7?0_l00007ol^hb0;o00001_o;//400ol0003ob:foo`000006ol:U_0;o00001oni
Wkh01?l0003o]io0okNO`?l00003okJP`P03o`000?nbVl7o/Y_100Co/Y_100?o0000ojVGa?l00000
0_l000000onWU<;o0000oin?``05oin?``03o`000?nFRLCoUXW400?oUXW400?o0000oi28a_n@R<H0
0on@R<H00ol0003oR8G9ohR5b@03ohR5b@03o`000?n3Q/koPhK>00?oPhK>00Co0000oh><don3S=?o
PhcC1ol000000on1S=Go0000ohVFfP04ohVFfP04o`000?nDX=coU:3LoiBPg0Go00001?ooool00ol0
003oooooooooo`0gooooo`03o`000?oooooooooo02Cooooo0_l00003ooooo`05o`000?oooooooooo
o`000?ooool01_l0000<ooooo`Go00001?ooool01?l0003oooooooooooooool2o`000004ooooool0
003o0000o`0000;ooooo00?o0000ooooool000000_l00002ooooo`;o00000_ooool01ol0003ooooo
oooooooooooo0000ooooool000001oooool00ol0003oooooooooo`15ooooo`008oooool00ol0003o
ooooooooo`0^ooooo`03o`000?nY_NSoZKgX00?oZKgX1?l00003ojVmj006o`000?nY_NSoZKgXojVm
j?l0003oZKgX1?l0001?ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`08ooooo`;o00001?n`f?@2o`0000?o/M7a00Co0000olCCi_o4dnKoa=?V0_l0
0004ol?;h003o`000?o?c=Ko000000KocL7?00?o0000olRkc_l000001_o;^<P01?l0003obKC5olVd
aOl00004ol^b`@05o`000?o8[Koob:foolR]_ol000001?o2YK`01?l0003o_Z>nokjS__l00006okVO
_P03o`000?ngWl3o000000Co]Z3200?o0000ok:K`OnbVl401?nbVl42o`0000GoYiC200?o0000oin?
`onOSl<00onOSl<00ol0003oUXW4oiJ9a003oiJ9a003o`000?n@R<KoT8S600?oT8S600?o0000ohR5
bOn8QLT00on8QLT00ol0003oPhK>oh>6cP03oh>6cP03o`000?n3S=?oPhcC00?oPhcC00?o0000ohNC
fOn7TmT00_n7TmT<o`0000?oUjCN00?o0000ooooooooool00_ooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04o`00
0003ooooool0003ooooo00_ooooo00?o0000ooooool000000_l00004ooooo`05o`000?oooooooooo
ooooool000000_ooool3o`0000;ooooo00?o0000ooooool000000ol000001?oooooo0000o`000?l0
0002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`14ooooo`009?ooool2o`0002oooooo00?o0000ojVmj?l000000_l00002ojVmj003o`000?nY_NSo
ZKgX00?oZKgX00?o0000ojVmj?l000000_l0001Dooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0<oooool2o`0000[ooooo0_l000000on`f?Co0000ok7Al@05ok7Al@03o`000?o4dnKo
000000Ko`l_P0ol00005olg1c`05o`000?o8^lkob;_>olRkc_l000001?o;^<P00ol0003obKC5olVd
a@02olVda@04o`000?o;//7obk;1o`0000Cob:fo00Go0000ol:U_?o2YKco`ZFlo`000003okjS_P03
o`000?niWkko^Inn00Co^Inn0_l00006okJP`P03o`000?nbVl7o/Y_100;o/Y_100?o0000ok:L`Ol0
00001OnWU<800ol0003oWho3oin?``03oin?``03o`000?nFRLCoUXW400CoUXW400?o0000oi28a_n@
R<H00on@R<H00ol0003oR8G9ohR5b@03ohR5b@03o`000?n3Q/koPhK>00?oPhK>00?o0000oh><don3
S=<00on3S=<00ol0003oQi?IohNCf@03ohNCf@03o`000?n>W=coSYcL00?oSYcL00Go0000oiNTg_nG
Y=koUjCNo`000003oiNTgP05o`000?ooooooooooooooool00000>Oooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo00Gooooo0_l000000ooooooo0000o`000004o`0000cooooo00?o0000
ooooool000000ol00003ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000;ooooo0_l0
00000ooooooo0000o`000003ooooo`;o00000oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo04_ooooo000Vooooo`03o`000?oooooooooo02gooooo00?o0000ojVmj?nY_NP01?nY_NP0
1?l0003oZKgXojVmj?nY_NP3o`0005Sooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo00Wooooo0_l00006ok7Al@?o00001?o3bn02o`0000?o`/;J00Go
0000olg1coo=`LoocL7?o`000005olRkcP04o`000?o;^<SobkS8o`0000GobKC500?o0000ol^b`Ol0
00001_o8[Kl00ol0003o`ZFlo`000005okjS_P03o`000?niWkko^Inn00;o^Inn00?o0000ok^S`Ol0
00001_nfX<800ol0003o/Y_1ok:K`@02o`0000?o/Yc100?o0000ojND`_nWU<800_nWU<800ol0003o
Who3oin?``04oin?``03o`000?nFRLCoUXW400?oUXW400?o0000oi28a_n@R<H00on@R<H00ol0003o
R8G9ohR5b@03ohR5b@03o`000?n3Q/koPhK>00?oPhK>00?o0000oh><don3S=<00on3S=<00ol0003o
Qi?IohNCf@04ohNCf@03o`000?n>W=coSYcL00?oSYcL00Go0000oiNTg_nGY=koUjCNo`000002oiNT
gP05o`000?ooooooooooooooool00000>Oooool00ol0003oooooooooo`0Yooooo`?o000000?ooooo
o`000?l000000ol0000<ooooo`03o`000?oooooo000000;ooooo0_l00004ooooo`05o`000?oooooo
ooooooooool000000oooool3o`000004ooooool0003o0000ooooo`?o00000_ooool00ol0003ooooo
o`000003ooooo`03o`000?oooooooooo053ooooo000Wooooo`03o`000?oooooooooo02gooooo00?o
0000ojVmj?nY_NP00onY_NP4o`0005cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo00[ooooo0_l000001?nadO7o0000o`000?l00003ok79k0;o0000
00?o`l_Po`000?o2`]X01Oo2`]X00ol0003ocL7?o`000006olRkcP03o`000?o;^<So000000KobKC5
0_l00008olR]_`03o`000?nnXkko_Z>n00Co_Z>n00?o0000okVO__niWkh00_l00003ok^S`@03o`00
0?nfX<;o]Z3200?o]Z3200?o0000ok:K`Ol000001OnbW<400ol0003oYiC2ojND`P03ojND`P03o`00
0?nOSl?oWho300?oWho300?o0000oiJ9a?nFRL@00onFRL@00ol0003oT8S6oi28aP03oi28aP03o`00
0?n8QLWoR8G900?oR8G900?o0000oh>6c_n3Q/h00on3Q/h00ol0003oPhcCoh><d`04oh><d`03o`00
0?n7TmWoQi?I00?oQi?I00?o0000ohjLg?n>W=`01?n>W=`01ol0003oUjCNoiNTg_nGY=ko0000oiNT
g_l000001?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02[ooooo00Go0000oooo
ool0003o0000ooooo`03o`00013ooooo0_l000001Ooooooo0000oooooooooooo000000?ooooo0_l0
0003ooooo`?o000000?oooooo`000?l000000_ooool3o`0000;ooooo0_l0001Fooooo`00:?ooool0
0ol0003oooooooooo`0]ooooo`03o`000?nY_NSo000000;o0000H?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02oooool00ol0003o/LW/ok79k005
ok79k0;o00001oo2`]X2o`0000Oob;_>0_l00006olVda@03o`000?o6/<Go000000Oob:fo0_l00006
okjS_P03o`000?niWkko000000Go^j?100?o0000okJP`_nfX<800onfX<82o`0000Ko/Yc100?o0000
ojND`_nWU<800onWU<800ol0003oWho3oin?``03oin?``04o`000?nFRLCoUXW4oiJ9a1?o00000_n3
Q/h00ol0003oPhcCoh><d`03oh><d`03o`000?n7TmWoQi?I00?oQi?I00?o0000ohjLg?n>W=`01?n>
W=`01?l0003oUjCNoiNTg_nGY=h4o`0000?ooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`0Yooooo`04o`000?oooooo0000ooooo`;o000000?oooooo`000?ooool04?ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooooooo`;o00000oooool2o`0000?ooooo00Co0000
oooooooooooooooo0ol00002ooooo`;o0000EOooool002Wooooo0_l0000^ooooo`03o`000?oooooo
oooo06;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0gooooo`;o00003?ooool0
0ol0003o/LW/ok79k002ok79k0;o000000?o/L7Vo`000?o2`]X01Oo2`]X00ol0003o_[_Go`000006
olRkcP03o`000?o4]/go000000GobKC500Go0000olJ`aOo6/<Goa[35o`000005olR]_`04o`000?o2
Z/7o`Z[1o`0000Ko_Z>n00?o0000ok^S`OnkXl401OnkXl400ol0003o]Z32okJP`P02o`000003ok:M
`_l0003o/Yc100Ko/Yc100?o0000ojND`_nWU<800_nWU<801?l0003oWho3oin?`onOSl<6o`0000?o
VI?<00?o0000oi>AconCTLl00onCTLl00ol0003oSI3Bohf@dP03ohf@dP04o`000?n9T]KoRI;FohVB
eQWo000000CoVJWRo`000?nIZN;o00000oooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo02Sooooo00Oo0000ooooooooooooooooo`000?oooooo000001;ooooo0_l000000ooooooo0000
o`000002ooooo`03o`000?oooooooooo00Co00000_ooool01?l0003oooooo`000?ooool2o`0000?o
oooo0ol00004ooooo`03o`000?oooooooooo05;ooooo000[ooooo`03o`000?oooooooooo02_ooooo
00?o0000ooooooooool0Hoooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooooooool02_ooool01?l0003o/LW/o`000?l00004ok71iP04o`000?o2`][o`/;Jol;2
fP;o00000onn^mL01?l0003ob;_>olRkc_o8^lh2o`0000?oa;K=00Go0000olVdaOo9]<GobKC5o`00
0004olJ`a@03o`000?o8[Koob:fo00;ob:fo00Go0000ol:Z`Oo2Z/7o`Z[1o`000005okjS_P;o0000
1onkXl400ol0003o]Z32o`000004ok:M`P03o`000?nbW<7o/Yc100Co/Yc100?o0000ojND`_nWU<80
0_nWU<84o`0000?oWYC900?o0000oiVCc?nITl`01?nITl`00ol0003oTi7?oi>Ac`03oi>Ac`03o`00
0?n=T=;oSI3B00?oSI3B00?o0000ohVBe_n9T]H00_n9T]H00ol0003oRIKJohVFfP04ohVFfP03o`00
0?n<W=goS9cM00?oS9cM00?o0000oi:Sh?nBXn001?nBXn000ol0003oVJWRoiVYhP02oiVYhP03o`00
0?nIZN;o000000;ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Wooooo`07o`00
0?ooooooooooooooool0003oooooo`00000Dooooo`?o00000_ooool2o`000003ooooool0003o0000
00?o00000_ooool3o`000004ooooool0003oooooo`0000?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1Aooooo`00;?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
06Cooooo00Go0000ooooooooooooooooo`00000looooo`03o`000?oooooooooo00[ooooo0_l00006
ok71iP03o`000?o2`][o000000Ko_[_G00?o0000olRkc_l000001_o4]/d00ol0003obKC5o`000006
olJ`a@04o`000?o8[Koob:foo`0000Go`Z[100Go0000okjS__nnXkko_Z>no`000002okjW`P03o`00
0?nkXl7o^j?100Co^j?10_l00005ok:M`P03o`000?nbW<7o/Yc100Co/Yc100?o0000ojND`_l00000
0_l000000onYV/Oo0000oijDb@05oijDb@03o`000?nITlcoVI?<00?oVI?<00?o0000oi>AconCTLl0
0onCTLl00ol0003oSI3Bohf@dP03ohf@dP03o`000?n9T]KoRI;F00?oRI;F00?o0000ohVFf_n9U]X0
1?n9U]X00ol0003oS9cMohbLg@03ohbLg@03o`000?nBXn3oTZ?P00CoTZ?P00?o0000oiVYh_nIZN80
0_nIZN801Ol0003oVJWRo`000?oooooo000003Sooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01;ooooo00Go0000ooooool0003o0000ooooo`02o`00
00?ooooo0ol00003ooooo`?o000000Coooooo`000?l0003o00001?ooool00ol0003oooooooooo`1G
ooooo`00;Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo06Cooooo00Go0000oooo
ooooooooooooo`00000mooooo`03o`000?oooooooooo00_ooooo00?o0000ok71i_na`NH00ona`NH2
o`0000Oo_[_G0_l00008olBfc@03o`000?o6/<Goa[3500Goa[3500?o0000olR]_ol000001_o2Z/40
1?l0003o_Z>nokjS__l00003okjW`P03o`000?nkXl7o^j?100?o^j?100?o0000okbV`ol000001_nb
WL800ol0003o/Yc1ok:L`@03ok:L`@;o00001OnYV/L00ol0003oWYC9oijDb@03oijDb@03o`000?nI
TlcoVI?<00CoVI?<00?o0000oi>AconCTLl00onCTLl00ol0003oSI3Bohf@dP03ohf@dP03o`000?n9
T]KoRI;F00?oRI;F00?o0000ohVFf_n9U]X00on9U]X00ol0003oS9cMohbLg@04ohbLg@03o`000?nB
Xn3oTZ?P00?oTZ?P00?o0000oiVYh_nIZN800_nIZN85o`0003Sooooo00?o0000ooooooooool0@_oo
ool01_l0003oooooooooool0003oooooo`0000?ooooo0ol000001ooooooo0000ooooool0003ooooo
o`000?ooool00ol00004ooooo`03o`000?oooooooooo05Oooooo000^ooooo`;o0000:Oooool00ol0
003oooooooooo`1Uooooo`04o`000?ooooooooooo`0003kooooo0_l0000<ooooo`03o`000?na`NKo
000000;o00000_n_^N400ol0003o_[_Gokjke`03okjke`03o`000?nk]]Go000000Ooa;K=0_l00007
olJ`a@;o00001oo2Z/400ol0003o_Z>no`000005okjW`P05o`000?nkXl7o^j?1ok^S`Ol000000onl
Y/<00ol0003o/Yg2ok:M`P03ok:M`P04o`000?nbW<7o/Yc1ok:L`@;o000000?o/J77o`000?nYV/L0
1?nYV/L00ol0003oWYC9oijDb@04oijDb@03o`000?nITlcoVI?<00?oVI?<00?o0000oi>AconCTLl0
0onCTLl00ol0003oSI3Bohf@dP03ohf@dP03o`000?n9T]KoRI;F00?oRI;F00?o0000ohVFf_n9U]X0
0on9U]X00ol0003oS9cMohbLg@04ohbLg@04o`000?nBXn3oTZ?Poi:Sh0Oo000000?oV[3Vo`000?nJ
/>H00_l0000hooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool00_l00003ooooo`Co
000000Goooooo`000?ooooooooooo`000003ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0E_ooool0033ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1Vooooo`03
o`000?oooooo0000043ooooo00?o0000ooooooooool02_ooool00ol0003o[kWQojnih@04ojnih@05
o`000?nn^mOo_[_Gokjkeol000000onk]]D00ol0003oa;K=olBfc@03olBfc@04o`000?o0//co`;;<
o`0000Goa[3500?o0000ol:^aol000001oo2Z/42o`0000Ko_ZO200Co0000ok^S`OnkXl7o00001?nl
Y/<00ol0003o/Yg2ok:M`P03ok:M`P04o`000?nbW<7o0000o`0000Co/J7700?o0000ojVJaonYV/L0
0onYV/L00ol0003oWYC9oijDb@03oijDb@04o`000?nITlcoVI?<oiVCc2Go00000onDZnH00ol0003o
V[3VoiZ`iP03oiZ`iP03o`000?nJ/>Ko000003Sooooo00?o0000ooooooooool0@Oooool01_l0003o
ooooooooool0003oooooo`0000?ooooo1ol000000ooooooo0000ooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0EOooool0037ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1Vooooo`03o`000?oooooo0000047ooooo00?o0000ooooooooool02Oooool00ol0
003o[kWQojnih@05ojnih@03o`000?nn^mOo000000Go^kKE00Go0000olBfcOo4]/goa;K=o`000004
ol2bc003o`000?o6/<Goa[3500;o00000oo2[/L00ol0003o`Z[1ol:Z`@03ol:Z`@03o`000?noZlKo
000000Ko_ZO200?o0000ok^S`Ol000001_nlY/<00ol0003o/Yg2ok:M`P02ok:M`P;o00001_naXLL0
0ol0003oZI[7ojVJa`03ojVJa`04o`000?nNU<WoWYC9oijDb@Ko00000onKWmL00ol0003oUIkIoiFN
f@03oiFNf@03o`000?n@WMcoT9gL00?oT9gL00?o0000ohfNgon=W]l00on=W]l00ol0003oS:7RohbQ
hP03ohbQhP03o`000?n?YNCoSjGT00CoSjGT00?o0000oiB[i_nDZnH01?nDZnH00ol0003oV[3VoiZ`
iP02oiZ`iP04o`000?nJ/>Ko0000o`0003Oooooo00?o0000ooooooooool0?Oooool00ol0003ooooo
ooooo`03ooooo`;o000000?oooooo`000?l000000oooool6o`000003ooooool0003o000000?ooooo
00?o0000ooooooooool0G?ooool003;ooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`1Wooooo`03o`000?oooooo0000047ooooo00?o0000ooooooooool02Oooool00ol0003o[kWQojni
h@04ojnih@;o00001onk]]D00ol0003oa;K=o`000005ol2bc003o`000?o6/<Go000000Ko`Zk700?o
0000ol:Z`Oo2Z/400_l00003okn[aP03o`000?nnYl;o_ZO200?o_ZO20_l00007okbV``03o`000?nb
WL;o/Yg200;o000000?o]:C8o`000?naXLL01_naXLL00ol0003oZI[7ojVJa`02ojVJa`Co00000onR
X]@00ol0003oVioGoi^Oe`04oi^Oe`03o`000?nEW]WoUIkI00?oUIkI00?o0000oi2Mg?n@WM`00on@
WM`00ol0003oSIkOohfNg`03ohfNg`03o`000?n<XN;oS:7R00?oS:7R00?o0000ohnUi?n?YN@01?n?
YN@00ol0003oU:_VoiB[iP04oiB[iP04o`000?nJ/>KoV[3VoiZ`iPCo00007_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01?ooool00ol0
003oooooooooo`0looooo`;o00001_ooool4o`0000;ooooo00?o0000ooooool000000_ooool6o`00
00;ooooo00?o0000ooooooooool0G?ooool003?ooooo0_l0000Tooooo`03o`000?oooooooooo06So
oooo0_l00012ooooo`;o00002_ooool00ol0003o[kWQojnih@03o`000003ojfcgOl0003o^kKE00Ko
^kKE0_l00006ol2bc0;o00001oo2[/L00ol0003o`Z[1o`000005okn[aP03o`000?nnYl;o_ZO200;o
_ZO200?o0000okfZa_l000001onlY/<00ol0003o/Yg2o`000004okBTb003o`000?naXLOo/J7700Co
/J7700?o0000ojVJaol000000_l000000onZY]?o0000oj:Re005oj:Re003o`000?nKWmOoVioG00Co
VioG00?o0000oiFNfOnEW]T00onEW]T00ol0003oT9gLoi2Mg003oi2Mg003o`000?n=W]ooSIkO00?o
SIkO00?o0000ohbQh_n<XN800on<XN800ol0003oSjGTohnUi003ohnUi003o`000?nDZnKoU:_V00;o
U:_V1_l00002ooooo`;o00007_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05ob4Q8OnHV9SooooooiRHV?lQ8B401?ooool00ol0003oooooooooo`0kooooo`;o00001_ooool5
o`0000;ooooo00?o0000ooooool000000oooool2o`000003ooooool0003ooooo00?ooooo00?o0000
ooooooooool0Foooool003Gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1Xoooo
o`?o0000A?ooool00ol0003oooooooooo`08ooooo`;o00001On]/md00ol0003o^kKEok^fe@02ok^f
e@;o000000?o^;;Co`000?o0//`01?o0//`00ol0003o_K3=o`000007ol:^a`;o00001onoZlH01?l0
003o_ZO2okjW`_l00003okfZaP03o`000?nlY/?o_:K300Co_:K30_l00005okBTb003o`000?naXLOo
/J7700Co/J770_l00005ojZVd`03o`000?nRX]CoXZ;D00CoXZ;D00?o0000oi^OeonKWmL00onKWmL0
0ol0003oUIkIoiFNf@03oiFNf@04o`000?n@WMcoT9gLoi2Mg1Wo00001oooool3o`0001kooooo00Go
410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001?ooool2o`0003co
oooo0_l00006ooooo`03o`000?oooooo000000;o00000_ooool00ol0003oooooo`000003ooooo`04
o`000?ooooooooooo`0006;ooooo000fooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool0I?ooool4o`0004Sooooo00?o0000ooooooooool02?ooool00ol0003o[K?Mojfcg@04ojfcg@04
o`000?nk]]Go0000o`0000Co^;;C00Go0000ol2bc?o0//co`;;<o`000003okf`c@03o`000?o2[/Oo
`Zk700?o`Zk700?o0000okj^bol000001onoZlH00ol0003o_ZO2o`000004okfZaP03o`000?nlY/?o
_:K300?o_:K300?o0000okZ[b_l000001_ndY<P01?l0003o/J77ok6QaonaXLL2o`000003ok6[d_l0
003oZZKC00GoZZKC00?o0000oj:Re?nRX]@00onRX]@01?l0003oVioGoi^OeonKWmL<o`0001cooooo
1?l0000Qooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b
00Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`05ooooo`;o000000?oooooo`00
0?ooool00_ooool00ol0003oooooooooo`03ooooo`;o000000?oooooo`000?ooool0HOooool003Oo
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Pooooo`Co0000COooool00ol0003o
ooooooooo`08ooooo`03o`000?n]/mgo[K?M00?o[K?M0_l00007okRbd`03o`000?o0//co000000Go
_K3=00Go0000ol:^aoo2[/Oo`Zk7o`000003okj^b`03o`000?noZlKo_j_600Co_j_60_l00006okfZ
aP03o`000?nlY/?o_:K300;o00000onjZlX00ol0003o]:C8okBTb003okBTb004o`000?naXLOo0000
o`0000Co/J_B00?o0000ojZVdonZY]<00onZY]<01?l0003oXZ;Doj:Re?nRX]@6o`0002Cooooo1?l0
000Uooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Co
oooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`05ooooo`05o`000?oooooo0000oooo
ool000002Oooool2o`0000;ooooo00?o0000ooooooooool0Goooool003Sooooo0_l0000Nooooo`03
o`000?oooooooooo05cooooo1?l0001Booooo`;o00002Oooool00ol0003o[K?Mo`000002o`000003
ojb_f_l0003o^;;C00Ko^;;C0_l00007okf`c@03o`000?o2[/Oo000000Co_Zk;00?o0000okn[a_no
ZlH00onoZlH00ol0003o_Jk;o`000006okfZaP03o`000?nlY/?o000000Go^Z_:00?o0000okBTb?nd
Y<P00ondY<P2o`0000Ko/J_B00?o0000ojZVdonZY]<00onZY]<4o`0002Kooooo1?l0000Yooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Cooooo00?o0000
ooooooooool0>Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo000000[ooooo00Co0000
oooooooooooo0000HOooool003[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1H
ooooo`Co0000F?ooool00ol0003oooooooooo`07ooooo`03o`000?n/[m[o[:oJ00?o[:oJ00?o0000
okRbdonh/]<00_nh/]<2o`000003okF`e?l0003o_K3=00Ko_K3=0_l00006okj^b`03o`000?noZlKo
_j_600;o00000onm[//00ol0003o_J[6okfZaP03okfZaP;o00001onjZlX00ol0003o]:C8okBTb002
o`000003okF^d_l0003o/J_B00Go/J_B00?o0000ojZVdonZY]<00ol0000Vooooo`Co0000;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000004ooooo`03o`00
0?oooooooooo04?ooooo00?o0000ooooool000002oooool00ol0003oooooooooo`1Rooooo`00>ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05Cooooo1?l0001Mooooo`03o`000?oo
oooooooo00Kooooo00?o0000ojb_f_n/[mX01?n/[mX01?l0003o^;;Co`000?l00004okF`e003o`00
0?nm/<go_K3=00?o_K3=00?o0000okZ`d?l000001_nn[//00ol0003o_j_6o`000006okf^b`03o`00
0?nmZ/Ko_J[600;o000000?o^jo=o`000?njZlX01_njZlX00ol0003o]:C8o`000004okF^dP03o`00
0?naZm;o/J_B00?o/J_B0ol0000Vooooo`?o0000<Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@04ooooo`03o`000?oooooooooo04Gooooo00?o0000oooo
ooooool0K_ooool003cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1@ooooo`Co
0000H_ooool00ol0003oooooooooo`06ooooo`03o`000?n/[m[o[:oJ00?o[:oJ0_l00007okF`e003
o`000?nm/<go_K3=00;o00000onj/=000ol0003o_Zk;okj^b`03okj^b`;o00001onm[//00ol0003o
_J[6o`000004ok^_c@03o`000?njZl[o^Z_:00Co^Z_:0_l00006okF^dP03o`000?naZm;o000000;o
00009Oooool4o`0004gooooo00?o0000ooooooooool0]_ooool003gooooo0_l0000Iooooo`03o`00
0?oooooooooo04gooooo0ol0001Wooooo`;o00001oooool00ol0003o[:oJo`000002o`0000;oZjkJ
00?o0000okF`e?ne/=@01?ne/=@00ol0003o_K3=o`000006okZ`d003o`000?nn[/_o_Zk;00;o0000
00?o^k3?o`000?nm[//01_nm[//2o`0000Ko^jo=00Co0000okZ[b_njZl[o^Z_:0_l000000oni/]?o
0000okF^dP05okF^dP;o00009?ooool4o`00057ooooo00?o0000ooooooooool0]_ooool003oooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`19ooooo`Co0000K?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?n[[][oZjkJ00CoZjkJ00?o0000okF`e?ne/=@00one/=@2o`0000Oo^[3@
00?o0000okj^bol000001?nk/<l00ol0003o_Jk;okf^b`03okf^b`03o`000?nk/]3o000000Ko^jo=
00Co0000okZ[b_l0003o00001?ni/]<01?l0003o]JkBokF^d_ne[]82o`0002;ooooo1?l0001Eoooo
o`03o`000?oooooooooo0;Kooooo0010ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0AOooool4o`00077ooooo00?o0000ooooooooool01?ooool00ol0003oZjkJoj^^fP05oj^^fP03
o`000?ne/=Co000000;o000000?o/k3Eo`000?nj/=001_nj/=02o`0000Ko^k3?00?o0000okf^bonm
[//00_l00003ok^bd003o`000?nk[lgo^jo=00?o^jo=0_l00006okVbd`04o`000?ne[];o0000o`00
023ooooo1?l0001Iooooo`03o`000?oooooooooo0;Kooooo0011ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0@Oooool4o`0007Kooooo00?o0000ooooooooool01?ooool00ol0003o
ZjkJoj^^fP04oj^^fP;o00001Onc/=D00ol0003o^[3@okZ`d002okZ`d0;o000000?o^;;Co`000?nk
/<l01Onk/<l00ol0003o_Jk;o`000006ok^bd003o`000?nk[lgo^jo=00;o000000?o^kKDo`000?ni
/]<01Oni/]<2o`0001kooooo1?l0001Mooooo`03o`000?oooooooooo0;Kooooo0012ooooo`;o0000
5?ooool00ol0003oooooooooo`0mooooo`Co0000Noooool2o`0000Gooooo00?o0000oj^^f_n[[]X0
0ol000000onZ[][o0000ok>`e@05ok>`e@04o`000?nj/=3o0000o`0000Co^;;C00?o0000ok^`conk
/<l00onk/<l2o`0000Oo^k;@00?o0000ok^_cOl000001?nk]]@01?l0003o^K;CokVbdoni/]<2o`00
01cooooo1?l0001Qooooo`03o`000?oooooooooo0;Kooooo0014ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool0>Oooool4o`00087ooooo00?o0000ooooooooool00oooool2o`0000Go
ZZkJ00?o0000ok>`eOnc/=D00onc/=D2o`0000Oo^;;C00?o0000ok^`conk/<l00_l000000onj]=Co
0000ok^bd006ok^bd0;o00001_nk]]@00ol0003o^K;Co`00000Jooooo`Co0000IOooool00ol0003o
ooooooooo`2fooooo`00AOooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03Gooooo
1?l00026ooooo`03o`000?oooooooooo00?ooooo00?o0000ojZ^f_nZ[]X01?nZ[]X00ol0003o/k3E
ok>`e@02o`000003ok:bf?l0003o^;;C00Ko^;;C00?o0000ok^`col000001?nj]=@00ol0003o^k;@
ok^bd002ok^bd0;o000000?o^kSGo`000?nk]]@01Onk]]@2o`0001Oooooo1?l0001Yooooo`03o`00
0?oooooooooo0;Kooooo0016ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<Ooo
ool4o`0008_ooooo00?o0000ooooooooool00oooool00ol0003oZZkJojZ^fP03ojZ^fP03o`000?nc
/=Go000000Co/[;H00?o0000okRbdonh/]<01?nh/]<2o`0000Ko^[CD00Co0000ok^bd?l0003o0000
1?nk^=L01?l0003o^kKDok^fe?nk]]@2o`0001Kooooo0ol0001]ooooo`03o`000?oooooooooo0;Ko
oooo0017ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0;Oooool4o`00093ooooo
00?o0000ooooooooool00oooool01?l0003oZZkJojZ^f_nZ[]X3o`0000Ko/[;H00?o0000okRbdonh
/]<00ol000000onf]MSo0000okZde005okZde0;o00001onk^=L00ol0003o^kKDo`00000Dooooo`Co
0000L?ooool00ol0003oooooooooo`2fooooo`00B?ooool2o`0000kooooo00?o0000ooooooooool0
:Oooool4o`0009Gooooo0_l00004ooooo`?o00000_nY/=`00ol0003o/[;Hok:bf004ok:bf0?o0000
1Onf]MP01?l0003o^[CDokZde?nj]=@2o`000003okVjf_l0003o^kSG00Ko^kSG0_l0000Aooooo`Co
0000M?ooool00ol0003oooooooooo`2fooooo`00B_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo02Gooooo1?l0002Kooooo`05o`000?ooooooooooooooool000001OnY/=`01?l0003o
/[;Hok:bf?nb/]P2o`000003ok6eg?l0003o][GH00Ko][GH00?o0000okZde?l000001?ni^]X00ol0
003o^kSGok^he`02ok^he`;o00003oooool4o`0007Sooooo00?o0000ooooooooool0]_ooool004_o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Qooooo`Co0000X?ooool01Ol0003o
oooooooooooooooo000000GoZK3L00?o0000ok:bf?l000001?na]M`00ol0003o][GHokJef004okJe
f0;o00001_ni^]X01?l0003o^kSGo`000?l0000=ooooo`Co0000O?ooool00ol0003oooooooooo`2f
ooooo`00C?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01kooooo1?l0002Uoooo
o`05o`000?ooooooooooooooool000000onY/=`3o`0000Ko/KGL00?o0000okJef?nf]MP00ol00002
okFjg@03o`000?ni^][o^K[J00?o^K[J0_l0000;ooooo`Co0000P?ooool00ol0003oooooooooo`2f
ooooo`00COooool2o`0000Sooooo00?o0000ooooooooool06_ooool4o`000:[ooooo0_l00002oooo
o`?o00000onY/ml00ol0003o/KGLok6eg003ok6eg0?o00001_ne^]d00ol0003o^K[Jo`000002o`00
00Wooooo1?l00024ooooo`03o`000?oooooooooo0;Kooooo001?ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool05oooool3o`000;3ooooo00?o0000ooooool000001_nY/ml00ol0003o
/KGLo`000002o`000003ok2jhOl0003o]K[M00Ko]K[M0_l00008ooooo`Co0000R?ooool00ol0003o
ooooooooo`2fooooo`00D?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo
1?l0002dooooo`03o`000?oooooo000000GoZK?O0_l00005ok2jh@03o`000?ne^]go]K[M00;o]K[M
0_l00006ooooo`Co0000S?ooool00ol0003oooooooooo`2fooooo`00DOooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00oooooo1?l0002iooooo`04o`000?oooooo0000ojVcg`?o0000
0_nY^>@00ol0003o/;[Qok2jh@03ok2jh@04o`000?ne^]go0000o`0000Gooooo0ol0002@ooooo`03
o`000?oooooooooo0;Kooooo001Booooo`;o00000oooool00ol0003oooooooooo`0;ooooo`Co0000
__ooool3o`0000KoZKST00Co0000ok2jhOn`^^7o/;[Q0ol00003ooooo`Co0000Toooool00ol0003o
ooooooooo`2fooooo`00E?ooool01?l0003oooooooooool00009ooooo`Co0000a?ooool2o`0000Go
ZKST1?l00002ooooo`Co0000Uoooool00ol0003oooooooooo`2fooooo`00EOooool00ol0003ooooo
o`000005ooooo`Co0000bOooool2o`000004ojVhi?l0003o0000o`0000;ooooo1?l0002Kooooo`03
o`000?oooooooooo0;Kooooo001Fooooo`;o000000?oooooo`000?l000000_l0003>ooooo`;o0000
00?oooooo`000?l000000_l0002Oooooo`03o`000?oooooooooo0;Kooooo001Gooooo`;o0000dooo
ool2o`0009_ooooo1?l000001Ol@413ooooooooooooooooo00000;Sooooo003oooooolcooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`2fooooo`00ooooooo<ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0]_ooool00?ooooooc?ooool00ol0003oooooooooo`03oooo
o`;o0000]oooool006kooooo0_l0003ooooooecooooo00?o0000ooooooooool0_?ooool0073ooooo
00?o0000ooooooooool0d?ooool2o`0008Kooooo00?o0000ooooooooool0_?ooool005oooooo00?o
0000omgMgOooool01_ooool3o`0000Gooooo00?o0000ooooooooool0a?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool0_?ooool005oooooo00?o<S8b
okZj^_ooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0<Cooooo00?o410@
omgMgOooool00_ooool3o`0000Kooooo00?o0000ooooooooool0POooool00omEEEGoIVIVo`00002n
ooooo`00Goooool01_mgMgOoQhN7odA4A?l0003o410@ohN7Q`Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`32ooooo`05olc<c?l@413o0000o`000?n7QhL00oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo08Gooooo0ol000000ol@413oooooooooo`2gooooo`00Gooo
ool01onYZJWo0000okZj^_oooooogMgMob4Q8On7QhL00_ooool2o`0000Cooooo0ol00034ooooo`06
ob4Q8On7QhOo<S8bojVYZOm4A4CoQhN70_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo08Oooooo00?o410@okZj^_ooool0^?ooool005oooooo00?ogMgMoa0@4?ooool00_ooool00ooM
gMgo410@ooooo`3>ooooo`07o`000?ooooooIVIVohN7QooMgMgo410@ooooo`02o`0000Gooooo0ol0
0029ooooo`03oiRHV?lb<S;ooooo0;Sooooo001Pooooo`03oa0@4?oMgMgooooo00;ooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0<;ooooo00Ko410@omgMgOmgMgOoMgMg
ooooool0002Dooooo`03omgMgOl0003o^[Zj0;Sooooo001Pooooo`06ohN7QolQ8B7ogMgMoooooomg
MgOo<S8bcoooool01_nYZJWoA4A4oiRHV?m4A4CoV9RHoa0@40;ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`27ooooo`03oeEEEOmgMgOoA4A40;Sooooo001Qooooo`05ogMgMol0003o
0000oc8b<_o<c<`0d?ooool01OnHV9So0000o`000?l@413oc<c<09?ooooo00GogMgMoa0@4?oooooo
8B4QomgMg@2gooooo`00oooooolhooooo`03okZj^_lb<S;ooooo09Cooooo00GoIVIVohN7Qooooooo
V9RHoeEEE@2gooooo`00ooooooliooooo`03o`000?oooooooooo09;ooooo00?ok^k^o`000?o^k^h0
0_ooool00ol0003ogMgMooooo`2eooooo`00ooooooo>ooooo`04oa0@4?l0003o0000ooooo`;o0000
00?o410@ooooooooool0]?ooool00?oooooooooooon<ooooo`00ooooooooooooohcooooo003ooooo
ooooooooS?ooool00?oooooooooooon<ooooo`00ooooooooooooohcooooo003oooooooooooooS?oo
ool00?oooooooooooon<ooooo`00ooooooooooooohcooooo003oooooooooooooS?ooool00?oooooo
oooooon<ooooo`00ooooooooooooohcooooo003oooooooooooooS?ooool00?oooooooooooon<oooo
o`00ooooooooooooohcooooo003oooooooooooooS?ooool00?oooooooooooon<ooooo`00oooooooo
ooooohcooooo003oooooooooooooS?ooool00?oooooooooooon<ooooo`00ooooooooooooohcooooo
003oooooooooooooS?ooool00?oooooooooooon<ooooo`00ooooooooooooohcooooo003ooooooooo
ooooS?ooool00?oooooooooooon<ooooo`00ooooooooooooohcooooo003oooooooooooooS?ooool0
0?oooooooooooon<ooooo`00ooooooooooooohcooooo003oooooooooooooS?ooool00?oooooooooo
oon<ooooo`00ooooooooooooohcooooo003oooooooooooooS?ooool00?oooooooooooon<ooooo`00
ooooooooooooohcooooo003ooooooa7ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003
oa0@4?oooooooooo00Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^
k^ko<S8bo`000?l@413oc<c<00Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<01?ooooo1?l000000ol@413oooooooooo`3`ooooo`00oooo
oolAooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooo
ooooool02Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOo
oooooiRHV?lQ8B402Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q
8OnHV9SooooooiRHV?lQ8B405Oooool00ol0003oooooooooo`3booooo`00oooooolAooooo`05oa0@
4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0:ooooo`05oa0@4?oooooooooooooo
ool@41002oooool5o`0000[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooo
ooooooooool000002Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooooooo
ooooo`00000Eooooo`03o`000?oooooooooo0?;ooooo003ooooooa7ooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0000_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B402Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0Eooooo`03o`000?oooooooooo0?;ooooo003ooooooa7ooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Sooooo00Go0000ooooooooooooooooo`00000;
ooooo`04omgMgOmEEEGoooooo`0000_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?mEEEGo0000oa0@4?o<c<`02Oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`00
0?l0003o0000olc<c00Eooooo`03o`000?oooooooooo0?;ooooo003ooooooa7ooooo00Go410@oooo
oooooooooooooa0@400?ooooo`03o`000?oooooooooo00Oooooo00Go410@oooooooooooooooooa0@
400<ooooo`03ogMgMoo<c<co000000_ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEE
EOn7QhOooooo00_ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj
^_l@41005Oooool00ol0003oooooooooo`3booooo`00oooooolAooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Wooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03onk^k_m4A4Co000000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgM
gOl@413oV9RH00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj
^_l000005Oooool00ol0003oooooooooo`3booooo`00oooooolAooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0=ooooo`03ogMgMol0003ooooo00[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<
c?m4A4Co0000oa0@40Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000
oa0@4?nYZJT04oooool00omEEEGoIVIVo`00003dooooo`00oooooonMooooo`;o00000_ooool2o`00
0>Sooooo003ooooooigooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMgXooooo`00oooooonNoooo
o`04omgMgOl0003o410@olc<c>Wooooo003loooooi[o00001oooool01?o^k^ko8B4Qoa0@4?o^k^kY
ooooo`00o?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool01Oooool01?lQ8B7oMgMgogMgMolb<S;Yooooo`00o?ooool00ol0003oooooooooo`2Moooo
o`;o00000_ooool2o`000>Sooooo003looooo`03o`000?oooooooooo0?ooooooS?ooool00?cooooo
00?o0000ooooooooool0oooooon<ooooo`00o?ooool00ol0003oooooooooo`3oooooohcooooo003l
ooooo`03o`000?oooooooooo0?ooooooS?ooool00?cooooo0_l0003oooooohgooooo003looooo`03
o`000?oooooooooo0?ooooooS?ooool00?cooooo00?o0000ooooooooool0oooooon<ooooo`00o?oo
ool00ol0003oooooooooo`3oooooohcooooo003looooo`03o`000?oooooooooo0?ooooooS?ooool0
0?cooooo00?o0000ooooooooool0oooooon<ooooo`00o?ooool00ol0003oooooooooo`3oooooohco
oooo003looooo`03o`000?oooooooooo0?ooooooS?ooool00?cooooo0_l0003oooooohgooooo003l
ooooo`03o`000?oooooooooo0?ooooooS?ooool00?cooooo00?o0000ooooooooool0oooooon<oooo
o`00o?ooool00ol0003oooooooooo`3oooooohcooooo003looooo`03o`000?oooooooooo0?oooooo
S?ooool00?cooooo00?o0000ooooooooool0oooooon<ooooo`00o?ooool00ol0003oooooooooo`3o
ooooohcooooo003looooo`03o`000?oooooooooo0?ooooooS?ooool00?cooooo0_l0003oooooohgo
oooo003looooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0oooooom3ooooo`00o?oo
ool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo0?oooooo?_ooool00?cooooo00?o0000
ooooooooool0oooooon<ooooo`00o?ooool00ol0003oooooooooo`3oooooohcooooo003Sooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`03o`000?oooooooooo
04Sooooo00?o0000ooooooooool0oooooom1ooooo`00hoooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01?ooool00ol0003oooooooooo`15
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0oooooolcooooo`00hoooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01Oooool2o`0003Wooooo00?o0000
ooooooooool0oooooomAooooo`00hoooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h01?ooool00ol0003oooooooooo`0_ooooo`04o`000?ooooooooooo`000?ooooooFOoo
ool00>?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00?o
0000ooooooooool0oooooon<ooooo`00hoooool01Ol@413ooooooooooooooooo410@00oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`3oooooohcooooo003Sooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool0
C_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo8oooool00>?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3ooooood7ooooo003looooo`03o`000?oooooooooo02kooooo00?o0000ooooool00000
4?ooool00ol0003oooooooooo`0Dooooo`04o`000?ooooooooooo`000?oooooo<?ooool00?cooooo
00?o0000ooooooooool0oooooon<ooooo`00o?ooool2o`00067ooooo00Co0000oooooooooooo0000
oooooolXooooo`00o?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool0ooooooldooooo`00o?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0?ooooooC_ooool00?cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0>oooo
o`04o`000?ooooooooooo`000?ooooooBoooool00?cooooo00?o0000ooooooooool0F?ooool00ol0
003oooooooooo`3ooooooc7ooooo003looooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo00000?oooooo:_ooool00?cooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooolSooooo`00o?ooool2o`00033ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`3ooooooc_ooooo003looooo`03o`000?oooooooooo04oooooo00?o0000
ooooooooool0ooooooljooooo`00o?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo
01oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo0?oooooo9_ooool0
0?cooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`3oooooockooooo003looooo`03
o`000?oooooooooo067ooooo00?o0000ooooooooool0oooooolXooooo`00o?ooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0oooooolHooooo`00o?oo
ool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo0?oooooo?Oooool00?cooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`0Fooooo`;o00003?ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo0?oooooo5Oooool00?cooooo0_l00015ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`3ooooooa7ooooo003looooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo0?oooooo<_ooool00?cooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0oooooolPooooo`00o?oo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0?oooooo>Oooool00?cooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool0ooooool?ooooo`00hoooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46
ooooo`;o000000?o410@ooooooooool00_ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooooaKooooo003Soooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0eooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool^
ooooo`00hoooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00004ooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo0?oooooo=oooool00>?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgo
ooooo`0000Gooooo0_l00015ooooo`03o`000?oooooooooo0?ooooooAOooool00>?ooooo00Go0000
ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Gooooo00?o0000ooooooooool0
Hoooool00ol0003oooooooooo`3oooooobKooooo003Sooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00omgMgOoc<c<o`000005ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo0?oooooo9Oooool00>?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Gooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom<ooooo`00hoooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool0
1?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`3oooooobOooooo003looooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool0oooooolLooooo`00o?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool04?ooool01Ol0003ooooooooooooooooo000000gooooo00Go
0000ooooooooooooooooo`00003oooooobGooooo003looooo`;o0000:Oooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0oooooolRooooo`00o?ooool0
0ol0003oooooooooo`0[ooooo`04o`000?ooooooooooo`0000gooooo00?o0000ooooooooool01ooo
ool01Ol0003ooooooooooooooooo00000?oooooo@Oooool00?cooooo00?o0000ooooooooool0BOoo
ool2o`0001Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooo00000?oooooo4_ooool00?cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0oooooolGooooo`00o?ooool00ol0
003oooooooooo`18ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000002_ooool00ol0
003oooooooooo`3oooooob[ooooo003looooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000002cooooo00?o0000oooooooo
ool0ooooool=ooooo`00o?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`3oooooo`cooooo003looooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`3oooooodgooooo003l
ooooo`;o00007Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool01_ooool2o`0000Gooooo00Co0000oooooooooooo0000ooooooliooooo`00o?ooool0
0ol0003oooooooooo`18ooooo`05o`000?ooooooooooooooool000006oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0?oooooo5oooool00?cooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0oooooolE
ooooo`00o?ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo00oooooo0ol0003ooooo
oc?ooooo003looooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0oooooollooooo`00
o?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool0
7?ooool01?l0003oooooooooool0000?ooooo`04o`000?ooooooooooo`000?oooooo:oooool00?co
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo0?oo
oooo5Oooool00?cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Zooooo`03o`00
0?oooooooooo01Cooooo00Co0000oooooooooooo0000ooooool[ooooo`00o?ooool2o`0004Sooooo
00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo00000?oooooo=Oooool00?cooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000?ooooo
00?o0000ooooooooool02Oooool00ol0003oooooo`00003ooooooaGooooo003looooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool04oooool01Ol0003ooooooooooooooooo000000Oooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo
7?ooool00?cooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`3oooooocGooooo003l
ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
oooooa[ooooo003Sooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c004ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`3ooooooe7ooooo003Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@04ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo0?oooooo
>?ooool00>?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
00001?ooool2o`0002[ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3ooooooc3o
oooo003Sooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q
00Cooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`3oooooobCooooo003Sooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Cooooo00?o0000
ooooooooool0LOooool00ol0003oooooooooo`3ooooooaSooooo003Sooooo`05oa0@4?oooooooooo
ooooool@41002oooool00omEEEGoQhN7ooooo`06ooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0?oooooo4oooool0
0>?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Kooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo0?oooooo<Oooool0
0>?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Cooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`3oooooofGooooo003looooo`03o`000?oooooo
oooo05[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo0?oooooo5_ooool00?cooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0?ooooooC_ooool00?cooooo0_l0000eooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`3ooooooacooooo003looooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo0?oooooo<Oooool00?cooooo00?o0000ooooooooool0BOooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo0_l0000?ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0oooooolFooooo`00o?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooood_ooooo003loooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0moooo
o`05o`000?ooooooooooooooool00000oooooolNooooo`00o?ooool00ol0003oooooooooo`3ooooo
ohcooooo003looooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo0?oooooo:oooool00?cooooo0_l0000^ooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`04ooooo`;o0000
oooooolNooooo`00o?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0?Oooool00ol0003oooooooooo`3ooooooa[ooooo003looooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0ooooool[ooooo`00o?ooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo03gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooo
ob3ooooo003looooo`03o`000?oooooooooo03kooooo00Co0000oooooooooooo00003?ooool00ol0
003oooooooooo`3ooooooc_ooooo003looooo`03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0oooooolYooooo`00o?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo0?oooooo
@Oooool00?cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0oooooolWooooo`00o?ooool2o`0002cooooo00?o0000
ooooool000004oooool00ol0003oooooooooo`3oooooodSooooo003looooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000ooooool_ooooo`00o?ooool00ol0003oooooooooo`3oooooohcooooo003looooo`03
o`000?oooooooooo0?ooooooS?ooool00?cooooo00?o0000ooooooooool0@_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooo0000017ooooo00?o0000ooooooooool0oooooolZooooo`00hooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<
c<`01?ooool00ol0003oooooooooo`3oooooohcooooo003Sooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@04ooooo`03o`000?oooooooooo
04Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3oooooocKooooo003Sooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000
ooooooooool0FOooool00ol0003oooooooooo`3ooooooc3ooooo003Sooooo`05o`000?oooooooooo
ooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Cooooo0_l0001<ooooo`;o0000oooo
ooloooooo`00hoooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000
olc<c004ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0oooooom7ooooo`00hooo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4004ooooo`03
o`000?oooooooooo053ooooo00?o0000ooooooooool0ooooooliooooo`00hoooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000004ooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`3oooooocCooooo003Sooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Cooooo00?o0000
ooooooooool0A?ooool00ol0003oooooo`00000;ooooo`03o`000?oooooooooo0?oooooo=oooool0
0?cooooo00?o0000ooooooooool0oooooon<ooooo`00o?ooool00ol0003oooooooooo`3oooooohco
oooo003looooo`;o0000oooooon=ooooo`00o?ooool00ol0003oooooooooo`3oooooohcooooo003l
ooooo`03o`000?oooooooooo0?ooooooS?ooool00?cooooo00?o0000ooooooooool0oooooon<oooo
o`00o?ooool00ol0003oooooooooo`3oooooohcooooo003looooo`03o`000?oooooooooo0?oooooo
S?ooool00?cooooo00?o0000ooooooooool0oooooon<ooooo`00o?ooool00ol0003oooooooooo`3o
ooooohcooooo003looooo`;o0000oooooon=ooooo`00o?ooool00ol0003oooooooooo`3oooooohco
oooo003looooo`03o`000?oooooooooo0?ooooooS?ooool00?cooooo00?o0000ooooooooool0oooo
oon<ooooo`00o?ooool00ol0003oooooooooo`3oooooohcooooo003looooo`03o`000?oooooooooo
0?ooooooS?ooool00?cooooo00?o0000ooooooooool0oooooon<ooooo`00o?ooool00ol0003ooooo
ooooo`3oooooohcooooo003looooo`;o0000oooooon=ooooo`00o?ooool00ol0003oooooooooo`3o
ooooohcooooo003looooo`03o`000?oooooooooo0?ooooooS?ooool00?cooooo00?o0000oooooooo
ool0oooooon<ooooo`00o?ooool00ol0003oooooooooo`3oooooohcooooo003dooooo`Co000000Go
410@ooooooooooooooooo`00003oooooohkooooo003fooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooon<ooooo`00m_ooool00ol0003oooooooooo`03ooooo`;o0000oooooon=
ooooo`00m_ooool00ol0003oooooooooo`3ooooooi;ooooo003fooooo`03o`000?oooooooooo0?oo
ooooT_ooool00?Kooooo00?o0000ooooooooool0oooooonBooooo`00m_ooool00ol0003ooooooooo
o`3ooooooi;ooooo003dooooo`03oeEEEOmVIVKo00000?ooooooU?ooool00?Sooooo0ol000000ol@
413oooooooooo`3oooooohgooooo003jooooo`03oa0@4?nj^[[ooooo0?ooooooS_ooool00?[ooooo
00?oV9RHoc8b<_ooool0oooooon>ooooo`00n_ooool00ooMgMgo0000okZj^P3oooooohkooooo003j
ooooo`03oeEEEOmgMgOoA4A40?ooooooS_ooool00?Wooooo00GogMgMoa0@4?oooooo8B4QomgMg@3o
ooooohgooooo003iooooo`05ofIVI_n7QhOooooooiRHV?mEEED0oooooon=ooooo`00n?ooool00oo^
k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo0?ooooooRoooool00?Sooooo00Co410@o`000?l0
003ooooo0_l000000ol@413oooooooooo`3ooooooh[ooooo003oooooooooooooS?ooool00?oooooo
oooooon<ooooo`00ooooooooooooohcooooo003oooooooooooooS?ooool00?oooooooooooon<oooo
o`00ooooooooooooohcooooo003oooooooooooooS?ooool00?oooooooooooon<ooooo`00oooooooo
ooooohcooooo003oooooooooooooS?ooool00?oooooooooooon<ooooo`00ooooooooooooohcooooo
003oooooooooooooS?ooool00?oooooooooooon<ooooo`00ooooooooooooohcooooo003ooooooooo
ooooS?ooool00?oooooooooooon<ooooo`00ooooooooooooohcooooo003oooooooooooooS?ooool0
0001\
\>"],
  ImageRangeCache->{{{0, 649.812}, {426.062, 0}} -> {-0.0764092, -0.0492291, \
0.00606487, 0.00606487}, {{15.75, 208.938}, {415.875, 222.688}} -> \
{-0.0826818, -0.0958102, 0.00656167, 0.00656167}, {{228.25, 421.5}, {415.875, \
222.688}} -> {-1.19775, -0.0956182, 0.00655937, 0.00655937}, {{440.812, \
634.062}, {415.875, 222.688}} -> {-3.05005, -0.181531, 0.00819518, \
0.00819518}, {{228.25, 421.5}, {203.312, 10.125}} -> {-1.65646, -1.57512, \
0.00819518, 0.00819518}}],

Cell[TextData[{
  "Fig. 7.10 To determine the force on a collection of particles, shown in \
the top picture, three steps must be carried out (bottom from left to right):\
\n(1) determine the density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_\(i\ j\)\)]],
  " on a grid, (2) determine the potential  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_\(\(\ \)\(i\ j\)\)\)]],
  "(and gradients) on the grid,  (3) interpolate forces back to the particle \
positions."
}], "Caption",
  CellTags->"Fig. 7.10"],

Cell[TextData[{
  " \tIn order to move the particles, we use the leapfrog method discussed in \
Chapter ",
  ButtonBox["1",
    ButtonData:>{"Chapter1.nb", "c:28"},
    ButtonStyle->"Hyperlink"],
  ". To solve Poisson's equation on the grid, we use the FFT method, which is \
fast and well adapted to periodic boundary conditions. "
}], "Text"],

Cell[TextData[{
  " \tThe more particles we keep, and the finer the grid, the finer the \
resolution of the simulation results. Density variations on a scale smaller \
than the grid will not be picked up.  This is an inherent limitation of grid \
methods: they work only if ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " is smooth compared to the grid spacing."
}], "Text"],

Cell["\<\
 \tOf course, this means that close interactions between individual \
stars are neglected in the PIC method. Since the density and potential are \
smoothed on the scale of the grid, and since this scale is large compared to \
an average interstellar spacing, the method cannot model the dynamics of \
binary star systems, and also neglects collisional effects such as \
hydrodynamic shocks. \
\>", "Text"],

Cell[TextData[{
  "\tAnother obvious limitation of our PIC method is that periodic boundary \
conditions are often poor approximations to the actual conditions in a \
self-gravitating system. For instance, to model an isolated galaxy, it would \
be more appropriate to impose the condition that the potential vanishes at \
infinity, or at least at some large distance from the galaxy. It is possible \
to modify the PIC method so as to account for such boundary conditions, by \
forgoing the use of the FFT method. In such situations, where a large region \
of the computational domain is empty, a uniform grid is highly inefficient.  \
Much recent progress has been made using time-varying nonuniform grids (",
  StyleBox["adaptive grids",
    FontSlant->"Italic"],
  "), chosen so that the grid is fine where there is rapid variation in the \
potential, and coarse outside of these regions. "
}], "Text",
  CellTags->"i:89"],

Cell[TextData[{
  "\t Recently, ",
  StyleBox["tree codes",
    FontSlant->"Italic"],
  " have also been applied to such problems with great success.  In a tree \
code, the potential is not determined on a grid. Rather, the force on a mass \
point is broken into two parts: one part due to nearby particles is treated \
exactly as a sum of pairwise interactions as in molecular dynamics, and the \
second part due to far-away particles is treated approximately as a multipole \
expansion of the far-away mass distribution.  Although these codes are quite \
complex compared to PIC, their overall efficiency is similar to that of the \
PIC method (",
  ButtonBox["Greengard, 1994",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  ")."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["7.3.3 Leapfrog Method", "Subsubtitle",
  CellTags->{"i:61", "c:30"}],

Cell[TextData[{
  "\tAs discussed in Chapter ",
  ButtonBox["1",
    ButtonData:>{"Chapter1.nb", "i:65"},
    ButtonStyle->"Hyperlink"],
  ", the leapfrog method is a second-order-accurate technique for integrating \
ODEs of the form ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{"\[DifferentialD]", 
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}], "/", \(\[DifferentialD]t\)}], " ", 
            "=", " ", 
            RowBox[{
              StyleBox["p",
                FontWeight->"Bold",
                FontSlant->"Plain"], "/", "m"}]}], ",", " ", 
          RowBox[{
            RowBox[{
              RowBox[{"\[DifferentialD]", 
                StyleBox["p",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}], "/", \(\[DifferentialD]t\)}], " ", 
            "=", " ", 
            RowBox[{
              StyleBox["f",
                FontWeight->"Bold",
                FontSlant->"Plain"], "(", 
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], ")"}]}]}], TraditionalForm]]],
  ",  where particle positions are evaluated at times ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(t\_n\), " ", "=", " ", 
            RowBox[{"n", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]]}]}], ",", " ", \(n = 0\), ",", 
          "1", ",", "2", ",", "..."}], TraditionalForm]]],
  ", and particle momenta are evaluated at the intermediate times ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(t\_\(n + 1/2\)\), "=", 
          RowBox[{\((n + 1/2)\), " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  ".  Positions are updated using the centered-difference form of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{"\[DifferentialD]", 
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], "/", \(\[DifferentialD]t\)}], "=", 
          RowBox[{
            StyleBox["p",
              FontWeight->"Bold",
              FontSlant->"Plain"], "/", "m"}]}], TraditionalForm]]],
  ", "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SubscriptBox[
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], "n"], "-", 
            SubscriptBox[
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], \(n - 1\)]}], "=", " ", 
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]], " ", 
            RowBox[{
              SubscriptBox[
                StyleBox["p",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], \(n - 1/2\)], "/", "m"}]}]}], 
        TraditionalForm]]],
  ". "
}], "UNNEQ"],

Cell[TextData[{
  "Momenta are updated using the centered difference form of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{"\[DifferentialD]", 
              StyleBox["p",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], "/", \(\[DifferentialD]t\)}], "=", 
          RowBox[{
            StyleBox["f",
              FontWeight->"Bold",
              FontSlant->"Plain"], "(", 
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], ")"}]}], TraditionalForm]]],
  ","
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SubscriptBox[
              StyleBox["p",
                FontWeight->"Bold",
                FontSlant->"Plain"], \(n + 1/2\)], "-", " ", 
            SubscriptBox[
              StyleBox["p",
                FontWeight->"Bold",
                FontSlant->"Plain"], \(n - 1/2\)]}], "=", " ", 
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]], " ", 
            RowBox[{
              StyleBox["f",
                FontWeight->"Bold",
                FontSlant->"Plain"], "(", 
              SubscriptBox[
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "n"], ")"}]}]}], TraditionalForm]]],
  ". "
}], "UNNEQ"],

Cell[TextData[{
  "We will define the initial positions for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(N\)\(\ \)\)\)]],
  "particles as a list ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], "o"], "=", 
          " ", \({{x\_1, y\_1}, \ {x\_2, y\_2},  ... , {x\_N, y\_N}}\)}], 
        TraditionalForm]]],
  ". The initial momenta are in a second list, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox["p",
              FontWeight->"Bold",
              FontSlant->"Plain"], "o"], 
          "=", \({{p\_\(x\_1\), p\_\(y\_1\)}, \ {p\_\(x\_2\), 
              p\_\(y\_2\)}, \(\(...\)\(.\)\), {p\_\(x\_N\), p\_\(y\_N\)}}\)}],
         TraditionalForm]]],
  ". \n\tAlthough initial conditions are provided for both ",
  Cell[BoxData[
      FormBox[
        StyleBox["r",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox["p",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " at time ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  ", the leapfrog method requires the momentum at time step ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], "/", "2"}], TraditionalForm]]],
  " in order to begin calculating ",
  Cell[BoxData[
      FormBox[
        StyleBox["r",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ". The momentum ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["p",
            FontWeight->"Bold",
            FontSlant->"Plain"], \(\(1/2\)\(\ \)\)], TraditionalForm]]],
  "can be found from the initial conditions  using a second-order accurate \
predictor-corrector step:\n\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SubscriptBox[
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], \(\(1/2\)\(\ \)\)], " ", "=", " ", 
            RowBox[{
              SubscriptBox[
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "o"], " ", "+", " ", 
              RowBox[{
                FractionBox[
                  SubscriptBox[
                    StyleBox["p",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "o"], "m"], " ", 
                RowBox[{
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["t",
                        FontSlant->"Italic"]}]], "/", "2"}]}]}]}], ",", "\n", 
          
          RowBox[{
            SubscriptBox[
              StyleBox["p",
                FontWeight->"Bold",
                FontSlant->"Plain"], \(\(1/2\)\(\ \)\)], "=", " ", 
            RowBox[{
              SubscriptBox[
                StyleBox["p",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "o"], " ", "+", " ", 
              RowBox[{\(1\/\(2  m\)\), 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox["f",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], "(", 
                      SubscriptBox[
                        StyleBox["r",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], "o"], ")"}], " ", "+", " ", 
                    RowBox[{
                      StyleBox["f",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], "(", 
                      SubscriptBox[
                        StyleBox["r",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], \(1/2\)], ")"}]}], ")"}], " ", 
                
                RowBox[{
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["t",
                        FontSlant->"Italic"]}]], "/", "2."}]}]}]}]}], 
        TraditionalForm]]]
}], "Text"],

Cell[TextData[{
  "The following module then runs the leapfrog method for ",
  Cell[BoxData[
      \(TraditionalForm\`N\_step\)]],
  " steps. Updated positions and momenta  are placed in lists ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], "n"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["p",
            FontWeight->"Bold",
            FontSlant->"Plain"], "n"], TraditionalForm]]],
  ",",
  " which have the same structure as ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], "o"], TraditionalForm]]],
  ". "
}], "Text"],

Cell[BoxData[{
    RowBox[{\(Clear["\<Global`*\>"];\), "\n"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{\(leapfrog[r0_, p0_, Nstep_, \[CapitalDelta]t_]\), " ", ":=", 
        " ", 
        RowBox[{"Module", "[", 
          RowBox[{\({}\), ",", "\[IndentingNewLine]", 
            StyleBox[\( (*\ initial\ conditions\ *) \),
              FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
            
            RowBox[{\(r[0]\  = \ r0\), ";", 
              "\[IndentingNewLine]", \(p[0]\  = \ p0\), ";", 
              "\[IndentingNewLine]", "\[IndentingNewLine]", 
              
              StyleBox[\( (*\ 
                  account\ for\ periodic\ boundary\ conditions\ *) \),
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(md[x_]\  := \ Mod[x, L]\), ";", 
              "\[IndentingNewLine]", \(r[
                  n_]\  := \((\ r[n]\  = Map[md, \ r1[n]])\)\  /; \ n > \ 0\),
               ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
              StyleBox[\( (*\ first\ half - step\ *) \),
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(r1[1/2]\  = \ 
                r0\  + \ p0\ \[CapitalDelta]t/\((2\ m)\)\), ";", 
              "\[IndentingNewLine]", \(p[1/2]\  = \ 
                p0\  + \ \(\[CapitalDelta]t\/\(4\ m\)\) \((f[r[0]]\  + \ 
                        f[r[1/2]])\)\), ";", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", 
              StyleBox[\( (*\ the\ leapfrog\ method\ *) \),
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(p[
                  n_]\  := \ \((p[n]\  = \ 
                      p[n - 1]\  + \ \[CapitalDelta]t\ f[r[n - 1/2]])\) /; \ 
                  n + 1/2 \[Element] Integers\  && \ n \[GreaterEqual] \ 1\), 
              ";", "\[IndentingNewLine]", \(r1[n_]\  := 
                r[n - 1]\  + \ \[CapitalDelta]t\ p[n - 1/2]/m\  /; 
                  n \[GreaterEqual] \ 1\), ";", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", 
              
              StyleBox[\( (*\ 
                  determine\ solution\ up\ to\ time\ step\ Nstep\ *) \),
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(Table[r[n], {n, 1, Nstep}]\), ";"}]}], 
          "]"}]}], ";"}]}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.66"],

Cell[TextData[{
  "Two details need to be mentioned. First, the function ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["f",
            FontWeight->"Bold",
            FontSlant->"Plain"], "(", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " determines the force on all ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " particles for given positions, with a structure of the form ",
  Cell[BoxData[
      \(TraditionalForm\`{{f\_\(1\ x\), f\_\(1\ y\)}, {f\_\(2\ x\), \ 
          f\_\(2\ y\)}, \(\(...\)\(.\)\), {f\_\(N\ x\), f\_\(N\ y\)}}\)]],
  ". We will specify this function in the next section. Second, the periodic \
boundary conditions  must be taken into account.  If a particle strays \
outside the box,  it is put back into the box on the other side using the ",
  StyleBox["Mod",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function. This function is applied to the entire vector of positions \
using ",
  StyleBox["Map",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ",
  StyleBox["Map ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "takes any function ",
  Cell[BoxData[
      \(TraditionalForm\`g(x)\)]],
  " and applies it to each element  of  the  vector ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], "=", 
          StyleBox[\({{x\_1, y\_1},  ... , {x\_N, y\_N}}\),
            FontWeight->"Plain"]}], TraditionalForm]]],
  " according to  "
}], "Text",
  CellTags->"i:60"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["Map",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["[",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            RowBox[{"g", ",", 
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], 
            StyleBox["]",
              FontFamily->"Courier",
              FontWeight->"Bold"]}], "=", 
          " ", \({g({x\_1, y\_1}),  ... , g({x\_N, y\_N})}\), " "}], 
        TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "Using ",
  StyleBox["Map",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " we can apply the ",
  StyleBox["Mod ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "function to all of the the particle positions in a single step, without \
needing a ",
  StyleBox["Table",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command. ",
  StyleBox["Map",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " works only with functions ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  " of a single variable, so we write the ",
  StyleBox["Mod ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "function (a function of two variables) in terms of a user-defined function \
",
  StyleBox["md",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", a function of a single variable."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["7.3.4 Force", "Subsubtitle",
  CellTags->"c:31"],

Cell[CellGroupData[{

Cell["Mass Density on the Grid", "Section",
  CellTags->"c:32"],

Cell[TextData[{
  "\tIn order to obtain the force field from given particle positions, we \
must first determine the density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_\(i\ j\)\)]],
  " on the ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " grid. The grid is defined by the following points:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{"x", "=", 
          RowBox[{"i", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`i = 0, 1, 2,  ... , M - 1\)]],
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"y", "=", 
            RowBox[{"j", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["y",
                    FontSlant->"Italic"]}]]}]}], ",", 
          FormBox[\(j = 0, 1, 2,  ... , M - 1\),
            "TraditionalForm"]}], TraditionalForm]]],
  ","
}], "UNNEQ"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], " ", "=", " ", 
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["y",
                  FontSlant->"Italic"]}]], " ", "=", " ", \(L/M\)}]}], 
        TraditionalForm]]],
  ". The points ",
  Cell[BoxData[
      \(TraditionalForm\`x = L\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y = L\)]],
  " are not kept in this grid, because  the periodic boundary conditions \
imply that these points are equivalent to ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y = 0\)]],
  " respectively."
}], "Text"],

Cell[TextData[{
  "Below, we choose values of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(L\)\(\ \)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " for use in some of the following examples. We assume that the particles \
have unit mass:"
}], "Text"],

Cell[BoxData[{
    \(\(M = 20;\)\), "\n", 
    \(\(L = 1;\)\), "\n", 
    \(\(\[CapitalDelta]x\  = \ \(\[CapitalDelta]y\  = \ L/M\);\)\), "\n", 
    \(\(m = 1;\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.67"],

Cell[TextData[{
  "\tFor given particle positions we determine ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_\(i\ j\)\)]],
  " using the technique of area weighting, also known as linear \
interpolation. This is only one of several methods one may use to obtain the \
density, but it is one of the most popular due to its relative simplicity and \
accuracy. For a discussion of other methods, see ",
  ButtonBox["Birdsall and Langdon, (1991)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text",
  CellTags->"i:88"],

Cell[TextData[{
  "\tA given particle at position ",
  Cell[BoxData[
      \(TraditionalForm\`{x, y}\)]],
  " falls inside one cell of the grid, as shown in Fig. ",
  ButtonBox["7.11",
    ButtonData:>"Fig. 7.11",
    ButtonStyle->"Hyperlink"],
  ". The four surrounding grid points are those closest to ",
  Cell[BoxData[
      \(TraditionalForm\`{x, y}\)]],
  ",  and are labeled ",
  Cell[BoxData[
      \(TraditionalForm\`\((i, j)\)\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\((i + 1, j)\)\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\((i, j + 1)\)\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\((i + 1, j + 1)\)\)]],
  ". The correct values of ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " can be determine using the ",
  StyleBox["Quotient",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function:"
}], "Text",
  CellTags->"i:58"],

Cell[TextData[Cell[BoxData[{
    FormBox[
      RowBox[{
        RowBox[{"i", "=", 
          RowBox[{
            StyleBox["Quotient",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["[",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            RowBox[{"x", ",", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]]}], 
            StyleBox["]",
              FontFamily->"Courier",
              FontWeight->"Bold"]}]}], ";"}], 
      TraditionalForm], "\[IndentingNewLine]", 
    FormBox[
      RowBox[{"j", "=", 
        RowBox[{
          RowBox[{
            StyleBox["Quotient",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["[",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            RowBox[{"y", ",", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["y",
                    FontSlant->"Italic"]}]]}], 
            StyleBox["]",
              FontFamily->"Courier",
              FontWeight->"Bold"]}], "."}]}], TraditionalForm]}]]], "NE3",
  CellTags->"(7.3.3)"],

Cell[TextData[{
  "However, the points ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(i\)\(+\)\(1\)\(\ \)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`j + 1\)]],
  " may actually be at ",
  Cell[BoxData[
      \(TraditionalForm\`i + 1 = M\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`j + 1 = M\)]],
  ". Consequently, we use the ",
  StyleBox["Mod ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "function to put these points back inside the correct range of ",
  Cell[BoxData[
      \(TraditionalForm\`i\ and\ j\)]],
  ", and call the results ",
  Cell[BoxData[
      \(TraditionalForm\`i\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`j\_1\)]]
}], "Text",
  CellTags->"i:59"],

Cell[TextData[Cell[BoxData[{
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{\(i\_1\), " ", "=", " ", 
            RowBox[{
              StyleBox["Mod",
                FontFamily->"Courier",
                FontWeight->"Bold"], 
              StyleBox["[",
                FontFamily->"Courier",
                FontWeight->"Bold"], \(i + 1, M\), 
              StyleBox["]",
                FontFamily->"Courier",
                FontWeight->"Bold"]}]}], ";"}], " "}], 
      TraditionalForm], "\[IndentingNewLine]", 
    FormBox[
      RowBox[{\(j\_1\), " ", "=", " ", 
        RowBox[{
          RowBox[{
            StyleBox["Mod",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["[",
              FontFamily->"Courier",
              FontWeight->"Bold"], \(j + 1; M\), 
            StyleBox["]",
              FontFamily->"Courier",
              FontWeight->"Bold"]}], "."}]}], TraditionalForm]}]]], "NE3",
  CellTags->"(7.3.4)"],

Cell[TextData[{
  "\tNow we must increment the density on these four grid points due to the \
presence of the particle. If we call this increment ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Rho]\_\(i\ j\)\)]],
  ",",
  " then we require that "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[Sum]\+\(i, j\)\), 
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["A",
                    FontSlant->"Italic"]}]], 
              " ", \(\[CapitalDelta]\[Rho]\_\(i\ j\)\)}]}], " ", "=", " ", 
          "m"}], TraditionalForm]]],
  ","
}], "NE3",
  CellTags->"(7.3.5)"],

Cell[TextData[{
  "where the sum is over all points on the grid, and where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["A",
                FontSlant->"Italic"]}]], "=", 
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]], " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["y",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  " is the area of a cell.  One way to satisfy Eq. ",
  ButtonBox["(7.3.5)",
    ButtonData:>{"Chapter7.nb", "(7.3.5)"},
    ButtonStyle->"Hyperlink"],
  "  would be to weight equally each of the four grid points surrounding the \
particle : ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[CapitalDelta]\[Rho]\_\(i\ j\)\), " ", "=", " ", 
          RowBox[{"m", "/", 
            RowBox[{"(", 
              RowBox[{"4", " ", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["A",
                      FontSlant->"Italic"]}]]}], 
              StyleBox[")",
                FontSlant->"Italic"]}]}]}], TraditionalForm]]],
  " for the four surrounding grid points, and ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Rho]\_\(i\ j\) = 0\)]],
  " for the other points.   However, this equal weighting is crude. What if \
the particle is very close to one of the grid points? This grid point should \
then get the lion's share of the particle's mass."
}], "Text"],

Cell[TextData[{
  "\tIn area weighting,  that portion of the mass ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " that is assigned to each of the four grid points  depends on the distance \
of the particle to the points. For instance, if the particle is right at the \
center of the cell, all four surrounding grid points get ",
  Cell[BoxData[
      \(TraditionalForm\`m/4\)]],
  ". However, if the particle is closest to the point ",
  Cell[BoxData[
      \(TraditionalForm\`\((i, j)\)\)]],
  " as shown in Fig. ",
  ButtonBox["7.11",
    ButtonData:>"Fig. 7.11",
    ButtonStyle->"Hyperlink"],
  ", this grid point is given more of the particles mass than the other \
points, according to the following prescription: break the cell into four \
rectangles as shown, each with a vertex at ",
  Cell[BoxData[
      \(TraditionalForm\`{x, y}\)]],
  ". Call the areas of these rectangles ",
  Cell[BoxData[
      \(TraditionalForm\`A\_1\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`A\_4\)]],
  ". These areas can be determined in terms of the length of the rectangle \
sides, ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[Delta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[Delta]", 
            StyleBox["y",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox[
            RowBox[{"\[Delta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], "1"], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox[
            RowBox[{"\[Delta]", 
              StyleBox["y",
                FontSlant->"Italic"]}]], "1"], TraditionalForm]]],
  "where"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[
            RowBox[{"\[Delta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], " ", "=", " ", 
          RowBox[{
            StyleBox["Mod",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["[",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            RowBox[{"x", ",", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]]}], 
            StyleBox["]",
              FontFamily->"Courier",
              FontWeight->"Bold"]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{
          StyleBox[
            RowBox[{"\[Delta]", 
              StyleBox["y",
                FontSlant->"Italic"]}]], " ", "=", " ", 
          RowBox[{
            StyleBox["Mod",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["[",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            RowBox[{"y", ",", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["y",
                    FontSlant->"Italic"]}]]}], 
            StyleBox["]",
              FontFamily->"Courier",
              FontWeight->"Bold"]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{
          SubscriptBox[
            StyleBox[
              RowBox[{"\[Delta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]], "1"], " ", "=", " ", 
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]], " ", "-", " ", 
            StyleBox[
              RowBox[{"\[Delta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{
          SubscriptBox[
            StyleBox[
              RowBox[{"\[Delta]", 
                StyleBox["y",
                  FontSlant->"Italic"]}]], "1"], " ", "=", " ", 
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["y",
                  FontSlant->"Italic"]}]], "-", 
            RowBox[{
              StyleBox[
                RowBox[{"\[Delta]", 
                  StyleBox["y",
                    FontSlant->"Italic"]}]], "."}]}]}]}], 
      TraditionalForm]]]], "NE3",
  CellTags->"(7.3.6)"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .75456 
%%ImageSize: 713 538 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00133574 0.0179657 0.00133574 [
[ 0 0 0 0 ]
[ 1 .75456 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .75456 L
0 .75456 L
closepath
clip
newpath
% Start of gray image
p
.02381 .01797 translate
.95238 .71862 scale
713 string
713 538 8 [713 0 0 538 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
0000000000FFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFF0000000000
000000FFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000
00FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFF0000000000
000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFF00FFFFFFFFFFFFFFFFFF0000000000
0000FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000000000FFFFFFFFFF000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF00FFFFFFFFFFFFFFFFFF00000000
0000FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFF000000FFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF00FFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF00
00000000FFFFFFFFFFFFFFFFFFFF000000FFFFFFFF00000000000000FFFFFFFFFFFFFF00
00000000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00000000FFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF000000FFFFFF00FFFFFFFFFFFFFF00
000000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFF000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF0000
000000FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF0000FFFFFFFFFFFF00
000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFF000000FFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF000000000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF0000
000000FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF0000FFFFFFFFFF00
000000FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFF
FFFFFFFFFFFFFFFF000000FFFFFFFF00000000000000FFFFFFFFFFFFFF0000000000FFFF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF0000
000000FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF00FFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFF000000FFFFFF00FFFFFFFFFFFFFF00000000FFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF0000FFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF0000FFFFFFFFFFFF00000000FFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF0000FFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF0000FFFFFFFFFF00000000FFFFFF
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF0000FF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF00FFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF0000FF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF0000FFFFFF00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF0000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF0000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF0000FFFF00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF0000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF0000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF0000FF00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF0000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF0000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF0000FF00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF0000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF00
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF00
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF00000000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF00
00000000FFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF00000000
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF00
00000000FFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00000000FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF0000000000
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF00000000FF
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF000000000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00000000FFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFF000000FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF00000000FF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00000000000000FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF0000000000FFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00000000FFFFFFFF000000000000FFFFFFFFFF000000FFFF00000000FFFF
FFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF00000000FFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000000000FFFFFFFFFFFFFFFF000000000000FFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF000000
FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF0000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFF000000000000FFFFFFFFFF000000FFFF00000000FFFFFFFFFFFFFF00
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000000000000000FFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFF
FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00000000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFF0000000000000000
0000FFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFF0000
00000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00000000000000FFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFF00000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000FFFFFFFFFFFFFFFFFFFFFF
FF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFF000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF0000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF0000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FF00000000FFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFF
FFFF0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFF0000FFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF
FFFF000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF
FF00000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFF000000000000FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000000000000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000
00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000
0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000
00000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF0000000000000000000000
0000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
00000000FFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF0000000000000000000000
0000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
00000000FFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF0000000000000000000000
0000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
00000000FFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFF00000000000000000000
0000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
00000000FFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000
00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFF00000000000000FFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFF
FFFF0000000000FFFF0000FFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF000000FFFFFF00FFFFFFFFFF
FFFF00000000FFFFFFFF00FFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFF00000000FFFFFFFFFF00FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFF00000000FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00000000FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00000000FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00000000FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFF000000FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000000000FFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF000000
00FFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
0000000000FFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
00FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
00000000000000FFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00000000FFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000
00000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000
00000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000
00000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFF0000000000000000
0000FFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
00FFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFF00000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000FFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFF00000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF00000000
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFF000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF0000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF0000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF0000000000FFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFF0000000000FFFF
FFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF000000000000FFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000FFFFFF
FFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFF
FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFF
FFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF
FFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFF
FFFF0000000000000000FFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFF
FFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFF00FFFFFFFFFFFF
FFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF00FFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF
FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF00FFFFFFFF
FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF
FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF0000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF000000000000000000000000000000000000
0000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF
FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF0000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF000000000000000000000000000000000000
0000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF0000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000FFFFFFFFFF000000000000000000000000000000000000
0000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF000000
0000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF000000
0000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFF000000
0000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{187.125, 141},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003Y0000/2000`400?l00000o`00003ojOooool0
0>Wooooo003Yooooo`00jOooool00>Wooooo003Yooooo`001oooool`0?ooo`040:ZZZP0000000000
0;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP0000000000
0;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP0000000000
0;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP0000000000
0;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP0000000000
0;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP0000000000
0;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP0000000000
0;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP0000000000
0;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP0000000000
0;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP0000000000
0;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP0000000000
0;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP0000000000
0;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP0000000000
0;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001ooooolS0?ooo`80ZZZZ2`3oool0102Z
ZZX000000000002o_kmO0?ooo`030410@0000000EEEE02@0oooo00<0EEEE0>?Sh`3oool07`3oool6
ooooo`001ooooolG0?ooo`030;no_`2EUID0oooo00H0oooo00H0_kno0?ooo`3oool0oooo02/[:`2Z
ZZX30?ooo`030=CDe02EUID0oooo00@0oooo00@0ZZZZ000000000000_knoBP3oool0102_[jl00000
06YZJP3De=@A0?ooo`030410@0000000EEEE00D0oooo00<0T92@0>[ZjP3oool0603oool01`3De=@0
j^[Z0?ooo`3oool0eMGE01DE5@3_knl00P3oool00`3Zj^X0UIFE0>o_k`0J0?ooo`Kooooo0007oooo
oaH0oooo00<0_kno0:ZZZP3oool01`3oool01P3Shn<0LG5a0?ooo`3oool0SXj>01`L70@0oooo00<0
hn?S09FEU@3oool00`3oool0102ZZZX000000000002o_km;0?ooo`030000002ZZZX0oooo0140oooo
00<0@4100000001EEED0103oool00`1aLG40j^[Z0?ooo`0J0?ooo`06075aL@3Zj^X0oooo0?ooo`0i
>CT0UIFE103oool00`20P800oooo0?ooo`0H0?ooo`Kooooo0007oooooaH0oooo00<0@4100?ooo`3o
ool0203oool01P2>SXh0a/K60?ooo`3Shn<000000<K6aP@0oooo00<0JVYZ0:ZZZP3oool00P3oool0
102ZZZX000000000002o_km;0?ooo`030000002ZZZX0oooo0140oooo00<0@4100000001EEED00`3o
ool00`1aLG40SXj>0?ooo`0K0?ooo`060>?Sh`2EUID0oooo0?ooo`2>SXh0EEEE103oool00`2ZZZX0
EEEE0?ooo`0H0?ooo`Kooooo0007oooooaD0oooo00<0LG5a0820P03oool00P3oool00`2ZZZX00000
08j>SP020?ooo`040=GEe@0L71`000000:ZZZP80oooo00<071`L075aL@3oool00`3oool00`2o_kl0
71`L0?ooo`020?ooo`040:ZZZP00000000000;no_`@0oooo00<0j^[Z0:ZZZP2ZZZX00`3oool00`2Z
ZZX0hn?S0?ooo`020?ooo`030:ZZZP3oool0oooo03T0oooo00<000000:ZZZP3oool04@3oool00`10
@400000005EEE@020?ooo`030<K6aP000000oooo00<0oooo00<0>CTi0410@03Shn<01@3oool00`1E
EED0ZZZZ0?ooo`050?ooo`060:ZZZP1EEED0000003Ti>@2ZZZX0hn?S0P3oool00`0i>CT000000820
P0020?ooo`030<K6aP0E5AD0oooo00@0oooo00<000000<K6aP3oool05`3oool6ooooo`001ooooolD
0?ooo`030>[ZjP000000_kno00<0oooo00P0X:2P0000003Zj^X0_kno0?ooo`3_knl0@41006][J`<0
oooo00<0P82002/[:`3oool0103oool01@000000UIFE0?ooo`3oool0ZZZZ008000000180_kno0?oo
o`3oool0oooo09FEU@0`<300j^[Z0?ooo`2ZZZX0P8200?ooo`000000EEEE0=oOg`3oool0P82001DE
5@20P80X0?ooo`090=oOg`2EUID0_kno0;no_`3De=@0oooo0=GEe@20P800j^[Z0080oooo00<0_kno
09FEU@3_knl0103oool00`000000ZZZZ0?ooo`0A0?ooo`030410@0000000EEEE0080oooo00<0@410
05EEE@3oool00`3oool0100[:b/0P8200;no_`3Zj^X40?ooo`0305EEE@2ZZZX0oooo00L0oooo00<0
00000:ZZZP3oool00`3oool00`1ZJVX0EEEE0=oOg`030?ooo`03020P803EeMD0oooo00<0oooo00<0
EEEE0410@03oool05`3oool6ooooo`001ooooolD0?ooo`030:ZZZP000000j^[Z00<0oooo00@0eMGE
00000036a/H0hn?S1`3oool00`36a/H000000=GEe@040?ooo`0505EEE@0i>CT0oooo0?ooo`2ZZZX0
0P0000001P2o_kl0oooo0?ooo`3oool000000820P0<0oooo00X0JVYZ075aL@3oool0oooo09FEU@3o
ool0EEEE075aL@3oool0ZZZZ9`3oool02@0E5AD0ZZZZ0?ooo`3oool0ZZZZ0820P02ZZZX071`L05EE
E@020?ooo`0301`L701EEED0UIFE00@0oooo00<000000:ZZZP3oool04@3oool00`10@400000005EE
E@020?ooo`030000002>SXh0oooo00<0oooo00@0LG5a05EEE@3oool0hn?S103oool00`1EEED0ZZZZ
0?ooo`070?ooo`030000002ZZZX0oooo00T0oooo00<0EEEE075aL@3oool00`3oool00`2ZZZX00000
0>?Sh`0G0?ooo`Kooooo0007oooooa@0oooo00<0EEEE0000003oool0103oool00`0L71`0SXj>0?oo
o`080?ooo`0301`L702ZZZX0oooo00<0oooo00D0EEEE0000003oool0oooo0:ZZZP02000000060;no
_`3oool0oooo0:ZZZP000000UIFE0`3oool0202o_kl000000>?Sh`3oool0_kno0:ZZZP000000ZZZZ
:03oool00`2ZZZX000000?ooo`030?ooo`0:02/[:`36a/H0oooo0>?Sh`2ZZZX0oooo00000036a/H0
eMGE0>?Sh`<0oooo00<000000:ZZZP3oool04@3oool01`10@400000005EEE@3oool0_kno0000002Z
ZZX0103oool00`36a/H0:b/[0?ooo`050?ooo`0305EEE@2ZZZX0oooo00L0oooo00<000000:ZZZP3o
ool02@3oool00`2EUID0>CTi0?ooo`030?ooo`030:ZZZP000000ZZZZ01L0oooo1_ooool000Oooooo
503oool00`1EEED000000?ooo`040?ooo`80EEEE2@3oool00`1EEED0JVYZ0?ooo`030?ooo`0505EE
E@000000oooo0?ooo`2ZZZX00P0000001P2o_kl0oooo0?ooo`3Shn<000000820P0<0oooo00<0eMGE
0000002>SXh00P3oool00`1aLG4000000>?Sh`0X0?ooo`0305EEE@0E5AD0oooo00<0oooo00L0P820
03Ti>@3oool0oooo09FEU@2>SXh0000000D0oooo00<0j^[Z0000002ZZZX04P3oool01`10@4000000
05EEE@3oool0_kno0000002ZZZX01@3oool010000000oooo0?ooo`1EEED8000000030:ZZZP3oool0
oooo0080oooo00<000000:ZZZP3oool02@3oool00`2o_kl000000>?Sh`030?ooo`030:ZZZP000000
ZZZZ01L0oooo1_ooool000Oooooo503oool00`1EEED000000?ooo`040?ooo`030;no_`000000j^[Z
00P0oooo00<0_kno030`<03oool00`3oool01@1EEED000000?ooo`3oool0ZZZZ0080000000H0_kno
0?ooo`3oool0oooo02/[:`1`L7040?ooo`060000001EEED0oooo0?ooo`2EUID00000:@3oool00`2E
UID000000?ooo`030?ooo`050:2PX0000000eMGE0?ooo`3_knl00P10@4050?ooo`030;no_`1EEED0
ZZZZ0180oooo00L0@4100000001EEED0oooo0;no_`000000ZZZZ00D0oooo00<0D51@09FEU@3oool0
103oool00`1EEED0ZZZZ0?ooo`070?ooo`030000002ZZZX0oooo00X0oooo00<05ADE09FEU@3oool0
0P3oool00`2ZZZX000000:ZZZP0G0?ooo`Kooooo0007oooooa@0oooo00<0SXj>0000003oool01@3o
ool00`0L71`0ZZZZ0?ooo`080?ooo`030000003Shn<0oooo0080oooo00D0>CTi05EEE@3oool0oooo
0:ZZZP02000000060;no_`3oool0oooo0?ooo`2ZZZX0:b/[103oool01`000000EEEE0?ooo`3oool0
EEEE01`L702ZZZX0:03oool00`3Shn<000000>?Sh`030?ooo`030;no_`000000ZZZZ0080oooo00<0
>CTi05EEE@3oool06@3oool01`10@400000005EEE@3oool0j^[Z0000002ZZZX01@3oool00`2EUID0
EEEE0?ooo`040?ooo`0305EEE@2ZZZX0oooo00L0oooo00<000000:ZZZP3oool02P3oool00`1EEED0
>CTi0?ooo`020?ooo`0308j>SP000000oooo01L0oooo1_ooool000Oooooo503oool00`36a/H00000
0;no_`040?ooo`030:ZZZP0L71`0EEEE00L0oooo00@0hn?S0:ZZZP0E5AD0ZZZZ0`3oool01@000000
SXj>0?ooo`3oool0ZZZZ0080000000<0_kno0?ooo`3oool00P3oool01`10@400ZZZZ0?ooo`3oool0
ZZZZ00000036a/H00P3oool01@000000SXj>08j>SP3EeMD0ZZZZ02L0oooo00<0@41008j>SP3oool0
0P3oool00`2o_kl000000:ZZZP020?ooo`030000000i>CT0hn?S01T0oooo00<0@4100000001EEED0
0P3oool00`0L71`0EEEE0?ooo`030?ooo`030>?Sh`1ZJVX0000000D0oooo00<0EEEE0:ZZZP3oool0
1`3oool00`000000ZZZZ0?ooo`090?ooo`030;no_`1EEED0000000<0oooo00<0EEEE03Ti>@3oool0
5`3oool6ooooo`001ooooolE0?ooo`0303Ti>@2EUID0oooo00@0oooo00<0hn?S0<K6aP3oool0203o
ool01`3EeMD0a/K60?ooo`3oool0eMGE0000003Shn<00P3oool0102ZZZX000000000002o_kl50?oo
o`0>075aL@2>SXh0ZZZZ02/[:`0i>CT0oooo0<K6aP2EUID000000>?Sh`3oool0EEEE00000036a/HV
0?ooo`030;no_`0L71`0hn?S0080oooo00X0JVYZ01`L703oool0oooo0;no_`000000hn?S075aL@3E
eMD0a/K65`3oool00`10@400000005EEE@020?ooo`0308j>SP0L71`0oooo00D0oooo00<0ZZZZ0?oo
o`3oool00`3oool00`1EEED0ZZZZ0?ooo`070?ooo`030000002ZZZX0oooo00/0oooo00H0ZZZZ0>?S
h`3oool0oooo01`L702>SXhH0?ooo`Kooooo0007oooooaD0oooo00<0eMGE051@D03oool04`3oool0
0`20P800ZZZZ0?ooo`020?ooo`040:ZZZP00000000000;no_`H0oooo00@0_kno0410@010@400j^[Z
<03oool03P3Zj^X0UIFE0:ZZZP20P800410@0:ZZZP3oool0_kno092@T01ZJVX0oooo0>[ZjP1PH600
EEEE5`3oool00`10@400000005EEE@030?ooo`030410@02ZZZX0oooo01@0oooo00<000000:ZZZP3o
ool03P3oool00`2o_kl0EEEE0?ooo`0H0?ooo`Kooooo0007oooooaH0oooo00<0_kno08j>SP3oool0
0`3oool00`36a/H00000075aL@080?ooo`0505EEE@0L71`0oooo0>?Sh`20P800103oool0102ZZZX0
00000000002o_kl50?ooo`050:ZZZP000000SXj>0?ooo`3Shn<0<P3oool00`1aLG40000009FEU@0P
0?ooo`030410@0000000EEEE00@0oooo00<0EEEE0>[ZjP3oool00`3oool201`L70`0oooo00@0ZZZZ
05EEE@000000ZZZZ2`3oool01@36a/H00000075aL@3oool0JVYZ01X0oooo1_ooool000Oooooo5`3o
ool20:ZZZP<0oooo00<0a/K60000001aLG40203oool0101EEED071`L0>?Sh`1aLG450?ooo`040:ZZ
ZP00000000000;no_`D0oooo00D0EEEE08j>SP3oool0oooo05EEE@0a0?ooo`0505EEE@0L71`0a/K6
0?ooo`3Shn<07`3oool00`10@400000005EEE@050?ooo`030820P03oool0oooo0080oooo0P0L71`=
0?ooo`030>?Sh`1EEED0ZZZZ00/0oooo00D0a/K60000001aLG40LG5a0>[ZjP0J0?ooo`Kooooo0007
oooooaP0oooo00<0hn?S0?ooo`3oool03P3oool00`36a/H0oooo0?ooo`040?ooo`040:ZZZP000000
00000;no_`D0oooo00D0hn?S05EEE@2ZZZX0P8200<K6aP0a0?ooo`050000003Shn<0oooo0>[ZjP1a
LG407`3oool00`10@400000005EEE@060?ooo`030>?Sh`3oool0oooo0200oooo0P3Shn<K0?ooo`Ko
oooo0007oooooc00oooo00@0ZZZZ000000000000_kno>`3oool01@2ZZZX0LG5a0:ZZZP20P800hn?S
01l0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP00000000000;no
_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool@0?ooo`0308j>SP1EEED0EEEE01d0
EEEE00@0>CTi000000000000@410G`1EEED00`0E5AD0000001`L700P05EEEBH0oooo1_ooool000Oo
oooo403oool00`1EEED000000000002S000002H0oooo1_ooool000Oooooo403oool00`1EEED00000
0000002S000002H0oooo1_ooool000Oooooo403oool00`3De=@0_kno0;no_`0M0;no_`0407moO`00
0000000008n?SaT0_kno00<0P8200:ZZZP2o_kl0@`2o_kl00`0`<30000000410@00P0;no_bH0oooo
1_ooool000Oooooo<03oool0102ZZZX000000000002o_klI0?ooo`030000002ZZZX0oooo04<0oooo
00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP00000000000;no_aT0oooo
00<000000:ZZZP3oool0@`3oool00`10@400000005EEE@160?ooo`Kooooo0007oooooc00oooo00@0
ZZZZ000000000000_kno6@3oool00`000000ZZZZ0?ooo`130?ooo`030410@0000000EEEE04H0oooo
1_ooool000Oooooo<03oool0102ZZZX000000000002o_klI0?ooo`030410@02o_kl0oooo04<0oooo
00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP00000000000;no_el0oooo
00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP00000000000;no_el0oooo
00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP00000000000;no_el0oooo
00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP00000000000;no_el0oooo
00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP00000000000;no_``0oooo
00<0ZZZZ0000001aLG400P2ZZZX00`3Shn<0oooo0?ooo`0b0?ooo`030410@0000000000000800000
00<0>CTi0?ooo`3oool04@3oool00`10@400000005EEE@160?ooo`Kooooo0007ooooobH0oooo00<0
ZZZZ0>[ZjP3oool01`3oool0102ZZZX000000000002o_kl<0?ooo`030=GEe@3Shn<0oooo0080oooo
00<0>CTi0>?Sh`3oool0<P3oool00`3Zj^X0>CTi0:ZZZP020:ZZZP0305EEE@3Shn<0oooo0140oooo
00<0@4100000001EEED0AP3oool6ooooo`001ooooolV0?ooo`0300000010@400hn?S00L0oooo00@0
ZZZZ000000000000_kno4@3oool00`1EEED0LG5a0?ooo`050?ooo`0305EEE@36a/H0oooo02/0oooo
00<0hn?S075aL@3oool00P3oool00`3Shn<0oooo0?ooo`0@0?ooo`030410@0000000EEEE04H0oooo
1_ooool000Oooooo9P3oool0102o_kl0oooo0;no_`2o_kl60?ooo`040:ZZZP00000000000;no_a00
oooo00<0kno_01DE5@1ZJVX01P3oool00`000000ZZZZ0?ooo`0/0?ooo`030>[ZjP20P800kno_01@0
oooo00<0@4100000001EEED0AP3oool6ooooo`001ooooolY0?ooo`030:ZZZP3Shn<0oooo00@0oooo
00D0ZZZZ000000000000_kno0?ooo`030:ZZZP040>[ZjP3oool0oooo0<K6aP@0ZZZZ0P3oool01@2Z
ZZX0SXj>02/[:`0L71`0hn?S00H0oooo00<000000:ZZZP3oool07P3oool30:ZZZP040>?Sh`3oool0
oooo0<K6aP@0ZZZZ103oool00`3Shn<0JVYZ0?ooo`0C0?ooo`030410@0000000EEEE04H0oooo1_oo
ool000Oooooo803oool00`3Shn<0ZZZZ0:ZZZP070?ooo`0305EEE@3oool0oooo00<0oooo00P0ZZZZ
000000000000_kno0?ooo`2>SXh000000:ZZZP@0oooo00@0P8200000000L71`0hn?S0`3oool00`2>
SXh0@4100>?Sh`070?ooo`030000002ZZZX0oooo01h0oooo00<0SXj>0000002ZZZX0103oool0102Z
ZZX0000001`L703Shn<50?ooo`0306YZJP36a/H0oooo0180oooo00<0@4100000001EEED0AP3oool6
ooooo`001ooooolO0?ooo`060820P00L71`0hn?S0?ooo`20P800ZZZZ1@3oool00`000000_kno0?oo
o`030?ooo`040:ZZZP00000000000;no_`80oooo00<0EEEE08j>SP3oool00`3oool00`2ZZZX00000
05EEE@050?ooo`0309FEU@1aLG40oooo02P0oooo00<0EEEE08j>SP3oool00`3oool00`3Shn<00000
05EEE@020?ooo`060=GEe@3oool0oooo0?ooo`20P800EEEE4`3oool00`10@400000005EEE@160?oo
o`Kooooo0007oooooal0oooo00<0410@0:ZZZP3oool00P3oool00`0[:b/0UIFE0?ooo`020?ooo`03
0:ZZZP000000_kno00@0oooo00@0ZZZZ000000000000_kno0P3oool00`3Zj^X0:b/[0>o_k`030?oo
o`060820P0000000ZZZZ0?ooo`3?cll0j^[Z0P3oool00`2_[jl000000?ooo`0X0?ooo`030>[ZjP0[
:b/0j^[Z00<0oooo00<0ZZZZ0000002ZZZX00P3oool01P20P800e=CD0?ooo`3De=@0<30`06YZJQ<0
oooo00<0@4100000001EEED0AP3oool6ooooo`001ooooolN0?ooo`030:ZZZP000000a/K600<0oooo
00<0ZZZZ0000003Shn<00P3oool0101aLG40>CTi0>[ZjP36a/H30?ooo`040:ZZZP00000000000;no
_`<0oooo00<0a/K605EEE@2ZZZX00P2ZZZX00`10@40000000<K6aP020?ooo`05075aL@2ZZZX0ZZZZ
01DE5@2>SXh0:P3oool00`36a/H0>CTi0:ZZZP020:ZZZP0305EEE@000000a/K60080oooo00H0eMGE
01`L70000000000001DE5@3Shn<C0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo7P3o
ool00`3Shn<000000:ZZZP030?ooo`030<K6aP000000SXj>0080oooo0P1EEED00`3oool0ZZZZ0?oo
o`020?ooo`040:ZZZP00000000000;no_`@0oooo00H0@41005EEE@1EEED0EEEE01DE5@0000040?oo
o`030>?Sh`2ZZZX0eMGE02`0oooo00H0EEEE0410@01EEED0EEEE01`L700000050?ooo`80ZZZZ5@3o
ool00`10@400000005EEE@160?ooo`Kooooo0007oooooal0oooo00<05ADE0:ZZZP3oool00`3oool0
2@000000EEEE0?ooo`3oool000000:ZZZP3oool0hn?S0<K6aP020?ooo`040:ZZZP00000000000;no
_`@0oooo00H0ZZZZ08j>SP3oool0oooo01DE5@0L71`c0?ooo`060>?Sh`1ZJVX0oooo0?ooo`0L71`0
5ADE703oool00`10@400000005EEE@160?ooo`Kooooo0007oooooal0oooo0P1EEED40?ooo`060000
001EEED0oooo0:ZZZP000000hn?S0P3oool0102>SXh0oooo0?ooo`2ZZZX2000000030;no_`3oool0
oooo00<0oooo00D0>CTi0>?Sh`3oool0000005EEE@0d0?ooo`0506YZJP3Shn<0oooo00000010@400
703oool00`10@400000005EEE@160?ooo`Kooooo0007oooooal0oooo00<0gmoO01DE5@2o_kl00P3o
ool01P2ZZZX000000:ZZZP3oool0EEEE0410@080oooo00D0_kno01DE5@3oool0oooo0:ZZZP020000
00030;no_`3oool0oooo00<0oooo00D0eMGE06YZJP2o_kl000000820P00?0?ooo`030820P03EeMD0
oooo0280oooo00D0gmoO06YZJP2o_kl00000061PH00L0?ooo`030410@0000000EEEE04H0oooo1_oo
ool000Oooooo8@3oool02@1aLG40SXj>09FEU@0L71`0>CTi0>?Sh`20P80000000:ZZZP020?ooo`05
075aL@0L71`0oooo0?ooo`2ZZZX00P0000000`2o_kl0oooo0?ooo`040?ooo`0408j>SP1EEED00000
0:ZZZPl0oooo00<000000:ZZZP3oool08`3oool0102>SXh0EEEE00000020P80L0?ooo`030410@000
0000EEEE04H0oooo1_ooool000Oooooo8P3oool0103Shn<0@41001`L703Shn<:0?ooo`040:ZZZP00
000000000;no_`L0oooo00<071`L0000003Shn<03`3oool00`000000ZZZZ0?ooo`0T0?ooo`0301`L
70000000ZZZZ01`0oooo00<0@4100000001EEED0AP3oool6ooooo`001ooooolQ0?ooo`030>?Sh`0L
71`0EEEE00`0oooo00@0ZZZZ000000000000_kno1`3oool00`36a/H000000?ooo`0?0?ooo`030000
002ZZZX0oooo02@0oooo00<0a/K60000002o_kl0703oool00`10@400000005EEE@160?ooo`Kooooo
0007ooooob40oooo00D0EEEE06YZJP3oool0oooo06YZJP0:0?ooo`040:ZZZP00000000000;no_`P0
oooo00<0P8200?ooo`3oool03P3oool00`2o_kl0j^[Z0?ooo`0U0?ooo`0306YZJP3_knl0oooo01/0
oooo00<0@4100000001EEED0AP3oool6ooooo`001ooooolQ0?ooo`050>?Sh`1EEED0ZZZZ075aL@36
a/H02P3oool0102ZZZX000000000002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oo
oooo<03oool0102ZZZX000000000002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oo
oooo<03oool0102ZZZX000000000002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oo
oooo<03oool0102ZZZX000000000002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oo
oooo<03oool0102ZZZX000000000002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oo
oooo<03oool0102ZZZX000000000002o_klI0?ooo`030:ZZZP3Shn<0oooo04<0oooo00<0@4100000
001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP00000000000;no_aT0oooo00<000000:ZZ
ZP3oool0@`3oool00`10@400000005EEE@160?ooo`Kooooo0007oooooc00oooo00@0ZZZZ00000000
0000_kno6@3oool00`000000ZZZZ0?ooo`130?ooo`030410@0000000EEEE04H0oooo1_ooool000Oo
oooo<03oool0102ZZZX000000000002o_klH0?ooo`040820P0000000EEEE0<K6aT<0oooo00<0@410
0000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP00000000000;no_aL0oooo00<0EEEE
0000000000000P0000000`3EeMD0oooo0?ooo`100?ooo`030410@0000000EEEE04H0oooo1_ooool0
00Oooooo<03oool0102ZZZX000000000002o_klF0?ooo`030:ZZZP000000000000<0000000<0P820
0?ooo`3oool0@03oool00`10@400000005EEE@160?ooo`Kooooo0007oooooc00oooo00D0ZZZZ0000
00000000<30`0410@0060?ooo`050;no_`10@400@4100410@02o_kl01@3oool01P2o_kl0@4100410
@010@400_kno06YZJPD0000000@0410@0410@010@400@4101P3oool01020P800@4100410@010@406
0?ooo`050;no_`10@400@4100410@02o_kl01@3oool01@2o_kl0@4100410@010@400L71`00H0oooo
00@0P8200410@010@400@4101P3oool01020P800@4100410@010@4060?ooo`090;no_`10@400@410
0410@020P800oooo0410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool01@2ZZZX000000000
0020P800ZZZZ00H0oooo00D0hn?S0:ZZZP2ZZZX0ZZZZ0>?Sh`050?ooo`060>?Sh`2ZZZX0ZZZZ0:ZZ
ZP3Shn<0ZZZZ1@000000101EEED0ZZZZ0:ZZZP2ZZZX60?ooo`040<K6aP2ZZZX0ZZZZ0:ZZZPH0oooo
00D0hn?S0:ZZZP2ZZZX0ZZZZ0>?Sh`050?ooo`050>?Sh`2ZZZX0ZZZZ0:ZZZP2o_kl01P3oool01036
a/H0ZZZZ0:ZZZP2ZZZX60?ooo`040<K6aP2ZZZX0ZZZZ0:ZZZPH0oooo00T0hn?S0:ZZZP2ZZZX0ZZZZ
0<K6aP3oool0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP00000000000;no
_aL0oooo00<071`L0000000000000P0000000`2o_kl0oooo0?ooo`100?ooo`030410@0000000EEEE
04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000002o_klH0?ooo`0406YZJP0i>CT0EEEE
0<K6aQ80oooo00<0000003Ti>@3Shn<0;P3oool00`10@400000005EEE@160?ooo`Kooooo0007oooo
oc00oooo00@0ZZZZ000000000000_kno7`3oool00`2EUID0_kno0?ooo`080?ooo`080>[ZjP3De=@0
oooo0?ooo`20P800j^[Z0;no_`3?cll40?ooo`030>[ZjP2EUID0j^[Z02H0oooo00<0@4100000001E
EED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP00000000000;no_aT0oooo00<000000:ZZZP3o
ool00P3oool00`1aLG40hn?S0?ooo`0:0?ooo`80ZZZZ103oool00`2ZZZX0oooo0?ooo`040?ooo`03
075aL@3Zj^X0oooo02@0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZ
ZP00000000000;no_aT0oooo00H000000:ZZZP3oool0oooo075aL@2>SXh=0?ooo`0305EEE@3oool0
oooo0080oooo00<0j^[Z08j>SP3oool0103oool00`3Shn<0@4100?ooo`0T0?ooo`030410@0000000
EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000002o_klI0?ooo`050000002ZZZX0
oooo0=GEe@0000000`3oool01`10@400EEEE0?ooo`3oool0eMGE0000001aLG400P3oool00`2>SXh0
0000000000050?ooo`030000003Shn<0oooo00@0oooo00<0@4100<K6aP3oool08`3oool00`10@400
000005EEE@160?ooo`Kooooo0007oooooc00oooo00@0ZZZZ000000000000_kno6@3oool01@10@400
_kno0?ooo`1`L700EEEE00<0oooo00`0X:2P0;no_`20P800oooo0820P010@400j^[Z09FEU@3oool0
ZZZZ0410@02ZZZX40?ooo`030<o?c`000000UIFE00D0oooo00<0P8200410@03oool08`3oool00`10
@400000005EEE@160?ooo`Kooooo0007oooooc00oooo00@0ZZZZ000000000000_kno703oool00`10
@400SXj>0?ooo`040?ooo`040<K6aP2ZZZX0EEEE0:ZZZPX0oooo00@0ZZZZ01`L703oool0ZZZZ103o
ool00`2o_kl000000>?Sh`0S0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0
102ZZZX000000000002o_klL0?ooo`030000002ZZZX0oooo00D0oooo00<0LG5a02/[:`36a/H02P3o
ool01020P800EEEE0?ooo`2ZZZX40?ooo`030;no_`000000ZZZZ02<0oooo00<0@4100000001EEED0
AP3oool6ooooo`001oooool`0?ooo`040:ZZZP00000000000;no_a`0oooo00<000000:ZZZP3oool0
1P3oool00`000000oooo0?ooo`090?ooo`0505EEE@2>SXh0oooo0?ooo`2o_kl00`3oool00`2o_kl0
00000:ZZZP0S0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX00000
0000002o_klL0?ooo`030000002ZZZX0oooo00D0oooo00<0a/K60000003oool02P3oool01@0E5AD0
a/K60?ooo`3oool0ZZZZ00<0oooo00<0_kno0000002ZZZX08`3oool00`10@400000005EEE@160?oo
o`Kooooo0007oooooc00oooo00@0ZZZZ000000000000_kno703oool00`0P8200ZZZZ0?ooo`050?oo
o`030820P010@400P82000T0oooo00<0eMGE020P803oool00P3oool01`1PH600oooo0?ooo`3oool0
[jn_0000003Zj^X08`3oool00`10@400000005EEE@160?ooo`Kooooo0007oooooc00oooo00@0ZZZZ
000000000000_kno703oool205EEE@@0oooo00P0a/K60>?Sh`0i>CT0UIFE0>?Sh`0i>CT071`L09FE
U@@0oooo00@0hn?S0:ZZZP0L71`0JVYZ0P3oool00`2ZZZX000000?ooo`020?ooo`030820P00i>CT0
oooo02<0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP0000000000
0;no_aT0oooo00D0EEEE0<K6aP3oool0ZZZZ01`L70050?ooo`030<K6aP2ZZZX0j^[Z0080oooo00<0
ZZZZ0>[ZjP3oool01@3oool00`2ZZZX0eMGE0?ooo`020?ooo`060;no_`3oool0oooo0?ooo`1EEED0
SXj>903oool00`10@400000005EEE@160?ooo`Kooooo0007oooooc00oooo00@0ZZZZ000000000000
_kno6@3oool01P000000ZZZZ0?ooo`3oool071`L0<K6aQX0oooo00<0@4100?ooo`3oool08`3oool0
0`10@400000005EEE@160?ooo`Kooooo0007oooooc00oooo00@0ZZZZ000000000000_kno6@3oool0
1`000000ZZZZ0?ooo`3oool0j^[Z05EEE@3Zj^X0603oool00`1ZJVX0clo?0?ooo`0T0?ooo`030410
@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000002o_klI0?ooo`030000
002ZZZX0oooo00<0oooo00<0LG5a0>?Sh`3oool05@3oool00`1aLG40hn?S0?ooo`0U0?ooo`030410
@0000000EEEE04H0oooo1_ooool000Oooooo:`3oool30:ZZZP030<K6aP3oool0ZZZZ0080000000<0
_kno0?ooo`3oool07P3oool00`3Shn<0oooo0?ooo`0C0?ooo`80hn?S9`3oool00`10@400000005EE
E@160?ooo`Kooooo0007ooooob00oooo00<0a/K605EEE@36a/H0203oool00`3Zj^X0000008j>SP02
0?ooo`040:ZZZP00000000000;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001ooooolP
0?ooo`040;no_`1EEED0ZZZZ0<o?c`P0oooo00D000000:ZZZP3oool0oooo0:ZZZP02000000030;no
_`3oool0oooo00h0oooo00<0gmoO0820P03oool0<P3oool01@3Zj^X0X:2P0820P02ZZZX0j^[Z01D0
oooo00<0@4100000001EEED0AP3oool6ooooo`001ooooolS0?ooo`030;no_`36a/H0oooo00H0oooo
00D000000:ZZZP3oool0oooo0:ZZZP02000000030;no_`3oool0oooo00h0oooo00<0_kno0000003o
ool0<`3oool00`2o_kl000000?ooo`0F0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo
903oool00`2>SXh0oooo0?ooo`050?ooo`050000002ZZZX0oooo0?ooo`2ZZZX00P0000000`2o_kl0
oooo0?ooo`0>0?ooo`030;no_`000000oooo03<0oooo00<0_kno0000003oool05P3oool00`10@400
000005EEE@160?ooo`Kooooo0007oooooaX0oooo00D0eMGE075aL@2ZZZX0ZZZZ0<K6aP050?ooo`03
0:ZZZP1aLG40oooo00D0oooo00D000000:ZZZP3oool0oooo0:ZZZP02000000030;no_`3oool0oooo
00X0oooo00<0P820000000000000100000000`1EEED0oooo0?ooo`0`0?ooo`030;no_`000000oooo
01H0oooo00<0@4100000001EEED0AP3oool6ooooo`001ooooolI0?ooo`030>[ZjP0@4100_kno0080
oooo00<0_kno061PH03oool00`3oool00`20P800:b/[0;no_`050?ooo`050000002ZZZX0oooo0?oo
o`2ZZZX00P0000000`2o_kl0oooo0?ooo`0:0?ooo`060=oOg`3De=@0oooo0?ooo`2o_kl000001`3o
ool00`20P800eMGE0?ooo`0Z0?ooo`030;no_`000000oooo01H0oooo00<0@4100000001EEED0AP3o
ool6ooooo`001ooooolI0?ooo`0308j>SP000000oooo00<0oooo00<0EEEE08j>SP3oool00P3oool2
05EEE@030:ZZZP3oool0oooo00<0oooo00D000000:ZZZP3oool0oooo0:ZZZP02000000060;no_`3o
ool0>CTi0000001aLG40j^[Z0P3oool02`36a/H0@410000000000000SXj>0?ooo`3Shn<0a/K60?oo
o`2o_kl0000000L0oooo00<000000:ZZZP3oool0703oool0102>SXh00000075aL@3Shn<20?ooo`05
0=GEe@1EEED000000000001ZJVX00`3oool00`2o_kl000000?ooo`0F0?ooo`030410@0000000EEEE
04H0oooo1_ooool000Oooooo6@3oool00`1EEED05ADE0?ooo`030?ooo`030820P00L71`0oooo0080
oooo00@000000:ZZZP3oool0_kno0`3oool00`2ZZZX000000:ZZZP020?ooo`040:ZZZP0000000000
0;no_`80oooo00<071`L0:ZZZP3oool00`3oool00`2o_kl0000005EEE@030?ooo`040<K6aP3Shn<0
_kno000000L0oooo00<000000:ZZZP3oool07@3oool00`1EEED0ZZZZ0?ooo`040?ooo`800000103o
ool00`2o_kl000000?ooo`0F0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo6@3oool0
0`2ZZZX000000?ooo`030?ooo`090:ZZZP000000a/K60?ooo`3Zj^X000000<K6aP3oool0_kno00<0
oooo00<0j^[Z075aL@2ZZZX00P3oool0102ZZZX000000000002o_kl20?ooo`030<K6aP0i>CT0oooo
00<0oooo00<0P8200000002>SXh0103oool00`2ZZZX0_kno000000070?ooo`030000002ZZZX0oooo
01d0oooo00<0eMGE03Ti>@3oool00`3oool00`2ZZZX0000003Ti>@040?ooo`030;no_`000000oooo
01H0oooo00<0@4100000001EEED0AP3oool6ooooo`001ooooolI0?ooo`030>[ZjP000000eMGE00<0
oooo00H0_kno0000002ZZZX0oooo0:2PX00E5AD20?ooo`030<o?c`3EeMD0oooo00H0oooo00@0ZZZZ
000000000000_kno0`3oool00`1ZJVX0/;2`0?ooo`020?ooo`03071`L0000000ZZZZ00D0oooo00<0
Shn?0000003oool01P3oool00`20P800eMGE0?ooo`0N0?ooo`0306YZJP2EUID0oooo0080oooo00<0
UIFE0000001EEED00`3oool00`3Zj^X0P8200000000G0?ooo`030410@0000000EEEE04H0oooo1_oo
ool000Oooooo6P3oool00`1ZJVX0LG5a0?ooo`020?ooo`060:ZZZP000000a/K60?ooo`1ZJVX0LG5a
0P3oool00`3Zj^X0LG5a0?ooo`060?ooo`040:ZZZP00000000000;no_`@0oooo00<05ADE00000000
00000`0000060?ooo`030>[ZjP1EEED0oooo02P0oooo00<071`L0000000000000`0000000`2ZZZX0
oooo0?ooo`030?ooo`0308j>SP3oool0oooo01D0oooo00<0@4100000001EEED0AP3oool6ooooo`00
1ooooolJ0?ooo`030>[ZjP0i>CT0ZZZZ0080oooo00H0EEEE03Ti>@3oool0hn?S01DE5@36a/H20?oo
o`80EEEE1`3oool0102ZZZX000000000002o_kl40?ooo`0609FEU@36a/H0oooo0?ooo`0[:b/00000
<@3oool01`36a/H0LG5a0?ooo`3oool0>CTi0000002ZZZX07@3oool00`10@400000005EEE@160?oo
o`Kooooo0007oooooa`0oooo00@0ZZZZ08j>SP1EEED000000P36a/H00`2>SXh0EEEE0?ooo`020?oo
o`0309FEU@2ZZZX0oooo00H0oooo00@0ZZZZ000000000000_kno103oool01P3Zj^X0>CTi0?ooo`3o
ool0000005EEEC80oooo00<0EEEE0<K6aP3oool00P00000N0?ooo`030410@0000000EEEE04H0oooo
1_ooool000Oooooo703oool0103Zj^X0EEEE01DE5@2`/;0@0?ooo`040:ZZZP00000000000;no_`D0
oooo00D0ZZZZ0820P03EeMD0000006YZJP0b0?ooo`050>[ZjP10@400gmoO0000000E5AD07P3oool0
0`10@400000005EEE@160?ooo`Kooooo0007oooooa`0oooo00D071`L05EEE@3oool0oooo0:ZZZP0?
0?ooo`040:ZZZP00000000000;no_`H0oooo00@0LG5a08j>SP000000ZZZZ<`3oool01036a/H0JVYZ
0000001EEEDN0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo703oool01@0L71`0hn?S
0?ooo`2o_kl0SXj>00l0oooo00@0ZZZZ000000000000_kno1P3oool0103Shn<0000000000036a/Hd
0?ooo`0302/[:`000000LG5a01h0oooo00<0@4100000001EEED0AP3oool6ooooo`001ooooolL0?oo
o`040>?Sh`2>SXh0ZZZZ0:ZZZQ00oooo00@0ZZZZ000000000000_kno1`3oool00`2>SXh000000?oo
o`0?0?ooo`030000002ZZZX0oooo0280oooo00<0ZZZZ0000002ZZZX07P3oool00`10@400000005EE
E@160?ooo`Kooooo0007oooooc00oooo00@0ZZZZ000000000000_kno203oool00`1@D500oooo0?oo
o`0>0?ooo`030000002ZZZX0oooo02<0oooo00<0@4100=GEe@3oool07@3oool00`10@400000005EE
E@160?ooo`Kooooo0007oooooc00oooo00@0ZZZZ000000000000_kno203oool00`3Zj^X0oooo0?oo
o`0>0?ooo`030000002ZZZX0oooo02<0oooo00<0hn?S0?ooo`3oool07@3oool00`10@400000005EE
E@160?ooo`Kooooo0007oooooc00oooo00@0ZZZZ000000000000_kno6@3oool00`1EEED0a/K60?oo
o`130?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000002o
_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000002o
_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000002o
_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000002o
_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000002o
_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000002o
_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000002o
_klI0?ooo`030410@02o_kl0oooo04<0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`
0?ooo`040:ZZZP00000000000;no_aT0oooo00<000000:ZZZP3oool0@`3oool00`10@400000005EE
E@160?ooo`Kooooo0007oooooc00oooo00@0ZZZZ000000000000_kno6@3oool00`000000ZZZZ0?oo
o`130?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000002o
_klI0?ooo`030000002ZZZX0oooo04<0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`
0?ooo`040:ZZZP00000000000;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`
0?ooo`040:ZZZP00000000000;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`
0?ooo`040:ZZZP00000000000;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`
0?ooo`040:ZZZP00000000000;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`
0?ooo`040:ZZZP00000000000;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`
0?ooo`040:ZZZP00000000000;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`
0?ooo`040:ZZZP00000000000;no_aT0oooo00<0EEEE0<K6aP3oool0@`3oool00`10@400000005EE
E@160?ooo`Kooooo0007oooooc00oooo00@0ZZZZ000000000000_kno6@3oool00`000000ZZZZ0?oo
o`130?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000002o
_klI0?ooo`030000002ZZZX0oooo04<0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool@
0?ooo`0305EEE@00000000000:<000009P3oool6ooooo`001oooool@0?ooo`0305EEE@0000000000
0:<000009P3oool6ooooo`001oooool@0?ooo`0308j>SP1EEED0EEEE01d0EEEE00@0>CTi00000000
0000@410G`1EEED00`0E5AD0000001`L700P05EEEBH0oooo1_ooool000Oooooo<03oool0102ZZZX0
00000000002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX0
00000000002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX0
00000000002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX0
00000000002o_kmO0?ooo`030410@0000000EEEE02H0oooo00<0_kno0>?Sh`3oool07@3oool6oooo
o`001oooool`0?ooo`040:ZZZP00000000000;no_el0oooo00<0@4100000001EEED0203oool00`2>
SXh0oooo0?ooo`0K0?ooo`030>[ZjP0L71`0hn?S01H0oooo00<0eMGE0>?Sh`3oool0103oool6oooo
o`001oooool40?ooo`80j^[Z2@3oool00`3EeMD0Jf][0>[ZjP0F0?ooo`030>[ZjP3oool0oooo00D0
oooo00@0ZZZZ000000000000_knoG`3oool00`10@400000005EEE@060?ooo`030>[ZjP20P800j^[Z
01X0oooo00H0ZZZZ0;no_`3oool0oooo06YZJP1EEEDG0?ooo`0309FEU@2o_kl0oooo00<0oooo1_oo
ool000Oooooo0`3oool00`3Shn<0LG5a0?ooo`060?ooo`060:ZZZP3oool0oooo0?ooo`2>SXh0>CTi
5P3oool00`3Shn<0LG5a0?ooo`050?ooo`040:ZZZP00000000000;no_el0oooo00<0@4100000001E
EED01@3oool00`3Zj^X0>CTi0?ooo`0L0?ooo`06075aL@3Shn<0oooo0<K6aP000000hn?S5`3oool0
0`1aLG40ZZZZ0?ooo`020?ooo`Kooooo0007ooooo`80oooo00<0j^[Z075aL@3oool01`3oool01`3S
hn<0LG5a0?ooo`3oool0hn?S0000003EeMD05P3oool00`3Shn<0LG5a0?ooo`040?ooo`040:ZZZP00
000000000;no_el0oooo00<0@4100000001EEED01@3oool00`20P800SXj>0?ooo`020?ooo`030<K6
aP1EEED0hn?S00H0oooo00<0EEEE0?ooo`3oool0103oool01P3Zj^X0ZZZZ05EEE@1EEED0JVYZ0:ZZ
ZP80oooo00@0j^[Z075aL@0i>CT0ZZZZ0P3oool00`000000SXj>0?ooo`050?ooo`0308j>SP36a/H0
oooo00D0oooo00H0ZZZZ075aL@1EEED0EEEE0:ZZZP3Shn<30?ooo`030>?Sh`000000j^[Z0080oooo
1_ooool000Oooooo0P3oool00`1EEED0hn?S0?ooo`080?ooo`0608j>SP3EeMD0oooo0?ooo`0i>CT0
UIFE5`3oool00`2>SXh0P8200?ooo`030?ooo`040:ZZZP00000000000;no_el0oooo00<0@4100000
001EEED01@3oool00`0E5AD0hn?S0?ooo`020?ooo`0405EEE@000000SXj>0>[ZjPD0oooo00<00000
0?ooo`3oool01P3oool00`2>SXh000000;no_`030?ooo`040=GEe@00000000000>?Sh`80oooo0P1E
EED60?ooo`0305EEE@2ZZZX0oooo00H0oooo00<0hn?S00000020P8001P3oool0100i>CT0UIFE0?oo
o`3oool6ooooo`001oooool00`3oool0ZZZZ051@D0030?ooo`090=oOg`000000JVYZ0=GEe@3oool0
_kno01DE5@000000clo?0080oooo00<0P820051@D03oool01@3oool00`1EEED0_kno0?ooo`050?oo
o`060;no_`20P800000005EEE@2o_kl0j^[Z103oool00`0P8200j^[Z0?ooo`020?ooo`040:ZZZP00
000000000;no_el0oooo00<0@4100000001EEED0103oool00`2o_kl0410@0?ooo`030?ooo`040:ZZ
ZP000000j^[Z0<o?c`D0oooo00<000000?ooo`3oool01P3oool00`2ZZZX000000;no_`040?ooo`03
0;no_`3Zj^X0oooo0080oooo00<0ZZZZ0000003Zj^X01@3oool00`1EEED0ZZZZ0?ooo`070?ooo`03
00000020P800oooo00D0oooo00@0P820051@D03oool0oooo1_ooool000Oooooo00<0oooo03Ti>@20
P8000`3oool0203Zj^X000000:ZZZP36a/H0j^[Z0?ooo`1EEED0SXj>0`3oool00`3Shn<05ADE0?oo
o`050?ooo`0305EEE@2o_kl0oooo00L0oooo00<000000:ZZZP3oool01@3oool00`10@400SXj>0?oo
o`020?ooo`040:ZZZP00000000000;no_el0oooo00<0@4100000001EEED0103oool00`1aLG40@410
0?ooo`040?ooo`030000002ZZZX0oooo00D0oooo00<000000?ooo`3oool01P3oool00`2ZZZX00000
0;no_`0:0?ooo`030000002ZZZX0oooo00@0oooo00<0EEEE0:ZZZP3oool01`3oool00`000000P820
0?ooo`050?ooo`040:ZZZP000000oooo0?ooo`Kooooo0007ooooo`030?ooo`000000ZZZZ00@0oooo
00@071`L075aL@3oool0j^[Z1`3oool00`0E5AD0a/K60?ooo`040?ooo`0305EEE@2o_kl0oooo00L0
oooo00<000000:ZZZP3oool01@3oool00`20P800>CTi0?ooo`020?ooo`040:ZZZP00000000000;no
_el0oooo00<0@4100000001EEED0103oool00`1EEED0@4100?ooo`040?ooo`80EEEE0P3oool405EE
E@030000001EEED0EEEE0080EEEE103oool00`2ZZZX000000;no_`0:0?ooo`80EEEE00<0oooo08j>
SP1EEED00P1EEED00`0L71`0>CTi05EEE@0205EEE@030<K6aP3oool0oooo0080oooo00<000000820
P03oool01@3oool0102ZZZX000000?ooo`3oool6ooooo`001oooool00`2ZZZX000000;no_`040?oo
o`03075aL@0i>CT0oooo00P0oooo00<0EEEE08j>SP3oool0103oool00`1EEED0_kno0?ooo`070?oo
o`030000002ZZZX0oooo00D0oooo00<0P8200000003oool00P3oool0102ZZZX000000000002o_kmO
0?ooo`030410@0000000EEEE00@0oooo00<0EEEE0410@03oool0103oool0102>SXh071`L0?ooo`3o
ool40:ZZZP030000002ZZZX0ZZZZ0080ZZZZ103oool00`2ZZZX000000;no_`0:0?ooo`0408j>SP00
0000oooo0<K6aP<0ZZZZ00<0>CTi075aL@2ZZZX00P2ZZZX00`3Shn<0oooo0?ooo`020?ooo`030000
0020P800oooo00D0oooo00@0ZZZZ0000003oool0oooo1_ooool000Oooooo00<0ZZZZ0000002o_kl0
103oool00`2o_kl000000>[ZjP080?ooo`04092@T00[:b/0oooo0820P0<0@41000<05ADE030`<010
@4000P10@4000`2o_kl0oooo0?ooo`020?ooo`030000002ZZZX0oooo00D0oooo00<0P8200000003o
ool00P3oool0102ZZZX000000000002o_kmO0?ooo`030410@0000000EEEE00@0oooo00<0JVYZ0410
@03oool0103oool00`3Zj^X000000<o?c`050?ooo`030000003oool0oooo00H0oooo00<0ZZZZ0000
002o_kl02P3oool00`3Zj^X000000<o?c`040?ooo`0305EEE@2ZZZX0oooo00L0oooo00<000000820
P03oool01@3oool0102ZZZX0820P0?ooo`3oool6ooooo`001oooool00`2ZZZX000000;no_`050?oo
o`0301`L702>SXh0oooo00L0oooo00<0eMGE0000003Shn<0103oool00`1EEED0_kno0?ooo`070?oo
o`030000002ZZZX0oooo00D0oooo00<0P8200000003oool00P3oool0102ZZZX000000000002o_kmO
0?ooo`030410@0000000EEEE00@0oooo00<0ZZZZ01DE5@3oool01@3oool00`0i>CT0UIFE0?ooo`04
0?ooo`030000003oool0oooo00H0oooo00<0ZZZZ0000002o_kl02`3oool00`0L71`0P8200?ooo`03
0?ooo`0305EEE@2ZZZX0oooo00L0oooo00<000000820P03oool01@3oool205EEE@80oooo1_ooool0
00Oooooo00<0hn?S0000002o_kl01@3oool00`1aLG40EEEE0?ooo`080?ooo`030000002>SXh0oooo
00<0oooo00<0EEEE0;no_`3oool01`3oool00`000000ZZZZ0?ooo`050?ooo`0306YZJP1EEED0oooo
0080oooo00@0ZZZZ000000000000_knoG`3oool00`10@400000005EEE@050?ooo`0301DE5@3Shn<0
oooo00<0oooo00<0ZZZZ08j>SP2ZZZX01@3oool00`000000oooo0?ooo`060?ooo`030:ZZZP000000
_kno00T0oooo00@0hn?S0:ZZZP2>SXh0UIFE103oool00`1EEED0ZZZZ0?ooo`070?ooo`0300000020
P800oooo00D0oooo00@0>CTi09FEU@3oool0oooo1_ooool000Oooooo00<0oooo01`L7020P800103o
ool00`36a/H0EEEE000000080?ooo`030:ZZZP0L71`0EEEE00@0oooo00<0EEEE0;no_`3oool01`3o
ool00`000000ZZZZ0?ooo`050?ooo`030410@02>SXh0oooo0080oooo00@0ZZZZ000000000000_kno
G`3oool00`10@400000005EEE@050?ooo`0306YZJP2>SXh0oooo00/0oooo00<0ZZZZ0?ooo`3oool0
1P3oool00`2ZZZX000000;no_`0A0?ooo`030<K6aP3Shn<0oooo00L0oooo00<000000820P03oool0
103oool00`3Shn<071`L0>[ZjP020?ooo`Kooooo0007ooooo`030?ooo`2ZZZX0D51@00H0oooo00<0
_kno0?ooo`3oool01`3oool00`3Zj^X0_kno0?ooo`030?ooo`030820P03?cll0oooo00L0oooo00<0
00000:ZZZP3oool01@3oool00`0P8200j^[Z0?ooo`020?ooo`040:ZZZP00000000000;no_el0oooo
00<0@4100000001EEED01@3oool00`3_knl0EEEE0=GEe@040?ooo`030>[ZjP20P800j^[Z00/0oooo
00D0kno_0;no_`1oOgl000000;no_`0;0?ooo`030;no_`2@T900oooo00/0oooo0P2o_kl00`000000
P8200?ooo`040?ooo`0305EEE@2o_kl0oooo0080oooo1_ooool000Oooooo0P3oool00`10@400hn?S
0?ooo`0N0?ooo`030000002ZZZX0oooo00@0oooo00<0SXj>09FEU@3oool00`3oool0102ZZZX00000
0000002o_kmO0?ooo`030410@0000000EEEE00L0oooo00<0LG5a0>?Sh`3oool00P3oool00`2ZZZX0
00000:ZZZP0<0?ooo`040>?Sh`1aLG4000000;no_`/0oooo00<0EEEE0000003oool0303oool00`2>
SXh071`L0820P0040?ooo`03075aL@3Shn<0oooo00<0oooo1_ooool000Oooooo0P3oool00`3Zj^X0
EEEE0?ooo`040?ooo`0301`L701EEED0oooo00L0oooo00<0LG5a00000036a/H02`3oool0102ZZZX0
EEEE0000002ZZZX40?ooo`030>?Sh`1EEED0oooo00@0oooo00@0ZZZZ000000000000_knoG`3oool0
0`10@400000005EEE@080?ooo`030:ZZZP3oool0oooo0080oooo00<0ZZZZ0?ooo`3oool03@3oool0
0`3Shn<0j^[Z0?ooo`0:0?ooo`030>?Sh`2o_kl0oooo00h0oooo00H0eMGE0?ooo`3oool0oooo0;no
_`3Shn<50?ooo`Kooooo0007ooooo`<0oooo00<0hn?S075aL@3oool00`3oool00`0L71`0EEEE0?oo
o`070?ooo`03075aL@000000a/K600`0oooo00<0hn?S05EEE@2ZZZX00`3oool00`3Shn<0LG5a0?oo
o`050?ooo`040:ZZZP00000000000;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001ooo
ool50?ooo`030>[ZjP3oool0oooo0200oooo00<0e=CD0?ooo`3oool01@3oool0102ZZZX000000000
002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000
002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000
002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000
002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000
002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000
002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000
002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000
002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000
002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000
002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000
002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool00>Wooooo003Yooooo`00jOooool00>Wo
oooo0000\
\>"],
  ImageRangeCache->{{{2.3125, 232.875}, {175.25, 0}} -> {-25.3376, -15.5257, \
4.05886, 4.05886}}],

Cell["Fig. 7.11 Quantities associated with area weighting.", "Caption",
  CellTags->"Fig. 7.11"],

Cell["We then increment the density according to the formulae", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(\[CapitalDelta]\[Rho]\_\(i\ j\)\), " ", "=", 
          RowBox[{"m", " ", 
            RowBox[{\(A\_1\), "/", 
              RowBox[{"(", 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["A",
                        FontSlant->"Italic"]}]], "2"], ")"}]}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{\(\[CapitalDelta]\[Rho]\_\(i\ j\_1\)\), " ", "=", " ", 
          RowBox[{"m", " ", 
            RowBox[{\(A\_2\), "/", 
              RowBox[{"(", 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["A",
                        FontSlant->"Italic"]}]], "2"], ")"}]}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{\(\[CapitalDelta]\[Rho]\_\(\(i\_1\) j\_1\)\), " ", "=", " ", 
          RowBox[{"m", " ", 
            RowBox[{\(A\_3\), "/", 
              RowBox[{"(", 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["A",
                        FontSlant->"Italic"]}]], "2"], ")"}]}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{\(\[CapitalDelta]\[Rho]\_\(\(i\_1\) j\)\), " ", "=", " ", 
          RowBox[{"m", " ", 
            RowBox[{\(A\_4\), "/", 
              RowBox[{
                RowBox[{"(", 
                  SuperscriptBox[
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["A",
                          FontSlant->"Italic"]}]], "2"], ")"}], "."}]}]}]}]}],
       TraditionalForm]]]], "NE3",
  CellTags->"(7.3.7)"],

Cell[TextData[{
  "In other words, the density increment at point ",
  Cell[BoxData[
      \(TraditionalForm\`\((i, j)\)\)]],
  " is weighted by the area of the rectangle in the ",
  StyleBox["opposite corner",
    FontSlant->"Italic"],
  ".  The reasoning behind this type of weighting is as follows. First, one \
can see that Eq. ",
  ButtonBox["(7.3.5)",
    ButtonData:>{"Chapter7.nb", "(7.3.5)"},
    ButtonStyle->"Hyperlink"],
  "  is still satisfied, because ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Sum]\+\(i = 1\)\%4 A\_i\), "=", 
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["A",
                FontSlant->"Italic"]}]]}], TraditionalForm]]],
  ". Second, one can also see that the closer the particle is to a given grid \
point, the larger the area associated with that grid point,  and the more \
mass is assigned to that grid point."
}], "Text"],

Cell[TextData[{
  "\tAlso, this type of weighting can be easily applied to one- or \
three-dimensional grids. In fact, we have used a form of one-dimensional area \
weighting already, in a different context; see the discussion surrounding \
Fig. ",
  ButtonBox["6.11",
    ButtonData:>{"Chapter6.nb", "Fig. 6.11"},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  "The following module takes a single particle at position ",
  Cell[BoxData[
      \(TraditionalForm\`z = {x, y}\)]],
  " and  increments the density matrix ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_\(i\ j\)\)]],
  " according to Eq. ",
  ButtonBox["(7.3.6)",
    ButtonData:>{"Chapter7.nb", "(7.3.6)"},
    ButtonStyle->"Hyperlink"],
  " :"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(setden[z_]\), " ", ":=", " ", 
        RowBox[{"Module", "[", 
          
          RowBox[{\({x, y, \[Delta]x, \[Delta]y, \[Delta]x1, \[Delta]y1, i, 
              j, i1, j1}\), ",", "\[IndentingNewLine]", 
            StyleBox[\( (*\ x\ and\ y\ positions\ of\ particle\ *) \),
              FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
            
            RowBox[{\(x = z[\([1]\)]\), ";", \(y = z[\([2]\)]\), ";", 
              "\[IndentingNewLine]", 
              StyleBox[\( (*\ lengths\ of\ the\ rectangle\ sides\ *) \),
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(\[Delta]x = Mod[x, \[CapitalDelta]x]\),
               ";", "\[IndentingNewLine]", \(\[Delta]y = 
                Mod[y, \[CapitalDelta]y]\), ";", 
              "\[IndentingNewLine]", \(\[Delta]x1\  = \ \[CapitalDelta]x - \
\[Delta]x\), ";", 
              "\[IndentingNewLine]", \(\[Delta]y1\  = \ \[CapitalDelta]y - \
\[Delta]y\), ";", "\[IndentingNewLine]", 
              
              StyleBox[\( (*\ 
                  determine\ surrounding\ grid\ points\ \((values\ \
incremented\ by\ 1\ in\ accord\ with\ Mathematica\ list\ notation)\)\ *) \),
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(i\  = 
                Quotient[x, \[CapitalDelta]x] + 1\), ";", 
              "\[IndentingNewLine]", \(j = \ 
                Quotient[y, \[CapitalDelta]y] + 1\), ";", 
              "\[IndentingNewLine]", \(i1\  = \ 1 + Mod[i, M]\), ";", 
              "\[IndentingNewLine]", \(j1\  = \ 1 + Mod[j, M]\), ";", 
              "\[IndentingNewLine]", 
              StyleBox[\( (*\ increment\ the\ density\ *) \),
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(\[Rho][\([i, 
                    j]\)]\  = \ \[Rho][\([i, j]\)] + \[Delta]x1*\[Delta]y1\), 
              ";", "\[IndentingNewLine]", \(\[Rho][\([i, 
                    j1]\)]\  = \[Rho][\([i, j1]\)] + \[Delta]x1*\[Delta]y\), 
              ";", "\[IndentingNewLine]", \(\[Rho][\([i1, 
                    j]\)]\  = \ \[Rho][\([i1, 
                      j]\)] + \ \[Delta]x*\[Delta]y1\), ";", 
              "\[IndentingNewLine]", \(\[Rho][\([i1, 
                    j1]\)]\  = \ \[Rho][\([i1, j1]\)] + \[Delta]x*\[Delta]y\),
               ";"}]}], "]"}]}], ";"}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.68"],

Cell[TextData[{
  "Note that matrix indices are increased by 1 over those in Eqs. ",
  ButtonBox["(7.3.3)",
    ButtonData:>{"Chapter7.nb", "(7.3.3)"},
    ButtonStyle->"Hyperlink"],
  "  and ",
  ButtonBox["(7.3.4)",
    ButtonData:>{"Chapter7.nb", "(7.3.4)"},
    ButtonStyle->"Hyperlink"],
  " ,  in order to comply with list notation:  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\({i, j}\)\(\ \)\(=\)\(\ \)\({0, 0}\)\(\ \)\)\)]],
  "in the notation of Eq. ",
  ButtonBox["(7.3.3)",
    ButtonData:>{"Chapter7.nb", "(7.3.3)"},
    ButtonStyle->"Hyperlink"],
  "  corresponds to element ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[Rho][\([1, 1]\)]\),
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  " of the matrix ",
  Cell[BoxData[
      FormBox[
        StyleBox["\[Rho]",
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  ".   Also, note that this whole  procedure is applied to only one particle. \
We must now apply it to all the particles. Before we do so,  note that we did \
not divide the density increment by ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["A",
                FontSlant->"Italic"]}]], "2"], TraditionalForm]]],
  "; nor did we multiply by ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  ". That's because these factors are the same for every particle. It is more \
efficient to wait until we have incremented the density due to all the \
particles, then multiply the density matrix by these constant factors \
(assuming that there are more particles than grid points, as is usually the \
case).  The following module evaluates the density for given particle \
positions:"
}], "Text"],

Cell[BoxData[
    RowBox[{\(density[r_]\), " ", ":=", " ", 
      RowBox[{"Module", "[", 
        RowBox[{\({\[CapitalDelta]A}\), ",", "\[IndentingNewLine]", 
          StyleBox[\( (*area\ of\ a\ cell*) \),
            FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
          
          RowBox[{\(\[CapitalDelta]A = \[CapitalDelta]x*\[CapitalDelta]y\), 
            ";", "\[IndentingNewLine]", 
            StyleBox[\( (*initialize\ the\ density\ matrix*) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(\[Rho]\  = \ Table[0, {M}, {M}]\), ";", 
            "\[IndentingNewLine]", 
            
            StyleBox[\( (*increment\ the\ density\ for\ all\ N\ particles\ at\
\ once*) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(Map[setden, r]\), ";", 
            "\[IndentingNewLine]", 
            StyleBox[
              RowBox[{"(*", 
                RowBox[{
                "properly", " ", "normalize", " ", Cell[TextData[StyleBox[
                  "\[Rho]",
                    FontColor->RGBColor[1, 0, 0]]]]}], "*)"}],
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(\[Rho] = \[Rho]*m/\[CapitalDelta]A^2\), 
            " ", ";"}]}], "]"}]}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.69"],

Cell[TextData[{
  "We use the ",
  StyleBox["Map",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function in order to apply our function ",
  Cell[BoxData[
      FormBox[
        StyleBox["setden",
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  " to the list of positions  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[\({{x\_1, y\_1},  ... , {x\_N, y\_N}}\),
            FontWeight->"Plain"]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "\tAs a test of the module, in Cell ",
  ButtonBox["7.70",
    ButtonData:>"Cell 7.70",
    ButtonStyle->"Hyperlink"],
  " we evaluate the density due to 20 particles with unit mass, distributed \
uniformly along the diagonal of the domain."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(r = 
        Table[{\[CapitalDelta]x\ i, \[CapitalDelta]x\ i}, {i, 0, 
            M - 1}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(density[r];\)\), "\n", 
    \(\(ListContourPlot[\[Rho]];\)\ \), "\n", 
    \(Sum[\[CapitalDelta]x\ \[CapitalDelta]y\ \[Rho][\([i, j]\)], {i, 1, 
        M}, {j, 1, M}]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.70"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0313765 0.0506073 -0.0313765 0.0506073 [
[.09514 -0.0125 -9 -9 ]
[.09514 -0.0125 9 0 ]
[.22166 -0.0125 -3 -9 ]
[.22166 -0.0125 3 0 ]
[.34818 -0.0125 -9 -9 ]
[.34818 -0.0125 9 0 ]
[.4747 -0.0125 -6 -9 ]
[.4747 -0.0125 6 0 ]
[.60121 -0.0125 -12 -9 ]
[.60121 -0.0125 12 0 ]
[.72773 -0.0125 -6 -9 ]
[.72773 -0.0125 6 0 ]
[.85425 -0.0125 -12 -9 ]
[.85425 -0.0125 12 0 ]
[.98077 -0.0125 -6 -9 ]
[.98077 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .09514 -18 -4.5 ]
[-0.0125 .09514 0 4.5 ]
[-0.0125 .22166 -6 -4.5 ]
[-0.0125 .22166 0 4.5 ]
[-0.0125 .34818 -18 -4.5 ]
[-0.0125 .34818 0 4.5 ]
[-0.0125 .4747 -12 -4.5 ]
[-0.0125 .4747 0 4.5 ]
[-0.0125 .60121 -24 -4.5 ]
[-0.0125 .60121 0 4.5 ]
[-0.0125 .72773 -12 -4.5 ]
[-0.0125 .72773 0 4.5 ]
[-0.0125 .85425 -24 -4.5 ]
[-0.0125 .85425 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09514 0 m
.09514 .00625 L
s
[(2.5)] .09514 -0.0125 0 1 Mshowa
.22166 0 m
.22166 .00625 L
s
[(5)] .22166 -0.0125 0 1 Mshowa
.34818 0 m
.34818 .00625 L
s
[(7.5)] .34818 -0.0125 0 1 Mshowa
.4747 0 m
.4747 .00625 L
s
[(10)] .4747 -0.0125 0 1 Mshowa
.60121 0 m
.60121 .00625 L
s
[(12.5)] .60121 -0.0125 0 1 Mshowa
.72773 0 m
.72773 .00625 L
s
[(15)] .72773 -0.0125 0 1 Mshowa
.85425 0 m
.85425 .00625 L
s
[(17.5)] .85425 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(20)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.12045 0 m
.12045 .00375 L
s
.14575 0 m
.14575 .00375 L
s
.17105 0 m
.17105 .00375 L
s
.19636 0 m
.19636 .00375 L
s
.24696 0 m
.24696 .00375 L
s
.27227 0 m
.27227 .00375 L
s
.29757 0 m
.29757 .00375 L
s
.32287 0 m
.32287 .00375 L
s
.37348 0 m
.37348 .00375 L
s
.39879 0 m
.39879 .00375 L
s
.42409 0 m
.42409 .00375 L
s
.44939 0 m
.44939 .00375 L
s
.5 0 m
.5 .00375 L
s
.5253 0 m
.5253 .00375 L
s
.55061 0 m
.55061 .00375 L
s
.57591 0 m
.57591 .00375 L
s
.62652 0 m
.62652 .00375 L
s
.65182 0 m
.65182 .00375 L
s
.67713 0 m
.67713 .00375 L
s
.70243 0 m
.70243 .00375 L
s
.75304 0 m
.75304 .00375 L
s
.77834 0 m
.77834 .00375 L
s
.80364 0 m
.80364 .00375 L
s
.82895 0 m
.82895 .00375 L
s
.87955 0 m
.87955 .00375 L
s
.90486 0 m
.90486 .00375 L
s
.93016 0 m
.93016 .00375 L
s
.95547 0 m
.95547 .00375 L
s
.06984 0 m
.06984 .00375 L
s
.04453 0 m
.04453 .00375 L
s
.01923 0 m
.01923 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .09514 m
.00625 .09514 L
s
[(2.5)] -0.0125 .09514 1 0 Mshowa
0 .22166 m
.00625 .22166 L
s
[(5)] -0.0125 .22166 1 0 Mshowa
0 .34818 m
.00625 .34818 L
s
[(7.5)] -0.0125 .34818 1 0 Mshowa
0 .4747 m
.00625 .4747 L
s
[(10)] -0.0125 .4747 1 0 Mshowa
0 .60121 m
.00625 .60121 L
s
[(12.5)] -0.0125 .60121 1 0 Mshowa
0 .72773 m
.00625 .72773 L
s
[(15)] -0.0125 .72773 1 0 Mshowa
0 .85425 m
.00625 .85425 L
s
[(17.5)] -0.0125 .85425 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(20)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .12045 m
.00375 .12045 L
s
0 .14575 m
.00375 .14575 L
s
0 .17105 m
.00375 .17105 L
s
0 .19636 m
.00375 .19636 L
s
0 .24696 m
.00375 .24696 L
s
0 .27227 m
.00375 .27227 L
s
0 .29757 m
.00375 .29757 L
s
0 .32287 m
.00375 .32287 L
s
0 .37348 m
.00375 .37348 L
s
0 .39879 m
.00375 .39879 L
s
0 .42409 m
.00375 .42409 L
s
0 .44939 m
.00375 .44939 L
s
0 .5 m
.00375 .5 L
s
0 .5253 m
.00375 .5253 L
s
0 .55061 m
.00375 .55061 L
s
0 .57591 m
.00375 .57591 L
s
0 .62652 m
.00375 .62652 L
s
0 .65182 m
.00375 .65182 L
s
0 .67713 m
.00375 .67713 L
s
0 .70243 m
.00375 .70243 L
s
0 .75304 m
.00375 .75304 L
s
0 .77834 m
.00375 .77834 L
s
0 .80364 m
.00375 .80364 L
s
0 .82895 m
.00375 .82895 L
s
0 .87955 m
.00375 .87955 L
s
0 .90486 m
.00375 .90486 L
s
0 .93016 m
.00375 .93016 L
s
0 .95547 m
.00375 .95547 L
s
0 .06984 m
.00375 .06984 L
s
0 .04453 m
.00375 .04453 L
s
0 .01923 m
.00375 .01923 L
s
.25 Mabswid
0 0 m
0 1 L
s
.09514 .99375 m
.09514 1 L
s
.22166 .99375 m
.22166 1 L
s
.34818 .99375 m
.34818 1 L
s
.4747 .99375 m
.4747 1 L
s
.60121 .99375 m
.60121 1 L
s
.72773 .99375 m
.72773 1 L
s
.85425 .99375 m
.85425 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.12045 .99625 m
.12045 1 L
s
.14575 .99625 m
.14575 1 L
s
.17105 .99625 m
.17105 1 L
s
.19636 .99625 m
.19636 1 L
s
.24696 .99625 m
.24696 1 L
s
.27227 .99625 m
.27227 1 L
s
.29757 .99625 m
.29757 1 L
s
.32287 .99625 m
.32287 1 L
s
.37348 .99625 m
.37348 1 L
s
.39879 .99625 m
.39879 1 L
s
.42409 .99625 m
.42409 1 L
s
.44939 .99625 m
.44939 1 L
s
.5 .99625 m
.5 1 L
s
.5253 .99625 m
.5253 1 L
s
.55061 .99625 m
.55061 1 L
s
.57591 .99625 m
.57591 1 L
s
.62652 .99625 m
.62652 1 L
s
.65182 .99625 m
.65182 1 L
s
.67713 .99625 m
.67713 1 L
s
.70243 .99625 m
.70243 1 L
s
.75304 .99625 m
.75304 1 L
s
.77834 .99625 m
.77834 1 L
s
.80364 .99625 m
.80364 1 L
s
.82895 .99625 m
.82895 1 L
s
.87955 .99625 m
.87955 1 L
s
.90486 .99625 m
.90486 1 L
s
.93016 .99625 m
.93016 1 L
s
.95547 .99625 m
.95547 1 L
s
.06984 .99625 m
.06984 1 L
s
.04453 .99625 m
.04453 1 L
s
.01923 .99625 m
.01923 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .09514 m
1 .09514 L
s
.99375 .22166 m
1 .22166 L
s
.99375 .34818 m
1 .34818 L
s
.99375 .4747 m
1 .4747 L
s
.99375 .60121 m
1 .60121 L
s
.99375 .72773 m
1 .72773 L
s
.99375 .85425 m
1 .85425 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .12045 m
1 .12045 L
s
.99625 .14575 m
1 .14575 L
s
.99625 .17105 m
1 .17105 L
s
.99625 .19636 m
1 .19636 L
s
.99625 .24696 m
1 .24696 L
s
.99625 .27227 m
1 .27227 L
s
.99625 .29757 m
1 .29757 L
s
.99625 .32287 m
1 .32287 L
s
.99625 .37348 m
1 .37348 L
s
.99625 .39879 m
1 .39879 L
s
.99625 .42409 m
1 .42409 L
s
.99625 .44939 m
1 .44939 L
s
.99625 .5 m
1 .5 L
s
.99625 .5253 m
1 .5253 L
s
.99625 .55061 m
1 .55061 L
s
.99625 .57591 m
1 .57591 L
s
.99625 .62652 m
1 .62652 L
s
.99625 .65182 m
1 .65182 L
s
.99625 .67713 m
1 .67713 L
s
.99625 .70243 m
1 .70243 L
s
.99625 .75304 m
1 .75304 L
s
.99625 .77834 m
1 .77834 L
s
.99625 .80364 m
1 .80364 L
s
.99625 .82895 m
1 .82895 L
s
.99625 .87955 m
1 .87955 L
s
.99625 .90486 m
1 .90486 L
s
.99625 .93016 m
1 .93016 L
s
.99625 .95547 m
1 .95547 L
s
.99625 .06984 m
1 .06984 L
s
.99625 .04453 m
1 .04453 L
s
.99625 .01923 m
1 .01923 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.9 g
.01923 .02122 m
.04408 .06984 L
.06984 .07569 L
.11459 .12045 L
.12045 .1263 L
.1652 .17105 L
.17105 .17691 L
.21581 .22166 L
.22166 .22751 L
.26641 .27227 L
.27227 .27812 L
.31702 .32287 L
.32287 .32873 L
.36763 .37348 L
.37348 .37934 L
.41823 .42409 L
.42409 .42994 L
.46884 .4747 L
.4747 .48055 L
.51945 .5253 L
.5253 .53116 L
.57006 .57591 L
.57591 .58177 L
.62066 .62652 L
.62652 .63237 L
.67127 .67713 L
.67713 .68298 L
.72188 .72773 L
.72773 .73359 L
.77249 .77834 L
.77834 .78419 L
.82309 .82895 L
.82895 .8348 L
.8737 .87955 L
.87955 .88541 L
.92431 .93016 L
.93016 .95592 L
.97878 .98077 L
.01923 .98077 L
F
0 g
.01923 .02122 m
.04408 .06984 L
.06984 .07569 L
.11459 .12045 L
.12045 .1263 L
.1652 .17105 L
.17105 .17691 L
.21581 .22166 L
.22166 .22751 L
.26641 .27227 L
.27227 .27812 L
.31702 .32287 L
.32287 .32873 L
.36763 .37348 L
.37348 .37934 L
.41823 .42409 L
.42409 .42994 L
.46884 .4747 L
.4747 .48055 L
.51945 .5253 L
.5253 .53116 L
.57006 .57591 L
.57591 .58177 L
.62066 .62652 L
.62652 .63237 L
.67127 .67713 L
.67713 .68298 L
.72188 .72773 L
.72773 .73359 L
.77249 .77834 L
.77834 .78419 L
.82309 .82895 L
.82895 .8348 L
.8737 .87955 L
.87955 .88541 L
.92431 .93016 L
.93016 .95592 L
.97878 .98077 L
s
.8 g
.01923 .02406 m
.03956 .06984 L
.06984 .08171 L
.10857 .12045 L
.12045 .13232 L
.15918 .17105 L
.17105 .18293 L
.20979 .22166 L
.22166 .23353 L
.26039 .27227 L
.27227 .28414 L
.311 .32287 L
.32287 .33475 L
.36161 .37348 L
.37348 .38536 L
.41222 .42409 L
.42409 .43596 L
.46282 .4747 L
.4747 .48657 L
.51343 .5253 L
.5253 .53718 L
.56404 .57591 L
.57591 .58778 L
.61464 .62652 L
.62652 .63839 L
.66525 .67713 L
.67713 .689 L
.71586 .72773 L
.72773 .73961 L
.76647 .77834 L
.77834 .79021 L
.81707 .82895 L
.82895 .84082 L
.86768 .87955 L
.87955 .89143 L
.91829 .93016 L
.93016 .96044 L
.97594 .98077 L
.01923 .98077 L
F
0 g
.01923 .02406 m
.03956 .06984 L
.06984 .08171 L
.10857 .12045 L
.12045 .13232 L
.15918 .17105 L
.17105 .18293 L
.20979 .22166 L
.22166 .23353 L
.26039 .27227 L
.27227 .28414 L
.311 .32287 L
.32287 .33475 L
.36161 .37348 L
.37348 .38536 L
.41222 .42409 L
.42409 .43596 L
.46282 .4747 L
.4747 .48657 L
.51343 .5253 L
.5253 .53718 L
.56404 .57591 L
.57591 .58778 L
.61464 .62652 L
.62652 .63839 L
.66525 .67713 L
.67713 .689 L
.71586 .72773 L
.72773 .73961 L
.76647 .77834 L
.77834 .79021 L
.81707 .82895 L
.82895 .84082 L
.86768 .87955 L
.87955 .89143 L
.91829 .93016 L
.93016 .96044 L
.97594 .98077 L
s
.7 g
.01923 .02709 m
.03603 .06984 L
.06984 .08681 L
.10347 .12045 L
.12045 .13742 L
.15408 .17105 L
.17105 .18803 L
.20468 .22166 L
.22166 .23864 L
.25529 .27227 L
.27227 .28924 L
.3059 .32287 L
.32287 .33985 L
.35651 .37348 L
.37348 .39046 L
.40711 .42409 L
.42409 .44106 L
.45772 .4747 L
.4747 .49167 L
.50833 .5253 L
.5253 .54228 L
.55894 .57591 L
.57591 .59289 L
.60954 .62652 L
.62652 .64349 L
.66015 .67713 L
.67713 .6941 L
.71076 .72773 L
.72773 .74471 L
.76136 .77834 L
.77834 .79532 L
.81197 .82895 L
.82895 .84592 L
.86258 .87955 L
.87955 .89653 L
.91319 .93016 L
.93016 .96397 L
.97291 .98077 L
.01923 .98077 L
F
0 g
.01923 .02709 m
.03603 .06984 L
.06984 .08681 L
.10347 .12045 L
.12045 .13742 L
.15408 .17105 L
.17105 .18803 L
.20468 .22166 L
.22166 .23864 L
.25529 .27227 L
.27227 .28924 L
.3059 .32287 L
.32287 .33985 L
.35651 .37348 L
.37348 .39046 L
.40711 .42409 L
.42409 .44106 L
.45772 .4747 L
.4747 .49167 L
.50833 .5253 L
.5253 .54228 L
.55894 .57591 L
.57591 .59289 L
.60954 .62652 L
.62652 .64349 L
.66015 .67713 L
.67713 .6941 L
.71076 .72773 L
.72773 .74471 L
.76136 .77834 L
.77834 .79532 L
.81197 .82895 L
.82895 .84592 L
.86258 .87955 L
.87955 .89653 L
.91319 .93016 L
.93016 .96397 L
.97291 .98077 L
s
.6 g
.01923 .03037 m
.03306 .06984 L
.06984 .09144 L
.09884 .12045 L
.12045 .14205 L
.14945 .17105 L
.17105 .19266 L
.20005 .22166 L
.22166 .24327 L
.25066 .27227 L
.27227 .29387 L
.30127 .32287 L
.32287 .34448 L
.35188 .37348 L
.37348 .39509 L
.40248 .42409 L
.42409 .44569 L
.45309 .4747 L
.4747 .4963 L
.5037 .5253 L
.5253 .54691 L
.55431 .57591 L
.57591 .59752 L
.60491 .62652 L
.62652 .64812 L
.65552 .67713 L
.67713 .69873 L
.70613 .72773 L
.72773 .74934 L
.75673 .77834 L
.77834 .79995 L
.80734 .82895 L
.82895 .85055 L
.85795 .87955 L
.87955 .90116 L
.90856 .93016 L
.93016 .96694 L
.96963 .98077 L
.01923 .98077 L
F
0 g
.01923 .03037 m
.03306 .06984 L
.06984 .09144 L
.09884 .12045 L
.12045 .14205 L
.14945 .17105 L
.17105 .19266 L
.20005 .22166 L
.22166 .24327 L
.25066 .27227 L
.27227 .29387 L
.30127 .32287 L
.32287 .34448 L
.35188 .37348 L
.37348 .39509 L
.40248 .42409 L
.42409 .44569 L
.45309 .4747 L
.4747 .4963 L
.5037 .5253 L
.5253 .54691 L
.55431 .57591 L
.57591 .59752 L
.60491 .62652 L
.62652 .64812 L
.65552 .67713 L
.67713 .69873 L
.70613 .72773 L
.72773 .74934 L
.75673 .77834 L
.77834 .79995 L
.80734 .82895 L
.82895 .85055 L
.85795 .87955 L
.87955 .90116 L
.90856 .93016 L
.93016 .96694 L
.96963 .98077 L
s
.5 g
.01923 .03393 m
.03045 .06984 L
.06984 .0958 L
.09448 .12045 L
.12045 .14641 L
.14509 .17105 L
.17105 .19702 L
.19569 .22166 L
.22166 .24763 L
.2463 .27227 L
.27227 .29823 L
.29691 .32287 L
.32287 .34884 L
.34752 .37348 L
.37348 .39945 L
.39812 .42409 L
.42409 .45006 L
.44873 .4747 L
.4747 .50066 L
.49934 .5253 L
.5253 .55127 L
.54994 .57591 L
.57591 .60188 L
.60055 .62652 L
.62652 .65248 L
.65116 .67713 L
.67713 .70309 L
.70177 .72773 L
.72773 .7537 L
.75237 .77834 L
.77834 .80431 L
.80298 .82895 L
.82895 .85491 L
.85359 .87955 L
.87955 .90552 L
.9042 .93016 L
.93016 .96955 L
.96607 .98077 L
.01923 .98077 L
F
0 g
.01923 .03393 m
.03045 .06984 L
.06984 .0958 L
.09448 .12045 L
.12045 .14641 L
.14509 .17105 L
.17105 .19702 L
.19569 .22166 L
.22166 .24763 L
.2463 .27227 L
.27227 .29823 L
.29691 .32287 L
.32287 .34884 L
.34752 .37348 L
.37348 .39945 L
.39812 .42409 L
.42409 .45006 L
.44873 .4747 L
.4747 .50066 L
.49934 .5253 L
.5253 .55127 L
.54994 .57591 L
.57591 .60188 L
.60055 .62652 L
.62652 .65248 L
.65116 .67713 L
.67713 .70309 L
.70177 .72773 L
.72773 .7537 L
.75237 .77834 L
.77834 .80431 L
.80298 .82895 L
.82895 .85491 L
.85359 .87955 L
.87955 .90552 L
.9042 .93016 L
.93016 .96955 L
.96607 .98077 L
s
.4 g
.01923 .03786 m
.02811 .06984 L
.06984 .10002 L
.09027 .12045 L
.12045 .15062 L
.14087 .17105 L
.17105 .20123 L
.19148 .22166 L
.22166 .25184 L
.24209 .27227 L
.27227 .30245 L
.2927 .32287 L
.32287 .35305 L
.3433 .37348 L
.37348 .40366 L
.39391 .42409 L
.42409 .45427 L
.44452 .4747 L
.4747 .50487 L
.49513 .5253 L
.5253 .55548 L
.54573 .57591 L
.57591 .60609 L
.59634 .62652 L
.62652 .6567 L
.64695 .67713 L
.67713 .7073 L
.69755 .72773 L
.72773 .75791 L
.74816 .77834 L
.77834 .80852 L
.79877 .82895 L
.82895 .85913 L
.84938 .87955 L
.87955 .90973 L
.89998 .93016 L
.93016 .97189 L
.96214 .98077 L
.01923 .98077 L
F
0 g
.01923 .03786 m
.02811 .06984 L
.06984 .10002 L
.09027 .12045 L
.12045 .15062 L
.14087 .17105 L
.17105 .20123 L
.19148 .22166 L
.22166 .25184 L
.24209 .27227 L
.27227 .30245 L
.2927 .32287 L
.32287 .35305 L
.3433 .37348 L
.37348 .40366 L
.39391 .42409 L
.42409 .45427 L
.44452 .4747 L
.4747 .50487 L
.49513 .5253 L
.5253 .55548 L
.54573 .57591 L
.57591 .60609 L
.59634 .62652 L
.62652 .6567 L
.64695 .67713 L
.67713 .7073 L
.69755 .72773 L
.72773 .75791 L
.74816 .77834 L
.77834 .80852 L
.79877 .82895 L
.82895 .85913 L
.84938 .87955 L
.87955 .90973 L
.89998 .93016 L
.93016 .97189 L
.96214 .98077 L
s
.3 g
.01923 .04227 m
.02598 .06984 L
.06984 .10416 L
.08612 .12045 L
.12045 .15477 L
.13673 .17105 L
.17105 .20538 L
.18733 .22166 L
.22166 .25599 L
.23794 .27227 L
.27227 .30659 L
.28855 .32287 L
.32287 .3572 L
.33916 .37348 L
.37348 .40781 L
.38976 .42409 L
.42409 .45842 L
.44037 .4747 L
.4747 .50902 L
.49098 .5253 L
.5253 .55963 L
.54158 .57591 L
.57591 .61024 L
.59219 .62652 L
.62652 .66084 L
.6428 .67713 L
.67713 .71145 L
.69341 .72773 L
.72773 .76206 L
.74401 .77834 L
.77834 .81267 L
.79462 .82895 L
.82895 .86327 L
.84523 .87955 L
.87955 .91388 L
.89584 .93016 L
.93016 .97402 L
.95773 .98077 L
.01923 .98077 L
F
0 g
.01923 .04227 m
.02598 .06984 L
.06984 .10416 L
.08612 .12045 L
.12045 .15477 L
.13673 .17105 L
.17105 .20538 L
.18733 .22166 L
.22166 .25599 L
.23794 .27227 L
.27227 .30659 L
.28855 .32287 L
.32287 .3572 L
.33916 .37348 L
.37348 .40781 L
.38976 .42409 L
.42409 .45842 L
.44037 .4747 L
.4747 .50902 L
.49098 .5253 L
.5253 .55963 L
.54158 .57591 L
.57591 .61024 L
.59219 .62652 L
.62652 .66084 L
.6428 .67713 L
.67713 .71145 L
.69341 .72773 L
.72773 .76206 L
.74401 .77834 L
.77834 .81267 L
.79462 .82895 L
.82895 .86327 L
.84523 .87955 L
.87955 .91388 L
.89584 .93016 L
.93016 .97402 L
.95773 .98077 L
s
.2 g
.01923 .04736 m
.02401 .06984 L
.06984 .10832 L
.08196 .12045 L
.12045 .15893 L
.13257 .17105 L
.17105 .20954 L
.18318 .22166 L
.22166 .26014 L
.23378 .27227 L
.27227 .31075 L
.28439 .32287 L
.32287 .36136 L
.335 .37348 L
.37348 .41197 L
.3856 .42409 L
.42409 .46257 L
.43621 .4747 L
.4747 .51318 L
.48682 .5253 L
.5253 .56379 L
.53743 .57591 L
.57591 .6144 L
.58803 .62652 L
.62652 .665 L
.63864 .67713 L
.67713 .71561 L
.68925 .72773 L
.72773 .76622 L
.73986 .77834 L
.77834 .81682 L
.79046 .82895 L
.82895 .86743 L
.84107 .87955 L
.87955 .91804 L
.89168 .93016 L
.93016 .97599 L
.95264 .98077 L
.01923 .98077 L
F
0 g
.01923 .04736 m
.02401 .06984 L
.06984 .10832 L
.08196 .12045 L
.12045 .15893 L
.13257 .17105 L
.17105 .20954 L
.18318 .22166 L
.22166 .26014 L
.23378 .27227 L
.27227 .31075 L
.28439 .32287 L
.32287 .36136 L
.335 .37348 L
.37348 .41197 L
.3856 .42409 L
.42409 .46257 L
.43621 .4747 L
.4747 .51318 L
.48682 .5253 L
.5253 .56379 L
.53743 .57591 L
.57591 .6144 L
.58803 .62652 L
.62652 .665 L
.63864 .67713 L
.67713 .71561 L
.68925 .72773 L
.72773 .76622 L
.73986 .77834 L
.77834 .81682 L
.79046 .82895 L
.82895 .86743 L
.84107 .87955 L
.87955 .91804 L
.89168 .93016 L
.93016 .97599 L
.95264 .98077 L
s
.1 g
.01923 .05346 m
.02217 .06984 L
.06984 .11257 L
.07772 .12045 L
.12045 .16317 L
.12832 .17105 L
.17105 .21378 L
.17893 .22166 L
.22166 .26439 L
.22954 .27227 L
.27227 .315 L
.28015 .32287 L
.32287 .3656 L
.33075 .37348 L
.37348 .41621 L
.38136 .42409 L
.42409 .46682 L
.43197 .4747 L
.4747 .51743 L
.48257 .5253 L
.5253 .56803 L
.53318 .57591 L
.57591 .61864 L
.58379 .62652 L
.62652 .66925 L
.6344 .67713 L
.67713 .71985 L
.685 .72773 L
.72773 .77046 L
.73561 .77834 L
.77834 .82107 L
.78622 .82895 L
.82895 .87168 L
.83683 .87955 L
.87955 .92228 L
.88743 .93016 L
.93016 .97783 L
.94654 .98077 L
.01923 .98077 L
F
0 g
.01923 .05346 m
.02217 .06984 L
.06984 .11257 L
.07772 .12045 L
.12045 .16317 L
.12832 .17105 L
.17105 .21378 L
.17893 .22166 L
.22166 .26439 L
.22954 .27227 L
.27227 .315 L
.28015 .32287 L
.32287 .3656 L
.33075 .37348 L
.37348 .41621 L
.38136 .42409 L
.42409 .46682 L
.43197 .4747 L
.4747 .51743 L
.48257 .5253 L
.5253 .56803 L
.53318 .57591 L
.57591 .61864 L
.58379 .62652 L
.62652 .66925 L
.6344 .67713 L
.67713 .71985 L
.685 .72773 L
.72773 .77046 L
.73561 .77834 L
.77834 .82107 L
.78622 .82895 L
.82895 .87168 L
.83683 .87955 L
.87955 .92228 L
.88743 .93016 L
.93016 .97783 L
.94654 .98077 L
s
.01923 .06138 m
.02044 .06984 L
.06984 .11699 L
.07329 .12045 L
.12045 .1676 L
.1239 .17105 L
.17105 .2182 L
.17451 .22166 L
.22166 .26881 L
.22512 .27227 L
.27227 .31942 L
.27572 .32287 L
.32287 .37003 L
.32633 .37348 L
.37348 .42063 L
.37694 .42409 L
.42409 .47124 L
.42754 .4747 L
.4747 .52185 L
.47815 .5253 L
.5253 .57246 L
.52876 .57591 L
.57591 .62306 L
.57937 .62652 L
.62652 .67367 L
.62997 .67713 L
.67713 .72428 L
.68058 .72773 L
.72773 .77488 L
.73119 .77834 L
.77834 .82549 L
.7818 .82895 L
.82895 .8761 L
.8324 .87955 L
.87955 .92671 L
.88301 .93016 L
.93016 .97956 L
.93862 .98077 L
.01923 .98077 L
F
.01923 .06138 m
.02044 .06984 L
.06984 .11699 L
.07329 .12045 L
.12045 .1676 L
.1239 .17105 L
.17105 .2182 L
.17451 .22166 L
.22166 .26881 L
.22512 .27227 L
.27227 .31942 L
.27572 .32287 L
.32287 .37003 L
.32633 .37348 L
.37348 .42063 L
.37694 .42409 L
.42409 .47124 L
.42754 .4747 L
.4747 .52185 L
.47815 .5253 L
.5253 .57246 L
.52876 .57591 L
.57591 .62306 L
.57937 .62652 L
.62652 .67367 L
.62997 .67713 L
.67713 .72428 L
.68058 .72773 L
.72773 .77488 L
.73119 .77834 L
.77834 .82549 L
.7818 .82895 L
.82895 .8761 L
.8324 .87955 L
.87955 .92671 L
.88301 .93016 L
.93016 .97956 L
.93862 .98077 L
s
.9 g
.98077 .97878 m
.95592 .93016 L
.93016 .92431 L
.88541 .87955 L
.87955 .8737 L
.8348 .82895 L
.82895 .82309 L
.78419 .77834 L
.77834 .77249 L
.73359 .72773 L
.72773 .72188 L
.68298 .67713 L
.67713 .67127 L
.63237 .62652 L
.62652 .62066 L
.58177 .57591 L
.57591 .57006 L
.53116 .5253 L
.5253 .51945 L
.48055 .4747 L
.4747 .46884 L
.42994 .42409 L
.42409 .41823 L
.37934 .37348 L
.37348 .36763 L
.32873 .32287 L
.32287 .31702 L
.27812 .27227 L
.27227 .26641 L
.22751 .22166 L
.22166 .21581 L
.17691 .17105 L
.17105 .1652 L
.1263 .12045 L
.12045 .11459 L
.07569 .06984 L
.06984 .04408 L
.02122 .01923 L
.98077 .01923 L
F
0 g
.98077 .97878 m
.95592 .93016 L
.93016 .92431 L
.88541 .87955 L
.87955 .8737 L
.8348 .82895 L
.82895 .82309 L
.78419 .77834 L
.77834 .77249 L
.73359 .72773 L
.72773 .72188 L
.68298 .67713 L
.67713 .67127 L
.63237 .62652 L
.62652 .62066 L
.58177 .57591 L
.57591 .57006 L
.53116 .5253 L
.5253 .51945 L
.48055 .4747 L
.4747 .46884 L
.42994 .42409 L
.42409 .41823 L
.37934 .37348 L
.37348 .36763 L
.32873 .32287 L
.32287 .31702 L
.27812 .27227 L
.27227 .26641 L
.22751 .22166 L
.22166 .21581 L
.17691 .17105 L
.17105 .1652 L
.1263 .12045 L
.12045 .11459 L
.07569 .06984 L
.06984 .04408 L
.02122 .01923 L
s
.8 g
.98077 .97594 m
.96044 .93016 L
.93016 .91829 L
.89143 .87955 L
.87955 .86768 L
.84082 .82895 L
.82895 .81707 L
.79021 .77834 L
.77834 .76647 L
.73961 .72773 L
.72773 .71586 L
.689 .67713 L
.67713 .66525 L
.63839 .62652 L
.62652 .61464 L
.58778 .57591 L
.57591 .56404 L
.53718 .5253 L
.5253 .51343 L
.48657 .4747 L
.4747 .46282 L
.43596 .42409 L
.42409 .41222 L
.38536 .37348 L
.37348 .36161 L
.33475 .32287 L
.32287 .311 L
.28414 .27227 L
.27227 .26039 L
.23353 .22166 L
.22166 .20979 L
.18293 .17105 L
.17105 .15918 L
.13232 .12045 L
.12045 .10857 L
.08171 .06984 L
.06984 .03956 L
.02406 .01923 L
.98077 .01923 L
F
0 g
.98077 .97594 m
.96044 .93016 L
.93016 .91829 L
.89143 .87955 L
.87955 .86768 L
.84082 .82895 L
.82895 .81707 L
.79021 .77834 L
.77834 .76647 L
.73961 .72773 L
.72773 .71586 L
.689 .67713 L
.67713 .66525 L
.63839 .62652 L
.62652 .61464 L
.58778 .57591 L
.57591 .56404 L
.53718 .5253 L
.5253 .51343 L
.48657 .4747 L
.4747 .46282 L
.43596 .42409 L
.42409 .41222 L
.38536 .37348 L
.37348 .36161 L
.33475 .32287 L
.32287 .311 L
.28414 .27227 L
.27227 .26039 L
.23353 .22166 L
.22166 .20979 L
.18293 .17105 L
.17105 .15918 L
.13232 .12045 L
.12045 .10857 L
.08171 .06984 L
.06984 .03956 L
.02406 .01923 L
s
.7 g
.98077 .97291 m
.96397 .93016 L
.93016 .91319 L
.89653 .87955 L
.87955 .86258 L
.84592 .82895 L
.82895 .81197 L
.79532 .77834 L
.77834 .76136 L
.74471 .72773 L
.72773 .71076 L
.6941 .67713 L
.67713 .66015 L
.64349 .62652 L
.62652 .60954 L
.59289 .57591 L
.57591 .55894 L
.54228 .5253 L
.5253 .50833 L
.49167 .4747 L
.4747 .45772 L
.44106 .42409 L
.42409 .40711 L
.39046 .37348 L
.37348 .35651 L
.33985 .32287 L
.32287 .3059 L
.28924 .27227 L
.27227 .25529 L
.23864 .22166 L
.22166 .20468 L
.18803 .17105 L
.17105 .15408 L
.13742 .12045 L
.12045 .10347 L
.08681 .06984 L
.06984 .03603 L
.02709 .01923 L
.98077 .01923 L
F
0 g
.98077 .97291 m
.96397 .93016 L
.93016 .91319 L
.89653 .87955 L
.87955 .86258 L
.84592 .82895 L
.82895 .81197 L
.79532 .77834 L
.77834 .76136 L
.74471 .72773 L
.72773 .71076 L
.6941 .67713 L
.67713 .66015 L
.64349 .62652 L
.62652 .60954 L
.59289 .57591 L
.57591 .55894 L
.54228 .5253 L
.5253 .50833 L
.49167 .4747 L
.4747 .45772 L
.44106 .42409 L
.42409 .40711 L
.39046 .37348 L
.37348 .35651 L
.33985 .32287 L
.32287 .3059 L
.28924 .27227 L
.27227 .25529 L
.23864 .22166 L
.22166 .20468 L
.18803 .17105 L
.17105 .15408 L
.13742 .12045 L
.12045 .10347 L
.08681 .06984 L
.06984 .03603 L
.02709 .01923 L
s
.6 g
.98077 .96963 m
.96694 .93016 L
.93016 .90856 L
.90116 .87955 L
.87955 .85795 L
.85055 .82895 L
.82895 .80734 L
.79995 .77834 L
.77834 .75673 L
.74934 .72773 L
.72773 .70613 L
.69873 .67713 L
.67713 .65552 L
.64812 .62652 L
.62652 .60491 L
.59752 .57591 L
.57591 .55431 L
.54691 .5253 L
.5253 .5037 L
.4963 .4747 L
.4747 .45309 L
.44569 .42409 L
.42409 .40248 L
.39509 .37348 L
.37348 .35188 L
.34448 .32287 L
.32287 .30127 L
.29387 .27227 L
.27227 .25066 L
.24327 .22166 L
.22166 .20005 L
.19266 .17105 L
.17105 .14945 L
.14205 .12045 L
.12045 .09884 L
.09144 .06984 L
.06984 .03306 L
.03037 .01923 L
.98077 .01923 L
F
0 g
.98077 .96963 m
.96694 .93016 L
.93016 .90856 L
.90116 .87955 L
.87955 .85795 L
.85055 .82895 L
.82895 .80734 L
.79995 .77834 L
.77834 .75673 L
.74934 .72773 L
.72773 .70613 L
.69873 .67713 L
.67713 .65552 L
.64812 .62652 L
.62652 .60491 L
.59752 .57591 L
.57591 .55431 L
.54691 .5253 L
.5253 .5037 L
.4963 .4747 L
.4747 .45309 L
.44569 .42409 L
.42409 .40248 L
.39509 .37348 L
.37348 .35188 L
.34448 .32287 L
.32287 .30127 L
.29387 .27227 L
.27227 .25066 L
.24327 .22166 L
.22166 .20005 L
.19266 .17105 L
.17105 .14945 L
.14205 .12045 L
.12045 .09884 L
.09144 .06984 L
.06984 .03306 L
.03037 .01923 L
s
.5 g
.98077 .96607 m
.96955 .93016 L
.93016 .9042 L
.90552 .87955 L
.87955 .85359 L
.85491 .82895 L
.82895 .80298 L
.80431 .77834 L
.77834 .75237 L
.7537 .72773 L
.72773 .70177 L
.70309 .67713 L
.67713 .65116 L
.65248 .62652 L
.62652 .60055 L
.60188 .57591 L
.57591 .54994 L
.55127 .5253 L
.5253 .49934 L
.50066 .4747 L
.4747 .44873 L
.45006 .42409 L
.42409 .39812 L
.39945 .37348 L
.37348 .34752 L
.34884 .32287 L
.32287 .29691 L
.29823 .27227 L
.27227 .2463 L
.24763 .22166 L
.22166 .19569 L
.19702 .17105 L
.17105 .14509 L
.14641 .12045 L
.12045 .09448 L
.0958 .06984 L
.06984 .03045 L
.03393 .01923 L
.98077 .01923 L
F
0 g
.98077 .96607 m
.96955 .93016 L
.93016 .9042 L
.90552 .87955 L
.87955 .85359 L
.85491 .82895 L
.82895 .80298 L
.80431 .77834 L
.77834 .75237 L
.7537 .72773 L
.72773 .70177 L
.70309 .67713 L
.67713 .65116 L
.65248 .62652 L
.62652 .60055 L
.60188 .57591 L
.57591 .54994 L
.55127 .5253 L
.5253 .49934 L
.50066 .4747 L
.4747 .44873 L
.45006 .42409 L
.42409 .39812 L
.39945 .37348 L
.37348 .34752 L
.34884 .32287 L
.32287 .29691 L
.29823 .27227 L
.27227 .2463 L
.24763 .22166 L
.22166 .19569 L
.19702 .17105 L
.17105 .14509 L
.14641 .12045 L
.12045 .09448 L
.0958 .06984 L
.06984 .03045 L
.03393 .01923 L
s
.4 g
.98077 .96214 m
.97189 .93016 L
.93016 .89998 L
.90973 .87955 L
.87955 .84938 L
.85913 .82895 L
.82895 .79877 L
.80852 .77834 L
.77834 .74816 L
.75791 .72773 L
.72773 .69755 L
.7073 .67713 L
.67713 .64695 L
.6567 .62652 L
.62652 .59634 L
.60609 .57591 L
.57591 .54573 L
.55548 .5253 L
.5253 .49513 L
.50487 .4747 L
.4747 .44452 L
.45427 .42409 L
.42409 .39391 L
.40366 .37348 L
.37348 .3433 L
.35305 .32287 L
.32287 .2927 L
.30245 .27227 L
.27227 .24209 L
.25184 .22166 L
.22166 .19148 L
.20123 .17105 L
.17105 .14087 L
.15062 .12045 L
.12045 .09027 L
.10002 .06984 L
.06984 .02811 L
.03786 .01923 L
.98077 .01923 L
F
0 g
.98077 .96214 m
.97189 .93016 L
.93016 .89998 L
.90973 .87955 L
.87955 .84938 L
.85913 .82895 L
.82895 .79877 L
.80852 .77834 L
.77834 .74816 L
.75791 .72773 L
.72773 .69755 L
.7073 .67713 L
.67713 .64695 L
.6567 .62652 L
.62652 .59634 L
.60609 .57591 L
.57591 .54573 L
.55548 .5253 L
.5253 .49513 L
.50487 .4747 L
.4747 .44452 L
.45427 .42409 L
.42409 .39391 L
.40366 .37348 L
.37348 .3433 L
.35305 .32287 L
.32287 .2927 L
.30245 .27227 L
.27227 .24209 L
.25184 .22166 L
.22166 .19148 L
.20123 .17105 L
.17105 .14087 L
.15062 .12045 L
.12045 .09027 L
.10002 .06984 L
.06984 .02811 L
.03786 .01923 L
s
.3 g
.98077 .95773 m
.97402 .93016 L
.93016 .89584 L
.91388 .87955 L
.87955 .84523 L
.86327 .82895 L
.82895 .79462 L
.81267 .77834 L
.77834 .74401 L
.76206 .72773 L
.72773 .69341 L
.71145 .67713 L
.67713 .6428 L
.66084 .62652 L
.62652 .59219 L
.61024 .57591 L
.57591 .54158 L
.55963 .5253 L
.5253 .49098 L
.50902 .4747 L
.4747 .44037 L
.45842 .42409 L
.42409 .38976 L
.40781 .37348 L
.37348 .33916 L
.3572 .32287 L
.32287 .28855 L
.30659 .27227 L
.27227 .23794 L
.25599 .22166 L
.22166 .18733 L
.20538 .17105 L
.17105 .13673 L
.15477 .12045 L
.12045 .08612 L
.10416 .06984 L
.06984 .02598 L
.04227 .01923 L
.98077 .01923 L
F
0 g
.98077 .95773 m
.97402 .93016 L
.93016 .89584 L
.91388 .87955 L
.87955 .84523 L
.86327 .82895 L
.82895 .79462 L
.81267 .77834 L
.77834 .74401 L
.76206 .72773 L
.72773 .69341 L
.71145 .67713 L
.67713 .6428 L
.66084 .62652 L
.62652 .59219 L
.61024 .57591 L
.57591 .54158 L
.55963 .5253 L
.5253 .49098 L
.50902 .4747 L
.4747 .44037 L
.45842 .42409 L
.42409 .38976 L
.40781 .37348 L
.37348 .33916 L
.3572 .32287 L
.32287 .28855 L
.30659 .27227 L
.27227 .23794 L
.25599 .22166 L
.22166 .18733 L
.20538 .17105 L
.17105 .13673 L
.15477 .12045 L
.12045 .08612 L
.10416 .06984 L
.06984 .02598 L
.04227 .01923 L
s
.2 g
.98077 .95264 m
.97599 .93016 L
.93016 .89168 L
.91804 .87955 L
.87955 .84107 L
.86743 .82895 L
.82895 .79046 L
.81682 .77834 L
.77834 .73986 L
.76622 .72773 L
.72773 .68925 L
.71561 .67713 L
.67713 .63864 L
.665 .62652 L
.62652 .58803 L
.6144 .57591 L
.57591 .53743 L
.56379 .5253 L
.5253 .48682 L
.51318 .4747 L
.4747 .43621 L
.46257 .42409 L
.42409 .3856 L
.41197 .37348 L
.37348 .335 L
.36136 .32287 L
.32287 .28439 L
.31075 .27227 L
.27227 .23378 L
.26014 .22166 L
.22166 .18318 L
.20954 .17105 L
.17105 .13257 L
.15893 .12045 L
.12045 .08196 L
.10832 .06984 L
.06984 .02401 L
.04736 .01923 L
.98077 .01923 L
F
0 g
.98077 .95264 m
.97599 .93016 L
.93016 .89168 L
.91804 .87955 L
.87955 .84107 L
.86743 .82895 L
.82895 .79046 L
.81682 .77834 L
.77834 .73986 L
.76622 .72773 L
.72773 .68925 L
.71561 .67713 L
.67713 .63864 L
.665 .62652 L
.62652 .58803 L
.6144 .57591 L
.57591 .53743 L
.56379 .5253 L
.5253 .48682 L
.51318 .4747 L
.4747 .43621 L
.46257 .42409 L
.42409 .3856 L
.41197 .37348 L
.37348 .335 L
.36136 .32287 L
.32287 .28439 L
.31075 .27227 L
.27227 .23378 L
.26014 .22166 L
.22166 .18318 L
.20954 .17105 L
.17105 .13257 L
.15893 .12045 L
.12045 .08196 L
.10832 .06984 L
.06984 .02401 L
.04736 .01923 L
s
.1 g
.98077 .94654 m
.97783 .93016 L
.93016 .88743 L
.92228 .87955 L
.87955 .83683 L
.87168 .82895 L
.82895 .78622 L
.82107 .77834 L
.77834 .73561 L
.77046 .72773 L
.72773 .685 L
.71985 .67713 L
.67713 .6344 L
.66925 .62652 L
.62652 .58379 L
.61864 .57591 L
.57591 .53318 L
.56803 .5253 L
.5253 .48257 L
.51743 .4747 L
.4747 .43197 L
.46682 .42409 L
.42409 .38136 L
.41621 .37348 L
.37348 .33075 L
.3656 .32287 L
.32287 .28015 L
.315 .27227 L
.27227 .22954 L
.26439 .22166 L
.22166 .17893 L
.21378 .17105 L
.17105 .12832 L
.16317 .12045 L
.12045 .07772 L
.11257 .06984 L
.06984 .02217 L
.05346 .01923 L
.98077 .01923 L
F
0 g
.98077 .94654 m
.97783 .93016 L
.93016 .88743 L
.92228 .87955 L
.87955 .83683 L
.87168 .82895 L
.82895 .78622 L
.82107 .77834 L
.77834 .73561 L
.77046 .72773 L
.72773 .685 L
.71985 .67713 L
.67713 .6344 L
.66925 .62652 L
.62652 .58379 L
.61864 .57591 L
.57591 .53318 L
.56803 .5253 L
.5253 .48257 L
.51743 .4747 L
.4747 .43197 L
.46682 .42409 L
.42409 .38136 L
.41621 .37348 L
.37348 .33075 L
.3656 .32287 L
.32287 .28015 L
.315 .27227 L
.27227 .22954 L
.26439 .22166 L
.22166 .17893 L
.21378 .17105 L
.17105 .12832 L
.16317 .12045 L
.12045 .07772 L
.11257 .06984 L
.06984 .02217 L
.05346 .01923 L
s
.98077 .93862 m
.97956 .93016 L
.93016 .88301 L
.92671 .87955 L
.87955 .8324 L
.8761 .82895 L
.82895 .7818 L
.82549 .77834 L
.77834 .73119 L
.77488 .72773 L
.72773 .68058 L
.72428 .67713 L
.67713 .62997 L
.67367 .62652 L
.62652 .57937 L
.62306 .57591 L
.57591 .52876 L
.57246 .5253 L
.5253 .47815 L
.52185 .4747 L
.4747 .42754 L
.47124 .42409 L
.42409 .37694 L
.42063 .37348 L
.37348 .32633 L
.37003 .32287 L
.32287 .27572 L
.31942 .27227 L
.27227 .22512 L
.26881 .22166 L
.22166 .17451 L
.2182 .17105 L
.17105 .1239 L
.1676 .12045 L
.12045 .07329 L
.11699 .06984 L
.06984 .02044 L
.06138 .01923 L
.98077 .01923 L
F
.98077 .93862 m
.97956 .93016 L
.93016 .88301 L
.92671 .87955 L
.87955 .8324 L
.8761 .82895 L
.82895 .7818 L
.82549 .77834 L
.77834 .73119 L
.77488 .72773 L
.72773 .68058 L
.72428 .67713 L
.67713 .62997 L
.67367 .62652 L
.62652 .57937 L
.62306 .57591 L
.57591 .52876 L
.57246 .5253 L
.5253 .47815 L
.52185 .4747 L
.4747 .42754 L
.47124 .42409 L
.42409 .37694 L
.42063 .37348 L
.37348 .32633 L
.37003 .32287 L
.32287 .27572 L
.31942 .27227 L
.27227 .22512 L
.26881 .22166 L
.22166 .17451 L
.2182 .17105 L
.17105 .1239 L
.1676 .12045 L
.12045 .07329 L
.11699 .06984 L
.06984 .02044 L
.06138 .01923 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00=Oooool5o`0000Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd07?ooool01Om4A4Co0000o`000?lb<S;ogMgM01gooooo00?o0000onk^
k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`Co000000So410@
ooooooooooook^k^oc8b<_l0003o<S8bonk^kQGooooo1?l000000ol@413oooooooooo`05o`0000Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd05?ooool4o`000005oa0@4?oooooooooo
oooooom4A4@00_l000000olb<S;ogMgMooooo`0Cooooo`Co000000?o410@ooooooooool00_ooool0
0ol0003ok^k^ooooo`05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01?ooooo1Ol0
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool003Gooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A005ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Nooooo`03ogMgMolb<S;ooooo01cooooo
00?oEEEEojVYZOooool01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06Oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05oooool00ol0003oooooooooo`02ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05Oooool00ol0
003oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Gooooo00?o0000ooooooooool01?ooool00omE
EEGoZJVYooooo`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Booooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000fooooo`03oiRHV?lQ8B7o
k^k^017ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03ojVYZOmEEEGo
oooo013ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41005oooool00ol0003oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool01?ooool00onYZJWoEEEEooooo`0@ooooo`03o`000?oooooooooo01;ooooo00?o
V9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo000gooooo`03oiRHV?lQ
8B7ok^k^00oooooo00?oMgMgoc8b<_ooool07_ooool00omgMgOo<S8booooo`0Mooooo`03ob4Q8Ooo
oooooooo00kooooo00?oMgMgoc8b<_ooool06Oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000005oooool00ol0003oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00oooooo
00?oMgMgoc8b<_ooool05Oooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Gooooo
00?o0000ooooooooool01Oooool00olQ8B7oooooooooo`0>ooooo`03ogMgMolb<S;ooooo01Cooooo
00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000?ooooo000hooooo`03ogMg
MomVIVKooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Looooo`05o`000?lQ8B7o0000oc8b
<_o<c<`07_ooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000005oooool00ol0003ooooooooo
o`05ooooo`03ogMgMomVIVKooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Fooooo`03o`00
0?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Fooooo`03o`000?oooooooooo00Go
oooo00?oEEEEolc<c?ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Kooooo00?oMgMgofIV
I_ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo000iooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Pooooo`03ojVYZOmgMgOooooo
00_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41005oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool01Oooool00onYZJWoMgMgooooo`0;ooooo`03o`000?oooooooooo01Wooooo00Go0000
oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo007ooooo000eooooo`05o`000?nj^[[o
oooooiRHV?l@41003?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01gooooo00Go
410@oooooooooooooooooc8b<P0<ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Oooooo00?o0000ooooooooool00_ooool01Ol0003o
^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
<S8b00cooooo00?o0000ooooooooool05Oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`03ooooo`00=Oooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo
1?l0000Mooooo`Co00007?ooool5o`0000cooooo1?l0000Iooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Eooooo`03oeEEEOmVIVKo000000Cooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c00<ooooo`Co00005Oooool00omEEEGoIVIVo`000005ooooo`Co00005Oooool00omE
EEGoIVIVo`000004ooooo`Go00003?ooool4o`0001Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool002;oooooool00015o`0000;ooooo000Roooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`00
8_ooool00ol0003oooooooooo`3ooooood7ooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oo
oooooooo0?oooooo@Oooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool0oooooom1
ooooo`7o00000Oooool1ooooo`008_ooool2o`0000Cooooo4Ol0003oooooobcooooo0_l00002oooo
o`008_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo00000?oo0000=Ol00006ooooo`7o
00000Oooool1ooooo`008_ooool00ol0003oooooooooo`03ooooo`04o`000?oooooooooooooooooo
0000=?l00006ooooo`7o00000Oooool1ooooo`008_ooool00ol0003oooooooooo`03ooooo`;o0000
1?ooooooo`0003;o00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooo
ool2o`0000Kooooo1?l000000oo<c<co0000o`00003oo`0002Wo00001_ooool1o`00007ooooo0Ooo
ool002;ooooo00?o0000ooooooooool00oooool3o`0000Oooooo1?l00002olc<c?oo0000:?l00006
ooooo`7o00000Oooool1ooooo`008_ooool00ol0003oooooooooo`03ooooo`?o00002Oooooooo`00
02co00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00oooool4o`0000[o
ooooool0000Zo`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`;o00001?ooool4o`0000cooooo
ool0000Xo`0000Gooooo0_l00002ooooo`008_ooool00ol0003oooooooooo`03ooooo`Go00002ooo
ooooo`0002So00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00oooool4
o`000003onKVi_l0003ooooo00Woooooool0000Xo`0000Kooooo0Ol00001ooooo`7ooooo000Roooo
o`03o`000?oooooooooo00?ooooo1_l0000;oooooooo00009ol00006ooooo`7o00000Oooool1oooo
o`008_ooool00ol0003oooooooooo`03ooooo`Go000000?oi^KVo`000?ooool02Oooool2o`000003
olc<c?l0003oVIVI00;o000000?oC4a<o`000?l00000ool0000Mo`0000Kooooo0Ol00001ooooo`7o
oooo000Rooooo`03o`000?oooooooooo00?ooooo1ol0000:ooooo`;o000000?oc<c<o`000?l00000
0ol000000om<C4co0000o`00003oo`0001co00001_ooool1o`00007ooooo0Oooool002;ooooo00?o
0000ooooooooool00oooool6o`000003onKVi_l0003ooooo00Sooooo00Ko0000onKVi_l0003oc<c<
o`000?nIVIT3o`000003oda<C?l0003o00000?oo00006ol00006ooooo`7o00000Oooool1ooooo`00
8_ooool00ol0003oooooooooo`03ooooo`Ko000000?oi^KVo`000?ooool02Oooool2o`000004olc<
c?l0003o0000oiVIV@?o000000?oC4a<o`000?l00000ool0000Jo`0000Kooooo0Ol00001ooooo`7o
oooo000Rooooo`;o00001?ooool;o`0000Oooooo00Co0000onKVi_l0003oc<c<0_l000001OnIVIWo
0000o`000?l0003oC4a<0?oo00006ol00005ooooo`;o00000_ooool002;ooooo00?o0000oooooooo
ool00oooool2o`000003oaTI6Ol0003o000000[o00001?ooool01?l0003oi^KVo`000?o<c<`2o`00
0005oiVIVOl0003o0000o`000?m<C4`0ool0000Jo`0000Kooooo0Ol00001ooooo`7ooooo000Roooo
o`03o`000?oooooooooo00?ooooo0ol000000olI6AWo0000o`000007o`0000;oi^KV0_l00003oooo
o`04o`000?oVi^Ko0000olc<c0;o000000GoVIVIo`000?l0003o0000oda<C03oo`0001Wo00001_oo
ool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00oooool4o`000003oaTI6Ol0003o
000000Go000000Koc<c<o`000?l0003o0000onKVi_l00003ooooo`04o`000?oVi^Ko0000olc<c0;o
000000GoVIVIo`000?l0003o0000oda<C03oo`0001So00001_ooool1o`00007ooooo0Oooool002;o
oooo00?o0000ooooooooool00oooool5o`000004oaTI6Ol0003o0000ofIVIPGo00000_o<c<`00ol0
003oi^KVo`000003ooooo`04o`000?oVi^Ko0000olc<c0;o000000OoVIVIo`000?l0003o0000oda<
C?l0003o6ATI0?oo00005Ol00006ooooo`7o00000Oooool1ooooo`008_ooool00ol0003ooooooooo
o`03ooooo`Ko000000Co6ATIo`000?l0003oIVIV0_l000002?nIVIWo0000o`000?l0003oc<c<o`00
0?oVi^Ko00000oooool01?l0003oi^KVo`000?o<c<`2o`000003oiVIVOl0003o000000?o000000?o
6ATIo`000?l00000ool0000Bo`0000Kooooo0Ol00001ooooo`7ooooo0007ooooo`Go00001Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00?ooooo1ol0
00000olI6AWo0000o`000003o`000008oiVIVOl0003o0000o`000?o<c<co0000onKVi_l00003oooo
o`04o`000?oVi^Ko0000olc<c0;o000000?oVIVIo`000?l000000ol000000olI6AWo0000o`00003o
o`00017o00001_ooool1o`00007ooooo0Oooool000Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A005
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00?ooooo2?l00000
0olI6AWo0000o`000004o`000007oiVIVOl0003o0000olc<c?l0003oi^KVo`000003ooooo`04o`00
0?oVi^Ko0000olc<c0;o000000?oVIVIo`000?l000000ol000000olI6AWo0000o`00003oo`00013o
00001_ooool1o`00007ooooo0Oooool000Sooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo2Ol000001OlI6AWo0000o`000?l0003oIVIV00;o
000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000?ooooo00Co0000onKVi_l0003oc<c<0_l0
00000onIVIWo0000ofIVIP03o`000003oaTI6Ol0003o00000?oo00003ol00006ooooo`7o00000Ooo
ool1ooooo`002Oooool00onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00003
ooooo`[o000000Go6ATIo`000?l0003o0000ofIVIP02o`000007oiVIVOl0003o0000olc<c?l0003o
i^KVo`000003ooooo`04o`000?oVi^Ko0000olc<c0Co000000GoIVIVo`000?l0003o0000oaTI6@3o
o`00013o00001?ooool3o`0000;ooooo000:ooooo`03ogMgMomVIVKooooo00_ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00?ooooo2ol000001OlI6AWo0000o`000?l0
003oIVIV00;o000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000?ooooo00Co0000onKVi_l0
003oc<c<1?l000001OmVIVKo0000o`000?l0003o6ATI0?oo00003ol00006ooooo`7o00000Oooool1
ooooo`002oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool00oooool<o`000005oaTI6Ol0003o0000o`000?mVIVH00_l000001onIVIWo0000o`000?o<
c<co0000onKVi_l000000oooool01?l0003oi^KVo`000?o<c<`4o`000005ofIVI_l0003o0000o`00
0?lI6AT0ool0000>o`0000Kooooo0Ol00001ooooo`7ooooo0007ooooo`05o`000?nj^[[ooooooiRH
V?l@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo3Ol000001OlI
6AWo0000o`000?l0003oIVIV00;o000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000?ooooo
00Go0000onKVi_l0003o0000ok>c/`03o`000005ofIVI_l0003o0000o`000?lI6AT0ool0000=o`00
00Kooooo0Ol00001ooooo`7ooooo0007ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool4o`00
00Kooooo00?o0000ooooooooool00oooool>o`000005oaTI6Ol0003o0000o`000?mVIVH00_l00000
1onIVIWo0000o`000?o<c<co0000onKVi_l000000oooool01Ol0003oi^KVo`000?l0003o/k>c00?o
000000GoIVIVo`000?l0003o0000oaTI6@3oo`0000co00001_ooool1o`00007ooooo0Oooool002;o
oooo00?o0000ooooooooool00oooool?o`000005oaTI6Ol0003o0000o`000?mVIVH00_l000001onI
VIWo0000o`000?o<c<co0000onKVi_l000000oooool2o`000003olc<c?l0003o/k>c00?o000000Go
IVIVo`000?l0003o0000oaTI6@3oo`0000_o00001_ooool1o`00007ooooo0Oooool002;ooooo00?o
0000ooooooooool00oooool@o`000005oaTI6Ol0003o0000o`000?mVIVH00_l000001onIVIWo0000
o`000?o<c<co0000onKVi_l000000oooool2o`000003olc<c?l0003o/k>c00?o000000GoIVIVo`00
0?l0003o0000oaTI6@3oo`0000[o00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000oooo
ooooool00ooooolAo`000005oaTI6Ol0003o0000o`000?mVIVH00_l000001onIVIWo0000o`000?o<
c<co0000onKVi_l000000_ooool01_l0003oi^KVo`000?o<c<co0000ok>c/`?o000000GoIVIVo`00
0?l0003o0000oaTI6@3oo`0000Wo00001_ooool1o`00007ooooo0Oooool002;ooooo0_l00004oooo
oako000000Coi^KVo`000?oooooooooo1Ol000000onc/k?o0000o`00003oo`0000ko00001Oooool2
o`0000;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5Ol000001Olc<c?o0000o`000?l0003o
Ogmo00;o000000Go/k>co`000?l0003oi^KVo`000003ooooo`05o`000?oVi^Ko0000o`000?nc/k<0
0_l000001OmoOgoo0000o`000?l0003o<c<c0?oo00002?l00006ooooo`7o00000Oooool1ooooo`00
8_ooool00ol0003oooooooooo`03oooooaKo000000Go<c<co`000?l0003o0000ogmoO`02o`000005
ok>c/ol0003o0000onKVi_l000000oooool01Ol0003oi^KVo`000?l0003o/k>c00;o000000GoOgmo
o`000?l0003o0000oc<c<`3oo`0000Oo00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000
ooooooooool00ooooolGo`000005oc<c<ol0003o0000o`000?moOgl00_l000001Onc/k?o0000o`00
0?oVi^Ko000000?ooooo00Go0000onKVi_l0003o0000ok>c/`02o`000005ogmoOol0003o0000o`00
0?lc<c<0ool00006o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?o
oooo6?l000001Olc<c?o0000o`000?l0003oOgmo00;o000000Go/k>co`000?l0003oi^KVo`000003
ooooo`05o`000?oVi^Ko0000o`000?nc/k<00_l000001OmoOgoo0000o`000?l0003o<c<c0?oo0000
1Ol00006ooooo`7o00000Oooool1ooooo`008_ooool00ol0003oooooooooo`03oooooaWo000000Go
<c<co`000?l0003o0000ogmoO`02o`000005ok>c/ol0003o0000onKVi_l000000oooool01Ol0003o
i^KVo`000?l0003o/k>c00;o000000GoOgmoo`000?l0003o0000oc<c<`3oo`0000Co00001_ooool1
o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooolJo`000005oc<c<ol0003o0000
o`000?moOgl00ol000001?o<c<co0000onKVi_l00003ooooo`05o`000?oVi^Ko0000o`000?nc/k<0
0_l000001OmoOgoo0000o`000?l0003o<c<c0?oo00000ol00006ooooo`7o00000Oooool1ooooo`00
8_ooool00ol0003oooooooooo`03oooooa_o000000Go<c<co`000?l0003o0000ogmoO`03o`000004
olc<c?l0003oi^KVo`0000?ooooo00Go0000onKVi_l0003o0000ok>c/`02o`000005ogmoOol0003o
0000o`000?lc<c<0ool00002o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`;o00001?oooolL
o`000005oc<c<ol0003o0000o`000?moOgl00ol000001?o<c<co0000onKVi_l00003ooooo`05o`00
0?oVi^Ko0000o`000?nc/k<00_l000001OmoOgoo0000o`000?l0003o<c<c0?oo00000Ol00005oooo
o`;o00000_ooool002;ooooo00?o0000ooooooooool00ooooolMo`000005oc<c<ol0003o0000o`00
0?moOgl00ol000001?o<c<co0000onKVi_l00003ooooo`05o`000?oVi^Ko0000o`000?nc/k<00_l0
00001OmoOgoo0000o`000?l0003o<c<c0?oo00001_ooool1o`00007ooooo0Oooool002;ooooo00?o
0000ooooooooool00ooooolNo`000005oc<c<ol0003o0000o`000?moOgl00ol000001?o<c<co0000
onKVi_l00003ooooo`05o`000?oVi^Ko0000o`000?nc/k<00_l000001OmoOgoo0000o`000?l0003o
<c<c0?ko00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooolOo`00
0005oc<c<ol0003o0000o`000?moOgl00ol000001?o<c<co0000onKVi_l00003ooooo`05o`000?oV
i^Ko0000o`000?nc/k<00_l000001OmoOgoo0000o`000?l0003o<c<c0?go00001_ooool1o`00007o
oooo0Oooool002;ooooo00?o0000ooooooooool00ooooolPo`000005oc<c<ol0003o0000o`000?mo
Ogl00ol000001?o<c<co0000onKVi_l00003ooooo`05o`000?oVi^Ko0000o`000?nc/k<00_l00000
1OmoOgoo0000o`000?l0003o<c<c0?co00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000
ooooooooool00ooooolRo`000004oda<C?l0003o0000ogmoO`?o000000Coc<c<o`000?oVi^Ko0000
0oooool01Ol0003oi^KVo`000?l0003o/k>c00;o000000GoOgmoo`000?l0003o0000oc<c<`3ko`00
00Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?ooooo8ol000001?m<C4co
0000o`000?moOgl3o`000004olc<c?l0003oi^KVo`0000?ooooo00Go0000onKVi_l0003o0000ok>c
/`02o`000005ogmoOol0003o0000o`000?lc<c<0n_l00006ooooo`7o00000Oooool1ooooo`008_oo
ool00ol0003oooooooooo`03ooooobCo000000CoC4a<o`000?l0003oOgmo0ol000001?o<c<co0000
onKVi_l00003ooooo`05o`000?oVi^Ko0000o`000?nc/k<00_l000001OmoOgoo0000o`000?l0003o
<c<c0?Wo00001_ooool1o`00007ooooo0Oooool002;ooooo0_l00004ooooobGo000000CoC4a<o`00
0?l0003oOgmo0ol000001?o<c<co0000onKVi_l00003ooooo`05o`000?oVi^Ko0000o`000?nc/k<0
0_l000001OmoOgoo0000o`000?l0003o<c<c0?So00001Oooool2o`0000;ooooo000Rooooo`03o`00
0?oooooooooo00?ooooo9_l000001Om<C4co0000o`000?l0003oVIVI00;o000000Coc<c<o`000?oV
i^Ko00000_ooool01?l0003oi^KVo`000?o<c<`2o`000004oiVIVOl0003o0000ofIVIP?o000000?o
6ATIo`000?l00000m?l00006ooooo`7o00000Oooool1ooooo`008_ooool00ol0003oooooooooo`03
ooooobOo000000GoC4a<o`000?l0003o0000oiVIV@02o`000004olc<c?l0003oi^KVo`0000;ooooo
00Co0000onKVi_l0003oc<c<0_l000001?nIVIWo0000o`000?mVIVH3o`000003oaTI6Ol0003o0000
0??o00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooolXo`000005
oda<C?l0003o0000o`000?nIVIT00_l000000oo<c<co0000o`000003ooooo`04o`000?oVi^Ko0000
olc<c0;o000000CoVIVIo`000?l0003oIVIV0ol000000olI6AWo0000o`00003bo`0000Kooooo0Ol0
0001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?ooooo:Ol000001Om<C4co0000o`000?l0
003oVIVI00;o000000?oc<c<o`000?l000000oooool01?l0003oi^KVo`000?o<c<`2o`000004oiVI
VOl0003o0000ofIVIP?o000000?o6ATIo`000?l00000lOl00006ooooo`7o00000Oooool1ooooo`00
8_ooool00ol0003oooooooooo`03ooooob[o000000GoC4a<o`000?l0003o0000oiVIV@03o`000003
onKVi_l0003ooooo00;ooooo00Co0000onKVi_l0003oc<c<0_l000001?nIVIWo0000o`000?mVIVH3
o`000003oaTI6Ol0003o00000?3o00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000oooo
ooooool00oooool[o`000005oda<C?l0003o0000o`000?nIVIT00ol000000ooVi^Ko0000ooooo`02
ooooo`04o`000?oVi^Ko0000olc<c0;o000000GoVIVIo`000?l0003o0000oda<C002o`000003oaTI
6Ol0003o00000>oo00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooo
ool/o`000005oda<C?l0003o0000o`000?nIVIT00ol000000ooVi^Ko0000ooooo`02ooooo`04o`00
0?oVi^Ko0000olc<c0;o000000GoVIVIo`000?l0003o0000oda<C002o`000003oaTI6Ol0003o0000
0>ko00001_ooool1o`00007ooooo0Oooool002;ooooo0_l00004ooooobgo000000?oC4a<o`000?l0
00000_l000001Onc/k?o0000o`000?oVi^Ko000000?ooooo00Co0000onKVi_l0003oc<c<0_l00000
1OnIVIWo0000o`000?l0003oC4a<00;o000000?o6ATIo`000?l00000kOl00005ooooo`;o00000_oo
ool002;ooooo00?o0000ooooooooool00oooool^o`000003oda<C?l0003o000000;o000000Go/k>c
o`000?l0003oi^KVo`000003ooooo`04o`000?oVi^Ko0000olc<c0;o000000GoVIVIo`000?l0003o
0000oda<C002o`000003oaTI6Ol0003o00000>co00001_ooool1o`00007ooooo0Oooool002;ooooo
00?o0000ooooooooool00oooool_o`000003oda<C?l0003o000000;o000000Go/k>co`000?l0003o
i^KVo`000003ooooo`04o`000?oVi^Ko0000olc<c0;o000000GoVIVIo`000?l0003o0000oda<C002
o`000003oaTI6Ol0003o00000>_o00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000oooo
ooooool00oooool`o`000003oda<C?l0003o000000;o000000Go/k>co`000?l0003oi^KVo`000003
ooooo`04o`000?oVi^Ko0000olc<c0;o000000GoVIVIo`000?l0003o0000oda<C002o`000003oaTI
6Ol0003o00000>[o00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooo
oolbo`000005ofIVI_l0003o0000o`000?nc/k<00_l000000ooVi^Ko0000ooooo`02ooooo`04o`00
0?oVi^Ko0000olc<c0;o000000GoVIVIo`000?l0003o0000oda<C002o`000003oaTI6Ol0003o0000
0>Wo00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooolco`000005
ofIVI_l0003o0000o`000?nc/k<00_l000000ooVi^Ko0000ooooo`02ooooo`04o`000?oVi^Ko0000
olc<c0;o000000GoVIVIo`000?l0003o0000oda<C002o`000003oaTI6Ol0003o00000>So00001_oo
ool1o`00007ooooo0Oooool001Sooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo00?ooooo=?l000001OmVIVKo0000o`000?l0003o/k>c00;o000000?oi^KVo`000?ooool0
0_ooool01?l0003oi^KVo`000?o<c<`2o`000005oiVIVOl0003o0000o`000?m<C4`00_l000000olI
6AWo0000o`00003Wo`0000Kooooo0Ol00001ooooo`7ooooo000Kooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool00ooooolbo`000004oc<c<ol0003o0000ofIVIP?o000000Go/k>co`00
0?l0003oi^KVo`000003ooooo`04o`000?oVi^Ko0000olc<c0;o000000GoVIVIo`000?l0003o0000
oda<C002o`000003oaTI6Ol0003o00000>Ko00001_ooool1o`00007ooooo0Oooool001cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03oooooc?o000000Co<c<co`000?l0003oIVIV
0ol000001Onc/k?o0000o`000?oVi^Ko000000?ooooo00Co0000onKVi_l0003oc<c<0_l000001OnI
VIWo0000o`000?l0003oC4a<00;o000000?o6ATIo`000?l00000iOl00006ooooo`7o00000Oooool1
ooooo`006oooool00omgMgOo<S8booooo`04ooooo`?o00000ooooolgo`000005ofIVI_l0003o0000
o`000?nc/k<01Ol00002ooooooCo00001?ooool3o`0000;ooooo000Hooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01Oooool00ol0003oooooooooo`03ooooocCo000000Go6ATIo`000?l0003o0000ofIV
IP03o`000006ok>c/ol0003oc<c<o`000?oVi^Ko00000oooool01?l0003oi^KVo`000?o<c<`3o`00
0004ogmoOol0003o0000oda<C>Oo00001_ooool1o`00007ooooo0Oooool001Sooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`03ooooocGo000000Go6ATIo`000?l0003o0000ofIVIP03
o`000006ok>c/ol0003oc<c<o`000?oVi^Ko00000oooool01?l0003oi^KVo`000?o<c<`3o`000004
ogmoOol0003o0000oda<C>Ko00001_ooool1o`00007ooooo0Oooool001Sooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`03ooooocKo000000Go6ATIo`000?l0003o0000ofIVIP03o`00
0006ok>c/ol0003oc<c<o`000?oVi^Ko00000oooool01?l0003oi^KVo`000?o<c<`3o`000004ogmo
Ool0003o0000oda<C>Go00001_ooool1o`00007ooooo0Oooool001Sooooo1?l00006ooooo`03o`00
0?oooooooooo00?ooooo=ol000001OlI6AWo0000o`000?l0003oIVIV00?o000000Ko/k>co`000?o<
c<co0000onKVi_l00003ooooo`04o`000?oVi^Ko0000olc<c0?o000000GoOgmoo`000?l0003o0000
oc<c<`3So`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?ooooo>?l0
00001OlI6AWo0000o`000?l0003oIVIV00?o000000Ko/k>co`000?o<c<co0000onKVi_l00003oooo
o`04o`000?oVi^Ko0000olc<c0?o000000GoOgmoo`000?l0003o0000oc<c<`3Ro`0000Kooooo0Ol0
0001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?ooooo>Ol000001OlI6AWo0000o`000?l0
003oIVIV00?o000000Ko/k>co`000?o<c<co0000onKVi_l00003ooooo`04o`000?oVi^Ko0000olc<
c0?o000000GoOgmoo`000?l0003o0000oc<c<`3Qo`0000Kooooo0Ol00001ooooo`7ooooo000Roooo
o`03o`000?oooooooooo00?ooooo>_l000001OlI6AWo0000o`000?l0003oIVIV00Go000000Coc<c<
o`000?oVi^Ko00000oooool01?l0003oi^KVo`000?o<c<`4o`000004ofIVI_l0003o0000oc<c<n3o
00001_ooool1o`00007ooooo0Oooool002;ooooo0_l00004oooooc_o000000Go6ATIo`000?l0003o
0000ofIVIP02o`000007oiVIVOl0003o0000olc<c?l0003oi^KVo`000003ooooo`04o`000?oVi^Ko
0000olc<c0Co000000CoIVIVo`000?l0003o<c<cgol00005ooooo`;o00000_ooool002;ooooo00?o
0000ooooooooool00ooooollo`000005oaTI6Ol0003o0000o`000?mVIVH00_l000001onIVIWo0000
o`000?o<c<co0000onKVi_l000000oooool01?l0003oi^KVo`000?o<c<`4o`000004ofIVI_l0003o
0000oc<c<mko00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooolm
o`000005oaTI6Ol0003o0000o`000?mVIVH00_l000001onIVIWo0000o`000?o<c<co0000onKVi_l0
00000oooool01?l0003oi^KVo`000?o<c<`4o`000004ofIVI_l0003o0000oc<c<mgo00001_ooool1
o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooolno`000003oaTI6Ol0003o0000
00Co000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000?ooooo00Go0000onKVi_l0003o0000
ok>c/`03o`000004ofIVI_l0003o0000oc<c<mco00001_ooool1o`00007ooooo0Oooool002;ooooo
00?o0000ooooooooool00oooooloo`000004oaTI6Ol0003o0000oda<C0?o000000OoVIVIo`000?l0
003oc<c<o`000?oVi^Ko000000?ooooo00Go0000onKVi_l0003o0000ok>c/`03o`000004ofIVI_l0
003o0000oc<c<m_o00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooo
oom0o`000004oaTI6Ol0003o0000oda<C0?o000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko0000
00?ooooo00Go0000onKVi_l0003o0000ok>c/`03o`000004ofIVI_l0003o0000oc<c<m[o00001_oo
ool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooom1o`000004oaTI6Ol0003o
0000oda<C0?o000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000?ooooo00Go0000onKVi_l0
003o0000ok>c/`03o`000004ofIVI_l0003o0000oc<c<mWo00001_ooool1o`00007ooooo0Oooool0
02;ooooo00?o0000ooooooooool00ooooom2o`000004oaTI6Ol0003o0000oda<C0?o000000OoVIVI
o`000?l0003oc<c<o`000?oVi^Ko000000?ooooo00Go0000onKVi_l0003o0000ok>c/`03o`000004
ofIVI_l0003o0000oc<c<mSo00001_ooool1o`00007ooooo0Oooool002;ooooo0_l00004ooooodoo
000000?oi^KVo`000?ooool00_ooool01Ol0003oi^KVo`000?l0003o/k>c00?o000000CoIVIVo`00
0?l0003o<c<ceol00005ooooo`;o00000_ooool002;ooooo00?o0000ooooooooool00ooooom6o`00
0005oc<c<ol0003o0000o`000?moOgl00_l000001Onc/k?o0000o`000?oVi^Ko000000?ooooo00Go
0000onKVi_l0003o0000ok>c/`03o`000004ofIVI_l0003o0000oc<c<mKo00001_ooool1o`00007o
oooo0Oooool002;ooooo00?o0000ooooooooool00ooooom7o`000005oc<c<ol0003o0000o`000?mo
Ogl00_l000001Onc/k?o0000o`000?oVi^Ko000000?ooooo00Go0000onKVi_l0003o0000ok>c/`03
o`000004ofIVI_l0003o0000oc<c<mGo00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000
ooooooooool00ooooom8o`000005oc<c<ol0003o0000o`000?moOgl00_l000001Onc/k?o0000o`00
0?oVi^Ko000000?ooooo00Go0000onKVi_l0003o0000ok>c/`03o`000004ofIVI_l0003o0000oc<c
<mCo00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooom9o`000005
oc<c<ol0003o0000o`000?moOgl00_l000001Onc/k?o0000o`000?oVi^Ko000000?ooooo00Go0000
onKVi_l0003o0000ok>c/`03o`000003ofIVI_l0003o00000=Co00001_ooool1o`00007ooooo0Ooo
ool002;ooooo00?o0000ooooooooool00ooooom:o`000005oc<c<ol0003o0000o`000?moOgl00_l0
00001Onc/k?o0000o`000?oVi^Ko000000?ooooo00Go0000onKVi_l0003o0000ok>c/`03o`000003
ofIVI_l0003oC4a<0=?o00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool0
0ooooom;o`000005oc<c<ol0003o0000o`000?moOgl00_l000001Onc/k?o0000o`000?oVi^Ko0000
00?ooooo00Go0000onKVi_l0003o0000ok>c/`03o`000003ofIVI_l0003oC4a<0=;o00001_ooool1
o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooom<o`000005oc<c<ol0003o0000
o`000?moOgl00_l000001Onc/k?o0000o`000?oVi^Ko000000?ooooo00Go0000onKVi_l0003o0000
ok>c/`05o`000003oda<C?l0003o00000<oo00001_ooool1o`00007ooooo0Oooool002;ooooo0_l0
0004ooooodgo000000Go<c<co`000?l0003o0000ogmoO`02o`000005ok>c/ol0003o0000onKVi_l0
00000oooool01Ol0003oi^KVo`000?l0003o/k>c00;o000000CoOgmoo`000?l0003oC4a<d?l00005
ooooo`;o00000_ooool002;ooooo00?o0000ooooooooool00ooooom>o`000005oc<c<ol0003o0000
o`000?moOgl00_l000001Onc/k?o0000o`000?oVi^Ko000000?ooooo00Go0000onKVi_l0003o0000
ok>c/`02o`000004ogmoOol0003o0000oda<C<oo00001_ooool1o`00007ooooo0Oooool002;ooooo
00?o0000ooooooooool00ooooom?o`000005oc<c<ol0003o0000o`000?moOgl00_l000001Onc/k?o
0000o`000?oVi^Ko000000?ooooo00Go0000onKVi_l0003o0000ok>c/`02o`000004ogmoOol0003o
0000oda<C<ko00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooom@
o`000005oc<c<ol0003o0000o`000?moOgl00_l000001Onc/k?o0000o`000?oVi^Ko000000?ooooo
00?o0000onKVi_l000001?l000001?moOgoo0000o`000?m<C4c=o`0000Kooooo0Ol00001ooooo`7o
oooo000Rooooo`03o`000?oooooooooo00?oooooDOl000001Olc<c?o0000o`000?l0003oOgmo00;o
000000Go/k>co`000?l0003oi^KVo`000003ooooo`04o`000?oVi^Ko0000olc<c0?o000000CoOgmo
o`000?l0003oC4a<c?l00006ooooo`7o00000Oooool1ooooo`008_ooool00ol0003oooooooooo`03
oooooe;o000000Go<c<co`000?l0003o0000ogmoO`02o`000005ok>c/ol0003o0000onKVi_l00000
0oooool01?l0003oi^KVo`000?o<c<`3o`000004ogmoOol0003o0000oda<C<_o00001_ooool1o`00
007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooomCo`000005oc<c<ol0003o0000o`00
0?moOgl00_l000001Onc/k?o0000o`000?oVi^Ko000000?ooooo00Co0000onKVi_l0003oc<c<0ol0
00001?moOgoo0000o`000?m<C4c:o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oo
oooooooo00?oooooE?l000001Olc<c?o0000o`000?l0003oOgmo00;o000000Go/k>co`000?l0003o
i^KVo`000003ooooo`04o`000?oVi^Ko0000olc<c0?o000000CoOgmoo`000?l0003oC4a<bOl00006
ooooo`7o00000Oooool1ooooo`008_ooool2o`0000CoooooEOl000001Olc<c?o0000o`000?l0003o
Ogmo00;o000000Go/k>co`000?l0003oi^KVo`000003ooooo`04o`000?oVi^Ko0000olc<c0?o0000
00CoOgmoo`000?l0003oC4a<b?l00005ooooo`;o00000_ooool002;ooooo00?o0000ooooooooool0
0ooooomDo`000004oaTI6Ol0003o0000oda<C0?o000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko
000000;ooooo00Co0000onKVi_l0003oc<c<0_l000001OnIVIWo0000o`000?l0003oC4a<00;o0000
00?o6ATIo`000?l00000`ol00006ooooo`7o00000Oooool1ooooo`008_ooool00ol0003ooooooooo
o`03oooooeGo000000Co6ATIo`000?l0003oC4a<0ol000001onIVIWo0000o`000?o<c<co0000onKV
i_l000000_ooool01?l0003oi^KVo`000?o<c<`2o`000005oiVIVOl0003o0000o`000?m<C4`00_l0
00000olI6AWo0000o`000032o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooo
oooo00?oooooE_l000001?lI6AWo0000o`000?m<C4`3o`000007oiVIVOl0003o0000olc<c?l0003o
i^KVo`000002ooooo`04o`000?oVi^Ko0000olc<c0;o000000GoVIVIo`000?l0003o0000oda<C002
o`000003oaTI6Ol0003o00000<7o00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000oooo
ooooool00ooooomGo`000004oaTI6Ol0003o0000oda<C0?o000000OoVIVIo`000?l0003oc<c<o`00
0?oVi^Ko000000;ooooo00Co0000onKVi_l0003oc<c<0_l000001OnIVIWo0000o`000?l0003oC4a<
00;o000000?o6ATIo`000?l00000`?l00006ooooo`7o00000Oooool1ooooo`008_ooool00ol0003o
ooooooooo`03oooooeSo000000Co6ATIo`000?l0003oC4a<0ol000001onIVIWo0000o`000?o<c<co
0000onKVi_l000000_ooool01?l0003oi^KVo`000?o<c<`2o`000005oiVIVOl0003o0000o`000?m<
C4`00_l000000olI6AWo0000o`00002oo`0000Kooooo0Ol00001ooooo`7ooooo0009ooooo`03o`00
0?o^k^kooooo00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`03oooooeWo000000Co6ATIo`000?l0003oC4a<0ol000001onIVIWo0000o`000?o<c<co
0000onKVi_l000000_ooool01?l0003oi^KVo`000?o<c<`2o`000003oiVIVOl0003o000000Co0000
00?o6ATIo`000?l00000__l00006ooooo`7o00000Oooool1ooooo`002Oooool00omEEEGoZJVYoooo
o`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00?oooooF_l0
00001?lI6AWo0000o`000?m<C4`3o`000007oiVIVOl0003o0000olc<c?l0003oi^KVo`000002oooo
o`04o`000?oVi^Ko0000olc<c0;o000000CoVIVIo`000?l0003oIVIV0ol000000olI6AWo0000o`00
002mo`0000Kooooo0Ol00001ooooo`7ooooo0009ooooo`03ojVYZOmEEEGooooo013ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03oooooe_o000000Co6ATIo`000?l0003oC4a<1?l0
00001_nc/k?o0000olc<c?l0003oi^KVo`0000;ooooo00Co0000onKVi_l0003oc<c<0_l000001?nI
VIWo0000o`000?mVIVH3o`000003oaTI6Ol0003o00000;co00001_ooool1o`00007ooooo0Oooool0
00[ooooo00?o8B4Qooooooooool03_ooool00omgMgOo<S8booooo`04ooooo`?o00000ooooomLo`00
0004oaTI6Ol0003o0000oda<C0Co000000Ko/k>co`000?o<c<co0000onKVi_l00002ooooo`04o`00
0?oVi^Ko0000olc<c0;o000000CoVIVIo`000?l0003oIVIV0ol000000olI6AWo0000o`00002ko`00
00Cooooo0ol00002ooooo`002_ooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`03oooooego000000Co6ATIo`000?l0003oC4a<1?l00000
1_nc/k?o0000olc<c?l0003oi^KVo`0000;ooooo00Co0000onKVi_l0003oc<c<0_l000001?nIVIWo
0000o`000?mVIVH3o`000003oaTI6Ol0003o00000;[o00001_ooool1o`00007ooooo0Oooool000[o
oooo00?oZJVYogMgMoooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?o
ooooG_l000001?lI6AWo0000o`000?m<C4`4o`000006ok>c/ol0003oc<c<o`000?oVi^Ko00000_oo
ool01?l0003oi^KVo`000?o<c<`2o`000004oiVIVOl0003o0000ofIVIP?o000000?o6ATIo`000?l0
0000^Ol00006ooooo`7o00000Oooool1ooooo`001oooool01Ol@413ooooooooooooooooo<S8b00co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03oooooeoo000000Go6ATIo`000?l0
003o0000ofIVIP03o`000006ok>c/ol0003oc<c<o`000?oVi^Ko00000_ooool01?l0003oi^KVo`00
0?o<c<`2o`000004oiVIVOl0003o0000ofIVIP?o000000?o6ATIo`000?l00000^?l00006ooooo`7o
00000Oooool1ooooo`001oooool5o`0000cooooo1?l00006ooooo`03o`000?oooooooooo00?ooooo
H?l000001OlI6AWo0000o`000?l0003oIVIV00?o000000Ko/k>co`000?o<c<co0000onKVi_l00002
ooooo`04o`000?oVi^Ko0000olc<c0;o000000CoVIVIo`000?l0003oIVIV0ol000000olI6AWo0000
o`00002go`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?oooooHOl0
00001OlI6AWo0000o`000?l0003oIVIV00?o000000Ko/k>co`000?o<c<co0000onKVi_l00002oooo
o`04o`000?oVi^Ko0000olc<c0;o000000CoVIVIo`000?l0003oIVIV0ol000000olI6AWo0000o`00
002fo`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?oooooH_l00000
1OlI6AWo0000o`000?l0003oIVIV00?o000000Ko/k>co`000?o<c<co0000onKVi_l00002ooooo`04
o`000?oVi^Ko0000olc<c0;o000000CoVIVIo`000?l0003oIVIV0ol000000olI6AWo0000o`00002e
o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?oooooHol000001OlI
6AWo0000o`000?l0003oIVIV00?o000000Ko/k>co`000?o<c<co0000onKVi_l00002ooooo`04o`00
0?oVi^Ko0000olc<c0;o000000CoVIVIo`000?l0003oIVIV0ol000000olI6AWo0000o`00002do`00
00Kooooo0Ol00001ooooo`7ooooo000Rooooo`;o00001?oooomTo`000005oaTI6Ol0003o0000o`00
0?mVIVH00ol000001_nc/k?o0000olc<c?l0003oi^KVo`0000;ooooo`ol00005ooooo`;o00000_oo
ool002;ooooo00?o0000ooooooooool00ooooomVo`000004oc<c<ol0003o0000ofIVIP?o000000Go
/k>co`000?l0003oi^KVo`000004ooooo`05o`000?oVi^Ko0000o`000?nc/k<00_l000001OmoOgoo
0000o`000?l0003o<c<c0;Go00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000oooooooo
ool00ooooomWo`000004oc<c<ol0003o0000ofIVIP?o000000Co/k>co`000?l0003oi^KV0_l00003
ooooo`05o`000?oVi^Ko0000o`000?nc/k<00_l000001OmoOgoo0000o`000?l0003o<c<c0;Co0000
1_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooomXo`000004oc<c<ol0
003o0000ofIVIP?o000000?o/k>co`000?l000000_oVi^H01_l0003ooooooooooooooooo0000onKV
iP;o000000Co/k>co`000?l0003oOgmo0ol000000olc<c?o0000o`00002ao`0000Kooooo0Ol00001
ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?oooooJOl000001?lc<c?o0000o`000?mVIVH3
o`000006ok>c/ol0003o0000o`000?oVi^Ko00000oooool01Ol0003oi^KVo`000?l0003o/k>c00;o
000000GoOgmoo`000?l0003o0000oc<c<`2bo`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03
o`000?oooooooooo00?oooooJ_l000001?lc<c?o0000o`000?mVIVH3o`000006ok>c/ol0003oc<c<
o`000?oVi^Ko00000oooool01Ol0003oi^KVo`000?l0003o/k>c00;o000000GoOgmoo`000?l0003o
0000oc<c<`2ao`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?ooooo
Jol000001?lc<c?o0000o`000?mVIVH3o`000006ok>c/ol0003oc<c<o`000?oVi^Ko00000oooool0
1Ol0003oi^KVo`000?l0003o/k>c00;o000000GoOgmoo`000?l0003o0000oc<c<`2`o`0000Kooooo
0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?oooooK?l000001?lc<c?o0000o`00
0?mVIVH5o`000004olc<c?l0003oi^KVo`0000?ooooo00Go0000onKVi_l0003o0000ok>c/`02o`00
0005ogmoOol0003o0000o`000?lc<c<0[ol00006ooooo`7o00000Oooool1ooooo`008_ooool2o`00
00CoooooKOl000001?lc<c?o0000o`000?mVIVH2o`000007oiVIVOl0003o0000olc<c?l0003oi^KV
o`000003ooooo`05o`000?oVi^Ko0000o`000?nc/k<00_l000001OmoOgoo0000o`000?l0003o<c<c
0:ko00001Oooool2o`0000;ooooo000Rooooo`03o`000?oooooooooo00?oooooK_l000001?lc<c?o
0000o`000?mVIVH2o`000007oiVIVOl0003o0000olc<c?l0003oi^KVo`000003ooooo`05o`000?oV
i^Ko0000o`000?nc/k<00_l000001OmoOgoo0000o`000?l0003o<c<c0:go00001_ooool1o`00007o
oooo0Oooool002;ooooo00?o0000ooooooooool00ooooom_o`000004oc<c<ol0003o0000ofIVIP;o
000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000?ooooo00Go0000onKVi_l0003o0000ok>c
/`02o`000005ogmoOol0003o0000o`000?lc<c<0[?l00006ooooo`7o00000Oooool1ooooo`008_oo
ool00ol0003oooooooooo`03ooooog3o000000?o<c<co`000?l000000ol000001onIVIWo0000o`00
0?o<c<co0000onKVi_l000000oooool01Ol0003oi^KVo`000?l0003o/k>c00;o000000GoOgmoo`00
0?l0003o0000oc<c<`2[o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo
00?oooooLOl000000olc<c?o0000oda<C003o`000007oiVIVOl0003o0000olc<c?l0003oi^KVo`00
0003ooooo`05o`000?oVi^Ko0000o`000?nc/k<00_l000001OmoOgoo0000o`000?l0003o<c<c0:[o
00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooombo`000003oc<c
<ol0003oC4a<00?o000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000?ooooo00Go0000onKV
i_l0003o0000ok>c/`02o`000005ogmoOol0003o0000o`000?lc<c<0ZOl00006ooooo`7o00000Ooo
ool1ooooo`008_ooool00ol0003oooooooooo`03ooooogGo000000GoC4a<o`000?l0003o0000oiVI
V@02o`000004olc<c?l0003oi^KVo`0000?ooooo00Go0000onKVi_l0003o0000ok>c/`02o`000005
ogmoOol0003o0000o`000?lc<c<0Z?l00006ooooo`7o00000Oooool1ooooo`008_ooool00ol0003o
ooooooooo`03ooooogKo000000GoC4a<o`000?l0003o0000oiVIV@02o`000004olc<c?l0003oi^KV
o`0000?ooooo00Go0000onKVi_l0003o0000ok>c/`02o`000005ogmoOol0003o0000o`000?lc<c<0
Yol00006ooooo`7o00000Oooool1ooooo`008_ooool2o`0000CoooooMol000000om<C4co0000o`00
0004o`000004olc<c?l0003oi^KVo`0000?ooooo00Go0000onKVi_l0003o0000ok>c/`02o`000005
ogmoOol0003o0000o`000?lc<c<0Y_l00005ooooo`;o00000_ooool002;ooooo00?o0000oooooooo
ool00ooooomho`000004oda<C?l0003o0000ogmoO`?o000000Coc<c<o`000?oVi^Ko00000_ooool0
1_l0003oi^KVo`000?o<c<co0000ok>c/`?o000000GoIVIVo`000?l0003o0000oaTI6@2To`0000Ko
oooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?oooooNOl000001?m<C4co0000
o`000?moOgl3o`000004olc<c?l0003oi^KVo`0000;ooooo00Ko0000onKVi_l0003oc<c<o`000?nc
/k<3o`000005ofIVI_l0003o0000o`000?lI6AT0Xol00006ooooo`7o00000Oooool1ooooo`008_oo
ool00ol0003oooooooooo`03ooooog[o000000CoC4a<o`000?l0003oOgmo0ol000001?o<c<co0000
onKVi_l00002ooooo`06o`000?oVi^Ko0000olc<c?l0003o/k>c0ol000000omVIVKo0000o`00002T
o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?oooooNol000001?m<
C4co0000o`000?moOgl3o`000004olc<c?l0003oi^KVo`0000;ooooo00Ko0000onKVi_l0003oc<c<
o`000?nc/k<3o`000003ofIVI_l0003o00000:?o00001_ooool1o`00007ooooo0Oooool002;ooooo
00?o0000ooooooooool00ooooomlo`000004oda<C?l0003o0000ogmoO`?o000000Coc<c<o`000?oV
i^Ko00000_ooool01_l0003oi^KVo`000?o<c<co0000ok>c/`?o000000?oIVIVo`000?m<C4`0X_l0
0006ooooo`7o00000Oooool1ooooo`008_ooool00ol0003oooooooooo`03oooooggo000000CoC4a<
o`000?l0003oOgmo1Ol000002_oVi^Ko0000oooooooooooo0000onKVi_l0003oc<c<o`000?nc/k<3
o`000003ofIVI_l0003oC4a<0:7o00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000oooo
ooooool00ooooomno`000004oda<C?l0003o0000ogmoO`;o000000Go/k>co`000?l0003oi^KVo`00
0002ooooo`06o`000?oVi^Ko0000olc<c?l0003o/k>c1Ol000000om<C4co0000o`00002No`0000Ko
oooo0Ol00001ooooo`7ooooo000Rooooo`;o00001?oooomoo`000004oda<C?l0003o0000ogmoO`;o
000000Go/k>co`000?l0003oi^KVo`000002ooooo`06o`000?oVi^Ko0000olc<c?l0003o/k>c1Ol0
00000om<C4co0000o`00002Mo`0000Gooooo0_l00002ooooo`008_ooool00ol0003oooooooooo`03
oooooh3o000000CoC4a<o`000?l0003oOgmo0_l000001Onc/k?o0000o`000?oVi^Ko000000;ooooo
00So0000onKVi_l0003oc<c<o`000?nc/k?o0000oiVIV@?o000000?oC4a<o`000?l00000W?l00006
ooooo`7o00000Oooool1ooooo`008_ooool00ol0003oooooooooo`03oooooh7o000000CoC4a<o`00
0?l0003oOgmo0_l000001Onc/k?o0000o`000?oVi^Ko000000;ooooo00So0000onKVi_l0003oc<c<
o`000?nc/k?o0000oiVIV@?o000000?oC4a<o`000?l00000Vol00006ooooo`7o00000Oooool1oooo
o`008_ooool00ol0003oooooooooo`03oooooh;o000000CoC4a<o`000?l0003oOgmo0_l000001Onc
/k?o0000o`000?oVi^Ko000000;ooooo00Co0000onKVi_l0003oc<c<0ol000001OnIVIWo0000o`00
0?l0003oC4a<09co00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooo
oon3o`000004oda<C?l0003o0000ogmoO`;o000000Go/k>co`000?l0003oi^KVo`000002ooooo`03
o`000?oVi^Ko000000;oc<c<0_l000001OnIVIWo0000o`000?l0003oC4a<09_o00001_ooool1o`00
007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooon7o`000004ogmoOol0003o0000ok>c
/`;o000000Koi^KVo`000?ooooooooooo`000?oVi^H2o`000004olc<c?l0003o0000oiVIV@?o0000
00?oC4a<o`000?l00000V?l00006ooooo`7o00000Oooool1ooooo`004?ooool4o`000008oa0@4?oo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooooooo00?oooooQ?l000001Olc
<c?o0000o`000?l0003oOgmo00;o000000Go/k>co`000?l0003oi^KVo`000002ooooo`05o`000?oV
i^Koi^KVo`000?o<c<`00_l000001OnIVIWo0000o`000?l0003oC4a<09Wo00001_ooool1o`00007o
oooo0Oooool001;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Ko
oooo00?o0000ooooooooool00ooooon5o`000005oc<c<ol0003o0000o`000?moOgl00_l000001Onc
/k?o0000o`000?oVi^Ko000000;ooooo0_l000000ooVi^Ko0000olc<c002o`000005oiVIVOl0003o
0000o`000?m<C4`0V?l00006ooooo`7o00000Oooool1ooooo`004_ooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41001_ooool3o`0000?oooooQ_l000001Olc<c?o0000o`00
0?l0003oOgmo00;o000000Go/k>co`000?l0003oi^KVo`000003ooooo`04o`000?oVi^Ko0000olc<
c0;o000000GoVIVIo`000?l0003o0000oda<C02Go`0000Cooooo0ol00002ooooo`004_ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`03
ooooohGo000000Go6ATIo`000?l0003o0000ofIVIP02o`000007oiVIVOl0003o0000olc<c?l0003o
i^KVo`000003ooooo`04o`000?oVi^Ko0000olc<c0;o000000GoVIVIo`000?l0003o0000oda<C02F
o`0000Kooooo0Ol00001ooooo`7ooooo000Booooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo00?oooooQ_l000001OlI6AWo0000o`000?l0
003oIVIV00;o000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000?ooooo00Co0000onKVi_l0
003oc<c<0_l000001OnIVIWo0000o`000?l0003oC4a<09Go00001_ooool1o`00007ooooo0Oooool0
01;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000
ooooooooool00ooooon7o`000005oaTI6Ol0003o0000o`000?mVIVH00_l000001onIVIWo0000o`00
0?o<c<co0000onKVi_l000000oooool01?l0003oi^KVo`000?o<c<`2o`000005oiVIVOl0003o0000
o`000?m<C4`0U?l00006ooooo`7o00000Oooool1ooooo`004_ooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`03ooooohSo000000Go6ATI
o`000?l0003o0000ofIVIP02o`000007oiVIVOl0003o0000olc<c?l0003oi^KVo`000003ooooo`04
o`000?oVi^Ko0000olc<c0;o000000OoVIVIo`000?l0003o0000oda<C?l0003o6ATI097o00001_oo
ool1o`00007ooooo0Oooool0013ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Kooooo00?o0000ooooooooool00ooooon9o`000005oaTI6Ol0003o0000o`000?mVIVH0
0_l000001onIVIWo0000o`000?o<c<co0000onKVi_l000000oooool01?l0003oi^KVo`000?o<c<`2
o`000003oiVIVOl0003o000000?o000000?o6ATIo`000?l00000S_l00006ooooo`7o00000Oooool1
ooooo`008_ooool00ol0003oooooooooo`03oooooh[o000000Go6ATIo`000?l0003o0000ofIVIP02
o`000007oiVIVOl0003o0000olc<c?l0003oi^KVo`000003ooooo`04o`000?oVi^Ko0000olc<c0;o
000000?oVIVIo`000?l000000ol000000olI6AWo0000o`00002=o`0000Kooooo0Ol00001ooooo`7o
oooo000Rooooo`03o`000?oooooooooo00?oooooRol000001OlI6AWo0000o`000?l0003oIVIV00;o
000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000?ooooo00Co0000onKVi_l0003oc<c<0_l0
00000onIVIWo0000o`000003o`000003oaTI6Ol0003o000008co00001_ooool1o`00007ooooo0Ooo
ool002;ooooo00?o0000ooooooooool00ooooon<o`000005oaTI6Ol0003o0000o`000?mVIVH00_l0
00001onIVIWo0000o`000?o<c<co0000onKVi_l000000oooool01?l0003oi^KVo`000?o<c<`2o`00
0003oiVIVOl0003oIVIV00?o000000?o6ATIo`000?l00000Rol00006ooooo`7o00000Oooool1oooo
o`008_ooool2o`0000CoooooSOl000001OlI6AWo0000o`000?l0003oIVIV00;o000000OoVIVIo`00
0?l0003oc<c<o`000?oVi^Ko000000?ooooo00Co0000onKVi_l0003oc<c<1?l000001OmVIVKo0000
o`000?l0003o6ATI08co00001Oooool2o`0000;ooooo000Rooooo`03o`000?oooooooooo00?ooooo
S_l000001OlI6AWo0000o`000?l0003oIVIV00;o000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko
000000?ooooo00Co0000onKVi_l0003oc<c<1?l000001OmVIVKo0000o`000?l0003o6ATI08_o0000
1_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooon?o`000005oaTI6Ol0
003o0000o`000?mVIVH00_l000001onIVIWo0000o`000?o<c<co0000onKVi_l000000oooool01?l0
003oi^KVo`000?o<c<`4o`000005ofIVI_l0003o0000o`000?lI6AT0R_l00006ooooo`7o00000Ooo
ool1ooooo`008_ooool00ol0003oooooooooo`03oooooi3o000000Go6ATIo`000?l0003o0000ofIV
IP02o`000007oiVIVOl0003o0000olc<c?l0003oi^KVo`000003ooooo`05o`000?oVi^Ko0000o`00
0?nc/k<00ol000001OmVIVKo0000o`000?l0003o6ATI08Wo00001_ooool1o`00007ooooo0Oooool0
02;ooooo00?o0000ooooooooool00ooooonAo`000005oaTI6Ol0003o0000o`000?mVIVH00_l00000
1onIVIWo0000o`000?o<c<co0000onKVi_l000000oooool01Ol0003oi^KVo`000?l0003o/k>c00?o
000000GoIVIVo`000?l0003o0000oaTI6@28o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03
o`000?oooooooooo00?oooooT_l000001OlI6AWo0000o`000?l0003oIVIV00;o000000OoVIVIo`00
0?l0003oc<c<o`000?oVi^Ko000000?ooooo0_l000000oo<c<co0000ok>c/`03o`000005ofIVI_l0
003o0000o`000?lI6AT0Qol00006ooooo`7o00000Oooool1ooooo`008_ooool00ol0003ooooooooo
o`03oooooi?o000000Go6ATIo`000?l0003o0000ofIVIP02o`000007oiVIVOl0003o0000olc<c?l0
003oi^KVo`000003ooooo`;o000000?oc<c<o`000?nc/k<00ol000001OmVIVKo0000o`000?l0003o
6ATI08Ko00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooonDo`00
0005oaTI6Ol0003o0000o`000?mVIVH00_l000001onIVIWo0000o`000?o<c<co0000onKVi_l00000
0_ooool01_l0003oi^KVo`000?o<c<co0000ok>c/`?o000000GoIVIVo`000?l0003o0000oaTI6@25
o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`;o00001?oooonQo`000004onKVi_l0003ooooo
ooooo`Go000000?o/k>co`000?l00000R_l00005ooooo`;o00000_ooool002;ooooo00?o0000oooo
ooooool00ooooonHo`000005oc<c<ol0003o0000o`000?moOgl00_l000001Onc/k?o0000o`000?oV
i^Ko000000?ooooo00Go0000onKVi_l0003o0000ok>c/`02o`000005ogmoOol0003o0000o`000?lc
<c<0Q?l00006ooooo`7o00000Oooool1ooooo`008_ooool00ol0003oooooooooo`03oooooiWo0000
00Go<c<co`000?l0003o0000ogmoO`02o`000005ok>c/ol0003o0000onKVi_l000000oooool01Ol0
003oi^KVo`000?l0003o/k>c00;o000000GoOgmoo`000?l0003o0000oc<c<`23o`0000Kooooo0Ol0
0001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?oooooV_l000001Olc<c?o0000o`000?l0
003oOgmo00;o000000Go/k>co`000?l0003oi^KVo`000003ooooo`05o`000?oVi^Ko0000o`000?nc
/k<00_l000001OmoOgoo0000o`000?l0003o<c<c08;o00001_ooool1o`00007ooooo0Oooool002;o
oooo00?o0000ooooooooool00ooooonKo`000005oc<c<ol0003o0000o`000?moOgl00_l000001Onc
/k?o0000o`000?oVi^Ko000000?ooooo00Go0000onKVi_l0003o0000ok>c/`02o`000005ogmoOol0
003o0000o`000?lc<c<0POl00006ooooo`7o00000Oooool1ooooo`008_ooool00ol0003ooooooooo
o`03oooooico000000Go<c<co`000?l0003o0000ogmoO`02o`000005ok>c/ol0003o0000onKVi_l0
00000oooool01Ol0003oi^KVo`000?l0003o/k>c00;o000000GoOgmoo`000?l0003o0000oc<c<`20
o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?oooooWOl000001Olc
<c?o0000o`000?l0003oOgmo00?o000000Coc<c<o`000?oVi^Ko00000oooool01Ol0003oi^KVo`00
0?l0003o/k>c00;o000000GoOgmoo`000?l0003o0000oc<c<`1oo`0000Kooooo0Ol00001ooooo`7o
oooo000Rooooo`03o`000?oooooooooo00?oooooW_l000001Olc<c?o0000o`000?l0003oOgmo00?o
000000Coc<c<o`000?oVi^Ko00000oooool01Ol0003oi^KVo`000?l0003o/k>c00;o000000GoOgmo
o`000?l0003o0000oc<c<`1no`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`;o00001?oooonO
o`000005oc<c<ol0003o0000o`000?moOgl00ol000001?o<c<co0000onKVi_l00003ooooo`05o`00
0?oVi^Ko0000o`000?nc/k<00_l000001OmoOgoo0000o`000?l0003o<c<c07go00001Oooool2o`00
00;ooooo000Rooooo`03o`000?oooooooooo00?oooooX?l000001Olc<c?o0000o`000?l0003oOgmo
00?o000000Coc<c<o`000?oVi^Ko00000oooool01Ol0003oi^KVo`000?l0003o/k>c00;o000000Go
Ogmoo`000?l0003o0000oc<c<`1lo`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oo
oooooooo00?oooooXOl000001Olc<c?o0000o`000?l0003oOgmo00?o000000Coc<c<o`000?oVi^Ko
00000oooool01Ol0003oi^KVo`000?l0003o/k>c00;o000000GoOgmoo`000?l0003o0000oc<c<`1k
o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?oooooX_l000001Olc
<c?o0000o`000?l0003oOgmo00?o000000Coc<c<o`000?oVi^Ko00000oooool01Ol0003oi^KVo`00
0?l0003o/k>c00;o000000GoOgmoo`000?l0003o0000oc<c<`1jo`0000Kooooo0Ol00001ooooo`7o
oooo000Rooooo`03o`000?oooooooooo00?oooooXol000001Olc<c?o0000o`000?l0003oOgmo00?o
000000Coc<c<o`000?oVi^Ko00000oooool01Ol0003oi^KVo`000?l0003o/k>c00;o000000GoOgmo
o`000?l0003o0000oc<c<`1io`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooo
oooo00?oooooY?l000001Olc<c?o0000o`000?l0003oOgmo00?o000000Coc<c<o`000?oVi^Ko0000
0oooool01Ol0003oi^KVo`000?l0003o/k>c00;o000000GoOgmoo`000?l0003o0000oc<c<`1ho`00
00Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?oooooYOl000001Olc<c?o
0000o`000?l0003oOgmo00?o000000Coc<c<o`000?oVi^Ko00000oooool01Ol0003oi^KVo`000?l0
003o/k>c00;o000000GoOgmoo`000?l0003o0000oc<c<`1go`0000Kooooo0Ol00001ooooo`7ooooo
000Rooooo`03o`000?oooooooooo00?oooooY_l000001Olc<c?o0000o`000?l0003oOgmo00?o0000
00Coc<c<o`000?oVi^Ko00000oooool01Ol0003oi^KVo`000?l0003o/k>c00;o000000GoOgmoo`00
0?l0003o0000oc<c<`1fo`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`;o00001?oooonWo`00
0005oc<c<ol0003o0000o`000?moOgl00ol000001?o<c<co0000onKVi_l00003ooooo`05o`000?oV
i^Ko0000o`000?nc/k<00_l000001OmoOgoo0000o`000?l0003o<c<c07Go00001Oooool2o`0000;o
oooo000Rooooo`03o`000?oooooooooo00?oooooZOl000001Om<C4co0000o`000?l0003oVIVI00;o
000000Coc<c<o`000?oVi^Ko00000_ooool01?l0003oi^KVo`000?o<c<`2o`000004oiVIVOl0003o
0000ofIVIP?o000000?o6ATIo`000?l00000LOl00006ooooo`7o00000Oooool1ooooo`008_ooool0
0ol0003oooooooooo`03oooooj[o000000GoC4a<o`000?l0003o0000oiVIV@02o`000004olc<c?l0
003oi^KVo`0000;ooooo00Co0000onKVi_l0003oc<c<0_l000001?nIVIWo0000o`000?mVIVH3o`00
0003oaTI6Ol0003o0000073o00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000oooooooo
ool00ooooon[o`000005oda<C?l0003o0000o`000?nIVIT00_l000000oo<c<co0000o`000003oooo
o`04o`000?oVi^Ko0000olc<c0;o000000CoVIVIo`000?l0003oIVIV0ol000000olI6AWo0000o`00
001_o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?ooooo[?l00000
1Om<C4co0000o`000?l0003oVIVI00;o000000?oc<c<o`000?l000000oooool01?l0003oi^KVo`00
0?o<c<`2o`000004oiVIVOl0003o0000ofIVIP?o000000?o6ATIo`000?l00000K_l00006ooooo`7o
00000Oooool1ooooo`008_ooool00ol0003oooooooooo`03ooooojgo000000GoC4a<o`000?l0003o
0000oiVIV@03o`000003onKVi_l0003ooooo00;ooooo00Co0000onKVi_l0003oc<c<0_l000001?nI
VIWo0000o`000?mVIVH3o`000003oaTI6Ol0003o000006go00001_ooool1o`00007ooooo0Oooool0
00Co000000?o410@ooooooooool01Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool00ooooon^o`000005oda<C?l0003o0000o`000?nIVIT00ol0
00000ooVi^Ko0000ooooo`02ooooo`04o`000?oVi^Ko0000olc<c0;o000000GoVIVIo`000?l0003o
0000oda<C002o`000003oaTI6Ol0003o000006co00001_ooool1o`00007ooooo0Oooool000;ooooo
00?o0000ooooooooool00_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool00ooooon_o`000005oda<C?l0003o0000o`00
0?nIVIT00ol000000ooVi^Ko0000ooooo`02ooooo`04o`000?oVi^Ko0000olc<c0;o000000GoVIVI
o`000?l0003o0000oda<C002o`000003oaTI6Ol0003o000006_o00001_ooool1o`00007ooooo0Ooo
ool000;ooooo00?o0000ooooooooool00oooool00onHV9So8B4Qonk^kP0Aooooo`03o`000?oooooo
oooo00?ooooo0ol00003oooook3o000000?oC4a<o`000?l000000_l000001Onc/k?o0000o`000?oV
i^Ko000000?ooooo00Co0000onKVi_l0003oc<c<0_l000001OnIVIWo0000o`000?l0003oC4a<00;o
000000?o6ATIo`000?l00000J_l00004ooooo`?o00000_ooool000;ooooo00?o0000ooooooooool0
1?ooool00onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
0ooooonao`000003oda<C?l0003o000000;o000000Go/k>co`000?l0003oi^KVo`000003ooooo`04
o`000?oVi^Ko0000olc<c0;o000000GoVIVIo`000?l0003o0000oda<C002o`000003oaTI6Ol0003o
000006Wo00001_ooool1o`00007ooooo0Oooool000;ooooo00?o0000ooooooooool01Oooool00omg
MgOoIVIVooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`03
oooook;o000000?oC4a<o`000?l000000_l000001Onc/k?o0000o`000?oVi^Ko000000?ooooo00Co
0000onKVi_l0003oc<c<0_l000001OnIVIWo0000o`000?l0003oC4a<00;o000000?o6ATIo`000?l0
0000J?l00006ooooo`7o00000Oooool1ooooo`000_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03oooook?o0000
00?oC4a<o`000?l000000_l000001Onc/k?o0000o`000?oVi^Ko000000?ooooo00Co0000onKVi_l0
003oc<c<0_l000001OnIVIWo0000o`000?l0003oC4a<00;o000000?o6ATIo`000?l00000Iol00006
ooooo`7o00000Oooool1ooooo`000_ooool00ol0003oooooooooo`02ooooo`05o`000?nj^[[ooooo
oiRHV?l@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo]Ol00000
1OmVIVKo0000o`000?l0003o/k>c00;o000000?oi^KVo`000?ooool00_ooool01?l0003oi^KVo`00
0?o<c<`2o`000005oiVIVOl0003o0000o`000?m<C4`00_l000000olI6AWo0000o`00001Vo`0000Ko
oooo0Ol00001ooooo`7ooooo00000omEEEGoIVIVo`000004ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`03?ooool4o`0000Kooooo00?o0000ooooooooool00ooooonfo`000005ofIVI_l0003o0000o`00
0?nc/k<00_l000000ooVi^Ko0000ooooo`02ooooo`04o`000?oVi^Ko0000olc<c0;o000000GoVIVI
o`000?l0003o0000oda<C002o`000003oaTI6Ol0003o000006Go00001_ooool1o`00007ooooo0Ooo
ool002;ooooo00?o0000ooooooooool00ooooongo`000005ofIVI_l0003o0000o`000?nc/k<00_l0
00000ooVi^Ko0000ooooo`02ooooo`04o`000?oVi^Ko0000olc<c0;o000000GoVIVIo`000?l0003o
0000oda<C002o`000003oaTI6Ol0003o000006Co00001_ooool1o`00007ooooo0Oooool002;ooooo
00?o0000ooooooooool00ooooonho`000005ofIVI_l0003o0000o`000?nc/k<00_l000000ooVi^Ko
0000ooooo`02ooooo`04o`000?oVi^Ko0000olc<c0;o000000GoVIVIo`000?l0003o0000oda<C002
o`000003oaTI6Ol0003o000006?o00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000oooo
ooooool00oooooneo`000005oaTI6Ol0003o0000o`000?mVIVH00ol000001Onc/k?o0000o`000?oV
i^Ko000000?ooooo00Co0000onKVi_l0003oc<c<0_l000001OnIVIWo0000o`000?l0003oC4a<00;o
000000?o6ATIo`000?l00000H_l00006ooooo`7o00000Oooool1ooooo`008_ooool2o`0000Cooooo
]_l000001OlI6AWo0000o`000?l0003oIVIV00?o000000?o/k>co`000?l000000ol00002ooooog7o
00001Oooool2o`0000;ooooo000Rooooo`03o`000?oooooooooo00?ooooo]ol000001OlI6AWo0000
o`000?l0003oIVIV00?o000000Ko/k>co`000?o<c<co0000onKVi_l00003ooooo`04o`000?oVi^Ko
0000olc<c0?o000000GoOgmoo`000?l0003o0000oc<c<`1So`0000Kooooo0Ol00001ooooo`7ooooo
000Rooooo`03o`000?oooooooooo00?ooooo^?l000001OlI6AWo0000o`000?l0003oIVIV00?o0000
00Ko/k>co`000?o<c<co0000onKVi_l00003ooooo`04o`000?oVi^Ko0000olc<c0?o000000GoOgmo
o`000?l0003o0000oc<c<`1Ro`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooo
oooo00?ooooo^Ol000001OlI6AWo0000o`000?l0003oIVIV00?o000000Ko/k>co`000?o<c<co0000
onKVi_l00003ooooo`04o`000?oVi^Ko0000olc<c0?o000000GoOgmoo`000?l0003o0000oc<c<`1Q
o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?ooooo^_l000001OlI
6AWo0000o`000?l0003oIVIV00?o000000Ko/k>co`000?o<c<co0000onKVi_l00003ooooo`04o`00
0?oVi^Ko0000olc<c0?o000000GoOgmoo`000?l0003o0000oc<c<`1Po`0000Kooooo0Ol00001oooo
o`7ooooo000Rooooo`03o`000?oooooooooo00?ooooo^ol000001OlI6AWo0000o`000?l0003oIVIV
00?o000000Ko/k>co`000?o<c<co0000onKVi_l00003ooooo`04o`000?oVi^Ko0000olc<c0?o0000
00GoOgmoo`000?l0003o0000oc<c<`1Oo`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`00
0?oooooooooo00?ooooo_?l000001OlI6AWo0000o`000?l0003oIVIV00?o000000Ko/k>co`000?o<
c<co0000onKVi_l00003ooooo`04o`000?oVi^Ko0000olc<c0?o000000GoOgmoo`000?l0003o0000
oc<c<`1No`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?ooooo_Ol0
00001OlI6AWo0000o`000?l0003oIVIV00Go000000Coc<c<o`000?oVi^Ko00000oooool01?l0003o
i^KVo`000?o<c<`4o`000004ofIVI_l0003o0000oc<c<ego00001_ooool1o`00007ooooo0Oooool0
02;ooooo0_l00004oooookko000000Go6ATIo`000?l0003o0000ofIVIP02o`000007oiVIVOl0003o
0000olc<c?l0003oi^KVo`000003ooooo`04o`000?oVi^Ko0000olc<c0Co000000CoIVIVo`000?l0
003o<c<cG?l00005ooooo`;o00000_ooool002;ooooo00?o0000ooooooooool00ooooonoo`000005
oaTI6Ol0003o0000o`000?mVIVH00_l000001onIVIWo0000o`000?o<c<co0000onKVi_l000000ooo
ool01?l0003oi^KVo`000?o<c<`4o`000004ofIVI_l0003o0000oc<c<e_o00001_ooool1o`00007o
oooo0Oooool002;ooooo00?o0000ooooooooool00oooooo0o`000005oaTI6Ol0003o0000o`000?mV
IVH00_l000001onIVIWo0000o`000?o<c<co0000onKVi_l000000oooool01?l0003oi^KVo`000?o<
c<`4o`000004ofIVI_l0003o0000oc<c<e[o00001_ooool1o`00007ooooo0Oooool002;ooooo00?o
0000ooooooooool00oooooo1o`000003oaTI6Ol0003o000000Co000000OoVIVIo`000?l0003oc<c<
o`000?oVi^Ko000000?ooooo00Go0000onKVi_l0003o0000ok>c/`03o`000004ofIVI_l0003o0000
oc<c<eWo00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00oooooo2o`00
0004oaTI6Ol0003o0000oda<C0?o000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000?ooooo
00Go0000onKVi_l0003o0000ok>c/`03o`000004ofIVI_l0003o0000oc<c<eSo00001_ooool1o`00
007ooooo0Oooool002;ooooo00?o0000ooooooooool00oooooo3o`000004oaTI6Ol0003o0000oda<
C0?o000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000?ooooo00Go0000onKVi_l0003o0000
ok>c/`03o`000004ofIVI_l0003o0000oc<c<eOo00001_ooool1o`00007ooooo0Oooool002;ooooo
00?o0000ooooooooool00oooooo4o`000004oaTI6Ol0003o0000oda<C0?o000000OoVIVIo`000?l0
003oc<c<o`000?oVi^Ko000000?ooooo00Go0000onKVi_l0003o0000ok>c/`03o`000004ofIVI_l0
003o0000oc<c<eKo00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooo
ooo5o`000004oaTI6Ol0003o0000oda<C0?o000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko0000
00?ooooo00Go0000onKVi_l0003o0000ok>c/`03o`000004ofIVI_l0003o0000oc<c<eGo00001_oo
ool1o`00007ooooo0Oooool002;ooooo0_l00004ooooom;o000000?oi^KVo`000?ooool00_ooool0
1Ol0003oi^KVo`000?l0003o/k>c00?o000000CoIVIVo`000?l0003o<c<cE?l00005ooooo`;o0000
0_ooool002;ooooo00?o0000ooooooooool00oooooo9o`000005oc<c<ol0003o0000o`000?moOgl0
0_l000001Onc/k?o0000o`000?oVi^Ko000000?ooooo0_l000000oo<c<co0000ok>c/`03o`000005
ofIVI_l0003o0000o`000?lI6AT0D_l00006ooooo`7o00000Oooool1ooooo`008_ooool00ol0003o
ooooooooo`03oooool[o000000Go<c<co`000?l0003o0000ogmoO`02o`000005ok>c/ol0003o0000
onKVi_l000000oooool2o`000003olc<c?l0003o/k>c00?o000000GoIVIVo`000?l0003o0000oaTI
6@1Ao`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?ooooobol00000
1Olc<c?o0000o`000?l0003oOgmo00;o000000Go/k>co`000?l0003oi^KVo`000003ooooo`;o0000
00?oc<c<o`000?nc/k<00ol000000omVIVKo0000o`00001Bo`0000Kooooo0Ol00001ooooo`7ooooo
000Rooooo`03o`000?oooooooooo00?oooooc?l000001Olc<c?o0000o`000?l0003oOgmo00;o0000
00Go/k>co`000?l0003oi^KVo`000003ooooo`;o000000?oc<c<o`000?nc/k<00ol000000omVIVKo
0000o`00001Ao`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?ooooo
cOl000001Olc<c?o0000o`000?l0003oOgmo00;o000000Go/k>co`000?l0003oi^KVo`000003oooo
o`;o000000?oc<c<o`000?nc/k<00ol000000omVIVKo0000oda<C01@o`0000Kooooo0Ol00001oooo
o`7ooooo000Rooooo`03o`000?oooooooooo00?oooooc_l000001Olc<c?o0000o`000?l0003oOgmo
00;o000000Go/k>co`000?l0003oi^KVo`000003ooooo`;o000000?oc<c<o`000?nc/k<00ol00000
0omVIVKo0000oda<C01?o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo
00?ooooocol000001Olc<c?o0000o`000?l0003oOgmo00;o000000Go/k>co`000?l0003oi^KVo`00
0003ooooo`;o000000?oc<c<o`000?nc/k<01Ol000000om<C4co0000o`00001<o`0000Kooooo0Ol0
0001ooooo`7ooooo000Rooooo`;o00001?ooooo@o`000005oc<c<ol0003o0000o`000?moOgl00_l0
00001Onc/k?o0000o`000?oVi^Ko000000?ooooo0_l000000oo<c<co0000ok>c/`05o`000003oda<
C?l0003o000004_o00001Oooool2o`0000;ooooo000Rooooo`03o`000?oooooooooo00?ooooodOl0
00001Olc<c?o0000o`000?l0003oOgmo00;o000000Go/k>co`000?l0003oi^KVo`000003ooooo`;o
000000Goc<c<o`000?nc/k?o0000oiVIV@03o`000003oda<C?l0003o000004[o00001_ooool1o`00
007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooooBo`000005oc<c<ol0003o0000o`00
0?moOgl00_l000001Onc/k?o0000o`000?oVi^Ko000000?ooooo0_l000001Oo<c<co0000ok>c/ol0
003oVIVI00?o000000?oC4a<o`000?l00000BOl00006ooooo`7o00000Oooool1ooooo`008_ooool0
0ol0003oooooooooo`03ooooom?o000000Go<c<co`000?l0003o0000ogmoO`02o`000005ok>c/ol0
003o0000onKVi_l000000oooool2o`000005olc<c?l0003o0000o`000?nIVIT00ol000000om<C4co
0000o`000018o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?ooooo
e?l000001Olc<c?o0000o`000?l0003oOgmo00;o000000Go/k>co`000?l0003oi^KVo`000003oooo
o`;o00000_o<c<`2o`000005oiVIVOl0003o0000o`000?m<C4`0BOl00006ooooo`7o00000Oooool1
ooooo`008_ooool00ol0003oooooooooo`03ooooomGo000000Go<c<co`000?l0003o0000ogmoO`02
o`000005ok>c/ol0003o0000onKVi_l000000oooool3o`000004olc<c?l0003o0000oiVIV@?o0000
00?oC4a<o`000?l00000A_l00006ooooo`7o00000Oooool1ooooo`004?ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`04ooooo`03o`000?oooooooooo00?ooooo
e_l000001Olc<c?o0000o`000?l0003oOgmo00;o000000Go/k>co`000?l0003oi^KVo`000003oooo
o`04o`000?oVi^Ko0000olc<c0;o000000GoVIVIo`000?l0003o0000oda<C017o`0000Kooooo0Ol0
0001ooooo`7ooooo000Booooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`03ooooomOo000000Go<c<co`000?l0003o0000ogmoO`02o`000005ok>c/ol0
003o0000onKVi_l000000oooool01?l0003oi^KVo`000?o<c<`2o`000005oiVIVOl0003o0000o`00
0?m<C4`0A_l00006ooooo`7o00000Oooool1ooooo`004_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00?ooooo0ol00003ooooomSo000000Go<c<co`000?l0003o0000ogmoO`02o`00
0005ok>c/ol0003o0000onKVi_l000000oooool01?l0003oi^KVo`000?o<c<`2o`000005oiVIVOl0
003o0000o`000?m<C4`0AOl00004ooooo`?o00000_ooool001;ooooo00?o0000ooooooooool01_oo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00?oooooeol000001?lI6AWo0000o`00
0?m<C4`3o`000007oiVIVOl0003o0000olc<c?l0003oi^KVo`000002ooooo`04o`000?oVi^Ko0000
olc<c0;o000000GoVIVIo`000?l0003o0000oda<C002o`000003oaTI6Ol0003o0000043o00001_oo
ool1o`00007ooooo0Oooool001;ooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Gooooo00?o0000ooooooooool00ooooooHo`000004oaTI6Ol0003o0000oda<C0?o0000
00OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000;ooooo00Co0000onKVi_l0003oc<c<0_l00000
1OnIVIWo0000o`000?l0003oC4a<00;o000000?o6ATIo`000?l00000?ol00006ooooo`7o00000Ooo
ool1ooooo`004_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool00ooooooIo`000004oaTI6Ol0003o0000oda<C0?o000000OoVIVIo`000?l0003oc<c<
o`000?oVi^Ko000000;ooooo00Co0000onKVi_l0003oc<c<0_l000001OnIVIWo0000o`000?l0003o
C4a<00;o000000?o6ATIo`000?l00000?_l00006ooooo`7o00000Oooool1ooooo`004_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00ooooooJo`00
0004oaTI6Ol0003o0000oda<C0?o000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000;ooooo
00Co0000onKVi_l0003oc<c<0_l000001OnIVIWo0000o`000?l0003oC4a<00;o000000?o6ATIo`00
0?l00000?Ol00006ooooo`7o00000Oooool1ooooo`004?ooool00omEEEGoIVIVo`000005ooooo`Co
00001_ooool00ol0003oooooooooo`03ooooom_o000000Co6ATIo`000?l0003oC4a<0ol000001onI
VIWo0000o`000?o<c<co0000onKVi_l000000_ooool01?l0003oi^KVo`000?o<c<`2o`000005oiVI
VOl0003o0000o`000?m<C4`00_l000000olI6AWo0000o`00000lo`0000Kooooo0Ol00001ooooo`7o
oooo000Rooooo`03o`000?oooooooooo00?ooooog?l000001?lI6AWo0000o`000?m<C4`3o`000007
oiVIVOl0003o0000olc<c?l0003oi^KVo`000002ooooo`04o`000?oVi^Ko0000olc<c0;o000000?o
VIVIo`000?l000001?l000000olI6AWo0000o`00000ko`0000Kooooo0Ol00001ooooo`7ooooo000R
ooooo`03o`000?oooooooooo00?ooooogOl000001?lI6AWo0000o`000?m<C4`3o`000007oiVIVOl0
003o0000olc<c?l0003oi^KVo`000002ooooo`04o`000?oVi^Ko0000olc<c0;o000000CoVIVIo`00
0?l0003oIVIV0ol000000olI6AWo0000o`00000jo`0000Kooooo0Ol00001ooooo`7ooooo000Roooo
o`03o`000?oooooooooo00?ooooog_l000001?lI6AWo0000o`000?m<C4`4o`000006ok>c/ol0003o
c<c<o`000?oVi^Ko00000_ooool01?l0003oi^KVo`000?o<c<`2o`000004oiVIVOl0003o0000ofIV
IP?o000000?o6ATIo`000?l00000>Ol00006ooooo`7o00000Oooool1ooooo`008_ooool2o`0000Co
oooogol000001?lI6AWo0000o`000?m<C4`4o`000006ok>c/ol0003oc<c<o`000?oVi^Ko00000_oo
ool01?l0003oi^KVo`000?o<c<`2o`000004oiVIVOl0003o0000ofIVIP?o000000?o6ATIo`000?l0
0000>?l00005ooooo`;o00000_ooool002;ooooo00?o0000ooooooooool00ooooooPo`000004oaTI
6Ol0003o0000oda<C0Co000000Ko/k>co`000?o<c<co0000onKVi_l00002ooooo`04o`000?oVi^Ko
0000olc<c0;o000000CoVIVIo`000?l0003oIVIV0ol000000olI6AWo0000o`00000go`0000Kooooo
0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?ooooohOl000001?lI6AWo0000o`00
0?m<C4`4o`000006ok>c/ol0003oc<c<o`000?oVi^Ko00000_ooool01?l0003oi^KVo`000?o<c<`2
o`000004oiVIVOl0003o0000ofIVIP?o000000?o6ATIo`000?l00000=_l00006ooooo`7o00000Ooo
ool1ooooo`008_ooool00ol0003oooooooooo`03ooooon;o000000Go6ATIo`000?l0003o0000ofIV
IP03o`000006ok>c/ol0003oc<c<o`000?oVi^Ko00000_ooool01?l0003oi^KVo`000?o<c<`2o`00
0004oiVIVOl0003o0000ofIVIP?o000000?o6ATIo`000?l00000=Ol00006ooooo`7o00000Oooool1
ooooo`008_ooool00ol0003oooooooooo`03ooooon?o000000Go6ATIo`000?l0003o0000ofIVIP03
o`000006ok>c/ol0003oc<c<o`000?oVi^Ko00000_ooool01?l0003oi^KVo`000?o<c<`2o`000004
oiVIVOl0003o0000ofIVIP?o000000?o6ATIo`000?l00000=?l00006ooooo`7o00000Oooool1oooo
o`008_ooool00ol0003oooooooooo`03ooooonCo000000Go6ATIo`000?l0003o0000ofIVIP03o`00
0006ok>c/ol0003oc<c<o`000?oVi^Ko00000_ooool01?l0003oi^KVo`000?o<c<`2o`000004oiVI
VOl0003o0000ofIVIP?o000000?o6ATIo`000?l00000<ol00006ooooo`7o00000Oooool1ooooo`00
8_ooool00ol0003oooooooooo`03ooooonGo000000Go6ATIo`000?l0003o0000ofIVIP03o`000006
ok>c/ol0003oc<c<o`000?oVi^Ko00000_ooool01?l0003oi^KVo`000?o<c<`2o`000004oiVIVOl0
003o0000ofIVIP?o000000?o6ATIo`000?l00000<_l00006ooooo`7o00000Oooool1ooooo`008_oo
ool00ol0003oooooooooo`03ooooonKo000000Go6ATIo`000?l0003o0000ofIVIP03o`000006ok>c
/ol0003oc<c<o`000?oVi^Ko00000_ooool01?l0003oi^KVo`000?o<c<`2o`000004oiVIVOl0003o
0000ofIVIP?o000000?o6ATIo`000?l00000<Ol00006ooooo`7o00000Oooool1ooooo`008_ooool2
o`0000Coooooiol000001OlI6AWo0000o`000?l0003oIVIV00?o000000Ko/k>co`000?o<c<co0000
onKVi_l00002oooood3o00001Oooool2o`0000;ooooo000Rooooo`03o`000?oooooooooo00?ooooo
jOl000001Olc<c?o0000o`000?l0003oOgmo00;o000000Go/k>co`000?l0003oi^KVo`000004oooo
o`05o`000?oVi^Ko0000o`000?nc/k<00_l000001OmoOgoo0000o`000?l0003o<c<c03;o00001_oo
ool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooooZo`000005oc<c<ol0003o
0000o`000?moOgl00_l000001?nc/k?o0000o`000?oVi^H2o`0000?ooooo00Go0000onKVi_l0003o
0000ok>c/`02o`000005ogmoOol0003o0000o`000?lc<c<0<Ol00006ooooo`7o00000Oooool1oooo
o`008_ooool00ol0003oooooooooo`03ooooon_o000000Go<c<co`000?l0003o0000ogmoO`02o`00
0003ok>c/ol0003o000000;oi^KV00Ko0000ooooooooooooooooo`000?oVi^H2o`000004ok>c/ol0
003o0000ogmoO`?o000000?o<c<co`000?l00000;_l00006ooooo`7o00000Oooool1ooooo`008_oo
ool00ol0003oooooooooo`03ooooonco000000Go<c<co`000?l0003o0000ogmoO`02o`000006ok>c
/ol0003o0000o`000?oVi^Ko00000oooool01Ol0003oi^KVo`000?l0003o/k>c00;o000000GoOgmo
o`000?l0003o0000oc<c<`0_o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooo
oooo00?oooookOl000001Olc<c?o0000o`000?l0003oOgmo00;o000000Ko/k>co`000?o<c<co0000
onKVi_l00003ooooo`05o`000?oVi^Ko0000o`000?nc/k<00_l000001OmoOgoo0000o`000?l0003o
<c<c02ko00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00oooooo^o`00
0005oc<c<ol0003o0000o`000?moOgl00_l000001_nc/k?o0000olc<c?l0003oi^KVo`0000?ooooo
00Go0000onKVi_l0003o0000ok>c/`02o`000005ogmoOol0003o0000o`000?lc<c<0;Ol00006oooo
o`7o00000Oooool1ooooo`008_ooool00ol0003oooooooooo`03ooooonoo000000Go<c<co`000?l0
003o0000ogmoO`04o`000004olc<c?l0003oi^KVo`0000?ooooo00Go0000onKVi_l0003o0000ok>c
/`02o`000005ogmoOol0003o0000o`000?lc<c<0;?l00006ooooo`7o00000Oooool1ooooo`008_oo
ool2o`0000Coooool?l000001olc<c?o0000o`000?l0003oOgmoo`000?nIVIT00_l000001?o<c<co
0000onKVi_l00003ooooo`05o`000?oVi^Ko0000o`000?nc/k<00_l000001OmoOgoo0000o`000?l0
003o<c<c02_o00001Oooool2o`0000;ooooo000Rooooo`03o`000?oooooooooo00?ooooolOl00000
1olc<c?o0000o`000?l0003oOgmoo`000?nIVIT00_l000001?o<c<co0000onKVi_l00003ooooo`05
o`000?oVi^Ko0000o`000?nc/k<00_l000001OmoOgoo0000o`000?l0003o<c<c02[o00001_ooool1
o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00oooooobo`000003oc<c<ol0003o0000
00?o000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000?ooooo00Go0000onKVi_l0003o0000
ok>c/`02o`000005ogmoOol0003o0000o`000?lc<c<0:Ol00006ooooo`7o00000Oooool1ooooo`00
8_ooool00ol0003oooooooooo`03oooooo?o000000?o<c<co`000?l000000ol000001onIVIWo0000
o`000?o<c<co0000onKVi_l000000oooool01Ol0003oi^KVo`000?l0003o/k>c00;o000000GoOgmo
o`000?l0003o0000oc<c<`0Xo`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooo
oooo00?ooooom?l000000olc<c?o0000oda<C003o`000007oiVIVOl0003o0000olc<c?l0003oi^KV
o`000003ooooo`05o`000?oVi^Ko0000o`000?nc/k<00_l000001OmoOgoo0000o`000?l0003o<c<c
02Oo00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooooeo`000003
oc<c<ol0003oC4a<00?o000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000?ooooo00Go0000
onKVi_l0003o0000ok>c/`02o`000005ogmoOol0003o0000o`000?lc<c<09_l00006ooooo`7o0000
0Oooool1ooooo`008_ooool00ol0003oooooooooo`03ooooooSo000000GoC4a<o`000?l0003o0000
oiVIV@02o`000004olc<c?l0003oi^KVo`0000?ooooo00Go0000onKVi_l0003o0000ok>c/`02o`00
0005ogmoOol0003o0000o`000?lc<c<09Ol00006ooooo`7o00000Oooool1ooooo`008_ooool00ol0
003oooooooooo`03ooooooWo000000GoC4a<o`000?l0003o0000oiVIV@02o`000004olc<c?l0003o
i^KVo`0000?ooooo00Go0000onKVi_l0003o0000ok>c/`02o`000005ogmoOol0003o0000o`000?lc
<c<09?l00006ooooo`7o00000Oooool1ooooo`008_ooool2o`0000Cooooon_l000001Om<C4co0000
o`000?l0003oVIVI00;o000000Coc<c<o`000?oVi^Ko00000oooool01Ol0003oi^KVo`000?l0003o
/k>c00;o000000GoOgmoo`000?l0003o0000oc<c<`0So`0000Gooooo0_l00002ooooo`008_ooool0
0ol0003oooooooooo`03oooooo_o000000GoC4a<o`000?l0003o0000oiVIV@02o`000004olc<c?l0
003oi^KVo`0000;ooooo00Co0000onKVi_l0003oc<c<0_l000001?nIVIWo0000o`000?mVIVH3o`00
0003oaTI6Ol0003o000001oo00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000oooooooo
ool00oooooolo`000005oda<C?l0003o0000o`000?nIVIT00_l000001?o<c<co0000onKVi_l00002
ooooo`04o`000?oVi^Ko0000olc<c0;o000000CoVIVIo`000?l0003oIVIV0ol00002oaTI6Aoo0000
1_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00oooooomo`000005oda<C?l0
003o0000o`000?nIVIT00_l000001?o<c<co0000onKVi_l00002ooooo`04o`000?oVi^Ko0000olc<
c0;o000000CoVIVIo`000?l0003oIVIV1?l000000olI6AWo0000o`00000Lo`0000Kooooo0Ol00001
ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?oooooo_l000001Om<C4co0000o`000?l0003o
VIVI00;o000000Coc<c<o`000?oVi^Ko00000_ooool01?l0003oi^KVo`000?o<c<`2o`000004oiVI
VOl0003o0000ofIVIPCo000000?o6ATIo`000?l000006ol00006ooooo`7o00000Oooool1ooooo`00
8_ooool00ol0003oooooooooo`03oooooooo000000GoC4a<o`000?l0003o0000oiVIV@02o`000004
olc<c?l0003oi^KVo`0000;ooooo00Co0000onKVi_l0003oc<c<0_l000001_nIVIWo0000o`000?mV
IVKo0000oda<C0;o000000?o6ATIo`000?l000006_l00006ooooo`7o00000Oooool1ooooo`001?l0
00000ol@413oooooooooo`02ooooo`03o`000?o^k^kooooo00Gooooo0_lQ8B45ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`03oooooooo00000Ol000001Om<C4co0000
o`000?l0003oVIVI00Co000000Soi^KVo`000?ooooooooooo`000?oVi^Ko0000olc<c0;o000000Ko
VIVIo`000?l0003oIVIVo`000?m<C4`2o`000003oaTI6Ol0003o000001Wo00001_ooool1o`00007o
oooo0Oooool000;ooooo00?o0000ooooooooool01?ooool00omEEEGoZJVYooooo`05ooooo`;o8B4Q
2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00?oooooool00002o`000007oda<
C?l0003o0000o`000?nIVIWo0000ok>c/`02o`000008onKVi_l0003oooooooooool0003oi^KVo`00
0?o<c<`2o`000003oiVIVOl0003o000000;o000000CoC4a<o`000?l0003o6ATI6_l00006ooooo`7o
00000Oooool1ooooo`000_ooool00ol0003oooooooooo`04ooooo`03ojVYZOmEEEGooooo013ooooo
00?o0000ooooooooool00oooool3o`0000?oooooool00003o`000007oda<C?l0003o0000o`000?nI
VIWo0000ok>c/`02o`000008onKVi_l0003oooooooooool0003oi^KVo`000?o<c<`2o`000003oiVI
VOl0003o000000;o000000CoC4a<o`000?l0003o6ATI6Ol00004ooooo`?o00000_ooool000;ooooo
00?o0000ooooooooool01Oooool00olQ8B7oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool00oooooooo`0000Co000000?oC4a<o`000?l000000ol000001Onc/k?o0000
o`000?oVi^Ko000000;ooooo00Co0000onKVi_l0003oc<c<0_l00002oiVIV@?o000000CoC4a<o`00
0?l0003o6ATI6?l00006ooooo`7o00000Oooool1ooooo`000_ooool00ol0003oooooooooo`05oooo
o`03oeEEEOo<c<cooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo00?oooooool00005o`000004oda<C?l0003o0000ogmoO`;o000000Go/k>co`000?l0003oi^KV
o`000002ooooo`04o`000?oVi^Ko0000olc<c0?o000000GoVIVIo`000?l0003o0000oda<C002o`00
0003oaTI6Ol0003o000001Go00001_ooool1o`00007ooooo0Oooool000;ooooo00?o0000oooooooo
ool01Oooool00onYZJWoMgMgooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool00oooooooo`0000Ko000000CoC4a<o`000?l0003oOgmo0_l000001Onc/k?o0000o`000?oVi^Ko
000000;ooooo00Co0000onKVi_l0003oc<c<0ol000001OnIVIWo0000o`000?l0003oC4a<00;o0000
00?o6ATIo`000?l000005?l00006ooooo`7o00000Oooool1ooooo`000_ooool00ol0003ooooooooo
o`02ooooo`05oa0@4?oooooooooooooooolb<S803?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00?oooooool00007o`000004oda<C?l0003o0000ogmoO`;o000000Go/k>co`000?l0
003oi^KVo`000002ooooo`03o`000?oVi^Ko000000;oc<c<0_l000001OnIVIWo0000o`000?l0003o
C4a<00;o000000?o6ATIo`000?l000004ol00006ooooo`7o00000Oooool1ooooo`0000?oEEEEofIV
I_l000001?ooool5o`0000cooooo1?l00006ooooo`03o`000?oooooooooo00?oooooool0000;o`00
0004ogmoOol0003o0000ok>c/`;o000000Koi^KVo`000?ooooooooooo`000?oVi^H2o`000004olc<
c?l0003o0000oiVIV@?o000000CoC4a<o`000?l0003o6ATI5?l00006ooooo`7o00000Oooool1oooo
o`008_ooool00ol0003oooooooooo`03oooooooo00002?l000001Olc<c?o0000o`000?l0003oOgmo
00;o000000Go/k>co`000?l0003oi^KVo`000002ooooo`05o`000?oVi^Koi^KVo`000?o<c<`00_l0
00001OnIVIWo0000o`000?l0003oC4a<00;o000000?o6ATIo`000?l000004Ol00006ooooo`7o0000
0Oooool1ooooo`008_ooool00ol0003oooooooooo`03oooooooo00002Ol000001Olc<c?o0000o`00
0?l0003oOgmo00;o000000Go/k>co`000?l0003oi^KVo`000002ooooo`;o000000?oi^KVo`000?o<
c<`00_l000001OnIVIWo0000o`000?l0003oC4a<00;o000000?o6ATIo`000?l000004?l00006oooo
o`7o00000Oooool1ooooo`008_ooool2o`0000Coooooool0000:o`000005oc<c<ol0003o0000o`00
0?moOgl00_l000001Onc/k?o0000o`000?oVi^Ko000000?ooooo00Co0000onKVi_l0003oc<c<0_l0
00001OnIVIWo0000o`000?l0003oC4a<00;o000000?o6ATIo`000?l000003ol00005ooooo`;o0000
0_ooool002;ooooo00?o0000ooooooooool00oooooooo`0000Wo000000Go6ATIo`000?l0003o0000
ofIVIP02o`000007oiVIVOl0003o0000olc<c?l0003oi^KVo`000003ooooo`04o`000?oVi^Ko0000
olc<c0;o000000GoVIVIo`000?l0003o0000oda<C00Co`0000Kooooo0Ol00001ooooo`7ooooo000R
ooooo`03o`000?oooooooooo00?oooooool0000:o`000005oaTI6Ol0003o0000o`000?mVIVH00_l0
00001onIVIWo0000o`000?o<c<co0000onKVi_l000000oooool01?l0003oi^KVo`000?o<c<`2o`00
0005oiVIVOl0003o0000o`000?m<C4`04_l00006ooooo`7o00000Oooool1ooooo`008_ooool00ol0
003oooooooooo`03oooooooo00002ol000001OlI6AWo0000o`000?l0003oIVIV00;o000000OoVIVI
o`000?l0003oc<c<o`000?oVi^Ko000000?ooooo00Co0000onKVi_l0003oc<c<0_l000001OnIVIWo
0000o`000?l0003oC4a<017o00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000oooooooo
ool00oooooooo`0000co000000Go6ATIo`000?l0003o0000ofIVIP02o`000007oiVIVOl0003o0000
olc<c?l0003oi^KVo`000003ooooo`04o`000?oVi^Ko0000olc<c0;o000000GoVIVIo`000?l0003o
0000oda<C00@o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?ooooo
ool0000=o`000005oaTI6Ol0003o0000o`000?mVIVH00_l000001onIVIWo0000o`000?o<c<co0000
onKVi_l000000oooool01?l0003oi^KVo`000?o<c<`2o`000004oiVIVOl0003o0000o`0000;oC4a<
3_l00006ooooo`7o00000Oooool1ooooo`008_ooool00ol0003oooooooooo`03oooooooo00003_l0
00001OlI6AWo0000o`000?l0003oIVIV00;o000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko0000
00?ooooo00Co0000onKVi_l0003oc<c<0_l000000onIVIWo0000o`000002o`000003oda<C?l0003o
000000_o00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00oooooooo`00
00oo000000Go6ATIo`000?l0003o0000ofIVIP02o`000007oiVIVOl0003o0000olc<c?l0003oi^KV
o`000003ooooo`04o`000?oVi^Ko0000olc<c0;o000000?oVIVIo`000?l000000_l000000om<C4co
0000o`00000:o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?ooooo
ool0000@o`000005oaTI6Ol0003o0000o`000?mVIVH00_l000001onIVIWo0000o`000?o<c<co0000
onKVi_l000000oooool01?l0003oi^KVo`000?o<c<`2o`000003oiVIVOl0003o000000;o000000?o
C4a<o`000?l000002Ol00006ooooo`7o00000Oooool1ooooo`008_ooool2o`0000Coooooool0000A
o`000005oaTI6Ol0003o0000o`000?mVIVH00_l000001onIVIWo0000o`000?o<c<co0000onKVi_l0
00000oooool01?l0003oi^KVo`000?o<c<`2o`0000;oVIVI0ol000000om<C4co0000o`000008o`00
00Gooooo0_l00002ooooo`008_ooool00ol0003oooooooooo`03oooooooo00004_l000001OlI6AWo
0000o`000?l0003oIVIV00;o000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000?ooooo00Co
0000onKVi_l0003oc<c<0ol000000onIVIWo0000o`00000;o`0000Kooooo0Ol00001ooooo`7ooooo
000Rooooo`03o`000?oooooooooo00?oooooool0000Co`000005oaTI6Ol0003o0000o`000?mVIVH0
0_l000001onIVIWo0000o`000?o<c<co0000onKVi_l000000oooool01?l0003oi^KVo`000?o<c<`@
o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?oooooool0000Do`00
0003oaTI6Ol0003o000000Co000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000?ooooo00?o
0000onKVi_l000000_o<c<`3o`000003oiVIVOl0003o000000So00001_ooool1o`00007ooooo0Ooo
ool002;ooooo00?o0000ooooooooool00oooooooo`0001Go000000Co6ATIo`000?l0003oC4a<0ol0
00001onIVIWo0000o`000?o<c<co0000onKVi_l000000oooool01?l0003oi^KVo`000?l00002olc<
c0co00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00oooooooo`0001Ko
000000Co6ATIo`000?l0003oC4a<0ol000001onIVIWo0000o`000?o<c<co0000onKVi_l000000ooo
ool00ol0003oi^KVonKViP02o`0000;oc<c<2_l00006ooooo`7o00000Oooool1ooooo`008_ooool0
0ol0003oooooooooo`03oooooooo00005ol000001?lI6AWo0000o`000?m<C4`3o`000007oiVIVOl0
003o0000olc<c?l0003oi^KVo`000003ooooo`?o000000?oi^KVo`000?l000002_l00006ooooo`7o
00000Oooool1ooooo`008_ooool00ol0003oooooooooo`03oooooooo00006?l000001?lI6AWo0000
o`000?m<C4`3o`000007oiVIVOl0003o0000olc<c?l0003oi^KVo`000005ooooo`go00001_ooool1
o`00007ooooo0Oooool002;ooooo0_l00004oooooooo00006Ol000001?lI6AWo0000o`000?m<C4`3
o`000007oiVIVOl0003o0000olc<c?l0003oi^KVo`000008ooooo`?o000000?oc<c<o`000?l00000
1?l00004ooooo`;o00000_ooool002;ooooo00?o0000ooooooooool00oooooooo`0001co000000Go
C4a<o`000?l0003o0000oiVIV@02o`000004olc<c?l0003oi^KVo`0000Wooooo0_l000000oo<c<co
0000o`000004o`0000Gooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?ooooo
ool0000Mo`000005oda<C?l0003o0000o`000?nIVIT00_l000000oo<c<co0000o`00000:ooooo`;o
000000?oc<c<o`000?l000000ol00005ooooo`7o00000Oooool1ooooo`008_ooool00ol0003ooooo
ooooo`03oooooooo00007_l000000om<C4co0000o`000003o`000004olc<c?l0003oi^KVo`0000Wo
oooo0_l000000oo<c<co0000o`000003o`0000Gooooo0Ol00001ooooo`7ooooo000Rooooo`03o`00
0?oooooooooo00?oooooool0000Oo`000004oda<C?l0003o0000oiVIV@?o000000?oi^KVo`000?oo
ool02Oooool7o`0000Gooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?ooooo
ool0000Po`000006oda<C?l0003o0000oiVIVOl0003oc<c<0_l0000:ooooo`;o000000?oc<c<o`00
0?l000000_l00005ooooo`7o00000Oooool1ooooo`008_ooool00ol0003oooooooooo`03oooooooo
0000:?l0000;ooooo`Ko00001Oooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool0
0oooooooo`0002Wo00002_ooool6o`0000Gooooo0Ol00001ooooo`7ooooo000Rooooo`;o00001?oo
ooooo`0002[o00002_ooool5o`0000Cooooo0_l00002ooooo`008_ooool00ol0003oooooooooo`03
oooooooo00008ol000000om<C4co0000o`000002o`0000;oi^KV0_l00008ooooo`Go00001Oooool1
o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00oooooooo`0002[o00000_oVi^H2o`00
00Oooooo1?l00005ooooo`7o00000Oooool1ooooo`008_ooool00ol0003oooooooooo`03oooooooo
0000;Ol000000ooVi^Ko0000o`000005ooooo`Co00001Oooool1o`00007ooooo0Oooool002;ooooo
00?o0000ooooooooool00oooooooo`0002oo000000?oi^KVo`000?ooool01?ooool3o`0000Gooooo
0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?oooooool0000co`0000?ooooo0ol0
0005ooooo`7o00000Oooool1ooooo`003oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP06ooooo`03o`000?oooooooooo00?oooooool0000eo`0000;ooooo0_l00005ooooo`7o00000Ooo
ool1ooooo`003oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`06ooooo`03o`000?oooooooooo00?oooooool0000io`0000Gooooo0Ol00001ooooo`7ooooo
000@ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4006ooooo`?o0000
0oooooooo`0002_o000000?o6ATIo`000?l000002ol00003ooooo`?o00000_ooool0017ooooo00?o
V9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
oooooom1ooooo`7o00000Oooool1ooooo`004_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`3ooooood7ooooo0Ol00001ooooo`7ooooo
000Cooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`04ooooo`03o`00
0?oooooooooo0?oooooo@Oooool1o`00007ooooo0Oooool000oooooo00Go0000okZj^_ooooooV9RH
oa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool00oooool1o`00007ooooo0Oooool000oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03ooooo`7o00000Oooool1ooooo`008_ooooooo`0004Go00000_ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.45856, -0.925172, 0.0763111, \
0.0763111}}],

Cell[BoxData[
    \(20\)], "Output"]
}, Open  ]],

Cell["\<\
The density is evenly distributed along the diagonal, and the total \
mass equals 20, as required. \
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["FFT for the Potential", "Section",
  CellTags->{"i:62", "c:33"}],

Cell[TextData[{
  "Now that we know the density on the grid, we solve Eq. ",
  ButtonBox["(7.3.2)",
    ButtonData:>{"Chapter7.nb", "(7.3.2)"},
    ButtonStyle->"Hyperlink"],
  "  for the potential on the grid, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_\(\(\ \)\(i\ j\)\)\)]],
  ". We do so using the FFT method described in Sec. ",
  ButtonBox["6.2.2",
    ButtonData:>{"Chapter6.nb", "c:26"},
    ButtonStyle->"Hyperlink"],
  ".  We then evaluate the force matrices ",
  Cell[BoxData[
      \(TraditionalForm\`F\_\(x\ i\ j\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`F\_\(y\ i\ j\)\)]],
  ", given by the discretized ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " derivatives of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_\(\(\ \)\(i\ j\)\)\)]],
  ":"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(F\_\(\(x\)\(\ \)\(i\)\(\ \)\(j\)\(\ \)\)\), "=", " ", 
          
          FractionBox[\(\[Phi]\_\(\(\ \)\(i + 1\ j\)\) - \[Phi]\_\(\(\ \)\(i \
- 1\ j\)\)\), 
            RowBox[{"2", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]]}]]}], ",", "\[IndentingNewLine]", 
        
        RowBox[{\(F\_\(\(y\)\(\ \)\(i\)\(\ \)\(j\)\(\ \)\)\), "=", " ", 
          RowBox[{
            
            FractionBox[\(\[Phi]\_\(\(\ \)\(i\ j + 1\)\) - \[Phi]\_\(\(\ \
\)\(i\ j - 1\)\)\), 
              RowBox[{"2", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]]}]], "."}]}]}], 
      TraditionalForm]]]], "NE3",
  CellTags->"(7.3.8)"],

Cell[TextData[{
  "However, care must be taken to make sure that ",
  Cell[BoxData[
      \(TraditionalForm\`i \[PlusMinus] 1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`j \[PlusMinus] 1\)]],
  " remain in the correct ranges. This is accomplished using the ",
  StyleBox["Mod ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "function. The module ",
  StyleBox["fft\[Phi]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " performs the FFT and determines the forces."
}], "Text"],

Cell[BoxData[{
    RowBox[{\(G\  = \ 1;\), " ", 
      StyleBox[\( (*\ 
          in\ SI\ units\ G\  = \ 
            6.67\ 10^\(-11\)\ but\ here\ we\ use\ scaled\ units\ *) \),
        FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", "\n", 
      StyleBox[\( (*\ \(function\ to\ keep\ i \[PlusMinus] 
              1\ and\ j\) \[PlusMinus] 1\ in\ the\ range\ from\ 1\ to\ M; \ 
          used\ in\ force\ evaluation\ *) \),
        FontColor->RGBColor[1, 0, 0]]}], "\n", 
    RowBox[{\(imod[i_]\  := \ 1\  + \ Mod[i - 1, M];\), "\[IndentingNewLine]",
       "\n"}], "\[IndentingNewLine]", 
    RowBox[{
      StyleBox[\( (*\ 
          factor\ in\ discrete\ Fourier\ transform\ \((see\ Eq . \ \((6  .2  \
.43)\))\)\ *) \),
        FontColor->RGBColor[1, 0, 
        0]], \(factor\[Phi][m_, n_, \[CapitalDelta]x_, \[CapitalDelta]y_, 
            M_]\  := \(factor\[Phi][m, n, \[CapitalDelta]x, \[CapitalDelta]y, 
              M] = \(-4\)\ \[Pi]\ G/\((\ \(4\/\[CapitalDelta]x\^2\) 
                        Sin[\[Pi]\ m/M]^2 + \(4\/\[CapitalDelta]y\^2\) 
                        Sin[\[Pi]\ n/M]^2\ )\)\  // N\);\)}], "\n", 
    RowBox[{\(factor\[Phi][0, 0, \[CapitalDelta]x_, \[CapitalDelta]y_, 
            M_]\  = \ 1;\), "\n", 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{\(fft\[Phi][\[Rho]_]\), ":=", " ", 
      RowBox[{"Module", "[", 
        RowBox[{\({\[Rho]ft, \[Phi]ft}\), ",", "\[IndentingNewLine]", 
          StyleBox[\( (*\ FFT\ of\ the\ density\ matrix\ *) \),
            FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
          
          RowBox[{\(\[Rho]ft = Fourier[\[Rho]]\), ";", "\[IndentingNewLine]", 
            
            
            StyleBox[\( (*\ 
                total\ mass\ in\ the\ box\ equals\ \(\(zero\)\(:\)\)\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(\[Rho]ft[\([1, 1]\)] = 0\), ";", 
            "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ 
                determine\ potential\ \(\((\)\(see\ Eq . \ \((6  .2  .43)\)\)\
\(\ \)\)*) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(\[Phi]ft = 
              Table[\[Rho]ft[\([m + 1, n + 1]\)]*
                  factor\[Phi][m, n, \[CapitalDelta]x, \[CapitalDelta]y, 
                    M], {m, 0, M - 1}, {n, 0, M - 1}]\), ";", 
            "\[IndentingNewLine]", \(\[Phi] = \ 
              Re[InverseFourier[\[Phi]ft]]\), ";", "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ \ data\ for\ forces, \ 
                including\ grid\ positions\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(Fx\  = \ \ Table[{\((i - 
                        1)\)\ \[CapitalDelta]x, \((j - 
                        1)\) \[CapitalDelta]y, \(-m\) \((\[Phi][\([imod[
                                i + 1], imod[j]]\)] - \[Phi][\([imod[i - 1], 
                              imod[j]]\)])\)/\((2\ \[CapitalDelta]x)\)}, {i, 
                  1, M + 1}, {j, 1, M + 1}]\), ";", 
            "\[IndentingNewLine]", \(Fy\  = \ \ Table[{\((i - 
                        1)\)\ \[CapitalDelta]x, \((j - 
                        1)\) \[CapitalDelta]y, \(-m\) \((\[Phi][\([imod[i], 
                              imod[j + 1]]\)] - \[Phi][\([imod[i], 
                              imod[j - 
                                  1]]\)])\)/\((2\ \[CapitalDelta]y)\)}, {i, 
                  1, M + 1}, {j, 1, M + 1}]\), ";"}]}], " ", 
        "]"}]}]}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.71"],

Cell[TextData[{
  "Note that we require the FFT  of ",
  Cell[BoxData[
      FormBox[
        StyleBox["\[Rho]",
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[Rho]\&~\),
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  ", to satisfy ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[\(\[Rho]\&~[\([1, 1]\)]\),
            FontFamily->"Courier",
            FontWeight->"Bold"], "=", "0"}], TraditionalForm]]],
  ". This is equivalent to ensuring that the total mass  in the domain is \
zero. Recall from Sec. ",
  ButtonBox["6.2.2",
    ButtonData:>{"Chapter6.nb", "c:26"},
    ButtonStyle->"Hyperlink"],
  " that this constraint on the mass density is required by the periodic \
boundary conditions, in order to keep the potential finite. Since the term ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[Rho]\&~[\([1, 1]\)]\),
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  " creates a uniform mass density, setting it equal to zero has no effect on \
the force between the particles. Physically, setting this term equal to zero \
is equivalent to adding a uniform ",
  StyleBox["negative",
    FontSlant->"Italic"],
  " mass density to the system so that the total mass vanishes. But this \
uniform mass density has no effect on the particle dynamics. \n\tAlso, note \
that the factor used to convert Fourier-transformed density to potential, ",
  StyleBox["factor\[Phi]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", is defined using double equal signs so that its values are remembered. \
We will be evaluating the potential many times, and it is wasteful to \
reevaluate the sin and cosine functions in ",
  StyleBox["factor\[Phi]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " at every timestep."
}], "Text"],

Cell[TextData[{
  "\tFinally,  note that we could have determined the force differently, by \
evaluating ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(-\[ImaginaryI]\), " ", 
          StyleBox["k",
            FontWeight->"Bold",
            FontSlant->"Plain"], " ", 
          RowBox[{
            StyleBox[
              OverscriptBox[
                StyleBox["\[Phi]",
                  FontWeight->"Plain",
                  FontSlant->"Plain"], "~"],
              FontWeight->"Plain",
              FontSlant->"Plain"], 
            StyleBox["(",
              FontWeight->"Plain",
              FontSlant->"Plain"], 
            StyleBox["k",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  " and then performing an FFT. However, this is not a good idea, for two \
reasons. First, two FFTs (one for each dimension) need to be done, and the \
FFT is the most time-consuming part of the algorithm. Second, this method \
places too much weight on large wavenumber contributions, and leads to large \
numerical error. This will be discussed in more detail in relation to Eq. (",
  ButtonBox["7.3.12",
    ButtonData:>"(7.3.12)",
    ButtonStyle->"Hyperlink"],
  ")."
}], "Text"],

Cell[TextData[{
  "In Cell ",
  ButtonBox["7.72",
    ButtonData:>"Cell 7.72",
    ButtonStyle->"Hyperlink"],
  ", we evaluate the potential and force created by the previous density \
distribution."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< Graphics`;\)\), "\n", 
    \(\(fft\[Phi][\[Rho]];\)\), "\n", 
    \(\(ListPlot3D[\[Phi], PlotRange \[Rule] All];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.72"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.15237 .19707 -5.94882 -9 ]
[.15237 .19707 .05118 0 ]
[.31741 .13214 -11.2392 -9 ]
[.31741 .13214 .76076 0 ]
[.49342 .06293 -10.5808 -9 ]
[.49342 .06293 1.41915 0 ]
[.68156 -0.01098 -9.92245 -9 ]
[.68156 -0.01098 2.07755 0 ]
[.77078 .10213 0 -6.15691 ]
[.77078 .10213 6 2.84309 ]
[.84915 .22213 0 -6.0419 ]
[.84915 .22213 12 2.9581 ]
[.9191 .32925 0 -5.94182 ]
[.9191 .32925 12 3.05818 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 12 3.14607 ]
[.02317 .27102 -18 -2.74731 ]
[.02317 .27102 0 6.25269 ]
[.01234 .33888 -12 -2.80473 ]
[.01234 .33888 0 6.19527 ]
[.00103 .40979 -6 -2.865 ]
[.00103 .40979 0 6.135 ]
[-0.01081 .48397 -6 -2.92835 ]
[-0.01081 .48397 0 6.07165 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.16157 .20642 m
.16617 .2111 L
s
[(5)] .15237 .19707 .98294 1 Mshowa
.32604 .14202 m
.33035 .14696 L
s
[(10)] .31741 .13214 .87321 1 Mshowa
.50139 .07336 m
.50537 .07857 L
s
[(15)] .49342 .06293 .76347 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(20)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.19364 .19386 m
.19637 .1967 L
s
.22611 .18115 m
.22881 .18402 L
s
.259 .16827 m
.26166 .17117 L
s
.29231 .15523 m
.29493 .15816 L
s
.3602 .12864 m
.36275 .13164 L
s
.39481 .11509 m
.39732 .11812 L
s
.42987 .10136 m
.43235 .10443 L
s
.4654 .08745 m
.46783 .09055 L
s
.53786 .05908 m
.5402 .06224 L
s
.57482 .04461 m
.57712 .0478 L
s
.61228 .02994 m
.61453 .03317 L
s
.65025 .01507 m
.65245 .01833 L
s
.12989 .21883 m
.13268 .2216 L
s
.0986 .23108 m
.10142 .23383 L
s
.06769 .24318 m
.07054 .2459 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.75847 .10666 m
.75231 .10893 L
s
[(5)] .77078 .10213 -1 .3682 Mshowa
.83673 .22638 m
.83053 .22851 L
s
[(10)] .84915 .22213 -1 .34264 Mshowa
.9066 .33325 m
.90035 .33526 L
s
[(15)] .9191 .32925 -1 .3204 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(20)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.77486 .13175 m
.77116 .13309 L
s
.79088 .15624 m
.78717 .15756 L
s
.80652 .18016 m
.8028 .18147 L
s
.8218 .20354 m
.81808 .20483 L
s
.85133 .24872 m
.8476 .24998 L
s
.86561 .27055 m
.86188 .2718 L
s
.87957 .29191 m
.87583 .29314 L
s
.89323 .31281 m
.88949 .31402 L
s
.91968 .35327 m
.91593 .35445 L
s
.93249 .37286 m
.92873 .37403 L
s
.94503 .39204 m
.94127 .3932 L
s
.95731 .41083 m
.95355 .41198 L
s
.74167 .08097 m
.73798 .08235 L
s
.72446 .05465 m
.72078 .05604 L
s
.70682 .02766 m
.70315 .02908 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.0354 .26625 m
.04151 .26387 L
s
[(-10)] .02317 .27102 1 -0.38949 Mshowa
.02462 .33425 m
.03076 .33194 L
s
[(-5)] .01234 .33888 1 -0.37673 Mshowa
.01336 .40531 m
.01953 .40307 L
s
[(0)] .00103 .40979 1 -0.36333 Mshowa
.00158 .47964 m
.00778 .47748 L
s
[(5)] -0.01081 .48397 1 -0.34926 Mshowa
.125 Mabswid
.03328 .27962 m
.03695 .2782 L
s
.03114 .2931 m
.03482 .29169 L
s
.02899 .3067 m
.03267 .30529 L
s
.02682 .32041 m
.0305 .31902 L
s
.02241 .34821 m
.0261 .34683 L
s
.02018 .3623 m
.02387 .36092 L
s
.01793 .37651 m
.02162 .37514 L
s
.01565 .39084 m
.01935 .38949 L
s
.01105 .41991 m
.01475 .41857 L
s
.00871 .43464 m
.01242 .43331 L
s
.00636 .4495 m
.01007 .44818 L
s
.00398 .4645 m
.0077 .46319 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.694 .303 .304 r
.38616 .65913 .40384 .64035 .43026 .66589 .41296 .68136 Metetra
.673 .255 .243 r
.41296 .68136 .43026 .66589 .45755 .68812 .44061 .70007 Metetra
.637 .181 .153 r
.44061 .70007 .45755 .68812 .48565 .70684 .46906 .71505 Metetra
.571 .064 .01 r
.46906 .71505 .48565 .70684 .5145 .72183 .49822 .72611 Metetra
.431 0 0 r
.49822 .72611 .5145 .72183 .54402 .73291 .52802 .73308 Metetra
.138 0 0 r
.52802 .73308 .54402 .73291 .57413 .73991 .55836 .7358 Metetra
.277 .753 .934 r
.55836 .7358 .57413 .73991 .60473 .74268 .58915 .73418 Metetra
.555 .83 .997 r
.58915 .73418 .60473 .74268 .63571 .74111 .62028 .7281 Metetra
.672 .8 .943 r
.62028 .7281 .63571 .74111 .66698 .73511 .65164 .71751 Metetra
.72 .757 .882 r
.65164 .71751 .66698 .73511 .69843 .72461 .68311 .70239 Metetra
.742 .721 .832 r
.68311 .70239 .69843 .72461 .72993 .70959 .71459 .68274 Metetra
.753 .693 .794 r
.71459 .68274 .72993 .70959 .76137 .69004 .74594 .6586 Metetra
.759 .671 .764 r
.74594 .6586 .76137 .69004 .79263 .66603 .77705 .63004 Metetra
.763 .653 .741 r
.77705 .63004 .79263 .66603 .82359 .6376 .80781 .59717 Metetra
.765 .639 .722 r
.80781 .59717 .82359 .6376 .85414 .60488 .83809 .56014 Metetra
.766 .627 .706 r
.83809 .56014 .85414 .60488 .88417 .568 .8678 .5191 Metetra
.767 .617 .693 r
.8678 .5191 .88417 .568 .91356 .52714 .89681 .47427 Metetra
.768 .608 .681 r
.89681 .47427 .91356 .52714 .94221 .48247 .92505 .42586 Metetra
.41 .387 .723 r
.92505 .42586 .94221 .48247 .97003 .43424 .96316 .45457 Metetra
.672 .254 .242 r
.36797 .67454 .38616 .65913 .41296 .68136 .39516 .69325 Metetra
.637 .18 .152 r
.39516 .69325 .41296 .68136 .44061 .70007 .42319 .70821 Metetra
.569 .062 .007 r
.42319 .70821 .44061 .70007 .46906 .71505 .45199 .71925 Metetra
.429 0 0 r
.45199 .71925 .46906 .71505 .49822 .72611 .48148 .72618 Metetra
.134 0 0 r
.48148 .72618 .49822 .72611 .52802 .73308 .51156 .72886 Metetra
.281 .755 .936 r
.51156 .72886 .52802 .73308 .55836 .7358 .54215 .72717 Metetra
.557 .83 .997 r
.54215 .72717 .55836 .7358 .58915 .73418 .57313 .72102 Metetra
.673 .799 .943 r
.57313 .72102 .58915 .73418 .62028 .7281 .6044 .71035 Metetra
.72 .757 .881 r
.6044 .71035 .62028 .7281 .65164 .71751 .63585 .69513 Metetra
.742 .721 .832 r
.63585 .69513 .65164 .71751 .68311 .70239 .66736 .67537 Metetra
.753 .692 .794 r
.66736 .67537 .68311 .70239 .71459 .68274 .6988 .6511 Metetra
.759 .67 .764 r
.6988 .6511 .71459 .68274 .74594 .6586 .73007 .6224 Metetra
.763 .653 .741 r
.73007 .6224 .74594 .6586 .77705 .63004 .76103 .58939 Metetra
.765 .639 .722 r
.76103 .58939 .77705 .63004 .80781 .59717 .79158 .55219 Metetra
.766 .627 .706 r
.79158 .55219 .80781 .59717 .83809 .56014 .8216 .51099 Metetra
.767 .617 .693 r
.8216 .51099 .83809 .56014 .8678 .5191 .85098 .46599 Metetra
.768 .608 .681 r
.85098 .46599 .8678 .5191 .89681 .47427 .87963 .4174 Metetra
.401 .381 .722 r
.87963 .4174 .89681 .47427 .92505 .42586 .91713 .4461 Metetra
.671 .228 .19 r
.91713 .4461 .92505 .42586 .96316 .45457 .95543 .47159 Metetra
.636 .179 .15 r
.3493 .68636 .36797 .67454 .39516 .69325 .37691 .70131 Metetra
.568 .06 .005 r
.37691 .70131 .39516 .69325 .42319 .70821 .40534 .71232 Metetra
.426 0 0 r
.40534 .71232 .42319 .70821 .45199 .71925 .4345 .71922 Metetra
.13 0 0 r
.4345 .71922 .45199 .71925 .48148 .72618 .46432 .72185 Metetra
.285 .757 .938 r
.46432 .72185 .48148 .72618 .51156 .72886 .4947 .7201 Metetra
.558 .829 .996 r
.4947 .7201 .51156 .72886 .54215 .72717 .52553 .71388 Metetra
.673 .799 .942 r
.52553 .71388 .54215 .72717 .57313 .72102 .55672 .70312 Metetra
.72 .756 .881 r
.55672 .70312 .57313 .72102 .6044 .71035 .58814 .6878 Metetra
.742 .72 .831 r
.58814 .6878 .6044 .71035 .63585 .69513 .61967 .66792 Metetra
.753 .692 .793 r
.61967 .66792 .63585 .69513 .66736 .67537 .65121 .64352 Metetra
.759 .67 .764 r
.65121 .64352 .66736 .67537 .6988 .6511 .68262 .61469 Metetra
.763 .653 .741 r
.68262 .61469 .6988 .6511 .73007 .6224 .7138 .58153 Metetra
.765 .638 .722 r
.7138 .58153 .73007 .6224 .76103 .58939 .74461 .54417 Metetra
.766 .627 .706 r
.74461 .54417 .76103 .58939 .79158 .55219 .77496 .50281 Metetra
.767 .617 .693 r
.77496 .50281 .79158 .55219 .8216 .51099 .80472 .45763 Metetra
.768 .608 .681 r
.80472 .45763 .8216 .51099 .85098 .46599 .83379 .40887 Metetra
.391 .374 .721 r
.83379 .40887 .85098 .46599 .87963 .4174 .87066 .43755 Metetra
.671 .227 .189 r
.87066 .43755 .87963 .4174 .91713 .4461 .90836 .46302 Metetra
.644 .174 .122 r
.90836 .46302 .91713 .4461 .95543 .47159 .9468 .48501 Metetra
.567 .057 .002 r
.3302 .69435 .3493 .68636 .37691 .70131 .35825 .70533 Metetra
.424 0 0 r
.35825 .70533 .37691 .70131 .40534 .71232 .38709 .71219 Metetra
.125 0 0 r
.38709 .71219 .40534 .71232 .4345 .71922 .41663 .71477 Metetra
.289 .759 .94 r
.41663 .71477 .4345 .71922 .46432 .72185 .4468 .71296 Metetra
.56 .829 .996 r
.4468 .71296 .46432 .72185 .4947 .7201 .47748 .70667 Metetra
.674 .798 .941 r
.47748 .70667 .4947 .7201 .52553 .71388 .50857 .69582 Metetra
.721 .756 .88 r
.50857 .69582 .52553 .71388 .55672 .70312 .53996 .6804 Metetra
.742 .72 .831 r
.53996 .6804 .55672 .70312 .58814 .6878 .57152 .6604 Metetra
.753 .692 .793 r
.57152 .6604 .58814 .6878 .61967 .66792 .60315 .63588 Metetra
.759 .67 .764 r
.60315 .63588 .61967 .66792 .65121 .64352 .63472 .6069 Metetra
.762 .653 .74 r
.63472 .6069 .65121 .64352 .68262 .61469 .66611 .57359 Metetra
.765 .638 .722 r
.66611 .57359 .68262 .61469 .7138 .58153 .69719 .53608 Metetra
.766 .627 .706 r
.69719 .53608 .7138 .58153 .74461 .54417 .72786 .49454 Metetra
.767 .617 .693 r
.72786 .49454 .74461 .54417 .77496 .50281 .75801 .44919 Metetra
.768 .608 .681 r
.75801 .44919 .77496 .50281 .80472 .45763 .78751 .40025 Metetra
.381 .367 .719 r
.78751 .40025 .80472 .45763 .83379 .40887 .82373 .42891 Metetra
.671 .227 .188 r
.82373 .42891 .83379 .40887 .87066 .43755 .86083 .45436 Metetra
.643 .172 .12 r
.86083 .45436 .87066 .43755 .90836 .46302 .89871 .47633 Metetra
.6 .096 .027 r
.89871 .47633 .90836 .46302 .9468 .48501 .93725 .49456 Metetra
.421 0 0 r
.31072 .69827 .3302 .69435 .35825 .70533 .33922 .70509 Metetra
.121 0 0 r
.33922 .70509 .35825 .70533 .38709 .71219 .36849 .70763 Metetra
.293 .76 .942 r
.36849 .70763 .38709 .71219 .41663 .71477 .39844 .70576 Metetra
.561 .829 .996 r
.39844 .70576 .41663 .71477 .4468 .71296 .42896 .69939 Metetra
.674 .798 .941 r
.42896 .69939 .4468 .71296 .47748 .70667 .45995 .68845 Metetra
.721 .755 .88 r
.45995 .68845 .47748 .70667 .50857 .69582 .49131 .67292 Metetra
.742 .72 .831 r
.49131 .67292 .50857 .69582 .53996 .6804 .52291 .65281 Metetra
.753 .692 .793 r
.52291 .65281 .53996 .6804 .57152 .6604 .55463 .62816 Metetra
.759 .67 .764 r
.55463 .62816 .57152 .6604 .60315 .63588 .58635 .59904 Metetra
.762 .652 .74 r
.58635 .59904 .60315 .63588 .63472 .6069 .61795 .56557 Metetra
.765 .638 .722 r
.61795 .56557 .63472 .6069 .66611 .57359 .64931 .5279 Metetra
.766 .627 .706 r
.64931 .5279 .66611 .57359 .69719 .53608 .68032 .4862 Metetra
.767 .617 .693 r
.68032 .4862 .69719 .53608 .72786 .49454 .71085 .44067 Metetra
.767 .608 .681 r
.71085 .44067 .72786 .49454 .75801 .44919 .74079 .39154 Metetra
.37 .36 .718 r
.74079 .39154 .75801 .44919 .78751 .40025 .77635 .4202 Metetra
.67 .226 .186 r
.77635 .4202 .78751 .40025 .82373 .42891 .81283 .44562 Metetra
.643 .171 .119 r
.81283 .44562 .82373 .42891 .86083 .45436 .85013 .46756 Metetra
.6 .095 .024 r
.85013 .46756 .86083 .45436 .89871 .47633 .88815 .48576 Metetra
.528 0 0 r
.88815 .48576 .89871 .47633 .93725 .49456 .92676 .49996 Metetra
.116 0 0 r
.29091 .69793 .31072 .69827 .33922 .70509 .31989 .70042 Metetra
.296 .762 .944 r
.31989 .70042 .33922 .70509 .36849 .70763 .34961 .69848 Metetra
.562 .828 .995 r
.34961 .69848 .36849 .70763 .39844 .70576 .37997 .69203 Metetra
.674 .797 .94 r
.37997 .69203 .39844 .70576 .42896 .69939 .41087 .68101 Metetra
.721 .755 .879 r
.41087 .68101 .42896 .69939 .45995 .68845 .44219 .66537 Metetra
.742 .719 .831 r
.44219 .66537 .45995 .68845 .49131 .67292 .47381 .64515 Metetra
.753 .692 .793 r
.47381 .64515 .49131 .67292 .52291 .65281 .50563 .62036 Metetra
.759 .67 .764 r
.50563 .62036 .52291 .65281 .55463 .62816 .53751 .5911 Metetra
.762 .652 .74 r
.53751 .5911 .55463 .62816 .58635 .59904 .56933 .55748 Metetra
.764 .638 .721 r
.56933 .55748 .58635 .59904 .61795 .56557 .60097 .51964 Metetra
.766 .626 .706 r
.60097 .51964 .61795 .56557 .64931 .5279 .63231 .47777 Metetra
.767 .617 .693 r
.63231 .47777 .64931 .5279 .68032 .4862 .66323 .43206 Metetra
.767 .608 .681 r
.66323 .43206 .68032 .4862 .71085 .44067 .69362 .38276 Metetra
.358 .352 .716 r
.69362 .38276 .71085 .44067 .74079 .39154 .7285 .41139 Metetra
.67 .225 .185 r
.7285 .41139 .74079 .39154 .77635 .4202 .76435 .4368 Metetra
.642 .17 .117 r
.76435 .4368 .77635 .4202 .81283 .44562 .80106 .45871 Metetra
.599 .093 .022 r
.80106 .45871 .81283 .44562 .85013 .46756 .83855 .47686 Metetra
.527 0 0 r
.83855 .47686 .85013 .46756 .88815 .48576 .87668 .49102 Metetra
.403 0 0 r
.87668 .49102 .88815 .48576 .92676 .49996 .91534 .50095 Metetra
.3 .763 .946 r
.27083 .69314 .29091 .69793 .31989 .70042 .30032 .69114 Metetra
.564 .828 .995 r
.30032 .69114 .31989 .70042 .34961 .69848 .33051 .68461 Metetra
.675 .797 .94 r
.33051 .68461 .34961 .69848 .37997 .69203 .3613 .67349 Metetra
.721 .754 .879 r
.3613 .67349 .37997 .69203 .41087 .68101 .39258 .65775 Metetra
.742 .719 .83 r
.39258 .65775 .41087 .68101 .44219 .66537 .42424 .6374 Metetra
.753 .691 .793 r
.42424 .6374 .44219 .66537 .47381 .64515 .45614 .61249 Metetra
.759 .67 .764 r
.45614 .61249 .47381 .64515 .50563 .62036 .48818 .58309 Metetra
.762 .652 .74 r
.48818 .58309 .50563 .62036 .53751 .5911 .52022 .54931 Metetra
.764 .638 .721 r
.52022 .54931 .53751 .5911 .56933 .55748 .55214 .51131 Metetra
.766 .626 .706 r
.55214 .51131 .56933 .55748 .60097 .51964 .58383 .46926 Metetra
.767 .617 .693 r
.58383 .46926 .60097 .51964 .63231 .47777 .61515 .42338 Metetra
.767 .608 .681 r
.61515 .42338 .63231 .47777 .66323 .43206 .64599 .37389 Metetra
.346 .344 .714 r
.64599 .37389 .66323 .43206 .69362 .38276 .68018 .4025 Metetra
.67 .224 .184 r
.68018 .4025 .69362 .38276 .7285 .41139 .71538 .42788 Metetra
.642 .169 .115 r
.71538 .42788 .7285 .41139 .76435 .4368 .7515 .44976 Metetra
.598 .092 .02 r
.7515 .44976 .76435 .4368 .80106 .45871 .78844 .46787 Metetra
.525 0 0 r
.78844 .46787 .80106 .45871 .83855 .47686 .82608 .48198 Metetra
.4 0 0 r
.82608 .48198 .83855 .47686 .87668 .49102 .8643 .49185 Metetra
.186 0 0 r
.8643 .49185 .87668 .49102 .91534 .50095 .90296 .49728 Metetra
.565 .828 .995 r
.25054 .68372 .27083 .69314 .30032 .69114 .28056 .67711 Metetra
.675 .796 .939 r
.28056 .67711 .30032 .69114 .33051 .68461 .31125 .6659 Metetra
.721 .754 .879 r
.31125 .6659 .33051 .68461 .3613 .67349 .34249 .65006 Metetra
.742 .719 .83 r
.34249 .65006 .3613 .67349 .39258 .65775 .37417 .62959 Metetra
.753 .691 .793 r
.37417 .62959 .39258 .65775 .42424 .6374 .40617 .60454 Metetra
.759 .669 .763 r
.40617 .60454 .42424 .6374 .45614 .61249 .43836 .57499 Metetra
.762 .652 .74 r
.43836 .57499 .45614 .61249 .48818 .58309 .47063 .54106 Metetra
.764 .638 .721 r
.47063 .54106 .48818 .58309 .52022 .54931 .50284 .50289 Metetra
.766 .626 .706 r
.50284 .50289 .52022 .54931 .55214 .51131 .53487 .46067 Metetra
.767 .617 .693 r
.53487 .46067 .55214 .51131 .58383 .46926 .5666 .4146 Metetra
.767 .608 .682 r
.5666 .4146 .58383 .46926 .61515 .42338 .5979 .36493 Metetra
.333 .335 .712 r
.5979 .36493 .61515 .42338 .64599 .37389 .63138 .39352 Metetra
.669 .223 .183 r
.63138 .39352 .64599 .37389 .68018 .4025 .66592 .41888 Metetra
.641 .168 .114 r
.66592 .41888 .68018 .4025 .71538 .42788 .70143 .44072 Metetra
.597 .09 .018 r
.70143 .44072 .71538 .42788 .7515 .44976 .73781 .45879 Metetra
.524 0 0 r
.73781 .45879 .7515 .44976 .78844 .46787 .77495 .47285 Metetra
.397 0 0 r
.77495 .47285 .78844 .46787 .82608 .48198 .81273 .48266 Metetra
.183 0 0 r
.81273 .48266 .82608 .48198 .8643 .49185 .85101 .48801 Metetra
.119 .657 .85 r
.85101 .48801 .8643 .49185 .90296 .49728 .88964 .48874 Metetra
.675 .795 .939 r
.23012 .66954 .25054 .68372 .28056 .67711 .2607 .65823 Metetra
.721 .754 .878 r
.2607 .65823 .28056 .67711 .31125 .6659 .29189 .64228 Metetra
.742 .718 .83 r
.29189 .64228 .31125 .6659 .34249 .65006 .3236 .62169 Metetra
.753 .691 .792 r
.3236 .62169 .34249 .65006 .37417 .62959 .3557 .59651 Metetra
.758 .669 .763 r
.3557 .59651 .37417 .62959 .40617 .60454 .38805 .56681 Metetra
.762 .652 .74 r
.38805 .56681 .40617 .60454 .43836 .57499 .42055 .53272 Metetra
.764 .638 .721 r
.42055 .53272 .43836 .57499 .47063 .54106 .45305 .49439 Metetra
.766 .626 .706 r
.45305 .49439 .47063 .54106 .50284 .50289 .48543 .45199 Metetra
.767 .617 .693 r
.48543 .45199 .50284 .50289 .53487 .46067 .51757 .40574 Metetra
.767 .608 .682 r
.51757 .40574 .53487 .46067 .5666 .4146 .54934 .35589 Metetra
.319 .326 .71 r
.54934 .35589 .5666 .4146 .5979 .36493 .5821 .38445 Metetra
.669 .222 .181 r
.5821 .38445 .5979 .36493 .63138 .39352 .61596 .40978 Metetra
.64 .166 .112 r
.61596 .40978 .63138 .39352 .66592 .41888 .65084 .43159 Metetra
.596 .088 .016 r
.65084 .43159 .66592 .41888 .70143 .44072 .68665 .44962 Metetra
.522 0 0 r
.68665 .44962 .70143 .44072 .73781 .45879 .72327 .46362 Metetra
.395 0 0 r
.72327 .46362 .73781 .45879 .77495 .47285 .7606 .47336 Metetra
.179 0 0 r
.7606 .47336 .77495 .47285 .81273 .48266 .79849 .47864 Metetra
.123 .66 .853 r
.79849 .47864 .81273 .48266 .85101 .48801 .83681 .47928 Metetra
.404 .798 .987 r
.83681 .47928 .85101 .48801 .88964 .48874 .8754 .47514 Metetra
.721 .753 .878 r
.20965 .65049 .23012 .66954 .2607 .65823 .2408 .63443 Metetra
.742 .718 .83 r
.2408 .63443 .2607 .65823 .29189 .64228 .27253 .61372 Metetra
.752 .691 .792 r
.27253 .61372 .29189 .64228 .3236 .62169 .30472 .5884 Metetra
.758 .669 .763 r
.30472 .5884 .3236 .62169 .3557 .59651 .33724 .55855 Metetra
.762 .652 .74 r
.33724 .55855 .3557 .59651 .38805 .56681 .36996 .5243 Metetra
.764 .638 .721 r
.36996 .5243 .38805 .56681 .42055 .53272 .40276 .4858 Metetra
.766 .626 .706 r
.40276 .4858 .42055 .53272 .45305 .49439 .4355 .44323 Metetra
.767 .616 .693 r
.4355 .44323 .45305 .49439 .48543 .45199 .46806 .3968 Metetra
.767 .608 .682 r
.46806 .3968 .48543 .45199 .51757 .40574 .50031 .34675 Metetra
.304 .315 .707 r
.50031 .34675 .51757 .40574 .54934 .35589 .53233 .3753 Metetra
.669 .221 .18 r
.53233 .3753 .54934 .35589 .5821 .38445 .56549 .40059 Metetra
.64 .165 .11 r
.56549 .40059 .5821 .38445 .61596 .40978 .59973 .42236 Metetra
.595 .087 .013 r
.59973 .42236 .61596 .40978 .65084 .43159 .63495 .44035 Metetra
.521 0 0 r
.63495 .44035 .65084 .43159 .68665 .44962 .67105 .45429 Metetra
.392 0 0 r
.67105 .45429 .68665 .44962 .72327 .46362 .70791 .46397 Metetra
.175 0 0 r
.70791 .46397 .72327 .46362 .7606 .47336 .74541 .46917 Metetra
.127 .663 .856 r
.74541 .46917 .7606 .47336 .79849 .47864 .7834 .46972 Metetra
.406 .798 .988 r
.7834 .46972 .79849 .47864 .83681 .47928 .82173 .46547 Metetra
.581 .824 .991 r
.82173 .46547 .83681 .47928 .8754 .47514 .86025 .45631 Metetra
.742 .718 .829 r
.18919 .6265 .20965 .65049 .2408 .63443 .22095 .60566 Metetra
.752 .69 .792 r
.22095 .60566 .2408 .63443 .27253 .61372 .25323 .58021 Metetra
.758 .669 .763 r
.25323 .58021 .27253 .61372 .30472 .5884 .28591 .55021 Metetra
.762 .652 .74 r
.28591 .55021 .30472 .5884 .33724 .55855 .31887 .5158 Metetra
.764 .638 .721 r
.31887 .5158 .33724 .55855 .36996 .5243 .35196 .47713 Metetra
.765 .626 .706 r
.35196 .47713 .36996 .5243 .40276 .4858 .38507 .43437 Metetra
.766 .616 .693 r
.38507 .43437 .40276 .4858 .4355 .44323 .41805 .38776 Metetra
.767 .608 .682 r
.41805 .38776 .4355 .44323 .46806 .3968 .45079 .33753 Metetra
.288 .305 .704 r
.45079 .33753 .46806 .3968 .50031 .34675 .48205 .36604 Metetra
.668 .22 .179 r
.48205 .36604 .50031 .34675 .53233 .3753 .51451 .39131 Metetra
.639 .164 .109 r
.51451 .39131 .53233 .3753 .56549 .40059 .54809 .41304 Metetra
.594 .085 .011 r
.54809 .41304 .56549 .40059 .59973 .42236 .58271 .43098 Metetra
.519 0 0 r
.58271 .43098 .59973 .42236 .63495 .44035 .61826 .44487 Metetra
.39 0 0 r
.61826 .44487 .63495 .44035 .67105 .45429 .65465 .45448 Metetra
.171 0 0 r
.65465 .45448 .67105 .45429 .70791 .46397 .69174 .4596 Metetra
.131 .665 .86 r
.69174 .4596 .70791 .46397 .74541 .46917 .72939 .46005 Metetra
.409 .799 .989 r
.72939 .46005 .74541 .46917 .7834 .46972 .76747 .45569 Metetra
.582 .823 .99 r
.76747 .45569 .7834 .46972 .82173 .46547 .8058 .44641 Metetra
.672 .8 .943 r
.8058 .44641 .82173 .46547 .86025 .45631 .84423 .43214 Metetra
.752 .69 .792 r
.16884 .59753 .18919 .6265 .22095 .60566 .20122 .57193 Metetra
.758 .669 .763 r
.20122 .57193 .22095 .60566 .25323 .58021 .23407 .54178 Metetra
.762 .652 .74 r
.23407 .54178 .25323 .58021 .28591 .55021 .26726 .50721 Metetra
.764 .638 .721 r
.26726 .50721 .28591 .55021 .31887 .5158 .30066 .46837 Metetra
.765 .626 .706 r
.30066 .46837 .31887 .5158 .35196 .47713 .33413 .42543 Metetra
.766 .616 .693 r
.33413 .42543 .35196 .47713 .38507 .43437 .36755 .37864 Metetra
.767 .608 .682 r
.36755 .37864 .38507 .43437 .41805 .38776 .40078 .32821 Metetra
.271 .293 .701 r
.40078 .32821 .41805 .38776 .45079 .33753 .43127 .3567 Metetra
.668 .219 .177 r
.43127 .3567 .45079 .33753 .48205 .36604 .463 .38193 Metetra
.639 .163 .107 r
.463 .38193 .48205 .36604 .51451 .39131 .49591 .40362 Metetra
.593 .083 .009 r
.49591 .40362 .51451 .39131 .54809 .41304 .52991 .42151 Metetra
.518 0 0 r
.52991 .42151 .54809 .41304 .58271 .43098 .56491 .43534 Metetra
.387 0 0 r
.56491 .43534 .58271 .43098 .61826 .44487 .60081 .44488 Metetra
.167 0 0 r
.60081 .44488 .61826 .44487 .65465 .45448 .63748 .44992 Metetra
.136 .668 .863 r
.63748 .44992 .65465 .45448 .69174 .4596 .67479 .45027 Metetra
.412 .8 .989 r
.67479 .45027 .69174 .4596 .72939 .46005 .71259 .4458 Metetra
.583 .823 .99 r
.71259 .4458 .72939 .46005 .76747 .45569 .75074 .43639 Metetra
.673 .799 .943 r
.75074 .43639 .76747 .45569 .8058 .44641 .78905 .42198 Metetra
.719 .766 .89 r
.78905 .42198 .8058 .44641 .84423 .43214 .82737 .40254 Metetra
.758 .669 .763 r
.14868 .56357 .16884 .59753 .20122 .57193 .1817 .53327 Metetra
.762 .651 .74 r
.1817 .53327 .20122 .57193 .23407 .54178 .21513 .49854 Metetra
.764 .638 .721 r
.21513 .49854 .23407 .54178 .26726 .50721 .24884 .45952 Metetra
.765 .626 .706 r
.24884 .45952 .26726 .50721 .30066 .46837 .28269 .4164 Metetra
.766 .616 .693 r
.28269 .4164 .30066 .46837 .33413 .42543 .31654 .36942 Metetra
.767 .608 .682 r
.31654 .36942 .33413 .42543 .36755 .37864 .35027 .31881 Metetra
.252 .28 .697 r
.35027 .31881 .36755 .37864 .40078 .32821 .37998 .34726 Metetra
.667 .218 .176 r
.37998 .34726 .40078 .32821 .43127 .3567 .41097 .37245 Metetra
.638 .162 .105 r
.41097 .37245 .43127 .3567 .463 .38193 .44318 .3941 Metetra
.592 .082 .007 r
.44318 .3941 .463 .38193 .49591 .40362 .47655 .41194 Metetra
.516 0 0 r
.47655 .41194 .49591 .40362 .52991 .42151 .51099 .42571 Metetra
.384 0 0 r
.51099 .42571 .52991 .42151 .56491 .43534 .54638 .43517 Metetra
.163 0 0 r
.54638 .43517 .56491 .43534 .60081 .44488 .58262 .44013 Metetra
.14 .67 .866 r
.58262 .44013 .60081 .44488 .63748 .44992 .61957 .44038 Metetra
.414 .8 .99 r
.61957 .44038 .63748 .44992 .67479 .45027 .6571 .4358 Metetra
.584 .822 .989 r
.6571 .4358 .67479 .45027 .71259 .4458 .69504 .42626 Metetra
.673 .799 .942 r
.69504 .42626 .71259 .4458 .75074 .43639 .73325 .41171 Metetra
.719 .766 .889 r
.73325 .41171 .75074 .43639 .78905 .42198 .77153 .39211 Metetra
.744 .734 .843 r
.77153 .39211 .78905 .42198 .82737 .40254 .80974 .36748 Metetra
.762 .651 .74 r
.12879 .52467 .14868 .56357 .1817 .53327 .16246 .48977 Metetra
.764 .638 .721 r
.16246 .48977 .1817 .53327 .21513 .49854 .19649 .45058 Metetra
.765 .626 .706 r
.19649 .45058 .21513 .49854 .24884 .45952 .23072 .40728 Metetra
.766 .616 .693 r
.23072 .40728 .24884 .45952 .28269 .4164 .26502 .36011 Metetra
.767 .608 .682 r
.26502 .36011 .28269 .4164 .31654 .36942 .29926 .3093 Metetra
.233 .267 .692 r
.29926 .3093 .31654 .36942 .35027 .31881 .32816 .33773 Metetra
.667 .218 .175 r
.32816 .33773 .35027 .31881 .37998 .34726 .35839 .36288 Metetra
.638 .16 .103 r
.35839 .36288 .37998 .34726 .41097 .37245 .3899 .38449 Metetra
.591 .08 .004 r
.3899 .38449 .41097 .37245 .44318 .3941 .42262 .40227 Metetra
.515 0 0 r
.42262 .40227 .44318 .3941 .47655 .41194 .45647 .41597 Metetra
.382 0 0 r
.45647 .41597 .47655 .41194 .51099 .42571 .49135 .42536 Metetra
.159 0 0 r
.49135 .42536 .51099 .42571 .54638 .43517 .52715 .43023 Metetra
.144 .673 .869 r
.52715 .43023 .54638 .43517 .58262 .44013 .56374 .43039 Metetra
.417 .801 .991 r
.56374 .43039 .58262 .44013 .61957 .44038 .60098 .42569 Metetra
.586 .822 .989 r
.60098 .42569 .61957 .44038 .6571 .4358 .63872 .41602 Metetra
.674 .798 .941 r
.63872 .41602 .6571 .4358 .69504 .42626 .6768 .40132 Metetra
.719 .765 .889 r
.6768 .40132 .69504 .42626 .73325 .41171 .71505 .38156 Metetra
.744 .734 .843 r
.71505 .38156 .73325 .41171 .77153 .39211 .75331 .35676 Metetra
.758 .707 .804 r
.75331 .35676 .77153 .39211 .80974 .36748 .79138 .32699 Metetra
.764 .637 .721 r
.10926 .48092 .12879 .52467 .16246 .48977 .1436 .44155 Metetra
.765 .626 .706 r
.1436 .44155 .16246 .48977 .19649 .45058 .17822 .39807 Metetra
.766 .616 .693 r
.17822 .39807 .19649 .45058 .23072 .40728 .21298 .35071 Metetra
.767 .608 .682 r
.21298 .35071 .23072 .40728 .26502 .36011 .24773 .29971 Metetra
.211 .252 .687 r
.24773 .29971 .26502 .36011 .29926 .3093 .27581 .32809 Metetra
.667 .217 .174 r
.27581 .32809 .29926 .3093 .32816 .33773 .30526 .35321 Metetra
.637 .159 .102 r
.30526 .35321 .32816 .33773 .35839 .36288 .33605 .37476 Metetra
.59 .078 .002 r
.33605 .37476 .35839 .36288 .3899 .38449 .36811 .39249 Metetra
.513 0 0 r
.36811 .39249 .3899 .38449 .42262 .40227 .40136 .40613 Metetra
.379 0 0 r
.40136 .40613 .42262 .40227 .45647 .41597 .43571 .41545 Metetra
.155 0 0 r
.43571 .41545 .45647 .41597 .49135 .42536 .47106 .42022 Metetra
.148 .675 .872 r
.47106 .42022 .49135 .42536 .52715 .43023 .50727 .42027 Metetra
.42 .801 .991 r
.50727 .42027 .52715 .43023 .56374 .43039 .54421 .41546 Metetra
.587 .822 .988 r
.54421 .41546 .56374 .43039 .60098 .42569 .58174 .40566 Metetra
.674 .798 .941 r
.58174 .40566 .60098 .42569 .63872 .41602 .61969 .39081 Metetra
.719 .765 .889 r
.61969 .39081 .63872 .41602 .6768 .40132 .65791 .37088 Metetra
.744 .734 .842 r
.65791 .37088 .6768 .40132 .71505 .38156 .69621 .34591 Metetra
.758 .707 .804 r
.69621 .34591 .71505 .38156 .75331 .35676 .73443 .31595 Metetra
.767 .685 .772 r
.73443 .31595 .75331 .35676 .79138 .32699 .77238 .28111 Metetra
.765 .626 .706 r
.09017 .43242 .10926 .48092 .1436 .44155 .12518 .38876 Metetra
.766 .616 .693 r
.12518 .38876 .1436 .44155 .17822 .39807 .1604 .34121 Metetra
.767 .608 .682 r
.1604 .34121 .17822 .39807 .21298 .35071 .19568 .29001 Metetra
.189 .236 .681 r
.19568 .29001 .21298 .35071 .24773 .29971 .22292 .31836 Metetra
.666 .216 .172 r
.22292 .31836 .24773 .29971 .27581 .32809 .25158 .34343 Metetra
.636 .158 .1 r
.25158 .34343 .27581 .32809 .30526 .35321 .28163 .36494 Metetra
.589 .076 0 r
.28163 .36494 .30526 .35321 .33605 .37476 .31301 .38261 Metetra
.511 0 0 r
.31301 .38261 .33605 .37476 .36811 .39249 .34565 .39618 Metetra
.376 0 0 r
.34565 .39618 .36811 .39249 .40136 .40613 .37946 .40542 Metetra
.151 0 0 r
.37946 .40542 .40136 .40613 .43571 .41545 .41433 .4101 Metetra
.152 .678 .874 r
.41433 .4101 .43571 .41545 .47106 .42022 .45016 .41005 Metetra
.422 .802 .992 r
.45016 .41005 .47106 .42022 .50727 .42027 .48679 .40511 Metetra
.588 .821 .988 r
.48679 .40511 .50727 .42027 .54421 .41546 .5241 .39518 Metetra
.674 .797 .94 r
.5241 .39518 .54421 .41546 .58174 .40566 .56193 .38018 Metetra
.719 .764 .888 r
.56193 .38018 .58174 .40566 .61969 .39081 .6001 .36009 Metetra
.744 .733 .842 r
.6001 .36009 .61969 .39081 .65791 .37088 .63845 .33493 Metetra
.758 .707 .804 r
.63845 .33493 .65791 .37088 .69621 .34591 .6768 .30477 Metetra
.767 .685 .772 r
.6768 .30477 .69621 .34591 .73443 .31595 .71498 .26974 Metetra
.772 .666 .746 r
.71498 .26974 .73443 .31595 .77238 .28111 .7528 .22999 Metetra
.766 .616 .693 r
.0716 .37935 .09017 .43242 .12518 .38876 .10729 .33161 Metetra
.767 .608 .682 r
.10729 .33161 .12518 .38876 .1604 .34121 .14311 .28022 Metetra
.164 .219 .674 r
.14311 .28022 .1604 .34121 .19568 .29001 .16948 .30853 Metetra
.666 .215 .171 r
.16948 .30853 .19568 .29001 .22292 .31836 .19733 .33356 Metetra
.636 .157 .098 r
.19733 .33356 .22292 .31836 .25158 .34343 .22662 .35501 Metetra
.588 .075 0 r
.22662 .35501 .25158 .34343 .28163 .36494 .25731 .37262 Metetra
.51 0 0 r
.25731 .37262 .28163 .36494 .31301 .38261 .28932 .38612 Metetra
.374 0 0 r
.28932 .38612 .31301 .38261 .34565 .39618 .32257 .39528 Metetra
.146 0 0 r
.32257 .39528 .34565 .39618 .37946 .40542 .35697 .39987 Metetra
.156 .68 .877 r
.35697 .39987 .37946 .40542 .41433 .4101 .39239 .3997 Metetra
.425 .802 .992 r
.39239 .3997 .41433 .4101 .45016 .41005 .42871 .39464 Metetra
.589 .821 .988 r
.42871 .39464 .45016 .41005 .48679 .40511 .4658 .38457 Metetra
.675 .797 .94 r
.4658 .38457 .48679 .40511 .5241 .39518 .50348 .36942 Metetra
.719 .764 .888 r
.50348 .36942 .5241 .39518 .56193 .38018 .54161 .34916 Metetra
.744 .733 .842 r
.54161 .34916 .56193 .38018 .6001 .36009 .58001 .32382 Metetra
.758 .707 .804 r
.58001 .32382 .6001 .36009 .63845 .33493 .61849 .29347 Metetra
.766 .684 .772 r
.61849 .29347 .63845 .33493 .6768 .30477 .6569 .25823 Metetra
.772 .666 .746 r
.6569 .25823 .6768 .30477 .71498 .26974 .69503 .21826 Metetra
.776 .65 .724 r
.69503 .21826 .71498 .26974 .7528 .22999 .73272 .17377 Metetra
.767 .608 .682 r
.05363 .32191 .0716 .37935 .10729 .33161 .08999 .27033 Metetra
.137 .2 .666 r
.08999 .27033 .10729 .33161 .14311 .28022 .11548 .2986 Metetra
.665 .214 .17 r
.11548 .2986 .14311 .28022 .16948 .30853 .1425 .32357 Metetra
.635 .155 .097 r
.1425 .32357 .16948 .30853 .19733 .33356 .17102 .34497 Metetra
.587 .073 0 r
.17102 .34497 .19733 .33356 .22662 .35501 .201 .36252 Metetra
.508 0 0 r
.201 .36252 .22662 .35501 .25731 .37262 .23236 .37595 Metetra
.371 0 0 r
.23236 .37595 .25731 .37262 .28932 .38612 .26504 .38502 Metetra
.142 0 0 r
.26504 .38502 .28932 .38612 .32257 .39528 .29895 .38951 Metetra
.161 .682 .88 r
.29895 .38951 .32257 .39528 .35697 .39987 .33396 .38924 Metetra
.427 .803 .993 r
.33396 .38924 .35697 .39987 .39239 .3997 .36996 .38406 Metetra
.59 .82 .987 r
.36996 .38406 .39239 .3997 .42871 .39464 .40681 .37384 Metetra
.675 .796 .939 r
.40681 .37384 .42871 .39464 .4658 .38457 .44435 .35854 Metetra
.719 .763 .887 r
.44435 .35854 .4658 .38457 .50348 .36942 .48243 .33811 Metetra
.744 .733 .842 r
.48243 .33811 .50348 .36942 .54161 .34916 .52087 .31258 Metetra
.758 .706 .803 r
.52087 .31258 .54161 .34916 .58001 .32382 .55949 .28204 Metetra
.766 .684 .772 r
.55949 .28204 .58001 .32382 .61849 .29347 .59812 .24659 Metetra
.772 .666 .746 r
.59812 .24659 .61849 .29347 .6569 .25823 .63658 .2064 Metetra
.775 .65 .724 r
.63658 .2064 .6569 .25823 .69503 .21826 .67468 .16168 Metetra
.778 .637 .705 r
.67468 .16168 .69503 .21826 .73272 .17377 .71225 .11269 Metetra
.109 .18 .657 r
.03634 .26033 .05363 .32191 .08999 .27033 .06093 .28856 Metetra
.665 .213 .168 r
.06093 .28856 .08999 .27033 .11548 .2986 .0871 .31348 Metetra
.635 .154 .095 r
.0871 .31348 .11548 .2986 .1425 .32357 .11482 .33483 Metetra
.587 .071 0 r
.11482 .33483 .1425 .32357 .17102 .34497 .14407 .35231 Metetra
.506 0 0 r
.14407 .35231 .17102 .34497 .201 .36252 .17477 .36567 Metetra
.368 0 0 r
.17477 .36567 .201 .36252 .23236 .37595 .20687 .37465 Metetra
.138 0 0 r
.20687 .37465 .23236 .37595 .26504 .38502 .24026 .37904 Metetra
.165 .685 .883 r
.24026 .37904 .26504 .38502 .29895 .38951 .27485 .37866 Metetra
.43 .803 .993 r
.27485 .37866 .29895 .38951 .33396 .38924 .31052 .37335 Metetra
.591 .82 .987 r
.31052 .37335 .33396 .38924 .36996 .38406 .34713 .36299 Metetra
.675 .795 .939 r
.34713 .36299 .36996 .38406 .40681 .37384 .38452 .34752 Metetra
.72 .763 .887 r
.38452 .34752 .40681 .37384 .44435 .35854 .42254 .32692 Metetra
.744 .732 .841 r
.42254 .32692 .44435 .35854 .48243 .33811 .46103 .30121 Metetra
.758 .706 .803 r
.46103 .30121 .48243 .33811 .52087 .31258 .49979 .27046 Metetra
.766 .684 .772 r
.49979 .27046 .52087 .31258 .55949 .28204 .53865 .2348 Metetra
.772 .666 .746 r
.53865 .2348 .55949 .28204 .59812 .24659 .57743 .19439 Metetra
.775 .65 .724 r
.57743 .19439 .59812 .24659 .63658 .2064 .61594 .14945 Metetra
.778 .637 .705 r
.61594 .14945 .63658 .2064 .67468 .16168 .65401 .10022 Metetra
.78 .625 .689 r
.65401 .10022 .67468 .16168 .71225 .11269 .69147 .04701 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.16157 .20642 m
.16617 .2111 L
s
[(5)] .15237 .19707 .98294 1 Mshowa
.32604 .14202 m
.33035 .14696 L
s
[(10)] .31741 .13214 .87321 1 Mshowa
.50139 .07336 m
.50537 .07857 L
s
[(15)] .49342 .06293 .76347 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(20)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.19364 .19386 m
.19637 .1967 L
s
.22611 .18115 m
.22881 .18402 L
s
.259 .16827 m
.26166 .17117 L
s
.29231 .15523 m
.29493 .15816 L
s
.3602 .12864 m
.36275 .13164 L
s
.39481 .11509 m
.39732 .11812 L
s
.42987 .10136 m
.43235 .10443 L
s
.4654 .08745 m
.46783 .09055 L
s
.53786 .05908 m
.5402 .06224 L
s
.57482 .04461 m
.57712 .0478 L
s
.61228 .02994 m
.61453 .03317 L
s
.65025 .01507 m
.65245 .01833 L
s
.12989 .21883 m
.13268 .2216 L
s
.0986 .23108 m
.10142 .23383 L
s
.06769 .24318 m
.07054 .2459 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00ioooool5o`0000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP1dooooo`00ioooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`1dooooo`00j?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@4100M?ooool00>Wooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooo
oooooooooooo000007Cooooo003Zooooo`03ogMgMomVIVKooooo00;ooooo00Go0000oooooooooooo
ooooo`00001dooooo`00joooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@oooooooo
ool0L_ooool00>Oooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL0M?ooool00>Oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h0M?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?Cooooo0_l0001booooo`00lOooool3o`000003ooooool0003ooooo077ooooo003_ooooo`;o
00001?ooool2o`00077ooooo003/ooooo`?o00001_ooool00ol0003oooooo`00001`ooooo`00j_oo
ool2o`0000Wooooo00?o0000ooooool00000L?ooool00>Oooooo0ol0000;ooooo`04o`000?oooooo
ooooo`0006oooooo003Uooooo`;o000000?oooooo`000?ooool02oooool01Ol0003ooooooooooooo
oooo000006kooooo003Rooooo`?o00001?ooool00ol0003oooooooooo`09ooooo`05o`000?oooooo
ooooooooool00000K_ooool00=oooooo0ol0000Cooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0Joooool00=gooooo0_l0000Gooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0J_ooool00=[ooooo0ol0000Iooooo`04o`000?ooooooooooooooo`;o0000K?ooool00=So
oooo0_l00002ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`1Yooooo`00eOooool3o`0000Cooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo06Sooooo002Xooooo`Co000000Go410@oooooooooooooooo
odA4A002o`000003oc8b<_oMgMgooooo01gooooo0_l0000Qooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0J?ooool00:[ooooo00?o0000ooooooooool01_ooool00omgMgOo<S8boooo
o`0Jooooo`?o00008oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06Oooooo002Z
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05oooool2o`0002Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1Wooooo`00Z_ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo01Gooooo0ol000000ooooooo0000ooooo`0Uooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0I_ooool00:[ooooo00?o0000ooooooooool00oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<01Cooooo0_l00005ooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`1Uooooo`00Z_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo01?ooooo0ol0000/ooooo`;o00002Oooool00ol0003oooooooooo`1Uooooo`00
Z_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo0_l0000^ooooo`04o`00
0?o7Wk3o0000o`0000Sooooo0_l0001Vooooo`00Z?ooool00omEEEGoIVIVo`000005ooooo`Co0000
3Oooool3o`00033ooooo00Co0000olNO/?l0003o00002_ooool00ol0003oooooooooo`1Sooooo`00
__ooool3o`0000;ooooo00?o0000ooooooooool0;Oooool00ol0003oain`olNO/002o`0000[ooooo
00?o0000ooooooooool0Hoooool00;cooooo0_l0000dooooo`07o`000?o7Wk3oain`olNO/?l0003o
ain`o`00000:ooooo`03o`000?oooooooooo06;ooooo002iooooo`?o0000=_ooool01ol0003oain`
olNO/?o7Wk3o0000olNO/?l000002oooool00ol0003oooooooooo`1Qooooo`00]oooool2o`0003So
oooo00?o0000olNO/?o7Wk000_o7Wk000ol0003oain`o`00000;ooooo`03o`000?oooooooooo067o
oooo002dooooo`?o0000>Oooool00ol0003oain`olNO/003olNO/004o`000?o7Wk3oain`o`0000_o
oooo00?o0000ooooooooool0H?ooool00;;ooooo0_l00003ooooo`03o`000?oooooooooo03Kooooo
00?o0000olNO/?o7Wk001?o7Wk000ol0003oain`o`00000<ooooo`03o`000?oooooooooo05oooooo
002_ooooo`?o00001_ooool00ol0003oooooooooo`0dooooo`03o`000?o7Wk3oain`00Goain`00?o
0000olNO/?l000003?ooool00ol0003oooooooooo`1Oooooo`00[Oooool2o`0003oooooo00?o0000
olNO/?o7Wk001_o7Wk001?l0003oain`olNO/?l0000;ooooo`;o0000H?ooool00:[ooooo0ol00011
ooooo`03o`000?o7Wk3oain`00Koain`00Co0000olNO/?o7Wk3o00003Oooool00ol0003ooooooooo
o`1Mooooo`00Z?ooool3o`0004;ooooo00?o0000olNO/?o7Wk001oo7Wk001?l0003oain`olNO/?l0
000=ooooo`03o`000?oooooooooo00Sooooo00GoA4A4o`000?l0003o<S8bomgMg@1@ooooo`00YOoo
ool3o`0000?ooooo00?o0000ooooooooool0?_ooool00ol0003oain`olNO/008olNO/005o`000?o7
Wk3oain`olNO/?l000003Oooool00ol0003oooooooooo`0:ooooo`03ogMgMolb<S;ooooo04oooooo
002Sooooo`;o0000Aoooool00ol0003oain`olNO/008olNO/005o`000?o7Wk3oain`olNO/?l00000
3_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04kooooo002Pooooo`?o0000B?oo
ool00ol0003oain`olNO/009olNO/005o`000?o7Wk3oain`olNO/?l000003_ooool00ol0003ooooo
ooooo`09ooooo`03ogMgMolb<S;ooooo04oooooo002Nooooo`;o0000B_ooool00ol0003oain`olNO
/00:olNO/003o`000?o7Wk3oain`00;oain`00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`05ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0D?ooool009_ooooo1?l0001;ooooo`03o`000?o7
Wk3oain`00[oain`00?o0000olNO/?o7Wk000_o7Wk000ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0D_ooool006cooooo1?l000002?l@413oooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^8?ooool3o`0000Cooooo00?o0000ooooooooool0Aoooool2o`0000co
ain`00?o0000olNO/?o7Wk000_o7Wk000ol0003oooooooooo`0=ooooo`;o00001Oooool00ol0003o
ooooooooo`1Booooo`00K_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL07_ooool2o`00053ooooo00Co0000olNS]?o7XkCo00002oo7Wk000ol0003oain`olNO/003olNO
/003o`000?oooooooooo00_ooooo00?o0000ooooool000001Oooool4o`00057ooooo001^ooooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Kooooo`?o0000DOooool01Ol0
003oaj>dolNS]?o7XkCo000000_oain`00?o0000olNO/?o7Wk000oo7Wk000ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo05Sooooo001^ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00000Iooooo`?o0000Doooool01Ol0003oaj>dolNS]?o7XkCo000000_oain`00?o
0000olNO/?o7Wk000oo7Wk000ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05Oooooo001^
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Fooooo`?o00000_oo
ool00ol0003oooooooooo`1@ooooo`03o`000?o7XkCoaj>d00?oaj>d00?o0000olNO/?o7Wk002?o7
Wk000ol0003oain`olNO/002olNO/003o`000?o7XkCo0000013ooooo00?o0000ooooooooool0E_oo
ool006kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01Cooooo0_l0
001Gooooo`03o`000?o7XkCoaj>d00Coaj>d00?o0000olNO/?o7Wk002?o7Wk001Ol0003oain`olNO
/?o7Wk3o000000;oaj>d00?o0000ooooooooool03_ooool00ol0003oooooooooo`1Fooooo`00K_oo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04Oooool3o`0005Sooooo
00?o0000olNS]?o7Xk@01Oo7Xk@00ol0003oain`olNO/009olNO/003o`000?o7Wk3o000000?oaj>d
00?o0000ooooooooool03oooool00ol0003oooooooooo`1Eooooo`00K?ooool00omEEEGoIVIVo`00
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03oooool2o`0005[ooooo00?o0000olNS]?o7Xk@0
1_o7Xk@00ol0003oain`olNO/009olNO/003o`000?o7Wk3o000000Coaj>d00?o0000ooooooooool0
3oooool00ol0003oooooooooo`1Dooooo`00Q?ooool4o`0005_ooooo00?o0000olNS]?o7Xk@01oo7
Xk@00ol0003oain`olNO/008olNO/0;o00001Oo7Xk@00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo05Cooooo0022ooooo`;o00001?ooool00ol0003oooooooooo`1Gooooo`03o`000?o7XkCo
aj>d00Soaj>d00?o0000olNO/?o7Wk002?o7Wk000ol0003oaj>dolNS]004olNS]003o`000?oooooo
oooo00oooooo0_l0001Eooooo`00Ooooool3o`0005oooooo00?o0000olNS]?o7Xk@02Oo7Xk@00ol0
003oain`olNO/007olNO/0;o00001oo7Xk@00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
05;ooooo001mooooo`;o0000HOooool00ol0003oaj>dolNS]00;olNS]003o`000?o7Wk3oain`00Go
ain`00?o0000olNS]?l000001oo7Xk@00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05;o
oooo001jooooo`?o0000Hoooool00ol0003oaj>dolNS]00;olNS]003o`000?o7Wk3oain`00Goain`
00?o0000olNS]?l000001oo7Xk@00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo057ooooo
001hooooo`;o00000_ooool00ol0003oooooooooo`1Pooooo`03o`000?o7XkCoaj>d00coaj>d00?o
0000olNO/?o7Wk001?o7Wk001?l0003oaj>dolNS]?l00008olNS]003o`000?oooooooooo017ooooo
00?o0000ooooooooool0D?ooool007Gooooo0ol00005ooooo`03o`000?oooooooooo05kooooo00?o
0000olNS]?o7Xk@03Oo7Xk@00ol0003oain`olNO/003olNO/005o`000?o7XkCoaj>dolNS]?l00000
2?o7Xk@00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo053ooooo001booooo`?o0000J?oo
ool00ol0003oaj>dolNS]00?olNS]005o`000?o7Wk3oain`olNO/?l000001?o7Xk@00ol0003oaj>d
olNS]006olNS]003o`000?oooooooooo01;ooooo00?o0000ooooooooool0Coooool0073ooooo0_l0
001[ooooo`03o`000?o7XkCoaj>d00ooaj>d00Go0000olNO/?o7Wk3oain`o`000004olNS]003o`00
0?o7XkCoaj>d00Ooaj>d00?o0000ooooooooool04_ooool00ol0003oooooooooo`1>ooooo`00KOoo
ool4o`0006_ooooo00?o0000olJV^Ol000004?o7Xk@01?l0003oain`olNO/?l00005olNS]003o`00
0?o7XkCoaj>d00Ooaj>d00?o0000ooooooooool04Oooool2o`00053ooooo001[ooooo`;o00001?oo
ool00ol0003oooooooooo`1Wooooo`04o`000?o6Y[WoaZJio`00017oaj>d0_l00006olNS]003o`00
0?o7XkCoaj>d00Ooaj>d00?o0000ooooooooool04oooool00ol0003oooooooooo`1=ooooo`00J?oo
ool3o`0006oooooo00Go0000olJV^Oo6Y[WoaZJio`00000AolNS]003o`000?o7XkCoaj>d00Goaj>d
00?o0000olNS]?o7Xk@02?o7Xk@00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04cooooo
001Vooooo`;o0000LOooool00ol0003oaZJiolJV^@03olJV^@03o`000?o7XkCoaj>d00koaj>d00?o
0000olNS]?o7Xk@01Oo7Xk@00ol0003oaj>dolNS]008olNS]003o`000?oooooooooo01?ooooo00?o
0000ooooooooool0C?ooool006?ooooo0ol0001booooo`03o`000?o6Y[WoaZJi00CoaZJi00?o0000
olNS]?o7Xk@03Oo7Xk@00ol0003oaZJio`000006olNS]003o`000?o7XkCoaj>d00Soaj>d00?o0000
ooooooooool05?ooool00ol0003oooooooooo`1;ooooo`00>oooool01Om4A4Co0000o`000?lb<S;o
gMgM027ooooo0_l00003ooooo`03o`000?oooooooooo06kooooo00?o0000olJV^Oo6Y[T01Oo6Y[T0
0ol0003oaj>dolNS]00<olNS]004o`000?o6Y[WoaZJio`0000Koaj>d00?o0000olNS]?o7Xk@02Oo7
Xk@00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04[ooooo000nooooo`03ogMgMolb<S;o
oooo01gooooo0ol0001eooooo`03o`000?o6Y[WoaZJi00OoaZJi00?o0000olNS]?o7Xk@02_o7Xk@0
1Ol0003oaZJiolJV^Oo6Y[Wo000000Ooaj>d00?o0000olNS]?o7Xk@02?o7Xk@00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo04[ooooo000oooooo`03o`000?oooooooooo01[ooooo0_l0001h
ooooo`03o`000?o6Y[WoaZJi00OoaZJi00?o0000olNS]?o7Xk@02Oo7Xk@00ol0003oaZJiolJV^@03
olJV^@03o`000?o7XkCoaj>d00Coaj>d00?o0000olNS]?o7Xk@02?o7Xk@00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo04Wooooo000nooooo`03ogMgMolb<S;ooooo01Sooooo0ol0001ioooo
o`03o`000?o6Y[WoaZJi00WoaZJi00?o0000olNS]?o7Xk@02?o7Xk@00ol0003oaZJiolJV^@03olJV
^@03o`000?o7XkCoaj>d00Coaj>d00?o0000olNS]?o7Xk@01oo7Xk@00ol0003oaZJio`00000Eoooo
o`?o0000B_ooool003_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Gooooo`;o00000_ooool00ol0
003oooooooooo`1fooooo`03o`000?o6Y[WoaZJi00[oaZJi00?o0000olNS]?o7Xk@01oo7Xk@00ol0
003oaZJiolJV^@04olJV^@03o`000?o7XkCoaj>d00Coaj>d00?o0000olNS]?o7Xk@01_o7Xk@01?l0
003oaZJiolJV^Ol0000Gooooo`03o`000?oooooooooo04Sooooo000kooooo`03o`000?oooooooooo
01Kooooo0ol0001looooo`03o`000?o6Y[WoaZJi00_oaZJi00?o0000olNS]?o7Xk@01_o7Xk@00ol0
003oaZJiolJV^@06olJV^@03o`000?o7XkCoaj>d00?oaj>d00?o0000olNS]?o7Xk@01Oo7Xk@01Ol0
003oaZJiolJV^Oo6Y[Wo000001Sooooo00?o0000ooooooooool0Aoooool003_ooooo00?o0000oooo
ooooool04oooool3o`0007kooooo00?o0000olJV^Oo6Y[T03Oo6Y[T00ol0003oaj>dolNS]004olNS
]003o`000?o6Y[WoaZJi00OoaZJi00?o0000olNS]?o7Xk@00oo7Xk@00ol0003oaj>dolNS]004olNS
]003o`000?o6Y[WoaZJi00?oaZJi00?o0000ooooooooool05Oooool00ol0003oooooooooo`17oooo
o`00>oooool4o`00013ooooo0_l00020ooooo`03o`000?o6Y[WoaZJi00koaZJi00?o0000olNS]?o7
Xk@00oo7Xk@00ol0003oaZJiolJV^@09olJV^@03o`000?o7XkCoaj>d00;oaj>d00?o0000olNS]?o7
Xk@00oo7Xk@00ol0003oaZJiolJV^@04olJV^@03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool0A_ooool004cooooo1Ol0001oooooo`03o`000?o6Y[WoaZJi00ooaZJi00?o0000olNS]?o7Xk@0
0oo7Xk@00ol0003oaZJiolJV^@09olJV^@03o`000?o7XkCoaj>d00;oaj>d00?o0000olNS]?o7Xk@0
0_o7Xk@00ol0003oaZJiolJV^@05olJV^@03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
AOooool004[ooooo0_l00023ooooo`;o00004_o6Y[T01Ol0003oaj>dolNS]?o7XkCo000000coaZJi
00?o0000olNS]?o7Xk@00_o7Xk@01Ol0003oaj>dolNS]?o7XkCo000000WoaZJi00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`15ooooo`00Aoooool3o`0008Cooooo00Co0000olFZ__o5Z[ko
00004Oo6Y[T01?l0003oaj>dolNS]?l0000>olJV^@05o`000?o7XkCoaj>dolNS]?l000000oo7Xk@0
0ol0003oaZJiolJV^@07olJV^@03o`000?oooooooooo01Oooooo00?o0000ooooooooool0A?ooool0
04Gooooo0_l00026ooooo`05o`000?o5Z[koaJZnolFZ__l000004Oo6Y[T00ol0003oaj>do`00000?
olJV^@05o`000?o7XkCoaj>dolNS]?l000000_o7Xk@00ol0003oaZJiolJV^@09olJV^@03o`000?oo
oooooooo01Kooooo0_l00015ooooo`00@_ooool4o`0008Kooooo00?o0000olFZ__o5Z[h00_o5Z[h0
0ol0003oaZJiolJV^@0@olJV^@03o`000?o6Y[WoaZJi00koaZJi00Oo0000olNS]?o7XkCoaj>do`00
0?o7XkCo000000coaZJi00?o0000ooooooooool05oooool00ol0003oooooooooo`08ooooo`Co0000
00So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kRoooooo0010ooooo`;o00001?ooool00ol0
003oooooooooo`22ooooo`03o`000?o5Z[koaJZn00CoaJZn00?o0000olJV^Oo6Y[T03_o6Y[T2o`00
017oaZJi00?o0000olNS]?o7Xk@00_l0000=olJV^@03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0;oooool0
03gooooo0ol0002:ooooo`03o`000?o5Z[koaJZn00GoaJZn00?o0000olJV^Oo6Y[T03Oo6Y[T01?l0
003oaJZnolFZ__l0000@olJV^@04o`000?o7XkCoaj>do`0000ooaZJi00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400_ooooo`00>oooool2o`0008cooooo00?o0000olFZ__o5Z[h01oo5Z[h00ol0003oaZJiolJV
^@0;olJV^@05o`000?o5Z[koaJZnolFZ__l000004?o6Y[T01?l0003oaj>do`000?l0000?olJV^@03
o`000?oooooooooo01Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool00000;oooool003Sooooo0ol0002=ooooo`03o`000?o5Z[koaJZn00So
aJZn00?o0000olJV^Oo6Y[T02_o6Y[T00ol0003oaJZnolFZ_P02olFZ_P03o`000?o6Y[WoaZJi00oo
aZJi00?o0000olJV^Ol000003oo6Y[T00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002oooooo000fooooo`;o
00000oooool00ol0003oooooooooo`29ooooo`03o`000?o5Z[koaJZn00[oaJZn00?o0000olJV^Oo6
Y[T02?o6Y[T00ol0003oaJZnolFZ_P04olFZ_P03o`000?o6Y[WoaZJi00koaZJi00?o0000olJV^Ol0
00004?o6Y[T00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@02oooooo000cooooo`?o0000T?ooool00ol0003o
aJZnolFZ_P0;olFZ_P03o`000?o6Y[WoaZJi00OoaZJi00?o0000olFZ__o5Z[h01Oo5Z[h00ol0003o
aZJiolJV^@0=olJV^@05o`000?o5Z[ko0000olJV^Ol000003oo6Y[T00ol0003oooooooooo`0Ioooo
o`;o00001oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0;oooool0
037ooooo0_l0002Booooo`03o`000?o5Z[koaJZn00coaJZn00?o0000olJV^Oo6Y[T01_o6Y[T00ol0
003oaJZnolFZ_P07olFZ_P03o`000?o6Y[WoaZJi00_oaZJi00Ko0000olFZ__o5Z[ko0000olJV^Ol0
000?olJV^@03o`000?oooooooooo01Sooooo00?o0000ooooool000001Oooool00omEEEGoIVIVo`00
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0;oooool002kooooo0ol0002Cooooo`03o`000?o5
Z[koaJZn00koaJZn00?o0000olJV^Oo6Y[T01?o6Y[T00ol0003oaJZnolFZ_P08olFZ_P03o`000?o6
Y[WoaZJi00[oaZJi00Oo0000olFZ__o5Z[koaJZno`000?o6Y[Wo0000013oaZJi00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0mooooo`00:oooool3o`0000;ooooo00?o0000ooooooooool0
Soooool2o`00017oaJZn00?o0000olJV^Oo6Y[T00oo6Y[T00ol0003oaJZnolFZ_P0:olFZ_P03o`00
0?o6Y[WoaZJi00SoaZJi00?o0000olFZ__o5Z[h00oo5Z[h2o`0000ooaZJi0_l0000Looooo`03o`00
0?oooooooooo03gooooo000Yooooo`;o0000U_ooool00ol0003oa:o5o`00000BolFZ_P05o`000?o6
Y[WoaZJiolJV^Ol000003Oo5Z[h00ol0003oaZJiolJV^@07olJV^@03o`000?o5Z[koaJZn00CoaJZn
0_l0000>olJV^@04o`000?o5Z[koaJZno`0001cooooo00?o0000ooooooooool0??ooool002Kooooo
0ol0002Gooooo`05o`000?o4[lGoa:o5olB_aOl000004Oo5Z[h01?l0003oaZJiolJV^Ol0000>olFZ
_P03o`000?o6Y[WoaZJi00KoaZJi00?o0000olFZ__o5Z[h01_o5Z[h00ol0003oaZJiolJV^@0;olJV
^@05o`000?o5Z[koaJZnolFZ__l000007Oooool00ol0003oooooooooo`0kooooo`009?ooool2o`00
09Wooooo00?o0000olB_aOo4[lD00_o4[lD00ol0003oaJZnolFZ_P0?olFZ_P03o`000?o6Y[Wo0000
013oaJZn00?o0000olJV^Oo6Y[T01?o6Y[T00ol0003oaJZnolFZ_P07olFZ_P03o`000?o6Y[WoaZJi
00[oaZJi00?o0000olFZ__o5Z[h00_o5Z[h00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
03_ooooo000Qooooo`?o00000_ooool00ol0003oooooooooo`2Eooooo`03o`000?o4[lGoa:o500Co
a:o500?o0000olFZ__o5Z[h03_o5Z[h2o`00017oaJZn00?o0000olJV^Oo6Y[T00oo6Y[T00ol0003o
aJZnolFZ_P07olFZ_P?o00002_o6Y[T00ol0003oaJZnolFZ_P04olFZ_P03o`000?oooooooooo01_o
oooo00?o0000ooooooooool0>_ooool001oooooo0_l0002Looooo`03o`000?o4[lGoa:o500Goa:o5
00?o0000olFZ__o5Z[h03Oo5Z[h00ol0003oa:o5o`00000BolFZ_P05o`000?o6Y[WoaZJiolJV^Ol0
00001oo5Z[h3o`000003olFZ__l0003o000000WoaZJi00?o0000olFZ__o5Z[h01Oo5Z[h00ol0003o
ooooooooo`0Jooooo`?o0000>oooool001cooooo0ol0002Mooooo`03o`000?o4[lGoa:o500Koa:o5
00?o0000olFZ__o5Z[h03?o5Z[h01Ol0003oa:o5olB_aOo4[lGo0000017oaJZn00Co0000olJV^Oo6
Y[Wo00001Oo5Z[h3o`0000GoaJZn00?o0000olJV^Oo6Y[T01_o6Y[T00ol0003oaJZnolFZ_P06olFZ
_P03o`000?oooooooooo01cooooo00?o0000ooooooooool0>Oooool001_ooooo0_l0002Nooooo`03
o`000?o4[lGoa:o500Soa:o500?o0000olFZ__o5Z[h02_o5Z[h00ol0003oa:o5olB_a@02olB_a@03
o`000?o5Z[koaJZn00ooaJZn00?o0000olJV^Ol000000oo5Z[h3o`0000WoaJZn00?o0000olJV^Oo6
Y[T01?o6Y[T00ol0003oaJZnolFZ_P08olFZ_P03o`000?oooooooooo01cooooo00?o0000oooooooo
ool0>?ooool001_ooooo00?o0000ooooool00000W?ooool00ol0003oa:o5olB_a@09olB_a@03o`00
0?o5Z[koaJZn00WoaJZn00?o0000olB_aOo4[lD01?o4[lD00ol0003oaJZnolFZ_P0>olFZ_P;o0000
00CoaJZno`000?l0003o00003?o5Z[h2o`0000CoaZJi00?o0000olFZ__o5Z[h02Oo5Z[h00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo03Sooooo000Jooooo`;o00000_ooool00ol0003ooooo
ooooo`2Hooooo`03o`000?o4[lGoa:o500_oa:o500?o0000olFZ__o5Z[h01oo5Z[h00ol0003oa:o5
olB_a@05olB_a@03o`000?o5Z[koaJZn00goaJZn1?l0000@olFZ_P05o`000?o6Y[WoaZJiolJV^Ol0
00003?o5Z[h00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo03Oooooo000Jooooo`?o0000
0_ooool00ol0003oooooooooo`2Fooooo`03o`000?o4[lGoa:o500coa:o500?o0000olFZ__o5Z[h0
1_o5Z[h00ol0003oa:o5olB_a@06olB_a@03o`000?o5Z[koaJZn00_oaJZn0ol00002olB_a@03o`00
0?o5Z[koaJZn00koaJZn0_l000000oo6Y[Wo0000olFZ_P0=olFZ_P03o`000?oooooooooo01gooooo
00?o0000ooooooooool0=_ooool001[ooooo00?o0000oa/^Z?l000000oooool00ol0003ooooooooo
o`2Dooooo`03o`000?o4[lGoa:o500koa:o500?o0000olFZ__o5Z[h01?o5Z[h00ol0003oa:o5olB_
a@08olB_a@03o`000?o5Z[koaJZn00OoaJZn1?l00004olB_a@03o`000?o5Z[koaJZn00koaJZn00?o
0000olJV^Ol000003oo5Z[h00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo03Kooooo0008
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo0_l000000olK;ZSo
0000ooooo`02ooooo`03o`000?oooooooooo00Oooooo0_l00028ooooo`;o00004Oo4[lD00ol0003o
aJZnolFZ_P03olFZ_P03o`000?o4[lGoa:o500Woa:o500?o0000olFZ__o5Z[h01Oo5Z[h2o`0000;o
aJZn00?o0000olB_aOo4[lD00oo4[lD00ol0003oaJZnolFZ_P0>olFZ_P?o00003oo5Z[h00ol0003o
ooooooooo`0Nooooo`;o0000=_ooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo0_l00002oa/^Z005o`000?ooooooooooooooool000001oooool00ol0
003oZSH[o`000027ooooo`03o`000?o2]<go0000017oa:o500?o0000olFZ__o5Z[h00_o5Z[h00ol0
003oa:o5olB_a@0;olB_a@04o`000?o5Z[koaJZnolFZ_P?o00000oo5Z[h00ol0003oa:o5olB_a@05
olB_a@03o`000?o5Z[koaJZn00coaJZn00Go0000olB_aOl0003oaJZno`00000?olFZ_P03o`000?oo
oooooooo01cooooo00?o0000ooooool00000=_ooool000Go00001Oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41001_ooool2o`0000?o6bjX00Go0000oooooooooooooooo
o`000004ooooo`;o00000onZ=R/00ol0003oooooooooo`23ooooo`05o`000?o2]<go`[C=ol:dcOl0
00004Oo4[lD01?l0003oaJZnolFZ__l0000>olB_a@Co00001Oo5Z[h00ol0003oa:o5olB_a@06olB_
a@03o`000?o5Z[koaJZn00_oaJZn00Oo0000olB_aOo4[lGoa:o5o`000?o5Z[ko000000koaJZn00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0dooooo`002_ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000001Oooool4o`0000?o6bjX00Go0000oooooooooooooooo
o`000002ooooo`03o`000?nZ=R_oZSH[00CoZSH[00?o0000ooooooooool03?ooool2o`0007;ooooo
0_l00004ol:dc@03o`000?o4[lGoa:o500ooa:o500?o0000olFZ__l000003Oo4[lD4o`0000KoaJZn
00?o0000olB_aOo4[lD01oo4[lD00ol0003oaJZnolFZ_P0:olFZ_P03o`000?o4[lGoa:o500;oa:o5
00Co0000olFZ__o5Z[ko00003Oo5Z[h00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03?o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooo000000Co6bjX00Co0000oooooooooooooooo0_l00008ojXf:`03o`000?oooooooooo
00[ooooo00?o0000ojXf:ol00000LOooool00ol0003o`[C=ol:dc@05ol:dc@03o`000?o4[lGoa:o5
00koa:o50_l0000;olB_a@?o00000oo4[lD00ol0003oaJZnolFZ_P03olFZ_P03o`000?o4[lGoa:o5
00Woa:o500?o0000olFZ__o5Z[h02?o5Z[h00ol0003oa:o5olB_a@04olB_a@03o`000?o5Z[ko0000
00goaJZn0_l0000Qooooo`03o`000?oooooooooo03;ooooo000:ooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@4005ooooo`04o`000?ooooooooooo`0000Go6bjX00?o0000
ooooool000002onZ=R/00ol0003oooooooooo`08ooooo`05o`000?nZ=R_oZSH[ojXf:ol00000Kooo
ool00ol0003o`[C=ol:dc@06ol:dc@03o`000?o4[lGoa:o500goa:o500?o0000ol:dcOl000002?o4
[lD3o`0000Koa:o500?o0000olFZ__o5Z[h00_o5Z[h00ol0003oa:o5olB_a@0:olB_a@03o`000?o5
Z[koaJZn00OoaJZn00?o0000olB_aOo4[lD01Oo4[lD01?l0003oaJZnolFZ__l0000;olFZ_P03o`00
0?o4[lGo0000027ooooo00?o0000ooooooooool0<_ooool000[ooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00Go0000ooooooooooooooooo`000005oa/^Z003
o`000?nZ=R_oZSH[00_oZSH[00?o0000ooooooooool01Oooool2o`0000GoZSH[00?o0000oooooooo
ool0Joooool00ol0003o`[C=ol:dc@08ol:dc@03o`000?o4[lGoa:o500_oa:o500Go0000ol:dcOo2
]<go`[C=o`000004olB_a@?o00002_o4[lD01?l0003oaJZnolFZ__l0000>olB_a@03o`000?o5Z[ko
aJZn00GoaJZn00?o0000olB_aOo4[lD01oo4[lD01?l0003oaJZnolFZ__l00009olFZ_P05o`000?o4
[lGoa:o5olB_aOl000008Oooool00ol0003oooooooooo`0aooooo`002?ooool00omEEEGoIVIVo`00
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2o`0000;ooooo00?o0000oa/^Z?lK;ZP0
0olK;ZP00ol0003oZSH[ojXf:`0<ojXf:`03o`000?oooooooooo00?ooooo00?o0000ojXf:onZ=R/0
1_nZ=R/00ol0003oooooooooo`0;ooooo`;o0000Foooool2o`0000_o`[C=00?o0000olB_aOo4[lD0
2Oo4[lD2o`0000Co`[C=00?o0000olB_aOl000000_l0000=olB_a@03o`000?o5Z[ko000000ooa:o5
00?o0000olFZ__o5Z[h01?o5Z[h00ol0003oa:o5olB_a@08olB_a@05o`000?o5Z[koaJZnolFZ__l0
00001oo5Z[h00ol0003oa:o5olB_a@02olB_a@03o`000?oooooooooo023ooooo00?o0000oooooooo
ool0<?ooool001Wooooo00Go0000ooooooooooooooooo`000006oa/^Z003o`000?nZ=R_oZSH[00co
ZSH[00Go0000ooooooooooooooooo`00000:ojXf:`03o`000?oooooooooo00Wooooo00Co0000ojXg
:onZ=b_o0000FOooool00ol0003o`[C=ol:dc@0<ol:dc@03o`000?o4[lGoa:o500Ooa:o500?o0000
ol:dcOo2]<d01?o2]<d2o`00013oa:o50_l0000@olB_a@03o`000?o5Z[koaJZn00?oaJZn00?o0000
olB_aOo4[lD02_o4[lD01?l0003oaJZnolFZ__l00006olFZ_P03o`000?o4[lGoa:o500Coa:o500?o
0000ooooooooool07_ooool2o`0003;ooooo000Iooooo`05o`000?ooooooooooooooool000001olK
;ZP00ol0003oZSH[ojXf:`0<ojXf:`03o`000?oooooo000000coZSH[00?o0000ooooooooool01_oo
ool2o`0000CoZSL[00?o0000ooooooooool0EOooool00ol0003o`[C=ol:dc@0=ol:dc@03o`000?o4
[lGoa:o500Koa:o500?o0000ol:dcOo2]<d00_o2]<d3o`000003ol:dcOl0003oa:o500koa:o500?o
0000ol:dcOl000004Oo4[lD01Ol0003oaJZnolFZ__o5Z[ko000000goa:o500Go0000olFZ__o5Z[ko
aJZno`000004olFZ_P03o`000?o4[lGoa:o500Goa:o500?o0000ooooooooool08?ooool00ol0003o
ooooooooo`0_ooooo`006Oooool00ol0003oooooooooo`02ooooo`03o`000?lK;ZSo6bjX00Co6bjX
0_l0000=ojXf:`?o00003OnZ=R/00ol0003oooooooooo`04ooooo`03o`000?nZ=b_oZSL[00GoZSL[
00?o0000ooooooooool02_ooool2o`0004Kooooo0_l0000Aol:dc@03o`000?o4[lGoa:o500Coa:o5
00?o0000ol:dcOo2]<d00ol00005ol:dc@03o`000?o4[lGoa:o500_oa:o500Go0000ol:dcOo2]<go
`[C=o`00000@olB_a@04o`000?o5Z[koaJZno`0000koa:o500?o0000olFZ__o5Z[h00_o5Z[h01?l0
003oaJZnolFZ__l00009olB_a@03o`000?oooooooooo023ooooo00?o0000ooooooooool0;_ooool0
01Sooooo00?o0000ooooooooool00oooool00ol0003o6bjXoa/^Z004oa/^Z003o`000?o4Vjko0000
00[oZSH[0_l00003oj8W6003o`000?nZ=R_oZSH[00_oZSH[00Co0000oooooooooooooooo0_l00009
ojXg:`03o`000?oooooooooo00Sooooo00Co0000ojXg;?nZ=bco0000A?ooool00ol0003o_[_Go`00
000Aol:dc@03o`000?o4[lGoa:o500;oa:o51Ol00008ol:dc@03o`000?o4[lGoa:o500Woa:o50_l0
0004ol:dc@03o`000?o4[lGoa:o500koa:o500?o0000olFZ__l000004?o4[lD00ol0003oaJZnolFZ
_P02olFZ_P;o00002_o4[lD00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02kooooo000H
ooooo`;o00001?ooool00ol0003o6bjXoa/^Z003oa/^Z005o`000?o4Vjkoa9^^olBK[_l000001onZ
=R/2o`0000KoXRLH00?o0000ojXf:onZ=R/02onZ=R/00ol0003oooooo`00000<ojXg:`03o`000?oo
oooooooo00Kooooo00?o0000ojXg;?nZ=b`00_nZ=b`00ol0003oooooooooo`0oooooo`;o00000onn
^mL00ol0003o`[C=ol:dc@0?ol:dc@03o`000?o4[lGoa:o500?o00003?o2]<d00ol0003oa:o5olB_
a@07olB_a@03o`000?o2]<go`[C=00Go`[C=00?o0000olB_aOo4[lD03Oo4[lD2o`00017oa:o500?o
0000olFZ__o5Z[h00_o5Z[h00ol0003oa:o5olB_a@0:olB_a@03o`000?oooooooooo023ooooo00?o
0000ooooooooool0;Oooool001Sooooo00?o0000ooooooooool01?ooool01Ol0003o6bjXoa/^Z?lK
;ZSo000000Goa9^^00?o0000ojXf:onZ=R/00_nZ=R/2o`0000WoXRLH00?o0000ojXf:onZ=R/02_nZ
=R/3o`0000goZSL[00?o0000ooooooooool00oooool2o`0000KoZSL/00?o0000ooooooooool02ooo
ool2o`00033ooooo00?o0000okjkeonn^mL00onn^mL00ol0003o`[C=ol:dc@0?ol:dc@?o00003oo2
]<d00ol0003oa:o5olB_a@06olB_a@03o`000?o2]<go`[C=00Ko`[C=00?o0000olB_aOo4[lD03?o4
[lD00ol0003o`[C=o`00000BolB_a@06o`000?o5Z[koaJZno`000?o4[lGo00002oo4[lD00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo02cooooo000Hooooo`03o`000?oooooooooo00Cooooo
00Co0000oa/^Z?lK;ZSo00001oo4Vjh01?l0003oZSH[o`000?l0000<oj8W6003o`000?nZ=R_oZSH[
00OoZSH[0_l00003oj8W6003o`000?nZ=b_oZSL[00_oZSL[00Go0000ooooooooooooooooo`000009
ojXg;003o`000?oooooooooo00Wooooo00?o0000ojXg;?l00000;_ooool2o`0000Oo_[_G00?o0000
ol:dcOo2]<d02oo2]<d5o`00017o`[C=00?o0000olB_aOo4[lD01?o4[lD00ol0003o`[C=ol:dc@07
ol:dc@03o`000?o4[lGoa:o500_oa:o500Go0000ol:dcOo2]<go`[C=o`00000AolB_a@03o`000?o5
Z[ko000000?oa:o500?o0000olB_aOo4[lD02?o4[lD00ol0003oooooooooo`0Qooooo`;o0000;Ooo
ool001Sooooo00?o0000ooooooooool01?ooool01?l0003o6bjXoa/^Z?l00008olBK[P;o00003_nR
9aP00ol0003oZSH[ojXf:`04ojXf:`;o00001_nR9aP00ol0003oZSL[ojXg:`0;ojXg:`03o`000?oo
oooo000000_oZSL/00?o0000ooooooooool01oooool01Ol0003oZSL/ojXg;?nZ=bco000002cooooo
00?o0000okjkeonn^mL01onn^mL00ol0003o`[C=ol:dc@08ol:dc@?o00000_o2]<d00ol0003o_[_G
o`00000Aol:dc@03o`000?o4[lGoa:o500;oa:o50_l0000;ol:dc@03o`000?o4[lGoa:o500Soa:o5
0_l00004ol:dc@03o`000?o4[lGoa:o500ooa:o50_l00004olB_a@03o`000?o4[lGoa:o500Woa:o5
00?o0000ooooooooool08?ooool2o`0000Wooooo1?l000001Ol@413oooooooooooooooooA4A400;o
000000?o<S8bomgMgOooool05_ooool001Sooooo00?o0000ooooooooool01Oooool2o`0000_oa9^^
00?o0000oj8W6?nR9aP03?nR9aP00ol0003oZSH[ojXf:`02ojXf:`03o`000?nR9aSoXRLH00OoXRLH
00?o0000ojXg:onZ=b/02_nZ=b/3o`0000coZSL/00?o0000ooooooooool01Oooool00ol0003oZSL/
ojXg;003ojXg;003o`000?oooooooooo00_ooooo0_l0000Kooooo`03o`000?nn^mOo_[_G00Wo_[_G
00?o0000ol:dcOo2]<d01?o2]<d3o`0000?o`[C=0_l00003okjke`03o`000?o2]<go`[C=00oo`[C=
00Co0000olB_aOo4[lGo00003Oo2]<d00ol0003oa:o5olB_a@07olB_a@03o`000?o2]<go`[C=00Go
`[C=00?o0000olB_aOo4[lD03Oo4[lD00ol0003o`[C=o`000005olB_a@03o`000?o4[lGoa:o500So
a:o500?o0000ooooooooool08_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Ko
oooo00?oMgMgoc8b<_ooool05_ooool001Oooooo00?o0000ooooooooool01_ooool00ol0003oa9^^
olBK[P0;olBK[P;o00003OnR9aP01?l0003oZSH[o`000?l0000;oj8W6003o`000?nZ=b_oZSL[00Oo
ZSL[0_l00003oj8X6@03o`000?nZ=bcoZSL/00[oZSL/00?o0000ooooooooool00oooool00ol0003o
ZSL/ojXg;005ojXg;003o`000?oooooooooo00Wooooo00Co0000ojXg;?nZ=bco00006?ooool2o`00
00go_[_G00Co0000ol:dcOo2]<go`[C=0_l00005ol:dc@03o`000?nn^mOo_[_G00?o_[_G00?o0000
ol:dcOo2]<d03oo2]<d00ol0003oa:o5o`00000?ol:dc@03o`000?o4[lGoa:o500Goa:o500?o0000
ol:dcOo2]<d01_o2]<d00ol0003oa:o5olB_a@0<olB_a@05o`000?o2]<go`[C=ol:dcOl000001Oo4
[lD00ol0003oa:o5olB_a@08olB_a@03o`000?oooooooooo027ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Gooooo000Gooooo`03o`000?oooooo
oooo00Kooooo00?o0000olBK[_o4Vjh03Oo4Vjh00ol0003oXRLHoj8W600:oj8W60?o00003OnR9aP0
0ol0003oZSL[ojXg:`04ojXg:`;o00001_nR:1T00ol0003oZSL/ojXg;00:ojXg;005o`000?oooooo
ooooooooool000002OnZ=b`00ol0003oooooooooo`07ooooo`03o`000?nZ=bcoZSL/00;oZSL/00?o
0000ooooooooool05?ooool00ol0003o_[_Gokjke`0=okjke`Co00001Oo2]<d2o`0000Oo_[_G00?o
0000ol:dcOo2]<d03_o2]<d2o`00013o`[C=00?o0000olB_aOo4[lD01?o4[lD00ol0003o`[C=ol:d
c@08ol:dc@03o`000?o4[lGoa:o500Woa:o50_l00004ol:dc@03o`000?o4[lGoa:o500Coa:o500?o
0000olB_aOo4[lD01oo4[lD00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01_ooool00omgMgOo<S8booooo`0Fooooo`005oooool00ol0003oooooooooo`06
ooooo`03o`000?o4Vjkoa9^^00koa9^^00?o0000oj8W6?nR9aP01onR9aP2o`0000?oUQ8000?o0000
oj8W6?nR9aP02onR9aP00ol0003oZSL[ojXg:`02ojXg:`03o`000?nR:1WoXRPI00OoXRPI00?o0000
ojXg;?nZ=b`02_nZ=b`00ol0003oooooo`00000;ojXg;003o`000?oooooooooo00Gooooo00?o0000
ojXg;?nZ=b`01?nZ=b`00ol0003oooooooooo`0Aooooo`;o00003_nn^mL4o`0000Ko`[C=00?o0000
okjkeonn^mL01onn^mL00ol0003o`[C=ol:dc@0=ol:dc@03o`000?nn^mOo0000017o`[C=00Co0000
olB_aOo4[lGoa:o50_l0000<ol:dc@03o`000?o4[lGoa:o500Ooa:o500?o0000ol:dcOo2]<d01Oo2
]<d00ol0003oa:o5olB_a@03olB_a@03o`000?o4[lGoa:o500Ooa:o50_l0000Sooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Oooooo
000Gooooo`03o`000?oooooooooo00Oooooo00?o0000olBK[_o4Vjh03_o4Vjh2o`0000CoXRLH0ol0
0006oiHB00;o00003?nR9aP01?l0003oZSL[o`000?l0000;oj8X6@03o`000?nZ=bcoZSL/00WoZSL/
0ol0000<ojXg;003o`000?oooooooooo00?ooooo00?o0000ojXg;?nZ=b`01_nZ=b`00ol0003ooooo
ooooo`09ooooo`?o00000_ooool2o`000003okS3hol0003o_[_G00[o_[_G0ol00003okjke`03o`00
0?o2]<go`[C=00?o`[C=00?o0000okjkeonn^mL02Onn^mL00ol0003o`[C=ol:dc@0:ol:dc@;o0000
0onn^mL00ol0003o`[C=ol:dc@0>ol:dc@04o`000?o4[lGoa:o5o`0000ko`[C=00?o0000olB_aOo4
[lD01_o4[lD00ol0003o`[C=ol:dc@06ol:dc@03o`000?o4[lGoa:o500Coa:o500?o0000olB_aOo4
[lD01Oo4[lD00ol0003o`[C=o`00000Tooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Iooooo`005oooool3o`0000Oooooo00?o0000olBK[_o4Vjh0
3_o4Vjh01?l0003oa9^^o`000?nR9aP2o`0000_oUQ8000?o0000oj8W6?nR9aP02OnR9aP3o`0000go
XRPI00?o0000ojXg;?nZ=b`01onZ=b`01Ol0003oXRPIoj8X6OnR:1Wo000000coZSL/00Go0000oooo
ooooooooooooo`00000:ojXg;003o`000?oooooooooo00Oooooo00Co0000ojXg;OnZ=bgoZSL]0_l0
0004okS3h`03o`000?nn^mOo_[_G00Go_[_G0ol00007okjke`03o`000?o2]<go`[C=00;o00003Onn
^mL00ol0003o`[C=ol:dc@08ol:dc@03o`000?nn^mOo_[_G00?o_[_G00?o0000ol:dcOo2]<d03_o2
]<d00ol0003oa:o5o`00000@ol:dc@03o`000?o4[lGoa:o500Coa:o500?o0000ol:dcOo2]<d01oo2
]<d00ol0003oa:o5olB_a@05olB_a@03o`000?o4[lGoa:o500?oa:o500Go0000ol:dcOo2]<go`[C=
o`00000Sooooo`;o00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Wooooo
000Fooooo`;o00002Oooool00ol0003oa9^^olBK[P0>olBK[P03o`000?o4Vjkoa9^^00;o00003OnF
4P000ol0003oXRLHoj8W6006oj8W60;o00000onF4P000ol0003oXRPIoj8X6@0;oj8X6@03o`000?nZ
=bcoZSL/00CoZSL/0_l00005oj8X6@03o`000?nZ=bcoZSL/00[oZSL/00?o0000ooooool000003?nZ
=b`00ol0003oooooooooo`05ooooo`03o`000?nZ=bgoZSL]00;o00001onh`n<01?l0003o_[_Gokjk
eonn^mL3o`0000[o_[_G00?o0000ol:dcOl000003onn^mL00ol0003o`[C=ol:dc@06ol:dc@;o0000
1onn^mL00ol0003o`[C=ol:dc@0=ol:dc@;o00004Oo2]<d00ol0003oa:o5olB_a@02olB_a@;o0000
2oo2]<d00ol0003oa:o5olB_a@05olB_a@03o`000?o4[lGoa:o500;o00001?o2]<d00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooo000000Gooooo00?oEEEEofIVI_l000001Oooool4o`0001Sooooo
000<ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`09ooooo`03o`00
0?o4Vjkoa9^^00coa9^^0_l00004olBK[P;o00003?nF4P02o`0000CoXRLH0_l00006oiHB0003o`00
0?nR:1WoXRPI00_oXRPI00Co0000ojXg;?nZ=bcoZSL/0_l00008oj8X6@03o`000?nZ=bcoZSL/00Wo
ZSL/0ol0000=ojXg;003o`000?oooooooooo00?ooooo00Co0000ojXg;OnZ=bgo00002Onh`n<4o`00
00go_[_G0_l0000Aokjke`03o`000?o2]<go`[C=00Co`[C=00?o0000okjkeonn^mL01onn^mL00ol0
003o`[C=ol:dc@0<ol:dc@03o`000?nn^mOo000001;o`[C=00Co0000olB_aOo4[lGo00003Oo2]<d0
0ol0003oa:o5olB_a@05olB_a@03o`000?o4[lGo000000Oo`[C=00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`0Vooooo`003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
00Wooooo00?o0000olBK[_o4Vjh02oo4Vjh01?l0003oa9faolBM/Ol00005olBK[P03o`000?nF4P3o
UQ8000_oUQ8000Co0000oj8W6?l0003o00002OnF4P000ol0003oXRPIoj8X6@0;oj8X6@03o`000?nZ
=bco000000_oXRPI0_l00008ojXg;005o`000?nS:1[oXbPJoj<X6_l000003OnZ=b`01_l0003ooooo
oooooooooooo0000ojXg;@;o00002?nh`n<4o`0000go_[_G0_l000000onh`n?o0000okjke`0@okjk
e`03o`000?o2]<go`[C=00?o`[C=00?o0000okjkeonn^mL02Onn^mL00ol0003o`[C=ol:dc@09ol:d
c@;o00000onn^mL00ol0003o`[C=ol:dc@0?ol:dc@03o`000?o4[lGo000000oo`[C=00?o0000olB_
aOo4[lD01Oo4[lD00ol0003o`[C=ol:dc@06ol:dc@03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool09Oooool000?ooooo1_l00007ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02Oooool00ol0003oa9^^olBK[P0:olBK[P05o`000?o4WK7oa9faolBM/Ol000001_o4Vjh2o`00
00_oUQ800ol0000;oiHB00;o00002onR:1T3o`0000goXRPI00?o0000ojXg;?nZ=b`00onZ=b`2o`00
00GoXbPJ00?o0000ojXg;?nZ=b`02onZ=b`00ol0003oooooo`000002o`0000So^<?S0_l00004okS3
h`03o`000?nn^mOo_[_G00So_[_G0_l00004okS3h`03o`000?nn^mOo_[_G00oo_[_G00?o0000ol:d
cOo2]<d00_l0000<okjke`03o`000?o2]<go`[C=00Oo`[C=0_l00005okjke`03o`000?o2]<go`[C=
00oo`[C=0_l0000@ol:dc@03o`000?o4[lGoa:o500Coa:o500?o0000ol:dcOl000001oo2]<d00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo02Gooooo000?ooooo`03ogMgMolb<S;ooooo00Co
oooo0_l0000;ooooo`03o`000?o4Vjkoa9^^00Woa9^^00Go0000olBM/Oo4WK7oa9fao`000008olBK
[P;o00001_nF4P03o`0000?oP@000_l0000;oiHB0003o`000?nR:1WoXRPI00KoXRPI0_l00003oiHC
0003o`000?nR:1WoXRPI00_oXRPI00Go0000ojXg;?nZ=bcoZSL/o`000008oj<X6P03o`000?nZ=bco
ZSL/00[oZSL/0ol00007okS3h`?o00001_nh`n<00ol0003o_[_Gokjke`06okjke`;o00001onh`n<0
0ol0003o_[_Gokjke`0>okjke`03o`000?o2]<go000000oo_[_G00?o0000ol:dcOo2]<d01Oo2]<d0
0ol0003o_[_Gokjke`06okjke`03o`000?o2]<go`[C=00go`[C=00?o0000okjkeol000004Oo2]<d0
1?l0003oa:o5olB_aOo4[lD2o`0000;o`[C=00?o0000ol:dcOo2]<d01_o2]<d00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo02Cooooo000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?o4Vjkoa9^^00Soa9^^00?o0000olBM/Oo4WK400oo4
WK400ol0003oa9^^olBK[P07olBK[P03o`000?nF4P3oUQ8000?o00002?n100000ol0003oUQ80oiHB
0009oiHB0003o`000?nR:1WoXRPI00;oXRPI0ol00006oiHC00;o00003?nR:1T00ol0003oZSL/o`00
000:oj<X6P;o00002?nZ=b`3o`000003ojc;l?l0003o^<?S00?o^<?S0ol0000:okS3h`03o`000?nn
^mOo_[_G00Co_[_G00?o0000okS3honh`n<01onh`n<00ol0003o_[_Gokjke`0>okjke`;o00004?nn
^mL00ol0003o`[C=ol:dc@03ol:dc@;o00002_nn^mL00ol0003o`[C=ol:dc@0:ol:dc@;o00000onn
^mL00ol0003o`[C=ol:dc@0>ol:dc@04o`000?o4[lGoa:o5o`0000Go`[C=00?o0000ol:dcOo2]<d0
1Oo2]<d00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02?ooooo000<ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003oa9^^olBK[P07olBK[P03o`000?o4
WK7oa9fa00Coa9fa00?o0000olBK[_o4Vjh02?o4Vjh2o`0000coP@000_l0000:oiHB0004o`000?nR
:1Wo0000o`0000_oUQ<000?o0000oj8X6OnR:1T02OnR:1T3o`0000coXbPJ00?o0000ojXg;?nZ=b`0
0onZ=b`2o`0000Go[<_`1?l0000=okS3h`03o`000?nn^mOo_[_G00;o_[_G0_l0000;okS3h`03o`00
0?nn^mOo_[_G00_o_[_G0_l000000onh`n?o0000okjke`0@okjke`03o`000?o2]<go`[C=00;o0000
3?nn^mL00ol0003o`[C=ol:dc@09ol:dc@03o`000?nn^mOo_[_G00?o_[_G00?o0000ol:dcOo2]<d0
3_o2]<d00ol0003oa:o5o`000007ol:dc@03o`000?o2]<go`[C=00Go`[C=00?o0000ooooooooool0
8_ooool3o`0002Cooooo000<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02ooo
ool00ol0003oa9^^olBK[P06olBK[P03o`000?o4WK7oa9fa00Goa9fa00?o0000olBK[_o4Vjh02_o4
Vjh3o`0000_oP@000_l00007oiHB00Co00003OnF4`000ol0003oXRPIoj8X6@06oj8X6@;o00000onF
4`000ol0003oXbPJoj<X6P0:oj<X6P03o`000?nZ=bcoZSL/00;o00001On/bo04o`00013o^<?S00Co
0000okjkeol0003o00003_nh`n<00ol0003o_[_Gokjke`08okjke`;o00001?nh`n<00ol0003o_[_G
okjke`0>okjke`03o`000?o2]<go000000oo_[_G00?o0000ol:dcOo2]<d01_o2]<d2o`0000Oo_[_G
00?o0000ol:dcOo2]<d03Oo2]<d2o`0000Wo`[C=00?o0000ol:dcOo2]<d01?o2]<d00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo02;ooooo000<ooooo`Co00001Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?o4Vjkoa9^^00Goa9^^00?o0000olBM/Oo4WK401_o4WK400ol0003oa9^^olBK
[P08olBK[P04o`000?o4WK7oa9faolBM/@;o00002on100000ol0003oUQ80oiHB0004o`0000CoPP00
0_l0000<oiHC00;o00001?nR:1T2o`0000KoUQ<00_l0000:oj<X6P?o00001?n/bo03o`0000Co[<_`
00?o0000okS3honh`n<03Onh`n<2o`00017o^<?S00?o0000okjkeonn^mL01?nn^mL3o`0000Oo^<?S
00?o0000okjkeonn^mL03Onn^mL2o`00013o_[_G00?o0000ol:dcOo2]<d01Oo2]<d00ol0003o_[_G
okjke`07okjke`03o`000?o2]<go`[C=00co`[C=00?o0000okjkeol000002Oo2]<d00ol0003o`[C=
ol:dc@05ol:dc@03o`000?oooooooooo02Cooooo00?o0000ooooooooool08Oooool001Gooooo0_l0
000=ooooo`03o`000?o4Vjkoa9^^00Coa9^^00?o0000olBM/Oo4WK401oo4WK400ol0003oa9^^olBK
[P07olBK[P03o`000?o4WK7oa9fa00Coa9fa0ol00005oh4000Ko00002_n20003o`0000_oUQ<000Co
0000oj8X6Ol0003o00002_nF4`000ol0003oXbPJoj<X6P04oj<X6P?o00001?n/bo03o`0000So[<_`
00?o0000okS3honh`n<02Onh`n<3o`000003ojc;l?l0003o^<?S013o^<?S00?o0000okjkeonn^mL0
0_nn^mL2o`0000[o^<?S00?o0000okjkeonn^mL02onn^mL2o`000003okS3hol0003o_[_G013o_[_G
00?o0000ol:dcOo2]<d00oo2]<d00ol0003o_[_Gokjke`09okjke`03o`000?o2]<go`[C=00Wo`[C=
0_l00003okjke`03o`000?o2]<go`[C=00Oo`[C=00?o0000ol:dcOo2]<d01?o2]<d00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo027ooooo000Eooooo`03o`000?oooooooooo00cooooo00?o
0000olBK[_o4Vjh00oo4Vjh00ol0003oa9faolBM/@08olBM/@03o`000?o4Vjkoa9^^00Koa9^^00?o
0000olBM/Oo4WK401Oo4WK400ol0003oa9^^olBK[P05o`0000KoGP000_l0000;oh8000;o00002?nF
4`04o`0000coUQ<000?o0000oj<X6_nS:1X00ol00003oiOAo0Co00003?n/bo000ol0003o^<?SokS3
h`06okS3h`;o00001On/bo000ol0003o^<?SokS3h`0?okS3h`04o`000?nn^mOo0000o`0000go^<?S
00?o0000okjkeonn^mL02Onn^mL00ol0003o^<?SokS3h`02okS3h`03o`000?nn^mOo_[_G00oo_[_G
00?o0000ol:dcOo2]<d00_l0000<okjke`03o`000?o2]<go`[C=00Oo`[C=0_l00005okjke`03o`00
0?o2]<go`[C=00So`[C=00?o0000ol:dcOo2]<d00oo2]<d00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo023ooooo000Eooooo`03o`000?oooooooooo00gooooo00Go0000olBK[_o4Vjkoa9^^
o`00000<olBM/@03o`000?o4Vjkoa9^^00Goa9^^00?o0000olBM/Oo4WK401_o4WK400ol0003oa9^^
olBK[P02olBK[PCo00001_mN0002o`0000_oPP000_l00002oiHC00Co00001?n20002o`0000[oUQ<0
0ol00005oiOAo0?o00003on/bo000ol0003o^<?SokS3h`03okS3h`;o00002?n/bo000ol0003o^<?S
okS3h`0>okS3h`;o00004?nh`n<00ol0003o_[_Gokjke`06okjke`;o00001_nh`n<00ol0003o_[_G
okjke`0>okjke`03o`000?o2]<go000000oo_[_G00?o0000ol:dcOo2]<d01Oo2]<d00ol0003o_[_G
okjke`06okjke`03o`000?o2]<go`[C=00So`[C=00?o0000ol:dcOo2]<d00_o2]<d2o`0002Oooooo
00?o0000ooooooooool07oooool001Gooooo00?o0000ooooooooool03Oooool01Ol0003oa9^^olBK
[_o4Vjko000000coa9fa00?o0000olBK[_o4Vjh01?o4Vjh00ol0003oa9faolBM/@07olBM/@03o`00
0?o4Vjkoa9^^00Koa9^^0ol00005oeh000;o00002On20004o`0000[oPP0000?o0000oiHC0?nF4`00
1?nF4`03o`0000GoUm7l0ol00003oiOAo003o`000?n/bo3o[<_`00go[<_`00?o0000okS3hol00000
0_l0000;ojc;l003o`000?nh`n?o^<?S00[o^<?S0ol000000on/c?3o0000okS3h`0@okS3h`03o`00
0?nn^mOo_[_G00?o_[_G0_l00008okS3h`03o`000?nn^mOo_[_G00ko_[_G0_l0000@okjke`03o`00
0?o2]<go`[C=00?o`[C=0_l00009okjke`03o`000?o2]<go`[C=00So`[C=00Oo0000ol:dcOo2]<go
`[C=o`000?nn^mOo000002Oooooo00?o0000ooooooooool07oooool001Cooooo0_l0000?ooooo`04
o`000?o4Vjkoa9^^o`0000goa9fa00?o0000olBK[_o4Vjh00oo4Vjh00ol0003oa9faolBM/@08olBM
/@03o`000?o4Vjkoa9^^00Koa9^^00?o0000olBM/Oo4WK401_l000000omN003o0000o`000002oh80
00Go00001?mN0002o`0000OoPP002?l00005oiOAo0?o00001onGdO`00ol0003o[<_`ojc;l00;ojc;
l0?o00003on/bo000ol0003o^<?SokS3h`06okS3h`?o00001On/c?000ol0003o^<?SokS3h`0>okS3
h`03o`000?nn^mOo_[_G00;o_[_G00?o0000okS3honh`n<02Onh`n<00ol0003o_[_Gokjke`0;okjk
e`;o000000?o^<?So`000?nn^mL04?nn^mL00ol0003o`[C=ol:dc@02o`0000co_[_G00?o0000ol:d
cOo2]<d02?o2]<d3o`0000?o_[_G00?o0000ooooooooool09?ooool2o`00023ooooo000Dooooo`03
o`000?oooooooooo00oooooo0_l0000?olBM/@05o`000?o4Vjkoa9^^olBK[_l000003?o4WK400ol0
003oa9^^olBK[P05olBK[P03o`000?o4WK7oa9fa00Goa9fa1ol00006oeh000_o00002?m^cOh00ol0
003oUm7lo`000002o`0000_oUm7l00?o0000ojc;l?n/bo001On/bo05o`0000?oUm7l00?o0000ojc;
l?n/bo003On/bo000ol0003o^<?SokS3h`03okS3h`;o00002On/c?000ol0003o^<?SokS3h`0>okS3
h`04o`000?nn^mOo0000o`0000go^<?S00?o0000okjkeonn^mL02?nn^mL2o`0000Co^<?S00?o0000
okjkeonn^mL03_nn^mL00ol0003o`[C=o`00000>okjke`03o`000?o2]<go`[C=00Oo`[C=0ol00004
okjke`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07Oooool001Cooooo00?o0000oooo
ooooool03oooool00ol0003oa9faolBM/@0>olBM/@05o`000?o4Vjkoa9^^olBK[_l000003?o4WK40
0ol0003oa9^^olBK[P04olBK[P03o`000?o4WK7oa9fa00Ooa9fa00Co0000olBK[_o4Vjkoa9^^2?l0
0007obZ_hP;o00002Om^cOh4o`0000koUm7l00?o0000ojc;l?n/bo001?l00009oiOAo003o`000?n/
bo3o[<_`00go[<_`00?o0000okS3hol000000_l0000<ojc<l003o`000?nh`n?o^<?S00go^<?S0_l0
000?okS3h`03o`000?nn^mOo_[_G00Ko_[_G0_l00007okS3h`03o`000?nn^mOo_[_G00go_[_G0_l0
000@okjke`03o`000?o2]<go`[C=00Go`[C=00Co0000okjkeonn^mOo00001Onn^mL00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01gooooo000Dooooo`03o`000?oooooooooo00oooooo00?o
0000olBM/Oo4WK403_o4WK401?l0003oa9^^olBK[_l0000=olBM/@03o`000?o4Vjkoa9^^00?oa9^^
00?o0000olBM/Oo4WK402?o4WK400ol0003oa9^^olBK[P06olBK[PCo00002?lZ[n82o`0000CoK/gn
0ol00004ofk=oP;o00002_nGdO`5o`0000koUm7l00?o0000ojc;l?n/bo003?n/bo02o`00013o[<c`
00?o0000okS3honh`n<02Onh`n<3o`000003ojc<l?l0003o^<?S00oo^<?S00?o0000okjkeonn^mL0
1?nn^mL00ol0003o^<?SokS3h`07okS3h`03o`000?nn^mOo_[_G00_o_[_G0_l000000onh`n?o0000
okjke`0?okjke`03o`000?o2]<go`[C=00?o`[C=0_l00004okjke`03o`000?nn^mOo_[_G00;o_[_G
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Looooo`005?ooool00ol0003ooooooooo
o`0@ooooo`03o`000?o4WK7oa9fa00koa9fa0_l0000?olBM/@05o`000?o4Vjkoa9^^olBK[_l00000
3?o4WK400ol0003oa9^^olBK[P04olBK[P03o`000?o4WK7oa9fa00;oa9fa2?l00002obZ_hPCo0000
2Om^cOh01?l0003oUm7loiOAo?nGdO`6o`0000GoKLgn00?o0000oiOAo?nGdO`03?nGdO`00ol0003o
[<_`ojc;l008ojc;l0?o00000_nFd_`00ol0003o[<c`ojc<l00=ojc<l003o`000?nh`n?o^<?S00Ko
^<?S0ol00005ojc<l003o`000?nh`n?o^<?S00go^<?S00?o0000okjkeonn^mL00_nn^mL2o`0000_o
^<?S00?o0000okjkeonn^mL02?nn^mL2o`0000Co^<?S00?o0000okjkeonn^mL03_nn^mL00ol0003o
`[C=ol:dc@02o`0000Oo_[_G00?o0000okjkeonn^mL00_nn^mL00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo01_ooooo000Dooooo`;o00004Oooool00ol0003oa9faolBM/@0>olBM/@03o`00
0?o4WK7oa9fa00koa9fa00Go0000olBK[_o4Vjkoa9^^o`00000<olBM/@03o`000?o4Vjkoa9^^00?o
a9^^00?o0000olBM/Oo4WK401oo4WK401?l0003oa9^^olBK[_o4VjhCo`0000coKLgn00?o0000oiOA
o?nGdO`03?nGdO`00ol0003o[<_`ojc;l004ojc;l0?o00001_nFd_`00ol0003o[<c`ojc<l00=ojc<
l003o`000?nh`n?o^<?S00?o^<?S0_l00009ojc<l003o`000?nh`n?o^<?S00go^<?S00Co0000okjk
eol0003o00003Onh`n<00ol0003o_[_Gokjke`06okjke`;o00001_nh`n<00ol0003o_[_Gokjke`0>
okjke`03o`000?o2]<go000000[o_[_G00?o0000okjkeonn^mL00_nn^mL00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01_ooooo000Cooooo`;o00004_ooool00ol0003oa9faolBM/@0>olBM
/@03o`000?o4WK7oa9fa00koa9fa00Co0000olBK[_o4Vjko00003Oo4WK400ol0003oa9^^olBK[P03
olBK[P03o`000?o4WK7oa9fa00Ooa9fa00Co0000olBK[_l0003o00001Oo4Vjh00ol0003oa9fao`00
0003o`0000Oo:JkQ0_l0000<ofg=oP;o00003OnGdO`00ol0003o[<_`ojc;l003o`0000[oU];l00?o
0000ojc<l?n/c?003On/c?000ol0003o^<?So`000002o`0000_o[<c`00?o0000okS3honh`n<03Onh
`n<2o`00013o^<?S00?o0000okjkeonn^mL01?nn^mL00ol0003o^<?SokS3h`07okS3h`03o`000?nn
^mOo_[_G00go_[_G0_l0000;okjke`03o`000?nn^mOo_[_G00;o_[_G00?o0000ooooooooool09Ooo
ool2o`0001cooooo000Cooooo`03o`000?oooooooooo01;ooooo00?o0000olBM/Oo4WK403?o4WK40
0ol0003o`j2do`00000@olBM/@;o00003oo4WK401Ol0003oa9^^olBK[_o4Vjko000000Woa9fa0ol0
0006olBK[P03o`000?o4WK7oa9fa00Coa9fa1Ol00004obV^h@;o00003?m]cOh00ol0003oUm7loiOA
o008oiOAo0Go00003_nFd_`00ol0003o[<c`ojc<l00;ojc<l0?o00003on/c?000ol0003o^<?SokS3
h`09okS3h`?o000000?o[<c`o`000?nh`n<04?nh`n<01?l0003o_[_Gokjkeonn^mL2o`0000[o^<?S
00?o0000okjkeonn^mL02onn^mL2o`000003okS4hol0003o_[_G00_o_[_G00?o0000okjkeonn^mL0
0_nn^mL00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01[ooooo000Cooooo`03o`000?oo
oooooooo01;ooooo00?o0000olBM/Oo4WK402oo4WK401?l0003o`j2dol>P]?l0000@olBM/@03o`00
0?o4WK7oa9fa00koa9fa00Co0000olBK[_o4Vjko00001oo4WK43o`0000;oa9fa00?o0000olBK[_o4
Vjh00oo4Vjh00ol0003oa9faolBM/@07olBM/@03o`000?o4Vjkoa9^^00So00002om]cOh01?l0003o
Um7loiOAo?nGdO`6o`0000GoK<gm00?o0000oiKBo?nFd_`03?nFd_`00ol0003o[<c`ojc<l005ojc<
l0Go00000onFd_`00ol0003o[<c`ojc<l00=ojc<l003o`000?nh`n?o^<?S00Go^<?S0ol00005ojc<
l003o`000?nh`n?o^<?S00ko^<?S00Co0000okjkeol0003o00003Onh`n<00ol0003o_[_Gokjke`08
okjke`;o00001?nha><00ol0003o_[_Gokjke`0:okjke`05o`000?nn^mOo_[_Gokjkeol00000:?oo
ool00ol0003oooooooooo`0Iooooo`004oooool00ol0003oooooooooo`0Booooo`03o`000?o4WK7o
a9fa00[oa9fa00Go0000ol>P]?o3X;Co`j2do`00000@olBM/@03o`000?o4WK7oa9fa00koa9fa00Co
0000olBK[_o4Vjko00001?o4WK43o`0000Goa9fa00?o0000olBK[_o4Vjh00oo4Vjh00ol0003oa9fa
olBM/@07olBM/@03o`000?o4Vjkoa9^^00Koa9^^4Ol0000<ofc=o@;o00003OnFd_`00ol0003o[<c`
ojc<l004o`0000WoU];l00?o0000ojc<l?n/c?003?n/c?000ol0003o^<?SokS3h`03okS3h`;o0000
2On/c?000ol0003o^<?SokS3h`0=okS3h`;o00004?nh`n<00ol0003o_[_Gokjke`05okjke`;o0000
1onha><00ol0003o_[_Gokjke`0:okjke`03o`000?nn^mOo_[_G00;o0000:?ooool00ol0003ooooo
ooooo`0Hooooo`004oooool3o`0001?ooooo00?o0000olBM/Oo4WK402?o4WK400ol0003o`j2dol>P
]003ol>P]003o`000?o4WK7oa9fa00coa9fa00?o0000ol>P]?l000004?o4WK42o`0000;oa9fa0ol0
0009olBM/@05o`000?o4Vjkoa9^^olBK[_l000002oo4WK400ol0003oa9^^olBK[P04olBK[P03o`00
0?o4WK7oa9fa00Goa9fa1_l00003obN^h0?o00003?m/cOd00ol0003oU];loiKBo008oiKBo0Go0000
3_nFd_`00ol0003o[<c`ojc<l00<ojc<l003o`000?nh`n?o000000;o00003?n/c?000ol0003o^<?S
okS3h`09okS3h`?o000000?o[<c`o`000?nh`n<03onh`n<00ol0003o_[_Gokjke`04okjke`03o`00
0?nha>?o^<CS00Oo^<CS00?o0000okjkeonn^mL02_nn^mL3o`000003okS4hol0003ooooo02Oooooo
00?o0000ooooooooool06?ooool001?ooooo00?o0000ooooooooool04oooool00ol0003oa9faolBM
/@07olBM/@03o`000?o3X;Co`j2d00Co`j2d00?o0000olBM/Oo4WK402oo4WK401?l0003o`j2dol>P
]?l0000@olBM/@Co00003?o4WK401?l0003oa9^^olBK[_l0000<olBM/@03o`000?o4Vjkoa9^^00?o
a9^^00?o0000olBM/Oo4WK401oo4WK400ol0003oa9^^olBK[P02olBK[PSo00002om/cOd01?l0003o
U];loiKBo?nFd_`6o`0000GoK<gm00?o0000oiKBo?nFd_`03?nFd_`00ol0003o[<c`ojc<l00:ojc<
l0Co00003_n/c?000ol0003o^<?SokS3h`06okS3h`?o00001On/c?000ol0003o^<?SokS3h`0>okS3
h`04o`000?nn^mOo_[_Gokjke`;o00002onha><00ol0003o_[_Gokjke`08okjke`?o00000onha><0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01Oooooo0008ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01_ooool00ol0003oooooooooo`0Cooooo`03o`000?o4WK7oa9fa00Koa9fa00?o0000
ol>P]?o3X;@01Oo3X;@00ol0003oa9faolBM/@0:olBM/@05o`000?o3X;Co`j2dol>P]?l000003_o4
WK43o`0000ooa9fa00Co0000olBK[_o4Vjko00003?o4WK400ol0003oa9^^olBK[P03olBK[P03o`00
0?o4WK7oa9fa00Ooa9fa00?o0000olBK[_o4Vjh01_o4Vjh00ol0003oa9fao`00000@o`0000coK<gm
0_l0000=oiKBo003o`000?n/c?3o[<c`00Go[<c`1?l00004oiKBo003o`000?n/c?3o[<c`00co[<c`
00?o0000okS3honh`n<00onh`n<2o`0000Wo[<c`00?o0000okS3honh`n<03Onh`n<01?l0003o_[_G
o`000?l0000=okS4h`03o`000?nn^mOo_[_G00Ko_[_G0_l00003okS4h`03o`000?nha>?o^<CS00?o
00009oooool00ol0003oooooooooo`0Fooooo`002?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo00?o0000ooooooooool05Oooool00ol0003oa9faolBM/@05olBM/@03o`000?o3X;Co`j2d00Ko
`j2d00?o0000olBM/Oo4WK402?o4WK400ol0003o`j2dol>P]003ol>P]003o`000?o4WK7oa9fa00So
a9fa0ol000001?o4WK7o0000ol>P]?l0000?olBM/@;o00003_o4WK401Ol0003oa9^^olBK[_o4Vjko
000000_oa9fa00?o0000olBK[_o4Vjh01?o4Vjh00ol0003oa9faolBM/@05olBM/@?o00002?lV[Ml3
o`0000coK<gm00?o0000oiKBo?nFd_`02onFd_`00ol0003o[<c`ojc<l004o`0000WoU];l00?o0000
ojc<l?n/c?003?n/c?000ol0003o^<?So`000002o`0000co[<c`00?o0000okS3honh`n<02onh`n<3
o`00013o^<CS00?o0000okjkeonn^mL01?nn^mL00ol0003o^<CSokS4h`04okS4h`06o`000?nha>?o
^<CSo`000?n[>S3o00009Oooool2o`0000Wooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00_ooool000Sooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo01Go
oooo00?o0000olBM/Oo4WK401?o4WK400ol0003o`j2dol>P]007ol>P]003o`000?o4WK7oa9fa00So
a9fa00?o0000ol>P]?o3X;@00oo3X;@00ol0003oa9faolBM/@06olBM/@;o00000oo4WK401?l0003o
`j2dol>P]?l0000?olBM/@03o`000?o4WK7oa9fa00goa9fa00Co0000olBK[_o4Vjko00003?o4WK40
0ol0003oa9^^olBK[P04olBK[P03o`000?o4WK7oa9fa00Koa9fa00?o0000olBK[_l000001ol00003
obJ]g`;o00002om/cOd00ol0003oU];loiKBo005oiKBo0So00003_nFd_`00ol0003o[<c`ojc<l00:
ojc<l0?o00003on/c?000ol0003o^<?SokS3h`08okS3h`?o00000_n/c?400ol0003o^<CSokS4h`0?
okS4h`04o`000?nn^mOo_[_Gokjke`;o00001onha><01?l0003o^<CSokS4hol00002oj/j<003o`00
0?oooooooooo00Wooooo0_l0000Iooooo`03o`000?oooooooooo00Kooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool000Sooooo00Go0000oooooooo
ooooooooo`000005ooooo`;o00005_ooool00ol0003oa9faolBM/@03olBM/@03o`000?o3X;Co`j2d
00So`j2d00?o0000olBM/Oo4WK401oo4WK400ol0003o`j2dol>P]004ol>P]003o`000?o4WK7oa9fa
00?oa9fa0ol00004olBM/@05o`000?o3X;Co`j2dol>P]?l000003oo4WK400ol0003oa9faolBM/@0=
olBM/@04o`000?o4Vjkoa9^^o`0000coa9fa00?o0000olBK[_o4Vjh00oo4Vjh00ol0003oa9faolBM
/@07olBM/@03o`000?o4Vjkoa9^^00Koa9^^6Ol00008of_=o@03o`000?nFd_coU];l00coU];l00?o
0000ojc<l?n/c?001On/c?04o`0000?oU];m00?o0000ojc<l?n/c?003On/c?000ol0003o^<?SokS3
h`04okS3h`?o00001_n/c?400ol0003o^<CSokS4h`0>okS4h`04o`000?nn^mOo0000o`0000[o^<CS
00Co0000okS4honha>?o00000_n[>S02o`0000Wooooo00?o0000oj/j<?l000006Oooool00ol0003o
ooooooooo`06ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4002oooo
o`002?ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool05_ooool01Ol0
003oa9faolBM/Oo4WK7o000000co`j2d00?o0000olBM/Oo4WK401Oo4WK400ol0003o`j2dol>P]006
ol>P]003o`000?o4WK7o000000;o00001_o4WK400ol0003o`j2dol>P]003ol>P]003o`000?o4WK7o
a9fa00_oa9fa00?o0000ol>P]?l000003oo4WK42o`0000koa9fa00Go0000olBK[_o4Vjkoa9^^o`00
000;olBM/@03o`000?o4Vjkoa9^^00Coa9^^00?o0000olBM/Oo4WK401_o4WK44o`0000So9JcO0_l0
000<of_=o@03o`000?nFd_coU];l00coU];l00?o0000ojc<l?n/c?001?l00008oiKBo@03o`000?n/
c?3o[<c`00go[<c`00?o0000okS3honh`n<00ol0000:ojc<l@03o`000?nha>?o^<CS00go^<CS0_l0
000=okS4h`03o`000?nha>?o000000CoZcX`00?o0000ooooooooool01Oooool01Ol0003oZcX`oj/j
<?n[>S3o000001Sooooo00?o0000ooooooooool01oooool00onHV9So8B4Qonk^kP03ooooo`05o`00
0?ooooooooooooooool000000_ooool000Sooooo00Go410@oooooooooooooooooa0@4005ooooo`03
o`000?oooooooooo01Kooooo00Co0000olBM/Oo4WK7o00003Oo3X;@00ol0003oa9faolBM/@04olBM
/@03o`000?o3X;Co`j2d00Ko`j2d0ol00009olBM/@03o`000?o3X;Co`j2d00?o`j2d00?o0000olBM
/Oo4WK402_o4WK401?l0003o`j2dol>P]?l0000?olBM/@03o`000?o4WK7oa9fa00goa9fa00Go0000
olBK[_o4Vjkoa9^^o`00000;olBM/@03o`000?o4Vjkoa9^^00Coa9^^00?o0000olBM/Oo4WK401_o4
WK401?l0003oa9^^olBK[_o4Vjh5o`0000Go9JcO00?o0000of_=oOm[cOd02_m[cOd00ol0003oU];l
oiKBo009oiKBo0Go00003OnFd_d00ol0003o[<c`ojc<l00<ojc<l0?o00003_n/c?400ol0003o^<CS
okS4h`09okS4h`?o000000?o[<cao`000?nha><03?nha><01?l0003o^<CSokS4hol00004oj/j<003
o`000?oooooooooo00Cooooo00?o0000oj/j<?n[>S000_n[>S02o`0000Wooooo0_l0000<ooooo`03
o`000?oooooooooo00Oooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo0000
00;ooooo0008ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0Foooo
o`03o`000?o4WK7o000000ko`j2d00?o0000olBM/Oo4WK400oo4WK400ol0003o`j2dol>P]004ol>P
]0?o000000?o`j2do`000?o4WK402?o4WK400ol0003o`j2dol>P]004ol>P]003o`000?o4WK7oa9fa
00Woa9fa00Go0000ol>P]?o3X;Co`j2do`00000?olBM/@03o`000?o4WK7oa9fa00goa9fa00Co0000
olBK[_o4Vjko00003?o4WK400ol0003oa9^^olBK[P03olBK[P03o`000?o4WK7oa9fa00Ooa9fa00?o
0000olBK[_o4Vjh01_o4Vjh8o`0000_oJlgm00Co0000oiKBo?nFd_coU];l1ol00005of[=o@03o`00
0?nFd_goU];m00_oU];m00?o0000ojc<l?n/c?002?n/c?03o`000003oiGBoOl0003o[<ca00ko[<ca
00?o0000okS4honha><01_nha><3o`0000Go[<ca00?o0000okS4honha><02onha><00ol0003o^<CS
o`000005oj/j<0;o00000oooool00ol0003oZcX`oj/j<005oj/j<003o`000?oooooooooo00Kooooo
00?o0000oj/j<?l000002_ooool3o`0000Wooooo00Go0000oooooooooooooooooa0@4003ooooo`7o
410@0Oooool1ooooo`002?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00?o0000oooooooo
ool06?ooool00ol0003o`j2dol>P]00>ol>P]003o`000?o4WK7oa9fa00;oa9fa00Co0000ol>P]?o3
X;Co`j2d0ol00005ol>P]003o`000?o4WK7oa9fa00Goa9fa00?o0000ol>P]?o3X;@01_o3X;@00ol0
003oa9faolBM/@08olBM/@03o`000?o3X;Co`j2d00;o`j2d00?o0000olBM/Oo4WK402oo4WK400ol0
003o`j2do`00000?olBM/@;o00003_o4WK401Ol0003oa9^^olBK[_o4Vjko000000_oa9fa00?o0000
olBK[_o4Vjh01?o4Vjh00ol0003oa9faolBM/@04olBM/A7o00003OmZcOd00ol0003oU];moiKBo@0;
oiKBo@03o`000?n/c?3o[<c`00Co[<c`0ol00005oiGBo@03o`000?n/c?7o[<ca00go[<ca00?o0000
okS4honha><00onha><2o`0000Wo[<ca00?o0000okS4honha><02onha><3o`0000KoZcX`00Co0000
oooooooooooo00002?n[>S000ol0003oooooooooo`04ooooo`;o00000_n[>S000ol0003ooooooooo
o`04ooooo`Co000000?oooooo`000?ooool01?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`004Oooool2o`0001Wooooo00?o0000ol>P]?o3X;@0
3_o3X;@01_l0003oa9faolBM/Oo4WK7o0000ol>P]0?o00002?o3X;@00ol0003oa9faolBM/@04olBM
/@03o`000?o3X;Co`j2d00Oo`j2d00?o0000olBM/Oo4WK401oo4WK400ol0003o`j2dol>P]003ol>P
]003o`000?o4WK7oa9fa00[oa9fa00Co0000ol>P]?o3X;Co00003oo4WK400ol0003oa9faolBM/@0=
olBM/@05o`000?o4Vjkoa9^^olBK[_l000002oo4WK400ol0003oa9^^olBK[P04olBK[P03o`000?o4
WK7oa9fa00Koa9fa00Co0000olBK[_o4Vjkoa9^^1_l00004obB/gP?o00003?mZcOd00ol0003oU];m
oiKBo@0;oiKBo@03o`000?n/c?3o[<c`00?o00002OnEd_d00ol0003o[<caojc<l@0=ojc<l@03o`00
0?nha>?o000000;o00002on/c?400ol0003o^<CSokS4h`09okS4h`Go00001on[>S03o`0000WoZcX`
00?o0000ooooooooool00oooool00ol0003oZcX`oj/j<002oj/j<0;o000000Coooooo`000?l0003o
00001Oooool2o`0000Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00_ooool0017ooooo00?o0000ooooooooool06Oooool00ol0003o`j2dol>P]00=ol>P
]003o`000?o4WK7oa9fa00?o00002oo3X;@00ol0003oa9faolBM/@03olBM/@03o`000?o3X;Co`j2d
00So`j2d00?o0000olBM/Oo4WK401_o4WK400ol0003o`j2dol>P]004ol>P]003o`000?o4WK7oa9fa
00Woa9fa00Go0000ol>P]?o3X;Co`j2do`00000?olBM/@03o`000?o4WK7oa9fa00goa9fa00Co0000
olBK[_o4Vjko00003?o4WK400ol0003oa9^^olBK[P03olBK[P03o`000?o4WK7oa9fa00Ooa9fa00?o
0000olBK[_o4Vjh01_o4Vjh:o`0000_oJ/gm00?o0000oiKBoOnFd_d01OnFd_d8o`0000goUM;m00?o
0000ojc<lOn/c?402on/c?43o`0000oo[<ca00?o0000okS4honha><01Onha><3o`0000?o[<ca00?o
0000ojc<lOl000001on[>S02o`0000[oZcX`0_l00002ooooo`;o00001_n[>S000ol0003ooooooooo
o`06ooooo`;o00004oooool0017ooooo00?o0000ooooooooool06Oooool00ol0003o`j2dol>P]00=
ol>P]0?o00003oo3X;@00ol0003oa9faolBM/@02olBM/@03o`000?o3X;Co`j2d00Wo`j2d00?o0000
olBM/Oo4WK401?o4WK400ol0003o`j2dol>P]006ol>P]003o`000?o4WK7oa9fa00Soa9fa00?o0000
ol>P]?o3X;@00_o3X;@00ol0003oa9faolBM/@0;olBM/@03o`000?o3X;Co000000ooa9fa0_l0000>
olBM/@05o`000?o4Vjkoa9^^olBK[_l000002oo4WK400ol0003oa9^^olBK[P04olBK[P03o`000?o4
WK7oa9fa00Goa9fa5_l00008ofW<o@03o`000?nEd_goUM;m00_oUM;m00?o0000ojc<lOn/c?401On/
c?45o`0000?oUM;m00?o0000ojc<lOn/c?403?n/c?400ol0003o^<CSokS4h`03okS4h`;o00001on/
c?400ol0003o[<cao`000006oj/j<003o`000?nT;1ko000000_oZcX`00Co0000ooooool0003o0000
1on[>S000ol0003oooooooooo`05ooooo`;o00004oooool0017ooooo00?o0000ooooooooool06Ooo
ool00ol0003o`j2dol>P]00;ol>P]0;o000000?o`j2do`000?o3X;@03oo3X;@01Ol0003oa9faolBM
/Oo4WK7o000000co`j2d00?o0000olBM/Oo4WK401?o4WK400ol0003o`j2dol>P]006ol>P]003o`00
0?o4WK7oa9fa00Ooa9fa00?o0000ol>P]?o3X;@00oo3X;@00ol0003oa9faolBM/@0:olBM/@04o`00
0?o3X;Co`j2do`0000ooa9fa00?o0000olBM/Oo4WK403Oo4WK401Ol0003oa9^^olBK[_o4Vjko0000
00_oa9fa00?o0000olBK[_o4Vjh00oo4Vjh00ol0003oa9faolBM/@06olBM/@03o`000?o4Vjkoa9^^
00?oa9^^0ol00008ob>[g@;o00003?mYc?d2o`0000coUM;m00?o0000ojc<lOn/c?401?l00009oiGB
o@03o`000?n/c?7o[<ca00co[<ca00?o0000okS4hol000000_l0000:ojc<l@;o00001On[>S001?l0
003oY2`Noj@/7_nT;1h2o`0000[oZcX`0_l00009oj/j<003o`000?oooooooooo00?ooooo0ol0000C
ooooo`004Oooool00ol0003oooooooooo`0Jooooo`03o`000?o3X;Co`j2d00Oo`j2d0ol00003ol>P
]003o`000?o3X;Co`j2d00ko`j2d00Co0000olBM/Oo4WK7o00003Oo3X;@00ol0003oa9faolBM/@03
olBM/@03o`000?o3X;Co`j2d00Oo`j2d00?o0000olBM/Oo4WK401_o4WK400ol0003o`j2dol>P]004
ol>P]003o`000?o4WK7oa9fa00Woa9fa00Go0000ol>P]?o3X;Co`j2do`00000?olBM/@03o`000?o4
WK7oa9fa00goa9fa00Co0000olBK[_o4Vjko00003?o4WK400ol0003oa9^^olBK[P03olBK[P03o`00
0?o4WK7oa9fa00Koa9fa00?o0000olBK[_o4Vjh01_o4Vjh7o`0000?o8j_M0_l0000<ofW<o@03o`00
0?nEd_goUM;m00CoUM;m2?l0000>oiGBo@03o`000?n/c?7o[<ca00[o[<ca0ol0000>ojc<l@;o0000
1?n[>S000ol0003oY2`Noj@/7P03oj@/7P03o`000?n[>S3oZcX`00SoZcX`0_l00009oj/j<0;o0000
0oooool00ol0003oooooo`00000Cooooo`004?ooool3o`0001_ooooo00?o0000ol>P]?o3X;@01?o3
X;@3o`0000Go`j2d00?o0000ol>S^?l000004?o3X;@2o`0000oo`j2d00Go0000olBM/Oo4WK7oa9fa
o`00000;ol>P]003o`000?o4WK7oa9fa00Coa9fa00?o0000ol>P]?o3X;@01_o3X;@00ol0003oa9fa
olBM/@07olBM/@03o`000?o3X;Co`j2d00?o`j2d00?o0000olBM/Oo4WK402oo4WK400ol0003oa:2d
o`00000?olBM/@;o00003_o4WK401Ol0003oa9^^olBK[_o4Vjko000000[oa9fa00?o0000olBK[_o4
Vjh01?o4Vjh00ol0003oa9faolBM/@05olBM/ASo00002?mYc?d00ol0003oUM;moiGBo@0<oiGBo@03
o`000?n/c?7o[<ca00Go[<ca1?l00002oiCBo@03o`000?n/c?7o[<ca00co[<ca00?o0000ojc<lOl0
00000_n[>S000ol0003oY2`Noj@/7P05oj@/7P;o00002?n[>S000ol0003oY2`Oo`00000:oj/j<006
o`000?oooooo0000o`000?oooooo00004oooool0013ooooo00?o0000ooooooooool07?ooool00ol0
003o`j2dol>P]003o`0000Oo`j2d00Co0000ol>S^?o3XkSo00004?o3X;@00ol0003o`j2dol>P]00>
ol>P]005o`000?o4WK7oa9faolBM/Ol000002oo3X;@00ol0003oa9faolBM/@04olBM/@03o`000?o3
X;Co`j2d00Ko`j2d00?o0000olBM/Oo4WK401oo4WK400ol0003o`j2dol>P]003ol>P]003o`000?o4
WK7oa9fa00[oa9fa00Co0000olBP]?o4X;Co00003oo4WK400ol0003oa9faolBM/@0=olBM/@04o`00
0?o4Vjkoa9^^o`0000_oa9fa00?o0000olBK[_o4Vjh00oo4Vjh00ol0003oa9faolBM/@07olBM/@03
o`000?o4Vjkoa9^^00;oa9^^1Ol00009ob:[g003o`000?mYc?goJLcm00[oJLcm00?o0000oiGBoOnE
d_d03?nEd_d00ol0003o[<caojc<l@04o`0000OoU=;m00?o0000ojc<lOn/c?403?n/c?43o`000003
oj/j<?l0003oY2`N00SoY2`N00?o0000oj/j<?n[>S001?n[>S001?l0003oY2`Ooj@/7onT;1l2o`00
00WoZcX`0ol000000ooooooo0000ooooo`0Booooo`004?ooool00ol0003oooooooooo`0Looooo`?o
00002Oo3X;@00ol0003o`j>hol>S^002ol>S^003o`000?o3X;Co`j2d00go`j2d00?o0000ol>P]?o3
X;@03_o3X;@01?l0003oa9faolBM/Ol0000<ol>P]003o`000?o4WK7oa9fa00?oa9fa00?o0000ol>P
]?o3X;@01oo3X;@00ol0003oa9faolBM/@06olBM/@03o`000?o3X;Co`j2d00Co`j2d00?o0000olBM
/Oo4WK402Oo4WK401Ol0003oa:2dolBP]?o4X;Co000000ooa9fa00?o0000olBM/Oo4WK403Oo4WK40
1?l0003oa9^^olBK[_l0000;olBM/@03o`000?o4Vjkoa9^^00?oa9^^00?o0000olBM/Oo4WK401oo4
WK400ol0003oa9^^olBK[P05olBK[PKo00001_lRZm`00ol0003oJLcmofW<o@0:ofW<o@03o`000?nE
d_goUM;m00WoUM;m1Ol0000<oiCBo@03o`000?n/c?7o[<ca00co[<ca1?l0000:oj@/7P03o`000?n[
>S3oZcX`00?oZcX`00?o0000oj@/7onT;1l00onT;1l00ol0003oZcX`oj/j<007oj/j<004o`000?oo
ooooooooo`0001?ooooo000@ooooo`03o`000?oooooooooo01Wooooo0ol000000ooooooo0000ol>P
]008ol>P]003o`000?o3XkSo`j>h00?o`j>h00?o0000ol>P]?o3X;@03?o3X;@00ol0003o`j>ho`00
000@ol>P]0;o00003_o3X;@01Ol0003oa9faolBM/Oo4WK7o000000_o`j2d00?o0000olBM/Oo4WK40
1?o4WK400ol0003o`j2dol>P]006ol>P]003o`000?o4WK7oa9fa00Ooa9fa00?o0000olBP]?o4X;@0
0oo4X;@00ol0003oa9faolBM/@0;olBM/@03o`000?o4X;Co000000ooa9fa0_l0000=olBM/@05o`00
0?o4Vjkoa9^^olBK[_l000002_o4WK400ol0003oa9^^olBK[P04olBK[P03o`000?o4WK7oa9fa00Co
a9fa1_l000000olRZmco0000ofW<o@0;ofW<o@04o`000?nEd_goUM;moiGBo@Oo00001?mXc?d00ol0
003oU=;moiCBo@0;oiCBo@03o`000?n/c?7o[<ca00_o[<ca0ol000000onI60Ko0000o`000009oj@/
7P;o00000_n[>S000ol0003oY2`Ooj@/7`05oj@/7`;o00001on[>S001?l0003oooooooooool0000C
ooooo`004?ooool00ol0003oooooooooo`0Fooooo`?o00001?ooool00ol0003o`j2dol>P]006ol>P
]003o`000?o3XkSo`j>h00Co`j>h00?o0000ol>P]?o3X;@02oo3X;@01?l0003o`j>hol>S^?l0000@
ol>P]003o`000?o3X;Co`j2d00go`j2d00Go0000olBM/Oo4WK7oa9fao`00000;ol>P]003o`000?o4
WK7oa9fa00?oa9fa00?o0000ol>P]?o3X;@01oo3X;@00ol0003oa9faolBM/@07olBM/@03o`000?o4
X;Coa:2d00?oa:2d00?o0000olBM/Oo4WK402_o4WK401?l0003oa:2dolBP]?l0000?olBM/@03o`00
0?o4WK7oa9fa00coa9fa00Co0000olBK[_o4Vjko00002oo4WK400ol0003oa9^^olBK[P03olBK[P03
o`000?o4WK7oa9fa00Ooa9fa00Co0000olBK[_o4Vjkoa9^^4_l0000<ofS<o@03o`000?nDd_goU=;m
00_oU=;m00?o0000ojc<lOn/c?401On/c?45o`000003oiCBoOl0003o000000?oVAP60_l00009oj@/
7P03o`000?n[>S3o000000WoY2`O00?o0000oj/j<?n[>S000on[>S000ol0003oooooooooo`02oooo
o`03o`000?oooooooooo013ooooo000@ooooo`;o00005?ooool3o`0000Oooooo00?o0000ol>P]?o3
X;@01Oo3X;@00ol0003o`j>hol>S^006ol>S^003o`000?o3X;Co`j2d00Wo`j2d00Go0000ol>S^?o3
XkSo`j>ho`00000@ol>P]003o`000?o3X;Co`j2d00go`j2d00Co0000olBM/Oo4WK7o00003?o3X;@0
0ol0003oa9faolBM/@03olBM/@03o`000?o3X;Co`j2d00Oo`j2d00?o0000olBM/Oo4WK401_o4WK40
0ol0003oa:2dolBP]004olBP]003o`000?o4WK7oa9fa00Woa9fa00Go0000olBP]?o4X;Coa:2do`00
000?olBM/@03o`000?o4WK7oa9fa00coa9fa00Co0000olBK[_o4Vjko00003?o4WK400ol0003oa9^^
olBK[P02olBK[P03o`000?o4WK7oa9fa00Ooa9fa00?o0000olBK[_o4Vjh01Oo4Vjh00ol0003oa9fa
o`000005o`0000Go8J[L0_l0000<ofS<o@03o`000?nDd_goU=;m00_oU=;m00?o0000ojc<lOn/c?40
1?l00007oiCBo@;o00001?nI60H2o`0000SoY2`N0_l0000:oj@/7`03o`000?n[>S3oZcX`00;oZcX`
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0@ooooo`003oooool00ol0003ooooooooo
o`0Booooo`;o00002oooool00ol0003o`j2dol>P]004ol>P]003o`000?o3XkSo`j>h00Ko`j>h00?o
0000ol>P]?o3X;@02?o3X;@00ol0003o`j>hol>S^003ol>S^003o`000?o3X;Co`j2d00co`j2d00?o
0000ol>S^?l000003oo3X;@2o`0000ko`j2d00Go0000olBM/Oo4WK7oa9fao`00000;ol>P]003o`00
0?o4WK7oa9fa00Coa9fa00?o0000olBP]?o4X;@01_o4X;@00ol0003oa9faolBM/@07olBM/@03o`00
0?o4X;Coa:2d00?oa:2d00?o0000olBM/Oo4WK402oo4WK42o`0000ooa9fa0_l0000=olBM/@05o`00
0?o4Vjkoa9^^olBK[_l000002_o4WK400ol0003oa9^^olBK[P04olBK[P03o`000?o4WK7oa9fa00Go
a9fa1ol000000olQZ]co0000ofS<o@0;ofS<o@03o`000?nDd_goU=;m00GoU=;m2?l0000<oiCBo@;o
00001OnI60H00ol0003oY2`Noj@/7P05oj@/7P04o`000?nI60Ko0000o`0000WoY2`O0_l00002oj/j
<003o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool000oooooo00?o0000oooooooo
ool03oooool3o`0000gooooo00?o0000ol>P]?o3X;@00oo3X;@00ol0003o`j>hol>S^008ol>S^003
o`000?o3X;Co`j2d00Ko`j2d00?o0000ol>S^?o3XkP01?o3XkP00ol0003o`j2dol>P]00;ol>P]004
o`000?o3XkSo`j>ho`0000oo`j2d00?o0000ol>P]?o3X;@03Oo3X;@01?l0003oa9faolBM/Ol0000<
ol>P]003o`000?o4WK7oa9fa00?oa9fa00?o0000olBP]?o4X;@01oo4X;@00ol0003oa9faolBM/@07
olBM/@03o`000?o4X;Coa:2d00?oa:2d00?o0000olBM/Oo4WK402_o4WK401?l0003oa:2dolBP]?l0
000>olBM/@03o`000?o4WK7oa9fa00coa9fa00Co0000olBK[_o4Vjko00002oo4WK400ol0003oa9^^
olBK[P03olBK[P03o`000?o4WK7oa9fa00Ooa9fa00?o0000olBK[_o4Vjh00oo4VjhFo`0000SoIlcl
00?o0000oiCBoOnDd_d02OnDd_d00ol0003oU=;mo`000005oiTH1P;o00001?nT;1h00ol0003oVAP6
oiTH1P02oiTH1P;o00002OnT;1l2o`0000Gooooo00?o0000ooooooooool04?ooool000oooooo00?o
0000ooooooooool03?ooool3o`00017ooooo00Go0000ol>P]?o3X;Co`j2do`00000;ol>S^003o`00
0?o3X;Co`j2d00Go`j2d00?o0000ol>S^?o3XkP01Oo3XkP00ol0003o`j2dol>P]00:ol>P]005o`00
0?o3XkSo`j>hol>S^?l000003oo3X;@00ol0003o`j2dol>P]00=ol>P]003o`000?o4WK7o000000go
`j2d00?o0000olBM/Oo4WK400oo4WK400ol0003oa:2dolBP]007olBP]003o`000?o4WK7oa9fa00Ko
a9fa00?o0000olBP]?o4X;@01?o4X;@00ol0003oa9faolBM/@09olBM/@05o`000?o4X;Coa:2dolBP
]?l000003_o4WK400ol0003oa9faolBM/@0<olBM/@04o`000?o4Vjkoa9^^o`0000coa9fa00?o0000
olBK[_o4Vjh00_o4Vjh00ol0003oa9faolBM/@07olBM/@03o`000?o4Vjkoa9^^00Coa9^^00?o0000
olBM/Oo4WK400_o4WK45o`0000Ko8:WK0_l0000<ofO<o003o`000?nDd_goU=;m00WoU=;m00?o0000
oiCBoOl000001_nI60H2o`000003oj@/7_l0003oVAP600KoVAP60_l00008oj@/7`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool04?ooool000oooooo00?o0000ooooooooool02Oooool3o`00
01Cooooo00Co0000ol>P]?o3X;Co00003Oo3XkP00ol0003o`j2dol>P]004ol>P]003o`000?o3XkSo
`j>h00Ko`j>h00?o0000ol>P]?o3X;@02?o3X;@00ol0003o`j>hol>S^003ol>S^003o`000?o3X;Co
`j2d00_o`j2d00?o0000ol>S^?l000003oo3X;@00ol0003o`j2dol>P]00=ol>P]005o`000?o4WK7o
a9faolBM/Ol000002oo4X;@00ol0003oa9faolBM/@04olBM/@03o`000?o4X;Coa:2d00Koa:2d00?o
0000olBM/Oo4WK401oo4WK400ol0003oa:2dolBP]002olBP]003o`000?o4WK7oa9fa00_oa9fa00?o
0000olBP]?l000003_o4WK42o`0000goa9fa00Go0000olBK[_o4Vjkoa9^^o`00000:olBM/@03o`00
0?o4Vjkoa9^^00?oa9^^00?o0000olBM/Oo4WK401_o4WK400ol0003oa9^^o`000006o`000003ob2Y
fol0003oIlcl00_oIlcl00?o0000oiCBoOnDd_d01OnDd_d8o`0000GoVAP60ol00009oiTH1P03o`00
0?nT;1ooY2`O00GoY2`O00?o0000ooooooooool00oooool00ol0003oooooooooo`0@ooooo`003ooo
ool3o`0000Kooooo0ol0000Gooooo`03o`000?o3X;Co000000ko`j>h00?o0000ol>P]?o3X;@00oo3
X;@00ol0003o`j>hol>S^007ol>S^003o`000?o3X;Co`j2d00Oo`j2d00?o0000ol>S^?o3XkP01?o3
XkP00ol0003o`j2dol>P]00:ol>P]004o`000?o3XkSo`j>ho`0000oo`j2d00?o0000ol>P]?o3X;@0
3Oo3X;@01?l0003oa9faolBM/Ol0000<olBP]003o`000?o4WK7oa9fa00?oa9fa00?o0000olBP]?o4
X;@01oo4X;@00ol0003oa9faolBM/@07olBM/@03o`000?o4X;Coa:2d00?oa:2d00?o0000olBM/Oo4
WK402Oo4WK401?l0003oa:2dolBP]?l0000>olBM/@03o`000?o4WK7oa9fa00coa9fa00Co0000olBK
[_o4Vjko00002oo4WK400ol0003oa9^^olBK[P03olBK[P03o`000?o4WK7oa9fa00Koa9fa00?o0000
olBK[_o4Vjh01_o4VjhFo`0000GoIlcl00Co0000ofO<o?mWc?co00000onI60H01?l0003oQ`00ohL0
0?n70002o`0000SoVAP60_l00004oj@/7`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
4?ooool000oooooo00?o0000ooooooooool00oooool3o`0001_ooooo00?o0000ol>S^?o3XkP03Oo3
XkP00ol0003o`j2dol>P]002ol>P]003o`000?o3XkSo`j>h00Wo`j>h00?o0000ol>P]?o3X;@01Oo3
X;@00ol0003o`j>hol>S^005ol>S^003o`000?o3X;Co`j2d00Wo`j2d00Go0000ol>S^?o3XkSo`j>h
o`00000>ol>P]003o`000?o3XkSo000000ko`j2d00?o0000olBM/Ol000003Oo4X;@00ol0003oa9fa
olBM/@03olBM/@03o`000?o4X;Coa:2d00Ooa:2d00?o0000olBM/Oo4WK401_o4WK400ol0003oa:2d
olBP]004olBP]003o`000?o4WK7oa9fa00Soa9fa00Go0000olBP]?o4X;Coa:2do`00000>olBM/@03
o`000?o4WK7oa9fa00coa9fa00Co0000olBK[_o4Vjko00003?o4WK401Ol0003oa9^^olBK[_o4Vjko
000000[oa9fa00?o0000olBK[_o4Vjh01?o4Vjh00ol0003oa9faolBM/@04olBM/@Go00001_lOZ=X2
o`0000SoIlcl00Oo0000ofO<o?mWc?coIlclo`000?nI60Ko000000KoQ`000_l00008oiTH1P;o0000
00?oY2`Oo`000?ooool01oooool00ol0003oooooooooo`0?ooooo`001Oooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Cooooo00Co0000oooooooooooooooo0ol0000Nooooo`03o`000?o3XkSo`j>h00ko
`j>h00Co0000ol>P]?o3X;Co00003?o3XkP00ol0003o`j2dol>P]004ol>P]003o`000?o3XkSo`j>h
00Oo`j>h00?o0000ol>P]?o3X;@01oo3X;@00ol0003o`j>hol>S^003ol>S^003o`000?o3X;Co`j2d
00[o`j2d00Co0000ol>S^?o3XkSo00003oo3X;@00ol0003oa:2dolBP]00=olBP]005o`000?o4WK7o
a9faolBM/Ol000002oo4X;@00ol0003oa9faolBM/@04olBM/@03o`000?o4X;Coa:2d00Goa:2d00?o
0000olBM/Oo4WK401oo4WK400ol0003oa:2dolBP]003olBP]003o`000?o4WK7oa9fa00[oa9fa00?o
0000olBP]?l000003_o4WK42o`0000goa9fa00Co0000olBK[_o4Vjko00002oo4WK400ol0003oa9^^
olBK[P03olBK[P03o`000?o4WK7oa9fa00Koa9fa00Co0000olBK[_o4Vjkoa9^^1ol000000olOZ=[o
0000ofO<o007ofO<o004o`000?mWc?coIlclofO<o0;o00002?n70003o`0000OoVAP600?o0000oooo
ooooool01oooool00ol0003oooooooooo`0?ooooo`002?ooool00omgMgOo<S8booooo`03ooooo`Co
00008_ooool00ol0003o`j>hol>S^00=ol>S^003o`000?o3X;Co000000go`j>h00?o0000ol>P]?o3
X;@00oo3X;@00ol0003o`j>hol>S^008ol>S^003o`000?o3X;Co`j2d00Ko`j2d00?o0000ol>S^?o3
XkP01?o3XkP00ol0003o`j2dol>P]009ol>P]005o`000?o3XkSo`j>hol>S^?l000003oo3X;@00ol0
003oa:2dolBP]00=olBP]004o`000?o4WK7oa9fao`0000coa:2d00?o0000olBM/Oo4WK400oo4WK40
0ol0003oa:2dolBP]007olBP]003o`000?o4WK7oa9fa00Koa9fa00?o0000olBP]?o4X;@00oo4X;@0
0ol0003oa9faolBM/@09olBM/@04o`000?o4X;Coa:2do`0000koa9fa00?o0000olBM/Oo4WK403?o4
WK401?l0003oa9^^olBK[_l0000;olBM/@03o`000?o4Vjkoa9^^00?oa9^^00?o0000olBM/Oo4WK40
1_o4WK400ol0003oa9^^olBK[P06olBK[P03o`000?o4WK7o000001;o00002?n70002o`0000CoVAP6
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0?ooooo`002Oooool00ol0003ooooooooo
o`02ooooo`;o00009?ooool00ol0003o`j>hol>S^00=ol>S^0;o00003oo3XkP01Ol0003o`j2dol>P
]?o3X;Co000000co`j>h00?o0000ol>P]?o3X;@01?o3X;@00ol0003o`j>hol>S^006ol>S^003o`00
0?o3X;Co`j2d00Oo`j2d00?o0000ol>S^?o3XkP00oo3XkP00ol0003o`j2dol>P]00;ol>P]003o`00
0?o3XkSo000000koa:2d00?o0000olBM/Ol000003Oo4X;@00ol0003oa9faolBM/@03olBM/@03o`00
0?o4X;Coa:2d00Ooa:2d00?o0000olBM/Oo4WK401Oo4WK400ol0003oa:2dolBP]004olBP]003o`00
0?o4WK7oa9fa00Soa9fa00Go0000olBP]?o4X;Coa:2do`00000>olBM/@03o`000?o4WK7oa9fa00go
a9fa0_l0000=olBM/@05o`000?o4Vjkoa9^^olBK[_l000002_o4WK400ol0003oa9^^olBK[P04olBK
[P03o`000?o4WK7oa9fa00Coa9fa1_l000000olNZ=Wo0000oajXf@04oajXf@03o`000?mW003o0000
00;o00001on70002o`000003oiTH1_l0003ooooo00[ooooo00?o0000ooooooooool03oooool000So
oooo00?oMgMgoc8b<_ooool01Oooool00ol0003oooooooooo`0Rooooo`03o`000?o3XkSo`j>h00_o
`j>h00?o0000ol>V_Ol000003oo3XkP01?l0003o`j2dol>P]?l0000=ol>S^003o`000?o3X;Co`j2d
00Co`j2d00?o0000ol>S^?o3XkP01_o3XkP00ol0003o`j2dol>P]006ol>P]003o`000?o3XkSo`j>h
00Co`j>h00?o0000ol>P]?o3X;@02_o3X;@01?l0003o`j>hol>S^?l0000?olBP]003o`000?o4X;Co
a:2d00goa:2d00Go0000olBM/Oo4WK7oa9fao`00000:olBP]003o`000?o4WK7oa9fa00Coa9fa00?o
0000olBP]?o4X;@01_o4X;@00ol0003oa9faolBM/@07olBM/@03o`000?o4X;Coa:2d00;oa:2d00?o
0000olBM/Oo4WK402_o4WK400ol0003oa:2do`00000>olBM/@03o`000?o4WK7oa9fa00coa9fa00Co
0000olBK[_o4Vjko00002oo4WK400ol0003oa9^^olBK[P03olBK[P03o`000?o4WK7oa9fa00Goa9fa
00?o0000olBK[_o4Vjh00oo4Vjh7o`000003oajXfOl0003oI`0000;oI`000_l00006ohL000;o0000
3?ooool00ol0003oooooooooo`0?ooooo`001Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Oooooo
00?o0000ooooooooool08Oooool00ol0003o`j>hol>S^00:ol>S^005o`000?o3Y[go`jJmol>V_Ol0
00003_o3XkP00ol0003o`j2do`00000>ol>S^003o`000?o3X;Co`j2d00?o`j2d00?o0000ol>S^?o3
XkP01oo3XkP00ol0003o`j2dol>P]005ol>P]003o`000?o3XkSo`j>h00Go`j>h00?o0000ol>P]?o3
X;@02Oo3X;@01Ol0003o`j>hol>S^?o3XkSo000000ooa:2d00?o0000olBP]?o4X;@03Oo4X;@01?l0
003oa9faolBM/Ol0000;olBP]003o`000?o4WK7oa9fa00?oa9fa00?o0000olBP]?o4X;@01oo4X;@0
0ol0003oa9faolBM/@06olBM/@03o`000?o4X;Coa:2d00?oa:2d00?o0000olBM/Oo4WK402Oo4WK40
1?l0003oa:2dolBP]?l0000>olBM/@03o`000?o4WK7oa9fa00coa9fa00Co0000olBK[_o4Vjko0000
2oo4WK400ol0003oa9^^olBK[P03olBK[P03o`000?o4WK7oa9fa00Koa9fa00?o0000olBK[_o4Vjh0
1Oo4Vjh01?l0003oa9faolBM/Oo4WK45o`0000;oI`000ol000000on7003o0000o`00000>ooooo`03
o`000?oooooooooo00oooooo0005ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
8?ooool00ol0003o`j>hol>S^009ol>S^003o`000?o3Y[go`jJm00;o`jJm00?o0000ol>S^?o3XkP0
3Oo3XkP00ol0003o`j>hol>S^00>ol>S^005o`000?o3X;Co`j2dol>P]?l000002oo3XkP00ol0003o
`j2dol>P]004ol>P]003o`000?o3XkSo`j>h00Ko`j>h00?o0000ol>P]?o3X;@01oo3X;@00ol0003o
`j>hol>S^003ol>S^003o`000?o4X;Coa:2d00_oa:2d00?o0000ol>S^?l000003_o4X;@00ol0003o
a9fao`00000=olBP]003o`000?o4WK7oa9fa00;oa9fa00?o0000olBP]?o4X;@01oo4X;@00ol0003o
a9faolBM/@05olBM/@03o`000?o4X;Coa:2d00Coa:2d00?o0000olBM/Oo4WK402?o4WK401Ol0003o
a:2dolBP]?o4X;Co000000goa9fa00?o0000olBP]?l000003_o4WK42o`0000goa9fa00Go0000olBK
[_o4Vjkoa9^^o`000009olBM/@03o`000?o4Vjkoa9^^00Coa9^^00?o0000olBM/Ol000001Oo4WK40
0ol0003oa9^^o`000005o`000003olBK[_l0003ooooo00gooooo00?o0000ooooooooool03oooool0
00Gooooo00?o0000ooooooooool02oooool2o`00027ooooo00?o0000ol>S^?o3XkP01oo3XkP00ol0
003o`jJmol>V_@04ol>V_@03o`000?o3XkSo`j>h00_o`j>h0_l0000@ol>S^004o`000?o3X;Co`j2d
o`0000co`j>h00?o0000ol>P]?o3X;@00oo3X;@00ol0003o`j>hol>S^007ol>S^003o`000?o3X;Co
`j2d00Ko`j2d00?o0000ol>S^?o3XkP01?o3XkP00ol0003oa:2dolBP]00:olBP]004o`000?o3XkSo
`j>ho`0000ooa:2d00?o0000olBP]?o4X;@03?o4X;@01Ol0003oa9faolBM/Oo4WK7o000000_oa:2d
00?o0000olBM/Oo4WK401?o4WK400ol0003oa:2dolBP]005olBP]003o`000?o4WK7oa9fa00Ooa9fa
00?o0000olBP]?o4X;@00_o4X;@00ol0003oa9faolBM/@09olBM/@04o`000?o4X;Coa:2do`0000ko
a9fa00?o0000olBM/Oo4WK403?o4WK401?l0003oa9^^olBK[_l0000:olBM/@03o`000?o4Vjkoa9^^
00?oa9^^00Co0000olBM/Oo4WK7o00001Oo4WK400ol0003oa9^^olBK[P05olBK[P03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03_ooool000Gooooo1?l0000<ooooo`03o`000?oooooooooo
01kooooo00?o0000ol>S^?o3XkP01_o3XkP00ol0003o`jJmol>V_@05ol>V_@03o`000?o3XkSo`j>h
00[o`j>h00Co0000ol>V_Oo3Y[go00003oo3XkP00ol0003o`j2do`00000>ol>S^005o`000?o3X;Co
`j2dol>P]?l000002oo3XkP00ol0003o`j2dol>P]004ol>P]003o`000?o3XkSo`j>h00Go`j>h00?o
0000olBP]?o4X;@02Oo4X;@01Ol0003o`j>hol>S^?o3XkSo000000ooa:2d00?o0000olBP]?o4X;@0
3?o4X;@01?l0003oa9faolBM/Ol0000<olBP]003o`000?o4WK7oa9fa00?oa9fa00?o0000olBP]?o4
X;@01_o4X;@00ol0003oa9faolBM/@06olBM/@03o`000?o4X;Coa:2d00?oa:2d00?o0000olBM/Oo4
WK402?o4WK401Ol0003oa:2dolBP]?o4X;Co000000koa9fa00?o0000olBM/Oo4WK403?o4WK401?l0
003oa9^^olBK[_l0000:olBM/@03o`000?o4Vjkoa9^^00?oa9^^00Go0000olBM/Oo4WK7oa9fao`00
0004olBM/@03o`000?o4Vjkoa9^^00Coa9^^00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0>ooooo`005_ooool00ol0003oooooooooo`0Nooooo`03o`000?o3XkSo`j>h00Co`j>h00?o0000
ol>V_Oo3Y[d01_o3Y[d00ol0003o`j>hol>S^009ol>S^005o`000?o3Y[go`jJmol>V_Ol000004?o3
XkP00ol0003o`j>hol>S^00=ol>S^004o`000?o3X;Co`j2do`0000co`j>h00?o0000ol>P]?o3X;@0
1?o3X;@00ol0003o`j>hol>S^006ol>S^003o`000?o4X;Coa:2d00Ooa:2d00?o0000ol>S^?o3XkP0
0oo3XkP00ol0003oa:2dolBP]00;olBP]003o`000?o3XkSo000000koa:2d0_l0000=olBP]003o`00
0?o4WK7oa9fa00;oa9fa00?o0000olBP]?o4X;@01oo4X;@00ol0003oa9faolBM/@05olBM/@03o`00
0?o4X;Coa:2d00Coa:2d00?o0000olBM/Oo4WK402?o4WK400ol0003oa:2dolBP]002olBP]003o`00
0?o4WK7oa9fa00[oa9fa00?o0000olBP]?l000003_o4WK42o`0000coa9fa00Go0000olBK[_o4Vjko
a9^^o`000005olBM/@03o`000?o4WK7oa9fa00;oa9fa00?o0000olBK[_o4Vjh00oo4Vjh00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00kooooo000Gooooo`03o`000?oooooooooo01gooooo
00?o0000ol>S^?o3XkP00oo3XkP00ol0003o`jJmol>V_@08ol>V_@03o`000?o3XkSo`j>h00Oo`j>h
00?o0000ol>V_Oo3Y[d00oo3Y[d00ol0003o`j>hol>S^00<ol>S^0;o00003oo3XkP00ol0003o`j2d
o`00000=ol>S^003o`000?o3X;Co`j2d00?o`j2d00?o0000ol>S^?o3XkP01oo3XkP00ol0003oa:2d
olBP]006olBP]003o`000?o3XkSo`j>h00Co`j>h00?o0000olBP]?o4X;@02_o4X;@01?l0003o`j>h
ol>S^?l0000>olBP]003o`000?o4X;Coa:2d00goa:2d00Co0000olBM/Oo4WK7o00002oo4X;@00ol0
003oa9faolBM/@04olBM/@03o`000?o4X;Coa:2d00Goa:2d00?o0000olBM/Oo4WK401_o4WK400ol0
003oa:2dolBP]003olBP]003o`000?o4WK7oa9fa00Woa9fa00Co0000olBP]?o4X;Co00003_o4WK40
0ol0003oa9faolBM/@0;olBM/@04o`000?o4Vjkoa9^^o`0000Ooa9fa00Go0000olBM/Oo4WK7oa9fa
o`000004olBK[P03o`000?oooooooooo013ooooo00?o0000ooooooooool03_ooool001Sooooo0_l0
000Nooooo`05o`000?o3XkSo`j>hol>S^?l000002oo3Y[d00ol0003o`j>hol>S^006ol>S^003o`00
0?o3Y[go`jJm00Co`jJm00?o0000ol>S^?o3XkP02oo3XkP01?l0003o`jJmol>V_Ol0000?ol>S^003
o`000?o3XkSo`j>h00go`j>h00Go0000ol>P]?o3X;Co`j2do`00000;ol>S^003o`000?o4X;Coa:2d
00Coa:2d00?o0000ol>S^?o3XkP01Oo3XkP00ol0003oa:2dolBP]009olBP]005o`000?o3XkSo`j>h
ol>S^?l000003_o4X;@00ol0003oa:2dolBP]00=olBP]004o`000?o4WK7oa9fao`0000_oa:2d00?o
0000olBM/Oo4WK400oo4WK400ol0003oa:2dolBP]006olBP]003o`000?o4WK7oa9fa00Goa9fa00?o
0000olBP]?o4X;@01?o4X;@00ol0003oa9faolBM/@08olBM/@05o`000?o4X;Coa:2dolBP]?l00000
3_o4WK400ol0003oa9faolBM/@0;olBM/@04o`000?o4Vjkoa9^^o`0000Ooa9fa00Go0000olBM/Oo4
WK7oa9fao`000004olBK[P03o`000?oooooooooo013ooooo00?o0000ooooooooool03_ooool001[o
oooo00?o0000ooooooooool06oooool01?l0003o`j>hol>S^?l0000=ol>V_@03o`000?o3XkSo`j>h
00Co`j>h00?o0000ol>V_Oo3Y[d01_o3Y[d00ol0003o`j>hol>S^009ol>S^005o`000?o3Y[go`jJm
ol>V_Ol000003oo3XkP00ol0003o`j>hol>S^00=ol>S^004o`000?o3X;Co`j2do`0000co`j>h00?o
0000olBP]?o4X;@01?o4X;@00ol0003o`j>hol>S^006ol>S^003o`000?o4X;Coa:2d00Ooa:2d00?o
0000ol>S^?o3XkP00oo3XkP00ol0003oa:2dolBP]00:olBP]003o`000?o3XkSo000000koa:2d00?o
0000olBM/Ol000003?o4X;@00ol0003oa9faolBM/@02olBM/@03o`000?o4X;Coa:2d00Soa:2d00?o
0000olBM/Oo4WK401?o4WK400ol0003oa:2dolBP]005olBP]003o`000?o4WK7oa9fa00Ooa9fa00?o
0000olBP]?o4X;@00_o4X;@00ol0003oa9faolBM/@0:olBM/@;o00003_o4WK42o`0000Woa9fa00Go
0000olBM/Oo4WK7oa9fao`000002olBK[P03o`000?oooooooooo017ooooo00?o0000ooooooooool0
3_ooool001_ooooo00?o0000ooooooooool06_ooool00ol0003o`j>ho`00000>ol>V_@03o`000?o3
XkSo`j>h00?o`j>h00?o0000ol>V_Oo3Y[d01oo3Y[d00ol0003o`j>hol>S^008ol>S^003o`000?o3
Y[go`jJm00?o`jJm00?o0000ol>S^?o3XkP02oo3XkP00ol0003o`jJmo`00000>ol>S^003o`000?o3
X;Co000000go`j>h00?o0000olBP]?o4X;@00oo4X;@00ol0003o`j>hol>S^007ol>S^003o`000?o4
X;Coa:2d00Koa:2d00?o0000ol>S^?o3XkP01?o3XkP00ol0003oa:2dolBP]009olBP]004o`000?o3
XkSo`j>ho`0000ooa:2d00?o0000olBP]?o4X;@03?o4X;@01?l0003oa9faolBM/Ol0000;olBP]003
o`000?o4WK7oa9fa00?oa9fa00?o0000olBP]?o4X;@01_o4X;@00ol0003oa9faolBM/@06olBM/@03
o`000?o4X;Coa:2d00?oa:2d00?o0000olBM/Oo4WK402Oo4WK401?l0003oa:2dolBP]?l0000=olBM
/@03o`000?o4WK7oa9fa00Woa9fa00Ko0000olBM/Oo4WK7o0000olBK[_l0000Dooooo`03o`000?oo
oooooooo00kooooo000Looooo`03o`000?oooooooooo01[ooooo00?o0000ol>V_Oo3Y[d03_o3Y[d0
1Ol0003o`j>hol>S^?o3XkSo000000_o`jJm00?o0000ol>S^?o3XkP01_o3XkP00ol0003o`jJmol>V
_@04ol>V_@03o`000?o3XkSo`j>h00[o`j>h00Co0000ol>V_Oo3Y[go00003oo3XkP00ol0003o`j>h
ol>S^00=ol>S^005o`000?o4X;Coa:2dolBP]?l000002oo3XkP00ol0003oa:2dolBP]004olBP]003
o`000?o3XkSo`j>h00Go`j>h00?o0000olBP]?o4X;@02?o4X;@01Ol0003o`j>hol>S^?o3XkSo0000
00ooa:2d00?o0000olBP]?o4X;@03?o4X;@01?l0003oa9faolBM/Ol0000;olBP]003o`000?o4WK7o
a9fa00;oa9fa00?o0000olBP]?o4X;@01oo4X;@00ol0003oa9faolBM/@05olBM/@03o`000?o4X;Co
a:2d00Coa:2d00?o0000olBM/Oo4WK402?o4WK401Ol0003oa:2dolBP]?o4X;Co000000goa9fa00?o
0000olBM/Oo4WK402_o4WK401Ol0003oa9fao`000?o4Vjko000001Gooooo00?o0000ooooooooool0
3Oooool001gooooo0_l0000Jooooo`03o`000?o3Y[go`jJm00ko`jJm00Co0000ol>S^?o3XkSo0000
3?o3Y[d00ol0003o`j>hol>S^005ol>S^003o`000?o3Y[go`jJm00Go`jJm00?o0000ol>S^?o3XkP0
2Oo3XkP01Ol0003o`jJmol>V_Oo3Y[go000000oo`j>h00?o0000ol>S^?o3XkP03Oo3XkP01?l0003o
a:2dolBP]?l0000<ol>S^003o`000?o4X;Coa:2d00Coa:2d00?o0000ol>S^?o3XkP01_o3XkP00ol0
003oa:2dolBP]007olBP]003o`000?o3XkSo`j>h00;o`j>h00?o0000olBP]?o4X;@02oo4X;@00ol0
003o`j>ho`00000=olBP]003o`000?o4WK7o000000goa:2d00Co0000olBM/Oo4WK7o00002oo4X;@0
0ol0003oa9faolBM/@04olBM/@03o`000?o4X;Coa:2d00Goa:2d00?o0000olBM/Oo4WK401oo4WK40
1Ol0003oa:2dolBP]?o4X;Co000000coa9fa00?o0000olBP]?l000002oo4WK401?l0003oa9faolBM
/Ol0000Fooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo01Sooooo00?o
0000ol>V_Oo3Y[d03Oo3Y[d00ol0003o`j>ho`00000>ol>V_@03o`000?o3XkSo`j>h00?o`j>h00?o
0000ol>V_Oo3Y[d01oo3Y[d00ol0003o`j>hol>S^007ol>S^003o`000?o3Y[go`jJm00?o`jJm00?o
0000ol>S^?o3XkP02oo3XkP00ol0003o`jJmo`00000>ol>S^003o`000?o4X;Co000000go`j>h00?o
0000olBP]?o4X;@00oo4X;@00ol0003o`j>hol>S^007ol>S^003o`000?o4X;Coa:2d00Koa:2d00?o
0000ol>S^?o3XkP00oo3XkP00ol0003oa:2dolBP]00:olBP]004o`000?o3XkSo`j>ho`0000koa:2d
00?o0000olBP]?o4X;@03?o4X;@01?l0003oa9faolBM/Ol0000;olBP]003o`000?o4WK7oa9fa00?o
a9fa00?o0000olBP]?o4X;@01_o4X;@00ol0003oa9faolBM/@06olBM/@03o`000?o4X;Coa:2d00?o
a:2d00?o0000olBM/Oo4WK402?o4WK401?l0003oa:2dolBP]?l0000<olBM/@03o`000?o4WK7o0000
01Kooooo00?o0000ooooooooool03Oooool0023ooooo00?o0000ooooooooool05oooool00ol0003o
`jJmol>V_@0=ol>V_@;o00003oo3Y[d00ol0003o`j>hol>S^002ol>S^003o`000?o3Y[go`jJm00So
`jJm00?o0000ol>S^?o3XkP01_o3XkP00ol0003o`jJmol>V_@04ol>V_@03o`000?o3XkSo`j>h00[o
`j>h00Co0000ol>V_Oo3Y[go00003oo3XkP00ol0003o`j>hol>S^00=ol>S^005o`000?o4X;Coa:2d
olBP]?l000002oo3XkP00ol0003oa:2dolBP]004olBP]003o`000?o3XkSo`j>h00Go`j>h00?o0000
olBP]?o4X;@02?o4X;@01Ol0003o`j>hol>S^?o3XkSo000000koa:2d00?o0000olBP]?o4X;@03?o4
X;@00ol0003oa9fao`00000<olBP]003o`000?o4WK7oa9fa00;oa9fa00?o0000olBP]?o4X;@01oo4
X;@00ol0003oa9faolBM/@05olBM/@03o`000?o4X;Coa:2d00Coa:2d00?o0000olBM/Oo4WK401oo4
WK401Ol0003oa:2dolBP]?o4X;Co000000goa9fa00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0=ooooo`008Oooool00ol0003oooooooooo`0Gooooo`03o`000?o3Y[go`jJm00_o`jJm00?o
0000ol:[`ol000004?o3Y[d01?l0003o`j>hol>S^?l0000<ol>V_@03o`000?o3XkSo`j>h00Co`j>h
00?o0000ol>V_Oo3Y[d01_o3Y[d00ol0003o`j>hol>S^008ol>S^005o`000?o3Y[go`jJmol>V_Ol0
00003oo3XkP00ol0003o`j>hol>S^00=ol>S^004o`000?o4X;Coa:2do`0000co`j>h00?o0000olBP
]?o4X;@00oo4X;@00ol0003o`j>hol>S^006ol>S^003o`000?o4X;Coa:2d00Ooa:2d00?o0000ol>S
^?o3XkP00oo3XkP00ol0003oa:2dolBP]00:olBP]003o`000?o3XkSo000000koa:2d00?o0000olBP
]?o4X;@03?o4X;@01?l0003oa9faolBM/Ol0000;olBP]003o`000?o4WK7oa9fa00Coa9fa00?o0000
olBP]?o4X;@01?o4X;@00ol0003oa9faolBM/@07olBM/@03o`000?o4X;Coa:2d00;oa:2d00?o0000
olBM/Oo4WK402Oo4WK42o`0001Oooooo00?o0000ooooooooool03Oooool002;ooooo0_l0000Goooo
o`03o`000?o3Y[go`jJm00[o`jJm00Go0000ol:[`oo2Zl?o`Z_3o`00000?ol>V_@03o`000?o3XkSo
000000go`jJm00?o0000ol>S^?o3XkP00oo3XkP00ol0003o`jJmol>V_@07ol>V_@03o`000?o3XkSo
`j>h00Oo`j>h00?o0000ol>V_Oo3Y[d00oo3Y[d00ol0003o`j>hol>S^00;ol>S^003o`000?o3Y[go
000000ko`j>h00?o0000olBP]?l000003Oo3XkP00ol0003oa:2dolBP]002olBP]003o`000?o3XkSo
`j>h00Oo`j>h00?o0000olBP]?o4X;@01_o4X;@00ol0003o`j>hol>S^004ol>S^003o`000?o4X;Co
a:2d00Woa:2d00Co0000ol>S^?o3XkSo00003_o4X;@00ol0003oa:2dolBP]00<olBP]004o`000?o4
WK7oa9fao`0000_oa:2d00?o0000olBM/Oo4WK400oo4WK400ol0003oa:2dolBP]006olBP]003o`00
0?o4WK7oa9fa00Goa9fa00?o0000olBP]?o4X;@00oo4X;@00ol0003oa9faolBM/@08olBM/@04o`00
0?ooooooooooo`0001Kooooo00?o0000ooooooooool03Oooool002Cooooo00?o0000ooooooooool0
5Oooool00ol0003o`jJmol>V_@08ol>V_@03o`000?o2Zl?o`Z_300;o`Z_300?o0000ol>V_Oo3Y[d0
3Oo3Y[d2o`0000oo`jJm00Go0000ol>S^?o3XkSo`j>ho`00000:ol>V_@03o`000?o3XkSo`j>h00Ko
`j>h00?o0000ol>V_Oo3Y[d01?o3Y[d00ol0003o`j>hol>S^00:ol>S^004o`000?o3Y[go`jJmo`00
00oo`j>h00?o0000ol>S^?o3XkP03Oo3XkP01Ol0003oa:2dolBP]?o4X;Co000000[o`j>h00?o0000
olBP]?o4X;@01?o4X;@00ol0003o`j>hol>S^005ol>S^003o`000?o4X;Coa:2d00Soa:2d00Go0000
ol>S^?o3XkSo`j>ho`00000=olBP]003o`000?o3XkSo000000goa:2d00?o0000olBM/Ol000003?o4
X;@00ol0003oa9faolBM/@02olBM/@03o`000?o4X;Coa:2d00Ooa:2d00?o0000olBM/Oo4WK401?o4
WK400ol0003oa:2dolBP]004olBP]003o`000?o4WK7oa9fa00Soa9fa00Go0000oooooooooooooooo
o`00000Eooooo`03o`000?oooooooooo00gooooo000Uooooo`03o`000?oooooooooo01Gooooo00?o
0000ol>V_Oo3Y[d01_o3Y[d00ol0003o`Z_3ol:[``04ol:[``03o`000?o3Y[go`jJm00_o`jJm00?o
0000ol:[`ol000003oo3Y[d01?l0003o`j>hol>S^?l0000<ol>V_@03o`000?o3XkSo`j>h00Co`j>h
00?o0000ol>V_Oo3Y[d01_o3Y[d00ol0003o`j>hol>S^008ol>S^003o`000?o3Y[go`jJm00;o`jJm
00?o0000ol>S^?o3XkP02oo3XkP2o`0000oo`j>h00Co0000olBP]?o4X;Co00002oo3XkP00ol0003o
a:2dolBP]003olBP]003o`000?o3XkSo`j>h00Oo`j>h00?o0000olBP]?o4X;@01_o4X;@00ol0003o
`j>hol>S^003ol>S^003o`000?o4X;Coa:2d00Woa:2d00Co0000ol>S^?o3XkSo00003_o4X;@00ol0
003oa:2dolBP]00<olBP]004o`000?o4WK7oa9fao`0000[oa:2d00?o0000olBM/Oo4WK400oo4WK40
0ol0003oa:2dolBP]006olBP]003o`000?o4WK7oa9fa00Koa9fa00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00cooooo000Vooooo`03o`000?oooooooooo
01Cooooo00?o0000ol>V_Oo3Y[d01Oo3Y[d00ol0003o`Z_3ol:[``05ol:[``03o`000?o3Y[go`jJm
00[o`jJm00Go0000ol:[`oo2Zl?o`Z_3o`00000>ol>V_@03o`000?o3XkSo000000go`jJm00?o0000
ol>S^?o3XkP00oo3XkP00ol0003o`jJmol>V_@07ol>V_@03o`000?o3XkSo`j>h00Oo`j>h00?o0000
ol>V_Oo3Y[d00oo3Y[d00ol0003o`j>hol>S^00:ol>S^004o`000?o3Y[go`jJmo`0000ko`j>h00?o
0000olBP]?l000003Oo3XkP01Ol0003oa:2dolBP]?o4X;Co000000[o`j>h00?o0000olBP]?o4X;@0
1Oo4X;@00ol0003o`j>hol>S^004ol>S^003o`000?o4X;Coa:2d00Soa:2d00Go0000ol>S^?o3XkSo
`j>ho`00000>olBP]003o`000?o4X;Coa:2d00coa:2d00Co0000olBM/Oo4WK7o00002oo4X;@01Ol0
003oa9faolBM/Oo4WK7o000000Woa:2d00?o0000olBM/Oo4WK401Oo4WK400ol0003oooooooooo`04
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03?ooool002Oooooo0_l0000Eoooo
o`03o`000?o3Y[go`jJm00?o`jJm00?o0000ol:[`oo2Zl<01oo2Zl<00ol0003o`jJmol>V_@08ol>V
_@03o`000?o2Zl?o`Z_300;o`Z_300?o0000ol>V_Oo3Y[d03?o3Y[d2o`0000oo`jJm00Go0000ol>S
^?o3XkSo`j>ho`00000:ol>V_@03o`000?o3XkSo`j>h00Ko`j>h00?o0000ol>V_Oo3Y[d01?o3Y[d0
0ol0003o`j>hol>S^009ol>S^005o`000?o3Y[go`jJmol>V_Ol000003oo3XkP00ol0003o`j>hol>S
^00<ol>S^004o`000?o4X;Coa:2do`0000_o`j>h00?o0000olBP]?o4X;@01?o4X;@00ol0003o`j>h
ol>S^006ol>S^003o`000?o4X;Coa:2d00Ooa:2d00?o0000ol>S^?o3XkP00_o3XkP00ol0003oa:2d
olBP]00:olBP]003o`000?o3XkSo000000goa:2d00?o0000olBM/Ol000003?o4X;@01Ol0003oa9fa
olBM/Oo4WK7o000000[oa:2d00?o0000olBM/Oo4WK401?o4WK400ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool03?ooool002Wooooo00?o0000ooooooooool0
4_ooool00ol0003o`jJmol>V_@02ol>V_@03o`000?o2Zl?o`Z_300Wo`Z_300?o0000ol>V_Oo3Y[d0
1_o3Y[d00ol0003o`Z_3ol:[``04ol:[``03o`000?o3Y[go`jJm00[o`jJm00?o0000ol:[`ol00000
3oo3Y[d01?l0003o`j>hol>S^?l0000<ol>V_@03o`000?o3XkSo`j>h00Co`j>h00?o0000ol>V_Oo3
Y[d01_o3Y[d00ol0003o`j>hol>S^007ol>S^003o`000?o3Y[go`jJm00?o`jJm00?o0000ol>S^?o3
XkP02oo3XkP2o`0000ko`j>h00?o0000olBP]?l000003Oo3XkP00ol0003oa:2dolBP]002olBP]003
o`000?o3XkSo`j>h00Oo`j>h00?o0000olBP]?o4X;@01_o4X;@00ol0003o`j>hol>S^003ol>S^003
o`000?o4X;Coa:2d00Woa:2d00Co0000ol>S^?o3XkSo00003_o4X;@00ol0003oa:2dolBP]00;olBP
]004o`000?o4WK7oa9fao`0000_oa:2d00?o0000olBM/Oo4WK400oo4WK400ol0003oooooooooo`07
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03?ooool002[ooooo00?o0000oooo
ooooool04_ooool01?l0003o`jJmol>V_Ol0000<ol:[``03o`000?o3Y[go`jJm00Go`jJm00?o0000
ol:[`oo2Zl<01Oo2Zl<00ol0003o`jJmol>V_@09ol>V_@05o`000?o2Zl?o`Z_3ol:[`ol000003_o3
Y[d00ol0003o`j>ho`00000=ol>V_@03o`000?o3XkSo`j>h00?o`j>h00?o0000ol>V_Oo3Y[d01oo3
Y[d00ol0003o`j>hol>S^006ol>S^003o`000?o3Y[go`jJm00Co`jJm00?o0000ol>S^?o3XkP02_o3
XkP01?l0003o`jJmol>V_Ol0000>ol>S^003o`000?o3XkSo`j>h00co`j>h00Go0000olBP]?o4X;Co
a:2do`00000:ol>S^003o`000?o4X;Coa:2d00Goa:2d00?o0000ol>S^?o3XkP01?o3XkP00ol0003o
a:2dolBP]008olBP]005o`000?o3XkSo`j>hol>S^?l000003_o4X;@00ol0003oa:2dolBP]00<olBP
]0;o00003?o4X;@00ol0003oa9faolBM/@02olBM/@03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0<ooooo`00:oooool00ol0003oooooooooo`0Aooooo`03
o`000?o3Y[go000000ko`Z_300?o0000ol>V_Oo3Y[d00oo3Y[d00ol0003o`Z_3ol:[``07ol:[``03
o`000?o3Y[go`jJm00Oo`jJm00?o0000ol:[`oo2Zl<00_o2Zl<00ol0003o`jJmol>V_@0<ol>V_@;o
00003oo3Y[d01Ol0003o`j>hol>S^?o3XkSo000000_o`jJm00?o0000ol>S^?o3XkP01?o3XkP00ol0
003o`jJmol>V_@05ol>V_@03o`000?o3XkSo`j>h00Wo`j>h00Go0000ol>V_Oo3Y[go`jJmo`00000>
ol>S^003o`000?o3XkSo`j>h00co`j>h00Co0000olBP]?o4X;Co00003?o3XkP00ol0003oa:2dolBP
]003olBP]003o`000?o3XkSo`j>h00Ko`j>h00?o0000olBP]?o4X;@01oo4X;@00ol0003o`j>hol>S
^002ol>S^003o`000?o4X;Coa:2d00[oa:2d00?o0000ol>S^?l000003Oo4X;@00ol0003oa:2dolBP
]00<olBP]004o`000?o4WK7oa9fao`0000cooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0<ooooo`00;?ooool2o`0001;ooooo00?o0000ol:[`oo2Zl<03Oo2Zl<00ol0003o`jJmol>V
_@02ol>V_@03o`000?o2Zl?o`Z_300So`Z_300?o0000ol>V_Oo3Y[d01_o3Y[d00ol0003o`Z_3ol:[
``04ol:[``03o`000?o3Y[go`jJm00[o`jJm00?o0000ol:[`ol000003oo3Y[d01?l0003o`j>hol>S
^?l0000<ol>V_@03o`000?o3XkSo`j>h00?o`j>h00?o0000ol>V_Oo3Y[d01oo3Y[d00ol0003o`j>h
ol>S^007ol>S^003o`000?o3Y[go`jJm00;o`jJm00?o0000ol>S^?o3XkP02oo3XkP00ol0003o`jJm
o`00000>ol>S^0;o00003Oo3XkP00ol0003oa:2dolBP]002olBP]003o`000?o3XkSo`j>h00Oo`j>h
00?o0000olBP]?o4X;@01_o4X;@00ol0003o`j>hol>S^003ol>S^003o`000?o4X;Coa:2d00Woa:2d
00Co0000ol>S^?o3XkSo00003Oo4X;@00ol0003oa:2dolBP]00<olBP]004o`000?o4WK7oa9fao`00
00gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0<ooooo`00;_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?o2Zl?o`Z_300ko`Z_300Co0000ol>V_Oo3Y[go00002oo2Zl<00ol0
003o`jJmol>V_@05ol>V_@03o`000?o2Zl?o`Z_300Go`Z_300?o0000ol>V_Oo3Y[d02Oo3Y[d01Ol0
003o`Z_3ol:[`oo2Zl?o000000ko`jJm00?o0000ol>S^?l000003_o3Y[d01Ol0003o`j>hol>S^?o3
XkSo000000[o`jJm00?o0000ol>S^?o3XkP01_o3XkP00ol0003o`jJmol>V_@04ol>V_@03o`000?o3
XkSo`j>h00Wo`j>h00Co0000ol>V_Oo3Y[go00003_o3XkP00ol0003o`j>hol>S^00=ol>S^005o`00
0?o4X;Coa:2dolBP]?l000002_o3XkP00ol0003oa:2dolBP]004olBP]003o`000?o3XkSo`j>h00Co
`j>h00?o0000olBP]?o4X;@02?o4X;@01Ol0003o`j>hol>S^?o3XkSo000000coa:2d00?o0000ol>S
^?l000003Oo4X;@00ol0003oa9fao`00000?ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool02oooool002oooooo00?o0000ooooooooool03oooool00ol0003o`Z_3ol:[``0=ol:[``03
o`000?o3Y[go000000go`Z_300?o0000ol>V_Oo3Y[d00oo3Y[d00ol0003o`Z_3ol:[``07ol:[``03
o`000?o3Y[go`jJm00Oo`jJm00?o0000ol:[`oo2Zl<00_o2Zl<00ol0003o`jJmol>V_@0=ol>V_@03
o`000?o3Y[go`jJm00go`jJm00Co0000ol>S^?o3XkSo00003?o3Y[d00ol0003o`j>hol>S^004ol>S
^003o`000?o3Y[go`jJm00Go`jJm00?o0000ol>S^?o3XkP02?o3XkP00ol0003o`jJmol>V_@02ol>V
_@03o`000?o3XkSo`j>h00_o`j>h00?o0000ol>S^?o3XkP03Oo3XkP01?l0003oa:2dolBP]?l0000;
ol>S^003o`000?o4X;Coa:2d00?oa:2d00?o0000ol>S^?o3XkP01_o3XkP00ol0003oa:2dolBP]006
olBP]003o`000?o3XkSo`j>h00?o`j>h00?o0000olBP]?o4X;@02?o4X;@01?l0003o`j>hol>S^?l0
000>olBP]003o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0;ooooo`00<?ooool00ol0003oooooooooo`0>ooooo`03o`000?o2Zl?o`Z_300go`Z_30_l0000>
ol:[``03o`000?o3Y[go`jJm00;o`jJm00?o0000ol:[`oo2Zl<02?o2Zl<00ol0003o`jJmol>V_@06
ol>V_@03o`000?o2Zl?o`Z_300Co`Z_300?o0000ol>V_Oo3Y[d02oo3Y[d2o`0000oo`jJm00?o0000
ol>S^?l000003Oo3Y[d00ol0003o`j>hol>S^003ol>S^003o`000?o3Y[go`jJm00Ko`jJm00?o0000
ol>S^?o3XkP01oo3XkP00ol0003o`jJmol>V_@03ol>V_@03o`000?o3XkSo`j>h00[o`j>h00?o0000
ol>V_Ol000003_o3XkP00ol0003oa:2do`00000<ol>S^003o`000?o4X;Coa:2d00;oa:2d00?o0000
ol>S^?o3XkP01oo3XkP00ol0003oa:2dolBP]005olBP]003o`000?o3XkSo`j>h00Co`j>h00?o0000
olBP]?o4X;@01oo4X;@01Ol0003o`j>hol>S^?o3XkSo000000koa:2d00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00_ooooo000aooooo`;o00003oooool0
0ol0003o`Z_3ol:[``0;ol:[``03o`000?o0/<[o000000oo`Z_300Co0000ol>V_Oo3Y[go00002oo2
Zl<00ol0003o`jJmol>V_@05ol>V_@03o`000?o2Zl?o`Z_300Go`Z_300?o0000ol>V_Oo3Y[d02_o3
Y[d01?l0003o`Z_3ol:[`ol0000>ol>V_@;o00003oo3Y[d01Ol0003o`j>hol>S^?o3XkSo000000[o
`jJm00?o0000ol>S^?o3XkP01Oo3XkP00ol0003o`jJmol>V_@04ol>V_@03o`000?o3XkSo`j>h00Wo
`j>h00Co0000ol>V_Oo3Y[go00003oo3XkP00ol0003o`j>hol>S^00<ol>S^005o`000?o4X;Coa:2d
olBP]?l000002Oo3XkP00ol0003oa:2dolBP]004olBP]003o`000?o3XkSo`j>h00Go`j>h00?o0000
olBP]?o4X;@01oo4X;@00ol0003o`j>hol>S^002ol>S^003o`000?o4X;Coa:2d00[oa:2d00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo000coooo
o`03o`000?oooooooooo00gooooo00?o0000ol:[`oo2Zl<02Oo2Zl<01Ol0003o`;3:ol2`b_o0/<[o
000000ko`Z_300?o0000ol>V_Ol000003Oo2Zl<00ol0003o`jJmol>V_@03ol>V_@03o`000?o2Zl?o
`Z_300Oo`Z_300?o0000ol>V_Oo3Y[d02?o3Y[d01Ol0003o`Z_3ol:[`oo2Zl?o000000go`jJm00?o
0000ol:[`ol000003oo3Y[d01?l0003o`j>hol>S^?l0000;ol>V_@03o`000?o3XkSo`j>h00Co`j>h
00?o0000ol>V_Oo3Y[d01_o3Y[d00ol0003o`j>hol>S^007ol>S^003o`000?o3Y[go`jJm00;o`jJm
00?o0000ol>S^?o3XkP02oo3XkP2o`0000ko`j>h00Co0000olBP]?o4X;Co00002oo3XkP00ol0003o
a:2dolBP]002olBP]003o`000?o3XkSo`j>h00Oo`j>h00?o0000olBP]?o4X;@01Oo4X;@00ol0003o
`j>hol>S^003ol>S^003o`000?o4X;Coa:2d00Woa:2d00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo000dooooo`03o`000?oooooooooo00cooooo
00?o0000ol:[`oo2Zl<02?o2Zl<00ol0003o`;3:ol2`bP02ol2`bP03o`000?o2Zl?o`Z_300co`Z_3
0_l0000>ol:[``03o`000?o3Y[go`jJm00;o`jJm00?o0000ol:[`oo2Zl<02Oo2Zl<00ol0003o`jJm
ol>V_@06ol>V_@03o`000?o2Zl?o`Z_300?o`Z_300?o0000ol>V_Oo3Y[d02Oo3Y[d01Ol0003o`Z_3
ol:[`oo2Zl?o000000ko`jJm00?o0000ol>S^?l000003?o3Y[d00ol0003o`j>hol>S^003ol>S^003
o`000?o3Y[go`jJm00Oo`jJm00?o0000ol>S^?o3XkP01_o3XkP00ol0003o`jJmol>V_@03ol>V_@03
o`000?o3XkSo`j>h00[o`j>h00Co0000ol>W_Oo3Ykgo00003Oo3XkP00ol0003oa:2do`00000<ol>S
^005o`000?o4X;Coa:2dolBP]?l000002_o3XkP00ol0003oa:2dolBP]004olBP]003o`000?o3XkSo
`j>h00Go`j>h00?o0000olBP]?o4X;@01oo4X;@00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02oooool003Gooooo00?o0000ooooooooool03?ooool00ol0
003o`Z_3ol:[``05ol:[``;o00001_o0/<X00ol0003o`Z_3ol:[``0:ol:[``03o`000?o0/<[o0000
00oo`Z_300Co0000ol>V_Oo3Y[go00003?o2Zl<00ol0003o`jJmol>V_@05ol>V_@03o`000?o2Zl?o
`Z_300Co`Z_300?o0000ol>V_Oo3Y[d02?o3Y[d00ol0003o`Z_3ol:[``02ol:[``03o`000?o3Y[go
`jJm00co`jJm0_l0000>ol>V_@05o`000?o3XkSo`j>hol>S^?l000002oo3Y[d00ol0003o`j>hol>S
^004ol>S^003o`000?o3Y[go`jJm00Co`jJm00?o0000ol>S^?o3XkP02Oo3XkP01Ol0003o`jNmol>W
_Oo3Ykgo000000ko`j>h00?o0000ol>S^?o3XkP02oo3XkP01?l0003oa:2dolBP]?l0000;ol>S^003
o`000?o4X;Coa:2d00?oa:2d00?o0000ol>S^?o3XkP01_o3XkP00ol0003oa:2dolBP]006olBP]003
o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`00
=_ooool2o`0000cooooo00?o0000ol:[`oo2Zl<01?o2Zl<00ol0003o`;3:ol2`bP06ol2`bP03o`00
0?o2Zl?o`Z_300Wo`Z_300Go0000ol2`b_o0/<[o`;3:o`00000>ol:[``03o`000?o3Y[go000000ko
`Z_300?o0000ol>V_Oo3Y[d00oo3Y[d00ol0003o`Z_3ol:[``06ol:[``03o`000?o3Y[go`jJm00Ko
`jJm00?o0000ol:[`oo2Zl<01?o2Zl<00ol0003o`jJmol>V_@0:ol>V_@03o`000?o2Zl?o000000ko
`jJm00Co0000ol>S^?o3XkSo00003?o3Y[d00ol0003o`j>hol>S^003ol>S^003o`000?o3Y[go`jJm
00Ko`jJm00?o0000ol>S^?o3XkP01oo3XkP00ol0003o`jNmol>W_@02ol>W_@03o`000?o3XkSo`j>h
00_o`j>h0_l0000>ol>S^0;o00003Oo3XkP01Ol0003oa:2dolBP]?o4X;Co000000Wo`j>h00?o0000
olBP]?o4X;@01Oo4X;@00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02_ooool003Sooooo00?o0000ooooooooool02_ooool00ol0003o`Z_3ol:[``02ol:[
``03o`000?o0/<[o`;3:00So`;3:00?o0000ol:[`oo2Zl<01oo2Zl<00ol0003o`;3:ol2`bP03ol2`
bP03o`000?o2Zl?o`Z_300_o`Z_30_l0000?ol:[``03o`000?o3Y[go`jJm00;o`jJm00?o0000ol:[
`oo2Zl<01oo2Zl<00ol0003o`jJmol>V_@05ol>V_@03o`000?o2Zl?o`Z_300Go`Z_300?o0000ol>V
_Oo3Y[d02Oo3Y[d01Ol0003o`Z_3ol:[`oo2Zl?o000000go`jJm00?o0000ol>S^?l000003_o3Y[d0
1Ol0003o`j>hol>S^?o3XkSo000000Wo`jJm00?o0000ol>S^?o3XkP01_o3XkP00ol0003o`jNmol>W
_@04ol>W_@03o`000?o3XkSo`j>h00Wo`j>h00Co0000ol>W_Oo3Ykgo00003Oo3XkP00ol0003o`j>h
ol>S^00<ol>S^005o`000?o4X;Coa:2dolBP]?l000002_o3XkP00ol0003oa:2dolBP]004olBP]003
o`000?oooooooooo01Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`00
>Oooool00ol0003oooooooooo`0:ooooo`04o`000?o2Zl?o`Z_3o`0000_o`;3:00?o0000ol:[`oo2
Zl<01Oo2Zl<2o`0000Ko`;3:00?o0000ol:[`oo2Zl<02_o2Zl<00ol0003o`;3:o`00000@ol:[``04
o`000?o3Y[go`jJmo`0000_o`Z_300?o0000ol>V_Oo3Y[d00oo3Y[d00ol0003o`Z_3ol:[``07ol:[
``03o`000?o3Y[go`jJm00Oo`jJm00?o0000ol:[`oo2Zl<00_o2Zl<00ol0003o`jJmol>V_@0<ol>V
_@03o`000?o3Y[go`jJm00go`jJm00Co0000ol>S^?o3XkSo00002oo3Y[d00ol0003o`j>hol>S^004
ol>S^003o`000?o3Ykgo`jNm00Go`jNm00?o0000ol>S^?o3XkP02?o3XkP01Ol0003o`jNmol>W_Oo3
Ykgo000000go`j>h00?o0000ol>S^?o3XkP03?o3XkP01?l0003oa:2dolBP]?l0000;ol>S^003o`00
0?o4X;Coa:2d00?oa:2d00?o0000ooooooooool06_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00[ooooo000jooooo`03o`000?oooooooooo00Wooooo00?o0000ol:[`ol000003Oo0
/<X00ol0003o`Z_3ol:[``03ol:[``03o`000?o0/<[o`;3:00Oo`;3:00?o0000ol:[`oo2Zl<02?o2
Zl<01Ol0003o`;3:ol2`b_o0/<[o000000oo`Z_300?o0000ol>V_Ol000003?o2Zl<00ol0003o`jJm
ol>V_@02ol>V_@03o`000?o2Zl?o`Z_300So`Z_300?o0000ol>V_Oo3Y[d01_o3Y[d00ol0003o`Z_3
ol:[``04ol:[``03o`000?o3Y[go`jJm00[o`jJm0_l0000?ol>V_@03o`000?o3XkSo000000co`jJm
00?o0000ol>S^?o3XkP00oo3XkP00ol0003o`jNmol>W_@06ol>W_@03o`000?o3XkSo`j>h00Oo`j>h
00?o0000ol>W_Oo3Ykd00_o3Ykd00ol0003o`j>hol>S^00:ol>S^003o`000?o3Ykgo000000ko`j>h
0_l0000=ol>S^005o`000?o4X;Coa:2dolBP]?l000007_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00[ooooo000kooooo`;o00002_ooool00ol0003o`;3:ol2`bP0<ol2`bP03o`00
0?o2Zl?o`Z_300;o`Z_300?o0000ol2`b_o0/<X02Oo0/<X00ol0003o`Z_3ol:[``06ol:[``03o`00
0?o0/<[o`;3:00?o`;3:00?o0000ol:[`oo2Zl<03?o2Zl<2o`0000ko`Z_300Co0000ol>V_Oo3Y[go
00002oo2Zl<00ol0003o`jJmol>V_@05ol>V_@03o`000?o2Zl?o`Z_300Go`Z_300?o0000ol>V_Oo3
Y[d02Oo3Y[d01?l0003o`Z_3ol:[`ol0000>ol>V_@;o00003_o3Y[d01Ol0003o`j>hol>S^?o3XkSo
000000[o`jNm00?o0000ol>S^?o3XkP01Oo3XkP00ol0003o`jNmol>W_@04ol>W_@03o`000?o3XkSo
`j>h00So`j>h00Co0000ol>W_Oo3Ykgo00003_o3XkP00ol0003o`j>hol>S^00<ol>S^004o`000?o4
X;Coa:2do`00023ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00?Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?o0/<[o`;3:00go`;3:00Co0000ol:[`oo2Zl?o0000
3?o0/<X00ol0003o`Z_3ol:[``04ol:[``;o00001_o0/<X00ol0003o`Z_3ol:[``0;ol:[``03o`00
0?o0/<[o000000ko`Z_300?o0000ol>V_Ol000003Oo2Zl<00ol0003o`jJmol>V_@03ol>V_@03o`00
0?o2Zl?o`Z_300Oo`Z_300?o0000ol>V_Oo3Y[d01oo3Y[d01Ol0003o`Z_3ol:[`oo2Zl?o000000go
`jJm00?o0000ol:[`ol000003_o3Y[d01?l0003o`j>hol>S^?l0000;ol>W_@03o`000?o3XkSo`j>h
00Co`j>h00?o0000ol>W_Oo3Ykd01Oo3Ykd00ol0003o`j>hol>S^007ol>S^003o`000?o3Ykgo`jNm
00;o`jNm00?o0000ol>S^?o3XkP02oo3XkP00ol0003o`j>hol>S^00<ol>S^003o`000?o4X;Co0000
027ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00?_ooool00ol0003o
ooooooooo`07ooooo`03o`000?o0/<[o`;3:00co`;3:00?o0000ol:[`ol000003_o0/<X00ol0003o
`Z_3ol:[``02ol:[``03o`000?o0/<[o`;3:00Oo`;3:00?o0000ol:[`oo2Zl<02Oo2Zl<01Ol0003o
`;3:ol2`b_o0/<[o000000go`Z_30_l0000>ol:[``03o`000?o3Y[go`jJm00;o`jJm00?o0000ol:[
`oo2Zl<02?o2Zl<00ol0003o`jJmol>V_@06ol>V_@03o`000?o2Zl?o`Z_300?o`Z_300?o0000ol>V
_Oo3Y[d02Oo3Y[d01Ol0003o`Z_3ol:[`oo2Zl?o000000go`jJm00?o0000ol>S^?l000003?o3Ykd0
0ol0003o`j>hol>S^003ol>S^003o`000?o3Ykgo`jNm00Oo`jNm00?o0000ol>S^?o3XkP01Oo3XkP0
0ol0003o`jNmol>W_@03ol>W_@03o`000?o3XkSo`j>h00[o`j>h00?o0000ol>W_Ol000003_o3XkP0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool0
03oooooo00?o0000ooooooooool01oooool00ol0003o`;3:ol2`bP0;ol2`bP;o00003oo0/<X01Ol0
003o`Z_3ol:[`oo2Zl?o000000_o`;3:00?o0000ol:[`oo2Zl<01_o2Zl<2o`0000Co`;3:00?o0000
ol:[`oo2Zl<02_o2Zl<00ol0003o`;3;o`00000?ol:[``04o`000?o3Y[go`jJmo`0000_o`Z_300?o
0000ol>V_Oo3Y[d01Oo3Y[d00ol0003o`Z_3ol:[``04ol:[``03o`000?o3Y[go`jJm00So`jJm00?o
0000ol:[`oo2Zl<00_o2Zl<00ol0003o`jJmol>V_@0;ol>V_@;o00003_o3Ykd01Ol0003o`j>hol>S
^?o3XkSo000000[o`jNm00?o0000ol>S^?o3XkP01?o3XkP00ol0003o`jNmol>W_@04ol>W_@03o`00
0?o3XkSo`j>h00Wo`j>h00Co0000ol>W_Oo3Ykgo00003Oo3XkP00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool0043ooooo0_l00007ooooo`03o`00
0?o0/<[o`;3:00[o`;3:00?o0000okfge?l000004?o0/<X00ol0003o`Z_3o`00000<ol2`bP03o`00
0?o2Zl?o`Z_300Go`Z_300?o0000ol2`b_o0/<X01Oo0/<X00ol0003o`Z_3ol:[``08ol:[``05o`00
0?o0/<_o`;3;ol2`bol000003_o2Zl<00ol0003o`jJmo`00000=ol:[``03o`000?o3Y[go`jJm00?o
`jJm00?o0000ol:[`oo2Zl<01_o2Zl<00ol0003o`jJmol>V_@06ol>V_@03o`000?o2Zl?o`Z_300?o
`Z_300?o0000ol>V_Oo3Y[d02_o3Y[d00ol0003o`Z_3o`00000>ol>W_@04o`000?o3XkSo`j>ho`00
00_o`jNm00?o0000ol>S^?o3XkP00oo3XkP00ol0003o`jNmol>W_@06ol>W_@03o`000?o3XkSo`j>h
00Oo`j>h00Go0000ol>W_Oo3Ykgo`jNmo`00000<ol>S^003o`000?oooooooooo02Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`09ooooo`00@_ooool00ol0003oooooooooo`05oooo
o`03o`000?o0/<[o`;3:00Oo`;3:0_l00003okfge003o`000?o0/<[o`;3:00go`;3:0_l0000>ol2`
bP03o`000?o2Zl?o`Z_300;o`Z_30_l00008ol2`bP03o`000?o2Zl?o`Z_300Oo`Z_300?o0000ol2`
boo0/</00_o0/</00ol0003o`Z_3ol:[``0<ol:[``;o00003_o2Zl<00ol0003o`jJmol>V_@02ol>V
_@03o`000?o2Zl?o`Z_300Oo`Z_300?o0000ol>V_Oo3Y[d01Oo3Y[d00ol0003o`Z_3ol:[``05ol:[
``03o`000?o3Y[go`jJm00So`jJm00Go0000ol:[`oo2Zl?o`Z_3o`00000=ol>W_@03o`000?o3XkSo
000000go`jNm00Go0000ol>S^?o3XkSo`j>ho`000009ol>W_@03o`000?o3XkSo`j>h00Ko`j>h00?o
0000ol>W_Oo3Ykd00oo3Ykd00ol0003o`j>hol>S^008ol>S^003o`000?oooooooooo02Kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`00@oooool00ol0003oooooooooo`05
ooooo`03o`000?o0/<[o`;3:00Go`;3:00?o0000okfge?nm]m@01?nm]m@00ol0003o`;3:ol2`bP0;
ol2`bP03o`000?nm]mCo000000ko`;3:00Go0000ol:[`oo2Zl?o`Z_3o`00000;ol2`bP03o`000?o2
Zl?o`Z_300Go`Z_300?o0000ol2`boo0/</01?o0/</00ol0003o`Z_3ol:[``0:ol:[``03o`000?o0
/<_o000000oo`Z_300Co0000ol>V_Oo3Y[go00002oo2Zl<00ol0003o`jJmol>V_@03ol>V_@03o`00
0?o2Zl?o`Z_300Ko`Z_300?o0000ol>V_Oo3Y[d01oo3Y[d00ol0003o`Z_3ol:[``02ol:[``03o`00
0?o3Ykgo`jNm00_o`jNm0_l0000>ol>W_@04o`000?o3XkSo`j>ho`0000_o`jNm00?o0000ol>S^?o3
XkP01?o3XkP00ol0003o`jNmol>W_@04ol>W_@03o`000?o3XkSo`j>h00Oo`j>h00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo0014ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ol2`b_o0/<X00oo0/<X00ol0003o_KODokfge006okfge003o`00
0?o0/<[o`;3:00So`;3:0_l00003okfge003o`000?o0/<[o`;3:00co`;3:00?o0000ol:[`ol00000
3Oo0/<X00ol0003o`Z_3ol:[``03ol:[``03o`000?o0/<_o`;3;00Go`;3;00?o0000ol:[`oo2Zl<0
2Oo2Zl<01Ol0003o`;3;ol2`boo0/<_o000000ko`Z_300?o0000ol>V_Ol000003?o2Zl<00ol0003o
`jJmol>V_@02ol>V_@03o`000?o2Zl?o`Z_300So`Z_300?o0000ol>V_Oo3Y[d01Oo3Y[d00ol0003o
`Z_3ol:[``04ol:[``03o`000?o3Ykgo`jNm00Wo`jNm00?o0000ol:[`ol000003_o3Ykd00ol0003o
`j>ho`00000<ol>W_@03o`000?o3XkSo`j>h00?o`j>h00?o0000ol>W_Oo3Ykd01_o3Ykd00ol0003o
`j>hol>S^005ol>S^003o`000?oooooooooo02[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`09ooooo`00AOooool2o`0000Gooooo00Co0000ol2`b_o0/<[o`;3:0_l0000:okfge003
o`000?o0/<[o`;3:00Go`;3:0_l00006okfge003o`000?o0/<[o`;3:00_o`;3:0_l0000>ol2`bP03
o`000?o2Zl?o`Z_300;o`Z_300?o0000ol2`boo0/</01oo0/</00ol0003o`Z_3ol:[``06ol:[``;o
00001?o0/</00ol0003o`Z_3ol:[``0<ol:[``;o00003_o2Zl<01?l0003o`jJmol>V_Ol0000;ol:[
``03o`000?o3Y[go`jJm00Co`jJm00?o0000ol:[`oo2Zl<01Oo2Zl<00ol0003o`jNmol>W_@08ol>W
_@05o`000?o2Zl?o`Z_3ol:[`ol000003_o3Ykd00ol0003o`jNmol>W_@0<ol>W_@05o`000?o3XkSo
`j>hol>S^?l000002Oo3Ykd00ol0003o`j>hol>S^004ol>S^003o`000?oooooooooo02cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`00Aoooool00ol0003oooooooooo`03
ooooo`03o`000?o0/<[o000000co_KOD00?o0000ol2`b_o0/<X01?o0/<X00ol0003o_KODokfge006
okfge003o`000?o0/<[o`;3:00[o`;3:00?o0000okfge?l000003oo0/<X01?l0003o`Z_3ol:[`ol0
000;ol2`b`03o`000?o2Zl?o`Z_300Co`Z_300?o0000ol2`boo0/</01Oo0/</00ol0003o`Z_3ol:[
``0:ol:[``03o`000?o0/L_o000000ko`Z_300?o0000ol>V_Ol000003?o2Zl<00ol0003o`jJmol>V
_@03ol>V_@03o`000?o2Zl?o`Z_300Oo`Z_300?o0000ol>W_Oo3Ykd01_o3Ykd00ol0003o`Z_3ol:[
``02ol:[``03o`000?o3Ykgo`jNm00_o`jNm0_l0000>ol>W_@04o`000?o3XkSo`j>ho`0000[o`jNm
00?o0000ol>S^?o3XkP00oo3XkP00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02Oooool004Sooooo00?o0000ooooooooool00oooool00ol0003o_KODokfg
e00<okfge004o`000?o0/<[o`;3:ol2`bP;o00002_nm]m@00ol0003o`;3:ol2`bP07ol2`bP;o0000
0onm]m@00ol0003o`;3:ol2`bP0<ol2`bP03o`000?o2Zl?o000000co`;3;00?o0000ol:[`oo2Zl<0
0_o2Zl<2o`0000So`;3;00?o0000ol:[`oo2Zl<02Oo2Zl<01Ol0003o`;7;ol2aboo0/L_o000000go
`Z_30_l0000>ol:[``05o`000?o3Y[go`jJmol>V_Ol000002_o2Zl<00ol0003o`jNmol>W_@05ol>W
_@03o`000?o2Zl?o`Z_300Co`Z_300?o0000ol>W_Oo3Ykd02Oo3Ykd01?l0003o`Z_3ol:[`ol0000=
ol>W_@03o`000?o3XkSo000000co`jNm00Go0000ol>S^?o3XkSo`j>ho`00000aooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool02?ooool004Wooooo00?o0000ooooooooool00_ooool0
0ol0003o_KODokfge00=okfge003o`000?o0/<[o000000co_KOD00?o0000ol2`b_o0/<X01Oo0/<X2
o`0000Ko_KOD00?o0000ol2`b_o0/<X02oo0/<X2o`0000ko`;3;00Co0000ol:[`oo2Zl?o00002oo0
/</00ol0003o`Z_3ol:[``06ol:[``;o00001Oo0/L/00ol0003o`Z_3ol:[``09ol:[``03o`000?o0
/L_o000000ko`Z_300Co0000ol>V_Oo3Y[go00003?o2Zl<00ol0003o`jNmol>W_@03ol>W_@03o`00
0?o2Zl?o`Z_300Go`Z_300?o0000ol>W_Oo3Ykd02?o3Ykd01Ol0003o`Z_3ol:[`oo2Zl?o000000go
`jNm0_l0000=ol>W_@04o`000?o3XkSo`j>ho`0003?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`08ooooo`00B_ooool2o`0000?ooooo00?o0000okfge?nm]m@03?nm]m@2o`0000ko
_KOD00?o0000ol2`b_o0/<X00oo0/<X00ol0003o_KODokfge006okfge003o`000?o0/<[o`;3:00Wo
`;3:0_l000000onm^=Co0000ol2`b`0=ol2`b`03o`000?o2Zl?o000000go`;3;00?o0000ol:[`oo2
Zl<01?o2Zl<00ol0003o`;7;ol2ab`05ol2ab`03o`000?o2Zl?o`Z_300So`Z_300Go0000ol2aboo0
/L_o`;7;o`00000=ol:[``03o`000?o3Y[go000000go`Z_300?o0000ol>W_Oo3Ykd00_o3Ykd00ol0
003o`Z_3ol:[``07ol:[``03o`000?o3Ykgo`jNm00Ko`jNm00?o0000ol:[`oo2Zl<00_o2Zl<00ol0
003o`jNmol>W_@0:ol>W_@03o`000?o2Zl?o000000go`jNm00?o0000ol>S^?l00000=Oooool01Ol0
003ooooooooooooooooo000000[ooooo001<ooooo`05o`000?ooooooooooooooool000002onm]m@2
o`000003okS0h?l0003o_KOD00ko_KOD00?o0000ol2`b_o0/<X00_l0000:okfge003o`000?o0/<[o
`;3:00Ko`;3:0_l00004okfhe003o`000?o0/<_o`;3;00_o`;3;0_l0000>ol2`b`03o`000?o2Zl?o
`Z_300;o`Z_30_l00009ol2ab`03o`000?o2Zl?o`Z_300Ko`Z_300?o0000ol2aboo0/L/00_o0/L/0
0ol0003o`Z_3ol:[``0;ol:[``;o00003oo2Zl<01?l0003o`jNmol>W_Ol0000:ol:[``03o`000?o3
Ykgo`jNm00Go`jNm00?o0000ol:[`oo2Zl<01?o2Zl<00ol0003o`jNmol>W_@08ol>W_@05o`000?o2
Zl?o`Z_3ol:[`ol000003Oo3Ykd00ol0003oooooooooo`0dooooo`05o`000?ooooooooooooooool0
00002_ooool004gooooo00Go0000ooooooooooooooooo`000009okfge003o`000?nh`>3o^<3P00;o
^<3P00?o0000okfge?nm]m@03?nm]m@00ol0003o`;3:o`00000=okfge003o`000?o0/<[o`;3:00Co
`;3:00?o0000okfhe?nm^=@01Onm^=@00ol0003o`;3;ol2`b`09ol2`b`03o`000?nm^=Co000000oo
`;3;00Co0000ol:[`oo2Zl?o00002oo0/L/00ol0003o`Z_3ol:[``04ol:[``;o00001_o0/L/00ol0
003o`Z_3ol:[``09ol:[``03o`000?o0/L_o000000oo`Z_300?o0000ol>W_Ol000003?o2Zl<00ol0
003o`jNmol>W_@03ol>W_@03o`000?o2Zl?o`Z_300Go`Z_300?o0000ol>W_Oo3Ykd01oo3Ykd00ol0
003o`Z_3ol:[``02ol:[``03o`000?o3Ykgo`jNm00[o`jNm00?o0000ooooooooool0=_ooool01?l0
003oooooooooool0000:ooooo`00C_ooool01Ol0003ooooooooooooooooo000000Ko_KOD0_l00006
okS0h003o`000?nm]mCo_KOD00_o_KOD0_l0000>okfge003o`000?o0/<[o`;3:00;o`;3:0_l00008
okfhe003o`000?o0/<_o`;3;00Oo`;3;0_l00003okfhe003o`000?o0/<_o`;3;00co`;3;00?o0000
ol:[`ol000003Oo0/L/00ol0003o`Z_3ol:[``02ol:[``03o`000?o0/L_o`;7;00Ko`;7;00?o0000
ol:[`oo2Zl<02?o2Zl<01Ol0003o`;7;ol2aboo0/L_o000000ko`Z_30_l0000=ol:[``03o`000?o3
Ykgo`jNm00;o`jNm00?o0000ol:[`oo2Zl<01oo2Zl<00ol0003o`jNmol>W_@04ol>W_@;o00001Oo2
Zl<00ol0003o`jNmol>W_@09ol>W_@03o`000?oooooooooo03Sooooo00?o0000ooooool000002_oo
ool004oooooo0_l00002ooooo`04o`000?nm]mCo_KODokfge0;o00002Onh`>000ol0003o_KODokfg
e008okfge0;o000000?o^<7Po`000?nm]m@03_nm]m@01?l0003o`;3:o`000?l0000;okfhe003o`00
0?o0/<_o`;3;00Go`;3;00?o0000okfhe?nm^=@01?nm^=@00ol0003o`;3;ol2`b`0;ol2`b`;o0000
3oo0/L/01?l0003o`Z_3ol:[`ol0000:ol2ab`03o`000?o2Zl?o`Z_300Ko`Z_300?o0000ol2aboo0
/L/00oo0/L/00ol0003o`Z_3ol:[``0:ol:[``03o`000?o0/L_o000000ko`Z_300Co0000ol>W_Oo3
Ykgo00002_o2Zl<00ol0003o`jNmol>W_@03ol>W_@03o`000?o2Zl?o`Z_300Ko`Z_300?o0000ol>W
_Oo3Ykd01oo3Ykd00ol0003oooooooooo`0iooooo`03o`000?oooooo000000[ooooo001Aooooo`06
o`000?ooooooooooo`000?nm]mCo00003?nh`>000ol0003o_KODokfge005okfge0;o00001?nh`N00
0ol0003o_KODokfge00<okfge0;o00003_nm^=@00ol0003o`;3;ol2`b`03ol2`b`03o`000?nm^=Co
_KSD00Go_KSD00?o0000ol2`boo0/</02_o0/</00ol0003o_KSDo`00000?ol2ab`03o`000?o2Zl?o
000000co`;7;00?o0000ol:[`oo2Zl<00oo2Zl<2o`0000Ko`;7;00?o0000ol:[`oo2Zl<02Oo2Zl<0
1Ol0003o`;7;ol2aboo0/L_o000000go`Z_300?o0000ol>W_Ol000003?o2Zl<01Ol0003o`jNmol>W
_Oo3Ykgo000000Wo`Z_300?o0000ol>W_Oo3Ykd01_o3Ykd00ol0003oooooooooo`0kooooo`03o`00
0?oooooo000000Wooooo001Booooo`04o`000?ooooooooooo`0000ko^<3P00?o0000okfge?nm]m@0
0_nm]m@2o`0000Oo^<7P00?o0000okfge?nm]m@02Onm]m@2o`000003okS1hOl0003o_KSD00go_KSD
00Co0000ol2`boo0/<_o`;3;0_l00009okfhe003o`000?o0/<_o`;3;00Oo`;3;0_l00003okfhe003
o`000?o0/L_o`;7;00co`;7;0_l0000=ol2ab`03o`000?o2Zl?o`Z_300;o`Z_300?o0000ol2aboo0
/L/01oo0/L/00ol0003o`Z_3ol:[``06ol:[``;o00001?o0/L/00ol0003o`Z_3ol:[``0;ol:[``;o
00003Oo2Zl<01?l0003o`jNmol>W_Ol0000;ol:[``03o`000?o3Ykgo`jNm00Co`jNm00?o0000oooo
ooooool0?Oooool2o`0000Wooooo001Cooooo`;o000000?oooooo`000?nh`>003Onh`>001?l0003o
_KODo`000?l0000:okS1h003o`000?nm]mCo_KOD00Oo_KOD00?o0000okS1hOnh`N400_nh`N400ol0
003o_KSDokfhe00<okfhe003o`000?o0/<_o000000co_KSD00?o0000ol2`boo0/</01Oo0/</00ol0
003o_KSDokfhe004okfhe003o`000?o0/L_o`;7;00[o`;7;00?o0000okfhe?l000003_o0/L/01?l0
003o`Z_3ol:[`ol0000:ol2ab`03o`000?o2Zl?o`Z_300Go`Z_300?o0000ol2aboo0/L/01Oo0/L/0
0ol0003o`Z_3ol:[``09ol:[``03o`000?o0/L_o000000go`Z_300?o0000ol>W_Ol000003?o2Zl<0
0ol0003o`jNmol>W_@03ol>W_@03o`000?oooooooooo03gooooo0ol00009ooooo`00EOooool00ol0
003oooooo`00000=okS0h0;o00003Onh`N000ol0003o_KODokfge004okfge0;o00001_nh`N400ol0
003o_KSDokfhe00;okfhe0;o00003_nm^=@00ol0003o`;3;ol2`b`03ol2`b`03o`000?nm^=Co_KSD
00Go_KSD00?o0000ol2aboo0/L/02?o0/L/2o`0000?o_KSD00?o0000ol2aboo0/L/02oo0/L/00ol0
003o`Z_3o`00000<ol2ab`03o`000?o2Zl?o`Z_300;o`Z_30_l00008ol2ab`03o`000?o2Zl?o`Z_3
00So`Z_300Go0000ol2aboo0/L_o`;7;o`00000<ol:[``;o00003_o2Zl<01Ol0003o`jNmol>W_Oo3
Ykgo000003cooooo1?l0000<ooooo`00E_ooool00ol0003oooooo`000009okS0h0?o000000?o[<_`
o`000?nh`N003Onh`N001?l0003o_KODokfge?nm]m@2o`0000Wo^<7Q00?o0000okfhe?nm^=@02?nm
^=@2o`000003okS1hOl0003o_KSD00go_KSD00Co0000ol2`boo0/<_o`;3;0_l00009okfhe003o`00
0?o0/L_o`;7;00Go`;7;0_l00005okfhe003o`000?o0/L_o`;7;00_o`;7;0_l0000>ol2ab`04o`00
0?o2Zl?o`Z_3o`0000_o`;7;00?o0000ol:[`oo2Zl<01Oo2Zl<2o`0000Co`;7;00?o0000ol:[`oo2
Zl<02Oo2Zl<00ol0003o`;7;o`00000>ol:[``04o`000?o3Ykgo`jNmo`0003Wooooo1?l0000@oooo
o`00Eoooool00ol0003oooooo`000005okS0h0?o00001On/bo000ol0003o^<7PokS1h00<okS1h003
o`000?nm]mCo000000_o^<7Q00?o0000okfhe?nm^=@01Onm^=@3o`0000Co^<7Q00?o0000okfhe?nm
^=@03?nm^=@00ol0003o`;3;o`00000<okfhe003o`000?o0/L_o`;7;00?o`;7;00?o0000okfhe?nm
^=@01_nm^=@00ol0003o`;7;ol2ab`09ol2ab`03o`000?nm^=Co000000ko`;7;00?o0000ol:[`ol0
00003?o0/L/00ol0003o`Z_3ol:[``04ol:[``03o`000?o0/L_o`;7;00Go`;7;00?o0000ol:[`oo2
Zl<01oo2Zl<01Ol0003o`;7;ol2aboo0/L_o000000go`Z_300?o0000ol>W_Ol00000=_ooool4o`00
01Cooooo001Hooooo`?o000000Co^<3Po`000?l0003o00002On/bo000ol0003o^<7PokS1h00;okS1
h0;o00003Onh`N400ol0003o_KSDokfhe002okfhe0;o00002?nh`N400ol0003o_KSDokfhe00;okfh
e0;o00003Onm^=@01?l0003o`;7;ol2aboo0/L/2o`0000Wo_KSD00?o0000ol2aboo0/L/01oo0/L/2
o`0000?o_KSD00?o0000ol2aboo0/L/02oo0/L/2o`0000go`;7;00?o0000ol:[`oo2Zl<00_o2Zl<2
o`0000So`;7;00?o0000ol:[`oo2Zl<01_o2Zl<00ol0003o`;7;ol2ab`02ol2ab`03o`000?o2Zl?o
`Z_300_o`Z_30_l0000dooooo`?o00006?ooool005[ooooo0ol0000<ojc;l003o`000?nh`N3o^<7P
00Oo^<7P0ol00002ojc;l003o`000?nh`N7o^<7Q00_o^<7Q00Co0000okfhe?l0003o00002onh`N40
0ol0003o_KSDokfhe008okfhe0;o000000?o^<7Qo`000?nm^=@03Onm^=@00ol0003o`;7;o`00000<
okfhe003o`000?o0/L_o`;7;00Co`;7;0_l00005okfhe003o`000?o0/L_o`;7;00[o`;7;00?o0000
okfhe?l000003_o0/L/01?l0003o`Z_3ol:[`ol0000;ol2ab`03o`000?o2Zl?o`Z_300?o`Z_30_l0
0006ol2ab`03o`000?o2Zl?o`Z_300Wo`Z_300?o0000ooooooooool0<?ooool4o`0001_ooooo001K
ooooo`03o`000?oooooo000000co[<_`00?o0000okS1h?nh`N000onh`N03o`0000Ko[<_`00?o0000
okS1hOnh`N402_nh`N42o`0000go^<7Q00?o0000okfhe?nm^=@01Onm^=@3o`0000Co^<7Q00?o0000
okfhe?nm^=@02onm^=@2o`0000go_KSD00?o0000ol2aboo0/L/00oo0/L/00ol0003o_KSDokfhe006
okfhe003o`000?o0/L_o`;7;00Oo`;7;0_l00003okfhe003o`000?o0/L_o`;7;00_o`;7;00?o0000
ol:[`ol000003?o0/L/00ol0003o`Z_3ol:[``02ol:[``03o`000?o0/L_o`;7;00Ko`;7;00?o0000
ol:[`oo2Zl<02?o2Zl<00ol0003oooooooooo`0]ooooo`Co00007oooool005cooooo00Co0000oooo
ool0003o00002on/bo000ol0003o^<7Po`000002o`0000[o[<_`00?o0000okS1hOnh`N401_nh`N43
o`0000;o[<c`00?o0000okS1hOnh`N402onh`N400ol0003o_KSDokfhe002okfhe0;o00002?nh`N40
0ol0003o_KSDokfhe008okfhe0;o000000?o^<7Qo`000?nm^=@03Onm^=@00ol0003o`;7;ol2ab`02
o`0000[o_KSD00?o0000ol2aboo0/L/01?o0/L/2o`0000Go_KSD00?o0000ol2aboo0/L/02oo0/L/2
o`0000ko`;7;00Co0000ol:[`oo2Zl?o00002_o0/L/00ol0003o`Z_3ol:[``06ol:[``03o`000?oo
oooooooo02[ooooo1?l0000Sooooo`00GOooool2o`000003ooooool0003o[<_`00So[<_`1?l0000=
ojc;l003o`000?nh`N7o^<7Q00?o^<7Q0_l00006ojc<l003o`000?nh`N7o^<7Q00_o^<7Q00Co0000
okfhe?l0003o00002onh`N400ol0003o_KSDokfhe004okfhe0?o00001?nh`N400ol0003o_KSDokfh
e00;okfhe003o`000?o0/L_o000000co_KSD00?o0000ol2aboo0/L/00oo0/L/00ol0003o_KSDokfh
e006okfhe003o`000?o0/L_o`;7;00Wo`;7;00?o0000okfhe?l000003_o0/L/00ol0003o`Z_3o`00
000<ol2ab`03o`000?o2Zl?o`Z_300?o`Z_30_l0000Yooooo`Co00009oooool005oooooo00?o0000
ooooool000000on/bo05o`0000CoT=?n0_l0000<ojc;l003o`000?nh`N7o000000;o00002On/c?00
0ol0003o^<7QokS1h@0:okS1h@;o00003Onh`N400ol0003o_KSDokfhe002okfhe0;o00002?nh`N40
0ol0003o_KSDokfhe00:okfhe0;o00003_nm^=@00ol0003o`;7;ol2ab`02o`0000Wo_KSD00?o0000
ol2aboo0/L/01oo0/L/2o`0000?o_KSD00?o0000ol2aboo0/L/02oo0/L/2o`0000go`;7;00?o0000
ol:[`oo2Zl<00_o2Zl<00ol0003oooooooooo`0Uooooo`Co0000:oooool0063ooooo00?o0000oooo
ool000000_l0000;oi3CoP03o`000?n/bo3o[<_`00So[<_`1?l0000<ojc<l003o`000?nh`N7o^<7Q
00Ko^<7Q0ol00002ojc<l003o`000?nh`N7o^<7Q00_o^<7Q00Co0000okfhe?l0003o00002onh`N40
0ol0003o_KSDokfhe007okfhe0;o000000?o^<7Qo`000?nm^=@03Onm^=@00ol0003o`;7;o`00000<
okfhe003o`000?o0/L_o`;7;00Co`;7;0_l00005okfhe003o`000?o0/L_o`;7;00[o`;7;00?o0000
okfhe?l000003_o0/L/01?l0003o`Z_3ol:[`ol0000Tooooo`Co0000;oooool0067ooooo00?o0000
ooooooooool00ol0000:oi3CoP;o00000on/bo05o`0000CoT=?n00?o0000ojc<l?n/c?002_n/c?00
0ol0003o^<7QokS1h@03okS1h@;o00001_n/c?000ol0003o^<7QokS1h@0:okS1h@;o00003Onh`N40
0ol0003o_KSDokfhe005okfhe0;o00001?nh`N400ol0003o_KSDokfhe00;okfhe0;o00003Onm^=@0
0ol0003o`;7;ol2ab`03ol2ab`03o`000?nm^=Co_KSD00Ko_KSD00?o0000ol2aboo0/L/01oo0/L/2
o`0000?o_KSD00?o0000ol2aboo0/L/02oo0/L/00ol0003o`Z_3o`00000Qooooo`Co0000<oooool0
06;ooooo0_l00003ooooo`;o00001On@doh8o`0000[oT=?n00?o0000ojc<l?n/c?002_n/c?000ol0
003o^<7Qo`000002o`0000Wo[<c`00?o0000okS1hOnh`N401_nh`N43o`0000;o[<c`00?o0000okS1
hOnh`N402onh`N400ol0003o_KSDokfhe002okfhe0;o00001onh`N400ol0003o_KSDokfhe008okfh
e0;o000000?o^<7Qo`000?nm^=@03Onm^=@00ol0003o`;7;ol2ab`02o`0000[o_KSD00?o0000ol2a
boo0/L/01?o0/L/2o`0000Go_KSD00?o0000ol2aboo0/L/02oo0/L/2o`0001kooooo1?l0000goooo
o`00I?ooool00ol0003oooooooooo`02ooooo`Go00001om<`o83o`0000WoT=?n00?o0000ojc<l?n/
c?001on/c?05o`0000co[<c`00?o0000okS1hOnh`N400onh`N42o`0000Ko[<c`00?o0000okS1hOnh
`N402onh`N401?l0003o_KSDo`000?l0000:okS1h@03o`000?nm^=Co_KSD00Go_KSD0_l00004okS1
h@03o`000?nm^=Co_KSD00_o_KSD00?o0000ol2abol000003?nm^=@00ol0003o`;7;ol2ab`03ol2a
b`03o`000?nm^=Co_KSD00Ko_KSD00?o0000ol2aboo0/L/02?o0/L/2o`0001gooooo0ol0000koooo
o`00IOooool00ol0003oooooooooo`04ooooo`?o00002Om<`o82o`0000SoT=?n00Co0000ojc<l?n/
c?3o[<c`1Ol00005ohoCoP03o`000?n/c?3o[<c`00[o[<c`00?o0000okS1hOl000000_l00009ojc<
l003o`000?nh`N7o^<7Q00Wo^<7Q0ol0000=okS1h@03o`000?nm^=Co_KSD00;o_KSD0_l00007okS1
h@03o`000?nm^=Co_KSD00[o_KSD0_l0000>okfhe003o`000?o0/L_o`;7;00;o00002_nm^=@00ol0
003o`;7;ol2ab`05ol2ab`;o00006oooool4o`0003kooooo001Vooooo`03o`000?oooooooooo00Ko
oooo5ol0000;ohoCoP;o00002On/c?04o`0000co[<c`00?o0000okS1hOnh`N401?nh`N44o`0000;o
[<c`00?o0000okS1hOnh`N403?nh`N401?l0003o_KSDo`000?l0000:okS1h@03o`000?nm^=Co_KSD
00Oo_KSD0_l000000onh`N7o0000okfhe00=okfhe003o`000?o0/L_o000000co_KSD00?o0000ol2a
boo0/L/01?o0/L/00ol0003oooooooooo`0Gooooo`Co0000@_ooool006Oooooo0_l0000Aooooo`Ko
00001Om;`o43o`0000_oSm?n00Co0000ojc<l?n/c?3o[<c`1Ol00004ohoDoP03o`000?n/c?3o[<c`
00[o[<c`00?o0000okS1hOnh`N400ol00007ojc<l003o`000?nh`N7o^<7Q00_o^<7Q0_l0000<okS1
h@03o`000?nm^=Co_KSD00Go_KSD0_l00004okS1h@03o`000?nm^=Co_KSD00_o_KSD0_l0000>okfh
e004o`000?o0/L_o`;7;ol2ab`;o00005_ooool4o`0004Kooooo001Yooooo`03o`000?oooooooooo
01?ooooo1ol00002od_3l@;o00001On?doh8o`0000[oSmCn00?o0000ojc<l?n/c?002?n/c?04o`00
00_o[<c`00?o0000okS1hOnh`N401onh`N43o`000003ojc<lOl0003o^<7Q00co^<7Q00?o0000okfh
e?nm^=@00_nm^=@2o`0000Oo^<7Q00?o0000okfhe?nm^=@02?nm^=@2o`000003okS1hOl0003o_KSD
00go_KSD00Co0000ol2abol0003o00005?ooool4o`0004[ooooo001Zooooo`03o`000?oooooooooo
01Wooooo2Ol00007od_2l@;o00002_n?e?h00ol0003o[<c`ojc<l004ojc<l0?o00001?n?e?h00ol0
003o[<c`ojc<l009ojc<l003o`000?nh`N7o^<7Q00?o^<7Q0ol00005ojc<l@03o`000?nh`N7o^<7Q
00_o^<7Q00Co0000okfhe?l0003o00002_nh`N400ol0003o_KSDokfhe005okfhe0;o00001?nh`N40
0ol0003o_KSDokfhe00;okfhe0;o00004_ooool4o`0004kooooo001[ooooo`03o`000?oooooooooo
023ooooo2?l00002od_2l@;o00002On?e?h00ol0003o[<c`ojc<l003o`0000SoSmCn00?o0000ojc<
l?n/c?002On/c?000ol0003o^<7Qo`000002o`0000Wo[<ca00?o0000okS1hOnh`N402Onh`N43o`00
00go^<7Q00?o0000okfhe?nm^=@00_nm^=@2o`0000Oo^<7Q00?o0000okfhe?nm^=@02?nm^=@2o`00
013ooooo1?l0001Booooo`00K?ooool2o`0002Oooooo4Ol0000<ohoDoP03o`000?n/c?3o[<c`00Oo
[<c`1?l0000<ojc<l@03o`000?nh`N7o^<7Q00Co^<7Q1?l00002ojc<l@03o`000?nh`N7o^<7Q00co
^<7Q00Co0000okfhe?l0003o00002_nh`N400ol0003o_KSDokfhe004okfhe0?o00003_ooool4o`00
05Kooooo001^ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01?ooool4o`0000Ko
BL;`0_l0000;ohoDoP04o`000?n/c?3o[<c`ojc<l0Go00001?n>e?h00ol0003o[<caojc<l@0:ojc<
l@03o`000?nh`N7o^<7Q00?o00001on/c?400ol0003o^<7QokS1h@0;okS1h@;o00003?nh`N400ol0
003o_KSDokfhe002okfhe0;o00003Oooool4o`0005[ooooo001_ooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool01oooool7o`0000;oBL;`0_l00005ohoDoPSo00002_n>e?h2o`0000Wo
[<ca1?l0000;ojc<l@03o`000?nh`N7o^<7Q00Oo^<7Q0ol000000on/c?7o0000okS1h@0<okS1h@04
o`000?nm^=Co0000o`0000cooooo0ol0001Nooooo`00L?ooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo00kooooo2Ol00007odS1l0;o00002on>e?h01?l0003o[<caojc<lOn/c?45o`00
00CoS]Co00?o0000ojc<lOn/c?402On/c?400ol0003o^<7QokS1h@03okS1h@?o00001On/c?400ol0
003o^<7QokS1h@0:okS1h@;o00002_ooool4o`00067ooooo001aooooo`;o00008_ooool00ol0003o
ooooooooo`0Fooooo`So00000_m8`O02o`0000GoS]Cn2?l0000:ohkDo`03o`000?n/c?7o[<ca00Wo
[<ca00?o0000okS1hOl000000_l00009ojc<l@03o`000?nh`N7o^<7Q00Ko^<7Q0ol00008ooooo`Co
0000IOooool007?ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Nooooo`Wo0000
1om7`Nl2o`0000[oS]Co00?o0000ojc<lOn/c?401on/c?44o`0000co[<ca00?o0000okS1hOnh`N40
0onh`N42o`0000Oooooo1?l0001Yooooo`00M?ooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo02Kooooo1ol00003odO1k`03o`000?n>e?ooS]Co00SoS]Co00Co0000ojc<lOn/c?7o[<ca
1Ol00004ohkDo`03o`000?n/c?7o[<ca00[o[<ca00?o0000okS1hOl000000_l00005ooooo`Co0000
KOooool007Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0]oooooa;o00002_n>
e?l00ol0003o[<caojc<l@07ojc<l@Co00001?ooool4o`00077ooooo001fooooo`;o00007Oooool0
0ol0003oooooooooo`0cooooo`Co00001om6`>l2o`0000[oS]Co00Co0000ojc<lOn/c?7o[<ca1Ol0
0004ooooo`Co0000MOooool007Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0f
ooooo`Oo00000om6`>l00ol0003oS]CoohkDo`03ohkDo`So00001Oooool4o`0007Wooooo001ioooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0?Oooool9o`0000[ooooo0ol0001moooo
o`00N_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04cooooo1?l00020ooooo`00
Noooool2o`0001Sooooo00?o0000ooooooooool0B?ooool4o`0008Cooooo001mooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0A?ooool4o`0008Sooooo001nooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool0@?ooool4o`0008cooooo001oooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool0?Oooool4o`00093ooooo0020ooooo`;o00004_ooool00ol0003o
ooooooooo`0iooooo`Co0000U?ooool008;ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0eooooo`Co0000V?ooool008?ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0aooooo`Co0000W?ooool008Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0^
ooooo`?o0000X?ooool008Gooooo0_l0000=ooooo`03o`000?oooooooooo02[ooooo1?l0002Soooo
o`00Qoooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Kooooo1?l0002Wooooo`00
R?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;ooooo1?l0002[ooooo`00ROoo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01kooooo1?l0002_ooooo`00R_ooool2
o`0000Sooooo00?o0000ooooooooool06_ooool4o`000;?ooooo002<ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool05_ooool4o`000;Oooooo002=ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool04_ooool4o`000;_ooooo002>ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool03_ooool4o`000;oooooo002?ooooo`;o00000oooool00ol0003ooooooooo
o`0;ooooo`?o0000`oooool0097ooooo00Co0000oooooooooooo00002Oooool4o`000<Kooooo002B
ooooo`03o`000?oooooo000000Gooooo1?l0003:ooooo`00Toooool2o`000003ooooool0003o0000
00;o0000c_ooool009Cooooo0_l0003Booooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0418495, 0.0166322, \
0.00355091, 0.00355091}}]
}, Open  ]],

Cell[TextData[{
  "The potential is minimized along the diagonal where the density is \
maximum, but also goes to zero at the box vertices due to the periodic \
boundary conditions: the mass distribution in surrounding boxes affects the \
potential. In Cell ",
  ButtonBox["7.73",
    ButtonData:>"Cell 7.73",
    ButtonStyle->"Hyperlink"],
  ", we show the resulting force field, evaluated on the grid."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(field\  = \ 
        Table[{{i\ \[CapitalDelta]x, 
              j\ \[CapitalDelta]y}, {\(Fx[\([i + 1, 
                      j + 1]\)]\)[\([3]\)], \(Fy[\([i + 1, 
                      j + 1]\)]\)[\([3]\)]} 0.001}, {i, 0, M - 1}, {j, 0, 
            M - 1}];\)\), "\n", 
    \(\(ListPlotVectorField[Flatten[field, 1], 
        Axes \[Rule] True];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.73"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0744689 0.895855 0.0744689 0.895855 [
[.25364 .06197 -9 -9 ]
[.25364 .06197 9 0 ]
[.43281 .06197 -9 -9 ]
[.43281 .06197 9 0 ]
[.61198 .06197 -9 -9 ]
[.61198 .06197 9 0 ]
[.79115 .06197 -9 -9 ]
[.79115 .06197 9 0 ]
[.97032 .06197 -3 -9 ]
[.97032 .06197 3 0 ]
[.06197 .25364 -18 -4.5 ]
[.06197 .25364 0 4.5 ]
[.06197 .43281 -18 -4.5 ]
[.06197 .43281 0 4.5 ]
[.06197 .61198 -18 -4.5 ]
[.06197 .61198 0 4.5 ]
[.06197 .79115 -18 -4.5 ]
[.06197 .79115 0 4.5 ]
[.06197 .97032 -6 -4.5 ]
[.06197 .97032 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.25364 .07447 m
.25364 .08072 L
s
[(0.2)] .25364 .06197 0 1 Mshowa
.43281 .07447 m
.43281 .08072 L
s
[(0.4)] .43281 .06197 0 1 Mshowa
.61198 .07447 m
.61198 .08072 L
s
[(0.6)] .61198 .06197 0 1 Mshowa
.79115 .07447 m
.79115 .08072 L
s
[(0.8)] .79115 .06197 0 1 Mshowa
.97032 .07447 m
.97032 .08072 L
s
[(1)] .97032 .06197 0 1 Mshowa
.125 Mabswid
.11926 .07447 m
.11926 .07822 L
s
.16405 .07447 m
.16405 .07822 L
s
.20885 .07447 m
.20885 .07822 L
s
.29843 .07447 m
.29843 .07822 L
s
.34323 .07447 m
.34323 .07822 L
s
.38802 .07447 m
.38802 .07822 L
s
.4776 .07447 m
.4776 .07822 L
s
.5224 .07447 m
.5224 .07822 L
s
.56719 .07447 m
.56719 .07822 L
s
.65677 .07447 m
.65677 .07822 L
s
.70157 .07447 m
.70157 .07822 L
s
.74636 .07447 m
.74636 .07822 L
s
.83595 .07447 m
.83595 .07822 L
s
.88074 .07447 m
.88074 .07822 L
s
.92553 .07447 m
.92553 .07822 L
s
.02968 .07447 m
.02968 .07822 L
s
.25 Mabswid
0 .07447 m
1 .07447 L
s
.07447 .25364 m
.08072 .25364 L
s
[(0.2)] .06197 .25364 1 0 Mshowa
.07447 .43281 m
.08072 .43281 L
s
[(0.4)] .06197 .43281 1 0 Mshowa
.07447 .61198 m
.08072 .61198 L
s
[(0.6)] .06197 .61198 1 0 Mshowa
.07447 .79115 m
.08072 .79115 L
s
[(0.8)] .06197 .79115 1 0 Mshowa
.07447 .97032 m
.08072 .97032 L
s
[(1)] .06197 .97032 1 0 Mshowa
.125 Mabswid
.07447 .11926 m
.07822 .11926 L
s
.07447 .16405 m
.07822 .16405 L
s
.07447 .20885 m
.07822 .20885 L
s
.07447 .29843 m
.07822 .29843 L
s
.07447 .34323 m
.07822 .34323 L
s
.07447 .38802 m
.07822 .38802 L
s
.07447 .4776 m
.07822 .4776 L
s
.07447 .5224 m
.07822 .5224 L
s
.07447 .56719 m
.07822 .56719 L
s
.07447 .65677 m
.07822 .65677 L
s
.07447 .70157 m
.07822 .70157 L
s
.07447 .74636 m
.07822 .74636 L
s
.07447 .83595 m
.07822 .83595 L
s
.07447 .88074 m
.07822 .88074 L
s
.07447 .92553 m
.07822 .92553 L
s
.07447 .02968 m
.07822 .02968 L
s
.25 Mabswid
.07447 0 m
.07447 1 L
s
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
0 0 Mdot
grestore
} def
% End of user PostScript
.0001 w
.07447 .07447 m
.07447 .07447 L
s
% Start of user PostScript
0 0 MAarrowzero1
% End of user PostScript
.07447 .11926 m
.12513 .0686 L
s
% Start of user PostScript
0 0.05 0.0565487 -0.00654867 MAarrowhead1
% End of user PostScript
.07447 .16405 m
.1195 .11902 L
s
% Start of user PostScript
0 0.1 0.0502655 0.0497345 MAarrowhead1
% End of user PostScript
.07447 .20885 m
.11387 .16945 L
s
% Start of user PostScript
0 0.15 0.0439823 0.106018 MAarrowhead1
% End of user PostScript
.07447 .25364 m
.10824 .21987 L
s
% Start of user PostScript
0 0.2 0.0376991 0.162301 MAarrowhead1
% End of user PostScript
.07447 .29843 m
.10261 .27029 L
s
% Start of user PostScript
0 0.25 0.0314159 0.218584 MAarrowhead1
% End of user PostScript
.07447 .34323 m
.09698 .32071 L
s
% Start of user PostScript
0 0.3 0.0251327 0.274867 MAarrowhead1
% End of user PostScript
.07447 .38802 m
.09136 .37113 L
s
% Start of user PostScript
0 0.35 0.0188496 0.33115 MAarrowhead1
% End of user PostScript
.07447 .43281 m
.08573 .42155 L
s
% Start of user PostScript
0 0.4 0.0125664 0.387434 MAarrowhead1
% End of user PostScript
.07447 .4776 m
.0801 .47197 L
s
% Start of user PostScript
0 0.45 0.00628319 0.443717 MAarrowhead1
% End of user PostScript
.07447 .5224 m
.07447 .5224 L
s
% Start of user PostScript
0 0.5 MAarrowzero1
% End of user PostScript
.07447 .56719 m
.06884 .57282 L
s
% Start of user PostScript
0 0.55 -0.00628319 0.556283 MAarrowhead1
% End of user PostScript
.07447 .61198 m
.06321 .62324 L
s
% Start of user PostScript
0 0.6 -0.0125664 0.612566 MAarrowhead1
% End of user PostScript
.07447 .65677 m
.05758 .67366 L
s
% Start of user PostScript
0 0.65 -0.0188496 0.66885 MAarrowhead1
% End of user PostScript
.07447 .70157 m
.05195 .72408 L
s
% Start of user PostScript
0 0.7 -0.0251327 0.725133 MAarrowhead1
% End of user PostScript
.07447 .74636 m
.04632 .7745 L
s
% Start of user PostScript
0 0.75 -0.0314159 0.781416 MAarrowhead1
% End of user PostScript
.07447 .79115 m
.0407 .82493 L
s
% Start of user PostScript
0 0.8 -0.0376991 0.837699 MAarrowhead1
% End of user PostScript
.07447 .83595 m
.03507 .87535 L
s
% Start of user PostScript
0 0.85 -0.0439823 0.893982 MAarrowhead1
% End of user PostScript
.07447 .88074 m
.02944 .92577 L
s
% Start of user PostScript
0 0.9 -0.0502655 0.950265 MAarrowhead1
% End of user PostScript
.07447 .92553 m
.02381 .97619 L
s
% Start of user PostScript
0 0.95 -0.0565487 1.00655 MAarrowhead1
% End of user PostScript
.11926 .07447 m
.0686 .12513 L
s
% Start of user PostScript
0.05 0 -0.00654867 0.0565487 MAarrowhead1
% End of user PostScript
.11926 .11926 m
.11926 .11926 L
s
% Start of user PostScript
0.05 0.05 MAarrowzero1
% End of user PostScript
.11926 .16405 m
.16992 .1134 L
s
% Start of user PostScript
0.05 0.1 0.106549 0.0434513 MAarrowhead1
% End of user PostScript
.11926 .20885 m
.16429 .16382 L
s
% Start of user PostScript
0.05 0.15 0.100265 0.0997345 MAarrowhead1
% End of user PostScript
.11926 .25364 m
.15866 .21424 L
s
% Start of user PostScript
0.05 0.2 0.0939823 0.156018 MAarrowhead1
% End of user PostScript
.11926 .29843 m
.15303 .26466 L
s
% Start of user PostScript
0.05 0.25 0.0876991 0.212301 MAarrowhead1
% End of user PostScript
.11926 .34323 m
.14741 .31508 L
s
% Start of user PostScript
0.05 0.3 0.0814159 0.268584 MAarrowhead1
% End of user PostScript
.11926 .38802 m
.14178 .3655 L
s
% Start of user PostScript
0.05 0.35 0.0751327 0.324867 MAarrowhead1
% End of user PostScript
.11926 .43281 m
.13615 .41592 L
s
% Start of user PostScript
0.05 0.4 0.0688496 0.38115 MAarrowhead1
% End of user PostScript
.11926 .4776 m
.13052 .46635 L
s
% Start of user PostScript
0.05 0.45 0.0625664 0.437434 MAarrowhead1
% End of user PostScript
.11926 .5224 m
.12489 .51677 L
s
% Start of user PostScript
0.05 0.5 0.0562832 0.493717 MAarrowhead1
% End of user PostScript
.11926 .56719 m
.11926 .56719 L
s
% Start of user PostScript
0.05 0.55 MAarrowzero1
% End of user PostScript
.11926 .61198 m
.11363 .61761 L
s
% Start of user PostScript
0.05 0.6 0.0437168 0.606283 MAarrowhead1
% End of user PostScript
.11926 .65677 m
.108 .66803 L
s
% Start of user PostScript
0.05 0.65 0.0374336 0.662566 MAarrowhead1
% End of user PostScript
.11926 .70157 m
.10238 .71845 L
s
% Start of user PostScript
0.05 0.7 0.0311504 0.71885 MAarrowhead1
% End of user PostScript
.11926 .74636 m
.09675 .76888 L
s
% Start of user PostScript
0.05 0.75 0.0248673 0.775133 MAarrowhead1
% End of user PostScript
.11926 .79115 m
.09112 .8193 L
s
% Start of user PostScript
0.05 0.8 0.0185841 0.831416 MAarrowhead1
% End of user PostScript
.11926 .83595 m
.08549 .86972 L
s
% Start of user PostScript
0.05 0.85 0.0123009 0.887699 MAarrowhead1
% End of user PostScript
.11926 .88074 m
.07986 .92014 L
s
% Start of user PostScript
0.05 0.9 0.0060177 0.943982 MAarrowhead1
% End of user PostScript
.11926 .92553 m
.07423 .97056 L
s
% Start of user PostScript
0.05 0.95 -0.000265482 1.00027 MAarrowhead1
% End of user PostScript
.16405 .07447 m
.11902 .1195 L
s
% Start of user PostScript
0.1 0 0.0497345 0.0502655 MAarrowhead1
% End of user PostScript
.16405 .11926 m
.1134 .16992 L
s
% Start of user PostScript
0.1 0.05 0.0434513 0.106549 MAarrowhead1
% End of user PostScript
.16405 .16405 m
.16405 .16405 L
s
% Start of user PostScript
0.1 0.1 MAarrowzero1
% End of user PostScript
.16405 .20885 m
.21471 .15819 L
s
% Start of user PostScript
0.1 0.15 0.156549 0.0934513 MAarrowhead1
% End of user PostScript
.16405 .25364 m
.20908 .20861 L
s
% Start of user PostScript
0.1 0.2 0.150265 0.149735 MAarrowhead1
% End of user PostScript
.16405 .29843 m
.20346 .25903 L
s
% Start of user PostScript
0.1 0.25 0.143982 0.206018 MAarrowhead1
% End of user PostScript
.16405 .34323 m
.19783 .30945 L
s
% Start of user PostScript
0.1 0.3 0.137699 0.262301 MAarrowhead1
% End of user PostScript
.16405 .38802 m
.1922 .35987 L
s
% Start of user PostScript
0.1 0.35 0.131416 0.318584 MAarrowhead1
% End of user PostScript
.16405 .43281 m
.18657 .4103 L
s
% Start of user PostScript
0.1 0.4 0.125133 0.374867 MAarrowhead1
% End of user PostScript
.16405 .4776 m
.18094 .46072 L
s
% Start of user PostScript
0.1 0.45 0.11885 0.43115 MAarrowhead1
% End of user PostScript
.16405 .5224 m
.17531 .51114 L
s
% Start of user PostScript
0.1 0.5 0.112566 0.487434 MAarrowhead1
% End of user PostScript
.16405 .56719 m
.16968 .56156 L
s
% Start of user PostScript
0.1 0.55 0.106283 0.543717 MAarrowhead1
% End of user PostScript
.16405 .61198 m
.16405 .61198 L
s
% Start of user PostScript
0.1 0.6 MAarrowzero1
% End of user PostScript
.16405 .65677 m
.15843 .6624 L
s
% Start of user PostScript
0.1 0.65 0.0937168 0.656283 MAarrowhead1
% End of user PostScript
.16405 .70157 m
.1528 .71282 L
s
% Start of user PostScript
0.1 0.7 0.0874336 0.712566 MAarrowhead1
% End of user PostScript
.16405 .74636 m
.14717 .76325 L
s
% Start of user PostScript
0.1 0.75 0.0811504 0.76885 MAarrowhead1
% End of user PostScript
.16405 .79115 m
.14154 .81367 L
s
% Start of user PostScript
0.1 0.8 0.0748673 0.825133 MAarrowhead1
% End of user PostScript
.16405 .83595 m
.13591 .86409 L
s
% Start of user PostScript
0.1 0.85 0.0685841 0.881416 MAarrowhead1
% End of user PostScript
.16405 .88074 m
.13028 .91451 L
s
% Start of user PostScript
0.1 0.9 0.0623009 0.937699 MAarrowhead1
% End of user PostScript
.16405 .92553 m
.12465 .96493 L
s
% Start of user PostScript
0.1 0.95 0.0560177 0.993982 MAarrowhead1
% End of user PostScript
.20885 .07447 m
.16945 .11387 L
s
% Start of user PostScript
0.15 0 0.106018 0.0439823 MAarrowhead1
% End of user PostScript
.20885 .11926 m
.16382 .16429 L
s
% Start of user PostScript
0.15 0.05 0.0997345 0.100265 MAarrowhead1
% End of user PostScript
.20885 .16405 m
.15819 .21471 L
s
% Start of user PostScript
0.15 0.1 0.0934513 0.156549 MAarrowhead1
% End of user PostScript
.20885 .20885 m
.20885 .20885 L
s
% Start of user PostScript
0.15 0.15 MAarrowzero1
% End of user PostScript
.20885 .25364 m
.25951 .20298 L
s
% Start of user PostScript
0.15 0.2 0.206549 0.143451 MAarrowhead1
% End of user PostScript
.20885 .29843 m
.25388 .2534 L
s
% Start of user PostScript
0.15 0.25 0.200265 0.199735 MAarrowhead1
% End of user PostScript
.20885 .34323 m
.24825 .30382 L
s
% Start of user PostScript
0.15 0.3 0.193982 0.256018 MAarrowhead1
% End of user PostScript
.20885 .38802 m
.24262 .35425 L
s
% Start of user PostScript
0.15 0.35 0.187699 0.312301 MAarrowhead1
% End of user PostScript
.20885 .43281 m
.23699 .40467 L
s
% Start of user PostScript
0.15 0.4 0.181416 0.368584 MAarrowhead1
% End of user PostScript
.20885 .4776 m
.23136 .45509 L
s
% Start of user PostScript
0.15 0.45 0.175133 0.424867 MAarrowhead1
% End of user PostScript
.20885 .5224 m
.22573 .50551 L
s
% Start of user PostScript
0.15 0.5 0.16885 0.48115 MAarrowhead1
% End of user PostScript
.20885 .56719 m
.2201 .55593 L
s
% Start of user PostScript
0.15 0.55 0.162566 0.537434 MAarrowhead1
% End of user PostScript
.20885 .61198 m
.21448 .60635 L
s
% Start of user PostScript
0.15 0.6 0.156283 0.593717 MAarrowhead1
% End of user PostScript
.20885 .65677 m
.20885 .65677 L
s
% Start of user PostScript
0.15 0.65 MAarrowzero1
% End of user PostScript
.20885 .70157 m
.20322 .7072 L
s
% Start of user PostScript
0.15 0.7 0.143717 0.706283 MAarrowhead1
% End of user PostScript
.20885 .74636 m
.19759 .75762 L
s
% Start of user PostScript
0.15 0.75 0.137434 0.762566 MAarrowhead1
% End of user PostScript
.20885 .79115 m
.19196 .80804 L
s
% Start of user PostScript
0.15 0.8 0.13115 0.81885 MAarrowhead1
% End of user PostScript
.20885 .83595 m
.18633 .85846 L
s
% Start of user PostScript
0.15 0.85 0.124867 0.875133 MAarrowhead1
% End of user PostScript
.20885 .88074 m
.1807 .90888 L
s
% Start of user PostScript
0.15 0.9 0.118584 0.931416 MAarrowhead1
% End of user PostScript
.20885 .92553 m
.17507 .9593 L
s
% Start of user PostScript
0.15 0.95 0.112301 0.987699 MAarrowhead1
% End of user PostScript
.25364 .07447 m
.21987 .10824 L
s
% Start of user PostScript
0.2 0 0.162301 0.0376991 MAarrowhead1
% End of user PostScript
.25364 .11926 m
.21424 .15866 L
s
% Start of user PostScript
0.2 0.05 0.156018 0.0939823 MAarrowhead1
% End of user PostScript
.25364 .16405 m
.20861 .20908 L
s
% Start of user PostScript
0.2 0.1 0.149735 0.150265 MAarrowhead1
% End of user PostScript
.25364 .20885 m
.20298 .25951 L
s
% Start of user PostScript
0.2 0.15 0.143451 0.206549 MAarrowhead1
% End of user PostScript
.25364 .25364 m
.25364 .25364 L
s
% Start of user PostScript
0.2 0.2 MAarrowzero1
% End of user PostScript
.25364 .29843 m
.3043 .24777 L
s
% Start of user PostScript
0.2 0.25 0.256549 0.193451 MAarrowhead1
% End of user PostScript
.25364 .34323 m
.29867 .29819 L
s
% Start of user PostScript
0.2 0.3 0.250265 0.249735 MAarrowhead1
% End of user PostScript
.25364 .38802 m
.29304 .34862 L
s
% Start of user PostScript
0.2 0.35 0.243982 0.306018 MAarrowhead1
% End of user PostScript
.25364 .43281 m
.28741 .39904 L
s
% Start of user PostScript
0.2 0.4 0.237699 0.362301 MAarrowhead1
% End of user PostScript
.25364 .4776 m
.28178 .44946 L
s
% Start of user PostScript
0.2 0.45 0.231416 0.418584 MAarrowhead1
% End of user PostScript
.25364 .5224 m
.27616 .49988 L
s
% Start of user PostScript
0.2 0.5 0.225133 0.474867 MAarrowhead1
% End of user PostScript
.25364 .56719 m
.27053 .5503 L
s
% Start of user PostScript
0.2 0.55 0.21885 0.53115 MAarrowhead1
% End of user PostScript
.25364 .61198 m
.2649 .60072 L
s
% Start of user PostScript
0.2 0.6 0.212566 0.587434 MAarrowhead1
% End of user PostScript
.25364 .65677 m
.25927 .65115 L
s
% Start of user PostScript
0.2 0.65 0.206283 0.643717 MAarrowhead1
% End of user PostScript
.25364 .70157 m
.25364 .70157 L
s
% Start of user PostScript
0.2 0.7 MAarrowzero1
% End of user PostScript
.25364 .74636 m
.24801 .75199 L
s
% Start of user PostScript
0.2 0.75 0.193717 0.756283 MAarrowhead1
% End of user PostScript
.25364 .79115 m
.24238 .80241 L
s
% Start of user PostScript
0.2 0.8 0.187434 0.812566 MAarrowhead1
% End of user PostScript
.25364 .83595 m
.23675 .85283 L
s
% Start of user PostScript
0.2 0.85 0.18115 0.86885 MAarrowhead1
% End of user PostScript
.25364 .88074 m
.23112 .90325 L
s
% Start of user PostScript
0.2 0.9 0.174867 0.925133 MAarrowhead1
% End of user PostScript
.25364 .92553 m
.2255 .95368 L
s
% Start of user PostScript
0.2 0.95 0.168584 0.981416 MAarrowhead1
% End of user PostScript
.29843 .07447 m
.27029 .10261 L
s
% Start of user PostScript
0.25 0 0.218584 0.0314159 MAarrowhead1
% End of user PostScript
.29843 .11926 m
.26466 .15303 L
s
% Start of user PostScript
0.25 0.05 0.212301 0.0876991 MAarrowhead1
% End of user PostScript
.29843 .16405 m
.25903 .20346 L
s
% Start of user PostScript
0.25 0.1 0.206018 0.143982 MAarrowhead1
% End of user PostScript
.29843 .20885 m
.2534 .25388 L
s
% Start of user PostScript
0.25 0.15 0.199735 0.200265 MAarrowhead1
% End of user PostScript
.29843 .25364 m
.24777 .3043 L
s
% Start of user PostScript
0.25 0.2 0.193451 0.256549 MAarrowhead1
% End of user PostScript
.29843 .29843 m
.29843 .29843 L
s
% Start of user PostScript
0.25 0.25 MAarrowzero1
% End of user PostScript
.29843 .34323 m
.34909 .29257 L
s
% Start of user PostScript
0.25 0.3 0.306549 0.243451 MAarrowhead1
% End of user PostScript
.29843 .38802 m
.34346 .34299 L
s
% Start of user PostScript
0.25 0.35 0.300265 0.299735 MAarrowhead1
% End of user PostScript
.29843 .43281 m
.33783 .39341 L
s
% Start of user PostScript
0.25 0.4 0.293982 0.356018 MAarrowhead1
% End of user PostScript
.29843 .4776 m
.33221 .44383 L
s
% Start of user PostScript
0.25 0.45 0.287699 0.412301 MAarrowhead1
% End of user PostScript
.29843 .5224 m
.32658 .49425 L
s
% Start of user PostScript
0.25 0.5 0.281416 0.468584 MAarrowhead1
% End of user PostScript
.29843 .56719 m
.32095 .54467 L
s
% Start of user PostScript
0.25 0.55 0.275133 0.524867 MAarrowhead1
% End of user PostScript
.29843 .61198 m
.31532 .5951 L
s
% Start of user PostScript
0.25 0.6 0.26885 0.58115 MAarrowhead1
% End of user PostScript
.29843 .65677 m
.30969 .64552 L
s
% Start of user PostScript
0.25 0.65 0.262566 0.637434 MAarrowhead1
% End of user PostScript
.29843 .70157 m
.30406 .69594 L
s
% Start of user PostScript
0.25 0.7 0.256283 0.693717 MAarrowhead1
% End of user PostScript
.29843 .74636 m
.29843 .74636 L
s
% Start of user PostScript
0.25 0.75 MAarrowzero1
% End of user PostScript
.29843 .79115 m
.2928 .79678 L
s
% Start of user PostScript
0.25 0.8 0.243717 0.806283 MAarrowhead1
% End of user PostScript
.29843 .83595 m
.28718 .8472 L
s
% Start of user PostScript
0.25 0.85 0.237434 0.862566 MAarrowhead1
% End of user PostScript
.29843 .88074 m
.28155 .89762 L
s
% Start of user PostScript
0.25 0.9 0.23115 0.91885 MAarrowhead1
% End of user PostScript
.29843 .92553 m
.27592 .94805 L
s
% Start of user PostScript
0.25 0.95 0.224867 0.975133 MAarrowhead1
% End of user PostScript
.34323 .07447 m
.32071 .09698 L
s
% Start of user PostScript
0.3 0 0.274867 0.0251327 MAarrowhead1
% End of user PostScript
.34323 .11926 m
.31508 .14741 L
s
% Start of user PostScript
0.3 0.05 0.268584 0.0814159 MAarrowhead1
% End of user PostScript
.34323 .16405 m
.30945 .19783 L
s
% Start of user PostScript
0.3 0.1 0.262301 0.137699 MAarrowhead1
% End of user PostScript
.34323 .20885 m
.30382 .24825 L
s
% Start of user PostScript
0.3 0.15 0.256018 0.193982 MAarrowhead1
% End of user PostScript
.34323 .25364 m
.29819 .29867 L
s
% Start of user PostScript
0.3 0.2 0.249735 0.250265 MAarrowhead1
% End of user PostScript
.34323 .29843 m
.29257 .34909 L
s
% Start of user PostScript
0.3 0.25 0.243451 0.306549 MAarrowhead1
% End of user PostScript
.34323 .34323 m
.34323 .34323 L
s
% Start of user PostScript
0.3 0.3 MAarrowzero1
% End of user PostScript
.34323 .38802 m
.39388 .33736 L
s
% Start of user PostScript
0.3 0.35 0.356549 0.293451 MAarrowhead1
% End of user PostScript
.34323 .43281 m
.38826 .38778 L
s
% Start of user PostScript
0.3 0.4 0.350265 0.349735 MAarrowhead1
% End of user PostScript
.34323 .4776 m
.38263 .4382 L
s
% Start of user PostScript
0.3 0.45 0.343982 0.406018 MAarrowhead1
% End of user PostScript
.34323 .5224 m
.377 .48862 L
s
% Start of user PostScript
0.3 0.5 0.337699 0.462301 MAarrowhead1
% End of user PostScript
.34323 .56719 m
.37137 .53905 L
s
% Start of user PostScript
0.3 0.55 0.331416 0.518584 MAarrowhead1
% End of user PostScript
.34323 .61198 m
.36574 .58947 L
s
% Start of user PostScript
0.3 0.6 0.325133 0.574867 MAarrowhead1
% End of user PostScript
.34323 .65677 m
.36011 .63989 L
s
% Start of user PostScript
0.3 0.65 0.31885 0.63115 MAarrowhead1
% End of user PostScript
.34323 .70157 m
.35448 .69031 L
s
% Start of user PostScript
0.3 0.7 0.312566 0.687434 MAarrowhead1
% End of user PostScript
.34323 .74636 m
.34885 .74073 L
s
% Start of user PostScript
0.3 0.75 0.306283 0.743717 MAarrowhead1
% End of user PostScript
.34323 .79115 m
.34323 .79115 L
s
% Start of user PostScript
0.3 0.8 MAarrowzero1
% End of user PostScript
.34323 .83595 m
.3376 .84157 L
s
% Start of user PostScript
0.3 0.85 0.293717 0.856283 MAarrowhead1
% End of user PostScript
.34323 .88074 m
.33197 .892 L
s
% Start of user PostScript
0.3 0.9 0.287434 0.912566 MAarrowhead1
% End of user PostScript
.34323 .92553 m
.32634 .94242 L
s
% Start of user PostScript
0.3 0.95 0.28115 0.96885 MAarrowhead1
% End of user PostScript
.38802 .07447 m
.37113 .09136 L
s
% Start of user PostScript
0.35 0 0.33115 0.0188496 MAarrowhead1
% End of user PostScript
.38802 .11926 m
.3655 .14178 L
s
% Start of user PostScript
0.35 0.05 0.324867 0.0751327 MAarrowhead1
% End of user PostScript
.38802 .16405 m
.35987 .1922 L
s
% Start of user PostScript
0.35 0.1 0.318584 0.131416 MAarrowhead1
% End of user PostScript
.38802 .20885 m
.35425 .24262 L
s
% Start of user PostScript
0.35 0.15 0.312301 0.187699 MAarrowhead1
% End of user PostScript
.38802 .25364 m
.34862 .29304 L
s
% Start of user PostScript
0.35 0.2 0.306018 0.243982 MAarrowhead1
% End of user PostScript
.38802 .29843 m
.34299 .34346 L
s
% Start of user PostScript
0.35 0.25 0.299735 0.300265 MAarrowhead1
% End of user PostScript
.38802 .34323 m
.33736 .39388 L
s
% Start of user PostScript
0.35 0.3 0.293451 0.356549 MAarrowhead1
% End of user PostScript
.38802 .38802 m
.38802 .38802 L
s
% Start of user PostScript
0.35 0.35 MAarrowzero1
% End of user PostScript
.38802 .43281 m
.43868 .38215 L
s
% Start of user PostScript
0.35 0.4 0.406549 0.343451 MAarrowhead1
% End of user PostScript
.38802 .4776 m
.43305 .43257 L
s
% Start of user PostScript
0.35 0.45 0.400265 0.399735 MAarrowhead1
% End of user PostScript
.38802 .5224 m
.42742 .48299 L
s
% Start of user PostScript
0.35 0.5 0.393982 0.456018 MAarrowhead1
% End of user PostScript
.38802 .56719 m
.42179 .53342 L
s
% Start of user PostScript
0.35 0.55 0.387699 0.512301 MAarrowhead1
% End of user PostScript
.38802 .61198 m
.41616 .58384 L
s
% Start of user PostScript
0.35 0.6 0.381416 0.568584 MAarrowhead1
% End of user PostScript
.38802 .65677 m
.41053 .63426 L
s
% Start of user PostScript
0.35 0.65 0.375133 0.624867 MAarrowhead1
% End of user PostScript
.38802 .70157 m
.4049 .68468 L
s
% Start of user PostScript
0.35 0.7 0.36885 0.68115 MAarrowhead1
% End of user PostScript
.38802 .74636 m
.39928 .7351 L
s
% Start of user PostScript
0.35 0.75 0.362566 0.737434 MAarrowhead1
% End of user PostScript
.38802 .79115 m
.39365 .78552 L
s
% Start of user PostScript
0.35 0.8 0.356283 0.793717 MAarrowhead1
% End of user PostScript
.38802 .83595 m
.38802 .83595 L
s
% Start of user PostScript
0.35 0.85 MAarrowzero1
% End of user PostScript
.38802 .88074 m
.38239 .88637 L
s
% Start of user PostScript
0.35 0.9 0.343717 0.906283 MAarrowhead1
% End of user PostScript
.38802 .92553 m
.37676 .93679 L
s
% Start of user PostScript
0.35 0.95 0.337434 0.962566 MAarrowhead1
% End of user PostScript
.43281 .07447 m
.42155 .08573 L
s
% Start of user PostScript
0.4 0 0.387434 0.0125664 MAarrowhead1
% End of user PostScript
.43281 .11926 m
.41592 .13615 L
s
% Start of user PostScript
0.4 0.05 0.38115 0.0688496 MAarrowhead1
% End of user PostScript
.43281 .16405 m
.4103 .18657 L
s
% Start of user PostScript
0.4 0.1 0.374867 0.125133 MAarrowhead1
% End of user PostScript
.43281 .20885 m
.40467 .23699 L
s
% Start of user PostScript
0.4 0.15 0.368584 0.181416 MAarrowhead1
% End of user PostScript
.43281 .25364 m
.39904 .28741 L
s
% Start of user PostScript
0.4 0.2 0.362301 0.237699 MAarrowhead1
% End of user PostScript
.43281 .29843 m
.39341 .33783 L
s
% Start of user PostScript
0.4 0.25 0.356018 0.293982 MAarrowhead1
% End of user PostScript
.43281 .34323 m
.38778 .38826 L
s
% Start of user PostScript
0.4 0.3 0.349735 0.350265 MAarrowhead1
% End of user PostScript
.43281 .38802 m
.38215 .43868 L
s
% Start of user PostScript
0.4 0.35 0.343451 0.406549 MAarrowhead1
% End of user PostScript
.43281 .43281 m
.43281 .43281 L
s
% Start of user PostScript
0.4 0.4 MAarrowzero1
% End of user PostScript
.43281 .4776 m
.48347 .42694 L
s
% Start of user PostScript
0.4 0.45 0.456549 0.393451 MAarrowhead1
% End of user PostScript
.43281 .5224 m
.47784 .47737 L
s
% Start of user PostScript
0.4 0.5 0.450265 0.449735 MAarrowhead1
% End of user PostScript
.43281 .56719 m
.47221 .52779 L
s
% Start of user PostScript
0.4 0.55 0.443982 0.506018 MAarrowhead1
% End of user PostScript
.43281 .61198 m
.46658 .57821 L
s
% Start of user PostScript
0.4 0.6 0.437699 0.562301 MAarrowhead1
% End of user PostScript
.43281 .65677 m
.46095 .62863 L
s
% Start of user PostScript
0.4 0.65 0.431416 0.618584 MAarrowhead1
% End of user PostScript
.43281 .70157 m
.45533 .67905 L
s
% Start of user PostScript
0.4 0.7 0.425133 0.674867 MAarrowhead1
% End of user PostScript
.43281 .74636 m
.4497 .72947 L
s
% Start of user PostScript
0.4 0.75 0.41885 0.73115 MAarrowhead1
% End of user PostScript
.43281 .79115 m
.44407 .7799 L
s
% Start of user PostScript
0.4 0.8 0.412566 0.787434 MAarrowhead1
% End of user PostScript
.43281 .83595 m
.43844 .83032 L
s
% Start of user PostScript
0.4 0.85 0.406283 0.843717 MAarrowhead1
% End of user PostScript
.43281 .88074 m
.43281 .88074 L
s
% Start of user PostScript
0.4 0.9 MAarrowzero1
% End of user PostScript
.43281 .92553 m
.42718 .93116 L
s
% Start of user PostScript
0.4 0.95 0.393717 0.956283 MAarrowhead1
% End of user PostScript
.4776 .07447 m
.47197 .0801 L
s
% Start of user PostScript
0.45 0 0.443717 0.00628319 MAarrowhead1
% End of user PostScript
.4776 .11926 m
.46635 .13052 L
s
% Start of user PostScript
0.45 0.05 0.437434 0.0625664 MAarrowhead1
% End of user PostScript
.4776 .16405 m
.46072 .18094 L
s
% Start of user PostScript
0.45 0.1 0.43115 0.11885 MAarrowhead1
% End of user PostScript
.4776 .20885 m
.45509 .23136 L
s
% Start of user PostScript
0.45 0.15 0.424867 0.175133 MAarrowhead1
% End of user PostScript
.4776 .25364 m
.44946 .28178 L
s
% Start of user PostScript
0.45 0.2 0.418584 0.231416 MAarrowhead1
% End of user PostScript
.4776 .29843 m
.44383 .33221 L
s
% Start of user PostScript
0.45 0.25 0.412301 0.287699 MAarrowhead1
% End of user PostScript
.4776 .34323 m
.4382 .38263 L
s
% Start of user PostScript
0.45 0.3 0.406018 0.343982 MAarrowhead1
% End of user PostScript
.4776 .38802 m
.43257 .43305 L
s
% Start of user PostScript
0.45 0.35 0.399735 0.400265 MAarrowhead1
% End of user PostScript
.4776 .43281 m
.42694 .48347 L
s
% Start of user PostScript
0.45 0.4 0.393451 0.456549 MAarrowhead1
% End of user PostScript
.4776 .4776 m
.4776 .4776 L
s
% Start of user PostScript
0.45 0.45 MAarrowzero1
% End of user PostScript
.4776 .5224 m
.52826 .47174 L
s
% Start of user PostScript
0.45 0.5 0.506549 0.443451 MAarrowhead1
% End of user PostScript
.4776 .56719 m
.52263 .52216 L
s
% Start of user PostScript
0.45 0.55 0.500265 0.499735 MAarrowhead1
% End of user PostScript
.4776 .61198 m
.51701 .57258 L
s
% Start of user PostScript
0.45 0.6 0.493982 0.556018 MAarrowhead1
% End of user PostScript
.4776 .65677 m
.51138 .623 L
s
% Start of user PostScript
0.45 0.65 0.487699 0.612301 MAarrowhead1
% End of user PostScript
.4776 .70157 m
.50575 .67342 L
s
% Start of user PostScript
0.45 0.7 0.481416 0.668584 MAarrowhead1
% End of user PostScript
.4776 .74636 m
.50012 .72384 L
s
% Start of user PostScript
0.45 0.75 0.475133 0.724867 MAarrowhead1
% End of user PostScript
.4776 .79115 m
.49449 .77427 L
s
% Start of user PostScript
0.45 0.8 0.46885 0.78115 MAarrowhead1
% End of user PostScript
.4776 .83595 m
.48886 .82469 L
s
% Start of user PostScript
0.45 0.85 0.462566 0.837434 MAarrowhead1
% End of user PostScript
.4776 .88074 m
.48323 .87511 L
s
% Start of user PostScript
0.45 0.9 0.456283 0.893717 MAarrowhead1
% End of user PostScript
.4776 .92553 m
.4776 .92553 L
s
% Start of user PostScript
0.45 0.95 MAarrowzero1
% End of user PostScript
.5224 .07447 m
.5224 .07447 L
s
% Start of user PostScript
0.5 0 MAarrowzero1
% End of user PostScript
.5224 .11926 m
.51677 .12489 L
s
% Start of user PostScript
0.5 0.05 0.493717 0.0562832 MAarrowhead1
% End of user PostScript
.5224 .16405 m
.51114 .17531 L
s
% Start of user PostScript
0.5 0.1 0.487434 0.112566 MAarrowhead1
% End of user PostScript
.5224 .20885 m
.50551 .22573 L
s
% Start of user PostScript
0.5 0.15 0.48115 0.16885 MAarrowhead1
% End of user PostScript
.5224 .25364 m
.49988 .27616 L
s
% Start of user PostScript
0.5 0.2 0.474867 0.225133 MAarrowhead1
% End of user PostScript
.5224 .29843 m
.49425 .32658 L
s
% Start of user PostScript
0.5 0.25 0.468584 0.281416 MAarrowhead1
% End of user PostScript
.5224 .34323 m
.48862 .377 L
s
% Start of user PostScript
0.5 0.3 0.462301 0.337699 MAarrowhead1
% End of user PostScript
.5224 .38802 m
.48299 .42742 L
s
% Start of user PostScript
0.5 0.35 0.456018 0.393982 MAarrowhead1
% End of user PostScript
.5224 .43281 m
.47737 .47784 L
s
% Start of user PostScript
0.5 0.4 0.449735 0.450265 MAarrowhead1
% End of user PostScript
.5224 .4776 m
.47174 .52826 L
s
% Start of user PostScript
0.5 0.45 0.443451 0.506549 MAarrowhead1
% End of user PostScript
.5224 .5224 m
.5224 .5224 L
s
% Start of user PostScript
0.5 0.5 MAarrowzero1
% End of user PostScript
.5224 .56719 m
.57306 .51653 L
s
% Start of user PostScript
0.5 0.55 0.556549 0.493451 MAarrowhead1
% End of user PostScript
.5224 .61198 m
.56743 .56695 L
s
% Start of user PostScript
0.5 0.6 0.550265 0.549735 MAarrowhead1
% End of user PostScript
.5224 .65677 m
.5618 .61737 L
s
% Start of user PostScript
0.5 0.65 0.543982 0.606018 MAarrowhead1
% End of user PostScript
.5224 .70157 m
.55617 .66779 L
s
% Start of user PostScript
0.5 0.7 0.537699 0.662301 MAarrowhead1
% End of user PostScript
.5224 .74636 m
.55054 .71822 L
s
% Start of user PostScript
0.5 0.75 0.531416 0.718584 MAarrowhead1
% End of user PostScript
.5224 .79115 m
.54491 .76864 L
s
% Start of user PostScript
0.5 0.8 0.525133 0.774867 MAarrowhead1
% End of user PostScript
.5224 .83595 m
.53928 .81906 L
s
% Start of user PostScript
0.5 0.85 0.51885 0.83115 MAarrowhead1
% End of user PostScript
.5224 .88074 m
.53365 .86948 L
s
% Start of user PostScript
0.5 0.9 0.512566 0.887434 MAarrowhead1
% End of user PostScript
.5224 .92553 m
.52803 .9199 L
s
% Start of user PostScript
0.5 0.95 0.506283 0.943717 MAarrowhead1
% End of user PostScript
.56719 .07447 m
.57282 .06884 L
s
% Start of user PostScript
0.55 0 0.556283 -0.00628319 MAarrowhead1
% End of user PostScript
.56719 .11926 m
.56719 .11926 L
s
% Start of user PostScript
0.55 0.05 MAarrowzero1
% End of user PostScript
.56719 .16405 m
.56156 .16968 L
s
% Start of user PostScript
0.55 0.1 0.543717 0.106283 MAarrowhead1
% End of user PostScript
.56719 .20885 m
.55593 .2201 L
s
% Start of user PostScript
0.55 0.15 0.537434 0.162566 MAarrowhead1
% End of user PostScript
.56719 .25364 m
.5503 .27053 L
s
% Start of user PostScript
0.55 0.2 0.53115 0.21885 MAarrowhead1
% End of user PostScript
.56719 .29843 m
.54467 .32095 L
s
% Start of user PostScript
0.55 0.25 0.524867 0.275133 MAarrowhead1
% End of user PostScript
.56719 .34323 m
.53905 .37137 L
s
% Start of user PostScript
0.55 0.3 0.518584 0.331416 MAarrowhead1
% End of user PostScript
.56719 .38802 m
.53342 .42179 L
s
% Start of user PostScript
0.55 0.35 0.512301 0.387699 MAarrowhead1
% End of user PostScript
.56719 .43281 m
.52779 .47221 L
s
% Start of user PostScript
0.55 0.4 0.506018 0.443982 MAarrowhead1
% End of user PostScript
.56719 .4776 m
.52216 .52263 L
s
% Start of user PostScript
0.55 0.45 0.499735 0.500265 MAarrowhead1
% End of user PostScript
.56719 .5224 m
.51653 .57306 L
s
% Start of user PostScript
0.55 0.5 0.493451 0.556549 MAarrowhead1
% End of user PostScript
.56719 .56719 m
.56719 .56719 L
s
% Start of user PostScript
0.55 0.55 MAarrowzero1
% End of user PostScript
.56719 .61198 m
.61785 .56132 L
s
% Start of user PostScript
0.55 0.6 0.606549 0.543451 MAarrowhead1
% End of user PostScript
.56719 .65677 m
.61222 .61174 L
s
% Start of user PostScript
0.55 0.65 0.600265 0.599735 MAarrowhead1
% End of user PostScript
.56719 .70157 m
.60659 .66217 L
s
% Start of user PostScript
0.55 0.7 0.593982 0.656018 MAarrowhead1
% End of user PostScript
.56719 .74636 m
.60096 .71259 L
s
% Start of user PostScript
0.55 0.75 0.587699 0.712301 MAarrowhead1
% End of user PostScript
.56719 .79115 m
.59533 .76301 L
s
% Start of user PostScript
0.55 0.8 0.581416 0.768584 MAarrowhead1
% End of user PostScript
.56719 .83595 m
.5897 .81343 L
s
% Start of user PostScript
0.55 0.85 0.575133 0.824867 MAarrowhead1
% End of user PostScript
.56719 .88074 m
.58408 .86385 L
s
% Start of user PostScript
0.55 0.9 0.56885 0.88115 MAarrowhead1
% End of user PostScript
.56719 .92553 m
.57845 .91427 L
s
% Start of user PostScript
0.55 0.95 0.562566 0.937434 MAarrowhead1
% End of user PostScript
.61198 .07447 m
.62324 .06321 L
s
% Start of user PostScript
0.6 0 0.612566 -0.0125664 MAarrowhead1
% End of user PostScript
.61198 .11926 m
.61761 .11363 L
s
% Start of user PostScript
0.6 0.05 0.606283 0.0437168 MAarrowhead1
% End of user PostScript
.61198 .16405 m
.61198 .16405 L
s
% Start of user PostScript
0.6 0.1 MAarrowzero1
% End of user PostScript
.61198 .20885 m
.60635 .21448 L
s
% Start of user PostScript
0.6 0.15 0.593717 0.156283 MAarrowhead1
% End of user PostScript
.61198 .25364 m
.60072 .2649 L
s
% Start of user PostScript
0.6 0.2 0.587434 0.212566 MAarrowhead1
% End of user PostScript
.61198 .29843 m
.5951 .31532 L
s
% Start of user PostScript
0.6 0.25 0.58115 0.26885 MAarrowhead1
% End of user PostScript
.61198 .34323 m
.58947 .36574 L
s
% Start of user PostScript
0.6 0.3 0.574867 0.325133 MAarrowhead1
% End of user PostScript
.61198 .38802 m
.58384 .41616 L
s
% Start of user PostScript
0.6 0.35 0.568584 0.381416 MAarrowhead1
% End of user PostScript
.61198 .43281 m
.57821 .46658 L
s
% Start of user PostScript
0.6 0.4 0.562301 0.437699 MAarrowhead1
% End of user PostScript
.61198 .4776 m
.57258 .51701 L
s
% Start of user PostScript
0.6 0.45 0.556018 0.493982 MAarrowhead1
% End of user PostScript
.61198 .5224 m
.56695 .56743 L
s
% Start of user PostScript
0.6 0.5 0.549735 0.550265 MAarrowhead1
% End of user PostScript
.61198 .56719 m
.56132 .61785 L
s
% Start of user PostScript
0.6 0.55 0.543451 0.606549 MAarrowhead1
% End of user PostScript
.61198 .61198 m
.61198 .61198 L
s
% Start of user PostScript
0.6 0.6 MAarrowzero1
% End of user PostScript
.61198 .65677 m
.66264 .60612 L
s
% Start of user PostScript
0.6 0.65 0.656549 0.593451 MAarrowhead1
% End of user PostScript
.61198 .70157 m
.65701 .65654 L
s
% Start of user PostScript
0.6 0.7 0.650265 0.649735 MAarrowhead1
% End of user PostScript
.61198 .74636 m
.65138 .70696 L
s
% Start of user PostScript
0.6 0.75 0.643982 0.706018 MAarrowhead1
% End of user PostScript
.61198 .79115 m
.64575 .75738 L
s
% Start of user PostScript
0.6 0.8 0.637699 0.762301 MAarrowhead1
% End of user PostScript
.61198 .83595 m
.64013 .8078 L
s
% Start of user PostScript
0.6 0.85 0.631416 0.818584 MAarrowhead1
% End of user PostScript
.61198 .88074 m
.6345 .85822 L
s
% Start of user PostScript
0.6 0.9 0.625133 0.874867 MAarrowhead1
% End of user PostScript
.61198 .92553 m
.62887 .90864 L
s
% Start of user PostScript
0.6 0.95 0.61885 0.93115 MAarrowhead1
% End of user PostScript
.65677 .07447 m
.67366 .05758 L
s
% Start of user PostScript
0.65 0 0.66885 -0.0188496 MAarrowhead1
% End of user PostScript
.65677 .11926 m
.66803 .108 L
s
% Start of user PostScript
0.65 0.05 0.662566 0.0374336 MAarrowhead1
% End of user PostScript
.65677 .16405 m
.6624 .15843 L
s
% Start of user PostScript
0.65 0.1 0.656283 0.0937168 MAarrowhead1
% End of user PostScript
.65677 .20885 m
.65677 .20885 L
s
% Start of user PostScript
0.65 0.15 MAarrowzero1
% End of user PostScript
.65677 .25364 m
.65115 .25927 L
s
% Start of user PostScript
0.65 0.2 0.643717 0.206283 MAarrowhead1
% End of user PostScript
.65677 .29843 m
.64552 .30969 L
s
% Start of user PostScript
0.65 0.25 0.637434 0.262566 MAarrowhead1
% End of user PostScript
.65677 .34323 m
.63989 .36011 L
s
% Start of user PostScript
0.65 0.3 0.63115 0.31885 MAarrowhead1
% End of user PostScript
.65677 .38802 m
.63426 .41053 L
s
% Start of user PostScript
0.65 0.35 0.624867 0.375133 MAarrowhead1
% End of user PostScript
.65677 .43281 m
.62863 .46095 L
s
% Start of user PostScript
0.65 0.4 0.618584 0.431416 MAarrowhead1
% End of user PostScript
.65677 .4776 m
.623 .51138 L
s
% Start of user PostScript
0.65 0.45 0.612301 0.487699 MAarrowhead1
% End of user PostScript
.65677 .5224 m
.61737 .5618 L
s
% Start of user PostScript
0.65 0.5 0.606018 0.543982 MAarrowhead1
% End of user PostScript
.65677 .56719 m
.61174 .61222 L
s
% Start of user PostScript
0.65 0.55 0.599735 0.600265 MAarrowhead1
% End of user PostScript
.65677 .61198 m
.60612 .66264 L
s
% Start of user PostScript
0.65 0.6 0.593451 0.656549 MAarrowhead1
% End of user PostScript
.65677 .65677 m
.65677 .65677 L
s
% Start of user PostScript
0.65 0.65 MAarrowzero1
% End of user PostScript
.65677 .70157 m
.70743 .65091 L
s
% Start of user PostScript
0.65 0.7 0.706549 0.643451 MAarrowhead1
% End of user PostScript
.65677 .74636 m
.70181 .70133 L
s
% Start of user PostScript
0.65 0.75 0.700265 0.699735 MAarrowhead1
% End of user PostScript
.65677 .79115 m
.69618 .75175 L
s
% Start of user PostScript
0.65 0.8 0.693982 0.756018 MAarrowhead1
% End of user PostScript
.65677 .83595 m
.69055 .80217 L
s
% Start of user PostScript
0.65 0.85 0.687699 0.812301 MAarrowhead1
% End of user PostScript
.65677 .88074 m
.68492 .85259 L
s
% Start of user PostScript
0.65 0.9 0.681416 0.868584 MAarrowhead1
% End of user PostScript
.65677 .92553 m
.67929 .90302 L
s
% Start of user PostScript
0.65 0.95 0.675133 0.924867 MAarrowhead1
% End of user PostScript
.70157 .07447 m
.72408 .05195 L
s
% Start of user PostScript
0.7 0 0.725133 -0.0251327 MAarrowhead1
% End of user PostScript
.70157 .11926 m
.71845 .10238 L
s
% Start of user PostScript
0.7 0.05 0.71885 0.0311504 MAarrowhead1
% End of user PostScript
.70157 .16405 m
.71282 .1528 L
s
% Start of user PostScript
0.7 0.1 0.712566 0.0874336 MAarrowhead1
% End of user PostScript
.70157 .20885 m
.7072 .20322 L
s
% Start of user PostScript
0.7 0.15 0.706283 0.143717 MAarrowhead1
% End of user PostScript
.70157 .25364 m
.70157 .25364 L
s
% Start of user PostScript
0.7 0.2 MAarrowzero1
% End of user PostScript
.70157 .29843 m
.69594 .30406 L
s
% Start of user PostScript
0.7 0.25 0.693717 0.256283 MAarrowhead1
% End of user PostScript
.70157 .34323 m
.69031 .35448 L
s
% Start of user PostScript
0.7 0.3 0.687434 0.312566 MAarrowhead1
% End of user PostScript
.70157 .38802 m
.68468 .4049 L
s
% Start of user PostScript
0.7 0.35 0.68115 0.36885 MAarrowhead1
% End of user PostScript
.70157 .43281 m
.67905 .45533 L
s
% Start of user PostScript
0.7 0.4 0.674867 0.425133 MAarrowhead1
% End of user PostScript
.70157 .4776 m
.67342 .50575 L
s
% Start of user PostScript
0.7 0.45 0.668584 0.481416 MAarrowhead1
% End of user PostScript
.70157 .5224 m
.66779 .55617 L
s
% Start of user PostScript
0.7 0.5 0.662301 0.537699 MAarrowhead1
% End of user PostScript
.70157 .56719 m
.66217 .60659 L
s
% Start of user PostScript
0.7 0.55 0.656018 0.593982 MAarrowhead1
% End of user PostScript
.70157 .61198 m
.65654 .65701 L
s
% Start of user PostScript
0.7 0.6 0.649735 0.650265 MAarrowhead1
% End of user PostScript
.70157 .65677 m
.65091 .70743 L
s
% Start of user PostScript
0.7 0.65 0.643451 0.706549 MAarrowhead1
% End of user PostScript
.70157 .70157 m
.70157 .70157 L
s
% Start of user PostScript
0.7 0.7 MAarrowzero1
% End of user PostScript
.70157 .74636 m
.75223 .6957 L
s
% Start of user PostScript
0.7 0.75 0.756549 0.693451 MAarrowhead1
% End of user PostScript
.70157 .79115 m
.7466 .74612 L
s
% Start of user PostScript
0.7 0.8 0.750265 0.749735 MAarrowhead1
% End of user PostScript
.70157 .83595 m
.74097 .79654 L
s
% Start of user PostScript
0.7 0.85 0.743982 0.806018 MAarrowhead1
% End of user PostScript
.70157 .88074 m
.73534 .84697 L
s
% Start of user PostScript
0.7 0.9 0.737699 0.862301 MAarrowhead1
% End of user PostScript
.70157 .92553 m
.72971 .89739 L
s
% Start of user PostScript
0.7 0.95 0.731416 0.918584 MAarrowhead1
% End of user PostScript
.74636 .07447 m
.7745 .04632 L
s
% Start of user PostScript
0.75 0 0.781416 -0.0314159 MAarrowhead1
% End of user PostScript
.74636 .11926 m
.76888 .09675 L
s
% Start of user PostScript
0.75 0.05 0.775133 0.0248673 MAarrowhead1
% End of user PostScript
.74636 .16405 m
.76325 .14717 L
s
% Start of user PostScript
0.75 0.1 0.76885 0.0811504 MAarrowhead1
% End of user PostScript
.74636 .20885 m
.75762 .19759 L
s
% Start of user PostScript
0.75 0.15 0.762566 0.137434 MAarrowhead1
% End of user PostScript
.74636 .25364 m
.75199 .24801 L
s
% Start of user PostScript
0.75 0.2 0.756283 0.193717 MAarrowhead1
% End of user PostScript
.74636 .29843 m
.74636 .29843 L
s
% Start of user PostScript
0.75 0.25 MAarrowzero1
% End of user PostScript
.74636 .34323 m
.74073 .34885 L
s
% Start of user PostScript
0.75 0.3 0.743717 0.306283 MAarrowhead1
% End of user PostScript
.74636 .38802 m
.7351 .39928 L
s
% Start of user PostScript
0.75 0.35 0.737434 0.362566 MAarrowhead1
% End of user PostScript
.74636 .43281 m
.72947 .4497 L
s
% Start of user PostScript
0.75 0.4 0.73115 0.41885 MAarrowhead1
% End of user PostScript
.74636 .4776 m
.72384 .50012 L
s
% Start of user PostScript
0.75 0.45 0.724867 0.475133 MAarrowhead1
% End of user PostScript
.74636 .5224 m
.71822 .55054 L
s
% Start of user PostScript
0.75 0.5 0.718584 0.531416 MAarrowhead1
% End of user PostScript
.74636 .56719 m
.71259 .60096 L
s
% Start of user PostScript
0.75 0.55 0.712301 0.587699 MAarrowhead1
% End of user PostScript
.74636 .61198 m
.70696 .65138 L
s
% Start of user PostScript
0.75 0.6 0.706018 0.643982 MAarrowhead1
% End of user PostScript
.74636 .65677 m
.70133 .70181 L
s
% Start of user PostScript
0.75 0.65 0.699735 0.700265 MAarrowhead1
% End of user PostScript
.74636 .70157 m
.6957 .75223 L
s
% Start of user PostScript
0.75 0.7 0.693451 0.756549 MAarrowhead1
% End of user PostScript
.74636 .74636 m
.74636 .74636 L
s
% Start of user PostScript
0.75 0.75 MAarrowzero1
% End of user PostScript
.74636 .79115 m
.79702 .74049 L
s
% Start of user PostScript
0.75 0.8 0.806549 0.743451 MAarrowhead1
% End of user PostScript
.74636 .83595 m
.79139 .79092 L
s
% Start of user PostScript
0.75 0.85 0.800265 0.799735 MAarrowhead1
% End of user PostScript
.74636 .88074 m
.78576 .84134 L
s
% Start of user PostScript
0.75 0.9 0.793982 0.856018 MAarrowhead1
% End of user PostScript
.74636 .92553 m
.78013 .89176 L
s
% Start of user PostScript
0.75 0.95 0.787699 0.912301 MAarrowhead1
% End of user PostScript
.79115 .07447 m
.82493 .0407 L
s
% Start of user PostScript
0.8 0 0.837699 -0.0376991 MAarrowhead1
% End of user PostScript
.79115 .11926 m
.8193 .09112 L
s
% Start of user PostScript
0.8 0.05 0.831416 0.0185841 MAarrowhead1
% End of user PostScript
.79115 .16405 m
.81367 .14154 L
s
% Start of user PostScript
0.8 0.1 0.825133 0.0748673 MAarrowhead1
% End of user PostScript
.79115 .20885 m
.80804 .19196 L
s
% Start of user PostScript
0.8 0.15 0.81885 0.13115 MAarrowhead1
% End of user PostScript
.79115 .25364 m
.80241 .24238 L
s
% Start of user PostScript
0.8 0.2 0.812566 0.187434 MAarrowhead1
% End of user PostScript
.79115 .29843 m
.79678 .2928 L
s
% Start of user PostScript
0.8 0.25 0.806283 0.243717 MAarrowhead1
% End of user PostScript
.79115 .34323 m
.79115 .34323 L
s
% Start of user PostScript
0.8 0.3 MAarrowzero1
% End of user PostScript
.79115 .38802 m
.78552 .39365 L
s
% Start of user PostScript
0.8 0.35 0.793717 0.356283 MAarrowhead1
% End of user PostScript
.79115 .43281 m
.7799 .44407 L
s
% Start of user PostScript
0.8 0.4 0.787434 0.412566 MAarrowhead1
% End of user PostScript
.79115 .4776 m
.77427 .49449 L
s
% Start of user PostScript
0.8 0.45 0.78115 0.46885 MAarrowhead1
% End of user PostScript
.79115 .5224 m
.76864 .54491 L
s
% Start of user PostScript
0.8 0.5 0.774867 0.525133 MAarrowhead1
% End of user PostScript
.79115 .56719 m
.76301 .59533 L
s
% Start of user PostScript
0.8 0.55 0.768584 0.581416 MAarrowhead1
% End of user PostScript
.79115 .61198 m
.75738 .64575 L
s
% Start of user PostScript
0.8 0.6 0.762301 0.637699 MAarrowhead1
% End of user PostScript
.79115 .65677 m
.75175 .69618 L
s
% Start of user PostScript
0.8 0.65 0.756018 0.693982 MAarrowhead1
% End of user PostScript
.79115 .70157 m
.74612 .7466 L
s
% Start of user PostScript
0.8 0.7 0.749735 0.750265 MAarrowhead1
% End of user PostScript
.79115 .74636 m
.74049 .79702 L
s
% Start of user PostScript
0.8 0.75 0.743451 0.806549 MAarrowhead1
% End of user PostScript
.79115 .79115 m
.79115 .79115 L
s
% Start of user PostScript
0.8 0.8 MAarrowzero1
% End of user PostScript
.79115 .83595 m
.84181 .78529 L
s
% Start of user PostScript
0.8 0.85 0.856549 0.793451 MAarrowhead1
% End of user PostScript
.79115 .88074 m
.83618 .83571 L
s
% Start of user PostScript
0.8 0.9 0.850265 0.849735 MAarrowhead1
% End of user PostScript
.79115 .92553 m
.83055 .88613 L
s
% Start of user PostScript
0.8 0.95 0.843982 0.906018 MAarrowhead1
% End of user PostScript
.83595 .07447 m
.87535 .03507 L
s
% Start of user PostScript
0.85 0 0.893982 -0.0439823 MAarrowhead1
% End of user PostScript
.83595 .11926 m
.86972 .08549 L
s
% Start of user PostScript
0.85 0.05 0.887699 0.0123009 MAarrowhead1
% End of user PostScript
.83595 .16405 m
.86409 .13591 L
s
% Start of user PostScript
0.85 0.1 0.881416 0.0685841 MAarrowhead1
% End of user PostScript
.83595 .20885 m
.85846 .18633 L
s
% Start of user PostScript
0.85 0.15 0.875133 0.124867 MAarrowhead1
% End of user PostScript
.83595 .25364 m
.85283 .23675 L
s
% Start of user PostScript
0.85 0.2 0.86885 0.18115 MAarrowhead1
% End of user PostScript
.83595 .29843 m
.8472 .28718 L
s
% Start of user PostScript
0.85 0.25 0.862566 0.237434 MAarrowhead1
% End of user PostScript
.83595 .34323 m
.84157 .3376 L
s
% Start of user PostScript
0.85 0.3 0.856283 0.293717 MAarrowhead1
% End of user PostScript
.83595 .38802 m
.83595 .38802 L
s
% Start of user PostScript
0.85 0.35 MAarrowzero1
% End of user PostScript
.83595 .43281 m
.83032 .43844 L
s
% Start of user PostScript
0.85 0.4 0.843717 0.406283 MAarrowhead1
% End of user PostScript
.83595 .4776 m
.82469 .48886 L
s
% Start of user PostScript
0.85 0.45 0.837434 0.462566 MAarrowhead1
% End of user PostScript
.83595 .5224 m
.81906 .53928 L
s
% Start of user PostScript
0.85 0.5 0.83115 0.51885 MAarrowhead1
% End of user PostScript
.83595 .56719 m
.81343 .5897 L
s
% Start of user PostScript
0.85 0.55 0.824867 0.575133 MAarrowhead1
% End of user PostScript
.83595 .61198 m
.8078 .64013 L
s
% Start of user PostScript
0.85 0.6 0.818584 0.631416 MAarrowhead1
% End of user PostScript
.83595 .65677 m
.80217 .69055 L
s
% Start of user PostScript
0.85 0.65 0.812301 0.687699 MAarrowhead1
% End of user PostScript
.83595 .70157 m
.79654 .74097 L
s
% Start of user PostScript
0.85 0.7 0.806018 0.743982 MAarrowhead1
% End of user PostScript
.83595 .74636 m
.79092 .79139 L
s
% Start of user PostScript
0.85 0.75 0.799735 0.800265 MAarrowhead1
% End of user PostScript
.83595 .79115 m
.78529 .84181 L
s
% Start of user PostScript
0.85 0.8 0.793451 0.856549 MAarrowhead1
% End of user PostScript
.83595 .83595 m
.83595 .83595 L
s
% Start of user PostScript
0.85 0.85 MAarrowzero1
% End of user PostScript
.83595 .88074 m
.8866 .83008 L
s
% Start of user PostScript
0.85 0.9 0.906549 0.843451 MAarrowhead1
% End of user PostScript
.83595 .92553 m
.88098 .8805 L
s
% Start of user PostScript
0.85 0.95 0.900265 0.899735 MAarrowhead1
% End of user PostScript
.88074 .07447 m
.92577 .02944 L
s
% Start of user PostScript
0.9 0 0.950265 -0.0502655 MAarrowhead1
% End of user PostScript
.88074 .11926 m
.92014 .07986 L
s
% Start of user PostScript
0.9 0.05 0.943982 0.0060177 MAarrowhead1
% End of user PostScript
.88074 .16405 m
.91451 .13028 L
s
% Start of user PostScript
0.9 0.1 0.937699 0.0623009 MAarrowhead1
% End of user PostScript
.88074 .20885 m
.90888 .1807 L
s
% Start of user PostScript
0.9 0.15 0.931416 0.118584 MAarrowhead1
% End of user PostScript
.88074 .25364 m
.90325 .23112 L
s
% Start of user PostScript
0.9 0.2 0.925133 0.174867 MAarrowhead1
% End of user PostScript
.88074 .29843 m
.89762 .28155 L
s
% Start of user PostScript
0.9 0.25 0.91885 0.23115 MAarrowhead1
% End of user PostScript
.88074 .34323 m
.892 .33197 L
s
% Start of user PostScript
0.9 0.3 0.912566 0.287434 MAarrowhead1
% End of user PostScript
.88074 .38802 m
.88637 .38239 L
s
% Start of user PostScript
0.9 0.35 0.906283 0.343717 MAarrowhead1
% End of user PostScript
.88074 .43281 m
.88074 .43281 L
s
% Start of user PostScript
0.9 0.4 MAarrowzero1
% End of user PostScript
.88074 .4776 m
.87511 .48323 L
s
% Start of user PostScript
0.9 0.45 0.893717 0.456283 MAarrowhead1
% End of user PostScript
.88074 .5224 m
.86948 .53365 L
s
% Start of user PostScript
0.9 0.5 0.887434 0.512566 MAarrowhead1
% End of user PostScript
.88074 .56719 m
.86385 .58408 L
s
% Start of user PostScript
0.9 0.55 0.88115 0.56885 MAarrowhead1
% End of user PostScript
.88074 .61198 m
.85822 .6345 L
s
% Start of user PostScript
0.9 0.6 0.874867 0.625133 MAarrowhead1
% End of user PostScript
.88074 .65677 m
.85259 .68492 L
s
% Start of user PostScript
0.9 0.65 0.868584 0.681416 MAarrowhead1
% End of user PostScript
.88074 .70157 m
.84697 .73534 L
s
% Start of user PostScript
0.9 0.7 0.862301 0.737699 MAarrowhead1
% End of user PostScript
.88074 .74636 m
.84134 .78576 L
s
% Start of user PostScript
0.9 0.75 0.856018 0.793982 MAarrowhead1
% End of user PostScript
.88074 .79115 m
.83571 .83618 L
s
% Start of user PostScript
0.9 0.8 0.849735 0.850265 MAarrowhead1
% End of user PostScript
.88074 .83595 m
.83008 .8866 L
s
% Start of user PostScript
0.9 0.85 0.843451 0.906549 MAarrowhead1
% End of user PostScript
.88074 .88074 m
.88074 .88074 L
s
% Start of user PostScript
0.9 0.9 MAarrowzero1
% End of user PostScript
.88074 .92553 m
.9314 .87487 L
s
% Start of user PostScript
0.9 0.95 0.956549 0.893451 MAarrowhead1
% End of user PostScript
.92553 .07447 m
.97619 .02381 L
s
% Start of user PostScript
0.95 0 1.00655 -0.0565487 MAarrowhead1
% End of user PostScript
.92553 .11926 m
.97056 .07423 L
s
% Start of user PostScript
0.95 0.05 1.00027 -0.000265482 MAarrowhead1
% End of user PostScript
.92553 .16405 m
.96493 .12465 L
s
% Start of user PostScript
0.95 0.1 0.993982 0.0560177 MAarrowhead1
% End of user PostScript
.92553 .20885 m
.9593 .17507 L
s
% Start of user PostScript
0.95 0.15 0.987699 0.112301 MAarrowhead1
% End of user PostScript
.92553 .25364 m
.95368 .2255 L
s
% Start of user PostScript
0.95 0.2 0.981416 0.168584 MAarrowhead1
% End of user PostScript
.92553 .29843 m
.94805 .27592 L
s
% Start of user PostScript
0.95 0.25 0.975133 0.224867 MAarrowhead1
% End of user PostScript
.92553 .34323 m
.94242 .32634 L
s
% Start of user PostScript
0.95 0.3 0.96885 0.28115 MAarrowhead1
% End of user PostScript
.92553 .38802 m
.93679 .37676 L
s
% Start of user PostScript
0.95 0.35 0.962566 0.337434 MAarrowhead1
% End of user PostScript
.92553 .43281 m
.93116 .42718 L
s
% Start of user PostScript
0.95 0.4 0.956283 0.393717 MAarrowhead1
% End of user PostScript
.92553 .4776 m
.92553 .4776 L
s
% Start of user PostScript
0.95 0.45 MAarrowzero1
% End of user PostScript
.92553 .5224 m
.9199 .52803 L
s
% Start of user PostScript
0.95 0.5 0.943717 0.506283 MAarrowhead1
% End of user PostScript
.92553 .56719 m
.91427 .57845 L
s
% Start of user PostScript
0.95 0.55 0.937434 0.562566 MAarrowhead1
% End of user PostScript
.92553 .61198 m
.90864 .62887 L
s
% Start of user PostScript
0.95 0.6 0.93115 0.61885 MAarrowhead1
% End of user PostScript
.92553 .65677 m
.90302 .67929 L
s
% Start of user PostScript
0.95 0.65 0.924867 0.675133 MAarrowhead1
% End of user PostScript
.92553 .70157 m
.89739 .72971 L
s
% Start of user PostScript
0.95 0.7 0.918584 0.731416 MAarrowhead1
% End of user PostScript
.92553 .74636 m
.89176 .78013 L
s
% Start of user PostScript
0.95 0.75 0.912301 0.787699 MAarrowhead1
% End of user PostScript
.92553 .79115 m
.88613 .83055 L
s
% Start of user PostScript
0.95 0.8 0.906018 0.843982 MAarrowhead1
% End of user PostScript
.92553 .83595 m
.8805 .88098 L
s
% Start of user PostScript
0.95 0.85 0.899735 0.900265 MAarrowhead1
% End of user PostScript
.92553 .88074 m
.87487 .9314 L
s
% Start of user PostScript
0.95 0.9 0.893451 0.956549 MAarrowhead1
% End of user PostScript
.92553 .92553 m
.92553 .92553 L
s
% Start of user PostScript
0.95 0.95 MAarrowzero1
% End of user PostScript
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooolmooooo`;o00002Oooool001kooooo00?o0000ooooooooool0oooooollooooo`?o
00002Oooool001kooooo0_l0003oooooobcooooo0_l0000=ooooo`Co00002_ooool001kooooo00?o
0000ooooooooool0oooooolZooooo`?o00003?ooool4o`0000_ooooo000Nooooo`03o`000?oooooo
oooo0?oooooo6Oooool2o`0000gooooo1?l0000<ooooo`Go00002oooool001kooooo00?o0000oooo
ooooool0<_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000:_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:Ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<
c<`0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000
ob4Q8Oo<c<`04_ooool3o`0000cooooo1?l0000>ooooo`Go000000?o410@ooooooooool01oooool0
01kooooo00?o0000ooooooooool0<_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0:_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B47ooooo`03o`000?oooooooooo02[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01_lQ8B7oV9RHoooooonHV9So8B4Qooooo`;o00003Oooool4o`0000cooooo
1Ol0000=ooooo`05o`000?oooooo0000ooooool000002oooool001kooooo00?o0000ooooooooool0
<_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0:oooool01Ol@413o
oooooooooooooooo410@00_ooooo1Ol0000[ooooo`05oa0@4?ooooooooooooooool@41002oooool0
1Ol0003ooooooooooooooooo000002[ooooo00Go410@oooooooooooooooooa0@400;ooooo`04o`00
0?ooooooooooooooo`Co00003?ooool4o`0000kooooo0ol0000=ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool02Oooool001kooooo00?o0000ooooooooool0<_ooool01Ol0003ooooo
oooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0:_ooool01Ol0003ooooooooooooooooo0000
00_ooooo00CoA4A4omgMgOoooooo0000;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go
0000oiRHV?ooooooV9RHob4Q8@0Zooooo`04o`000?ooooooooooooooo`;o00002_ooool00olb<S;o
V9RHooooo`04o`0000cooooo1Ol0000=ooooo`03o`000?oooooo000000gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`09ooooo`007_ooool00ol0003oooooooooo`0booooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`0Yooooo`05o`000?oooooooooooooo
ool000002oooool01?oMgMgoEEEEooooool0000/ooooo`05o`000?ooooooooooooooool000002ooo
ool01Ol0003oEEEEo`000?l@413oc<c<02[ooooo00?o0000ooooooooool00ol0000:ooooo`03olc<
c?l0003o000000Co00003Oooool3o`0000gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Wooooo000Nooooo`03o`000?oooooooooo03;ooooo00Go
410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo02Sooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03ogMgMoo<c<co000002cooooo00Go410@oooooooooooooooooa0@400;oooo
o`03oeEEEOn7QhOooooo01oooooo0_l0000;ooooo`03oa0@4?l0003o000000;o00002oooool00ol@
413o0000o`000003o`0000gooooo00?o0000ooooool000003Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool001kooooo00?o0000oooooooo
ool0<_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@400Z
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00000/ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV00Mooooo`Co00002oooool5o`0000_ooooo
00?o0000okZj^_l000000ol0000<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo000Nooooo`03o`000?oo
oooooooo03;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool0:oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@2oooool2o`0000gooooo1?l0
000;ooooo`Go000000?ok^k^ooooooooool02Oooool01OnYZJWo0000o`000?l@413o000000cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo
00?oEEEEofIVI_l000002oooool001kooooo00?o0000ooooooooool0coooool4o`0000_ooooo1Ol0
000=ooooo`Co00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Dooooo`007_ooool00ol0003oooooooooo`2>
ooooo`03o`000?oooooooooo02kooooo0_l0000=ooooo`Co00002oooool6o`0000cooooo00Co0000
oooooooooooo00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Eooooo`007_ooool00ol0003oooooooooo`2>
ooooo`;o0000;Oooool4o`0000_ooooo1Ol0000>ooooo`?o00003?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo01Kooooo000Nooooo`03o`000?oooooooooo00kooooo0_l0001/oooo
o`03o`000?oooooooooo00kooooo1?l0000Looooo`;o00003Oooool4o`0000_ooooo1_l0000=oooo
o`03o`000?oooooo000000cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Goooo
o`007_ooool00ol0003oooooooooo`0=ooooo`?o0000K?ooool2o`0000kooooo0ol0000Mooooo`?o
00002oooool5o`0000kooooo0ol0000=ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0Hooooo`001?ooooooo`0006Go0000000>ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool02_ooool4o`0000kooooo0_l0000>ooooo`;o00003_oo
ool2o`0000kooooo00?o0000ooooooooool03?ooool2o`0000gooooo0ol0000=ooooo`?o00003_oo
ool2o`0000oooooo00?o0000ooooooooool02_ooool4o`0000kooooo0ol0000>ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00_ooooo0ol0000;ooooo`007_ooool00ol0003oooooooooo`09ooooo`Go00003Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooool000003Oooool0
0ol0003oooooooooo`0:ooooo`?o00003_ooool5o`0000cooooo0ol0000=ooooo`03o`000?oooooo
oooo01_ooooo1Ol0000?ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0:_ooool2
o`0000gooooo1Ol0000;ooooo`007_ooool00ol0003oooooooooo`0:ooooo`?o00003Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0;ooooo`?o00003Oooool4o`0000gooooo00?o0000ooooooooool0;Oooool3o`00
07_ooooo0ol0000<ooooo`Co00003Oooool001kooooo00?o0000ooooooooool02Oooool00ol0003o
ooooo`00000=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0:ooooo`;o000000?oooooo`000?ooool03?ooool5o`0000cooooo0_l0000>ooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool0JOooool2o`0000gooooo1?l0000<ooooo`Go
00003Oooool001kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`?o0000
3Oooool4o`0000gooooo0_l0002/ooooo`?o00003?ooool4o`0000kooooo0ol0000>ooooo`007_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0:ooooo`;o000000?oooooo`000?ooool03?ooool5o`0000cooooo0_l0
000>ooooo`03o`000?oooooooooo09_ooooo0_l0000=ooooo`Co00003?ooool5o`0000gooooo00?o
0000ooooool000003oooool001kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool3o`0000kooooo0ol0000=
ooooo`;o0000[?ooool3o`0000cooooo1?l0000>ooooo`?o00003Oooool00ol0003oooooooooo`0@
ooooo`007_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool02_ooool2o`000003ooooool0003ooooo00cooooo1Ol0000<ooooo`?o00003Oooool00ol0
003oooooooooo`2Kooooo`;o00003Oooool4o`0000cooooo1Ol0000=ooooo`03o`000?oooooo0000
00gooooo00?o0000ooooooooool04Oooool001kooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo0ol0000>ooooo`?o00003_ooool00ol0003o
ooooooooo`2Zooooo`?o00003?ooool5o`0000gooooo0ol0000=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool04_ooool001kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooo000000gooooo1Ol0000<ooooo`?o00003_ooool00ol0003ooooo
ooooo`2Kooooo`;o00003?ooool4o`0000cooooo1Ol0000=ooooo`03o`000?oooooo000000gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Cooooo`007_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00cooooo0_l0000>ooooo`?o00003_ooool00ol0003ooooooooo
o`2Zooooo`Co00002oooool5o`0000gooooo1?l0000<ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Dooooo`007_ooool01Ol0003oooooo`000?oo
oooo000000kooooo1?l0000<ooooo`?o00003_ooool00ol0003oooooooooo`1Zooooo`03o`000?oo
oooooooo02kooooo0_l0000=ooooo`Co00002oooool5o`0000gooooo00Co0000oooooooooooo0000
3?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
5Oooool001kooooo00Co0000ooooool0003o00003_ooool3o`0000kooooo00?o0000ooooooooool0
Noooool2o`0002gooooo1?l0000;ooooo`Go00003Oooool4o`0000cooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
5_ooool001kooooo1Ol0000=ooooo`;o00003Oooool2o`0006cooooo00?o0000ooooooooool03_oo
ool4o`0001cooooo0_l0000=ooooo`Co00002oooool6o`0000cooooo00Co0000oooooooooooo0000
3?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0Gooooo`007_ooool3o`0000kooooo00?o0000ooooooooool03?oo
ool3o`0006cooooo0_l0000>ooooo`?o00007?ooool4o`0000_ooooo1Ol0000>ooooo`?o00003?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Sooooo000Nooooo`;o00003Oooool2
o`0000gooooo1?l0000>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool0
0ol0003oooooo`00000>ooooo`Co00003Oooool2o`0000kooooo00?o0000ooooooooool02oooool4
o`0000_ooooo1_l0000=ooooo`03o`000?oooooo000000cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0Iooooo`007Oooool2o`0000gooooo0ol0000<ooooo`Co00003_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo0_l0000>ooooo`?o00003_ooool00ol0
003oooooooooo`0Jooooo`Go00003_ooool3o`0007Wooooo000Looooo`03o`000?oooooo000000_o
oooo1?l0000<ooooo`Go00003Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`?o00003_ooool4o`0000go
oooo0_l0000>ooooo`03o`000?oooooooooo01[ooooo1_l0000?ooooo`03o`000?oooooooooo06Wo
oooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`08ooooo`Co00003_ooool3o`0000gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool3o`0000gooooo0ol0000>ooooo`03o`000?oooooooooo02gooooo
0ol0001kooooo`?o00003Oooool001kooooo00?o0000ooooooooool01oooool5o`0000gooooo00?o
0000ooooool000003Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool02_ooool3o`0000kooooo1Ol0000<ooooo`;o00003_ooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo06Wooooo0_l0000=ooooo`Co00003_ooool001kooooo00?o0000
ooooooooool02?ooool3o`0000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool3o`0000gooooo1?l0000=
ooooo`03o`000?oooooooooo0:_ooooo0ol0000<ooooo`Co00003oooool001kooooo00?o0000oooo
ooooool01oooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0:ooooo`;o000000?oooooo`000?ooool03?ooool5o`00
00cooooo0_l0000>ooooo`03o`000?oooooooooo09_ooooo0_l0000=ooooo`Co00003?ooool5o`00
00oooooo000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool3o`0000go
oooo1?l0000=ooooo`;o0000[?ooool3o`0000cooooo1?l0000>ooooo`?o00004?ooool001kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool02_ooool2o`000003ooooool0003ooooo00cooooo1Ol0000<ooooo`;o0000
3_ooool00ol0003oooooooooo`2Kooooo`;o00003Oooool4o`0000cooooo1Ol0000=ooooo`03o`00
0?oooooo0000017ooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo0ol0000>ooooo`?o00003Ooo
ool2o`000:cooooo0ol0000<ooooo`Co00003_ooool3o`0000gooooo00?o0000ooooooooool04_oo
ool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00[ooooo0_l000000ooooooo0000ooooo`0<ooooo`Go00003?ooool3o`0000gooooo00?o0000
ooooooooool0Voooool2o`0000gooooo1?l0000<ooooo`Go00003Oooool00ol0003oooooo`00000=
ooooo`03o`000?oooooooooo01?ooooo000Nooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0;ooooo`?o00003_ooool3o`0000kooooo00?o0000oooo
ooooool0Z_ooool3o`0000cooooo1Ol0000=ooooo`?o00003Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo01Cooooo000Nooooo`05o`000?ooooooooooooooool000003Oooool00ol0
003oooooo`00000=ooooo`Go00003?ooool3o`0000kooooo00?o0000ooooooooool0J_ooool00ol0
003oooooooooo`0^ooooo`;o00003?ooool4o`0000cooooo1Ol0000=ooooo`03o`000?oooooo0000
00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Eooooo`007_ooool01?l0003o
ooooooooool0000>ooooo`;o00003_ooool3o`0000kooooo00?o0000ooooooooool0Noooool2o`00
02gooooo1?l0000;ooooo`Go00003Oooool4o`0000cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo01Kooooo000Nooooo`03o`000?oooooo000000ko
oooo1?l0000<ooooo`?o00003Oooool2o`0006cooooo00?o0000ooooooooool03_ooool4o`0001co
oooo0_l0000=ooooo`Co00002oooool5o`0000gooooo00Co0000oooooooooooo00003?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05oooool001ko
oooo0_l0000>ooooo`?o00003_ooool00ol0003oooooooooo`0:ooooo`Go0000K?ooool2o`0000ko
oooo0ol0000Looooo`Co00002oooool5o`0000gooooo1?l0000<ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01So
oooo000Nooooo`;o00003_ooool2o`0000gooooo0_l0000;ooooo`Ko00003_ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000003_ooool4o`0000gooooo
0_l0000>ooooo`03o`000?oooooooooo00_ooooo1?l0000;ooooo`Ko00003?ooool01?l0003ooooo
ooooool0000<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo01Wooooo000Nooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool4o`0000[ooooo1_l0000>ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool2o`0000kooooo0ol0000>ooooo`03o`000?oooooooooo01[ooooo
1Ol0000>ooooo`?o0000JOooool001kooooo00?o0000ooooooooool02_ooool2o`0000cooooo1Ol0
000<ooooo`Go00003Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000000kooooo1?l0
000=ooooo`;o00003_ooool00ol0003oooooooooo`0Jooooo`Ko00003oooool00ol0003ooooooooo
o`1Xooooo`007_ooool00ol0003oooooooooo`08ooooo`Co00002oooool5o`0000kooooo0ol0000=
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00cooooo0_l0000>ooooo`?o00003_ooool00ol0003oooooooooo`0]
ooooo`?o0000Noooool001kooooo00?o0000ooooooooool01_ooool5o`0000cooooo1Ol0000=oooo
o`03o`000?oooooo000000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo0ol0000>ooooo`Co00003Oooool2o`0000kooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`1Yooooo`;o00003oooool001kooooo00?o0000oooooooo
ool01Oooool5o`0000kooooo0ol0000=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0000kooooo0ol0000=oooo
o`?o00003_ooool00ol0003oooooooooo`2Zooooo`Co00003oooool001kooooo00?o0000oooooooo
ool01Oooool5o`0000gooooo00?o0000ooooool000003Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool3o`0000kooooo1Ol0000<ooooo`;o
00003_ooool00ol0003oooooooooo`2Kooooo`;o00003?ooool5o`00013ooooo000Nooooo`03o`00
0?oooooooooo00Kooooo0ol0000=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool000003?ooool4o`0000go
oooo1?l0000=ooooo`03o`000?oooooooooo0:[ooooo1?l0000;ooooo`Go00004Oooool001kooooo
00?o0000ooooooooool01Oooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`;o000000?oooooo`000?ooool0
3?ooool5o`0000cooooo0_l0000>ooooo`03o`000?oooooooooo09_ooooo0_l0000<ooooo`Go0000
3?ooool5o`00017ooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`00000<ooooo`Co00003Oooool4o`0000gooooo0_l0002[ooooo`Co00002oooool5o`0000kooooo
0ol0000Booooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`;o000000?oooooo`000?ooool03?oo
ool5o`0000_ooooo0ol0000>ooooo`03o`000?oooooooooo09_ooooo0_l0000<ooooo`Go00003?oo
ool5o`0000gooooo00?o0000ooooool000004oooool001kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`00
000<ooooo`Co00003Oooool4o`0000gooooo0_l0001[ooooo`03o`000?oooooooooo03gooooo1?l0
000;ooooo`Go00003_ooool3o`0000gooooo00?o0000ooooooooool05?ooool001kooooo00Go0000
ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo0000oooo
o`0<ooooo`Go00003?ooool3o`0000gooooo00?o0000ooooooooool0Joooool00ol0003ooooooooo
o`0]ooooo`;o00003?ooool5o`0000cooooo1Ol0000=ooooo`03o`000?oooooo000000gooooo00?o
0000ooooooooool05Oooool001kooooo00Co0000oooooooooooo00003oooool00ol0003ooooooooo
o`0:ooooo`Co00003Oooool4o`0000kooooo00?o0000ooooooooool0JOooool00ol0003ooooooooo
o`0>ooooo`?o0000;?ooool4o`0000_ooooo1_l0000=ooooo`?o00003Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo01Kooooo000Nooooo`03o`000?oooooo000000oooooo00?o0000
ooooooooool02oooool5o`0000cooooo0ol0000=ooooo`;o0000K?ooool00ol0003oooooooooo`0>
ooooo`Co00007?ooool2o`0000_ooooo1Ol0000=ooooo`Co00003Oooool00ol0003oooooo`00000=
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05oooool001kooooo0_l0000?oooo
o`03o`000?oooooooooo00_ooooo1?l0000>ooooo`03o`000?oooooooooo00[ooooo1Ol0001Joooo
o`03o`000?oooooooooo00kooooo0ol0000>ooooo`?o00006oooool5o`0000[ooooo1_l0000=oooo
o`Co00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool06?ooool001kooooo0_l0000>ooooo`03o`000?oooooooooo00cooooo0ol0000=ooooo`;o
00002oooool6o`0000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooo000000kooooo1?l0000<ooooo`?o00003_ooool00ol0003oooooooooo`09ooooo`Ko
00003?ooool4o`0000gooooo00Co0000oooooooooooo00003?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool06Oooool001kooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0:ooooo`Go00002_ooool6o`0000kooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool02_ooool01?l0003oooooooooool0000=ooooo`?o00003_ooool3o`0000kooooo00?o0000oooo
ooooool06Oooool6o`0000kooooo0ol0001Iooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o
00002oooool6o`0000cooooo1Ol0000=ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool0
00003_ooool4o`0000cooooo0ol0000>ooooo`03o`000?oooooooooo01_ooooo1Ol0000?ooooo`03
o`000?oooooooooo05Sooooo000Nooooo`03o`000?oooooooooo01Sooooo1?l0000:ooooo`Ko0000
3_ooool3o`0000gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00[ooooo00Co0000oooooooooooo00003Oooool3o`0000kooooo0ol0000>ooooo`03
o`000?oooooooooo02gooooo0ol0001[ooooo`007_ooool00ol0003oooooooooo`08ooooo`;o0000
3?ooool5o`0000cooooo1Ol0000=ooooo`03o`000?oooooo000000gooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool00000
3_ooool4o`0000cooooo0ol0000>ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
J_ooool001kooooo00?o0000ooooooooool01_ooool4o`0000_ooooo1Ol0000>ooooo`?o00003Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02_oo
ool01?l0003oooooooooool0000=ooooo`?o00003_ooool3o`0000kooooo00?o0000ooooooooool0
[Oooool001kooooo00?o0000ooooooooool01?ooool5o`0000cooooo1Ol0000=ooooo`03o`000?oo
oooo000000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00_ooooo0ol0000>ooooo`Co00003?ooool3o`0000kooooo00?o0000ooooooooool0Vooo
ool2o`00017ooooo000Nooooo`03o`000?oooooooooo00?ooooo1Ol0000>ooooo`?o00003Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02Oooool0
1?l0003oooooooooool0000=ooooo`Co00003Oooool3o`0000kooooo00?o0000ooooooooool0Z_oo
ool4o`00017ooooo000Nooooo`03o`000?oooooooooo00?ooooo1Ol0000=ooooo`03o`000?oooooo
000000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00[ooooo0ol0000>ooooo`Go00002oooool3o`0000kooooo00?o0000ooooooooool0Voooool2
o`0000cooooo1Ol0000Booooo`007_ooool00ol0003oooooooooo`04ooooo`?o00003Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02Oooool01Ol0
003ooooooooooooooooo000000cooooo1?l0000=ooooo`Co00003Oooool00ol0003oooooooooo`2Z
ooooo`Co00002oooool5o`0001?ooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ool000003Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool02_ooool2o`000003ooooool0003ooooo00cooooo1Ol0000;ooooo`?o00003_ooool00ol0
003oooooooooo`2Kooooo`;o00003?ooool5o`0000cooooo1Ol0000Cooooo`007_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`09ooooo`05o`000?ooooooooooooooool000003?ooool4o`0000gooooo1?l0000=oooo
o`;o0000J_ooool00ol0003oooooooooo`0nooooo`Co00002oooool5o`0000kooooo0ol0000Doooo
o`007_ooool01Ol0003ooooooooooooooooo000000oooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0:ooooo`;o000000?oooooo`000?ooool03?ooool5o`0000_ooooo0ol0000>oooo
o`03o`000?oooooooooo06[ooooo0_l0000_ooooo`;o00003?ooool5o`0000cooooo1Ol0000=oooo
o`03o`000?oooooo000001Gooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo1Ol00006ooooo`04o`000?ooooooooooo`0000oooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0:ooooo`Co00003Oooool4o`0000cooooo0ol0001[ooooo`03o`000?oooooo
oooo00gooooo1?l0000/ooooo`Co00002oooool5o`0000kooooo0ol0000=ooooo`03o`000?oooooo
oooo01Kooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooo000000oooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0;ooooo`Go00003?ooool3o`0000_ooooo1?l0001/ooooo`03o`000?oo
oooooooo00gooooo1Ol0000Kooooo`;o00003?ooool5o`0000cooooo1Ol0000=ooooo`03o`000?oo
oooo000000gooooo00?o0000ooooooooool05oooool000?ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0_l0000?ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool02oooool4o`0000cooooo0ol0000<ooooo`Co0000Foooool00ol0003ooooooooo
o`0>ooooo`?o00003Oooool4o`0001_ooooo1?l0000;ooooo`Ko00003Oooool3o`0000gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Hooooo`000oooool01Ol0003ooooooooooooo
oooo000000gooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0000gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0<ooooo`?o00002oooool4o`0000_ooooo1_l0000=ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool02oooool00ol0003oooooo`00000>ooooo`Co00003?oo
ool3o`0000kooooo00?o0000ooooooooool02Oooool5o`0000gooooo1?l0000=ooooo`03o`000?oo
oooo000000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Iooooo`000oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`0Zooooo`?o00003?ooool4o`0000_ooooo1_l0000=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo00Co
0000oooooooooooo00003Oooool3o`0000kooooo0ol0000>ooooo`03o`000?oooooooooo01Wooooo
1_l0000>ooooo`?o0000BOooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0:?ooool4o`0000_ooooo1_l0000<ooooo`Co0000
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000000kooooo1?l0000<ooooo`?o0000
3_ooool00ol0003oooooooooo`0Kooooo`Co00004?ooool00ol0003oooooooooo`18ooooo`000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03
o`000?oooooooooo01Sooooo0_l0000=ooooo`Co00002oooool6o`0000gooooo1?l0000<ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`04
o`000?ooooooooooo`0000gooooo0ol0000>ooooo`?o00003_ooool00ol0003oooooooooo`0]oooo
o`?o0000Foooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0Gooooo`?o00002oooool6o`0000cooooo1?l0000=
ooooo`;o000000?oooooo`000?ooool02oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool02oooool00ol0003oooooo`00000>ooooo`Co00003?ooool3
o`0000kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Jooooo`007_ooool00ol0
003oooooooooo`06ooooo`;o00003Oooool4o`0000_ooooo1_l0000=ooooo`Co00003?ooool2o`00
00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`04o`000?oooooooooo
o`0000gooooo0ol0000>ooooo`?o00003_ooool00ol0003oooooooooo`2Mooooo`007_ooool00ol0
003oooooooooo`05ooooo`?o00003?ooool5o`0000cooooo1?l0000=ooooo`04o`000?oooooooooo
o`0000cooooo0_l0000>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool0
0ol0003oooooo`00000>ooooo`Co00003?ooool3o`0000kooooo00?o0000ooooooooool0W_ooool0
01kooooo00?o0000ooooooooool00oooool4o`0000cooooo1Ol0000=ooooo`Co00003?ooool00ol0
003oooooooooo`0=ooooo`;o00003_ooool00ol0003oooooooooo`0:ooooo`04o`000?oooooooooo
o`0000gooooo0ol0000>ooooo`?o00003_ooool00ol0003oooooooooo`2Jooooo`;o00004oooool0
01kooooo00?o0000ooooooooool00_ooool5o`0000cooooo1?l0000=ooooo`04o`000?oooooooooo
o`0000cooooo00?o0000ooooooooool03Oooool2o`0000kooooo00?o0000ooooooooool02oooool3
o`0000kooooo1?l0000<ooooo`?o00003_ooool00ol0003oooooooooo`2Jooooo`?o00004oooool0
01kooooo00Co0000oooooooooooooooo1Ol0000=ooooo`Co00003?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00gooooo0_l0000;ooooo`04o`000?ooooooooooo`0000gooooo1?l0
000=ooooo`?o00003_ooool00ol0003oooooooooo`2Jooooo`;o00003Oooool4o`0001Cooooo000N
ooooo`04o`000?ooooooooooooooo`Co00003Oooool01?l0003oooooooooool0000<ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03Oooool2o`0000cooooo0ol0000>ooooo`Go0000
2oooool3o`0000kooooo00?o0000ooooooooool0V_ooool3o`0000cooooo1Ol0000Dooooo`007_oo
ool01?l0003oooooooooooooool4o`0000cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_l0000<ooooo`Co0000
3Oooool4o`0000gooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0^ooooo`;o0000
3Oooool4o`0000cooooo1Ol0000Eooooo`007_ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00_ooooo1?l0000=ooooo`Go00002oooool3o`0000kooooo00?o0000ooooooooool0
J_ooool2o`0002kooooo0ol0000<ooooo`Go00003?ooool4o`0001Kooooo000Nooooo`03o`000?oo
oooo000000oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00_ooooo1?l0000=ooooo`Co00002oooool4o`0006[ooooo00?o0000ooooooooool03_oo
ool4o`0001cooooo0_l0000=ooooo`Co00003?ooool5o`0000gooooo1?l0000Fooooo`007_ooool2
o`0000oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00cooooo1Ol0000;ooooo`?o00003?ooool3o`0006cooooo0_l0000?ooooo`Go00006_ooool3
o`0000cooooo1Ol0000<ooooo`Co00003Oooool01?l0003oooooooooool0000Gooooo`007_ooool2
o`0000kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00cooooo1?l0000<ooooo`?o00002oooool4o`0000kooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooo000000gooooo1?l0000=ooooo`Co00003?ooool0
0ol0003oooooooooo`0;ooooo`Co00003?ooool5o`0000gooooo1?l0000<ooooo`03o`000?oooooo
oooo01Wooooo000Nooooo`03o`000?oooooooooo03cooooo0ol0000;ooooo`Co00002oooool5o`00
00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`;o00003_ooool5o`00
00cooooo0_l0000Kooooo`Go00003?ooool4o`00013ooooo00?o0000ooooooooool09oooool001ko
oooo00?o0000ooooooooool0>_ooool3o`0000cooooo1?l0000;ooooo`Go00003Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooo000000kooooo0ol0000=ooooo`Co00003Oooool00ol0003o
ooooooooo`0Jooooo`Go00003_ooool3o`0003[ooooo000Nooooo`03o`000?oooooooooo03Sooooo
1?l0000;ooooo`Ko00003?ooool4o`0000cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool2o`0000kooooo
1Ol0000<ooooo`;o0000;Oooool4o`0000oooooo00?o0000ooooooooool0>Oooool001kooooo00?o
0000ooooooooool0:?ooool2o`0000gooooo1?l0000;ooooo`Ko00003?ooool00ol0003oooooo`00
0002o`0000_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooool000003_ooool3o`0000kooooo0ol0000=ooooo`03o`000?oo
oooooooo02kooooo0ol0001;ooooo`007_ooool00ol0003oooooooooo`0Vooooo`Co00002oooool6
o`0000cooooo1?l0000<ooooo`05o`000?ooooooooooooooool000002oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool2o`0000kooooo1Ol0
000<ooooo`;o0000@Oooool00ol0003oooooooooo`1:ooooo`007_ooool00ol0003oooooooooo`0F
ooooo`;o00003Oooool4o`0000_ooooo1_l0000=ooooo`Co00002oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool00ol0003oooooo`00000>
ooooo`?o00003_ooool3o`0000gooooo00?o0000ooooooooool0S_ooool001kooooo00?o0000oooo
ooooool05Oooool3o`0000_ooooo1_l0000<ooooo`Co00003Oooool01?l0003oooooooooool0000;
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<
ooooo`;o00003_ooool5o`0000cooooo0_l0002Pooooo`007_ooool00ol0003oooooooooo`04oooo
o`;o00003Oooool4o`0000_ooooo1_l0000=ooooo`Co00003?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool00ol0003oooooo`00000>oooo
o`?o00003_ooool3o`0000gooooo00?o0000ooooooooool0X?ooool001kooooo00?o0000oooooooo
ool00oooool3o`0000cooooo1Ol0000<ooooo`Co00003Oooool01?l0003oooooooooool0000<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<oooo
o`;o00003_ooool5o`0000cooooo0_l0002booooo`007_ooool01?l0003oooooooooooooool4o`00
00cooooo1Ol0000=ooooo`Co00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool02oooool00ol0003oooooo`00000>ooooo`?o00003_ooool3o`00
00gooooo00?o0000ooooooooool0Voooool2o`0001Gooooo000Nooooo`03o`000?oooooooooo00Go
00003?ooool4o`0000gooooo00Co0000oooooooooooo00003?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool2o`0000kooooo1Ol0000<oooo
o`;o0000[?ooool3o`0001Gooooo000Nooooo`03o`000?oooooo000000Co00003Oooool4o`0000co
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooool000003_ooool4o`0000gooooo0ol0000=ooooo`03o`000?oooooooooo06[o
oooo00?o0000ooooooooool0;_ooool2o`0000gooooo1?l0000Fooooo`007_ooool00ol0003ooooo
o`000003o`0000gooooo00Co0000oooooooooooo00003?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool2o`0000kooooo1_l0000;ooooo`;o
0000O?ooool2o`0002kooooo0ol0000<ooooo`Go00005_ooool001kooooo00?o0000ooooool00000
0ol0000<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00_ooooo1?l0000=ooooo`Co00002oooool2o`0006cooooo
00?o0000ooooooooool03_ooool4o`0001cooooo0_l0000=ooooo`Co00003?ooool5o`0001Oooooo
000Nooooo`;o00000_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo1_l0
000;ooooo`;o00003Oooool3o`0006cooooo0_l0000>ooooo`Ko00006_ooool3o`0000cooooo1Ol0
000<ooooo`Co00006?ooool001kooooo0_l0000>ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo1?l0000;
ooooo`;o00003Oooool4o`0000kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:
ooooo`04o`000?ooooooooooo`0000gooooo1?l0000=ooooo`Co00003?ooool00ol0003ooooooooo
o`0;ooooo`Co00003?ooool5o`0000gooooo1?l0000Hooooo`007_ooool00ol0003oooooooooo`1;
ooooo`;o00003Oooool3o`0000cooooo1Ol0000=ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool02oooool3o`0000kooooo1Ol0000;ooooo`;o00007?ooool5o`0000cooooo1?l0000@
ooooo`03o`000?oooooooooo01Oooooo000Nooooo`03o`000?oooooooooo04[ooooo0_l0000<oooo
o`Co00003?ooool5o`0000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool00ol0003oooooo`00000=oooo
o`Co00003Oooool4o`0000cooooo00?o0000ooooooooool06oooool5o`0000kooooo0ol0000Zoooo
o`007_ooool00ol0003oooooooooo`18ooooo`Co00002oooool5o`0000gooooo1?l0000<ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00cooooo0_l0000>ooooo`Go00003?ooool2o`0002cooooo1?l0000@ooooo`03
o`000?oooooooooo02Wooooo000Nooooo`03o`000?oooooooooo03Sooooo0_l0000=ooooo`Co0000
2oooool5o`0000gooooo00?o0000ooooool000000_l0000;ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000000kooooo
0ol0000=ooooo`Co00003Oooool00ol0003oooooooooo`0]ooooo`?o0000??ooool001kooooo00?o
0000ooooooooool0=_ooool4o`0000_ooooo1_l0000<ooooo`Co00003?ooool01Ol0003ooooooooo
oooooooo000000_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00cooooo0_l0000>ooooo`Go00003?ooool2o`00043ooooo00?o0000ooooooooool0
>oooool001kooooo00?o0000ooooooooool09_ooool2o`0000gooooo1?l0000;ooooo`Ko00003?oo
ool00ol0003oooooo`000002o`0000_ooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000003_ooool3o`0000kooooo0ol0
000=ooooo`03o`000?oooooooooo07kooooo000Nooooo`03o`000?oooooooooo02Cooooo1?l0000;
ooooo`Ko00003?ooool4o`0000cooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`;o00003_oo
ool5o`0000cooooo0_l0002@ooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o00003Oooool4
o`0000_ooooo1_l0000=ooooo`Co00002oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool02oooool00ol0003oooooo`00000>ooooo`?o00003_ooool3
o`0000gooooo00?o0000ooooooooool0T?ooool001kooooo00?o0000ooooooooool04oooool3o`00
00_ooooo1_l0000<ooooo`Co00003Oooool01?l0003oooooooooool0000;ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`;o00003_ooool5
o`0000cooooo0_l0002Rooooo`007_ooool00ol0003oooooooooo`02ooooo`;o00003Oooool4o`00
00_ooooo1_l0000=ooooo`Co00003?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool02oooool00ol0003oooooo`00000>ooooo`?o00003_ooool3o`00
00gooooo00?o0000ooooooooool0X_ooool001kooooo00Co0000oooooooooooooooo0ol0000<oooo
o`Go00003?ooool4o`0000gooooo00Co0000oooooooooooo00003?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool2o`0000kooooo1Ol0000<
ooooo`;o0000]?ooool001kooooo00?o0000ooooool000000ol0000<ooooo`Go00003Oooool4o`00
00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooool000003_ooool3o`0000kooooo0ol0000=ooooo`03o`000?oooooooooo
06[ooooo0_l0000_ooooo`;o00005oooool001kooooo1_l0000<ooooo`Co00003Oooool01?l0003o
ooooooooool0000<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`;o00003_ooool5o`0000cooooo0_l0001looooo`?o0000;Oooool3o`00
01Oooooo000Nooooo`Go00003Oooool4o`0000cooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool4o`0000go
oooo0ol0000<ooooo`;o0000K?ooool00ol0003oooooooooo`0>ooooo`Go00006oooool2o`0000go
oooo1?l0000Hooooo`007_ooool4o`0000gooooo00Co0000oooooooooooo00003?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`Ko00002oooool2o`0000gooooo0ol0001/ooooo`;o00003_ooool4o`0001co
oooo0ol0000<ooooo`Go00006?ooool001kooooo1?l0000<ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03Oooool4o`0000_ooooo0_l0000=ooooo`Co00003_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooo00003Oooool4o`0000go
oooo0_l0000>ooooo`03o`000?oooooooooo00_ooooo1?l0000<ooooo`Go00006Oooool001kooooo
00?o0000ooooool00000Foooool2o`0000gooooo0ol0000<ooooo`Co00003_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00_ooooo0ol0000=ooooo`Ko00002oooool2o`0001cooooo
1Ol0000<ooooo`Co00006_ooool001kooooo00?o0000ooooooooool0FOooool2o`0000gooooo1?l0
000<ooooo`Go00003Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`;o000000?oooooo`000?ooool03?oo
ool4o`0000gooooo1?l0000<ooooo`03o`000?oooooooooo01_ooooo1Ol0000>ooooo`?o00006_oo
ool001kooooo00?o0000ooooooooool0F?ooool3o`0000cooooo1Ol0000=ooooo`?o00003Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0;ooooo`?o00003_ooool5o`0000_ooooo0_l0000]ooooo`Co00004?ooool0
0ol0003oooooooooo`0Iooooo`007_ooool00ol0003oooooooooo`18ooooo`;o00003?ooool4o`00
00cooooo1Ol0000=ooooo`03o`000?oooooo000000gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000003Oooool5o`00
00cooooo1?l0000<ooooo`03o`000?oooooooooo02kooooo0ol0000/ooooo`007_ooool00ol0003o
ooooooooo`16ooooo`Co00002oooool5o`0000gooooo1?l0000<ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00co
oooo0_l0000>ooooo`?o00003_ooool2o`00043ooooo00?o0000ooooooooool0:oooool001kooooo
00?o0000ooooooooool0=_ooool2o`0000gooooo1?l0000;ooooo`Go00003Oooool01?l0003ooooo
ooooool0000<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooo000000kooooo0ol0000=ooooo`?o00003_ooool00ol0003o
ooooooooo`1^ooooo`007_ooool00ol0003oooooooooo`0dooooo`Co00002oooool5o`0000gooooo
1?l0000<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo0_l0000>ooooo`Go00003?ooool00ol0003ooooo
ooooo`1oooooo`007_ooool00ol0003oooooooooo`0Tooooo`;o00003Oooool4o`0000_ooooo1_l0
000<ooooo`04o`000?ooooooooooo`0000cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000003_ooool4o`0000gooooo
0ol0000=ooooo`03o`000?oooooooooo083ooooo000Nooooo`03o`000?oooooooooo02;ooooo1?l0
000;ooooo`Go00003_ooool3o`0000cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool2o`0000kooooo0ol0
000>ooooo`;o0000T_ooool001kooooo00?o0000ooooooooool04_ooool2o`0000gooooo1?l0000;
ooooo`Ko00003Oooool00ol0003oooooo`00000<ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000000kooooo1?l0000=
ooooo`;o00003_ooool00ol0003oooooooooo`2Booooo`007_ooool00ol0003oooooooooo`0Aoooo
o`?o00002oooool5o`0000kooooo0ol0000=ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo0_l0000>oooo
o`?o00003_ooool00ol0003oooooooooo`2Sooooo`007_ooool00ol0003oooooooooo`02o`0000go
oooo1?l0000;ooooo`Ko00003Oooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000000ko
oooo1?l0000=ooooo`;o00003_ooool00ol0003oooooooooo`1Zooooo`;o0000>?ooool001kooooo
00?o0000ooooool000000_l0000<ooooo`Co00003_ooool3o`0000gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3?ooool2o`0000kooooo0ol0000>ooooo`03o`000?oooooooooo07_ooooo0ol0000gooooo`000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0
1?ooool4o`0000cooooo1Ol0000=ooooo`03o`000?oooooo000000gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3?ooool4o`0000gooooo0_l0000=ooooo`;o0000K?ooool2o`0000oooooo1Ol0000Kooooo`;o0000
6Oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003ooooo
ooooo`04ooooo`Co00003_ooool3o`0000gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`?o00003_ooool00ol0003oooooooooo`0<ooooo`?o0000K?ooool3o`0000gooooo
1?l0000Looooo`?o00006Oooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000
1?ooool5o`0000gooooo00?o0000ooooool000003Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00gooooo0_l0000=ooooo`;o00003Oooool4o`0000kooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0:ooooo`?o00003_ooool5o`0000cooooo0_l0000>ooooo`03o`00
0?oooooooooo00_ooooo1?l0000Jooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo
00CoA4A4omgMgOoooooo00001_ooool3o`0006cooooo00?o0000ooooooooool03?ooool3o`0000co
oooo1?l0000>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool3o`0000go
oooo1?l0000=ooooo`;o00007?ooool4o`0001_ooooo0003ooooo`05o`000?ooooooooooooooool0
00002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo06Wooooo0_l0000=oooo
o`Co00003?ooool5o`0000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool2o`000003ooooool0003ooooo
00cooooo1Ol0000<ooooo`;o00003_ooool00ol0003oooooooooo`0Kooooo`Go00006oooool000?o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0J?ooool3o`0000cooooo1?l0000>ooooo`?o00003Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;oooo
o`?o00003Oooool4o`0000gooooo0_l0000^ooooo`?o00007?ooool000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0Eoooool2o`00
00gooooo1?l0000<ooooo`Go00003Oooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`;o000000?oooooo`00
0?ooool03?ooool5o`0000cooooo0_l0000>ooooo`03o`000?oooooooooo02oooooo00?o0000oooo
ooooool06oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo
00Kooooo00?o0000ooooooooool0E_ooool3o`0000cooooo1Ol0000=ooooo`?o00003Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0;ooooo`?o00003_ooool3o`0000gooooo0_l0001Oooooo`007_ooool00ol0003o
ooooooooo`16ooooo`;o00003?ooool4o`0000cooooo1Ol0000=ooooo`03o`000?oooooo000000go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooool000003Oooool5o`0000cooooo0ol0000=ooooo`03o`000?oooooooooo05oo
oooo000Nooooo`03o`000?oooooooooo04Cooooo1?l0000;ooooo`Go00003Oooool4o`0000cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool2o`0000kooooo0ol0000>ooooo`03o`000?oooooooooo06oooooo
000Nooooo`03o`000?oooooooooo03Cooooo0_l0000=ooooo`Co00002oooool5o`0000gooooo00Co
0000oooooooooooo00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool02oooool00ol0003oooooo`00000>ooooo`Co00003?ooool3o`0000kooooo
00?o0000ooooooooool0L?ooool001kooooo00?o0000ooooooooool0<_ooool4o`0000_ooooo1Ol0
000=ooooo`Co00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`;o00003_ooool3o`0000kooooo00?o
0000ooooooooool0POooool001kooooo00?o0000ooooooooool08_ooool2o`0000gooooo1?l0000;
ooooo`Ko00003?ooool01?l0003oooooooooool0000<ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000000kooooo1?l0
000=ooooo`;o00003_ooool00ol0003oooooooooo`22ooooo`007_ooool00ol0003oooooooooo`0P
ooooo`Co00002oooool5o`0000kooooo0ol0000<ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo0_l0000>
ooooo`?o00003_ooool00ol0003oooooooooo`2Cooooo`007_ooool00ol0003oooooooooo`0@oooo
o`;o00003Oooool4o`0000_ooooo1_l0000=ooooo`03o`000?oooooo000000cooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ool000003_ooool4o`0000gooooo0_l0000>ooooo`03o`000?oooooooooo06[ooooo00?o0000oooo
ooooool09oooool001kooooo00?o0000ooooooooool03oooool3o`0000_ooooo1Ol0000>ooooo`?o
00003Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0<ooooo`;o00003_ooool3o`0000kooooo00?o0000oooooooo
ool0Noooool2o`0002Sooooo000Nooooo`?o00003Oooool4o`0000_ooooo1_l0000=ooooo`03o`00
0?oooooo000000gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03?ooool4o`0000gooooo0_l0000=ooooo`;o0000
K?ooool2o`0000oooooo1?l0000Wooooo`007_ooool3o`0000cooooo1?l0000>ooooo`?o00003Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo0ol0000>ooooo`03o`000?oo
oooooooo00cooooo0ol0001/ooooo`?o00003Oooool3o`0002Wooooo000Looooo`Co00003?ooool5
o`0000gooooo00?o0000ooooool000003Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00gooooo0_l0000=ooooo`;o00003Oooool4o`0000kooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0;ooooo`?o00003_ooool5o`0000cooooo0_l0000>ooooo`03o`000?oooooo
oooo01Wooooo000Kooooo`Co00003_ooool3o`0006cooooo00?o0000ooooooooool03?ooool3o`00
00cooooo1?l0000>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool3o`00
00gooooo1?l0000=ooooo`03o`000?oooooooooo02[ooooo000Jooooo`Go00003oooool00ol0003o
ooooooooo`1Yooooo`;o00003Oooool4o`0000cooooo1Ol0000=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[o
oooo0ol0000>ooooo`Go00003?ooool2o`0000kooooo00?o0000ooooooooool0:oooool001_ooooo
1?l0001jooooo`?o00003?ooool4o`0000kooooo0ol0000=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo
0ol0000=ooooo`Co00003Oooool2o`0003gooooo000Looooo`03o`000?oooooo000006Wooooo0_l0
000=ooooo`Co00003?ooool5o`0000gooooo00?o0000ooooool000003Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool2o`000003ooooool0
003ooooo00cooooo1Ol0000<ooooo`;o00003_ooool00ol0003oooooooooo`0mooooo`007_ooool0
0ol0003oooooooooo`1Vooooo`?o00003?ooool4o`0000kooooo0ol0000=ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00_ooooo0ol0000=ooooo`Co00003Oooool2o`0004oooooo000Nooooo`03o`000?oooooooooo
05Gooooo0_l0000=ooooo`Co00003?ooool5o`0000gooooo00?o0000ooooool000003Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool2o`00
0003ooooool0003ooooo00cooooo1Ol0000<ooooo`;o00003_ooool00ol0003oooooooooo`1?oooo
o`007_ooool00ol0003oooooooooo`1Dooooo`?o00003?ooool5o`0000gooooo0ol0000=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00_ooooo0ol0000>ooooo`?o00003Oooool2o`00067ooooo000Nooooo`03o`00
0?oooooooooo04Cooooo0_l0000<ooooo`Co00003?ooool5o`0000gooooo00?o0000ooooool00000
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
2oooool00ol0003oooooo`00000=ooooo`Go00003?ooool3o`0000gooooo00?o0000ooooooooool0
HOooool001kooooo00?o0000ooooooooool0@_ooool4o`0000_ooooo1Ol0000=ooooo`Co00003?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0<ooooo`;o00003_ooool3o`0000kooooo00?o0000ooooooooool0LOoo
ool001kooooo00?o0000ooooooooool0<_ooool2o`0000gooooo1?l0000;ooooo`Go00003Oooool0
1?l0003oooooooooool0000<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000000kooooo1?l0000<ooooo`?o00003_oo
ool00ol0003oooooooooo`1booooo`007_ooool00ol0003oooooooooo`0`ooooo`Co00002oooool5
o`0000gooooo1?l0000<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo0_l0000>ooooo`?o00003_ooool0
0ol0003oooooooooo`23ooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o00003Oooool4o`00
00_ooooo1_l0000<ooooo`04o`000?ooooooooooo`0000cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000003_ooool4
o`0000gooooo0_l0000>ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool05oooool0
01kooooo00?o0000ooooooooool07_ooool4o`0000_ooooo1Ol0000>ooooo`?o00003?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0<ooooo`;o00003_ooool3o`0000kooooo00?o0000ooooooooool0Noooool2o`00
01Sooooo000Nooooo`03o`000?oooooooooo00kooooo0_l0000=ooooo`Co00002oooool6o`0000go
oooo00?o0000ooooool000003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`Co00003Oooool2o`0000go
oooo0_l0001/ooooo`03o`000?oooooooooo00kooooo1?l0000Gooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`?o00002oooool5o`0000kooooo0ol0000=ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool3o`0000kooooo00?o0000ooooooooool03?ooool3o`0006cooooo
0_l0000>ooooo`?o00006Oooool001kooooo0_l0000<ooooo`Co00002oooool6o`0000gooooo00?o
0000ooooool000003Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo0_l0
000=ooooo`;o00003Oooool4o`0000kooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0;ooooo`?o00003_ooool4o`0000gooooo0_l0000Jooooo`007_ooool00ol0003oooooooooo`0:
ooooo`Co00003_ooool3o`0006cooooo00?o0000ooooooooool03?ooool3o`0000cooooo1?l0000>
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool3o`0000gooooo0ol0000>
ooooo`03o`000?oooooooooo01[ooooo000Nooooo`03o`000?oooooooooo00Wooooo1Ol0000?oooo
o`03o`000?oooooooooo06Wooooo0_l0000=ooooo`Co00003?ooool5o`0000gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool3o`0000kooooo1Ol0000<ooooo`;o00003_ooool00ol0003oooooooooo`0Koooo
o`007_ooool00ol0003oooooooooo`0:ooooo`?o0000Noooool3o`0000cooooo1?l0000>ooooo`?o
00003Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`?o00003Oooool4o`0000gooooo00?o0000oooooooo
ool0;?ooool001kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Yooooo`;o0000
3Oooool4o`0000cooooo1Ol0000=ooooo`03o`000?oooooo000000gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo0ol0000>ooooo`Go0000
3?ooool2o`0000kooooo00?o0000ooooooooool0;Oooool001kooooo00?o0000ooooooooool0M_oo
ool3o`0000cooooo1?l0000>ooooo`?o00003Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`?o00003Ooo
ool4o`0000gooooo0_l0000oooooo`007_ooool00ol0003oooooooooo`1Uooooo`;o00003Oooool4
o`0000cooooo1Ol0000=ooooo`03o`000?oooooo000000gooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo0000ooooo`0<
ooooo`Go00003?ooool2o`0000kooooo00?o0000ooooooooool0?oooool001kooooo00?o0000oooo
ooooool0I?ooool3o`0000cooooo1?l0000>ooooo`?o00003Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;oooo
o`?o00003Oooool4o`0000gooooo0_l0001Aooooo`007_ooool00ol0003oooooooooo`1Cooooo`;o
00003Oooool4o`0000cooooo1Ol0000=ooooo`03o`000?oooooo000000gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo
0000ooooo`0<ooooo`Go00003?ooool2o`0000kooooo00?o0000ooooooooool0DOooool001kooooo
00?o0000ooooooooool0D_ooool3o`0000cooooo1Ol0000=ooooo`?o00003Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0;ooooo`?o00003_ooool3o`0000gooooo0_l0001Sooooo`007_ooool00ol0003ooooooooo
o`12ooooo`;o00003?ooool4o`0000cooooo1Ol0000=ooooo`03o`000?oooooo000000gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooool000003Oooool5o`0000cooooo0ol0000=ooooo`03o`000?oooooooooo06?ooooo000N
ooooo`03o`000?oooooooooo043ooooo1?l0000;ooooo`Go00003Oooool4o`0000cooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03?ooool2o`0000kooooo0ol0000>ooooo`03o`000?oooooooooo07?ooooo000Noooo
o`03o`000?oooooo0000033ooooo0_l0000=ooooo`Co00002oooool5o`0000gooooo00Co0000oooo
oooooooo00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool02oooool00ol0003oooooo`00000>ooooo`Co00003?ooool3o`0000kooooo00?o0000
ooooooooool0M?ooool001kooooo00Co0000ooooool0003o0000;Oooool4o`0000_ooooo1Ol0000=
ooooo`Co00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`;o00003_ooool3o`0000kooooo00?o0000
ooooooooool0QOooool001kooooo1Ol0000Looooo`;o00003Oooool4o`0000_ooooo1_l0000<oooo
o`04o`000?ooooooooooo`0000cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool4o`0000gooooo0_l0000=
ooooo`;o0000K?ooool00ol0003oooooooooo`0Iooooo`007_ooool3o`0001cooooo1?l0000;oooo
o`Go00003_ooool3o`0000cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<oooo
o`?o00003_ooool00ol0003oooooooooo`0<ooooo`?o0000K?ooool2o`0001[ooooo000Nooooo`;o
00003_ooool00ol0003oooooooooo`0;ooooo`Co00002oooool6o`0000gooooo00?o0000ooooool0
00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo0_l0000=ooooo`;o
00003Oooool4o`0000kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooo000000kooooo1?l0000Iooooo`007Oooool2o`0001_ooooo1Ol0000>ooooo`?o0000
K?ooool00ol0003oooooooooo`0<ooooo`?o00003?ooool4o`0000kooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0<ooooo`;o00003_ooool3o`0001_ooooo000Looooo`03o`000?oo
oooo000001[ooooo1_l0000?ooooo`03o`000?oooooooooo06Wooooo0_l0000=ooooo`Co00003?oo
ool5o`0000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool02oooool3o`0000kooooo1?l0000=ooooo`;o00007?oo
ool001kooooo00?o0000ooooooooool06_ooool3o`0007_ooooo0ol0000<ooooo`Co00003_ooool3
o`0000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03?ooool3o`0000gooooo0ol0000>ooooo`03o`000?oooooo
oooo01cooooo000Nooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0JOooool2o`00
00gooooo1?l0000<ooooo`Go00003Oooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`?o00003_ooool5o`00
00cooooo0_l0000>ooooo`03o`000?oooooooooo01gooooo000Nooooo`03o`000?oooooooooo08Ko
oooo0ol0000<ooooo`Co00003_ooool3o`0000gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool3o`0000go
oooo1?l0000=ooooo`03o`000?oooooooooo02kooooo000Nooooo`03o`000?oooooooooo07Gooooo
0_l0000=ooooo`Co00003?ooool5o`0000gooooo00?o0000ooooool000003Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool3o`0000kooooo
1Ol0000<ooooo`;o00003_ooool00ol0003oooooooooo`0_ooooo`007_ooool00ol0003ooooooooo
o`1dooooo`?o00003?ooool4o`0000kooooo0ol0000=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo0ol0
000=ooooo`Co00003Oooool2o`00047ooooo000Nooooo`03o`000?oooooooooo06?ooooo0_l0000=
ooooo`Co00003?ooool5o`0000gooooo00?o0000ooooool000003Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool2o`000003ooooool0003o
oooo00cooooo1Ol0000<ooooo`;o00003_ooool00ol0003oooooooooo`11ooooo`007_ooool00ol0
003oooooooooo`1Rooooo`?o00003?ooool4o`0000kooooo0ol0000=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00_ooooo0ol0000=ooooo`Co00003Oooool2o`0005?ooooo000Nooooo`03o`000?oooooooooo057o
oooo0_l0000=ooooo`Co00003?ooool5o`0000gooooo00?o0000ooooool000003Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool2o`000003
ooooool0003ooooo00cooooo1Ol0000<ooooo`;o00003_ooool00ol0003oooooooooo`1Cooooo`00
7_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03kooooo0ol0000<ooooo`Go0000
3Oooool3o`0000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool02oooool3o`0000kooooo0ol0000=ooooo`;o0000
IOooool001kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0^ooooo`;o00003?oo
ool4o`0000cooooo1Ol0000=ooooo`03o`000?oooooo000000gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000003Ooo
ool5o`0000cooooo0ol0000=ooooo`03o`000?oooooooooo06Gooooo0003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`00
0?oooooooooo00kooooo0ol0000]ooooo`Co00002oooool5o`0000gooooo1?l0000<ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00cooooo0_l0000>ooooo`?o00003_ooool00ol0003oooooooooo`1eooooo`000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B401_ooool00ol0003oooooooooo`0>ooooo`Co00007?ooool2o`0000gooooo1?l0000;ooooo`Go
00003Oooool01?l0003oooooooooool0000<ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo1?l0000<oooo
o`?o00003Oooool2o`0007Sooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0
003ooooooooooooooooo000000Gooooo0ol0000>ooooo`?o00007?ooool4o`0000_ooooo1Ol0000=
ooooo`Co00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo0ol0000>
ooooo`03o`000?oooooooooo00[ooooo1Ol0001Jooooo`03o`000?oooooooooo01_ooooo0003oooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Gooooo1?l0
000<ooooo`?o00003_ooool00ol0003oooooooooo`0;ooooo`Co00002oooool6o`0000cooooo00Co
0000oooooooooooo00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
0_l0000=ooooo`;o00002oooool6o`0000kooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooo000001_ooooo0003ooooo`05o`000?ooooooooooooooool00000
2oooool01Ol0003oEEEEo`000?l@413oc<c<00Cooooo0ol0000>ooooo`03o`000?oooooooooo01[o
oooo1Ol0000>ooooo`?o0000K?ooool00ol0003oooooooooo`0;ooooo`Co00002_ooool6o`0000ko
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool02_ooool01?l0003oooooooooool0000=ooooo`?o00007?ooool000?o
oooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Gooooo1?l0000=oooo
o`03o`000?oooooooooo01[ooooo1_l0000?ooooo`03o`000?oooooooooo06Wooooo0_l0000<oooo
o`Go00003?ooool5o`0000gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool00ol0003oooooo`00000>oooo
o`Co00006oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH
00Gooooo00Co0000oooooooooooo0000;?ooool3o`0007[ooooo1?l0000;ooooo`Go00003_ooool3
o`0000gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00[ooooo00Co0000oooooooooooo00003Oooool3o`0000kooooo0ol0000Mooooo`000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@0_ooool01Ol0003ooooo
oooooooooooo000002gooooo00?o0000ooooooooool0JOooool2o`0000cooooo1Ol0000<ooooo`Go
00003Oooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0;ooooo`?o00003_ooool4o`0000cooooo0ol0000Nooooo`00
7_ooool00ol0003oooooooooo`2Eooooo`Co00002oooool5o`0000kooooo0ol0000=ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`04o`00
0?ooooooooooo`0000gooooo1?l0000=ooooo`?o00003_ooool00ol0003oooooooooo`0Nooooo`00
7_ooool00ol0003oooooooooo`25ooooo`;o00003?ooool5o`0000cooooo1Ol0000=ooooo`03o`00
0?oooooo000000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00_ooooo0ol0000>ooooo`Go00002oooool3o`0000kooooo00?o0000ooooooooool0
7oooool001kooooo00?o0000ooooooooool0Poooool4o`0000_ooooo1Ol0000>ooooo`?o00003Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02Ooo
ool01?l0003oooooooooool0000=ooooo`Co00003Oooool4o`0000gooooo00?o0000ooooooooool0
<?ooool001kooooo00?o0000ooooooooool0Loooool2o`0000cooooo1Ol0000<ooooo`Go00003Ooo
ool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0:ooooo`?o00003_ooool5o`0000_ooooo0ol0000>ooooo`03o`000?oo
oooooooo037ooooo000Nooooo`03o`000?oooooooooo077ooooo1?l0000;ooooo`Go00003_ooool3
o`0000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00Wooooo00Go0000ooooooooooooooooo`00000<ooooo`Co00003Oooool4o`0000gooooo0_l0
0013ooooo`007_ooool00ol0003oooooooooo`1Qooooo`;o00003?ooool5o`0000cooooo1Ol0000=
ooooo`03o`000?oooooo000000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo0000ooooo`0<ooooo`Go00002oooool3
o`0000kooooo00?o0000ooooooooool0@oooool001kooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0mooooo`Co00002oooool5o`0000kooooo0ol0000=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`09ooooo`05o`000?oooooooooo
ooooool000003?ooool4o`0000gooooo1?l0000=ooooo`;o0000EOooool001kooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0]ooooo`;o00003?ooool5o`0000cooooo1Ol0000=oooo
o`03o`000?oooooo000000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00[ooooo0_l000000ooooooo0000ooooo`0<ooooo`Go00002oooool3o`00
00kooooo00?o0000ooooooooool0EOooool001kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`?o0000;?ooool4o`0000_ooooo1_l0000=ooooo`?o00003Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0:ooooo`Co00003Oooool4o`0000gooooo0_l0001Wooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo1?l0000Looooo`;o00002oooool5o`0000gooooo
1?l0000=ooooo`03o`000?oooooo000000gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool5o`0000cooooo
0ol0000=ooooo`;o0000J?ooool001cooooo00?o0000ooooool000003_ooool3o`0000kooooo0ol0
000Kooooo`Go00002_ooool6o`0000gooooo1?l0000<ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool02oooool4o`0000kooooo00?o0000ooooooooool02_ooool5o`0006Sooooo000L
ooooo`04o`000?oooooo0000o`0000gooooo1?l0000<ooooo`?o00003_ooool00ol0003ooooooooo
o`09ooooo`Ko00003?ooool4o`0000gooooo00Co0000oooooooooooo00003?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo0ol0000=ooooo`;o00002oooool6o`0000gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Iooooo`006oooool4o`0000gooooo0ol0
000>ooooo`03o`000?oooooooooo01Wooooo1_l0000>ooooo`?o0000K?ooool00ol0003ooooooooo
o`0:ooooo`Go00002_ooool6o`0000gooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool01?l0003ooooooooo
ool0000Looooo`006oooool4o`0000cooooo0ol0000>ooooo`03o`000?oooooooooo01_ooooo1Ol0
000?ooooo`03o`000?oooooooooo06Wooooo0_l0000;ooooo`Ko00003?ooool5o`0000cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool02oooool00ol0003oooooo`00000Mooooo`006_ooool3o`000003ooooool0003o
oooo00_ooooo00?o0000ooooooooool0;Oooool3o`0007[ooooo1?l0000:ooooo`Ko00003_ooool3
o`0000cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00[ooooo00Co0000oooooooooooo00003Oooool3o`0001kooooo000Iooooo`?o00000_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0JOooool2
o`0000cooooo1Ol0000<ooooo`Go00003Oooool00ol0003oooooo`00000<ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
000000kooooo1?l0000Mooooo`006Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
0:Gooooo1?l0000;ooooo`Go00003_ooool3o`0000gooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooo00003Oooool3
o`0000kooooo0ol0000Oooooo`006?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
09Gooooo0_l0000<ooooo`Go00003?ooool5o`0000gooooo00?o0000ooooool000003Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool3o`00
00kooooo1?l0000<ooooo`?o00008?ooool001kooooo00?o0000ooooooooool0Toooool4o`0000_o
oooo1Ol0000>ooooo`?o00003Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02_ooool01?l0003oooooooooool0000=ooooo`Co00003Oooool3o`00
00kooooo00?o0000ooooooooool08?ooool001kooooo00?o0000ooooooooool0Poooool2o`0000co
oooo1Ol0000<ooooo`Go00003Oooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`?o00003_ooool5o`0000_o
oooo0ol0000>ooooo`03o`000?oooooooooo027ooooo000Nooooo`03o`000?oooooooooo087ooooo
1?l0000;ooooo`Go00003_ooool3o`0000gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo00003Oooool4o`0000go
oooo1?l0000=ooooo`03o`000?oooooooooo03;ooooo000Nooooo`03o`000?oooooooooo077ooooo
0_l0000<ooooo`Go00003?ooool5o`0000gooooo00?o0000ooooool000003Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool3o`0000kooooo
1Ol0000;ooooo`?o00003_ooool00ol0003oooooooooo`0cooooo`007_ooool00ol0003ooooooooo
o`0^ooooo`03o`000?oooooooooo03kooooo1?l0000;ooooo`Go00003_ooool3o`0000gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo00Go
0000ooooooooooooooooo`00000<ooooo`Co00003Oooool4o`0000gooooo0_l00015ooooo`007_oo
ool00ol0003oooooooooo`0^ooooo`;o0000;oooool2o`0000cooooo1Ol0000<ooooo`Go00003Ooo
ool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0:ooooo`;o000000?oooooo`000?ooool03?ooool5o`0000_ooooo0ol0
000>ooooo`03o`000?oooooooooo04Gooooo000Nooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool03Oooool4o`0002cooooo1?l0000;ooooo`Go00003_ooool3o`0000gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool02_ooool4o`0000gooooo1?l0000<ooooo`?o0000Eoooool001kooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0=ooooo`Go00006oooool2o`0000cooooo1Ol0000<oooo
o`Go00003Oooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo1Ol0000;oooo
o`?o00003?ooool4o`0005Sooooo000Nooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03_ooool3o`0000gooooo1?l0000Kooooo`Co00002oooool6o`0000gooooo0ol0000=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool4o`0000cooooo0ol0000<ooooo`Co
0000FOooool001kooooo0_l0000<ooooo`03o`000?oooooo000000kooooo1?l0000<ooooo`?o0000
3_ooool00ol0003oooooooooo`09ooooo`Go00003Oooool4o`0000gooooo00?o0000ooooool00000
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo0ol0000;ooooo`Co0000
2oooool6o`0000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool00_l0
000<ooooo`?o00003_ooool3o`0000kooooo00?o0000ooooooooool06Oooool6o`0000kooooo0ol0
001Zooooo`?o00003?ooool4o`0000_ooooo1_l0000=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01[ooooo000J
ooooo`05o`000?oooooo0000ooooool000003?ooool4o`0000cooooo0ol0000>ooooo`03o`000?oo
oooooooo01_ooooo1?l0000@ooooo`03o`000?oooooooooo06Oooooo1?l0000;ooooo`Ko00003?oo
ool4o`0000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool06oooool001Wooooo0ol00002ooooo`03o`000?oooooo
oooo00Wooooo0ol0000>ooooo`03o`000?oooooooooo02gooooo0ol0001Zooooo`;o00003Oooool4
o`0000_ooooo1_l0000=ooooo`Co00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool02_ooool01?l0003oooooooooool0000Nooooo`006Oooool4
o`000003ooooool0003ooooo00Wooooo0ol0000>ooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool0J?ooool3o`0000_ooooo1_l0000<ooooo`Co00003Oooool01?l0003oooooooooool0
000<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooo000001oooooo000Hooooo`?o00000oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo09[ooooo0_l0000=ooooo`Co00002oooool6o`0000gooooo1?l0000<
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:
ooooo`04o`000?ooooooooooo`0000gooooo0ol0000Pooooo`005oooool3o`0000Cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`2Jooooo`?o00003?ooool5o`0000cooooo1?l0000=
ooooo`04o`000?ooooooooooo`0000cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000003_ooool4o`0001oooooo000G
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Toooool2o`0000gooooo1?l0000<
ooooo`Go00003Oooool4o`0000cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooo00003Oooool3o`0000kooooo0ol0
000Qooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo09;ooooo0ol0000<
ooooo`Go00003?ooool4o`0000gooooo00Co0000oooooooooooo00003?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool3o`0000kooooo1?l0
000<ooooo`?o00008_ooool001kooooo00?o0000ooooooooool0POooool2o`0000gooooo1?l0000<
ooooo`Go00003Oooool4o`0000cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooo00003Oooool4o`0000gooooo0ol0
000>ooooo`03o`000?oooooooooo02;ooooo000Nooooo`03o`000?oooooooooo083ooooo0ol0000<
ooooo`Go00003?ooool4o`0000gooooo00Co0000oooooooooooo00003?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool3o`0000kooooo1Ol0
000;ooooo`?o00003_ooool00ol0003oooooooooo`0Sooooo`007_ooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo02kooooo0_l0000=ooooo`Co00003?ooool5o`0000gooooo1?l0000<
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:
ooooo`04o`000?ooooooooooo`0000gooooo1?l0000=ooooo`Co00003Oooool00ol0003ooooooooo
o`0dooooo`007_ooool00ol0003oooooooooo`0nooooo`;o0000;_ooool3o`0000cooooo1Ol0000<
ooooo`Co00003Oooool01?l0003oooooooooool0000<ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`?o00003_ooool5o`0000_ooooo0ol0
000>ooooo`03o`000?oooooooooo03Gooooo000Nooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool03Oooool4o`0001cooooo0_l0000=ooooo`Co00003?ooool5o`0000gooooo1?l0000<
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00_ooooo1?l0000=ooooo`Co00002oooool4o`0004Oooooo000Noooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool03Oooool5o`0001[ooooo0ol0000<oooo
o`Go00003?ooool4o`0000gooooo00Co0000oooooooooooo00003?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<
ooooo`Go00002oooool3o`0000cooooo0ol00019ooooo`007_ooool2o`0000kooooo00?o0000oooo
ooooool02oooool00ol0003oooooo`00000>ooooo`?o00003Oooool4o`0000cooooo00?o0000oooo
ooooool02oooool4o`0000cooooo1Ol0000=ooooo`Co00003?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00cooooo1?l0000<ooooo`?o00002oooool4o`0000kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Wooooo000Mooooo`;o
00003_ooool00ol0003oooooooooo`0<ooooo`;o00003_ooool5o`0000cooooo0_l0000Kooooo`Go
00003?ooool4o`00013ooooo00?o0000ooooooooool0FOooool3o`0000cooooo1?l0000;ooooo`Go
00003Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool06_ooool001cooooo00?o0000ooooool000002oooool00ol0003oooooo`00000>ooooo`?o0000
3_ooool3o`0000gooooo00?o0000ooooooooool06_ooool5o`0000kooooo0ol0001[ooooo`?o0000
3?ooool4o`0000_ooooo1Ol0000=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0Kooooo`006oooool01?l0003oooooooooool0000;ooooo`;o0000
3_ooool5o`0000cooooo0_l0000]ooooo`Co00003oooool00ol0003oooooooooo`1Xooooo`Co0000
2oooool6o`0000cooooo1?l0000<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0Looooo`006?ooool00ol0003oooooo`000003ooooo`03o`000?oo
oooooooo00Sooooo0ol0000>ooooo`?o00003Oooool00ol0003oooooooooo`0^ooooo`?o0000J_oo
ool2o`0000gooooo1?l0000;ooooo`Ko00003?ooool00ol0003oooooo`000002o`0000_ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01gooooo000H
ooooo`;o00001?ooool00ol0003oooooooooo`07ooooo`Go00003?ooool2o`00047ooooo00?o0000
ooooooooool0Ioooool4o`0000_ooooo1_l0000<ooooo`Co00003?ooool01Ol0003ooooooooooooo
oooo000000_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo01kooooo000Gooooo`?o00001?ooool00ol0003oooooooooo`07ooooo`?o00003Oooool0
0ol0003oooooooooo`2Kooooo`;o00003Oooool4o`0000_ooooo1_l0000=ooooo`Co00002oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool0
0ol0003oooooo`00000Qooooo`005_ooool5o`0000?ooooo00?o0000ooooooooool01_ooool2o`00
0:cooooo0ol0000;ooooo`Ko00003?ooool4o`0000gooooo00Co0000oooooooooooo00002oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool2
o`0002;ooooo000Fooooo`?o00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
09_ooooo0_l0000=ooooo`Co00002oooool6o`0000gooooo1?l0000<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo0000
00kooooo0ol0000Rooooo`005Oooool2o`0000Oooooo00?o0000ooooooooool0X_ooool3o`0000co
oooo1Ol0000<ooooo`Co00003Oooool01?l0003oooooooooool0000<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`;o00003_ooool5o`00
027ooooo000Dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0TOooool2o`0000go
oooo1?l0000<ooooo`Go00003Oooool4o`0000cooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000003_ooool3o`0000ko
oooo0ol0000Sooooo`007_ooool00ol0003oooooooooo`2@ooooo`?o00003?ooool5o`0000cooooo
1?l0000=ooooo`04o`000?ooooooooooo`0000cooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo0_l0000>ooooo`Go00003?ooool2o`0002Go
oooo000Nooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0;_ooool2o`0000gooooo
1?l0000<ooooo`Go00003Oooool4o`0000cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooool000003_ooool4o`0000gooooo
0ol0000=ooooo`03o`000?oooooooooo02Gooooo000Nooooo`03o`000?oooooooooo04kooooo0_l0
000^ooooo`?o00003?ooool5o`0000cooooo1?l0000=ooooo`04o`000?ooooooooooo`0000cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo
0_l0000>ooooo`Ko00002oooool2o`0003Oooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo03co
oooo00?o0000ooooooooool03_ooool4o`0001cooooo0_l0000=ooooo`Co00003?ooool5o`0000go
oooo1?l0000<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo1?l0000=ooooo`Co00002oooool2o`0003Wo
oooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?oo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo03cooooo0_l0000>ooooo`Ko00006_ooool3o`00
00cooooo1Ol0000<ooooo`Co00003Oooool01?l0003oooooooooool0000<ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00_ooooo1_l0000;ooooo`;o00003Oooool3o`0003Wooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0000=ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool02_ooool01?l0003oooooooooool0000=ooooo`Co0000
3Oooool4o`0000cooooo00?o0000ooooooooool02oooool4o`0000cooooo1Ol0000=ooooo`Co0000
3?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo1?l0000;ooooo`;o0000
3Oooool4o`0000kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Iooooo`000ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P05ooooo`;o
00003_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo0ol0000>ooooo`Go
00002oooool2o`0001cooooo1Ol0000<ooooo`Co00004?ooool00ol0003oooooooooo`1Iooooo`;o
00003Oooool3o`0000cooooo1Ol0000=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool06_ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`00
0?o<c<`01?ooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ool000003Oooool4o`0000gooooo1?l0000<ooooo`03o`000?oooooooooo01_ooooo1Ol0000>oooo
o`?o0000Joooool2o`0000cooooo1?l0000<ooooo`Go00003Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo01_ooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@
413o^[Zjoooooonj^[[o410@00?ooooo00Co0000oooooooooooo00003?ooool00ol0003ooooooooo
o`0<ooooo`;o00003_ooool5o`0000cooooo0_l0000/ooooo`Co00004?ooool00ol0003ooooooooo
o`1Xooooo`Co00002oooool5o`0000gooooo1?l0000<ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool07?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj
^[[ooooookZj^_l000000_ooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooool0
00003_ooool3o`0000gooooo1?l0000=ooooo`03o`000?oooooooooo02gooooo0ol0001[ooooo`;o
00003Oooool4o`0000_ooooo1Ol0000=ooooo`03o`000?oooooo000000;o00002oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo01gooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01onYZJWo410@o`000?l@413oZJVYooooool000001?ooool00ol0003oooooooooo`07
ooooo`;o00003_ooool5o`0000cooooo0_l00010ooooo`03o`000?oooooooooo06Sooooo1?l0000;
ooooo`Ko00003?ooool4o`0000cooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool07_ooool001Kooooo00?o0000ooooool000001Oooool0
0ol0003oooooooooo`06ooooo`?o00003_ooool3o`0000gooooo00?o0000ooooooooool0Voooool2
o`0000gooooo1?l0000;ooooo`Ko00003?ooool00ol0003oooooo`000002o`0000_ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01oooooo000Foooo
o`;o00001_ooool00ol0003oooooooooo`05ooooo`Go00003?ooool2o`000:_ooooo1?l0000;oooo
o`Ko00003?ooool4o`0000cooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Pooooo`005Oooool3o`00
00Kooooo00?o0000ooooooooool01Oooool3o`0000gooooo00?o0000ooooooooool0Voooool2o`00
00gooooo1?l0000;ooooo`Ko00003Oooool4o`0000_ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000008oooool001Co
oooo1Ol00005ooooo`03o`000?oooooooooo00Cooooo0_l0002/ooooo`?o00002oooool6o`0000co
oooo1?l0000=ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo0_l0000Tooooo`005?ooool3o`0000Oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2Kooooo`;o00003Oooool4o`0000_o
oooo1_l0000=ooooo`Co00003?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool02oooool00ol0003oooooo`00000>ooooo`?o00009?ooool001?ooooo
0_l00009ooooo`03o`000?oooooooooo0:3ooooo0ol0000<ooooo`Go00003?ooool4o`0000gooooo
00Co0000oooooooooooo00003?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03?ooool2o`0000kooooo1Ol0000Sooooo`004_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo05kooooo0_l0000_ooooo`;o00003Oooool4o`0000cooooo
1Ol0000=ooooo`Co00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool00ol0003oooooo`00000>ooooo`?o00003_ooool3o`0002Gooooo
000Nooooo`03o`000?oooooooooo05kooooo0ol0000]ooooo`?o00003?ooool5o`0000cooooo1?l0
000=ooooo`04o`000?ooooooooooo`0000cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo0_l0000>ooooo`Go00003?ooool2o`0002Oooooo
000Nooooo`03o`000?oooooooooo04cooooo0_l0000?ooooo`Go00006oooool2o`0000gooooo1?l0
000<ooooo`Go00003Oooool4o`0000cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool4o`0000gooooo0ol0
000<ooooo`;o0000:Oooool001kooooo00?o0000ooooooooool0C?ooool3o`0000gooooo1?l0000L
ooooo`?o00003?ooool5o`0000cooooo1?l0000=ooooo`04o`000?ooooooooooo`0000cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool6o`0000_ooooo0_l0000=ooooo`?o0000:Oooool001kooooo0_l0000>
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:
ooooo`;o000000?oooooo`000?ooool03?ooool5o`0000cooooo0_l0000>ooooo`03o`000?oooooo
oooo00_ooooo1?l0000<ooooo`Go00003Oooool4o`0000cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0=ooooo`Co00002oooool2o`0000gooooo1?l0000>ooooo`03o`000?oooooo
oooo01Wooooo000Mooooo`;o00003_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool02oooool3o`0000gooooo1?l0000=ooooo`;o00007?ooool5o`00
00cooooo1?l0000@ooooo`03o`000?oooooooooo05Wooooo0_l0000=ooooo`?o00003?ooool4o`00
00kooooo00?o0000ooooooooool06_ooool001cooooo00?o0000ooooool000003Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo0000ooooo`0<ooooo`Go
00003?ooool2o`0000kooooo00?o0000ooooooooool06oooool5o`0000kooooo0ol0001Zooooo`;o
00003Oooool4o`0000cooooo1Ol0000=ooooo`03o`000?oooooooooo01_ooooo000Kooooo`04o`00
0?ooooooooooo`0000cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`?o
00003_ooool3o`0000gooooo0_l0000]ooooo`Co00004?ooool00ol0003oooooooooo`1Xooooo`?o
00003?ooool5o`0000gooooo0ol0000=ooooo`03o`000?oooooooooo01cooooo000Jooooo`05o`00
0?ooooooooooooooool000002oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000000go
oooo1Ol0000<ooooo`?o00003Oooool00ol0003oooooooooo`0^ooooo`?o0000Joooool2o`0000co
oooo1?l0000<ooooo`Go00003Oooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo01go
oooo000Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0<ooooo`;o00003_ooool3o`0000kooooo00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`1Xooooo`Co00002oooool5o`0000gooooo1?l0000<ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool07_ooool001Sooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooo000000kooooo1?l0000<ooooo`?o00003_ooool00ol0003ooooooooo
o`2Kooooo`;o00003Oooool4o`0000_ooooo1Ol0000=ooooo`04o`000?ooooooooooo`0000cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Oooooo`005oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo0_l0000>ooooo`?o00003_ooool00ol0003ooooooooo
o`2Zooooo`Co00002oooool5o`0000gooooo1?l0000<ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Pooooo`005?ooool00ol0003oooooo`000007
ooooo`03o`000?oooooooooo00Cooooo1?l0000=ooooo`;o00003_ooool00ol0003oooooooooo`2K
ooooo`;o00003Oooool4o`0000_ooooo1_l0000<ooooo`04o`000?ooooooooooo`0000cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo027ooooo000D
ooooo`;o00002?ooool00ol0003oooooooooo`03ooooo`?o00003_ooool00ol0003oooooooooo`2Z
ooooo`Co00002oooool5o`0000kooooo0ol0000<ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02;ooooo000Coooo
o`Co00001oooool00ol0003oooooooooo`03ooooo`;o00003_ooool00ol0003oooooooooo`2Koooo
o`;o00003Oooool4o`0000_ooooo1_l0000=ooooo`03o`000?oooooo000000cooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ool000009Oooool001;ooooo0ol00009ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0Zoooool3o`0000_ooooo1Ol0000>ooooo`?o00003Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`;o
00009_ooool001;ooooo0_l0000:ooooo`05o`000?ooooooooooooooool00000K?ooool2o`0002oo
oooo0_l0000=ooooo`Co00002oooool6o`0000gooooo00?o0000ooooool000003Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool00ol0003o
ooooo`00000>ooooo`Co00009Oooool0017ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`1^ooooo`?o0000;Oooool3o`0000cooooo1?l0000>ooooo`?o00003Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`;o00003_ooool3o`0002Oooooo000@ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0G?ooool2o`0000oooooo1Ol0000Kooooo`;o00003Oooool4o`0000cooooo1Ol0
000=ooooo`03o`000?oooooo000000gooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool4o`0000gooooo0_l0
000=ooooo`;o00006Oooool001kooooo00?o0000ooooooooool0G?ooool3o`0000gooooo1?l0000L
ooooo`?o00003?ooool4o`0000kooooo0ol0000=ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03?ooool3o`0000kooooo00?o0000ooooooooool03?ooool3o`0001Wooooo000Noooo
o`;o00003_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0:ooooo`?o00003_ooool5o`0000cooooo0_l0000>oooo
o`03o`000?oooooooooo00_ooooo1?l0000<ooooo`Go00003Oooool00ol0003oooooo`00000=oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool2o`0000gooooo0_l0000=oooo
o`Co00006_ooool001gooooo0_l0000>ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo0ol0000=ooooo`Co
00003Oooool2o`0001cooooo1?l0000>ooooo`?o0000K?ooool00ol0003oooooooooo`0<ooooo`?o
00003?ooool4o`0001_ooooo000Looooo`03o`000?oooooo000000gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo0000
ooooo`0<ooooo`Go00003?ooool2o`0000kooooo00?o0000ooooooooool06oooool5o`0000oooooo
00?o0000ooooooooool0JOooool2o`0000gooooo1?l0000<ooooo`Go00006oooool001_ooooo00Co
0000oooooooooooo00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool02oooool3o`0000gooooo1?l0000=ooooo`;o0000;_ooool3o`0007_ooooo
0ol0000<ooooo`Co00003_ooool3o`0001cooooo000Jooooo`05o`000?ooooooooooooooool00000
2oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo0000
ooooo`0<ooooo`Go00003?ooool2o`0000kooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`1Yooooo`;o00003Oooool4o`0000cooooo1Ol0000=ooooo`03o`000?oooooo000001gooooo
000Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00_ooooo0ol0000>ooooo`?o00003Oooool2o`000:cooooo0ol0
000<ooooo`Go00003Oooool3o`0000gooooo00?o0000ooooooooool07_ooool001Sooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooool000003Oooool5o`0000cooooo0ol0000=ooooo`;o0000WOooool2o`0000cooooo1?l0000<
ooooo`Go00003Oooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo01oooooo000Goooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0<oooo
o`;o00003_ooool3o`0000kooooo00?o0000ooooooooool0Z_ooool4o`0000_ooooo1Ol0000=oooo
o`Co00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo023ooooo000Fooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooo`00000>ooooo`Co
00003?ooool3o`0000kooooo00?o0000ooooooooool0Voooool2o`0000gooooo1?l0000;ooooo`Go
00003Oooool01?l0003oooooooooool0000<ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool08Oooool001Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`;o
00003_ooool3o`0000kooooo00?o0000ooooooooool0Z_ooool4o`0000_ooooo1Ol0000=ooooo`Co
00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool08_ooool001;ooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`02ooooo`Co0000
3Oooool2o`0000kooooo00?o0000ooooooooool0Voooool2o`0000gooooo1?l0000;ooooo`Ko0000
3?ooool01?l0003oooooooooool0000<ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0Sooooo`004_ooool2o`0000[ooooo00Co0000oooooooooooo
oooo0ol0000>ooooo`03o`000?oooooooooo0:[ooooo1?l0000;ooooo`Go00003_ooool3o`0000co
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool09?ooool0017ooooo1?l00009ooooo`04o`000?ooooooooooooooo`;o
00003_ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo02kooooo0_l0000=ooooo`Co
00002oooool6o`0000gooooo00?o0000ooooool000003?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool00ol0003oooooo`00000Wooooo`00
4?ooool3o`0000_ooooo00Co0000oooooooooooo0000OOooool2o`0002kooooo0ol0000;ooooo`Go
00003_ooool3o`0000gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool2o`0002Sooooo000@ooooo`;o0000
3?ooool00ol0003oooooo`00001/ooooo`;o00003oooool4o`0001cooooo0_l0000=ooooo`Co0000
2oooool6o`0000gooooo00?o0000ooooool000003Oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`Co0000
9oooool000oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1/ooooo`?o00003Ooo
ool3o`0001gooooo0ol0000<ooooo`Co00003_ooool3o`0000gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0<ooooo`?o0000:Oooool000kooooo00?o0000ooooooooool03Oooool2
o`0000kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`?o00003_ooool5
o`0000cooooo0_l0000>ooooo`03o`000?oooooooooo00_ooooo1?l0000<ooooo`Go00003Oooool0
0ol0003oooooo`00000=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool2
o`0000kooooo00?o0000ooooooooool06Oooool001gooooo0_l0000>ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool02oooool3o`0000gooooo1?l0000=ooooo`03o`000?oooooooooo
01_ooooo1?l0000>ooooo`?o0000K?ooool00ol0003oooooooooo`0Zooooo`007?ooool00ol0003o
ooooo`00000=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo0000ooooo`0<ooooo`Go
00003?ooool2o`0000kooooo00?o0000ooooooooool06oooool5o`0000oooooo00?o0000oooooooo
ool0J_ooool00ol0003oooooooooo`0[ooooo`006oooool01?l0003oooooooooool0000<ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00_ooooo0ol0000=ooooo`Co00003Oooool2o`0002kooooo0ol0002[ooooo`00
6_ooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo0000ooooo`0<ooooo`Go
00003?ooool2o`0000kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`2Zooooo`00
6Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo0ol0000>ooooo`?o0000
3Oooool2o`000>kooooo000Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo0000oooo
o`0<ooooo`Go00003?ooool3o`0000gooooo00?o0000ooooooooool0k_ooool001Oooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool02oooool3o`0000kooooo0ol0000>ooooo`03o`000?oooooooooo0?kooooo000Foooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooo000000gooooo1Ol0000<ooooo`?o00003_ooool00ol0003oooooooooo`3ooooo
o`005Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool03?ooool2o`0000kooooo0ol0000>ooooo`03o`000?oooooooooo0?oooooo4Oooool001Cooooo
00?o0000ooooooooool01oooool01ol0003ooooooooooooooooo0000ooooool000003_ooool4o`00
00cooooo0ol0000>ooooo`03o`000?oooooooooo0?oooooo4_ooool001?ooooo00?o0000oooooooo
ool02?ooool01?l0003oooooooooooooool2o`0000kooooo0ol0000>ooooo`03o`000?oooooooooo
0?oooooo8oooool0013ooooo00?o0000ooooool000002oooool00ol0003oooooooooo`04o`0000go
oooo0_l0000>ooooo`03o`000?oooooooooo0?oooooo9?ooool0013ooooo0_l00002ooooo`Co0000
00?o410@ooooooooool00oooool00ol0003oooooo`000002o`0000kooooo00?o0000ooooooooool0
ooooooleooooo`003oooool4o`0000?ooooo00?o0000ooooooooool01Oooool01?l0003oooooo`00
0?l0000>ooooo`03o`000?oooooooooo0?oooooo=_ooool000kooooo0ol00005ooooo`03o`000?oo
oooooooo00Gooooo0_l0003oooooodWooooo000>ooooo`;o00001_ooool00ol0003oooooooooo`05
ooooo`?o0000oooooom8ooooo`003Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0oooooom8ooooo`003?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom8ooooo`005_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0?ooooooB?ooool001Cooooo00?oEEEEofIVI_l000001ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo003oooooofWooooo003oooooofWo
oooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0959237, -0.0895275, \
0.00393125, 0.00393125}}]
}, Open  ]],

Cell["\<\
One can see that particles will be attracted to the mass \
distribution along the diagonal unless they are close to the edge of the box, \
so that they are attracted to the mass distribution in one of the other \
surrounding boxes. \
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Interpolation of the Force from the Grid to Particle \
Positions\
\>", "Section",
  CellTags->{"i:63", "c:34"}],

Cell[TextData[{
  "Now that we know the force on the grid, we must interpolate the force back \
to the particle positions. One can easily do this by first creating \
interpolating functions for ",
  Cell[BoxData[
      \(TraditionalForm\`F\_x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`F\_y\)]],
  ", and then evaluating these functions at each particle  position. This is \
set up in the module below:"
}], "Text"],

Cell[BoxData[
    \(Fpart[r_, Fx_, Fy_]\  := 
      Module[{}, \[IndentingNewLine]fxi\  = \ 
          Interpolation[Flatten[Fx, 1], 
            InterpolationOrder \[Rule] 1]; \[IndentingNewLine]fyi\  = \ 
          Interpolation[Flatten[Fy, 1], 
            InterpolationOrder \[Rule] 1]; \[IndentingNewLine]F\  = \ 
          Table[{fxi[r[\([m, 1]\)], r[\([m, 2]\)]], 
              fyi[r[\([m, 1]\)], r[\([m, 2]\)]]}, {m, 1, 
              Length[r]}]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.74"],

Cell["\<\
We reduce the order of the interpolation to 1 (linear \
interpolation) from the default of 3 (cubic interpolation) in order to speed \
up the process. Also, we will find that linear interpolation is actually more \
accurate, because the total system momentum is exactly conserved in the \
simulation when linear interpolation is used.\
\>", "Text"],

Cell["\<\
\t To test this module, we evaluate the force on the particles that \
are evenly distributed along the box diagonal:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Fpart[r, Fx, Fy];\)\), "\n", 
    \(F\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.75"],

Cell[BoxData[
    \({{2.969107051673673`*^-16, 8.229602123953836`*^-15}, {0.`, 
        0.`}, {8.881784197001252`*^-15, 
        8.881784197001252`*^-15}, {\(-8.881784197001252`*^-15\), \
\(-8.881784197001252`*^-15\)}, {3.902877655076609`*^-15, 
        4.623635174044601`*^-15}, {0.`, 0.`}, {0.`, 
        0.`}, {1.1135241121310874`*^-14, 
        1.0181040951492131`*^-14}, {\(-8.881784197001252`*^-15\), \
\(-8.881784197001252`*^-15\)}, {0.`, 
        0.`}, {\(-3.0756135938911294`*^-15\), \(-1.1876428206694692`*^-15\)}, \
{0.`, 0.`}, {1.4415150379361347`*^-15, 
        8.506083262705283`*^-15}, {\(-8.881784197001252`*^-15\), \
\(-8.881784197001252`*^-15\)}, {0.`, 0.`}, {0.`, 0.`}, {0.`, 
        0.`}, {1.4415150379361347`*^-15, 
        8.506083262705283`*^-15}, {\(-8.881784197001252`*^-15\), \
\(-8.881784197001252`*^-15\)}, {0.`, 0.`}}\)], "Output"]
}, Open  ]],

Cell["\<\
The forces on the particles vanish because of their even \
distribution.  \
\>", "Text"],

Cell["\<\
\tFor those who might wish to apply the PIC method on a mainframe \
computer, the above module is reproduced below without making use of \
interpolating functions. Rather, the linear interpolation is carried out \
directly. One can see from this module that linear interpolation back to the \
particles is just another form of area weighting:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(Fpart1[r_, Fx_, Fy_]\), " ", ":=", " ", 
        RowBox[{"Module", "[", 
          
          RowBox[{\({x, y, Npart, 
              area1, \[Delta]x, \[Delta]y, \[Delta]x1, \[Delta]y1, a1, a2, 
              a3, a4, i, i1, j, j1, fx, fy}\), ",", "\[IndentingNewLine]", 
            
            RowBox[{\(Npart\  = \ Length[r]\), ";", 
              "\[IndentingNewLine]", \(\[CapitalDelta]A = \[CapitalDelta]x*\
\[CapitalDelta]y\), ";", "\[IndentingNewLine]", 
              StyleBox[\( (*\ x\ and\ y\ positions\ of\ particle\ *) \),
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(x = 
                Table[r[\([n, 1]\)], {n, 1, Npart}]\), ";", 
              "\[IndentingNewLine]", \(y = 
                Table[r[\([n, 2]\)], {n, 1, Npart}]\), ";", 
              "\[IndentingNewLine]", 
              
              StyleBox[\( (*\ 
                  list\ of\ lengths\ of\ the\ rectangle\ sides\ for\ each\ \
particle\ *) \),
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(\[Delta]x = Mod[x, \[CapitalDelta]x]\),
               ";", "\[IndentingNewLine]", \(\[Delta]y = 
                Mod[y, \[CapitalDelta]y]\), ";", 
              "\[IndentingNewLine]", \(\[Delta]x1\  = \ \[CapitalDelta]x - \
\[Delta]x\), ";", 
              "\[IndentingNewLine]", \(\[Delta]y1\  = \ \[CapitalDelta]y - \
\[Delta]y\), ";", "\[IndentingNewLine]", 
              StyleBox[\( (*\ list\ of\ rectangle\ areas\ \ *) \),
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(a1\  = \ 
                Table[\[Delta]x1[\([n]\)]\ \[Delta]y1[\([n]\)], {n, 1, 
                    Npart}]\), ";", 
              "\[IndentingNewLine]", \(a2\  = \ 
                Table[\[Delta]x1[\([n]\)] \[Delta]y[\([n]\)], {n, 1, 
                    Npart}]\), ";", 
              "\[IndentingNewLine]", \(a3\  = \ 
                Table[\[Delta]x[\([n]\)] \[Delta]y[\([n]\)], {n, 1, Npart}]\),
               ";", "\[IndentingNewLine]", \(a4\  = \ 
                Table[\[Delta]x[\([n]\)] \[Delta]y1[\([n]\)], {n, 1, 
                    Npart}]\), ";", "\[IndentingNewLine]", 
              
              StyleBox[\( (*\ 
                  list\ of\ surrounding\ grid\ points\ for\ all\ particles\ \ \
*) \),
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(i\  = 
                Quotient[x, \[CapitalDelta]x] + 1\), ";", 
              "\[IndentingNewLine]", \(j\  = \ 
                Quotient[y, \[CapitalDelta]y] + 1\), ";", 
              "\[IndentingNewLine]", \(i1\  = \ 1 + Mod[i, Mx]\), ";", 
              "\[IndentingNewLine]", \(j1\  = \ 1 + Mod[j, My]\), ";", 
              "\[IndentingNewLine]", 
              
              StyleBox[\( (*\ 
                  linear\ interpolation\ by\ area\ weighting\ *) \),
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(fx\  = 
                Table[Fx[\([i[\([n]\)], j[\([n]\)]]\)]*
                      a1[\([n]\)]\  + \[IndentingNewLine]\ 
                    Fx[\([i[\([n]\)], j1[\([n]\)]]\)]*a2[\([n]\)]\  + \ 
                    Fx[\([i1[\([n]\)], j1[\([n]\)]]\)]*a3[\([n]\)]\  + \ 
                    Fx[\([i1[\([n]\)], j[\([n]\)]]\)]*a4[\([n]\)], {n, 1, 
                    Npart}]\), ";", 
              "\[IndentingNewLine]", \(fy\  = 
                Table[\ Fy[\([i[\([n]\)], j[\([n]\)]]\)]*
                      a1[\([n]\)]\  + \[IndentingNewLine]Fy[\([i[\([n]\)], 
                          j1[\([n]\)]]\)]*a2[\([n]\)]\  + \ 
                    Fy[\([i1[\([n]\)], j1[\([n]\)]]\)]*a3[\([n]\)]\  + \ 
                    Fy[\([i1[\([n]\)], j[\([n]\)]]\)]*a4[\([n]\)], {n, 1, 
                    Npart}]\), ";", "\[IndentingNewLine]", 
              
              StyleBox[\( (*\ table\ of\ forces\ for\ each\ particle, \ 
                  paroperly\ normalized\ *) \),
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(F = 
                Table[{fx[\([m]\)], fy[\([m]\)]}, {m, 1, 
                      Npart}]/\[CapitalDelta]A\), ";"}]}], "]"}]}], 
      ";"}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.76"],

Cell[TextData[{
  "We must now put these modules together to create the force function ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["f",
            FontWeight->"Bold",
            FontSlant->"Plain"], "(", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " used in the leapfrog routine:"
}], "Text"],

Cell[BoxData[
    RowBox[{\(f[r_]\), " ", ":=", " ", 
      RowBox[{"Module", "[", 
        RowBox[{\({}\), ",", "\[IndentingNewLine]", 
          StyleBox[\( (*determine\ the\ density\ *) \),
            FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
          RowBox[{\(density[r]\), ";", "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ 
                determine\ the\ force\ on\ the\ grid\ and\ the\ potential\ \
matrix\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(fft\[Phi][\[Rho]]\), ";", 
            "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ 
                determine\ the\ force\ at\ the\ particle\ positions\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(Fpart[r, Fx, Fy]\)}]}], " ", 
        "]"}]}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.77"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["7.3.5 Examples", "Subsubtitle",
  CellTags->"c:35"],

Cell[CellGroupData[{

Cell["Code Tests ", "Section",
  CellTags->"c:36"],

Cell[TextData[{
  "It is always very important to test the validity of simulation results  \
One type of test involves running example problems where one already knows \
the answer. These sort of tests are used in the early stages of code \
development, to find errors in the program. For instance, we can take two \
particles a distance ",
  Cell[BoxData[
      \(TraditionalForm\`2  R\)]],
  " apart and orbit the particles around one another. Theoretically, they \
should follow a circular orbit of radius ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " if they are given a velocity  ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " such that the centrifugal force balances the gravitational attraction. \
Since we are solving for the gravitational force in two dimensions only, the \
force of gravitational attraction between particles a distance ",
  Cell[BoxData[
      \(TraditionalForm\`2  R\)]],
  " apart is ",
  Cell[BoxData[
      \(TraditionalForm\`F = G\ m\^2/\ R\)]],
  ". Thus, for circular motion, ",
  Cell[BoxData[
      \(TraditionalForm\`m\ v\^2/R = G\ m\^2/R\)]],
  ", which implies"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(v\^2 = G\ m\)\)\)]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "In Cell ",
  ButtonBox["7.78",
    ButtonData:>"Cell 7.78",
    ButtonStyle->"Hyperlink"],
  ", we test this result by running the code for several rotation periods. \
Also, we time the code using a function called ",
  StyleBox["Timing",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", available in the add-on package ",
  StyleBox["Utilities",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(<< Utilities`;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(m = 1; M = 40; 
    L = 1; \[CapitalDelta]x\  = \ \(\[CapitalDelta]y\  = \ 
        L/M\); \[CapitalDelta]t = 0.04;\[IndentingNewLine]\), "\n", 
    \(\(Clear[r, p];\)\), "\n", 
    \(\(R\  = \ 0.1;\)\), "\n", 
    \(\(r0\  = \ {{0.5, \ 0.5 - R}, {0.5, 0.5\  + \ R}};\)\), "\n", 
    \(\(v\  = \ Sqrt[\ G\ m];\)\), "\n", 
    \(\(\(p0\  = \ {{m\ v, 0}, {\(-m\)\ v, 0}};\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(Timing[leapfrog[r0, p0, 30, \[CapitalDelta]t]]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.78"],

Cell[BoxData[
    \({15.08`\ Second, Null}\)], "Output"]
}, Open  ]],

Cell["\<\
The code takes quite a while to run, but most of the time is spent \
on the FFT.  Fortunately, the time for the FFT is not affected by an increase \
in the number of particles, so running the code with a thousand particles \
doesn't take much longer than running it with two particles. \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Table[
        ListPlot[r[n], PlotRange \[Rule] {{0, 1}, {0, 1}}, 
          AspectRatio \[Rule] 1], {n, 0, 30, 1}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.79"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.5 .4 Mdot
.5 .6 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0002Qooooo`;o
0000Z?ooool000?ooooo00?o0000ooooooooool02Oooool01?m4A4CogMgMooooool00007ooooo`03
o`000?oooooooooo0:7ooooo0_l0002Xooooo`000oooool00ol0003oooooooooo`09ooooo`04omgM
gOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413ooooo
ooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
V9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0?oooooo
C?ooool00004oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o
0000oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Ooo
ool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0oooooom<ooooo`000oooool00ol0003oooooooooo`09ooooo`05o`000?nH
V9SooooooiRHV?lQ8B401_ooool3o`000:7ooooo0_l0002Xooooo`000oooool00ol0003ooooooooo
o`09ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2Qooooo`;o0000
Z?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.53933 .40684 Mdot
.46067 .59316 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0003oooooodco
oooo0003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`3oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`2^ooooo`;o0000Voooool000?ooooo00?o410@ooooooooool0
2_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo0:kooooo0_l0002Kooooo`0000Co
V9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0?oooooo
C?ooool00004oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o
0000oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0U?ooool2o`000;Gooooo00001?nHV9SooooooiRHV?mg
MgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0
U?ooool2o`000;Gooooo0003ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003oooooodcooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.57323 .42634 Mdot
.42677 .57366 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0003oooooodco
oooo0003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`3oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00[ooooo
00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRH
V?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0;Wooooo0_l0002@ooooo`006_ooool00ol0003o
ooooooooo`2iooooo`;o0000T?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o
0000oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo08Wooooo0_l00030ooooo`006_ooool00ol0003oooooooooo`29oooo
o`;o0000`?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooC?ooool00004oiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003oooooodcooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.59777 .45527 Mdot
.40223 .54473 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0003oooooodco
oooo0003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`3oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00[ooooo
00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRH
V?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`31ooooo`;o0000R?ooool001[o
oooo00?o0000ooooooooool0`Oooool2o`0008Sooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0P?ooool2o`000<Wooooo000Jooooo`03o`000?oooooooooo083ooooo0_l00039oooo
o`006_ooool2o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooC?ooool00004oiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003oooooodcooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.6108 .48955 Mdot
.3892 .51045 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0003oooooodco
oooo0003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`3oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00[ooooo
00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRH
V?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0aOooool2o`0008Cooooo000Jooooo`03o`00
0?oooooooooo0<Gooooo0_l00024ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`1looooo`;o0000cOooool001[ooooo00?o0000ooooooooool0O?ooool2
o`000<gooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool2o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooC?ooool00004oiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003oooooodcooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.61177 .525 Mdot
.38823 .475 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0003oooooodco
oooo0003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`3oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00[ooooo
00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRH
V?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`1looooo`;o
0000cOooool001[ooooo00?o0000ooooooooool0O?ooool2o`000<gooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0aOoo
ool2o`0008Cooooo000Jooooo`03o`000?oooooooooo0<Gooooo0_l00024ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool2o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooC?ooool00004oiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003oooooodcooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.60134 .55777 Mdot
.39866 .44223 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0003oooooodco
oooo0003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`3oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00[ooooo
00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRH
V?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo07oooooo0_l0003:ooooo`00
6_ooool00ol0003oooooooooo`1oooooo`;o0000b_ooool001[ooooo0_l0003oooooodgooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o
0000oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0`_ooool2o`0008Oooooo000Joooo
o`03o`000?oooooooooo0<;ooooo0_l00027ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooC?ooool00004oiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003oooooodcooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.58105 .58485 Mdot
.41895 .41515 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0003oooooodco
oooo0003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`3oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00[ooooo
00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRH
V?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo08Kooooo
0_l00033ooooo`006_ooool00ol0003oooooooooo`26ooooo`;o0000`oooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o
0000oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0^oooool2o`0008kooooo000Jooooo`03o`000?oooooo
oooo0;_ooooo0_l0002>ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooC?ooool00004oiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003oooooodcooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.55292 .60376 Mdot
.44708 .39624 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
08oooooo0_l0002jooooo`000oooool00ol@413oooooooooo`09ooooo`Go00001_ooool3o`0008oo
oooo0_l0002jooooo`000oooool00ol0003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oo
oooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol0003oooooooooo`09ooooo`04omgM
gOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413ooooo
ooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
V9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0?oooooo
C?ooool00004oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o
0000oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Ooo
ool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0oooooom<ooooo`000oooool00ol0003oooooooooo`09ooooo`05o`000?nH
V9SooooooiRHV?lQ8B401_ooool3o`000?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0/_ooool2o`0009Oooooo
0003ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003ooooooooo
o`2booooo`;o0000Uoooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.51949 .61255 Mdot
.48051 .38745 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`2Jooooo`;o0000[oooool0
01[ooooo00?o0000ooooooooool0V_ooool2o`000:oooooo00001?lb<S;o0000oc8b<_o^k^h5oooo
o`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0oooooom<oooo
o`0000CoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006ooooo`?o
0000oooooom<ooooo`000oooool00ol0003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oo
oooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol0003oooooooooo`09ooooo`04omgM
gOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413ooooo
ooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
V9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0?oooooo
C?ooool00004oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o
0000oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Ooo
ool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0oooooom<ooooo`000oooool00ol0003oooooooooo`09ooooo`05o`000?nH
V9SooooooiRHV?lQ8B401_ooool3o`000?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000ooo
ool00ol@413oooooooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0oooo
oom<ooooo`0000CoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@
1_ooool00ol0003oooooooooo`2Wooooo`;o0000X_ooool001[ooooo00?o0000ooooooooool0Yooo
ool2o`000:;ooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.48397 .60983 Mdot
.51603 .39017 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0:Kooooo0_l0002Sooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q
8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0:Kooooo0_l0002Soooo
o`0000CoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006ooooo`?o
0000oooooom<ooooo`000oooool00ol0003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oo
oooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol0003oooooooooo`09ooooo`04omgM
gOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413ooooo
ooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
V9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0?oooooo
C?ooool00004oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o
0000oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Ooo
ool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0oooooom<ooooo`000oooool00ol0003oooooooooo`09ooooo`05o`000?nH
V9SooooooiRHV?lQ8B401_ooool3o`000?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000ooo
ool00ol@413oooooooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0oooo
oom<ooooo`0000CoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oo
oooooooo09_ooooo0_l0002^ooooo`0000Co<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`00
0?l@4106ooooo`03o`000?oooooooooo09_ooooo0_l0002^ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.45028 .59508 Mdot
.54972 .40492 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0003oooooodco
oooo0003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`2aooooo`;o0000V?ooool000?ooooo00?o0000ooooooooool02Oooool01?oMgMgoEEEE
ooooool00007ooooo`03o`000?oooooooooo0;7ooooo0_l0002Hooooo`000oooool00ol@413ooooo
ooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
V9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0?oooooo
C?ooool00004oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o
0000oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Ooo
ool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo093ooooo
0_l0002iooooo`000oooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`2@ooooo`;o0000^Oooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003oooooodcooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.42264 .56907 Mdot
.57736 .43093 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0003oooooodco
oooo0003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`3oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00[ooooo
00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRH
V?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`2jooooo`;o0000Soooool001[ooooo00?o
0000ooooooooool0^_ooool2o`0008oooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o
0000oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0Qoooool2o`000<;ooooo000Jooooo`03o`000?oooooooooo08Oooooo0_l0
0032ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooC?ooool00004oiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003oooooodcooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.40495 .53421 Mdot
.59505 .46579 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0003oooooodco
oooo0003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`3oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00[ooooo
00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRH
V?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`30ooooo`;o0000ROooool001[ooooo00?o0000ooooooooool0`?ooool2
o`0008Wooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0POooool2o`000<Sooooo000Jooooo`03o`00
0?oooooooooo087ooooo0_l00038ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool2o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooC?ooool00004oiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003oooooodcooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.40022 .49463 Mdot
.59978 .50537 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0003oooooodco
oooo0003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`3oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00[ooooo
00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRH
V?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo083ooooo0_l00039ooooo`006_ooool0
0ol0003oooooooooo`20ooooo`;o0000bOooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0<7ooooo0_l00028ooooo`006_ooool00ol0003oooooooooo`31ooooo`;o0000
R?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool2o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooC?ooool00004oiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003oooooodcooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.40943 .4558 Mdot
.59057 .5442 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0003oooooodco
oooo0003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`3oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00[ooooo
00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRH
V?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`23ooooo`;o0000a_ooool001[o
oooo00?o0000ooooooooool0Poooool2o`000<Kooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0__ooool2o`0008_ooooo000Jooooo`03o`000?oooooooooo0;kooooo0_l0002;oooo
o`006_ooool2o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooC?ooool00004oiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003oooooodcooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.43105 .42313 Mdot
.56895 .57687 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0003oooooodco
oooo0003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`3oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00[ooooo
00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRH
V?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`2:
ooooo`;o0000_oooool001[ooooo00?o0000ooooooooool0R_ooool2o`000;oooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o
0000oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0]oooool2o`00
09;ooooo000Jooooo`03o`000?oooooooooo0;Oooooo0_l0002Booooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooC?ooool00004oiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003oooooodcooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.46158 .40047 Mdot
.53842 .59953 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0002Dooooo`;o
0000]Oooool000?ooooo00?o0000ooooooooool02Oooool01?m4A4CogMgMooooool00007ooooo`03
o`000?oooooooooo09Cooooo0_l0002eooooo`000oooool00ol0003oooooooooo`09ooooo`04omgM
gOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413ooooo
ooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
V9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0?oooooo
C?ooool00004oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o
0000oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Ooo
ool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0[Oooool2o`0009cooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go
0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000[Oooool2o`0009cooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.49674 .38971 Mdot
.50326 .61029 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`2Pooooo`;o0000ZOooool0
01[ooooo00?o0000ooooooooool0X?ooool2o`000:Wooooo00001?lb<S;o0000oc8b<_o^k^h5oooo
o`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0oooooom<oooo
o`0000CoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006ooooo`?o
0000oooooom<ooooo`000oooool00ol0003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oo
oooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol0003oooooooooo`09ooooo`04omgM
gOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413ooooo
ooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
V9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0?oooooo
C?ooool00004oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o
0000oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Ooo
ool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0oooooom<ooooo`000oooool00ol0003oooooooooo`09ooooo`05o`000?nH
V9SooooooiRHV?lQ8B401_ooool3o`000?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000ooo
ool00ol@413oooooooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0oooo
oom<ooooo`0000CoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oo
oooooooo0:;ooooo0_l0002Wooooo`0000Co<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`00
0?l@4106ooooo`03o`000?oooooooooo0:;ooooo0_l0002Wooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.53228 .39126 Mdot
.46772 .60874 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0:_ooooo0_l0002Nooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q
8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0:_ooooo0_l0002Noooo
o`0000CoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006ooooo`?o
0000oooooom<ooooo`000oooool00ol0003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oo
oooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol0003oooooooooo`09ooooo`04omgM
gOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413ooooo
ooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
V9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0?oooooo
C?ooool00004oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o
0000oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Ooo
ool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0oooooom<ooooo`000oooool00ol0003oooooooooo`09ooooo`05o`000?nH
V9SooooooiRHV?lQ8B401_ooool3o`000?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000ooo
ool00ol@413oooooooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0U_oo
ool2o`000;?ooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o
0000ooooooooool0U_ooool2o`000;?ooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.56435 .40411 Mdot
.43565 .59589 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0003oooooodco
oooo0003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`2fooooo`;o0000Toooool000?ooooo00?o0000ooooooooool02Oooool01?oMgMgoEEEE
ooooool00007ooooo`03o`000?oooooooooo0;Kooooo0_l0002Cooooo`000oooool00ol@413ooooo
ooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
V9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0?oooooo
C?ooool00004oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o
0000oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Ooo
ool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo08_ooooo
0_l0002nooooo`000oooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`2;ooooo`;o0000__ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003oooooodcooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.58994 .42652 Mdot
.41006 .57348 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0003oooooodco
oooo0003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`3oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00[ooooo
00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRH
V?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0__ooool2o`0008_ooooo000Jooooo`03o`000?oooooooooo0;kooooo0_l0002;ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o
0000oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo08?ooooo0_l00036ooooo`006_ooool00ol0003oooooooooo`23oooo
o`;o0000a_ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooC?ooool00004oiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003oooooodcooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.6067 .45629 Mdot
.3933 .54371 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0003oooooodco
oooo0003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`3oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00[ooooo
00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRH
V?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`34ooooo`;o0000QOooool001[o
oooo00?o0000ooooooooool0a?ooool2o`0008Gooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0O_ooool2o`000<_ooooo000Jooooo`03o`000?oooooooooo07kooooo0_l0003;oooo
o`006_ooool2o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooC?ooool00004oiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003oooooodcooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.61281 .49055 Mdot
.38719 .50945 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0003oooooodco
oooo0003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`3oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00[ooooo
00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRH
V?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`36ooooo`;o0000Poooool001[ooooo00?o0000ooooooooool0a_ooool2o`0008?ooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`1looooo`;o0000cOooool001[ooooo00?o0000ooooooooool0O?ooool2
o`000<gooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool2o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooC?ooool00004oiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003oooooodcooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.60714 .52583 Mdot
.39286 .47417 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0003oooooodco
oooo0003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`3oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00[ooooo
00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRH
V?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`1mooooo`;o
0000c?ooool001[ooooo00?o0000ooooooooool0OOooool2o`000<cooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0a?oo
ool2o`0008Gooooo000Jooooo`03o`000?oooooooooo0<Cooooo0_l00025ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool2o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooC?ooool00004oiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003oooooodcooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.58949 .55811 Mdot
.41051 .44189 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0003oooooodco
oooo0003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`3oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00[ooooo
00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRH
V?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo08?ooooo0_l00036ooooo`00
6_ooool00ol0003oooooooooo`23ooooo`;o0000a_ooool001[ooooo0_l0003oooooodgooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o
0000oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0__ooool2o`0008_ooooo000Joooo
o`03o`000?oooooooooo0;kooooo0_l0002;ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooC?ooool00004oiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003oooooodcooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.5611 .58332 Mdot
.4389 .41668 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0003oooooodco
oooo0003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`3oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00[ooooo
00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRH
V?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo08gooooo
0_l0002looooo`006_ooool00ol0003oooooooooo`2=ooooo`;o0000_?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o
0000oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0;Gooooo
0_l0002Dooooo`006_ooool00ol0003oooooooooo`2eooooo`;o0000U?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooC?ooool00004oiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003oooooodcooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.52477 .59775 Mdot
.47523 .40225 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0003oooooodco
oooo0003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`2Hooooo`;o0000/Oooool000?ooooo00?o0000ooooooooool02Oooool01?oMgMgoEEEE
ooooool00007ooooo`03o`000?oooooooooo09Sooooo0_l0002aooooo`000oooool00ol@413ooooo
ooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
V9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0?oooooo
C?ooool00004oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o
0000oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Ooo
ool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0ZOooool2o`000:3ooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go
0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000ZOooool2o`000:3ooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.48493 .59873 Mdot
.51507 .40127 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0002Vooooo`;o
0000Xoooool000?ooooo00?o0000ooooooooool02Oooool01?m4A4CogMgMooooool00007ooooo`03
o`000?oooooooooo0:Kooooo0_l0002Sooooo`000oooool00ol0003oooooooooo`09ooooo`04omgM
gOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413ooooo
ooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
V9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0?oooooo
C?ooool00004oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o
0000oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Ooo
ool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0W?ooool2o`000:gooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go
0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000W?ooool2o`000:gooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.44722 .58592 Mdot
.55278 .41408 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0003oooooodco
oooo0003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`3oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00[ooooo
00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRH
V?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0/_ooool2o`0009Oooooo
00001?lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0
/_ooool2o`0009Oooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o
0000oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0Soooool2o`000;[ooooo000Jooooo`03o`000?oooooo
oooo08oooooo0_l0002jooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooC?ooool00004oiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003oooooodcooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.41687 .56138 Mdot
.58313 .43862 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=_ooool4o`00007o410@0Oooool1ooooo`00DOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03Sooooo00?o0000ooooooooool00_ooool0057ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^02kooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000;?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000
ooooooooool00_ooool0057ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^02gooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0hooooo`03o`000?oo
oooooooo00;ooooo001Aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`0/ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000]ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02gooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0>?ooool00ol0003ooooo
ooooo`02ooooo`00DOooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
:oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0;oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooooooo00;ooooo001A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`00DOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00]ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0/ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool001[oooooool0001;o`0000Cooooo000Jooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodcooooo0003ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo
0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2
o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo0ol0003oooooodco
oooo0003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`3oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00[ooooo
00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRH
V?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom<ooooo`0000Co
<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`2looooo`;o0000SOooool001[ooooo00?o0000ooooooooool0_?ooool2o`0008go
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o
0000oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`25ooooo`;o0000a?ooool001[ooooo00?o0000ooooooooool0QOooool2o`000<Co
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooC?ooool00004oiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003oooooodcooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
C?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000
oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?oo
ool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOoo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo0_l0003oooooodgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool0013ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodco
oooo000Booooo`03o`000?oooooooooo00Gooooo0ol0003oooooodcooooo000Booooo`03o`000?oo
oooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0
003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo
00?oEEEEofIVI_l00000oooooomFooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0809693, -0.0610006, \
0.00380357, 0.00380357}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "\tCell ",
  ButtonBox["7.79",
    ButtonData:>"Cell 7.79",
    ButtonStyle->"Hyperlink"],
  " shows that the two particles orbit in  nearly circular motion, as \
expected.  The orbit is not perfectly circular, because  of the influence of \
the periodic boundary conditions: these particles are also attracted to their \
images in the surrounding boxes, causing a slight distortion of the orbit.  "
}], "Text"],

Cell[TextData[{
  "\tIt can also be  useful to test whether constants of the motion are being \
properly evaluated. However, we will see that in the PIC method these \
constants do not always provide us with a good measure of solution accuracy. \
For example, the total momentum should not vary: ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox["P",
              FontWeight->"Bold",
              FontSlant->"Plain"], "tot"], "=", " ", 
          RowBox[{\(\[Sum]\+i\), 
            StyleBox[
              SubscriptBox["p", 
                StyleBox["i",
                  FontWeight->"Plain",
                  FontSlant->"Italic"]],
              FontWeight->"Bold",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  ". This is checked in Cell ",
  ButtonBox["7.80",
    ButtonData:>"Cell 7.80",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Ptot[n_]\  := \ 
        Sum[\(p[n]\)[\([m]\)], {m, 1, Length[p[n]]}];\)\), "\n", 
    \(\(ListPlot[Table[Ptot[n], {n, 1/2, 30, 1}], 
        PlotLabel \[Rule] \ "\<momentum\n\>", \ 
        AxesLabel \[Rule] {"\<Px\>", "\<Py\>"}, 
        PlotRange \[Rule] All];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.80"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.699927 6.54831e+13 0.603319 2.57363e+13 [
[.0451 .59082 -21.75 -12.5 ]
[.0451 .59082 21.75 0 ]
[.17606 .59082 -21.75 -12.5 ]
[.17606 .59082 21.75 0 ]
[.30703 .59082 -21.75 -12.5 ]
[.30703 .59082 21.75 0 ]
[.43799 .59082 -21.75 -12.5 ]
[.43799 .59082 21.75 0 ]
[.56896 .59082 -21.75 -12.5 ]
[.56896 .59082 21.75 0 ]
[.83089 .59082 -18.75 -12.5 ]
[.83089 .59082 18.75 0 ]
[.96186 .59082 -18.75 -12.5 ]
[.96186 .59082 18.75 0 ]
[1.025 .60332 0 -6 ]
[1.025 .60332 16 6 ]
[.68743 .08859 -43.5 -6.25 ]
[.68743 .08859 0 6.25 ]
[.68743 .21727 -55.5 -6.25 ]
[.68743 .21727 0 6.25 ]
[.68743 .34596 -43.5 -6.25 ]
[.68743 .34596 0 6.25 ]
[.68743 .47464 -43.5 -6.25 ]
[.68743 .47464 0 6.25 ]
[.69993 .64303 -8 0 ]
[.69993 .64303 8 12 ]
[.5 .63053 -26.0625 0 ]
[.5 .63053 26.0625 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.0451 .60332 m
.0451 .60957 L
s
gsave
.0451 .59082 -21.75 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-14) show
grestore
.17606 .60332 m
.17606 .60957 L
s
gsave
.17606 .59082 -21.75 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-8) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-15) show
grestore
.30703 .60332 m
.30703 .60957 L
s
gsave
.30703 .59082 -21.75 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-6) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-15) show
grestore
.43799 .60332 m
.43799 .60957 L
s
gsave
.43799 .59082 -21.75 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-15) show
grestore
.56896 .60332 m
.56896 .60957 L
s
gsave
.56896 .59082 -21.75 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-15) show
grestore
.83089 .60332 m
.83089 .60957 L
s
gsave
.83089 .59082 -18.75 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-15) show
grestore
.96186 .60332 m
.96186 .60957 L
s
gsave
.96186 .59082 -18.75 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-15) show
grestore
.125 Mabswid
.07784 .60332 m
.07784 .60707 L
s
.11058 .60332 m
.11058 .60707 L
s
.14332 .60332 m
.14332 .60707 L
s
.2088 .60332 m
.2088 .60707 L
s
.24155 .60332 m
.24155 .60707 L
s
.27429 .60332 m
.27429 .60707 L
s
.33977 .60332 m
.33977 .60707 L
s
.37251 .60332 m
.37251 .60707 L
s
.40525 .60332 m
.40525 .60707 L
s
.47074 .60332 m
.47074 .60707 L
s
.50348 .60332 m
.50348 .60707 L
s
.53622 .60332 m
.53622 .60707 L
s
.6017 .60332 m
.6017 .60707 L
s
.63444 .60332 m
.63444 .60707 L
s
.66719 .60332 m
.66719 .60707 L
s
.73267 .60332 m
.73267 .60707 L
s
.76541 .60332 m
.76541 .60707 L
s
.79815 .60332 m
.79815 .60707 L
s
.86364 .60332 m
.86364 .60707 L
s
.89638 .60332 m
.89638 .60707 L
s
.92912 .60332 m
.92912 .60707 L
s
.01235 .60332 m
.01235 .60707 L
s
.9946 .60332 m
.9946 .60707 L
s
.25 Mabswid
0 .60332 m
1 .60332 L
s
gsave
1.025 .60332 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Px) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.69993 .08859 m
.70618 .08859 L
s
gsave
.68743 .08859 -43.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-14) show
grestore
.69993 .21727 m
.70618 .21727 L
s
gsave
.68743 .21727 -55.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-14) show
grestore
.69993 .34596 m
.70618 .34596 L
s
gsave
.68743 .34596 -43.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-14) show
grestore
.69993 .47464 m
.70618 .47464 L
s
gsave
.68743 .47464 -43.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-15) show
grestore
.125 Mabswid
.69993 .11433 m
.70368 .11433 L
s
.69993 .14007 m
.70368 .14007 L
s
.69993 .1658 m
.70368 .1658 L
s
.69993 .19154 m
.70368 .19154 L
s
.69993 .24301 m
.70368 .24301 L
s
.69993 .26875 m
.70368 .26875 L
s
.69993 .29448 m
.70368 .29448 L
s
.69993 .32022 m
.70368 .32022 L
s
.69993 .37169 m
.70368 .37169 L
s
.69993 .39743 m
.70368 .39743 L
s
.69993 .42317 m
.70368 .42317 L
s
.69993 .4489 m
.70368 .4489 L
s
.69993 .50037 m
.70368 .50037 L
s
.69993 .52611 m
.70368 .52611 L
s
.69993 .55185 m
.70368 .55185 L
s
.69993 .57758 m
.70368 .57758 L
s
.69993 .06286 m
.70368 .06286 L
s
.69993 .03712 m
.70368 .03712 L
s
.69993 .01138 m
.70368 .01138 L
s
.25 Mabswid
.69993 0 m
.69993 .61803 L
s
gsave
.69993 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Py) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87.0625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(momentum) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.008 w
.75809 .60332 Mdot
.74355 .59618 Mdot
.02381 .25473 Mdot
.10015 .28044 Mdot
.22374 .31759 Mdot
.42003 .20615 Mdot
.51091 .16329 Mdot
.40185 .12615 Mdot
.50364 .20901 Mdot
.65631 .23901 Mdot
.78717 .28759 Mdot
.97619 .32616 Mdot
.7799 .10329 Mdot
.84896 .05186 Mdot
.93984 .16901 Mdot
.95438 .21187 Mdot
.40912 .11758 Mdot
.4382 .18187 Mdot
.56907 .24187 Mdot
.46728 .28759 Mdot
.05289 .33473 Mdot
.1365 .09758 Mdot
.32188 .10901 Mdot
.46728 .17472 Mdot
.63086 .10615 Mdot
.57634 .06615 Mdot
.38731 .01472 Mdot
.55453 .09901 Mdot
.72174 .14472 Mdot
.78717 .10615 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{403.75, 249.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0001=b000`400?l00000o`00003ooooooom9
ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool00?oo
ooooBOooool00ol0003oooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo
003oooooodWooooo00?o0000ooooooooool0[Oooool00;cooooo0ol00029ooooo`?o0000[Oooool0
0;cooooo0ol00029ooooo`03o`000?oooooooooo0:gooooo002looooo`?o0000ROooool00ol0003o
ooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o
0000ooooooooool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooooom9oooo
o`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool00?oooooo
BOooool00ol0003oooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003o
ooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool3o`000:gooooo003oooooodWo
oooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooo
oom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool0
0?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooooooo03ko
oooo0ol0001/ooooo`00oooooom9ooooo`03o`000?oooooooooo03kooooo0ol0001/ooooo`00oooo
oom9ooooo`03o`000?oooooooooo03kooooo0ol0001/ooooo`00oooooom9ooooo`03o`000?oooooo
oooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003o
ooooooooo`2]ooooo`00oooooolAooooo`?o0000=Oooool3o`000:gooooo003ooooooa7ooooo0ol0
000eooooo`03o`000?oooooooooo0:gooooo003ooooooa7ooooo0ol0000eooooo`03o`000?oooooo
oooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003o
ooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003ooooooagooooo0_o^
k^h3ooooo`;ok^k^9Oooool00ol0003oooooooooo`2]ooooo`00oooooolFooooo`Go00000_ooool0
1oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb
<S;o0000oc8b<_o^k^hFooooo`03o`000?oooooooooo0:gooooo003ooooooaKooooo00GoV9RHob4Q
8Oo^k^koooooodA4A003ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05_ooool00ol0003oooooooooo`2]ooooo`00oooo
ool>ooooo`Ko00000oooool00onHV9So8B4Qonk^kP05ooooo`03omgMgOl0003ogMgM00Oooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01Kooooo00?o0000ooooooooool0
[Oooool00?oooooo6?ooool00onHV9So8B4Qonk^kP03ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h0
1_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000005_ooool00ol0003o
ooooooooo`2]ooooo`00oooooolIooooo`0;ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_oooooo
k^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
5_ooool4o`000:cooooo003ooooooa[ooooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41005_ooool00ol0003ooooo
ooooo`2]ooooo`00oooooolFooooo`05o`000?nj^[[ooooooiRHV?l@41003_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool3o`0000Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`2]ooooo`00COooool3o`000<Gooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c00<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP09oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2]oooo
o`00COooool3o`000;Kooooo0ol0000[ooooo`Co00000oooool00ol0003oooooooooo`04o`0000Ko
oooo00?o0000ooooooooool0[Oooool004gooooo0ol0002fooooo`?o0000<_ooool01ol0003ooooo
oooooooooooo0000ooooool000001_ooool00ol0003oooooooooo`2]ooooo`00ooooool7ooooo`?o
0000<_ooool00ol0003oooooooooo`02ooooo`;o00001_ooool00ol0003oooooooooo`0Pooooo`?o
0000R_ooool00?oooooo:Oooool3o`0000oooooo0_l00005ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool08?ooool6o`0008Oooooo002Oooooo`?o0000Q_ooool3o`0001gooooo00?o
0000ooooooooool08?ooool6o`0008Oooooo002Oooooo`?o0000Q_ooool3o`0001gooooo00?o0000
ooooooooool08oooool3o`0008Oooooo002Oooooo`?o0000Y_ooool00ol0003oooooooooo`2]oooo
o`00oooooom9ooooo`?o0000[Oooool00<Kooooo0ol0001oooooo`03o`000?oooooooooo0:gooooo
0036ooooo`?o0000Ooooool00ol0003oooooooooo`2]ooooo`00a_ooool3o`0007oooooo00?o0000
ooooooooool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00`_ooool3o`0008?o
oooo00?o0000ooooooooool0[Oooool00<;ooooo0ol00023ooooo`03o`000?oooooooooo0:gooooo
0032ooooo`?o0000Poooool00ol0003oooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooo
oooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003o
ooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo0ol0
002]ooooo`00oooooom9ooooo`03o`000?oooooooooo00Kooooo0ol0002Tooooo`00oooooom9oooo
o`03o`000?oooooooooo00Kooooo0ol0002Tooooo`00oooooom9ooooo`03o`000?oooooooooo00Ko
oooo0ol0002Tooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o
0000ooooooooool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooooom9oooo
o`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool00??ooooo
0ol0001Booooo`03o`000?oooooooooo0:gooooo003cooooo`?o0000D_ooool00ol0003ooooooooo
o`2]ooooo`00loooool3o`0005;ooooo0ol0002]ooooo`00oooooom9ooooo`03o`000?oooooooooo
06Oooooo0ol00013ooooo`00oooooom9ooooo`03o`000?oooooooooo06Oooooo0ol00013ooooo`00
h?ooool3o`0006Gooooo00?o0000ooooooooool0Ioooool3o`0004?ooooo003Pooooo`?o0000IOoo
ool00ol0003oooooooooo`2]ooooo`00h?ooool3o`0006Gooooo00?o0000ooooooooool0[Oooool0
0?ooooooBOooool00ol0003oooooooooo`2]ooooo`00doooool3o`0007;ooooo00?o0000oooooooo
ool0[Oooool00=?ooooo0ol0001booooo`03o`000?oooooooooo0:gooooo003Cooooo`?o0000L_oo
ool00ol0003oooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003ooooo
odWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool3o`000:gooooo003oooooodWooooo
00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooooom9
ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool00<_o
oooo0ol0001jooooo`03o`000?oooooooooo0:gooooo003;ooooo`?o0000Coooool2onk^kP?ooooo
0_o^k^hTooooo`03o`000?oooooooooo0:gooooo003;ooooo`?o00008_ooool3o`0001Cooooo1?l0
00000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool03Om4A4Co0000o`000?lb<S;ogMgMooooooo^
k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o
0000oc8b<_o^k^hEooooo`03o`000?oooooooooo0:gooooo003`ooooo`?o00005_ooool00ol0003o
ooooooooo`04ooooo`;o8B4Q2?ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^
kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Eooooo`03o`00
0?oooooooooo06gooooo0ol0000mooooo`00l?ooool3o`0000_ooooo1_l00005ooooo`03o`000?oo
oooooooo00oooooo00Oo0000ooooooooooooooooomgMgOl0003ogMgM00Oooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@01Gooooo00?o0000ooooooooool0KOooool3o`00
03gooooo003oooooo`[ooooo00?o0000ooooooooool03_ooool02OmgMgOo<S8booooooooooook^k^
oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Eooooo`03o`000?oooooooooo06gooooo0ol0000mooooo`00ooooool:ooooo`03o`000?oo
oooooooo00_ooooo00go0000ob4Q8Ol0003o<S8bolc<c?ooooook^k^oeEEEOo^k^koooooonk^k_mE
EEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001Gooooo
1?l0002/ooooo`00ooooool:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00ooo
ool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400Eooooo`03o`000?oooooooooo0:gooooo003oooooo`[ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`08ooooo`?o00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0:gooooo
003oooooo`Sooooo00?oEEEEofIVI_l000003Oooool4o`0000cooooo00?oEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo0:gooooo003oooooocKooooo1?l00003ooooo`03o`000?oo
oooooooo00Co00001Oooool00ol0003oooooooooo`2]ooooo`00oooooolmooooo`07o`000?oooooo
ooooooooool0003oooooo`000005ooooo`03o`000?oooooooooo0:gooooo003oooooocgooooo00?o
0000ooooooooool00_ooool2o`0000Gooooo00?o0000ooooooooool0[Oooool00?oooooo??ooool2
o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2]ooooo`00oooooom9oooo
o`03o`000?oooooooooo0:gooooo003oooooocGooooo0ol0000Aooooo`03o`000?oooooooooo0:go
oooo003oooooo`kooooo0ol0000Tooooo`?o00004Oooool00ol0003oooooooooo`2]ooooo`00oooo
ool>ooooo`?o00009?ooool3o`00017ooooo00?o0000ooooooooool0[Oooool00?oooooo3_ooool3
o`0003Sooooo0ol0002]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWo
oooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`006_oo
ool3o`000?oooooo;?ooool00ol0003oooooooooo`2]ooooo`006_ooool3o`000?oooooo;?ooool0
0ol0003oooooooooo`2]ooooo`006_ooool3o`000?oooooo;?ooool00ol0003oooooooooo`2]oooo
o`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o0000ooooooooool0
[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooo
oooo0:gooooo003oooooodWooooo0ol0002]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:go
oooo003oooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003ooooooooo
o`2]ooooo`00??ooool3o`000?oooooo2_ooool00ol0003oooooooooo`2]ooooo`00??ooool3o`00
0?oooooo2_ooool00ol0003oooooooooo`2]ooooo`00??ooool3o`000?oooooo2_ooool00ol0003o
ooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003Pooooo`?o0000IOoo
ool00ol0003oooooooooo`0Sooooo`?o0000Qoooool00>3ooooo0ol0001Uooooo`03o`000?oooooo
oooo02?ooooo0ol00027ooooo`00h?ooool3o`0006Gooooo00?o0000ooooooooool08oooool3o`00
08Oooooo003oooooodWooooo0ol0002]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo
003oooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]
ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o0000oooooooo
ool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oo
oooooooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0
003oooooooooo`2]ooooo`00Loooool3o`000=;ooooo00?o0000ooooooooool0[Oooool007?ooooo
0ol0003Booooo`03o`000?oooooooooo0:gooooo001cooooo`?o0000d_ooool3o`000:gooooo003o
ooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003oooooooooo`1goooo
o`?o0000<oooool00?ooooooBOooool00ol0003oooooooooo`1gooooo`?o0000<oooool00?oooooo
BOooool00ol0003oooooooooo`1gooooo`?o0000<oooool00?ooooooBOooool00ol0003ooooooooo
o`2]ooooo`009oooool3o`000?;ooooo0_o^k^h3ooooo`;ok^k^9Oooool00ol0003oooooooooo`2]
ooooo`009oooool3o`000>cooooo1?l000002Ol@413oooooonk^k_mEEEGok^k^ooooooo^k^koEEEE
onk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQKooooo00?o0000
ooooooooool0[Oooool002Oooooo0ol0003^ooooo`03o`000?oooooooooo00;ooooo00Gok^k^oeEE
EOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Fooooo`03o`000?oooooooooo0:gooooo003oooooo`kooooo1_l00005ooooo`03o`000?oooooo
oooo00?ooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41005_ooool00ol0003oooooooooo`2]ooooo`00oooooolIooooo`03o`000?oooooo
oooo00;ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`00000Fooooo`03o`000?oooooooooo0:gooooo003ooooooaWooooo00_o
0000ooooooooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`00000Fooooo`Co0000[?ooool00?oooooo6Oooool0
1?l0003oooooooooooooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@400Fooooo`03o`000?oooooooooo0:gooooo003ooooooaWooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
5_ooool00ol0003oooooooooo`2]ooooo`00oooooolGooooo`03oeEEEOmVIVKo000000gooooo00?o
EEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo0ol00004ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0[Oooool00?oooooo??ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0[Oooool00?oooooo=Oooool4
o`0000?ooooo00?o0000ooooooooool01?l00006ooooo`03o`000?oooooooooo0:gooooo003ooooo
occooooo00Oo0000ooooooooooooooooo`000?oooooo000000Kooooo00?o0000ooooooooool0[Ooo
ool00?oooooo??ooool00ol0003oooooooooo`02ooooo`;o00001_ooool00ol0003oooooooooo`2]
ooooo`00oooooolkooooo`;o00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003ooooo
ooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo0ol0002]
ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o0000oooooooo
ool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oo
oooooooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0
003oooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo
00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooooom9
ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo0ol0002]ooooo`00oooooom9ooooo`03
o`000?oooooooooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOoo
ool00ol0003oooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003ooooo
odWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00
oooooom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Ooo
ool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooooooo
0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool3o`000:gooooo
003oooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]
ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o0000oooooooo
ool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oo
oooooooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0
003oooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo
00?o0000ooooooooool0[Oooool00?ooooooBOooool3o`000:gooooo003oooooodWooooo00?o0000
ooooooooool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooooom9ooooo`03
o`000?oooooooooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOoo
ool00ol0003oooooooooo`2]ooooo`00oooooolMooooo`;ok^k^0oooool2onk^kRGooooo00?o0000
ooooooooool0[Oooool00?oooooo5oooool03Om4A4Co0000o`000?lb<S;ogMgMooooooo^k^koEEEE
onk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b
<_o^k^hFooooo`03o`000?oooooooooo0:gooooo003ooooooa[ooooo00WoMgMgoc8b<_oooooooooo
onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL05_ooool00ol0003oooooooooo`2]ooooo`00ooooool>ooooo`Ko00001oooool01ol0
003ooooooooooooooooogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41005_ooool00ol0003oooooooooo`2]ooooo`00oooooolJooooo`09ogMgMolb
<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000001Kooooo00?o0000ooooooooool0[Oooool00?oooooo5oooool03Ol0
003o8B4Qo`000?lb<S;oc<c<ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000005_ooool00ol0003oooooooooo`2]
ooooo`00oooooolGooooo`03o`000?oooooooooo00?ooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41005_ooool4o`000:cooooo003ooooo
oaOooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL05_ooool00ol0003oooooooooo`2]ooooo`00oooooolGooooo`Co00003?ooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool3o`0000;ooooo0_l00007
ooooo`03o`000?oooooooooo0:gooooo003ooooooccooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0:gooooo003oooooocGooooo1?l00003oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2]oooo
o`00oooooollooooo`03o`000?oooooooooo00?o00001oooool00ol0003oooooooooo`2]ooooo`00
oooooollooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0[Oooool00?oooooo
>oooool2o`0000;ooooo1?l00006ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o
0000ooooooooool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooooom9oooo
o`03o`000?oooooooooo0:gooooo003oooooodWooooo0ol0002]ooooo`00oooooom9ooooo`03o`00
0?oooooooooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool0
0ol0003oooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWo
oooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooo
oom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool0
0?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:go
oooo003oooooodWooooo0ol0002]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003o
ooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]oooo
o`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o0000ooooooooool0
[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooo
oooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003o
ooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o
0000ooooooooool0[Oooool00?ooooooBOooool3o`000:gooooo003oooooodWooooo00?o0000oooo
ooooool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooooom9ooooo`03o`00
0?oooooooooo0:gooooo000Jooooo`;ok^k^0oooool2onk^kS?ooooo0_o^k^h3ooooo`;ok^k^<ooo
ool2onk^kP?ooooo0_o^k^hdooooo`;ok^k^0oooool2onk^kS?ooooo0_o^k^h3ooooo`;ok^k^?_oo
ool00ol0003oooooooooo`0Xooooo`;ok^k^0oooool2onk^kS?ooooo0_o^k^h3ooooo`;ok^k^A?oo
ool001Cooooo1?l000002Ol@413oooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co
000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQgooooo00Goc<c<ob4Q8Ol0003o8B4Q
olc<c002ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@oooo
ooooooook^k^oc8b<_l0003o<S8bonk^kQgooooo00Gok^k^oc8b<_l0003o410@olc<c002ooooo`07
onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b
<_l0003o<S8bonk^kR3ooooo0_l000002_l@413oooooooooooo^k^koEEEEonk^k_ooooook^k^oeEE
EOo^k^h3ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQgooooo1Ol00002
ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@oooooooooooo
k^k^oc8b<_l0003o<S8bonk^kRoooooo00?o0000ooooooooool08Oooool5o`0000;ooooo00Ook^k^
oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^7oooool2o`00000:oa0@4?ooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^
kP?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^=Oooool001Kooooo00?o
0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@03oooo
o`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL07Oooool01OmEEEGoMgMgoooooonHV9So8B4Q00?ooooo00Gok^k^oeEEEOoMgMgo
EEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Qoooo
o`03o`000?oooooooooo00;ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
0oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg02oooooo00?o0000ooooooooool08Oooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0Pooooo`03o`000?oooooooooo00;ooooo00Gok^k^oeEEEOoMgMgo
EEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0eoooo
o`002oooool6o`0000Gooooo00?o0000ooooooooool00oooool00ooMgMgo0000omgMg@07ooooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Eooooo`Ko00000_ooool01Ol0
003ooooooooooooooooo000000Cooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41005Oooool6o`0000;ooooo00Go0000oooooooooooooooo
o`000004ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@01Kooooo1_l00002ooooo`Go00001?ooool00ooMgMgo0000omgMg@07ooooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Eooooo`Ko00000oooool00onH
V9So8B4Qonk^kP05ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@02oooooo00?o0000ooooooooool08_ooool00onHV9So8B4Qonk^kP05
ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@01gooooo1Ol00004ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@03Gooooo000Fooooo`03o`000?oooooooooo00;ooooo00Go
k^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`00000Mooooo`05oc8b<_nHV9SooooooiRHV?lb<S800oooool01Oo^k^koEEEEomgMgOmEEEGo
k^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001gooooo00Go
0000oiRHV?ooooooV9RHob4Q8@03ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000007_ooool01?m4A4CogMgMooooool00004
ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000007oooool00onHV9So8B4Qonk^kP03ooooo`05onk^k_mEEEGogMgMoeEEEOo^
k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000;oooool00ol0
003oooooooooo`0Sooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`04odA4A?oM
gMgoooooo`0000Cooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`00000eooooo`005_ooool02ol0003oooooooooooooooook^k^
oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000001gooooo00Goc<c<o`000?l0003o0000olc<c002ooooo`07onk^k_mEEEGok^k^
ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Mooooo`05o`000?mEEEGo0000oa0@4?o<c<`00_ooool01oo^k^koEEEEonk^k_ooooook^k^
oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007_oo
ool01?oMgMgoEEEEooooool00003ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Pooooo`0;ogMgMomVIVKo
ooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool00000;oooool00ol0003oooooooooo`0Tooooo`0;ogMgMomVIVKo
ooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000007Oooool01?oMgMgoEEEEooooool00003ooooo`07onk^k_mE
EEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`00000eooooo`005_ooool01?l0003oooooooooooooool2onk^kP?ooooo0_o^k^h5oooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Mooooo`05oa0@4?nj^[[o
oooookZj^_l@41000_ooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@400Mooooo`03oeEEEOn7QhOooooo00Cooooo0_o^k^h3ooooo`;ok^k^
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41007oooool00omgMgOo
c<c<o`000003ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@027ooooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Oooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100;oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo00;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@01kooooo00?oMgMgolc<c?l000000oooool2onk^kP?ooooo0_o^
k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400eooooo`005_oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0Mooooo`05o`000?nj^[[ooooookZj^_l000003_ooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL07Oooool00ooMgMgo410@oiRHV00@ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Oooooo`03onk^k_m4A4Co000000oooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo00Go0000okZj^_ooooooV9RH
oa0@400>ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0_ooooo`?o
00008Oooool01Ol0003o^[ZjoooooonHV9So410@00kooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg01kooooo00?ok^k^odA4A?l000003oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=Oooool001Cooooo00?oEEEEofIVI_l000003Oooool0
0omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool3o`0000Cooooo00?o
0000ooooooooool02oooool01OnYZJWo410@o`000?l@413oZJVY00cooooo00?oEEEEofIVI_l00000
1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo0ol00002ooooo`;o00003oooool01?o<c<co
A4A4o`000?l@410<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08
ooooo`?o00000_ooool2o`00017ooooo00?oMgMgo`000?ooool03?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool3o`0000;ooooo0_l0000>ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`03?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02?ooool3o`0000;ooooo0_l0000Pooooo`03o`000?oooooooooo027ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c00<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08
ooooo`?o00000_ooool2o`00013ooooo00?oMgMgo`000?ooool03?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool3o`0000;ooooo0_l0000Vooooo`00>Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo037ooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`0aooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
<_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo037ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04Oooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0aooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool08oooool003;ooooo1?l00003ooooo`03o`000?oooooooooo00Co0000;?ooool4
o`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Zooooo`Co00000oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo02_ooooo1?l00003ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0:_ooool4o`0000?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo043ooooo1?l00003ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0:_ooool4o`0000?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Sooooo`00>Oooool01ol0003ooooooooooooooooo0000ooooool00000<ooo
ool00ol0003oooooooooo`03o`0003Cooooo00?o0000ooooooooool00ol0000eooooo`03o`000?oo
oooooooo00?o0000=?ooool00ol0003oooooooooo`03o`00023ooooo00?o0000ooooooooool0Aooo
ool00ol0003oooooooooo`03o`0003Cooooo00?o0000ooooooooool00ol0000Vooooo`00>Oooool0
0ol0003oooooooooo`02ooooo`;o0000<oooool01?l0003oooooooooool0000fooooo`04o`000?oo
ooooooooo`0003Oooooo00Co0000oooooooooooo0000=_ooool01?l0003oooooooooool0000Roooo
o`03o`000?oooooooooo04Oooooo00Co0000oooooooooooo0000=_ooool01?l0003oooooooooool0
000Xooooo`00>?ooool2o`0000Gooooo00?o0000ooooooooool0<?ooool2o`0000;ooooo1?l0000b
ooooo`;o00000_ooool4o`0003?ooooo0_l00002ooooo`Co0000<_ooool2o`0000;ooooo1?l0000O
ooooo`03o`000?oooooooooo04Kooooo0_l00002ooooo`Co0000<_ooool2o`0000;ooooo1?l0000U
ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o0000oooooooo
ool03oooool3o`0009_ooooo003oooooodWooooo00?o0000ooooooooool03oooool3o`0007oooooo
0ol000000ol@413oooooooooo`02ooooo`;o00000_ooool2o`0000kooooo003oooooodWooooo00?o
0000ooooooooool03oooool3o`00083ooooo00?o0000ooooooooool01?ooool01_o^k^ko8B4QohN7
Qonj^[[o0000omgMg@kooooo003oooooodWooooo00?o0000ooooooooool05_ooool3o`0007Wooooo
00?o0000ooooooooool01Oooool01?oMgMgo0000oa0@4?o<c<`?ooooo`004Oooooooo`000;oo0000
3_ooool3o`000003ob4Q8Oo<c<cooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^3oooool001Oooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`?o000000?oooooo`000?ooool0
3Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0?ooooo`05o`000?ooooooooooohN7Qol@41000oooool01?lQ8B7o
MgMgogMgMolb<S8?ooooo`009Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo03So
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo01go
oooo00Go0000ooooooooooooooooo`000002ooooo`;o00000_ooool2o`0000kooooo000Uooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool07Oooool01Ol0003ooooooooooon7QhOo410@
01Kooooo003oooooodWooooo00?o0000ooooooooool0TOooool4o`000003ob4Q8Oo<c<cooooo01Go
oooo003oooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003ooooooooo
o`2]ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooo
oooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooo
oooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooom:ooooo`?o000000?o410@oooooooo
ool0ZOooool00?ooooooC?ooool00ol@413o^[Zjooooo`2Zooooo`00oooooom<ooooo`03oiRHV?lb
<S;ooooo0:[ooooo003ooooood?ooooo0ol000000ol@413oooooooooo`03ooooo`03omgMgOl0003o
^[Zj0:[ooooo003oooooodCooooo00?o0000ooooooooool01Oooool00omEEEGoMgMgodA4A02Zoooo
o`00oooooom4ooooo`03o`000?oooooooooo00Cooooo00GogMgMoa0@4?oooooo8B4QomgMg@2Yoooo
o`00oooooom4ooooo`?o000000Wo8B4Qolc<c?ooooooooooofIVI_n7QhOooooooiRHV?mEEED0ZOoo
ool00?ooooooA?ooool02Ol0003ooooooooooon7QhOo410@ooooooo^k^ko0000onk^kP02ooooo`03
o`000?oMgMgooooo0:Oooooo003oooooodCooooo00Oo0000ooooooooooooooooo`000?oooooo410@
00;o000000Coooooo`000?l0003o410@Z?ooool00?ooooooA?ooool01Ol0003ooooooooooon7QhOo
410@0;3ooooo003ooooood?ooooo1?l000000olQ8B7oc<c<ooooo`2_ooooo`00oooooooiooooo`00
oooooooiooooo`00dOooool2o`0000;ooooo00Oo0000oooooooooooo0000oa0@4?o^k^koEEEE00;o
000000?oEEEEonk^k_ooool00_l00002ooooo`07o`000?ooooooooooo`000?l@413ok^k^oeEEE@02
o`000005odA4A?nj^[[oooooooooool@41000_l000001?oooooo0000o`000?l@4102ooooo`05oiRH
V?l0003o0000odA4A?nj^[X00oooool01_nHV9So0000o`000?mgMgOo0000oa0@40;o00000_ooool0
1Ol0003oooooooooool0003o410@0>Kooooo003Booooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooomEEEGoMgMg0_ooool01OmgMgOoEEEEoooooooooooo000000;ooooo00_o0000oooooooo
oooo0000oooooomEEEGoMgMgooooooo^k^koMgMgoa0@4003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol@413o^[Zjonk^k_mgMgOo410@00?ooooo00Go0000ojVYZOooooooQhN7o`000002
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0iOooool00=;ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooo`000004ooooo`04o`000?ooooooooooo`0000;ooooo
00Ko0000oooooooooooo0000ooooool00008ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo0>Gooooo003Booooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooool000001?ooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooo`00
0?ooool01_l00003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo0>Gooooo003Booooo`0:o`000?o<c<coc<c<o`000?nYZJWogMgMob4Q8OooooooEEEE
ogMgM`;ooooo00GoMgMgoeEEEOooooooooooo`000002olc<c00;o`000?nYZJWogMgMob4Q8Ooooooo
EEEEohN7Qoo^k^koooooohN7Qolb<S800oooool01Ol0003oQhN7oooooonYZJWo000000?ooooo00?o
0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000;ooooo00Oo0000olc<c?o<c<co
0000ojVYZOoMgMgo8B4Q0>Oooooo003Aooooo`0;oa0@4?l0003o8B4Qo`000?mgMgOo410@o`000?nY
ZJWoooooonk^k_mEEED00_l000003_mEEEGok^k^ooooool@413o0000ob4Q8Ol0003oMgMgoa0@4?l0
003oZJVYooooooo^k^koEEEE0_l000001om4A4Cok^k^oooooooooooo410@o`000?mgMgL00_l00000
0onHV9Sooooooa0@4005o`0000?ooooo00Co410@o`000?oooooooooo0_l000002Ooooooo410@o`00
0?lQ8B7o0000ogMgMol@413o0000ojVYZ@3Wooooo`00noooool00ol0003oooooooooo`3jooooo`00
noooool00ol0003oooooooooo`3jooooo`00oooooooiooooo`00oooooooiooooo`00oooooooioooo
o`00\
\>"],
  ImageRangeCache->{{{0, 503.688}, {310.938, 0}} -> {-1.12924*^-14, \
-2.34425*^-14, 4.29387*^-17, 1.09253*^-16}}]
}, Open  ]],

Cell[TextData[{
  "The error is down at the level of the machine precision. This is an \
excellent check to make sure there are no errors in the code. But the \
accuracy is ",
  StyleBox["too good ",
    FontSlant->"Italic"],
  "to be of any further use!  We can vary the grid spacing and the time step \
size, making them as large as we wish,  and we will find that total momentum \
is ",
  "always conserved",
  ". (Try it.) Thus, evaluation of ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["P",
            FontWeight->"Bold",
            FontSlant->"Plain"], "tot"], TraditionalForm]]],
  " tells us nothing about the accuracy of the solution. "
}], "Text"],

Cell[TextData[{
  "\tIt is interesting that this negligible error grows dramatically if a \
second-order interpolation scheme is used in the module ",
  StyleBox["Fpart",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". One might have expected that second-order interpolation would be more \
accurate than first-order interpolation. However, first-order interpolation \
(linear interpolation from the grid to the particles) works best, because the \
area-weighting used to create the density on the grid in the first place is \
also a linear interpolation. In the PIC method, it has been shown that one \
should use the same method to interpolate from the grid to the particle \
positions as one uses to determine the density from these positions [",
  ButtonBox["Birdsall and Langdon (1991)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  "]."
}], "Text"],

Cell[TextData[{
  "\tAnother conserved quantity (in infinite space) is the total angular \
momentum, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[\(L\_z\),
            FontSlant->"Italic"], "=", 
          RowBox[{
            OverscriptBox[
              StyleBox["z",
                FontWeight->"Bold"], "^"], "\[CenterDot]", 
            RowBox[{\(\[Sum]\+i\), 
              RowBox[{
                StyleBox[
                  SubscriptBox["r", 
                    StyleBox["i",
                      FontWeight->"Plain",
                      FontSlant->"Italic"]],
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox[" ",
                  FontWeight->"Bold"], "\[Times]", 
                StyleBox[
                  SubscriptBox["p", 
                    StyleBox["i",
                      FontWeight->"Plain",
                      FontSlant->"Italic"]],
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}]}]}]}], TraditionalForm]]],
  ". To evaluate this quantity we require the momentum at the same time as \
the position. This can be obtained by averaging, as shown in Cell ",
  ButtonBox["7.81",
    ButtonData:>"Cell 7.81",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(p[n_]\  := \ \((p[n - 1/2]\  + p[n + 1/2])\)/2\  /; \ 
          n \[Element] Integers\  && \ n > \ 0;\)\n\), "\n", 
    \(\(angmom[n_]\  := \ 
        Sum[\(r[n]\)[\([i, 1]\)] \(p[n]\)[\([i, 2]\)] - \(r[n]\)[\([i, 
                  2]\)] \(p[n]\)[\([i, 1]\)], {i, 1, 
            Length[r[n]]}];\)\[IndentingNewLine]\), "\n", 
    \(\(ListPlot[
        Table[{n\ \[CapitalDelta]t, angmom[n] - angmom[0]}, {n, 0, 30}], 
        PlotLabel \[Rule] \ "\<change in angular momentum versus time\>", \ 
        AxesLabel \[Rule] {"\<t\>", "\<\>"}, 
        PlotJoined \[Rule] True];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.81"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.793651 0.967038 188.859 [
[.18254 .01024 -9 -9 ]
[.18254 .01024 9 0 ]
[.34127 .01024 -9 -9 ]
[.34127 .01024 9 0 ]
[.5 .01024 -9 -9 ]
[.5 .01024 9 0 ]
[.65873 .01024 -9 -9 ]
[.65873 .01024 9 0 ]
[.81746 .01024 -3 -9 ]
[.81746 .01024 3 0 ]
[.97619 .01024 -9 -9 ]
[.97619 .01024 9 0 ]
[1.025 .02274 0 -6 ]
[1.025 .02274 10 6 ]
[.01131 .11717 -42 -4.5 ]
[.01131 .11717 0 4.5 ]
[.01131 .2116 -36 -4.5 ]
[.01131 .2116 0 4.5 ]
[.01131 .30603 -42 -4.5 ]
[.01131 .30603 0 4.5 ]
[.01131 .40046 -36 -4.5 ]
[.01131 .40046 0 4.5 ]
[.01131 .49489 -42 -4.5 ]
[.01131 .49489 0 4.5 ]
[.01131 .58932 -36 -4.5 ]
[.01131 .58932 0 4.5 ]
[.5 .63053 -116.062 0 ]
[.5 .63053 116.062 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .02274 m
.18254 .02899 L
s
[(0.2)] .18254 .01024 0 1 Mshowa
.34127 .02274 m
.34127 .02899 L
s
[(0.4)] .34127 .01024 0 1 Mshowa
.5 .02274 m
.5 .02899 L
s
[(0.6)] .5 .01024 0 1 Mshowa
.65873 .02274 m
.65873 .02899 L
s
[(0.8)] .65873 .01024 0 1 Mshowa
.81746 .02274 m
.81746 .02899 L
s
[(1)] .81746 .01024 0 1 Mshowa
.97619 .02274 m
.97619 .02899 L
s
[(1.2)] .97619 .01024 0 1 Mshowa
.125 Mabswid
.06349 .02274 m
.06349 .02649 L
s
.10317 .02274 m
.10317 .02649 L
s
.14286 .02274 m
.14286 .02649 L
s
.22222 .02274 m
.22222 .02649 L
s
.2619 .02274 m
.2619 .02649 L
s
.30159 .02274 m
.30159 .02649 L
s
.38095 .02274 m
.38095 .02649 L
s
.42063 .02274 m
.42063 .02649 L
s
.46032 .02274 m
.46032 .02649 L
s
.53968 .02274 m
.53968 .02649 L
s
.57937 .02274 m
.57937 .02649 L
s
.61905 .02274 m
.61905 .02649 L
s
.69841 .02274 m
.69841 .02649 L
s
.7381 .02274 m
.7381 .02649 L
s
.77778 .02274 m
.77778 .02649 L
s
.85714 .02274 m
.85714 .02649 L
s
.89683 .02274 m
.89683 .02649 L
s
.93651 .02274 m
.93651 .02649 L
s
.25 Mabswid
0 .02274 m
1 .02274 L
s
gsave
1.025 .02274 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .11717 m
.03006 .11717 L
s
[(-0.0045)] .01131 .11717 1 0 Mshowa
.02381 .2116 m
.03006 .2116 L
s
[(-0.004)] .01131 .2116 1 0 Mshowa
.02381 .30603 m
.03006 .30603 L
s
[(-0.0035)] .01131 .30603 1 0 Mshowa
.02381 .40046 m
.03006 .40046 L
s
[(-0.003)] .01131 .40046 1 0 Mshowa
.02381 .49489 m
.03006 .49489 L
s
[(-0.0025)] .01131 .49489 1 0 Mshowa
.02381 .58932 m
.03006 .58932 L
s
[(-0.002)] .01131 .58932 1 0 Mshowa
.125 Mabswid
.02381 .04163 m
.02756 .04163 L
s
.02381 .06051 m
.02756 .06051 L
s
.02381 .0794 m
.02756 .0794 L
s
.02381 .09828 m
.02756 .09828 L
s
.02381 .13606 m
.02756 .13606 L
s
.02381 .15494 m
.02756 .15494 L
s
.02381 .17383 m
.02756 .17383 L
s
.02381 .19271 m
.02756 .19271 L
s
.02381 .23049 m
.02756 .23049 L
s
.02381 .24937 m
.02756 .24937 L
s
.02381 .26826 m
.02756 .26826 L
s
.02381 .28714 m
.02756 .28714 L
s
.02381 .32492 m
.02756 .32492 L
s
.02381 .3438 m
.02756 .3438 L
s
.02381 .36269 m
.02756 .36269 L
s
.02381 .38157 m
.02756 .38157 L
s
.02381 .41935 m
.02756 .41935 L
s
.02381 .43823 m
.02756 .43823 L
s
.02381 .45712 m
.02756 .45712 L
s
.02381 .476 m
.02756 .476 L
s
.02381 .51378 m
.02756 .51378 L
s
.02381 .53266 m
.02756 .53266 L
s
.02381 .55155 m
.02756 .55155 L
s
.02381 .57043 m
.02756 .57043 L
s
.02381 .00386 m
.02756 .00386 L
s
.02381 .60821 m
.02756 .60821 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -177.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(change) show
105.000 13.000 moveto
(in) show
123.000 13.000 moveto
(angular) show
171.000 13.000 moveto
(momentum) show
225.125 13.000 moveto
(versus) show
267.125 13.000 moveto
(time) show
291.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.04035 .61803 m
.05556 .29717 L
.0873 .26748 L
.11905 .30902 L
.15079 .36754 L
.18254 .3166 L
.21429 .20998 L
.24603 .19089 L
.27778 .27573 L
.30952 .39146 L
.34127 .40656 L
.37302 .29923 L
.40476 .2102 L
.43651 .22381 L
.46825 .25059 L
.5 .20059 L
.53175 .13269 L
.56349 .13039 L
.59524 .15295 L
.62698 .10209 L
.65873 .01472 L
.69048 .04339 L
.72222 .16929 L
.75397 .25549 L
.78571 .21498 L
.81746 .11354 L
.84921 .089 L
.88095 .14909 L
.9127 .18325 L
.94444 .11282 L
.97619 .06697 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Foooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00006Oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool05oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`06Oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`08_oo
ool4o`000003oa0@4?oooooooooo01oooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?oo
ool5o`0001;ooooo001Kooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oo
oooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05oeEEEOmgMgOooooooiRHV?lQ8B406Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B409?ooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo00Cooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@04_ooool005_ooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^01[ooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go00006Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000Iooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000002Cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0;ooooo`03
oiRHV?lQ8B7ok^k^01?ooooo001Kooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So
8B4Qonk^kP0Iooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool0000J
ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q01Wooooo
00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S809?ooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h04_ooool005_o
oooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo01Sooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0001[ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`06Oooool01Ol0003ooooooooooooooooo0000
00_ooooo00Goc<c<o`000?l0003o0000olc<c00Tooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool03Oooool00omgMgOoIVIVooooo`0Aooooo`00Foooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool05oooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l000006_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
6oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400Toooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0@oooo
o`00>?ooool00ol0003oooooooooo`0Pooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@01Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000001[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01_ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000009?ooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@400B
ooooo`00>?ooool2o`00027ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`06Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool0
6Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@6Oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0Rooooo`03oeEEEOmV
IVKo000002?ooooo00?oEEEEofIVI_l000003?ooool01OnHV9So410@o`000?lQ8B7oc<c<01;ooooo
000hooooo`03o`000?oooooooooo0?oooooo;_ooool003Sooooo00?o0000ooooooooool0ooooool^
ooooo`00>?ooool00ol0003oooooooooo`2eooooo`03o`000?oooooooooo06cooooo00GoV9RHo`00
0?l0003oA4A4okZj^P04ooooo`00>?ooool00ol0003oooooooooo`2eooooo`;o0000KOooool01Ol@
413o^[Zjonk^k_mgMgOo410@00Cooooo000hooooo`03o`000?oooooooooo0;Cooooo00Co0000oooo
oooooooo0000K?ooool00ol0003oooooooooo`06ooooo`00<Oooooooo`0002Co00002oooool00ol0
003oooooooooo`06ooooo`00>?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`;o00000oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`06ooooo`00>?ooool00ol0003oooooooooo`2cooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0IOooool00ol@413o0000o`000003o`0000Gooooo000hooooo`03o`000?oo
oooooooo0;?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Vooooo`03o`000?oo
oooooooo00Kooooo000hooooo`03o`000?oooooooooo0;?ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00Kooooo000hooooo`;o0000/oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo06gooooo000hooooo`03o`000?oooooooooo0;;o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1/ooooo`00>?ooool00ol0003ooooo
ooooo`2booooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0K?ooool003Sooooo00?o
0000ooooooooool0/Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo06cooooo000h
ooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1[
ooooo`00>?ooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0Joooool003Sooooo0_l0002aooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0Joooool003Sooooo00?o0000ooooooooool0/?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo04oooooo00?o0000ooooooooool06Oooool003Sooooo00?o0000ooooooooool0/?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool06Ooo
ool003Sooooo00?o0000ooooooooool0[oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo04gooooo00?o0000ooooooooool06_ooool003Sooooo00?o0000ooooooooool0[oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool06oooool003So
oooo0_l0002`ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0C?ooool00ol0003o
ooooooooo`0Kooooo`00>?ooool00ol0003oooooooooo`2^ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Looooo`00>?ooool00ol0003ooooooooo
o`2^ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0BOooool00ol0003ooooooooo
o`0Mooooo`00>?ooool00ol0003oooooooooo`2^ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool09oooool2o`00023ooooo00?o0000ooooooooool07Oooool003Sooooo00?o0000oooo
ooooool0[Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ool000007oooool00ol0003oooooooooo`0Nooooo`00>?ooool00ol0003oooooooooo`2]ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool09?ooool01Ol0003ooooooooooooooooo0000
01kooooo00?o0000ooooooooool07_ooool003Sooooo0_l0002^ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool08_ooool2o`0000Cooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Oooooo`00>?ooool00ol0003oooooooooo`2/ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool08?ooool000Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o000000?o410@ooooooooool00_ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool0[?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo023ooooo0005oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`06ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0Zoooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo027ooooo0003o`0000;ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@
4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo1Ol00008oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Z_ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo02;ooooo0005ooooo`05o`000?ooooooooooooooool000002oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04odA4A?oM
gMgoooooo`0000Sooooo00?oMgMgoc8b<_ooool01?ooool2o`000:[ooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0Rooooo`001Oooool01Ol0003ooooooooooooooooo000000_ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?oM
gMgoEEEEooooool00005ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`2Yooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool08oooool000Gooooo00Go410@
oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooo
oooooooooooo410@00Cooooo00?oMgMgolc<c?l000001Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0:Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Sooooo`00
1Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00oo^k^koA4A4o`000005ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0Yoooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo02Cooooo0005ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03ogMgMol0003ooooo00Cooooo
1?l00006ooooo`03o`000?oooooooooo093ooooo2ol0000<ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool09?ooool003Sooooo0_l0002Aooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Gooooo000h
ooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool02_ooool2o`0000Oooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0Uooooo`00>?ooool00ol0003oooooooooo`2?oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo02Kooooo000hooooo`03o`000?oooooooooo08kooooo00?o0000oooooooo
ool03_ooool2o`0000?ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Vooooo`00
>?ooool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo013ooooo00?o0000ooooool00000
8Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Wooooo`00>?ooool00ol0003oooooooooo`2>ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Wooooo`00>?ooool2
o`0008kooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Xooooo`00>?ooool00ol0
003oooooooooo`2=ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0:?ooool003So
oooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Wo
oooo000hooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool0>?ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Yooooo`00>?ooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0:_ooool003Sooooo0_l0002<ooooo`03o`000?oooooooooo03Wooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0:_ooool003Sooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool06oooool01?l0003oooooooooool0000]
ooooo`00>?ooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo000002gooooo000hooooo`03
o`000?oooooooooo08Wooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool0;?ooool003Sooooo00?o0000ooooooooool0
ROooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
COooool003Sooooo00?o0000ooooooooool0??ooool2o`0004_ooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04kooooo000hooooo`;o0000??ooool0
0ol0003oooooo`00001:ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`1>ooooo`00>?ooool00ol0003oooooooooo`0iooooo`;o00000oooool00ol0
003oooooooooo`17ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`1>ooooo`00>?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0Coooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0fooooo`;o00001_ooool0
0ol0003oooooooooo`16ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`1?ooooo`003Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0A?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0Coooool000Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@4100
2oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003oooo
o`Go00001_ooool2o`0003Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Yoooo
o`;o00006?ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool0D?ooool000gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00CoA4A4omgMgOoooooo0000
1oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
:Oooool01?l0003oooooo`000?l0000Fooooo`03o`000?oooooooooo04Cooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`1@ooooo`003Oooool01Ol0003ooooooooooooooooo000000_o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool0
1?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00;ooooo0ol0000Booooo`03o`000?oo
oooooooo04Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1@ooooo`003Oooool0
1Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@
4?ooooooooooooooool@41001?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Go
oooo0_l0000@ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`1Aooooo`003Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00oo^k^koA4A4o`000007
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo00Oooooo0_l0000=ooooo`03o`000?oooooooooo04Oooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`1Booooo`003Oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
Doooool003Sooooo0_l0000cooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0B?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Cooooo000hooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0EOooool003Sooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool03_ooool2o`00
00Kooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
05Gooooo000hooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`1;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0E_ooool003Sooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool04Oooool01?l0003oooooooooool0001?ooooo`05o`000?oooooooooooooo
ool00000FOooool003Sooooo0_l0000booooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo000004oooooo00Co0000oooooooo
oooo0000F_ooool003Sooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1>ooooo`03
o`000?oooooo000005_ooooo000hooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0
F_ooool003Sooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool0a?ooool003Sooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0a?ooool0
03Sooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool0a?ooool003Sooooo0_l0000?ooooo`;o00007oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0aOooool003Sooooo
00?o0000ooooooooool03Oooool00ol0003oooooo`00000Oooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`35ooooo`00>?ooool00ol0003ooooooooo
o`0<ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool0aOooool003Sooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo0<Kooooo000hooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`36ooooo`00>?ooool2o`00
00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`36ooooo`00>?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0aoooool003Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo0<Oooooo
0005ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01OnHV9So410@o`000?lb<S;o
c<c<00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`37ooooo`001Oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00Go410@okZj^_ooooooMgMgoc8b<P07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
0<Sooooo0003o`0000;ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?oooooooooo
ooooool@41000oooool01Ol@413ooooooooooooooooo410@00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`38ooooo`001Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool00onYZJWo
410@ooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool0b?ooool000Gooooo00Go0000ooooooooooooooooo`00000;ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Gooooo00?o410@
o`000?nj^[X01?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0<Wooooo0005ooooo`05oa0@4?oooooo
ooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@4006ooooo`03okZj^_lQ8B7ooooo00?ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0bOooool000Gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00Go410@oiRHV?oooooo^[Zjo`000004ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo0<Wooooo0005ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05ojVYZOl@413o0000oa0@
4?nYZJT01?ooool4o`0000Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo0<[ooooo000hooooo`;o00001oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo0<[ooooo000hooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`3:ooooo`00>?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0b_ooool003Sooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo0<_ooooo000hooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`3;ooooo`00>?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0boooool003Sooooo
0_l00006ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0c?ooool003Sooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0<cooooo000h
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`3<
ooooo`00>?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0cOooool003Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Gooooo`05
o`000?ooooooooooooooool00000:?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
0<gooooo000hooooo`;o00001_ooool00ol0003oooooooooo`0Hooooo`04o`000?ooooooooooo`00
02Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`3=ooooo`00>?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooool00000:_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo0<gooooo000hooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0c_ooool003Sooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`15ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0c_ooool003Sooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0c_ooool003Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`16oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0coooool003Sooooo0_l00006ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3?ooooo`00
>?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`3?ooooo`00>?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo04Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`3?ooooo`003Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00GoV9RHoa0@4?l0003o<S8bolc<c006oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Aoooool2o`0000Wooooo00?o0000oooo
ooooool0d?ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05oa0@4?nj
^[[oooooogMgMolb<S801_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04[ooooo
0ol00006ooooo`03o`000?oooooooooo0=3ooooo0005ooooo`Ko00000_ooool01Ol@413ooooooooo
oooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41001oooool00ol0003oooooooooo`04ooooo`;o00001Oooool00ol0003oooooooooo`1=oooo
o`;o00001?ooool00ol0003oooooooooo`3@ooooo`003Oooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_oo
ool00onYZJWo410@ooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Cooo
ool4o`000=?ooooo000=ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000005ooooo`03oa0@4?l0003o^[Zj00Ko
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo0=7o
oooo000=ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03okZj^_lQ8B7ooooo00Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`3oooooobOooooo000=ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo0?oooooo9oooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00GoZJVY
oa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oolWooooo`00>?ooool2o`0000Gooooo00?o0000ooooooooool0oooooolWooooo`00>?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo9oooool003Sooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`3oooooobOooooo000hooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooolWooooo`00>?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0?oooooo9oooool003Sooooo0_l00005ooooo`03o`000?oooooooooo0?oooooo9oooool0
03Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooobOooooo000hooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooolWooooo`00>?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo0?oooooo9oooool003Sooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`3oooooobOooooo000hooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0oooooolWooooo`00>?ooool2o`0000Cooooo00?o0000ooooooooool0oooooolXoooo
o`00>?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo:?ooool003Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooobSooooo000hooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0oooooolXooooo`00>?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo0?oooooo:?ooool003Sooooo0_l00004ooooo`03o`000?oooooooooo
0?oooooo:?ooool003Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooobSo
oooo000hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooolXooooo`001Ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo1Ol00004ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo:?ooool0
00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0oooooolXooooo`000ol00002ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4004ooooo`03oiRHV?lQ8B7o
k^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo0?oooooo:?ooool000Gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000Gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`;o00001?ooool00ol0003oooooooooo`3oooooobSooooo
0005ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000006ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooolX
ooooo`001Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41001oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooobSooooo
0005ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooolX
ooooo`001Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01OnHV9So410@o`000?lQ8B7oc<c<00Co
oooo1?l00006ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooolXooooo`00
>?ooool2o`0000Cooooo00?o0000ooooooooool0oooooolXooooo`00>?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo0?oooooo:?ooool003Sooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`3oooooobSooooo000hooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0oooooolYooooo`00>?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oo
oooo:Oooool003Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3oooooobWooooo
000hooooo`;o00000oooool00ol0003oooooooooo`3oooooobWooooo000hooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0oooooolYooooo`00>?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo0?oooooo:Oooool003Sooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`3oooooobWooooo000hooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
oooooolYooooo`00>?ooool2o`0000?ooooo00?o0000ooooooooool0oooooolYooooo`00>?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo:Oooool003Sooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`3oooooobWooooo000hooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0oooooolYooooo`00>?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0?oooooo:Oooool003Sooooo0_l00003ooooo`03o`000?oooooooooo0?oooooo:Ooo
ool003Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3oooooobWooooo000hoooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0oooooolYooooo`003Oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo1Ol00006ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0oooooolYooooo`003Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0oooooolYooooo`001Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Cooooo00?o
V9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo:Ooo
ool000gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000Gooooo00?oV9RHob4Q8Oo^k^h01_ooool2o`0000;o
oooo00?o0000ooooooooool0oooooolZooooo`003Oooool01Ol0003ooooooooooooooooo000000_o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool0
0omgMgOoIVIVooooo`05ooooo`05o`000?ooooooooooooooool00000ooooool/ooooo`003Oooool0
1Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@
4?ooooooooooooooool@41001oooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooooooo
ool00000ooooool/ooooo`003Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Ol0003o^[Zjoooo
oonHV9So410@00Kooooo00Go0000ooooooooooooooooo`00003oooooobcooooo000=ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool01Ol0003ooooooooo
oooooooo00000?oooooo;?ooool003Sooooo0_l00002ooooo`03o`000?oooooooooo0?oooooo:_oo
ool003Sooooo00Go0000ooooooooooooooooo`00003oooooobcooooo000hooooo`05o`000?oooooo
ooooooooool00000ooooool/ooooo`00>?ooool01Ol0003ooooooooooooooooo00000?oooooo;?oo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool005Gooooo00Go8B4Qo`000?l0003oA4A4omgMg@0fooooo`05ob4Q8Ol0003o0000odA4A?oMgMd0
doooool005Sooooo00?oMgMgoc8b<_ooool0>?ooool00omgMgOo<S8booooo`3Booooo`00FOooool0
0ol0003oooooooooo`0hooooo`03o`000?oooooooooo0=7ooooo000eooooo`05ofIVI_l0003o0000
odA4A?o<c<`00_ooool01?l@413o0000o`000?ooool2o`000003oa0@4?ooooooV9RH00;o000000?o
MgMgoa0@4?l000000_ooool01?l@413o0000o`000?ooool2o`000008oa0@4?ooooook^k^oeEEEOl0
003o410@olc<c?l00002ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj2?ooool5o`0000;ooooo
00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`05ooooo`06oiRHV?l0003o0000ogMg
Mol@413o00000_ooool01?l@413o0000o`000?ooool2o`000008oa0@4?ooooook^k^oeEEEOl0003o
410@olc<c?l00003ooooo`07oiRHV?l0003o0000ogMgMol0003o410@ooooo`05o`0000?ooooo00So
V9RHo`000?l0003oMgMgoa0@4?l0003ooooooa0@40Go00001_ooool2o`0000;ooooo00Oo0000oooo
oooooooo0000oa0@4?o^k^koEEEE00;o000000?oEEEEonk^k_ooool00_l00002ooooo`07o`000?oo
ooooooooo`000?l@413ok^k^oeEEE@02o`000005odA4A?nj^[[oooooooooool@41000_l000001?oo
oooo0000o`000?l@4102ooooo`05oiRHV?l0003o0000odA4A?nj^[X00oooool01_nHV9So0000o`00
0?mgMgOo0000oa0@40;o00000_ooool01Ol0003oooooooooool0003o410@00Kooooo00?o8B4Qoc8b
<_ooool00oooool02?o^k^koEEEEo`000?l0003oA4A4okZj^_oooooo410@1Ol00003ooooo`06oa0@
4?lb<S;o0000o`000?l@413oZJVY0oooool02OnHV9So0000o`000?mgMgOo0000oa0@4?oooooo410@
oc8b<P02o`000003oa0@4?nYZJWooooo00Kooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`Go
000000?oooooo`000?l000000_ooool01ol0003oooooooooool0003o410@onk^k_mEEED00_l00000
0om4A4Co^[Zjooooo`0Fooooo`00=?ooool01_mVIVKoMgMgooooooooooooQhN7oa0@40?ooooo00Go
0000ooooooooooooooooo`000002ooooo`05o`000?o<c<cok^k^ohN7Qol000001?ooool01Ol0003o
oooooooooooooooo000000;ooooo00KoEEEEogMgMoooooook^k^oeEEEOl00002ooooo`06oeEEEOmg
MgOoooooonk^k_mgMgOo410@2_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooooooo
ool000002?ooool01Ol0003oc<c<onk^k_n7QhOo000000Cooooo00Go0000ooooooooooooooooo`00
0002ooooo`06oeEEEOmgMgOoooooonk^k_mEEEGo00000oooool01Ol0003oZJVYoooooon7QhOo0000
00Cooooo00?o0000ooooooooool00oooool01Ol0003oc<c<onk^k_n7QhOo000000Cooooo00?o0000
ooooooooool02?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooEEEEogMgM`;ooooo
00GoMgMgoeEEEOooooooooooo`000002ooooo`0;o`000?ooooooooooo`000?ooooooEEEEogMgMooo
ooook^k^ogMgMol@41000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go410@okZj^_o^
k^koMgMgoa0@4003ooooo`05o`000?nYZJWoooooohN7Qol000000_ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00Cooooo00CoV9RHoc8b<_l@413o^[Zj0oooool01_mEEEGoMgMg
ooooooo^k^koMgMgoa0@40?ooooo00?o0000ooooooooool01?ooool01_l0003oZJVYoooooooooooo
^[Zjo`0000?ooooo00Go0000ojVYZOooooooQhN7o`000002ooooo`06o`000?nYZJWooooooooooonj
^[[o00001oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Gooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00002ooooo`08o`000?ooooooEEEEogMgMoooooook^k^ogMgMol@410Goooo
o`00=?ooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000000_ooool01Ol@
413oQhN7ooooooo^k^ko000000Cooooo00Go0000ooooooooooooooooo`000002ooooo`06o`000?oo
ooooooooooooooo^k^ko00000_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`000008ooooo`05oa0@4?n7QhOoooooonk^k_l000001?ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Ko0000ooooooooooooooooonk^k_l00003ooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`03ooooo`05oa0@4?n7QhOooooo
onk^k_l000001?ooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooool000001?ooool01?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oo
oooo00002?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`04ooooo`04oa0@4?nj^[[oV9RHoc8b<P?ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`05okZj^_n7QhOoIVIVofIVI_l@41000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go^[ZjohN7QomVIVKoIVIVoa0@4007ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000001cooooo
000dooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000002ooooo`03okZj
^_l@413o000000;o00001?ooool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000oooooooo
ooooooooonk^k_l00002ooooo`Ko00002_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool000002?ooool00onj^[[o410@o`000002o`0000Cooooo00Go0000oooooooooooooooo
o`000002ooooo`06o`000?ooooooooooooooooo^k^ko00000oooool01Ol0003ooooooooooooooooo
000000Cooooo00?o0000ooooooooool00oooool00onj^[[o410@o`000002o`0000Cooooo00?o0000
ooooooooool02?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000Cooooo00Co
0000oooooooooooo00000_ooool01Ol0003oooooooooool0003ooooo00Ko00000oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`06oiRHV?lb
<S;oooooooooool@413o^[Zj0_ooool6o`0000?ooooo00?o0000ooooooooool01?ooool01_lb<S;o
8B4QogMgMomgMgOoQhN7onk^kP?ooooo00Go0000ooooooooooooooooo`000002ooooo`06oc8b<_lQ
8B7oMgMgogMgMon7QhOok^k^1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000005o`0001Oooooo000dooooo`06
ofIVI_mgMgOooooooooooon7QhOo00000oooool01Ol0003oMgMgoooooonYZJWo000000Gooooo00?o
c<c<o`000?ooool00oooool01Ol0003oQhN7oooooonYZJWo000000;ooooo00KoEEEEogMgMooooooo
k^k^oeEEEOl00002ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b2_ooool00ol0003ooooooooo
o`03ooooo`05o`000?n7QhOoooooojVYZOl000002oooool00oo<c<co0000ooooo`03ooooo`05o`00
0?n7QhOoooooojVYZOl000000_ooool01_mEEEGoMgMgooooooo^k^koEEEEo`0000?ooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Kooooo00?oc<c<o`000?ooool00ooo
ool00ol0003o<S8bomgMg@08ooooo`0:o`000?o<c<coc<c<o`000?nYZJWogMgMob4Q8OooooooEEEE
ogMgM`;ooooo00GoMgMgoeEEEOooooooooooo`000002olc<c00;o`000?nYZJWogMgMob4Q8Ooooooo
EEEEohN7Qoo^k^koooooohN7Qolb<S800oooool01Ol0003oQhN7oooooonYZJWo000000?ooooo00?o
0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000;ooooo00Oo0000olc<c?o<c<co
0000ojVYZOoMgMgo8B4Q00Cooooo00?ok^k^o`000?oMgMd00_ooool02_nHV9So<S8boooooooooooo
EEEEohN7Qoo^k^koooooohN7Qolb<S83ooooo`03o`000?lb<S;ogMgM00Cooooo00Ko0000okZj^_oo
ooook^k^ogMgMol00003ooooo`05o`000?ooooooooooooooool000000_ooool01_l0003o^[Zjoooo
ooo^k^koMgMgo`0000Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`0>
o`000?o<c<coc<c<o`000?nYZJWogMgMob4Q8OooooooEEEEohN7Qoo^k^koooooohN7Qolb<S8Goooo
o`00=?ooool01_o^k^koIVIVo`000?l0003oA4A4o`0000?ooooo00Go0000ogMgMol0003o0000oiRH
V003ooooo`04oc8b<_l0003o0000oiRHV0?ooooo00?o410@o`000?mgMgL00_l000003OnHV9Sooooo
ooooooo^k^koEEEEo`000?lQ8B7oZJVYo`000?l@413oooooonk^k_mEEED00_l000000om4A4Cok^k^
ooooo`07ooooo`03oa0@4?l0003o000000Cooooo00?o410@o`000?mgMgL00_l000000onHV9Sooooo
ooooo`07ooooo`04oc8b<_l0003o0000oiRHV0?ooooo00?o410@o`000?mgMgL00_l000003OnHV9So
ooooooooooo^k^koEEEEo`000?lQ8B7oZJVYo`000?l@413ooooooa0@4?l000000_ooool2o`0000Co
oooo00?o0000ooooooooool01?ooool01?lb<S;o0000o`000?nHV9P3ooooo`;o000000CoZJVYob4Q
8Ol0003o8B4Q1Oooool02ol@413o0000ob4Q8Ol0003oMgMgoa0@4?l0003oZJVYooooooo^k^koEEEE
00;o000000koEEEEonk^k_oooooo410@o`000?lQ8B7o0000ogMgMol@413o0000ojVYZOooooook^k^
oeEEE@;o000000OoA4A4onk^k_oooooooooooa0@4?l0003oMgMg00;o000000?oV9RHooooool@4100
1Ol00003ooooo`04oa0@4?l0003oooooooooo`;o000000Wooooooa0@4?l0003o8B4Qo`000?mgMgOo
410@o`000?nYZJT01?ooool00ol@413o0000o`000002ooooo`?o000000?oooooonk^k_mEEED00_l0
00001?m4A4Cok^k^ooooooooool2o`000004ojVYZOlQ8B7o0000ob4Q8@;ooooo00KoZJVYob4Q8Ol0
003o0000oc8b<_l00002ooooo`04oa0@4?l0003oooooooooo`;o00000_ooool01_nYZJWo8B4Qo`00
0?l0003o<S8bo`0000Gooooo00?o410@o`000?l000000ol00004ooooo`03oa0@4?l0003o000000?o
oooo00_o410@o`000?lQ8B7o0000ogMgMol@413o0000ojVYZOooooook^k^oeEEE@02o`000003odA4
A?o^k^kooooo01Kooooo000mooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0@?oo
ool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo037ooooo000mooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooo
oooo04gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Wooooo`00??ooool00ol@
413o0000ooooo`0]ooooo`03oa0@4?oooooooooo033ooooo00?o410@o`000?l00000W?ooool00ol@
413oooooooooo`0Wooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.243838, -0.00541057, \
0.00543053, 2.2821*^-5}}]
}, Open  ]],

Cell["\<\
It is not well conserved, because the periodic boundary conditions \
break the cylindrical symmetry required for angular momentum conservation.  \
Thus, tracking angular momentum is not particularly useful unless the \
boundaries are far from the region of interest.\
\>", "Text"],

Cell["\<\
\tA third conserved quantity is the total energy of the system, \
\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`E\_total\  = \[Sum]\+i\ p\_i\%2\/\(2  m\) + 
          1\/2\ \(\[Integral]\[Rho]\ \[Phi]\ \(\(\[DifferentialD]\^2 
                  r\)\(\ \)\)\)\)]],
  ". "
}], "NE3",
  CellTags->"(7.3.9)"],

Cell[TextData[{
  "The second term is the total gravitational potential energy ",
  Cell[BoxData[
      \(TraditionalForm\`U\)]],
  ". In order to evaluate this quantity  we write the integral as a sum over \
the grid:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{"U", " ", "=", " ", 
            
            RowBox[{\(\[Integral]\[Rho]\ \[Phi]\ \[DifferentialD]\^2 r\), 
              "\[TildeEqual]", 
              RowBox[{
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], " ", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["y",
                      FontSlant->"Italic"]}]], 
                " ", \(\[Sum]\+\(i, j = 0\)\%\(M - 1\)\(\[Rho]\_\(i\ j\)\) \
\[Phi]\_\(\(\ \)\(i\ j\)\)\)}]}]}]}], TraditionalForm]]],
  "."
}], "NE3",
  CellTags->"(7.3.10)"],

Cell[TextData[{
  "Since the potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " and the density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " are not saved from step to step, one can either reevaluate them, or  \
modify the previous code to evaluate and store the energy as the positions \
and momenta are updated. We proceed with the former approach below."
}], "Text"],

Cell[TextData[{
  "\tTo evaluate the kinetic energy, we require the momenta at the same time \
step as the positions. We could employ the averaging method that we used to \
determine the angular momentum. However, it is just as accurate, and somewhat \
faster, to write the kinetic energy at ",
  "time step",
  " ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " as"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(K(t\_n)\), "=", 
          RowBox[{\(\[Sum]\+i\), " ", 
            FractionBox[
              
              RowBox[{\(\(p\_i\)(t\_\(n - 1/2\))\), 
                " ", \(\(p\_i\)(t\_\(n + 1/2\))\), Cell[""]}], \(2  m\)]}]}], 
        TraditionalForm]]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "In Cell ",
  ButtonBox["7.82",
    ButtonData:>"Cell 7.82",
    ButtonStyle->"Hyperlink"],
  ", we evaluate the energy."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(kineticenergy[n_]\  := \ 
        Sum[\(p[n - 1/2]\)[\([i]\)] . \(p[n + 1/2]\)[\([i]\)], {i, 1, 
                Length[p[n + 1/2]]}]/\((2\ m)\) /; 
          n > 0\  && \ n \[Element] Integers;\)\), "\n", 
    \(\(kineticenergy[n_]\  := \ 
        Sum[\(p[n]\)[\([i]\)] . \(p[n]\)[\([i]\)], {i, 1, 
                Length[p[n]]}]/\((2\ m)\) /; 
          n > 0\  && \ n + 1/2 \[Element] Integers;\)\), "\n", 
    \(\(\(kineticenergy[0]\  := \ 
        Sum[\(p[0]\)[\([i]\)] . \(p[0]\)[\([i]\)], {i, 1, 
              Length[p[0]]}]/\((2\ m)\);\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(energy[n_]\  := \(energy[n]\  = 
          Module[{}, \[IndentingNewLine]Npart\  = \ 
              Length[r[n]]; \[IndentingNewLine]density[
              r[n]]; \[IndentingNewLine]fft\[Phi][\[Rho]]; \
\[IndentingNewLine]potentialenergy[n] = 
              1/2\ \[CapitalDelta]x\ \[CapitalDelta]y\ Sum[\[Rho][\([i, 
                        j]\)]\ \[Phi][\([i, j]\)], {i, 1, M}, {j, 1, 
                    M}]; \[IndentingNewLine]kineticenergy[n] + 
              potentialenergy[n]]\);\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(ListPlot[Table[{n\ \[CapitalDelta]t, energy[n]}, {n, 0, 30}], 
        PlotJoined \[Rule] True, PlotLabel -> "\<total energy\>", 
        AxesLabel \[Rule] {"\<t\>", "\<\>"}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.82"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.793651 1.85213 0.238045 [
[.18254 .17332 -9 -9 ]
[.18254 .17332 9 0 ]
[.34127 .17332 -9 -9 ]
[.34127 .17332 9 0 ]
[.5 .17332 -9 -9 ]
[.5 .17332 9 0 ]
[.65873 .17332 -9 -9 ]
[.65873 .17332 9 0 ]
[.81746 .17332 -3 -9 ]
[.81746 .17332 3 0 ]
[.97619 .17332 -9 -9 ]
[.97619 .17332 9 0 ]
[1.025 .18582 0 -6 ]
[1.025 .18582 10 6 ]
[.01131 .06679 -24 -4.5 ]
[.01131 .06679 0 4.5 ]
[.01131 .30484 -24 -4.5 ]
[.01131 .30484 0 4.5 ]
[.01131 .42386 -12 -4.5 ]
[.01131 .42386 0 4.5 ]
[.01131 .54288 -24 -4.5 ]
[.01131 .54288 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .18582 m
.18254 .19207 L
s
[(0.2)] .18254 .17332 0 1 Mshowa
.34127 .18582 m
.34127 .19207 L
s
[(0.4)] .34127 .17332 0 1 Mshowa
.5 .18582 m
.5 .19207 L
s
[(0.6)] .5 .17332 0 1 Mshowa
.65873 .18582 m
.65873 .19207 L
s
[(0.8)] .65873 .17332 0 1 Mshowa
.81746 .18582 m
.81746 .19207 L
s
[(1)] .81746 .17332 0 1 Mshowa
.97619 .18582 m
.97619 .19207 L
s
[(1.2)] .97619 .17332 0 1 Mshowa
.125 Mabswid
.06349 .18582 m
.06349 .18957 L
s
.10317 .18582 m
.10317 .18957 L
s
.14286 .18582 m
.14286 .18957 L
s
.22222 .18582 m
.22222 .18957 L
s
.2619 .18582 m
.2619 .18957 L
s
.30159 .18582 m
.30159 .18957 L
s
.38095 .18582 m
.38095 .18957 L
s
.42063 .18582 m
.42063 .18957 L
s
.46032 .18582 m
.46032 .18957 L
s
.53968 .18582 m
.53968 .18957 L
s
.57937 .18582 m
.57937 .18957 L
s
.61905 .18582 m
.61905 .18957 L
s
.69841 .18582 m
.69841 .18957 L
s
.7381 .18582 m
.7381 .18957 L
s
.77778 .18582 m
.77778 .18957 L
s
.85714 .18582 m
.85714 .18957 L
s
.89683 .18582 m
.89683 .18957 L
s
.93651 .18582 m
.93651 .18957 L
s
.25 Mabswid
0 .18582 m
1 .18582 L
s
gsave
1.025 .18582 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .06679 m
.03006 .06679 L
s
[(-7.5)] .01131 .06679 1 0 Mshowa
.02381 .30484 m
.03006 .30484 L
s
[(-6.5)] .01131 .30484 1 0 Mshowa
.02381 .42386 m
.03006 .42386 L
s
[(-6)] .01131 .42386 1 0 Mshowa
.02381 .54288 m
.03006 .54288 L
s
[(-5.5)] .01131 .54288 1 0 Mshowa
.125 Mabswid
.02381 .0906 m
.02756 .0906 L
s
.02381 .1144 m
.02756 .1144 L
s
.02381 .13821 m
.02756 .13821 L
s
.02381 .16201 m
.02756 .16201 L
s
.02381 .20962 m
.02756 .20962 L
s
.02381 .23343 m
.02756 .23343 L
s
.02381 .25723 m
.02756 .25723 L
s
.02381 .28103 m
.02756 .28103 L
s
.02381 .32864 m
.02756 .32864 L
s
.02381 .35245 m
.02756 .35245 L
s
.02381 .37625 m
.02756 .37625 L
s
.02381 .40006 m
.02756 .40006 L
s
.02381 .44767 m
.02756 .44767 L
s
.02381 .47147 m
.02756 .47147 L
s
.02381 .49527 m
.02756 .49527 L
s
.02381 .51908 m
.02756 .51908 L
s
.02381 .04299 m
.02756 .04299 L
s
.02381 .01918 m
.02756 .01918 L
s
.02381 .56669 m
.02756 .56669 L
s
.02381 .59049 m
.02756 .59049 L
s
.02381 .6143 m
.02756 .6143 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(total) show
99.000 13.000 moveto
(energy) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.05556 .55768 L
.0873 .16915 L
.11905 .34379 L
.15079 .60332 L
.18254 .37449 L
.21429 .37715 L
.24603 .54093 L
.27778 .32113 L
.30952 .54039 L
.34127 .58424 L
.37302 .25141 L
.40476 .3665 L
.43651 .50444 L
.46825 .26156 L
.5 .52564 L
.53175 .35049 L
.56349 .39046 L
.59524 .47097 L
.62698 .54707 L
.65873 .50027 L
.69048 .4178 L
.72222 .4968 L
.75397 .59849 L
.78571 .33887 L
.81746 .5763 L
.84921 .58131 L
.88095 .1323 L
.9127 .40403 L
.94444 .46076 L
.97619 .5797 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo
000Qooooo`;o0000oooooom6ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo0_l0003ooooo
odKooooo000Qooooo`;o0000oooooom6ooooo`002Oooool00ol0003ok^k^ooooo`05ooooo`;o8B4Q
1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo0_l0003oooooodKooooo0009ooooo`03oeEE
EOnYZJWooooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo0_l0003oooooodKooooo
0005o`0000Cooooo00?oZJVYoeEEEOooool04?ooool00ol0003oooooooooo`02ooooo`;o0000oooo
oom6ooooo`002_ooool00olQ8B7oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00?ooooo0ol0003o
ooooodGooooo000:ooooo`03oeEEEOo<c<cooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004
ooooo`;o0000oooooom6ooooo`002_ooool00onYZJWoMgMgooooo`0;ooooo`03o`000?oooooooooo
00Kooooo0_l0003oooooodKooooo0007ooooo`05oa0@4?oooooooooooooooolb<S803?ooool00ol0
003oooooooooo`06ooooo`;o0000oooooom6ooooo`001oooool5o`0000cooooo1?l00005ooooo`;o
0000oooooom6ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo0_l0003oooooodKooooo000Q
ooooo`?o0000oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooool0
0000oooooom5ooooo`008Oooool00ol0003oooooo`00003oooooodGooooo000Qooooo`03o`000?oo
oooo00000?ooooooAOooool0027ooooo00?o0000ooooool00000oooooom5ooooo`008Oooool00ol0
003oooooo`00003oooooodGooooo000Qooooo`03o`000?oooooo00000?ooooooAOooool0027ooooo
0ol0003oooooodGooooo000Qooooo`03o`000?oooooo00000?ooooooAOooool0027ooooo00?o0000
ooooool00000oooooom5ooooo`008Oooool00ol0003oooooo`00003oooooodGooooo000Qooooo`03
o`000?oooooo00000?ooooooAOooool0027ooooo00?o0000ooooool00000ooooool:ooooo`03o`00
0?oooooooooo03Sooooo000Qooooo`03o`000?oooooo00000?oooooo2_ooool00ol0003ooooooooo
o`0hooooo`008Oooool3o`000?oooooo2_ooool00ol0003oooooooooo`0hooooo`008Oooool00ol0
003oooooo`00003oooooo`[ooooo00?o0000ooooooooool0>?ooool0027ooooo00?o0000ooooool0
00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00007Oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool06_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0
7Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q
8Oo<c<`09Oooool4o`000003oa0@4?oooooooooo00oooooo00?o0000ooooooooool04Oooool4o`00
0003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`Go00004oooool0027ooooo00?o0000ooooool0
00009?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@07Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oo
oooooooo01_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMg
oooooonHV9So8B4Q01gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ
8B7oV9RHoooooonHV9So8B4Q02Oooooo00?o0000ooooooooool04Oooool2o`0001Cooooo00?o0000
ooooooooool01?ooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Cooooo`008Oooool0
1?l0003oooooooooool0000Sooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Q
onk^kP0Nooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0001cooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000007Oooool01Ol@413ooooooooooooo
oooo410@00_ooooo00Go0000ooooooooooooooooo`00000Wooooo`03o`000?oooooooooo017ooooo
0_l0000Dooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h05?ooool0027ooooo00Co
0000oooooooooooo00008oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^
k^h07Oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00007Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Mooooo`05o`00
0?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b02Oooooo00?o0000oooo
ooooool04Oooool2o`0001Cooooo00?o0000ooooooooool03?ooool00onHV9So8B4Qonk^kP0Coooo
o`008Oooool01?l0003oooooooooool0000Sooooo`05o`000?ooooooooooooooool000003_ooool0
0omgMgOoIVIVooooo`0Looooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEoooo
ool0000Mooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<
01gooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`09ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooo000001Cooooo00?o0000ooooooooool03Ooo
ool00omgMgOoIVIVooooo`0Booooo`008Oooool4o`0002?ooooo00Go410@oooooooooooooooooa0@
400?ooooo`03o`000?oooooooooo01_ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMg
Moo<c<co000001gooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo01oo
oooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41009oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooo000001Cooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0Aooooo`008Oooool01?l0003oooooooooool0000Sooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@01gooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0<ooooo`03onk^k_m4A4Co000001gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`03omgMgOl@413oV9RH01oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooookZj^_l000009oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo000001Cooooo00?o
0000ooooooooool02_ooool01Ol0003o^[ZjoooooonHV9So410@01?ooooo000Qooooo`04o`000?oo
ooooooooo`0002?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`07Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool07?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@7Oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0Uooooo`03oeEEEOmVIVKo0000
01;ooooo00?o0000ooooool000004_ooool00omEEEGoIVIVo`00000<ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`04oooool0027ooooo00Co0000oooooooooooo00004?ooool00ol0003oooooooooo`3d
ooooo`03o`000?oooooo000003Wooooo000Qooooo`04o`000?ooooooooooo`00013ooooo00?o0000
ooooooooool0m?ooool00ol0003oooooo`00000iooooo`008Oooool01?l0003oooooooooool0000@
ooooo`03o`000?oooooooooo0?Cooooo00Co0000oooooooooooo0000;oooool01OnHV9So0000o`00
0?m4A4Co^[Zj00Cooooo000Qooooo`04o`000?ooooooooooo`00013ooooo00?o0000ooooooooool0
m?ooool01?l0003oooooooooool0000_ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool0027o
oooo00Co0000oooooooooooo00004?ooool2o`000?Gooooo00Co0000oooooooooooo0000;oooool0
0ol0003oooooooooo`06ooooo`006_ooooooo`0003[o00003?ooool00ol0003oooooooooo`06oooo
o`008Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Cooooo0_l00003oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00Kooooo000Qooooo`04o`000?ooooooooooo`0000oooooo00?o0000
ooooool000007?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo013ooooo00Co0000
oooooooooooo00006oooool00ol0003oooooooooo`0?ooooo`03oa0@4?l0003o000000?o00001Ooo
ool0027ooooo00Co0000oooooooooooo00003oooool00ol0003oooooo`00003eooooo`04o`000?oo
ooooooooo`0002oooooo00?o0000ooooooooool01_ooool0027ooooo00Co0000oooooooooooo0000
3oooool01?l0003oooooooooool0003dooooo`04o`000?ooooooooooo`0002oooooo00?o0000oooo
ooooool01_ooool0027ooooo00Co0000oooooooooooo00003oooool01?l0003oooooooooool0003c
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=Oooool0027ooooo00Go0000oooo
ooooooooooooo`00000>ooooo`04o`000?ooooooooooo`000??ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0eooooo`008Oooool3o`000003ooooool0003ooooo00gooooo00Co0000
oooooooooooo0000loooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Gooooo000Q
ooooo`05o`000?ooooooooooooooool000003_ooool01?l0003oooooooooool0003cooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0=Oooool0027ooooo00Go0000oooooooooooooooo
o`00000>ooooo`05o`000?ooooooooooooooool00000l_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo03Gooooo000Qooooo`05o`000?ooooooooooooooool000003_ooool01Ol0003o
oooooooooooooooo00000?;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0eoooo
o`008Oooool01Ol0003ooooooooooooooooo000000kooooo00Go0000ooooooooooooooooo`00003b
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=Oooool0027ooooo00Go0000oooo
ooooooooooooo`00000>ooooo`05o`000?ooooooooooooooool00000l_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo03Gooooo000Qooooo`05o`000?ooooooooooooooool000003_oo
ool01Ol0003ooooooooooooooooo00000?;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0eooooo`008Oooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`3`ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
=?ooool0027ooooo0ol000000ooooooo0000ooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0koooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Cooooo000Q
ooooo`05o`000?ooooooooooooooool000003Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo0>oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0dooooo`008Oooool0
1Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`3_ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0=?ooool0027ooooo00Go0000
ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0kooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Cooooo000Qooooo`05o`000?oooooo
ooooooooool000003Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0>kooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0dooooo`008Oooool01Ol0003ooooooooooooo
oooo000000gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Aooooo`03o`000?oo
oooooooo09Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0dooooo`008Oooool0
1Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`1Aooooo`03o`000?oooooooooo09Wooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0dooooo`008Oooool3o`000003ooooool0003ooooo00cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1Aooooo`03o`000?oooooooooo09Wooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0cooooo`008Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Aooooo`;o0000V_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo03?ooooo000Qooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo057o
oooo0_l0000Looooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0cooooo`008Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Aooooo`;o00007?ooool00ol0003ooooo
ooooo`1kooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<oooool0027ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0D?ooool00ol0003oooooo`00000Kooooo`03o`000?oooooooooo07_ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0cooooo`008Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1?
ooooo`04o`000?ooooooooooo`0001_ooooo00?o0000ooooooooool0Noooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo03?ooooo000Qooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04oooooo00Co0000
oooooooooooo00006oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0<oooool0027ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Coooool01?l0003oooooooooool0
000Jooooo`03o`000?oooooo000007cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0cooooo`008Oooool3o`0000;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo04oooooo00Go0000ooooooooooooooooo`00000Iooooo`03o`000?oo
oooo000007cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0cooooo`008Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1>ooooo`05o`000?ooooooooooooooool000006Oooool00ol0003oooooo`00
001looooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0<_ooool0027ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0C_ooool01Ol0003ooooooooooooooooo000001Wooooo00?o0000ooooool00000O?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03;ooooo000Qooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo04kooooo00Go0000ooooooooooooooooo`00000Iooooo`03o`000?oooooo000007_ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0booooo`008Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1>
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05_ooool00ol0003oooooo`00001k
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<_ooool000Oooooo00Gok^k^oc8b
<_l0003o410@olc<c005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0C_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooool00000Noooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03;ooooo0007
ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05Ooo
ool01?l0003oooooooooool0001kooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
<_ooool000Go00000_ooool01Ol0003ooooooooooooooooo0000013ooooo00?o0000ooooooooool0
0_ooool3o`0000;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo04gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Dooooo`05o`00
0?ooooooooooooooool00000N_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03;o
oooo0007ooooo`05o`000?nHV9SooooooiRHV?lQ8B403oooool00omgMgOo<S8booooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo04cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Dooooo`05
o`000?ooooooooooooooool00000N_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
03;ooooo0007ooooo`05o`000?mEEEGo0000oa0@4?o<c<`03?ooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01Cooooo00Go0000ooooooooooooooooo`00001jooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0<Oooool000Oooooo00?oEEEEohN7Qoooool03_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0D
ooooo`05o`000?ooooooooooooooool00000N_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo037ooooo0007ooooo`03omgMgOl@413oV9RH00kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`1<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool0
1Ol0003ooooooooooooooooo000007[ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0aooooo`002?ooool01?o<c<coA4A4o`000?l@410<ooooo`Co00001Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Cooooo`05o`000?ooooooooooooooool00000N_ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo037ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo00Go0000oooooooooooooooo
o`00001jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0<Oooool0027ooooo0ol0
0003ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0N?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo037ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0<Oooool0027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0;oooool00ol0003oooooo`00000Ioooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo07Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0aoooo
o`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo000001Wooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0M_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo037ooooo000Qooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooool000006Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Mooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0`ooooo`008Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooo000001Wooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0GOoo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0<?oo
ool0027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool0;_ooool00ol0003oooooo`00000Hooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo05gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo033ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo02kooooo00?o0000ooooool000006?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo033ooooo000Qooooo`?o00000oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooo`00000Hooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0C?ooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0<?ooool0027ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0;Oooool01Ol0003ooooooooooooooooo000001Oooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool03_ooool2o`0004cooooo00?o0000ooooool000005oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo033ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02cooooo00Go0000oooooooooooo
ooooo`00000Gooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00gooooo00?o0000ooooool00000Boooool00ol0003o
ooooo`00000Gooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0<?ooool0027ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0;?ooool01Ol0003ooooooooooooooooo000001Oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool03?ooool01Ol0003ooooooooooooooooo000004[ooooo00?o0000ooooool000005oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo033ooooo000Qooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02co
oooo00Go0000ooooooooooooooooo`00000Gooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo00Go0000oooo
ooooooooooooo`00001:ooooo`03o`000?oooooo000001Oooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0_ooooo`008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0/ooooo`05o`000?oooooooooo
ooooool000005oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0Aoooool00ol0003oooooo`00000Gooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0;oooool0027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0;?ooool01Ol0003ooooooooooooooooo
000001Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo04Kooooo00?o0000ooooool000005oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo02oooooo000Qooooo`?o00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool04?ooool6o`0001Kooooo00Go0000ooooooooooooooooo`00000G
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`15
ooooo`03o`000?oooooo000001Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0_
ooooo`008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00?ooooo1Ol0000@oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0A?ooool01?l0003oooooooooool0000F
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0;oooool0027ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`13ooooo`05o`000?ooooooooooooooool000005Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02oooooo000Qooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0@_ooool01Ol0003ooooooooooooooooo000001Gooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0_ooooo`008Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo047ooooo00Go0000ooooooooooooooooo`00000Eooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool0;oooool0027ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`10ooooo`05o`000?ooooooooooooooool000005Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo02oooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0@?ooool01Ol0003ooooooooooooooooo000001Gooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0^ooooo`008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
03oooooo00Go0000ooooooooooooooooo`00000Eooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0;_ooool0027ooooo0ol00004ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool0;_ooool0027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo02kooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
?Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0^ooooo`008Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo03gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0;Oooool0027ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0looooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02gooooo000Gooooo`05onk^k_lb<S;o0000
oa0@4?o<c<`01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0/ooooo`005oooool01OmEEEGoMgMgoooooonHV9So
8B4Q00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0:oooool000oooooo1_l00002ooooo`05o`000?oooooooooo
ooooool000001Oooool3o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08?ooool00ol0003oooooo`00000H
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo02_ooooo000Gooooo`05o`000?nHV9SooooooiRHV?lQ8B401Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo023ooooo00?o0000ooooool000006?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0Zooooo`005oooool01Ol0003oEEEEo`000?l@413oc<c<00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo000001Sooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0:_ooool001Oooooo00?oEEEEohN7Qoooool01oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo01kooooo00Go0000ooooooooooooooooo`00000Fooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo02Wooooo000Gooooo`03omgMgOl@413oV9RH00Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Nooooo`05o`000?ooooooooooooooool000005_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Y
ooooo`006?ooool01?o<c<coA4A4o`000?l@4105ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0:?ooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Xoooo
o`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02Oooooo000Qooooo`?o0000
1Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0Vooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo02Kooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool09Oooool0
027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Uooooo`008Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo02Cooooo000Qooooo`03o`000?oooooooooo00Gooooo
00Go0000ooooooooooooooooo`00000Fooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool09?ooool0027ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000001Ko
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Tooooo`008Oooool3o`0000Gooooo
00Go0000ooooooooooooooooo`00000Fooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0Eooooo`04o`000?ooooooooooo`00013ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02?ooooo000Qooooo`03
o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`00000Fooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Eooooo`04o`000?oooooooooo
o`00013ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo02?ooooo000Qooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo00005_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05Oooool0
1?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Sooooo`008Oooool00ol0003oooooooooo`06ooooo`04o`000?oooooo
ooooo`0001Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo01Gooooo00Co0000oooooooooooo00004?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool08oooool0027ooooo00?o0000ooooooooool01_oo
ool01?l0003oooooooooool0000Fooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0Eooooo`04o`000?ooooooooooo`00013ooooo00Go0000oooooooo
ooooooooo`00000Looooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo02;ooooo000Qooooo`03o`000?oooooooooo00Ko
oooo00Co0000oooooooooooo00005_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool05_ooool00ol0003oooooo`00000@ooooo`05o`000?oooooooooo
ooooool000007Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Rooooo`008Oooool00ol0003oooooooooo`06oooo
o`04o`000?ooooooooooo`0001Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooool000004Oooool01?l0003oooooooooool0
000Mooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo02;ooooo000Qooooo`03o`000?oooooooooo00Kooooo00Co0000
oooooooooooo00005oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool05oooool2o`0001;ooooo00Co0000oooooooooooo00007_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Qooooo`008Oooool3o`0000Kooooo00Co0000oooooooooooo00005oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05oooool2o`0001;ooooo
00Co0000oooooooooooo00007_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Qooooo`008Oooool00ol0003ooooo
ooooo`06ooooo`04o`000?ooooooooooo`0001Oooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool04?ooool01?l0003o
ooooooooool0000Oooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo027ooooo000Qooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooool000006?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo0000023ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool08Oooool0027ooooo00?o0000ooooooooool01_ooool00ol0003oooooo`00000Hooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool05Oooool01Ol0003ooooooooooooooooo0000
00oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo0000
023ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool08?ooool0027ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooo`00000Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05Oooool01Ol0003o
oooooooooooooooo000000oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0[oooo
o`03o`000?oooooo0000027ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool08?ooool0027ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooo`00000Hooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool05Oooool01?l0003oooooooooool0000Aooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0:oooool00ol0003oooooo`00000Qooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo023ooooo000Qooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooool000006Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo01Gooooo00Co0000oooooooooooo00004Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo02cooooo0_l0000Rooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo023ooooo000Qooooo`?o
00001_ooool00ol0003oooooo`00000Iooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool05_ooool00ol0003oooooo`00000Aooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01oooooo000Qooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooool000006Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooool000004Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Oooooo`008Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooo000001Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooo0000017ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool07ooo
ool0027ooooo00?o0000ooooooooool01_ooool00ol0003oooooo`00000Iooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool05oooool00ol0003oooooo`00000Aooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Nooooo`008Oooool00ol0
003oooooooooo`07ooooo`;o00006Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooool000004Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
05?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool07_ooool000Sooooo00GoA4A4o`000?l0003o<S8bomgMg@04oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool01oooool2
o`0001Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo01kooooo000;ooooo`03ogMgMolb<S;ooooo00?ooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
00?ooooo00?o0000ooooooooool01oooool2o`0001Wooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`1Dooooo`04o`000?ooooooooooo`0001kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0Nooooo`001Ol00007ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool00_ooool3o`0000Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo05Cooooo00Co0000oooooooooooo00007_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo01gooooo000;ooooo`03ogMgMolb<S;ooooo00gooooo00?oMgMgoc8b
<_ooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0E?ooool00ol0003oooooo`00000Pooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool07Oooool000Sooooo00Go0000ob4Q8Ol0003o<S8bolc<c00;ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Wooooo00Go0000
ooooooooooooooooo`00000`ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0EOoo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool07Ooo
ool000Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool06Oooool01Ol0003ooooooooooooooooo0000037ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool07Oooool000Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06Oooool01Ol0003ooooooooooooo
oooo000003;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1gooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool07?ooool000Sooooo1?l0000<ooooo`Co00001Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Wooooo00Go0000ooooooooooooooooo`00
000booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0N?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo01cooooo000Qooooo`03o`000?oooooooooo02?ooooo00Go0000
ooooooooooooooooo`00000cooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0N?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01cooooo000Qooooo`03o`000?oooooo
oooo02?ooooo00Go0000ooooooooooooooooo`00000dooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0N?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01_ooooo000Q
ooooo`?o00009?ooool01?l0003oooooooooool0000eooooo`05o`000?ooooooooooooooool00000
O?ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo01_ooooo000Qooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooool00000=oooool01?l0003oooooooooool0001looooo`05o`000?oooooooooooooo
ool000004_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool06oooool0027ooooo00?o0000ooooooooool09?ooool00ol0003oooooo`00000gooooo`04
o`000?ooooooooooo`0007cooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Kooooo`008Oooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooo000003Sooooo00?o0000ooooool00000OOooool01?l0
003oooooooooool0000Booooo`Ko00001?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01[ooooo000Qooooo`03o`000?oooooooooo02Cooooo00?o0000ooooool00000>Oooool2o`00
07gooooo00Co0000oooooooooooo00006?ooool5o`0002Oooooo00?o0000ooooooooool06_ooool0
027ooooo00?o0000ooooooooool09?ooool00ol0003oooooo`00000jooooo`03o`000?oooooooooo
07_ooooo00Co0000oooooooooooo0000HOooool0027ooooo00?o0000ooooooooool09?ooool00ol0
003oooooo`00002iooooo`03o`000?oooooo0000067ooooo000Qooooo`?o00009?ooool00ol0003o
ooooo`00002iooooo`;o0000H_ooool0027ooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`2hooooo`;o0000H_ooool0027ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`2iooooo`03o`000?oooooooooo063ooooo000Qooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0^Oooool00ol0003oooooooooo`1Pooooo`008Oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo0?oooooo7Oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00=Sooooo00Ko8B4Qo`00
0?l0003oA4A4omgMgOooool3o`000003oa0@4?oooooooooo08Cooooo003Kooooo`03ogMgMolb<S;o
oooo00;ooooo00?o410@okZj^_ooool0QOooool00=cooooo00Ko0000oooooooooooooooooiRHV?lb
<S:6ooooo`00Roooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00Kok^k^oeEEEOl0003o0000
oeEEEOo^k^h3ooooo`05oiRHV?l0003o0000odA4A?nj^[X00_ooool01_nHV9So0000o`000?mgMgOo
410@o`0000;ooooo1Ol00008ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj0_ooool01?l@413o
0000o`000?ooool2o`000004oa0@4?ooooook^k^oeEEE@;o000000CoA4A4okZj^_oooooo410@1Ol0
0003ooooo`06onk^k_mEEEGo0000oa0@4?o<c<co00000oooool00ooMgMgo0000okZj^P25ooooo`00
Roooool01Ol@413o^[Zjonk^k_mgMgOo410@00;ooooo00KoEEEEogMgMoooooooooooogMgMomEEED3
ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool01Ol0003oc<c<onk^k_n7QhOo000000Gooooo
00?o0000ooooooooool02?ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40?ooooo00Go0000oooo
ooooooooooooo`000002ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0oooool00ol0003ooooo
ooooo`04ooooo`06oeEEEOmgMgOoooooonk^k_mEEEGo00000oooool00omEEEGoMgMgodA4A025oooo
o`00Roooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000006ooooo`05oa0@4?n7QhOoooooonk^k_l000001Oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01?ooool01_l0003oooooooooooooooook^k^o`0000;o
oooo00GogMgMoa0@4?oooooo8B4QomgMg@24ooooo`00Roooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03okZj^_l@413o0000
00;o00001Oooool00ol0003oooooooooo`08ooooo`Ko00000oooool01Ol0003ooooooooooooooooo
000000;ooooo1_l00003ooooo`03o`000?oooooooooo00Cooooo00Ko0000ooooooooooooooooonk^
k_l00002ooooo`05ofIVI_n7QhOooooooiRHV?mEEED0Q?ooool008_ooooo00?o0000ooooooooool0
1?ooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@?ooooo00?o0000ooooooooool01oooool00oo<
c<co0000ooooo`04ooooo`03o`000?oooooooooo00Sooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb
<S83ooooo`05o`000?n7QhOoooooojVYZOl000000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b
<P?ooooo00?o0000oc8b<_oMgMd01?ooool02_mEEEGoMgMgooooooo^k^koEEEEo`000?ooooook^k^
o`000?o^k^h2ooooo`03o`000?oMgMgooooo08;ooooo0029ooooo`03oa0@4?l0003o000000?o0000
0oooool02?o^k^koEEEEo`000?l0003oEEEEonk^k_oooooo410@1Ol00004ooooo`04oc8b<_l0003o
0000oiRHV0Gooooo00?o0000ooooooooool02?ooool01_o^k^koEEEEo`000?l0003oA4A4onk^kP;o
oooo00?o410@o`000?mgMgL00_l000001OnHV9Soooooooooooo^k^koEEEE00;o000000CoA4A4onk^
k_oooooooooo0_l000001?nYZJWo8B4Qo`000?lQ8B42ooooo`06onk^k_mEEEGo0000ob4Q8OnYZJWo
00000_l@4102o`000004ooooool0003o0000oa0@48?ooooo002;ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2iooooo`00Roooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0^Oooool00:[ooooo00?o
410@o`000?l00000^oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.136823, -7.84456, \
0.00504448, 0.0168185}}]
}, Open  ]],

Cell["\<\
Surprisingly, the energy is not well conserved, although the \
particle dynamics is apparently correct.\
\>", "Text"],

Cell[TextData[{
  "\tAs a further check, the kinetic and potential energies are shown in Cell \
",
  ButtonBox["7.83",
    ButtonData:>"Cell 7.83",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(p1 = \ 
        ListPlot[
          Table[{n\ \[CapitalDelta]t, potentialenergy[n]}, {n, 0, 30}], 
          PlotJoined \[Rule] True, PlotStyle \[Rule] RGBColor[0, 0, 1], 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(p2 = \ 
        ListPlot[Table[{n\ \[CapitalDelta]t, kineticenergy[n]}, {n, 0, 30}], 
          PlotJoined \[Rule] True, PlotStyle \[Rule] RGBColor[1, 0, 0], 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(Show[p1, p2, DisplayFunction \[Rule] $DisplayFunction, 
        AxesLabel \[Rule] {"\<t\>", "\<\>"}, 
        PlotLabel \[Rule] \ 
          TableForm[{{StyleForm["\<kinetic\>", 
                  FontColor \[Rule] RGBColor[1, 0, 0]], "\< and \>", 
                StyleForm["\<potential\>", 
                  FontColor \[Rule] RGBColor[0, 0, 1]], "\< energy\>"}}, 
            TableSpacing \[Rule] 0]];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.83"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.793651 0.542755 0.0605636 [
[.18254 .53026 -9 -9 ]
[.18254 .53026 9 0 ]
[.34127 .53026 -9 -9 ]
[.34127 .53026 9 0 ]
[.5 .53026 -9 -9 ]
[.5 .53026 9 0 ]
[.65873 .53026 -9 -9 ]
[.65873 .53026 9 0 ]
[.81746 .53026 -3 -9 ]
[.81746 .53026 3 0 ]
[.97619 .53026 -9 -9 ]
[.97619 .53026 9 0 ]
[1.025 .54276 0 -6 ]
[1.025 .54276 10 6 ]
[.01131 .05825 -12 -4.5 ]
[.01131 .05825 0 4.5 ]
[.01131 .17937 -12 -4.5 ]
[.01131 .17937 0 4.5 ]
[.01131 .3005 -12 -4.5 ]
[.01131 .3005 0 4.5 ]
[.01131 .42163 -12 -4.5 ]
[.01131 .42163 0 4.5 ]
[.5 .63053 -86 0 ]
[.5 .63053 86 12.3125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .54276 m
.18254 .54901 L
s
[(0.2)] .18254 .53026 0 1 Mshowa
.34127 .54276 m
.34127 .54901 L
s
[(0.4)] .34127 .53026 0 1 Mshowa
.5 .54276 m
.5 .54901 L
s
[(0.6)] .5 .53026 0 1 Mshowa
.65873 .54276 m
.65873 .54901 L
s
[(0.8)] .65873 .53026 0 1 Mshowa
.81746 .54276 m
.81746 .54901 L
s
[(1)] .81746 .53026 0 1 Mshowa
.97619 .54276 m
.97619 .54901 L
s
[(1.2)] .97619 .53026 0 1 Mshowa
.125 Mabswid
.06349 .54276 m
.06349 .54651 L
s
.10317 .54276 m
.10317 .54651 L
s
.14286 .54276 m
.14286 .54651 L
s
.22222 .54276 m
.22222 .54651 L
s
.2619 .54276 m
.2619 .54651 L
s
.30159 .54276 m
.30159 .54651 L
s
.38095 .54276 m
.38095 .54651 L
s
.42063 .54276 m
.42063 .54651 L
s
.46032 .54276 m
.46032 .54651 L
s
.53968 .54276 m
.53968 .54651 L
s
.57937 .54276 m
.57937 .54651 L
s
.61905 .54276 m
.61905 .54651 L
s
.69841 .54276 m
.69841 .54651 L
s
.7381 .54276 m
.7381 .54651 L
s
.77778 .54276 m
.77778 .54651 L
s
.85714 .54276 m
.85714 .54651 L
s
.89683 .54276 m
.89683 .54651 L
s
.93651 .54276 m
.93651 .54651 L
s
.25 Mabswid
0 .54276 m
1 .54276 L
s
gsave
1.025 .54276 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .05825 m
.03006 .05825 L
s
[(-8)] .01131 .05825 1 0 Mshowa
.02381 .17937 m
.03006 .17937 L
s
[(-6)] .01131 .17937 1 0 Mshowa
.02381 .3005 m
.03006 .3005 L
s
[(-4)] .01131 .3005 1 0 Mshowa
.02381 .42163 m
.03006 .42163 L
s
[(-2)] .01131 .42163 1 0 Mshowa
.125 Mabswid
.02381 .08853 m
.02756 .08853 L
s
.02381 .11881 m
.02756 .11881 L
s
.02381 .14909 m
.02756 .14909 L
s
.02381 .20966 m
.02756 .20966 L
s
.02381 .23994 m
.02756 .23994 L
s
.02381 .27022 m
.02756 .27022 L
s
.02381 .33078 m
.02756 .33078 L
s
.02381 .36106 m
.02756 .36106 L
s
.02381 .39135 m
.02756 .39135 L
s
.02381 .45191 m
.02756 .45191 L
s
.02381 .48219 m
.02756 .48219 L
s
.02381 .51247 m
.02756 .51247 L
s
.02381 .02797 m
.02756 .02797 L
s
.02381 .57304 m
.02756 .57304 L
s
.02381 .60332 m
.02756 .60332 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -147 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.3125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(kinetic) show
105.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
105.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
111.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(and) show
135.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
135.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
135.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(potential) show
189.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
189.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
195.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(energy) show
231.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
0.000 0.000 0.000 setrgbcolor
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .01472 m
.05556 .1579 L
.0873 .06172 L
.11905 .10936 L
.15079 .17855 L
.18254 .12321 L
.21429 .12589 L
.24603 .16818 L
.27778 .11134 L
.30952 .16499 L
.34127 .17336 L
.37302 .08572 L
.40476 .11196 L
.43651 .14448 L
.46825 .08155 L
.5 .14972 L
.53175 .1077 L
.56349 .12101 L
.59524 .14469 L
.62698 .16682 L
.65873 .15685 L
.69048 .13635 L
.72222 .15545 L
.75397 .17936 L
.78571 .11085 L
.81746 .1684 L
.84921 .16663 L
.88095 .04987 L
.9127 .11795 L
.94444 .13354 L
.97619 .16629 L
s
1 0 0 r
.02381 .60332 m
.05556 .59827 L
.0873 .5956 L
.11905 .5924 L
.15079 .58924 L
.18254 .58635 L
.21429 .58436 L
.24603 .58373 L
.27778 .58465 L
.30952 .58679 L
.34127 .58957 L
.37302 .59254 L
.40476 .59558 L
.43651 .59815 L
.46825 .59928 L
.5 .5983 L
.53175 .59576 L
.56349 .59262 L
.59524 .58942 L
.62698 .58666 L
.65873 .58472 L
.69048 .58424 L
.72222 .58523 L
.75397 .5872 L
.78571 .58965 L
.81746 .59252 L
.84921 .59556 L
.88095 .59808 L
.9127 .59914 L
.94444 .59798 L
.97619 .59548 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003o4oooool0
0ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool001?o
oooo00?o0000ooooooooool0oooooomCooooo`004oooool00ol0003oooooooooo`3ooooooe?ooooo
000Cooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo00?o003oooooooooool0oooooomC
ooooo`004oooool00ol00?ooooooooooo`3ooooooe?ooooo000Cooooo`03o`00oooooooooooo0?oo
ooooDoooool001?ooooo00?o0000o`00ooooool0oooooomCooooo`004oooool00ol0003o003ooooo
o`3ooooooe?ooooo000Cooooo`03o`000?l00?oooooo0?ooooooDoooool001?ooooo00?o0000o`00
ooooool0oooooomCooooo`004oooool00ol0003o003oooooo`3ooooooe?ooooo000Cooooo`03o`00
0?oooooo003o0?ooooooDoooool001?ooooo00?o0000ooooool00?l0oooooomCooooo`004oooool0
0ol0003oooooo`00o`3ooooooe?ooooo000Cooooo`03o`000?oooooo003o0?oooooo5_ooool00ol0
0?ooooooooooo`0jooooo`002?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000oooo
ool00?l0oooooolFooooo`03o`00oooooooooooo03[ooooo0008ooooo`05ob4Q8OnHV9SooooooiRH
V?lQ8B401_ooool01?l0003oooooooooool00?oooooooaGooooo0_l00?lkooooo`001_l00002oooo
o`05o`000?ooooooooooooooool000001_ooool3o`000003o`00oooooooooooo0?oooooo4_ooool0
0ol00?ooooooo`00o`0kooooo`002?ooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00Co0000
oooooooooooo003o4?ooool00ol00?ooooooooooo`3oooooo`7ooooo00Co003ooooooooooooo003o
>_ooool000Sooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`04o`000?ooooooooooo`00oa3o
oooo00?o003oooooooooool0ooooool1ooooo`04o`00ooooooooooooo`00oc[ooooo0008ooooo`05
oa0@4?nj^[[ooooookZj^_l@41001_ooool01Ol0003ooooooooooooooooo003o00oooooo0_l00?oo
ooooo`7ooooo00Go003oooooooooooooooooo`00o`0jooooo`002?ooool01Ol0003o^[Zjoooooonj
^[[o000000Kooooo00Go0000ooooooooooooooooo`00o`0>ooooo`04o`00ooooooooooooo`00oooo
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0gooooo`002?ooool01OnYZJWo410@
o`000?l@413oZJVY00Kooooo00Go0000ooooooooooooooooo`00o`0>ooooo`04o`00oooooooooooo
o`00oooooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0gooooo`004oooool01Ol0
003ooooooooooooooooo003o00kooooo00Go003oooooooooooooooooo`00o`3nooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool0=_ooool001?ooooo00Go0000ooooooooooooooooo`00
o`0=ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0n_ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo03Kooooo000Cooooo`03o`000?oooooooooo00;ooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo07Kooooo00?o003o
ooooooooool0POooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo03Gooooo000Coooo
o`03o`000?oooooooooo00;ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo05Kooooo0_l00?lMooooo`03o`00oooooooooooo087ooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`0eooooo`004oooool2o`0000?ooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo05Gooooo00?o003oooooool0
0?l06oooool00ol00?ooooooo`00o`21ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool0=Oooool001?ooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00Oooooo00?o003oooooooooool0Doooool01Ol00?oooooooooooooooooo003o01[o
oooo00?o003oooooool00?l0POooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo03Co
oooo000Cooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`07ooooo`03o`00oooooooooooo05?ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`0Fooooo`05o`00ooooooooooooooooool00?l0P?ooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo03Cooooo000Cooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool0
1oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo05;ooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`0Eooooo`05o`00ooooooooooooooooool00?l0P?ooool00ol00?oo
ooooooooo`08ooooo`03o`00oooooooooooo03?ooooo000Cooooo`03o`000?oooooooooo00?ooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo053ooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool0O?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo03?ooooo
000Cooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool01oooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo053ooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0Booooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0O?ooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo03;ooooo000Cooooo`03o`000?oooooooooo00?ooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo04oooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool03oooool2o`00of_ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0b
ooooo`004oooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool03Oooool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo01Wooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool03_ooool01?l00?ooooooo`00ool00?m?ooooo`03o`00oooooooooooo01Kooooo00?o003o
ooooooooool02oooool00ol00?ooooooooooo`0booooo`004oooool00ol0003oooooooooo`04oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0aoooo
o`03o`00oooooooooooo01Wooooo00?o003oooooooooool02_ooool2o`00o`kooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00;ooooo0_l00?m=oooo
o`03o`00oooooooooooo01Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0aoooo
o`004oooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool03_ooool00ol00?ooooooooooo`0_ooooo`03o`00oooooooo003o01Wooooo00?o003ooooooooo
ool03Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003ooooooooo
ool02oooool00ol00?ooooooooooo`05ooooo`;o003oB_ooool00ol00?ooooooo`00o`0Gooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool0<Oooool001?ooooo0_l00005ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0_ooooo`03o`00
oooooooo003o01Wooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`;o003o
B?ooool00ol00?ooooooo`00o`0Gooooo`03o`00oooooooooooo00gooooo0_l00?laooooo`004ooo
ool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool04?oo
ool00ol00?ooooooooooo`0@ooooo`Ko003o5oooool01Ol00?oooooooooooooooooo003o01Sooooo
00?o003oooooooooool03oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`;o003oAOooool01Ol00?oooooo
oooooooooooo003o01Gooooo00?o003oooooooooool04?ooool2o`00oboooooo000Cooooo`03o`00
0?oooooooooo00Gooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00
oooooooooooo013ooooo00?o003oooooooooool00oooool5o`00oa7ooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0
3Oooool00ol00?ooooooooooo`12ooooo`05o`00ooooooooooooooooool00?l05Oooool00ol00?oo
ooooooooo`0Booooo`?o003o;?ooool001?ooooo00?o0000ooooooooool01Oooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool03_ooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`0Dooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`0;ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03oooool2o`00od7ooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01Gooooo
0_l00?lZooooo`004oooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool04_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01;ooooo00?o
003oooooooooool05?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo03kooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01Oooooo0_l0
0?lXooooo`004oooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool04_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00_ooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01;ooooo00?o003o
ooooooooool05Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00gooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo03cooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo01[ooooo00?o003o
ooooooooool09Oooool001?ooooo00?o0000ooooooooool01Oooool01Ol00?oooooooooooooooooo
003o01Kooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooo
oooo01Kooooo00Co003ooooooooooooo003o4?ooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo01Gooooo0_l00?lPooooo`?o003o6Oooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo013ooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Tooooo`004oooool0
0ol0003oooooooooo`06ooooo`04o`00ooooooooooooo`00oaKooooo00?o003oooooooooool02ooo
ool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo01Sooooo00?o003oooooool00?l04?oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool06ooo
ool2o`00o`?ooooo0_l00?lFooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03ooo
ool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo02?ooooo000Cooooo`03o`000?oooooo
oooo00Kooooo00Co003ooooooooooooo003o5oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00oooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00oooooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`0@ooooo`04o`00oooo
ooooooooo`00oacooooo0_l00?lIooooo`;o003o1oooool00ol00?ooooooooooo`0Cooooo`03o`00
oooooooooooo00Sooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Nooooo`03o`00
oooooooooooo02;ooooo000Cooooo`03o`000?oooooooooo00Kooooo00?o003oooooool00?l06?oo
ool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool0;?oo
ool00ol00?ooooooo`00o`0Oooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool02?oo
ool2o`00oa;ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooo
oooooooo01oooooo00?o003oooooooooool08Oooool001?ooooo0_l00007ooooo`03o`00oooooooo
003o01Wooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooo
oooo02kooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`0Booooo`;o003o3Oooool2
o`00oa3ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo023ooooo00?o003oooooooooool08?ooool001?ooooo00?o0000ooooooooool01_ooool00ol0
0?ooooooo`00o`0Iooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool04oooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`1Aooooo`;o003o4?ooool2o`00oa7ooooo00?o003oooooooooool03Oooool00ol0
0?ooooooooooo`0:ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool08Oooool00ol0
0?ooooooooooo`0Oooooo`004oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo01Wo
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo00?o
oooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo05Co
oooo00?o003oooooooooool02oooool2o`00oaCooooo0_l00?l<ooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo01ko
oooo000Cooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool06Oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo01Kooooo00Go003oooooooooooooooooo`00o`0Aooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool0EOooool2o`00o`Sooooo0ol00?lHooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo02Cooooo00?o003oooooooooool07Oooool001?ooooo00?o0000ooooooooool0
9?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Oooooo00Co003ooooooooooooo
003o4_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo05Oooooo00?o003ooooooooo
ool00oooool2o`00oacooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Looooo`00
4oooool00ol0003oooooooooo`0Tooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
6?ooool00ol00?ooooooo`00o`0Cooooo`?o003o2?ooool00ol00?ooooooooooo`1Iooooo`03o`00
oooooooo003o00;o003o7oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00kooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Wooooo`03o`00oooooooooooo01_ooooo
000Cooooo`03o`000?oooooooooo02Cooooo00Go003oooooooooooooooooo`00o`0Looooo`03o`00
oooooooooooo01Gooooo0ol00?l5ooooo`03o`00oooooooooooo05[ooooo00?o003oooooooooool0
8Oooool2o`00o`Gooooo00?o003oooooooooool04?ooool;o`00odOooooo0008ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0Uooooo`04o`00ooooooooooooo`00ocOo
oooo0ol00?l2ooooo`03o`00oooooooooooo083ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`1Rooooo`002?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000oooooooo
ool09Oooool00ol00?ooooooo`00o`0kooooo`;o003oQ?ooool01?l00?ooooooooooool00?mUoooo
o`001_l00002ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Voooo
o`03o`00oooooooooooo0<7ooooo00?o003oooooool00?l0IOooool000Sooooo00Go0000oiRHV?oo
ooooV9RHob4Q8@06ooooo`?o0000joooool00ol00?ooooooooooo`1Tooooo`002?ooool01Ol0003o
EEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0oooooomCooooo`002?ooool00omEEEGo
QhN7ooooo`08ooooo`03o`000?oooooooooo0?ooooooDoooool000Sooooo00?ogMgMoa0@4?nHV9P0
2?ooool00ol0003oooooooooo`3ooooooe?ooooo0009ooooo`04olc<c?m4A4Co0000oa0@40Kooooo
00?o0000ooooooooool0oooooomCooooo`004oooool00ol0003oooooooooo`3ooooooe?ooooo000C
ooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo00?o0000ooooooooool0oooooomCoooo
o`004oooool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo0?oooooo
Doooool001?ooooo0_l0003ooooooeCooooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool0
01?ooooo00?o0000ooooooooool0oooooomCooooo`004oooool00ol0003oooooooooo`3ooooooe?o
oooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo00?o0000ooooooooool0oooo
oomCooooo`004oooool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo
0?ooooooDoooool001?ooooo00?o0000ooooooooool0oooooomCooooo`004oooool00ol0003ooooo
ooooo`3ooooooe?ooooo000Cooooo`;o0000oooooomDooooo`004oooool00ol0003oooooooooo`3o
oooooe?ooooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo00?o0000oooooooo
ool0oooooomCooooo`004oooool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oo
oooooooo0?ooooooDoooool001?ooooo00?o0000ooooooooool0oooooomCooooo`004oooool00ol0
003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo
0_l0003ooooooeCooooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo00?o0000
ooooooooool0oooooomCooooo`004oooool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03
o`000?oooooooooo0?ooooooDoooool001?ooooo00?o0000ooooooooool0oooooomCooooo`004ooo
ool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool0
00[ooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooDoooool000_o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooooe?ooooo0006o`0000;ooooo
1Ol00006ooooo`?o0000oooooomCooooo`002?ooool01?m4A4CogMgMooooool00007ooooo`03o`00
0?oooooooooo0?ooooooDoooool000Sooooo00CogMgMoeEEEOoooooo00001oooool00ol0003ooooo
ooooo`3ooooooe?ooooo0009ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0oooo
oomCooooo`002Oooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0?ooooooDoooool0
00[ooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03
o`000?oooooooooo0?ooooooDoooool001?ooooo00?o0000ooooooooool0oooooomCooooo`004ooo
ool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool0
01?ooooo0_l0003ooooooeCooooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo
00?o0000ooooooooool0oooooomCooooo`004oooool00ol0003oooooooooo`3ooooooe?ooooo000C
ooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo00?o0000ooooooooool0oooooomCoooo
o`004oooool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo0?oooooo
Doooool001?ooooo00?o0000ooooooooool0oooooomCooooo`004oooool00ol0003oooooooooo`3o
oooooe?ooooo000Cooooo`;o0000oooooomDooooo`004oooool00ol0003oooooooooo`3ooooooe?o
oooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo00?o0000ooooooooool0oooo
oomCooooo`004oooool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo
0?ooooooDoooool001?ooooo00?o0000ooooooooool0oooooomCooooo`004oooool00ol0003ooooo
ooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo00?o0000
ooooooooool0oooooomCooooo`004oooool2o`000?ooooooE?ooool001?ooooo00?o0000oooooooo
ool0oooooomCooooo`004oooool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oo
oooooooo0?ooooooDoooool001?ooooo00?o0000ooooooooool0oooooomCooooo`004oooool00ol0
003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool000Sooooo
1Ol00006ooooo`03o`000?oooooooooo0?ooooooDoooool000Sooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A006ooooo`03o`000?oooooooooo0?ooooooDoooool000Ko00000oooool00onHV9So8B4Qonk^
kP07ooooo`03o`000?oooooooooo0?ooooooDoooool000[ooooo00?oV9RHob4Q8Oo^k^h01_ooool3
o`000?ooooooDoooool000_ooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`3ooooo
oe?ooooo000<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooomCooooo`00
2?ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0oooooomCooooo`00
2?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooomCooooo`00
4oooool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo0?ooooooDooo
ool001?ooooo00?o0000ooooooooool0oooooomCooooo`004oooool00ol0003oooooooooo`3ooooo
oe?ooooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo0_l0003ooooooeCooooo
000Cooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo00?o0000ooooooooool0oooooomC
ooooo`004oooool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo0?oo
ooooDoooool001?ooooo00?o0000ooooooooool0oooooomCooooo`004oooool00ol0003ooooooooo
o`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo00?o0000oooo
ooooool0oooooomCooooo`004oooool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`;o0000
oooooomDooooo`004oooool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooo
oooo0?ooooooDoooool001?ooooo00?o0000ooooooooool0oooooomCooooo`004oooool00ol0003o
ooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo00?o
0000ooooooooool09_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000
7_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@oooooooo
ool07Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000
oa0@4?o<c<`07oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ
8B7o0000ob4Q8Oo<c<`0:?ooool4o`000003oa0@4?oooooooooo02Gooooo1?l000000ol@413ooooo
ooooo`02ooooo`;o8B4Q1?ooool5o`0001Cooooo000Cooooo`03o`000?oooooooooo02Kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A401ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`0Noooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q
8@0Oooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?oooooo
V9RHob4Q8@0Zooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01?ooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Dooooo`004oooool00ol0003oooooooooo`0Vooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Oooooo`05oa0@4?oooooooooo
ooooool@41002oooool5o`0001oooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oo
ooooooooooooool000007oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooo
ooooooooo`00000Zooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02oooool00onH
V9So8B4Qonk^kP0Eooooo`004oooool00ol0003oooooooooo`0Vooooo`05o`000?oooooooooooooo
ool000003Oooool00onHV9So8B4Qonk^kP0Nooooo`05o`000?ooooooooooooooool000002oooool0
1?m4A4CogMgMooooool0000Pooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RH
oooooonHV9So8B4Q01oooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9Sooooo
oiRHV?lb<S80:_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00cooooo00?oV9RH
ob4Q8Oo^k^h05?ooool001?ooooo0_l0000Wooooo`05o`000?ooooooooooooooool000003_ooool0
0omgMgOoIVIVooooo`0Mooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEoooo
ool0000Pooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<
01oooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0:_oo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool04ooo
ool001?ooooo00?o0000ooooooooool09_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o
0000ooooooooool07?ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000
8?ooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool08Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400Zooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Booooo`004oooool00ol0
003oooooooooo`0Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonH
V9So410@01kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co0000023ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH027ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000:_ooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@400Dooooo`004oooool0
0ol0003oooooooooo`0Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`00
0?lQ8B7oc<c<01kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo01oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@41oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0:?ooool00omEEEGoIVIV
o`00000Yooooo`03oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Dooooo`00
4oooool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo0?ooooooDooo
ool001?ooooo00?o0000ooooooooool0oooooomCooooo`004oooool00ol0003oooooooooo`3ooooo
odWooooo00GoV9RHo`000?l0003oA4A4okZj^P05ooooo`004oooool00ol0003oooooooooo`3ooooo
odWooooo00Go410@okZj^_o^k^koMgMgoa0@4005ooooo`002oooooooo`0004Wo00002oooool00ol0
003oooooooooo`07ooooo`004oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Oo
oooo000Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01oooool001?ooooo00?o
0000ooooooooool0oooooom7ooooo`03oa0@4?l0003o000000?o00001_ooool001?ooooo00?o0000
ooooooooool0oooooom9ooooo`03o`000?oooooooooo00Oooooo000Cooooo`03o`000?oooooooooo
0?ooooooBOooool00ol0003oooooooooo`07ooooo`004oooool00ol0003oooooooooo`3ooooooe?o
oooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo00?o0000ooooooooool0oooo
oomCooooo`004oooool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`;o0000oooooomDoooo
o`004oooool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo0?oooooo
Doooool001?ooooo00?o0000ooooooooool0oooooomCooooo`004oooool00ol0003oooooooooo`0f
ooooob3oo`00LOoooolPool006_ooooo000Cooooo`03o`000?oooooooooo02cooooo2_oo000Poooo
o`[oo`00GOooool:ool0023ooooo2ooo001Pooooo`004oooool00ol0003oooooooooo`0Qooooo`_o
o`00=?ooool;ool004Oooooo2ooo000eooooo`[oo`00E_ooool001?ooooo00?o0000ooooooooool0
5oooool:ool004[ooooo2_oo000cooooo`[oo`00B_ooool:ool004cooooo000Cooooo`03o`000?oo
oooooooo00cooooo2ooo001Nooooo`_oo`007_ooool:ool005kooooo2ooo000Doooooa3oo`007Ooo
ool001?ooooo00?o0000ooooooooool00_ooool:ool007Cooooo7_oo001coooooaCoo`00;Oooool0
01?ooooo1Ooo003ooooooe7ooooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo
00?o0000ooooooooool0oooooomCooooo`004oooool00ol0003oooooooooo`3ooooooe?ooooo000C
ooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo00?o0000ooooooooool0oooooomCoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00X?ooool01?l@4?oo003oo`00ool00?mXooooo`06ob4Q8Ol0003o0000odA4A?oMgMgooooo0ol0
00000ol@413oooooooooo`1@ooooo`00XOooool00ol00?ooooooooooo`1[ooooo`03ogMgMolb<S;o
oooo00;ooooo00?o410@okZj^_ooool0DOooool00:7ooooo00?o003oooooooooool0K?ooool01_l0
003oooooooooooooooooV9RHoc8b<U;ooooo0016ooooo`;oo`000_ooool00ooo413oo`00ool00002
ooooo`Goo`000_ooool01?oo413oo`00ool00?ooool2ool00004ool@4?ooooooonk^oomEE@;oo`00
00?oodA4oonj^_ooool00_ooool01OooV9Soo`00ool00?ooA4CookZj00?ooooo1Ooo0003ooooo`05
oomVI_oo003oo`00oom4A?ooc<`01_ooool01_nHV9So0000o`000?mgMgOo410@o`0000;ooooo00Co
410@o`000?l0003ooooo0_l000001?l@413oooooonk^k_mEEED2o`000003oiRHV?l0003o410@00So
oooo00Wo003oogMgool00?oo003ooeEEooo^k_ooooooonk^oomEEOl00_l00?l00omEEOook^kooooo
o`02ooooo`05oiRHool00?oo003oodA4oonj^_l00_ooool01_o^k_ooEEGoo`00ool00?ooA4CookZj
o`;ooooo00Co413oo`00ool00?oooooo0_l00?l01?l@4?oooooooooooonHV?l2o`00o`03odA4oonj
^_oooooo00;ooooo1Ol00?l2ooooo`06oiRHool00?oo003oogMgool@4?oo003o0_ooool5o`00o`Ko
oooo00Kok^k^oeEEEOl0003o0000odA4A?nj^[X2ooooo`04oa0@4?l0003o0000ooooo`;o000000Co
410@ooooooo^k^koEEEE0_l000001?m4A4Co^[Zjooooool@4105o`0000?ooooo00Kok^k^oeEEEOl0
003o410@olc<c?l00003ooooo`03omgMgOl0003o^[Zj057ooooo0017ooooo`05ool00?ooooooonk^
oolb<_ooc<`01Oooool00ooo003oooooooooo`03ooooo`05ool00?oooooooooooooooooo00000_oo
ool01_ooEEGoogMgooooooook^koogMgool@40?ooooo00Gooa0@oonj^_ook^koogMgool@4005oooo
o`03ool00?oooooooooo00;ooooo00KoofIVoomgMooooooooooooon7Qooo4106ooooo`05o`000?o<
c<cok^k^ohN7Qol000001?ooool01Ol0003ooooooooooooooooo000000;ooooo00KoEEEEogMgMooo
ooook^k^oeEEEOl00009ooooo`09o`00oomEEOook^kooooooomgMoooEEGooooooomEEOooMgOo00;o
oooo00?oMgOooeEEooooool00_ooool01Ol@4?oo^[[oonk^oomgMooo413o00;ooooo00KoEEGoogMg
ooooooook^koogMgool@4?l3ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol@4?oo^[[o
onk^oomgMooo413o00Gooooo00?o003oooooooooool00_ooool01Ol00?ooc<coonk^oon7Qooo003o
00Gooooo00?o003oooooooooool01_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40?ooooo00Go
0000ooooooooooooooooo`000002ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0oooool00ol0
003oooooooooo`04ooooo`06oeEEEOmgMgOoooooonk^k_mEEEGo00000oooool00omEEEGoMgMgodA4
A01Aooooo`00Aoooool01?oo003ooiRHoolb<_ooc<`6ooooo`03ool00?oooooooooo00?ooooo00Go
o`00ooooooooooooooooool00002ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
1oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Wooooo00Go410@ohN7Qooooooo
k^k^o`000004ooooo`05o`000?ooooooooooooooool000000_ooool01_l0003ooooooooooooooooo
k^k^o`0000Wooooo00?o003oonk^ooooool00_ooool00ol00?ooooooo`00o`04ooooo`05o`00oooo
ooooooooooooool00?l01_ooool00ol00?ooooooooooo`06ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00;ooooo00Go413oohN7oooo
ooook^koo`00o`05ooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool01_ooool01Ol0
003ooooooooooooooooo000000;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04
ooooo`06o`000?ooooooooooooooooo^k^ko00000_ooool01OoMgMgo410@oooooolQ8B7ogMgM053o
oooo0017ooooo`03ool00?oo413ooiRH00Oooooo00?oo`00ooooooooool00oooool01Ooo003ooooo
ooooooooooooo`0000;ooooo1_oo0003ooooo`03ool00?oooooooooo00Oooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`09ooooo`03okZj^_l@413o000000;o00001?ooool01Ol0003o
oooooooooooooooo000000;ooooo00Ko0000ooooooooooooooooonk^k_l00009ooooo`03o`00ooo^
k_oooooo00;ooooo00?o003oooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00Kooooo
1_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo00;ooooo00?o^[[ooa0@ool00?l00_l00?l5ooooo`03o`00oooooooooooo00Ko
oooo1_l00003ooooo`05o`000?ooooooooooooooool000000_ooool6o`0000?ooooo00?o0000oooo
ooooool01?ooool01_l0003oooooooooooooooook^k^o`0000;ooooo00GoIVIVohN7QoooooooV9RH
oeEEE@1@ooooo`00Aoooool01?oo003oonk^oomEEOooQhL6ooooo`03ool00?oooooooooo00?ooooo
00Goo`00oon7QoooooooojVYool00002ooooo`06oomEEOooQhOoonk^ooooooooQhOooc8b0oooool0
0ooo003oooooooooo`07ooooo`03ool00?oooooooooo00;ooooo00KoofIVoomgMooooooooooooon7
Qooo0009ooooo`03olc<c?l0003ooooo00?ooooo00Go0000ohN7QoooooooZJVYo`000002ooooo`06
ofIVI_mgMgOoooooonk^k_mEEEGo00002Oooool02Ol00?ooEEGoonk^ooooooooMgOoofIVoooooooo
EEGoogMgo`02ooooo`03ogMgoomEEOoooooo00;ooooo00?o003oooooooooool01?ooool01_mEEOoo
QhOoonk^ooooooooQhOooc8bo`?ooooo00Go003oohN7ooooooooZJWoo`00o`03ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool01Oooool00oo<c?oo003oooooo`04ooooo`03o`00oooo
oooooooo00Kooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S83ooooo`05o`000?n7QhOoooooojVY
ZOl000000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P?ooooo00?o0000oc8b<_oMgMd01?oo
ool02_mEEEGoMgMgooooooo^k^koEEEEo`000?ooooook^k^o`000?o^k^h2ooooo`03o`000?oMgMgo
oooo04kooooo0017ooooo`05ool00?ooooooodA4ool00?oo41000oooool00ooo413oo`00ool00004
ooooo`03ool@4?oo003oogMg00;oo`0000GooiRHooooooooooooonk^oomEE@02ool00004oom4A?oo
k^koooooool@40Goo`001?ooool00ooo413oo`00ool00004ooooo`06ooo^k_ooIVKoo`00ool00?oo
A4Coo`001oooool01?lb<S;o0000o`000?nHV9P3ooooo`03oa0@4?l0003oMgMg00;o000000WoV9RH
ooooooooooook^k^oeEEEOl0003o410@olc<c?l000002?ooool00ol@4?oo003oogMgo`02o`00o`05
ofIVooo^k_ooooooonk^oomEEOl00_l00?l01?mEEOook^koooooool@4?l5o`00o`?ooooo00Kok^ko
oeEEool00?oo003oodA4ooo^k_l2ooooo`03oa0@ool00?ooMgOo00;o003o00?oV9Soooooool@4?l0
1Ol00?l4ooooo`03oa0@ool00?oo003o00Gooooo00Co<S;oo`00ool00?ooV9So1Oooool00ol00?oo
ooooooooo`06ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0_ooool00ol@413o0000ogMgM`02
o`000005oiRHV?ooooooooooonk^k_mEEED00_l000001?m4A4Cok^k^ooooooooool2o`000004ojVY
ZOlQ8B7o0000ob4Q8@;ooooo00Kok^k^oeEEEOl0003o8B4QojVYZOl00002oa0@40;o000000Cooooo
o`000?l0003o410@Coooool004Oooooo00?oo`00ooooooooool07Oooool00ooo003oooooooooo`0]
ooooo`03o`000?oooooooooo01Oooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0F
ooooo`03o`00oooooooooooo08?ooooo0017ooooo`03ool00?oooooooooo00Oooooo00?oo`00oooo
ooooool04oooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo02?ooooo00?o0000oooo
ooooool05oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`23ooooo`00A_ooool2ool000Wooooo00?ooa0@oooooooo
ool07Oooool00ooo413oooooooooo`0Rooooo`;o0000>oooool00ol@4?ooooooooooo`0:ooooo`03
oa0@ool00?oo003o08Gooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.0742721, -8.96179, \
0.00482121, 0.0631792}}]
}, Open  ]],

Cell[TextData[{
  "The kinetic energy (red curve) varies smoothly and is nearly constant, \
just as one would expect for this nearly circular motion. However, the \
potential energy (blue curve) varies considerably  from step to step. \
Clearly, this potential energy is in error.  The reason for this error can be \
understood by substituting  the discrete Fourier transform representation for \
",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_\(i\ j\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_\(\(\ \)\(i\ j\)\)\)]],
  " into Eq. ",
  ButtonBox["(7.3.10)",
    ButtonData:>{"Chapter7.nb", "(7.3.10)"},
    ButtonStyle->"Hyperlink"],
  " . Using orthogonality of the Fourier modes, one finds"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{"U", " ", "=", " ", 
          RowBox[{
            RowBox[{\(M\^2\), 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]], " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["y",
                    FontSlant->"Italic"]}]], 
              " ", \(\[Sum]\+\(m, n = 0\)\%\(M - 1\)\(\[Rho]\&~\_\(m\ n\)\) \
\(\[Phi]\&~\_\(m\ n\)\^*\)\)}], "=", 
            RowBox[{\(-4\), " ", "\[Pi]", " ", \(L\^2\), "G", 
              RowBox[{
                UnderoverscriptBox[
                  StyleBox["\[Sum]",
                    FontSize->9], \(m, 
                  n = 0\), \(M - 
                    1\)], \(\((\(|\)\(\[Rho]\&~\_\(m\ n\)\)\(|\))\)\^2\/\(\(\
\[Kappa]\^2\)(m, \ n)\)\)}]}]}]}], TraditionalForm]]],
  "."
}], "NE3",
  CellTags->"(7.3.11)"],

Cell[TextData[{
  "where, in the second step, we employed Eq. ",
  ButtonBox["(6.2.43)",
    ButtonData:>{"Chapter6.nb", "(6.2.43)"},
    ButtonStyle->"Hyperlink"],
  "  (multiplied by the factor ",
  Cell[BoxData[
      \(TraditionalForm\`4\ \[Pi]\ G\)]],
  "), and where ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Kappa]\^2\)(m, n)\)]],
  " is"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(\[Kappa]\^2\)(m, n)\), " ", "=", " ", 
          RowBox[{
            RowBox[{
              FractionBox["4", 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]], 
                  "2"]], \(\(sin\^2\)(\[Pi]\ m/M)\)}], " ", "+", 
            RowBox[{
              FractionBox["4", 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["y",
                        FontSlant->"Italic"]}]], 
                  "2"]], \(\(sin\^2\)(\[Pi]\ n/M)\)}]}]}], 
        TraditionalForm]]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "The function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa]\^2\)]],
  " approximates the square of the wavenumber, ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(k\^2\), "=", 
          RowBox[{\(\((2\ \[Pi])\)\^2\), 
            RowBox[{"(", 
              RowBox[{
                RowBox[{\(m\^2\), "/", 
                  SuperscriptBox[
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["x",
                          FontSlant->"Italic"]}]], "2"]}], "+", 
                RowBox[{\(n\^2\), "/", 
                  SuperscriptBox[
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["y",
                          FontSlant->"Italic"]}]], "2"]}]}], ")"}]}]}], 
        TraditionalForm]]],
  ", provided that ",
  Cell[BoxData[
      FormBox[
        RowBox[{"k", " ", 
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]]}], TraditionalForm]]],
  " is small. In this limit Eq. ",
  ButtonBox["(7.3.11)",
    ButtonData:>{"Chapter7.nb", "(7.3.11)"},
    ButtonStyle->"Hyperlink"],
  "  returns to the correct result for the potential energy, ",
  Cell[BoxData[
      \(TraditionalForm\`U = \(-4\)\ \[Pi]\ G \
\(\[Integral]\[DifferentialD]\^2 
                k \((\(|\)\(\[Rho]\&~\)\(|\))\)\^2\/k\^2\)\)]],
  ".   However, for large wavenumbers, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa]\^2\)]],
  "deviates considerably from ",
  Cell[BoxData[
      \(TraditionalForm\`k\^2\)]],
  ", and in fact ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa]\^2\)]],
  " ",
  "goes to zero",
  " as ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " approach ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " . This implies that, for a given particle density,  large wavenumber \
contributions to the potential energy are afforded much more weight than they \
deserve. As a result,  large-wavenumber contributions to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " produce dramatic variations in ",
  Cell[BoxData[
      \(TraditionalForm\`U\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tOf course, we already know that large wavenumbers are not properly \
handled by the FFT solution anyway, so the nonconservation of the potential \
energy due to large-wavenumber contributions might be regarded as an \
indicator that the PIC method is breaking down. However, we can see in this \
example that the actual particle dynamics appears to be working well. The \
reason for this apparent contradiction is that the dynamics depends on the \
force, not the energy, and the force is not so heavily weighted toward large \
wavenumbers as is the energy. Recall that we used a centered difference \
method for the force field at the grid points, Eqs. ",
  ButtonBox["(7.3.8)",
    ButtonData:>{"Chapter7.nb", "(7.3.8)"},
    ButtonStyle->"Hyperlink"],
  " . If we write the force in terms of a discrete Fourier transform, we find \
that"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            OverscriptBox[
              StyleBox["F",
                FontWeight->"Bold",
                FontSlant->"Plain"], "~"], \(m\ n\)], "=", 
          RowBox[{
            RowBox[{\(-\[ImaginaryI]\), " ", 
              RowBox[{
                StyleBox["K",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox["(",
                  FontWeight->"Plain"], 
                StyleBox[\(m, n\),
                  FontWeight->"Plain"], 
                StyleBox[")",
                  FontWeight->"Plain"]}], " ", \(\[Phi]\&~\_\(m\ n\)\)}], "=",
             " ", 
            RowBox[{"4", " ", "\[Pi]", " ", "\[ImaginaryI]", " ", "G", " ", 
              RowBox[{
                StyleBox["K",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox["(",
                  FontWeight->"Plain"], 
                StyleBox[\(m, n\),
                  FontWeight->"Plain"], 
                StyleBox[")",
                  
                  FontWeight->
                    "Plain"]}], \(\[Rho]\&~\_\(m\ n\)\/\(\(\[Kappa]\^2\)(m, \ 
                    n)\)\), " "}]}]}], TraditionalForm]]],
  ","
}], "NE3",
  CellTags->"(7.3.12)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["K",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["(",
              FontWeight->"Plain"], 
            StyleBox[\(m, n\),
              FontWeight->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{"(", 
            RowBox[{
              FractionBox[\(sin(2\ \[Pi]\ m/M)\), 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]]], ",", 
              FractionBox[\(sin(2\ \[Pi]\ n/M)\), 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["y",
                      FontSlant->"Italic"]}]]]}], ")"}]}], 
        TraditionalForm]]],
  " is a vector that approximates ",
  Cell[BoxData[
      FormBox[
        StyleBox["k",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " at small ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(k\)\(|\)\)\)]],
  ". Thus, large wavenumbers are still weighted too heavily compared to the \
exact expression ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            OverscriptBox[
              StyleBox["F",
                FontWeight->"Bold",
                FontSlant->"Plain"], "~"], "=", 
            RowBox[{"4", " ", "\[Pi]", " ", "\[ImaginaryI]", " ", "G", " ", 
              StyleBox["k",
                FontWeight->"Bold",
                FontSlant->"Plain"], \(\[Rho]\&~\/k\^2\)}]}], ","}], 
        TraditionalForm]]],
  "but ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["K",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["(",
            FontWeight->"Plain"], 
          StyleBox[\(m, n\),
            FontWeight->"Plain"], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " ",
  "also becomes small",
  " at large wavenumbers. This greatly reduces the effect that \
large-wavenumber contributions to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " have on the force. In other words, large-wavenumber ripples in the \
density have much less effect on the force than they do on the potential \
energy. As a result, the PIC method can still be working properly, even when \
energy is not well conserved. "
}], "Text"],

Cell[TextData[{
  "\tNote that Eq. (",
  ButtonBox["7.3.12",
    ButtonData:>"(7.3.12)",
    ButtonStyle->"Hyperlink"],
  ") relies on using a finite difference method, Eq. (",
  ButtonBox["7.3.8",
    ButtonData:>"(7.3.8)",
    ButtonStyle->"Hyperlink"],
  "), to determine the force from the potential. If instead we determined the \
force by applying an inverse FFT to the expression ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          OverscriptBox[
            StyleBox["F",
              FontWeight->"Bold",
              FontSlant->"Plain"], "~"], "=", 
          RowBox[{\(-\[ImaginaryI]\), " ", 
            StyleBox["k",
              FontWeight->"Bold",
              FontSlant->"Plain"], " ", \(\[Phi]\&~\)}]}], 
        TraditionalForm]]],
  ", large wavenumbers would be weighted too heavily.  This is the main \
reason why Eq. (",
  ButtonBox["7.3.8",
    ButtonData:>"(7.3.8)",
    ButtonStyle->"Hyperlink"],
  ") is the preferred method for force evaluation."
}], "Text"],

Cell["\<\
\tHowever, it can still  useful to keep track of the energy, \
particularly when the density has little or no large-wavenumber \
contributions. This will be true if the density is a reasonably smooth \
function of position. \
\>", "Text"],

Cell["\<\
\tSince energy is not necessarily  a good indicator of the code \
accuracy, and since linear momentum is always exactly conserved, constants of \
the motion are of limited use in accuracy tests. We must therefore fall back \
on the old standby techniques for determining the validity of our results: \
\
\>", "Text"],

Cell[TextData[{
  "\t(1) increase and/or decrease the time step size by  factors of two to \
ensure that results are independent of ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "\t(2) increase and/or decrease the grid spacing  by  factors of two to \
ensure that results are independent of ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "\t(3) increase and/or decrease the particle number by  factors of two \
(decreasing or increasing  the mass per particle by the same factor so that \
mass density remains the same) to ensure that results are independent of ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Gravitational Collapse in a Cold Gas", "Section",
  CellTags->{"i:56", "c:37"}],

Cell[TextData[{
  "A cold uniform gas is unstable to gravitational collapse. Due to the \
attraction of the gas to itself, small density variations grow over time. \
Matter is attracted to maxima in these variations, increasing their size. \
This is called the",
  StyleBox[" ",
    FontSlant->"Italic"],
  StyleBox[ButtonBox["Jeans",
    ButtonData:>{
      URL[ 
      "http://www-history.mcs.st-andrews.ac.uk/history/Mathematicians/Jeans.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  StyleBox[" instability",
    FontSlant->"Italic"],
  ". This basic phenomenon is responsible for the formation of all the \
structure we can see in the night sky, including planets, stars,  and \
galaxies. "
}], "Text",
  CellTags->"i:80"],

Cell[TextData[{
  "\tThe instability can also be studied from a different point of view by \
considering the energy of the system. According to Eq. ",
  ButtonBox["(7.3.11)",
    ButtonData:>{"Chapter7.nb", "(7.3.11)"},
    ButtonStyle->"Hyperlink"],
  " , the potential energy is a negative quantity, becoming more negative as \
the gas collapses and the density becomes more concentrated.  In order to \
conserve energy,  kinetic energy must increase. As the gas collapses, it \
heats.   What is the end product of this process?"
}], "Text"],

Cell[TextData[{
  "\tWe can study  gravitational collapse and heating  in a PIC simulation. \
In Cells ",
  ButtonBox["7.84",
    ButtonData:>"Cell 7.84",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["7.85",
    ButtonData:>"Cell 7.85",
    ButtonStyle->"Hyperlink"],
  " we run a simulation of 1000 particles, initially distributed randomly \
throughout the box, and with zero initial momentum. We perform the simulation \
on a rather coarse 10 by 10 spatial grid, since we are not interested in \
quantitative accuracy at this point, only in the qualitative effects \
associated with the collapse."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< Utilities`;\)\), "\n", 
    \(m = 1; M = 10; 
    L = 1; \[CapitalDelta]x\  = \ \(\[CapitalDelta]y\  = \ 
        L/M\); \[CapitalDelta]t\  = \ 0.003;\), "\n", 
    \(\(Clear[r, p];\)\), "\n", 
    \(\(r0\  = \ Table[{Random[], Random[]}, {1000}];\)\), "\n", 
    \(\(p0 = \ Table[{0, 0}, {1000}];\)\), "\n", 
    \(Timing[leapfrog[r0, p0, 60, \[CapitalDelta]t]]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.84"],

Cell[BoxData[
    \({31.99`\ Second, Null}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Table[
        ListPlot[r[n], PlotRange \[Rule] {{0, 1}, {0, 1}}, 
          AspectRatio \[Rule] 1], {n, 0, 60, 1}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.85"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.09778 .67691 Mdot
.82671 .4342 Mdot
.08394 .4987 Mdot
.0469 .03404 Mdot
.38689 .41733 Mdot
.24526 .04851 Mdot
.62835 .01346 Mdot
.26275 .45949 Mdot
.31187 .97379 Mdot
.77287 .00162 Mdot
.32942 .21516 Mdot
.47044 .09704 Mdot
.23164 .53825 Mdot
.64373 .66284 Mdot
.1477 .03955 Mdot
.59683 .6288 Mdot
.76081 .62222 Mdot
.35156 .58029 Mdot
.13246 .60876 Mdot
.08881 .1208 Mdot
.82058 .63497 Mdot
.31594 .11918 Mdot
.49117 .41981 Mdot
.8455 .02214 Mdot
.25952 .88155 Mdot
.20177 .3593 Mdot
.11182 .84201 Mdot
.60495 .7305 Mdot
.35101 .21979 Mdot
.25338 .15021 Mdot
.21856 .61103 Mdot
.16457 .02941 Mdot
.39797 .97606 Mdot
.84863 .91023 Mdot
.90681 .55625 Mdot
.00313 .88809 Mdot
.64728 .6747 Mdot
.80136 .52879 Mdot
.53546 .83269 Mdot
.19642 .7983 Mdot
.18445 .6129 Mdot
.94304 .64809 Mdot
.96589 .00188 Mdot
.77847 .61868 Mdot
.56792 .02582 Mdot
.92983 .70845 Mdot
.66112 .46957 Mdot
.9267 .82036 Mdot
.01384 .79488 Mdot
.12534 .29157 Mdot
.47837 .96218 Mdot
.92892 .49327 Mdot
.29392 .34928 Mdot
.98589 .84518 Mdot
.32803 .3474 Mdot
.20742 .22649 Mdot
.7601 .32158 Mdot
.27759 .51804 Mdot
.09899 .85201 Mdot
.35088 .69768 Mdot
.08515 .05713 Mdot
.22555 .40611 Mdot
.60678 .09495 Mdot
.29662 .91284 Mdot
.31286 .74567 Mdot
.31074 .06766 Mdot
.98483 .39827 Mdot
.10332 .84117 Mdot
.22472 .07669 Mdot
.82573 .32313 Mdot
.12574 .22468 Mdot
.47485 .62546 Mdot
.04059 .16754 Mdot
.2493 .21935 Mdot
.43381 .0726 Mdot
.95268 .30651 Mdot
.12095 .32693 Mdot
.64194 .23885 Mdot
.13613 .92866 Mdot
.53862 .39768 Mdot
.9114 .85197 Mdot
.71289 .07455 Mdot
.78566 .6273 Mdot
.23805 .44909 Mdot
.74507 .45975 Mdot
.98874 .22974 Mdot
.31126 .38715 Mdot
.03606 .92323 Mdot
.19031 .06023 Mdot
.39412 .68439 Mdot
.05418 .13157 Mdot
.8555 .28671 Mdot
.14278 .27959 Mdot
.14261 .21217 Mdot
.35712 .6523 Mdot
.90456 .76308 Mdot
.61204 .19255 Mdot
.91582 .53334 Mdot
.30078 .80539 Mdot
.87975 .6101 Mdot
.11047 .74517 Mdot
.48563 .92571 Mdot
.05629 .6136 Mdot
.63013 .639 Mdot
.91351 .33401 Mdot
.48752 .42683 Mdot
.55639 .68171 Mdot
.58296 .66375 Mdot
.94435 .48916 Mdot
.66714 .13042 Mdot
.64357 .68377 Mdot
.78738 .52032 Mdot
.5331 .9386 Mdot
.30175 .5946 Mdot
.47681 .325 Mdot
.67162 .95561 Mdot
.5633 .991 Mdot
.1841 .52878 Mdot
.00691 .30929 Mdot
.60114 .86502 Mdot
.06257 .82013 Mdot
.934 .73461 Mdot
.419 .13636 Mdot
.14662 .21429 Mdot
.88591 .19776 Mdot
.84486 .61969 Mdot
.4091 .87276 Mdot
.17324 .66408 Mdot
.8458 .88176 Mdot
.98914 .13531 Mdot
.83889 .57247 Mdot
.388 .27028 Mdot
.77632 .75233 Mdot
.45399 .53567 Mdot
.35732 .61597 Mdot
.30738 .32138 Mdot
.47141 .41821 Mdot
.46251 .70169 Mdot
.06231 .54546 Mdot
.28927 .03761 Mdot
.21652 .6637 Mdot
.30014 .9023 Mdot
.37763 .09123 Mdot
.91214 .63202 Mdot
.60131 .3389 Mdot
.45815 .09635 Mdot
.24399 .72293 Mdot
.15077 .77497 Mdot
.77258 .30472 Mdot
.68825 .07328 Mdot
.71027 .75926 Mdot
.39898 .03567 Mdot
.49375 .09556 Mdot
.09884 .13337 Mdot
.11612 .00433 Mdot
.1867 .50135 Mdot
.51481 .66543 Mdot
.72856 .405 Mdot
.27082 .9425 Mdot
.57779 .63003 Mdot
.49824 .63779 Mdot
.88953 .55676 Mdot
.78797 .87853 Mdot
.49055 .52109 Mdot
.29422 .78296 Mdot
.39171 .38772 Mdot
.1781 .77864 Mdot
.20501 .88637 Mdot
.66329 .11321 Mdot
.47645 .48137 Mdot
.39247 .17071 Mdot
.89866 .85133 Mdot
.89423 .53292 Mdot
.00913 .29458 Mdot
.10626 .6544 Mdot
.51858 .77349 Mdot
.81204 .87143 Mdot
.12687 .38577 Mdot
.63394 .0928 Mdot
.92186 .4994 Mdot
.97065 .97959 Mdot
.44541 .01804 Mdot
.57818 .80888 Mdot
.54674 .16671 Mdot
.68395 .27595 Mdot
.53761 .87213 Mdot
.57769 .62156 Mdot
.01903 .09864 Mdot
.76564 .75012 Mdot
.89217 .71287 Mdot
.1317 .65733 Mdot
.97031 .21346 Mdot
.16105 .67774 Mdot
.52491 .19543 Mdot
.58287 .86886 Mdot
.97816 .02872 Mdot
.89892 .59291 Mdot
.44055 .15659 Mdot
.32124 .97135 Mdot
.42152 .05795 Mdot
.55559 .22123 Mdot
.52935 .34508 Mdot
.42389 .5639 Mdot
.55904 .13162 Mdot
.26284 .88616 Mdot
.03413 .93619 Mdot
.67997 .0173 Mdot
.05597 .90747 Mdot
.78104 .4244 Mdot
.61541 .75088 Mdot
.4598 .45305 Mdot
.1939 .69293 Mdot
.90421 .23182 Mdot
.66455 .34784 Mdot
.48032 .66792 Mdot
.10551 .21623 Mdot
.21748 .78175 Mdot
.07138 .28003 Mdot
.53752 .76445 Mdot
.01541 .37257 Mdot
.75647 .34005 Mdot
.4 .62169 Mdot
.29667 .887 Mdot
.2061 .92876 Mdot
.39246 .65518 Mdot
.54156 .58092 Mdot
.91214 .98727 Mdot
.43604 .36469 Mdot
.69466 .20552 Mdot
.36467 .08466 Mdot
.15714 .44107 Mdot
.34925 .71209 Mdot
.40067 .10102 Mdot
.94925 .0904 Mdot
.104 .21402 Mdot
.74315 .16164 Mdot
.71154 .55883 Mdot
.2016 .58073 Mdot
.7994 .57157 Mdot
.76555 .21603 Mdot
.10475 .36605 Mdot
.40089 .13138 Mdot
.94761 .92498 Mdot
.05163 .41929 Mdot
.54694 .82396 Mdot
.10238 .32888 Mdot
.44294 .60995 Mdot
.35923 .16724 Mdot
.7314 .05111 Mdot
.15763 .58651 Mdot
.932 .47955 Mdot
.39208 .37048 Mdot
.82725 .1135 Mdot
.9912 .2391 Mdot
.87965 .18852 Mdot
.93956 .81981 Mdot
.33271 .36455 Mdot
.83718 .49093 Mdot
.88977 .7546 Mdot
.47795 .3237 Mdot
.15837 .70349 Mdot
.32032 .73718 Mdot
.22637 .22394 Mdot
.92824 .36671 Mdot
.39912 .11044 Mdot
.93704 .12761 Mdot
.51947 .92193 Mdot
.99748 .30779 Mdot
.18676 .55737 Mdot
.1603 .81686 Mdot
.29699 .80277 Mdot
.68235 .49317 Mdot
.13862 .09928 Mdot
.36203 .75598 Mdot
.91225 .87534 Mdot
.43379 .38927 Mdot
.51313 .7649 Mdot
.49675 .26167 Mdot
.99367 .84297 Mdot
.49927 .95387 Mdot
.80691 .2856 Mdot
.33897 .13701 Mdot
.50992 .48283 Mdot
.65662 .64384 Mdot
.37131 .38355 Mdot
.2946 .88786 Mdot
.45906 .5082 Mdot
.86081 .49859 Mdot
.94593 .7433 Mdot
.36406 .23692 Mdot
.95226 .90033 Mdot
.86479 .28305 Mdot
.14535 .61473 Mdot
.52582 .14604 Mdot
.63543 .1319 Mdot
.86919 .5022 Mdot
.26412 .74836 Mdot
.5746 .61433 Mdot
.80506 .24016 Mdot
.71379 .11574 Mdot
.85913 .49685 Mdot
.34973 .87882 Mdot
.90687 .59652 Mdot
.48495 .59577 Mdot
.76152 .98179 Mdot
.95913 .44973 Mdot
.1261 .84989 Mdot
.08994 .94753 Mdot
.86198 .10153 Mdot
.51534 .3332 Mdot
.05691 .86137 Mdot
.80155 .21746 Mdot
.19778 .36452 Mdot
.45181 .33864 Mdot
.29091 .768 Mdot
.96686 .74287 Mdot
.52938 .7862 Mdot
.00774 .29314 Mdot
.40329 .93632 Mdot
.9178 .3456 Mdot
.54131 .83479 Mdot
.40246 .0124 Mdot
.4844 .97342 Mdot
.60091 .79495 Mdot
.28662 .6089 Mdot
.1491 .45631 Mdot
.99571 .84091 Mdot
.18224 .71344 Mdot
.46633 .0547 Mdot
.1745 .42031 Mdot
.06304 .11838 Mdot
.2567 .0747 Mdot
.52173 .28359 Mdot
.85424 .0623 Mdot
.03733 .31017 Mdot
.25333 .26735 Mdot
.75071 .70127 Mdot
.10423 .81104 Mdot
.755 .86036 Mdot
.92199 .0976 Mdot
.28867 .80566 Mdot
.74749 .6773 Mdot
.22563 .68727 Mdot
.49078 .60259 Mdot
.7039 .40368 Mdot
.63654 .54029 Mdot
.66657 .09351 Mdot
.38322 .27294 Mdot
.91586 .39224 Mdot
.27899 .4619 Mdot
.16086 .53188 Mdot
.357 .3643 Mdot
.87219 .72623 Mdot
.60951 .687 Mdot
.64656 .03896 Mdot
.11873 .08441 Mdot
.94266 .63528 Mdot
.48219 .54411 Mdot
.27609 .54177 Mdot
.09897 .27117 Mdot
.36023 .14953 Mdot
.81998 .80927 Mdot
.19938 .61765 Mdot
.46298 .44498 Mdot
.32719 .89142 Mdot
.85347 .75798 Mdot
.68063 .85247 Mdot
.73474 .67357 Mdot
.73797 .21719 Mdot
.25255 .12946 Mdot
.46187 .67542 Mdot
.15358 .85829 Mdot
.10164 .52589 Mdot
.3336 .04901 Mdot
.90226 .90824 Mdot
.87061 .60403 Mdot
.57507 .01681 Mdot
.01715 .84605 Mdot
.89445 .16434 Mdot
.28241 .17248 Mdot
.15648 .94715 Mdot
.02986 .04302 Mdot
.69461 .27173 Mdot
.87628 .18473 Mdot
.59297 .74585 Mdot
.54269 .13572 Mdot
.69071 .83761 Mdot
.67207 .53169 Mdot
.11563 .8208 Mdot
.65492 .68563 Mdot
.22119 .65645 Mdot
.37251 .51315 Mdot
.06471 .7093 Mdot
.34265 .47013 Mdot
.3701 .43756 Mdot
.46637 .28539 Mdot
.77713 .69172 Mdot
.92368 .14967 Mdot
.08642 .85411 Mdot
.25161 .61799 Mdot
.97079 .03331 Mdot
.59669 .93235 Mdot
.7496 .37686 Mdot
.22418 .4192 Mdot
.68489 .66756 Mdot
.88153 .94907 Mdot
.3148 .23 Mdot
.41516 .66368 Mdot
.53767 .53828 Mdot
.49147 .51401 Mdot
.45125 .68417 Mdot
.23986 .89602 Mdot
.48046 .65086 Mdot
.64317 .96367 Mdot
.73087 .274 Mdot
.41899 .54447 Mdot
.04597 .60643 Mdot
.53746 .59539 Mdot
.73118 .37643 Mdot
.1223 .93171 Mdot
.19351 .83815 Mdot
.63083 .4177 Mdot
.74226 .15398 Mdot
.39097 .52168 Mdot
.26179 .50312 Mdot
.7478 .55801 Mdot
.53093 .22912 Mdot
.32882 .01355 Mdot
.48496 .62269 Mdot
.79136 .41816 Mdot
.75378 .24625 Mdot
.66906 .48645 Mdot
.56027 .4081 Mdot
.03823 .06874 Mdot
.81801 .25413 Mdot
.64726 .54706 Mdot
.55622 .75101 Mdot
.89946 .98905 Mdot
.02529 .52189 Mdot
.57065 .9755 Mdot
.54033 .8992 Mdot
.77929 .55735 Mdot
.78655 .65295 Mdot
.11023 .0709 Mdot
.22628 .24485 Mdot
.072 .00216 Mdot
.40827 .99072 Mdot
.42474 .4551 Mdot
.85205 .23971 Mdot
.52528 .46605 Mdot
.82676 .71782 Mdot
.95463 .49055 Mdot
.28642 .81862 Mdot
.17534 .9332 Mdot
.49987 .16567 Mdot
.06511 .8623 Mdot
.27359 .92082 Mdot
.99311 .86015 Mdot
.86532 .9301 Mdot
.56838 .40505 Mdot
.01327 .69038 Mdot
.0431 .939 Mdot
.18652 .97256 Mdot
.08847 .44845 Mdot
.90009 .15394 Mdot
.91313 .51524 Mdot
.40022 .98827 Mdot
.84801 .65294 Mdot
.12663 .06745 Mdot
.8549 .7928 Mdot
.26131 .13735 Mdot
.28652 .38775 Mdot
.24804 .44697 Mdot
.24342 .44875 Mdot
.06152 .47441 Mdot
.15495 .0003 Mdot
.16143 .32047 Mdot
.24182 .48506 Mdot
.76121 .3322 Mdot
.39381 .83212 Mdot
.63458 .26475 Mdot
.53891 .03932 Mdot
.37327 .1274 Mdot
.25239 .65157 Mdot
.12523 .68043 Mdot
.00897 .20282 Mdot
.0637 .20602 Mdot
.85402 .20252 Mdot
.90227 .88554 Mdot
.6122 .71746 Mdot
.14106 .55334 Mdot
.21839 .88534 Mdot
.50649 .28859 Mdot
.67947 .84602 Mdot
.13322 .16119 Mdot
.42708 .19445 Mdot
.00799 .48076 Mdot
.41811 .99163 Mdot
.94429 .27474 Mdot
.56409 .78911 Mdot
.04202 .3892 Mdot
.95189 .07166 Mdot
.90096 .83586 Mdot
.7335 .18631 Mdot
.39447 .54727 Mdot
.05403 .34029 Mdot
.26125 .38608 Mdot
.62695 .14584 Mdot
.25326 .90532 Mdot
.20884 .1542 Mdot
.30897 .63058 Mdot
.64475 .36509 Mdot
.26695 .24138 Mdot
.69286 .29343 Mdot
.36599 .40552 Mdot
.95935 .10712 Mdot
.97152 .85825 Mdot
.90532 .76683 Mdot
.71027 .47217 Mdot
.27837 .621 Mdot
.45702 .56684 Mdot
.06953 .4668 Mdot
.14805 .93626 Mdot
.42479 .10171 Mdot
.8811 .69488 Mdot
.73193 .80827 Mdot
.51511 .28936 Mdot
.77258 .70115 Mdot
.54359 .43111 Mdot
.86726 .93432 Mdot
.83332 .95894 Mdot
.58889 .31332 Mdot
.3763 .3921 Mdot
.51935 .84653 Mdot
.22825 .45583 Mdot
.09456 .74482 Mdot
.34715 .76095 Mdot
.36263 .93654 Mdot
.83204 .47159 Mdot
.59006 .23539 Mdot
.28845 .04049 Mdot
.7228 .30107 Mdot
.45513 .08155 Mdot
.13391 .98775 Mdot
.07883 .68945 Mdot
.61456 .14122 Mdot
.85058 .23361 Mdot
.52 .39641 Mdot
.50343 .47266 Mdot
.15736 .45986 Mdot
.67139 .00107 Mdot
.5673 .22447 Mdot
.38295 .96058 Mdot
.84451 .9234 Mdot
.92782 .87903 Mdot
.71059 .93565 Mdot
.84899 .18959 Mdot
.09603 .79442 Mdot
.99841 .95597 Mdot
.57604 .39802 Mdot
.49498 .48331 Mdot
.41868 .93816 Mdot
.82358 .48225 Mdot
.85137 .71369 Mdot
.44064 .52167 Mdot
.00686 .79029 Mdot
.51282 .64264 Mdot
.29627 .85464 Mdot
.66383 .45305 Mdot
.20024 .06022 Mdot
.66542 .49708 Mdot
.6242 .66221 Mdot
.17044 .01376 Mdot
.20553 .72405 Mdot
.34686 .53151 Mdot
.35416 .01036 Mdot
.90622 .00984 Mdot
.34729 .22007 Mdot
.3934 .36721 Mdot
.05102 .36543 Mdot
.72957 .91416 Mdot
.85078 .30521 Mdot
.06415 .41708 Mdot
.22658 .643 Mdot
.8937 .40332 Mdot
.02106 .91895 Mdot
.54685 .87181 Mdot
.6669 .90858 Mdot
.64063 .86196 Mdot
.31961 .68851 Mdot
.24723 .49475 Mdot
.26859 .32308 Mdot
.51766 .58059 Mdot
.4178 .01788 Mdot
.45351 .16351 Mdot
.19122 .37488 Mdot
.55981 .76019 Mdot
.17016 .45593 Mdot
.01296 .88838 Mdot
.50326 .54735 Mdot
.37234 .02642 Mdot
.18365 .85883 Mdot
.12511 .53166 Mdot
.91507 .53575 Mdot
.60745 .95107 Mdot
.49726 .51787 Mdot
.15394 .78756 Mdot
.30604 .14299 Mdot
.59413 .02737 Mdot
.13588 .68706 Mdot
.58117 .13899 Mdot
.63262 .13972 Mdot
.20883 .11257 Mdot
.44897 .28088 Mdot
.08372 .58091 Mdot
.5339 .74513 Mdot
.47627 .62984 Mdot
.03664 .22726 Mdot
.32234 .84228 Mdot
.73059 .08427 Mdot
.72821 .81491 Mdot
.59471 .3972 Mdot
.14704 .67593 Mdot
.96209 .25749 Mdot
.93821 .56336 Mdot
.51313 .9766 Mdot
.85448 .98245 Mdot
.97923 .23147 Mdot
.37821 .35261 Mdot
.94259 .00421 Mdot
.05587 .51033 Mdot
.212 .91994 Mdot
.32767 .69541 Mdot
.61729 .52274 Mdot
.18063 .01949 Mdot
.6552 .26525 Mdot
.24242 .45613 Mdot
.14207 .28865 Mdot
.38794 .47368 Mdot
.16284 .05718 Mdot
.00973 .12107 Mdot
.22025 .05297 Mdot
.95386 .61075 Mdot
.00825 .13303 Mdot
.62619 .91533 Mdot
.39096 .61029 Mdot
.44556 .89585 Mdot
.73577 .34504 Mdot
.20314 .43972 Mdot
.5937 .05639 Mdot
.8152 .96604 Mdot
.43085 .99921 Mdot
.80547 .84496 Mdot
.2106 .94624 Mdot
.85161 .23422 Mdot
.20235 .81321 Mdot
.22542 .31889 Mdot
.81139 .20292 Mdot
.77986 .42304 Mdot
.07562 .85788 Mdot
.57672 .98332 Mdot
.48193 .80149 Mdot
.76152 .01729 Mdot
.05107 .80227 Mdot
.95605 .17232 Mdot
.84047 .85603 Mdot
.10444 .9381 Mdot
.63812 .04282 Mdot
.87902 .61922 Mdot
.82673 .8399 Mdot
.09916 .19618 Mdot
.75111 .98202 Mdot
.52244 .21285 Mdot
.26918 .18054 Mdot
.76092 .19556 Mdot
.21811 .37826 Mdot
.80487 .02324 Mdot
.37764 .52223 Mdot
.70044 .08514 Mdot
.73951 .47941 Mdot
.82142 .46592 Mdot
.91278 .63951 Mdot
.72226 .26975 Mdot
.16167 .65748 Mdot
.19981 .0569 Mdot
.89249 .47695 Mdot
.43889 .86133 Mdot
.67438 .09868 Mdot
.63402 .83809 Mdot
.29674 .57645 Mdot
.93358 .75295 Mdot
.55723 .09704 Mdot
.11216 .28703 Mdot
.64445 .45753 Mdot
.38991 .01728 Mdot
.48277 .80004 Mdot
.19009 .96038 Mdot
.59029 .3231 Mdot
.7512 .09905 Mdot
.91591 .22442 Mdot
.11719 .26096 Mdot
.61917 .64797 Mdot
.1836 .50801 Mdot
.06194 .55093 Mdot
.07144 .22099 Mdot
.4175 .0934 Mdot
.68153 .20371 Mdot
.93472 .29336 Mdot
.49144 .24333 Mdot
.34443 .97026 Mdot
.74024 .14428 Mdot
.42852 .74584 Mdot
.62305 .88332 Mdot
.80936 .09787 Mdot
.43945 .3753 Mdot
.74742 .54694 Mdot
.368 .15432 Mdot
.32992 .45354 Mdot
.68647 .95061 Mdot
.3952 .16018 Mdot
.19503 .70728 Mdot
.05077 .18992 Mdot
.4548 .563 Mdot
.62224 .44408 Mdot
.83175 .67969 Mdot
.81289 .34621 Mdot
.3923 .30438 Mdot
.06547 .79927 Mdot
.0243 .15007 Mdot
.73555 .34573 Mdot
.33782 .19946 Mdot
.34035 .18555 Mdot
.14279 .49218 Mdot
.28958 .99563 Mdot
.68799 .92918 Mdot
.66734 .55155 Mdot
.85625 .2495 Mdot
.85445 .20534 Mdot
.46395 .94511 Mdot
.78898 .40608 Mdot
.43965 .79505 Mdot
.05344 .06035 Mdot
.10182 .59558 Mdot
.71309 .8748 Mdot
.95903 .1034 Mdot
.42351 .87916 Mdot
.27104 .17422 Mdot
.75617 .32761 Mdot
.41479 .92472 Mdot
.90172 .12227 Mdot
.95085 .9796 Mdot
.11274 .71619 Mdot
.5112 .18456 Mdot
.0593 .65584 Mdot
.40937 .58897 Mdot
.34621 .78105 Mdot
.45034 .48557 Mdot
.9227 .90188 Mdot
.1793 .31136 Mdot
.16653 .57427 Mdot
.76451 .38664 Mdot
.26481 .452 Mdot
.81366 .40704 Mdot
.15207 .73581 Mdot
.30247 .22248 Mdot
.09277 .07997 Mdot
.89309 .6335 Mdot
.74655 .29892 Mdot
.44275 .14793 Mdot
.82385 .39704 Mdot
.26345 .83657 Mdot
.65732 .82277 Mdot
.49894 .44993 Mdot
.39251 .37076 Mdot
.68528 .0429 Mdot
.24044 .63495 Mdot
.38281 .82042 Mdot
.14767 .55498 Mdot
.48972 .18692 Mdot
.40112 .25606 Mdot
.04696 .03899 Mdot
.57727 .85902 Mdot
.78351 .20241 Mdot
.91995 .03625 Mdot
.28457 .75248 Mdot
.52744 .66549 Mdot
.59929 .70958 Mdot
.287 .03054 Mdot
.21648 .88916 Mdot
.13933 .47556 Mdot
.72676 .70224 Mdot
.73821 .2195 Mdot
.67979 .66325 Mdot
.16095 .36048 Mdot
.89628 .46084 Mdot
.241 .32423 Mdot
.61172 .70836 Mdot
.71356 .65874 Mdot
.01243 .99878 Mdot
.42656 .6282 Mdot
.79595 .10963 Mdot
.28723 .15264 Mdot
.06919 .40739 Mdot
.54902 .93314 Mdot
.3894 .74413 Mdot
.38807 .57266 Mdot
.49312 .28329 Mdot
.14707 .24843 Mdot
.8814 .57493 Mdot
.43351 .58969 Mdot
.86898 .57615 Mdot
.00695 .96149 Mdot
.07302 .46652 Mdot
.71972 .80885 Mdot
.00383 .05913 Mdot
.1707 .87571 Mdot
.61443 .315 Mdot
.78263 .30305 Mdot
.12131 .03171 Mdot
.63556 .05462 Mdot
.23991 .45677 Mdot
.20206 .46493 Mdot
.37093 .88062 Mdot
.19511 .50345 Mdot
.29791 .4141 Mdot
.47539 .6946 Mdot
.29408 .35497 Mdot
.30469 .81889 Mdot
.67965 .03997 Mdot
.52206 .51584 Mdot
.55834 .00826 Mdot
.8865 .46122 Mdot
.31843 .55149 Mdot
.68444 .99628 Mdot
.9475 .67087 Mdot
.48933 .49284 Mdot
.64959 .25676 Mdot
.01393 .79824 Mdot
.35551 .9018 Mdot
.70924 .97935 Mdot
.67586 .86183 Mdot
.18718 .46351 Mdot
.11752 .85356 Mdot
.30069 .00229 Mdot
.79909 .30207 Mdot
.61625 .00601 Mdot
.8516 .63121 Mdot
.12692 .51317 Mdot
.20201 .37444 Mdot
.11299 .71493 Mdot
.84649 .47265 Mdot
.40374 .73558 Mdot
.17063 .61082 Mdot
.21656 .27207 Mdot
.05311 .75726 Mdot
.91588 .26978 Mdot
.25402 .45518 Mdot
.29963 .26377 Mdot
.40242 .82398 Mdot
.17271 .7506 Mdot
.20041 .44954 Mdot
.05972 .03567 Mdot
.35392 .97689 Mdot
.65598 .30009 Mdot
.18329 .36607 Mdot
.43942 .02802 Mdot
.13018 .60882 Mdot
.52354 .75824 Mdot
.87616 .15364 Mdot
.22391 .49447 Mdot
.47374 .32966 Mdot
.0512 .74387 Mdot
.27333 .88012 Mdot
.99148 .7082 Mdot
.91941 .90323 Mdot
.3355 .40811 Mdot
.73612 .53716 Mdot
.89608 .38009 Mdot
.60594 .92834 Mdot
.37254 .62185 Mdot
.72978 .7747 Mdot
.14863 .12738 Mdot
.25603 .44505 Mdot
.09743 .38351 Mdot
.9827 .56492 Mdot
.10595 .6753 Mdot
.06329 .66169 Mdot
.77045 .26719 Mdot
.32717 .12454 Mdot
.87437 .88709 Mdot
.72123 .1962 Mdot
.50182 .26524 Mdot
.99146 .4215 Mdot
.35319 .13786 Mdot
.73543 .97645 Mdot
.25576 .75436 Mdot
.75273 .41153 Mdot
.14981 .07906 Mdot
.68943 .74983 Mdot
.37935 .81187 Mdot
.36226 .6253 Mdot
.50498 .92478 Mdot
.64103 .42909 Mdot
.00316 .65953 Mdot
.64957 .0076 Mdot
.64997 .52167 Mdot
.91414 .03114 Mdot
.39421 .76731 Mdot
.16142 .61962 Mdot
.2444 .68825 Mdot
.47198 .86978 Mdot
.86505 .87638 Mdot
.10972 .24449 Mdot
.36007 .95161 Mdot
.46869 .81539 Mdot
.35691 .29207 Mdot
.81912 .80779 Mdot
.70694 .7704 Mdot
.90498 .77665 Mdot
.31273 .0031 Mdot
.74356 .15703 Mdot
.06833 .31484 Mdot
.27158 .28725 Mdot
.20328 .43846 Mdot
.16186 .04276 Mdot
.84321 .48686 Mdot
.69316 .22737 Mdot
.48631 .19479 Mdot
.87404 .41958 Mdot
.77937 .42438 Mdot
.96906 .64293 Mdot
.46664 .42128 Mdot
.22549 .48589 Mdot
.39831 .10644 Mdot
.95391 .19864 Mdot
.19503 .66798 Mdot
.79206 .15588 Mdot
.35182 .18112 Mdot
.0989 .92851 Mdot
.86551 .98633 Mdot
.22486 .50893 Mdot
.08614 .56195 Mdot
.25581 .866 Mdot
.6195 .14067 Mdot
.03031 .38011 Mdot
.22119 .03423 Mdot
.0764 .18147 Mdot
.02617 .36625 Mdot
.28434 .02559 Mdot
.67435 .18513 Mdot
.18544 .09708 Mdot
.80884 .1988 Mdot
.96058 .58815 Mdot
.7227 .63685 Mdot
.70477 .72215 Mdot
.1032 .49618 Mdot
.67446 .34205 Mdot
.882 .46195 Mdot
.59806 .16058 Mdot
.85584 .0957 Mdot
.31372 .13499 Mdot
.18149 .91057 Mdot
.12828 .03791 Mdot
.37265 .71176 Mdot
.1677 .44976 Mdot
.64995 .07491 Mdot
.46293 .7276 Mdot
.54675 .57873 Mdot
.78847 .38556 Mdot
.66475 .11678 Mdot
.19041 .22497 Mdot
.80891 .02108 Mdot
.87669 .08998 Mdot
.62742 .11051 Mdot
.74842 .05207 Mdot
.25477 .39875 Mdot
.58072 .60231 Mdot
.60483 .32384 Mdot
.11779 .87471 Mdot
.05808 .7451 Mdot
.32932 .48915 Mdot
.39333 .62832 Mdot
.1389 .26418 Mdot
.58443 .60725 Mdot
.26221 .1742 Mdot
.95701 .49673 Mdot
.51379 .12213 Mdot
.70223 .09798 Mdot
.93308 .51982 Mdot
.0974 .77415 Mdot
.81529 .64511 Mdot
.03932 .02904 Mdot
.48598 .15596 Mdot
.64599 .40072 Mdot
.34707 .89178 Mdot
.06156 .79347 Mdot
.08486 .71758 Mdot
.10456 .29674 Mdot
.57107 .59545 Mdot
.40232 .19876 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool00oooool2o`0000Sooooo00?o0000ooooooooool00_ooool2o`0000Wo
oooo0ol0000>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool2o`0000;o
oooo0_l0000:ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo0_l00008ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool01?ooool2o`0000Sooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo0000ooooo`03ooooo`;o
00002_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00?ooooo0_l00008ooooo`03o`000?oooooooooo00;ooooo0_l00009ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`;o0000
0_ooool2o`0000[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`04o`00
0?ooooooooooooooo`;o00002_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool01?ooool2o`0000Sooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo0000ooooo`03ooooo`;o
00002_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003oooooooooo`1_ooooo`;o0000
@?ooool2o`00017ooooo0_l00009ooooo`;o0000D_ooool2o`0002;ooooo000Nooooo`03o`000?oo
oooooooo06Oooooo0_l00006ooooo`;o00003_ooool2o`00033ooooo0_l0000Eooooo`;o00001Ooo
ool2o`0005;ooooo0_l0000Rooooo`007_ooool00ol0003oooooooooo`0cooooo`;o0000<_ooool2
o`0001Kooooo0_l0000fooooo`;o00003oooool2o`0007gooooo000Nooooo`03o`000?oooooooooo
03?ooooo0_l00002ooooo`;o0000@_ooool2o`0000Oooooo0_l00007ooooo`;o0000:?ooool2o`00
023ooooo0_l0000Hooooo`;o0000D_ooool001kooooo00?o0000ooooooooool0=oooool2o`0004;o
oooo0_l00007ooooo`;o00001oooool2o`0004[ooooo0_l0000Hooooo`;o00003_ooool2o`0000[o
oooo0_l0000fooooo`007_ooool00ol0003oooooooooo`1Hooooo`;o0000Foooool2o`0004_ooooo
0ol0000:ooooo`;o0000=_ooool001kooooo00?o0000ooooooooool02Oooool2o`0004gooooo0_l0
000Kooooo`;o00005?ooool2o`0002Sooooo0_l00006ooooo`;o0000@oooool2o`0003Kooooo0_l0
000;ooooo`007_ooool00ol0003oooooooooo`09ooooo`;o00006?ooool2o`0000cooooo0_l0000V
ooooo`;o00006_ooool2o`0001Cooooo0_l0000`ooooo`;o0000I_ooool2o`0001?ooooo0_l0000;
ooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o00005_ooool2o`0000cooooo0_l0000Aoooo
o`;o00004oooool2o`000<[ooooo0_l0000Aooooo`;o00003Oooool001kooooo00?o0000oooooooo
ool02oooool2o`0000;ooooo0_l0000Eooooo`;o00007?ooool2o`0001Cooooo0_l0000Rooooo`;o
0000Yoooool2o`0000oooooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o0000
0_ooool2o`0001Gooooo0_l00004ooooo`;o0000;?ooool2o`0002;ooooo0_l0000[ooooo`;o0000
8Oooool2o`0000Wooooo0_l0001<ooooo`;o00007_ooool001kooooo00?o0000ooooooooool01_oo
ool2o`0000?ooooo0_l0000Oooooo`;o00000oooool2o`0002Oooooo0_l0001?ooooo`;o00007_oo
ool2o`000003ooooool0003o000000Wooooo1?l0001Zooooo`007_ooool00ol0003oooooooooo`06
ooooo`;o0000:Oooool2o`0009Sooooo0_l0000>ooooo`;o0000J_ooool001kooooo00?o0000oooo
ooooool0C?ooool2o`0001[ooooo0_l0003Mooooo`007_ooool2o`0004Cooooo0_l00007ooooo`;o
00006_ooool2o`00083ooooo0_l00003ooooo`;o0000E_ooool001kooooo00?o0000ooooooooool0
@oooool2o`0004kooooo0_l0000Xooooo`;o00003?ooool2o`0001gooooo0_l00003ooooo`;o0000
E_ooool001kooooo0_l0000Iooooo`;o00005oooool2o`0000[ooooo0_l00016ooooo`;o00003?oo
ool2o`0002Sooooo0_l0000<ooooo`;o0000N_ooool001kooooo0_l0000>ooooo`;o00002Oooool2
o`0001Oooooo0_l00007ooooo`;o000000?oooooo`000?l00000A_ooool2o`0008_ooooo0_l0000c
ooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o0000:oooool2o`000003ooooool0003o0000
0=?ooooo0_l0000cooooo`007_ooool00ol0003oooooooooo`08ooooo`;o00006oooool2o`0003[o
oooo0_l0003Tooooo`007_ooool00ol0003oooooooooo`08ooooo`;o00005_ooool2o`0000?ooooo
0_l0000jooooo`;o0000c_ooool2o`0001Cooooo000Nooooo`03o`000?oooooooooo023ooooo0_l0
000]ooooo`;o0000>?ooool2o`0004Cooooo0_l0000;ooooo`;o00001_ooool2o`0004_ooooo0_l0
000Dooooo`007_ooool00ol0003oooooooooo`15ooooo`;o00002?ooool2o`0003Sooooo0_l00014
ooooo`;o00002oooool2o`0000Kooooo0_l0001Qooooo`007_ooool00ol0003oooooooooo`0Joooo
o`;o00004Oooool2o`0001Kooooo0_l0003oooooo`7ooooo000Nooooo`03o`000?oooooooooo01[o
oooo0_l00006ooooo`;o00002Oooool2o`00067ooooo0_l0001Gooooo`;o0000G?ooool001kooooo
00?o0000ooooooooool08_ooool2o`0004kooooo0_l0000Looooo`;o0000C_ooool2o`0000Oooooo
0_l0001Looooo`007_ooool00ol0003oooooooooo`1booooo`;o0000K?ooool2o`0003Oooooo0_l0
000Fooooo`;o00005?ooool001kooooo00?o0000ooooooooool0Moooool2o`0000_ooooo0_l00014
ooooo`;o00002Oooool2o`0004;ooooo0_l0000Fooooo`;o00005?ooool001kooooo00?o0000oooo
ooooool0Moooool2o`0000_ooooo0_l0000;ooooo`;o00002Oooool2o`0002?ooooo0_l00007oooo
o`;o00002Oooool2o`0003_ooooo0_l0000cooooo`007_ooool00ol0003oooooooooo`02ooooo`;o
00009Oooool2o`0000gooooo0_l0001Gooooo`;o00000_ooool2o`0000Gooooo0_l0000Cooooo`;o
00003_ooool2o`0001Cooooo0_l00007ooooo`;o00003_ooool2o`00017ooooo0_l0000=ooooo`;o
00005?ooool2o`0001gooooo000Nooooo`;o00000oooool2o`0002Gooooo0_l0000=ooooo`;o0000
A?ooool2o`0000Kooooo0_l0000=ooooo`;o00006_ooool2o`0002Cooooo0_l00007ooooo`;o0000
3_ooool2o`00017ooooo0_l0000?ooooo`;o00004_ooool2o`0001gooooo000Nooooo`03o`000?oo
oooooooo07kooooo0_l00006ooooo`;o0000S?ooool2o`0001kooooo0_l0000Aooooo`007_ooool0
0ol0003oooooooooo`1mooooo`;o0000]Oooool2o`00017ooooo000Nooooo`03o`000?oooooooooo
07gooooo0ol00018ooooo`;o0000=Oooool2o`0003?ooooo0_l0000Aooooo`007_ooool00ol0003o
ooooooooo`10ooooo`;o0000??ooool2o`0004Sooooo0_l0000:ooooo`;o0000:Oooool2o`0000So
oooo0_l0000looooo`007_ooool00ol0003oooooooooo`10ooooo`;o0000T_ooool2o`0000kooooo
0_l0000Sooooo`;o0000??ooool001kooooo00Co0000ooooool0003o00003oooool2o`0000Oooooo
0_l00018ooooo`;o0000Koooool2o`0000kooooo0_l0001Qooooo`007_ooool01?l0003oooooo`00
0?l0000?ooooo`;o00001oooool2o`0004Sooooo0_l0000nooooo`;o0000O?ooool2o`0002Cooooo
000Nooooo`03o`000?oooooooooo02cooooo0_l0000hooooo`;o00003Oooool2o`0002cooooo0_l0
001looooo`;o00009?ooool001kooooo00?o0000ooooooooool0;?ooool2o`00023ooooo0_l0000F
ooooo`;o00003Oooool2o`0005kooooo0_l0001Fooooo`;o00006?ooool001kooooo00Co0000oooo
ool0003o00003?ooool2o`0000gooooo0_l0000`ooooo`;o0000;_ooool2o`0003;ooooo0_l0000F
ooooo`;o00002Oooool2o`0005Kooooo0_l0000Hooooo`007_ooool01?l0003oooooo`000?l0000<
ooooo`;o00003Oooool2o`0004Cooooo0_l0000Jooooo`;o00001?ooool2o`0002Kooooo0_l00004
ooooo`;o00005_ooool2o`00077ooooo0_l00008ooooo`007_ooool00ol0003oooooooooo`1Aoooo
o`;o00003oooool2o`0000Kooooo0_l00003ooooo`;o00004oooool2o`0002Kooooo0_l0000;oooo
o`;o00003oooool2o`00077ooooo0_l00008ooooo`007_ooool00ol0003oooooooooo`1Aooooo`;o
00005oooool2o`0000?ooooo0_l00018ooooo`;o00002Oooool3o`0000?ooooo0_l0001kooooo`00
7_ooool00ol0003oooooooooo`1Oooooo`;o0000Hoooool3o`000003ooooool0003o000002?ooooo
0_l0001Hooooo`007_ooool00ol0003oooooooooo`1Oooooo`;o0000:oooool2o`0001Wooooo0_l0
000Oooooo`;o00008oooool2o`0005Sooooo000Nooooo`;o00001Oooool2o`0004Sooooo0_l0000Q
ooooo`;o00006Oooool2o`0001Wooooo0_l0001oooooo`;o00007Oooool001kooooo00?o0000oooo
ooooool01?ooool2o`0003[ooooo0_l0000<ooooo`;o00002Oooool2o`0001Kooooo0_l000000ooo
oooo0000o`00001gooooo`;o0000:_ooool2o`0000Kooooo0_l00005ooooo`;o00007Oooool001ko
oooo00?o0000ooooooooool0@?ooool2o`0001Oooooo0_l0000Iooooo`;o00005Oooool2o`0000go
oooo0_l0001Aooooo`?o00003Oooool2o`0001[ooooo0_l00006ooooo`;o00009?ooool001kooooo
00?o0000ooooooooool09oooool2o`0005?ooooo0_l0000=ooooo`;o00003Oooool2o`0002;ooooo
0_l0000^ooooo`;o00003Oooool2o`0004Sooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l0
001Cooooo`;o00004Oooool2o`0002gooooo0_l0000]ooooo`;o0000<?ooool2o`0002Kooooo000N
ooooo`03o`000?oooooooooo077ooooo0_l0000Looooo`;o00003Oooool2o`0000kooooo0_l0000m
ooooo`;o0000<?ooool2o`0002Kooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0001Voooo
o`;o0000:oooool2o`0000kooooo0_l0002Gooooo`007_ooool00ol0003oooooooooo`09ooooo`;o
0000COooool2o`00027ooooo0_l0002fooooo`;o00004_ooool001kooooo00?o0000ooooooooool0
DOooool2o`000003ooooool0003o000000;ooooo0_l0000Qooooo`;o0000]_ooool2o`0001;ooooo
000Nooooo`03o`000?oooooooooo057ooooo0_l000000ooooooo0000o`00003aooooo`007_ooool0
0ol0003oooooooooo`0Eooooo`;o0000??ooool2o`0001Wooooo0_l0003Gooooo`007_ooool00ol0
003oooooooooo`0Eooooo`;o0000??ooool2o`0001Kooooo0_l000000ooooooo0000o`00000boooo
o`;o0000<oooool2o`00043ooooo0_l0000/ooooo`007_ooool00ol0003oooooooooo`1[ooooo`;o
0000;_ooool2o`0000Gooooo0_l0000cooooo`;o00004Oooool2o`0002gooooo0ol0000[ooooo`00
7_ooool00ol0003oooooooooo`0<ooooo`;o0000SOooool2o`0004gooooo0_l0000Tooooo`;o0000
2?ooool2o`0002_ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol00006ooooo`03o`000?oooooooooo00cooooo0_l0001iooooo`;o00004Oooool2o`0002Oooooo
0_l0001;ooooo`;o0000=Oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool07?ooool2o`0006Wo
oooo0_l0000Aooooo`;o00002oooool2o`0001[ooooo0_l0000Qooooo`;o00002oooool2o`0002Oo
oooo0_l0000Yooooo`000oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^
k^h01oooool3o`0001cooooo0_l0001<ooooo`;o00004oooool2o`0002Kooooo0_l0000mooooo`;o
00002oooool2o`0000kooooo0_l0000Gooooo`;o00005?ooool2o`0001?ooooo0003ooooo`05o`00
0?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`04o`000?oooooo0000o`00
06Wooooo0_l0000Cooooo`;o0000F?ooool2o`00023ooooo0_l00006ooooo`?o00003?ooool2o`00
01kooooo0_l0000Cooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool01Oooool01?l0003oooooo`000?l0000@ooooo`;o0000a_ooool2o`0000?ooooo0_l0000K
ooooo`;o00001oooool2o`0000cooooo0_l0000cooooo`000oooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Aooooo`;o0000boooool2
o`0003;ooooo0_l0000cooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000
okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo02[ooooo0_l0001jooooo`;o0000Sooo
ool2o`0000kooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`00
0?lQ8B7oc<c<00Kooooo00?o0000ooooooooool07_ooool2o`0000[ooooo1?l0000iooooo`;o0000
?Oooool2o`0004gooooo0_l00010ooooo`;o00003_ooool001kooooo00?o0000ooooooooool07_oo
ool2o`0000cooooo0_l0000Oooooo`;o00006?ooool2o`0000Gooooo0_l0001looooo`;o00001ooo
ool2o`0000Wooooo0_l00015ooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o0000>?ooool2
o`0000oooooo0_l0000=ooooo`?o0000@Oooool2o`0003Wooooo0_l0000Booooo`;o0000AOooool0
01kooooo00?o0000ooooooooool04oooool2o`00013ooooo0_l0000Cooooo`;o00002Oooool2o`00
01Oooooo0_l0000=ooooo`;o0000@_ooool2o`000003ooooool0003o0000073ooooo0_l0000Ooooo
o`007_ooool00ol0003oooooooooo`08ooooo`;o00006oooool2o`0001?ooooo0_l00003ooooo`;o
00001?ooool2o`0006gooooo0_l0000Wooooo`;o0000Aoooool2o`0001oooooo000Nooooo`03o`00
0?oooooooooo00Sooooo0_l0000eooooo`;o00008Oooool2o`0004Cooooo0_l0000cooooo`;o0000
@oooool2o`0001Kooooo0_l000000ooooooo0000o`000008ooooo`007_ooool00ol0003ooooooooo
o`1Rooooo`;o0000A?ooool2o`0006Kooooo0ol0000?ooooo`;o00005_ooool2o`000003ooooool0
003o000000Sooooo000Nooooo`03o`000?oooooooooo07;ooooo0_l00018ooooo`;o0000D_ooool3
o`0003Cooooo000Nooooo`03o`000?oooooooooo07;ooooo0_l00018ooooo`;o00003oooool2o`00
03?ooooo0_l0000=ooooo`;o0000:oooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo05?o
oooo0_l00017ooooo`;o0000;oooool2o`0003?ooooo0_l0000=ooooo`;o0000:oooool2o`0000Oo
oooo000Nooooo`03o`000?oooooooooo023ooooo0_l0000Sooooo`;o00003?ooool2o`0004Oooooo
0_l0001Cooooo`;o0000E?ooool001kooooo00?o0000ooooooooool08?ooool2o`0000[ooooo0_l0
000Gooooo`;o0000Z_ooool2o`0001oooooo0_l0000cooooo`007_ooool2o`0002gooooo0_l0003T
ooooo`;o0000<oooool001kooooo00?o0000ooooooooool0O_ooool2o`0008Kooooo0_l0000ooooo
o`007_ooool00ol0003oooooooooo`1nooooo`;o0000Coooool2o`0003Gooooo0_l0000]ooooo`;o
00004?ooool001kooooo00?o0000ooooooooool08_ooool2o`0007Wooooo0_l0000`ooooo`;o0000
I?ooool2o`00013ooooo000Nooooo`03o`000?oooooooooo02;ooooo0_l00005ooooo`;o0000<_oo
ool2o`0003kooooo1?l0000Yooooo`;o00001Oooool2o`0007Cooooo000Nooooo`03o`000?oooooo
oooo02Wooooo0_l0000Sooooo`;o00003Oooool2o`00043ooooo0_l0000Yooooo`;o00001Oooool2
o`0002?ooooo0_l0001?ooooo`007_ooool00ol0003oooooooooo`0Looooo`;o00009?ooool2o`00
00[ooooo0_l0000Zooooo`;o0000H_ooool2o`0000Oooooo0_l0000=ooooo`;o0000;_ooool2o`00
01oooooo000Nooooo`03o`000?oooooooooo01cooooo0_l0000Tooooo`;o0000=?ooool4o`0006;o
oooo0_l00007ooooo`;o000000?oooooo`000?l00000>_ooool2o`0000Oooooo0_l0000Fooooo`00
7_ooool00ol0003oooooooooo`1hooooo`;o0000H?ooool2o`0000kooooo0_l00013ooooo`;o0000
5_ooool001kooooo00?o0000ooooooooool04oooool2o`0001Gooooo0_l0001Rooooo`;o0000B_oo
ool2o`0006_ooooo000Nooooo`03o`000?oooooooooo01?ooooo0_l0000Eooooo`;o0000H_ooool2
o`0000cooooo0_l00008ooooo`;o0000KOooool2o`00033ooooo000Nooooo`03o`000?oooooooooo
023ooooo0_l0000booooo`;o0000?_ooool2o`0000Kooooo0_l00008ooooo`;o0000F_ooool2o`00
00kooooo0_l000000ooooooo0000o`00000`ooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o
00002?ooool2o`0002Sooooo0_l0000nooooo`;o00002oooool4o`0005gooooo0_l0000>ooooo`;o
0000<oooool001kooooo0ol0000Uooooo`;o00000oooool2o`0004Cooooo0_l0000_ooooo`Co0000
>?ooool2o`0004gooooo0_l0000Iooooo`007_ooool4o`0002Cooooo0_l00019ooooo`;o0000Jooo
ool2o`0004gooooo0_l0000Iooooo`007_ooool01?l0003oooooo`000?l0000Mooooo`;o0000cooo
ool2o`0005Kooooo000Nooooo`;o00007oooool2o`000;7ooooo0_l0000Dooooo`;o00001_ooool2
o`0000oooooo0_l00015ooooo`007_ooool00ol0003oooooooooo`1kooooo`;o0000E?ooool2o`00
01Cooooo0_l0000>ooooo`;o000000?oooooo`000?l000001?ooool2o`0000kooooo0_l0000eoooo
o`007_ooool00ol0003oooooooooo`1kooooo`;o0000N_ooool2o`000003ooooool0003o000001Co
oooo0_l0000Pooooo`;o00003?ooool2o`0000Gooooo000Nooooo`?o00002?ooool2o`0002cooooo
0_l0003jooooo`;o00003?ooool2o`0000Gooooo000Nooooo`?o00002?ooool2o`0000Sooooo0_l0
000Rooooo`;o0000Poooool2o`0000Oooooo0_l00021ooooo`007_ooool00ol0003oooooooooo`0B
ooooo`;o0000Yoooool2o`0000Oooooo0_l00021ooooo`007_ooool00ol0003oooooooooo`0`oooo
o`;o00004oooool2o`000?oooooo0Oooool001kooooo00?o0000ooooooooool0<?ooool2o`0001?o
oooo0_l00003ooooo`;o00001oooool2o`0000_ooooo0_l0000eooooo`;o00008oooool2o`0000?o
oooo0_l0000`ooooo`;o00004oooool2o`0003gooooo000Nooooo`03o`000?oooooooooo02?ooooo
0_l0000Uooooo`;o00001oooool2o`0000_ooooo0_l0000eooooo`;o00008oooool2o`0000?ooooo
0_l0000`ooooo`;o00004oooool2o`0003gooooo000Nooooo`03o`000?oooooooooo01gooooo0_l0
0004ooooo`;o0000LOooool3o`0005Wooooo0_l0001Cooooo`007_ooool00ol0003oooooooooo`0M
ooooo`;o0000Moooool2o`0000_ooooo0_l0001=ooooo`?o0000D_ooool001kooooo00?o0000oooo
ooooool0Xoooool2o`0004kooooo0_l0000`ooooo`;o00008?ooool001kooooo00?o0000oooooooo
ool0Soooool2o`0002kooooo0_l0001Tooooo`;o00008?ooool001kooooo00?o0000ooooooooool0
3Oooool2o`00083ooooo0_l0000^ooooo`;o00005_ooool2o`0001Wooooo0_l0001Cooooo`007_oo
ool00ol0003oooooooooo`0=ooooo`;o0000VOooool2o`0002gooooo0_l0000Booooo`;o00001Ooo
ool2o`0003;ooooo0_l0000Oooooo`007_ooool00ol0003oooooooooo`1Wooooo`;o0000?oooool2
o`0002[ooooo0_l0000Eooooo`;o00005oooool2o`00023ooooo0_l0000Oooooo`007_ooool2o`00
05cooooo0_l0000:ooooo`;o0000Joooool2o`0002kooooo0_l00011ooooo`007_ooool00ol0003o
ooooooooo`1Kooooo`;o00006_ooool2o`000<kooooo000Nooooo`03o`000?oooooooooo05_ooooo
0_l0000Jooooo`;o0000c_ooool001kooooo00?o0000ooooooooool0<?ooool2o`0000_ooooo0_l0
003oooooo`Wooooo000Nooooo`03o`000?oooooooooo033ooooo0_l0000;ooooo`;o0000<Oooool2
o`000=Gooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l00006ooooo`;o00004?ooool2o`00
01Oooooo0_l00003ooooo`;o0000:_ooool2o`0000Kooooo0_l0000:ooooo`;o00003?ooool2o`00
04;ooooo0_l0001Jooooo`;o00006oooool001kooooo00?o0000ooooooooool01?ooool2o`0000Ko
oooo0_l0000@ooooo`;o00005oooool2o`0000?ooooo0_l0000Zooooo`;o00004Oooool3o`0000co
oooo0_l00012ooooo`;o0000F_ooool2o`0001_ooooo000Nooooo`04o`000?ooooooooooooooo`;o
0000N?ooool2o`000<[ooooo000Nooooo`04o`000?ooooooooooooooo`;o0000=oooool2o`0000;o
oooo0_l0000kooooo`;o00003_ooool2o`0005gooooo0_l0001Kooooo`007_ooool00ol0003ooooo
ooooo`0jooooo`;o00000_ooool2o`0000?ooooo0_l00016ooooo`;o0000GOooool2o`0000Cooooo
0_l0001Eooooo`007_ooool00ol0003oooooooooo`06ooooo`;o0000>oooool2o`000:_ooooo0_l0
000]ooooo`;o00009_ooool001kooooo00?o0000ooooooooool01_ooool2o`0001Cooooo0_l00007
ooooo`;o0000C_ooool2o`0008Gooooo0_l0000Qooooo`;o00009_ooool001kooooo00?o0000oooo
ooooool07?ooool2o`0000Oooooo0_l0000Zooooo`;o00001_ooool2o`0000Kooooo0_l0000Boooo
o`;o00001?ooool2o`0007Oooooo0_l00006ooooo`;o0000BOooool001kooooo00?o0000oooooooo
ool02_ooool2o`0004Gooooo0_l00006ooooo`;o00001_ooool2o`0001Sooooo0_l0000<ooooo`;o
0000JOooool2o`00057ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo0_l0001Zooooo`;o
00004Oooool2o`0009_ooooo0_l0000Oooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0M_ooool2o`0002go
oooo0_l00004ooooo`;o00002_ooool2o`0000Cooooo0_l00019ooooo`;o00007?ooool2o`0001oo
oooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol0001?ooooo`;o
0000E?ooool2o`0000Cooooo0_l0000:ooooo`;o00001?ooool2o`0000oooooo0_l0000hooooo`;o
0000<_ooool2o`0000Wooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4Co
gMgMooooool00007ooooo`03o`000?oooooooooo04oooooo0_l0001mooooo`;o00004Oooool2o`00
03_ooooo0_l0000Looooo`;o00002Oooool000?ooooo00Go0000ooooooooooooooooo`00000;oooo
o`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool04_ooool2o`00037ooooo0_l0000/
ooooo`;o0000@?ooool2o`0002[ooooo0_l00006ooooo`;o00004Oooool2o`0000Kooooo0_l0000H
ooooo`;o00009oooool000?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co
000000Oooooo00?o0000ooooooooool04_ooool2o`00037ooooo0_l0000Rooooo`;o00002?ooool2
o`0003gooooo0_l000000ooooooo0000o`00000booooo`;o00004Oooool2o`0000Kooooo0_l00011
ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool0
0ol0003oooooooooo`1Yooooo`;o0000Aoooool2o`0003gooooo0_l0001Dooooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`1M
ooooo`;o0000T_ooool2o`0005Cooooo000Nooooo`03o`000?oooooooooo00gooooo0_l00002oooo
o`;o0000<_ooool2o`0001Kooooo0_l0000Kooooo`;o00006Oooool2o`0003;ooooo0_l0000boooo
o`;o00006Oooool2o`0002gooooo000Nooooo`03o`000?oooooooooo00gooooo0_l00002ooooo`;o
00008_ooool2o`0000kooooo0_l0000cooooo`;o00006?ooool3o`0000Gooooo0_l0000[ooooo`;o
0000<_ooool2o`0001Wooooo0_l0000Tooooo`;o00001oooool001kooooo00?o0000ooooooooool0
=Oooool2o`0005gooooo0_l00006ooooo`;o0000Foooool3o`0004;ooooo0_l00007ooooo`007_oo
ool00ol0003oooooooooo`2Jooooo`;o0000GOooool3o`0004_ooooo000Nooooo`03o`000?oooooo
oooo09[ooooo0_l0000Aooooo`;o00007Oooool2o`0007Wooooo000Nooooo`03o`000?oooooooooo
0:gooooo0_l0000Mooooo`;o0000>oooool2o`0003cooooo000Nooooo`03o`000?oooooooooo07Co
oooo0_l0002Cooooo`;o0000??ooool001kooooo00?o0000ooooooooool0;oooool2o`0000gooooo
0_l0000dooooo`;o0000dOooool001kooooo00?o0000ooooooooool0;oooool2o`0000gooooo0_l0
0026ooooo`;o0000Ooooool001kooooo00?o0000ooooooooool0COooool4o`00047ooooo0_l0000b
ooooo`;o0000Ooooool001kooooo00?o0000ooooooooool06Oooool2o`0001Oooooo0_l00009oooo
o`;o00002_ooool8o`00047ooooo0_l0000:ooooo`;o0000U?ooool2o`00017ooooo000Nooooo`;o
00006_ooool2o`0001Oooooo0_l00009ooooo`;o00002_ooool4o`0000Gooooo0_l0000Cooooo`;o
0000:?ooool2o`0000_ooooo0_l0000dooooo`;o0000G_ooool2o`00017ooooo000Nooooo`03o`00
0?oooooooooo02cooooo0_l00005ooooo`;o00004Oooool2o`0000?ooooo0_l000000ooooooo0000
o`000002ooooo`;o00004oooool2o`0001gooooo0_l00009ooooo`;o0000@Oooool2o`00077ooooo
000Nooooo`03o`000?oooooooooo02cooooo0_l00005ooooo`;o00004Oooool2o`0000;ooooo0ol0
00001?oooooo0000o`000?ooool2o`0003?ooooo0_l00015ooooo`;o0000N?ooool001kooooo00?o
0000ooooooooool0;oooool2o`0001Wooooo0_l00005ooooo`;o00001?ooool2o`0007Cooooo0_l0
000Oooooo`;o0000:oooool3o`000003ooooool0003o000002Kooooo000Nooooo`03o`000?oooooo
oooo02oooooo0_l00008ooooo`;o00000oooool2o`0001Oooooo0_l0002Eooooo`;o0000:oooool3
o`000003ooooool0003o000002Kooooo000Nooooo`03o`000?oooooooooo01;ooooo1?l0000Soooo
o`;o00000oooool2o`0006Oooooo0_l0001Nooooo`;o0000?_ooool001kooooo00?o0000oooooooo
ool04_ooool4o`0005Gooooo0_l0000jooooo`;o0000:_ooool2o`0003;ooooo0_l000000ooooooo
0000o`00000kooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o0000FOooool2o`0000gooooo
0_l0000Tooooo`;o0000<Oooool2o`0000kooooo0_l0000Uooooo`;o00000oooool2o`0003Kooooo
000Nooooo`03o`000?oooooooooo013ooooo0_l0000Gooooo`;o0000Coooool2o`0002Cooooo0_l0
0011ooooo`;o0000:_ooool2o`0000gooooo0_l0000Wooooo`007_ooool3o`0002Wooooo0_l00031
ooooo`;o0000<?ooool2o`0000_ooooo0_l0000Jooooo`007_ooool3o`0009Oooooo0_l00004oooo
o`;o00000oooool2o`0004Sooooo0_l0000Jooooo`;o00008Oooool2o`0001[ooooo000Nooooo`03
o`000?oooooooooo04Gooooo0_l00004ooooo`;o0000@Oooool2o`0000Oooooo0_l00004ooooo`;o
00000oooool2o`00037ooooo0_l0000aooooo`;o00001?ooool2o`0003Oooooo000Nooooo`03o`00
0?oooooooooo04Gooooo0_l00004ooooo`;o00006_ooool2o`0002Gooooo0_l00015ooooo`;o0000
=oooool2o`0001oooooo0_l0000Fooooo`007_ooool00ol0003oooooooooo`0Zooooo`;o0000>ooo
ool2o`0003;ooooo0_l0000mooooo`;o0000<?ooool2o`0001cooooo0_l00003ooooo`;o000000?o
ooooo`000?l000004oooool001kooooo00?o0000ooooooooool07Oooool2o`0000_ooooo0_l0000I
ooooo`;o00001Oooool2o`0004gooooo0_l0000mooooo`;o0000<?ooool2o`0001cooooo0_l00006
ooooo`;o00004oooool001kooooo00?o0000ooooooooool05oooool2o`0000Cooooo0_l0000Voooo
o`;o00001Oooool2o`0008Kooooo0_l0000mooooo`?o00004_ooool2o`0000Wooooo0_l0000Boooo
o`007_ooool2o`0001Sooooo0_l0000Pooooo`;o0000VOooool2o`0003gooooo1Ol0000@ooooo`;o
00002Oooool2o`0001;ooooo000Nooooo`03o`000?oooooooooo03Wooooo1?l0000Dooooo`;o0000
`oooool2o`0002oooooo000Nooooo`03o`000?oooooooooo03Sooooo0_l000000ooooooo0000o`00
0008ooooo`;o00002_ooool2o`0003kooooo0_l0002dooooo`007_ooool00ol0003oooooooooo`0>
ooooo`;o0000:?ooool2o`0000_ooooo0_l0001:ooooo`;o0000]?ooool001kooooo00?o0000oooo
ooooool03_ooool2o`0001Gooooo0_l0001>ooooo`;o00009Oooool2o`000:Wooooo000Nooooo`03
o`000?oooooooooo02Gooooo0_l0000_ooooo`;o00007Oooool2o`0002Gooooo1?l00006ooooo`;o
0000OOooool2o`00023ooooo000Nooooo`03o`000?oooooooooo05Kooooo0_l00013ooooo`;o0000
00?oooooo`000?l000001_ooool2o`0005Cooooo0_l0000Wooooo`;o00001?ooool2o`0001[ooooo
000Nooooo`03o`000?oooooooooo00Cooooo0_l0001aooooo`;o00000_ooool2o`0000kooooo0_l0
000>ooooo`;o0000:?ooool2o`0000Sooooo0_l0000[ooooo`;o0000;Oooool2o`0001[ooooo000N
ooooo`03o`000?oooooooooo00Cooooo0_l0000Gooooo`;o0000F?ooool2o`0000;ooooo0_l0000>
ooooo`;o0000>?ooool2o`0000Sooooo0_l0001fooooo`007_ooool00ol0003oooooooooo`0Moooo
o`;o00006Oooool2o`000<Kooooo0_l00015ooooo`007_ooool00ol0003oooooooooo`0Uooooo`;o
00002Oooool2o`0000Kooooo0_l0000cooooo`;o0000Ioooool2o`0002Sooooo0_l0000Mooooo`;o
00001Oooool2o`0001oooooo000Nooooo`03o`000?oooooooooo02Gooooo0_l00009ooooo`;o0000
>oooool2o`00023ooooo0_l00015ooooo`;o0000Aoooool2o`0000Cooooo0ol0000Oooooo`007_oo
ool00ol0003oooooooooo`17ooooo`;o0000A_ooool2o`0001[ooooo0_l0000nooooo`;o0000>?oo
ool2o`00023ooooo000Nooooo`03o`000?oooooooooo04Oooooo0_l0000=ooooo`;o0000Doooool2
o`0001kooooo0_l0000Nooooo`;o0000F_ooool001kooooo00?o0000ooooooooool04?ooool2o`00
04Cooooo0_l0000/ooooo`;o00004oooool2o`00033ooooo0_l0001jooooo`007_ooool00ol0003o
ooooooooo`0@ooooo`;o0000J_ooool2o`0000Kooooo0_l0000Cooooo`;o00001Oooool2o`0002co
oooo0_l0000Oooooo`;o0000E_ooool001kooooo0_l0000Aooooo`;o0000DOooool2o`0001Oooooo
0_l0000Rooooo`;o0000;?ooool2o`0000Gooooo0_l0000Hooooo`;o0000E_ooool001kooooo00?o
0000ooooooooool04?ooool2o`0001Sooooo1?l0000eooooo`;o0000L?ooool2o`00073ooooo000N
ooooo`03o`000?oooooooooo02[ooooo1?l0000;ooooo`;o0000]?ooool2o`0000Sooooo0_l0000R
ooooo`;o00001?ooool2o`0002;ooooo000Nooooo`03o`000?oooooooooo03Wooooo0_l0002Xoooo
o`;o00002_ooool2o`0000Sooooo0_l0000Rooooo`;o00001?ooool2o`0002;ooooo000Nooooo`03
o`000?oooooooooo01Sooooo0_l0001/ooooo`;o00002?ooool2o`00057ooooo0_l00018ooooo`;o
00006?ooool001kooooo00?o0000ooooooooool06?ooool2o`0006cooooo0_l00008ooooo`;o0000
Voooool2o`0000cooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`2@ooooo`;o0000ZOoo
ool2o`0000[ooooo000Nooooo`03o`000?oooooooooo07[ooooo0_l00024ooooo`;o00002oooool2
o`0003Sooooo000Nooooo`03o`000?oooooooooo03;ooooo0_l0000Xooooo`;o00007?ooool2o`00
08Cooooo0_l0000;ooooo`;o00001oooool2o`0000;ooooo0_l0000[ooooo`007_ooool00ol0003o
ooooooooo`0booooo`;o0000:?ooool2o`00053ooooo0_l0001Vooooo`;o00000_ooool2o`0002_o
oooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0000Tooooo`;o0000;oooool2o`0003Cooooo
0_l00006ooooo`Co0000Uoooool001kooooo00?o0000ooooooooool05oooool2o`0002Cooooo0_l0
000_ooooo`;o0000=?ooool2o`0000Kooooo0_l0002Iooooo`007_ooool00ol0003oooooooooo`0_
ooooo`;o0000ooooool4ooooo`;o00004Oooool001kooooo00?o0000ooooooooool0;oooool2o`00
053ooooo0_l00006ooooo`;o0000ZOooool2o`00017ooooo0003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooo
oooo05kooooo0_l0000Qooooo`;o00001_ooool2o`0009Gooooo0_l0000Uooooo`000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_oo
ool00ol0003oooooooooo`0Mooooo`;o0000?oooool2o`0003[ooooo0_l0000?ooooo`;o00002Ooo
ool2o`0006Sooooo0_l000000ooooooo0000o`00000Rooooo`000oooool01Ol@413ooooooooooooo
oooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o00007Oooool2o`0007_ooooo
0_l0000?ooooo`;o00002Oooool2o`0006_ooooo0_l0000Rooooo`000oooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo09_o
oooo0_l0000Looooo`;o0000G?ooool2o`0002kooooo0003ooooo`05o`000?ooooooooooooooool0
00002oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool02oooool2o`00
08kooooo0_l0000Looooo`?o0000Foooool2o`0002kooooo0003ooooo`05oa0@4?oooooooooooooo
ool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo00_ooooo0_l0000Ioooo
o`?o0000<?ooool2o`00023ooooo0_l0000?ooooo`;o0000;?ooool2o`0005kooooo0_l0000[oooo
o`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0
003oooooooooo`0Vooooo`?o00002_ooool2o`0000?ooooo0_l00009ooooo`;o00005?ooool2o`00
023ooooo0_l0000?ooooo`;o0000S?ooool2o`0001Kooooo0_l0000Cooooo`000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`0>
ooooo`;o00006oooool2o`0000Kooooo0_l00003ooooo`;o00002Oooool2o`0002_ooooo0_l00015
ooooo`;o0000NOooool2o`0001?ooooo000Nooooo`03o`000?oooooooooo00kooooo0_l0000Koooo
o`;o00000oooool2o`0000_ooooo0_l0000?ooooo`;o00008?ooool2o`0004Gooooo0_l00010oooo
o`;o00007oooool2o`0002_ooooo000Nooooo`03o`000?oooooooooo033ooooo0_l0000;ooooo`;o
00003oooool2o`0000Kooooo0_l0000Mooooo`;o00001oooool2o`0001[ooooo0_l0000Looooo`;o
0000>Oooool2o`0000Cooooo0_l0000Dooooo`;o00002Oooool2o`0002_ooooo000Nooooo`03o`00
0?oooooooooo05Kooooo0_l0000Jooooo`;o000000?oooooo`000?l000001oooool2o`0001Kooooo
0_l00002ooooo`;o00007?ooool2o`0003Wooooo0_l0000Jooooo`;o0000=_ooool001kooooo00?o
0000ooooooooool0L_ooool2o`0000Sooooo0_l00009ooooo`;o00003Oooool2o`0002Kooooo0_l0
000kooooo`;o0000B_ooool001kooooo00?o0000ooooooooool0H?ooool2o`0001[ooooo0_l00009
ooooo`;o00003_ooool2o`0001oooooo0_l00004ooooo`;o0000>oooool2o`0001Cooooo0_l0000d
ooooo`007_ooool00ol0003oooooooooo`1:ooooo`;o00005?ooool2o`0003Gooooo0_l0000Ooooo
o`;o0000COooool2o`0000Sooooo0_l0000;ooooo`;o00001?ooool2o`00027ooooo000Nooooo`03
o`000?oooooooooo04[ooooo0_l0001Booooo`;o0000Aoooool2o`0001kooooo0_l0000Eooooo`;o
00001?ooool2o`0000Sooooo0_l0000Gooooo`007_ooool00ol0003oooooooooo`2Nooooo`;o0000
:Oooool2o`0001cooooo0_l0000looooo`;o00001oooool2o`0001Oooooo000Nooooo`03o`000?oo
oooooooo04Kooooo0_l0001Kooooo`;o00009?ooool2o`0000Kooooo0_l0001Booooo`;o00004?oo
ool2o`0000kooooo000Nooooo`03o`000?oooooooooo04Kooooo0_l0001Kooooo`;o0000;?ooool2
o`0003;ooooo0_l0000`ooooo`;o00003_ooool001kooooo00?o0000ooooooooool0aOooool2o`00
03kooooo0_l0000Wooooo`;o00005oooool001kooooo0_l0001?ooooo`;o00008?ooool2o`0002Ko
oooo0_l0000[ooooo`;o0000=Oooool2o`0001;ooooo0_l0000Looooo`;o00005oooool001kooooo
00?o0000ooooooooool03oooool2o`0000gooooo0_l0000Tooooo`;o00002?ooool2o`00023ooooo
0_l00009ooooo`;o00006oooool2o`0006;ooooo0_l0000Booooo`;o0000=Oooool001kooooo0_l0
000@ooooo`;o00003Oooool2o`0000Oooooo0_l00007ooooo`;o00004_ooool2o`0003Gooooo0_l0
001Wooooo`;o0000HOooool001kooooo0_l0000Aooooo`;o00005Oooool2o`0000Oooooo0_l0002E
ooooo`;o00006oooool2o`00067ooooo000Nooooo`03o`000?oooooooooo013ooooo0_l0000Roooo
o`;o00003?ooool2o`0003oooooo0_l0000Nooooo`;o00000_ooool2o`00013ooooo0_l0000<oooo
o`;o00001?ooool2o`0000[ooooo0_l0001/ooooo`007_ooool00ol0003oooooooooo`0dooooo`;o
00001Oooool2o`0000Gooooo0_l0000oooooo`;o00004oooool2o`0000Wooooo0_l00002ooooo`;o
00004?ooool2o`0001;ooooo0_l0000:ooooo`Co0000J_ooool001kooooo00?o0000ooooooooool0
>oooool2o`0005_ooooo0_l00011ooooo`;o0000Doooool2o`0001Gooooo000Nooooo`03o`000?oo
oooooooo0<kooooo0_l0000Kooooo`;o0000@oooool2o`0001Gooooo000Nooooo`03o`000?oooooo
oooo01cooooo1?l0000<ooooo`;o00000_ooool2o`00063ooooo0_l0000jooooo`;o00006oooool2
o`0000;ooooo0_l0001Fooooo`007_ooool00ol0003oooooooooo`0Looooo`Co00001Oooool2o`00
00Gooooo0_l00002ooooo`;o0000H?ooool2o`0005_ooooo0_l0000Iooooo`;o0000>oooool001ko
oooo00?o0000ooooooooool09Oooool2o`0006Sooooo0_l0000Pooooo`;o00006_ooool2o`0003_o
oooo0_l0000kooooo`007_ooool00ol0003oooooooooo`0Xooooo`;o00006oooool2o`0003Gooooo
0_l0000Aooooo`;o00008?ooool2o`0000oooooo0_l00009ooooo`;o00000_ooool2o`0007Cooooo
000Nooooo`03o`000?oooooooooo00;o00005?ooool2o`00013ooooo0_l0000Kooooo`;o00001?oo
ool2o`0001Oooooo0_l0000Fooooo`;o0000A?ooool2o`0000gooooo0_l0001dooooo`007_ooool0
0ol0003oooooooooo`02o`0001Cooooo0_l0000Sooooo`;o00003_ooool2o`0001Oooooo0_l0002C
ooooo`;o0000C?ooool001kooooo00?o0000ooooooooool0>oooool2o`0002Wooooo0_l0000^oooo
o`;o0000HOooool2o`0001oooooo0_l0000[ooooo`007_ooool00ol0003oooooooooo`1Vooooo`;o
00001_ooool2o`0002Kooooo0_l00022ooooo`;o0000:oooool001kooooo0_l0001_ooooo`;o0000
8_ooool2o`0005Cooooo0_l00006ooooo`;o00001Oooool2o`0004kooooo000Nooooo`03o`000?oo
oooooooo02oooooo0_l0001Qooooo`;o0000E?ooool2o`0000Kooooo0_l00005ooooo`;o0000C_oo
ool001kooooo00?o0000ooooooooool0;oooool2o`0000[ooooo0_l00026ooooo`;o0000IOooool2
o`0001;ooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o0000:?ooool2o`00
03Sooooo0_l00018ooooo`;o00000_ooool2o`0006Gooooo0_l0000Booooo`;o00001oooool001ko
oooo00?o0000ooooooooool04Oooool2o`0000kooooo0_l0000Dooooo`;o0000=?ooool2o`0000Ko
oooo0_l00018ooooo`;o0000D?ooool2o`0000_ooooo0_l0000Wooooo`007_ooool00ol0003ooooo
ooooo`0Gooooo`;o00002?ooool2o`0001Cooooo0_l0000dooooo`;o0000E?ooool2o`0004Cooooo
0_l00006ooooo`;o00002oooool2o`0002Oooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0
0008ooooo`;o0000X?ooool2o`0004Cooooo0_l0000looooo`007_ooool00ol0003oooooooooo`0o
ooooo`;o00002_ooool2o`0009Cooooo0_l0001Tooooo`007_ooool00ol0003oooooooooo`0ooooo
o`;o00002_ooool2o`0009Cooooo0_l0000dooooo`;o0000;_ooool001kooooo00?o0000oooooooo
ool0T_ooool2o`0008?ooooo0_l0000^ooooo`007_ooool00ol0003oooooooooo`2Booooo`;o0000
;Oooool2o`0008Cooooo000Nooooo`03o`000?oooooooooo02gooooo0_l0001@ooooo`;o0000@?oo
ool2o`0006Wooooo0_l0000Iooooo`007_ooool00ol0003oooooooooo`0]ooooo`;o0000=Oooool2
o`0001Wooooo0_l0002[ooooo`;o00006Oooool001kooooo00?o0000ooooooooool0I?ooool2o`00
0>7ooooo000Nooooo`03o`000?oooooooooo00gooooo1?l0000:ooooo`;o00000oooool2o`00043o
oooo0_l0000Fooooo`;o0000;Oooool2o`0008Cooooo0_l00005ooooo`;o00003oooool001kooooo
00?o0000ooooooooool03Oooool4o`0000[ooooo0_l00003ooooo`;o0000<?ooool2o`0000kooooo
0_l0000Fooooo`;o00002oooool2o`00023ooooo0_l0000Booooo`;o0000L?ooool2o`0000Gooooo
0_l0000?ooooo`007_ooool2o`0003Gooooo0_l0000Looooo`;o0000<oooool2o`0002Sooooo0_l0
000:ooooo`;o00001Oooool2o`0001Kooooo0_l0000Gooooo`;o0000D?ooool001kooooo00?o0000
ooooooooool0=?ooool2o`0001Wooooo0_l00007ooooo`;o0000Eoooool2o`00017ooooo0_l0000F
ooooo`;o00005oooool2o`000003ooooool0003o000002?ooooo0_l0000<ooooo`;o00006_ooool0
01kooooo00?o0000ooooooooool03Oooool2o`00043ooooo0_l00007ooooo`;o00006?ooool2o`00
08Cooooo0_l0000Gooooo`;o00002_ooool2o`0000cooooo0_l0000Jooooo`007_ooool00ol0003o
ooooooooo`0=ooooo`;o0000G_ooool2o`0000?ooooo0_l0000booooo`;o00002_ooool2o`0002oo
oooo0_l0000/ooooo`;o0000=?ooool001kooooo00?o0000ooooooooool0KOooool2o`0003Oooooo
0_l0000:ooooo`;o0000;oooool2o`0003gooooo0_l0000Sooooo`007_ooool00ol0003ooooooooo
o`2Sooooo`;o00001_ooool2o`0007Gooooo0_l0000Sooooo`007_ooool00ol0003oooooooooo`1J
ooooo`;o00008?ooool2o`0002Gooooo0_l00006ooooo`;o0000MOooool2o`0002?ooooo000Noooo
o`03o`000?oooooooooo05[ooooo0_l0000Pooooo`;o0000I?ooool2o`0006?ooooo000Nooooo`03
o`000?oooooooooo01cooooo0_l0000?ooooo`;o0000MOooool2o`0003cooooo0_l00005ooooo`;o
0000G?ooool001kooooo00?o0000ooooooooool07?ooool2o`0000oooooo0_l00007ooooo`;o0000
K?ooool2o`0004?ooooo0_l0000gooooo`;o00008oooool001kooooo00?o0000ooooooooool0=_oo
ool2o`0000_ooooo0_l0000Wooooo`;o0000]?ooool2o`0002?ooooo000Nooooo`03o`000?oooooo
oooo04?ooooo0_l0000Gooooo`;o00003_ooool2o`000=Wooooo000Nooooo`03o`000?oooooooooo
02kooooo0_l0000/ooooo`;o0000B_ooool2o`0009gooooo000Nooooo`?o0000;_ooool2o`0007So
oooo0_l00009ooooo`;o0000T_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo1Ol0000>ooooo`;o00002Oooool2o`00
09Kooooo0_l0000:ooooo`;o0000DOooool2o`0003?ooooo0003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooo
oooo00;o00003_ooool2o`0000Wooooo0_l0001^ooooo`;o0000<_ooool2o`00057ooooo0_l0000c
ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00
0006ooooo`Go00003oooool2o`0002Wooooo0_l0001=ooooo`;o00003?ooool2o`000:cooooo0003
ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo
00?o0000ooooooooool00_l0000:ooooo`;o00000oooool2o`0002Wooooo0_l0000Nooooo`;o0000
>oooool2o`000:cooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<00Kooooo00?o0000ooooooooool03?ooool2o`0004cooooo1_l0000iooooo`;o
0000[?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj
^_l@41001_ooool00ol0003oooooooooo`1Jooooo`;o00000_ooool2o`0005Sooooo0_l0000/oooo
o`;o00000_ooool2o`0001[ooooo0_l0000oooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo01kooooo0_l0000N
ooooo`;o0000=oooool2o`0003oooooo0_l0000/ooooo`;o00000_ooool2o`0001[ooooo0_l0000o
ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVY
Z@06ooooo`03o`000?oooooooooo01kooooo0_l0000Nooooo`;o0000=oooool2o`0001_ooooo0_l0
001Cooooo`;o0000G?ooool001kooooo00?o0000ooooooooool0<?ooool2o`0002Oooooo0_l00004
ooooo`;o0000<oooool2o`0005?ooooo0_l0001Looooo`007_ooool00ol0003oooooooooo`0@oooo
o`;o00003oooool2o`0000gooooo0_l0000Wooooo`;o00001?ooool2o`0001Oooooo0_l0002_oooo
o`;o00000_ooool2o`0001Sooooo000Nooooo`03o`000?oooooooooo013ooooo0_l0000?ooooo`;o
0000EOooool2o`0000Gooooo0_l0000]ooooo`;o00008_ooool2o`0005Gooooo0_l00002ooooo`;o
00006?ooool001kooooo00?o0000ooooooooool0Ooooool2o`0002gooooo0_l0000Rooooo`;o0000
Loooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`1l
ooooo`;o0000;?ooool4o`0009Wooooo000Nooooo`03o`000?oooooooooo05;ooooo0_l0000Xoooo
o`;o0000;?ooool4o`0002kooooo0_l00013ooooo`;o00009?ooool001kooooo00?o0000oooooooo
ool0>oooool2o`0001Gooooo0_l0001fooooo`;o00004?ooool2o`0002_ooooo0_l0000Fooooo`;o
00007Oooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo01gooooo0_l000000ooooooo0000
o`00000Iooooo`;o0000:?ooool2o`0006?ooooo0_l0000mooooo`;o0000=?ooool3o`0000Gooooo
000Nooooo`04o`000?ooooooooooooooo`;o00006_ooool2o`000003ooooool0003o000004?ooooo
0_l0000nooooo`;o0000<_ooool2o`0002Oooooo0_l0000hooooo`;o000000?oooooo`000?l00000
1_ooool001kooooo00Co0000oooooooooooooooo0_l0000Rooooo`;o0000O_ooool2o`0003;ooooo
0_l0000Wooooo`;o0000>?ooool2o`0000Wooooo000Nooooo`;o00007Oooool2o`0000Oooooo0_l0
002booooo`;o0000AOooool2o`0000;ooooo0_l0000Qooooo`007_ooool00ol0003oooooooooo`0H
ooooo`;o00000_ooool2o`0000Cooooo0_l0000hooooo`;o0000Noooool2o`0003;ooooo0_l0000A
ooooo`;o00000_ooool2o`00027ooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l00002oooo
o`;o00002?ooool2o`0000[ooooo0_l00008ooooo`;o00008_ooool2o`0005[ooooo0_l0001Coooo
o`;o0000:Oooool2o`0000gooooo000Nooooo`03o`000?oooooooooo00kooooo0_l000001?oooooo
0000o`000?ooool2o`0001Sooooo0_l00008ooooo`;o0000DOooool2o`0002_ooooo0_l0000Boooo
o`;o00002_ooool2o`0001Oooooo0_l00015ooooo`;o00001Oooool2o`0000Kooooo000Nooooo`03
o`000?oooooooooo00kooooo0_l000000ooooooo0000o`00001hooooo`;o0000<_ooool2o`0000_o
oooo0_l0000:ooooo`;o00005oooool2o`0004cooooo0_l00006ooooo`007_ooool00ol0003ooooo
ooooo`1?ooooo`;o0000K_ooool2o`0008Kooooo000Nooooo`03o`000?oooooooooo04oooooo0_l0
0014ooooo`;o00005oooool2o`0000Wooooo0_l00019ooooo`;o0000@Oooool001kooooo00?o0000
ooooooooool08_ooool2o`0005gooooo0_l0000Booooo`;o00005?ooool2o`000003ooooool0003o
000000Wooooo0_l0000Yooooo`;o00007_ooool2o`00047ooooo000Nooooo`03o`000?oooooooooo
02;ooooo0_l0000?ooooo`;o0000C?ooool2o`0002Sooooo0_l0000gooooo`;o0000;oooool2o`00
00gooooo0_l0000Qooooo`007_ooool00ol0003oooooooooo`0cooooo`;o00008?ooool2o`0001Oo
oooo0_l00004ooooo`;o00004?ooool2o`0007Cooooo0_l0000Gooooo`;o00003Oooool2o`0000Co
oooo0_l0000Kooooo`007_ooool00ol0003oooooooooo`1@ooooo`;o00000oooool2o`0001Oooooo
0_l00004ooooo`;o00004?ooool2o`0003kooooo0_l0000dooooo`;o00004Oooool2o`0001Wooooo
0_l0000Kooooo`007_ooool00ol0003oooooooooo`0oooooo`;o00000_ooool2o`0000_ooooo0ol0
0009ooooo`;o0000J?ooool2o`0004Oooooo0_l00007ooooo`;o00001oooool2o`0002Cooooo000N
ooooo`;o000000?oooooo`000?l00000?Oooool2o`000004ooooool0003o0000o`0000cooooo0_l0
0009ooooo`;o0000^_ooool2o`0000Oooooo0_l0000Tooooo`007_ooool2o`000003ooooool0003o
0000043ooooo0_l0000Hooooo`;o00002?ooool2o`0000Gooooo0_l0003Hooooo`007_ooool00ol0
003oooooooooo`1:ooooo`;o00006_ooool2o`0000Gooooo0_l0000Nooooo`;o0000^?ooool001ko
oooo00?o0000ooooooooool0B_ooool2o`00047ooooo0_l0000Mooooo`;o0000VOooool001kooooo
0_l0001Nooooo`;o00004?ooool2o`0003_ooooo0_l0001jooooo`;o00001oooool2o`0001Cooooo
000Nooooo`03o`000?oooooooooo04kooooo0_l0000=ooooo`;o00004?ooool2o`000;Kooooo0ol0
0007ooooo`;o00005?ooool001kooooo00?o0000ooooooooool03_ooool2o`0003kooooo0_l00025
ooooo`;o0000B_ooool2o`0000Cooooo0_l0000Nooooo`007_ooool00ol0003oooooooooo`0>oooo
o`;o00009oooool2o`0009cooooo0_l0000iooooo`;o00003oooool2o`0002Cooooo000Nooooo`03
o`000?oooooooooo03Oooooo0_l0000Sooooo`;o0000Roooool2o`0002Gooooo0_l0000eooooo`00
7_ooool00ol0003oooooooooo`1Looooo`;o0000JOooool2o`00023ooooo0_l0001Looooo`007_oo
ool00ol0003oooooooooo`03ooooo`;o0000??ooool2o`0001;ooooo0_l0001`ooooo`;o0000O_oo
ool001kooooo00?o0000ooooooooool00oooool2o`0000?ooooo0_l0000gooooo`;o00004_ooool2
o`0004kooooo0_l0001Wooooo`;o0000=oooool001kooooo00?o0000ooooooooool02?ooool2o`00
07Wooooo0_l0000Eooooo`;o00001?ooool2o`0000?ooooo0_l0001Wooooo`;o00008?ooool2o`00
01Gooooo000Nooooo`03o`000?oooooooooo01cooooo0_l0000:ooooo`;o00005Oooool2o`0004;o
oooo0_l0000Eooooo`;o00001?ooool2o`0001oooooo0_l0000Iooooo`;o0000=oooool2o`0001Wo
oooo0_l0000Eooooo`007_ooool00ol0003oooooooooo`0Looooo`;o00001_ooool2o`0000;ooooo
0_l0000;ooooo`;o00002?ooool2o`0006gooooo0_l0000>ooooo`;o000000?oooooo`000?l00000
6Oooool2o`0003Oooooo0_l0000`ooooo`007_ooool00ol0003oooooooooo`07ooooo`;o00006ooo
ool2o`0000Kooooo0_l00007ooooo`;o0000B?ooool2o`0002gooooo0_l0000>ooooo`;o00008ooo
ool2o`00037ooooo0_l0000_ooooo`007_ooool00ol0003oooooooooo`07ooooo`;o000000?ooooo
o`000?l000004_ooool2o`0000cooooo0_l00014ooooo`;o00002oooool2o`0000?ooooo0_l0000S
ooooo`;o0000>?ooool2o`00037ooooo0_l0000_ooooo`007_ooool00ol0003oooooooooo`0:oooo
o`;o00004_ooool2o`0003Cooooo0_l0000Looooo`;o00004?ooool2o`0002?ooooo0_l0002Loooo
o`007_ooool00ol0003oooooooooo`1Dooooo`;o0000?Oooool2o`000;;ooooo000Nooooo`03o`00
0?oooooooooo01Wooooo0_l0000Dooooo`;o00003oooool2o`00057ooooo0_l0002booooo`007_oo
ool2o`0001[ooooo0_l0000Dooooo`;o00003oooool2o`0002oooooo0_l0001>ooooo`;o00006?oo
ool2o`0003gooooo0_l0000[ooooo`007_ooool00ol0003oooooooooo`1aooooo`;o0000:oooool2
o`00027ooooo0_l0000Hooooo`;o0000?Oooool2o`0002_ooooo000Nooooo`03o`000?oooooooooo
09kooooo0_l0000fooooo`;o0000J?ooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo03[o
oooo0_l0000looooo`;o0000G?ooool2o`0003?ooooo0_l0000cooooo`;o00001Oooool001kooooo
0ol0000jooooo`;o0000??ooool2o`0001gooooo0_l0000dooooo`;o0000??ooool2o`0003[ooooo
000Nooooo`?o0000Uoooool2o`0003Cooooo0_l0000fooooo`;o0000@?ooool001kooooo00?o0000
ooooooooool0K?ooool2o`0009Oooooo0_l00010ooooo`007_ooool00ol0003oooooooooo`0ioooo
o`;o0000:Oooool2o`0000Kooooo0_l0003Iooooo`007_ooool00ol0003oooooooooo`0iooooo`;o
00009_ooool2o`000003ooooool0003o000001Oooooo0_l0000Jooooo`;o00006_ooool2o`0003Co
oooo0_l0001Jooooo`007_ooool00ol0003oooooooooo`1Qooooo`;o00003?ooool2o`0000cooooo
0_l0000Jooooo`;o00002?ooool2o`00013ooooo0_l0000[ooooo`;o00001oooool2o`0005[ooooo
000Nooooo`03o`000?oooooooooo06oooooo0_l0000booooo`;o0000?Oooool2o`0000cooooo0_l0
00000ooooooo0000o`00000Mooooo`;o00007Oooool2o`0000Cooooo0_l0000>ooooo`007_ooool0
0ol0003oooooooooo`2gooooo`;o0000=oooool2o`000003ooooool0003o000001gooooo0_l0000M
ooooo`;o00001?ooool2o`0000kooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l0001Eoooo
o`;o0000=oooool2o`0005cooooo0_l0000=ooooo`;o00008Oooool001kooooo00?o0000oooooooo
ool09oooool2o`0005Gooooo0_l000001?oooooo0000o`000?ooool2o`0002gooooo0_l0001Poooo
o`;o00002Oooool2o`0000;ooooo0_l0000Qooooo`005?ooool4o`000003oa0@4?oooooooooo00?o
oooo00?o0000ooooooooool0POooool2o`000003ooooool0003o000002gooooo0_l0001[ooooo`;o
00009Oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Jooooo`;o0000
O_ooool2o`0006_ooooo000Fooooo`03o`000?oooooooooo00Gooooo1Ol0001Hooooo`;o0000;?oo
ool2o`00053ooooo0_l0001[ooooo`005_ooool00ol0003oooooooooo`08ooooo`;o0000Q_ooool2
o`000;gooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000oooooooo
ool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Dooooo`03oeEEEOmV
IVKo00000?ooooooD_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.09911 .67713 Mdot
.82697 .434 Mdot
.08548 .49894 Mdot
.0477 .03381 Mdot
.38612 .41769 Mdot
.24556 .04814 Mdot
.62787 .014 Mdot
.26241 .45973 Mdot
.31167 .9737 Mdot
.77268 .00223 Mdot
.32936 .2148 Mdot
.46967 .09701 Mdot
.23157 .5381 Mdot
.64291 .66284 Mdot
.14825 .03917 Mdot
.59558 .62897 Mdot
.76106 .62197 Mdot
.35112 .58013 Mdot
.13346 .60875 Mdot
.08938 .12059 Mdot
.82119 .63458 Mdot
.31611 .11887 Mdot
.4901 .42018 Mdot
.84577 .02245 Mdot
.2593 .8816 Mdot
.2021 .36021 Mdot
.11259 .84182 Mdot
.60407 .73036 Mdot
.35081 .21938 Mdot
.2537 .14991 Mdot
.21855 .61068 Mdot
.16507 .029 Mdot
.39707 .9765 Mdot
.84943 .91046 Mdot
.90722 .55613 Mdot
.00418 .88809 Mdot
.6465 .67466 Mdot
.80212 .52838 Mdot
.53459 .8327 Mdot
.1964 .79822 Mdot
.18475 .61262 Mdot
.94382 .64795 Mdot
.96678 .00176 Mdot
.77893 .61837 Mdot
.56736 .02615 Mdot
.93075 .70837 Mdot
.66084 .4693 Mdot
.92791 .82057 Mdot
.01516 .79517 Mdot
.12588 .29181 Mdot
.47741 .96248 Mdot
.92933 .49348 Mdot
.29352 .34969 Mdot
.9871 .84535 Mdot
.32754 .34772 Mdot
.20769 .22662 Mdot
.76013 .3212 Mdot
.27701 .51791 Mdot
.09985 .85179 Mdot
.35024 .69748 Mdot
.08584 .05687 Mdot
.22577 .40693 Mdot
.60654 .09492 Mdot
.29619 .91288 Mdot
.31219 .74581 Mdot
.31089 .06741 Mdot
.98554 .39832 Mdot
.10415 .84097 Mdot
.22508 .07626 Mdot
.82562 .32287 Mdot
.12619 .2247 Mdot
.47396 .62512 Mdot
.0411 .16739 Mdot
.24951 .21927 Mdot
.43308 .07256 Mdot
.95305 .30627 Mdot
.12172 .32722 Mdot
.64191 .23845 Mdot
.13679 .92837 Mdot
.53774 .39781 Mdot
.91256 .85213 Mdot
.71236 .07503 Mdot
.78617 .62696 Mdot
.23801 .44949 Mdot
.74539 .45931 Mdot
.98921 .22954 Mdot
.31067 .38762 Mdot
.03701 .92307 Mdot
.19072 .05978 Mdot
.39353 .68401 Mdot
.05477 .13139 Mdot
.85537 .28647 Mdot
.14321 .2799 Mdot
.14302 .21216 Mdot
.3566 .65208 Mdot
.90558 .76311 Mdot
.61187 .19211 Mdot
.91623 .53337 Mdot
.30016 .80573 Mdot
.88028 .60967 Mdot
.11144 .74523 Mdot
.48466 .92597 Mdot
.05749 .61372 Mdot
.62916 .63908 Mdot
.91356 .33392 Mdot
.48645 .4272 Mdot
.55547 .68145 Mdot
.58191 .66369 Mdot
.94481 .48934 Mdot
.66685 .13044 Mdot
.64278 .68371 Mdot
.78806 .5199 Mdot
.53224 .93891 Mdot
.30131 .59436 Mdot
.47611 .32505 Mdot
.67103 .95629 Mdot
.56264 .99143 Mdot
.18456 .52873 Mdot
.00769 .30911 Mdot
.60032 .86527 Mdot
.06359 .82014 Mdot
.93503 .73464 Mdot
.41841 .13598 Mdot
.14703 .2143 Mdot
.88584 .19773 Mdot
.84547 .61928 Mdot
.40804 .87315 Mdot
.17357 .66392 Mdot
.84663 .88196 Mdot
.98972 .13517 Mdot
.83952 .57212 Mdot
.38757 .27011 Mdot
.77651 .75217 Mdot
.45311 .53578 Mdot
.3569 .61577 Mdot
.30701 .32166 Mdot
.47041 .41858 Mdot
.46178 .70119 Mdot
.06359 .54561 Mdot
.28946 .03732 Mdot
.21639 .66344 Mdot
.29962 .90238 Mdot
.37724 .09096 Mdot
.91273 .63168 Mdot
.60095 .33861 Mdot
.45741 .09627 Mdot
.24364 .72287 Mdot
.15121 .7749 Mdot
.77253 .30438 Mdot
.68772 .0737 Mdot
.70981 .75922 Mdot
.39823 .03582 Mdot
.49292 .09563 Mdot
.09939 .13318 Mdot
.11683 .00399 Mdot
.18717 .5014 Mdot
.51388 .66504 Mdot
.72874 .4045 Mdot
.27072 .94238 Mdot
.57659 .63009 Mdot
.49725 .63739 Mdot
.88996 .55659 Mdot
.7884 .87881 Mdot
.48938 .5213 Mdot
.29362 .78325 Mdot
.39095 .38807 Mdot
.17825 .77854 Mdot
.20523 .88628 Mdot
.66293 .11331 Mdot
.47537 .4817 Mdot
.392 .17013 Mdot
.89981 .85149 Mdot
.89461 .53293 Mdot
.00988 .29438 Mdot
.10755 .65457 Mdot
.51774 .77328 Mdot
.81267 .87165 Mdot
.128 .38624 Mdot
.63361 .09289 Mdot
.92225 .49963 Mdot
.97158 .97949 Mdot
.44454 .01831 Mdot
.57731 .80881 Mdot
.54624 .16646 Mdot
.68414 .27553 Mdot
.53673 .8723 Mdot
.57644 .62165 Mdot
.01974 .09847 Mdot
.76573 .74997 Mdot
.89291 .71262 Mdot
.13263 .65737 Mdot
.97063 .21328 Mdot
.16153 .67765 Mdot
.52431 .19514 Mdot
.58203 .8691 Mdot
.97901 .02861 Mdot
.89937 .5925 Mdot
.43992 .15623 Mdot
.32095 .97132 Mdot
.42078 .05797 Mdot
.55516 .22088 Mdot
.52865 .34509 Mdot
.42328 .56387 Mdot
.55859 .13148 Mdot
.26259 .8862 Mdot
.03507 .93602 Mdot
.67938 .01801 Mdot
.0569 .90726 Mdot
.78129 .42398 Mdot
.61458 .75076 Mdot
.45882 .45339 Mdot
.19387 .6927 Mdot
.90416 .23165 Mdot
.66457 .3474 Mdot
.4795 .66747 Mdot
.10599 .2162 Mdot
.21732 .78172 Mdot
.07205 .28001 Mdot
.53667 .76423 Mdot
.0163 .37255 Mdot
.75654 .33964 Mdot
.39959 .62146 Mdot
.29615 .88712 Mdot
.2064 .92857 Mdot
.39195 .65488 Mdot
.54031 .58093 Mdot
.91299 .98723 Mdot
.43527 .36493 Mdot
.6948 .20524 Mdot
.36437 .08442 Mdot
.15806 .44154 Mdot
.34858 .71195 Mdot
.4001 .10068 Mdot
.94987 .09045 Mdot
.10447 .21399 Mdot
.74301 .16184 Mdot
.7115 .55861 Mdot
.20174 .58042 Mdot
.80016 .57116 Mdot
.76555 .2161 Mdot
.10593 .36632 Mdot
.40033 .13093 Mdot
.94863 .92498 Mdot
.05282 .41945 Mdot
.54607 .82395 Mdot
.1033 .32905 Mdot
.44226 .6097 Mdot
.35902 .16676 Mdot
.73093 .05171 Mdot
.15835 .58639 Mdot
.93239 .47976 Mdot
.39138 .37077 Mdot
.82714 .11404 Mdot
.99171 .23889 Mdot
.87962 .18855 Mdot
.94079 .82004 Mdot
.33215 .36492 Mdot
.83772 .49077 Mdot
.89068 .75456 Mdot
.47726 .32374 Mdot
.15883 .70344 Mdot
.31965 .73727 Mdot
.22661 .22398 Mdot
.92844 .3668 Mdot
.39856 .11007 Mdot
.93748 .12765 Mdot
.51856 .92218 Mdot
.99824 .30758 Mdot
.18713 .55721 Mdot
.16064 .81676 Mdot
.29638 .8031 Mdot
.68228 .49284 Mdot
.13913 .09894 Mdot
.36128 .75596 Mdot
.91339 .87546 Mdot
.43293 .38962 Mdot
.5123 .76465 Mdot
.49608 .26152 Mdot
.99489 .84316 Mdot
.49831 .95411 Mdot
.80674 .28541 Mdot
.33893 .13664 Mdot
.50871 .48316 Mdot
.65586 .64387 Mdot
.3706 .38391 Mdot
.2941 .88797 Mdot
.45809 .50846 Mdot
.86128 .49859 Mdot
.94704 .74342 Mdot
.36375 .23659 Mdot
.95333 .90036 Mdot
.86467 .28281 Mdot
.14617 .61466 Mdot
.52518 .14592 Mdot
.63518 .13181 Mdot
.86964 .50224 Mdot
.26367 .74843 Mdot
.57333 .61444 Mdot
.80493 .24024 Mdot
.71337 .11603 Mdot
.85961 .49684 Mdot
.34892 .87912 Mdot
.90735 .59612 Mdot
.48392 .59551 Mdot
.76134 .98241 Mdot
.95964 .44988 Mdot
.12677 .8497 Mdot
.09078 .94722 Mdot
.86213 .10195 Mdot
.51463 .33322 Mdot
.05791 .86128 Mdot
.80144 .21769 Mdot
.19817 .36544 Mdot
.45111 .33876 Mdot
.29032 .76822 Mdot
.96807 .74307 Mdot
.52853 .78604 Mdot
.00848 .29293 Mdot
.40227 .93682 Mdot
.91789 .34558 Mdot
.54044 .83482 Mdot
.40163 .01273 Mdot
.48344 .97371 Mdot
.60003 .79483 Mdot
.28625 .60866 Mdot
.15011 .45668 Mdot
.99695 .8411 Mdot
.18236 .71329 Mdot
.4655 .05482 Mdot
.17525 .42098 Mdot
.06365 .11819 Mdot
.25702 .07434 Mdot
.52117 .28343 Mdot
.85446 .06267 Mdot
.03811 .31008 Mdot
.25334 .26762 Mdot
.75061 .70107 Mdot
.10504 .81092 Mdot
.75506 .86062 Mdot
.92251 .09776 Mdot
.28812 .80595 Mdot
.74742 .6771 Mdot
.22539 .68708 Mdot
.48973 .60229 Mdot
.7041 .40313 Mdot
.63573 .54033 Mdot
.66613 .09373 Mdot
.3828 .2728 Mdot
.91596 .39252 Mdot
.27845 .46207 Mdot
.16163 .53191 Mdot
.35639 .36462 Mdot
.8729 .72602 Mdot
.6086 .68691 Mdot
.64609 .03942 Mdot
.11931 .0841 Mdot
.9434 .6351 Mdot
.48111 .54418 Mdot
.27561 .5416 Mdot
.0996 .27121 Mdot
.36002 .14909 Mdot
.82062 .80929 Mdot
.19946 .61729 Mdot
.46199 .44533 Mdot
.32649 .89165 Mdot
.85419 .75788 Mdot
.68003 .85276 Mdot
.73456 .67342 Mdot
.73804 .2171 Mdot
.25288 .12913 Mdot
.46112 .67497 Mdot
.15407 .85813 Mdot
.10326 .52613 Mdot
.33348 .04885 Mdot
.90337 .90833 Mdot
.87116 .6036 Mdot
.57453 .01719 Mdot
.01831 .84616 Mdot
.89455 .16439 Mdot
.28267 .17217 Mdot
.15704 .94686 Mdot
.03067 .04282 Mdot
.69484 .27131 Mdot
.87626 .18479 Mdot
.59209 .74569 Mdot
.54214 .1356 Mdot
.69013 .83781 Mdot
.67172 .53153 Mdot
.11636 .82066 Mdot
.65419 .68558 Mdot
.22105 .65619 Mdot
.37188 .51323 Mdot
.06599 .70956 Mdot
.3419 .47028 Mdot
.36936 .43787 Mdot
.46578 .28529 Mdot
.7773 .69143 Mdot
.92397 .14969 Mdot
.08733 .85393 Mdot
.25141 .61771 Mdot
.9716 .03322 Mdot
.596 .93281 Mdot
.74973 .37641 Mdot
.22438 .41991 Mdot
.68431 .66753 Mdot
.88237 .94918 Mdot
.31477 .22978 Mdot
.41457 .66332 Mdot
.53644 .53843 Mdot
.49029 .51427 Mdot
.45053 .68372 Mdot
.23983 .896 Mdot
.4796 .65046 Mdot
.64258 .96429 Mdot
.731 .27366 Mdot
.41837 .54451 Mdot
.04711 .60653 Mdot
.53622 .59534 Mdot
.73134 .37594 Mdot
.12303 .9314 Mdot
.19365 .83806 Mdot
.63039 .41742 Mdot
.74208 .1542 Mdot
.39041 .52178 Mdot
.26135 .50304 Mdot
.7481 .55771 Mdot
.53038 .22885 Mdot
.32864 .01345 Mdot
.484 .62235 Mdot
.79157 .41775 Mdot
.75381 .24612 Mdot
.66883 .48617 Mdot
.55944 .40813 Mdot
.03897 .06854 Mdot
.81788 .25409 Mdot
.64655 .54706 Mdot
.55537 .75079 Mdot
.90028 .98903 Mdot
.02626 .52199 Mdot
.56998 .97594 Mdot
.53945 .89949 Mdot
.77987 .55698 Mdot
.78697 .65262 Mdot
.11085 .0706 Mdot
.22645 .24506 Mdot
.07282 .00188 Mdot
.40738 .99114 Mdot
.42392 .45541 Mdot
.85195 .23966 Mdot
.52414 .46633 Mdot
.82724 .71754 Mdot
.95515 .4907 Mdot
.2859 .81887 Mdot
.17581 .93295 Mdot
.49911 .16554 Mdot
.06608 .86218 Mdot
.27337 .92078 Mdot
.99428 .86026 Mdot
.86613 .93027 Mdot
.56759 .40502 Mdot
.01455 .6907 Mdot
.04402 .9388 Mdot
.18694 .97221 Mdot
.08997 .44871 Mdot
.90026 .154 Mdot
.9135 .51539 Mdot
.39933 .98871 Mdot
.84858 .65256 Mdot
.12721 .06712 Mdot
.85574 .79285 Mdot
.26163 .13704 Mdot
.28609 .3883 Mdot
.24789 .44735 Mdot
.24332 .44913 Mdot
.06282 .4746 Mdot
.15551 .99991 Mdot
.16187 .32105 Mdot
.24165 .48514 Mdot
.76125 .33181 Mdot
.39283 .83234 Mdot
.63453 .26436 Mdot
.53821 .03956 Mdot
.37294 .127 Mdot
.2521 .65137 Mdot
.1262 .68053 Mdot
.00942 .20263 Mdot
.06416 .20592 Mdot
.85394 .20261 Mdot
.90341 .88566 Mdot
.61135 .71732 Mdot
.14207 .55338 Mdot
.2185 .88528 Mdot
.50587 .28847 Mdot
.67887 .84627 Mdot
.13368 .16102 Mdot
.42651 .19389 Mdot
.0088 .48082 Mdot
.41722 .99204 Mdot
.94455 .2745 Mdot
.56322 .78898 Mdot
.04309 .38931 Mdot
.95257 .07166 Mdot
.90212 .83603 Mdot
.73351 .18633 Mdot
.39399 .54729 Mdot
.05495 .34032 Mdot
.26109 .38676 Mdot
.62674 .14565 Mdot
.25314 .9053 Mdot
.2092 .15393 Mdot
.30848 .63042 Mdot
.64459 .3647 Mdot
.26703 .2414 Mdot
.69311 .29296 Mdot
.36524 .40594 Mdot
.95994 .10713 Mdot
.97269 .85838 Mdot
.90636 .76689 Mdot
.71048 .47172 Mdot
.27802 .62077 Mdot
.45616 .56678 Mdot
.0709 .46701 Mdot
.14865 .93598 Mdot
.42415 .10147 Mdot
.88174 .69455 Mdot
.73171 .80828 Mdot
.51453 .28922 Mdot
.77268 .70088 Mdot
.54261 .43127 Mdot
.86806 .93449 Mdot
.83378 .95924 Mdot
.58857 .31304 Mdot
.37555 .39249 Mdot
.51847 .84657 Mdot
.22831 .4562 Mdot
.09568 .74492 Mdot
.34642 .76101 Mdot
.36188 .93685 Mdot
.83249 .47141 Mdot
.5898 .23498 Mdot
.28864 .0402 Mdot
.72298 .30062 Mdot
.45437 .08152 Mdot
.13456 .9874 Mdot
.08014 .6897 Mdot
.61435 .14101 Mdot
.85048 .23359 Mdot
.51904 .39665 Mdot
.50223 .47301 Mdot
.15827 .46022 Mdot
.6708 .00184 Mdot
.56693 .22409 Mdot
.38212 .96095 Mdot
.84522 .92364 Mdot
.92895 .87914 Mdot
.71012 .93632 Mdot
.84892 .18975 Mdot
.09692 .79436 Mdot
.99939 .95587 Mdot
.57531 .39792 Mdot
.49378 .48367 Mdot
.41767 .93861 Mdot
.82413 .482 Mdot
.85195 .71341 Mdot
.43982 .52183 Mdot
.00822 .79061 Mdot
.51181 .6423 Mdot
.29572 .85484 Mdot
.66362 .45273 Mdot
.20062 .05975 Mdot
.66513 .49685 Mdot
.62326 .66222 Mdot
.17093 .01335 Mdot
.20538 .72386 Mdot
.34622 .53147 Mdot
.35374 .01043 Mdot
.90699 .00982 Mdot
.34711 .21968 Mdot
.39271 .36749 Mdot
.05204 .36551 Mdot
.72933 .91473 Mdot
.85065 .30492 Mdot
.06542 .41729 Mdot
.22645 .64273 Mdot
.8937 .40366 Mdot
.02203 .91883 Mdot
.54597 .87199 Mdot
.66629 .90916 Mdot
.63992 .86225 Mdot
.31898 .68846 Mdot
.24696 .49475 Mdot
.2684 .32356 Mdot
.51646 .5805 Mdot
.41697 .01816 Mdot
.45286 .16318 Mdot
.19171 .37577 Mdot
.55895 .75999 Mdot
.17091 .45634 Mdot
.01399 .88835 Mdot
.50206 .5474 Mdot
.3718 .0265 Mdot
.18393 .85872 Mdot
.12638 .53181 Mdot
.91548 .53577 Mdot
.60683 .95157 Mdot
.49604 .51811 Mdot
.15432 .78748 Mdot
.30627 .14267 Mdot
.59371 .02772 Mdot
.13669 .68712 Mdot
.58085 .13878 Mdot
.63239 .13958 Mdot
.20921 .11215 Mdot
.44841 .28077 Mdot
.08511 .58106 Mdot
.53307 .74485 Mdot
.47539 .62949 Mdot
.03716 .22712 Mdot
.32165 .84253 Mdot
.73011 .08476 Mdot
.72795 .81496 Mdot
.59407 .397 Mdot
.14771 .67591 Mdot
.96245 .25727 Mdot
.93875 .56325 Mdot
.51222 .9769 Mdot
.85498 .98266 Mdot
.97964 .23127 Mdot
.3776 .35286 Mdot
.94344 .00412 Mdot
.05713 .51049 Mdot
.21224 .91979 Mdot
.32702 .69533 Mdot
.6163 .52282 Mdot
.18108 .01906 Mdot
.65524 .26485 Mdot
.24232 .45645 Mdot
.14251 .28899 Mdot
.38727 .47391 Mdot
.16333 .05678 Mdot
.01039 .12091 Mdot
.2206 .05255 Mdot
.95456 .61057 Mdot
.00887 .13286 Mdot
.6255 .91584 Mdot
.39059 .6101 Mdot
.44453 .89622 Mdot
.73591 .34459 Mdot
.20353 .44032 Mdot
.59335 .05657 Mdot
.81549 .96643 Mdot
.42996 .99959 Mdot
.80604 .84508 Mdot
.21089 .946 Mdot
.85151 .23419 Mdot
.20234 .81314 Mdot
.22545 .3196 Mdot
.8113 .20319 Mdot
.78009 .42262 Mdot
.07656 .85773 Mdot
.5761 .98378 Mdot
.48106 .8014 Mdot
.76123 .01792 Mdot
.05219 .80239 Mdot
.95637 .17222 Mdot
.84126 .85619 Mdot
.10526 .93777 Mdot
.63768 .04323 Mdot
.87956 .6188 Mdot
.82743 .84002 Mdot
.09961 .19611 Mdot
.75085 .98268 Mdot
.52184 .21258 Mdot
.26945 .18025 Mdot
.76092 .1957 Mdot
.21836 .37914 Mdot
.80482 .02378 Mdot
.37704 .5223 Mdot
.69987 .08554 Mdot
.73986 .47898 Mdot
.82187 .46567 Mdot
.9134 .63918 Mdot
.72242 .2694 Mdot
.16218 .65737 Mdot
.2002 .05643 Mdot
.89274 .47719 Mdot
.43789 .86158 Mdot
.67392 .0989 Mdot
.63327 .83823 Mdot
.29623 .57622 Mdot
.93467 .75304 Mdot
.55675 .09703 Mdot
.11277 .28717 Mdot
.64401 .4573 Mdot
.38919 .01751 Mdot
.48191 .79996 Mdot
.1905 .96007 Mdot
.58994 .32283 Mdot
.75076 .09957 Mdot
.91593 .22425 Mdot
.11772 .26107 Mdot
.61815 .64804 Mdot
.1841 .50804 Mdot
.06321 .55108 Mdot
.07194 .22091 Mdot
.41686 .09318 Mdot
.68163 .20341 Mdot
.93493 .29308 Mdot
.49077 .24314 Mdot
.34395 .97038 Mdot
.74001 .14454 Mdot
.42773 .74558 Mdot
.62231 .8837 Mdot
.8091 .09854 Mdot
.43862 .37559 Mdot
.74773 .54662 Mdot
.36773 .15385 Mdot
.32918 .45375 Mdot
.68588 .95132 Mdot
.39471 .15963 Mdot
.19497 .70706 Mdot
.05123 .18979 Mdot
.45395 .56296 Mdot
.62161 .44391 Mdot
.83225 .67933 Mdot
.81282 .34593 Mdot
.39185 .30443 Mdot
.06651 .79933 Mdot
.02486 .1499 Mdot
.73569 .34527 Mdot
.33776 .19897 Mdot
.34027 .18508 Mdot
.14388 .49238 Mdot
.28964 .99537 Mdot
.68741 .92985 Mdot
.66685 .55148 Mdot
.85614 .2494 Mdot
.85437 .20542 Mdot
.46297 .94544 Mdot
.78912 .40567 Mdot
.43875 .79501 Mdot
.05417 .06012 Mdot
.10326 .59573 Mdot
.71269 .87522 Mdot
.95964 .10341 Mdot
.42246 .87954 Mdot
.27131 .17392 Mdot
.75623 .32721 Mdot
.41375 .9252 Mdot
.90207 .12244 Mdot
.95176 .97953 Mdot
.1138 .71633 Mdot
.51052 .18434 Mdot
.06057 .65605 Mdot
.40893 .58884 Mdot
.34546 .78119 Mdot
.44941 .48587 Mdot
.92381 .90195 Mdot
.17957 .31205 Mdot
.16715 .57414 Mdot
.76462 .38621 Mdot
.26446 .45229 Mdot
.81378 .40676 Mdot
.15256 .73577 Mdot
.30254 .22225 Mdot
.09341 .07971 Mdot
.89364 .6331 Mdot
.74662 .29853 Mdot
.44211 .14761 Mdot
.82391 .39684 Mdot
.26311 .8367 Mdot
.65663 .82284 Mdot
.49779 .4503 Mdot
.39181 .37105 Mdot
.68471 .04348 Mdot
.24025 .63469 Mdot
.38189 .82061 Mdot
.14858 .55499 Mdot
.489 .18667 Mdot
.40064 .25576 Mdot
.04775 .03876 Mdot
.57642 .8592 Mdot
.78346 .20264 Mdot
.92066 .03627 Mdot
.28401 .75264 Mdot
.52649 .66516 Mdot
.5984 .70942 Mdot
.28717 .03025 Mdot
.21662 .88909 Mdot
.14047 .47583 Mdot
.72643 .70212 Mdot
.73829 .2194 Mdot
.67918 .66323 Mdot
.16162 .36114 Mdot
.89647 .46113 Mdot
.24096 .32487 Mdot
.61087 .70822 Mdot
.71322 .65866 Mdot
.01336 .9986 Mdot
.42597 .62792 Mdot
.79563 .11029 Mdot
.28751 .15233 Mdot
.07049 .40761 Mdot
.5482 .93348 Mdot
.38864 .74395 Mdot
.38764 .57258 Mdot
.49248 .28319 Mdot
.14748 .2486 Mdot
.88188 .57464 Mdot
.43288 .58953 Mdot
.8695 .57583 Mdot
.00791 .96136 Mdot
.07442 .46674 Mdot
.71937 .80887 Mdot
.00464 .05898 Mdot
.17112 .87555 Mdot
.61424 .31466 Mdot
.78253 .30273 Mdot
.12196 .03137 Mdot
.63515 .05495 Mdot
.23983 .4571 Mdot
.2024 .46529 Mdot
.37 .881 Mdot
.19545 .50346 Mdot
.29728 .41454 Mdot
.47464 .69409 Mdot
.29366 .35539 Mdot
.30407 .81919 Mdot
.67909 .04055 Mdot
.52083 .51607 Mdot
.55769 .00865 Mdot
.88671 .46144 Mdot
.31782 .55134 Mdot
.68382 .9971 Mdot
.94839 .6708 Mdot
.48815 .49319 Mdot
.6496 .25637 Mdot
.01525 .79853 Mdot
.35466 .90215 Mdot
.70868 .98014 Mdot
.67525 .86217 Mdot
.18771 .46388 Mdot
.11826 .85336 Mdot
.30074 .00204 Mdot
.79891 .30179 Mdot
.61578 .00656 Mdot
.85218 .63081 Mdot
.12821 .51335 Mdot
.2024 .37539 Mdot
.11405 .71507 Mdot
.8469 .47256 Mdot
.40299 .7353 Mdot
.17112 .6106 Mdot
.21667 .27255 Mdot
.0543 .75745 Mdot
.91592 .26953 Mdot
.25378 .45548 Mdot
.29952 .2638 Mdot
.40143 .82415 Mdot
.17294 .7505 Mdot
.20081 .45005 Mdot
.0605 .03543 Mdot
.35339 .97705 Mdot
.65605 .29967 Mdot
.18381 .3669 Mdot
.43858 .02824 Mdot
.13122 .60882 Mdot
.52271 .75798 Mdot
.87625 .15381 Mdot
.22392 .49451 Mdot
.47303 .32973 Mdot
.05243 .7441 Mdot
.27299 .8802 Mdot
.99275 .70851 Mdot
.92051 .9033 Mdot
.33481 .40855 Mdot
.73637 .53683 Mdot
.89605 .38032 Mdot
.60525 .92882 Mdot
.37212 .62164 Mdot
.72952 .77464 Mdot
.1491 .12709 Mdot
.2558 .44542 Mdot
.09878 .38378 Mdot
.98343 .56491 Mdot
.10721 .67549 Mdot
.06457 .66191 Mdot
.77042 .26701 Mdot
.32724 .12421 Mdot
.87536 .88726 Mdot
.72132 .1961 Mdot
.50117 .2651 Mdot
.9922 .42154 Mdot
.35303 .13747 Mdot
.73507 .97715 Mdot
.25536 .75442 Mdot
.75291 .41107 Mdot
.15031 .07869 Mdot
.68884 .7498 Mdot
.37846 .81203 Mdot
.36182 .62508 Mdot
.50404 .925 Mdot
.64064 .42881 Mdot
.00429 .65975 Mdot
.64903 .00825 Mdot
.64939 .52159 Mdot
.91486 .03117 Mdot
.39337 .76722 Mdot
.16201 .61946 Mdot
.24406 .68812 Mdot
.47102 .86996 Mdot
.86599 .87655 Mdot
.11025 .24452 Mdot
.35938 .95186 Mdot
.4678 .81538 Mdot
.35654 .29213 Mdot
.81975 .8078 Mdot
.70645 .77037 Mdot
.90606 .77675 Mdot
.31268 .00292 Mdot
.7434 .15725 Mdot
.06914 .31486 Mdot
.27145 .28757 Mdot
.20367 .43908 Mdot
.16236 .04237 Mdot
.8437 .48674 Mdot
.69333 .22705 Mdot
.48561 .1945 Mdot
.87412 .41975 Mdot
.77961 .42396 Mdot
.96995 .64292 Mdot
.46565 .42165 Mdot
.22551 .486 Mdot
.39776 .10608 Mdot
.95412 .19849 Mdot
.19505 .66771 Mdot
.79187 .15634 Mdot
.35166 .18062 Mdot
.09975 .92817 Mdot
.86608 .98649 Mdot
.22485 .50888 Mdot
.08759 .56213 Mdot
.25558 .86606 Mdot
.61929 .14048 Mdot
.03129 .38016 Mdot
.22153 .03381 Mdot
.07687 .18135 Mdot
.02709 .36626 Mdot
.28451 .02529 Mdot
.67433 .1849 Mdot
.18585 .09664 Mdot
.80876 .19911 Mdot
.96125 .58802 Mdot
.72251 .63673 Mdot
.70425 .72211 Mdot
.10485 .49645 Mdot
.67455 .34158 Mdot
.88224 .46214 Mdot
.59784 .16025 Mdot
.85596 .09615 Mdot
.31389 .13467 Mdot
.18191 .91039 Mdot
.12889 .03757 Mdot
.37197 .71151 Mdot
.16849 .4502 Mdot
.64953 .07518 Mdot
.46216 .72722 Mdot
.5455 .57878 Mdot
.78854 .38517 Mdot
.6644 .11687 Mdot
.19073 .2251 Mdot
.80889 .02159 Mdot
.877 .09032 Mdot
.62715 .11049 Mdot
.74802 .05267 Mdot
.25468 .39948 Mdot
.57937 .6025 Mdot
.60455 .32353 Mdot
.11854 .87446 Mdot
.05928 .7453 Mdot
.32852 .48918 Mdot
.39291 .62809 Mdot
.13935 .26439 Mdot
.5831 .60744 Mdot
.26249 .17392 Mdot
.95754 .49688 Mdot
.51306 .12212 Mdot
.70169 .09832 Mdot
.93354 .51992 Mdot
.09838 .77415 Mdot
.81587 .64473 Mdot
.04014 .02883 Mdot
.48524 .1558 Mdot
.64574 .40034 Mdot
.34627 .89209 Mdot
.06264 .79356 Mdot
.0861 .71779 Mdot
.10523 .29685 Mdot
.56975 .59559 Mdot
.40181 .19807 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool00_ooool2o`0000Wo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo0_l00002ooooo`;o00002_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`;o00002?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo0_l00008ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`?o00001?ooool2o`0000[o
oooo00?o0000ooooooooool00_ooool001kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`04ooooo`;o00001oooool00ol0003oooooooooo`02ooooo`;o00002Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool2o`0000;ooooo
0_l0000:ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool01?l0003ooooo
ooooooooool2o`0000[ooooo00?o0000ooooooooool00oooool2o`0000Sooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`04ooooo`;o00002?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool3o`0000Cooooo0_l0000:ooooo`03
o`000?oooooooooo00;ooooo000Nooooo`03o`000?oooooooooo06oooooo0_l00010ooooo`;o0000
4Oooool2o`0000Wooooo0_l0001Booooo`;o00008_ooool001kooooo00?o0000ooooooooool0<ooo
ool2o`0003;ooooo0_l00006ooooo`;o00003Oooool2o`00037ooooo0_l0000Looooo`;o0000D_oo
ool2o`0002;ooooo000Nooooo`03o`000?oooooooooo03?ooooo0_l0000booooo`;o00005Oooool2
o`0004Sooooo0_l0001mooooo`007_ooool00ol0003oooooooooo`0gooooo`;o0000@Oooool2o`00
00Oooooo0_l00007ooooo`;o0000:Oooool2o`0000oooooo0_l0000?ooooo`;o00006?ooool2o`00
05;ooooo000Nooooo`03o`000?oooooooooo03Oooooo0_l00011ooooo`;o00001oooool2o`0000Oo
oooo0_l0000Yooooo`;o00008?ooool2o`0001Sooooo0_l0000>ooooo`;o00002_ooool2o`0003Ko
oooo000Nooooo`03o`000?oooooooooo05Sooooo0_l0002Xooooo`?o00002_ooool2o`0003Kooooo
000Nooooo`03o`000?oooooooooo00Wooooo0_l0000Wooooo`;o00009?ooool2o`0001_ooooo0_l0
000Cooooo`;o0000:?ooool2o`0000Oooooo0_l00013ooooo`;o0000=_ooool2o`0000_ooooo000N
ooooo`03o`000?oooooooooo00Wooooo0_l0000Iooooo`;o00003?ooool2o`0002Gooooo0_l0000J
ooooo`;o00004oooool2o`0002Sooooo0_l00007ooooo`;o0000I_ooool2o`0001?ooooo0_l0000;
ooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o00005oooool2o`0001kooooo0_l0000Coooo
o`;o0000b_ooool2o`00017ooooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o
00000oooool2o`0001Cooooo0_l0000Looooo`;o00005?ooool2o`00027ooooo0_l0002Xooooo`;o
00003oooool2o`0000gooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l00003ooooo`;o0000
5?ooool2o`0000Cooooo0_l0000/ooooo`;o00008Oooool2o`0002cooooo0_l0000Qooooo`;o0000
2Oooool2o`0004cooooo0_l0000Nooooo`007_ooool00ol0003oooooooooo`06ooooo`;o00000ooo
ool2o`0001oooooo0_l00003ooooo`;o00009oooool2o`0004oooooo0_l0000Nooooo`;o000000?o
ooooo`000?l000002Oooool3o`0006_ooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l0000Y
ooooo`;o0000V?ooool2o`0000gooooo0_l0001[ooooo`007_ooool00ol0003oooooooooo`1<oooo
o`;o00006_ooool2o`000=gooooo000Nooooo`;o0000AOooool2o`0000Kooooo0_l0000Jooooo`;o
0000P?ooool2o`0000?ooooo0_l0001Fooooo`007_ooool00ol0003oooooooooo`0aooooo`;o0000
2_ooool2o`0000Gooooo0_l0001=ooooo`;o0000:?ooool2o`0000_ooooo0_l0000Nooooo`;o0000
0oooool2o`0005Kooooo000Nooooo`;o00006Oooool2o`0001Oooooo0_l00007ooooo`;o000000?o
ooooo`000?l00000A_ooool2o`0000cooooo0_l0000Xooooo`;o00002oooool2o`0007_ooooo000N
ooooo`;o00003_ooool2o`0000Wooooo0_l0000Pooooo`;o000000?oooooo`000?l00000A_ooool2
o`0008_ooooo0_l0000cooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o0000ooooool4oooo
o`;o0000<oooool001kooooo00?o0000ooooooooool02Oooool2o`0001[ooooo0_l0000jooooo`;o
0000i?ooool001kooooo00?o0000ooooooooool02Oooool2o`0001Gooooo0_l00003ooooo`;o0000
>_ooool2o`000<oooooo0_l0000Cooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o0000;Ooo
ool2o`0003Sooooo0_l00014ooooo`;o00002_ooool2o`0000Kooooo0_l0001=ooooo`;o00004ooo
ool001kooooo00?o0000ooooooooool0AOooool2o`0000Sooooo0_l0000hooooo`;o0000A?ooool2
o`0000[ooooo0_l00006ooooo`;o0000H_ooool001kooooo00?o0000ooooooooool06_ooool2o`00
017ooooo0_l0000Fooooo`;o0000ooooool1ooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o
00001oooool2o`0000Sooooo0_l00013ooooo`;o00007?ooool2o`000;Gooooo000Nooooo`03o`00
0?oooooooooo02?ooooo0_l0001=ooooo`;o00007?ooool2o`0004gooooo0_l00008ooooo`;o0000
G?ooool001kooooo00?o0000ooooooooool0goooool2o`0000Sooooo0_l0000^ooooo`;o00005_oo
ool2o`0001Cooooo000Nooooo`03o`000?oooooooooo07Oooooo0_l0000:ooooo`;o0000AOooool2
o`0004gooooo0_l0000Fooooo`;o00005?ooool001kooooo00?o0000ooooooooool0>?ooool2o`00
03gooooo0_l0000:ooooo`;o00003?ooool2o`0000Wooooo0_l0000Sooooo`;o00001oooool2o`00
00Sooooo0_l0000looooo`;o0000<oooool001kooooo00?o0000ooooooooool00_ooool2o`0002Go
oooo0_l0000=ooooo`;o0000Eoooool2o`0000;ooooo0_l00005ooooo`;o00004oooool2o`0000ko
oooo0_l0000Aooooo`;o000000?oooooo`000?l000001oooool2o`0000kooooo0_l0000Aooooo`;o
00003Oooool2o`0001Cooooo0_l0000Mooooo`007_ooool2o`0000?ooooo0_l0000Uooooo`;o0000
Doooool2o`0000Kooooo0_l0000=ooooo`;o00006_ooool2o`0002Cooooo0_l00007ooooo`;o0000
3_ooool2o`00017ooooo0_l0000?ooooo`;o00004_ooool2o`0001gooooo000Nooooo`03o`000?oo
oooooooo07kooooo0_l00006ooooo`;o0000S?ooool2o`0001kooooo0_l0000Aooooo`007_ooool0
0ol0003oooooooooo`1mooooo`;o0000]Oooool2o`00017ooooo000Nooooo`03o`000?oooooooooo
043ooooo0_l0000kooooo`;o0000BOooool2o`0003Gooooo0_l0000cooooo`;o00004Oooool001ko
oooo00?o0000ooooooooool0@?ooool2o`0003_ooooo0_l00019ooooo`;o00002Oooool2o`0002[o
oooo0_l00008ooooo`;o0000??ooool001kooooo00?o0000ooooooooool04Oooool2o`000<3ooooo
0ol0000>ooooo`;o00008oooool2o`0003cooooo000Nooooo`04o`000?oooooo0000o`00013ooooo
0_l00006ooooo`;o0000B?ooool2o`0006oooooo0_l0000>ooooo`;o0000HOooool001kooooo00Co
0000ooooool0003o00006?ooool2o`0004Sooooo0_l000000ooooooo0000o`00000kooooo`;o0000
O?ooool2o`0002Cooooo000Nooooo`03o`000?oooooooooo02cooooo0_l0000hooooo`;o00003Ooo
ool2o`0002cooooo0_l0001looooo`;o00009?ooool001kooooo00?o0000ooooooooool0;?ooool2
o`00023ooooo0_l0000Uooooo`;o0000G_ooool2o`0005Kooooo0_l0000Hooooo`007_ooool01?l0
003oooooo`000?l0000=ooooo`;o00003?ooool2o`00033ooooo0_l0000^ooooo`;o0000<Oooool2
o`0001Oooooo0_l00009ooooo`;o0000E_ooool2o`0001Sooooo000Nooooo`04o`000?oooooo0000
o`0000gooooo0_l0000<ooooo`;o0000A?ooool2o`0000Kooooo0_l0000Booooo`;o00001?ooool2
o`0002Kooooo0_l00003ooooo`;o00005oooool2o`0007;ooooo0_l00007ooooo`007_ooool00ol0
003oooooooooo`1Aooooo`;o00003oooool2o`0000Kooooo0_l00003ooooo`;o00004oooool2o`00
02Kooooo0_l0000;ooooo`;o00003_ooool2o`0007?ooooo0_l00007ooooo`007_ooool00ol0003o
ooooooooo`1Aooooo`;o00003?ooool2o`0000kooooo0_l00018ooooo`;o00002Oooool3o`0000;o
oooo0_l0001looooo`007_ooool00ol0003oooooooooo`1Oooooo`;o0000A_ooool2o`0001_ooooo
0ol000000ooooooo0000o`00000Rooooo`;o0000FOooool001kooooo00?o0000ooooooooool0S?oo
ool2o`0001Wooooo0_l0000Oooooo`;o00008_ooool2o`0005Wooooo000Nooooo`;o00001Oooool2
o`0004Sooooo0_l0000Qooooo`;o00006Oooool2o`0009[ooooo0_l0000Mooooo`007_ooool00ol0
003oooooooooo`04ooooo`;o0000>_ooool2o`0000cooooo0_l00009ooooo`;o00005_ooool4o`00
07Sooooo0_l0000Zooooo`;o00001_ooool2o`0000Gooooo0_l0000Mooooo`007_ooool00ol0003o
ooooooooo`10ooooo`;o00005oooool2o`0001Sooooo0_l0000Fooooo`;o00003Oooool2o`00057o
oooo0ol0000=ooooo`;o00006_ooool2o`0000Kooooo0_l0000Tooooo`007_ooool00ol0003ooooo
ooooo`0Wooooo`;o0000Doooool2o`0000gooooo0_l0000=ooooo`;o00008_ooool2o`0002kooooo
0_l0000=ooooo`;o0000B?ooool001kooooo00?o0000ooooooooool09oooool2o`0005?ooooo0_l0
000Aooooo`;o0000;Oooool2o`0002gooooo0_l0000`ooooo`;o00009_ooool001kooooo00?o0000
ooooooooool02Oooool2o`0006Kooooo0_l0000Looooo`;o00003Oooool2o`0000gooooo0_l0000n
ooooo`;o0000<?ooool2o`0002Kooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0001Voooo
o`;o00002?ooool2o`00027ooooo0_l0000=ooooo`;o0000V?ooool001kooooo00?o0000oooooooo
ool0F?ooool2o`00027ooooo0_l0002fooooo`;o00004_ooool001kooooo00?o0000ooooooooool0
DOooool2o`000003ooooool0003o000000;ooooo0_l0003Iooooo`;o00004_ooool001kooooo00?o
0000ooooooooool0DOooool2o`000003ooooool0003o00000?7ooooo000Nooooo`03o`000?oooooo
oooo01Gooooo0_l0000looooo`;o00006Oooool2o`000=Oooooo000Nooooo`03o`000?oooooooooo
01Gooooo0_l0000looooo`;o00005_ooool2o`000003ooooool0003o000003;ooooo0_l0000coooo
o`;o0000@?ooool2o`0002cooooo000Nooooo`03o`000?oooooooooo06_ooooo0_l0000^ooooo`;o
00001Oooool2o`0003?ooooo0_l0000Aooooo`;o0000;Oooool3o`0002_ooooo000Nooooo`03o`00
0?oooooooooo00gooooo0_l0002<ooooo`;o00009_ooool2o`0002Gooooo0_l0000Tooooo`;o0000
2?ooool2o`0002_ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol00006ooooo`03o`000?oooooooooo00gooooo0_l0001hooooo`;o00004Oooool2o`0000[ooooo
0_l0000Kooooo`;o0000Boooool2o`0003Gooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo01co
oooo0_l0001Qooooo`;o00001_ooool2o`00017ooooo0_l0000:ooooo`;o0000?_ooool2o`0000_o
oooo0_l0000Wooooo`;o0000:Oooool000?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03
oiRHV?lQ8B7ok^k^00Oooooo0ol0000Looooo`;o0000C?ooool2o`0001?ooooo0_l0001Uooooo`;o
00002oooool2o`0000kooooo0_l0000Gooooo`;o00005?ooool2o`0001?ooooo0003ooooo`05o`00
0?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`04o`000?oooooo0000o`00
06Wooooo0_l0001]ooooo`;o00008?ooool2o`0000Kooooo0ol0000<ooooo`;o00007_ooool2o`00
01?ooooo0003ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05oooo
o`04o`000?oooooo0000o`00013ooooo0_l00036ooooo`;o00000oooool2o`0001_ooooo0_l00007
ooooo`;o00003?ooool2o`0003?ooooo0003ooooo`05oa0@4?ooooooooooooooool@41003oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo017ooooo0_l0003;ooooo`;o0000<_ooool2
o`0003?ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonH
V9So410@00Kooooo00?o0000ooooooooool0:_ooool2o`0007[ooooo0_l0002?ooooo`;o00003_oo
ool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
1_ooool00ol0003oooooooooo`0Nooooo`;o00002_ooool4o`0003Wooooo0_l0000mooooo`;o0000
COooool2o`00043ooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`0Nooooo`;o00003?oo
ool2o`0001oooooo0_l0000Hooooo`;o00001?ooool3o`0007cooooo0_l00007ooooo`;o00002Ooo
ool2o`0004Gooooo000Nooooo`03o`000?oooooooooo01?ooooo0_l0000hooooo`;o00003oooool2
o`0000gooooo0ol00010ooooo`;o0000>_ooool2o`0001;ooooo0_l00015ooooo`007_ooool00ol0
003oooooooooo`0Cooooo`;o00004?ooool2o`0001?ooooo0_l0000:ooooo`;o00005_ooool2o`00
053ooooo0_l00002ooooo`;o0000L?ooool2o`0001oooooo000Nooooo`03o`000?oooooooooo00So
oooo0_l0000Kooooo`;o00004oooool2o`0000?ooooo0_l00005ooooo`;o0000H?ooool2o`0000[o
oooo0_l0000Wooooo`;o0000Aoooool2o`0001oooooo000Nooooo`03o`000?oooooooooo00Sooooo
0_l0000eooooo`;o00008Oooool2o`0004Cooooo0_l0000cooooo`;o0000@oooool2o`0001Kooooo
0_l000000ooooooo0000o`000008ooooo`007_ooool00ol0003oooooooooo`1Rooooo`;o0000F?oo
ool2o`0005;ooooo0ol0000?ooooo`;o00005_ooool2o`000003ooooool0003o000000Sooooo000N
ooooo`03o`000?oooooooooo07;ooooo0_l00018ooooo`;o0000D_ooool3o`0003Cooooo000Noooo
o`03o`000?oooooooooo07;ooooo0_l0001Iooooo`;o0000<oooool2o`0000gooooo0_l0000[oooo
o`;o00001oooool001kooooo00?o0000ooooooooool0Doooool2o`0004Kooooo0_l0000`ooooo`;o
0000<oooool2o`0000gooooo0_l0000[ooooo`;o00001oooool001kooooo00?o0000ooooooooool0
8?ooool2o`0002Cooooo0_l0000;ooooo`;o0000A_ooool2o`0005Cooooo0_l0001Dooooo`007_oo
ool00ol0003oooooooooo`0Pooooo`;o00002_ooool2o`0001Sooooo0_l0002Yooooo`;o00007ooo
ool2o`0003?ooooo000Nooooo`;o0000;Oooool2o`000>Cooooo0_l0000cooooo`007_ooool00ol0
003oooooooooo`1nooooo`;o0000Coooool2o`0003Gooooo0_l0000oooooo`007_ooool00ol0003o
ooooooooo`1nooooo`;o0000Coooool2o`0003Gooooo0_l0000]ooooo`;o00004?ooool001kooooo
00?o0000ooooooooool08_ooool2o`0007Wooooo0_l0002Fooooo`;o00004?ooool001kooooo00?o
0000ooooooooool08_ooool2o`0000Gooooo0_l0000booooo`;o0000?_ooool4o`0002Wooooo0_l0
0005ooooo`;o0000M?ooool001kooooo00?o0000ooooooooool0:Oooool2o`0002?ooooo0_l0000=
ooooo`;o0000@?ooool2o`0002Wooooo0_l00005ooooo`;o00008oooool2o`0004oooooo000Noooo
o`03o`000?oooooooooo01cooooo0_l0000`ooooo`;o0000:_ooool2o`0006;ooooo0_l00007oooo
o`;o00003Oooool2o`0002kooooo0_l0000Oooooo`007_ooool00ol0003oooooooooo`0Looooo`;o
00009?ooool2o`0003Cooooo1?l0001Rooooo`;o00001oooool2o`000003ooooool0003o000003[o
oooo0_l00007ooooo`;o00005_ooool001kooooo00?o0000ooooooooool0@_ooool2o`0003Cooooo
0_l0001Pooooo`;o00003_ooool2o`0004?ooooo0_l0000Fooooo`007_ooool00ol0003ooooooooo
o`0Cooooo`;o00005Oooool2o`0006;ooooo0_l0001:ooooo`;o0000Joooool001kooooo00?o0000
ooooooooool04oooool2o`0001Gooooo0_l0001Rooooo`;o00003?ooool2o`0000Oooooo0_l0001^
ooooo`;o0000<?ooool001kooooo00?o0000ooooooooool08Oooool2o`00073ooooo0_l00007oooo
o`;o00001oooool2o`0005_ooooo0_l0000>ooooo`;o000000?oooooo`000?l00000<?ooool001ko
oooo00?o0000ooooooooool08Oooool2o`0000Oooooo0_l0000Xooooo`;o0000?Oooool2o`0000_o
oooo0_l000000ooooooo0000o`00001Mooooo`;o00003_ooool2o`0003?ooooo000Nooooo`04o`00
0?oooooo0000o`0002Cooooo0_l00003ooooo`;o0000:?ooool2o`0001[ooooo0_l0000^ooooo`;o
000000?oooooo`000?l00000>?ooool2o`0004gooooo0_l0000Iooooo`007_ooool01?l0003ooooo
o`000?l0000Tooooo`;o0000BOooool2o`0006_ooooo0_l0001=ooooo`;o00006Oooool001kooooo
00Co0000ooooool0003o00007Oooool2o`000;7ooooo0_l0000Looooo`;o0000E_ooool001kooooo
0_l0000Oooooo`;o0000/Oooool2o`0001Cooooo0_l00006ooooo`;o00002Oooool2o`0000Cooooo
0_l00015ooooo`007_ooool00ol0003oooooooooo`1kooooo`;o0000J_ooool2o`0000kooooo0_l0
00000ooooooo0000o`000004ooooo`;o00003_ooool2o`0003Gooooo000Nooooo`03o`000?oooooo
oooo07_ooooo0_l0001jooooo`;o00005oooool2o`00023ooooo0_l0000<ooooo`;o00001Oooool0
01kooooo0ol00008ooooo`;o0000;?ooool2o`000?[ooooo0_l0000<ooooo`;o00001Oooool001ko
oooo0ol00008ooooo`;o00002?ooool2o`0002;ooooo0_l00023ooooo`;o00001oooool2o`00087o
oooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0002Wooooo`;o00001oooool2o`00087ooooo
000Nooooo`03o`000?oooooooooo037ooooo0_l0000Booooo`;o0000[?ooool2o`0005;ooooo000N
ooooo`03o`000?oooooooooo037ooooo0_l0000Booooo`;o00003?ooool2o`0000_ooooo0_l0000e
ooooo`;o00008oooool2o`0000;ooooo0_l0000aooooo`;o00004oooool2o`0003gooooo000Noooo
o`03o`000?oooooooooo02?ooooo0_l0000Uooooo`;o00001oooool2o`0000_ooooo0_l0000eoooo
o`;o00008oooool2o`0000;ooooo0_l0000`ooooo`;o00005?ooool2o`0003gooooo000Nooooo`03
o`000?oooooooooo01gooooo0_l00004ooooo`;o00009Oooool2o`0004[ooooo0ol0001Iooooo`;o
0000Doooool001kooooo00?o0000ooooooooool07Oooool2o`0007Oooooo0_l0000;ooooo`;o0000
C_ooool2o`0005;ooooo000Nooooo`03o`000?oooooooooo0:?ooooo0_l0001>ooooo`;o0000<?oo
ool2o`00023ooooo000Nooooo`03o`000?oooooooooo08oooooo0_l0000^ooooo`;o0000<Oooool2
o`00037ooooo0_l0000Pooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o0000Ooooool2o`00
02kooooo0_l0000Fooooo`;o00006Oooool2o`0005?ooooo000Nooooo`03o`000?oooooooooo00ko
oooo0_l0002Hooooo`;o0000;Oooool2o`0001;ooooo0_l0000iooooo`;o00007oooool001kooooo
00?o0000ooooooooool0I_ooool2o`00043ooooo0_l0000Zooooo`;o00005Oooool2o`0001Oooooo
0_l0000Pooooo`;o00007oooool001kooooo0_l0001Looooo`;o00002Oooool2o`0006cooooo0_l0
000^ooooo`;o0000@Oooool001kooooo00?o0000ooooooooool0Foooool2o`0001[ooooo0_l0003>
ooooo`007_ooool00ol0003oooooooooo`1Kooooo`;o00006_ooool2o`000<kooooo000Nooooo`03
o`000?oooooooooo033ooooo0_l0000<ooooo`;o00006oooool2o`000>[ooooo000Nooooo`03o`00
0?oooooooooo033ooooo0_l0000<ooooo`;o0000ooooool8ooooo`007_ooool00ol0003ooooooooo
o`05ooooo`;o00001_ooool2o`0000oooooo0_l0000Hooooo`;o00000_ooool2o`0002[ooooo0_l0
0006ooooo`;o00005oooool2o`0004;ooooo0_l0001Kooooo`;o00006oooool001kooooo00?o0000
ooooooooool01Oooool2o`0000Kooooo0_l0000?ooooo`;o00006?ooool2o`0000;ooooo0_l0000Z
ooooo`;o00001_ooool2o`0000[ooooo0_l0000;ooooo`;o0000@_ooool2o`0005_ooooo0_l0000K
ooooo`007_ooool01?l0003oooooooooooooool2o`0007Sooooo0ol00039ooooo`007_ooool01?l0
003oooooooooooooool2o`0003Oooooo0_l00002ooooo`;o0000>oooool2o`0000gooooo0_l0001N
ooooo`;o00001?ooool2o`0005Gooooo000Nooooo`03o`000?oooooooooo03[ooooo0_l00002oooo
o`;o00000oooool2o`0004Gooooo0_l0001Nooooo`;o00001?ooool2o`0005Gooooo000Nooooo`03
o`000?oooooooooo00Kooooo0_l0000kooooo`;o0000f_ooool2o`0002Kooooo000Nooooo`03o`00
0?oooooooooo00Kooooo0_l0000Dooooo`;o0000E_ooool2o`0008Kooooo0_l0000Qooooo`;o0000
9_ooool001kooooo00?o0000ooooooooool07?ooool2o`0000Oooooo0_l0000Zooooo`;o00001_oo
ool2o`0000Kooooo0_l0000Aooooo`;o00001Oooool2o`0007Oooooo0_l00006ooooo`;o0000BOoo
ool001kooooo00?o0000ooooooooool02_ooool2o`0001Wooooo0_l0000Zooooo`;o00001_ooool2
o`0000Kooooo0_l0000Hooooo`;o00003?ooool2o`0006Wooooo0_l0001Aooooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool0
0ol0003oooooooooo`0:ooooo`;o0000J_ooool2o`00017ooooo0_l0002Kooooo`;o00007oooool0
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo07Kooooo0_l0000]ooooo`;o00001?ooool2o`0000[ooooo0_l00004
ooooo`;o0000BOooool2o`0001cooooo0_l0000Oooooo`000oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol00006ooooo`?o0000Coooool2o`0005Cooooo0_l00004ooooo`;o00002_ooool2
o`0000Cooooo0_l0000?ooooo`;o0000>?ooool2o`0003;ooooo0_l00009ooooo`000oooool01Ol0
003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool00ol0003ooooooooo
o`1?ooooo`;o0000OOooool2o`00017ooooo0_l0000kooooo`;o00007?ooool2o`0000Wooooo0003
ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`00
0?oooooooooo04Gooooo0_l0000/ooooo`;o0000?oooool2o`0002_ooooo0_l00006ooooo`;o0000
4Oooool2o`0000Kooooo0_l0000Hooooo`;o00009oooool000?ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool04oooool2o`00033ooooo
0_l0000Rooooo`;o00002?ooool2o`0003gooooo1?l0000cooooo`;o00004Oooool2o`0000Kooooo
0_l00011ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
1oooool00ol0003oooooooooo`0Cooooo`;o0000E?ooool2o`0004Oooooo0_l0000mooooo`;o0000
E?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo
00?o0000ooooooooool0GOooool2o`0009;ooooo0_l0001Dooooo`007_ooool00ol0003ooooooooo
o`0=ooooo`;o00000_ooool2o`0004[ooooo0_l0000Jooooo`;o00006_ooool2o`0003;ooooo0_l0
000booooo`;o0000B?ooool001kooooo00?o0000ooooooooool03Oooool2o`0000;ooooo0_l0000R
ooooo`;o00003_ooool2o`0003;ooooo0_l0000Hooooo`Co00001?ooool2o`0002cooooo0_l0000_
ooooo`;o000000?oooooo`000?l000006Oooool2o`0002Cooooo0_l00007ooooo`007_ooool00ol0
003oooooooooo`0eooooo`;o00003_ooool2o`0004cooooo0_l00006ooooo`;o0000G?ooool3o`00
01cooooo0_l0000Tooooo`;o00001oooool001kooooo00?o0000ooooooooool0V_ooool2o`00033o
oooo0_l0000[ooooo`?o0000Boooool001kooooo00?o0000ooooooooool0V_ooool2o`00013ooooo
0_l0000Nooooo`;o0000NOooool001kooooo00?o0000ooooooooool0[?ooool2o`0005_ooooo0_l0
000looooo`007_ooool00ol0003oooooooooo`1dooooo`;o0000Toooool2o`0003cooooo000Noooo
o`03o`000?oooooooooo03kooooo0_l0000dooooo`;o0000dOooool001kooooo00?o0000oooooooo
ool0;oooool2o`0000gooooo0_l00026ooooo`;o0000Ooooool001kooooo00?o0000ooooooooool0
;oooool2o`0001_ooooo0_l000000ooooooo0000o`000011ooooo`;o0000<_ooool2o`0007oooooo
000Nooooo`03o`000?oooooooooo01Wooooo0_l0000Hooooo`;o00002?ooool2o`0000[ooooo1Ol0
00000ooooooo0000o`000011ooooo`;o00002_ooool2o`0009Cooooo0_l0000Aooooo`007_ooool2
o`0001[ooooo0_l0000Hooooo`;o00002?ooool2o`0000[ooooo1?l00005ooooo`;o0000?Oooool2
o`0000_ooooo0_l0000dooooo`;o0000G_ooool2o`00017ooooo000Nooooo`03o`000?oooooooooo
03?ooooo0_l0000Aooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo0_l0000Coooo
o`;o00007Oooool2o`0000Wooooo0_l00011ooooo`;o0000LOooool001kooooo00?o0000oooooooo
ool0;Oooool2o`0000Cooooo0_l0000Aooooo`;o00000_ooool3o`000004ooooool0003o0000oooo
o`;o00005?ooool2o`0001gooooo0_l00015ooooo`;o00007oooool2o`0005Oooooo000Nooooo`03
o`000?oooooooooo02gooooo1?l0000Iooooo`;o00001Oooool2o`0000?ooooo0_l0001eooooo`;o
00007oooool2o`0002_ooooo0ol000000ooooooo0000o`00000Vooooo`007_ooool00ol0003ooooo
ooooo`0_ooooo`;o00002?ooool2o`0000?ooooo0_l0000Fooooo`;o0000[oooool2o`0001;ooooo
0ol000000ooooooo0000o`00000Vooooo`007_ooool00ol0003oooooooooo`0Cooooo`?o00008ooo
ool2o`0000?ooooo0_l0001Vooooo`;o0000Goooool2o`0003kooooo000Nooooo`03o`000?oooooo
oooo01?ooooo0ol0001Eooooo`;o0000>Oooool2o`0002_ooooo0_l0000>ooooo`;o00009_ooool2
o`0003[ooooo000Nooooo`03o`000?oooooooooo013ooooo0_l0001Iooooo`;o00003Oooool2o`00
02?ooooo0_l0000booooo`;o00003_ooool2o`0002Kooooo0_l00002ooooo`;o0000=_ooool001ko
oooo00?o0000ooooooooool04?ooool2o`0001Sooooo0_l0001>ooooo`;o00008oooool2o`0006ko
oooo0_l0000=ooooo`;o00009oooool001kooooo00Co0000ooooool0003o0000:Oooool2o`000<3o
oooo0_l0000`ooooo`;o00002oooool2o`0001[ooooo000Nooooo`04o`000?oooooo0000o`0009Go
oooo0_l00004ooooo`;o00000oooool2o`0004Wooooo0_l0000Jooooo`;o00008Oooool2o`0001[o
oooo000Nooooo`03o`000?oooooooooo04Gooooo0_l00003ooooo`;o0000@_ooool2o`0000Kooooo
0_l00004ooooo`;o00000oooool2o`0003;ooooo0_l0000aooooo`;o00001?ooool2o`0003Oooooo
000Nooooo`03o`000?oooooooooo04Gooooo0_l00003ooooo`;o00006oooool2o`0002Gooooo0_l0
0015ooooo`;o0000=oooool2o`0001oooooo0_l0000Fooooo`007_ooool00ol0003oooooooooo`0[
ooooo`;o0000>_ooool2o`0003;ooooo0_l0000mooooo`;o0000<?ooool2o`0001cooooo0_l00003
ooooo`;o000000?oooooo`000?l000004oooool001kooooo00?o0000ooooooooool07_ooool2o`00
00_ooooo0_l0000Hooooo`;o00001Oooool2o`0004gooooo0_l0000mooooo`;o0000<?ooool2o`00
01cooooo0_l00006ooooo`;o00004oooool001kooooo00?o0000ooooooooool06?ooool2o`0000Co
oooo0_l0000Uooooo`;o00001Oooool2o`0008Kooooo0_l0000mooooo`?o00004_ooool2o`0000Wo
oooo0_l0000Booooo`007_ooool2o`0001Wooooo0_l0000Oooooo`;o0000VOooool2o`0003gooooo
0ol000000ooooooo0000o`00000?ooooo`;o00002Oooool2o`0001;ooooo000Nooooo`03o`000?oo
oooooooo03Wooooo1?l0000Dooooo`;o0000a?ooool2o`0002kooooo000Nooooo`03o`000?oooooo
oooo03Sooooo0_l000000ooooooo0000o`000008ooooo`;o00002_ooool2o`0003kooooo0_l0002d
ooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o0000:?ooool2o`0000_ooooo0_l0001:oooo
o`;o0000]?ooool001kooooo00?o0000ooooooooool03_ooool2o`0001Kooooo0_l0001=ooooo`;o
00009?ooool2o`000:[ooooo000Nooooo`03o`000?oooooooooo02Kooooo0_l0000^ooooo`;o0000
7Oooool2o`0002Cooooo1?l00006ooooo`;o0000O_ooool2o`00023ooooo000Nooooo`03o`000?oo
oooooooo05Kooooo0_l00015ooooo`;o00001_ooool2o`0005Gooooo0_l0000Wooooo`;o00001?oo
ool2o`0001[ooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0001`ooooo`;o00000oooool2
o`0000kooooo0_l0000>ooooo`;o00009oooool2o`0000Wooooo0_l0000[ooooo`;o0000;Oooool2
o`0001[ooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0000Gooooo`;o0000Eoooool2o`00
00?ooooo0_l0000>ooooo`;o00003_ooool2o`0002Oooooo0_l00009ooooo`;o0000M_ooool001ko
oooo00?o0000ooooooooool07Oooool2o`0001Wooooo0_l00037ooooo`;o0000A?ooool001kooooo
00?o0000ooooooooool09Oooool2o`0000Wooooo0_l00006ooooo`;o0000<_ooool2o`0006Sooooo
0_l0000Yooooo`;o00007?ooool2o`0000Gooooo0_l0000Oooooo`007_ooool00ol0003ooooooooo
o`0Uooooo`;o00002Oooool2o`0003[ooooo0_l0000Qooooo`;o0000AOooool2o`0004Oooooo0_l0
0005ooooo`;o00007oooool001kooooo00?o0000ooooooooool0Aoooool2o`0004Kooooo0_l0000I
ooooo`;o0000?oooool2o`0003Wooooo0_l0000Oooooo`007_ooool00ol0003oooooooooo`17oooo
o`;o00003?ooool2o`0005?ooooo0_l0000Oooooo`;o00007_ooool2o`0005[ooooo000Nooooo`03
o`000?oooooooooo017ooooo0_l00012ooooo`;o0000;Oooool2o`0001;ooooo0_l0000aooooo`;o
0000N_ooool001kooooo00?o0000ooooooooool04Oooool2o`0006Wooooo0_l00006ooooo`;o0000
4_ooool2o`0000Gooooo0_l0000]ooooo`;o00007oooool2o`0005Kooooo000Nooooo`;o00004Ooo
ool2o`00057ooooo0_l0000Gooooo`;o00008Oooool2o`0002gooooo0_l00005ooooo`;o00006?oo
ool2o`0005Kooooo000Nooooo`03o`000?oooooooooo013ooooo0_l0000Hooooo`Co0000=Oooool2
o`00073ooooo0_l0001`ooooo`007_ooool00ol0003oooooooooo`0Zooooo`Co00002oooool2o`00
0;Cooooo0_l00008ooooo`;o00008_ooool2o`0000Cooooo0_l0000Rooooo`007_ooool00ol0003o
ooooooooo`0iooooo`;o0000Z?ooool2o`0000[ooooo0_l00008ooooo`;o00008_ooool2o`0000Co
oooo0_l0000Rooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o0000Joooool2o`0000Sooooo
0_l0001Booooo`;o0000B?ooool2o`0001Sooooo000Nooooo`03o`000?oooooooooo01Sooooo0_l0
001[ooooo`;o00002?ooool3o`0009_ooooo0_l0000=ooooo`;o00002Oooool001kooooo00?o0000
ooooooooool0T?ooool2o`000:[ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`1joooo
o`;o0000Q?ooool2o`0000_ooooo0_l0000hooooo`007_ooool00ol0003oooooooooo`0booooo`;o
0000:?ooool2o`0001cooooo0_l00024ooooo`;o00002oooool2o`0000Sooooo0_l00002ooooo`;o
0000:_ooool001kooooo00?o0000ooooooooool0<_ooool2o`0002Sooooo0_l0001?ooooo`;o0000
J?ooool2o`0000;ooooo0_l0000Zooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o00008ooo
ool2o`0002oooooo0_l0000dooooo`;o00001_ooool3o`0009Sooooo000Nooooo`03o`000?oooooo
oooo01Sooooo0_l0000Sooooo`;o0000;oooool2o`0003Cooooo0_l00006ooooo`;o0000VOooool0
01kooooo00?o0000ooooooooool0;oooool2o`00053ooooo0_l0002aooooo`;o00004Oooool001ko
oooo00?o0000ooooooooool0;oooool2o`00053ooooo0_l00006ooooo`;o0000ZOooool2o`00017o
oooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0
003o410@olc<c006ooooo`03o`000?oooooooooo05kooooo0_l0000Yooooo`;o0000UOooool2o`00
02Gooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMg
MoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo01gooooo0_l0000oooooo`;o0000>Oooool2
o`0000oooooo0_l00009ooooo`;o0000JOooool2o`000003ooooool0003o000002;ooooo0003oooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
000Mooooo`;o0000N_ooool2o`0000oooooo0_l00009ooooo`;o0000K?ooool2o`0002;ooooo0003
ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo
00?o0000ooooooooool0Voooool2o`0001_ooooo0_l0001Mooooo`;o0000;_ooool000?ooooo00Go
0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003o
ooooooooo`0;ooooo`;o0000S_ooool2o`0001_ooooo0_l0001Mooooo`;o0000;_ooool000?ooooo
00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000oooooooo
ool02oooool2o`0001[ooooo0_l0000`ooooo`;o00008?ooool2o`0000oooooo0_l0000[ooooo`;o
0000Goooool2o`0002_ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo
410@oiRHV008ooooo`03o`000?oooooooooo02Oooooo0_l0000;ooooo`;o00000_ooool2o`0000Wo
oooo0_l0000Dooooo`;o00008?ooool2o`0000oooooo0_l0000[ooooo`;o0000Goooool2o`0001Ko
oooo0_l0000Cooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0
003o410@1_ooool00ol0003oooooooooo`0?ooooo`;o00006_ooool2o`0000Oooooo0_l00002oooo
o`;o00002Oooool2o`0002_ooooo0_l00014ooooo`;o0000N_ooool2o`0001?ooooo000Nooooo`03
o`000?oooooooooo00oooooo0_l0000Jooooo`;o00001?ooool2o`0000[ooooo0_l0000?ooooo`;o
00008?ooool2o`0004Cooooo0_l00011ooooo`;o00005?ooool2o`0000Wooooo0_l0000[ooooo`00
7_ooool00ol0003oooooooooo`0aooooo`;o00002_ooool2o`0000oooooo0_l00006ooooo`;o0000
7Oooool2o`0000Oooooo0_l0000Iooooo`;o00007?ooool2o`0003[ooooo0_l00004ooooo`;o0000
5?ooool2o`0000Wooooo0_l0000[ooooo`007_ooool00ol0003oooooooooo`1Fooooo`;o00006_oo
ool2o`000003ooooool0003o000000Oooooo0_l0000Fooooo`;o000000?oooooo`000?l000007?oo
ool2o`0003[ooooo0_l0001Booooo`007_ooool00ol0003oooooooooo`1booooo`;o00002?ooool2
o`0000Sooooo0_l0000>ooooo`;o0000Hoooool2o`0004[ooooo000Nooooo`03o`000?oooooooooo
063ooooo0_l0000Jooooo`;o00002?ooool2o`0000kooooo0_l0000Oooooo`;o00001Oooool2o`00
03_ooooo0_l0000Dooooo`;o00004_ooool2o`00023ooooo000Nooooo`03o`000?oooooooooo04[o
oooo0_l0000Dooooo`;o0000=?ooool2o`0001oooooo0_l00005ooooo`;o0000Aoooool2o`0000So
oooo0_l0000;ooooo`;o00001Oooool2o`00023ooooo000Nooooo`03o`000?oooooooooo04[ooooo
0_l0001Booooo`;o0000Aoooool2o`0001kooooo0_l0000Eooooo`;o00003oooool2o`0001Kooooo
000Nooooo`03o`000?oooooooooo09kooooo0_l0000Xooooo`;o00007Oooool2o`0003cooooo0_l0
0008ooooo`;o00005_ooool001kooooo00?o0000ooooooooool0A_ooool2o`0005[ooooo0_l0000T
ooooo`;o00001oooool2o`0005;ooooo0_l0000@ooooo`;o00003_ooool001kooooo00?o0000oooo
ooooool0A_ooool2o`0005[ooooo0_l0000]ooooo`;o0000<_ooool2o`00033ooooo0_l0000>oooo
o`007_ooool00ol0003oooooooooo`35ooooo`;o0000?_ooool2o`0002Sooooo0_l0000Fooooo`00
7_ooool2o`0004oooooo0_l0000Pooooo`;o00009_ooool2o`0002_ooooo0_l0000eooooo`;o0000
4_ooool2o`0001gooooo0_l0000Fooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o00003Ooo
ool2o`0002?ooooo0_l00008ooooo`;o00008?ooool2o`0000Wooooo0_l0000Kooooo`;o0000H_oo
ool2o`0001;ooooo0_l0000eooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o00003Oooool2
o`0000Kooooo0_l00008ooooo`;o00004Oooool2o`0003Gooooo0_l0001Wooooo`;o0000HOooool0
01kooooo0_l0000Booooo`;o00005?ooool2o`0000Sooooo0_l0002Dooooo`;o00006oooool2o`00
067ooooo000Nooooo`;o00004_ooool2o`00027ooooo0_l0000<ooooo`;o0000?oooool2o`0001ko
oooo0_l00002ooooo`;o00004?ooool2o`0000cooooo0_l00004ooooo`;o00002_ooool2o`0006co
oooo000Nooooo`03o`000?oooooooooo03Cooooo0_l00005ooooo`;o00001Oooool2o`0003oooooo
0_l0000Cooooo`;o00002Oooool2o`0000;ooooo0_l0000@ooooo`;o00004_ooool2o`0000[ooooo
0ol0001[ooooo`007_ooool00ol0003oooooooooo`0kooooo`;o0000Foooool2o`00043ooooo0_l0
001Dooooo`;o00005Oooool001kooooo00?o0000ooooooooool0T_ooool2o`0003[ooooo0_l0000K
ooooo`;o0000@oooool2o`0001Gooooo000Nooooo`03o`000?oooooooooo01cooooo0_l000000ooo
oooo0000o`00000;ooooo`;o00000_ooool2o`00063ooooo0_l0000jooooo`;o00006oooool2o`00
00;ooooo0_l0001Fooooo`007_ooool00ol0003oooooooooo`0Looooo`;o000000?oooooo`000?l0
00001?ooool2o`0000Gooooo0_l00002ooooo`;o0000_Oooool2o`0001Wooooo0_l0000kooooo`00
7_ooool00ol0003oooooooooo`0Uooooo`;o0000EOooool2o`00013ooooo0_l0000Pooooo`;o0000
6oooool2o`0003_ooooo0_l0000kooooo`007_ooool00ol0003oooooooooo`0Xooooo`;o00006ooo
ool2o`0003Gooooo0_l0000@ooooo`;o00008?ooool2o`00013ooooo0_l00009ooooo`;o00000_oo
ool2o`0007Cooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l0000@ooooo`;o00006oooool2
o`0000Cooooo0_l0000Gooooo`;o0000G?ooool2o`0000gooooo0_l0001dooooo`007_ooool01?l0
003oooooooooooooool2o`0001?ooooo0_l0000Sooooo`;o00003_ooool2o`0001Oooooo0_l0002C
ooooo`;o0000C?ooool001kooooo00Co0000oooooooooooooooo0_l0000hooooo`;o0000:Oooool2
o`0002kooooo0_l0001Qooooo`;o00008?ooool2o`0002[ooooo000Nooooo`03o`000?oooooooooo
06Kooooo0_l00006ooooo`;o00009_ooool2o`0008?ooooo0_l0000Zooooo`007_ooool2o`0006oo
oooo0_l0000Rooooo`;o0000E?ooool2o`0000Kooooo0_l00005ooooo`;o0000C_ooool001kooooo
00?o0000ooooooooool0<?ooool2o`00063ooooo0_l0001Dooooo`;o00001_ooool2o`0000Gooooo
0_l0001>ooooo`007_ooool00ol0003oooooooooo`0`ooooo`;o00002Oooool2o`0008Gooooo0_l0
001Vooooo`;o00004oooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo017ooooo0_l0000X
ooooo`;o0000>?ooool2o`0004Oooooo0_l00002ooooo`;o0000I_ooool2o`0001?ooooo0_l00006
ooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o00009?ooool2o`0003Cooooo0_l00006oooo
o`;o0000Aoooool2o`00057ooooo0_l0000;ooooo`;o00009oooool001kooooo00?o0000oooooooo
ool06?ooool2o`0000Oooooo0_l0000Dooooo`;o0000=?ooool2o`0005Cooooo0_l00014ooooo`;o
00001_ooool2o`0000_ooooo0_l0000Wooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o0000
1oooool2o`000:3ooooo0_l00014ooooo`;o0000??ooool001kooooo00?o0000ooooooooool0?ooo
ool2o`0000[ooooo0_l0002Dooooo`;o0000I?ooool001kooooo00?o0000ooooooooool0?oooool2
o`0000[ooooo0_l00015ooooo`;o0000COooool2o`0003Gooooo0_l0000]ooooo`007_ooool00ol0
003oooooooooo`2Booooo`;o0000;?ooool2o`0005Kooooo0_l0000]ooooo`007_ooool00ol0003o
ooooooooo`30ooooo`;o0000QOooool001kooooo00?o0000ooooooooool0;Oooool2o`00053ooooo
0_l0002[ooooo`;o00006Oooool001kooooo00?o0000ooooooooool0;Oooool2o`0003Gooooo0_l0
000Iooooo`;o0000Zoooool2o`0001Wooooo000Nooooo`03o`000?oooooooooo06Cooooo0_l0003Q
ooooo`007_ooool00ol0003oooooooooo`0=ooooo`Co00002_ooool2o`0000?ooooo0_l0001Hoooo
o`;o00002oooool2o`00023ooooo0_l0000Aooooo`;o0000L_ooool2o`0000Gooooo0_l0000>oooo
o`007_ooool00ol0003oooooooooo`0=ooooo`Co00002_ooool2o`0000?ooooo0_l0000`ooooo`;o
00003Oooool2o`0001Oooooo0_l0000;ooooo`;o00008?ooool2o`00017ooooo0_l0001booooo`;o
00001Oooool2o`0000kooooo000Nooooo`;o0000=Oooool2o`0001cooooo0_l0000=ooooo`;o0000
COooool2o`0001;ooooo0_l0000Fooooo`;o00005oooool2o`00053ooooo000Nooooo`03o`000?oo
oooooooo03Cooooo0_l0000Iooooo`;o00001oooool2o`0005Kooooo0_l0000Booooo`;o00005_oo
ool2o`0001Oooooo0_l000000ooooooo0000o`00000Sooooo`;o00003Oooool2o`0001Wooooo000N
ooooo`03o`000?oooooooooo00kooooo0_l0000oooooo`;o00001oooool2o`0001Oooooo0_l0000c
ooooo`;o0000D?ooool2o`0001Sooooo0_l00009ooooo`;o00003Oooool2o`0001Wooooo000Noooo
o`03o`000?oooooooooo00kooooo0_l0001Mooooo`;o00000_ooool2o`0003?ooooo0_l0000:oooo
o`;o0000;oooool2o`0002gooooo0_l0000cooooo`007_ooool00ol0003oooooooooo`1]ooooo`;o
0000>oooool2o`0000Kooooo0_l0000_ooooo`;o0000?Oooool2o`0002?ooooo000Nooooo`03o`00
0?oooooooooo07cooooo0_l0000Tooooo`;o00001_ooool2o`0007Kooooo0ol0000Rooooo`007_oo
ool00ol0003oooooooooo`1Jooooo`;o00008?ooool2o`0002Cooooo0_l0000nooooo`;o0000?ooo
ool2o`0002;ooooo000Nooooo`03o`000?oooooooooo05[ooooo0_l00018ooooo`;o0000??ooool2
o`0006?ooooo000Nooooo`03o`000?oooooooooo01cooooo0_l0000?ooooo`;o0000MOooool2o`00
04?ooooo0_l0001Looooo`007_ooool00ol0003oooooooooo`0Looooo`;o00003oooool2o`0000Oo
oooo0_l0002aooooo`;o0000=oooool2o`0002?ooooo000Nooooo`03o`000?oooooooooo03Kooooo
0_l0000;ooooo`;o00009oooool2o`000;Cooooo0_l0000Sooooo`007_ooool00ol0003ooooooooo
o`13ooooo`;o00005_ooool2o`0000oooooo0_l0003Iooooo`007_ooool00ol0003oooooooooo`0^
ooooo`;o0000:oooool2o`0004_ooooo0_l0002Mooooo`007_ooool01?l0003oooooo`000?l0000]
ooooo`;o0000N?ooool2o`0000Wooooo0_l0002Booooo`000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool01?l0003oooooo`00
0?l0000?ooooo`;o00002Oooool2o`0009Kooooo0_l0000:ooooo`;o0000DOooool2o`0003?ooooo
0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?oooooo
V9RHob4Q8@06ooooo`04o`000?ooooooooooooooo`;o00003Oooool2o`0000Wooooo0_l0001^oooo
o`;o0000<_ooool2o`00057ooooo0_l0000cooooo`000oooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o000000?oooooo`000?l000003oooool2
o`0002Sooooo0_l0001=ooooo`;o00003?ooool2o`000:cooooo0003ooooo`05o`000?oooooooooo
ooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00Co0000oooooooooooooooo
0_l0000:ooooo`;o00000oooool2o`0002Sooooo0_l0000Nooooo`;o0000>_ooool3o`000:cooooo
0003ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Ko
oooo00?o0000ooooooooool03Oooool2o`0004_ooooo1Ol0000iooooo`;o0000[Oooool000?ooooo
00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0
003oooooooooo`1Jooooo`;o000000?oooooo`000?l00000FOooool2o`0002cooooo0_l00002oooo
o`;o00006_ooool3o`0003kooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool07_ooool2o`0001kooooo0_l0000g
ooooo`;o0000?oooool2o`0002cooooo0_l00002ooooo`;o00006_ooool3o`0003kooooo0003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o
0000ooooooooool07_ooool2o`0001kooooo0_l0000gooooo`;o00006oooool2o`0005?ooooo0_l0
001Looooo`007_ooool00ol0003oooooooooo`0`ooooo`;o00009oooool2o`0000Cooooo0_l0000c
ooooo`;o0000Doooool2o`0005cooooo000Nooooo`03o`000?oooooooooo017ooooo0_l0000?oooo
o`;o00003?ooool2o`0002Oooooo0_l00004ooooo`;o00005oooool2o`000;3ooooo0_l00002oooo
o`;o00005oooool001kooooo00?o0000ooooooooool04Oooool2o`0000oooooo0_l0001Dooooo`;o
00001?ooool2o`0002gooooo0_l0000Rooooo`;o0000Eoooool2o`0000;ooooo0_l0000Gooooo`00
7_ooool00ol0003oooooooooo`1nooooo`;o0000;Oooool2o`0002;ooooo0_l0001dooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo07cooooo0_l0000/
ooooo`Co0000VOooool001kooooo00?o0000ooooooooool0DOooool2o`0002Wooooo0_l0000/oooo
o`Co0000;_ooool2o`0004?ooooo0_l0000Tooooo`007_ooool00ol0003oooooooooo`0Nooooo`;o
00006oooool2o`0001Cooooo0_l0001gooooo`;o00004?ooool2o`0002_ooooo0_l0000Fooooo`;o
00007Oooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo01kooooo1?l0000Iooooo`;o0000
9oooool2o`0006Cooooo0_l0000mooooo`;o0000=?ooool3o`0000Gooooo000Nooooo`03o`000?oo
oooooooo00;ooooo0_l0000Looooo`;o0000@_ooool2o`0003kooooo0_l0000cooooo`;o00009ooo
ool2o`0003Wooooo1?l00006ooooo`007_ooool00ol0003oooooooooo`02ooooo`;o00008Oooool2
o`0007gooooo0_l0000cooooo`;o00009oooool2o`0003Wooooo0_l00008ooooo`007_ooool2o`00
01gooooo0_l00004ooooo`;o000000?oooooo`000?l00000/_ooool2o`0004Gooooo0_l00003oooo
o`;o00008?ooool001kooooo00?o0000ooooooooool06?ooool2o`0000;ooooo0_l00004ooooo`;o
0000>?ooool2o`0007_ooooo0_l0000booooo`;o00004Oooool2o`0000?ooooo0_l0000Pooooo`00
7_ooool00ol0003oooooooooo`0Eooooo`;o000000?oooooo`000?l000005?ooool2o`0000Sooooo
0_l0000Rooooo`;o0000FOooool2o`0005Cooooo0_l0000Yooooo`;o00003Oooool001kooooo00?o
0000ooooooooool03oooool4o`0000;ooooo0_l0000Gooooo`;o00002?ooool2o`00053ooooo0_l0
000[ooooo`;o00004oooool2o`0000Wooooo0_l0000Hooooo`;o0000AOooool2o`0000Gooooo0_l0
0006ooooo`007_ooool00ol0003oooooooooo`0?ooooo`Co0000Moooool2o`0003?ooooo0_l0000;
ooooo`;o00002Oooool2o`0001Sooooo0_l0001<ooooo`;o00001_ooool001kooooo00?o0000oooo
ooooool0Coooool2o`0006kooooo0_l00026ooooo`007_ooool00ol0003oooooooooo`1?ooooo`;o
0000A?ooool2o`0002;ooooo0_l00019ooooo`;o0000@Oooool001kooooo00?o0000ooooooooool0
8_ooool2o`0005gooooo0_l0000Booooo`;o00004oooool2o`000003ooooool0003o000000[ooooo
0_l00019ooooo`;o0000@Oooool001kooooo00?o0000ooooooooool08_ooool2o`00013ooooo0_l0
001;ooooo`;o00009oooool2o`000003ooooool0003o000003Gooooo0_l0000_ooooo`;o00003_oo
ool2o`00023ooooo000Nooooo`03o`000?oooooooooo03Cooooo0_l0000Oooooo`;o00005_ooool2
o`0000Gooooo0_l0000?ooooo`;o0000GOooool2o`0001Kooooo0_l0000Gooooo`;o00003_ooool2
o`0000?ooooo0_l0000Kooooo`007_ooool00ol0003oooooooooo`1@ooooo`;o00000oooool2o`00
01Kooooo0_l00005ooooo`;o00003oooool2o`0003oooooo0_l0000dooooo`;o00004Oooool2o`00
01Wooooo0_l0000Kooooo`007_ooool00ol0003oooooooooo`0oooooo`;o00000_ooool2o`0000_o
oooo0ol00009ooooo`;o0000J?ooool2o`0004Oooooo0_l00007ooooo`;o00002?ooool2o`0002?o
oooo000Nooooo`;o000000?oooooo`000?l00000?Oooool2o`000004ooooool0003o0000o`0000co
oooo0_l00008ooooo`?o0000^_ooool2o`0000Sooooo0_l0000Sooooo`007_ooool2o`000003oooo
ool0003o0000043ooooo0_l0000Gooooo`;o00002Oooool2o`0000Cooooo0_l0003Iooooo`007_oo
ool00ol0003oooooooooo`1:ooooo`;o00006_ooool2o`0000Cooooo0_l0000Nooooo`;o0000^Ooo
ool001kooooo00?o0000ooooooooool0B_ooool2o`00043ooooo0_l0000Mooooo`;o0000V_ooool0
01kooooo0_l0001Nooooo`;o00004?ooool2o`0003[ooooo0_l0001kooooo`;o00002?ooool2o`00
01?ooooo000Nooooo`03o`000?oooooooooo04kooooo0_l0000=ooooo`;o00004?ooool2o`000;Ko
oooo0ol00008ooooo`;o00004oooool001kooooo00?o0000ooooooooool03_ooool2o`0003kooooo
0_l0003Booooo`;o00000oooool2o`0001kooooo000Nooooo`03o`000?oooooooooo00kooooo0_l0
000Wooooo`;o0000W?ooool2o`0003Wooooo0_l0000@ooooo`;o00008oooool001kooooo00?o0000
ooooooooool0=oooool2o`0002?ooooo0_l0001gooooo`;o00004_ooool2o`0002Gooooo0_l0000e
ooooo`007_ooool00ol0003oooooooooo`1Looooo`;o0000JOooool2o`00023ooooo0_l0001Loooo
o`007_ooool00ol0003oooooooooo`03ooooo`;o0000??ooool2o`0001;ooooo0_l0001`ooooo`;o
0000O_ooool001kooooo00?o0000ooooooooool00oooool2o`0000?ooooo0_l0000gooooo`;o0000
4_ooool2o`0004gooooo0_l0001Yooooo`;o0000=_ooool001kooooo00?o0000ooooooooool02?oo
ool2o`0007Sooooo0_l0000Eooooo`;o00001Oooool2o`0000;ooooo0_l0001Yooooo`;o00007ooo
ool2o`0001Gooooo000Nooooo`03o`000?oooooooooo01cooooo0_l0000:ooooo`;o00005Oooool2
o`00047ooooo0_l0000Eooooo`;o00001Oooool2o`0001oooooo0_l0000Hooooo`;o0000>?ooool2
o`0001Wooooo0_l0000Eooooo`007_ooool00ol0003oooooooooo`0Looooo`;o00001_ooool2o`00
00;ooooo0_l0000;ooooo`;o00002?ooool2o`0007gooooo0_l000000ooooooo0000o`00000Hoooo
o`;o0000>?ooool2o`00033ooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0000Kooooo`;o
00001_ooool2o`0000Oooooo0_l0001gooooo`;o00003_ooool2o`0002?ooooo0_l0000aooooo`;o
0000;oooool001kooooo00?o0000ooooooooool01oooool2o`000003ooooool0003o000001;ooooo
0_l0000<ooooo`;o0000A?ooool2o`0000_ooooo0_l00003ooooo`;o00008oooool2o`0000?ooooo
0_l0000cooooo`;o0000<Oooool2o`0002oooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0
000Booooo`;o0000=?ooool2o`0001cooooo0_l0000;ooooo`;o00000oooool2o`0002?ooooo0_l0
002Looooo`007_ooool00ol0003oooooooooo`1Dooooo`;o0000??ooool2o`000;?ooooo000Noooo
o`03o`000?oooooooooo01Wooooo0_l0000Dooooo`;o00003oooool2o`00053ooooo0_l0002coooo
o`007_ooool2o`0001[ooooo0_l0000Dooooo`;o00003oooool2o`0007oooooo0_l0000Hooooo`;o
0000?_ooool2o`0002[ooooo000Nooooo`03o`000?oooooooooo077ooooo0_l0000[ooooo`;o0000
8Oooool2o`0001Sooooo0_l0000nooooo`;o0000:_ooool001kooooo00?o0000ooooooooool0LOoo
ool2o`0002_ooooo0_l0000fooooo`;o0000JOooool2o`0000Cooooo000Nooooo`03o`000?oooooo
oooo03[ooooo0_l0000looooo`;o0000G?ooool2o`0003?ooooo0_l0000dooooo`;o00001?ooool0
01kooooo0ol0000jooooo`;o0000??ooool2o`0001gooooo0_l0001booooo`;o0000>_ooool001ko
oooo0ol0002Gooooo`;o0000=?ooool2o`0003Kooooo0_l00010ooooo`007_ooool00ol0003ooooo
ooooo`3=ooooo`;o0000=_ooool2o`00043ooooo000Nooooo`03o`000?oooooooooo03Wooooo0_l0
000Yooooo`;o00001_ooool2o`000=Wooooo000Nooooo`03o`000?oooooooooo03Wooooo0_l0000V
ooooo`;o000000?oooooo`000?l000001_ooool2o`0002_ooooo0_l0000Jooooo`;o0000T?ooool0
01kooooo00?o0000ooooooooool0HOooool2o`0000cooooo0_l0000<ooooo`;o00006_ooool2o`00
00Oooooo0_l0000Aooooo`;o0000=?ooool2o`0004Cooooo0_l00005ooooo`;o00003Oooool001ko
oooo00?o0000ooooooooool0Koooool2o`0000cooooo0_l0000Sooooo`;o0000?_ooool2o`0000Oo
oooo0_l00006ooooo`;o0000??ooool2o`0000Gooooo0_l0000=ooooo`007_ooool00ol0003ooooo
ooooo`2gooooo`;o0000:Oooool2o`0000cooooo0_l000000ooooooo0000o`00000Mooooo`;o0000
<oooool001kooooo00?o0000ooooooooool0:?ooool2o`0005Cooooo0_l0000gooooo`;o0000=ooo
ool2o`00023ooooo0_l000000ooooooo0000o`00000>ooooo`;o00008?ooool001kooooo00?o0000
ooooooooool0:?ooool2o`0005Cooooo1?l0000aooooo`;o0000H?ooool2o`0000[ooooo0_l00002
ooooo`;o00008?ooool001Cooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
083ooooo0_l00002ooooo`;o0000;Oooool2o`0006cooooo0_l0000Tooooo`005_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo05[ooooo0_l0000Xooooo`;o0000E?ooool2o`0006_o
oooo000Fooooo`03o`000?oooooooooo00Gooooo1Ol0000/ooooo`;o0000:_ooool2o`0002cooooo
0_l0001@ooooo`;o0000Joooool001Kooooo00?o0000ooooooooool02?ooool2o`0002cooooo0_l0
001Hooooo`;o0000_Oooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0
003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Cooooo
00?oEEEEofIVI_l00000oooooomBooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.10324 .67783 Mdot
.82777 .43339 Mdot
.09027 .49968 Mdot
.05018 .03311 Mdot
.38373 .41883 Mdot
.24647 .04698 Mdot
.62637 .01568 Mdot
.26136 .46048 Mdot
.31104 .97341 Mdot
.77208 .00412 Mdot
.32917 .21368 Mdot
.46731 .0969 Mdot
.23136 .53766 Mdot
.64037 .66282 Mdot
.14997 .038 Mdot
.59174 .62946 Mdot
.76186 .62118 Mdot
.3497 .57965 Mdot
.13655 .6087 Mdot
.09117 .11994 Mdot
.82307 .63338 Mdot
.31662 .11791 Mdot
.4868 .42131 Mdot
.84663 .02343 Mdot
.2586 .88172 Mdot
.20313 .36303 Mdot
.11498 .84125 Mdot
.60137 .72993 Mdot
.35018 .21814 Mdot
.25467 .14898 Mdot
.21857 .60962 Mdot
.16664 .02775 Mdot
.39429 .97784 Mdot
.85191 .91117 Mdot
.90852 .55574 Mdot
.00745 .88808 Mdot
.64409 .67455 Mdot
.80442 .52712 Mdot
.53189 .83274 Mdot
.19636 .79798 Mdot
.1857 .61173 Mdot
.94628 .64752 Mdot
.96954 .00139 Mdot
.78035 .61739 Mdot
.5656 .02715 Mdot
.93362 .70813 Mdot
.65995 .46846 Mdot
.93164 .82121 Mdot
.01923 .79604 Mdot
.12754 .29256 Mdot
.47444 .9634 Mdot
.93061 .49413 Mdot
.29231 .35097 Mdot
.99086 .84588 Mdot
.32602 .34873 Mdot
.20855 .22701 Mdot
.76023 .32002 Mdot
.27528 .51753 Mdot
.10254 .85111 Mdot
.34822 .69687 Mdot
.088 .05604 Mdot
.22645 .40945 Mdot
.6058 .09483 Mdot
.29486 .913 Mdot
.31014 .74625 Mdot
.31132 .06664 Mdot
.98774 .3985 Mdot
.10673 .84038 Mdot
.22618 .07495 Mdot
.82528 .32206 Mdot
.1276 .22476 Mdot
.4712 .62411 Mdot
.0427 .16691 Mdot
.25015 .21904 Mdot
.43084 .07243 Mdot
.95421 .30553 Mdot
.12409 .32816 Mdot
.64179 .23724 Mdot
.13885 .92747 Mdot
.53501 .39822 Mdot
.91614 .8526 Mdot
.71072 .07653 Mdot
.78773 .62591 Mdot
.23792 .45072 Mdot
.74635 .45795 Mdot
.99067 .22892 Mdot
.30886 .38907 Mdot
.03995 .92256 Mdot
.192 .05838 Mdot
.39165 .68284 Mdot
.05659 .13083 Mdot
.855 .28571 Mdot
.14456 .28083 Mdot
.14431 .21212 Mdot
.35497 .65141 Mdot
.90874 .76321 Mdot
.61131 .19076 Mdot
.91754 .53346 Mdot
.29824 .80675 Mdot
.88193 .60835 Mdot
.11443 .74542 Mdot
.48166 .92676 Mdot
.06122 .61409 Mdot
.62615 .63933 Mdot
.91373 .33364 Mdot
.48316 .42832 Mdot
.55261 .68066 Mdot
.57868 .66348 Mdot
.94628 .48988 Mdot
.66595 .13054 Mdot
.64037 .68353 Mdot
.79011 .51864 Mdot
.52957 .93985 Mdot
.29994 .5936 Mdot
.47395 .3252 Mdot
.66918 .95839 Mdot
.56057 .99276 Mdot
.18597 .52861 Mdot
.01009 .30855 Mdot
.59777 .86605 Mdot
.06678 .82017 Mdot
.93824 .73475 Mdot
.41657 .13478 Mdot
.14829 .2143 Mdot
.88565 .19764 Mdot
.84734 .61804 Mdot
.40477 .87438 Mdot
.17462 .66342 Mdot
.84919 .88259 Mdot
.99154 .13476 Mdot
.84145 .57106 Mdot
.38624 .2696 Mdot
.7771 .75165 Mdot
.45035 .53609 Mdot
.35558 .61513 Mdot
.30588 .32256 Mdot
.4673 .41971 Mdot
.45951 .69965 Mdot
.06757 .54607 Mdot
.29001 .03644 Mdot
.21603 .66265 Mdot
.29801 .90264 Mdot
.37602 .09013 Mdot
.91458 .63063 Mdot
.59982 .33772 Mdot
.45514 .09602 Mdot
.24257 .72268 Mdot
.15257 .77471 Mdot
.77237 .30333 Mdot
.68606 .075 Mdot
.70839 .75909 Mdot
.39593 .03625 Mdot
.49036 .09581 Mdot
.10108 .13259 Mdot
.11902 .00292 Mdot
.18861 .50156 Mdot
.511 .66384 Mdot
.72928 .40294 Mdot
.2704 .94203 Mdot
.57289 .63024 Mdot
.49417 .6362 Mdot
.8913 .55607 Mdot
.78972 .87969 Mdot
.48577 .52195 Mdot
.29178 .78409 Mdot
.38857 .38918 Mdot
.17875 .77826 Mdot
.20593 .88599 Mdot
.66181 .11363 Mdot
.47201 .48273 Mdot
.39057 .16836 Mdot
.90336 .85196 Mdot
.89579 .53295 Mdot
.01219 .29378 Mdot
.11148 .65508 Mdot
.51514 .77263 Mdot
.81459 .87232 Mdot
.13146 .38771 Mdot
.63257 .09318 Mdot
.92347 .50031 Mdot
.97447 .97917 Mdot
.44185 .01912 Mdot
.5746 .80859 Mdot
.54467 .16573 Mdot
.6847 .27422 Mdot
.53399 .87282 Mdot
.57263 .62191 Mdot
.02192 .09795 Mdot
.76598 .7495 Mdot
.8952 .71184 Mdot
.13548 .65749 Mdot
.97162 .21273 Mdot
.163 .6774 Mdot
.52245 .19426 Mdot
.57944 .86983 Mdot
.98162 .02825 Mdot
.90077 .59128 Mdot
.43798 .1551 Mdot
.32005 .97124 Mdot
.41851 .05803 Mdot
.55382 .21981 Mdot
.52648 .3451 Mdot
.42137 .56376 Mdot
.55718 .13106 Mdot
.26184 .88633 Mdot
.03798 .93549 Mdot
.67757 .02018 Mdot
.05979 .9066 Mdot
.78203 .42269 Mdot
.61198 .7504 Mdot
.45579 .45442 Mdot
.19382 .692 Mdot
.90402 .23113 Mdot
.66461 .34605 Mdot
.47693 .66612 Mdot
.10746 .21612 Mdot
.21683 .7816 Mdot
.07412 .27995 Mdot
.53405 .76356 Mdot
.01906 .37253 Mdot
.75675 .33839 Mdot
.3983 .62077 Mdot
.29456 .88747 Mdot
.2073 .92797 Mdot
.39034 .65395 Mdot
.53648 .58097 Mdot
.91561 .98713 Mdot
.43288 .36568 Mdot
.69523 .20442 Mdot
.36346 .08368 Mdot
.16087 .44299 Mdot
.3465 .71152 Mdot
.39833 .09963 Mdot
.95178 .09057 Mdot
.10594 .21389 Mdot
.74257 .16243 Mdot
.71137 .55793 Mdot
.20222 .57948 Mdot
.80251 .56992 Mdot
.76552 .21628 Mdot
.10955 .36718 Mdot
.39863 .12955 Mdot
.9518 .925 Mdot
.05648 .41998 Mdot
.54338 .8239 Mdot
.10611 .32959 Mdot
.44012 .60894 Mdot
.35835 .16528 Mdot
.7295 .05356 Mdot
.16055 .58602 Mdot
.93364 .48041 Mdot
.3892 .37168 Mdot
.82679 .11569 Mdot
.9933 .23825 Mdot
.87952 .18864 Mdot
.94459 .82071 Mdot
.33042 .36606 Mdot
.83937 .49028 Mdot
.8935 .75441 Mdot
.47511 .32387 Mdot
.16026 .7033 Mdot
.31757 .73752 Mdot
.22736 .2241 Mdot
.92906 .36706 Mdot
.39685 .10892 Mdot
.93882 .12777 Mdot
.51574 .92296 Mdot
.00058 .30694 Mdot
.18829 .55674 Mdot
.16172 .81645 Mdot
.29452 .80411 Mdot
.68205 .49183 Mdot
.14073 .09787 Mdot
.35896 .75591 Mdot
.91691 .87583 Mdot
.43025 .39067 Mdot
.50973 .76388 Mdot
.49404 .26106 Mdot
.9987 .84371 Mdot
.49534 .95486 Mdot
.80622 .28482 Mdot
.3388 .1355 Mdot
.50497 .48419 Mdot
.6535 .64395 Mdot
.36841 .38507 Mdot
.29256 .88831 Mdot
.45507 .50924 Mdot
.86274 .49858 Mdot
.95049 .74378 Mdot
.36281 .23558 Mdot
.95664 .90045 Mdot
.86433 .28207 Mdot
.1487 .61442 Mdot
.52321 .14555 Mdot
.63441 .13153 Mdot
.87101 .50238 Mdot
.26231 .74864 Mdot
.56943 .61473 Mdot
.80455 .24048 Mdot
.71209 .11693 Mdot
.86107 .4968 Mdot
.34641 .88004 Mdot
.90884 .59492 Mdot
.48075 .59474 Mdot
.76076 .98431 Mdot
.96125 .45034 Mdot
.12885 .84913 Mdot
.09341 .94626 Mdot
.8626 .10325 Mdot
.51242 .33326 Mdot
.06099 .86099 Mdot
.80112 .21838 Mdot
.19937 .36827 Mdot
.44894 .33915 Mdot
.28852 .7689 Mdot
.9718 .74371 Mdot
.52589 .78555 Mdot
.01078 .29232 Mdot
.39911 .93837 Mdot
.91821 .34552 Mdot
.53774 .83489 Mdot
.39908 .01371 Mdot
.48048 .97461 Mdot
.59728 .79448 Mdot
.28512 .6079 Mdot
.1532 .45782 Mdot
.00078 .84168 Mdot
.18275 .71283 Mdot
.46293 .05517 Mdot
.17753 .42306 Mdot
.06553 .11758 Mdot
.25799 .07323 Mdot
.51945 .28293 Mdot
.85513 .06381 Mdot
.04053 .30983 Mdot
.25338 .26845 Mdot
.75029 .70047 Mdot
.10756 .81056 Mdot
.75523 .86143 Mdot
.92413 .09826 Mdot
.28642 .80682 Mdot
.74723 .67651 Mdot
.22469 .68649 Mdot
.48646 .6014 Mdot
.70469 .40144 Mdot
.63321 .54043 Mdot
.66477 .09441 Mdot
.38152 .27239 Mdot
.91631 .39336 Mdot
.2768 .46263 Mdot
.16402 .53199 Mdot
.35451 .36564 Mdot
.8751 .72538 Mdot
.60576 .68664 Mdot
.64462 .04083 Mdot
.1211 .08315 Mdot
.94572 .63457 Mdot
.47778 .54438 Mdot
.27416 .54108 Mdot
.10156 .27135 Mdot
.35934 .14775 Mdot
.82257 .80932 Mdot
.19977 .61618 Mdot
.45893 .44639 Mdot
.32436 .89233 Mdot
.85643 .75759 Mdot
.67818 .85364 Mdot
.73402 .67295 Mdot
.73825 .21683 Mdot
.25391 .12811 Mdot
.45877 .67362 Mdot
.15558 .85763 Mdot
.10819 .52684 Mdot
.33312 .04835 Mdot
.90677 .9086 Mdot
.87287 .60227 Mdot
.57282 .01837 Mdot
.02189 .84648 Mdot
.89486 .16456 Mdot
.28346 .17122 Mdot
.15877 .94594 Mdot
.03317 .04221 Mdot
.69554 .27001 Mdot
.87619 .18498 Mdot
.58936 .74522 Mdot
.54044 .13523 Mdot
.68836 .83845 Mdot
.67063 .53104 Mdot
.1186 .82024 Mdot
.65193 .6854 Mdot
.22067 .65539 Mdot
.36989 .51347 Mdot
.06995 .71036 Mdot
.33959 .47075 Mdot
.36709 .43883 Mdot
.46397 .28498 Mdot
.77783 .69054 Mdot
.92486 .14975 Mdot
.09014 .85337 Mdot
.25081 .61685 Mdot
.97414 .03292 Mdot
.59385 .93424 Mdot
.75011 .37502 Mdot
.22501 .42209 Mdot
.68251 .66744 Mdot
.88497 .94951 Mdot
.31467 .22909 Mdot
.41272 .6622 Mdot
.53266 .53886 Mdot
.48663 .51506 Mdot
.44829 .68232 Mdot
.23972 .89592 Mdot
.47691 .64923 Mdot
.64075 .9662 Mdot
.73138 .27264 Mdot
.41643 .54467 Mdot
.05063 .60681 Mdot
.5324 .59516 Mdot
.73184 .37444 Mdot
.1253 .93044 Mdot
.19409 .83777 Mdot
.62902 .41655 Mdot
.74152 .15489 Mdot
.38863 .52211 Mdot
.26003 .50282 Mdot
.74899 .55679 Mdot
.52869 .22801 Mdot
.3281 .01316 Mdot
.48102 .62132 Mdot
.79222 .41651 Mdot
.7539 .2457 Mdot
.66813 .48534 Mdot
.55687 .40821 Mdot
.04127 .06792 Mdot
.81748 .25399 Mdot
.64436 .54707 Mdot
.55271 .75012 Mdot
.90283 .98897 Mdot
.02927 .52229 Mdot
.56792 .97728 Mdot
.5367 .90036 Mdot
.78165 .55585 Mdot
.78824 .65159 Mdot
.11278 .06968 Mdot
.22698 .24571 Mdot
.07536 .00101 Mdot
.40463 .99243 Mdot
.42139 .45636 Mdot
.85164 .23951 Mdot
.52062 .46717 Mdot
.82875 .71666 Mdot
.95676 .49117 Mdot
.2843 .81963 Mdot
.17724 .93218 Mdot
.49677 .16513 Mdot
.06908 .86179 Mdot
.27271 .92068 Mdot
.99789 .86063 Mdot
.86865 .93082 Mdot
.56515 .40493 Mdot
.01849 .69165 Mdot
.04689 .9382 Mdot
.18826 .97112 Mdot
.09461 .44954 Mdot
.9008 .1542 Mdot
.9147 .51583 Mdot
.39659 .99003 Mdot
.85034 .6514 Mdot
.12902 .06609 Mdot
.85835 .793 Mdot
.26261 .13606 Mdot
.28479 .39001 Mdot
.24747 .44854 Mdot
.24305 .45032 Mdot
.06685 .4752 Mdot
.15725 .99869 Mdot
.16324 .32283 Mdot
.24114 .48542 Mdot
.76138 .33061 Mdot
.38981 .83303 Mdot
.63435 .26315 Mdot
.53604 .04028 Mdot
.37193 .12577 Mdot
.25123 .65076 Mdot
.1292 .68083 Mdot
.01081 .20206 Mdot
.06558 .2056 Mdot
.8537 .20289 Mdot
.90693 .88602 Mdot
.60872 .71691 Mdot
.14515 .55351 Mdot
.21885 .8851 Mdot
.50394 .28811 Mdot
.677 .84702 Mdot
.1351 .1605 Mdot
.42476 .19217 Mdot
.01131 .48103 Mdot
.41445 .99327 Mdot
.94536 .27375 Mdot
.56052 .78856 Mdot
.04641 .38967 Mdot
.95465 .07167 Mdot
.9057 .83655 Mdot
.7335 .1864 Mdot
.39245 .54736 Mdot
.05779 .34044 Mdot
.26059 .38883 Mdot
.62607 .14508 Mdot
.25277 .90524 Mdot
.21033 .15309 Mdot
.30696 .62991 Mdot
.64408 .36351 Mdot
.26727 .24147 Mdot
.69387 .29151 Mdot
.36292 .40722 Mdot
.96176 .10713 Mdot
.9763 .85878 Mdot
.90958 .76705 Mdot
.7111 .47035 Mdot
.27694 .62008 Mdot
.45351 .56659 Mdot
.07513 .46767 Mdot
.15051 .93509 Mdot
.42218 .10072 Mdot
.88372 .69355 Mdot
.73104 .80831 Mdot
.51273 .2888 Mdot
.77298 .70006 Mdot
.53959 .43175 Mdot
.87056 .93501 Mdot
.8352 .96018 Mdot
.58761 .31219 Mdot
.37323 .39371 Mdot
.51573 .84671 Mdot
.22851 .45735 Mdot
.09912 .74525 Mdot
.34416 .7612 Mdot
.35954 .93778 Mdot
.83388 .47085 Mdot
.58898 .23371 Mdot
.28922 .03931 Mdot
.72354 .29925 Mdot
.45204 .08144 Mdot
.13657 .9863 Mdot
.08418 .69048 Mdot
.61367 .14038 Mdot
.85018 .23353 Mdot
.51608 .39738 Mdot
.49852 .47411 Mdot
.16105 .46134 Mdot
.66898 .0042 Mdot
.56577 .22295 Mdot
.37958 .96209 Mdot
.84742 .9244 Mdot
.93244 .87945 Mdot
.70865 .93841 Mdot
.84873 .19025 Mdot
.09969 .79418 Mdot
.00242 .95554 Mdot
.57307 .39765 Mdot
.49009 .48477 Mdot
.41456 .94002 Mdot
.8258 .48123 Mdot
.85374 .71254 Mdot
.43726 .52234 Mdot
.0124 .79158 Mdot
.50867 .64126 Mdot
.29404 .85544 Mdot
.66294 .45173 Mdot
.20181 .05831 Mdot
.66422 .49614 Mdot
.62036 .66224 Mdot
.17247 .01207 Mdot
.20497 .72328 Mdot
.34424 .53133 Mdot
.35247 .01062 Mdot
.90935 .00977 Mdot
.34655 .21848 Mdot
.39056 .36835 Mdot
.0552 .36578 Mdot
.72858 .91648 Mdot
.85027 .30406 Mdot
.06935 .41793 Mdot
.22608 .64189 Mdot
.8937 .40467 Mdot
.02504 .91845 Mdot
.54327 .87256 Mdot
.66439 .91093 Mdot
.63771 .86314 Mdot
.31702 .68827 Mdot
.24618 .49475 Mdot
.26783 .32505 Mdot
.51276 .58021 Mdot
.4144 .019 Mdot
.45084 .16216 Mdot
.19324 .37853 Mdot
.55628 .7594 Mdot
.17322 .45759 Mdot
.0172 .88824 Mdot
.49832 .54756 Mdot
.37016 .02676 Mdot
.1848 .85835 Mdot
.13028 .53226 Mdot
.91679 .53581 Mdot
.60491 .95313 Mdot
.49228 .51885 Mdot
.15552 .78725 Mdot
.30695 .14168 Mdot
.5924 .0288 Mdot
.13919 .68727 Mdot
.57986 .13813 Mdot
.63168 .13915 Mdot
.21037 .11085 Mdot
.44669 .2804 Mdot
.08942 .58153 Mdot
.53047 .744 Mdot
.47263 .62845 Mdot
.03878 .22671 Mdot
.31955 .84329 Mdot
.72864 .08627 Mdot
.72717 .81512 Mdot
.59208 .39637 Mdot
.1498 .67586 Mdot
.96358 .2566 Mdot
.94047 .56293 Mdot
.5094 .9778 Mdot
.85654 .98332 Mdot
.98093 .23066 Mdot
.37572 .35364 Mdot
.94605 .00386 Mdot
.06103 .51102 Mdot
.21298 .91932 Mdot
.32501 .69507 Mdot
.61323 .52308 Mdot
.18249 .01773 Mdot
.65536 .26363 Mdot
.24202 .45747 Mdot
.14387 .29004 Mdot
.38515 .47463 Mdot
.16486 .05554 Mdot
.01241 .1204 Mdot
.22167 .05123 Mdot
.95675 .61003 Mdot
.01081 .13235 Mdot
.62336 .9174 Mdot
.38938 .6095 Mdot
.44132 .89738 Mdot
.73633 .34319 Mdot
.20474 .44216 Mdot
.59225 .05713 Mdot
.8164 .96763 Mdot
.4272 .00075 Mdot
.80777 .84545 Mdot
.21176 .94524 Mdot
.85122 .23411 Mdot
.2023 .81293 Mdot
.22557 .32178 Mdot
.81104 .20403 Mdot
.78081 .42133 Mdot
.07948 .85726 Mdot
.57418 .98519 Mdot
.47838 .80115 Mdot
.76034 .01989 Mdot
.05562 .80273 Mdot
.95738 .1719 Mdot
.8437 .85667 Mdot
.10779 .93675 Mdot
.6363 .04448 Mdot
.88125 .61751 Mdot
.82958 .84037 Mdot
.101 .19592 Mdot
.75004 .98469 Mdot
.51999 .21172 Mdot
.27027 .17937 Mdot
.76088 .1961 Mdot
.21916 .38181 Mdot
.80465 .02543 Mdot
.37518 .5225 Mdot
.69815 .08679 Mdot
.7409 .47766 Mdot
.82328 .46488 Mdot
.91532 .63818 Mdot
.7229 .26834 Mdot
.16376 .65703 Mdot
.20139 .05498 Mdot
.89355 .47793 Mdot
.43481 .86236 Mdot
.6725 .09959 Mdot
.63095 .83866 Mdot
.29467 .57553 Mdot
.93806 .75334 Mdot
.55525 .09703 Mdot
.11464 .28762 Mdot
.64264 .45661 Mdot
.38698 .01821 Mdot
.47924 .79969 Mdot
.19175 .95909 Mdot
.58886 .322 Mdot
.74942 .10118 Mdot
.916 .22376 Mdot
.11937 .2614 Mdot
.61498 .64824 Mdot
.18564 .50816 Mdot
.06716 .55152 Mdot
.0735 .22068 Mdot
.4149 .0925 Mdot
.68189 .2025 Mdot
.93558 .29224 Mdot
.48871 .24255 Mdot
.34246 .97074 Mdot
.73929 .14535 Mdot
.42527 .7448 Mdot
.62 .88489 Mdot
.80831 .10059 Mdot
.43608 .37646 Mdot
.74871 .54563 Mdot
.36686 .15241 Mdot
.32688 .4544 Mdot
.68404 .95351 Mdot
.39319 .15795 Mdot
.19483 .70641 Mdot
.05267 .18938 Mdot
.45133 .56283 Mdot
.61967 .44339 Mdot
.83382 .67822 Mdot
.81265 .34506 Mdot
.39043 .30459 Mdot
.06972 .79951 Mdot
.02662 .14938 Mdot
.73612 .34388 Mdot
.33753 .19748 Mdot
.34002 .18364 Mdot
.14723 .493 Mdot
.28982 .99456 Mdot
.68562 .93189 Mdot
.66532 .55124 Mdot
.85583 .24909 Mdot
.85412 .20567 Mdot
.45996 .94645 Mdot
.78956 .40443 Mdot
.43597 .7949 Mdot
.05645 .05943 Mdot
.10766 .59618 Mdot
.71147 .87654 Mdot
.9615 .10344 Mdot
.41923 .88072 Mdot
.27214 .17302 Mdot
.75639 .32599 Mdot
.41055 .92668 Mdot
.90313 .12296 Mdot
.95458 .9793 Mdot
.11704 .71674 Mdot
.50841 .18368 Mdot
.06447 .65668 Mdot
.40753 .58844 Mdot
.34314 .78163 Mdot
.44652 .4868 Mdot
.92721 .90217 Mdot
.18041 .31416 Mdot
.16906 .57376 Mdot
.76497 .38487 Mdot
.2634 .4532 Mdot
.81416 .40589 Mdot
.15409 .73566 Mdot
.30276 .22154 Mdot
.0954 .07889 Mdot
.89534 .63186 Mdot
.74683 .29734 Mdot
.44013 .1466 Mdot
.8241 .39621 Mdot
.26205 .8371 Mdot
.65452 .82308 Mdot
.49423 .45143 Mdot
.38962 .37197 Mdot
.68297 .04527 Mdot
.23971 .63389 Mdot
.37906 .82118 Mdot
.15138 .55502 Mdot
.48681 .18592 Mdot
.39916 .25483 Mdot
.0502 .03807 Mdot
.57379 .85975 Mdot
.78332 .20335 Mdot
.92285 .03635 Mdot
.2823 .75311 Mdot
.52355 .66414 Mdot
.59566 .70894 Mdot
.28768 .02936 Mdot
.21705 .88888 Mdot
.14394 .47668 Mdot
.72543 .70176 Mdot
.7385 .21911 Mdot
.6773 .66315 Mdot
.1637 .36316 Mdot
.89706 .46201 Mdot
.24086 .32682 Mdot
.60823 .7078 Mdot
.71215 .6584 Mdot
.01623 .99803 Mdot
.42413 .62707 Mdot
.79466 .11231 Mdot
.28835 .15136 Mdot
.0745 .4083 Mdot
.54565 .93453 Mdot
.38626 .74339 Mdot
.38629 .57233 Mdot
.4905 .28285 Mdot
.14875 .24913 Mdot
.88338 .57373 Mdot
.43091 .58904 Mdot
.87113 .57485 Mdot
.01089 .96095 Mdot
.07874 .46743 Mdot
.7183 .80893 Mdot
.00715 .05848 Mdot
.1724 .87508 Mdot
.61364 .31363 Mdot
.78222 .30176 Mdot
.12397 .03032 Mdot
.63386 .05595 Mdot
.23961 .45812 Mdot
.20346 .4664 Mdot
.36714 .88213 Mdot
.19652 .50354 Mdot
.29538 .41589 Mdot
.47228 .69255 Mdot
.29239 .35672 Mdot
.30214 .82009 Mdot
.67738 .04232 Mdot
.51703 .51679 Mdot
.55565 .00985 Mdot
.88741 .4621 Mdot
.31591 .55087 Mdot
.68192 .9996 Mdot
.95117 .67062 Mdot
.48451 .49425 Mdot
.64962 .25516 Mdot
.01933 .7994 Mdot
.35205 .90321 Mdot
.70696 .98258 Mdot
.67337 .8632 Mdot
.18935 .46501 Mdot
.12055 .85273 Mdot
.30088 .00126 Mdot
.79835 .30094 Mdot
.6143 .00824 Mdot
.85399 .62958 Mdot
.13216 .5139 Mdot
.20362 .37828 Mdot
.1173 .71549 Mdot
.84815 .47231 Mdot
.40064 .73445 Mdot
.17265 .60994 Mdot
.21701 .27404 Mdot
.05798 .75803 Mdot
.91605 .26878 Mdot
.25308 .45641 Mdot
.29918 .26389 Mdot
.39838 .82469 Mdot
.17365 .7502 Mdot
.20205 .45163 Mdot
.0629 .03467 Mdot
.35174 .97754 Mdot
.65627 .29837 Mdot
.18541 .36943 Mdot
.43599 .02889 Mdot
.1344 .60881 Mdot
.52012 .75719 Mdot
.87651 .15433 Mdot
.22398 .49463 Mdot
.47084 .32995 Mdot
.05621 .74477 Mdot
.27195 .88043 Mdot
.9967 .70944 Mdot
.92391 .90352 Mdot
.33266 .40989 Mdot
.73714 .53583 Mdot
.89596 .38099 Mdot
.60312 .9303 Mdot
.37078 .62098 Mdot
.72872 .77446 Mdot
.15056 .12621 Mdot
.25511 .44658 Mdot
.10293 .38463 Mdot
.98569 .56488 Mdot
.11106 .67607 Mdot
.06852 .66257 Mdot
.7703 .26648 Mdot
.32744 .12318 Mdot
.87844 .88776 Mdot
.72155 .1958 Mdot
.49912 .26467 Mdot
.99452 .42168 Mdot
.35254 .13625 Mdot
.73396 .97929 Mdot
.25415 .75458 Mdot
.75347 .40965 Mdot
.15189 .07753 Mdot
.68699 .74968 Mdot
.37569 .81252 Mdot
.36043 .62443 Mdot
.50112 .92567 Mdot
.63945 .42792 Mdot
.00779 .66041 Mdot
.64737 .01026 Mdot
.64758 .52134 Mdot
.91706 .03124 Mdot
.39077 .76695 Mdot
.16386 .61898 Mdot
.24304 .6877 Mdot
.46805 .87053 Mdot
.8689 .87708 Mdot
.11189 .24464 Mdot
.35728 .95265 Mdot
.46502 .81537 Mdot
.35541 .29232 Mdot
.82168 .80782 Mdot
.70494 .77027 Mdot
.90941 .77705 Mdot
.31249 .00238 Mdot
.74288 .15792 Mdot
.07165 .31494 Mdot
.27106 .28856 Mdot
.20489 .44095 Mdot
.16392 .04113 Mdot
.84522 .48639 Mdot
.69383 .22606 Mdot
.48347 .19362 Mdot
.87441 .42025 Mdot
.78035 .42267 Mdot
.97274 .64289 Mdot
.46258 .42277 Mdot
.22558 .48635 Mdot
.39606 .10497 Mdot
.95478 .19803 Mdot
.19514 .66688 Mdot
.79128 .15776 Mdot
.35115 .17911 Mdot
.10239 .92713 Mdot
.86784 .98697 Mdot
.22483 .50876 Mdot
.09206 .56267 Mdot
.25487 .86623 Mdot
.6186 .1399 Mdot
.03433 .38034 Mdot
.22256 .03251 Mdot
.07835 .181 Mdot
.02995 .3663 Mdot
.285 .02439 Mdot
.67427 .1842 Mdot
.18714 .09525 Mdot
.80849 .20004 Mdot
.96335 .58761 Mdot
.72191 .63636 Mdot
.70263 .72199 Mdot
.10989 .49727 Mdot
.67483 .34016 Mdot
.88298 .4627 Mdot
.59714 .15922 Mdot
.85633 .09752 Mdot
.31441 .13366 Mdot
.18322 .90983 Mdot
.13081 .03649 Mdot
.36987 .71071 Mdot
.17091 .45157 Mdot
.64823 .07598 Mdot
.45976 .72604 Mdot
.54164 .5789 Mdot
.78877 .38397 Mdot
.66332 .11715 Mdot
.19171 .22548 Mdot
.80885 .02316 Mdot
.87794 .09135 Mdot
.62628 .11042 Mdot
.7468 .05452 Mdot
.2544 .40175 Mdot
.57525 .60307 Mdot
.60368 .32257 Mdot
.12088 .8737 Mdot
.063 .74592 Mdot
.32608 .48927 Mdot
.39154 .62735 Mdot
.14073 .26505 Mdot
.57902 .60801 Mdot
.26337 .17305 Mdot
.9592 .49733 Mdot
.5108 .12206 Mdot
.70001 .09937 Mdot
.935 .52022 Mdot
.1014 .77415 Mdot
.81766 .64356 Mdot
.04269 .02815 Mdot
.48296 .1553 Mdot
.64496 .39916 Mdot
.34379 .89302 Mdot
.06596 .79383 Mdot
.08993 .71844 Mdot
.1073 .29721 Mdot
.56569 .59601 Mdot
.40024 .19595 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool00oooool2o`0000So
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo0_l000000ooooooo0000o`00000;ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool01Oooool2o`0000Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`;o
00002Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo0_l00008ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`?o
00001Oooool2o`0000Wooooo00?o0000ooooooooool00_ooool001kooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo0_l00008ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00;o00002oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`;o00002Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Cooooo0_l00008ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`?o00004?ooool00ol0003ooooo
ooooo`02ooooo`007_ooool00ol0003oooooooooo`1^ooooo`;o0000@Oooool2o`00017ooooo0_l0
0008ooooo`;o0000E?ooool2o`00027ooooo000Nooooo`03o`000?oooooooooo03Cooooo0_l0000a
ooooo`;o00001Oooool2o`0000kooooo0_l0000aooooo`;o00004Oooool2o`0000Sooooo0_l0001D
ooooo`;o00008Oooool001kooooo00?o0000ooooooooool0=?ooool2o`00037ooooo0_l0000Eoooo
o`;o0000B?ooool2o`0007gooooo000Nooooo`03o`000?oooooooooo03Oooooo0_l00011ooooo`;o
00001oooool2o`0000Oooooo0_l0000Xooooo`;o00004?ooool2o`0002Wooooo0_l0001Booooo`00
7_ooool00ol0003oooooooooo`0gooooo`;o0000@Oooool2o`0000Oooooo0_l00007ooooo`;o0000
:?ooool2o`00023ooooo0_l0000Iooooo`;o0000D_ooool001kooooo00?o0000ooooooooool0FOoo
ool2o`0007gooooo0_l0000Wooooo`Co00002_ooool2o`0003Kooooo000Nooooo`03o`000?oooooo
oooo00[ooooo0_l0000Vooooo`;o00009Oooool2o`0001Wooooo0_l0000Dooooo`;o0000:?ooool2
o`0000Kooooo0_l00013ooooo`Co00002_ooool2o`0002[ooooo0_l0000:ooooo`007_ooool00ol0
003oooooooooo`0:ooooo`;o00006?ooool2o`0000cooooo0_l0000Uooooo`;o00006Oooool2o`00
01Cooooo0_l0000Xooooo`;o00001_ooool2o`0006Sooooo0_l0000Cooooo`;o00002_ooool001ko
oooo00?o0000ooooooooool03?ooool2o`0000;ooooo0_l0000Booooo`;o00007_ooool2o`0001?o
oooo0_l0003;ooooo`;o00004Oooool2o`0000cooooo000Nooooo`03o`000?oooooooooo00cooooo
0_l00002ooooo`;o00005?ooool2o`0000Gooooo0_l0000Eooooo`;o00005?ooool2o`00027ooooo
0_l0002Yooooo`;o00003oooool2o`0000cooooo000Nooooo`03o`000?oooooooooo00cooooo0_l0
000Hooooo`;o00001Oooool2o`0000;ooooo0_l0000Wooooo`;o00008Oooool2o`0002_ooooo0_l0
000Qooooo`;o0000FOooool2o`0001gooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0000X
ooooo`;o00009oooool2o`0004kooooo0_l0000Oooooo`Co00002Oooool2o`0006gooooo000Noooo
o`03o`000?oooooooooo00Oooooo0_l00013ooooo`;o0000OOooool2o`0000_ooooo1?l0001[oooo
o`007_ooool00ol0003oooooooooo`1<ooooo`;o00006_ooool2o`00073ooooo0_l0001[ooooo`00
7_ooool2o`0004Gooooo0_l0000Rooooo`;o0000Ooooool2o`0005cooooo000Nooooo`03o`000?oo
oooooooo01Sooooo0_l0000Gooooo`;o00002_ooool2o`0000Gooooo0_l0001<ooooo`;o0000=_oo
ool2o`0001gooooo0_l00004ooooo`;o0000E_ooool001kooooo0ol0000>ooooo`;o00002?ooool2
o`0001Oooooo0_l00007ooooo`;o000000?oooooo`000?l00000AOooool2o`0000cooooo0_l0000X
ooooo`;o00003?ooool2o`0002?ooooo0_l0001Fooooo`007_ooool3o`0000kooooo0_l0000Zoooo
o`;o000000?oooooo`000?l00000AOooool2o`0003Kooooo0_l00029ooooo`007_ooool00ol0003o
ooooooooo`3ooooooa?ooooo0_l0000cooooo`007_ooool00ol0003oooooooooo`09ooooo`;o0000
6oooool2o`0003Wooooo0_l0002_ooooo`;o0000<oooool001kooooo00?o0000ooooooooool02Ooo
ool2o`0001Kooooo0_l00003ooooo`;o0000>Oooool2o`000<oooooo0_l0000Cooooo`007_ooool0
0ol0003oooooooooo`0Qooooo`;o00008_ooool2o`0000Wooooo0_l0000fooooo`;o0000DOooool2
o`0005Gooooo0_l0000Cooooo`007_ooool00ol0003oooooooooo`0]ooooo`;o00005_ooool2o`00
00Wooooo0_l0000fooooo`;o0000AOooool2o`0000[ooooo0_l00006ooooo`;o0000H_ooool001ko
oooo00?o0000ooooooooool06oooool2o`00013ooooo0_l0002Pooooo`;o00004_ooool2o`0006;o
oooo000Nooooo`03o`000?oooooooooo01_ooooo0_l00006ooooo`;o0000COooool2o`0001_ooooo
0_l0002fooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o0000COooool2o`0001_ooooo0_l0
001>ooooo`;o00002?ooool2o`0005cooooo000Nooooo`03o`000?oooooooooo07Kooooo0_l0001W
ooooo`;o00002?ooool2o`0004Kooooo0_l0000Dooooo`007_ooool00ol0003oooooooooo`1foooo
o`;o00002oooool2o`0004Gooooo0_l0001=ooooo`;o00005_ooool2o`0001Cooooo000Nooooo`03
o`000?oooooooooo03Wooooo0_l00018ooooo`;o00002oooool2o`0000Wooooo0_l0000Tooooo`;o
00001oooool2o`0000Sooooo0_l00013ooooo`;o0000;?ooool001kooooo00?o0000ooooooooool0
0oooool2o`0002Gooooo0_l0000=ooooo`;o0000@_ooool2o`00017ooooo0_l00002ooooo`;o0000
1Oooool2o`0001?ooooo0_l0000?ooooo`;o00004Oooool2o`000003ooooool0003o000000Kooooo
0_l0000aooooo`;o00005?ooool2o`0001gooooo000Nooooo`;o00001?ooool2o`0002Gooooo0_l0
001Aooooo`;o00001_ooool2o`0000gooooo0_l0000Jooooo`;o00009Oooool2o`0000Kooooo0_l0
000?ooooo`;o00004Oooool2o`0000gooooo0_l0000Dooooo`;o00007Oooool001kooooo00?o0000
ooooooooool0OOooool2o`0000Kooooo0_l0001Yooooo`;o00004Oooool2o`0000oooooo0_l0000N
ooooo`;o00004Oooool001kooooo00?o0000ooooooooool0OOooool2o`0009Gooooo0_l0000Noooo
o`?o00004?ooool001kooooo00?o0000ooooooooool0@?ooool2o`0003_ooooo0_l00018ooooo`;o
0000K?ooool2o`00013ooooo000Nooooo`03o`000?oooooooooo043ooooo0_l00025ooooo`;o0000
2_ooool2o`0002Wooooo0_l00017ooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o0000D?oo
ool2o`0006kooooo0ol0000=ooooo`;o00006Oooool2o`0000Wooooo0_l0000looooo`007_ooool0
0ol0003oooooooooo`02o`0000oooooo0_l00007ooooo`;o0000Aoooool2o`0006oooooo0_l0000=
ooooo`;o00009?ooool2o`0003cooooo000Nooooo`03o`000?oooooooooo00;o00006?ooool2o`00
04[ooooo0_l0000jooooo`;o0000O_ooool2o`0002?ooooo000Nooooo`03o`000?oooooooooo02go
oooo0_l0000gooooo`;o00003Oooool2o`0002_ooooo0_l0001nooooo`;o00008oooool001kooooo
00?o0000ooooooooool0;Oooool2o`0001oooooo0_l0000Uooooo`;o00001_ooool2o`0005Gooooo
0_l0001Gooooo`;o00006?ooool001kooooo00Co0000ooooool0003o00003Oooool2o`0000gooooo
0_l0000_ooooo`;o00004_ooool2o`0001Wooooo0_l0000booooo`;o00005oooool2o`0000Sooooo
0_l0001Gooooo`;o00006?ooool001kooooo00Co0000ooooool0003o00003Oooool2o`0000gooooo
0_l0000booooo`;o00003oooool2o`0000Kooooo0_l00002ooooo`;o00004oooool2o`0002Oooooo
0_l00003ooooo`;o00005oooool2o`0007;ooooo0_l00007ooooo`007_ooool00ol0003ooooooooo
o`1Aooooo`;o00005oooool2o`0000;ooooo0_l0000Cooooo`;o00009oooool2o`0000[ooooo0_l0
000?ooooo`;o0000Loooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo063ooooo0_l0001F
ooooo`;o00002Oooool4o`0000;ooooo0_l0001looooo`007_ooool00ol0003oooooooooo`1Poooo
o`;o0000A?ooool2o`0001_ooooo1_l0000Sooooo`;o0000FOooool001kooooo00?o0000oooooooo
ool0Coooool2o`00023ooooo0_l0000Hooooo`;o00006Oooool2o`0001oooooo0_l0000Sooooo`;o
0000FOooool001kooooo0_l00006ooooo`;o0000B?ooool2o`0000Wooooo0_l0000Eooooo`;o0000
6?ooool2o`0009cooooo0_l0000Looooo`007_ooool00ol0003oooooooooo`05ooooo`;o0000>Ooo
ool2o`0001Sooooo0_l0000Gooooo`;o00005Oooool2o`00067ooooo0_l0000Zooooo`;o00001_oo
ool2o`0000Kooooo0_l0000Looooo`007_ooool00ol0003oooooooooo`10ooooo`;o0000<Oooool2
o`0000Oooooo0_l0000<ooooo`;o00003Oooool2o`0005;ooooo0_l0000>ooooo`;o00006_ooool2
o`0000Kooooo0_l0000Tooooo`007_ooool00ol0003oooooooooo`0Xooooo`;o0000D_ooool2o`00
01_ooooo0_l0000Sooooo`;o0000;Oooool2o`0000kooooo0_l00018ooooo`007_ooool00ol0003o
ooooooooo`0Xooooo`;o0000I?ooool2o`0002kooooo0_l0000]ooooo`;o0000F?ooool001kooooo
00?o0000ooooooooool02_ooool2o`0006Cooooo0_l0000Looooo`;o00003Oooool2o`0000kooooo
0_l0000nooooo`;o0000<?ooool2o`0002Kooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0
001Tooooo`;o00002Oooool2o`00023ooooo0_l0000>ooooo`;o0000L?ooool2o`0002Kooooo000N
ooooo`03o`000?oooooooooo05;ooooo1?l00002ooooo`;o00008Oooool2o`000;Kooooo0_l0000B
ooooo`007_ooool00ol0003oooooooooo`1Booooo`Co00000_ooool2o`000=Wooooo0_l0000Boooo
o`007_ooool00ol0003oooooooooo`1Dooooo`;o00006?ooool2o`000=Oooooo000Nooooo`03o`00
0?oooooooooo01Gooooo0_l0000mooooo`;o00006?ooool2o`000=Oooooo000Nooooo`03o`000?oo
oooooooo01Gooooo0_l0001Cooooo`;o0000;_ooool2o`0000Gooooo0_l0000dooooo`;o0000@?oo
ool2o`0002cooooo000Nooooo`03o`000?oooooooooo06[ooooo0_l0000^ooooo`;o00001Oooool2
o`0003Cooooo0_l0000Aooooo`;o0000;Oooool3o`0002_ooooo000Nooooo`03o`000?oooooooooo
00gooooo0_l0002dooooo`;o00009Oooool2o`0002Cooooo0_l00008ooooo`;o0000:oooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000oooo
ooooool03Oooool2o`0007Oooooo0_l0000Aooooo`;o00002oooool2o`0001_ooooo0_l0001;oooo
o`;o0000=Oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnH
V9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool07Oooool2o`0004_ooooo0_l0000B
ooooo`;o00001_ooool2o`00017ooooo0_l0000;ooooo`;o0000?_ooool2o`0000_ooooo0_l0000W
ooooo`;o00005?ooool2o`0001?ooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0onHV9So8B4Qonk^kP07ooooo`?o00007Oooool2o`0004_ooooo0_l0000Booooo`;o0000I_ooool2
o`0000_ooooo0_l0000>ooooo`;o00005oooool2o`0001Cooooo0_l0000Cooooo`000oooool01Ol0
003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01_ooool01?l0003oooooo`000?l0
003Iooooo`;o00000_ooool2o`0001_ooooo0_l00006ooooo`?o00002oooool2o`0003Cooooo0003
ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`04o`000?oo
oooo0000o`00013ooooo0_l00037ooooo`;o00000_ooool2o`0001_ooooo0_l00007ooooo`;o0000
2oooool3o`0003?ooooo0003ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo017ooooo0_l0003oooooo`;o0000<oooool000?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003o
ooooooooo`0[ooooo`;o0000N?ooool2o`00097ooooo0_l0000=ooooo`000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo
01kooooo0ol0000:ooooo`?o0000>Oooool2o`0003cooooo0_l0001>ooooo`;o0000@Oooool2o`00
00gooooo000Nooooo`03o`000?oooooooooo01kooooo0ol0000;ooooo`;o00007oooool2o`0001So
oooo0_l00004ooooo`?o0000@?ooool2o`0003[ooooo0_l00007ooooo`;o00002Oooool2o`0004Go
oooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0000gooooo`;o00003oooool2o`0000gooooo
0ol00010ooooo`;o0000>_ooool2o`0001;ooooo0_l00015ooooo`007_ooool00ol0003ooooooooo
o`0Dooooo`;o00003oooool2o`0001?ooooo0_l0000:ooooo`;o00005_ooool2o`0005Cooooo0_l0
001`ooooo`;o00007oooool001kooooo00?o0000ooooooooool02?ooool2o`0001_ooooo0_l0000C
ooooo`;o00001?ooool2o`0000Cooooo0_l0001Pooooo`;o00002_ooool2o`0002Oooooo0_l00017
ooooo`;o00005_ooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0000foooo
o`;o00008?ooool2o`0004Cooooo0_l0000cooooo`;o0000@oooool2o`0001Oooooo0_l000000ooo
oooo0000o`000007ooooo`007_ooool00ol0003oooooooooo`1Rooooo`;o0000Eoooool2o`0005?o
oooo0ol0000?ooooo`;o00005oooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo07;ooooo
0_l00017ooooo`;o00004?ooool2o`00047ooooo0ol0000/ooooo`;o00001_ooool001kooooo00?o
0000ooooooooool0L_ooool2o`0005Wooooo0_l0000booooo`;o00003_ooool2o`0002cooooo0_l0
0006ooooo`007_ooool00ol0003oooooooooo`1Cooooo`;o0000A_ooool2o`0006Cooooo0_l0000>
ooooo`;o0000=?ooool001kooooo00?o0000ooooooooool08?ooool2o`0002Cooooo0_l0000;oooo
o`;o0000A_ooool2o`0005Cooooo0_l0001Dooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o
00002_ooool2o`0001Sooooo0_l0002Yooooo`;o00007oooool2o`0003?ooooo000Nooooo`;o0000
;Oooool2o`000>Cooooo0_l0000cooooo`007_ooool00ol0003oooooooooo`1nooooo`;o0000Cooo
ool2o`0003Gooooo0_l0000]ooooo`;o00004?ooool001kooooo00?o0000ooooooooool0O_ooool2
o`0004oooooo0_l0000eooooo`;o0000;Oooool2o`00013ooooo000Nooooo`03o`000?oooooooooo
02?ooooo0_l0001hooooo`;o0000Z?ooool001kooooo00?o0000ooooooooool08oooool2o`0000Go
oooo0_l0000aooooo`;o0000?_ooool3o`0002[ooooo0_l00005ooooo`;o0000M?ooool001kooooo
00?o0000ooooooooool0:_ooool2o`0002;ooooo0_l0000=ooooo`;o0000?oooool2o`0002[ooooo
0_l00005ooooo`;o00005?ooool2o`0000gooooo0_l0000^ooooo`;o00007oooool001kooooo00?o
0000ooooooooool07Oooool2o`0002oooooo0_l0000Yooooo`;o0000Hoooool2o`0000Oooooo0_l0
000=ooooo`;o0000;_ooool2o`0001oooooo000Nooooo`03o`000?oooooooooo01gooooo0_l0000S
ooooo`;o0000=?ooool3o`0005oooooo0_l00002ooooo`;o00002_ooool2o`0004?ooooo0_l0000F
ooooo`007_ooool00ol0003oooooooooo`12ooooo`;o0000=?ooool2o`00063ooooo0_l0000>oooo
o`;o0000@oooool2o`0001Kooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0000Eooooo`;o
0000H?ooool2o`000;Sooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0000Eooooo`;o0000
H?ooool2o`0000cooooo0_l00008ooooo`;o0000K_ooool2o`00033ooooo000Nooooo`03o`000?oo
oooooooo09?ooooo0_l00006ooooo`;o00002?ooool2o`0005_ooooo0_l0000>ooooo`;o000000?o
ooooo`000?l00000<?ooool001kooooo00?o0000ooooooooool08Oooool2o`0000Sooooo0_l0000W
ooooo`;o0000?Oooool2o`0000_ooooo0_l000000ooooooo0000o`00001Mooooo`;o00003_ooool2
o`0003?ooooo000Nooooo`04o`000?oooooo0000o`00023ooooo0_l00002ooooo`;o00001?ooool2
o`0002Oooooo0_l0000Iooooo`;o0000;oooool2o`000003ooooool0003o000003Sooooo0_l0001=
ooooo`;o00006Oooool001kooooo00?o0000ooooool000000_l0000Sooooo`;o0000B?ooool2o`00
06cooooo0_l0001=ooooo`;o00006Oooool001kooooo00?o0000ooooooooool00_l0000Mooooo`;o
0000/?ooool2o`0001Cooooo0_l00006ooooo`;o0000E_ooool001kooooo0_l0000Pooooo`;o0000
/?ooool2o`0001Cooooo0_l00006ooooo`;o00002Oooool2o`0000?ooooo0_l00016ooooo`007_oo
ool00ol0003oooooooooo`1kooooo`;o0000N_ooool2o`000003ooooool0003o000000?ooooo0_l0
000?ooooo`;o00008?ooool2o`0001?ooooo000Mooooo`;o000000?oooooo`000?l00000N_ooool2
o`0007[ooooo0_l0000Gooooo`;o00008?ooool2o`0001?ooooo000Mooooo`;o000000?oooooo`00
0?l000002?ooool2o`000?oooooo?Oooool001kooooo00?o0000ooooooooool02Oooool2o`0000So
oooo0_l0000Rooooo`;o0000P_ooool2o`0000Kooooo0_l00022ooooo`007_ooool00ol0003ooooo
ooooo`0Cooooo`;o00008_ooool2o`0008;ooooo0_l00006ooooo`;o0000P_ooool001kooooo00?o
0000ooooooooool0loooool2o`0005;ooooo000Nooooo`03o`000?oooooooooo037ooooo0_l0000B
ooooo`;o00006?ooool2o`0003Gooooo0_l0000Sooooo`;o00000oooool2o`00037ooooo0_l0000C
ooooo`;o0000?Oooool001kooooo00?o0000ooooooooool0<Oooool2o`0001;ooooo0_l00003oooo
o`;o00001oooool2o`0000[ooooo0_l0000eooooo`;o00008oooool2o`0000?ooooo0_l0000`oooo
o`;o00005?ooool2o`0003gooooo000Nooooo`03o`000?oooooooooo01kooooo0_l00004ooooo`;o
00009?ooool2o`0000Oooooo0_l00010ooooo`?o0000F_ooool2o`0005?ooooo000Nooooo`03o`00
0?oooooooooo01kooooo0_l00004ooooo`;o0000Koooool2o`0000_ooooo0_l0001?ooooo`;o0000
D_ooool001kooooo00?o0000ooooooooool0X_ooool2o`0004oooooo0_l0000`ooooo`;o00008?oo
ool001kooooo00?o0000ooooooooool0S_ooool2o`0002oooooo0_l0000aooooo`;o0000<Oooool2
o`00023ooooo000Nooooo`03o`000?oooooooooo00oooooo0_l0001mooooo`;o0000;oooool2o`00
01Kooooo0_l0000Iooooo`;o0000Doooool001kooooo00?o0000ooooooooool03oooool2o`0009Ko
oooo0_l0000^ooooo`;o00004_ooool2o`0001Oooooo0_l0000Pooooo`;o00007oooool001kooooo
00?o0000ooooooooool0I_ooool2o`0003oooooo0_l0000[ooooo`;o00005Oooool2o`0001Oooooo
0_l0000Pooooo`;o00007oooool001kooooo0_l0001Looooo`;o00002Oooool2o`0006cooooo0_l0
001aooooo`007_ooool00ol0003oooooooooo`1Kooooo`;o00006Oooool2o`000<oooooo000Noooo
o`03o`000?oooooooooo05_ooooo0_l0000Iooooo`;o0000coooool001kooooo00?o0000oooooooo
ool0Foooool2o`000>[ooooo000Nooooo`03o`000?oooooooooo037ooooo0_l0000;ooooo`;o0000
SOooool2o`0007Sooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l00006ooooo`;o00003ooo
ool2o`00013ooooo0_l0000;ooooo`;o00009oooool2o`0000Kooooo0_l0000Hooooo`;o0000@_oo
ool2o`0005_ooooo0_l0000Kooooo`007_ooool00ol0003oooooooooo`06ooooo`;o00001_ooool2
o`0000oooooo0_l0000Gooooo`;o00000oooool2o`0002Sooooo0_l00006ooooo`;o00002_ooool2
o`0000cooooo0_l0002Oooooo`;o00006oooool001kooooo00?o0000ooooooooool00_ooool2o`00
03Cooooo0_l00003ooooo`;o0000>oooool3o`000<[ooooo000Nooooo`03o`000?oooooooooo00;o
oooo0_l0001fooooo`?o00003Oooool2o`0005kooooo0_l00004ooooo`;o0000EOooool001kooooo
00?o0000ooooooooool0>oooool2o`000003ooooool0003o000004[ooooo0_l0001Nooooo`;o0000
1?ooool2o`0005Gooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0000booooo`;o000000?o
ooooo`000?l000000oooool2o`000=[ooooo0_l0000Vooooo`007_ooool00ol0003oooooooooo`07
ooooo`;o00005?ooool2o`0002Cooooo0_l0000_ooooo`;o0000Ooooool2o`0000Gooooo0_l0000Q
ooooo`;o00009_ooool001kooooo00?o0000ooooooooool07Oooool2o`0000Sooooo0_l0000Xoooo
o`;o00008Oooool2o`0007oooooo0_l00005ooooo`;o0000BOooool001kooooo00?o0000oooooooo
ool02oooool2o`0001[ooooo0_l0000Xooooo`;o00001Oooool2o`0000Kooooo0_l0000Hooooo`;o
00003?ooool2o`000;gooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo0_l0001;ooooo`;o
00001_ooool2o`0001?ooooo0_l00003ooooo`;o00003?ooool2o`0009cooooo0_l0000Oooooo`00
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0MOooool2o`0002gooooo0_l0000@ooooo`;o00001?ooool2o`0004[o
oooo0_l0000Looooo`;o00007oooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go
00001_ooool3o`000:Cooooo0_l00004ooooo`;o00002_ooool2o`0000Cooooo0_l0000@ooooo`;o
0000>?ooool2o`0003?ooooo0_l00008ooooo`000oooool01Ol0003ooooooooooooooooo000000_o
oooo00CoA4A4omgMgOoooooo00001oooool00ol0003oooooooooo`1?ooooo`;o0000FOooool2o`00
02;ooooo0_l0000Aooooo`;o00001_ooool2o`0005;ooooo0_l00008ooooo`000oooool01Ol0003o
oooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`1?
ooooo`;o00008Oooool2o`00043ooooo0_l0000[ooooo`;o00001_ooool2o`0001;ooooo0_l00006
ooooo`;o00005oooool2o`0002Oooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo01Cooooo0_l0000`ooooo`;o00008?ooool2
o`0000Sooooo0_l0000mooooo`;o000000?oooooo`000?l00000>oooool2o`0000[ooooo0_l00006
ooooo`;o00005oooool2o`0002Oooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo01Cooooo0_l0000`ooooo`;o00008?ooool2
o`0004Oooooo0_l0000nooooo`;o0000E?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=
ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0G?ooool2o`0006[ooooo0_l0000c
ooooo`;o0000B?ooool001kooooo00?o0000ooooooooool04_ooool2o`0004Sooooo0_l0000Koooo
o`;o00006Oooool2o`0003;ooooo0_l0000cooooo`;o0000B?ooool001kooooo00?o0000oooooooo
ool03_ooool2o`0000;ooooo0_l0000aooooo`;o0000<_ooool2o`0001Oooooo1?l00004ooooo`;o
0000G_ooool2o`0001cooooo0_l0000Uooooo`;o00001_ooool001kooooo00?o0000ooooooooool0
3_ooool2o`0002Kooooo0_l0000=ooooo`;o0000Boooool2o`0000Kooooo0_l0001Nooooo`;o0000
7?ooool2o`0002Gooooo0_l00006ooooo`007_ooool00ol0003oooooooooo`0fooooo`;o0000HOoo
ool2o`00037ooooo0_l0001iooooo`007_ooool00ol0003oooooooooo`2Iooooo`;o00004?ooool2
o`0001oooooo0_l0001iooooo`007_ooool00ol0003oooooooooo`2[ooooo`;o0000G?ooool2o`00
03cooooo000Nooooo`03o`000?oooooooooo0?oooooo2_ooool2o`0003cooooo000Nooooo`03o`00
0?oooooooooo03kooooo0_l0000cooooo`;o0000d_ooool001kooooo00?o0000ooooooooool0<?oo
ool2o`0000cooooo0_l0000cooooo`;o0000D?ooool2o`00083ooooo000Nooooo`03o`000?oooooo
oooo033ooooo0_l0000<ooooo`;o00003oooool2o`00043ooooo0_l0000booooo`;o0000P?ooool0
01kooooo00?o0000ooooooooool06oooool2o`0002kooooo0ol000000ooooooo0000o`000010oooo
o`;o0000XOooool2o`00017ooooo000Nooooo`;o00007?ooool2o`0001Kooooo0_l00009ooooo`;o
00002Oooool5o`0000Cooooo0_l00019ooooo`;o0000=?ooool2o`0005oooooo0_l0000Aooooo`00
7_ooool00ol0003oooooooooo`0cooooo`;o00002Oooool2o`0000Wooooo0_l00003ooooo`;o0000
0_ooool2o`0001;ooooo0_l0000Mooooo`;o00002Oooool2o`0000_ooooo0_l0000^ooooo`;o0000
1?ooool2o`0007;ooooo000Nooooo`03o`000?oooooooooo02kooooo0_l00004ooooo`;o00004?oo
ool2o`0000;ooooo0ol000000ooooooo0000o`00000Fooooo`;o00007Oooool2o`0000Wooooo0_l0
000kooooo`;o00008?ooool2o`0005Kooooo000Nooooo`03o`000?oooooooooo02kooooo1?l00002
ooooo`;o00004?ooool2o`0000;ooooo0ol00004ooooo`;o00000oooool2o`0009Oooooo0_l0000Z
ooooo`?o00000_ooool2o`0002Gooooo000Nooooo`03o`000?oooooooooo033ooooo0_l00007oooo
o`;o00005_ooool2o`0000?ooooo0_l0002`ooooo`;o00004Oooool3o`0000;ooooo0_l0000Uoooo
o`007_ooool00ol0003oooooooooo`0Dooooo`?o00008_ooool2o`0000?ooooo0_l0001Uooooo`;o
0000:oooool2o`0003Cooooo0_l0000mooooo`007_ooool00ol0003oooooooooo`0Dooooo`?o0000
9oooool2o`0002[ooooo0_l0000iooooo`;o0000:oooool2o`0000oooooo0_l0000Vooooo`;o0000
>_ooool001kooooo00?o0000ooooooooool0J_ooool2o`0000gooooo0_l0000Sooooo`;o0000@ooo
ool2o`0002Kooooo0_l00003ooooo`;o0000=Oooool001kooooo00?o0000ooooooooool04_ooool2
o`0001Oooooo0_l0001<ooooo`;o00008oooool2o`0004gooooo0_l0000Qooooo`;o00003?ooool2
o`0002Oooooo000Nooooo`03o`000?oooooooooo00;o00004?ooool2o`0001Oooooo0_l00030oooo
o`;o00006Oooool2o`0001Cooooo0_l0000;ooooo`;o00006_ooool001kooooo00?o0000oooooooo
ool00_l0002Cooooo`;o00002Oooool2o`0006Kooooo0_l0000Qooooo`;o00006_ooool001kooooo
00?o0000ooooooooool0AOooool2o`0000?ooooo0_l00011ooooo`;o00001_ooool2o`0000Cooooo
0_l00003ooooo`;o0000<oooool2o`0003Sooooo0_l0000fooooo`007_ooool00ol0003ooooooooo
o`15ooooo`;o00000oooool2o`0001[ooooo0_l0000Uooooo`;o00003?ooool2o`0003Sooooo0_l0
000fooooo`Co00007oooool2o`0001Gooooo000Nooooo`03o`000?oooooooooo02cooooo0_l0000h
ooooo`;o0000L_ooool2o`00037ooooo0_l0000Qooooo`;o000000?oooooo`000?l000004_ooool0
01kooooo00?o0000ooooooooool0;?ooool2o`0001Oooooo0_l00005ooooo`;o0000Boooool2o`00
03Wooooo0_l00004ooooo`;o0000C_ooool2o`0000Oooooo0_l0000Booooo`007_ooool00ol0003o
ooooooooo`0Iooooo`;o00001Oooool2o`0002?ooooo0_l00005ooooo`;o0000Boooool2o`0003Wo
oooo0_l0000nooooo`;o00005?ooool2o`0000Sooooo0_l0000Aooooo`007_ooool2o`0001[ooooo
0_l00005ooooo`;o00005oooool2o`000=Wooooo0_l000000ooooooo0000o`00000?ooooo`;o0000
2_ooool2o`00017ooooo000Nooooo`03o`000?oooooooooo03Wooooo0_l000000ooooooo0000o`00
000Booooo`;o0000aOooool2o`0000oooooo0_l0000Mooooo`007_ooool00ol0003oooooooooo`0h
ooooo`;o00000_ooool2o`0000Oooooo0_l00009ooooo`;o0000mOooool001kooooo00?o0000oooo
ooooool04?ooool2o`0002Kooooo0_l0000;ooooo`;o0000BOooool2o`000;Gooooo000Nooooo`03
o`000?oooooooooo013ooooo0_l0000Eooooo`;o0000Boooool2o`0001[ooooo0_l00008ooooo`;o
0000Zoooool001kooooo00?o0000ooooooooool09oooool2o`0002cooooo0_l0000Mooooo`;o0000
9?ooool2o`0000Sooooo0_l0001oooooo`;o00008?ooool001kooooo00?o0000ooooooooool0EOoo
ool2o`0004Gooooo0_l00006ooooo`;o0000Eoooool2o`0002Kooooo0_l00005ooooo`;o00006Ooo
ool001kooooo00?o0000ooooooooool01Oooool2o`0006oooooo0_l00002ooooo`;o00003_ooool2
o`0000kooooo1?l0000Uooooo`;o00002Oooool2o`0002gooooo0_l0000]ooooo`;o00006Oooool0
01kooooo00?o0000ooooooooool01Oooool2o`0001Sooooo0_l0001Eooooo`;o00000_ooool2o`00
00kooooo0_l0000>ooooo`;o00009oooool2o`0000Wooooo0_l0000aooooo`;o0000A?ooool001ko
oooo00?o0000ooooooooool07oooool2o`0001Oooooo0_l00037ooooo`;o0000A?ooool001kooooo
00?o0000ooooooooool09_ooool2o`0000Wooooo0_l00005ooooo`;o0000<_ooool2o`0006Sooooo
0_l00017ooooo`;o00001Oooool2o`0001oooooo000Nooooo`03o`000?oooooooooo02Kooooo0_l0
0009ooooo`;o0000>Oooool2o`00023ooooo0_l00016ooooo`;o00005?ooool2o`00037ooooo0_l0
0005ooooo`;o00007oooool001kooooo00?o0000ooooooooool0Aoooool2o`0004Gooooo0_l0000I
ooooo`;o0000@Oooool2o`0003Sooooo0_l0000Oooooo`007_ooool00ol0003oooooooooo`17oooo
o`;o00003?ooool2o`0005;ooooo0_l0000Oooooo`;o0000Noooool001kooooo00?o0000oooooooo
ool0EOooool2o`0002cooooo0_l0000Booooo`;o0000<Oooool2o`0002?ooooo0_l0001Fooooo`00
7_ooool00ol0003oooooooooo`0Booooo`;o0000Ioooool2o`0000Kooooo0_l0000Booooo`;o0000
1Oooool2o`0002gooooo0_l0000Pooooo`;o0000E_ooool001kooooo0_l0000Cooooo`;o0000Cooo
ool2o`0001Kooooo0_l0000Qooooo`;o0000;Oooool2o`0000Gooooo0_l0001aooooo`007_ooool0
0ol0003oooooooooo`0Booooo`;o00005oooool4o`0003Cooooo0_l0001_ooooo`;o0000LOooool0
01kooooo00?o0000ooooooooool0:oooool4o`0000[ooooo0_l0002Xooooo`;o00002_ooool2o`00
00Wooooo0_l0000Rooooo`;o00000oooool2o`0002;ooooo000Nooooo`03o`000?oooooooooo03Wo
oooo0_l0002Xooooo`;o00002_ooool2o`0000Wooooo0_l0000Rooooo`;o00000oooool2o`0002;o
oooo000Nooooo`03o`000?oooooooooo01[ooooo0_l0001Yooooo`;o00002?ooool2o`0009gooooo
0_l0000Gooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o0000JOooool2o`0000Sooooo0_l0
002Mooooo`;o00003?ooool2o`0000Wooooo000Nooooo`03o`000?oooooooooo08oooooo0_l0001`
ooooo`;o0000>Oooool2o`0000Wooooo000Nooooo`03o`000?oooooooooo07Wooooo0_l00026oooo
o`;o00002_ooool2o`0003Sooooo000Nooooo`03o`000?oooooooooo03?ooooo0_l0000Wooooo`;o
00006oooool2o`0009;ooooo0_l00008ooooo`;o00000_ooool2o`0002[ooooo000Nooooo`03o`00
0?oooooooooo03?ooooo0_l00009ooooo`;o00007?ooool2o`00013ooooo0_l0000looooo`;o0000
JOooool2o`0000;ooooo0_l0000Zooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o00008ooo
ool2o`0002kooooo0_l0000cooooo`;o00001Oooool4o`0009Wooooo000Nooooo`03o`000?oooooo
oooo01Wooooo0_l00028ooooo`;o00001Oooool2o`0009_ooooo000Nooooo`03o`000?oooooooooo
033ooooo0_l0001>ooooo`;o0000/oooool2o`00013ooooo000Nooooo`03o`000?oooooooooo033o
oooo0_l0001>ooooo`;o00001_ooool2o`0009Oooooo0_l0000Booooo`;o00004?ooool000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
00Kooooo00?o0000ooooooooool0GOooool2o`0002Wooooo0_l0000>ooooo`;o0000Qoooool4o`00
02;ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMg
MoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo01oooooo0_l0000looooo`;o0000>Oooool2
o`0000oooooo0_l00009ooooo`;o0000KOooool2o`0002;ooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0000Oooooo`;o0000R?oo
ool2o`0000Wooooo0_l0002Aooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go
0000oiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo09[ooooo0_l0000Kooooo`;o0000
Goooool2o`0002gooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<00Kooooo00?o0000ooooooooool03?ooool2o`0008cooooo0_l0000Kooooo`;o
0000Goooool2o`0002gooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGo
QhN7ooooo`08ooooo`03o`000?oooooooooo00cooooo0_l0000Jooooo`;o00002_ooool2o`0000go
oooo0_l0000Dooooo`;o00007oooool2o`0000oooooo0_l0000[ooooo`;o0000HOooool2o`0001Ko
oooo0_l0000Booooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nH
V9P02?ooool00ol0003oooooooooo`0Xooooo`;o00002_ooool2o`0000;ooooo0_l00009ooooo`;o
00005?ooool2o`0001oooooo0_l0000?ooooo`;o0000:oooool2o`00067ooooo0_l0000Fooooo`;o
00004_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@
40Kooooo00?o0000ooooooooool04?ooool2o`0001[ooooo0_l0000:ooooo`;o00000oooool2o`00
033ooooo0_l00014ooooo`;o0000T?ooool001kooooo00?o0000ooooooooool04?ooool2o`0001[o
oooo0_l00003ooooo`;o00002_ooool2o`0000kooooo0_l0000Pooooo`;o0000A?ooool2o`0004?o
oooo0_l0000Cooooo`;o00002Oooool2o`0002_ooooo000Nooooo`03o`000?oooooooooo037ooooo
0_l0000Jooooo`;o00001oooool2o`0001cooooo0_l00007ooooo`;o00006Oooool2o`0001cooooo
0_l0000looooo`;o00001?ooool2o`0001?ooooo0_l00009ooooo`;o0000:oooool001kooooo00?o
0000ooooooooool0E_ooool2o`0001Wooooo0_l000000ooooooo0000o`000007ooooo`;o00005_oo
ool2o`000003ooooool0003o000001cooooo0_l0000looooo`;o0000DOooool001kooooo00?o0000
ooooooooool0LOooool2o`0000Sooooo0_l00009ooooo`;o00003Oooool3o`0006Cooooo0_l00019
ooooo`007_ooool00ol0003oooooooooo`1Pooooo`;o00006Oooool2o`0000Wooooo0_l0000>oooo
o`;o00007_ooool2o`0000Cooooo0_l0000nooooo`;o00005?ooool2o`0000_ooooo0_l00004oooo
o`;o00008?ooool001kooooo00?o0000ooooooooool0B_ooool2o`0001Cooooo0_l0001Dooooo`;o
00001?ooool2o`0004Wooooo0_l00009ooooo`;o00002oooool2o`0000Cooooo0_l00008ooooo`;o
00005_ooool001kooooo00?o0000ooooooooool0B_ooool2o`00057ooooo0_l00018ooooo`;o0000
7_ooool2o`0002Kooooo0_l0000Fooooo`007_ooool00ol0003oooooooooo`2Mooooo`;o0000:?oo
ool2o`0001kooooo0_l0000looooo`;o00008?ooool001kooooo00?o0000ooooooooool0AOooool2
o`0005[ooooo0_l0000Tooooo`;o00001oooool2o`0003Cooooo0_l0000Mooooo`;o00004Oooool2
o`0000gooooo000Nooooo`03o`000?oooooooooo04Gooooo0_l0001Jooooo`;o0000;Oooool2o`00
03Cooooo0_l0000`ooooo`;o00003Oooool001kooooo00?o0000ooooooooool0Uoooool2o`0002_o
oooo0_l0001Zooooo`;o00005Oooool001kooooo0_l0001?ooooo`;o00007oooool2o`0002Kooooo
0_l0000[ooooo`;o0000=_ooool2o`0001;ooooo0_l0000Nooooo`;o00005Oooool001kooooo00?o
0000ooooooooool08?ooool2o`0002;ooooo0_l00008ooooo`;o00007oooool2o`0000[ooooo0_l0
001oooooo`;o00004_ooool2o`0003Gooooo000Nooooo`03o`000?oooooooooo017ooooo0_l0000=
ooooo`;o00001_ooool2o`0000Oooooo0_l0000Aooooo`;o0000=Oooool2o`0006Kooooo0_l0001R
ooooo`007_ooool3o`00017ooooo0ol0000Dooooo`;o00001oooool2o`0000oooooo0_l0000noooo
o`;o0000@_ooool2o`0001_ooooo0_l0001Rooooo`007_ooool3o`0001;ooooo0_l0000Qooooo`;o
00002oooool2o`0003kooooo0_l0000Nooooo`;o00000_ooool2o`00013ooooo0_l0000<ooooo`;o
00001?ooool2o`0000[ooooo0_l0001]ooooo`007_ooool00ol0003oooooooooo`0eooooo`;o0000
1?ooool2o`0005[ooooo0_l00009ooooo`;o00000_ooool2o`00013ooooo0_l0000Booooo`;o0000
2_ooool4o`0006_ooooo000Nooooo`03o`000?oooooooooo03_ooooo0_l0001Jooooo`;o0000@Ooo
ool2o`0005Gooooo0_l0000Dooooo`007_ooool00ol0003oooooooooo`2Aooooo`;o0000>_ooool2
o`0001cooooo0_l00014ooooo`;o00005?ooool001kooooo00?o0000ooooooooool07Oooool2o`00
0003ooooool0003o000000_ooooo0_l00002ooooo`;o0000G_ooool2o`0003[ooooo0_l0000Loooo
o`;o00000_ooool2o`0005Kooooo000Nooooo`03o`000?oooooooooo01gooooo0_l000000ooooooo
0000o`000004ooooo`;o00001Oooool2o`0000;ooooo0_l0001mooooo`;o0000?Oooool2o`0001[o
oooo0_l0000jooooo`007_ooool00ol0003oooooooooo`0Vooooo`;o0000Doooool2o`00017ooooo
0_l0000Pooooo`;o00006_ooool2o`0003gooooo0_l0000jooooo`007_ooool00ol0003ooooooooo
o`0Yooooo`;o00006_ooool2o`0003Cooooo0_l0000Aooooo`;o0000<Oooool2o`0000Wooooo0_l0
0002ooooo`;o0000MOooool001kooooo00?o0000ooooooooool0:Oooool2o`0001[ooooo0_l00004
ooooo`;o00005_ooool2o`0005cooooo0_l0000=ooooo`;o0000MOooool001kooooo00?o0000oooo
ooooool00_ooool2o`0001?ooooo0_l0000Rooooo`;o00003_ooool2o`0001Kooooo0_l0000`oooo
o`;o0000H_ooool2o`0004cooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0000Cooooo`;o
00008_ooool2o`0002Wooooo0_l0000]ooooo`;o0000H_ooool2o`00023ooooo0_l0000Zooooo`00
7_ooool00ol0003oooooooooo`1Vooooo`;o00001Oooool2o`000:cooooo0_l0000Zooooo`007_oo
ool2o`0006kooooo0_l0000Rooooo`;o0000EOooool2o`0000Kooooo0_l00005ooooo`;o0000C_oo
ool001kooooo00?o0000ooooooooool0<?ooool2o`0005oooooo0_l0001Eooooo`;o00001_ooool2
o`0000Gooooo0_l0001>ooooo`007_ooool00ol0003oooooooooo`0`ooooo`;o00002Oooool2o`00
08Gooooo0_l0001Wooooo`;o00006_ooool001kooooo00?o0000ooooooooool04oooool2o`0002Ko
oooo0_l0000`ooooo`;o00001Oooool2o`0004Sooooo0_l00002ooooo`;o0000Foooool2o`0000[o
oooo0_l0000Cooooo`;o00001Oooool001kooooo00?o0000ooooooooool04oooool2o`0002;ooooo
0_l0000dooooo`;o00001Oooool2o`0004Sooooo0_l0001Aooooo`;o00003?ooool2o`0001oooooo
0_l00005ooooo`007_ooool00ol0003oooooooooo`0Rooooo`;o00004oooool2o`0008Wooooo0_l0
0015ooooo`;o00001_ooool2o`0003Cooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l00007
ooooo`;o0000W_ooool2o`0004Gooooo0_l0000looooo`007_ooool00ol0003oooooooooo`0Ioooo
o`;o00009?ooool2o`0000[ooooo0_l0002Cooooo`;o0000IOooool001kooooo00?o0000oooooooo
ool0?oooool2o`0000[ooooo0_l00014ooooo`;o0000COooool2o`0003Kooooo0_l0000]ooooo`00
7_ooool00ol0003oooooooooo`2Aooooo`;o0000;?ooool2o`0005Oooooo0_l0000]ooooo`007_oo
ool00ol0003oooooooooo`2oooooo`;o0000Q_ooool001kooooo00?o0000ooooooooool0;_ooool2
o`0004kooooo0_l0002]ooooo`;o00006?ooool001kooooo00?o0000ooooooooool0;_ooool2o`00
03?ooooo0_l0000Iooooo`;o0000[Oooool2o`0001Sooooo000Nooooo`03o`000?oooooooooo06?o
oooo0_l0003Rooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o00003?ooool2o`0000?ooooo
0_l0001Fooooo`;o00002oooool2o`00023ooooo0_l0000Aooooo`;o0000M?ooool2o`0000Gooooo
0_l0000=ooooo`007_ooool00ol0003oooooooooo`0>ooooo`Co00002_ooool2o`0000?ooooo0_l0
000^ooooo`;o00003_ooool2o`0001Kooooo0_l0000;ooooo`;o00008?ooool2o`00017ooooo0_l0
001dooooo`;o00001Oooool2o`0000gooooo000Nooooo`;o00004Oooool2o`0002;ooooo0_l0000K
ooooo`;o00003_ooool2o`0004gooooo0_l0000Aooooo`;o00005_ooool2o`0001Sooooo0_l00002
ooooo`;o0000C?ooool001kooooo00?o0000ooooooooool0=?ooool2o`0001Wooooo0_l00007oooo
o`;o0000E_ooool2o`00017ooooo0_l0000Fooooo`;o00006?ooool2o`0000;ooooo0_l0000Soooo
o`;o00003Oooool2o`0001Sooooo000Nooooo`03o`000?oooooooooo00oooooo0_l0000nooooo`;o
00001oooool2o`0001Oooooo0_l0000booooo`;o0000Joooool2o`0000[ooooo0_l0000=ooooo`;o
00006?ooool001kooooo00?o0000ooooooooool03oooool2o`00063ooooo0_l0000booooo`;o0000
2_ooool2o`0002oooooo0_l0000^ooooo`;o0000<oooool001kooooo00?o0000ooooooooool0K?oo
ool2o`0003Cooooo0_l00006ooooo`;o00001Oooool2o`0002oooooo0_l0000oooooo`;o00008_oo
ool001kooooo00?o0000ooooooooool0K?ooool2o`0000gooooo0_l0000Uooooo`;o00001_ooool2
o`0007Oooooo0ol0000Qooooo`007_ooool00ol0003oooooooooo`1Jooooo`;o00007oooool2o`00
06Cooooo0_l00011ooooo`;o00008Oooool001kooooo00?o0000ooooooooool0F_ooool2o`0004Oo
oooo0_l0000looooo`;o0000I?ooool001kooooo00?o0000ooooooooool07Oooool2o`0000kooooo
0_l0001dooooo`;o0000A?ooool2o`0005cooooo000Nooooo`03o`000?oooooooooo01gooooo0_l0
000>ooooo`;o00001oooool2o`000;7ooooo0_l0000iooooo`;o00008Oooool001kooooo00?o0000
ooooooooool0=_ooool2o`0000[ooooo0_l0000Wooooo`;o0000]oooool2o`00027ooooo000Noooo
o`03o`000?oooooooooo04;ooooo0_l0000Gooooo`;o00003_ooool2o`0003[ooooo0_l0002Noooo
o`007_ooool00ol0003oooooooooo`0^ooooo`;o0000:oooool2o`0004[ooooo0_l00009ooooo`;o
0000Toooool001kooooo00?o0000ooooooooool00_l0000/ooooo`;o0000P_ooool2o`0009?ooooo
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o
8B4Qolc<c006ooooo`03o`000?oooooooooo00;o00003oooool2o`0000Wooooo0_l0001/ooooo`;o
0000<_ooool2o`0005?ooooo0_l0000booooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`02oooo
o`;o00003Oooool2o`0000Wooooo0_l0000Nooooo`;o0000C?ooool2o`0003;ooooo0_l0001Coooo
o`;o0000<_ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooo
ooooool000001_ooool3o`0000;ooooo0_l0000?ooooo`;o00009oooool2o`0005[ooooo0_l0002]
ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo00;ooooo0_l0000:ooooo`;o00000oooool2o`0004Oooooo0_l0
000iooooo`?o0000[Oooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0
003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`0>ooooo`;o0000BOooool2o`000004oooo
ool0003o0000o`0003Sooooo0_l0002^ooooo`000oooool01Ol@413ooooooooooooooooo410@00_o
oooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo05Wooooo0_l00002oooo
o`;o0000F?ooool2o`0002cooooo0_l00003ooooo`;o00006oooool2o`0003kooooo0003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000
ooooooooool07oooool2o`0001gooooo0_l0000fooooo`;o0000?oooool2o`0002cooooo0_l00003
ooooo`;o00006oooool2o`0003kooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool07oooool2o`0000oooooo0_l0
000<ooooo`;o0000=_ooool2o`0001_ooooo0_l0001Cooooo`;o0000GOooool001kooooo00?o0000
ooooooooool0<?ooool2o`00067ooooo0_l0001Cooooo`;o0000GOooool001kooooo00?o0000oooo
ooooool04_ooool2o`0000kooooo0_l0000dooooo`;o00001?ooool2o`0001Oooooo0_l0002boooo
o`;o00000_ooool2o`0001Kooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0000>ooooo`;o
0000=?ooool2o`0000Cooooo0_l0000Gooooo`;o00001?ooool2o`0002kooooo0_l0000Rooooo`;o
0000F?ooool2o`0000;ooooo0_l0000Fooooo`007_ooool00ol0003oooooooooo`1mooooo`;o0000
;_ooool2o`0002;ooooo0_l0001dooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo07_ooooo0_l0000/ooooo`Co0000V_ooool001kooooo00?o0000oooo
ooooool0>oooool2o`0001Cooooo0_l0000Xooooo`;o0000;?ooool4o`0007Gooooo0_l0000Soooo
o`007_ooool00ol0003oooooooooo`0Oooooo`;o00006_ooool2o`0001Cooooo0_l0001fooooo`;o
00004Oooool2o`0002cooooo0_l0000Fooooo`;o00008oooool001gooooo0_l0000Qooooo`Co0000
@Oooool2o`0006?ooooo0_l0000Aooooo`;o0000;?ooool2o`0003Gooooo0_l00004ooooo`007Ooo
ool2o`0000Gooooo0_l0000Looooo`;o0000@Oooool2o`0003kooooo0_l0000booooo`;o0000:Ooo
ool2o`0003Wooooo0_l000000ooooooo0000o`000004ooooo`007_ooool00ol0003oooooooooo`03
ooooo`;o00008Oooool2o`0007cooooo0_l0000booooo`;o0000:Oooool2o`0003Wooooo0_l00007
ooooo`007_ooool2o`0001[ooooo0_l00002ooooo`;o00001?ooool2o`000003ooooool0003o0000
0?[ooooo0_l00002ooooo`;o00007oooool001kooooo00?o0000ooooooooool06Oooool2o`0000;o
oooo0_l00004ooooo`;o0000=_ooool2o`0007_ooooo0_l00018ooooo`;o00000_ooool2o`0001oo
oooo000Nooooo`03o`000?oooooooooo01Kooooo0_l0000Fooooo`;o00002?ooool2o`00027ooooo
0_l0001kooooo`;o0000=?ooool2o`0002Wooooo0_l0000<ooooo`007_ooool00ol0003ooooooooo
o`0@ooooo`Co00000_ooool2o`0001Kooooo0_l00008ooooo`;o0000Coooool2o`0002_ooooo0_l0
000iooooo`;o00006oooool2o`0002Wooooo0_l00005ooooo`;o00001Oooool001kooooo00?o0000
ooooooooool04?ooool4o`0007Gooooo0_l0000[ooooo`;o00004oooool2o`0000[ooooo0_l0000H
ooooo`;o0000COooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo04oooooo0_l0001]oooo
o`;o00002oooool2o`0000[ooooo0_l0001^ooooo`007_ooool00ol0003oooooooooo`1?ooooo`;o
0000@oooool2o`0002;ooooo0_l00004ooooo`;o0000Qoooool001kooooo00?o0000ooooooooool0
8oooool2o`0005[ooooo0_l0000Cooooo`;o00004oooool2o`0000;ooooo0_l00009ooooo`;o0000
Boooool2o`00043ooooo000Nooooo`03o`000?oooooooooo02?ooooo0_l0000?ooooo`;o0000BOoo
ool2o`0002Sooooo0_l00002ooooo`;o0000=?ooool2o`00023ooooo0_l0000?ooooo`;o00003_oo
ool2o`0001oooooo000Nooooo`03o`000?oooooooooo03Cooooo0_l0000Nooooo`;o00005oooool2
o`0001Gooooo0_l0001Mooooo`;o00006?ooool2o`0001Oooooo0_l0000>ooooo`;o00000oooool2
o`0001[ooooo000Nooooo`03o`000?oooooooooo053ooooo0_l00002ooooo`;o00005oooool2o`00
00Cooooo0_l0000?ooooo`;o0000Moooool2o`00017ooooo0_l0000Iooooo`;o00006_ooool001ko
oooo00?o0000ooooooooool0?oooool2o`0000;ooooo0_l0000;ooooo`?o00008?ooool2o`00053o
oooo0_l00019ooooo`;o00004Oooool2o`0002;ooooo000Nooooo`?o000000?oooooo`000?l00000
??ooool2o`000004ooooool0003o0000o`0000cooooo0_l00008ooooo`?o0000Ioooool2o`0005;o
oooo0_l00008ooooo`;o00008_ooool001kooooo0ol000000ooooooo0000o`00000oooooo`;o0000
5oooool3o`0000Oooooo0_l00005ooooo`;o0000Zoooool2o`0002cooooo000Nooooo`03o`000?oo
oooooooo04[ooooo0_l0000Iooooo`;o00001Oooool2o`000=Wooooo000Nooooo`03o`000?oooooo
oooo04[ooooo0_l0000oooooo`;o0000^_ooool001kooooo0_l0001Nooooo`;o0000;?ooool2o`00
01gooooo0_l0001mooooo`;o00002?ooool2o`0001;ooooo000Nooooo`03o`000?oooooooooo04ko
oooo0_l0000=ooooo`;o00003oooool2o`0003[ooooo0_l0001looooo`?o00002?ooool2o`0001;o
oooo000Nooooo`03o`000?oooooooooo00oooooo0_l0000mooooo`;o00007_ooool2o`000;?ooooo
0_l00003ooooo`;o00007Oooool001kooooo00?o0000ooooooooool03oooool2o`0002Kooooo0_l0
002Kooooo`;o0000>oooool2o`00013ooooo0_l0000Rooooo`007_ooool00ol0003oooooooooo`0g
ooooo`;o00008oooool2o`0007Kooooo0_l0000kooooo`;o0000=?ooool001kooooo00?o0000oooo
ooooool0G?ooool2o`0006Wooooo0_l0000Pooooo`;o0000G?ooool001kooooo00?o0000oooooooo
ool01?ooool2o`0003_ooooo0_l0000Booooo`;o0000L?ooool2o`00023ooooo0_l0001Looooo`00
7_ooool00ol0003oooooooooo`04ooooo`;o00000oooool2o`0003Kooooo0_l0000Booooo`;o0000
COooool2o`000:7ooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0000Booooo`;o0000H_oo
ool2o`0001Gooooo0_l00005ooooo`;o00000oooool2o`0006Wooooo0_l0000Pooooo`;o00005?oo
ool001kooooo00?o0000ooooooooool07Oooool2o`0000[ooooo0_l0000Dooooo`;o0000@?ooool2
o`0001Gooooo0_l00005ooooo`;o00007oooool2o`0004gooooo0_l0000Pooooo`;o00005?ooool0
01kooooo00?o0000ooooooooool09Oooool2o`0000;ooooo0_l0000;ooooo`;o00001oooool2o`00
07oooooo0_l0000Iooooo`;o0000>Oooool2o`0002oooooo000Nooooo`03o`000?oooooooooo00So
oooo0_l0000Kooooo`;o00001_ooool2o`0000Oooooo0_l0001eooooo`;o00003_ooool2o`0001co
oooo0_l0000iooooo`?o0000;_ooool001kooooo00?o0000ooooooooool02?ooool2o`000003oooo
ool0003o000001;ooooo0_l0000<ooooo`;o0000@_ooool2o`0000_ooooo0_l0000]ooooo`;o0000
3_ooool2o`0002?ooooo0_l0000cooooo`;o0000;_ooool001kooooo00?o0000ooooooooool02ooo
ool2o`0001;ooooo0_l0000cooooo`;o00006oooool2o`0000_ooooo0_l00003ooooo`;o00008ooo
ool2o`0003Sooooo0_l0001Sooooo`007_ooool00ol0003oooooooooo`11ooooo`;o00004Oooool2
o`0002gooooo0_l0000Sooooo`;o0000WOooool001kooooo00?o0000ooooooooool06_ooool2o`00
01?ooooo0_l0000@ooooo`;o0000C_ooool2o`000;Cooooo000Nooooo`;o00006oooool2o`0001?o
oooo0_l0001Pooooo`;o0000ROooool2o`0002Wooooo000Nooooo`03o`000?oooooooooo073ooooo
0_l0000[ooooo`;o00008_ooool2o`0001Oooooo0_l00010ooooo`;o0000:Oooool001kooooo0_l0
001aooooo`;o0000:oooool2o`0002;ooooo0_l0000Gooooo`;o0000Joooool001kooooo1?l0000i
ooooo`;o0000VOooool2o`0003Cooooo0_l0000jooooo`007_ooool01?l0003oooooo`000?l0000i
ooooo`;o0000>oooool2o`0001gooooo0_l0000mooooo`;o0000=?ooool2o`0003[ooooo000Noooo
o`03o`000?oooooooooo07Oooooo0_l0000Mooooo`;o0000=?ooool2o`0007Wooooo000Nooooo`03
o`000?oooooooooo0<cooooo0_l0000gooooo`;o0000@?ooool001kooooo00?o0000ooooooooool0
>Oooool2o`0002Wooooo0_l00005ooooo`;o0000V?ooool2o`00043ooooo000Nooooo`03o`000?oo
oooooooo03Wooooo0_l0000Vooooo`;o000000?oooooo`000?l000001Oooool2o`0002_ooooo0_l0
002]ooooo`007_ooool00ol0003oooooooooo`1Qooooo`;o00002oooool2o`0000cooooo0_l0000J
ooooo`;o00001oooool2o`0001;ooooo0_l0000dooooo`;o0000AOooool2o`0000Gooooo0_l0000<
ooooo`007_ooool00ol0003oooooooooo`1^ooooo`;o00003?ooool2o`0002?ooooo0_l0000Boooo
o`;o0000:oooool2o`0000Oooooo0_l00015ooooo`;o00001Oooool2o`0000cooooo000Nooooo`03
o`000?oooooooooo0;Oooooo0_l0000Yooooo`;o00003?ooool2o`000003ooooool0003o000001go
oooo0_l0000cooooo`007_ooool00ol0003oooooooooo`0Xooooo`;o0000SOooool2o`0003Oooooo
0_l000000ooooooo0000o`00000Mooooo`;o00000_ooool2o`0000kooooo0_l0000Oooooo`007_oo
ool00ol0003oooooooooo`0Xooooo`;o0000Doooool2o`0009Oooooo0_l00009ooooo`;o00000ooo
ool2o`0001oooooo000Dooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`1J
ooooo`;o00008Oooool4o`0000;ooooo0_l0000]ooooo`;o0000KOooool2o`0002Cooooo000Foooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0F_ooool2o`0002?ooooo0_l00002oooo
o`;o0000;Oooool2o`0009?ooooo000Fooooo`03o`000?oooooooooo00Gooooo0ol000000ooooooo
0000o`00000/ooooo`;o0000ZOooool2o`0006_ooooo000Fooooo`03o`000?oooooooooo00Wooooo
0_l0000/ooooo`;o0000ZOooool2o`0006_ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?oo
ool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooo
oe3ooooo000Dooooo`03oeEEEOmVIVKo00000?ooooooD_ooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.11041 .67901 Mdot
.82918 .4323 Mdot
.09878 .50099 Mdot
.05459 .03184 Mdot
.37945 .42086 Mdot
.24806 .04492 Mdot
.62368 .0186 Mdot
.25961 .46186 Mdot
.30988 .97293 Mdot
.77104 .00744 Mdot
.32879 .21171 Mdot
.46315 .09664 Mdot
.2311 .53696 Mdot
.63586 .66278 Mdot
.15304 .03591 Mdot
.58504 .63021 Mdot
.76326 .61979 Mdot
.34711 .5788 Mdot
.14193 .60858 Mdot
.09437 .11877 Mdot
.82636 .6313 Mdot
.31746 .11617 Mdot
.48101 .42324 Mdot
.84817 .02517 Mdot
.25737 .88194 Mdot
.205 .36793 Mdot
.11922 .8403 Mdot
.59654 .7292 Mdot
.34904 .21596 Mdot
.25637 .14731 Mdot
.21872 .6078 Mdot
.16945 .0255 Mdot
.38944 .98009 Mdot
.85627 .91242 Mdot
.91093 .55506 Mdot
.01328 .88805 Mdot
.6398 .67434 Mdot
.80839 .52496 Mdot
.52707 .83281 Mdot
.19634 .79758 Mdot
.18747 .61021 Mdot
.9507 .64678 Mdot
.97446 .00073 Mdot
.78286 .61567 Mdot
.5624 .0289 Mdot
.93874 .70771 Mdot
.65834 .46699 Mdot
.93823 .8223 Mdot
.02642 .79751 Mdot
.1305 .29393 Mdot
.46918 .96501 Mdot
.93296 .4952 Mdot
.2902 .35328 Mdot
.99756 .84679 Mdot
.32334 .35055 Mdot
.21008 .22767 Mdot
.76039 .31796 Mdot
.27236 .51696 Mdot
.10732 .84995 Mdot
.34463 .69578 Mdot
.09186 .05454 Mdot
.22764 .4138 Mdot
.60441 .09471 Mdot
.29251 .91323 Mdot
.3065 .74696 Mdot
.312 .06524 Mdot
.99167 .39881 Mdot
.11132 .8394 Mdot
.22814 .07262 Mdot
.82473 .32065 Mdot
.13012 .22487 Mdot
.46626 .62241 Mdot
.04556 .16605 Mdot
.25127 .21862 Mdot
.42687 .07215 Mdot
.95627 .30428 Mdot
.12825 .32985 Mdot
.64152 .23513 Mdot
.14249 .9259 Mdot
.53018 .39894 Mdot
.92245 .8534 Mdot
.70784 .07916 Mdot
.79049 .62408 Mdot
.23782 .45291 Mdot
.74797 .45557 Mdot
.99326 .22785 Mdot
.30568 .39169 Mdot
.0452 .92164 Mdot
.19431 .05589 Mdot
.38826 .68079 Mdot
.05984 .12984 Mdot
.85438 .28444 Mdot
.14696 .2825 Mdot
.14661 .21205 Mdot
.35203 .65022 Mdot
.91435 .76337 Mdot
.61029 .18844 Mdot
.91996 .53358 Mdot
.29484 .80846 Mdot
.88489 .60606 Mdot
.11967 .74577 Mdot
.47633 .92817 Mdot
.06785 .61473 Mdot
.62083 .63974 Mdot
.91409 .33318 Mdot
.47737 .43025 Mdot
.54752 .67929 Mdot
.57298 .66309 Mdot
.94896 .49081 Mdot
.66432 .13074 Mdot
.63607 .6832 Mdot
.7937 .51644 Mdot
.5248 .94149 Mdot
.29749 .59228 Mdot
.47015 .32545 Mdot
.66591 .96206 Mdot
.55685 .99509 Mdot
.18852 .52845 Mdot
.01428 .30763 Mdot
.59322 .86742 Mdot
.07243 .8202 Mdot
.94395 .73494 Mdot
.41332 .13266 Mdot
.15057 .2143 Mdot
.88536 .19752 Mdot
.85065 .61586 Mdot
.39899 .87655 Mdot
.17654 .66255 Mdot
.8537 .88368 Mdot
.99478 .13402 Mdot
.84484 .56922 Mdot
.38387 .26873 Mdot
.77813 .75076 Mdot
.44542 .53666 Mdot
.35316 .61398 Mdot
.3039 .32418 Mdot
.46183 .42165 Mdot
.45542 .69699 Mdot
.07465 .5469 Mdot
.2909 .03489 Mdot
.21552 .66127 Mdot
.2952 .90311 Mdot
.37385 .08864 Mdot
.91794 .62882 Mdot
.59781 .33615 Mdot
.45115 .09552 Mdot
.24077 .72232 Mdot
.155 .77439 Mdot
.77212 .3015 Mdot
.68316 .07727 Mdot
.70587 .75887 Mdot
.3919 .03694 Mdot
.48588 .09607 Mdot
.10412 .13152 Mdot
.12293 .001 Mdot
.19119 .50193 Mdot
.50584 .66178 Mdot
.7302 .40021 Mdot
.26981 .94143 Mdot
.56641 .63044 Mdot
.48868 .63421 Mdot
.89372 .55517 Mdot
.79203 .88122 Mdot
.47941 .52309 Mdot
.28853 .78549 Mdot
.38433 .39119 Mdot
.17967 .77779 Mdot
.20714 .88548 Mdot
.65981 .11422 Mdot
.46608 .48452 Mdot
.38803 .16531 Mdot
.90962 .85277 Mdot
.89794 .53295 Mdot
.01621 .29278 Mdot
.11827 .65594 Mdot
.51048 .77151 Mdot
.81796 .87349 Mdot
.13748 .39036 Mdot
.6307 .09371 Mdot
.92574 .50143 Mdot
.97962 .97862 Mdot
.43711 .02052 Mdot
.56977 .80823 Mdot
.54189 .16444 Mdot
.68562 .27195 Mdot
.5291 .87374 Mdot
.56593 .62228 Mdot
.02577 .09701 Mdot
.76643 .7487 Mdot
.89933 .71047 Mdot
.14043 .65768 Mdot
.97341 .21178 Mdot
.16563 .67694 Mdot
.51919 .19271 Mdot
.5748 .87114 Mdot
.98628 .0276 Mdot
.90333 .58918 Mdot
.43455 .15311 Mdot
.31841 .97109 Mdot
.41448 .05809 Mdot
.55145 .21792 Mdot
.52262 .34511 Mdot
.41786 .56357 Mdot
.55466 .13033 Mdot
.26052 .88655 Mdot
.04319 .93455 Mdot
.6744 .02393 Mdot
.06496 .90543 Mdot
.78332 .42043 Mdot
.60734 .74977 Mdot
.45042 .45624 Mdot
.19387 .6908 Mdot
.90382 .23027 Mdot
.66465 .34368 Mdot
.47232 .66381 Mdot
.11012 .21597 Mdot
.21602 .78141 Mdot
.07779 .27988 Mdot
.52936 .76242 Mdot
.02393 .37256 Mdot
.75711 .3362 Mdot
.39586 .61952 Mdot
.29175 .88811 Mdot
.20889 .9269 Mdot
.38738 .6523 Mdot
.52972 .581 Mdot
.92025 .98698 Mdot
.42862 .36701 Mdot
.69591 .20301 Mdot
.36181 .08235 Mdot
.16575 .44555 Mdot
.34279 .71072 Mdot
.3952 .09779 Mdot
.95514 .09077 Mdot
.10858 .21371 Mdot
.74177 .16346 Mdot
.71113 .55672 Mdot
.20319 .57791 Mdot
.80655 .56775 Mdot
.76546 .21659 Mdot
.11584 .36878 Mdot
.39561 .12713 Mdot
.95743 .92502 Mdot
.06297 .42095 Mdot
.53858 .82384 Mdot
.11104 .33062 Mdot
.43625 .60762 Mdot
.35715 .1627 Mdot
.72697 .05678 Mdot
.16443 .58537 Mdot
.93592 .4815 Mdot
.38531 .37334 Mdot
.82619 .11855 Mdot
.99612 .23716 Mdot
.8794 .18884 Mdot
.95131 .82187 Mdot
.32738 .36813 Mdot
.84226 .48942 Mdot
.89852 .75414 Mdot
.47132 .32408 Mdot
.16281 .70306 Mdot
.31389 .73793 Mdot
.22868 .22429 Mdot
.93023 .36752 Mdot
.39382 .10689 Mdot
.94122 .12797 Mdot
.51071 .92433 Mdot
.0047 .30586 Mdot
.19042 .55595 Mdot
.16366 .81593 Mdot
.29123 .80577 Mdot
.68157 .49007 Mdot
.1436 .09595 Mdot
.35484 .7558 Mdot
.92312 .87648 Mdot
.4255 .39255 Mdot
.50511 .76257 Mdot
.49045 .26023 Mdot
.00548 .84467 Mdot
.49007 .95618 Mdot
.80535 .28379 Mdot
.33852 .13347 Mdot
.49832 .48601 Mdot
.64932 .64406 Mdot
.36452 .38715 Mdot
.28985 .88891 Mdot
.4497 .5106 Mdot
.86534 .49855 Mdot
.95665 .7444 Mdot
.36113 .23381 Mdot
.96253 .90062 Mdot
.86377 .28082 Mdot
.15313 .61398 Mdot
.51971 .14489 Mdot
.63299 .13107 Mdot
.87347 .50258 Mdot
.25994 .74896 Mdot
.56259 .61517 Mdot
.80388 .24088 Mdot
.70984 .1185 Mdot
.86366 .49672 Mdot
.342 .88162 Mdot
.91158 .59285 Mdot
.47512 .59347 Mdot
.75973 .98766 Mdot
.96416 .45113 Mdot
.13255 .84817 Mdot
.09809 .94454 Mdot
.86343 .10549 Mdot
.50851 .33331 Mdot
.06648 .86047 Mdot
.80056 .21955 Mdot
.20154 .37324 Mdot
.44508 .33983 Mdot
.28534 .77001 Mdot
.97845 .74483 Mdot
.52118 .78471 Mdot
.01478 .2913 Mdot
.39358 .94103 Mdot
.91881 .34542 Mdot
.53292 .83504 Mdot
.39458 .01537 Mdot
.47524 .97618 Mdot
.59239 .79388 Mdot
.28315 .60655 Mdot
.15856 .45984 Mdot
.00761 .84267 Mdot
.18355 .71204 Mdot
.4584 .05575 Mdot
.1815 .4267 Mdot
.06888 .11648 Mdot
.25968 .07125 Mdot
.51638 .28205 Mdot
.85633 .06582 Mdot
.04476 .30943 Mdot
.25347 .26991 Mdot
.74973 .69941 Mdot
.11204 .80998 Mdot
.7555 .86285 Mdot
.92697 .0991 Mdot
.28342 .80828 Mdot
.7469 .67546 Mdot
.22357 .68544 Mdot
.48064 .59991 Mdot
.70569 .39848 Mdot
.62874 .54059 Mdot
.66236 .09562 Mdot
.37922 .27169 Mdot
.917 .39479 Mdot
.27403 .46369 Mdot
.1682 .53215 Mdot
.35117 .36748 Mdot
.87902 .72426 Mdot
.6007 .68616 Mdot
.642 .0433 Mdot
.12432 .08142 Mdot
.94988 .63367 Mdot
.47188 .54475 Mdot
.2717 .54023 Mdot
.10504 .27163 Mdot
.35811 .14538 Mdot
.826 .80941 Mdot
.20046 .61428 Mdot
.45351 .44824 Mdot
.32061 .89352 Mdot
.86041 .75706 Mdot
.67491 .85518 Mdot
.73307 .67213 Mdot
.73858 .21636 Mdot
.25572 .12627 Mdot
.45455 .67129 Mdot
.15827 .85678 Mdot
.11667 .52804 Mdot
.33242 .04745 Mdot
.91278 .9091 Mdot
.87591 .59996 Mdot
.56972 .02042 Mdot
.02825 .84699 Mdot
.89545 .16485 Mdot
.28479 .16951 Mdot
.16184 .94431 Mdot
.03761 .04109 Mdot
.69671 .26775 Mdot
.87611 .18532 Mdot
.5845 .74441 Mdot
.53742 .13459 Mdot
.68525 .83956 Mdot
.66867 .53016 Mdot
.12259 .81957 Mdot
.64793 .68507 Mdot
.22011 .65401 Mdot
.36627 .51392 Mdot
.07692 .71174 Mdot
.33549 .47163 Mdot
.36302 .44055 Mdot
.46076 .28443 Mdot
.77879 .68899 Mdot
.92646 .14987 Mdot
.09517 .85241 Mdot
.24983 .61536 Mdot
.97864 .03238 Mdot
.58999 .93674 Mdot
.75078 .37258 Mdot
.22613 .42588 Mdot
.67932 .66724 Mdot
.8896 .9501 Mdot
.31446 .22789 Mdot
.40936 .66025 Mdot
.52598 .5396 Mdot
.48018 .51643 Mdot
.44425 .67992 Mdot
.23954 .89579 Mdot
.47209 .64716 Mdot
.6375 .96954 Mdot
.73202 .27086 Mdot
.41288 .54494 Mdot
.05691 .60731 Mdot
.52566 .59482 Mdot
.73267 .37182 Mdot
.12933 .92876 Mdot
.19489 .83727 Mdot
.62659 .41503 Mdot
.74052 .1561 Mdot
.38534 .52268 Mdot
.25784 .50254 Mdot
.75056 .55515 Mdot
.52569 .22653 Mdot
.32708 .01264 Mdot
.47572 .6196 Mdot
.79336 .41433 Mdot
.75402 .24496 Mdot
.66683 .48386 Mdot
.55233 .40836 Mdot
.04534 .06679 Mdot
.8168 .25381 Mdot
.64045 .54706 Mdot
.54799 .74896 Mdot
.90734 .98892 Mdot
.03467 .52285 Mdot
.56419 .97963 Mdot
.53179 .90189 Mdot
.78477 .55386 Mdot
.79051 .64979 Mdot
.11623 .06801 Mdot
.22793 .24684 Mdot
.07991 .99944 Mdot
.39977 .99465 Mdot
.41685 .45806 Mdot
.85114 .23926 Mdot
.5144 .46866 Mdot
.83143 .71512 Mdot
.9597 .49198 Mdot
.28146 .8209 Mdot
.17978 .93082 Mdot
.49268 .16436 Mdot
.07444 .8611 Mdot
.27152 .92051 Mdot
.00434 .86125 Mdot
.8731 .93179 Mdot
.56086 .4048 Mdot
.02545 .69325 Mdot
.05201 .93712 Mdot
.19061 .96918 Mdot
.10282 .45102 Mdot
.90177 .15456 Mdot
.9169 .51653 Mdot
.39181 .99226 Mdot
.85348 .64937 Mdot
.13226 .06425 Mdot
.86296 .79328 Mdot
.26432 .13429 Mdot
.28254 .39308 Mdot
.24678 .45066 Mdot
.24262 .45244 Mdot
.07403 .47628 Mdot
.16037 .99651 Mdot
.1657 .32595 Mdot
.24035 .48599 Mdot
.7616 .32851 Mdot
.38452 .83422 Mdot
.634 .26104 Mdot
.53214 .04154 Mdot
.37014 .1236 Mdot
.24977 .64968 Mdot
.1344 .68133 Mdot
.01328 .20108 Mdot
.06813 .20506 Mdot
.8533 .2034 Mdot
.91312 .88665 Mdot
.60402 .71619 Mdot
.15052 .55372 Mdot
.21946 .88476 Mdot
.50053 .28746 Mdot
.6737 .84834 Mdot
.13767 .15955 Mdot
.42168 .18918 Mdot
.01584 .48144 Mdot
.40955 .99541 Mdot
.94682 .2725 Mdot
.55572 .78786 Mdot
.05227 .39035 Mdot
.95835 .07166 Mdot
.91201 .83745 Mdot
.73344 .18652 Mdot
.38956 .54747 Mdot
.0628 .34071 Mdot
.25975 .39251 Mdot
.62484 .14412 Mdot
.25213 .90513 Mdot
.21236 .15158 Mdot
.30427 .62898 Mdot
.64316 .36143 Mdot
.26769 .24159 Mdot
.69515 .28899 Mdot
.3588 .40952 Mdot
.96499 .10713 Mdot
.98273 .85947 Mdot
.91529 .76732 Mdot
.71211 .46795 Mdot
.27507 .61885 Mdot
.44875 .56628 Mdot
.08264 .46886 Mdot
.15381 .93353 Mdot
.4187 .09937 Mdot
.88728 .69178 Mdot
.72985 .80837 Mdot
.50952 .28805 Mdot
.77353 .69861 Mdot
.53426 .43259 Mdot
.87498 .93593 Mdot
.83772 .96184 Mdot
.58588 .31069 Mdot
.36911 .39593 Mdot
.51082 .84696 Mdot
.22893 .45938 Mdot
.1052 .74582 Mdot
.34015 .7615 Mdot
.35545 .93936 Mdot
.83632 .46986 Mdot
.58752 .23149 Mdot
.29016 .03774 Mdot
.72447 .29685 Mdot
.44792 .08125 Mdot
.14016 .98434 Mdot
.0913 .69183 Mdot
.61243 .1393 Mdot
.84969 .23343 Mdot
.51084 .39867 Mdot
.49195 .47601 Mdot
.16587 .46332 Mdot
.66577 .00827 Mdot
.56371 .22093 Mdot
.37513 .96401 Mdot
.8513 .92573 Mdot
.93861 .88001 Mdot
.70603 .94204 Mdot
.8484 .19112 Mdot
.10464 .79388 Mdot
.00783 .95493 Mdot
.56911 .39718 Mdot
.48359 .48666 Mdot
.40907 .94246 Mdot
.8287 .4799 Mdot
.85694 .71103 Mdot
.43267 .52324 Mdot
.01977 .79321 Mdot
.50307 .63947 Mdot
.29107 .85646 Mdot
.66171 .44999 Mdot
.20397 .05574 Mdot
.66254 .49489 Mdot
.6152 .66227 Mdot
.17522 .00978 Mdot
.20437 .72228 Mdot
.34069 .53113 Mdot
.35019 .01092 Mdot
.91355 .00972 Mdot
.34552 .21638 Mdot
.38671 .36993 Mdot
.06077 .36632 Mdot
.72722 .91953 Mdot
.84963 .30258 Mdot
.0763 .4191 Mdot
.22555 .64044 Mdot
.89379 .40635 Mdot
.03043 .91778 Mdot
.53843 .87358 Mdot
.66102 .914 Mdot
.6338 .86471 Mdot
.31355 .6879 Mdot
.24494 .49485 Mdot
.26685 .32768 Mdot
.50619 .57971 Mdot
.40985 .02044 Mdot
.44729 .16034 Mdot
.19594 .38337 Mdot
.55153 .75837 Mdot
.17725 .4598 Mdot
.02293 .88803 Mdot
.49171 .54786 Mdot
.36727 .02715 Mdot
.18635 .85772 Mdot
.13701 .53303 Mdot
.91921 .53586 Mdot
.60147 .95588 Mdot
.48566 .52012 Mdot
.15767 .78688 Mdot
.30808 .13989 Mdot
.58997 .03071 Mdot
.14356 .68754 Mdot
.57804 .13703 Mdot
.63038 .13845 Mdot
.21248 .10854 Mdot
.44363 .27976 Mdot
.09707 .58235 Mdot
.52584 .74252 Mdot
.46769 .62667 Mdot
.04166 .22599 Mdot
.31583 .84459 Mdot
.72605 .08891 Mdot
.72578 .8154 Mdot
.58859 .39531 Mdot
.15347 .67576 Mdot
.96559 .25546 Mdot
.9436 .56238 Mdot
.50438 .97937 Mdot
.85931 .9845 Mdot
.98323 .22961 Mdot
.37235 .35507 Mdot
.9507 .00342 Mdot
.06799 .51195 Mdot
.21428 .91848 Mdot
.32145 .69457 Mdot
.60779 .52351 Mdot
.18503 .01536 Mdot
.65551 .26149 Mdot
.24156 .45928 Mdot
.14631 .29192 Mdot
.3813 .47592 Mdot
.1676 .05332 Mdot
.016 .11951 Mdot
.2236 .04889 Mdot
.9607 .60913 Mdot
.01423 .13145 Mdot
.61955 .92014 Mdot
.3871 .60841 Mdot
.43564 .89943 Mdot
.73705 .34075 Mdot
.20689 .44536 Mdot
.59021 .05813 Mdot
.81799 .96975 Mdot
.42231 .00276 Mdot
.81081 .84611 Mdot
.2133 .9439 Mdot
.85073 .23398 Mdot
.20228 .81256 Mdot
.22586 .32558 Mdot
.81056 .20545 Mdot
.78206 .41906 Mdot
.08468 .85644 Mdot
.57069 .98767 Mdot
.47358 .80075 Mdot
.75878 .02333 Mdot
.06172 .80331 Mdot
.9592 .17135 Mdot
.84798 .85753 Mdot
.11229 .93495 Mdot
.63382 .04666 Mdot
.88428 .61527 Mdot
.83334 .84099 Mdot
.10351 .19556 Mdot
.74859 .98824 Mdot
.51672 .21022 Mdot
.27167 .17779 Mdot
.76079 .19679 Mdot
.22059 .38649 Mdot
.80438 .02834 Mdot
.37176 .52287 Mdot
.69513 .08897 Mdot
.74266 .47534 Mdot
.82572 .46351 Mdot
.91881 .63646 Mdot
.7237 .26649 Mdot
.16658 .65642 Mdot
.20356 .05242 Mdot
.89505 .47916 Mdot
.42934 .86375 Mdot
.67 .10082 Mdot
.62683 .83943 Mdot
.29195 .57434 Mdot
.94408 .75384 Mdot
.55253 .09702 Mdot
.11796 .28847 Mdot
.64021 .45539 Mdot
.38311 .01936 Mdot
.47445 .79925 Mdot
.19397 .95735 Mdot
.58695 .32054 Mdot
.74707 .10397 Mdot
.91617 .22295 Mdot
.12231 .262 Mdot
.60937 .64857 Mdot
.1884 .50843 Mdot
.07419 .55232 Mdot
.07627 .22028 Mdot
.41141 .09126 Mdot
.6823 .20094 Mdot
.93674 .29082 Mdot
.48511 .24147 Mdot
.33981 .97134 Mdot
.73804 .14675 Mdot
.42089 .74343 Mdot
.61588 .887 Mdot
.80694 .10416 Mdot
.43156 .37801 Mdot
.7504 .54388 Mdot
.3653 .14991 Mdot
.32285 .45559 Mdot
.68081 .95731 Mdot
.3905 .15505 Mdot
.19471 .70529 Mdot
.05524 .18866 Mdot
.44662 .56264 Mdot
.61622 .44248 Mdot
.83662 .67629 Mdot
.81238 .34353 Mdot
.38788 .3049 Mdot
.07543 .79981 Mdot
.02974 .14846 Mdot
.73684 .34143 Mdot
.33709 .19487 Mdot
.33952 .18113 Mdot
.15302 .49409 Mdot
.29004 .99318 Mdot
.68246 .93543 Mdot
.66261 .55081 Mdot
.85531 .24858 Mdot
.85372 .2061 Mdot
.45463 .94822 Mdot
.79033 .40224 Mdot
.43102 .79473 Mdot
.06051 .05817 Mdot
.11526 .59688 Mdot
.7093 .87884 Mdot
.9648 .10347 Mdot
.4135 .8828 Mdot
.27356 .1714 Mdot
.75668 .32386 Mdot
.40489 .92927 Mdot
.905 .12387 Mdot
.9596 .9789 Mdot
.12268 .71745 Mdot
.5047 .1825 Mdot
.07139 .65776 Mdot
.40491 .58771 Mdot
.33902 .78237 Mdot
.44137 .48842 Mdot
.93323 .90255 Mdot
.18198 .31785 Mdot
.17245 .57309 Mdot
.76557 .38253 Mdot
.26162 .45485 Mdot
.81485 .40435 Mdot
.15681 .73547 Mdot
.30308 .22028 Mdot
.09896 .07742 Mdot
.89842 .62969 Mdot
.74717 .29526 Mdot
.43663 .14482 Mdot
.82448 .39508 Mdot
.2602 .83776 Mdot
.65077 .8235 Mdot
.48798 .45335 Mdot
.38572 .37363 Mdot
.67991 .04837 Mdot
.23885 .63249 Mdot
.37407 .82217 Mdot
.15627 .55508 Mdot
.48298 .18454 Mdot
.39652 .25323 Mdot
.05455 .03681 Mdot
.5691 .86074 Mdot
.78303 .20454 Mdot
.92672 .03649 Mdot
.27929 .75387 Mdot
.5183 .66238 Mdot
.59078 .70809 Mdot
.28851 .02779 Mdot
.21781 .8885 Mdot
.14995 .47818 Mdot
.72366 .70113 Mdot
.73883 .2186 Mdot
.67398 .66298 Mdot
.16736 .36674 Mdot
.8982 .46347 Mdot
.24073 .33025 Mdot
.60352 .70706 Mdot
.71027 .65794 Mdot
.02135 .99699 Mdot
.42077 .62559 Mdot
.79299 .11579 Mdot
.28978 .14963 Mdot
.08157 .40957 Mdot
.54108 .93637 Mdot
.38204 .74241 Mdot
.38373 .57189 Mdot
.48703 .28223 Mdot
.15103 .25007 Mdot
.88608 .57216 Mdot
.42732 .58819 Mdot
.87404 .57317 Mdot
.01622 .96021 Mdot
.08641 .46867 Mdot
.71641 .80906 Mdot
.0116 .05759 Mdot
.17468 .87426 Mdot
.61256 .3118 Mdot
.78171 .30006 Mdot
.12756 .02844 Mdot
.63155 .05771 Mdot
.2393 .45994 Mdot
.20537 .46837 Mdot
.36214 .88409 Mdot
.19848 .50376 Mdot
.29212 .41832 Mdot
.46804 .68991 Mdot
.2902 .35911 Mdot
.29872 .82161 Mdot
.67438 .04539 Mdot
.51029 .51805 Mdot
.55198 .01195 Mdot
.88871 .46319 Mdot
.31254 .55008 Mdot
.67859 .00397 Mdot
.95614 .6703 Mdot
.4781 .4961 Mdot
.6496 .25305 Mdot
.02652 .80086 Mdot
.34749 .90503 Mdot
.70391 .98686 Mdot
.67004 .86502 Mdot
.19223 .46703 Mdot
.1246 .85168 Mdot
.30102 .99992 Mdot
.79743 .29944 Mdot
.61163 .01117 Mdot
.85721 .62745 Mdot
.13897 .51484 Mdot
.20581 .38333 Mdot
.12294 .71621 Mdot
.85037 .47186 Mdot
.39645 .73295 Mdot
.17539 .60878 Mdot
.21766 .27664 Mdot
.06449 .75901 Mdot
.91632 .26751 Mdot
.25192 .45809 Mdot
.29856 .26407 Mdot
.393 .82564 Mdot
.17498 .74971 Mdot
.20424 .45439 Mdot
.06719 .0333 Mdot
.34883 .97836 Mdot
.6566 .29611 Mdot
.18825 .37389 Mdot
.43141 .03 Mdot
.13993 .60875 Mdot
.51549 .75583 Mdot
.87699 .15526 Mdot
.22419 .49495 Mdot
.46696 .33032 Mdot
.06288 .7459 Mdot
.27011 .88084 Mdot
.00371 .71107 Mdot
.92993 .90393 Mdot
.3289 .41229 Mdot
.73847 .53406 Mdot
.89588 .38212 Mdot
.59929 .9329 Mdot
.3683 .61979 Mdot
.72732 .77415 Mdot
.15317 .12461 Mdot
.25396 .44864 Mdot
.11017 .38621 Mdot
.98977 .56484 Mdot
.1177 .67705 Mdot
.07551 .66371 Mdot
.7701 .26555 Mdot
.32774 .12134 Mdot
.88389 .88863 Mdot
.72191 .19529 Mdot
.49553 .26388 Mdot
.99867 .42194 Mdot
.35163 .13409 Mdot
.73199 .98305 Mdot
.25206 .75482 Mdot
.75442 .40715 Mdot
.15474 .07545 Mdot
.68375 .74947 Mdot
.37082 .81338 Mdot
.35788 .62325 Mdot
.4959 .92685 Mdot
.63732 .42636 Mdot
.01401 .66152 Mdot
.64441 .01375 Mdot
.64436 .52089 Mdot
.92096 .03139 Mdot
.38618 .76649 Mdot
.16713 .61813 Mdot
.24133 .68693 Mdot
.46275 .87155 Mdot
.87404 .87799 Mdot
.11482 .24487 Mdot
.35359 .95397 Mdot
.46006 .81536 Mdot
.35338 .2927 Mdot
.82507 .80787 Mdot
.70226 .7701 Mdot
.91534 .77758 Mdot
.31207 .00145 Mdot
.74197 .15908 Mdot
.07606 .31512 Mdot
.27039 .29032 Mdot
.20704 .44421 Mdot
.16674 .03891 Mdot
.84788 .48576 Mdot
.69464 .22436 Mdot
.47973 .19203 Mdot
.87498 .42107 Mdot
.78163 .4204 Mdot
.97773 .64286 Mdot
.45717 .42471 Mdot
.22579 .48705 Mdot
.39306 .10303 Mdot
.95599 .19725 Mdot
.19545 .66547 Mdot
.79026 .1602 Mdot
.35023 .17647 Mdot
.10709 .92531 Mdot
.87099 .98785 Mdot
.22491 .50864 Mdot
.1 .56363 Mdot
.25363 .86652 Mdot
.61734 .13893 Mdot
.03968 .38071 Mdot
.22441 .03022 Mdot
.08101 .18037 Mdot
.03498 .36642 Mdot
.2858 .02281 Mdot
.67409 .183 Mdot
.18948 .09277 Mdot
.80802 .20164 Mdot
.96714 .58693 Mdot
.72085 .6357 Mdot
.69977 .72177 Mdot
.11855 .49866 Mdot
.67527 .33766 Mdot
.88437 .46362 Mdot
.59586 .15747 Mdot
.85699 .09992 Mdot
.31525 .13185 Mdot
.18553 .90884 Mdot
.13423 .03457 Mdot
.36612 .70931 Mdot
.17512 .45398 Mdot
.64592 .07741 Mdot
.45546 .72401 Mdot
.53484 .57908 Mdot
.78918 .38187 Mdot
.66139 .11767 Mdot
.19348 .22614 Mdot
.80879 .02593 Mdot
.87961 .09314 Mdot
.6247 .11033 Mdot
.74465 .05776 Mdot
.25393 .40572 Mdot
.56805 .60394 Mdot
.60212 .32089 Mdot
.12502 .8724 Mdot
.06957 .74695 Mdot
.32177 .4895 Mdot
.38899 .62603 Mdot
.1432 .26623 Mdot
.57191 .60889 Mdot
.26487 .17151 Mdot
.96221 .4981 Mdot
.50678 .12195 Mdot
.69706 .10122 Mdot
.93767 .52072 Mdot
.10675 .77419 Mdot
.8208 .64151 Mdot
.04722 .02693 Mdot
.47897 .15437 Mdot
.64356 .3971 Mdot
.33944 .89463 Mdot
.07185 .79428 Mdot
.09668 .71955 Mdot
.11097 .29791 Mdot
.55857 .59666 Mdot
.39745 .19228 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`02o`0000_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`;o
00002?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Kooooo0_l00005ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool2o`0000Kooooo0_l00007ooooo`03
o`000?oooooooooo00;ooooo000Nooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;o00002oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00?ooooo0_l00008ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool01_ooool2o`0000Gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`04ooooo`;o00002?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool2o`0000oooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0=Oooool2o`0009gooooo0_l0000Qooooo`;o0000;?ooool2o`00023ooooo000N
ooooo`03o`000?oooooooooo03Gooooo0_l0000_ooooo`;o00001_ooool2o`0003oooooo0_l0000B
ooooo`;o00003oooool2o`0004oooooo0_l0000Pooooo`007_ooool00ol0003oooooooooo`0hoooo
o`;o0000;?ooool2o`0000Kooooo0_l0000<ooooo`;o0000<Oooool2o`0001;ooooo0_l00008oooo
o`;o0000N?ooool001kooooo00?o0000ooooooooool0>?ooool2o`0003kooooo0_l00002ooooo`;o
0000BOooool2o`0000Cooooo0_l0001hooooo`007_ooool00ol0003oooooooooo`1Iooooo`;o0000
7Oooool2o`0000Oooooo0_l00007ooooo`;o0000:Oooool2o`00013ooooo0_l0001nooooo`007_oo
ool00ol0003oooooooooo`0cooooo`;o00009?ooool2o`0002Kooooo0_l00007ooooo`;o0000:Ooo
ool2o`00023ooooo0_l0000Jooooo`;o00003_ooool2o`0000_ooooo0_l0000eooooo`007_ooool0
0ol0003oooooooooo`0;ooooo`;o00006?ooool2o`0000cooooo0_l0000Uooooo`;o00005oooool2
o`0003kooooo0_l0000Rooooo`;o00006_ooool2o`0000cooooo1?l0000;ooooo`;o0000:oooool2
o`0000Sooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l000000ooooooo0000o`00000Eoooo
o`;o00007_ooool2o`0001?ooooo0_l0000Gooooo`;o00004oooool2o`0002Wooooo0_l00007oooo
o`;o0000@oooool2o`0002Cooooo0_l0000Dooooo`;o00002?ooool001kooooo00?o0000oooooooo
ool03_ooool2o`0000;ooooo0_l0000Dooooo`;o00006oooool2o`0001?ooooo0_l0000/ooooo`;o
0000<_ooool2o`0006Wooooo0_l0000Aooooo`;o00002oooool001kooooo00?o0000ooooooooool0
3_ooool2o`0000;ooooo0_l0000Dooooo`;o00001?ooool2o`0002[ooooo0_l0000Oooooo`;o0000
[?ooool2o`0000oooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`08ooooo`;o00001?oo
ool2o`0001kooooo0_l00002ooooo`;o00009_ooool2o`0001oooooo0_l0002/ooooo`;o00007?oo
ool001kooooo00?o0000ooooooooool02?ooool2o`0002Sooooo0_l0001eooooo`;o00008_ooool2
o`0007Sooooo000Nooooo`03o`000?oooooooooo04gooooo0_l0000Iooooo`;o0000?oooool2o`00
01oooooo0_l000000ooooooo0000o`000008ooooo`;o0000K_ooool001kooooo00?o0000oooooooo
ool0AOooool2o`0000Kooooo0_l0000Iooooo`;o0000H?ooool2o`0000_ooooo1?l0001/ooooo`00
7_ooool2o`0003?ooooo0_l0000:ooooo`;o00001Oooool2o`0009;ooooo0_l0001/ooooo`007_oo
ool00ol0003oooooooooo`0Jooooo`;o00005_ooool2o`0000Oooooo0_l000000ooooooo0000o`00
001Aooooo`;o0000EOooool2o`0005gooooo000Nooooo`03o`000?oooooooooo00;o00003_ooool2
o`0000Sooooo0_l0000Oooooo`;o000000?oooooo`000?l00000@oooool2o`0000cooooo0_l0000Y
ooooo`;o00002oooool2o`0001gooooo0_l00004ooooo`;o0000Eoooool001kooooo00?o0000oooo
ooooool00_l0000>ooooo`;o0000LOooool2o`0003Oooooo0_l0000;ooooo`;o00008oooool2o`00
05Oooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l0000hooooo`;o0000[oooool2o`0003?o
oooo000Nooooo`03o`000?oooooooooo00_ooooo0_l0000Eooooo`;o00000oooool2o`0003Sooooo
0_l0002_ooooo`;o0000<oooool001kooooo00?o0000ooooooooool02oooool2o`0001Gooooo0_l0
000/ooooo`;o0000=Oooool2o`000:[ooooo0_l0000Booooo`007_ooool00ol0003oooooooooo`16
ooooo`;o00002?ooool2o`0003Gooooo0_l0002Zooooo`;o00004_ooool001kooooo00?o0000oooo
ooooool07?ooool2o`00013ooooo0_l0000Fooooo`;o0000Q_ooool2o`0000[ooooo0_l0001[oooo
o`007_ooool00ol0003oooooooooo`0Looooo`;o00004?ooool2o`0005kooooo0_l0000nooooo`;o
00002_ooool2o`0000Kooooo0_l0001Sooooo`007_ooool00ol0003oooooooooo`0Tooooo`;o0000
C?ooool2o`0001[ooooo0_l0001Booooo`;o0000Hoooool001kooooo00?o0000ooooooooool09?oo
ool2o`0004cooooo0_l0003Cooooo`007_ooool00ol0003oooooooooo`1eooooo`;o0000Ioooool2
o`0000Sooooo0_l0001Mooooo`007_ooool00ol0003oooooooooo`0iooooo`;o0000>_ooool2o`00
00_ooooo0_l00015ooooo`;o00004oooool2o`0000Sooooo0_l0000`ooooo`;o00005_ooool2o`00
01?ooooo000Nooooo`03o`000?oooooooooo02_ooooo0_l0000<ooooo`;o0000Aoooool2o`0000_o
oooo0_l000000ooooooo0000o`000006ooooo`;o00009?ooool2o`0000Oooooo0_l00008ooooo`;o
0000AOooool2o`0001Kooooo0_l0000Cooooo`007_ooool00ol0003oooooooooo`04ooooo`;o0000
9Oooool2o`0004oooooo0_l00006ooooo`;o00002Oooool2o`000003ooooool0003o000000Kooooo
0_l0000Dooooo`;o00003_ooool2o`00017ooooo0_l0001Dooooo`;o00007?ooool001kooooo0_l0
0005ooooo`;o0000M_ooool2o`0000Kooooo0_l0000Zooooo`;o00009?ooool2o`0000Oooooo0_l0
000booooo`;o00005?ooool2o`0001cooooo000Nooooo`03o`000?oooooooooo07cooooo0_l0001H
ooooo`;o00001oooool2o`0000kooooo0_l0000Aooooo`;o00003oooool4o`0001oooooo0_l0000?
ooooo`007_ooool00ol0003oooooooooo`11ooooo`;o0000>Oooool2o`00077ooooo0_l0000Aoooo
o`;o00004Oooool2o`0001oooooo0_l0000?ooooo`007_ooool00ol0003oooooooooo`11ooooo`;o
0000>Oooool2o`0004Wooooo0_l0001]ooooo`;o00003oooool001kooooo00?o0000ooooooooool0
aoooool2o`0000Wooooo0_l0001cooooo`007_ooool00ol0003oooooooooo`0Booooo`;o0000Cooo
ool2o`0006gooooo0ol0000Yooooo`;o0000Aoooool001kooooo00Co0000oooooooooooooooo0_l0
000?ooooo`;o00001oooool2o`0004Kooooo0_l000000ooooooo0000o`00001[ooooo`;o00003_oo
ool2o`0001Wooooo0_l00008ooooo`;o0000?Oooool001kooooo00Co0000oooooooooooooooo0_l0
000Hooooo`;o0000BOooool2o`0000cooooo0_l0000[ooooo`;o0000@?ooool2o`0002?ooooo0_l0
000Hooooo`;o00008oooool001kooooo00?o0000ooooooooool0;_ooool2o`0001oooooo0_l0000S
ooooo`;o00001oooool2o`0002;ooooo0_l0001oooooo`;o00008oooool001kooooo00?o0000oooo
ooooool03oooool2o`0001gooooo0_l0000Oooooo`;o0000;?ooool2o`00037ooooo0_l0001loooo
o`;o00005oooool001kooooo00Co0000oooooooooooooooo0_l0000<ooooo`;o00003Oooool2o`00
04;ooooo0_l00006ooooo`;o00005_ooool2o`0002cooooo0_l0000Hooooo`;o00002?ooool2o`00
05Sooooo0_l0000Gooooo`007_ooool01?l0003oooooooooooooool2o`0001_ooooo0_l0000boooo
o`;o00003_ooool2o`0000Kooooo0_l00002ooooo`;o00004_ooool2o`0002Oooooo0_l0000Moooo
o`;o00002?ooool2o`0006Wooooo0_l00006ooooo`007_ooool00ol0003oooooooooo`1Booooo`;o
00006_ooool2o`0003_ooooo0_l0000;ooooo`;o00002Oooool4o`0000;ooooo0_l0001dooooo`;o
00001_ooool001kooooo00?o0000ooooooooool0H?ooool2o`0005Kooooo0_l00009ooooo`Co0000
0_ooool2o`0007cooooo000Nooooo`03o`000?oooooooooo063ooooo0_l0000>ooooo`;o00006?oo
ool2o`0001Wooooo0_l0000Pooooo`;o0000O_ooool001kooooo00?o0000ooooooooool01_ooool2
o`0004Oooooo0_l0000Oooooo`;o00006?ooool2o`0001Wooooo0_l0000Pooooo`;o00008oooool2
o`0005Wooooo000Nooooo`;o00001oooool2o`0003Wooooo0_l0000<ooooo`;o00002Oooool2o`00
01Oooooo0_l0001gooooo`;o0000>oooool2o`0001cooooo000Nooooo`03o`000?oooooooooo047o
oooo0_l0000Gooooo`;o00005oooool2o`0000Kooooo0_l0000<ooooo`;o00003Oooool2o`0008Oo
oooo0_l00006ooooo`;o00007?ooool001kooooo00?o0000ooooooooool0Noooool2o`0000cooooo
0_l0000=ooooo`;o00009?ooool2o`0002gooooo0_l0000Zooooo`;o00001_ooool2o`0002Cooooo
000Nooooo`03o`000?oooooooooo02Wooooo0_l0001Rooooo`;o0000;oooool2o`0002gooooo0_l0
000>ooooo`;o00006_ooool2o`0002cooooo000Nooooo`03o`000?oooooooooo02Wooooo0_l00015
ooooo`;o00006oooool2o`0000gooooo0_l0000>ooooo`;o0000?oooool2o`0000kooooo0_l00018
ooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o0000Hoooool2o`0000Sooooo0_l0000Poooo
o`;o00003_ooool2o`0003oooooo0_l0000`ooooo`;o00009_ooool001kooooo00?o0000oooooooo
ool02oooool2o`0004_ooooo0_l0000Pooooo`;o0000Xoooool2o`0002Kooooo000Nooooo`03o`00
0?oooooooooo05;ooooo0_l000001?oooooo0000o`000?ooool2o`000=[ooooo0_l0000Aooooo`00
7_ooool00ol0003oooooooooo`1Booooo`;o000000?oooooo`000?l000005oooool2o`000<Cooooo
0_l0000Aooooo`007_ooool00ol0003oooooooooo`1Dooooo`;o00006?ooool2o`000=Oooooo000N
ooooo`03o`000?oooooooooo01Kooooo0_l0000looooo`;o00005?ooool2o`0003Cooooo0_l0002U
ooooo`007_ooool00ol0003oooooooooo`0Fooooo`;o0000D_ooool2o`0002gooooo0_l00005oooo
o`;o0000=Oooool2o`00043ooooo0_l0000/ooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o
0000ROooool2o`0002Oooooo0_l0000Cooooo`;o00004Oooool2o`0002gooooo0ol0000[ooooo`00
7_ooool00ol0003oooooooooo`0>ooooo`;o0000MOooool2o`00017ooooo0_l0000Xooooo`;o0000
9_ooool2o`0002Cooooo0_l00008ooooo`;o0000:oooool000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0JOooool2o`0001;ooooo
0_l00006ooooo`;o00004Oooool2o`0000_ooooo0_l0001Yooooo`;o0000=Oooool000?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Ko
oooo00?o0000ooooooooool07_ooool2o`0004Wooooo0_l0000Booooo`;o00009_ooool2o`00043o
oooo0_l0000:ooooo`;o00009oooool2o`0001Gooooo0_l0000Booooo`000oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool5o`0001cooooo0_l0002jooooo`;o
00002oooool2o`0000[ooooo0_l0000Wooooo`;o00005Oooool2o`0001;ooooo0003ooooo`05o`00
0?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo00;o
0000f?ooool2o`0000;ooooo0_l0000Sooooo`;o00003?ooool2o`0003Cooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo01;o
oooo0_l0003:ooooo`;o00006_ooool2o`0000Oooooo0_l0000<ooooo`;o0000=?ooool000?ooooo
00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool04_ooool2o`00093ooooo0_l0001Dooooo`;o00001oooool2o`0000cooooo0_l0000dooooo`00
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006oooo
o`03o`000?oooooooooo02cooooo0_l0000iooooo`;o0000>oooool2o`0009;ooooo0_l0000=oooo
o`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006
ooooo`03o`000?oooooooooo01oooooo0ol0000:ooooo`?o0000>?ooool2o`0000?ooooo0ol0001m
ooooo`;o00001oooool2o`00047ooooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`0Ooooo
o`?o00002oooool2o`0001oooooo0_l0000Looooo`?o0000@?ooool2o`0003_ooooo0_l00007oooo
o`;o00002Oooool2o`0004Gooooo000Nooooo`03o`000?oooooooooo01Gooooo0_l0000gooooo`;o
00003_ooool2o`0004oooooo0_l00002ooooo`;o0000=oooool2o`0001;ooooo0_l00015ooooo`00
7_ooool00ol0003oooooooooo`0Eooooo`;o00003oooool2o`0001kooooo0_l0000Fooooo`;o0000
Doooool2o`0002Wooooo0_l00016ooooo`;o00007oooool001kooooo00?o0000ooooooooool02Ooo
ool2o`0001_ooooo0_l0000Cooooo`;o00000oooool2o`0000Cooooo0_l0000Jooooo`;o0000@ooo
ool2o`0003Gooooo0_l00016ooooo`;o00005oooool2o`0000Kooooo000Nooooo`03o`000?oooooo
oooo00Wooooo0_l0000`ooooo`;o00000oooool2o`00023ooooo0_l00013ooooo`;o00004_ooool2
o`0006Gooooo0_l0000Hooooo`;o000000?oooooo`000?l000001_ooool001kooooo00?o0000oooo
ooooool0LOooool2o`0004Sooooo0_l0000?ooooo`;o0000@_ooool2o`00013ooooo0_l0000Hoooo
o`;o00002Oooool001kooooo00?o0000ooooooooool0LOooool2o`0005Wooooo0_l00012ooooo`;o
0000;_ooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo0?oooooo0_ooool2o`0000kooooo
0_l0000]ooooo`;o00001Oooool001kooooo00?o0000ooooooooool0Doooool2o`0004Gooooo0_l0
001Uooooo`;o00003_ooool2o`0003Cooooo000Nooooo`03o`000?oooooooooo027ooooo0_l0000S
ooooo`;o00002oooool2o`0004Gooooo0_l0001Eooooo`;o0000E?ooool001kooooo00?o0000oooo
ooooool08Oooool2o`0000[ooooo0_l0000Gooooo`;o0000ZOooool2o`0001oooooo0_l0000coooo
o`007_ooool2o`0002kooooo0_l0001>ooooo`;o0000D?ooool2o`00047ooooo0_l0000cooooo`00
7_ooool00ol0003oooooooooo`1mooooo`;o0000D?ooool2o`0003Cooooo0_l0000_ooooo`;o0000
3oooool001kooooo00?o0000ooooooooool0ooooool6ooooo`;o0000;oooool2o`0000oooooo000N
ooooo`03o`000?oooooooooo02Cooooo0_l0001eooooo`;o0000;Oooool2o`0000Gooooo0_l0001d
ooooo`007_ooool00ol0003oooooooooo`0Tooooo`;o0000=oooool2o`0003cooooo1?l0000[oooo
o`;o00001Oooool2o`0002?ooooo0_l0001?ooooo`007_ooool00ol0003oooooooooo`0Zooooo`;o
0000<Oooool2o`0001[ooooo0_l0000Rooooo`;o0000?oooool2o`0000Oooooo0_l0000=ooooo`;o
0000;_ooool2o`0001oooooo000Nooooo`03o`000?oooooooooo01kooooo0_l0000:ooooo`;o0000
8_ooool2o`0002Oooooo1?l0001Pooooo`;o000000?oooooo`000?l000001oooool2o`000003oooo
ool0003o000003[ooooo0_l0000Oooooo`007_ooool00ol0003oooooooooo`0Nooooo`;o0000;_oo
ool2o`0002Oooooo0_l0001Rooooo`;o00003Oooool2o`0004Cooooo0_l0000Eooooo`007_ooool0
0ol0003oooooooooo`13ooooo`;o0000joooool2o`0001Gooooo000Nooooo`03o`000?oooooooooo
01Gooooo0_l0000/ooooo`;o0000Aoooool2o`0008Oooooo0_l0000`ooooo`007_ooool00ol0003o
ooooooooo`0Eooooo`;o00005Oooool2o`0005kooooo0_l0000<ooooo`;o00002?ooool2o`0005co
oooo0_l0000Aooooo`;o0000<?ooool001kooooo00?o0000ooooooooool0;?ooool2o`0006Cooooo
0_l00006ooooo`;o00000oooool2o`0000?ooooo0_l0001Looooo`;o00003_ooool2o`0003?ooooo
000Nooooo`03o`000?oooooooooo02;ooooo0_l0000`ooooo`;o0000??ooool2o`0000_ooooo0_l0
00000ooooooo0000o`00000jooooo`;o0000<_ooool2o`0003?ooooo000Nooooo`04o`000?oooooo
ooooooooo`;o00007oooool2o`0000Oooooo0_l0000Wooooo`;o00006Oooool2o`00037ooooo0_l0
000jooooo`;o0000C?ooool2o`0001Wooooo000Nooooo`04o`000?ooooooooooooooo`;o00008ooo
ool2o`0000?ooooo0_l00012ooooo`;o0000H?ooool2o`0001cooooo0_l0000kooooo`;o00006Ooo
ool001kooooo00?o0000ooooooooool08?ooool2o`0000Cooooo0_l0002Yooooo`;o00005?ooool2
o`0000Kooooo0_l0000>ooooo`;o0000A_ooool001kooooo0_l0000Qooooo`;o0000aOooool2o`00
00kooooo0_l000000ooooooo0000o`000003ooooo`;o00003oooool2o`0003Gooooo000Nooooo`;o
0000Noooool2o`0007_ooooo0_l000000ooooooo0000o`00000Dooooo`;o00008Oooool2o`0001;o
oooo000Nooooo`;o00000_ooool2o`0007Oooooo0_l0002gooooo`;o00004_ooool001kooooo00Co
0000oooooooooooooooo0_l00007ooooo`;o0000[_ooool2o`0000Oooooo0_l00022ooooo`007_oo
ool00ol0003oooooooooo`0:ooooo`;o00002Oooool2o`000:?ooooo0_l00007ooooo`;o0000P_oo
ool001kooooo00?o0000ooooooooool05Oooool2o`00023ooooo0_l0002jooooo`;o0000D_ooool0
01kooooo00?o0000ooooooooool0=oooool2o`0008;ooooo0_l00003ooooo`;o0000<Oooool2o`00
01?ooooo0_l0000mooooo`007_ooool00ol0003oooooooooo`1Oooooo`;o0000=?ooool2o`0002Co
oooo0_l00003ooooo`;o0000<?ooool2o`0001Cooooo0_l0000mooooo`007_ooool00ol0003ooooo
ooooo`0booooo`;o00004Oooool2o`0001Sooooo0_l0000dooooo`;o0000Foooool2o`0005?ooooo
000Nooooo`03o`000?oooooooooo02Kooooo0_l0000:ooooo`;o00004Oooool2o`0000?ooooo0_l0
0007ooooo`;o0000?oooool3o`0005cooooo0_l0001Booooo`007_ooool00ol0003oooooooooo`0P
ooooo`;o00001?ooool2o`0002;ooooo0_l00007ooooo`;o0000?oooool2o`0000_ooooo0_l0001@
ooooo`;o0000<?ooool2o`00023ooooo000Nooooo`03o`000?oooooooooo023ooooo0_l0001ooooo
o`;o00006oooool2o`0003;ooooo0_l0000aooooo`;o00008?ooool001kooooo00?o0000oooooooo
ool0__ooool2o`0001Oooooo0_l0000Iooooo`;o0000Doooool001kooooo00?o0000ooooooooool0
4?ooool2o`0007_ooooo0_l00018ooooo`;o00004_ooool3o`0005Wooooo000Nooooo`03o`000?oo
oooooooo013ooooo0_l0001kooooo`;o00005oooool2o`0002cooooo0_l0000Eooooo`?o00005_oo
ool2o`00027ooooo0_l0000Nooooo`007_ooool00ol0003oooooooooo`2Vooooo`;o0000;?ooool2
o`0002kooooo0_l0000Qooooo`;o00007_ooool001kooooo0_l0001Vooooo`;o0000h?ooool001ko
oooo00?o0000ooooooooool0F_ooool2o`0000Wooooo0_l0000>ooooo`;o0000d?ooool001kooooo
00?o0000ooooooooool0F_ooool2o`0001Wooooo0_l0003@ooooo`007_ooool00ol0003ooooooooo
o`1Jooooo`;o0000joooool001kooooo00?o0000ooooooooool0F_ooool2o`00077ooooo0_l0001h
ooooo`007_ooool00ol0003oooooooooo`07ooooo`;o00001oooool2o`00023ooooo0_l0001Coooo
o`;o0000A?ooool2o`0007Sooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l00007ooooo`;o
00004?ooool2o`0000kooooo0_l0000;ooooo`;o00009Oooool2o`0000Kooooo0_l0000:ooooo`;o
00002oooool2o`000:7ooooo0_l0000Kooooo`007_ooool00ol0003oooooooooo`04ooooo`;o0000
7?ooool2o`0001Wooooo1?l0000Uooooo`;o00001_ooool2o`0000Wooooo0ol0001^ooooo`;o0000
1?ooool2o`0003Sooooo0_l0000Kooooo`007_ooool00ol0003oooooooooo`04ooooo`;o0000<ooo
ool2o`0000;ooooo0_l0000jooooo`;o0000Koooool2o`0000Cooooo0_l0001Eooooo`007_ooool0
0ol0003oooooooooo`0iooooo`;o0000?_ooool2o`0000gooooo0_l0002mooooo`007_ooool00ol0
003oooooooooo`09ooooo`;o0000OOooool2o`0006_ooooo0_l00005ooooo`;o00008Oooool2o`00
02Kooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0000aooooo`;o000000?oooooo`000?l0
0000]?ooool2o`0000Gooooo0_l0000Qooooo`;o00009_ooool001kooooo00?o0000ooooooooool0
8?ooool2o`0001[ooooo0_l000000ooooooo0000o`000003ooooo`;o0000;?ooool2o`000=?ooooo
000Nooooo`03o`000?oooooooooo00gooooo0_l0000Aooooo`;o00001oooool2o`0001Wooooo0_l0
000Iooooo`;o00004Oooool2o`0000Gooooo0_l0003<ooooo`000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003ooooooooo
o`0=ooooo`;o00006_ooool2o`0002Gooooo0_l00006ooooo`;o00001Oooool2o`0001Sooooo0_l0
000;ooooo`;o0000P?ooool2o`0001cooooo0_l0000Oooooo`000oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0D?oo
ool2o`0000Kooooo0_l0000Jooooo`;o00004?ooool2o`0002gooooo0_l00004ooooo`;o00004?oo
ool2o`0003Wooooo0_l0000Looooo`;o00007oooool000?ooooo00Go410@oooooooooooooooooa0@
400;ooooo`Go00001_ooool3o`0007Cooooo0_l0000/ooooo`;o00001?ooool2o`0000_ooooo0_l0
0004ooooo`;o00004?ooool2o`0001;ooooo0_l00006ooooo`;o0000Doooool2o`0000Oooooo0003
ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00007ooooo`03o`00
0?oooooooooo0:;ooooo0_l00004ooooo`;o0000=oooool2o`0000Kooooo0_l0000Booooo`;o0000
1_ooool2o`0003Oooooo0_l00007ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo
00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`1>ooooo`;o0000H_ooool2o`0003go
oooo0_l0000:ooooo`;o00001_ooool2o`0001Oooooo0_l0000Wooooo`000oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0Fooooo`;o
0000=_ooool2o`00027ooooo0_l0000looooo`;o000000?oooooo`000?l00000?Oooool2o`0002_o
oooo0_l0000Wooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l0
00001oooool00ol0003oooooooooo`0Fooooo`;o0000Coooool2o`0000Sooooo0_l0000looooo`;o
0000U_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Ko
oooo00?o0000ooooooooool0A_ooool2o`0001oooooo0_l0001Oooooo`;o0000=?ooool2o`0004Oo
oooo000Nooooo`03o`000?oooooooooo01Gooooo0_l0000_ooooo`;o00004oooool2o`0006_ooooo
0_l0000`ooooo`;o00000_ooool2o`0004Oooooo000Nooooo`03o`000?oooooooooo013ooooo0_l0
0003ooooo`;o0000A?ooool2o`0001[ooooo0_l0000Iooooo`;o0000I_ooool3o`0001_ooooo0_l0
000Wooooo`;o00001?ooool001kooooo00?o0000ooooooooool04?ooool2o`0003?ooooo0_l0000`
ooooo`;o00006?ooool3o`0000Cooooo0_l0001Pooooo`?o00006oooool2o`0002Oooooo0_l00004
ooooo`007_ooool00ol0003oooooooooo`0gooooo`;o00003?ooool2o`0004[ooooo0_l00005oooo
o`;o0000<Oooool2o`0007[ooooo000Nooooo`03o`000?oooooooooo03Oooooo0_l0001Nooooo`;o
0000<_ooool2o`0007[ooooo000Nooooo`03o`000?oooooooooo09Oooooo0_l0000Aooooo`;o0000
GOooool2o`0003cooooo000Nooooo`03o`000?oooooooooo0:[ooooo0_l0001Mooooo`;o0000??oo
ool001kooooo00?o0000ooooooooool0L_ooool2o`000=?ooooo000Nooooo`03o`000?oooooooooo
03oooooo0_l0000aooooo`;o0000D?ooool2o`00087ooooo000Nooooo`03o`000?oooooooooo03;o
oooo0_l0000;ooooo`;o0000Poooool2o`00087ooooo000Nooooo`03o`000?oooooooooo03;ooooo
0_l0000;ooooo`;o00003Oooool2o`0003oooooo0_l00012ooooo`;o0000L_ooool001kooooo0_l0
000Nooooo`;o0000:_ooool7o`0003oooooo0_l0000:ooooo`;o0000=_ooool2o`00063ooooo0_l0
000@ooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o00005_ooool2o`0000Oooooo0_l00009
ooooo`Go00000oooool2o`0001;ooooo0_l0000Wooooo`;o00002oooool2o`0002oooooo0_l0000Q
ooooo`;o0000A?ooool2o`00013ooooo000Nooooo`03o`000?oooooooooo03Gooooo0_l00007oooo
o`;o00001_ooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000004_ooool2o`00
01cooooo0_l00009ooooo`;o0000??ooool2o`00027ooooo0_l0001Fooooo`007_ooool00ol0003o
ooooooooo`0_ooooo`;o00001Oooool2o`0000kooooo0_l00002ooooo`;o00000_ooool4o`00037o
oooo0_l00032ooooo`007_ooool00ol0003oooooooooo`0_ooooo`;o000000?oooooo`000?l00000
0_ooool2o`0001;ooooo0_l00004ooooo`;o00000oooool2o`000;7ooooo0_l0000Aooooo`Co0000
00?oooooo`000?l000009Oooool001kooooo00?o0000ooooooooool05oooool3o`0001Sooooo0_l0
0006ooooo`;o00000oooool2o`0001Cooooo0_l0001<ooooo`;o0000;Oooool2o`0000oooooo0_l0
000Sooooo`;o00004Oooool4o`000003ooooool0003o000002Gooooo000Nooooo`03o`000?oooooo
oooo01Oooooo0ol0000Pooooo`;o00000oooool2o`0002Sooooo0_l0000hooooo`;o0000;Oooool2
o`0000oooooo0_l0000Wooooo`;o00000_ooool2o`0003Gooooo000Nooooo`03o`000?oooooooooo
06Wooooo0_l0002Qooooo`;o00000_ooool2o`0003Gooooo000Nooooo`03o`000?oooooooooo01Co
oooo0_l0000Gooooo`;o0000BOooool2o`0002;ooooo0_l0001?ooooo`;o0000F?ooool001kooooo
00?o0000ooooooooool05?ooool2o`0001Oooooo0_l00019ooooo`;o00008_ooool2o`0004oooooo
0_l0000Jooooo`;o00005?ooool2o`0002Kooooo000Nooooo`04o`000?ooooooooooooooo`;o0000
d_ooool2o`0003;ooooo0_l0000Dooooo`;o00002oooool2o`0001Wooooo000Nooooo`04o`000?oo
ooooooooooooo`;o0000@_ooool2o`0000?ooooo0_l00017ooooo`;o00001?ooool2o`0000?ooooo
0_l0000eooooo`;o0000>Oooool2o`0001[ooooo0_l0000Iooooo`007_ooool00ol0003ooooooooo
o`15ooooo`;o00000oooool2o`0001Sooooo0_l0000Uooooo`;o00001_ooool2o`0000Cooooo0_l0
0003ooooo`;o0000>Oooool2o`0003?ooooo1?l0000eooooo`007_ooool00ol0003oooooooooo`1T
ooooo`;o00009Oooool2o`0004cooooo0_l0000cooooo`;o00008?ooool2o`0000;ooooo0_l0000A
ooooo`007_ooool00ol0003oooooooooo`0^ooooo`;o00005Oooool2o`0000Gooooo0_l00019oooo
o`;o0000>_ooool2o`0005Kooooo0_l00003ooooo`;o00000_ooool2o`00017ooooo000Nooooo`03
o`000?oooooooooo02;ooooo0_l0000:ooooo`;o00005Oooool2o`0000Gooooo0_l00019ooooo`;o
0000>_ooool2o`00043ooooo0_l0000Dooooo`;o00002?ooool2o`00013ooooo000Nooooo`;o0000
7Oooool2o`0000Cooooo0_l0000Fooooo`;o00005?ooool2o`000<?ooooo0_l000000ooooooo0000
o`00000?ooooo`;o00002_ooool2o`00013ooooo000Nooooo`03o`000?oooooooooo01cooooo0_l0
000Looooo`Co00004_ooool2o`000<Kooooo0_l0000?ooooo`;o00007?ooool001kooooo00?o0000
ooooooooool0>Oooool2o`000003ooooool0003o000000Oooooo0_l0003oooooo`7ooooo000Noooo
o`03o`000?oooooooooo01;ooooo0_l0000Uooooo`;o00002_ooool2o`0004Oooooo0_l0002goooo
o`007_ooool00ol0003oooooooooo`0Booooo`;o00005Oooool2o`0004Sooooo0_l0000Iooooo`;o
0000]oooool001kooooo00?o0000ooooooooool0:Oooool2o`0002Wooooo0_l0000Mooooo`;o0000
8oooool2o`0000Sooooo0_l0001Jooooo`;o00009_ooool2o`0001oooooo000Nooooo`03o`000?oo
oooooooo05Cooooo0_l00012ooooo`Co00001_ooool2o`0002Wooooo0_l0000_ooooo`;o00009_oo
ool2o`0000Gooooo0_l0000Hooooo`007_ooool00ol0003oooooooooo`07ooooo`;o0000K?ooool2
o`0000;ooooo0_l0000>ooooo`;o00003Oooool4o`0002Gooooo0_l0000:ooooo`;o0000G_ooool2
o`0001Sooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0001/ooooo`;o00000_ooool2o`00
00kooooo0_l0000=ooooo`;o00009oooool2o`00043ooooo0_l00012ooooo`007_ooool00ol0003o
ooooooooo`0Rooooo`;o00005Oooool2o`0009[ooooo0_l0000/ooooo`;o0000@_ooool001kooooo
00?o0000ooooooooool08_ooool2o`0000Cooooo0_l00009ooooo`;o00001?ooool2o`00033ooooo
0_l0001Xooooo`;o0000BOooool2o`0002Gooooo000Nooooo`03o`000?oooooooooo02Sooooo0_l0
0009ooooo`;o0000=_ooool2o`0007oooooo0_l0000booooo`;o00001Oooool2o`0001kooooo000N
ooooo`03o`000?oooooooooo04Oooooo0_l00014ooooo`;o00006?ooool2o`0004?ooooo0_l0000i
ooooo`;o00007_ooool001kooooo00?o0000ooooooooool0Aoooool2o`0000_ooooo0_l0000goooo
o`;o00006?ooool2o`0001oooooo0_l0001mooooo`007_ooool00ol0003oooooooooo`1Dooooo`;o
0000;?ooool2o`00017ooooo0_l0000aooooo`;o00009_ooool2o`0005Gooooo000Nooooo`03o`00
0?oooooooooo01Cooooo0_l0001Uooooo`;o00001Oooool2o`00017ooooo0_l00005ooooo`;o0000
;_ooool2o`0002;ooooo0_l0001Eooooo`007_ooool2o`0001Gooooo0_l0001;ooooo`;o00006?oo
ool2o`0001oooooo0_l0000^ooooo`;o00001Oooool2o`0007;ooooo000Nooooo`03o`000?oooooo
oooo01Cooooo0_l0000Gooooo`;o0000<_ooool2o`00073ooooo0_l0000Vooooo`;o00009oooool2
o`00027ooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0000Gooooo`Co00002Oooool2o`00
0:Oooooo0_l0000;ooooo`;o00002Oooool2o`00027ooooo0_l00004ooooo`;o00008Oooool001ko
oooo00?o0000ooooooooool0;oooool2o`0000Wooooo0_l0002Wooooo`;o00002oooool2o`0002co
oooo0_l0000Wooooo`007_ooool00ol0003oooooooooo`0Looooo`;o0000I_ooool2o`0000Oooooo
0_l0002Pooooo`;o00005_ooool001kooooo00?o0000ooooooooool07?ooool2o`0006Kooooo0_l0
0007ooooo`?o0000Woooool2o`0000gooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`2>
ooooo`;o0000L_ooool2o`0000_ooooo0_l0000]ooooo`;o00001oooool001kooooo00?o0000oooo
ooooool0=?ooool2o`0004?ooooo0_l00027ooooo`;o00002oooool2o`0000Oooooo0_l00002oooo
o`;o0000:Oooool001kooooo00?o0000ooooooooool0=?ooool2o`0002Gooooo0_l0000Looooo`;o
0000WOooool2o`0000;ooooo0_l0000Yooooo`007_ooool00ol0003oooooooooo`0nooooo`;o0000
6oooool2o`00013ooooo0_l0000kooooo`;o0000Voooool001kooooo00?o0000ooooooooool06ooo
ool2o`00027ooooo0_l0000]ooooo`;o0000<Oooool2o`0000Kooooo1?l0002Kooooo`007_ooool0
0ol0003oooooooooo`0Kooooo`;o00005?ooool2o`0006gooooo0_l00006ooooo`;o0000WOooool0
01kooooo00?o0000ooooooooool0<Oooool2o`0004gooooo0_l00005ooooo`;o0000[Oooool2o`00
00oooooo000Nooooo`03o`000?oooooooooo083ooooo0_l00005ooooo`;o0000VOooool2o`0001;o
oooo0_l0000?ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`1Mooooo`;o0000=oooool2o`00
00oooooo0_l0001iooooo`Co00008Oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool08Oooool2
o`0003[ooooo0_l0000gooooo`;o00003oooool2o`0000Sooooo0_l0001aooooo`;o00008Oooool0
00?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_oo
ool3o`00027ooooo0_l0001eooooo`;o00005oooool2o`0006Kooooo0_l0000/ooooo`000oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`03o`00
0?oooooooooo09Sooooo0_l0000Kooooo`;o0000H_ooool2o`0002cooooo0003ooooo`05o`000?oo
ooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000oooooooo
ool03_ooool2o`0004Sooooo0_l0001Kooooo`;o0000IOooool2o`0002Wooooo0003ooooo`05oa0@
4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo00ko
oooo0_l0000Iooooo`?o00002Oooool2o`0000;ooooo0_l00008ooooo`;o00004oooool2o`00023o
oooo0_l0000>ooooo`;o0000:_ooool2o`0006Cooooo0_l0000Fooooo`;o00004Oooool000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000oooooooo
ool0:Oooool3o`0000Wooooo0_l00002ooooo`;o00002?ooool2o`0003Gooooo0_l0000>ooooo`;o
0000:_ooool2o`0007cooooo0_l0000Aooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`0Booooo`;o00006_ooool2o`00
00gooooo0_l0000>ooooo`;o00008?ooool2o`0004;ooooo0_l00015ooooo`;o00005?ooool2o`00
00Wooooo0_l0000Zooooo`007_ooool00ol0003oooooooooo`0Booooo`;o00006_ooool2o`0000;o
oooo0_l00009ooooo`;o00003_ooool2o`0000Kooooo0_l0000Hooooo`;o00003?ooool2o`0001So
oooo0_l0000Jooooo`;o0000AOooool2o`0001Cooooo0_l00009ooooo`;o0000:_ooool001kooooo
00?o0000ooooooooool0<_ooool2o`00027ooooo0_l0000Mooooo`;o00001oooool2o`0001Cooooo
0_l00002ooooo`;o00006oooool2o`0003kooooo0_l0001Aooooo`007_ooool00ol0003ooooooooo
o`1`ooooo`;o00000_ooool2o`0000oooooo0_l0000<ooooo`;o00007oooool2o`0003kooooo0_l0
0007ooooo`;o0000B?ooool001kooooo00?o0000ooooooooool0L?ooool2o`0000Sooooo0_l00009
ooooo`;o00003Oooool2o`0006Oooooo0_l0000Dooooo`;o00004Oooool2o`0001oooooo000Noooo
o`03o`000?oooooooooo05oooooo0_l0000Iooooo`;o00006?ooool2o`0001kooooo0_l00004oooo
o`;o0000COooool2o`0000Sooooo0_l0000;ooooo`;o00001?ooool2o`0001oooooo000Nooooo`03
o`000?oooooooooo04[ooooo0_l0000Cooooo`;o0000>_ooool2o`0001Oooooo0_l00004ooooo`;o
0000COooool2o`0001Gooooo0_l0000?ooooo`;o00005?ooool001kooooo00?o0000ooooooooool0
B_ooool2o`0004oooooo0_l00019ooooo`;o0000?oooool2o`0000Sooooo0_l0000Dooooo`007_oo
ool00ol0003oooooooooo`15ooooo`;o0000F?ooool2o`0002Gooooo0_l0000Nooooo`;o0000?ooo
ool2o`0001kooooo000Nooooo`03o`000?oooooooooo04Gooooo0_l0001Hooooo`;o00009Oooool2
o`0000Oooooo0_l0000fooooo`;o0000<Oooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo
09Gooooo0_l0000hooooo`;o0000=_ooool2o`0002Sooooo0_l00007ooooo`;o00002oooool001ko
oooo00?o0000ooooooooool0COooool2o`0001oooooo0_l0000Uooooo`;o0000:oooool2o`0003Wo
oooo0_l0000Booooo`;o00007_ooool2o`0001Cooooo000Nooooo`;o0000C_ooool2o`0001oooooo
0_l0000:ooooo`;o0000A_ooool2o`0003Wooooo0_l0000Booooo`;o0000=?ooool001kooooo00?o
0000ooooooooool08_ooool2o`0000kooooo0_l0000?ooooo`;o0000=Oooool2o`000<_ooooo000N
ooooo`03o`000?oooooooooo01?ooooo0_l0000=ooooo`;o00001_ooool2o`0000Kooooo0_l0000?
ooooo`;o0000W_ooool2o`0006;ooooo000Nooooo`03o`000?oooooooooo00;o00004Oooool2o`00
01Gooooo0_l00009ooooo`;o00002oooool2o`0003gooooo0_l0000Mooooo`;o00000_ooool2o`00
01kooooo0_l0000Mooooo`;o0000H_ooool001kooooo00?o0000ooooooooool00_l0000Booooo`;o
00007oooool2o`0000Cooooo0_l00005ooooo`;o0000?Oooool2o`0001;ooooo0_l00009ooooo`;o
00000_ooool2o`00013ooooo0_l0000<ooooo`;o00001Oooool2o`0000[ooooo0_l0001^ooooo`00
7_ooool00ol0003oooooooooo`0Dooooo`;o00009Oooool2o`0005Sooooo0_l0000Oooooo`;o0000
4oooool2o`0000[ooooo1?l0001/ooooo`007_ooool00ol0003oooooooooo`2@ooooo`;o0000Aooo
ool2o`0005Sooooo0_l0000Booooo`007_ooool00ol0003oooooooooo`2@ooooo`;o0000>_ooool2
o`0001cooooo0_l00017ooooo`;o00004_ooool001kooooo00?o0000ooooooooool08_ooool2o`00
00[ooooo0_l00002ooooo`;o0000V?ooool2o`0001cooooo0_l00003ooooo`;o00006oooool2o`00
03Wooooo000Nooooo`03o`000?oooooooooo023ooooo1?l0000:ooooo`;o00000_ooool2o`0004Ko
oooo0_l0000@ooooo`;o00008?ooool2o`0003oooooo0_l0000Kooooo`;o0000>Oooool001kooooo
00?o0000ooooooooool08?ooool2o`0000Kooooo0_l0001@ooooo`;o00004?ooool2o`00023ooooo
0_l0000Kooooo`;o0000N_ooool001kooooo00?o0000ooooooooool0:?ooool2o`0001_ooooo0_l0
0003ooooo`;o0000Loooool2o`0000[ooooo0_l00002ooooo`;o0000M_ooool001kooooo00?o0000
ooooooooool0:oooool2o`0001Sooooo0_l00003ooooo`;o00005_ooool2o`00033ooooo0_l0000Y
ooooo`;o00003_ooool2o`0002Sooooo0_l0001<ooooo`007_ooool00ol0003oooooooooo`04oooo
o`;o00005?ooool2o`0000oooooo0_l0000>ooooo`;o00009Oooool2o`00033ooooo0_l0001Soooo
o`;o00008Oooool2o`0002Wooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0000Dooooo`;o
00007oooool2o`0002Oooooo0_l00006ooooo`;o0000[_ooool2o`0002Wooooo000Nooooo`03o`00
0?oooooooooo06Cooooo0_l00006ooooo`;o00008_ooool2o`0005kooooo0_l00005ooooo`;o0000
C_ooool001kooooo0_l0002Aooooo`;o0000EOooool2o`0000Oooooo0_l00005ooooo`;o0000C_oo
ool001kooooo00?o0000ooooooooool0<Oooool2o`0000Sooooo0_l0002Zooooo`;o0000G_ooool0
01kooooo00?o0000ooooooooool0<Oooool2o`0000Sooooo0_l0001oooooo`;o00000_ooool2o`00
06_ooooo0_l0000Hooooo`007_ooool2o`0001Kooooo0_l0001Dooooo`;o00001_ooool2o`0004Oo
oooo0_l00002ooooo`;o0000D?ooool2o`0000cooooo0_l0000;ooooo`;o00006?ooool001kooooo
0_l0000Fooooo`;o00008Oooool2o`00037ooooo0_l00006ooooo`;o0000WOooool2o`0000cooooo
0_l0000Uooooo`007_ooool00ol0003oooooooooo`0Tooooo`;o00004_ooool2o`0008Kooooo0_l0
0018ooooo`;o0000>oooool001kooooo00?o0000ooooooooool06oooool2o`0000Oooooo0_l0002J
ooooo`;o0000B?ooool2o`0003_ooooo000Nooooo`03o`000?oooooooooo01_ooooo0_l0000Qoooo
o`;o00002_ooool2o`0004Cooooo0_l0001=ooooo`;o0000I_ooool001kooooo00?o0000oooooooo
ool0?_ooool2o`0000[ooooo0_l00014ooooo`;o0000COooool2o`0003Wooooo0_l0000[ooooo`00
7_ooool00ol0003oooooooooo`2nooooo`;o0000F_ooool2o`0002_ooooo000Nooooo`03o`000?oo
oooooooo07gooooo0_l0000oooooo`;o0000Qoooool001kooooo00?o0000ooooooooool0;oooool2
o`0004cooooo0_l0002`ooooo`;o00005_ooool001kooooo00?o0000ooooooooool0;oooool2o`00
037ooooo0_l0003;ooooo`;o00005_ooool001kooooo00?o0000ooooooooool0H_ooool2o`0001Co
oooo0_l0000]ooooo`;o0000W_ooool001kooooo00?o0000ooooooooool08oooool2o`0005?ooooo
0_l0000;ooooo`;o00008?ooool2o`00017ooooo0_l0001gooooo`;o00001Oooool2o`0000_ooooo
000Nooooo`03o`000?oooooooooo013ooooo1?l0000:ooooo`;o00000oooool2o`0003_ooooo0_l0
000Sooooo`;o0000<oooool2o`0003Wooooo0_l0000looooo`;o00001Oooool2o`0000_ooooo000N
ooooo`;o00004Oooool4o`0000[ooooo0_l0000Eooooo`;o00006Oooool2o`0000kooooo0_l0001<
ooooo`;o00004Oooool2o`0001Oooooo0_l0000Iooooo`;o00000_ooool2o`0004cooooo000Noooo
o`03o`000?oooooooooo03Gooooo0_l0000Gooooo`Co00001Oooool2o`0005Gooooo0_l0000Aoooo
o`;o00005oooool2o`0001gooooo0_l0000Uooooo`;o00003Oooool2o`0001Kooooo000Nooooo`03
o`000?oooooooooo04kooooo0_l00007ooooo`;o00005_ooool2o`0003;ooooo0_l0001_ooooo`;o
00002_ooool2o`0000gooooo0_l0000Fooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o0000
G?ooool2o`0003;ooooo0_l0000:ooooo`;o0000<?ooool2o`00037ooooo0_l0000aooooo`007_oo
ool00ol0003oooooooooo`0Aooooo`;o0000Eoooool2o`0003Cooooo0_l00006ooooo`;o00001Ooo
ool2o`00033ooooo0_l00012ooooo`;o00008?ooool001kooooo00?o0000ooooooooool0J_ooool2
o`0000gooooo0_l0000Uooooo`;o00001_ooool2o`0007_ooooo0_l0000Pooooo`007_ooool00ol0
003oooooooooo`1Iooooo`;o00007_ooool2o`0006Gooooo0_l00013ooooo`;o00008?ooool001ko
oooo00?o0000ooooooooool0FOooool2o`0004Oooooo0_l0000looooo`;o0000@oooool2o`00023o
oooo000Nooooo`03o`000?oooooooooo01oooooo0_l0000=ooooo`;o0000L_ooool2o`0004Cooooo
0_l0001Mooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o00003Oooool2o`0000Kooooo0_l0
002`ooooo`;o0000>oooool2o`00023ooooo000Nooooo`03o`000?oooooooooo03Kooooo0_l0000:
ooooo`;o00009_ooool2o`000;Wooooo0_l0000Pooooo`007_ooool00ol0003oooooooooo`12oooo
o`;o00005_ooool2o`0000kooooo0_l0000iooooo`;o0000X?ooool001kooooo00?o0000oooooooo
ool0;oooool2o`0002Wooooo0_l00019ooooo`;o00002_ooool2o`0009Cooooo000Nooooo`03o`00
0?oooooooooo02oooooo0_l00020ooooo`;o0000U?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000oooooooo
ool00_ooool2o`0000oooooo0_l00009ooooo`;o0000J?ooool2o`0003;ooooo0_l0001Fooooo`;o
0000<Oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7o
V9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool00_ooool4o`0000gooooo0_l00009oooo
o`;o00007?ooool2o`0004[ooooo0_l0000booooo`;o0000E_ooool2o`00037ooooo0003ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004
ooooo`?o00003Oooool2o`0002Kooooo0_l0001Hooooo`;o0000[oooool000?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool00ol0003ooooooooo
o`05ooooo`;o00002Oooool2o`0000;ooooo0_l00020ooooo`;o0000[oooool000?ooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003ooooo
ooooo`0@ooooo`;o0000BOooool2o`000>[ooooo0003ooooo`05oa0@4?ooooooooooooooool@4100
2oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool08?ooool2o`0003Ko
oooo0_l000001?oooooo0000o`000?l0001Gooooo`;o0000;_ooool2o`0000;ooooo0_l0000Moooo
o`;o0000?Oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooo
okZj^_l000001_ooool00ol0003oooooooooo`0Pooooo`;o00007?ooool2o`0001Sooooo0_l00002
ooooo`;o00005_ooool2o`0003oooooo0_l0000^ooooo`;o00000_ooool2o`0001gooooo0_l0000m
ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVY
Z@06ooooo`03o`000?oooooooooo037ooooo0_l0000;ooooo`;o0000=?ooool2o`0001_ooooo0_l0
001Eooooo`;o0000GOooool001kooooo00?o0000ooooooooool09?ooool2o`0000_ooooo0_l0001N
ooooo`;o0000EOooool2o`0005gooooo000Nooooo`03o`000?oooooooooo01?ooooo0_l0000?oooo
o`;o0000<Oooool2o`0000Cooooo0_l0000Fooooo`;o0000]_ooool2o`0000;ooooo0_l0000Doooo
o`007_ooool00ol0003oooooooooo`0Cooooo`;o0000@_ooool2o`0000Cooooo0_l0000Fooooo`;o
00001Oooool2o`0002gooooo0_l0000Rooooo`;o0000G?ooool2o`0000;ooooo0_l0000Dooooo`00
7_ooool00ol0003oooooooooo`1looooo`;o0000;Oooool2o`0002;ooooo0_l0001fooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo07Wooooo0_l0000/
ooooo`;o0000W_ooool001kooooo00?o0000ooooooooool0>oooool2o`0001?ooooo0_l0000Woooo
o`;o0000;?ooool4o`0007Wooooo0_l0000Qooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o
000000?oooooo`000?l000005_ooool2o`0001?ooooo0_l0001Gooooo`;o00007Oooool2o`00017o
oooo0_l0000^ooooo`;o00005oooool2o`00027ooooo000Nooooo`?o00008?ooool2o`000003oooo
ool0003o00000:?ooooo0_l0000Aooooo`;o0000;_ooool2o`0003[ooooo000Nooooo`?o00001Ooo
ool2o`0005cooooo0_l0000mooooo`;o0000Goooool2o`0003_ooooo0_l00005ooooo`007_ooool3
o`0000Gooooo0_l0000Hooooo`;o00001_ooool2o`0003[ooooo0_l0000mooooo`;o0000<oooool2
o`0002[ooooo0_l0000kooooo`;o00001Oooool001kooooo0_l0000Looooo`;o00000_ooool2o`00
00?ooooo0_l000000ooooooo0000o`00002^ooooo`;o0000Boooool2o`0000;ooooo0_l0000Moooo
o`007_ooool00ol0003oooooooooo`0Gooooo`;o00000_ooool2o`0000Oooooo0_l0000eooooo`;o
0000N_ooool2o`0004_ooooo0_l00002ooooo`;o00007Oooool001kooooo00?o0000ooooooooool0
5oooool2o`0001Kooooo0_l00007ooooo`;o00008Oooool2o`0007[ooooo0_l0000gooooo`;o0000
:Oooool2o`0000[ooooo000Nooooo`;o00004_ooool2o`000003ooooool0003o000001Wooooo0_l0
0007ooooo`;o0000Noooool2o`0005Wooooo0_l0000Yooooo`;o00002_ooool001kooooo0_l0000B
ooooo`;o000000?oooooo`000?l00000LOooool2o`0002cooooo0_l0000Cooooo`;o00002_ooool2
o`0001[ooooo0_l0001Cooooo`007_ooool00ol0003oooooooooo`1>ooooo`;o0000=oooool2o`00
03Cooooo0_l0000;ooooo`;o00002_ooool2o`0001[ooooo0_l0001Cooooo`007_ooool00ol0003o
ooooooooo`1>ooooo`;o0000@_ooool2o`0002?ooooo0_l00004ooooo`;o0000R?ooool001kooooo
00?o0000ooooooooool09Oooool2o`0000kooooo0_l0001Kooooo`;o00005?ooool2o`000003oooo
ool0003o000000[ooooo0_l0001=ooooo`;o0000?oooool001kooooo00?o0000ooooooooool09Ooo
ool2o`0000kooooo0_l00017ooooo`;o0000:?ooool2o`000003ooooool0003o000005Wooooo0_l0
000@ooooo`;o00003_ooool2o`0001gooooo000Nooooo`03o`000?oooooooooo05Cooooo0_l0000X
ooooo`;o0000H_ooool2o`0003Cooooo0_l0000>ooooo`;o00000oooool2o`0001Sooooo000Noooo
o`03o`000?oooooooooo053ooooo0_l00002ooooo`;o00005Oooool2o`0000Gooooo0_l0000>oooo
o`;o0000G_ooool2o`0001Wooooo0_l0000Booooo`;o00006_ooool2o`0001Sooooo000Nooooo`03
o`000?oooooooooo03oooooo0_l00002ooooo`;o00002oooool3o`0001Sooooo0_l00005ooooo`;o
00003_ooool2o`00043ooooo0_l0000gooooo`;o00004_ooool2o`0001;ooooo0_l0000Pooooo`00
7_ooool00ol0003oooooooooo`02o`000003ooooool0003o000003[ooooo0_l00002ooooo`;o0000
3?ooool2o`0000Oooooo0ol0001Wooooo`;o0000EOooool2o`0000Sooooo0_l0000Pooooo`007_oo
ool00ol0003oooooooooo`02o`000003ooooool0003o000003kooooo0_l0000Eooooo`?o0000__oo
ool2o`0002[ooooo000Nooooo`03o`000?oooooooooo04[ooooo0_l0000Hooooo`;o00001?ooool2
o`000=_ooooo000Nooooo`03o`000?oooooooooo04[ooooo0_l0000Hooooo`;o00001?ooool2o`00
01kooooo0_l0002kooooo`007_ooool2o`0008_ooooo0_l0000Mooooo`;o0000P?ooool2o`0000So
oooo0_l0000@ooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o0000>oooool2o`0000cooooo
0_l0000?ooooo`;o0000>_ooool2o`0007oooooo0ol00008ooooo`;o00004?ooool001kooooo00?o
0000ooooooooool04Oooool2o`0003_ooooo0_l0000<ooooo`;o00003oooool2o`000;_ooooo0_l0
000Kooooo`007_ooool00ol0003oooooooooo`0hooooo`;o0000joooool2o`00023ooooo000Noooo
o`03o`000?oooooooooo03Sooooo0_l0000Qooooo`;o0000M_ooool2o`0003gooooo0_l0000Aoooo
o`;o00008?ooool001kooooo00?o0000ooooooooool01_ooool2o`0005?ooooo0_l0001fooooo`;o
0000?Oooool2o`0003?ooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l0000jooooo`;o0000
4?ooool2o`0006oooooo0_l0000Qooooo`;o0000GOooool001kooooo00?o0000ooooooooool02ooo
ool2o`0003Gooooo0_l0000@ooooo`;o0000Koooool2o`00027ooooo0_l0001Mooooo`007_ooool0
0ol0003oooooooooo`0;ooooo`;o00004_ooool2o`0000Wooooo0_l0000Dooooo`;o0000Foooool2
o`0000?ooooo0_l0001]ooooo`;o00008?ooool2o`0001;ooooo000Nooooo`03o`000?oooooooooo
01oooooo0_l00005ooooo`;o00000_ooool2o`0001Cooooo0_l0000nooooo`;o00005Oooool2o`00
00Cooooo0_l00003ooooo`;o0000KOooool2o`00023ooooo0_l0000Booooo`007_ooool00ol0003o
ooooooooo`0Vooooo`;o00003_ooool2o`0004Sooooo0_l0000Eooooo`;o00009_ooool2o`0005Oo
oooo0_l0000]ooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o00005?ooool2o`0000cooooo
0_l00006ooooo`;o0000M?ooool2o`00017ooooo0_l0000Iooooo`;o0000??ooool2o`0002gooooo
000Nooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo0000o`00000Aooooo`;o00003?oo
ool2o`0003oooooo0_l0000kooooo`;o00003_ooool2o`0001cooooo0_l0000looooo`;o0000;Ooo
ool001kooooo00?o0000ooooooooool03Oooool2o`0004Gooooo0_l0000Iooooo`;o00002oooool2
o`0000?ooooo0_l0000Tooooo`;o00004oooool2o`0002?ooooo0_l0001Tooooo`007_ooool00ol0
003oooooooooo`0Looooo`;o00004_ooool2o`0000oooooo0_l0000Aooooo`;o00009_ooool2o`00
00?ooooo0_l0000Tooooo`;o0000>?ooool2o`0006Cooooo000Nooooo`03o`000?oooooooooo01co
oooo0_l0000Booooo`;o00003oooool2o`0004gooooo0_l0002eooooo`007_ooool2o`00097ooooo
0_l0002;ooooo`;o0000:?ooool001kooooo0ol0001_ooooo`;o0000[?ooool2o`0002Sooooo000N
ooooo`?o0000>oooool2o`0003;ooooo0_l0000Zooooo`;o00008_ooool2o`0001Sooooo0_l0001/
ooooo`007_ooool01?l0003oooooooooooooool2o`0003Sooooo0_l0001Nooooo`;o00008_ooool2
o`0001Sooooo0_l0001/ooooo`007_ooool01?l0003oooooooooooooool2o`0007?ooooo0_l0001L
ooooo`;o0000=_ooool2o`0003Wooooo000Nooooo`03o`000?oooooooooo07Kooooo0_l0000Loooo
o`;o0000?_ooool2o`0003Kooooo0_l0000iooooo`007_ooool00ol0003oooooooooo`0jooooo`;o
0000F?ooool2o`0003Gooooo0_l0000iooooo`;o0000?oooool001kooooo00?o0000ooooooooool0
>_ooool2o`0002Gooooo1?l00005ooooo`;o0000Goooool2o`0003Wooooo0_l0000oooooo`007_oo
ool00ol0003oooooooooo`1Qooooo`Co00001Oooool2o`0002[ooooo0_l0002_ooooo`007_ooool0
0ol0003oooooooooo`1]ooooo`;o00009oooool2o`0000Sooooo0_l0002Booooo`;o00001?ooool2
o`0000_ooooo000Nooooo`03o`000?oooooooooo06gooooo0_l0000;ooooo`;o00009?ooool2o`00
017ooooo0_l0001oooooo`;o00001?ooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo02Wo
oooo0_l0001?ooooo`;o0000=oooool2o`0003Gooooo0_l0000Wooooo`;o0000<_ooool001kooooo
00?o0000ooooooooool0:Oooool2o`0008[ooooo0_l0000Zooooo`;o00001oooool2o`0000?ooooo
0_l00002ooooo`;o00007_ooool2o`0000;ooooo0_l0000>ooooo`;o00007_ooool001kooooo00?o
0000ooooooooool0]Oooool2o`0002[ooooo0_l0000<ooooo`;o00000_ooool2o`0002;ooooo0_l0
000:ooooo`;o00000_ooool2o`0001kooooo000Dooooo`Co000000?o410@ooooooooool00oooool0
0ol0003oooooooooo`1Jooooo`;o00007oooool2o`000003ooooool0003o00000:?ooooo0_l0000R
ooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo0_l0000[oooo
o`;o0000:?ooool2o`0001oooooo0_l000001?oooooo0000o`000?ooool2o`0002kooooo0_l0002D
ooooo`005_ooool00ol0003oooooooooo`05ooooo`?o00000oooool2o`00017ooooo0_l0000Hoooo
o`;o0000;?ooool2o`00027ooooo0_l0000^ooooo`;o0000U?ooool001Kooooo00?o0000oooooooo
ool07_ooool2o`0004Kooooo0_l0003Wooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo
000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@
ooooo`005?ooool00omEEEGoIVIVo`00003ooooooe;ooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.12098 .68067 Mdot
.83135 .43064 Mdot
.11191 .50297 Mdot
.0614 .02984 Mdot
.37285 .42403 Mdot
.25045 .04177 Mdot
.61947 .02294 Mdot
.25718 .46406 Mdot
.30797 .97223 Mdot
.76949 .01245 Mdot
.32812 .20872 Mdot
.45688 .09612 Mdot
.23094 .53608 Mdot
.62893 .66267 Mdot
.15782 .03265 Mdot
.57497 .63112 Mdot
.76541 .61768 Mdot
.34297 .57749 Mdot
.14994 .6083 Mdot
.09933 .1169 Mdot
.83133 .62819 Mdot
.31858 .11344 Mdot
.47222 .42607 Mdot
.85058 .02781 Mdot
.25551 .88225 Mdot
.20794 .37525 Mdot
.12573 .83897 Mdot
.58908 .72811 Mdot
.34725 .21269 Mdot
.25891 .1447 Mdot
.21921 .60511 Mdot
.17384 .02202 Mdot
.38218 .98329 Mdot
.86289 .91428 Mdot
.91481 .55404 Mdot
.0223 .88796 Mdot
.63321 .674 Mdot
.81423 .52178 Mdot
.51961 .83295 Mdot
.19644 .79702 Mdot
.19036 .60794 Mdot
.95758 .64571 Mdot
.98203 .99973 Mdot
.78671 .61305 Mdot
.55734 .03152 Mdot
.9467 .70711 Mdot
.6558 .46477 Mdot
.94828 .82389 Mdot
.03732 .79958 Mdot
.13506 .29609 Mdot
.46115 .96745 Mdot
.93675 .49672 Mdot
.28708 .3569 Mdot
.00789 .84812 Mdot
.31927 .35343 Mdot
.21245 .22863 Mdot
.76063 .31488 Mdot
.26822 .51628 Mdot
.11466 .84833 Mdot
.33907 .69408 Mdot
.09784 .05217 Mdot
.22944 .42024 Mdot
.60211 .09461 Mdot
.28892 .91363 Mdot
.30092 .74795 Mdot
.31285 .06306 Mdot
.99777 .39931 Mdot
.11837 .83803 Mdot
.23118 .06904 Mdot
.824 .31854 Mdot
.13404 .22504 Mdot
.45862 .61997 Mdot
.04998 .16476 Mdot
.25292 .21794 Mdot
.42082 .07165 Mdot
.95944 .30247 Mdot
.13454 .33255 Mdot
.64102 .23199 Mdot
.14807 .92354 Mdot
.5228 .40002 Mdot
.93204 .8546 Mdot
.70345 .0831 Mdot
.79471 .62129 Mdot
.2378 .45625 Mdot
.75032 .452 Mdot
.99726 .2263 Mdot
.30091 .39578 Mdot
.05333 .92024 Mdot
.19794 .05204 Mdot
.38291 .67771 Mdot
.06485 .12828 Mdot
.85355 .28261 Mdot
.1507 .28507 Mdot
.1502 .21193 Mdot
.34739 .64835 Mdot
.92296 .76361 Mdot
.60865 .18503 Mdot
.92384 .53371 Mdot
.28964 .81085 Mdot
.8895 .60264 Mdot
.12753 .74631 Mdot
.46815 .93033 Mdot
.07806 .61569 Mdot
.61265 .64029 Mdot
.91474 .3325 Mdot
.46857 .43307 Mdot
.53968 .67725 Mdot
.5643 .66241 Mdot
.95324 .49213 Mdot
.66178 .1311 Mdot
.62945 .68268 Mdot
.79909 .51312 Mdot
.51741 .94394 Mdot
.29377 .59029 Mdot
.46434 .3258 Mdot
.66093 .96753 Mdot
.55099 .99862 Mdot
.19249 .52835 Mdot
.02056 .30635 Mdot
.58621 .86952 Mdot
.08114 .82024 Mdot
.95277 .73523 Mdot
.40835 .12944 Mdot
.15411 .21428 Mdot
.88503 .19741 Mdot
.85569 .61262 Mdot
.3902 .87984 Mdot
.1796 .66127 Mdot
.86056 .88533 Mdot
.99979 .13289 Mdot
.84995 .5665 Mdot
.38019 .2675 Mdot
.7797 .74945 Mdot
.43778 .53753 Mdot
.34927 .61218 Mdot
.3009 .32674 Mdot
.45349 .42454 Mdot
.44903 .69309 Mdot
.08558 .54816 Mdot
.29207 .03253 Mdot
.21503 .65923 Mdot
.29094 .90386 Mdot
.37051 .08635 Mdot
.92324 .62617 Mdot
.59473 .33381 Mdot
.44509 .09465 Mdot
.23822 .72171 Mdot
.1588 .77397 Mdot
.77176 .29877 Mdot
.67878 .08067 Mdot
.70204 .75859 Mdot
.38583 .03783 Mdot
.47914 .0963 Mdot
.10884 .1298 Mdot
.129 .99801 Mdot
.19521 .50265 Mdot
.49783 .6588 Mdot
.7315 .39611 Mdot
.26885 .94055 Mdot
.5566 .63059 Mdot
.48022 .63142 Mdot
.89755 .55382 Mdot
.79549 .88354 Mdot
.46974 .52479 Mdot
.28358 .78744 Mdot
.37778 .39439 Mdot
.18123 .77714 Mdot
.20897 .88469 Mdot
.65673 .11517 Mdot
.45704 .4872 Mdot
.38417 .1608 Mdot
.91911 .85398 Mdot
.90138 .53289 Mdot
.02222 .2914 Mdot
.12829 .65709 Mdot
.50326 .76988 Mdot
.82302 .87528 Mdot
.14641 .39454 Mdot
.62774 .09457 Mdot
.9294 .50299 Mdot
.98757 .97778 Mdot
.42988 .02253 Mdot
.56236 .80774 Mdot
.53761 .16253 Mdot
.68689 .26856 Mdot
.52155 .87513 Mdot
.55583 .62267 Mdot
.03167 .09556 Mdot
.76711 .74751 Mdot
.90575 .70836 Mdot
.14783 .6579 Mdot
.9762 .21041 Mdot
.16971 .67626 Mdot
.51421 .19038 Mdot
.56765 .87313 Mdot
.99346 .02658 Mdot
.90744 .58614 Mdot
.42936 .15007 Mdot
.31583 .97087 Mdot
.40833 .05808 Mdot
.5478 .21509 Mdot
.51671 .34509 Mdot
.41228 .56328 Mdot
.55071 .12927 Mdot
.25851 .88688 Mdot
.05124 .93309 Mdot
.66962 .02945 Mdot
.07297 .90367 Mdot
.78524 .41702 Mdot
.60017 .74886 Mdot
.44219 .45896 Mdot
.19427 .68905 Mdot
.90362 .22908 Mdot
.66463 .34012 Mdot
.46514 .6605 Mdot
.11424 .21574 Mdot
.21493 .78111 Mdot
.0834 .27989 Mdot
.5221 .76074 Mdot
.03135 .37273 Mdot
.75763 .33291 Mdot
.39181 .61756 Mdot
.2875 .88908 Mdot
.21129 .92526 Mdot
.38264 .64977 Mdot
.51941 .58099 Mdot
.92734 .98684 Mdot
.42207 .36908 Mdot
.6968 .20099 Mdot
.35924 .08029 Mdot
.17299 .44946 Mdot
.33707 .70946 Mdot
.39044 .09502 Mdot
.9603 .09102 Mdot
.11268 .21343 Mdot
.74054 .165 Mdot
.71071 .55485 Mdot
.20493 .57568 Mdot
.81251 .56454 Mdot
.76529 .21703 Mdot
.12518 .3714 Mdot
.39103 .12352 Mdot
.96607 .92508 Mdot
.0729 .42254 Mdot
.53117 .82377 Mdot
.11843 .33236 Mdot
.43015 .60568 Mdot
.35526 .15885 Mdot
.72315 .0616 Mdot
.17032 .58438 Mdot
.9396 .48304 Mdot
.37928 .37599 Mdot
.82533 .12277 Mdot
.00046 .23557 Mdot
.87929 .18918 Mdot
.96157 .82356 Mdot
.32275 .37139 Mdot
.84659 .48814 Mdot
.90627 .75371 Mdot
.46554 .32437 Mdot
.16676 .7027 Mdot
.30823 .73844 Mdot
.2307 .22454 Mdot
.93214 .36817 Mdot
.38923 .10384 Mdot
.9449 .12826 Mdot
.50293 .92635 Mdot
.01089 .30432 Mdot
.19379 .55487 Mdot
.16669 .8152 Mdot
.2862 .8081 Mdot
.68071 .48742 Mdot
.14808 .09294 Mdot
.34852 .75561 Mdot
.93255 .87745 Mdot
.41817 .39546 Mdot
.49795 .76063 Mdot
.48504 .2589 Mdot
.01586 .84602 Mdot
.482 .95822 Mdot
.80412 .28229 Mdot
.33798 .13035 Mdot
.48813 .48876 Mdot
.64291 .64417 Mdot
.35854 .39046 Mdot
.28575 .88982 Mdot
.44145 .51265 Mdot
.86932 .49847 Mdot
.96612 .74534 Mdot
.35853 .23119 Mdot
.97157 .90089 Mdot
.86302 .27904 Mdot
.1598 .61326 Mdot
.51434 .14387 Mdot
.63073 .13046 Mdot
.87728 .50284 Mdot
.25644 .74933 Mdot
.55228 .61565 Mdot
.8029 .24146 Mdot
.70643 .12088 Mdot
.86762 .49657 Mdot
.33535 .88395 Mdot
.91596 .58988 Mdot
.46646 .59171 Mdot
.75814 .99272 Mdot
.96874 .45229 Mdot
.13823 .84681 Mdot
.10537 .9419 Mdot
.86472 .1088 Mdot
.5025 .33335 Mdot
.07495 .85967 Mdot
.79969 .22126 Mdot
.20492 .3807 Mdot
.43916 .34088 Mdot
.28054 .77151 Mdot
.98869 .74649 Mdot
.51388 .78349 Mdot
.02076 .28988 Mdot
.38528 .94488 Mdot
.91984 .34525 Mdot
.52548 .83529 Mdot
.3878 .01767 Mdot
.46724 .97857 Mdot
.58491 .79304 Mdot
.28023 .6045 Mdot
.16648 .46294 Mdot
.01803 .84406 Mdot
.18498 .7109 Mdot
.45154 .05651 Mdot
.18741 .43219 Mdot
.07406 .11475 Mdot
.26219 .06818 Mdot
.51167 .28068 Mdot
.85819 .06884 Mdot
.05116 .30895 Mdot
.25362 .27213 Mdot
.74889 .69783 Mdot
.11895 .80922 Mdot
.75589 .86501 Mdot
.93128 .10034 Mdot
.27885 .81032 Mdot
.74642 .67389 Mdot
.22215 .68387 Mdot
.47172 .59784 Mdot
.70708 .39405 Mdot
.62185 .54079 Mdot
.65866 .09748 Mdot
.37567 .27071 Mdot
.91822 .39684 Mdot
.27008 .46544 Mdot
.17449 .53246 Mdot
.34606 .37041 Mdot
.8851 .72254 Mdot
.59286 .68544 Mdot
.63796 .04696 Mdot
.12933 .07871 Mdot
.95639 .63236 Mdot
.46286 .54535 Mdot
.26818 .5391 Mdot
.11036 .27216 Mdot
.35618 .14182 Mdot
.83117 .80959 Mdot
.20179 .61149 Mdot
.44521 .45101 Mdot
.31492 .89527 Mdot
.86651 .75628 Mdot
.66995 .8575 Mdot
.73163 .67089 Mdot
.73897 .2157 Mdot
.25844 .12339 Mdot
.44795 .6679 Mdot
.16241 .85554 Mdot
.12905 .52973 Mdot
.33122 .04605 Mdot
.92187 .90987 Mdot
.88062 .59652 Mdot
.5648 .0235 Mdot
.03799 .84767 Mdot
.89641 .16535 Mdot
.28668 .16687 Mdot
.16655 .94183 Mdot
.04445 .03934 Mdot
.69833 .2644 Mdot
.87607 .18587 Mdot
.57704 .74321 Mdot
.53274 .13363 Mdot
.68055 .84124 Mdot
.66559 .52882 Mdot
.12875 .81865 Mdot
.64177 .68456 Mdot
.21954 .65195 Mdot
.36052 .51467 Mdot
.08751 .71374 Mdot
.32924 .47305 Mdot
.35674 .44324 Mdot
.45586 .28357 Mdot
.7803 .68667 Mdot
.92894 .15006 Mdot
.10296 .85097 Mdot
.2485 .61312 Mdot
.98559 .03154 Mdot
.58397 .94052 Mdot
.75175 .36891 Mdot
.22783 .43149 Mdot
.67447 .66692 Mdot
.89671 .95101 Mdot
.31404 .22606 Mdot
.40405 .6573 Mdot
.51578 .54068 Mdot
.47041 .51847 Mdot
.43794 .67639 Mdot
.23925 .89558 Mdot
.46461 .64419 Mdot
.63248 .97455 Mdot
.73288 .26824 Mdot
.40722 .54535 Mdot
.0666 .60806 Mdot
.51536 .59427 Mdot
.73387 .3679 Mdot
.13551 .92625 Mdot
.19616 .83652 Mdot
.62287 .41276 Mdot
.739 .1579 Mdot
.38 .52358 Mdot
.25483 .50233 Mdot
.75289 .55267 Mdot
.52111 .22428 Mdot
.32539 .01184 Mdot
.46752 .61717 Mdot
.79508 .41102 Mdot
.75415 .24388 Mdot
.66473 .48164 Mdot
.54541 .40861 Mdot
.05162 .06503 Mdot
.81583 .25356 Mdot
.63441 .547 Mdot
.54069 .74725 Mdot
.91421 .98893 Mdot
.04311 .52376 Mdot
.55834 .98319 Mdot
.52421 .90418 Mdot
.78946 .55085 Mdot
.794 .64708 Mdot
.12158 .06538 Mdot
.22942 .24852 Mdot
.08696 .99698 Mdot
.39235 .99791 Mdot
.40978 .46067 Mdot
.85044 .23893 Mdot
.50487 .47091 Mdot
.83555 .71282 Mdot
.96436 .49315 Mdot
.27715 .82268 Mdot
.18367 .92872 Mdot
.48657 .16307 Mdot
.08271 .86006 Mdot
.26967 .92028 Mdot
.01425 .86213 Mdot
.87991 .93324 Mdot
.55433 .40462 Mdot
.03604 .69552 Mdot
.05993 .93546 Mdot
.19425 .9662 Mdot
.11527 .45333 Mdot
.9033 .15514 Mdot
.92048 .51748 Mdot
.38464 .99542 Mdot
.85831 .64634 Mdot
.1373 .06135 Mdot
.86999 .7937 Mdot
.26686 .13154 Mdot
.27928 .39786 Mdot
.2459 .45392 Mdot
.24213 .45569 Mdot
.0851 .47796 Mdot
.1652 .99314 Mdot
.16954 .3307 Mdot
.2394 .48701 Mdot
.76193 .32536 Mdot
.37655 .83601 Mdot
.63337 .25787 Mdot
.52607 .0434 Mdot
.36737 .12032 Mdot
.24773 .64802 Mdot
.14214 .68201 Mdot
.01708 .19964 Mdot
.0721 .20423 Mdot
.85275 .20418 Mdot
.9225 .88761 Mdot
.59674 .71513 Mdot
.1585 .55401 Mdot
.22038 .88423 Mdot
.49529 .28645 Mdot
.6687 .85033 Mdot
.14166 .15805 Mdot
.417 .1847 Mdot
.02293 .48217 Mdot
.40208 .99857 Mdot
.94909 .27071 Mdot
.54832 .78685 Mdot
.06122 .39153 Mdot
.96402 .07162 Mdot
.92159 .83875 Mdot
.73325 .18673 Mdot
.3848 .54763 Mdot
.07041 .34125 Mdot
.25859 .39816 Mdot
.62285 .14275 Mdot
.25113 .90498 Mdot
.21549 .14924 Mdot
.30012 .62752 Mdot
.6417 .35831 Mdot
.26828 .24175 Mdot
.69695 .28522 Mdot
.35252 .4131 Mdot
.96994 .10707 Mdot
.99263 .86048 Mdot
.92404 .76772 Mdot
.7135 .46435 Mdot
.27233 .61696 Mdot
.44137 .56587 Mdot
.09421 .47071 Mdot
.15888 .93117 Mdot
.41337 .09726 Mdot
.89286 .68912 Mdot
.72802 .80852 Mdot
.50459 .28688 Mdot
.77442 .69645 Mdot
.5261 .43388 Mdot
.88176 .93732 Mdot
.84157 .96434 Mdot
.58321 .3084 Mdot
.36276 .39943 Mdot
.50324 .84736 Mdot
.22969 .46251 Mdot
.11438 .74669 Mdot
.33401 .7619 Mdot
.3493 .94163 Mdot
.83998 .46837 Mdot
.58523 .22816 Mdot
.29142 .03535 Mdot
.72577 .29329 Mdot
.44167 .08084 Mdot
.14571 .98131 Mdot
.10214 .69383 Mdot
.6104 .13775 Mdot
.84901 .23333 Mdot
.50281 .40059 Mdot
.48199 .47883 Mdot
.17304 .46636 Mdot
.6609 .01427 Mdot
.56053 .21791 Mdot
.36846 .96674 Mdot
.85721 .92772 Mdot
.94802 .88084 Mdot
.70199 .94749 Mdot
.84794 .19243 Mdot
.11226 .79354 Mdot
.01618 .95399 Mdot
.56311 .39652 Mdot
.47373 .48946 Mdot
.40071 .9461 Mdot
.83301 .47793 Mdot
.86189 .70874 Mdot
.42551 .52461 Mdot
.03093 .7955 Mdot
.49438 .63688 Mdot
.28655 .85794 Mdot
.65974 .44737 Mdot
.20737 .05181 Mdot
.65988 .49301 Mdot
.60726 .66228 Mdot
.1795 .00622 Mdot
.20373 .72082 Mdot
.33517 .53088 Mdot
.34667 .0113 Mdot
.91995 .00972 Mdot
.3439 .21321 Mdot
.38076 .37246 Mdot
.06925 .36727 Mdot
.72509 .92409 Mdot
.84876 .30039 Mdot
.08693 .42099 Mdot
.22498 .63827 Mdot
.89413 .40871 Mdot
.03877 .91675 Mdot
.53096 .87511 Mdot
.65587 .91857 Mdot
.62777 .86709 Mdot
.30823 .68725 Mdot
.24332 .49521 Mdot
.26545 .33171 Mdot
.49609 .57899 Mdot
.40291 .02249 Mdot
.44194 .15756 Mdot
.20011 .39073 Mdot
.5442 .75687 Mdot
.18327 .46318 Mdot
.03179 .88768 Mdot
.48165 .54838 Mdot
.36285 .02764 Mdot
.18873 .85677 Mdot
.14692 .53413 Mdot
.9231 .53587 Mdot
.59609 .96004 Mdot
.47563 .52202 Mdot
.16106 .78638 Mdot
.30961 .13708 Mdot
.58606 .0336 Mdot
.1501 .68788 Mdot
.57515 .13545 Mdot
.62827 .13747 Mdot
.2158 .10495 Mdot
.43895 .2788 Mdot
.10883 .58358 Mdot
.51866 .74034 Mdot
.46004 .62414 Mdot
.04608 .22496 Mdot
.31015 .84648 Mdot
.72213 .09288 Mdot
.72364 .81587 Mdot
.5833 .39377 Mdot
.15902 .67558 Mdot
.96869 .25384 Mdot
.94855 .56157 Mdot
.49661 .98168 Mdot
.86359 .9863 Mdot
.9868 .22809 Mdot
.36715 .35736 Mdot
.95785 .00278 Mdot
.07877 .5134 Mdot
.21622 .91719 Mdot
.31598 .69373 Mdot
.59944 .52412 Mdot
.18898 .01169 Mdot
.65563 .25831 Mdot
.24103 .46209 Mdot
.1501 .29481 Mdot
.37518 .47795 Mdot
.17189 .04986 Mdot
.0215 .11814 Mdot
.22656 .04531 Mdot
.96688 .60783 Mdot
.01947 .13008 Mdot
.61367 .92426 Mdot
.38329 .60667 Mdot
.42694 .90258 Mdot
.73807 .3371 Mdot
.21016 .45013 Mdot
.58688 .05968 Mdot
.82042 .97296 Mdot
.41487 .00568 Mdot
.81535 .84714 Mdot
.21564 .94185 Mdot
.85005 .23384 Mdot
.20234 .81204 Mdot
.22644 .33127 Mdot
.80982 .20754 Mdot
.78392 .41563 Mdot
.09273 .85522 Mdot
.56519 .99143 Mdot
.46614 .80019 Mdot
.75644 .0285 Mdot
.07105 .80412 Mdot
.96205 .17056 Mdot
.85449 .85882 Mdot
.1192 .93226 Mdot
.62997 .04992 Mdot
.88899 .61194 Mdot
.83904 .84196 Mdot
.10745 .19497 Mdot
.74637 .99359 Mdot
.51175 .20793 Mdot
.27369 .17536 Mdot
.76058 .19781 Mdot
.22282 .39354 Mdot
.804 .03275 Mdot
.36629 .52347 Mdot
.69059 .09225 Mdot
.74519 .47188 Mdot
.82936 .46147 Mdot
.92431 .63393 Mdot
.72479 .26378 Mdot
.17094 .65551 Mdot
.20697 .04849 Mdot
.89752 .48089 Mdot
.42096 .86588 Mdot
.66619 .10271 Mdot
.6205 .84061 Mdot
.28792 .57259 Mdot
.95335 .7546 Mdot
.54826 .09703 Mdot
.12304 .28986 Mdot
.63643 .45355 Mdot
.37727 .02093 Mdot
.46703 .79863 Mdot
.19739 .95468 Mdot
.584 .31834 Mdot
.74358 .10812 Mdot
.91654 .22182 Mdot
.12685 .26297 Mdot
.60075 .64901 Mdot
.19266 .50898 Mdot
.08504 .55353 Mdot
.08058 .21969 Mdot
.40605 .08934 Mdot
.68278 .19868 Mdot
.93857 .2888 Mdot
.47969 .23978 Mdot
.33575 .97219 Mdot
.73613 .14885 Mdot
.41411 .74136 Mdot
.60952 .8902 Mdot
.80492 .10946 Mdot
.42461 .38041 Mdot
.75291 .54123 Mdot
.36288 .14615 Mdot
.31675 .4575 Mdot
.67591 .96298 Mdot
.38644 .15076 Mdot
.19484 .70366 Mdot
.05925 .18757 Mdot
.43931 .56238 Mdot
.61094 .44111 Mdot
.84095 .67342 Mdot
.81206 .34122 Mdot
.3839 .30546 Mdot
.08421 .80025 Mdot
.03455 .14707 Mdot
.73787 .33777 Mdot
.33631 .19098 Mdot
.33867 .17736 Mdot
.16159 .49577 Mdot
.29018 .99117 Mdot
.67765 .9407 Mdot
.65839 .55013 Mdot
.85461 .24787 Mdot
.85316 .20678 Mdot
.44648 .9509 Mdot
.7915 .39891 Mdot
.42343 .79451 Mdot
.06678 .0562 Mdot
.12643 .59776 Mdot
.70594 .8823 Mdot
.96985 .10347 Mdot
.40476 .88597 Mdot
.27562 .1689 Mdot
.75709 .32067 Mdot
.39629 .93312 Mdot
.90786 .12522 Mdot
.96732 .97832 Mdot
.13106 .71847 Mdot
.49907 .18071 Mdot
.08196 .65936 Mdot
.40061 .58656 Mdot
.33272 .78345 Mdot
.43341 .49088 Mdot
.94239 .90315 Mdot
.18454 .32338 Mdot
.17762 .57212 Mdot
.76649 .379 Mdot
.25914 .45744 Mdot
.81594 .40199 Mdot
.16101 .7352 Mdot
.30345 .21836 Mdot
.1045 .07508 Mdot
.90325 .62646 Mdot
.74765 .29219 Mdot
.43133 .14207 Mdot
.82515 .39332 Mdot
.2574 .83869 Mdot
.64504 .82416 Mdot
.47852 .45617 Mdot
.37967 .37628 Mdot
.6753 .05295 Mdot
.23775 .63039 Mdot
.36654 .82365 Mdot
.16357 .55515 Mdot
.47726 .18239 Mdot
.39246 .25087 Mdot
.06127 .03483 Mdot
.56186 .86225 Mdot
.78255 .20627 Mdot
.93264 .03673 Mdot
.27478 .75485 Mdot
.51017 .65982 Mdot
.58329 .7068 Mdot
.28958 .02544 Mdot
.21895 .88791 Mdot
.15882 .48048 Mdot
.72094 .7002 Mdot
.73923 .21787 Mdot
.6689 .6627 Mdot
.17292 .37222 Mdot
.90013 .46553 Mdot
.24065 .33541 Mdot
.59622 .70595 Mdot
.7074 .65722 Mdot
.02921 .99537 Mdot
.41543 .62334 Mdot
.79056 .1209 Mdot
.29181 .14692 Mdot
.09237 .4116 Mdot
.53401 .93912 Mdot
.37554 .74093 Mdot
.3795 .57116 Mdot
.48176 .28125 Mdot
.15458 .25151 Mdot
.89028 .56985 Mdot
.42161 .58691 Mdot
.87853 .57068 Mdot
.02442 .95905 Mdot
.09823 .47059 Mdot
.71353 .8093 Mdot
.01841 .0562 Mdot
.17815 .87303 Mdot
.61087 .30905 Mdot
.78099 .29752 Mdot
.13314 .02549 Mdot
.62793 .06036 Mdot
.23899 .46276 Mdot
.20837 .47139 Mdot
.3546 .88697 Mdot
.2016 .50429 Mdot
.28738 .4221 Mdot
.46141 .68608 Mdot
.28696 .36285 Mdot
.29347 .82381 Mdot
.66983 .04995 Mdot
.49998 .51994 Mdot
.54622 .01506 Mdot
.89084 .46471 Mdot
.3074 .54895 Mdot
.67355 .01041 Mdot
.96387 .66985 Mdot
.46836 .49885 Mdot
.64947 .2499 Mdot
.03741 .8029 Mdot
.34066 .90768 Mdot
.69923 .9933 Mdot
.66498 .86775 Mdot
.19662 .47014 Mdot
.13083 .85018 Mdot
.30101 .99798 Mdot
.79614 .2972 Mdot
.60743 .01555 Mdot
.86215 .62427 Mdot
.14898 .51623 Mdot
.2092 .3909 Mdot
.13132 .71725 Mdot
.85376 .47115 Mdot
.38999 .73068 Mdot
.17966 .60703 Mdot
.21873 .28055 Mdot
.0744 .76042 Mdot
.91682 .26573 Mdot
.25036 .46072 Mdot
.29755 .26441 Mdot
.38488 .82707 Mdot
.17714 .749 Mdot
.20761 .45853 Mdot
.07382 .03115 Mdot
.34439 .97952 Mdot
.65699 .2927 Mdot
.19262 .38066 Mdot
.42443 .03158 Mdot
.14816 .60856 Mdot
.50831 .75384 Mdot
.87776 .15665 Mdot
.22472 .49561 Mdot
.46104 .33086 Mdot
.07303 .74754 Mdot
.26732 .88145 Mdot
.01444 .71343 Mdot
.93907 .90455 Mdot
.3232 .41599 Mdot
.7404 .53139 Mdot
.89593 .38373 Mdot
.59335 .93684 Mdot
.36427 .61792 Mdot
.72516 .77372 Mdot
.15727 .1221 Mdot
.25239 .45183 Mdot
.1209 .38881 Mdot
.99613 .56484 Mdot
.1275 .6784 Mdot
.08619 .6654 Mdot
.7698 .26416 Mdot
.32805 .11848 Mdot
.89222 .88994 Mdot
.72231 .1946 Mdot
.49009 .26262 Mdot
.0051 .42236 Mdot
.35017 .13081 Mdot
.72896 .98872 Mdot
.24899 .75509 Mdot
.75581 .40339 Mdot
.15918 .07222 Mdot
.67884 .74916 Mdot
.36346 .81467 Mdot
.35379 .62141 Mdot
.48786 .92863 Mdot
.63404 .42403 Mdot
.02355 .66311 Mdot
.63987 .0189 Mdot
.63936 .52018 Mdot
.92691 .03166 Mdot
.37918 .76581 Mdot
.17214 .61683 Mdot
.23896 .68574 Mdot
.4546 .87315 Mdot
.88189 .87937 Mdot
.11933 .24525 Mdot
.34802 .95587 Mdot
.45241 .8154 Mdot
.35025 .29337 Mdot
.83019 .80799 Mdot
.69818 .7699 Mdot
.92441 .77834 Mdot
.31125 9e-05 Mdot
.74056 .16081 Mdot
.0828 .31554 Mdot
.2694 .29304 Mdot
.21031 .44907 Mdot
.17113 .03546 Mdot
.85189 .48482 Mdot
.69572 .22188 Mdot
.47413 .18956 Mdot
.87601 .42217 Mdot
.78354 .41696 Mdot
.98547 .64284 Mdot
.44891 .4276 Mdot
.22632 .48826 Mdot
.3885 .10009 Mdot
.95794 .19613 Mdot
.19622 .6634 Mdot
.78875 .16377 Mdot
.34874 .17252 Mdot
.1143 .9226 Mdot
.87586 .9892 Mdot
.22527 .50866 Mdot
.11222 .56506 Mdot
.25176 .86694 Mdot
.61529 .13754 Mdot
.04785 .38141 Mdot
.22725 .02671 Mdot
.08515 .17938 Mdot
.04265 .36675 Mdot
.28684 .02043 Mdot
.67367 .1813 Mdot
.19316 .08894 Mdot
.80729 .20398 Mdot
.97307 .58597 Mdot
.71925 .63467 Mdot
.69538 .72146 Mdot
.1312 .50067 Mdot
.67586 .33391 Mdot
.88662 .46489 Mdot
.59378 .15494 Mdot
.85801 .10351 Mdot
.31637 .12901 Mdot
.18904 .90734 Mdot
.13955 .03155 Mdot
.3603 .70715 Mdot
.1814 .45766 Mdot
.64234 .07957 Mdot
.44878 .721 Mdot
.5245 .57928 Mdot
.78985 .37869 Mdot
.6584 .11852 Mdot
.19623 .22713 Mdot
.80875 .03014 Mdot
.88216 .09582 Mdot
.62217 .11026 Mdot
.74142 .0626 Mdot
.25327 .41166 Mdot
.55724 .60502 Mdot
.59971 .31835 Mdot
.13137 .87052 Mdot
.07957 .74845 Mdot
.31527 .48995 Mdot
.38481 .62397 Mdot
.14704 .26804 Mdot
.56122 .60997 Mdot
.26706 .16912 Mdot
.96699 .49924 Mdot
.50063 .12172 Mdot
.69262 .10403 Mdot
.94195 .5214 Mdot
.11489 .7743 Mdot
.82555 .63845 Mdot
.05421 .02501 Mdot
.473 .15285 Mdot
.6414 .39405 Mdot
.33289 .897 Mdot
.0809 .79494 Mdot
.10694 .7212 Mdot
.11654 .29913 Mdot
.54783 .59745 Mdot
.39322 .18689 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;o
00002oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool01?l0003oooooo`000?l0000=ooooo`03o`000?oooooooooo00;ooooo000Nooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00Kooooo0_l00006ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooo
oooooooo0_l0000:ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00Co0000ooooool0003o00003Oooool0
0ol0003oooooooooo`02ooooo`007_ooool00ol0003oooooooooo`0fooooo`;o0000Boooool2o`00
05;ooooo0_l0001>ooooo`;o00007_ooool001kooooo00?o0000ooooooooool0>Oooool2o`0002_o
oooo0_l00005ooooo`;o0000J?ooool2o`0001gooooo0_l0000_ooooo`;o00007_ooool001kooooo
00?o0000ooooooooool0>Oooool2o`0002_ooooo0_l00005ooooo`;o0000?_ooool2o`0001;ooooo
0_l0000@ooooo`;o00008Oooool2o`0004oooooo000Nooooo`03o`000?oooooooooo07[ooooo0_l0
000aooooo`;o00004_ooool2o`0000Wooooo0_l00005ooooo`;o0000L_ooool001kooooo00?o0000
ooooooooool0=?ooool2o`0002?ooooo0_l0000Looooo`;o000000?oooooo`000?l000000oooool2
o`0000Oooooo0_l0000kooooo`;o00001Oooool2o`0007Wooooo000Nooooo`03o`000?oooooooooo
00kooooo0_l0000Gooooo`;o00002oooool2o`0002?ooooo0ol0000Kooooo`;o00001_ooool2o`00
00Oooooo0_l0000Zooooo`;o00003oooool2o`00083ooooo000Nooooo`03o`000?oooooooooo00ko
oooo0_l0000Gooooo`;o00007Oooool2o`0001;ooooo0_l0000Fooooo`;o0000@?ooool2o`0003co
oooo0_l0000Looooo`;o0000;Oooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo013ooooo
0_l00002ooooo`;o00004oooool2o`0001_ooooo0_l0000Zooooo`;o00004_ooool2o`0002Wooooo
0_l0000Sooooo`;o00006_ooool2o`0000oooooo0_l0000;ooooo`;o00005oooool2o`00017ooooo
0_l000000ooooooo0000o`000006ooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o00000_oo
ool2o`0001?ooooo0_l00004ooooo`;o0000:_ooool2o`0002Wooooo0_l0000Yooooo`;o00001ooo
ool2o`0001[ooooo0_l0000Yooooo`Co00009?ooool2o`00017ooooo0_l00009ooooo`007_ooool0
0ol0003oooooooooo`0@ooooo`;o00007Oooool2o`0000?ooooo0_l0000Uooooo`;o00007?ooool2
o`0003oooooo0_l00015ooooo`;o0000:?ooool2o`0001[ooooo000Nooooo`03o`000?oooooooooo
00[ooooo0_l0000Xooooo`;o00009Oooool2o`0001cooooo0_l0002`ooooo`;o00006_ooool001ko
oooo00?o0000ooooooooool02_ooool2o`00047ooooo0_l0001Hooooo`;o0000W_ooool001kooooo
00?o0000ooooooooool0A_ooool2o`0000Gooooo0_l0000Iooooo`;o0000?Oooool2o`0002;ooooo
0_l0001jooooo`007_ooool00ol0003oooooooooo`0dooooo`;o00002Oooool2o`0000Gooooo0_l0
000Pooooo`;o0000Goooool4o`0000Wooooo0_l0001_ooooo`007_ooool2o`0001gooooo0_l0000F
ooooo`;o00001_ooool2o`000003ooooool0003o000008Sooooo0_l0000;ooooo`?o0000K_ooool0
01kooooo00?o0000ooooooooool00_ooool2o`0000kooooo0_l00008ooooo`;o00007_ooool2o`00
0003ooooool0003o000004kooooo0_l00016ooooo`;o0000K_ooool001kooooo00?o0000oooooooo
ool00_ooool2o`0000kooooo0_l0001]ooooo`;o00003?ooool2o`0002[ooooo0_l0002:ooooo`00
7_ooool00ol0003oooooooooo`0Yooooo`;o0000E_ooool2o`0003Sooooo0_l0000;ooooo`;o0000
7Oooool2o`0000Cooooo0_l0001Hooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o00005?oo
ool2o`0000Cooooo0_l0000gooooo`;o0000I?ooool2o`0001gooooo0_l00004ooooo`;o0000F?oo
ool001kooooo00?o0000ooooooooool03Oooool2o`0001Cooooo0_l0000Rooooo`;o00002?ooool2
o`0000oooooo0_l0002_ooooo`;o0000<_ooool001kooooo00?o0000ooooooooool0Aoooool2o`00
00Sooooo0_l0000booooo`;o0000S?ooool2o`00023ooooo0_l0000@ooooo`007_ooool00ol0003o
ooooooooo`0Nooooo`;o00004?ooool2o`0005?ooooo0_l0002^ooooo`;o00004?ooool001kooooo
00?o0000ooooooooool07_ooool2o`00013ooooo0_l0003ooooooaKooooo000Nooooo`03o`000?oo
oooooooo02Kooooo0_l00019ooooo`;o00006?ooool2o`00043ooooo0_l0000:ooooo`;o0000K?oo
ool001kooooo00?o0000ooooooooool09_ooool2o`0004Wooooo0_l0000Hooooo`;o0000@?ooool2
o`0000[ooooo0_l00006ooooo`;o0000I?ooool001kooooo00?o0000ooooooooool0M?ooool2o`00
06_ooooo0_l0001Tooooo`007_ooool00ol0003oooooooooo`0kooooo`;o0000=oooool2o`0000[o
oooo0_l00035ooooo`007_ooool00ol0003oooooooooo`0/ooooo`;o00003Oooool2o`0004?ooooo
0_l0001Jooooo`;o00002Oooool2o`0004_ooooo0_l0000Aooooo`007_ooool00ol0003ooooooooo
o`06ooooo`;o00009?ooool2o`0004gooooo0_l0000@ooooo`;o000000?oooooo`000?l000001_oo
ool2o`0002Kooooo0_l00006ooooo`;o00004_ooool2o`0000Wooooo0_l0000booooo`;o00005ooo
ool2o`00017ooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l0001cooooo`;o00001Oooool2
o`0000Wooooo0_l000000ooooooo0000o`000006ooooo`;o00005?ooool2o`00013ooooo0_l00006
ooooo`;o00002?ooool2o`0004Oooooo0_l0000Zooooo`007_ooool2o`0007_ooooo0_l00006oooo
o`;o0000:_ooool2o`0002;ooooo1?l0001Eooooo`;o00006_ooool001kooooo00?o0000oooooooo
ool0@_ooool2o`0003Kooooo0_l0001Hooooo`;o00001oooool2o`0003Cooooo0_l0000Fooooo`;o
00002_ooool2o`0000kooooo000Nooooo`03o`000?oooooooooo04;ooooo0_l0000fooooo`;o0000
HOooool2o`0000oooooo0_l0000Sooooo`Co00008?ooool2o`0000kooooo000Nooooo`03o`000?oo
oooooooo0<Kooooo0_l0000Vooooo`;o00004_ooool2o`00017ooooo0_l0000Pooooo`;o00003_oo
ool001kooooo00?o0000ooooooooool05?ooool2o`0004gooooo0_l0001Qooooo`;o00002Oooool2
o`0002oooooo0_l00013ooooo`007_ooool00ol0003oooooooooo`03ooooo`;o00003oooool2o`00
00Kooooo0_l00015ooooo`;o0000K?ooool2o`0007Cooooo000Nooooo`03o`000?oooooooooo00?o
oooo0_l0000Gooooo`;o0000BOooool2o`0000[ooooo0_l0001Mooooo`;o00003_ooool2o`0001Wo
oooo0_l00018ooooo`007_ooool00ol0003oooooooooo`0_ooooo`;o00007oooool2o`0001Gooooo
0_l0000:ooooo`;o00001_ooool2o`0002;ooooo0_l0000aooooo`;o00003_ooool2o`0001Wooooo
0_l00009ooooo`;o0000?Oooool001kooooo00?o0000ooooooooool0;oooool2o`0001oooooo0_l0
000Yooooo`;o00008_ooool2o`0006Oooooo0_l0000Iooooo`;o00008_ooool001kooooo00?o0000
ooooooooool00_ooool2o`0000gooooo0_l0000<ooooo`;o0000@_ooool2o`0000Gooooo0_l0000E
ooooo`;o0000;?ooool2o`0001Sooooo0_l0001Hooooo`;o00002_ooool2o`0001Kooooo000Noooo
o`03o`000?oooooooooo00;ooooo0_l0000=ooooo`;o00003?ooool2o`0003;ooooo0_l0000>oooo
o`;o00001Oooool2o`0000;ooooo0_l0000Aooooo`;o00009_ooool2o`0000Cooooo0_l0000Hoooo
o`;o00002?ooool2o`0005[ooooo0_l0000@ooooo`;o00001?ooool001kooooo00?o0000oooooooo
ool0Doooool2o`0001Wooooo0_l0000iooooo`;o00003?ooool2o`0001[ooooo0_l0001/ooooo`;o
00001?ooool001kooooo00?o0000ooooooooool0HOooool2o`0005Cooooo0_l00009ooooo`Co0000
0_ooool2o`0007gooooo000Nooooo`03o`000?oooooooooo067ooooo0_l0000=ooooo`;o00005_oo
ool2o`0003Sooooo2?l0001mooooo`007_ooool00ol0003oooooooooo`1@ooooo`;o00007_ooool2
o`0001Kooooo0_l0000Iooooo`;o00008Oooool2o`0007oooooo000Nooooo`03o`000?oooooooooo
00Oooooo0_l00017ooooo`;o00002Oooool2o`0001Gooooo0_l0000_ooooo`;o0000A_ooool2o`00
05[ooooo000Nooooo`;o00002?ooool2o`0003Wooooo0_l0000Gooooo`;o00005Oooool2o`0000Ko
oooo0_l0000;ooooo`;o0000H_ooool2o`0003gooooo0_l0000Kooooo`007_ooool00ol0003ooooo
ooooo`12ooooo`;o0000=_ooool2o`0000_ooooo0_l0000=ooooo`;o00009Oooool2o`0006?ooooo
0_l00006ooooo`;o00006oooool001kooooo00?o0000ooooooooool0:_ooool2o`00063ooooo0_l0
0008ooooo`;o00009Oooool2o`0002gooooo0_l0000[ooooo`;o00001oooool2o`0002?ooooo000N
ooooo`03o`000?oooooooooo02[ooooo0_l00013ooooo`;o00002?ooool2o`00017ooooo0_l0001N
ooooo`?o0000:_ooool2o`0002cooooo000Nooooo`03o`000?oooooooooo06oooooo0_l00008oooo
o`;o00007oooool2o`0000oooooo0_l00010ooooo`;o00003Oooool2o`0004Wooooo000Nooooo`03
o`000?oooooooooo00cooooo0_l0001;ooooo`;o0000?oooool2o`0000oooooo0_l00010ooooo`;o
00003Oooool2o`00027ooooo0_l0000Vooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o0000
AOooool4o`0000;ooooo0_l0002Booooo`;o0000<?ooool2o`0001Cooooo0_l0000@ooooo`007_oo
ool00ol0003oooooooooo`1Cooooo`Co00005_ooool2o`000<Kooooo0_l0000@ooooo`007_ooool0
0ol0003oooooooooo`1Eooooo`;o00005_ooool2o`000=Sooooo000Nooooo`03o`000?oooooooooo
01Sooooo0_l0000kooooo`;o00004oooool2o`000=_ooooo000Nooooo`03o`000?oooooooooo01So
oooo0_l0001@ooooo`;o0000:oooool2o`0000Gooooo0_l0000gooooo`;o0000K_ooool001kooooo
00?o0000ooooooooool0Poooool2o`0001;ooooo0_l00005ooooo`;o00008_ooool2o`0001?ooooo
0_l00010ooooo`;o0000;?ooool001kooooo00?o0000ooooooooool03oooool2o`0006_ooooo0_l0
0005ooooo`;o0000?Oooool2o`0002Kooooo0_l0000]ooooo`;o0000;?ooool001kooooo00?o0000
ooooooooool03oooool2o`0005Sooooo0_l0000Aooooo`;o00006?ooool2o`0000_ooooo0_l00015
ooooo`;o0000;_ooool2o`0002_ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo01oooooo0_l00018ooooo`;o0000:oooool2
o`0000_ooooo0_l00012ooooo`;o00009oooool2o`0000Sooooo0_l0000[ooooo`000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_oo
ool00ol0003oooooooooo`0Oooooo`;o0000a_ooool2o`0000[ooooo0_l0000Kooooo`;o00002_oo
ool2o`0001Gooooo0_l0000Booooo`000oooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h01oooool3o`000003ooooool0003o00000=Oooooo0_l00002ooooo`;o00004ooo
ool2o`0002Oooooo0_l0000Eooooo`;o00004_ooool000?ooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00Co0000oooooooooooooooo0_l0000@ooooo`;o0000
aOooool2o`0000;ooooo0_l0000Rooooo`;o00003Oooool2o`0003Cooooo0003ooooo`05o`000?oo
ooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo01?ooooo
0_l0003Uooooo`;o00001_ooool2o`0000gooooo0_l0000dooooo`000oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Wooooo`;o0000
>Oooool2o`0005Kooooo0_l00007ooooo`;o00003?ooool2o`0002Kooooo0_l0000<ooooo`000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03
o`000?oooooooooo027ooooo0_l0000:ooooo`;o0000>?ooool2o`0000?ooooo0ol0000cooooo`;o
0000Goooool2o`0003Cooooo0_l0000<ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo027ooooo0_l0000:oooo
o`?o0000??ooool3o`0003oooooo0_l0000looooo`;o0000FOooool001kooooo00?o0000oooooooo
ool05_ooool2o`0000Wooooo0_l0000;ooooo`;o00007_ooool2o`0000oooooo0_l0001=ooooo`;o
00000_ooool2o`0003Sooooo0_l00007ooooo`;o0000D?ooool001kooooo00?o0000ooooooooool0
5_ooool2o`0003Kooooo0_l0000?ooooo`;o0000DOooool2o`0002[ooooo0_l0000<ooooo`;o0000
1oooool2o`0000Wooooo0_l0000Tooooo`;o00007oooool001kooooo00?o0000ooooooooool02ooo
ool2o`0001[ooooo0_l0000Nooooo`;o0000G?ooool2o`0003Oooooo0_l0000Pooooo`;o00009?oo
ool2o`0001oooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l0000Jooooo`;o00004oooool2
o`0000?ooooo0_l00004ooooo`;o00006Oooool2o`00047ooooo0_l0000Cooooo`;o0000POooool2
o`000003ooooool0003o000000Gooooo000Nooooo`03o`000?oooooooooo03cooooo0_l00003oooo
o`;o00007oooool2o`0000cooooo0_l00018ooooo`;o00004?ooool2o`0005Cooooo0_l0000Ioooo
o`;o000000?oooooo`000?l000001Oooool001kooooo00?o0000ooooooooool0L?ooool2o`0005[o
oooo0_l00012ooooo`;o00004?ooool2o`0002?ooooo000Mooooo`;o0000oooooolCooooo`;o0000
=Oooool001gooooo0_l0002Jooooo`;o0000M_ooool2o`0003Gooooo000Nooooo`03o`000?oooooo
oooo05?ooooo0_l00013ooooo`;o0000Eoooool2o`0000kooooo0_l0000=ooooo`;o0000=Oooool0
01kooooo00?o0000ooooooooool08oooool2o`0002kooooo0_l0002Looooo`;o00003_ooool2o`00
04Cooooo000Nooooo`03o`000?oooooooooo02?ooooo0_l0000Qooooo`;o0000Qoooool2o`00047o
oooo0_l0000cooooo`007_ooool2o`0002oooooo0_l0000Fooooo`;o0000<oooool2o`0005;ooooo
0_l0000dooooo`;o00002oooool2o`0003?ooooo000Nooooo`03o`000?oooooooooo02kooooo0_l0
001;ooooo`;o0000R?ooool2o`00033ooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`2J
ooooo`;o0000;_ooool2o`0000Gooooo0_l0001Tooooo`;o00003_ooool001kooooo00?o0000oooo
ooooool0V_ooool3o`0002gooooo0_l00005ooooo`;o0000M?ooool001kooooo00?o0000oooooooo
ool09Oooool2o`0003Kooooo0_l0000looooo`;o0000@_ooool2o`0000Oooooo0_l0000<ooooo`;o
0000;_ooool2o`0001oooooo000Nooooo`03o`000?oooooooooo02Gooooo0_l00005ooooo`;o0000
;oooool2o`0001Sooooo0_l0001Rooooo`;o00000_ooool2o`0000Oooooo1?l0000:ooooo`;o0000
;_ooool2o`0001oooooo000Nooooo`03o`000?oooooooooo02cooooo0_l00018ooooo`?o0000H_oo
ool2o`0000gooooo0_l00014ooooo`;o00005Oooool001kooooo00?o0000ooooooooool08?ooool2
o`0002cooooo0_l0000Vooooo`;o0000^?ooool2o`0001Gooooo000Nooooo`03o`000?oooooooooo
023ooooo0_l0000/ooooo`;o0000moooool001kooooo00?o0000ooooooooool05oooool2o`0002[o
oooo0_l00016ooooo`;o00003?ooool2o`0000Oooooo0_l0001`ooooo`;o0000<Oooool001kooooo
00?o0000ooooooooool05oooool2o`0002[ooooo0_l00016ooooo`;o00000oooool2o`0000Oooooo
0_l00007ooooo`;o0000GOooool2o`0000kooooo0_l000000ooooooo0000o`00000aooooo`007_oo
ool00ol0003oooooooooo`0]ooooo`;o0000HOooool2o`0000_ooooo0_l000000ooooooo0000o`00
000looooo`;o00008Oooool2o`0000kooooo0_l0000dooooo`007_ooool00ol0003oooooooooo`03
ooooo`;o00007oooool2o`0000Oooooo0_l0001^ooooo`;o000000?oooooo`000?l00000??ooool2
o`0004gooooo0_l0000Hooooo`007_ooool00ol0003oooooooooo`03ooooo`;o00007oooool2o`00
02gooooo0_l0000Iooooo`;o0000HOooool2o`0001Gooooo0_l00005ooooo`;o0000??ooool2o`00
01Sooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0000Sooooo`;o00000oooool2o`0002Co
oooo0_l0000Iooooo`;o0000HOooool2o`0001Gooooo0_l00005ooooo`;o0000E_ooool001kooooo
00?o0000ooooooooool08_ooool2o`0000Cooooo0_l00003ooooo`;o0000b?ooool2o`000003oooo
ool0003o000000?ooooo0_l00016ooooo`007_ooool2o`0002?ooooo0_l0003Cooooo`;o000000?o
ooooo`000?l000000oooool2o`0000oooooo0_l0000Rooooo`;o00004Oooool001kooooo00Co0000
ooooool0003o0000N?ooool2o`0009Gooooo0_l0000Rooooo`;o00004Oooool001kooooo00Co0000
ooooool0003o00000_ooool2o`0000Sooooo0_l0001Zooooo`;o0000?_ooool2o`0008cooooo000N
ooooo`03o`000?oooooooooo00?ooooo0_l00008ooooo`;o0000Z_ooool2o`0000Oooooo0_l00023
ooooo`007_ooool00ol0003oooooooooo`32ooooo`;o0000;oooool2o`0005;ooooo000Nooooo`03
o`000?oooooooooo01Oooooo0_l0003Jooooo`;o0000D_ooool001kooooo00?o0000ooooooooool0
5oooool2o`000:7ooooo0_l00003ooooo`;o0000<Oooool2o`0001Cooooo0_l0000mooooo`007_oo
ool00ol0003oooooooooo`0hooooo`;o0000FOooool2o`0002Gooooo0_l00003ooooo`;o0000<Ooo
ool2o`0001Cooooo0_l0000mooooo`007_ooool00ol0003oooooooooo`0hooooo`;o00009?ooool2
o`0003?ooooo0_l0001Oooooo`;o0000DOooool001kooooo00?o0000ooooooooool0G_ooool2o`00
03?ooooo0_l0001Oooooo`;o0000DOooool001kooooo00?o0000ooooooooool08_ooool2o`0000Co
oooo0_l00009ooooo`;o00004Oooool2o`0000[ooooo0_l0000nooooo`;o00002oooool2o`00057o
oooo0_l0000aooooo`;o00008?ooool001kooooo00?o0000ooooooooool08_ooool2o`0000Cooooo
0_l00009ooooo`;o00004Oooool2o`0000;ooooo0_l00006ooooo`;o0000?_ooool2o`0000_ooooo
0_l0000Looooo`;o00006Oooool2o`0001Sooooo0_l0000aooooo`;o00008?ooool001kooooo00?o
0000ooooooooool0B_ooool2o`00077ooooo0_l0000Iooooo`;o00004_ooool2o`0005Wooooo000N
ooooo`03o`000?oooooooooo01?ooooo0_l0001fooooo`;o0000Aoooool2o`0001Kooooo0_l0000F
ooooo`;o0000@Oooool001kooooo00?o0000ooooooooool04oooool2o`0007Kooooo0_l0000Goooo
o`;o0000;_ooool2o`0002kooooo0_l0000Qooooo`;o00007_ooool001kooooo00?o0000oooooooo
ool0Y?ooool2o`00087ooooo0_l0000Nooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o
0000ooooooooool0I?ooool2o`000>7ooooo000Nooooo`03o`000?oooooooooo05Wooooo0_l00009
ooooo`;o00003Oooool2o`000=;ooooo000Nooooo`03o`000?oooooooooo05Wooooo0_l0000Hoooo
o`;o0000F?ooool2o`0007Sooooo000Nooooo`03o`000?oooooooooo05Wooooo0_l0001booooo`;o
0000N?ooool001kooooo00?o0000ooooooooool02_ooool2o`0000Kooooo0_l00015ooooo`;o0000
k?ooool001kooooo00?o0000ooooooooool02_ooool2o`0000Kooooo0_l0001Hooooo`;o00005ooo
ool2o`0006?ooooo0_l00004ooooo`;o0000>Oooool2o`0001[ooooo000Nooooo`03o`000?oooooo
oooo00Kooooo0_l0000Mooooo`;o00003Oooool2o`0002oooooo0_l00005ooooo`;o00002_ooool2
o`0000_ooooo0_l0001Sooooo`;o00001?ooool2o`0003Wooooo0_l0000Jooooo`007_ooool00ol0
003oooooooooo`06ooooo`;o00007Oooool2o`0000gooooo0_l00009ooooo`;o00009?ooool2o`00
013ooooo0ol0003=ooooo`007_ooool00ol0003oooooooooo`0oooooo`;o0000=_ooool2o`0007co
oooo0_l00006ooooo`;o0000B?ooool001kooooo00?o0000ooooooooool02oooool2o`0002kooooo
0_l00002ooooo`;o0000AOooool2o`0006gooooo0_l00006ooooo`;o0000B?ooool001kooooo00?o
0000ooooooooool02oooool2o`0002kooooo0_l00002ooooo`;o0000AOooool2o`0009Oooooo0_l0
000Vooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o0000n_ooool2o`0002Kooooo000Noooo
o`03o`000?oooooooooo013ooooo0_l0000Aooooo`;o00006?ooool2o`000003ooooool0003o0000
02kooooo0_l0003Eooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0@ooooo`;o00006Oooool2o`00
013ooooo0_l000000ooooooo0000o`000002ooooo`;o0000:_ooool2o`0000Gooooo0_l00011oooo
o`;o00004?ooool2o`0001Cooooo0_l0000Tooooo`;o0000?Oooool000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
02_ooooo0_l0000Gooooo`;o00002_ooool2o`0000Gooooo0_l00005ooooo`;o00005oooool2o`00
00_ooooo0_l0000]ooooo`;o00001Oooool2o`00013ooooo0_l0000Dooooo`;o00001_ooool2o`00
01cooooo0_l0000Looooo`;o00007oooool000?ooooo00Go410@oooooooooooooooooa0@400;oooo
o`Go00001_ooool3o`00053ooooo0_l00005ooooo`;o00001Oooool2o`0001;ooooo0_l0000@oooo
o`;o00006Oooool2o`0000Gooooo0_l0000;ooooo`;o0000=Oooool2o`00017ooooo0_l0000Woooo
o`;o00006?ooool2o`0000Gooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01?m4
A4CogMgMooooool00007ooooo`03o`000?oooooooooo07;ooooo0_l0000[ooooo`;o00001Oooool2
o`0004[ooooo0_l00009ooooo`;o00001_ooool2o`0003Wooooo0_l00005ooooo`000oooool01Ol0
003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003ooooooooo
o`2`ooooo`;o0000@?ooool2o`00017ooooo0_l00010ooooo`000oooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`2]ooooo`;o000000?o
ooooo`000?l00000KOooool2o`0002Kooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo01[ooooo0_l0000booooo`;o00007_oo
ool2o`0003gooooo0_l0000Gooooo`;o0000=_ooool2o`0001oooooo0_l0000Vooooo`000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooooooo
o`0Jooooo`;o0000<_ooool2o`0001Gooooo0_l00007ooooo`;o0000E_ooool2o`0003?ooooo0_l0
00000ooooooo0000o`000017ooooo`007_ooool00ol0003oooooooooo`1Uooooo`;o0000U?ooool2
o`0004[ooooo000Nooooo`?o00005?ooool2o`0000;ooooo0_l0000/ooooo`;o00004Oooool2o`00
0:3ooooo0_l0000Looooo`;o0000;?ooool001kooooo0ol0000Dooooo`;o00000_ooool2o`0002co
oooo0_l0000Aooooo`;o00006_ooool2o`0001Sooooo0_l0000iooooo`;o0000COooool2o`0002co
oooo000Nooooo`03o`000?oooooooooo07Gooooo0_l0000Gooooo`?o00001?ooool2o`0003?ooooo
0_l0001kooooo`007_ooool00ol0003oooooooooo`16ooooo`;o0000A_ooool2o`0000Gooooo0_l0
001cooooo`;o0000>oooool001kooooo00?o0000ooooooooool0>Oooool2o`0000_ooooo0_l0001<
ooooo`;o00004Oooool2o`00067ooooo0_l0000kooooo`007_ooool00ol0003oooooooooo`0ioooo
o`;o0000FOooool2o`00017ooooo0_l0002Nooooo`007_ooool00ol0003oooooooooo`33ooooo`;o
0000P_ooool001kooooo00?o0000ooooooooool0L?ooool2o`00057ooooo0_l00022ooooo`007_oo
ool00ol0003oooooooooo`1`ooooo`;o0000H?ooool2o`0007?ooooo000Nooooo`03o`000?oooooo
oooo03Cooooo0_l0000:ooooo`;o0000T?ooool2o`0007?ooooo000Nooooo`;o00008_ooool2o`00
017ooooo0_l0000:ooooo`;o00003?ooool2o`0003gooooo0_l0000looooo`;o00008oooool2o`00
04Gooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`0Qooooo`;o00009_ooool7o`0003go
oooo0_l00008ooooo`;o0000<_ooool2o`0002?ooooo0_l00015ooooo`;o00003_ooool001kooooo
00?o0000ooooooooool0=oooool2o`0000Kooooo0_l00008ooooo`Go00000_ooool2o`00017ooooo
0_l0000Wooooo`;o00002Oooool2o`000:kooooo000Nooooo`03o`000?oooooooooo03Oooooo0_l0
0006ooooo`;o00001_ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l00000
4Oooool2o`0001cooooo0_l00009ooooo`;o0000O?ooool2o`0003_ooooo000Nooooo`03o`000?oo
oooooooo03;ooooo0_l00003ooooo`;o00003_ooool2o`000004ooooool0003o0000ooooo`Co0000
0oooool2o`0002_ooooo0_l0001>ooooo`;o00004Oooool2o`0002Cooooo0_l0000@ooooo`Co0000
00?oooooo`000?l000009?ooool001kooooo00?o0000ooooooooool0<_ooool4o`000003ooooool0
003o000001Kooooo0_l00003ooooo`;o0000Noooool2o`00017ooooo0_l0000Wooooo`;o00003Ooo
ool4o`000003ooooool0003o000002Cooooo000Nooooo`03o`000?oooooooooo01_ooooo0ol0000F
ooooo`;o00001_ooool2o`0000;ooooo0_l0001Nooooo`;o0000C?ooool2o`0001gooooo0_l00002
ooooo`;o0000=?ooool001kooooo00?o0000ooooooooool06oooool3o`0001kooooo0_l00002oooo
o`;o00009Oooool2o`0003Oooooo0_l0001<ooooo`;o00008Oooool2o`0003Cooooo000Nooooo`03
o`000?oooooooooo01Sooooo0_l0001=ooooo`;o00003Oooool2o`0009?ooooo0_l0000jooooo`00
7_ooool00ol0003oooooooooo`0Hooooo`;o00005_ooool2o`0004Cooooo0_l0000Qooooo`;o0000
L?ooool2o`0001?ooooo0_l0000Uooooo`007_ooool00ol0003oooooooooo`03ooooo`;o0000:ooo
ool2o`0006Oooooo0_l0000iooooo`;o0000B_ooool2o`0000_ooooo0_l0000Hooooo`007_ooool0
0ol0003oooooooooo`03ooooo`;o0000AOooool2o`0004Cooooo0_l00012ooooo`;o0000>oooool2
o`0001[ooooo0_l0000Hooooo`007_ooool00ol0003oooooooooo`15ooooo`;o00000oooool2o`00
01Kooooo0_l0000/ooooo`;o00001?ooool2o`0000?ooooo0_l0000looooo`;o0000=?ooool4o`00
03Cooooo000Nooooo`03o`000?oooooooooo04Gooooo0_l0000Kooooo`;o00009Oooool2o`0000_o
oooo0_l00003ooooo`;o0000=Oooool2o`0000Gooooo0_l0000dooooo`;o00008Oooool2o`000003
ooooool0003o0000013ooooo000Nooooo`03o`000?oooooooooo033ooooo0_l0000Cooooo`;o0000
1?ooool2o`0003cooooo0_l00017ooooo`;o0000@_ooool2o`0001[ooooo0_l000000ooooooo0000
o`00000@ooooo`007_ooool00ol0003oooooooooo`0`ooooo`;o00004oooool2o`0000Cooooo0_l0
0017ooooo`;o0000P?ooool3o`0001?ooooo0_l00008ooooo`;o00003oooool001kooooo0_l0000X
ooooo`;o00004_ooool2o`0001;ooooo0_l00013ooooo`;o0000POooool2o`0001?ooooo0_l00008
ooooo`;o00003oooool001kooooo00?o0000ooooooooool08?ooool2o`0000Gooooo0_l0000Boooo
o`Co00004?ooool2o`000<Sooooo0_l0000?ooooo`;o00006oooool001kooooo00?o0000oooooooo
ool08?ooool2o`0001_ooooo0_l00006ooooo`;o0000d_ooool2o`0000oooooo0_l0000Kooooo`00
7_ooool00ol0003oooooooooo`0kooooo`;o00002?ooool2o`000?oooooo0Oooool001kooooo00?o
0000ooooooooool05Oooool2o`0002Cooooo0_l0000dooooo`;o00006?ooool2o`0007?ooooo0_l0
0015ooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o00005Oooool2o`0002Gooooo0_l0000L
ooooo`;o00006?ooool2o`0007?ooooo0_l0000Uooooo`;o00007_ooool001kooooo00?o0000oooo
ooooool0;?ooool2o`0002Gooooo0_l00010ooooo`;o00001oooool2o`0002cooooo0_l0001Ioooo
o`;o00007_ooool001kooooo00?o0000ooooooooool02_ooool2o`0006Oooooo0_l00002ooooo`;o
00007?ooool4o`0000Gooooo0_l0000Oooooo`;o00002oooool2o`0003Oooooo0_l0000Wooooo`;o
00005oooool001kooooo00?o0000ooooooooool02_ooool2o`0006Oooooo0_l00002ooooo`;o0000
3Oooool2o`0000gooooo1?l0000Vooooo`;o0000A?ooool2o`0002Oooooo0_l0000Gooooo`007_oo
ool00ol0003oooooooooo`0Vooooo`;o00004_ooool2o`0004[ooooo0_l0000=ooooo`;o0000?Ooo
ool2o`00077ooooo000Nooooo`03o`000?oooooooooo02Kooooo0_l0000=ooooo`;o00000oooool2
o`0002gooooo0_l0001Yooooo`;o00005oooool2o`0003;ooooo0_l0000Tooooo`007_ooool00ol0
003oooooooooo`0/ooooo`;o00001oooool2o`00013ooooo0_l0000Pooooo`;o0000P_ooool2o`00
03;ooooo0_l00005ooooo`;o00007Oooool001kooooo00?o0000ooooooooool0;?ooool2o`0001Wo
oooo0_l0000:ooooo`;o0000=Oooool2o`0009cooooo0_l0000Mooooo`007_ooool00ol0003ooooo
ooooo`1Cooooo`;o0000=Oooool2o`0001Sooooo0_l0000Pooooo`;o0000:Oooool2o`0005Cooooo
000Nooooo`03o`000?oooooooooo083ooooo0_l0000@ooooo`;o00004?ooool2o`00023ooooo0_l0
000Yooooo`;o0000E?ooool001kooooo00?o0000ooooooooool06?ooool2o`0005oooooo0_l00005
ooooo`;o00004?ooool2o`0000Cooooo0_l0000`ooooo`;o0000Noooool001kooooo0_l0000Ioooo
o`;o0000A_ooool2o`0001Oooooo0_l0000Mooooo`;o0000<?ooool2o`0000Kooooo0_l0000Yoooo
o`;o0000B?ooool001kooooo00?o0000ooooooooool06?ooool2o`0001Gooooo0_l0000:ooooo`;o
00008oooool2o`00073ooooo0_l0000?ooooo`;o00003?ooool2o`0000[ooooo0_l0000Qooooo`;o
00000oooool2o`00023ooooo000Nooooo`03o`000?oooooooooo01Sooooo0_l0000Eooooo`Co0000
2?ooool2o`000:Kooooo0_l0000<ooooo`;o0000;Oooool2o`0000?ooooo0_l0000Pooooo`007_oo
ool00ol0003oooooooooo`0aooooo`;o0000oooooolEooooo`007_ooool00ol0003oooooooooo`22
ooooo`;o00001oooool2o`000:?ooooo0_l0000Eooooo`007_ooool00ol0003oooooooooo`0Poooo
o`;o0000H?ooool2o`0000Oooooo0_l0001gooooo`;o00002_ooool2o`0001kooooo0_l0000>oooo
o`;o00001Oooool001kooooo00?o0000ooooooooool08?ooool2o`0006Wooooo0_l0001gooooo`;o
00002_ooool2o`0000_ooooo0_l0000Qooooo`;o00001Oooool001kooooo00?o0000ooooooooool0
=_ooool2o`00027ooooo0_l0000Looooo`;o0000XOooool2o`000003ooooool0003o000002Sooooo
000Nooooo`03o`000?oooooooooo03Kooooo0_l00007ooooo`;o00006?ooool2o`0001cooooo0_l0
002Qooooo`;o0000:oooool001kooooo00?o0000ooooooooool0?oooool2o`0002[ooooo0_l0000`
ooooo`;o00001oooool2o`0009oooooo000Nooooo`03o`000?oooooooooo06_ooooo0_l0000`oooo
o`;o00001_ooool3o`0009oooooo000Nooooo`03o`000?oooooooooo01oooooo0_l0000Booooo`;o
0000L?ooool2o`000:3ooooo000Nooooo`03o`000?oooooooooo01oooooo0_l0000Booooo`;o0000
BOooool2o`0000Gooooo0_l0002Looooo`;o00004oooool2o`0000gooooo000Nooooo`03o`000?oo
oooooooo05_ooooo0_l0000Qooooo`;o00001Oooool2o`0000gooooo0_l0002=ooooo`;o000000?o
ooooo`000?l000004?ooool2o`0000gooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo05_ooooo
0_l0000gooooo`;o00003Oooool2o`00087ooooo0_l0000Oooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003o
ooooooooo`0Uooooo`;o0000K_ooool2o`0000cooooo0_l00009ooooo`;o0000J_ooool2o`0002_o
oooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo0000
00Kooooo0ol0000Uooooo`;o0000K_ooool2o`0001Oooooo0_l0001Zooooo`;o0000:oooool000?o
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool0
0ol0003oooooooooo`3ooooooakooooo0_l0000Xooooo`000oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo03Kooooo0_l0
000;ooooo`;o00004_ooool2o`0001oooooo0_l0000>ooooo`;o00009oooool2o`0006[ooooo0_l0
000Xooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool02?oo
ool00ol0003oooooooooo`0Booooo`;o00006?ooool3o`0000Oooooo0_l00002ooooo`;o00001ooo
ool2o`0001;ooooo0_l0000Oooooo`;o00003_ooool2o`0002Oooooo0ol00022ooooo`;o00003ooo
ool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o
0000ooooooooool04_ooool2o`0001Sooooo0ol000000ooooooo0000o`000008ooooo`;o000000?o
ooooo`000?l000003_ooool2o`0001kooooo0_l00013ooooo`;o0000B?ooool2o`0001Cooooo0_l0
0009ooooo`;o00005oooool2o`0000oooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?oo
ool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo01Gooooo0_l0000Iooooo`;o0000
2oooool2o`0000kooooo0_l0000Nooooo`;o0000@?ooool2o`0004_ooooo0_l0000Dooooo`;o0000
2Oooool2o`0002Sooooo000Nooooo`03o`000?oooooooooo01Gooooo0_l0000Mooooo`;o00007_oo
ool2o`0001cooooo0_l00007ooooo`;o00005oooool2o`0001Wooooo0_l00014ooooo`;o0000D?oo
ool001kooooo00?o0000ooooooooool0=?ooool2o`0001kooooo0_l0000Iooooo`;o000000?ooooo
o`000?l000001oooool2o`0001Cooooo0_l000000ooooooo0000o`00000Kooooo`;o0000@_ooool2
o`0000Oooooo0_l00017ooooo`007_ooool00ol0003oooooooooo`1_ooooo`;o00002?ooool2o`00
00Sooooo0_l0000<ooooo`;o00007_ooool2o`0004_ooooo0_l0000Dooooo`;o0000<Oooool001ko
oooo00?o0000ooooooooool0GOooool2o`0001[ooooo0_l00008ooooo`;o00003?ooool2o`0007Oo
oooo0_l00008ooooo`;o00003?ooool2o`0000Cooooo0_l0000Mooooo`007_ooool00ol0003ooooo
ooooo`19ooooo`;o00004_ooool2o`0003Wooooo0_l0000Gooooo`;o00001?ooool2o`00057ooooo
0_l0000Fooooo`;o00001?ooool2o`0001gooooo000Nooooo`03o`000?oooooooooo04Wooooo0_l0
001=ooooo`;o00005oooool2o`0000Cooooo0_l0000]ooooo`;o0000@?ooool2o`0000Wooooo0_l0
000Booooo`007_ooool00ol0003oooooooooo`2Mooooo`;o0000Aoooool2o`00043ooooo0_l00009
ooooo`;o00004_ooool001kooooo00?o0000ooooooooool0AOooool2o`0005Kooooo0_l0000Toooo
o`;o0000@oooool2o`0003gooooo000Nooooo`03o`000?oooooooooo04Gooooo0_l0001<ooooo`;o
0000;_ooool2o`0000Sooooo0_l0000iooooo`;o0000<_ooool2o`0000Wooooo000Nooooo`03o`00
0?oooooooooo09?ooooo0_l0000hooooo`;o0000;oooool2o`0001?ooooo0_l0000Nooooo`;o0000
1oooool2o`0000Wooooo000Nooooo`03o`000?oooooooooo04cooooo0_l0000Oooooo`;o00002Ooo
ool2o`0004Gooooo0_l0000mooooo`;o00004oooool2o`0001kooooo0_l0000Booooo`007_ooool2
o`0004Cooooo0_l00007ooooo`;o00007oooool2o`0000Wooooo0_l00015ooooo`;o0000Q_ooool0
01kooooo00?o0000ooooooooool0<oooool2o`0000kooooo0_l0003oooooo`?ooooo000Nooooo`03
o`000?oooooooooo01Oooooo0_l0000=ooooo`;o00001?ooool2o`0000Gooooo0_l0000=ooooo`;o
0000>oooool2o`0001gooooo0_l00012ooooo`;o0000Hoooool001kooooo00?o0000ooooooooool0
5oooool2o`0000gooooo0_l00004ooooo`;o00002?ooool2o`0000[ooooo0_l0000kooooo`;o0000
4_ooool2o`0000Wooooo0_l00002ooooo`;o00003oooool2o`0000cooooo0_l00005ooooo`;o0000
2oooool2o`0000_ooooo0_l0001Sooooo`007_ooool00ol0003oooooooooo`04ooooo`;o00004_oo
ool2o`0001cooooo0_l00004ooooo`;o0000EOooool2o`0000gooooo0_l0000?ooooo`;o00003?oo
ool2o`0000Gooooo0_l0000;ooooo`;o0000L?ooool001kooooo00?o0000ooooooooool01?ooool2
o`0001;ooooo0_l0000Rooooo`;o0000D?ooool2o`0004Oooooo0_l0001^ooooo`007_ooool00ol0
003oooooooooo`2>ooooo`;o0000Aoooool2o`00017ooooo0_l00019ooooo`;o00004?ooool001ko
oooo00?o0000ooooooooool0b_ooool2o`0001kooooo0_l00003ooooo`;o00007?ooool2o`0002Ko
oooo0_l0000@ooooo`007_ooool00ol0003oooooooooo`0`ooooo`;o000000?oooooo`000?l00000
@oooool2o`00013ooooo0_l0000Oooooo`;o00007Oooool2o`0002?ooooo0_l0000Looooo`;o0000
>?ooool001kooooo00?o0000ooooooooool08oooool4o`0000Wooooo0_l000000ooooooo0000o`00
0013ooooo`;o00004?ooool2o`0001oooooo0_l0002Jooooo`007_ooool00ol0003oooooooooo`0S
ooooo`Co00000oooool2o`0001Sooooo0_l00023ooooo`;o0000O?ooool001kooooo00?o0000oooo
ooooool0:_ooool2o`0001Sooooo0_l00004ooooo`;o00005?ooool2o`00033ooooo0_l0000Yoooo
o`;o00002_ooool2o`0000;ooooo0_l0000[ooooo`;o0000Boooool001kooooo00?o0000oooooooo
ool0;Oooool2o`0000cooooo0_l0000=ooooo`;o00005?ooool2o`00033ooooo0_l0000Yooooo`;o
00003_ooool2o`0002_ooooo0_l0000Rooooo`;o00009oooool001kooooo00?o0000ooooooooool0
;Oooool2o`0000cooooo0_l0001Aooooo`;o0000S_ooool2o`0002Oooooo000Nooooo`03o`000?oo
oooooooo00Sooooo0_l0000Cooooo`;o0000A?ooool2o`0000Gooooo0_l0000Rooooo`;o0000J?oo
ool2o`0004gooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0000Cooooo`;o0000A?ooool2
o`0000Gooooo0_l00023ooooo`;o00001oooool2o`0004gooooo000Nooooo`;o0000<oooool2o`00
0;;ooooo0_l00007ooooo`;o0000E_ooool001kooooo00?o0000ooooooooool0<_ooool2o`0000Oo
oooo0_l0002Yooooo`;o0000Goooool001kooooo00?o0000ooooooooool0>oooool2o`0003Cooooo
0_l00017ooooo`;o00000_ooool2o`0005Cooooo0_l0000<ooooo`;o00003?ooool2o`0001Gooooo
000Nooooo`03o`000?oooooooooo03Sooooo0_l0000_ooooo`;o00001_ooool2o`0004Oooooo0_l0
0002ooooo`;o0000E?ooool2o`0000cooooo0_l0000<ooooo`;o00005Oooool001kooooo00Co0000
oooooooooooooooo0_l0000Eooooo`;o00007_ooool2o`0002oooooo0_l0002Qooooo`;o0000>Ooo
ool001kooooo00Co0000oooooooooooooooo0_l0000Eooooo`;o00003Oooool2o`0009Gooooo0_l0
001<ooooo`;o0000>Oooool001kooooo00?o0000ooooooooool09_ooool3o`0001Gooooo0_l0001>
ooooo`;o0000;_ooool2o`0008Oooooo000Nooooo`03o`000?oooooooooo01oooooo0_l00005oooo
o`;o00005_ooool2o`0000Wooooo0_l00013ooooo`;o0000C_ooool2o`0003cooooo0_l0000Yoooo
o`007_ooool00ol0003oooooooooo`0Oooooo`;o0000:?ooool2o`0009?ooooo0_l0000looooo`;o
0000:Oooool001kooooo00?o0000ooooooooool0^oooool2o`0008[ooooo000Nooooo`03o`000?oo
oooooooo07_ooooo0_l0000nooooo`;o0000R_ooool001kooooo00?o0000ooooooooool0<?ooool2
o`0004Wooooo0_l0002eooooo`;o00004oooool001kooooo00?o0000ooooooooool0<?ooool2o`00
02kooooo0_l0003@ooooo`;o00004oooool001kooooo00?o0000ooooooooool0H?ooool2o`0001Co
oooo0_l0000;ooooo`;o00008?ooool2o`000:3ooooo000Nooooo`03o`000?oooooooooo07Kooooo
0_l0000;ooooo`;o00008?ooool2o`00013ooooo0_l0001mooooo`;o00003oooool001kooooo00?o
0000ooooooooool05?ooool4o`0000Wooooo0_l00002ooooo`;o0000=oooool2o`0004cooooo0_l0
0009ooooo`;o0000??ooool2o`0003oooooo0_l00005ooooo`;o00002?ooool001kooooo0_l0000E
ooooo`Co00002Oooool2o`0000;ooooo0_l0000>ooooo`;o00006?ooool2o`0000gooooo0_l0001<
ooooo`;o00004Oooool2o`0001Sooooo0_l0000Jooooo`;o00000_ooool2o`0004;ooooo0_l00008
ooooo`007_ooool00ol0003oooooooooo`0eooooo`;o00006?ooool2o`0000Cooooo0_l0001:oooo
o`;o00007?ooool2o`0001Sooooo0_l0000Nooooo`;o0000:?ooool2o`0000gooooo0_l0000Coooo
o`007_ooool00ol0003oooooooooo`1=ooooo`;o00001_ooool2o`0001Kooooo0_l0000booooo`;o
00002_ooool2o`0006Oooooo0_l0000;ooooo`;o00003Oooool2o`0001?ooooo000Nooooo`03o`00
0?oooooooooo01Cooooo0_l0000gooooo`;o00007_ooool2o`0002oooooo0_l00006ooooo`;o0000
1Oooool2o`00037ooooo0_l0000dooooo`;o0000;oooool001kooooo00?o0000ooooooooool05?oo
ool2o`0005;ooooo0_l0000dooooo`;o00001_ooool2o`0003Sooooo0_l00016ooooo`;o00007Ooo
ool001kooooo00?o0000ooooooooool0J?ooool2o`0000gooooo0_l0002_ooooo`;o00007Oooool0
01kooooo00?o0000ooooooooool0Moooool2o`0002Oooooo0_l0000mooooo`;o0000Aoooool2o`00
01gooooo000Nooooo`03o`000?oooooooooo05Oooooo0_l00017ooooo`;o0000?Oooool2o`0004Oo
oooo0_l0000Mooooo`007_ooool00ol0003oooooooooo`0Qooooo`;o00003Oooool2o`0002Gooooo
0_l0002?ooooo`;o0000GOooool001kooooo00?o0000ooooooooool08Oooool2o`0000gooooo0_l0
0005ooooo`;o0000[oooool2o`0003kooooo0_l0000Mooooo`007_ooool00ol0003oooooooooo`0g
ooooo`;o00002Oooool2o`000>Cooooo0_l0000Mooooo`007_ooool00ol0003oooooooooo`12oooo
o`;o00009?ooool2o`0003Wooooo0_l0002Rooooo`007_ooool00ol0003oooooooooo`0`ooooo`;o
00009_ooool2o`0000kooooo0_l0000iooooo`;o00002Oooool2o`0009Oooooo000Nooooo`03o`00
0?oooooooooo033ooooo0_l0000Vooooo`;o0000E?ooool2o`0009Oooooo0003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03
o`000?oooooooooo01Kooooo0_l00008ooooo`;o0000I?ooool2o`0003;ooooo0_l0001Kooooo`;o
0000;_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7o
V9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool01_ooool2o`0000kooooo0_l00008oooo
o`;o00006_ooool2o`0004Sooooo0_l0000booooo`;o0000Foooool2o`0002kooooo0003ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol00006
ooooo`Co00003Oooool2o`0002?ooooo0_l0001Eooooo`?o0000/Oooool000?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool00ol0003ooooooooo
o`08ooooo`;o00002Oooool2o`0000;ooooo0_l0001jooooo`?o0000/Oooool000?ooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003ooooo
ooooo`08ooooo`;o00002Oooool2o`000?oooooo<oooool000?ooooo00Go410@oooooooooooooooo
oa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`0Sooooo`;o
0000<_ooool4o`0005Sooooo0_l0000_ooooo`;o00000oooool2o`0001oooooo0_l0000kooooo`00
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006oooo
o`03o`000?oooooooooo02?ooooo0_l0000Iooooo`;o00005oooool5o`0005Oooooo0_l0000_oooo
o`;o00000oooool2o`0001oooooo0_l0000kooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo03;ooooo0_l0000:
ooooo`;o00006_ooool2o`0001Kooooo0_l0000Kooooo`;o0000E_ooool2o`0005kooooo000Noooo
o`03o`000?oooooooooo02Kooooo0_l0000:ooooo`;o0000?_ooool2o`0001_ooooo0_l0001Foooo
o`;o0000G_ooool001kooooo00?o0000ooooooooool05_ooool2o`0000kooooo0_l0003oooooob3o
oooo000Nooooo`03o`000?oooooooooo01Kooooo0_l0000nooooo`;o00000oooool2o`0001Kooooo
0_l0000dooooo`;o00008oooool2o`00063ooooo0_l00003ooooo`;o00004?ooool001kooooo00?o
0000ooooooooool0E_ooool2o`0000?ooooo0_l0000Fooooo`;o00001?ooool2o`0002kooooo0_l0
000Sooooo`;o0000H?ooool2o`0000?ooooo0_l0000@ooooo`007_ooool00ol0003oooooooooo`1i
ooooo`;o0000c?ooool001kooooo00?o0000ooooooooool0YOooool2o`000:3ooooo000Nooooo`03
o`000?oooooooooo02;ooooo0_l0000Hooooo`;o0000>?ooool2o`0002gooooo1?l0002Nooooo`00
7_ooool00ol0003oooooooooo`0Rooooo`;o000000?oooooo`000?l000005Oooool2o`0001;ooooo
0_l0000Tooooo`;o0000;oooool2o`0001gooooo0_l0001Pooooo`;o00007Oooool001kooooo00?o
0000ooooooooool00_ooool2o`00027ooooo0_l0000Yooooo`;o0000M?ooool2o`00017ooooo0_l0
000booooo`;o00006Oooool2o`0001gooooo000Nooooo`04o`000?ooooooooooooooo`?o00009Ooo
ool2o`0003Kooooo0_l0001fooooo`;o0000:_ooool2o`0000Kooooo0_l0000hooooo`007_ooool3
o`000003ooooool0003o000000Gooooo0_l0000Gooooo`;o00000oooool2o`000003ooooool0003o
000003Kooooo0_l0000looooo`;o0000=?ooool2o`0002kooooo0_l00010ooooo`007_ooool3o`00
00Sooooo0_l0000Cooooo`;o00000_ooool2o`0000?ooooo0_l0001gooooo`;o0000=?ooool2o`00
073ooooo000Nooooo`03o`000?oooooooooo01[ooooo0_l000000ooooooo0000o`00000Booooo`;o
0000m?ooool2o`0000;ooooo0_l0000Jooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o0000
5Oooool2o`0000Kooooo0_l0000Nooooo`;o0000Noooool2o`0003[ooooo0_l0000Cooooo`;o0000
0_ooool2o`0001[ooooo000Nooooo`04o`000?ooooooooooooooo`;o00004Oooool2o`000003oooo
ool0003o0000023ooooo0_l0000Nooooo`;o0000F?ooool2o`00027ooooo0_l0000jooooo`;o0000
:oooool2o`0000Kooooo000Nooooo`04o`000?ooooooooooooooo`;o00004Oooool2o`000003oooo
ool0003o000009[ooooo0_l0000mooooo`;o0000Boooool2o`0000Kooooo000Nooooo`03o`000?oo
oooooooo04kooooo0_l0000eooooo`;o0000@Oooool2o`0000[ooooo0_l0000Looooo`;o0000Dooo
ool001kooooo00?o0000ooooooooool09oooool2o`0002Gooooo0_l0000eooooo`;o0000<oooool2
o`0000cooooo0_l0000:ooooo`;o0000LOooool001kooooo00?o0000ooooooooool09oooool2o`00
00gooooo0_l0001Hooooo`;o00008_ooool2o`0000Cooooo0_l0002;ooooo`007_ooool00ol0003o
ooooooooo`0fooooo`;o0000F?ooool2o`0001?ooooo0_l00002ooooo`;o00002Oooool2o`00057o
oooo0_l0000Rooooo`;o00006_ooool001kooooo00?o0000ooooooooool0Noooool2o`0002Sooooo
0_l00002ooooo`;o0000G?ooool2o`0001;ooooo0_l0000>ooooo`;o00000oooool2o`0001Gooooo
000Nooooo`03o`000?oooooooooo04oooooo0_l00002ooooo`;o00005?ooool2o`00013ooooo0_l0
001Tooooo`;o00007?ooool2o`0001[ooooo0_l0000Cooooo`;o00005Oooool001kooooo00?o0000
ooooooooool0@?ooool2o`0000;ooooo0_l00009ooooo`?o000000?oooooo`000?l000005?ooool2
o`0000Cooooo0_l0000>ooooo`;o0000H?ooool2o`0001cooooo0_l0000Cooooo`;o0000<Oooool0
01kooooo00?o0000ooooooooool00oooool2o`000003ooooool0003o000003Sooooo0_l000001?oo
oooo0000o`000?l0000:ooooo`;o00001oooool2o`0001Cooooo0_l0000>ooooo`;o0000@Oooool2
o`00053ooooo0_l00008ooooo`;o00002?ooool2o`0001gooooo000Nooooo`03o`000?oooooooooo
00?ooooo0_l000000ooooooo0000o`00000kooooo`;o00005?ooool2o`0006Oooooo0_l0001Joooo
o`;o00002?ooool2o`0001gooooo000Nooooo`03o`000?oooooooooo04[ooooo0_l0000Fooooo`;o
0000hoooool001kooooo00?o0000ooooooooool0B_ooool2o`0001Kooooo0_l00004ooooo`;o0000
gOooool001kooooo0_l0001Yooooo`;o00007Oooool2o`000:oooooo0_l0000=ooooo`007_ooool0
0ol0003oooooooooo`0Dooooo`;o0000>?ooool2o`0000[ooooo0_l0000[ooooo`;o00007Oooool2
o`0008Gooooo0ol00008ooooo`;o00003Oooool001kooooo00?o0000ooooooooool05?ooool2o`00
02?ooooo0_l0000Cooooo`;o00002_ooool2o`0000oooooo0_l0000iooooo`;o0000QOooool3o`00
01Oooooo000Nooooo`03o`000?oooooooooo03Wooooo0_l0000`ooooo`;o0000^oooool2o`0001go
oooo000Nooooo`03o`000?oooooooooo05[ooooo0_l0002hooooo`;o00004_ooool2o`0001gooooo
000Nooooo`03o`000?oooooooooo00Sooooo0_l0000hooooo`;o00005_ooool2o`000;Sooooo0_l0
000aooooo`007_ooool00ol0003oooooooooo`08ooooo`;o00000oooool2o`0003?ooooo0_l0000@
ooooo`;o0000Noooool2o`0007Cooooo000Nooooo`03o`000?oooooooooo00gooooo0_l0000Boooo
o`;o00002Oooool2o`0002Kooooo0_l0001kooooo`;o00005Oooool2o`0005gooooo000Nooooo`03
o`000?oooooooooo027ooooo0_l00005ooooo`;o00000_ooool2o`0001?ooooo0_l0001Looooo`;o
00008_ooool2o`0002?ooooo0_l0001<ooooo`;o00003oooool001kooooo00?o0000ooooooooool0
:?ooool2o`0000kooooo0_l00007ooooo`;o0000Eoooool2o`0000?ooooo0_l0000Rooooo`;o0000
C_ooool2o`00027ooooo0_l0000?ooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o00005?oo
ool2o`0000_ooooo0_l00006ooooo`;o0000@oooool2o`0001Gooooo0_l00004ooooo`;o0000Mooo
ool2o`0000Gooooo0_l0000[ooooo`007_ooool00ol0003oooooooooo`0=ooooo`Co00004_ooool2
o`0000_ooooo0_l0001;ooooo`;o00005Oooool2o`0008Cooooo0_l0000[ooooo`007_ooool00ol0
003oooooooooo`0?ooooo`;o0000V?ooool2o`0001;ooooo0_l0001Looooo`;o0000:_ooool001ko
oooo00?o0000ooooooooool07_ooool2o`0001;ooooo0_l0000>ooooo`;o00003oooool2o`0001So
oooo0_l0000jooooo`;o00003oooool2o`000003ooooool0003o000001Wooooo0_l00011ooooo`;o
0000:_ooool001kooooo00?o0000ooooooooool07_ooool2o`0001;ooooo0_l0000>ooooo`;o0000
3oooool2o`0001Sooooo0_l0000:ooooo`;o0000:Oooool2o`0001Cooooo0_l0000Looooo`;o0000
KOooool001kooooo00?o0000ooooooooool0NOooool2o`0000?ooooo0_l0000Tooooo`;o0000>_oo
ool2o`0006Gooooo000Nooooo`;o0000Ooooool2o`0000gooooo0_l0001Aooooo`;o0000?Oooool2
o`0002Kooooo000Nooooo`04o`000?ooooooooooooooo`;o0000>Oooool2o`0004oooooo0_l0002@
ooooo`;o00009_ooool001kooooo00Co0000oooooooooooooooo0_l0000iooooo`;o0000;oooool2
o`000=Sooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0001Wooooo`;o0000:_ooool2o`00
02?ooooo0_l00027ooooo`007_ooool00ol0003oooooooooo`04ooooo`;o0000Toooool2o`0002?o
oooo0_l0000Hooooo`;o0000KOooool001kooooo00?o0000ooooooooool0>oooool2o`0003Oooooo
0_l0001Rooooo`;o0000<oooool2o`0003Sooooo000Nooooo`03o`000?oooooooooo03_ooooo0_l0
000gooooo`;o00007?ooool2o`0003oooooo0_l0000hooooo`;o0000>?ooool001kooooo00?o0000
ooooooooool0H?ooool2o`000003ooooool0003o000000Cooooo0_l0000Wooooo`;o0000?oooool2
o`0003;ooooo0_l0000nooooo`007_ooool00ol0003oooooooooo`1Pooooo`;o000000?oooooo`00
0?l000001?ooool2o`0005oooooo0_l0000kooooo`;o0000?_ooool001kooooo00?o0000oooooooo
ool0K?ooool2o`0002Kooooo0_l0000dooooo`;o0000J_ooool2o`0000Gooooo0_l00008ooooo`00
7_ooool00ol0003oooooooooo`0[ooooo`;o0000?oooool2o`0002Kooooo0_l00007ooooo`;o0000
Uoooool2o`0000Gooooo0_l00008ooooo`007_ooool00ol0003oooooooooo`0[ooooo`;o0000Booo
ool2o`0002?ooooo0_l0000Booooo`;o0000U?ooool001kooooo00?o0000ooooooooool0N?ooool2
o`0003Oooooo0_l0000fooooo`;o0000:_ooool2o`0001;ooooo0_l0000Looooo`007_ooool00ol0
003oooooooooo`1Jooooo`;o0000F?ooool2o`0003?ooooo0_l0000Zooooo`;o00000_ooool2o`00
00[ooooo0_l00002ooooo`;o00007?ooool001Cooooo1?l000000ol@413oooooooooo`03ooooo`03
o`000?oooooooooo03;ooooo0_l0000Vooooo`;o0000F?ooool2o`0002Wooooo0_l0000>ooooo`;o
000000?oooooo`000?l000009Oooool2o`0000[ooooo0_l0000Pooooo`005_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l0000Aooooo`;o00006?ooool2o`0002[ooooo
0_l0000Iooooo`Co0000H_ooool2o`0000kooooo0_l000000ooooooo0000o`00001Cooooo`005_oo
ool00ol0003oooooooooo`05ooooo`?o00001Oooool2o`00017ooooo0_l0000<ooooo`;o0000=_oo
ool2o`0001Wooooo1?l00002ooooo`;o0000;_ooool2o`0008[ooooo0_l0000:ooooo`005_ooool0
0ol0003oooooooooo`0^ooooo`;o0000Eoooool2o`0002kooooo0_l0002:ooooo`;o00002_ooool0
01Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3o
oooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Cooooo00?oEEEEofIVI_l00000oooo
oomBooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.13543 .6828 Mdot
.83449 .42826 Mdot
.13029 .5057 Mdot
.07131 .02687 Mdot
.36325 .42871 Mdot
.25376 .03723 Mdot
.61327 .02894 Mdot
.25417 .46741 Mdot
.30498 .97128 Mdot
.76731 .0195 Mdot
.32701 .20442 Mdot
.44797 .09515 Mdot
.23117 .53513 Mdot
.61887 .66245 Mdot
.16486 .02782 Mdot
.56075 .63204 Mdot
.76852 .61464 Mdot
.33669 .57563 Mdot
.1611 .60775 Mdot
.10663 .11408 Mdot
.83841 .62385 Mdot
.31988 .10934 Mdot
.45967 .42994 Mdot
.85413 .03157 Mdot
.25287 .88267 Mdot
.21232 .38555 Mdot
.13514 .83727 Mdot
.57827 .72657 Mdot
.34462 .20803 Mdot
.26244 .14084 Mdot
.22041 .60142 Mdot
.1803 .01688 Mdot
.37203 .98744 Mdot
.87239 .91687 Mdot
.92075 .55259 Mdot
.03544 .88775 Mdot
.62364 .67347 Mdot
.82226 .51746 Mdot
.50872 .83317 Mdot
.19686 .7963 Mdot
.19485 .60478 Mdot
.96771 .64429 Mdot
.99306 .99828 Mdot
.79226 .60932 Mdot
.5498 .03518 Mdot
.95836 .70631 Mdot
.65201 .46164 Mdot
.9627 .82607 Mdot
.05283 .80225 Mdot
.14162 .29934 Mdot
.44961 .97091 Mdot
.94253 .4987 Mdot
.28283 .36231 Mdot
.02278 .84986 Mdot
.31347 .35779 Mdot
.2159 .22991 Mdot
.76096 .31055 Mdot
.26291 .51568 Mdot
.12523 .84624 Mdot
.33098 .69159 Mdot
.10663 .04863 Mdot
.232 .42912 Mdot
.5985 .0946 Mdot
.28378 .91424 Mdot
.29285 .74917 Mdot
.31368 .05985 Mdot
.00668 .40007 Mdot
.12854 .83629 Mdot
.23556 .06384 Mdot
.82311 .31557 Mdot
.13976 .22526 Mdot
.44743 .61675 Mdot
.05645 .1629 Mdot
.25521 .21689 Mdot
.41211 .07078 Mdot
.96406 .30005 Mdot
.14347 .33663 Mdot
.64013 .22762 Mdot
.15611 .92021 Mdot
.5121 .40157 Mdot
.94575 .85624 Mdot
.69717 .08864 Mdot
.80082 .61734 Mdot
.23805 .46109 Mdot
.75349 .44698 Mdot
.00308 .22416 Mdot
.29423 .4019 Mdot
.06521 .91819 Mdot
.20335 .04639 Mdot
.37494 .67337 Mdot
.07217 .12598 Mdot
.85252 .28019 Mdot
.15615 .28882 Mdot
.15545 .21171 Mdot
.34049 .6456 Mdot
.9354 .76397 Mdot
.60615 .18038 Mdot
.92977 .53378 Mdot
.28223 .81391 Mdot
.89629 .59785 Mdot
.13855 .74708 Mdot
.45636 .93347 Mdot
.09294 .61707 Mdot
.60078 .64094 Mdot
.91584 .33159 Mdot
.45598 .43697 Mdot
.52823 .67445 Mdot
.55183 .66134 Mdot
.95968 .4939 Mdot
.65802 .13172 Mdot
.61981 .68191 Mdot
.80672 .50846 Mdot
.50662 .94732 Mdot
.28854 .58751 Mdot
.456 .32627 Mdot
.65377 .97518 Mdot
.54229 .00358 Mdot
.19837 .52844 Mdot
.02938 .30477 Mdot
.57601 .87256 Mdot
.09379 .82026 Mdot
.96562 .73568 Mdot
.40118 .12484 Mdot
.15929 .21422 Mdot
.88473 .19741 Mdot
.86294 .60807 Mdot
.37776 .88438 Mdot
.18427 .65947 Mdot
.87041 .88764 Mdot
.00711 .13123 Mdot
.85718 .56274 Mdot
.37486 .26588 Mdot
.78197 .74764 Mdot
.42659 .53879 Mdot
.34334 .60952 Mdot
.29665 .33062 Mdot
.44151 .4286 Mdot
.43957 .68777 Mdot
.10158 .54997 Mdot
.29339 .02917 Mdot
.2149 .65641 Mdot
.2849 .90496 Mdot
.36567 .08306 Mdot
.93116 .62257 Mdot
.59028 .33051 Mdot
.43646 .09321 Mdot
.23496 .72076 Mdot
.16439 .77349 Mdot
.77131 .29495 Mdot
.67256 .08541 Mdot
.69652 .75825 Mdot
.3773 .03883 Mdot
.46964 .09633 Mdot
.11578 .12719 Mdot
.13784 .99359 Mdot
.20114 .50398 Mdot
.48602 .65482 Mdot
.73325 .39034 Mdot
.26734 .93936 Mdot
.54262 .63056 Mdot
.46791 .6278 Mdot
.90328 .55192 Mdot
.8004 .88681 Mdot
.45592 .52716 Mdot
.27654 .78991 Mdot
.36826 .39924 Mdot
.18371 .77631 Mdot
.21155 .88351 Mdot
.65222 .11659 Mdot
.44401 .49095 Mdot
.37869 .15459 Mdot
.93262 .85564 Mdot
.90661 .5327 Mdot
.03067 .28965 Mdot
.14201 .65851 Mdot
.49267 .76765 Mdot
.83019 .87781 Mdot
.15877 .40081 Mdot
.62331 .09587 Mdot
.93501 .50496 Mdot
.99915 .97657 Mdot
.41953 .02521 Mdot
.5516 .80711 Mdot
.53137 .15988 Mdot
.68846 .26386 Mdot
.51053 .87709 Mdot
.54147 .62296 Mdot
.04017 .09341 Mdot
.76809 .74589 Mdot
.9152 .70542 Mdot
.15814 .65808 Mdot
.98035 .20855 Mdot
.17568 .67527 Mdot
.50708 .18712 Mdot
.55724 .87598 Mdot
.00393 .02505 Mdot
.9137 .58205 Mdot
.42195 .14571 Mdot
.31194 .97056 Mdot
.39945 .05791 Mdot
.54253 .21108 Mdot
.50814 .34501 Mdot
.40379 .56286 Mdot
.54485 .12784 Mdot
.25566 .88732 Mdot
.06301 .93096 Mdot
.66282 .037 Mdot
.08471 .90112 Mdot
.78793 .41217 Mdot
.58966 .74761 Mdot
.43026 .46283 Mdot
.19543 .68668 Mdot
.90353 .22761 Mdot
.66447 .3351 Mdot
.45458 .65608 Mdot
.12027 .21538 Mdot
.21366 .78069 Mdot
.09151 .28006 Mdot
.51149 .75845 Mdot
.04199 .37322 Mdot
.75835 .3283 Mdot
.3854 .61464 Mdot
.28147 .89045 Mdot
.21468 .9229 Mdot
.37543 .64614 Mdot
.50456 .58093 Mdot
.93755 .98672 Mdot
.41251 .37217 Mdot
.69779 .19831 Mdot
.35545 .07728 Mdot
.18302 .45509 Mdot
.32875 .70757 Mdot
.38365 .09112 Mdot
.96774 .09128 Mdot
.11869 .21299 Mdot
.73874 .16716 Mdot
.71003 .55216 Mdot
.20793 .5728 Mdot
.8207 .5601 Mdot
.76496 .21765 Mdot
.1381 .37549 Mdot
.38453 .1185 Mdot
.97857 .92517 Mdot
.08728 .42496 Mdot
.52036 .82371 Mdot
.12881 .33516 Mdot
.42105 .60296 Mdot
.35247 .15344 Mdot
.71768 .06832 Mdot
.17872 .58297 Mdot
.94522 .48506 Mdot
.3705 .38004 Mdot
.8242 .12859 Mdot
.00675 .23339 Mdot
.87927 .18976 Mdot
.97634 .82586 Mdot
.31617 .3763 Mdot
.8527 .48638 Mdot
.91752 .75309 Mdot
.45725 .32476 Mdot
.17254 .70219 Mdot
.30006 .73902 Mdot
.23358 .22481 Mdot
.93509 .36905 Mdot
.38272 .09953 Mdot
.95025 .12863 Mdot
.49159 .9291 Mdot
.01957 .30236 Mdot
.19891 .55355 Mdot
.17119 .8143 Mdot
.27904 .81108 Mdot
.67925 .48367 Mdot
.15471 .08848 Mdot
.33939 .75527 Mdot
.94604 .87881 Mdot
.40749 .3998 Mdot
.48743 .758 Mdot
.47738 .25691 Mdot
.03076 .84772 Mdot
.47039 .96116 Mdot
.80252 .28022 Mdot
.33703 .12583 Mdot
.47354 .4926 Mdot
.63362 .64423 Mdot
.34991 .39546 Mdot
.27992 .89112 Mdot
.42944 .51552 Mdot
.87507 .49831 Mdot
.97991 .74667 Mdot
.35476 .22752 Mdot
.98467 .90129 Mdot
.86212 .2767 Mdot
.1692 .61213 Mdot
.50657 .1424 Mdot
.62729 .12973 Mdot
.88284 .50312 Mdot
.25166 .74967 Mdot
.53761 .61605 Mdot
.80155 .24223 Mdot
.70159 .12427 Mdot
.87335 .49629 Mdot
.32591 .88713 Mdot
.92261 .5859 Mdot
.45394 .58949 Mdot
.75582 .99989 Mdot
.97558 .45387 Mdot
.14643 .84503 Mdot
.11597 .93811 Mdot
.86662 .11334 Mdot
.49378 .33334 Mdot
.0873 .85851 Mdot
.79845 .22355 Mdot
.20991 .39124 Mdot
.43057 .34244 Mdot
.27375 .77337 Mdot
.00359 .74881 Mdot
.50319 .78183 Mdot
.02916 .28809 Mdot
.3737 .94994 Mdot
.9215 .34504 Mdot
.51462 .83567 Mdot
.3783 .02054 Mdot
.45577 .98195 Mdot
.57409 .79194 Mdot
.27626 .60156 Mdot
.17744 .46743 Mdot
.03296 .8458 Mdot
.18744 .70936 Mdot
.44175 .0574 Mdot
.19564 .43994 Mdot
.08162 .11217 Mdot
.26564 .06371 Mdot
.50483 .27868 Mdot
.86092 .07309 Mdot
.06024 .30851 Mdot
.25388 .27532 Mdot
.74774 .69563 Mdot
.12893 .80837 Mdot
.75639 .86806 Mdot
.93747 .102 Mdot
.27236 .81293 Mdot
.74576 .67167 Mdot
.22067 .68165 Mdot
.45883 .59523 Mdot
.70889 .38785 Mdot
.61181 .541 Mdot
.65331 .10016 Mdot
.3705 .26947 Mdot
.92026 .39957 Mdot
.265 .46819 Mdot
.18338 .533 Mdot
.33869 .37486 Mdot
.89399 .72009 Mdot
.58149 .68437 Mdot
.63207 .05205 Mdot
.13668 .07466 Mdot
.96598 .63061 Mdot
.44989 .54627 Mdot
.26364 .53776 Mdot
.11799 .27311 Mdot
.35333 .13678 Mdot
.83854 .8099 Mdot
.20429 .60768 Mdot
.43322 .45494 Mdot
.30681 .8977 Mdot
.87534 .75518 Mdot
.66285 .86078 Mdot
.72958 .66913 Mdot
.73935 .21483 Mdot
.26226 .11911 Mdot
.43819 .66329 Mdot
.16839 .85386 Mdot
.14584 .53194 Mdot
.32926 .04396 Mdot
.93481 .91098 Mdot
.88748 .59177 Mdot
.55742 .02778 Mdot
.05201 .84848 Mdot
.8979 .16611 Mdot
.28914 .16298 Mdot
.17336 .93826 Mdot
.05436 .03674 Mdot
.70038 .25977 Mdot
.87612 .18674 Mdot
.56623 .74154 Mdot
.52589 .13227 Mdot
.67385 .84363 Mdot
.66101 .52689 Mdot
.13766 .81755 Mdot
.63283 .6838 Mdot
.21926 .64909 Mdot
.35192 .51582 Mdot
.10267 .71649 Mdot
.32028 .47526 Mdot
.34761 .44723 Mdot
.44882 .28234 Mdot
.78257 .68343 Mdot
.93262 .15036 Mdot
.11434 .84903 Mdot
.24697 .60997 Mdot
.9957 .03027 Mdot
.57512 .94587 Mdot
.75308 .36377 Mdot
.23033 .4393 Mdot
.66749 .66639 Mdot
.90707 .95228 Mdot
.31329 .22345 Mdot
.39609 .65308 Mdot
.50106 .54221 Mdot
.45645 .52128 Mdot
.42859 .67154 Mdot
.2388 .89526 Mdot
.45364 .64024 Mdot
.62519 .98162 Mdot
.73394 .26463 Mdot
.39861 .54594 Mdot
.08075 .60914 Mdot
.5005 .59348 Mdot
.73547 .3624 Mdot
.14441 .9227 Mdot
.19811 .83548 Mdot
.61748 .4096 Mdot
.7368 .16041 Mdot
.37176 .52488 Mdot
.25115 .50243 Mdot
.75617 .54912 Mdot
.51452 .22107 Mdot
.32273 .01068 Mdot
.4556 .614 Mdot
.79752 .40632 Mdot
.75424 .2424 Mdot
.66153 .4785 Mdot
.53543 .40902 Mdot
.06072 .0624 Mdot
.81453 .25322 Mdot
.62561 .54685 Mdot
.53005 .74491 Mdot
.92409 .98905 Mdot
.05557 .52514 Mdot
.54966 .98822 Mdot
.51316 .90734 Mdot
.79614 .54659 Mdot
.79908 .64325 Mdot
.12942 .06144 Mdot
.23159 .25085 Mdot
.09729 .99331 Mdot
.38189 .00223 Mdot
.39933 .4645 Mdot
.84957 .23856 Mdot
.49101 .47414 Mdot
.84154 .7096 Mdot
.97132 .49476 Mdot
.27103 .82498 Mdot
.18925 .92571 Mdot
.478 .16102 Mdot
.09479 .85857 Mdot
.26698 .91999 Mdot
.02855 .86323 Mdot
.88976 .93527 Mdot
.54494 .40445 Mdot
.0512 .6985 Mdot
.07151 .93303 Mdot
.19952 .96187 Mdot
.13251 .45672 Mdot
.9056 .15602 Mdot
.92598 .51861 Mdot
.37463 .9995 Mdot
.86533 .6421 Mdot
.1447 .05704 Mdot
.88013 .79433 Mdot
.27038 .12743 Mdot
.27491 .40495 Mdot
.24496 .45865 Mdot
.24172 .4604 Mdot
.1013 .48043 Mdot
.17225 .98822 Mdot
.17522 .33751 Mdot
.2385 .48878 Mdot
.76238 .32094 Mdot
.36527 .83847 Mdot
.63229 .25341 Mdot
.51717 .04594 Mdot
.36335 .11565 Mdot
.24521 .64562 Mdot
.15288 .68284 Mdot
.02259 .19765 Mdot
.07792 .20307 Mdot
.85206 .20533 Mdot
.93586 .88896 Mdot
.58608 .71363 Mdot
.16961 .55438 Mdot
.22168 .88343 Mdot
.48777 .28494 Mdot
.66152 .85316 Mdot
.14755 .15579 Mdot
.41032 .17843 Mdot
.03343 .48338 Mdot
.39134 .00291 Mdot
.95244 .26836 Mdot
.53756 .78549 Mdot
.07413 .39343 Mdot
.97223 .07148 Mdot
.93524 .84055 Mdot
.73283 .1871 Mdot
.37735 .54783 Mdot
.08131 .34224 Mdot
.25712 .40637 Mdot
.61978 .14097 Mdot
.24967 .90475 Mdot
.22008 .14578 Mdot
.29415 .62536 Mdot
.63953 .35393 Mdot
.26905 .24197 Mdot
.69926 .27996 Mdot
.34352 .41835 Mdot
.97711 .10689 Mdot
.00699 .86187 Mdot
.93669 .7683 Mdot
.71523 .4593 Mdot
.26866 .61423 Mdot
.43053 .56536 Mdot
.11109 .47342 Mdot
.16617 .92781 Mdot
.40566 .09415 Mdot
.9011 .68537 Mdot
.72538 .8088 Mdot
.49744 .28517 Mdot
.77578 .69344 Mdot
.51431 .43572 Mdot
.89157 .93927 Mdot
.84713 .96786 Mdot
.57931 .30514 Mdot
.3536 .40472 Mdot
.49216 .84792 Mdot
.23103 .46704 Mdot
.12723 .7479 Mdot
.32513 .76239 Mdot
.34064 .94461 Mdot
.84515 .4663 Mdot
.58186 .22348 Mdot
.29286 .03194 Mdot
.72741 .28835 Mdot
.43275 .08008 Mdot
.15378 .97689 Mdot
.11759 .69665 Mdot
.60727 .13572 Mdot
.84815 .23326 Mdot
.49113 .40329 Mdot
.46778 .48272 Mdot
.18301 .47077 Mdot
.65397 .02245 Mdot
.5559 .21364 Mdot
.3591 .97029 Mdot
.86568 .93051 Mdot
.96153 .882 Mdot
.6961 .95513 Mdot
.84735 .1943 Mdot
.12324 .79324 Mdot
.0283 .95259 Mdot
.55447 .39567 Mdot
.45966 .49335 Mdot
.38875 .95116 Mdot
.83902 .47523 Mdot
.86913 .7055 Mdot
.41493 .52656 Mdot
.04679 .79845 Mdot
.48167 .63347 Mdot
.28013 .85991 Mdot
.65679 .44368 Mdot
.21242 .04613 Mdot
.65586 .49034 Mdot
.59568 .66221 Mdot
.1858 .00099 Mdot
.20335 .71881 Mdot
.3271 .53065 Mdot
.34156 .01168 Mdot
.92917 .0098 Mdot
.3415 .20871 Mdot
.37209 .37634 Mdot
.08144 .36884 Mdot
.72191 .93045 Mdot
.84767 .29739 Mdot
.10231 .42382 Mdot
.22466 .63526 Mdot
.89497 .41174 Mdot
.05097 .91524 Mdot
.52007 .87726 Mdot
.64843 .92494 Mdot
.61901 .87051 Mdot
.30056 .68617 Mdot
.24156 .49608 Mdot
.26362 .33757 Mdot
.48146 .57812 Mdot
.39292 .02519 Mdot
.43433 .15353 Mdot
.20616 .4013 Mdot
.53352 .75481 Mdot
.19173 .46808 Mdot
.04471 .88713 Mdot
.4673 .5492 Mdot
.35654 .02811 Mdot
.19219 .85542 Mdot
.16051 .53561 Mdot
.92904 .5358 Mdot
.58814 .96595 Mdot
.46134 .52464 Mdot
.16608 .78581 Mdot
.31148 .13292 Mdot
.58007 .03767 Mdot
.15927 .68829 Mdot
.57075 .13335 Mdot
.62506 .13622 Mdot
.22072 .09966 Mdot
.43219 .27744 Mdot
.12544 .58519 Mdot
.50815 .73736 Mdot
.44884 .62079 Mdot
.05246 .22357 Mdot
.30198 .84906 Mdot
.71653 .09845 Mdot
.72056 .8166 Mdot
.57574 .39172 Mdot
.16691 .67527 Mdot
.97324 .25167 Mdot
.95596 .5605 Mdot
.48533 .98488 Mdot
.86986 .98885 Mdot
.992 .22602 Mdot
.35959 .36088 Mdot
.96822 .00188 Mdot
.0946 .51551 Mdot
.21894 .91533 Mdot
.30807 .69238 Mdot
.58733 .52492 Mdot
.19482 .00629 Mdot
.65559 .25386 Mdot
.24061 .46623 Mdot
.15563 .29905 Mdot
.36599 .48095 Mdot
.17823 .04478 Mdot
.02943 .11617 Mdot
.23086 .04013 Mdot
.97599 .6061 Mdot
.02704 .12812 Mdot
.60509 .93007 Mdot
.37725 .60405 Mdot
.41442 .9071 Mdot
.73942 .33198 Mdot
.21488 .45679 Mdot
.58173 .06194 Mdot
.82389 .97749 Mdot
.40419 .00962 Mdot
.82178 .84863 Mdot
.21896 .93892 Mdot
.8492 .23372 Mdot
.20265 .81133 Mdot
.22755 .33929 Mdot
.80875 .21037 Mdot
.78652 .41077 Mdot
.10451 .85351 Mdot
.55699 .99674 Mdot
.4553 .79948 Mdot
.75311 .03576 Mdot
.08451 .80519 Mdot
.96632 .16949 Mdot
.86383 .86065 Mdot
.12918 .92847 Mdot
.62431 .05445 Mdot
.89593 .60726 Mdot
.84718 .84335 Mdot
.11326 .19406 Mdot
.74314 .00116 Mdot
.50463 .20465 Mdot
.27639 .17179 Mdot
.76017 .19922 Mdot
.22611 .40355 Mdot
.80352 .03902 Mdot
.35802 .52439 Mdot
.68418 .09686 Mdot
.74859 .46702 Mdot
.83447 .45864 Mdot
.93251 .6305 Mdot
.72613 .26005 Mdot
.17728 .65419 Mdot
.21201 .04281 Mdot
.90136 .48311 Mdot
.40888 .86897 Mdot
.66073 .10542 Mdot
.61126 .84236 Mdot
.2824 .57023 Mdot
.96681 .75569 Mdot
.5419 .09707 Mdot
.13033 .29205 Mdot
.63092 .45095 Mdot
.36904 .02282 Mdot
.45621 .79785 Mdot
.20235 .9508 Mdot
.57971 .3152 Mdot
.73874 .11385 Mdot
.91725 .2204 Mdot
.13341 .26446 Mdot
.58821 .64952 Mdot
.19891 .51005 Mdot
.10092 .55527 Mdot
.08689 .21888 Mdot
.39829 .08651 Mdot
.6832 .19567 Mdot
.94129 .28615 Mdot
.47204 .23723 Mdot
.32991 .97327 Mdot
.73341 .15178 Mdot
.40424 .7384 Mdot
.60021 .89481 Mdot
.80215 .11678 Mdot
.41449 .38398 Mdot
.75642 .53747 Mdot
.35936 .14087 Mdot
.30815 .4604 Mdot
.66891 .97088 Mdot
.38066 .14484 Mdot
.1956 .70147 Mdot
.06514 .18602 Mdot
.42857 .56209 Mdot
.60331 .43921 Mdot
.84725 .66941 Mdot
.81175 .33793 Mdot
.37805 .30644 Mdot
.09695 .80086 Mdot
.04154 .14508 Mdot
.73923 .33264 Mdot
.33503 .18554 Mdot
.33729 .17205 Mdot
.17343 .49821 Mdot
.29 .98844 Mdot
.67078 .94801 Mdot
.65222 .5491 Mdot
.85374 .24698 Mdot
.85246 .2078 Mdot
.43476 .9547 Mdot
.79321 .39418 Mdot
.41247 .79422 Mdot
.07591 .05325 Mdot
.1417 .5987 Mdot
.70106 .88718 Mdot
.97717 .10336 Mdot
.39219 .89052 Mdot
.27836 .16522 Mdot
.75764 .31618 Mdot
.38407 .93842 Mdot
.91198 .12709 Mdot
.97854 .97752 Mdot
.14266 .71981 Mdot
.49101 .17814 Mdot
.09722 .66159 Mdot
.39384 .58482 Mdot
.32364 .78489 Mdot
.42177 .4944 Mdot
.95552 .90401 Mdot
.1885 .33122 Mdot
.18508 .57081 Mdot
.76778 .37403 Mdot
.25603 .46131 Mdot
.81759 .39861 Mdot
.16711 .73486 Mdot
.30376 .21556 Mdot
.11262 .07157 Mdot
.91045 .62197 Mdot
.74826 .28794 Mdot
.42376 .13811 Mdot
.82627 .39073 Mdot
.25347 .83989 Mdot
.63677 .82514 Mdot
.46502 .46004 Mdot
.37087 .38034 Mdot
.66877 .05926 Mdot
.2366 .62745 Mdot
.35585 .8257 Mdot
.17379 .55524 Mdot
.46922 .17917 Mdot
.3866 .24765 Mdot
.07105 .03188 Mdot
.55133 .86442 Mdot
.78179 .2086 Mdot
.94118 .03707 Mdot
.26847 .75599 Mdot
.49824 .65635 Mdot
.57244 .70495 Mdot
.29078 .02209 Mdot
.22054 .88703 Mdot
.17104 .48381 Mdot
.71703 .6989 Mdot
.73961 .21691 Mdot
.66159 .66223 Mdot
.18084 .38019 Mdot
.90323 .46818 Mdot
.24076 .34276 Mdot
.58554 .70439 Mdot
.70327 .65619 Mdot
.04058 .99296 Mdot
.40736 .62013 Mdot
.78728 .12785 Mdot
.29448 .1429 Mdot
.10796 .41465 Mdot
.52367 .94295 Mdot
.36613 .7388 Mdot
.37282 .57007 Mdot
.47427 .27978 Mdot
.15977 .25358 Mdot
.8965 .56667 Mdot
.413 .58511 Mdot
.88506 .56725 Mdot
.03634 .95734 Mdot
.11547 .47338 Mdot
.70939 .80972 Mdot
.02823 .05415 Mdot
.18314 .87129 Mdot
.60835 .30512 Mdot
.78007 .29398 Mdot
.1413 .02111 Mdot
.62259 .06408 Mdot
.23887 .46691 Mdot
.21282 .47575 Mdot
.34396 .89087 Mdot
.20637 .50537 Mdot
.28106 .42764 Mdot
.45159 .68092 Mdot
.28255 .36846 Mdot
.28595 .82667 Mdot
.66336 .0562 Mdot
.48501 .52264 Mdot
.53768 .01936 Mdot
.89419 .46665 Mdot
.30008 .54747 Mdot
.66643 .01922 Mdot
.9752 .66928 Mdot
.45441 .50269 Mdot
.64907 .24551 Mdot
.05289 .80551 Mdot
.33105 .91121 Mdot
.69247 .00239 Mdot
.6577 .87161 Mdot
.20296 .47467 Mdot
.13981 .84822 Mdot
.30056 .99536 Mdot
.7945 .2941 Mdot
.60117 .02163 Mdot
.8693 .61981 Mdot
.16269 .51817 Mdot
.21414 .40158 Mdot
.14293 .7186 Mdot
.85862 .47012 Mdot
.38058 .72744 Mdot
.18595 .60454 Mdot
.2204 .28607 Mdot
.08863 .76232 Mdot
.91767 .26343 Mdot
.24852 .46463 Mdot
.29603 .26499 Mdot
.37339 .82907 Mdot
.1805 .74808 Mdot
.21251 .46436 Mdot
.0835 .02793 Mdot
.33804 .98097 Mdot
.65733 .28788 Mdot
.19895 .3904 Mdot
.41442 .03364 Mdot
.1596 .60812 Mdot
.49779 .7511 Mdot
.87895 .15863 Mdot
.22593 .49689 Mdot
.45253 .33162 Mdot
.08757 .74973 Mdot
.26337 .88228 Mdot
.02979 .7165 Mdot
.95217 .90544 Mdot
.31517 .4214 Mdot
.74306 .52759 Mdot
.8963 .38584 Mdot
.58462 .94242 Mdot
.35807 .61515 Mdot
.72207 .7732 Mdot
.16332 .11834 Mdot
.2505 .45649 Mdot
.13565 .39291 Mdot
.00547 .56494 Mdot
.14092 .68012 Mdot
.10158 .66776 Mdot
.76936 .26224 Mdot
.32826 .11425 Mdot
.90428 .89177 Mdot
.72265 .19375 Mdot
.48238 .26072 Mdot
.01448 .42313 Mdot
.34795 .12611 Mdot
.72455 .99674 Mdot
.24484 .75533 Mdot
.7577 .39807 Mdot
.16574 .06744 Mdot
.67184 .74874 Mdot
.35298 .81646 Mdot
.34758 .61868 Mdot
.47623 .93124 Mdot
.62926 .42077 Mdot
.03731 .66517 Mdot
.63329 .02598 Mdot
.63204 .51915 Mdot
.93548 .03206 Mdot
.36912 .76485 Mdot
.17939 .61495 Mdot
.23602 .68396 Mdot
.44279 .87552 Mdot
.89322 .88129 Mdot
.12588 .24586 Mdot
.34015 .95833 Mdot
.4413 .81553 Mdot
.34567 .29451 Mdot
.83748 .80824 Mdot
.69235 .76967 Mdot
.93747 .77941 Mdot
.30972 .99822 Mdot
.73852 .16323 Mdot
.09247 .31635 Mdot
.26804 .29705 Mdot
.21504 .45583 Mdot
.17761 .03038 Mdot
.8576 .48349 Mdot
.697 .21854 Mdot
.46628 .18593 Mdot
.87775 .42352 Mdot
.7862 .4121 Mdot
.99679 .64289 Mdot
.43703 .43167 Mdot
.22748 .49025 Mdot
.38203 .09591 Mdot
.96094 .19465 Mdot
.19789 .66058 Mdot
.78667 .16861 Mdot
.3465 .167 Mdot
.12471 .91882 Mdot
.88299 .99112 Mdot
.22626 .50905 Mdot
.12928 .56693 Mdot
.24912 .86746 Mdot
.61214 .13573 Mdot
.0596 .38264 Mdot
.23134 .02166 Mdot
.09127 .17793 Mdot
.05365 .36745 Mdot
.288 .01707 Mdot
.67283 .17908 Mdot
.19867 .08334 Mdot
.80621 .20716 Mdot
.98185 .58475 Mdot
.71696 .63318 Mdot
.68912 .72101 Mdot
.14834 .50342 Mdot
.67656 .32862 Mdot
.8901 .46649 Mdot
.59056 .15155 Mdot
.85952 .10847 Mdot
.31768 .1248 Mdot
.19403 .90516 Mdot
.14734 .02708 Mdot
.35179 .70402 Mdot
.19018 .46296 Mdot
.63711 .08263 Mdot
.43899 .7168 Mdot
.50963 .57948 Mdot
.79088 .37418 Mdot
.65402 .1198 Mdot
.20027 .22852 Mdot
.80874 .03611 Mdot
.88587 .09956 Mdot
.61833 .1103 Mdot
.7368 .06938 Mdot
.25246 .41998 Mdot
.54196 .60618 Mdot
.59618 .31475 Mdot
.1405 .86801 Mdot
.09392 .75048 Mdot
.30607 .49081 Mdot
.37828 .62093 Mdot
.15263 .2707 Mdot
.54613 .61113 Mdot
.27004 .16559 Mdot
.97413 .5008 Mdot
.49176 .1213 Mdot
.68639 .10801 Mdot
.9484 .52226 Mdot
.12646 .77459 Mdot
.83233 .63419 Mdot
.06436 .02216 Mdot
.46459 .15052 Mdot
.63822 .38979 Mdot
.3236 .90023 Mdot
.09398 .79583 Mdot
.1214 .72347 Mdot
.12449 .30113 Mdot
.53257 .59827 Mdot
.38722 .17954 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00So
oooo0_l00004ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo0_l000000ooooooo0000o`000002ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`;o
000000?oooooo`000?ooool03oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[o
oooo0_l000000ooooooo0000ooooo`0;ooooo`;o000000?oooooo`000?ooool03oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`03ooooo`;o00002Oooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0;ooooo`;o000000?oooooo`000?ooool03_ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool01oooool2o`000003ooooool0003o000000;ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo
0_l000000ooooooo0000ooooo`0?ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
2_ooool2o`000003ooooool0003ooooo00kooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`03ooooo`;o00002Oooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooooooo
o`0kooooo`;o0000@_ooool2o`000:Wooooo0_l0000Kooooo`007_ooool00ol0003oooooooooo`1U
ooooo`;o00001?ooool2o`0001;ooooo0_l0002Yooooo`;o00006oooool001kooooo00?o0000oooo
ooooool0IOooool2o`0000Cooooo0_l0003Jooooo`007_ooool00ol0003oooooooooo`0fooooo`;o
00008_ooool2o`0004oooooo0_l0000Xooooo`;o00007_ooool2o`00053ooooo000Nooooo`03o`00
0?oooooooooo017ooooo0_l0000Gooooo`;o00002_ooool2o`0000oooooo0_l0000Aooooo`;o0000
6?ooool2o`000003ooooool0003o000003;ooooo0_l0000Booooo`;o00003oooool2o`0000?ooooo
0_l0000Nooooo`;o0000D?ooool001kooooo0_l0000Booooo`;o00005oooool2o`0001_ooooo0_l0
000Aooooo`;o00006?ooool2o`000003ooooool0003o000000?ooooo0_l00006ooooo`;o0000>Ooo
ool2o`0000Wooooo0_l00004ooooo`;o0000MOooool001kooooo0_l0000Dooooo`;o00000_ooool2
o`0001?ooooo0_l00003ooooo`;o0000?Oooool2o`0000[ooooo0_l00006ooooo`;o0000:oooool2
o`00013ooooo0_l00005ooooo`;o0000Noooool001kooooo00?o0000ooooooooool04oooool2o`00
00;ooooo0_l0000Cooooo`;o00000oooool2o`0000?ooooo0_l0000Sooooo`;o00004oooool2o`00
03oooooo0_l0000@ooooo`;o0000COooool2o`0001Sooooo0_l0000Booooo`;o00001Oooool001ko
oooo00?o0000ooooooooool04oooool2o`00027ooooo0_l0000Sooooo`;o00009_ooool2o`0002[o
oooo0_l0001Qooooo`;o00006?ooool2o`0001;ooooo0_l00005ooooo`007_ooool00ol0003ooooo
ooooo`0>ooooo`;o0000?_ooool2o`0003?ooooo0_l0000Zooooo`;o00001oooool2o`0001Wooooo
0_l0000Looooo`;o00004?ooool2o`0002Wooooo0_l0000Gooooo`007_ooool00ol0003ooooooooo
o`0>ooooo`;o0000=oooool2o`0000Gooooo0_l0000Wooooo`;o0000?oooool2o`0001Wooooo0_l0
000Looooo`;o00003_ooool4o`0002Wooooo0_l0000Gooooo`007_ooool00ol0003oooooooooo`11
ooooo`;o00001?ooool2o`0001kooooo0_l0000>ooooo`;o0000R?ooool2o`0004Cooooo000Noooo
o`03o`000?oooooooooo03Kooooo0_l00006ooooo`;o000000?oooooo`000?l000009?ooool2o`00
03_ooooo0_l0002Qooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o00005Oooool2o`0000Ko
oooo0_l000000ooooooo0000o`00001Qooooo`;o0000XOooool001kooooo0_l0000Fooooo`;o0000
2?ooool2o`000:Sooooo0_l0001looooo`007_ooool00ol0003oooooooooo`05ooooo`;o00003_oo
ool2o`000;3ooooo1?l00009ooooo`;o0000LOooool001kooooo00?o0000ooooooooool01Oooool2
o`0002Cooooo0_l0000eooooo`;o00006_ooool2o`0000cooooo0_l0000iooooo`;o00002oooool3
o`00073ooooo000Nooooo`03o`000?oooooooooo013ooooo0_l0000Dooooo`;o00000oooool2o`00
03Gooooo0_l0000Jooooo`;o00003?ooool2o`0002_ooooo0_l0000Jooooo`;o0000L?ooool001ko
oooo00?o0000ooooooooool04?ooool2o`0001Cooooo0_l0000Pooooo`;o00002?ooool2o`0006Go
oooo0_l0000;ooooo`;o0000Ooooool001kooooo00?o0000ooooooooool0<_ooool2o`0001Cooooo
0_l00008ooooo`;o0000L_ooool2o`0001gooooo0_l0001Pooooo`007_ooool00ol0003ooooooooo
o`0Pooooo`;o00004?ooool2o`0004kooooo0_l0001Qooooo`;o00001?ooool2o`0004_ooooo0_l0
000=ooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o00001_ooool2o`0005Sooooo0_l0001W
ooooo`;o00009oooool2o`0002;ooooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`0Xoooo
o`;o0000AOooool2o`000:?ooooo0_l0000aooooo`007_ooool00ol0003oooooooooo`1_ooooo`;o
00006?ooool2o`000;cooooo000Nooooo`03o`000?oooooooooo03cooooo0_l0000eooooo`;o0000
5?ooool2o`00043ooooo0_l0001jooooo`007_ooool00ol0003oooooooooo`0looooo`;o0000=Ooo
ool2o`0000Sooooo0_l0001<ooooo`;o00002_ooool2o`0006kooooo000Nooooo`03o`000?oooooo
oooo02kooooo0_l0001=ooooo`;o0000F?ooool2o`0000Kooooo0_l0001Vooooo`007_ooool00ol0
003oooooooooo`09ooooo`;o00008oooool2o`0004Wooooo0_l0000?ooooo`;o0000Doooool2o`00
05Kooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`09ooooo`;o0000KOooool3o`0000Go
oooo0_l00008ooooo`;o00000_ooool2o`0000Gooooo0_l0000Wooooo`;o00001oooool2o`0006ko
oooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`14ooooo`;o0000<_ooool2o`0000Kooooo
0_l0000<ooooo`;o00001Oooool2o`0001Gooooo0_l0000@ooooo`;o00001oooool2o`00017ooooo
0_l00009ooooo`;o0000=Oooool2o`0002Wooooo000Nooooo`;o0000AOooool2o`0003;ooooo0_l0
000booooo`;o00008_ooool2o`0000Sooooo0_l00009ooooo`;o0000=Oooool2o`0000oooooo0_l0
000Hooooo`007_ooool00ol0003oooooooooo`3@ooooo`;o000000?oooooo`000?l00000F?ooool2
o`0000_ooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`3Cooooo`;o00001_ooool2o`00
03Kooooo0_l0000Uooooo`;o00002oooool001kooooo00?o0000ooooooooool0I?ooool2o`0005oo
oooo0_l0000Dooooo`;o0000=_ooool2o`0002Gooooo0_l0000;ooooo`007_ooool00ol0003ooooo
ooooo`0Fooooo`;o00001oooool2o`0004?ooooo0_l000000ooooooo0000o`00001Looooo`;o0000
9Oooool2o`0002Sooooo0_l0000_ooooo`007_ooool00ol0003oooooooooo`05ooooo`;o00003ooo
ool2o`0000Oooooo0_l00016ooooo`;o00002Oooool2o`0005cooooo0_l0000Jooooo`;o00004ooo
ool2o`0001?ooooo0_l0000_ooooo`007_ooool00ol0003oooooooooo`05ooooo`;o0000:_ooool2
o`0001kooooo0_l0000Oooooo`;o00001Oooool2o`00027ooooo0_l0000booooo`?o0000;_ooool2
o`0004Cooooo000Nooooo`03o`000?oooooooooo037ooooo0_l0000Nooooo`;o00009_ooool2o`00
027ooooo0_l0000cooooo`;o00003Oooool2o`0006Gooooo000Nooooo`03o`000?oooooooooo01?o
oooo0_l0000=ooooo`;o0000<?ooool2o`0000gooooo0_l00004ooooo`;o00000_ooool2o`0000oo
oooo0_l0001Pooooo`;o0000@_ooool2o`00027ooooo000Nooooo`03o`000?oooooooooo00Gooooo
0_l0000<ooooo`;o00003Oooool2o`00033ooooo0_l0000=ooooo`;o00001?ooool2o`0000;ooooo
0_l0000?ooooo`;o0000;Oooool2o`0001Wooooo0_l0000booooo`;o00002_ooool2o`0001[ooooo
0_l0000;ooooo`;o00005?ooool001kooooo0ol00005ooooo`;o0000F_ooool2o`0004Cooooo0_l0
0004ooooo`;o00001_ooool2o`00017ooooo0_l00008ooooo`;o0000:?ooool2o`0000[ooooo0_l0
000Wooooo`;o00005?ooool001kooooo0ol0001Qooooo`;o0000A?ooool2o`0000cooooo0_l0000:
ooooo`Co00000_ooool2o`0000Wooooo0_l0001cooooo`007_ooool00ol0003oooooooooo`1_oooo
o`;o00005Oooool2o`0003Wooooo1?l00002ooooo`;o0000O_ooool001kooooo00?o0000oooooooo
ool0DOooool2o`0000Wooooo0_l0000Aooooo`Co00004oooool2o`0001Wooooo0_l0000Rooooo`;o
0000P?ooool001kooooo00?o0000ooooooooool02Oooool2o`0003Sooooo0_l0000<ooooo`;o0000
2Oooool2o`0001?ooooo0_l00005ooooo`;o00002oooool2o`0001[ooooo0_l0000Rooooo`;o0000
P?ooool001kooooo00?o0000ooooooooool02Oooool2o`0003Sooooo0_l0000cooooo`;o00002ooo
ool2o`000<3ooooo000Nooooo`;o0000U?ooool2o`0002Oooooo0_l0000/ooooo`;o0000?oooool2
o`0001[ooooo000Nooooo`03o`000?oooooooooo06kooooo0_l00007ooooo`;o00004?ooool2o`00
00Sooooo0_l0000Wooooo`;o0000;?ooool2o`0003oooooo0_l0000Jooooo`007_ooool00ol0003o
ooooooooo`0/ooooo`;o0000@?ooool2o`0000Oooooo0_l0000@ooooo`;o0000Uoooool2o`0002?o
oooo000Nooooo`03o`000?oooooooooo02cooooo0_l0001Yooooo`;o00004?ooool2o`00043ooooo
0_l0000]ooooo`;o00001_ooool2o`0002?ooooo000Nooooo`03o`000?oooooooooo00kooooo0_l0
001:ooooo`;o0000>oooool2o`00013ooooo0_l00010ooooo`?o0000;?ooool2o`0002_ooooo000N
ooooo`03o`000?oooooooooo00kooooo0_l00014ooooo`Co00000_ooool2o`00017ooooo0_l0001m
ooooo`;o0000<_ooool2o`0002Gooooo000Nooooo`03o`000?oooooooooo05Cooooo1?l0000Eoooo
o`;o0000OOooool2o`0000kooooo0_l0000Rooooo`;o00005?ooool2o`0000oooooo000Nooooo`03
o`000?oooooooooo05Kooooo0_l0000Booooo`;o0000T?ooool2o`0003Sooooo0_l0000?ooooo`00
7_ooool00ol0003oooooooooo`1Fooooo`;o00004_ooool2o`000=_ooooo000Nooooo`03o`000?oo
oooooooo01[ooooo0_l0001Nooooo`;o00001Oooool2o`00017ooooo0_l00006ooooo`;o0000>Ooo
ool2o`0006kooooo000Nooooo`03o`000?oooooooooo01[ooooo0_l0001Nooooo`;o00001Oooool2
o`00017ooooo0_l00006ooooo`;o00008oooool2o`0001Cooooo0_l0001^ooooo`007_ooool00ol0
003oooooooooo`1Yooooo`;o0000:?ooool2o`0002cooooo0_l00024ooooo`007_ooool00ol0003o
ooooooooo`0Aooooo`;o0000E_ooool2o`0002Sooooo0_l0000<ooooo`;o0000Aoooool2o`0002go
oooo0_l0000/ooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o0000S_ooool2o`0004Oooooo
0_l0000]ooooo`?o0000:oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool08Oooool2o`000<Cooooo0_l0000Vooooo`;o0000
2Oooool2o`0001Sooooo0_l0000Aooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`03ooooo`;o
00007?ooool2o`000;Oooooo0_l0000;ooooo`;o00009_ooool2o`0000_ooooo0_l0000Fooooo`;o
00004Oooool000?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo0ol00003ooooo`;o0000eOooool2o`0000?ooooo0_l0000Booooo`;o00009oooool2o`0002Wo
oooo0003ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`03
o`000?oooooooooo01Gooooo0_l0001?ooooo`;o0000Moooool2o`0001;ooooo0_l0001Booooo`00
0oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003o
ooooooooo`0Eooooo`;o0000Coooool2o`0003Sooooo0_l0001Pooooo`;o00003Oooool2o`0003Co
oooo0003ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo06_ooooo0ol0000booooo`;o0000F?ooool2o`0000Kooooo0ol0000<ooooo`;o
0000:?ooool2o`0000[ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o
^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool08_ooool2o`0000[ooooo0_l0000koooo
o`?o0000?_ooool2o`0000?ooooo0_l00017ooooo`;o00001oooool2o`0000cooooo0_l0000Xoooo
o`;o00002_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0Rooooo`?o00002Oooool4o`0002gooooo0_l0001;
ooooo`;o00000oooool2o`0003Wooooo0_l0001Iooooo`007_ooool00ol0003oooooooooo`0Hoooo
o`;o00002Oooool2o`0000_ooooo0_l0000Mooooo`;o00003_ooool2o`0007gooooo0_l0000<oooo
o`;o00001oooool2o`00053ooooo000Nooooo`03o`000?oooooooooo01Sooooo0_l0000eooooo`;o
0000D_ooool2o`0003Wooooo0_l0000<ooooo`;o00001oooool2o`0002oooooo0_l0000Oooooo`00
7_ooool2o`0000kooooo0_l0000Jooooo`;o00007Oooool2o`0001Sooooo0_l0000oooooo`;o0000
5?ooool2o`0004Cooooo0_l0000Uooooo`;o00007oooool001kooooo0_l0000>ooooo`;o00006_oo
ool2o`0001;ooooo0_l00009ooooo`;o00006?ooool2o`0000_ooooo0_l00018ooooo`;o00004Ooo
ool2o`00037ooooo0_l0000Qooooo`;o00006_ooool2o`0000Oooooo000Nooooo`03o`000?oooooo
oooo03gooooo0_l00003ooooo`;o0000:oooool2o`0005_ooooo0_l0001Dooooo`;o00006_ooool2
o`0000Oooooo000Nooooo`?o0000@_ooool2o`000<cooooo0_l0000eooooo`007_ooool3o`0009Go
oooo0_l0001iooooo`;o0000=Oooool001kooooo00?o0000ooooooooool0UOooool2o`0007Wooooo
0_l0000eooooo`007_ooool00ol0003oooooooooo`1Cooooo`;o0000W?ooool2o`0000gooooo0_l0
000>ooooo`;o0000=Oooool001kooooo00?o0000ooooooooool09Oooool2o`0002cooooo0_l0001j
ooooo`;o00008?ooool2o`0000gooooo0_l0000?ooooo`;o0000=?ooool001kooooo00?o0000oooo
ooooool09Oooool2o`0005?ooooo0_l0001Cooooo`;o0000@?ooool2o`0003Cooooo000Nooooo`;o
0000<Oooool2o`0001Gooooo0_l0000aooooo`;o0000COooool2o`0003[ooooo0_l0000aooooo`;o
00003Oooool001kooooo00?o0000ooooooooool0<?ooool2o`0001Gooooo0_l00020ooooo`;o0000
1_ooool2o`0003;ooooo0_l0000aooooo`;o00003Oooool001kooooo00?o0000ooooooooool0Uooo
ool2o`0003Sooooo0_l0000=ooooo`;o0000IOooool001kooooo00?o0000ooooooooool0Uoooool4
o`0004Gooooo0_l00006ooooo`;o00003?ooool2o`0004oooooo000Nooooo`03o`000?oooooooooo
02Oooooo0_l0000cooooo`;o00006?ooool2o`00027ooooo0_l00011ooooo`;o00002_ooool4o`00
00[ooooo0_l0000^ooooo`;o00007oooool001kooooo00?o0000ooooooooool09oooool2o`0003?o
oooo0_l0000Hooooo`;o0000I?ooool2o`0000cooooo0_l0000jooooo`;o00002_ooool2o`0001?o
oooo000Nooooo`03o`000?oooooooooo02kooooo0_l00014ooooo`;o0000_?ooool2o`0001?ooooo
000Nooooo`03o`000?oooooooooo02;ooooo0_l0000:ooooo`;o0000A?ooool2o`000=7ooooo000N
ooooo`03o`000?oooooooooo02;ooooo0_l0000Zooooo`;o0000>?ooool2o`0008[ooooo0_l0000a
ooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o0000<_ooool2o`0003Sooooo0_l0000<oooo
o`;o00002?ooool2o`0003gooooo0_l0000Pooooo`;o00003_ooool2o`000003ooooool0003o0000
037ooooo000Nooooo`03o`000?oooooooooo01[ooooo0_l0001booooo`;o00001_ooool2o`0000So
oooo0_l0000mooooo`;o00008?ooool2o`0000kooooo0_l0000dooooo`007_ooool00ol0003ooooo
ooooo`14ooooo`;o0000B?ooool2o`0000[ooooo0_l00002ooooo`;o0000S_ooool2o`0001Oooooo
000Nooooo`03o`000?oooooooooo00Gooooo0ol0000Wooooo`;o00004oooool2o`0005Cooooo0_l0
0002ooooo`;o0000<_ooool2o`0001Cooooo0_l00005ooooo`;o0000?Oooool2o`0001Oooooo000N
ooooo`03o`000?oooooooooo00Gooooo0ol0000Nooooo`;o00001oooool2o`000:7ooooo0_l0000D
ooooo`;o00001Oooool2o`0005Kooooo000Nooooo`03o`000?oooooooooo02Kooooo0_l00014oooo
o`;o0000ROooool4o`0000?ooooo0_l00017ooooo`007_ooool00ol0003oooooooooo`0Zooooo`;o
00000_ooool2o`0002?ooooo0_l0000Gooooo`;o0000ROooool4o`0000?ooooo0_l0000?ooooo`;o
0000=_ooool001kooooo0_l00003ooooo`;o00008?ooool2o`0000Cooooo0_l00002ooooo`;o0000
8oooool2o`000;[ooooo0_l0000Tooooo`;o00004?ooool001kooooo00?o0000ooooooooool00_oo
ool2o`000003ooooool0003o000001gooooo0_l0002Booooo`;o00002?ooool2o`00077ooooo0_l0
000@ooooo`007_ooool00ol0003oooooooooo`05ooooo`;o00002?ooool2o`0006Kooooo0_l0000o
ooooo`;o00002?ooool2o`0008?ooooo000Nooooo`03o`000?oooooooooo00oooooo0_l0001Voooo
o`;o0000N_ooool2o`0005;ooooo000Nooooo`03o`000?oooooooooo0;kooooo0_l0000cooooo`;o
0000D_ooool001kooooo00?o0000ooooooooool06_ooool2o`0009cooooo0_l00004ooooo`;o0000
<_ooool2o`0001?ooooo0_l0000nooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o0000W?oo
ool2o`0003Sooooo1?l0000Aooooo`;o0000?_ooool001kooooo00?o0000ooooooooool0m?ooool2
o`00057ooooo000Nooooo`03o`000?oooooooooo093ooooo0ol0002dooooo`007_ooool00ol0003o
ooooooooo`2@ooooo`?o0000:Oooool2o`0001[ooooo0_l0000Hooooo`;o0000Doooool001kooooo
00?o0000ooooooooool0>Oooool2o`00027ooooo0_l0000aooooo`;o00002oooool2o`0001kooooo
0_l0000Jooooo`;o00004_ooool2o`0000Cooooo0_l0000booooo`;o00007oooool001kooooo00?o
0000ooooooooool09_ooool2o`0000?ooooo0_l0000<ooooo`;o00008Oooool2o`00037ooooo0_l0
000;ooooo`;o0000=_ooool2o`0001Kooooo0_l0000hooooo`;o00007oooool001kooooo00?o0000
ooooooooool09_ooool2o`0000?ooooo0_l00008ooooo`;o00003oooool2o`0000[ooooo0_l00020
ooooo`;o0000;_ooool2o`00047ooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l0000Moooo
o`;o00003oooool2o`0000;ooooo0_l00006ooooo`;o0000=?ooool2o`0007[ooooo0_l00011oooo
o`007_ooool00ol0003oooooooooo`0Fooooo`;o0000<_ooool2o`0003cooooo0_l0000Gooooo`;o
0000Q?ooool2o`0001kooooo000Nooooo`03o`000?oooooooooo0:7ooooo0_l00024ooooo`;o0000
7_ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0<cooooo0_l0001i
ooooo`007_ooool00ol0003oooooooooo`1Rooooo`;o0000J?ooool2o`0007Wooooo000Nooooo`03
o`000?oooooooooo06;ooooo0_l0000=ooooo`;o0000e?ooool001kooooo00?o0000ooooooooool0
F?ooool2o`0001Oooooo0_l0001hooooo`;o00001?ooool2o`0005Cooooo000Nooooo`03o`000?oo
oooooooo00gooooo0_l00019ooooo`;o0000TOooool2o`0000Cooooo0_l0001Dooooo`007_ooool0
0ol0003oooooooooo`0=ooooo`;o00001oooool2o`00043ooooo0_l0003Booooo`;o00006Oooool0
01kooooo00?o0000ooooooooool02_ooool2o`0000[ooooo0_l00010ooooo`;o0000:?ooool2o`00
0:Sooooo0_l0000Iooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o00007Oooool2o`0003So
oooo0_l00005ooooo`;o00002Oooool2o`0000_ooooo0_l0001booooo`;o00001Oooool2o`0004So
oooo000Nooooo`03o`000?oooooooooo02Wooooo0_l0000hooooo`;o00001Oooool2o`0000Wooooo
0_l0001oooooo`;o00001Oooool2o`0004Sooooo000Nooooo`03o`000?oooooooooo00oooooo0_l0
000Vooooo`;o0000>oooool2o`000=7ooooo000Nooooo`03o`000?oooooooooo00oooooo0_l0000V
ooooo`;o00002?ooool2o`00037ooooo0_l0000=ooooo`;o0000V_ooool2o`0002Kooooo000Noooo
o`03o`000?oooooooooo047ooooo0_l00010ooooo`;o0000GOooool2o`0003_ooooo0_l0000Voooo
o`007_ooool00ol0003oooooooooo`0mooooo`;o000000?oooooo`000?l00000MOooool2o`0001;o
oooo0_l0000Eooooo`;o00001_ooool2o`0001gooooo0_l0000looooo`000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003o
ooooooooo`0Dooooo`;o00004_ooool2o`0001?ooooo0_l000000ooooooo0000o`00001eooooo`;o
00004_ooool2o`0001gooooo0_l0000Booooo`;o00002Oooool2o`0003cooooo0003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Dooooo`;o00004_ooool2o`0004Cooooo0_l00010ooooo`;o0000@?ooool2o`0000[o
oooo0_l00017ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`?o
0000;oooool2o`0003gooooo0_l00004ooooo`;o00002_ooool2o`0002kooooo0_l00010ooooo`;o
00004_ooool2o`0001oooooo0_l0000Nooooo`000oooool01Ol0003ooooooooooooooooo000000_o
oooo00CoA4A4omgMgOoooooo00001oooool3o`0002oooooo0_l0000>ooooo`;o000000Coooooo`00
0?l0003ooooo0_l0000Eooooo`;o00005_ooool2o`0000[ooooo0_l0000Jooooo`;o00001?ooool2
o`0006;ooooo0_l0000Oooooo`;o00007_ooool000?ooooo00Go0000ooooooooooooooooo`00000;
ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0?oooool2o`000004ooooool0
003o0000ooooo`;o00002?ooool2o`0000Cooooo0_l00005ooooo`;o00004Oooool2o`0002_ooooo
0_l00004ooooo`;o00002Oooool2o`00053ooooo0_l00016ooooo`000oooool01Ol@413ooooooooo
oooooooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`1?ooooo`;o0000
1?ooool2o`0001Sooooo0_l0000iooooo`;o000000?oooooo`000?l000005_ooool2o`0003Sooooo
0_l00016ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
1oooool00ol0003oooooooooo`2Zooooo`;o00006Oooool2o`0003Cooooo0ol0000Qooooo`;o0000
9_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo
00?o0000ooooooooool07oooool2o`000=[ooooo0ol0000Qooooo`;o00009_ooool001kooooo00?o
0000ooooooooool07oooool2o`0004_ooooo0_l0003Iooooo`007_ooool00ol0003oooooooooo`1>
ooooo`;o00004_ooool2o`0000Sooooo0_l0001Jooooo`;o0000OOooool001kooooo00Co0000oooo
oooooooooooo0_l0000Eooooo`;o00000oooool2o`0002oooooo0_l0000Booooo`;o0000I?ooool2
o`0004oooooo0_l0000/ooooo`007_ooool01?l0003oooooooooooooool2o`0001Gooooo0_l00003
ooooo`;o0000>?ooool2o`0001Wooooo0_l0000Gooooo`;o0000O_ooool2o`0000cooooo0_l0000/
ooooo`007_ooool00ol0003oooooooooo`17ooooo`;o00003_ooool2o`0001Wooooo0_l0000Foooo
o`?o00001?ooool2o`0007Sooooo0_l0000jooooo`007_ooool00ol0003oooooooooo`17ooooo`;o
0000@Oooool2o`0000Gooooo0_l0002dooooo`007_ooool00ol0003oooooooooo`2@ooooo`;o0000
4Oooool2o`000:;ooooo000Nooooo`03o`000?oooooooooo03_ooooo0_l0000:ooooo`;o0000Aooo
ool2o`00017ooooo0_l0000Kooooo`;o0000QOooool001kooooo00?o0000ooooooooool0>oooool2
o`0000[ooooo0_l0001gooooo`;o00003oooool2o`0007Cooooo000Nooooo`03o`000?oooooooooo
06gooooo0_l0001Rooooo`;o00007_ooool2o`0005Cooooo000Nooooo`03o`000?oooooooooo06go
oooo0_l00022ooooo`;o0000E?ooool001kooooo0_l0003:ooooo`;o0000O?ooool001kooooo00?o
0000ooooooooool0=oooool2o`0000Wooooo0_l00009ooooo`;o0000>_ooool2o`0003kooooo0_l0
001^ooooo`;o00003?ooool001kooooo00?o0000ooooooooool09oooool2o`0000kooooo0_l00009
ooooo`;o00002?ooool3o`0003[ooooo0_l0001Iooooo`;o00009Oooool2o`0002cooooo0_l0000<
ooooo`007_ooool00ol0003oooooooooo`0Wooooo`;o00006Oooool2o`0000Gooooo1Ol000000ooo
oooo0000o`00000?ooooo`;o0000<Oooool2o`0003_ooooo0_l0000Booooo`;o00009Oooool2o`00
03[ooooo000Nooooo`03o`000?oooooooooo03[ooooo0_l00005ooooo`;o00001_ooool3o`000003
ooooool0003o000000;o00003oooool2o`0001cooooo0_l00008ooooo`;o00002Oooool2o`0003_o
oooo0_l0001eooooo`007_ooool00ol0003oooooooooo`0fooooo`;o00000_ooool2o`0000Gooooo
0_l00004ooooo`;o000000Coooooo`000?l0003ooooo1?l000000ooooooo0000o`00000Zooooo`;o
00002?ooool2o`0006Gooooo0_l0000Nooooo`;o00003?ooool4o`000003ooooool0003o000002?o
oooo000Nooooo`03o`000?oooooooooo03Kooooo0ol000000ooooooo0000o`00000;ooooo`;o0000
00?oooooo`000?l000000oooool2o`000003ooooool0003o000009_ooooo0_l0000Nooooo`;o0000
0_ooool2o`0000Sooooo1?l000000ooooooo0000o`00000Sooooo`007_ooool00ol0003ooooooooo
o`0Pooooo`?o00005?ooool2o`0000Gooooo0_l0001Looooo`;o0000MOooool2o`0003;ooooo000N
ooooo`03o`000?oooooooooo023ooooo0ol0000Kooooo`;o000000?oooooo`000?l000008Oooool2
o`0003Kooooo0_l0001_ooooo`;o0000>?ooool001kooooo00?o0000ooooooooool07Oooool2o`00
02;ooooo0_l0000Qooooo`;o00003Oooool2o`0005kooooo0_l0000hooooo`;o0000>?ooool001ko
oooo00?o0000ooooooooool01oooool2o`0001Cooooo0_l0000Dooooo`;o0000?_ooool2o`0001oo
oooo0_l0000mooooo`;o00001?ooool2o`0003Sooooo0_l0000<ooooo`;o00009?ooool001kooooo
00?o0000ooooooooool01oooool2o`0002[ooooo0_l0001Oooooo`;o0000@oooool2o`0003Kooooo
1?l0000<ooooo`;o00003?ooool2o`0001Kooooo000Nooooo`03o`000?oooooooooo04Kooooo0_l0
00000ooooooo0000o`000026ooooo`;o0000?_ooool2o`0001cooooo0_l0000Fooooo`007_ooool0
0ol0003oooooooooo`16ooooo`;o000000?oooooo`000?l000005?ooool2o`0002_ooooo0_l00003
ooooo`;o00000oooool2o`0003Wooooo0_l0001dooooo`007_ooool00ol0003oooooooooo`1:oooo
o`;o00004oooool2o`0002Cooooo0_l00005ooooo`;o00000oooool2o`0000?ooooo0_l00020oooo
o`;o00006_ooool2o`0000;ooooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`0dooooo`;o
00003oooool2o`0000?ooooo0_l0000iooooo`;o0000TOooool2o`0001Cooooo0_l00004ooooo`;o
00000_ooool2o`0000gooooo000Nooooo`;o0000=Oooool2o`0000oooooo0_l00007ooooo`;o0000
@?ooool2o`0008Kooooo0_l0000Dooooo`;o00002Oooool2o`0000cooooo000Nooooo`03o`000?oo
oooooooo02Kooooo0_l00004ooooo`;o00003oooool4o`0000gooooo0_l00010ooooo`;o0000ROoo
ool2o`0000oooooo0_l0000;ooooo`;o00003?ooool001kooooo00?o0000ooooooooool09_ooool2
o`0000Cooooo0_l0000?ooooo`Co0000`Oooool2o`0001Oooooo0_l0000?ooooo`;o00006Oooool0
01kooooo00?o0000ooooooooool0?Oooool2o`0000Kooooo0_l0002kooooo`;o0000@oooool001ko
oooo00?o0000ooooooooool0?Oooool2o`0000Kooooo0_l0003oooooo`7ooooo000Nooooo`03o`00
0?oooooooooo01_ooooo0_l0000Dooooo`;o00007_ooool2o`0001_ooooo0_l0000Gooooo`;o0000
O_ooool2o`0003kooooo000Nooooo`03o`000?oooooooooo01_ooooo0_l0000Dooooo`;o00007_oo
ool2o`0001_ooooo0_l0000Gooooo`;o0000@?ooool2o`0003cooooo0_l0000Pooooo`;o00007?oo
ool001kooooo00?o0000ooooooooool0T?ooool2o`0000Sooooo0_l0000]ooooo`;o0000G_ooool2
o`0000Gooooo0_l0000Eooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o0000H?ooool2o`00
00?ooooo0_l0000<ooooo`;o00002oooool4o`0000Kooooo0_l0000Oooooo`;o00005_ooool2o`00
05_ooooo0_l0000Eooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o0000;?ooool2o`0003;o
oooo0_l00003ooooo`;o00003?ooool2o`0000_ooooo1?l0000Wooooo`;o00005_ooool2o`0001So
oooo0_l0001Hooooo`007_ooool00ol0003oooooooooo`0[ooooo`;o00002oooool2o`0000;ooooo
0_l0000Xooooo`;o0000QOooool2o`0003Cooooo0_l0000Rooooo`007_ooool00ol0003ooooooooo
o`0[ooooo`;o00000oooool2o`0000Kooooo0_l0000=ooooo`;o00007Oooool2o`000;_ooooo0_l0
0005ooooo`;o00006oooool001kooooo00?o0000ooooooooool0<?ooool2o`0001Gooooo0_l00009
ooooo`;o0000<oooool2o`0006Wooooo0_l0000fooooo`;o00006oooool001kooooo00?o0000oooo
ooooool0D_ooool2o`0003?ooooo0_l0000Fooooo`;o00008_ooool2o`0002gooooo0_l0001Coooo
o`007_ooool00ol0003oooooooooo`2Oooooo`;o00008_ooool2o`0008;ooooo000Nooooo`03o`00
0?oooooooooo05gooooo0_l0000Hooooo`;o00001?ooool2o`0000oooooo0_l0000gooooo`;o0000
=_ooool2o`0004Kooooo000Nooooo`;o00007_ooool2o`0003kooooo0_l0000Hooooo`;o00001?oo
ool2o`0000oooooo0_l00004ooooo`;o0000<Oooool2o`0000Oooooo0_l0000Pooooo`;o00002ooo
ool2o`00027ooooo0_l0000Sooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o00005?ooool2
o`0000Sooooo0_l0001Eooooo`;o0000>_ooool2o`00017ooooo0_l0000=ooooo`;o0000;_ooool2
o`0000?ooooo0_l0000Nooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o00005?ooool3o`00
00Oooooo0_l0002Tooooo`;o0000@_ooool2o`0001kooooo000Nooooo`03o`000?oooooooooo01go
oooo0_l0000Eooooo`;o0000dOooool2o`0002[ooooo0_l0000Booooo`007_ooool00ol0003ooooo
ooooo`1oooooo`;o00001_ooool2o`0007kooooo0_l0000:ooooo`;o00007_ooool2o`0001;ooooo
000Nooooo`?o00009_ooool2o`0005Oooooo0_l00006ooooo`?o0000ROooool2o`0000Oooooo0_l0
00000ooooooo0000o`00000Vooooo`007_ooool3o`0002Kooooo0_l0000`ooooo`;o00006oooool2
o`00017ooooo0_l0002Booooo`;o000000?oooooo`000?l000009_ooool001kooooo00?o0000oooo
ooooool0>?ooool2o`0000Gooooo0_l0000Gooooo`;o00006oooool2o`000=3ooooo000Nooooo`03
o`000?oooooooooo03Sooooo0_l00005ooooo`;o0000:?ooool2o`000=cooooo000Nooooo`03o`00
0?oooooooooo06Wooooo0_l0000]ooooo`;o00002?ooool2o`000:?ooooo000Nooooo`03o`000?oo
oooooooo09Sooooo0_l00006ooooo`Co0000POooool2o`00023ooooo000Nooooo`03o`000?oooooo
oooo02Gooooo0_l0000?ooooo`;o0000A?ooool2o`0000Cooooo0_l0000Looooo`;o0000Poooool2
o`0001Cooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0Uooooo`;o00003oooool2o`00
02;ooooo0_l0000Pooooo`;o00001?ooool2o`000:Cooooo0_l0000Aooooo`;o00002_ooool001ko
oooo00?o0000ooooooooool0F_ooool2o`0003?ooooo0_l0002;ooooo`;o00002_ooool2o`0001go
oooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0
003o410@olc<c006ooooo`03o`000?oooooooooo08oooooo0_l0000>ooooo`;o0000Noooool2o`00
02Wooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMg
MoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo097ooooo0_l0000<ooooo`;o0000O_ooool2
o`0002Kooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooo
oooo000000Kooooo0ol0000Zooooo`;o0000IOooool2o`0001Kooooo0_l0001dooooo`;o00009_oo
ool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40
1_ooool00ol0003oooooooooo`0Zooooo`;o00006?ooool2o`00013ooooo0_l0000Oooooo`;o0000
3?ooool2o`0002;ooooo0_l0002Looooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo
00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo03Sooooo0_l000000ooooooo
0000o`000007ooooo`;o00004?ooool2o`0001oooooo0_l0000<ooooo`;o00009Oooool2o`00077o
oooo0_l0000Hooooo`;o00003?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03
oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool05_ooool2o`0001Sooooo0_l00006ooooo`;o
000000Coooooo`000?l0003ooooo0_l0000<ooooo`;o00007_ooool2o`0003kooooo0_l0001?oooo
o`;o00005Oooool2o`0000Wooooo0_l0000Hooooo`;o00003?ooool000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool05_ooool2o`00
01Sooooo0_l000000ooooooo0000o`000009ooooo`;o00003?ooool2o`0001kooooo0_l0000ooooo
o`;o0000C_ooool2o`0001Gooooo0_l0000aooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`0cooooo`;o000000?ooooo
o`000?l000006oooool2o`0001_ooooo0_l00007ooooo`;o00005Oooool2o`0001Wooooo1?l00017
ooooo`;o0000Coooool001kooooo00?o0000ooooooooool06_ooool2o`0001[ooooo0_l0000Koooo
o`;o00006?ooool2o`000003ooooool0003o000000Oooooo0_l0000Booooo`;o000000?oooooo`00
0?l000006Oooool2o`0004Wooooo0_l00008ooooo`;o0000AOooool001kooooo00?o0000oooooooo
ool06_ooool2o`00057ooooo0_l00008ooooo`;o00001oooool2o`0000_ooooo0ol0001`ooooo`;o
00005Oooool2o`0000_ooooo0_l00005ooooo`;o00006_ooool001kooooo00?o0000ooooooooool0
G?ooool2o`0001Wooooo0_l00007ooooo`;o00003?ooool2o`0001cooooo0_l0001Nooooo`;o0000
2Oooool2o`0000_ooooo0_l00005ooooo`;o00006_ooool001kooooo00?o0000ooooooooool0BOoo
ool2o`00017ooooo0_l0000fooooo`;o00005_ooool2o`0005kooooo0_l0000iooooo`007_ooool0
0ol0003oooooooooo`19ooooo`;o0000BOooool2o`0001Kooooo0_l0001mooooo`;o00002Oooool2
o`0000oooooo000Nooooo`03o`000?oooooooooo09Sooooo0_l0000Booooo`;o00001?ooool2o`00
037ooooo0_l0000Sooooo`;o00007oooool2o`0000Wooooo0_l0000?ooooo`007_ooool00ol0003o
ooooooooo`15ooooo`;o0000DOooool2o`0001Sooooo0_l0000aooooo`;o00008oooool2o`0003_o
oooo000Nooooo`03o`000?oooooooooo04Gooooo0_l00018ooooo`;o0000;_ooool2o`0008Kooooo
000Nooooo`03o`000?oooooooooo08oooooo0_l0000^ooooo`;o00002Oooool2o`0003Cooooo0_l0
000Cooooo`;o0000:Oooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo04cooooo0_l0000M
ooooo`;o00002Oooool2o`0005;ooooo0_l0000dooooo`;o00004oooool2o`00023ooooo0_l00007
ooooo`;o00001Oooool001kooooo00?o0000ooooooooool0@oooool2o`0000Oooooo0_l0000Moooo
o`;o00002Oooool2o`0004?ooooo0_l0001jooooo`;o00003_ooool001kooooo0_l00014ooooo`;o
0000>?ooool2o`0003cooooo0_l0002:ooooo`007_ooool00ol0003oooooooooo`0fooooo`;o0000
2_ooool2o`0003Wooooo0_l0000Aooooo`;o00002?ooool2o`0000;ooooo0_l00011ooooo`;o0000
I?ooool001kooooo00?o0000ooooooooool0:_ooool2o`0000?ooooo0_l00005ooooo`Co00002?oo
ool2o`0004cooooo0_l00008ooooo`;o00000_ooool2o`00047ooooo0_l0001Tooooo`007_ooool0
0ol0003oooooooooo`0Kooooo`;o00003Oooool2o`0000?ooooo0_l00007ooooo`;o00000_ooool2
o`00077ooooo0_l0000=ooooo`;o00001Oooool2o`0000cooooo0_l0001booooo`007_ooool00ol0
003oooooooooo`08ooooo`;o00004Oooool2o`0001oooooo0_l0001<ooooo`;o00008oooool2o`00
00gooooo0_l00005ooooo`;o00003?ooool2o`0007;ooooo000Nooooo`03o`000?oooooooooo00So
oooo0_l0000Cooooo`;o0000Joooool2o`0004Wooooo0_l0001`ooooo`007_ooool00ol0003ooooo
ooooo`0Mooooo`;o0000J?ooool2o`0004cooooo0_l0000Booooo`;o00000oooool2o`0001oooooo
0_l0000Xooooo`;o00003?ooool001kooooo00?o0000ooooooooool0M_ooool2o`0000oooooo0_l0
000Oooooo`;o00007Oooool2o`00023ooooo0_l00003ooooo`;o00007oooool2o`0002Sooooo0_l0
000<ooooo`007_ooool00ol0003oooooooooo`0booooo`;o000000?oooooo`000?l00000?oooool2
o`00033ooooo0_l0000Mooooo`;o0000O_ooool001kooooo00?o0000ooooooooool0:_ooool2o`00
00Kooooo0_l000000ooooooo0000o`00001Hooooo`;o0000]_ooool001kooooo00?o0000oooooooo
ool0:?ooool4o`0000;ooooo0_l0000Dooooo`;o00000oooool2o`0004Cooooo0_l0000dooooo`;o
00000oooool2o`0002kooooo0_l0001;ooooo`007_ooool00ol0003oooooooooo`0Xooooo`;o0000
1?ooool2o`0000_ooooo0_l00007ooooo`;o00000oooool2o`0001?ooooo0_l0001Iooooo`;o0000
2_ooool2o`0000?ooooo0_l0000^ooooo`;o00009Oooool2o`0002Cooooo000Nooooo`03o`000?oo
oooooooo033ooooo0_l00009ooooo`;o00008Oooool2o`0002_ooooo0_l0000/ooooo`;o0000I_oo
ool2o`0002Cooooo000Nooooo`03o`000?oooooooooo033ooooo0_l0000^ooooo`;o00001Oooool2
o`0002;ooooo0_l0001[ooooo`;o0000COooool001kooooo00?o0000ooooooooool0H?ooool2o`00
00Gooooo0_l00026ooooo`;o00001oooool2o`0004gooooo000Nooooo`03o`000?oooooooooo00go
oooo0_l0000Cooooo`;o0000`Oooool2o`0000Sooooo0_l0001Fooooo`007_ooool2o`0000kooooo
0_l0000Cooooo`;o00004?ooool2o`0000Gooooo0_l0002Xooooo`;o0000H?ooool001kooooo00?o
0000ooooooooool0=?ooool2o`0000Gooooo0_l0000aooooo`;o0000A_ooool2o`0000;ooooo0_l0
001Jooooo`;o00003Oooool2o`00023ooooo000Nooooo`03o`000?oooooooooo06Oooooo0_l00005
ooooo`;o0000A_ooool2o`0000;ooooo0_l0001Jooooo`;o00003Oooool2o`0000cooooo0_l0000B
ooooo`007_ooool00ol0003oooooooooo`0iooooo`;o0000;?ooool2o`000:Cooooo0_l0000Toooo
o`;o00004_ooool001kooooo00?o0000ooooooooool0>Oooool2o`0007oooooo0_l0001Aooooo`;o
0000>?ooool001kooooo00?o0000ooooooooool01_ooool2o`0001Gooooo0_l0001/ooooo`;o0000
;Oooool2o`0008_ooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l0000Eooooo`;o00002ooo
ool2o`0001;ooooo0_l00008ooooo`;o0000@Oooool2o`0004oooooo0_l00011ooooo`;o00009_oo
ool001kooooo00?o0000ooooooooool08oooool2o`0000Gooooo0_l0000Booooo`;o00002?ooool2
o`0009;ooooo0_l00011ooooo`;o00009_ooool001kooooo00?o0000ooooooooool08oooool2o`00
09?ooooo0_l0002=ooooo`007_ooool00ol0003oooooooooo`1hooooo`;o0000?_ooool2o`0008go
oooo000Nooooo`03o`000?oooooooooo07Sooooo0_l0003=ooooo`007_ooool00ol0003ooooooooo
o`0booooo`;o0000ooooool3ooooo`;o00003oooool001kooooo00?o0000ooooooooool0<_ooool2
o`0002Wooooo0_l0000Dooooo`;o00002_ooool2o`00023ooooo0_l0002Cooooo`;o00003oooool0
01kooooo00?o0000ooooooooool0GOooool2o`0001Cooooo0_l0000:ooooo`;o00008?ooool2o`00
017ooooo0_l0002Aooooo`007_ooool00ol0003oooooooooo`2Xooooo`;o00002_ooool2o`00097o
oooo000Nooooo`;o00009_ooool2o`0000;ooooo0_l0000<ooooo`;o0000Koooool2o`0001;ooooo
0_l0000Hooooo`;o00007_ooool2o`0000;ooooo0_l0000nooooo`;o00002oooool001kooooo0_l0
000Iooooo`Co00002Oooool2o`0000;ooooo0_l0000<ooooo`;o00005Oooool2o`0000_ooooo0_l0
0011ooooo`;o00007?ooool2o`0001Sooooo0_l0000Nooooo`;o00000_ooool2o`0003kooooo0_l0
000;ooooo`007_ooool00ol0003oooooooooo`0Hooooo`Co0000<_ooool2o`0000_ooooo0_l00011
ooooo`;o00002Oooool2o`0007_ooooo0_l0000Oooooo`007_ooool00ol0003oooooooooo`1;oooo
o`;o00001_ooool2o`0001Gooooo0_l0000^ooooo`;o00003Oooool2o`0006gooooo0_l0000<oooo
o`;o00003_ooool2o`0000oooooo000Nooooo`03o`000?oooooooooo04_ooooo0_l00006ooooo`;o
00005Oooool2o`0002kooooo0_l00006ooooo`;o0000>_ooool2o`0003Sooooo0_l0000Looooo`;o
00003oooool001kooooo00?o0000ooooooooool06Oooool2o`0004_ooooo0_l0000jooooo`;o0000
>_ooool2o`0004cooooo0_l0000Iooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o0000Booo
ool2o`0000cooooo0_l0002fooooo`;o00006Oooool001kooooo00?o0000ooooooooool0M?ooool2
o`0002Kooooo0_l0000oooooo`;o0000COooool2o`0001Wooooo000Nooooo`03o`000?oooooooooo
05Gooooo0_l00015ooooo`;o0000?oooool2o`0000Sooooo0_l00013ooooo`;o00006Oooool001ko
oooo00?o0000ooooooooool09Oooool2o`0000[ooooo0_l00005ooooo`;o00006oooool2o`00093o
oooo0_l0001Nooooo`007_ooool00ol0003oooooooooo`0Uooooo`;o00002_ooool2o`0000Gooooo
0_l0003cooooo`;o00006?ooool001kooooo00?o0000ooooooooool0@Oooool2o`0005cooooo0_l0
002<ooooo`;o00006?ooool001kooooo00?o0000ooooooooool0@Oooool2o`0002;ooooo0_l0000h
ooooo`;o00002_ooool2o`0009[ooooo000Nooooo`03o`000?oooooooooo03;ooooo0_l0000aoooo
o`;o0000A?ooool2o`0009[ooooo000Nooooo`03o`000?oooooooooo03;ooooo0_l0000Rooooo`;o
0000koooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co
8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool09?ooool2o`00033ooooo0_l0000Zoooo
o`;o0000<oooool2o`00067ooooo0_l0000[ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0J
ooooo`;o00002?ooool2o`0001Kooooo0_l00014ooooo`;o00003?ooool2o`0002Gooooo0_l0001Q
ooooo`;o0000:oooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooo
ooooooooool000001_ooool3o`0000_ooooo0_l0000=ooooo`?o00007oooool2o`0005;ooooo0_l0
002eooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RH
oc8b<P06ooooo`03o`000?oooooooooo00_ooooo1?l0000<ooooo`;o0000Loooool2o`000;Gooooo
0003ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Ko
oooo00?o0000ooooooooool03Oooool2o`0000Sooooo0_l0002Fooooo`;o0000U_ooool000?ooooo
00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0
003oooooooooo`0=ooooo`;o00002?ooool2o`0000gooooo0_l00027ooooo`;o0000<_ooool2o`00
00?ooooo0_l0000Rooooo`?o0000>?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`0Vooooo`;o00005_ooool2
o`0001Cooooo0_l000000ooooooo0000o`00002:ooooo`;o00000oooool2o`0002;ooooo0ol0000h
ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVY
Z@06ooooo`03o`000?oooooooooo03Cooooo0_l00008ooooo`;o00005?ooool2o`000004ooooool0
003o0000o`0001Gooooo0_l0000Jooooo`;o0000^_ooool001kooooo00?o0000ooooooooool0:Ooo
ool2o`0000Wooooo0_l0000Rooooo`;o00005Oooool2o`0001[ooooo0_l0001Iooooo`;o0000Gooo
ool001kooooo00?o0000ooooooooool06_ooool2o`0000gooooo0_l0002kooooo`;o0000Goooool0
01kooooo00?o0000ooooooooool06_ooool2o`0003Sooooo0_l0000Jooooo`;o0000<oooool2o`00
02Cooooo0_l0001jooooo`007_ooool00ol0003oooooooooo`1Dooooo`;o00000oooool2o`0001Go
oooo0_l0000cooooo`;o00009?ooool2o`0006Sooooo0_l00002ooooo`;o00003?ooool001kooooo
00?o0000ooooooooool0FOooool2o`0001[ooooo0_l0002nooooo`;o00000_ooool2o`0000cooooo
000Nooooo`03o`000?oooooooooo07Gooooo0_l0000Zooooo`;o0000Y?ooool001kooooo00?o0000
ooooooooool09_ooool4o`0001;ooooo0_l0001Sooooo`Co0000X_ooool001kooooo00?o0000oooo
ooooool09_ooool4o`0001;ooooo0_l0000@ooooo`;o00008oooool2o`0002kooooo0_l00027oooo
o`;o00006Oooool001kooooo00?o0000ooooooooool0C_ooool2o`0002?ooooo0_l0001>ooooo`;o
00004_ooool2o`0003Kooooo0_l0000Kooooo`;o00006Oooool001kooooo00?o0000ooooooooool0
1oooool2o`0001cooooo0_l00004ooooo`;o0000U_ooool2o`0001;ooooo0_l0000fooooo`;o0000
=_ooool001kooooo00?o0000ooooooooool00oooool2o`000004ooooool0003o0000o`0000Cooooo
0_l0000Booooo`;o00000_ooool2o`0000;ooooo1?l0000aooooo`;o0000??ooool2o`0006Wooooo
0_l0000nooooo`007_ooool2o`0000Cooooo0_l000000ooooooo0000o`000005ooooo`;o00004_oo
ool2o`0000Kooooo0_l0000cooooo`;o0000??ooool2o`0003Gooooo0_l0000booooo`;o0000?_oo
ool001kooooo00?o0000ooooooooool07_ooool2o`0001?ooooo0_l00005ooooo`;o0000Uoooool2
o`0005Kooooo0_l00002ooooo`;o00005_ooool001kooooo00?o0000ooooooooool06?ooool2o`00
0004ooooool0003o0000ooooo`;o00004oooool2o`0000Gooooo0_l0003_ooooo`;o00000_ooool2
o`0001Kooooo000Nooooo`?o00006?ooool2o`000003ooooool0003o000003[ooooo0_l0001joooo
o`;o0000@?ooool2o`00033ooooo000Nooooo`?o00001Oooool2o`00053ooooo0_l0001Fooooo`;o
00008_ooool2o`00043ooooo0_l0000`ooooo`007_ooool00ol0003oooooooooo`05ooooo`;o0000
8oooool2o`00027ooooo0_l0001Pooooo`;o0000@Oooool2o`0005?ooooo000Nooooo`03o`000?oo
oooooooo02[ooooo0_l0000;ooooo`;o00005?ooool2o`0003;ooooo0_l00012ooooo`;o00002ooo
ool2o`0001kooooo0_l0001Cooooo`007_ooool00ol0003oooooooooo`0gooooo`;o0000B?ooool2
o`0003Cooooo0_l0000<ooooo`;o00002oooool2o`0007?ooooo000Nooooo`03o`000?oooooooooo
08cooooo0_l0000Dooooo`;o000000?oooooo`000?l000002_ooool2o`0000Cooooo0_l0001Aoooo
o`;o0000>oooool001kooooo00?o0000ooooooooool0S?ooool2o`0001Cooooo0_l000000ooooooo
0000o`00000:ooooo`;o0000Eoooool2o`0002?ooooo0_l0000Fooooo`007_ooool00ol0003ooooo
ooooo`11ooooo`;o000000?oooooo`000?l000002?ooool2o`0000;ooooo0_l0003:ooooo`;o0000
3oooool2o`0000?ooooo0_l0000Aooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o0000=Ooo
ool2o`000003ooooool0003o000000Sooooo0_l00002ooooo`;o00004_ooool2o`0000oooooo0_l0
001Wooooo`;o00007_ooool2o`0001cooooo0_l0000Dooooo`;o00004Oooool001kooooo00?o0000
ooooooooool01oooool2o`000003ooooool0003o000003Sooooo0_l00009ooooo`;o00005Oooool2
o`0000oooooo0_l0001Wooooo`;o00007_ooool2o`0001Gooooo0_l0000Cooooo`;o00006Oooool0
01kooooo00?o0000ooooooooool01oooool2o`0004Kooooo0_l00006ooooo`;o00004oooool2o`00
00gooooo0_l0002Jooooo`;o00002Oooool2o`0000Sooooo0_l0000Iooooo`007_ooool00ol0003o
ooooooooo`1:ooooo`;o00002oooool2o`0001?ooooo0_l0000=ooooo`;o0000@_ooool2o`00067o
oooo0_l0000Sooooo`007_ooool00ol0003oooooooooo`1:ooooo`;o00005?ooool2o`0005gooooo
0_l00026ooooo`007_ooool2o`0001Sooooo0_l00017ooooo`;o00000oooool2o`000=Gooooo0_l0
0009ooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o00008_ooool2o`00013ooooo0_l0000:
ooooo`;o00002_ooool2o`000<[ooooo1?l00007ooooo`;o00002Oooool001kooooo00?o0000oooo
ooooool0>oooool2o`00013ooooo0_l0000:ooooo`;o0000:?ooool2o`0001kooooo0_l0002<oooo
o`Co00004_ooool001kooooo00?o0000ooooooooool0J?ooool2o`0001Wooooo0_l0000Nooooo`;o
0000Qoooool2o`0001Wooooo000Nooooo`03o`000?oooooooooo05Sooooo0_l0000>ooooo`;o0000
`_ooool2o`0001Wooooo000Nooooo`03o`000?oooooooooo00cooooo0_l0000eooooo`;o00004ooo
ool2o`000;kooooo0_l0000]ooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o00000oooool2
o`00017ooooo0_l00009ooooo`;o00004_ooool2o`0000kooooo0_l00033ooooo`;o0000;Oooool0
01kooooo00?o0000ooooooooool04Oooool2o`00017ooooo0_l00005ooooo`;o00000_ooool2o`00
017ooooo0_l0000?ooooo`;o0000l_ooool001kooooo00?o0000ooooooooool0:oooool2o`0000co
oooo0_l00007ooooo`;o0000Roooool2o`0006Wooooo0_l0000;ooooo`007_ooool00ol0003ooooo
ooooo`0Vooooo`;o00002_ooool2o`0000Gooooo0_l0001Qooooo`;o00008oooool2o`0000cooooo
0_l0001Yooooo`;o00002oooool001kooooo00?o0000ooooooooool04?ooool2o`000003ooooool0
003o0000017ooooo0_l0000:ooooo`;o0000Hoooool2o`0000?ooooo0_l0000Sooooo`;o00009?oo
ool2o`0002cooooo0_l0000`ooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o000000?ooooo
o`000?l00000Noooool2o`0000Gooooo0_l0001>ooooo`;o0000;?ooool2o`0000Kooooo0_l0000X
ooooo`007_ooool00ol0003oooooooooo`0Rooooo`;o00004?ooool2o`0000gooooo0_l0000>oooo
o`;o00009?ooool2o`0001Gooooo0_l0002;ooooo`?o00009oooool001kooooo00?o0000oooooooo
ool08_ooool2o`00013ooooo0_l0000=ooooo`;o00003_ooool2o`0002Cooooo0_l0000oooooo`;o
0000H_ooool2o`0002Oooooo000Nooooo`03o`000?oooooooooo06_ooooo0_l0000iooooo`;o0000
4_ooool2o`0008_ooooo000Nooooo`03o`000?oooooooooo06_ooooo0_l0000dooooo`;o00000ooo
ool2o`0000oooooo0_l0000Mooooo`;o0000Koooool001kooooo0_l0000oooooo`;o0000=Oooool2
o`0000?ooooo0_l0000Uooooo`;o00005?ooool2o`0001gooooo0_l0001_ooooo`007_ooool00ol0
003oooooooooo`05ooooo`;o0000=oooool2o`0003Gooooo0_l00003ooooo`;o00003Oooool2o`00
09Sooooo0_l0000Rooooo`007_ooool00ol0003oooooooooo`05ooooo`;o000000?oooooo`000?l0
0000Ooooool2o`0005?ooooo0_l00013ooooo`;o00008_ooool001kooooo00?o0000ooooooooool0
2?ooool2o`00063ooooo0_l0001booooo`;o0000Ioooool001kooooo00?o0000ooooooooool0?Ooo
ool2o`0002_ooooo0_l0000Yooooo`;o0000/?ooool001kooooo00?o0000ooooooooool0?Oooool2
o`0005Kooooo0_l0000Tooooo`;o0000R_ooool001kooooo00?o0000ooooooooool0LOooool2o`00
04Sooooo0_l0001Booooo`;o0000=_ooool001kooooo00?o0000ooooooooool0Goooool4o`0000Co
oooo0_l00008ooooo`;o00006oooool2o`0004Gooooo0_l0000hooooo`;o0000=_ooool001kooooo
00?o0000ooooooooool0Goooool4o`0000Cooooo0_l0000Uooooo`;o0000@?ooool2o`0000?ooooo
0_l0001`ooooo`007_ooool00ol0003oooooooooo`0^ooooo`;o0000X?ooool2o`0003Kooooo0_l0
000`ooooo`;o00001Oooool2o`0000Cooooo000Nooooo`03o`000?oooooooooo02kooooo0_l0000j
ooooo`;o00009?ooool2o`0003Gooooo0_l0000oooooo`;o0000<?ooool2o`0000Gooooo0_l00004
ooooo`007_ooool00ol0003oooooooooo`1Zooooo`;o00009?ooool2o`0000Sooooo0_l0000[oooo
o`;o0000O_ooool001kooooo00?o0000ooooooooool0=?ooool2o`0002Cooooo0_l0000Iooooo`;o
00008oooool2o`0001?ooooo0_l0001looooo`;o00006?ooool001kooooo00?o0000ooooooooool0
=?ooool2o`0002Cooooo0_l0000Iooooo`;o0000>?ooool2o`0006Kooooo0_l00002ooooo`;o0000
2oooool2o`0000?ooooo0_l0000Hooooo`005?ooool4o`000003oa0@4?oooooooooo00?ooooo00?o
0000ooooooooool02Oooool2o`00017ooooo0_l0000;ooooo`;o0000k?ooool2o`0000;ooooo0_l0
000;ooooo`;o00007Oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09
ooooo`;o00004Oooool2o`0000_ooooo0_l0000cooooo`;o0000DOooool2o`0003Cooooo0_l0001N
ooooo`005_ooool00ol0003oooooooooo`05ooooo`?o0000G_ooool2o`000003ooooool0003o0000
01?ooooo0_l0000iooooo`;o0000=?ooool2o`0000Wooooo0_l0001;ooooo`;o00001_ooool001Ko
oooo00?o0000ooooooooool0JOooool2o`0001?ooooo0_l0001jooooo`;o0000Boooool2o`0000Ko
oooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooo
oom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Dooooo`03oeEEEOmVIVKo0000
0?ooooooD_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.15431 .68531 Mdot
.83892 .42499 Mdot
.15454 .50937 Mdot
.08539 .02248 Mdot
.34976 .43547 Mdot
.2581 .03087 Mdot
.60439 .03691 Mdot
.25082 .47241 Mdot
.30039 .97001 Mdot
.76428 .02908 Mdot
.32529 .19834 Mdot
.43567 .09345 Mdot
.23228 .53436 Mdot
.60457 .66204 Mdot
.17492 .02084 Mdot
.54118 .63278 Mdot
.77297 .61043 Mdot
.32748 .57307 Mdot
.17608 .60669 Mdot
.11705 .10989 Mdot
.84821 .61798 Mdot
.3212 .10336 Mdot
.44217 .4352 Mdot
.85926 .03674 Mdot
.24928 .88317 Mdot
.2186 .39972 Mdot
.14818 .83524 Mdot
.56304 .72448 Mdot
.34089 .20155 Mdot
.26716 .13521 Mdot
.22291 .5965 Mdot
.18955 .00947 Mdot
.35837 .99246 Mdot
.88572 .92031 Mdot
.9296 .55063 Mdot
.054 .88731 Mdot
.61002 .67267 Mdot
.83293 .51186 Mdot
.49323 .83348 Mdot
.1979 .79542 Mdot
.20171 .60049 Mdot
.98221 .64252 Mdot
.00875 .99618 Mdot
.80014 .60416 Mdot
.53886 .04001 Mdot
.97501 .70535 Mdot
.64653 .45737 Mdot
.98291 .82893 Mdot
.07422 .8055 Mdot
.15077 .30414 Mdot
.43351 .97568 Mdot
.95111 .50116 Mdot
.27733 .3703 Mdot
.04353 .85192 Mdot
.30553 .3643 Mdot
.22074 .23153 Mdot
.76137 .30468 Mdot
.25669 .51547 Mdot
.13986 .84371 Mdot
.31957 .68802 Mdot
.11918 .0434 Mdot
.23557 .44097 Mdot
.59298 .0948 Mdot
.27667 .91512 Mdot
.28176 .75048 Mdot
.31416 .05526 Mdot
.01935 .40139 Mdot
.14262 .83424 Mdot
.24164 .05651 Mdot
.82211 .31155 Mdot
.14788 .22556 Mdot
.43148 .61259 Mdot
.06566 .16029 Mdot
.25823 .21524 Mdot
.39989 .06938 Mdot
.97062 .29696 Mdot
.15568 .34266 Mdot
.63861 .22177 Mdot
.16727 .91566 Mdot
.49691 .40369 Mdot
.96485 .85843 Mdot
.68841 .09612 Mdot
.80946 .61189 Mdot
.2389 .46791 Mdot
.75762 .44016 Mdot
.01131 .22133 Mdot
.28546 .41094 Mdot
.08213 .91525 Mdot
.21114 .03836 Mdot
.36336 .66743 Mdot
.08258 .12264 Mdot
.85133 .27713 Mdot
.16384 .29419 Mdot
.16292 .21133 Mdot
.33053 .64166 Mdot
.95295 .76451 Mdot
.60242 .17429 Mdot
.93859 .53374 Mdot
.27213 .81763 Mdot
.90605 .59141 Mdot
.15337 .74812 Mdot
.43984 .93788 Mdot
.11415 .61906 Mdot
.5839 .64165 Mdot
.91766 .33042 Mdot
.4384 .44229 Mdot
.51188 .67076 Mdot
.53435 .65972 Mdot
.96909 .4962 Mdot
.65261 .13272 Mdot
.60609 .68083 Mdot
.81704 .50227 Mdot
.49131 .95175 Mdot
.28158 .58376 Mdot
.44435 .32696 Mdot
.64375 .98554 Mdot
.52976 .0102 Mdot
.20693 .52901 Mdot
.04143 .30298 Mdot
.56161 .87679 Mdot
.1117 .82029 Mdot
.98387 .73636 Mdot
.39107 .1185 Mdot
.16665 .21408 Mdot
.88455 .19761 Mdot
.87309 .60191 Mdot
.36073 .89032 Mdot
.19118 .65701 Mdot
.88426 .89074 Mdot
.01747 .12886 Mdot
.86713 .55778 Mdot
.36737 .26388 Mdot
.78517 .74523 Mdot
.41057 .54054 Mdot
.33458 .60567 Mdot
.29091 .33641 Mdot
.42469 .43422 Mdot
.42589 .68072 Mdot
.12443 .55252 Mdot
.29456 .02452 Mdot
.21568 .65262 Mdot
.27666 .9065 Mdot
.35883 .07849 Mdot
.94267 .61787 Mdot
.58406 .326 Mdot
.42447 .09095 Mdot
.23117 .71928 Mdot
.17231 .77299 Mdot
.77075 .28984 Mdot
.66398 .09174 Mdot
.68888 .75786 Mdot
.36574 .03975 Mdot
.45667 .09591 Mdot
.12568 .12329 Mdot
.15033 .98721 Mdot
.20975 .50635 Mdot
.4691 .64982 Mdot
.73549 .38253 Mdot
.26502 .93776 Mdot
.52317 .63024 Mdot
.45049 .62332 Mdot
.91171 .54935 Mdot
.80721 .89126 Mdot
.43666 .53036 Mdot
.267 .79288 Mdot
.35489 .40655 Mdot
.18758 .77531 Mdot
.21504 .88183 Mdot
.64582 .11863 Mdot
.42564 .49611 Mdot
.37114 .14637 Mdot
.95138 .85785 Mdot
.91444 .53226 Mdot
.04221 .28763 Mdot
.16002 .66004 Mdot
.47751 .76474 Mdot
.84013 .88124 Mdot
.17521 .41012 Mdot
.61687 .09774 Mdot
.94337 .50732 Mdot
.01564 .97482 Mdot
.40509 .02861 Mdot
.53641 .80638 Mdot
.5225 .15633 Mdot
.69025 .25759 Mdot
.4949 .87969 Mdot
.52151 .62302 Mdot
.05211 .09026 Mdot
.76949 .74373 Mdot
.92876 .70153 Mdot
.17196 .65808 Mdot
.98635 .2061 Mdot
.18416 .67386 Mdot
.49707 .18268 Mdot
.54252 .87992 Mdot
.01879 .02277 Mdot
.92299 .57683 Mdot
.41162 .13968 Mdot
.30622 .97007 Mdot
.38696 .05747 Mdot
.5351 .20557 Mdot
.49596 .34481 Mdot
.39117 .56225 Mdot
.53639 .12595 Mdot
.25176 .88787 Mdot
.07973 .92787 Mdot
.65345 .04688 Mdot
.10147 .89753 Mdot
.79158 .40554 Mdot
.57476 .746 Mdot
.41334 .46825 Mdot
.198 .68356 Mdot
.90366 .22591 Mdot
.66408 .32825 Mdot
.43941 .65038 Mdot
.12885 .21484 Mdot
.2124 .78012 Mdot
.10292 .28058 Mdot
.49632 .75543 Mdot
.05689 .37431 Mdot
.75927 .32205 Mdot
.37555 .61043 Mdot
.27325 .89229 Mdot
.21925 .91961 Mdot
.36475 .64106 Mdot
.48351 .58091 Mdot
.95191 .98661 Mdot
.3989 .37683 Mdot
.69873 .19502 Mdot
.34998 .07304 Mdot
.19646 .463 Mdot
.31702 .70476 Mdot
.37428 .08587 Mdot
.97825 .09141 Mdot
.12724 .21234 Mdot
.73619 .17008 Mdot
.70897 .5484 Mdot
.21291 .56932 Mdot
.83162 .55422 Mdot
.76436 .21846 Mdot
.15527 .38178 Mdot
.37562 .11174 Mdot
.99626 .9253 Mdot
.10767 .42854 Mdot
.505 .82369 Mdot
.14284 .33954 Mdot
.40778 .59921 Mdot
.34844 .14608 Mdot
.71003 .07738 Mdot
.19034 .58104 Mdot
.95354 .4876 Mdot
.35815 .38619 Mdot
.82276 .13631 Mdot
.01553 .23056 Mdot
.87943 .19071 Mdot
.99709 .82889 Mdot
.30715 .38364 Mdot
.86105 .48405 Mdot
.93342 .75231 Mdot
.44567 .32532 Mdot
.18073 .70144 Mdot
.28861 .73957 Mdot
.23754 .22502 Mdot
.93955 .37021 Mdot
.37377 .09364 Mdot
.95787 .12904 Mdot
.47561 .93284 Mdot
.0314 .30005 Mdot
.20654 .55211 Mdot
.17763 .81324 Mdot
.26931 .81468 Mdot
.6769 .47858 Mdot
.16424 .082 Mdot
.3266 .75469 Mdot
.96481 .88063 Mdot
.39225 .40629 Mdot
.47237 .75456 Mdot
.46686 .25398 Mdot
.05145 .84969 Mdot
.4542 .96529 Mdot
.80054 .2775 Mdot
.3354 .11945 Mdot
.45322 .4978 Mdot
.62048 .64418 Mdot
.33788 .40296 Mdot
.27198 .89286 Mdot
.41235 .51943 Mdot
.88319 .49801 Mdot
.99948 .74852 Mdot
.34949 .22252 Mdot
.00321 .90186 Mdot
.8611 .27378 Mdot
.18203 .61037 Mdot
.49562 .14033 Mdot
.62219 .12892 Mdot
.89078 .50336 Mdot
.24554 .74986 Mdot
.51723 .61627 Mdot
.79977 .24321 Mdot
.69488 .1289 Mdot
.88141 .49586 Mdot
.31291 .89128 Mdot
.93241 .58084 Mdot
.43633 .5868 Mdot
.75249 .00975 Mdot
.98547 .45604 Mdot
.15783 .84282 Mdot
.13085 .93288 Mdot
.86935 .11933 Mdot
.48152 .3332 Mdot
.10483 .85686 Mdot
.79675 .22646 Mdot
.21697 .40575 Mdot
.41844 .34479 Mdot
.26463 .77549 Mdot
.02465 .7519 Mdot
.48791 .77965 Mdot
.04063 .28599 Mdot
.35812 .9562 Mdot
.92413 .34477 Mdot
.49918 .83621 Mdot
.36548 .02382 Mdot
.43978 .9866 Mdot
.5589 .79063 Mdot
.27118 .59744 Mdot
.19208 .47383 Mdot
.05368 .84779 Mdot
.1915 .70733 Mdot
.42819 .05832 Mdot
.20675 .45062 Mdot
.09238 .10838 Mdot
.27009 .05735 Mdot
.49512 .27585 Mdot
.86484 .07888 Mdot
.07281 .30827 Mdot
.25428 .27979 Mdot
.74624 .69269 Mdot
.14278 .80757 Mdot
.75701 .87223 Mdot
.94612 .10406 Mdot
.26357 .81609 Mdot
.74494 .66866 Mdot
.21956 .67861 Mdot
.44076 .59207 Mdot
.71112 .37949 Mdot
.59757 .54118 Mdot
.6458 .10383 Mdot
.36324 .26799 Mdot
.92357 .40308 Mdot
.25896 .47249 Mdot
.19559 .53398 Mdot
.32846 .38153 Mdot
.90671 .71667 Mdot
.56548 .68278 Mdot
.62372 .05879 Mdot
.1472 .06874 Mdot
.97973 .62841 Mdot
.43168 .54759 Mdot
.25825 .53639 Mdot
.12857 .27469 Mdot
.34921 .12986 Mdot
.8488 .81043 Mdot
.20872 .60267 Mdot
.41626 .46044 Mdot
.29556 .90093 Mdot
.88784 .75367 Mdot
.65291 .8653 Mdot
.72679 .66674 Mdot
.73959 .21378 Mdot
.26743 .11284 Mdot
.42411 .6572 Mdot
.17671 .85168 Mdot
.16764 .53477 Mdot
.32613 .04094 Mdot
.95274 .91249 Mdot
.89726 .58548 Mdot
.54668 .03346 Mdot
.0716 .84931 Mdot
.90015 .16727 Mdot
.29219 .15736 Mdot
.18285 .93328 Mdot
.06837 .03291 Mdot
.70281 .25365 Mdot
.87636 .18804 Mdot
.55099 .73932 Mdot
.51613 .13042 Mdot
.66455 .84692 Mdot
.65439 .5242 Mdot
.15005 .81635 Mdot
.62015 .68271 Mdot
.21979 .64524 Mdot
.33946 .51759 Mdot
.12365 .72021 Mdot
.30797 .47862 Mdot
.33481 .45301 Mdot
.43899 .28065 Mdot
.78593 .67904 Mdot
.93793 .15079 Mdot
.13022 .84661 Mdot
.2455 .60566 Mdot
.01009 .02834 Mdot
.56245 .95314 Mdot
.75484 .35679 Mdot
.2339 .44979 Mdot
.65773 .66557 Mdot
.92168 .95399 Mdot
.31203 .21976 Mdot
.38439 .6472 Mdot
.48015 .5444 Mdot
.43701 .52505 Mdot
.41506 .66505 Mdot
.23815 .89478 Mdot
.43795 .63517 Mdot
.61484 .99127 Mdot
.73513 .25989 Mdot
.38577 .54675 Mdot
.10099 .61071 Mdot
.47938 .59251 Mdot
.73749 .35496 Mdot
.1568 .91789 Mdot
.20101 .83408 Mdot
.60991 .40535 Mdot
.73373 .1638 Mdot
.35946 .52676 Mdot
.24719 .50326 Mdot
.76068 .54421 Mdot
.50528 .2166 Mdot
.3186 .00899 Mdot
.43871 .60999 Mdot
.80088 .39985 Mdot
.75421 .24047 Mdot
.65682 .47421 Mdot
.52137 .40964 Mdot
.0736 .05855 Mdot
.81289 .25279 Mdot
.6131 .54653 Mdot
.5149 .74182 Mdot
.93792 .98932 Mdot
.0736 .5272 Mdot
.53714 .99501 Mdot
.49755 .9115 Mdot
.80541 .54074 Mdot
.80635 .638 Mdot
.14061 .05567 Mdot
.23464 .25399 Mdot
.11204 .98794 Mdot
.36774 .0075 Mdot
.38419 .47005 Mdot
.84854 .23819 Mdot
.47144 .47862 Mdot
.85004 .70522 Mdot
.98141 .49694 Mdot
.26276 .82777 Mdot
.19698 .92148 Mdot
.46637 .15786 Mdot
.11198 .85652 Mdot
.26316 .91961 Mdot
.04854 .86444 Mdot
.90372 .93796 Mdot
.53173 .4043 Mdot
.07229 .70234 Mdot
.08799 .92953 Mdot
.20694 .95577 Mdot
.1552 .46166 Mdot
.90897 .1573 Mdot
.93421 .51986 Mdot
.36114 .00442 Mdot
.87529 .63636 Mdot
.15529 .05076 Mdot
.8944 .79521 Mdot
.27505 .12142 Mdot
.2694 .41513 Mdot
.24423 .46536 Mdot
.24171 .46709 Mdot
.12449 .48392 Mdot
.18223 .98123 Mdot
.18334 .34707 Mdot
.2381 .49174 Mdot
.76297 .31495 Mdot
.34978 .84169 Mdot
.63053 .24737 Mdot
.50446 .04919 Mdot
.3577 .10922 Mdot
.24242 .64225 Mdot
.16718 .68372 Mdot
.0304 .19502 Mdot
.08627 .20146 Mdot
.85123 .20697 Mdot
.95438 .89079 Mdot
.571 .71158 Mdot
.18451 .55487 Mdot
.22343 .88228 Mdot
.47733 .28274 Mdot
.65149 .85707 Mdot
.15598 .15244 Mdot
.40099 .16999 Mdot
.04863 .48535 Mdot
.37659 .0084 Mdot
.95728 .26542 Mdot
.52231 .78377 Mdot
.09232 .3964 Mdot
.98384 .07109 Mdot
.95422 .84293 Mdot
.73202 .1877 Mdot
.36601 .54809 Mdot
.09657 .34396 Mdot
.25542 .41788 Mdot
.61519 .13875 Mdot
.24762 .90443 Mdot
.22655 .14072 Mdot
.28606 .62216 Mdot
.6364 .34798 Mdot
.27001 .2422 Mdot
.70206 .27291 Mdot
.33109 .42589 Mdot
.98727 .10643 Mdot
.02726 .86363 Mdot
.9545 .76914 Mdot
.71728 .45246 Mdot
.26408 .61039 Mdot
.415 .56474 Mdot
.13447 .47726 Mdot
.1763 .92316 Mdot
.39475 .0898 Mdot
.91301 .68025 Mdot
.72167 .80928 Mdot
.48733 .2827 Mdot
.77787 .68938 Mdot
.49759 .43831 Mdot
.90549 .94184 Mdot
.85497 .97263 Mdot
.57379 .3006 Mdot
.34087 .4125 Mdot
.47642 .84874 Mdot
.23335 .47345 Mdot
.14444 .74952 Mdot
.31269 .76291 Mdot
.32883 .94828 Mdot
.85226 .46354 Mdot
.57701 .21712 Mdot
.29421 .02721 Mdot
.72935 .2818 Mdot
.42034 .07875 Mdot
.16515 .97062 Mdot
.13828 .70027 Mdot
.60255 .13317 Mdot
.84712 .23329 Mdot
.47471 .40691 Mdot
.44802 .48797 Mdot
.19644 .47706 Mdot
.64436 .03314 Mdot
.54935 .20781 Mdot
.34644 .97459 Mdot
.87758 .93421 Mdot
.98046 .88355 Mdot
.68775 .96549 Mdot
.84662 .19687 Mdot
.13841 .79315 Mdot
.0454 .95051 Mdot
.54236 .3946 Mdot
.44003 .49863 Mdot
.37237 .95768 Mdot
.84713 .47169 Mdot
.87949 .70104 Mdot
.39961 .52928 Mdot
.06862 .80207 Mdot
.46363 .62925 Mdot
.2714 .86241 Mdot
.6525 .43864 Mdot
.21962 .03815 Mdot
.65 .4867 Mdot
.57928 .66196 Mdot
.19481 .99344 Mdot
.20376 .71615 Mdot
.31573 .53054 Mdot
.33433 .01192 Mdot
.94213 .00998 Mdot
.33807 .20242 Mdot
.35986 .38224 Mdot
.09855 .37136 Mdot
.71725 .93907 Mdot
.8464 .29349 Mdot
.12395 .42795 Mdot
.22508 .6312 Mdot
.89669 .41544 Mdot
.06829 .91303 Mdot
.50463 .88017 Mdot
.63796 .93355 Mdot
.60655 .87533 Mdot
.28986 .6844 Mdot
.24009 .49792 Mdot
.26137 .3459 Mdot
.46103 .57719 Mdot
.37915 .02845 Mdot
.42381 .14791 Mdot
.2146 .41599 Mdot
.51834 .75211 Mdot
.20327 .47501 Mdot
.063 .88622 Mdot
.44738 .55044 Mdot
.34781 .02841 Mdot
.19707 .85358 Mdot
.17842 .53759 Mdot
.93787 .53557 Mdot
.57667 .97405 Mdot
.44151 .52815 Mdot
.17328 .78522 Mdot
.31356 .12688 Mdot
.57119 .04316 Mdot
.17163 .68864 Mdot
.56425 .1307 Mdot
.62026 .13472 Mdot
.22782 .09202 Mdot
.42269 .27562 Mdot
.1476 .58703 Mdot
.49308 .73341 Mdot
.43289 .61648 Mdot
.06145 .22176 Mdot
.29055 .85244 Mdot
.70869 .106 Mdot
.71623 .81769 Mdot
.56522 .38907 Mdot
.17774 .67469 Mdot
.97973 .24891 Mdot
.96675 .55916 Mdot
.46955 .98923 Mdot
.87883 .99233 Mdot
.99943 .2233 Mdot
.34898 .36623 Mdot
.98291 .0006 Mdot
.1174 .51846 Mdot
.22258 .91273 Mdot
.29701 .69029 Mdot
.57052 .52587 Mdot
.20319 .99852 Mdot
.65523 .24788 Mdot
.24062 .47218 Mdot
.1634 .30513 Mdot
.35263 .4853 Mdot
.18735 .03744 Mdot
.04055 .11334 Mdot
.23681 .03287 Mdot
.98906 .60396 Mdot
.03769 .12535 Mdot
.59287 .93806 Mdot
.36792 .60023 Mdot
.3969 .9133 Mdot
.74109 .32506 Mdot
.2215 .46578 Mdot
.57399 .06509 Mdot
.82877 .98366 Mdot
.38926 .01471 Mdot
.83066 .85073 Mdot
.22344 .93486 Mdot
.84818 .23368 Mdot
.20342 .81045 Mdot
.22949 .35032 Mdot
.80726 .21406 Mdot
.79004 .40411 Mdot
.12119 .85124 Mdot
.5451 .00396 Mdot
.43992 .79859 Mdot
.74848 .04557 Mdot
.1034 .80656 Mdot
.97252 .16806 Mdot
.87693 .86313 Mdot
.14308 .92333 Mdot
.61623 .06049 Mdot
.90591 .60092 Mdot
.85854 .84529 Mdot
.1216 .19267 Mdot
.73853 .01156 Mdot
.49469 .20009 Mdot
.27984 .16663 Mdot
.75946 .20112 Mdot
.23076 .41734 Mdot
.80291 .04761 Mdot
.34588 .52579 Mdot
.67539 .10306 Mdot
.753 .46042 Mdot
.8414 .45489 Mdot
.94439 .62603 Mdot
.72763 .25516 Mdot
.18627 .65231 Mdot
.21922 .03483 Mdot
.90724 .48579 Mdot
.39193 .87327 Mdot
.65314 .10915 Mdot
.59811 .8449 Mdot
.27528 .56721 Mdot
.98589 .75721 Mdot
.53265 .09714 Mdot
.14042 .29541 Mdot
.62309 .44742 Mdot
.35787 .02489 Mdot
.44086 .79685 Mdot
.20925 .94535 Mdot
.57366 .31086 Mdot
.73222 .12145 Mdot
.91851 .21873 Mdot
.14259 .26669 Mdot
.57067 .64991 Mdot
.20791 .51202 Mdot
.12365 .55774 Mdot
.09591 .21781 Mdot
.38732 .08258 Mdot
.68334 .19192 Mdot
.94523 .28285 Mdot
.46158 .23352 Mdot
.32171 .97449 Mdot
.72965 .15571 Mdot
.39022 .73414 Mdot
.58692 .90132 Mdot
.79853 .12651 Mdot
.4001 .3893 Mdot
.76122 .53228 Mdot
.35438 .13369 Mdot
.29651 .46473 Mdot
.65916 .98153 Mdot
.37271 .13698 Mdot
.1976 .69859 Mdot
.0736 .18387 Mdot
.41314 .56175 Mdot
.5926 .43663 Mdot
.85623 .66401 Mdot
.81156 .33343 Mdot
.36971 .30812 Mdot
.11497 .80174 Mdot
.05143 .14228 Mdot
.74092 .3257 Mdot
.333 .17813 Mdot
.33513 .1648 Mdot
.18923 .5018 Mdot
.28909 .98486 Mdot
.66119 .95785 Mdot
.64339 .54761 Mdot
.85274 .24596 Mdot
.85162 .20926 Mdot
.41839 .95991 Mdot
.79564 .38768 Mdot
.39707 .7938 Mdot
.08889 .04892 Mdot
.16171 .59946 Mdot
.69408 .89384 Mdot
.98751 .10297 Mdot
.37473 .8967 Mdot
.28186 .15989 Mdot
.75833 .3101 Mdot
.36746 .94516 Mdot
.91776 .12957 Mdot
.99443 .97637 Mdot
.15806 .72143 Mdot
.47995 .17444 Mdot
.11874 .66474 Mdot
.38338 .58228 Mdot
.31092 .78676 Mdot
.40505 .49936 Mdot
.97386 .90518 Mdot
.19444 .34205 Mdot
.19557 .56914 Mdot
.76956 .36728 Mdot
.2525 .46698 Mdot
.82002 .39393 Mdot
.17567 .73443 Mdot
.30389 .21153 Mdot
.12419 .0664 Mdot
.92096 .61604 Mdot
.74896 .28229 Mdot
.41322 .13258 Mdot
.82809 .38707 Mdot
.24822 .84134 Mdot
.62509 .82661 Mdot
.44624 .46525 Mdot
.35847 .3865 Mdot
.65977 .06756 Mdot
.23576 .62342 Mdot
.3411 .82839 Mdot
.18761 .55541 Mdot
.45828 .17453 Mdot
.37845 .24339 Mdot
.08494 .02753 Mdot
.53644 .86743 Mdot
.78065 .21161 Mdot
.9532 .03749 Mdot
.26011 .75714 Mdot
.48103 .65195 Mdot
.55713 .70237 Mdot
.29178 .01751 Mdot
.22267 .88575 Mdot
.18726 .4886 Mdot
.71161 .69718 Mdot
.73988 .21575 Mdot
.65133 .66148 Mdot
.19177 .39158 Mdot
.90818 .47136 Mdot
.24126 .35297 Mdot
.57042 .70222 Mdot
.69753 .65475 Mdot
.05659 .98945 Mdot
.39546 .61561 Mdot
.78301 .13693 Mdot
.29778 .13704 Mdot
.1295 .41919 Mdot
.50896 .94803 Mdot
.35289 .73581 Mdot
.36259 .5685 Mdot
.4639 .27766 Mdot
.16713 .2565 Mdot
.90548 .56245 Mdot
.40027 .58262 Mdot
.89436 .56271 Mdot
.05316 .95482 Mdot
.13902 .47736 Mdot
.70359 .81041 Mdot
.04199 .05115 Mdot
.19005 .86894 Mdot
.60475 .2997 Mdot
.77897 .28927 Mdot
.15291 .01474 Mdot
.61493 .06906 Mdot
.23928 .47287 Mdot
.21927 .48191 Mdot
.3294 .89594 Mdot
.2135 .50744 Mdot
.27314 .43561 Mdot
.4374 .67419 Mdot
.27686 .37672 Mdot
.27567 .8302 Mdot
.65441 .06444 Mdot
.4641 .5263 Mdot
.5254 .02499 Mdot
.89931 .469 Mdot
.29007 .54566 Mdot
.65665 .03071 Mdot
.99136 .66862 Mdot
.43492 .50785 Mdot
.64823 .23962 Mdot
.07423 .80868 Mdot
.318 .9157 Mdot
.68307 .01468 Mdot
.64748 .87692 Mdot
.21187 .48111 Mdot
.15227 .8458 Mdot
.29915 .99195 Mdot
.79254 .28996 Mdot
.59213 .02971 Mdot
.87939 .61378 Mdot
.18073 .52088 Mdot
.22106 .41625 Mdot
.15833 .72023 Mdot
.86544 .46869 Mdot
.36726 .72292 Mdot
.195 .60109 Mdot
.2229 .2937 Mdot
.1085 .76484 Mdot
.91908 .26061 Mdot
.24667 .47033 Mdot
.29384 .26596 Mdot
.35761 .8317 Mdot
.18558 .74692 Mdot
.21944 .47232 Mdot
.0973 .02319 Mdot
.3292 .98265 Mdot
.65749 .28132 Mdot
.20788 .40422 Mdot
.40045 .03618 Mdot
.17494 .60721 Mdot
.48269 .7475 Mdot
.88071 .16133 Mdot
.22835 .49923 Mdot
.44061 .33271 Mdot
.10786 .75264 Mdot
.25799 .88336 Mdot
.05107 .7203 Mdot
.97044 .90666 Mdot
.30426 .42912 Mdot
.74663 .52238 Mdot
.89726 .38849 Mdot
.57215 .95003 Mdot
.34879 .61116 Mdot
.71775 .77259 Mdot
.17205 .1128 Mdot
.24853 .46313 Mdot
.15511 .39932 Mdot
.0189 .56526 Mdot
.15852 .68209 Mdot
.12315 .67107 Mdot
.76876 .25967 Mdot
.32815 .10816 Mdot
.92126 .8942 Mdot
.72274 .19283 Mdot
.4718 .25793 Mdot
.02784 .42452 Mdot
.34467 .11956 Mdot
.71826 .00774 Mdot
.23959 .75543 Mdot
.76021 .3908 Mdot
.17518 .06053 Mdot
.66212 .74817 Mdot
.3385 .81881 Mdot
.33841 .61475 Mdot
.45992 .93495 Mdot
.62251 .41634 Mdot
.05668 .6678 Mdot
.62402 .03529 Mdot
.62159 .51768 Mdot
.94754 .03259 Mdot
.35508 .76349 Mdot
.18959 .61228 Mdot
.23279 .6814 Mdot
.42616 .87892 Mdot
.90923 .88385 Mdot
.13509 .2468 Mdot
.32936 .96131 Mdot
.42562 .81578 Mdot
.33925 .29642 Mdot
.84762 .80867 Mdot
.68431 .76942 Mdot
.95583 .7809 Mdot
.30699 .99572 Mdot
.73566 .16648 Mdot
.10603 .31783 Mdot
.26625 .30284 Mdot
.22165 .46496 Mdot
.1869 .02305 Mdot
.86549 .48171 Mdot
.69836 .21427 Mdot
.45558 .18075 Mdot
.8806 .42505 Mdot
.78981 .40543 Mdot
.0129 .64307 Mdot
.4203 .43736 Mdot
.22977 .49349 Mdot
.37311 .09025 Mdot
.96542 .19276 Mdot
.20115 .65684 Mdot
.78393 .17491 Mdot
.34321 .15949 Mdot
.1392 .91376 Mdot
.89323 .99374 Mdot
.22843 .51021 Mdot
.15185 .56914 Mdot
.24557 .86809 Mdot
.6074 .13348 Mdot
.07611 .38473 Mdot
.23696 .01459 Mdot
.1001 .17584 Mdot
.06903 .36881 Mdot
.28897 .01248 Mdot
.67126 .17637 Mdot
.2067 .0753 Mdot
.80469 .21129 Mdot
.99447 .58331 Mdot
.7138 .63108 Mdot
.6805 .72036 Mdot
.17056 .50717 Mdot
.67731 .3214 Mdot
.89538 .46842 Mdot
.58571 .14724 Mdot
.86172 .11505 Mdot
.31901 .11871 Mdot
.20089 .9021 Mdot
.15845 .02057 Mdot
.33971 .69958 Mdot
.2021 .47043 Mdot
.62966 .08678 Mdot
.42498 .71104 Mdot
.48862 .57976 Mdot
.79241 .36802 Mdot
.6478 .12166 Mdot
.20602 .2304 Mdot
.80882 .04431 Mdot
.89111 .1046 Mdot
.61265 .11052 Mdot
.73037 .07853 Mdot
.2516 .43128 Mdot
.52086 .60729 Mdot
.59121 .30979 Mdot
.15313 .86481 Mdot
.11397 .75322 Mdot
.29364 .49238 Mdot
.36837 .61659 Mdot
.16051 .2745 Mdot
.52531 .61222 Mdot
.27392 .16046 Mdot
.98446 .50293 Mdot
.47948 .12042 Mdot
.67795 .11337 Mdot
.95788 .52331 Mdot
.14221 .77515 Mdot
.84173 .62844 Mdot
.07876 .01795 Mdot
.4531 .14702 Mdot
.63371 .38408 Mdot
.31083 .90445 Mdot
.11242 .79706 Mdot
.1407 .72634 Mdot
.13544 .30431 Mdot
.51132 .59906 Mdot
.37901 .16995 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool00_l0000<ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0;ooooo`?o00004?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00Oooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo000Nooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool01?l0000:ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`?o00004?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0>_ooool2o`0002Oooooo0_l0000>ooooo`;o000000?oooooo`000?l00000<?oo
ool2o`0003_ooooo0_l0000:ooooo`;o0000>oooool2o`0001Oooooo000Nooooo`03o`000?oooooo
oooo03[ooooo0_l0000Nooooo`;o00001oooool2o`0000Cooooo0_l0000;ooooo`;o0000<?ooool2
o`0003_ooooo0_l00005ooooo`;o00000oooool2o`0003_ooooo0_l0000Gooooo`007_ooool00ol0
003oooooooooo`0^ooooo`;o00006Oooool2o`0000oooooo0_l0000=ooooo`;o00003oooool2o`00
05kooooo0_l0000@ooooo`;o0000FOooool001kooooo00?o0000ooooooooool05Oooool2o`0001Oo
oooo0_l0000Iooooo`;o00004?ooool2o`0001gooooo0_l0001Nooooo`;o0000Joooool001kooooo
00?o0000ooooooooool00_ooool2o`00017ooooo0_l000000ooooooo0000o`00000Eooooo`;o0000
1?ooool2o`0002Cooooo0_l0003Zooooo`007_ooool00ol0003oooooooooo`02ooooo`;o00005?oo
ool2o`0000;ooooo0_l0000Aooooo`;o00001?ooool2o`0000;ooooo0_l0000Qooooo`;o00004_oo
ool2o`000003ooooool0003o000003;ooooo0_l0002Nooooo`007_ooool01?l0003oooooo`000?l0
000Fooooo`;o00000oooool2o`0001_ooooo0_l0000Qooooo`;o00003oooool2o`000004ooooool0
003o0000ooooo`;o00000_ooool2o`0000Oooooo0_l0000Uooooo`;o0000Boooool2o`00057ooooo
000Nooooo`04o`000?oooooo0000o`0001Kooooo0_l0000gooooo`;o00002_ooool2o`0000oooooo
0_l00008ooooo`;o00001oooool2o`0003[ooooo0_l0000Cooooo`;o00008Oooool2o`00057ooooo
000Nooooo`03o`000?oooooooooo01;ooooo0_l0000_ooooo`;o00001?ooool2o`0000Gooooo0_l0
001Looooo`;o00003?ooool2o`0000oooooo0_l00002ooooo`;o0000GOooool2o`0001Gooooo000N
ooooo`03o`000?oooooooooo01;ooooo0_l0000Uooooo`;o00002?ooool2o`0000Cooooo0_l0000c
ooooo`;o0000;_ooool2o`00013ooooo0_l00005ooooo`;o00001?ooool2o`0004Cooooo0_l0000K
ooooo`Co00004oooool001kooooo00?o0000ooooooooool0>Oooool2o`0000Kooooo1?l0000Qoooo
o`;o00002oooool2o`0000Wooooo0_l0000[ooooo`;o00004oooool2o`0000Gooooo0_l0001:oooo
o`;o00007Oooool2o`0001?ooooo000Nooooo`03o`000?oooooooooo02?ooooo0_l0000Looooo`;o
00008oooool2o`0000_ooooo0_l0000fooooo`;o00002Oooool2o`0004_ooooo0_l00012ooooo`00
7_ooool00ol0003oooooooooo`0Sooooo`;o0000TOooool2o`0001Sooooo0_l0000Mooooo`;o0000
4_ooool2o`0004;ooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l00025ooooo`;o0000;_oo
ool2o`0001gooooo0_l0000@ooooo`;o0000A?ooool001kooooo0_l0000;ooooo`;o00003Oooool2
o`0001?ooooo0_l0001`ooooo`;o0000Goooool2o`0004Cooooo000Nooooo`03o`000?oooooooooo
00[ooooo0_l0000Nooooo`;o00000_ooool2o`0001[ooooo0_l0000Fooooo`;o0000hoooool001ko
oooo00?o0000ooooooooool05?ooool2o`0001Cooooo0_l0000Nooooo`;o00002?ooool2o`0000co
oooo0_l0000Fooooo`;o00002oooool2o`0003kooooo0_l0001nooooo`007_ooool00ol0003ooooo
ooooo`0Dooooo`;o00007oooool2o`0001gooooo0_l0000Tooooo`;o00002oooool2o`0003_ooooo
0_l000000ooooooo0000o`00001nooooo`007_ooool00ol0003oooooooooo`0eooooo`;o0000Oooo
ool2o`0000cooooo0_l0000;ooooo`;o0000M?ooool001kooooo00?o0000ooooooooool09?ooool2
o`0000Kooooo0_l00028ooooo`;o00003?ooool2o`0000_ooooo0ol0001cooooo`007_ooool00ol0
003oooooooooo`0Tooooo`;o00001_ooool2o`00053ooooo0_l00014ooooo`;o00003?ooool2o`00
06Sooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`1^ooooo`;o00003_ooool2o`000;co
oooo0_l00009ooooo`007_ooool00ol0003oooooooooo`0oooooo`;o0000;Oooool2o`0007?ooooo
0_l0001Rooooo`007_ooool00ol0003oooooooooo`0oooooo`;o0000<?ooool2o`0001;ooooo0_l0
001Looooo`;o00001?ooool2o`0002[ooooo0_l0000`ooooo`007_ooool00ol0003oooooooooo`0a
ooooo`;o0000?_ooool2o`0000Oooooo0_l00009ooooo`;o0000H_ooool2o`0002[ooooo0_l0000`
ooooo`007_ooool00ol0003oooooooooo`0aooooo`;o0000@oooool2o`0000;ooooo0_l0001=oooo
o`;o0000O?ooool001kooooo00?o0000ooooooooool03Oooool2o`0006Kooooo0ol00004ooooo`;o
0000Boooool2o`0007cooooo000Nooooo`03o`000?oooooooooo00gooooo0_l0000gooooo`;o0000
;Oooool2o`0000Gooooo0_l00008ooooo`;o00000_ooool2o`0004Sooooo0_l0001Tooooo`;o0000
2oooool001kooooo00?o0000ooooooooool0A_ooool2o`0002gooooo0_l0000?ooooo`;o00000_oo
ool2o`0000Cooooo0_l0000[ooooo`;o00005Oooool2o`0000Kooooo0_l0001Looooo`;o00002ooo
ool001kooooo00?o0000ooooooooool0T?ooool2o`0001Oooooo0_l0000Booooo`;o00001Oooool2
o`0001Kooooo0_l0001Yooooo`007_ooool2o`000:[ooooo0_l0000Iooooo`;o0000POooool001ko
oooo00?o0000ooooooooool0I?ooool2o`0006Sooooo0_l00007ooooo`;o00002Oooool2o`0003[o
oooo0_l0000?ooooo`;o00003?ooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo01[ooooo
0_l00018ooooo`;o000000?oooooo`000?l00000IOooool2o`0000Oooooo0_l00009ooooo`;o0000
>_ooool2o`0000oooooo0_l0000<ooooo`;o00002?ooool001kooooo00?o0000ooooooooool06_oo
ool2o`0000Kooooo0_l00013ooooo`;o00001oooool2o`0000Cooooo0_l0001;ooooo`;o00002ooo
ool2o`0006_ooooo0_l00008ooooo`007_ooool00ol0003oooooooooo`09ooooo`;o00005oooool2
o`00013ooooo0_l0000Mooooo`;o00006oooool2o`0000Cooooo0_l0001;ooooo`;o00002oooool2
o`0000Kooooo0_l0000jooooo`;o0000<Oooool001kooooo00?o0000ooooooooool02Oooool2o`00
02Wooooo0_l0000Mooooo`;o0000Poooool2o`0003[ooooo0_l0000aooooo`007_ooool00ol0003o
ooooooooo`1Tooooo`;o00000oooool2o`000003ooooool0003o000000gooooo0_l0000Kooooo`;o
0000=?ooool2o`0004Oooooo0_l0000^ooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o0000
3?ooool2o`0002kooooo0_l0000=ooooo`;o00000oooool2o`000003ooooool0003o000000gooooo
0_l0000Kooooo`;o0000=?ooool2o`0001[ooooo0_l0000[ooooo`;o0000;_ooool001kooooo00?o
0000ooooooooool02?ooool2o`0000gooooo0_l0000<ooooo`;o0000;_ooool2o`0000_ooooo0_l0
0016ooooo`;o00008_ooool2o`0001[ooooo0_l0000Cooooo`;o0000A_ooool001kooooo00?o0000
ooooooooool00_ooool2o`0000Cooooo0_l0001Hooooo`;o00002Oooool2o`0003Gooooo0_l00004
ooooo`;o00006_ooool2o`0001Kooooo0_l0000Oooooo`;o00009Oooool2o`0000_ooooo0_l0000B
ooooo`007_ooool00ol0003oooooooooo`02ooooo`;o0000JOooool4o`00017ooooo0_l0000Poooo
o`;o00003Oooool2o`0000_ooooo0ol00003ooooo`;o00002?ooool2o`0000cooooo0_l00016oooo
o`;o00002oooool2o`0001;ooooo000Nooooo`03o`000?oooooooooo05?ooooo0_l0000Jooooo`;o
00004Oooool2o`0002oooooo0_l0000;ooooo`?o00000oooool2o`0000Sooooo0_l0000eooooo`;o
0000?_ooool001kooooo00?o0000ooooooooool0Doooool2o`0000Sooooo0_l0000Fooooo`;o0000
2oooool2o`00043ooooo1?l0000booooo`;o00002oooool2o`0003kooooo000Nooooo`03o`000?oo
oooooooo00gooooo0_l0000gooooo`;o00005Oooool2o`0001Kooooo0_l0000;ooooo`;o00006Ooo
ool2o`0002Gooooo0_l0000dooooo`;o0000Boooool001kooooo00?o0000ooooooooool03Oooool2
o`0003Oooooo0_l0001Eooooo`;o0000Z?ooool001kooooo00?o0000ooooooooool0KOooool2o`00
00Kooooo0_l0000?ooooo`;o00001oooool2o`0002Wooooo0_l0002;ooooo`007_ooool2o`0006ko
oooo0_l00006ooooo`;o00003oooool2o`0000Oooooo0_l0000Yooooo`;o0000LOooool2o`0001So
oooo000Nooooo`03o`000?oooooooooo02oooooo0_l0003looooo`;o00006?ooool001kooooo00?o
0000ooooooooool0;oooool2o`0002[ooooo0_l0000gooooo`;o00004?ooool2o`00047ooooo0_l0
000hooooo`;o00008_ooool001kooooo00?o0000ooooooooool04Oooool2o`0004;ooooo0_l00000
1?oooooo0000o`000?ooool2o`0000kooooo0_l0000Wooooo`;o00004?ooool2o`00047ooooo0_l0
000_ooooo`;o00001oooool2o`0002;ooooo000Nooooo`03o`000?oooooooooo017ooooo0_l00012
ooooo`;o000000?oooooo`000?l000004Oooool2o`0007gooooo0_l0000^ooooo`;o0000:oooool0
01kooooo00?o0000ooooooooool0Eoooool2o`00013ooooo0_l0001oooooo`?o0000=?ooool2o`00
02Cooooo000Nooooo`03o`000?oooooooooo05Oooooo0_l0000@ooooo`;o00003?ooool2o`0000Go
oooo0_l0001[ooooo`;o0000=?ooool2o`0001Gooooo0_l0000=ooooo`007_ooool00ol0003ooooo
ooooo`1gooooo`;o00001Oooool2o`0006_ooooo0_l0001;ooooo`;o00003Oooool001kooooo00?o
0000ooooooooool07?ooool2o`0007?ooooo0_l00005ooooo`;o00009_ooool2o`0001Cooooo0_l0
000Sooooo`;o0000B_ooool001kooooo00?o0000ooooooooool07?ooool2o`0004[ooooo0_l0000W
ooooo`;o00001Oooool2o`0002Kooooo0_l0000Dooooo`;o00008oooool2o`0004[ooooo000Noooo
o`03o`000?oooooooooo06Sooooo0_l0000Vooooo`;o00002oooool2o`000:Sooooo000Nooooo`03
o`000?oooooooooo01Cooooo0_l0001jooooo`;o00002oooool2o`000:Sooooo000Nooooo`03o`00
0?oooooooooo01Cooooo0_l0003Dooooo`;o0000;Oooool2o`0002cooooo000Nooooo`03o`000?oo
oooooooo0=[ooooo0_l0000>ooooo`;o0000;Oooool3o`0002_ooooo0003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo00Kooooo0_l0
000Kooooo`;o0000]Oooool2o`0000?ooooo0_l00006ooooo`;o0000<Oooool2o`0001[ooooo0_l0
000?ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`06ooooo`;o00006oooool2o`000;[ooooo
0_l00006ooooo`;o00009_ooool2o`0000[ooooo0_l0000Iooooo`;o00003oooool000?ooooo00Go
410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0001Vooooo`;o0000
=Oooool2o`0005Cooooo0_l0000Jooooo`;o00002_ooool2o`0002[ooooo0003ooooo`05o`000?oo
ooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo01Sooooo
0_l0001<ooooo`;o00000_ooool3o`00033ooooo0_l0001Dooooo`;o0000D_ooool000?ooooo00Go
0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0
6?ooool2o`00053ooooo0ol0000mooooo`;o0000IOooool2o`0002[ooooo0_l00008ooooo`000ooo
ool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2Zooooo`;o00000_ooool2o`00067ooooo0_l0000Zooooo`;o00002?ooool000?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003o
ooooooooo`0Uooooo`;o00002_ooool2o`0002cooooo0_l0001=ooooo`;o0000B_ooool2o`0000Ko
oooo0_l0000=ooooo`;o0000=?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0Uooooo`?o00002Oooool3o`00
01cooooo0_l0000=ooooo`;o0000?oooool2o`0003gooooo0_l0000;ooooo`;o00003?ooool2o`00
00Kooooo0_l00013ooooo`007_ooool00ol0003oooooooooo`0Kooooo`;o00002Oooool2o`0000[o
oooo0_l0000Looooo`;o00003oooool2o`0003gooooo0_l0000Eooooo`;o00009_ooool2o`0000_o
oooo0_l00006ooooo`;o00003?ooool2o`0002?ooooo0_l0000Nooooo`007_ooool00ol0003ooooo
ooooo`02o`0000kooooo0_l00009ooooo`;o0000A?ooool2o`0000_ooooo0_l00017ooooo`;o0000
4oooool2o`0002Kooooo0_l0000aooooo`;o00007_ooool001kooooo00?o0000ooooooooool00_l0
000>ooooo`;o00006_ooool2o`0001_ooooo0_l0000Sooooo`;o0000G?ooool2o`0005Cooooo0_l0
000Mooooo`;o00001?ooool001kooooo00?o0000ooooooooool0;?ooool2o`0001_ooooo0_l0002d
ooooo`;o00008Oooool2o`0001gooooo0_l00004ooooo`007_ooool01?l0003oooooooooooooool2
o`0003cooooo0_l00003ooooo`;o0000^Oooool2o`0004Kooooo000Nooooo`04o`000?oooooooooo
ooooo`;o0000??ooool2o`0000?ooooo0_l0001<ooooo`;o0000Noooool3o`0003Gooooo000Noooo
o`03o`000?oooooooooo09;ooooo0_l0001kooooo`?o0000=Oooool001kooooo00?o0000oooooooo
ool0coooool2o`00023ooooo0_l0000Mooooo`;o0000=Oooool001kooooo00?o0000ooooooooool0
E?ooool2o`00027ooooo0_l0001Fooooo`;o00008?ooool2o`0000gooooo0_l00015ooooo`007_oo
ool00ol0003oooooooooo`0Xooooo`;o0000:_ooool2o`00027ooooo0_l0001@ooooo`;o0000=Ooo
ool2o`0000oooooo0_l0000dooooo`007_ooool00ol0003oooooooooo`0Xooooo`;o0000Woooool2
o`0000Kooooo0_l0000nooooo`;o00009oooool2o`0000_ooooo000Nooooo`;o0000d_ooool2o`00
00gooooo0_l0000Rooooo`;o0000=?ooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo03;o
oooo0_l0000Dooooo`;o0000B_ooool2o`0004[ooooo0_l00006ooooo`;o00006_ooool2o`00047o
oooo000Nooooo`03o`000?oooooooooo03;ooooo0_l0000Dooooo`;o0000B_ooool3o`0004Gooooo
0_l0000:ooooo`;o00003?ooool2o`0004oooooo000Nooooo`03o`000?oooooooooo09Gooooo0_l0
0015ooooo`;o00003Oooool2o`0000Wooooo0_l0000_ooooo`;o00007_ooool001kooooo00?o0000
ooooooooool0Loooool2o`0007Kooooo0_l0000jooooo`;o00002_ooool2o`0001;ooooo000Noooo
o`03o`000?oooooooooo02[ooooo0_l0000_ooooo`;o00005Oooool3o`000;kooooo0_l0000Boooo
o`007_ooool00ol0003oooooooooo`0Zooooo`;o0000;oooool2o`0001Gooooo0_l0003Cooooo`00
7_ooool00ol0003oooooooooo`0Vooooo`;o00002?ooool2o`000:kooooo0_l0000booooo`;o0000
<Oooool001kooooo00?o0000ooooooooool09_ooool2o`0000Sooooo0_l0001Cooooo`;o00003?oo
ool2o`0000Sooooo0_l00011ooooo`;o00007_ooool2o`0000oooooo0_l000000ooooooo0000o`00
000aooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o0000<?ooool2o`0003Cooooo0_l00004
ooooo`;o00001_ooool2o`0000Sooooo0_l0000cooooo`;o0000;?ooool2o`0000oooooo0_l0000d
ooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o0000<?ooool2o`0003[ooooo0_l0000:oooo
o`;o000000?oooooo`000?l00000=_ooool2o`0001Gooooo0_l00004ooooo`;o0000?_ooool2o`00
01Kooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0002<ooooo`;o000000?oooooo`000?l0
0000COooool2o`0000Cooooo0_l0000nooooo`;o00005_ooool001kooooo00?o0000ooooooooool0
2Oooool3o`000>[ooooo0_l000000ooooooo0000o`000003ooooo`;o0000Aoooool001kooooo00?o
0000ooooooooool02_ooool2o`000>[ooooo0_l000000ooooooo0000o`000003ooooo`;o00003ooo
ool2o`0003Kooooo000Nooooo`03o`000?oooooooooo02[ooooo0_l00005ooooo`;o00004Oooool2
o`0002Cooooo0_l0002Sooooo`;o0000=_ooool001kooooo00?o0000ooooooooool0:_ooool2o`00
00Gooooo0_l0000Aooooo`;o00009?ooool2o`0005Cooooo0_l0001eooooo`;o00003_ooool001ko
oooo0_l00007ooooo`;o0000B_ooool2o`0006;ooooo0_l00008ooooo`;o0000MOooool2o`0000ko
oooo000Nooooo`03o`000?oooooooooo00Kooooo0_l000000ooooooo0000o`00000Mooooo`;o0000
0oooool2o`0000;ooooo0_l0000Oooooo`;o0000H_ooool2o`0003_ooooo0_l0001Booooo`007_oo
ool00ol0003oooooooooo`09ooooo`;o00002Oooool2o`0001;ooooo0_l00003ooooo`;o00000_oo
ool2o`00047ooooo0_l0001mooooo`;o0000D_ooool001kooooo00?o0000ooooooooool05?ooool2
o`0005kooooo0_l00010ooooo`;o00001?ooool2o`0003Cooooo0_l0000Cooooo`;o0000?_ooool0
01kooooo00?o0000ooooooooool0]_ooool2o`0000Cooooo0_l0000dooooo`Co00004Oooool2o`00
03kooooo000Nooooo`03o`000?oooooooooo01kooooo0_l0003Dooooo`;o0000DOooool001kooooo
00?o0000ooooooooool07_ooool2o`000?oooooo:?ooool001kooooo00?o0000ooooooooool0f?oo
ool2o`0001Wooooo0_l0001Booooo`007_ooool00ol0003oooooooooo`2<ooooo`?o0000:oooool2
o`0001cooooo0_l0000Cooooo`;o00001?ooool2o`0005;ooooo000Nooooo`03o`000?oooooooooo
08cooooo0ol0000[ooooo`;o00006?ooool2o`0001Oooooo0_l0000gooooo`;o00007oooool001ko
oooo00?o0000ooooooooool0Roooool2o`0000_ooooo0_l0000jooooo`;o0000;_ooool2o`00023o
oooo0_l0000Oooooo`007_ooool00ol0003oooooooooo`1Jooooo`;o0000;oooool2o`0000_ooooo
0_l0001Zooooo`;o0000@Oooool001kooooo00?o0000ooooooooool0:_ooool2o`0002kooooo0_l0
003[ooooo`007_ooool00ol0003oooooooooo`0Zooooo`;o00000_ooool2o`0000_ooooo0_l0003o
ooooo`_ooooo000Nooooo`03o`000?oooooooooo01_ooooo0_l0000Aooooo`;o00002oooool2o`00
01Cooooo0_l0000aooooo`;o00005oooool2o`0008Wooooo0_l0000Mooooo`007_ooool00ol0003o
ooooooooo`0Kooooo`;o00006_ooool2o`0001Sooooo0_l0000aooooo`;o00005oooool2o`0002co
oooo0_l0001Kooooo`;o00007Oooool001kooooo0_l0000hooooo`;o00003Oooool2o`0008?ooooo
0_l0001jooooo`007_ooool00ol0003oooooooooo`16ooooo`;o00000_ooool2o`000:3ooooo0_l0
001Iooooo`007_ooool00ol0003oooooooooo`1:ooooo`;o0000X?ooool2o`0000?ooooo0_l0001D
ooooo`007_ooool00ol0003oooooooooo`3aooooo`;o0000E?ooool001kooooo00?o0000oooooooo
ool0Goooool2o`000>Kooooo000Nooooo`03o`000?oooooooooo05oooooo0_l0000<ooooo`;o0000
Qoooool2o`0004oooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l00012ooooo`;o00005Ooo
ool2o`0008Oooooo0_l00006ooooo`;o0000;Oooool2o`0001Sooooo000Nooooo`03o`000?oooooo
oooo01;ooooo0_l00008ooooo`;o0000>?ooool2o`000:Kooooo0_l0000]ooooo`;o00006?ooool0
01kooooo00?o0000ooooooooool03_ooool2o`0000cooooo0_l0003oooooob[ooooo000Nooooo`03
o`000?oooooooooo00kooooo0_l00016ooooo`;o00009_ooool2o`0006?ooooo0_l0001Rooooo`00
7_ooool00ol0003oooooooooo`0^ooooo`;o00009_ooool2o`0000oooooo0_l00008ooooo`;o0000
2oooool2o`0006?ooooo0_l00006ooooo`;o0000F_ooool001kooooo00?o0000ooooooooool05Ooo
ool2o`0001Oooooo0_l0000`ooooo`;o00001Oooool2o`0000Sooooo0_l0001Gooooo`;o00007ooo
ool2o`0005[ooooo000Nooooo`03o`000?oooooooooo01Gooooo0_l00019ooooo`;o00003_ooool2
o`0005Sooooo0_l0000cooooo`;o00002?ooool2o`0001Gooooo0_l0000Uooooo`007_ooool00ol0
003oooooooooo`0jooooo`;o0000=?ooool2o`0000cooooo0_l0000dooooo`;o0000?Oooool2o`00
00[ooooo0_l00008ooooo`;o00005Oooool2o`0002Gooooo0003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo
03[ooooo0_l00012ooooo`;o0000;?ooool2o`0000Kooooo0_l0000mooooo`;o00004Oooool2o`00
03oooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Jooooo`;o0000T?ooool2o`0005Sooooo0_l0000ooooo
o`000oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`?o00006_ooool2o`00
01;ooooo0_l0000Cooooo`;o0000^oooool2o`0004Gooooo0003ooooo`05o`000?oooooooooooooo
ool000002oooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo00;ooooo0_l0000Z
ooooo`;o00003oooool2o`0000;ooooo0_l0000Uooooo`;o0000<Oooool2o`0000[ooooo0_l0001B
ooooo`;o000000?oooooo`000?l000009_ooool2o`0001gooooo0003ooooo`05o`000?oooooooooo
ooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo00;ooooo0_l0
000kooooo`;o000000?oooooo`000?l000009_ooool2o`0000?ooooo0_l0000:ooooo`;o00006Ooo
ool2o`0000Gooooo0_l0000:ooooo`;o00005oooool2o`0003Wooooo0_l0000Yooooo`;o00007Ooo
ool000?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o
0000ooooooooool0=Oooool2o`0000_ooooo0_l0000[ooooo`;o00002_ooool2o`0001Wooooo0_l0
000=ooooo`;o00006oooool2o`0003Wooooo0_l00018ooooo`000oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0eooooo`;o00008_oo
ool2o`00013ooooo0_l0000hooooo`;o0000X?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0@_ooool4o`0000gooooo0_l0
0004ooooo`;o00004?ooool2o`0005Wooooo0_l0001Gooooo`;o00009_ooool001kooooo00?o0000
ooooooooool09_ooool2o`0001[ooooo1?l000000ooooooo0000o`000006ooooo`;o00000_ooool2
o`00077ooooo0_l0001Gooooo`;o00009_ooool001kooooo00?o0000ooooooooool09_ooool2o`00
01oooooo0_l00006ooooo`;o0000m_ooool001kooooo00?o0000ooooooooool01Oooool2o`00067o
oooo0_l0002Sooooo`;o00002oooool2o`0002_ooooo000Nooooo`03o`000?oooooooooo00Gooooo
0_l0000Hooooo`;o00000oooool2o`0004;ooooo0_l0002Sooooo`;o00002oooool2o`0002_ooooo
000Nooooo`03o`000?oooooooooo01oooooo0_l00003ooooo`;o0000:?ooool2o`0000oooooo0_l0
003Vooooo`007_ooool00ol0003oooooooooo`1>ooooo`;o00003oooool2o`0002Gooooo0_l0002o
ooooo`007_ooool00ol0003oooooooooo`1Eooooo`;o00005oooool2o`0001Gooooo0ol00004oooo
o`;o0000;oooool2o`0008Sooooo000Nooooo`03o`000?oooooooooo04Sooooo0_l0000;ooooo`;o
00005oooool2o`0001Gooooo0_l00005ooooo`;o00004?ooool2o`0001gooooo0_l0000Aooooo`;o
00008?ooool2o`0005?ooooo000Nooooo`03o`000?oooooooooo04Sooooo0_l00010ooooo`;o0000
4_ooool2o`00033ooooo0_l0000Pooooo`;o0000Doooool001kooooo00?o0000ooooooooool0R_oo
ool2o`0003[ooooo0_l0001oooooo`007_ooool00ol0003oooooooooo`18ooooo`;o0000O?ooool2
o`0007oooooo000Nooooo`;o0000@?ooool2o`0000Oooooo0_l0000Oooooo`;o0000N_ooool2o`00
063ooooo000Nooooo`03o`000?oooooooooo03oooooo0_l0000Xooooo`;o0000N_ooool2o`0002Ko
oooo0_l0000]ooooo`;o00002Oooool001kooooo00?o0000ooooooooool0c_ooool2o`0003gooooo
0_l0000]ooooo`;o00002Oooool001kooooo00?o0000ooooooooool0;_ooool2o`0005?ooooo0_l0
0019ooooo`;o00008Oooool2o`0005Cooooo000Nooooo`03o`000?oooooooooo02kooooo0_l0000<
ooooo`;o00001_ooool2o`0000Gooooo1?l0000=ooooo`;o00009Oooool2o`0000Sooooo0_l0001R
ooooo`;o00007_ooool2o`0003Cooooo000Nooooo`03o`000?oooooooooo03cooooo0_l00006oooo
o`;o00001?ooool6o`0000cooooo0_l0000Tooooo`;o00002Oooool2o`0008;ooooo0_l00002oooo
o`;o00002?ooool2o`0002Kooooo000Nooooo`03o`000?oooooooooo03kooooo0_l0000:ooooo`Ko
0000:Oooool2o`0000Oooooo0_l0002;ooooo`;o00001?ooool2o`0000Sooooo0ol000000ooooooo
0000o`00000Rooooo`007_ooool00ol0003oooooooooo`0jooooo`;o00000_ooool2o`0000?ooooo
0_l00003ooooo`Oo000000?oooooo`000?l000009oooool2o`0005Kooooo0_l0000looooo`;o0000
3oooool2o`000003ooooool0003o000002;ooooo000Nooooo`03o`000?oooooooooo02Sooooo0ol0
000?ooooo`Ko00000oooool2o`0000?ooooo1?l000001?oooooo0000o`000?ooool2o`0007oooooo
0_l0001dooooo`007_ooool00ol0003oooooooooo`0Xooooo`?o00004Oooool2o`0000?ooooo0_l0
000Mooooo`;o0000<oooool2o`00047ooooo0_l0001]ooooo`007_ooool00ol0003oooooooooo`0T
ooooo`;o00006oooool4o`0001_ooooo0_l0000cooooo`;o0000@Oooool2o`0003[ooooo0ol0000`
ooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o00005_ooool2o`0001gooooo0_l0000Zoooo
o`;o0000G_ooool2o`0004?ooooo0ol0000<ooooo`;o00008_ooool001kooooo00?o0000oooooooo
ool03?ooool2o`0002_ooooo0_l0000dooooo`;o00007Oooool2o`0003oooooo0_l0001Booooo`;o
00003Oooool2o`0001?ooooo000Nooooo`03o`000?oooooooooo03Wooooo0_l0000<ooooo`Co0000
4?ooool2o`00037ooooo0_l0002Rooooo`;o00004oooool001kooooo00?o0000ooooooooool0Aooo
ool4o`00013ooooo0_l0000Yooooo`;o0000T_ooool2o`0001_ooooo0_l0000>ooooo`007_ooool0
0ol0003oooooooooo`16ooooo`;o00000_ooool2o`0003Cooooo0_l00004ooooo`;o00000oooool2
o`0000;ooooo0_l00029ooooo`?o00006_ooool2o`0000;ooooo0_l0000:ooooo`007_ooool2o`00
03[ooooo0_l0000;ooooo`;o00000_ooool2o`0003Cooooo0_l00009ooooo`;o00000_ooool2o`00
07Gooooo0_l0000Cooooo`;o00005?ooool2o`0000Sooooo0_l0000:ooooo`007_ooool00ol0003o
ooooooooo`0iooooo`;o00004Oooool2o`000;Sooooo0_l0000Eooooo`;o00004_ooool2o`0000Wo
oooo0_l00009ooooo`007_ooool00ol0003oooooooooo`0cooooo`;o00002oooool3o`0000Wooooo
0_l0000kooooo`;o0000T_ooool2o`00013ooooo0_l0000;ooooo`;o00002Oooool001kooooo00?o
0000ooooooooool0;_ooool2o`0000?ooooo0_l0000;ooooo`?o00000oooool2o`00047ooooo0_l0
0020ooooo`;o00008_ooool2o`0001Kooooo000Nooooo`03o`000?oooooooooo02kooooo0_l0000?
ooooo`;o00001Oooool2o`000<?ooooo0_l0000jooooo`007_ooool00ol0003oooooooooo`0ooooo
o`;o00003_ooool2o`0001Wooooo0_l0001Jooooo`;o0000Ooooool001kooooo00?o0000oooooooo
ool08_ooool2o`0001?ooooo0_l0000Fooooo`;o00006Oooool2o`0001Kooooo0_l00012ooooo`;o
0000I?ooool2o`0001Wooooo000Nooooo`03o`000?oooooooooo02;ooooo0_l0000Cooooo`;o0000
BOooool2o`0004gooooo0_l0000Looooo`;o0000>oooool2o`0000Gooooo0_l0000Booooo`007_oo
ool00ol0003oooooooooo`0Dooooo`;o0000E_ooool2o`0000?ooooo0_l0000Gooooo`;o00001ooo
ool2o`00023ooooo0_l0000Jooooo`;o00007?ooool2o`0004;ooooo0_l0000Booooo`007_ooool0
0ol0003oooooooooo`0Dooooo`;o0000:Oooool2o`0002_ooooo0_l00003ooooo`;o00002oooool2
o`0000[ooooo0ol00006ooooo`;o00008?ooool2o`00093ooooo000Nooooo`03o`000?oooooooooo
03oooooo0_l0000Rooooo`;o00006Oooool2o`0000[ooooo0ol0001Vooooo`;o0000<?ooool2o`00
023ooooo000Nooooo`03o`000?oooooooooo03;ooooo0_l00007ooooo`;o00002_ooool2o`0000Oo
oooo0_l0000Aooooo`;o0000S_ooool2o`00033ooooo0_l00006ooooo`;o00006?ooool001kooooo
00?o0000ooooooooool0<_ooool2o`0000;ooooo0_l00003ooooo`;o00002_ooool2o`0000Oooooo
0_l0003Kooooo`;o00006?ooool001kooooo00?o0000ooooooooool0=_ooool2o`0004Wooooo0_l0
000kooooo`;o0000@_ooool2o`0004?ooooo000Nooooo`03o`000?oooooooooo05[ooooo0_l0000U
ooooo`;o00005Oooool2o`0002Cooooo0_l0000cooooo`;o00003Oooool2o`0004?ooooo000Noooo
o`03o`000?oooooooooo05[ooooo0_l0000Gooooo`;o00001?ooool2o`0000gooooo0_l0000>oooo
o`;o0000:Oooool2o`0000Sooooo0_l0000Cooooo`;o00003oooool2o`0005;ooooo000Nooooo`;o
0000M?ooool2o`0000Cooooo0_l0000=ooooo`;o00000oooool2o`0003Cooooo0_l00008ooooo`;o
00004oooool2o`00043ooooo0_l00004ooooo`;o00006oooool001kooooo00?o0000ooooooooool0
9?ooool2o`0001;ooooo0_l00005ooooo`;o0000C?ooool2o`0007_ooooo0_l0000Hooooo`;o0000
1?ooool2o`0001_ooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l0000Booooo`?o00001?oo
ool2o`000<Wooooo0_l0000:ooooo`;o0000;oooool001kooooo00?o0000ooooooooool09?ooool2
o`0001?ooooo0_l0003Kooooo`;o00007_ooool2o`0000oooooo000Nooooo`03o`000?oooooooooo
07_ooooo0_l00005ooooo`;o0000Voooool2o`000003ooooool0003o000001;ooooo0_l0000?oooo
o`007_ooool00ol0003oooooooooo`02ooooo`;o0000DOooool2o`0002Cooooo0_l00005ooooo`?o
0000V_ooool2o`000003ooooool0003o000002?ooooo000Nooooo`03o`000?oooooooooo00;ooooo
0_l0000Yooooo`;o00003?ooool2o`0000Cooooo0_l0000Booooo`;o00006oooool2o`0000oooooo
0_l00032ooooo`007_ooool00ol0003oooooooooo`0]ooooo`;o00003?ooool2o`0000Cooooo0_l0
000Sooooo`;o00002_ooool2o`000=?ooooo000Nooooo`03o`000?oooooooooo06Kooooo0_l0003O
ooooo`007_ooool00ol0003oooooooooo`2Booooo`;o0000U?ooool2o`0001gooooo000Nooooo`03
o`000?oooooooooo03[ooooo0_l0000mooooo`;o00000oooool2o`0001;ooooo0_l00005ooooo`Co
0000Roooool2o`000003ooooool0003o000001[ooooo000Nooooo`03o`000?oooooooooo03[ooooo
0_l0000Kooooo`;o00008?ooool2o`0000?ooooo0_l0000Iooooo`Co0000Poooool2o`0000Wooooo
0_l0000Booooo`;o00001_ooool001kooooo00?o0000ooooooooool0;?ooool2o`0002Wooooo0_l0
000aooooo`;o0000U?ooool2o`0001gooooo0_l00006ooooo`007_ooool00ol0003oooooooooo`0/
ooooo`;o0000G?ooool2o`0009Kooooo0_l0000Sooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003ooooooooo
o`2;ooooo`;o00002oooool2o`0008Sooooo0_l0000Sooooo`000oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`14ooooo`;o00003_ooool2o`0003Gooooo0_l0000;ooooo`;o0000[Oooool000?ooooo00Go
410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`00033o
oooo0_l00009ooooo`Co00001Oooool2o`0000kooooo0_l0000Mooooo`;o00002oooool2o`00023o
oooo0_l0001nooooo`;o00008oooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05
o`000?nHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0`ooooo`;o00002Oooool4o`00
0003ooooool0003o0000037ooooo0_l0000;ooooo`;o00008?ooool2o`0005cooooo0_l0000Foooo
o`;o00002?ooool2o`0001Wooooo0_l00008ooooo`000oooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo03Gooooo0_l00009
ooooo`;o00002_ooool2o`0001_ooooo0_l0000jooooo`;o0000FOooool2o`0001Kooooo0_l0000S
ooooo`;o00002?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOo
oooo00Sooooo00?o0000ooooooooool0=Oooool4o`0001?ooooo0_l00004ooooo`;o00005Oooool2
o`0000_ooooo0_l0000Cooooo`;o00006?ooool2o`00053ooooo0_l0001>ooooo`000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0M
ooooo`;o00006?ooool2o`000003ooooool0003o000001Kooooo0_l0000Iooooo`;o00001oooool2
o`00013ooooo0_l000000ooooooo0000o`00000Jooooo`;o0000C_ooool2o`0000[ooooo0_l00012
ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_oo
ool00ol0003oooooooooo`0Mooooo`;o00006oooool2o`0002kooooo0_l000000ooooooo0000o`00
0005ooooo`;o00001_ooool2o`0000[ooooo0ol0000Iooooo`;o000000?oooooo`000?l00000F_oo
ool2o`0001Gooooo0_l0000;ooooo`;o00007_ooool001kooooo00?o0000ooooooooool08Oooool2
o`0004Oooooo0_l00008ooooo`;o00001_ooool2o`0000_ooooo0_l0000Iooooo`;o0000J_ooool2
o`0000Sooooo0_l0000;ooooo`;o00001Oooool2o`0001Oooooo000Nooooo`03o`000?oooooooooo
027ooooo0_l0000fooooo`;o0000]Oooool2o`0001cooooo0_l0000Gooooo`007_ooool00ol0003o
ooooooooo`19ooooo`;o00003_ooool2o`0003?ooooo0_l0000Eooooo`;o0000X?ooool001kooooo
00?o0000ooooooooool0BOooool2o`0004?ooooo0_l0000Eooooo`;o0000Ioooool2o`0001oooooo
0_l00009ooooo`;o00002oooool001kooooo00?o0000ooooooooool0AOooool2o`0004cooooo0_l0
000Aooooo`;o0000??ooool2o`0002Sooooo0_l0000Oooooo`;o00002Oooool2o`0000_ooooo000N
ooooo`03o`000?oooooooooo04Gooooo0_l0001<ooooo`;o00004Oooool2o`0000Cooooo0_l0000f
ooooo`;o0000HOooool001kooooo00?o0000ooooooooool0R_ooool2o`00023ooooo0_l0001Doooo
o`;o00005?ooool2o`0002gooooo000Nooooo`03o`000?oooooooooo07;ooooo0_l0000Fooooo`;o
0000M_ooool2o`0001Cooooo0_l0000]ooooo`007_ooool00ol0003oooooooooo`02o`0004Wooooo
0_l0000Jooooo`;o00002Oooool2o`0004Kooooo0_l0000:ooooo`;o0000Loooool2o`0000[ooooo
000Nooooo`03o`000?oooooooooo00;o0000@Oooool2o`0000Kooooo0_l0000Jooooo`;o00004?oo
ool2o`0003oooooo0_l0000:ooooo`;o0000Loooool2o`0000[ooooo000Nooooo`03o`000?oooooo
oooo04?ooooo0_l0000dooooo`;o00004?ooool2o`0000Oooooo0_l0000Oooooo`;o0000T?ooool0
01kooooo0_l0000iooooo`;o00002?ooool2o`0004Oooooo0_l00007ooooo`;o00000_ooool2o`00
01_ooooo0_l0002@ooooo`007_ooool00ol0003oooooooooo`0hooooo`;o00002?ooool2o`0005Co
oooo0_l00015ooooo`;o0000I_ooool001kooooo00?o0000ooooooooool0=?ooool2o`0000Cooooo
0_l000000ooooooo0000o`000017ooooo`;o0000Eoooool2o`0006Kooooo000Nooooo`03o`000?oo
oooooooo033ooooo0_l00002ooooo`;o00001?ooool2o`000003ooooool0003o000004Oooooo0_l0
000Rooooo`;o00003?ooool2o`0000Kooooo0_l0000>ooooo`;o0000MOooool001kooooo00?o0000
ooooooooool08_ooool2o`0000cooooo0_l0001Aooooo`;o00009Oooool2o`0000cooooo0_l00006
ooooo`;o00003_ooool4o`0003kooooo0_l0000cooooo`007_ooool00ol0003oooooooooo`0>oooo
o`;o00004_ooool2o`0004kooooo0_l0000?ooooo`;o0000COooool2o`0001Cooooo0_l00004oooo
o`;o00008_ooool2o`0002[ooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o
00005?ooool2o`0004cooooo0_l0000^ooooo`;o0000A?ooool2o`0000Cooooo0_l0001>ooooo`;o
00001oooool001kooooo00?o0000ooooooooool09?ooool2o`00013ooooo1?l0001@ooooo`;o0000
5_ooool2o`0001kooooo0_l00023ooooo`007_ooool00ol0003oooooooooo`0fooooo`Co0000D?oo
ool2o`0003Kooooo0_l00023ooooo`007_ooool00ol0003oooooooooo`13ooooo`;o0000@Oooool2
o`0003Wooooo0_l0000hooooo`;o0000:?ooool2o`00023ooooo000Nooooo`03o`000?oooooooooo
02oooooo0_l000000ooooooo0000o`000008ooooo`;o00001Oooool2o`0000?ooooo0_l0000loooo
o`;o0000;?ooool2o`0000_ooooo0_l00003ooooo`;o0000<oooool2o`0002Sooooo0_l0000Poooo
o`007_ooool00ol0003oooooooooo`0^ooooo`?o000000?oooooo`000?l000002?ooool2o`0000[o
oooo0_l0000@ooooo`;o0000F?ooool2o`00013ooooo0_l0001oooooo`007_ooool00ol0003ooooo
ooooo`0^ooooo`;o00001?ooool2o`0002Cooooo1?l00006ooooo`;o0000Toooool2o`0004cooooo
000Nooooo`03o`000?oooooooooo03Cooooo0_l0000Vooooo`;o00001_ooool2o`0008Sooooo0_l0
0009ooooo`;o0000C?ooool001kooooo00?o0000ooooooooool0k_ooool2o`0005Oooooo000Noooo
o`03o`000?oooooooooo03cooooo0_l0000/ooooo`;o0000Moooool2o`0006;ooooo000Nooooo`;o
00005?ooool2o`0001Cooooo0_l0000<ooooo`;o00000oooool2o`0002cooooo0_l00015ooooo`;o
00000_ooool2o`0002cooooo0_l0000eooooo`;o00003_ooool2o`0001_ooooo000Nooooo`03o`00
0?oooooooooo01?ooooo0_l0000Dooooo`;o00003?ooool2o`0002[ooooo0_l0001<ooooo`;o0000
0_ooool2o`0005Wooooo0_l00008ooooo`;o00003_ooool2o`0000gooooo0_l0000<ooooo`007_oo
ool00ol0003oooooooooo`0jooooo`;o00009oooool2o`000:_ooooo0_l0000Wooooo`;o00003?oo
ool001kooooo00?o0000ooooooooool0>_ooool2o`0004[ooooo0_l0000^ooooo`;o0000Soooool0
01kooooo00?o0000ooooooooool0Q_ooool2o`0002kooooo0_l0002?ooooo`007_ooool00ol0003o
ooooooooo`0nooooo`;o0000hoooool2o`0002;ooooo000Nooooo`03o`000?oooooooooo00cooooo
0_l0000Fooooo`;o00002Oooool2o`0000gooooo0_l00007ooooo`;o0000T?ooool2o`0004Sooooo
0_l0000Rooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o00005_ooool2o`0000Wooooo0_l0
000Fooooo`;o0000:_ooool2o`0006Cooooo0_l0001/ooooo`007_ooool00ol0003oooooooooo`0Z
ooooo`;o00000oooool2o`0004;ooooo0_l0000nooooo`;o0000T_ooool001kooooo00?o0000oooo
ooooool0:_ooool2o`0008Oooooo0_l0002Booooo`007_ooool00ol0003oooooooooo`2Looooo`;o
0000ZOooool001kooooo00?o0000ooooooooool0=Oooool2o`0003Sooooo0_l0000:ooooo`;o0000
7oooool2o`0009kooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`0eooooo`;o00008ooo
ool2o`0001?ooooo0_l0000:ooooo`;o0000<_ooool2o`0008_ooooo0_l00009ooooo`007_ooool0
0ol0003oooooooooo`1Jooooo`;o0000Aoooool2o`0000[ooooo0_l0002Fooooo`007_ooool00ol0
003oooooooooo`2Sooooo`;o0000DOooool2o`0000?ooooo0_l0001:ooooo`007_ooool00ol0003o
ooooooooo`0^ooooo`;o00002?ooool2o`0005oooooo0_l0000Looooo`;o00006_ooool2o`00027o
oooo0_l00003ooooo`;o0000A?ooool2o`0000Cooooo000Nooooo`;o00001Oooool2o`0002Gooooo
0_l000000ooooooo0000o`000008ooooo`;o00004_ooool2o`0000Wooooo0_l00010ooooo`;o0000
7?ooool2o`0001[ooooo0_l0001/ooooo`;o00001?ooool001kooooo00?o0000ooooooooool01?oo
ool2o`0001Wooooo1?l00008ooooo`;o00007oooool2o`0000Wooooo0_l0000=ooooo`;o0000;Ooo
ool2o`0000gooooo0_l0001gooooo`;o00003?ooool2o`0001[ooooo000Nooooo`03o`000?oooooo
oooo01oooooo1?l0000Wooooo`;o00001?ooool2o`0001Cooooo0_l0000]ooooo`;o00001_ooool2
o`0000Gooooo0_l0000fooooo`;o0000?oooool2o`0000cooooo0_l0000?ooooo`;o00002Oooool0
01kooooo00?o0000ooooooooool0B_ooool2o`0000Cooooo0_l0001;ooooo`;o0000?Oooool2o`00
05kooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`1Rooooo`;o00002oooool2o`000=Ko
oooo000Nooooo`03o`000?oooooooooo01oooooo0_l00011ooooo`;o00002oooool2o`0002Kooooo
0_l0002Iooooo`;o00004oooool001kooooo00?o0000ooooooooool07oooool2o`0007Kooooo0_l0
0011ooooo`;o0000E_ooool2o`0001?ooooo000Nooooo`03o`000?oooooooooo03Cooooo0_l0002T
ooooo`;o00002Oooool2o`0004_ooooo0_l0000Cooooo`007_ooool00ol0003oooooooooo`0Zoooo
o`;o00002?ooool2o`0000?ooooo0_l0000Gooooo`;o0000TOooool2o`00063ooooo000Nooooo`03
o`000?oooooooooo02[ooooo0_l0000=ooooo`;o00005oooool2o`000??ooooo000Nooooo`03o`00
0?oooooooooo047ooooo0_l0001Hooooo`;o0000U_ooool2o`0001;ooooo000Nooooo`03o`000?oo
oooooooo03Cooooo0_l0000;ooooo`;o0000F?ooool2o`0000Wooooo0_l0002;ooooo`;o00004_oo
ool001kooooo00?o0000ooooooooool0=?ooool2o`0002_ooooo0_l00013ooooo`;o0000Woooool0
01kooooo00?o0000ooooooooool0HOooool2o`0004oooooo0_l0002Cooooo`000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`0Yooooo`;o0000:?ooool2o`0002Sooooo0_l0000cooooo`;o0000Toooool0
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonH
V9So8B4Q00Kooooo00?o0000ooooooooool08?ooool2o`0000Oooooo0_l0000Aooooo`;o00005Ooo
ool2o`0002Sooooo0_l0000<ooooo`;o0000T_ooool2o`0002Kooooo0003ooooo`05oa0@4?oooooo
ooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0000Pooooo`;o0000
6_ooool2o`0004gooooo0_l0002Booooo`;o00009_ooool000?ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool00ol0003oooooooooo`0Booooo`;o
00003Oooool2o`0006Sooooo0_l0002jooooo`000oooool01Ol0003ooooooooooooooooo000000_o
oooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo01;ooooo1?l00007oooo
o`;o00000_ooool2o`0008Oooooo0_l0002Kooooo`000oooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo01Cooooo0_l00007
ooooo`;o00002oooool2o`0007kooooo0_l0000kooooo`;o00009_ooool2o`0003Kooooo0003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o
0000ooooooooool05?ooool2o`0001Cooooo0_l0000:ooooo`;o00001_ooool2o`000:7ooooo0_l0
0004ooooo`;o00009_ooool3o`0003Gooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0;Oooool2o`0000Oooooo
0_l00006ooooo`;o00004_ooool3o`00037ooooo0_l0001Iooooo`;o0000;Oooool2o`0003Gooooo
000Nooooo`03o`000?oooooooooo02gooooo0_l0000Sooooo`Co00005?ooool2o`0001[ooooo0_l0
001Mooooo`;o0000H?ooool001kooooo00?o0000ooooooooool08?ooool2o`0003;ooooo0_l0000D
ooooo`;o0000NOooool2o`00063ooooo000Nooooo`03o`000?oooooooooo023ooooo0_l0001noooo
o`;o0000YOooool001kooooo00?o0000ooooooooool0DOooool2o`0001Sooooo0_l0000cooooo`;o
00009Oooool2o`0007kooooo000Nooooo`03o`000?oooooooooo057ooooo0_l00003ooooo`;o0000
4oooool2o`0000?ooooo0_l0001Eooooo`;o0000L_ooool2o`0000?ooooo0_l00005ooooo`007_oo
ool00ol0003oooooooooo`0Zooooo`;o00004Oooool2o`0001Oooooo0_l0000Hooooo`;o0000:_oo
ool2o`0009gooooo0_l00003ooooo`;o00001Oooool001kooooo00?o0000ooooooooool0:_ooool4
o`0000oooooo0_l0001Mooooo`Co0000Yoooool001kooooo00?o0000ooooooooool0;?ooool2o`00
073ooooo0_l0002Wooooo`007_ooool00ol0003oooooooooo`0Yooooo`;o00001?ooool2o`0001co
oooo0_l0000Oooooo`;o0000`_ooool2o`0001?ooooo000Nooooo`03o`000?oooooooooo02Kooooo
0_l000000ooooooo0000o`000002ooooo`Co00007?ooool2o`0001oooooo0_l0001>ooooo`;o0000
5?ooool2o`0003gooooo0_l0000Mooooo`;o00004oooool001kooooo00?o0000ooooooooool03Ooo
ool2o`0000Cooooo0_l0000Aooooo`;o00001Oooool2o`0006Sooooo0_l0000Uooooo`;o00005?oo
ool2o`0003gooooo0_l0000booooo`007_ooool2o`0000_ooooo0_l000000ooooooo0000o`000004
ooooo`;o00003_ooool2o`00013ooooo0_l0000Sooooo`;o0000>oooool2o`00077ooooo0_l0000k
ooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o00005oooool2o`00013ooooo0_l00005oooo
o`;o00007?ooool2o`000:kooooo0_l0000kooooo`007_ooool00ol0003oooooooooo`0Nooooo`Co
00006_ooool2o`0009;ooooo0_l0001Oooooo`;o00000oooool2o`0000oooooo000Nooooo`03o`00
0?oooooooooo01kooooo1?l0000booooo`;o0000N_ooool2o`0005oooooo0_l00003ooooo`;o0000
3oooool001kooooo00?o0000ooooooooool01Oooool2o`0000Gooooo0_l0000Pooooo`;o00009?oo
ool2o`0007[ooooo0_l00017ooooo`;o0000;?ooool001kooooo00?o0000ooooooooool01Oooool2
o`0000Gooooo0_l0000Pooooo`;o00007?ooool2o`0005cooooo0_l0000Tooooo`;o0000Aoooool2
o`0002cooooo000Nooooo`03o`000?oooooooooo03[ooooo0_l0000@ooooo`;o0000G?ooool2o`00
09_ooooo000Nooooo`03o`000?oooooooooo03[ooooo0_l0000oooooo`;o0000MOooool2o`0005?o
oooo000Nooooo`03o`000?oooooooooo07_ooooo0_l0000eooooo`;o00003Oooool2o`0000_ooooo
0_l0000Rooooo`;o0000Doooool001kooooo00?o0000ooooooooool0Q_ooool2o`0001Gooooo0_l0
00000ooooooo0000o`00000:ooooo`;o00001?ooool2o`0000gooooo0_l0000;ooooo`;o0000I_oo
ool2o`0000oooooo000Nooooo`03o`000?oooooooooo04;ooooo0_l000000ooooooo0000o`000006
ooooo`;o000000?oooooo`000?l00000=?ooool2o`0001Gooooo0_l000000ooooooo0000o`00000:
ooooo`;o0000Goooool2o`0001Cooooo0_l0000Aooooo`;o00000oooool2o`0000[ooooo000Noooo
o`03o`000?oooooooooo013ooooo0_l0000`ooooo`Go00001_ooool2o`000003ooooool0003o0000
0;_ooooo0_l0000Dooooo`;o00005_ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00go
oooo0_l000000ooooooo0000o`00000booooo`;o00002?ooool2o`00027ooooo0_l0003Dooooo`00
7_ooool00ol0003oooooooooo`0=ooooo`;o0000?oooool2o`0000Cooooo0ol0000;ooooo`;o0000
3Oooool2o`0008oooooo0_l0000Gooooo`;o00005Oooool2o`0001?ooooo000Nooooo`03o`000?oo
oooooooo04Wooooo0_l00009ooooo`?o00002oooool2o`0000?ooooo0_l0001eooooo`;o00008_oo
ool2o`0001Oooooo0_l0000:ooooo`;o00002Oooool2o`0001?ooooo000Nooooo`03o`000?oooooo
oooo01gooooo0_l0000Zooooo`;o00007?ooool2o`0000gooooo0_l0001Vooooo`;o0000Aoooool2
o`0001kooooo000Nooooo`;o00007_ooool2o`0001kooooo0_l0000Mooooo`;o00006?ooool2o`00
04?ooooo0_l0002:ooooo`007_ooool2o`0003kooooo0_l0000=ooooo`;o00003_ooool2o`0000?o
oooo0_l0001Hooooo`;o0000O?ooool2o`0000cooooo000Nooooo`03o`000?oooooooooo04cooooo
0_l00008ooooo`;o00002Oooool2o`000=Cooooo1?l0000<ooooo`007_ooool00ol0003ooooooooo
o`1Fooooo`;o0000A_ooool2o`0009Oooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`0B
ooooo`;o00005Oooool2o`0001Wooooo0_l0000gooooo`;o00007oooool2o`0009;ooooo0_l0000C
ooooo`007_ooool00ol0003oooooooooo`0Booooo`;o00000oooool2o`00013ooooo0_l00004oooo
o`;o000000?oooooo`000?l000004?ooool2o`00013ooooo0_l0000;ooooo`;o00006?ooool2o`00
0;?ooooo0_l0000Cooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o00005_ooool2o`000003
ooooool0003o000000oooooo0_l0000<ooooo`;o00000oooool2o`0000_ooooo0_l0002gooooo`;o
0000:Oooool001kooooo00?o0000ooooooooool0:_ooool2o`0000Wooooo0_l00005ooooo`;o0000
1Oooool2o`0000cooooo0_l00039ooooo`;o0000:Oooool001kooooo00?o0000ooooooooool0:_oo
ool2o`0000Wooooo0_l00005ooooo`;o0000ooooool3ooooo`;o00001Oooool001kooooo00?o0000
ooooooooool05_ooool4o`000?oooooo9oooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo
01Kooooo1?l0000<ooooo`;o00003oooool2o`0005kooooo0_l0002^ooooo`007_ooool00ol0003o
ooooooooo`0Vooooo`;o00003oooool2o`0000cooooo0_l0001:ooooo`;o00001?ooool2o`0003;o
oooo0_l0001<ooooo`;o0000;?ooool001kooooo00?o0000ooooooooool0AOooool2o`0000_ooooo
0_l0000gooooo`;o00001?ooool2o`0002[ooooo0_l0000<ooooo`;o00006?ooool2o`0003;ooooo
0_l00007ooooo`;o00008oooool001kooooo00?o0000ooooooooool0D_ooool2o`0003Oooooo0_l0
000`ooooo`;o00009_ooool2o`0003_ooooo0_l0000Sooooo`007_ooool00ol0003oooooooooo`10
ooooo`;o0000<Oooool2o`000:gooooo0_l0000Sooooo`007_ooool00ol0003oooooooooo`10oooo
o`;o00009Oooool2o`0000[ooooo0_l0000/ooooo`;o0000Y?ooool001kooooo0_l0000<ooooo`;o
0000F_ooool2o`0003?ooooo0_l00003ooooo`;o00004oooool2o`0008oooooo000Nooooo`03o`00
0?oooooooooo00_ooooo1?l0002=ooooo`;o00005Oooool2o`000003ooooool0003o0000073ooooo
0_l0000Mooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o0000<?ooool2o`0002oooooo0_l0
0003ooooo`;o0000??ooool2o`0001kooooo0_l0001Cooooo`;o00007Oooool001kooooo00?o0000
ooooooooool0?oooool2o`0002oooooo0_l00003ooooo`;o00003Oooool2o`0004gooooo0_l0001b
ooooo`007_ooool00ol0003oooooooooo`1Wooooo`;o00006oooool2o`000<7ooooo000Nooooo`03
o`000?oooooooooo06Oooooo0_l0000Wooooo`;o0000BOooool2o`0006[ooooo000Nooooo`03o`00
0?oooooooooo05kooooo0ol0000_ooooo`;o0000BOooool2o`0006[ooooo000Nooooo`03o`000?oo
oooooooo03;ooooo0_l0000Zooooo`?o0000/Oooool2o`0003?ooooo000Nooooo`04o`000?oooooo
ooooooooo`;o0000;oooool2o`00033ooooo0_l00007ooooo`;o00006_ooool2o`0002cooooo0_l0
001Iooooo`;o0000:oooool2o`0000Kooooo000Nooooo`04o`000?ooooooooooooooo`;o0000HOoo
ool2o`0000Oooooo0_l0000Jooooo`;o0000;?ooool2o`0008Kooooo0_l00006ooooo`007_ooool0
0ol0003oooooooooo`0gooooo`;o0000VOooool2o`0007?ooooo000Nooooo`03o`000?oooooooooo
03Oooooo0_l0000Qooooo`;o00002oooool2o`0006Cooooo0_l00003ooooo`;o0000=Oooool2o`00
03cooooo000Nooooo`03o`000?oooooooooo023ooooo0_l0000;ooooo`;o0000:oooool2o`0000_o
oooo0_l0000Rooooo`;o0000@?ooool2o`0003[ooooo0_l0000Vooooo`;o00005?ooool001kooooo
00?o0000ooooooooool03_ooool2o`00013ooooo0_l0000;ooooo`;o0000G?ooool2o`0000Sooooo
0_l0000]ooooo`;o0000Ioooool2o`0000;ooooo0_l0000Dooooo`005?ooool4o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool03_ooool2o`0002_ooooo0_l0000Pooooo`;o00004Ooo
ool2o`0002?ooooo0_l0000]ooooo`;o0000E?ooool2o`0000;ooooo0_l0000=ooooo`;o00006?oo
ool001Kooooo00?o0000ooooooooool01Oooool01?l0003oooooo`000?l0000jooooo`;o00008?oo
ool2o`000003ooooool0003o000000kooooo0_l0000iooooo`;o0000KOooool2o`0000;ooooo0_l0
000Wooooo`005_ooool00ol0003oooooooooo`05ooooo`Co0000?Oooool2o`00023ooooo0_l00019
ooooo`;o0000V_ooool001Kooooo00?o0000ooooooooool0A_ooool2o`000?oooooo2?ooool001Ko
oooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo
000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Cooooo00?oEEEEofIVI_l00000oooooomB
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.17825 .68793 Mdot
.84506 .42063 Mdot
.18545 .5145 Mdot
.10522 .01604 Mdot
.33136 .44519 Mdot
.26344 .02214 Mdot
.59183 .04713 Mdot
.24772 .47991 Mdot
.29343 .96831 Mdot
.76012 .0418 Mdot
.3227 .18975 Mdot
.41889 .09068 Mdot
.23512 .53425 Mdot
.5844 .66139 Mdot
.18907 .01077 Mdot
.51439 .63327 Mdot
.77928 .60471 Mdot
.31432 .56967 Mdot
.19589 .60477 Mdot
.1317 .10365 Mdot
.86168 .61019 Mdot
.32222 .09468 Mdot
.41799 .4425 Mdot
.8666 .04367 Mdot
.24463 .88368 Mdot
.2274 .4192 Mdot
.16571 .83297 Mdot
.54188 .7217 Mdot
.33577 .19252 Mdot
.27328 .12695 Mdot
.22768 .59024 Mdot
.20258 .9988 Mdot
.34043 .99808 Mdot
.90433 .92471 Mdot
.94253 .54809 Mdot
.07983 .88639 Mdot
.59083 .67154 Mdot
.84694 .50488 Mdot
.4715 .83396 Mdot
.20023 .79438 Mdot
.2122 .5948 Mdot
.00253 .64043 Mdot
.03074 .99306 Mdot
.81122 .59718 Mdot
.52326 .04613 Mdot
.99839 .70428 Mdot
.63876 .45167 Mdot
.01093 .83255 Mdot
.10326 .80948 Mdot
.16327 .31101 Mdot
.4113 .98206 Mdot
.96355 .50422 Mdot
.27063 .3821 Mdot
.07189 .85417 Mdot
.29501 .37411 Mdot
.22732 .23342 Mdot
.76184 .29689 Mdot
.25021 .51632 Mdot
.15948 .84083 Mdot
.3038 .68296 Mdot
.13676 .03578 Mdot
.24057 .45654 Mdot
.58456 .09543 Mdot
.26722 .91621 Mdot
.26728 .7516 Mdot
.31371 .04882 Mdot
.03702 .40374 Mdot
.16151 .83199 Mdot
.24969 .04633 Mdot
.82103 .30622 Mdot
.15914 .22589 Mdot
.409 .60716 Mdot
.07867 .15663 Mdot
.26212 .21259 Mdot
.38286 .06721 Mdot
.97983 .29318 Mdot
.172 .35155 Mdot
.63613 .21413 Mdot
.18235 .9096 Mdot
.47558 .40655 Mdot
.99121 .86119 Mdot
.67647 .10593 Mdot
.82132 .60463 Mdot
.24095 .47751 Mdot
.76293 .43106 Mdot
.0227 .21774 Mdot
.27468 .42402 Mdot
.10593 .91108 Mdot
.22201 .02713 Mdot
.34686 .65946 Mdot
.09723 .11778 Mdot
.85004 .27341 Mdot
.17443 .30174 Mdot
.17332 .21066 Mdot
.31649 .63606 Mdot
.9774 .76536 Mdot
.59688 .16658 Mdot
.95144 .53358 Mdot
.25902 .82193 Mdot
.92001 .58314 Mdot
.1727 .74939 Mdot
.41699 .94392 Mdot
.14317 .62161 Mdot
.56057 .6422 Mdot
.92053 .32899 Mdot
.41404 .4497 Mdot
.48862 .66615 Mdot
.51 .65749 Mdot
.98253 .49927 Mdot
.64492 .13424 Mdot
.58669 .67936 Mdot
.83067 .49439 Mdot
.46997 .95751 Mdot
.2729 .57887 Mdot
.42827 .32806 Mdot
.62984 .99931 Mdot
.512 .0186 Mdot
.21923 .53061 Mdot
.05765 .30113 Mdot
.54158 .8825 Mdot
.13622 .82055 Mdot
.00942 .7374 Mdot
.37727 .11004 Mdot
.17689 .21373 Mdot
.88464 .19821 Mdot
.88719 .59371 Mdot
.33793 .89778 Mdot
.20142 .65363 Mdot
.90365 .89476 Mdot
.0319 .12554 Mdot
.88074 .55142 Mdot
.35714 .26147 Mdot
.78964 .74206 Mdot
.38771 .54297 Mdot
.32196 .60016 Mdot
.28355 .34506 Mdot
.40124 .44222 Mdot
.4063 .67143 Mdot
.15507 .55582 Mdot
.29499 .01823 Mdot
.21835 .64767 Mdot
.26588 .90844 Mdot
.34938 .07224 Mdot
.95907 .61195 Mdot
.57549 .31992 Mdot
.40798 .08752 Mdot
.22736 .71706 Mdot
.18335 .77249 Mdot
.77008 .28322 Mdot
.65231 .09997 Mdot
.67842 .75741 Mdot
.35046 .04022 Mdot
.43921 .09466 Mdot
.1396 .11746 Mdot
.1676 .97818 Mdot
.222 .51052 Mdot
.44526 .64365 Mdot
.73828 .3722 Mdot
.26159 .93563 Mdot
.49615 .62961 Mdot
.42617 .61773 Mdot
.92403 .54599 Mdot
.81648 .89713 Mdot
.41002 .53461 Mdot
.25467 .7963 Mdot
.33675 .41735 Mdot
.19358 .77413 Mdot
.21968 .87945 Mdot
.63685 .12146 Mdot
.39979 .50333 Mdot
.36098 .1357 Mdot
.97717 .86067 Mdot
.92604 .53143 Mdot
.05777 .28543 Mdot
.18303 .66139 Mdot
.45613 .76099 Mdot
.85383 .88577 Mdot
.19645 .42372 Mdot
.60762 .10037 Mdot
.95557 .51009 Mdot
.03867 .97218 Mdot
.38514 .03268 Mdot
.51525 .80556 Mdot
.51005 .15166 Mdot
.69212 .24951 Mdot
.47305 .88316 Mdot
.49383 .62287 Mdot
.06871 .08569 Mdot
.77148 .74091 Mdot
.94798 .69656 Mdot
.19016 .65761 Mdot
.99496 .20292 Mdot
.1961 .6718 Mdot
.48327 .17671 Mdot
.522 .88518 Mdot
.03949 .01933 Mdot
.93654 .5704 Mdot
.39737 .13152 Mdot
.2979 .96927 Mdot
.37009 .05645 Mdot
.52474 .19814 Mdot
.47893 .34443 Mdot
.37251 .5614 Mdot
.52432 .12353 Mdot
.24669 .88846 Mdot
.10323 .92347 Mdot
.64069 .05939 Mdot
.12508 .89265 Mdot
.79646 .39658 Mdot
.55407 .74395 Mdot
.38941 .47601 Mdot
.20309 .67952 Mdot
.90421 .2241 Mdot
.66329 .31907 Mdot
.41786 .64304 Mdot
.14079 .21399 Mdot
.21171 .77935 Mdot
.11875 .28158 Mdot
.47484 .75155 Mdot
.07747 .37637 Mdot
.76041 .31375 Mdot
.36065 .60449 Mdot
.2625 .89463 Mdot
.22517 .91514 Mdot
.34922 .63408 Mdot
.45434 .58103 Mdot
.97189 .98642 Mdot
.3797 .38404 Mdot
.69927 .19126 Mdot
.34222 .06713 Mdot
.21429 .47424 Mdot
.30082 .70063 Mdot
.36167 .07895 Mdot
.99298 .0912 Mdot
.13916 .21131 Mdot
.73264 .17395 Mdot
.70737 .54327 Mdot
.22094 .56545 Mdot
.84598 .54668 Mdot
.76337 .21953 Mdot
.17746 .39155 Mdot
.36372 .1028 Mdot
.02107 .92531 Mdot
.13578 .43378 Mdot
.48344 .82369 Mdot
.16131 .34631 Mdot
.38855 .59398 Mdot
.34276 .13621 Mdot
.69939 .08932 Mdot
.20633 .57852 Mdot
.96563 .4908 Mdot
.34126 .39558 Mdot
.82099 .14632 Mdot
.02759 .22702 Mdot
.8799 .19222 Mdot
.02597 .83272 Mdot
.29524 .3947 Mdot
.87239 .4811 Mdot
.95564 .75141 Mdot
.42969 .32624 Mdot
.1922 .70027 Mdot
.27342 .73977 Mdot
.24284 .22496 Mdot
.94618 .37178 Mdot
.36175 .08583 Mdot
.96862 .12942 Mdot
.45345 .93796 Mdot
.04726 .29751 Mdot
.2178 .55091 Mdot
.1867 .81205 Mdot
.25671 .81884 Mdot
.67328 .47179 Mdot
.17777 .07265 Mdot
.30893 .75373 Mdot
.99072 .88292 Mdot
.37101 .41595 Mdot
.45112 .75012 Mdot
.45264 .24978 Mdot
.0797 .85179 Mdot
.4319 .97095 Mdot
.79815 .27401 Mdot
.33273 .11053 Mdot
.42512 .50486 Mdot
.60201 .64393 Mdot
.32169 .41419 Mdot
.2616 .89507 Mdot
.38811 .52477 Mdot
.8946 .49756 Mdot
.02686 .75106 Mdot
.34235 .21573 Mdot
.0292 .90248 Mdot
.86005 .27027 Mdot
.19934 .60765 Mdot
.4805 .13734 Mdot
.61475 .12812 Mdot
.90208 .50354 Mdot
.23825 .74971 Mdot
.48892 .61636 Mdot
.79748 .24442 Mdot
.68582 .13504 Mdot
.89272 .49525 Mdot
.29531 .8966 Mdot
.9466 .57466 Mdot
.41183 .58347 Mdot
.74779 .02289 Mdot
.99944 .4591 Mdot
.1732 .8402 Mdot
.15116 .92591 Mdot
.87321 .12703 Mdot
.46467 .33295 Mdot
.12923 .85476 Mdot
.79451 .23004 Mdot
.2267 .42541 Mdot
.40148 .34845 Mdot
.25299 .77776 Mdot
.05355 .75581 Mdot
.46638 .77687 Mdot
.05608 .28369 Mdot
.3377 .96345 Mdot
.92818 .34448 Mdot
.47751 .83693 Mdot
.34865 .0271 Mdot
.41779 .99283 Mdot
.53789 .78913 Mdot
.26517 .5918 Mdot
.21139 .48311 Mdot
.08195 .84993 Mdot
.19814 .70466 Mdot
.40961 .0591 Mdot
.2215 .46504 Mdot
.10754 .1028 Mdot
.27547 .04848 Mdot
.48159 .27186 Mdot
.87039 .08661 Mdot
.09 .30844 Mdot
.25493 .28598 Mdot
.74436 .68883 Mdot
.16137 .80698 Mdot
.75772 .87779 Mdot
.95812 .10648 Mdot
.25228 .81973 Mdot
.74396 .66466 Mdot
.21968 .67452 Mdot
.41573 .58818 Mdot
.71376 .36846 Mdot
.57766 .54129 Mdot
.63543 .10873 Mdot
.35332 .2663 Mdot
.92885 .40747 Mdot
.25252 .47919 Mdot
.21226 .53587 Mdot
.31471 .39165 Mdot
.92474 .71206 Mdot
.54329 .68052 Mdot
.61205 .06746 Mdot
.16202 .06013 Mdot
.99903 .62576 Mdot
.40634 .54943 Mdot
.25255 .53543 Mdot
.14289 .27719 Mdot
.34341 .12047 Mdot
.86303 .81124 Mdot
.21628 .59624 Mdot
.39237 .46829 Mdot
.28039 .90513 Mdot
.90545 .75161 Mdot
.63911 .87141 Mdot
.72304 .66356 Mdot
.73954 .21264 Mdot
.27418 .10367 Mdot
.40398 .64914 Mdot
.18804 .84889 Mdot
.19525 .53851 Mdot
.32117 .03662 Mdot
.97737 .91439 Mdot
.9111 .5774 Mdot
.53132 .04068 Mdot
.09859 .85011 Mdot
.90347 .16898 Mdot
.29576 .14922 Mdot
.19573 .92643 Mdot
.08799 .02728 Mdot
.70544 .24588 Mdot
.87692 .18998 Mdot
.52976 .73645 Mdot
.50242 .1279 Mdot
.65172 .85139 Mdot
.64498 .52057 Mdot
.16676 .81518 Mdot
.60231 .68122 Mdot
.22205 .64017 Mdot
.32195 .52032 Mdot
.15121 .72478 Mdot
.29165 .4838 Mdot
.3174 .46137 Mdot
.42543 .27838 Mdot
.79085 .67325 Mdot
.94552 .15138 Mdot
.15162 .84383 Mdot
.24471 .59986 Mdot
.03023 .02538 Mdot
.54458 .96271 Mdot
.75708 .34754 Mdot
.23904 .46373 Mdot
.64417 .66436 Mdot
.94192 .95618 Mdot
.31005 .21447 Mdot
.36738 .63923 Mdot
.45117 .54741 Mdot
.41013 .53003 Mdot
.39569 .65635 Mdot
.23728 .89399 Mdot
.41578 .62864 Mdot
.60028 .00425 Mdot
.73633 .25388 Mdot
.36681 .54787 Mdot
.12976 .61305 Mdot
.45026 .5914 Mdot
.73998 .34511 Mdot
.17355 .91153 Mdot
.20537 .83218 Mdot
.59942 .39975 Mdot
.72951 .16827 Mdot
.3416 .52947 Mdot
.24373 .50563 Mdot
.76684 .53758 Mdot
.49245 .21047 Mdot
.3123 .00653 Mdot
.41507 .60487 Mdot
.80545 .39112 Mdot
.75395 .23805 Mdot
.65004 .4685 Mdot
.50165 .4106 Mdot
.09165 .05291 Mdot
.81085 .25227 Mdot
.59552 .54599 Mdot
.49351 .73784 Mdot
.95711 .98969 Mdot
.0996 .53017 Mdot
.51934 .00391 Mdot
.47578 .91683 Mdot
.81798 .53299 Mdot
.81648 .63103 Mdot
.15632 .04726 Mdot
.23883 .25808 Mdot
.13265 .98024 Mdot
.34916 .01331 Mdot
.36261 .47802 Mdot
.84738 .23792 Mdot
.44429 .48476 Mdot
.86202 .69935 Mdot
.99567 .49996 Mdot
.25212 .83101 Mdot
.20743 .91559 Mdot
.45082 .15312 Mdot
.13566 .85399 Mdot
.25795 .91905 Mdot
.076 .8656 Mdot
.92329 .94138 Mdot
.51328 .40423 Mdot
.10128 .70734 Mdot
.1112 .92457 Mdot
.21696 .94741 Mdot
.1841 .46908 Mdot
.91382 .15913 Mdot
.94631 .52121 Mdot
.34347 .0098 Mdot
.88931 .62871 Mdot
.17019 .04166 Mdot
.91444 .79642 Mdot
.28102 .11262 Mdot
.26297 .42943 Mdot
.24429 .47489 Mdot
.24267 .47655 Mdot
.15561 .48896 Mdot
.19603 .97142 Mdot
.19476 .36046 Mdot
.23897 .49669 Mdot
.7637 .30699 Mdot
.32883 .84578 Mdot
.62777 .23936 Mdot
.48664 .0531 Mdot
.34993 .10046 Mdot
.23997 .63758 Mdot
.18579 .6844 Mdot
.0414 .19157 Mdot
.09809 .19921 Mdot
.85028 .20928 Mdot
.97984 .89309 Mdot
.55002 .70882 Mdot
.20426 .55565 Mdot
.22578 .8806 Mdot
.4631 .27964 Mdot
.63755 .86239 Mdot
.16787 .14746 Mdot
.38806 .15892 Mdot
.07051 .48838 Mdot
.35703 .01464 Mdot
.96418 .26186 Mdot
.50094 .78161 Mdot
.11768 .40083 Mdot
.00015 .07019 Mdot
.98035 .84595 Mdot
.73058 .18871 Mdot
.3492 .5485 Mdot
.1177 .34671 Mdot
.25375 .4336 Mdot
.60839 .13614 Mdot
.24486 .9039 Mdot
.23547 .1333 Mdot
.27576 .61745 Mdot
.63195 .34003 Mdot
.27117 .24236 Mdot
.70522 .26381 Mdot
.31447 .43667 Mdot
.00157 .10544 Mdot
.05516 .86558 Mdot
.97932 .77036 Mdot
.71966 .44336 Mdot
.25889 .60503 Mdot
.39286 .56396 Mdot
.16522 .48291 Mdot
.19002 .91685 Mdot
.37964 .0839 Mdot
.93002 .67364 Mdot
.71649 .81008 Mdot
.47341 .27923 Mdot
.78103 .68404 Mdot
.47395 .44193 Mdot
.92498 .94513 Mdot
.866 .97888 Mdot
.56613 .29438 Mdot
.32377 .42376 Mdot
.45441 .85006 Mdot
.23731 .48252 Mdot
.16669 .75152 Mdot
.2955 .76342 Mdot
.31309 .9525 Mdot
.8619 .46 Mdot
.57013 .20863 Mdot
.2949 .02078 Mdot
.73149 .27338 Mdot
.40324 .07657 Mdot
.18079 .96186 Mdot
.16482 .70448 Mdot
.59554 .13011 Mdot
.84595 .23352 Mdot
.45206 .41183 Mdot
.4207 .49512 Mdot
.21437 .48619 Mdot
.63121 .04666 Mdot
.54018 .19998 Mdot
.32969 .97942 Mdot
.8942 .93898 Mdot
.00674 .88549 Mdot
.67616 .97917 Mdot
.84575 .20035 Mdot
.15863 .79346 Mdot
.06921 .94736 Mdot
.52552 .39332 Mdot
.41274 .50584 Mdot
.35067 .96545 Mdot
.85796 .46721 Mdot
.89422 .69496 Mdot
.37748 .53305 Mdot
.09818 .80648 Mdot
.43847 .62405 Mdot
.26003 .8654 Mdot
.64639 .43191 Mdot
.22953 .02711 Mdot
.64163 .48184 Mdot
.55658 .66135 Mdot
.2074 .9827 Mdot
.2059 .71273 Mdot
.30025 .5308 Mdot
.32426 .01172 Mdot
.96017 .01019 Mdot
.33333 .19365 Mdot
.34312 .39126 Mdot
.12233 .37515 Mdot
.71045 .95047 Mdot
.84501 .28859 Mdot
.15264 .43427 Mdot
.22712 .62584 Mdot
.8999 .41982 Mdot
.09259 .90981 Mdot
.48304 .88396 Mdot
.62336 .94496 Mdot
.58901 .88201 Mdot
.27582 .68144 Mdot
.23973 .50153 Mdot
.25884 .35771 Mdot
.43303 .57621 Mdot
.36083 .0319 Mdot
.40939 .14024 Mdot
.22591 .43551 Mdot
.49695 .74865 Mdot
.21887 .48489 Mdot
.0885 .88475 Mdot
.42004 .5522 Mdot
.33598 .02819 Mdot
.20387 .85104 Mdot
.20161 .54039 Mdot
.95074 .53518 Mdot
.56035 .98484 Mdot
.4142 .53279 Mdot
.18341 .78466 Mdot
.31558 .11815 Mdot
.55822 .05029 Mdot
.18799 .68872 Mdot
.55472 .12747 Mdot
.6132 .13303 Mdot
.23766 .08119 Mdot
.40952 .27324 Mdot
.17616 .58882 Mdot
.47171 .72832 Mdot
.41039 .61086 Mdot
.07397 .21943 Mdot
.27521 .85666 Mdot
.69798 .11597 Mdot
.71017 .81928 Mdot
.55073 .38572 Mdot
.19239 .67362 Mdot
.9889 .24548 Mdot
.9821 .55762 Mdot
.44784 .99506 Mdot
.89161 .99689 Mdot
.00995 .21976 Mdot
.33449 .37443 Mdot
.00357 .99865 Mdot
.1486 .52253 Mdot
.22727 .90918 Mdot
.28206 .68701 Mdot
.54748 .52702 Mdot
.21491 .98747 Mdot
.65428 .24007 Mdot
.2417 .48075 Mdot
.17419 .31365 Mdot
.33372 .49162 Mdot
.20026 .02688 Mdot
.05599 .10931 Mdot
.24471 .02286 Mdot
.00737 .60143 Mdot
.05248 .12147 Mdot
.57572 .94874 Mdot
.35379 .59476 Mdot
.37275 .92144 Mdot
.7431 .31588 Mdot
.23068 .47782 Mdot
.56255 .06934 Mdot
.83558 .99186 Mdot
.36908 .02067 Mdot
.84284 .85356 Mdot
.22925 .92939 Mdot
.84703 .23382 Mdot
.20523 .80933 Mdot
.23277 .36537 Mdot
.80524 .21876 Mdot
.79476 .39511 Mdot
.14388 .84858 Mdot
.52814 .01338 Mdot
.41842 .79742 Mdot
.74205 .05856 Mdot
.12946 .80848 Mdot
.9815 .16618 Mdot
.89522 .86638 Mdot
.16194 .91657 Mdot
.60485 .0683 Mdot
.92016 .59256 Mdot
.87432 .84787 Mdot
.13334 .19054 Mdot
.73204 .02536 Mdot
.4811 .1937 Mdot
.28405 .15913 Mdot
.75829 .20362 Mdot
.23717 .4357 Mdot
.80216 .05919 Mdot
.32861 .52795 Mdot
.66357 .11115 Mdot
.75864 .45165 Mdot
.85069 .45008 Mdot
.96129 .62042 Mdot
.72917 .24899 Mdot
.19892 .6496 Mdot
.22915 .0238 Mdot
.91624 .48883 Mdot
.36854 .87899 Mdot
.64278 .1141 Mdot
.57959 .84857 Mdot
.26676 .56355 Mdot
.01256 .75932 Mdot
.51943 .09721 Mdot
.15404 .3004 Mdot
.61218 .44272 Mdot
.34306 .02676 Mdot
.41938 .79554 Mdot
.21847 .93793 Mdot
.56529 .30493 Mdot
.72363 .13127 Mdot
.92059 .21689 Mdot
.15514 .2699 Mdot
.54658 .65 Mdot
.22068 .51561 Mdot
.15416 .56089 Mdot
.10865 .21632 Mdot
.37239 .07724 Mdot
.68281 .18752 Mdot
.9509 .2789 Mdot
.44749 .22818 Mdot
.31042 .97566 Mdot
.72454 .16089 Mdot
.37063 .7281 Mdot
.5683 .91013 Mdot
.7939 .13909 Mdot
.37978 .39748 Mdot
.76773 .5253 Mdot
.34748 .12406 Mdot
.28156 .47129 Mdot
.64573 .99562 Mdot
.36203 .12673 Mdot
.20191 .69488 Mdot
.08562 .18087 Mdot
.39111 .56134 Mdot
.57786 .43329 Mdot
.8689 .65686 Mdot
.81157 .32738 Mdot
.35812 .31091 Mdot
.13946 .80318 Mdot
.06527 .13836 Mdot
.74294 .31651 Mdot
.3299 .16816 Mdot
.33185 .15498 Mdot
.21005 .50732 Mdot
.28679 .98027 Mdot
.64795 .97083 Mdot
.63094 .5455 Mdot
.85163 .24486 Mdot
.85067 .21135 Mdot
.39575 .96682 Mdot
.79905 .37898 Mdot
.3757 .79308 Mdot
.10718 .04257 Mdot
.18735 .59964 Mdot
.6843 .90268 Mdot
.00207 .10207 Mdot
.35111 .9046 Mdot
.28613 .15213 Mdot
.75916 .30203 Mdot
.3455 .95319 Mdot
.92579 .13274 Mdot
.01679 .9746 Mdot
.17793 .72318 Mdot
.46506 .16909 Mdot
.14752 .66868 Mdot
.36741 .57875 Mdot
.29335 .78914 Mdot
.38102 .50648 Mdot
.99929 .90662 Mdot
.20323 .35696 Mdot
.21025 .5672 Mdot
.77195 .3583 Mdot
.24909 .47531 Mdot
.82356 .38761 Mdot
.18751 .73383 Mdot
.30368 .20561 Mdot
.14042 .05882 Mdot
.93606 .60846 Mdot
.74971 .27504 Mdot
.39868 .12503 Mdot
.83091 .38204 Mdot
.24161 .84296 Mdot
.60874 .82878 Mdot
.42028 .4724 Mdot
.34153 .3959 Mdot
.64753 .07817 Mdot
.23597 .61802 Mdot
.32106 .83183 Mdot
.20613 .55582 Mdot
.44359 .16796 Mdot
.36741 .23784 Mdot
.1045 .02115 Mdot
.51567 .87146 Mdot
.77899 .21538 Mdot
.96997 .03787 Mdot
.24963 .75812 Mdot
.45672 .64654 Mdot
.53581 .6989 Mdot
.29202 .01134 Mdot
.2255 .88391 Mdot
.20851 .49573 Mdot
.70421 .69496 Mdot
.73985 .21444 Mdot
.63703 .66036 Mdot
.20661 .40805 Mdot
.91596 .475 Mdot
.24252 .36712 Mdot
.54939 .69927 Mdot
.68965 .65278 Mdot
.07888 .98432 Mdot
.37797 .60926 Mdot
.77762 .14848 Mdot
.30163 .12847 Mdot
.15773 .4262 Mdot
.48836 .95452 Mdot
.33454 .73163 Mdot
.34729 .56635 Mdot
.44977 .27468 Mdot
.17733 .26052 Mdot
.9184 .55706 Mdot
.38154 .57915 Mdot
.9075 .55688 Mdot
.07662 .95108 Mdot
.16972 .4832 Mdot
.69552 .81148 Mdot
.06108 .04675 Mdot
.19942 .86572 Mdot
.59973 .29231 Mdot
.77769 .28317 Mdot
.16915 .0055 Mdot
.60407 .07555 Mdot
.24086 .48145 Mdot
.22854 .49059 Mdot
.30985 .90234 Mdot
.22396 .51123 Mdot
.26391 .44701 Mdot
.41709 .66548 Mdot
.26996 .38896 Mdot
.26226 .83434 Mdot
.64222 .07496 Mdot
.43535 .53114 Mdot
.50803 .03202 Mdot
.9071 .47175 Mdot
.27737 .54375 Mdot
.64337 .04522 Mdot
.01398 .66796 Mdot
.40788 .51476 Mdot
.64665 .23192 Mdot
.1032 .8125 Mdot
.30061 .92114 Mdot
.67028 .03056 Mdot
.63327 .8841 Mdot
.22418 .49018 Mdot
.16902 .84295 Mdot
.29602 .98759 Mdot
.79027 .28459 Mdot
.57914 .0401 Mdot
.89355 .60572 Mdot
.20406 .5249 Mdot
.2304 .43566 Mdot
.17819 .722 Mdot
.87491 .4668 Mdot
.34872 .71667 Mdot
.20803 .59635 Mdot
.22654 .30405 Mdot
.13553 .76823 Mdot
.92133 .25732 Mdot
.2454 .47864 Mdot
.29079 .26748 Mdot
.33626 .83504 Mdot
.1932 .74546 Mdot
.22912 .48313 Mdot
.11683 .01624 Mdot
.31714 .98432 Mdot
.65726 .27261 Mdot
.22007 .42337 Mdot
.38109 .03911 Mdot
.19514 .60547 Mdot
.46134 .74285 Mdot
.88328 .16498 Mdot
.23288 .50341 Mdot
.42413 .33442 Mdot
.13543 .75652 Mdot
.251 .88461 Mdot
.08009 .72503 Mdot
.99572 .90816 Mdot
.29001 .44011 Mdot
.75137 .51537 Mdot
.89925 .39176 Mdot
.55457 .96008 Mdot
.33521 .60547 Mdot
.71177 .77192 Mdot
.18447 .1046 Mdot
.247 .47261 Mdot
.17999 .40949 Mdot
.03803 .56592 Mdot
.18096 .68406 Mdot
.1517 .67511 Mdot
.76793 .25637 Mdot
.32738 .09945 Mdot
.9447 .89733 Mdot
.72235 .19198 Mdot
.45749 .25392 Mdot
.04657 .42698 Mdot
.3399 .11054 Mdot
.70936 .02239 Mdot
.2335 .75524 Mdot
.76349 .3811 Mdot
.18857 .05056 Mdot
.64875 .74744 Mdot
.31876 .82184 Mdot
.3252 .60913 Mdot
.43736 .94015 Mdot
.61312 .41048 Mdot
.08361 .67121 Mdot
.61114 .04714 Mdot
.60693 .51567 Mdot
.96434 .03316 Mdot
.33576 .76157 Mdot
.20386 .60849 Mdot
.2299 .67777 Mdot
.40299 .8837 Mdot
.93154 .88715 Mdot
.14773 .24815 Mdot
.31489 .96464 Mdot
.40375 .81613 Mdot
.33044 .29951 Mdot
.86167 .80937 Mdot
.67333 .76916 Mdot
.98135 .78294 Mdot
.30229 .9924 Mdot
.73173 .17078 Mdot
.12462 .32031 Mdot
.26405 .31106 Mdot
.23082 .47717 Mdot
.20001 .0125 Mdot
.87631 .47943 Mdot
.69959 .20908 Mdot
.44121 .17353 Mdot
.88516 .42673 Mdot
.79463 .39643 Mdot
.03543 .64342 Mdot
.39693 .44548 Mdot
.23403 .49876 Mdot
.36109 .08276 Mdot
.97207 .19038 Mdot
.20717 .65199 Mdot
.78039 .1829 Mdot
.33849 .14944 Mdot
.1588 .90723 Mdot
.90783 .99716 Mdot
.23267 .51285 Mdot
.18074 .57159 Mdot
.24107 .8687 Mdot
.60037 .1308 Mdot
.09903 .38804 Mdot
.24436 .00489 Mdot
.1127 .1728 Mdot
.09028 .37118 Mdot
.28921 .00633 Mdot
.66851 .17327 Mdot
.21806 .06397 Mdot
.80261 .21654 Mdot
.01216 .58179 Mdot
.70951 .62819 Mdot
.66875 .71944 Mdot
.19867 .51254 Mdot
.67805 .31171 Mdot
.90329 .47065 Mdot
.57843 .14198 Mdot
.86486 .12355 Mdot
.32008 .10995 Mdot
.21006 .89783 Mdot
.17402 .01115 Mdot
.32288 .69331 Mdot
.21815 .48102 Mdot
.61922 .09223 Mdot
.40517 .70303 Mdot
.45936 .58026 Mdot
.79464 .3598 Mdot
.63908 .12427 Mdot
.21395 .23274 Mdot
.80903 .05535 Mdot
.89844 .11114 Mdot
.60436 .11106 Mdot
.72145 .09064 Mdot
.25101 .44642 Mdot
.49171 .6084 Mdot
.58436 .30305 Mdot
.17009 .86089 Mdot
.14093 .75683 Mdot
.27784 .49535 Mdot
.35361 .61048 Mdot
.17138 .27983 Mdot
.49663 .61326 Mdot
.27878 .15299 Mdot
.99903 .50588 Mdot
.4629 .11868 Mdot
.66675 .12037 Mdot
.9715 .52464 Mdot
.16292 .7761 Mdot
.85465 .62083 Mdot
.099 .01175 Mdot
.43763 .14189 Mdot
.62738 .37654 Mdot
.29366 .90978 Mdot
.13752 .79892 Mdot
.16548 .7297 Mdot
.1502 .30916 Mdot
.4817 .59995 Mdot
.36799 .15774 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool00oooool2o`0000Sooooo00?o0000ooooooooool03Oooool2o`0000oo
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`03ooooo`;o00002Oooool00ol0003oooooooooo`0:ooooo`;o000000?oooooo`000?ooool0
2_ooool2o`0000;ooooo00?o0000ooooooooool00_l0000;ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo
0_l00008ooooo`03o`000?oooooooooo00gooooo0_l0000?ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool00_ooool001kooooo00?o0000ooooooooool0<oooool2o`0001Kooooo0_l0
000=ooooo`;o00001Oooool2o`0000Wooooo0_l00036ooooo`;o00004Oooool001kooooo00?o0000
ooooooooool07?ooool2o`0001Kooooo0_l00003ooooo`;o00000_ooool2o`0001cooooo0_l00008
ooooo`;o00001Oooool3o`0003Wooooo0_l0002:ooooo`;o00004Oooool001kooooo00?o0000oooo
ooooool07?ooool4o`0000;ooooo0_l0000@ooooo`;o00000oooool2o`0000;ooooo0_l0000Loooo
o`;o00002?ooool2o`0000Kooooo0_l000000ooooooo0000o`00000fooooo`;o0000WOooool001ko
oooo00?o0000ooooooooool02Oooool2o`0001?ooooo0_l00002ooooo`;o0000>?ooool2o`0001;o
oooo0_l0000`ooooo`;o0000Xoooool001kooooo00?o0000ooooooooool02Oooool2o`0001?ooooo
0_l0000[ooooo`;o00001Oooool2o`0000Sooooo0_l0000Fooooo`;o0000;?ooool2o`0003oooooo
0_l0000:ooooo`;o0000E_ooool001kooooo00?o0000ooooooooool01_ooool2o`0001Kooooo0_l0
000Vooooo`;o00000oooool2o`0000Gooooo0_l00008ooooo`;o00005_ooool2o`0006gooooo0_l0
0005ooooo`;o00000oooool2o`0005Kooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l0000@
ooooo`;o00008oooool2o`0000Gooooo1Ol0000Pooooo`Ko0000Noooool2o`0005_ooooo000Noooo
o`03o`000?oooooooooo01Sooooo0_l0000Sooooo`;o00001Oooool2o`000003ooooool0003o0000
023ooooo1_l00002ooooo`;o0000;_ooool2o`0003?ooooo0_l0001_ooooo`007_ooool00ol0003o
ooooooooo`1aooooo`;o00001_ooool2o`0002Kooooo0_l0000cooooo`;o0000GOooool2o`00013o
oooo000Nooooo`03o`000?oooooooooo02Sooooo0_l0000jooooo`;o00004oooool2o`000;[ooooo
1?l0000>ooooo`007_ooool00ol0003oooooooooo`0Xooooo`;o0000>_ooool2o`0000Sooooo0_l0
0008ooooo`;o0000;oooool2o`0000gooooo0_l0001mooooo`;o00003_ooool001kooooo00?o0000
ooooooooool07oooool2o`0001;ooooo0_l0000iooooo`;o00002?ooool2o`0002oooooo0_l0000=
ooooo`;o0000>Oooool2o`00027ooooo0_l0000_ooooo`007_ooool00ol0003oooooooooo`0@oooo
o`;o00003Oooool2o`0000kooooo0_l00002ooooo`;o00006?ooool2o`0005Oooooo0_l0000Doooo
o`;o00001Oooool2o`0000Cooooo0_l00002ooooo`;o00009?ooool2o`00027ooooo0_l0000_oooo
o`007_ooool00ol0003oooooooooo`0@ooooo`;o00007Oooool2o`0000Sooooo0_l0000Booooo`;o
00001_ooool2o`0000_ooooo0_l00012ooooo`;o00002Oooool2o`0000Wooooo0_l00005ooooo`;o
00001?ooool2o`0000;ooooo0_l0001hooooo`007_ooool2o`0001_ooooo0_l0000Mooooo`;o0000
6_ooool2o`0000_ooooo0_l0000fooooo`;o00005Oooool2o`0009Cooooo000Nooooo`03o`000?oo
oooooooo01[ooooo0_l0001Hooooo`;o00009?ooool2o`0006Oooooo0_l00012ooooo`007_ooool0
0ol0003oooooooooo`0Zooooo`;o0000B?ooool2o`0000_ooooo0_l00019ooooo`;o00007oooool2
o`0001;ooooo1?l00012ooooo`007_ooool00ol0003oooooooooo`0Zooooo`;o00001Oooool2o`00
04kooooo0_l00019ooooo`;o00007oooool2o`0001;ooooo0_l00014ooooo`007_ooool00ol0003o
ooooooooo`0aooooo`;o00004?ooool2o`000?oooooo0oooool001kooooo00?o0000ooooooooool0
@oooool2o`0002Kooooo0_l0000;ooooo`;o0000Aoooool4o`0008;ooooo000Mooooo`;o0000KOoo
ool2o`0000_ooooo0_l0000iooooo`;o00003?ooool4o`0008;ooooo000Mooooo`;o0000>?ooool2
o`0003Gooooo0_l00014ooooo`;o00006?ooool2o`0007Sooooo000Nooooo`03o`000?oooooooooo
03Kooooo0_l0000eooooo`;o00001_ooool2o`0000Sooooo0_l0000oooooo`;o00002oooool3o`00
07Oooooo000Nooooo`03o`000?oooooooooo04Wooooo0_l0000Vooooo`;o00000_ooool2o`0000So
oooo0_l0000oooooo`;o00003?ooool2o`0007Oooooo000Nooooo`03o`000?oooooooooo04Wooooo
0_l0000Vooooo`;o00001?ooool2o`000<kooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0
001Mooooo`;o00001?ooool2o`0000Sooooo0_l0002Dooooo`;o0000;_ooool001kooooo00?o0000
ooooooooool04_ooool2o`0005gooooo0_l0000>ooooo`;o0000G?ooool2o`0003Kooooo0_l0000^
ooooo`007_ooool00ol0003oooooooooo`24ooooo`;o0000?oooool2o`0001Sooooo0_l00005oooo
o`;o0000Eoooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo06Gooooo0_l0000Mooooo`;o
00001Oooool2o`0002gooooo0_l00009ooooo`;o00007oooool2o`0005Oooooo0_l00006ooooo`00
7_ooool00ol0003oooooooooo`1Uooooo`?o00008oooool2o`0001Sooooo0_l0000Cooooo`;o0000
Roooool001kooooo0_l0000Pooooo`;o0000AOooool2o`0000Kooooo0_l00002ooooo`;o0000<Ooo
ool2o`0001[ooooo0_l0000=ooooo`;o0000MOooool001gooooo0ol0000Pooooo`;o00001_ooool2
o`0000oooooo0_l0000Kooooo`;o00005oooool2o`0000;ooooo0_l0001=ooooo`;o00003Oooool2
o`0000Kooooo0_l0001]ooooo`007Oooool2o`0002Wooooo0_l0000?ooooo`;o00006oooool2o`00
07?ooooo0_l0000<ooooo`;o0000FOooool2o`0001;ooooo000Nooooo`03o`000?oooooooooo00ko
oooo0_l0001Dooooo`;o00000_ooool4o`0000_ooooo0_l00017ooooo`;o00002?ooool2o`0000So
oooo0_l0001:ooooo`;o00004Oooool2o`0001;ooooo000Nooooo`03o`000?oooooooooo00kooooo
0_l00017ooooo`;o00002oooool2o`0000;ooooo1?l0000;ooooo`;o0000Aoooool2o`0000_ooooo
0_l00005ooooo`;o0000B_ooool2o`0002Gooooo000Nooooo`03o`000?oooooooooo01_ooooo0_l0
000<ooooo`;o0000;?ooool2o`0000Wooooo0_l0001Yooooo`;o00004?ooool2o`0006Kooooo000N
ooooo`03o`000?oooooooooo01_ooooo0_l0000<ooooo`;o0000=oooool2o`0000Sooooo0_l0000T
ooooo`;o0000@Oooool2o`0000Sooooo0_l0001Vooooo`007_ooool00ol0003oooooooooo`0=oooo
o`;o0000GOooool3o`0002?ooooo0_l0000Booooo`;o00008oooool3o`0000Oooooo0_l0000noooo
o`;o0000<?ooool001kooooo00?o0000ooooooooool01_ooool2o`0000Gooooo0_l00016ooooo`;o
00005_ooool2o`0000?ooooo0_l00009ooooo`;o00009oooool2o`0000Sooooo0_l0000Iooooo`?o
0000Aoooool2o`000003ooooool0003o000002gooooo000Nooooo`03o`000?oooooooooo00Kooooo
0_l0001=ooooo`;o00001oooool2o`0001;ooooo0_l00009ooooo`;o00008?ooool2o`0000oooooo
0_l0000<ooooo`;o00001?ooool2o`0005;ooooo0_l0000Mooooo`;o00003_ooool001kooooo00?o
0000ooooooooool0B?ooool2o`0001Cooooo0_l0000Mooooo`;o00008?ooool2o`0001gooooo0ol0
0002ooooo`?o00008Oooool2o`00043ooooo0_l0000<ooooo`;o00003_ooool001kooooo00?o0000
ooooooooool0B?ooool2o`00027ooooo0_l00004ooooo`;o00002_ooool2o`00043ooooo0_l00000
1?oooooo0000o`000?l00009ooooo`;o00002oooool2o`0000[ooooo0_l00010ooooo`;o00007?oo
ool001kooooo00?o0000ooooooooool04Oooool2o`0005Sooooo0_l00004ooooo`;o00009Oooool2
o`0002Sooooo0_l0000:ooooo`;o00002oooool2o`00027ooooo0_l00017ooooo`007_ooool00ol0
003oooooooooo`0Aooooo`;o0000K_ooool2o`0000Oooooo0_l0000<ooooo`;o00007_ooool2o`00
04Cooooo0_l00017ooooo`007_ooool00ol0003oooooooooo`21ooooo`;o00001oooool2o`0002co
oooo0_l0002=ooooo`007_ooool00ol0003oooooooooo`0booooo`;o0000aOooool2o`0000cooooo
0_l0000nooooo`007_ooool2o`0003?ooooo0_l0000Uooooo`;o000000?oooooo`000?l000003?oo
ool2o`0003Kooooo0_l0001Eooooo`;o00003?ooool2o`0002Kooooo0_l0000Fooooo`007_ooool0
0ol0003oooooooooo`1Gooooo`Co000000?oooooo`000?l000002_ooool4o`0002;ooooo0_l0000B
ooooo`;o0000Roooool2o`0001Kooooo000Nooooo`03o`000?oooooooooo01Gooooo0_l00010oooo
o`;o00003oooool2o`0000[ooooo0_l0000Hooooo`;o0000]oooool001kooooo00?o0000oooooooo
ool05Oooool2o`00047ooooo0_l0000Jooooo`;o00001?ooool2o`0006_ooooo0_l0000looooo`;o
00008?ooool001kooooo00?o0000ooooooooool0F?ooool2o`00023ooooo0_l0001[ooooo`;o0000
??ooool2o`00023ooooo000Nooooo`03o`000?oooooooooo0;kooooo0_l0001Kooooo`;o00007_oo
ool2o`0000[ooooo000Nooooo`03o`000?oooooooooo06Oooooo0_l0000Sooooo`;o00001Oooool2
o`0002Wooooo0_l0000Yooooo`;o0000<?ooool2o`0000Gooooo0_l0000Gooooo`;o00002_ooool0
01kooooo00?o0000ooooooooool08Oooool2o`0004Cooooo0_l0000Rooooo`?o00001Oooool2o`00
043ooooo0_l0000Booooo`?o0000=_ooool2o`0002?ooooo000Nooooo`03o`000?oooooooooo027o
oooo0_l0001Xooooo`;o00003?ooool2o`0003[ooooo0_l0000Cooooo`;o0000Foooool001kooooo
00?o0000ooooooooool0VOooool2o`0004oooooo0_l0001Kooooo`007_ooool00ol0003ooooooooo
o`0Hooooo`;o0000h?ooool2o`0004_ooooo000Nooooo`03o`000?oooooooooo01Sooooo0_l0003P
ooooo`;o0000Boooool001kooooo00?o0000ooooooooool0f_ooool2o`0000gooooo0_l0001Loooo
o`007_ooool00ol0003oooooooooo`09ooooo`;o00007?ooool2o`0003cooooo0_l0001cooooo`;o
00000oooool2o`0000Kooooo1?l0000^ooooo`;o00007Oooool2o`0000gooooo0003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo00Wo
oooo0_l0000Looooo`;o0000??ooool2o`000004ooooool0003o0000o`0002gooooo0_l00015oooo
o`;o00001_ooool2o`00033ooooo0ol0000Looooo`;o00003Oooool000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000
ooooooooool0J?ooool3o`0002gooooo0_l0000<ooooo`;o0000L_ooool3o`0002[ooooo0003oooo
o`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`?o00007?ooool2
o`0008Sooooo0_l00004ooooo`;o0000HOooool2o`0000[ooooo0_l0000Zooooo`000oooool01Ol0
003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`0L
ooooo`;o0000S_ooool2o`0004Cooooo0_l0000Kooooo`;o0000;_ooool2o`0000Kooooo0003oooo
o`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooo
oooo05oooooo0_l0002Aooooo`;o0000Boooool2o`0000Kooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05oooooo0_l0000k
ooooo`;o00005oooool2o`0002Sooooo0_l0000_ooooo`;o0000=Oooool000?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003ooooooooo
o`0Yooooo`;o00002Oooool2o`0001_ooooo0_l00019ooooo`;o00005oooool2o`0002Sooooo0_l0
000;ooooo`;o00008_ooool2o`0003Gooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool07oooool2o`0000Sooooo
0ol00008ooooo`?o00006_ooool2o`0000kooooo0_l00008ooooo`;o0000G_ooool2o`0001oooooo
0_l0000;ooooo`;o00001_ooool2o`0000gooooo0_l0000eooooo`007_ooool01?l0003oooooo`00
0?l00002ooooo`;o00003oooool2o`0000Wooooo0_l00009ooooo`;o00002Oooool2o`0002[ooooo
0_l00008ooooo`;o0000G_ooool2o`0001oooooo0_l00006ooooo`;o00000oooool2o`0000Kooooo
0ol0000Sooooo`;o00007_ooool001kooooo00Co0000ooooool0003o00000_ooool2o`0000oooooo
0_l0003Nooooo`;o00003?ooool2o`0002?ooooo0_l0000Nooooo`007_ooool00ol0003ooooooooo
o`0`ooooo`;o00006Oooool2o`000=Gooooo0_l0000Sooooo`007_ooool00ol0003oooooooooo`05
ooooo`;o0000:Oooool2o`0001Wooooo0_l00010ooooo`;o0000Toooool2o`0002?ooooo000Noooo
o`03o`000?oooooooooo00Gooooo0_l00026ooooo`;o0000?oooool2o`0002kooooo0_l00017oooo
o`007_ooool00ol0003oooooooooo`11ooooo`;o00000oooool2o`0008Kooooo0_l0000^ooooo`;o
00003oooool2o`0003Kooooo000Nooooo`03o`000?oooooooooo047ooooo0_l00003ooooo`;o0000
:oooool2o`0007cooooo0_l0000Looooo`;o0000=_ooool001kooooo00?o0000ooooooooool0Looo
ool2o`0005?ooooo0_l00007ooooo`;o00007_ooool2o`0001cooooo0_l0000fooooo`007_ooool0
0ol0003oooooooooo`1Dooooo`;o0000L_ooool2o`0000Oooooo0_l0000/ooooo`;o0000A_ooool0
01kooooo00?o0000ooooooooool0E?ooool2o`0008_ooooo0_l0000Looooo`;o00004?ooool2o`00
02[ooooo0_l00008ooooo`007_ooool00ol0003oooooooooo`0/ooooo`;o0000HOooool2o`0004co
oooo0_l00002ooooo`;o00001_ooool2o`0002Kooooo0_l0000Zooooo`;o00002?ooool001kooooo
0_l0000]ooooo`;o0000HOooool2o`0004cooooo0_l0000:ooooo`;o00006Oooool2o`00047ooooo
000Nooooo`03o`000?oooooooooo097ooooo0_l0001Hooooo`;o00002Oooool2o`0000cooooo0_l0
0011ooooo`007_ooool00ol0003oooooooooo`1:ooooo`;o0000AOooool2o`0005Sooooo0_l00009
ooooo`;o0000;oooool2o`0001kooooo000Nooooo`03o`000?oooooooooo03Kooooo0_l0000Boooo
o`;o00009?ooool2o`000;Gooooo0_l0000<ooooo`;o00004?ooool001kooooo00?o0000oooooooo
ool0=_ooool2o`0003Sooooo0_l0001_ooooo`;o0000D_ooool2o`00013ooooo000Nooooo`03o`00
0?oooooooooo05[ooooo0_l0000Cooooo`;o0000L?ooool2o`0006Cooooo000Nooooo`03o`000?oo
oooooooo02kooooo0_l0000Zooooo`;o00004oooool2o`0002Oooooo0_l0001iooooo`;o0000<_oo
ool001kooooo00?o0000ooooooooool0;_ooool2o`00057ooooo0_l0000;ooooo`;o00002?ooool2
o`0003Sooooo0_l0000Fooooo`;o00001?ooool2o`0000gooooo0_l0000?ooooo`;o000000?ooooo
o`000?l00000<_ooool001kooooo00?o0000ooooooooool0:_ooool2o`0005Gooooo0_l0000;oooo
o`;o0000@_ooool2o`0001Kooooo0_l00004ooooo`;o00003Oooool2o`0000oooooo0_l0000eoooo
o`007_ooool00ol0003oooooooooo`0Zooooo`;o00002?ooool2o`00053ooooo0_l0000:ooooo`;o
00000_ooool2o`0009Wooooo0_l0000Dooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o0000
4_ooool2o`00013ooooo0_l0001@ooooo`;o00002_ooool2o`0000;ooooo0_l0001Nooooo`;o0000
00?oooooo`000?l00000=_ooool2o`0001Cooooo000Nooooo`03o`000?oooooooooo00kooooo0ol0
000Aooooo`;o0000:oooool2o`000:Gooooo0_l000000ooooooo0000o`000002ooooo`;o0000B?oo
ool001kooooo00?o0000ooooooooool03oooool2o`0003kooooo0_l0002/ooooo`;o00004?ooool2
o`0003Kooooo000Nooooo`03o`000?oooooooooo0;oooooo0_l0001>ooooo`;o0000:Oooool2o`00
00_ooooo000Nooooo`03o`000?oooooooooo0;Cooooo0_l00009ooooo`;o0000NOooool2o`0000_o
oooo000Nooooo`03o`000?oooooooooo00_ooooo0_l0001Jooooo`;o0000Boooool2o`0003kooooo
0_l0001Aooooo`007_ooool2o`0000cooooo0_l00002ooooo`;o00007Oooool2o`0000Gooooo0_l0
000`ooooo`;o0000R_ooool3o`00057ooooo000Nooooo`03o`000?oooooooooo00oooooo0_l0000M
ooooo`;o00001Oooool2o`0000oooooo0_l0001/ooooo`;o00001?ooool2o`0003Oooooo0_l0001B
ooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o0000:oooool2o`0006cooooo0_l00004oooo
o`;o0000>?ooool2o`00017ooooo0_l0000nooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o
00004_ooool2o`0000;ooooo0_l0000Oooooo`;o00007?ooool2o`0006Kooooo0_l0000Jooooo`;o
00004Oooool2o`0003kooooo000Nooooo`03o`000?oooooooooo02gooooo0_l00002ooooo`;o0000
0_ooool2o`0001_ooooo0_l0000Looooo`;o0000I_ooool2o`0001Wooooo0_l0001Booooo`007_oo
ool00ol0003oooooooooo`0eooooo`;o0000]_ooool2o`0000Cooooo0_l0001Booooo`007_ooool0
0ol0003oooooooooo`0Tooooo`;o0000TOooool2o`0001_ooooo0_l0000Gooooo`;o0000F?ooool0
01kooooo00?o0000ooooooooool09?ooool2o`00097ooooo0_l0000Kooooo`;o0000LOooool001ko
oooo00?o0000ooooooooool0R?ooool2o`0007[ooooo0_l00011ooooo`007_ooool00ol0003ooooo
ooooo`27ooooo`?o0000N_ooool2o`00027ooooo0_l0000Nooooo`007_ooool00ol0003ooooooooo
o`27ooooo`;o00002_ooool2o`0009;ooooo0_l0000Nooooo`007_ooool00ol0003oooooooooo`26
ooooo`;o00002oooool2o`000;;ooooo000Nooooo`03o`000?oooooooooo08Kooooo0_l0002ooooo
o`007_ooool00ol0003oooooooooo`39ooooo`;o0000O?ooool001kooooo00?o0000ooooooooool0
F?ooool2o`0003kooooo0_l0000_ooooo`;o00008Oooool2o`0003cooooo0_l0000Kooooo`007_oo
ool00ol0003oooooooooo`0Rooooo`;o00003?ooool2o`0002Kooooo0_l0000Tooooo`;o00006?oo
ool2o`0005;ooooo0_l00004ooooo`;o0000=_ooool2o`0001_ooooo000Nooooo`;o00008oooool2
o`0000cooooo0_l00002ooooo`;o0000B?ooool2o`0007;ooooo0_l0001Cooooo`007_ooool00ol0
003oooooooooo`0dooooo`;o0000oooooolBooooo`007_ooool00ol0003oooooooooo`0nooooo`;o
00004?ooool2o`000?Gooooo000Nooooo`03o`000?oooooooooo03_ooooo0_l000000ooooooo0000
o`00000@ooooo`;o0000YOooool2o`0000Gooooo0_l00017ooooo`007_ooool00ol0003ooooooooo
o`0kooooo`;o0000^_ooool2o`0000Gooooo0_l00017ooooo`007_ooool00ol0003oooooooooo`18
ooooo`;o000000?oooooo`000?l00000n_ooool001kooooo00?o0000ooooooooool0B?ooool2o`00
0003ooooool0003o000009Oooooo0_l0001Qooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o
0000bOooool2o`0000Kooooo0_l00012ooooo`;o00005Oooool001kooooo00?o0000ooooooooool0
5Oooool2o`0000;ooooo0_l00009ooooo`;o0000=_ooool2o`0000_ooooo0_l0001Mooooo`;o0000
8_ooool2o`0004;ooooo0_l0000Eooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o00003Ooo
ool2o`0003Kooooo0_l0000;ooooo`;o0000GOooool2o`0003Kooooo0_l00015ooooo`007_ooool0
0ol0003oooooooooo`1Dooooo`;o0000W_ooool2o`0000[ooooo0_l00008ooooo`;o0000>oooool0
01kooooo00?o0000ooooooooool0E?ooool2o`00027ooooo0_l0000fooooo`;o0000@oooool2o`00
01Cooooo0_l0000kooooo`007_ooool00ol0003oooooooooo`0Looooo`;o0000=_ooool2o`00027o
oooo0_l0000fooooo`;o0000Eoooool2o`0003gooooo000Nooooo`03o`000?oooooooooo01cooooo
0_l0000Hooooo`;o00007?ooool2o`0000cooooo0_l00007ooooo`;o0000UOooool2o`0000Cooooo
0_l0000Fooooo`;o00009Oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0=_ooool2o`0002Cooooo
0_l00004ooooo`;o00001oooool2o`0003[ooooo0_l0001Eooooo`;o00000_ooool2o`0001cooooo
0_l0000Uooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0G?ooool2o`0000gooooo0_l0000:ooooo`;o0000
;_ooool2o`0005Gooooo0ol00016ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo
1Ol00006ooooo`?o00008_ooool2o`0004Oooooo0_l0000:ooooo`;o0000A_ooool2o`0003gooooo
0ol00016ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo
00001oooool00ol0003oooooooooo`08ooooo`;o00006?ooool2o`0007oooooo0_l0000Jooooo`;o
0000Q_ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`00
00Oooooo00?o0000ooooooooool02?ooool2o`0008gooooo0_l0000:ooooo`;o0000X_ooool000?o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0=_ooool2o`0000Oooooo0_l0001Fooooo`;o0000:_ooool2o`0006Gooooo0_l0000Koooo
o`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0
003oooooooooo`0fooooo`;o00001oooool2o`0004kooooo0_l0000>ooooo`;o00008_ooool2o`00
06Gooooo0_l0000Kooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`00
0?ooool01_ooool00ol0003oooooooooo`1Tooooo`;o00003oooool2o`0001Sooooo0_l0000>oooo
o`;o0000Y_ooool001kooooo00?o0000ooooooooool0A_ooool2o`0001cooooo0_l00003ooooo`;o
00002_ooool2o`000=3ooooo000Nooooo`03o`000?oooooooooo04Kooooo0_l0000Qooooo`;o0000
Y?ooool2o`0000oooooo0_l0000Uooooo`007_ooool00ol0003oooooooooo`0looooo`;o00001Ooo
ool2o`000003ooooool0003o000000gooooo0_l0000>ooooo`;o0000Z?ooool2o`0000oooooo0_l0
000Uooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o00008_ooool2o`0000_ooooo0_l00005
ooooo`;o000000?oooooo`000?l000003Oooool2o`0000kooooo0_l0002eooooo`;o0000:Oooool0
01kooooo00?o0000ooooooooool02oooool2o`0002;ooooo0_l0000Pooooo`;o0000Noooool2o`00
02Cooooo0_l0000Vooooo`;o0000:Oooool001kooooo00?o0000ooooooooool0:?ooool2o`0000Co
oooo0_l0000Nooooo`;o000000?oooooo`000?l00000IOooool2o`0001Cooooo0_l0000Tooooo`;o
0000DOooool001kooooo00?o0000ooooooooool0:?ooool2o`0000Cooooo0_l0000Eooooo`Ko0000
0oooool2o`0001;ooooo0_l0001Dooooo`;o0000SOooool001kooooo00?o0000ooooooooool0AOoo
ool6o`0000oooooo0_l00006ooooo`;o0000hoooool001kooooo00?o0000ooooooooool0F_ooool2
o`0002;ooooo0_l00004ooooo`;o00004?ooool2o`0002_ooooo0_l0000Qooooo`;o0000Goooool0
01kooooo00?o0000ooooooooool0COooool2o`0000?ooooo0_l0000Dooooo`;o00004oooool3o`00
00Cooooo0_l0000@ooooo`;o0000:oooool2o`00027ooooo0_l0001Oooooo`007_ooool00ol0003o
ooooooooo`1=ooooo`;o00000oooool2o`0001Cooooo0_l0000Cooooo`;o00000oooool2o`0008co
oooo0_l0000eooooo`007_ooool2o`0008?ooooo0_l00018ooooo`;o00009Oooool2o`0001_ooooo
0_l0000eooooo`007_ooool00ol0003oooooooooo`1:ooooo`;o0000P?ooool2o`0002Gooooo0_l0
001Booooo`007_ooool00ol0003oooooooooo`1:ooooo`;o0000mOooool2o`0000Cooooo000Noooo
o`03o`000?oooooooooo06?ooooo0_l0002_ooooo`;o0000:oooool2o`0000Cooooo000Nooooo`03
o`000?oooooooooo04Cooooo0_l00004ooooo`;o00005oooool2o`000:oooooo0_l0000aooooo`00
7_ooool00ol0003oooooooooo`14ooooo`;o00001?ooool2o`0002oooooo0_l0001Booooo`;o0000
@_ooool2o`0000?ooooo0_l0000]ooooo`007_ooool00ol0003oooooooooo`0hooooo`;o00007Ooo
ool2o`0002;ooooo0_l0001Booooo`;o00001_ooool2o`0003[ooooo0_l00003ooooo`;o00002?oo
ool3o`0002;ooooo000Nooooo`03o`000?oooooooooo03Sooooo0_l00008ooooo`;o00001oooool3
o`0000Wooooo0_l0000/ooooo`;o0000D?ooool2o`0004Wooooo0ol000000ooooooo0000o`00000O
ooooo`007_ooool00ol0003oooooooooo`12ooooo`;o00000oooool2o`000003ooooool0003o0000
00?o00008oooool2o`0000Kooooo0_l00009ooooo`;o0000Woooool2o`0001oooooo000Nooooo`03
o`000?oooooooooo04?ooooo0_l00002ooooo`;o000000?oooooo`000?l000001?l0000Rooooo`;o
00001_ooool2o`0009cooooo0ol0000/ooooo`007_ooool00ol0003oooooooooo`0booooo`?o0000
3?ooool4o`000004ooooool0003o0000ooooo`Oo00002oooool2o`0006oooooo0_l0001:ooooo`?o
0000;?ooool001kooooo00?o0000ooooooooool0<_ooool3o`0000cooooo1?l000001?oooooo0000
o`000?ooool3o`0000oooooo0_l0000_ooooo`;o0000?_ooool2o`0007Wooooo000Nooooo`03o`00
0?oooooooooo01?ooooo0_l0000Iooooo`;o00004_ooool5o`0004Gooooo0_l0002Hooooo`;o0000
7oooool001kooooo00?o0000ooooooooool04oooool2o`0001Wooooo0_l0000Eooooo`?o00008?oo
ool2o`000;cooooo0_l0000>ooooo`;o00003oooool001kooooo00?o0000ooooooooool0@?ooool2
o`0000Cooooo0_l0000>ooooo`;o00004?ooool2o`0001_ooooo0_l00023ooooo`;o00004_ooool2
o`0001Kooooo0_l0000?ooooo`007_ooool00ol0003oooooooooo`10ooooo`;o00001_ooool4o`00
00[ooooo0_l0000]ooooo`;o0000Poooool2o`0001;ooooo0ol0000Jooooo`;o00002_ooool001ko
oooo0_l00019ooooo`Co0000doooool2o`0001[ooooo0_l00003ooooo`;o00001Oooool001kooooo
00?o0000ooooooooool0B?ooool5o`00037ooooo0_l00002ooooo`;o00000_ooool2o`0008Oooooo
0_l0000@ooooo`;o00004_ooool2o`0000Wooooo0_l00005ooooo`007_ooool00ol0003ooooooooo
o`10ooooo`;o00001_ooool2o`000003ooooool0003o000002_ooooo0_l00004ooooo`;o00000_oo
ool2o`0000;ooooo0_l00027ooooo`;o00004?ooool2o`0001;ooooo0_l0000:ooooo`;o00001?oo
ool001kooooo00?o0000ooooooooool0@?ooool2o`0000;ooooo0ol0000aooooo`;o0000^Oooool2
o`0000cooooo0_l00004ooooo`007_ooool00ol0003oooooooooo`0hooooo`;o00000_ooool2o`00
00Kooooo0ol000000ooooooo0000o`00000fooooo`;o0000/Oooool2o`0001;ooooo000Nooooo`03
o`000?oooooooooo03Sooooo0_l00002ooooo`;o00001_ooool2o`0000;ooooo0_l00003ooooo`;o
0000<Oooool2o`0003oooooo0_l0000]ooooo`;o0000EOooool001kooooo00?o0000ooooooooool0
A?ooool2o`0000Oooooo0_l0000Fooooo`;o0000F_ooool2o`0000_ooooo0_l0000Pooooo`;o0000
?_ooool2o`0001Gooooo000Nooooo`03o`000?oooooooooo02cooooo0_l0000gooooo`;o0000Iooo
ool2o`00063ooooo0_l0000Eooooo`007_ooool00ol0003oooooooooo`0/ooooo`;o00004?ooool2
o`0003[ooooo0_l0000booooo`;o0000AOooool2o`00047ooooo0_l0000=ooooo`007_ooool00ol0
003oooooooooo`0Looooo`;o00008?ooool2o`0002Oooooo0_l00002ooooo`;o00003Oooool2o`00
00Gooooo0_l0000[ooooo`;o0000AOooool2o`00047ooooo0_l0000=ooooo`007_ooool00ol0003o
ooooooooo`0Looooo`;o00009Oooool2o`0001Sooooo0_l00008ooooo`;o00000_ooool2o`0000[o
oooo0_l00008ooooo`Co00001?ooool2o`0007_ooooo0_l0000Qooooo`;o00007?ooool001kooooo
00?o0000ooooooooool0@Oooool4o`0000?ooooo0_l00004ooooo`;o00003Oooool2o`0001Sooooo
0_l00008ooooo`Co00001?ooool2o`0007_ooooo0_l0000Qooooo`;o00001_ooool2o`0001Cooooo
000Nooooo`03o`000?oooooooooo03_ooooo0_l00004ooooo`;o00001Oooool2o`0000Cooooo0_l0
000aooooo`;o0000L_ooool2o`0003[ooooo0_l0000Dooooo`007_ooool00ol0003oooooooooo`0k
ooooo`Co0000NOooool2o`0003_ooooo0_l0001@ooooo`007_ooool00ol0003oooooooooo`0moooo
o`;o00005oooool2o`0002;ooooo0_l0000looooo`;o00003oooool2o`0001Oooooo0_l0001Soooo
o`007_ooool00ol0003oooooooooo`1Fooooo`;o00005Oooool2o`0000Cooooo0_l00005ooooo`;o
00004oooool2o`0002cooooo0_l0000:ooooo`;o00005oooool2o`0002_ooooo0_l0000Gooooo`;o
00001?ooool2o`0001Oooooo000Nooooo`;o0000A?ooool2o`0002Sooooo0_l00004ooooo`;o0000
2oooool2o`0000gooooo0_l0000/ooooo`;o0000D?ooool2o`0000Wooooo0_l0000<ooooo`;o0000
1?ooool2o`0001Oooooo000Nooooo`03o`000?oooooooooo04?ooooo0_l0000kooooo`;o00000_oo
ool2o`0009Cooooo0_l0000[ooooo`007_ooool00ol0003oooooooooo`0^ooooo`;o00003_ooool3
o`0004?ooooo0_l0002Mooooo`;o000000?oooooo`000?l000004oooool2o`0000[ooooo000Noooo
o`03o`000?oooooooooo02kooooo0_l0000>ooooo`?o0000h_ooool2o`000003ooooool0003o0000
01?ooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0^ooooo`;o00008oooool2o`00023o
oooo0_l00004ooooo`?o0000bOooool001kooooo00?o0000ooooooooool02?ooool2o`0003Kooooo
0_l00002ooooo`;o00003Oooool2o`0001Sooooo0_l00006ooooo`;o00001?ooool3o`000<Wooooo
000Nooooo`03o`000?oooooooooo00Sooooo0_l0000fooooo`;o00000_ooool2o`0001cooooo0_l0
0009ooooo`;o0000_Oooool2o`0001Wooooo000Nooooo`03o`000?oooooooooo03Oooooo0_l0000Y
ooooo`;o0000b?ooool2o`0001Wooooo000Nooooo`03o`000?oooooooooo03Oooooo0_l0001@oooo
o`;o0000YOooool2o`0001Gooooo000Nooooo`03o`000?oooooooooo03oooooo0_l0000Dooooo`;o
00007?ooool2o`0000?ooooo0_l0000?ooooo`;o0000VOooool2o`0000[ooooo0_l0000Eooooo`00
7_ooool00ol0003oooooooooo`02o`0003gooooo0_l0000Dooooo`;o00007?ooool2o`0000?ooooo
0_l0000Fooooo`?o0000TOooool2o`00027ooooo000Nooooo`03o`000?oooooooooo00;o0000P?oo
ool2o`0000cooooo0ol0002Dooooo`;o00007_ooool001kooooo00?o0000ooooooooool0=Oooool2
o`0004_ooooo0ol0002Rooooo`;o00007_ooool001kooooo00?o0000ooooooooool0=Oooool2o`00
00oooooo0_l0000:ooooo`;o0000;oooool2o`0000Wooooo0_l0002gooooo`000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool0
0ol0003oooooooooo`11ooooo`;o00000oooool2o`0000[ooooo0_l0000Kooooo`;o00002Oooool2
o`0001;ooooo0_l0002<ooooo`;o00002Oooool2o`0001kooooo0003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oo
oooooooo043ooooo1?l0000[ooooo`;o00002Oooool2o`0008Sooooo0_l0000Fooooo`;o00002Ooo
ool2o`0001kooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000000Kooooo0ol0000iooooo`;o00001Oooool4o`0000Oooooo0_l0000Hooooo`;o0000
<Oooool2o`0006[ooooo0_l00011ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo
00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000>Oooool2o`00013ooooo0_l0000Hooooo`;o
0000<Oooool2o`000:gooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003o
EEEEo`000?l@413oc<c<00Kooooo0ol0000kooooo`?o00004_ooool2o`0001Oooooo0_l00006oooo
o`;o00003_ooool4o`0007Cooooo0_l0000<ooooo`;o00005Oooool2o`0002Oooooo0003ooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo
03_ooooo1Ol0000@ooooo`;o00005?ooool2o`000003ooooool0003o000000Kooooo0_l00004oooo
o`;o00002?ooool4o`0001Oooooo0_l0001Kooooo`;o00003?ooool2o`0000_ooooo0_l00008oooo
o`;o00003?ooool2o`0001Wooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooM
gMgo410@oiRHV008ooooo`03o`000?oooooooooo02Kooooo0_l0000Eooooo`?o00009_ooool2o`00
00Oooooo0_l00006ooooo`;o00002?ooool2o`0001Wooooo0ol0001eooooo`;o00005_ooool2o`00
00Kooooo0_l0000Aooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4
A?l0003o410@1_ooool00ol0003oooooooooo`0Vooooo`;o0000Aoooool2o`00013ooooo0_l0000H
ooooo`Co0000UOooool2o`00017ooooo000Nooooo`03o`000?oooooooooo04Wooooo0_l0000;oooo
o`;o0000;_ooool2o`0001?ooooo0_l0002Zooooo`007_ooool00ol0003oooooooooo`0Zooooo`;o
00007Oooool2o`0000_ooooo0_l0000^ooooo`;o0000R_ooool2o`00023ooooo0_l0000Aooooo`00
7_ooool00ol0003oooooooooo`0Zooooo`;o0000G_ooool2o`00013ooooo0_l0001dooooo`;o0000
8?ooool2o`0000_ooooo0_l00004ooooo`007_ooool00ol0003oooooooooo`16ooooo`;o0000>ooo
ool2o`0000Gooooo0_l0000@ooooo`;o0000AOooool2o`0003Sooooo0_l0000Rooooo`;o00001?oo
ool001kooooo00?o0000ooooooooool0A_ooool2o`0003_ooooo0_l0000Hooooo`;o0000A?ooool2
o`00023ooooo0_l0000Fooooo`;o0000:?ooool001kooooo00?o0000ooooooooool0KOooool2o`00
02kooooo0_l00004ooooo`;o0000H?ooool2o`00043ooooo000Nooooo`03o`000?oooooooooo04[o
oooo0_l0000Gooooo`;o00002?ooool2o`0003Cooooo0_l0002Rooooo`007_ooool2o`0004Gooooo
0_l00004ooooo`;o00005oooool2o`0000kooooo0_l0003Booooo`007_ooool2o`0000Sooooo0_l0
000kooooo`;o0000;Oooool2o`0000oooooo0_l00007ooooo`;o00008oooool2o`0000cooooo0_l0
0025ooooo`007_ooool00ol0003oooooooooo`07ooooo`;o0000Noooool2o`0000Oooooo0_l00000
0ooooooo0000o`00000Pooooo`;o00003?ooool2o`0008Gooooo000Nooooo`03o`000?oooooooooo
03gooooo0_l00004ooooo`;o0000>_ooool2o`0000oooooo0_l0000Looooo`;o0000Uoooool001ko
oooo0_l0000nooooo`Co00000_ooool2o`0003[ooooo0_l0000]ooooo`;o0000;?ooool2o`0006Wo
oooo000Nooooo`03o`000?oooooooooo03gooooo1?l0000looooo`;o0000GOooool2o`0006Wooooo
000Nooooo`03o`000?oooooooooo03[ooooo0_l000000ooooooo0000o`00000^ooooo`;o00003_oo
ool2o`0002?ooooo0_l0001booooo`;o0000;oooool001kooooo00?o0000ooooooooool0=oooool2
o`000003ooooool0003o0000037ooooo0_l0000cooooo`;o00003Oooool2o`0000Oooooo0_l0000?
ooooo`;o0000BOooool2o`0002oooooo000Nooooo`03o`000?oooooooooo03Oooooo0_l0001:oooo
o`;o0000;?ooool2o`0000Oooooo0_l0000?ooooo`Co00006?ooool2o`0000Gooooo0_l0001Goooo
o`007_ooool00ol0003oooooooooo`02o`0002[ooooo0_l0001Eooooo`;o00005_ooool2o`00033o
oooo0_l0000Hooooo`;o00001Oooool2o`0005Oooooo000Nooooo`03o`000?oooooooooo00;o0000
5Oooool2o`0001?ooooo0_l0000>ooooo`;o0000@_ooool2o`0001Wooooo0_l0000Oooooo`;o0000
ROooool001kooooo00?o0000ooooooooool05oooool2o`00027ooooo1?l00005ooooo`;o0000>ooo
ool2o`0003[ooooo0_l0000oooooo`;o0000:oooool2o`0001_ooooo000Nooooo`03o`000?oooooo
oooo02gooooo0_l0000;ooooo`;o00001oooool2o`0000;ooooo0_l0002dooooo`;o0000:oooool2
o`0001_ooooo000Nooooo`03o`000?oooooooooo02gooooo0_l0000?ooooo`;o00001oooool2o`00
06Cooooo0_l0000<ooooo`;o0000R_ooool001kooooo00?o0000ooooooooool0=oooool2o`0000Go
oooo0_l0000Fooooo`;o00001oooool2o`0004cooooo0_l0000<ooooo`;o00000oooool2o`0003So
oooo0_l0001;ooooo`007_ooool00ol0003oooooooooo`0gooooo`?o00007?ooool4o`0000Gooooo
0_l0001Oooooo`;o0000>?ooool2o`0004_ooooo000Nooooo`03o`000?oooooooooo03Kooooo1Ol0
000Mooooo`;o0000U?ooool2o`0005Oooooo000Nooooo`03o`000?oooooooooo03Kooooo0_l00000
0ooooooo0000o`00000Zooooo`;o0000Qoooool2o`0005Oooooo000Nooooo`03o`000?oooooooooo
03kooooo0_l0000Uooooo`;o0000N_ooool2o`0003cooooo0_l0000?ooooo`;o00005Oooool001ko
oooo00?o0000ooooooooool0?_ooool2o`0006[ooooo0_l00002ooooo`;o0000<Oooool2o`00037o
oooo0_l00009ooooo`;o00003oooool2o`0001Gooooo000Nooooo`;o0000>oooool2o`0002;ooooo
0_l0001:ooooo`;o00000_ooool2o`0006Cooooo0_l0000aooooo`007_ooool00ol0003ooooooooo
o`0aooooo`;o00001oooool4o`00023ooooo0_l0000Pooooo`;o0000__ooool2o`0000Gooooo000N
ooooo`03o`000?oooooooooo01gooooo0_l0000Booooo`;o00002Oooool2o`0004;ooooo0_l0000]
ooooo`;o0000Soooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo01gooooo0_l0002@oooo
o`;o0000U_ooool001kooooo00?o0000ooooooooool0?oooool2o`000>Sooooo0_l0000Looooo`00
7_ooool00ol0003oooooooooo`0oooooo`;o00001Oooool2o`0002Gooooo0_l0002jooooo`;o0000
7?ooool001kooooo00?o0000ooooooooool0A_ooool2o`0002Gooooo0_l0001Vooooo`;o0000L?oo
ool001kooooo00?o0000ooooooooool0=_ooool2o`0007Cooooo0_l0000Wooooo`;o0000L?ooool0
01kooooo00?o0000ooooooooool05_ooool2o`0001Gooooo0_l00007ooooo`;o0000M?ooool2o`00
09Wooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l0000Eooooo`;o00000oooool2o`00043o
oooo0_l0000Oooooo`;o0000/?ooool001kooooo00?o0000ooooooooool0<_ooool2o`0003Gooooo
0_l00009ooooo`;o00007oooool2o`000;3ooooo000Nooooo`03o`000?oooooooooo03Wooooo0_l0
000^ooooo`;o0000?Oooool2o`0009gooooo000Nooooo`04o`000?oooooo0000o`0003Sooooo0_l0
001Qooooo`;o00002_ooool2o`0009gooooo000Nooooo`04o`000?oooooo0000o`0005Cooooo0_l0
0015ooooo`;o0000FOooool2o`0000Cooooo0_l00018ooooo`007_ooool00ol0003oooooooooo`0k
ooooo`;o00006?ooool2o`0003_ooooo0_l0000Looooo`;o0000AOooool2o`0000Cooooo0_l00018
ooooo`007_ooool00ol0003oooooooooo`0kooooo`;o0000EOooool2o`0000Wooooo0_l0000Aoooo
o`;o00007Oooool2o`0007Kooooo000Nooooo`;o00001_ooool2o`0002_ooooo1?l0000Cooooo`;o
00002?ooool2o`0003[ooooo0_l00005ooooo`;o00001Oooool2o`00033ooooo0_l0001Aooooo`;o
00003oooool2o`0001;ooooo000Nooooo`03o`000?oooooooooo00Gooooo0_l0000[ooooo`Co0000
4oooool2o`0000Sooooo0_l0000;ooooo`;o0000;Oooool2o`0000Gooooo0_l0002:ooooo`;o0000
3oooool2o`0001;ooooo000Nooooo`03o`000?oooooooooo00gooooo0_l0000Iooooo`Co00007?oo
ool2o`0001Kooooo0_l0001fooooo`;o0000KOooool001kooooo00?o0000ooooooooool00_l0000;
ooooo`;o00006Oooool4o`0001cooooo0_l00003ooooo`;o0000@Oooool2o`0004Kooooo0_l0001]
ooooo`007_ooool00ol0003oooooooooo`02o`0004_ooooo0_l0000=ooooo`;o00002oooool2o`00
02Gooooo0_l0002eooooo`007_ooool00ol0003oooooooooo`1Looooo`;o00002oooool2o`000<oo
oooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`0Xooooo`;o0000[Oooool2o`00067ooooo
0_l0000;ooooo`007_ooool00ol0003oooooooooo`0Xooooo`;o00003Oooool2o`0009kooooo0_l0
000:ooooo`;o0000EOooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo037ooooo0_l00004
ooooo`;o00000_ooool2o`000:Kooooo0_l0001Rooooo`007_ooool00ol0003oooooooooo`0aoooo
o`;o00002?ooool2o`0000Cooooo0_l0000;ooooo`;o0000A?ooool2o`000;7ooooo000Nooooo`03
o`000?oooooooooo047ooooo0_l0000;ooooo`;o0000A?ooool2o`0000Wooooo0_l0002Vooooo`00
7_ooool00ol0003oooooooooo`0hooooo`;o0000IOooool2o`0009[ooooo0_l0000:ooooo`007_oo
ool00ol0003oooooooooo`0hooooo`;o0000ooooool2ooooo`;o00002_ooool001kooooo00?o0000
ooooooooool0Foooool2o`0004kooooo0_l0002Jooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003ooooooooo
o`0_ooooo`;o00003?ooool2o`0001cooooo0_l0000Iooooo`;o0000<oooool2o`0009[ooooo0003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RH
ob4Q8@06ooooo`03o`000?oooooooooo02oooooo0_l0000<ooooo`;o00004?ooool2o`0002Gooooo
0_l0000<ooooo`;o0000Woooool2o`00023ooooo0003ooooo`05oa0@4?ooooooooooooooool@4100
2oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0000Yooooo`;o00009?ooool2o`0003?o
oooo0_l0002Oooooo`;o00008?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05
oc8b<_nHV9SooooooiRHV?lb<S801_ooool00ol0003oooooooooo`0Yooooo`;o0000oooooolMoooo
o`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006
ooooo`03o`000?oooooooooo01cooooo0_l0000;ooooo`;o00001Oooool2o`00077ooooo0_l0002R
ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@
4006ooooo`03o`000?oooooooooo01cooooo0ol00007ooooo`;o00002?ooool2o`0000gooooo0_l0
001Rooooo`;o0000@?ooool2o`0002gooooo0_l0000aooooo`000oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo01gooooo
0_l00007ooooo`;o00004Oooool2o`0000Cooooo0_l0002Mooooo`;o00001Oooool2o`0002gooooo
0_l0000aooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@06ooooo`03o`000?oooooooooo01gooooo0_l0000Cooooo`;o00001Oooool2o`0004Co
oooo0_l0001Mooooo`;o0000=?ooool2o`00037ooooo000Nooooo`03o`000?oooooooooo03;ooooo
0_l0000Kooooo`;o0000;_ooool2o`0006;ooooo0_l0001Rooooo`007_ooool00ol0003ooooooooo
o`0Xooooo`;o00009?ooool4o`0001;ooooo0_l0001mooooo`;o0000H_ooool001kooooo00?o0000
ooooooooool0:?ooool2o`0002Cooooo1?l0000Booooo`;o0000<oooool2o`000:cooooo000Noooo
o`03o`000?oooooooooo09Wooooo0_l0000Wooooo`;o0000Poooool001kooooo00?o0000oooooooo
ool0C_ooool2o`0001Cooooo0_l0001Looooo`;o0000Poooool001kooooo00Co0000ooooool0003o
00000oooool2o`0002[ooooo1?l0000;ooooo`;o00003Oooool2o`000003ooooool0003o0000017o
oooo0_l0000_ooooo`;o0000/?ooool001kooooo00Co0000ooooool0003o00000oooool2o`0002[o
oooo1?l0000;ooooo`;o00004?ooool2o`0001Kooooo0_l0000Zooooo`Co0000[_ooool001kooooo
00?o0000ooooooooool0<?ooool2o`0000;ooooo0_l0000cooooo`;o0000;?ooool2o`000:kooooo
000Nooooo`03o`000?oooooooooo02gooooo0_l000001?oooooo0000o`000?ooool3o`0001Cooooo
0_l0003kooooo`007_ooool00ol0003oooooooooo`0]ooooo`;o00001?ooool2o`0001Gooooo0_l0
000Kooooo`;o0000d_ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l00003
ooooo`;o00003Oooool2o`0000cooooo0_l0000/ooooo`;o00009oooool2o`0002Kooooo0_l0001N
ooooo`;o00008Oooool2o`0000[ooooo000Nooooo`;o00005oooool3o`0000?ooooo0_l0000=oooo
o`;o00003?ooool2o`0000?ooooo0_l0001@ooooo`;o00009_ooool2o`0001Kooooo0_l00016oooo
o`;o0000;Oooool001kooooo00?o0000ooooooooool04oooool2o`000003ooooool0003o000000ko
oooo1?l0000Dooooo`;o0000T?ooool2o`0003cooooo0_l0000gooooo`007_ooool00ol0003ooooo
ooooo`0Cooooo`;o00004Oooool4o`0002_ooooo0_l0002gooooo`;o0000=oooool001kooooo00?o
0000ooooooooool0<oooool2o`00023ooooo0_l0001dooooo`;o0000KOooool2o`0000;ooooo0_l0
0007ooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o00001Oooool2o`0001cooooo0_l00008
ooooo`;o00004Oooool2o`0007Wooooo0_l0001]ooooo`;o00000_ooool2o`0000Oooooo000Noooo
o`03o`000?oooooooooo00kooooo0_l00005ooooo`;o00009_ooool2o`0000_ooooo0_l00004oooo
o`;o0000cOooool2o`0002Kooooo000Nooooo`03o`000?oooooooooo04[ooooo0_l0001Hooooo`;o
00009_ooool2o`00057ooooo0_l0000Vooooo`007_ooool00ol0003oooooooooo`2Tooooo`;o0000
9_ooool2o`0007Wooooo000Nooooo`03o`000?oooooooooo0?;ooooo0_l0001Cooooo`007_ooool0
0ol0003oooooooooo`13ooooo`Co0000;Oooool2o`0007cooooo0_l0001Cooooo`007_ooool00ol0
003oooooooooo`13ooooo`Co00001?ooool2o`0002Oooooo0_l00009ooooo`;o00005Oooool2o`00
0003ooooool0003o0000017ooooo0_l0000=ooooo`;o00003Oooool2o`0007;ooooo0_l00007oooo
o`007_ooool3o`0001Kooooo0_l000000ooooooo0000o`00000Zooooo`;o00001?ooool4o`00033o
oooo0_l0000Eooooo`;o000000?oooooo`000?l000002oooool2o`0000Cooooo0_l0000=ooooo`;o
00003Oooool2o`0004Gooooo0_l0000Hooooo`;o00004Oooool2o`0000Oooooo000Nooooo`?o0000
5_ooool2o`000003ooooool0003o0000037ooooo0ol0001Gooooo`;o0000JOooool2o`0001Sooooo
0_l0000Jooooo`007_ooool00ol0003oooooooooo`0Uooooo`;o00009Oooool2o`000>cooooo0_l0
000;ooooo`007_ooool00ol0003oooooooooo`0Uooooo`;o00008_ooool2o`0000Kooooo0_l0003?
ooooo`;o00005_ooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo043ooooo0_l00007oooo
o`;o00001_ooool2o`0000Wooooo0_l0000<ooooo`;o0000VOooool2o`0001_ooooo0_l0000;oooo
o`;o00005_ooool001kooooo0_l00006ooooo`;o0000>Oooool2o`0001[ooooo0_l00003ooooo`;o
00001oooool2o`0009Wooooo0_l0000Xooooo`;o00005_ooool001kooooo00?o0000ooooooooool0
1Oooool2o`0004Cooooo0_l0000:ooooo`;o00002?ooool2o`0000_ooooo0_l0001Zooooo`;o0000
Joooool001kooooo00?o0000ooooooooool0<?ooool2o`0001Wooooo0_l00005ooooo`;o00000ooo
ool2o`0001Gooooo0_l0001Zooooo`;o0000I?ooool3o`0000Cooooo000Nooooo`03o`000?oooooo
oooo01[ooooo0_l00002ooooo`;o00004?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000=
ooooo`;o00002_ooool2o`0000Oooooo0_l0001Hooooo`;o0000ROooool3o`0000Cooooo000Noooo
o`03o`000?oooooooooo01[ooooo0_l00002ooooo`;o00005?ooool2o`000003ooooool0003o0000
00gooooo0_l0000Cooooo`;o0000F?ooool2o`0008?ooooo0_l0000;ooooo`007_ooool00ol0003o
ooooooooo`0aooooo`;o00001oooool2o`0000?ooooo0_l00004ooooo`;o00003?ooool2o`0004;o
oooo0_l0002Qooooo`;o00002oooool001kooooo00?o0000ooooooooool0<Oooool2o`0000Oooooo
0_l00003ooooo`;o00001?ooool2o`0000Wooooo0_l000000ooooooo0000o`000012ooooo`;o0000
[_ooool001kooooo00?o0000ooooooooool07Oooool2o`00037ooooo0_l0000<ooooo`;o00005Ooo
ool2o`000=3ooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0000Hooooo`;o000000?ooooo
o`000?l000002oooool2o`0000gooooo0_l0000Pooooo`;o00005Oooool2o`000:_ooooo0_l0000S
ooooo`007_ooool00ol0003oooooooooo`03ooooo`;o00006oooool2o`0000_ooooo0_l0000=oooo
o`;o00002?ooool2o`000=[ooooo0_l0000Sooooo`007_ooool00ol0003oooooooooo`16ooooo`;o
0000ooooool001kooooo00?o0000ooooooooool0DOooool2o`000?Cooooo000Nooooo`03o`000?oo
oooooooo04?ooooo0_l0000<ooooo`;o0000??ooool2o`0008kooooo0_l0000Vooooo`007_ooool0
0ol0003oooooooooo`13ooooo`;o0000AOooool2o`0000?ooooo0_l0002>ooooo`;o00001oooool2
o`0001gooooo000Nooooo`03o`000?oooooooooo08?ooooo0_l00005ooooo`;o0000>oooool2o`00
05oooooo0ol0000Looooo`007_ooool00ol0003oooooooooo`0Booooo`;o0000;_ooool2o`0003oo
oooo0_l0000booooo`;o00003_ooool2o`00063ooooo0_l0000Looooo`007_ooool2o`0001?ooooo
0_l000000ooooooo0000o`00000[ooooo`;o0000Loooool2o`0002[ooooo0_l0001Rooooo`007_oo
ool00ol0003oooooooooo`0Eooooo`;o0000Boooool2o`0000Sooooo0_l0000]ooooo`;o0000A_oo
ool2o`0006;ooooo000Nooooo`03o`000?oooooooooo06;ooooo0_l00008ooooo`;o00009oooool2
o`0000Cooooo0_l0002Aooooo`;o00005oooool001kooooo00?o0000ooooooooool0UOooool2o`00
01Wooooo0_l0001looooo`;o00005oooool001kooooo00?o0000ooooooooool0=oooool2o`00037o
oooo0_l00011ooooo`;o000000?oooooo`000?l00000UOooool001kooooo00?o0000ooooooooool0
=oooool2o`0002Wooooo0_l00006ooooo`;o00000_ooool2o`0000gooooo0_l0000^ooooo`;o0000
V?ooool001kooooo00?o0000ooooooooool0Foooool4o`0000?ooooo0_l0000:ooooo`;o00003Ooo
ool2o`000<Sooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0000booooo`;o00007Oooool4
o`0002Wooooo0_l00015ooooo`;o0000M_ooool001kooooo00Co0000oooooooooooooooo0_l00005
ooooo`;o0000<_ooool2o`0002?ooooo0_l0000Uooooo`;o0000AOooool2o`0007Kooooo000Noooo
o`04o`000?ooooooooooooooo`;o0000;oooool2o`0002gooooo0_l00004ooooo`;o0000Koooool2
o`0003_ooooo0_l0000`ooooo`007_ooool00ol0003oooooooooo`0Wooooo`;o00002Oooool2o`00
02Gooooo0_l0000<ooooo`;o00006Oooool2o`0005Cooooo0_l0000kooooo`;o0000<?ooool001ko
oooo00?o0000ooooooooool05_ooool2o`0000oooooo0_l0000Fooooo`;o00006?ooool2o`0000So
oooo0_l0000Mooooo`;o0000;_ooool2o`0009?ooooo000Nooooo`03o`000?oooooooooo01Kooooo
0_l0000Wooooo`;o000000?oooooo`000?l000006?ooool2o`0000Gooooo0_l0001=ooooo`;o0000
Q?ooool2o`0000gooooo000Nooooo`03o`000?oooooooooo04;ooooo0_l0000Hooooo`;o0000eOoo
ool2o`0000?ooooo0_l0000=ooooo`005?ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool01_ooool2o`0005Kooooo0_l0000Tooooo`;o0000Q_ooool2o`0002Gooooo0_l0000B
ooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo0_l0001Foooo
o`;o00009?ooool2o`0000Oooooo0_l0000oooooo`;o0000??ooool2o`00013ooooo0_l00003oooo
o`;o00008_ooool001Kooooo00?o0000ooooooooool01Oooool3o`0003kooooo0_l0000[ooooo`;o
00008?ooool2o`0003[ooooo0_l00003ooooo`;o0000C_ooool2o`0000?ooooo0_l0000Rooooo`00
5_ooool00ol0003oooooooooo`05ooooo`;o0000?oooool2o`0002_ooooo0_l0001Looooo`;o0000
O?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3o
oooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Cooooo00?oEEEEofIVI_l0
0000oooooomBooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.20784 .69023 Mdot
.85353 .41498 Mdot
.22407 .52226 Mdot
.1331 .00649 Mdot
.30708 .45923 Mdot
.26944 .01035 Mdot
.5742 .05982 Mdot
.24591 .49118 Mdot
.28328 .96593 Mdot
.75427 .0584 Mdot
.31886 .1777 Mdot
.39595 .08631 Mdot
.24078 .53559 Mdot
.55632 .66036 Mdot
.20873 .99609 Mdot
.47722 .63364 Mdot
.7882 .59707 Mdot
.29626 .56535 Mdot
.22199 .60156 Mdot
.15212 .09417 Mdot
.88019 .59998 Mdot
.32219 .08222 Mdot
.38439 .45315 Mdot
.87701 .05276 Mdot
.23906 .88397 Mdot
.23928 .44496 Mdot
.18859 .83042 Mdot
.51253 .71809 Mdot
.32882 .18005 Mdot
.28089 .1147 Mdot
.23592 .58274 Mdot
.22055 .98343 Mdot
.31745 .00363 Mdot
.93022 .93014 Mdot
.96116 .54499 Mdot
.11567 .88483 Mdot
.56395 .67 Mdot
.86536 .49647 Mdot
.44125 .83471 Mdot
.20496 .79323 Mdot
.2277 .58782 Mdot
.03071 .63801 Mdot
.06128 .98833 Mdot
.82636 .58795 Mdot
.50135 .05351 Mdot
.03087 .70313 Mdot
.62785 .44417 Mdot
.04944 .83697 Mdot
.1426 .8145 Mdot
.18012 .32079 Mdot
.38059 .9903 Mdot
.98137 .50804 Mdot
.26307 .39983 Mdot
.11052 .85654 Mdot
.28175 .38931 Mdot
.23602 .23536 Mdot
.76234 .28678 Mdot
.24481 .51935 Mdot
.18495 .83759 Mdot
.28262 .67569 Mdot
.16112 .02454 Mdot
.24758 .47684 Mdot
.57189 .09676 Mdot
.25529 .91727 Mdot
.24967 .75224 Mdot
.31133 .03987 Mdot
.06146 .40775 Mdot
.18606 .82953 Mdot
.25975 .03239 Mdot
.81993 .29921 Mdot
.17448 .22611 Mdot
.37726 .59979 Mdot
.09695 .15137 Mdot
.26694 .20818 Mdot
.3601 .06366 Mdot
.99265 .28876 Mdot
.19344 .36481 Mdot
.63227 .20434 Mdot
.20213 .9015 Mdot
.4462 .41085 Mdot
.02765 .86453 Mdot
.66054 .11832 Mdot
.83739 .59509 Mdot
.24506 .49105 Mdot
.7697 .41904 Mdot
.03828 .21327 Mdot
.26246 .44272 Mdot
.1391 .90541 Mdot
.2365 .01171 Mdot
.32383 .64886 Mdot
.1178 .11053 Mdot
.84875 .26902 Mdot
.18874 .31229 Mdot
.18753 .20941 Mdot
.29734 .62807 Mdot
.01131 .76664 Mdot
.58868 .15718 Mdot
.96989 .53334 Mdot
.24313 .82667 Mdot
.93983 .57304 Mdot
.19727 .75078 Mdot
.38536 .95188 Mdot
.18107 .62417 Mdot
.52847 .6425 Mdot
.92499 .32731 Mdot
.38005 .46054 Mdot
.45563 .66052 Mdot
.47576 .65469 Mdot
.00144 .50348 Mdot
.6341 .13642 Mdot
.55958 .67741 Mdot
.8484 .48474 Mdot
.44048 .9651 Mdot
.26304 .57281 Mdot
.40623 .33007 Mdot
.61063 .01748 Mdot
.4872 .02876 Mdot
.23617 .53403 Mdot
.07936 .29944 Mdot
.51397 .88999 Mdot
.16836 .82116 Mdot
.04477 .73893 Mdot
.35905 .09872 Mdot
.19089 .21293 Mdot
.88518 .19948 Mdot
.90681 .58302 Mdot
.30783 .90699 Mdot
.21646 .64916 Mdot
.93077 .8998 Mdot
.05185 .12087 Mdot
.89941 .54346 Mdot
.34354 .25859 Mdot
.79588 .73797 Mdot
.35538 .54634 Mdot
.30445 .59225 Mdot
.2746 .35812 Mdot
.36831 .45407 Mdot
.37833 .65904 Mdot
.19457 .56004 Mdot
.29371 .00985 Mdot
.22432 .64139 Mdot
.25253 .91053 Mdot
.33646 .0636 Mdot
.9821 .60468 Mdot
.5638 .31181 Mdot
.38521 .08242 Mdot
.22458 .71392 Mdot
.19847 .77201 Mdot
.76928 .27489 Mdot
.63656 .11035 Mdot
.66417 .75692 Mdot
.33074 .03947 Mdot
.41574 .09202 Mdot
.15902 .10858 Mdot
.19099 .96547 Mdot
.23867 .51747 Mdot
.41193 .63582 Mdot
.74166 .35874 Mdot
.25673 .9327 Mdot
.45829 .62885 Mdot
.39233 .61047 Mdot
.94184 .54179 Mdot
.82901 .90468 Mdot
.37295 .54034 Mdot
.23981 .80012 Mdot
.31298 .43323 Mdot
.20283 .7728 Mdot
.22569 .87615 Mdot
.62441 .12522 Mdot
.36304 .51373 Mdot
.34758 .12177 Mdot
.01265 .86409 Mdot
.943 .53015 Mdot
.07863 .28322 Mdot
.2119 .66212 Mdot
.42625 .75602 Mdot
.87273 .89156 Mdot
.22358 .44355 Mdot
.59447 .10393 Mdot
.97315 .51339 Mdot
.07058 .96809 Mdot
.35844 .03678 Mdot
.48583 .8045 Mdot
.4927 .14553 Mdot
.69383 .23946 Mdot
.44269 .88796 Mdot
.45517 .62264 Mdot
.09173 .07892 Mdot
.77429 .73732 Mdot
.97485 .69047 Mdot
.21383 .65632 Mdot
.00722 .19883 Mdot
.21283 .66886 Mdot
.46463 .16853 Mdot
.49358 .89201 Mdot
.06817 .01406 Mdot
.95596 .56277 Mdot
.37773 .12062 Mdot
.28606 .96792 Mdot
.348 .05414 Mdot
.51044 .18818 Mdot
.45562 .34405 Mdot
.34556 .56042 Mdot
.50731 .12038 Mdot
.24055 .88886 Mdot
.13613 .91736 Mdot
.62346 .0748 Mdot
.15698 .88655 Mdot
.80293 .38464 Mdot
.5255 .74136 Mdot
.35573 .48733 Mdot
.21223 .67452 Mdot
.90547 .22236 Mdot
.66197 .30688 Mdot
.38736 .63337 Mdot
.15709 .21252 Mdot
.21262 .77842 Mdot
.13994 .28342 Mdot
.44476 .74646 Mdot
.10575 .37996 Mdot
.76176 .3029 Mdot
.33876 .59629 Mdot
.24922 .89726 Mdot
.23249 .90922 Mdot
.32718 .62462 Mdot
.41453 .5811 Mdot
.99973 .98586 Mdot
.35356 .39534 Mdot
.69891 .18734 Mdot
.3313 .05883 Mdot
.23719 .48983 Mdot
.27896 .69442 Mdot
.34499 .06968 Mdot
.01367 .09029 Mdot
.15545 .20959 Mdot
.72774 .17901 Mdot
.70498 .5364 Mdot
.23326 .56165 Mdot
.86489 .53727 Mdot
.76178 .22098 Mdot
.20561 .40714 Mdot
.34822 .09077 Mdot
.05549 .92485 Mdot
.17251 .44235 Mdot
.45339 .82372 Mdot
.18515 .35687 Mdot
.36071 .58698 Mdot
.33489 .12284 Mdot
.6845 .10482 Mdot
.22805 .57558 Mdot
.98295 .49494 Mdot
.31894 .41027 Mdot
.81885 .15908 Mdot
.04397 .22268 Mdot
.88088 .19457 Mdot
.06531 .83729 Mdot
.28032 .41192 Mdot
.88779 .4775 Mdot
.98645 .75044 Mdot
.40781 .32797 Mdot
.2081 .69851 Mdot
.25466 .73918 Mdot
.24969 .22422 Mdot
.95593 .37397 Mdot
.34585 .07542 Mdot
.98378 .12961 Mdot
.42282 .94493 Mdot
.06837 .29496 Mdot
.23375 .55054 Mdot
.19931 .81076 Mdot
.24151 .82341 Mdot
.66787 .46288 Mdot
.19681 .05904 Mdot
.2849 .75217 Mdot
.02657 .88561 Mdot
.34243 .43019 Mdot
.42139 .74418 Mdot
.43363 .24385 Mdot
.11822 .85403 Mdot
.40119 .97848 Mdot
.79535 .26962 Mdot
.32846 .0979 Mdot
.3861 .51465 Mdot
.57607 .64343 Mdot
.30068 .43083 Mdot
.24878 .89754 Mdot
.35406 .53203 Mdot
.9107 .49692 Mdot
.0644 .75441 Mdot
.33291 .2063 Mdot
.06515 .90282 Mdot
.85906 .2662 Mdot
.22269 .60358 Mdot
.46008 .13284 Mdot
.60397 .12742 Mdot
.91824 .50359 Mdot
.23054 .74907 Mdot
.44957 .61637 Mdot
.79462 .24583 Mdot
.67374 .14288 Mdot
.90863 .49442 Mdot
.27209 .90332 Mdot
.96682 .56736 Mdot
.37765 .57922 Mdot
.74109 .03999 Mdot
.01889 .46359 Mdot
.19339 .83708 Mdot
.17813 .91676 Mdot
.87865 .13676 Mdot
.4418 .33283 Mdot
.16173 .85229 Mdot
.79163 .23429 Mdot
.23963 .45113 Mdot
.37781 .35444 Mdot
.23921 .78006 Mdot
.09288 .76082 Mdot
.43632 .77322 Mdot
.0768 .28133 Mdot
.31154 .97123 Mdot
.93432 .34424 Mdot
.44734 .83797 Mdot
.32712 .02958 Mdot
.38743 .0009 Mdot
.50894 .78735 Mdot
.25886 .58445 Mdot
.23622 .49644 Mdot
.12051 .85224 Mdot
.20872 .70127 Mdot
.38406 .05937 Mdot
.24039 .48408 Mdot
.12873 .0944 Mdot
.28128 .03629 Mdot
.46315 .2664 Mdot
.87819 .09678 Mdot
.11343 .30929 Mdot
.2559 .29449 Mdot
.74205 .6839 Mdot
.18552 .80672 Mdot
.75845 .88506 Mdot
.97478 .10912 Mdot
.2388 .82372 Mdot
.74286 .65947 Mdot
.22237 .66923 Mdot
.38099 .58321 Mdot
.71676 .35414 Mdot
.55009 .54132 Mdot
.62126 .11499 Mdot
.3401 .26443 Mdot
.93717 .41285 Mdot
.24682 .48962 Mdot
.23435 .53941 Mdot
.29688 .40747 Mdot
.95001 .70614 Mdot
.5125 .6775 Mdot
.59589 .07825 Mdot
.18275 .04753 Mdot
.02576 .62267 Mdot
.37085 .55199 Mdot
.24769 .53567 Mdot
.16184 .281 Mdot
.33534 .10758 Mdot
.88279 .81238 Mdot
.22843 .58842 Mdot
.35875 .47979 Mdot
.26119 .91008 Mdot
.93018 .74881 Mdot
.62002 .87965 Mdot
.71805 .65943 Mdot
.73892 .21155 Mdot
.28264 .09009 Mdot
.37524 .6383 Mdot
.20313 .84527 Mdot
.22988 .54388 Mdot
.31345 .03039 Mdot
.01126 .91652 Mdot
.93065 .56744 Mdot
.50969 .04947 Mdot
.13585 .85096 Mdot
.90835 .17148 Mdot
.29962 .13721 Mdot
.21277 .91696 Mdot
.11552 .01892 Mdot
.708 .2364 Mdot
.87797 .19285 Mdot
.50022 .73276 Mdot
.48337 .12439 Mdot
.63405 .85744 Mdot
.63172 .51574 Mdot
.18864 .8141 Mdot
.57716 .67932 Mdot
.22743 .63368 Mdot
.29842 .52465 Mdot
.18591 .72985 Mdot
.27153 .49209 Mdot
.29459 .47361 Mdot
.4069 .27547 Mdot
.79803 .66573 Mdot
.95635 .15215 Mdot
.17947 .8407 Mdot
.24568 .59217 Mdot
.05819 .02079 Mdot
.51965 .975 Mdot
.75986 .33546 Mdot
.24638 .48215 Mdot
.62534 .66267 Mdot
.96979 .95877 Mdot
.30708 .20664 Mdot
.34309 .62868 Mdot
.41146 .55138 Mdot
.37276 .5367 Mdot
.36802 .6447 Mdot
.23627 .89268 Mdot
.38448 .61998 Mdot
.57998 .02138 Mdot
.73736 .24652 Mdot
.33967 .54953 Mdot
.16822 .61564 Mdot
.41064 .58981 Mdot
.74293 .33228 Mdot
.19557 .90316 Mdot
.21193 .82973 Mdot
.58499 .39249 Mdot
.72379 .17406 Mdot
.3167 .53348 Mdot
.24211 .51076 Mdot
.77526 .52877 Mdot
.475 .20193 Mdot
.30282 .00286 Mdot
.38199 .59802 Mdot
.81158 .37968 Mdot
.7533 .23517 Mdot
.64041 .46099 Mdot
.47398 .41209 Mdot
.11698 .04454 Mdot
.80839 .25169 Mdot
.57103 .5451 Mdot
.46336 .73272 Mdot
.98372 .98997 Mdot
.13735 .53444 Mdot
.49435 .01511 Mdot
.44564 .9239 Mdot
.83472 .52309 Mdot
.83042 .62195 Mdot
.17819 .03493 Mdot
.24439 .26327 Mdot
.1608 .96934 Mdot
.32546 .01882 Mdot
.33278 .48942 Mdot
.84613 .23789 Mdot
.40659 .49351 Mdot
.87889 .69155 Mdot
.01551 .50432 Mdot
.2394 .83453 Mdot
.22092 .90763 Mdot
.43012 .14614 Mdot
.16698 .85105 Mdot
.2512 .91805 Mdot
.11363 .8666 Mdot
.95029 .94555 Mdot
.48753 .40438 Mdot
.14121 .71406 Mdot
.14333 .91783 Mdot
.22976 .93637 Mdot
.2203 .48072 Mdot
.92079 .16169 Mdot
.96383 .52268 Mdot
.3209 .01483 Mdot
.90907 .61861 Mdot
.19097 .02837 Mdot
.94233 .79801 Mdot
.28829 .09954 Mdot
.25621 .44927 Mdot
.24601 .4884 Mdot
.24549 .48996 Mdot
.19576 .4969 Mdot
.21468 .95769 Mdot
.21071 .37948 Mdot
.24224 .50488 Mdot
.76454 .29658 Mdot
.30081 .85094 Mdot
.62357 .2289 Mdot
.46216 .05754 Mdot
.33944 .08832 Mdot
.23893 .63127 Mdot
.20962 .68454 Mdot
.05678 .18705 Mdot
.11477 .1959 Mdot
.84925 .21254 Mdot
.01491 .8958 Mdot
.52093 .70517 Mdot
.23016 .55717 Mdot
.22896 .87817 Mdot
.4439 .27543 Mdot
.61828 .86961 Mdot
.18449 .1399 Mdot
.37063 .14471 Mdot
.10223 .49294 Mdot
.33192 .02078 Mdot
.97395 .25771 Mdot
.47097 .77883 Mdot
.15156 .40818 Mdot
.02313 .06835 Mdot
.01631 .84968 Mdot
.72818 .19036 Mdot
.32521 .54928 Mdot
.14577 .35148 Mdot
.25266 .4548 Mdot
.59842 .13315 Mdot
.2414 .90293 Mdot
.24743 .12224 Mdot
.2638 .61059 Mdot
.62578 .32952 Mdot
.2725 .2422 Mdot
.70851 .25248 Mdot
.29302 .45219 Mdot
.02169 .10355 Mdot
.09327 .86756 Mdot
.01371 .77211 Mdot
.72234 .4314 Mdot
.25396 .59765 Mdot
.36133 .56304 Mdot
.20441 .49184 Mdot
.20808 .90825 Mdot
.35943 .07588 Mdot
.95397 .6654 Mdot
.70923 .81132 Mdot
.45453 .27451 Mdot
.78576 .67715 Mdot
.44115 .44728 Mdot
.95188 .94912 Mdot
.88145 .98685 Mdot
.5555 .28599 Mdot
.30157 .44009 Mdot
.42378 .85205 Mdot
.24378 .49537 Mdot
.19462 .75376 Mdot
.27246 .76375 Mdot
.29246 .95699 Mdot
.87498 .45561 Mdot
.56051 .19741 Mdot
.29397 .01219 Mdot
.73368 .26292 Mdot
.37957 .0731 Mdot
.20183 .94966 Mdot
.19772 .70881 Mdot
.58513 .12665 Mdot
.84467 .23411 Mdot
.42103 .41906 Mdot
.38253 .50531 Mdot
.23751 .49923 Mdot
.61338 .06327 Mdot
.52749 .18951 Mdot
.30802 .98425 Mdot
.91744 .9449 Mdot
.04316 .88766 Mdot
.66016 .99703 Mdot
.84472 .20507 Mdot
.18469 .79426 Mdot
.10229 .94263 Mdot
.50214 .39183 Mdot
.37456 .51593 Mdot
.32262 .97402 Mdot
.87239 .46175 Mdot
.91513 .68683 Mdot
.34629 .53823 Mdot
.13833 .81207 Mdot
.40361 .61737 Mdot
.24614 .86871 Mdot
.63778 .42305 Mdot
.24255 .01207 Mdot
.62982 .47546 Mdot
.52528 .66027 Mdot
.22427 .96792 Mdot
.21117 .70855 Mdot
.28014 .53195 Mdot
.31049 .01052 Mdot
.98527 .0102 Mdot
.32687 .18143 Mdot
.32097 .40538 Mdot
.1537 .38167 Mdot
.70051 .96538 Mdot
.84359 .2826 Mdot
.18926 .4446 Mdot
.23209 .61891 Mdot
.90559 .42488 Mdot
.12664 .90528 Mdot
.45302 .88906 Mdot
.60313 .95994 Mdot
.56465 .8911 Mdot
.25881 .67663 Mdot
.24168 .50816 Mdot
.25638 .37468 Mdot
.3948 .57499 Mdot
.33721 .03472 Mdot
.3896 .1299 Mdot
.24059 .46072 Mdot
.46683 .74421 Mdot
.23914 .49868 Mdot
.12401 .88255 Mdot
.38243 .5546 Mdot
.32024 .02675 Mdot
.21322 .8476 Mdot
.23137 .54472 Mdot
.96923 .53466 Mdot
.53739 .99887 Mdot
.3764 .53897 Mdot
.19746 .78418 Mdot
.31705 .10544 Mdot
.53965 .05919 Mdot
.20932 .68823 Mdot
.54092 .12364 Mdot
.60292 .13122 Mdot
.25068 .06601 Mdot
.39141 .27021 Mdot
.21224 .59016 Mdot
.44169 .72162 Mdot
.37866 .60329 Mdot
.09129 .21634 Mdot
.25587 .86158 Mdot
.68358 .1287 Mdot
.70167 .82156 Mdot
.5308 .38155 Mdot
.21203 .67177 Mdot
.00179 .24131 Mdot
.00362 .55603 Mdot
.41805 .00276 Mdot
.90977 .00269 Mdot
.02452 .21533 Mdot
.31535 .38728 Mdot
.03262 .99555 Mdot
.18924 .52848 Mdot
.23302 .90442 Mdot
.26344 .68183 Mdot
.51556 .52863 Mdot
.23037 .97249 Mdot
.65238 .23011 Mdot
.24477 .49313 Mdot
.18904 .32551 Mdot
.30794 .5009 Mdot
.2183 .01157 Mdot
.07733 .10346 Mdot
.2546 .00928 Mdot
.03291 .59847 Mdot
.07296 .11591 Mdot
.55194 .9626 Mdot
.33296 .58731 Mdot
.34049 .93133 Mdot
.74541 .30391 Mdot
.24311 .4939 Mdot
.54596 .07485 Mdot
.84506 .00249 Mdot
.34278 .02666 Mdot
.8596 .85727 Mdot
.23639 .92218 Mdot
.84579 .23432 Mdot
.20901 .80805 Mdot
.23806 .38613 Mdot
.80255 .22463 Mdot
.80102 .38314 Mdot
.17359 .84554 Mdot
.50433 .02504 Mdot
.38847 .79571 Mdot
.73305 .07544 Mdot
.16371 .81113 Mdot
.99444 .16368 Mdot
.92085 .87049 Mdot
.18679 .90775 Mdot
.58897 .07806 Mdot
.94038 .58212 Mdot
.8963 .8512 Mdot
.14962 .18716 Mdot
.72283 .04325 Mdot
.46289 .18476 Mdot
.28894 .14805 Mdot
.75642 .20693 Mdot
.24582 .45962 Mdot
.80112 .07457 Mdot
.30503 .53137 Mdot
.64797 .12127 Mdot
.76585 .44011 Mdot
.86308 .44411 Mdot
.98499 .61354 Mdot
.73054 .2415 Mdot
.21668 .64581 Mdot
.24217 .00878 Mdot
.9299 .49213 Mdot
.33693 .88623 Mdot
.62875 .12041 Mdot
.55402 .85363 Mdot
.25762 .55955 Mdot
.04937 .76218 Mdot
.50082 .09714 Mdot
.17205 .30774 Mdot
.59709 .43656 Mdot
.32387 .02768 Mdot
.38946 .79363 Mdot
.23017 .92816 Mdot
.55379 .29693 Mdot
.71241 .1436 Mdot
.92395 .21503 Mdot
.17196 .27447 Mdot
.51343 .64973 Mdot
.23801 .52175 Mdot
.19354 .56482 Mdot
.12633 .21412 Mdot
.35266 .06987 Mdot
.68106 .1827 Mdot
.95895 .27433 Mdot
.42872 .22055 Mdot
.2951 .97643 Mdot
.71767 .16755 Mdot
.34358 .7197 Mdot
.54267 .92162 Mdot
.78813 .15491 Mdot
.35212 .41027 Mdot
.77661 .51605 Mdot
.33808 .111 Mdot
.26409 .48156 Mdot
.62726 .0141 Mdot
.34801 .11327 Mdot
.21003 .69031 Mdot
.10262 .17656 Mdot
.35975 .56092 Mdot
.55763 .42908 Mdot
.88676 .64751 Mdot
.81191 .31938 Mdot
.34245 .3155 Mdot
.17131 .80533 Mdot
.08459 .13275 Mdot
.74527 .30451 Mdot
.32527 .15466 Mdot
.32697 .14159 Mdot
.23674 .51593 Mdot
.28224 .97442 Mdot
.62971 .9878 Mdot
.61349 .5426 Mdot
.8505 .2438 Mdot
.84965 .21432 Mdot
.36457 .97554 Mdot
.80376 .3675 Mdot
.34637 .792 Mdot
.13286 .03317 Mdot
.21982 .59869 Mdot
.67071 .91421 Mdot
.02252 .10025 Mdot
.31985 .91428 Mdot
.29107 .14067 Mdot
.76008 .29148 Mdot
.3172 .9621 Mdot
.93695 .13669 Mdot
.04797 .97175 Mdot
.20296 .72482 Mdot
.44524 .16144 Mdot
.18435 .67292 Mdot
.34373 .57413 Mdot
.26986 .79208 Mdot
.34726 .51644 Mdot
.03465 .90816 Mdot
.21603 .37758 Mdot
.23035 .56536 Mdot
.77506 .34655 Mdot
.24682 .48757 Mdot
.82863 .37926 Mdot
.20365 .73294 Mdot
.30286 .19666 Mdot
.163 .04764 Mdot
.95747 .59901 Mdot
.7504 .26601 Mdot
.37859 .11484 Mdot
.83517 .37524 Mdot
.23398 .8446 Mdot
.58596 .83203 Mdot
.38409 .48271 Mdot
.31913 .41061 Mdot
.63103 .09133 Mdot
.23842 .61092 Mdot
.29409 .83625 Mdot
.2306 .55695 Mdot
.42396 .15881 Mdot
.35286 .23059 Mdot
.13201 .0117 Mdot
.48686 .87668 Mdot
.77666 .22003 Mdot
.99339 .03795 Mdot
.23757 .75876 Mdot
.42276 .63969 Mdot
.50608 .69435 Mdot
.29056 .00319 Mdot
.22921 .88126 Mdot
.23581 .50647 Mdot
.69417 .69221 Mdot
.73928 .21313 Mdot
.61711 .6588 Mdot
.2263 .43142 Mdot
.92806 .479 Mdot
.24507 .38693 Mdot
.52017 .69537 Mdot
.67889 .65014 Mdot
.10993 .97681 Mdot
.35261 .60066 Mdot
.77088 .16277 Mdot
.30568 .1158 Mdot
.1935 .43763 Mdot
.45977 .96281 Mdot
.30949 .72578 Mdot
.32519 .56366 Mdot
.4307 .27063 Mdot
.19119 .26599 Mdot
.93688 .55046 Mdot
.35433 .57466 Mdot
.9261 .54963 Mdot
.1093 .94556 Mdot
.20867 .49245 Mdot
.68433 .8131 Mdot
.08754 .04018 Mdot
.21191 .86126 Mdot
.59277 .28236 Mdot
.7762 .27548 Mdot
.19157 .99201 Mdot
.58886 .08373 Mdot
.24453 .4938 Mdot
.24139 .50285 Mdot
.28399 .91031 Mdot
.2386 .51774 Mdot
.25421 .46325 Mdot
.38816 .65404 Mdot
.26223 .40739 Mdot
.24587 .83894 Mdot
.62572 .088 Mdot
.39591 .53753 Mdot
.48381 .0404 Mdot
.91897 .47478 Mdot
.26276 .54236 Mdot
.62549 .06304 Mdot
.04535 .66729 Mdot
.3701 .52414 Mdot
.64394 .22207 Mdot
.14245 .8173 Mdot
.27787 .92754 Mdot
.65302 .0504 Mdot
.61356 .89375 Mdot
.2406 .5029 Mdot
.19092 .83958 Mdot
.29013 .98208 Mdot
.78772 .27779 Mdot
.56073 .05296 Mdot
.91343 .59505 Mdot
.23383 .53119 Mdot
.24266 .4607 Mdot
.20321 .72364 Mdot
.88807 .46442 Mdot
.32329 .70806 Mdot
.22647 .59029 Mdot
.23178 .31795 Mdot
.17052 .77248 Mdot
.92483 .25363 Mdot
.2457 .49079 Mdot
.28668 .26976 Mdot
.30764 .83927 Mdot
.20451 .74368 Mdot
.24226 .4978 Mdot
.14405 .00597 Mdot
.30096 .98553 Mdot
.65635 .2613 Mdot
.23607 .44871 Mdot
.35538 .04172 Mdot
.22167 .60245 Mdot
.43146 .73669 Mdot
.88699 .16983 Mdot
.24055 .51061 Mdot
.40149 .33735 Mdot
.17106 .76125 Mdot
.24249 .88583 Mdot
.11979 .73113 Mdot
.03083 .90977 Mdot
.27267 .45595 Mdot
.75772 .50612 Mdot
.90301 .39572 Mdot
.5301 .97302 Mdot
.31598 .59744 Mdot
.70349 .77126 Mdot
.20212 .09223 Mdot
.24683 .48614 Mdot
.21115 .42558 Mdot
.06555 .56704 Mdot
.20895 .68561 Mdot
.18793 .67939 Mdot
.76677 .25226 Mdot
.32536 .08691 Mdot
.97687 .90113 Mdot
.72109 .19147 Mdot
.43837 .24825 Mdot
.0728 .4311 Mdot
.33309 .09795 Mdot
.69677 .04133 Mdot
.22734 .75465 Mdot
.76769 .3684 Mdot
.20735 .0361 Mdot
.63031 .7466 Mdot
.29211 .82576 Mdot
.30681 .60113 Mdot
.40619 .94724 Mdot
.60015 .40283 Mdot
.12125 .67582 Mdot
.59343 .06177 Mdot
.58652 .51295 Mdot
.98775 .03354 Mdot
.30947 .75889 Mdot
.22373 .60329 Mdot
.22852 .67284 Mdot
.37063 .89014 Mdot
.96226 .89123 Mdot
.16475 .25001 Mdot
.29583 .96797 Mdot
.37329 .81642 Mdot
.31868 .30452 Mdot
.88118 .81037 Mdot
.65836 .76895 Mdot
.0167 .78572 Mdot
.29453 .98799 Mdot
.72637 .17636 Mdot
.14914 .32461 Mdot
.26157 .32265 Mdot
.2432 .49344 Mdot
.21828 .99716 Mdot
.89118 .47661 Mdot
.70034 .20314 Mdot
.42195 .16361 Mdot
.89234 .42851 Mdot
.80102 .38445 Mdot
.06699 .64398 Mdot
.36415 .45749 Mdot
.24129 .50723 Mdot
.34513 .07277 Mdot
.98185 .18745 Mdot
.21748 .64596 Mdot
.7759 .19278 Mdot
.33181 .13586 Mdot
.18453 .89889 Mdot
.92843 .00146 Mdot
.24006 .51803 Mdot
.21707 .57423 Mdot
.23584 .86912 Mdot
.59005 .12775 Mdot
.13074 .39319 Mdot
.25352 .99184 Mdot
.13036 .16819 Mdot
.11953 .3751 Mdot
.28781 .99826 Mdot
.66392 .16993 Mdot
.23353 .04821 Mdot
.79982 .22306 Mdot
.03708 .58021 Mdot
.70369 .62432 Mdot
.65274 .71819 Mdot
.23386 .52083 Mdot
.67872 .29886 Mdot
.91521 .47312 Mdot
.56761 .13582 Mdot
.86932 .13432 Mdot
.32036 .09723 Mdot
.2217 .89206 Mdot
.19557 .99741 Mdot
.29997 .68459 Mdot
.2389 .49566 Mdot
.6047 .09918 Mdot
.37734 .69151 Mdot
.41935 .58082 Mdot
.79775 .34899 Mdot
.62696 .12776 Mdot
.22456 .23536 Mdot
.80935 .07 Mdot
.90866 .11939 Mdot
.59239 .11203 Mdot
.70898 .10642 Mdot
.2513 .46656 Mdot
.45125 .60966 Mdot
.57502 .29399 Mdot
.19221 .85608 Mdot
.17551 .76118 Mdot
.25977 .50115 Mdot
.3322 .60204 Mdot
.18605 .28724 Mdot
.45664 .61448 Mdot
.2846 .14191 Mdot
.01927 .51011 Mdot
.44075 .11548 Mdot
.65205 .12913 Mdot
.9908 .52641 Mdot
.18932 .77743 Mdot
.87243 .61089 Mdot
.12755 .00255 Mdot
.41685 .13452 Mdot
.6186 .36671 Mdot
.27136 .91618 Mdot
.17015 .80158 Mdot
.19627 .73325 Mdot
.1697 .31645 Mdot
.44081 .60089 Mdot
.35349 .14224 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02Oooool2o`0000;o
oooo0_l00003ooooo`;o00002Oooool00ol0003oooooooooo`09ooooo`;o00000oooool00ol0003o
ooooooooo`02ooooo`;o00002Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00_o
oooo0ol0000?ooooo`03o`000?oooooooooo00;o00001?ooool2o`0000Gooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool01Oooool4o`0000;ooooo0ol0000@ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool02Oooool2o`0000;ooooo0_l00003ooooo`;o0000
2Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo0_l00009ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool02oooool3o`0000oooooo00?o0000ooooooooool0
0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo
000Nooooo`03o`000?oooooooooo02Oooooo0_l00002ooooo`;o00007_ooool2o`0000;ooooo0_l0
0002ooooo`;o00001_ooool2o`0000Cooooo0_l0003Iooooo`;o00002Oooool001kooooo00?o0000
ooooooooool09oooool2o`0001[ooooo0_l00004ooooo`Co00000_ooool2o`0000;ooooo0_l00006
ooooo`;o00001?ooool2o`000=Wooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`0Boooo
o`;o00004oooool2o`0001[ooooo0_l00004ooooo`Co00003_ooool2o`0000Oooooo0_l0000goooo
o`;o0000:Oooool2o`0007gooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0000=ooooo`;o
0000@Oooool4o`0003Gooooo0_l0000Sooooo`;o00001?ooool2o`0007gooooo000Nooooo`03o`00
0?oooooooooo00oooooo0_l0000@ooooo`;o0000@oooool4o`0004kooooo0_l00008ooooo`;o0000
Poooool001kooooo00?o0000ooooooooool03oooool2o`0001oooooo0_l0000fooooo`;o0000=_oo
ool2o`0001Kooooo0_l0002=ooooo`007_ooool00ol0003oooooooooo`0`ooooo`;o00002?ooool2
o`0002Sooooo0ol00004ooooo`;o0000;Oooool2o`0000Cooooo0_l0002Uooooo`007_ooool00ol0
003oooooooooo`0jooooo`;o00009_ooool6o`0000?ooooo0_l0000]ooooo`;o0000Zoooool001ko
oooo00?o0000ooooooooool09oooool2o`0000gooooo0_l0000Hooooo`;o00004?ooool2o`0000;o
oooo0_l00002ooooo`;o0000dOooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo02Oooooo
0_l0000=ooooo`;o00001oooool2o`0000oooooo0_l00005ooooo`;o00004Oooool2o`0000Cooooo
0_l0003;ooooo`Co00001_ooool001kooooo00?o0000ooooooooool06?ooool2o`0002Gooooo0_l0
000Fooooo`;o00002?ooool2o`0000Cooooo0_l00007ooooo`;o00009oooool2o`0004?ooooo0_l0
000=ooooo`;o0000D?ooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo01Sooooo0_l00017
ooooo`;o00001?ooool2o`0000Kooooo0_l0000Xooooo`;o0000@oooool2o`0000Oooooo0_l00004
ooooo`;o0000F?ooool001kooooo00?o0000ooooooooool08_ooool2o`0001?ooooo0_l0000foooo
o`;o0000M_ooool2o`0005kooooo000Nooooo`03o`000?oooooooooo02;ooooo0_l0000=ooooo`;o
00001?ooool2o`0000oooooo0_l0001Hooooo`;o0000;?ooool2o`0007Gooooo000Nooooo`;o0000
<_ooool2o`0001Gooooo0_l0001Eooooo`;o000000?oooooo`000?l000003_ooool2o`0001cooooo
0_l00017ooooo`;o0000;?ooool001kooooo00?o0000ooooooooool0KOooool2o`00033ooooo0_l0
000Aooooo`;o0000IOooool2o`0002cooooo000Nooooo`03o`000?oooooooooo03cooooo0_l0000Z
ooooo`;o00000oooool2o`0000[ooooo0_l0000Gooooo`;o00005oooool2o`0000[ooooo0_l0000h
ooooo`;o0000E?ooool001kooooo00?o0000ooooooooool0??ooool2o`0002[ooooo0_l0000?oooo
o`;o00005oooool2o`0001Oooooo0_l0000:ooooo`;o00001?ooool2o`0003;ooooo0_l0001Doooo
o`007_ooool00ol0003oooooooooo`1=ooooo`;o00006_ooool2o`0000Kooooo0_l0001:ooooo`;o
00001?ooool2o`0000;ooooo0_l0001nooooo`007_ooool00ol0003oooooooooo`03ooooo`;o0000
B?ooool2o`0001[ooooo0_l00006ooooo`;o0000D?ooool2o`0000;ooooo0_l0001nooooo`007_oo
ool00ol0003oooooooooo`03ooooo`;o0000Ioooool2o`000003ooooool0003o000009;ooooo0_l0
0012ooooo`007_ooool00ol0003oooooooooo`1/ooooo`;o000000?oooooo`000?l000001_ooool2
o`0003Cooooo0_l0000Hooooo`;o0000=oooool2o`000003ooooool0003o000004;ooooo000Noooo
o`03o`000?oooooooooo06cooooo0_l00003ooooo`;o00001?ooool2o`0003Cooooo0_l0000<oooo
o`;o000000?oooooo`000?l000001oooool2o`00027ooooo0_l0000Dooooo`;o0000AOooool001ko
oooo00?o0000ooooooooool06_ooool2o`00053ooooo0_l00003ooooo`;o0000B?ooool2o`000003
ooooool0003o000002[ooooo0_l0001Kooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o0000
BOooool2o`0001;ooooo0_l00010ooooo`;o0000R_ooool001kooooo00?o0000ooooooooool0IOoo
ool3o`00017ooooo0_l00002ooooo`;o0000??ooool2o`0008[ooooo000Nooooo`03o`000?oooooo
oooo00;o0000E_ooool2o`0000cooooo0_l00002ooooo`;o00004Oooool2o`0004Sooooo0_l0001n
ooooo`007_ooool00ol0003oooooooooo`02o`0003cooooo0_l0000Hooooo`;o00004?ooool2o`00
0003ooooool0003o000001Cooooo0_l00012ooooo`Co0000O?ooool001kooooo00?o0000oooooooo
ool09_ooool2o`0000Gooooo0_l0000?ooooo`;o0000;Oooool2o`0001Cooooo0_l0000aooooo`;o
00004Oooool2o`0004kooooo0_l0000/ooooo`007_ooool00ol0003oooooooooo`0Vooooo`;o0000
1Oooool2o`0002_ooooo0_l00008ooooo`;o000000Coooooo`000?l0003o00001oooool2o`0002co
oooo0_l0000Eooooo`;o00002?ooool2o`0005Oooooo0_l0000/ooooo`007_ooool2o`0000Cooooo
0_l0001Eooooo`;o00002?ooool2o`000004ooooool0003o0000o`0000Oooooo0_l0000/ooooo`;o
00007oooool2o`0008Gooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0000@ooooo`;o0000
C?ooool2o`0005Sooooo0_l0000Kooooo`;o0000Joooool001kooooo00?o0000ooooooooool00ooo
ool2o`00013ooooo0_l0000Iooooo`;o0000<Oooool2o`0000Cooooo0_l0001Booooo`;o00006ooo
ool2o`0000Kooooo0_l0001Sooooo`007_ooool00ol0003oooooooooo`0Rooooo`;o00003?ooool2
o`0003Oooooo0ol0001@ooooo`;o00003Oooool2o`0001Gooooo0_l0001Eooooo`;o00003?ooool0
01kooooo00?o0000ooooooooool08_ooool2o`0003?ooooo0_l0000Aooooo`;o000000?oooooo`00
0?l000002?ooool2o`0004?ooooo0_l00008ooooo`;o00000oooool2o`0006cooooo0_l0000<oooo
o`007_ooool00ol0003oooooooooo`0Dooooo`;o0000@Oooool2o`0000Kooooo0_l0000<ooooo`;o
00002?ooool2o`0001;ooooo0_l0000iooooo`;o0000Ooooool001kooooo00?o0000ooooooooool0
3Oooool2o`0000Gooooo0_l00019ooooo`;o00005_ooool2o`0001;ooooo0_l0000Dooooo`;o0000
9Oooool2o`0000Gooooo0_l00002ooooo`;o0000C_ooool2o`0002;ooooo000Nooooo`03o`000?oo
oooooooo00gooooo0_l0000mooooo`;o00006oooool2o`0000;ooooo0_l00008ooooo`;o00008?oo
ool2o`0000Kooooo0_l00009ooooo`;o00006_ooool2o`0000Gooooo0_l00002ooooo`;o0000C_oo
ool2o`0002;ooooo000Nooooo`03o`000?oooooooooo04cooooo0_l0000Kooooo`;o00000_ooool2
o`0002[ooooo0_l0000Aooooo`;o00003?ooool2o`0000Cooooo0_l00005ooooo`;o0000O_ooool0
01kooooo00?o0000ooooooooool0Noooool2o`0003gooooo1?l00002ooooo`;o00001Oooool3o`00
00Kooooo0_l00008ooooo`;o0000H?ooool2o`0000Wooooo000Nooooo`03o`000?oooooooooo01Oo
oooo0_l0001Rooooo`;o00005?ooool2o`0002Wooooo1_l00006ooooo`;o00001_ooool2o`0000So
oooo0_l0001Pooooo`;o00002Oooool001kooooo00?o0000ooooooooool05oooool2o`0004oooooo
0_l0000Iooooo`;o00003?ooool2o`00027ooooo0_l00008ooooo`Co00002?ooool2o`0004_ooooo
0_l000000ooooooo0000o`00000Aooooo`;o00006?ooool001kooooo00?o0000ooooooooool0GOoo
ool2o`0000Wooooo0_l0000Iooooo`;o0000;oooool2o`0001Cooooo0_l0001;ooooo`;o000000?o
ooooo`000?l000004Oooool2o`0001Sooooo000Nooooo`03o`000?oooooooooo03Sooooo0_l0000N
ooooo`;o000000?oooooo`000?l000000_l00007ooooo`;o00001oooool2o`0006Kooooo0_l0001^
ooooo`007_ooool00ol0003oooooooooo`0hooooo`;o00007_ooool2o`000003ooooool0003o0000
00Wooooo0_l00007ooooo`;o00000oooool2o`0002Kooooo0_l0000iooooo`;o00002_ooool2o`00
06;ooooo000Nooooo`03o`000?oooooooooo05[ooooo0_l0000Hooooo`;o00004_ooool2o`0001;o
oooo0_l00015ooooo`;o0000H_ooool001kooooo0_l0000Looooo`;o0000?Oooool2o`0002cooooo
0_l0002Yooooo`;o00004_ooool001kooooo00?o0000ooooooooool06oooool2o`0004Wooooo0_l0
002Dooooo`;o0000=Oooool2o`0001;ooooo000Nooooo`03o`000?oooooooooo06Kooooo0_l0001C
ooooo`;o0000?oooool2o`0004Wooooo000Nooooo`03o`000?oooooooooo08Kooooo0_l0000coooo
o`;o0000BOooool2o`0003oooooo000Nooooo`03o`000?oooooooooo08Gooooo0ol00005ooooo`;o
0000J?ooool2o`0000gooooo0_l0000Oooooo`;o00005_ooool2o`0000Kooooo000Nooooo`03o`00
0?oooooooooo08Gooooo0_l00006ooooo`;o0000J?ooool2o`0002kooooo0_l0000Fooooo`;o0000
1_ooool001kooooo00?o0000ooooooooool09_ooool2o`0006_ooooo0_l0000oooooo`;o00003ooo
ool2o`0003Gooooo0_l0000Yooooo`007_ooool00ol0003oooooooooo`0Vooooo`;o0000Joooool2
o`0003oooooo0_l0000?ooooo`;o0000=Oooool2o`0000Gooooo0_l0000Rooooo`007_ooool00ol0
003oooooooooo`0Mooooo`;o0000b?ooool3o`0003Wooooo0_l0000Rooooo`007_ooool00ol0003o
ooooooooo`0Mooooo`;o0000AOooool2o`00087ooooo0ol0001Mooooo`007_ooool00ol0003ooooo
ooooo`1Tooooo`Go0000L?ooool2o`0000gooooo0_l0001Mooooo`007_ooool00ol0003ooooooooo
o`1Vooooo`?o0000:Oooool2o`0004Gooooo0_l0001/ooooo`007_ooool00ol0003oooooooooo`0>
ooooo`;o00007Oooool2o`0006?ooooo0_l0000>ooooo`;o0000>oooool2o`0005[ooooo0_l0000:
ooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o00007Oooool2o`0007?ooooo0_l00003oooo
o`;o0000=_ooool2o`0000Gooooo0_l000000ooooooo0000o`00001@ooooo`;o00002_ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000oooo
ooooool0Yoooool2o`0003gooooo0_l000000ooooooo0000o`00000=ooooo`;o00007oooool3o`00
02_ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q
8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo027ooooo0_l0000kooooo`;o0000D_ooool2
o`0004Cooooo0_l0000Oooooo`?o0000:oooool000?ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0000Qooooo`;o0000>oooool2o`0005;ooooo0_l0001X
ooooo`;o0000:Oooool000?ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^00Kooooo0ol0002Fooooo`;o0000<Oooool2o`0001Gooooo0_l0000jooooo`;o0000:Oooool0
00?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000
ooooooooool0H?ooool2o`0000Kooooo0_l0000/ooooo`;o0000<Oooool2o`0001Gooooo0_l0000@
ooooo`;o00006oooool2o`0003Kooooo0003ooooo`05oa0@4?ooooooooooooooool@41003oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo02kooooo0_l00009ooooo`;o00006?ooool2
o`0000_ooooo0_l00006ooooo`;o0000R?ooool2o`0001_ooooo0_l0000fooooo`000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oo
oooooooo00Sooooo0_l0000Tooooo`?o00002?ooool3o`0001Oooooo0_l0002Gooooo`;o00008_oo
ool2o`0003Gooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`00
0?lQ8B7oc<c<00Kooooo00?o0000ooooooooool01?ooool2o`0000;ooooo0_l0000@ooooo`;o0000
2Oooool2o`0000Sooooo0_l00009ooooo`;o0000/?ooool2o`0002;ooooo0_l0000Fooooo`;o0000
7Oooool001kooooo00?o0000ooooooooool01?ooool2o`0001Cooooo0_l00009ooooo`;o0000jOoo
ool2o`0001Kooooo0_l0000Mooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o0000Noooool2
o`0004Cooooo0_l0000Uooooo`;o00000_ooool2o`0002Sooooo0_l0000Sooooo`007_ooool00ol0
003oooooooooo`0:ooooo`;o0000@Oooool2o`0003Sooooo0_l00014ooooo`;o00009Oooool2o`00
00;ooooo0_l00006ooooo`?o00007oooool2o`0002?ooooo000Nooooo`03o`000?oooooooooo03Go
oooo0_l0000Fooooo`;o0000N?ooool2o`0003Oooooo0ol00014ooooo`007_ooool00ol0003ooooo
ooooo`0eooooo`;o0000>?ooool2o`0005Kooooo0_l00007ooooo`;o0000MOooool001kooooo00?o
0000ooooooooool0Koooool2o`0005oooooo0_l0000Oooooo`;o00002_ooool2o`0000oooooo0ol0
000fooooo`007_ooool00ol0003oooooooooo`15ooooo`;o00000_ooool2o`0009Oooooo0_l0000=
ooooo`;o00002_ooool2o`0000oooooo0ol0000fooooo`007Oooool2o`0004Oooooo0_l00002oooo
o`;o0000T_ooool2o`0000?ooooo0_l0000[ooooo`;o0000=_ooool001gooooo0_l0001Fooooo`;o
0000<oooool2o`0005;ooooo0_l0000:ooooo`;o00009Oooool2o`0003Gooooo000Nooooo`03o`00
0?oooooooooo05Cooooo0_l0000cooooo`;o0000G_ooool2o`000003ooooool0003o0000013ooooo
0_l0000@ooooo`;o0000=Oooool001kooooo00?o0000ooooooooool0<Oooool2o`0005Oooooo0_l0
001Pooooo`;o00004?ooool2o`0004Oooooo000Nooooo`;o0000<_ooool2o`0005Oooooo0_l0001F
ooooo`;o00004Oooool2o`0000cooooo0_l0000Tooooo`;o00007?ooool001kooooo00?o0000oooo
ooooool0h_ooool2o`00017ooooo0_l0000<ooooo`;o00009?ooool2o`0001cooooo000Nooooo`03
o`000?oooooooooo06cooooo0_l0003;ooooo`;o00003?ooool001kooooo00?o0000ooooooooool0
K?ooool2o`0006?ooooo0_l0001Vooooo`;o00003?ooool001kooooo00?o0000ooooooooool0Booo
ool2o`0001gooooo0_l0001Uooooo`;o00005oooool2o`0005_ooooo000Nooooo`03o`000?oooooo
oooo03[ooooo0_l0000?ooooo`;o00007Oooool2o`0002Kooooo0_l0001Fooooo`;o00001?ooool2
o`0001kooooo0_l000000ooooooo0000o`00000booooo`007_ooool00ol0003oooooooooo`0joooo
o`;o00007Oooool2o`00023ooooo0_l0000;ooooo`;o00002?ooool2o`0005cooooo0_l0000<oooo
o`;o00004?ooool2o`000003ooooool0003o000003;ooooo000Nooooo`03o`000?oooooooooo03Co
oooo0_l0000Sooooo`;o00008?ooool2o`0000_ooooo0_l00006ooooo`;o0000I?ooool2o`0000Ko
oooo0_l0000dooooo`;o00004Oooool001kooooo00?o0000ooooooooool0=?ooool2o`0004[ooooo
0_l0000:ooooo`;o00000_ooool2o`0006Cooooo1?l00002ooooo`;o0000=_ooool2o`00017ooooo
000Nooooo`03o`000?oooooooooo01Gooooo0_l0000Iooooo`;o0000C_ooool2o`0000[ooooo0_l0
001Zooooo`;o00000_ooool2o`0004Wooooo000Nooooo`03o`000?oooooooooo01Gooooo0_l0000B
ooooo`;o00001Oooool2o`0008_ooooo0_l0001?ooooo`;o0000=oooool001kooooo00?o0000oooo
ooooool05Oooool2o`0001;ooooo0_l0000=ooooo`;o0000M_ooool2o`0000_ooooo0_l0000eoooo
o`;o00006?ooool2o`0003Oooooo000Nooooo`03o`000?oooooooooo03Sooooo0_l0001fooooo`;o
0000@_ooool2o`0004Wooooo0_l00006ooooo`007_ooool00ol0003oooooooooo`3cooooo`;o0000
B_ooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0000kooooo`;o0000I_oo
ool2o`0003[ooooo0ol0001Aooooo`007_ooool00ol0003oooooooooo`0Booooo`;o00000_ooool2
o`0003Oooooo0_l0001Oooooo`;o00001Oooool2o`00023ooooo0_l0000Iooooo`;o00004?ooool2
o`0003oooooo000Nooooo`;o00005oooool2o`0009Sooooo0_l0000Wooooo`;o0000:oooool2o`00
03oooooo000Nooooo`03o`000?oooooooooo06?ooooo0_l00029ooooo`;o00001?ooool2o`00057o
oooo000Nooooo`03o`000?oooooooooo03Cooooo0_l0000]ooooo`;o0000K_ooool2o`0001Wooooo
0_l00004ooooo`;o0000DOooool001kooooo00?o0000ooooooooool08Oooool2o`00017ooooo0_l0
001mooooo`;o00007_ooool2o`0007;ooooo000Nooooo`03o`000?oooooooooo027ooooo0_l0000F
ooooo`;o0000N?ooool2o`0009;ooooo000Nooooo`03o`000?oooooooooo03?ooooo0_l00004oooo
o`;o00003?ooool2o`0002;ooooo0_l0003Jooooo`007_ooool00ol0003oooooooooo`0cooooo`;o
000000?oooooo`000?l000003oooool2o`0002;ooooo0_l0002Gooooo`;o0000@Oooool001kooooo
00?o0000ooooooooool0=_ooool2o`0001Wooooo0_l0002aooooo`;o0000@Oooool001kooooo00?o
0000ooooooooool0;?ooool2o`0000_ooooo0_l0000Fooooo`;o0000e_ooool2o`0001cooooo000N
ooooo`03o`000?oooooooooo02cooooo0_l0000;ooooo`;o0000AOooool2o`0004Gooooo0_l0001P
ooooo`;o00007?ooool001kooooo00?o0000ooooooooool0P?ooool2o`0000[ooooo0_l0000ioooo
o`;o00009?ooool2o`0005Sooooo000Nooooo`03o`000?oooooooooo08cooooo0_l0001Oooooo`;o
00001?ooool2o`0005;ooooo000Nooooo`03o`000?oooooooooo07kooooo0_l0001cooooo`;o0000
D_ooool001kooooo00?o0000ooooooooool0O_ooool2o`000<Oooooo000Nooooo`03o`000?oooooo
oooo093ooooo0_l0002Jooooo`;o00006Oooool001kooooo00?o0000ooooooooool0T?ooool2o`00
06Kooooo0_l00005ooooo`;o0000:oooool2o`0001Wooooo000Nooooo`;o0000;?ooool2o`000<_o
oooo0_l00005ooooo`;o0000A_ooool001kooooo00?o0000ooooooooool0:oooool2o`0004[ooooo
0_l0001/ooooo`;o0000H?ooool001kooooo00?o0000ooooooooool0>?ooool2o`0001_ooooo0_l0
000Pooooo`;o0000K?ooool2o`00063ooooo000Nooooo`03o`000?oooooooooo03Sooooo0_l0000K
ooooo`;o0000U_ooool2o`0005Sooooo000Nooooo`03o`000?oooooooooo0>gooooo0_l0001Hoooo
o`007_ooool00ol0003oooooooooo`0kooooo`;o0000R?ooool2o`00083ooooo000Nooooo`03o`00
0?oooooooooo03_ooooo0_l00028ooooo`;o0000;_ooool2o`0000[ooooo0_l00014ooooo`007_oo
ool00ol0003oooooooooo`3eooooo`;o00002_ooool2o`0004Cooooo000Nooooo`03o`000?oooooo
oooo02?ooooo0_l0000Zooooo`;o0000^_ooool2o`0002Kooooo0_l0000Booooo`007_ooool00ol0
003oooooooooo`0Sooooo`;o00006oooool4o`0000_ooooo0_l0002cooooo`;o00000oooool4o`00
02Kooooo0_l0000Booooo`007_ooool00ol0003oooooooooo`0Nooooo`;o00003_ooool2o`00013o
oooo1?l0001Tooooo`;o0000F_ooool2o`0000?ooooo0_l0000looooo`007_ooool00ol0003ooooo
ooooo`0Nooooo`;o00003_ooool2o`0007Sooooo0_l0001Fooooo`?o0000A?ooool001kooooo00?o
0000ooooooooool0BOooool2o`000003ooooool0003o000001Cooooo0_l0002Looooo`?o0000A?oo
ool001kooooo00?o0000ooooooooool0BOooool2o`000003ooooool0003o000000Wooooo0_l00009
ooooo`;o0000>oooool2o`000:Kooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo02Kooooo0_l0000_
ooooo`;o0000A_ooool2o`0001Wooooo0_l0002;ooooo`000oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09_ooool2
o`0004Oooooo0_l00019ooooo`;o0000IOooool2o`0002Cooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41002oooool5o`0000Kooooo0ol0001Aooooo`;o00007?ooool2o`000;3ooooo0_l0000T
ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001ooo
ool00ol0003oooooooooo`1Aooooo`;o0000K?ooool2o`0008Kooooo0003ooooo`05o`000?oooooo
ooooooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo03oooooo
0_l0000@ooooo`;o00004Oooool2o`0003Cooooo0_l0000Sooooo`;o0000Q_ooool000?ooooo00Go
410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0
4?ooool2o`0001_ooooo0_l0000@ooooo`;o00004?ooool2o`0000Wooooo0_l00006ooooo`;o0000
2?ooool2o`0002[ooooo0_l0002[ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo
00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0@ooooo`;o00006oooool2o`0002Sooooo
0_l00003ooooo`;o00001_ooool2o`0000Sooooo0_l0000Mooooo`;o00001oooool2o`0009Gooooo
0_l0000Hooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool0
1_ooool00ol0003oooooooooo`1Gooooo`;o00002oooool2o`0002Oooooo0_l00007ooooo`;o0000
NOooool2o`0001[ooooo0_l0000Hooooo`007_ooool00ol0003oooooooooo`25ooooo`;o0000Kooo
ool2o`0001Wooooo0_l0000dooooo`007_ooool00ol0003oooooooooo`25ooooo`;o0000Koooool2
o`0004oooooo000Nooooo`03o`000?oooooooooo047ooooo0_l00028ooooo`;o0000EOooool2o`00
02?ooooo000Nooooo`03o`000?oooooooooo047ooooo0_l00028ooooo`;o0000DOooool2o`0000;o
oooo0_l0000Sooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o0000;oooool2o`0001Oooooo
0_l0000;ooooo`;o0000A?ooool2o`0003Cooooo0_l0000eooooo`;o00009oooool001kooooo00?o
0000ooooooooool05?ooool2o`0002oooooo0_l0000Gooooo`;o00000_ooool2o`0000Oooooo0_l0
0014ooooo`;o0000=?ooool2o`0005kooooo000Nooooo`03o`000?oooooooooo03_ooooo0_l0000U
ooooo`;o0000F_ooool2o`0008Oooooo000Nooooo`03o`000?oooooooooo03_ooooo0_l0000Qoooo
o`;o0000G_ooool2o`0003Gooooo0_l0001@ooooo`007_ooool00ol0003oooooooooo`0dooooo`;o
00003oooool2o`0000[ooooo0_l0000;ooooo`;o0000J?ooool2o`0002_ooooo0_l0000Mooooo`;o
0000<Oooool001kooooo00?o0000ooooooooool0=?ooool2o`0000?ooooo0_l0000:ooooo`;o0000
0oooool2o`0000Gooooo0_l0000hooooo`;o0000>oooool2o`0004[ooooo0_l0000aooooo`007_oo
ool00ol0003oooooooooo`0iooooo`;o00003_ooool3o`0000?ooooo0_l0000jooooo`;o0000^_oo
ool001kooooo0_l0001:ooooo`?o00000oooool2o`0000[ooooo0_l0000Looooo`;o0000c?ooool0
01kooooo00?o0000ooooooooool0B_ooool2o`0000;ooooo0_l00005ooooo`;o00001?ooool2o`00
01Oooooo0_l00003ooooo`;o0000WOooool2o`0002gooooo000Nooooo`03o`000?oooooooooo04co
oooo1?l00005ooooo`;o00002Oooool2o`00013ooooo1?l0002Rooooo`;o0000;Oooool001kooooo
00?o0000ooooooooool0B_ooool4o`0001;ooooo0_l0000@ooooo`;o00000oooool2o`0005?ooooo
0_l0001:ooooo`;o0000;Oooool001kooooo00?o0000ooooooooool00_ooool2o`0004Kooooo0ol0
0002ooooo`;o00009_ooool2o`0005?ooooo0_l00007ooooo`;o0000@Oooool2o`0000?ooooo0_l0
000Xooooo`007_ooool00ol0003oooooooooo`02ooooo`;o0000B_ooool3o`0008Cooooo0_l00016
ooooo`;o0000:?ooool001kooooo00?o0000ooooooooool0C_ooool2o`000?Oooooo000Nooooo`03
o`000?oooooooooo05cooooo0_l00037ooooo`Co00007_ooool001kooooo00?o0000ooooooooool0
C?ooool2o`0000kooooo0_l0001[ooooo`;o0000D_ooool3o`0000Gooooo1?l0000Nooooo`007_oo
ool00ol0003oooooooooo`14ooooo`;o00001_ooool2o`0002?ooooo0_l0001Fooooo`;o0000D_oo
ool3o`0000[ooooo0_l0000Kooooo`007_ooool00ol0003oooooooooo`14ooooo`;o00001?ooool4
o`0000Cooooo0_l0000Mooooo`;o00001_ooool2o`000:oooooo0_l0000Kooooo`007_ooool00ol0
003oooooooooo`1:ooooo`Co00001?ooool2o`0001cooooo0_l00007ooooo`;o0000UOooool2o`00
03Gooooo000Nooooo`03o`000?oooooooooo04Wooooo0_l000000ooooooo0000o`00000Jooooo`;o
00001_ooool2o`0009kooooo0_l0000eooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o0000
7oooool4o`0000Oooooo1Ol00006ooooo`;o00004_ooool2o`0001Kooooo0_l0002Xooooo`;o0000
6oooool001kooooo00?o0000ooooooooool07Oooool2o`0001oooooo1?l00007ooooo`Go00001_oo
ool2o`0002[ooooo0_l0002Cooooo`;o00003?ooool2o`0000Gooooo0_l0000?ooooo`;o00002_oo
ool001kooooo00?o0000ooooooooool0??ooool2o`0000_ooooo1?l00038ooooo`;o00003?ooool3
o`0001Gooooo0_l0000:ooooo`007_ooool2o`0003gooooo0_l0000;ooooo`Co00000oooool2o`00
00kooooo0_l00032ooooo`;o00008Oooool001gooooo0_l00003ooooo`;o0000Aoooool3o`0000?o
oooo0_l0000>ooooo`;o00005_ooool2o`000:cooooo0_l0000Oooooo`007Oooool2o`0000?ooooo
0_l00016ooooo`Co0000:oooool2o`0007Sooooo0_l0000booooo`;o00004oooool2o`0000[ooooo
000Nooooo`03o`000?oooooooooo00;ooooo0_l00015ooooo`Co0000YOooool2o`0004Oooooo0_l0
000:ooooo`007_ooool00ol0003oooooooooo`02ooooo`;o0000A_ooool3o`0002Gooooo0_l00005
ooooo`;o0000@?ooool2o`0007_ooooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`19oooo
o`?o00008Oooool2o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l00000@?ooool2o`00
00cooooo0_l0000]ooooo`;o0000?_ooool2o`0000gooooo000Nooooo`03o`000?oooooooooo04So
oooo1Ol0000Pooooo`;o00001oooool2o`00057ooooo0_l0000]ooooo`;o0000COooool001kooooo
00?o0000ooooooooool0AOooool2o`000003ooooool0003o000000?o00009oooool2o`0009Gooooo
0_l0000Xooooo`;o00004?ooool001kooooo00?o0000ooooooooool0AOooool2o`0000;ooooo0_l0
000Booooo`;o00005Oooool2o`0009Gooooo0_l0000Xooooo`;o00001oooool2o`0000Oooooo000N
ooooo`03o`000?oooooooooo03Wooooo0_l0000Rooooo`;o0000A?ooool2o`0005?ooooo0_l0000d
ooooo`;o00003_ooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo03Wooooo0_l0000=oooo
o`;o00003Oooool2o`0000Kooooo0_l00002ooooo`;o00002_ooool2o`0003;ooooo0_l0001Coooo
o`;o0000=?ooool2o`0000Oooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`0Yooooo`;o
00007Oooool6o`0000Wooooo0_l00006ooooo`;o00000_ooool2o`0000[ooooo0_l0001`ooooo`;o
0000E?ooool2o`0000kooooo000Nooooo`03o`000?oooooooooo02Wooooo0_l0000Mooooo`Ko0000
7_ooool2o`0000Oooooo0ol00005ooooo`;o0000H_ooool2o`0003;ooooo0_l0000Pooooo`;o0000
3_ooool001kooooo00?o0000ooooooooool0B?ooool2o`0000Oooooo0_l0000Iooooo`;o00001ooo
ool3o`0000Gooooo0_l0000`ooooo`;o00004_ooool2o`00053ooooo0_l0000Gooooo`;o00005ooo
ool001kooooo00?o0000ooooooooool0Aoooool2o`0000Sooooo0_l0000Rooooo`;o0000>?ooool2
o`0000Gooooo0_l0000;ooooo`;o0000Foooool2o`0000cooooo0_l00004ooooo`;o00004Oooool0
01kooooo00?o0000ooooooooool0Aoooool2o`0002Kooooo0_l00015ooooo`;o0000J?ooool2o`00
01;ooooo0_l0000Aooooo`007_ooool2o`0004Wooooo0_l0000Looooo`;o00000_ooool2o`0000?o
oooo0_l00003ooooo`;o00003?ooool2o`000:Gooooo0_l000000ooooooo0000o`00000Iooooo`00
7_ooool00ol0003oooooooooo`18ooooo`;o00007?ooool2o`0000;ooooo0_l00008ooooo`;o0000
0_ooool2o`0000Sooooo0_l0002Uooooo`;o000000?oooooo`000?l000006Oooool001kooooo0_l0
0018ooooo`;o0000;oooool2o`000<gooooo000Nooooo`;o0000??ooool2o`0000[ooooo0_l00007
ooooo`;o00006_ooool2o`0000?ooooo0_l0003Dooooo`007_ooool00ol0003oooooooooo`0koooo
o`;o00002oooool2o`0000Kooooo0_l0000Dooooo`;o00001?ooool2o`0000?ooooo0_l00030oooo
o`;o00004_ooool001kooooo00?o0000ooooooooool04Oooool2o`0002Sooooo0_l0000:ooooo`?o
00004_ooool2o`0000Sooooo0_l00009ooooo`;o0000`?ooool2o`000003ooooool0003o000000oo
oooo000Nooooo`03o`000?oooooooooo017ooooo0_l0000Xooooo`;o00002_ooool2o`0001?ooooo
0_l0003<ooooo`;o00002_ooool2o`0000oooooo000Nooooo`03o`000?oooooooooo057ooooo0_l0
003Gooooo`;o000000?oooooo`000?l000006?ooool001kooooo00?o0000ooooooooool0@_ooool2
o`0000;ooooo0_l00009ooooo`;o00006Oooool2o`000003ooooool0003o000000_ooooo0_l0002_
ooooo`;o00006?ooool001kooooo00?o0000ooooooooool0@_ooool2o`0000;ooooo0_l0000Toooo
o`;o000000?oooooo`000?l000001_ooool2o`0000?ooooo0_l00039ooooo`007_ooool00ol0003o
ooooooooo`08ooooo`;o0000?oooool2o`0002cooooo0_l0000:ooooo`?o0000Z?ooool2o`0001Oo
oooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0000oooooo`;o00001Oooool2o`0002Kooooo
0_l00009ooooo`?o0000WOooool2o`0000Wooooo0_l0000Gooooo`007_ooool00ol0003ooooooooo
o`16ooooo`;o00002?ooool2o`0001Kooooo0_l00007ooooo`;o00001Oooool2o`0008oooooo0_l0
000Hooooo`;o00008_ooool001kooooo00?o0000ooooooooool0@Oooool2o`0000?ooooo0_l0000P
ooooo`;o00001oooool2o`0000kooooo0_l00026ooooo`;o0000??ooool000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o
0000ooooooooool0@Oooool2o`0000?ooooo0_l00004ooooo`;o00004Oooool2o`00023ooooo0_l0
002Rooooo`;o00008?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0C?ooool4o`0000oooooo
0_l00002ooooo`;o00001Oooool2o`0000cooooo0_l00022ooooo`;o00003_ooool2o`0001Oooooo
0_l0000Pooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooooooo
ooooo`000006ooooo`?o00001oooool2o`0003[ooooo0_l00009ooooo`;o00004?ooool2o`000003
ooooool0003o000000Gooooo0_l00003ooooo`;o00001_ooool3o`00017ooooo0_l0001_ooooo`;o
00003_ooool2o`0000cooooo0_l0000Gooooo`;o00004_ooool000?ooooo00Go0000oooooooooooo
ooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`07oooo
o`;o0000>_ooool4o`0001Wooooo0_l00006ooooo`;o00001Oooool2o`0000Kooooo0_l0000Boooo
o`;o0000SOooool2o`0001Oooooo0_l0000Booooo`000oooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo04Cooooo0ol0000Q
ooooo`;o00003Oooool2o`000<;ooooo0_l0000:ooooo`000oooool01Ol@413ooooooooooooooooo
410@00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`2?ooooo`;o0000Z_ooool2
o`0000[ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008
ooooo`03o`000?oooooooooo04Wooooo0_l00007ooooo`;o00009oooool2o`0001;ooooo0_l00027
ooooo`;o0000;Oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co
0000oa0@40Kooooo00?o0000ooooooooool0<oooool2o`0001Cooooo0_l00007ooooo`;o00009ooo
ool2o`00017ooooo1?l00026ooooo`;o00008_ooool2o`0000Wooooo000Nooooo`03o`000?oooooo
oooo03?ooooo0_l0000Booooo`;o0000=_ooool2o`0000gooooo1?l0002Aooooo`;o00005oooool2
o`0000Wooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l00011ooooo`;o0000<?ooool2o`00
00Cooooo0_l0000?ooooo`;o0000N?ooool2o`0001Oooooo0_l0000Rooooo`007_ooool00ol0003o
ooooooooo`04ooooo`;o0000<Oooool2o`0002gooooo0_l0000Aooooo`;o00005Oooool2o`0004oo
oooo0_l0000Wooooo`;o0000>oooool001kooooo00?o0000ooooooooool0=oooool2o`0002Cooooo
0_l00007ooooo`;o00000oooool2o`0002Cooooo0_l0001>ooooo`;o0000I?ooool001kooooo00?o
0000ooooooooool0B_ooool2o`00017ooooo0_l0000<ooooo`;o00009?ooool2o`000;Cooooo000N
ooooo`03o`000?oooooooooo04Kooooo0_l00002ooooo`;o0000;_ooool2o`0001_ooooo0_l0002^
ooooo`007_ooool00ol0003oooooooooo`06ooooo`;o0000?_ooool2o`0003;ooooo0_l00006oooo
o`;o00004oooool2o`000:kooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l0001^ooooo`;o
00002_ooool2o`000003ooooool0003o00000<3ooooo000Nooooo`03o`000?oooooooooo01;ooooo
0_l0000aooooo`;o0000;oooool2o`0000gooooo0_l0000Qooooo`;o00003Oooool2o`0008kooooo
000Nooooo`03o`000?oooooooooo01;ooooo0_l0000^ooooo`Go0000;Oooool2o`0003;ooooo0_l0
000=ooooo`;o0000S_ooool001kooooo00?o0000ooooooooool0@_ooool3o`00023ooooo0_l0000=
ooooo`;o0000;Oooool2o`0003Cooooo0_l00011ooooo`;o0000:Oooool001kooooo0_l00013oooo
o`;o00008Oooool2o`0003cooooo0_l0000dooooo`;o0000@Oooool2o`0002Wooooo000Nooooo`03
o`000?oooooooooo047ooooo0_l0000gooooo`;o00006oooool2o`000:kooooo000Nooooo`03o`00
0?oooooooooo047ooooo0_l0000dooooo`;o000000?oooooo`000?l000006oooool2o`0002cooooo
0_l0000Nooooo`;o00001_ooool2o`0005Sooooo000Nooooo`03o`000?oooooooooo047ooooo0_l0
000dooooo`;o00005oooool2o`0001Gooooo0_l00008ooooo`;o00004_ooool4o`0001cooooo0_l0
0006ooooo`;o0000F?ooool001kooooo00?o0000ooooooooool0@Oooool2o`0004gooooo0_l0000E
ooooo`;o00002?ooool2o`0001Cooooo0_l0000fooooo`;o0000<Oooool2o`0001?ooooo000Noooo
o`03o`000?oooooooooo00_ooooo0_l0000dooooo`;o0000_?ooool2o`00037ooooo0_l0000Coooo
o`007_ooool00ol0003oooooooooo`0;ooooo`;o0000=?ooool2o`000003ooooool0003o000006go
oooo0_l0002Booooo`007_ooool00ol0003oooooooooo`0hooooo`;o00001oooool2o`000003oooo
ool0003o000000;o0000Joooool2o`0009;ooooo000Nooooo`03o`000?oooooooooo02?ooooo0_l0
000Cooooo`;o00001oooool2o`0000?ooooo0_l00008ooooo`;o00001_ooool2o`0004Wooooo0_l0
000=ooooo`;o0000Aoooool2o`0004[ooooo000Nooooo`03o`000?oooooooooo02?ooooo0_l0000D
ooooo`;o00005Oooool2o`0000Kooooo0_l00019ooooo`;o00003Oooool2o`0000Cooooo0_l00011
ooooo`;o0000B_ooool001kooooo00?o0000ooooooooool0>Oooool2o`0001Oooooo0_l0001Toooo
o`;o0000<oooool2o`0005Sooooo000Nooooo`03o`000?oooooooooo043ooooo0_l0000@ooooo`;o
00002Oooool2o`0008kooooo0_l0000fooooo`;o00008?ooool001kooooo00?o0000ooooooooool0
?oooool3o`0001_ooooo0_l00036ooooo`;o00008?ooool001kooooo00?o0000ooooooooool0?ooo
ool3o`0003Gooooo0_l0001Uooooo`;o0000>_ooool2o`0001gooooo0_l0000<ooooo`007_ooool0
0ol0003oooooooooo`1Gooooo`;o00007_ooool2o`0002Oooooo0_l00003ooooo`;o0000=oooool2
o`0003[ooooo0_l0000Mooooo`;o00003?ooool001kooooo00?o0000ooooooooool0@?ooool2o`00
01Gooooo0_l00017ooooo`;o00000oooool2o`000:3ooooo000Nooooo`;o0000@Oooool2o`000?oo
oooo1_ooool001kooooo00?o0000ooooooooool01_ooool2o`0003Sooooo0_l0001Sooooo`;o0000
X?ooool001kooooo00?o0000ooooooooool01_ooool2o`0003Cooooo0_l00003ooooo`;o00008_oo
ool2o`0003kooooo0_l0002:ooooo`;o00005?ooool001kooooo00?o0000ooooooooool0??ooool2
o`0000?ooooo0_l0000Rooooo`;o0000b_ooool2o`0001Cooooo000Nooooo`03o`000?oooooooooo
02[ooooo0_l0000Iooooo`;o0000ooooool1ooooo`007_ooool00ol0003oooooooooo`0Zooooo`;o
00006Oooool2o`0005cooooo0_l0002Rooooo`007_ooool00ol0003oooooooooo`1/ooooo`;o0000
=Oooool2o`0002_ooooo0_l0001eooooo`007_ooool00ol0003oooooooooo`0nooooo`;o0000;?oo
ool2o`0001gooooo0_l00013ooooo`;o0000MOooool001kooooo00?o0000ooooooooool0?_ooool2
o`00027ooooo0_l0000Xooooo`;o0000^_ooool001kooooo00?o0000ooooooooool0>?ooool2o`00
00Cooooo0_l0000Qooooo`;o0000i?ooool001kooooo00?o0000ooooooooool08oooool2o`0001?o
oooo0_l00002ooooo`Co0000Doooool2o`0000[ooooo0_l0002Vooooo`007_ooool00ol0003ooooo
ooooo`0Sooooo`;o00005oooool4o`0005?ooooo0_l0000:ooooo`;o0000Y_ooool001kooooo00?o
0000ooooooooool02_ooool2o`0004?ooooo0_l0000gooooo`;o0000K_ooool2o`0000Gooooo0_l0
0016ooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o0000@oooool2o`0003Oooooo0_l0000M
ooooo`;o0000Coooool2o`0000Gooooo0_l00016ooooo`007_ooool00ol0003oooooooooo`0noooo
o`;o0000AOooool2o`0000gooooo0_l0000Aooooo`;o0000W_ooool001kooooo00?o0000oooooooo
ool0?_ooool2o`0004Gooooo0_l00005ooooo`;o00001_ooool2o`0003?ooooo0_l0001Oooooo`;o
00006oooool001kooooo0_l0000mooooo`;o00002Oooool2o`0004?ooooo0_l0000kooooo`;o0000
Goooool2o`00017ooooo0_l00008ooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o0000:?oo
ool3o`0000Sooooo0ol00004ooooo`;o00002_ooool2o`000>;ooooo0_l00008ooooo`007_ooool0
0ol0003oooooooooo`0Aooooo`;o0000:?ooool2o`0000Wooooo0_l00005ooooo`;o00002_ooool2
o`0002_ooooo0_l0001<ooooo`;o0000LOooool001kooooo00?o0000ooooooooool06_ooool2o`00
02gooooo0_l0000Eooooo`;o00009?ooool2o`0004cooooo0_l0001aooooo`007_ooool00ol0003o
ooooooooo`0<ooooo`;o00003?ooool2o`0001Oooooo1?l0000Booooo`;o00002Oooool2o`0000[o
oooo0_l0003Uooooo`007_ooool00ol0003oooooooooo`02o`0000[ooooo0_l0000Uooooo`Co0000
7Oooool2o`000?7ooooo000Nooooo`03o`000?oooooooooo00;o0000d?ooool2o`0007?ooooo000N
ooooo`03o`000?oooooooooo00;o0000<Oooool2o`0000Oooooo1?l0001:ooooo`;o0000A_ooool2
o`0000gooooo0_l0001Tooooo`007_ooool00ol0003oooooooooo`02o`00037ooooo0_l00007oooo
o`Co0000B_ooool2o`0005Gooooo0_l0001Tooooo`007_ooool00ol0003oooooooooo`0iooooo`;o
00001_ooool2o`0005;ooooo0_l0002`ooooo`007_ooool00ol0003oooooooooo`0iooooo`;o0000
1_ooool2o`0000Oooooo0_l00019ooooo`;o0000/?ooool001kooooo00Co0000oooooooooooooooo
0_l0000iooooo`;o00003?ooool2o`000?_ooooo000Nooooo`04o`000?ooooooooooooooo`;o0000
>Oooool2o`0006?ooooo0_l0002Tooooo`007_ooool00ol0003oooooooooo`2Qooooo`;o0000Y?oo
ool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`00
0?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0>?ooool2o`0000Gooooo0_l0000Cooooo`;o0000
5_ooool2o`0000gooooo0_l0003:ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0hooooo`;o
00001Oooool2o`0001?ooooo0_l0000Fooooo`;o00003?ooool3o`000;7ooooo0_l0000Gooooo`00
0oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006oooo
o`?o0000B_ooool2o`0002kooooo0_l0002booooo`;o00005oooool000?ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool00ol0003oooooooooo`0c
ooooo`;o00005Oooool2o`000?_ooooo0003ooooo`05o`000?ooooooooooooooool000002oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0<oooool3o`0000;ooooo0_l0
001Pooooo`;o0000Zoooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj
^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`0dooooo`;o00000_ooool2o`0000Kooooo
0_l0001Hooooo`;o0000Zoooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`0Yooooo`;o00001_ooool2o`0000[o
oooo0_l000000ooooooo0000o`00002Hooooo`;o00001_ooool2o`0003Kooooo0ol0000Zooooo`00
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06oooo
o`03o`000?oooooooooo02Wooooo0ol00005ooooo`;o00001_ooool2o`0000;ooooo0_l0000foooo
o`;o0000Hoooool2o`0000Kooooo0_l0000fooooo`?o0000:_ooool001kooooo00?o0000oooooooo
ool0:_ooool2o`0000gooooo0_l0000jooooo`;o0000d?ooool001kooooo00?o0000ooooooooool0
:_ooool2o`0000Oooooo0_l0002[ooooo`;o0000IOooool001kooooo00?o0000ooooooooool0<ooo
ool2o`0001Gooooo0_l00013ooooo`;o0000Coooool2o`0006Gooooo000Nooooo`03o`000?oooooo
oooo04[ooooo0ol0000>ooooo`;o0000<_ooool2o`000;Kooooo000Nooooo`03o`000?oooooooooo
03Sooooo0ol00006ooooo`;o00002?ooool2o`0000kooooo0_l0003Zooooo`007_ooool00ol0003o
ooooooooo`0hooooo`?o00001_ooool2o`0000Oooooo0_l0000oooooo`;o0000;Oooool2o`0008_o
oooo000Nooooo`03o`000?oooooooooo00cooooo0_l00003ooooo`;o00009Oooool2o`000003oooo
ool0003o000000gooooo0_l0000?ooooo`;o0000;_ooool4o`0002_ooooo0_l0002;ooooo`007_oo
ool00ol0003oooooooooo`0<ooooo`;o00000oooool2o`0002?ooooo1ol0000?ooooo`;o00003Ooo
ool2o`0000?ooooo0_l0000[ooooo`;o0000^?ooool001kooooo00?o0000ooooooooool0=_ooool2
o`0000;ooooo0_l0000@ooooo`;o00004_ooool2o`000>Gooooo000Nooooo`03o`000?oooooooooo
03Cooooo0_l00008ooooo`;o00002?ooool2o`000?gooooo000Nooooo`04o`000?oooooooooooooo
o`;o0000<Oooool2o`0000Sooooo0_l000000ooooooo0000o`000005ooooo`;o0000oOooool001ko
oooo0_l00002ooooo`;o00008?ooool2o`0000?ooooo0_l00006ooooo`Co00003Oooool2o`0001_o
oooo0_l0000Vooooo`;o0000Uoooool2o`0002Kooooo000Nooooo`03o`000?oooooooooo02;ooooo
0ol00003ooooo`;o00001_ooool4o`0000Kooooo0_l0000Rooooo`;o00009_ooool2o`0002Sooooo
0_l0001]ooooo`;o00009_ooool001kooooo00?o0000ooooooooool08?ooool4o`0001Kooooo0_l0
001dooooo`;o00006?ooool2o`0004Oooooo0_l0000booooo`007_ooool00ol0003oooooooooo`0P
ooooo`;o00007oooool2o`0000cooooo0_l0001iooooo`;o0000Aoooool2o`0003;ooooo000Noooo
o`03o`000?oooooooooo00;o00000oooool2o`0003[ooooo0_l0000<ooooo`;o0000m_ooool001ko
oooo00?o0000ooooooooool00_l00003ooooo`;o00004oooool2o`0000Gooooo0_l0000Yooooo`;o
0000nOooool001kooooo00?o0000ooooooooool06_ooool2o`0000Gooooo0_l0000Vooooo`;o0000
00?oooooo`000?l00000Moooool2o`00063ooooo0_l0000Nooooo`007_ooool00ol0003ooooooooo
o`19ooooo`;o0000N_ooool2o`00063ooooo0_l0000Nooooo`007_ooool00ol0003oooooooooo`15
ooooo`;o0000Doooool2o`000:_ooooo000Nooooo`03o`000?oooooooooo04Gooooo0ol0001Boooo
o`;o0000:Oooool2o`00083ooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l0000Pooooo`;o
00000_ooool2o`0007Wooooo0_l00020ooooo`007_ooool00ol0003oooooooooo`05ooooo`;o0000
6_ooool2o`000003ooooool0003o000000Wooooo0_l0000Eooooo`;o00000_ooool3o`0001cooooo
0_l00027ooooo`;o0000Doooool001kooooo00?o0000ooooooooool01Oooool2o`0000?ooooo0_l0
000Eooooo`;o00003?ooool2o`0001Wooooo0ol0000Looooo`;o00002Oooool2o`0001Kooooo0_l0
00000ooooooo0000o`00000Booooo`;o0000COooool2o`0005?ooooo000Nooooo`03o`000?oooooo
oooo00[ooooo0_l0000hooooo`;o00000oooool3o`0002Sooooo0_l0000Fooooo`;o000000?ooooo
o`000?l000002oooool2o`0000Gooooo0_l0000>ooooo`;o0000Hoooool2o`0001_ooooo0_l0000@
ooooo`007_ooool01?l0003oooooooooooooool2o`00047ooooo0_l00003ooooo`;o0000DOooool2
o`0001Gooooo0_l0000>ooooo`;o0000Doooool2o`0001_ooooo0_l0000@ooooo`007_ooool01?l0
003oooooooooooooool2o`0003Gooooo0_l0000Cooooo`;o0000M?ooool2o`0008;ooooo000Noooo
o`;o0000>Oooool2o`0000Cooooo0_l0000=ooooo`;o0000foooool2o`0000gooooo0_l0000<oooo
o`007_ooool00ol0003oooooooooo`0Aooooo`;o00004_ooool2o`0000;ooooo0_l0000@ooooo`;o
000000?oooooo`000?l000002?ooool4o`0000Sooooo0_l0002cooooo`;o00007oooool2o`0000go
oooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`07ooooo`;o00002?ooool2o`0001;ooooo
0_l00002ooooo`;o00003_ooool4o`0000?ooooo0_l00002ooooo`;o00000_ooool4o`0000Sooooo
0_l0000:ooooo`;o0000Yoooool2o`0003cooooo000Nooooo`03o`000?oooooooooo00Kooooo0ol0
000`ooooo`;o00001Oooool2o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`;o000000?o
ooooo`000?l000001Oooool2o`0000Kooooo0_l0003Uooooo`007_ooool00ol0003oooooooooo`06
ooooo`;o0000?oooool2o`0000Gooooo0_l000000ooooooo0000o`000005ooooo`;o00002_ooool2
o`00073ooooo0_l0001_ooooo`007_ooool00ol0003oooooooooo`02o`0002Kooooo1?l0000:oooo
o`;o00002Oooool2o`0000cooooo0_l00003ooooo`;o00003_ooool2o`00073ooooo0_l0001_oooo
o`007_ooool00ol0003oooooooooo`02o`0002Kooooo1?l0000:ooooo`;o00002Oooool2o`0000_o
oooo0ol00003ooooo`;o0000lOooool001kooooo00?o0000ooooooooool0BOooool2o`0000?ooooo
0_l0000mooooo`;o00007Oooool2o`0009Wooooo000Nooooo`03o`000?oooooooooo00kooooo0_l0
000iooooo`;o0000@_ooool2o`0001gooooo0_l0002Iooooo`007_ooool00ol0003oooooooooo`0>
ooooo`;o0000=oooool2o`0000gooooo0_l0003Booooo`;o00006oooool001kooooo00?o0000oooo
ooooool0Aoooool2o`0000Kooooo0_l00005ooooo`;o00004oooool2o`000;gooooo0_l0000Koooo
o`007_ooool00ol0003oooooooooo`17ooooo`;o00001_ooool2o`0001[ooooo0_l0003Jooooo`00
7_ooool00ol0003oooooooooo`17ooooo`;o0000o_ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`0Mooooo`Co0000I?ooool2o`0009oooooo0_l00009
ooooo`;o00005?ooool001kooooo00?o0000ooooooooool07Oooool4o`0005oooooo0_l00003oooo
o`;o0000Woooool2o`0000Wooooo0_l0000Dooooo`007_ooool2o`0003kooooo0_l00011ooooo`;o
0000[oooool2o`0001Cooooo000Nooooo`03o`000?oooooooooo03gooooo0_l0000jooooo`;o0000
]_ooool2o`0001Cooooo000Nooooo`03o`000?oooooooooo04;ooooo0_l0000Gooooo`;o00007?oo
ool2o`000<cooooo000Nooooo`03o`000?oooooooooo04;ooooo0_l0000Gooooo`;o0000Hoooool2
o`0007Gooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`1Sooooo`;o0000;?ooool2o`00
01cooooo0_l0000?ooooo`;o0000MOooool2o`0000kooooo000Nooooo`03o`000?oooooooooo03[o
oooo0_l0000Looooo`;o00002Oooool2o`0002Kooooo0_l00004ooooo`;o00007?ooool2o`0002oo
oooo0_l0001Uooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o00006oooool2o`0000Sooooo
0_l00009ooooo`;o00004Oooool3o`000003ooooool0003o000002gooooo0_l0001Cooooo`;o0000
IOooool001kooooo00?o0000ooooooooool02oooool2o`0000Kooooo0_l0000Kooooo`;o00004ooo
ool4o`00013ooooo0_l000000ooooooo0000o`000003ooooo`;o0000AOooool2o`0009gooooo000N
ooooo`03o`000?oooooooooo00_ooooo0_l0000jooooo`;o00003oooool2o`0000;ooooo0_l00003
ooooo`;o00000_ooool2o`0000_ooooo0_l0000aooooo`;o000000?oooooo`000?l00000WOooool0
01kooooo00?o0000ooooooooool08?ooool2o`0003Kooooo0_l00002ooooo`;o00001oooool2o`00
00_ooooo0_l0000:ooooo`;o00009Oooool2o`000:3ooooo000Nooooo`03o`000?oooooooooo023o
oooo0_l0000hooooo`;o00008_ooool2o`000<Oooooo000Nooooo`03o`000?oooooooooo04Cooooo
0_l0000Dooooo`;o00000_ooool4o`000>Gooooo000Nooooo`03o`000?oooooooooo013ooooo0_l0
000booooo`;o00005_ooool6o`0006Oooooo0_l0001?ooooo`;o00009Oooool2o`0000Cooooo000N
ooooo`03o`000?oooooooooo013ooooo0_l0000looooo`;o00003?ooool2o`0001[ooooo0_l0001?
ooooo`;o0000Coooool2o`00023ooooo0_l00003ooooo`;o00001?ooool001Cooooo1?l000000ol@
413oooooooooo`03ooooo`03o`000?oooooooooo03[ooooo0_l0000Booooo`;o0000:?ooool2o`00
0<;ooooo0_l00009ooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo0_l0000booooo`?o00000oooool2o`000003ooooool0003o000008kooooo0_l0001booooo`00
5_ooool00ol0003oooooooooo`05ooooo`?o00001_ooool2o`0003?ooooo0_l00003ooooo`;o0000
00?oooooo`000?l000005?ooool2o`00053ooooo0_l0000Vooooo`;o0000L_ooool001Kooooo00?o
0000ooooooooool0HOooool2o`00053ooooo0_l0002Jooooo`005_ooool00ol0003oooooooooo`3o
oooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000oooooooo
ool0oooooom@ooooo`005?ooool00omEEEGoIVIVo`00003ooooooe;ooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.24318 .69217 Mdot
.86514 .40793 Mdot
.26949 .53366 Mdot
.17153 .9921 Mdot
.27642 .48027 Mdot
.27519 .9948 Mdot
.54966 .0749 Mdot
.247 .50801 Mdot
.26952 .96226 Mdot
.74591 .07973 Mdot
.31326 .16061 Mdot
.36454 .07944 Mdot
.25036 .53945 Mdot
.51733 .65894 Mdot
.23515 .97502 Mdot
.42597 .63354 Mdot
.80076 .58705 Mdot
.2733 .56022 Mdot
.25478 .59664 Mdot
.1806 .07964 Mdot
.90576 .58665 Mdot
.31958 .06469 Mdot
.33811 .46912 Mdot
.89157 .06448 Mdot
.23329 .88363 Mdot
.25449 .47828 Mdot
.21747 .82757 Mdot
.47153 .71355 Mdot
.31954 .16269 Mdot
.28973 .0961 Mdot
.24885 .57437 Mdot
.24347 .9628 Mdot
.28902 .00778 Mdot
.96569 .93646 Mdot
.9876 .54149 Mdot
.16465 .88236 Mdot
.5266 .66799 Mdot
.88963 .48675 Mdot
.39925 .83577 Mdot
.2137 .79264 Mdot
.24914 .57981 Mdot
.07032 .63513 Mdot
.10368 .98112 Mdot
.84675 .57607 Mdot
.47103 .06177 Mdot
.07586 .70185 Mdot
.61263 .4345 Mdot
.10195 .84213 Mdot
.19268 .82035 Mdot
.20246 .33488 Mdot
.33923 .99964 Mdot
.00665 .51301 Mdot
.25536 .42728 Mdot
.16295 .85892 Mdot
.26626 .41372 Mdot
.24705 .23681 Mdot
.76279 .27419 Mdot
.24263 .52607 Mdot
.21683 .83385 Mdot
.25716 .66506 Mdot
.1946 .00767 Mdot
.25705 .50333 Mdot
.55314 .09902 Mdot
.24161 .9176 Mdot
.23069 .75228 Mdot
.30549 .02752 Mdot
.09532 .41442 Mdot
.21687 .82684 Mdot
.27122 .01365 Mdot
.81881 .29016 Mdot
.19494 .22595 Mdot
.33305 .59019 Mdot
.12272 .14365 Mdot
.27263 .20055 Mdot
.33093 .05734 Mdot
.01037 .28388 Mdot
.22126 .38506 Mdot
.62643 .19204 Mdot
.22709 .89056 Mdot
.40604 .41804 Mdot
.07758 .86827 Mdot
.63983 .13312 Mdot
.85908 .58281 Mdot
.25221 .51015 Mdot
.7783 .40333 Mdot
.05946 .20777 Mdot
.25022 .46919 Mdot
.18317 .8978 Mdot
.25462 .99099 Mdot
.29303 .63447 Mdot
.14647 .09951 Mdot
.84755 .26404 Mdot
.20794 .32708 Mdot
.20663 .207 Mdot
.27301 .6161 Mdot
.05803 .76843 Mdot
.5764 .14627 Mdot
.99609 .53323 Mdot
.22606 .83172 Mdot
.96759 .56126 Mdot
.2276 .75254 Mdot
.34224 .96146 Mdot
.22913 .62624 Mdot
.48385 .64268 Mdot
.93175 .32545 Mdot
.33339 .47672 Mdot
.40949 .65323 Mdot
.4281 .65095 Mdot
.02801 .50939 Mdot
.61905 .1393 Mdot
.5219 .67492 Mdot
.87133 .47336 Mdot
.39953 .97476 Mdot
.25363 .566 Mdot
.37616 .33367 Mdot
.58432 .04037 Mdot
.45303 .04042 Mdot
.25782 .54014 Mdot
.10836 .29828 Mdot
.4759 .89954 Mdot
.20855 .82206 Mdot
.09351 .74107 Mdot
.33589 .08293 Mdot
.20969 .21119 Mdot
.88636 .20177 Mdot
.93407 .56968 Mdot
.269 .91822 Mdot
.23742 .6436 Mdot
.9681 .90578 Mdot
.07941 .11416 Mdot
.92518 .53381 Mdot
.3261 .25501 Mdot
.80452 .73273 Mdot
.31177 .55109 Mdot
.28148 .58108 Mdot
.2644 .37837 Mdot
.324 .47162 Mdot
.33891 .64325 Mdot
.24479 .5657 Mdot
.28933 .99886 Mdot
.23533 .63366 Mdot
.23757 .91203 Mdot
.31904 .05132 Mdot
.01416 .59583 Mdot
.54794 .30115 Mdot
.35471 .07462 Mdot
.22463 .71006 Mdot
.21886 .772 Mdot
.76824 .26475 Mdot
.61564 .12276 Mdot
.64467 .75648 Mdot
.306 .03605 Mdot
.38389 .08711 Mdot
.18609 .0948 Mdot
.22197 .94741 Mdot
.25963 .5283 Mdot
.36495 .62569 Mdot
.74565 .34151 Mdot
.25047 .92847 Mdot
.40631 .62721 Mdot
.34482 .60106 Mdot
.96721 .53685 Mdot
.84589 .91411 Mdot
.32276 .54804 Mdot
.22404 .80459 Mdot
.28299 .45708 Mdot
.21678 .77191 Mdot
.23333 .87182 Mdot
.60729 .12991 Mdot
.31366 .52804 Mdot
.33038 .10295 Mdot
.06136 .86802 Mdot
.96737 .52851 Mdot
.1066 .2812 Mdot
.2469 .66205 Mdot
.38464 .74914 Mdot
.89883 .89868 Mdot
.25629 .47093 Mdot
.57575 .10857 Mdot
.9982 .51748 Mdot
.11494 .96176 Mdot
.32441 .03935 Mdot
.44498 .80307 Mdot
.46889 .13737 Mdot
.69499 .22751 Mdot
.40045 .89454 Mdot
.40221 .62161 Mdot
.12395 .0688 Mdot
.77822 .73277 Mdot
.0121 .68306 Mdot
.24355 .6541 Mdot
.02447 .19372 Mdot
.23532 .66516 Mdot
.4397 .15737 Mdot
.45423 .90077 Mdot
.10805 .0059 Mdot
.9834 .5541 Mdot
.352 .10578 Mdot
.27032 .96534 Mdot
.3201 .04907 Mdot
.49066 .17518 Mdot
.4242 .34427 Mdot
.30855 .5596 Mdot
.48365 .11609 Mdot
.23403 .88863 Mdot
.18011 .90897 Mdot
.60029 .09315 Mdot
.19819 .87878 Mdot
.81139 .36925 Mdot
.48587 .73813 Mdot
.31039 .5039 Mdot
.22703 .66883 Mdot
.9078 .22098 Mdot
.65996 .29088 Mdot
.3442 .62094 Mdot
.1789 .20997 Mdot
.21676 .77789 Mdot
.16739 .28673 Mdot
.40291 .73954 Mdot
.14418 .38638 Mdot
.76326 .28894 Mdot
.30813 .58524 Mdot
.23441 .89958 Mdot
.24094 .90171 Mdot
.29736 .61156 Mdot
.3597 .58089 Mdot
.03868 .98444 Mdot
.31954 .41375 Mdot
.69692 .18375 Mdot
.3161 .04695 Mdot
.26447 .51103 Mdot
.25283 .68504 Mdot
.32337 .05681 Mdot
.04242 .0881 Mdot
.17729 .20665 Mdot
.72111 .18547 Mdot
.70144 .52743 Mdot
.25071 .55857 Mdot
.88999 .5259 Mdot
.75936 .22292 Mdot
.24061 .43163 Mdot
.32835 .07423 Mdot
.10316 .92342 Mdot
.21917 .45707 Mdot
.41172 .8238 Mdot
.21543 .37362 Mdot
.3218 .57833 Mdot
.32418 .1042 Mdot
.66435 .12414 Mdot
.2557 .57247 Mdot
.00753 .50052 Mdot
.29059 .43367 Mdot
.81622 .17501 Mdot
.06614 .21742 Mdot
.88254 .19811 Mdot
.11898 .84259 Mdot
.2631 .43847 Mdot
.90881 .47335 Mdot
.02898 .74937 Mdot
.37802 .33116 Mdot
.22942 .69646 Mdot
.2341 .73754 Mdot
.25819 .22189 Mdot
.97012 .37722 Mdot
.32516 .06116 Mdot
.00514 .12936 Mdot
.38024 .95389 Mdot
.09646 .29272 Mdot
.25478 .55168 Mdot
.21666 .80971 Mdot
.22534 .82832 Mdot
.65995 .45139 Mdot
.22354 .03888 Mdot
.25465 .74935 Mdot
.07584 .88845 Mdot
.30548 .45147 Mdot
.37993 .73592 Mdot
.40843 .23555 Mdot
.16982 .85622 Mdot
.35835 .98778 Mdot
.79214 .26421 Mdot
.32175 .07968 Mdot
.3322 .52829 Mdot
.53998 .64261 Mdot
.27446 .45599 Mdot
.23449 .89968 Mdot
.30859 .54178 Mdot
.93343 .4961 Mdot
.11605 .75884 Mdot
.32086 .19265 Mdot
.115 .90254 Mdot
.85829 .26167 Mdot
.25256 .59779 Mdot
.43269 .12603 Mdot
.58849 .12689 Mdot
.94123 .50348 Mdot
.22415 .74814 Mdot
.39576 .61557 Mdot
.79111 .24736 Mdot
.65792 .15237 Mdot
.93107 .49339 Mdot
.24425 .91076 Mdot
.99526 .55913 Mdot
.33059 .57421 Mdot
.73145 .06184 Mdot
.0466 .47017 Mdot
.21913 .83336 Mdot
.21275 .90446 Mdot
.8861 .14883 Mdot
.41112 .33335 Mdot
.20302 .84917 Mdot
.78799 .23914 Mdot
.25593 .48414 Mdot
.34624 .36425 Mdot
.22497 .78257 Mdot
.14717 .76736 Mdot
.39454 .76826 Mdot
.10456 .27911 Mdot
.27908 .97865 Mdot
.94351 .34421 Mdot
.40548 .83943 Mdot
.30045 .02974 Mdot
.34607 .01016 Mdot
.46878 .78513 Mdot
.25372 .57551 Mdot
.26572 .5151 Mdot
.17192 .85452 Mdot
.22454 .6976 Mdot
.35001 .05796 Mdot
.26303 .50899 Mdot
.15827 .08165 Mdot
.28634 .01988 Mdot
.43845 .25903 Mdot
.88897 .10996 Mdot
.14448 .31159 Mdot
.25731 .30625 Mdot
.73924 .67774 Mdot
.21585 .80702 Mdot
.75905 .89432 Mdot
.99789 .11166 Mdot
.22472 .82799 Mdot
.74165 .65288 Mdot
.22946 .66282 Mdot
.33312 .57727 Mdot
.72008 .33584 Mdot
.51155 .54156 Mdot
.60204 .12258 Mdot
.32311 .26231 Mdot
.95006 .41943 Mdot
.24385 .50569 Mdot
.26144 .54525 Mdot
.27478 .43297 Mdot
.98502 .69869 Mdot
.46931 .67381 Mdot
.57361 .09121 Mdot
.21162 .02873 Mdot
.06342 .61894 Mdot
.32266 .55566 Mdot
.2456 .53835 Mdot
.18628 .28674 Mdot
.32437 .08931 Mdot
.91022 .81381 Mdot
.24641 .57949 Mdot
.3135 .49668 Mdot
.23916 .9149 Mdot
.96438 .74521 Mdot
.59357 .89063 Mdot
.71144 .65422 Mdot
.73738 .21078 Mdot
.29204 .0702 Mdot
.33489 .62443 Mdot
.22275 .84074 Mdot
.27024 .5513 Mdot
.3017 .0213 Mdot
.05795 .91858 Mdot
.95795 .55577 Mdot
.47969 .05946 Mdot
.18445 .8516 Mdot
.91536 .17505 Mdot
.30319 .11915 Mdot
.2339 .90456 Mdot
.15389 .00632 Mdot
.71005 .22544 Mdot
.87968 .197 Mdot
.45876 .72815 Mdot
.45744 .1192 Mdot
.60966 .86557 Mdot
.61314 .50947 Mdot
.21641 .81327 Mdot
.54213 .67691 Mdot
.23764 .62558 Mdot
.26893 .53184 Mdot
.22779 .73533 Mdot
.24987 .50591 Mdot
.26656 .49227 Mdot
.38184 .2717 Mdot
.8084 .65614 Mdot
.9717 .15308 Mdot
.2143 .83705 Mdot
.24986 .58264 Mdot
.09699 .0136 Mdot
.485 .99026 Mdot
.76319 .31998 Mdot
.25645 .50652 Mdot
.59909 .66045 Mdot
.0082 .96146 Mdot
.30279 .1945 Mdot
.30967 .61476 Mdot
.35629 .55679 Mdot
.32222 .54562 Mdot
.32938 .62979 Mdot
.23552 .89047 Mdot
.34045 .6088 Mdot
.552 .0425 Mdot
.73796 .23795 Mdot
.30284 .55216 Mdot
.21773 .61786 Mdot
.35612 .58739 Mdot
.74634 .31585 Mdot
.22349 .89183 Mdot
.22167 .82705 Mdot
.56524 .38338 Mdot
.71612 .18137 Mdot
.28408 .53963 Mdot
.24417 .52027 Mdot
.78681 .51729 Mdot
.45184 .18986 Mdot
.28899 .99731 Mdot
.33594 .58916 Mdot
.81961 .36519 Mdot
.752 .23193 Mdot
.62684 .4513 Mdot
.43603 .41523 Mdot
.15233 .03198 Mdot
.80543 .25107 Mdot
.53687 .544 Mdot
.42137 .72586 Mdot
.02073 .98972 Mdot
.18827 .54095 Mdot
.45971 .02837 Mdot
.40384 .93306 Mdot
.85687 .51094 Mdot
.84952 .61029 Mdot
.20847 .01648 Mdot
.25149 .26969 Mdot
.19833 .95378 Mdot
.2963 .02248 Mdot
.29338 .50622 Mdot
.84485 .23828 Mdot
.35293 .50687 Mdot
.9026 .68137 Mdot
.04402 .51044 Mdot
.22607 .83819 Mdot
.23711 .89754 Mdot
.40246 .1361 Mdot
.20656 .84743 Mdot
.24328 .91607 Mdot
.16472 .86728 Mdot
.98735 .95026 Mdot
.4521 .40549 Mdot
.19248 .7217 Mdot
.18596 .90863 Mdot
.24492 .92247 Mdot
.26355 .49835 Mdot
.93066 .16517 Mdot
.98887 .52446 Mdot
.29307 .01804 Mdot
.93675 .60558 Mdot
.21982 .00852 Mdot
.98076 .80008 Mdot
.29641 .07976 Mdot
.25036 .47656 Mdot
.25059 .5076 Mdot
.25128 .50899 Mdot
.24715 .51005 Mdot
.23829 .93945 Mdot
.23211 .40665 Mdot
.24916 .51788 Mdot
.76544 .28328 Mdot
.2638 .85762 Mdot
.61735 .21549 Mdot
.42878 .06205 Mdot
.32521 .07147 Mdot
.24114 .62295 Mdot
.23913 .68419 Mdot
.07829 .18108 Mdot
.13785 .19091 Mdot
.84816 .21702 Mdot
.0632 .89869 Mdot
.48035 .70056 Mdot
.26171 .55979 Mdot
.23331 .87479 Mdot
.41831 .26984 Mdot
.59155 .87931 Mdot
.20764 .12811 Mdot
.34798 .12626 Mdot
.14828 .49997 Mdot
.30092 .02519 Mdot
.98767 .25305 Mdot
.42939 .77518 Mdot
.19481 .42147 Mdot
.05496 .06495 Mdot
.06562 .85402 Mdot
.7244 .19295 Mdot
.29296 .55092 Mdot
.18158 .36032 Mdot
.25304 .48318 Mdot
.58387 .12991 Mdot
.23761 .9011 Mdot
.26287 .10537 Mdot
.25206 .60079 Mdot
.61734 .31576 Mdot
.2739 .24123 Mdot
.71155 .23902 Mdot
.26699 .47517 Mdot
.04954 .10021 Mdot
.14601 .86944 Mdot
.06107 .7745 Mdot
.72533 .41584 Mdot
.251 .58776 Mdot
.31824 .5623 Mdot
.25372 .5063 Mdot
.23065 .89682 Mdot
.33335 .0645 Mdot
.98728 .65538 Mdot
.699 .81316 Mdot
.42931 .26822 Mdot
.79275 .66842 Mdot
.39566 .4559 Mdot
.98882 .9536 Mdot
.90305 .99674 Mdot
.54071 .27486 Mdot
.2739 .46446 Mdot
.38114 .85479 Mdot
.25357 .5136 Mdot
.22852 .75643 Mdot
.24469 .76347 Mdot
.26666 .96104 Mdot
.89272 .45044 Mdot
.54713 .18284 Mdot
.29 .00088 Mdot
.73567 .25044 Mdot
.34828 .06714 Mdot
.22929 .9326 Mdot
.23712 .71329 Mdot
.56968 .12305 Mdot
.84333 .23526 Mdot
.37831 .43034 Mdot
.32967 .52 Mdot
.26514 .51749 Mdot
.58932 .083 Mdot
.50985 .17597 Mdot
.28082 .98812 Mdot
.94944 .9519 Mdot
.09326 .88977 Mdot
.63818 .02013 Mdot
.84353 .21132 Mdot
.21705 .79582 Mdot
.14865 .93562 Mdot
.46982 .39045 Mdot
.32266 .52976 Mdot
.28764 .98239 Mdot
.89165 .45537 Mdot
.94442 .67639 Mdot
.30456 .54535 Mdot
.18967 .8186 Mdot
.35457 .60863 Mdot
.23094 .87188 Mdot
.62569 .4116 Mdot
.2585 .992 Mdot
.61326 .46724 Mdot
.48169 .65881 Mdot
.24515 .94869 Mdot
.2212 .70406 Mdot
.2573 .5355 Mdot
.2921 .00733 Mdot
.0203 .00957 Mdot
.31819 .16431 Mdot
.29279 .42831 Mdot
.19348 .39377 Mdot
.68606 .98467 Mdot
.84226 .27553 Mdot
.23529 .46182 Mdot
.2417 .6101 Mdot
.91531 .43048 Mdot
.1727 .89904 Mdot
.41133 .89597 Mdot
.57509 .97951 Mdot
.53115 .90292 Mdot
.24084 .66937 Mdot
.24739 .51935 Mdot
.25447 .39978 Mdot
.34192 .5736 Mdot
.30785 .03533 Mdot
.36299 .11591 Mdot
.25864 .4928 Mdot
.42492 .7383 Mdot
.2636 .5177 Mdot
.1719 .87938 Mdot
.33101 .55806 Mdot
.29978 .02288 Mdot
.22571 .84342 Mdot
.26662 .55103 Mdot
.99548 .53422 Mdot
.50529 .01653 Mdot
.32511 .54726 Mdot
.21664 .78426 Mdot
.31709 .08668 Mdot
.51353 .06968 Mdot
.23625 .68731 Mdot
.52116 .11911 Mdot
.58805 .12936 Mdot
.26672 .04499 Mdot
.36717 .26635 Mdot
.25659 .59072 Mdot
.39988 .71245 Mdot
.33438 .59343 Mdot
.11525 .21209 Mdot
.23382 .86677 Mdot
.66492 .14407 Mdot
.6897 .8247 Mdot
.50347 .37662 Mdot
.23745 .66922 Mdot
.01973 .23641 Mdot
.0338 .5546 Mdot
.37672 .01219 Mdot
.93524 .00983 Mdot
.04444 .20993 Mdot
.291 .40861 Mdot
.07299 .99058 Mdot
.24115 .53769 Mdot
.23968 .89829 Mdot
.24306 .67404 Mdot
.47065 .53124 Mdot
.24921 .9532 Mdot
.64901 .21777 Mdot
.25095 .51097 Mdot
.20918 .34225 Mdot
.27472 .51521 Mdot
.24208 .99015 Mdot
.10692 .09473 Mdot
.26596 .99129 Mdot
.06934 .59494 Mdot
.10138 .10777 Mdot
.51911 .98006 Mdot
.3038 .57761 Mdot
.29881 .9426 Mdot
.74798 .28853 Mdot
.25895 .51543 Mdot
.52233 .08151 Mdot
.85819 .01599 Mdot
.30999 .03104 Mdot
.88266 .86189 Mdot
.24453 .91305 Mdot
.8445 .23535 Mdot
.21618 .80714 Mdot
.24596 .41559 Mdot
.79904 .23175 Mdot
.80921 .36766 Mdot
.21091 .84191 Mdot
.47135 .0386 Mdot
.34699 .79325 Mdot
.72029 .09709 Mdot
.20645 .81445 Mdot
.01302 .16036 Mdot
.95622 .87543 Mdot
.21841 .89598 Mdot
.56685 .08984 Mdot
.96867 .56977 Mdot
.92689 .85526 Mdot
.17184 .18174 Mdot
.7097 .06598 Mdot
.43867 .17246 Mdot
.29414 .1313 Mdot
.75355 .21122 Mdot
.25703 .49049 Mdot
.79954 .09478 Mdot
.27484 .53705 Mdot
.62764 .13326 Mdot
.77502 .42511 Mdot
.87962 .43701 Mdot
.01793 .60518 Mdot
.73142 .23284 Mdot
.24042 .6409 Mdot
.25812 .98878 Mdot
.95023 .49571 Mdot
.29512 .8954 Mdot
.60988 .12803 Mdot
.51891 .86029 Mdot
.2497 .55597 Mdot
.09996 .76599 Mdot
.47506 .09646 Mdot
.19543 .31851 Mdot
.57625 .42871 Mdot
.29971 .02625 Mdot
.348 .79089 Mdot
.2439 .91589 Mdot
.53804 .28632 Mdot
.69795 .15858 Mdot
.92915 .21335 Mdot
.19392 .28093 Mdot
.46721 .64928 Mdot
.25973 .53145 Mdot
.24362 .5699 Mdot
.1502 .21079 Mdot
.32737 .05918 Mdot
.67726 .17786 Mdot
.97033 .26929 Mdot
.40394 .20971 Mdot
.2751 .97609 Mdot
.70856 .17588 Mdot
.30711 .70799 Mdot
.5075 .93604 Mdot
.781 .17422 Mdot
.31612 .43024 Mdot
.78875 .50406 Mdot
.32557 .09268 Mdot
.24637 .49784 Mdot
.60206 .03748 Mdot
.3301 .09491 Mdot
.22358 .6853 Mdot
.12662 .1702 Mdot
.31694 .56081 Mdot
.52982 .42409 Mdot
.91188 .63539 Mdot
.81266 .30897 Mdot
.32197 .32309 Mdot
.21084 .80824 Mdot
.11162 .12458 Mdot
.74786 .2891 Mdot
.31852 .13594 Mdot
.31985 .12289 Mdot
.26805 .52855 Mdot
.27455 .96687 Mdot
.60459 .00984 Mdot
.58915 .53872 Mdot
.84942 .24296 Mdot
.84857 .21845 Mdot
.32364 .98511 Mdot
.81002 .35283 Mdot
.3067 .79062 Mdot
.1684 .01905 Mdot
.25937 .59618 Mdot
.65183 .92902 Mdot
.05078 .09695 Mdot
.27962 .92573 Mdot
.29625 .12334 Mdot
.76102 .2782 Mdot
.28186 .9711 Mdot
.95236 .14146 Mdot
.09121 .96711 Mdot
.23359 .72657 Mdot
.41888 .15068 Mdot
.22975 .67715 Mdot
.31041 .56856 Mdot
.24146 .79542 Mdot
.30248 .53009 Mdot
.08332 .9094 Mdot
.23368 .40628 Mdot
.25604 .56403 Mdot
.77898 .33148 Mdot
.24725 .50555 Mdot
.83571 .36854 Mdot
.22513 .7322 Mdot
.30108 .18279 Mdot
.19425 .03087 Mdot
.98744 .5875 Mdot
.75085 .25519 Mdot
.35223 .10077 Mdot
.84139 .36634 Mdot
.22658 .84608 Mdot
.5545 .83666 Mdot
.3338 .49805 Mdot
.29069 .43401 Mdot
.60887 .10712 Mdot
.24482 .60168 Mdot
.25892 .84184 Mdot
.26064 .55918 Mdot
.39758 .1463 Mdot
.3344 .22073 Mdot
.16998 .99746 Mdot
.44692 .88342 Mdot
.77345 .22558 Mdot
.02616 .03722 Mdot
.22569 .75917 Mdot
.37521 .63074 Mdot
.46419 .6888 Mdot
.28612 .99258 Mdot
.23408 .87761 Mdot
.2679 .52193 Mdot
.68065 .68884 Mdot
.73781 .21209 Mdot
.58927 .65673 Mdot
.25089 .46285 Mdot
.94642 .48339 Mdot
.24947 .41553 Mdot
.47929 .69053 Mdot
.66417 .64667 Mdot
.1531 .96584 Mdot
.3172 .58922 Mdot
.76257 .17999 Mdot
.30915 .09684 Mdot
.23824 .4564 Mdot
.42009 .97329 Mdot
.27626 .71707 Mdot
.29509 .56058 Mdot
.40523 .26522 Mdot
.20961 .27336 Mdot
.96298 .54277 Mdot
.31645 .56934 Mdot
.95218 .54108 Mdot
.15472 .93751 Mdot
.25702 .5072 Mdot
.66886 .81545 Mdot
.12451 .03026 Mdot
.22783 .85564 Mdot
.58308 .2692 Mdot
.77446 .2661 Mdot
.2221 .97209 Mdot
.56752 .0937 Mdot
.25137 .51161 Mdot
.25805 .52008 Mdot
.25213 .91933 Mdot
.25754 .52811 Mdot
.2458 .48631 Mdot
.34702 .63938 Mdot
.25447 .4352 Mdot
.228 .84375 Mdot
.60349 .10362 Mdot
.34105 .54626 Mdot
.4505 .04981 Mdot
.93684 .47805 Mdot
.24843 .54268 Mdot
.60152 .08421 Mdot
.08923 .66661 Mdot
.31919 .53667 Mdot
.63954 .2098 Mdot
.19245 .82283 Mdot
.25066 .93396 Mdot
.62991 .07442 Mdot
.5862 .90656 Mdot
.26097 .52058 Mdot
.21864 .83557 Mdot
.28043 .97496 Mdot
.78487 .26943 Mdot
.535 .06814 Mdot
.94117 .58153 Mdot
.2687 .5404 Mdot
.25798 .49263 Mdot
.23382 .72536 Mdot
.90639 .46162 Mdot
.28941 .69573 Mdot
.25103 .58305 Mdot
.23927 .33668 Mdot
.21357 .77754 Mdot
.93014 .24974 Mdot
.24892 .50852 Mdot
.28137 .2731 Mdot
.26976 .84477 Mdot
.22085 .7421 Mdot
.25903 .51774 Mdot
.18139 .99052 Mdot
.27982 .98554 Mdot
.65433 .24702 Mdot
.25594 .48143 Mdot
.32278 .04244 Mdot
.2549 .59774 Mdot
.38982 .72819 Mdot
.89217 .17623 Mdot
.25217 .52218 Mdot
.37047 .34234 Mdot
.21484 .76673 Mdot
.23331 .88656 Mdot
.17267 .73851 Mdot
.07916 .91113 Mdot
.25376 .47899 Mdot
.76628 .49415 Mdot
.90974 .40042 Mdot
.49612 .98916 Mdot
.29026 .58593 Mdot
.69203 .77067 Mdot
.22704 .07343 Mdot
.24934 .50545 Mdot
.24909 .44986 Mdot
.10554 .56888 Mdot
.24268 .68671 Mdot
.23228 .68368 Mdot
.76512 .24733 Mdot
.32069 .06919 Mdot
.02108 .90548 Mdot
.71846 .19167 Mdot
.41304 .24035 Mdot
.1097 .43781 Mdot
.32344 .07994 Mdot
.67903 .0652 Mdot
.22285 .75393 Mdot
.77296 .35208 Mdot
.23311 .01508 Mdot
.60481 .74578 Mdot
.25748 .83069 Mdot
.28286 .58922 Mdot
.36275 .95624 Mdot
.58228 .39308 Mdot
.17205 .68137 Mdot
.5692 .07915 Mdot
.55807 .50951 Mdot
.02044 .03327 Mdot
.27443 .75488 Mdot
.24998 .59635 Mdot
.23057 .66658 Mdot
.32677 .89847 Mdot
.00445 .89599 Mdot
.18715 .25249 Mdot
.27163 .97057 Mdot
.33161 .81675 Mdot
.30347 .31262 Mdot
.90826 .81163 Mdot
.63786 .76893 Mdot
.0653 .78939 Mdot
.28267 .98195 Mdot
.71917 .18342 Mdot
.18042 .33216 Mdot
.25909 .33924 Mdot
.25898 .51517 Mdot
.24216 .97586 Mdot
.91168 .47336 Mdot
.70009 .19685 Mdot
.39604 .15023 Mdot
.90345 .43039 Mdot
.80937 .36894 Mdot
.11168 .64485 Mdot
.32019 .47523 Mdot
.25239 .52033 Mdot
.32435 .05903 Mdot
.99611 .1839 Mdot
.23367 .63877 Mdot
.77023 .20472 Mdot
.32255 .11703 Mdot
.2171 .88798 Mdot
.95708 .0066 Mdot
.25149 .52705 Mdot
.26105 .57704 Mdot
.23075 .86902 Mdot
.57482 .12458 Mdot
.17207 .40298 Mdot
.2638 .97488 Mdot
.15471 .1611 Mdot
.15825 .38248 Mdot
.28357 .98779 Mdot
.65657 .16664 Mdot
.25336 .02656 Mdot
.79615 .23093 Mdot
.07294 .5786 Mdot
.69578 .6193 Mdot
.63079 .71663 Mdot
.27418 .53279 Mdot
.67929 .28204 Mdot
.93301 .47578 Mdot
.55166 .12888 Mdot
.87549 .1477 Mdot
.31883 .07866 Mdot
.23565 .88471 Mdot
.22517 .97689 Mdot
.27012 .67185 Mdot
.26384 .51567 Mdot
.58458 .1077 Mdot
.33872 .67593 Mdot
.36432 .58119 Mdot
.80191 .33507 Mdot
.61024 .13214 Mdot
.23817 .23776 Mdot
.80966 .08921 Mdot
.9226 .12951 Mdot
.57508 .11367 Mdot
.69171 .12651 Mdot
.25335 .49336 Mdot
.39611 .6103 Mdot
.56225 .28201 Mdot
.22015 .85002 Mdot
.21781 .76623 Mdot
.24222 .51202 Mdot
.30275 .59028 Mdot
.20536 .29755 Mdot
.4021 .61511 Mdot
.29109 .1251 Mdot
.04853 .51597 Mdot
.41111 .10994 Mdot
.63293 .13951 Mdot
.01796 .52899 Mdot
.22181 .77938 Mdot
.89698 .59798 Mdot
.16697 .98868 Mdot
.38874 .12403 Mdot
.60653 .35408 Mdot
.24504 .92272 Mdot
.21057 .80516 Mdot
.23325 .7371 Mdot
.19494 .32747 Mdot
.38503 .60114 Mdot
.33493 .12209 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`09ooooo`;o00000_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`04o`000?oooooo0000o`0000co
oooo0ol0000>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool2o`000003
ooooool0003ooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00Co0000ooooool0003o00003Oooool00ol0003oooooooooo`02oooo
o`007_ooool00ol0003oooooooooo`02ooooo`;o00006oooool2o`0000gooooo0_l0000;ooooo`;o
00001_ooool2o`0001Gooooo0ol0000?ooooo`;o0000D_ooool2o`0006[ooooo0_l00005ooooo`;o
00004_ooool001kooooo00?o0000ooooooooool00_ooool2o`0001Oooooo0_l0000Nooooo`;o0000
1_ooool2o`0000oooooo0_l00004ooooo`;o00004?ooool2o`0000Sooooo0_l00018ooooo`;o0000
J_ooool2o`0001Wooooo000Nooooo`03o`000?oooooooooo01_ooooo0_l0000Sooooo`;o00001_oo
ool2o`0000[ooooo0_l0000Pooooo`;o0000:?ooool2o`00077ooooo0_l0000booooo`007_ooool0
0ol0003oooooooooo`0cooooo`;o00002oooool2o`0000Kooooo0_l0000?ooooo`Co0000@oooool2
o`00077ooooo0_l0000booooo`007_ooool00ol0003oooooooooo`0cooooo`;o00009?ooool7o`00
06_ooooo0_l0001jooooo`007_ooool00ol0003oooooooooo`1Looooo`Co0000Joooool2o`0007[o
oooo000Nooooo`03o`000?oooooooooo047ooooo0_l0000;ooooo`;o00003Oooool4o`00033ooooo
0_l0002dooooo`007_ooool00ol0003oooooooooo`0Tooooo`;o00001oooool2o`0000cooooo0_l0
0004ooooo`;o00002oooool2o`0000gooooo1_l0000^ooooo`;o0000]?ooool001kooooo00?o0000
ooooooooool00oooool2o`0001oooooo0_l00007ooooo`;o00003?ooool2o`00027ooooo0_l00000
0ooooooo0000o`00003Tooooo`007_ooool00ol0003oooooooooo`03ooooo`?o0000FOooool3o`00
05kooooo0_l00025ooooo`007_ooool00ol0003oooooooooo`04ooooo`;o0000?oooool2o`0001So
oooo0ol00003ooooo`;o0000:?ooool2o`0000Cooooo0_l0000Sooooo`;o00001?ooool2o`0008Go
oooo000Nooooo`03o`000?oooooooooo04Gooooo0_l0000Nooooo`;o0000:?ooool2o`0000Cooooo
0_l0000Hooooo`;o00002Oooool2o`0008_ooooo000Nooooo`03o`000?oooooooooo05?ooooo0_l0
000>ooooo`Co0000B?ooool2o`0009Kooooo000Nooooo`03o`000?oooooooooo05?ooooo0_l0000>
ooooo`?o0000:?ooool2o`000;Oooooo000Nooooo`;o0000IOooool2o`0002Sooooo0_l0002goooo
o`007_ooool00ol0003oooooooooo`1Tooooo`;o0000hOooool001kooooo00?o0000ooooooooool0
IOooool4o`0000Gooooo0_l0000Xooooo`;o0000[Oooool001kooooo00?o0000ooooooooool0IOoo
ool4o`0000Gooooo0_l0000Gooooo`;o00003?ooool2o`000003ooooool0003o0000053ooooo0_l0
001Kooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o0000E?ooool6o`0001gooooo0_l0000<
ooooo`;o0000@_ooool2o`0000Sooooo0_l00005ooooo`;o0000<_ooool2o`0002Oooooo000Noooo
o`03o`000?oooooooooo00kooooo0_l0000Dooooo`;o0000?_ooool2o`0000;ooooo0_l00003oooo
o`;o0000>oooool2o`0002gooooo0_l00008ooooo`;o0000>Oooool2o`0002Oooooo000Nooooo`03
o`000?oooooooooo02Cooooo0_l0000eooooo`;o00001oooool4o`0000Gooooo0_l0000dooooo`;o
00001Oooool2o`0009_ooooo000Nooooo`03o`000?oooooooooo04Kooooo0_l0000Cooooo`;o0000
1oooool5o`0000Kooooo0_l0000booooo`;o00002_ooool2o`0001Sooooo0_l0001looooo`007_oo
ool00ol0003oooooooooo`16ooooo`;o00007oooool2o`0000Kooooo0_l0000nooooo`;o00006?oo
ool2o`0007cooooo000Nooooo`03o`000?oooooooooo03Oooooo0_l0000Sooooo`;o00001_ooool3
o`0000_ooooo0_l00011ooooo`;o0000=oooool2o`0005Oooooo000Nooooo`03o`000?oooooooooo
02oooooo0_l00006ooooo`;o00008oooool2o`0000Kooooo0ol00002ooooo`;o00001oooool2o`00
03;ooooo0_l0000=ooooo`;o00001?ooool2o`0000;ooooo0_l0000]ooooo`;o0000Eoooool001ko
oooo00?o0000ooooooooool0;oooool2o`0003;ooooo0_l00004ooooo`;o00003_ooool2o`0002_o
oooo0_l0000Cooooo`;o00000_ooool2o`0008Kooooo000Nooooo`03o`000?oooooooooo00[ooooo
0_l0001Gooooo`Co00004_ooool2o`0003Wooooo0_l0001=ooooo`;o0000@_ooool001kooooo00?o
0000ooooooooool02_ooool2o`0005Wooooo0ol0001<ooooo`Co00001oooool2o`0004;ooooo0_l0
0012ooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o00005oooool2o`00023ooooo0_l0000:
ooooo`?o0000;Oooool2o`0001cooooo1?l00007ooooo`;o0000?oooool2o`0004Gooooo000Noooo
o`03o`000?oooooooooo00cooooo0_l0000Aooooo`;o00002oooool2o`0000[ooooo0_l0000Poooo
o`;o00001?ooool2o`0000Gooooo0_l0000]ooooo`;o00006?ooool2o`0003Cooooo0_l0000Hoooo
o`;o0000AOooool001kooooo0_l0000=ooooo`;o00007_ooool2o`0003;ooooo0_l0000<ooooo`;o
0000@?ooool2o`0003Cooooo0_l0001Oooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o0000
@oooool2o`0001;ooooo1?l00005ooooo`;o0000D?ooool2o`0008Gooooo000Nooooo`03o`000?oo
oooooooo01gooooo0_l0000booooo`;o00004_ooool4o`0000Gooooo0_l00017ooooo`;o000000?o
ooooo`000?l000001?ooool4o`0008?ooooo000Nooooo`03o`000?oooooooooo01gooooo0_l0001S
ooooo`;o0000<oooool2o`000003ooooool0003o000000Kooooo0_l0001Iooooo`;o00008Oooool2
o`0000Gooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l0001Zooooo`;o0000<oooool2o`00
06Cooooo0_l0000Qooooo`;o00001Oooool001kooooo00?o0000ooooooooool05_ooool2o`0004go
oooo0_l0000;ooooo`;o00009Oooool2o`0001cooooo0_l0002>ooooo`007_ooool00ol0003ooooo
ooooo`1Nooooo`;o00001Oooool2o`0000_ooooo0_l0000Mooooo`;o00001_ooool2o`0000[ooooo
0_l0002Pooooo`007_ooool00ol0003oooooooooo`1Looooo`Co00001?ooool2o`0000?ooooo0_l0
000?ooooo`;o00005Oooool2o`0001;ooooo0_l0000>ooooo`;o00002Oooool2o`0000;ooooo0_l0
000>ooooo`;o0000LOooool001kooooo00?o0000ooooooooool08?ooool2o`0003Wooooo0ol00006
ooooo`;o00000oooool2o`0000;ooooo0_l0000;ooooo`;o00003Oooool2o`0002[ooooo1?l00002
ooooo`;o00000oooool2o`0000;ooooo0_l0000>ooooo`;o00001oooool2o`0006Sooooo000Noooo
o`?o00008?ooool2o`0001gooooo0_l0000Jooooo`;o00004?ooool2o`0001[ooooo0_l0000Toooo
o`;o00001_ooool2o`000004ooooool0003o0000o`0000Cooooo0ol0000Iooooo`;o0000BOooool2
o`0001gooooo000Nooooo`?o0000?oooool2o`0001_ooooo0_l0001Aooooo`;o00002Oooool3o`00
00Cooooo0ol00004ooooo`;o00000_ooool2o`0005[ooooo0_l0000Mooooo`007_ooool00ol0003o
ooooooooo`1Looooo`;o00001Oooool2o`0001[ooooo0_l00011ooooo`;o00001?ooool2o`0000;o
oooo0_l0001iooooo`007_ooool00ol0003oooooooooo`1Sooooo`;o00006_ooool2o`0001?ooooo
0_l0000_ooooo`;o00000oooool2o`0007_ooooo000Nooooo`03o`000?oooooooooo09Cooooo0_l0
000_ooooo`;o00000oooool2o`0006Kooooo0_l0000Cooooo`007_ooool00ol0003oooooooooo`0T
ooooo`;o0000[_ooool2o`0005cooooo0_l0000Cooooo`007_ooool00ol0003oooooooooo`0Toooo
o`;o0000Eoooool2o`0003Sooooo0_l0000Kooooo`;o0000@oooool2o`000003ooooool0003o0000
02Wooooo000Nooooo`;o0000O_ooool2o`0000Gooooo0_l0000aooooo`;o0000H?ooool2o`000003
ooooool0003o000002Wooooo000Nooooo`03o`000?oooooooooo07gooooo0_l00005ooooo`;o0000
C?ooool2o`0006Cooooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`2;ooooo`;o0000AOoo
ool2o`0006Cooooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`02o`0002cooooo0_l0000b
ooooo`;o00009oooool2o`0005;ooooo0_l0001Vooooo`007_ooool00ol0003oooooooooo`02o`00
02cooooo0_l0000booooo`Co0000NOooool2o`0006Kooooo000Nooooo`03o`000?oooooooooo06?o
oooo0ol0001[ooooo`;o0000Eoooool2o`0001_ooooo000Nooooo`03o`000?oooooooooo02Gooooo
0_l0002Zooooo`;o0000Eoooool2o`0001_ooooo000Nooooo`03o`000?oooooooooo02Gooooo0_l0
001Tooooo`;o0000^_ooool001kooooo00?o0000ooooooooool0Roooool2o`0000kooooo0_l00005
ooooo`;o0000?_ooool2o`0001Kooooo0_l00009ooooo`;o00005oooool2o`0000Gooooo0_l0000P
ooooo`007_ooool00ol0003oooooooooo`2Kooooo`;o00001Oooool2o`0003Cooooo0_l00008oooo
o`;o00005_ooool2o`0000Wooooo0_l0000Gooooo`;o00001Oooool2o`00023ooooo000Nooooo`03
o`000?oooooooooo01Gooooo0_l0000Mooooo`;o0000:?ooool2o`0004kooooo0_l0000Xooooo`;o
00002oooool2o`0000gooooo0_l0001Aooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o0000
7Oooool2o`0002Sooooo0_l0001>ooooo`;o0000;_ooool2o`0000Gooooo0ol0000<ooooo`;o0000
B_ooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo0=kooooo0_l00006ooooo`;o0000F?oo
ool2o`0000Gooooo000Nooooo`03o`000?oooooooooo02Wooooo0_l0001Tooooo`;o0000=oooool2
o`0001_ooooo0_l0001Pooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`Go00001_ooool00ol0003oooooooooo`04ooooo`;o00008oooool2o`0003?ooooo0_l00004
ooooo`;o0000:Oooool2o`0003Oooooo0_l0000Kooooo`Co0000G_ooool000?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o
0000ooooooooool01?ooool2o`0005Sooooo0_l00004ooooo`;o0000NOooool2o`0000Kooooo0_l0
000aooooo`?o0000:_ooool000?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7ok^k^00Oooooo0ol0001Eooooo`;o0000R?ooool2o`0003Wooooo0ol0000Zooooo`000oooool0
1Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003ooooooooo
o`1Eooooo`;o0000aOooool2o`0002Wooooo0003ooooo`05o`000?ooooooooooooooool000003_oo
ool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo03Kooooo0_l00007ooooo`;o0000]Ooo
ool2o`0002Cooooo0_l0000Yooooo`000oooool01Ol@413ooooooooooooooooo410@00oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`;o00000oooool2o`0002Gooooo0_l0
0007ooooo`;o0000?_ooool2o`0004_ooooo0_l0000Xooooo`;o0000Coooool000?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003ooooo
ooooo`0:ooooo`;o00000oooool2o`00013ooooo0_l0000:ooooo`;o00001oooool2o`0000Sooooo
0_l0000mooooo`;o0000Boooool2o`0001kooooo0_l00003ooooo`;o00006oooool2o`0001[ooooo
0_l0000Kooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c006ooooo`03o`000?oooooooooo027ooooo0_l0000:ooooo`;o00004Oooool2o`0008?o
oooo0_l0000Uooooo`;o00000oooool2o`0001_ooooo0_l0000Jooooo`;o00006oooool001kooooo
00?o0000ooooooooool04Oooool2o`000;;ooooo0_l00008ooooo`;o0000?oooool2o`0003Gooooo
000Nooooo`03o`000?oooooooooo017ooooo0_l0000mooooo`;o00005oooool2o`0006Cooooo0_l0
000oooooo`;o00004Oooool2o`0002;ooooo000Nooooo`03o`000?oooooooooo03_ooooo0_l0000C
ooooo`;o00005oooool2o`0007Sooooo0_l0000>ooooo`;o00000_ooool2o`0002[ooooo0_l0000R
ooooo`007_ooool00ol0003oooooooooo`0kooooo`;o0000XOooool2o`0000?ooooo0_l0000>oooo
o`;o00000_ooool2o`0004kooooo000Nooooo`03o`000?oooooooooo0=kooooo0_l0000@ooooo`;o
00003Oooool3o`0004Gooooo000Nooooo`03o`000?oooooooooo0>[ooooo0_l00004ooooo`;o0000
3Oooool3o`0004Gooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l00015ooooo`;o000000?o
ooooo`000?l00000<oooool2o`0006Oooooo1?l0000Pooooo`;o0000=oooool001kooooo00?o0000
ooooooooool00_ooool2o`0004Gooooo0_l000000ooooooo0000o`000007ooooo`;o0000:_ooool3
o`0005oooooo0_l00007ooooo`;o00003_ooool2o`00013ooooo0ol0000fooooo`007_ooool00ol0
003oooooooooo`1Eooooo`;o0000:oooool2o`0005oooooo0_l0000Gooooo`;o00004Oooool3o`00
03Gooooo000Nooooo`03o`000?oooooooooo0=7ooooo0_l0000Rooooo`;o00001_ooool2o`00017o
oooo0_l0000eooooo`007_ooool00ol0003oooooooooo`3Aooooo`;o00006?ooool2o`0000Sooooo
0_l00006ooooo`;o0000:oooool2o`0001_ooooo000Nooooo`;o0000>_ooool2o`000;3ooooo0_l0
000Eooooo`;o00009_ooool2o`00017ooooo0_l00008ooooo`007_ooool00ol0003oooooooooo`0i
ooooo`;o0000:oooool2o`0008Sooooo0_l0000@ooooo`;o0000>Oooool2o`0000Sooooo000Noooo
o`03o`000?oooooooooo06Kooooo0_l0000Rooooo`;o0000I?ooool2o`0005Gooooo000Nooooo`03
o`000?oooooooooo06Gooooo0_l0000Sooooo`;o0000Qoooool2o`0003;ooooo000Nooooo`03o`00
0?oooooooooo06Gooooo0_l0000Iooooo`;o0000M?ooool2o`0000Gooooo0_l0000@ooooo`;o0000
0_ooool2o`0003;ooooo000Nooooo`03o`000?oooooooooo07?ooooo0_l0000;ooooo`;o00001Ooo
ool2o`0006gooooo1?l00003ooooo`;o00004?ooool2o`0003Kooooo000Nooooo`03o`000?oooooo
oooo04kooooo0_l0000Sooooo`;o00000oooool2o`0000[ooooo0_l000000ooooooo0000o`00000`
ooooo`;o0000?Oooool2o`000003ooooool0003o000003[ooooo0_l0000>ooooo`007_ooool00ol0
003oooooooooo`10ooooo`;o00003?ooool2o`0000Oooooo0_l0000Oooooo`;o00002_ooool2o`00
02Kooooo0_l0000;ooooo`;o0000>Oooool2o`0000Gooooo0_l0000jooooo`;o00003_ooool001ko
oooo00?o0000ooooooooool0@?ooool2o`0001Gooooo0_l0001Cooooo`;o0000AOooool3o`0001So
oooo0_l0000gooooo`007_ooool00ol0003oooooooooo`0Nooooo`?o00006_ooool2o`000;Kooooo
0_l0000Iooooo`;o0000=oooool001kooooo00Co0000ooooool0003o00007Oooool3o`0001[ooooo
0_l0001fooooo`;o00009?ooool2o`0001[ooooo0_l0001@ooooo`007_ooool01?l0003oooooo`00
0?l0000aooooo`;o00001?ooool2o`00077ooooo0_l00006ooooo`;o00009?ooool2o`0001[ooooo
0_l0001@ooooo`007_ooool00ol0003oooooooooo`0booooo`;o00001?ooool2o`00077ooooo0_l0
0012ooooo`;o00000oooool2o`00013ooooo0_l0000oooooo`007_ooool00ol0003oooooooooo`0K
ooooo`;o0000]Oooool2o`0001_ooooo0_l00003ooooo`;o00004?ooool2o`0003oooooo000Noooo
o`03o`000?oooooooooo01_ooooo0_l0002eooooo`;o0000Loooool001kooooo00?o0000oooooooo
ool07oooool2o`0001kooooo0_l0003oooooo`Oooooo000Nooooo`;o00008?ooool2o`0001kooooo
0_l0001]ooooo`;o0000Uoooool001kooooo00?o0000ooooooooool0[_ooool2o`0009Oooooo000N
ooooo`03o`000?oooooooooo053ooooo0_l0002booooo`;o0000@Oooool001kooooo00?o0000oooo
ooooool0:oooool2o`0002?ooooo0_l0002booooo`;o0000@Oooool001kooooo00?o0000oooooooo
ool0:oooool2o`0003;ooooo0_l0003Vooooo`007_ooool00ol0003oooooooooo`1Oooooo`;o0000
I?ooool2o`0002Sooooo0_l0001Fooooo`007_ooool00ol0003oooooooooo`0kooooo`;o0000R?oo
ool2o`0002Sooooo0_l00003ooooo`;o0000DOooool001kooooo00?o0000ooooooooool0>oooool2
o`0002Sooooo0_l0002=ooooo`;o0000DOooool001kooooo00?o0000ooooooooool0>oooool2o`00
00;ooooo0_l0000Tooooo`;o0000a?ooool2o`0001[ooooo000Nooooo`03o`000?oooooooooo03_o
oooo0_l00002ooooo`;o0000j_ooool2o`0001[ooooo000Nooooo`03o`000?oooooooooo03Oooooo
0_l0000nooooo`;o00002Oooool2o`0007Gooooo0_l0001<ooooo`007_ooool00ol0003ooooooooo
o`0gooooo`;o00001Oooool2o`0000[ooooo0_l0000Zooooo`?o00002Oooool2o`0006;ooooo0_l0
000Aooooo`;o00001_ooool2o`0004Cooooo000Nooooo`03o`000?oooooooooo03kooooo0_l0000:
ooooo`;o00001?ooool2o`0002Cooooo0_l0001^ooooo`;o00006Oooool2o`0004Cooooo000Noooo
o`03o`000?oooooooooo043ooooo0_l0000>ooooo`;o00008_ooool2o`0007Sooooo0_l0001Goooo
o`007_ooool00ol0003oooooooooo`10ooooo`;o0000<_ooool2o`00013ooooo0_l0001Vooooo`;o
0000?oooool2o`0001Kooooo000Nooooo`03o`000?oooooooooo08Kooooo0_l0002Wooooo`;o0000
5_ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0<7ooooo0_l0000d
ooooo`;o00002_ooool2o`0004;ooooo000Nooooo`03o`000?oooooooooo0<7ooooo0_l0000doooo
o`;o00002_ooool2o`0004;ooooo000Nooooo`03o`000?oooooooooo03Oooooo0_l0003oooooo`oo
oooo000Nooooo`03o`000?oooooooooo03Oooooo0_l0000cooooo`;o0000fOooool001kooooo00?o
0000ooooooooool0K?ooool2o`0009Sooooo0_l00005ooooo`;o0000>?ooool001kooooo00?o0000
ooooooooool0ooooool4ooooo`Go00001?ooool3o`0003Sooooo000Nooooo`03o`000?oooooooooo
0?oooooo1?ooool3o`0000Kooooo0_l0000iooooo`007_ooool00ol0003oooooooooo`12ooooo`;o
0000G?ooool2o`000:Gooooo000Nooooo`03o`000?oooooooooo04;ooooo0_l0000>ooooo`;o0000
C?ooool2o`0009Gooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`0_ooooo`;o00008Ooo
ool2o`000>?ooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`0_ooooo`;o00004oooool2
o`0006kooooo0_l0002Aooooo`007_ooool00ol0003oooooooooo`0[ooooo`;o00005oooool2o`00
06kooooo0_l0002Aooooo`007_ooool00ol0003oooooooooo`0[ooooo`;o0000J?ooool2o`000;3o
oooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413o
ooooooooo`04ooooo`03o`000?oooooooooo03_ooooo0_l0001Hooooo`;o00008_ooool2o`0008co
oooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0kooooo`;o0000O?ooool2o`0008cooooo0003ooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol0001?ooooo`;o0000doooool2o`00027o
oooo0003ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00007oooo
o`03o`000?oooooooooo03Cooooo0_l0000Iooooo`;o0000Z?ooool2o`0002Wooooo0_l0000Qoooo
o`000oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool0
0ol0003oooooooooo`0dooooo`;o00004Oooool3o`0004Gooooo0_l0001Xooooo`;o0000C?ooool0
00?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000
ooooooooool0Aoooool3o`00013ooooo0_l0000cooooo`;o0000Q?ooool2o`00033ooooo0003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooo
oooo05[ooooo0_l0001[ooooo`;o0000C?ooool2o`00033ooooo0003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo01_ooooo0_l0000_
ooooo`?o00000oooool2o`00013ooooo0_l0000Tooooo`;o0000>oooool2o`0001oooooo0_l0001M
ooooo`007_ooool00ol0003oooooooooo`0Kooooo`;o0000;oooool3o`0000?ooooo0_l0000@oooo
o`;o00006_ooool2o`0000Sooooo0_l0001Looooo`;o0000Aoooool2o`0001Cooooo000Nooooo`03
o`000?oooooooooo03_ooooo0_l00013ooooo`;o0000[oooool2o`0001Cooooo000Nooooo`03o`00
0?oooooooooo03_ooooo0_l0001[ooooo`;o0000C_ooool2o`0004gooooo000Nooooo`03o`000?oo
oooooooo04oooooo0_l0000:ooooo`;o0000Boooool2o`0000gooooo0_l0000oooooo`;o0000COoo
ool001kooooo00?o0000ooooooooool0B_ooool2o`0000?ooooo0_l0000:ooooo`;o00001_ooool2
o`0001;ooooo0_l0000nooooo`;o0000JOooool2o`000003ooooool0003o0000023ooooo000Noooo
o`03o`000?oooooooooo04[ooooo0_l00009ooooo`;o00000oooool2o`0000Oooooo0_l0000Boooo
o`;o0000B_ooool2o`0005gooooo0_l000000ooooooo0000o`00000Pooooo`007_ooool00ol0003o
ooooooooo`0Pooooo`;o0000;Oooool2o`0000Cooooo0_l00003ooooo`;o0000Ioooool2o`0005Go
oooo0_l0000[ooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o0000;Oooool4o`000<Oooooo
0_l0000[ooooo`007_ooool00ol0003oooooooooo`1Aooooo`;o0000m?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`1=ooooo`;o0000coooool2o`00
02Oooooo000Nooooo`;o0000C_ooool2o`00013ooooo0_l0001Wooooo`;o00002?ooool2o`0004[o
oooo0_l0000Wooooo`007_ooool00ol0003oooooooooo`19ooooo`;o00002_ooool2o`0000Sooooo
0_l0000Looooo`;o0000BOooool2o`0000Sooooo0_l0001:ooooo`;o00009oooool001kooooo00?o
0000ooooooooool0@oooool2o`0000Cooooo0_l0000:ooooo`;o000000?oooooo`000?l000008ooo
ool2o`0009oooooo0_l0000Wooooo`007_ooool00ol0003oooooooooo`13ooooo`;o00000oooool2
o`0000kooooo0_l00039ooooo`;o00008_ooool001kooooo00?o0000ooooooooool0B?ooool2o`00
00?ooooo0_l00006ooooo`;o0000c?ooool2o`0002;ooooo000Nooooo`03o`000?oooooooooo04go
oooo0_l00006ooooo`;o0000K?ooool2o`0008;ooooo000Nooooo`03o`000?oooooooooo00_ooooo
0_l00010ooooo`Co00005?ooool2o`0000?ooooo0_l0001Gooooo`;o0000P_ooool001kooooo00?o
0000ooooooooool02oooool2o`00043ooooo1?l0000Dooooo`;o00000oooool2o`000:_ooooo0_l0
000:ooooo`?o00008Oooool001kooooo00?o0000ooooooooool0COooool2o`0000Cooooo0_l0000?
ooooo`;o00000_ooool2o`000:gooooo0_l0000:ooooo`?o00001Oooool3o`0001Wooooo000Noooo
o`03o`000?oooooooooo04gooooo1?l00002ooooo`;o000000?oooooo`000?l000003?ooool2o`00
00;ooooo0_l00031ooooo`?o00006Oooool001kooooo00?o0000ooooooooool0C_ooool3o`0000Go
oooo0_l0003Hooooo`;o00005Oooool001kooooo00?o0000ooooooooool0C?ooool5o`000<cooooo
0_l0000Aooooo`;o00005Oooool001kooooo00?o0000ooooooooool0C?ooool2o`000<oooooo0_l0
000Xooooo`007_ooool00ol0003oooooooooo`1>ooooo`Co000000?oooooo`000?l00000e_ooool2
o`0001[ooooo000Nooooo`03o`000?oooooooooo04kooooo1?l000000ooooooo0000o`00002Poooo
o`;o0000=?ooool2o`0000Cooooo0_l0000Dooooo`007_ooool00ol0003oooooooooo`1<ooooo`;o
00001?ooool2o`0000kooooo0_l00004ooooo`;o0000Roooool2o`0003Cooooo0_l00004ooooo`;o
00005?ooool001kooooo0ol0000/ooooo`;o00007_ooool2o`0000Cooooo0_l0000>ooooo`;o0000
1?ooool2o`000=gooooo000Nooooo`?o0000;?ooool2o`0001gooooo1_l0000@ooooo`;o0000VOoo
ool2o`00033ooooo0_l0000Gooooo`007_ooool00ol0003oooooooooo`1;ooooo`Ko00002_ooool2
o`0000Cooooo0_l0000<ooooo`;o0000Roooool2o`00033ooooo0_l0000Gooooo`007_ooool00ol0
003oooooooooo`05ooooo`;o00000oooool2o`00043ooooo2?l00007ooooo`;o00004_ooool2o`00
043ooooo0_l0000@ooooo`;o0000COooool2o`0003?ooooo000Nooooo`?o00001Oooool2o`0000?o
oooo0_l0000oooooo`Go000000Coooooo`000?l0003o0000GOooool2o`00013ooooo0_l0001=oooo
o`;o0000<oooool001kooooo0ol0000<ooooo`;o0000?Oooool9o`000003ooooool0003o00000:Go
oooo0_l00012ooooo`;o00001Oooool001kooooo00?o0000ooooooooool03?ooool2o`0003gooooo
2Ol000000ooooooo0000o`00000@ooooo`;o0000Toooool2o`0004;ooooo0_l00005ooooo`007_oo
ool00ol0003oooooooooo`1;ooooo`[o00004_ooool2o`000=kooooo000Nooooo`03o`000?oooooo
oooo04_ooooo0_l000000ooooooo0000o`000003ooooo`;o0000b?ooool2o`0001kooooo0_l00008
ooooo`007_ooool00ol0003oooooooooo`02ooooo`;o0000Aoooool2o`000003ooooool0003o0000
00;o000000?oooooo`000?l000002Oooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2
o`0007Kooooo0_l0000kooooo`;o00005oooool2o`0000Gooooo0_l00008ooooo`007_ooool00ol0
003oooooooooo`02ooooo`;o0000C?ooool2o`000003ooooool0003o000000;o00001oooool2o`00
00;ooooo0_l000001?oooooo0000o`000?ooool2o`0002_ooooo0_l00019ooooo`;o0000E?ooool2
o`0000Sooooo0_l00005ooooo`007_ooool00ol0003oooooooooo`1@ooooo`;o000000?oooooo`00
0?l000000_l0000nooooo`;o0000T_ooool2o`0001Gooooo0_l00005ooooo`007_ooool00ol0003o
ooooooooo`1:ooooo`Go000000Coooooo`000?l0003ooooo1?l000000ooooooo0000o`00000:oooo
o`;o0000EOooool2o`0006cooooo0_l0000;ooooo`;o00002?ooool2o`0000Gooooo000Nooooo`03
o`000?oooooooooo03Wooooo0_l0000?ooooo`Go000000Coooooo`000?l0003ooooo1?l000000ooo
oooo0000o`000006ooooo`;o00000_ooool2o`0003cooooo0_l0000Gooooo`;o0000M?ooool2o`00
00;ooooo0ol00005ooooo`;o00002?ooool001kooooo00?o0000ooooooooool0>Oooool2o`0001;o
oooo0_l000000ooooooo0000o`000003o`0000[ooooo0ol00003ooooo`;o0000>oooool2o`0000Ko
oooo0_l00025ooooo`;o00000_ooool2o`0000Kooooo0_l00008ooooo`007_ooool00ol0003ooooo
ooooo`1Aooooo`;o00003?ooool2o`0000Cooooo0ol00003ooooo`;o0000?Oooool2o`0009_ooooo
000Nooooo`;o0000D?ooool2o`0000;ooooo0ol00005ooooo`;o00001?ooool2o`0000;ooooo0ol0
0003ooooo`;o0000f_ooool001kooooo00?o0000ooooooooool01oooool2o`0004Kooooo0_l00002
ooooo`?o00001Oooool2o`000004ooooool0003o0000ooooo`;o0000fOooool2o`0000Wooooo000N
ooooo`03o`000?oooooooooo00Oooooo0_l00014ooooo`;o00003oooool2o`0000Gooooo1?l00007
ooooo`;o0000`Oooool2o`0000Oooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`1=oooo
o`;o00000_ooool2o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`000003ooooool0003o0000
00Co00001oooool2o`000<7ooooo0_l0000:ooooo`;o00001_ooool001kooooo00?o0000oooooooo
ool0COooool6o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`000003ooooool0003o00000=7o
oooo0_l00007ooooo`;o00001_ooool001kooooo00?o0000ooooooooool0Boooool2o`000004oooo
ool0003o0000o`0001;ooooo0_l0003Aooooo`;o00003oooool001kooooo00?o0000ooooooooool0
7_ooool2o`0002_ooooo0_l000000ooooooo0000o`00000Aooooo`Co0000aoooool2o`0000Wooooo
0_l0000>ooooo`007_ooool00ol0003oooooooooo`0Nooooo`;o0000:oooool2o`0000;ooooo0_l0
000@ooooo`Co0000aoooool2o`0000Wooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`1=
ooooo`Co00005_ooool2o`0000;ooooo0_l0002Rooooo`;o0000=_ooool001kooooo00?o0000oooo
ooooool05?ooool2o`0003Kooooo1?l000000ooooooo0000o`00000<ooooo`;o00001?ooool5o`00
0003ooooool0003o00000:;ooooo0_l0000fooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o
0000=_ooool3o`0000;ooooo0_l00004ooooo`;o00001_ooool2o`0000Cooooo0_l000000ooooooo
0000o`000007ooooo`?o0000^_ooool2o`0001Oooooo000Nooooo`03o`000?oooooooooo04gooooo
0_l00008ooooo`;o00001oooool2o`0000oooooo0ol0002Oooooo`;o00006Oooool2o`0001Oooooo
000Nooooo`03o`000?oooooooooo04gooooo0_l0000;ooooo`;o00001?ooool2o`0000kooooo0_l0
002>ooooo`;o00004Oooool2o`0000gooooo0_l0000Iooooo`;o00002?ooool001kooooo00?o0000
ooooooooool0COooool4o`0000Oooooo1?l00002ooooo`;o00000oooool2o`0000?ooooo0ol00005
ooooo`;o0000S_ooool2o`00023ooooo0_l0000Iooooo`;o00002?ooool000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o
0000ooooooooool04_ooool2o`0003_ooooo0_l00007ooooo`;o00001?ooool2o`0000?ooooo0_l0
0003ooooo`?o0000g?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool00_l0000@ooooo`;o0000
>Oooool5o`0001Oooooo0_l0002eooooo`;o00009Oooool000?ooooo00Go410@oooooooooooooooo
oa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool5o`0004_ooooo1Ol0000Jooooo`;o
00002oooool2o`000:Gooooo0_l0000Uooooo`000oooool01Ol0003ooooooooooooooooo000000_o
oooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo04_ooooo0_l000000ooo
oooo0000o`00000Looooo`;o00002oooool2o`000<cooooo0003ooooo`05o`000?oooooooooooooo
ool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool00_ooool2
o`0004Oooooo0_l0003Oooooo`;o00006Oooool000?ooooo00Go410@oooooooooooooooooa0@400;
ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool00_ooool2o`0004Kooooo0_l0000O
ooooo`;o00000_ooool2o`0000cooooo0_l0002Aooooo`;o00006_ooool2o`0001Wooooo0003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooo
oooo04[ooooo0_l0000Aooooo`;o00003?ooool2o`0000;ooooo0_l0000<ooooo`;o0000TOooool2
o`0003Gooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@
4106ooooo`03o`000?oooooooooo05Gooooo0_l00006ooooo`;o00000_ooool2o`0001[ooooo1?l0
0036ooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o0000<Oooool2o`00013ooooo0_l0000:
ooooo`;o00006_ooool4o`0005gooooo0_l0001Wooooo`007_ooool00ol0003oooooooooo`0@oooo
o`;o0000<Oooool2o`0002Oooooo0_l0000Aooooo`;o0000GOooool2o`0006Oooooo000Nooooo`03
o`000?oooooooooo04Wooooo0ol0000Mooooo`;o000000?oooooo`000?l000001Oooool2o`0000[o
oooo0_l00036ooooo`007_ooool00ol0003oooooooooo`16ooooo`;o000000Coooooo`000?l0003o
00007Oooool2o`0000Sooooo0_l0000;ooooo`;o0000aOooool001kooooo00?o0000ooooooooool0
A_ooool2o`0001oooooo0_l0000=ooooo`;o00002?ooool2o`000<Gooooo000Nooooo`03o`000?oo
oooooooo04Sooooo0_l0000Aooooo`;o00002_ooool2o`0000gooooo0_l0000>ooooo`;o0000_ooo
ool001kooooo00?o0000ooooooooool04oooool2o`0003?ooooo0_l0000Aooooo`;o0000:Oooool2
o`0009cooooo0_l0000Qooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o0000<oooool4o`00
027ooooo0_l0002eooooo`;o00008Oooool001kooooo00?o0000ooooooooool0B?ooool4o`0001ko
oooo0_l000000ooooooo0000o`00000Zooooo`;o00004?ooool2o`0009[ooooo000Nooooo`03o`00
0?oooooooooo023ooooo0_l0000Wooooo`;o00007oooool2o`0002gooooo0_l0000@ooooo`;o0000
9oooool2o`00077ooooo000Nooooo`03o`000?oooooooooo023ooooo0_l0001booooo`;o0000?_oo
ool2o`00077ooooo000Nooooo`;o0000P_ooool2o`0000Cooooo0_l0000;ooooo`;o0000Eoooool2
o`0005Sooooo000Nooooo`03o`000?oooooooooo04_ooooo0_l0000dooooo`;o00001?ooool2o`00
05[ooooo0_l00008ooooo`;o00005?ooool2o`0003Sooooo0_l00008ooooo`007_ooool00ol0003o
ooooooooo`1;ooooo`;o0000Boooool2o`0000[ooooo0_l0000Eooooo`;o00009_ooool2o`0001ko
oooo0_l0000hooooo`;o00002?ooool001kooooo00?o0000ooooooooool0C?ooool2o`0004[ooooo
0_l0000:ooooo`;o00005Oooool2o`0000;ooooo0_l00026ooooo`007_ooool00ol0003ooooooooo
o`16ooooo`Co00000_ooool2o`000003ooooool0003o000006kooooo0_l00026ooooo`007_ooool0
0ol0003oooooooooo`0Iooooo`;o0000:oooool4o`0000Gooooo0_l0001Fooooo`;o0000EOooool2
o`0004Oooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l0000[ooooo`Ko00002?ooool2o`00
057ooooo0_l0001Eooooo`;o0000Aoooool001kooooo00?o0000ooooooooool0BOooool4o`0000Oo
oooo0_l0000nooooo`;o00004?ooool2o`0009oooooo000Nooooo`03o`000?oooooooooo04Oooooo
0_l00002ooooo`;o00007Oooool2o`0002Sooooo0_l0000@ooooo`;o00001?ooool2o`0003kooooo
0_l00011ooooo`;o00005_ooool001kooooo00?o0000ooooooooool0Aoooool2o`00027ooooo0_l0
0010ooooo`;o0000?_ooool2o`00047ooooo0_l0000Fooooo`007_ooool00ol0003oooooooooo`02
o`0003;ooooo0_l0000Aooooo`;o000000?oooooo`000?l00000eOooool2o`0002Cooooo000Noooo
o`03o`000?oooooooooo00;o0000<_ooool2o`0000oooooo2?l000000ooooooo0000o`00003Aoooo
o`;o00009?ooool001kooooo00?o0000ooooooooool0AOooool2o`0000;ooooo1?l000000ooooooo
0000o`000013ooooo`;o0000A?ooool2o`0006cooooo000Nooooo`03o`000?oooooooooo04_ooooo
0_l00016ooooo`;o00000oooool2o`0003oooooo0_l0001/ooooo`007_ooool00ol0003ooooooooo
o`16ooooo`;o00000oooool2o`0000gooooo0_l0000looooo`;o0000[Oooool001kooooo00?o0000
ooooooooool0AOooool3o`0001;ooooo0_l0003Pooooo`;o00002Oooool001kooooo0_l0000Foooo
o`;o0000;_ooool2o`00057ooooo0_l0002Rooooo`;o00002Oooool001kooooo00?o0000oooooooo
ool05Oooool2o`0002gooooo0_l0001Booooo`;o0000[Oooool001kooooo00?o0000ooooooooool0
A?ooool2o`0001[ooooo0_l0003Uooooo`007_ooool00ol0003oooooooooo`15ooooo`;o00006Ooo
ool2o`000>Gooooo000Nooooo`03o`000?oooooooooo04Gooooo0_l00002ooooo`;o0000<oooool2
o`0001Gooooo0_l0002`ooooo`007_ooool00ol0003oooooooooo`19ooooo`;o00002oooool2o`00
02Kooooo0_l0000Eooooo`;o0000<_ooool2o`0007cooooo000Nooooo`03o`000?oooooooooo05Ko
oooo0_l0001aooooo`;o0000O?ooool001kooooo00?o0000ooooooooool0>_ooool2o`000?oooooo
3?ooool001kooooo00?o0000ooooooooool0>_ooool2o`0000cooooo0_l0000kooooo`;o0000`?oo
ool001kooooo00?o0000ooooooooool0B?ooool2o`00037ooooo0_l00008ooooo`;o00002_ooool2
o`000;Cooooo000Nooooo`03o`000?oooooooooo04Gooooo0_l0000dooooo`;o00005?ooool2o`00
06Kooooo0_l00006ooooo`;o0000A?ooool001kooooo00?o0000ooooooooool0AOooool3o`0002oo
oooo0_l00020ooooo`;o00001_ooool2o`0004Cooooo000Nooooo`03o`000?oooooooooo03Cooooo
0_l0000@ooooo`Co0000;Oooool2o`0000Kooooo0_l00005ooooo`;o00004_ooool2o`000:_ooooo
000Nooooo`03o`000?oooooooooo01[ooooo0_l0000Hooooo`;o00003_ooool2o`0000;ooooo0_l0
000eooooo`;o00001Oooool2o`0001;ooooo0_l0002[ooooo`007_ooool00ol0003oooooooooo`0J
ooooo`;o0000:?ooool2o`000>oooooo0_l0000@ooooo`007_ooool00ol0003oooooooooo`15oooo
o`;o0000N_ooool2o`0007;ooooo0_l0000@ooooo`007_ooool2o`0000Kooooo0_l0000nooooo`;o
00002?ooool2o`0002Sooooo0_l00016ooooo`;o0000Q?ooool001kooooo00?o0000ooooooooool0
1Oooool2o`0003gooooo1Ol00006ooooo`;o00001?ooool2o`0002;ooooo0_l0003<ooooo`007_oo
ool00ol0003oooooooooo`14ooooo`Go00003?ooool2o`0007Kooooo0_l0001hooooo`007_ooool0
0ol0003oooooooooo`0Rooooo`;o00008Oooool3o`0008Gooooo0_l0001hooooo`007_ooool00ol0
003oooooooooo`0Rooooo`;o00008Oooool2o`0000Cooooo0_l0003jooooo`007_ooool00ol0003o
ooooooooo`0Looooo`;o00009?ooool3o`0000Kooooo0_l0003jooooo`007_ooool00ol0003ooooo
ooooo`0?ooooo`;o00002oooool2o`0000kooooo0_l0000Dooooo`?o0000=oooool2o`0004gooooo
0_l0001jooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o00006oooool2o`0001Cooooo0ol0
000gooooo`;o0000COooool2o`00013ooooo0_l0001Xooooo`007_ooool00ol0003oooooooooo`0@
ooooo`;o0000<?ooool3o`0004;ooooo0_l0001Dooooo`;o0000J?ooool001kooooo00?o0000oooo
ooooool04?ooool2o`0002oooooo1Ol00011ooooo`;o0000__ooool001kooooo00?o0000oooooooo
ool0@Oooool6o`000?oooooo0Oooool001kooooo00?o0000ooooooooool0@_ooool2o`000003oooo
ool0003o000004gooooo0_l0002aooooo`007_ooool00ol0003oooooooooo`12ooooo`;o0000D?oo
ool2o`000;7ooooo000Nooooo`03o`000?oooooooooo017ooooo0_l0001=ooooo`;o00002oooool2
o`000=Sooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<
ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo017ooooo0_l0000^ooooo`;o00007Ooo
ool2o`0000_ooooo0_l0003Hooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`11ooooo`?o0000
1_ooool2o`00027ooooo0_l0003Hooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo
00Go0000ooooooooooooooooo`000006ooooo`?o0000@_ooool2o`0000Kooooo0_l0003_ooooo`;o
00002_ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRH
V?lb<S801_ooool00ol0003oooooooooo`2=ooooo`;o0000[?ooool2o`0000[ooooo0003ooooo`05
o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000
ooooooooool0@?ooool4o`000003ooooool0003o000004Kooooo0_l0002hooooo`000oooool01Ol@
413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oo
oooooooo043ooooo1?l000000ooooooo0000o`00003oooooo`7ooooo0003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0
@?ooool4o`0009_ooooo0_l00012ooooo`;o00008_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`0oooooo`;o
000000?oooooo`000?l00000TOooool2o`0000Sooooo0_l00012ooooo`?o00008Oooool001kooooo
00?o0000ooooooooool0>_ooool2o`0000?ooooo0_l0000Wooooo`;o0000Joooool2o`0004gooooo
0_l0000Qooooo`007_ooool00ol0003oooooooooo`0jooooo`?o00000oooool2o`0002Kooooo0_l0
003Mooooo`007_ooool00ol0003oooooooooo`0jooooo`?o00000oooool2o`00043ooooo0_l0001H
ooooo`;o0000JOooool001kooooo00?o0000ooooooooool0>_ooool2o`0000Kooooo1Ol0000koooo
o`;o0000F?ooool2o`0006Wooooo000Nooooo`03o`000?oooooooooo04;ooooo1Ol00009ooooo`;o
0000mOooool001kooooo00?o0000ooooooooool0@_ooool5o`0000Wooooo0_l0003eooooo`007_oo
ool00ol0003oooooooooo`12ooooo`?o0000>Oooool2o`00033ooooo0_l0002Eooooo`007_ooool0
0ol0003oooooooooo`12ooooo`Go0000=oooool4o`0002kooooo0_l0002Eooooo`007_ooool00ol0
003oooooooooo`0Mooooo`;o00001?ooool2o`0001_ooooo0_l00002ooooo`Co00002?ooool2o`00
02kooooo0_l00035ooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o00001?ooool2o`0001_o
oooo0_l00003ooooo`?o00002?ooool2o`0000;ooooo0_l0003aooooo`007_ooool00ol0003ooooo
ooooo`0nooooo`?o00000_ooool2o`000003ooooool0003o000000cooooo0_l0003aooooo`007_oo
ool2o`0003Wooooo0_l00004ooooo`?o00000_ooool2o`000?oooooo0oooool001kooooo00?o0000
ooooooooool04Oooool2o`00023ooooo0ol00002ooooo`;o00003?ooool2o`00033ooooo0_l0002_
ooooo`;o00007?ooool001kooooo00?o0000ooooooooool04Oooool2o`0001kooooo1Ol0000@oooo
o`;o00002_ooool2o`0002Cooooo0_l0002_ooooo`;o00007?ooool001kooooo00?o0000oooooooo
ool0<Oooool2o`0001oooooo0_l0001Aooooo`;o0000M?ooool2o`0002[ooooo000Nooooo`03o`00
0?oooooooooo0:Gooooo0_l0000Kooooo`;o0000Eoooool2o`0002[ooooo000Nooooo`03o`000?oo
oooooooo013ooooo0_l00003ooooo`;o00006_ooool2o`0001Gooooo0_l0001hooooo`;o0000Pooo
ool001kooooo00?o0000ooooooooool04?ooool2o`0000?ooooo0_l0000Dooooo`;o00001?ooool2
o`0001Cooooo0ol0003mooooo`007_ooool00ol0003oooooooooo`0[ooooo`;o00006_ooool3o`00
0?gooooo000Nooooo`03o`000?oooooooooo04Sooooo0_l0003Yooooo`;o00004_ooool001kooooo
00?o0000ooooooooool0=?ooool2o`0000Kooooo0_l0000:ooooo`;o0000L_ooool2o`0007Gooooo
0_l0000Booooo`007_ooool00ol0003oooooooooo`0aooooo`;o000000?oooooo`000?l000001_oo
ool2o`0000[ooooo0_l00013ooooo`;o0000;Oooool2o`0008Wooooo000Nooooo`03o`000?oooooo
oooo037ooooo0_l0000Eooooo`;o0000@oooool2o`000;Sooooo000Nooooo`03o`000?oooooooooo
01Gooooo0_l00003ooooo`;o00009_ooool2o`0000Cooooo0_l0003mooooo`007_ooool00ol0003o
ooooooooo`0Eooooo`;o00000oooool2o`0002Kooooo0_l000000ooooooo0000o`000003o`0007?o
oooo0_l00028ooooo`007_ooool2o`0004Cooooo1ol0000Booooo`;o00008?ooool2o`0000;ooooo
0_l0000iooooo`;o0000=?ooool2o`0005;ooooo000Nooooo`;o00004Oooool2o`0002;ooooo0_l0
00000ooooooo0000o`00000:ooooo`;o00000_ooool5o`00013ooooo0_l00008ooooo`;o00005_oo
ool2o`0000;ooooo0_l0000Cooooo`;o0000F_ooool2o`0002_ooooo0_l0000Uooooo`007_ooool2
o`00017ooooo0_l0000?ooooo`;o00004Oooool2o`000003ooooool0003o000000kooooo1Ol0000J
ooooo`;o0000:?ooool2o`0000Gooooo0_l00027ooooo`;o00009Oooool001kooooo00?o0000oooo
ooooool00oooool2o`0001cooooo0_l0000Nooooo`;o00001Oooool4o`0004Cooooo0_l0000Goooo
o`;o0000W?ooool001kooooo00?o0000ooooooooool00oooool2o`0003?ooooo0_l00007ooooo`;o
00001Oooool2o`0005oooooo0_l0000?ooooo`;o0000Noooool2o`0000kooooo000Nooooo`03o`00
0?oooooooooo01Kooooo0ol0000Mooooo`Co00004Oooool2o`0006gooooo0_l0001kooooo`;o0000
3_ooool001kooooo00?o0000ooooooooool05_ooool3o`0001gooooo0_l0000Aooooo`Co0000`_oo
ool2o`0003Kooooo000Nooooo`03o`000?oooooooooo04Wooooo1?l00032ooooo`;o0000=_ooool0
01kooooo00?o0000ooooooooool03oooool2o`0003Wooooo0ol000000ooooooo0000o`000003oooo
o`;o0000l_ooool001kooooo00?o0000ooooooooool03oooool2o`0000cooooo0_l0000]ooooo`Co
00000oooool2o`000?;ooooo000Nooooo`03o`000?oooooooooo01gooooo0_l0000]ooooo`;o0000
2Oooool2o`000>kooooo000Nooooo`03o`000?oooooooooo04gooooo0_l00008ooooo`;o0000Mooo
ool2o`0007Gooooo000Nooooo`03o`000?oooooooooo04Kooooo0_l00005ooooo`;o0000<?ooool2
o`0004oooooo0_l0001eooooo`007_ooool00ol0003oooooooooo`0/ooooo`;o00006?ooool2o`00
00Gooooo0_l0000`ooooo`;o00008?ooool2o`0009?ooooo0_l0000?ooooo`007_ooool00ol0003o
ooooooooo`0/ooooo`Co00006Oooool2o`0000;ooooo0_l0001Booooo`;o0000Toooool2o`0000oo
oooo000Nooooo`03o`000?oooooooooo02kooooo0_l0000Iooooo`;o00004_ooool2o`000>Sooooo
000Nooooo`03o`000?oooooooooo05gooooo0_l0003Xooooo`007_ooool00ol0003oooooooooo`14
ooooo`;o00001_ooool2o`000?Wooooo000Nooooo`;o0000AOooool2o`0000Kooooo0_l0003_oooo
o`;o00002?ooool001kooooo00?o0000ooooooooool0??ooool2o`0000oooooo0_l0000Yooooo`;o
0000]oooool2o`0000[ooooo0_l00008ooooo`007_ooool00ol0003oooooooooo`0looooo`;o0000
3oooool2o`0002?ooooo0_l00004ooooo`;o0000]oooool2o`0000[ooooo0_l00008ooooo`007_oo
ool00ol0003oooooooooo`1Cooooo`;o00007Oooool2o`000=?ooooo000Nooooo`04o`000?oooooo
0000o`00023ooooo0_l0000Xooooo`;o00001_ooool3o`0001Gooooo0_l0003Jooooo`007_ooool0
1?l0003oooooo`000?l0000Iooooo`;o00001Oooool2o`0000_ooooo0_l0000Kooooo`;o00001ooo
ool3o`0001Cooooo0_l0003Jooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o00004_ooool2
o`0002Cooooo0ol0003`ooooo`007_ooool00ol0003oooooooooo`14ooooo`;o00003_ooool2o`00
00;ooooo0_l0000Zooooo`;o0000`Oooool001kooooo00?o0000ooooooooool0A?ooool2o`0000;o
oooo0_l000000ooooooo0000o`000005ooooo`So00009?ooool2o`0000Cooooo0_l00031ooooo`00
7_ooool00ol0003oooooooooo`15ooooo`;o000000Coooooo`000?l0003ooooo0_l00005ooooo`;o
000000?oooooo`000?l000000_l0000Uooooo`;o0000=oooool2o`0008kooooo000Nooooo`03o`00
0?oooooooooo01kooooo0_l0000Uooooo`;o00004?ooool4o`0004[ooooo0_l0000@ooooo`;o0000
S_ooool001kooooo00?o0000ooooooooool02?ooool2o`0001Cooooo0_l0000gooooo`Co00002_oo
ool2o`0003kooooo0_l0000dooooo`;o0000J_ooool001kooooo00?o0000ooooooooool02?ooool2
o`0002Sooooo0_l0000Sooooo`?o00002oooool2o`0000Wooooo0_l0001Yooooo`;o0000J_ooool0
01kooooo00?o0000ooooooooool00oooool2o`0000oooooo0_l0000Looooo`;o00000oooool2o`00
01;ooooo0_l00002ooooo`Go00000oooool3o`0001Kooooo0_l0000Xooooo`;o000000?oooooo`00
0?l00000Z?ooool001Cooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo0_l0000?ooooo`;o00007_ooool2o`000003ooooool0003o000001;ooooo0_l00002ooooo`Go
000000?oooooo`000?l000000_ooool2o`0003oooooo0_l000000ooooooo0000o`00002Xooooo`00
5_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03?ooooo0ol0000Jooooo`;o0000
0oooool2o`0000;ooooo0ol00035ooooo`;o00009?ooool001Kooooo00?o0000ooooooooool01Ooo
ool3o`0003?ooooo0_l0000Uooooo`;o00003_ooool2o`000;Gooooo0_l0000Tooooo`005_ooool0
0ol0003oooooooooo`1Rooooo`;o00003_ooool2o`000=_ooooo000Fooooo`03o`000?oooooooooo
0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003ooooo
ooooo`3ooooooe3ooooo000Dooooo`03oeEEEOmVIVKo00000?ooooooD_ooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.28093 .69145 Mdot
.88096 .39956 Mdot
.31408 .55004 Mdot
.22295 .96987 Mdot
.24301 .51195 Mdot
.27889 .97498 Mdot
.51611 .09165 Mdot
.2526 .53275 Mdot
.25323 .95582 Mdot
.73384 .10686 Mdot
.30541 .13589 Mdot
.32451 .06769 Mdot
.26379 .54751 Mdot
.46259 .65729 Mdot
.26599 .94811 Mdot
.35472 .63262 Mdot
.81819 .57423 Mdot
.24887 .55638 Mdot
.29072 .58881 Mdot
.21998 .0571 Mdot
.94132 .57009 Mdot
.3122 .04073 Mdot
.27917 .49465 Mdot
.9116 .07921 Mdot
.22932 .88235 Mdot
.27196 .52158 Mdot
.251 .82541 Mdot
.41433 .70752 Mdot
.30751 .13796 Mdot
.29869 .0679 Mdot
.26616 .56603 Mdot
.26877 .93763 Mdot
.25666 .00782 Mdot
.01434 .94325 Mdot
.02501 .53809 Mdot
.22627 .87806 Mdot
.47422 .66562 Mdot
.92191 .47588 Mdot
.34042 .83679 Mdot
.22785 .79385 Mdot
.27493 .57117 Mdot
.12649 .63203 Mdot
.1631 .96984 Mdot
.87431 .56123 Mdot
.42948 .06991 Mdot
.13837 .70054 Mdot
.59148 .42241 Mdot
.17463 .84776 Mdot
.25167 .82726 Mdot
.23128 .3554 Mdot
.2875 .00761 Mdot
.04285 .51977 Mdot
.24897 .46684 Mdot
.22815 .86058 Mdot
.25016 .45126 Mdot
.26022 .23677 Mdot
.76305 .25929 Mdot
.24611 .53853 Mdot
.25353 .83053 Mdot
.23233 .65078 Mdot
.23993 .9814 Mdot
.2685 .53857 Mdot
.52616 .10208 Mdot
.22884 .91597 Mdot
.21486 .75236 Mdot
.29432 .01059 Mdot
.14212 .42544 Mdot
.25244 .82487 Mdot
.28207 .98941 Mdot
.81788 .27907 Mdot
.22155 .22483 Mdot
.2764 .57809 Mdot
.15829 .13189 Mdot
.27893 .18726 Mdot
.29541 .04567 Mdot
.03454 .27903 Mdot
.25462 .41587 Mdot
.61758 .17731 Mdot
.25511 .87812 Mdot
.35055 .43028 Mdot
.14691 .87193 Mdot
.61348 .14959 Mdot
.88855 .56745 Mdot
.26259 .53703 Mdot
.78919 .3831 Mdot
.08822 .20083 Mdot
.24102 .50586 Mdot
.23776 .88718 Mdot
.27425 .96482 Mdot
.25621 .61437 Mdot
.18603 .0821 Mdot
.84667 .25861 Mdot
.2328 .34783 Mdot
.23133 .20212 Mdot
.24734 .59978 Mdot
.12271 .77082 Mdot
.55807 .13428 Mdot
.0332 .5338 Mdot
.21199 .83733 Mdot
.00636 .54831 Mdot
.26165 .75451 Mdot
.28718 .97113 Mdot
.28507 .62641 Mdot
.4215 .6427 Mdot
.94186 .32362 Mdot
.27427 .50253 Mdot
.34384 .64423 Mdot
.36132 .6459 Mdot
.06681 .51763 Mdot
.59841 .1427 Mdot
.46901 .67198 Mdot
.90113 .46045 Mdot
.34175 .9855 Mdot
.24744 .56012 Mdot
.33723 .34042 Mdot
.54876 .06742 Mdot
.40607 .05244 Mdot
.28152 .55036 Mdot
.14655 .29835 Mdot
.42293 .91149 Mdot
.25509 .8239 Mdot
.16126 .74407 Mdot
.30727 .06043 Mdot
.23382 .20714 Mdot
.88848 .20549 Mdot
.97175 .55416 Mdot
.22572 .92921 Mdot
.26378 .63569 Mdot
.01948 .91238 Mdot
.11759 .10404 Mdot
.96068 .52289 Mdot
.3047 .25011 Mdot
.8165 .72614 Mdot
.25842 .55821 Mdot
.25539 .56802 Mdot
.25387 .41015 Mdot
.26872 .49954 Mdot
.28692 .62303 Mdot
.30029 .57252 Mdot
.28056 .98432 Mdot
.25257 .6237 Mdot
.22409 .91164 Mdot
.29617 .03348 Mdot
.05945 .58539 Mdot
.52649 .28741 Mdot
.31634 .06166 Mdot
.22998 .70532 Mdot
.24414 .77313 Mdot
.76684 .25298 Mdot
.58832 .13661 Mdot
.61779 .75626 Mdot
.27633 .02748 Mdot
.34185 .07801 Mdot
.22366 .0729 Mdot
.25881 .92431 Mdot
.28212 .54476 Mdot
.30149 .61284 Mdot
.75025 .31995 Mdot
.24384 .9222 Mdot
.33327 .62467 Mdot
.28316 .58852 Mdot
.00308 .53167 Mdot
.86858 .92543 Mdot
.26112 .55859 Mdot
.21154 .81063 Mdot
.24909 .49285 Mdot
.23603 .77222 Mdot
.24271 .86688 Mdot
.584 .13527 Mdot
.2539 .54811 Mdot
.30924 .07607 Mdot
.12876 .87197 Mdot
.00208 .52694 Mdot
.14368 .27976 Mdot
.28468 .65904 Mdot
.32725 .73982 Mdot
.93488 .907 Mdot
.29074 .50865 Mdot
.54947 .11423 Mdot
.03382 .52299 Mdot
.17616 .95158 Mdot
.28371 .0374 Mdot
.38829 .80113 Mdot
.43645 .12632 Mdot
.69496 .21407 Mdot
.34096 .90255 Mdot
.32772 .6198 Mdot
.16864 .05313 Mdot
.78369 .72713 Mdot
.06399 .67392 Mdot
.27701 .64916 Mdot
.04851 .18747 Mdot
.26279 .65931 Mdot
.40619 .14228 Mdot
.3993 .9117 Mdot
.1638 .99278 Mdot
.02201 .54491 Mdot
.32016 .0842 Mdot
.25205 .95987 Mdot
.28652 .03864 Mdot
.46346 .15855 Mdot
.3823 .34596 Mdot
.26243 .55983 Mdot
.45115 .10987 Mdot
.22918 .88735 Mdot
.23515 .89703 Mdot
.56935 .11407 Mdot
.24801 .86873 Mdot
.82211 .35027 Mdot
.43047 .734 Mdot
.25477 .52993 Mdot
.2483 .66159 Mdot
.91174 .2203 Mdot
.65682 .2705 Mdot
.28737 .60486 Mdot
.20737 .20543 Mdot
.22607 .77871 Mdot
.2017 .29235 Mdot
.34421 .7302 Mdot
.19314 .39941 Mdot
.76481 .27185 Mdot
.26888 .57131 Mdot
.22123 .90055 Mdot
.24979 .89314 Mdot
.2609 .59289 Mdot
.28815 .58031 Mdot
.0928 .98105 Mdot
.27773 .44491 Mdot
.69243 .18105 Mdot
.29552 .02964 Mdot
.29194 .54019 Mdot
.22755 .67227 Mdot
.29615 .03822 Mdot
.08205 .08361 Mdot
.20583 .20153 Mdot
.71233 .19338 Mdot
.69621 .51599 Mdot
.27203 .55737 Mdot
.9239 .51263 Mdot
.75585 .22537 Mdot
.27963 .46745 Mdot
.30332 .05112 Mdot
.16993 .92001 Mdot
.27501 .48133 Mdot
.3535 .82363 Mdot
.25176 .39987 Mdot
.27203 .56831 Mdot
.31017 .07715 Mdot
.63841 .14657 Mdot
.28612 .56943 Mdot
.04281 .50845 Mdot
.2573 .47032 Mdot
.81286 .19441 Mdot
.09613 .21087 Mdot
.88509 .20323 Mdot
.19072 .84823 Mdot
.24592 .47696 Mdot
.93772 .46882 Mdot
.08788 .74803 Mdot
.33935 .33722 Mdot
.25555 .69284 Mdot
.21641 .73526 Mdot
.26813 .21643 Mdot
.99051 .3824 Mdot
.29893 .04099 Mdot
.03509 .12821 Mdot
.3223 .96378 Mdot
.13389 .29125 Mdot
.27867 .5555 Mdot
.23872 .81012 Mdot
.21229 .8339 Mdot
.64856 .43685 Mdot
.25782 .01026 Mdot
.22312 .74525 Mdot
.14441 .89081 Mdot
.26066 .48516 Mdot
.32307 .72468 Mdot
.37526 .22392 Mdot
.23333 .85775 Mdot
.30282 .99676 Mdot
.78854 .25776 Mdot
.31086 .05415 Mdot
.26514 .54732 Mdot
.48943 .64167 Mdot
.24607 .49279 Mdot
.22182 .90047 Mdot
.25372 .55528 Mdot
.96536 .49536 Mdot
.1856 .76454 Mdot
.30602 .17235 Mdot
.18331 .90072 Mdot
.85798 .25688 Mdot
.28609 .58906 Mdot
.39569 .1158 Mdot
.56641 .12667 Mdot
.97374 .50355 Mdot
.22224 .74746 Mdot
.32061 .61394 Mdot
.78694 .24882 Mdot
.6376 .16305 Mdot
.96258 .49241 Mdot
.21652 .91682 Mdot
.03522 .55043 Mdot
.27125 .56865 Mdot
.71752 .08936 Mdot
.08661 .48003 Mdot
.24924 .8301 Mdot
.25352 .88917 Mdot
.89605 .16347 Mdot
.37025 .33524 Mdot
.25193 .84552 Mdot
.78357 .24434 Mdot
.27424 .52694 Mdot
.30659 .38159 Mdot
.21423 .78629 Mdot
.21597 .77541 Mdot
.33635 .76152 Mdot
.14149 .27736 Mdot
.2431 .98299 Mdot
.95707 .34477 Mdot
.34684 .84098 Mdot
.26909 .02493 Mdot
.2942 .01769 Mdot
.41306 .78232 Mdot
.25183 .56632 Mdot
.29513 .5412 Mdot
.23499 .8562 Mdot
.24604 .69275 Mdot
.30766 .05213 Mdot
.2862 .54208 Mdot
.1991 .06187 Mdot
.28849 .99847 Mdot
.40585 .24915 Mdot
.90358 .12646 Mdot
.18366 .31683 Mdot
.25923 .32252 Mdot
.73575 .67026 Mdot
.25104 .80891 Mdot
.75932 .90581 Mdot
.03001 .11355 Mdot
.21388 .83296 Mdot
.74026 .64472 Mdot
.2428 .65467 Mdot
.27261 .57046 Mdot
.72369 .31286 Mdot
.45731 .54275 Mdot
.57626 .13111 Mdot
.30222 .25959 Mdot
.96967 .42769 Mdot
.24616 .52986 Mdot
.28974 .55454 Mdot
.25059 .47112 Mdot
.03372 .68914 Mdot
.40893 .669 Mdot
.54316 .10595 Mdot
.24992 .00103 Mdot
.11713 .6148 Mdot
.26315 .56112 Mdot
.2485 .54535 Mdot
.21687 .29529 Mdot
.30948 .06326 Mdot
.94818 .81539 Mdot
.26937 .57007 Mdot
.25758 .52359 Mdot
.21841 .91776 Mdot
.01174 .74049 Mdot
.55682 .90483 Mdot
.7025 .64782 Mdot
.73449 .21059 Mdot
.30005 .04235 Mdot
.28225 .60636 Mdot
.24607 .83641 Mdot
.30977 .56129 Mdot
.28468 .0079 Mdot
.12258 .91971 Mdot
.99595 .54292 Mdot
.4386 .06967 Mdot
.24316 .85165 Mdot
.92524 .17995 Mdot
.3055 .09187 Mdot
.25696 .89049 Mdot
.20601 .9864 Mdot
.71099 .21352 Mdot
.88223 .20279 Mdot
.40108 .72199 Mdot
.42221 .11132 Mdot
.57583 .87626 Mdot
.58704 .50163 Mdot
.24897 .81376 Mdot
.49313 .67407 Mdot
.25392 .61508 Mdot
.23872 .54427 Mdot
.27378 .74047 Mdot
.23198 .52795 Mdot
.23808 .52073 Mdot
.34942 .26687 Mdot
.82312 .64423 Mdot
.99335 .15407 Mdot
.25446 .83365 Mdot
.25823 .57212 Mdot
.15156 .00197 Mdot
.43673 .00842 Mdot
.76705 .30057 Mdot
.26866 .53923 Mdot
.56237 .65785 Mdot
.06142 .96351 Mdot
.2969 .17539 Mdot
.26755 .59554 Mdot
.28468 .56419 Mdot
.26028 .55772 Mdot
.27926 .6103 Mdot
.23615 .88724 Mdot
.28308 .59407 Mdot
.51405 .06671 Mdot
.73771 .22848 Mdot
.25766 .55694 Mdot
.27797 .61877 Mdot
.28551 .58379 Mdot
.75016 .29522 Mdot
.25521 .87877 Mdot
.23524 .82507 Mdot
.5384 .37241 Mdot
.70608 .19022 Mdot
.24717 .54994 Mdot
.25149 .53619 Mdot
.80267 .50265 Mdot
.42117 .1733 Mdot
.27075 .98828 Mdot
.27698 .57805 Mdot
.8299 .3475 Mdot
.74976 .2285 Mdot
.60782 .43914 Mdot
.38415 .42195 Mdot
.20068 .01234 Mdot
.80196 .2504 Mdot
.48886 .54325 Mdot
.36269 .71663 Mdot
.07218 .98801 Mdot
.25531 .55139 Mdot
.41193 .04271 Mdot
.34505 .94365 Mdot
.88646 .49659 Mdot
.87587 .59552 Mdot
.2488 .98893 Mdot
.25997 .27738 Mdot
.24625 .93141 Mdot
.26272 .02148 Mdot
.24693 .53237 Mdot
.84367 .23928 Mdot
.28275 .52754 Mdot
.93603 .66839 Mdot
.08583 .51913 Mdot
.21578 .84217 Mdot
.25439 .88632 Mdot
.36493 .12179 Mdot
.25305 .84343 Mdot
.23588 .91233 Mdot
.22837 .86682 Mdot
.03851 .95494 Mdot
.40405 .40931 Mdot
.25403 .73041 Mdot
.23898 .89574 Mdot
.26053 .90654 Mdot
.30712 .52543 Mdot
.94447 .16974 Mdot
.0245 .52709 Mdot
.26113 .01672 Mdot
.97541 .58946 Mdot
.25682 .98024 Mdot
.03385 .80246 Mdot
.30305 .05143 Mdot
.24767 .51375 Mdot
.25877 .53485 Mdot
.26051 .53591 Mdot
.30301 .53087 Mdot
.26434 .91772 Mdot
.25807 .44576 Mdot
.2601 .53765 Mdot
.76629 .26722 Mdot
.22249 .86497 Mdot
.60841 .19863 Mdot
.38296 .06528 Mdot
.306 .04804 Mdot
.24875 .61202 Mdot
.27213 .68148 Mdot
.1084 .17291 Mdot
.16891 .18322 Mdot
.84709 .22295 Mdot
.13025 .90107 Mdot
.42354 .69453 Mdot
.29452 .56397 Mdot
.23943 .87072 Mdot
.38452 .26242 Mdot
.55448 .89191 Mdot
.23911 .10918 Mdot
.3199 .10103 Mdot
.21091 .51257 Mdot
.26495 .02498 Mdot
.00683 .24815 Mdot
.37152 .77032 Mdot
.24874 .44452 Mdot
.099 .05874 Mdot
.13379 .85861 Mdot
.71878 .19668 Mdot
.25445 .55495 Mdot
.22569 .37635 Mdot
.25609 .52129 Mdot
.56276 .12669 Mdot
.23487 .89804 Mdot
.28149 .07923 Mdot
.24408 .58781 Mdot
.60596 .29797 Mdot
.27522 .23847 Mdot
.71375 .22392 Mdot
.24036 .5087 Mdot
.08786 .09431 Mdot
.21357 .87038 Mdot
.12663 .77762 Mdot
.72861 .39589 Mdot
.252 .57622 Mdot
.2646 .56235 Mdot
.30585 .52905 Mdot
.2556 .8839 Mdot
.30107 .04743 Mdot
.03373 .64315 Mdot
.6845 .81574 Mdot
.396 .2599 Mdot
.80289 .65762 Mdot
.33146 .47038 Mdot
.03986 .958 Mdot
.93308 .00855 Mdot
.5202 .26045 Mdot
.24413 .50008 Mdot
.32255 .85817 Mdot
.26627 .53922 Mdot
.26587 .75937 Mdot
.21714 .763 Mdot
.23882 .96219 Mdot
.91699 .44469 Mdot
.52819 .1649 Mdot
.28161 .98596 Mdot
.73706 .23633 Mdot
.30938 .05613 Mdot
.26066 .91189 Mdot
.27944 .71607 Mdot
.54713 .1195 Mdot
.84202 .23715 Mdot
.32105 .44884 Mdot
.2639 .54121 Mdot
.29285 .54285 Mdot
.55712 .10533 Mdot
.48525 .15899 Mdot
.25023 .98849 Mdot
.99335 .9596 Mdot
.1634 .89116 Mdot
.60824 .04877 Mdot
.8422 .21932 Mdot
.25411 .79917 Mdot
.20947 .92462 Mdot
.42616 .39055 Mdot
.25906 .54896 Mdot
.24774 .98805 Mdot
.91763 .44832 Mdot
.98529 .66346 Mdot
.25411 .55569 Mdot
.2503 .8263 Mdot
.29004 .5971 Mdot
.21797 .87437 Mdot
.60889 .39718 Mdot
.2753 .96668 Mdot
.59007 .45697 Mdot
.42074 .65682 Mdot
.26753 .92589 Mdot
.23732 .69878 Mdot
.23659 .54374 Mdot
.26922 .00025 Mdot
.06906 .00732 Mdot
.30687 .13982 Mdot
.25939 .46482 Mdot
.24224 .41583 Mdot
.66558 .0093 Mdot
.84126 .26747 Mdot
.28736 .48899 Mdot
.25706 .59864 Mdot
.93122 .43655 Mdot
.23051 .88999 Mdot
.3527 .90448 Mdot
.53641 .00412 Mdot
.48482 .91772 Mdot
.22659 .65959 Mdot
.25757 .53713 Mdot
.25362 .43805 Mdot
.27501 .57207 Mdot
.27334 .03092 Mdot
.32936 .09586 Mdot
.27817 .53441 Mdot
.36644 .73034 Mdot
.28852 .54377 Mdot
.23155 .87439 Mdot
.26703 .56308 Mdot
.27435 .0145 Mdot
.24133 .83939 Mdot
.3019 .55998 Mdot
.03265 .5344 Mdot
.46107 .03695 Mdot
.26201 .5585 Mdot
.24087 .78584 Mdot
.31381 .05988 Mdot
.47758 .08092 Mdot
.26709 .68424 Mdot
.49332 .11354 Mdot
.56667 .12765 Mdot
.28388 .01684 Mdot
.33645 .2614 Mdot
.30364 .58903 Mdot
.34106 .70012 Mdot
.2775 .58072 Mdot
.14753 .20604 Mdot
.2134 .87153 Mdot
.64144 .1614 Mdot
.67287 .82891 Mdot
.46624 .37132 Mdot
.26726 .66438 Mdot
.04425 .23096 Mdot
.07746 .55376 Mdot
.32177 .02101 Mdot
.97043 .01805 Mdot
.07154 .20333 Mdot
.2622 .44436 Mdot
.12942 .98231 Mdot
.29912 .5513 Mdot
.24692 .89118 Mdot
.22579 .66359 Mdot
.40737 .53591 Mdot
.26897 .93032 Mdot
.64347 .20296 Mdot
.26068 .53647 Mdot
.23529 .36604 Mdot
.2392 .53711 Mdot
.26962 .96247 Mdot
.14812 .08128 Mdot
.27679 .96859 Mdot
.12183 .59135 Mdot
.141 .09534 Mdot
.47375 .00117 Mdot
.26657 .56607 Mdot
.24809 .95416 Mdot
.75063 .2697 Mdot
.27638 .54421 Mdot
.48946 .08872 Mdot
.87613 .03273 Mdot
.27159 .03078 Mdot
.91444 .86733 Mdot
.25282 .90242 Mdot
.84327 .23712 Mdot
.22815 .80782 Mdot
.25653 .45723 Mdot
.79464 .23994 Mdot
.8196 .34853 Mdot
.25424 .83825 Mdot
.42609 .05308 Mdot
.29178 .79006 Mdot
.70213 .1246 Mdot
.25592 .81912 Mdot
.03925 .15599 Mdot
.005 .88099 Mdot
.25486 .88199 Mdot
.53642 .10323 Mdot
.00815 .55593 Mdot
.96908 .85988 Mdot
.20158 .17288 Mdot
.69091 .09445 Mdot
.40628 .15591 Mdot
.29891 .10567 Mdot
.74937 .21653 Mdot
.27007 .53092 Mdot
.79704 .12108 Mdot
.24257 .54727 Mdot
.60154 .14647 Mdot
.78669 .40588 Mdot
.9018 .429 Mdot
.06447 .59517 Mdot
.73136 .22339 Mdot
.26905 .63344 Mdot
.27485 .96368 Mdot
.97997 .49995 Mdot
.2428 .90694 Mdot
.5848 .13653 Mdot
.47022 .86869 Mdot
.24587 .55462 Mdot
.17033 .77106 Mdot
.43974 .09425 Mdot
.22517 .33441 Mdot
.54756 .4193 Mdot
.27078 .02007 Mdot
.29278 .78729 Mdot
.25803 .90192 Mdot
.51638 .27261 Mdot
.67977 .17593 Mdot
.93698 .21217 Mdot
.22178 .29001 Mdot
.40294 .64823 Mdot
.28298 .54638 Mdot
.29928 .57568 Mdot
.18146 .20556 Mdot
.2962 .04282 Mdot
.67042 .17345 Mdot
.98631 .26411 Mdot
.37138 .19426 Mdot
.25218 .97255 Mdot
.69673 .18587 Mdot
.2615 .68993 Mdot
.4589 .95349 Mdot
.77229 .19692 Mdot
.27195 .46265 Mdot
.80543 .4888 Mdot
.30919 .06643 Mdot
.23322 .52304 Mdot
.56797 .06564 Mdot
.30798 .06874 Mdot
.24352 .6791 Mdot
.15952 .16057 Mdot
.26375 .5617 Mdot
.49174 .41884 Mdot
.94723 .6201 Mdot
.81393 .29574 Mdot
.29637 .33598 Mdot
.25621 .81277 Mdot
.14922 .11215 Mdot
.75055 .27021 Mdot
.30908 .10921 Mdot
.3099 .09594 Mdot
.29883 .54683 Mdot
.26362 .95662 Mdot
.57013 .03772 Mdot
.55502 .53395 Mdot
.84855 .24252 Mdot
.84754 .22398 Mdot
.27335 .99337 Mdot
.81806 .33472 Mdot
.25559 .78861 Mdot
.21669 .99696 Mdot
.30102 .5906 Mdot
.62559 .94777 Mdot
.08969 .09104 Mdot
.23322 .93719 Mdot
.30085 .09684 Mdot
.76184 .26233 Mdot
.24213 .97765 Mdot
.97358 .14697 Mdot
.15194 .95931 Mdot
.26745 .72734 Mdot
.38342 .13576 Mdot
.28073 .67968 Mdot
.26785 .56271 Mdot
.21307 .79994 Mdot
.24902 .54937 Mdot
.15127 .90953 Mdot
.25563 .447 Mdot
.28437 .56382 Mdot
.78375 .31262 Mdot
.25211 .53173 Mdot
.84533 .35525 Mdot
.25129 .73118 Mdot
.29787 .16156 Mdot
.23698 .00498 Mdot
.02941 .57416 Mdot
.75077 .24285 Mdot
.31968 .07992 Mdot
.85015 .35512 Mdot
.22215 .84762 Mdot
.51099 .84273 Mdot
.26983 .52239 Mdot
.25727 .47064 Mdot
.5795 .12506 Mdot
.25659 .58961 Mdot
.22036 .84808 Mdot
.2922 .56306 Mdot
.36185 .12924 Mdot
.31201 .20643 Mdot
.22108 .97517 Mdot
.39118 .89181 Mdot
.76922 .23188 Mdot
.07165 .03471 Mdot
.21772 .76007 Mdot
.30994 .61944 Mdot
.40552 .68166 Mdot
.27755 .97856 Mdot
.24057 .87323 Mdot
.29944 .54394 Mdot
.66225 .68481 Mdot
.73501 .21157 Mdot
.55034 .6543 Mdot
.27827 .50476 Mdot
.97369 .48846 Mdot
.25598 .45647 Mdot
.4219 .68442 Mdot
.6438 .64234 Mdot
.21027 .94924 Mdot
.27183 .5747 Mdot
.75246 .19994 Mdot
.31069 .06868 Mdot
.28823 .48544 Mdot
.36426 .98529 Mdot
.23861 .70409 Mdot
.25838 .55837 Mdot
.37148 .25793 Mdot
.23292 .28287 Mdot
.99962 .53449 Mdot
.2684 .56378 Mdot
.98858 .53174 Mdot
.21403 .92517 Mdot
.30738 .53021 Mdot
.64742 .81877 Mdot
.17557 .01463 Mdot
.24652 .84976 Mdot
.56954 .2522 Mdot
.77237 .25516 Mdot
.25936 .94564 Mdot
.538 .10515 Mdot
.26165 .53699 Mdot
.27656 .54396 Mdot
.21918 .92695 Mdot
.27851 .54412 Mdot
.24182 .51873 Mdot
.29218 .62077 Mdot
.2483 .47475 Mdot
.21282 .84871 Mdot
.57384 .12142 Mdot
.27192 .55808 Mdot
.40479 .0591 Mdot
.96328 .48178 Mdot
.23842 .54683 Mdot
.56961 .10834 Mdot
.15084 .66622 Mdot
.2572 .55364 Mdot
.63275 .19493 Mdot
.25142 .8293 Mdot
.22328 .93803 Mdot
.59919 .10247 Mdot
.54827 .92293 Mdot
.28247 .5449 Mdot
.25083 .83191 Mdot
.26677 .96506 Mdot
.78172 .25955 Mdot
.49977 .08482 Mdot
.97969 .56557 Mdot
.303 .55368 Mdot
.27493 .53406 Mdot
.26765 .72606 Mdot
.93204 .45853 Mdot
.24925 .67712 Mdot
.27952 .57473 Mdot
.24928 .3625 Mdot
.26241 .78405 Mdot
.93807 .24593 Mdot
.25617 .53414 Mdot
.27485 .27764 Mdot
.22639 .85107 Mdot
.24243 .74076 Mdot
.27738 .54465 Mdot
.23117 .96682 Mdot
.25535 .98212 Mdot
.65054 .22962 Mdot
.27778 .52406 Mdot
.28386 .03836 Mdot
.29126 .58999 Mdot
.33203 .71669 Mdot
.8992 .18448 Mdot
.2671 .54007 Mdot
.33057 .35143 Mdot
.26442 .77337 Mdot
.22594 .88626 Mdot
.23752 .74713 Mdot
.14653 .91138 Mdot
.23729 .51195 Mdot
.77778 .47892 Mdot
.92119 .40587 Mdot
.44894 .00846 Mdot
.25944 .57149 Mdot
.67609 .77024 Mdot
.2591 .04591 Mdot
.25577 .53304 Mdot
.28992 .48509 Mdot
.16287 .57237 Mdot
.27913 .68518 Mdot
.28144 .68612 Mdot
.76282 .24168 Mdot
.31139 .04481 Mdot
.08215 .9098 Mdot
.71389 .19292 Mdot
.37974 .22932 Mdot
.16054 .44929 Mdot
.30946 .0547 Mdot
.65461 .0944 Mdot
.22294 .75368 Mdot
.77938 .33167 Mdot
.26475 .98634 Mdot
.56936 .74523 Mdot
.21973 .83635 Mdot
.25557 .57417 Mdot
.30546 .96585 Mdot
.5579 .38116 Mdot
.23597 .68745 Mdot
.5364 .09867 Mdot
.51813 .50585 Mdot
.06587 .03142 Mdot
.23424 .74891 Mdot
.28047 .58676 Mdot
.23847 .65852 Mdot
.26985 .90922 Mdot
.06295 .90107 Mdot
.21581 .25565 Mdot
.2449 .97006 Mdot
.27685 .81729 Mdot
.28451 .32582 Mdot
.94574 .81301 Mdot
.6096 .7693 Mdot
.13255 .79409 Mdot
.26679 .97288 Mdot
.70971 .19198 Mdot
.21911 .34514 Mdot
.25696 .36346 Mdot
.27634 .54419 Mdot
.26922 .94916 Mdot
.94013 .46981 Mdot
.69801 .19081 Mdot
.36104 .13219 Mdot
.92045 .43237 Mdot
.81996 .34976 Mdot
.17383 .64624 Mdot
.26557 .50345 Mdot
.26672 .53998 Mdot
.29799 .03948 Mdot
.01669 .17968 Mdot
.25623 .62946 Mdot
.76319 .21852 Mdot
.3102 .08996 Mdot
.25471 .87514 Mdot
.99673 .01214 Mdot
.26643 .54178 Mdot
.30659 .57918 Mdot
.22792 .86831 Mdot
.55263 .12151 Mdot
.22355 .42171 Mdot
.2732 .95403 Mdot
.1877 .14989 Mdot
.20686 .39709 Mdot
.27543 .97401 Mdot
.64539 .16363 Mdot
.2759 .99797 Mdot
.79157 .23985 Mdot
.12483 .57762 Mdot
.68486 .61297 Mdot
.60044 .71488 Mdot
.31251 .54987 Mdot
.67924 .26109 Mdot
.95924 .47879 Mdot
.52847 .12123 Mdot
.88372 .16392 Mdot
.31337 .05268 Mdot
.25094 .8765 Mdot
.26111 .94976 Mdot
.23816 .65451 Mdot
.28916 .543 Mdot
.55697 .11755 Mdot
.28804 .65516 Mdot
.29186 .58132 Mdot
.80723 .31768 Mdot
.58751 .13715 Mdot
.25463 .239 Mdot
.80979 .11412 Mdot
.94138 .14148 Mdot
.55039 .11603 Mdot
.66907 .15057 Mdot
.25817 .52949 Mdot
.31929 .61031 Mdot
.54468 .26651 Mdot
.25234 .84375 Mdot
.26535 .7723 Mdot
.23038 .53022 Mdot
.26561 .57463 Mdot
.22977 .31172 Mdot
.32565 .61518 Mdot
.29749 .09927 Mdot
.09148 .52425 Mdot
.37092 .10071 Mdot
.60839 .15092 Mdot
.05711 .53289 Mdot
.25847 .78255 Mdot
.93135 .58147 Mdot
.21961 .96737 Mdot
.35137 .10881 Mdot
.59013 .3381 Mdot
.21917 .92722 Mdot
.25686 .8105 Mdot
.27327 .74034 Mdot
.22687 .34419 Mdot
.3088 .60046 Mdot
.31211 .09445 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`;o00003oooool00ol0003o
ooooooooo`0<ooooo`;o00001?ooool2o`0000Wooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool2o`0000Oo
oooo00?o0000ooooooooool02?ooool2o`0000?ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`;o00002Oooool00ol0003ooooo
ooooo`0=ooooo`;o00003oooool00ol0003oooooooooo`08ooooo`;o00000oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02?ooool2o`0000?ooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool00_ooool001kooooo00?o0000ooooooooool04_ooool2o`0003Gooooo0_l0
0004ooooo`?o00001_ooool3o`000003ooooool0003o000002cooooo0_l00002ooooo`;o0000A?oo
ool2o`0005Gooooo0_l0000Jooooo`007_ooool00ol0003oooooooooo`0mooooo`;o00004?ooool3
o`0000Kooooo0ol000000ooooooo0000o`00000/ooooo`;o00000_ooool2o`0004Cooooo0_l0001E
ooooo`;o00004oooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo03Gooooo0_l00006oooo
o`;o00004_ooool2o`0000;ooooo0_l0003Yooooo`;o00001Oooool001kooooo00?o0000oooooooo
ool0=Oooool2o`0001[ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`000=Wo
oooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`1Aooooo`;o000000?oooooo`000?l00000
0_ooool2o`0000;ooooo0_l00006ooooo`;o0000dOooool2o`0000kooooo000Nooooo`03o`000?oo
oooooooo057ooooo1Ol0000>ooooo`;o0000hOooool001kooooo00?o0000ooooooooool0D_ooool3
o`000003ooooool0003o00000>oooooo000Nooooo`03o`000?oooooooooo017ooooo0_l00011oooo
o`Co00001?ooool2o`000>Wooooo000Nooooo`03o`000?oooooooooo017ooooo1?l0000oooooo`?o
00001Oooool2o`000;_ooooo0_l0000/ooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o0000
@oooool2o`0000;ooooo0_l0000dooooo`;o00008Oooool2o`0006;ooooo0_l0000/ooooo`007_oo
ool00ol0003oooooooooo`1Hooooo`?o000000Coooooo`000?l0003o00000_ooool2o`0002oooooo
0_l0000Qooooo`;o0000T?ooool001kooooo00?o0000ooooooooool0F?ooool3o`000004ooooool0
003o0000o`0000;ooooo0_l0000Oooooo`;o0000`oooool001kooooo00?o0000ooooooooool0D?oo
ool2o`0000[ooooo1?l000000ooooooo0000o`00000Oooooo`;o0000`oooool001kooooo00?o0000
ooooooooool0D?ooool2o`0000[ooooo1ol0001Oooooo`;o0000Poooool001kooooo0_l0000doooo
o`;o0000:Oooool6o`0001cooooo0_l00004ooooo`;o0000>_ooool2o`0008?ooooo000Nooooo`03
o`000?oooooooooo03?ooooo0_l0000Yooooo`Ko00007?ooool2o`0000Cooooo0_l0002oooooo`00
7_ooool00ol0003oooooooooo`0Looooo`;o00009Oooool2o`0001_ooooo0ol0000Looooo`;o0000
a_ooool001kooooo00?o0000ooooooooool07?ooool2o`0001oooooo0_l00004ooooo`;o00006ooo
ool5o`0001[ooooo0_l00036ooooo`007_ooool00ol0003oooooooooo`0mooooo`;o00008Oooool5
o`0001?ooooo0_l0000kooooo`;o0000T?ooool001kooooo00?o0000ooooooooool0GOooool2o`00
0004ooooool0003o0000o`0000;ooooo0_l0000Aooooo`;o0000:Oooool2o`0000Wooooo0_l00005
ooooo`;o0000T?ooool001kooooo00?o0000ooooooooool0GOooool2o`000004ooooool0003o0000
o`0000;ooooo0_l0000Qooooo`Co00005oooool2o`0000Wooooo0_l0002Gooooo`007_ooool00ol0
003oooooooooo`15ooooo`;o0000@Oooool4o`000;_ooooo000Nooooo`03o`000?oooooooooo04Go
oooo0_l0000Iooooo`?o00002?ooool2o`000=[ooooo000Nooooo`03o`000?oooooooooo02cooooo
0_l0000Yooooo`;o00001oooool3o`000003ooooool0003o000000Gooooo0_l0000Zooooo`;o0000
Roooool2o`00027ooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0000Cooooo`;o00002_oo
ool2o`0001gooooo0_l0000;ooooo`;o0000<Oooool2o`0008_ooooo0_l0000Qooooo`007_ooool0
0ol0003oooooooooo`0Gooooo`;o00007oooool2o`0002[ooooo0_l0000hooooo`;o0000Yoooool0
01kooooo00?o0000ooooooooool0HOooool2o`0003Sooooo0_l000000ooooooo0000o`000015oooo
o`;o0000H?ooool001kooooo00?o0000ooooooooool06Oooool2o`0004Cooooo1?l0000hooooo`;o
00001oooool2o`0003oooooo0_l0001Pooooo`007_ooool00ol0003oooooooooo`0Hooooo`?o0000
3oooool2o`0003?ooooo1?l00004ooooo`;o00008_ooool2o`0001Oooooo0_l0000[ooooo`;o0000
2_ooool2o`0006Sooooo000Nooooo`03o`000?oooooooooo01Sooooo0_l0000@ooooo`;o0000<Ooo
ool3o`000003ooooool0003o000000Cooooo0_l0000Rooooo`;o00007Oooool2o`0002Gooooo0_l0
000:ooooo`;o0000J?ooool001kooooo0_l0001Nooooo`?o00001?ooool2o`0000kooooo0_l0000a
ooooo`;o000000?oooooo`000?l000004oooool2o`0008Kooooo000Nooooo`03o`000?oooooooooo
02;ooooo0_l0000iooooo`;o00001Oooool2o`0000kooooo0_l0000aooooo`;o000000?oooooo`00
0?l000000_l00003ooooo`;o00003?ooool2o`0008Kooooo000Nooooo`03o`000?oooooooooo02;o
oooo0_l0000iooooo`;o00003oooool2o`0003[ooooo1?l00003ooooo`;o00000_ooool2o`0003?o
oooo0_l0001Kooooo`007_ooool00ol0003oooooooooo`0/ooooo`;o00007?ooool2o`0001Cooooo
0_l0000<ooooo`;o00005Oooool2o`0000Sooooo0_l0000Tooooo`;o0000<oooool2o`0005_ooooo
000Nooooo`03o`000?oooooooooo00Kooooo0_l0000Tooooo`;o00007?ooool2o`0001Cooooo0_l0
000Sooooo`;o00002?ooool2o`0000_ooooo0_l0000Aooooo`;o00001?ooool2o`0004cooooo0_l0
0012ooooo`007_ooool00ol0003oooooooooo`06ooooo`;o0000MOooool2o`0001gooooo0_l0000A
ooooo`Co00000_ooool2o`0004cooooo0_l00012ooooo`007_ooool00ol0003oooooooooo`1moooo
o`;o0000:Oooool2o`0000Cooooo1Ol0001<ooooo`;o0000A_ooool001kooooo00?o0000oooooooo
ool0Loooool2o`0003?ooooo0_l00004ooooo`Co00001?ooool2o`0004Oooooo0_l00016ooooo`00
7_ooool00ol0003oooooooooo`1cooooo`;o00005Oooool2o`0002Cooooo0_l000000ooooooo0000
o`000005o`0002Kooooo0_l00010ooooo`;o00008oooool001kooooo00?o0000ooooooooool01ooo
ool2o`0006Wooooo0_l0000Fooooo`;o00009oooool3o`0000;ooooo0_l0000Vooooo`;o0000@?oo
ool2o`0002?ooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0000Vooooo`;o0000@?ooool3
o`00043ooooo0_l000000ooooooo0000o`00002>ooooo`007_ooool00ol0003oooooooooo`0_oooo
o`;o0000;_ooool2o`00013ooooo0_l00006ooooo`;o0000=_ooool2o`0000Cooooo0_l000001?oo
oooo0000o`000?l0002:ooooo`007_ooool00ol0003oooooooooo`1Oooooo`?o00005oooool2o`00
03Kooooo0_l00007ooooo`?o0000R_ooool001kooooo00?o0000ooooooooool0H?ooool2o`0001ko
oooo0_l0000iooooo`;o000000?oooooo`000?l00000K_ooool2o`0001Oooooo000Nooooo`03o`00
0?oooooooooo083ooooo0_l0000looooo`;o0000K_ooool2o`0001Oooooo000Nooooo`03o`000?oo
oooooooo0;oooooo0_l0000:ooooo`;o0000Joooool2o`0000gooooo000Nooooo`;o0000>_ooool2
o`0008Cooooo0_l000001?oooooo0000o`000?l00006ooooo`;o00002?ooool2o`00067ooooo0_l0
000=ooooo`007_ooool00ol0003oooooooooo`0iooooo`;o0000Qoooool3o`00013ooooo0_l0001X
ooooo`;o00001_ooool001kooooo00?o0000ooooooooool02Oooool2o`0007Gooooo0_l0002moooo
o`;o00001_ooool001kooooo00?o0000ooooooooool02Oooool2o`0002Gooooo0_l0001>ooooo`;o
00004Oooool2o`0000Gooooo0_l0002[ooooo`007_ooool00ol0003oooooooooo`0`ooooo`;o0000
:oooool2o`0003Cooooo0_l00005ooooo`;o0000;oooool5o`0004_ooooo0_l00002ooooo`;o0000
9_ooool001kooooo00?o0000ooooooooool0GOooool2o`0004Wooooo0_l0000Qooooo`Go0000Booo
ool2o`0000;ooooo0_l0000Vooooo`007_ooool00ol0003oooooooooo`2Xooooo`;o0000QOooool2
o`0001Kooooo000Nooooo`03o`000?oooooooooo01oooooo0_l0000Looooo`;o00008?ooool2o`00
02Cooooo0_l0001?ooooo`;o0000Eoooool2o`0001Kooooo000Nooooo`03o`000?oooooooooo01oo
oooo0_l0000Looooo`;o00007Oooool2o`000003ooooool0003o000002Cooooo0_l0001?ooooo`;o
000000?oooooo`000?l00000K?ooool001kooooo00Co0000oooooooooooooooo0_l0001Iooooo`;o
0000Ioooool2o`0001;ooooo0_l0001/ooooo`007_ooool01?l0003oooooooooooooool2o`000<;o
oooo0_l0000Fooooo`;o0000B_ooool2o`0001cooooo000Nooooo`03o`000?oooooooooo03?ooooo
0_l0002Xooooo`?o0000@?ooool2o`0000Oooooo0_l0000Looooo`007_ooool00ol0003ooooooooo
o`0<ooooo`;o00009Oooool2o`0002;ooooo0_l00025ooooo`;o0000@?ooool2o`0002Gooooo000N
ooooo`03o`000?oooooooooo00cooooo0_l00019ooooo`;o0000Q_ooool6o`0006;ooooo0003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooo
oooo07Gooooo0_l0001Cooooo`;o00004oooool7o`0001kooooo0_l00011ooooo`000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_oo
ool00ol0003oooooooooo`1eooooo`;o0000Doooool2o`0001Oooooo1Ol0000?ooooo`;o00002ooo
ool2o`00047ooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^
kP07ooooo`?o00006Oooool2o`000:Oooooo0_l0000Rooooo`;o00002Oooool2o`0000Cooooo0_l0
001>ooooo`000oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01_oo
ool00ol0003oooooooooo`0Cooooo`;o00001?ooool2o`0002Cooooo0_l00006ooooo`;o0000NOoo
ool2o`0000Wooooo0_l0000Rooooo`;o0000:?ooool3o`0002Wooooo0003ooooo`05o`000?oooooo
ooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo01?ooooo0_l0
000Gooooo`;o00002Oooool2o`0000Kooooo0_l00006ooooo`?o00005oooool2o`0006[ooooo0_l0
001<ooooo`Co0000:?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0;?ooool2o`0000Wooooo0_l00006ooooo`;o00001ooo
ool2o`0001Oooooo0_l00028ooooo`;o0000<?ooool2o`0002Sooooo0003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
6oooool2o`000<Kooooo0_l00006ooooo`;o0000@?ooool2o`0001Sooooo0003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000oooooooo
ool06oooool2o`0003Kooooo0_l00029ooooo`;o00000oooool2o`0000Kooooo0_l00003ooooo`;o
0000>oooool2o`0001Sooooo000Nooooo`03o`000?oooooooooo05?ooooo0_l00029ooooo`;o0000
4?ooool2o`0000;ooooo0_l0000Hooooo`;o0000=oooool001kooooo00?o0000ooooooooool0m?oo
ool2o`0001Sooooo0_l0000Dooooo`;o00008Oooool001kooooo00?o0000ooooooooool0A?ooool2
o`00033ooooo0_l0001/ooooo`;o00001?ooool2o`0000Kooooo0_l0000Kooooo`;o00004oooool2
o`00027ooooo000Nooooo`03o`000?oooooooooo04Cooooo0_l0000`ooooo`;o0000K?ooool2o`00
00Cooooo1?l00002ooooo`Co00006oooool2o`0003Kooooo000Nooooo`03o`000?oooooooooo00[o
oooo0_l0001[ooooo`;o0000E_ooool2o`0001_ooooo0_l00002ooooo`;o00001?ooool2o`0004oo
oooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0001[ooooo`;o0000E_ooool2o`0002Gooooo
0_l0001?ooooo`007_ooool00ol0003oooooooooo`1@ooooo`;o0000V_ooool2o`00023ooooo0_l0
000gooooo`007_ooool00ol0003oooooooooo`1?ooooo`?o00000oooool2o`0009Gooooo0_l0000?
ooooo`?o00003_ooool2o`0003Oooooo000Nooooo`03o`000?oooooooooo04oooooo0_l00004oooo
o`;o0000VOooool2o`0000;ooooo0_l00005ooooo`Go00003_ooool4o`0003Gooooo000Nooooo`03
o`000?oooooooooo0?3ooooo0_l00002ooooo`;o00001Oooool2o`0001?ooooo0_l0000Kooooo`;o
00006?ooool001kooooo0ol0001Oooooo`;o00007oooool2o`0007[ooooo0_l00003ooooo`;o0000
:_ooool2o`0001Sooooo000Nooooo`?o0000Goooool2o`0001oooooo0_l0000cooooo`;o0000?_oo
ool2o`0000Gooooo0_l00003ooooo`;o0000A?ooool001kooooo00?o0000ooooooooool0@_ooool2
o`00077ooooo0_l0000nooooo`Co0000C_ooool001kooooo00?o0000ooooooooool0@_ooool2o`00
01[ooooo0_l0000Eooooo`;o0000OOooool2o`000004ooooool0003o0000ooooo`Co00004Oooool2
o`0000;ooooo0_l0000booooo`007_ooool00ol0003oooooooooo`1Nooooo`;o00002Oooool2o`00
00[ooooo0_l00002ooooo`;o00000_ooool2o`0002Kooooo0_l0000booooo`;o00006Oooool2o`00
00Cooooo1?l0000Aooooo`;o00000_ooool2o`0003;ooooo000Nooooo`03o`000?oooooooooo06Wo
oooo0_l0000>ooooo`;o00000_ooool2o`0002Kooooo0_l0000booooo`;o00006Oooool2o`0004Oo
oooo0_l00008ooooo`007_ooool00ol0003oooooooooo`1]ooooo`;o0000?_ooool2o`0004Kooooo
0_l0000Fooooo`;o0000;_ooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo06gooooo0_l0
000nooooo`;o00008_ooool2o`0001gooooo0_l00003ooooo`;o00005_ooool2o`0003Sooooo000N
ooooo`03o`000?oooooooooo0:Cooooo0_l0000[ooooo`;o00007Oooool2o`0000?ooooo0_l0001@
ooooo`007_ooool00ol0003oooooooooo`0Zooooo`;o00009?ooool2o`0000?ooooo0_l0001=oooo
o`;o0000XOooool001kooooo00?o0000ooooooooool01oooool2o`00027ooooo0ol0000Sooooo`;o
00000oooool2o`000:oooooo0_l0000oooooo`007_ooool00ol0003oooooooooo`07ooooo`;o0000
8_ooool2o`0001_ooooo0_l0002looooo`;o0000?oooool001kooooo00?o0000ooooooooool0B?oo
ool2o`0005gooooo0_l0002Nooooo`007_ooool00ol0003oooooooooo`14ooooo`;o0000HOooool2
o`0009kooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l0000Dooooo`;o00001Oooool2o`00
0?oooooo0_ooool001kooooo00?o0000ooooooooool09oooool2o`0001Cooooo0_l00003ooooo`;o
0000[?ooool2o`0001?ooooo0_l00010ooooo`007_ooool00ol0003oooooooooo`0/ooooo`;o0000
5?ooool2o`0007gooooo0_l0000]ooooo`;o00004oooool2o`00043ooooo000Nooooo`;o0000;Ooo
ool2o`0009?ooooo0_l0000booooo`;o0000D?ooool001kooooo00?o0000ooooooooool0mOooool2
o`00053ooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0Aoooool2o`000?kooooo000Nooooo`03o`000?oooooooooo04Oooooo0_l0002Nooooo`;o0000
4_ooool2o`0004[ooooo000Nooooo`03o`000?oooooooooo03Sooooo0_l0002]ooooo`;o00004_oo
ool2o`0000Gooooo0_l00013ooooo`007_ooool00ol0003oooooooooo`0hooooo`;o0000]_ooool2
o`00013ooooo0_l00013ooooo`007_ooool00ol0003oooooooooo`1@ooooo`;o0000W_ooool2o`00
03cooooo0_l0000Gooooo`007_ooool00ol0003oooooooooo`1@ooooo`;o00001_ooool2o`000=Co
oooo0_l0000Gooooo`007_ooool00ol0003oooooooooo`1Hooooo`;o0000kOooool001kooooo00?o
0000ooooooooool0nOooool2o`0004cooooo000Nooooo`03o`000?oooooooooo04Gooooo0_l0000E
ooooo`;o00005_ooool2o`0008?ooooo0_l0000;ooooo`;o0000?oooool001kooooo00?o0000oooo
ooooool0AOooool2o`0001Gooooo0_l0000<ooooo`;o00002?ooool2o`0004Kooooo0_l00018oooo
o`;o0000?oooool001kooooo00?o0000ooooooooool0J_ooool2o`00053ooooo0_l00029ooooo`00
7_ooool00ol0003oooooooooo`13ooooo`;o000000?oooooo`000?l000008_ooool2o`000<Oooooo
0_l0000Booooo`007_ooool00ol0003oooooooooo`13ooooo`;o000000?oooooo`000?l000000_l0
000^ooooo`;o0000S?ooool2o`0000;ooooo0_l0000Wooooo`;o00004_ooool001kooooo0_l00019
ooooo`;o00007Oooool2o`0000oooooo0_l0002<ooooo`?o000000?oooooo`000?l00000>oooool0
01kooooo00?o0000ooooooooool0Ioooool2o`0009gooooo0ol00007ooooo`;o0000=Oooool001ko
oooo00?o0000ooooooooool0Aoooool2o`000<Kooooo0ol0000eooooo`007_ooool00ol0003ooooo
ooooo`17ooooo`;o0000a_ooool2o`0003Kooooo000Nooooo`03o`000?oooooooooo04gooooo1?l0
003fooooo`007_ooool00ol0003oooooooooo`18ooooo`;o00000oooool4o`000?Kooooo000Noooo
o`03o`000?oooooooooo04Sooooo0_l0003mooooo`007_ooool00ol0003oooooooooo`2Cooooo`;o
00005_ooool2o`0009[ooooo000Nooooo`03o`000?oooooooooo04Gooooo0_l0001<ooooo`;o0000
5_ooool2o`0009[ooooo000Nooooo`03o`000?oooooooooo04Gooooo0_l0003oooooo`7ooooo000N
ooooo`03o`000?oooooooooo063ooooo0_l0001?ooooo`;o0000Roooool2o`0000Oooooo000Noooo
o`03o`000?oooooooooo063ooooo0_l0001?ooooo`;o0000BOooool2o`00043ooooo0_l00007oooo
o`007_ooool00ol0003oooooooooo`3looooo`;o0000BOooool001kooooo00?o0000ooooooooool0
Q_ooool2o`000;oooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo
0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo08Kooooo0_l0002oooooo`000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0?oooool2o`00087ooooo0_l0000Uooooo`;o0000G?ooool000?ooooo00Go
410@oooooooooooooooooa0@400;ooooo`Go00001_ooool3o`0003_ooooo0_l00002ooooo`;o0000
3Oooool2o`0007;ooooo0_l0000Uooooo`;o0000;oooool2o`0002_ooooo0003ooooo`05o`000?oo
ooooooooooooool000002oooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo03_o
oooo0_l0000Aooooo`;o0000b_ooool2o`0002_ooooo0003ooooo`05o`000?ooooooooooooooool0
00002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo0?cooooo0_l0000Yoooo
o`;o00007_ooool000?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co0000
00Oooooo00?o0000ooooooooool0C_ooool2o`0002oooooo0_l0001kooooo`;o0000:Oooool2o`00
01kooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007oooo
o`03o`000?oooooooooo04kooooo0_l0000_ooooo`;o0000a_ooool000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0Boooool2o`00
00;ooooo0_l0003fooooo`007_ooool00ol0003oooooooooo`1;ooooo`;o00000_ooool2o`0004_o
oooo0_l0000@ooooo`;o0000Uoooool001kooooo00?o0000ooooooooool0AOooool2o`0003;ooooo
0_l0000Qooooo`;o00004?ooool2o`0000cooooo0_l00029ooooo`007_ooool00ol0003ooooooooo
o`0Zooooo`;o00006Oooool2o`0003;ooooo0_l00011ooooo`;o0000ROooool001kooooo00?o0000
ooooooooool0:_ooool2o`000?oooooo3?ooool2o`0000kooooo000Nooooo`03o`000?oooooooooo
06kooooo0_l0002aooooo`;o00005?ooool2o`0000kooooo000Nooooo`03o`000?oooooooooo06ko
oooo0_l0002aooooo`;o00001?ooool2o`0001kooooo000Nooooo`03o`000?oooooooooo04kooooo
0_l0001oooooo`;o0000E_ooool2o`0000;ooooo0_l0000Jooooo`007_ooool00ol0003ooooooooo
o`1>ooooo`;o0000LOooool2o`0000cooooo0_l0001Jooooo`;o00006_ooool001kooooo00?o0000
ooooooooool0`Oooool2o`0008Cooooo000Nooooo`03o`000?oooooooooo04gooooo1_l00003oooo
o`;o0000c_ooool2o`0001oooooo000Nooooo`03o`000?oooooooooo033ooooo0_l0000Kooooo`Ko
00000oooool2o`0000cooooo0_l00030ooooo`;o00007oooool001kooooo0_l0000aooooo`;o0000
6oooool2o`0001Gooooo0_l00030ooooo`;o00007oooool001kooooo00?o0000ooooooooool0COoo
ool4o`000?Kooooo000Nooooo`03o`000?oooooooooo04oooooo0_l0001[ooooo`;o0000KOooool2
o`0001[ooooo000Nooooo`03o`000?oooooooooo04oooooo0_l00003ooooo`;o0000I_ooool2o`00
06?ooooo0_l00008ooooo`;o00006_ooool001kooooo00?o0000ooooooooool0D?ooool2o`0000;o
oooo0_l0003;ooooo`;o00009?ooool001kooooo00?o0000ooooooooool0COooool2o`000003oooo
ool0003o000000Gooooo0_l0003Dooooo`;o00006?ooool001kooooo00?o0000ooooooooool0COoo
ool2o`000003ooooool0003o000000Gooooo0_l0000?ooooo`;o0000`oooool3o`0001Oooooo000N
ooooo`03o`000?oooooooooo04gooooo0_l000000ooooooo0000o`00000Fooooo`;o0000a?ooool2
o`0001Oooooo000Nooooo`03o`000?oooooooooo04cooooo0ol0003Iooooo`;o00007Oooool001ko
oooo00?o0000ooooooooool06?ooool2o`0003;ooooo0_l0002[ooooo`;o0000;Oooool2o`0000[o
oooo0_l0000Aooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o0000>oooool2o`000:;ooooo
0_l0000iooooo`?o00004?ooool001kooooo00?o0000ooooooooool0DOooool2o`0000;ooooo0_l0
0003ooooo`;o0000fOooool2o`00013ooooo000Nooooo`03o`000?oooooooooo057ooooo0_l00006
ooooo`?o0000Y_ooool2o`0003Cooooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`1<oooo
o`?o00002_ooool2o`000:Oooooo0_l0000aooooo`;o000000?oooooo`000?l000003Oooool001ko
oooo00?o0000ooooooooool0C?ooool3o`0000Sooooo0_l00033ooooo`;o00005oooool3o`0000oo
oooo000Nooooo`03o`000?oooooooooo05?ooooo0_l00002ooooo`;o0000`oooool2o`0001Sooooo
0_l0000?ooooo`007_ooool2o`0004cooooo0_l00006ooooo`Co0000I?ooool2o`0004Cooooo0_l0
000gooooo`;o00002oooool001kooooo00?o0000ooooooooool0B_ooool3o`0000Gooooo0_l00000
1?oooooo0000o`000?l0001<ooooo`;o00005Oooool2o`0004Cooooo0_l0000eooooo`Co00002ooo
ool001kooooo00?o0000ooooooooool02_ooool2o`0003kooooo0_l00006ooooo`;o00000_ooool2
o`0000;ooooo0_l00018ooooo`;o0000T_ooool2o`0000gooooo000Nooooo`03o`000?oooooooooo
00[ooooo0_l0000mooooo`Co00003Oooool2o`000>_ooooo000Nooooo`03o`000?oooooooooo043o
oooo0_l00007ooooo`Go0000f_ooool2o`0001gooooo000Nooooo`03o`000?oooooooooo01;ooooo
0_l0000/ooooo`;o00002_ooool2o`00093ooooo0_l00018ooooo`;o00007Oooool001kooooo00?o
0000ooooooooool02_ooool2o`0000Kooooo0_l00004ooooo`;o0000;oooool4o`00097ooooo0_l0
001Wooooo`007_ooool00ol0003oooooooooo`07ooooo`;o000000?oooooo`000?l000003?ooool4
o`0002cooooo1Ol00002ooooo`?o00000_ooool4o`000=cooooo0_l0000Aooooo`007_ooool2o`00
00Gooooo0_l000000ooooooo0000o`00000Aooooo`;o0000;?ooool2o`0000Gooooo0ol00002oooo
o`Co00002?ooool2o`000=;ooooo0_l0000Aooooo`007_ooool2o`0000Gooooo0_l00011ooooo`;o
00000oooool2o`000004ooooool0003o0000o`0000?ooooo0_l000000ooooooo0000o`000005oooo
o`?o0000iOooool001kooooo0_l0000?ooooo`;o0000=oooool2o`0000?ooooo1_l00002ooooo`;o
00000_ooool2o`0000Cooooo1?l0003Kooooo`;o00002?ooool001kooooo0_l00007ooooo`?o0000
1Oooool2o`0003cooooo1ol000000ooooooo0000o`000002o`0000Kooooo0_l0000Pooooo`;o0000
;_ooool2o`0008_ooooo0_l00002ooooo`;o00001?ooool001kooooo00?o0000ooooooooool01?oo
ool5o`00047ooooo3_l0000Xooooo`;o0000;_ooool2o`0008oooooo0_l00004ooooo`007_ooool0
0ol0003oooooooooo`04ooooo`;o0000A?ooool4o`0000;ooooo1Ol00004ooooo`Go0000<oooool2
o`000;Cooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l00014ooooo`;o00000_ooool2o`00
00?ooooo0ol000000ooooooo0000o`000007o`0003;ooooo0_l00008ooooo`;o0000Xoooool2o`00
00Gooooo000Nooooo`?o00000oooool2o`0004Cooooo1ol00002ooooo`;o00000_ooool9o`0003co
oooo0_l0002Sooooo`;o00001Oooool001kooooo0ol00007ooooo`;o0000@?ooool;o`0000?ooooo
0ol00003ooooo`;o00000_ooool3o`000>?ooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0
000<ooooo`;o0000=Oooool6o`0000Gooooo0_l000001?oooooo0000o`000?ooool3o`000004oooo
ool0003o0000o`000=Cooooo0_l0000=ooooo`007_ooool01?l0003oooooo`000?l0000Dooooo`;o
0000=Oooool7o`000003ooooool0003o000000;o00000_ooool2o`0000;ooooo0_l0003Hooooo`;o
00003Oooool001kooooo00Co0000ooooool0003o0000Boooool7o`000003ooooool0003o000000;o
00001_ooool2o`000;Sooooo0_l0000]ooooo`007_ooool00ol0003oooooooooo`1<ooooo`;o0000
0_ooool5o`0000?ooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o00000;Gooooo
0_l0000]ooooo`007_ooool00ol0003oooooooooo`1>ooooo`;o00000_ooool3o`0000?ooooo0_l0
00001?oooooo0000o`000?l00003ooooo`;o0000eoooool2o`0000_ooooo000Nooooo`03o`000?oo
oooooooo04kooooo0ol000000ooooooo0000o`000002o`0000?ooooo0_l00032ooooo`;o00003ooo
ool2o`0000[ooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`0aooooo`;o00007?ooool3
o`000003ooooool0003o000000;o00000_ooool2o`0000?ooooo0_l0002mooooo`;o00003oooool2
o`0001Oooooo000Nooooo`03o`000?oooooooooo00Gooooo0_l0000Zooooo`;o00006oooool;o`00
00Cooooo0ol0002Vooooo`;o0000?oooool001kooooo00?o0000ooooooooool01Oooool2o`0001go
oooo0_l0000Xooooo`?o000000?oooooo`000?l000001Ol00004ooooo`;o000000?oooooo`000?l0
0000Y?ooool2o`0003oooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l0000`ooooo`;o0000
0_ooool3o`0000?ooooo0_l00039ooooo`;o00006_ooool001kooooo00?o0000ooooooooool03ooo
ool2o`0004Gooooo0_l000000ooooooo0000o`000002o`000<kooooo0_l0000Jooooo`007_ooool0
0ol0003oooooooooo`0?ooooo`;o0000>_ooool2o`0000[ooooo1Ol0003[ooooo`007_ooool00ol0
003oooooooooo`0Sooooo`;o00009_ooool2o`0000;ooooo0_l00006ooooo`Ko000000Coooooo`00
0?l0003o0000f?ooool2o`0000cooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo02?ooooo0_l0
000Zooooo`Co00001Oooool5o`000004ooooool0003o0000o`000=Sooooo0_l0000<ooooo`000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B401_ooool00ol0003oooooooooo`0Aooooo`;o0000?_ooool4o`0000?ooooo1?l0002mooooo`;o
0000;?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool000001_ooool3o`00017ooooo0_l0000iooooo`;o000000?oooooo`000?l000000_ooool2o`00
00Gooooo0_l00004ooooo`;o0000]oooool2o`0002cooooo0003ooooo`05o`000?oooooooooooooo
ool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0C?ooool2
o`000003ooooool0003o000000oooooo0_l0003Uooooo`000oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo05Sooooo0ol0
003/ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool02?oo
ool00ol0003oooooooooo`1Gooooo`Co00002Oooool2o`000>7ooooo0003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo04gooooo0_l0
0008ooooo`;o00001Oooool2o`0000Cooooo0_l0001eooooo`;o0000J_ooool000?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0
8_ooool2o`0002Wooooo1?l0000=ooooo`;o00001?ooool4o`0007?ooooo0_l0001Zooooo`007_oo
ool00ol0003oooooooooo`0Rooooo`;o0000:_ooool3o`0000Gooooo0_l00009ooooo`;o000000?o
ooooo`000?l000000_l0003Oooooo`007_ooool00ol0003oooooooooo`1Fooooo`;o00000oooool2
o`0000Cooooo0_l00003ooooo`;o0000b?ooool2o`0001Gooooo000Nooooo`03o`000?oooooooooo
04kooooo0_l00009ooooo`Co00002Oooool4o`000<Kooooo0_l0000Eooooo`007_ooool00ol0003o
ooooooooo`1>ooooo`;o00002Oooool2o`0000gooooo0_l0003Mooooo`007_ooool00ol0003ooooo
ooooo`1?ooooo`;o00002?ooool2o`000>cooooo000Nooooo`03o`000?oooooooooo02Gooooo0_l0
000Xooooo`;o00000_ooool2o`0001[ooooo0_l0003Fooooo`007_ooool00ol0003oooooooooo`0U
ooooo`;o0000:oooool3o`0001[ooooo0_l0003Fooooo`007_ooool00ol0003oooooooooo`1Boooo
o`;o0000loooool001kooooo00?o0000ooooooooool01oooool2o`0006?ooooo0_l0000Gooooo`;o
00005?ooool2o`00033ooooo0_l0000hooooo`;o0000?_ooool001kooooo00?o0000ooooooooool0
1oooool2o`0002_ooooo0_l0000fooooo`;o00000oooool2o`0001;ooooo0_l0000Dooooo`;o0000
<?ooool2o`0001kooooo0_l0000Hooooo`;o0000?_ooool001kooooo00?o0000ooooooooool0=?oo
ool2o`00023ooooo0_l0000Iooooo`;o00003?ooool2o`0005oooooo0_l0000;ooooo`;o0000F?oo
ool001kooooo0_l00018ooooo`;o00003Oooool2o`0002Oooooo0_l0001Oooooo`;o0000IOooool0
01kooooo00?o0000ooooooooool0Aoooool6o`0000gooooo0_l0001Cooooo`;o0000U_ooool001ko
oooo00?o0000ooooooooool0A_ooool2o`000003ooooool0003o000000;o00001?ooool2o`0000Go
oooo1?l0000Yooooo`;o00002oooool2o`0001_ooooo0_l00002ooooo`;o0000C?ooool2o`0004Co
oooo000Nooooo`03o`000?oooooooooo04Kooooo0_l000000ooooooo0000o`000002ooooo`;o0000
0_ooool2o`0000Gooooo0_l0000[ooooo`;o00002oooool2o`0001oooooo0_l0001<ooooo`;o0000
A?ooool001kooooo00?o0000ooooooooool0AOooool2o`0000Kooooo0_l00004ooooo`;o0000@Ooo
ool2o`000:Cooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`0]ooooo`;o00005_ooool2
o`0000cooooo0_l00011ooooo`;o0000U?ooool2o`0000kooooo0_l00009ooooo`007_ooool00ol0
003oooooooooo`0]ooooo`;o0000D_ooool2o`0006Sooooo0_l0000oooooo`;o00006Oooool001ko
oooo00?o0000ooooooooool04Oooool2o`0003?ooooo0_l0000iooooo`;o00004Oooool2o`0000Ko
oooo0_l0001=ooooo`;o0000F_ooool001kooooo00?o0000ooooooooool04Oooool2o`0003?ooooo
0_l00005ooooo`;o0000AOooool2o`0000Kooooo0_l0002Yooooo`007_ooool00ol0003ooooooooo
o`1;ooooo`Co00002?ooool2o`000>kooooo000Nooooo`03o`000?oooooooooo04_ooooo0_l00006
ooooo`?o000000?oooooo`000?l000009oooool2o`000<Gooooo000Nooooo`03o`000?oooooooooo
05?ooooo0ol000000ooooooo0000o`00000Wooooo`;o00000oooool2o`0004cooooo0_l0001boooo
o`007_ooool00ol0003oooooooooo`07ooooo`;o0000@?ooool2o`0000Kooooo0_l00004ooooo`;o
0000;?ooool2o`0004cooooo0_l0001booooo`007_ooool00ol0003oooooooooo`07ooooo`;o0000
@?ooool2o`000004ooooool0003o0000ooooo`Co00001?ooool2o`000>kooooo000Nooooo`03o`00
0?oooooooooo04cooooo0_l000000ooooooo0000o`000006ooooo`;o0000;Oooool2o`000;oooooo
000Nooooo`03o`000?oooooooooo04Wooooo0_l0000kooooo`;o0000_oooool001kooooo0_l0000Z
ooooo`;o00007_ooool2o`00023ooooo0_l0003Jooooo`007_ooool00ol0003oooooooooo`0Yoooo
o`;o00007?ooool4o`00023ooooo0_l0003Jooooo`007_ooool00ol0003oooooooooo`17ooooo`Co
0000>?ooool2o`000<;ooooo000Nooooo`03o`000?oooooooooo08?ooooo0_l00032ooooo`007_oo
ool00ol0003oooooooooo`2oooooo`;o0000Q_ooool001kooooo00?o0000ooooooooool0Eoooool2
o`0000oooooo0_l00008ooooo`;o0000Boooool2o`0008Kooooo000Nooooo`03o`000?oooooooooo
05Oooooo0_l0000?ooooo`;o00002?ooool2o`000=?ooooo000Nooooo`03o`000?oooooooooo07ko
oooo0_l00037ooooo`007_ooool00ol0003oooooooooo`1Cooooo`;o00004?ooool2o`0001Oooooo
0_l0001kooooo`;o00002?ooool2o`00043ooooo000Nooooo`03o`000?oooooooooo05?ooooo0_l0
000@ooooo`;o00001Oooool2o`0000Gooooo0_l00026ooooo`;o00002?ooool2o`00043ooooo000N
ooooo`03o`000?oooooooooo04kooooo0_l00003ooooo`;o00005oooool2o`0000Gooooo0_l0003B
ooooo`007_ooool00ol0003oooooooooo`12ooooo`;o00002_ooool2o`0003Sooooo0_l0002moooo
o`007_ooool00ol0003oooooooooo`12ooooo`;o0000A?ooool2o`000;gooooo000Nooooo`03o`00
0?oooooooooo00;o0000BOooool2o`0000Sooooo0_l0000?ooooo`;o0000goooool001kooooo00?o
0000ooooooooool00_l0000^ooooo`;o00004_ooool2o`0000Gooooo0_l00008ooooo`;o00003ooo
ool2o`0004gooooo0_l0002@ooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o00005_ooool2
o`0001;ooooo0_l00003ooooo`;o0000J_ooool2o`00093ooooo000Nooooo`;o00006Oooool2o`00
02[ooooo0_l00002ooooo`?o0000o?ooool001kooooo00?o0000ooooooooool0@_ooool4o`0000;o
oooo0_l00007ooooo`;o0000m?ooool001kooooo00?o0000ooooooooool0@_ooool4o`0000_ooooo
0_l0001booooo`;o0000P?ooool001kooooo00?o0000ooooooooool0@oooool2o`0000gooooo0_l0
001aooooo`;o0000P?ooool001kooooo00?o0000ooooooooool0@_ooool3o`0000gooooo0_l0000E
ooooo`;o0000g?ooool001kooooo00?o0000ooooooooool0>?ooool2o`0000Sooooo0_l0000Uoooo
o`;o0000g?ooool001kooooo00?o0000ooooooooool0>?ooool2o`0003_ooooo0_l0001;ooooo`;o
00005?ooool2o`0006gooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l0000=ooooo`;o0000
5?ooool4o`0000Gooooo0_l0000Qooooo`;o0000Boooool2o`0001Cooooo0_l0001]ooooo`007_oo
ool00ol0003oooooooooo`0Tooooo`;o00003Oooool2o`0000gooooo0_l00005ooooo`Co00001Ooo
ool2o`000??ooooo000Nooooo`03o`000?oooooooooo02Gooooo0_l0000Kooooo`;o000000?ooooo
o`000?l00000ooooool1ooooo`007_ooool00ol0003oooooooooo`0Uooooo`;o00007_ooool2o`00
00Wooooo0_l0000`ooooo`;o0000`oooool001kooooo00?o0000ooooooooool0D?ooool3o`0002oo
oooo0_l00033ooooo`007_ooool00ol0003oooooooooo`12ooooo`;o00001_ooool2o`0000?ooooo
1?l00008ooooo`;o0000j_ooool001kooooo00?o0000ooooooooool0@_ooool2o`0000Kooooo0_l0
0003ooooo`;o00002_ooool2o`000>[ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo02Oooooo
0_l0000Mooooo`;o00004oooool2o`000>[ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo02Oo
oooo0_l0000Mooooo`;o0000ooooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05
o`000?ooooooooooooooool000001_ooool3o`00047ooooo0_l0000;ooooo`;o0000:_ooool2o`00
0<_ooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b00Kooooo00?o0000ooooooooool01oooool2o`0003Sooooo0_l0000;ooooo`;o0000:_ooool2
o`000<_ooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0
003oc<c<00Kooooo00?o0000ooooooooool01oooool2o`000?oooooo?oooool000?ooooo00Go410@
oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooo
ooooo`16ooooo`;o000000?oooooo`000?l000000_ooool2o`000?Sooooo0003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000oooooooo
ool0@Oooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`Co0000g_ooool2o`0001Ko
oooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY
00Kooooo00?o0000ooooooooool0@Oooool2o`0000[ooooo1?l00029ooooo`;o0000Doooool3o`00
01Gooooo000Nooooo`03o`000?oooooooooo04gooooo1?l00005ooooo`;o0000M_ooool2o`0000[o
oooo0_l0001Dooooo`;o00005Oooool001kooooo00?o0000ooooooooool0Coooool2o`0000Gooooo
0_l0001fooooo`;o0000Moooool001kooooo00?o0000ooooooooool0B?ooool2o`0000?ooooo1?l0
000Nooooo`;o0000e_ooool001kooooo00?o0000ooooooooool0B?ooool2o`0000?ooooo1?l0000N
ooooo`;o0000e_ooool001kooooo00?o0000ooooooooool0COooool3o`0008Oooooo0_l0001^oooo
o`007_ooool00ol0003oooooooooo`11ooooo`;o00002_ooool4o`0008Kooooo0_l0001^ooooo`00
7_ooool00ol0003oooooooooo`11ooooo`Co00001oooool5o`0001[ooooo0_l0003Jooooo`007_oo
ool00ol0003oooooooooo`11ooooo`Co00001Oooool4o`000003ooooool0003o000001[ooooo1?l0
003Hooooo`007_ooool00ol0003oooooooooo`12ooooo`;o00001_ooool2o`0000;ooooo0ol0000L
ooooo`;o0000<oooool2o`000:?ooooo000Nooooo`03o`000?oooooooooo04;ooooo0_l0000:oooo
o`;o0000D_ooool2o`000:?ooooo000Nooooo`03o`000?oooooooooo03Gooooo0_l00003ooooo`;o
00001Oooool2o`000003ooooool0003o000000Kooooo1?l0003gooooo`007_ooool2o`0003Kooooo
0_l00003ooooo`;o00001Oooool2o`000004ooooool0003o0000o`0000Cooooo0ol0003iooooo`00
7_ooool00ol0003oooooooooo`15ooooo`;o000000Coooooo`000?l0003ooooo0_l0003jooooo`00
7_ooool00ol0003oooooooooo`0Wooooo`;o00007oooool2o`0001_ooooo0_l0003Pooooo`007_oo
ool00ol0003oooooooooo`0Wooooo`;o00007Oooool4o`0001_ooooo0_l0003@ooooo`;o00003_oo
ool001kooooo00?o0000ooooooooool0A?ooool4o`000>oooooo0_l0000>ooooo`007_ooool00ol0
003oooooooooo`14ooooo`Co00000oooool4o`0004Kooooo0_l0002>ooooo`;o00008?ooool001ko
oooo00?o0000ooooooooool0@Oooool2o`0000?ooooo0_l00002ooooo`Go0000A_ooool2o`0008ko
oooo0_l0000Pooooo`007_ooool00ol0003oooooooooo`0Vooooo`;o00001?ooool2o`0001?ooooo
1?l00002ooooo`;o000000?oooooo`000?l00000noooool001kooooo00?o0000ooooooooool09_oo
ool2o`0000Cooooo0_l0000Eooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`Co0000
I_ooool2o`0008kooooo000Nooooo`?o0000AOooool2o`0000Kooooo1?l0001Vooooo`;o0000S_oo
ool001kooooo0ol00015ooooo`?o00001oooool2o`000?Kooooo000Nooooo`03o`000?oooooooooo
04Gooooo0ol000000ooooooo0000o`000004ooooo`;o0000m_ooool001kooooo00?o0000oooooooo
ool0AOooool6o`0000?ooooo0ol0003fooooo`007_ooool00ol0003oooooooooo`0[ooooo`;o0000
1?ooool2o`0001?ooooo0ol00003ooooo`Go0000:_ooool2o`0003?ooooo0_l0002Eooooo`007_oo
ool00ol0003oooooooooo`0[ooooo`;o00001?ooool2o`0001Oooooo1ol0000Zooooo`;o0000<ooo
ool2o`0009Gooooo000Nooooo`03o`000?oooooooooo04Sooooo1?l0003kooooo`007_ooool2o`00
017ooooo0_l0000Dooooo`;o00003oooool2o`0000_ooooo0_l00002ooooo`;o00001?ooool4o`00
01Wooooo0_l0003Jooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o00005?ooool2o`0000oo
oooo0_l0000;ooooo`;o00002?ooool4o`0001Wooooo0_l00002ooooo`;o0000@?ooool2o`0009Co
oooo000Nooooo`03o`000?oooooooooo04_ooooo0_l00004ooooo`;o00007?ooool2o`00043ooooo
0_l00010ooooo`;o0000=oooool2o`0001Wooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0
000Cooooo`?o00005_ooool2o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l00000:?oo
ool2o`0000Gooooo0_l0001/ooooo`;o0000=oooool2o`0001Wooooo000Nooooo`03o`000?oooooo
oooo00;ooooo0_l0000Cooooo`;o00004oooool3o`0001Kooooo0_l00002ooooo`;o00001_ooool2
o`000003ooooool0003o000002Sooooo0_l00005ooooo`;o0000`?ooool001kooooo00?o0000oooo
ooooool00_ooool2o`0003kooooo0ol000001?oooooo0000o`000?ooool2o`0000Kooooo0ol00016
ooooo`;o0000Zoooool001kooooo00?o0000ooooooooool09?ooool2o`0000gooooo0_l0000=oooo
o`?o000000?oooooo`000?l000002_ooool2o`0004Kooooo0_l0002[ooooo`007_ooool00ol0003o
ooooooooo`0Tooooo`;o00003Oooool2o`0001Kooooo0_l0001Qooooo`;o0000Uoooool001kooooo
00?o0000ooooooooool0@?ooool5o`0000Kooooo0_l00003ooooo`;o000000?oooooo`000?l00000
FOooool2o`0006Kooooo0_l0000_ooooo`007_ooool00ol0003oooooooooo`10ooooo`Oo00002Ooo
ool2o`000003ooooool0003o00000<7ooooo0_l0000_ooooo`007_ooool00ol0003oooooooooo`15
ooooo`;o00001Oooool2o`0000Gooooo0_l0003booooo`007_ooool00ol0003oooooooooo`1<oooo
o`;o0000nOooool001kooooo00?o0000ooooooooool0A?ooool2o`0000;ooooo0_l00009ooooo`;o
0000l_ooool001kooooo00?o0000ooooooooool0A?ooool2o`0000;ooooo0_l00009ooooo`;o0000
l_ooool001kooooo00Co0000oooooooooooooooo0_l0001=ooooo`;o00006_ooool2o`000=Wooooo
000Nooooo`04o`000?ooooooooooooooo`;o0000COooool4o`0001Sooooo0_l0001Iooooo`;o0000
O_ooool001kooooo0_l0000fooooo`;o00002Oooool2o`0000oooooo1?l0001booooo`;o0000O_oo
ool001kooooo00?o0000ooooooooool0=Oooool2o`0000Wooooo0_l0000;ooooo`;o00000_ooool6
o`0003[ooooo0_l0002dooooo`007_ooool00ol0003oooooooooo`08ooooo`?o0000@_ooool3o`00
00;ooooo0_l000000ooooooo0000o`00000jooooo`;o0000]?ooool001kooooo00?o0000oooooooo
ool02?ooool3o`0002;ooooo0_l0000Oooooo`;o00000_ooool2o`000>_ooooo0_l00006ooooo`00
7_ooool00ol0003oooooooooo`0@ooooo`;o00006oooool2o`0001_ooooo0_l00002ooooo`;o0000
1?ooool3o`0000kooooo0_l0003Hooooo`;o00001_ooool001kooooo00?o0000ooooooooool04?oo
ool2o`0003Gooooo0_l000000ooooooo0000o`000007ooooo`Co00002?ooool2o`0000Cooooo0_l0
003Pooooo`007_ooool00ol0003oooooooooo`0aooooo`;o00004?ooool3o`000003ooooool0003o
000000?ooooo0_l00005ooooo`Go00001oooool2o`000>Kooooo000Nooooo`03o`000?oooooooooo
037ooooo0_l0000@ooooo`?o00001_ooool4o`0000?ooooo0_l000001?oooooo0000o`000?ooool2
o`000>cooooo000Nooooo`03o`000?oooooooooo04Cooooo0_l00008ooooo`;o00000oooool8o`00
0>cooooo000Nooooo`03o`000?oooooooooo04Cooooo0_l00005ooooo`;o00002?ooool4o`000>ko
oooo000Nooooo`03o`000?oooooooooo01[ooooo0_l0000:ooooo`;o00008_ooool3o`0000;ooooo
0_l00005ooooo`;o0000koooool001kooooo00?o0000ooooooooool06_ooool2o`0000[ooooo0_l0
000Rooooo`?o00000_ooool2o`0000Kooooo0_l0000Booooo`;o00001Oooool2o`000=?ooooo000N
ooooo`03o`000?oooooooooo01?ooooo0_l0000Zooooo`;o00002_ooool4o`0000?ooooo1?l00000
0ooooooo0000o`00000Booooo`;o00001Oooool2o`000=?ooooo000Nooooo`03o`000?oooooooooo
01?ooooo0_l0000Zooooo`;o00002oooool3o`0000?ooooo1?l000001?oooooo0000o`000?l0003]
ooooo`005?ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0<Oooool2o`00
01[ooooo0_l00006ooooo`;o000000?oooooo`000?l00000kOooool001Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0aooooo`;o00003oooool2o`00017ooooo0ol00006ooooo`;o
0000ioooool001Kooooo00?o0000ooooooooool01Oooool3o`0004;ooooo0_l0000Booooo`;o0000
0_ooool2o`0000;ooooo0_l0003Wooooo`005_ooool00ol0003oooooooooo`1Rooooo`;o0000jooo
ool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooo
oe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Cooooo00?oEEEEofIVI_l00000
oooooomBooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.31366 .68387 Mdot
.90244 .39012 Mdot
.34447 .57322 Mdot
.28425 .93951 Mdot
.21494 .55617 Mdot
.27828 .94977 Mdot
.47102 .10846 Mdot
.26097 .56698 Mdot
.23846 .94415 Mdot
.71705 .14052 Mdot
.29501 .09943 Mdot
.27745 .0464 Mdot
.27673 .56277 Mdot
.38519 .65555 Mdot
.29468 .91732 Mdot
.26268 .62978 Mdot
.84193 .55848 Mdot
.2287 .55808 Mdot
.31793 .58041 Mdot
.27005 .02295 Mdot
.99056 .5512 Mdot
.29749 .0083 Mdot
.21485 .53657 Mdot
.93864 .09703 Mdot
.23136 .88016 Mdot
.28621 .57693 Mdot
.28468 .82437 Mdot
.33398 .69969 Mdot
.29273 .10172 Mdot
.30391 .02827 Mdot
.28244 .56164 Mdot
.29072 .90959 Mdot
.22686 .99876 Mdot
.08148 .94928 Mdot
.079 .53596 Mdot
.29472 .87293 Mdot
.40021 .66305 Mdot
.96492 .4647 Mdot
.26445 .83822 Mdot
.2483 .79711 Mdot
.29694 .56552 Mdot
.20448 .62851 Mdot
.24098 .95119 Mdot
.91202 .5435 Mdot
.37268 .07543 Mdot
.22034 .69794 Mdot
.56234 .408 Mdot
.26405 .85352 Mdot
.31062 .83526 Mdot
.26424 .38582 Mdot
.23088 .00816 Mdot
.09607 .52949 Mdot
.24542 .52144 Mdot
.29961 .86218 Mdot
.23636 .50405 Mdot
.27466 .23357 Mdot
.76284 .24273 Mdot
.25442 .55939 Mdot
.28968 .82819 Mdot
.21604 .63406 Mdot
.29116 .94697 Mdot
.27792 .58269 Mdot
.48825 .10515 Mdot
.22274 .91129 Mdot
.20931 .75276 Mdot
.27679 .98639 Mdot
.20254 .44597 Mdot
.28778 .82401 Mdot
.28848 .95879 Mdot
.81735 .2662 Mdot
.2535 .22059 Mdot
.21556 .56767 Mdot
.20608 .11287 Mdot
.28529 .16537 Mdot
.25539 .02419 Mdot
.06686 .27481 Mdot
.28897 .46244 Mdot
.60385 .16113 Mdot
.28203 .86571 Mdot
.2814 .45435 Mdot
.23643 .8746 Mdot
.5805 .16639 Mdot
.92917 .54912 Mdot
.27273 .57292 Mdot
.80274 .35788 Mdot
.12711 .19145 Mdot
.23766 .55595 Mdot
.29603 .87577 Mdot
.29029 .93383 Mdot
.22168 .59194 Mdot
.23958 .0539 Mdot
.84639 .25299 Mdot
.26153 .37764 Mdot
.26059 .19162 Mdot
.22706 .58194 Mdot
.20907 .77372 Mdot
.53093 .12174 Mdot
.08723 .53617 Mdot
.20845 .84383 Mdot
.06093 .53541 Mdot
.29417 .75456 Mdot
.22548 .9762 Mdot
.33437 .62265 Mdot
.33275 .64289 Mdot
.95665 .32219 Mdot
.21109 .54398 Mdot
.25986 .63215 Mdot
.2733 .63867 Mdot
.12394 .52982 Mdot
.57037 .14634 Mdot
.39432 .66866 Mdot
.9403 .44659 Mdot
.26927 .99327 Mdot
.246 .55915 Mdot
.29061 .35372 Mdot
.50138 .09683 Mdot
.34163 .06171 Mdot
.29926 .56749 Mdot
.19366 .30088 Mdot
.34783 .9248 Mdot
.3007 .82685 Mdot
.24673 .74733 Mdot
.27326 .02762 Mdot
.26222 .19785 Mdot
.89187 .21103 Mdot
.02398 .53753 Mdot
.19038 .93582 Mdot
.28989 .62434 Mdot
.09059 .91851 Mdot
.17004 .08776 Mdot
.00962 .5119 Mdot
.27995 .24247 Mdot
.83308 .71807 Mdot
.20637 .57061 Mdot
.23166 .55857 Mdot
.2444 .45769 Mdot
.211 .54328 Mdot
.22769 .59896 Mdot
.34405 .58192 Mdot
.26748 .96373 Mdot
.2731 .6112 Mdot
.21847 .90835 Mdot
.26791 .00676 Mdot
.12493 .57464 Mdot
.49765 .27011 Mdot
.27154 .03898 Mdot
.24264 .69735 Mdot
.27194 .77442 Mdot
.76485 .24009 Mdot
.553 .15078 Mdot
.58041 .75647 Mdot
.2453 .00972 Mdot
.29137 .06001 Mdot
.27104 .03922 Mdot
.29442 .89894 Mdot
.29843 .56921 Mdot
.2263 .59629 Mdot
.75546 .29354 Mdot
.23998 .9131 Mdot
.24295 .61944 Mdot
.21521 .57559 Mdot
.05405 .52735 Mdot
.89918 .93851 Mdot
.19993 .57437 Mdot
.20953 .81899 Mdot
.21841 .54344 Mdot
.25987 .77298 Mdot
.25441 .86194 Mdot
.55254 .1409 Mdot
.19671 .57513 Mdot
.28352 .03786 Mdot
.21847 .87502 Mdot
.05167 .52645 Mdot
.18985 .27961 Mdot
.31622 .6505 Mdot
.25561 .72633 Mdot
.98441 .91601 Mdot
.31629 .56163 Mdot
.51318 .12019 Mdot
.08604 .53095 Mdot
.25478 .93475 Mdot
.2405 .02591 Mdot
.30974 .79847 Mdot
.39226 .11086 Mdot
.69292 .20002 Mdot
.2638 .9119 Mdot
.2368 .61526 Mdot
.22903 .02772 Mdot
.79121 .72029 Mdot
.13665 .66315 Mdot
.30634 .63957 Mdot
.08181 .17956 Mdot
.29007 .64913 Mdot
.36099 .12154 Mdot
.32102 .92357 Mdot
.23792 .9706 Mdot
.07724 .5365 Mdot
.28297 .05155 Mdot
.23577 .94876 Mdot
.24989 .01867 Mdot
.42636 .13742 Mdot
.32905 .35143 Mdot
.21638 .56509 Mdot
.40655 .10021 Mdot
.23039 .88495 Mdot
.29459 .88385 Mdot
.52874 .13608 Mdot
.2987 .85874 Mdot
.83534 .32775 Mdot
.35282 .72864 Mdot
.20122 .56598 Mdot
.27333 .65074 Mdot
.91793 .22074 Mdot
.6517 .24587 Mdot
.22297 .58585 Mdot
.24276 .1966 Mdot
.2424 .78077 Mdot
.24287 .30115 Mdot
.26923 .71674 Mdot
.25194 .42552 Mdot
.76621 .25227 Mdot
.22778 .56038 Mdot
.21639 .89947 Mdot
.25898 .88409 Mdot
.22534 .57351 Mdot
.20868 .58086 Mdot
.16899 .97365 Mdot
.23206 .49267 Mdot
.68461 .1797 Mdot
.26945 .00371 Mdot
.3102 .5784 Mdot
.21133 .65679 Mdot
.26383 .0104 Mdot
.13689 .07482 Mdot
.24147 .19186 Mdot
.70107 .20253 Mdot
.68852 .50197 Mdot
.29039 .5617 Mdot
.97 .49838 Mdot
.75104 .2283 Mdot
.31381 .51983 Mdot
.27279 .01812 Mdot
.25454 .91259 Mdot
.32691 .52185 Mdot
.27691 .82351 Mdot
.28939 .44187 Mdot
.21939 .56181 Mdot
.29154 .03876 Mdot
.60623 .1705 Mdot
.30923 .56966 Mdot
.09472 .51999 Mdot
.22478 .52241 Mdot
.8084 .21737 Mdot
.13654 .2021 Mdot
.88879 .2103 Mdot
.27735 .85406 Mdot
.23256 .53027 Mdot
.97743 .46476 Mdot
.16961 .74619 Mdot
.29295 .34932 Mdot
.28298 .68407 Mdot
.20888 .7323 Mdot
.2788 .20534 Mdot
.01936 .39109 Mdot
.26718 .01146 Mdot
.07638 .1252 Mdot
.25127 .97115 Mdot
.18072 .29157 Mdot
.29752 .56523 Mdot
.26417 .81229 Mdot
.20967 .84056 Mdot
.63242 .41899 Mdot
.29442 .97251 Mdot
.19991 .74064 Mdot
.23368 .89146 Mdot
.21577 .53434 Mdot
.2528 .70805 Mdot
.33426 .20708 Mdot
.30169 .85941 Mdot
.23833 1 Mdot
.78455 .25044 Mdot
.29371 .01905 Mdot
.19717 .5736 Mdot
.41785 .64105 Mdot
.22178 .54427 Mdot
.21731 .89925 Mdot
.20158 .57454 Mdot
.01013 .49578 Mdot
.27045 .77161 Mdot
.28856 .14206 Mdot
.26785 .89612 Mdot
.85848 .25208 Mdot
.31239 .5798 Mdot
.34619 .09967 Mdot
.53528 .12665 Mdot
.0196 .50486 Mdot
.22884 .74643 Mdot
.23015 .60953 Mdot
.78218 .25001 Mdot
.61195 .17409 Mdot
.0067 .49252 Mdot
.19888 .91914 Mdot
.09276 .54266 Mdot
.20928 .56656 Mdot
.69779 .12361 Mdot
.14429 .49583 Mdot
.27994 .82786 Mdot
.29358 .87363 Mdot
.90889 .18075 Mdot
.31942 .34089 Mdot
.30068 .84254 Mdot
.77844 .24948 Mdot
.28869 .58087 Mdot
.26043 .41337 Mdot
.21342 .79212 Mdot
.29443 .78493 Mdot
.2624 .75226 Mdot
.18759 .27673 Mdot
.21226 .97921 Mdot
.97672 .34658 Mdot
.27037 .84295 Mdot
.23787 .01081 Mdot
.23642 .01743 Mdot
.33472 .77859 Mdot
.25341 .56104 Mdot
.31436 .57622 Mdot
.30246 .85808 Mdot
.27121 .68342 Mdot
.25933 .03666 Mdot
.30193 .58375 Mdot
.2543 .03033 Mdot
.28502 .97033 Mdot
.36353 .23579 Mdot
.92291 .14617 Mdot
.23087 .32703 Mdot
.26162 .34517 Mdot
.73117 .66144 Mdot
.28639 .8123 Mdot
.75893 .91968 Mdot
.07394 .11367 Mdot
.21305 .83904 Mdot
.73844 .63496 Mdot
.2616 .64342 Mdot
.20907 .56678 Mdot
.72763 .28454 Mdot
.37983 .54672 Mdot
.54189 .13992 Mdot
.278 .25529 Mdot
.99891 .43857 Mdot
.25315 .56381 Mdot
.30955 .57002 Mdot
.2289 .52437 Mdot
.10165 .67729 Mdot
.32297 .66336 Mdot
.5022 .12121 Mdot
.29229 .96411 Mdot
.19334 .61048 Mdot
.20349 .57138 Mdot
.2556 .55969 Mdot
.25266 .30716 Mdot
.28911 .02686 Mdot
.00074 .81674 Mdot
.2903 .56387 Mdot
.20281 .5617 Mdot
.20726 .9169 Mdot
.07766 .73409 Mdot
.50558 .92199 Mdot
.69018 .64028 Mdot
.72981 .21124 Mdot
.3024 .00507 Mdot
.2237 .58543 Mdot
.27081 .83296 Mdot
.33582 .57606 Mdot
.26346 .98691 Mdot
.21002 .91818 Mdot
.04907 .5301 Mdot
.38256 .07767 Mdot
.30407 .85215 Mdot
.93892 .18642 Mdot
.30474 .05176 Mdot
.27836 .87628 Mdot
.27278 .95589 Mdot
.71006 .20152 Mdot
.88585 .2106 Mdot
.3198 .71397 Mdot
.37429 .09881 Mdot
.52863 .88938 Mdot
.5503 .49264 Mdot
.28222 .81569 Mdot
.4238 .67105 Mdot
.27321 .60231 Mdot
.21571 .56403 Mdot
.31553 .742 Mdot
.22305 .55967 Mdot
.21657 .56016 Mdot
.31039 .26052 Mdot
.84379 .62982 Mdot
.02364 .15489 Mdot
.29382 .83118 Mdot
.26813 .56451 Mdot
.22502 .98167 Mdot
.36899 .02733 Mdot
.77142 .27676 Mdot
.2788 .58069 Mdot
.51079 .65518 Mdot
.13549 .96312 Mdot
.28922 .14633 Mdot
.22423 .57498 Mdot
.20618 .57588 Mdot
.19904 .57519 Mdot
.22421 .58786 Mdot
.2409 .88315 Mdot
.21948 .5779 Mdot
.46339 .09202 Mdot
.73614 .21874 Mdot
.214 .56722 Mdot
.33371 .61638 Mdot
.20783 .58068 Mdot
.75433 .27014 Mdot
.28579 .86573 Mdot
.25313 .8244 Mdot
.50233 .35981 Mdot
.69336 .20032 Mdot
.21495 .56682 Mdot
.26197 .56101 Mdot
.82429 .48458 Mdot
.3804 .15099 Mdot
.25087 .97231 Mdot
.21365 .56864 Mdot
.84273 .32661 Mdot
.74627 .22516 Mdot
.58136 .42446 Mdot
.31576 .43655 Mdot
.26491 .98062 Mdot
.79805 .24971 Mdot
.42092 .54421 Mdot
.28539 .70351 Mdot
.14422 .98281 Mdot
.32453 .56825 Mdot
.3461 .05503 Mdot
.26963 .95351 Mdot
.92652 .48043 Mdot
.91259 .57741 Mdot
.29305 .95308 Mdot
.26922 .28622 Mdot
.29662 .90553 Mdot
.23061 .01107 Mdot
.20496 .56793 Mdot
.84279 .24106 Mdot
.20613 .55949 Mdot
.98307 .65249 Mdot
.14712 .53238 Mdot
.21502 .8468 Mdot
.27074 .87495 Mdot
.31847 .09933 Mdot
.29909 .84016 Mdot
.2331 .90621 Mdot
.29825 .86605 Mdot
.10936 .95804 Mdot
.33951 .41881 Mdot
.31649 .73594 Mdot
.29534 .88183 Mdot
.27372 .88991 Mdot
.33781 .56428 Mdot
.96355 .17549 Mdot
.07633 .5316 Mdot
.2309 .00614 Mdot
.02965 .57069 Mdot
.29537 .94488 Mdot
.10746 .80481 Mdot
.30424 .01316 Mdot
.24895 .5634 Mdot
.26787 .5714 Mdot
.27013 .57199 Mdot
.34669 .56264 Mdot
.28738 .89455 Mdot
.28451 .50055 Mdot
.27158 .56628 Mdot
.76688 .24904 Mdot
.189 .87194 Mdot
.59574 .17847 Mdot
.32264 .06357 Mdot
.28074 .01515 Mdot
.26106 .5991 Mdot
.30232 .67296 Mdot
.14998 .16108 Mdot
.20939 .17066 Mdot
.84621 .23049 Mdot
.21976 .90156 Mdot
.34357 .68692 Mdot
.31737 .57247 Mdot
.24875 .86645 Mdot
.34182 .25258 Mdot
.50272 .90719 Mdot
.27747 .07832 Mdot
.2876 .06362 Mdot
.28847 .53624 Mdot
.23004 .01529 Mdot
.03315 .24347 Mdot
.29367 .76388 Mdot
.30519 .4828 Mdot
.1606 .04751 Mdot
.22351 .86273 Mdot
.71087 .20165 Mdot
.21843 .5648 Mdot
.27498 .40445 Mdot
.2607 .57093 Mdot
.53253 .12354 Mdot
.23663 .89369 Mdot
.30001 .04089 Mdot
.24236 .57531 Mdot
.59076 .27532 Mdot
.27624 .23229 Mdot
.71437 .20816 Mdot
.21981 .55517 Mdot
.1409 .08384 Mdot
.29143 .8705 Mdot
.21356 .78152 Mdot
.73214 .37078 Mdot
.25656 .56695 Mdot
.21037 .567 Mdot
.34532 .56295 Mdot
.2793 .87091 Mdot
.26333 .0206 Mdot
.09935 .62879 Mdot
.66402 .81918 Mdot
.35304 .24883 Mdot
.81729 .64463 Mdot
.25275 .49896 Mdot
.11058 .96071 Mdot
.97416 .02172 Mdot
.49227 .24206 Mdot
.21917 .55019 Mdot
.24844 .86247 Mdot
.27763 .57354 Mdot
.30051 .76056 Mdot
.19914 .76328 Mdot
.21649 .95678 Mdot
.95024 .43893 Mdot
.50112 .14378 Mdot
.26873 .96491 Mdot
.73731 .22141 Mdot
.26454 .03529 Mdot
.28979 .89005 Mdot
.31673 .71299 Mdot
.51479 .11587 Mdot
.84095 .23993 Mdot
.25217 .4826 Mdot
.19755 .57073 Mdot
.31108 .57676 Mdot
.51459 .12881 Mdot
.45117 .13802 Mdot
.22319 .98069 Mdot
.05387 .9669 Mdot
.25202 .89059 Mdot
.56781 .08233 Mdot
.84089 .22915 Mdot
.29058 .80407 Mdot
.2825 .90883 Mdot
.36833 .39451 Mdot
.19644 .57503 Mdot
.212 .98542 Mdot
.95279 .44122 Mdot
.04271 .6476 Mdot
.20626 .57172 Mdot
.31124 .83512 Mdot
.21703 .58336 Mdot
.2141 .87594 Mdot
.58579 .37962 Mdot
.28832 .93645 Mdot
.55779 .44489 Mdot
.33421 .65451 Mdot
.28637 .90112 Mdot
.25909 .68945 Mdot
.22374 .55937 Mdot
.24561 .98515 Mdot
.1373 .00137 Mdot
.29285 .10386 Mdot
.22623 .51692 Mdot
.29423 .4531 Mdot
.63715 .03979 Mdot
.84086 .2587 Mdot
.33189 .533 Mdot
.27466 .58558 Mdot
.9561 .44337 Mdot
.29401 .87977 Mdot
.27529 .91418 Mdot
.4832 .03322 Mdot
.41997 .93503 Mdot
.22216 .64746 Mdot
.26905 .56378 Mdot
.25415 .49185 Mdot
.2043 .57335 Mdot
.23825 .01704 Mdot
.29009 .06466 Mdot
.29268 .58587 Mdot
.28875 .71922 Mdot
.3053 .57813 Mdot
.29657 .86885 Mdot
.2017 .57256 Mdot
.24747 .99761 Mdot
.25964 .83615 Mdot
.32514 .57406 Mdot
.08673 .53633 Mdot
.40055 .05772 Mdot
.19908 .57499 Mdot
.26819 .78855 Mdot
.30429 .02331 Mdot
.42863 .09108 Mdot
.29641 .67558 Mdot
.45445 .10608 Mdot
.53631 .12609 Mdot
.29749 .98048 Mdot
.30007 .25461 Mdot
.33827 .58666 Mdot
.2668 .68181 Mdot
.21609 .56919 Mdot
.18899 .19679 Mdot
.20332 .8754 Mdot
.61262 .17934 Mdot
.64922 .83431 Mdot
.41691 .36703 Mdot
.29563 .65476 Mdot
.07732 .2249 Mdot
.1413 .55509 Mdot
.25687 .02344 Mdot
.01882 .02646 Mdot
.10818 .19477 Mdot
.23297 .49597 Mdot
.20643 .96789 Mdot
.34568 .57184 Mdot
.2553 .88352 Mdot
.2184 .65073 Mdot
.31584 .54537 Mdot
.28499 .90519 Mdot
.63482 .18613 Mdot
.27076 .57104 Mdot
.26507 .40103 Mdot
.2106 .56747 Mdot
.29467 .9299 Mdot
.20423 .05954 Mdot
.28354 .94091 Mdot
.19666 .58841 Mdot
.19492 .0751 Mdot
.41052 .02492 Mdot
.22816 .55847 Mdot
.20018 .96035 Mdot
.75301 .24818 Mdot
.28941 .58099 Mdot
.44437 .09499 Mdot
.90029 .0529 Mdot
.23299 .021 Mdot
.9583 .87325 Mdot
.26067 .89108 Mdot
.84231 .23978 Mdot
.24626 .81058 Mdot
.26799 .51438 Mdot
.7895 .2487 Mdot
.83238 .32577 Mdot
.29681 .83542 Mdot
.36418 .06564 Mdot
.22646 .7865 Mdot
.67819 .15741 Mdot
.30424 .82499 Mdot
.07578 .14988 Mdot
.07276 .88639 Mdot
.29027 .86797 Mdot
.49526 .11702 Mdot
.06379 .5418 Mdot
.02747 .86453 Mdot
.24029 .15757 Mdot
.66486 .12941 Mdot
.36279 .13355 Mdot
.30192 .06645 Mdot
.74365 .22272 Mdot
.28054 .58164 Mdot
.79346 .15363 Mdot
.21636 .56442 Mdot
.56836 .15976 Mdot
.80143 .38155 Mdot
.93172 .42053 Mdot
.13183 .58442 Mdot
.72981 .21384 Mdot
.29588 .62241 Mdot
.28778 .9339 Mdot
.02313 .50585 Mdot
.19299 .9169 Mdot
.55162 .14524 Mdot
.40187 .8786 Mdot
.2472 .55905 Mdot
.25752 .77752 Mdot
.39125 .08866 Mdot
.25962 .35778 Mdot
.50847 .40896 Mdot
.24143 .0049 Mdot
.22726 .78304 Mdot
.27024 .88752 Mdot
.48701 .25518 Mdot
.65778 .19445 Mdot
.9484 .21187 Mdot
.25436 .3019 Mdot
.31121 .64711 Mdot
.2998 .569 Mdot
.34347 .5834 Mdot
.22092 .19661 Mdot
.2602 .01689 Mdot
.65947 .17001 Mdot
.00845 .25937 Mdot
.33137 .17167 Mdot
.23171 .9623 Mdot
.68189 .19708 Mdot
.21573 .66642 Mdot
.39084 .97297 Mdot
.76177 .22249 Mdot
.22493 .51127 Mdot
.82779 .46996 Mdot
.28759 .02956 Mdot
.22855 .55868 Mdot
.52249 .09693 Mdot
.28094 .03168 Mdot
.26811 .66901 Mdot
.2032 .14512 Mdot
.21024 .56729 Mdot
.44016 .41467 Mdot
.997 .6016 Mdot
.81585 .27957 Mdot
.26645 .35738 Mdot
.30038 .81861 Mdot
.20014 .09197 Mdot
.75298 .24859 Mdot
.29669 .06975 Mdot
.29662 .05622 Mdot
.31829 .57295 Mdot
.25151 .94164 Mdot
.52359 .06977 Mdot
.50697 .52915 Mdot
.84814 .24272 Mdot
.84673 .23106 Mdot
.22099 .99441 Mdot
.82801 .31309 Mdot
.20372 .78739 Mdot
.27721 .96397 Mdot
.33076 .58394 Mdot
.58912 .97096 Mdot
.14361 .08048 Mdot
.19297 .94396 Mdot
.30324 .05673 Mdot
.76227 .24457 Mdot
.20759 .97647 Mdot
.00263 .15295 Mdot
.23202 .94546 Mdot
.29897 .72388 Mdot
.33753 .11402 Mdot
.32667 .67593 Mdot
.22369 .5614 Mdot
.19472 .80732 Mdot
.19966 .57534 Mdot
.23912 .90686 Mdot
.27861 .50327 Mdot
.30591 .56796 Mdot
.78934 .28959 Mdot
.25987 .56757 Mdot
.85806 .33932 Mdot
.27901 .72719 Mdot
.29283 .12962 Mdot
.28699 .969 Mdot
.08938 .56019 Mdot
.74979 .22964 Mdot
.28153 .04828 Mdot
.86211 .34146 Mdot
.22557 .84957 Mdot
.45002 .85022 Mdot
.20329 .55855 Mdot
.22464 .52271 Mdot
.54127 .14379 Mdot
.27063 .57749 Mdot
.19015 .85471 Mdot
.31451 .57146 Mdot
.3177 .10391 Mdot
.28646 .18434 Mdot
.28269 .94417 Mdot
.31276 .90121 Mdot
.76393 .2386 Mdot
.13504 .02838 Mdot
.2192 .76154 Mdot
.23152 .60452 Mdot
.32197 .67318 Mdot
.26517 .95878 Mdot
.24996 .86859 Mdot
.31947 .57439 Mdot
.63687 .68027 Mdot
.73045 .21184 Mdot
.49554 .65184 Mdot
.30042 .56209 Mdot
.01367 .49517 Mdot
.2635 .51289 Mdot
.34066 .67707 Mdot
.61535 .63736 Mdot
.28007 .92567 Mdot
.22369 .56253 Mdot
.74042 .22201 Mdot
.30696 .02986 Mdot
.33057 .53139 Mdot
.29073 .99542 Mdot
.20619 .68719 Mdot
.22298 .56141 Mdot
.32975 .24805 Mdot
.25984 .2944 Mdot
.05125 .5268 Mdot
.21858 .56256 Mdot
.03953 .5228 Mdot
.28433 .90823 Mdot
.3448 .56406 Mdot
.61748 .82319 Mdot
.24374 .98863 Mdot
.2665 .84442 Mdot
.55075 .23095 Mdot
.76976 .24309 Mdot
.29612 .91515 Mdot
.49785 .11696 Mdot
.27199 .57137 Mdot
.29061 .57588 Mdot
.19587 .93008 Mdot
.29442 .56817 Mdot
.24365 .56257 Mdot
.22847 .59823 Mdot
.24527 .52926 Mdot
.208 .85397 Mdot
.535 .14003 Mdot
.19987 .57528 Mdot
.3421 .06524 Mdot
.00182 .48683 Mdot
.23575 .55791 Mdot
.52772 .13394 Mdot
.2321 .66494 Mdot
.19683 .57668 Mdot
.62237 .17803 Mdot
.3104 .8368 Mdot
.20475 .93681 Mdot
.55858 .13363 Mdot
.4955 .9426 Mdot
.29769 .57718 Mdot
.2832 .82923 Mdot
.25148 .94991 Mdot
.7782 .24849 Mdot
.45239 .1012 Mdot
.03336 .54813 Mdot
.32507 .57334 Mdot
.28785 .58534 Mdot
.29911 .72241 Mdot
.9678 .45586 Mdot
.21229 .65433 Mdot
.3028 .56871 Mdot
.26097 .39946 Mdot
.30885 .79076 Mdot
.94965 .24261 Mdot
.26512 .56912 Mdot
.26753 .28315 Mdot
.18973 .85768 Mdot
.26758 .7376 Mdot
.29102 .57949 Mdot
.2886 .93572 Mdot
.23288 .97137 Mdot
.64406 .20949 Mdot
.29466 .57847 Mdot
.24244 .02469 Mdot
.31872 .58141 Mdot
.25979 .6997 Mdot
.90845 .19486 Mdot
.28045 .56653 Mdot
.2831 .36887 Mdot
.31133 .77936 Mdot
.22552 .88476 Mdot
.30705 .75458 Mdot
.23431 .90882 Mdot
.22786 .55722 Mdot
.79291 .45994 Mdot
.93976 .41211 Mdot
.38295 .029 Mdot
.22976 .56005 Mdot
.65379 .77004 Mdot
.29405 .00777 Mdot
.264 .57015 Mdot
.32264 .53732 Mdot
.24098 .57853 Mdot
.31097 .67722 Mdot
.32542 .68192 Mdot
.75965 .23558 Mdot
.29513 .01158 Mdot
.16755 .91273 Mdot
.70685 .19549 Mdot
.33823 .21352 Mdot
.22616 .47119 Mdot
.28944 .01975 Mdot
.62179 .12887 Mdot
.23126 .7534 Mdot
.78701 .30682 Mdot
.29618 .95046 Mdot
.51987 .74497 Mdot
.19044 .84295 Mdot
.23067 .56169 Mdot
.23727 .97219 Mdot
.52501 .36727 Mdot
.30623 .6899 Mdot
.49267 .1188 Mdot
.46205 .50325 Mdot
.12912 .026 Mdot
.19951 .74206 Mdot
.30552 .57718 Mdot
.25294 .64749 Mdot
.20804 .9195 Mdot
.14471 .90528 Mdot
.25012 .25861 Mdot
.22239 .96264 Mdot
.21545 .81871 Mdot
.26291 .34601 Mdot
.99766 .81414 Mdot
.57028 .77026 Mdot
.22073 .80015 Mdot
.2496 .95791 Mdot
.6977 .20179 Mdot
.26345 .36665 Mdot
.25543 .39914 Mdot
.28931 .58121 Mdot
.2933 .91866 Mdot
.97949 .46682 Mdot
.69317 .18574 Mdot
.31778 .10586 Mdot
.94589 .43468 Mdot
.83299 .32696 Mdot
.25521 .64694 Mdot
.20949 .5467 Mdot
.27958 .56821 Mdot
.26622 .01066 Mdot
.04574 .17464 Mdot
.28087 .61726 Mdot
.75473 .23348 Mdot
.29407 .0506 Mdot
.29134 .86238 Mdot
.05161 .01695 Mdot
.28 .56476 Mdot
.33919 .58265 Mdot
.23144 .86721 Mdot
.52087 .11844 Mdot
.28195 .45476 Mdot
.2788 .92919 Mdot
.23134 .13115 Mdot
.2639 .42527 Mdot
.26381 .95473 Mdot
.62908 .16124 Mdot
.29595 .96193 Mdot
.78622 .24925 Mdot
.19853 .57836 Mdot
.66949 .60539 Mdot
.55821 .7133 Mdot
.33693 .57383 Mdot
.67783 .2365 Mdot
.99731 .48302 Mdot
.49523 .1127 Mdot
.89429 .18306 Mdot
.30124 .01742 Mdot
.26627 .86824 Mdot
.29626 .91834 Mdot
.21297 .63433 Mdot
.30614 .57878 Mdot
.51965 .12781 Mdot
.23016 .62888 Mdot
.21029 .58233 Mdot
.81377 .29661 Mdot
.55679 .14244 Mdot
.2729 .23746 Mdot
.80962 .14525 Mdot
.96641 .15506 Mdot
.5158 .11862 Mdot
.6411 .17705 Mdot
.26402 .57581 Mdot
.22729 .60766 Mdot
.52069 .24698 Mdot
.28427 .83818 Mdot
.31001 .7776 Mdot
.22802 .5577 Mdot
.22768 .5614 Mdot
.25807 .33089 Mdot
.23299 .61266 Mdot
.30234 .05963 Mdot
.15441 .53699 Mdot
.32051 .08359 Mdot
.5772 .16237 Mdot
.11454 .53949 Mdot
.29378 .78596 Mdot
.97913 .5621 Mdot
.28291 .93796 Mdot
.30624 .08421 Mdot
.56811 .31827 Mdot
.20295 .92719 Mdot
.30179 .81718 Mdot
.30918 .74 Mdot
.26341 .36947 Mdot
.21913 .59713 Mdot
.2856 .05434 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`09ooooo`;o00000_ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool2o`0000Wo
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;o
oooo000Nooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01_ooool2o`000003oooo
ool0003o000000;ooooo00?o0000ooooooooool00_ooool2o`0000Wooooo0_l0000>ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o0000ooooooooool0Aooo
ool2o`000003ooooool0003o000000;o00001?ooool3o`0000Kooooo1Ol0003Wooooo`007_ooool0
0ol0003oooooooooo`17ooooo`Co000000?oooooo`000?l000001?ooool3o`0000Kooooo1_l0003V
ooooo`007_ooool00ol0003oooooooooo`17ooooo`Co00002?ooool2o`0000;ooooo0_l00003oooo
o`;o000000?oooooo`000?l00000i_ooool001kooooo00?o0000ooooooooool03Oooool2o`0003So
oooo1?l00002ooooo`;o000000?oooooo`000?l000000oooool4o`000005ooooool0003o0000o`00
0?ooool00_l0003Wooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o0000>Oooool3o`0000;o
oooo0_l000001Ooooooo0000o`000?l0003ooooo00?o00000oooool3o`000003ooooool0003o0000
0=Wooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`0Vooooo`;o00008?ooool5o`0000;o
oooo1?l000000ooooooo0000o`000009ooooo`;o00008?ooool2o`000;Kooooo0_l0000<ooooo`00
7_ooool00ol0003oooooooooo`02ooooo`;o00008_ooool4o`0001cooooo0_l00002ooooo`?o0000
0_ooool2o`0000Cooooo0_l00003ooooo`;o00000oooool2o`0001?ooooo0_l00002ooooo`;o0000
1oooool2o`000<Cooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0000Tooooo`;o00007?oo
ool2o`0000Oooooo0_l00004ooooo`Oo00000oooool3o`0001;ooooo0_l00002ooooo`;o0000cOoo
ool001kooooo00?o0000ooooooooool0Coooool2o`0000Kooooo1?l00005ooooo`;o0000=oooool2
o`000:cooooo000Nooooo`03o`000?oooooooooo053ooooo1?l00004ooooo`;o0000?oooool2o`00
0:cooooo000Nooooo`03o`000?oooooooooo053ooooo1_l00002ooooo`;o000000?oooooo`000?l0
00000_l0001/ooooo`;o0000N_ooool001kooooo00?o0000ooooooooool0E?ooool2o`0000Gooooo
1?l0001/ooooo`;o0000N_ooool001kooooo00?o0000ooooooooool0<?ooool2o`0002Cooooo0_l0
003_ooooo`007_ooool00ol0003oooooooooo`0`ooooo`;o00009?ooool3o`0000;ooooo0_l0003Z
ooooo`007_ooool2o`0005Sooooo0ol000000ooooooo0000o`000002ooooo`;o0000`?ooool2o`00
02Cooooo000Nooooo`03o`000?oooooooooo04[ooooo0_l0000<ooooo`?o000000?oooooo`000?l0
00000ol0000;ooooo`;o0000/oooool2o`0002Cooooo000Nooooo`03o`000?oooooooooo03kooooo
0_l0000:ooooo`;o00003Oooool2o`000003ooooool0003o000000;o00003?ooool2o`00013ooooo
0_l00037ooooo`007_ooool00ol0003oooooooooo`0nooooo`;o00006oooool2o`000003ooooool0
003o000000_ooooo0_l0000Aooooo`;o0000aoooool001kooooo00?o0000ooooooooool0FOooool4
o`0000Sooooo0_l00004ooooo`;o00001Oooool2o`000=?ooooo000Nooooo`03o`000?oooooooooo
05Wooooo0ol00002ooooo`;o00001Oooool2o`0000Cooooo0_l00005ooooo`;o0000doooool001ko
oooo00?o0000ooooooooool0G?ooool4o`0004Kooooo0_l0002Oooooo`007_ooool00ol0003ooooo
ooooo`0Xooooo`;o00004Oooool2o`0001oooooo0_l00018ooooo`;o0000Woooool001kooooo00?o
0000ooooooooool0:?ooool2o`00017ooooo0_l0000Iooooo`;o00007Oooool2o`000003ooooool0
003o00000<gooooo000Nooooo`03o`000?oooooooooo02_ooooo0_l0000Yooooo`;o00007Oooool2
o`000003ooooool0003o00000<gooooo000Nooooo`03o`000?oooooooooo02[ooooo0ol0000boooo
o`;o00000oooool2o`0004kooooo0_l0002Aooooo`007_ooool00ol0003oooooooooo`0Zooooo`;o
0000<oooool2o`0000?ooooo0_l0001>ooooo`;o0000TOooool001kooooo00?o0000ooooooooool0
<oooool2o`0004Kooooo0_l0003:ooooo`007_ooool00ol0003oooooooooo`0cooooo`;o00002?oo
ool2o`0003cooooo0_l0000:ooooo`;o00002_ooool2o`000;;ooooo000Nooooo`03o`000?oooooo
oooo03gooooo0_l00018ooooo`;o00000oooool2o`0000Gooooo0_l0002booooo`007_ooool00ol0
003oooooooooo`1Looooo`;o00001Oooool2o`0000Oooooo0_l00008ooooo`;o00005?ooool2o`00
017ooooo0_l00005ooooo`;o0000QOooool2o`0001Sooooo000Nooooo`;o0000G?ooool3o`0000Go
oooo0_l00007ooooo`;o00002?ooool2o`0000Sooooo0_l0000=ooooo`;o00003_ooool2o`0000Go
oooo0_l00025ooooo`;o00006?ooool001kooooo00?o0000ooooooooool0Foooool2o`0000Kooooo
0_l0000Kooooo`;o00003Oooool2o`0000[ooooo0_l0002Zooooo`007_ooool00ol0003ooooooooo
o`1Kooooo`;o00001_ooool2o`0002_ooooo0_l00003ooooo`;o00001?ooool2o`000:[ooooo000N
ooooo`03o`000?oooooooooo07_ooooo0_l0000Cooooo`;o00000oooool2o`000;3ooooo000Noooo
o`03o`000?oooooooooo01Cooooo0_l0000Yooooo`;o0000:Oooool2o`0000oooooo0_l0000Poooo
o`;o0000Z?ooool001kooooo00?o0000ooooooooool05?ooool2o`0002Wooooo0_l0000Yooooo`;o
0000<Oooool3o`0000?ooooo0_l0002Rooooo`007_ooool00ol0003oooooooooo`2Looooo`Go0000
0_ooool4o`000:3ooooo000Nooooo`03o`000?oooooooooo077ooooo0_l0000Yooooo`;o000000?o
ooooo`000?l000000_ooool4o`000004ooooool0003o0000o`0003Cooooo0_l0001Vooooo`007_oo
ool00ol0003oooooooooo`0Eooooo`;o0000F_ooool2o`0003Gooooo1?l0000cooooo`;o0000I_oo
ool001kooooo00?o0000ooooooooool05Oooool2o`0004Cooooo0_l00016ooooo`Co00000oooool2
o`0001[ooooo0_l0000<ooooo`;o0000LOooool001kooooo00?o0000ooooooooool0Aoooool2o`00
01;ooooo0_l0000Eooooo`;o0000;oooool4o`0000[ooooo0_l0000Cooooo`;o00003?ooool2o`00
077ooooo000Nooooo`03o`000?oooooooooo04Oooooo0_l0000Yooooo`;o0000<oooool3o`0000Oo
oooo0_l0002Dooooo`007_ooool00ol0003oooooooooo`26ooooo`;o00001oooool2o`0001Kooooo
0ol0002Mooooo`007_ooool00ol0003oooooooooo`1Jooooo`;o0000:_ooool2o`0000Oooooo0_l0
000Iooooo`Co00000_ooool3o`0003;ooooo0_l0001Pooooo`007_ooool00ol0003oooooooooo`0n
ooooo`;o00006_ooool2o`0004?ooooo0_l00009ooooo`Co000000?oooooo`000?l000000_l0000b
ooooo`;o00007?ooool2o`0004;ooooo000Nooooo`03o`000?oooooooooo03kooooo0_l0000Joooo
o`;o0000@oooool2o`0000_ooooo0_l000000ooooooo0000o`000004ooooo`;o0000C?ooool2o`00
02?ooooo0_l0000Mooooo`007_ooool2o`0001Kooooo0_l00013ooooo`;o00007?ooool2o`0003Ko
oooo0_l00003ooooo`;o0000LOooool2o`0001gooooo000Nooooo`;o00001Oooool2o`0000oooooo
0_l0001Qooooo`;o0000=_ooool2o`0004cooooo0_l0000fooooo`;o00003oooool001kooooo0_l0
0005ooooo`;o0000A?ooool2o`0008cooooo0_l0000Tooooo`;o0000=_ooool2o`0000oooooo000N
ooooo`03o`000?oooooooooo02gooooo0_l0000Kooooo`;o0000JOooool2o`0000Wooooo0_l00006
ooooo`;o00003_ooool2o`0006gooooo000Nooooo`03o`000?oooooooooo02gooooo0_l00026oooo
o`;o000000?oooooo`000?l000001_ooool2o`0000Kooooo0_l0001mooooo`007_ooool00ol0003o
ooooooooo`1Iooooo`;o0000GOooool3o`0008cooooo000Nooooo`03o`000?oooooooooo05Wooooo
0_l0001Nooooo`;o00001_ooool2o`0000oooooo0_l0001cooooo`007_ooool00ol0003ooooooooo
o`10ooooo`;o00009_ooool2o`0005Oooooo0_l0000?ooooo`;o0000Loooool001kooooo00?o0000
ooooooooool02oooool2o`0003?ooooo0_l0000Vooooo`;o0000FOooool2o`00073ooooo0_l0000@
ooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o00002Oooool2o`000:Kooooo0_l00003oooo
o`;o000000?oooooo`000?l000001?ooool2o`0000cooooo0_l0001Iooooo`;o00004?ooool001ko
oooo00?o0000ooooooooool05_ooool2o`000:Kooooo0_l00003ooooo`;o000000?oooooo`000?l0
00001?ooool2o`0000cooooo0_l00017ooooo`;o00008_ooool001kooooo00?o0000ooooooooool0
FOooool2o`0008;ooooo0_l00010ooooo`;o00000_ooool2o`0002;ooooo000Nooooo`03o`000?oo
oooooooo05Wooooo0_l0001_ooooo`;o00004Oooool2o`00043ooooo0_l0000<ooooo`;o00006?oo
ool001kooooo00?o0000ooooooooool09Oooool2o`0002?ooooo0_l00005ooooo`;o0000Moooool2
o`00067ooooo0_l0000Hooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`Go00001_ooool00ol0003oooooooooo`0Oooooo`;o00001?ooool2o`0002?ooooo0_l00005
ooooo`;o0000Ooooool2o`0004oooooo0_l0000Rooooo`000oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003ooooooooo
o`0Oooooo`;o00006?ooool2o`0000Wooooo0_l00005ooooo`;o00001?ooool2o`0007oooooo0_l0
0006ooooo`;o00001_ooool2o`0003oooooo0_l0000Rooooo`000oooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool3o`0003Wooooo0_l00009ooooo`;o00001Ooo
ool2o`0000Cooooo0_l00027ooooo`;o000000?oooooo`000?l000000oooool2o`0006?ooooo0003
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oo
oooooooo02Sooooo0_l0002cooooo`Go000000?oooooo`000?l00000H_ooool000?ooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0:?oo
ool2o`0002gooooo0_l0000@ooooo`;o0000M?ooool3o`000003ooooool0003o000006;ooooo0003
ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo05Oooooo0_l0000@ooooo`;o0000H_ooool2o`0001Gooooo0_l0000gooooo`;o0000:?oo
ool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
1_ooool00ol0003oooooooooo`1Zooooo`;o0000HOooool2o`0001Gooooo0_l00003ooooo`;o0000
<Oooool4o`00013ooooo0_l0000Eooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo06[ooooo0_l0001mooooo`;o
0000<Oooool4o`00013ooooo0_l0000Eooooo`007_ooool00ol0003oooooooooo`3Yooooo`Co0000
5_ooool2o`0004;ooooo000Nooooo`03o`000?oooooooooo04kooooo0_l0002Kooooo`Go00001?oo
ool2o`0000gooooo0_l0000Qooooo`;o00007oooool001kooooo00?o0000ooooooooool05Oooool2
o`0003Oooooo0_l0002Looooo`Go00000oooool2o`00033ooooo0_l0000Oooooo`007_ooool00ol0
003oooooooooo`0Eooooo`;o0000f?ooool3o`0005Gooooo000Nooooo`03o`000?oooooooooo0:oo
oooo0_l0000oooooo`;o00006oooool4o`0003Kooooo000Nooooo`03o`000?oooooooooo05Gooooo
0ol0001Gooooo`;o0000?oooool3o`0001[ooooo1?l0000fooooo`007_ooool00ol0003ooooooooo
o`1Eooooo`?o00006_ooool2o`0006Cooooo0_l0000Gooooo`Co0000D_ooool001kooooo00?o0000
ooooooooool0EOooool2o`0001_ooooo0_l0001Tooooo`;o00006Oooool4o`0001Kooooo0ol0000g
ooooo`007_ooool00ol0003oooooooooo`07ooooo`;o0000C_ooool2o`0004?ooooo0_l0001Foooo
o`Co00005Oooool5o`0001oooooo0_l0000Dooooo`007_ooool00ol0003oooooooooo`07ooooo`;o
0000C_ooool2o`0004?ooooo0_l00007ooooo`;o0000:Oooool2o`0002;ooooo1?l0000Hooooo`;o
00007oooool2o`0001Cooooo000Nooooo`03o`000?oooooooooo06Oooooo0_l00006ooooo`;o0000
=?ooool2o`0002Wooooo0_l0000Oooooo`;o000000Coooooo`000?l0003o00000_ooool8o`0004Ko
oooo000Nooooo`;o0000J?ooool2o`0000;ooooo0_l00002ooooo`;o0000P?ooool2o`0000;ooooo
0_l00002ooooo`So00003_ooool2o`0000;ooooo0_l0000booooo`007_ooool00ol0003ooooooooo
o`1Fooooo`;o00001Oooool2o`0000cooooo0_l0000]ooooo`;o0000FOooool2o`0001Sooooo0_l0
0002ooooo`;o0000<_ooool001kooooo00Co0000ooooool0003o0000C?ooool2o`0000Oooooo0_l0
0005ooooo`;o0000>oooool2o`00077ooooo0_l0000hooooo`007_ooool01?l0003oooooo`000?l0
001<ooooo`;o00004_ooool2o`000:[ooooo0_l0000hooooo`007_ooool00ol0003oooooooooo`1Q
ooooo`;o0000i?ooool001kooooo00?o0000ooooooooool0ooooool7ooooo`;o0000?oooool001ko
oooo00?o0000ooooooooool0W_ooool2o`00057ooooo0_l0000Cooooo`;o0000?oooool001kooooo
00?o0000ooooooooool04_ooool2o`0008[ooooo0_l0001Aooooo`;o0000E?ooool001kooooo00?o
0000ooooooooool04_ooool2o`0002Gooooo0_l00021ooooo`;o0000>Oooool2o`0004kooooo000N
ooooo`03o`000?oooooooooo03Wooooo0ol00020ooooo`;o0000>Oooool2o`0000cooooo0_l00010
ooooo`007_ooool00ol0003oooooooooo`0jooooo`;o00005oooool2o`000;3ooooo0_l00010oooo
o`007_ooool00ol0003oooooooooo`1Cooooo`;o0000Toooool2o`0005gooooo000Nooooo`03o`00
0?oooooooooo05?ooooo0_l0002Cooooo`;o00004oooool2o`0004Sooooo000Nooooo`03o`000?oo
oooooooo03Oooooo0_l0002hooooo`;o00002_ooool2o`0004Sooooo000Nooooo`03o`000?oooooo
oooo03Oooooo0_l0000Gooooo`;o0000Woooool2o`00017ooooo0_l00011ooooo`007_ooool00ol0
003oooooooooo`1@ooooo`;o0000/_ooool2o`00047ooooo000Nooooo`;o0000??ooool2o`0000ko
oooo0_l00002ooooo`;o0000m_ooool001kooooo00?o0000ooooooooool0>oooool2o`0000kooooo
0_l00002ooooo`;o0000m_ooool001kooooo00?o0000ooooooooool0C_ooool2o`000:cooooo0_l0
0019ooooo`007_ooool00ol0003oooooooooo`1>ooooo`;o0000[?ooool2o`0004Wooooo000Noooo
o`03o`000?oooooooooo0?oooooo2_ooool2o`0003cooooo000Nooooo`03o`000?oooooooooo0?oo
oooo2_ooool2o`0003cooooo000Nooooo`03o`000?oooooooooo0;Gooooo0_l0002@ooooo`007_oo
ool00ol0003oooooooooo`2eooooo`;o0000O?ooool2o`0001;ooooo000Nooooo`03o`000?oooooo
oooo04Oooooo0_l00032ooooo`;o000000?oooooo`000?l000008oooool2o`0001;ooooo000Noooo
o`03o`000?oooooooooo04Oooooo0_l00032ooooo`;o000000?oooooo`000?l00000=oooool001ko
oooo00?o0000ooooooooool0D?ooool2o`000;Wooooo0_l0000jooooo`007_ooool00ol0003ooooo
ooooo`1@ooooo`;o0000mOooool001kooooo00?o0000ooooooooool0oooooolDooooo`;o0000<_oo
ool001kooooo00?o0000ooooooooool0I?ooool2o`000:gooooo0ol0000aooooo`007_ooool00ol0
003oooooooooo`1Aooooo`;o00004Oooool2o`000:kooooo0_l0000aooooo`007_ooool00ol0003o
ooooooooo`1Aooooo`;o0000i_ooool2o`0000cooooo000Nooooo`;o0000D_ooool2o`0000Sooooo
0_l0000:ooooo`;o0000d?ooool2o`0000cooooo000Nooooo`03o`000?oooooooooo05[ooooo0ol0
000:ooooo`;o0000g_ooool001kooooo00?o0000ooooooooool0D?ooool2o`000003ooooool0003o
000000Gooooo0_l0002Uooooo`;o0000A?ooool001kooooo00?o0000ooooooooool0D?ooool2o`00
0003ooooool0003o000004[ooooo0_l0001Pooooo`;o0000A?ooool001kooooo00?o0000oooooooo
ool0Woooool2o`000:Kooooo000Nooooo`03o`000?oooooooooo05;ooooo0_l0000_ooooo`;o0000
8_ooool2o`0009kooooo000Nooooo`03o`000?oooooooooo05;ooooo0_l00004ooooo`;o0000:Ooo
ool2o`0002;ooooo0_l0002Nooooo`007_ooool00ol0003oooooooooo`1Booooo`;o00001?ooool2
o`00093ooooo0_l0001Kooooo`007_ooool00ol0003oooooooooo`3Zooooo`;o0000Foooool001ko
oooo00?o0000ooooooooool0DOooool2o`0006Oooooo0_l0002;ooooo`007_ooool00ol0003ooooo
ooooo`1Aooooo`;o0000Ioooool2o`0004Cooooo0_l00015ooooo`007_ooool00ol0003ooooooooo
o`1Booooo`;o0000[?ooool2o`0004Gooooo000Nooooo`03o`000?oooooooooo05;ooooo0_l0003c
ooooo`007_ooool00ol0003oooooooooo`02ooooo`;o0000oooooolNooooo`;o00009?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool2o`00073ooooo0_l0002[ooooo`;o00009?ooool000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo07Cooooo0_l0003Aooooo`000oooool01Ol@413ooooooooooooooooo410@
00_ooooo1Ol00006ooooo`?o0000Coooool5o`000??ooooo0003ooooo`05o`000?oooooooooooooo
ool000002oooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo04oooooo1Ol0003c
ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001ooo
ool00ol0003oooooooooo`1Eooooo`;o0000l?ooool000?ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0EOooool2o`0004[ooooo0_l0
000@ooooo`;o0000T_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000000Oooooo00?o0000ooooooooool0DOooool2o`0004kooooo0_l0000@ooooo`;o0000N?oo
ool2o`0001Sooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`06ooooo`03o`000?oooooooooo057ooooo0_l0000hooooo`;o0000X?ooool2o`0001Sooooo000N
ooooo`03o`000?oooooooooo06[ooooo0_l0000Oooooo`;o0000??ooool2o`0007cooooo000Noooo
o`03o`000?oooooooooo06[ooooo0_l0001Mooooo`;o0000H?ooool2o`0001[ooooo000Nooooo`03
o`000?oooooooooo04kooooo0_l00002ooooo`;o0000IOooool2o`00073ooooo0_l0000Jooooo`00
7_ooool00ol0003oooooooooo`1>ooooo`;o00000_ooool2o`0006Gooooo0_l0002<ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo<?ooool2
o`0001Kooooo000Nooooo`03o`000?oooooooooo06?ooooo0_l0003:ooooo`;o00005_ooool001ko
oooo00?o0000ooooooooool0Hoooool2o`000<cooooo0ol0000=ooooo`;o00001?ooool001kooooo
00?o0000ooooooooool0F_ooool2o`000=Gooooo1?l0000<ooooo`;o00001?ooool001kooooo00?o
0000ooooooooool0?_ooool2o`0001[ooooo0_l0001Eooooo`;o0000Noooool2o`0000?ooooo0_l0
000Booooo`007_ooool00ol0003oooooooooo`0nooooo`;o0000LOooool2o`0007_ooooo0_l0000G
ooooo`007_ooool2o`0005gooooo0_l0003Yooooo`007_ooool00ol0003oooooooooo`1Gooooo`?o
00000_ooool2o`000=Wooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`1;ooooo`;o0000
2_ooool3o`000=gooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`1;ooooo`;o00003Ooo
ool2o`000:;ooooo0_l00017ooooo`007_ooool00ol0003oooooooooo`1Jooooo`;o0000X_ooool2
o`0003Kooooo0_l00002ooooo`;o00002oooool001kooooo00?o0000ooooooooool0oooooolgoooo
o`;o00000_ooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo04Gooooo0_l00032ooooo`;o
0000;oooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo04Gooooo0_l00032ooooo`;o0000
??ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooob[ooooo0_l0000Looooo`007_ooool00ol0003oooooooooo`1>ooooo`;o00003oooool2o`00
0<Sooooo0_l0000Eooooo`;o00001Oooool001gooooo0_l0001@ooooo`;o00003oooool2o`000:Oo
oooo0_l0000fooooo`;o00001Oooool001gooooo0_l0003oooooo`_ooooo0_l0000mooooo`007_oo
ool3o`0004Oooooo0_l00006ooooo`;o0000G_ooool2o`0009Kooooo000Nooooo`Go0000:Oooool2
o`0001[ooooo0ol00005ooooo`;o0000G_ooool2o`0009Kooooo000Nooooo`03o`000?oooooo0000
00;o0000:Oooool2o`0001_ooooo0_l00004ooooo`;o0000ioooool2o`0000kooooo000Nooooo`;o
0000Coooool2o`0000Sooooo0_l00022ooooo`;o0000FOooool2o`0000kooooo000Nooooo`03o`00
0?oooooooooo00;ooooo0ol00014ooooo`;o00002oooool4o`0003Sooooo0_l00018ooooo`;o0000
JOooool001kooooo00?o0000ooooooooool00_ooool3o`0004Cooooo0_l0000;ooooo`;o0000>_oo
ool2o`000;?ooooo000Nooooo`04o`000?oooooo0000o`0004Cooooo0_l0003oooooo`7ooooo000N
ooooo`04o`000?oooooo0000o`0004Cooooo0_l0000;ooooo`?o0000l_ooool001kooooo00?o0000
ooooooooool0AOooool2o`0000_ooooo0ol0003booooo`007_ooool00ol0003oooooooooo`0Koooo
o`;o0000:?ooool2o`0001_ooooo0_l0003Sooooo`007_ooool00ol0003oooooooooo`09ooooo`;o
00004?ooool2o`0002Sooooo0_l00005ooooo`;o00005?ooool2o`0000;ooooo0_l0003Oooooo`00
7_ooool00ol0003oooooooooo`09ooooo`;o00000_ooool2o`0003Kooooo0ol00004ooooo`;o0000
6?ooool2o`000=oooooo000Nooooo`03o`000?oooooooooo00cooooo0ol0000<ooooo`;o00001ooo
ool2o`00023ooooo0ol00003ooooo`;o0000Doooool2o`000:Cooooo000Nooooo`03o`000?oooooo
oooo00cooooo0_l00007ooooo`;o000000Coooooo`000?l0003ooooo0_l00007ooooo`;o00001_oo
ool2o`0001Wooooo0_l00003ooooo`;o00006Oooool3o`0003Oooooo0_l0002Tooooo`007_ooool0
0ol0003oooooooooo`0@ooooo`;o00000oooool5o`0001;ooooo0_l0000Dooooo`;o00005_ooool2
o`0000_ooooo0ol0003Mooooo`007_ooool00ol0003oooooooooo`04ooooo`;o00002_ooool2o`00
00?ooooo1Ol00007ooooo`;o00002oooool2o`0001;ooooo0_l0000Fooooo`;o00002Oooool2o`00
0>3ooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0000;ooooo`;o00001oooool2o`0000Go
oooo0_l0000;ooooo`;o0000=Oooool2o`000>3ooooo000Nooooo`03o`000?oooooooooo017ooooo
0_l00007ooooo`;o00009?ooool6o`0001gooooo0_l0000Pooooo`;o0000WOooool2o`00027ooooo
000Nooooo`03o`000?oooooooooo00Oooooo0_l0000gooooo`Ko00007Oooool2o`0001;ooooo0_l0
000<ooooo`;o0000WOooool2o`00027ooooo000Nooooo`;o00002?ooool2o`0003Oooooo0_l00000
0ooooooo0000o`00000booooo`;o0000/Oooool2o`0001;ooooo0_l00007ooooo`007_ooool00ol0
003oooooooooo`13ooooo`;o0000iOooool2o`0001;ooooo0_l00007ooooo`007_ooool00ol0003o
ooooooooo`0Zooooo`;o00005_ooool3o`000004ooooool0003o0000ooooo`;o0000o?ooool001ko
oooo00?o0000ooooooooool06Oooool2o`0000oooooo0_l0000Booooo`?o000000?oooooo`000?l0
00001ol000000ooooooo0000o`000005o`000;_ooooo0_l0000gooooo`007_ooool00ol0003ooooo
ooooo`0Iooooo`;o00008oooool3o`000003ooooool0003o000000Go00000_ooool:o`000003oooo
ool0003o000000Co00000_ooool2o`0000?ooooo0_l00005ooooo`Go0000Woooool2o`0002[ooooo
0_l0000;ooooo`007_ooool00ol0003oooooooooo`0mooooo`co00000_oooolEo`0000?ooooo0_l0
0005ooooo`Go0000boooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo03gooooo2?l0000:
ooooo`Oo000000?oooooo`000?l000000oooool7o`0000;ooooo0_l0003Pooooo`007_ooool00ol0
003oooooooooo`06ooooo`;o0000=?ooool8o`000003ooooool0003o000000Wooooo2Ol00003oooo
o`co00001?ooool2o`000=Wooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l0000Looooo`;o
00005_ooool5o`000004ooooool0003o0000ooooo`;o00001?ooool2o`0000Cooooo1ol00002oooo
o`;o00001_ooool6o`000004ooooool0003o0000ooooo`;o0000fOooool001kooooo00?o0000oooo
ooooool09?ooool2o`0001Kooooo1Ol000000ooooooo0000o`000003o`0000?ooooo0ol00005oooo
o`Ko000000?oooooo`000?l000003Ol000000ooooooo0000o`00002jooooo`;o00008?ooool001ko
oooo00?o0000ooooooooool0??ooool2o`000005ooooool0003o0000o`000?ooool00_l000000ooo
oooo0000o`000002ooooo`;o00002?oooolBo`0000Cooooo1?l0002gooooo`;o00008?ooool001ko
oooo00?o0000ooooooooool09oooool2o`0001Kooooo1Ol000001?oooooo0000o`000?l0000=oooo
o`Oo00000_ooool2o`000003ooooool0003o000000?o000000Coooooo`000?l0003ooooo1?l0003I
ooooo`007_ooool00ol0003oooooooooo`0Wooooo`;o00004oooool2o`0000Cooooo1Ol0000>oooo
o`;o00000_ooool4o`000003ooooool0003o000000Oooooo0_l000000ooooooo0000o`000002o`00
0=Wooooo000Nooooo`03o`000?oooooooooo03cooooo0_l00006ooooo`?o00005?ooool2o`0000go
oooo0_l0003Kooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`14ooooo`;o0000ooooool2oooo
o`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B401_ooool00ol0003oooooooooo`13ooooo`Co0000ooooool1ooooo`000oooool01Ol@
413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000@ooo
ool5o`0000Wooooo0_l0003dooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go
0000oiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo04Kooooo0_l00009ooooo`;o0000
0_ooool2o`000>Wooooo0_l00005ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo
00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo04Oooooo0_l0000<ooooo`;o
0000Ooooool2o`0006Sooooo0_l00005ooooo`000oooool01Ol@413ooooooooooooooooo410@00_o
oooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`16ooooo`?o0000SOooool2o`0006oo
oooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03
o`000?oooooooooo03_ooooo0_l00009ooooo`Co00002oooool2o`000?3ooooo0003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo
03_ooooo0_l0000;ooooo`?o00002_ooool2o`00017ooooo0_l0003Mooooo`007_ooool00ol0003o
ooooooooo`19ooooo`Co00002_ooool2o`0000oooooo0_l0003Mooooo`007_ooool00ol0003ooooo
ooooo`1;ooooo`;o00002_ooool2o`0000?ooooo0_l0000;ooooo`;o0000g?ooool001kooooo00?o
0000ooooooooool0F_ooool4o`0000_ooooo0_l0003Looooo`007_ooool00ol0003oooooooooo`0L
ooooo`;o00008?ooool2o`0000Oooooo0_l0000Aooooo`;o0000joooool001kooooo00?o0000oooo
ooooool07?ooool2o`00023ooooo0_l00007ooooo`;o00002?ooool2o`000;_ooooo0_l0000goooo
o`007_ooool00ol0003oooooooooo`11ooooo`?o00003?ooool3o`0009Wooooo0_l0000Pooooo`;o
0000=oooool001kooooo00?o0000ooooooooool0@Oooool3o`0000cooooo0_l0001booooo`;o0000
9_ooool2o`0005Wooooo000Nooooo`03o`000?oooooooooo05Gooooo0_l00008ooooo`;o00008ooo
ool2o`0003kooooo0_l0000Fooooo`;o0000JOooool001kooooo00?o0000ooooooooool0DOooool2
o`0000;ooooo0_l00008ooooo`;o00001oooool2o`0001[ooooo0_l0001Fooooo`;o0000JOooool0
01kooooo00?o0000ooooooooool0Coooool4o`0000kooooo0_l00005ooooo`;o0000W?ooool2o`00
03oooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0000hooooo`;o00002?ooool3o`0000Wo
oooo0_l00005ooooo`;o0000Xoooool2o`0003oooooo000Nooooo`;o00002oooool2o`0003Oooooo
0ol00008ooooo`;o00001Oooool2o`0000?ooooo0_l00007ooooo`;o0000>?ooool2o`0009cooooo
0_l0000:ooooo`007_ooool00ol0003oooooooooo`11ooooo`Co00004?ooool2o`0000Gooooo0_l0
0005ooooo`;o00001?ooool2o`0000kooooo0_l0000Rooooo`;o00000oooool2o`0009Oooooo0_l0
000:ooooo`007_ooool00ol0003oooooooooo`11ooooo`;o00006Oooool2o`0000_ooooo0_l0000>
ooooo`;o00009oooool2o`000:?ooooo000Nooooo`03o`000?oooooooooo047ooooo0_l0002Woooo
o`;o0000Foooool001kooooo00?o0000ooooooooool0:?ooool2o`0001gooooo0_l0000Looooo`;o
00005oooool2o`0006[ooooo0_l0001Kooooo`007_ooool00ol0003oooooooooo`0Xooooo`;o0000
6?ooool2o`0000?ooooo0_l0000Looooo`;o00005Oooool4o`000<Oooooo000Nooooo`03o`000?oo
oooooooo04;ooooo0_l0000?ooooo`;o00009oooool2o`0000Sooooo0_l0002oooooo`007_ooool0
0ol0003oooooooooo`1Cooooo`;o00002Oooool2o`0000Gooooo0_l0000Oooooo`;o0000_oooool0
01kooooo00?o0000ooooooooool07Oooool2o`0003gooooo1?l000000ooooooo0000o`000002oooo
o`?o00000oooool2o`000=[ooooo000Nooooo`03o`000?oooooooooo01gooooo0_l0000mooooo`;o
00000oooool2o`0000?ooooo0_l00003ooooo`;o0000G_ooool2o`0007[ooooo000Nooooo`03o`00
0?oooooooooo05?ooooo0ol00002ooooo`;o00002?ooool2o`0000;ooooo0_l0001Sooooo`;o0000
N_ooool001kooooo00?o0000ooooooooool0?oooool2o`0001;ooooo0ol00002ooooo`;o00002?oo
ool2o`0000;ooooo0_l00004ooooo`;o0000fOooool001kooooo00?o0000ooooooooool0?oooool2
o`0000oooooo0_l0000=ooooo`;o00002oooool2o`000=Wooooo000Nooooo`03o`000?oooooooooo
053ooooo0_l0000=ooooo`;o0000i_ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`14ooooo`;o00001Oooool2o`000?[ooooo000Nooooo`;o0000AOoo
ool2o`0000Gooooo0_l00003ooooo`;o00005_ooool2o`000=gooooo000Nooooo`03o`000?oooooo
oooo053ooooo0_l00007ooooo`;o00003Oooool2o`000=gooooo000Nooooo`03o`000?oooooooooo
04kooooo0_l00009ooooo`;o0000k?ooool001kooooo00?o0000ooooooooool0C_ooool2o`000?Oo
oooo000Nooooo`03o`000?oooooooooo06?ooooo0ol0001;ooooo`;o0000U?ooool001kooooo00?o
0000ooooooooool0Doooool2o`0000kooooo0ol0001;ooooo`;o0000F?ooool2o`0003[ooooo000N
ooooo`03o`000?oooooooooo05?ooooo0_l00005ooooo`;o0000XOooool2o`0000cooooo0_l0000j
ooooo`007_ooool00ol0003oooooooooo`1Jooooo`;o000000?oooooo`000?l00000W_ooool2o`00
04Sooooo000Nooooo`03o`000?oooooooooo04oooooo0_l00006ooooo`;o00001?ooool2o`000>So
oooo000Nooooo`03o`000?oooooooooo04oooooo0_l00006ooooo`;o00005_ooool2o`000=Kooooo
000Nooooo`03o`000?oooooooooo043ooooo0_l0000]ooooo`;o0000e_ooool001kooooo00?o0000
ooooooooool05Oooool2o`0002Wooooo0_l0000Qooooo`;o0000h_ooool001kooooo00?o0000oooo
ooooool05Oooool2o`0003cooooo0_l0000>ooooo`;o0000h_ooool001kooooo00?o0000oooooooo
ool0?Oooool2o`0001Cooooo0_l0000;ooooo`Co0000hoooool001kooooo00?o0000ooooooooool0
?Oooool2o`00027ooooo1?l00011ooooo`;o0000X?ooool001kooooo00?o0000ooooooooool0<ooo
ool2o`00017ooooo0_l00004ooooo`;o0000Eoooool2o`000:3ooooo000Nooooo`;o0000=?ooool2
o`00017ooooo0_l00004ooooo`;o0000nOooool001kooooo00?o0000ooooooooool0@?ooool2o`00
00Gooooo0_l00008ooooo`;o00002Oooool2o`0000;ooooo0_l0003Uooooo`007_ooool00ol0003o
ooooooooo`10ooooo`;o00001Oooool2o`0000Sooooo0_l00009ooooo`;o00000_ooool2o`0005Oo
oooo0_l0002<ooooo`007_ooool00ol0003oooooooooo`1Nooooo`;o0000FOooool2o`0008cooooo
000Nooooo`03o`000?oooooooooo03gooooo0_l00004ooooo`;o00005_ooool2o`000003ooooool0
003o00000>Oooooo000Nooooo`03o`000?oooooooooo03gooooo0_l00004ooooo`;o00005_ooool2
o`000>[ooooo000Nooooo`03o`000?oooooooooo0;Gooooo0_l0000Iooooo`;o0000MOooool001ko
oooo00?o0000ooooooooool0D?ooool2o`0000;ooooo0_l0001Oooooo`;o00006Oooool2o`0007Go
oooo000Nooooo`03o`000?oooooooooo043ooooo0_l0000>ooooo`;o00000_ooool2o`000?7ooooo
000Nooooo`03o`000?oooooooooo043ooooo0_l0000>ooooo`;o00000_ooool2o`0000_ooooo0_l0
0006ooooo`;o0000g?ooool001kooooo00?o0000ooooooooool0@Oooool2o`0000Sooooo0_l00003
ooooo`;o00003oooool2o`0000Kooooo0_l0003Looooo`007_ooool00ol0003oooooooooo`11oooo
o`;o00000oooool2o`0000?ooooo0_l0000?ooooo`;o0000jOooool001kooooo00?o0000oooooooo
ool0?_ooool2o`0000Kooooo0_l0000;ooooo`;o00001_ooool3o`000>Wooooo000Nooooo`03o`00
0?oooooooooo03kooooo0_l00006ooooo`;o00002oooool2o`0000Kooooo0_l00003ooooo`;o0000
iOooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Q
o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0@Oooool2o`0001gooooo0_l0003Uooooo`00
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRH
V?lQ8B401_ooool00ol0003oooooooooo`11ooooo`;o00002_ooool2o`000?Sooooo0003ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol00014
ooooo`;o00001oooool2o`0001;ooooo0_l0003Tooooo`000oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooooooo04Cooooo0_l0
000Dooooo`;o00001Oooool2o`000>Cooooo0003ooooo`05o`000?ooooooooooooooool000002ooo
ool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool07oooool2o`0003Wooooo
0_l0003[ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo
^[Zjoa0@4006ooooo`03o`000?oooooooooo01oooooo0_l0000Jooooo`;o0000ooooool;ooooo`00
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006oooo
o`03o`000?oooooooooo03_ooooo0_l0000?ooooo`;o00001?ooool2o`0000Gooooo0_l0003/oooo
o`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06
ooooo`03o`000?oooooooooo04cooooo0_l00004ooooo`;o00001?ooool3o`000>Gooooo0_l00005
ooooo`007Oooool2o`0004;ooooo1?l0000Dooooo`;o00001?ooool2o`0007Cooooo0_l0001Zoooo
o`;o00001Oooool001gooooo0_l00012ooooo`Co00006_ooool2o`0007Cooooo0_l0001aooooo`00
7_ooool00ol0003oooooooooo`1>ooooo`;o00001_ooool5o`0000Cooooo0_l0001Tooooo`;o0000
P?ooool001kooooo00?o0000ooooooooool0C_ooool2o`0000Kooooo1_l00002ooooo`?o0000I?oo
ool2o`00083ooooo000Nooooo`03o`000?oooooooooo05Oooooo1_l000000ooooooo0000o`00003W
ooooo`007_ooool00ol0003oooooooooo`1Dooooo`;o00000_ooool2o`000003ooooool0003o0000
07;ooooo0_l0001fooooo`007_ooool00ol0003oooooooooo`1@ooooo`;o00000_ooool2o`0000Ko
oooo0_l00003ooooo`;o0000K?ooool2o`0007Kooooo000Nooooo`03o`000?oooooooooo043ooooo
0ol0000=ooooo`Co00001?ooool2o`0000;ooooo0ol00002ooooo`;o0000i?ooool001kooooo00?o
0000ooooooooool0>_ooool2o`0000Cooooo0ol0000?ooooo`Co00000_ooool2o`0000?ooooo0ol0
003Wooooo`007_ooool00ol0003oooooooooo`0jooooo`;o00001?ooool4o`0000oooooo0ol00008
ooooo`;o0000ioooool001kooooo00?o0000ooooooooool0@_ooool2o`000003ooooool0003o0000
00cooooo0_l0000iooooo`;o0000]oooool001kooooo0_l00016ooooo`;o00006?ooool2o`0002go
oooo0_l0002gooooo`007_ooool00ol0003oooooooooo`0jooooo`;o00001?ooool2o`00013ooooo
0_l00002ooooo`;o00001oooool2o`000>Kooooo000Nooooo`03o`000?oooooooooo03[ooooo0_l0
0004ooooo`;o00004?ooool2o`0000;ooooo0_l00005ooooo`?o0000ioooool001kooooo00?o0000
ooooooooool0>_ooool2o`00017ooooo1?l0000:ooooo`Go0000ioooool001kooooo00?o0000oooo
ooooool01Oooool2o`0003kooooo0_l00006ooooo`Co00001oooool7o`000>Sooooo000Nooooo`03
o`000?oooooooooo00Gooooo0_l0000nooooo`Co00001?ooool2o`0000?ooooo0_l00004ooooo`Co
000000?oooooo`000?l00000j?ooool001kooooo00?o0000ooooooooool0Aoooool2o`0000Cooooo
0_l00003ooooo`;o00000oooool2o`000003ooooool0003o000000?o0000j?ooool001kooooo00?o
0000ooooooooool0>Oooool2o`0000kooooo0_l00009ooooo`;o000000?oooooo`000?l000000_oo
ool3o`000=Gooooo0_l0000Booooo`007_ooool00ol0003oooooooooo`0iooooo`;o00000oooool2
o`000003ooooool0003o000000;o00001?ooool2o`0000Wooooo1?l00003ooooo`?o0000eOooool2
o`0001;ooooo000Nooooo`03o`000?oooooooooo03kooooo0_l000000ooooooo0000o`000002o`00
00;ooooo0_l0000=ooooo`;o00000oooool3o`00027ooooo0_l00036ooooo`007_ooool00ol0003o
ooooooooo`17ooooo`;o000000?oooooo`000?l000000oooool3o`0000Wooooo0ol0000Qooooo`;o
0000a_ooool001kooooo00?o0000ooooooooool05?ooool2o`0002oooooo1?l000000ooooooo0000
o`000003ooooo`?o00002_ooool2o`000>Wooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0
000_ooooo`Co00002oooool3o`0000?ooooo0_l0001<ooooo`;o0000WOooool001kooooo00?o0000
ooooooooool0B?ooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool3o`0000?ooooo0_l0
001<ooooo`;o0000WOooool001kooooo00?o0000ooooooooool0B?ooool3o`0000?ooooo0_l00000
0ooooooo0000o`000002o`0000Cooooo0_l0003/ooooo`007_ooool00ol0003oooooooooo`12oooo
o`?o00001?ooool2o`0000Sooooo0_l00004ooooo`;o000000?oooooo`000?l00000jOooool001ko
oooo0_l00013ooooo`?o00005?ooool2o`000003ooooool0003o000000Cooooo0_l0003Sooooo`00
7_ooool00ol0003oooooooooo`0[ooooo`;o00005_ooool2o`0001Cooooo0_l000000ooooooo0000
o`000004ooooo`;o0000hoooool001kooooo00?o0000ooooooooool0:oooool2o`0001Kooooo0_l0
0003ooooo`Co00003?ooool3o`000003ooooool0003o0000047ooooo0_l0002Vooooo`007_ooool0
0ol0003oooooooooo`13ooooo`?o00000_ooool4o`0000cooooo1?l00013ooooo`;o0000Y_ooool0
01kooooo00?o0000ooooooooool0<_ooool2o`00013ooooo0_l00002ooooo`Co00000oooool2o`00
0004ooooool0003o0000ooooo`;o000000?oooooo`000?l000000_l0003[ooooo`007_ooool00ol0
003oooooooooo`0booooo`;o00001oooool2o`0000;ooooo0_l00009ooooo`;o00000oooool2o`00
0004ooooool0003o0000ooooo`;o00001Oooool2o`000=kooooo0_l00009ooooo`007_ooool00ol0
003oooooooooo`0Iooooo`;o00008?ooool7o`0001Wooooo0ol0002Eooooo`;o0000Aoooool2o`00
00Wooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l0000Rooooo`;o000000?oooooo`000?l0
00006Oooool3o`0000Kooooo0_l0000jooooo`;o0000DOooool2o`0005;ooooo000Nooooo`03o`00
0?oooooooooo03kooooo0_l0000Gooooo`;o00002oooool2o`0000Oooooo0_l0000aooooo`;o0000
YOooool001kooooo00?o0000ooooooooool0??ooool4o`0001Oooooo0_l00003ooooo`;o00003ooo
ool2o`000=Sooooo000Nooooo`03o`000?oooooooooo03cooooo0_l0000Iooooo`;o00000oooool2
o`000>Wooooo000Nooooo`03o`000?oooooooooo03[ooooo0_l0000Cooooo`;o00002?ooool3o`00
02Sooooo0_l00031ooooo`007_ooool00ol0003oooooooooo`0jooooo`;o00000_ooool2o`0000oo
oooo0_l00007ooooo`Co0000:?ooool2o`0009[ooooo0_l0000Uooooo`007_ooool00ol0003ooooo
ooooo`0nooooo`;o00003_ooool2o`0000Sooooo0_l00013ooooo`;o0000POooool2o`0002Gooooo
000Nooooo`03o`000?oooooooooo03_ooooo0_l0000:ooooo`Co00000oooool2o`0000Sooooo0_l0
0002ooooo`;o0000?oooool2o`000:Sooooo000Nooooo`03o`000?oooooooooo03_ooooo0_l0000:
ooooo`Co00003Oooool2o`000004ooooool0003o0000o`000>Wooooo000Nooooo`;o00005oooool2
o`00037ooooo0ol00002ooooo`;o00001_ooool2o`0000?ooooo0ol0003Yooooo`007_ooool00ol0
003oooooooooo`0Fooooo`;o0000<_ooool2o`0000;ooooo0_l00002ooooo`Ko00000oooool3o`00
0>Wooooo000Nooooo`03o`000?oooooooooo04;ooooo0_l00009ooooo`;o00000oooool5o`0000Co
oooo0_l0003Zooooo`007_ooool00ol0003oooooooooo`0Oooooo`?o00006oooool2o`0000?ooooo
0_l00009ooooo`;o00000oooool2o`000003ooooool0003o000000?ooooo0_l0003[ooooo`007_oo
ool00ol0003oooooooooo`0Oooooo`?o00001_ooool2o`0001?ooooo0_l00005ooooo`;o000000?o
ooooo`000?l000002Oooool3o`000003ooooool0003o000000;ooooo1?l0003Yooooo`007_ooool0
0ol0003oooooooooo`0=ooooo`;o00006Oooool2o`0001[ooooo0_l000000ooooooo0000o`00000:
ooooo`;o000000?oooooo`000?l000000oooool3o`000>Wooooo000Nooooo`03o`000?oooooooooo
00gooooo0_l0000`ooooo`;o00004_ooool2o`0000Cooooo0_l0003/ooooo`007_ooool00ol0003o
ooooooooo`0oooooo`;o00001oooool3o`0000;ooooo0ol00009ooooo`;o000000?oooooo`000?l0
00007Oooool2o`0003kooooo0_l0002:ooooo`007_ooool00ol0003oooooooooo`0cooooo`;o0000
4?ooool2o`000004ooooool0003o0000o`0000;ooooo0ol00009ooooo`;o000000?oooooo`000?l0
00007Oooool2o`0003kooooo0_l0002:ooooo`007_ooool00ol0003oooooooooo`0cooooo`;o0000
2_ooool4o`0000;ooooo0_l0003oooooo`7ooooo000Nooooo`03o`000?oooooooooo03oooooo1?l0
00001?oooooo0000o`000?l0000;ooooo`;o00002Oooool2o`000>Sooooo000Nooooo`03o`000?oo
oooooooo02_ooooo0_l0000Dooooo`;o000000Coooooo`000?l0003o00001Oooool2o`0000Cooooo
0_l00009ooooo`;o0000j?ooool001kooooo00?o0000ooooooooool0:oooool2o`0001Cooooo0_l0
0008ooooo`?o00001?ooool2o`0000;ooooo0_l0003_ooooo`007_ooool00ol0003oooooooooo`1;
ooooo`;o00001Oooool2o`0000;ooooo0_l0003_ooooo`005?ooool4o`000003oa0@4?oooooooooo
00?ooooo00?o0000ooooooooool0A?ooool2o`0000gooooo0_l0003booooo`005_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo04Cooooo0_l00006ooooo`;o00001Oooool2o`0000Go
oooo0_l0003[ooooo`005_ooool00ol0003oooooooooo`05ooooo`?o0000A_ooool2o`000004oooo
ool0003o0000ooooo`;o00003?ooool2o`000>_ooooo000Fooooo`03o`000?oooooooooo04kooooo
0_l000000ooooooo0000o`00003looooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000F
ooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@oooo
o`005?ooool00omEEEGoIVIVo`00003ooooooe;ooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000
\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.33078 .67288 Mdot
.93147 .38004 Mdot
.3502 .60401 Mdot
.33845 .90315 Mdot
.19912 .61112 Mdot
.27283 .91724 Mdot
.412 .12208 Mdot
.26562 .61071 Mdot
.23222 .92562 Mdot
.69595 .17915 Mdot
.28238 .04511 Mdot
.22892 .00976 Mdot
.28034 .58864 Mdot
.27838 .65443 Mdot
.31204 .8834 Mdot
.16736 .62732 Mdot
.87438 .54029 Mdot
.21608 .57037 Mdot
.32404 .57947 Mdot
.3197 .97439 Mdot
.05972 .53188 Mdot
.27365 .96194 Mdot
.16166 .5932 Mdot
.97466 .11719 Mdot
.24412 .87708 Mdot
.28737 .64051 Mdot
.3107 .82527 Mdot
.23568 .68775 Mdot
.27615 .0478 Mdot
.30015 .97424 Mdot
.28738 .56817 Mdot
.30253 .87935 Mdot
.2093 .97623 Mdot
.17542 .95209 Mdot
.15811 .53886 Mdot
.35164 .86792 Mdot
.29482 .66098 Mdot
.02234 .4555 Mdot
.18753 .84077 Mdot
.27294 .80245 Mdot
.30233 .57039 Mdot
.30086 .62367 Mdot
.32656 .92484 Mdot
.96418 .524 Mdot
.30171 .0716 Mdot
.31424 .68773 Mdot
.5231 .39225 Mdot
.35264 .8598 Mdot
.35488 .84478 Mdot
.2959 .43073 Mdot
.18508 .99489 Mdot
.17489 .54583 Mdot
.24277 .59404 Mdot
.35798 .8644 Mdot
.22565 .57819 Mdot
.28873 .22515 Mdot
.7618 .22568 Mdot
.26131 .59105 Mdot
.3165 .82771 Mdot
.21375 .61584 Mdot
.33314 .90564 Mdot
.27724 .63379 Mdot
.43628 .10627 Mdot
.23068 .90356 Mdot
.21978 .75024 Mdot
.25569 .95031 Mdot
.27311 .48607 Mdot
.31444 .82515 Mdot
.28687 .91978 Mdot
.81736 .2522 Mdot
.28773 .21022 Mdot
.16744 .56564 Mdot
.26653 .07946 Mdot
.29075 .13116 Mdot
.21908 .98834 Mdot
.10914 .27173 Mdot
.31396 .52886 Mdot
.58233 .1448 Mdot
.3019 .85358 Mdot
.20509 .49785 Mdot
.33482 .87666 Mdot
.53942 .18178 Mdot
.98545 .52926 Mdot
.27486 .61747 Mdot
.8191 .32777 Mdot
.17749 .17761 Mdot
.23864 .61721 Mdot
.34227 .8644 Mdot
.29702 .89759 Mdot
.1989 .57315 Mdot
.30099 .01058 Mdot
.84704 .24748 Mdot
.28948 .42087 Mdot
.29179 .17174 Mdot
.21598 .56988 Mdot
.31182 .77579 Mdot
.49144 .10847 Mdot
.16695 .54401 Mdot
.22289 .85051 Mdot
.1394 .52659 Mdot
.31623 .75372 Mdot
.17656 .97049 Mdot
.36044 .6213 Mdot
.22241 .64376 Mdot
.97772 .32186 Mdot
.16074 .59858 Mdot
.17372 .62013 Mdot
.17845 .63128 Mdot
.20444 .55103 Mdot
.53256 .14943 Mdot
.28954 .66539 Mdot
.99166 .43377 Mdot
.19573 .98828 Mdot
.24609 .56888 Mdot
.23946 .37676 Mdot
.43953 .12553 Mdot
.26568 .05902 Mdot
.29945 .59484 Mdot
.24849 .30698 Mdot
.25149 .93563 Mdot
.33344 .83184 Mdot
.33649 .74799 Mdot
.23812 .9802 Mdot
.29223 .17964 Mdot
.89704 .21861 Mdot
.09783 .52277 Mdot
.17742 .93659 Mdot
.30228 .61477 Mdot
.19037 .92227 Mdot
.23875 .05905 Mdot
.07807 .50359 Mdot
.25408 .23051 Mdot
.85619 .70841 Mdot
.17057 .5906 Mdot
.21448 .55967 Mdot
.23603 .52509 Mdot
.16609 .6003 Mdot
.17817 .57731 Mdot
.36265 .59786 Mdot
.25342 .93404 Mdot
.28565 .60126 Mdot
.22842 .90232 Mdot
.23933 .96621 Mdot
.21793 .56718 Mdot
.4598 .24834 Mdot
.22648 .00128 Mdot
.26042 .68248 Mdot
.29628 .77612 Mdot
.76197 .22696 Mdot
.50777 .16341 Mdot
.52762 .75727 Mdot
.22077 .97808 Mdot
.23684 .02592 Mdot
.31829 .99052 Mdot
.31831 .87267 Mdot
.29742 .60356 Mdot
.16124 .58264 Mdot
.76123 .26243 Mdot
.24405 .90088 Mdot
.15654 .615 Mdot
.16057 .56944 Mdot
.12789 .52738 Mdot
.94055 .9528 Mdot
.15762 .5968 Mdot
.22458 .82845 Mdot
.19809 .60739 Mdot
.28406 .7738 Mdot
.26862 .85708 Mdot
.51049 .14558 Mdot
.15883 .60851 Mdot
.2544 .98455 Mdot
.32334 .87723 Mdot
.12394 .53025 Mdot
.24411 .28089 Mdot
.3294 .64173 Mdot
.18538 .7085 Mdot
.05279 .92435 Mdot
.32196 .62508 Mdot
.46406 .12473 Mdot
.16338 .54481 Mdot
.33631 .9123 Mdot
.20511 9e-05 Mdot
.21714 .79852 Mdot
.33482 .08697 Mdot
.68802 .18664 Mdot
.1861 .91851 Mdot
.1521 .61172 Mdot
.30037 .988 Mdot
.80156 .71222 Mdot
.23489 .64879 Mdot
.31817 .63063 Mdot
.12736 .1686 Mdot
.30508 .63826 Mdot
.30632 .08973 Mdot
.22611 .93222 Mdot
.32079 .93836 Mdot
.15753 .53297 Mdot
.24321 .00327 Mdot
.22892 .93021 Mdot
.21846 .98453 Mdot
.37661 .10978 Mdot
.2678 .3644 Mdot
.1826 .57928 Mdot
.34736 .08333 Mdot
.24274 .88148 Mdot
.34242 .87037 Mdot
.47666 .15643 Mdot
.33665 .84949 Mdot
.85119 .30196 Mdot
.25396 .72129 Mdot
.16544 .61047 Mdot
.29206 .63853 Mdot
.92723 .22259 Mdot
.64345 .21804 Mdot
.16952 .57173 Mdot
.28207 .17938 Mdot
.26466 .78328 Mdot
.28647 .31308 Mdot
.19142 .69843 Mdot
.31071 .46965 Mdot
.76707 .23152 Mdot
.19465 .55955 Mdot
.22792 .89664 Mdot
.26915 .87433 Mdot
.19924 .56155 Mdot
.14529 .58694 Mdot
.26829 .95753 Mdot
.1905 .5622 Mdot
.67282 .18001 Mdot
.24251 .96407 Mdot
.30864 .62463 Mdot
.21046 .63745 Mdot
.23252 .96863 Mdot
.21023 .0567 Mdot
.28134 .17343 Mdot
.68721 .21245 Mdot
.67728 .48575 Mdot
.2946 .5771 Mdot
.03302 .48565 Mdot
.74488 .23154 Mdot
.33058 .58949 Mdot
.24091 .97087 Mdot
.34192 .90227 Mdot
.35965 .57807 Mdot
.19524 .82526 Mdot
.31888 .50247 Mdot
.17777 .56497 Mdot
.26748 .98517 Mdot
.56701 .19374 Mdot
.31308 .57937 Mdot
.17122 .53903 Mdot
.1995 .59216 Mdot
.80303 .24287 Mdot
.18764 .18908 Mdot
.89417 .21946 Mdot
.35861 .86055 Mdot
.22435 .59973 Mdot
.03209 .46329 Mdot
.27279 .74086 Mdot
.24181 .37052 Mdot
.30251 .67092 Mdot
.21719 .7244 Mdot
.28903 .18559 Mdot
.05953 .40577 Mdot
.23549 .96794 Mdot
.13279 .11799 Mdot
.18465 .96844 Mdot
.2358 .29441 Mdot
.29954 .58555 Mdot
.28874 .81657 Mdot
.22454 .84753 Mdot
.61 .39801 Mdot
.32145 .92466 Mdot
.19543 .73171 Mdot
.333 .89084 Mdot
.18159 .59869 Mdot
.18468 .68532 Mdot
.28792 .18169 Mdot
.35658 .86178 Mdot
.18252 .98963 Mdot
.78015 .2426 Mdot
.26927 .96958 Mdot
.14833 .60658 Mdot
.31519 .64203 Mdot
.20676 .60898 Mdot
.22885 .89629 Mdot
.16773 .60046 Mdot
.07357 .49977 Mdot
.35231 .77881 Mdot
.26986 .09746 Mdot
.35024 .89043 Mdot
.86018 .24754 Mdot
.31845 .57825 Mdot
.28826 .07032 Mdot
.49223 .1258 Mdot
.08512 .50999 Mdot
.24529 .74232 Mdot
.14846 .60647 Mdot
.77698 .25064 Mdot
.57971 .18441 Mdot
.06911 .49604 Mdot
.20329 .9173 Mdot
.17697 .54 Mdot
.16223 .57295 Mdot
.67223 .16364 Mdot
.22021 .52689 Mdot
.30455 .82735 Mdot
.3225 .85818 Mdot
.92511 .20044 Mdot
.26167 .35332 Mdot
.33635 .84096 Mdot
.77282 .25401 Mdot
.289 .6424 Mdot
.21298 .46241 Mdot
.22788 .799 Mdot
.36232 .79617 Mdot
.18789 .74119 Mdot
.24189 .27723 Mdot
.19843 .96425 Mdot
.0046 .35088 Mdot
.19095 .84594 Mdot
.21537 .98278 Mdot
.18769 .00308 Mdot
.23812 .77561 Mdot
.25394 .56623 Mdot
.31324 .61947 Mdot
.35633 .86073 Mdot
.29219 .66942 Mdot
.21384 .00637 Mdot
.29883 .63275 Mdot
.31359 .98422 Mdot
.27497 .93234 Mdot
.31345 .21695 Mdot
.94801 .16836 Mdot
.2819 .34409 Mdot
.26364 .37677 Mdot
.7248 .65152 Mdot
.31363 .81813 Mdot
.75748 .93586 Mdot
.13353 .10942 Mdot
.22853 .84554 Mdot
.73577 .62388 Mdot
.27797 .63117 Mdot
.16053 .57153 Mdot
.73162 .25154 Mdot
.27459 .55923 Mdot
.49661 .14738 Mdot
.2527 .24824 Mdot
.04213 .45379 Mdot
.25921 .60771 Mdot
.31003 .59491 Mdot
.21327 .59492 Mdot
.19796 .66199 Mdot
.21843 .65644 Mdot
.44823 .1345 Mdot
.32554 .91815 Mdot
.29088 .60638 Mdot
.16118 .589 Mdot
.26085 .5848 Mdot
.28967 .32287 Mdot
.26324 .97577 Mdot
.07399 .81686 Mdot
.29705 .56834 Mdot
.16492 .60916 Mdot
.21556 .91219 Mdot
.16955 .72461 Mdot
.43324 .94117 Mdot
.67273 .63194 Mdot
.72308 .21289 Mdot
.29425 .95425 Mdot
.17578 .56951 Mdot
.29247 .83091 Mdot
.33833 .59837 Mdot
.24291 .95394 Mdot
.31593 .91267 Mdot
.12496 .52111 Mdot
.31133 .07724 Mdot
.35118 .85363 Mdot
.95752 .19444 Mdot
.29667 .99628 Mdot
.29393 .86188 Mdot
.33667 .91728 Mdot
.7066 .19065 Mdot
.89104 .22053 Mdot
.22295 .70228 Mdot
.31459 .07603 Mdot
.46168 .90416 Mdot
.49908 .48437 Mdot
.3087 .81985 Mdot
.32546 .66825 Mdot
.28409 .59296 Mdot
.20516 .59293 Mdot
.34237 .74184 Mdot
.22373 .60155 Mdot
.20698 .60953 Mdot
.26692 .25148 Mdot
.87291 .61312 Mdot
.06505 .15455 Mdot
.32244 .83049 Mdot
.27175 .567 Mdot
.31138 .94993 Mdot
.28233 .03874 Mdot
.77599 .24998 Mdot
.27855 .62953 Mdot
.43708 .65339 Mdot
.23517 .95668 Mdot
.28018 .10328 Mdot
.19083 .56154 Mdot
.14437 .59406 Mdot
.15685 .59911 Mdot
.17972 .56995 Mdot
.25305 .87819 Mdot
.16772 .56814 Mdot
.39767 .11429 Mdot
.73278 .20962 Mdot
.1836 .58595 Mdot
.3659 .61693 Mdot
.14655 .58311 Mdot
.75836 .24218 Mdot
.30802 .853 Mdot
.27378 .82523 Mdot
.45497 .34606 Mdot
.6778 .21108 Mdot
.19561 .59224 Mdot
.26836 .59648 Mdot
.85289 .4635 Mdot
.32925 .11967 Mdot
.23554 .94611 Mdot
.16378 .56737 Mdot
.85829 .30273 Mdot
.74128 .22223 Mdot
.54522 .4081 Mdot
.2359 .46774 Mdot
.32926 .9377 Mdot
.79382 .24891 Mdot
.32462 .55145 Mdot
.20033 .68481 Mdot
.24074 .96968 Mdot
.37233 .59418 Mdot
.26751 .05617 Mdot
.19235 .95553 Mdot
.98021 .46419 Mdot
.96411 .55687 Mdot
.3276 .90958 Mdot
.27799 .29611 Mdot
.33462 .87802 Mdot
.20935 .98677 Mdot
.17956 .6116 Mdot
.84254 .24363 Mdot
.14506 .60132 Mdot
.05036 .63351 Mdot
.22959 .55636 Mdot
.23009 .85159 Mdot
.28394 .86336 Mdot
.26675 .06079 Mdot
.33251 .83838 Mdot
.24069 .89775 Mdot
.35545 .86573 Mdot
.20777 .95665 Mdot
.26277 .4416 Mdot
.36389 .73931 Mdot
.33985 .8677 Mdot
.28267 .87252 Mdot
.34537 .61217 Mdot
.98951 .18223 Mdot
.15273 .54139 Mdot
.21153 .98179 Mdot
.10781 .55171 Mdot
.3232 .9029 Mdot
.20838 .8062 Mdot
.29525 .96121 Mdot
.25081 .62298 Mdot
.27075 .61677 Mdot
.2727 .61684 Mdot
.36607 .60324 Mdot
.30126 .87058 Mdot
.30044 .57735 Mdot
.27553 .60476 Mdot
.76686 .22996 Mdot
.17795 .87791 Mdot
.57626 .1567 Mdot
.25353 .04783 Mdot
.25171 .9681 Mdot
.26972 .58963 Mdot
.31803 .66174 Mdot
.20411 .14207 Mdot
.25905 .14858 Mdot
.84588 .23946 Mdot
.32443 .90014 Mdot
.24318 .67663 Mdot
.31961 .5897 Mdot
.26258 .86202 Mdot
.29264 .23892 Mdot
.42933 .92423 Mdot
.31576 .03088 Mdot
.25231 .01002 Mdot
.35332 .57551 Mdot
.20607 .99159 Mdot
.0684 .23911 Mdot
.2055 .75733 Mdot
.34758 .54153 Mdot
.24175 .02518 Mdot
.32644 .86653 Mdot
.70044 .20777 Mdot
.19394 .58368 Mdot
.32087 .4491 Mdot
.26171 .62931 Mdot
.49012 .11962 Mdot
.2474 .88803 Mdot
.31108 .98717 Mdot
.24386 .57029 Mdot
.57014 .24799 Mdot
.27672 .2207 Mdot
.71268 .19316 Mdot
.20977 .61264 Mdot
.21156 .06359 Mdot
.35892 .8708 Mdot
.31557 .78543 Mdot
.73597 .34028 Mdot
.259 .56709 Mdot
.17069 .58006 Mdot
.36067 .6057 Mdot
.29686 .85796 Mdot
.227 .97947 Mdot
.19622 .61289 Mdot
.63483 .82342 Mdot
.30288 .23351 Mdot
.8376 .62963 Mdot
.17243 .54962 Mdot
.20868 .95875 Mdot
.0302 .03483 Mdot
.45549 .21843 Mdot
.20468 .6123 Mdot
.17891 .86675 Mdot
.27916 .61652 Mdot
.32276 .76148 Mdot
.2003 .76151 Mdot
.21002 .94287 Mdot
.99559 .43485 Mdot
.46237 .11939 Mdot
.25448 .93462 Mdot
.73586 .20693 Mdot
.22115 .99963 Mdot
.30895 .8676 Mdot
.33897 .70607 Mdot
.46939 .11113 Mdot
.84044 .24356 Mdot
.18216 .53753 Mdot
.15006 .60755 Mdot
.30943 .61892 Mdot
.45979 .15044 Mdot
.40466 .11171 Mdot
.20964 .96156 Mdot
.13818 .97134 Mdot
.34413 .88897 Mdot
.51393 .11848 Mdot
.83994 .24051 Mdot
.31765 .8118 Mdot
.3483 .89087 Mdot
.29768 .40768 Mdot
.15315 .60747 Mdot
.19328 .97089 Mdot
.00031 .43591 Mdot
.12551 .62896 Mdot
.17478 .5951 Mdot
.35738 .84545 Mdot
.1571 .57486 Mdot
.22695 .87659 Mdot
.55468 .3592 Mdot
.29278 .90062 Mdot
.51363 .43233 Mdot
.22662 .65193 Mdot
.29641 .87517 Mdot
.28073 .6745 Mdot
.22024 .58523 Mdot
.22833 .95825 Mdot
.2299 .98677 Mdot
.27702 .05039 Mdot
.19961 .58779 Mdot
.33628 .50962 Mdot
.59819 .07521 Mdot
.84136 .24963 Mdot
.35599 .59069 Mdot
.28335 .57888 Mdot
.9936 .45211 Mdot
.34615 .8694 Mdot
.19333 .92097 Mdot
.41122 .06309 Mdot
.327 .95192 Mdot
.2294 .63271 Mdot
.27393 .6007 Mdot
.25284 .56732 Mdot
.1508 .5816 Mdot
.2117 .98907 Mdot
.24734 .0172 Mdot
.29138 .64414 Mdot
.20229 .70398 Mdot
.30299 .62069 Mdot
.34946 .86364 Mdot
.15447 .58912 Mdot
.22641 .9674 Mdot
.2786 .83404 Mdot
.32653 .59633 Mdot
.16647 .54367 Mdot
.32019 .07286 Mdot
.15517 .59798 Mdot
.29329 .79286 Mdot
.28535 .97259 Mdot
.36422 .09593 Mdot
.31299 .66379 Mdot
.40146 .09446 Mdot
.49402 .12378 Mdot
.30076 .93303 Mdot
.26005 .2445 Mdot
.34834 .59035 Mdot
.1897 .65885 Mdot
.1673 .56576 Mdot
.23975 .18101 Mdot
.21373 .87826 Mdot
.57758 .19625 Mdot
.61563 .84079 Mdot
.35377 .36621 Mdot
.31013 .64406 Mdot
.12111 .21763 Mdot
.229 .5633 Mdot
.19525 .01151 Mdot
.08542 .03302 Mdot
.15669 .18265 Mdot
.20762 .56953 Mdot
.30247 .94362 Mdot
.36749 .60012 Mdot
.26596 .87512 Mdot
.22398 .63482 Mdot
.20533 .56787 Mdot
.29281 .87836 Mdot
.62107 .16866 Mdot
.27356 .61455 Mdot
.29319 .45251 Mdot
.1965 .60616 Mdot
.30878 .89261 Mdot
.27628 .02308 Mdot
.28347 .90705 Mdot
.29183 .58911 Mdot
.26501 .04039 Mdot
.32396 .04521 Mdot
.19752 .56136 Mdot
.17347 .95755 Mdot
.75463 .22546 Mdot
.28803 .62536 Mdot
.38431 .09682 Mdot
.93241 .07624 Mdot
.20437 .99705 Mdot
.01908 .87867 Mdot
.26894 .87878 Mdot
.84195 .24331 Mdot
.26931 .81526 Mdot
.2735 .59097 Mdot
.78394 .25722 Mdot
.84765 .29965 Mdot
.3276 .83425 Mdot
.28815 .0684 Mdot
.17218 .78366 Mdot
.64905 .19308 Mdot
.33912 .83288 Mdot
.126 .14022 Mdot
.16785 .89029 Mdot
.31575 .85422 Mdot
.44077 .12869 Mdot
.14402 .53134 Mdot
.10889 .868 Mdot
.2845 .13068 Mdot
.63165 .16855 Mdot
.31001 .1006 Mdot
.29912 .0109 Mdot
.73633 .22944 Mdot
.27994 .6396 Mdot
.78864 .19163 Mdot
.20239 .59063 Mdot
.52628 .17158 Mdot
.81959 .35192 Mdot
.9719 .413 Mdot
.22683 .57592 Mdot
.72627 .20508 Mdot
.3066 .61353 Mdot
.29226 .89884 Mdot
.08616 .51575 Mdot
.16573 .92304 Mdot
.50813 .1527 Mdot
.30271 .88849 Mdot
.24964 .57423 Mdot
.34582 .78439 Mdot
.3278 .07502 Mdot
.29382 .39186 Mdot
.45642 .39915 Mdot
.21977 .97598 Mdot
.1725 .77921 Mdot
.27945 .8724 Mdot
.44858 .23297 Mdot
.63179 .21266 Mdot
.96467 .21268 Mdot
.288 .31689 Mdot
.20172 .64599 Mdot
.29881 .60159 Mdot
.3625 .59749 Mdot
.26689 .18 Mdot
.22642 .9768 Mdot
.64326 .16791 Mdot
.03854 .25565 Mdot
.28586 .13819 Mdot
.22202 .94296 Mdot
.66378 .20873 Mdot
.18368 .63824 Mdot
.29614 .98956 Mdot
.74984 .24912 Mdot
.18458 .57979 Mdot
.85702 .44796 Mdot
.26105 .97791 Mdot
.23151 .60479 Mdot
.46298 .12846 Mdot
.25087 .97981 Mdot
.28894 .65559 Mdot
.25829 .11813 Mdot
.17134 .58123 Mdot
.37269 .41525 Mdot
.06899 .58003 Mdot
.81859 .26125 Mdot
.23533 .38935 Mdot
.33185 .82682 Mdot
.26596 .05658 Mdot
.75466 .22573 Mdot
.27971 .01369 Mdot
.27782 .00048 Mdot
.31699 .60768 Mdot
.24349 .92018 Mdot
.46185 .10304 Mdot
.43921 .52651 Mdot
.84853 .24362 Mdot
.84649 .23953 Mdot
.18274 .9825 Mdot
.83991 .28806 Mdot
.17016 .7866 Mdot
.33356 .92188 Mdot
.33725 .58387 Mdot
.53831 .99798 Mdot
.2153 .05993 Mdot
.17478 .9439 Mdot
.29892 .00088 Mdot
.76191 .22615 Mdot
.1916 .96444 Mdot
.042 .15868 Mdot
.32281 .92454 Mdot
.31857 .71697 Mdot
.28451 .07883 Mdot
.35427 .66987 Mdot
.18899 .56991 Mdot
.19667 .81593 Mdot
.16929 .60775 Mdot
.33518 .90183 Mdot
.29268 .58106 Mdot
.30876 .58201 Mdot
.79567 .26299 Mdot
.26432 .61277 Mdot
.8744 .32091 Mdot
.30096 .71953 Mdot
.28593 .08224 Mdot
.32974 .92333 Mdot
.17745 .54944 Mdot
.74747 .2166 Mdot
.241 .00116 Mdot
.87786 .32546 Mdot
.24127 .85171 Mdot
.36285 .85833 Mdot
.15324 .60473 Mdot
.1993 .59238 Mdot
.49237 .16092 Mdot
.27738 .57313 Mdot
.18184 .8609 Mdot
.3167 .58884 Mdot
.26848 .06265 Mdot
.25975 .15142 Mdot
.33785 .90658 Mdot
.21837 .90968 Mdot
.7577 .24518 Mdot
.22074 .01332 Mdot
.23372 .76118 Mdot
.16133 .59148 Mdot
.22067 .66251 Mdot
.25249 .9305 Mdot
.26345 .86373 Mdot
.31848 .61318 Mdot
.60122 .67569 Mdot
.72385 .21308 Mdot
.41712 .6504 Mdot
.30494 .63059 Mdot
.07243 .50571 Mdot
.26639 .58903 Mdot
.23882 .66773 Mdot
.57507 .63245 Mdot
.34388 .8978 Mdot
.18508 .55997 Mdot
.72675 .24456 Mdot
.29392 .97687 Mdot
.35274 .59135 Mdot
.20947 .99255 Mdot
.19023 .66331 Mdot
.1973 .57427 Mdot
.28243 .23394 Mdot
.28726 .30806 Mdot
.12555 .52334 Mdot
.18011 .57083 Mdot
.11219 .51769 Mdot
.34673 .8892 Mdot
.3581 .60664 Mdot
.57505 .8286 Mdot
.31885 .9504 Mdot
.28483 .83997 Mdot
.52513 .20512 Mdot
.7664 .23068 Mdot
.32098 .88182 Mdot
.44439 .12681 Mdot
.2746 .61468 Mdot
.28996 .61634 Mdot
.19466 .92784 Mdot
.29451 .60223 Mdot
.24792 .61639 Mdot
.17412 .57827 Mdot
.24336 .60023 Mdot
.22155 .85903 Mdot
.48509 .157 Mdot
.14678 .59895 Mdot
.26817 .05932 Mdot
.05803 .49509 Mdot
.23817 .57974 Mdot
.4742 .15795 Mdot
.32159 .65963 Mdot
.15587 .60575 Mdot
.606 .16055 Mdot
.3547 .84578 Mdot
.20627 .92939 Mdot
.50705 .16453 Mdot
.42131 .96441 Mdot
.29553 .61794 Mdot
.30837 .82826 Mdot
.24035 .92727 Mdot
.77414 .23688 Mdot
.39061 .11343 Mdot
.10992 .5323 Mdot
.32535 .6013 Mdot
.28682 .64339 Mdot
.31862 .7152 Mdot
.0175 .45548 Mdot
.19038 .62795 Mdot
.30781 .57259 Mdot
.27169 .45283 Mdot
.34142 .7996 Mdot
.96614 .24016 Mdot
.26886 .61328 Mdot
.25997 .28939 Mdot
.1751 .86375 Mdot
.29051 .73142 Mdot
.2897 .62223 Mdot
.33736 .89913 Mdot
.2208 .95044 Mdot
.63368 .18772 Mdot
.29525 .64105 Mdot
.20831 .99671 Mdot
.32491 .58012 Mdot
.18751 .67609 Mdot
.92043 .20742 Mdot
.28307 .60298 Mdot
.23183 .39821 Mdot
.34397 .78652 Mdot
.23796 .88215 Mdot
.36309 .76127 Mdot
.33202 .90362 Mdot
.22625 .61322 Mdot
.81236 .43686 Mdot
.96836 .41988 Mdot
.29613 .04343 Mdot
.20735 .55883 Mdot
.62216 .77018 Mdot
.32088 .95574 Mdot
.26743 .61624 Mdot
.3359 .60333 Mdot
.32292 .59151 Mdot
.32719 .66638 Mdot
.35167 .67486 Mdot
.75541 .22946 Mdot
.27067 .9643 Mdot
.27751 .9126 Mdot
.69702 .19948 Mdot
.29102 .1899 Mdot
.2972 .51376 Mdot
.26338 .97041 Mdot
.57971 .16598 Mdot
.24875 .75075 Mdot
.79578 .27741 Mdot
.31678 .90727 Mdot
.44976 .74526 Mdot
.18272 .8495 Mdot
.21278 .55912 Mdot
.17805 .96828 Mdot
.48162 .35189 Mdot
.36254 .68812 Mdot
.43569 .13657 Mdot
.38402 .50599 Mdot
.2152 .01236 Mdot
.18358 .73103 Mdot
.3115 .57596 Mdot
.26818 .63478 Mdot
.16537 .92563 Mdot
.25299 .90723 Mdot
.28658 .25981 Mdot
.21373 .94605 Mdot
.16916 .82131 Mdot
.24076 .37525 Mdot
.07 .81404 Mdot
.51471 .77188 Mdot
.32195 .80814 Mdot
.23726 .93447 Mdot
.68299 .21231 Mdot
.30688 .40004 Mdot
.25381 .45126 Mdot
.2879 .62578 Mdot
.30659 .88485 Mdot
.03404 .46647 Mdot
.68489 .18225 Mdot
.26947 .06375 Mdot
.983 .43852 Mdot
.84856 .30081 Mdot
.33655 .64609 Mdot
.16694 .60252 Mdot
.282 .6061 Mdot
.23476 .96788 Mdot
.08581 .1678 Mdot
.29482 .60726 Mdot
.74511 .24845 Mdot
.27265 .9955 Mdot
.31772 .85013 Mdot
.12788 .01829 Mdot
.28304 .59805 Mdot
.34732 .59269 Mdot
.24548 .86572 Mdot
.47633 .11439 Mdot
.33306 .50725 Mdot
.27893 .8996 Mdot
.28274 .09886 Mdot
.31867 .47134 Mdot
.25229 .92744 Mdot
.60592 .15963 Mdot
.30559 .91714 Mdot
.78045 .25827 Mdot
.29157 .58487 Mdot
.64749 .5971 Mdot
.49857 .71214 Mdot
.33777 .60559 Mdot
.67404 .20969 Mdot
.05257 .49031 Mdot
.4484 .10228 Mdot
.90738 .20492 Mdot
.27971 .96795 Mdot
.28002 .85995 Mdot
.31956 .88368 Mdot
.2029 .61252 Mdot
.30388 .62263 Mdot
.47013 .13649 Mdot
.18108 .60205 Mdot
.1443 .58862 Mdot
.82152 .27207 Mdot
.51569 .14685 Mdot
.29096 .2312 Mdot
.80907 .18197 Mdot
.99948 .1696 Mdot
.46834 .11999 Mdot
.60767 .20372 Mdot
.26506 .63004 Mdot
.14519 .60645 Mdot
.4887 .22253 Mdot
.30858 .834 Mdot
.34063 .78396 Mdot
.23344 .59583 Mdot
.19781 .55807 Mdot
.28665 .35709 Mdot
.14801 .61127 Mdot
.3008 .00402 Mdot
.23816 .56036 Mdot
.26328 .05131 Mdot
.53754 .17253 Mdot
.19727 .5531 Mdot
.31872 .79118 Mdot
.04641 .54155 Mdot
.33953 .90274 Mdot
.25612 .04295 Mdot
.53913 .29422 Mdot
.20755 .92206 Mdot
.3338 .82625 Mdot
.33127 .73774 Mdot
.299 .40701 Mdot
.14249 .5963 Mdot
.25605 .99845 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wo
oooo0_l00003ooooo`?o00001Oooool2o`0000;ooooo0ol000000ooooooo0000ooooo`06ooooo`;o
00001Oooool3o`0000kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`00
7_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`09ooooo`;o00000oooool00ol0003oooooooooo`02o`0000Sooooo
0_l000000ooooooo0000ooooo`0>ooooo`;o00003_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00;ooooo000Nooooo`03o`000?oooooooooo047ooooo0_l00003ooooo`;o00001_oo
ool2o`0000kooooo0_l0003Wooooo`007_ooool00ol0003oooooooooo`0kooooo`;o00001Oooool6
o`0000Kooooo0_l00007ooooo`;o00001?ooool3o`000>Oooooo000Nooooo`03o`000?oooooooooo
03_ooooo0_l00005ooooo`Co00004Oooool2o`0000Cooooo0_l0003Xooooo`007_ooool00ol0003o
ooooooooo`0Uooooo`;o00009Oooool2o`000?Wooooo000Nooooo`03o`000?oooooooooo02Gooooo
0_l0000Uooooo`;o0000nOooool001kooooo00?o0000ooooooooool0BOooool3o`0000[ooooo0_l0
003_ooooo`007_ooool00ol0003oooooooooo`19ooooo`?o00002_ooool2o`000>oooooo000Noooo
o`03o`000?oooooooooo06?ooooo0_l0003Rooooo`007_ooool00ol0003oooooooooo`06ooooo`;o
00004?ooool2o`0004Wooooo0_l0003Rooooo`007_ooool00ol0003oooooooooo`06ooooo`;o0000
4?ooool2o`000?oooooo;_ooool001kooooo00?o0000ooooooooool0D_ooool2o`0000Cooooo0_l0
003]ooooo`007_ooool00ol0003oooooooooo`1?ooooo`;o000000?oooooo`000?l000001?ooool2
o`0000;ooooo0_l0003Yooooo`007_ooool00ol0003oooooooooo`1?ooooo`;o00001oooool2o`00
00;ooooo0_l00007ooooo`;o0000h?ooool001kooooo00?o0000ooooooooool0C_ooool2o`0000Ko
oooo1?l0000;ooooo`;o0000h?ooool001kooooo0_l0001?ooooo`;o000000?oooooo`000?l00000
0oooool2o`000>oooooo000Nooooo`03o`000?oooooooooo043ooooo0_l0000?ooooo`Co0000l_oo
ool001kooooo00?o0000ooooooooool0@?ooool2o`0000Sooooo0_l00006ooooo`?o0000l_ooool0
01kooooo00?o0000ooooooooool0@_ooool2o`0000Kooooo0_l00006ooooo`?o0000l_ooool001ko
oooo00?o0000ooooooooool0@Oooool3o`0000oooooo0_l0000]ooooo`;o0000`oooool001kooooo
00?o0000ooooooooool0@Oooool2o`00013ooooo0_l00005ooooo`;o00009_ooool2o`000<?ooooo
000Nooooo`03o`000?oooooooooo05[ooooo0_l00002ooooo`;o0000ioooool001kooooo00?o0000
ooooooooool0F_ooool2o`0000;ooooo0_l00004ooooo`Co0000E_ooool2o`0008Oooooo000Noooo
o`03o`000?oooooooooo067ooooo1ol0001Fooooo`;o0000Joooool2o`0001[ooooo000Nooooo`03
o`000?oooooooooo05?ooooo0_l00003ooooo`;o00001oooool3o`000<Oooooo0_l0000Jooooo`00
7_ooool00ol0003oooooooooo`1Cooooo`;o00000oooool3o`0001;ooooo0_l0003Hooooo`007_oo
ool00ol0003oooooooooo`1Iooooo`;o00003_ooool2o`0000;ooooo0_l0003Hooooo`007_ooool0
0ol0003oooooooooo`1Oooooo`;o00002?ooool2o`000=cooooo000Nooooo`03o`000?oooooooooo
05oooooo0_l0003Vooooo`007_ooool00ol0003oooooooooo`1booooo`;o00002_ooool2o`000<Oo
oooo000Nooooo`03o`000?oooooooooo05Cooooo0_l00002ooooo`;o00006?ooool2o`0000Gooooo
0_l00003ooooo`;o0000aoooool001kooooo0_l0001Eooooo`;o00000_ooool2o`0000Oooooo0_l0
000Fooooo`;o00004oooool2o`000;Oooooo000Nooooo`03o`000?oooooooooo05Oooooo0_l00008
ooooo`;o0000:oooool2o`0000;ooooo0_l0002cooooo`007_ooool00ol0003oooooooooo`1Goooo
o`;o0000<Oooool2o`0000Kooooo0_l00008ooooo`;o0000ZOooool001kooooo00?o0000oooooooo
ool09oooool2o`0004gooooo0_l00007ooooo`;o00002Oooool2o`0000Sooooo0_l00006ooooo`;o
0000ZOooool001kooooo00?o0000ooooooooool09oooool2o`0004gooooo0_l00003ooooo`Ko0000
4oooool2o`000003ooooool0003o00000:kooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l0
000Wooooo`;o0000:Oooool4o`0001Sooooo0_l0002Pooooo`;o00003?ooool001kooooo00?o0000
ooooooooool09oooool2o`0002Oooooo0_l0000Eooooo`;o0000:Oooool4o`0000Gooooo0_l00006
ooooo`;o0000U?ooool2o`0000cooooo000Nooooo`03o`000?oooooooooo06Oooooo0_l0000Ioooo
o`;o00003_ooool4o`0000Gooooo0ol00005ooooo`;o0000X_ooool001kooooo00?o0000oooooooo
ool0P_ooool2o`0000Oooooo0ol00005ooooo`;o00001oooool2o`000:Wooooo000Nooooo`03o`00
0?oooooooooo08_ooooo0ol00004ooooo`?o00001oooool2o`000:Wooooo000Nooooo`03o`000?oo
oooooooo05Sooooo1?l0000_ooooo`;o00001Oooool2o`000;?ooooo000Nooooo`03o`000?oooooo
oooo05Sooooo1?l0000^ooooo`;o00000_ooool2o`0000Gooooo0_l0002`ooooo`007_ooool00ol0
003oooooooooo`1Iooooo`;o0000;oooool2o`0000;ooooo0_l00005ooooo`;o0000/?ooool001ko
oooo00?o0000ooooooooool09Oooool2o`0001Oooooo0_l0000Iooooo`;o0000k?ooool001kooooo
00?o0000ooooooooool09Oooool2o`0001Oooooo0_l0001Rooooo`;o00005Oooool2o`0008cooooo
000Nooooo`03o`000?oooooooooo053ooooo0_l0001;ooooo`;o00000oooool4o`0001?ooooo0_l0
002<ooooo`007_ooool2o`00057ooooo0_l0000oooooo`;o00002_ooool2o`0000Gooooo0_l00003
ooooo`;o0000W?ooool001kooooo00?o0000ooooooooool04Oooool2o`0003gooooo0_l0000ooooo
o`;o00003_ooool2o`0000Kooooo0_l0002Looooo`007_ooool00ol0003oooooooooo`0Aooooo`;o
0000Poooool3o`000003ooooool0003o000000Gooooo0_l0000Dooooo`;o0000S_ooool001kooooo
00?o0000ooooooooool02_ooool2o`0008[ooooo0ol000000ooooooo0000o`000002o`0001Wooooo
0_l00008ooooo`;o0000Q?ooool001kooooo00?o0000ooooooooool02_ooool2o`00093ooooo0_l0
0003ooooo`;o00007_ooool2o`0001?ooooo0_l0001_ooooo`007_ooool00ol0003oooooooooo`2Q
ooooo`;o00005Oooool2o`0001cooooo0_l0001_ooooo`007_ooool00ol0003oooooooooo`0Hoooo
o`;o00002oooool2o`0007[ooooo0_l0000Eooooo`;o00003?ooool2o`000003ooooool0003o0000
00;ooooo0_l0001Qooooo`;o00003oooool2o`0000Cooooo000Nooooo`03o`000?oooooooooo01So
oooo0_l0000;ooooo`;o0000<?ooool2o`0000;ooooo0_l0001:ooooo`;o00000_ooool2o`0001Wo
oooo0_l000000ooooooo0000o`000002ooooo`;o0000HOooool2o`0000oooooo0_l00004ooooo`00
7_ooool00ol0003oooooooooo`1Gooooo`;o00000_ooool2o`0004[ooooo0_l00002ooooo`;o0000
V_ooool001kooooo00?o0000ooooooooool0=_ooool2o`00023ooooo0_l000000ooooooo0000o`00
0021ooooo`;o0000Ioooool001kooooo00?o0000ooooooooool0;oooool2o`0000Gooooo0_l0000B
ooooo`;o00001oooool2o`0000?ooooo1Ol0001>ooooo`;o0000:_ooool2o`0000;ooooo0_l00000
0ooooooo0000o`00000Sooooo`;o0000>Oooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo
02oooooo0_l0000Iooooo`;o00001oooool2o`0000Cooooo0ol0001?ooooo`;o00002oooool2o`00
01gooooo0_l00002ooooo`;o00009_ooool2o`0003Wooooo0_l00007ooooo`007_ooool00ol0003o
ooooooooo`1Jooooo`;o0000G?ooool2o`00013ooooo0_l0000@ooooo`;o0000JOooool001kooooo
00?o0000ooooooooool0>Oooool2o`0001oooooo0_l0001^ooooo`;o00004?ooool2o`0000Cooooo
0_l0000Hooooo`;o0000BOooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0>Oooool2o`0001oooooo0_l0001Hooooo`;o0000
6Oooool2o`00017ooooo1?l0000Fooooo`;o0000=Oooool2o`0001;ooooo0003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03
o`000?oooooooooo0;Cooooo0_l00002ooooo`;o00005Oooool2o`0001?ooooo0_l0001=ooooo`;o
00004_ooool000?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo0ol0002hooooo`;o00009?ooool2o`0004Wooooo0_l0000Looooo`000oooool01Ol0003ooooo
oooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`31ooooo`;o
00006oooool2o`0004Wooooo0_l0000Looooo`000oooool01Ol0003ooooooooooooooooo000000ko
oooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`2Wooooo`;o00006?ooool2o`0002Go
oooo0_l000000ooooooo0000o`00000fooooo`;o00000_ooool2o`0001kooooo0003ooooo`05oa0@
4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Wo
oooo0_l0001<ooooo`;o0000:oooool2o`000003ooooool0003o000000Oooooo0_l00006ooooo`Go
0000=_ooool2o`0000;ooooo0_l0000Nooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo05Wooooo0_l0001^oooo
o`;o00002Oooool2o`000003ooooool0003o000000Co00000oooool2o`0000Gooooo0_l000000ooo
oooo0000o`00001:ooooo`;o00003oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`39ooooo`;o00003Oooool5
o`0000[ooooo0_l00006ooooo`;o0000AOooool2o`0000oooooo000Nooooo`03o`000?oooooooooo
02?ooooo0_l0000mooooo`;o0000;?ooool2o`0003_ooooo0_l0000Pooooo`;o0000;_ooool3o`00
02Gooooo000Nooooo`03o`000?oooooooooo02?ooooo0_l0000aooooo`;o00002_ooool2o`0002co
oooo0_l00009ooooo`;o0000<?ooool2o`0001kooooo0_l0000_ooooo`Co00001oooool2o`0001co
oooo000Nooooo`03o`000?oooooooooo05Kooooo0_l00002ooooo`;o0000?oooool2o`00053ooooo
0_l00002ooooo`;o000000?oooooo`000?l00000:?ooool2o`0000Wooooo0_l0000Looooo`007_oo
ool00ol0003oooooooooo`1Jooooo`;o0000UOooool2o`000003ooooool0003o0000057ooooo000N
ooooo`03o`000?oooooooooo04kooooo0_l0000:ooooo`;o0000Soooool2o`000004ooooool0003o
0000ooooo`;o000000Coooooo`000?l0003o0000D?ooool001kooooo00?o0000ooooooooool0C_oo
ool2o`0000Sooooo1?l00002ooooo`;o0000;_ooool2o`0005_ooooo0_l000001?oooooo0000o`00
0?ooool2o`0000;ooooo0_l0001@ooooo`007_ooool00ol0003oooooooooo`1Hooooo`;o00001?oo
ool2o`0002kooooo0_l0001Xooooo`;o0000COooool001kooooo00?o0000ooooooooool04_ooool2
o`0004Oooooo0_l0002Kooooo`;o00004oooool4o`0002Gooooo0_l0000?ooooo`007_ooool00ol0
003oooooooooo`0Booooo`;o0000Aoooool2o`0009Gooooo0_l00006ooooo`;o00001Oooool2o`00
00[ooooo1Ol0000Tooooo`;o00003oooool001kooooo00?o0000ooooooooool0D?ooool2o`0009Ko
oooo0_l00008ooooo`;o00001_ooool2o`0000Gooooo0_l0000:ooooo`Go0000=Oooool001kooooo
00?o0000ooooooooool0C_ooool4o`0003oooooo0_l0000Rooooo`;o0000<Oooool2o`0000Cooooo
1_l00004ooooo`;o00001?ooool2o`0000gooooo1?l00003ooooo`;o0000<Oooool001kooooo0_l0
001?ooooo`;o00000oooool2o`0003cooooo0_l0000Rooooo`;o0000<oooool2o`0000;ooooo1?l0
0006ooooo`;o00001?ooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`00037ooooo000N
ooooo`03o`000?oooooooooo00Sooooo0_l00019ooooo`;o0000UOooool2o`0000_ooooo0ol0000<
ooooo`;o0000?oooool001kooooo00?o0000ooooooooool02?ooool2o`000>gooooo0_l000001?oo
oooo0000o`000?l0001:ooooo`007_ooool00ol0003oooooooooo`1Iooooo`;o0000V?ooool2o`00
00Gooooo0ol00009ooooo`;o0000?oooool001kooooo00?o0000ooooooooool0FOooool2o`0009So
oooo0_l0000:ooooo`;o00001Oooool2o`0003oooooo000Nooooo`03o`000?oooooooooo0?oooooo
0_l00016ooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o0000i_ooool2o`0003kooooo000N
ooooo`03o`000?oooooooooo01oooooo0_l0003Vooooo`;o0000?_ooool001kooooo00?o0000oooo
ooooool0Boooool2o`000;;ooooo0_l00016ooooo`007_ooool00ol0003oooooooooo`1;ooooo`;o
0000/_ooool2o`0004Kooooo000Nooooo`03o`000?oooooooooo04_ooooo0_l0003jooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo053ooooo0_l0002k
ooooo`;o0000>?ooool001kooooo00?o0000ooooooooool0D?ooool2o`000;_ooooo0_l0000hoooo
o`007_ooool00ol0003oooooooooo`19ooooo`;o00002oooool2o`0005?ooooo0_l0002Jooooo`00
7_ooool00ol0003oooooooooo`19ooooo`;o00002oooool2o`0005?ooooo0_l0001Rooooo`;o0000
=_ooool001kooooo0_l0003ooooooa7ooooo1_l0000booooo`007_ooool00ol0003oooooooooo`3o
oooooa7ooooo1Ol0000booooo`007_ooool00ol0003oooooooooo`1=ooooo`;o00002_ooool2o`00
0>cooooo000Nooooo`03o`000?oooooooooo04gooooo0_l0000:ooooo`;o0000k?ooool001kooooo
00?o0000ooooooooool0FOooool2o`000>cooooo000Nooooo`03o`000?oooooooooo05Wooooo0ol0
003[ooooo`007_ooool00ol0003oooooooooo`1Jooooo`;o0000_?ooool2o`0002gooooo000Noooo
o`03o`000?oooooooooo05[ooooo0_l0002looooo`;o00008?ooool2o`0000_ooooo000Nooooo`03
o`000?oooooooooo05[ooooo0_l0002mooooo`;o00007oooool2o`0000_ooooo000Nooooo`03o`00
0?oooooooooo0?oooooo1oooool2o`00017ooooo0_l0000/ooooo`007_ooool00ol0003ooooooooo
o`3oooooo`Oooooo0_l0000oooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0joooool2o`0005[o
oooo000Nooooo`03o`000?oooooooooo05Sooooo0_l0002Aooooo`;o0000F_ooool001kooooo00?o
0000ooooooooool0F?ooool2o`0003Kooooo0_l0002eooooo`007_ooool2o`00097ooooo0_l00006
ooooo`;o0000K?ooool2o`0003oooooo000Nooooo`;o0000D_ooool2o`0004Gooooo0_l0001/oooo
o`;o0000?oooool001kooooo00?o0000ooooooooool0DOooool2o`0000Kooooo0_l0003/ooooo`00
7_ooool00ol0003oooooooooo`1Iooooo`;o0000EOooool2o`0009Gooooo000Nooooo`03o`000?oo
oooooooo0;3ooooo0_l0002Eooooo`007_ooool00ol0003oooooooooo`1Cooooo`;o00006_ooool2
o`000=Kooooo000Nooooo`03o`000?oooooooooo04[ooooo0_l00007ooooo`;o00006_ooool2o`00
0=Kooooo000Nooooo`03o`000?oooooooooo04[ooooo0_l0003kooooo`007_ooool00ol0003ooooo
ooooo`1:ooooo`;o0000noooool001kooooo00?o0000ooooooooool0B_ooool2o`0000Kooooo0_l0
003cooooo`007_ooool00ol0003oooooooooo`1:ooooo`;o00001_ooool2o`000=Oooooo0_l0000J
ooooo`007_ooool00ol0003oooooooooo`3oooooobcooooo0_l0000Jooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo04Sooooo0_l0000Aooooo`;o0000
j_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@
4?oooooooooo00Cooooo00?o0000ooooooooool0B?ooool2o`00017ooooo0_l00019ooooo`;o0000
Woooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo04Oooooo0_l0001Mooooo`;o00006_ooool2o`0008?ooooo
0003ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol00017ooooo`;o0000
5oooool2o`0002kooooo0_l0000`ooooo`;o0000Poooool000?ooooo00Go0000oooooooooooooooo
o`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0H?ooool2o`0002ko
oooo0_l0002eooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoo
oooo00001oooool00ol0003oooooooooo`0?ooooo`;o0000C?ooool2o`000>Sooooo0003ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo
00oooooo0_l0001<ooooo`;o0000C_ooool2o`0009Sooooo0003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo05gooooo0_l0001>oooo
o`;o0000ROooool2o`0000gooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omg
MgOo0000ooooo`06ooooo`03o`000?oooooooooo07Gooooo0_l00031ooooo`;o00003Oooool001ko
oooo00?o0000ooooooooool0MOooool2o`000=3ooooo000Nooooo`03o`000?oooooooooo05[ooooo
0_l0003Kooooo`;o00003_ooool001kooooo00?o0000ooooooooool0F_ooool2o`000=_ooooo0_l0
000>ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
05cooooo0_l0003Yooooo`007_ooool00ol0003oooooooooo`1Looooo`;o0000AOooool2o`0009Wo
oooo1?l00005ooooo`007Oooool2o`000:Gooooo0_l0001Oooooo`;o0000>?ooool4o`0000Gooooo
000Mooooo`;o0000ooooool7ooooo`;o0000=Oooool2o`0000[ooooo000Nooooo`03o`000?oooooo
oooo057ooooo0_l0003Xooooo`;o00002_ooool001kooooo00?o0000ooooooooool0DOooool2o`00
0?Cooooo000Nooooo`03o`000?oooooooooo06Cooooo0_l0002]ooooo`;o0000<_ooool001kooooo
0_l0001?ooooo`;o00001?ooool2o`0000Gooooo0_l00007ooooo`;o0000[Oooool2o`0002[ooooo
0_l00006ooooo`007_ooool00ol0003oooooooooo`02ooooo`?o00001Oooool2o`0004;ooooo0_l0
0004ooooo`;o00001Oooool2o`000>;ooooo0_l00006ooooo`007_ooool00ol0003oooooooooo`02
ooooo`?o00001Oooool2o`000?oooooo??ooool001kooooo00?o0000ooooooooool0@Oooool2o`00
0?oooooo1Oooool001kooooo00?o0000ooooooooool01_ooool2o`0003Wooooo0_l0003>ooooo`;o
0000:?ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00Kooooo0ol00010ooooo`;o0000
a_ooool2o`0002Sooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`07ooooo`;o0000@?oo
ool2o`0001Kooooo1?l0003Rooooo`007_ooool00ol0003oooooooooo`1Qooooo`Co0000h_ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool01ooo
ool2o`0004cooooo0_l00017ooooo`;o0000>?ooool2o`0006gooooo000Nooooo`03o`000?oooooo
oooo00Oooooo0_l00004ooooo`;o0000A_ooool2o`0004Oooooo0_l0000hooooo`;o0000KOooool0
01kooooo00?o0000ooooooooool03Oooool2o`000?oooooo>Oooool001kooooo00?o0000oooooooo
ool03oooool2o`000003ooooool0003o00000?oooooo=?ooool001kooooo00?o0000ooooooooool0
3oooool2o`000003ooooool0003o000002_ooooo0_l0003oooooo`Oooooo000Nooooo`;o00005Ooo
ool2o`0002Wooooo0_l0000Sooooo`;o0000hOooool001kooooo00?o0000ooooooooool04oooool4
o`0004gooooo0_l0003Qooooo`007_ooool00ol0003oooooooooo`0Cooooo`Co0000DOooool2o`00
00oooooo0_l0003<ooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o0000C_ooool3o`0000ko
oooo0_l0003<ooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o0000@oooool2o`0000[ooooo
0_l0003Looooo`007_ooool00ol0003oooooooooo`0Hooooo`;o00001_ooool2o`0003_ooooo0_l0
003Xooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o00001_ooool2o`0000?ooooo0_l0003o
ooooob7ooooo000Nooooo`03o`000?oooooooooo01cooooo0_l00007ooooo`;o0000ooooool?oooo
o`;o00004?ooool001kooooo00?o0000ooooooooool07?ooool2o`0000Oooooo0_l00002ooooo`;o
00006?ooool2o`0000Cooooo0_l00010ooooo`;o0000Z?ooool2o`00013ooooo000Nooooo`03o`00
0?oooooooooo02Cooooo0ol00002ooooo`;o00006?ooool2o`0000Cooooo0_l0000Gooooo`;o0000
9oooool2o`000:oooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o00003ooo
ool2o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`00037ooooo0_l0003Hooooo`;o00002Ooo
ool001kooooo00?o0000ooooooooool03oooool2o`0000oooooo0_l00009ooooo`;o00000_ooool2
o`000?oooooo5oooool001kooooo00?o0000ooooooooool0;oooool2o`0000?ooooo0_l000000ooo
oooo0000o`00003oooooo`oooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l0000Qooooo`?o
00000oooool5o`0003Cooooo0_l0002Yooooo`;o0000;Oooool001kooooo00?o0000ooooooooool0
2oooool2o`00027ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o0000=_ooool2o`000:Wo
oooo0_l0000]ooooo`007_ooool00ol0003oooooooooo`0aooooo`?o000000?oooooo`000?l00000
oooooolAooooo`007_ooool2o`00023ooooo0_l0000Cooooo`Co00001_ooool2o`0002Gooooo0_l0
003Pooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o00004oooool4o`0000Cooooo1?l0000U
ooooo`;o0000h?ooool001kooooo00?o0000ooooooooool0??ooool2o`0000Wooooo0_l0003/oooo
o`;o00004?ooool001kooooo00?o0000ooooooooool0>?ooool2o`000005ooooool0003o0000o`00
0?ooool01Ol00003ooooo`Co00002_ooool2o`000=kooooo0_l0000@ooooo`007_ooool00ol0003o
ooooooooo`0hooooo`co00000_ooool2o`000003ooooool0003o000000[ooooo0_l0003`ooooo`00
7_ooool00ol0003oooooooooo`0aooooo`?o00000_ooool2o`0000;ooooo1Ol00004ooooo`;o0000
00?oooooo`000?l000001_ooool4o`0000;ooooo0_l0003aooooo`007_ooool00ol0003ooooooooo
o`0`ooooo`Co000000Goooooo`000?l0003o0000ooooo`02o`0000Cooooo0_l000001?oooooo0000
o`000?l00006ooooo`Oo00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`000>Oo
oooo000Nooooo`03o`000?oooooooooo033ooooo2?l000000ooooooo0000o`000002ooooo`Co0000
00?oooooo`000?l000001oooool3o`0000Sooooo0_l000001?oooooo0000o`000?ooool6o`000>Go
oooo000Nooooo`03o`000?oooooooooo02oooooo1_l000000ooooooo0000o`000004ooooo`?o0000
1oooool2o`0000Gooooo0_l00007ooooo`;o00002?ooool3o`0000cooooo0_l0003Fooooo`007_oo
ool00ol0003oooooooooo`0_ooooo`;o00000oooool5o`0000?ooooo0_l00007ooooo`?o00001Ooo
ool2o`0000Wooooo0_l00002ooooo`Co000000?oooooo`000?l000001?l00008ooooo`Co0000e?oo
ool001kooooo00?o0000ooooooooool04_ooool2o`0001Wooooo0_l000001?oooooo0000o`000?oo
ool7o`0000_ooooo0_l00002ooooo`;o00003Oooool2o`000003ooooool0003o000000_o00002Ooo
ool2o`000=Cooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0000Hooooo`?o000000Cooooo
o`000?l0003ooooo0ol00002ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Cooooo0_l0
0006ooooo`;o00002?ooool4o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o0000fooo
ool001kooooo00?o0000ooooooooool0:oooool3o`0000[ooooo0_l000000ooooooo0000o`000002
o`0000Cooooo0_l0000<ooooo`;o00001?ooool2o`0000;ooooo1?l00004ooooo`;o00001Oooool2
o`000=_ooooo000Nooooo`03o`000?oooooooooo02_ooooo0_l000000ooooooo0000o`000002o`00
0003ooooool0003o000000?ooooo0_l00003ooooo`?o00004Oooool8o`0000;ooooo0_l00006oooo
o`Ko00001?ooool5o`000=Gooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo02_ooooo0_l00000
0ooooooo0000o`000002o`000003ooooool0003o000000Kooooo2?l00008ooooo`;o00001?ooool6
o`000004ooooool0003o0000ooooo`Co00000_ooool2o`000003ooooool0003o000000?o00001?oo
ool5o`0000?ooooo0_l0003@ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0Zooooo`?o0000
00?oooooo`000?l000000_l00003ooooo`;o00001?ooool8o`0000Gooooo0_l000000ooooooo0000
o`000006ooooo`;o00000oooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000Gooooo
0_l00003ooooo`;o000000?oooooo`000?l00000Eoooool2o`0007Oooooo0003ooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0000Zooooo`[o
000000?oooooo`000?l000000_l0000<ooooo`;o000000Coooooo`000?l0003ooooo0_l00006oooo
o`Co000000?oooooo`000?l000003?ooool2o`0000;ooooo0_l00006ooooo`?o0000FOooool2o`00
07Oooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So
8B4Q00Kooooo00?o0000ooooooooool0:oooool3o`000003ooooool0003o000000?o00000oooool2
o`0000cooooo0_l00004ooooo`;o00002?ooool2o`000005ooooool0003o0000o`000?ooool00ol0
0007ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0000?ooooo0_l0003Booooo`000ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03
o`000?oooooooooo02_ooooo1_l000000ooooooo0000o`000003ooooo`;o00000oooool2o`0000Oo
oooo1?l0000<ooooo`;o000000?oooooo`000?l000001Ol00007ooooo`;o000000Coooooo`000?l0
003o00000_ooool7o`000=;ooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool00omE
EEGoQhN7ooooo`08ooooo`03o`000?oooooooooo02_ooooo2_l00007ooooo`;o000000?oooooo`00
0?l000001_ooool2o`0000Oooooo0_l00003ooooo`;o000000?oooooo`000?l000001?l00005oooo
o`;o00001Oooool2o`0000Cooooo0ol0003Dooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0/ooooo`Wo000000?oooooo`00
0?l000001?ooool6o`0000?ooooo0_l00009ooooo`Go00003_ooool2o`0000Oooooo0_l0002Zoooo
o`;o0000;Oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000
oa0@40Kooooo00?o0000ooooooooool0;?ooool5o`000003ooooool0003o000000;ooooo0_l00004
ooooo`Oo00000_ooool2o`0000Gooooo0_l00004ooooo`Oo000000?oooooo`000?l000000_ooool4
o`000003ooooool0003o000000Oooooo0_l0002Zooooo`;o0000;Oooool001kooooo00?o0000oooo
ooooool0;oooool2o`00013ooooo0_l00006ooooo`;o000000?oooooo`000?l000001Oooool6o`00
0003ooooool0003o000000So00003oooool2o`000=;ooooo000Nooooo`03o`000?oooooooooo03Co
oooo0_l0000Cooooo`;o00002Oooool3o`0000?ooooo2_l0000=ooooo`Co0000d_ooool001kooooo
00?o0000ooooooooool0=?ooool2o`0001Oooooo0_l0000:ooooo`?o00000_ooool4o`0000?ooooo
0_l0000:ooooo`;o0000N?ooool2o`0005[ooooo000Nooooo`03o`000?oooooooooo03;ooooo0_l0
0006ooooo`;o00004Oooool2o`0000[ooooo0ol00002ooooo`Co00000oooool2o`0008Cooooo0_l0
001Jooooo`007_ooool00ol0003oooooooooo`0Uooooo`;o00002oooool2o`0000;ooooo0_l00002
ooooo`;o00005Oooool3o`0000;ooooo0_l00007ooooo`;o00000_ooool2o`0007;ooooo0_l0000c
ooooo`;o0000>Oooool001kooooo00?o0000ooooooooool03?ooool2o`0001Oooooo0_l0000?oooo
o`;o00003Oooool3o`0000Wooooo1?l000000ooooooo0000o`000005ooooo`Co00000_ooool2o`00
05;ooooo0_l0000Nooooo`;o0000<oooool2o`0003Wooooo000Nooooo`03o`000?oooooooooo00co
oooo0_l0000booooo`;o00000oooool3o`0000_ooooo0_l000000ooooooo0000o`000005ooooo`;o
0000F?ooool2o`0008kooooo000Nooooo`03o`000?oooooooooo03Sooooo0_l00006ooooo`;o0000
5Oooool7o`000003ooooool0003o00000>Kooooo000Nooooo`03o`000?oooooooooo03Sooooo0_l0
000:ooooo`;o00004Oooool7o`000003ooooool0003o000000?o00000oooool2o`000=kooooo000N
ooooo`03o`000?oooooooooo03gooooo0_l00005ooooo`;o00004oooool4o`0000Cooooo0ol00003
ooooo`Co0000g?ooool001kooooo00?o0000ooooooooool0?Oooool2o`0000Wooooo0_l0000Ooooo
o`;o00006?ooool2o`000<;ooooo000Nooooo`;o0000Aoooool4o`0003Wooooo0_l00005ooooo`;o
0000G?ooool2o`0005gooooo000Nooooo`03o`000?oooooooooo04?ooooo0_l000000ooooooo0000
o`00000>ooooo`;o00000_ooool2o`0002kooooo0_l0001Looooo`;o0000GOooool001kooooo00?o
0000ooooooooool0>_ooool2o`0000Oooooo0_l0000Aooooo`;o00000_ooool2o`0000Sooooo0_l0
003Qooooo`007_ooool00ol0003oooooooooo`0jooooo`Co00001_ooool2o`0001Kooooo0_l00005
ooooo`?o0000hOooool001kooooo00?o0000ooooooooool0>_ooool4o`0000Kooooo0_l0000Doooo
o`Co00001?ooool3o`000>;ooooo000Nooooo`03o`000?oooooooooo03[ooooo0_l0000>ooooo`;o
00003_ooool2o`0000Kooooo0_l00002ooooo`;o0000goooool001kooooo00?o0000ooooooooool0
B_ooool2o`0000oooooo0_l000000ooooooo0000o`000006ooooo`;o00001oooool2o`000=Kooooo
000Nooooo`03o`000?oooooooooo05Oooooo0_l00002ooooo`;o000000?oooooo`000?l000001ooo
ool2o`0000Gooooo0ol0003Fooooo`007_ooool00ol0003oooooooooo`0iooooo`;o00004?ooool2
o`0000[ooooo0_l0000>ooooo`;o00001Oooool2o`0004oooooo0_l00026ooooo`007_ooool00ol0
003oooooooooo`0iooooo`;o00004?ooool2o`0007;ooooo0_l00026ooooo`007_ooool00ol0003o
ooooooooo`1Aooooo`;o0000m?ooool001kooooo00?o0000ooooooooool0>?ooool2o`0000?ooooo
0_l0000Booooo`;o0000m?ooool001kooooo00?o0000ooooooooool0>?ooool2o`0000?ooooo0_l0
000:ooooo`;o00005oooool2o`0000kooooo0_l0003Cooooo`007_ooool00ol0003oooooooooo`19
ooooo`;o00005oooool2o`0000kooooo0_l0003Cooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo03[ooooo0_l0003oooooo`cooooo000Nooooo`;o0000
>oooool2o`0000Sooooo0_l0003oooooo`;ooooo000Nooooo`03o`000?oooooooooo03kooooo0_l0
0004ooooo`;o0000ooooool2ooooo`007_ooool00ol0003oooooooooo`0hooooo`;o00001?ooool2
o`0002[ooooo0_l0002Vooooo`;o0000<oooool001kooooo00?o0000ooooooooool0>?ooool2o`00
033ooooo0_l0002Vooooo`;o0000<oooool001kooooo00?o0000ooooooooool0W_ooool2o`00063o
oooo0_l00015ooooo`007_ooool00ol0003oooooooooo`1Sooooo`;o0000>Oooool2o`00063ooooo
0_l00015ooooo`007_ooool00ol0003oooooooooo`1Nooooo`;o00000oooool2o`000>;ooooo000N
ooooo`03o`000?oooooooooo04kooooo0_l0000>ooooo`;o0000ioooool001kooooo00?o0000oooo
ooooool0<oooool2o`0000gooooo0_l0000:ooooo`;o0000moooool001kooooo00?o0000oooooooo
ool0<oooool2o`0000gooooo0_l0003oooooo`Cooooo000Nooooo`03o`000?oooooooooo03Sooooo
0_l000000ooooooo0000o`00000Mooooo`;o0000joooool001kooooo00?o0000ooooooooool0>?oo
ool2o`000003ooooool0003o000001gooooo0_l0003[ooooo`007_ooool00ol0003oooooooooo`1X
ooooo`;o00002?ooool2o`000=?ooooo000Nooooo`03o`000?oooooooooo03Wooooo0_l0000Aoooo
o`;o00001oooool2o`00017ooooo0_l000000ooooooo0000o`000005ooooo`;o0000doooool001ko
oooo00?o0000ooooooooool0>Oooool2o`00017ooooo0_l00007ooooo`;o00005?ooool2o`00027o
oooo0_l0002gooooo`007_ooool00ol0003oooooooooo`1Yooooo`;o00008oooool2o`000;Oooooo
000Nooooo`;o0000A?ooool2o`0000Sooooo0_l0000Jooooo`;o0000g?ooool001kooooo00?o0000
ooooooooool0@oooool2o`0000Sooooo0_l0000Dooooo`;o0000h_ooool001kooooo00?o0000oooo
ooooool0?oooool2o`0002;ooooo0_l00012ooooo`;o0000W_ooool001kooooo00?o0000oooooooo
ool0?oooool2o`0006Kooooo0_l0002Nooooo`007_ooool00ol0003oooooooooo`0mooooo`;o0000
2Oooool2o`0001_ooooo0_l0000;ooooo`;o0000doooool001kooooo00?o0000ooooooooool0?Ooo
ool2o`0000Wooooo0_l0000Kooooo`;o00002oooool2o`000=?ooooo000Nooooo`03o`000?oooooo
oooo0<Kooooo0_l0001oooooo`007_ooool00ol0003oooooooooo`2Sooooo`;o00008Oooool2o`00
07oooooo000Nooooo`03o`000?oooooooooo04Wooooo0_l0000=ooooo`;o00000_ooool2o`0000?o
oooo0_l00010ooooo`;o0000X_ooool001kooooo00?o0000ooooooooool0=?ooool2o`0001?ooooo
0_l0000=ooooo`;o00000_ooool2o`0000?ooooo0_l0000;ooooo`;o0000eoooool001kooooo00?o
0000ooooooooool0=?ooool2o`0003Sooooo0_l0003Gooooo`007_ooool00ol0003oooooooooo`0d
ooooo`;o00007?ooool2o`0000kooooo0_l00007ooooo`?o0000fOooool001kooooo00?o0000oooo
ooooool0<oooool3o`0001cooooo0_l0000>ooooo`;o00001oooool3o`000=Wooooo000Nooooo`03
o`000?oooooooooo03?ooooo0_l0000_ooooo`;o00001_ooool2o`000=Wooooo0003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006oooo
o`03o`000?oooooooooo05_ooooo0_l00007ooooo`;o0000hOooool000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000
ooooooooool0Foooool2o`0001Gooooo0_l0003Cooooo`000oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000@_ooool2o`0000;ooooo0_l0
000Sooooo`;o00001Oooool2o`000=?ooooo0003ooooo`05o`000?ooooooooooooooool000002ooo
ool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000ooooooooool0@_ooool2o`0000;ooooo
0_l0000=ooooo`;o00005?ooool2o`000=[ooooo0003ooooo`05o`000?ooooooooooooooool00000
2oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0@?ooool2o`0001?o
oooo0_l0003`ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oo
oooo^[Zjoa0@4006ooooo`03o`000?oooooooooo043ooooo0_l0000Sooooo`;o0000h?ooool000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool0
0ol0003oooooooooo`1Sooooo`Co0000h?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`0Cooooo`;o00009ooo
ool2o`0001Gooooo0_l0000>ooooo`;o0000h_ooool001kooooo00?o0000ooooooooool04oooool3
o`0002Kooooo0_l0000Eooooo`;o00001Oooool2o`0000Kooooo0_l0003Sooooo`007_ooool00ol0
003oooooooooo`0Dooooo`;o00007Oooool2o`0002Gooooo0_l00004ooooo`Co0000hoooool001ko
oooo00?o0000ooooooooool0<oooool2o`0000Kooooo0_l0000Hooooo`;o00002Oooool4o`0006Ko
oooo0_l0001kooooo`007_ooool00ol0003oooooooooo`0kooooo`;o00002?ooool2o`0000kooooo
0_l00008ooooo`Ko00000oooool2o`0004gooooo0_l0000Aooooo`;o0000Noooool001kooooo00?o
0000ooooooooool0AOooool2o`0001Cooooo0_l00002ooooo`?o000000?oooooo`000?l000000_l0
00000ooooooo0000o`00001=ooooo`;o0000S_ooool001kooooo00?o0000ooooooooool0E_ooool2
o`0000?ooooo0_l00003ooooo`;o00000oooool7o`000=_ooooo000Nooooo`03o`000?oooooooooo
05Kooooo0_l00008ooooo`;o00001?ooool2o`0000;ooooo0_l0003Kooooo`007_ooool00ol0003o
ooooooooo`0iooooo`;o00007Oooool2o`0000kooooo0ol0001Iooooo`;o0000POooool001kooooo
00?o0000ooooooooool0>Oooool2o`0001gooooo0_l0000>ooooo`?o0000FOooool2o`00087ooooo
000Nooooo`03o`000?oooooooooo03[ooooo0_l0000:ooooo`;o00009oooool3o`000=Gooooo000N
ooooo`03o`000?oooooooooo03Oooooo0_l000000ooooooo0000o`000009ooooo`?o00006oooool2
o`0000Cooooo0_l00004ooooo`?o0000eOooool001kooooo0_l0000hooooo`;o00002oooool5o`00
0003ooooool0003o000001Cooooo0_l000000ooooooo0000o`000004ooooo`;o0000g?ooool001ko
oooo00?o0000ooooooooool0A?ooool2o`000004ooooool0003o0000ooooo`;o00004_ooool4o`00
0003ooooool0003o000000Wooooo0_l0003Gooooo`007_ooool00ol0003oooooooooo`14ooooo`;o
00003Oooool2o`0000Oooooo1?l00003ooooo`Co00001oooool2o`0000;ooooo0_l0003Cooooo`00
7_ooool00ol0003oooooooooo`0gooooo`;o00002oooool2o`0000_ooooo1?l00002ooooo`;o0000
0_ooool3o`0000Oooooo0_l00008ooooo`Go0000doooool001kooooo00?o0000ooooooooool0=Ooo
ool4o`0001?ooooo0_l00003ooooo`?o00000oooool3o`000003ooooool0003o000000kooooo1ol0
003Eooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o00005?ooool3o`0001Cooooo0_l00004
ooooo`;o00001?ooool2o`0000Kooooo0_l00004ooooo`;o00000_ooool8o`000=Gooooo000Noooo
o`03o`000?oooooooooo01oooooo0_l0000Eooooo`;o00009_ooool4o`0000Cooooo0_l00002oooo
o`Ko000000?oooooo`000?l00000e?ooool001kooooo00?o0000ooooooooool0Doooool2o`0000;o
oooo0ol00004ooooo`;o00000oooool2o`0000Kooooo0ol00003ooooo`;o0000e?ooool001kooooo
00?o0000ooooooooool0=_ooool2o`0000kooooo0_l00003ooooo`;o00001Oooool3o`0000;ooooo
0ol00002ooooo`;o00001Oooool4o`0000;ooooo0_l0003Looooo`007_ooool00ol0003ooooooooo
o`02ooooo`;o0000<_ooool2o`0000Wooooo0_l00003ooooo`;o00000oooool2o`000003ooooool0
003o000000;ooooo0ol00006ooooo`Go00001Oooool2o`0000;ooooo0_l0003Looooo`007_ooool0
0ol0003oooooooooo`02ooooo`;o0000?Oooool2o`0000Kooooo1?l000000ooooooo0000o`000003
ooooo`;o00001_ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l00000hOoo
ool001kooooo00?o0000ooooooooool0BOooool4o`0001?ooooo0ol000000ooooooo0000o`00003Q
ooooo`007_ooool00ol0003oooooooooo`0booooo`;o00006?ooool2o`00013ooooo1?l0000:oooo
o`?o0000f?ooool001kooooo00?o0000ooooooooool0<_ooool2o`0001Sooooo0_l0000@ooooo`Co
00001_ooool2o`0000;ooooo1?l0003Gooooo`007_ooool00ol0003oooooooooo`16ooooo`;o0000
6?ooool2o`0000Kooooo0_l00003ooooo`?o0000eoooool001kooooo00?o0000ooooooooool0A_oo
ool2o`0000;ooooo0_l0000?ooooo`?o00003?ooool4o`000=Wooooo000Nooooo`;o0000Aoooool2
o`0000;ooooo0ol0000:ooooo`;o00000_ooool3o`0000Oooooo0_l00002ooooo`Go0000fOooool0
01kooooo00?o0000ooooooooool0A_ooool3o`0000;ooooo0_l0000:ooooo`;o00000_ooool2o`00
00Sooooo0_l000000ooooooo0000o`000003o`0002Gooooo0_l0002cooooo`007_ooool00ol0003o
ooooooooo`17ooooo`;o00001Oooool2o`0000Sooooo0_l00009ooooo`Co000000?oooooo`000?l0
00000_l0000Vooooo`;o0000/oooool001kooooo00?o0000ooooooooool0@oooool2o`0000Wooooo
0_l00008ooooo`;o00002Oooool2o`000003ooooool0003o000000;ooooo0_l0003Kooooo`007_oo
ool00ol0003oooooooooo`12ooooo`?o00004Oooool2o`0000_ooooo0_l000001?oooooo0000o`00
0?ooool2o`000=cooooo000Nooooo`03o`000?oooooooooo03kooooo0_l00002ooooo`;o00004Ooo
ool3o`0000Oooooo0_l00002ooooo`;o00001?ooool2o`000=cooooo000Nooooo`03o`000?oooooo
oooo03Sooooo0_l000001?oooooo0000o`000?ooool2o`0000_ooooo0_l00008ooooo`;o00000_oo
ool2o`0000Cooooo0_l00005ooooo`;o000000?oooooo`000?l00000g?ooool001kooooo00?o0000
ooooooooool0<_ooool2o`0000Cooooo1Ol00002ooooo`;o00002_ooool2o`0000cooooo0_l0000;
ooooo`Co0000gOooool001kooooo00?o0000ooooooooool03Oooool2o`0002?ooooo0_l00006oooo
o`;o00000oooool2o`0000Kooooo0_l0000Kooooo`Ko00007Oooool2o`000;kooooo000Nooooo`03
o`000?oooooooooo00gooooo0_l0000Sooooo`;o00001oooool2o`0000;ooooo0_l00005ooooo`?o
000000?oooooo`000?l000000_ooool2o`0001Cooooo1?l0000Oooooo`;o0000__ooool001kooooo
00?o0000ooooooooool0>oooool2o`0000;ooooo0_l00004ooooo`?o00000_ooool2o`0000;ooooo
0_l00005ooooo`;o00001oooool2o`000>Oooooo000Nooooo`03o`000?oooooooooo04Gooooo0_l0
0002ooooo`;o00000oooool3o`0000Cooooo0_l00007ooooo`;o0000T_ooool2o`0005?ooooo000N
ooooo`03o`000?oooooooooo03Kooooo0_l0000Aooooo`;o00000oooool3o`0001?ooooo0_l00000
0ooooooo0000o`000029ooooo`;o0000Doooool001kooooo00?o0000ooooooooool0=_ooool2o`00
02cooooo0_l000000ooooooo0000o`00000Pooooo`;o0000_?ooool001kooooo00?o0000oooooooo
ool0=Oooool2o`0000Wooooo0_l00002ooooo`;o00006?ooool2o`0002Wooooo0_l0002looooo`00
7_ooool00ol0003oooooooooo`0eooooo`;o00002Oooool3o`000003ooooool0003o000000;ooooo
0_l0000Dooooo`;o0000ioooool001kooooo0_l00012ooooo`;o000000?oooooo`000?l000000_oo
ool2o`0000Gooooo0_l0000@ooooo`;o000000?oooooo`000?l00000hOooool001kooooo00?o0000
ooooooooool0=Oooool2o`0000gooooo0_l00005ooooo`;o00000_ooool2o`0000_ooooo0_l00003
ooooo`;o000000?oooooo`000?l000000_l00036ooooo`;o00005oooool001kooooo00?o0000oooo
ooooool0=?ooool3o`0000?ooooo0_l00003ooooo`;o00001oooool2o`000003ooooool0003o0000
00Kooooo0_l00007ooooo`;o00001_ooool4o`000<Kooooo0_l0000Gooooo`007_ooool00ol0003o
ooooooooo`0dooooo`;o00001?ooool2o`0000?ooooo0ol00004ooooo`Co00002Oooool2o`0000oo
oooo0_l0003Qooooo`007_ooool00ol0003oooooooooo`10ooooo`;o00001?ooool2o`0000?ooooo
0_l00008ooooo`;o00001Oooool2o`000>Wooooo000Nooooo`03o`000?oooooooooo03[ooooo1?l0
0002ooooo`;o00002?ooool3o`0000Oooooo0ol00005ooooo`;o00009oooool2o`000<3ooooo000N
ooooo`03o`000?oooooooooo03Kooooo2?l00007ooooo`Oo00000_ooool2o`0000?ooooo0ol00000
0ooooooo0000o`00000/ooooo`;o0000`?ooool001kooooo00?o0000ooooooooool0:Oooool2o`00
00[ooooo1Ol000000ooooooo0000o`000008ooooo`Oo00000_ooool2o`0000;ooooo0ol00002oooo
o`Co0000k?ooool001kooooo00?o0000ooooooooool0:Oooool2o`0000[ooooo0_l00004ooooo`;o
00000oooool2o`000003ooooool0003o000000Gooooo0_l00005ooooo`?o00001Oooool2o`0000;o
oooo0_l00005ooooo`;o0000hOooool001kooooo00?o0000ooooooooool0@?ooool2o`000003oooo
ool0003o000000?o00002Oooool2o`0000Sooooo1?l00005ooooo`;o0000hOooool001kooooo00?o
0000ooooooooool0=oooool2o`0000Sooooo0_l000000ooooooo0000o`000002o`000003ooooool0
003o000000;ooooo0_l00002ooooo`;o00002?ooool2o`000>[ooooo000Nooooo`03o`000?oooooo
oooo03Oooooo0_l00008ooooo`Co00001?ooool2o`0000;ooooo1?l00002ooooo`;o00003Oooool2
o`000>?ooooo000Nooooo`03o`000?oooooooooo03cooooo0_l00002ooooo`Go00000_ooool2o`00
00Kooooo0_l00002ooooo`;o00002Oooool2o`000004ooooool0003o0000o`000>?ooooo000Noooo
o`03o`000?oooooooooo03Oooooo0_l00003ooooo`;o000000?oooooo`000?l000001?l00002oooo
o`;o00004oooool4o`000003ooooool0003o000000;o0000h_ooool001Cooooo1?l000000ol@413o
ooooooooo`03ooooo`03o`000?oooooooooo03Oooooo0ol00005ooooo`Co00006Oooool2o`0000Go
oooo0_l0003Rooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Sooooo
0_l00004ooooo`Co00004oooool2o`0000Gooooo0_l0001=ooooo`;o0000V_ooool001Kooooo00?o
0000ooooooooool01Oooool3o`0003kooooo1?l00002ooooo`;o00002Oooool2o`0000Cooooo0_l0
0005ooooo`;o0000COooool2o`0009[ooooo000Fooooo`03o`000?oooooooooo04cooooo0_l00009
ooooo`;o0000m_ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003o
ooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Cooooo00?o
EEEEofIVI_l00000oooooomBooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.32659 .66261 Mdot
.96958 .37078 Mdot
.32586 .64444 Mdot
.37264 .86201 Mdot
.20262 .67165 Mdot
.26606 .87831 Mdot
.33882 .1269 Mdot
.26272 .66302 Mdot
.23906 .90049 Mdot
.67136 .2198 Mdot
.26631 .97149 Mdot
.19147 .95516 Mdot
.27017 .62756 Mdot
.16184 .65483 Mdot
.31584 .84637 Mdot
.09673 .62628 Mdot
.91898 .52131 Mdot
.2137 .59735 Mdot
.30588 .59238 Mdot
.35415 .91165 Mdot
.15492 .52038 Mdot
.24724 .90242 Mdot
.13411 .65656 Mdot
.02168 .13752 Mdot
.26614 .87207 Mdot
.27443 .7085 Mdot
.32443 .82798 Mdot
.14422 .66886 Mdot
.25788 .97464 Mdot
.28461 .90453 Mdot
.27697 .59146 Mdot
.30305 .84637 Mdot
.21059 .94003 Mdot
.29471 .94609 Mdot
.25657 .55842 Mdot
.38616 .86096 Mdot
.17424 .66021 Mdot
.09749 .45337 Mdot
.13498 .84212 Mdot
.29643 .81058 Mdot
.28736 .59179 Mdot
.37671 .6267 Mdot
.39515 .89096 Mdot
.03641 .50636 Mdot
.22485 .04842 Mdot
.39096 .67533 Mdot
.47216 .37663 Mdot
.41881 .86473 Mdot
.37657 .85408 Mdot
.31911 .49439 Mdot
.1617 .96662 Mdot
.27121 .57929 Mdot
.24132 .67733 Mdot
.39258 .8649 Mdot
.22218 .66564 Mdot
.30147 .20908 Mdot
.75959 .2092 Mdot
.26191 .63466 Mdot
.32969 .82876 Mdot
.22506 .60296 Mdot
.3564 .8592 Mdot
.26584 .68994 Mdot
.36901 .10049 Mdot
.25314 .89263 Mdot
.24413 .74293 Mdot
.23853 .90328 Mdot
.33629 .55287 Mdot
.32798 .82807 Mdot
.27881 .87361 Mdot
.81793 .23771 Mdot
.32099 .19046 Mdot
.14048 .5761 Mdot
.32894 .02667 Mdot
.2948 .08018 Mdot
.19777 .93673 Mdot
.16182 .26985 Mdot
.32078 .61717 Mdot
.55038 .12826 Mdot
.311 .84092 Mdot
.13612 .57082 Mdot
.41448 .87613 Mdot
.48907 .19335 Mdot
.06403 .51174 Mdot
.26612 .66981 Mdot
.83814 .2935 Mdot
.23891 .15428 Mdot
.24326 .68466 Mdot
.36834 .85138 Mdot
.29388 .85709 Mdot
.19265 .56796 Mdot
.35118 .94782 Mdot
.84891 .24212 Mdot
.31066 .48171 Mdot
.32158 .13867 Mdot
.21513 .57262 Mdot
.40158 .77981 Mdot
.43637 .09252 Mdot
.26523 .56848 Mdot
.25334 .85633 Mdot
.23853 .5345 Mdot
.32363 .75311 Mdot
.152 .9536 Mdot
.35614 .62739 Mdot
.12263 .64511 Mdot
.00656 .32355 Mdot
.13688 .65883 Mdot
.11134 .61094 Mdot
.10631 .62499 Mdot
.29747 .59086 Mdot
.48303 .14999 Mdot
.17182 .66237 Mdot
.05828 .42567 Mdot
.14393 .96836 Mdot
.24556 .5943 Mdot
.19008 .41302 Mdot
.36357 .14732 Mdot
.19111 .03714 Mdot
.2778 .63489 Mdot
.30502 .31616 Mdot
.16101 .93784 Mdot
.34872 .83782 Mdot
.40744 .74892 Mdot
.21195 .91777 Mdot
.32082 .14893 Mdot
.90452 .22792 Mdot
.19771 .52038 Mdot
.19037 .93044 Mdot
.29311 .61453 Mdot
.31573 .92087 Mdot
.31524 .0114 Mdot
.16934 .50813 Mdot
.2307 .21239 Mdot
.88894 .69729 Mdot
.15843 .61843 Mdot
.20726 .57769 Mdot
.22896 .61669 Mdot
.14682 .66299 Mdot
.14933 .56671 Mdot
.34915 .6237 Mdot
.24458 .89592 Mdot
.28178 .60239 Mdot
.25377 .89334 Mdot
.21983 .91274 Mdot
.32027 .57512 Mdot
.41226 .22124 Mdot
.19344 .94585 Mdot
.27651 .66316 Mdot
.31125 .77961 Mdot
.75795 .21431 Mdot
.45099 .17182 Mdot
.45122 .75934 Mdot
.21113 .9322 Mdot
.19079 .97344 Mdot
.35067 .92542 Mdot
.32736 .84417 Mdot
.2753 .64908 Mdot
.12056 .5777 Mdot
.76688 .22893 Mdot
.25779 .88551 Mdot
.09711 .61345 Mdot
.12876 .57444 Mdot
.22426 .54264 Mdot
.99711 .96641 Mdot
.14217 .62503 Mdot
.2544 .83779 Mdot
.19729 .67759 Mdot
.30264 .77558 Mdot
.28327 .8513 Mdot
.45574 .14698 Mdot
.14771 .64587 Mdot
.22865 .91517 Mdot
.41214 .87684 Mdot
.21975 .54835 Mdot
.30101 .28213 Mdot
.31893 .63797 Mdot
.13589 .6806 Mdot
.14867 .92918 Mdot
.3038 .69595 Mdot
.40063 .12404 Mdot
.25997 .57478 Mdot
.3985 .88401 Mdot
.18878 .95708 Mdot
.14075 .79892 Mdot
.26868 .04698 Mdot
.67958 .17457 Mdot
.1345 .9205 Mdot
.09528 .61135 Mdot
.35977 .93056 Mdot
.81606 .70319 Mdot
.33915 .63463 Mdot
.30726 .62832 Mdot
.18599 .15077 Mdot
.30016 .63283 Mdot
.2468 .03902 Mdot
.1462 .93344 Mdot
.38802 .89668 Mdot
.2565 .54714 Mdot
.21005 .93681 Mdot
.23616 .90446 Mdot
.20241 .93522 Mdot
.31481 .07032 Mdot
.20486 .38798 Mdot
.16893 .60447 Mdot
.2775 .05158 Mdot
.26492 .87588 Mdot
.36991 .85477 Mdot
.41234 .17136 Mdot
.35604 .83981 Mdot
.86949 .27322 Mdot
.15714 .70809 Mdot
.15516 .65898 Mdot
.29475 .63129 Mdot
.94049 .22571 Mdot
.63082 .18839 Mdot
.1376 .56907 Mdot
.32126 .14983 Mdot
.28775 .78674 Mdot
.32741 .32806 Mdot
.13343 .66921 Mdot
.35654 .53646 Mdot
.76699 .21101 Mdot
.17731 .57492 Mdot
.25504 .89134 Mdot
.27965 .86253 Mdot
.18837 .56579 Mdot
.10976 .59977 Mdot
.36696 .92904 Mdot
.16573 .64697 Mdot
.6566 .1815 Mdot
.22362 .91175 Mdot
.28536 .67848 Mdot
.22462 .61918 Mdot
.21251 .91375 Mdot
.29823 .01997 Mdot
.32119 .14215 Mdot
.6706 .22205 Mdot
.66125 .46823 Mdot
.28023 .60794 Mdot
.11662 .48103 Mdot
.7375 .23447 Mdot
.3211 .67133 Mdot
.21739 .90995 Mdot
.40845 .88728 Mdot
.36314 .64627 Mdot
.13666 .82623 Mdot
.33214 .58819 Mdot
.15544 .58166 Mdot
.24241 .91507 Mdot
.52016 .21366 Mdot
.29425 .60358 Mdot
.265 .57615 Mdot
.19268 .67139 Mdot
.79757 .26848 Mdot
.24886 .16712 Mdot
.90177 .23034 Mdot
.41607 .86561 Mdot
.22517 .67803 Mdot
.10527 .46983 Mdot
.37268 .73273 Mdot
.19221 .40399 Mdot
.30545 .65777 Mdot
.23943 .70873 Mdot
.29826 .15392 Mdot
.11294 .43053 Mdot
.21411 .91133 Mdot
.20528 .10017 Mdot
.14178 .95434 Mdot
.29418 .29898 Mdot
.28044 .62008 Mdot
.30711 .8232 Mdot
.25477 .85375 Mdot
.57986 .37462 Mdot
.33259 .86916 Mdot
.21109 .7149 Mdot
.41372 .8865 Mdot
.16995 .66997 Mdot
.13741 .65428 Mdot
.24071 .14406 Mdot
.38808 .86265 Mdot
.14961 .96518 Mdot
.77531 .2344 Mdot
.2436 .9059 Mdot
.12827 .64325 Mdot
.19127 .64789 Mdot
.20814 .68002 Mdot
.25562 .89086 Mdot
.15921 .63212 Mdot
.15927 .51652 Mdot
.41288 .78818 Mdot
.2532 .03335 Mdot
.40999 .88108 Mdot
.86347 .24328 Mdot
.30117 .59105 Mdot
.22714 .02152 Mdot
.43479 .12161 Mdot
.17446 .52793 Mdot
.26726 .73399 Mdot
.09554 .60713 Mdot
.77154 .25019 Mdot
.5396 .19238 Mdot
.15338 .51175 Mdot
.23161 .91091 Mdot
.27765 .55585 Mdot
.13816 .58996 Mdot
.64151 .20575 Mdot
.3019 .58181 Mdot
.31817 .82856 Mdot
.3359 .84169 Mdot
.94505 .22191 Mdot
.20324 .375 Mdot
.35371 .83963 Mdot
.767 .25709 Mdot
.27474 .70809 Mdot
.17094 .5365 Mdot
.25522 .80675 Mdot
.40712 .81029 Mdot
.1346 .72338 Mdot
.29915 .27732 Mdot
.20735 .93777 Mdot
.04271 .35933 Mdot
.13585 .84773 Mdot
.20935 .93993 Mdot
.16065 .97273 Mdot
.15042 .7715 Mdot
.25103 .58779 Mdot
.28922 .67111 Mdot
.38691 .86194 Mdot
.29962 .65513 Mdot
.18428 .95853 Mdot
.27661 .68804 Mdot
.35875 .92211 Mdot
.26252 .88561 Mdot
.25991 .18937 Mdot
.97976 .19182 Mdot
.32999 .36855 Mdot
.26425 .42083 Mdot
.71563 .64124 Mdot
.32804 .82634 Mdot
.75443 .95385 Mdot
.2097 .09393 Mdot
.25797 .8514 Mdot
.73164 .61234 Mdot
.28316 .62447 Mdot
.1351 .58704 Mdot
.73479 .21637 Mdot
.15887 .5898 Mdot
.43843 .15085 Mdot
.22971 .23713 Mdot
.10304 .47798 Mdot
.26017 .66043 Mdot
.28689 .6321 Mdot
.21089 .67487 Mdot
.31348 .64249 Mdot
.12611 .6474 Mdot
.38068 .14131 Mdot
.34194 .86546 Mdot
.37025 .6127 Mdot
.14407 .61412 Mdot
.26007 .623 Mdot
.32337 .34288 Mdot
.23801 .9097 Mdot
.17578 .81399 Mdot
.28498 .58976 Mdot
.15265 .66082 Mdot
.24355 .90337 Mdot
.28435 .7071 Mdot
.33136 .95594 Mdot
.64757 .62391 Mdot
.71436 .21513 Mdot
.27654 .8909 Mdot
.14805 .56602 Mdot
.30659 .83016 Mdot
.31248 .63143 Mdot
.23064 .90981 Mdot
.40711 .90097 Mdot
.22292 .52802 Mdot
.23348 .0584 Mdot
.37635 .85425 Mdot
.982 .20345 Mdot
.27773 .92189 Mdot
.30115 .84626 Mdot
.38125 .87226 Mdot
.70032 .18144 Mdot
.89836 .23215 Mdot
.13749 .68079 Mdot
.24773 .03516 Mdot
.36467 .91672 Mdot
.42957 .48035 Mdot
.3234 .82632 Mdot
.20634 .66663 Mdot
.27947 .59606 Mdot
.21097 .63136 Mdot
.34909 .74176 Mdot
.23374 .65189 Mdot
.2137 .66514 Mdot
.22411 .23843 Mdot
.9145 .59524 Mdot
.11985 .15039 Mdot
.33606 .83103 Mdot
.26562 .58612 Mdot
.38402 .90677 Mdot
.19185 .03087 Mdot
.7803 .22214 Mdot
.26678 .68422 Mdot
.33189 .65569 Mdot
.3457 .93886 Mdot
.27147 .041 Mdot
.17409 .56351 Mdot
.11154 .61767 Mdot
.14195 .62834 Mdot
.15477 .56471 Mdot
.27128 .87112 Mdot
.13738 .57039 Mdot
.31767 .12667 Mdot
.72746 .2016 Mdot
.1739 .61437 Mdot
.3665 .62531 Mdot
.11238 .59307 Mdot
.76166 .21338 Mdot
.3181 .83976 Mdot
.29306 .82733 Mdot
.39578 .33254 Mdot
.65909 .22134 Mdot
.19547 .62687 Mdot
.26553 .64316 Mdot
.89012 .44069 Mdot
.27185 .07293 Mdot
.23133 .91013 Mdot
.13593 .57793 Mdot
.87644 .27615 Mdot
.73478 .21964 Mdot
.49776 .39175 Mdot
.15692 .52408 Mdot
.37622 .88577 Mdot
.78953 .24756 Mdot
.20671 .57633 Mdot
.13395 .65751 Mdot
.34573 .94307 Mdot
.38699 .62997 Mdot
.18976 .03813 Mdot
.13879 .9476 Mdot
.05109 .45171 Mdot
.03733 .53695 Mdot
.34475 .86044 Mdot
.28545 .30698 Mdot
.35392 .84782 Mdot
.20641 .94719 Mdot
.17705 .6598 Mdot
.84331 .24657 Mdot
.1136 .6474 Mdot
.1492 .613 Mdot
.31671 .5982 Mdot
.25873 .85553 Mdot
.29226 .85042 Mdot
.21623 .00304 Mdot
.34854 .83709 Mdot
.25918 .88645 Mdot
.38944 .8636 Mdot
.3265 .9446 Mdot
.18261 .48551 Mdot
.38697 .7433 Mdot
.36466 .85168 Mdot
.28714 .8531 Mdot
.32427 .66884 Mdot
.02391 .18902 Mdot
.24967 .56679 Mdot
.20999 .94286 Mdot
.21531 .54201 Mdot
.33457 .85608 Mdot
.32852 .80758 Mdot
.27628 .89564 Mdot
.25166 .68827 Mdot
.26436 .66987 Mdot
.26523 .66949 Mdot
.3528 .65308 Mdot
.30427 .84462 Mdot
.29568 .66968 Mdot
.2675 .65329 Mdot
.76584 .21125 Mdot
.19359 .88194 Mdot
.54697 .13386 Mdot
.18848 .01315 Mdot
.22745 .90752 Mdot
.26878 .59265 Mdot
.31368 .65244 Mdot
.26984 .10813 Mdot
.312 .11165 Mdot
.84658 .24908 Mdot
.41233 .89422 Mdot
.14672 .66188 Mdot
.29725 .61958 Mdot
.27896 .85635 Mdot
.24146 .21914 Mdot
.32499 .9372 Mdot
.34251 .9655 Mdot
.22079 .93793 Mdot
.39013 .62742 Mdot
.20127 .95197 Mdot
.11379 .2344 Mdot
.13596 .74601 Mdot
.36654 .61706 Mdot
.32996 .98439 Mdot
.41278 .86858 Mdot
.68762 .21428 Mdot
.188 .61349 Mdot
.35446 .51272 Mdot
.25775 .69279 Mdot
.43289 .11246 Mdot
.26644 .87983 Mdot
.30844 .91683 Mdot
.24558 .58064 Mdot
.54256 .21642 Mdot
.27731 .20122 Mdot
.70836 .17983 Mdot
.21491 .67588 Mdot
.29626 .02457 Mdot
.40227 .86891 Mdot
.40414 .79206 Mdot
.7402 .30434 Mdot
.25621 .58354 Mdot
.15336 .60304 Mdot
.34441 .65759 Mdot
.30511 .84412 Mdot
.20341 .92372 Mdot
.31291 .60209 Mdot
.59241 .82822 Mdot
.24977 .21127 Mdot
.8665 .61349 Mdot
.11047 .61638 Mdot
.3267 .9458 Mdot
.1064 .04418 Mdot
.4092 .18813 Mdot
.20743 .68002 Mdot
.13553 .86927 Mdot
.26803 .66765 Mdot
.32932 .76333 Mdot
.22185 .75515 Mdot
.22377 .92034 Mdot
.05648 .43572 Mdot
.40898 .0898 Mdot
.24505 .89579 Mdot
.73241 .19384 Mdot
.19159 .94644 Mdot
.31551 .84339 Mdot
.34085 .69699 Mdot
.40875 .10193 Mdot
.8409 .24755 Mdot
.12751 .61205 Mdot
.13099 .64802 Mdot
.28544 .66961 Mdot
.39239 .16591 Mdot
.34344 .07604 Mdot
.21553 .93098 Mdot
.25022 .96678 Mdot
.41507 .88379 Mdot
.44556 .15277 Mdot
.83987 .25241 Mdot
.33112 .82237 Mdot
.39191 .8692 Mdot
.21991 .4364 Mdot
.13771 .64375 Mdot
.19742 .94413 Mdot
.06368 .43581 Mdot
.24014 .61017 Mdot
.16672 .62571 Mdot
.38039 .85549 Mdot
.12129 .57621 Mdot
.25518 .8755 Mdot
.51433 .33646 Mdot
.2889 .86036 Mdot
.45521 .42168 Mdot
.12819 .64852 Mdot
.29708 .84688 Mdot
.29321 .65771 Mdot
.22649 .62278 Mdot
.22421 .91991 Mdot
.33397 .95637 Mdot
.25941 .97767 Mdot
.19096 .6691 Mdot
.35965 .588 Mdot
.5459 .11328 Mdot
.84298 .24052 Mdot
.34987 .65927 Mdot
.27758 .58701 Mdot
.04806 .46547 Mdot
.37711 .85697 Mdot
.13678 .92277 Mdot
.31959 .08433 Mdot
.21729 .95797 Mdot
.24433 .62086 Mdot
.26723 .64831 Mdot
.24848 .65895 Mdot
.12344 .59797 Mdot
.20257 .94542 Mdot
.20997 .95127 Mdot
.27475 .7064 Mdot
.13393 .67779 Mdot
.27955 .67161 Mdot
.38056 .8568 Mdot
.13369 .61268 Mdot
.21879 .92442 Mdot
.2946 .83271 Mdot
.30162 .63006 Mdot
.26483 .56767 Mdot
.23165 .07048 Mdot
.13874 .62638 Mdot
.31062 .80037 Mdot
.25965 .9068 Mdot
.28837 .08751 Mdot
.31055 .65347 Mdot
.33242 .07318 Mdot
.43717 .11834 Mdot
.29255 .87611 Mdot
.22158 .22972 Mdot
.32939 .60531 Mdot
.13308 .6323 Mdot
.13971 .57477 Mdot
.29571 .15389 Mdot
.24429 .87946 Mdot
.53541 .21012 Mdot
.56695 .84788 Mdot
.28071 .37236 Mdot
.30437 .63789 Mdot
.17583 .20715 Mdot
.3219 .58795 Mdot
.15406 .98267 Mdot
.17715 .03249 Mdot
.21654 .16279 Mdot
.19547 .65776 Mdot
.38659 .90837 Mdot
.35619 .63791 Mdot
.27809 .86466 Mdot
.23938 .62115 Mdot
.10869 .60536 Mdot
.2925 .84896 Mdot
.6 .15121 Mdot
.26582 .66632 Mdot
.31185 .52576 Mdot
.20222 .65125 Mdot
.30993 .85143 Mdot
.34531 .96753 Mdot
.2784 .86803 Mdot
.36865 .60316 Mdot
.33597 .98666 Mdot
.22606 .04838 Mdot
.18237 .58032 Mdot
.17201 .94534 Mdot
.75498 .20316 Mdot
.27112 .67677 Mdot
.31044 .08733 Mdot
.97456 .10113 Mdot
.1952 .95639 Mdot
.10444 .88167 Mdot
.27761 .86415 Mdot
.84258 .24722 Mdot
.29239 .82175 Mdot
.26785 .67997 Mdot
.77843 .26426 Mdot
.86523 .27049 Mdot
.34217 .83395 Mdot
.20882 .05174 Mdot
.14155 .77824 Mdot
.61512 .22839 Mdot
.35525 .84163 Mdot
.19114 .12203 Mdot
.29089 .89189 Mdot
.3273 .8398 Mdot
.37235 .13348 Mdot
.24483 .53732 Mdot
.22184 .86816 Mdot
.32828 .08703 Mdot
.59161 .20809 Mdot
.25288 .04918 Mdot
.28556 .93583 Mdot
.72764 .2358 Mdot
.26799 .70174 Mdot
.78227 .23329 Mdot
.20567 .62678 Mdot
.47381 .17955 Mdot
.84117 .31807 Mdot
.02473 .40916 Mdot
.3285 .58124 Mdot
.72057 .19761 Mdot
.29496 .6141 Mdot
.28862 .85954 Mdot
.17386 .53782 Mdot
.16592 .92408 Mdot
.45236 .15645 Mdot
.19208 .89485 Mdot
.25025 .60415 Mdot
.41431 .79374 Mdot
.25537 .04461 Mdot
.32222 .43948 Mdot
.39058 .39329 Mdot
.21344 .93317 Mdot
.14127 .77238 Mdot
.28533 .8553 Mdot
.40051 .20466 Mdot
.60089 .229 Mdot
.98696 .21433 Mdot
.3187 .33539 Mdot
.11056 .64384 Mdot
.27595 .64574 Mdot
.3495 .62152 Mdot
.31464 .15142 Mdot
.20568 .92251 Mdot
.62073 .16665 Mdot
.07764 .25275 Mdot
.23972 .08861 Mdot
.22832 .91468 Mdot
.64195 .21961 Mdot
.17335 .61009 Mdot
.19082 .98827 Mdot
.73726 .27418 Mdot
.16405 .65936 Mdot
.89467 .42404 Mdot
.23585 .91101 Mdot
.24066 .65908 Mdot
.38941 .1546 Mdot
.2255 .91266 Mdot
.29627 .64407 Mdot
.31725 .07336 Mdot
.15482 .60491 Mdot
.29124 .42655 Mdot
.1736 .5616 Mdot
.82217 .24178 Mdot
.20636 .43648 Mdot
.34632 .83645 Mdot
.333 .00201 Mdot
.75507 .20327 Mdot
.25815 .93851 Mdot
.2543 .92574 Mdot
.29117 .65253 Mdot
.24469 .89266 Mdot
.38441 .13148 Mdot
.34635 .53337 Mdot
.85011 .24493 Mdot
.84729 .24865 Mdot
.16771 .95743 Mdot
.85374 .26048 Mdot
.16046 .78346 Mdot
.37136 .8728 Mdot
.31708 .59638 Mdot
.46831 .02564 Mdot
.30031 .02065 Mdot
.18236 .93608 Mdot
.28302 .9255 Mdot
.76039 .20827 Mdot
.19895 .9412 Mdot
.09351 .16185 Mdot
.39742 .89602 Mdot
.32185 .70755 Mdot
.22968 .0242 Mdot
.35628 .66575 Mdot
.17221 .5919 Mdot
.22119 .82395 Mdot
.16376 .64481 Mdot
.41197 .89214 Mdot
.28861 .67359 Mdot
.28933 .61039 Mdot
.80238 .23471 Mdot
.26186 .66612 Mdot
.8945 .30035 Mdot
.30993 .70872 Mdot
.27716 .0154 Mdot
.3548 .87041 Mdot
.28302 .55533 Mdot
.74356 .20449 Mdot
.20778 .93595 Mdot
.8977 .30745 Mdot
.26674 .85308 Mdot
.25097 .86515 Mdot
.13112 .65515 Mdot
.19249 .67147 Mdot
.43151 .17324 Mdot
.27215 .58442 Mdot
.1992 .86547 Mdot
.2948 .61913 Mdot
.22013 .00215 Mdot
.23617 .10391 Mdot
.37321 .86381 Mdot
.14277 .91435 Mdot
.75081 .25067 Mdot
.31996 .98043 Mdot
.25806 .75795 Mdot
.11662 .58547 Mdot
.13087 .6487 Mdot
.24547 .89436 Mdot
.2792 .85753 Mdot
.29321 .66123 Mdot
.55018 .67239 Mdot
.71529 .21492 Mdot
.30537 .65352 Mdot
.28888 .70579 Mdot
.15421 .52821 Mdot
.26101 .67766 Mdot
.14214 .65532 Mdot
.51703 .62956 Mdot
.38638 .86567 Mdot
.16393 .57262 Mdot
.71199 .26535 Mdot
.27115 .90796 Mdot
.34511 .66227 Mdot
.14619 .97353 Mdot
.19462 .63501 Mdot
.18856 .60036 Mdot
.23435 .21338 Mdot
.31206 .32406 Mdot
.22215 .53549 Mdot
.16122 .59164 Mdot
.20832 .52742 Mdot
.38735 .86659 Mdot
.34028 .65833 Mdot
.51341 .83457 Mdot
.37878 .90108 Mdot
.29809 .83597 Mdot
.49106 .17406 Mdot
.76206 .21857 Mdot
.33023 .84551 Mdot
.37686 .13005 Mdot
.26626 .66625 Mdot
.2723 .66548 Mdot
.2184 .9196 Mdot
.27457 .64756 Mdot
.25206 .67699 Mdot
.14129 .56886 Mdot
.24258 .68073 Mdot
.25184 .86295 Mdot
.42298 .16896 Mdot
.12287 .62734 Mdot
.19504 .03417 Mdot
.13592 .51429 Mdot
.24317 .61493 Mdot
.40855 .17636 Mdot
.39023 .65665 Mdot
.14231 .63906 Mdot
.58111 .143 Mdot
.37646 .85445 Mdot
.23 .91549 Mdot
.44403 .19112 Mdot
.31841 .98026 Mdot
.27426 .66735 Mdot
.3217 .82889 Mdot
.23933 .89757 Mdot
.7694 .22526 Mdot
.31533 .11514 Mdot
.21251 .52884 Mdot
.29926 .64007 Mdot
.27213 .70531 Mdot
.32173 .70534 Mdot
.08491 .46172 Mdot
.1892 .60363 Mdot
.2915 .5923 Mdot
.2769 .52858 Mdot
.35546 .8118 Mdot
.98874 .23859 Mdot
.26388 .66571 Mdot
.25316 .29622 Mdot
.18677 .868 Mdot
.30415 .72257 Mdot
.27193 .67262 Mdot
.36631 .85817 Mdot
.22482 .91946 Mdot
.61762 .16537 Mdot
.27879 .70835 Mdot
.19236 .95196 Mdot
.30664 .59254 Mdot
.13583 .64576 Mdot
.9359 .22171 Mdot
.27047 .65011 Mdot
.1831 .4441 Mdot
.35723 .79627 Mdot
.26196 .87744 Mdot
.39531 .76942 Mdot
.41123 .89354 Mdot
.23315 .67561 Mdot
.83687 .41014 Mdot
.01 .43106 Mdot
.20216 .03839 Mdot
.19725 .57459 Mdot
.57631 .77096 Mdot
.33216 .89202 Mdot
.26289 .67 Mdot
.32129 .67953 Mdot
.37957 .61674 Mdot
.32218 .65706 Mdot
.35318 .66905 Mdot
.75002 .22346 Mdot
.24462 .90358 Mdot
.38455 .90664 Mdot
.68449 .20436 Mdot
.24258 .15471 Mdot
.35363 .58221 Mdot
.23807 .90689 Mdot
.52855 .20168 Mdot
.27096 .74496 Mdot
.8054 .24511 Mdot
.32245 .85862 Mdot
.35084 .74723 Mdot
.20013 .85461 Mdot
.20539 .57356 Mdot
.14316 .95338 Mdot
.42659 .33595 Mdot
.39324 .68659 Mdot
.36532 .14704 Mdot
.28293 .52471 Mdot
.31653 .98102 Mdot
.18909 .71228 Mdot
.29534 .58983 Mdot
.27625 .62651 Mdot
.15008 .92636 Mdot
.36745 .90482 Mdot
.32139 .25752 Mdot
.22384 .92026 Mdot
.1479 .82251 Mdot
.22023 .41746 Mdot
.17053 .81102 Mdot
.4341 .77468 Mdot
.4087 .81921 Mdot
.23588 .90296 Mdot
.66536 .2224 Mdot
.34286 .44738 Mdot
.25004 .52601 Mdot
.27104 .67731 Mdot
.30756 .8478 Mdot
.10741 .47434 Mdot
.67277 .18024 Mdot
.22183 .00236 Mdot
.03532 .44653 Mdot
.8665 .27163 Mdot
.3934 .64973 Mdot
.14981 .66369 Mdot
.26986 .65409 Mdot
.21387 .91203 Mdot
.13927 .15662 Mdot
.28904 .6077 Mdot
.73475 .26179 Mdot
.24827 .92221 Mdot
.32981 .83754 Mdot
.22988 .00901 Mdot
.27076 .64287 Mdot
.32633 .61378 Mdot
.26809 .86282 Mdot
.41672 .1063 Mdot
.36605 .58232 Mdot
.27586 .86607 Mdot
.33396 .04706 Mdot
.35963 .53936 Mdot
.24659 .89275 Mdot
.57417 .15798 Mdot
.30282 .86535 Mdot
.77471 .26567 Mdot
.36664 .60544 Mdot
.61576 .58957 Mdot
.41283 .71292 Mdot
.31062 .64717 Mdot
.66692 .18236 Mdot
.129 .50789 Mdot
.38592 .08597 Mdot
.92318 .22885 Mdot
.25341 .90427 Mdot
.29027 .85059 Mdot
.32754 .84588 Mdot
.21081 .59621 Mdot
.28051 .6745 Mdot
.40705 .14001 Mdot
.15476 .58149 Mdot
.10657 .60129 Mdot
.83046 .24563 Mdot
.46215 .14814 Mdot
.30733 .21796 Mdot
.80769 .2228 Mdot
.04228 .18377 Mdot
.40624 .11657 Mdot
.56832 .22815 Mdot
.25986 .6894 Mdot
.09246 .60879 Mdot
.44735 .19212 Mdot
.32092 .83092 Mdot
.35251 .79279 Mdot
.24394 .64395 Mdot
.18303 .57156 Mdot
.31135 .39232 Mdot
.09168 .6129 Mdot
.28749 .92894 Mdot
.32383 .60093 Mdot
.20776 .99994 Mdot
.48791 .17925 Mdot
.29464 .58455 Mdot
.32975 .79955 Mdot
.14028 .52677 Mdot
.37588 .86279 Mdot
.20929 .98276 Mdot
.50211 .26545 Mdot
.23426 .91153 Mdot
.34839 .83677 Mdot
.33527 .73496 Mdot
.32734 .45997 Mdot
.09549 .60039 Mdot
.22892 .92433 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00Co0000oooooooooooooooo1?l00008ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool01oooool2o`0000Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02oooo
o`007_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0>ooooo`04o`000?ooooooooooooooo`Co00002?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo0_l00004ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool00_ooool001kooooo00?o0000ooooooooool0Aoooool2o`000?ko
oooo000Nooooo`03o`000?oooooooooo03Wooooo0_l0000<ooooo`;o00006Oooool2o`000>?ooooo
000Nooooo`03o`000?oooooooooo03Wooooo0_l0000Kooooo`;o00002_ooool2o`000>?ooooo000N
ooooo`03o`000?oooooooooo05Kooooo0_l0003_ooooo`007_ooool00ol0003oooooooooo`16oooo
o`;o00005Oooool3o`000>Oooooo000Nooooo`03o`000?oooooooooo04Kooooo0ol0000Cooooo`Co
0000=?ooool2o`000;7ooooo000Nooooo`03o`000?oooooooooo04Oooooo0_l0000Cooooo`;o0000
2Oooool2o`0002_ooooo0_l0002aooooo`007_ooool00ol0003oooooooooo`0jooooo`;o0000:ooo
ool2o`000=kooooo000Nooooo`03o`000?oooooooooo03Gooooo0_l00003ooooo`?o00003oooool4
o`000?Oooooo000Nooooo`03o`000?oooooooooo03Gooooo0_l00003ooooo`?o00003oooool4o`00
0?Oooooo000Nooooo`03o`000?oooooooooo03[ooooo0_l00002ooooo`;o00003?ooool2o`0000Ko
oooo0_l0003aooooo`007_ooool00ol0003oooooooooo`0Nooooo`;o00007_ooool2o`0000cooooo
0_l00006ooooo`;o0000lOooool001kooooo00?o0000ooooooooool07_ooool2o`0002oooooo0_l0
0002ooooo`;o00004oooool2o`000=gooooo000Nooooo`03o`000?oooooooooo04Gooooo0_l00007
ooooo`?o00000_ooool2o`0001?ooooo0_l0003Mooooo`007_ooool2o`00047ooooo0_l00003oooo
o`;o00001oooool2o`0000Kooooo0_l0003_ooooo`007_ooool00ol0003oooooooooo`10ooooo`;o
00005?ooool2o`000>oooooo000Nooooo`03o`000?oooooooooo04Sooooo0_l0003mooooo`007_oo
ool00ol0003oooooooooo`18ooooo`;o0000oOooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo04Oo
oooo0_l0000Iooooo`;o0000hoooool001kooooo00?o0000ooooooooool0Aoooool2o`0000_ooooo
0_l0000<ooooo`?o00000oooool2o`000=gooooo000Nooooo`03o`000?oooooooooo05Cooooo0_l0
000=ooooo`;o00000oooool2o`0000;ooooo0_l0003Iooooo`007_ooool00ol0003oooooooooo`1L
ooooo`;o00003_ooool2o`000=Wooooo000Nooooo`03o`000?oooooooooo05cooooo0_l00006oooo
o`;o0000hOooool001kooooo00?o0000ooooooooool0F_ooool2o`0000Gooooo0_l000001?oooooo
0000o`000?ooool2o`00013ooooo0_l0003<ooooo`007_ooool00ol0003oooooooooo`1:ooooo`;o
00003_ooool2o`0000Gooooo0_l00004ooooo`;o00004?ooool2o`0000Kooooo0_l00034ooooo`00
7_ooool00ol0003oooooooooo`1:ooooo`;o0000=Oooool2o`0000Oooooo0_l0002kooooo`007_oo
ool00ol0003oooooooooo`10ooooo`;o0000B?ooool2o`000;_ooooo000Nooooo`03o`000?oooooo
oooo043ooooo0_l0003oooooo`Kooooo000Nooooo`;o0000@?ooool2o`0003?ooooo0_l0000;oooo
o`;o0000]_ooool2o`0000cooooo000Nooooo`03o`000?oooooooooo03oooooo0_l00008ooooo`;o
0000:Oooool2o`0000_ooooo0_l0002fooooo`;o00003?ooool001kooooo00?o0000ooooooooool0
BOooool2o`0000Wooooo0_l0000]ooooo`;o0000`_ooool001kooooo00?o0000ooooooooool0E?oo
ool2o`0000_ooooo0_l0000Pooooo`;o0000`_ooool001kooooo00?o0000ooooooooool0HOooool3
o`0002Gooooo0_l0000Rooooo`;o0000V?ooool001kooooo00?o0000ooooooooool0H_ooool2o`00
01cooooo0_l00007ooooo`;o00008_ooool2o`0009Sooooo000Nooooo`03o`000?oooooooooo083o
oooo0_l00008ooooo`;o0000^oooool001kooooo00?o0000ooooooooool0>_ooool2o`0004;ooooo
0_l00009ooooo`?o0000^oooool001kooooo00?o0000ooooooooool0>_ooool2o`0002Oooooo0_l0
0005ooooo`;o00004_ooool2o`0000Wooooo0_l0002looooo`007_ooool00ol0003oooooooooo`1S
ooooo`;o00001Oooool2o`0000[ooooo0_l0000gooooo`;o0000U_ooool001kooooo00?o0000oooo
ooooool0MOooool3o`000003ooooool0003o000003Cooooo0_l0002Fooooo`007_ooool00ol0003o
ooooooooo`1eooooo`;o00000_ooool2o`0003?ooooo0_l0002Gooooo`007_ooool00ol0003ooooo
ooooo`03ooooo`;o0000Goooool2o`0004Sooooo0_l0002Gooooo`007_ooool00ol0003ooooooooo
o`03ooooo`;o0000Goooool2o`0001;ooooo0_l00006ooooo`;o0000aOooool001kooooo00?o0000
ooooooooool0B_ooool2o`0001Sooooo0_l0000Booooo`;o00001_ooool2o`0003Oooooo0_l0002<
ooooo`007_ooool00ol0003oooooooooo`1:ooooo`;o00006?ooool2o`0000cooooo0ol0000Koooo
o`Co00009Oooool2o`0008cooooo000Nooooo`;o00009?ooool2o`0001?ooooo0_l0000Xooooo`Co
00003?ooool3o`0001Gooooo0_l00004ooooo`Co00001Oooool2o`0002Cooooo0_l00026ooooo`00
7_ooool00ol0003oooooooooo`0Sooooo`;o00004oooool2o`00013ooooo0ol0000?ooooo`?o0000
0oooool4o`0001Cooooo0_l0000>ooooo`;o000000?oooooo`000?l000002_ooool2o`0002Cooooo
0_l00026ooooo`007_ooool00ol0003oooooooooo`0Yooooo`;o00007oooool3o`0000oooooo0ol0
000Kooooo`;o00004Oooool4o`0002Kooooo0_l0002>ooooo`007_ooool00ol0003oooooooooo`0Y
ooooo`;o0000I?ooool2o`0002Kooooo0_l0002>ooooo`007_ooool00ol0003oooooooooo`0Joooo
o`;o00009_ooool2o`000?oooooo1?ooool001kooooo00?o0000ooooooooool06_ooool2o`0002Ko
oooo0_l00009ooooo`;o0000;?ooool2o`0004Sooooo0ol0001oooooo`007_ooool00ol0003ooooo
ooooo`1=ooooo`;o0000;?ooool2o`0000Sooooo0_l0000nooooo`?o0000Ooooool001kooooo00?o
0000ooooooooool0P_ooool2o`000004ooooool0003o0000ooooo`;o00001Oooool2o`000;Kooooo
000Nooooo`03o`000?oooooooooo087ooooo0ol00004ooooo`;o00001Oooool2o`0000_ooooo0_l0
000kooooo`;o0000K?ooool001kooooo00?o0000ooooooooool0POooool2o`0001?ooooo0_l00003
ooooo`?o0000>oooool2o`0000Oooooo0_l0001Sooooo`007_ooool00ol0003oooooooooo`2Foooo
o`;o00000oooool2o`0003Cooooo0_l00002ooooo`Co00001oooool4o`0006?ooooo000Nooooo`03
o`000?oooooooooo00[ooooo0_l00035ooooo`;o00000_ooool4o`0000Oooooo0_l0001Uooooo`00
7_ooool00ol0003oooooooooo`04ooooo`;o00001?ooool2o`0007Gooooo0_l00016ooooo`;o0000
O?ooool001kooooo00?o0000ooooooooool01?ooool2o`0004[ooooo0_l0000Booooo`;o00006ooo
ool2o`0000Wooooo0ol0000jooooo`;o0000Koooool2o`0000_ooooo0003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo053ooooo0_l0
000Booooo`;o00009_ooool3o`0000cooooo0_l0000>ooooo`;o0000?Oooool2o`0004kooooo0_l0
000;ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`2Kooooo`;o00003_ooool2o`0003Wooooo
0_l00002ooooo`;o0000Foooool000?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo0ol0001Fooooo`;o0000S_ooool2o`0005oooooo0003ooooo`05o`000?oo
ooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo05Kooooo
0_l0001@ooooo`;o0000<?ooool2o`0000cooooo0_l00007ooooo`;o0000B?ooool2o`0000[ooooo
0003ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`00
0?oooooooooo03Gooooo0_l00017ooooo`;o0000:?ooool2o`0002;ooooo0_l0000<ooooo`;o0000
3?ooool2o`0000Cooooo0_l000000ooooooo0000o`000018ooooo`;o00002_ooool000?ooooo00Go
410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
=Oooool2o`0002Oooooo0_l0000Nooooo`;o0000:_ooool2o`00013ooooo0_l0000>ooooo`;o0000
8?ooool2o`0000?ooooo0_l0001Booooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo04Oooooo0ol00003ooooo`;o
00003oooool2o`0004Gooooo0_l00003ooooo`;o00004?ooool2o`0003Gooooo1?l0001@ooooo`00
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006oooo
o`03o`000?oooooooooo04Oooooo0ol00003ooooo`;o0000E_ooool2o`0000Gooooo0_l0000]oooo
o`;o00001oooool2o`0000Gooooo0_l00005ooooo`Go0000A_ooool2o`0000Sooooo000Nooooo`03
o`000?oooooooooo04[ooooo0_l0000Dooooo`;o0000B_ooool2o`0001oooooo0_l00007ooooo`;o
00000oooool2o`0000Oooooo0_l00005ooooo`;o00001Oooool4o`0004Oooooo0_l00008ooooo`00
7_ooool00ol0003oooooooooo`1:ooooo`;o00005?ooool2o`00023ooooo0_l00019ooooo`;o0000
0oooool6o`0001?ooooo0_l00007ooooo`;o00001?ooool2o`0000Kooooo0_l0000Xooooo`;o0000
00?oooooo`000?l000005_ooool001kooooo00?o0000ooooooooool0P_ooool2o`0004kooooo1_l0
000Hooooo`;o00001?ooool2o`0000;ooooo0_l00006ooooo`;o0000:?ooool5o`0001Kooooo000N
ooooo`03o`000?oooooooooo0;Gooooo0_l00008ooooo`;o00000oooool2o`0002[ooooo0_l00003
ooooo`?o0000:_ooool2o`0000Cooooo0_l00004ooooo`;o00005oooool001kooooo00?o0000oooo
ooooool0A?ooool2o`0006oooooo0_l00008ooooo`;o00000oooool2o`0002oooooo0_l0000Zoooo
o`?o00001?ooool2o`0001gooooo000Nooooo`03o`000?oooooooooo027ooooo0_l0000Qooooo`;o
0000Y_ooool2o`0000[ooooo1?l00005ooooo`;o00007Oooool3o`0002Cooooo000Nooooo`03o`00
0?oooooooooo027ooooo0_l0000Tooooo`;o0000Woooool2o`0000;ooooo0_l0000:ooooo`Co0000
1Oooool2o`0000?ooooo0_l0000Hooooo`;o00009Oooool001kooooo00?o0000ooooooooool0AOoo
ool4o`0009oooooo0_l0000Looooo`;o00001_ooool2o`0002gooooo0_l00008ooooo`007_ooool0
0ol0003oooooooooo`15ooooo`;o0000`?ooool2o`0000Gooooo1?l00003ooooo`;o00009_ooool2
o`0000Sooooo000Nooooo`03o`000?oooooooooo0?oooooo0oooool2o`0000?ooooo0_l000000ooo
oooo0000o`000002ooooo`Co00000oooool2o`00033ooooo000Nooooo`03o`000?oooooooooo0?Oo
oooo0_l00004ooooo`;o00000oooool2o`0000Kooooo0_l000000ooooooo0000o`000003o`0003Go
oooo000Nooooo`;o00005_ooool2o`000=Wooooo0_l00005ooooo`;o00001?ooool2o`0000kooooo
1?l0000fooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o0000fOooool2o`0001_ooooo0_l0
000hooooo`007_ooool00ol0003oooooooooo`1Tooooo`;o0000Soooool2o`00053ooooo000Noooo
o`03o`000?oooooooooo06Cooooo0_l00025ooooo`;o00002?ooool2o`0001[ooooo0_l0000doooo
o`007_ooool00ol0003oooooooooo`2Oooooo`;o0000@_ooool2o`0000Kooooo0_l0000;ooooo`?o
00005_ooool2o`0003Cooooo000Nooooo`03o`000?oooooooooo09oooooo0_l00012ooooo`;o0000
4oooool3o`0000Cooooo0_l00016ooooo`007_ooool00ol0003oooooooooo`0`ooooo`;o0000cOoo
ool2o`0001Cooooo0ol0000_ooooo`007_ooool00ol0003oooooooooo`0`ooooo`;o0000^_ooool2
o`0002Oooooo1?l0000^ooooo`007_ooool00ol0003oooooooooo`1Mooooo`;o0000SOooool2o`00
02Wooooo1?l0000/ooooo`007_ooool00ol0003oooooooooo`1Mooooo`;o0000^_ooool2o`0002co
oooo000Nooooo`03o`000?oooooooooo05kooooo0_l0003Wooooo`007_ooool00ol0003ooooooooo
o`1Nooooo`;o0000ioooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooo`gooooo0_l0000iooooo`007_ooool00ol0003oooooooooo`1>ooooo`;o
0000_?ooool2o`0003Wooooo000Nooooo`03o`000?oooooooooo04kooooo0_l0000<ooooo`;o0000
jOooool001kooooo0_l0001Mooooo`;o0000`Oooool2o`0002Kooooo000Nooooo`03o`000?oooooo
oooo0>gooooo0_l0000`ooooo`;o00009_ooool001kooooo00?o0000ooooooooool0FOooool2o`00
09;ooooo0_l0000aooooo`;o00009Oooool001kooooo00?o0000ooooooooool0FOooool2o`000<Go
oooo0_l0000Uooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo05oooooo0_l0002/ooooo`;o0000>?ooool001kooooo00?o0000ooooooooool0Goooool2
o`000:cooooo0_l0000hooooo`007_ooool3o`00067ooooo0_l0003Tooooo`007_ooool3o`00067o
oooo0_l0003Tooooo`007_ooool00ol0003oooooooooo`1Vooooo`;o0000goooool001kooooo00?o
0000ooooooooool0I_ooool2o`0001Gooooo0_l00038ooooo`007_ooool00ol0003oooooooooo`1S
ooooo`;o00006?ooool2o`0000Sooooo0_l0000Jooooo`;o0000X_ooool001kooooo00?o0000oooo
ooooool0Hoooool2o`0002;ooooo0_l0000Jooooo`;o0000X_ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`1Uooooo`;o0000h?ooool001kooooo00?o
0000ooooooooool0IOooool2o`000>3ooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool02_ooool2o`000?oooooo??ooool001kooooo00?o0000ooooooooool02_oo
ool2o`000?oooooo??ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`1Wooooo`;o0000g_ooool001kooooo00?o0000ooooooooool0Eoooool2o`0000ko
oooo0_l0003>ooooo`;o00003_ooool001kooooo00?o0000ooooooooool0?_ooool2o`0001Oooooo
0_l0000looooo`;o00008Oooool2o`0007gooooo0_l0000>ooooo`007_ooool00ol0003ooooooooo
o`0nooooo`;o0000EOooool2o`00027ooooo0_l0002=ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0?_ooool2o`000?oooooo2?ooool001kooooo00?o0000ooooooooool0?_ooool2o`0005kooooo
0_l0002Wooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o0000
00?o410@ooooooooool01?ooool00ol0003oooooooooo`1Qooooo`;o00006?ooool2o`00027ooooo
0_l0002Wooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0HOooool2o`0001Sooooo0_l0003:ooooo`000ooo
ool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`?o0000oooooom8ooooo`000ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`0jooooo`;o0000ooooool<ooooo`000oooool01Ol0003ooooooooooooooooo000000_o
oooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`0jooooo`;o0000ooooool<oooo
o`000oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0
003oooooooooo`04ooooo`;o0000ooooool7ooooo`;o0000>Oooool000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool01?ooool2o`00
03Cooooo0_l0003@ooooo`;o0000>Oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=oooo
o`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0>_ooool2o`000?oooooo3?ooool001ko
oooo00?o0000ooooooooool0@oooool2o`000?oooooo0oooool001kooooo00?o0000ooooooooool0
@oooool2o`0000gooooo0_l0000looooo`;o0000]Oooool001kooooo00?o0000ooooooooool03ooo
ool2o`00047ooooo0_l0000looooo`;o0000SOooool2o`0002Kooooo000Nooooo`03o`000?oooooo
oooo00oooooo0_l0001:ooooo`;o0000`_ooool2o`0002Kooooo000Nooooo`04o`000?oooooo0000
o`00023ooooo0_l0000hooooo`;o0000j_ooool001kooooo00Co0000ooooool0003o00008?ooool2
o`000?oooooo9Oooool001kooooo00?o0000ooooooooool03_ooool2o`000003ooooool0003o0000
02cooooo0_l00002ooooo`;o0000ooooool3ooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o
000000?oooooo`000?l00000;?ooool2o`0000;ooooo0_l0000Pooooo`;o0000]_ooool2o`0002So
oooo000Nooooo`03o`000?oooooooooo03Oooooo0_l0000/ooooo`;o0000]_ooool2o`0002Sooooo
000Nooooo`03o`000?oooooooooo00Oooooo0_l0000^ooooo`;o0000<_ooool2o`000=[ooooo000N
ooooo`03o`000?oooooooooo00Oooooo0_l0001Rooooo`;o0000f_ooool001kooooo0_l0000=oooo
o`;o00003_ooool2o`000?oooooo:_ooool001kooooo00?o0000ooooooooool03?ooool2o`0000ko
oooo0_l0003oooooob[ooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool05oooool2o`0004gooooo0_l0003Oooooo`007_ooool00ol0003oooooooooo`0<
ooooo`;o00002Oooool2o`0004gooooo0_l0003Oooooo`007_ooool00ol0003oooooooooo`0<oooo
o`;o0000aOooool2o`0007;ooooo000Nooooo`03o`000?oooooooooo01kooooo0_l0002cooooo`;o
0000L_ooool001kooooo00?o0000ooooooooool07_ooool3o`000?oooooo9oooool001kooooo00?o
0000ooooooooool07Oooool4o`000?oooooo9oooool001kooooo00?o0000ooooooooool07Oooool2
o`0000?ooooo0_l0001Tooooo`;o0000_Oooool001kooooo00?o0000ooooooooool08_ooool2o`00
03gooooo0_l0000Uooooo`;o0000_Oooool001kooooo00?o0000ooooooooool0=oooool2o`0002So
oooo0_l0003Tooooo`007_ooool00ol0003oooooooooo`0gooooo`;o0000ooooool?ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo06Cooooo0_l0003Q
ooooo`007_ooool00ol0003oooooooooo`1Tooooo`;o0000hOooool001kooooo0_l0003oooooodWo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool02?oo
ool2o`0001cooooo0_l0000;ooooo`;o0000oooooolCooooo`007_ooool00ol0003oooooooooo`08
ooooo`;o00001oooool2o`0001?ooooo0_l00006ooooo`;o00000oooool2o`000?oooooo4oooool0
01kooooo00?o0000ooooooooool04Oooool2o`0001Gooooo0_l00004ooooo`;o0000?oooool2o`00
0=Kooooo000Nooooo`03o`000?oooooooooo02Sooooo0_l00006ooooo`;o0000?Oooool2o`000=Ko
oooo000Nooooo`03o`000?oooooooooo02kooooo1?l0000:ooooo`;o0000ooooool:ooooo`007_oo
ool00ol0003oooooooooo`0^ooooo`?o00002oooool2o`000>Wooooo0_l0000Nooooo`007_ooool0
0ol0003oooooooooo`0Yooooo`;o00001?ooool2o`0001cooooo0_l00009ooooo`;o00001oooool2
o`000<Cooooo0_l0000Nooooo`007_ooool00ol0003oooooooooo`0Yooooo`;o00000oooool2o`00
00Gooooo0_l00009ooooo`?o000000?oooooo`000?l000001oooool2o`0000Oooooo1?l00007oooo
o`;o0000i?ooool001kooooo00?o0000ooooooooool0;_ooool2o`0000Gooooo0_l00009ooooo`?o
000000?oooooo`000?l000004?ooool2o`0001Cooooo0_l0003Iooooo`007_ooool00ol0003ooooo
ooooo`0cooooo`;o00003oooool2o`0000?ooooo0_l0000Qooooo`;o00000_ooool2o`000=Gooooo
000Nooooo`03o`000?oooooooooo00Sooooo0_l0000Yooooo`?o00003_ooool2o`0000?ooooo1?l0
000Sooooo`?o0000e?ooool001kooooo00?o0000ooooooooool02?ooool2o`0002[ooooo0_l0000<
ooooo`;o000000?oooooo`000?l000001?ooool2o`0002Cooooo0_l0003Dooooo`007_ooool00ol0
003oooooooooo`12ooooo`;o000000?oooooo`000?l00000ooooool1ooooo`007_ooool00ol0003o
ooooooooo`13ooooo`;o00002_ooool2o`000?Kooooo000Nooooo`;o0000A?ooool2o`0000[ooooo
0_l0003fooooo`007_ooool00ol0003oooooooooo`1Yooooo`;o0000g?ooool001kooooo00?o0000
ooooooooool0E_ooool4o`0000oooooo0_l0003Looooo`007_ooool00ol0003oooooooooo`1?oooo
o`;o00001Oooool4o`000>gooooo000Nooooo`03o`000?oooooooooo03Cooooo0_l0000Iooooo`;o
0000m_ooool001kooooo00?o0000ooooooooool0;?ooool4o`0000Cooooo0_l00003ooooo`;o0000
4_ooool2o`000?Sooooo000Nooooo`03o`000?oooooooooo02Wooooo1ol00009ooooo`Co00004?oo
ool2o`0000?ooooo0_l0003cooooo`007_ooool00ol0003oooooooooo`0Xooooo`Co00001Oooool2
o`0000Cooooo0_l00002ooooo`;o00001Oooool2o`0000kooooo0_l0003cooooo`007_ooool00ol0
003oooooooooo`0Sooooo`;o000000?oooooo`000?l000001?l00005ooooo`;o00000oooool3o`00
00?ooooo0_l000001?oooooo0000o`000?ooool2o`0000cooooo1?l0000@ooooo`;o0000hOooool0
01kooooo00?o0000ooooooooool08oooool2o`000003ooooool0003o000000Co00002_ooool2o`00
00Cooooo0_l000000ooooooo0000o`00000?ooooo`Ko00003_ooool2o`000>7ooooo000Nooooo`03
o`000?oooooooooo02?ooooo0_l00003ooooo`;o00001?ooool2o`0000Oooooo0_l00006ooooo`;o
00002oooool2o`0000Kooooo0_l00008ooooo`;o00001oooool2o`0000Kooooo0_l00002ooooo`;o
0000d_ooool001kooooo00?o0000ooooooooool08_ooool2o`0000[ooooo0_l00007ooooo`;o0000
4oooool2o`000003ooooool0003o000000?ooooo0_l00006ooooo`Co00001oooool2o`0000Kooooo
0_l00002ooooo`;o0000d_ooool001kooooo00?o0000ooooooooool08_ooool2o`0000Cooooo0_l0
000Sooooo`Co000000?oooooo`000?l000001?l00004ooooo`;o00001oooool2o`000003ooooool0
003o000000Oooooo0_l0003Dooooo`007_ooool00ol0003oooooooooo`0Xooooo`?o00001Oooool2
o`0000;ooooo0_l0000Gooooo`;o00000oooool2o`0000;ooooo0_l000001?oooooo0000o`000?oo
ool4o`0000Gooooo0_l000000ooooooo0000o`000007ooooo`;o0000DOooool2o`00087ooooo0003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@
olc<c006ooooo`03o`000?oooooooooo023ooooo0_l00007ooooo`;o00001Oooool2o`0000;ooooo
0_l0000Fooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`Wo0000H_ooool2o`00087o
oooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMooo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo023ooooo0_l00002ooooo`;o00006_ooool3o`00
00Wooooo0_l00005ooooo`;o00000_ooool2o`0000;ooooo0_l00002ooooo`?o000000?oooooo`00
0?l00000`?ooool2o`00023ooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0
003ooooooooooooooooo000000Kooooo0ol0000Kooooo`;o00000oooool2o`0000;ooooo0_l0000C
ooooo`;o00001Oooool3o`0001Cooooo0_l0000:ooooo`Co0000__ooool2o`00023ooooo0003oooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o
0000ooooooooool06oooool2o`0000;ooooo0ol0000<ooooo`;o00002Oooool2o`0000[ooooo0_l0
0006ooooo`;o00002?ooool2o`0000?ooooo0_l00004ooooo`Go00003Oooool2o`000=7ooooo0003
ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo
00?o0000ooooooooool06oooool2o`0000;ooooo0_l0000=ooooo`;o00000oooool2o`0000Cooooo
0_l0000:ooooo`;o00001_ooool2o`0000Sooooo0_l00003ooooo`;o00001?ooool2o`0000?ooooo
0_l0000:ooooo`?o0000dOooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEE
EOn7QhOooooo00Sooooo00?o0000ooooooooool06_ooool3o`0000;ooooo0_l0000=ooooo`;o0000
0oooool3o`0001Cooooo0_l0000;ooooo`;o000000?oooooo`000?l000002oooool2o`0000[ooooo
0_l0003Booooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0
2?ooool00ol0003oooooooooo`0Jooooo`?o00000oooool2o`0000?ooooo1?l00003ooooo`;o0000
1_ooool2o`0000?ooooo0_l0000?ooooo`;o00002oooool2o`000003ooooool0003o000001Sooooo
0_l0001dooooo`;o0000:_ooool2o`0002oooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo01[ooooo0ol00003ooooo`;o
00000oooool4o`0000;ooooo0ol00006ooooo`;o00000oooool2o`00013ooooo0_l0000>ooooo`?o
00002?ooool2o`0000cooooo0_l0001dooooo`;o0000:_ooool2o`0002oooooo000Nooooo`03o`00
0?oooooooooo023ooooo0_l00009ooooo`;o00000_ooool2o`0000?ooooo0_l0000?ooooo`?o0000
0oooool2o`0000kooooo1?l00005ooooo`Co00002oooool2o`0000;ooooo0_l0003>ooooo`007_oo
ool00ol0003oooooooooo`0Pooooo`;o00003Oooool2o`0001Cooooo0ol00002ooooo`?o00002_oo
ool2o`0000?ooooo0ol00005ooooo`;o00002?ooool2o`0000?ooooo0_l00002ooooo`;o0000c_oo
ool001kooooo00?o0000ooooooooool07_ooool2o`0000[ooooo0_l00006ooooo`;o00004_ooool2
o`0000;ooooo0ol00003ooooo`;o00001Oooool3o`0001?ooooo0ol00003ooooo`;o0000FOooool2
o`0007Oooooo000Nooooo`03o`000?oooooooooo01_ooooo0_l000000ooooooo0000o`000004oooo
o`;o00000oooool3o`0000Kooooo0_l00007ooooo`;o00000_ooool2o`0000Gooooo0_l00008oooo
o`;o00000_ooool6o`0000Kooooo0_l0000;ooooo`;o000000Coooooo`000?l0003ooooo0_l00000
0ooooooo0000o`000003ooooo`;o0000DOooool2o`0007Oooooo000Nooooo`03o`000?oooooooooo
01_ooooo0_l00007ooooo`;o00000oooool3o`0000oooooo0_l00002ooooo`?o00004_ooool4o`00
00Cooooo1ol0000=ooooo`;o00001?ooool2o`0000;ooooo0ol0000Wooooo`;o0000XOooool001ko
oooo00?o0000ooooooooool09oooool2o`0000Oooooo0_l00009ooooo`;o00000oooool2o`0000oo
oooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo1?l000000ooooooo0000o`000007oooo
o`;o00003_ooool2o`0002Sooooo0_l0002Qooooo`007_ooool00ol0003oooooooooo`0Wooooo`;o
00001oooool2o`0000Wooooo0_l0000Dooooo`;o00000oooool2o`000003ooooool0003o000000;o
oooo1?l00003ooooo`;o00001?ooool2o`0000Cooooo0_l0003Eooooo`007_ooool00ol0003ooooo
ooooo`0Zooooo`;o0000<Oooool4o`0000?ooooo0_l0000:ooooo`;o0000eOooool001kooooo00?o
0000ooooooooool08?ooool2o`0000Cooooo0_l000001?oooooo0000o`000?l0000Oooooo`;o0000
1Oooool4o`0000Kooooo0ol00003ooooo`;o0000POooool2o`00063ooooo000Nooooo`03o`000?oo
oooooooo023ooooo0_l00002ooooo`Oo000000?oooooo`000?l000000oooool3o`0001Oooooo0_l0
0005ooooo`Ko00001?ooool2o`0000?ooooo0ol00002ooooo`;o00002_ooool2o`00077ooooo0_l0
001Pooooo`007_ooool00ol0003oooooooooo`0Qooooo`;o000000?oooooo`000?l000001?l00002
ooooo`;o00000oooool3o`0000Kooooo0_l0000Gooooo`Go00002Oooool2o`0000?ooooo0_l0000:
ooooo`;o00002?ooool2o`000<Wooooo000Nooooo`;o00008_ooool2o`0000;ooooo0ol0000Boooo
o`;o00000_ooool2o`0000Sooooo0_l00009ooooo`Co00001?ooool2o`0000Cooooo0ol0000;oooo
o`;o00002oooool2o`000<Wooooo000Nooooo`03o`000?oooooooooo02Oooooo1Ol00004ooooo`;o
00003?ooool2o`0000Sooooo0_l00009ooooo`?o00001Oooool9o`0000Cooooo0_l00005ooooo`;o
0000e_ooool001kooooo00?o0000ooooooooool09oooool5o`0000;ooooo1Ol00008ooooo`;o0000
3Oooool2o`000003ooooool0003o000000Gooooo0_l00005ooooo`Ko00001?ooool2o`000004oooo
ool0003o0000ooooo`Go00002oooool2o`000<[ooooo000Nooooo`03o`000?oooooooooo02Oooooo
0ol00002ooooo`Co000000Coooooo`000?l0003ooooo0ol00004ooooo`;o00003Oooool2o`000004
ooooool0003o0000ooooo`;o00002Oooool2o`0000;ooooo0_l00004ooooo`?o00000oooool5o`00
00_ooooo0_l0003:ooooo`007_ooool00ol0003oooooooooo`0/ooooo`Co00001?ooool3o`0000[o
oooo0_l000000ooooooo0000o`00000:ooooo`So00000oooool2o`0000Wooooo0_l00004ooooo`;o
00000_ooool2o`000=Gooooo000Nooooo`03o`000?oooooooooo02_ooooo1?l0000@ooooo`Co0000
00?oooooo`000?l000002oooool7o`0000gooooo0_l00009ooooo`;o0000eOooool001kooooo00?o
0000ooooooooool09oooool2o`0000;ooooo0_l00006ooooo`;o00001Oooool3o`000004ooooool0
003o0000o`00013ooooo3Ol00006ooooo`?o00002?ooool2o`000=Kooooo000Nooooo`03o`000?oo
oooooooo02Oooooo0_l0000:ooooo`;o00001Oooool3o`000003ooooool0003o000000;o00003ooo
ool5o`000003ooooool0003o000000Go00001_ooool2o`0000Wooooo0_l0000nooooo`;o0000U_oo
ool001kooooo00?o0000ooooooooool09oooool2o`0001?ooooo0_l00002ooooo`Co000000Cooooo
o`000?l0003ooooo1?l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l000001?oooooo0000
o`000?ooool2o`0001oooooo0_l0000booooo`;o0000U_ooool001kooooo00?o0000ooooooooool0
9oooool4o`00017ooooo0_l000000ooooooo0000o`000003o`000004ooooool0003o0000ooooo`Go
000000Coooooo`000?l0003ooooo1Ol00003ooooo`;o00002Oooool2o`0001Gooooo0_l0003:oooo
o`007_ooool00ol0003oooooooooo`0Xooooo`?o00005?ooool3o`0000Wooooo0_l00006ooooo`;o
00001?ooool2o`0000Wooooo0_l0003Qooooo`007_ooool00ol0003oooooooooo`1;ooooo`;o0000
1_ooool2o`0002Oooooo0_l00039ooooo`007_ooool00ol0003oooooooooo`1;ooooo`;o000000?o
ooooo`000?l000001?l00002ooooo`;o00009?ooool2o`000<Wooooo000Nooooo`03o`000?oooooo
oooo04kooooo1_l00002ooooo`;o0000koooool001kooooo00?o0000ooooooooool0D?ooool2o`00
00gooooo0_l0003Vooooo`007_ooool00ol0003oooooooooo`1Oooooo`;o00002_ooool2o`000;3o
oooo0_l0000Xooooo`007_ooool2o`0005Cooooo0_l0000Fooooo`;o0000/?ooool2o`0002Sooooo
000Nooooo`03o`000?oooooooooo05?ooooo0ol00004ooooo`;o00002?ooool2o`0009oooooo0_l0
0010ooooo`007_ooool00ol0003oooooooooo`0_ooooo`;o00006Oooool2o`0000Sooooo2?l00005
ooooo`;o000000Coooooo`000?l0003o0000W_ooool2o`00043ooooo000Nooooo`03o`000?oooooo
oooo02oooooo0_l0000Iooooo`;o00002Oooool5o`0000Oooooo0_l00002ooooo`;o0000h?ooool0
01kooooo00?o0000ooooooooool0>Oooool2o`0000Kooooo0_l0000oooooo`;o0000`oooool001ko
oooo00?o0000ooooooooool0>Oooool2o`0000Kooooo0_l0000oooooo`;o0000`oooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`0Xooooo`;o0000=Ooo
ool2o`000>Kooooo000Nooooo`03o`000?oooooooooo02Sooooo0_l0000eooooo`;o0000i_ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`1eooooo`;o
0000d?ooool001kooooo00?o0000ooooooooool0Doooool2o`0001Cooooo0_l0000:ooooo`;o0000
d?ooool001kooooo00?o0000ooooooooool0Doooool2o`0001Cooooo0_l0003Looooo`007_ooool0
0ol0003oooooooooo`1]ooooo`;o0000f?ooool001kooooo00?o0000ooooooooool0Boooool2o`00
00Oooooo0_l0000Gooooo`;o00002oooool2o`000<_ooooo000Nooooo`03o`000?oooooooooo02So
oooo0_l0000Qooooo`;o00001oooool2o`0001Sooooo0_l0000:ooooo`;o0000boooool001kooooo
0_l0000Yooooo`;o0000A?ooool2o`00013ooooo0_l00035ooooo`007_ooool00ol0003ooooooooo
o`1Uooooo`;o00006Oooool2o`000<Gooooo000Nooooo`03o`000?oooooooooo04Cooooo0_l0000:
ooooo`;o00004oooool2o`000>3ooooo000Nooooo`03o`000?oooooooooo04Cooooo0_l0000:oooo
o`;o0000?Oooool2o`000;Kooooo000Nooooo`03o`000?oooooooooo06Oooooo0_l0000Vooooo`;o
0000]_ooool001kooooo00?o0000ooooooooool0Ioooool2o`000=kooooo000Nooooo`03o`000?oo
oooooooo07cooooo0_l00039ooooo`007_ooool00ol0003oooooooooo`0Zooooo`;o000000?ooooo
o`000?l00000COooool2o`0003Wooooo0_l0002>ooooo`007_ooool00ol0003oooooooooo`0Zoooo
o`;o000000?oooooo`000?l00000;oooool2o`0002Wooooo0_l0000/ooooo`;o0000S_ooool001ko
oooo00?o0000ooooooooool0:_ooool2o`0003;ooooo0_l000000ooooooo0000o`00000Vooooo`;o
0000_?ooool001kooooo00?o0000ooooooooool0:_ooool2o`0003Gooooo0_l0000Kooooo`;o0000
aoooool001kooooo00?o0000ooooooooool0<?ooool2o`0004cooooo0_l00037ooooo`007_ooool0
0ol0003oooooooooo`0`ooooo`;o00009oooool2o`0002Oooooo0_l00033ooooo`007_ooool00ol0
003oooooooooo`1Iooooo`;o00009oooool2o`000<?ooooo0003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooo
oooo06kooooo0_l0000?ooooo`;o00000_ooool2o`000<;ooooo0003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oo
oooooooo06kooooo1?l0000=ooooo`;o00000_ooool2o`000<;ooooo0003ooooo`05oa0@4?oooooo
ooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0000Zooooo`;o0000
=Oooool2o`0000Cooooo0_l00007ooooo`;o0000eOooool000?ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool00ol0003oooooooooo`0Zooooo`;o
0000=Oooool2o`0000Cooooo0_l0003Nooooo`000oooool01Ol0003ooooooooooooooooo000000_o
oooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo04oooooo0_l0003foooo
o`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006
ooooo`03o`000?oooooooooo04oooooo0_l0000Fooooo`;o00005oooool2o`000<Gooooo0003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o
0000ooooooooool0<oooool2o`0002Oooooo0_l00009ooooo`;o00001_ooool2o`0000oooooo0_l0
0035ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@06ooooo`03o`000?oooooooooo03?ooooo1?l0000Uooooo`;o00004Oooool2o`000=Kooooo
000Nooooo`03o`000?oooooooooo03Gooooo0_l0001:ooooo`;o0000a?ooool001kooooo00?o0000
ooooooooool0;?ooool2o`0002gooooo0_l0000;ooooo`;o00005oooool2o`000<Cooooo000Noooo
o`03o`000?oooooooooo02cooooo0_l0000Fooooo`;o00005Oooool2o`0000?ooooo0_l00006oooo
o`;o0000gOooool001kooooo00?o0000ooooooooool0:?ooool2o`0001[ooooo0_l0000Eooooo`;o
00000oooool2o`000003ooooool0003o000000Co0000Doooool2o`0008Wooooo000Nooooo`03o`00
0?oooooooooo02Sooooo0_l0000aooooo`;o00000oooool2o`000003ooooool0003o000000Ko0000
DOooool2o`0008Wooooo000Nooooo`03o`000?oooooooooo05cooooo0_l00002ooooo`;o00000_oo
ool2o`0000?ooooo1?l0000fooooo`;o0000X_ooool001kooooo00?o0000ooooooooool0Coooool2
o`0000_ooooo0ol00008ooooo`;o00000_ooool4o`0003Cooooo0_l0002Rooooo`007_ooool00ol0
003oooooooooo`1?ooooo`;o00003?ooool2o`0000;ooooo1?l000001?oooooo0000o`000?l00003
ooooo`Ko0000eOooool001kooooo00?o0000ooooooooool0:?ooool2o`0003Gooooo1_l000001?oo
oooo0000o`000?ooool2o`0000Cooooo0ol0003Eooooo`007_ooool00ol0003oooooooooo`0Xoooo
o`;o0000<_ooool5o`000005ooooool0003o0000o`000?ooool01Ol00004ooooo`;o0000e_ooool0
01kooooo00?o0000ooooooooool0:?ooool2o`00037ooooo1ol000001?oooooo0000o`000?ooool3
o`0000Kooooo0_l00013ooooo`;o0000TOooool001kooooo0_l0000Yooooo`;o00009_ooool2o`00
0003ooooool0003o000000?ooooo1Ol00003ooooo`?o00003?ooool2o`000003ooooool0003o0000
00;o0000?_ooool2o`00097ooooo000Nooooo`03o`000?oooooooooo03gooooo0_l0000?ooooo`Co
000000?oooooo`000?l000000_ooool6o`0000Cooooo0_l00006ooooo`;o00001oooool8o`000<go
oooo000Nooooo`03o`000?oooooooooo03gooooo0_l0000?ooooo`Co00001Oooool6o`0000Sooooo
0_l00002ooooo`;o00001Oooool2o`000003ooooool0003o000000Go0000cOooool001kooooo00?o
0000ooooooooool0Eoooool2o`000004ooooool0003o0000o`0000Sooooo0_l00005ooooo`;o0000
0_ooool2o`000003ooooool0003o000000Oo0000boooool001kooooo00?o0000ooooooooool0?Ooo
ool2o`0000kooooo0ol00003ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000;ooooo
0_l0000;ooooo`?o00001oooool3o`000003ooooool0003o000000?o00001Oooool3o`000<7ooooo
000Nooooo`03o`000?oooooooooo03Wooooo0_l00002ooooo`;o00001Oooool2o`0000Oooooo0ol0
0003ooooo`;o000000?oooooo`000?l000001_ooool2o`0000_ooooo0_l00008ooooo`?o00000_oo
ool4o`0000Cooooo1?l00031ooooo`007_ooool00ol0003oooooooooo`0Xooooo`;o00003oooool2
o`0000Wooooo0_l0000>ooooo`Co00004?ooool2o`0000Gooooo0_l00009ooooo`?o00000_ooool2
o`000003ooooool0003o00000<?ooooo000Nooooo`03o`000?oooooooooo02Sooooo0_l0000Xoooo
o`Co000000?oooooo`000?l000003oooool2o`0000Gooooo0_l00004ooooo`;o000000Coooooo`00
0?l0003ooooo0_l00002ooooo`;o0000a_ooool001kooooo00?o0000ooooooooool0Coooool5o`00
00?ooooo0_l00002ooooo`;o00006?ooool2o`000003ooooool0003o000000Sooooo0ol00032oooo
o`007_ooool00ol0003oooooooooo`1;ooooo`;o00000_ooool6o`0000Kooooo0_l0000Tooooo`Co
0000`_ooool001kooooo00?o0000ooooooooool07_ooool2o`0001_ooooo0_l0000>ooooo`;o0000
1Oooool3o`0002Sooooo0_l00002ooooo`Co0000`_ooool001kooooo00?o0000ooooooooool07_oo
ool2o`0001_ooooo0_l0000Cooooo`?o00008oooool2o`0000Gooooo0_l00003ooooo`?o0000`_oo
ool001kooooo00?o0000ooooooooool0D?ooool3o`0002?ooooo0_l00009ooooo`?o0000`oooool0
01kooooo00?o0000ooooooooool0Boooool6o`0000Gooooo0_l00002ooooo`;o00003?ooool2o`00
01;ooooo0_l00003ooooo`?o0000`oooool001kooooo00?o0000ooooooooool0>_ooool2o`0000oo
oooo1_l00005ooooo`;o00000_ooool2o`0000cooooo0_l0000Booooo`?o00000oooool2o`000<?o
oooo000Nooooo`03o`000?oooooooooo03[ooooo0_l0000>ooooo`Co00002?ooool2o`0002;ooooo
0_l000000ooooooo0000o`000003ooooo`;o0000`oooool001kooooo0_l0001;ooooo`Co0000:Ooo
ool2o`000003ooooool0003o000000Cooooo0_l00035ooooo`007_ooool00ol0003oooooooooo`19
ooooo`Oo00002?ooool2o`0001Wooooo0_l00002ooooo`;o00001oooool2o`000<Gooooo000Noooo
o`03o`000?oooooooooo04Kooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o0000
00;o00000_ooool2o`0000;ooooo0_l0000Iooooo`;o00001?ooool3o`000<_ooooo000Nooooo`03
o`000?oooooooooo047ooooo3?l00003ooooo`;o00000_ooool2o`0001Wooooo0_l00008ooooo`?o
0000boooool001kooooo00?o0000ooooooooool0:_ooool2o`0001Gooooo2_l0000Tooooo`;o0000
e_ooool001kooooo00?o0000ooooooooool0:_ooool2o`0001Gooooo2?l00002ooooo`;o00004ooo
ool2o`00013ooooo0_l0003Cooooo`007_ooool00ol0003oooooooooo`0Xooooo`;o00005oooool8
o`0000;ooooo0_l0000Cooooo`;o000000?oooooo`000?l000003Oooool2o`000=?ooooo000Noooo
o`03o`000?oooooooooo02Sooooo0_l00008ooooo`;o00002_ooool3o`0000;ooooo1?l00006oooo
o`;o00001oooool2o`0000_ooooo0_l0000<ooooo`;o0000e?ooool001kooooo00?o0000oooooooo
ool0:?ooool2o`0000?ooooo0_l00003ooooo`;o00002_ooool3o`0000;ooooo0_l000000ooooooo
0000o`000005ooooo`Co00001Oooool4o`0001Cooooo0_l000000ooooooo0000o`00003Dooooo`00
7_ooool00ol0003oooooooooo`0/ooooo`?o00005?ooool2o`000003ooooool0003o000000Oooooo
0_l00007ooooo`?o00004oooool2o`0000?ooooo0_l0003Booooo`007_ooool00ol0003ooooooooo
o`0/ooooo`;o00003?ooool2o`0000Gooooo0ol0000Eooooo`;o00005_ooool4o`000=;ooooo000N
ooooo`03o`000?oooooooooo02_ooooo0_l0000:ooooo`;o000000?oooooo`000?l000000_ooool6
o`0001Gooooo0_l0000Fooooo`;o0000e?ooool001kooooo00?o0000ooooooooool0:oooool2o`00
00?ooooo0_l00005ooooo`;o00000oooool6o`0000;ooooo0_l0000:ooooo`;o00001oooool2o`00
00_ooooo0_l00004ooooo`;o0000fOooool001kooooo00?o0000ooooooooool0<?ooool2o`0000[o
oooo1_l00002ooooo`;o00002_ooool2o`0001Cooooo0_l00004ooooo`;o0000fOooool001kooooo
00?o0000ooooooooool0=?ooool2o`0000Kooooo1_l0000Tooooo`;o00001?ooool2o`000=Wooooo
000Nooooo`03o`000?oooooooooo02Wooooo0_l00009ooooo`;o00001?ooool8o`0001[ooooo0_l0
0008ooooo`;o00001?ooool4o`000=Oooooo000Nooooo`;o0000:_ooool2o`0000oooooo0ol00002
ooooo`?o00006_ooool2o`0000Sooooo0_l00006ooooo`;o0000eoooool001kooooo00?o0000oooo
ooooool0:_ooool2o`000003ooooool0003o000000_ooooo0_l000001?oooooo0000o`000?ooool2
o`000:oooooo0_l0001Dooooo`007_ooool00ol0003oooooooooo`0Zooooo`;o000000?oooooo`00
0?l000000oooool2o`0000Gooooo1_l00004ooooo`;o00008oooool2o`0008Oooooo0_l0001Doooo
o`007_ooool00ol0003oooooooooo`0booooo`;o00001?ooool5o`0000Kooooo0_l0000Sooooo`;o
0000gOooool001kooooo00?o0000ooooooooool0>?ooool2o`000?oooooo3_ooool001kooooo00?o
0000ooooooooool0;Oooool2o`000003ooooool0003o000001_ooooo0_l0000Looooo`;o0000dooo
ool2o`0000Gooooo000Nooooo`03o`000?oooooooooo02_ooooo1?l000000ooooooo0000o`00000K
ooooo`;o00007?ooool3o`000=;ooooo0_l00005ooooo`007_ooool00ol0003oooooooooo`0[oooo
o`;o00000oooool2o`00023ooooo0_l0000Hooooo`;o0000fOooool001kooooo00?o0000oooooooo
ool0:oooool2o`0000?ooooo0_l00008ooooo`;o00005?ooool4o`000??ooooo000Nooooo`03o`00
0?oooooooooo02_ooooo0_l0000=ooooo`;o00005?ooool2o`000?Gooooo000Nooooo`03o`000?oo
oooooooo053ooooo0_l0000Aooooo`?o0000hOooool001kooooo00?o0000ooooooooool0;_ooool2
o`00013ooooo0_l0000Qooooo`?o000000?oooooo`000?l00000g_ooool001kooooo00?o0000oooo
ooooool0;_ooool2o`0000[ooooo0_l00004ooooo`;o00009Oooool4o`000=cooooo000Nooooo`03
o`000?oooooooooo03[ooooo0_l0000]ooooo`;o0000g?ooool001Cooooo1?l000000ol@413ooooo
ooooo`03ooooo`03o`000?oooooooooo0?ooooooB?ooool001Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Fooooo`03o`000?oooooooooo00Gooooo0ol0000o
ooooo`;o0000ooooool7ooooo`005_ooool00ol0003oooooooooo`17ooooo`;o0000ooooool7oooo
o`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?oooooo
D?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005?ooool00omEEEGoIVIVo`00003o
oooooe;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.30123 .66265 Mdot
.0178 .36426 Mdot
.2799 .69818 Mdot
.37982 .81412 Mdot
.22434 .73437 Mdot
.2621 .82946 Mdot
.25925 .11739 Mdot
.25695 .72304 Mdot
.25782 .86453 Mdot
.64376 .25894 Mdot
.25071 .87663 Mdot
.17583 .88422 Mdot
.2529 .68181 Mdot
.06991 .65905 Mdot
.30778 .80283 Mdot
.06077 .63032 Mdot
.9794 .50494 Mdot
.22187 .6426 Mdot
.26871 .6279 Mdot
.36633 .83527 Mdot
.26585 .53166 Mdot
.2298 .83132 Mdot
.13583 .72217 Mdot
.08101 .15451 Mdot
.29103 .85785 Mdot
.25688 .77732 Mdot
.32451 .82704 Mdot
.08067 .65051 Mdot
.24239 .88008 Mdot
.26501 .8208 Mdot
.25611 .63676 Mdot
.29506 .80643 Mdot
.23071 .88881 Mdot
.40637 .92089 Mdot
.35125 .6022 Mdot
.39018 .84787 Mdot
.07641 .66279 Mdot
.18993 .46794 Mdot
.11332 .83768 Mdot
.31445 .81657 Mdot
.25854 .63568 Mdot
.42078 .64409 Mdot
.43062 .84695 Mdot
.13086 .50021 Mdot
.15781 .00341 Mdot
.43333 .67272 Mdot
.40895 .36315 Mdot
.45107 .86415 Mdot
.37035 .8579 Mdot
.32867 .58494 Mdot
.16247 .92268 Mdot
.35923 .63557 Mdot
.24506 .76408 Mdot
.39498 .85892 Mdot
.22989 .75777 Mdot
.31322 .18297 Mdot
.75611 .1937 Mdot
.25857 .6917 Mdot
.32782 .82625 Mdot
.24338 .60801 Mdot
.3569 .80587 Mdot
.25177 .74855 Mdot
.29063 .08122 Mdot
.28266 .87086 Mdot
.27605 .73453 Mdot
.23334 .84507 Mdot
.37891 .64218 Mdot
.32693 .82745 Mdot
.26932 .81753 Mdot
.81901 .22305 Mdot
.35153 .15931 Mdot
.13769 .60166 Mdot
.37999 .9528 Mdot
.2961 .00929 Mdot
.19916 .87114 Mdot
.22259 .26781 Mdot
.30604 .72353 Mdot
.50567 .10951 Mdot
.30967 .82234 Mdot
.09151 .65913 Mdot
.46011 .86843 Mdot
.42756 .19895 Mdot
.16548 .50864 Mdot
.25365 .7287 Mdot
.85955 .25593 Mdot
.30621 .11671 Mdot
.25275 .75418 Mdot
.36868 .83298 Mdot
.28471 .80826 Mdot
.20043 .58328 Mdot
.38185 .86839 Mdot
.85226 .23661 Mdot
.31981 .56861 Mdot
.34729 .09101 Mdot
.22288 .59655 Mdot
.45725 .78795 Mdot
.36486 .06766 Mdot
.3572 .61652 Mdot
.29109 .85513 Mdot
.33828 .56851 Mdot
.31525 .75449 Mdot
.15383 .92314 Mdot
.32395 .6485 Mdot
.05385 .65005 Mdot
.04419 .32786 Mdot
.14187 .72106 Mdot
.08155 .61004 Mdot
.06781 .62449 Mdot
.37341 .65374 Mdot
.41977 .14479 Mdot
.07732 .66217 Mdot
.13988 .4289 Mdot
.11814 .93399 Mdot
.24488 .63993 Mdot
.14692 .46787 Mdot
.27922 .15693 Mdot
.13278 .99397 Mdot
.24679 .68924 Mdot
.358 .32757 Mdot
.09727 .92768 Mdot
.34368 .83965 Mdot
.44365 .75542 Mdot
.20588 .84356 Mdot
.34566 .10423 Mdot
.91493 .23806 Mdot
.30681 .54469 Mdot
.22739 .91157 Mdot
.26845 .63352 Mdot
.42815 .90346 Mdot
.38123 .94054 Mdot
.27296 .53821 Mdot
.21277 .18577 Mdot
.93659 .68553 Mdot
.17026 .65668 Mdot
.21135 .61597 Mdot
.22828 .72357 Mdot
.15489 .72735 Mdot
.14205 .57305 Mdot
.30901 .66531 Mdot
.24576 .8471 Mdot
.2657 .62456 Mdot
.28597 .87341 Mdot
.21813 .84781 Mdot
.40251 .60572 Mdot
.35526 .18622 Mdot
.18281 .87531 Mdot
.28498 .65237 Mdot
.31545 .78356 Mdot
.75277 .20224 Mdot
.38243 .17262 Mdot
.3415 .76541 Mdot
.22076 .87242 Mdot
.16503 .90203 Mdot
.36238 .84543 Mdot
.32158 .80988 Mdot
.24533 .7059 Mdot
.10786 .58599 Mdot
.77184 .19514 Mdot
.27707 .85982 Mdot
.07229 .61885 Mdot
.12306 .59374 Mdot
.32511 .58277 Mdot
.07537 .97545 Mdot
.15386 .66139 Mdot
.29135 .84204 Mdot
.21634 .74847 Mdot
.3124 .7776 Mdot
.29551 .83824 Mdot
.38759 .14107 Mdot
.1633 .68801 Mdot
.21757 .8335 Mdot
.46687 .86907 Mdot
.32151 .59056 Mdot
.35556 .28141 Mdot
.28799 .64874 Mdot
.11589 .6509 Mdot
.27345 .92308 Mdot
.27058 .77051 Mdot
.32352 .11252 Mdot
.35175 .62752 Mdot
.42679 .8467 Mdot
.19439 .89764 Mdot
.09323 .79529 Mdot
.20321 .98496 Mdot
.66726 .1634 Mdot
.11415 .91286 Mdot
.07302 .61815 Mdot
.39679 .85826 Mdot
.83699 .69399 Mdot
.41893 .63503 Mdot
.27775 .64262 Mdot
.25586 .11951 Mdot
.27818 .64338 Mdot
.19245 .96593 Mdot
.09508 .92343 Mdot
.42386 .84383 Mdot
.35171 .58661 Mdot
.19614 .85582 Mdot
.25612 .8675 Mdot
.20817 .87196 Mdot
.24671 .01145 Mdot
.14664 .42713 Mdot
.17679 .64351 Mdot
.20666 .99806 Mdot
.29032 .8607 Mdot
.37121 .83337 Mdot
.33692 .17672 Mdot
.35314 .82596 Mdot
.89036 .24312 Mdot
.0872 .69027 Mdot
.17072 .71024 Mdot
.28214 .64004 Mdot
.95848 .22928 Mdot
.61268 .15757 Mdot
.1296 .58208 Mdot
.35668 .10637 Mdot
.30733 .78975 Mdot
.36281 .34609 Mdot
.10507 .64006 Mdot
.38078 .62447 Mdot
.76577 .1915 Mdot
.17738 .60866 Mdot
.28858 .87524 Mdot
.28868 .84216 Mdot
.1921 .59043 Mdot
.10699 .62249 Mdot
.44158 .88616 Mdot
.16462 .73725 Mdot
.63571 .18287 Mdot
.22132 .8479 Mdot
.25214 .73836 Mdot
.24677 .61544 Mdot
.21272 .84765 Mdot
.37894 .95933 Mdot
.35709 .09649 Mdot
.65096 .23 Mdot
.63914 .45068 Mdot
.25442 .65862 Mdot
.21781 .49656 Mdot
.72915 .23618 Mdot
.29189 .76195 Mdot
.2127 .8381 Mdot
.44078 .86331 Mdot
.3377 .72702 Mdot
.10824 .82204 Mdot
.32229 .69477 Mdot
.15516 .61407 Mdot
.22738 .83197 Mdot
.46346 .22873 Mdot
.25903 .64923 Mdot
.35243 .63612 Mdot
.20613 .75243 Mdot
.79299 .29141 Mdot
.3146 .13201 Mdot
.91218 .242 Mdot
.43957 .86494 Mdot
.23677 .7586 Mdot
.19654 .49481 Mdot
.4437 .72982 Mdot
.14842 .4551 Mdot
.29136 .65568 Mdot
.26905 .69173 Mdot
.30627 .10773 Mdot
.18038 .4715 Mdot
.21258 .84377 Mdot
.28983 .06282 Mdot
.12638 .92727 Mdot
.35046 .30364 Mdot
.2504 .67202 Mdot
.31661 .82621 Mdot
.29186 .85318 Mdot
.54105 .34979 Mdot
.32692 .80457 Mdot
.24407 .6951 Mdot
.46031 .87358 Mdot
.18214 .74253 Mdot
.1188 .62602 Mdot
.19937 .09125 Mdot
.38857 .8572 Mdot
.14236 .92614 Mdot
.77003 .22568 Mdot
.228 .83039 Mdot
.13821 .68412 Mdot
.08669 .66039 Mdot
.22627 .75184 Mdot
.28862 .87463 Mdot
.17498 .6717 Mdot
.25965 .55689 Mdot
.4397 .801 Mdot
.24021 .9465 Mdot
.43561 .86367 Mdot
.86865 .23897 Mdot
.26576 .62691 Mdot
.17568 .94959 Mdot
.36282 .10879 Mdot
.27727 .56955 Mdot
.28868 .72567 Mdot
.07716 .61558 Mdot
.76601 .24799 Mdot
.48998 .19616 Mdot
.25272 .55111 Mdot
.27385 .89267 Mdot
.36876 .59685 Mdot
.14026 .62031 Mdot
.60633 .24631 Mdot
.36594 .66045 Mdot
.31982 .82581 Mdot
.33227 .82005 Mdot
.96994 .24381 Mdot
.14984 .41038 Mdot
.3494 .83406 Mdot
.76119 .25786 Mdot
.25574 .77464 Mdot
.14374 .63293 Mdot
.2897 .81273 Mdot
.41831 .82596 Mdot
.11124 .70065 Mdot
.3543 .27496 Mdot
.23631 .89673 Mdot
.09178 .37402 Mdot
.11176 .84355 Mdot
.22257 .88212 Mdot
.15737 .92611 Mdot
.09069 .76343 Mdot
.2461 .63048 Mdot
.25359 .73048 Mdot
.38678 .85691 Mdot
.29115 .65238 Mdot
.17705 .89437 Mdot
.2479 .74688 Mdot
.38123 .84575 Mdot
.25397 .82831 Mdot
.20949 .15046 Mdot
.01874 .21482 Mdot
.37094 .40138 Mdot
.2621 .48348 Mdot
.70227 .632 Mdot
.32789 .83126 Mdot
.74927 .97269 Mdot
.29746 .05865 Mdot
.29324 .85063 Mdot
.72538 .6019 Mdot
.27669 .63446 Mdot
.13607 .61596 Mdot
.73656 .18116 Mdot
.06539 .63543 Mdot
.36742 .14602 Mdot
.21171 .22048 Mdot
.18302 .52097 Mdot
.25901 .72125 Mdot
.25116 .68467 Mdot
.22405 .75685 Mdot
.40976 .63682 Mdot
.06423 .64175 Mdot
.30259 .13655 Mdot
.33921 .8045 Mdot
.41888 .63513 Mdot
.15348 .64942 Mdot
.25541 .6769 Mdot
.35131 .36813 Mdot
.22459 .83159 Mdot
.30379 .8078 Mdot
.25993 .63372 Mdot
.1667 .71479 Mdot
.28175 .88305 Mdot
.39105 .69107 Mdot
.21423 .95217 Mdot
.61127 .61829 Mdot
.70397 .21703 Mdot
.25783 .81564 Mdot
.14203 .57943 Mdot
.31177 .82482 Mdot
.26715 .68035 Mdot
.23268 .85404 Mdot
.46409 .87841 Mdot
.325 .56138 Mdot
.16361 .01823 Mdot
.37366 .84936 Mdot
.01338 .21211 Mdot
.25681 .83182 Mdot
.30038 .82363 Mdot
.39645 .81934 Mdot
.69135 .17346 Mdot
.90838 .24448 Mdot
.08127 .65752 Mdot
.18579 .9717 Mdot
.24326 .91568 Mdot
.34062 .48893 Mdot
.32478 .82933 Mdot
.1039 .6685 Mdot
.26345 .62089 Mdot
.23003 .681 Mdot
.33307 .74533 Mdot
.25027 .71048 Mdot
.23449 .72501 Mdot
.18677 .22009 Mdot
.97449 .57903 Mdot
.18851 .13753 Mdot
.33287 .82792 Mdot
.25282 .62719 Mdot
.42684 .8514 Mdot
.11782 .00139 Mdot
.78391 .19476 Mdot
.25174 .74259 Mdot
.20425 .66942 Mdot
.43736 .90482 Mdot
.26262 .95634 Mdot
.17426 .58493 Mdot
.11134 .64854 Mdot
.15432 .66511 Mdot
.15021 .57712 Mdot
.29067 .85475 Mdot
.13114 .58814 Mdot
.23374 .1235 Mdot
.72036 .19441 Mdot
.18516 .6551 Mdot
.33723 .64856 Mdot
.10962 .61387 Mdot
.76382 .18531 Mdot
.31591 .82101 Mdot
.30742 .82505 Mdot
.3261 .31991 Mdot
.63685 .22976 Mdot
.2129 .67274 Mdot
.25792 .70176 Mdot
.93735 .41791 Mdot
.21541 .0057 Mdot
.24118 .86242 Mdot
.13329 .60301 Mdot
.89737 .24824 Mdot
.72695 .21679 Mdot
.43758 .37734 Mdot
.09375 .60296 Mdot
.39491 .82385 Mdot
.78538 .24497 Mdot
.10019 .62163 Mdot
.09688 .63228 Mdot
.43206 .89988 Mdot
.36794 .67944 Mdot
.12832 .99897 Mdot
.11364 .92748 Mdot
.13926 .451 Mdot
.13611 .52668 Mdot
.34214 .80383 Mdot
.29133 .31931 Mdot
.35133 .81224 Mdot
.22304 .89168 Mdot
.1968 .71155 Mdot
.8455 .24904 Mdot
.11471 .69622 Mdot
.27357 .60325 Mdot
.38253 .66144 Mdot
.29292 .85237 Mdot
.29527 .83008 Mdot
.17838 .9214 Mdot
.3443 .83174 Mdot
.28271 .86466 Mdot
.39204 .85507 Mdot
.43057 .91478 Mdot
.11166 .5556 Mdot
.37811 .7527 Mdot
.3647 .83011 Mdot
.2879 .82606 Mdot
.28269 .73477 Mdot
.06769 .19379 Mdot
.34483 .61535 Mdot
.22725 .88851 Mdot
.32954 .557 Mdot
.32893 .80206 Mdot
.43445 .80829 Mdot
.25629 .8176 Mdot
.25466 .75542 Mdot
.25485 .7294 Mdot
.25432 .7287 Mdot
.3128 .71469 Mdot
.29851 .81199 Mdot
.27703 .77044 Mdot
.25449 .7118 Mdot
.76368 .19349 Mdot
.23523 .87877 Mdot
.50506 .10852 Mdot
.14106 .9565 Mdot
.21875 .8358 Mdot
.26004 .61718 Mdot
.29043 .65519 Mdot
.33781 .05598 Mdot
.36134 .05783 Mdot
.84885 .25813 Mdot
.46604 .87862 Mdot
.07758 .64899 Mdot
.2582 .6679 Mdot
.29424 .8429 Mdot
.19461 .19148 Mdot
.20608 .93301 Mdot
.35231 .88145 Mdot
.20504 .8507 Mdot
.39262 .69311 Mdot
.2172 .89589 Mdot
.16945 .22755 Mdot
.09603 .72999 Mdot
.35551 .70842 Mdot
.40417 .92235 Mdot
.46512 .86439 Mdot
.67243 .21993 Mdot
.20037 .65681 Mdot
.36925 .59882 Mdot
.25404 .75761 Mdot
.36063 .09652 Mdot
.28814 .86154 Mdot
.29448 .83059 Mdot
.24692 .61258 Mdot
.50618 .18057 Mdot
.27929 .17119 Mdot
.70144 .16795 Mdot
.23426 .7412 Mdot
.37442 .96196 Mdot
.41149 .8603 Mdot
.45897 .80213 Mdot
.74487 .26279 Mdot
.24975 .62177 Mdot
.16049 .63891 Mdot
.3032 .72065 Mdot
.30438 .8237 Mdot
.20227 .85573 Mdot
.40892 .61247 Mdot
.52925 .83304 Mdot
.2004 .18008 Mdot
.90802 .59823 Mdot
.08133 .69053 Mdot
.43004 .91496 Mdot
.20575 .04138 Mdot
.35287 .14831 Mdot
.22718 .74847 Mdot
.12396 .86503 Mdot
.25241 .72589 Mdot
.31932 .76704 Mdot
.25875 .74692 Mdot
.25349 .88504 Mdot
.13324 .4482 Mdot
.33944 .04911 Mdot
.24549 .84624 Mdot
.72708 .18206 Mdot
.18457 .87817 Mdot
.31038 .81308 Mdot
.31952 .69333 Mdot
.33293 .08215 Mdot
.84273 .25099 Mdot
.10243 .69588 Mdot
.14154 .69204 Mdot
.25108 .72811 Mdot
.31455 .17087 Mdot
.27253 .02352 Mdot
.23936 .8865 Mdot
.36753 .94205 Mdot
.45193 .87047 Mdot
.36434 .17916 Mdot
.84127 .26346 Mdot
.32931 .83031 Mdot
.40345 .84041 Mdot
.14519 .48664 Mdot
.15064 .68464 Mdot
.22366 .9023 Mdot
.1429 .44803 Mdot
.35703 .60862 Mdot
.18137 .66593 Mdot
.37446 .85998 Mdot
.11316 .59102 Mdot
.28993 .86529 Mdot
.46357 .31183 Mdot
.28054 .81148 Mdot
.38219 .41735 Mdot
.05985 .64842 Mdot
.29097 .81153 Mdot
.29209 .65157 Mdot
.24027 .67422 Mdot
.23594 .86885 Mdot
.4223 .90755 Mdot
.24405 .88311 Mdot
.20275 .75264 Mdot
.35533 .68511 Mdot
.47973 .14931 Mdot
.84588 .2313 Mdot
.31774 .7388 Mdot
.2613 .61757 Mdot
.121 .49082 Mdot
.37998 .83868 Mdot
.11102 .91467 Mdot
.22202 .08743 Mdot
.12302 .94609 Mdot
.26063 .62427 Mdot
.2554 .70689 Mdot
.24594 .75825 Mdot
.12598 .62555 Mdot
.21434 .88626 Mdot
.19076 .86867 Mdot
.25326 .76954 Mdot
.0953 .65023 Mdot
.24784 .72955 Mdot
.38267 .84424 Mdot
.14134 .64592 Mdot
.22851 .86834 Mdot
.30503 .82626 Mdot
.25925 .68025 Mdot
.35699 .6153 Mdot
.15136 .04735 Mdot
.1501 .66245 Mdot
.31882 .80754 Mdot
.23845 .82815 Mdot
.21128 .0596 Mdot
.28987 .65502 Mdot
.25494 .03403 Mdot
.36556 .10441 Mdot
.2782 .80837 Mdot
.189 .20868 Mdot
.28693 .6398 Mdot
.10541 .61204 Mdot
.13628 .59897 Mdot
.35074 .11227 Mdot
.28504 .87161 Mdot
.48406 .21951 Mdot
.49423 .85422 Mdot
.20452 .3896 Mdot
.28097 .6466 Mdot
.23965 .18924 Mdot
.39343 .63428 Mdot
.1365 .93707 Mdot
.28662 .01197 Mdot
.28468 .12959 Mdot
.20247 .75077 Mdot
.44041 .86091 Mdot
.31719 .68938 Mdot
.28922 .84542 Mdot
.25785 .62241 Mdot
.04509 .6518 Mdot
.28684 .81233 Mdot
.57004 .13295 Mdot
.2543 .72532 Mdot
.31533 .62585 Mdot
.22523 .70283 Mdot
.30063 .80285 Mdot
.39698 .89333 Mdot
.27216 .8198 Mdot
.4149 .63447 Mdot
.39204 .91194 Mdot
.13772 .02971 Mdot
.1842 .61744 Mdot
.1954 .91929 Mdot
.75386 .18216 Mdot
.24909 .73363 Mdot
.23204 .05922 Mdot
.02852 .12454 Mdot
.20732 .89896 Mdot
.22542 .87742 Mdot
.28546 .84082 Mdot
.84463 .25062 Mdot
.31093 .82461 Mdot
.25836 .77357 Mdot
.77332 .26866 Mdot
.88525 .23999 Mdot
.33823 .8298 Mdot
.14253 .01343 Mdot
.13977 .76863 Mdot
.57578 .2608 Mdot
.34925 .84592 Mdot
.26861 .08722 Mdot
.40793 .88067 Mdot
.32415 .82019 Mdot
.29396 .12607 Mdot
.34479 .56928 Mdot
.35252 .86124 Mdot
.36518 .02606 Mdot
.54499 .24471 Mdot
.19975 .97589 Mdot
.2673 .84308 Mdot
.71786 .24068 Mdot
.25321 .76442 Mdot
.77554 .27463 Mdot
.22377 .67481 Mdot
.40961 .18099 Mdot
.86587 .28078 Mdot
.09125 .41308 Mdot
.40826 .60813 Mdot
.71294 .19103 Mdot
.26718 .63408 Mdot
.28061 .81174 Mdot
.27607 .58235 Mdot
.1935 .91413 Mdot
.38383 .15268 Mdot
.10788 .89317 Mdot
.24941 .6531 Mdot
.44918 .80624 Mdot
.18634 .99208 Mdot
.34032 .50579 Mdot
.31248 .39527 Mdot
.22555 .87621 Mdot
.13895 .76128 Mdot
.28803 .83034 Mdot
.34322 .16693 Mdot
.56395 .24219 Mdot
.0164 .21569 Mdot
.34421 .35831 Mdot
.05245 .64483 Mdot
.24488 .70191 Mdot
.30974 .6616 Mdot
.35937 .10875 Mdot
.20675 .85605 Mdot
.59115 .16471 Mdot
.12648 .24979 Mdot
.20038 .01925 Mdot
.24944 .87419 Mdot
.61581 .2284 Mdot
.18391 .59504 Mdot
.1045 .96591 Mdot
.72453 .29529 Mdot
.16792 .742 Mdot
.94189 .39986 Mdot
.22312 .83202 Mdot
.25431 .72054 Mdot
.30508 .16988 Mdot
.21602 .83375 Mdot
.28835 .64608 Mdot
.3698 .00956 Mdot
.16253 .64125 Mdot
.20323 .45673 Mdot
.29501 .56279 Mdot
.8265 .22191 Mdot
.18237 .50535 Mdot
.34113 .84203 Mdot
.38628 .92514 Mdot
.75403 .18211 Mdot
.24053 .84652 Mdot
.23641 .836 Mdot
.25223 .70893 Mdot
.25589 .85476 Mdot
.2955 .14831 Mdot
.23349 .5627 Mdot
.85325 .24596 Mdot
.84967 .25724 Mdot
.17698 .91733 Mdot
.86956 .23184 Mdot
.17779 .7769 Mdot
.38231 .8154 Mdot
.2757 .63038 Mdot
.37673 .04474 Mdot
.37761 .95753 Mdot
.21443 .91508 Mdot
.26335 .83376 Mdot
.75758 .19145 Mdot
.22848 .90325 Mdot
.15865 .15877 Mdot
.43829 .85672 Mdot
.30673 .70176 Mdot
.18389 .94654 Mdot
.33108 .67179 Mdot
.17538 .62983 Mdot
.26332 .82863 Mdot
.18217 .68768 Mdot
.45457 .87303 Mdot
.27326 .77331 Mdot
.25548 .6586 Mdot
.8091 .20633 Mdot
.25697 .72651 Mdot
.91809 .27806 Mdot
.30329 .70084 Mdot
.26594 .92459 Mdot
.35731 .80896 Mdot
.37758 .5866 Mdot
.73809 .19336 Mdot
.1946 .85643 Mdot
.92145 .28788 Mdot
.29516 .84741 Mdot
.14711 .8641 Mdot
.13873 .70791 Mdot
.20598 .75234 Mdot
.35931 .17698 Mdot
.25821 .61813 Mdot
.24165 .86398 Mdot
.25703 .66782 Mdot
.18346 .91766 Mdot
.21988 .03754 Mdot
.38139 .81407 Mdot
.09801 .90972 Mdot
.74351 .25405 Mdot
.40671 .92589 Mdot
.28629 .75407 Mdot
.10156 .5915 Mdot
.07072 .63831 Mdot
.24818 .84762 Mdot
.29374 .84338 Mdot
.25451 .71923 Mdot
.47556 .67358 Mdot
.70506 .21644 Mdot
.17644 .66851 Mdot
.26306 .78279 Mdot
.25267 .57253 Mdot
.25404 .77093 Mdot
.07336 .64573 Mdot
.43273 .63323 Mdot
.39827 .82675 Mdot
.16237 .60277 Mdot
.69644 .28242 Mdot
.2489 .82539 Mdot
.3125 .74371 Mdot
.10823 .93937 Mdot
.21716 .6162 Mdot
.19739 .64269 Mdot
.19136 .18438 Mdot
.33255 .34316 Mdot
.32342 .57324 Mdot
.16432 .6275 Mdot
.31196 .56338 Mdot
.3971 .83708 Mdot
.29837 .72108 Mdot
.42056 .83984 Mdot
.40969 .83974 Mdot
.30459 .82637 Mdot
.4446 .13739 Mdot
.75671 .20681 Mdot
.32386 .80331 Mdot
.29867 .12122 Mdot
.25398 .72511 Mdot
.24859 .72242 Mdot
.25996 .89897 Mdot
.24696 .70445 Mdot
.25767 .74179 Mdot
.13168 .57545 Mdot
.24671 .76405 Mdot
.28987 .85921 Mdot
.34941 .17188 Mdot
.12964 .66221 Mdot
.13794 .98719 Mdot
.23174 .55522 Mdot
.24965 .66655 Mdot
.33215 .18508 Mdot
.42461 .66502 Mdot
.15623 .67805 Mdot
.54589 .12414 Mdot
.37033 .8576 Mdot
.26793 .88918 Mdot
.37052 .20978 Mdot
.2033 .97437 Mdot
.24635 .72432 Mdot
.32211 .82565 Mdot
.25016 .85732 Mdot
.76391 .21365 Mdot
.23612 .1004 Mdot
.32171 .55152 Mdot
.25671 .69334 Mdot
.2534 .76798 Mdot
.30633 .69919 Mdot
.17038 .48381 Mdot
.20562 .59493 Mdot
.25997 .63466 Mdot
.27357 .63184 Mdot
.3479 .82376 Mdot
.01849 .23709 Mdot
.25575 .72538 Mdot
.24793 .30389 Mdot
.22487 .86593 Mdot
.30454 .71586 Mdot
.24858 .72936 Mdot
.36995 .8108 Mdot
.24452 .87579 Mdot
.5943 .14229 Mdot
.25622 .77675 Mdot
.19839 .89128 Mdot
.26921 .62751 Mdot
.11288 .6196 Mdot
.95585 .23655 Mdot
.25172 .70804 Mdot
.14217 .51165 Mdot
.34843 .80767 Mdot
.29017 .8631 Mdot
.39434 .78205 Mdot
.45623 .87379 Mdot
.24797 .74128 Mdot
.8671 .38083 Mdot
.06726 .44926 Mdot
.12311 .01115 Mdot
.20092 .61045 Mdot
.50797 .77324 Mdot
.32618 .81601 Mdot
.25575 .73007 Mdot
.28718 .7631 Mdot
.40383 .65718 Mdot
.29673 .65895 Mdot
.32818 .67294 Mdot
.74359 .21724 Mdot
.22839 .83127 Mdot
.46164 .8885 Mdot
.6693 .2089 Mdot
.19959 .10528 Mdot
.384 .67012 Mdot
.22469 .83172 Mdot
.46781 .23268 Mdot
.29209 .73915 Mdot
.81539 .21199 Mdot
.31419 .802 Mdot
.22904 .75271 Mdot
.24229 .85442 Mdot
.20958 .60868 Mdot
.13568 .9255 Mdot
.36063 .32035 Mdot
.3891 .69402 Mdot
.28637 .14541 Mdot
.17202 .57141 Mdot
.40599 .92773 Mdot
.21711 .68961 Mdot
.26284 .62673 Mdot
.2751 .63413 Mdot
.16376 .9164 Mdot
.45599 .88977 Mdot
.35275 .25033 Mdot
.24991 .88171 Mdot
.15564 .81903 Mdot
.20262 .47878 Mdot
.29765 .80464 Mdot
.31987 .78115 Mdot
.46179 .83061 Mdot
.24739 .86046 Mdot
.64449 .23072 Mdot
.3663 .51253 Mdot
.24402 .62797 Mdot
.24912 .73418 Mdot
.2988 .80377 Mdot
.199 .50111 Mdot
.65667 .17865 Mdot
.18544 .91699 Mdot
.10453 .46446 Mdot
.88692 .24108 Mdot
.41534 .66526 Mdot
.15954 .72654 Mdot
.25198 .71204 Mdot
.21286 .84515 Mdot
.20547 .13581 Mdot
.26883 .62849 Mdot
.72394 .27198 Mdot
.23165 .83467 Mdot
.32659 .82016 Mdot
.341 .97595 Mdot
.25189 .69996 Mdot
.28265 .65321 Mdot
.29307 .8517 Mdot
.34204 .08824 Mdot
.37095 .67583 Mdot
.27251 .82366 Mdot
.37461 .97586 Mdot
.37829 .62812 Mdot
.25023 .84757 Mdot
.5326 .15429 Mdot
.29102 .80399 Mdot
.76935 .27025 Mdot
.41154 .64314 Mdot
.5705 .58529 Mdot
.29177 .72093 Mdot
.26498 .70178 Mdot
.65563 .15519 Mdot
.22366 .54728 Mdot
.30896 .05661 Mdot
.94286 .25337 Mdot
.23387 .8284 Mdot
.29585 .83384 Mdot
.3206 .80205 Mdot
.23015 .59815 Mdot
.24868 .73287 Mdot
.3311 .1333 Mdot
.1506 .57662 Mdot
.10226 .62336 Mdot
.84046 .21863 Mdot
.39516 .14249 Mdot
.32207 .19569 Mdot
.80612 .26443 Mdot
.09543 .19503 Mdot
.32989 .10258 Mdot
.52144 .24881 Mdot
.25403 .75092 Mdot
.07416 .61854 Mdot
.39552 .15391 Mdot
.32048 .82365 Mdot
.34344 .80323 Mdot
.25707 .70256 Mdot
.18431 .6043 Mdot
.32939 .44029 Mdot
.06977 .62134 Mdot
.26893 .8369 Mdot
.38684 .66213 Mdot
.16718 .92468 Mdot
.42627 .18012 Mdot
.37619 .63943 Mdot
.32639 .80836 Mdot
.25285 .5327 Mdot
.38437 .81609 Mdot
.17836 .90122 Mdot
.45493 .2322 Mdot
.27396 .88893 Mdot
.34276 .84326 Mdot
.31949 .73544 Mdot
.34357 .534 Mdot
.08301 .61324 Mdot
.21582 .83663 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`;o00002Oooool01?l0003o
ooooo`000?l0000=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00Co0000ooooool0003o00003Oooool01?l0003oooooooooooooool2o`0000[ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool00_ooool001kooooo00?o0000ooooooooool0@_ooool2o`0001Sooooo0_l0000Foooo
o`;o0000dOooool001kooooo00?o0000ooooooooool09?ooool2o`0000Cooooo0_l0000Pooooo`;o
00002oooool2o`000003ooooool0003o000001Kooooo0_l0003Aooooo`007_ooool00ol0003ooooo
ooooo`0Tooooo`;o00001?ooool2o`00023ooooo0_l0000;ooooo`;o0000k?ooool001kooooo00?o
0000ooooooooool0<Oooool2o`0000[ooooo0_l0003oooooo`Wooooo000Nooooo`03o`000?oooooo
oooo037ooooo0_l0000:ooooo`;o0000ooooool9ooooo`007_ooool00ol0003oooooooooo`1Doooo
o`;o0000lOooool001kooooo00?o0000ooooooooool0E?ooool2o`0001gooooo0_l0003Booooo`00
7_ooool00ol0003oooooooooo`0Yooooo`;o0000B?ooool2o`000=;ooooo000Nooooo`03o`000?oo
oooooooo02Wooooo0_l0000Tooooo`;o0000m_ooool001kooooo00?o0000ooooooooool0@oooool2
o`0000[ooooo0_l0003fooooo`007_ooool00ol0003oooooooooo`0oooooo`;o00000_ooool2o`00
0?oooooo0oooool001kooooo00?o0000ooooooooool0?oooool2o`000?oooooo1oooool001kooooo
00?o0000ooooooooool0;Oooool2o`0004Oooooo0_l0003?ooooo`007_ooool00ol0003ooooooooo
o`0]ooooo`;o0000>oooool2o`0000[ooooo0_l0003?ooooo`007_ooool2o`0006_ooooo0_l0003K
ooooo`007_ooool00ol0003oooooooooo`1Pooooo`;o00002?ooool2o`000=_ooooo000Nooooo`03
o`000?oooooooooo047ooooo0_l00004ooooo`;o00005?ooool2o`000003ooooool0003o000000So
oooo0_l00005ooooo`;o0000e?ooool001kooooo00?o0000ooooooooool0@Oooool2o`0000Cooooo
0_l0000Aooooo`;o000000?oooooo`000?l000004_ooool2o`000=Cooooo000Nooooo`03o`000?oo
oooooooo05[ooooo0_l0003[ooooo`007_ooool00ol0003oooooooooo`1cooooo`;o0000d_ooool0
01kooooo00?o0000ooooooooool0Loooool2o`000=;ooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`1Jooooo`;o0000joooool001kooooo00?o0000ooooooooool0F_ooool2o`0000cooooo0_l0003M
ooooo`007_ooool00ol0003oooooooooo`14ooooo`;o00003Oooool2o`0001?ooooo0_l0003Moooo
o`007_ooool00ol0003oooooooooo`14ooooo`;o00003Oooool2o`0001Kooooo0_l0003Jooooo`00
7_ooool00ol0003oooooooooo`0mooooo`;o0000;?ooool4o`000=Sooooo000Nooooo`03o`000?oo
oooooooo03gooooo0_l0000^ooooo`;o000000Coooooo`000?l0003o0000e?ooool001kooooo00?o
0000ooooooooool0L?ooool3o`000=Cooooo000Nooooo`;o0000B_ooool2o`0001cooooo0_l0003N
ooooo`007_ooool00ol0003oooooooooo`0mooooo`;o00002_ooool2o`0001cooooo0_l00003oooo
o`;o00001Oooool2o`000=;ooooo000Nooooo`03o`000?oooooooooo03gooooo0_l0000Pooooo`;o
00002oooool2o`0000;ooooo1Ol0000[ooooo`;o0000YOooool001kooooo00?o0000ooooooooool0
Goooool2o`0000oooooo1?l0000/ooooo`;o0000YOooool001kooooo00?o0000ooooooooool0IOoo
ool2o`0000Oooooo0_l0000`ooooo`;o0000YOooool001kooooo00?o0000ooooooooool0D?ooool2
o`0000gooooo0_l00004ooooo`;o00001oooool2o`000=Oooooo000Nooooo`03o`000?oooooooooo
04oooooo0ol0000;ooooo`Co0000i_ooool001kooooo00?o0000ooooooooool0B?ooool2o`0000Go
oooo0_l0000<ooooo`;o0000C_ooool2o`0009Sooooo000Nooooo`03o`000?oooooooooo00Gooooo
0_l00011ooooo`;o00004Oooool2o`00053ooooo0_l0002Hooooo`007_ooool00ol0003ooooooooo
o`05ooooo`;o0000DOooool2o`000003ooooool0003o00000>[ooooo000Nooooo`03o`000?oooooo
oooo05Sooooo0_l00008ooooo`;o00001?ooool2o`0004_ooooo0_l0002@ooooo`007_ooool00ol0
003oooooooooo`0oooooo`;o00007Oooool2o`0000;ooooo0_l00004ooooo`;o0000Boooool2o`00
093ooooo000Nooooo`03o`000?oooooooooo03Wooooo0_l00004ooooo`;o00007Oooool2o`0002co
oooo0_l0002iooooo`007_ooool00ol0003oooooooooo`0iooooo`;o0000?oooool4o`0000kooooo
0_l0000_ooooo`;o0000R?ooool001kooooo00?o0000ooooooooool0FOooool2o`0001oooooo1?l0
0006ooooo`;o0000=oooool2o`0008Sooooo000Nooooo`03o`000?oooooooooo05Wooooo0_l00000
0ooooooo0000o`00000Aooooo`;o00000_ooool2o`0000oooooo0_l00031ooooo`007_ooool2o`00
047ooooo0_l0000Jooooo`;o00004Oooool2o`0000;ooooo0_l0000Sooooo`;o0000[Oooool001ko
oooo00?o0000ooooooooool05_ooool2o`0002Sooooo0_l0000gooooo`;o000000?oooooo`000?l0
00006_ooool2o`0000oooooo0_l0000Vooooo`;o0000M?ooool001kooooo00?o0000ooooooooool0
5_ooool2o`0003oooooo0_l0000Pooooo`;o000000?oooooo`000?l00000:oooool2o`0001Sooooo
0_l0000<ooooo`;o0000M?ooool001kooooo00?o0000ooooooooool0;oooool2o`0002Kooooo0_l0
000Eooooo`;o0000Doooool2o`0008;ooooo000Nooooo`03o`000?oooooooooo02oooooo0_l0000m
ooooo`;o0000IOooool2o`00073ooooo000Nooooo`03o`000?oooooooooo06_ooooo0_l0001?oooo
o`;o00005oooool2o`00073ooooo000Nooooo`03o`000?oooooooooo05oooooo0_l0000:ooooo`;o
0000Coooool2o`0002;ooooo0_l0001Uooooo`007_ooool00ol0003oooooooooo`1Gooooo`;o0000
1_ooool2o`000003ooooool0003o000000Wooooo0_l00009ooooo`;o0000Hoooool2o`000003oooo
ool0003o000006Gooooo000Nooooo`03o`000?oooooooooo05Oooooo0_l00009ooooo`;o00001Ooo
ool2o`0000;ooooo0_l00009ooooo`;o0000Hoooool2o`0006Sooooo000Nooooo`03o`000?oooooo
oooo06Wooooo0_l00006ooooo`?o0000GOooool2o`0007Cooooo000Nooooo`03o`000?oooooooooo
03gooooo0_l0000booooo`?o00003Oooool2o`0000?ooooo0_l0000Hooooo`;o0000:Oooool2o`00
00Cooooo0_l0000Eooooo`;o000000?oooooo`000?l000001?ooool2o`0005Cooooo000Nooooo`03
o`000?oooooooooo03[ooooo0_l000000ooooooo0000o`000002ooooo`;o00007oooool2o`0000Co
oooo0_l0000Gooooo`;o00000oooool2o`0001Sooooo0_l0000Yooooo`;o00006oooool2o`000003
ooooool0003o000000Cooooo0_l000000ooooooo0000o`00001Aooooo`007_ooool00ol0003ooooo
ooooo`0jooooo`;o00001Oooool2o`0001oooooo0_l00004ooooo`;o00001Oooool2o`0008?ooooo
0_l0001Aooooo`007_ooool00ol0003oooooooooo`0kooooo`;o00003Oooool2o`0002?ooooo0_l0
001cooooo`;o00003?ooool2o`000003ooooool0003o0000053ooooo0003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo01;ooooo0_l0
0007ooooo`;o00007_ooool2o`0000gooooo0_l0002Hooooo`Co00001?ooool2o`0000Cooooo1ol0
0002ooooo`;o0000B_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool04_ooool2o`0000Oooooo
0_l00018ooooo`;o0000=?ooool2o`0004Wooooo0_l00004ooooo`;o00001?ooool4o`000003oooo
ool0003o000000;ooooo0_l0001:ooooo`000oooool01Ol@413ooooooooooooooooo410@00cooooo
00?oV9RHob4Q8Oo^k^h01oooool3o`0006Gooooo0_l0000Pooooo`;o00004_ooool2o`000:[ooooo
0003ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`03o`00
0?oooooooooo08Oooooo0_l0001Xooooo`;o0000E?ooool000?ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0lOooool3o`0000oooooo
0_l00012ooooo`000oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0iooooo`;o0000>Oooool2o`0005oooooo0_l0000Kooooo`;o0000
3oooool2o`0004;ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zj
oooooonHV9So410@00Kooooo00?o0000ooooooooool00_l0000gooooo`;o0000>Oooool2o`0005oo
oooo0_l0000Mooooo`;o00003oooool2o`00043ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool01?l0003Moooo
o`;o00004Oooool2o`0000oooooo0_l00010ooooo`007_ooool01?l0003oooooooooooooool3o`00
09Gooooo0_l00016ooooo`;o00001Oooool2o`0000Cooooo0_l0000Mooooo`;o0000>?ooool001ko
oooo00?o0000ooooooooool0>Oooool2o`0000Kooooo0_l0001Fooooo`;o0000??ooool2o`0000So
oooo0_l00005ooooo`;o00001?ooool2o`0001Wooooo0_l00002ooooo`;o0000>?ooool001kooooo
00?o0000ooooooooool0>Oooool2o`0000Kooooo0_l0002Dooooo`;o00007Oooool2o`0000kooooo
0_l000000ooooooo0000o`00000looooo`007_ooool00ol0003oooooooooo`0cooooo`;o0000G_oo
ool2o`0002oooooo0_l0000`ooooo`;o00003_ooool2o`0003oooooo000Nooooo`03o`000?oooooo
oooo03?ooooo0_l0001Nooooo`;o0000;oooool2o`0000Gooooo1?l000000ooooooo0000o`00000m
ooooo`;o00001_ooool2o`0001_ooooo0_l0000Aooooo`007_ooool00ol0003oooooooooo`2@oooo
o`;o00000_ooool2o`0003Gooooo1?l000000ooooooo0000o`00000mooooo`;o00001_ooool2o`00
01_ooooo0_l0000Aooooo`007_ooool00ol0003oooooooooo`02ooooo`;o0000S?ooool2o`0000;o
oooo0_l0001Cooooo`;o00009_ooool2o`0001;ooooo0_l0000<ooooo`;o00004_ooool001kooooo
00?o0000ooooooooool00_ooool2o`000>7ooooo0_l00002ooooo`;o00009_ooool2o`0000?ooooo
0_l00004ooooo`;o00001oooool2o`0000cooooo0_l0000Booooo`007_ooool00ol0003ooooooooo
o`2cooooo`;o0000<?ooool2o`0002oooooo0_l00004ooooo`?o00001Oooool2o`00017ooooo0_l0
000>ooooo`007_ooool00ol0003oooooooooo`2]ooooo`;o00001?ooool2o`0000cooooo0_l0000h
ooooo`;o00005?ooool2o`0000[ooooo0_l00004ooooo`?o00004Oooool2o`0000kooooo000Noooo
o`03o`000?oooooooooo02Gooooo0_l00018ooooo`;o0000=?ooool2o`0000Kooooo0_l0000Boooo
o`;o0000<_ooool2o`0000Cooooo0_l0000Booooo`Co00003Oooool2o`000003ooooool0003o0000
02;ooooo000Nooooo`;o00009_ooool2o`0004Sooooo0_l0000dooooo`;o0000C_ooool2o`0001Oo
oooo0ol0000?ooooo`;o00003?ooool2o`0001Oooooo000Nooooo`03o`000?oooooooooo0>kooooo
0_l0000Nooooo`;o00000oooool2o`0001Wooooo0_l0000Gooooo`007_ooool00ol0003ooooooooo
o`3=ooooo`;o00007oooool2o`0000?ooooo0_l0000Kooooo`;o000000?oooooo`000?l00000<_oo
ool001kooooo00?o0000ooooooooool0]oooool2o`0001Cooooo0_l0000Oooooo`;o00000oooool2
o`0001_ooooo0_l0000eooooo`007_ooool00ol0003oooooooooo`2gooooo`;o0000=Oooool2o`00
01;ooooo0_l00009ooooo`;o0000>?ooool001kooooo00?o0000ooooooooool0A?ooool2o`000;7o
oooo0_l00009ooooo`;o00002Oooool2o`0003Sooooo000Nooooo`03o`000?oooooooooo04Cooooo
0_l0002Qooooo`;o00003Oooool3o`0004kooooo000Nooooo`03o`000?oooooooooo06oooooo0_l0
001fooooo`;o00003Oooool4o`0004gooooo000Nooooo`03o`000?oooooooooo06oooooo0_l00027
ooooo`;o0000;?ooool2o`0001oooooo000Nooooo`03o`000?oooooooooo0?oooooo5_ooool2o`00
00oooooo0_l0000Oooooo`007_ooool00ol0003oooooooooo`1_ooooo`;o0000KOooool2o`0003Go
oooo0_l0000`ooooo`007_ooool00ol0003oooooooooo`1_ooooo`;o0000KOooool2o`0006Oooooo
000Nooooo`03o`000?oooooooooo0?oooooo:?ooool2o`0001kooooo000Nooooo`03o`000?oooooo
oooo0?kooooo0_l0000Wooooo`;o00007_ooool001kooooo00?o0000ooooooooool0ioooool2o`00
01Gooooo0_l00017ooooo`007_ooool00ol0003oooooooooo`3Wooooo`;o0000G_ooool001kooooo
0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo04cooooo0_l0000Pooooo`;o0000eooo
ool001kooooo00?o0000ooooooooool0C?ooool2o`00023ooooo0_l0003Gooooo`007_ooool00ol0
003oooooooooo`2Cooooo`;o0000/_ooool001kooooo00?o0000ooooooooool0Toooool2o`000;;o
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0Fooo
ool2o`0000Wooooo0_l00009ooooo`;o0000e?ooool001kooooo00?o0000ooooooooool0Foooool2
o`0000Wooooo0_l00009ooooo`;o0000e?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`0:ooooo`;o0000I?ooool2o`000=Gooooo000Nooooo`03o`00
0?oooooooooo00[ooooo0_l0001Tooooo`;o0000eOooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0J?ooool2o`000=gooooo000Nooooo`03o`00
0?oooooooooo06Sooooo0_l00008ooooo`;o0000doooool001kooooo0_l0001cooooo`;o0000>?oo
ool2o`0009Wooooo000Nooooo`03o`000?oooooooooo0:cooooo0_l0002Iooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo06cooooo0_l0003Iooooo`00
7_ooool00ol0003oooooooooo`02ooooo`;o0000J?ooool2o`0001?ooooo0_l00034ooooo`007_oo
ool00ol0003oooooooooo`02ooooo`;o0000OOooool2o`000<Cooooo000Nooooo`03o`000?oooooo
oooo06kooooo0_l0003Gooooo`007_ooool00ol0003oooooooooo`1^ooooo`;o0000eoooool001ko
oooo00?o0000ooooooooool06_ooool2o`000?oooooo;?ooool001kooooo00?o0000ooooooooool0
6_ooool2o`0006kooooo0_l0002kooooo`007_ooool00ol0003oooooooooo`2:ooooo`;o0000R_oo
ool2o`0002oooooo000Nooooo`03o`000?oooooooooo0?oooooo5oooool2o`0002oooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0?_ooool2o`000?oo
oooo2?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003
oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0?_ooool2o`000?oooooo2?ooool000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo067ooooo0_l0003Tooooo`000oooool01Ol@413ooooooooooooooooo410@00_o
oooo1Ol00006ooooo`?o0000HOooool2o`000<_ooooo0_l0000Gooooo`000oooool01Ol0003ooooo
oooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool00ol0003oooooooooo`1doooo
o`;o0000^?ooool2o`0001Oooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01?oM
gMgoEEEEooooool00007ooooo`03o`000?oooooooooo07Cooooo0_l0003Aooooo`000oooool01Ol@
413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0]
ooooo`;o0000oooooolIooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000001oooool00ol0003oooooooooo`0Jooooo`;o00004Oooool2o`000?oooooo6Oooool0
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000
ooooooooool06_ooool2o`000?oooooo;?ooool001kooooo00?o0000ooooooooool0N?ooool2o`00
0;?ooooo0_l0000Hooooo`007_ooool00ol0003oooooooooo`1hooooo`;o0000/oooool2o`0001So
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0:Ooo
ool2o`000003ooooool0003o00000?oooooo6_ooool001kooooo00?o0000ooooooooool0:Oooool2
o`000003ooooool0003o00000?oooooo6_ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo06Oooooo
0_l0003Nooooo`007_ooool00ol0003oooooooooo`1Wooooo`;o0000g_ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`0Booooo`;o00004oooool2o`00
0003ooooool0003o00000?oooooo7?ooool001kooooo0_l0000Cooooo`;o00004oooool5o`000:3o
oooo0_l0001iooooo`007_ooool00ol0003oooooooooo`0Yooooo`;o000000?oooooo`000?l00000
W_ooool2o`0007Wooooo000Nooooo`03o`000?oooooooooo02cooooo0_l0000@ooooo`;o0000oooo
ool8ooooo`007_ooool00ol0003oooooooooo`0nooooo`;o0000ooooool8ooooo`007_ooool00ol0
003oooooooooo`0Nooooo`;o0000oooooolXooooo`007_ooool00ol0003oooooooooo`0Nooooo`;o
00003?ooool2o`0000cooooo0_l0003oooooo`cooooo000Nooooo`03o`000?oooooooooo02cooooo
0_l00009ooooo`;o000000?oooooo`000?l00000ooooool<ooooo`007_ooool00ol0003ooooooooo
o`0gooooo`;o0000ooooool?ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo03kooooo0_l0003oooooo`Sooooo000Nooooo`03o`000?oooooooooo03?o
oooo0_l00009ooooo`;o00004Oooool2o`000?Cooooo000Nooooo`03o`000?oooooooooo02_ooooo
0_l00006ooooo`;o00007?ooool2o`000?Cooooo000Nooooo`03o`000?oooooooooo02_ooooo0_l0
000nooooo`;o0000f_ooool001kooooo00?o0000ooooooooool08oooool2o`0004Kooooo0_l0003J
ooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o00005oooool2o`0000Gooooo0_l0003ooooo
o`?ooooo000Nooooo`03o`000?oooooooooo03cooooo0_l00005ooooo`;o0000ooooool3ooooo`00
7_ooool2o`0002Oooooo0_l0000Eooooo`;o0000ooooool9ooooo`007_ooool00ol0003ooooooooo
o`0Vooooo`;o00003oooool2o`0000Cooooo0_l0000/ooooo`;o0000cOooool2o`0000_ooooo000N
ooooo`03o`000?oooooooooo03;ooooo0_l00003ooooo`;o0000<_ooool2o`000<gooooo0_l0000;
ooooo`007_ooool00ol0003oooooooooo`0Zooooo`;o00001_ooool2o`000?oooooo5?ooool001ko
oooo00?o0000ooooooooool0:_ooool2o`0004Oooooo0_l0003Booooo`007_ooool00ol0003ooooo
ooooo`1cooooo`;o0000d_ooool001kooooo00?o0000ooooooooool0=oooool2o`000?oooooo3ooo
ool001kooooo00?o0000ooooooooool0=oooool2o`000?oooooo3oooool001kooooo00?o0000oooo
ooooool0:?ooool2o`000?oooooo7_ooool001kooooo00?o0000ooooooooool0:?ooool2o`000?oo
oooo7_ooool001kooooo00?o0000ooooooooool0C_ooool2o`0000;ooooo0_l0003cooooo`007_oo
ool00ol0003oooooooooo`1>ooooo`;o00000_ooool2o`0001Sooooo0_l0003Iooooo`007_ooool0
0ol0003oooooooooo`1Eooooo`;o00005Oooool2o`000=Wooooo000Nooooo`03o`000?oooooooooo
05Gooooo0_l0003`ooooo`007_ooool00ol0003oooooooooo`1Pooooo`;o0000iOooool001kooooo
00?o0000ooooooooool0AOooool2o`0001Wooooo0_l0003Uooooo`007_ooool2o`0004Kooooo0_l0
0007ooooo`;o00005?ooool2o`000>7ooooo000Nooooo`03o`000?oooooooooo04kooooo0_l0000D
ooooo`;o0000hOooool001kooooo00?o0000ooooooooool08?ooool2o`0002Gooooo0_l00007oooo
o`;o00005Oooool2o`000=kooooo000Nooooo`03o`000?oooooooooo023ooooo0_l0000Uooooo`;o
00001oooool2o`0001Gooooo0_l0003Nooooo`007_ooool00ol0003oooooooooo`18ooooo`;o0000
4_ooool2o`0000?ooooo0_l00003ooooo`;o0000goooool001kooooo00?o0000ooooooooool0B?oo
ool2o`0001;ooooo0_l00003ooooo`;o00000oooool2o`000=oooooo000Nooooo`03o`000?oooooo
oooo05Kooooo0_l0000<ooooo`;o00001?ooool4o`000=Wooooo000Nooooo`03o`000?oooooooooo
02[ooooo0_l00008ooooo`;o00006?ooool2o`0000Kooooo0_l0000<ooooo`?o00000oooool4o`00
0=Wooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l000000ooooooo0000o`000008ooooo`;o
00006?ooool2o`0001Gooooo0_l0003Pooooo`007_ooool00ol0003oooooooooo`0Wooooo`;o0000
00Coooooo`000?l0003ooooo0_l0003oooooo`_ooooo0_l0000<ooooo`007_ooool00ol0003ooooo
ooooo`0Vooooo`;o00000_ooool2o`000003ooooool0003o000002Oooooo0_l0003Qooooo`;o0000
3?ooool001kooooo00?o0000ooooooooool09_ooool2o`0000gooooo0_l00006ooooo`;o00005ooo
ool2o`0000kooooo0ol0001<ooooo`;o0000T?ooool001kooooo00?o0000ooooooooool07oooool2
o`0000Kooooo0_l0000<ooooo`;o00001_ooool2o`0002Oooooo0ol00005ooooo`;o00001oooool2
o`0003cooooo0_l0002@ooooo`007_ooool00ol0003oooooooooo`0Mooooo`Ko00001?ooool2o`00
017ooooo0_l0000Xooooo`;o00002?ooool2o`0000Oooooo0_l0003>ooooo`000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool0
0ol0003oooooooooo`0Mooooo`;o00000_ooool2o`000003ooooool0003o000001;ooooo1?l00003
ooooo`;o00008oooool2o`000>7ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo02Cooooo0_l0
000Booooo`;o00001Oooool2o`0000?ooooo0_l0000^ooooo`;o0000dOooool000?ooooo00Go410@
oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`0002Sooooo
0_l0000Jooooo`;o000000?oooooo`000?l00000:oooool2o`000:gooooo0_l0000Rooooo`000ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`03
o`000?oooooooooo01[ooooo0_l0000;ooooo`Co00001_ooool2o`0001Cooooo0_l0000<ooooo`;o
00005oooool2o`0000Cooooo0_l0001booooo`;o0000>Oooool2o`0002;ooooo0003ooooo`05o`00
0?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000oooo
ooooool06_ooool2o`0000_ooooo1?l00006ooooo`;o00001Oooool2o`0001_ooooo0_l0000Goooo
o`;o00003oooool2o`0006Oooooo0_l0001Mooooo`000oooool01Ol@413ooooooooooooooooo410@
00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`0Fooooo`;o00007_ooool4o`00
00Kooooo0_l00009ooooo`;o00008oooool2o`0000gooooo1?l00034ooooo`000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0Foooo
o`?o00001Oooool2o`0001Kooooo0_l00005ooooo`;o000000?oooooo`000?l000002Oooool3o`00
02;ooooo0_l0000?ooooo`;o0000a?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool05Oooool4o`0000Gooooo1?l00006
ooooo`;o00001?ooool2o`0000gooooo0_l00002ooooo`?o00002?ooool2o`0001kooooo0_l00002
ooooo`;o00003oooool2o`000<Cooooo000Nooooo`03o`000?oooooooooo01?ooooo1?l00009oooo
o`?o00001Oooool2o`0000Cooooo0_l00008ooooo`;o00001oooool3o`0000Sooooo0_l00002oooo
o`?o00006Oooool2o`0000;ooooo0_l0001Aooooo`;o0000P_ooool001kooooo00?o0000oooooooo
ool04oooool3o`0000Kooooo0_l000000ooooooo0000o`000002o`0000Kooooo0_l0000=ooooo`;o
00004oooool2o`000003ooooool0003o000000;o0000Koooool2o`0008;ooooo000Nooooo`03o`00
0?oooooooooo01;ooooo0ol00007ooooo`Go00001?ooool2o`0000;ooooo0_l0000Rooooo`;o0000
00?oooooo`000?l000000_l0000Tooooo`;o0000cOooool001kooooo00?o0000ooooooooool04_oo
ool2o`0000Wooooo0_l00004ooooo`Co00002_ooool2o`0001Sooooo0_l000001?oooooo0000o`00
0?ooool4o`0000gooooo0_l0000:ooooo`;o00001oooool3o`000<gooooo000Nooooo`03o`000?oo
oooooooo013ooooo0_l0000Aooooo`;o00003?ooool2o`0000;ooooo0_l0000Dooooo`Go000000?o
ooooo`000?l000001Ol0000:ooooo`;o00002_ooool2o`0000Oooooo0_l0003>ooooo`007_ooool0
0ol0003oooooooooo`0@ooooo`;o00002Oooool2o`0000kooooo0_l00008ooooo`;o00005Oooool2
o`0000;ooooo0_l000000ooooooo0000o`000003o`0002Cooooo0_l00005ooooo`?o00000oooool2
o`0005Gooooo0_l0001Uooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o00002?ooool2o`00
00kooooo0_l0000Rooooo`?o000000?oooooo`000?l000000ol0000Fooooo`;o000000?oooooo`00
0?l000002Oooool2o`0000?ooooo1Ol00003ooooo`;o0000EOooool2o`0006Gooooo000Nooooo`03
o`000?oooooooooo017ooooo1?l00009ooooo`;o00004?ooool2o`0001Wooooo0_l00002ooooo`?o
00001_ooool3o`0001?ooooo0_l000000ooooooo0000o`000003ooooo`;o00002Oooool2o`000003
ooooool0003o00000<7ooooo000Nooooo`03o`000?oooooooooo017ooooo1?l00009ooooo`;o0000
4?ooool3o`0000;ooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l00009ooooo`Go0000
6oooool3o`0000Wooooo0_l000000ooooooo0000o`000030ooooo`007_ooool00ol0003ooooooooo
o`0=ooooo`;o00000_ooool2o`000003ooooool0003o000001Cooooo0_l00005ooooo`;o00000_oo
ool2o`0000Gooooo0_l00006ooooo`;o00004?ooool3o`000003ooooool0003o000001_ooooo0_l0
0009ooooo`;o000000?oooooo`000?l00000`?ooool001kooooo00?o0000ooooooooool03Oooool4
o`0000?ooooo0ol00004ooooo`;o00000oooool2o`0000Sooooo0_l00002ooooo`;o00008?ooool2
o`0000Gooooo0_l000000ooooooo0000o`000009ooooo`;o00000oooool2o`000=_ooooo000Noooo
o`;o00003?ooool6o`0000Cooooo0ol00003ooooo`;o00000oooool4o`0000[ooooo0_l0000Moooo
o`;o000000?oooooo`000?l000001_ooool5o`0000Sooooo0_l00003ooooo`;o0000foooool001ko
oooo00?o0000ooooooooool02oooool2o`0000Wooooo0_l0000:ooooo`;o00005?ooool2o`0001?o
oooo0_l00009ooooo`Go00006?ooool2o`000=3ooooo000Nooooo`03o`000?oooooooooo01?ooooo
0_l000000ooooooo0000o`000002ooooo`;o00005oooool2o`0000?ooooo0_l00003ooooo`;o0000
4?ooool2o`0000Wooooo1?l0000Gooooo`;o00002?ooool2o`000<Kooooo000Nooooo`03o`000?oo
oooooooo01?ooooo2Ol0000:ooooo`;o00001Oooool3o`0000?ooooo0_l00008ooooo`;o00004?oo
ool2o`0000_ooooo1?l000000ooooooo0000o`00000@ooooo`;o00000oooool4o`0000?ooooo0_l0
0036ooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o000000?oooooo`000?l000003?ooool2
o`0000Gooooo0ol0000^ooooo`Go00004?ooool2o`0000?ooooo1?l00007ooooo`;o000000?ooooo
o`000?l00000_oooool001kooooo00?o0000ooooooooool05Oooool2o`0000Oooooo0_l0000>oooo
o`;o00001Oooool4o`0001Cooooo1Ol0000>ooooo`;o00008Oooool2o`000003ooooool0003o0000
0;oooooo000Nooooo`03o`000?oooooooooo01kooooo0_l0000Eooooo`Co00001Oooool2o`0000go
oooo1Ol0000Fooooo`;o00003oooool2o`000<cooooo000Nooooo`03o`000?oooooooooo03Gooooo
0_l00007ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l000000ooooooo0000
o`00000Hooooo`?o00003oooool2o`0000kooooo0_l0000;ooooo`;o0000[oooool001kooooo00?o
0000ooooooooool0;oooool2o`00013ooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0
003o000000;o00005_ooool2o`0000_ooooo0_l0000Cooooo`;o00002oooool2o`000:oooooo000N
ooooo`03o`000?oooooooooo02oooooo0_l0000Fooooo`;o00001_ooool3o`000003ooooool0003o
000001oooooo0_l0003Aooooo`007_ooool00ol0003oooooooooo`0Yooooo`;o00007?ooool2o`00
00Gooooo1?l000000ooooooo0000o`00000Oooooo`;o0000dOooool001kooooo00?o0000oooooooo
ool0:Oooool2o`0000;ooooo0_l0000Oooooo`;o00007oooool2o`000;_ooooo0_l0000Iooooo`00
7_ooool00ol0003oooooooooo`0Hooooo`;o00004oooool2o`0000;ooooo0_l00004ooooo`;o0000
2Oooool2o`0000Sooooo1?l0000Cooooo`;o00002_ooool2o`000;_ooooo0_l0000Iooooo`007_oo
ool00ol0003oooooooooo`0Fooooo`Co00004?ooool2o`0000Gooooo0_l00004ooooo`;o00002Ooo
ool2o`0000Sooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00003_ooool3o`0001Gooooo
0ol00039ooooo`007_ooool00ol0003oooooooooo`0Fooooo`;o00001Oooool2o`0000;ooooo0_l0
0007ooooo`;o00007oooool2o`0000;ooooo0ol000000ooooooo0000o`00000?ooooo`?o00004ooo
ool4o`0008kooooo0_l0000iooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o00000_ooool2
o`0002Sooooo0_l0000:ooooo`;o00001_ooool2o`0000Cooooo0_l0000Cooooo`;o0000T?ooool2
o`0003Wooooo000Nooooo`;o00008Oooool2o`0002Wooooo0_l000000ooooooo0000o`000004o`00
00?ooooo0_l00005ooooo`Co0000iOooool001kooooo00?o0000ooooooooool08?ooool2o`0002?o
oooo0_l00004ooooo`Wo00002_ooool4o`000>Gooooo000Nooooo`03o`000?oooooooooo02Wooooo
0_l0000Jooooo`;o00001Oooool5o`0001kooooo0_l0003Fooooo`007_ooool00ol0003ooooooooo
o`0Yooooo`;o00002?ooool2o`0000Oooooo0_l0000>ooooo`Go00007_ooool2o`000=Kooooo000N
ooooo`03o`000?oooooooooo03;ooooo0ol00007ooooo`;o00003oooool4o`00017ooooo0_l0003S
ooooo`007_ooool00ol0003oooooooooo`0booooo`;o00006_ooool2o`0000oooooo0_l000000ooo
oooo0000o`00003Sooooo`007_ooool00ol0003oooooooooo`0Zooooo`;o00008oooool2o`0000[o
oooo1_l0003Vooooo`007_ooool00ol0003oooooooooo`0Xooooo`Co00006_ooool2o`0000Gooooo
1Ol00009ooooo`Ko0000i_ooool001kooooo00?o0000ooooooooool0:?ooool2o`0000Kooooo0_l0
000Dooooo`Co00000_ooool6o`0000Sooooo0_l00003ooooo`;o00002Oooool2o`000=_ooooo000N
ooooo`03o`000?oooooooooo01_ooooo0_l0000Aooooo`Co00005_ooool2o`0000;ooooo1Ol00009
ooooo`;o00003_ooool2o`00023ooooo0_l0002iooooo`007_ooool00ol0003oooooooooo`0Koooo
o`;o00004Oooool2o`0001cooooo1Ol0000kooooo`;o0000^Oooool001kooooo00?o0000oooooooo
ool0AOooool2o`0000Kooooo0ol00006ooooo`Co00002_ooool2o`000>7ooooo000Nooooo`03o`00
0?oooooooooo037ooooo0_l0000Booooo`;o00001_ooool3o`0000Kooooo1?l000000ooooooo0000
o`000006ooooo`?o0000hOooool001kooooo00?o0000ooooooooool0<Oooool3o`0000?ooooo0_l0
000?ooooo`;o00000oooool5o`0000Wooooo0_l00006ooooo`;o0000h_ooool001kooooo00?o0000
ooooooooool0<_ooool2o`0000?ooooo0_l0000?ooooo`;o00000oooool5o`0000oooooo0_l00005
ooooo`;o0000gOooool001kooooo00?o0000ooooooooool0@_ooool2o`0000;ooooo0_l00004oooo
o`Ko00003oooool2o`0000Gooooo0_l0003Mooooo`007_ooool2o`0003oooooo0_l00002ooooo`;o
000000Coooooo`000?l0003o00001?ooool6o`000?Gooooo000Nooooo`03o`000?oooooooooo03ko
oooo0ol00004ooooo`?o00001_ooool2o`0000Wooooo0_l00007ooooo`;o00004oooool2o`000<ko
oooo000Nooooo`03o`000?oooooooooo03kooooo0ol00004ooooo`Co00001Oooool3o`0000Sooooo
0_l00007ooooo`;o00004oooool2o`0001?ooooo0_l0002iooooo`007_ooool00ol0003ooooooooo
o`15ooooo`Ko000000?oooooo`000?l000000ol0000kooooo`;o0000^Oooool001kooooo00?o0000
ooooooooool06Oooool2o`0000kooooo0_l0000Nooooo`;o000000?oooooo`000?l000002oooool4
o`000>[ooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l0000>ooooo`;o00008Oooool4o`00
00Wooooo1?l00007ooooo`;o00001Oooool2o`000=[ooooo000Nooooo`03o`000?oooooooooo02Wo
oooo0_l0000Sooooo`;o00005?ooool2o`0000Gooooo0_l0003Jooooo`007_ooool00ol0003ooooo
ooooo`0Yooooo`;o00008oooool2o`0000Cooooo1?l00019ooooo`;o0000Y?ooool001kooooo00?o
0000ooooooooool0C_ooool4o`0000;ooooo1?l00019ooooo`;o0000Y?ooool001kooooo00?o0000
ooooooooool0=_ooool2o`0001Oooooo0ol0000?ooooo`;o0000i?ooool001kooooo00?o0000oooo
ooooool0=_ooool2o`0001Oooooo0_l0000@ooooo`;o000000?oooooo`000?l000005_ooool2o`00
0<Wooooo000Nooooo`03o`000?oooooooooo057ooooo0_l0000?ooooo`Co00005_ooool2o`000<Wo
oooo000Nooooo`03o`000?oooooooooo057ooooo0_l0000?ooooo`;o0000;Oooool2o`000;Cooooo
000Nooooo`03o`000?oooooooooo063ooooo0_l0000_ooooo`;o0000]?ooool000?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo
00?o0000ooooooooool0H?ooool2o`000>Gooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo01[o
oooo0_l0003oooooobcooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003o
oooooooooooooooo000000Kooooo0ol0000Jooooo`;o0000Koooool2o`000;[ooooo0003ooooo`05
o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000
ooooooooool0F_ooool2o`000003ooooool0003o000000[o00000_ooool3o`0001gooooo0_l00004
ooooo`;o0000]?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o
0000o`000?o<c<`01_ooool00ol0003oooooooooo`1Jooooo`oo000000?oooooo`000?l000000_l0
0002ooooo`;o00007?ooool2o`000003ooooool0003o00000;Cooooo0003ooooo`05oa0@4?oooooo
ooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0
E_ooool4o`0000;ooooo1Ol00003ooooo`Co00000_ooool2o`000004ooooool0003o0000ooooo`;o
00005oooool2o`0000?ooooo0_l0002gooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo05Kooooo1_l000000ooo
oooo0000o`000004o`000003ooooool0003o000000;o00001Oooool5o`0000;ooooo0_l0000Coooo
o`;o0000_?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000
oa0@4?nYZJT01_ooool00ol0003oooooooooo`1@ooooo`;o00001Oooool5o`000003ooooool0003o
000000;ooooo0_l00003ooooo`;o00001_ooool2o`0000Cooooo0_l000000ooooooo0000o`000002
o`000<cooooo000Nooooo`03o`000?oooooooooo02kooooo0_l0000Oooooo`?o000000?oooooo`00
0?l000003Oooool2o`0000;ooooo0_l0000?ooooo`Co00000_ooool2o`000<Sooooo000Nooooo`03
o`000?oooooooooo01oooooo0_l0000=ooooo`;o00007oooool2o`000003ooooool0003o000000;o
00002oooool9o`0001?ooooo0_l00038ooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o0000
;?ooool2o`0000?ooooo1?l00008ooooo`co00000oooool2o`0000gooooo0_l00039ooooo`007_oo
ool00ol0003oooooooooo`18ooooo`?o00000_ooool3o`000004ooooool0003o0000ooooo`;o0000
0oooool2o`0000?ooooo3?l00003ooooo`Co00002oooool3o`0000Gooooo0_l00031ooooo`007_oo
ool00ol0003oooooooooo`15ooooo`Ko00000oooool5o`0000Kooooo1Ol000000ooooooo0000o`00
0002ooooo`_o000000Coooooo`000?l0003ooooo0_l00009ooooo`;o00001Oooool2o`0000cooooo
0_l0002cooooo`007_ooool00ol0003oooooooooo`12ooooo`Oo00001_ooool5o`0000Kooooo1?l0
0007ooooo`Co000000?oooooo`000?l000000ol00003ooooo`Go00006oooool2o`0001Cooooo0_l0
002Mooooo`007_ooool00ol0003oooooooooo`0Qooooo`;o00007oooool9o`0000Oooooo0ol00007
ooooo`;o00003oooool2o`0000Cooooo1?l00006ooooo`;o0000:Oooool2o`0009gooooo000Noooo
o`03o`000?oooooooooo027ooooo0_l0000Nooooo`Co00001?ooool2o`0000Sooooo0_l00004oooo
o`;o000000?oooooo`000?l000003_ooool2o`0000Gooooo0_l00002ooooo`;o00001?ooool6o`00
00;ooooo0_l00030ooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o00007Oooool4o`00013o
oooo0_l00004ooooo`Go00003Oooool3o`0000Wooooo0_l00006ooooo`Co00000_ooool3o`000;oo
oooo000Nooooo`03o`000?oooooooooo023ooooo0_l0000Mooooo`Co00001Oooool6o`0000Gooooo
0_l00005ooooo`Co00003Oooool4o`0000?ooooo0_l00004ooooo`;o00003?ooool4o`000;gooooo
000Nooooo`03o`000?oooooooooo047ooooo1Ol00002ooooo`Oo00002oooool4o`0000oooooo0_l0
0003ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00000:ooooo`?o0000
_Oooool001kooooo0_l00010ooooo`Oo00001oooool2o`0000cooooo0ol0000Gooooo`;o00001?oo
ool2o`0000[ooooo0_l0002nooooo`007_ooool00ol0003oooooooooo`0kooooo`Ko00001oooool2
o`000003ooooool0003o000000;ooooo0_l00009ooooo`?o00007_ooool2o`0000[ooooo0_l0000D
ooooo`;o0000Z?ooool001kooooo00?o0000ooooooooool0>oooool6o`0000Oooooo0_l000000ooo
oooo0000o`000004o`0000Wooooo0ol0000Gooooo`;o00001?ooool5o`0000_ooooo0_l0000Aoooo
o`;o0000Z?ooool001kooooo00?o0000ooooooooool0B_ooool5o`0000Oooooo0_l00002ooooo`;o
00004_ooool2o`0000Cooooo1?l00002ooooo`Go00000oooool2o`0000Kooooo0ol0002jooooo`00
7_ooool00ol0003oooooooooo`0Tooooo`;o00001_ooool2o`0001cooooo1?l00002ooooo`;o0000
1?ooool6o`0001;ooooo0_l00006ooooo`;o00002_ooool2o`0000Kooooo0ol00002ooooo`;o0000
0_ooool2o`000;;ooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l00006ooooo`;o00003?oo
ool2o`0000Wooooo0ol00002ooooo`;o00000oooool3o`0000Kooooo1?l0000Looooo`;o00004?oo
ool3o`0000;ooooo1_l0002booooo`007_ooool00ol0003oooooooooo`0jooooo`;o000000?ooooo
o`000?l000001_ooool3o`000003ooooool0003o000000Cooooo0_l00007ooooo`?o00007Oooool2
o`0001Gooooo1?l000000ooooooo0000o`00002aooooo`007_ooool00ol0003oooooooooo`0moooo
o`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l00002ooooo`;o00002Oooool4o`00
03?ooooo1ol0002aooooo`007_ooool00ol0003oooooooooo`0gooooo`;o00001oooool2o`0000;o
oooo0ol00004ooooo`Co00002_ooool3o`0003Cooooo1?l0002cooooo`007_ooool00ol0003ooooo
ooooo`0gooooo`?o00002oooool2o`000004ooooool0003o0000ooooo`Co00002oooool2o`0002Go
oooo0_l0000@ooooo`;o0000/_ooool001kooooo00?o0000ooooooooool0>?ooool2o`0000[ooooo
0_l00002ooooo`;o000000?oooooo`000?l000000_l00008ooooo`;o00005Oooool2o`00017ooooo
0_l0000@ooooo`;o0000/_ooool001kooooo00?o0000ooooooooool0=Oooool2o`0000_ooooo1?l0
0004ooooo`Ko00001oooool2o`0001Gooooo0_l0000Kooooo`;o0000^_ooool001kooooo00?o0000
ooooooooool0=Oooool2o`0000_ooooo0_l00002ooooo`?o000000?oooooo`000?l000000_ooool2
o`0000?ooooo1?l0000dooooo`;o00000oooool4o`000;?ooooo000Nooooo`03o`000?oooooooooo
01oooooo0_l0000Kooooo`;o00001_ooool5o`0000[ooooo1?l0000Vooooo`;o00004Oooool4o`00
0;?ooooo000Nooooo`03o`000?oooooooooo01oooooo0_l0000Dooooo`;o00001Oooool2o`0000Co
oooo1?l0000?ooooo`;o00009_ooool2o`000<Sooooo000Nooooo`03o`000?oooooooooo03Gooooo
0_l00004ooooo`;o00000_ooool2o`000003ooooool0003o000000Gooooo0_l00005ooooo`;o0000
mOooool001kooooo0_l0000cooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00001?oo
ool2o`0000;ooooo0_l00005ooooo`;o0000=_ooool2o`000;gooooo000Nooooo`03o`000?oooooo
oooo03;ooooo0_l00002ooooo`;o00003Oooool3o`0003oooooo1Ol0002kooooo`007_ooool00ol0
003oooooooooo`16ooooo`;o0000?Oooool4o`000003ooooool0003o00000;_ooooo000Nooooo`03
o`000?oooooooooo01cooooo0_l0000Xooooo`;o0000?Oooool2o`000<3ooooo000Nooooo`03o`00
0?oooooooooo01cooooo0_l00002ooooo`?o00006?ooool2o`0000Wooooo0_l0000cooooo`;o0000
2oooool2o`000;gooooo000Nooooo`03o`000?oooooooooo023ooooo0ol0000>ooooo`;o00000_oo
ool2o`000004ooooool0003o0000ooooo`;o00001Oooool2o`0000Oooooo0_l0000^ooooo`;o0000
2oooool2o`000;gooooo000Nooooo`03o`000?oooooooooo037ooooo0_l00002ooooo`;o000000Co
ooooo`000?l0003ooooo0_l00005ooooo`;o00001oooool2o`0003?ooooo0_l00006ooooo`;o0000
_Oooool001kooooo00?o0000ooooooooool06oooool2o`00017ooooo0_l000000ooooooo0000o`00
0003ooooo`;o00000oooool2o`0001Sooooo0_l0000Xooooo`?o0000aOooool001kooooo00?o0000
ooooooooool06oooool2o`0000_ooooo1?l00002ooooo`Ko00000_ooool2o`0001[ooooo0_l00000
0ooooooo0000o`00000Rooooo`;o00001?ooool3o`000<Gooooo000Nooooo`03o`000?oooooooooo
01cooooo0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o000000;o00000oooool2o`00
0003ooooool0003o000001kooooo0_l0000Uooooo`;o00001Oooool2o`000<Gooooo000Nooooo`03
o`000?oooooooooo01cooooo0_l00003ooooo`;o00000_ooool2o`0001Sooooo0_l0000oooooo`;o
0000aOooool001kooooo00?o0000ooooooooool08_ooool2o`0001_ooooo0_l0003oooooo`Oooooo
000Nooooo`03o`000?oooooooooo01oooooo0_l000000ooooooo0000o`000004ooooo`;o0000oooo
oolNooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o00001oooool2o`0004Wooooo0_l00003
ooooo`;o0000cOooool001kooooo00?o0000ooooooooool0Loooool2o`0000?ooooo0_l0003=oooo
o`007_ooool00ol0003oooooooooo`0Tooooo`;o00004_ooool2o`00013ooooo0_l0003kooooo`00
7_ooool2o`0002Gooooo0_l0000?ooooo`;o000000?oooooo`000?l000004?ooool2o`000?_ooooo
000Nooooo`03o`000?oooooooooo03Gooooo0_l0000;ooooo`;o0000<oooool2o`000<kooooo000N
ooooo`03o`000?oooooooooo02[ooooo0_l0000Fooooo`;o00003Oooool2o`0002Cooooo0_l0003>
ooooo`007_ooool00ol0003oooooooooo`0Zooooo`;o00009Oooool2o`0002Cooooo0_l0003>oooo
o`007_ooool00ol0003oooooooooo`1fooooo`?o0000c_ooool001kooooo00?o0000ooooooooool0
7_ooool2o`0001[ooooo0_l0000jooooo`;o0000coooool001kooooo00?o0000ooooooooool07_oo
ool2o`0001[ooooo0_l0003oooooo`cooooo000Nooooo`03o`000?oooooooooo03Sooooo0_l0002e
ooooo`;o0000E_ooool001kooooo00?o0000ooooooooool05?ooool2o`0002;ooooo0_l00003oooo
o`?o0000:oooool2o`0000Wooooo0_l0001gooooo`;o0000E_ooool001kooooo00?o0000oooooooo
ool05?ooool2o`0002Oooooo0ol0000[ooooo`;o00002Oooool2o`000<oooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0?_ooool2o`000?oooooo2?oo
ool001kooooo00?o0000ooooooooool0:Oooool2o`0001?ooooo0_l0003oooooo`Sooooo000Noooo
o`03o`000?oooooooooo02Wooooo0_l0003ooooooagooooo000Dooooo`Co000000?o410@oooooooo
ool00oooool00ol0003oooooooooo`0Wooooo`;o00003oooool2o`000?oooooo3_ooool001Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Wooooo`;o00003oooool2o`000?oooooo
3_ooool001Kooooo00?o0000ooooooooool01Oooool3o`0002Kooooo0_l0000Gooooo`;o0000oooo
ool7ooooo`005_ooool00ol0003oooooooooo`0^ooooo`;o00005oooool2o`000?oooooo1oooool0
01Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3o
oooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Cooooo00?oEEEEofIVI_l00000oooo
oomBooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.26072 .68862 Mdot
.07611 .3626 Mdot
.22599 .77159 Mdot
.35214 .76131 Mdot
.26227 .80412 Mdot
.26298 .76671 Mdot
.18302 .09098 Mdot
.25365 .79474 Mdot
.28193 .80707 Mdot
.61262 .29464 Mdot
.24249 .75807 Mdot
.18745 .79365 Mdot
.23737 .75577 Mdot
.01241 .67045 Mdot
.28699 .75159 Mdot
.05694 .64485 Mdot
.05822 .49785 Mdot
.24001 .71134 Mdot
.22659 .69208 Mdot
.34948 .74834 Mdot
.37273 .57371 Mdot
.22971 .74684 Mdot
.17192 .79049 Mdot
.1528 .16368 Mdot
.30949 .82197 Mdot
.24564 .84442 Mdot
.30734 .81382 Mdot
.05127 .64102 Mdot
.23695 .76162 Mdot
.24934 .72504 Mdot
.23433 .70866 Mdot
.27893 .75738 Mdot
.26431 .8127 Mdot
.48883 .87562 Mdot
.42341 .67408 Mdot
.35956 .82375 Mdot
.01355 .67228 Mdot
.28937 .50723 Mdot
.12974 .82299 Mdot
.31794 .81197 Mdot
.22801 .70647 Mdot
.43086 .67934 Mdot
.42898 .7948 Mdot
.24038 .5185 Mdot
.10822 .93455 Mdot
.43982 .68523 Mdot
.33549 .35416 Mdot
.44784 .85399 Mdot
.33578 .84665 Mdot
.32072 .70582 Mdot
.18867 .85728 Mdot
.42123 .71589 Mdot
.259 .85204 Mdot
.3626 .84014 Mdot
.25348 .85208 Mdot
.32261 .14424 Mdot
.75174 .17855 Mdot
.25521 .76746 Mdot
.30768 .81191 Mdot
.26325 .64326 Mdot
.32909 .74767 Mdot
.24405 .81232 Mdot
.21077 .04205 Mdot
.30868 .82474 Mdot
.30367 .73606 Mdot
.24331 .7706 Mdot
.39111 .75314 Mdot
.30792 .81465 Mdot
.26212 .75007 Mdot
.82066 .20798 Mdot
.37549 .11547 Mdot
.15853 .64922 Mdot
.40922 .85595 Mdot
.29238 .9107 Mdot
.2259 .78608 Mdot
.28772 .26299 Mdot
.27531 .84418 Mdot
.44585 .0839 Mdot
.29539 .79139 Mdot
.08215 .7555 Mdot
.47059 .8512 Mdot
.35631 .19602 Mdot
.27844 .53245 Mdot
.24536 .79766 Mdot
.88315 .21685 Mdot
.37088 .06257 Mdot
.26859 .82754 Mdot
.33913 .80472 Mdot
.27167 .74998 Mdot
.21957 .62802 Mdot
.3821 .77286 Mdot
.8573 .23027 Mdot
.31383 .68624 Mdot
.36464 .02675 Mdot
.23698 .65088 Mdot
.4728 .79782 Mdot
.28164 .02488 Mdot
.42472 .69063 Mdot
.32239 .83293 Mdot
.42021 .63126 Mdot
.28976 .76161 Mdot
.18219 .87214 Mdot
.2722 .69542 Mdot
.01833 .6626 Mdot
.09044 .33569 Mdot
.18029 .78665 Mdot
.08268 .62398 Mdot
.06116 .63573 Mdot
.41918 .73775 Mdot
.34407 .1289 Mdot
.01779 .66901 Mdot
.23157 .44946 Mdot
.12239 .88255 Mdot
.24684 .71097 Mdot
.11523 .54475 Mdot
.19568 .15224 Mdot
.09555 .92967 Mdot
.22006 .76167 Mdot
.40468 .34087 Mdot
.06655 .9029 Mdot
.31637 .82792 Mdot
.44035 .76771 Mdot
.2254 .75445 Mdot
.3629 .04393 Mdot
.92889 .24763 Mdot
.4039 .6002 Mdot
.27755 .86564 Mdot
.23901 .68034 Mdot
.50891 .8685 Mdot
.42396 .84684 Mdot
.37106 .59937 Mdot
.20197 .1478 Mdot
.00781 .6755 Mdot
.20546 .71137 Mdot
.22633 .68149 Mdot
.24138 .84007 Mdot
.19478 .79523 Mdot
.15504 .60284 Mdot
.25194 .73193 Mdot
.25737 .78112 Mdot
.24548 .67568 Mdot
.3135 .82832 Mdot
.23709 .7667 Mdot
.45352 .65847 Mdot
.2922 .13991 Mdot
.19926 .7859 Mdot
.28366 .66789 Mdot
.30369 .78545 Mdot
.74676 .19018 Mdot
.30477 .16229 Mdot
.20735 .77498 Mdot
.24832 .79164 Mdot
.16657 .80973 Mdot
.34694 .75231 Mdot
.29887 .76718 Mdot
.22113 .77765 Mdot
.12239 .61371 Mdot
.77611 .16189 Mdot
.29494 .81269 Mdot
.07898 .6371 Mdot
.14278 .63386 Mdot
.40916 .65356 Mdot
.17959 .96988 Mdot
.19216 .71162 Mdot
.32173 .8285 Mdot
.25598 .82299 Mdot
.30689 .77903 Mdot
.2996 .80816 Mdot
.30842 .12288 Mdot
.20654 .74057 Mdot
.22844 .7384 Mdot
.48649 .8522 Mdot
.40655 .66409 Mdot
.40471 .27744 Mdot
.24629 .68652 Mdot
.12797 .63269 Mdot
.39735 .88686 Mdot
.23758 .84536 Mdot
.24166 .0849 Mdot
.41945 .70578 Mdot
.41789 .80107 Mdot
.22357 .81458 Mdot
.08623 .78494 Mdot
.15136 .89478 Mdot
.65078 .15173 Mdot
.12694 .88945 Mdot
.08221 .63795 Mdot
.39848 .77347 Mdot
.8679 .68605 Mdot
.46543 .65404 Mdot
.24072 .68407 Mdot
.32949 .07148 Mdot
.24856 .68099 Mdot
.15517 .86633 Mdot
.07735 .89911 Mdot
.42221 .783 Mdot
.42559 .65394 Mdot
.20935 .75824 Mdot
.28193 .80849 Mdot
.23626 .78854 Mdot
.18274 .92506 Mdot
.09785 .48373 Mdot
.20556 .70192 Mdot
.14757 .91586 Mdot
.30955 .82319 Mdot
.3419 .80225 Mdot
.25682 .16981 Mdot
.3244 .80247 Mdot
.91399 .21233 Mdot
.05496 .67562 Mdot
.2146 .76903 Mdot
.26063 .67658 Mdot
.98186 .23199 Mdot
.58755 .12464 Mdot
.14475 .61699 Mdot
.38321 .04789 Mdot
.31379 .78858 Mdot
.39105 .36821 Mdot
.10966 .62297 Mdot
.37561 .73543 Mdot
.76377 .17255 Mdot
.19475 .66772 Mdot
.31655 .83337 Mdot
.29215 .80405 Mdot
.20906 .64357 Mdot
.13521 .66034 Mdot
.48265 .82943 Mdot
.19458 .83025 Mdot
.61009 .18239 Mdot
.23849 .76772 Mdot
.22439 .80588 Mdot
.26987 .64093 Mdot
.23561 .76563 Mdot
.43869 .87562 Mdot
.38366 .03518 Mdot
.62805 .2353 Mdot
.60974 .43474 Mdot
.22898 .73256 Mdot
.3228 .54134 Mdot
.72003 .23583 Mdot
.25367 .85571 Mdot
.23147 .75211 Mdot
.43755 .82914 Mdot
.28805 .82038 Mdot
.11925 .80893 Mdot
.29153 .82193 Mdot
.17663 .6684 Mdot
.2306 .73544 Mdot
.39695 .23796 Mdot
.22236 .71985 Mdot
.41515 .7207 Mdot
.24463 .83589 Mdot
.78973 .30989 Mdot
.37698 .08151 Mdot
.92607 .25304 Mdot
.42766 .85371 Mdot
.26153 .8414 Mdot
.29476 .54847 Mdot
.4761 .73596 Mdot
.1153 .52691 Mdot
.26536 .6799 Mdot
.29474 .69434 Mdot
.31151 .04448 Mdot
.25592 .53705 Mdot
.23411 .76102 Mdot
.37238 .00358 Mdot
.14073 .8825 Mdot
.40161 .30727 Mdot
.2226 .74493 Mdot
.31118 .81647 Mdot
.32221 .83206 Mdot
.49312 .32459 Mdot
.30243 .73323 Mdot
.28263 .69225 Mdot
.47217 .85041 Mdot
.22337 .81806 Mdot
.12945 .61363 Mdot
.1698 .01899 Mdot
.3558 .83866 Mdot
.16284 .86771 Mdot
.76446 .21593 Mdot
.23051 .74174 Mdot
.1796 .7334 Mdot
.0173 .68056 Mdot
.26127 .827 Mdot
.31603 .83279 Mdot
.21481 .7257 Mdot
.35707 .62849 Mdot
.4254 .81372 Mdot
.23487 .83139 Mdot
.42569 .83563 Mdot
.87597 .23388 Mdot
.22626 .6914 Mdot
.14505 .85365 Mdot
.28131 .08132 Mdot
.37306 .64328 Mdot
.30027 .73044 Mdot
.09008 .63772 Mdot
.76047 .24353 Mdot
.42967 .19369 Mdot
.35058 .62136 Mdot
.31528 .84553 Mdot
.43478 .66411 Mdot
.16732 .66986 Mdot
.566 .28357 Mdot
.40093 .76022 Mdot
.30556 .81068 Mdot
.30878 .78841 Mdot
.00072 .26488 Mdot
.10479 .46145 Mdot
.32087 .81672 Mdot
.75543 .25578 Mdot
.24333 .84012 Mdot
.14213 .74686 Mdot
.31826 .80811 Mdot
.39012 .83661 Mdot
.12535 .68082 Mdot
.40411 .26877 Mdot
.27645 .82879 Mdot
.15133 .39834 Mdot
.12562 .82873 Mdot
.25241 .80132 Mdot
.17981 .85844 Mdot
.07071 .75151 Mdot
.24301 .70008 Mdot
.22229 .79949 Mdot
.35384 .83866 Mdot
.27087 .67638 Mdot
.19609 .80894 Mdot
.22698 .81111 Mdot
.37134 .75795 Mdot
.25349 .75759 Mdot
.16769 .09727 Mdot
.06556 .23563 Mdot
.40252 .44477 Mdot
.25713 .5736 Mdot
.68267 .62562 Mdot
.30964 .82317 Mdot
.74152 .99093 Mdot
.38186 .00107 Mdot
.32126 .82988 Mdot
.71592 .59453 Mdot
.26296 .67266 Mdot
.16232 .66433 Mdot
.73698 .1464 Mdot
.00451 .69119 Mdot
.28772 .12841 Mdot
.19999 .19598 Mdot
.27313 .59212 Mdot
.2594 .79432 Mdot
.21791 .75636 Mdot
.25539 .84101 Mdot
.47223 .65046 Mdot
.03535 .64532 Mdot
.22254 .11622 Mdot
.31373 .73771 Mdot
.43423 .67616 Mdot
.1884 .70055 Mdot
.25141 .75143 Mdot
.37222 .40067 Mdot
.23053 .74022 Mdot
.42042 .79239 Mdot
.23269 .70497 Mdot
.21001 .77518 Mdot
.31666 .83554 Mdot
.46066 .69182 Mdot
.11101 .92107 Mdot
.55884 .61825 Mdot
.69235 .21749 Mdot
.24609 .72964 Mdot
.15686 .61614 Mdot
.30343 .80666 Mdot
.21838 .75034 Mdot
.24961 .78025 Mdot
.48667 .84522 Mdot
.41166 .62466 Mdot
.11 .9548 Mdot
.34101 .83155 Mdot
.05247 .21863 Mdot
.24273 .72748 Mdot
.28947 .78755 Mdot
.37221 .76173 Mdot
.67972 .16542 Mdot
.92175 .25616 Mdot
.05979 .64213 Mdot
.14115 .88221 Mdot
.12999 .88641 Mdot
.23935 .52216 Mdot
.30891 .81953 Mdot
.03721 .67769 Mdot
.24385 .67507 Mdot
.25906 .74859 Mdot
.29456 .75711 Mdot
.271 .78331 Mdot
.26673 .79459 Mdot
.15707 .19459 Mdot
.05924 .57076 Mdot
.26779 .10995 Mdot
.30998 .81302 Mdot
.23974 .69607 Mdot
.43293 .78689 Mdot
.06579 .95225 Mdot
.78696 .16811 Mdot
.24264 .80756 Mdot
.09473 .70097 Mdot
.49733 .85419 Mdot
.25547 .84254 Mdot
.19032 .63296 Mdot
.14378 .69078 Mdot
.19359 .71518 Mdot
.16495 .61372 Mdot
.30375 .8175 Mdot
.14838 .62776 Mdot
.1563 .10382 Mdot
.71197 .18703 Mdot
.21708 .71414 Mdot
.28565 .69649 Mdot
.13658 .65151 Mdot
.76512 .15794 Mdot
.29885 .79072 Mdot
.30956 .80955 Mdot
.25246 .30885 Mdot
.61074 .23538 Mdot
.24575 .73654 Mdot
.25092 .77737 Mdot
.99497 .39816 Mdot
.16886 .91033 Mdot
.26239 .79456 Mdot
.15518 .64936 Mdot
.9213 .21957 Mdot
.71816 .21284 Mdot
.36646 .36778 Mdot
.06098 .6988 Mdot
.3751 .7562 Mdot
.7815 .24046 Mdot
.02576 .68143 Mdot
.09285 .61962 Mdot
.48623 .83962 Mdot
.31809 .74816 Mdot
.08791 .93897 Mdot
.11991 .89105 Mdot
.23877 .47 Mdot
.25179 .54052 Mdot
.31581 .74175 Mdot
.29561 .33385 Mdot
.32259 .76995 Mdot
.25547 .8113 Mdot
.24086 .77304 Mdot
.84943 .2501 Mdot
.15233 .749 Mdot
.39126 .62588 Mdot
.41565 .74443 Mdot
.31998 .82882 Mdot
.29017 .79475 Mdot
.16393 .81661 Mdot
.3172 .81469 Mdot
.30277 .82 Mdot
.36025 .83423 Mdot
.50424 .86752 Mdot
.06404 .64664 Mdot
.33407 .76896 Mdot
.33579 .79897 Mdot
.28344 .78522 Mdot
.23419 .81094 Mdot
.12131 .19373 Mdot
.41788 .69136 Mdot
.25915 .8096 Mdot
.42801 .60126 Mdot
.30373 .74203 Mdot
.49974 .80758 Mdot
.24383 .72842 Mdot
.26333 .82618 Mdot
.2491 .79891 Mdot
.24733 .79803 Mdot
.25464 .79281 Mdot
.28323 .76882 Mdot
.25595 .87163 Mdot
.24413 .78456 Mdot
.76072 .1762 Mdot
.28941 .85244 Mdot
.44795 .07628 Mdot
.11808 .87935 Mdot
.23136 .75017 Mdot
.2486 .67142 Mdot
.25559 .68425 Mdot
.39702 .98334 Mdot
.39895 .98499 Mdot
.85308 .26543 Mdot
.48535 .85253 Mdot
.04237 .64505 Mdot
.21855 .7384 Mdot
.30186 .81132 Mdot
.15602 .15341 Mdot
.10485 .90251 Mdot
.34004 .77524 Mdot
.21456 .74732 Mdot
.35747 .77534 Mdot
.25053 .81457 Mdot
.23305 .21493 Mdot
.09571 .71304 Mdot
.31536 .81603 Mdot
.44939 .84001 Mdot
.482 .85162 Mdot
.65483 .22353 Mdot
.23091 .71979 Mdot
.35866 .71117 Mdot
.25642 .82548 Mdot
.27861 .06509 Mdot
.30444 .82083 Mdot
.27273 .72927 Mdot
.24905 .67419 Mdot
.45849 .13882 Mdot
.28208 .12775 Mdot
.6921 .15647 Mdot
.26642 .81257 Mdot
.43264 .87587 Mdot
.3848 .83993 Mdot
.47347 .81224 Mdot
.74933 .21799 Mdot
.24367 .68845 Mdot
.19089 .69312 Mdot
.24661 .79889 Mdot
.29232 .79014 Mdot
.22698 .77081 Mdot
.47329 .6439 Mdot
.43303 .83576 Mdot
.15953 .13725 Mdot
.9676 .58755 Mdot
.08958 .76773 Mdot
.50302 .86663 Mdot
.31648 .01405 Mdot
.28946 .09531 Mdot
.26316 .82103 Mdot
.14771 .84763 Mdot
.24127 .79481 Mdot
.29152 .77323 Mdot
.29908 .74456 Mdot
.28933 .82404 Mdot
.22176 .47976 Mdot
.26061 .98734 Mdot
.25649 .77973 Mdot
.72026 .17056 Mdot
.20417 .79043 Mdot
.2919 .77273 Mdot
.27799 .71057 Mdot
.25016 .04423 Mdot
.84627 .25289 Mdot
.11587 .78243 Mdot
.18375 .74351 Mdot
.22187 .79666 Mdot
.23402 .16258 Mdot
.20132 .9448 Mdot
.27394 .81699 Mdot
.46429 .89309 Mdot
.45382 .84666 Mdot
.27599 .19419 Mdot
.84455 .27241 Mdot
.30895 .8256 Mdot
.37686 .80319 Mdot
.08309 .56091 Mdot
.19301 .73518 Mdot
.26478 .83388 Mdot
.23297 .47983 Mdot
.45 .63391 Mdot
.21842 .72223 Mdot
.33928 .84938 Mdot
.13188 .62565 Mdot
.31864 .83166 Mdot
.40348 .28563 Mdot
.27001 .75245 Mdot
.29794 .42496 Mdot
.02486 .65644 Mdot
.27842 .76586 Mdot
.27888 .67234 Mdot
.25996 .74549 Mdot
.26054 .7966 Mdot
.47956 .84051 Mdot
.23803 .76391 Mdot
.24096 .83843 Mdot
.32276 .80178 Mdot
.40054 .17777 Mdot
.85021 .22142 Mdot
.26715 .82826 Mdot
.24198 .67784 Mdot
.2096 .53895 Mdot
.35018 .81032 Mdot
.11861 .89107 Mdot
.13307 .07081 Mdot
.0567 .91612 Mdot
.27426 .65639 Mdot
.24553 .78101 Mdot
.25281 .86017 Mdot
.15648 .66988 Mdot
.24518 .80388 Mdot
.19818 .76765 Mdot
.23902 .83281 Mdot
.09127 .63229 Mdot
.22267 .797 Mdot
.35186 .82069 Mdot
.17624 .69424 Mdot
.25373 .79159 Mdot
.30398 .80609 Mdot
.21627 .75089 Mdot
.42482 .68913 Mdot
.08726 .00444 Mdot
.18881 .71181 Mdot
.31087 .80665 Mdot
.23141 .73652 Mdot
.14453 .00905 Mdot
.25779 .68286 Mdot
.18045 .96975 Mdot
.28391 .07574 Mdot
.26268 .73125 Mdot
.1643 .17914 Mdot
.2341 .70243 Mdot
.10803 .60845 Mdot
.15648 .64532 Mdot
.39779 .05565 Mdot
.32144 .8391 Mdot
.42254 .22324 Mdot
.38549 .85529 Mdot
.13245 .42148 Mdot
.24905 .68212 Mdot
.30797 .15978 Mdot
.43229 .70158 Mdot
.14619 .87226 Mdot
.39291 .96404 Mdot
.35293 .08032 Mdot
.23584 .84637 Mdot
.45846 .80362 Mdot
.25867 .76237 Mdot
.29458 .80764 Mdot
.2744 .65249 Mdot
.01458 .70522 Mdot
.27643 .76525 Mdot
.52962 .11107 Mdot
.24646 .79527 Mdot
.30176 .75521 Mdot
.26153 .76831 Mdot
.2809 .74605 Mdot
.41709 .7996 Mdot
.26701 .75962 Mdot
.42778 .68479 Mdot
.41969 .81566 Mdot
.06762 .99121 Mdot
.20302 .67915 Mdot
.2401 .86832 Mdot
.7517 .16182 Mdot
.2334 .79911 Mdot
.16068 .00853 Mdot
.09493 .14177 Mdot
.23975 .8165 Mdot
.36237 .8509 Mdot
.28898 .8002 Mdot
.84842 .25252 Mdot
.31619 .81464 Mdot
.25431 .86641 Mdot
.76868 .26973 Mdot
.90784 .20884 Mdot
.3131 .81388 Mdot
.09487 .95366 Mdot
.17403 .75594 Mdot
.52992 .28966 Mdot
.31979 .83574 Mdot
.348 .03301 Mdot
.49123 .85352 Mdot
.30362 .7899 Mdot
.21451 .10237 Mdot
.42589 .62928 Mdot
.45981 .83673 Mdot
.38829 .9434 Mdot
.4904 .27739 Mdot
.16183 .87488 Mdot
.25154 .7332 Mdot
.70717 .24316 Mdot
.24533 .82846 Mdot
.76942 .31234 Mdot
.25364 .74127 Mdot
.33496 .17256 Mdot
.89331 .24118 Mdot
.17005 .43032 Mdot
.45676 .65643 Mdot
.70382 .18425 Mdot
.23502 .68174 Mdot
.2704 .75373 Mdot
.37127 .65932 Mdot
.24316 .87968 Mdot
.3052 .13698 Mdot
.05961 .87742 Mdot
.25036 .72576 Mdot
.44372 .81798 Mdot
.13249 .91263 Mdot
.34504 .59854 Mdot
.22921 .41004 Mdot
.25368 .79723 Mdot
.17241 .74804 Mdot
.28545 .79055 Mdot
.28039 .11663 Mdot
.5199 .25164 Mdot
.0536 .21493 Mdot
.36346 .38752 Mdot
.02724 .65401 Mdot
.21945 .7739 Mdot
.253 .72708 Mdot
.39497 .05128 Mdot
.23201 .77239 Mdot
.55389 .15983 Mdot
.18396 .24451 Mdot
.17359 .9231 Mdot
.27847 .8106 Mdot
.58492 .23416 Mdot
.20943 .60756 Mdot
.04604 .92667 Mdot
.71144 .31134 Mdot
.20271 .82682 Mdot
.99868 .3782 Mdot
.23028 .73971 Mdot
.2713 .79412 Mdot
.21895 .17158 Mdot
.22907 .74141 Mdot
.26957 .67547 Mdot
.40713 .92288 Mdot
.19339 .69577 Mdot
.12049 .51074 Mdot
.4056 .59646 Mdot
.83157 .2017 Mdot
.16754 .60248 Mdot
.31453 .83327 Mdot
.41373 .826 Mdot
.75195 .16162 Mdot
.23531 .73769 Mdot
.23304 .73173 Mdot
.21661 .78011 Mdot
.27347 .7976 Mdot
.20555 .15017 Mdot
.12347 .62254 Mdot
.85827 .24578 Mdot
.85402 .26413 Mdot
.21026 .8544 Mdot
.88742 .20268 Mdot
.22734 .7672 Mdot
.35776 .75301 Mdot
.22732 .69311 Mdot
.27077 .04452 Mdot
.43399 .8712 Mdot
.26329 .86785 Mdot
.24793 .72712 Mdot
.75388 .17506 Mdot
.27131 .83831 Mdot
.2346 .14423 Mdot
.44301 .80812 Mdot
.27438 .71632 Mdot
.15819 .84409 Mdot
.28385 .70044 Mdot
.19832 .68927 Mdot
.30985 .81956 Mdot
.22503 .74303 Mdot
.46241 .84326 Mdot
.2572 .87264 Mdot
.22165 .73016 Mdot
.81578 .17841 Mdot
.25479 .79772 Mdot
.94577 .25459 Mdot
.28021 .71376 Mdot
.25599 .80412 Mdot
.33158 .74198 Mdot
.44662 .64286 Mdot
.7315 .18233 Mdot
.20868 .7603 Mdot
.94949 .26703 Mdot
.3156 .82246 Mdot
.07573 .84839 Mdot
.17962 .76549 Mdot
.24456 .83565 Mdot
.28036 .16911 Mdot
.24211 .6813 Mdot
.2952 .84198 Mdot
.21905 .73861 Mdot
.16989 .80962 Mdot
.21259 .94629 Mdot
.35421 .75953 Mdot
.08857 .89113 Mdot
.73586 .25461 Mdot
.46484 .85128 Mdot
.30732 .75533 Mdot
.11542 .61606 Mdot
.04349 .63797 Mdot
.26038 .78351 Mdot
.30082 .81101 Mdot
.21898 .78966 Mdot
.36707 .68673 Mdot
.69362 .21658 Mdot
.071 .69861 Mdot
.24137 .8568 Mdot
.34973 .64817 Mdot
.2541 .864 Mdot
.03814 .64531 Mdot
.31584 .6544 Mdot
.37097 .7818 Mdot
.18017 .65754 Mdot
.67968 .29494 Mdot
.23683 .73016 Mdot
.2631 .83378 Mdot
.10094 .88901 Mdot
.24898 .62491 Mdot
.22351 .70679 Mdot
.15702 .14451 Mdot
.34798 .36688 Mdot
.40875 .6415 Mdot
.1889 .68405 Mdot
.40192 .6307 Mdot
.36913 .79937 Mdot
.24257 .79887 Mdot
.28977 .83767 Mdot
.4025 .77043 Mdot
.29974 .80297 Mdot
.38498 .09106 Mdot
.75063 .19487 Mdot
.29961 .75445 Mdot
.21879 .09584 Mdot
.24549 .79493 Mdot
.2306 .79063 Mdot
.30503 .8491 Mdot
.22439 .77675 Mdot
.26678 .81368 Mdot
.14425 .60435 Mdot
.26036 .84864 Mdot
.3219 .83353 Mdot
.26986 .16265 Mdot
.16722 .7082 Mdot
.10212 .9188 Mdot
.3306 .62654 Mdot
.25841 .73989 Mdot
.25173 .18182 Mdot
.42336 .68961 Mdot
.19798 .72839 Mdot
.49848 .10054 Mdot
.33582 .84574 Mdot
.30706 .83523 Mdot
.29017 .21901 Mdot
.10278 .94072 Mdot
.22518 .79195 Mdot
.30592 .81024 Mdot
.26935 .79753 Mdot
.75786 .2016 Mdot
.16358 .0674 Mdot
.41657 .60411 Mdot
.2149 .76493 Mdot
.24175 .83115 Mdot
.27373 .714 Mdot
.26549 .53134 Mdot
.23275 .61586 Mdot
.22626 .70417 Mdot
.26391 .7635 Mdot
.31593 .82614 Mdot
.05588 .23421 Mdot
.25074 .79607 Mdot
.24454 .31242 Mdot
.27991 .84387 Mdot
.28895 .72564 Mdot
.23146 .7957 Mdot
.34152 .75845 Mdot
.27376 .80897 Mdot
.56229 .11662 Mdot
.2402 .84357 Mdot
.22802 .80767 Mdot
.22669 .69121 Mdot
.11963 .6097 Mdot
.98108 .25059 Mdot
.23643 .78092 Mdot
.11596 .60421 Mdot
.31412 .81318 Mdot
.31226 .82586 Mdot
.3529 .79676 Mdot
.46652 .84343 Mdot
.27012 .81369 Mdot
.90301 .35031 Mdot
.13969 .48184 Mdot
.06484 .96429 Mdot
.21785 .67392 Mdot
.40305 .7786 Mdot
.30204 .73048 Mdot
.25206 .80001 Mdot
.24605 .84937 Mdot
.39218 .71601 Mdot
.25754 .68711 Mdot
.28176 .69951 Mdot
.7364 .2101 Mdot
.23007 .74564 Mdot
.50513 .85807 Mdot
.65154 .21173 Mdot
.16804 .03775 Mdot
.38064 .77696 Mdot
.23062 .74325 Mdot
.39725 .25812 Mdot
.30283 .74289 Mdot
.82564 .17902 Mdot
.29113 .73834 Mdot
.12306 .76145 Mdot
.29581 .83568 Mdot
.22449 .67215 Mdot
.15691 .87897 Mdot
.28839 .30568 Mdot
.34809 .71813 Mdot
.20738 .12869 Mdot
.0764 .64467 Mdot
.46704 .85426 Mdot
.26045 .68243 Mdot
.22709 .6921 Mdot
.26718 .66992 Mdot
.20336 .8851 Mdot
.5111 .8617 Mdot
.37884 .23705 Mdot
.28342 .81842 Mdot
.19805 .80601 Mdot
.19081 .5669 Mdot
.41555 .78957 Mdot
.18823 .78641 Mdot
.47684 .83802 Mdot
.26813 .7979 Mdot
.62006 .2363 Mdot
.37317 .60179 Mdot
.24033 .75711 Mdot
.23357 .79954 Mdot
.28033 .75125 Mdot
.29742 .55743 Mdot
.63657 .17588 Mdot
.17194 .80787 Mdot
.18939 .50147 Mdot
.90998 .20987 Mdot
.40119 .69773 Mdot
.20038 .79339 Mdot
.23773 .78399 Mdot
.23468 .76281 Mdot
.28127 .0995 Mdot
.24365 .67786 Mdot
.71257 .27827 Mdot
.23146 .73302 Mdot
.30524 .79231 Mdot
.43877 .91665 Mdot
.23583 .77397 Mdot
.22993 .71867 Mdot
.31085 .82034 Mdot
.25952 .05308 Mdot
.34462 .78871 Mdot
.27005 .7684 Mdot
.39659 .88121 Mdot
.36774 .73977 Mdot
.26261 .78494 Mdot
.47971 .14542 Mdot
.27274 .73416 Mdot
.76438 .27139 Mdot
.42215 .69955 Mdot
.50632 .58889 Mdot
.1594 .74357 Mdot
.21724 .77402 Mdot
.6393 .12736 Mdot
.32281 .61677 Mdot
.227 .00523 Mdot
.96737 .27713 Mdot
.23027 .73962 Mdot
.29311 .80116 Mdot
.29678 .75162 Mdot
.25403 .63085 Mdot
.2233 .80002 Mdot
.24999 .1119 Mdot
.16563 .596 Mdot
.12983 .6599 Mdot
.85152 .19149 Mdot
.3164 .12489 Mdot
.33389 .16173 Mdot
.80564 .30331 Mdot
.15921 .20048 Mdot
.24781 .07223 Mdot
.46553 .26536 Mdot
.25381 .81713 Mdot
.08737 .64132 Mdot
.33244 .10421 Mdot
.30387 .80457 Mdot
.31019 .80843 Mdot
.27121 .77791 Mdot
.20124 .66389 Mdot
.33878 .50676 Mdot
.07951 .64209 Mdot
.25238 .72906 Mdot
.41617 .74267 Mdot
.15117 .82736 Mdot
.35392 .17179 Mdot
.42807 .71643 Mdot
.30453 .80949 Mdot
.36383 .56918 Mdot
.35678 .76441 Mdot
.17292 .79736 Mdot
.39808 .19307 Mdot
.31288 .8383 Mdot
.31533 .83528 Mdot
.28465 .74671 Mdot
.34389 .63506 Mdot
.10171 .64057 Mdot
.22509 .73497 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool02?ooool2o`0000?ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo0_l000000ooooooo0000o`000005ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00;ooooo000Nooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
2?ooool2o`0000?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`04ooooo`;o00002?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_oo
ool00ol0003oooooooooo`0[ooooo`;o00000oooool2o`0001Cooooo0_l0003oooooo`007_ooool0
0ol0003oooooooooo`0[ooooo`;o00000oooool2o`000?oooooo5_ooool001kooooo00?o0000oooo
ooooool0Hoooool2o`000>;ooooo000Nooooo`03o`000?oooooooooo03?ooooo0_l0000^ooooo`;o
0000h_ooool001kooooo00?o0000ooooooooool0<oooool2o`000?oooooo4oooool001kooooo00?o
0000ooooooooool0Eoooool2o`000>kooooo000Nooooo`03o`000?oooooooooo05Oooooo0_l0000I
ooooo`;o0000doooool001kooooo00?o0000ooooooooool0L_ooool2o`000=?ooooo000Nooooo`03
o`000?oooooooooo06gooooo0_l0000:ooooo`;o0000c?ooool001kooooo00?o0000ooooooooool0
<oooool2o`0003Sooooo0_l0000:ooooo`;o0000c?ooool001kooooo00?o0000ooooooooool0<ooo
ool2o`000?oooooo4oooool001kooooo00?o0000ooooooooool0@?ooool2o`0000_ooooo0_l0000B
ooooo`;o00003oooool2o`000=?ooooo000Nooooo`03o`000?oooooooooo043ooooo0_l0000;oooo
o`;o00001Oooool2o`0000_ooooo0_l0000?ooooo`;o0000doooool001kooooo00?o0000oooooooo
ool0E?ooool2o`0002;ooooo0_l0003=ooooo`007_ooool2o`00057ooooo0_l0000Vooooo`;o0000
0_ooool2o`000<Wooooo000Nooooo`03o`000?oooooooooo053ooooo0_l0000Zooooo`?o0000b?oo
ool001kooooo00?o0000ooooooooool0OOooool2o`000<Sooooo000Nooooo`03o`000?oooooooooo
07Cooooo0_l0003Aooooo`007_ooool00ol0003oooooooooo`1Fooooo`;o00007?ooool2o`000=7o
oooo000Nooooo`03o`000?oooooooooo037ooooo0_l0000Sooooo`;o0000koooool001kooooo00?o
0000ooooooooool09oooool2o`0000Sooooo0_l0000dooooo`;o0000g_ooool001kooooo00?o0000
ooooooooool09oooool2o`0002?ooooo0_l0000Iooooo`;o0000g_ooool001kooooo00?o0000oooo
ooooool0C?ooool2o`0000[ooooo0_l0000dooooo`;o0000]oooool001kooooo00?o0000oooooooo
ool0Eoooool3o`0001Gooooo0_l0000Mooooo`;o0000]oooool001kooooo00?o0000ooooooooool0
Eoooool2o`0001Kooooo0_l00005ooooo`;o00005Oooool2o`000;Sooooo000Nooooo`03o`000?oo
oooooooo04[ooooo0_l0000Zooooo`;o00005Oooool2o`000;Sooooo000Nooooo`03o`000?oooooo
oooo04[ooooo0_l0003kooooo`007_ooool00ol0003oooooooooo`0gooooo`;o0000@?ooool2o`00
0<cooooo000Nooooo`03o`000?oooooooooo03Oooooo0_l0000:ooooo`;o00005Oooool2o`0001go
oooo0_l0003<ooooo`007_ooool00ol0003oooooooooo`0booooo`;o00003oooool2o`0001;ooooo
0_l000000ooooooo0000o`00003[ooooo`007_ooool2o`0003?ooooo0_l0000>ooooo`;o00004ooo
ool2o`0004Gooooo0_l0002Wooooo`007_ooool00ol0003oooooooooo`0_ooooo`;o00004Oooool2
o`0002Cooooo0_l0000dooooo`;o0000Yoooool001kooooo00?o0000ooooooooool0;oooool2o`00
03Oooooo0_l0003Mooooo`007_ooool00ol0003oooooooooo`1=ooooo`;o00001?ooool2o`0005?o
oooo0_l0002Mooooo`007_ooool00ol0003oooooooooo`1=ooooo`;o00001?ooool2o`0005?ooooo
0_l0002Mooooo`007_ooool00ol0003oooooooooo`14ooooo`;o00004Oooool2o`0001gooooo0_l0
000kooooo`;o0000T_ooool001kooooo00?o0000ooooooooool0A?ooool2o`00017ooooo0_l0000M
ooooo`;o0000>oooool2o`0009;ooooo000Nooooo`03o`000?oooooooooo063ooooo0_l0003Uoooo
o`007_ooool00ol0003oooooooooo`1Pooooo`;o000000?oooooo`000?l00000E_ooool2o`0000oo
oooo0_l0001iooooo`007_ooool00ol0003oooooooooo`0oooooo`;o00005oooool3o`0000Sooooo
0_l00007ooooo`;o0000COooool2o`0000oooooo0_l0001iooooo`007_ooool00ol0003ooooooooo
o`0oooooo`;o00005oooool3o`00017ooooo0_l0003Iooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo033ooooo0_l0000]ooooo`;o0000<?ooool2o`00
0;Cooooo000Nooooo`03o`000?oooooooooo01_ooooo0_l0000Cooooo`;o0000:Oooool2o`0000;o
oooo0_l0000`ooooo`;o0000]?ooool001kooooo00?o0000ooooooooool06oooool2o`0001;ooooo
0_l0000Gooooo`;o00004Oooool2o`0000Sooooo0_l0000aooooo`;o0000[Oooool001kooooo00?o
0000ooooooooool0;oooool2o`0000gooooo0_l00008ooooo`;o00006oooool2o`00037ooooo0_l0
001Aooooo`;o0000F_ooool001kooooo0_l0000oooooo`?o0000S_ooool2o`0001[ooooo0_l0001J
ooooo`007_ooool00ol0003oooooooooo`0_ooooo`;o00002_ooool2o`0000;ooooo0_l0002>oooo
o`;o0000M_ooool001kooooo00?o0000ooooooooool0;oooool2o`0000[ooooo0_l0002Pooooo`;o
00005_ooool2o`00053ooooo000Nooooo`03o`000?oooooooooo063ooooo0_l0001>ooooo`;o0000
:oooool2o`0001Kooooo0_l0001@ooooo`007_ooool00ol0003oooooooooo`0^ooooo`;o00006?oo
ool2o`0000[ooooo0_l00009ooooo`?o00001_ooool2o`0004Kooooo0_l0000nooooo`;o00001_oo
ool2o`0004gooooo000Nooooo`03o`000?oooooooooo02kooooo0_l0000Hooooo`;o00002_ooool2
o`0000Wooooo0_l00007ooooo`;o0000Koooool2o`0001Gooooo0_l00006ooooo`;o0000COooool0
01kooooo00?o0000ooooooooool0Coooool2o`0000Kooooo0_l00020ooooo`;o00002oooool2o`00
01Cooooo0_l00019ooooo`007_ooool00ol0003oooooooooo`13ooooo`;o00002_ooool2o`0000Ko
oooo0_l0000@ooooo`;o00001?ooool2o`0007Gooooo0_l0000<ooooo`;o00001_ooool2o`0004Wo
oooo000Nooooo`03o`000?oooooooooo04?ooooo0_l0000Tooooo`;o00001?ooool2o`0005[ooooo
0_l0000Tooooo`Go0000DOooool001kooooo00?o0000ooooooooool0<Oooool2o`0004_ooooo0_l0
001;ooooo`;o00008oooool5o`00013ooooo0_l000000ooooooo0000o`00000mooooo`007_ooool0
0ol0003oooooooooo`0aooooo`;o00006oooool2o`0002kooooo0_l00012ooooo`;o00009_ooool2
o`0000Cooooo0_l0000Cooooo`;o000000?oooooo`000?l00000?Oooool001kooooo00?o0000oooo
ooooool0C_ooool2o`0007;ooooo0_l0000Mooooo`;o00001oooool2o`0005_ooooo000Nooooo`03
o`000?oooooooooo0>7ooooo1?l0001Rooooo`007_ooool00ol0003oooooooooo`3Sooooo`;o0000
2_ooool2o`00023ooooo0_l0000dooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`0Sooooo`;o00002_ooool2o`0002Gooooo
0_l0000Uooooo`;o00002Oooool2o`0006Gooooo0ol0000Oooooo`;o0000=?ooool000?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Ko
oooo00?o0000ooooooooool08oooool2o`0000[ooooo0_l0000<ooooo`;o00005oooool2o`0001So
oooo0_l0000;ooooo`;o00002Oooool2o`0006Kooooo0_l0001Eooooo`000oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool3o`00033ooooo0_l0000;ooooo`;o
0000<Oooool2o`000=Gooooo0003ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So
8B4Qonk^kP06ooooo`03o`000?oooooooooo033ooooo0_l00030ooooo`;o00005_ooool2o`00013o
oooo0_l0000Yooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_oo
ool01Oooool00ol0003oooooooooo`3booooo`;o00005_ooool2o`00013ooooo0_l0000Yooooo`00
0oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3[ooooo`;o00006_ooool2o`0001[ooooo0ol0000Qooooo`000oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo
0=3ooooo0_l0000Cooooo`;o00001?ooool2o`0001[ooooo0_l0000Jooooo`Co00008?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`0=ooooo`;o0000>Oooool2o`0008Kooooo0_l0000;ooooo`;o00001_ooool2
o`0000gooooo0_l0000_ooooo`;o00008?ooool001kooooo00?o0000ooooooooool03Oooool2o`00
03Wooooo0_l0000@ooooo`;o0000POooool2o`00017ooooo0_l00002ooooo`;o00009Oooool2o`00
00[ooooo0_l0000Nooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o0000Boooool2o`00087o
oooo0_l0000Aooooo`;o00007_ooool2o`0000Wooooo0_l0000:ooooo`;o00007_ooool001kooooo
00?o0000ooooooooool0QOooool2o`0004[ooooo0_l0000mooooo`;o0000=Oooool001kooooo00?o
0000ooooooooool0QOooool2o`0004[ooooo0_l0001dooooo`007_ooool00ol0003oooooooooo`3o
oooooaCooooo0_l0000Vooooo`;o00002_ooool001kooooo00?o0000ooooooooool03_ooool2o`00
0:[ooooo0_l0001Gooooo`;o00001?ooool2o`00023ooooo0_l0000:ooooo`007_ooool00ol0003o
ooooooooo`0>ooooo`;o000000?oooooo`000?l00000I?ooool2o`0000Cooooo0_l0000kooooo`;o
00001_ooool2o`000004ooooool0003o0000ooooo`;o00007?ooool2o`00037ooooo0_l0000/oooo
o`007_ooool00ol0003oooooooooo`0Aooooo`;o0000I?ooool2o`0000Cooooo0_l00013ooooo`;o
000000Coooooo`000?l0003ooooo0_l0000Looooo`;o00004_ooool2o`0002;ooooo0_l0000Woooo
o`007_ooool00ol0003oooooooooo`3Rooooo`;o00003oooool2o`0000Gooooo0_l0000Rooooo`;o
00009oooool001kooooo00?o0000ooooooooool0>?ooool2o`000:Sooooo0_l0000?ooooo`;o0000
7_ooool2o`0003;ooooo000Nooooo`03o`000?oooooooooo03Sooooo0_l0003Fooooo`;o000000?o
ooooo`000?l000005Oooool2o`0001_ooooo000Nooooo`;o0000Y_ooool2o`0006Sooooo0ol0000G
ooooo`?o00003oooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo0:Gooooo0_l00014oooo
o`;o00001?ooool2o`0001cooooo0ol0000Fooooo`?o00001?ooool2o`0000[ooooo0_l0000:oooo
o`007_ooool00ol0003oooooooooo`1mooooo`;o0000K?ooool2o`0000Cooooo0_l0000eooooo`;o
00001Oooool2o`0001Kooooo000Nooooo`03o`000?oooooooooo07gooooo0_l00038ooooo`007Ooo
ool2o`0005_ooooo0_l0000hooooo`;o0000O?ooool3o`0003?ooooo000Mooooo`;o0000Foooool2
o`0002Cooooo0_l0000Booooo`;o0000O?ooool3o`0001gooooo0_l0000Dooooo`007_ooool00ol0
003oooooooooo`1oooooo`;o0000Loooool4o`0003Wooooo0_l0000Dooooo`007_ooool00ol0003o
ooooooooo`3dooooo`Co00005_ooool2o`0003Oooooo000Nooooo`03o`000?oooooooooo07oooooo
0_l0000Jooooo`;o0000LOooool2o`0002Kooooo0_l0000?ooooo`007_ooool00ol0003ooooooooo
o`1oooooo`;o00006_ooool2o`0004Oooooo0_l0001@ooooo`;o00003oooool001kooooo00?o0000
ooooooooool0]?ooool2o`0002kooooo0_l0001Qooooo`007_ooool00ol0003oooooooooo`1ooooo
o`;o0000<oooool2o`00097ooooo000Nooooo`03o`000?oooooooooo07oooooo0_l0000Wooooo`;o
0000WOooool001kooooo00?o0000ooooooooool0Z?ooool2o`0009gooooo000Nooooo`03o`000?oo
oooooooo0<?ooooo0_l0000Dooooo`;o0000K?ooool001kooooo00?o0000ooooooooool0`oooool2
o`0001Cooooo0_l0001/ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000oooooooo
ool0F_ooool2o`000:Kooooo0_l00013ooooo`007_ooool00ol0003oooooooooo`1>ooooo`;o0000
2_ooool2o`0002;ooooo0_l00022ooooo`;o0000@oooool001kooooo00?o0000ooooooooool0C_oo
ool2o`0002kooooo0_l0001Sooooo`;o00006?ooool2o`0004Sooooo000Nooooo`03o`000?oooooo
oooo04_ooooo0_l0002Fooooo`;o00004Oooool2o`0000Gooooo0_l00018ooooo`007_ooool00ol0
003oooooooooo`1;ooooo`;o0000ZOooool2o`0004oooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`2Looooo`;o0000ZOooool001kooooo00?o0000ooooooooool0W?ooool2o`000:Wooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool06Oooool2o`00047o
oooo0_l0003Yooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o0000@Oooool2o`000>Wooooo
000Nooooo`03o`000?oooooooooo07oooooo0_l00036ooooo`007_ooool00ol0003oooooooooo`1o
ooooo`;o0000a_ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?oo
oooo8oooool2o`0002Cooooo000Nooooo`03o`000?oooooooooo06Wooooo0_l0002fooooo`;o0000
9?ooool001kooooo00?o0000ooooooooool0JOooool2o`000=cooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool05Oooool2o`000?oooooo<Oooool001ko
oooo00?o0000ooooooooool05Oooool2o`0005Kooooo0_l0003Hooooo`007_ooool00ol0003ooooo
ooooo`1]ooooo`;o00001?ooool2o`0000Kooooo0_l0003:ooooo`007_ooool00ol0003ooooooooo
o`1cooooo`;o00001_ooool2o`000<[ooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom2ooooo`;o00001?ooool001kooooo00?o0000oooooooo
ool0oooooom2ooooo`;o00001?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`1booooo`;o0000doooool001kooooo00?o0000ooooooooool0L_ooool2
o`000=?ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l00000
0ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0?oooooo@?ooool2o`0000Kooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool5
o`0000Kooooo0ol0000]ooooo`;o0000A_ooool2o`000<Sooooo0_l00006ooooo`000oooool01Ol0
003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool00ol0003ooooooooo
o`0]ooooo`;o0000A_ooool2o`000=3ooooo0003ooooo`05o`000?ooooooooooooooool000002ooo
ool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go
410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0
A_ooool2o`000?oooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4
o`000007ooooo`03o`000?oooooooooo04Kooooo0_l0003oooooo`000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool09oooool2
o`000?oooooo7oooool001kooooo00?o0000ooooooooool09oooool2o`0003Cooooo0_l0003Xoooo
o`007_ooool00ol0003oooooooooo`1Mooooo`;o0000j?ooool001kooooo00?o0000ooooooooool0
<oooool2o`000?oooooo4oooool001kooooo00?o0000ooooooooool0<oooool2o`0008gooooo0_l0
0023ooooo`007_ooool00ol0003oooooooooo`32ooooo`;o0000Poooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo07oooooo0_l00036ooooo`007_ooool00ol0003oooooooooo`17ooooo`;o0000=_oo
ool2o`000<Kooooo000Nooooo`;o0000B?ooool2o`000?kooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`0Nooooo`;o0000oooooolXooooo`007_ooool00ol0003oooooooooo`0Nooooo`;o0000oooo
oolXooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
04[ooooo0_l0003kooooo`007_ooool00ol0003oooooooooo`1:ooooo`;o0000noooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`14ooooo`;o00000_oo
ool2o`000?gooooo000Nooooo`03o`000?oooooooooo01cooooo0_l0000;ooooo`;o00006Oooool2
o`0000;ooooo0_l0003mooooo`007_ooool00ol0003oooooooooo`0Looooo`;o00002oooool2o`00
0?oooooo7Oooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool03oooool2o`000?oooooo=oooool001kooooo0_l0000@ooooo`;o0000:?ooool2o`00
0?oooooo3Oooool001kooooo00?o0000ooooooooool0>Oooool2o`000?oooooo3Oooool001kooooo
00?o0000ooooooooool0F_ooool2o`0000kooooo0_l0003Kooooo`007_ooool00ol0003ooooooooo
o`0Sooooo`;o0000=Oooool2o`0000kooooo0_l0003Kooooo`007_ooool00ol0003oooooooooo`0S
ooooo`;o0000oooooolSooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo04[ooooo0_l0003kooooo`007_ooool00ol0003oooooooooo`1:ooooo`;o0000
noooool001kooooo00?o0000ooooooooool08Oooool2o`0002Oooooo0_l0003kooooo`007_ooool0
0ol0003oooooooooo`0Qooooo`;o0000oooooolUooooo`007_ooool00ol0003oooooooooo`1Boooo
o`;o00000_ooool2o`000>oooooo000Nooooo`03o`000?oooooooooo05;ooooo0_l00002ooooo`;o
0000koooool001kooooo00?o0000ooooooooool0@?ooool2o`0000gooooo0_l0003fooooo`007_oo
ool00ol0003oooooooooo`10ooooo`;o00003?ooool3o`0001Cooooo0_l0003Pooooo`007_ooool0
0ol0003oooooooooo`0Qooooo`;o0000:oooool2o`0001Gooooo0_l0003Pooooo`007_ooool00ol0
003oooooooooo`0Qooooo`;o0000>Oooool2o`000>Wooooo000Nooooo`;o0000GOooool2o`000>Wo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0GOoo
ool2o`000>Sooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l00014ooooo`;o0000j?ooool0
01kooooo00?o0000ooooooooool05oooool2o`000?oooooo;oooool001kooooo00?o0000oooooooo
ool0>_ooool2o`000?oooooo3?ooool001kooooo00?o0000ooooooooool0>_ooool2o`0003Kooooo
0_l0003Cooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o0000HOooool2o`000=?ooooo000N
ooooo`03o`000?oooooooooo00oooooo0_l0000nooooo`;o00009?ooool2o`000=3ooooo000Noooo
o`03o`000?oooooooooo04oooooo0_l0000Tooooo`;o0000d?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0:3ooooo0_l0002Dooooo`;o00003oooool001kooooo00?o0000ooooooooool0X?ooool2
o`0009Cooooo0_l0000?ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`1Eooooo`;o0000S_oo
ool2o`00063ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
EEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo03;ooooo0_l0000Qooooo`;o0000
:Oooool2o`0006?ooooo0_l0001Pooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo
00Go0000ooooooooooooooooo`000006ooooo`?o0000<_ooool2o`0003Sooooo0_l00007ooooo`;o
00002?ooool3o`000<Gooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003o
V9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool08_ooool2o`0000[ooooo0_l00002oooo
o`;o0000>?ooool2o`0000Oooooo0_l00008ooooo`;o00000_ooool2o`0000;ooooo0_l0002noooo
o`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c006
ooooo`03o`000?oooooooooo02;ooooo0_l00007ooooo`;o000000?oooooo`000?l000000_ooool2
o`00047ooooo0_l0000<ooooo`;o00000_ooool2o`000;kooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo01oooooo0_l00002
ooooo`;o00001_ooool2o`0001?ooooo0_l0003oooooo`Kooooo0003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo01oooooo0_l00002
ooooo`;o00006oooool2o`000?oooooo1_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool08Oooool2o`000003ooooool0
003o000000;o00001oooool2o`000003ooooool0003o000001Cooooo0_l0003mooooo`007_ooool0
0ol0003oooooooooo`0Jooooo`;o00001Oooool2o`000003ooooool0003o000000;o00000oooool2
o`0000;ooooo0_l000000ooooooo0000o`00000Dooooo`;o00006oooool2o`0004_ooooo0_l0002C
ooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o00002?ooool2o`0000Gooooo0_l0000hoooo
o`;o00001oooool2o`0004;ooooo0_l0002Cooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o
00001oooool2o`0000;ooooo0_l000000ooooooo0000o`00000Tooooo`;o00007oooool2o`0001;o
oooo0_l0001Fooooo`;o0000Joooool001kooooo00?o0000ooooooooool05oooool2o`0000Oooooo
0_l00005ooooo`;o00000oooool2o`0001Gooooo0_l00008ooooo`;o00006?ooool2o`0000Oooooo
0_l00009ooooo`;o00001Oooool2o`0005Kooooo0_l0001[ooooo`007_ooool00ol0003ooooooooo
o`0/ooooo`;o00005Oooool2o`0000Wooooo0_l0000Gooooo`;o00001oooool2o`0000Wooooo0_l0
0002ooooo`;o00000oooool4o`000;oooooo000Nooooo`03o`000?oooooooooo01[ooooo0_l00009
ooooo`;o00000oooool2o`0000kooooo0_l0000Booooo`;o0000;oooool2o`0000?ooooo1?l00006
ooooo`;o0000]oooool001kooooo00?o0000ooooooooool02_ooool2o`0000Cooooo0_l00004oooo
o`Ko00002Oooool2o`0000?ooooo0_l0000>ooooo`;o0000<?ooool2o`00023ooooo0_l0002goooo
o`007_ooool00ol0003oooooooooo`0:ooooo`;o000000Coooooo`000?l0003ooooo0_l00004oooo
o`Go00000_ooool2o`0003Gooooo0_l0000Fooooo`;o0000fOooool001kooooo00?o0000oooooooo
ool03Oooool4o`0000Gooooo1?l00003ooooo`;o00008Oooool2o`0000oooooo0_l000000ooooooo
0000o`00000Oooooo`;o00002_ooool2o`0000[ooooo0_l00007ooooo`;o0000[oooool001kooooo
00?o0000ooooooooool01oooool5o`0000;ooooo1Ol00002ooooo`Go00005Oooool2o`0000oooooo
0_l0000?ooooo`;o00008_ooool2o`0000[ooooo0_l0000:ooooo`;o00001oooool2o`000:oooooo
000Nooooo`03o`000?oooooooooo00Oooooo1Ol00002ooooo`;o000000?oooooo`000?l000000_oo
ool2o`0001Oooooo0ol0000mooooo`;o0000eoooool001kooooo0_l0000Yooooo`;o00001?ooool3
o`0001Sooooo0_l0000:ooooo`;o00005oooool2o`0002Gooooo0_l0002`ooooo`007_ooool00ol0
003oooooooooo`04ooooo`?o00008Oooool2o`0001oooooo0_l0000:ooooo`;o00003?ooool2o`00
01cooooo0_l00003ooooo`;o00002?ooool2o`000003ooooool0003o000000;o0000/?ooool001ko
oooo00?o0000ooooooooool01?ooool3o`0002oooooo0_l0000Mooooo`;o00003?ooool2o`00013o
oooo0_l0000:ooooo`;o00000oooool2o`0000Oooooo0ol000000ooooooo0000o`00002booooo`00
7_ooool00ol0003oooooooooo`02ooooo`;o00008_ooool4o`0000cooooo0_l0000mooooo`;o0000
6?ooool2o`000;Kooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0000Rooooo`Co00001ooo
ool2o`0000[ooooo0_l00011ooooo`;o00001oooool2o`000;cooooo000Nooooo`03o`000?oooooo
oooo037ooooo0_l00002ooooo`;o00001?ooool4o`0001Wooooo0_l0000Vooooo`;o00001oooool2
o`000;cooooo000Nooooo`03o`000?oooooooooo00Co0000:oooool2o`000004ooooool0003o0000
ooooo`;o00001?ooool2o`00013ooooo0_l00004ooooo`;o00000oooool2o`000>gooooo000Noooo
o`03o`000?oooooooooo00Co0000:oooool2o`000003ooooool0003o000000oooooo1?l00006oooo
o`;o00000_ooool4o`0000;ooooo0_l0000]ooooo`;o0000_oooool001kooooo1Ol00006ooooo`;o
00001?ooool2o`0003?ooooo1?l00004ooooo`Co00000_ooool2o`000004ooooool0003o0000oooo
o`;o0000;Oooool2o`000003ooooool0003o00000;cooooo000Nooooo`?o00000_ooool2o`0000Co
oooo0_l00004ooooo`;o00005Oooool2o`0001Oooooo0_l0000:ooooo`Go00000_ooool5o`0003;o
oooo0ol0002looooo`007_ooool00ol0003oooooooooo`02ooooo`Co00007oooool2o`0001;ooooo
0_l00003ooooo`;o00001Oooool2o`000003ooooool0003o000000[o0000=?ooool2o`000;gooooo
000Nooooo`03o`000?oooooooooo00Cooooo0_l0000cooooo`;o00002_ooool2o`000003ooooool0
003o000000Wo00003oooool2o`0000oooooo0_l0000Booooo`;o00000_ooool2o`0008Wooooo0_l0
000_ooooo`007_ooool00ol0003oooooooooo`0looooo`;o00003Oooool3o`0000;ooooo0ol0000?
ooooo`;o00003oooool2o`00017ooooo0ol00002ooooo`;o0000ROooool2o`0002oooooo000Noooo
o`;o0000;?ooool2o`0000gooooo1?l00007ooooo`?o00000oooool2o`0000Cooooo0_l00005oooo
o`;o0000:_ooool4o`0000[ooooo0_l0002cooooo`007_ooool2o`0002cooooo0_l00008ooooo`;o
00000oooool3o`0000Sooooo0ol00002ooooo`;o00002?ooool2o`0000;ooooo0ol000000ooooooo
0000o`00000Vooooo`Co00002_ooool2o`000;?ooooo000Nooooo`03o`000?oooooooooo013ooooo
0_l000000ooooooo0000o`00000Pooooo`;o00001?ooool2o`0000gooooo0_l00008ooooo`;o0000
00?oooooo`000?l000000_l000000ooooooo0000o`00000Pooooo`;o00001Oooool2o`000<3ooooo
000Nooooo`;o00004Oooool2o`000003ooooool0003o000000Kooooo0_l0000Looooo`;o00001?oo
ool2o`0000Oooooo0_l000000ooooooo0000o`00000:ooooo`?o00009?ooool2o`0000Gooooo0_l0
00000ooooooo0000o`00002mooooo`007_ooool01?l0003oooooooooooooool2o`0001Sooooo0_l0
000Looooo`;o00001?ooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0000_ooooo
0_l0000Zooooo`;o00000_ooool2o`000;gooooo000Nooooo`04o`000?ooooooooooooooo`;o0000
;oooool2o`00017ooooo1Ol0000Jooooo`;o00007_ooool2o`000<7ooooo000Nooooo`03o`000?oo
oooooooo03;ooooo0_l00005ooooo`?o00000oooool2o`0000Cooooo2Ol00008ooooo`;o00003?oo
ool2o`0000[ooooo0_l0003Eooooo`007_ooool00ol0003oooooooooo`0Kooooo`;o00007?ooool3
o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`Co00001oooool4o`0001Oooooo0_l0003E
ooooo`007_ooool00ol0003oooooooooo`0Kooooo`;o00007_ooool2o`0000Gooooo0_l0000Aoooo
o`Co00008_ooool2o`0000Sooooo1?l0002nooooo`007_ooool00ol0003oooooooooo`0kooooo`;o
00001oooool2o`000003ooooool0003o000000cooooo0_l0000Fooooo`;o00003?ooool2o`0000Ko
oooo1_l0002nooooo`007_ooool00ol0003oooooooooo`13ooooo`?o000000?oooooo`000?l00000
9?ooool2o`0001Cooooo0_l00032ooooo`007_ooool00ol0003oooooooooo`12ooooo`?o00001ooo
ool4o`0000[ooooo0_l0003[ooooo`007_ooool00ol0003oooooooooo`0looooo`;o00001?ooool4
o`0000?ooooo1ol00005ooooo`;o00000oooool2o`000>_ooooo000Nooooo`03o`000?oooooooooo
03Kooooo0_l00004ooooo`;o00001_ooool<o`000003ooooool0003o000000;ooooo0_l00007oooo
o`;o0000ioooool001kooooo00?o0000ooooooooool0=_ooool2o`0000?ooooo0_l00008ooooo`Go
00000_ooool4o`000003ooooool0003o000000;ooooo0_l00007ooooo`?o00005Oooool2o`0001oo
oooo0_l0002^ooooo`007_ooool00ol0003oooooooooo`0kooooo`;o00001_ooool7o`0000;ooooo
0_l00007ooooo`;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000Booooo`;o0000
3?ooool2o`00017ooooo0_l0002^ooooo`007_ooool00ol0003oooooooooo`0oooooo`;o00000_oo
ool2o`000003ooooool0003o000000;o00001?ooool4o`0000Wooooo0_l00002ooooo`;o000000Co
ooooo`000?l0003o00000oooool2o`0000Wooooo0_l0000>ooooo`?o0000`Oooool001kooooo00?o
0000ooooooooool0<?ooool2o`0000Kooooo0_l00005ooooo`;o00000oooool5o`0000Gooooo1?l0
000;ooooo`Co00000_ooool2o`0000?ooooo0_l00009ooooo`;o00003_ooool2o`000<;ooooo000N
ooooo`03o`000?oooooooooo02[ooooo0_l00004ooooo`;o00000_ooool2o`0000;ooooo0_l00008
ooooo`Oo00001oooool2o`0000Gooooo0ol00003ooooo`?o00000oooool2o`0000;ooooo0_l00005
ooooo`;o00004oooool2o`000<;ooooo000Nooooo`;o00005?ooool2o`0001Gooooo0_l000000ooo
oooo0000o`000005ooooo`;o00003?ooool3o`0000;ooooo0_l00005ooooo`Go000000Coooooo`00
0?l0003ooooo1?l000000ooooooo0000o`000005ooooo`;o00000_ooool2o`0000Gooooo0_l0003G
ooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o00006?ooool2o`0001?ooooo1ol00005oooo
o`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000002o`000004ooooool0003o
0000o`0000kooooo0_l000000ooooooo0000o`000009ooooo`;o0000b_ooool001kooooo00?o0000
ooooooooool05oooool2o`0001_ooooo0_l0000=ooooo`[o000000?oooooo`000?l000001?ooool2
o`000003ooooool0003o000000?ooooo1_l0000;ooooo`;o000000?oooooo`000?l000000oooool3
o`0000?ooooo0_l0003:ooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o00006oooool2o`00
00[ooooo0_l000000ooooooo0000o`000003ooooo`Go000000?oooooo`000?l000000oooool2o`00
00;ooooo0_l00003ooooo`Ko00002Oooool2o`0000;ooooo0_l00004ooooo`?o00001_ooool2o`00
0<Oooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l0000Jooooo`;o000000?oooooo`000?l0
00000oooool3o`0000Gooooo1Ol00005ooooo`;o00003oooool2o`000004ooooool0003o0000o`00
00Cooooo0_l00007ooooo`;o0000aoooool001kooooo00?o0000ooooooooool09?ooool2o`00013o
oooo0_l0000:ooooo`?o000000?oooooo`000?l000000ol00005ooooo`Co00000_ooool2o`0000;o
oooo0_l000000ooooooo0000o`00000?ooooo`Co00000oooool2o`000=3ooooo000Nooooo`03o`00
0?oooooooooo01Wooooo0_l0000Kooooo`;o00001?ooool2o`0000Cooooo0_l00002ooooo`Go0000
1?ooool4o`000003ooooool0003o000000Co00000oooool2o`0000Kooooo0_l000000ooooooo0000
o`000006ooooo`;o00006Oooool2o`000;[ooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l0
000Qooooo`;o00001?ooool2o`000003ooooool0003o000000Ko00000_ooool4o`000003ooooool0
003o000000;ooooo0_l000000ooooooo0000o`000008ooooo`;o000000?oooooo`000?l000003_oo
ool2o`0000Gooooo0_l0000:ooooo`;o0000^_ooool001kooooo00?o0000ooooooooool0?oooool3
o`000003ooooool0003o000000So00003_ooool2o`0000gooooo0_l00004ooooo`;o00001_ooool2
o`0000?ooooo1?l00036ooooo`007_ooool00ol0003oooooooooo`0oooooo`?o000000?oooooo`00
0?l000000_l00002ooooo`;o00000_ooool2o`0000Gooooo0_l0000:ooooo`;o00002?ooool2o`00
00Cooooo0_l00006ooooo`;o00000oooool4o`000<Kooooo000Nooooo`03o`000?oooooooooo02;o
oooo0_l0000Nooooo`Go00000_ooool2o`000003ooooool0003o000000Co00000_ooool2o`0000[o
oooo0_l0000Booooo`;o00000_ooool2o`0000Gooooo0_l00036ooooo`007_ooool00ol0003ooooo
ooooo`0Hooooo`;o00002?ooool2o`0001kooooo0_l00005ooooo`[o000000?oooooo`000?l00000
0_ooool2o`0000Gooooo0_l0000Cooooo`;o00003oooool2o`000<3ooooo000Nooooo`03o`000?oo
oooooooo01Sooooo0_l0000Looooo`;o000000?oooooo`000?l000000_ooool2o`0000Kooooo0_l0
0002ooooo`Co00001?ooool2o`000003ooooool0003o000000;ooooo1?l00003ooooo`Go00002?oo
ool2o`0001Oooooo0_l00002ooooo`;o0000_?ooool001kooooo00?o0000ooooooooool0=?ooool4
o`000003ooooool0003o000000;ooooo0ol00003ooooo`So00000_ooool3o`0000Wooooo2ol00008
ooooo`;o00005Oooool2o`0000Cooooo0_l0002looooo`000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003ooooooooo
o`0dooooo`;o00000oooool2o`0000;ooooo0ol00003ooooo`Ko000000?oooooo`000?l000002_l0
0003ooooo`So00008_ooool6o`000;kooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo03Cooooo
0_l00003ooooo`Ko00001Oooool5o`000003ooooool0003o000000_o00000oooool2o`0000?ooooo
0_l0000>ooooo`;o00005?ooool4o`0000gooooo0_l0002_ooooo`000oooool01Ol@413ooooooooo
oooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000=?ooool2o`0000Go
oooo0_l00007ooooo`;o000000Goooooo`000?l0003o0000ooooo`0<o`0000?ooooo0_l0000=oooo
o`;o00001?ooool2o`0000?ooooo0_l0000=ooooo`?o00004?ooool2o`000:oooooo0003ooooo`05
o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000
ooooooooool0A?ooool2o`0000;ooooo0_l000000ooooooo0000o`000006o`0000Oooooo1Ol00006
ooooo`;o00000_ooool4o`0000Oooooo1?l0000;ooooo`?o00002oooool2o`000;Cooooo0003oooo
o`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o
0000ooooooooool0??ooool2o`0000Oooooo0_l00005ooooo`Oo00001Oooool2o`000003ooooool0
003o000000Ko00000_ooool2o`0000?ooooo0ol00009ooooo`;o00006Oooool2o`000;Cooooo0003
ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo
00?o0000ooooooooool08oooool2o`0000gooooo1?l00006ooooo`;o00001oooool3o`0000?ooooo
0_l00003ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo2Ol00005ooooo`;o0000
0_ooool2o`0001cooooo0_l0000@ooooo`;o0000Yoooool000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`0Sooooo`;o
00003Oooool4o`0000Kooooo0_l00008ooooo`Co000000?oooooo`000?l000000_ooool5o`000003
ooooool0003o000000?o00000_ooool9o`0000Wooooo0_l0000Looooo`;o00002?ooool2o`0000Ko
oooo0_l0002Wooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@06ooooo`03o`000?oooooooooo04Gooooo3?l000000ooooooo0000o`000004o`00
00Cooooo2Ol0000Oooooo`Co00003_ooool2o`000:oooooo000Nooooo`03o`000?oooooooooo037o
oooo0_l0000Booooo`;o00000oooool2o`000004ooooool0003o0000o`0000?ooooo1?l000000ooo
oooo0000o`000005ooooo`Oo00007_ooool4o`0000Cooooo0_l0002iooooo`007_ooool00ol0003o
ooooooooo`0aooooo`;o00004_ooool2o`0000Oooooo0_l000000ooooooo0000o`000002ooooo`;o
000000?oooooo`000?l000000ol000000ooooooo0000o`000006o`0000Sooooo0_l0000Looooo`;o
0000^Oooool001kooooo00?o0000ooooooooool09_ooool2o`0002Oooooo1?l00007ooooo`?o0000
00?oooooo`000?l000001?l0000:ooooo`;o000000?oooooo`000?l00000e?ooool001kooooo00?o
0000ooooooooool09Oooool3o`0000Gooooo0_l0000?ooooo`;o00003?ooool2o`000003ooooool0
003o000000Co000000?oooooo`000?l000000_ooool2o`0000Cooooo1_l0000;ooooo`;o00003ooo
ool2o`000<?ooooo000Nooooo`03o`000?oooooooooo02Gooooo0_l00006ooooo`;o00003?ooool2
o`000003ooooool0003o000000Sooooo1_l00003ooooo`Co000000?oooooo`000?l000002Oooool5
o`0000Gooooo0_l0000Eooooo`;o00001_ooool2o`0000gooooo0_l0002/ooooo`007_ooool00ol0
003oooooooooo`0kooooo`;o00002oooool4o`0000Gooooo0ol0000>ooooo`Go00001?ooool2o`00
00Cooooo0_l0000Gooooo`;o00003Oooool2o`000:cooooo000Nooooo`03o`000?oooooooooo04[o
oooo0ol00004ooooo`?o00001_ooool4o`0000;ooooo1ol0000:ooooo`;o00002?ooool2o`0000Wo
oooo0_l000000ooooooo0000o`000006ooooo`;o00001?ooool2o`000:kooooo000Nooooo`03o`00
0?oooooooooo04[ooooo0ol00002ooooo`;o00000oooool2o`0000Cooooo1?l00002ooooo`Ko0000
2Oooool5o`0000Gooooo1?l00009ooooo`;o000000?oooooo`000?l000000oooool2o`000003oooo
ool0003o000000Cooooo1Ol0002[ooooo`007_ooool00ol0003oooooooooo`0_ooooo`;o00006Ooo
ool3o`0000;ooooo1?l000000ooooooo0000o`000003o`0000?ooooo0_l00004ooooo`Co00002Ooo
ool5o`0000Gooooo0_l0000Cooooo`;o00000_ooool4o`0000;ooooo1?l0002[ooooo`007_ooool0
0ol0003oooooooooo`0_ooooo`;o00006?ooool5o`000003ooooool0003o000000;o00000_ooool4
o`0000?ooooo0_l00004ooooo`;o00001Oooool2o`0001_ooooo0_l00007ooooo`;o000000?ooooo
o`000?l000000_l00004ooooo`;o0000Zoooool001kooooo00?o0000ooooooooool05Oooool2o`00
01Gooooo0_l0000Kooooo`;o000000?oooooo`000?l000000oooool2o`0000cooooo0_l000000ooo
oooo0000o`000005ooooo`?o00006_ooool2o`0000Oooooo0_l00009ooooo`;o0000Zoooool001ko
oooo0_l0000Fooooo`;o00005Oooool2o`0001kooooo1ol00007ooooo`;o00000oooool2o`0000Wo
oooo0_l00006ooooo`;o00007oooool4o`0000;ooooo0ol0002[ooooo`007_ooool00ol0003ooooo
ooooo`0[ooooo`;o00004oooool2o`0000cooooo1?l00008ooooo`;o00005_ooool2o`0000Gooooo
0_l00006ooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`Co00000_ooool7o`000:Oooooo
000Nooooo`03o`000?oooooooooo02_ooooo0_l00009ooooo`;o000000?oooooo`000?l000001Ooo
ool2o`0000Sooooo0_l00002ooooo`;o0000:Oooool2o`0000Kooooo0_l00004ooooo`;o00001?oo
ool2o`0000Gooooo0_l00006ooooo`Ko0000YOooool001kooooo00?o0000ooooooooool0=_ooool2
o`000003ooooool0003o000000oooooo0_l00002ooooo`;o0000D?ooool4o`000:?ooooo000Noooo
o`03o`000?oooooooooo04kooooo0_l00006ooooo`;o0000B_ooool2o`000:?ooooo000Nooooo`03
o`000?oooooooooo02kooooo0_l000000ooooooo0000o`00000Gooooo`;o00000_ooool5o`0000?o
oooo0_l00017ooooo`Co0000Y?ooool001kooooo00?o0000ooooooooool0;_ooool2o`000003oooo
ool0003o000001Oooooo0_l00003ooooo`Co0000=_ooool2o`0001Cooooo1?l0002Tooooo`007_oo
ool00ol0003oooooooooo`0[ooooo`;o00000oooool2o`0000Gooooo0_l0000Fooooo`?o0000=ooo
ool2o`000;cooooo000Nooooo`03o`000?oooooooooo00oooooo0_l0000Jooooo`;o00000oooool2
o`0000Gooooo0_l0000Gooooo`;o0000=oooool4o`0000kooooo0_l0002Zooooo`007_ooool00ol0
003oooooooooo`0?ooooo`;o00004Oooool2o`0000_ooooo0_l0000Jooooo`;o0000??ooool4o`00
00kooooo0_l0002Zooooo`007_ooool00ol0003oooooooooo`0Rooooo`Co00001?ooool2o`0000?o
oooo0_l0000Jooooo`;o0000<?ooool2o`000<Sooooo000Nooooo`03o`000?oooooooooo02Cooooo
1?l00002ooooo`;o00004_ooool2o`0003gooooo0_l00038ooooo`007_ooool00ol0003ooooooooo
o`0Mooooo`;o00001_ooool3o`0001Kooooo0_l0000mooooo`;o0000b?ooool001kooooo00?o0000
ooooooooool06Oooool2o`0000;ooooo0_l00003ooooo`Go0000K?ooool2o`000;;ooooo000Noooo
o`03o`000?oooooooooo01Wooooo0_l00007ooooo`?o00002?ooool2o`0006Cooooo0_l0002boooo
o`007_ooool00ol0003oooooooooo`0Eooooo`;o00005_ooool2o`000?oooooo6Oooool001kooooo
0_l0000Fooooo`;o00001oooool2o`000?oooooo:?ooool001kooooo00?o0000ooooooooool04_oo
ool2o`0000[ooooo0_l0003oooooobSooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0003o
ooooocCooooo000Nooooo`03o`000?oooooooooo03?ooooo0_l0000Vooooo`;o0000j_ooool001ko
oooo00?o0000ooooooooool09oooool2o`0000[ooooo0_l0000Vooooo`;o0000j_ooool001kooooo
00?o0000ooooooooool03_ooool2o`0001Oooooo0_l00003ooooo`;o0000GOooool2o`000;[ooooo
000Nooooo`03o`000?oooooooooo00kooooo0_l0000=ooooo`;o000000?oooooo`000?l000002_oo
ool2o`0005gooooo0_l0002jooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o000000?ooooo
o`000?l000004_ooool2o`0004[ooooo0_l00035ooooo`007_ooool00ol0003oooooooooo`0;oooo
o`;o00009oooool2o`000003ooooool0003o000004Oooooo0_l00035ooooo`007_ooool00ol0003o
ooooooooo`0;ooooo`;o00003_ooool2o`0001[ooooo0_l0003oooooo`oooooo000Nooooo`03o`00
0?oooooooooo01_ooooo0_l0003oooooob_ooooo000Nooooo`03o`000?oooooooooo01oooooo0_l0
003oooooobOooooo000Nooooo`03o`000?oooooooooo01Sooooo0_l00005ooooo`;o0000oooooolW
ooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o00000oooool2o`000?oooooo:Oooool001ko
oooo00?o0000ooooooooool07Oooool2o`0001kooooo0_l0000kooooo`;o0000boooool001kooooo
00?o0000ooooooooool0?Oooool2o`0000;ooooo0_l0000gooooo`;o0000boooool001kooooo0_l0
0012ooooo`;o0000ooooool5ooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o00002?ooool2
o`0000?ooooo0_l0003oooooobKooooo000Nooooo`03o`000?oooooooooo017ooooo0_l00008oooo
o`;o00000oooool2o`000?oooooo9_ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`1looooo`;o0000bOooool001kooooo00?o0000ooooooooool04Ooo
ool2o`0006Wooooo0_l00039ooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o00008oooool3
o`000?oooooo3oooool001kooooo00?o0000ooooooooool0=_ooool3o`000?oooooo3oooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0OOooool3
o`000<Oooooo000Nooooo`03o`000?oooooooooo057ooooo0_l0000Zooooo`?o0000aoooool001ko
oooo00?o0000ooooooooool04_ooool2o`0003gooooo0_l0002Jooooo`;o0000F?ooool001Cooooo
1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo01;ooooo0_l0003Iooooo`;o0000
F?ooool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodSooooo000F
ooooo`03o`000?oooooooooo00Gooooo0ol0003oooooodSooooo000Fooooo`03o`000?oooooooooo
0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003ooooo
ooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Cooooo00?oEEEE
ofIVI_l00000oooooomBooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.21933 .75273 Mdot
.14313 .36742 Mdot
.19424 .84351 Mdot
.29027 .71445 Mdot
.30397 .85783 Mdot
.26556 .70667 Mdot
.11718 .04575 Mdot
.25891 .85426 Mdot
.29864 .73292 Mdot
.57691 .32739 Mdot
.24634 .64561 Mdot
.24011 .69083 Mdot
.23641 .83671 Mdot
.98835 .69071 Mdot
.25465 .71237 Mdot
.08616 .67476 Mdot
.15308 .50923 Mdot
.26764 .80967 Mdot
.19831 .79105 Mdot
.29993 .67299 Mdot
.46086 .64812 Mdot
.24734 .67336 Mdot
.25069 .8489 Mdot
.23378 .16084 Mdot
.30865 .76516 Mdot
.24486 .88262 Mdot
.27075 .78235 Mdot
.05416 .6468 Mdot
.24681 .64718 Mdot
.23979 .65267 Mdot
.22441 .81098 Mdot
.25561 .71678 Mdot
.30036 .71776 Mdot
.53662 .81669 Mdot
.45838 .7688 Mdot
.29412 .78307 Mdot
.98438 .69056 Mdot
.38371 .57728 Mdot
.19084 .79424 Mdot
.29834 .79067 Mdot
.21204 .8082 Mdot
.40312 .73624 Mdot
.3776 .73832 Mdot
.3515 .56931 Mdot
.08698 .84276 Mdot
.40786 .71803 Mdot
.25758 .35137 Mdot
.40563 .82934 Mdot
.27697 .80927 Mdot
.28931 .86124 Mdot
.24507 .76234 Mdot
.44028 .81305 Mdot
.27706 .90833 Mdot
.29729 .80059 Mdot
.28359 .91486 Mdot
.32709 .09003 Mdot
.74684 .16238 Mdot
.2578 .84517 Mdot
.26782 .78004 Mdot
.281 .72003 Mdot
.27452 .70261 Mdot
.24992 .85716 Mdot
.13967 .97725 Mdot
.31593 .75663 Mdot
.31194 .75857 Mdot
.26591 .69593 Mdot
.35804 .87161 Mdot
.26939 .78336 Mdot
.2562 .69396 Mdot
.82332 .19157 Mdot
.38916 .05588 Mdot
.20518 .72653 Mdot
.39853 .74039 Mdot
.28178 .76411 Mdot
.27634 .69237 Mdot
.35193 .25322 Mdot
.24151 .93536 Mdot
.37155 .04381 Mdot
.26552 .75122 Mdot
.11972 .85286 Mdot
.44247 .82217 Mdot
.27886 .18236 Mdot
.38726 .59086 Mdot
.25064 .85273 Mdot
.90942 .1762 Mdot
.42368 .98773 Mdot
.28449 .87714 Mdot
.27846 .76376 Mdot
.25498 .70367 Mdot
.24876 .71361 Mdot
.33803 .67838 Mdot
.86449 .22204 Mdot
.28747 .84317 Mdot
.36948 .93779 Mdot
.25776 .74469 Mdot
.44233 .80481 Mdot
.19666 .95298 Mdot
.45245 .78623 Mdot
.33161 .7874 Mdot
.47181 .72033 Mdot
.25144 .77548 Mdot
.23864 .78904 Mdot
.21462 .78106 Mdot
.01591 .68525 Mdot
.14471 .34773 Mdot
.25979 .84343 Mdot
.11453 .65825 Mdot
.08644 .66378 Mdot
.41983 .83273 Mdot
.2613 .09714 Mdot
.99194 .68529 Mdot
.32556 .49198 Mdot
.16079 .80792 Mdot
.25508 .81238 Mdot
.10236 .64738 Mdot
.1198 .13295 Mdot
.08819 .84433 Mdot
.21764 .83721 Mdot
.44317 .35746 Mdot
.06788 .86033 Mdot
.26824 .79389 Mdot
.39063 .78279 Mdot
.26563 .67231 Mdot
.36846 .96058 Mdot
.94722 .25522 Mdot
.47596 .68647 Mdot
.32407 .78282 Mdot
.21736 .76413 Mdot
.55528 .82276 Mdot
.42543 .73773 Mdot
.44856 .69577 Mdot
.19856 .09471 Mdot
.11259 .67349 Mdot
.26617 .79256 Mdot
.25431 .78283 Mdot
.26725 .92909 Mdot
.27497 .84962 Mdot
.1867 .66753 Mdot
.2002 .8186 Mdot
.27457 .71011 Mdot
.23023 .76468 Mdot
.32113 .76049 Mdot
.27173 .68706 Mdot
.47036 .73175 Mdot
.22692 .07713 Mdot
.25414 .68708 Mdot
.2727 .72467 Mdot
.27247 .78164 Mdot
.74028 .1768 Mdot
.22395 .1372 Mdot
.10598 .78061 Mdot
.28728 .70012 Mdot
.21067 .70204 Mdot
.29934 .66921 Mdot
.25849 .72865 Mdot
.22241 .84473 Mdot
.16258 .66898 Mdot
.7803 .12819 Mdot
.29847 .74705 Mdot
.11844 .6737 Mdot
.18837 .70272 Mdot
.45911 .75032 Mdot
.2999 .93271 Mdot
.25995 .78649 Mdot
.32971 .79303 Mdot
.30223 .87527 Mdot
.28089 .77828 Mdot
.2864 .76128 Mdot
.22521 .0872 Mdot
.27856 .80569 Mdot
.25683 .65841 Mdot
.46824 .82492 Mdot
.45567 .76309 Mdot
.44623 .27072 Mdot
.20972 .76133 Mdot
.16816 .64062 Mdot
.4886 .82365 Mdot
.21863 .89117 Mdot
.16376 .03646 Mdot
.4451 .80382 Mdot
.358 .74893 Mdot
.27729 .71171 Mdot
.12873 .7703 Mdot
.12732 .77336 Mdot
.62979 .13763 Mdot
.17193 .84078 Mdot
.12443 .67631 Mdot
.3506 .68953 Mdot
.91403 .68159 Mdot
.47857 .69247 Mdot
.211 .7623 Mdot
.39602 .00162 Mdot
.2229 .7563 Mdot
.15077 .74064 Mdot
.09263 .85599 Mdot
.37133 .72073 Mdot
.46554 .74531 Mdot
.25215 .66488 Mdot
.30038 .73229 Mdot
.2824 .69557 Mdot
.1388 .80218 Mdot
.06384 .56109 Mdot
.25857 .79137 Mdot
.11402 .80305 Mdot
.30958 .76433 Mdot
.28019 .75938 Mdot
.17815 .14891 Mdot
.2693 .76594 Mdot
.9412 .17979 Mdot
.05991 .67271 Mdot
.28656 .82708 Mdot
.23817 .75211 Mdot
.01139 .23233 Mdot
.55379 .08691 Mdot
.18257 .68313 Mdot
.39587 .96797 Mdot
.2974 .7804 Mdot
.4111 .39683 Mdot
.1436 .62989 Mdot
.33117 .86113 Mdot
.76144 .15281 Mdot
.23461 .76109 Mdot
.32424 .76736 Mdot
.28226 .75051 Mdot
.24104 .7354 Mdot
.19512 .72216 Mdot
.48255 .76542 Mdot
.2594 .89976 Mdot
.57968 .17833 Mdot
.27067 .68858 Mdot
.22188 .85612 Mdot
.2888 .70844 Mdot
.27488 .68555 Mdot
.46312 .77242 Mdot
.39575 .95129 Mdot
.60155 .23738 Mdot
.57193 .42232 Mdot
.22022 .82455 Mdot
.41736 .61995 Mdot
.71021 .23269 Mdot
.22171 .91679 Mdot
.26756 .67461 Mdot
.39034 .7842 Mdot
.22824 .89243 Mdot
.179 .7853 Mdot
.24887 .92724 Mdot
.22389 .75352 Mdot
.24999 .65565 Mdot
.32234 .24112 Mdot
.20428 .81429 Mdot
.43416 .82124 Mdot
.29467 .89311 Mdot
.7877 .32419 Mdot
.42762 .01246 Mdot
.94427 .26207 Mdot
.37599 .82606 Mdot
.28957 .89594 Mdot
.38575 .63925 Mdot
.46687 .75097 Mdot
.09923 .62373 Mdot
.23655 .74326 Mdot
.30481 .73781 Mdot
.3111 .95508 Mdot
.33082 .63781 Mdot
.27239 .68245 Mdot
.44053 .91788 Mdot
.18675 .81103 Mdot
.44542 .31073 Mdot
.21596 .82933 Mdot
.28534 .78789 Mdot
.33043 .78788 Mdot
.43618 .29984 Mdot
.25894 .68452 Mdot
.31092 .72927 Mdot
.44535 .81571 Mdot
.28878 .87277 Mdot
.16463 .6301 Mdot
.15372 .92088 Mdot
.29184 .79893 Mdot
.21489 .78159 Mdot
.75889 .20433 Mdot
.24983 .66668 Mdot
.25547 .7962 Mdot
.98268 .70902 Mdot
.30004 .87861 Mdot
.32325 .76695 Mdot
.2775 .80006 Mdot
.43209 .73555 Mdot
.3633 .81781 Mdot
.24623 .69151 Mdot
.37235 .79458 Mdot
.88596 .22689 Mdot
.20067 .79071 Mdot
.15113 .73585 Mdot
.19848 .03213 Mdot
.44144 .74906 Mdot
.29345 .75959 Mdot
.13629 .67919 Mdot
.75501 .2363 Mdot
.36006 .18261 Mdot
.42807 .72848 Mdot
.33813 .76993 Mdot
.46544 .75364 Mdot
.22206 .74826 Mdot
.51948 .31823 Mdot
.38734 .86489 Mdot
.27217 .77827 Mdot
.26412 .74967 Mdot
.03814 .28455 Mdot
.07276 .53121 Mdot
.26882 .78131 Mdot
.7497 .25052 Mdot
.24277 .87806 Mdot
.18261 .86636 Mdot
.32319 .78812 Mdot
.32025 .83074 Mdot
.17648 .68045 Mdot
.44615 .25912 Mdot
.3127 .73664 Mdot
.21782 .43543 Mdot
.18358 .79934 Mdot
.29181 .70517 Mdot
.2334 .76238 Mdot
.09583 .74106 Mdot
.24711 .80525 Mdot
.21817 .85313 Mdot
.29029 .79899 Mdot
.24561 .74018 Mdot
.25409 .70537 Mdot
.22917 .85657 Mdot
.32167 .67681 Mdot
.25924 .69381 Mdot
.13702 .02667 Mdot
.12043 .25264 Mdot
.42205 .50358 Mdot
.25125 .7043 Mdot
.65361 .62464 Mdot
.27216 .79374 Mdot
.7309 .00698 Mdot
.4505 .91757 Mdot
.32718 .78669 Mdot
.70157 .59227 Mdot
.24735 .75032 Mdot
.21622 .74128 Mdot
.736 .11117 Mdot
.97825 .7533 Mdot
.20623 .09353 Mdot
.19429 .15987 Mdot
.35897 .7068 Mdot
.26499 .85559 Mdot
.20951 .83367 Mdot
.29288 .89714 Mdot
.50192 .68293 Mdot
.03863 .66222 Mdot
.14842 .07831 Mdot
.26609 .69014 Mdot
.41235 .73871 Mdot
.25203 .78062 Mdot
.25432 .83596 Mdot
.38539 .44402 Mdot
.25313 .66319 Mdot
.48678 .7729 Mdot
.21773 .80833 Mdot
.28466 .83165 Mdot
.33149 .76316 Mdot
.49155 .71025 Mdot
.0375 .86646 Mdot
.48345 .63035 Mdot
.67944 .21544 Mdot
.24238 .66442 Mdot
.19228 .68642 Mdot
.27629 .77252 Mdot
.19353 .82892 Mdot
.27641 .70158 Mdot
.47044 .80268 Mdot
.46909 .71581 Mdot
.08197 .86829 Mdot
.28047 .79294 Mdot
.09962 .22066 Mdot
.23815 .64477 Mdot
.26631 .74415 Mdot
.30763 .70934 Mdot
.66527 .15562 Mdot
.93932 .26582 Mdot
.07111 .64268 Mdot
.12818 .76601 Mdot
.04909 .83182 Mdot
.13988 .58841 Mdot
.27367 .7896 Mdot
.0066 .697 Mdot
.22984 .76705 Mdot
.29086 .82811 Mdot
.24062 .77834 Mdot
.28978 .85046 Mdot
.29997 .85242 Mdot
.13507 .15908 Mdot
.16768 .58263 Mdot
.3476 .06393 Mdot
.26672 .78038 Mdot
.23507 .80059 Mdot
.39034 .72025 Mdot
.03985 .88508 Mdot
.79023 .14097 Mdot
.24827 .85505 Mdot
.02987 .74407 Mdot
.52009 .79391 Mdot
.25437 .70022 Mdot
.22426 .71869 Mdot
.21162 .75476 Mdot
.26257 .78849 Mdot
.1986 .68569 Mdot
.29894 .76037 Mdot
.18953 .69794 Mdot
.09039 .06778 Mdot
.70242 .17808 Mdot
.26944 .79936 Mdot
.2223 .78433 Mdot
.19348 .71448 Mdot
.76603 .1301 Mdot
.26422 .75168 Mdot
.29113 .77749 Mdot
.1801 .29853 Mdot
.58044 .23771 Mdot
.28732 .81759 Mdot
.25287 .84964 Mdot
.06263 .38395 Mdot
.14562 .77976 Mdot
.28709 .71485 Mdot
.20347 .72482 Mdot
.94915 .18902 Mdot
.70863 .20673 Mdot
.28869 .36535 Mdot
.06918 .8042 Mdot
.31451 .69571 Mdot
.77809 .23342 Mdot
.98689 .75009 Mdot
.119 .62888 Mdot
.50082 .77081 Mdot
.24468 .83046 Mdot
.07591 .85868 Mdot
.15903 .83051 Mdot
.33986 .51415 Mdot
.3675 .59006 Mdot
.26668 .69666 Mdot
.29824 .35247 Mdot
.26849 .73019 Mdot
.29526 .71243 Mdot
.29908 .83297 Mdot
.85552 .24875 Mdot
.23068 .80724 Mdot
.48103 .67906 Mdot
.40277 .83665 Mdot
.32521 .78304 Mdot
.27252 .74823 Mdot
.19102 .69519 Mdot
.26754 .77995 Mdot
.30547 .75446 Mdot
.2952 .79397 Mdot
.54288 .80929 Mdot
.05005 .75351 Mdot
.26109 .78812 Mdot
.27629 .75683 Mdot
.27008 .73813 Mdot
.20484 .86848 Mdot
.18402 .18503 Mdot
.45078 .78953 Mdot
.29643 .7128 Mdot
.5009 .67302 Mdot
.25916 .69975 Mdot
.52224 .80398 Mdot
.24042 .66048 Mdot
.27474 .87366 Mdot
.25483 .85398 Mdot
.25279 .85333 Mdot
.20434 .85977 Mdot
.25877 .72819 Mdot
.23952 .93494 Mdot
.24703 .85006 Mdot
.7574 .15802 Mdot
.33454 .79341 Mdot
.3759 .02915 Mdot
.13046 .78035 Mdot
.26116 .67398 Mdot
.24075 .76412 Mdot
.22194 .75132 Mdot
.43643 .88507 Mdot
.41668 .8868 Mdot
.85973 .27 Mdot
.46679 .81585 Mdot
.03959 .6551 Mdot
.20138 .82333 Mdot
.29163 .76194 Mdot
.1269 .10248 Mdot
.03651 .84963 Mdot
.29671 .66904 Mdot
.24963 .65376 Mdot
.28567 .85762 Mdot
.29377 .71367 Mdot
.29973 .19238 Mdot
.14106 .70541 Mdot
.2534 .90533 Mdot
.45324 .74585 Mdot
.46077 .82808 Mdot
.63463 .22415 Mdot
.27596 .80733 Mdot
.31498 .84967 Mdot
.26508 .87031 Mdot
.19553 .00986 Mdot
.30293 .75912 Mdot
.24596 .65094 Mdot
.25469 .77409 Mdot
.39894 .0865 Mdot
.28371 .06704 Mdot
.68015 .14374 Mdot
.29989 .86517 Mdot
.45552 .76953 Mdot
.31867 .80158 Mdot
.44368 .81711 Mdot
.75356 .17113 Mdot
.24391 .79178 Mdot
.24839 .77784 Mdot
.20295 .86264 Mdot
.26642 .74795 Mdot
.27323 .68484 Mdot
.50574 .69441 Mdot
.2938 .82606 Mdot
.12864 .08027 Mdot
.04976 .58855 Mdot
.14666 .84379 Mdot
.54072 .80737 Mdot
.42037 .95706 Mdot
.22379 .02235 Mdot
.30207 .872 Mdot
.209 .80917 Mdot
.24583 .85117 Mdot
.25011 .77995 Mdot
.32157 .75879 Mdot
.31454 .74043 Mdot
.31385 .5381 Mdot
.18329 .89174 Mdot
.27349 .70887 Mdot
.71206 .15793 Mdot
.26034 .69122 Mdot
.25959 .7332 Mdot
.22828 .76117 Mdot
.17035 .98027 Mdot
.85192 .2523 Mdot
.17866 .86443 Mdot
.26105 .80456 Mdot
.21978 .85122 Mdot
.15723 .13997 Mdot
.14587 .8288 Mdot
.30574 .72729 Mdot
.52884 .82466 Mdot
.4157 .81025 Mdot
.18728 .19683 Mdot
.85011 .27836 Mdot
.26981 .79862 Mdot
.30603 .75638 Mdot
.0435 .65766 Mdot
.26786 .79975 Mdot
.30778 .73962 Mdot
.3253 .53836 Mdot
.51231 .6817 Mdot
.27619 .80086 Mdot
.27925 .81226 Mdot
.17684 .68804 Mdot
.32626 .7747 Mdot
.33592 .25733 Mdot
.25678 .70398 Mdot
.21004 .45017 Mdot
.02273 .67572 Mdot
.25922 .72409 Mdot
.25766 .73378 Mdot
.28179 .83035 Mdot
.28982 .71138 Mdot
.49702 .7642 Mdot
.24694 .64763 Mdot
.29227 .89724 Mdot
.26429 .90553 Mdot
.31142 .19561 Mdot
.85643 .20983 Mdot
.21734 .89373 Mdot
.22912 .77554 Mdot
.30502 .62239 Mdot
.28639 .7684 Mdot
.15923 .84361 Mdot
.0585 .03592 Mdot
.02045 .86933 Mdot
.28202 .7298 Mdot
.24786 .84971 Mdot
.26609 .928 Mdot
.21657 .74098 Mdot
.28959 .70521 Mdot
.24169 .66587 Mdot
.2393 .87085 Mdot
.11961 .6345 Mdot
.2242 .85031 Mdot
.28816 .7807 Mdot
.24113 .7701 Mdot
.28726 .70429 Mdot
.2839 .77017 Mdot
.19837 .82972 Mdot
.4531 .78456 Mdot
.04355 .94126 Mdot
.25765 .78519 Mdot
.28162 .79034 Mdot
.24023 .66115 Mdot
.09393 .93365 Mdot
.22597 .74901 Mdot
.12197 .87374 Mdot
.20056 .0246 Mdot
.24715 .67532 Mdot
.14764 .13822 Mdot
.19267 .79857 Mdot
.13764 .63044 Mdot
.20219 .72152 Mdot
.42968 .97915 Mdot
.33677 .78107 Mdot
.35235 .22024 Mdot
.24028 .83475 Mdot
.06935 .46852 Mdot
.22095 .75528 Mdot
.37284 .11548 Mdot
.43002 .78853 Mdot
.18881 .78174 Mdot
.47777 .88893 Mdot
.41188 .01132 Mdot
.28395 .91268 Mdot
.42961 .74161 Mdot
.20394 .84011 Mdot
.28545 .75317 Mdot
.28511 .7241 Mdot
.02057 .76428 Mdot
.26041 .7223 Mdot
.47718 .08107 Mdot
.25137 .85256 Mdot
.26937 .89529 Mdot
.3004 .8356 Mdot
.25263 .70387 Mdot
.38593 .69965 Mdot
.26106 .70606 Mdot
.40189 .7567 Mdot
.39948 .70998 Mdot
.01899 .93421 Mdot
.24395 .77504 Mdot
.29573 .78125 Mdot
.74882 .14081 Mdot
.23837 .84967 Mdot
.104 .93161 Mdot
.17392 .14795 Mdot
.28777 .71378 Mdot
.46833 .80063 Mdot
.28073 .74545 Mdot
.85438 .25196 Mdot
.29922 .7869 Mdot
.25577 .92311 Mdot
.76443 .26723 Mdot
.93375 .17608 Mdot
.26668 .78019 Mdot
.07395 .87277 Mdot
.24645 .74713 Mdot
.47656 .31638 Mdot
.26935 .80098 Mdot
.41712 .95362 Mdot
.53701 .81622 Mdot
.26363 .7515 Mdot
.14233 .06017 Mdot
.47699 .71506 Mdot
.52571 .80188 Mdot
.3884 .83166 Mdot
.42725 .30759 Mdot
.15421 .74479 Mdot
.24138 .64269 Mdot
.69551 .24255 Mdot
.24919 .86856 Mdot
.76392 .34592 Mdot
.2886 .8231 Mdot
.25503 .15107 Mdot
.92393 .19964 Mdot
.25584 .46547 Mdot
.47143 .72502 Mdot
.69332 .1759 Mdot
.21235 .76591 Mdot
.25734 .70563 Mdot
.43704 .76753 Mdot
.30169 .80547 Mdot
.22301 .1047 Mdot
.04657 .84706 Mdot
.25699 .82153 Mdot
.39264 .8215 Mdot
.10655 .80536 Mdot
.33306 .73004 Mdot
.14828 .4406 Mdot
.29051 .70478 Mdot
.24332 .74177 Mdot
.27296 .7417 Mdot
.21656 .04826 Mdot
.46784 .25751 Mdot
.09893 .20945 Mdot
.37583 .42629 Mdot
.03475 .6749 Mdot
.22001 .84298 Mdot
.20075 .81519 Mdot
.41551 .97338 Mdot
.27622 .68712 Mdot
.50812 .14924 Mdot
.2472 .23327 Mdot
.16819 .79195 Mdot
.30214 .72905 Mdot
.54881 .23641 Mdot
.24516 .66284 Mdot
.01602 .87167 Mdot
.69725 .32319 Mdot
.27098 .88836 Mdot
.06488 .36103 Mdot
.25419 .66199 Mdot
.28662 .85632 Mdot
.13784 .15974 Mdot
.25962 .66273 Mdot
.24633 .74463 Mdot
.41681 .80882 Mdot
.25131 .78095 Mdot
.05267 .58955 Mdot
.49151 .66039 Mdot
.83785 .18032 Mdot
.16937 .73684 Mdot
.26824 .80017 Mdot
.39508 .71489 Mdot
.74914 .14045 Mdot
.24411 .64481 Mdot
.24428 .64623 Mdot
.20926 .84523 Mdot
.28827 .72728 Mdot
.12254 .13706 Mdot
.0405 .70899 Mdot
.86563 .24337 Mdot
.8608 .26832 Mdot
.26842 .76056 Mdot
.90791 .17216 Mdot
.29787 .75826 Mdot
.29781 .6998 Mdot
.19257 .79059 Mdot
.16476 .01795 Mdot
.45416 .76569 Mdot
.3141 .78362 Mdot
.23945 .6427 Mdot
.74966 .15775 Mdot
.31286 .74597 Mdot
.31455 .11404 Mdot
.40028 .75308 Mdot
.23574 .76086 Mdot
.16934 .71979 Mdot
.22549 .76841 Mdot
.24643 .78111 Mdot
.33672 .79044 Mdot
.28762 .81097 Mdot
.43005 .80227 Mdot
.24529 .9337 Mdot
.20785 .82041 Mdot
.82346 .14977 Mdot
.2607 .85524 Mdot
.9784 .22917 Mdot
.24802 .75852 Mdot
.2534 .66749 Mdot
.27857 .69068 Mdot
.48367 .72144 Mdot
.72404 .17001 Mdot
.25296 .66737 Mdot
.98264 .24438 Mdot
.31486 .777 Mdot
.04539 .82012 Mdot
.25901 .82315 Mdot
.29475 .89279 Mdot
.20058 .147 Mdot
.23261 .7816 Mdot
.33642 .7909 Mdot
.20333 .82376 Mdot
.19849 .68589 Mdot
.21832 .81736 Mdot
.29232 .71163 Mdot
.11406 .85358 Mdot
.72784 .25193 Mdot
.48414 .7643 Mdot
.30787 .76701 Mdot
.15647 .66658 Mdot
.04787 .65251 Mdot
.27662 .71324 Mdot
.29037 .76087 Mdot
.21147 .84946 Mdot
.22608 .72996 Mdot
.68093 .21423 Mdot
.00751 .73898 Mdot
.23107 .89818 Mdot
.42316 .75919 Mdot
.25986 .92171 Mdot
.03519 .65849 Mdot
.1812 .71601 Mdot
.30222 .73454 Mdot
.22142 .7451 Mdot
.6609 .30332 Mdot
.23736 .65476 Mdot
.21641 .89806 Mdot
.12949 .81866 Mdot
.28251 .67589 Mdot
.26628 .80124 Mdot
.13247 .09111 Mdot
.35794 .39812 Mdot
.46202 .7367 Mdot
.23954 .77181 Mdot
.46162 .72665 Mdot
.29903 .75262 Mdot
.20205 .86208 Mdot
.14891 .80804 Mdot
.34575 .70292 Mdot
.27707 .76467 Mdot
.31321 .02741 Mdot
.74421 .18155 Mdot
.25726 .71678 Mdot
.14575 .05122 Mdot
.25029 .85226 Mdot
.23408 .84807 Mdot
.33477 .76813 Mdot
.22539 .84495 Mdot
.27698 .86643 Mdot
.17742 .66599 Mdot
.27765 .90263 Mdot
.33205 .78427 Mdot
.1905 .1388 Mdot
.23836 .77614 Mdot
.09747 .82856 Mdot
.41187 .73739 Mdot
.26977 .82963 Mdot
.17311 .16549 Mdot
.38243 .73593 Mdot
.27048 .79642 Mdot
.43717 .06667 Mdot
.27695 .80804 Mdot
.32894 .75539 Mdot
.20844 .2183 Mdot
.0305 .88505 Mdot
.22872 .84799 Mdot
.27044 .77776 Mdot
.28815 .72452 Mdot
.75164 .18808 Mdot
.10343 .01405 Mdot
.48555 .68549 Mdot
.20053 .83779 Mdot
.24342 .86958 Mdot
.23506 .75997 Mdot
.35848 .61327 Mdot
.26532 .6793 Mdot
.20768 .80558 Mdot
.25529 .89958 Mdot
.26308 .80678 Mdot
.10116 .22767 Mdot
.25605 .85382 Mdot
.24288 .32226 Mdot
.32975 .79236 Mdot
.26036 .7616 Mdot
.2358 .84878 Mdot
.28227 .71364 Mdot
.30023 .72469 Mdot
.52006 .08472 Mdot
.23719 .88186 Mdot
.2806 .70632 Mdot
.19788 .7898 Mdot
.15176 .62736 Mdot
.0124 .26272 Mdot
.23842 .84809 Mdot
.11473 .72437 Mdot
.25811 .80125 Mdot
.31458 .76661 Mdot
.27509 .80249 Mdot
.43683 .80216 Mdot
.29155 .86698 Mdot
.94458 .31912 Mdot
.22339 .53774 Mdot
.03121 .89941 Mdot
.25037 .77331 Mdot
.24778 .7833 Mdot
.25901 .66912 Mdot
.25819 .85502 Mdot
.21485 .90517 Mdot
.33857 .79436 Mdot
.2188 .75323 Mdot
.22515 .76547 Mdot
.72876 .20105 Mdot
.24916 .67163 Mdot
.51258 .81802 Mdot
.63114 .21165 Mdot
.14953 .94648 Mdot
.33308 .8834 Mdot
.25345 .66762 Mdot
.31894 .27918 Mdot
.29444 .76399 Mdot
.8372 .14524 Mdot
.25418 .69413 Mdot
.06353 .7708 Mdot
.33624 .79012 Mdot
.25226 .77223 Mdot
.20829 .80341 Mdot
.21537 .29106 Mdot
.2763 .76697 Mdot
.13579 .09543 Mdot
.01467 .73512 Mdot
.48982 .76815 Mdot
.30297 .71381 Mdot
.20497 .79231 Mdot
.25576 .74566 Mdot
.26489 .81486 Mdot
.53128 .82388 Mdot
.39795 .21729 Mdot
.30913 .73449 Mdot
.27977 .77543 Mdot
.18992 .6927 Mdot
.48303 .77102 Mdot
.09657 .78258 Mdot
.4516 .83632 Mdot
.2892 .72188 Mdot
.59176 .23864 Mdot
.35881 .72594 Mdot
.24977 .89273 Mdot
.23862 .84976 Mdot
.25375 .71054 Mdot
.38783 .65229 Mdot
.61236 .17014 Mdot
.20069 .68326 Mdot
.28183 .56795 Mdot
.93644 .177 Mdot
.3452 .75359 Mdot
.28037 .84725 Mdot
.24031 .84873 Mdot
.27313 .68378 Mdot
.35589 .04386 Mdot
.22426 .76478 Mdot
.7003 .28055 Mdot
.24678 .64939 Mdot
.26388 .75512 Mdot
.50767 .83374 Mdot
.23677 .84573 Mdot
.19208 .80916 Mdot
.30874 .76875 Mdot
.1786 .99285 Mdot
.28513 .89568 Mdot
.26554 .71529 Mdot
.38484 .76072 Mdot
.31978 .8652 Mdot
.27785 .71548 Mdot
.41516 .12727 Mdot
.24964 .68473 Mdot
.75973 .26889 Mdot
.39144 .7771 Mdot
.41729 .60956 Mdot
.06602 .77403 Mdot
.19672 .8432 Mdot
.61694 .09686 Mdot
.40673 .72744 Mdot
.15182 .92339 Mdot
.9975 .29943 Mdot
.24339 .66548 Mdot
.27627 .7541 Mdot
.25634 .71377 Mdot
.27839 .70556 Mdot
.22457 .85156 Mdot
.17157 .07236 Mdot
.19694 .65219 Mdot
.18997 .71944 Mdot
.86445 .16324 Mdot
.23292 .0902 Mdot
.34026 .11391 Mdot
.80676 .3379 Mdot
.23038 .19628 Mdot
.16893 .01941 Mdot
.40121 .27863 Mdot
.26159 .86297 Mdot
.13437 .68272 Mdot
.26276 .0365 Mdot
.26812 .77029 Mdot
.25605 .79752 Mdot
.28306 .85044 Mdot
.2387 .75932 Mdot
.33807 .60112 Mdot
.12285 .68063 Mdot
.24075 .64279 Mdot
.3997 .83294 Mdot
.17622 .71259 Mdot
.27485 .15095 Mdot
.4373 .80961 Mdot
.26376 .79369 Mdot
.4576 .63859 Mdot
.29341 .71728 Mdot
.21086 .68079 Mdot
.33208 .14429 Mdot
.33314 .76139 Mdot
.26819 .80236 Mdot
.23936 .77249 Mdot
.3233 .77319 Mdot
.1543 .68813 Mdot
.25322 .64988 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03?ooool3o`0000oooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo000Nooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool3o`0000oooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Oooooo0_l00004ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooooooo
o`0kooooo`;o0000[Oooool2o`0005_ooooo000Nooooo`03o`000?oooooooooo03_ooooo0_l00015
ooooo`;o00000oooool2o`000;kooooo000Nooooo`03o`000?oooooooooo01kooooo0_l0001Roooo
o`;o00000oooool2o`000;kooooo000Nooooo`03o`000?oooooooooo01kooooo0_l0000Aooooo`Co
0000oooooolCooooo`007_ooool00ol0003oooooooooo`0aooooo`Co00004?ooool2o`000?oooooo
0Oooool001kooooo00?o0000ooooooooool0?Oooool2o`0000Kooooo0_l0003oooooo`7ooooo000N
ooooo`03o`000?oooooooooo02Sooooo0_l0000Cooooo`;o00008oooool2o`000>?ooooo000Noooo
o`03o`000?oooooooooo02Sooooo0_l0000Booooo`;o00009?ooool2o`0001;ooooo0_l0003?oooo
o`007_ooool00ol0003oooooooooo`0looooo`;o0000>?ooool2o`000<oooooo000Nooooo`03o`00
0?oooooooooo00oooooo0_l0000Pooooo`;o00007_ooool2o`000?Cooooo000Nooooo`03o`000?oo
oooooooo00oooooo0_l0000Pooooo`;o00007_ooool2o`000?Cooooo000Nooooo`03o`000?oooooo
oooo073ooooo0_l00003ooooo`;o0000d?ooool001kooooo00?o0000ooooooooool08_ooool2o`00
04cooooo0_l00003ooooo`;o0000d?ooool001kooooo00?o0000ooooooooool08_ooool2o`0001ko
oooo0_l0003oooooo`Cooooo000Nooooo`;o0000;?ooool2o`0001Gooooo0_l0003oooooo`Cooooo
000Nooooo`03o`000?oooooooooo02_ooooo0_l0001=ooooo`;o0000boooool001kooooo00?o0000
ooooooooool0N_ooool2o`000<_ooooo000Nooooo`03o`000?oooooooooo02[ooooo0_l0003ooooo
oacooooo000Nooooo`03o`000?oooooooooo02[ooooo0_l00011ooooo`;o0000f?ooool001kooooo
00?o0000ooooooooool06Oooool2o`0003gooooo0_l0000Cooooo`;o00006oooool2o`000;_ooooo
000Nooooo`03o`000?oooooooooo01Wooooo0_l0000mooooo`;o0000<?ooool2o`000;_ooooo000N
ooooo`03o`000?oooooooooo03Cooooo0_l0003ooooooa;ooooo000Nooooo`03o`000?oooooooooo
02cooooo0_l00006ooooo`;o00004?ooool2o`000?oooooo000Nooooo`03o`000?oooooooooo02Ko
oooo0_l00004ooooo`;o00006?ooool2o`0004oooooo0_l0002^ooooo`007_ooool00ol0003ooooo
ooooo`0Vooooo`;o0000Koooool2o`000:kooooo000Nooooo`03o`000?oooooooooo04Gooooo0_l0
000gooooo`;o00009Oooool2o`0000Wooooo0_l0002Eooooo`007_ooool00ol0003oooooooooo`15
ooooo`;o000000?oooooo`000?l000007?ooool2o`0001Kooooo0_l0000Uooooo`;o00002Oooool2
o`0009Gooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l0000Fooooo`;o00001oooool2o`00
01cooooo0_l0003Oooooo`007_ooool00ol0003oooooooooo`0Wooooo`?o00004_ooool2o`000003
ooooool0003o00000?oooooo1oooool001kooooo00?o0000ooooooooool0:?ooool2o`0001;ooooo
0_l0000Cooooo`;o0000LOooool2o`00087ooooo000Nooooo`;o00009_ooool2o`0002[ooooo0_l0
001aooooo`;o0000POooool001kooooo00?o0000ooooooooool09Oooool2o`0001gooooo0_l0003o
ooooo`;ooooo000Nooooo`03o`000?oooooooooo04Cooooo0_l0003oooooo`;ooooo000Nooooo`03
o`000?oooooooooo0>_ooooo0_l0001Jooooo`007_ooool00ol0003oooooooooo`1Rooooo`;o0000
1oooool2o`0007kooooo0_l0001Jooooo`007_ooool00ol0003oooooooooo`1Rooooo`;o00001ooo
ool2o`0000Sooooo0_l0003@ooooo`007_ooool00ol0003oooooooooo`1eooooo`;o0000d?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`23ooooo`;o
0000`_ooool001kooooo00?o0000ooooooooool0Poooool2o`00073ooooo0_l00003ooooo`;o0000
Boooool001kooooo00?o0000ooooooooool08oooool2o`000=3ooooo0_l00003ooooo`;o0000Booo
ool001kooooo00?o0000ooooooooool08oooool2o`000?oooooo8oooool001kooooo00?o0000oooo
ooooool09?ooool2o`0000Kooooo0_l0000<ooooo`;o00002Oooool2o`0008;ooooo0_l0001loooo
o`007_ooool00ol0003oooooooooo`0Tooooo`;o00001_ooool2o`000003ooooool0003o000000Wo
oooo0_l00009ooooo`;o0000P_ooool2o`0002Cooooo0_l0000<ooooo`;o0000B?ooool001kooooo
00?o0000ooooooooool0;oooool2o`0003Oooooo0_l0001_ooooo`;o00005?ooool2o`0000cooooo
0_l0000=ooooo`;o0000>Oooool001kooooo00?o0000ooooooooool0=?ooool4o`0000Gooooo0_l0
000Yooooo`;o0000Koooool2o`00037ooooo0_l0000iooooo`007_ooool2o`0003Gooooo1?l00005
ooooo`;o00004?ooool2o`0000Cooooo0_l0001:ooooo`;o0000IOooool2o`0003gooooo000Noooo
o`03o`000?oooooooooo04oooooo0_l00004ooooo`;o0000B_ooool2o`00053ooooo0_l0000Coooo
o`;o0000?Oooool001kooooo00?o0000ooooooooool0e?ooool2o`0000gooooo0_l0000;ooooo`Go
0000D_ooool001kooooo00?o0000ooooooooool0:?ooool3o`00013ooooo0_l0000;ooooo`;o0000
R_ooool2o`0000gooooo0_l0000;ooooo`Co0000Doooool001kooooo00?o0000ooooooooool0:?oo
ool3o`00013ooooo0_l0000;ooooo`;o0000YOooool2o`0002Cooooo0_l0000`ooooo`007_ooool0
0ol0003oooooooooo`0dooooo`;o0000^Oooool2o`0002Cooooo0_l0000`ooooo`007_ooool00ol0
003oooooooooo`0dooooo`;o0000SOooool2o`0002;ooooo0_l0001Nooooo`007_ooool00ol0003o
ooooooooo`33ooooo`;o00008_ooool2o`0000Sooooo0_l0000`ooooo`;o00008_ooool001kooooo
00?o0000ooooooooool0gOooool2o`0001;ooooo0_l0000`ooooo`?o00001Oooool2o`0001[ooooo
000Nooooo`03o`000?oooooooooo0;Sooooo0_l0000Sooooo`;o000000?oooooo`000?l000002ooo
ool2o`0003Gooooo0_l00005ooooo`Go00005oooool001kooooo00?o0000ooooooooool0Eoooool2
o`0001Sooooo0_l00015ooooo`;o00009_ooool2o`0000_ooooo0ol0000Looooo`;o00007_ooool4
o`0001Oooooo000Nooooo`03o`000?oooooooooo03Sooooo0_l0000Mooooo`;o00006?ooool2o`00
07_ooooo0_l0000Looooo`;o0000>Oooool001kooooo00?o0000ooooooooool0>?ooool2o`000;Ko
oooo0_l0000nooooo`;o00005Oooool001kooooo00?o0000ooooooooool0l?ooool2o`0001Kooooo
0_l0000Vooooo`;o00005Oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0GOooool2o`000:Wooooo0_l0000mooooo`000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01_ooool00ol0003oooooooooo`0iooooo`;o00003?ooool2o`0001Cooooo0_l00002ooooo`;o
0000i?ooool000?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo0ol0000iooooo`;o00003?ooool2o`0001Sooooo0_l00026ooooo`;o0000?Oooool2o`0001go
oooo0003ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`03
o`000?oooooooooo0>Wooooo0_l00008ooooo`;o0000<oooool2o`0001gooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0>;o
oooo0_l0000?ooooo`;o0000D_ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool07?ooool2o`000<Cooooo0_l0000^ooooo`;o
0000<oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRH
V?l@41001_ooool00ol0003oooooooooo`0Looooo`;o0000Zoooool2o`0004Oooooo0_l0000coooo
o`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006
ooooo`03o`000?oooooooooo0<Wooooo0_l0000>ooooo`;o0000K?ooool001kooooo00?o0000oooo
ooooool0@?ooool2o`0003_ooooo0_l0001Jooooo`;o0000K?ooool001kooooo00?o0000oooooooo
ool07?ooool2o`0002;ooooo0_l0000/ooooo`;o00003Oooool2o`0009Kooooo0_l0000`ooooo`00
7_ooool00ol0003oooooooooo`0Looooo`;o0000D?ooool2o`0005[ooooo0_l00019ooooo`;o0000
<?ooool001kooooo00?o0000ooooooooool07Oooool2o`000:_ooooo0_l0001@ooooo`;o0000:Ooo
ool001kooooo00?o0000ooooooooool07Oooool2o`000?gooooo0_l0000Looooo`;o00002oooool0
01kooooo00?o0000ooooooooool00_l0001:ooooo`;o0000UOooool2o`0001Cooooo0_l0000ooooo
o`;o00002oooool001kooooo00?o0000ooooooooool00_l0001:ooooo`;o0000H?ooool2o`0000Wo
oooo0_l00004ooooo`;o00008_ooool2o`0000cooooo0_l00006ooooo`;o0000C?ooool001kooooo
00?o0000ooooooooool0IOooool2o`0004Oooooo0_l00009ooooo`;o000000Coooooo`000?l0003o
oooo0_l0000`ooooo`;o0000E?ooool001kooooo00?o0000ooooooooool0IOooool2o`0005Gooooo
0_l0000Pooooo`;o0000=Oooool2o`0002Cooooo0_l0000:ooooo`007_ooool00ol0003ooooooooo
o`3Nooooo`;o0000=Oooool2o`0002Cooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`3`
ooooo`;o00008?ooool2o`0003?ooooo000Nooooo`;o00009?ooool2o`0004Wooooo0_l0001ioooo
o`;o00001Oooool2o`0001oooooo0ol0000cooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o
0000BOooool2o`0007Wooooo0_l0000Vooooo`?o00007?ooool2o`0001Gooooo000Nooooo`03o`00
0?oooooooooo06Wooooo0_l0000Rooooo`;o00001Oooool2o`0009[ooooo0_l0000Eooooo`007_oo
ool00ol0003oooooooooo`02o`0006Oooooo0_l0000Rooooo`;o00001Oooool2o`0009Wooooo0_l0
000Fooooo`007_ooool00ol0003oooooooooo`02o`000?oooooo;?ooool4o`0001Kooooo000Noooo
o`03o`000?oooooooooo0??ooooo0ol0000Nooooo`;o00005oooool2o`0001Sooooo000Nooooo`03
o`000?oooooooooo08gooooo0_l0001Tooooo`?o00007Oooool3o`00037ooooo000Nooooo`03o`00
0?oooooooooo08gooooo0_l00024ooooo`;o0000<_ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`1Tooooo`;o00006?ooool2o`00063ooooo0_l0000^
ooooo`;o0000=Oooool001kooooo00?o0000ooooooooool0I?ooool2o`0001Sooooo0_l0001Poooo
o`;o0000;_ooool2o`0003Gooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0003oooooocko
oooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0003oooooockooooo000Nooooo`03o`000?oo
oooooooo04;ooooo0_l0003oooooo`Cooooo000Nooooo`03o`000?oooooooooo04;ooooo0_l0003o
ooooo`Cooooo000Nooooo`03o`000?oooooooooo03Kooooo0_l0003oooooo`Wooooo0_l00005oooo
o`007_ooool2o`0003Oooooo0_l0001Booooo`;o0000]?ooool2o`0000Gooooo000Nooooo`03o`00
0?oooooooooo08[ooooo0_l00017ooooo`;o0000L_ooool001kooooo00?o0000ooooooooool0Qooo
ool2o`0004[ooooo0_l0001booooo`007_ooool00ol0003oooooooooo`27ooooo`;o00001?ooool2
o`000;Sooooo000Nooooo`03o`000?oooooooooo08gooooo0_l0002hooooo`007_ooool00ol0003o
ooooooooo`2Gooooo`;o00003?ooool2o`000:3ooooo000Nooooo`03o`000?oooooooooo09Oooooo
0_l0000<ooooo`;o0000R?ooool2o`0001Kooooo000Nooooo`03o`000?oooooooooo04_ooooo0_l0
002Booooo`;o00006oooool2o`00037ooooo0_l0000Fooooo`007_ooool00ol0003oooooooooo`1;
ooooo`;o0000J_ooool2o`0002Kooooo0_l0000Kooooo`;o0000BOooool001kooooo00?o0000oooo
ooooool0]oooool2o`0008kooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooo`?ooooo0_l0
0013ooooo`007_ooool00ol0003oooooooooo`3oooooo`?ooooo0_l00013ooooo`007_ooool00ol0
003oooooooooo`3dooooo`;o0000DOooool001kooooo00?o0000ooooooooool0:oooool2o`000<Oo
oooo0_l0001Aooooo`007_ooool2o`0002cooooo0_l0000Sooooo`;o0000mOooool001kooooo00?o
0000ooooooooool0D?ooool2o`0000_ooooo0_l0003Xooooo`007_ooool00ol0003oooooooooo`1M
ooooo`;o0000;Oooool2o`000;Wooooo000Nooooo`03o`000?oooooooooo017ooooo0_l0001ioooo
o`;o0000^Oooool001kooooo00?o0000ooooooooool04Oooool2o`000?oooooo=Oooool001kooooo
00?o0000ooooooooool0:_ooool2o`0002kooooo0_l0003[ooooo`007_ooool00ol0003ooooooooo
o`0Zooooo`;o0000;_ooool2o`000>_ooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool04?oo
ool2o`000?oooooo=_ooool001kooooo00?o0000ooooooooool04?ooool2o`000?oooooo=_ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3ooooo
odSooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`1`ooooo`;o00004?ooool2o`000<?ooooo0003ooooo`05
oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol0001`ooooo`;o00004?ooool2o`00
0<?ooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00007
ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go0000ooooooooooooooooo`00000;
ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0oooooom8ooooo`000oooool0
1Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003ooooooooo
o`3oooooodSooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00
0007ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0;Kooooo0_l0002?oooo
o`007_ooool00ol0003oooooooooo`2fooooo`;o0000Soooool001kooooo00?o0000ooooooooool0
M_ooool2o`000<oooooo000Nooooo`03o`000?oooooooooo07Kooooo0_l0003?ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo04?ooooo0_l0003ooooo
o`?ooooo000Nooooo`03o`000?oooooooooo02cooooo0_l0000Eooooo`;o0000ooooool3ooooo`00
7_ooool00ol0003oooooooooo`0/ooooo`;o0000Boooool2o`000<cooooo000Nooooo`03o`000?oo
oooooooo07Wooooo0_l0003<ooooo`007_ooool00ol0003oooooooooo`10ooooo`;o0000ooooool6
ooooo`007_ooool2o`00047ooooo0_l0003oooooo`Kooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo04oooooo0_l0003fooooo`007_ooool00ol0
003oooooooooo`0Booooo`;o0000>oooool2o`000?Kooooo000Nooooo`03o`000?oooooooooo01;o
oooo0_l0003oooooocCooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo06Kooooo0_l0
003Oooooo`007_ooool00ol0003oooooooooo`1Vooooo`;o0000goooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
QOooool2o`000<3ooooo000Nooooo`03o`000?oooooooooo08Gooooo0_l00030ooooo`007_ooool0
0ol0003oooooooooo`0^ooooo`;o0000oooooolHooooo`007_ooool00ol0003oooooooooo`0^oooo
o`;o0000>_ooool2o`000=_ooooo000Nooooo`03o`000?oooooooooo06[ooooo0_l0003Kooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0003ooooooc;ooooo000Nooooo`03o`00
0?oooooooooo01Cooooo0_l0003ooooooc;ooooo000Nooooo`03o`000?oooooooooo04Gooooo0_l0
000Kooooo`;o00000_ooool2o`000=oooooo000Nooooo`03o`000?oooooooooo04Gooooo0_l0000K
ooooo`;o00000_ooool2o`000=oooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo017ooooo0_l0003oooooocGooooo000Nooooo`03o`000?oooooooooo017o
oooo0_l0003oooooocGooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0F?ooool2o`0001Cooooo0_l0003Gooooo`007_ooool00ol0003oooooooooo`1H
ooooo`;o00005?ooool2o`000=Oooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0NOooool2o`000<cooooo000Nooooo`03o`000?oooooooooo03;ooooo
0_l00015ooooo`;o0000c?ooool001kooooo00?o0000ooooooooool0<_ooool2o`000?oooooo5?oo
ool001kooooo00?o0000ooooooooool03?ooool2o`0001_ooooo0_l0003ooooooagooooo000Noooo
o`03o`000?oooooooooo00cooooo0ol0000Jooooo`;o0000B?ooool2o`0000Gooooo0_l0003;oooo
o`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000
oa0@4?o<c<`01_ooool00ol0003oooooooooo`0=ooooo`;o0000I?ooool2o`0000Gooooo0_l0001T
ooooo`;o0000IOooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0h?ooool2o`0006Gooooo0003
ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo
0ol0001Zooooo`;o0000foooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?nHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1Zooooo`;o0000foooool000?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0
003oooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool00omE
EEGoQhN7ooooo`08ooooo`03o`000?oooooooooo08Cooooo0_l00031ooooo`000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`1`oooo
o`;o00004_ooool2o`000<7ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<
c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo073ooooo0_l0003Eooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo05oooooo0_l0000Sooooo`;o
0000`Oooool001kooooo00?o0000ooooooooool07?ooool2o`00047ooooo0_l0000Sooooo`;o0000
B_ooool2o`0007Gooooo000Nooooo`03o`000?oooooooooo01cooooo0_l00005ooooo`;o00002?oo
ool2o`000:7ooooo0_l0001eooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o00001?ooool6
o`0000;ooooo0_l0001Vooooo`;o0000[?ooool001kooooo00?o0000ooooooooool08oooool2o`00
00Cooooo1?l00004ooooo`;o0000I_ooool2o`000:cooooo000Nooooo`03o`000?oooooooooo02?o
oooo0_l00012ooooo`;o0000g_ooool001kooooo00?o0000ooooooooool0<oooool2o`0003;ooooo
0_l0000@ooooo`;o00005_ooool2o`000;Cooooo000Nooooo`03o`000?oooooooooo01?ooooo0_l0
000Nooooo`;o00005Oooool2o`0002gooooo0_l0000Fooooo`;o0000]?ooool001kooooo00?o0000
ooooooooool03Oooool2o`0000Cooooo0_l0000dooooo`Go0000nOooool001kooooo00?o0000oooo
ooooool03Oooool2o`0000kooooo0_l0000Zooooo`Oo0000@_ooool2o`000;?ooooo000Nooooo`;o
00003?ooool2o`00013ooooo0_l0000Mooooo`;o00003?ooool6o`0002[ooooo0_l0000Fooooo`;o
0000/oooool001kooooo00?o0000ooooooooool02Oooool4o`0002oooooo0_l0000;ooooo`Ko0000
:oooool2o`000<_ooooo000Nooooo`03o`000?oooooooooo00Oooooo1Ol0000Eooooo`;o00009_oo
ool2o`0000;ooooo1?l0003fooooo`007_ooool00ol0003oooooooooo`07ooooo`Go00005Oooool2
o`0002Oooooo0_l00003ooooo`?o0000B_ooool2o`000:Wooooo000Nooooo`03o`000?oooooooooo
00Sooooo0_l0000>ooooo`;o0000<?ooool8o`0004[ooooo0_l0002Yooooo`007_ooool00ol0003o
ooooooooo`0Hooooo`;o00005Oooool2o`0000Gooooo0_l000000ooooooo0000o`00000?ooooo`Ko
0000moooool001kooooo00?o0000ooooooooool0;oooool4o`0000?ooooo0_l000000ooooooo0000
o`00000?ooooo`;o000000?oooooo`000?l000000ol0000:ooooo`?o0000j?ooool001kooooo00?o
0000ooooooooool01oooool2o`0000Kooooo0_l00007ooooo`;o00001_ooool4o`0000gooooo0_l0
000Iooooo`?o000000?oooooo`000?l000000ol00007ooooo`?o0000@?ooool2o`000:Kooooo000N
ooooo`03o`000?oooooooooo00?ooooo0_l00002ooooo`;o00001_ooool2o`0000Oooooo0_l00006
ooooo`Ko00009_ooool2o`0000?ooooo1?l00003ooooo`;o00000oooool2o`0000Gooooo0_l0000i
ooooo`;o0000Y_ooool001kooooo00?o0000ooooooooool00oooool2o`0001oooooo0_l00002oooo
o`;o00002oooool2o`0000Wooooo0_l0000:ooooo`;o00001?ooool2o`0000Cooooo0_l0000:oooo
o`;o00001?ooool2o`0002cooooo0_l0002]ooooo`007_ooool00ol0003oooooooooo`0Tooooo`;o
00000_ooool2o`0000_ooooo1?l00004ooooo`;o000000?oooooo`000?l000004?ooool5o`0001?o
oooo0_l0000/ooooo`;o00001Oooool2o`000003ooooool0003o0000087ooooo0_l0000Pooooo`00
7_ooool01?l0003oooooooooooooool2o`0002Gooooo0_l0000=ooooo`;o000000?oooooo`000?l0
00000ol0000>ooooo`Go00000_ooool4o`0003oooooo0_l000000ooooooo0000o`000003ooooo`;o
000000?oooooo`000?l00000POooool2o`0001Oooooo0_l00007ooooo`007_ooool01?l0003ooooo
ooooooooool2o`0002_ooooo0_l00005ooooo`;o00000oooool4o`0000oooooo2ol0000Fooooo`;o
00009oooool2o`000003ooooool0003o00000:;ooooo0_l00007ooooo`007_ooool00ol0003ooooo
ooooo`0^ooooo`;o00001Oooool2o`0000?ooooo0_l0000>ooooo`Co00000oooool7o`0001Kooooo
0_l0000Wooooo`;o0000Xoooool3o`0000Sooooo000Nooooo`03o`000?oooooooooo03[ooooo0_l0
000>ooooo`Co000000?oooooo`000?l000000ol00002ooooo`Co00002?ooool2o`0002[ooooo0_l0
0007ooooo`;o00001oooool2o`0009[ooooo0ol00008ooooo`007_ooool3o`0003[ooooo0_l0000C
ooooo`Ko00000oooool2o`0000Sooooo0_l0000Zooooo`;o00004?ooool2o`000:Gooooo000Noooo
o`?o0000>_ooool2o`0000Cooooo0_l0000=ooooo`?o000000?oooooo`000?l000000ol000000ooo
oooo0000o`000002ooooo`;o00006_ooool2o`000<cooooo000Nooooo`03o`000?oooooooooo02[o
oooo0_l0000=ooooo`;o00001Oooool2o`0000cooooo1?l00003ooooo`?o000000?oooooo`000?l0
00001?l0000=ooooo`;o00002oooool2o`000<cooooo000Nooooo`03o`000?oooooooooo02[ooooo
0_l0000=ooooo`;o00004oooool6o`0000;ooooo1ol0000?ooooo`;o00000oooool2o`000=Cooooo
000Nooooo`03o`000?oooooooooo00Wooooo0_l00013ooooo`;o000000Goooooo`000?l0003o0000
ooooo`04o`000004ooooool0003o0000o`0000?ooooo0_l0000?ooooo`;o00002oooool2o`0001co
oooo0_l0002Mooooo`;o00002_ooool001kooooo00?o0000ooooooooool02Oooool2o`0002[ooooo
0_l00004ooooo`;o00004?ooool4o`0000Cooooo3Ol0000Jooooo`Co00007?ooool2o`0009gooooo
0_l0000:ooooo`007_ooool00ol0003oooooooooo`0eooooo`Co00000_ooool2o`00013ooooo1ol0
0002ooooo`[o00007?ooool2o`0000;ooooo0_l0000Booooo`;o000000?oooooo`000?l00000[_oo
ool001kooooo00?o0000ooooooooool0<oooool2o`0000;ooooo0_l000000ooooooo0000o`000009
ooooo`;o00002?ooool5o`0000;ooooo0ol00002ooooo`;o000000?oooooo`000?l000005Oooool2
o`0000Cooooo0_l00003ooooo`;o00004_ooool5o`000:kooooo000Nooooo`03o`000?oooooooooo
03?ooooo0_l00005ooooo`?o000000?oooooo`000?l000001Oooool2o`0000Wooooo0ol00004oooo
o`Go00006Oooool2o`0000Cooooo0_l0000Hooooo`;o00000_ooool2o`000:cooooo000Nooooo`03
o`000?oooooooooo027ooooo0_l0000Hooooo`;o000000Coooooo`000?l0003o00003oooool3o`00
00;ooooo0_l00002ooooo`?o000000?oooooo`000?l000000_l0000@ooooo`;o00007oooool2o`00
0003ooooool0003o000000;ooooo0_l0002/ooooo`007_ooool00ol0003oooooooooo`0Qooooo`;o
00006oooool3o`0000Cooooo0_l00009ooooo`;o000000?oooooo`000?l000000_l000000ooooooo
0000o`000002o`000003ooooool0003o000000Co00001Oooool2o`0000Oooooo0_l0000=ooooo`;o
00001Oooool2o`0000Wooooo0_l000000ooooooo0000o`00002`ooooo`007_ooool00ol0003ooooo
ooooo`15ooooo`;o00002Oooool2o`000003ooooool0003o000000?ooooo0_l00003ooooo`?o0000
00?oooooo`000?l000001Oooool2o`0001Kooooo0_l00005ooooo`;o00003?ooool2o`000;3ooooo
000Nooooo`04o`000?ooooooooooooooo`;o0000:_ooool2o`0001_ooooo0_l00004ooooo`;o0000
2oooool5o`0001Kooooo0_l00005ooooo`;o00001oooool2o`0000_ooooo0_l0002`ooooo`007_oo
ool3o`000003ooooool0003o000002[ooooo0_l00004ooooo`;o00005Oooool2o`0000Cooooo0_l0
0002ooooo`;o00002?ooool6o`0001?ooooo0ol00005ooooo`;o000000?oooooo`000?l000000_oo
ool4o`0000Sooooo0_l0002cooooo`007_ooool3o`0001_ooooo0_l0000@ooooo`;o00001?ooool2
o`0000gooooo0_l00007ooooo`?o00001_ooool3o`0000Sooooo1Ol0000Cooooo`;o00001?ooool2
o`0000?ooooo0_l00002ooooo`Co00002?ooool2o`000;?ooooo000Nooooo`03o`000?oooooooooo
00Kooooo0_l0000Cooooo`;o00004?ooool3o`0001;ooooo1?l00003ooooo`Go000000?oooooo`00
0?l000000ol000000ooooooo0000o`000002o`0000Wooooo0_l0000Iooooo`;o00002Oooool2o`00
00Wooooo0_l0002booooo`007_ooool00ol0003oooooooooo`06ooooo`;o00009_ooool2o`0001Co
oooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo1ol000000ooooooo0000o`000004oooo
o`;o00000oooool2o`0002_ooooo0_l00002ooooo`;o0000/_ooool001kooooo0_l00015ooooo`?o
00001Oooool2o`0000Cooooo1?l00002ooooo`;o00000oooool2o`0000?ooooo0_l0000<ooooo`;o
00006Oooool2o`0000;ooooo1?l000000ooooooo0000o`00002Wooooo`;o00002?ooool001kooooo
00?o0000ooooooooool03?ooool2o`0003?ooooo1_l00002ooooo`;o000000?oooooo`000?l00000
1?ooool2o`0000;ooooo1Ol00002ooooo`Co00002oooool2o`0000;ooooo0_l0000<ooooo`;o0000
2oooool2o`0000Cooooo1Ol0002Tooooo`;o000000?oooooo`000?l000002?ooool001kooooo00?o
0000ooooooooool03?ooool2o`0003?ooooo1_l00002ooooo`;o00001oooool2o`0000;ooooo0_l0
00000ooooooo0000o`000002ooooo`Co00000_ooool2o`0000;ooooo0_l00003ooooo`;o00004?oo
ool3o`0001;ooooo0_l0002Uooooo`;o00002oooool001kooooo00?o0000ooooooooool0A?ooool2
o`0000;ooooo0ol00002ooooo`;o00000oooool3o`000005ooooool0003o0000o`000?ooool03?l0
00000ooooooo0000o`00000@ooooo`;o00001?ooool2o`0000Cooooo0_l00030ooooo`007_ooool0
0ol0003oooooooooo`10ooooo`;o000000Coooooo`000?l0003ooooo2Ol00002ooooo`Co000000?o
ooooo`000?l000002?l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l0000?ooooo`;o0000
2_ooool2o`0000Wooooo0_l0000;ooooo`;o0000Z?ooool001kooooo00?o0000ooooooooool00ooo
ool2o`00027ooooo0_l0000Hooooo`ko00000oooool4o`000003ooooool0003o000000Ko00000_oo
ool4o`000004ooooool0003o0000ooooo`;o00009_ooool2o`0000Oooooo0_l00002ooooo`;o0000
Z?ooool001kooooo00?o0000ooooooooool00oooool2o`00027ooooo0_l0000Iooooo`;o00000_oo
ool4o`000003ooooool0003o000000Oooooo0_l000000ooooooo0000o`000003o`0000Gooooo1?l0
00000ooooooo0000o`000002ooooo`?o00007_ooool2o`0000Cooooo0ol00006ooooo`Co0000Z_oo
ool001kooooo00?o0000ooooooooool04Oooool2o`0001;ooooo0ol0000Mooooo`;o00000oooool2
o`000004ooooool0003o0000o`0000?ooooo0_l000000ooooooo0000o`000003o`0000Gooooo0_l0
0003ooooo`;o00000_ooool3o`0001kooooo0_l00004ooooo`Co00001Oooool4o`0000;ooooo0_l0
002Vooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o00004_ooool2o`0001oooooo0_l00000
0ooooooo0000o`000006o`0000Gooooo0ol0000<ooooo`?o0000:_ooool2o`0000Gooooo0ol00003
ooooo`;o0000Y_ooool001kooooo00?o0000ooooooooool04Oooool2o`0003?ooooo0_l000000ooo
oooo0000o`000006o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o00001Oooool2o`00
00;ooooo0_l0000Cooooo`;o0000b_ooool001kooooo00?o0000ooooooooool06oooool2o`000003
ooooool0003o000000Kooooo0_l00003ooooo`;o00003?ooool2o`0000Oooooo0_l00004ooooo`So
00000oooool3o`000004ooooool0003o0000ooooo`Go00000oooool2o`0000Gooooo0_l0000@oooo
o`;o0000b_ooool001kooooo00?o0000ooooooooool06oooool2o`000003ooooool0003o000000Ko
oooo0_l00003ooooo`;o00002Oooool2o`000003ooooool0003o000000Oooooo1?l00002ooooo`;o
00000_ooool6o`000004ooooool0003o0000o`0000Cooooo1Ol00003ooooo`;o000000?oooooo`00
0?l000001?l0000@ooooo`;o00004_ooool2o`000;Kooooo000Nooooo`03o`000?oooooooooo03Ko
oooo0_l0000<ooooo`;o00001_ooool2o`000003ooooool0003o000000Co00001?ooool2o`000004
ooooool0003o0000o`0000?ooooo0_l000000ooooooo0000o`000003o`00017ooooo0_l0000;oooo
o`;o00001Oooool2o`000;Kooooo000Nooooo`03o`000?oooooooooo03[ooooo1Ol0000:ooooo`Co
00000oooool3o`0000;ooooo1_l00002ooooo`;o00001_ooool6o`0001gooooo0_l00004ooooo`?o
0000]_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co
8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0<oooool2o`0000Gooooo1ol00008oooo
o`Co00000oooool9o`0000?ooooo0ol00008ooooo`Go00002Oooool2o`0001Oooooo0_l0000Eoooo
o`;o0000X?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ
8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0<oooool2o`0000Gooooo0_l00003
ooooo`;o00003_ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000000oooool2
o`0000Wooooo1Ol00009ooooo`;o0000;_ooool2o`000:3ooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0000hooooo`;o000000?o
ooooo`000?l000002oooool2o`0000Gooooo0_l00002ooooo`Go00000_ooool5o`0003Gooooo0_l0
002aooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RH
oc8b<P06ooooo`03o`000?oooooooooo01;ooooo0_l0000=ooooo`;o00001_ooool2o`0000gooooo
0_l000000ooooooo0000o`000003ooooo`;o00001_ooool2o`0000Kooooo2?l00002ooooo`Go0000
1?ooool2o`0002?ooooo1?l000000ooooooo0000o`000005ooooo`?o00003oooool3o`0009kooooo
0003ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Ko
oooo00?o0000ooooooooool04_ooool2o`0000_ooooo1?l00006ooooo`;o00005?ooool3o`0000Go
oooo0_l00003ooooo`;o00000_ooool8o`0000Kooooo0_l00003ooooo`;o00008oooool7o`0000Ko
oooo0_l0000?ooooo`?o0000W_ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05
oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`0Oooooo`;o00002oooool2o`00
00;ooooo0_l00008ooooo`;o00000oooool6o`0000;ooooo0_l00003ooooo`;o00000oooool4o`00
0003ooooool0003o000000Kooooo0_l0000Sooooo`;o00001Oooool4o`0001kooooo0_l0002Ioooo
o`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006
ooooo`03o`000?oooooooooo02cooooo0_l00002ooooo`;o00001oooool3o`0000Cooooo1ol00008
ooooo`;o00000_ooool2o`000003ooooool0003o000000?o0000:?ooool2o`0000Gooooo0ol0000O
ooooo`;o0000VOooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o
0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`0iooooo`;o00000_ooool3o`0000Gooooo0_l0
0008ooooo`;o000000?oooooo`000?l000000oooool4o`00033ooooo1?l00005ooooo`;o00005?oo
ool2o`0009_ooooo000Nooooo`03o`000?oooooooooo02Kooooo0_l0000Eooooo`?o00000oooool2
o`0000gooooo0_l00005ooooo`;o00005oooool2o`0001Sooooo0ol00005ooooo`;o00003Oooool2
o`0000Gooooo0_l0002Kooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o00006Oooool2o`00
01Gooooo1?l00002ooooo`;o00002_ooool2o`0000Sooooo0_l0000Gooooo`;o00002?ooool2o`00
00_ooooo0_l000000ooooooo0000o`00000Eooooo`;o00001Oooool2o`0009_ooooo000Nooooo`03
o`000?oooooooooo00_ooooo0_l0000`ooooo`Co00000_ooool2o`0000[ooooo0ol00008ooooo`;o
00008?ooool2o`0000_ooooo0_l000000ooooooo0000o`000006ooooo`;o00001Oooool2o`0000_o
oooo0ol00005ooooo`;o0000UOooool001kooooo00?o0000ooooooooool07?ooool2o`0000gooooo
0_l0000@ooooo`?o00000oooool2o`0000_ooooo0_l00007ooooo`Co00006Oooool2o`0001[ooooo
1?l00005ooooo`;o00002oooool3o`0000Gooooo0_l0002Eooooo`007_ooool00ol0003ooooooooo
o`0<ooooo`;o00003_ooool2o`0000gooooo0_l00003ooooo`;o00002Oooool3o`0000Cooooo0_l0
0007ooooo`;o00001oooool2o`000003ooooool0003o000000Co00001oooool2o`00013ooooo0_l0
0002ooooo`;o00001?ooool2o`00013ooooo0_l0002cooooo`007_ooool00ol0003oooooooooo`0<
ooooo`;o00008_ooool2o`0000Wooooo0ol00002ooooo`Co00001_ooool3o`0000Oooooo0_l00000
1?oooooo0000o`000?l00003ooooo`;o00001Oooool2o`0001Cooooo0_l00002ooooo`Co00000_oo
ool2o`0001_ooooo0_l0002Tooooo`007_ooool00ol0003oooooooooo`0mooooo`;o000000Cooooo
o`000?l0003ooooo0_l00004ooooo`?o00000oooool2o`0000cooooo0ol0000Nooooo`?o00000ooo
ool2o`0000Wooooo0_l0000@ooooo`;o0000Y?ooool001kooooo00?o0000ooooooooool0=?ooool2
o`0000Oooooo0ol00003ooooo`;o00001?ooool2o`0000Cooooo0_l0000=ooooo`;o00007oooool2
o`0000kooooo0_l0002fooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o00004_ooool2o`00
00;ooooo0_l00002ooooo`;o00001Oooool5o`0000?ooooo0_l0000;ooooo`;o00001oooool2o`00
0>cooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l0000;ooooo`?o00004Oooool2o`0000;o
oooo0_l00009ooooo`?o00000_ooool2o`000003ooooool0003o000000;o00000_ooool2o`0000Go
oooo0_l00005ooooo`Co0000k?ooool001kooooo00?o0000ooooooooool02?ooool2o`000003oooo
ool0003o000000cooooo0_l0000Uooooo`?o000000?oooooo`000?l000003?l00003ooooo`Co0000
2Oooool2o`000>?ooooo000Nooooo`;o00002Oooool2o`0001Wooooo0_l0000Looooo`oo00001Ooo
ool2o`000003ooooool0003o000000;o000000?oooooo`000?l000000oooool2o`000>?ooooo000N
ooooo`03o`000?oooooooooo01[ooooo0_l00005ooooo`Co00007_ooool4o`0000Gooooo2?l00004
ooooo`Co000000?oooooo`000?l00000j?ooool001kooooo00?o0000ooooooooool05Oooool2o`00
00?ooooo0_l00005ooooo`;o00008Oooool4o`0000Gooooo1ol00005ooooo`;o00001?ooool2o`00
0>Kooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l000000ooooooo0000o`00000Wooooo`;o
00001_ooool2o`0000Gooooo0_l0000:ooooo`?o00000oooool2o`0000Oooooo0_l0003Mooooo`00
7_ooool00ol0003oooooooooo`0Booooo`;o00008_ooool2o`0000Kooooo0_l0000Aooooo`;o0000
1oooool2o`000003ooooool0003o000000Gooooo0_l00002ooooo`;o00004?ooool2o`000<_ooooo
000Nooooo`03o`000?oooooooooo00Sooooo0_l0000=ooooo`;o00007Oooool3o`0000Gooooo0_l0
000=ooooo`;o00000_ooool2o`0000?ooooo0_l00003ooooo`Co00001Oooool2o`0001Cooooo0_l0
003;ooooo`007_ooool01?l0003oooooooooooooool4o`0000?ooooo0_l0000=ooooo`;o00007_oo
ool2o`0000Gooooo0_l0000:ooooo`Go00000oooool2o`0000;ooooo0_l00003ooooo`;o00004ooo
ool2o`000=Gooooo000Nooooo`04o`000?ooooooooooooooo`Co00003oooool2o`0000kooooo0_l0
000Tooooo`?o00001Oooool2o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o00004?oo
ool2o`000=Gooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0000>ooooo`;o0000;oooool2
o`000003ooooool0003o000000;o00000_ooool2o`000>Oooooo000Nooooo`03o`000?oooooooooo
04_ooooo0_l0000;ooooo`;o00000oooool3o`000>Oooooo000Nooooo`03o`000?oooooooooo04Wo
oooo1?l0000@ooooo`;o00002Oooool2o`000=gooooo000Nooooo`03o`000?oooooooooo00Kooooo
0_l000000ooooooo0000o`00000nooooo`Co00006oooool2o`0001Wooooo0_l00005ooooo`;o0000
^oooool001kooooo00?o0000ooooooooool01_ooool2o`000003ooooool0003o000004Wooooo0_l0
000]ooooo`;o00001Oooool2o`0000_ooooo0_l0002^ooooo`007_ooool00ol0003oooooooooo`0g
ooooo`;o00002_ooool2o`000003ooooool0003o000000Gooooo0_l00005ooooo`;o00001_ooool2
o`0003Wooooo0_l0002^ooooo`007_ooool00ol0003oooooooooo`0gooooo`;o00002_ooool2o`00
0003ooooool0003o000000Gooooo0_l00004ooooo`;o00001?ooool5o`000>Wooooo000Nooooo`03
o`000?oooooooooo00Kooooo0_l0000jooooo`?o00000_ooool2o`0000[ooooo0_l00004ooooo`Co
0000j_ooool001kooooo0_l00007ooooo`;o0000>_ooool2o`0000?ooooo0_l00006ooooo`?o0000
1?ooool2o`0000?ooooo0_l0003Zooooo`007_ooool00ol0003oooooooooo`12ooooo`;o00002_oo
ool6o`0000;ooooo0_l0003_ooooo`007_ooool00ol0003oooooooooo`12ooooo`;o00002_ooool2
o`0000;ooooo0_l00002ooooo`;o0000koooool001kooooo00?o0000ooooooooool0E_ooool2o`00
0>oooooo000Nooooo`03o`000?oooooooooo05Sooooo0_l0003]ooooo`007_ooool00ol0003ooooo
ooooo`14ooooo`;o00004_ooool2o`00037ooooo0_l000000ooooooo0000o`00002gooooo`007_oo
ool00ol0003oooooooooo`0^ooooo`;o00005?ooool2o`0004Gooooo0_l000000ooooooo0000o`00
002gooooo`007_ooool00ol0003oooooooooo`0]ooooo`?o00007oooool3o`000?Gooooo000Noooo
o`03o`000?oooooooooo02gooooo0_l0000Nooooo`Go0000mOooool001kooooo00?o0000oooooooo
ool0COooool2o`0000?ooooo0ol0003booooo`007_ooool00ol0003oooooooooo`0Nooooo`;o0000
<_ooool3o`0000Sooooo0_l0003Xooooo`007_ooool00ol0003oooooooooo`02ooooo`;o00005_oo
ool2o`0000;ooooo0_l0000Zooooo`Co00003oooool2o`000>Sooooo000Nooooo`03o`000?oooooo
oooo00;ooooo0_l0000Fooooo`;o0000;_ooool4o`0002Kooooo0_l0003Aooooo`007_ooool00ol0
003oooooooooo`0:ooooo`;o0000J?ooool2o`000=7ooooo000Nooooo`03o`000?oooooooooo00[o
oooo0_l0003ooooooccooooo000Nooooo`03o`000?oooooooooo02cooooo0_l0003ooooooa[ooooo
000Nooooo`;o0000;Oooool2o`0004oooooo0_l00038ooooo`007_ooool00ol0003oooooooooo`0l
ooooo`;o0000?oooool2o`0000Cooooo0_l00032ooooo`007_ooool00ol0003oooooooooo`0loooo
o`;o00008oooool2o`00023ooooo1?l00030ooooo`007_ooool00ol0003oooooooooo`1Qooooo`;o
00004Oooool2o`0000oooooo0_l00030ooooo`007_ooool00ol0003oooooooooo`1dooooo`;o0000
dOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`1m
ooooo`;o0000b?ooool001kooooo00?o0000ooooooooool0OOooool2o`0000Cooooo0_l00032oooo
o`007_ooool00ol0003oooooooooo`23ooooo`;o0000`_ooool001kooooo00?o0000ooooooooool0
:Oooool2o`0005gooooo0_l0002mooooo`007_ooool00ol0003oooooooooo`0Yooooo`;o00002?oo
ool2o`0005?ooooo0_l0002mooooo`007_ooool00ol0003oooooooooo`0cooooo`;o0000oooooolC
ooooo`007_ooool00ol0003oooooooooo`26ooooo`;o0000_oooool001kooooo00?o0000oooooooo
ool0Q_ooool2o`000;oooooo000Dooooo`Co000000?o410@ooooooooool00oooool00ol0003ooooo
ooooo`0fooooo`;o0000ooooool@ooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo03Kooooo0_l0003ooooooa3ooooo000Fooooo`03o`000?oooooooooo00Gooooo0ol0003o
ooooodSooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000oooooooo
ool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oo
oooooooo0?ooooooD?ooool001Cooooo00?oEEEEofIVI_l00000oooooomBooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.20376 .82712 Mdot
.21683 .37955 Mdot
.19529 .88988 Mdot
.21531 .70027 Mdot
.32782 .87525 Mdot
.26814 .6826 Mdot
.0681 .97922 Mdot
.26656 .8806 Mdot
.2974 .68095 Mdot
.53481 .35998 Mdot
.25692 .57863 Mdot
.30528 .62741 Mdot
.24988 .89144 Mdot
.99656 .72069 Mdot
.22808 .70549 Mdot
.15583 .72422 Mdot
.26013 .54842 Mdot
.29403 .88896 Mdot
.20871 .88157 Mdot
.2348 .64279 Mdot
.51545 .74592 Mdot
.27291 .64192 Mdot
.33599 .87637 Mdot
.31617 .14159 Mdot
.28574 .71155 Mdot
.25139 .87936 Mdot
.23124 .74477 Mdot
.09018 .67157 Mdot
.26333 .57804 Mdot
.23996 .6245 Mdot
.23776 .89587 Mdot
.23759 .70616 Mdot
.31797 .65392 Mdot
.54809 .75175 Mdot
.4482 .86474 Mdot
.21222 .73525 Mdot
.98692 .71837 Mdot
.45746 .68253 Mdot
.29186 .7559 Mdot
.25967 .75765 Mdot
.22673 .89395 Mdot
.32719 .80563 Mdot
.28435 .69534 Mdot
.44745 .65964 Mdot
.11069 .73839 Mdot
.32893 .76917 Mdot
.18001 .35548 Mdot
.31718 .7894 Mdot
.21161 .75256 Mdot
.24615 .97929 Mdot
.31309 .67264 Mdot
.41323 .90001 Mdot
.28956 .91602 Mdot
.21336 .74369 Mdot
.30605 .92927 Mdot
.32385 .0125 Mdot
.74145 .14372 Mdot
.2636 .89273 Mdot
.22674 .74342 Mdot
.29051 .82592 Mdot
.21527 .69625 Mdot
.26229 .86842 Mdot
.08927 .88382 Mdot
.29913 .69636 Mdot
.29732 .78795 Mdot
.28828 .66147 Mdot
.29519 .95831 Mdot
.22872 .74544 Mdot
.25493 .67776 Mdot
.82771 .17225 Mdot
.38846 .97294 Mdot
.28438 .82703 Mdot
.33965 .63612 Mdot
.26207 .62153 Mdot
.32132 .63991 Mdot
.41092 .23854 Mdot
.21369 .983 Mdot
.28379 .97765 Mdot
.23572 .72233 Mdot
.19933 .93235 Mdot
.36971 .7814 Mdot
.19902 .15472 Mdot
.47351 .6855 Mdot
.2623 .87562 Mdot
.94088 .13186 Mdot
.45502 .88767 Mdot
.29125 .88435 Mdot
.21056 .72703 Mdot
.24379 .69444 Mdot
.28685 .83062 Mdot
.26797 .62178 Mdot
.87475 .21054 Mdot
.24964 .96891 Mdot
.35051 .81405 Mdot
.28288 .85331 Mdot
.36473 .80319 Mdot
.12859 .84207 Mdot
.43382 .87827 Mdot
.3111 .73356 Mdot
.48132 .82271 Mdot
.2213 .78745 Mdot
.31089 .69713 Mdot
.18655 .8627 Mdot
.04845 .71999 Mdot
.20523 .36467 Mdot
.34157 .87052 Mdot
.18315 .71779 Mdot
.1502 .7125 Mdot
.37577 .91262 Mdot
.17728 .04218 Mdot
.99831 .71182 Mdot
.41285 .56373 Mdot
.24254 .72101 Mdot
.26914 .89446 Mdot
.12563 .77414 Mdot
.05494 .09871 Mdot
.12567 .74608 Mdot
.23918 .88743 Mdot
.47329 .37932 Mdot
.10938 .80389 Mdot
.21864 .74739 Mdot
.29315 .79411 Mdot
.3056 .6334 Mdot
.35335 .84364 Mdot
.9713 .25953 Mdot
.50914 .79172 Mdot
.34333 .69375 Mdot
.22303 .85242 Mdot
.56827 .77136 Mdot
.38042 .63962 Mdot
.48377 .81308 Mdot
.2012 .01871 Mdot
.25734 .69478 Mdot
.32662 .86209 Mdot
.28889 .87822 Mdot
.29119 .97232 Mdot
.34993 .8714 Mdot
.24805 .76977 Mdot
.18426 .88663 Mdot
.28701 .67358 Mdot
.23504 .8578 Mdot
.30303 .69828 Mdot
.30326 .64911 Mdot
.44454 .81554 Mdot
.16499 .98854 Mdot
.31445 .62894 Mdot
.25791 .80767 Mdot
.23734 .77207 Mdot
.73325 .16067 Mdot
.14568 .09333 Mdot
.056 .78466 Mdot
.31493 .64941 Mdot
.28338 .62995 Mdot
.23675 .6317 Mdot
.22195 .71371 Mdot
.2444 .88384 Mdot
.2357 .75719 Mdot
.78501 .0927 Mdot
.28382 .6953 Mdot
.19719 .73465 Mdot
.26964 .80428 Mdot
.46475 .85323 Mdot
.40817 .84803 Mdot
.3311 .85326 Mdot
.30838 .74625 Mdot
.33214 .88514 Mdot
.24615 .77347 Mdot
.26152 .72 Mdot
.14523 .02718 Mdot
.34307 .8526 Mdot
.28845 .62291 Mdot
.40764 .78686 Mdot
.45967 .86486 Mdot
.48031 .2616 Mdot
.20467 .84211 Mdot
.23526 .6858 Mdot
.53883 .75103 Mdot
.21678 .89468 Mdot
.09846 .96098 Mdot
.42371 .89354 Mdot
.26165 .70695 Mdot
.3248 .64254 Mdot
.21873 .75688 Mdot
.15116 .6522 Mdot
.60348 .11911 Mdot
.25338 .77013 Mdot
.2057 .73983 Mdot
.27178 .64003 Mdot
.98171 .68381 Mdot
.45208 .74919 Mdot
.21213 .846 Mdot
.4438 .90416 Mdot
.22119 .84008 Mdot
.18903 .62725 Mdot
.15147 .79777 Mdot
.28115 .6797 Mdot
.46189 .84394 Mdot
.30036 .61491 Mdot
.30005 .67865 Mdot
.31993 .64378 Mdot
.14238 .67001 Mdot
.05175 .66054 Mdot
.31576 .87009 Mdot
.1315 .68251 Mdot
.28728 .70913 Mdot
.21031 .72321 Mdot
.10568 .11141 Mdot
.21214 .7325 Mdot
.9748 .14273 Mdot
.10248 .68706 Mdot
.34702 .85938 Mdot
.23101 .83832 Mdot
.04847 .22821 Mdot
.50888 .03999 Mdot
.25352 .7842 Mdot
.38477 .85905 Mdot
.26271 .76655 Mdot
.42243 .43571 Mdot
.20536 .67061 Mdot
.26235 .95367 Mdot
.75902 .1308 Mdot
.29196 .86042 Mdot
.30506 .70328 Mdot
.26313 .70873 Mdot
.28642 .84677 Mdot
.29081 .80855 Mdot
.43943 .70333 Mdot
.32505 .9212 Mdot
.54357 .16897 Mdot
.30024 .65085 Mdot
.23907 .87484 Mdot
.2955 .81204 Mdot
.30954 .64753 Mdot
.44265 .66946 Mdot
.38153 .83773 Mdot
.57072 .23593 Mdot
.52481 .41554 Mdot
.23556 .89505 Mdot
.48236 .72933 Mdot
.69932 .22604 Mdot
.2033 .93398 Mdot
.30254 .64015 Mdot
.29539 .73497 Mdot
.18163 .92108 Mdot
.27992 .75661 Mdot
.21019 .98777 Mdot
.29446 .84853 Mdot
.27525 .62028 Mdot
.24363 .23761 Mdot
.22039 .89123 Mdot
.40778 .90974 Mdot
.33202 .90186 Mdot
.7867 .3354 Mdot
.45944 .91992 Mdot
.96814 .26797 Mdot
.28397 .7808 Mdot
.307 .90143 Mdot
.44585 .76367 Mdot
.41393 .77174 Mdot
.11492 .74659 Mdot
.22374 .82194 Mdot
.29464 .80028 Mdot
.29843 .82249 Mdot
.38666 .78259 Mdot
.3073 .64618 Mdot
.47754 .80668 Mdot
.27181 .72436 Mdot
.48183 .31508 Mdot
.23512 .89096 Mdot
.24807 .74964 Mdot
.30927 .73508 Mdot
.3722 .27504 Mdot
.21849 .6771 Mdot
.31738 .78963 Mdot
.3732 .77058 Mdot
.34308 .88628 Mdot
.22514 .68437 Mdot
.16434 .78956 Mdot
.21247 .74292 Mdot
.29631 .69119 Mdot
.75337 .18961 Mdot
.27565 .63464 Mdot
.33738 .84574 Mdot
.98062 .74527 Mdot
.32317 .88629 Mdot
.30393 .70326 Mdot
.33324 .85811 Mdot
.46125 .85396 Mdot
.26343 .80502 Mdot
.26711 .59129 Mdot
.2764 .74425 Mdot
.89972 .2166 Mdot
.21311 .88165 Mdot
.19954 .63214 Mdot
.12489 .95154 Mdot
.46414 .86184 Mdot
.271 .79528 Mdot
.22063 .74766 Mdot
.74953 .22564 Mdot
.28343 .15946 Mdot
.45971 .84932 Mdot
.32981 .69498 Mdot
.45216 .84829 Mdot
.30095 .83924 Mdot
.46524 .35337 Mdot
.33603 .94429 Mdot
.23505 .74201 Mdot
.22031 .72305 Mdot
.08269 .30196 Mdot
.05941 .62226 Mdot
.21497 .74042 Mdot
.74383 .24168 Mdot
.25067 .87616 Mdot
.25394 .95531 Mdot
.30097 .75903 Mdot
.22627 .79955 Mdot
.26098 .71423 Mdot
.48064 .24618 Mdot
.3264 .66356 Mdot
.28846 .49236 Mdot
.28279 .75845 Mdot
.31744 .64716 Mdot
.3052 .67161 Mdot
.16992 .73867 Mdot
.26193 .89376 Mdot
.23586 .87641 Mdot
.21224 .74306 Mdot
.23132 .82106 Mdot
.31809 .63792 Mdot
.24761 .86993 Mdot
.25045 .63656 Mdot
.2681 .67015 Mdot
.12238 .931 Mdot
.18223 .26424 Mdot
.42675 .58505 Mdot
.25284 .87154 Mdot
.61073 .63182 Mdot
.23091 .75178 Mdot
.71723 .01993 Mdot
.48823 .80969 Mdot
.30477 .73534 Mdot
.6801 .59661 Mdot
.2419 .83965 Mdot
.29726 .8343 Mdot
.73368 .07425 Mdot
.98491 .81793 Mdot
.12998 .03542 Mdot
.19343 .10741 Mdot
.40966 .85033 Mdot
.27008 .88287 Mdot
.22971 .88719 Mdot
.31855 .90357 Mdot
.49499 .73208 Mdot
.07609 .69521 Mdot
.08582 .01918 Mdot
.21809 .68354 Mdot
.3429 .8125 Mdot
.32356 .856 Mdot
.26253 .89353 Mdot
.38867 .50501 Mdot
.28065 .62982 Mdot
.51019 .75359 Mdot
.23014 .89541 Mdot
.34894 .86094 Mdot
.31738 .69486 Mdot
.48229 .74293 Mdot
.00021 .79962 Mdot
.37796 .66455 Mdot
.66471 .20986 Mdot
.24821 .64208 Mdot
.26022 .79298 Mdot
.24309 .73767 Mdot
.2039 .88639 Mdot
.29753 .6623 Mdot
.40916 .75302 Mdot
.4844 .82159 Mdot
.09445 .76559 Mdot
.2113 .74194 Mdot
.15514 .21485 Mdot
.24328 .60715 Mdot
.24277 .71596 Mdot
.22269 .69195 Mdot
.6475 .1424 Mdot
.9624 .27239 Mdot
.11603 .66436 Mdot
.1625 .65237 Mdot
.00977 .76844 Mdot
.06175 .68981 Mdot
.23379 .74941 Mdot
.01125 .72669 Mdot
.23616 .86193 Mdot
.30891 .88131 Mdot
.20112 .79637 Mdot
.29621 .88384 Mdot
.31606 .87521 Mdot
.12182 .10979 Mdot
.29384 .63396 Mdot
.41711 .99228 Mdot
.22288 .74283 Mdot
.24848 .89049 Mdot
.30291 .67286 Mdot
.04827 .80325 Mdot
.79436 .11187 Mdot
.26129 .86975 Mdot
.00513 .79215 Mdot
.50286 .72999 Mdot
.25907 .59683 Mdot
.28022 .83219 Mdot
.30966 .82798 Mdot
.33339 .85251 Mdot
.26385 .79517 Mdot
.27539 .70931 Mdot
.2657 .80252 Mdot
.04117 .01436 Mdot
.69136 .16621 Mdot
.31961 .86901 Mdot
.18412 .86631 Mdot
.28599 .80546 Mdot
.76691 .10038 Mdot
.23038 .72366 Mdot
.25807 .74161 Mdot
.11185 .28704 Mdot
.54506 .2364 Mdot
.31669 .87603 Mdot
.26026 .89059 Mdot
.13939 .37633 Mdot
.16804 .64715 Mdot
.30037 .66746 Mdot
.28515 .82426 Mdot
.98332 .15391 Mdot
.69811 .19732 Mdot
.20925 .37211 Mdot
.12544 .90368 Mdot
.23226 .67497 Mdot
.7752 .22304 Mdot
.98219 .82174 Mdot
.17569 .66737 Mdot
.47374 .70265 Mdot
.18185 .8881 Mdot
.10519 .76415 Mdot
.23814 .75216 Mdot
.43159 .59012 Mdot
.46382 .67945 Mdot
.21693 .69172 Mdot
.29863 .3785 Mdot
.21282 .71344 Mdot
.31934 .64763 Mdot
.33947 .8645 Mdot
.86451 .24406 Mdot
.32908 .84895 Mdot
.53337 .75122 Mdot
.34465 .91188 Mdot
.30282 .73094 Mdot
.25106 .71471 Mdot
.25242 .60877 Mdot
.21682 .74051 Mdot
.28733 .69829 Mdot
.21286 .74018 Mdot
.54526 .74617 Mdot
.0794 .8643 Mdot
.19081 .79824 Mdot
.21083 .72286 Mdot
.25429 .70965 Mdot
.20136 .89172 Mdot
.25159 .16269 Mdot
.43704 .88319 Mdot
.31737 .64991 Mdot
.5384 .76216 Mdot
.21789 .69682 Mdot
.50525 .79519 Mdot
.24706 .63578 Mdot
.28113 .88056 Mdot
.26489 .87621 Mdot
.26357 .87612 Mdot
.18144 .89516 Mdot
.238 .71142 Mdot
.2297 .95479 Mdot
.25818 .88445 Mdot
.75387 .13746 Mdot
.34884 .72318 Mdot
.2891 .95479 Mdot
.19071 .67938 Mdot
.29273 .64055 Mdot
.24699 .86115 Mdot
.21261 .82941 Mdot
.43993 .76305 Mdot
.39792 .76245 Mdot
.86952 .27116 Mdot
.40459 .76979 Mdot
.07009 .68194 Mdot
.21863 .88811 Mdot
.26676 .71775 Mdot
.10967 .03404 Mdot
.00612 .78658 Mdot
.23954 .6083 Mdot
.29062 .60485 Mdot
.20369 .90397 Mdot
.32206 .64606 Mdot
.36252 .15711 Mdot
.22826 .72148 Mdot
.1944 .94745 Mdot
.41249 .65923 Mdot
.39706 .79283 Mdot
.61123 .22106 Mdot
.31502 .87623 Mdot
.25009 .95618 Mdot
.27293 .87632 Mdot
.12315 .92059 Mdot
.28123 .70414 Mdot
.22639 .61739 Mdot
.26663 .87278 Mdot
.32635 .01426 Mdot
.28133 .97803 Mdot
.66514 .12807 Mdot
.31699 .8784 Mdot
.43299 .66422 Mdot
.22659 .74695 Mdot
.36862 .81122 Mdot
.75755 .12167 Mdot
.25691 .88467 Mdot
.31586 .85945 Mdot
.18688 .89402 Mdot
.24008 .71886 Mdot
.31568 .64093 Mdot
.50051 .76057 Mdot
.13918 .79057 Mdot
.11097 .00379 Mdot
.15656 .61155 Mdot
.24338 .90029 Mdot
.54169 .74333 Mdot
.49833 .87352 Mdot
.16375 .91572 Mdot
.32447 .88162 Mdot
.30256 .75456 Mdot
.25916 .87615 Mdot
.21769 .78239 Mdot
.31825 .77955 Mdot
.31656 .67366 Mdot
.39793 .6358 Mdot
.13268 .75825 Mdot
.28631 .67314 Mdot
.70227 .14275 Mdot
.31902 .63251 Mdot
.23055 .7148 Mdot
.19963 .81772 Mdot
.10718 .88323 Mdot
.86037 .24835 Mdot
.27317 .91704 Mdot
.341 .84855 Mdot
.23896 .87593 Mdot
.08841 .10103 Mdot
.13259 .69683 Mdot
.31729 .66255 Mdot
.55691 .74891 Mdot
.32908 .76303 Mdot
.10295 .1868 Mdot
.85854 .28082 Mdot
.22827 .75647 Mdot
.21415 .71782 Mdot
.03785 .77137 Mdot
.34146 .8486 Mdot
.32962 .66311 Mdot
.40821 .63484 Mdot
.53934 .74536 Mdot
.3278 .86299 Mdot
.21141 .75471 Mdot
.25655 .78375 Mdot
.30618 .71583 Mdot
.26393 .22435 Mdot
.24812 .69252 Mdot
.12741 .49773 Mdot
.05511 .70846 Mdot
.24343 .70844 Mdot
.24077 .81598 Mdot
.29472 .88862 Mdot
.30628 .66061 Mdot
.47272 .68998 Mdot
.26248 .57661 Mdot
.332 .90636 Mdot
.20482 .96133 Mdot
.21793 .20139 Mdot
.86539 .19504 Mdot
.18483 .91619 Mdot
.23723 .87173 Mdot
.38822 .75667 Mdot
.21083 .72799 Mdot
.2377 .77504 Mdot
.00251 .98436 Mdot
.01837 .81141 Mdot
.28089 .82679 Mdot
.25806 .88738 Mdot
.27781 .95002 Mdot
.30359 .82831 Mdot
.32141 .64453 Mdot
.29512 .60673 Mdot
.25004 .87158 Mdot
.17951 .66545 Mdot
.24496 .8738 Mdot
.21149 .7351 Mdot
.32001 .84711 Mdot
.30942 .65539 Mdot
.25343 .73477 Mdot
.21486 .88667 Mdot
.43514 .87689 Mdot
.02783 .86106 Mdot
.33116 .85125 Mdot
.24308 .76307 Mdot
.25925 .62893 Mdot
.07503 .83601 Mdot
.21616 .82738 Mdot
.1018 .75538 Mdot
.12657 .94084 Mdot
.23977 .66116 Mdot
.1397 .08131 Mdot
.1911 .88298 Mdot
.19587 .68505 Mdot
.28182 .82328 Mdot
.43883 .87778 Mdot
.32099 .71815 Mdot
.27637 .20886 Mdot
.10766 .78843 Mdot
.01961 .53134 Mdot
.21784 .83744 Mdot
.42784 .05283 Mdot
.37939 .87078 Mdot
.27102 .6875 Mdot
.52899 .79383 Mdot
.45213 .91721 Mdot
.3242 .93036 Mdot
.35445 .68922 Mdot
.17972 .89238 Mdot
.26526 .70895 Mdot
.28534 .82265 Mdot
.06612 .82489 Mdot
.24716 .70648 Mdot
.41071 .03645 Mdot
.26232 .87769 Mdot
.23411 .98803 Mdot
.32101 .87359 Mdot
.2311 .69855 Mdot
.31218 .62716 Mdot
.25746 .68859 Mdot
.32675 .83416 Mdot
.33224 .62604 Mdot
.99783 .86278 Mdot
.29734 .86942 Mdot
.33401 .68806 Mdot
.74534 .11768 Mdot
.2558 .86976 Mdot
.07913 .83108 Mdot
.25943 .13765 Mdot
.32402 .64402 Mdot
.52879 .74348 Mdot
.26415 .70533 Mdot
.86321 .24804 Mdot
.26276 .74963 Mdot
.25906 .93419 Mdot
.76043 .26102 Mdot
.96587 .13895 Mdot
.21969 .7417 Mdot
.09209 .7757 Mdot
.32949 .7517 Mdot
.41529 .34414 Mdot
.21676 .74997 Mdot
.45976 .84721 Mdot
.54648 .77299 Mdot
.22476 .72422 Mdot
.08341 .99549 Mdot
.48662 .81508 Mdot
.55235 .76223 Mdot
.34549 .70242 Mdot
.357 .33857 Mdot
.18902 .6257 Mdot
.23959 .59773 Mdot
.68237 .23833 Mdot
.25931 .87145 Mdot
.75859 .37732 Mdot
.31084 .88041 Mdot
.1746 .11219 Mdot
.95952 .15425 Mdot
.34249 .52634 Mdot
.44379 .80575 Mdot
.68099 .16453 Mdot
.21991 .85373 Mdot
.24857 .69366 Mdot
.45596 .8774 Mdot
.33977 .7123 Mdot
.14383 .05043 Mdot
.07297 .80615 Mdot
.26805 .8949 Mdot
.29577 .8103 Mdot
.13235 .69048 Mdot
.29269 .88243 Mdot
.07625 .48867 Mdot
.31426 .65062 Mdot
.32649 .7517 Mdot
.25643 .70951 Mdot
.15854 .95014 Mdot
.4081 .26015 Mdot
.15284 .19519 Mdot
.37986 .48069 Mdot
.07782 .71046 Mdot
.24267 .8848 Mdot
.18452 .88569 Mdot
.4125 .86893 Mdot
.31514 .64378 Mdot
.45237 .12977 Mdot
.3108 .21358 Mdot
.20589 .65334 Mdot
.30658 .67179 Mdot
.50654 .23476 Mdot
.28916 .76136 Mdot
.01951 .80568 Mdot
.681 .33203 Mdot
.33579 .90474 Mdot
.13957 .34837 Mdot
.28253 .62814 Mdot
.29128 .88297 Mdot
.06526 .13403 Mdot
.29237 .62815 Mdot
.23374 .8285 Mdot
.37785 .6843 Mdot
.31754 .86128 Mdot
.00967 .69074 Mdot
.54326 .74349 Mdot
.84652 .15605 Mdot
.21114 .88651 Mdot
.22047 .75114 Mdot
.33044 .62438 Mdot
.74575 .11718 Mdot
.26043 .59737 Mdot
.26306 .606 Mdot
.22904 .883 Mdot
.29083 .68217 Mdot
.05016 .10916 Mdot
.99756 .80697 Mdot
.87619 .23765 Mdot
.87075 .26912 Mdot
.32504 .67281 Mdot
.93366 .13799 Mdot
.35032 .75663 Mdot
.22109 .68808 Mdot
.1973 .8801 Mdot
.07236 .96214 Mdot
.42897 .66226 Mdot
.3407 .69232 Mdot
.24005 .6037 Mdot
.74501 .13804 Mdot
.33157 .66749 Mdot
.3882 .06297 Mdot
.30834 .70486 Mdot
.21395 .81148 Mdot
.21952 .61786 Mdot
.18998 .83862 Mdot
.30567 .86814 Mdot
.33218 .75174 Mdot
.33762 .85851 Mdot
.34916 .75263 Mdot
.23827 .95081 Mdot
.22539 .89109 Mdot
.83332 .11875 Mdot
.26812 .87916 Mdot
.0178 .1997 Mdot
.22574 .81056 Mdot
.2558 .57399 Mdot
.21903 .68098 Mdot
.47952 .81227 Mdot
.71551 .15499 Mdot
.3024 .61755 Mdot
.02262 .21811 Mdot
.28986 .72817 Mdot
.05752 .78472 Mdot
.34169 .85778 Mdot
.33219 .90156 Mdot
.12547 .10706 Mdot
.24223 .87718 Mdot
.34632 .72998 Mdot
.22091 .88853 Mdot
.25872 .59962 Mdot
.25002 .66928 Mdot
.21629 .69813 Mdot
.1823 .7988 Mdot
.71912 .2456 Mdot
.46061 .67951 Mdot
.28654 .78083 Mdot
.23075 .74919 Mdot
.08577 .68488 Mdot
.28701 .67577 Mdot
.266 .71654 Mdot
.22943 .88046 Mdot
.10647 .79523 Mdot
.66647 .20837 Mdot
.98091 .78423 Mdot
.23234 .89413 Mdot
.44895 .87457 Mdot
.26611 .93339 Mdot
.06564 .68772 Mdot
.08383 .8032 Mdot
.21407 .70837 Mdot
.28707 .84685 Mdot
.63908 .30854 Mdot
.24874 .62314 Mdot
.18684 .91804 Mdot
.20425 .73621 Mdot
.30814 .77062 Mdot
.30871 .8795 Mdot
.12006 .01888 Mdot
.36186 .44155 Mdot
.47176 .84156 Mdot
.30511 .85985 Mdot
.47818 .83491 Mdot
.21032 .71648 Mdot
.18963 .89315 Mdot
.05313 .76703 Mdot
.2578 .66807 Mdot
.24796 .7301 Mdot
.23318 .92985 Mdot
.73738 .16542 Mdot
.21934 .70915 Mdot
.08623 .98295 Mdot
.26166 .87757 Mdot
.25223 .87581 Mdot
.33441 .6887 Mdot
.24561 .88495 Mdot
.28113 .88086 Mdot
.24114 .76365 Mdot
.289 .90738 Mdot
.31245 .72831 Mdot
.11672 .09683 Mdot
.3252 .84209 Mdot
.14135 .72743 Mdot
.4456 .85995 Mdot
.27855 .89365 Mdot
.10055 .13423 Mdot
.29829 .79634 Mdot
.34019 .85048 Mdot
.36101 .01417 Mdot
.21152 .75141 Mdot
.32289 .68368 Mdot
.12973 .20703 Mdot
.99175 .81564 Mdot
.24954 .87468 Mdot
.23223 .74174 Mdot
.29482 .67829 Mdot
.74523 .17166 Mdot
.06381 .93866 Mdot
.51643 .78496 Mdot
.21876 .88609 Mdot
.25383 .87084 Mdot
.2136 .81248 Mdot
.43049 .7368 Mdot
.29783 .78506 Mdot
.22262 .89204 Mdot
.24903 .98796 Mdot
.21166 .76955 Mdot
.15463 .21386 Mdot
.26513 .8787 Mdot
.24236 .33468 Mdot
.35029 .72988 Mdot
.23476 .80311 Mdot
.25392 .87183 Mdot
.21417 .70165 Mdot
.30813 .66744 Mdot
.4649 .04137 Mdot
.24471 .87946 Mdot
.32528 .64187 Mdot
.20775 .88057 Mdot
.21025 .68067 Mdot
.051 .2717 Mdot
.25296 .8853 Mdot
.15995 .85857 Mdot
.20657 .77347 Mdot
.29299 .70971 Mdot
.19176 .79122 Mdot
.35916 .75255 Mdot
.30044 .88083 Mdot
.99224 .28654 Mdot
.31387 .63195 Mdot
.02966 .81911 Mdot
.29166 .872 Mdot
.10288 .78199 Mdot
.21859 .65101 Mdot
.26703 .87664 Mdot
.20063 .9166 Mdot
.25285 .8613 Mdot
.20619 .82939 Mdot
.1915 .83518 Mdot
.72055 .18881 Mdot
.27529 .63997 Mdot
.4808 .77059 Mdot
.60755 .20768 Mdot
.15478 .82385 Mdot
.26277 .95035 Mdot
.28126 .63511 Mdot
.2373 .2978 Mdot
.26979 .78906 Mdot
.85161 .10893 Mdot
.22291 .68971 Mdot
.05017 .78091 Mdot
.34542 .73511 Mdot
.2877 .87216 Mdot
.29315 .71352 Mdot
.1449 .27451 Mdot
.19847 .81824 Mdot
.07574 .04349 Mdot
.99067 .8313 Mdot
.47008 .68329 Mdot
.32638 .77826 Mdot
.21843 .8832 Mdot
.24979 .83565 Mdot
.32666 .72402 Mdot
.51522 .77897 Mdot
.40916 .18985 Mdot
.31341 .67112 Mdot
.35341 .74244 Mdot
.22302 .85361 Mdot
.50731 .75308 Mdot
.05677 .77682 Mdot
.38436 .82093 Mdot
.29762 .67421 Mdot
.55879 .23742 Mdot
.30862 .87045 Mdot
.264 .98327 Mdot
.25599 .86948 Mdot
.2334 .70312 Mdot
.44436 .77907 Mdot
.58338 .15982 Mdot
.26009 .59675 Mdot
.37028 .68123 Mdot
.9692 .13969 Mdot
.25644 .81797 Mdot
.35248 .86896 Mdot
.25447 .8832 Mdot
.30783 .64693 Mdot
.41855 .96073 Mdot
.22831 .85582 Mdot
.68651 .27889 Mdot
.26888 .61078 Mdot
.22351 .72704 Mdot
.53848 .74116 Mdot
.25125 .88839 Mdot
.19279 .88457 Mdot
.28444 .71832 Mdot
.11172 .89909 Mdot
.21673 .95401 Mdot
.26105 .69338 Mdot
.32808 .64467 Mdot
.2506 .95443 Mdot
.28657 .67761 Mdot
.33948 .09385 Mdot
.23402 .67602 Mdot
.7552 .26265 Mdot
.31298 .853 Mdot
.30074 .66196 Mdot
.01936 .80459 Mdot
.20869 .8866 Mdot
.5871 .06111 Mdot
.44315 .85338 Mdot
.10326 .80882 Mdot
.03455 .32008 Mdot
.2657 .63413 Mdot
.25349 .71674 Mdot
.22078 .70758 Mdot
.29601 .81751 Mdot
.24476 .87285 Mdot
.10287 .0091 Mdot
.25384 .74967 Mdot
.28641 .80418 Mdot
.88111 .13195 Mdot
.15166 .03154 Mdot
.33874 .04625 Mdot
.80967 .37 Mdot
.30298 .1792 Mdot
.10311 .93702 Mdot
.3299 .29008 Mdot
.27028 .87262 Mdot
.22042 .75039 Mdot
.19217 .93608 Mdot
.23099 .73668 Mdot
.20762 .77262 Mdot
.28579 .8896 Mdot
.29132 .86163 Mdot
.32167 .74249 Mdot
.20628 .74359 Mdot
.23772 .60201 Mdot
.33727 .90677 Mdot
.23902 .6242 Mdot
.19344 .11273 Mdot
.39968 .89309 Mdot
.22415 .7657 Mdot
.5193 .73248 Mdot
.21521 .70131 Mdot
.27423 .60321 Mdot
.25946 .07857 Mdot
.32401 .68945 Mdot
.21958 .75279 Mdot
.20912 .79819 Mdot
.27595 .91016 Mdot
.24448 .76495 Mdot
.28569 .61015 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02o`0000_ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo000Nooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02o`0000_ooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo
000Nooooo`03o`000?oooooooooo01gooooo0_l0003oooooobWooooo000Nooooo`03o`000?oooooo
oooo01gooooo0_l00016ooooo`;o0000h?ooool001kooooo00?o0000ooooooooool02Oooool2o`00
05[ooooo0ol00009ooooo`;o0000e?ooool001kooooo00?o0000ooooooooool02Oooool2o`0000go
oooo0_l00009ooooo`;o00006?ooool2o`0002Oooooo0_l00009ooooo`;o0000e?ooool001kooooo
00?o0000ooooooooool06?ooool2o`0000Wooooo0_l0000Hooooo`;o0000Y_ooool2o`00063ooooo
000Nooooo`03o`000?oooooooooo0>Gooooo0_l0001Pooooo`007_ooool00ol0003oooooooooo`0[
ooooo`;o0000oooooolKooooo`007_ooool00ol0003oooooooooo`0[ooooo`Co0000oooooolIoooo
o`007_ooool00ol0003oooooooooo`0Pooooo`;o00002oooool2o`000?oooooo6Oooool001kooooo
00?o0000ooooooooool08?ooool2o`0000Cooooo0_l0001Iooooo`;o0000a?ooool001kooooo00?o
0000ooooooooool09_ooool2o`0005Wooooo0_l0000@ooooo`;o00003?ooool2o`000:Cooooo000N
ooooo`03o`000?oooooooooo01Gooooo0_l0000Oooooo`;o0000Foooool2o`0000cooooo0_l0002T
ooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o00007oooool2o`0003;ooooo0_l0003Koooo
o`007_ooool00ol0003oooooooooo`0[ooooo`;o0000?Oooool2o`000=_ooooo000Nooooo`;o0000
;?ooool2o`0005[ooooo0_l0002nooooo`007_ooool00ol0003oooooooooo`27ooooo`;o0000__oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`2koooo
o`;o0000R_ooool001kooooo00?o0000ooooooooool0N_ooool2o`0003oooooo0_l0002:ooooo`00
7_ooool00ol0003oooooooooo`1jooooo`;o0000boooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3Zooooo`;o0000Foooool001kooooo00?o0000oooo
ooooool0j_ooool2o`0005_ooooo000Nooooo`03o`000?oooooooooo02Wooooo0_l0000Uooooo`;o
0000mOooool001kooooo00?o0000ooooooooool0:Oooool2o`0002Gooooo0_l0003eooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0:oooool2o`000<kooooo0_l0001:ooooo`007_ooool00ol0003o
ooooooooo`0[ooooo`;o0000?Oooool2o`0008oooooo0_l0001:ooooo`007_ooool00ol0003ooooo
ooooo`0>ooooo`;o00004_ooool2o`0004Kooooo0_l0003Kooooo`007_ooool2o`0000oooooo0_l0
0009ooooo`;o00001oooool2o`000=7ooooo0_l0001@ooooo`007_ooool00ol0003oooooooooo`0I
ooooo`;o0000f_ooool2o`00053ooooo000Nooooo`03o`000?oooooooooo02Gooooo0_l0000Doooo
o`;o0000e?ooool2o`0003Cooooo000Nooooo`03o`000?oooooooooo00cooooo0_l0000@ooooo`;o
00000oooool4o`0001Cooooo0_l00031ooooo`;o00004Oooool2o`0003Cooooo000Nooooo`03o`00
0?oooooooooo00cooooo0_l0000@ooooo`;o00000oooool2o`00013ooooo0_l00004ooooo`;o0000
`Oooool2o`0004Oooooo000Nooooo`03o`000?oooooooooo03Gooooo0_l00004ooooo`;o0000/Ooo
ool2o`0005Oooooo000Nooooo`03o`000?oooooooooo0<3ooooo0_l0000/ooooo`;o00006oooool2
o`0003[ooooo000Nooooo`03o`000?oooooooooo0<3ooooo0_l0000`ooooo`;o00005oooool2o`00
03[ooooo000Nooooo`03o`000?oooooooooo0?;ooooo0_l0001Cooooo`007_ooool00ol0003ooooo
ooooo`2?ooooo`;o0000@oooool2o`00077ooooo000Nooooo`03o`000?oooooooooo08oooooo0_l0
0013ooooo`;o00007Oooool2o`0002Gooooo0_l0000Booooo`;o00005oooool001kooooo00?o0000
ooooooooool04Oooool2o`0000[ooooo0_l0003Dooooo`;o00009Oooool2o`0001;ooooo0_l0000G
ooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o00002_ooool2o`00037ooooo0_l0002Loooo
o`;o000000?oooooo`000?l00000>?ooool2o`0000Wooooo0ol0000>ooooo`007_ooool00ol0003o
ooooooooo`1@ooooo`;o00004Oooool2o`0006Wooooo0_l0000@ooooo`;o00003?ooool2o`000003
ooooool0003o000003Sooooo0_l00009ooooo`Go00003?ooool001kooooo00?o0000ooooooooool0
Hoooool2o`0006Wooooo0_l0000@ooooo`;o00002oooool2o`0004[ooooo0_l0000<ooooo`007_oo
ool00ol0003oooooooooo`3]ooooo`;o0000F?ooool001kooooo0_l0003oooooodWooooo000Noooo
o`03o`000?oooooooooo03gooooo0_l0002Vooooo`;o0000COooool2o`0000Kooooo0_l00009oooo
o`007_ooool00ol0003oooooooooo`0mooooo`;o0000<oooool2o`00077ooooo0_l0000Xooooo`;o
00008oooool2o`0000Kooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`1Hooooo`;o0000
6?ooool2o`0004Kooooo0_l0000^ooooo`;o00008oooool2o`0003Kooooo000Nooooo`03o`000?oo
oooooooo04kooooo0_l00008ooooo`;o0000H?ooool2o`0002kooooo0_l0001Kooooo`007_ooool0
0ol0003oooooooooo`1>ooooo`;o0000ROooool2o`0000;ooooo0_l0000=ooooo`;o0000FOooool0
01kooooo00?o0000ooooooooool0[Oooool2o`0002[ooooo0_l00002ooooo`;o00003Oooool2o`00
05Wooooo000Nooooo`03o`000?oooooooooo0:gooooo0_l0000oooooo`;o00006Oooool2o`0003co
oooo000Nooooo`03o`000?oooooooooo0>kooooo0_l0000Iooooo`;o0000??ooool001kooooo00?o
0000ooooooooool0G_ooool2o`000>Oooooo000Nooooo`03o`000?oooooooooo05kooooo0_l0003W
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo01go
oooo0_l00037ooooo`;o0000Goooool001kooooo00?o0000ooooooooool07Oooool2o`0006;ooooo
0_l0001Sooooo`;o00002Oooool2o`0005Cooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo02kooooo0_l0001Aooooo`;o0000
K_ooool2o`0002;ooooo0_l0000`ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`0^ooooo`;o
0000[oooool2o`0003Cooooo0_l0000`ooooo`000oooool01Ol@413ooooooooooooooooo410@00co
oooo00?oV9RHob4Q8Oo^k^h01oooool3o`0000;ooooo0_l0003Kooooo`;o0000I_ooool000?ooooo
00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000oooooooo
ool00_ooool2o`0003oooooo0_l0003oooooo`?ooooo0003ooooo`05o`000?ooooooooooooooool0
00003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo02Kooooo0_l0000Kooooo`;o
0000ooooool3ooooo`000oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Vooooo`;o0000;_ooool2o`0006Wooooo0_l0000Aooooo`?o
0000@Oooool2o`0002gooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o
^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0E_ooool2o`0000Wooooo0_l0001Noooo
o`;o00004Oooool3o`00047ooooo0_l0000]ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo02kooooo0_l0000a
ooooo`;o0000_Oooool2o`0002Gooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0000Yoooo
o`;o0000l?ooool2o`0002Gooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0002nooooo`;o
0000P_ooool001kooooo00?o0000ooooooooool0D_ooool2o`0006oooooo0_l0000[ooooo`;o0000
1_ooool2o`0004gooooo000Nooooo`03o`000?oooooooooo00cooooo0_l00014ooooo`;o0000Rooo
ool2o`0000oooooo0_l00006ooooo`;o0000COooool001kooooo00?o0000ooooooooool03?ooool2
o`000=7ooooo0_l0001Vooooo`007_ooool00ol0003oooooooooo`2Qooooo`;o0000Y?ooool001ko
oooo00?o0000ooooooooool0Boooool2o`0005Cooooo0_l0000:ooooo`;o00000oooool2o`000003
ooooool0003o000006;ooooo0_l0000/ooooo`007_ooool00ol0003oooooooooo`1;ooooo`;o0000
=?ooool2o`0002[ooooo0_l00003ooooo`;o000000?oooooo`000?l000008oooool2o`0003gooooo
0_l0000/ooooo`007_ooool00ol0003oooooooooo`21ooooo`;o0000Eoooool2o`0001;ooooo0_l0
000Uooooo`;o0000<?ooool001kooooo00?o0000ooooooooool0V?ooool2o`0004cooooo0_l00006
ooooo`;o00009Oooool2o`00033ooooo000Nooooo`03o`000?oooooooooo09Sooooo0_l0001<oooo
o`;o0000;?ooool3o`00033ooooo000Nooooo`;o0000oooooolFooooo`?o0000<?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooocWooooo0_l0
000=ooooo`007_ooool00ol0003oooooooooo`21ooooo`;o00005Oooool2o`0005Oooooo1?l00013
ooooo`;o00003Oooool001kooooo00?o0000ooooooooool0=oooool2o`0004Sooooo0_l0000Eoooo
o`;o0000Eoooool4o`0005;ooooo000Nooooo`03o`000?oooooooooo03Oooooo0_l0003nooooo`;o
00003_ooool001kooooo00?o0000ooooooooool03?ooool2o`000?oooooo2_ooool2o`0001kooooo
0_l0000>ooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o00007Oooool2o`0004Sooooo0_l0
002Pooooo`;o00007?ooool2o`00013ooooo000Nooooo`03o`000?oooooooooo02_ooooo0_l00018
ooooo`;o0000__ooool2o`00013ooooo000Nooooo`03o`000?oooooooooo0=_ooooo0_l0000foooo
o`;o0000<_ooool001kooooo00?o0000ooooooooool0foooool2o`0003Kooooo0_l0000booooo`00
7_ooool00ol0003oooooooooo`0Pooooo`;o0000oooooolMooooo`;o00001oooool001kooooo00?o
0000ooooooooool08?ooool2o`0004Gooooo0_l0003Eooooo`;o00001oooool001kooooo00?o0000
ooooooooool0Ioooool2o`000=kooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0BOooool2o`000?cooooo000Nooooo`;o00006?ooool2o`00033ooooo
0_l0003looooo`007_ooool00ol0003oooooooooo`0Gooooo`;o0000ooooool_ooooo`007_ooool0
0ol0003oooooooooo`3<ooooo`;o0000NOooool001kooooo00?o0000ooooooooool0c?ooool2o`00
07Wooooo000Nooooo`03o`000?oooooooooo09Wooooo0_l0002/ooooo`007_ooool00ol0003ooooo
ooooo`2Iooooo`;o0000[?ooool001kooooo00?o0000ooooooooool01oooool2o`000?oooooo?ooo
ool001kooooo00?o0000ooooooooool01oooool2o`000?oooooo?oooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0=Wooooo0_l0001/ooooo`007_ooool00ol0003oooooooooo`1;ooooo`;o0000S?oo
ool2o`00027ooooo0_l00019ooooo`007_ooool00ol0003oooooooooo`1;ooooo`;o00008oooool2
o`0008[ooooo0_l00019ooooo`007_ooool00ol0003oooooooooo`1`ooooo`;o0000eOooool001ko
oooo00?o0000ooooooooool0Poooool2o`000<;ooooo000Nooooo`03o`000?oooooooooo02Wooooo
0_l0001Hooooo`;o0000`_ooool001kooooo0_l0000Zooooo`;o0000oooooolMooooo`007_ooool0
0ol0003oooooooooo`2Cooooo`;o0000/_ooool001kooooo00?o0000ooooooooool0=_ooool2o`00
05_ooooo0_l0002booooo`007_ooool00ol0003oooooooooo`0fooooo`;o0000L_ooool2o`0009_o
oooo000Nooooo`03o`000?oooooooooo0:[ooooo0_l0002Kooooo`007_ooool00ol0003ooooooooo
o`0oooooo`;o0000ooooool7ooooo`007_ooool00ol0003oooooooooo`0oooooo`;o0000`_ooool2
o`0004;ooooo000Nooooo`03o`000?oooooooooo043ooooo0_l00031ooooo`;o0000@_ooool001ko
oooo00?o0000ooooooooool0:Oooool2o`0001Gooooo0_l0003oooooo`Kooooo000Nooooo`03o`00
0?oooooooooo02Wooooo0_l0000Gooooo`;o00006Oooool2o`0003Oooooo0_l0001Kooooo`;o0000
D_ooool001kooooo00?o0000ooooooooool0@_ooool2o`0001Wooooo0_l0000gooooo`;o0000Fooo
ool2o`0005;ooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03
o`000?oooooooooo0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo
00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool3o`000?ooooooB?ooool000?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000oooo
ooooool0oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEE
EOoooooo00001oooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo0?ooooooB?ooool0
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000
ooooooooool0oooooom8ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMg
o`000?ooool01_ooool00ol0003oooooooooo`2Wooooo`;o0000W_ooool001kooooo00?o0000oooo
ooooool0Yoooool2o`0009kooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`25ooooo`;o0000`?ooool001kooooo00?o0000ooooooooool0
QOooool2o`000<3ooooo000Nooooo`03o`000?oooooooooo07;ooooo0_l0003Cooooo`007_ooool0
0ol0003oooooooooo`1booooo`;o0000doooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
07Oooooo0_l0003>ooooo`007_ooool00ol0003oooooooooo`1gooooo`;o0000c_ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o0000oooo
oolaooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o0000@oooool2o`000>_ooooo000Noooo
o`03o`000?oooooooooo05[ooooo0_l0003[ooooo`007_ooool00ol0003oooooooooo`0Uooooo`;o
0000oooooolQooooo`007_ooool2o`0002Kooooo0_l0003oooooob7ooooo000Nooooo`03o`000?oo
oooooooo07[ooooo0_l0003;ooooo`007_ooool00ol0003oooooooooo`1jooooo`;o0000boooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
06_ooooo0_l0003Jooooo`007_ooool00ol0003oooooooooo`1[ooooo`;o0000f_ooool001kooooo
00?o0000ooooooooool00_ooool2o`000?ooooooA?ooool001kooooo00?o0000ooooooooool00_oo
ool2o`000?ooooooA?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0D?ooool2o`000?Gooooo000Nooooo`;o0000DOooool2o`000?Gooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo08;ooooo
0_l00033ooooo`007_ooool00ol0003oooooooooo`22ooooo`;o0000`oooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo04oooooo1?l0003dooooo`007_ooool00ol0003oooooooooo`1?ooooo`Co0000
m?ooool001kooooo00?o0000ooooooooool0Coooool4o`000?Cooooo000Nooooo`03o`000?oooooo
oooo08Oooooo0_l0002nooooo`007_ooool00ol0003oooooooooo`27ooooo`;o0000__ooool001ko
oooo00?o0000ooooooooool0Doooool2o`0003?ooooo0_l0002mooooo`000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0
003oooooooooo`1Cooooo`;o0000<oooool2o`000;gooooo0003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooo
oooo04[ooooo0_l00004ooooo`?o0000Q_ooool2o`0006cooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0001:ooooo`;o00001?oo
ool3o`0008Kooooo0_l0001/ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go
0000oiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo04Wooooo0ol00004ooooo`;o0000
0oooool2o`000?3ooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<00Kooooo00?o0000ooooooooool0BOooool4o`0000Cooooo0_l00002ooooo`;o
00000oooool4o`000>Wooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGo
QhN7ooooo`08ooooo`03o`000?oooooooooo04[ooooo0ol000001?oooooo0000o`000?ooool2o`00
00Kooooo1Ol0003Yooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@
4?nHV9P02?ooool00ol0003oooooooooo`0_ooooo`;o00006Oooool2o`0000;ooooo0_l00003oooo
o`;o00001?ooool2o`000>cooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<
c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo02oooooo0_l0000Rooooo`;o00002Oooool2
o`000>Oooooo000Nooooo`03o`000?oooooooooo04?ooooo1?l0000Gooooo`;o0000ioooool001ko
oooo00?o0000ooooooooool03oooool2o`0003;ooooo1?l0000:ooooo`Ko00001oooool2o`000>Oo
oooo000Nooooo`03o`000?oooooooooo00oooooo0_l0000Xooooo`;o00003oooool2o`000003oooo
ool0003o000000;ooooo1_l00003ooooo`;o00002oooool2o`000=kooooo000Nooooo`03o`000?oo
oooooooo03Wooooo0_l0000?ooooo`;o000000?oooooo`000?l000002Oooool5o`0000;ooooo1?l0
0004ooooo`?o0000gOooool001kooooo00?o0000ooooooooool0>Oooool2o`0000kooooo0_l00005
ooooo`;o00001Oooool3o`000003ooooool0003o000000;ooooo1Ol00004ooooo`;o0000F?ooool2
o`0008?ooooo000Nooooo`03o`000?oooooooooo03gooooo0_l0000:ooooo`;o00001Oooool4o`00
0003ooooool0003o000000?o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o0000
00;o00006oooool2o`0003oooooo0_l00023ooooo`007_ooool00ol0003oooooooooo`0mooooo`;o
00003Oooool3o`0000?ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00002ooooo`;o
00000_ooool3o`0000Cooooo0_l0000Aooooo`;o00000_ooool2o`000<Cooooo000Nooooo`03o`00
0?oooooooooo04cooooo0ol00005ooooo`Go00000_ooool2o`000003ooooool0003o000000?ooooo
0ol00004ooooo`;o00003?ooool2o`0000?ooooo0_l00038ooooo`007_ooool00ol0003ooooooooo
o`18ooooo`;o00000oooool2o`0000Gooooo0ol00004ooooo`;o000000?oooooo`000?l000000_oo
ool6o`00013ooooo0_l0003=ooooo`007_ooool00ol0003oooooooooo`0cooooo`;o00004oooool2
o`0000?ooooo0_l00006ooooo`;o00002Oooool9o`000=kooooo000Nooooo`03o`000?oooooooooo
03?ooooo0_l0000Yooooo`_o0000g_ooool001kooooo0_l0000^ooooo`;o00000_ooool2o`0000co
oooo0_l00002ooooo`;o00006?ooool3o`000003ooooool0003o000000?o0000hOooool001kooooo
00?o0000ooooooooool0;Oooool2o`0000;ooooo0_l0000<ooooo`;o00000_ooool2o`0001Sooooo
0_l000000ooooooo0000o`000003o`000>;ooooo000Nooooo`03o`000?oooooooooo063ooooo0_l0
00000ooooooo0000o`00000Mooooo`;o00002Oooool2o`000;Sooooo000Nooooo`03o`000?oooooo
oooo00gooooo0_l0000kooooo`;o00003_ooool2o`000003ooooool0003o000000;o00000_ooool2
o`0001gooooo0_l00003ooooo`;o00001?ooool2o`000;Sooooo000Nooooo`03o`000?oooooooooo
00gooooo0_l0000Cooooo`;o00004_ooool2o`0001;ooooo0_l0000>ooooo`;o000000?oooooo`00
0?l000000_l00002ooooo`;o000000Coooooo`000?l0003o00003_ooool2o`0000kooooo1?l0002l
ooooo`007_ooool00ol0003oooooooooo`0Rooooo`;o00004Oooool3o`0001Sooooo0_l0000<oooo
o`Co00001?ooool4o`0000gooooo0_l0000@ooooo`;o0000_?ooool001kooooo00?o0000oooooooo
ool06Oooool2o`0000oooooo0_l00009ooooo`;o00002?ooool2o`0000cooooo0_l000001?oooooo
0000o`000?ooool2o`0000Wooooo1_l00004ooooo`;o00008_ooool2o`000;Wooooo000Nooooo`03
o`000?oooooooooo01Wooooo0_l0000?ooooo`;o00004oooool2o`0000Kooooo0_l00004ooooo`;o
00001?ooool2o`0000Cooooo0_l00002ooooo`So000000?oooooo`000?l000009?ooool2o`000;Wo
oooo000Nooooo`03o`000?oooooooooo04?ooooo0_l00002ooooo`?o00001Oooool2o`0000Sooooo
0_l00002ooooo`?o00000_ooool3o`000003ooooool0003o00000=oooooo000Nooooo`03o`000?oo
oooooooo03[ooooo0_l00004ooooo`;o000000?oooooo`000?l000000oooool2o`0000Gooooo0_l0
0006ooooo`Co000000Coooooo`000?l0003o0000<oooool3o`000;;ooooo000Nooooo`03o`000?oo
oooooooo01?ooooo0_l0000Booooo`;o00004Oooool2o`0000Cooooo0_l000000ooooooo0000o`00
000>ooooo`;o00000_ooool2o`000003ooooool0003o000000?o00001_ooool2o`0000gooooo0_l0
000Kooooo`Ko0000Y?ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo01?ooooo0_l00003
ooooo`;o00000oooool2o`0000Sooooo0_l0000Cooooo`;o00001Oooool4o`000003ooooool0003o
000000Wooooo0_l00005ooooo`;o00002Oooool2o`0000gooooo0_l000000ooooooo0000o`00000H
ooooo`;o00000_ooool3o`000:?ooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0@oooo
o`?o00001Oooool2o`0000?ooooo0_l0000Mooooo`;o00001_ooool3o`000003ooooool0003o0000
00Kooooo0_l00002ooooo`;o00003oooool2o`000004ooooool0003o0000o`0000Cooooo0_l00006
ooooo`;o00007Oooool2o`000:oooooo000Nooooo`04o`000?oooooo0000o`0000oooooo0ol0000D
ooooo`;o00006Oooool4o`0000Oooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00001_oo
ool2o`0000Oooooo0_l000000ooooooo0000o`000003o`0000;ooooo0_l0000Uooooo`;o0000[ooo
ool001kooooo00Co0000ooooool0003o00005?ooool2o`00013ooooo0_l0000Iooooo`Co00001Ooo
ool4o`000004ooooool0003o0000o`0000Gooooo0_l00002ooooo`?o00001?ooool2o`0000;ooooo
0_l00002ooooo`?o0000fOooool001kooooo00?o0000ooooooooool05Oooool2o`00013ooooo0_l0
000Iooooo`?o00000_ooool2o`0000;ooooo1?l000000ooooooo0000o`000006ooooo`?o00000_oo
ool3o`000003ooooool0003o000000;o00000_ooool2o`0000?ooooo0_l0003Iooooo`007_ooool2
o`0002Sooooo0_l0000Iooooo`?o00000_ooool2o`00013ooooo0_l00003ooooo`;o000000?ooooo
o`000?l000002Oooool2o`0002Sooooo0_l0002_ooooo`007_ooool00ol0003oooooooooo`12oooo
o`;o00000_ooool4o`0000Sooooo0_l00003ooooo`;o00001_ooool3o`0000[ooooo0_l0000Moooo
o`;o00002Oooool2o`000:oooooo000Nooooo`03o`000?oooooooooo00kooooo0_l0000aooooo`;o
000000?oooooo`000?l000002?l00003ooooo`?o00000oooool2o`0000Kooooo0ol0000Yooooo`;o
0000^_ooool001kooooo00?o0000ooooooooool03_ooool2o`0000Gooooo0_l0000Zooooo`Go0000
0oooool5o`000003ooooool0003o000000?o000000?oooooo`000?l000000_ooool4o`000>?ooooo
0_l00005ooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o00005_ooool2o`0001;ooooo1Ol0
00000ooooooo0000o`000002o`0000?ooooo1_l000000ooooooo0000o`000002ooooo`Co00003Ooo
ool2o`000=Cooooo0_l00005ooooo`007_ooool00ol0003oooooooooo`0]ooooo`;o00002?ooool2
o`0000Oooooo1_l000000ooooooo0000o`000002ooooo`;o000000Coooooo`000?l0003ooooo1?l0
0006ooooo`;o00000_ooool2o`0000Wooooo0_l0003Kooooo`007_ooool00ol0003oooooooooo`0<
ooooo`;o0000:Oooool2o`0000Oooooo1?l00006ooooo`?o000000Coooooo`000?l0003ooooo1?l0
0003ooooo`;o00001Oooool2o`0000?ooooo0_l0003Gooooo`;o000000?oooooo`000?l000001Ooo
ool001kooooo00?o0000ooooooooool03?ooool2o`00027ooooo0_l0000?ooooo`;o00000_ooool9
o`0000Cooooo0_l00005ooooo`;o00002_ooool4o`0000Gooooo0_l0003>ooooo`;o000000?ooooo
o`000?l000001Oooool001kooooo00?o0000ooooooooool00_l0000]ooooo`;o00003oooool2o`00
00;ooooo1ol00009ooooo`;o00004?ooool2o`0000Gooooo0_l0003Hooooo`007_ooool00ol0003o
ooooooooo`02o`0002Sooooo0_l0000Dooooo`;o00000oooool2o`0000Gooooo0_l00006ooooo`;o
00001?ooool2o`0000Gooooo0_l00009ooooo`Co0000:Oooool2o`0000Cooooo0_l0002Vooooo`00
7_ooool00ol0003oooooooooo`0Zooooo`;o00005?ooool3o`0000Wooooo0_l0000<ooooo`;o0000
0_ooool2o`000003ooooool0003o000000Wooooo1?l0000Yooooo`;o00000_ooool4o`0000Cooooo
0_l0002Pooooo`007_ooool00ol0003oooooooooo`0looooo`Co000000?oooooo`000?l000002ooo
ool2o`0000cooooo1ol00009ooooo`;o0000;oooool2o`0000Kooooo0_l0002Pooooo`007_ooool0
0ol0003oooooooooo`0Pooooo`;o00004Oooool2o`0000Oooooo1?l000000ooooooo0000o`000004
ooooo`;o00000_ooool2o`000003ooooool0003o000000cooooo0_l000000ooooooo0000o`000002
o`0000Wooooo0_l0000Jooooo`;o0000_Oooool001kooooo00?o0000ooooooooool08?ooool2o`00
017ooooo0_l0000:ooooo`Ko00000_ooool3o`000003ooooool0003o000000?ooooo0_l0000Boooo
o`;o00002Oooool2o`0001Oooooo0_l0000Qooooo`;o0000V_ooool001kooooo00?o0000oooooooo
ool0?oooool;o`0000Kooooo0_l00004ooooo`;o00003?ooool2o`0000Wooooo0_l0000Xooooo`;o
00003Oooool2o`000003ooooool0003o000000;o0000S?ooool2o`0000[ooooo000Nooooo`03o`00
0?oooooooooo027ooooo0_l00002ooooo`;o00006?ooool:o`0000gooooo0_l00008ooooo`;o0000
=oooool2o`0000Sooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l0002<ooooo`;o0000
2_ooool001kooooo0_l0000Rooooo`;o00000_ooool2o`0001[ooooo2Ol00003ooooo`?o000000?o
ooooo`000?l000003Oooool2o`0000Cooooo1?l0000Uooooo`;o00004_ooool2o`0000Cooooo1ol0
00000ooooooo0000o`00002Dooooo`007_ooool00ol0003oooooooooo`11ooooo`Go000000?ooooo
o`000?l000000_l00002ooooo`?o000000?oooooo`000?l000002oooool2o`0000Kooooo1?l00003
ooooo`;o00000_ooool2o`0000kooooo0_l0000<ooooo`;o00004?ooool3o`0000Gooooo1?l00000
1?oooooo0000o`000?ooool2o`0009Cooooo000Nooooo`03o`000?oooooooooo01gooooo0_l0000R
ooooo`Co000000Coooooo`000?l0003ooooo0_l00005ooooo`;o00001Oooool2o`0000;ooooo0_l0
00000ooooooo0000o`00000=ooooo`?o000000?oooooo`000?l000001oooool2o`0000Gooooo0_l0
000Nooooo`?o0000Xoooool001kooooo00?o0000ooooooooool07Oooool2o`0000Sooooo0_l0000J
ooooo`;o000000Coooooo`000?l0003ooooo0_l00005ooooo`;o00001Oooool3o`000004ooooool0
003o0000ooooo`;o00003_ooool2o`0000[ooooo0_l0000Sooooo`;o0000Y_ooool001kooooo00?o
0000ooooooooool07_ooool2o`0000Oooooo0_l0000Qooooo`?o00002oooool4o`0000;ooooo0_l0
0007ooooo`;o00005?ooool2o`0000cooooo1?l0000@ooooo`;o00002_ooool2o`0000;ooooo0_l0
002Fooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o00003?ooool2o`000003ooooool0003o
000002Gooooo0_l00003ooooo`?o00001?ooool2o`0000Oooooo0_l0000;ooooo`;o00005?ooool2
o`0000cooooo1?l0000Looooo`;o00000_ooool2o`0009Kooooo000Nooooo`04o`000?oooooo0000
o`0000cooooo0_l0000<ooooo`;o00009?ooool2o`0000;ooooo0_l00004ooooo`Go000000?ooooo
o`000?l000005?ooool2o`0001Kooooo0_l00036ooooo`007_ooool01?l0003oooooo`000?l00007
ooooo`;o0000=Oooool4o`0000Kooooo0_l00002ooooo`?o00004?ooool2o`0000Gooooo0_l0000<
ooooo`;o00002?ooool2o`000003ooooool0003o000001Cooooo0_l0000Dooooo`;o00001Oooool2
o`00093ooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0000@ooooo`;o00002Oooool2o`00
01Sooooo0_l00008ooooo`;o000000?oooooo`000?l000004_ooool2o`0001?ooooo0_l0000;oooo
o`;o00005?ooool2o`0001Cooooo0_l00005ooooo`;o0000T?ooool001kooooo00?o0000oooooooo
ool03_ooool2o`0000[ooooo0_l00009ooooo`;o00006?ooool2o`0000Sooooo0_l000000ooooooo
0000o`00000Eooooo`;o000000?oooooo`000?l000009?ooool2o`0001Gooooo0_l0002Rooooo`00
7_ooool00ol0003oooooooooo`0<ooooo`Co00003Oooool2o`0002Cooooo0_l0000Cooooo`?o0000
2?ooool2o`000003ooooool0003o000000cooooo0_l00004ooooo`;o00004?ooool2o`0001Gooooo
0_l0002Rooooo`007_ooool00ol0003oooooooooo`0<ooooo`Go00003?ooool2o`0002Cooooo0_l0
0009ooooo`?o00001oooool3o`0000;ooooo0_l0000Eooooo`;o00001?ooool2o`0002Sooooo0_l0
002Eooooo`;o00002_ooool001kooooo0ol0000>ooooo`?o00003_ooool2o`0002?ooooo0_l00008
ooooo`?o00003?ooool2o`00027ooooo0_l0000Rooooo`;o0000UOooool2o`0000[ooooo000Noooo
o`?o00007oooool2o`0000Sooooo0_l00006ooooo`;o00001oooool2o`0000Sooooo0_l0000>oooo
o`;o00001oooool2o`0000Cooooo0_l0000Kooooo`;o00007oooool2o`000:Cooooo0003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006
ooooo`?o0000:Oooool2o`0000Kooooo0_l00007ooooo`;o00005?ooool2o`0000;ooooo0_l00005
ooooo`;o00001_ooool2o`0001Sooooo0_l0000Rooooo`;o00001Oooool2o`0009gooooo0003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q
8@06ooooo`?o00007_ooool2o`0000gooooo0_l0000>ooooo`;o00004Oooool6o`0000Gooooo1?l0
000Nooooo`;o00008Oooool2o`0000Kooooo0_l0002Mooooo`000oooool01Ol@413ooooooooooooo
oooo410@00_ooooo00Go0000ooooooooooooooooo`000005ooooo`Co00007_ooool2o`0000gooooo
0_l00008ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000003ooooo`;o
00002oooool4o`0000Kooooo0ol00011ooooo`;o0000YOooool000?ooooo00Go0000oooooooooooo
ooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801Oooool2o`0000kooooo0_l00009oooo
o`;o00001_ooool2o`0001Kooooo0_l000000ooooooo0000o`000004ooooo`;o00000oooool2o`00
0003ooooool0003o000000Sooooo0_l00005ooooo`;o000000?oooooo`000?l000005?ooool2o`00
0=?ooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003o
c<c<00Kooooo00?o0000ooooooooool00_ooool2o`0000Sooooo0_l00006ooooo`;o000000?ooooo
o`000?l000001_ooool2o`0002Oooooo0_l00008ooooo`Co00000oooool2o`0000_ooooo0_l0000:
ooooo`;o00006?ooool2o`0000Wooooo0_l0002Wooooo`;o00001Oooool000?ooooo00Go410@oooo
oooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`02ooooo`;o00004?ooool2o`0000Oooooo0_l0000aooooo`Ko00000oooool5o`0000Sooooo0_l0
000Tooooo`;o00002Oooool2o`0000;ooooo0_l0002Sooooo`;o00001Oooool000?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003ooooo
ooooo`02ooooo`;o00006Oooool2o`0002;ooooo0_l00002ooooo`;o00002Oooool2o`0000Sooooo
1?l0000=ooooo`;o00001oooool2o`0002;ooooo1Ol0002Zooooo`000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo00;o
oooo0_l0000mooooo`;o00000_ooool2o`0000?ooooo0_l0000@ooooo`;o00003Oooool2o`000003
ooooool0003o000000Cooooo0_l0000Fooooo`;o00002_ooool4o`000:;ooooo0_l00007ooooo`00
7_ooool00ol0003oooooooooo`06ooooo`;o0000=?ooool3o`0000_ooooo0_l00003ooooo`;o0000
2oooool2o`00013ooooo0_l0000Looooo`;o00003?ooool2o`000:3ooooo1?l00007ooooo`007_oo
ool00ol0003oooooooooo`06ooooo`;o0000=?ooool3o`0000Kooooo1?l00006ooooo`;o00002?oo
ool2o`000004ooooool0003o0000o`0001[ooooo0_l0000Nooooo`;o0000X?ooool3o`0000Wooooo
000Nooooo`03o`000?oooooooooo017ooooo0_l0000Kooooo`;o00005Oooool4o`0000oooooo0ol0
0002ooooo`;o00006_ooool2o`0001gooooo0ol0002Pooooo`;o00002_ooool001kooooo00?o0000
ooooooooool04Oooool2o`0001_ooooo0_l0000>ooooo`;o00000_ooool2o`0000Cooooo0_l0000=
ooooo`Go00000oooool4o`0003Gooooo0_l0002]ooooo`007_ooool00ol0003oooooooooo`0Foooo
o`;o00009_ooool6o`0000Cooooo0_l0000=ooooo`Go00000oooool4o`000=_ooooo0_l00007oooo
o`007_ooool00ol0003oooooooooo`0Fooooo`;o00009oooool4o`0001Cooooo1?l00002ooooo`;o
00001oooool2o`0002oooooo0_l0002Uooooo`;o00001oooool001kooooo00?o0000ooooooooool0
5?ooool2o`0002Cooooo0_l00007ooooo`;o00002?ooool2o`0000Sooooo0_l00004ooooo`;o0000
1oooool2o`00013ooooo0_l0000Mooooo`;o0000[_ooool001kooooo00?o0000ooooooooool05?oo
ool2o`0002Cooooo0_l00007ooooo`?o000000?oooooo`000?l000000_ooool4o`0000oooooo0_l0
000Hooooo`;o0000cOooool001kooooo00?o0000ooooooooool09_ooool2o`0001;ooooo0_l00002
ooooo`;o00001?ooool2o`000003ooooool0003o000000;ooooo0_l0000Aooooo`;o00001_ooool2
o`0000Oooooo0_l0000Qooooo`;o000000?oooooo`000?l00000/?ooool001kooooo00?o0000oooo
ooooool09_ooool2o`0001Kooooo0_l000000ooooooo0000o`00000Fooooo`;o00002Oooool4o`00
00;ooooo0_l00003ooooo`;o00008?ooool3o`000003ooooool0003o00000;3ooooo000Nooooo`03
o`000?oooooooooo047ooooo0_l0000Fooooo`;o000000?oooooo`000?l000001_ooool2o`000004
ooooool0003o0000ooooo`?o00005?ooool2o`0000cooooo1?l0002dooooo`007_ooool2o`0004Go
oooo0_l0000Booooo`;o00000_ooool2o`0000Cooooo0_l00003ooooo`Ko00005?ooool2o`0000Wo
oooo0_l000000ooooooo0000o`000004o`000;;ooooo000Nooooo`03o`000?oooooooooo04?ooooo
1Ol0000@ooooo`;o00002?ooool2o`000004ooooool0003o0000ooooo`Go00007oooool2o`0000Co
oooo0ol0002booooo`007_ooool00ol0003oooooooooo`0`ooooo`;o00004Oooool7o`0001Wooooo
1?l000000ooooooo0000o`000005o`0000[ooooo0_l0000Gooooo`;o0000/oooool001kooooo00?o
0000ooooooooool01Oooool2o`0002Wooooo0_l0000Fooooo`?o000000?oooooo`000?l000000_l0
000;ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000007o`0000[ooooo0_l0
000Booooo`;o00001?ooool2o`000;;ooooo000Nooooo`03o`000?oooooooooo00Gooooo0_l0000?
ooooo`;o00008Oooool2o`0000kooooo0_l000000ooooooo0000o`000002o`0000_ooooo0_l00002
ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`00000N
ooooo`?o000000?oooooo`000?l000000_l0002[ooooo`;o00001Oooool001kooooo00?o0000oooo
ooooool05_ooool2o`00023ooooo0ol0000Fooooo`;o00003?ooool2o`0000Gooooo0_l00002oooo
o`;o00008_ooool2o`000003ooooool0003o00000:gooooo0_l00005ooooo`007_ooool00ol0003o
ooooooooo`0hooooo`;o00003oooool2o`000003ooooool0003o000000Go00002_ooool5o`000004
ooooool0003o0000o`0000Gooooo0_l000000ooooooo0000o`000007ooooo`;o00002Oooool2o`00
0<?ooooo000Nooooo`03o`000?oooooooooo04Wooooo3Ol00003ooooo`Ko000000Coooooo`000?l0
003ooooo0ol00005ooooo`;o000000?oooooo`000?l000001oooool2o`0000Wooooo0_l0000:oooo
o`;o00003_ooool2o`000:Oooooo000Nooooo`03o`000?oooooooooo04Wooooo3_l00002ooooo`Co
00001Oooool6o`000003ooooool0003o000001kooooo1?l000000ooooooo0000o`000002o`0000co
oooo0_l0002Wooooo`007_ooool00ol0003oooooooooo`0looooo`;o000000?oooooo`000?l00000
1Oooool2o`000003ooooool0003o000000ko000000?oooooo`000?l000000_ooool7o`000004oooo
ool0003o0000ooooo`;o00007_ooool4o`0000?ooooo0_l0002eooooo`007_ooool00ol0003ooooo
ooooo`0Iooooo`;o00001?ooool2o`0001Wooooo1?l000000ooooooo0000o`000004o`000003oooo
ool0003o000000?ooooo0_l000001Ooooooo0000o`000?l0003ooooo00Co000000Coooooo`000?l0
003ooooo3Ol0000Rooooo`?o0000^oooool001kooooo00?o0000ooooooooool06Oooool2o`0000Co
oooo0_l0000Gooooo`Go000000?oooooo`000?l000001Ol000001?oooooo0000o`000?l00002oooo
o`Oo00000_ooool2o`0000Gooooo0ol00002ooooo`;o00000oooool2o`000004ooooool0003o0000
ooooo`;o00007Oooool2o`000;_ooooo000Nooooo`03o`000?oooooooooo03Oooooo0ol000001?oo
oooo0000o`000?ooool8o`000004ooooool0003o0000ooooo`So00001oooool5o`0000Oooooo0_l0
00001?oooooo0000o`000?ooool2o`0002?ooooo0_l0002eooooo`007_ooool00ol0003ooooooooo
o`0fooooo`?o000000?oooooo`000?l000000ol00004ooooo`Co000000?oooooo`000?l000000_l0
00000ooooooo0000o`000005o`0000Gooooo1Ol0000Pooooo`;o00004?ooool2o`000;Gooooo000N
ooooo`03o`000?oooooooooo03Kooooo1_l000000ooooooo0000o`000003ooooo`Wo00000_ooool2
o`000003ooooool0003o000000?o000000?oooooo`000?l000009_ooool2o`0000Kooooo0_l0002o
ooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o00005Oooool4o`0000Oooooo0_l00002oooo
o`Go00001_ooool4o`000003ooooool0003o000002kooooo0_l0002oooooo`007_ooool2o`00027o
oooo0_l0000Yooooo`;o00004oooool2o`0000Kooooo0_l0000Hooooo`;o0000`oooool001kooooo
00?o0000ooooooooool09Oooool2o`0001Oooooo0_l0000;ooooo`;o00004oooool2o`000003oooo
ool0003o000000?ooooo0ol0000Gooooo`;o00002?ooool2o`000;Wooooo000Nooooo`03o`000?oo
oooooooo02Gooooo0_l0000Gooooo`;o00006_ooool2o`0000Oooooo0_l00003ooooo`Co00008?oo
ool2o`000;Wooooo000Nooooo`03o`000?oooooooooo05Kooooo0_l00002ooooo`;o00003?ooool4
o`0001Cooooo0_l00035ooooo`007_ooool00ol0003oooooooooo`1Fooooo`;o00005?ooool2o`00
00Sooooo0_l00008ooooo`;o0000aOooool001kooooo00?o0000ooooooooool0<Oooool2o`0000Go
oooo0_l00003ooooo`;o00005_ooool2o`0000?ooooo0_l0000@ooooo`;o00002?ooool2o`0001Oo
oooo0_l0002fooooo`007_ooool00ol0003oooooooooo`0Tooooo`;o00002oooool2o`0000Cooooo
1?l00002ooooo`;o00005_ooool2o`0000?ooooo0_l0000cooooo`Co0000]?ooool001kooooo00?o
0000ooooooooool09?ooool2o`00017ooooo1?l0000[ooooo`;o0000:Oooool2o`000;Cooooo000N
ooooo`03o`000?oooooooooo06Kooooo0_l0003Oooooo`007_ooool00ol0003oooooooooo`18oooo
o`;o00005Oooool2o`000>Kooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l0000Gooooo`;o
00002Oooool2o`0000Sooooo0_l0000;ooooo`;o00001?ooool2o`000>3ooooo000Nooooo`03o`00
0?oooooooooo02Cooooo0_l0000Dooooo`;o000000Coooooo`000?l0003o00004?ooool4o`00017o
oooo0_l0003Pooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o00002_ooool2o`0001_ooooo
0_l00002ooooo`;o00004?ooool2o`000?Gooooo000Nooooo`03o`000?oooooooooo017ooooo0_l0
000:ooooo`;o00001_ooool2o`000?oooooo8Oooool001kooooo00?o0000ooooooooool09Oooool2
o`0004;ooooo0_l0003Looooo`007_ooool00ol0003oooooooooo`0kooooo`;o0000;?ooool2o`00
0=cooooo000Nooooo`;o00009Oooool2o`0000Wooooo0_l0000:ooooo`;o00003?ooool2o`0000Ko
oooo0_l00003ooooo`;o0000koooool001kooooo00?o0000ooooooooool09?ooool2o`0000Wooooo
0_l0000Aooooo`;o00000oooool4o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo
0_l0003[ooooo`007_ooool00ol0003oooooooooo`12ooooo`;o00000oooool2o`0000Cooooo0ol0
00000ooooooo0000o`000007ooooo`;o0000joooool001kooooo00?o0000ooooooooool07?ooool2
o`0002oooooo0ol0000<ooooo`;o00009_ooool2o`000<7ooooo000Nooooo`03o`000?oooooooooo
01?ooooo0_l00007ooooo`;o00008?ooool2o`0001cooooo0_l0000Vooooo`;o0000`Oooool001ko
oooo00?o0000ooooooooool04oooool2o`0002Wooooo0_l0003oooooo`Sooooo000Nooooo`03o`00
0?oooooooooo04gooooo0_l0003hooooo`007_ooool00ol0003oooooooooo`1=ooooo`;o00003?oo
ool2o`0001gooooo0_l0003;ooooo`007_ooool00ol0003oooooooooo`1Kooooo`;o00007Oooool2
o`000<_ooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0000hooooo`;o00002Oooool3o`00
0>gooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0000hooooo`;o00002Oooool3o`000>go
oooo000Nooooo`;o00006Oooool2o`0002Oooooo0_l0000?ooooo`;o0000loooool001kooooo0_l0
000Iooooo`;o00006?ooool2o`0000cooooo0ol00005ooooo`;o00000oooool2o`0000?ooooo0_l0
003cooooo`007_ooool00ol0003oooooooooo`0booooo`;o00003?ooool2o`0000Kooooo0_l00003
ooooo`;o0000n?ooool001Cooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
08?ooooo0_l00032ooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Oo
oooo0_l0001Zooooo`;o0000`_ooool001Kooooo00?o0000ooooooooool01Oooool3o`0001Oooooo
0_l0003ooooooboooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000
ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03
o`000?oooooooooo0?ooooooD?ooool001Cooooo00?oEEEEofIVI_l00000oooooomBooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.21665 .88918 Mdot
.29415 .40291 Mdot
.22517 .90664 Mdot
.16522 .71381 Mdot
.32865 .86539 Mdot
.26967 .68957 Mdot
.04534 .89357 Mdot
.27304 .87653 Mdot
.28157 .66045 Mdot
.48399 .39576 Mdot
.27146 .55671 Mdot
.35772 .60668 Mdot
.26949 .91323 Mdot
.03812 .76016 Mdot
.21998 .72452 Mdot
.26344 .79096 Mdot
.3697 .62914 Mdot
.30708 .93408 Mdot
.24368 .94387 Mdot
.18276 .65112 Mdot
.53386 .8502 Mdot
.2965 .65005 Mdot
.39626 .87708 Mdot
.39286 .10177 Mdot
.25263 .68135 Mdot
.26352 .84671 Mdot
.20829 .72019 Mdot
.16602 .71678 Mdot
.28199 .5542 Mdot
.25067 .6385 Mdot
.26254 .94705 Mdot
.2333 .72116 Mdot
.31752 .62545 Mdot
.52683 .69155 Mdot
.39913 .946 Mdot
.15633 .70378 Mdot
.02144 .75556 Mdot
.49314 .80634 Mdot
.37973 .72597 Mdot
.22357 .73296 Mdot
.25771 .94706 Mdot
.22718 .86775 Mdot
.18182 .68069 Mdot
.50729 .77119 Mdot
.17826 .64532 Mdot
.2252 .82422 Mdot
.10771 .36637 Mdot
.20715 .74686 Mdot
.17234 .70658 Mdot
.20624 .05535 Mdot
.36262 .61498 Mdot
.34679 .96273 Mdot
.29145 .88495 Mdot
.15478 .70039 Mdot
.31333 .90409 Mdot
.3089 .89427 Mdot
.7353 .12131 Mdot
.26949 .90633 Mdot
.20444 .72029 Mdot
.28779 .91734 Mdot
.18065 .71836 Mdot
.27545 .85315 Mdot
.07998 .77518 Mdot
.26573 .66411 Mdot
.26697 .81482 Mdot
.30145 .66269 Mdot
.22183 .00238 Mdot
.20584 .72032 Mdot
.25879 .69354 Mdot
.83473 .14847 Mdot
.36249 .85871 Mdot
.35422 .9129 Mdot
.25917 .56786 Mdot
.24491 .52245 Mdot
.3487 .62525 Mdot
.46239 .21809 Mdot
.19698 .98994 Mdot
.18955 .86778 Mdot
.22046 .71375 Mdot
.30169 .97611 Mdot
.26135 .74145 Mdot
.12305 .10801 Mdot
.52249 .79743 Mdot
.27471 .86979 Mdot
.98159 .08043 Mdot
.4487 .76919 Mdot
.28587 .85895 Mdot
.16959 .70934 Mdot
.24319 .7139 Mdot
.31444 .93182 Mdot
.19834 .60882 Mdot
.88932 .19421 Mdot
.21465 .05335 Mdot
.3015 .68176 Mdot
.29945 .93924 Mdot
.25307 .79648 Mdot
.10038 .72003 Mdot
.37607 .95213 Mdot
.2704 .69519 Mdot
.45181 .91906 Mdot
.21215 .79861 Mdot
.36311 .63227 Mdot
.18943 .92325 Mdot
.12033 .76683 Mdot
.26992 .39047 Mdot
.39682 .87305 Mdot
.28621 .79828 Mdot
.25268 .78125 Mdot
.29941 .96328 Mdot
.10439 .95522 Mdot
.03806 .74908 Mdot
.47499 .66364 Mdot
.33547 .65477 Mdot
.28086 .94181 Mdot
.19079 .90442 Mdot
.00351 .0492 Mdot
.20503 .65801 Mdot
.27165 .90638 Mdot
.49381 .40802 Mdot
.19498 .74456 Mdot
.19175 .71319 Mdot
.18198 .80093 Mdot
.33227 .63582 Mdot
.30815 .71044 Mdot
.00268 .25939 Mdot
.50435 .89616 Mdot
.33417 .62997 Mdot
.24756 .92042 Mdot
.55027 .72189 Mdot
.30371 .57138 Mdot
.47966 .92595 Mdot
.21407 .90403 Mdot
.40605 .74463 Mdot
.36411 .90802 Mdot
.31233 .943 Mdot
.30649 .97192 Mdot
.3963 .8692 Mdot
.31758 .8765 Mdot
.19878 .9274 Mdot
.29011 .67008 Mdot
.25311 .9286 Mdot
.26694 .66345 Mdot
.32075 .64936 Mdot
.37775 .89374 Mdot
.12094 .8657 Mdot
.35976 .61181 Mdot
.24633 .88264 Mdot
.21557 .76642 Mdot
.7252 .14052 Mdot
.07715 .02649 Mdot
.04707 .78987 Mdot
.32567 .63538 Mdot
.35058 .60026 Mdot
.18611 .6349 Mdot
.20684 .72205 Mdot
.27505 .89253 Mdot
.3231 .85425 Mdot
.79098 .0542 Mdot
.26017 .67188 Mdot
.30833 .81215 Mdot
.34852 .89856 Mdot
.43184 .94442 Mdot
.47499 .74999 Mdot
.378 .89935 Mdot
.26764 .71085 Mdot
.33814 .86535 Mdot
.22048 .77196 Mdot
.23842 .69953 Mdot
.08109 .93819 Mdot
.3803 .88001 Mdot
.3131 .6315 Mdot
.3038 .74887 Mdot
.42533 .95261 Mdot
.5066 .24942 Mdot
.2272 .90621 Mdot
.31679 .76135 Mdot
.55533 .68347 Mdot
.23559 .8658 Mdot
.06378 .86422 Mdot
.36325 .96124 Mdot
.16708 .69013 Mdot
.35364 .61017 Mdot
.33129 .75267 Mdot
.20775 .56069 Mdot
.56996 .09405 Mdot
.3404 .70377 Mdot
.31613 .81829 Mdot
.19149 .63049 Mdot
.07878 .69799 Mdot
.38476 .81347 Mdot
.23728 .91165 Mdot
.45446 .78492 Mdot
.23946 .90723 Mdot
.25359 .55258 Mdot
.24845 .73691 Mdot
.18399 .67035 Mdot
.4192 .93234 Mdot
.33799 .61115 Mdot
.28409 .65698 Mdot
.33985 .6292 Mdot
.18188 .56414 Mdot
.07419 .7782 Mdot
.35284 .92183 Mdot
.18777 .58558 Mdot
.25402 .67814 Mdot
.16751 .70734 Mdot
.0451 .0555 Mdot
.18105 .71631 Mdot
.0188 .09734 Mdot
.18791 .72152 Mdot
.37934 .87068 Mdot
.23932 .9081 Mdot
.09363 .2168 Mdot
.44634 .97728 Mdot
.3299 .88489 Mdot
.33603 .73257 Mdot
.22908 .75802 Mdot
.42222 .49012 Mdot
.29434 .74434 Mdot
.19311 .00558 Mdot
.75655 .10526 Mdot
.33668 .93453 Mdot
.26721 .66496 Mdot
.24503 .6915 Mdot
.3216 .93735 Mdot
.37399 .88585 Mdot
.35487 .65864 Mdot
.37077 .90622 Mdot
.49965 .15206 Mdot
.31637 .65132 Mdot
.26743 .86604 Mdot
.28749 .90536 Mdot
.32877 .64726 Mdot
.38461 .58721 Mdot
.32986 .71145 Mdot
.53398 .23019 Mdot
.46681 .41633 Mdot
.2633 .93218 Mdot
.50868 .84914 Mdot
.68647 .21494 Mdot
.20609 .91505 Mdot
.32438 .64596 Mdot
.18552 .70117 Mdot
.16194 .91766 Mdot
.37353 .73628 Mdot
.18283 .00738 Mdot
.35113 .92194 Mdot
.29838 .62913 Mdot
.16526 .22604 Mdot
.25565 .93662 Mdot
.34343 .973 Mdot
.34595 .87658 Mdot
.78664 .34435 Mdot
.45729 .80642 Mdot
.99917 .26974 Mdot
.18267 .73571 Mdot
.307 .86978 Mdot
.46466 .89284 Mdot
.31796 .79596 Mdot
.17393 .8791 Mdot
.23014 .88923 Mdot
.27006 .85614 Mdot
.26977 .67628 Mdot
.4024 .9282 Mdot
.32743 .64825 Mdot
.4747 .69196 Mdot
.35357 .65695 Mdot
.51017 .32045 Mdot
.26693 .92046 Mdot
.21908 .72254 Mdot
.26842 .69731 Mdot
.30237 .2479 Mdot
.19983 .70161 Mdot
.30221 .84731 Mdot
.26443 .72916 Mdot
.3708 .87104 Mdot
.30481 .76926 Mdot
.21132 .65761 Mdot
.15889 .70076 Mdot
.36291 .62999 Mdot
.74755 .17044 Mdot
.29867 .64379 Mdot
.39331 .87723 Mdot
.01031 .78739 Mdot
.32462 .86298 Mdot
.26623 .66541 Mdot
.36429 .89429 Mdot
.45173 .96037 Mdot
.16414 .78487 Mdot
.28915 .53815 Mdot
.17486 .70646 Mdot
.91887 .20147 Mdot
.24816 .94414 Mdot
.27381 .56794 Mdot
.0805 .84589 Mdot
.44861 .96138 Mdot
.24552 .82655 Mdot
.3267 .82833 Mdot
.74365 .21056 Mdot
.20372 .11763 Mdot
.4524 .95889 Mdot
.29657 .64612 Mdot
.39953 .9315 Mdot
.36306 .91138 Mdot
.40219 .3933 Mdot
.26485 .98696 Mdot
.21265 .71959 Mdot
.19864 .71667 Mdot
.13472 .31758 Mdot
.07641 .73474 Mdot
.18572 .71417 Mdot
.73738 .22855 Mdot
.26454 .84586 Mdot
.32742 .0039 Mdot
.26137 .73716 Mdot
.15077 .76349 Mdot
.34756 .77075 Mdot
.50728 .22905 Mdot
.31906 .62296 Mdot
.35676 .58489 Mdot
.37328 .72526 Mdot
.32576 .62598 Mdot
.36062 .61388 Mdot
.27998 .75027 Mdot
.27757 .94808 Mdot
.26612 .87184 Mdot
.16009 .70095 Mdot
.23268 .8906 Mdot
.36544 .60911 Mdot
.27344 .85688 Mdot
.18608 .63645 Mdot
.27623 .6801 Mdot
.14083 .81181 Mdot
.24794 .27083 Mdot
.40359 .69448 Mdot
.25946 .01169 Mdot
.54842 .64915 Mdot
.20631 .72051 Mdot
.69975 .02949 Mdot
.4867 .69796 Mdot
.26387 .69909 Mdot
.64873 .60893 Mdot
.24685 .91181 Mdot
.36298 .91004 Mdot
.72975 .03419 Mdot
.02436 .88011 Mdot
.07043 .95128 Mdot
.19764 .02995 Mdot
.41904 .98006 Mdot
.27242 .87891 Mdot
.26503 .90994 Mdot
.32419 .87415 Mdot
.45017 .79072 Mdot
.15518 .74579 Mdot
.04471 .93908 Mdot
.1925 .7077 Mdot
.24537 .87779 Mdot
.37279 .90927 Mdot
.2713 .91696 Mdot
.37705 .59329 Mdot
.3037 .63881 Mdot
.49665 .73968 Mdot
.25733 .94926 Mdot
.38463 .86897 Mdot
.2817 .6536 Mdot
.4341 .78357 Mdot
.99861 .73189 Mdot
.23834 .72547 Mdot
.64707 .19957 Mdot
.2618 .65871 Mdot
.33034 .89611 Mdot
.22068 .718 Mdot
.24084 .91444 Mdot
.30543 .65864 Mdot
.30448 .71109 Mdot
.46078 .9216 Mdot
.15179 .66796 Mdot
.1685 .70512 Mdot
.21592 .19851 Mdot
.25739 .61519 Mdot
.23032 .71011 Mdot
.15849 .70379 Mdot
.62511 .1241 Mdot
.99247 .27501 Mdot
.19899 .70982 Mdot
.22844 .56986 Mdot
.00644 .70846 Mdot
.0229 .80822 Mdot
.20918 .72065 Mdot
.05114 .76572 Mdot
.25517 .93323 Mdot
.30871 .90342 Mdot
.19224 .81111 Mdot
.28829 .88455 Mdot
.31203 .8695 Mdot
.11925 .04082 Mdot
.41032 .72712 Mdot
.46305 .89197 Mdot
.19972 .71902 Mdot
.26867 .94779 Mdot
.19959 .65846 Mdot
.09703 .71956 Mdot
.80005 .07957 Mdot
.27555 .85755 Mdot
.01641 .84032 Mdot
.44843 .67562 Mdot
.26748 .54081 Mdot
.3288 .92959 Mdot
.38853 .88641 Mdot
.37937 .89626 Mdot
.32951 .90042 Mdot
.24678 .6825 Mdot
.34136 .90045 Mdot
.01337 .94431 Mdot
.67782 .15008 Mdot
.34869 .91237 Mdot
.17711 .92648 Mdot
.36828 .88843 Mdot
.76816 .06762 Mdot
.21371 .71557 Mdot
.22843 .71941 Mdot
.05054 .2726 Mdot
.50304 .2307 Mdot
.3258 .9058 Mdot
.26923 .89839 Mdot
.22383 .37671 Mdot
.22092 .54714 Mdot
.29884 .65452 Mdot
.35711 .9099 Mdot
.02774 .11042 Mdot
.68565 .1833 Mdot
.13385 .38886 Mdot
.21915 .98067 Mdot
.16542 .68663 Mdot
.77269 .20824 Mdot
.00975 .89063 Mdot
.26433 .73646 Mdot
.40781 .65022 Mdot
.14977 .9184 Mdot
.17918 .67515 Mdot
.33036 .68428 Mdot
.4949 .69381 Mdot
.52283 .78724 Mdot
.19069 .71607 Mdot
.29647 .41724 Mdot
.18311 .72014 Mdot
.3256 .61933 Mdot
.35373 .87294 Mdot
.87738 .23507 Mdot
.40368 .87105 Mdot
.55136 .82857 Mdot
.26123 .95393 Mdot
.26245 .69547 Mdot
.23659 .70385 Mdot
.31976 .56807 Mdot
.18979 .71566 Mdot
.25829 .66978 Mdot
.15615 .70113 Mdot
.51473 .68861 Mdot
.14965 .9635 Mdot
.15299 .8047 Mdot
.17221 .70928 Mdot
.2439 .7055 Mdot
.22541 .88414 Mdot
.31869 .12221 Mdot
.38453 .95793 Mdot
.32077 .62328 Mdot
.54186 .85483 Mdot
.20001 .72225 Mdot
.44979 .785 Mdot
.26184 .65128 Mdot
.27985 .85646 Mdot
.27454 .86944 Mdot
.27454 .86999 Mdot
.1891 .9014 Mdot
.23072 .71853 Mdot
.22965 .9355 Mdot
.27187 .88763 Mdot
.75009 .11327 Mdot
.33273 .6701 Mdot
.19349 .8384 Mdot
.28251 .60884 Mdot
.31459 .64747 Mdot
.26101 .93442 Mdot
.22753 .89424 Mdot
.40181 .64601 Mdot
.33587 .64384 Mdot
.88339 .26842 Mdot
.29886 .72771 Mdot
.13975 .72694 Mdot
.25589 .92233 Mdot
.24109 .69507 Mdot
.11146 .94242 Mdot
.01173 .72437 Mdot
.19262 .59285 Mdot
.32499 .60406 Mdot
.14735 .91667 Mdot
.332 .61491 Mdot
.41747 .10553 Mdot
.33369 .75821 Mdot
.15635 .9534 Mdot
.33351 .59659 Mdot
.29058 .75617 Mdot
.58326 .21338 Mdot
.33424 .91622 Mdot
.18851 .02244 Mdot
.27678 .85296 Mdot
.08558 .80825 Mdot
.25157 .6751 Mdot
.22194 .6269 Mdot
.2774 .94344 Mdot
.24183 .90198 Mdot
.27313 .84539 Mdot
.64603 .10783 Mdot
.3138 .86229 Mdot
.37289 .58081 Mdot
.15333 .70467 Mdot
.2587 .79837 Mdot
.76144 .06882 Mdot
.27302 .94634 Mdot
.36302 .91726 Mdot
.20068 .89579 Mdot
.22614 .71118 Mdot
.34178 .63536 Mdot
.45709 .83118 Mdot
.0245 .75453 Mdot
.11531 .90229 Mdot
.29065 .67039 Mdot
.34898 .92157 Mdot
.50943 .68535 Mdot
.54025 .77696 Mdot
.13392 .78013 Mdot
.32479 .86176 Mdot
.37829 .70867 Mdot
.27464 .87238 Mdot
.20807 .78574 Mdot
.29301 .80087 Mdot
.29911 .63837 Mdot
.44664 .76147 Mdot
.12298 .63222 Mdot
.29013 .67053 Mdot
.69017 .12381 Mdot
.36131 .61341 Mdot
.21867 .71924 Mdot
.20157 .86475 Mdot
.08528 .7695 Mdot
.87253 .24015 Mdot
.36364 .93159 Mdot
.39411 .874 Mdot
.26933 .8728 Mdot
.03253 .0442 Mdot
.1599 .58696 Mdot
.31018 .6315 Mdot
.55329 .67803 Mdot
.21757 .7216 Mdot
.02713 .16451 Mdot
.87061 .2795 Mdot
.20464 .72351 Mdot
.14752 .70125 Mdot
.07118 .88837 Mdot
.3881 .87892 Mdot
.32965 .61881 Mdot
.45582 .75834 Mdot
.53284 .81487 Mdot
.35616 .90136 Mdot
.16973 .70719 Mdot
.34024 .87917 Mdot
.26716 .67848 Mdot
.1909 .18171 Mdot
.24791 .7101 Mdot
.05941 .56873 Mdot
.12742 .75563 Mdot
.23846 .7176 Mdot
.23514 .8881 Mdot
.294 .9128 Mdot
.30701 .64516 Mdot
.41059 .63277 Mdot
.28038 .55067 Mdot
.34877 .88111 Mdot
.16191 .97867 Mdot
.12633 .1944 Mdot
.87836 .17532 Mdot
.1796 .90645 Mdot
.25739 .9414 Mdot
.43068 .89813 Mdot
.16204 .7063 Mdot
.32933 .70941 Mdot
.97009 .92005 Mdot
.05329 .75107 Mdot
.27204 .90932 Mdot
.27082 .89295 Mdot
.28418 .93095 Mdot
.37303 .90037 Mdot
.33518 .62071 Mdot
.34033 .59549 Mdot
.26707 .84532 Mdot
.27073 .72776 Mdot
.27426 .86983 Mdot
.16119 .70591 Mdot
.37735 .90434 Mdot
.31551 .64258 Mdot
.22869 .71538 Mdot
.25305 .91366 Mdot
.37809 .95141 Mdot
.04782 .77227 Mdot
.38038 .8972 Mdot
.21517 .7426 Mdot
.28177 .63861 Mdot
.09776 .73125 Mdot
.22899 .89298 Mdot
.12677 .64434 Mdot
.08342 .83234 Mdot
.24401 .68211 Mdot
.14315 .0009 Mdot
.21918 .94024 Mdot
.28563 .7697 Mdot
.35329 .91164 Mdot
.40911 .75868 Mdot
.28227 .67522 Mdot
.19843 .18589 Mdot
.01949 .74243 Mdot
.98829 .60954 Mdot
.23634 .90384 Mdot
.46578 .96721 Mdot
.29282 .93214 Mdot
.3507 .62328 Mdot
.54438 .69775 Mdot
.45768 .80155 Mdot
.34557 .91078 Mdot
.24837 .66202 Mdot
.1864 .91647 Mdot
.24505 .6892 Mdot
.27574 .90789 Mdot
.15287 .88027 Mdot
.24288 .7161 Mdot
.32554 .96555 Mdot
.274 .87347 Mdot
.20446 .03863 Mdot
.32025 .88409 Mdot
.22653 .72118 Mdot
.22412 .59638 Mdot
.25778 .70092 Mdot
.22813 .8961 Mdot
.24614 .58105 Mdot
.00914 .78404 Mdot
.33573 .93556 Mdot
.34692 .62193 Mdot
.74123 .09121 Mdot
.27693 .86317 Mdot
.09651 .72404 Mdot
.3437 .10561 Mdot
.34165 .61089 Mdot
.55459 .69278 Mdot
.24809 .6909 Mdot
.87588 .23987 Mdot
.22739 .72331 Mdot
.26347 .90644 Mdot
.7564 .2507 Mdot
.00816 .09377 Mdot
.19496 .71735 Mdot
.15491 .68164 Mdot
.38748 .76553 Mdot
.34619 .37718 Mdot
.18778 .71046 Mdot
.46339 .72991 Mdot
.52252 .7317 Mdot
.20583 .71674 Mdot
.04869 .9095 Mdot
.45715 .91039 Mdot
.54648 .72585 Mdot
.27294 .59651 Mdot
.28136 .3752 Mdot
.24997 .54557 Mdot
.24768 .59936 Mdot
.66672 .22981 Mdot
.27154 .84701 Mdot
.75289 .40826 Mdot
.31433 .90712 Mdot
.10063 .05024 Mdot
.00432 .1014 Mdot
.41768 .62235 Mdot
.37478 .88273 Mdot
.66577 .14873 Mdot
.24772 .92098 Mdot
.24804 .71051 Mdot
.43687 .97078 Mdot
.34981 .63991 Mdot
.07849 .96948 Mdot
.14205 .76262 Mdot
.27723 .93345 Mdot
.18404 .78934 Mdot
.19791 .5984 Mdot
.23953 .00273 Mdot
.01972 .55414 Mdot
.32117 .63298 Mdot
.38541 .77094 Mdot
.24426 .70168 Mdot
.12564 .82152 Mdot
.3411 .25915 Mdot
.21231 .16829 Mdot
.37179 .56023 Mdot
.16348 .76136 Mdot
.27474 .89597 Mdot
.19876 .92914 Mdot
.36899 .74684 Mdot
.3376 .63826 Mdot
.38546 .09597 Mdot
.37046 .18325 Mdot
.26906 .55075 Mdot
.29427 .64739 Mdot
.4565 .22846 Mdot
.32132 .86648 Mdot
.06037 .73791 Mdot
.66146 .33886 Mdot
.37658 .88734 Mdot
.22121 .34032 Mdot
.30577 .63707 Mdot
.28378 .87743 Mdot
.00419 .09437 Mdot
.31638 .63664 Mdot
.23552 .89876 Mdot
.30237 .58374 Mdot
.36308 .91742 Mdot
.00021 .80536 Mdot
.56195 .83257 Mdot
.85903 .12726 Mdot
.27628 .00643 Mdot
.19448 .71317 Mdot
.24752 .57341 Mdot
.74174 .09057 Mdot
.28004 .59743 Mdot
.28426 .61249 Mdot
.26433 .89125 Mdot
.28178 .66823 Mdot
.99065 .06692 Mdot
.98964 .90334 Mdot
.89112 .2275 Mdot
.88483 .26598 Mdot
.36008 .61588 Mdot
.96809 .09713 Mdot
.37216 .76255 Mdot
.16565 .7063 Mdot
.2309 .9425 Mdot
.00906 .88745 Mdot
.36621 .58122 Mdot
.33972 .62676 Mdot
.2506 .6109 Mdot
.73973 .11467 Mdot
.32756 .62018 Mdot
.44686 .98605 Mdot
.19684 .68166 Mdot
.21625 .85401 Mdot
.28724 .55866 Mdot
.18575 .89402 Mdot
.34728 .92778 Mdot
.30188 .72226 Mdot
.36184 .88444 Mdot
.23795 .71171 Mdot
.23863 .92871 Mdot
.25988 .93003 Mdot
.8469 .08375 Mdot
.27368 .87304 Mdot
.06567 .16207 Mdot
.22195 .85449 Mdot
.26236 .52492 Mdot
.18129 .70251 Mdot
.43582 .89871 Mdot
.70529 .13604 Mdot
.3406 .61303 Mdot
.0709 .18457 Mdot
.25263 .69712 Mdot
.11085 .75048 Mdot
.39754 .87137 Mdot
.34615 .87635 Mdot
.06087 .04694 Mdot
.26157 .9444 Mdot
.32652 .68437 Mdot
.25747 .92251 Mdot
.32284 .56106 Mdot
.28902 .55485 Mdot
.16453 .71276 Mdot
.28423 .74039 Mdot
.70903 .235 Mdot
.39955 .6133 Mdot
.25468 .79475 Mdot
.32179 .84335 Mdot
.16495 .7363 Mdot
.28793 .67086 Mdot
.24122 .69414 Mdot
.26278 .88266 Mdot
.03153 .85939 Mdot
.64915 .19779 Mdot
.987 .83069 Mdot
.24744 .85713 Mdot
.43627 .97349 Mdot
.27096 .90596 Mdot
.13552 .73438 Mdot
.03035 .88809 Mdot
.15133 .70727 Mdot
.34222 .92776 Mdot
.6128 .31138 Mdot
.26746 .63425 Mdot
.18399 .90539 Mdot
.30892 .6699 Mdot
.31451 .8687 Mdot
.33291 .92721 Mdot
.12707 .92098 Mdot
.35739 .50559 Mdot
.44282 .93699 Mdot
.3531 .923 Mdot
.45609 .93509 Mdot
.14878 .70282 Mdot
.20671 .89447 Mdot
.99787 .73023 Mdot
.17372 .66717 Mdot
.22728 .71314 Mdot
.16395 .79507 Mdot
.72969 .14521 Mdot
.20419 .72631 Mdot
.05304 .89361 Mdot
.27406 .87361 Mdot
.27564 .8752 Mdot
.30851 .63619 Mdot
.27393 .89413 Mdot
.27762 .86419 Mdot
.31643 .86795 Mdot
.28961 .87413 Mdot
.27226 .68948 Mdot
.05478 .0345 Mdot
.38909 .8901 Mdot
.22505 .64183 Mdot
.44011 .96858 Mdot
.28084 .92275 Mdot
.03918 .08669 Mdot
.19798 .85138 Mdot
.38329 .88539 Mdot
.26868 .92648 Mdot
.17224 .70589 Mdot
.29481 .64084 Mdot
.05754 .18478 Mdot
.98684 .74386 Mdot
.27684 .87346 Mdot
.21012 .71969 Mdot
.28829 .66411 Mdot
.73826 .15107 Mdot
.05629 .84599 Mdot
.5103 .88475 Mdot
.25699 .90441 Mdot
.26883 .84517 Mdot
.21637 .85662 Mdot
.46038 .87105 Mdot
.31435 .88929 Mdot
.25572 .9466 Mdot
.24485 .03348 Mdot
.1861 .73752 Mdot
.21339 .1894 Mdot
.27368 .87382 Mdot
.24299 .35215 Mdot
.34007 .68259 Mdot
.22349 .8385 Mdot
.27657 .86765 Mdot
.1715 .71692 Mdot
.29926 .64384 Mdot
.39164 .9779 Mdot
.26081 .84793 Mdot
.35124 .61431 Mdot
.24266 .94344 Mdot
.29459 .76525 Mdot
.09738 .27641 Mdot
.27235 .89127 Mdot
.24 .97535 Mdot
.18332 .74972 Mdot
.25759 .67679 Mdot
.14085 .77846 Mdot
.2485 .71154 Mdot
.29315 .86283 Mdot
.0476 .25063 Mdot
.38923 .76662 Mdot
.0659 .73524 Mdot
.32052 .94188 Mdot
.00311 .78241 Mdot
.19821 .66957 Mdot
.2745 .86905 Mdot
.21135 .89349 Mdot
.17225 .90421 Mdot
.22083 .89248 Mdot
.18902 .89093 Mdot
.71102 .17212 Mdot
.29857 .64837 Mdot
.40954 .72612 Mdot
.57939 .19872 Mdot
.19683 .69235 Mdot
.19196 .97693 Mdot
.30411 .64384 Mdot
.15668 .31599 Mdot
.24269 .81181 Mdot
.87099 .06834 Mdot
.21214 .71492 Mdot
.07721 .79281 Mdot
.32519 .69395 Mdot
.3125 .94339 Mdot
.36413 .64633 Mdot
.07997 .25399 Mdot
.15138 .85991 Mdot
.03458 .97251 Mdot
.99963 .92359 Mdot
.41307 .61611 Mdot
.3257 .84379 Mdot
.2521 .94497 Mdot
.25061 .90943 Mdot
.364 .65106 Mdot
.46216 .73532 Mdot
.41196 .15166 Mdot
.29925 .64007 Mdot
.39554 .72097 Mdot
.27495 .99386 Mdot
.49434 .7407 Mdot
.05799 .7736 Mdot
.27843 .797 Mdot
.29186 .65951 Mdot
.51955 .23193 Mdot
.2401 .98715 Mdot
.27682 .0306 Mdot
.277 .86259 Mdot
.22889 .72235 Mdot
.45944 .90748 Mdot
.54773 .14295 Mdot
.32287 .55765 Mdot
.42456 .81959 Mdot
.01225 .09421 Mdot
.1715 .87125 Mdot
.3953 .8676 Mdot
.27282 .887 Mdot
.32756 .64818 Mdot
.45235 .85073 Mdot
.24873 .92537 Mdot
.67018 .27334 Mdot
.29137 .61813 Mdot
.20367 .71786 Mdot
.53576 .65504 Mdot
.2713 .89895 Mdot
.22287 .93218 Mdot
.25059 .68904 Mdot
.08485 .78521 Mdot
.16224 .97392 Mdot
.25871 .70029 Mdot
.25166 .56459 Mdot
.18466 .00354 Mdot
.28591 .6719 Mdot
.25512 .03454 Mdot
.23306 .69953 Mdot
.75047 .25232 Mdot
.21486 .90678 Mdot
.16974 .75 Mdot
.01011 .8335 Mdot
.2451 .90032 Mdot
.5459 .0166 Mdot
.44 .96651 Mdot
.09949 .69069 Mdot
.07973 .34007 Mdot
.28902 .6438 Mdot
.23649 .70136 Mdot
.2073 .72666 Mdot
.29874 .91744 Mdot
.27359 .86698 Mdot
.05658 .92251 Mdot
.31619 .85821 Mdot
.37243 .8813 Mdot
.90397 .09572 Mdot
.08513 .94334 Mdot
.32572 .94525 Mdot
.81455 .40132 Mdot
.37141 .14644 Mdot
.07186 .83385 Mdot
.25468 .30072 Mdot
.27616 .85414 Mdot
.32828 .82937 Mdot
.14465 .80076 Mdot
.2106 .71872 Mdot
.18698 .752 Mdot
.27883 .89476 Mdot
.33159 .93837 Mdot
.28228 .89615 Mdot
.31852 .82026 Mdot
.24535 .60765 Mdot
.25069 .94687 Mdot
.31269 .57801 Mdot
.117 .0502 Mdot
.32183 .95269 Mdot
.20437 .74395 Mdot
.54556 .83483 Mdot
.16194 .71271 Mdot
.33641 .5734 Mdot
.18555 .982 Mdot
.29203 .64512 Mdot
.19316 .71375 Mdot
.20562 .81983 Mdot
.22339 .00952 Mdot
.3446 .84791 Mdot
.31288 .61718 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`;o000000?oooooo`000?oo
ool02Oooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l00002ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`?o0000
00Goooooo`000?l0003oooooo`000005ooooo`;o00001?ooool2o`0000;ooooo00?o0000oooooooo
ool01Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003oooooooooo`0gooooo`;o0000
0_ooool2o`0000Sooooo0_l0000?ooooo`;o0000koooool001kooooo00?o0000ooooooooool0AOoo
ool2o`0000Wooooo0_l0003eooooo`007_ooool00ol0003oooooooooo`1@ooooo`;o0000Foooool2
o`0009Sooooo000Nooooo`03o`000?oooooooooo0:gooooo0_l0002Hooooo`007_ooool00ol0003o
ooooooooo`0iooooo`;o0000ooooool=ooooo`007_ooool00ol0003oooooooooo`0iooooo`;o0000
ooooool=ooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o0000oooooolaooooo`007_ooool0
0ol0003oooooooooo`0Eooooo`;o00009Oooool2o`0001Sooooo0_l00027ooooo`;o0000I_ooool0
01kooooo00?o0000ooooooooool03_ooool2o`0002cooooo0_l0000=ooooo`;o00000_ooool2o`00
00Gooooo0_l00027ooooo`;o00002?ooool2o`0005cooooo000Nooooo`03o`000?oooooooooo00ko
oooo0_l0000kooooo`;o00000_ooool2o`0009Sooooo0_l0001Looooo`007_ooool00ol0003ooooo
ooooo`0Sooooo`;o00006Oooool2o`000?oooooo2?ooool001kooooo00?o0000ooooooooool01_oo
ool2o`0001_ooooo0_l0000Iooooo`;o0000ooooool8ooooo`007_ooool00ol0003oooooooooo`06
ooooo`;o00002?ooool2o`000?oooooo=_ooool001kooooo0_l0000Aooooo`;o00002oooool2o`00
00?ooooo0_l0003oooooobCooooo000Nooooo`;o00007_ooool2o`0000?ooooo0_l0000Nooooo`;o
0000ooooool4ooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o0000<_ooool2o`000003oooo
ool0003o00000;Wooooo0_l00018ooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o0000<_oo
ool2o`000;cooooo0_l00018ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0loooool2o`000003
ooooool0003o000001oooooo0_l0000Uooooo`;o00001oooool001kooooo00?o0000ooooooooool0
loooool2o`000003ooooool0003o000001oooooo0_l0000Uooooo`;o00001oooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?oooooo0Oooool2o`0003Wooooo0_l0000:ooooo`007_ooool00ol0003o
ooooooooo`3oooooo`7ooooo0_l0000=ooooo`;o0000:_ooool2o`0000[ooooo000Nooooo`03o`00
0?oooooooooo00Wooooo0_l0003oooooo`Gooooo0_l0000fooooo`007_ooool00ol0003ooooooooo
o`09ooooo`;o0000h_ooool2o`0005Sooooo000Nooooo`03o`000?oooooooooo0>gooooo0_l0001H
ooooo`007_ooool5o`0007Oooooo0_l0000jooooo`;o0000=_ooool2o`0003?ooooo0_l0000Soooo
o`007_ooool7o`0007Gooooo0_l0000jooooo`;o0000Joooool2o`0001?ooooo0_l0000>ooooo`00
7_ooool2o`0000?ooooo0_l0001hooooo`;o0000^Oooool2o`0000kooooo000Nooooo`;o0000KOoo
ool2o`0000kooooo0_l00006ooooo`;o0000K?ooool2o`0005?ooooo000Nooooo`03o`000?oooooo
oooo02Cooooo0_l00016ooooo`;o00005_ooool2o`0004Sooooo0_l0000Rooooo`;o0000Doooool0
01kooooo00?o0000ooooooooool01Oooool2o`0001gooooo0_l0002Xooooo`;o0000Moooool001ko
oooo00?o0000ooooooooool01Oooool2o`000>Gooooo0_l00002ooooo`;o0000EOooool001kooooo
00?o0000ooooooooool0?_ooool2o`000:cooooo0_l00002ooooo`;o0000EOooool001kooooo00?o
0000ooooooooool0?_ooool2o`000:_ooooo0_l0001Jooooo`007_ooool00ol0003oooooooooo`1S
ooooo`;o0000H_ooool2o`0001?ooooo0_l0000=ooooo`;o0000F_ooool001kooooo00?o0000oooo
ooooool0Hoooool2o`0006;ooooo0_l0000Cooooo`;o0000=Oooool2o`0003;ooooo000Nooooo`03
o`000?oooooooooo0?oooooo5?ooool2o`0003;ooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0hOooool2o`0006Cooooo000Nooooo`03o`000?oooooo
oooo0>7ooooo0_l0001Tooooo`007_ooool00ol0003oooooooooo`3Xooooo`;o0000GOooool001ko
oooo00?o0000ooooooooool0[_ooool2o`0003Sooooo0ol0001Looooo`007_ooool00ol0003ooooo
ooooo`1eooooo`;o0000=oooool2o`0002Cooooo0_l0000Cooooo`;o00008?ooool2o`0003[ooooo
000Nooooo`;o0000M_ooool2o`0000_ooooo0_l0000Jooooo`;o0000=?ooool2o`0000;ooooo0_l0
000Booooo`;o00007Oooool2o`0003[ooooo000Nooooo`03o`000?oooooooooo08;ooooo0_l0000J
ooooo`;o0000>?ooool2o`0001;ooooo0_l0001Iooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
4Oooool2o`000?oooooo=Oooool001kooooo00?o0000ooooooooool01Oooool2o`0000[ooooo0_l0
003oooooocGooooo000Nooooo`03o`000?oooooooooo00Gooooo0_l0000jooooo`;o0000[?ooool2
o`0005Kooooo000Nooooo`03o`000?oooooooooo047ooooo0_l0002Pooooo`;o00002_ooool2o`00
05Kooooo000Nooooo`03o`000?oooooooooo0>?ooooo0_l0000dooooo`;o0000;?ooool001kooooo
00?o0000ooooooooool0oooooolJooooo`;o0000;?ooool001kooooo00?o0000ooooooooool0>_oo
ool2o`000?oooooo3?ooool001kooooo00?o0000ooooooooool03oooool2o`0000;ooooo0_l0000U
ooooo`Co0000=_ooool2o`0006Gooooo0_l0001Zooooo`007_ooool00ol0003oooooooooo`0?oooo
o`;o00000_ooool2o`0002Oooooo0_l0000fooooo`;o0000IOooool2o`0006[ooooo000Nooooo`03
o`000?oooooooooo047ooooo0_l0003oooooo`Gooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo02Gooooo0_l0000Jooooo`;o
0000f_ooool2o`0002Sooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo02Gooooo0_l0002Xoooo
o`;o0000C?ooool2o`0002Sooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onH
V9So8B4Qonk^kP07ooooo`?o0000@_ooool2o`0007Cooooo0_l0000Dooooo`?o0000M_ooool000?o
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000oooo
ooooool0@_ooool2o`0007Cooooo0_l0000Dooooo`;o0000Eoooool2o`0001kooooo0003ooooo`05
o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo
0?oooooo:?ooool2o`0001kooooo0003ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo0>kooooo0_l00007ooooo`;o0000C_ooool000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool0
0ol0003oooooooooo`2jooooo`;o0000<_ooool2o`0000Oooooo0_l0001>ooooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oo
oooooooo0;[ooooo0_l0000Oooooo`;o0000J_ooool001kooooo00?o0000ooooooooool06_ooool2
o`0007Kooooo0_l00017ooooo`;o0000J_ooool001kooooo00?o0000ooooooooool06_ooool2o`00
07Kooooo0_l0002cooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo03;ooooo0_l0001Looooo`;o0000F_ooool2o`00033ooooo0_l0000Wooooo`007_oo
ool00ol0003oooooooooo`0booooo`;o0000G?ooool2o`0000gooooo1?l00002ooooo`;o00000_oo
ool2o`0002[ooooo0_l0000Eooooo`;o0000<?ooool2o`0002Oooooo000Nooooo`03o`000?oooooo
oooo09oooooo1?l00002ooooo`;o00000_ooool2o`0002[ooooo0_l0000;ooooo`;o0000=Oooool2
o`0002cooooo000Nooooo`03o`000?oooooooooo0>;ooooo0_l0000eooooo`;o0000;?ooool001ko
oooo00?o0000ooooooooool0oooooolIooooo`?o0000;?ooool001kooooo00?o0000ooooooooool0
oooooolIooooo`?o0000;?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`1Nooooo`;o0000@Oooool2o`000:Cooooo000Nooooo`;o00003?ooool2o`00
057ooooo0_l00011ooooo`;o0000COooool4o`0005?ooooo000Nooooo`03o`000?oooooooooo00_o
oooo0_l00009ooooo`;o0000f?ooool4o`0005?ooooo000Nooooo`;o00005oooool2o`0005?ooooo
0_l0003Jooooo`007_ooool2o`0006cooooo0_l0003Jooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo7?ooool3o`0002Wooooo000Nooooo`03
o`000?oooooooooo04cooooo0_l0003=ooooo`?o00008oooool2o`0000Cooooo000Nooooo`03o`00
0?oooooooooo00cooooo0_l0000nooooo`;o0000R?ooool2o`0006Oooooo1?l00004ooooo`007_oo
ool00ol0003oooooooooo`0<ooooo`;o00003_ooool2o`000;Sooooo0_l0001Wooooo`;o00001_oo
ool001kooooo00?o0000ooooooooool07?ooool2o`000?Wooooo0_l0000^ooooo`007_ooool00ol0
003oooooooooo`3ooooooaSooooo0_l0000^ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo0_l0001@ooooo`;o0000m_ooool001kooooo00?o0000ooooooooool0
Coooool2o`000?Kooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0`oooool2o`0008;ooooo000Nooooo`03o`000?oooooooooo0<?ooooo0_l00022oooo
o`007_ooool00ol0003oooooooooo`0Xooooo`;o00001Oooool2o`000?oooooo5oooool001kooooo
00?o0000ooooooooool0:?ooool2o`0000Gooooo0_l0001aooooo`;o0000Xoooool001kooooo00?o
0000ooooooooool0X_ooool2o`000:?ooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0dooo
ool2o`0007;ooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l0000/ooooo`;o0000SOooool2
o`0007;ooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l0000/ooooo`;o0000]_ooool2o`00
04Wooooo000Nooooo`03o`000?oooooooooo0?cooooo0_l00019ooooo`007_ooool2o`000?oooooo
BOooool001kooooo00?o0000ooooooooool0Boooool2o`000?[ooooo000Nooooo`03o`000?oooooo
oooo04_ooooo0_l0003jooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool07oooool2o`000?oooooo
9oooool001kooooo00?o0000ooooooooool07oooool2o`000?oooooo9oooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`1Gooooo`;o0000k_ooool001ko
oooo00?o0000ooooooooool0AOooool2o`00013ooooo0_l0000Cooooo`;o0000fOooool001kooooo
00?o0000ooooooooool0AOooool2o`0002Gooooo0_l0003Iooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l0003ooooooaoooooo000Noooo
o`03o`000?oooooooooo02Oooooo0_l0000[ooooo`;o0000lOooool000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000oooo
ooooool0E?ooool2o`0002Wooooo0_l00036ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Ooooool2o`00
01Sooooo0_l0002/ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006oooo
o`?o0000VOooool2o`000:cooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01?m4
A4CogMgMooooool00007ooooo`03o`000?oooooooooo05cooooo0_l0002Wooooo`;o0000@?ooool0
00?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o
0000ooooooooool0G?ooool2o`000:Oooooo0_l00010ooooo`000oooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`2Looooo`;o0000Dooo
ool2o`0005Cooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00
0007ooooo`03o`000?oooooooooo09cooooo0_l0001Cooooo`;o0000E?ooool000?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0U?oo
ool2o`000;7ooooo000Nooooo`03o`000?oooooooooo05cooooo0_l0000fooooo`;o0000/Oooool0
01kooooo00?o0000ooooooooool0G?ooool2o`000>Wooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
QOooool2o`000<3ooooo000Nooooo`03o`000?oooooooooo08Gooooo0_l00030ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo073ooooo0_l0003Eooooo`007_oo
ool00ol0003oooooooooo`1`ooooo`;o0000eOooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`1<ooooo`;o0000nOooool001kooooo00?o0000ooooooooool0C?ooool2o`0000?ooooo0_l0003d
ooooo`007_ooool00ol0003oooooooooo`1Aooooo`;o0000m?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo05[ooooo0_l0003[ooooo`007_ooool00ol0003oooooooooo`1Cooooo`;o00001Oooool2
o`000>_ooooo000Nooooo`03o`000?oooooooooo04gooooo0_l00004ooooo`;o0000l_ooool001ko
oooo00?o0000ooooooooool0A?ooool2o`0000Oooooo0_l0003hooooo`007_ooool2o`0004Gooooo
0_l0000=ooooo`;o00000_ooool2o`000>kooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0
001:ooooo`;o00000oooool2o`0000;ooooo1Ol0003[ooooo`007_ooool00ol0003oooooooooo`02
ooooo`;o0000B_ooool2o`0000Cooooo0_l00002ooooo`Co00002Oooool2o`000>3ooooo000Noooo
o`03o`000?oooooooooo03oooooo0_l0000Cooooo`;o00000oooool2o`0000[ooooo0_l0000>oooo
o`;o0000d?ooool001kooooo00?o0000ooooooooool0=oooool2o`0000Kooooo0_l0000Hooooo`;o
00002_ooool2o`0000kooooo0_l0003@ooooo`007_ooool00ol0003oooooooooo`0gooooo`;o0000
5Oooool2o`000?Oooooo000Nooooo`03o`000?oooooooooo00oooooo0_l0000eooooo`;o00001_oo
ool4o`0000?ooooo0_l0000=ooooo`;o0000hOooool001kooooo00?o0000ooooooooool03oooool2
o`0003Gooooo0_l00004ooooo`;o00000_ooool2o`0000?ooooo0_l00008ooooo`;o00000oooool2
o`0000?ooooo0_l0003Looooo`007_ooool00ol0003oooooooooo`1<ooooo`;o00004Oooool2o`00
00Sooooo0_l0003Looooo`007_ooool00ol0003oooooooooo`1Rooooo`;o0000hoooool001kooooo
00?o0000ooooooooool0C?ooool2o`0001Cooooo0_l0000?ooooo`Co0000d?ooool001kooooo00?o
0000ooooooooool0>Oooool2o`00017ooooo0_l0000@ooooo`;o00004?ooool2o`000003ooooool0
003o000000;o0000d?ooool001kooooo00?o0000ooooooooool0<?ooool2o`0000Oooooo0_l0000S
ooooo`;o00004?ooool2o`0000Oooooo0_l0003<ooooo`007_ooool00ol0003oooooooooo`0`oooo
o`;o0000Aoooool2o`000<cooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo03_ooooo0_l0000i
ooooo`;o0000coooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0>oooool2o`0000Sooooo0_l0
000>ooooo`Co00003oooool2o`000003ooooool0003o000000Wooooo0_l0003?ooooo`000oooool0
1Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000
??ooool2o`0000Oooooo0_l00005ooooo`;o00001oooool4o`0000oooooo0_l000001?oooooo0000
o`000?ooool2o`000=Oooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003o
V9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0??ooool2o`0000kooooo0_l0000Hoooo
o`;o00001_ooool2o`000=Oooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0
003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0I_ooool2o`0000Sooooo0_l0003E
ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool0
0ol0003oooooooooo`0looooo`;o00003_ooool2o`0000[ooooo0_l0000Eooooo`?o000000?ooooo
o`000?l00000F_ooool2o`0006cooooo0_l00008ooooo`000oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0looooo`;o00003_ooool3
o`0000Wooooo0_l0000@ooooo`?o00000_ooool6o`0000Wooooo0_l0001?ooooo`;o0000K?ooool2
o`0000Sooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@
4106ooooo`03o`000?oooooooooo04gooooo0_l000000ooooooo0000o`000006ooooo`;o00003_oo
ool5o`000004ooooool0003o0000ooooo`?o00002_ooool2o`0000;ooooo0_l00033ooooo`007_oo
ool00ol0003oooooooooo`1@ooooo`;o00002Oooool2o`0000Gooooo0_l00002ooooo`Co00001?oo
ool2o`000004ooooool0003o0000o`0000kooooo0_l00033ooooo`007_ooool00ol0003ooooooooo
o`1Kooooo`;o00001Oooool2o`0000;ooooo1Ol00002ooooo`;o00005Oooool2o`000<7ooooo000N
ooooo`03o`000?oooooooooo06?ooooo1Ol000000ooooooo0000o`000002ooooo`?o00005?ooool2
o`000<7ooooo000Nooooo`03o`000?oooooooooo04Cooooo0_l0000Mooooo`Go00000_ooool2o`00
0004ooooool0003o0000o`000=Oooooo000Nooooo`03o`000?oooooooooo03[ooooo0_l00008oooo
o`;o00005oooool2o`0000;ooooo0ol00002ooooo`;o000000Coooooo`000?l0003o00001_ooool4
o`000=7ooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l0000Booooo`Co00005oooool2o`00
00Sooooo0_l00002ooooo`Go00000oooool3o`0000Kooooo1?l0000;ooooo`;o0000a?ooool001ko
oooo00?o0000ooooooooool09?ooool2o`0001;ooooo0_l0000Iooooo`;o00002_ooool3o`000003
ooooool0003o000000Go000000?oooooo`000?l000001Oooool2o`0000gooooo0_l00034ooooo`00
7_ooool00ol0003oooooooooo`0hooooo`;o00004oooool2o`0000Sooooo0_l00003ooooo`Ko0000
00Coooooo`000?l0003ooooo1ol000000ooooooo0000o`00003Gooooo`007_ooool00ol0003ooooo
ooooo`15ooooo`;o00001_ooool2o`0000Sooooo0_l000000ooooooo0000o`000005o`000003oooo
ool0003o000000Gooooo0ol00002ooooo`;o0000eoooool001kooooo00?o0000ooooooooool09Ooo
ool2o`0000oooooo0_l0000=ooooo`;o00004oooool:o`000003ooooool0003o000000Co00001ooo
ool2o`0000_ooooo0_l00036ooooo`007_ooool00ol0003oooooooooo`0Uooooo`;o00003oooool2
o`0002?ooooo1?l000000ooooooo0000o`000007o`0000Wooooo0_l0000;ooooo`?o0000;?ooool2
o`0009Oooooo000Nooooo`;o0000>?ooool2o`0001Sooooo0_l00009ooooo`?o00000oooool6o`00
00[ooooo0_l0000<ooooo`;o0000;?ooool2o`0009Oooooo000Nooooo`03o`000?oooooooooo03Oo
oooo0_l0000Hooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`0000Oo
oooo0_l0000fooooo`;o0000Voooool001kooooo00?o0000ooooooooool0?Oooool6o`0000kooooo
0_l00004ooooo`?o000000?oooooo`000?l000001?l00008ooooo`;o00001?ooool2o`0003Wooooo
0_l0002Kooooo`007_ooool00ol0003oooooooooo`0mooooo`Ko00002_ooool2o`0000;ooooo0_l0
0004ooooo`?o000000Coooooo`000?l0003ooooo0ol0000>ooooo`;o0000e_ooool001kooooo00?o
0000ooooooooool0COooool2o`0000?ooooo0ol00002ooooo`;o000000?oooooo`000?l000000_oo
ool2o`0003Kooooo0_l0002_ooooo`007_ooool00ol0003oooooooooo`0]ooooo`;o00001Oooool2
o`0001cooooo0ol00002ooooo`;o000000?oooooo`000?l00000>_ooool2o`000:oooooo000Noooo
o`03o`000?oooooooooo02gooooo0_l00005ooooo`;o00000_ooool2o`0000;ooooo0_l0000Boooo
o`;o00001Oooool5o`0000Cooooo0_l00006ooooo`;o0000gOooool001kooooo00?o0000oooooooo
ool0>?ooool2o`0000;ooooo0_l0000Booooo`;o00001oooool3o`0000Cooooo0_l00006ooooo`;o
0000gOooool001kooooo00?o0000ooooooooool0=_ooool2o`0001Kooooo1?l00002ooooo`;o0000
0_ooool2o`0003Cooooo0_l0000Pooooo`;o0000UOooool001kooooo00?o0000ooooooooool0=_oo
ool3o`0001Gooooo1?l000000ooooooo0000o`000005o`0003Cooooo0_l0000Pooooo`;o0000UOoo
ool001kooooo00?o0000ooooooooool0;_ooool2o`0000Oooooo0_l00003ooooo`;o00003Oooool5
o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`;o00002_ooool2o`0004Cooooo0_l0002E
ooooo`007_ooool00ol0003oooooooooo`0^ooooo`;o00000_ooool2o`0000Sooooo0_l0000=oooo
o`Go00003_ooool2o`0000Kooooo0ol000000ooooooo0000o`00000fooooo`;o00003?ooool2o`00
09Gooooo000Nooooo`03o`000?oooooooooo03;ooooo0_l0000Hooooo`?o00001Oooool2o`00013o
oooo0ol0000iooooo`?o0000X_ooool001kooooo00?o0000ooooooooool07?ooool2o`0001Cooooo
0_l00008ooooo`;o00003_ooool3o`0000Gooooo0_l00010ooooo`;o00002oooool2o`0000;ooooo
0_l00007ooooo`;o0000UOooool001kooooo00?o0000ooooooooool07?ooool2o`0001kooooo0_l0
000<ooooo`Go000000Goooooo`000?l0003o0000ooooo`02o`00013ooooo0_l0000Gooooo`;o0000
5Oooool2o`0000Gooooo0_l00008ooooo`;o00001oooool2o`0009Gooooo000Nooooo`03o`000?oo
oooooooo01Gooooo0_l0000aooooo`Co00000_ooool8o`00013ooooo0_l0000Gooooo`;o00006Ooo
ool2o`000003ooooool0003o000000kooooo0_l0002Hooooo`007_ooool2o`0001Kooooo0_l0000E
ooooo`Ko00001Oooool3o`0000?ooooo0_l00009ooooo`Go000000?oooooo`000?l000001Ol00015
ooooo`;o00004Oooool2o`0009Sooooo000Nooooo`03o`000?oooooooooo02cooooo1_l000000ooo
oooo0000o`000002ooooo`?o00000oooool2o`0000[ooooo1?l00003ooooo`;o00006Oooool2o`00
0=[ooooo000Nooooo`?o0000;?ooool;o`0000?ooooo0_l0000=ooooo`Co00007_ooool2o`0000[o
oooo0_l0003>ooooo`007_ooool3o`0002gooooo0_l000000ooooooo0000o`000005o`0000;ooooo
0ol000000ooooooo0000o`000006ooooo`Ko000000Coooooo`000?l0003o00001?ooool2o`0000[o
oooo0ol00005ooooo`;o00003_ooool2o`000<kooooo000Nooooo`03o`000?oooooooooo037ooooo
1Ol00002ooooo`Oo00000_ooool2o`000003ooooool0003o000000Wo00001?ooool2o`0000[ooooo
0ol00005ooooo`;o0000g_ooool001kooooo00?o0000ooooooooool0<Oooool5o`000003ooooool0
003o000000[o000000?oooooo`000?l000000_l000000ooooooo0000o`000002o`000?[ooooo000N
ooooo`03o`000?oooooooooo01_ooooo1?l0000Cooooo`Co000000Coooooo`000?l0003ooooo4ol0
000_ooooo`;o0000bOooool001kooooo00?o0000ooooooooool06oooool4o`0001Sooooo1?l00002
ooooo`So000000?oooooo`000?l000000_l0000Dooooo`;o00007?ooool2o`00037ooooo0_l0002F
ooooo`007_ooool00ol0003oooooooooo`02o`0001Wooooo0_l0000<ooooo`;o00003_ooool2o`00
00;ooooo1?l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Cooooo`;o00005Oooool4
o`0000Sooooo0_l0000[ooooo`?o0000U_ooool001kooooo00?o0000ooooooooool00_l0000Woooo
o`;o00004oooool3o`0000;ooooo0_l00004ooooo`;o00001oooool4o`0000Oooooo0_l0000Foooo
o`Co00002?ooool2o`00013ooooo0_l0000Iooooo`;o0000T?ooool2o`0000Gooooo000Nooooo`03
o`000?oooooooooo01cooooo0_l0000Wooooo`;o00002oooool4o`0000Oooooo0_l0000:ooooo`;o
0000:?ooool2o`00017ooooo0_l0002Hooooo`?o00001?ooool001kooooo00?o0000ooooooooool0
4Oooool2o`0000;ooooo0_l00005ooooo`;o00002_ooool2o`0000Sooooo0_l00003ooooo`;o0000
3?ooool2o`0000_ooooo0_l0000Eooooo`;o00002_ooool2o`0001_ooooo0_l0000Booooo`;o0000
VOooool2o`0000Cooooo000Nooooo`03o`000?oooooooooo013ooooo0ol00002ooooo`;o00004Ooo
ool2o`0000Sooooo0_l00003ooooo`?o00004oooool2o`0000;ooooo0ol0000Qooooo`;o00006ooo
ool2o`000;?ooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0000<ooooo`;o00009_ooool2
o`0000Sooooo0_l00009ooooo`;o00000_ooool2o`0000Gooooo0_l00013ooooo`;o0000Z?ooool0
01kooooo00?o0000ooooooooool00_ooool2o`0003Oooooo0_l000000ooooooo0000o`000002oooo
o`;o00003Oooool2o`0000Gooooo0_l00002ooooo`;o00008_ooool2o`0001_ooooo0_l0002Noooo
o`;o00002?ooool001kooooo00?o0000ooooooooool0;_ooool2o`0000_ooooo0_l000001?oooooo
0000o`000?l0000Kooooo`;o00005_ooool2o`0000[ooooo0_l0002kooooo`;o00002?ooool001ko
oooo0_l00009ooooo`;o00000oooool2o`00017ooooo0_l0000<ooooo`;o00000oooool2o`0000;o
oooo0_l00006ooooo`;o00005_ooool2o`0000Kooooo0_l0000Cooooo`;o00008?ooool2o`000:oo
oooo000Nooooo`03o`000?oooooooooo00Cooooo0_l00002ooooo`;o00000oooool2o`00017ooooo
0_l0000Aooooo`;o00000_ooool4o`0001cooooo0_l00006ooooo`;o00001oooool2o`0002cooooo
0_l0002_ooooo`007_ooool00ol0003oooooooooo`03ooooo`?o00007oooool2o`0001;ooooo0_l0
000;ooooo`;o00004_ooool2o`0000cooooo0_l0003Mooooo`007_ooool00ol0003oooooooooo`03
ooooo`;o00000oooool2o`0001_ooooo0_l0000Oooooo`;o00004_ooool2o`0000cooooo0_l0000G
ooooo`;o00003Oooool2o`000;Gooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0000Poooo
o`;o000000?oooooo`000?l000000_ooool2o`00033ooooo0_l00003ooooo`;o00002oooool2o`00
00[ooooo0_l0000:ooooo`;o000000?oooooo`000?l00000]Oooool001kooooo00?o0000oooooooo
ool03Oooool2o`0001Cooooo0_l00005ooooo`;o000000?oooooo`000?l000000_ooool2o`0000oo
oooo0_l0000Hooooo`;o00001Oooool2o`00013ooooo0_l00003ooooo`;o00004Oooool2o`000;So
oooo000Nooooo`03o`000?oooooooooo00gooooo0_l00009ooooo`;o00002Oooool2o`0001gooooo
0_l0000Eooooo`;o000000Coooooo`000?l0003ooooo0_l0000Iooooo`;o00004_ooool2o`000;Oo
oooo000Nooooo`03o`000?oooooooooo00_ooooo0_l0000;ooooo`;o0000:_ooool2o`0001?ooooo
0_l00004ooooo`;o00003?ooool2o`0000[ooooo0_l0000Cooooo`;o00004Oooool2o`000:Cooooo
000Nooooo`03o`000?oooooooooo00_ooooo0_l00002ooooo`;o00001Oooool2o`0002cooooo0_l0
000Wooooo`;o00002_ooool2o`0002Kooooo0_l0002Tooooo`007_ooool00ol0003oooooooooo`0?
ooooo`;o00000oooool4o`0001;ooooo0_l00020ooooo`;o0000VOooool001kooooo0_l0000Eoooo
o`;o00004Oooool2o`000003ooooool0003o000002;ooooo0_l0001Looooo`;o0000VOooool001ko
oooo1?l0000Fooooo`;o00003_ooool2o`0000Sooooo0_l0000=ooooo`;o00003?ooool2o`0003Wo
oooo0_l00003ooooo`Co0000]Oooool001kooooo00Co0000ooooool0003o00005_ooool2o`0001So
oooo0_l0000=ooooo`;o0000Aoooool2o`0000?ooooo1?l0000Dooooo`;o0000Woooool001kooooo
00Co0000ooooool0003o00002_ooool2o`0002_ooooo0_l0000Hooooo`;o0000>_ooool2o`0001Ko
oooo0_l0002Oooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0;ooooo`;o00002?ooool2o`00
027ooooo0_l0000Eooooo`;o000000?oooooo`000?l00000>_ooool2o`000;Oooooo0003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06
ooooo`03o`000?oooooooooo01Gooooo0_l0000Jooooo`;o00006oooool3o`0000Gooooo0_l0000;
ooooo`;o0000@Oooool2o`0009oooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool0
1Ol0003ooooooooooooooooo000000Kooooo0ol0000[ooooo`;o00001?ooool2o`0000Cooooo0_l0
0008ooooo`;o00002oooool4o`0000Cooooo0_l000000ooooooo0000o`000002o`0000Kooooo0_l0
0011ooooo`;o0000Woooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nH
V9SooooooiRHV?lb<S801_ooool00ol0003oooooooooo`0[ooooo`;o00002_ooool2o`0000Sooooo
0_l0000=ooooo`;o00001oooool4o`0003Cooooo0_l0002dooooo`000oooool01Ol0003ooooooooo
oooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c005ooooo`;o0000<?ooool2o`00067o
oooo0_l00009ooooo`;o0000ZOooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05
oa0@4?nj^[[ooooookZj^_l@41001Oooool2o`0000Gooooo0_l0000Cooooo`;o00005?ooool2o`00
067ooooo0_l00009ooooo`;o0000ZOooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`03ooooo`;o00004oooool2
o`00013ooooo0_l0000>ooooo`;o00003oooool2o`0001?ooooo0_l0003Uooooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oo
oooooooo02[ooooo0_l0000>ooooo`;o00003oooool2o`0000Kooooo0_l0000;ooooo`;o00005ooo
ool2o`0002kooooo0_l0002Looooo`007_ooool00ol0003oooooooooo`1Cooooo`;o00003_ooool2
o`0001Cooooo0_l0000;ooooo`;o00008Oooool2o`0009cooooo000Nooooo`03o`000?oooooooooo
02Gooooo0_l0000Hooooo`;o00008_ooool2o`00027ooooo0_l0002oooooo`007_ooool00ol0003o
ooooooooo`0Uooooo`;o00006?ooool2o`0000Cooooo0_l0000Looooo`;o0000h_ooool001kooooo
00?o0000ooooooooool0AOooool2o`0000Gooooo0_l0000Hooooo`;o0000Aoooool2o`0009Kooooo
000Nooooo`03o`000?oooooooooo04cooooo0_l0000Hooooo`?o00009oooool2o`0001gooooo0_l0
002<ooooo`;o00002?ooool001kooooo00Co0000ooooool0003o00004_ooool2o`0000;ooooo0_l0
001>ooooo`;o00009oooool2o`0001_ooooo0_l00004ooooo`;o0000R?ooool2o`0000Sooooo000N
ooooo`04o`000?oooooo0000o`0001;ooooo0_l00002ooooo`;o0000U?ooool2o`0000Cooooo0_l0
002Booooo`007_ooool01?l0003oooooooooooooool2o`0003Sooooo0_l00008ooooo`;o0000oooo
ool1ooooo`007_ooool01?l0003oooooooooooooool2o`0003Sooooo0_l00008ooooo`;o00007_oo
ool3o`000=oooooo000Nooooo`03o`000?oooooooooo00kooooo0_l00006ooooo`;o0000>_ooool5
o`0000kooooo0ol0003Oooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o00001_ooool2o`00
03Wooooo1_l00007ooooo`;o00003?ooool2o`0003?ooooo0_l00006ooooo`;o0000W?ooool001ko
oooo0_l0000mooooo`;o00004oooool2o`0000;ooooo0ol00006ooooo`;o00003?ooool2o`00027o
oooo0_l0000@ooooo`;o00001_ooool2o`0009cooooo000Nooooo`03o`000?oooooooooo03cooooo
0_l00004ooooo`Co00003_ooool5o`0000cooooo0_l0000Xooooo`;o00006oooool2o`0009Wooooo
000Nooooo`03o`000?oooooooooo00Kooooo0_l0000jooooo`Co00001_ooool2o`0000Kooooo1ol0
0008ooooo`Co00002oooool2o`0003Sooooo0_l0002Iooooo`007_ooool00ol0003oooooooooo`06
ooooo`;o00009Oooool2o`0001?ooooo0_l00008ooooo`;o00001oooool3o`000003ooooool0003o
000000Oooooo1Ol0000;ooooo`;o0000doooool001kooooo00?o0000ooooooooool04Oooool2o`00
013ooooo0_l00008ooooo`;o00003_ooool2o`0001Oooooo0_l00003ooooo`;o00001Oooool2o`00
0003ooooool0003o000000;o000000?oooooo`000?l00000foooool001kooooo00?o0000oooooooo
ool04Oooool2o`00013ooooo0_l0000Eooooo`;o000000?oooooo`000?l000001oooool4o`0000Wo
oooo1Ol00003ooooo`;o00001Oooool7o`000003ooooool0003o0000013ooooo0_l00039ooooo`00
7_ooool00ol0003oooooooooo`0dooooo`;o00001?ooool2o`0000[ooooo1?l00008ooooo`Ko0000
2?ooool6o`0000kooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000?o0000
4Oooool2o`000;?ooooo000Nooooo`03o`000?oooooooooo03Cooooo0_l0000Looooo`Ko00000_oo
ool2o`0000Cooooo0ol00002ooooo`;o00002?ooool2o`0000?ooooo0_l000000ooooooo0000o`00
0002o`000003ooooool0003o000000?o00004Oooool2o`000;?ooooo000Nooooo`03o`000?oooooo
oooo04cooooo0_l00005ooooo`Wo00001oooool4o`0000Gooooo0_l000000ooooooo0000o`00000;
ooooo`?o0000b?ooool001kooooo00?o0000ooooooooool01?ooool2o`0002Sooooo0_l00004oooo
o`;o00005_ooool2o`0000Kooooo0ol000000ooooooo0000o`000009ooooo`;o00001Oooool5o`00
00Wooooo1ol00038ooooo`007_ooool00ol0003oooooooooo`04ooooo`;o0000:?ooool2o`0000Co
oooo0_l0000?ooooo`;o00001Oooool2o`0000?ooooo0_l000000ooooooo0000o`00000>ooooo`;o
00001?ooool2o`000003ooooool0003o000000Kooooo1ol0003;ooooo`007_ooool00ol0003ooooo
ooooo`15ooooo`;o00001Oooool2o`0000?ooooo0_l00002ooooo`;o00000oooool3o`0000Oooooo
0_l000000ooooooo0000o`000009ooooo`;o000000?oooooo`000?l000001Ol0000Vooooo`;o0000
Xoooool001kooooo00Co0000ooooool0003o00001Oooool2o`0000_ooooo0_l0000]ooooo`;o0000
0oooool3o`0000[ooooo0ol00003ooooo`?o00001Oooool2o`0000?ooooo0_l00009ooooo`[o0000
9_ooool2o`000:?ooooo000Nooooo`04o`000?oooooo0000o`0000Gooooo0_l0000;ooooo`;o0000
9?ooool2o`0000Oooooo2?l00008ooooo`Go00002oooool2o`00013ooooo1?l00002ooooo`;o0000
5_ooool3o`000;;ooooo000Nooooo`04o`000?oooooo0000o`0000[ooooo1?l0000Yooooo`?o0000
0_ooool6o`000003ooooool0003o000000Co00002?ooool8o`0000Kooooo0_l00005ooooo`;o0000
2Oooool2o`0000?ooooo0_l0000Iooooo`?o00002oooool2o`000:Gooooo000Nooooo`03o`000?oo
oooooooo00_ooooo1?l0000Yooooo`;o00000oooool6o`0000?ooooo1?l00009ooooo`Oo00001_oo
ool2o`0000Gooooo0_l00004ooooo`;o00000oooool2o`0000?ooooo0ol0000>ooooo`Co00005?oo
ool2o`000:Gooooo000Nooooo`;o00008_ooool2o`0001Kooooo0_l0000=ooooo`;o000000Cooooo
o`000?l0003o00001Oooool3o`00017ooooo0_l00002ooooo`Co000000?oooooo`000?l000000ooo
ool5o`0000kooooo1?l0002kooooo`007_ooool00ol0003oooooooooo`0Qooooo`;o00004Oooool2
o`0000;ooooo1?l00005ooooo`;o00001_ooool5o`000003ooooool0003o000000Sooooo0_l00005
ooooo`Co00000oooool2o`0000;ooooo0_l00003ooooo`;o00000oooool4o`000<Gooooo0_l00007
ooooo`007_ooool00ol0003oooooooooo`0dooooo`So00001Oooool3o`000005ooooool0003o0000
o`000?ooool00ol00003ooooo`;o000000?oooooo`000?l000001?l000000ooooooo0000o`000005
ooooo`Co00000_ooool2o`0000[ooooo1?l000000ooooooo0000o`00000Hooooo`;o0000Zoooool2
o`0000Oooooo000Nooooo`03o`000?oooooooooo00cooooo0_l0000Xooooo`;o00002_ooool2o`00
0005ooooool0003o0000o`000?ooool01_l00003ooooo`Ko00002_ooool2o`0000;ooooo0_l00004
ooooo`;o000000?oooooo`000?l000001_l0000Jooooo`;o0000]?ooool001kooooo00?o0000oooo
ooooool03?ooool2o`0003_ooooo1ol00002ooooo`Co00001Oooool2o`0000oooooo2?l000000ooo
oooo0000o`00000Jooooo`;o0000]?ooool001kooooo00?o0000ooooooooool0;?ooool2o`0000?o
oooo0_l00005ooooo`;o00001Oooool2o`0000Wooooo0_l00002ooooo`;o00000oooool3o`0000?o
oooo1_l0000:ooooo`;o00000_ooool4o`000003ooooool0003o00000=?ooooo000Nooooo`03o`00
0?oooooooooo02Gooooo0_l00005ooooo`?o00000_ooool2o`0000Gooooo0_l00005ooooo`;o0000
2oooool2o`0000Gooooo0ol00003ooooo`;o00000_ooool2o`0000[ooooo0_l00007ooooo`;o0000
6oooool2o`000:Kooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o00005Ooo
ool2o`0000Kooooo0_l0000:ooooo`;o00004Oooool2o`000005ooooool0003o0000o`000?ooool0
0_l00002ooooo`;o00005?ooool4o`0001kooooo0_l000000ooooooo0000o`00002Sooooo`;o0000
2?ooool2o`0000Cooooo000Nooooo`03o`000?oooooooooo00kooooo0_l0000Uooooo`;o00000_oo
ool2o`0001;ooooo1Ol000000ooooooo0000o`000002ooooo`;o00003oooool2o`0000?ooooo1?l0
000Qooooo`;o00001?ooool2o`000:Oooooo0_l00004ooooo`007_ooool00ol0003oooooooooo`0e
ooooo`;o00001_ooool2o`0000[ooooo0_l00002ooooo`Go000000?oooooo`000?l000004_ooool3
o`000003ooooool0003o000000;o00004?ooool2o`0001Oooooo0_l0002]ooooo`007_ooool00ol0
003oooooooooo`0mooooo`;o00001Oooool2o`0000?ooooo0_l00003ooooo`Go00001Oooool2o`00
0003ooooool0003o000000Gooooo0_l00003ooooo`;o00000_ooool4o`0000?ooooo0_l0000:oooo
o`?o00000oooool2o`000<7ooooo000Nooooo`03o`000?oooooooooo04Cooooo0_l000000ooooooo
0000o`000006ooooo`Co00000oooool4o`000003ooooool0003o000000?ooooo1?l00005ooooo`;o
00001oooool2o`0000[ooooo0_l00004ooooo`;o00002_ooool2o`000;Gooooo000Nooooo`03o`00
0?oooooooooo00[ooooo0_l0000:ooooo`;o0000;oooool2o`0000Kooooo1?l00003ooooo`;o0000
1Oooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`?o00008Oooool2o`0000;ooooo
0_l0002eooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o00002_ooool2o`0000Sooooo0_l0
000Qooooo`;o00000_ooool2o`0000Kooooo0ol00005ooooo`;o00001?ooool2o`0000Gooooo0_l0
0002ooooo`;o00008_ooool2o`000;Wooooo000Nooooo`03o`000?oooooooooo00;o00005_ooool2
o`0000Kooooo0_l0000Qooooo`;o00000_ooool2o`0000;ooooo2?l00003ooooo`?o00002?ooool2
o`000003ooooool0003o000000;o00008?ooool2o`000;gooooo000Nooooo`03o`000?oooooooooo
00;o00005_ooool2o`00037ooooo3Ol00009ooooo`;o00000oooool2o`0001Kooooo0_l00008oooo
o`;o0000_Oooool001kooooo0_l0000Dooooo`;o0000>?ooool;o`0001oooooo0_l00005ooooo`;o
0000aoooool001kooooo00?o0000ooooooooool04oooool2o`0001[ooooo0_l0000Oooooo`?o0000
4_ooool2o`0000oooooo0ol0000=ooooo`;o0000_oooool001kooooo00?o0000ooooooooool07_oo
ool2o`0000oooooo0_l0000Pooooo`;o00004_ooool2o`0000oooooo0_l000000ooooooo0000o`00
000;ooooo`;o0000_oooool001kooooo00?o0000ooooooooool07_ooool2o`0005Wooooo0_l0000D
ooooo`;o0000]_ooool001kooooo00?o0000ooooooooool0;Oooool2o`0002kooooo0_l0000>oooo
o`;o00000oooool2o`0001[ooooo0ol0002fooooo`007_ooool00ol0003oooooooooo`0]ooooo`;o
0000;_ooool2o`0000Oooooo0_l00005ooooo`;o00000oooool2o`0001Oooooo0_l000000ooooooo
0000o`000003ooooo`;o0000/_ooool001kooooo00?o0000ooooooooool05Oooool2o`0004oooooo
0_l0000Sooooo`;o00001_ooool2o`000;;ooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0
000<ooooo`;o0000BOooool2o`0000[ooooo0_l0000Looooo`?o0000^_ooool001kooooo00?o0000
ooooooooool01oooool2o`0002Sooooo0_l0000Gooooo`;o00004_ooool4o`0000[ooooo0_l0000L
ooooo`;o0000^oooool001kooooo00?o0000ooooooooool0<Oooool2o`0000Oooooo0_l0000>oooo
o`;o00004_ooool2o`0001_ooooo0_l0000=ooooo`;o000000?oooooo`000?l00000^?ooool001ko
oooo00?o0000ooooooooool0<Oooool2o`0000Gooooo1?l00007ooooo`;o0000=_ooool2o`0000Oo
oooo0_l00007ooooo`;o0000^?ooool001kooooo00?o0000ooooooooool0>?ooool2o`0000Wooooo
0_l0000oooooo`;o0000`Oooool001kooooo00?o0000ooooooooool0B_ooool2o`0000Kooooo0_l0
000iooooo`;o0000^?ooool001kooooo00?o0000ooooooooool0??ooool2o`0000cooooo0_l00006
ooooo`;o0000>Oooool2o`000;Sooooo000Dooooo`Co000000?o410@ooooooooool00oooool00ol0
003oooooooooo`0looooo`;o00005oooool2o`000?3ooooo000Fooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0EOooool2o`000?3ooooo000Fooooo`03o`000?oooooooooo00Gooooo
0ol0003oooooodSooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000
ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03
o`000?oooooooooo0?ooooooD?ooool001Cooooo00?oEEEEofIVI_l00000oooooomBooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.25191 .93048 Mdot
.3694 .44395 Mdot
.27415 .89943 Mdot
.14589 .74292 Mdot
.31064 .84298 Mdot
.26591 .71627 Mdot
.05652 .79641 Mdot
.27947 .85514 Mdot
.25812 .66607 Mdot
.42218 .43929 Mdot
.28684 .57317 Mdot
.38794 .61731 Mdot
.29124 .90946 Mdot
.1162 .80475 Mdot
.22742 .75714 Mdot
.37057 .85918 Mdot
.45232 .73614 Mdot
.3097 .94919 Mdot
.28828 .97515 Mdot
.1568 .68882 Mdot
.51928 .95054 Mdot
.30788 .68626 Mdot
.41836 .86613 Mdot
.45767 .03725 Mdot
.22188 .67341 Mdot
.27776 .80334 Mdot
.2058 .71035 Mdot
.27239 .77692 Mdot
.29894 .56874 Mdot
.26686 .68471 Mdot
.29081 .96596 Mdot
.23896 .75035 Mdot
.30239 .62901 Mdot
.47442 .64241 Mdot
.31747 .00333 Mdot
.13323 .68992 Mdot
.09139 .79847 Mdot
.49265 .93092 Mdot
.43363 .70795 Mdot
.20154 .71995 Mdot
.29371 .96807 Mdot
.14418 .91345 Mdot
.1065 .68928 Mdot
.53237 .88699 Mdot
.27232 .58236 Mdot
.13661 .87136 Mdot
.04498 .38302 Mdot
.11781 .71261 Mdot
.16263 .67805 Mdot
.17616 .0983 Mdot
.38805 .58669 Mdot
.26208 .99321 Mdot
.28659 .8348 Mdot
.1294 .6754 Mdot
.30725 .85606 Mdot
.28158 .75523 Mdot
.72745 .09424 Mdot
.27768 .8958 Mdot
.20422 .71195 Mdot
.28048 .98213 Mdot
.17371 .75535 Mdot
.28655 .82615 Mdot
.1094 .66902 Mdot
.23055 .65766 Mdot
.23587 .83845 Mdot
.29933 .6888 Mdot
.15923 .00686 Mdot
.20446 .70995 Mdot
.2617 .72854 Mdot
.84531 .11924 Mdot
.30828 .73514 Mdot
.39923 .97699 Mdot
.18281 .53855 Mdot
.2335 .45907 Mdot
.35427 .63959 Mdot
.50571 .18939 Mdot
.19781 .96064 Mdot
.12383 .74136 Mdot
.22053 .72121 Mdot
.39618 .97983 Mdot
.15177 .71171 Mdot
.05807 .04072 Mdot
.53789 .91083 Mdot
.28611 .84827 Mdot
.03638 .01788 Mdot
.40612 .65687 Mdot
.27474 .82077 Mdot
.15864 .70838 Mdot
.24825 .74887 Mdot
.32958 .00414 Mdot
.15214 .6361 Mdot
.90957 .1718 Mdot
.18829 .10405 Mdot
.23499 .56989 Mdot
.30775 .99337 Mdot
.14489 .7895 Mdot
.1151 .61075 Mdot
.29218 .99876 Mdot
.22365 .67522 Mdot
.38583 .99974 Mdot
.2214 .80592 Mdot
.38961 .5938 Mdot
.2196 .95835 Mdot
.22911 .81735 Mdot
.33466 .43122 Mdot
.41387 .86479 Mdot
.38074 .88073 Mdot
.35842 .85257 Mdot
.21537 .97666 Mdot
.06197 .84796 Mdot
.11458 .79302 Mdot
.50372 .77883 Mdot
.40669 .61298 Mdot
.29035 .95736 Mdot
.28569 .01188 Mdot
.96975 .98699 Mdot
.30627 .59915 Mdot
.30559 .90117 Mdot
.5025 .44495 Mdot
.30509 .69394 Mdot
.1905 .69541 Mdot
.09649 .80292 Mdot
.33984 .66673 Mdot
.24263 .59188 Mdot
.04272 .25402 Mdot
.46188 .99052 Mdot
.30606 .59567 Mdot
.28187 .96172 Mdot
.50278 .68011 Mdot
.21957 .54171 Mdot
.44036 .02453 Mdot
.25053 .76588 Mdot
.51731 .80427 Mdot
.37336 .93381 Mdot
.32434 .97625 Mdot
.31279 .93296 Mdot
.40476 .85701 Mdot
.37164 .96738 Mdot
.23922 .94125 Mdot
.2813 .69016 Mdot
.27857 .97104 Mdot
.22865 .65453 Mdot
.32028 .6762 Mdot
.27777 .95558 Mdot
.11286 .73039 Mdot
.38191 .62491 Mdot
.24527 .9385 Mdot
.21106 .76468 Mdot
.715 .11543 Mdot
.02981 .93985 Mdot
.07447 .79581 Mdot
.31883 .6505 Mdot
.39785 .60395 Mdot
.16064 .67116 Mdot
.21279 .7447 Mdot
.30563 .88015 Mdot
.39296 .94123 Mdot
.79869 .01195 Mdot
.23639 .67264 Mdot
.40453 .88954 Mdot
.40304 .97353 Mdot
.36605 .01506 Mdot
.50605 .65924 Mdot
.3915 .92786 Mdot
.22205 .69098 Mdot
.32264 .8335 Mdot
.21017 .7733 Mdot
.22285 .69766 Mdot
.04889 .83212 Mdot
.38389 .89423 Mdot
.32341 .67122 Mdot
.18271 .72052 Mdot
.35933 .01803 Mdot
.52452 .23234 Mdot
.2681 .94641 Mdot
.379 .84493 Mdot
.54408 .62601 Mdot
.26809 .82111 Mdot
.06493 .75833 Mdot
.2807 .99873 Mdot
.10277 .69398 Mdot
.36091 .60902 Mdot
.42099 .75762 Mdot
.28114 .50741 Mdot
.52523 .05891 Mdot
.40044 .65233 Mdot
.40992 .89531 Mdot
.13565 .65556 Mdot
.21757 .72791 Mdot
.28433 .87926 Mdot
.27655 .95236 Mdot
.42899 .67008 Mdot
.27136 .95023 Mdot
.32323 .51587 Mdot
.34935 .68698 Mdot
.11334 .68652 Mdot
.34168 .00077 Mdot
.35766 .6402 Mdot
.25988 .66217 Mdot
.3396 .64372 Mdot
.24172 .49434 Mdot
.13487 .89791 Mdot
.36635 .94993 Mdot
.26645 .52777 Mdot
.22272 .67011 Mdot
.15522 .7086 Mdot
.00208 .98339 Mdot
.17761 .7155 Mdot
.07627 .03849 Mdot
.29957 .77027 Mdot
.37852 .87078 Mdot
.26125 .95358 Mdot
.14727 .19606 Mdot
.35583 .89138 Mdot
.38741 .96837 Mdot
.26249 .61764 Mdot
.20742 .75575 Mdot
.40552 .56723 Mdot
.36888 .82823 Mdot
.13988 .02085 Mdot
.75345 .07526 Mdot
.36326 .98113 Mdot
.22693 .65219 Mdot
.23195 .69447 Mdot
.34272 .99848 Mdot
.42526 .94832 Mdot
.24407 .63638 Mdot
.38605 .8719 Mdot
.44439 .12363 Mdot
.31529 .67827 Mdot
.29738 .84223 Mdot
.27494 .97467 Mdot
.3285 .67343 Mdot
.30013 .53397 Mdot
.25363 .59935 Mdot
.48939 .21852 Mdot
.39686 .42784 Mdot
.2948 .94001 Mdot
.49891 .96454 Mdot
.67023 .19826 Mdot
.23415 .87093 Mdot
.32783 .67882 Mdot
.10274 .68653 Mdot
.1727 .89189 Mdot
.43478 .72684 Mdot
.1722 .99205 Mdot
.38472 .97156 Mdot
.31099 .67092 Mdot
.09217 .20483 Mdot
.29706 .95202 Mdot
.2624 .0016 Mdot
.33624 .83698 Mdot
.78745 .35172 Mdot
.41886 .6947 Mdot
.0388 .26695 Mdot
.10829 .70138 Mdot
.29435 .82341 Mdot
.44466 .01039 Mdot
.20425 .82382 Mdot
.26372 .99405 Mdot
.25369 .93586 Mdot
.2456 .89937 Mdot
.23681 .5529 Mdot
.38251 .05308 Mdot
.32826 .67666 Mdot
.43681 .59028 Mdot
.40952 .61237 Mdot
.5298 .32608 Mdot
.30162 .92295 Mdot
.20601 .7095 Mdot
.22221 .67753 Mdot
.22971 .2139 Mdot
.20542 .74563 Mdot
.27489 .89574 Mdot
.15279 .70013 Mdot
.3678 .84409 Mdot
.36817 .86109 Mdot
.27778 .55477 Mdot
.13769 .67697 Mdot
.40402 .59557 Mdot
.74066 .14593 Mdot
.30939 .68242 Mdot
.41191 .89687 Mdot
.07441 .83144 Mdot
.30829 .82752 Mdot
.22646 .65304 Mdot
.3662 .91315 Mdot
.41175 .04625 Mdot
.09373 .764 Mdot
.30808 .52291 Mdot
.1024 .68623 Mdot
.94461 .17975 Mdot
.2914 .97543 Mdot
.34838 .54268 Mdot
.07325 .73252 Mdot
.40276 .03993 Mdot
.2278 .85063 Mdot
.41378 .9054 Mdot
.73659 .18996 Mdot
.12984 .04989 Mdot
.41442 .04819 Mdot
.25152 .62625 Mdot
.3119 .99321 Mdot
.3976 .96269 Mdot
.32961 .44526 Mdot
.19518 .9892 Mdot
.20888 .712 Mdot
.20123 .726 Mdot
.19369 .33414 Mdot
.13365 .85669 Mdot
.18325 .70393 Mdot
.72953 .21026 Mdot
.28009 .80508 Mdot
.38947 .01083 Mdot
.22042 .72626 Mdot
.10709 .73166 Mdot
.40862 .83436 Mdot
.52549 .20561 Mdot
.29695 .61478 Mdot
.40516 .70983 Mdot
.43108 .70412 Mdot
.31745 .6359 Mdot
.3925 .58592 Mdot
.38166 .77089 Mdot
.29198 .96938 Mdot
.29876 .85089 Mdot
.14008 .6772 Mdot
.2503 .93923 Mdot
.38853 .61033 Mdot
.29815 .83114 Mdot
.14692 .66907 Mdot
.27711 .71177 Mdot
.19169 .68725 Mdot
.31429 .27361 Mdot
.34222 .8187 Mdot
.26817 .11061 Mdot
.45944 .67858 Mdot
.20301 .70394 Mdot
.67662 .03545 Mdot
.4503 .5985 Mdot
.21945 .68057 Mdot
.60361 .62986 Mdot
.26235 .95892 Mdot
.401 .96519 Mdot
.72277 .99056 Mdot
.0965 .93362 Mdot
.04062 .85016 Mdot
.21521 .91753 Mdot
.40099 .08276 Mdot
.27507 .85706 Mdot
.30423 .90784 Mdot
.31241 .82981 Mdot
.36922 .85333 Mdot
.26591 .80454 Mdot
.03322 .84479 Mdot
.19251 .74964 Mdot
.15847 .92499 Mdot
.39136 .9428 Mdot
.28146 .91404 Mdot
.33995 .7116 Mdot
.31371 .67809 Mdot
.44799 .73352 Mdot
.28956 .9706 Mdot
.38573 .86646 Mdot
.23899 .64006 Mdot
.3496 .8294 Mdot
.03078 .67236 Mdot
.1066 .79963 Mdot
.62469 .18318 Mdot
.27551 .70252 Mdot
.38162 .97934 Mdot
.21352 .71339 Mdot
.29038 .91702 Mdot
.29765 .68056 Mdot
.18025 .68378 Mdot
.40117 .00632 Mdot
.24065 .59405 Mdot
.15606 .68598 Mdot
.27932 .16819 Mdot
.27602 .66062 Mdot
.22899 .72087 Mdot
.12667 .73331 Mdot
.59547 .09898 Mdot
.03094 .27341 Mdot
.30624 .77271 Mdot
.30666 .52647 Mdot
.0377 .65955 Mdot
.01872 .92578 Mdot
.20466 .70652 Mdot
.12827 .80902 Mdot
.28065 .97521 Mdot
.29651 .90251 Mdot
.20806 .81898 Mdot
.27482 .86623 Mdot
.29394 .8494 Mdot
.1351 .94798 Mdot
.48909 .83162 Mdot
.47018 .78008 Mdot
.20058 .71036 Mdot
.29041 .97245 Mdot
.12013 .67331 Mdot
.18854 .6486 Mdot
.80776 .04315 Mdot
.28791 .83257 Mdot
.06105 .88448 Mdot
.35885 .63665 Mdot
.27751 .52231 Mdot
.36098 .99982 Mdot
.43117 .93074 Mdot
.3916 .9232 Mdot
.37668 .98467 Mdot
.22289 .6779 Mdot
.39491 .97817 Mdot
.0128 .8624 Mdot
.65999 .12841 Mdot
.35449 .93364 Mdot
.19804 .96185 Mdot
.42031 .95564 Mdot
.76945 .03091 Mdot
.21524 .72323 Mdot
.21076 .71184 Mdot
.99756 .25385 Mdot
.45249 .21877 Mdot
.31788 .9132 Mdot
.28068 .88372 Mdot
.31199 .38878 Mdot
.2862 .48421 Mdot
.28372 .66853 Mdot
.40309 .97455 Mdot
.08489 .05335 Mdot
.66959 .16354 Mdot
.06749 .41518 Mdot
.32644 .02127 Mdot
.12897 .71952 Mdot
.77016 .18795 Mdot
.06857 .95065 Mdot
.35038 .81667 Mdot
.30686 .61799 Mdot
.1491 .92728 Mdot
.28063 .61038 Mdot
.39898 .63517 Mdot
.52391 .80983 Mdot
.54847 .89746 Mdot
.19025 .75609 Mdot
.29186 .47657 Mdot
.18057 .74134 Mdot
.31596 .62354 Mdot
.34211 .86832 Mdot
.89512 .22101 Mdot
.4393 .88306 Mdot
.53866 .90436 Mdot
.18147 .96238 Mdot
.21943 .67863 Mdot
.23047 .71075 Mdot
.37649 .56393 Mdot
.18873 .70655 Mdot
.23001 .66601 Mdot
.13236 .68028 Mdot
.45194 .64285 Mdot
.24524 .03626 Mdot
.14552 .80652 Mdot
.16311 .71252 Mdot
.23874 .71853 Mdot
.26813 .85686 Mdot
.38061 .05519 Mdot
.30469 .00526 Mdot
.30897 .62884 Mdot
.51329 .94329 Mdot
.20604 .76202 Mdot
.35816 .77935 Mdot
.27723 .69568 Mdot
.275 .81998 Mdot
.28324 .84705 Mdot
.28458 .84811 Mdot
.22706 .88537 Mdot
.23445 .74043 Mdot
.24444 .88714 Mdot
.28649 .87088 Mdot
.74534 .08452 Mdot
.29395 .63857 Mdot
.12412 .71036 Mdot
.37118 .57647 Mdot
.32004 .68185 Mdot
.27949 .978 Mdot
.26091 .9374 Mdot
.32874 .55007 Mdot
.25311 .55181 Mdot
.90238 .2615 Mdot
.17592 .69811 Mdot
.24457 .78405 Mdot
.29987 .92935 Mdot
.22197 .69191 Mdot
.14478 .83072 Mdot
.05234 .67157 Mdot
.16861 .61798 Mdot
.34521 .63905 Mdot
.12286 .90835 Mdot
.32502 .6165 Mdot
.45986 .03186 Mdot
.41602 .80343 Mdot
.14441 .93328 Mdot
.239 .56944 Mdot
.1718 .72791 Mdot
.54854 .19959 Mdot
.33466 .93227 Mdot
.14175 .05428 Mdot
.27806 .81796 Mdot
.08579 .6928 Mdot
.22505 .66981 Mdot
.23343 .67215 Mdot
.28704 .98207 Mdot
.1704 .76651 Mdot
.26336 .70275 Mdot
.62042 .08133 Mdot
.29583 .83368 Mdot
.28977 .52778 Mdot
.11343 .6797 Mdot
.15025 .78533 Mdot
.76493 .01199 Mdot
.28934 .97551 Mdot
.38328 .95311 Mdot
.24347 .8755 Mdot
.22512 .71999 Mdot
.34669 .65753 Mdot
.37664 .89962 Mdot
.9455 .72435 Mdot
.15621 .78362 Mdot
.41258 .7527 Mdot
.43205 .91896 Mdot
.44453 .63961 Mdot
.55078 .68355 Mdot
.13811 .64534 Mdot
.30727 .83006 Mdot
.41979 .67649 Mdot
.28927 .8523 Mdot
.21844 .78803 Mdot
.2569 .8242 Mdot
.26982 .63381 Mdot
.45902 .89411 Mdot
.14548 .5327 Mdot
.28198 .6914 Mdot
.67411 .09989 Mdot
.37994 .62409 Mdot
.22288 .73849 Mdot
.23007 .89525 Mdot
.10267 .65921 Mdot
.88933 .22704 Mdot
.42863 .92154 Mdot
.40977 .88831 Mdot
.3009 .85314 Mdot
.99518 .97206 Mdot
.21172 .51229 Mdot
.2894 .63185 Mdot
.52199 .6176 Mdot
.12262 .69447 Mdot
.96171 .13115 Mdot
.88721 .27432 Mdot
.20297 .70454 Mdot
.11552 .70258 Mdot
.14053 .99282 Mdot
.39886 .89674 Mdot
.3129 .60672 Mdot
.46726 .88885 Mdot
.49365 .88402 Mdot
.35796 .92031 Mdot
.15812 .67691 Mdot
.40196 .95934 Mdot
.22474 .66353 Mdot
.12253 .12303 Mdot
.25127 .74384 Mdot
.01578 .66072 Mdot
.23593 .80876 Mdot
.24122 .74162 Mdot
.24466 .93983 Mdot
.28638 .91126 Mdot
.29325 .65828 Mdot
.31473 .59777 Mdot
.29698 .56294 Mdot
.34109 .84064 Mdot
.14121 .96622 Mdot
.04219 .17513 Mdot
.89693 .14957 Mdot
.20481 .87443 Mdot
.28291 .98009 Mdot
.43358 .02535 Mdot
.14484 .70183 Mdot
.3964 .65822 Mdot
.96296 .84752 Mdot
.12604 .69723 Mdot
.26447 .96709 Mdot
.28519 .87734 Mdot
.28726 .88234 Mdot
.41062 .95432 Mdot
.33069 .62812 Mdot
.36847 .61888 Mdot
.2848 .80881 Mdot
.35642 .80267 Mdot
.30273 .85014 Mdot
.14265 .694 Mdot
.40204 .94302 Mdot
.30552 .65825 Mdot
.21579 .71149 Mdot
.29942 .91517 Mdot
.29432 .99902 Mdot
.10465 .68681 Mdot
.39552 .92621 Mdot
.20476 .73156 Mdot
.29863 .67951 Mdot
.16266 .63704 Mdot
.25964 .93717 Mdot
.18476 .55855 Mdot
.07773 .71772 Mdot
.25413 .72545 Mdot
.16751 .89103 Mdot
.26508 .96791 Mdot
.36568 .86057 Mdot
.40008 .9784 Mdot
.34232 .64794 Mdot
.23428 .65493 Mdot
.12464 .14719 Mdot
.96679 .7038 Mdot
.98076 .7026 Mdot
.26991 .94672 Mdot
.47424 .8619 Mdot
.20004 .96349 Mdot
.4083 .58822 Mdot
.5301 .61159 Mdot
.42711 .68843 Mdot
.34442 .86921 Mdot
.1474 .66168 Mdot
.22157 .91633 Mdot
.22996 .69016 Mdot
.26605 .96863 Mdot
.27256 .91918 Mdot
.24444 .74081 Mdot
.227 .85956 Mdot
.28513 .85267 Mdot
.18636 .05455 Mdot
.30345 .877 Mdot
.23475 .7581 Mdot
.15153 .60708 Mdot
.2572 .73084 Mdot
.14786 .93599 Mdot
.16814 .57593 Mdot
.05483 .70765 Mdot
.35632 .9739 Mdot
.33875 .58559 Mdot
.73559 .06048 Mdot
.29591 .84252 Mdot
.15635 .62889 Mdot
.4204 .04599 Mdot
.34047 .6102 Mdot
.55206 .65177 Mdot
.23579 .69668 Mdot
.89334 .22677 Mdot
.20445 .71078 Mdot
.27247 .85457 Mdot
.7518 .23575 Mdot
.06429 .03588 Mdot
.19518 .70847 Mdot
.24968 .60916 Mdot
.4111 .78728 Mdot
.27154 .42216 Mdot
.18527 .68792 Mdot
.431 .62227 Mdot
.46602 .69816 Mdot
.20844 .72488 Mdot
.04702 .81055 Mdot
.39001 .9914 Mdot
.51067 .69695 Mdot
.20103 .53092 Mdot
.20471 .42462 Mdot
.31659 .5029 Mdot
.2642 .64212 Mdot
.64697 .21604 Mdot
.28289 .81212 Mdot
.74624 .4404 Mdot
.30429 .91037 Mdot
.04538 .96713 Mdot
.06239 .03621 Mdot
.46005 .74129 Mdot
.27368 .94561 Mdot
.6457 .12714 Mdot
.28522 .96143 Mdot
.25104 .74344 Mdot
.38886 .04063 Mdot
.33644 .59372 Mdot
.04112 .86972 Mdot
.24448 .72355 Mdot
.28546 .94208 Mdot
.09786 .76624 Mdot
.28664 .54829 Mdot
.19313 .08217 Mdot
.98422 .63584 Mdot
.31176 .6454 Mdot
.41058 .79754 Mdot
.23708 .71177 Mdot
.12755 .68659 Mdot
.26961 .25307 Mdot
.27542 .12286 Mdot
.34335 .67001 Mdot
.27882 .81692 Mdot
.30703 .88527 Mdot
.23868 .94541 Mdot
.29443 .63454 Mdot
.33952 .66029 Mdot
.30681 .03636 Mdot
.42341 .13784 Mdot
.3336 .48623 Mdot
.27087 .65176 Mdot
.39844 .21472 Mdot
.33672 .95843 Mdot
.14004 .67878 Mdot
.63705 .34438 Mdot
.38466 .85492 Mdot
.30602 .33836 Mdot
.31571 .67652 Mdot
.27215 .85455 Mdot
.95693 .04229 Mdot
.32476 .67483 Mdot
.25293 .94646 Mdot
.21925 .52223 Mdot
.38172 .95157 Mdot
.0244 .92022 Mdot
.55116 .91987 Mdot
.87703 .09275 Mdot
.33991 .08325 Mdot
.19361 .69168 Mdot
.17199 .56177 Mdot
.73623 .05971 Mdot
.29813 .63769 Mdot
.30141 .65624 Mdot
.30364 .87866 Mdot
.2643 .67858 Mdot
.94677 .01294 Mdot
.01045 .99097 Mdot
.91159 .21204 Mdot
.90409 .2586 Mdot
.37154 .58843 Mdot
.01473 .04597 Mdot
.36284 .77662 Mdot
.14109 .74184 Mdot
.27833 .97457 Mdot
.97708 .80424 Mdot
.28184 .53139 Mdot
.31885 .59079 Mdot
.26812 .65667 Mdot
.73295 .08673 Mdot
.30711 .60501 Mdot
.47882 .88494 Mdot
.10995 .68234 Mdot
.23886 .88244 Mdot
.35192 .53806 Mdot
.21194 .92861 Mdot
.36739 .96218 Mdot
.25319 .70595 Mdot
.35775 .89515 Mdot
.13461 .68688 Mdot
.25135 .87853 Mdot
.29938 .94018 Mdot
.86612 .04351 Mdot
.27879 .85044 Mdot
.12385 .11169 Mdot
.23636 .88444 Mdot
.27135 .51234 Mdot
.17146 .74274 Mdot
.35264 .97108 Mdot
.69193 .1122 Mdot
.36003 .64067 Mdot
.1285 .1396 Mdot
.21688 .68468 Mdot
.20355 .7232 Mdot
.41505 .87457 Mdot
.3364 .83688 Mdot
.01491 .96907 Mdot
.28481 .97991 Mdot
.28387 .65766 Mdot
.30019 .92924 Mdot
.37615 .55855 Mdot
.32461 .47889 Mdot
.14368 .7432 Mdot
.3756 .69259 Mdot
.69637 .21926 Mdot
.30585 .57264 Mdot
.22567 .80885 Mdot
.39541 .93006 Mdot
.27428 .79813 Mdot
.27773 .68942 Mdot
.22296 .69146 Mdot
.30032 .86598 Mdot
.99034 .91672 Mdot
.62714 .18112 Mdot
.02421 .87514 Mdot
.27125 .8065 Mdot
.39508 .04847 Mdot
.27757 .85447 Mdot
.24105 .79151 Mdot
.00978 .96306 Mdot
.12226 .72286 Mdot
.37724 .983 Mdot
.58016 .31211 Mdot
.28597 .67804 Mdot
.21133 .87027 Mdot
.39591 .62641 Mdot
.30609 .95271 Mdot
.33946 .94859 Mdot
.16711 .80335 Mdot
.34087 .60074 Mdot
.37995 .01386 Mdot
.37755 .96232 Mdot
.39988 .0181 Mdot
.12156 .70675 Mdot
.25036 .87399 Mdot
.97626 .70177 Mdot
.11766 .6917 Mdot
.21904 .71221 Mdot
.12334 .65722 Mdot
.72008 .11998 Mdot
.21116 .75677 Mdot
.05438 .79226 Mdot
.28588 .85303 Mdot
.29794 .85763 Mdot
.2688 .61416 Mdot
.3027 .88187 Mdot
.27174 .83323 Mdot
.37636 .95845 Mdot
.28372 .82447 Mdot
.2257 .67032 Mdot
.0127 .95467 Mdot
.41647 .92326 Mdot
.32332 .58848 Mdot
.40538 .05436 Mdot
.28103 .92414 Mdot
.99222 .02403 Mdot
.12418 .8923 Mdot
.39174 .90611 Mdot
.17845 .81052 Mdot
.16257 .67799 Mdot
.25617 .62828 Mdot
.99473 .15149 Mdot
.01406 .67867 Mdot
.30249 .85572 Mdot
.20771 .71248 Mdot
.27118 .67497 Mdot
.72978 .12539 Mdot
.08443 .74678 Mdot
.46757 .97606 Mdot
.30235 .89905 Mdot
.28387 .80937 Mdot
.23958 .88618 Mdot
.45204 .99687 Mdot
.31672 .97429 Mdot
.29448 .96922 Mdot
.24509 .04137 Mdot
.18679 .71586 Mdot
.27517 .1496 Mdot
.28181 .85227 Mdot
.2454 .37796 Mdot
.30444 .65404 Mdot
.22886 .86308 Mdot
.29741 .84833 Mdot
.15829 .7472 Mdot
.27786 .64968 Mdot
.29239 .88435 Mdot
.2801 .8053 Mdot
.35581 .61748 Mdot
.28754 .97541 Mdot
.36554 .85705 Mdot
.15182 .27725 Mdot
.29265 .87646 Mdot
.32859 .05545 Mdot
.18656 .73335 Mdot
.2228 .667 Mdot
.12288 .76675 Mdot
.1412 .68639 Mdot
.27753 .83132 Mdot
.11145 .20872 Mdot
.42988 .90911 Mdot
.14148 .66054 Mdot
.33586 .98125 Mdot
.93737 .78549 Mdot
.20205 .71478 Mdot
.28102 .84593 Mdot
.24677 .84877 Mdot
.12302 .92568 Mdot
.25643 .93422 Mdot
.21649 .92618 Mdot
.69884 .15001 Mdot
.30906 .68517 Mdot
.30051 .6931 Mdot
.54439 .18297 Mdot
.26364 .58235 Mdot
.14091 .96991 Mdot
.31326 .68166 Mdot
.08198 .33539 Mdot
.22358 .83031 Mdot
.89849 .02209 Mdot
.22024 .75607 Mdot
.14202 .8042 Mdot
.28137 .66972 Mdot
.32584 .98303 Mdot
.40796 .60305 Mdot
.02335 .2276 Mdot
.1367 .88836 Mdot
.01904 .88658 Mdot
.03673 .00588 Mdot
.3235 .57299 Mdot
.30658 .9019 Mdot
.29265 .97524 Mdot
.26071 .95857 Mdot
.3738 .60125 Mdot
.37305 .70081 Mdot
.40471 .09615 Mdot
.27301 .63935 Mdot
.40035 .71175 Mdot
.32577 .09157 Mdot
.44617 .73602 Mdot
.09664 .7734 Mdot
.16673 .77464 Mdot
.27462 .6708 Mdot
.47215 .22045 Mdot
.17926 .065 Mdot
.28805 .03799 Mdot
.29579 .84177 Mdot
.23619 .75557 Mdot
.43647 .02205 Mdot
.5021 .11632 Mdot
.37505 .55453 Mdot
.442 .95816 Mdot
.06908 .03573 Mdot
.11722 .90841 Mdot
.40056 .85654 Mdot
.29171 .87101 Mdot
.32797 .67577 Mdot
.44846 .73539 Mdot
.27824 .96727 Mdot
.64985 .26363 Mdot
.3069 .66122 Mdot
.20626 .72407 Mdot
.50474 .58146 Mdot
.29305 .88693 Mdot
.27037 .95146 Mdot
.21953 .68031 Mdot
.09651 .67197 Mdot
.13057 .96457 Mdot
.25506 .72488 Mdot
.18119 .52324 Mdot
.13567 .01709 Mdot
.27484 .68948 Mdot
.17323 .93711 Mdot
.24195 .74183 Mdot
.74491 .23736 Mdot
.13973 .93663 Mdot
.06765 .84532 Mdot
.03405 .8594 Mdot
.29346 .89116 Mdot
.48495 .95873 Mdot
.40729 .05704 Mdot
.1385 .59011 Mdot
.13408 .3622 Mdot
.30354 .68325 Mdot
.22786 .70426 Mdot
.21464 .75894 Mdot
.29292 .99057 Mdot
.30172 .84605 Mdot
.04247 .82168 Mdot
.36299 .95537 Mdot
.42708 .94449 Mdot
.93628 .0528 Mdot
.05016 .83741 Mdot
.29806 .81349 Mdot
.82179 .43359 Mdot
.4316 .0936 Mdot
.07738 .72487 Mdot
.17976 .3119 Mdot
.27975 .82371 Mdot
.41676 .90454 Mdot
.12866 .66165 Mdot
.20972 .71583 Mdot
.19213 .73823 Mdot
.27044 .87834 Mdot
.35531 .98635 Mdot
.24018 .02791 Mdot
.41361 .89507 Mdot
.26181 .65275 Mdot
.17134 .95515 Mdot
.37671 .56948 Mdot
.05806 .96452 Mdot
.2307 .97957 Mdot
.20643 .73117 Mdot
.5404 .93497 Mdot
.14009 .73987 Mdot
.38416 .57827 Mdot
.13129 .85198 Mdot
.25003 .63017 Mdot
.19211 .69102 Mdot
.22419 .83317 Mdot
.18079 .06994 Mdot
.42133 .92324 Mdot
.32736 .65855 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02o`0000_ooooo00?o0000oooooooo
ool00_ooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?ooool03oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`02ooooo`007_ooool00ol0003oooooooooo`08ooooo`;o00000oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_l0000<ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool00_l0000;ooooo`?o00000_ooool2o`0000;ooooo
0_l00005ooooo`03o`000?oooooooooo00gooooo0_l0000?ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooooooo
o`08ooooo`;o00009_ooool2o`0002gooooo0_l0000Mooooo`;o00003?ooool2o`000;Wooooo000N
ooooo`03o`000?oooooooooo05Wooooo0_l0000Pooooo`;o00003oooool2o`0006Oooooo0_l00009
ooooo`;o0000;_ooool2o`0001Gooooo000Nooooo`03o`000?oooooooooo05Wooooo0_l0000Hoooo
o`;o00000_ooool2o`0000;ooooo0_l0001hooooo`;o00002Oooool2o`0002kooooo0_l0000Eoooo
o`007_ooool00ol0003oooooooooo`08ooooo`;o00007_ooool2o`0004Oooooo1?l00002ooooo`;o
00001Oooool2o`000<Oooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0000Nooooo`?o0000
>oooool2o`0000Wooooo0_l0000;ooooo`;o00002_ooool2o`0009Cooooo0_l0000Uooooo`007_oo
ool00ol0003oooooooooo`0Yooooo`;o0000>oooool2o`00027ooooo1?l0002Cooooo`;o00007?oo
ool2o`0000Oooooo000Nooooo`03o`000?oooooooooo04[ooooo0_l0000mooooo`Co0000/Oooool2
o`0000Oooooo000Nooooo`03o`000?oooooooooo04[ooooo0_l00015ooooo`;o0000Hoooool2o`00
04oooooo000Nooooo`03o`000?oooooooooo097ooooo0_l0001Sooooo`;o0000Coooool001kooooo
00?o0000ooooooooool04?ooool4o`0003Sooooo0_l0000<ooooo`;o00001?ooool2o`0002oooooo
0_l00015ooooo`;o0000KOooool001kooooo00?o0000ooooooooool03oooool5o`000003ooooool0
003o000003Gooooo0_l0000<ooooo`;o00001?ooool2o`0001Sooooo0_l00003ooooo`;o00004?oo
ool2o`0004Gooooo0_l0001]ooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o00001?ooool2
o`0003Gooooo0_l0000/ooooo`;o00000oooool2o`00087ooooo0_l0000Aooooo`;o00007?ooool2
o`0001;ooooo000Nooooo`04o`000?ooooooooooooooo`;o0000Ooooool2o`000003ooooool0003o
000007_ooooo0_l0000Aooooo`;o00007?ooool2o`0001;ooooo000Nooooo`04o`000?oooooooooo
ooooo`;o00008oooool2o`0005Cooooo0_l00004ooooo`Go0000`?ooool001kooooo0_l0000Hoooo
o`;o00003Oooool2o`00053ooooo0_l00002ooooo`;o00001Oooool2o`000:Oooooo0_l0000Ioooo
o`007_ooool00ol0003oooooooooo`0Gooooo`;o00004Oooool2o`0000cooooo0_l0000]ooooo`;o
00003oooool2o`0000Kooooo0_l0002Zooooo`;o00006Oooool001kooooo00?o0000ooooooooool0
:_ooool2o`0000cooooo0_l0000]ooooo`;o00003oooool2o`0000Kooooo0_l0000Uooooo`;o0000
@_ooool2o`0005[ooooo000Nooooo`03o`000?oooooooooo083ooooo0_l0000Uooooo`;o0000@_oo
ool2o`0005[ooooo000Nooooo`03o`000?oooooooooo03Kooooo0_l0002cooooo`;o0000F_ooool0
01kooooo00?o0000ooooooooool0=_ooool2o`000?oooooo4?ooool001kooooo00?o0000oooooooo
ool0=oooool2o`000?oooooo3oooool001kooooo00?o0000ooooooooool0=oooool2o`000?oooooo
3oooool001kooooo00?o0000ooooooooool0lOooool2o`0005Cooooo000Nooooo`03o`000?oooooo
oooo0<Kooooo0_l0000Yooooo`;o0000E?ooool001kooooo00?o0000ooooooooool0>oooool2o`00
02gooooo0_l0000Booooo`;o0000A_ooool2o`0007oooooo000Nooooo`03o`000?oooooooooo03_o
oooo0_l0000]ooooo`;o00004_ooool2o`0006[ooooo0_l00002ooooo`;o0000Eoooool001kooooo
00?o0000ooooooooool0j_ooool2o`0000;ooooo0_l0001Gooooo`007_ooool00ol0003ooooooooo
o`1Vooooo`;o00008?ooool2o`0008oooooo0_l0000/ooooo`007_ooool00ol0003oooooooooo`1V
ooooo`;o00005oooool2o`0000Oooooo0_l0001Nooooo`;o0000;oooool2o`0002cooooo000Noooo
o`03o`000?oooooooooo03Gooooo0_l00018ooooo`;o0000??ooool2o`0002Wooooo0_l0001Moooo
o`007_ooool2o`0003Kooooo0_l00026ooooo`;o00006?ooool2o`0006kooooo000Nooooo`03o`00
0?oooooooooo03Wooooo0_l0002Looooo`;o0000K_ooool001kooooo00?o0000ooooooooool0>Ooo
ool2o`000?oooooo3Oooool001kooooo00?o0000ooooooooool09?ooool2o`0002gooooo0_l0003b
ooooo`007_ooool00ol0003oooooooooo`0Tooooo`;o0000;Oooool2o`0008Sooooo0_l0001Xoooo
o`007_ooool00ol0003oooooooooo`2Oooooo`;o0000??ooool2o`0000Gooooo0_l0001Qooooo`00
7_ooool00ol0003oooooooooo`2Oooooo`;o0000@oooool4o`0002Oooooo0_l0000fooooo`007_oo
ool00ol0003oooooooooo`0Tooooo`;o0000;oooool2o`0003Gooooo0_l0001Hooooo`;o00009ooo
ool2o`0003Kooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l0000_ooooo`;o0000=Oooool2
o`00043ooooo0_l0000Iooooo`;o0000G?ooool001kooooo00?o0000ooooooooool0c_ooool2o`00
00;ooooo0_l0000Eooooo`;o0000G?ooool001kooooo00?o0000ooooooooool0d_ooool2o`00067o
oooo0_l0000@ooooo`007_ooool00ol0003oooooooooo`3oooooocKooooo0_l0000@ooooo`007_oo
ool00ol0003oooooooooo`0Vooooo`;o0000G_ooool2o`000;oooooo000Nooooo`03o`000?oooooo
oooo02Kooooo0_l0001Nooooo`;o0000_oooool001kooooo00?o0000ooooooooool0kOooool2o`00
05Sooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l00037ooooo`;o0000F?ooool001kooooo
0_l0000Uooooo`;o0000;oooool2o`0008Sooooo0_l0000nooooo`;o00007_ooool2o`0000Kooooo
000Nooooo`03o`000?oooooooooo05Gooooo0_l00028ooooo`;o0000?_ooool2o`0001kooooo0_l0
0006ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0e_ooool2o`0006oooooo000Nooooo`03o`00
0?oooooooooo0=Kooooo0_l0001_ooooo`007_ooool00ol0003oooooooooo`1Gooooo`;o0000k_oo
ool001kooooo00?o0000ooooooooool0Eoooool2o`000<_ooooo0_l0000Qooooo`007_ooool00ol0
003oooooooooo`0:ooooo`;o0000oooooolIooooo`;o00008Oooool001kooooo00?o0000oooooooo
ool02_ooool2o`000?oooooo9?ooool2o`0001Kooooo000Nooooo`03o`000?oooooooooo0<Sooooo
0_l0001Uooooo`;o00005_ooool001kooooo00?o0000ooooooooool0[Oooool2o`0001Sooooo0ol0
001mooooo`007_ooool00ol0003oooooooooo`2]ooooo`;o00006?ooool2o`0002gooooo0_l0001?
ooooo`007_ooool00ol0003oooooooooo`2Pooooo`;o0000BOooool2o`0000Wooooo0_l0001?oooo
o`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0
003oooooooooo`2Pooooo`;o0000BOooool2o`0005[ooooo0003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooo
oooo02cooooo0_l0002Xooooo`;o0000Koooool000?ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0000/ooooo`;o0000P?ooool2o`0002Kooooo0_l0001_
ooooo`000oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01_ooool0
0ol0003oooooooooo`2^ooooo`;o0000Uoooool000?ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool06_ooool2o`0008_ooooo0_l0002N
ooooo`000oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Jooooo`;o00001?ooool2o`0008Gooooo0_l00010ooooo`;o0000G?ooool0
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_oo
ool00ol0003oooooooooo`0Pooooo`;o0000aoooool2o`0003Wooooo0_l0000Qooooo`000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`00
0?oooooooooo04Oooooo0_l0000dooooo`;o0000Coooool2o`0005Cooooo0_l0000Qooooo`007_oo
ool00ol0003oooooooooo`17ooooo`;o0000=?ooool2o`00013ooooo0_l0000:ooooo`;o0000<Ooo
ool2o`0000kooooo0_l0001Wooooo`007_ooool00ol0003oooooooooo`2?ooooo`;o00001?ooool2
o`0000Cooooo0_l00011ooooo`;o0000?oooool2o`0002Kooooo000Nooooo`03o`000?oooooooooo
09Gooooo0_l00028ooooo`;o00009_ooool001kooooo00?o0000ooooooooool00oooool2o`000?oo
oooo6Oooool3o`0002Oooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0003ooooooaWooooo
0ol0000Wooooo`007_ooool00ol0003oooooooooo`2Vooooo`;o0000Woooool001kooooo00?o0000
ooooooooool0Y_ooool2o`0004Kooooo1?l0001Eooooo`007_ooool00ol0003oooooooooo`3^oooo
o`Co0000EOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0001E
ooooo`;o0000lOooool001kooooo00?o0000ooooooooool02_ooool2o`0004Sooooo0_l0003Zoooo
o`;o00001Oooool001kooooo00?o0000ooooooooool02_ooool2o`000?oooooo5oooool2o`0001co
oooo0_l00005ooooo`007_ooool00ol0003oooooooooo`3oooooob;ooooo0ol0000Sooooo`007_oo
ool00ol0003oooooooooo`3?ooooo`;o0000D?ooool2o`0002Cooooo000Nooooo`03o`000?oooooo
oooo00Sooooo0_l00035ooooo`;o0000M_ooool001kooooo00?o0000ooooooooool02?ooool2o`00
0?oooooo?_ooool001kooooo00?o0000ooooooooool01_ooool2o`0005[ooooo0_l0002hooooo`;o
0000:Oooool001kooooo00?o0000ooooooooool01_ooool2o`0002Gooooo0_l0000cooooo`;o0000
^?ooool2o`0002Wooooo000Nooooo`03o`000?oooooooooo02gooooo0_l0003ooooooaWooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0=_oo
ool2o`000?oooooo4?ooool001kooooo00?o0000ooooooooool0=_ooool2o`00087ooooo0_l0002<
ooooo`007_ooool00ol0003oooooooooo`2iooooo`;o0000S?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0:Sooooo0_l0002Mooooo`007_ooool00ol0003oooooooooo`2Xooooo`;o0000WOooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o
00008_ooool2o`000?oooooo2oooool001kooooo00?o0000ooooooooool05oooool2o`0002;ooooo
0_l0000Rooooo`;o0000i_ooool001kooooo00?o0000ooooooooool0Goooool2o`000>Kooooo000N
ooooo`03o`000?oooooooooo0<_ooooo0_l0001jooooo`007_ooool00ol0003oooooooooo`3;oooo
o`;o0000N_ooool001kooooo0_l0003mooooo`;o0000BOooool001kooooo00?o0000ooooooooool0
o?ooool2o`0004Wooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`0Wooooo`;o0000oooooolOoooo
o`007_ooool00ol0003oooooooooo`0Wooooo`;o0000oooooolOooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`1<ooooo`;o0000nOooool001ko
oooo00?o0000ooooooooool0C?ooool2o`000?Wooooo000Nooooo`03o`000?oooooooooo00_ooooo
0_l0003ooooooc_ooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l0001Dooooo`;o0000i?oo
ool001kooooo00?o0000ooooooooool0HOooool2o`000>Cooooo0003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooo
oooo0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooo
oooooooooooooa0@400;ooooo`Go00001_ooool3o`000?ooooooB?ooool000?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0oooo
oom8ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo0000
1oooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0
oooooom8ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool0
1_ooool00ol0003oooooooooo`0Booooo`;o0000ooooooldooooo`007_ooool00ol0003ooooooooo
o`0Booooo`;o0000ooooooldooooo`007_ooool00ol0003oooooooooo`1Dooooo`;o0000lOooool0
01kooooo00?o0000ooooooooool0?_ooool2o`0001Cooooo0_l0003aooooo`007_ooool00ol0003o
ooooooooo`0nooooo`;o0000?Oooool2o`000<Sooooo000Nooooo`03o`000?oooooooooo06Wooooo
0_l0000Booooo`;o0000b?ooool001kooooo00?o0000ooooooooool0JOooool2o`0009cooooo0_l0
000nooooo`007_ooool00ol0003oooooooooo`3oooooo`Sooooo0_l0000nooooo`007_ooool00ol0
003oooooooooo`25ooooo`;o0000Ioooool2o`0005Oooooo000Nooooo`03o`000?oooooooooo07Co
oooo0_l0000?ooooo`;o0000Ioooool2o`0005Oooooo000Nooooo`03o`000?oooooooooo06Oooooo
0_l0000;ooooo`;o0000:Oooool2o`000:Kooooo000Nooooo`03o`000?oooooooooo06Oooooo0_l0
000fooooo`;o0000Y_ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0B?ooool2o`000?gooooo000Nooooo`03o`00
0?oooooooooo04Sooooo0_l0003mooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo05_ooooo
0_l0003Zooooo`007_ooool00ol0003oooooooooo`1Kooooo`;o00002?ooool2o`000>3ooooo000N
ooooo`03o`000?oooooooooo05Wooooo0_l0000:ooooo`;o0000h?ooool001kooooo00?o0000oooo
ooooool0FOooool2o`0000gooooo0_l0003Mooooo`007_ooool00ol0003oooooooooo`1Xooooo`;o
0000gOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`1:ooooo`;o0000noooool001kooooo00?o0000ooooooooool0B_ooool2o`000?_ooooo000Noooo
o`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`1Sooooo`;o0000h_ooool001kooooo
00?o0000ooooooooool0Eoooool2o`0000[ooooo0_l0003Rooooo`007_ooool00ol0003ooooooooo
o`1Gooooo`;o0000k_ooool001kooooo00?o0000ooooooooool0@Oooool2o`00017ooooo0_l0003a
ooooo`007_ooool00ol0003oooooooooo`11ooooo`;o00004Oooool2o`0000oooooo0_l0003Poooo
o`007_ooool00ol0003oooooooooo`1Uooooo`;o0000h?ooool001kooooo00?o0000ooooooooool0
=oooool2o`0000[ooooo0_l0000Aooooo`;o00002?ooool2o`000>Gooooo000Nooooo`03o`000?oo
oooooooo03Oooooo0_l0000:ooooo`;o00004Oooool2o`0000Sooooo0_l0003Uooooo`007_ooool0
0ol0003oooooooooo`1Cooooo`;o00001Oooool2o`0000Cooooo0_l0003Uooooo`007_ooool00ol0
003oooooooooo`0[ooooo`;o00004?ooool2o`0001Cooooo0_l00003ooooo`Co0000joooool001ko
oooo00?o0000ooooooooool0:oooool2o`00013ooooo0_l0000Iooooo`;o00000oooool2o`000>So
oooo000Nooooo`03o`000?oooooooooo03Oooooo0_l0000Tooooo`;o00003oooool2o`000=Oooooo
000Nooooo`03o`000?oooooooooo03Oooooo0_l0000:ooooo`;o0000:?ooool3o`000=Oooooo000N
ooooo`03o`000?oooooooooo04?ooooo0_l0000Xooooo`;o0000f?ooool001kooooo00?o0000oooo
ooooool0FOooool2o`000>cooooo000Nooooo`;o0000Coooool2o`0000Wooooo0_l0000<ooooo`;o
0000g_ooool001kooooo00?o0000ooooooooool0BOooool2o`0000?ooooo0_l00006ooooo`;o0000
3oooool2o`0000gooooo0_l0003?ooooo`007_ooool00ol0003oooooooooo`19ooooo`;o00002ooo
ool2o`0001kooooo0_l0003?ooooo`007_ooool00ol0003oooooooooo`0hooooo`;o0000??ooool2
o`000<oooooo000Nooooo`03o`000?oooooooooo03Cooooo0_l00002ooooo`;o00008_ooool2o`00
01Sooooo0_l0003?ooooo`007_ooool00ol0003oooooooooo`0dooooo`;o00009_ooool2o`0001So
oooo0_l00008ooooo`;o0000aOooool001kooooo00?o0000ooooooooool0B?ooool4o`00017ooooo
0_l0000Gooooo`;o00002?ooool2o`000<Gooooo000Nooooo`03o`000?oooooooooo04Sooooo1?l0
000=ooooo`;o00000_ooool4o`0000Cooooo0_l0000?ooooo`;o0000coooool001kooooo00?o0000
ooooooooool0<oooool2o`0002Cooooo0_l00004ooooo`;o00001?ooool2o`0000kooooo0_l0003@
ooooo`007_ooool00ol0003oooooooooo`0cooooo`;o0000@?ooool2o`0000;ooooo0_l0003<oooo
o`007_ooool00ol0003oooooooooo`1Booooo`Co00008oooool2o`0002Gooooo0_l0002Uooooo`00
7_ooool00ol0003oooooooooo`1Booooo`Co00005?ooool2o`0003Cooooo0_l0002Uooooo`007_oo
ool00ol0003oooooooooo`1Uooooo`;o00000oooool2o`0000Wooooo0_l00003ooooo`?o00001?oo
ool2o`000<Cooooo000Nooooo`03o`000?oooooooooo02Wooooo0_l0000Pooooo`;o00005oooool3
o`0000kooooo0_l00003ooooo`?o00001?ooool2o`0000Oooooo0_l0002kooooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_oo
ool00ol0003oooooooooo`0Yooooo`;o00007oooool3o`0001Oooooo0_l00003ooooo`;o00004?oo
ool2o`0000gooooo0_l0002kooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1:ooooo`;o0000
4oooool2o`000003ooooool0003o000000Gooooo0_l0000@ooooo`;o00000_ooool2o`000<Kooooo
0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Ko
oooo0ol0001>ooooo`;o00003oooool2o`000003ooooool0003o000000Oooooo0_l0000Booooo`;o
00003Oooool2o`000;Oooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003o
V9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0C_ooool2o`0000oooooo0_l0000:oooo
o`;o00002?ooool2o`0000Kooooo0_l00002ooooo`;o00002oooool2o`000;Oooooo0003ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000
ooooooooool0;Oooool2o`00037ooooo1?l0000Aooooo`;o00001_ooool2o`0000;ooooo0_l00034
ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool0
0ol0003oooooooooo`0]ooooo`;o00007_ooool2o`0000Sooooo0_l00007ooooo`Co00001oooool2
o`0000Cooooo0_l00007ooooo`;o0000boooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool08Oooool2o`0002[ooooo0_l00008
ooooo`;o00004_ooool2o`0000Cooooo0_l00007ooooo`;o00001?ooool3o`0002Gooooo0_l0002M
ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_oo
ool00ol0003oooooooooo`0Qooooo`;o0000<?ooool2o`0000Oooooo0_l00008ooooo`;o00006?oo
ool3o`0002Gooooo0_l0002Mooooo`007_ooool00ol0003oooooooooo`0cooooo`;o00007?ooool4
o`0000Oooooo0_l00002ooooo`;o00001?ooool2o`0000Sooooo0_l00002ooooo`;o00001?ooool2
o`0002[ooooo0_l0002Oooooo`007_ooool00ol0003oooooooooo`0cooooo`;o00007?ooool2o`00
00gooooo0_l0000>ooooo`;o00000_ooool2o`0000Cooooo0_l0000<ooooo`;o00007?ooool2o`00
09oooooo000Nooooo`03o`000?oooooooooo06?ooooo0_l0000Booooo`?o00003_ooool2o`000;go
oooo000Nooooo`03o`000?oooooooooo02oooooo0_l0000Mooooo`?o00003oooool2o`000003oooo
ool0003o000000;ooooo0_l0000>ooooo`?o00000oooool2o`0002kooooo0_l0002Hooooo`007_oo
ool00ol0003oooooooooo`0_ooooo`;o00007?ooool4o`0000Wooooo0_l00002ooooo`Co00001Ooo
ool2o`0001Cooooo0_l0000^ooooo`;o00004Oooool2o`0008Gooooo000Nooooo`03o`000?oooooo
oooo04gooooo0_l00005ooooo`;o00001?ooool6o`00063ooooo0_l00025ooooo`007_ooool00ol0
003oooooooooo`0]ooooo`;o00000_ooool2o`0001Sooooo0_l00007ooooo`;o00001_ooool3o`00
00Cooooo0_l0000<ooooo`;o00002oooool2o`000;cooooo0_l00009ooooo`007_ooool00ol0003o
ooooooooo`0]ooooo`;o00000_ooool2o`0001Oooooo0ol00008ooooo`;o00001?ooool4o`0000Co
oooo0_l00007ooooo`;o000000?oooooo`000?l000000_l0000;ooooo`;o00003?ooool2o`000:ko
oooo0_l00009ooooo`007_ooool00ol0003oooooooooo`1:ooooo`;o00001_ooool2o`000003oooo
ool0003o000000Cooooo0_l0000=ooooo`Co000000?oooooo`000?l000000_l0000Iooooo`;o0000
00?oooooo`000?l000001Oooool2o`000:oooooo000Nooooo`03o`000?oooooooooo02Wooooo0_l0
000Wooooo`;o00003Oooool2o`0000Oooooo0_l0000Sooooo`;o00001Oooool2o`000:oooooo000N
ooooo`03o`000?oooooooooo02Wooooo0_l0000>ooooo`;o00006oooool2o`0000Wooooo0_l00008
ooooo`;o0000f_ooool001kooooo0_l0000jooooo`;o00002oooool2o`0000Wooooo0_l000000ooo
oooo0000o`000002o`0000cooooo0_l00005ooooo`;o00004Oooool2o`0002oooooo0_l0002Foooo
o`007_ooool00ol0003oooooooooo`0Xooooo`;o00007?ooool4o`0000Oooooo0_l000000ooooooo
0000o`000008ooooo`?o00000oooool2o`0001Sooooo0_l0000_ooooo`;o0000U_ooool001kooooo
00?o0000ooooooooool02?ooool2o`0001?ooooo0_l00005ooooo`;o00000_ooool2o`0001cooooo
1?l00009ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`?o00001Oooool2o`0000Go
oooo0_l0000>ooooo`;o000000?oooooo`000?l000007_ooool2o`000:Gooooo000Nooooo`04o`00
0?ooooooooooooooo`;o00001Oooool2o`0001?ooooo0_l00005ooooo`Co00000_ooool4o`0001Wo
oooo0_l00007ooooo`;o000000Coooooo`000?l0003ooooo1?l000000ooooooo0000o`000002oooo
o`?o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000>ooooo`;o000000?oooooo`00
0?l000007_ooool2o`000:Gooooo000Nooooo`04o`000?ooooooooooooooo`;o00008oooool2o`00
00;ooooo1?l0000Gooooo`;o00002Oooool2o`0000Cooooo0_l00008ooooo`;o00002?ooool2o`00
0=_ooooo000Nooooo`03o`000?oooooooooo04Cooooo1Ol00007ooooo`;o00001_ooool2o`00013o
oooo0_l0003Kooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o00004?ooool2o`0000_ooooo
0_l00002ooooo`;o00004_ooool5o`0000Oooooo0_l00003ooooo`Go00001oooool2o`0000;ooooo
0_l00003ooooo`Co00006Oooool2o`000;kooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l0
0005ooooo`;o00003?ooool2o`0000;ooooo0_l00002ooooo`;o00001oooool2o`0000;ooooo0_l0
000Booooo`?o000000Coooooo`000?l0003o00002Oooool5o`0000Sooooo0_l00002ooooo`Co0000
0oooool2o`0001Wooooo0_l0002nooooo`007_ooool00ol0003oooooooooo`06ooooo`;o00004ooo
ool2o`0000Kooooo0_l000001?oooooo0000o`000?ooool2o`0000Cooooo1?l0000Aooooo`?o0000
00Coooooo`000?l0003o00002Oooool2o`0000?ooooo0_l00007ooooo`Oo00006oooool2o`000<7o
oooo000Nooooo`03o`000?oooooooooo00;o00007oooool2o`0000?ooooo1Ol00004ooooo`Co0000
4?ooool4o`0000_ooooo0_l00005ooooo`;o00000_ooool2o`0000?ooooo1ol0000Kooooo`;o0000
2oooool2o`0000cooooo0_l0002Vooooo`007_ooool00ol0003oooooooooo`02o`0001kooooo0ol0
0004ooooo`Co00002oooool2o`0000_ooooo0_l0000=ooooo`;o00002Oooool;o`0002Wooooo0_l0
000<ooooo`;o00003_ooool2o`0009Kooooo000Nooooo`03o`000?oooooooooo01gooooo1_l00002
ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o00001Oooool2o`0000;ooooo0_l00006
ooooo`;o00003oooool2o`0000[ooooo1ol00007ooooo`;o0000@?ooool2o`0009Kooooo000Noooo
o`03o`000?oooooooooo01gooooo1_l00002ooooo`Oo00000oooool2o`0000Oooooo1?l00006oooo
o`;o00000oooool2o`0000[ooooo1_l00004ooooo`;o000000?oooooo`000?l000002oooool2o`00
01Sooooo0_l0002nooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o00001Oooool2o`000003
ooooool0003o000000?ooooo0_l00006ooooo`;o00001oooool5o`0000Oooooo0_l000000ooooooo
0000o`00000<ooooo`Go00000oooool3o`0001Kooooo0_l0000?ooooo`;o0000__ooool001kooooo
00?o0000ooooooooool06?ooool2o`0000?ooooo0_l00003ooooo`Co00001?ooool2o`0000kooooo
0ol00007ooooo`;o000000?oooooo`000?l000003Oooool4o`0000Cooooo0ol0000Eooooo`;o0000
3?ooool2o`000<7ooooo000Nooooo`03o`000?oooooooooo01gooooo0_l00005ooooo`?o00000ooo
ool2o`0000Wooooo0_l00003ooooo`;o00002?ooool2o`000003ooooool0003o000000;o00002ooo
ool2o`0000Oooooo0_l0000Sooooo`;o00003Oooool2o`0000gooooo0_l0002Sooooo`007_ooool2
o`00023ooooo1?l00002ooooo`;o00001?ooool2o`000003ooooool0003o000000Gooooo0_l0000=
ooooo`;o00000oooool2o`0000[ooooo0_l0000Nooooo`;o00007?ooool2o`0000gooooo0_l0002E
ooooo`Co00002_ooool001kooooo00?o0000ooooooooool07oooool4o`0000Sooooo0_l000000ooo
oooo0000o`000007ooooo`;o00001Oooool2o`0000Kooooo0_l0000:ooooo`;o000000?oooooo`00
0?l000007_ooool2o`00017ooooo0_l0002/ooooo`;o000000?oooooo`000?l000000_l0000:oooo
o`007_ooool00ol0003oooooooooo`0>ooooo`;o00004oooool2o`0000Wooooo0ol00006ooooo`Ko
000000?oooooo`000?l000001_ooool2o`0000Kooooo0_l00002ooooo`;o0000=?ooool3o`000:_o
oooo0_l0000?ooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o00004oooool3o`0000Oooooo
1?l00008ooooo`_o00000oooool4o`0000?ooooo0_l00006ooooo`;o00004_ooool2o`0001;ooooo
1?l00007ooooo`;o0000_?ooool001kooooo00?o0000ooooooooool08_ooool4o`0000Oooooo0_l0
0002ooooo`;o00002_ooool8o`0000;ooooo1?l0000;ooooo`;o00004_ooool2o`0001;ooooo1?l0
0035ooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o00002oooool2o`0000gooooo0_l00003
ooooo`;o000000?oooooo`000?l000000oooool7o`0000gooooo0_l0003cooooo`007_ooool00ol0
003oooooooooo`0Eooooo`;o00003oooool2o`0000kooooo1Ol00002ooooo`;o000000?oooooo`00
0?l000000oooool3o`000003ooooool0003o000000Oooooo0_l0003cooooo`007_ooool00ol0003o
ooooooooo`0Tooooo`Co00003oooool2o`0000Cooooo1?l000000ooooooo0000o`000004o`000003
ooooool0003o000000;o0000n_ooool001kooooo00?o0000ooooooooool05Oooool2o`0000gooooo
0_l0000Gooooo`Wo00001Oooool2o`0000;ooooo0_l0000hooooo`;o0000Y?ooool2o`0001Kooooo
000Nooooo`03o`000?oooooooooo01Gooooo0_l0000:ooooo`;o00004Oooool2o`0000Oooooo0_l0
00001?oooooo0000o`000?ooool3o`0000Wooooo1?l0000fooooo`;o0000Y?ooool2o`0001Kooooo
000Nooooo`03o`000?oooooooooo01Cooooo0_l00009ooooo`Co00000_ooool2o`0000gooooo0_l0
0003ooooo`;o00000oooool3o`0000;ooooo0_l0000;ooooo`?o0000m?ooool001kooooo00?o0000
ooooooooool05?ooool2o`0000Wooooo0_l00004ooooo`;o00004_ooool2o`0000?ooooo0ol0000?
ooooo`;o00003_ooool2o`0002_ooooo1?l0002fooooo`007_ooool00ol0003oooooooooo`0joooo
o`;o00002?ooool2o`0001[ooooo0_l0000[ooooo`Co0000]_ooool001kooooo00?o0000oooooooo
ool09?ooool2o`0000?ooooo0ol0000;ooooo`;o000000?oooooo`000?l000002?ooool2o`0000;o
oooo1Ol00014ooooo`;o0000]?ooool001kooooo00?o0000ooooooooool09?ooool2o`0000?ooooo
1?l00007ooooo`;o000000?oooooo`000?l000001_ooool4o`0000Gooooo2?l00011ooooo`;o0000
]?ooool001kooooo00?o0000ooooooooool05oooool2o`0001;ooooo0_l00002ooooo`;o00000ooo
ool2o`0000Wooooo1?l0000:ooooo`?o0000moooool001kooooo0_l0000Hooooo`;o00005_ooool2
o`0000Wooooo0_l0000>ooooo`;o000000?oooooo`000?l00000n?ooool001kooooo00?o0000oooo
ooooool0>_ooool2o`0000kooooo0_l000000ooooooo0000o`00000cooooo`;o0000`oooool001ko
oooo00?o0000ooooooooool0=?ooool2o`0000Cooooo0_l00003ooooo`Ko000000Coooooo`000?l0
003ooooo0_l0000<ooooo`;o0000:Oooool2o`000003ooooool0003o00000<3ooooo000Nooooo`03
o`000?oooooooooo017ooooo0_l0000Qooooo`;o00001?ooool2o`0000?ooooo1_l000000ooooooo
0000o`000003o`0000cooooo0_l0000/ooooo`;o0000`?ooool001kooooo00?o0000ooooooooool0
4Oooool2o`0000Oooooo0_l0000Sooooo`;o000000?oooooo`000?l000001?ooool2o`000?gooooo
000Nooooo`03o`000?oooooooooo01[ooooo1?l00006ooooo`;o00003Oooool2o`0000[ooooo0ol0
000;ooooo`;o0000n?ooool001kooooo00?o0000ooooooooool07?ooool2o`0000Kooooo0_l0000=
ooooo`;o00002oooool2o`0000_ooooo0_l0000>ooooo`;o0000j?ooool001kooooo00?o0000oooo
ooooool06oooool2o`0002?ooooo0_l0000Kooooo`Co00005oooool2o`000<gooooo000Nooooo`03
o`000?oooooooooo01_ooooo0_l0000Eooooo`;o00003?ooool2o`0001gooooo0_l0000Gooooo`;o
0000cOooool001kooooo00?o0000ooooooooool0<_ooool2o`00023ooooo0_l0000Jooooo`Co0000
;?ooool2o`000:Gooooo000Nooooo`03o`000?oooooooooo05Cooooo0_l0000Jooooo`Co00008Ooo
ool2o`0000Wooooo0_l0002Uooooo`007_ooool00ol0003oooooooooo`0]ooooo`Co00006_ooool2
o`0004Sooooo0_l0002Fooooo`;o00006?ooool001kooooo00?o0000ooooooooool0;Oooool4o`00
01;ooooo0_l00006ooooo`;o0000=Oooool2o`000:Wooooo0_l0000Hooooo`007_ooool00ol0003o
ooooooooo`0[ooooo`;o00005_ooool2o`0000Gooooo0_l0000fooooo`;o0000`oooool000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<
00Kooooo00?o0000ooooooooool03_ooool2o`00017ooooo0_l00008ooooo`;o00007Oooool2o`00
0?_ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRH
V?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo00kooooo0_l00004ooooo`;o00002oooool2
o`0005kooooo0_l00034ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`000006ooooo`?o00003_ooool2o`0000Cooooo0_l00004ooooo`;o00000ooo
ool2o`0003Cooooo0_l0000Zooooo`;o0000a?ooool000?ooooo00Go0000ooooooooooooooooo`00
000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool00ol0003oooooooooo`0Jooooo`?o0000
0_ooool2o`0000Wooooo0_l00006ooooo`;o00008Oooool3o`0001Sooooo0_l0000Aooooo`;o0000
`_ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<
c<`01_ooool00ol0003oooooooooo`0Kooooo`;o00001Oooool2o`0000Kooooo0ol00005ooooo`;o
00004?ooool2o`0000cooooo1ol0000Gooooo`;o00004Oooool2o`0001oooooo0_l0002Dooooo`;o
00002oooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj
^_l@41001_ooool00ol0003oooooooooo`0Rooooo`;o00000_ooool2o`0000?ooooo0_l0000Goooo
o`?o00000_ooool2o`0000Oooooo1?l000001?oooooo0000o`000?l0001:ooooo`Co0000T_ooool2
o`0000_ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj
^[[o000000Kooooo00?o0000ooooooooool02oooool2o`0001Wooooo0_l0000>ooooo`;o00003Ooo
ool2o`0000;ooooo0_l0000=ooooo`;o0000C?ooool2o`0009oooooo0003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0
2oooool2o`0002Wooooo0_l0000Pooooo`;o00000oooool2o`000>Sooooo000Nooooo`03o`000?oo
oooooooo043ooooo0_l00004ooooo`;o00003_ooool3o`0000Cooooo0_l0000<ooooo`;o000000?o
ooooo`000?l00000eoooool001kooooo00?o0000ooooooooool02_ooool2o`0003Cooooo0_l00004
ooooo`;o00002oooool6o`0001;ooooo0_l000000ooooooo0000o`00003Gooooo`007_ooool00ol0
003oooooooooo`0:ooooo`;o0000<_ooool2o`0000oooooo0_l00002ooooo`Oo00000_ooool2o`00
0>Wooooo000Nooooo`03o`000?oooooooooo03kooooo0_l0000?ooooo`;o00001_ooool4o`000003
ooooool0003o000000;ooooo0_l0000Booooo`;o0000dOooool001kooooo00?o0000ooooooooool0
5?ooool2o`0001Gooooo0_l0000Hooooo`;o00003oooool2o`000003ooooool0003o000000;ooooo
0_l000001?oooooo0000o`000?l0000;ooooo`;o00001?ooool2o`0002Gooooo0_l0002Zooooo`00
7_ooool00ol0003oooooooooo`0<ooooo`;o00001_ooool2o`0001Gooooo0_l0000Hooooo`;o0000
3Oooool4o`000004ooooool0003o0000ooooo`?o000000Coooooo`000?l0003o00000_ooool2o`00
00Oooooo0_l0000Aooooo`;o00006?ooool2o`000:[ooooo000Nooooo`03o`000?oooooooooo00co
oooo0_l0000gooooo`;o00003Oooool2o`0000?ooooo0_l000000ooooooo0000o`000007ooooo`;o
00000_ooool2o`0001Kooooo0_l00034ooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o0000
>oooool2o`0001kooooo1?l0003Jooooo`007_ooool00ol0003oooooooooo`19ooooo`;o00004Ooo
ool3o`0000;ooooo0_l00008ooooo`;o00001_ooool2o`000=;ooooo000Nooooo`03o`000?oooooo
oooo00Oooooo0_l00009ooooo`;o0000@oooool3o`0000;ooooo1?l000000ooooooo0000o`00000@
ooooo`;o00000_ooool2o`000<kooooo000Nooooo`03o`000?oooooooooo00Oooooo1?l00005oooo
o`Co0000>?ooool2o`0000Wooooo2Ol0000Gooooo`;o0000_?ooool2o`00013ooooo000Nooooo`;o
00002_ooool2o`0000Gooooo0_l0000Eooooo`;o00007Oooool2o`0000Cooooo0_l00009ooooo`Wo
00004?ooool2o`0000;ooooo0_l0002oooooo`;o00004?ooool001kooooo00?o0000ooooooooool0
9oooool2o`0001gooooo0_l0000<ooooo`So000000?oooooo`000?l000000ol0000>ooooo`;o0000
0_ooool2o`0000?ooooo0_l0003<ooooo`007_ooool00ol0003oooooooooo`07ooooo`;o00007_oo
ool2o`0001gooooo0_l0000;ooooo`Ko00001?ooool5o`00017ooooo0ol00003ooooo`;o00000ooo
ool3o`000<Kooooo000Nooooo`03o`000?oooooooooo00;o00001Oooool2o`0001kooooo0_l0000M
ooooo`;o00002oooool4o`0000Kooooo0_l0000Dooooo`?o00002?ooool3o`0001Gooooo0_l0002_
ooooo`007_ooool00ol0003oooooooooo`02o`0004Cooooo0_l0000[ooooo`?o00003?ooool2o`00
01;ooooo0_l0002_ooooo`007_ooool00ol0003oooooooooo`16ooooo`;o00003Oooool2o`0000Oo
oooo0_l0000;ooooo`;o00003?ooool2o`0000Oooooo1?l00031ooooo`007_ooool00ol0003ooooo
ooooo`09ooooo`;o00007Oooool2o`0001Oooooo0_l00005ooooo`;o00002oooool2o`0000;ooooo
1?l000000ooooooo0000o`00000;ooooo`?o00002Oooool4o`0000Wooooo0_l00031ooooo`007_oo
ool00ol0003oooooooooo`09ooooo`;o00007Oooool2o`0001Cooooo0_l000000ooooooo0000o`00
0005ooooo`;o00000oooool2o`0000[ooooo1?l0000?ooooo`;o00002Oooool4o`0000Sooooo0_l0
0032ooooo`007_ooool00ol0003oooooooooo`04ooooo`;o0000>?ooool2o`0000_ooooo1?l0000:
ooooo`Co00000_ooool2o`0001Sooooo0_l00008ooooo`;o0000`_ooool001kooooo00?o0000oooo
ooooool01?ooool2o`0004Gooooo0_l000000ooooooo0000o`000004ooooo`;o00000_ooool5o`00
00;ooooo0_l0000Gooooo`;o0000cOooool001kooooo00?o0000ooooooooool0B_ooool2o`0000;o
oooo0_l00004ooooo`;o000000?oooooo`000?l000000_l00003ooooo`?o00005oooool2o`00017o
oooo0_l0000?ooooo`;o0000ZOooool001kooooo00?o0000ooooooooool00_ooool2o`0000cooooo
0_l0000dooooo`;o000000?oooooo`000?l000000_l0000:ooooo`Ko000000?oooooo`000?l00000
0_l0000Yooooo`;o00002oooool2o`0000;ooooo0_l0000;ooooo`;o0000W?ooool001kooooo00?o
0000ooooooooool00_ooool2o`0000cooooo0_l0000Fooooo`;o00007?ooool2o`000003ooooool0
003o000000;o00003_ooool2o`0000?ooooo0_l0000Mooooo`Co00004Oooool2o`0000;ooooo0_l0
000?ooooo`;o0000W?ooool001kooooo00?o0000ooooooooool09?ooool2o`0000;ooooo0_l00008
ooooo`Co00009Oooool2o`0001?ooooo0_l0000=ooooo`Co00004Oooool2o`000;7ooooo000Noooo
o`03o`000?oooooooooo02Cooooo0_l0000<ooooo`Co00004Oooool2o`0000cooooo0ol00003oooo
o`;o00004oooool2o`0000Oooooo0_l00006ooooo`?o00003Oooool2o`000;Cooooo000Nooooo`03
o`000?oooooooooo02Sooooo0_l0000Mooooo`;o00000oooool2o`0000Oooooo0ol00006ooooo`;o
00004?ooool2o`0000Oooooo0_l00003ooooo`;o000000Coooooo`000?l0003o00003Oooool2o`00
01_ooooo0_l0002Gooooo`007_ooool2o`0002Wooooo0_l0000Rooooo`;o00001oooool2o`0000Go
oooo1_l0000Dooooo`;o00001_ooool2o`0000;ooooo0_l0000Zooooo`;o0000Uoooool001kooooo
00?o0000ooooooooool0G?ooool2o`000004ooooool0003o0000o`0001Cooooo0_l0000:ooooo`?o
00009_ooool2o`0009[ooooo000Nooooo`03o`000?oooooooooo02;ooooo1?l0000iooooo`;o0000
6_ooool2o`0000Gooooo0ol0000Vooooo`;o0000V_ooool001kooooo00?o0000ooooooooool08_oo
ool4o`0003?ooooo1?l00002ooooo`;o00006_ooool2o`0000_ooooo0_l0000Qooooo`;o0000V_oo
ool001kooooo00?o0000ooooooooool0:oooool2o`0002[ooooo1_l00002ooooo`;o00000_ooool2
o`0000kooooo0_l0000Cooooo`;o00008Oooool2o`0009[ooooo000Nooooo`03o`000?oooooooooo
02_ooooo0_l0000Eooooo`Co00004Oooool2o`000004ooooool0003o0000ooooo`;o00001?ooool2
o`0000kooooo0_l00039ooooo`;o00001oooool001kooooo00?o0000ooooooooool01?ooool2o`00
03cooooo1?l0000>ooooo`;o00001?ooool2o`000003ooooool0003o0000017ooooo0_l0000Foooo
o`;o00009Oooool2o`0008gooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`04ooooo`;o
0000C_ooool2o`000003ooooool0003o000000Gooooo0_l0000@ooooo`;o00002Oooool2o`0000Ko
oooo1ol0000Uooooo`;o0000U_ooool001kooooo00?o0000ooooooooool00_ooool2o`00023ooooo
0_l00009ooooo`;o00004Oooool2o`0001?ooooo0_l00005ooooo`;o00006oooool3o`0000Gooooo
1_l0002nooooo`007_ooool00ol0003oooooooooo`02ooooo`;o00008?ooool2o`0000Kooooo0_l0
00000ooooooo0000o`00000@ooooo`?o00006Oooool2o`0001cooooo0ol00039ooooo`007_ooool0
0ol0003oooooooooo`0[ooooo`?o00004oooool2o`0000_ooooo0_l0000=ooooo`;o00000oooool2
o`0000Gooooo0_l0000@ooooo`?o00002_ooool2o`0001;ooooo0_l0002Yooooo`007_ooool00ol0
003oooooooooo`0Kooooo`;o00003_ooool3o`00023ooooo0ol0000Aooooo`;o00001Oooool2o`00
00Cooooo0_l00004ooooo`;o00004Oooool2o`0001;ooooo0_l0000>ooooo`;o0000VOooool001ko
oooo00?o0000ooooooooool06oooool2o`0000cooooo0_l000000ooooooo0000o`000006ooooo`;o
00005_ooool7o`0001cooooo0_l00004ooooo`;o0000=Oooool2o`0009Wooooo000Nooooo`03o`00
0?oooooooooo00Kooooo0_l0000Qooooo`;o00002Oooool2o`0001Cooooo1Ol000001?oooooo0000
o`000?l00006ooooo`;o000000Coooooo`000?l0003o00007Oooool2o`000<Wooooo000Nooooo`03
o`000?oooooooooo00Kooooo0_l00011ooooo`Co00002?ooool2o`0000;ooooo0_l000001?oooooo
0000o`000?l0000Looooo`?o000000?oooooo`000?l000001_ooool2o`0001[ooooo0_l0002Roooo
o`007_ooool00ol0003oooooooooo`0Xooooo`;o00007oooool2o`0000?ooooo0_l00003ooooo`Co
00004oooool2o`0000oooooo0_l00002ooooo`;o00001Oooool3o`0001[ooooo0_l0002Rooooo`00
7_ooool2o`0001?ooooo0_l0000Dooooo`;o00009?ooool2o`0000?ooooo0ol0000;ooooo`;o0000
1oooool2o`0000Oooooo0_l00003ooooo`;o00003?ooool2o`0001gooooo0_l0002Pooooo`007_oo
ool00ol0003oooooooooo`02o`00013ooooo0_l0000mooooo`;o000000?oooooo`000?l000000_l0
0004ooooo`;o000000?oooooo`000?l000000_l0000@ooooo`;o00000oooool2o`0000Oooooo0_l0
000Rooooo`;o0000X?ooool001kooooo00?o0000ooooooooool00_l0000booooo`;o00006oooool2
o`0000?ooooo0_l00002ooooo`Co000000?oooooo`000?l000004Oooool2o`0000Cooooo0_l00007
ooooo`;o00000_ooool2o`000<3ooooo000Nooooo`03o`000?oooooooooo03Cooooo0_l00006oooo
o`;o00001Oooool2o`0000cooooo0_l00003ooooo`;o00000_ooool2o`0000gooooo0_l00007oooo
o`;o00000_ooool2o`0000Oooooo0_l00004ooooo`;o00001Oooool2o`0000cooooo0_l0002[oooo
o`007_ooool01?l0003oooooo`000?l0000fooooo`;o00000oooool3o`0000Cooooo0_l0000<oooo
o`;o00001Oooool3o`0000kooooo0_l00008ooooo`;o000000Coooooo`000?l0003o00001?ooool4
o`0000_ooooo0_l0000<ooooo`;o0000Zoooool001kooooo00Co0000ooooool0003o00002_ooool2
o`0000;ooooo0_l0000Eooooo`;o00000_ooool2o`0000_ooooo0_l00003ooooo`?o00004oooool2
o`0000Cooooo1?l0000Gooooo`;o00000_ooool2o`0000Cooooo0ol0000Nooooo`;o0000Yoooool0
01kooooo00Co0000oooooooooooooooo0_l00008ooooo`;o00000_ooool2o`0001Gooooo0_l00002
ooooo`;o00009_ooool2o`0000;ooooo0_l00002ooooo`Co00005oooool2o`0000?ooooo0_l00002
ooooo`;o00007_ooool2o`000:Oooooo000Nooooo`04o`000?ooooooooooooooo`;o00009oooool2
o`0002Kooooo0_l00002ooooo`;o00000_ooool4o`00017ooooo0_l00004ooooo`;o00000_ooool3
o`000<?ooooo0_l00006ooooo`007_ooool00ol0003oooooooooo`1Eooooo`So00001_ooool4o`00
00Sooooo0ol00007ooooo`;o00001?ooool2o`0001?ooooo0_l0002Yooooo`;o00001_ooool001ko
oooo00?o0000ooooooooool0@_ooool2o`00017ooooo2?l00006ooooo`Co00002Oooool2o`0000Ko
oooo0_l00002ooooo`Go00004oooool2o`000;7ooooo000Nooooo`03o`000?oooooooooo04;ooooo
0_l00003ooooo`;o00003_ooool4o`0000kooooo0_l00007ooooo`;o00001?ooool2o`0000;ooooo
1?l00037ooooo`007_ooool2o`0004Sooooo0_l0000>ooooo`Co00002oooool2o`000003ooooool0
003o000000Oooooo0_l00002ooooo`?o00001?ooool2o`000<Sooooo000Nooooo`;o0000Ioooool2
o`0000Oooooo0_l00005ooooo`?o0000__ooool2o`0000kooooo000Nooooo`04o`000?oooooo0000
o`0003[ooooo0_l0000Nooooo`;o00004_ooool2o`0000[ooooo0_l0000Eooooo`;o0000Doooool2
o`0004kooooo0_l0000>ooooo`005?ooool4o`000003oa0@4?oooooooooo00?ooooo00Co0000oooo
ool0003o0000:Oooool2o`0000Sooooo0_l00005ooooo`;o00005?ooool3o`0000Oooooo0_l00003
ooooo`?o00006?ooool2o`0001Gooooo0_l0001Cooooo`;o0000G_ooool001Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Zooooo`;o00002?ooool2o`0001_ooooo0ol0000<oooo
o`?o0000;?ooool2o`000;Kooooo000Fooooo`03o`000?oooooooooo00Gooooo0ol0001Gooooo`;o
00000_ooool3o`0000gooooo0_l00004ooooo`;o00001_ooool2o`0001Cooooo0_l0002fooooo`00
5_ooool00ol0003oooooooooo`1Oooooo`;o00000_ooool3o`0000gooooo0_l00004ooooo`;o0000
1_ooool2o`000<cooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000
ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Dooooo`03
oeEEEOmVIVKo00000?ooooooD_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.29758 .94884 Mdot
.43413 .50509 Mdot
.3269 .87509 Mdot
.15672 .77735 Mdot
.28064 .81528 Mdot
.25649 .75669 Mdot
.10307 .69574 Mdot
.28443 .82412 Mdot
.23342 .69502 Mdot
.34671 .49872 Mdot
.29857 .62379 Mdot
.39035 .65086 Mdot
.31191 .88737 Mdot
.22841 .84164 Mdot
.24493 .79334 Mdot
.45039 .92321 Mdot
.49973 .8514 Mdot
.30757 .93888 Mdot
.33464 .97515 Mdot
.15828 .74437 Mdot
.47385 .0418 Mdot
.30032 .74099 Mdot
.40497 .85217 Mdot
.49922 .9524 Mdot
.20172 .68804 Mdot
.28687 .75863 Mdot
.2194 .71504 Mdot
.37396 .83982 Mdot
.30953 .61709 Mdot
.27742 .75058 Mdot
.31996 .95531 Mdot
.2503 .78533 Mdot
.27586 .66134 Mdot
.39066 .60758 Mdot
.23151 .0256 Mdot
.14284 .69273 Mdot
.1979 .83542 Mdot
.4579 .04695 Mdot
.45194 .70042 Mdot
.19749 .71888 Mdot
.32997 .95901 Mdot
.08981 .94048 Mdot
.06972 .71353 Mdot
.52523 .99945 Mdot
.36609 .55419 Mdot
.07835 .90388 Mdot
.99314 .40568 Mdot
.0652 .69007 Mdot
.17864 .66963 Mdot
.15733 .11613 Mdot
.38838 .58363 Mdot
.18521 .99047 Mdot
.27625 .77899 Mdot
.13636 .6693 Mdot
.29117 .80025 Mdot
.24505 .62346 Mdot
.71581 .06195 Mdot
.28827 .86889 Mdot
.22073 .7177 Mdot
.27687 .01464 Mdot
.1915 .79471 Mdot
.29145 .79493 Mdot
.17449 .58168 Mdot
.20363 .67679 Mdot
.21622 .85133 Mdot
.27965 .73342 Mdot
.11779 .98533 Mdot
.21964 .71421 Mdot
.26111 .77481 Mdot
.86002 .08382 Mdot
.23549 .62275 Mdot
.41685 .01886 Mdot
.12235 .54105 Mdot
.22741 .42073 Mdot
.33693 .67671 Mdot
.53826 .14965 Mdot
.22163 .90517 Mdot
.09272 .62044 Mdot
.23172 .74061 Mdot
.46435 .96048 Mdot
.0713 .6948 Mdot
.01224 .95664 Mdot
.52226 .01922 Mdot
.29333 .81878 Mdot
.11169 .93997 Mdot
.33034 .56129 Mdot
.26092 .77811 Mdot
.17526 .72125 Mdot
.25563 .79046 Mdot
.3374 .04266 Mdot
.1315 .69049 Mdot
.93708 .1427 Mdot
.17225 .12917 Mdot
.17691 .49327 Mdot
.31386 .01274 Mdot
.06662 .77688 Mdot
.15841 .52956 Mdot
.20995 .00921 Mdot
.18683 .67742 Mdot
.29802 .05249 Mdot
.2449 .80522 Mdot
.38997 .58035 Mdot
.26796 .96689 Mdot
.35023 .85925 Mdot
.39295 .49238 Mdot
.39547 .85365 Mdot
.44576 .95668 Mdot
.43992 .9199 Mdot
.14977 .96153 Mdot
.05265 .73245 Mdot
.22585 .83125 Mdot
.49831 .89861 Mdot
.44794 .59301 Mdot
.30056 .94506 Mdot
.38338 .08372 Mdot
.9555 .91474 Mdot
.39861 .57369 Mdot
.33381 .88016 Mdot
.49611 .49208 Mdot
.39589 .66066 Mdot
.20933 .69554 Mdot
.04754 .79809 Mdot
.32466 .71741 Mdot
.1843 .50954 Mdot
.09173 .24351 Mdot
.39051 .06678 Mdot
.26922 .59477 Mdot
.31909 .97452 Mdot
.42287 .64868 Mdot
.14614 .54571 Mdot
.37696 .10092 Mdot
.2893 .63091 Mdot
.59566 .86681 Mdot
.35865 .94322 Mdot
.32894 .97995 Mdot
.31268 .87224 Mdot
.3777 .84284 Mdot
.40492 .03516 Mdot
.29334 .93052 Mdot
.26124 .72871 Mdot
.30794 .98335 Mdot
.19934 .67187 Mdot
.29972 .72254 Mdot
.18158 .99016 Mdot
.142 .60284 Mdot
.37687 .6605 Mdot
.25634 .97017 Mdot
.22268 .76354 Mdot
.70042 .08483 Mdot
.00874 .84134 Mdot
.13791 .7973 Mdot
.29494 .68944 Mdot
.41627 .63128 Mdot
.16098 .72871 Mdot
.23353 .77317 Mdot
.32872 .85568 Mdot
.43386 .0122 Mdot
.80883 .96621 Mdot
.21829 .69587 Mdot
.46564 .96084 Mdot
.42952 .02729 Mdot
.28471 .05562 Mdot
.50596 .57997 Mdot
.37525 .9428 Mdot
.18647 .69009 Mdot
.29128 .79863 Mdot
.21662 .77296 Mdot
.21678 .71339 Mdot
.05009 .71994 Mdot
.35741 .90035 Mdot
.31358 .73105 Mdot
.08394 .70355 Mdot
.27959 .05272 Mdot
.53305 .20765 Mdot
.31511 .96109 Mdot
.41113 .92684 Mdot
.50712 .57996 Mdot
.30014 .77121 Mdot
.10321 .6549 Mdot
.20216 .00083 Mdot
.07838 .71263 Mdot
.34672 .63445 Mdot
.47472 .77019 Mdot
.35311 .48697 Mdot
.46012 .01014 Mdot
.42752 .61848 Mdot
.46862 .96564 Mdot
.10936 .70317 Mdot
.3688 .76805 Mdot
.18288 .93175 Mdot
.31986 .96641 Mdot
.36981 .56944 Mdot
.30859 .96703 Mdot
.3845 .51057 Mdot
.42378 .65323 Mdot
.07943 .71904 Mdot
.25366 .03659 Mdot
.35368 .69169 Mdot
.23411 .69139 Mdot
.31894 .68156 Mdot
.30659 .45515 Mdot
.22571 .00057 Mdot
.35917 .95785 Mdot
.34624 .50311 Mdot
.20183 .6853 Mdot
.17126 .72353 Mdot
.98126 .8994 Mdot
.19753 .72725 Mdot
.15344 .96152 Mdot
.39656 .82512 Mdot
.34854 .8656 Mdot
.29109 .97241 Mdot
.20856 .16242 Mdot
.24364 .79549 Mdot
.41993 .03011 Mdot
.18985 .53512 Mdot
.20286 .75616 Mdot
.36343 .66813 Mdot
.41542 .91227 Mdot
.10706 .01226 Mdot
.74831 .04043 Mdot
.37237 .00109 Mdot
.19628 .6662 Mdot
.22516 .71561 Mdot
.35295 .02743 Mdot
.44547 .99581 Mdot
.13831 .64357 Mdot
.37005 .83268 Mdot
.37584 .07464 Mdot
.2948 .72468 Mdot
.31895 .81243 Mdot
.2672 .01332 Mdot
.30692 .71905 Mdot
.21013 .51423 Mdot
.1819 .52335 Mdot
.4351 .19726 Mdot
.31474 .45572 Mdot
.32529 .92343 Mdot
.45697 .06838 Mdot
.64846 .17466 Mdot
.27633 .81159 Mdot
.30953 .7303 Mdot
.059 .68777 Mdot
.21123 .84774 Mdot
.46042 .72667 Mdot
.18355 .94995 Mdot
.39433 .99856 Mdot
.3058 .73364 Mdot
.02833 .17332 Mdot
.33732 .94054 Mdot
.18912 .99588 Mdot
.30737 .79451 Mdot
.78918 .35822 Mdot
.34481 .59493 Mdot
.08731 .26002 Mdot
.07319 .68088 Mdot
.27267 .77406 Mdot
.39856 .10644 Mdot
.11156 .83978 Mdot
.36101 .07555 Mdot
.28714 .95873 Mdot
.23362 .92415 Mdot
.21136 .46379 Mdot
.3471 .14914 Mdot
.30748 .72401 Mdot
.37092 .50942 Mdot
.43555 .58946 Mdot
.54006 .33108 Mdot
.33272 .90475 Mdot
.20892 .71122 Mdot
.18635 .67947 Mdot
.16043 .16718 Mdot
.22848 .79488 Mdot
.25083 .92767 Mdot
.07008 .68674 Mdot
.33768 .81494 Mdot
.40497 .9483 Mdot
.3429 .48584 Mdot
.14726 .67223 Mdot
.41662 .58476 Mdot
.73121 .11561 Mdot
.30133 .74013 Mdot
.39539 .90965 Mdot
.1729 .86772 Mdot
.27932 .78932 Mdot
.19644 .66728 Mdot
.34465 .91902 Mdot
.35163 .10622 Mdot
.06147 .7439 Mdot
.3206 .5404 Mdot
.06902 .68192 Mdot
.97864 .15052 Mdot
.33568 .97525 Mdot
.40901 .54665 Mdot
.10453 .62605 Mdot
.33637 .09161 Mdot
.22493 .86169 Mdot
.46624 .97432 Mdot
.72704 .16311 Mdot
.07397 .95983 Mdot
.35644 .11186 Mdot
.20991 .63755 Mdot
.22101 .02061 Mdot
.40385 .99433 Mdot
.25058 .51998 Mdot
.1469 .96282 Mdot
.22013 .71854 Mdot
.22212 .74564 Mdot
.25826 .35591 Mdot
.22168 .96553 Mdot
.20266 .70939 Mdot
.71895 .18584 Mdot
.28985 .76293 Mdot
.42999 .99001 Mdot
.19081 .72607 Mdot
.10178 .70724 Mdot
.43388 .89883 Mdot
.53407 .17269 Mdot
.2664 .63817 Mdot
.41718 .84587 Mdot
.45323 .69377 Mdot
.29394 .67216 Mdot
.39846 .58278 Mdot
.45091 .79852 Mdot
.3071 .9604 Mdot
.32334 .82255 Mdot
.15037 .67258 Mdot
.27868 .96357 Mdot
.38424 .63531 Mdot
.31324 .80143 Mdot
.13615 .72259 Mdot
.26799 .75807 Mdot
.26232 .58233 Mdot
.37821 .27215 Mdot
.25907 .94323 Mdot
.27953 .17945 Mdot
.33688 .72014 Mdot
.2166 .7036 Mdot
.64454 .03679 Mdot
.38498 .51867 Mdot
.18626 .6832 Mdot
.53894 .65899 Mdot
.28551 .97848 Mdot
.41028 .00052 Mdot
.71062 .94421 Mdot
.19781 .97026 Mdot
.04301 .74211 Mdot
.2538 .78322 Mdot
.36785 .15766 Mdot
.27781 .82492 Mdot
.33841 .88843 Mdot
.28712 .78255 Mdot
.26112 .91249 Mdot
.37564 .86043 Mdot
.05389 .7445 Mdot
.21351 .79544 Mdot
.09864 .95181 Mdot
.38156 .95987 Mdot
.29353 .89159 Mdot
.27722 .84324 Mdot
.30463 .73695 Mdot
.36404 .73589 Mdot
.3231 .96149 Mdot
.3555 .85976 Mdot
.20266 .65539 Mdot
.24206 .87423 Mdot
.09741 .62614 Mdot
.01065 .86688 Mdot
.59457 .15942 Mdot
.27932 .76261 Mdot
.41042 .03814 Mdot
.21973 .72259 Mdot
.33934 .89974 Mdot
.27383 .72246 Mdot
.07821 .67631 Mdot
.31686 .06456 Mdot
.33726 .55655 Mdot
.17108 .68518 Mdot
.34342 .11667 Mdot
.28792 .73002 Mdot
.23568 .74381 Mdot
.12908 .77015 Mdot
.55387 .06499 Mdot
.07825 .26816 Mdot
.39746 .84147 Mdot
.37857 .51596 Mdot
.10238 .62558 Mdot
.04148 .03306 Mdot
.21651 .70793 Mdot
.23762 .84386 Mdot
.30964 .98621 Mdot
.28141 .88488 Mdot
.24338 .81587 Mdot
.26226 .83615 Mdot
.26922 .82177 Mdot
.17747 .83471 Mdot
.53245 .9369 Mdot
.4422 .67338 Mdot
.21945 .71621 Mdot
.31334 .96627 Mdot
.07468 .70689 Mdot
.30018 .60507 Mdot
.81816 .00235 Mdot
.29416 .80244 Mdot
.13699 .91755 Mdot
.24572 .62052 Mdot
.28657 .53692 Mdot
.37768 .0395 Mdot
.44106 .96334 Mdot
.37363 .93747 Mdot
.40312 .04296 Mdot
.2091 .69493 Mdot
.42233 .03301 Mdot
.04272 .77467 Mdot
.6348 .10001 Mdot
.34181 .93683 Mdot
.24186 .97091 Mdot
.44207 .00628 Mdot
.7702 .99037 Mdot
.22988 .74224 Mdot
.20743 .71845 Mdot
.95353 .23031 Mdot
.3932 .19593 Mdot
.30107 .90337 Mdot
.29261 .85482 Mdot
.39681 .41589 Mdot
.34947 .45164 Mdot
.25858 .7049 Mdot
.42112 .01781 Mdot
.1606 .97773 Mdot
.64734 .13708 Mdot
.0135 .45161 Mdot
.42768 .02803 Mdot
.12659 .76287 Mdot
.76696 .16167 Mdot
.15416 .99517 Mdot
.41253 .89787 Mdot
.19483 .61604 Mdot
.1758 .91621 Mdot
.37858 .57863 Mdot
.43613 .60582 Mdot
.52071 .92827 Mdot
.54381 .00396 Mdot
.21141 .79826 Mdot
.28447 .56523 Mdot
.20121 .76851 Mdot
.29276 .65626 Mdot
.31161 .85622 Mdot
.91891 .20151 Mdot
.43936 .89037 Mdot
.49464 .97566 Mdot
.12525 .94577 Mdot
.18769 .68333 Mdot
.23141 .73221 Mdot
.41259 .58635 Mdot
.20834 .71264 Mdot
.20983 .68615 Mdot
.14069 .67765 Mdot
.35752 .61271 Mdot
.34995 .07692 Mdot
.16775 .79957 Mdot
.18058 .7287 Mdot
.23794 .74444 Mdot
.31316 .81881 Mdot
.42758 .95918 Mdot
.22374 .01628 Mdot
.28445 .66262 Mdot
.45269 .02302 Mdot
.22989 .80274 Mdot
.2394 .77959 Mdot
.28233 .75758 Mdot
.2673 .77918 Mdot
.28857 .81666 Mdot
.29091 .81817 Mdot
.28228 .85182 Mdot
.24504 .77015 Mdot
.27122 .82199 Mdot
.2987 .84237 Mdot
.73796 .05073 Mdot
.24498 .63451 Mdot
.09012 .59469 Mdot
.43908 .57107 Mdot
.30484 .73482 Mdot
.3018 .99011 Mdot
.30225 .95658 Mdot
.24464 .48516 Mdot
.17434 .49384 Mdot
.92765 .25039 Mdot
.07643 .68534 Mdot
.35461 .84 Mdot
.34104 .9142 Mdot
.21284 .70754 Mdot
.20784 .70794 Mdot
.1284 .63355 Mdot
.16703 .67498 Mdot
.34436 .69763 Mdot
.12854 .88291 Mdot
.30336 .64693 Mdot
.47822 .93817 Mdot
.4623 .85324 Mdot
.15965 .89309 Mdot
.15198 .57744 Mdot
.0778 .70894 Mdot
.50458 .17665 Mdot
.32227 .9287 Mdot
.1121 .06284 Mdot
.27529 .77926 Mdot
.12565 .59154 Mdot
.20816 .68775 Mdot
.25163 .74002 Mdot
.29892 .98811 Mdot
.12446 .63059 Mdot
.24819 .5764 Mdot
.58326 .04726 Mdot
.26923 .80044 Mdot
.2033 .50811 Mdot
.10954 .67214 Mdot
.07085 .76752 Mdot
.76757 .9518 Mdot
.30719 .97329 Mdot
.37836 .96977 Mdot
.29776 .83998 Mdot
.23348 .74111 Mdot
.32845 .70041 Mdot
.26849 .95861 Mdot
.89341 .70007 Mdot
.22516 .66047 Mdot
.49834 .84315 Mdot
.48134 .90656 Mdot
.34811 .61026 Mdot
.53403 .59858 Mdot
.17067 .53498 Mdot
.27757 .79512 Mdot
.42694 .65822 Mdot
.29903 .82382 Mdot
.24325 .78567 Mdot
.22429 .84076 Mdot
.23804 .65837 Mdot
.43558 .02124 Mdot
.18638 .46105 Mdot
.26222 .7305 Mdot
.65096 .06984 Mdot
.37185 .65755 Mdot
.23804 .76555 Mdot
.27553 .90712 Mdot
.15589 .56876 Mdot
.91185 .2087 Mdot
.46013 .90113 Mdot
.39025 .8968 Mdot
.32397 .82584 Mdot
.98036 .88907 Mdot
.27428 .46909 Mdot
.2605 .66101 Mdot
.46304 .57022 Mdot
.06314 .68283 Mdot
.90686 .08824 Mdot
.90938 .26535 Mdot
.21823 .70164 Mdot
.12108 .71772 Mdot
.23283 .07339 Mdot
.37504 .90736 Mdot
.28506 .62622 Mdot
.4428 .01456 Mdot
.41829 .94929 Mdot
.33931 .92415 Mdot
.17309 .66672 Mdot
.43434 .02088 Mdot
.19226 .67312 Mdot
.06655 .04575 Mdot
.25564 .78539 Mdot
.00465 .7659 Mdot
.35392 .85511 Mdot
.24847 .77348 Mdot
.26645 .96718 Mdot
.27916 .89088 Mdot
.26738 .69539 Mdot
.20821 .59531 Mdot
.30784 .609 Mdot
.3132 .79698 Mdot
.1454 .93164 Mdot
.96853 .14507 Mdot
.92268 .11723 Mdot
.25359 .82487 Mdot
.31154 .98678 Mdot
.41276 .12956 Mdot
.15842 .71232 Mdot
.43076 .62418 Mdot
.98224 .77217 Mdot
.23373 .65858 Mdot
.26407 .99589 Mdot
.2981 .84881 Mdot
.28867 .82009 Mdot
.41814 .99122 Mdot
.30916 .66201 Mdot
.3727 .66676 Mdot
.29546 .77083 Mdot
.41606 .88095 Mdot
.32194 .82345 Mdot
.15502 .69843 Mdot
.39586 .96614 Mdot
.28018 .69737 Mdot
.21537 .7219 Mdot
.34252 .89745 Mdot
.21177 .01027 Mdot
.20015 .61729 Mdot
.37958 .94232 Mdot
.21155 .72944 Mdot
.29923 .74056 Mdot
.25157 .5706 Mdot
.29858 .95741 Mdot
.25992 .50636 Mdot
.11137 .61276 Mdot
.26334 .78048 Mdot
.21997 .76313 Mdot
.31803 .96646 Mdot
.41985 .94673 Mdot
.41939 .02275 Mdot
.25417 .55967 Mdot
.19346 .66069 Mdot
.06189 .09194 Mdot
.94456 .6733 Mdot
.00591 .80435 Mdot
.30914 .96403 Mdot
.44695 .75451 Mdot
.12997 .96822 Mdot
.43819 .57647 Mdot
.48926 .53834 Mdot
.36156 .58768 Mdot
.3238 .82018 Mdot
.07426 .68357 Mdot
.27598 .89461 Mdot
.22205 .71019 Mdot
.26317 .0001 Mdot
.39683 .93737 Mdot
.2493 .77367 Mdot
.14413 .73935 Mdot
.29275 .82309 Mdot
.18361 .04326 Mdot
.27952 .85822 Mdot
.25049 .79881 Mdot
.10296 .65004 Mdot
.25486 .77145 Mdot
.09439 .95539 Mdot
.11015 .60418 Mdot
.13903 .64196 Mdot
.36076 .98633 Mdot
.31558 .57937 Mdot
.72652 .02532 Mdot
.30702 .8157 Mdot
.24075 .56249 Mdot
.47655 .9615 Mdot
.32203 .63789 Mdot
.52364 .62058 Mdot
.22828 .72015 Mdot
.91673 .20842 Mdot
.19812 .71267 Mdot
.2822 .79261 Mdot
.74578 .21559 Mdot
.1401 .9607 Mdot
.21466 .71446 Mdot
.34944 .57121 Mdot
.39855 .81496 Mdot
.19704 .48748 Mdot
.20392 .68461 Mdot
.36809 .53361 Mdot
.375 .6749 Mdot
.22668 .7438 Mdot
.07972 .70729 Mdot
.29924 .0465 Mdot
.44256 .67714 Mdot
.14293 .49812 Mdot
.13556 .4932 Mdot
.3764 .49214 Mdot
.27927 .71261 Mdot
.62092 .19574 Mdot
.28809 .775 Mdot
.73804 .47522 Mdot
.28933 .89578 Mdot
.01486 .86953 Mdot
.14006 .95388 Mdot
.46736 .868 Mdot
.17725 .98308 Mdot
.61746 .09848 Mdot
.32482 .97335 Mdot
.25511 .78425 Mdot
.32277 .08232 Mdot
.30805 .57787 Mdot
.03498 .76151 Mdot
.34941 .69636 Mdot
.2952 .92591 Mdot
.04989 .74336 Mdot
.37222 .53188 Mdot
.1589 .13461 Mdot
.976 .73021 Mdot
.28724 .68301 Mdot
.39957 .82942 Mdot
.23458 .73624 Mdot
.16313 .56863 Mdot
.19861 .23976 Mdot
.34025 .04891 Mdot
.29117 .79886 Mdot
.38978 .86903 Mdot
.33185 .86169 Mdot
.29233 .93652 Mdot
.20997 .55042 Mdot
.31939 .7031 Mdot
.22662 .94146 Mdot
.4647 .07124 Mdot
.38969 .4502 Mdot
.24317 .68187 Mdot
.3331 .18761 Mdot
.3403 .02566 Mdot
.25012 .63851 Mdot
.60591 .349 Mdot
.36141 .81981 Mdot
.38838 .34312 Mdot
.30637 .73568 Mdot
.26135 .82156 Mdot
.92473 .98022 Mdot
.31237 .73247 Mdot
.28037 .96875 Mdot
.146 .49304 Mdot
.37548 .96668 Mdot
.07615 .02463 Mdot
.51153 .00193 Mdot
.90206 .05156 Mdot
.39732 .12819 Mdot
.21209 .689 Mdot
.11501 .58276 Mdot
.72734 .02445 Mdot
.30486 .70545 Mdot
.30423 .72409 Mdot
.33591 .8541 Mdot
.24257 .70978 Mdot
.91908 .94977 Mdot
.05316 .06566 Mdot
.93871 .19065 Mdot
.92968 .24693 Mdot
.3611 .58785 Mdot
.07924 .98116 Mdot
.3253 .79692 Mdot
.14767 .78291 Mdot
.32979 .97585 Mdot
.97511 .72053 Mdot
.19558 .51493 Mdot
.28679 .58692 Mdot
.28183 .72733 Mdot
.7227 .05374 Mdot
.27698 .6223 Mdot
.47478 .77961 Mdot
.06007 .69986 Mdot
.27488 .89442 Mdot
.40239 .54639 Mdot
.25959 .94003 Mdot
.36748 .97408 Mdot
.20299 .70533 Mdot
.33158 .89545 Mdot
.06343 .67927 Mdot
.2733 .81319 Mdot
.33665 .92589 Mdot
.89348 .99751 Mdot
.28225 .81892 Mdot
.19493 .04159 Mdot
.26508 .89752 Mdot
.28056 .53251 Mdot
.18665 .7885 Mdot
.25411 .01774 Mdot
.67275 .08265 Mdot
.3553 .69047 Mdot
.19738 .07713 Mdot
.19315 .69258 Mdot
.3136 .70704 Mdot
.39718 .87372 Mdot
.30745 .79457 Mdot
.99257 .87902 Mdot
.31074 .98337 Mdot
.23222 .65527 Mdot
.34001 .91383 Mdot
.40937 .58267 Mdot
.35314 .43103 Mdot
.15344 .77887 Mdot
.43532 .65879 Mdot
.67935 .19739 Mdot
.2043 .56523 Mdot
.20962 .81505 Mdot
.43832 .00312 Mdot
.37931 .85909 Mdot
.25762 .72663 Mdot
.21437 .70765 Mdot
.33066 .83932 Mdot
.97508 .96618 Mdot
.59743 .15709 Mdot
.09173 .912 Mdot
.2924 .7533 Mdot
.33548 .0957 Mdot
.28325 .79331 Mdot
.35336 .8455 Mdot
.01311 .02657 Mdot
.12863 .74801 Mdot
.39123 .01266 Mdot
.53936 .31054 Mdot
.29276 .74244 Mdot
.25997 .81851 Mdot
.45273 .604 Mdot
.29409 .01023 Mdot
.33281 .9475 Mdot
.23356 .67661 Mdot
.30793 .72567 Mdot
.29814 .06202 Mdot
.37919 .98011 Mdot
.32055 .07427 Mdot
.13038 .72377 Mdot
.30323 .83893 Mdot
.98664 .68194 Mdot
.09792 .73197 Mdot
.2221 .72541 Mdot
.11462 .54085 Mdot
.70645 .08919 Mdot
.23395 .78987 Mdot
.09117 .68818 Mdot
.29399 .82367 Mdot
.31305 .8314 Mdot
.2285 .62494 Mdot
.32499 .857 Mdot
.26513 .79551 Mdot
.41349 .02807 Mdot
.27243 .77061 Mdot
.18852 .67429 Mdot
.99522 .86356 Mdot
.41079 .94522 Mdot
.40958 .56676 Mdot
.35181 .11334 Mdot
.28349 .9041 Mdot
.96392 .94927 Mdot
.08131 .91724 Mdot
.36841 .91744 Mdot
.11311 .68438 Mdot
.17862 .67019 Mdot
.21946 .64633 Mdot
.94312 .1081 Mdot
.07558 .62523 Mdot
.31943 .82997 Mdot
.22076 .71927 Mdot
.24772 .70723 Mdot
.71792 .09409 Mdot
.15103 .65185 Mdot
.3946 .05174 Mdot
.34284 .87801 Mdot
.2922 .7719 Mdot
.27622 .89881 Mdot
.41572 .10265 Mdot
.31362 .02937 Mdot
.33335 .96151 Mdot
.25416 .01731 Mdot
.20881 .70688 Mdot
.33826 .0857 Mdot
.28747 .82173 Mdot
.25015 .41656 Mdot
.25415 .64976 Mdot
.24952 .87312 Mdot
.3104 .82195 Mdot
.17276 .78185 Mdot
.25013 .68146 Mdot
.19004 .77711 Mdot
.29362 .76125 Mdot
.33922 .6465 Mdot
.33436 .97608 Mdot
.41049 .94465 Mdot
.21296 .2749 Mdot
.3091 .84933 Mdot
.41173 .10247 Mdot
.21159 .7251 Mdot
.19849 .68108 Mdot
.13903 .75492 Mdot
.06459 .67885 Mdot
.25913 .79389 Mdot
.18407 .15637 Mdot
.43593 .04331 Mdot
.24592 .60791 Mdot
.341 .9912 Mdot
.89678 .78995 Mdot
.2235 .77332 Mdot
.2848 .81481 Mdot
.29079 .7928 Mdot
.10259 .92895 Mdot
.30119 .95246 Mdot
.26426 .93859 Mdot
.68168 .12189 Mdot
.30052 .7406 Mdot
.17309 .67781 Mdot
.49916 .15736 Mdot
.33229 .50742 Mdot
.1145 .94055 Mdot
.30301 .73848 Mdot
.01687 .35729 Mdot
.21946 .838 Mdot
.9382 .96954 Mdot
.24092 .8006 Mdot
.23705 .80716 Mdot
.22822 .66769 Mdot
.33174 .99188 Mdot
.42255 .58266 Mdot
.97586 .19437 Mdot
.15219 .90058 Mdot
.03303 .79262 Mdot
.09532 .07273 Mdot
.22267 .56144 Mdot
.28146 .94414 Mdot
.33396 .97403 Mdot
.27888 .98026 Mdot
.36011 .57783 Mdot
.2521 .67936 Mdot
.38389 .01305 Mdot
.24285 .66661 Mdot
.36865 .71363 Mdot
.37267 .15661 Mdot
.36265 .73976 Mdot
.17315 .772 Mdot
.08125 .74984 Mdot
.25021 .70422 Mdot
.41552 .19895 Mdot
.13295 .11655 Mdot
.30115 .01037 Mdot
.30669 .81491 Mdot
.25039 .79325 Mdot
.38925 .11401 Mdot
.44062 .0747 Mdot
.40772 .57816 Mdot
.42868 .08141 Mdot
.1457 .9596 Mdot
.09341 .92876 Mdot
.37031 .84353 Mdot
.30656 .8436 Mdot
.30692 .72247 Mdot
.40927 .62845 Mdot
.31165 .97974 Mdot
.62361 .24911 Mdot
.3065 .72717 Mdot
.22526 .74121 Mdot
.44693 .52283 Mdot
.31172 .86081 Mdot
.32346 .94433 Mdot
.19967 .69279 Mdot
.14585 .57636 Mdot
.12434 .93406 Mdot
.25012 .76129 Mdot
.12564 .51232 Mdot
.1076 .00708 Mdot
.25489 .72573 Mdot
.11687 .81737 Mdot
.25509 .79195 Mdot
.73759 .21718 Mdot
.09174 .94649 Mdot
.99902 .93219 Mdot
.08947 .87816 Mdot
.33897 .86719 Mdot
.39189 .88879 Mdot
.356 .12095 Mdot
.20164 .52098 Mdot
.19728 .39152 Mdot
.30026 .74198 Mdot
.22697 .72324 Mdot
.23664 .79353 Mdot
.28832 .02913 Mdot
.32049 .81878 Mdot
.06203 .71597 Mdot
.39046 .03095 Mdot
.45027 .99347 Mdot
.98169 .00106 Mdot
.04836 .72487 Mdot
.25926 .68088 Mdot
.83245 .46859 Mdot
.47677 .01649 Mdot
.12193 .62424 Mdot
.11052 .3247 Mdot
.2792 .78883 Mdot
.4705 .97181 Mdot
.14398 .54362 Mdot
.22369 .72607 Mdot
.21805 .73135 Mdot
.2653 .84794 Mdot
.36405 .00585 Mdot
.2086 .12768 Mdot
.47354 .96328 Mdot
.27676 .72364 Mdot
.11641 .93978 Mdot
.41954 .58743 Mdot
.02446 .86346 Mdot
.15445 .97691 Mdot
.22509 .72746 Mdot
.50595 .02832 Mdot
.1496 .773 Mdot
.40844 .60884 Mdot
.10814 .70939 Mdot
.21165 .64567 Mdot
.21075 .68717 Mdot
.25772 .8354 Mdot
.15216 .10407 Mdot
.4649 .98761 Mdot
.3223 .72181 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo0_l00005ooooo`;o00001oooool00ol0003oooooooooo`02o`0000_ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`04ooooo`;o00002?ooool01?l0003oooooo`000?l00007oooo
o`;o00000oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;o00002Oooool3o`00
013ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`;o00002Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool2o`00
00Gooooo00?o0000ooooooooool00_ooool001kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`04o`000?oooooo0000o`0000cooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool01?l0
003oooooooooooooool2o`0000_ooooo00?o0000ooooooooool02?ooool4o`000003ooooool0003o
oooo00kooooo00?o0000ooooooooool00_l00009ooooo`?o00004?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00;ooooo0_l00009ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo000Noooo
o`03o`000?oooooooooo01oooooo0_l0000Oooooo`?o00006?ooool2o`000003ooooool0003o0000
01;ooooo0_l0000Hooooo`;o00000oooool2o`000;Cooooo000Nooooo`03o`000?oooooooooo01oo
oooo0_l0000Oooooo`?o00004?ooool2o`0000Kooooo0_l000000ooooooo0000o`000002ooooo`;o
00005Oooool4o`0000cooooo0_l00006ooooo`;o0000]?ooool001kooooo00?o0000ooooooooool0
7oooool2o`0002Cooooo0_l0000<ooooo`;o000000?oooooo`000?l000002_ooool2o`0001Gooooo
1?l0000<ooooo`;o000000?oooooo`000?l000002Oooool2o`000:kooooo000Nooooo`03o`000?oo
oooooooo04Gooooo0_l00007ooooo`?o00001Oooool2o`0002_ooooo1?l00005ooooo`;o00002Ooo
ool2o`0000gooooo0_l0002Oooooo`007_ooool00ol0003oooooooooo`14ooooo`;o00002?ooool3
o`0003;ooooo1?l00002ooooo`;o00006oooool2o`0009oooooo000Nooooo`03o`000?oooooooooo
01Gooooo0_l0000]ooooo`;o000000?oooooo`000?l000008_ooool2o`0001Oooooo0_l00003oooo
o`;o00001?ooool2o`0005Oooooo0_l0001Mooooo`007_ooool00ol0003oooooooooo`02o`0001?o
oooo0_l0000`ooooo`;o00008_ooool2o`0000;ooooo0_l0000Aooooo`;o00000oooool3o`0000Go
oooo0_l0000?ooooo`;o0000A_ooool2o`0005gooooo000Nooooo`03o`000?oooooooooo00;o0000
F?ooool2o`0000Kooooo0_l0000;ooooo`;o00002_ooool2o`0000Gooooo1?l000001?oooooo0000
o`000?l0000Fooooo`;o0000YOooool001kooooo00?o0000ooooooooool02Oooool2o`0004oooooo
0_l00006ooooo`;o00005oooool2o`0000?ooooo0_l00002ooooo`?o0000`?ooool001kooooo00?o
0000ooooooooool02Oooool2o`0004?ooooo0_l0000`ooooo`?o00000_ooool2o`0004Kooooo0_l0
001hooooo`007_ooool00ol0003oooooooooo`1>ooooo`;o00009oooool2o`0000Sooooo0_l0001:
ooooo`;o00008?ooool2o`0005Kooooo000Nooooo`03o`000?oooooooooo03Sooooo0_l000000ooo
oooo0000o`00000]ooooo`;o00002oooool2o`0000Kooooo0_l00009ooooo`;o00002_ooool2o`00
05Oooooo0_l0001Fooooo`007_ooool00ol0003oooooooooo`0Booooo`;o00009?ooool2o`000003
ooooool0003o0000023ooooo0_l0000;ooooo`;o00004oooool2o`0000Wooooo0_l00005ooooo`;o
00000oooool2o`0002;ooooo0_l0002;ooooo`007_ooool00ol0003oooooooooo`0Booooo`;o0000
BOooool2o`0000cooooo0_l0000Tooooo`;o00009oooool2o`0008_ooooo000Nooooo`;o0000F?oo
ool2o`0000Cooooo0_l0000<ooooo`;o00003oooool2o`0006kooooo0_l0000cooooo`;o00009?oo
ool001kooooo00?o0000ooooooooool0Eoooool3o`0000?ooooo0_l0000Mooooo`;o0000JOooool2
o`0000?ooooo0_l0000cooooo`;o00009?ooool001kooooo00?o0000ooooooooool0F?ooool2o`00
08gooooo0_l0001Nooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o0000>oooool2o`0008Ko
oooo0_l0001Pooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o00004Oooool2o`0003_ooooo
0_l00004ooooo`;o0000Boooool2o`0003?ooooo0_l0001Pooooo`007_ooool00ol0003ooooooooo
o`0=ooooo`;o0000E?ooool2o`0001Kooooo0_l0000Cooooo`;o00007_ooool2o`0009Gooooo000N
ooooo`03o`000?oooooooooo07_ooooo0_l0000Cooooo`;o000000?oooooo`000?l00000>oooool2
o`0007Gooooo000Nooooo`03o`000?oooooooooo01_ooooo0_l0000[ooooo`;o00006_ooool2o`00
013ooooo0_l0000Cooooo`;o00001_ooool2o`0003_ooooo0_l0001eooooo`007_ooool00ol0003o
ooooooooo`0Kooooo`;o00007oooool2o`0000[ooooo0_l0000Jooooo`;o00002?ooool2o`000003
ooooool0003o000000?ooooo0_l0000Cooooo`;o0000^_ooool001kooooo00?o0000ooooooooool0
??ooool2o`00033ooooo0_l000000ooooooo0000o`00003Dooooo`007_ooool00ol0003ooooooooo
o`1Uooooo`;o00004_ooool2o`0000cooooo0_l0001>ooooo`;o0000>_ooool2o`0003;ooooo000N
ooooo`03o`000?oooooooooo06Gooooo0_l00003ooooo`;o00003Oooool2o`0000cooooo0_l0001>
ooooo`;o00001oooool2o`00037ooooo0_l0000booooo`007_ooool00ol0003oooooooooo`1Zoooo
o`;o0000M?ooool4o`0003oooooo0_l0000Rooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o
0000Eoooool2o`0007Oooooo0_l0000oooooo`;o00008_ooool001kooooo00?o0000ooooooooool0
4?ooool2o`0005Oooooo0_l0001jooooo`;o0000H?ooool001kooooo00?o0000ooooooooool0JOoo
ool2o`0005[ooooo0_l0000Nooooo`;o0000H?ooool001kooooo0_l0001gooooo`;o00002_ooool3
o`00043ooooo0_l00003ooooo`;o0000Noooool001kooooo00?o0000ooooooooool0;Oooool2o`00
04Oooooo0_l0000:ooooo`?o0000AOooool2o`0007_ooooo000Nooooo`03o`000?oooooooooo02go
oooo0_l0000oooooo`;o00003Oooool2o`000;3ooooo0_l0000Fooooo`007_ooool00ol0003ooooo
ooooo`1^ooooo`Co00002oooool2o`000;3ooooo0_l0000Fooooo`007_ooool00ol0003ooooooooo
o`1^ooooo`Co00002?ooool2o`000<_ooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l00006
ooooo`;o0000>oooool4o`0000[ooooo0_l0001^ooooo`;o0000??ooool2o`0001gooooo000Noooo
o`03o`000?oooooooooo02Oooooo0_l00006ooooo`;o0000>oooool2o`0000;ooooo0_l0001hoooo
o`;o0000??ooool2o`0001gooooo000Nooooo`03o`000?oooooooooo073ooooo0_l0001Xooooo`;o
0000Joooool001kooooo00?o0000ooooooooool0f_ooool2o`0006_ooooo000Nooooo`03o`000?oo
oooooooo03Cooooo0_l0000:ooooo`;o0000>oooool2o`0000?ooooo0_l00033ooooo`007_ooool0
0ol0003oooooooooo`0dooooo`;o00002_ooool2o`0003_ooooo0_l00003ooooo`;o0000`oooool0
01kooooo00?o0000ooooooooool0<?ooool2o`000?oooooo5_ooool001kooooo00?o0000oooooooo
ool0<?ooool2o`0009cooooo0_l0001gooooo`007_ooool00ol0003oooooooooo`3>ooooo`;o0000
GOooool2o`0001Sooooo000Nooooo`03o`000?oooooooooo0?oooooo;_ooool2o`0000Sooooo0_l0
000>ooooo`007_ooool00ol0003oooooooooo`3oooooocSooooo0_l0000>ooooo`007_ooool2o`00
06kooooo0_l0000looooo`;o0000SOooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo06go
oooo0_l0000looooo`;o0000SOooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo03Sooooo
0_l0000iooooo`Co00009oooool2o`0001kooooo0_l00027ooooo`007_ooool00ol0003ooooooooo
o`0hooooo`;o0000>Oooool4o`0002Oooooo0_l0000Mooooo`?o0000Qoooool001kooooo00?o0000
ooooooooool0@?ooool2o`0007_ooooo0_l0000Yooooo`;o00002oooool2o`00053ooooo000Noooo
o`03o`000?oooooooooo033ooooo0_l0000>ooooo`;o0000Y_ooool2o`0000_ooooo0_l0001@oooo
o`007_ooool00ol0003oooooooooo`0`ooooo`;o0000oooooolFooooo`007_ooool00ol0003ooooo
ooooo`05ooooo`;o0000Xoooool2o`0009_ooooo000Nooooo`03o`000?oooooooooo00Gooooo0_l0
002Iooooo`;o00002?ooool2o`0002?ooooo0_l0001fooooo`007_ooool00ol0003oooooooooo`1G
ooooo`;o0000Aoooool2o`0002gooooo0_l0001fooooo`007_ooool00ol0003oooooooooo`1Goooo
o`;o0000k_ooool001kooooo00?o0000ooooooooool0i_ooool2o`0005oooooo000Nooooo`03o`00
0?oooooooooo06Sooooo0_l0001looooo`;o0000Goooool001kooooo00?o0000ooooooooool0J?oo
ool2o`000<?ooooo0_l0000Hooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`Go00001_ooool00ol0003oooooooooo`3oooooobkooooo0_l0000:ooooo`;o00003?oo
ool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^
k_ooooooA4A400Kooooo00?o0000ooooooooool0O?ooool2o`0000_ooooo0_l0000kooooo`;o0000
4Oooool2o`0005kooooo0_l0000<ooooo`000oooool01Ol@413ooooooooooooooooo410@00cooooo
00?oV9RHob4Q8Oo^k^h01oooool3o`0007cooooo0_l00005ooooo`;o00001?ooool2o`0003_ooooo
0_l0000Aooooo`;o0000K?ooool000?ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0Poooool2o`000:;ooooo0_l0000Nooooo`000ooo
ool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooo
ooooo`3oooooobSooooo0_l0000Nooooo`000oooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Yooooo`;o0000NOooool4o`0001oooooo
0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Ko
oooo00?o0000ooooooooool0ZOooool2o`0007Wooooo1?l0000Oooooo`000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo
0>kooooo0_l0001Gooooo`007_ooool00ol0003oooooooooo`3/ooooo`Co0000Eoooool001kooooo
00?o0000ooooooooool0k?ooool2o`0005Wooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
oc?ooooo0_l0000Cooooo`007_ooool00ol0003oooooooooo`3ooooooc?ooooo0_l0000Cooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo03cooooo0_l0
003oooooo`[ooooo000Nooooo`03o`000?oooooooooo01[ooooo0_l0000Pooooo`;o0000ooooool:
ooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o0000ooooool?ooooo`;o00006oooool001ko
oooo00?o0000ooooooooool0aoooool2o`00063ooooo0ol0000Kooooo`007_ooool2o`000<Sooooo
0_l0001Pooooo`;o00007?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo01Sooooo0_l0003ooooo
obkooooo000Nooooo`03o`000?oooooooooo01Sooooo0_l0003oooooo`_ooooo0_l0000Qooooo`00
7_ooool00ol0003oooooooooo`0Eooooo`;o0000ooooool>ooooo`;o00008Oooool001kooooo00?o
0000ooooooooool05Oooool2o`000?oooooo<Oooool001kooooo00?o0000ooooooooool0@Oooool2
o`0003Cooooo0_l0003>ooooo`007_ooool00ol0003oooooooooo`11ooooo`;o0000=?ooool2o`00
0<kooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0
003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`2[ooooo`;o0000V_ooool001kooooo
00?o0000ooooooooool0Zoooool2o`0009[ooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo023ooooo0_l0003oooooobKooooo000Nooooo`03o`00
0?oooooooooo023ooooo0_l0003oooooobKooooo000Nooooo`03o`000?oooooooooo0:_ooooo0_l0
002Jooooo`007_ooool00ol0003oooooooooo`2[ooooo`;o0000V_ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo07[ooooo0_l0003;ooooo`007_ooool00ol0003oooooooooo`1jooooo`;o0000AOoo
ool2o`0008Cooooo000Nooooo`;o0000`_ooool2o`0008Cooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00Co0000oooooooooooooooo0_l0001=ooooo`;o0000Z_ooool2o`00
04Wooooo000Nooooo`04o`000?ooooooooooooooo`;o0000COooool2o`000:[ooooo0_l00019oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`0looooo`;o0000ooooool:ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0loooo
o`;o0000ooooool:ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol@413o
oooooooooooooooo410@00_ooooo1Ol00006ooooo`?o0000oooooom8ooooo`000oooool01Ol0003o
oooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool00ol0003oooooooooo`3o
ooooodSooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0
0007ooooo`03o`000?oooooooooo0?oooooo@?ooool2o`0000Kooooo0003ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo0?oooooo@?oo
ool2o`0000Kooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00
0007ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0COooool2o`0002kooooo0_l0
0038ooooo`007_ooool00ol0003oooooooooo`1=ooooo`;o0000;_ooool2o`000<Sooooo000Noooo
o`03o`000?oooooooooo04Kooooo0_l0003oooooo`007_ooool00ol0003oooooooooo`16ooooo`;o
0000ooooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`1_ooooo`;o0000e_ooool001kooooo00?o0000ooooooooool0Koooool2o`000=Kooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0Noooool2o`000<[ooooo000Nooooo`;o000000?oooooo`00
0?l00000Joooool2o`0000cooooo0_l0003:ooooo`007_ooool00ol0003oooooooooo`02o`0005ko
oooo1?l00009ooooo`;o0000f?ooool001kooooo00?o0000ooooooooool0H?ooool4o`000>?ooooo
000Nooooo`03o`000?oooooooooo03Sooooo0_l0003oooooo`kooooo000Nooooo`03o`000?oooooo
oooo03Sooooo0_l00007ooooo`;o0000ooooool5ooooo`007_ooool00ol0003oooooooooo`11oooo
o`;o0000b?ooool2o`0003[ooooo000Nooooo`03o`000?oooooooooo05Gooooo0_l0002dooooo`;o
0000>_ooool001kooooo00?o0000ooooooooool0EOooool2o`000?3ooooo000Nooooo`03o`000?oo
oooooooo0>cooooo0_l0001Iooooo`007_ooool00ol0003oooooooooo`3/ooooo`;o0000FOooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`1;ooooo`;o
00007_ooool2o`0000;ooooo0_l0003Fooooo`007_ooool00ol0003oooooooooo`0looooo`;o0000
3Oooool2o`0001kooooo0_l00002ooooo`;o0000e_ooool001kooooo00?o0000ooooooooool0:?oo
ool2o`000003ooooool0003o000000Sooooo0_l00005ooooo`;o0000>?ooool2o`0000Cooooo0_l0
000Oooooo`;o0000Z?ooool001kooooo00?o0000ooooooooool0:?ooool2o`000003ooooool0003o
000000Sooooo0_l0000oooooo`;o00001?ooool2o`0001oooooo0_l0002Xooooo`007_ooool00ol0
003oooooooooo`0Zooooo`;o00002Oooool2o`0003Kooooo0_l0003Hooooo`007_ooool2o`0002_o
oooo0_l00011ooooo`;o0000f?ooool001kooooo00?o0000ooooooooool0K?ooool2o`0001_ooooo
0_l0002looooo`007_ooool00ol0003oooooooooo`0nooooo`;o00004?ooool2o`0001Kooooo0_l0
0002ooooo`;o00006oooool2o`000;cooooo000Nooooo`03o`000?oooooooooo03Sooooo0_l00004
ooooo`;o00004?ooool2o`0001Kooooo0_l0000:ooooo`;o00000oooool2o`000<cooooo000Noooo
o`03o`000?oooooooooo02Gooooo0_l0000Aooooo`;o000000?oooooo`000?l000000oooool2o`00
03;ooooo0_l00003ooooo`;o0000c?ooool001kooooo00?o0000ooooooooool09Oooool2o`0001Co
oooo0_l00003ooooo`;o0000=Oooool2o`000<kooooo000Nooooo`03o`000?oooooooooo03gooooo
0_l0000>ooooo`;o0000:?ooool4o`000<cooooo000Nooooo`03o`000?oooooooooo03Oooooo0_l0
0004ooooo`;o00003_ooool2o`0002[ooooo0_l0000Booooo`;o0000^?ooool001kooooo00?o0000
ooooooooool0=oooool2o`0005Cooooo0_l0002hooooo`007_ooool00ol0003oooooooooo`0_oooo
o`;o0000oooooolGooooo`007_ooool00ol0003oooooooooo`0_ooooo`;o00009_ooool2o`0001co
oooo0_l0003@ooooo`007_ooool00ol0003oooooooooo`0cooooo`;o00001Oooool2o`0001_ooooo
0_l0000Kooooo`?o0000d?ooool001kooooo00?o0000ooooooooool0<oooool2o`0000Gooooo0_l0
000Mooooo`;o00006Oooool2o`0002Gooooo0_l0002Zooooo`007_ooool00ol0003oooooooooo`0Q
ooooo`;o000000?oooooo`000?l00000<oooool2o`0000Wooooo0_l0000eooooo`;o0000Z_ooool0
01kooooo00?o0000ooooooooool08Oooool2o`000003ooooool0003o000000Gooooo0_l0000goooo
o`;o0000hOooool001kooooo00?o0000ooooooooool0:oooool2o`0005;ooooo1?l00034ooooo`00
7_ooool2o`00047ooooo0_l0000mooooo`Co0000a?ooool001kooooo00?o0000ooooooooool0@?oo
ool2o`00037ooooo0_l0003Booooo`007_ooool00ol0003oooooooooo`1Zooooo`;o00001oooool2
o`000=;ooooo000Nooooo`03o`000?oooooooooo04oooooo0_l0000Iooooo`;o0000foooool001ko
oooo00?o0000ooooooooool0A?ooool2o`0000Cooooo0_l00003ooooo`;o00005_ooool2o`000=ko
oooo000Nooooo`03o`000?oooooooooo03kooooo0_l00004ooooo`;o00001?ooool2o`0000cooooo
0_l0000=ooooo`;o00006?ooool2o`000<Cooooo000Nooooo`03o`000?oooooooooo02oooooo1?l0
000;ooooo`;o00006?ooool2o`0001[ooooo0_l0000;ooooo`;o00003oooool2o`000;?ooooo000N
ooooo`03o`000?oooooooooo02oooooo1?l0000Kooooo`;o00007Oooool2o`0000Gooooo0_l0000E
ooooo`;o00001Oooool2o`000;?ooooo000Nooooo`03o`000?oooooooooo02_ooooo0_l0000Poooo
o`?o00007Oooool2o`0000kooooo0_l0000;ooooo`?o0000^_ooool001kooooo00?o0000oooooooo
ool0:oooool4o`0001kooooo0_l0000Aooooo`Co00003Oooool2o`0000Cooooo0_l00004ooooo`;o
000000?oooooo`000?l000002?ooool2o`000;_ooooo000Nooooo`03o`000?oooooooooo027ooooo
0_l0000:ooooo`;o00001_ooool2o`0001[ooooo0_l0000=ooooo`Co00003Oooool2o`0000Cooooo
0_l00002ooooo`;o00000oooool3o`0000;ooooo0_l0000Iooooo`?o0000Y?ooool001kooooo00?o
0000ooooooooool08Oooool2o`0001;ooooo0_l0000Jooooo`;o00009oooool5o`0000;ooooo1_l0
000Iooooo`?o0000Y?ooool001kooooo00?o0000ooooooooool0FOooool2o`0001Kooooo0_l00007
ooooo`;o000000?oooooo`000?l000000oooool4o`000<7ooooo000Nooooo`03o`000?oooooooooo
02Gooooo0_l0000booooo`;o00005_ooool2o`0000oooooo1?l00003ooooo`;o0000_?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413o
c<c<00Kooooo00?o0000ooooooooool06Oooool2o`0000[ooooo0_l0000/ooooo`;o00005oooool2
o`0001_ooooo0_l00003ooooo`;o0000]oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool06Ooo
ool2o`0002Gooooo0_l0000Aooooo`;o00005oooool2o`00023ooooo0_l0002gooooo`000oooool0
1Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000
@?ooool2o`0006Sooooo0_l0002Kooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo
00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo023ooooo0_l00008ooooo`;o
0000Hoooool2o`0001Wooooo0_l0002Kooooo`000oooool01Ol0003ooooooooooooooooo000000_o
oooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo023ooooo0_l00008oooo
o`;o0000<Oooool2o`0002_ooooo0_l00003ooooo`;o0000]_ooool000?ooooo00Go410@oooooooo
oooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0C?ooool2o`00
00oooooo0_l000000ooooooo0000o`00000;ooooo`;o00003?ooool2o`0000Cooooo0_l00007oooo
o`;o0000^oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH
00Sooooo00?o0000ooooooooool08?ooool2o`0002[ooooo0_l0000Booooo`;o00002oooool2o`00
0003ooooool0003o000000Wooooo0_l00004ooooo`;o0000a?ooool000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool08?ooool2
o`0001Wooooo0_l0000cooooo`;o0000eOooool001kooooo00?o0000ooooooooool0>oooool4o`00
02;ooooo0_l0000Tooooo`;o0000__ooool001kooooo00?o0000ooooooooool06_ooool2o`00027o
oooo0_l0000=ooooo`;o00002?ooool2o`0000Wooooo0_l0000Tooooo`;o00007Oooool2o`0009oo
oooo000Nooooo`03o`000?oooooooooo01Cooooo0_l00004ooooo`;o000000?oooooo`000?l00000
1Oooool2o`00023ooooo1?l00002ooooo`;o00002?ooool2o`0000Gooooo0_l0000Yooooo`;o0000
7?ooool2o`0009oooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l00006ooooo`Co00001?oo
ool2o`00023ooooo1?l00002ooooo`;o00002oooool2o`0000;ooooo0_l0000Rooooo`;o00001Ooo
ool2o`000;gooooo000Nooooo`03o`000?oooooooooo01cooooo1?l00004ooooo`;o0000<oooool3
o`0002Gooooo1?l00032ooooo`007_ooool00ol0003oooooooooo`0Tooooo`Co00009?ooool2o`00
00cooooo0_l0000Aooooo`;o00005?ooool2o`000<;ooooo000Nooooo`03o`000?oooooooooo02Ko
oooo0_l0000Hooooo`;o00002_ooool2o`0001Oooooo0_l00006ooooo`;o00002_ooool2o`000<co
oooo000Nooooo`03o`000?oooooooooo043ooooo0_l0000;ooooo`;o00000oooool2o`00017ooooo
0_l0000Booooo`;o0000c?ooool001kooooo00?o0000ooooooooool0:Oooool2o`0002;ooooo0_l0
0003ooooo`;o0000loooool001kooooo00?o0000ooooooooool0:Oooool2o`0001Kooooo1?l0000J
ooooo`;o00002Oooool2o`000=_ooooo000Nooooo`03o`000?oooooooooo01gooooo0_l0000Roooo
o`Co00002_ooool2o`0000kooooo0_l00009ooooo`;o00006Oooool2o`000<3ooooo000Nooooo`;o
00007_ooool2o`0000kooooo0_l0000Pooooo`;o0000:_ooool2o`0000Sooooo0ol0002oooooo`00
7_ooool00ol0003oooooooooo`0Mooooo`;o00003_ooool2o`0000oooooo0_l00007ooooo`;o0000
4_ooool2o`0001kooooo0_l00009ooooo`;o0000_oooool001kooooo00?o0000ooooooooool07Ooo
ool2o`0001oooooo0_l00007ooooo`Co00004?ooool2o`0001Sooooo0_l0000@ooooo`Co00008?oo
ool2o`0009[ooooo000Nooooo`03o`000?oooooooooo03_ooooo0_l00008ooooo`;o000000Cooooo
o`000?l0003o00001_ooool2o`0000?ooooo1?l00006ooooo`;o00004oooool3o`0000Gooooo0_l0
0008ooooo`Co00008?ooool2o`0009[ooooo000Nooooo`03o`000?oooooooooo03_ooooo0_l00008
ooooo`;o00002_ooool2o`0000?ooooo1?l00006ooooo`;o00005?ooool2o`0000Gooooo0_l00038
ooooo`007_ooool00ol0003oooooooooo`0dooooo`;o00001_ooool2o`0000Sooooo0_l00003oooo
o`;o00009Oooool2o`000003ooooool0003o00000=3ooooo000Nooooo`03o`000?oooooooooo02So
oooo0_l0000:ooooo`Co00001?ooool3o`0000Oooooo0_l00003ooooo`;o00009Oooool2o`000003
ooooool0003o00000=3ooooo000Nooooo`03o`000?oooooooooo01oooooo0_l00007ooooo`;o0000
0_ooool3o`0000?ooooo0_l00002ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0001co
oooo0_l0000Iooooo`;o00005?ooool2o`000:7ooooo0_l0000Fooooo`007_ooool00ol0003ooooo
ooooo`0Eooooo`;o00002?ooool2o`0000Wooooo1Ol00003ooooo`Co00000oooool3o`0000;ooooo
0_l00008ooooo`;o00004Oooool2o`0000cooooo0_l0000;ooooo`;o00005?ooool2o`000:7ooooo
0_l0000Fooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o000000Coooooo`000?l0003o0000
4oooool2o`0000Sooooo0_l00002ooooo`?o000000?oooooo`000?l000000_l00008ooooo`;o0000
1?ooool4o`0001Oooooo0_l0000Qooooo`;o0000^Oooool001kooooo00?o0000ooooooooool04?oo
ool6o`0002;ooooo0ol000000ooooooo0000o`00000=ooooo`Oo00001oooool2o`0000Wooooo0_l0
003Gooooo`;o00002?ooool001kooooo00?o0000ooooooooool04?ooool7o`0000[ooooo0_l0000A
ooooo`;o00000_ooool3o`0000;ooooo1Ol00009ooooo`Co00002_ooool2o`0000Wooooo0_l0003G
ooooo`;o00002?ooool001kooooo00?o0000ooooooooool03oooool8o`0000?ooooo0_l00005oooo
o`;o00004Oooool2o`0000?ooooo0_l00002ooooo`Ko00006Oooool2o`000>Wooooo000Nooooo`03
o`000?oooooooooo00oooooo1?l00007ooooo`;o00002oooool2o`000003ooooool0003o000000go
oooo1_l000001?oooooo0000o`000?l00005ooooo`;o00004_ooool2o`00017ooooo0_l0003Foooo
o`007_ooool00ol0003oooooooooo`0Cooooo`;o00002?ooool2o`0000Sooooo0_l000000ooooooo
0000o`00000?ooooo`Co000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00002Oooool2o`00
01Sooooo1?l0000Nooooo`;o0000]_ooool001kooooo00?o0000ooooooooool04oooool2o`0000So
oooo0_l0000?ooooo`;o00004?ooool2o`000003ooooool0003o000000?ooooo0_l00009ooooo`;o
00000_ooool2o`0001?ooooo0ol0000Pooooo`;o0000]_ooool001kooooo0_l0000@ooooo`;o0000
7Oooool2o`0001?ooooo0_l0000Booooo`;o00003_ooool2o`0000?ooooo0_l0000Qooooo`;o0000
SOooool2o`0002Oooooo000Nooooo`03o`000?oooooooooo00oooooo0_l00006ooooo`;o00001_oo
ool2o`0001gooooo0_l00002ooooo`?o00002?ooool2o`000003ooooool0003o000000gooooo0_l0
0003ooooo`;o000000?oooooo`000?l000009_ooool2o`0008gooooo0_l0000Wooooo`007_ooool0
0ol0003oooooooooo`0Dooooo`Go00001?ooool4o`0001gooooo1_l00008ooooo`?o000000?ooooo
o`000?l000003Oooool2o`000003ooooool0003o000000;o0000hOooool001kooooo00?o0000oooo
ooooool05?ooool4o`0000Gooooo1?l0000Mooooo`So00001Oooool3o`0001Cooooo0_l0003Soooo
o`007_ooool00ol0003oooooooooo`0Cooooo`Co00002?ooool2o`0000kooooo0_l0000;ooooo`[o
00001Oooool2o`0000[ooooo0_l0000Kooooo`;o0000dOooool001kooooo00?o0000ooooooooool0
4?ooool2o`000003ooooool0003o000000;o00003?ooool2o`0000[ooooo0_l0000;ooooo`;o0000
0_ooool7o`00013ooooo0_l0000<ooooo`;o00003Oooool2o`000=7ooooo000Nooooo`03o`000?oo
oooooooo00cooooo0_l00002ooooo`;o00001?ooool2o`0000_ooooo0_l0000Gooooo`;o000000?o
ooooo`000?l000000_ooool5o`0001Sooooo0_l00003ooooo`;o00000_ooool2o`000<kooooo0_l0
000<ooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o00002?ooool2o`0000kooooo1?l0000:
ooooo`?o00001Oooool2o`000004ooooool0003o0000ooooo`Ko00003Oooool3o`0000Gooooo1Ol0
0003ooooo`;o00000_ooool2o`000<kooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`0<
ooooo`;o00006?ooool4o`0000[ooooo0ol00003ooooo`Co00000oooool7o`0000Oooooo0ol00003
ooooo`?o00001?ooool6o`0000?ooooo0_l0000[ooooo`;o0000/oooool001kooooo00?o0000oooo
ooooool03?ooool2o`0002;ooooo0_l00005ooooo`;o000000?oooooo`000?l000000_l00003oooo
o`;o000000Coooooo`000?l0003o00002?ooool4o`0000Gooooo0ol000000ooooooo0000o`000002
ooooo`?o0000;oooool2o`000:Gooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`0=oooo
o`;o00003Oooool2o`0001;ooooo0_l00005ooooo`;o00002?ooool8o`0000Sooooo0_l00004oooo
o`Co00001_ooool3o`000=Gooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o
00003Oooool2o`0002Gooooo0_l00002ooooo`?o00001oooool2o`0000Cooooo0_l00006ooooo`Go
00003_ooool2o`000=?ooooo000Nooooo`03o`000?oooooooooo02_ooooo0_l0000Kooooo`;o0000
5?ooool3o`00017ooooo0_l0003Cooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o00007ooo
ool2o`0001Sooooo1Ol00004ooooo`;o00002oooool6o`00017ooooo0_l0003Cooooo`007_ooool0
0ol0003oooooooooo`0:ooooo`Go000000?oooooo`000?l000007Oooool2o`0001?ooooo1ol00003
ooooo`;o00002oooool5o`0001;ooooo0_l0003Cooooo`007_ooool00ol0003oooooooooo`0<oooo
o`?o000000?oooooo`000?l000005?ooool2o`0000Oooooo0_l0000Cooooo`Co000000?oooooo`00
0?l00000o?ooool001kooooo0_l0000Gooooo`;o00003_ooool2o`0002kooooo0_l0003_ooooo`00
7_ooool00ol0003oooooooooo`0Fooooo`;o00004Oooool2o`0002_ooooo0_l00003ooooo`;o0000
<?ooool2o`000;Sooooo000Nooooo`03o`000?oooooooooo02Wooooo0_l0000Cooooo`;o00003ooo
ool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l00000<?ooool2o`000;Sooooo000N
ooooo`03o`000?oooooooooo03kooooo0_l0000?ooooo`;o00000_ooool2o`0000?ooooo0ol0003/
ooooo`007_ooool00ol0003oooooooooo`07ooooo`;o00007?ooool2o`0001cooooo0ol00007oooo
o`;o00002?ooool6o`000>[ooooo000Nooooo`;o00002?ooool2o`0001cooooo0_l0000Looooo`?o
00000oooool2o`0000;ooooo0_l00008ooooo`;o000000Coooooo`000?l0003o0000j_ooool001ko
oooo0_l0000Dooooo`;o00004Oooool2o`0001Gooooo0_l0000:ooooo`;o000000?oooooo`000?l0
00009_ooool2o`00023ooooo0_l0002_ooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o0000
4Oooool2o`0000Gooooo0_l00005ooooo`;o00001oooool2o`0000?ooooo0_l000001?oooooo0000
o`000?ooool2o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o00001Oooool4o`0001Go
oooo0_l0000Pooooo`;o0000Xoooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00[ooooo
0_l0000Qooooo`;o00001Oooool2o`0000cooooo0_l000001?oooooo0000o`000?ooool2o`0000?o
oooo1_l000001?oooooo0000o`000?l00003ooooo`Go0000g?ooool2o`0000[ooooo000Nooooo`03
o`000?oooooooooo00[ooooo0_l00006ooooo`;o00006_ooool3o`0000Wooooo0_l0000>ooooo`;o
000000?oooooo`000?l000000_ooool7o`0000;ooooo0_l0000jooooo`;o0000[oooool001kooooo
00?o0000ooooooooool04_ooool2o`0001[ooooo0ol00003ooooo`;o00001?ooool2o`0000kooooo
0_l00005ooooo`Oo000000?oooooo`000?l00000>oooool2o`000:oooooo000Nooooo`03o`000?oo
oooooooo02cooooo0_l00006ooooo`;o00005Oooool8o`0000Kooooo0_l0003/ooooo`007_ooool0
0ol0003oooooooooo`0/ooooo`;o00002oooool2o`00013ooooo1_l00006ooooo`;o0000k_ooool0
01kooooo00?o0000ooooooooool0>Oooool2o`0000gooooo0_l00005ooooo`;o00001_ooool2o`00
0<Kooooo0_l0000Vooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`07ooooo`;o0000<Oooool2
o`0000[ooooo1Ol000000ooooooo0000o`000004o`0000Gooooo1_l00003ooooo`;o0000_Oooool2
o`0002Kooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4Q
oiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo00Oooooo0_l0000Pooooo`;o00003ooo
ool2o`0000Gooooo0_l00003ooooo`;o000000?oooooo`000?l000002Ol00002ooooo`Oo00000ooo
ool4o`0000;ooooo0_l0003Oooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o00002oooool2o`0001cooooo0_l00007ooooo`;o0000
3Oooool2o`0000Oooooo1Ol00003ooooo`?o000000?oooooo`000?l000000oooool2o`0000Gooooo
0_l00002ooooo`;o00009_ooool2o`000;Oooooo0003ooooo`05o`000?ooooooooooooooool00000
2oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000ooooooooool02oooool2o`0002Go
oooo0_l0000=ooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`;o00001?ooool2o`00
00Kooooo0ol00004ooooo`;o0000:_ooool2o`000;Oooooo0003ooooo`05o`000?oooooooooooooo
ool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo0ol00017ooooo`Co000000?ooooo
o`000?l000003_ooool2o`0000Cooooo0_l0003Sooooo`000oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`?o0000BOooool2o`000003ooooool0
003o00000?Wooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooo
oonj^[[o000000Kooooo00?o0000ooooooooool0EOooool3o`0000cooooo0_l0003Qooooo`000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03
o`000?oooooooooo043ooooo0_l00009ooooo`;o00002?ooool5o`0000Kooooo0_l00002ooooo`;o
00001?ooool2o`00017ooooo0_l00038ooooo`007_ooool00ol0003oooooooooo`0Rooooo`;o0000
7?ooool2o`0000Wooooo0_l00003ooooo`;o00001Oooool6o`0000?ooooo1_l00004ooooo`;o0000
4Oooool2o`000<Sooooo000Nooooo`03o`000?oooooooooo02;ooooo0_l0000/ooooo`Ko00000_oo
ool5o`0000Cooooo1_l0000:ooooo`;o0000e?ooool001kooooo00?o0000ooooooooool0C_ooool2
o`000003ooooool0003o000000co00000_ooool2o`0000;ooooo0_l0000:ooooo`;o00002_ooool2
o`000<Sooooo000Nooooo`03o`000?oooooooooo04kooooo0_l00006ooooo`Co000000?oooooo`00
0?l000000_l00006ooooo`;o00005_ooool2o`000<Sooooo000Nooooo`03o`000?oooooooooo04Go
oooo0_l0000Kooooo`Go00005oooool2o`000<Oooooo000Nooooo`03o`000?oooooooooo03Kooooo
0_l0000=ooooo`;o00006oooool4o`0000kooooo0_l00008ooooo`;o0000aoooool001kooooo00?o
0000ooooooooool0=_ooool2o`0000Cooooo0_l00005ooooo`;o00002oooool3o`00027ooooo0_l0
003Aooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o00006_ooool2o`0000Gooooo1?l00009
ooooo`?o00002_ooool3o`0000Oooooo0_l00006ooooo`;o00001?ooool2o`000=3ooooo000Noooo
o`04o`000?oooooo0000o`0001oooooo0_l0000Sooooo`?o000000?oooooo`000?l000002oooool2
o`0000Gooooo1Ol00005ooooo`;o00001_ooool2o`0000?ooooo1Ol00004ooooo`;o00007oooool2
o`000:Oooooo000Nooooo`04o`000?oooooo0000o`0004Gooooo0_l000000ooooooo0000o`00000;
ooooo`;o00001Oooool2o`000003ooooool0003o000000gooooo0_l00003ooooo`;o000000?ooooo
o`000?l000001?ooool2o`0000Gooooo0_l0000Hooooo`;o0000Yoooool001kooooo00?o0000oooo
ooooool0@Oooool2o`0000oooooo0_l00009ooooo`;o000000?oooooo`000?l000003Oooool2o`00
01?ooooo0_l00031ooooo`007_ooool2o`0004;ooooo0ol0000>ooooo`;o00001?ooool2o`0000?o
oooo0_l000000ooooooo0000o`00000Nooooo`;o00004?ooool2o`0000[ooooo0_l0002Wooooo`00
7_ooool00ol0003oooooooooo`12ooooo`;o00005?ooool2o`000003ooooool0003o000000Cooooo
0_l00004ooooo`Co00001?ooool2o`0000_ooooo0_l00002ooooo`;o00004?ooool2o`0000[ooooo
0_l0002Wooooo`007_ooool00ol0003oooooooooo`1Gooooo`;o00000_ooool2o`0000Cooooo0_l0
0003ooooo`Go00000oooool3o`0000Kooooo0_l00003ooooo`;o0000bOooool001kooooo00?o0000
ooooooooool0AOooool2o`00013ooooo0_l00008ooooo`;o00000oooool4o`0000Cooooo0ol00005
ooooo`?o0000c_ooool001kooooo00?o0000ooooooooool01?ooool2o`0003oooooo0_l0000Joooo
o`;o00001Oooool2o`0000?ooooo1?l00005ooooo`;o0000aoooool2o`0000Kooooo000Nooooo`04
o`000?oooooo0000o`0000?ooooo0_l0000^ooooo`;o0000=?ooool2o`000003ooooool0003o0000
02Gooooo0_l0000Xooooo`;o0000Ooooool2o`0000Kooooo000Nooooo`03o`000?oooooo000000?o
0000<Oooool2o`0002Cooooo0_l0000>ooooo`;o00003oooool2o`0001Oooooo0_l0000Xooooo`;o
0000Qoooool001kooooo00Co0000oooooooooooooooo0_l00018ooooo`Co00002oooool2o`0000Ko
oooo0_l0000Gooooo`Co0000b?ooool001kooooo00?o0000ooooooooool0Boooool4o`0001?ooooo
0_l00002ooooo`;o00000oooool2o`00013ooooo0_l00038ooooo`007_ooool00ol0003ooooooooo
o`0Iooooo`;o0000Boooool4o`000003ooooool0003o000001Kooooo0_l0002jooooo`;o00001_oo
ool001kooooo00?o0000ooooooooool06Oooool2o`0000_ooooo0_l00010ooooo`;o00006Oooool2
o`000;[ooooo0_l00006ooooo`007_ooool00ol0003oooooooooo`0Vooooo`;o0000;oooool2o`00
0>kooooo000Nooooo`03o`000?oooooooooo05Oooooo0_l00008ooooo`;o00001oooool2o`0000oo
oooo0_l0002nooooo`;o00002_ooool001kooooo00?o0000ooooooooool0<?ooool2o`0002Gooooo
0_l00002ooooo`;o00001?ooool2o`0000Oooooo0_l0000?ooooo`;o00003_ooool2o`000:kooooo
0_l0000:ooooo`007_ooool00ol0003oooooooooo`0`ooooo`;o00008oooool4o`000004ooooool0
003o0000o`0000_ooooo0_l0000Qooooo`;o0000^_ooool001kooooo00?o0000ooooooooool0D_oo
ool2o`000004ooooool0003o0000o`0000;ooooo0_l0000<ooooo`;o000000?oooooo`000?l00000
3_ooool2o`0000Gooooo0_l00005ooooo`;o00004oooool2o`0009_ooooo0_l0000:ooooo`007_oo
ool2o`0002kooooo0_l0000Sooooo`;o00000_ooool2o`0001;ooooo0ol00003ooooo`;o00002Ooo
ool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000_ooooo0_l0002Kooooo`;o00002_oo
ool001kooooo00?o0000ooooooooool05Oooool2o`0001Kooooo0_l0000Eooooo`;o00004_ooool2
o`0000Cooooo0_l00008ooooo`Co00001?ooool2o`0001oooooo0_l0002dooooo`007_ooool00ol0
003oooooooooo`0Eooooo`;o0000;Oooool2o`0000oooooo0_l000000ooooooo0000o`000004oooo
o`;o00002?ooool2o`0000cooooo0_l0000Pooooo`;o0000[Oooool001kooooo00?o0000oooooooo
ool0EOooool2o`0001oooooo0_l00004ooooo`;o00006_ooool2o`000:gooooo000Nooooo`03o`00
0?oooooooooo01[ooooo0_l0000eooooo`;o00005oooool3o`0000oooooo0_l00005ooooo`;o0000
[_ooool2o`0001;ooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l00002ooooo`;o00003?oo
ool2o`0000_ooooo0_l0000Jooooo`;o00005oooool3o`0000Oooooo0_l0000=ooooo`;o0000[_oo
ool2o`0001;ooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l0000@ooooo`;o00002oooool2
o`0003Gooooo0_l00006ooooo`;o00005Oooool2o`000;[ooooo000Nooooo`03o`000?oooooooooo
04Sooooo0_l0000Looooo`;o00000_ooool4o`0001gooooo0_l000000ooooooo0000o`00002goooo
o`007_ooool00ol0003oooooooooo`18ooooo`;o00004_ooool2o`0000Sooooo0_l000001?oooooo
0000o`000?l0000Fooooo`;o00002_ooool2o`000;Oooooo000Nooooo`03o`000?oooooooooo01[o
oooo0_l000000ooooooo0000o`00000^ooooo`;o00003Oooool2o`0000Oooooo0_l00002ooooo`;o
00005oooool2o`00027ooooo0_l0002Pooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o0000
00?oooooo`000?l000003?ooool2o`0000[ooooo0_l0000Dooooo`;o00003?ooool2o`0000Sooooo
0_l0000nooooo`;o0000V_ooool2o`0000Cooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l0
0005ooooo`;o00002_ooool2o`0002;ooooo0_l0003Tooooo`;o00001?ooool001kooooo00?o0000
ooooooooool09?ooool2o`0002cooooo0_l00007ooooo`;o00000oooool2o`0000Wooooo0_l00008
ooooo`;o00001_ooool2o`0001Sooooo0_l0000@ooooo`;o0000W?ooool001kooooo00?o0000oooo
ooooool06Oooool2o`0000Gooooo1?l0000Rooooo`;o00002?ooool4o`0000Oooooo0_l00003oooo
o`;o00002?ooool3o`0000Sooooo1?l00004ooooo`;o00006?ooool2o`00013ooooo0_l0002Loooo
o`007_ooool00ol0003oooooooooo`0Iooooo`;o00001Oooool4o`0002;ooooo0_l00008ooooo`;o
00001Oooool2o`0000Gooooo0_l00005ooooo`;o00000oooool2o`0000Cooooo0_l00004ooooo`?o
00002?ooool2o`00063ooooo0_l0001Rooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o0000
2Oooool2o`0002Wooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l000000ooooooo0000
o`000006ooooo`;o00001?ooool2o`0000Sooooo0ol000000ooooooo0000o`00001Mooooo`;o0000
H_ooool001kooooo0_l0000Kooooo`Co00001oooool2o`00017ooooo0_l0000Sooooo`;o00002Ooo
ool2o`0001Kooooo0_l00002ooooo`;o0000Koooool2o`00033ooooo0_l0000<ooooo`;o00004?oo
ool001kooooo00?o0000ooooooooool07?ooool2o`0000_ooooo0_l0000=ooooo`;o00008oooool3
o`0002Cooooo0_l0000Hooooo`;o0000EOooool2o`00033ooooo0_l0000<ooooo`;o00004?ooool0
01kooooo00?o0000ooooooooool00_l0000Iooooo`;o00003?ooool2o`0003;ooooo0ol00004oooo
o`;o00002oooool2o`0001[ooooo0_l0000?ooooo`;o0000Yoooool001kooooo00?o0000oooooooo
ool00_l0000Booooo`;o00001Oooool2o`0000cooooo1?l0000Vooooo`;o00001?ooool2o`0000;o
oooo1Ol00002ooooo`;o000000?oooooo`000?l000002?ooool2o`0000Gooooo0_l0000=ooooo`;o
00001?ooool2o`0000Cooooo0_l0002booooo`007_ooool00ol0003oooooooooo`0Dooooo`;o0000
4oooool7o`0002?ooooo0_l000001?oooooo0000o`000?ooool2o`0000Gooooo1?l000000ooooooo
0000o`000003o`0000kooooo0_l0000=ooooo`;o00000_ooool2o`0000Kooooo0_l000001?oooooo
0000o`000?l0002^ooooo`007_ooool00ol0003oooooooooo`0/ooooo`Co00005?ooool2o`0000go
oooo0_l000000ooooooo0000o`000008ooooo`Oo000000?oooooo`000?l000003?ooool2o`0000Go
oooo0_l0000<ooooo`;o00001oooool5o`0006[ooooo0_l0000dooooo`;o00003?ooool001kooooo
00?o0000ooooooooool09_ooool2o`0001Cooooo0_l00006ooooo`;o00002Oooool2o`0000;ooooo
0_l00002ooooo`;o00001oooool6o`00013ooooo0ol00004ooooo`;o00005Oooool2o`0006gooooo
0_l0000Xooooo`;o00002_ooool2o`0000cooooo000Nooooo`03o`000?oooooooooo02Kooooo0_l0
000Dooooo`;o00003Oooool2o`0000;ooooo0_l00006ooooo`;o00000_ooool2o`0000?ooooo0_l0
0003ooooo`;o00004?ooool2o`0001cooooo0_l0002Fooooo`;o00006?ooool001kooooo00?o0000
ooooooooool0Boooool2o`0000kooooo0_l00003ooooo`;o00000_ooool7o`0000Sooooo0_l0000N
ooooo`Co00001_ooool2o`000:Sooooo000Nooooo`03o`000?oooooooooo02kooooo1?l0000Woooo
o`;o00002Oooool2o`000003ooooool0003o000000;o00002?ooool2o`0001kooooo0_l00008oooo
o`;o0000Z?ooool001kooooo00?o0000ooooooooool05_ooool2o`0001Kooooo1?l0000Uooooo`Co
00001_ooool2o`0000Cooooo0_l0000>ooooo`;o0000/?ooool2o`0001cooooo000Nooooo`03o`00
0?oooooooooo01Kooooo0_l0000:ooooo`;o00004_ooool2o`0001oooooo0_l00007ooooo`?o0000
1?ooool2o`0000kooooo0_l0002`ooooo`;o00007?ooool001kooooo00?o0000ooooooooool08_oo
ool2o`0001;ooooo0_l0000Uooooo`;o000000Coooooo`000?l0003o00003_ooool2o`00023ooooo
0_l0002booooo`007_ooool00ol0003oooooooooo`0gooooo`?o00008oooool3o`000003ooooool0
003o000000Sooooo0_l00004ooooo`;o00004Oooool2o`0000;ooooo0_l00009ooooo`;o0000HOoo
ool2o`0004oooooo000Dooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`0g
ooooo`?o00009?ooool2o`0000Sooooo0_l000000ooooooo0000o`00000Booooo`;o00000oooool2
o`0000;ooooo0_l00004ooooo`;o0000I_ooool2o`0004oooooo000Fooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0;_ooool2o`0000Wooooo0_l0000Gooooo`;o00005?ooool2o`00
01Gooooo0_l0000<ooooo`?o0000S_ooool2o`0002Oooooo000Fooooo`03o`000?oooooooooo00Go
oooo0ol0000^ooooo`;o00002Oooool2o`0001Oooooo0_l0000Xooooo`;o00003oooool2o`0001So
oooo0_l0001eooooo`;o00009oooool001Kooooo00?o0000ooooooooool0Q?ooool2o`0002Wooooo
0_l0002Nooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooo
oooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005?ooool00omEEEGo
IVIVo`00003ooooooe;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.34373 .9416 Mdot
.48099 .58549 Mdot
.36665 .83851 Mdot
.19818 .80734 Mdot
.24583 .78173 Mdot
.24764 .80329 Mdot
.18803 .60637 Mdot
.28395 .78601 Mdot
.21398 .74505 Mdot
.26102 .5837 Mdot
.29876 .70646 Mdot
.3628 .70269 Mdot
.32526 .84885 Mdot
.35652 .86428 Mdot
.27037 .82435 Mdot
.49881 .9807 Mdot
.51233 .96855 Mdot
.30284 .90496 Mdot
.3734 .9506 Mdot
.18873 .80373 Mdot
.40506 .11632 Mdot
.27504 .80984 Mdot
.35555 .83803 Mdot
.5088 .86058 Mdot
.19829 .72306 Mdot
.2846 .72233 Mdot
.24485 .73476 Mdot
.4455 .90128 Mdot
.30739 .69689 Mdot
.27982 .82615 Mdot
.3441 .92075 Mdot
.26679 .81795 Mdot
.24106 .72126 Mdot
.28223 .5943 Mdot
.15895 .02034 Mdot
.18211 .71045 Mdot
.33063 .85685 Mdot
.40147 .14448 Mdot
.43527 .70387 Mdot
.21359 .73014 Mdot
.35881 .9268 Mdot
.06252 .95202 Mdot
.07066 .74543 Mdot
.49065 .10149 Mdot
.44341 .55103 Mdot
.04893 .9233 Mdot
.95317 .43498 Mdot
.04935 .67844 Mdot
.2152 .68293 Mdot
.15157 .11327 Mdot
.36671 .60313 Mdot
.12973 .96304 Mdot
.26012 .72518 Mdot
.17218 .68134 Mdot
.26463 .74242 Mdot
.21078 .52362 Mdot
.69761 .02462 Mdot
.29649 .82697 Mdot
.24879 .73779 Mdot
.2796 .01725 Mdot
.23663 .82401 Mdot
.28542 .76308 Mdot
.25519 .52651 Mdot
.1922 .71839 Mdot
.21676 .84794 Mdot
.2498 .7925 Mdot
.1005 .9442 Mdot
.24651 .73376 Mdot
.26053 .82271 Mdot
.88028 .04181 Mdot
.16741 .54237 Mdot
.41311 .04004 Mdot
.08181 .56892 Mdot
.22536 .40116 Mdot
.29564 .7364 Mdot
.55662 .09723 Mdot
.26407 .82747 Mdot
.09187 .52121 Mdot
.25203 .76858 Mdot
.50304 .93074 Mdot
.02838 .68837 Mdot
.98991 .8613 Mdot
.4808 .11601 Mdot
.29119 .78398 Mdot
.21394 .84505 Mdot
.24261 .4946 Mdot
.24742 .73616 Mdot
.21653 .7446 Mdot
.26636 .82881 Mdot
.34009 .05279 Mdot
.14271 .75925 Mdot
.97381 .10569 Mdot
.16811 .13399 Mdot
.12984 .44337 Mdot
.3192 .00232 Mdot
.02453 .76205 Mdot
.21658 .47619 Mdot
.14572 .99315 Mdot
.16944 .7007 Mdot
.21298 .07405 Mdot
.27704 .79672 Mdot
.36836 .58928 Mdot
.32386 .94877 Mdot
.44999 .89432 Mdot
.43624 .57557 Mdot
.34238 .84155 Mdot
.48212 .02139 Mdot
.49021 .98055 Mdot
.10831 .9255 Mdot
.07971 .62167 Mdot
.35379 .85636 Mdot
.45826 .01719 Mdot
.46333 .59017 Mdot
.31037 .9076 Mdot
.46974 .1286 Mdot
.96248 .83582 Mdot
.46829 .56967 Mdot
.3476 .84692 Mdot
.47072 .55241 Mdot
.45461 .64423 Mdot
.24242 .7152 Mdot
.03307 .78875 Mdot
.28567 .78629 Mdot
.13694 .45585 Mdot
.15051 .2271 Mdot
.3052 .11738 Mdot
.22988 .62841 Mdot
.35263 .96112 Mdot
.31195 .63303 Mdot
.09004 .57733 Mdot
.30449 .14933 Mdot
.31827 .52721 Mdot
.65053 .9302 Mdot
.32779 .93498 Mdot
.32768 .95789 Mdot
.30331 .79799 Mdot
.31987 .82719 Mdot
.41927 .08021 Mdot
.34813 .89609 Mdot
.23787 .78154 Mdot
.33692 .96725 Mdot
.18663 .71231 Mdot
.26051 .78774 Mdot
.10692 .00032 Mdot
.19295 .50465 Mdot
.34297 .71525 Mdot
.27741 .97523 Mdot
.24886 .76354 Mdot
.67824 .04842 Mdot
.01741 .73757 Mdot
.23498 .79015 Mdot
.2539 .75379 Mdot
.40555 .67602 Mdot
.18909 .79411 Mdot
.26526 .80103 Mdot
.33614 .82255 Mdot
.45147 .06442 Mdot
.82242 .91742 Mdot
.21112 .73912 Mdot
.49721 .0218 Mdot
.43449 .06104 Mdot
.20795 .06575 Mdot
.48023 .51341 Mdot
.33833 .94224 Mdot
.17117 .70803 Mdot
.24929 .76213 Mdot
.24083 .77042 Mdot
.22343 .74444 Mdot
.08781 .61429 Mdot
.31185 .89433 Mdot
.28272 .80681 Mdot
.02384 .69607 Mdot
.20516 .05728 Mdot
.53049 .1723 Mdot
.3587 .95064 Mdot
.41388 .99946 Mdot
.44461 .54657 Mdot
.31632 .72769 Mdot
.17525 .5689 Mdot
.14362 .97671 Mdot
.09219 .73918 Mdot
.31179 .68497 Mdot
.49276 .78947 Mdot
.41466 .49033 Mdot
.36952 .94511 Mdot
.42676 .6021 Mdot
.49792 .02525 Mdot
.12058 .76132 Mdot
.4875 .81607 Mdot
.10549 .96204 Mdot
.35882 .95527 Mdot
.2925 .49354 Mdot
.34441 .95727 Mdot
.43038 .52858 Mdot
.46672 .6349 Mdot
.08366 .75842 Mdot
.17511 .04374 Mdot
.32112 .7625 Mdot
.21334 .74229 Mdot
.27688 .74365 Mdot
.36689 .43843 Mdot
.33232 .07587 Mdot
.33683 .94623 Mdot
.41562 .50424 Mdot
.19749 .72136 Mdot
.21286 .74813 Mdot
.985 .80797 Mdot
.23831 .74884 Mdot
.25459 .86337 Mdot
.45579 .88252 Mdot
.29836 .85241 Mdot
.32383 .96341 Mdot
.27839 .11008 Mdot
.14006 .69369 Mdot
.43192 .07079 Mdot
.12865 .4833 Mdot
.22012 .75807 Mdot
.29385 .78919 Mdot
.43108 .98938 Mdot
.09695 .98423 Mdot
.73947 .00111 Mdot
.36643 .99717 Mdot
.18251 .70405 Mdot
.22805 .75201 Mdot
.35411 .02968 Mdot
.44 .02685 Mdot
.05866 .67318 Mdot
.32437 .79262 Mdot
.29658 .9987 Mdot
.2577 .78902 Mdot
.32271 .78066 Mdot
.26746 .02256 Mdot
.26502 .78391 Mdot
.12808 .52454 Mdot
.12202 .47668 Mdot
.37153 .15982 Mdot
.22727 .50573 Mdot
.34743 .8873 Mdot
.39553 .15244 Mdot
.6181 .14317 Mdot
.31507 .74664 Mdot
.27099 .79812 Mdot
.05151 .7 Mdot
.27166 .78742 Mdot
.45078 .73572 Mdot
.21812 .88489 Mdot
.38335 .00411 Mdot
.28132 .8121 Mdot
.97548 .13205 Mdot
.367 .90905 Mdot
.13683 .96498 Mdot
.26211 .75285 Mdot
.79195 .36461 Mdot
.25461 .52335 Mdot
.14542 .24887 Mdot
.07427 .67269 Mdot
.24631 .72768 Mdot
.34041 .17599 Mdot
.05254 .84485 Mdot
.45024 .12918 Mdot
.32379 .9552 Mdot
.23687 .92574 Mdot
.1925 .3991 Mdot
.30774 .22144 Mdot
.26655 .78934 Mdot
.29132 .45281 Mdot
.43635 .58472 Mdot
.5402 .33511 Mdot
.35221 .87026 Mdot
.2274 .72835 Mdot
.17014 .70209 Mdot
.10135 .10456 Mdot
.26628 .83676 Mdot
.23774 .93619 Mdot
.02401 .68481 Mdot
.28491 .78485 Mdot
.41468 .02263 Mdot
.39875 .4412 Mdot
.1838 .68609 Mdot
.4049 .59371 Mdot
.71694 .07897 Mdot
.27528 .81215 Mdot
.34963 .91446 Mdot
.29861 .88689 Mdot
.244 .75068 Mdot
.18333 .7052 Mdot
.30904 .90853 Mdot
.28637 .13767 Mdot
.06582 .72678 Mdot
.32366 .58694 Mdot
.07174 .68964 Mdot
.02341 .11236 Mdot
.37211 .95062 Mdot
.44892 .57154 Mdot
.16608 .54149 Mdot
.26676 .11359 Mdot
.23944 .8557 Mdot
.49002 .03128 Mdot
.71308 .1297 Mdot
.04351 .85438 Mdot
.2927 .14784 Mdot
.18012 .67826 Mdot
.14551 .02101 Mdot
.38744 .00607 Mdot
.17336 .62482 Mdot
.1228 .91571 Mdot
.24323 .73912 Mdot
.25632 .77157 Mdot
.3241 .38629 Mdot
.327 .049 Mdot
.23987 .73036 Mdot
.70376 .15465 Mdot
.28733 .72834 Mdot
.44553 .95218 Mdot
.18322 .73576 Mdot
.13553 .69206 Mdot
.42649 .95914 Mdot
.52975 .12763 Mdot
.23183 .69173 Mdot
.39282 .98265 Mdot
.441 .69472 Mdot
.25534 .73553 Mdot
.38096 .60096 Mdot
.48223 .83169 Mdot
.32087 .92541 Mdot
.33004 .79078 Mdot
.18704 .68677 Mdot
.31226 .96125 Mdot
.35291 .68053 Mdot
.31081 .77134 Mdot
.15762 .78428 Mdot
.25497 .81122 Mdot
.33209 .5113 Mdot
.43632 .26389 Mdot
.18506 .04316 Mdot
.29334 .22841 Mdot
.18824 .77838 Mdot
.24217 .72144 Mdot
.59855 .03241 Mdot
.30355 .46207 Mdot
.17297 .70585 Mdot
.44791 .69725 Mdot
.31293 .96981 Mdot
.39699 .01564 Mdot
.6907 .89661 Mdot
.32087 .98207 Mdot
.08098 .63749 Mdot
.29597 .64748 Mdot
.32856 .21018 Mdot
.27767 .78498 Mdot
.35775 .85604 Mdot
.25188 .73743 Mdot
.16127 .94943 Mdot
.45696 .91225 Mdot
.11072 .64719 Mdot
.25541 .8321 Mdot
.06553 .96204 Mdot
.35088 .95978 Mdot
.30404 .85009 Mdot
.21339 .96384 Mdot
.27668 .81077 Mdot
.2487 .75063 Mdot
.35117 .92814 Mdot
.30247 .84676 Mdot
.18108 .6969 Mdot
.14681 .90115 Mdot
.19504 .60115 Mdot
.94319 .92718 Mdot
.55269 .12646 Mdot
.27502 .82937 Mdot
.42015 .07453 Mdot
.23829 .74463 Mdot
.37442 .86776 Mdot
.24138 .7813 Mdot
.01207 .68194 Mdot
.23199 .09251 Mdot
.42123 .54706 Mdot
.20926 .70281 Mdot
.40368 .0375 Mdot
.28621 .81544 Mdot
.25019 .77473 Mdot
.16575 .80454 Mdot
.49286 .01952 Mdot
.13506 .25951 Mdot
.45227 .91092 Mdot
.43536 .52918 Mdot
.19765 .61337 Mdot
.08376 .12561 Mdot
.24073 .72624 Mdot
.35972 .8648 Mdot
.33796 .96867 Mdot
.26754 .84908 Mdot
.28837 .80327 Mdot
.25337 .7951 Mdot
.2446 .78611 Mdot
.24791 .70715 Mdot
.54637 .03786 Mdot
.38119 .57974 Mdot
.25024 .73673 Mdot
.33359 .93417 Mdot
.06735 .74926 Mdot
.40189 .59538 Mdot
.83216 .95716 Mdot
.28896 .77017 Mdot
.23988 .93265 Mdot
.13473 .63673 Mdot
.29129 .58239 Mdot
.38082 .054 Mdot
.42308 .98346 Mdot
.33498 .93678 Mdot
.41148 .07789 Mdot
.20964 .73157 Mdot
.42932 .06685 Mdot
.10741 .68591 Mdot
.59787 .06336 Mdot
.31707 .92105 Mdot
.29868 .95372 Mdot
.43935 .03926 Mdot
.7697 .94656 Mdot
.2545 .76918 Mdot
.22085 .7382 Mdot
.91761 .20144 Mdot
.32664 .15487 Mdot
.28171 .87282 Mdot
.29931 .81376 Mdot
.47086 .45704 Mdot
.40424 .43901 Mdot
.22946 .7619 Mdot
.41738 .04083 Mdot
.25921 .87973 Mdot
.61532 .10273 Mdot
.97454 .4988 Mdot
.50763 .01458 Mdot
.15873 .80534 Mdot
.76206 .12924 Mdot
.26205 .01703 Mdot
.44261 .97404 Mdot
.09709 .64667 Mdot
.2276 .88413 Mdot
.4564 .57063 Mdot
.44657 .5941 Mdot
.48646 .04291 Mdot
.51367 .10101 Mdot
.25456 .83024 Mdot
.2722 .68643 Mdot
.2454 .79332 Mdot
.2564 .71767 Mdot
.27032 .83345 Mdot
.94985 .17574 Mdot
.4061 .89458 Mdot
.42014 .0371 Mdot
.09503 .91085 Mdot
.17557 .70815 Mdot
.24093 .76463 Mdot
.42434 .62884 Mdot
.24386 .73366 Mdot
.20337 .72744 Mdot
.17778 .6922 Mdot
.24313 .60812 Mdot
.44858 .08903 Mdot
.22033 .78218 Mdot
.22218 .75356 Mdot
.24412 .77833 Mdot
.34268 .77715 Mdot
.44714 .85028 Mdot
.15799 .00011 Mdot
.24882 .72415 Mdot
.36844 .08509 Mdot
.26837 .83441 Mdot
.12977 .77797 Mdot
.27779 .82776 Mdot
.25743 .73942 Mdot
.28616 .78093 Mdot
.28875 .78281 Mdot
.33543 .80605 Mdot
.26177 .80122 Mdot
.29736 .74896 Mdot
.30223 .80449 Mdot
.72595 .01219 Mdot
.19808 .66081 Mdot
.08355 .50322 Mdot
.48326 .58376 Mdot
.27061 .80327 Mdot
.32559 .97246 Mdot
.3433 .94959 Mdot
.16321 .44722 Mdot
.10685 .46249 Mdot
.96023 .23504 Mdot
.01374 .68442 Mdot
.44003 .89255 Mdot
.36885 .88278 Mdot
.21746 .73993 Mdot
.2866 .60146 Mdot
.23139 .61861 Mdot
.18871 .75181 Mdot
.31587 .77609 Mdot
.16363 .84228 Mdot
.26673 .70675 Mdot
.4649 .83775 Mdot
.47333 .904 Mdot
.20188 .83447 Mdot
.08356 .61516 Mdot
.02205 .69846 Mdot
.44716 .14027 Mdot
.30268 .90457 Mdot
.10083 .05199 Mdot
.26713 .7424 Mdot
.18893 .518 Mdot
.20565 .72649 Mdot
.2711 .81827 Mdot
.31284 .96446 Mdot
.10586 .51785 Mdot
.23507 .48375 Mdot
.52724 .00461 Mdot
.24116 .76274 Mdot
.12561 .51813 Mdot
.14011 .67997 Mdot
.0281 .74883 Mdot
.76915 .88955 Mdot
.32432 .94367 Mdot
.35426 .96748 Mdot
.34341 .79548 Mdot
.25032 .7708 Mdot
.28511 .76468 Mdot
.1676 .99161 Mdot
.86093 .68141 Mdot
.30198 .56335 Mdot
.54924 .93599 Mdot
.49694 .89131 Mdot
.23351 .60789 Mdot
.49276 .52489 Mdot
.21695 .45373 Mdot
.24261 .75801 Mdot
.40214 .65485 Mdot
.29783 .78959 Mdot
.27609 .78012 Mdot
.20903 .84287 Mdot
.21006 .70968 Mdot
.3896 .12926 Mdot
.23627 .41271 Mdot
.2389 .78347 Mdot
.61591 .03307 Mdot
.3361 .71101 Mdot
.26177 .79461 Mdot
.32538 .89739 Mdot
.22662 .50798 Mdot
.94132 .18447 Mdot
.45829 .87751 Mdot
.34176 .8984 Mdot
.32935 .79459 Mdot
.9905 .79927 Mdot
.33575 .45064 Mdot
.22825 .71731 Mdot
.37975 .53897 Mdot
.03959 .68291 Mdot
.86118 .03781 Mdot
.93829 .25277 Mdot
.24468 .7176 Mdot
.16175 .74128 Mdot
.33583 .12657 Mdot
.3276 .90743 Mdot
.24896 .67747 Mdot
.39461 .12219 Mdot
.31521 .00243 Mdot
.30843 .91025 Mdot
.20951 .67827 Mdot
.44424 .06321 Mdot
.17785 .70499 Mdot
.02984 .95207 Mdot
.26299 .82511 Mdot
.02618 .87234 Mdot
.44907 .8957 Mdot
.26073 .8061 Mdot
.2961 .96788 Mdot
.27437 .85121 Mdot
.23409 .75562 Mdot
.11233 .62837 Mdot
.30713 .68751 Mdot
.26749 .75389 Mdot
.17542 .87781 Mdot
.90538 .10621 Mdot
.95761 .07693 Mdot
.30856 .76542 Mdot
.33907 .96507 Mdot
.38006 .21054 Mdot
.1995 .73466 Mdot
.43667 .60701 Mdot
.03153 .69775 Mdot
.34658 .64653 Mdot
.27249 .99578 Mdot
.30327 .80962 Mdot
.28264 .75187 Mdot
.40165 .00992 Mdot
.27004 .72315 Mdot
.34802 .73382 Mdot
.29208 .73888 Mdot
.44216 .95618 Mdot
.32375 .79305 Mdot
.19494 .71781 Mdot
.36566 .97285 Mdot
.24248 .76017 Mdot
.22892 .74503 Mdot
.37057 .86587 Mdot
.14684 .9949 Mdot
.30911 .58065 Mdot
.34175 .94354 Mdot
.23444 .73751 Mdot
.28245 .8158 Mdot
.34188 .53746 Mdot
.33818 .95115 Mdot
.3356 .48339 Mdot
.17269 .53239 Mdot
.27207 .83582 Mdot
.28803 .63624 Mdot
.3671 .9396 Mdot
.44598 .02123 Mdot
.41752 .04643 Mdot
.16699 .50398 Mdot
.16975 .69102 Mdot
.01473 .02091 Mdot
.94745 .65096 Mdot
.06253 .9033 Mdot
.34666 .95517 Mdot
.3828 .65522 Mdot
.08451 .95324 Mdot
.4439 .58283 Mdot
.42597 .47924 Mdot
.27776 .51282 Mdot
.2849 .76819 Mdot
.03764 .71746 Mdot
.33402 .85286 Mdot
.22457 .74683 Mdot
.26933 .00238 Mdot
.49408 .94362 Mdot
.25885 .80731 Mdot
.09246 .62378 Mdot
.2917 .78733 Mdot
.19846 .00742 Mdot
.25502 .82591 Mdot
.27229 .83342 Mdot
.08766 .71116 Mdot
.25481 .81401 Mdot
.0673 .95829 Mdot
.0791 .65822 Mdot
.24907 .59903 Mdot
.35183 .97561 Mdot
.28164 .60444 Mdot
.71162 .98624 Mdot
.30393 .78535 Mdot
.32866 .52901 Mdot
.50257 .86738 Mdot
.28651 .69349 Mdot
.4688 .60044 Mdot
.22961 .75781 Mdot
.94721 .18411 Mdot
.21128 .72878 Mdot
.28462 .72964 Mdot
.73723 .18949 Mdot
.24048 .86539 Mdot
.24777 .7353 Mdot
.43391 .56034 Mdot
.34672 .84653 Mdot
.13145 .58013 Mdot
.23835 .70241 Mdot
.28999 .4696 Mdot
.25371 .66987 Mdot
.25629 .76994 Mdot
.1508 .61282 Mdot
.21106 .07039 Mdot
.34108 .67014 Mdot
.09938 .49029 Mdot
.08139 .58567 Mdot
.42302 .50438 Mdot
.28296 .80306 Mdot
.58572 .1671 Mdot
.28247 .74211 Mdot
.72773 .51406 Mdot
.27441 .86126 Mdot
.01287 .76457 Mdot
.24266 .85173 Mdot
.43997 .99458 Mdot
.10283 .99672 Mdot
.57624 .0611 Mdot
.35921 .95985 Mdot
.26229 .82349 Mdot
.25542 .0938 Mdot
.27008 .59414 Mdot
.06346 .65427 Mdot
.42597 .68859 Mdot
.30497 .8865 Mdot
.03788 .72366 Mdot
.44223 .53975 Mdot
.13668 .16806 Mdot
.9981 .82949 Mdot
.24894 .74629 Mdot
.3504 .86359 Mdot
.23974 .77076 Mdot
.21522 .481 Mdot
.13403 .21802 Mdot
.3996 .94661 Mdot
.22843 .92601 Mdot
.46918 .91765 Mdot
.34077 .82877 Mdot
.34716 .90333 Mdot
.13451 .49877 Mdot
.27586 .76771 Mdot
.1631 .8224 Mdot
.48624 .98543 Mdot
.43359 .43204 Mdot
.21729 .73554 Mdot
.26555 .14107 Mdot
.33751 .06518 Mdot
.36075 .62811 Mdot
.5658 .35299 Mdot
.30954 .78493 Mdot
.46314 .35182 Mdot
.27772 .81004 Mdot
.25363 .77988 Mdot
.90761 .91098 Mdot
.27926 .80577 Mdot
.3128 .96386 Mdot
.08672 .48844 Mdot
.35054 .96295 Mdot
.14911 .11185 Mdot
.44348 .07254 Mdot
.93734 .00339 Mdot
.44389 .14861 Mdot
.24358 .70712 Mdot
.08233 .63006 Mdot
.71269 .98528 Mdot
.29092 .79598 Mdot
.28754 .81013 Mdot
.35031 .82194 Mdot
.22335 .75915 Mdot
.90741 .88069 Mdot
.11326 .12501 Mdot
.97383 .16241 Mdot
.96266 .23086 Mdot
.33249 .61322 Mdot
.16811 .89963 Mdot
.2667 .81856 Mdot
.18629 .81837 Mdot
.37493 .95196 Mdot
.00361 .6426 Mdot
.11931 .52829 Mdot
.24869 .61684 Mdot
.28412 .81424 Mdot
.70644 .01595 Mdot
.24099 .67173 Mdot
.43479 .68054 Mdot
.04771 .72698 Mdot
.31482 .88638 Mdot
.43237 .5762 Mdot
.31622 .92708 Mdot
.35153 .96521 Mdot
.17012 .72145 Mdot
.29331 .88065 Mdot
.02783 .68382 Mdot
.29313 .74164 Mdot
.36256 .89329 Mdot
.93229 .94535 Mdot
.28062 .78105 Mdot
.28337 .94613 Mdot
.30065 .88984 Mdot
.28656 .58331 Mdot
.22929 .82617 Mdot
.16564 .03568 Mdot
.64384 .04658 Mdot
.32185 .75953 Mdot
.28075 .98948 Mdot
.18845 .71941 Mdot
.40149 .71238 Mdot
.3461 .86971 Mdot
.26209 .75306 Mdot
.99689 .7822 Mdot
.33557 .95873 Mdot
.18619 .67994 Mdot
.36672 .88205 Mdot
.41867 .62716 Mdot
.37375 .40059 Mdot
.19433 .80978 Mdot
.46319 .63936 Mdot
.65578 .16809 Mdot
.11325 .59137 Mdot
.21632 .80865 Mdot
.45674 .05835 Mdot
.45474 .91659 Mdot
.23547 .77841 Mdot
.21893 .74068 Mdot
.34297 .80701 Mdot
.98011 .00618 Mdot
.55597 .124 Mdot
.18807 .9346 Mdot
.29965 .7104 Mdot
.27295 .11308 Mdot
.28125 .73106 Mdot
.44197 .89512 Mdot
.03558 .07727 Mdot
.16902 .77549 Mdot
.3866 .01966 Mdot
.48885 .30624 Mdot
.28483 .81999 Mdot
.31201 .75842 Mdot
.48264 .59804 Mdot
.28553 .037 Mdot
.31726 .92498 Mdot
.30521 .57375 Mdot
.25484 .86816 Mdot
.2191 .07893 Mdot
.36233 .97756 Mdot
.24017 .10024 Mdot
.17257 .74841 Mdot
.34566 .79557 Mdot
.02829 .67125 Mdot
.11708 .77691 Mdot
.23682 .75081 Mdot
.12675 .44919 Mdot
.68575 .05245 Mdot
.26886 .81762 Mdot
.16574 .59602 Mdot
.29302 .78813 Mdot
.31412 .79923 Mdot
.19471 .66736 Mdot
.3328 .82281 Mdot
.25838 .75417 Mdot
.43039 .07615 Mdot
.25632 .72062 Mdot
.17024 .70002 Mdot
.00542 .7665 Mdot
.37742 .95515 Mdot
.47333 .56562 Mdot
.29317 .14461 Mdot
.28813 .86285 Mdot
.9558 .86623 Mdot
.0666 .9283 Mdot
.32419 .9159 Mdot
.08282 .57206 Mdot
.21526 .68403 Mdot
.19211 .69252 Mdot
.90197 .05578 Mdot
.16748 .59141 Mdot
.3204 .79914 Mdot
.24549 .73993 Mdot
.22462 .75874 Mdot
.69995 .05669 Mdot
.24214 .57919 Mdot
.30564 .10286 Mdot
.36608 .84628 Mdot
.28786 .73987 Mdot
.31677 .89069 Mdot
.36591 .18314 Mdot
.31003 .05443 Mdot
.36408 .93075 Mdot
.2733 .96452 Mdot
.24606 .71459 Mdot
.39762 .99234 Mdot
.28632 .78481 Mdot
.25671 .47327 Mdot
.20289 .6739 Mdot
.28015 .86572 Mdot
.309 .79115 Mdot
.21597 .81059 Mdot
.22179 .73721 Mdot
.11382 .66496 Mdot
.29325 .72556 Mdot
.30173 .7005 Mdot
.37371 .95205 Mdot
.42772 .02028 Mdot
.27891 .26888 Mdot
.31465 .81254 Mdot
.48164 .12381 Mdot
.25233 .72833 Mdot
.19145 .71655 Mdot
.18766 .74405 Mdot
.02357 .68355 Mdot
.2429 .75265 Mdot
.26674 .08586 Mdot
.42155 .15718 Mdot
.35271 .58939 Mdot
.33802 .9753 Mdot
.87546 .79543 Mdot
.25997 .83023 Mdot
.28211 .77832 Mdot
.32401 .73668 Mdot
.11015 .91646 Mdot
.34575 .94484 Mdot
.31989 .92672 Mdot
.65637 .08678 Mdot
.27419 .81026 Mdot
.0679 .68237 Mdot
.43897 .11709 Mdot
.39186 .45933 Mdot
.11486 .89393 Mdot
.27432 .80996 Mdot
.96247 .383 Mdot
.23436 .83124 Mdot
.99471 .90943 Mdot
.27168 .83756 Mdot
.34395 .80123 Mdot
.18203 .69067 Mdot
.33184 .97385 Mdot
.41285 .58156 Mdot
.93742 .15374 Mdot
.19472 .89435 Mdot
.08069 .69563 Mdot
.17176 .12139 Mdot
.12874 .58296 Mdot
.26032 .96145 Mdot
.36777 .94833 Mdot
.30267 .97378 Mdot
.3291 .58035 Mdot
.12991 .68227 Mdot
.34617 .90659 Mdot
.21485 .7196 Mdot
.3047 .73062 Mdot
.41284 .19927 Mdot
.24804 .75538 Mdot
.27777 .76733 Mdot
.03339 .72679 Mdot
.22498 .75788 Mdot
.35053 .16036 Mdot
.10044 .149 Mdot
.3164 .9518 Mdot
.30339 .78465 Mdot
.27028 .82637 Mdot
.33166 .17981 Mdot
.36141 .0114 Mdot
.4169 .62237 Mdot
.39909 .18146 Mdot
.24671 .86297 Mdot
.0975 .93395 Mdot
.31142 .8282 Mdot
.31057 .80733 Mdot
.26574 .78757 Mdot
.34128 .53961 Mdot
.34355 .9646 Mdot
.58908 .22856 Mdot
.2863 .8104 Mdot
.25596 .7662 Mdot
.36929 .48214 Mdot
.32009 .82317 Mdot
.36996 .91499 Mdot
.19748 .72467 Mdot
.21459 .50981 Mdot
.1448 .88584 Mdot
.24863 .80203 Mdot
.0874 .52587 Mdot
.10264 .97756 Mdot
.2339 .77659 Mdot
.09529 .68804 Mdot
.27191 .83836 Mdot
.72724 .191 Mdot
.07055 .94046 Mdot
.95481 .00953 Mdot
.17602 .88479 Mdot
.36718 .83381 Mdot
.2686 .8132 Mdot
.29919 .15817 Mdot
.27425 .48241 Mdot
.26669 .43563 Mdot
.27933 .81458 Mdot
.23567 .75541 Mdot
.26996 .82202 Mdot
.28802 .03715 Mdot
.32174 .78851 Mdot
.11885 .61747 Mdot
.40101 .0828 Mdot
.44725 .02672 Mdot
.04604 .93831 Mdot
.08288 .61815 Mdot
.21666 .57278 Mdot
.84825 .50819 Mdot
.49582 .9243 Mdot
.19361 .5475 Mdot
.05061 .34045 Mdot
.27232 .75361 Mdot
.49512 .02775 Mdot
.17676 .45292 Mdot
.24875 .74844 Mdot
.25769 .73461 Mdot
.26354 .80488 Mdot
.36003 .00046 Mdot
.18735 .20484 Mdot
.50363 .02144 Mdot
.28203 .81137 Mdot
.08821 .90704 Mdot
.43774 .62488 Mdot
.02015 .75489 Mdot
.10137 .95236 Mdot
.2544 .73558 Mdot
.44531 .10849 Mdot
.19055 .80285 Mdot
.40622 .65898 Mdot
.1227 .57607 Mdot
.18489 .68925 Mdot
.24281 .70436 Mdot
.2965 .82644 Mdot
.13741 .1167 Mdot
.48076 .03825 Mdot
.29404 .8025 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool01?l0003oooooo`000?l0000<ooooo`04o`000?oooooo0000
o`0000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`;o00002Oooool0
1?l0003oooooooooooooool4o`0000Sooooo00?o0000ooooooooool00_l00006ooooo`;o00001?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`09ooooo`;o00000_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`09ooooo`;o00000_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo000Nooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00cooooo0ol0000?ooooo`03o`000?oooooooooo00;ooooo0_l00009ooooo`04o`000?oooooo
ooooooooo`Co00002?ooool00ol0003oooooooooo`08ooooo`?o00000oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`09ooooo`;o00000_ooool00ol0003ooooooooo
o`07ooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003oooooooooo`0l
ooooo`;o0000??ooool2o`0000;ooooo0_l0000Wooooo`;o0000ROooool2o`0000Oooooo0_l0000:
ooooo`007_ooool00ol0003oooooooooo`1aooooo`;o00002oooool2o`0006Sooooo0_l00018oooo
o`;o00004oooool001kooooo00?o0000ooooooooool0LOooool2o`0000[ooooo0_l0000Rooooo`;o
0000?oooool2o`0000Cooooo0_l0001Mooooo`007_ooool00ol0003oooooooooo`1Aooooo`;o0000
1?ooool2o`00027ooooo0_l000000ooooooo0000o`00000Booooo`;o00002Oooool2o`0000?ooooo
0_l0000oooooo`;o0000Hoooool001kooooo00Co0000oooooooooooooooo0_l0000Xooooo`;o0000
0oooool2o`0001oooooo1?l00002ooooo`;o00008Oooool2o`0000Oooooo0_l00002ooooo`;o0000
1?ooool2o`0000;ooooo0_l00006ooooo`;o000000?oooooo`000?l000001?l0002Uooooo`007_oo
ool01?l0003oooooooooooooool2o`0002Sooooo0_l00003ooooo`;o00008Oooool2o`0002kooooo
0_l00002ooooo`;o00001?ooool2o`0000[ooooo0_l00003ooooo`Co0000?Oooool2o`0006Kooooo
000Nooooo`03o`000?oooooooooo08_ooooo1?l0000>ooooo`?o0000?oooool2o`0006Kooooo000N
ooooo`03o`000?oooooooooo06oooooo0_l0000Jooooo`Co00003?ooool4o`000:Sooooo000Noooo
o`03o`000?oooooooooo06oooooo0_l0000Zooooo`;o00008Oooool2o`0000Cooooo0_l00021oooo
o`007_ooool00ol0003oooooooooo`0booooo`;o00009Oooool3o`0002?ooooo0_l00003ooooo`;o
00004_ooool2o`0001Cooooo0_l0000>ooooo`;o00001?ooool2o`0004kooooo0_l0000aooooo`00
7_ooool00ol0003oooooooooo`0booooo`;o00009Oooool3o`0002?ooooo0_l000000ooooooo0000
o`000002o`0000Gooooo0_l0000;ooooo`;o00005?ooool2o`0006Cooooo0_l0000aooooo`007_oo
ool00ol0003oooooooooo`0eooooo`;o000000?oooooo`000?l00000B?ooool4o`0000Gooooo0_l0
000=ooooo`;o0000O_ooool2o`0002_ooooo000Nooooo`03o`000?oooooooooo03Gooooo0_l00000
0ooooooo0000o`00001:ooooo`;o00005?ooool2o`00037ooooo0_l0001;ooooo`;o0000:oooool0
01kooooo00?o0000ooooooooool0I_ooool2o`0001cooooo0_l00017ooooo`;o00002Oooool2o`00
06gooooo000Nooooo`;o00007_ooool2o`0004Oooooo0_l00002ooooo`;o0000K?ooool2o`000003
ooooool0003o000006[ooooo000Nooooo`03o`000?oooooooooo01gooooo0_l00012ooooo`;o0000
1oooool2o`0000cooooo0_l0001Qooooo`;o00000_ooool2o`00043ooooo0_l0000Tooooo`007_oo
ool00ol0003oooooooooo`0oooooo`;o00008?ooool2o`0001Gooooo0_l0000Fooooo`;o0000COoo
ool2o`00043ooooo0_l0000Tooooo`007_ooool00ol0003oooooooooo`0oooooo`;o0000B?ooool2
o`0000Gooooo0_l0000Uooooo`;o0000S_ooool001kooooo00?o0000ooooooooool0?oooool2o`00
02Wooooo0_l0000Mooooo`;o000000Coooooo`000?l0003ooooo0_l0000Vooooo`;o00001Oooool2
o`0008Oooooo000Nooooo`03o`000?oooooooooo03oooooo0_l0000Yooooo`;o00006oooool2o`00
00?ooooo0_l000000ooooooo0000o`00000]ooooo`;o0000Qoooool001kooooo00?o0000oooooooo
ool0@?ooool2o`0004Gooooo0ol0002mooooo`007_ooool00ol0003oooooooooo`10ooooo`?o0000
@Oooool2o`0000;ooooo0_l00002ooooo`;o0000^Oooool001kooooo00?o0000ooooooooool01ooo
ool2o`0003Sooooo0_l0000Uooooo`;o00006?ooool4o`0000;ooooo0_l00002ooooo`;o0000YOoo
ool2o`0001;ooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0000jooooo`;o00008oooool2
o`0001Sooooo1?l00002ooooo`;o0000Foooool2o`0004cooooo0_l0000Booooo`007_ooool00ol0
003oooooooooo`13ooooo`;o0000>Oooool2o`0000Cooooo0_l0001Oooooo`;o0000H?ooool001ko
oooo00?o0000ooooooooool0Doooool2o`0001oooooo0_l00008ooooo`;o0000DOooool2o`0007Co
oooo000Nooooo`03o`000?oooooooooo05?ooooo0_l0000Oooooo`;o00006?ooool2o`00047ooooo
0_l0001dooooo`007_ooool00ol0003oooooooooo`17ooooo`;o0000AOooool2o`000;Oooooo000N
ooooo`03o`000?oooooooooo04Oooooo0_l00006ooooo`;o0000m_ooool001kooooo00?o0000oooo
ooooool0Coooool2o`00063ooooo0_l0002Dooooo`007_ooool2o`0004_ooooo0_l0000Cooooo`;o
0000>_ooool2o`0000Kooooo0_l0000<ooooo`;o00004Oooool2o`00087ooooo000Nooooo`03o`00
0?oooooooooo01gooooo0_l0000[ooooo`;o00004oooool2o`0003[ooooo0_l00006ooooo`;o0000
7oooool2o`0007;ooooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o0000K_oo
ool2o`0009?ooooo0_l0000Dooooo`;o00003Oooool001kooooo00?o0000ooooooooool0;?ooool2
o`0002Sooooo0_l0000eooooo`;o0000Toooool2o`0002?ooooo000Nooooo`03o`000?oooooooooo
00?ooooo0_l0000Wooooo`?o00009?ooool5o`000>oooooo000Nooooo`03o`000?oooooooooo00?o
oooo0_l0000Tooooo`;o00000_ooool2o`0002Cooooo1?l00008ooooo`;o00007oooool2o`0000Wo
oooo0_l0000;ooooo`;o0000[Oooool001kooooo00?o0000ooooooooool0:Oooool2o`0000Wooooo
0_l0000Yooooo`;o00007oooool2o`0000Wooooo0_l0000;ooooo`;o0000[Oooool001kooooo00?o
0000ooooooooool0=?ooool2o`0004Kooooo0_l0000Jooooo`;o00005oooool2o`0009Cooooo000N
ooooo`03o`000?oooooooooo01Oooooo0_l00008ooooo`;o0000A_ooool2o`00017ooooo0_l0000J
ooooo`;o00005_ooool3o`0009Cooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l00008oooo
o`;o0000A_ooool2o`00013ooooo0_l0000Aooooo`;o00001Oooool2o`00017ooooo0_l00006oooo
o`;o0000<_ooool2o`0000kooooo0_l0001Aooooo`007_ooool00ol0003oooooooooo`1kooooo`;o
00004Oooool2o`0000Gooooo0_l0000Aooooo`;o0000>_ooool2o`0000kooooo0_l00013ooooo`;o
00003?ooool001kooooo00?o0000ooooooooool0<oooool2o`000?oooooo1Oooool2o`0000cooooo
000Nooooo`03o`000?oooooooooo03?ooooo0_l0000Tooooo`;o0000k?ooool001kooooo00?o0000
ooooooooool0D_ooool2o`0000Gooooo0_l0000booooo`;o0000^?ooool001kooooo00?o0000oooo
ooooool0D_ooool2o`0000Oooooo0_l0000Qooooo`;o00003Oooool2o`0003Kooooo0_l00020oooo
o`007_ooool00ol0003oooooooooo`0Mooooo`;o0000??ooool2o`00027ooooo0_l0000<ooooo`;o
0000=oooool2o`00083ooooo000Nooooo`;o00007_ooool2o`0003cooooo0_l00002ooooo`;o0000
:oooool2o`000;Wooooo000Nooooo`03o`000?oooooooooo05oooooo0_l00005ooooo`;o00005?oo
ool2o`0006?ooooo0_l0001:ooooo`;o00006?ooool001kooooo00?o0000ooooooooool0GOooool2
o`0000Oooooo0_l0000Dooooo`;o00001oooool2o`0005[ooooo0_l0001:ooooo`;o00006?ooool0
01kooooo00?o0000ooooooooool0GOooool2o`0000oooooo0_l00005ooooo`;o00003_ooool2o`00
0<3ooooo000Nooooo`03o`000?oooooooooo06kooooo0_l00005ooooo`;o0000`Oooool2o`0000go
oooo000Nooooo`03o`000?oooooooooo0;[ooooo0_l0001looooo`;o00003Oooool001kooooo00?o
0000ooooooooool0:?ooool2o`00093ooooo0_l0000Eooooo`;o0000M?ooool001kooooo00?o0000
ooooooooool0:?ooool2o`0007kooooo0_l0000Wooooo`;o0000M?ooool001kooooo00?o0000oooo
ooooool0Joooool2o`0003_ooooo0_l00027ooooo`;o00005?ooool001kooooo00?o0000oooooooo
ool0J?ooool2o`000003ooooool0003o00000<Cooooo0_l0000Dooooo`007_ooool00ol0003ooooo
ooooo`1Xooooo`;o00005?ooool2o`000<Oooooo000Nooooo`03o`000?oooooooooo07?ooooo0_l0
0009ooooo`;o0000[_ooool4o`0001Gooooo000Nooooo`03o`000?oooooooooo07?ooooo0_l0002i
ooooo`Co00005Oooool001kooooo00?o0000ooooooooool0j?ooool2o`0000;ooooo0_l0001Ioooo
o`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0
003oooooooooo`3Xooooo`;o00000_ooool2o`0005Wooooo0003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooo
oooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7o
k^k^00Oooooo0ol00022ooooo`;o0000`oooool000?ooooo00Go0000ooooooooooooooooo`00000=
ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0P_ooool2o`000:;ooooo0_l0000O
ooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool0
0ol0003oooooooooo`0iooooo`;o0000joooool2o`0001oooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Wooooo0_l0000/
ooooo`;o00003_ooool2o`000<kooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0Ioooool2o`0000kooooo0_l0
003>ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c006ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool09ooo
ool2o`000?oooooo7oooool001kooooo00?o0000ooooooooool09oooool2o`0003Oooooo0_l0003U
ooooo`007_ooool00ol0003oooooooooo`1Pooooo`;o0000iOooool001kooooo00?o0000oooooooo
ool0;Oooool2o`0002cooooo0_l0001Nooooo`;o0000R_ooool001kooooo00?o0000ooooooooool0
;Oooool2o`0002cooooo0_l0001Nooooo`;o0000N?ooool2o`00013ooooo000Nooooo`03o`000?oo
oooooooo0?oooooo=Oooool3o`00013ooooo000Nooooo`03o`000?oooooooooo0?oooooo=Oooool2
o`00017ooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo02_ooooo0_l0003ooooooa_ooooo000Nooooo`;o0000;?ooool2o`000?oooooo0Oooool2
o`0001Sooooo000Nooooo`03o`000?oooooooooo0?oooooo;_ooool2o`0001Sooooo000Nooooo`03
o`000?oooooooooo02Sooooo0_l0003ooooooakooooo000Nooooo`03o`000?oooooooooo02Sooooo
0_l0003ooooooakooooo000Nooooo`03o`000?oooooooooo08[ooooo0_l0002kooooo`007_ooool0
0ol0003oooooooooo`1Gooooo`;o0000<Oooool2o`000;_ooooo000Nooooo`03o`000?oooooooooo
05Oooooo0_l0003^ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`2Kooooo`;o0000Z_ooool001kooooo00?o0000ooooooooool0Vooo
ool2o`000:[ooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0[?ooool2o`0009Wooooo000Nooooo`03o`000?oooooooooo0:cooooo
0_l0002Iooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o0000ooooooljooooo`007_ooool0
0ol0003oooooooooo`0<ooooo`;o0000ooooooljooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`;o0000Toooool2o`000;?ooooo000Nooooo`03o`000?oooooooooo09;ooooo
0_l0000Pooooo`;o0000TOooool001kooooo00?o0000ooooooooool0]?ooool2o`00097ooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3mooooo`;o0000B?ooool001kooooo00?o0000ooooooooool0
oOooool2o`0004Sooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooolfooooo`;o0000
4?ooool001kooooo00?o0000ooooooooool0IOooool2o`000<kooooo0_l0000@ooooo`007_ooool0
0ol0003oooooooooo`1Uooooo`;o0000h?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8
ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol00006ooooo`?o0000>_ooool2o`0000Wooooo0_l0000^ooooo`;o0000d?ooool0
00?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o
0000ooooooooool0>_ooool2o`0000Wooooo0_l0000^ooooo`;o0000d?ooool000?ooooo00Go0000
ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0
oooooom8ooooo`000oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000
1oooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo04Wooooo0_l0003looooo`000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooo
ooooo`19ooooo`;o0000o?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`29ooooo`;o0000
_?ooool001kooooo00?o0000ooooooooool0ROooool2o`000:Oooooo0_l0000Cooooo`007_ooool0
0ol0003oooooooooo`1Cooooo`;o0000gOooool2o`0001?ooooo000Nooooo`03o`000?oooooooooo
05?ooooo0_l0000Nooooo`;o00002Oooool3o`000<Kooooo000Nooooo`03o`000?oooooooooo02Ko
oooo0_l0001;ooooo`;o00002Oooool3o`000<Kooooo000Nooooo`03o`000?oooooooooo02Kooooo
0_l00009ooooo`;o0000oooooolEooooo`007_ooool00ol0003oooooooooo`0Uooooo`;o00002_oo
ool2o`000?oooooo5Oooool001kooooo0_l0000Vooooo`;o00003_ooool2o`0002Cooooo0_l0000<
ooooo`;o0000g?ooool001kooooo00?o0000ooooooooool0:?ooool2o`0000_ooooo0_l0000;oooo
o`;o00005oooool2o`0000cooooo0_l0003Looooo`007_ooool00ol0003oooooooooo`0Xooooo`;o
00006?ooool2o`0003Oooooo0_l0000Hooooo`;o0000/?ooool001kooooo00?o0000ooooooooool0
7oooool2o`0003kooooo0_l0000Jooooo`;o00006?ooool2o`000;3ooooo000Nooooo`03o`000?oo
oooooooo01oooooo0_l0000nooooo`;o0000i_ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`1Jooooo`;o0000joooool001kooooo00?o0000oooooooo
ool0Coooool2o`0000Wooooo0_l0003[ooooo`007_ooool00ol0003oooooooooo`0Tooooo`;o0000
7?ooool2o`0000_ooooo0_l0003fooooo`007_ooool00ol0003oooooooooo`0Tooooo`;o00007?oo
ool2o`0004;ooooo0_l0002oooooo`007_ooool00ol0003oooooooooo`0Vooooo`;o00006_ooool2
o`0000Cooooo0_l0000;ooooo`;o00004_ooool2o`0000Wooooo0_l0000@ooooo`;o0000_oooool0
01kooooo00?o0000ooooooooool09_ooool2o`00023ooooo0_l0000;ooooo`;o00004_ooool2o`00
00Wooooo0_l0003Aooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o00000_ooool2o`0006Go
oooo0_l00032ooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o00000_ooool2o`0003gooooo
0_l0000Vooooo`;o0000`_ooool001kooooo00?o0000ooooooooool0Boooool2o`0000kooooo0_l0
003Zooooo`007_ooool00ol0003oooooooooo`0Xooooo`;o00008Oooool2o`000>cooooo0_l0000<
ooooo`007_ooool2o`0002Wooooo0_l0003ooooooa3ooooo0_l0000<ooooo`007_ooool00ol0003o
ooooooooo`0Gooooo`;o00006Oooool2o`0000Oooooo0_l00009ooooo`;o0000>oooool4o`000<3o
oooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0000Iooooo`;o00001oooool2o`0000Wooooo
0_l0000kooooo`Co0000ROooool2o`0003Gooooo000Nooooo`03o`000?oooooooooo04;ooooo0_l0
0002ooooo`;o00008?ooool2o`000:Kooooo0_l0000eooooo`007_ooool00ol0003oooooooooo`12
ooooo`;o00004_ooool2o`00013ooooo0_l0000^ooooo`;o0000C_ooool2o`0005gooooo000Noooo
o`03o`000?oooooooooo01kooooo0_l00005ooooo`;o00004_ooool2o`0001_ooooo0_l00010oooo
o`;o0000C_ooool2o`0005gooooo000Nooooo`03o`000?oooooooooo01[ooooo0_l00002ooooo`;o
00001Oooool2o`0001;ooooo0_l0003oooooo`gooooo000Nooooo`03o`000?oooooooooo01[ooooo
0_l0000Tooooo`;o00003Oooool2o`000?Kooooo000Nooooo`03o`000?oooooooooo01Sooooo0_l0
000<ooooo`;o00006?ooool2o`0000gooooo0_l0000Booooo`;o0000=oooool2o`000:Wooooo000N
ooooo`03o`000?oooooooooo01Sooooo0_l00009ooooo`;o000000?oooooo`000?l000009oooool2
o`0001;ooooo0_l00002ooooo`;o00007oooool3o`00017ooooo0_l0002Yooooo`007_ooool00ol0
003oooooooooo`0Sooooo`;o00003oooool2o`00037ooooo0_l0000Oooooo`?o0000_?ooool001ko
oooo00?o0000ooooooooool0=?ooool2o`000?oooooo4_ooool001kooooo00?o0000ooooooooool0
Joooool2o`0000[ooooo0_l0003>ooooo`007_ooool00ol0003oooooooooo`0booooo`;o0000=ooo
ool2o`0000[ooooo0_l0000Cooooo`;o0000^Oooool001kooooo00?o0000ooooooooool0<_ooool2
o`0005Sooooo0_l0002iooooo`007_ooool00ol0003oooooooooo`0kooooo`;o0000B?ooool2o`00
00Gooooo0_l0002iooooo`007_ooool2o`0003cooooo0_l00018ooooo`;o00001Oooool2o`000;Wo
oooo000Nooooo`03o`000?oooooooooo08cooooo0_l00007ooooo`;o0000/?ooool001kooooo00?o
0000ooooooooool0UOooool2o`000;3ooooo000Nooooo`03o`000?oooooooooo08Wooooo0_l0002l
ooooo`007_ooool00ol0003oooooooooo`1Nooooo`;o0000:Oooool2o`000;cooooo000Nooooo`03
o`000?oooooooooo05kooooo0_l0000fooooo`;o0000[oooool001kooooo00?o0000ooooooooool0
5_ooool2o`0001gooooo0_l0001Mooooo`Co0000[oooool001kooooo00?o0000ooooooooool05_oo
ool3o`0001cooooo0_l0000;ooooo`;o0000B_ooool4o`0000;ooooo0_l0002aooooo`007_ooool0
0ol0003oooooooooo`0Gooooo`;o00002oooool2o`0001cooooo0_l0000Kooooo`;o00009oooool4
o`0000;ooooo1?l0002eooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o00002Oooool2o`00
02Gooooo0_l0000Booooo`;o00009oooool4o`000;_ooooo000Nooooo`03o`000?oooooooooo01Wo
oooo0_l0000<ooooo`;o00008_ooool2o`0000kooooo0_l00003ooooo`;o00001Oooool2o`0000oo
oooo0_l00008ooooo`;o0000`oooool001kooooo00?o0000ooooooooool05_ooool2o`0000kooooo
0ol0000Xooooo`;o00001_ooool4o`0000?ooooo0_l00005ooooo`;o00003oooool2o`0000Sooooo
0_l00006ooooo`Co00002_ooool3o`000:cooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l0
000>ooooo`;o0000:Oooool2o`0000Kooooo0_l0000:ooooo`;o00008oooool4o`0000[ooooo0ol0
002/ooooo`007_ooool00ol0003oooooooooo`0Qooooo`;o00003oooool2o`00037ooooo0_l00008
ooooo`;o00000oooool2o`0001gooooo0_l0002booooo`000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003ooooooooo
o`0Qooooo`;o00003oooool2o`00023ooooo0_l00002ooooo`;o00005Oooool2o`0000?ooooo0_l0
000:ooooo`;o00002oooool2o`0000Cooooo0_l0002booooo`000oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`0booooo`;o00008?ooool2o`0000;ooooo0_l0000Uooooo`?o00002oooool2o`0000[ooooo
0_l0002/ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooooooo
ooooo`000006ooooo`?o0000<_ooool2o`0000Oooooo0_l0000@ooooo`;o0000:Oooool2o`0000Go
oooo0_l0000Cooooo`;o00000oooool2o`000:cooooo0003ooooo`05o`000?ooooooooooooooool0
00002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0>oooool2o`00
013ooooo0_l0000:ooooo`;o00006?ooool2o`0000?ooooo0_l0000=ooooo`;o00002oooool2o`00
0;7ooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413o
c<c<00Kooooo00?o0000ooooooooool0>Oooool2o`0001cooooo1?l0000Hooooo`;o00004_ooool2
o`000003ooooool0003o00000;_ooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool0
0omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo03Wooooo0_l0000=ooooo`;o000000?ooooo
o`000?l000002_ooool2o`00037ooooo0_l0002kooooo`000oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0]ooooo`;o00003Oooool2
o`0000[ooooo0_l000000ooooooo0000o`00000Kooooo`;o0000gOooool000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool05ooo
ool3o`0001?ooooo0_l0000=ooooo`;o0000:_ooool2o`000=gooooo000Nooooo`03o`000?oooooo
oooo01Oooooo0ol00009ooooo`;o00008_ooool2o`0000Cooooo0_l0003hooooo`007_ooool00ol0
003oooooooooo`0Fooooo`?o00002_ooool2o`0002;ooooo0_l00004ooooo`;o0000=?ooool2o`00
0<;ooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l00002ooooo`;o00006?ooool2o`0004go
oooo0_l00005ooooo`;o0000^oooool001kooooo00?o0000ooooooooool06_ooool2o`0000Cooooo
0_l0000Booooo`;o00004Oooool2o`0002Sooooo0_l0000Aooooo`Co00000_ooool2o`000;_ooooo
000Nooooo`03o`000?oooooooooo01Oooooo0_l00007ooooo`;o00009Oooool2o`0002Sooooo0_l0
000Aooooo`Co0000_oooool001kooooo00?o0000ooooooooool05oooool2o`0004Sooooo0_l0000a
ooooo`;o0000/Oooool001kooooo00?o0000ooooooooool05_ooool2o`00013ooooo0_l0000`oooo
o`;o00001Oooool2o`00037ooooo0_l0002aooooo`007_ooool00ol0003oooooooooo`0Fooooo`;o
00004?ooool2o`00033ooooo0_l0000fooooo`;o0000/oooool001kooooo0_l0002Aooooo`Co0000
/oooool001kooooo0_l0000Looooo`;o00000oooool2o`0004_ooooo0_l0000Qooooo`;o0000]Ooo
ool001kooooo00?o0000ooooooooool06oooool2o`0000?ooooo0_l0000jooooo`;o00003oooool2
o`000=Sooooo000Nooooo`;o0000GOooool2o`000=;ooooo0_l0000Eooooo`007_ooool00ol0003o
ooooooooo`0Aooooo`;o0000IOooool2o`0000Gooooo0_l0002_ooooo`;o00005Oooool001kooooo
00?o0000ooooooooool04Oooool2o`0000?ooooo0_l0001Pooooo`;o00001Oooool3o`000<Gooooo
000Nooooo`03o`000?oooooooooo01Kooooo0_l0000Tooooo`;o0000@_ooool2o`000<Gooooo000N
ooooo`03o`000?oooooooooo027ooooo0_l0000Iooooo`;o0000ooooool:ooooo`007_ooool00ol0
003oooooooooo`0Qooooo`;o00006?ooool2o`000?oooooo2oooool001kooooo00?o0000oooooooo
ool01Oooool2o`0003Cooooo0_l0000=ooooo`;o00000_ooool2o`0001_ooooo0_l0003Jooooo`00
7_ooool00ol0003oooooooooo`05ooooo`;o00002?ooool2o`0000?ooooo0_l0000Xooooo`;o0000
2_ooool2o`0000;ooooo0_l0000Kooooo`;o0000f_ooool001kooooo00?o0000ooooooooool03ooo
ool2o`0000?ooooo0_l0000Xooooo`;o00003Oooool2o`00037ooooo0_l00035ooooo`007_ooool0
0ol0003oooooooooo`0<ooooo`;o00006oooool2o`0000_ooooo1?l00006ooooo`;o00002oooool2
o`00023ooooo0_l0000?ooooo`;o00001oooool2o`000;cooooo000Nooooo`03o`000?oooooooooo
00;o00000_ooool3o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`;o00004_ooool2o`00
0003ooooool0003o000000Wooooo1_l00006ooooo`Co0000:oooool2o`0001Sooooo0_l00029oooo
o`;o0000<Oooool001kooooo00?o0000ooooooooool00_l00002ooooo`?o00000_ooool2o`0000Oo
oooo0_l0000;ooooo`;o00001Oooool2o`0000cooooo0_l00002ooooo`?o00001oooool2o`00013o
oooo0_l0000;ooooo`;o0000/Oooool2o`00037ooooo000Nooooo`03o`000?oooooooooo00;o0000
0_ooool3o`0000cooooo0_l00006ooooo`;o00000_ooool2o`0001Oooooo0ol0000Iooooo`;o0000
2_ooool3o`0002?ooooo0_l0002oooooo`007_ooool00ol0003oooooooooo`05ooooo`;o00003?oo
ool2o`0000Kooooo0_l0000;ooooo`;o00002Oooool2o`000003ooooool0003o000000Co00002ooo
ool2o`0001Oooooo0_l0000Tooooo`;o0000_oooool001kooooo00?o0000ooooooooool01?ooool2
o`00013ooooo0_l0000@ooooo`?o00002?ooool2o`000005ooooool0003o0000o`000?ooool00_l0
000;ooooo`;o00004?ooool2o`00033ooooo0_l0002jooooo`007_ooool00ol0003oooooooooo`03
ooooo`Go00003_ooool2o`00017ooooo0_l0000<ooooo`;o00008?ooool2o`0000Gooooo0_l0000Y
ooooo`;o000000?oooooo`000?l00000]oooool001kooooo0_l00004ooooo`;o000000?oooooo`00
0?l000001Oooool2o`0002Cooooo0_l00002ooooo`;o00004?ooool2o`0001?ooooo1?l0000@oooo
o`;o00006_ooool2o`000;Oooooo000Nooooo`03o`000?oooooooooo00gooooo0_l0000Tooooo`;o
000000Coooooo`000?l0003o00001oooool2o`0000Oooooo1?l0000Aooooo`;o00004_ooool2o`00
01Gooooo0_l0002looooo`007_ooool00ol0003oooooooooo`0dooooo`Go00001oooool2o`0000Wo
oooo0ol00005ooooo`;o00002?ooool2o`0002[ooooo0_l0002looooo`007_ooool00ol0003ooooo
ooooo`0Hooooo`;o00006_ooool5o`0000Oooooo0_l00009ooooo`?o00001Oooool2o`0000Sooooo
0_l0000:ooooo`;o0000g?ooool001kooooo00?o0000ooooooooool06?ooool2o`0001gooooo1?l0
0005ooooo`;o00002_ooool2o`0000oooooo0_l0000:ooooo`;o00004oooool2o`000<Oooooo000N
ooooo`03o`000?oooooooooo00Sooooo0_l0000_ooooo`Co00002Oooool2o`0000?ooooo0ol00000
0ooooooo0000o`00000Jooooo`;o00004Oooool2o`000<Oooooo000Nooooo`03o`000?oooooooooo
00Sooooo0_l0000_ooooo`Co00001Oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`00
01[ooooo0_l0003Jooooo`007_ooool00ol0003oooooooooo`08ooooo`;o0000:Oooool2o`0000Co
oooo1Ol00004ooooo`;o00001_ooool7o`0000?ooooo0_l00002ooooo`;o0000kOooool001kooooo
00?o0000ooooooooool01oooool3o`000003ooooool0003o000000Cooooo0_l0000Pooooo`;o0000
1oooool2o`000003ooooool0003o000000Wooooo1Ol000000ooooooo0000o`000002ooooo`;o0000
0_ooool2o`000003ooooool0003o00000>[ooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0
0002ooooo`;o00001?ooool2o`0002Wooooo1ol00003ooooo`;o00000_ooool8o`0000Kooooo1Ol0
0006ooooo`;o0000h_ooool001kooooo00?o0000ooooooooool0?_ooool5o`0000?ooooo0_l00002
ooooo`Ko00001oooool4o`0000Cooooo0_l00002ooooo`;o0000h_ooool001kooooo00?o0000oooo
ooooool0=oooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0000Kooooo0ol00000
1?oooooo0000o`000?l00005ooooo`;o00000oooool2o`000003ooooool0003o000000cooooo0_l0
000Oooooo`;o0000]oooool001kooooo00?o0000ooooooooool00_ooool2o`0001Kooooo0_l0000K
ooooo`;o00001?ooool2o`0000;ooooo1Ol00002ooooo`;o000000?oooooo`000?l000001Ol00009
ooooo`?o00001oooool2o`0000Kooooo0_l0000Oooooo`;o0000]oooool001kooooo00?o0000oooo
ooooool00_ooool2o`0001Kooooo0_l0000Dooooo`;o00003oooool5o`0000;ooooo0_l000000ooo
oooo0000o`000008o`0000?ooooo1Ol00008ooooo`;o0000h?ooool001kooooo00?o0000oooooooo
ool04oooool2o`0001_ooooo0_l00007ooooo`;o00001_ooool7o`000004ooooool0003o0000oooo
o`;o00001?ooool3o`000003ooooool0003o000000Go0000j_ooool001kooooo00?o0000oooooooo
ool01Oooool2o`0000cooooo0_l0000Oooooo`;o00000oooool2o`0000Kooooo0ol000001Ooooooo
0000o`000?l0003ooooo00;o00000_ooool2o`0000Oooooo0_l0000:ooooo`;o0000hoooool001ko
oooo0_l00006ooooo`;o00002oooool2o`00023ooooo0_l00003ooooo`;o00001_ooool2o`0000;o
oooo0_l00002ooooo`Ko00002Oooool2o`0000?ooooo0_l00003ooooo`;o0000hoooool001kooooo
00?o0000ooooooooool00_ooool2o`0000kooooo0_l0000Uooooo`;o00002Oooool4o`000003oooo
ool0003o000000_o00000_ooool2o`0000?ooooo0_l0003Xooooo`007_ooool00ol0003ooooooooo
o`02ooooo`;o0000?ooooolCo`000?7ooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0000A
ooooo`;o00005oooool<o`0001;ooooo0_l00002ooooo`;o0000h?ooool001kooooo00?o0000oooo
ooooool01?ooool2o`00017ooooo0_l0000:ooooo`;o00001Oooool2o`0001Sooooo1?l00002oooo
o`Go00002_ooool2o`0000Kooooo0_l000001?oooooo0000o`000?l0003Pooooo`007_ooool5o`00
00;ooooo0_l0000Mooooo`;o00008Oooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`00
00Sooooo0_l00005ooooo`;o00000_ooool2o`000>7ooooo000Nooooo`Go0000B?ooool2o`0000;o
oooo0ol00005ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`000>Gooooo000Nooooo`03
o`000?oooooooooo04[ooooo0_l000000ooooooo0000o`000002o`0000Gooooo0_l000001?oooooo
0000o`000?l00005ooooo`;o0000i?ooool001kooooo00?o0000ooooooooool0<oooool2o`0001Go
oooo0_l000000ooooooo0000o`000002o`00013ooooo1?l0003Rooooo`007_ooool00ol0003ooooo
ooooo`0Rooooo`;o00000_ooool2o`0000_ooooo0_l00004ooooo`;o00003Oooool2o`000003oooo
ool0003o000000;o00002Oooool2o`0000Wooooo0_l00006ooooo`;o0000f_ooool001kooooo00?o
0000ooooooooool08_ooool2o`0000;ooooo0_l0000Aooooo`;o00002Oooool2o`0000;ooooo2?l0
0006ooooo`Go00002_ooool2o`0000Cooooo0_l0003Cooooo`;o00001Oooool001kooooo00?o0000
ooooooooool0;oooool2o`0001?ooooo0_l00003ooooo`Oo00000_ooool2o`0000;ooooo1ol00002
ooooo`Co00000_ooool2o`000=Wooooo0_l00005ooooo`007_ooool00ol0003oooooooooo`07oooo
o`;o00009_ooool2o`0001Wooooo0ol00004ooooo`co00000_ooool4o`000003ooooool0003o0000
0>7ooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0000oooooo`;o000000?oooooo`000?l0
00000oooool6o`0000;ooooo1ol000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l0
0000<oooool2o`000:Wooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo03Wooooo0_l0000=oooo
o`;o00000_ooool3o`000003ooooool0003o000000?o00001_ooool4o`000003ooooool0003o0000
00?ooooo1?l0000cooooo`;o0000ZOooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0>Oooool2
o`00017ooooo1?l000000ooooooo0000o`000003ooooo`;o00000_ooool2o`0000;ooooo0_l00005
ooooo`Co00000oooool2o`000:_ooooo0_l0000/ooooo`000oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000C_ooool2o`0000;ooooo1_l0
0002ooooo`;o00000_ooool2o`0000;ooooo1?l00006ooooo`;o0000Zoooool2o`0002?ooooo0_l0
0007ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RH
oc8b<P06ooooo`03o`000?oooooooooo03Wooooo0ol0000@ooooo`?o00000_ooool5o`0000;ooooo
1Ol00005ooooo`Co00001_ooool2o`000=3ooooo0_l00007ooooo`000oooool01Ol0003ooooooooo
oooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo02oo
oooo0_l000000ooooooo0000o`000005ooooo`?o00004?ooool3o`0000;ooooo1Ol000000ooooooo
0000o`000004o`000003ooooool0003o000000Wooooo1Ol0003Iooooo`000oooool01Ol@413ooooo
oooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo
02oooooo0_l000000ooooooo0000o`000007ooooo`?o00001?ooool2o`0000cooooo1?l000000ooo
oooo0000o`000004o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`Co0000coooool2o`00
00Wooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o
000000Kooooo00?o0000ooooooooool0>oooool3o`0000Cooooo0_l0000;ooooo`?o000000?ooooo
o`000?l000001_l00003ooooo`;o000000Coooooo`000?l0003o0000f?ooool2o`0000Wooooo0003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo
00?o0000ooooooooool0@_ooool2o`0000_ooooo0_l00002ooooo`So00000_ooool2o`0000?ooooo
0_l0000fooooo`;o0000Zoooool001kooooo00?o0000ooooooooool0>?ooool2o`0001Gooooo0_l0
0002ooooo`?o000000?oooooo`000?l000000_l00002ooooo`;o0000>oooool2o`000:_ooooo000N
ooooo`03o`000?oooooooooo037ooooo0_l00005ooooo`;o00006Oooool3o`0000;ooooo0_l0000?
ooooo`;o00000oooool2o`000=Oooooo000Nooooo`03o`000?oooooooooo037ooooo0_l0000Foooo
o`;o00001_ooool2o`000003ooooool0003o000000;ooooo0_l0000:ooooo`;o00000_ooool3o`00
00?ooooo0_l0003Gooooo`007_ooool00ol0003oooooooooo`16ooooo`;o000000?oooooo`000?l0
00001?ooool:o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`000003
ooooool0003o00000=[ooooo000Nooooo`03o`000?oooooooooo04Kooooo1?l00005ooooo`[o0000
0oooool2o`0000?ooooo0_l000000ooooooo0000o`000005ooooo`;o0000;?ooool2o`000:Gooooo
0_l00005ooooo`007_ooool00ol0003oooooooooo`0nooooo`;o00002?ooool2o`0000Gooooo0ol0
00000ooooooo0000o`000002o`0001cooooo0_l0000Tooooo`;o0000YOooool2o`0000Gooooo000N
ooooo`03o`000?oooooooooo03kooooo0_l0000?ooooo`;o000000?oooooo`000?l000000_l0000I
ooooo`;o00000_ooool2o`0001kooooo0_l0002Pooooo`;o00004?ooool001kooooo00?o0000oooo
ooooool0D_ooool4o`0001Wooooo0_l00002ooooo`;o00007_ooool2o`000:3ooooo0_l0000@oooo
o`007_ooool00ol0003oooooooooo`0aooooo`;o00003Oooool2o`0001;ooooo0_l0000Eooooo`;o
00001_ooool2o`000=;ooooo000Nooooo`03o`000?oooooooooo00gooooo0_l0000Rooooo`;o0000
3Oooool3o`0001_ooooo0_l0000;ooooo`Co00001?ooool2o`000=;ooooo000Nooooo`03o`000?oo
oooooooo00gooooo0_l0000booooo`?o00003oooool2o`0000Wooooo0ol00005ooooo`;o00001Ooo
ool2o`0000Cooooo0_l0000Hooooo`;o0000^?ooool001kooooo0_l00013ooooo`;o00001oooool2
o`0000Kooooo1?l00006ooooo`Co00001Oooool4o`0002?ooooo0_l0002hooooo`007_ooool00ol0
003oooooooooo`0:ooooo`;o0000?_ooool3o`0000Sooooo0_l00006ooooo`;o00002Oooool2o`00
00Gooooo0ol0003Eooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o0000?_ooool2o`0001_o
oooo0_l00006ooooo`?o0000eOooool001kooooo00?o0000ooooooooool0EOooool2o`00013ooooo
0_l0000hooooo`;o0000Voooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo04[ooooo1?l0
00000ooooooo0000o`000004ooooo`Co000000?oooooo`000?l000004_ooool5o`0002kooooo0_l0
002Kooooo`;o00001oooool001kooooo00?o0000ooooooooool0B_ooool4o`000003ooooool0003o
000000Kooooo0_l000000ooooooo0000o`00000Booooo`Go000000?oooooo`000?l000000_l0000W
ooooo`;o0000T_ooool2o`0001;ooooo000Nooooo`03o`000?oooooooooo04oooooo0_l0000Koooo
o`Co00001?ooool4o`0002Oooooo0_l0002Booooo`;o00004_ooool001kooooo00?o0000oooooooo
ool01?ooool2o`00057ooooo0_l0000Cooooo`Co0000eoooool001kooooo00?o0000ooooooooool0
1?ooool2o`0002oooooo0_l0000Pooooo`;o0000>?ooool2o`000;Cooooo000Nooooo`03o`000?oo
oooooooo03Gooooo0_l0000Iooooo`;o00002Oooool2o`0003Cooooo0_l0002@ooooo`;o00008_oo
ool001kooooo00?o0000ooooooooool0A_ooool2o`0000Sooooo0_l00009ooooo`;o00005_ooool3
o`0001[ooooo0_l0002Aooooo`;o00008_ooool001kooooo00?o0000ooooooooool0:oooool2o`00
00Sooooo0_l0000<ooooo`;o000000?oooooo`000?l000005Oooool4o`000003ooooool0003o0000
00oooooo0ol0000Jooooo`;o0000]Oooool001kooooo00?o0000ooooooooool0:oooool2o`0000So
oooo0_l0000<ooooo`;o00006?ooool4o`000003ooooool0003o000000Wooooo0_l00027ooooo`;o
0000Coooool001kooooo00?o0000ooooooooool0G_ooool2o`0000?ooooo0_l00008ooooo`;o0000
0oooool2o`0001Oooooo0_l0000@ooooo`;o0000Eoooool2o`0004oooooo000Nooooo`03o`000?oo
oooooooo027ooooo0_l0000Hooooo`;o00009?ooool4o`0000Sooooo0_l00003ooooo`;o00003?oo
ool2o`0000Wooooo1Ol0000=ooooo`;o0000Z?ooool001kooooo00?o0000ooooooooool08Oooool2
o`0001Sooooo0_l0000Tooooo`;o00000oooool2o`0000?ooooo1?l0000Aooooo`;o00002_ooool4
o`0004cooooo0_l0001Yooooo`007_ooool2o`0002gooooo0_l00005ooooo`;o0000<Oooool2o`00
00?ooooo0_l0000Pooooo`;o0000COooool2o`0006Wooooo000Nooooo`03o`000?oooooooooo013o
oooo0_l0000Jooooo`;o00001Oooool2o`0002Wooooo0_l0000=ooooo`;o00007_ooool2o`0000Oo
oooo0_l0002_ooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o00001oooool2o`0004?ooooo
1Ol00003ooooo`;o00001?ooool3o`0002Oooooo0_l0002_ooooo`007_ooool00ol0003ooooooooo
o`0Iooooo`Co0000@oooool3o`0000?ooooo0_l00004ooooo`;o00001Oooool2o`0001[ooooo0_l0
002Booooo`;o00006_ooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo01_ooooo0_l00013
ooooo`;o00003?ooool2o`0000?ooooo0_l0000Jooooo`?o0000TOooool2o`0001[ooooo0_l00006
ooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o00000_ooool2o`0003oooooo0_l00007oooo
o`;o00001?ooool2o`0001[ooooo0_l00002ooooo`;o0000LOooool2o`0003kooooo000Nooooo`03
o`000?oooooooooo023ooooo0_l00002ooooo`;o0000?Oooool4o`0000Gooooo0_l00006ooooo`;o
00006_ooool2o`0000;ooooo0_l0001aooooo`;o0000?_ooool001kooooo00?o0000ooooooooool0
3?ooool2o`0005Gooooo0_l00007ooooo`;o0000fOooool001kooooo00?o0000ooooooooool03?oo
ool2o`00017ooooo0_l0000Uooooo`;o000000?oooooo`000?l000006?ooool3o`0000_ooooo0_l0
000Zooooo`;o0000T?ooool2o`0001Kooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0000;
ooooo`;o00009Oooool2o`000003ooooool0003o000001Sooooo0ol00008ooooo`;o000000?ooooo
o`000?l00000:_ooool2o`00033ooooo0_l0001Nooooo`;o00005_ooool001kooooo00?o0000oooo
ooooool04_ooool2o`0003Kooooo0_l0000Rooooo`;o00000_ooool2o`0002_ooooo0_l0000^oooo
o`;o0000M_ooool001kooooo00?o0000ooooooooool07?ooool2o`0001_ooooo0_l0000>ooooo`?o
00006_ooool4o`0000Sooooo0_l0000[ooooo`;o00003Oooool2o`0009Oooooo000Nooooo`03o`00
0?oooooooooo00_ooooo0_l0000?ooooo`;o00006oooool2o`0000kooooo0_l0000Kooooo`Go0000
@oooool2o`0009Oooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l00006ooooo`;o0000E?oo
ool5o`0000Gooooo0_l0003Booooo`007_ooool00ol0003oooooooooo`0Cooooo`;o00002?ooool2
o`0004Kooooo0_l00003ooooo`Co00001Oooool3o`0002Oooooo0_l0002<ooooo`;o00006_ooool0
01kooooo00?o0000ooooooooool07Oooool2o`0003Wooooo0_l0000;ooooo`;o00000_ooool5o`00
00Gooooo0ol00008ooooo`;o00007Oooool2o`0005Oooooo0_l0000cooooo`;o00006_ooool001ko
oooo0_l0000aooooo`;o00009_ooool2o`0000Wooooo1?l00002ooooo`Co00001?ooool6o`0000Oo
oooo0_l0001fooooo`;o0000Coooool001kooooo00?o0000ooooooooool01_ooool2o`0000Sooooo
0_l00005ooooo`;o00001?ooool2o`00017ooooo0_l0000[ooooo`;o00001?ooool2o`0000Gooooo
0ol00004ooooo`;o00000_ooool3o`0001Gooooo0_l0002hooooo`007_ooool00ol0003ooooooooo
o`06ooooo`;o00002?ooool2o`0000Gooooo0_l00004ooooo`;o0000?_ooool2o`0000Kooooo0ol0
0004ooooo`?o00000_ooool2o`0000;ooooo1?l0000Cooooo`?o0000Noooool2o`0003_ooooo000N
ooooo`03o`000?oooooooooo01;ooooo0_l0001Aooooo`?o000000Coooooo`000?l0003ooooo1?l0
00000ooooooo0000o`000004ooooo`;o00003_ooool2o`0000?ooooo0_l0001looooo`;o0000>ooo
ool001kooooo00?o0000ooooooooool04Oooool3o`0000[ooooo0_l00006ooooo`;o00006Oooool2
o`0000kooooo0_l0000>ooooo`?o000000?oooooo`000?l000000_ooool2o`0000?ooooo1Ol0000D
ooooo`;o0000__ooool001kooooo00?o0000ooooooooool04Oooool2o`0000_ooooo0_l00006oooo
o`Co00005oooool2o`0000kooooo0_l00002ooooo`;o00002_ooool3o`000003ooooool0003o0000
00?ooooo1ol0003Fooooo`007_ooool00ol0003oooooooooo`0Xooooo`;o0000:oooool2o`0000Go
oooo0_l00004ooooo`;o00001Oooool8o`00037ooooo0_l0002Sooooo`007_ooool00ol0003ooooo
ooooo`1Looooo`;o00001?ooool2o`0000;ooooo0_l000001?oooooo0000o`000?l00003ooooo`;o
00000_ooool2o`0002gooooo0_l0002Sooooo`007_ooool00ol0003oooooooooo`1Fooooo`;o0000
1_ooool2o`0000Kooooo1_l00002ooooo`;o00000oooool2o`0001Oooooo0_l0002iooooo`007_oo
ool00ol0003oooooooooo`0Mooooo`;o00003?ooool2o`0002Wooooo0_l00006ooooo`;o00002?oo
ool4o`0000;ooooo0_l00002ooooo`;o00006?ooool2o`000;Wooooo000Nooooo`03o`000?oooooo
oooo01gooooo0_l0000<ooooo`;o0000=oooool2o`0000cooooo0_l0000Wooooo`;o000000?ooooo
o`000?l00000Yoooool001kooooo00?o0000ooooooooool06oooool2o`0004Oooooo0_l0000Foooo
o`;o00001oooool2o`0001?ooooo0ol000000ooooooo0000o`000014ooooo`;o0000HOooool001ko
oooo00?o0000ooooooooool06oooool2o`0005oooooo0_l00007ooooo`;o00004oooool2o`0004Oo
oooo0ol0001Qooooo`007_ooool00ol0003oooooooooo`0booooo`;o00008oooool2o`0002oooooo
0_l0001Iooooo`;o0000H_ooool001Cooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oo
oooooooo02_ooooo0ol00004ooooo`;o00008oooool2o`0002Cooooo0_l00009ooooo`;o000000?o
ooooo`000?l00000^_ooool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0M
ooooo`;o00003?ooool3o`0002Kooooo0_l0000Mooooo`;o00002?ooool2o`0000cooooo0_l0002j
ooooo`005_ooool00ol0003oooooooooo`05ooooo`?o00007Oooool2o`0003Gooooo0_l00006oooo
o`;o00005Oooool2o`0000gooooo0_l00033ooooo`005_ooool00ol0003oooooooooo`1Tooooo`;o
00009?ooool2o`000<?ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o
0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Doooo
o`03oeEEEOmVIVKo00000?ooooooD_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.37809 .91167 Mdot
.50387 .67982 Mdot
.37515 .7995 Mdot
.27224 .82648 Mdot
.21941 .74974 Mdot
.24794 .84472 Mdot
.28577 .54994 Mdot
.27371 .75203 Mdot
.2138 .80595 Mdot
.17425 .70184 Mdot
.27999 .82051 Mdot
.30457 .77698 Mdot
.321 .80036 Mdot
.46009 .8778 Mdot
.29542 .84698 Mdot
.51815 .02907 Mdot
.496 .07838 Mdot
.29476 .84281 Mdot
.39351 .90745 Mdot
.25285 .85332 Mdot
.32551 .16756 Mdot
.24595 .87462 Mdot
.27808 .82026 Mdot
.4846 .77052 Mdot
.21752 .77508 Mdot
.26964 .71102 Mdot
.27511 .77173 Mdot
.48405 .95792 Mdot
.28472 .80904 Mdot
.27776 .89359 Mdot
.35441 .86519 Mdot
.28403 .84356 Mdot
.21147 .80265 Mdot
.16863 .615 Mdot
.10556 .99225 Mdot
.24516 .74755 Mdot
.44531 .867 Mdot
.33531 .22051 Mdot
.38331 .72116 Mdot
.24731 .75736 Mdot
.37033 .87582 Mdot
.06037 .9491 Mdot
.10878 .78074 Mdot
.438 .18586 Mdot
.50046 .56472 Mdot
.04617 .93011 Mdot
.9253 .47162 Mdot
.06618 .67829 Mdot
.26412 .72416 Mdot
.15948 .09147 Mdot
.32672 .64778 Mdot
.09867 .91534 Mdot
.24161 .69323 Mdot
.23049 .71657 Mdot
.23493 .70113 Mdot
.18295 .45174 Mdot
.66968 .98252 Mdot
.29292 .77802 Mdot
.28023 .77449 Mdot
.28871 .98952 Mdot
.29655 .84224 Mdot
.268 .743 Mdot
.33612 .49932 Mdot
.20381 .77794 Mdot
.24027 .8269 Mdot
.2273 .84994 Mdot
.11033 .88648 Mdot
.2774 .77105 Mdot
.2639 .86183 Mdot
.90903 .99285 Mdot
.11179 .48901 Mdot
.39246 .03999 Mdot
.06383 .6172 Mdot
.227 .3964 Mdot
.23748 .81752 Mdot
.55742 .03197 Mdot
.30917 .74005 Mdot
.11003 .44233 Mdot
.27673 .80315 Mdot
.50967 .89695 Mdot
.0181 .69177 Mdot
.99432 .75981 Mdot
.42284 .19496 Mdot
.27571 .75474 Mdot
.3404 .73292 Mdot
.15681 .45294 Mdot
.23775 .71123 Mdot
.27589 .77921 Mdot
.27883 .85726 Mdot
.33882 .03579 Mdot
.18858 .83067 Mdot
.0231 .05858 Mdot
.17617 .12069 Mdot
.09468 .41053 Mdot
.32373 .96195 Mdot
.01594 .74838 Mdot
.27969 .44596 Mdot
.10296 .95479 Mdot
.17696 .74467 Mdot
.14084 .07122 Mdot
.30331 .7881 Mdot
.3293 .62284 Mdot
.3738 .90416 Mdot
.5161 .92565 Mdot
.45769 .6763 Mdot
.26561 .82347 Mdot
.49401 .0722 Mdot
.51205 .03129 Mdot
.09517 .87268 Mdot
.1341 .52945 Mdot
.45683 .87365 Mdot
.39545 .11982 Mdot
.45497 .60271 Mdot
.31484 .84333 Mdot
.54105 .15541 Mdot
.99438 .75337 Mdot
.51552 .5806 Mdot
.33695 .80712 Mdot
.42405 .62749 Mdot
.48484 .64242 Mdot
.27963 .75848 Mdot
.05302 .77713 Mdot
.23609 .85939 Mdot
.10141 .42063 Mdot
.21843 .20191 Mdot
.22195 .14205 Mdot
.19612 .69488 Mdot
.37394 .92487 Mdot
.18693 .64972 Mdot
.05703 .63011 Mdot
.23368 .17515 Mdot
.33912 .44986 Mdot
.68944 .99233 Mdot
.28882 .90176 Mdot
.32022 .90941 Mdot
.27569 .72588 Mdot
.24289 .8067 Mdot
.41958 .10281 Mdot
.38543 .84402 Mdot
.22671 .83517 Mdot
.35817 .92549 Mdot
.19714 .77209 Mdot
.22304 .85404 Mdot
.05451 .99118 Mdot
.25195 .43233 Mdot
.28157 .79289 Mdot
.30468 .94993 Mdot
.28048 .77152 Mdot
.64475 .00602 Mdot
.05901 .63789 Mdot
.34649 .78057 Mdot
.21526 .82988 Mdot
.36149 .73798 Mdot
.25037 .85231 Mdot
.29725 .82616 Mdot
.31895 .78733 Mdot
.45102 .09765 Mdot
.84163 .86612 Mdot
.22373 .79501 Mdot
.50305 .07027 Mdot
.42253 .0745 Mdot
.14515 .05142 Mdot
.43567 .4609 Mdot
.2911 .91802 Mdot
.18128 .74473 Mdot
.21245 .73412 Mdot
.27481 .77274 Mdot
.24512 .78746 Mdot
.15202 .52851 Mdot
.25915 .86377 Mdot
.24403 .88009 Mdot
.9968 .69764 Mdot
.14553 .03717 Mdot
.51387 .12392 Mdot
.38747 .91921 Mdot
.39623 .0527 Mdot
.36211 .52992 Mdot
.31017 .70708 Mdot
.25996 .51256 Mdot
.1079 .93073 Mdot
.14466 .77025 Mdot
.2569 .76723 Mdot
.47489 .81543 Mdot
.4612 .5115 Mdot
.26068 .86142 Mdot
.40243 .60409 Mdot
.50172 .07223 Mdot
.16942 .82096 Mdot
.56969 .86912 Mdot
.05355 .97454 Mdot
.38339 .92275 Mdot
.21111 .44225 Mdot
.36972 .92371 Mdot
.45808 .56431 Mdot
.48209 .63054 Mdot
.12654 .79921 Mdot
.11368 .02766 Mdot
.26518 .84616 Mdot
.21178 .80494 Mdot
.22638 .82304 Mdot
.41812 .43711 Mdot
.43692 .12386 Mdot
.30493 .91043 Mdot
.46912 .524 Mdot
.21571 .77494 Mdot
.2746 .78243 Mdot
.01748 .71378 Mdot
.28803 .78232 Mdot
.36431 .74583 Mdot
.48045 .93777 Mdot
.23912 .82476 Mdot
.35178 .92707 Mdot
.35311 .032 Mdot
.066 .60932 Mdot
.42803 .09051 Mdot
.08119 .45209 Mdot
.25543 .76697 Mdot
.2098 .9144 Mdot
.42372 .05005 Mdot
.11057 .93828 Mdot
.72512 .95752 Mdot
.34867 .96888 Mdot
.19168 .76336 Mdot
.24475 .79825 Mdot
.34781 .00583 Mdot
.41419 .03973 Mdot
.01154 .71515 Mdot
.25433 .75727 Mdot
.22127 .8908 Mdot
.22381 .85373 Mdot
.30262 .75677 Mdot
.27575 .00235 Mdot
.22243 .8516 Mdot
.06208 .55787 Mdot
.07621 .44973 Mdot
.30192 .1016 Mdot
.14368 .58197 Mdot
.35101 .83539 Mdot
.32518 .21542 Mdot
.57482 .10244 Mdot
.33184 .69926 Mdot
.22966 .86472 Mdot
.07892 .72185 Mdot
.32838 .72947 Mdot
.40456 .75552 Mdot
.27403 .79455 Mdot
.35731 .98683 Mdot
.25024 .88646 Mdot
.93443 .08147 Mdot
.37521 .86208 Mdot
.10854 .91307 Mdot
.21549 .72404 Mdot
.79602 .37168 Mdot
.16474 .47947 Mdot
.21239 .23169 Mdot
.10841 .67758 Mdot
.22354 .70107 Mdot
.27972 .22595 Mdot
.02649 .84218 Mdot
.52583 .16346 Mdot
.35501 .9248 Mdot
.25502 .8988 Mdot
.17988 .34906 Mdot
.26858 .27965 Mdot
.22451 .85588 Mdot
.20869 .41613 Mdot
.41465 .59755 Mdot
.52948 .33824 Mdot
.34927 .82465 Mdot
.25747 .7633 Mdot
.17887 .74508 Mdot
.05796 .025 Mdot
.30643 .86666 Mdot
.23913 .91614 Mdot
.01009 .69283 Mdot
.22186 .75938 Mdot
.40588 .07661 Mdot
.44275 .41089 Mdot
.24123 .72427 Mdot
.37102 .62288 Mdot
.69528 .03577 Mdot
.24551 .87949 Mdot
.2879 .89986 Mdot
.42002 .88133 Mdot
.21524 .72385 Mdot
.19314 .76432 Mdot
.26852 .87093 Mdot
.22467 .14585 Mdot
.1065 .71578 Mdot
.31533 .66366 Mdot
.10932 .70863 Mdot
.08229 .06214 Mdot
.39023 .90718 Mdot
.46689 .61292 Mdot
.24021 .48377 Mdot
.20305 .11077 Mdot
.26797 .83152 Mdot
.48954 .07451 Mdot
.69217 .08914 Mdot
.04455 .74085 Mdot
.23179 .16134 Mdot
.17114 .74359 Mdot
.08959 .9996 Mdot
.3552 .99537 Mdot
.11286 .75882 Mdot
.12719 .85031 Mdot
.27223 .77534 Mdot
.29312 .80355 Mdot
.38591 .4275 Mdot
.43064 .10435 Mdot
.28363 .76962 Mdot
.68144 .1163 Mdot
.27121 .71703 Mdot
.43316 .90361 Mdot
.20229 .75694 Mdot
.19944 .69385 Mdot
.39306 .00627 Mdot
.50887 .06838 Mdot
.20393 .77372 Mdot
.3488 .09996 Mdot
.39467 .70957 Mdot
.21713 .81687 Mdot
.34347 .6424 Mdot
.47714 .86851 Mdot
.32764 .86475 Mdot
.3108 .76442 Mdot
.24409 .72566 Mdot
.34379 .92997 Mdot
.29527 .75086 Mdot
.28767 .75173 Mdot
.21428 .84235 Mdot
.24786 .85799 Mdot
.393 .46451 Mdot
.4854 .24729 Mdot
.12788 .11916 Mdot
.30835 .26458 Mdot
.07086 .83459 Mdot
.27251 .76078 Mdot
.53308 .02107 Mdot
.21763 .42623 Mdot
.18452 .74814 Mdot
.32288 .74882 Mdot
.33874 .93186 Mdot
.36652 .009 Mdot
.66017 .84948 Mdot
.44132 .96507 Mdot
.14815 .54989 Mdot
.3254 .54559 Mdot
.28775 .24686 Mdot
.27077 .74885 Mdot
.35099 .81647 Mdot
.21866 .70933 Mdot
.08564 .96302 Mdot
.50604 .95876 Mdot
.19659 .56834 Mdot
.30403 .85721 Mdot
.05691 .95725 Mdot
.30829 .93668 Mdot
.30334 .79545 Mdot
.16845 .05664 Mdot
.24422 .88042 Mdot
.13783 .77767 Mdot
.36416 .87451 Mdot
.23822 .82139 Mdot
.18191 .76125 Mdot
.0801 .90693 Mdot
.30399 .61052 Mdot
.89453 .98052 Mdot
.49475 .08072 Mdot
.26869 .88674 Mdot
.41529 .0888 Mdot
.26539 .77998 Mdot
.38021 .82879 Mdot
.21943 .84138 Mdot
.97731 .69728 Mdot
.15705 .09582 Mdot
.48596 .5561 Mdot
.26344 .74544 Mdot
.44764 .93634 Mdot
.27596 .89627 Mdot
.27043 .81001 Mdot
.23804 .83004 Mdot
.40628 .96128 Mdot
.20088 .24627 Mdot
.47486 .97489 Mdot
.47375 .55975 Mdot
.30494 .63465 Mdot
.14052 .20357 Mdot
.27075 .7643 Mdot
.4564 .877 Mdot
.35842 .92552 Mdot
.25642 .79814 Mdot
.32235 .78978 Mdot
.25026 .75194 Mdot
.22934 .75042 Mdot
.31957 .6064 Mdot
.53826 .12844 Mdot
.30164 .50885 Mdot
.2837 .77435 Mdot
.3441 .87817 Mdot
.09702 .79445 Mdot
.4814 .60618 Mdot
.8518 .90789 Mdot
.27099 .74772 Mdot
.35679 .91914 Mdot
.04769 .67574 Mdot
.28949 .66069 Mdot
.37276 .04419 Mdot
.38206 .98711 Mdot
.28644 .91225 Mdot
.40625 .08983 Mdot
.22965 .78332 Mdot
.4203 .07969 Mdot
.20653 .61087 Mdot
.54292 .0183 Mdot
.28607 .87912 Mdot
.35635 .90603 Mdot
.41742 .05342 Mdot
.76786 .90021 Mdot
.2824 .80278 Mdot
.24973 .77181 Mdot
.8893 .1664 Mdot
.25912 .09207 Mdot
.26194 .82127 Mdot
.29109 .76982 Mdot
.52975 .50972 Mdot
.44702 .44023 Mdot
.21456 .8255 Mdot
.39643 .04297 Mdot
.36564 .75835 Mdot
.56835 .05884 Mdot
.95215 .55755 Mdot
.56143 .98977 Mdot
.22704 .8391 Mdot
.75428 .09019 Mdot
.37889 .00948 Mdot
.44717 .03666 Mdot
.02997 .69422 Mdot
.2977 .82708 Mdot
.5121 .57853 Mdot
.43349 .59916 Mdot
.4293 .14281 Mdot
.46507 .18207 Mdot
.30472 .85106 Mdot
.25187 .83932 Mdot
.29918 .81575 Mdot
.21866 .80311 Mdot
.22939 .79984 Mdot
.99018 .14259 Mdot
.33987 .89233 Mdot
.32788 .07806 Mdot
.09449 .86101 Mdot
.1881 .75225 Mdot
.25965 .80386 Mdot
.40927 .6889 Mdot
.28452 .77222 Mdot
.2185 .7847 Mdot
.23743 .7296 Mdot
.13097 .63782 Mdot
.53152 .08066 Mdot
.29363 .76355 Mdot
.28039 .78716 Mdot
.25922 .81476 Mdot
.34305 .74446 Mdot
.42945 .74244 Mdot
.11276 .96059 Mdot
.21544 .80687 Mdot
.27692 .12157 Mdot
.30814 .85486 Mdot
.05778 .77444 Mdot
.26985 .88921 Mdot
.24732 .71653 Mdot
.27271 .75121 Mdot
.27438 .75314 Mdot
.36181 .76218 Mdot
.28052 .82914 Mdot
.30624 .69344 Mdot
.28851 .76672 Mdot
.70703 .96919 Mdot
.16731 .71593 Mdot
.09477 .43116 Mdot
.5035 .61019 Mdot
.23416 .86897 Mdot
.34488 .92718 Mdot
.37341 .91922 Mdot
.09116 .42799 Mdot
.05407 .44894 Mdot
.00173 .21483 Mdot
.98269 .69309 Mdot
.49177 .94095 Mdot
.37116 .84054 Mdot
.23921 .78528 Mdot
.3591 .52942 Mdot
.33934 .63724 Mdot
.23823 .83529 Mdot
.26538 .86364 Mdot
.23137 .78706 Mdot
.22384 .79512 Mdot
.41436 .74012 Mdot
.45096 .95147 Mdot
.2739 .75994 Mdot
.04172 .67237 Mdot
.99945 .69679 Mdot
.37679 .08495 Mdot
.27976 .85219 Mdot
.10865 .02314 Mdot
.25473 .72232 Mdot
.26119 .47125 Mdot
.22364 .78172 Mdot
.28935 .88981 Mdot
.32479 .91178 Mdot
.10531 .4264 Mdot
.2248 .41496 Mdot
.44555 .9523 Mdot
.222 .73252 Mdot
.06384 .55076 Mdot
.19864 .70671 Mdot
.01912 .73293 Mdot
.77032 .82684 Mdot
.33497 .88795 Mdot
.31815 .94202 Mdot
.3592 .75585 Mdot
.27252 .80619 Mdot
.23058 .84016 Mdot
.08753 .00049 Mdot
.84269 .66845 Mdot
.37114 .49707 Mdot
.57285 .02552 Mdot
.47814 .8754 Mdot
.12315 .63984 Mdot
.43141 .46432 Mdot
.26798 .39317 Mdot
.2155 .73011 Mdot
.34692 .6698 Mdot
.28022 .75979 Mdot
.30268 .77981 Mdot
.22008 .82792 Mdot
.19862 .78369 Mdot
.3349 .21436 Mdot
.28892 .38033 Mdot
.22747 .83669 Mdot
.56308 .9897 Mdot
.27425 .7893 Mdot
.28709 .82261 Mdot
.36457 .86504 Mdot
.30135 .47364 Mdot
.97961 .15326 Mdot
.42154 .85241 Mdot
.27797 .88052 Mdot
.30894 .76775 Mdot
.03039 .70707 Mdot
.39029 .4502 Mdot
.20607 .79526 Mdot
.28085 .52957 Mdot
.04873 .6937 Mdot
.82219 .98083 Mdot
.97531 .2364 Mdot
.27453 .75658 Mdot
.23283 .77314 Mdot
.43687 .15545 Mdot
.26985 .88421 Mdot
.21328 .75924 Mdot
.33689 .20648 Mdot
.21222 .02518 Mdot
.27295 .86904 Mdot
.25997 .71778 Mdot
.43657 .086 Mdot
.18733 .7574 Mdot
.01706 .84601 Mdot
.27332 .85563 Mdot
.0767 .97019 Mdot
.51069 .93233 Mdot
.27583 .8342 Mdot
.32798 .93767 Mdot
.26978 .79619 Mdot
.21226 .82505 Mdot
.04288 .68217 Mdot
.28697 .79851 Mdot
.21808 .72383 Mdot
.23446 .8026 Mdot
.85109 .05962 Mdot
.00545 .02691 Mdot
.34332 .71826 Mdot
.35813 .91817 Mdot
.34111 .27549 Mdot
.26464 .77011 Mdot
.41815 .60721 Mdot
.11443 .6325 Mdot
.43844 .6614 Mdot
.28858 .96507 Mdot
.29163 .76909 Mdot
.266 .6988 Mdot
.36673 .00755 Mdot
.2243 .8077 Mdot
.29424 .81911 Mdot
.27345 .72722 Mdot
.44095 .01991 Mdot
.30139 .76723 Mdot
.25739 .75564 Mdot
.3212 .95751 Mdot
.21286 .83146 Mdot
.25517 .78044 Mdot
.37019 .82704 Mdot
.10321 .95713 Mdot
.40887 .57552 Mdot
.29283 .9216 Mdot
.26686 .76095 Mdot
.25893 .88601 Mdot
.42097 .5294 Mdot
.36831 .92057 Mdot
.40319 .48196 Mdot
.2454 .47878 Mdot
.28062 .87981 Mdot
.34658 .54311 Mdot
.39797 .89422 Mdot
.45078 .07843 Mdot
.39892 .04898 Mdot
.09053 .47268 Mdot
.16993 .74322 Mdot
.98672 .93716 Mdot
.97364 .63774 Mdot
.14788 .98953 Mdot
.37289 .92304 Mdot
.29085 .57706 Mdot
.06487 .92235 Mdot
.427 .60613 Mdot
.34785 .43623 Mdot
.19128 .46457 Mdot
.23505 .72624 Mdot
.0353 .75826 Mdot
.37245 .80132 Mdot
.24189 .79474 Mdot
.28372 .97424 Mdot
.5601 .944 Mdot
.27222 .83594 Mdot
.06848 .52737 Mdot
.27717 .7561 Mdot
.23197 .94528 Mdot
.23711 .78356 Mdot
.29361 .85735 Mdot
.10966 .78123 Mdot
.26087 .84947 Mdot
.06504 .9462 Mdot
.07962 .72702 Mdot
.36019 .59076 Mdot
.33229 .94068 Mdot
.24219 .6639 Mdot
.68832 .94378 Mdot
.28219 .76114 Mdot
.40722 .5212 Mdot
.49415 .77455 Mdot
.23718 .78165 Mdot
.38927 .59522 Mdot
.24465 .80347 Mdot
.98675 .1527 Mdot
.24288 .76111 Mdot
.27464 .68927 Mdot
.72478 .15685 Mdot
.35465 .74968 Mdot
.28448 .77348 Mdot
.49774 .56709 Mdot
.27065 .87152 Mdot
.08488 .69829 Mdot
.27733 .7478 Mdot
.20864 .42746 Mdot
.13134 .69604 Mdot
.2884 .80266 Mdot
.24073 .5458 Mdot
.1362 .06984 Mdot
.21655 .6904 Mdot
.0727 .50222 Mdot
.05098 .69881 Mdot
.45351 .53472 Mdot
.27829 .89211 Mdot
.5373 .12817 Mdot
.26589 .72755 Mdot
.71446 .55806 Mdot
.26058 .80867 Mdot
.04332 .66054 Mdot
.35796 .73246 Mdot
.38938 .10493 Mdot
.05108 .99152 Mdot
.51594 .01401 Mdot
.37957 .92459 Mdot
.27266 .85389 Mdot
.1956 .07944 Mdot
.22923 .64447 Mdot
.12264 .56141 Mdot
.46838 .69603 Mdot
.30848 .82344 Mdot
.06023 .71007 Mdot
.49282 .56451 Mdot
.12604 .1875 Mdot
.04938 .92421 Mdot
.21464 .82334 Mdot
.27837 .88784 Mdot
.25521 .80991 Mdot
.27245 .41706 Mdot
.07926 .18688 Mdot
.43302 .83045 Mdot
.18274 .02476 Mdot
.51643 .96122 Mdot
.32463 .79272 Mdot
.38565 .85114 Mdot
.07286 .46944 Mdot
.22557 .84162 Mdot
.13395 .69182 Mdot
.47998 .88885 Mdot
.46491 .42554 Mdot
.20811 .80365 Mdot
.20329 .07254 Mdot
.33158 .07754 Mdot
.45061 .64298 Mdot
.51501 .35719 Mdot
.23745 .75646 Mdot
.52724 .36258 Mdot
.24399 .88053 Mdot
.2504 .74119 Mdot
.90653 .83707 Mdot
.2399 .87653 Mdot
.34323 .92997 Mdot
.04432 .50252 Mdot
.31407 .93589 Mdot
.23587 .18013 Mdot
.35874 .12308 Mdot
.98728 .94639 Mdot
.47806 .15033 Mdot
.27801 .75168 Mdot
.07799 .69521 Mdot
.68975 .94276 Mdot
.26417 .88814 Mdot
.26107 .89323 Mdot
.33586 .78915 Mdot
.22084 .81546 Mdot
.91294 .80818 Mdot
.18769 .16825 Mdot
.01971 .12589 Mdot
.00466 .20967 Mdot
.28909 .66827 Mdot
.28463 .79414 Mdot
.20894 .83302 Mdot
.25771 .8416 Mdot
.40118 .90957 Mdot
.06038 .57685 Mdot
.06032 .56418 Mdot
.21161 .68058 Mdot
.27872 .89671 Mdot
.68128 .97371 Mdot
.20811 .75154 Mdot
.36201 .59633 Mdot
.07042 .75992 Mdot
.3456 .85659 Mdot
.4406 .62385 Mdot
.36726 .88752 Mdot
.32403 .93297 Mdot
.16429 .75227 Mdot
.25163 .84288 Mdot
.02447 .69855 Mdot
.29734 .68959 Mdot
.36635 .84656 Mdot
.98801 .88624 Mdot
.27062 .74858 Mdot
.37568 .82083 Mdot
.33172 .8567 Mdot
.28687 .66707 Mdot
.29001 .85168 Mdot
.09513 .03079 Mdot
.60035 .00388 Mdot
.26485 .84222 Mdot
.37021 .87095 Mdot
.20756 .76347 Mdot
.45125 .73312 Mdot
.27431 .8537 Mdot
.21539 .72432 Mdot
.03191 .68457 Mdot
.35227 .90881 Mdot
.16006 .72987 Mdot
.36846 .83922 Mdot
.4014 .68974 Mdot
.38641 .38156 Mdot
.26798 .82957 Mdot
.46309 .63403 Mdot
.62256 .13056 Mdot
.04441 .64127 Mdot
.24748 .79267 Mdot
.45612 .09536 Mdot
.49842 .96814 Mdot
.22638 .83179 Mdot
.24008 .78654 Mdot
.32643 .77688 Mdot
.00318 .0353 Mdot
.49838 .0783 Mdot
.30861 .93081 Mdot
.28768 .69768 Mdot
.21575 .10529 Mdot
.26833 .69064 Mdot
.49711 .94041 Mdot
.07426 .11441 Mdot
.24247 .80178 Mdot
.36729 .00374 Mdot
.42788 .2986 Mdot
.26951 .89156 Mdot
.34291 .71262 Mdot
.48761 .60586 Mdot
.28223 .03394 Mdot
.29568 .87615 Mdot
.36842 .50227 Mdot
.21045 .99006 Mdot
.15201 .07132 Mdot
.33252 .95206 Mdot
.16859 .10146 Mdot
.24441 .77996 Mdot
.35757 .75717 Mdot
.10112 .67178 Mdot
.17523 .82015 Mdot
.26132 .7873 Mdot
.15128 .37499 Mdot
.65451 .00971 Mdot
.30354 .83864 Mdot
.25548 .53431 Mdot
.27795 .757 Mdot
.2938 .76943 Mdot
.17821 .73749 Mdot
.31702 .78615 Mdot
.25203 .72488 Mdot
.43199 .10288 Mdot
.23908 .69366 Mdot
.17665 .74675 Mdot
.04737 .67022 Mdot
.3249 .94663 Mdot
.51475 .57904 Mdot
.23739 .15303 Mdot
.28896 .80363 Mdot
.97057 .77827 Mdot
.07893 .92549 Mdot
.2713 .88986 Mdot
.0753 .48028 Mdot
.2643 .7257 Mdot
.18477 .76354 Mdot
.87094 .99599 Mdot
.27409 .58795 Mdot
.29815 .77105 Mdot
.2752 .77618 Mdot
.2176 .81745 Mdot
.67279 .01345 Mdot
.33556 .53941 Mdot
.2189 .12653 Mdot
.35937 .81051 Mdot
.27014 .72741 Mdot
.34822 .86001 Mdot
.31096 .24476 Mdot
.30791 .05031 Mdot
.37647 .88182 Mdot
.29911 .88177 Mdot
.2859 .74645 Mdot
.43743 .87888 Mdot
.27421 .75267 Mdot
.26367 .5525 Mdot
.16762 .72599 Mdot
.31019 .83925 Mdot
.28761 .76486 Mdot
.28375 .82933 Mdot
.2084 .80724 Mdot
.06833 .56973 Mdot
.2767 .71458 Mdot
.24436 .78761 Mdot
.3945 .90931 Mdot
.42512 .07691 Mdot
.34621 .25645 Mdot
.30048 .77444 Mdot
.53537 .12769 Mdot
.29418 .75165 Mdot
.20734 .77052 Mdot
.26331 .7423 Mdot
.01458 .69829 Mdot
.23391 .72246 Mdot
.35601 .98858 Mdot
.39652 .25157 Mdot
.44412 .59752 Mdot
.32774 .93332 Mdot
.87009 .80205 Mdot
.30108 .8764 Mdot
.27022 .74828 Mdot
.33328 .70025 Mdot
.1467 .88726 Mdot
.37828 .91462 Mdot
.3689 .88893 Mdot
.61871 .0437 Mdot
.2445 .87564 Mdot
.99659 .69878 Mdot
.36549 .05603 Mdot
.43924 .42758 Mdot
.14597 .83116 Mdot
.24217 .87726 Mdot
.91852 .41347 Mdot
.26512 .81158 Mdot
.07604 .84031 Mdot
.30257 .86269 Mdot
.42088 .7989 Mdot
.15749 .73726 Mdot
.32603 .92898 Mdot
.38164 .59992 Mdot
.9084 .10543 Mdot
.26404 .86149 Mdot
.16435 .60962 Mdot
.26086 .15071 Mdot
.05437 .62979 Mdot
.24847 .94932 Mdot
.38415 .90335 Mdot
.32765 .93641 Mdot
.28629 .61193 Mdot
.03774 .70243 Mdot
.29271 .78067 Mdot
.20268 .79229 Mdot
.22089 .77084 Mdot
.44419 .22482 Mdot
.13859 .78164 Mdot
.37471 .77228 Mdot
.0196 .70935 Mdot
.21558 .81908 Mdot
.28187 .10082 Mdot
.08149 .16763 Mdot
.32785 .86539 Mdot
.28157 .76073 Mdot
.28999 .85055 Mdot
.27244 .22633 Mdot
.27237 .92279 Mdot
.40014 .685 Mdot
.36093 .26261 Mdot
.35918 .74674 Mdot
.12947 .92318 Mdot
.236 .80689 Mdot
.2953 .77092 Mdot
.22374 .85437 Mdot
.26201 .47603 Mdot
.36583 .92497 Mdot
.54356 .1999 Mdot
.25694 .89049 Mdot
.28904 .79899 Mdot
.28046 .4611 Mdot
.30866 .78178 Mdot
.39479 .87015 Mdot
.21831 .77293 Mdot
.28892 .46995 Mdot
.19526 .81867 Mdot
.25575 .83801 Mdot
.06855 .55951 Mdot
.12196 .92994 Mdot
.22652 .82951 Mdot
.10952 .571 Mdot
.28883 .87275 Mdot
.7123 .15814 Mdot
.07566 .91987 Mdot
.92641 .07721 Mdot
.29102 .86882 Mdot
.3633 .79899 Mdot
.14485 .73201 Mdot
.24448 .17373 Mdot
.34515 .4673 Mdot
.33586 .49795 Mdot
.25299 .88221 Mdot
.25511 .797 Mdot
.30289 .84269 Mdot
.29264 .01521 Mdot
.2994 .76396 Mdot
.19978 .54176 Mdot
.39924 .11059 Mdot
.42326 .04251 Mdot
.13586 .86262 Mdot
.14434 .53057 Mdot
.18076 .49715 Mdot
.87162 .5542 Mdot
.48227 .82831 Mdot
.27481 .50046 Mdot
.00137 .36001 Mdot
.25954 .73198 Mdot
.49472 .07065 Mdot
.21798 .38203 Mdot
.27808 .78383 Mdot
.29664 .75637 Mdot
.26317 .75791 Mdot
.34595 .9697 Mdot
.17467 .26926 Mdot
.50791 .06761 Mdot
.28029 .89528 Mdot
.08969 .85994 Mdot
.42948 .67896 Mdot
.04896 .64836 Mdot
.0747 .9108 Mdot
.28451 .76156 Mdot
.37053 .16785 Mdot
.26508 .82302 Mdot
.37307 .72697 Mdot
.15719 .46713 Mdot
.17914 .75698 Mdot
.27787 .74885 Mdot
.32341 .8106 Mdot
.13661 .11138 Mdot
.47378 .07391 Mdot
.25188 .88313 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool02?ooool2o`0000?ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool2o`0000Ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`;o00002_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`;o00003oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;o
oooo000Nooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`0<ooooo`;o00001?ooool2o`0000Oooooo
0_l000000ooooooo0000ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`;o00003Oooool3o`0000oooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
0_ooool001kooooo00?o0000ooooooooool0KOooool2o`0000Cooooo0_l00002ooooo`;o00000ooo
ool2o`00053ooooo0_l000000ooooooo0000o`00001dooooo`007_ooool00ol0003oooooooooo`1c
ooooo`;o00000_ooool2o`0005Sooooo0_l00004ooooo`;o0000K_ooool001kooooo00?o0000oooo
ooooool0Foooool2o`0004Oooooo0_l0000aooooo`;o0000K_ooool001kooooo00?o0000oooooooo
ool0Foooool2o`0004Oooooo0_l00006ooooo`;o0000VOooool001kooooo00?o0000ooooooooool0
Roooool2o`0001cooooo0_l000000ooooooo0000o`00002Iooooo`007_ooool00ol0003ooooooooo
o`0?ooooo`;o00003_ooool2o`0001Kooooo0_l00008ooooo`;o0000B?ooool2o`0001cooooo0_l0
000;ooooo`;o0000Soooool001kooooo0ol0000?ooooo`;o00003_ooool4o`0001Cooooo0_l00008
ooooo`;o0000HOooool2o`00013ooooo0_l0002?ooooo`007_ooool3o`0001_ooooo0_l00004oooo
o`;o0000C?ooool2o`00037ooooo1?l0000;ooooo`;o0000U?ooool001kooooo00?o0000oooooooo
ool06oooool2o`0003_ooooo0_l0000Eooooo`;o0000<Oooool2o`0000gooooo0_l0002Dooooo`00
7_ooool2o`0002cooooo0_l0000[ooooo`;o00004?ooool2o`00027ooooo0_l0001?ooooo`;o0000
Ioooool001kooooo0_l0000/ooooo`;o0000?Oooool2o`0000oooooo0_l00006ooooo`;o00002?oo
ool2o`0004oooooo0_l0001Wooooo`007_ooool00ol0003oooooooooo`1eooooo`;o00001?ooool4
o`0000Cooooo1?l0000nooooo`;o0000P?ooool001kooooo00?o0000ooooooooool0MOooool2o`00
00Kooooo0_l00006ooooo`;o0000?_ooool2o`00083ooooo000Nooooo`03o`000?oooooooooo063o
oooo0_l0000Looooo`;o00001_ooool2o`000;oooooo000Nooooo`;o0000;?ooool2o`0003?ooooo
0_l0000Kooooo`?o00001?ooool4o`000;oooooo000Nooooo`03o`000?oooooooooo02_ooooo0_l0
0006ooooo`;o0000?_ooool2o`0000Sooooo0_l00005ooooo`;o0000`Oooool001kooooo00?o0000
ooooooooool00oooool2o`0002kooooo0_l0000nooooo`;o0000@?ooool2o`0005[ooooo0_l0000d
ooooo`007_ooool00ol0003oooooooooo`03ooooo`;o00004_ooool2o`0009cooooo0_l0001Joooo
o`;o0000=?ooool001kooooo00?o0000ooooooooool05oooool2o`000?oooooo;oooool001kooooo
00?o0000ooooooooool0XOooool2o`000:Cooooo000Nooooo`03o`000?oooooooooo02Sooooo1?l0
00000ooooooo0000o`00001^ooooo`Ko0000Y?ooool001kooooo00?o0000ooooooooool0:?ooool4
o`000003ooooool0003o000000oooooo0_l00015ooooo`;o00003oooool2o`0000?ooooo1_l0002V
ooooo`007_ooool00ol0003oooooooooo`0nooooo`;o00009_ooool4o`0001Kooooo0_l00003oooo
o`?o00003_ooool2o`0000?ooooo1_l00028ooooo`;o00007?ooool001kooooo00?o0000oooooooo
ool0>oooool2o`0002Wooooo1?l0000Fooooo`;o00000oooool3o`0000Kooooo0_l0000=ooooo`?o
00002Oooool2o`0007kooooo0_l0000Looooo`007_ooool00ol0003oooooooooo`0kooooo`;o0000
B?ooool2o`0000Oooooo0_l0000=ooooo`;o00002_ooool2o`00087ooooo0_l0000Iooooo`007_oo
ool00ol0003oooooooooo`1fooooo`;o00004_ooool2o`000:3ooooo0_l0000Iooooo`007_ooool0
0ol0003oooooooooo`1fooooo`;o00002?ooool2o`000003ooooool0003o000000;ooooo0_l00000
0ooooooo0000o`00001Aooooo`;o00004_ooool2o`0005Cooooo000Nooooo`03o`000?oooooooooo
033ooooo0_l0000Nooooo`;o0000;_ooool2o`000003ooooool0003o000000;ooooo0_l0001Doooo
o`;o00004_ooool2o`0005Cooooo000Nooooo`03o`000?oooooooooo02oooooo0ol0000Nooooo`;o
0000?_ooool2o`000;Gooooo000Nooooo`03o`000?oooooooooo02oooooo0_l0001Nooooo`?o0000
]Oooool001kooooo0_l0000dooooo`;o00008oooool2o`0000Cooooo0_l0000=ooooo`;o00005Ooo
ool2o`0000;ooooo0_l00005ooooo`;o00009_ooool2o`0008kooooo000Nooooo`03o`000?oooooo
oooo03?ooooo0_l0000=ooooo`;o00005?ooool2o`0000Cooooo0_l0000=ooooo`;o00002oooool2
o`0000Sooooo0_l00002ooooo`;o0000;Oooool2o`0006[ooooo0_l0000Rooooo`007_ooool00ol0
003oooooooooo`12ooooo`;o0000=_ooool2o`0000cooooo0_l0002Iooooo`;o00008_ooool001ko
oooo00?o0000ooooooooool0:?ooool2o`0001Cooooo0_l0000nooooo`;o0000aoooool001kooooo
00?o0000ooooooooool05?ooool2o`0001;ooooo0_l0000Dooooo`;o0000?_ooool2o`000<Oooooo
000Nooooo`03o`000?oooooooooo01Cooooo0_l00033ooooo`;o0000K?ooool001kooooo00?o0000
ooooooooool09Oooool2o`0000kooooo0_l00015ooooo`;o0000Foooool2o`0006cooooo000Noooo
o`03o`000?oooooooooo02Gooooo0_l0000>ooooo`;o00007oooool2o`0001Wooooo0_l00009oooo
o`;o00003?ooool2o`0001Oooooo0_l0002Rooooo`007_ooool00ol0003oooooooooo`02ooooo`;o
0000?oooool2o`00017ooooo0_l0000Iooooo`;o00005oooool2o`0001Oooooo0_l0002Rooooo`00
7_ooool00ol0003oooooooooo`02ooooo`;o0000?oooool2o`0006Gooooo0ol0000Iooooo`;o0000
Ooooool001kooooo00?o0000ooooooooool0Z_ooool3o`0001Wooooo0_l0001oooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0A?ooool2o`00047ooooo0_l0002eooooo`;o00001oooool001kooooo
00?o0000ooooooooool0A?ooool3o`00043ooooo0_l0002eooooo`;o00001oooool001kooooo00?o
0000ooooooooool0AOooool2o`000?oooooo0Oooool001kooooo0_l0001Booooo`;o0000A?ooool2
o`000:kooooo000Nooooo`03o`000?oooooooooo04Wooooo0_l00006ooooo`;o0000A?ooool2o`00
0:7ooooo0_l000000ooooooo0000o`000008ooooo`007_ooool00ol0003oooooooooo`19ooooo`;o
0000?oooool2o`00023ooooo0_l0000eooooo`;o00000oooool2o`00053ooooo0_l000000ooooooo
0000o`000008ooooo`007_ooool00ol0003oooooooooo`17ooooo`;o0000@Oooool2o`00023ooooo
0_l0000eooooo`;o00000oooool2o`0005gooooo000Nooooo`03o`000?oooooooooo04Oooooo0_l0
001Nooooo`;o0000W_ooool001kooooo00?o0000ooooooooool0Yoooool2o`0007Cooooo0_l0000X
ooooo`007_ooool00ol0003oooooooooo`0Fooooo`;o00008Oooool2o`0002_ooooo0_l0000<oooo
o`;o0000Yoooool2o`0002Sooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l0000Qooooo`;o
0000:oooool2o`0000cooooo0_l0003Aooooo`007_ooool00ol0003oooooooooo`18ooooo`;o0000
00?oooooo`000?l00000n_ooool001kooooo00?o0000ooooooooool0B?ooool2o`000003ooooool0
003o00000?[ooooo000Nooooo`03o`000?oooooooooo04Wooooo0_l00018ooooo`;o0000/_ooool0
01kooooo00?o0000ooooooooool0BOooool2o`0003oooooo0_l00007ooooo`;o0000/_ooool001ko
oooo00?o0000ooooooooool05_ooool2o`0000gooooo0_l0001Sooooo`;o0000^oooool001kooooo
00?o0000ooooooooool05_ooool2o`0000gooooo0_l0003oooooob7ooooo0003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo08Gooooo
0_l00030ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`25ooooo`;o0000`?ooool000?ooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0002]ooooo`;o
0000V?ooool000?ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Ko
oooo00?o0000ooooooooool0:_ooool2o`0001Oooooo0_l0001Xooooo`;o0000V?ooool000?ooooo
00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000oooooooo
ool0:_ooool2o`0001Oooooo0_l0000Tooooo`;o0000g?ooool000?ooooo00Go410@oooooooooooo
oooooa0@400?ooooo`03o`000?oooooooooo00Cooooo0_l0001Zooooo`;o0000g?ooool000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool2o`00
0?ooooooBOooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01Oooool2o`0006Sooooo0_l000000ooooooo0000o`00003Looooo`007Oooool2o`00
06Sooooo0_l000000ooooooo0000o`00003Looooo`007_ooool00ol0003oooooooooo`1Yooooo`;o
0000g?ooool001kooooo00?o0000ooooooooool0Eoooool2o`00013ooooo0_l0000Qooooo`;o0000
^Oooool001kooooo00?o0000ooooooooool0E?ooool2o`000003ooooool0003o000003?ooooo0_l0
002iooooo`007_ooool00ol0003oooooooooo`11ooooo`;o00004Oooool2o`000?7ooooo000Noooo
o`03o`000?oooooooooo047ooooo0_l0003oooooo`Gooooo000Nooooo`03o`000?oooooooooo0?oo
oooo>_ooool2o`0000cooooo000Nooooo`03o`000?oooooooooo0?oooooo>_ooool2o`0000cooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0?Oooool2
o`0001[ooooo0_l00006ooooo`;o0000=oooool2o`000:_ooooo000Nooooo`03o`000?oooooooooo
03gooooo0_l0000Jooooo`;o00001_ooool2o`0003Oooooo0_l0002[ooooo`007_ooool2o`0007ko
oooo0_l00038ooooo`007_ooool00ol0003oooooooooo`1/ooooo`;o00003oooool2o`000<Sooooo
000Nooooo`03o`000?oooooooooo06cooooo0_l0003Iooooo`007_ooool00ol0003oooooooooo`1a
ooooo`;o0000e?ooool001kooooo00?o0000ooooooooool0H?ooool2o`0000oooooo0_l0003Doooo
o`007_ooool00ol0003oooooooooo`1Pooooo`;o0000iOooool001kooooo00?o0000ooooooooool0
=Oooool2o`000?oooooo4Oooool001kooooo00?o0000ooooooooool0=Oooool2o`000?oooooo4Ooo
ool001kooooo00?o0000ooooooooool0Joooool2o`000=[ooooo000Nooooo`03o`000?oooooooooo
05?ooooo0_l0000Fooooo`;o0000f_ooool001kooooo00?o0000ooooooooool0Doooool2o`000?;o
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0Qoooool2o`000;kooooo000Nooooo`;o0000
R?ooool2o`000;kooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`2Xooooo`;o0000WOooool001kooooo00?o0000oooo
ooooool0Z?ooool2o`0009gooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`0003Oooooo0_l0003ooooooa3ooooo000N
ooooo`03o`000?oooooooooo03Kooooo0_l0003ooooooa3ooooo000Nooooo`03o`000?oooooooooo
0:?ooooo0_l0002Rooooo`007Oooool2o`000:Gooooo0_l0002Rooooo`007Oooool2o`000:Wooooo
0_l0002Nooooo`007_ooool00ol0003oooooooooo`2Wooooo`;o0000W_ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooo`;o0000A_ooool001ko
oooo00?o0000ooooooooool0;Oooool2o`000=3ooooo0_l00016ooooo`007_ooool00ol0003ooooo
ooooo`0]ooooo`;o0000oooooolIooooo`007_ooool00ol0003oooooooooo`13ooooo`;o00005Ooo
ool2o`0001kooooo0_l0003;ooooo`007_ooool00ol0003oooooooooo`13ooooo`;o00005Oooool2
o`0001kooooo0_l0003;ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0Doooool2o`000?;o
oooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`16ooooo`;o00002oooool2o`000?;ooooo0003ooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol00016ooooo`;o0000ooooool000?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000oooo
ooooool0oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEE
EOoooooo00001oooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo0?ooooooB?ooool0
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000
ooooooooool06oooool2o`0006oooooo0_l0002Iooooo`;o00007_ooool000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool06oooool2
o`0002?ooooo0_l00003ooooo`;o0000AOooool2o`0009Wooooo0_l0000Nooooo`007_ooool00ol0
003oooooooooo`10ooooo`;o00000oooool2o`0000gooooo0_l0003aooooo`007_ooool00ol0003o
ooooooooo`0Mooooo`;o0000=Oooool2o`000?7ooooo000Nooooo`03o`000?oooooooooo01gooooo
0_l0001dooooo`;o0000/_ooool001kooooo00?o0000ooooooooool06_ooool2o`0000;ooooo0_l0
000Pooooo`;o000000?oooooo`000?l00000=?ooool2o`00013ooooo0_l00006ooooo`;o0000/_oo
ool001kooooo00?o0000ooooooooool06_ooool3o`000003ooooool0003o0000023ooooo0_l00000
0ooooooo0000o`00000dooooo`;o00004?ooool2o`000;[ooooo000Nooooo`03o`000?oooooooooo
01_ooooo0_l0000aooooo`;o0000moooool001kooooo00?o0000ooooooooool0C_ooool2o`0001go
oooo0_l0000Eooooo`;o0000`Oooool001kooooo00?o0000ooooooooool0KOooool2o`0001Gooooo
0_l00007ooooo`;o0000^?ooool001kooooo00?o0000ooooooooool08?ooool2o`0001oooooo0_l0
001:ooooo`;o0000^?ooool001kooooo00?o0000ooooooooool08?ooool2o`0001oooooo0_l0000D
ooooo`;o0000k_ooool001kooooo00?o0000ooooooooool03Oooool2o`0000Kooooo0_l00010oooo
o`;o00004Oooool2o`0000oooooo0_l0003:ooooo`007_ooool2o`0000kooooo0_l00006ooooo`?o
00005oooool2o`0000Kooooo0_l0000aooooo`;o00003oooool2o`000<[ooooo000Nooooo`03o`00
0?oooooooooo01Kooooo0_l0000Gooooo`;o00001_ooool2o`000?oooooo3oooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`1Gooooo`;o0000<Oooool2
o`000;_ooooo000Nooooo`03o`000?oooooooooo03[ooooo0_l0000Kooooo`;o00008oooool2o`00
00[ooooo1?l0002kooooo`007_ooool00ol0003oooooooooo`0_ooooo`;o00002Oooool2o`00033o
oooo0_l0000>ooooo`;o00002_ooool2o`000;gooooo000Nooooo`03o`000?oooooooooo01Cooooo
0_l0000Iooooo`;o00008?ooool2o`0000Oooooo0_l0000@ooooo`;o0000^oooool2o`0001cooooo
000Nooooo`03o`000?oooooooooo01Cooooo0_l00003ooooo`;o0000=_ooool2o`0000Oooooo0_l0
0002ooooo`;o0000bOooool2o`0001cooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l0000f
ooooo`;o00002oooool2o`000>Oooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0000Koooo
o`;o00006Oooool2o`0000?ooooo0_l0003dooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o
00006oooool2o`0001Oooooo1?l0000aooooo`;o0000a_ooool001kooooo00?o0000ooooooooool0
B_ooool2o`0003?ooooo0_l00036ooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o0000oooo
oolVooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o0000oooooolVooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo03Oooooo0_l0000`ooooo`;o
00002_ooool2o`000=3ooooo000Nooooo`;o00002oooool2o`0000Sooooo0_l0000Qooooo`;o0000
7?ooool2o`0001;ooooo0_l00009ooooo`?o0000d?ooool001kooooo00?o0000ooooooooool02_oo
ool2o`0000Sooooo0_l0000oooooo`;o00007Oooool2o`000=7ooooo000Nooooo`03o`000?oooooo
oooo05kooooo0_l0003Wooooo`007_ooool00ol0003oooooooooo`1Nooooo`;o0000<_ooool2o`00
01Cooooo0_l0002Mooooo`007_ooool00ol0003oooooooooo`1@ooooo`;o0000@?ooool2o`0001Co
oooo0_l0002Mooooo`007_ooool00ol0003oooooooooo`1@ooooo`;o0000mOooool001kooooo00?o
0000ooooooooool0P?ooool2o`000<Gooooo000Nooooo`03o`000?oooooooooo083ooooo0_l0000B
ooooo`;o0000/Oooool001kooooo00?o0000ooooooooool04_ooool2o`00083ooooo0_l0002aoooo
o`007_ooool00ol0003oooooooooo`0Booooo`;o00004oooool2o`0000Cooooo0_l0000Xooooo`;o
00006?ooool3o`00017ooooo0_l00030ooooo`007_ooool00ol0003oooooooooo`0Wooooo`;o0000
0_ooool4o`0002Sooooo0_l0000Hooooo`?o00004Oooool2o`000<3ooooo000Nooooo`03o`000?oo
oooooooo02_ooooo0_l0000Rooooo`;o0000?_ooool2o`000;Kooooo000Nooooo`03o`000?oooooo
oooo04oooooo0_l0000Hooooo`;o00009?ooool2o`000;Kooooo000Nooooo`03o`000?oooooooooo
03gooooo0_l0000Zooooo`;o0000g?ooool001kooooo00?o0000ooooooooool0?Oooool2o`0000_o
oooo0_l0000Jooooo`;o00001Oooool2o`000=Sooooo000Nooooo`03o`000?oooooooooo04[ooooo
0_l0000Jooooo`;o00001Oooool2o`000=Sooooo000Nooooo`;o00004_ooool2o`0001Wooooo0_l0
000[ooooo`;o0000k?ooool001kooooo00?o0000ooooooooool04Oooool2o`0001Wooooo0_l0000T
ooooo`;o00001Oooool2o`000;cooooo0_l0000^ooooo`007_ooool00ol0003oooooooooo`0@oooo
o`;o0000@?ooool2o`0004Kooooo0_l00018ooooo`;o0000<Oooool2o`0001Sooooo0_l0000Doooo
o`007_ooool00ol0003oooooooooo`0@ooooo`Co0000P_ooool2o`0000;ooooo0_l00018ooooo`;o
0000Boooool2o`0001Cooooo000Nooooo`03o`000?oooooooooo00oooooo0_l000000ooooooo0000
o`00000@ooooo`;o0000L?ooool2o`000:oooooo000Nooooo`03o`000?oooooooooo00oooooo0_l0
000Cooooo`;o0000Joooool2o`0000Wooooo1Ol0002Vooooo`007_ooool00ol0003oooooooooo`0B
ooooo`;o0000:?ooool2o`0005?ooooo0_l00009ooooo`Go0000Y_ooool001kooooo00?o0000oooo
ooooool04_ooool2o`0000_ooooo0_l0000Kooooo`;o0000ooooool:ooooo`007_ooool00ol0003o
ooooooooo`0Oooooo`;o0000H?ooool2o`000<Cooooo000Nooooo`03o`000?oooooooooo013ooooo
0_l00018ooooo`;o00009Oooool2o`0001oooooo0ol0002Rooooo`007_ooool00ol0003ooooooooo
o`0@ooooo`;o00006Oooool2o`0002gooooo0_l00016ooooo`?o0000X_ooool001kooooo00?o0000
ooooooooool0:oooool2o`0007Kooooo0_l0002Rooooo`007_ooool00ol0003oooooooooo`1Eoooo
o`;o0000l?ooool001kooooo00?o0000ooooooooool0EOooool2o`0001[ooooo0_l0003Dooooo`00
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@
4?o<c<`01_ooool00ol0003oooooooooo`1aooooo`;o0000e?ooool000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000
ooooooooool0L_ooool2o`0000Kooooo0_l00007ooooo`;o00001oooool2o`000;Wooooo0003oooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
001booooo`;o00001?ooool4o`0000Oooooo0_l00004ooooo`;o000000?oooooo`000?l00000^Ooo
ool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40
1_ooool00ol0003oooooooooo`1hooooo`;o00001Oooool2o`0000Sooooo0_l00005ooooo`;o0000
]Oooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`01_ooool00ol0003oooooooooo`1Tooooo`;o00006Oooool2o`0000?ooooo0_l000000ooooooo
0000o`000007ooooo`;o00001_ooool4o`000:_ooooo0003ooooo`05oa0@4?ooooooooooooooool@
41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo017ooooo0_l0000Nooooo`;o
0000<Oooool2o`0001kooooo0_l000000ooooooo0000o`00000?ooooo`Co00001?ooool2o`000:Go
oooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03
o`000?oooooooooo017ooooo0_l0000Nooooo`;o00003?ooool2o`0001Sooooo0_l00004ooooo`;o
0000<oooool2o`0000[ooooo0_l0002Uooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`0cooooo`;o00002_ooool2o`00
01Sooooo0_l00004ooooo`;o0000<oooool2o`000;7ooooo000Nooooo`03o`000?oooooooooo017o
oooo0_l0000Pooooo`;o0000oooooolCooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o0000
ooooooleooooo`007_ooool00ol0003oooooooooo`1Wooooo`;o00003?ooool2o`0001Cooooo0_l0
002jooooo`007_ooool00ol0003oooooooooo`1Wooooo`;o00003?ooool2o`0000oooooo0_l00003
ooooo`;o0000^_ooool001kooooo00?o0000ooooooooool03_ooool2o`0007Kooooo0_l0000Aoooo
o`;o0000[?ooool001kooooo00?o0000ooooooooool03_ooool2o`00017ooooo0_l0000looooo`;o
0000<Oooool2o`0000Gooooo0_l0002/ooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o0000
4?ooool2o`0000?ooooo0_l0000gooooo`;o00002Oooool2o`0002Kooooo0_l0002Tooooo`;o0000
3Oooool001kooooo00?o0000ooooooooool03oooool2o`0001?ooooo1?l00012ooooo`;o0000c?oo
ool2o`0000gooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0000Hooooo`;o0000A_ooool2
o`00023ooooo0_l0000:ooooo`;o0000Zoooool001kooooo00?o0000ooooooooool02_ooool2o`00
03[ooooo0_l0000Tooooo`;o00008?ooool2o`0000[ooooo0_l0002[ooooo`007_ooool00ol0003o
ooooooooo`0<ooooo`;o0000:oooool2o`0000_ooooo0_l0000Nooooo`;o0000goooool001kooooo
0_l0000=ooooo`;o0000:oooool2o`0002_ooooo0_l0003Oooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool02_ooool2o`0004kooooo0_l0000^ooooo`;o0000^oooool001kooooo00?o0000oooooooo
ool02_ooool2o`0003oooooo0_l0000=ooooo`;o00001_ooool2o`0002Kooooo0_l0002kooooo`00
7_ooool00ol0003oooooooooo`1;ooooo`;o00003?ooool3o`0000Kooooo0_l0002Zooooo`;o0000
=oooool001kooooo00?o0000ooooooooool02oooool2o`00013ooooo0_l0000jooooo`?o00004Ooo
ool2o`0009oooooo0_l0000gooooo`007_ooool00ol0003oooooooooo`09ooooo`Co00004?ooool2
o`0004kooooo0_l0003Hooooo`007_ooool00ol0003oooooooooo`09ooooo`Co00004_ooool2o`00
073ooooo0_l0002dooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o00001?ooool2o`0000co
oooo0_l0000Pooooo`;o0000AOooool2o`0000Oooooo0_l0000=ooooo`;o0000YOooool001kooooo
00?o0000ooooooooool02_ooool2o`0000Gooooo0_l0000^ooooo`;o0000AOooool2o`0001Kooooo
0_l0002Uooooo`007_ooool00ol0003oooooooooo`06ooooo`;o00000_ooool2o`0007;ooooo0_l0
0037ooooo`007_ooool00ol0003oooooooooo`06ooooo`;o0000>_ooool2o`00017ooooo0_l00006
ooooo`;o00007oooool2o`000003ooooool0003o00000<Cooooo000Nooooo`05o`000?oooooo0000
o`000?ooool00_l0000Sooooo`;o00006Oooool2o`0000Kooooo0_l00007ooooo`Co00001_ooool4
o`0001gooooo0_l000000ooooooo0000o`00002hooooo`;o00002_ooool001kooooo00Go0000oooo
ool0003o0000ooooo`02o`0000;ooooo0_l00004ooooo`;o00001oooool2o`00013ooooo0_l0000C
ooooo`?o00002oooool2o`0000Oooooo0_l0000:ooooo`;o0000<oooool2o`000:Gooooo0_l0000:
ooooo`007_ooool01?l0003oooooooooooooool2o`000003ooooool0003o000000;o00001?ooool2
o`0000Oooooo1?l0000>ooooo`;o00004oooool3o`0000_ooooo0_l00006ooooo`;o00001Oooool2
o`0000gooooo0_l0000Zooooo`;o0000Y?ooool2o`0000Cooooo0ol00004ooooo`007_ooool2o`00
00;ooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool2o`0000Wooooo0_l0000Loooo
o`;o00003_ooool2o`000003ooooool0003o000000Sooooo0_l00005ooooo`;o00003Oooool2o`00
0=3ooooo0_l00004ooooo`?o00001?ooool001kooooo00?o0000ooooooooool02?ooool2o`0002_o
oooo0_l0000>ooooo`;o000000?oooooo`000?l000007_ooool2o`000=gooooo000Nooooo`03o`00
0?oooooooooo00Kooooo0_l0000Gooooo`;o00006oooool2o`0002?ooooo0_l0003Tooooo`007_oo
ool00ol0003oooooooooo`02ooooo`;o00000_ooool2o`0000Oooooo0_l0000>ooooo`;o00006ooo
ool2o`0000Gooooo0_l00004ooooo`;o00002Oooool2o`0000_ooooo0_l0000Iooooo`;o0000bOoo
ool001kooooo00?o0000ooooooooool00_ooool2o`0000_ooooo0_l0000booooo`;o00001?ooool2
o`0000Wooooo1?l0000Cooooo`;o00003oooool2o`000<Wooooo000Nooooo`03o`000?oooooooooo
00Co00006oooool2o`00017ooooo0_l0000Cooooo`;o00000oooool2o`0000;ooooo0_l00002oooo
o`Co00004oooool2o`000=[ooooo000Nooooo`03o`000?oooooooooo00;o00007Oooool2o`00017o
oooo0_l0000Cooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`;o00005_ooool2o`0000_o
oooo0_l0003<ooooo`007_ooool00ol0003oooooooooo`0Fooooo`;o0000:_ooool3o`0000?ooooo
0_l00005ooooo`;o000000?oooooo`000?l000006?ooool2o`0000_ooooo0_l0003<ooooo`007_oo
ool00ol0003oooooooooo`0Fooooo`;o00006_ooool2o`0000kooooo0ol00003ooooo`Go000000Go
ooooo`000?l0003o0000ooooo`02o`000004ooooool0003o0000o`0001gooooo0_l0003@ooooo`00
7_ooool00ol0003oooooooooo`0Fooooo`;o00006?ooool4o`0000kooooo0_l00004ooooo`Go0000
00?oooooo`000?l000000_ooool6o`0000oooooo0_l0000<ooooo`;o0000d?ooool001kooooo00?o
0000ooooooooool00_ooool2o`0002Oooooo0_l00003ooooo`;o00004?ooool4o`0000?ooooo0_l0
0005ooooo`Ko00004Oooool2o`0000;ooooo0_l00003ooooo`;o00007Oooool2o`000;Kooooo000N
ooooo`03o`000?oooooooooo00;ooooo0_l0000Wooooo`;o00005?ooool2o`000003ooooool0003o
000000[ooooo0_l0000Iooooo`;o00000oooool2o`0001gooooo0_l0002fooooo`007_ooool00ol0
003oooooooooo`0_ooooo`;o00001Oooool2o`0000Wooooo0_l0000^ooooo`;o0000e?ooool001ko
oooo00?o0000ooooooooool02_ooool2o`0002?ooooo0_l00005ooooo`;o00005Oooool2o`0000;o
oooo0_l0000=ooooo`;o00003oooool2o`00013ooooo0_l00003ooooo`;o0000_Oooool001kooooo
00?o0000ooooooooool02_ooool2o`0002Oooooo1_l0000Dooooo`;o00000_ooool4o`0000_ooooo
0_l00009ooooo`;o00005_ooool2o`0000?ooooo0_l0002mooooo`007_ooool01?l0003ooooooooo
ooooool2o`00033ooooo1ol0000Booooo`;o00001?ooool6o`000003ooooool0003o000000[ooooo
0_l00004ooooo`;o00001?ooool3o`000=?ooooo000Nooooo`;o00000_ooool2o`0003;ooooo0_l0
00000ooooooo0000o`000006ooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o0000
1_ooool4o`000004ooooool0003o0000ooooo`;o00001oooool2o`0000Sooooo1Ol0003Cooooo`00
7_ooool00ol0003oooooooooo`0aooooo`;o00001_ooool2o`0000Gooooo0_l000001?oooooo0000
o`000?ooool2o`0000Gooooo0_l00006ooooo`?o000000Coooooo`000?l0003ooooo0_l0000Aoooo
o`;o0000c_ooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo037ooooo0_l00003ooooo`;o
000000?oooooo`000?l000000oooool2o`0000Wooooo0_l000000ooooooo0000o`000005o`0000;o
oooo0ol00004ooooo`Co00004?ooool3o`0000cooooo0_l0002nooooo`;o00001_ooool001kooooo
00?o0000ooooooooool01oooool2o`0000[ooooo0_l0000<ooooo`;o00004oooool2o`000003oooo
ool0003o000000?ooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo1Ol000000ooooooo
0000o`000009o`0000;ooooo1?l0000@ooooo`Go00002_ooool2o`000;kooooo0_l00006ooooo`00
7_ooool00ol0003oooooooooo`07ooooo`;o00002_ooool2o`0000cooooo0_l0000Dooooo`Go0000
0oooool4o`000003ooooool0003o000000Gooooo0_l00003ooooo`;o000000?oooooo`000?l00000
1Ol000000ooooooo0000o`000002o`0001?ooooo0ol0003:ooooo`;o00001_ooool001kooooo00?o
0000ooooooooool0=oooool6o`0000;ooooo0_l0000>ooooo`?o00000_ooool2o`0000;ooooo2?l0
00000ooooooo0000o`00000?ooooo`;o0000doooool001kooooo00?o0000ooooooooool0:oooool2
o`0000kooooo0_l0000Booooo`;o000000?oooooo`000?l000000_l00002ooooo`Go000000?ooooo
o`000?l000000ol0003Tooooo`007_ooool00ol0003oooooooooo`0[ooooo`;o00003oooool2o`00
0003ooooool0003o000000;ooooo0ol00002ooooo`;o00000oooool2o`0000?ooooo0_l000000ooo
oooo0000o`000003o`000003ooooool0003o000000;o000000?oooooo`000?l000005?ooool2o`00
027ooooo0_l0002/ooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o0000:oooool5o`000003
ooooool0003o000000;o00000_ooool2o`0000?ooooo0_l00005ooooo`Ko00000_ooool4o`0001Ko
oooo0_l0000Qooooo`;o00000_ooool2o`000:Sooooo000Nooooo`03o`000?oooooooooo00gooooo
1?l0000Hooooo`;o00004oooool2o`0000;ooooo0ol0000?ooooo`Ko000000Coooooo`000?l0003o
oooo0ol00005ooooo`;o0000=Oooool2o`0009Sooooo0_l0000>ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`;o00004?ooool3o`0000Oooooo0_l0000Cooooo`;o00001Oooool2o`0000;ooooo
1?l00002ooooo`;o000000Coooooo`000?l0003ooooo0ol00002ooooo`?o000000?oooooo`000?l0
00000_l00004ooooo`;o00001Oooool2o`000<Sooooo0_l0000>ooooo`007_ooool00ol0003ooooo
ooooo`0Oooooo`?o00001oooool2o`00017ooooo0_l00005ooooo`[o00000_ooool2o`000004oooo
ool0003o0000ooooo`?o00000_ooool3o`000003ooooool0003o000000;o00002oooool2o`000=So
oooo000Nooooo`03o`000?oooooooooo03cooooo0_l00005ooooo`;o00000_ooool7o`0000?ooooo
0_l00003ooooo`?o00001Oooool2o`0000?ooooo0ol0003Qooooo`007_ooool00ol0003ooooooooo
o`17ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o00000_ooool4o`0000Gooooo0_l0
0003ooooo`Co00000_ooool2o`000=cooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo01_ooooo
0_l0000Qooooo`;o00002oooool3o`0000Oooooo1Ol0000;ooooo`;o00000_ooool2o`000=cooooo
0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?oooooo
V9RHob4Q8@06ooooo`03o`000?oooooooooo01_ooooo0_l0000Qooooo`?o00001?ooool2o`0000Co
oooo0ol000000ooooooo0000o`000003ooooo`Ko00001Oooool2o`0000Cooooo0_l0003Pooooo`00
0oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006oooo
o`?o00009Oooool2o`0001Sooooo0_l00004ooooo`?o00000oooool2o`0000;ooooo0_l00003oooo
o`;o00000oooool3o`0000?ooooo0_l00003ooooo`;o00003?ooool2o`0000;ooooo0_l0000=oooo
o`;o0000`?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9Sooooo
oiRHV?lb<S801_ooool00ol0003oooooooooo`0Uooooo`;o00006Oooool5o`000003ooooool0003o
000000;o000000?oooooo`000?l000000_ooool3o`0000Cooooo1ol00007ooooo`;o00003?ooool2
o`000004ooooool0003o0000o`0000gooooo0_l0002@ooooo`;o0000;_ooool000?ooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003ooooo
ooooo`10ooooo`Go00000oooool5o`0000?ooooo0_l00002ooooo`Wo00003?ooool2o`0000[ooooo
0_l0002Pooooo`;o0000;_ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@
4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`10ooooo`Co000000?oooooo`000?l0
00000_ooool4o`0000;ooooo1?l000000ooooooo0000o`000002ooooo`;o00003oooool2o`000;[o
oooo0_l0000Pooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oo
oooo^[Zjo`000006ooooo`03o`000?oooooooooo04Gooooo0_l00008ooooo`Oo00000_ooool2o`00
00_ooooo0_l0000:ooooo`;o0000/_ooool2o`00023ooooo0003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0A?ooool2
o`0000[ooooo1?l00009ooooo`;o00001_ooool2o`0000Oooooo0_l000000ooooooo0000o`00000S
ooooo`;o0000[oooool001kooooo00?o0000ooooooooool0>oooool2o`0000Gooooo1?l00003oooo
o`;o00001Oooool2o`0000[ooooo0ol0000?ooooo`;o00009_ooool2o`000:oooooo000Nooooo`03
o`000?oooooooooo03?ooooo1?l00004ooooo`;o00001Oooool3o`0000Cooooo0_l00006ooooo`;o
00000oooool5o`000003ooooool0003o000001Sooooo0_l0003?ooooo`007_ooool00ol0003ooooo
ooooo`0cooooo`Co00002_ooool3o`000003ooooool0003o000000;ooooo0ol00005ooooo`?o0000
0_ooool5o`0000Gooooo0_l0000;ooooo`;o00001oooool2o`000<oooooo000Nooooo`03o`000?oo
oooooooo047ooooo1_l00003ooooo`;o00001_ooool4o`0000Oooooo0_l000000ooooooo0000o`00
000;ooooo`;o00001Oooool2o`000003ooooool0003o0000023ooooo0_l0001Kooooo`;o0000Cooo
ool001kooooo00?o0000ooooooooool0:oooool2o`0000cooooo0_l00006ooooo`Oo000000Cooooo
o`000?l0003o00001oooool3o`000004ooooool0003o0000o`0000?ooooo0_l0000Eooooo`;o0000
00?oooooo`000?l000004?ooool2o`0000kooooo0_l0001Kooooo`;o0000Coooool001kooooo00?o
0000ooooooooool04oooool2o`0001Kooooo0_l0000<ooooo`;o00001Oooool4o`000005ooooool0
003o0000o`000?ooool00_l00008ooooo`;o000000?oooooo`000?l000000_l0000_ooooo`;o0000
_?ooool001kooooo00?o0000ooooooooool04oooool2o`0002_ooooo0_l00004ooooo`;o000000?o
ooooo`000?l000001?ooool2o`0000?ooooo1?l0000Fooooo`;o0000/oooool2o`0002;ooooo000N
ooooo`03o`000?oooooooooo01Gooooo0_l0000_ooooo`Go00000oooool3o`0000?ooooo0_l00009
ooooo`Co00002oooool2o`0000Cooooo0ol0002/ooooo`;o00008_ooool001kooooo00?o0000oooo
ooooool01?ooool2o`0000oooooo0_l0000[ooooo`Oo00001Oooool6o`0000Cooooo0_l00002oooo
o`So00004?ooool3o`0000;ooooo0_l0003<ooooo`007_ooool01?l0003oooooooooooooool2o`00
0003ooooool0003o000003cooooo1Ol00005ooooo`So00001?ooool2o`0000;ooooo1?l00002oooo
o`;o00003oooool2o`0000Cooooo0_l0003<ooooo`007_ooool01?l0003oooooooooooooool2o`00
02;ooooo0_l0000Oooooo`;o00001?ooool2o`0000?ooooo0ol00008ooooo`;o00005Oooool2o`00
05kooooo0_l0001booooo`007_ooool2o`0002Kooooo0_l0000Mooooo`Co00001Oooool3o`000003
ooooool0003o000000Cooooo0_l000000ooooooo0000o`000003ooooo`;o00006?ooool2o`0000[o
oooo0_l0001<ooooo`;o0000L_ooool001kooooo00?o0000ooooooooool0A?ooool3o`0000Kooooo
0ol00005ooooo`Co000000?oooooo`000?l000000oooool3o`0001Oooooo0_l0000:ooooo`;o0000
`?ooool001kooooo00?o0000ooooooooool0A?ooool3o`0000;ooooo0_l000000ooooooo0000o`00
0007ooooo`Co00000_ooool2o`0000;ooooo0ol00006ooooo`;o00000_ooool2o`000=Wooooo000N
ooooo`03o`000?oooooooooo01Wooooo1?l0000;ooooo`;o00007oooool2o`000003ooooool0003o
000000?ooooo0ol00003ooooo`;o00000_ooool2o`0000;ooooo0_l00007ooooo`;o00000_ooool3
o`0000Oooooo0_l0003?ooooo`007_ooool00ol0003oooooooooo`0Iooooo`Co00002oooool2o`00
01gooooo0_l00007ooooo`Co00002_ooool2o`0000Kooooo0_l00005ooooo`Co000000?oooooo`00
0?l000000_ooool2o`000<oooooo000Nooooo`03o`000?oooooooooo04Oooooo0_l00007ooooo`Co
00002_ooool4o`0000Cooooo0_l00007ooooo`;o000000?oooooo`000?l000006Oooool2o`0000So
oooo0_l0001eooooo`;o0000=oooool001kooooo00?o0000ooooooooool0B?ooool2o`0000Wooooo
1?l00003ooooo`;o00001?ooool2o`0001;ooooo0_l00006ooooo`;o00003oooool2o`0000Sooooo
0_l0000Looooo`;o0000Eoooool2o`0003Oooooo000Nooooo`03o`000?oooooooooo01_ooooo0_l0
000[ooooo`;o00000_ooool2o`0000Gooooo1?l00003ooooo`;o00005_ooool4o`0000Kooooo0_l0
000Booooo`;o00008oooool2o`00093ooooo000Nooooo`03o`000?oooooooooo01_ooooo0_l0000]
ooooo`Co00003?ooool6o`0001;ooooo1?l0000Jooooo`?o00001?ooool2o`000:kooooo000Noooo
o`03o`000?oooooooooo04[ooooo1?l00008ooooo`Go000000?oooooo`000?l000000_l0000<oooo
o`;o00001_ooool2o`0001Cooooo0_l00004ooooo`?o00001?ooool2o`000:kooooo000Nooooo`03
o`000?oooooooooo04_ooooo1Ol00006ooooo`Go00000_ooool2o`0000gooooo0_l00008ooooo`;o
00003?ooool2o`0000Cooooo0_l0002kooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o0000
2_ooool2o`0001oooooo1Ol000001?oooooo0000o`000?l00007ooooo`;o00005oooool2o`0000co
oooo0_l0002gooooo`;o00002?ooool001kooooo00?o0000ooooooooool08?ooool2o`0000[ooooo
0_l0000Oooooo`;o000000?oooooo`000?l000001_l00002ooooo`;o00003Oooool2o`0000Sooooo
0ol0000Rooooo`;o0000Xoooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo04Cooooo0_l0
0009ooooo`Wo00000_ooool2o`0000gooooo0ol00007ooooo`?o00008_ooool2o`000:gooooo000N
ooooo`03o`000?oooooooooo04Cooooo0_l00009ooooo`Co000000?oooooo`000?l000000ol0000A
ooooo`;o00004Oooool2o`000<Sooooo000Nooooo`03o`000?oooooooooo04oooooo0_l00005oooo
o`?o00009?ooool2o`0002?ooooo0_l0002Sooooo`007_ooool2o`00053ooooo0_l00005ooooo`;o
000000Coooooo`000?l0003o0000A_ooool2o`0005;ooooo0_l0001?ooooo`007_ooool00ol0003o
ooooooooo`1Iooooo`?o00006Oooool2o`0000;ooooo0_l0000>ooooo`;o0000Joooool2o`0004oo
oooo000Nooooo`03o`000?oooooooooo01Kooooo0_l0001Hooooo`;o00000oooool2o`0000;ooooo
1Ol0000;ooooo`;o0000Q_ooool2o`0003Cooooo000Nooooo`03o`000?oooooooooo01Cooooo1?l0
0017ooooo`;o00000oooool3o`0000Oooooo1?l00005ooooo`;o00000_ooool5o`00097ooooo0_l0
000dooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o00002Oooool2o`0001oooooo0_l0000G
ooooo`;o00001?ooool2o`0000?ooooo0ol00007ooooo`;o00001oooool2o`0000?ooooo1?l00037
ooooo`007_ooool00ol0003oooooooooo`0Looooo`;o000000?oooooo`000?l000007oooool2o`00
00Sooooo0_l0000=ooooo`Co00006_ooool2o`000<kooooo000Nooooo`03o`000?oooooooooo01Co
oooo0_l00006ooooo`;o0000;?ooool2o`0000oooooo0_l0000Cooooo`;o00000_ooool3o`0000?o
oooo0_l0003;ooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o000000?oooooo`000?l00000
4?ooool2o`0002cooooo0_l00005ooooo`;o00004oooool2o`0000;ooooo0ol00002ooooo`?o0000
boooool001kooooo00?o0000ooooooooool03?ooool2o`0000?ooooo0_l00003ooooo`;o00003_oo
ool2o`0002cooooo0_l00005ooooo`;o00003oooool6o`000003ooooool0003o000000Ko0000:Ooo
ool2o`000:7ooooo000Nooooo`03o`000?oooooooooo00_ooooo0ol00008ooooo`;o00003?ooool2
o`00043ooooo0_l00003ooooo`Oo000000?oooooo`000?l000001?l0000[ooooo`;o0000XOooool0
01kooooo00?o0000ooooooooool02oooool2o`0001;ooooo0_l00003ooooo`;o0000>_ooool2o`00
00?ooooo0ol00002ooooo`Co0000=?ooool2o`000:?ooooo000Nooooo`03o`000?oooooooooo01oo
oooo0_l0000oooooo`Co000000Coooooo`000?l0003o00000_ooool2o`00027ooooo0_l0000Coooo
o`;o0000Xoooool001kooooo00?o0000ooooooooool08?ooool2o`0003kooooo1?l00002ooooo`?o
00009?ooool2o`0000Wooooo0_l0002Sooooo`;o00002?ooool001kooooo00?o0000ooooooooool0
8?ooool2o`0003kooooo0_l000000ooooooo0000o`000002ooooo`?o0000;_ooool2o`0000;ooooo
1?l0002Mooooo`;o00002?ooool001kooooo00?o0000ooooooooool0Aoooool2o`0001[ooooo0_l0
0003ooooo`;o0000<_ooool4o`0001;ooooo0_l0000Xooooo`;o0000JOooool001kooooo00?o0000
ooooooooool04Oooool2o`0003Cooooo0_l0000Mooooo`;o0000B_ooool2o`0002Sooooo0_l0001O
ooooo`;o00002?ooool001kooooo0_l0000Aooooo`?o0000>_ooool2o`00013ooooo0_l00005oooo
o`;o00009_ooool2o`000:gooooo0_l00008ooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o
00002oooool2o`0002kooooo0_l0000@ooooo`;o00001oooool2o`0002?ooooo0ol0002gooooo`00
7_ooool00ol0003oooooooooo`0>ooooo`;o00003Oooool2o`0004Gooooo0_l00002ooooo`;o0000
8oooool2o`0000[ooooo0_l0001=ooooo`;o0000GOooool001kooooo00?o0000ooooooooool03_oo
ool2o`0000gooooo0_l00002ooooo`;o0000@Oooool2o`0003?ooooo0_l00005ooooo`;o0000A_oo
ool2o`0005gooooo000Nooooo`03o`000?oooooooooo01Sooooo0_l00007ooooo`;o0000@_ooool2
o`0001Wooooo0_l0000Nooooo`;o00000_ooool2o`000:7ooooo000Nooooo`03o`000?oooooooooo
01Sooooo0_l00010ooooo`;o00002Oooool2o`0001Wooooo0_l00009ooooo`;o00005oooool2o`00
0:7ooooo000Nooooo`03o`000?oooooooooo01Gooooo0_l00013ooooo`;o00004?ooool3o`0001co
oooo0_l0000Aooooo`;o0000@_ooool2o`0006?ooooo000Nooooo`03o`000?oooooooooo01Gooooo
0_l0001Eooooo`?o0000;oooool2o`0004;ooooo0_l0001Sooooo`007_ooool00ol0003ooooooooo
o`0=ooooo`;o0000BOooool2o`0003cooooo0_l00011ooooo`;o0000K?ooool001kooooo00?o0000
ooooooooool03Oooool2o`0004Wooooo0_l0000looooo`;o0000@Oooool2o`0006cooooo000Noooo
o`03o`000?oooooooooo0=Kooooo0_l0000_ooooo`;o00005_ooool2o`0002Kooooo000Nooooo`03
o`000?oooooooooo0=Kooooo0_l0000_ooooo`;o00005_ooool2o`0002Kooooo000Nooooo`03o`00
0?oooooooooo073ooooo0_l00006ooooo`;o0000cOooool001kooooo00?o0000ooooooooool03?oo
ool4o`0001cooooo0_l0000Booooo`;o00006?ooool2o`0001Cooooo0_l00006ooooo`;o0000>?oo
ool3o`0009;ooooo000Dooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`0<
ooooo`Co00003_ooool2o`0000cooooo0_l0000Booooo`;o00006?ooool2o`0005Kooooo0ol0000W
ooooo`;o0000AOooool2o`0002;ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool07_ooool2o`0004oooooo0_l0001[ooooo`;o0000>Oooool2o`0000[ooooo0_l0000Roooo
o`005_ooool00ol0003oooooooooo`05ooooo`?o00006Oooool2o`0005Cooooo0_l0002Vooooo`;o
0000;_ooool001Kooooo00?o0000ooooooooool08Oooool2o`000?oooooo;Oooool001Kooooo00?o
0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Foooo
o`03o`000?oooooooooo0?ooooooD?ooool001Cooooo00?oEEEEofIVI_l00000oooooomBooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.38531 .86284 Mdot
.49722 .78519 Mdot
.34324 .76794 Mdot
.34486 .84 Mdot
.21213 .73576 Mdot
.25873 .87303 Mdot
.38118 .52184 Mdot
.25917 .73858 Mdot
.24054 .86554 Mdot
.11152 .84862 Mdot
.25561 .93154 Mdot
.22823 .86493 Mdot
.29264 .7582 Mdot
.52693 .88683 Mdot
.31041 .85684 Mdot
.51528 .06553 Mdot
.46031 .173 Mdot
.27643 .76953 Mdot
.38137 .84881 Mdot
.32561 .88682 Mdot
.24411 .20049 Mdot
.2289 .91563 Mdot
.19588 .79949 Mdot
.42337 .68824 Mdot
.25935 .83641 Mdot
.25168 .73375 Mdot
.30049 .82271 Mdot
.49404 .00452 Mdot
.25305 .92284 Mdot
.27711 .9301 Mdot
.33859 .79726 Mdot
.29584 .85745 Mdot
.21013 .88366 Mdot
.0705 .66485 Mdot
.07472 .94381 Mdot
.3161 .80495 Mdot
.52206 .87333 Mdot
.26612 .28379 Mdot
.29754 .75906 Mdot
.28851 .80171 Mdot
.35228 .81184 Mdot
.08499 .93144 Mdot
.18874 .81858 Mdot
.37488 .25454 Mdot
.53605 .59166 Mdot
.07145 .92403 Mdot
.90919 .51597 Mdot
.11219 .69304 Mdot
.31231 .79469 Mdot
.18063 .04909 Mdot
.2729 .72551 Mdot
.10011 .85173 Mdot
.22944 .69724 Mdot
.30045 .78169 Mdot
.2141 .6952 Mdot
.16283 .39569 Mdot
.62851 .93579 Mdot
.27589 .74207 Mdot
.30436 .82459 Mdot
.29972 .92534 Mdot
.34538 .84961 Mdot
.24863 .74613 Mdot
.41008 .49274 Mdot
.24493 .84499 Mdot
.27743 .79877 Mdot
.22429 .89196 Mdot
.1554 .81394 Mdot
.30234 .82272 Mdot
.27172 .88193 Mdot
.95128 .93625 Mdot
.07 .45222 Mdot
.35848 .01616 Mdot
.06858 .68382 Mdot
.23211 .40262 Mdot
.19423 .89469 Mdot
.53771 .95664 Mdot
.33673 .6778 Mdot
.14075 .37678 Mdot
.296 .84116 Mdot
.48219 .86 Mdot
.03713 .70583 Mdot
.029 .66056 Mdot
.35543 .25823 Mdot
.25505 .74524 Mdot
.4421 .64451 Mdot
.08058 .42653 Mdot
.23667 .71841 Mdot
.33001 .82537 Mdot
.28931 .86863 Mdot
.33238 .98948 Mdot
.26795 .89267 Mdot
.09014 .998 Mdot
.19548 .08834 Mdot
.07181 .38852 Mdot
.32111 .88934 Mdot
.03928 .73888 Mdot
.34181 .43194 Mdot
.08762 .89811 Mdot
.21393 .80484 Mdot
.08411 .04762 Mdot
.31132 .78954 Mdot
.27859 .68842 Mdot
.39673 .84042 Mdot
.5513 .9518 Mdot
.44886 .79261 Mdot
.19034 .80061 Mdot
.4863 .1079 Mdot
.51159 .06973 Mdot
.11908 .80867 Mdot
.2023 .45755 Mdot
.5228 .88683 Mdot
.32391 .20128 Mdot
.42469 .63283 Mdot
.30236 .76933 Mdot
.5974 .16965 Mdot
.05642 .67387 Mdot
.5411 .60415 Mdot
.29823 .77169 Mdot
.35338 .7225 Mdot
.48827 .65437 Mdot
.30991 .82048 Mdot
.11016 .76713 Mdot
.20227 .91399 Mdot
.07837 .39713 Mdot
.2928 .16327 Mdot
.14629 .1479 Mdot
.18306 .79437 Mdot
.37123 .86777 Mdot
.07911 .69781 Mdot
.04812 .70002 Mdot
.16869 .18481 Mdot
.35368 .38802 Mdot
.71718 .0496 Mdot
.24814 .83488 Mdot
.30197 .83075 Mdot
.24289 .68318 Mdot
.17799 .78633 Mdot
.40875 .10451 Mdot
.38465 .78894 Mdot
.23548 .87835 Mdot
.35974 .85987 Mdot
.23852 .84095 Mdot
.2068 .90343 Mdot
.02445 .96592 Mdot
.31248 .37468 Mdot
.21203 .87784 Mdot
.32835 .88974 Mdot
.3047 .7939 Mdot
.5959 .95748 Mdot
.1255 .55501 Mdot
.42778 .78255 Mdot
.20195 .89687 Mdot
.28707 .82011 Mdot
.32131 .89474 Mdot
.31595 .84683 Mdot
.279 .76228 Mdot
.43643 .11192 Mdot
.87001 .8133 Mdot
.25783 .85385 Mdot
.48873 .10435 Mdot
.39709 .06711 Mdot
.09863 .01499 Mdot
.37779 .42134 Mdot
.24214 .85957 Mdot
.22036 .79807 Mdot
.19597 .729 Mdot
.30405 .78871 Mdot
.27693 .83733 Mdot
.22852 .46405 Mdot
.21294 .81342 Mdot
.21821 .92768 Mdot
.99872 .70811 Mdot
.10295 .99418 Mdot
.48037 .06098 Mdot
.38763 .87 Mdot
.36568 .08274 Mdot
.26875 .53519 Mdot
.28794 .72187 Mdot
.34565 .47936 Mdot
.10232 .86683 Mdot
.23362 .80792 Mdot
.20556 .86389 Mdot
.41763 .84562 Mdot
.49114 .54773 Mdot
.15758 .75883 Mdot
.35827 .62843 Mdot
.48547 .10466 Mdot
.25434 .87458 Mdot
.62478 .92243 Mdot
.02561 .97171 Mdot
.38105 .87135 Mdot
.13504 .40639 Mdot
.37198 .86861 Mdot
.46617 .61654 Mdot
.47179 .64053 Mdot
.21168 .83926 Mdot
.07172 .99095 Mdot
.21227 .91662 Mdot
.23821 .86649 Mdot
.19613 .89607 Mdot
.45762 .44751 Mdot
.52945 .1531 Mdot
.26672 .84139 Mdot
.50495 .55862 Mdot
.25738 .83776 Mdot
.33172 .82711 Mdot
.08052 .62802 Mdot
.32655 .82707 Mdot
.44219 .64655 Mdot
.4743 .98427 Mdot
.19406 .79072 Mdot
.36197 .86557 Mdot
.42021 .92581 Mdot
.01382 .54389 Mdot
.41146 .08976 Mdot
.04752 .43385 Mdot
.29496 .79026 Mdot
.14897 .00766 Mdot
.40083 .08998 Mdot
.1532 .8737 Mdot
.70372 .91063 Mdot
.31888 .91199 Mdot
.23114 .83429 Mdot
.27236 .84768 Mdot
.33355 .95152 Mdot
.37277 .03096 Mdot
.99476 .76502 Mdot
.18865 .73951 Mdot
.16706 .75369 Mdot
.21082 .90167 Mdot
.26589 .75323 Mdot
.28831 .94651 Mdot
.20137 .90321 Mdot
.0148 .6087 Mdot
.04417 .43538 Mdot
.23367 .01812 Mdot
.07551 .68329 Mdot
.32578 .77968 Mdot
.25262 .26512 Mdot
.51451 .04975 Mdot
.32835 .68548 Mdot
.20669 .9109 Mdot
.14052 .75475 Mdot
.36349 .69763 Mdot
.31651 .78873 Mdot
.32565 .71051 Mdot
.31962 .941 Mdot
.22991 .93283 Mdot
.90549 .02145 Mdot
.35066 .80643 Mdot
.11257 .8439 Mdot
.18692 .72171 Mdot
.80171 .38012 Mdot
.08447 .45325 Mdot
.28582 .20485 Mdot
.17142 .70113 Mdot
.21356 .70918 Mdot
.2203 .26453 Mdot
.03343 .83404 Mdot
.58667 .18465 Mdot
.36732 .87001 Mdot
.28269 .83936 Mdot
.17427 .30415 Mdot
.23093 .33342 Mdot
.20305 .90493 Mdot
.13123 .39242 Mdot
.37335 .63158 Mdot
.50719 .34104 Mdot
.31672 .7784 Mdot
.29069 .814 Mdot
.2169 .80436 Mdot
.03462 .92907 Mdot
.33503 .87696 Mdot
.25459 .86334 Mdot
.02534 .71088 Mdot
.17782 .7488 Mdot
.38517 .10845 Mdot
.47518 .38917 Mdot
.30679 .79037 Mdot
.31897 .67831 Mdot
.66354 .98633 Mdot
.22806 .92134 Mdot
.22468 .85173 Mdot
.50408 .8678 Mdot
.20461 .72356 Mdot
.23322 .83484 Mdot
.23117 .81098 Mdot
.17023 .13547 Mdot
.18098 .71911 Mdot
.29364 .77577 Mdot
.17945 .74372 Mdot
.15926 .99451 Mdot
.377 .84763 Mdot
.46136 .67055 Mdot
.31727 .44575 Mdot
.14935 .08708 Mdot
.29738 .79967 Mdot
.46998 .10219 Mdot
.66174 .04059 Mdot
.0793 .63373 Mdot
.17717 .15748 Mdot
.19212 .82484 Mdot
.05553 .95891 Mdot
.3128 .9552 Mdot
.09093 .89976 Mdot
.16907 .77451 Mdot
.29773 .82418 Mdot
.31609 .8398 Mdot
.43815 .48067 Mdot
.52223 .13959 Mdot
.31852 .82411 Mdot
.64935 .06957 Mdot
.25158 .73783 Mdot
.38598 .84449 Mdot
.24883 .79264 Mdot
.28356 .72923 Mdot
.34354 .02903 Mdot
.46787 .99511 Mdot
.20493 .86465 Mdot
.30098 .19332 Mdot
.31335 .74508 Mdot
.20379 .89349 Mdot
.28984 .71427 Mdot
.43533 .90318 Mdot
.31626 .78816 Mdot
.27234 .75546 Mdot
.30824 .79217 Mdot
.36002 .87184 Mdot
.22396 .84341 Mdot
.25415 .75359 Mdot
.29629 .88719 Mdot
.25162 .88692 Mdot
.44244 .43285 Mdot
.52274 .22167 Mdot
.0845 .17779 Mdot
.32208 .29387 Mdot
.9918 .88524 Mdot
.29912 .81763 Mdot
.44558 .99891 Mdot
.13624 .40434 Mdot
.22513 .80632 Mdot
.17636 .8216 Mdot
.3508 .86601 Mdot
.32491 .97457 Mdot
.61475 .80388 Mdot
.53594 .93267 Mdot
.22889 .48514 Mdot
.34767 .46972 Mdot
.24737 .27468 Mdot
.26082 .73414 Mdot
.31309 .77885 Mdot
.20075 .71287 Mdot
.03614 .95936 Mdot
.5265 .99719 Mdot
.29253 .51818 Mdot
.34067 .86608 Mdot
.07411 .93763 Mdot
.26028 .87989 Mdot
.28402 .74846 Mdot
.13816 .12605 Mdot
.22457 .92426 Mdot
.06517 .80916 Mdot
.34926 .80725 Mdot
.18854 .79077 Mdot
.21385 .83719 Mdot
.04578 .89846 Mdot
.40631 .6549 Mdot
.85838 .02715 Mdot
.4177 .01959 Mdot
.26648 .91586 Mdot
.39871 .0817 Mdot
.29234 .82596 Mdot
.3476 .79009 Mdot
.22056 .88871 Mdot
.96969 .72098 Mdot
.09526 .07894 Mdot
.53036 .57938 Mdot
.31764 .81018 Mdot
.4614 .8231 Mdot
.26796 .94518 Mdot
.28896 .84577 Mdot
.32506 .84726 Mdot
.29476 .88412 Mdot
.27381 .22537 Mdot
.47131 .02639 Mdot
.49211 .60553 Mdot
.40336 .69179 Mdot
.20758 .27017 Mdot
.29788 .81859 Mdot
.51621 .88458 Mdot
.35915 .85855 Mdot
.25014 .75117 Mdot
.33242 .78572 Mdot
.25308 .72791 Mdot
.22899 .7331 Mdot
.38273 .53848 Mdot
.51385 .20575 Mdot
.21843 .46117 Mdot
.3082 .82563 Mdot
.33318 .80425 Mdot
.17088 .8394 Mdot
.53753 .63205 Mdot
.88091 .85517 Mdot
.24987 .74708 Mdot
.4536 .88198 Mdot
.9892 .7285 Mdot
.2803 .77627 Mdot
.35469 .00887 Mdot
.32448 .96586 Mdot
.23736 .85379 Mdot
.39016 .07976 Mdot
.26716 .84235 Mdot
.39841 .0715 Mdot
.31646 .56894 Mdot
.46621 .96302 Mdot
.25219 .81174 Mdot
.39239 .83556 Mdot
.38072 .04627 Mdot
.76482 .85239 Mdot
.30192 .8403 Mdot
.2857 .81784 Mdot
.86846 .12462 Mdot
.19699 .0045 Mdot
.24532 .7656 Mdot
.27051 .74152 Mdot
.57172 .57366 Mdot
.47689 .45224 Mdot
.22547 .88142 Mdot
.36177 .02176 Mdot
.43863 .65258 Mdot
.50242 .00433 Mdot
.94649 .62763 Mdot
.59284 .95711 Mdot
.31508 .86109 Mdot
.74276 .04382 Mdot
.48241 .97578 Mdot
.43334 .0809 Mdot
.9927 .75314 Mdot
.35439 .76522 Mdot
.54609 .59921 Mdot
.39986 .62379 Mdot
.36111 .22451 Mdot
.40434 .24815 Mdot
.34192 .85813 Mdot
.24014 .98114 Mdot
.33749 .83796 Mdot
.20544 .88846 Mdot
.20746 .76792 Mdot
.04366 .09965 Mdot
.25522 .86687 Mdot
.23347 .09243 Mdot
.13214 .80162 Mdot
.22982 .81127 Mdot
.28178 .84523 Mdot
.36126 .76923 Mdot
.31586 .82521 Mdot
.25674 .84807 Mdot
.30705 .7929 Mdot
.04059 .69127 Mdot
.59561 .0589 Mdot
.35358 .7628 Mdot
.33112 .82992 Mdot
.27847 .84931 Mdot
.31709 .73233 Mdot
.37318 .64797 Mdot
.0936 .90121 Mdot
.20811 .88807 Mdot
.18866 .1356 Mdot
.33438 .86049 Mdot
.02327 .77304 Mdot
.26578 .92147 Mdot
.2426 .72453 Mdot
.25539 .74224 Mdot
.25542 .74366 Mdot
.35541 .73337 Mdot
.29415 .85077 Mdot
.30082 .676 Mdot
.26372 .74545 Mdot
.67888 .92251 Mdot
.16327 .79447 Mdot
.11895 .37127 Mdot
.4995 .64972 Mdot
.21426 .91283 Mdot
.34827 .85544 Mdot
.37882 .86838 Mdot
.032 .42058 Mdot
.01531 .44706 Mdot
.05471 .18782 Mdot
.97898 .71052 Mdot
.51278 .98153 Mdot
.33926 .79481 Mdot
.27388 .83784 Mdot
.4211 .47946 Mdot
.43244 .6868 Mdot
.30244 .90868 Mdot
.21885 .93152 Mdot
.31606 .73797 Mdot
.2024 .88642 Mdot
.32456 .6572 Mdot
.40043 .98584 Mdot
.34157 .7033 Mdot
.02798 .74313 Mdot
.006 .70414 Mdot
.29852 .006 Mdot
.25403 .78468 Mdot
.13649 .97396 Mdot
.24516 .73162 Mdot
.33421 .44316 Mdot
.26193 .8444 Mdot
.30459 .93172 Mdot
.32485 .82971 Mdot
.11716 .34711 Mdot
.2183 .35905 Mdot
.33599 .88623 Mdot
.2192 .72629 Mdot
.0204 .60069 Mdot
.27901 .76467 Mdot
.04163 .72323 Mdot
.77185 .76538 Mdot
.32813 .80957 Mdot
.27453 .88438 Mdot
.34351 .7328 Mdot
.29168 .8436 Mdot
.19418 .90363 Mdot
.02922 .99025 Mdot
.83535 .66162 Mdot
.42987 .44975 Mdot
.57629 .10602 Mdot
.42296 .85658 Mdot
.03561 .69439 Mdot
.35678 .41718 Mdot
.3192 .34311 Mdot
.20708 .72664 Mdot
.27171 .71511 Mdot
.25541 .74832 Mdot
.31156 .79228 Mdot
.25428 .80471 Mdot
.21946 .86295 Mdot
.27721 .28595 Mdot
.34026 .35668 Mdot
.2356 .87898 Mdot
.48795 .93857 Mdot
.20798 .87565 Mdot
.30357 .84711 Mdot
.37456 .82176 Mdot
.37284 .45855 Mdot
.0302 .11292 Mdot
.34447 .82484 Mdot
.21445 .83668 Mdot
.26965 .75736 Mdot
.10105 .625 Mdot
.43411 .46368 Mdot
.21447 .87497 Mdot
.18043 .54581 Mdot
.08818 .71722 Mdot
.78717 .91855 Mdot
.02263 .21502 Mdot
.29973 .8146 Mdot
.31906 .81593 Mdot
.52668 .16712 Mdot
.21563 .83368 Mdot
.20044 .85542 Mdot
.27607 .27623 Mdot
.12203 .01879 Mdot
.23876 .80621 Mdot
.31114 .78849 Mdot
.41514 .08895 Mdot
.22678 .82302 Mdot
.03607 .7344 Mdot
.28382 .86959 Mdot
.15227 .05114 Mdot
.5415 .96308 Mdot
.28838 .85391 Mdot
.34948 .87727 Mdot
.2631 .74663 Mdot
.21737 .88684 Mdot
.00249 .749 Mdot
.25582 .91529 Mdot
.18569 .72047 Mdot
.30987 .72845 Mdot
.80257 .0058 Mdot
.07272 .96443 Mdot
.3538 .6981 Mdot
.3566 .84795 Mdot
.29845 .33459 Mdot
.3298 .81946 Mdot
.3787 .62826 Mdot
.22018 .58898 Mdot
.50162 .69412 Mdot
.30561 .89869 Mdot
.2674 .74447 Mdot
.24751 .68323 Mdot
.32054 .97735 Mdot
.20008 .89097 Mdot
.22779 .90261 Mdot
.25051 .74439 Mdot
.42055 .06481 Mdot
.26223 .75838 Mdot
.32276 .81179 Mdot
.2698 .90975 Mdot
.20965 .89303 Mdot
.28626 .8257 Mdot
.3342 .78825 Mdot
.08669 .9009 Mdot
.49053 .59118 Mdot
.24183 .86524 Mdot
.29812 .8015 Mdot
.24301 .92832 Mdot
.48408 .5394 Mdot
.37534 .86844 Mdot
.45791 .49683 Mdot
.32047 .44443 Mdot
.28839 .89811 Mdot
.39555 .47411 Mdot
.39327 .83624 Mdot
.44002 .11694 Mdot
.36672 .02851 Mdot
.02841 .45605 Mdot
.20016 .81133 Mdot
.98256 .84415 Mdot
.02254 .63608 Mdot
.2535 .05079 Mdot
.37512 .87001 Mdot
.19552 .53081 Mdot
.07503 .87758 Mdot
.38895 .6495 Mdot
.26299 .40711 Mdot
.11216 .43351 Mdot
.19586 .71118 Mdot
.06705 .80273 Mdot
.3714 .75673 Mdot
.27139 .84684 Mdot
.30037 .91042 Mdot
.60082 .93953 Mdot
.28483 .8554 Mdot
.06151 .44752 Mdot
.25682 .74424 Mdot
.27989 .8505 Mdot
.23304 .74888 Mdot
.30681 .86439 Mdot
.17347 .85377 Mdot
.272 .87041 Mdot
.09005 .91916 Mdot
.11492 .8061 Mdot
.45816 .60934 Mdot
.30156 .87614 Mdot
.20825 .75866 Mdot
.65367 .89881 Mdot
.25234 .75492 Mdot
.47085 .53197 Mdot
.44923 .68883 Mdot
.20152 .87813 Mdot
.29243 .61371 Mdot
.27082 .85051 Mdot
.03895 .11196 Mdot
.28414 .80903 Mdot
.26022 .68655 Mdot
.70689 .11716 Mdot
.43909 .65225 Mdot
.31188 .82567 Mdot
.54004 .58732 Mdot
.19695 .87394 Mdot
.07017 .83153 Mdot
.31045 .81535 Mdot
.13262 .39935 Mdot
.03736 .74395 Mdot
.30901 .83971 Mdot
.33428 .50578 Mdot
.0771 .04872 Mdot
.10644 .7452 Mdot
.06164 .52985 Mdot
.05147 .82455 Mdot
.46633 .58116 Mdot
.27473 .95078 Mdot
.47255 .07591 Mdot
.24798 .74127 Mdot
.69641 .60813 Mdot
.24994 .75651 Mdot
.10078 .57089 Mdot
.44428 .63495 Mdot
.33055 .19296 Mdot
.02161 .97045 Mdot
.43245 .95555 Mdot
.37435 .86958 Mdot
.28336 .86837 Mdot
.14767 .04183 Mdot
.19661 .72914 Mdot
.19815 .49023 Mdot
.47865 .71748 Mdot
.29451 .75765 Mdot
.11475 .70817 Mdot
.52226 .6031 Mdot
.1268 .19463 Mdot
.12943 .00607 Mdot
.20621 .89342 Mdot
.20707 .88333 Mdot
.27662 .84874 Mdot
.3294 .3663 Mdot
.03693 .14483 Mdot
.4247 .71609 Mdot
.15257 .09663 Mdot
.53609 .99696 Mdot
.28373 .76525 Mdot
.38689 .79426 Mdot
.0257 .45381 Mdot
.19563 .90287 Mdot
.1324 .58358 Mdot
.43798 .78791 Mdot
.48329 .42797 Mdot
.22886 .87086 Mdot
.15267 .97975 Mdot
.323 .06345 Mdot
.51401 .67492 Mdot
.45213 .36289 Mdot
.17716 .74482 Mdot
.57939 .37515 Mdot
.22316 .92517 Mdot
.25254 .72527 Mdot
.92412 .76166 Mdot
.21492 .92285 Mdot
.35852 .86913 Mdot
.01802 .531 Mdot
.27065 .87621 Mdot
.32816 .23264 Mdot
.26912 .15185 Mdot
.06055 .87975 Mdot
.49802 .13646 Mdot
.30626 .81715 Mdot
.10497 .77511 Mdot
.65564 .89779 Mdot
.24325 .95157 Mdot
.24178 .94576 Mdot
.2936 .76589 Mdot
.24142 .8677 Mdot
.93884 .73539 Mdot
.27146 .19584 Mdot
.07997 .07763 Mdot
.05821 .18125 Mdot
.23793 .76089 Mdot
.39145 .69573 Mdot
.17931 .83713 Mdot
.33522 .8531 Mdot
.39366 .8529 Mdot
.13692 .52929 Mdot
.02041 .61773 Mdot
.18981 .77847 Mdot
.27465 .94705 Mdot
.64405 .92741 Mdot
.19947 .84807 Mdot
.2756 .53919 Mdot
.13056 .79756 Mdot
.35184 .8159 Mdot
.42489 .68994 Mdot
.39109 .83126 Mdot
.28673 .87007 Mdot
.19037 .79588 Mdot
.21876 .79276 Mdot
.05117 .72397 Mdot
.28974 .67642 Mdot
.33812 .79424 Mdot
.07067 .81998 Mdot
.25762 .73762 Mdot
.42996 .69754 Mdot
.34241 .81093 Mdot
.28013 .78825 Mdot
.34352 .86246 Mdot
.04467 .00689 Mdot
.53716 .95442 Mdot
.21079 .91316 Mdot
.42953 .7407 Mdot
.25259 .82016 Mdot
.46472 .76657 Mdot
.20213 .82188 Mdot
.18681 .72196 Mdot
.09596 .59906 Mdot
.34886 .83512 Mdot
.16335 .79834 Mdot
.33663 .793 Mdot
.35085 .7734 Mdot
.3907 .36962 Mdot
.34239 .84242 Mdot
.43735 .64478 Mdot
.57565 .08336 Mdot
.00074 .70678 Mdot
.28784 .78194 Mdot
.44075 .11379 Mdot
.51405 .01043 Mdot
.23741 .87587 Mdot
.2738 .83925 Mdot
.28563 .75979 Mdot
.04516 .05217 Mdot
.42123 .01759 Mdot
.42324 .89362 Mdot
.26655 .72365 Mdot
.16757 .07572 Mdot
.25298 .68758 Mdot
.52132 .97849 Mdot
.12817 .13631 Mdot
.32814 .82991 Mdot
.33638 .95987 Mdot
.35802 .28731 Mdot
.25834 .93307 Mdot
.35007 .69528 Mdot
.46898 .6282 Mdot
.2822 .99845 Mdot
.26728 .80302 Mdot
.42128 .4503 Mdot
.18129 .08053 Mdot
.09971 .04229 Mdot
.29259 .89634 Mdot
.10925 .08241 Mdot
.32629 .82084 Mdot
.3383 .73519 Mdot
.20293 .69012 Mdot
.26893 .85743 Mdot
.28784 .8317 Mdot
.1844 .30885 Mdot
.60893 .96087 Mdot
.32409 .85065 Mdot
.34683 .49842 Mdot
.25672 .74498 Mdot
.25988 .75555 Mdot
.19006 .82613 Mdot
.27911 .76004 Mdot
.24966 .72394 Mdot
.42137 .10953 Mdot
.22903 .70254 Mdot
.21283 .80904 Mdot
.11732 .588 Mdot
.26358 .90687 Mdot
.53458 .6051 Mdot
.18761 .14319 Mdot
.2781 .7484 Mdot
.01313 .69093 Mdot
.12147 .90767 Mdot
.22182 .83438 Mdot
.08258 .403 Mdot
.31258 .79616 Mdot
.20852 .84564 Mdot
.84916 .92946 Mdot
.37977 .61744 Mdot
.2602 .75861 Mdot
.29999 .82494 Mdot
.23521 .87127 Mdot
.6331 .96427 Mdot
.42081 .52425 Mdot
.14038 .13013 Mdot
.31826 .7788 Mdot
.24941 .74352 Mdot
.35476 .8177 Mdot
.25469 .29697 Mdot
.30572 .01537 Mdot
.35818 .81931 Mdot
.31748 .77248 Mdot
.31621 .80144 Mdot
.44004 .75916 Mdot
.25758 .74087 Mdot
.27125 .66 Mdot
.16037 .79867 Mdot
.32418 .80413 Mdot
.25559 .75565 Mdot
.34491 .84183 Mdot
.22462 .87524 Mdot
.0421 .49286 Mdot
.25459 .73686 Mdot
.19749 .88148 Mdot
.38306 .85112 Mdot
.40901 .11289 Mdot
.40948 .23571 Mdot
.26946 .75096 Mdot
.57273 .11814 Mdot
.32282 .79687 Mdot
.25013 .83471 Mdot
.33897 .76372 Mdot
.03532 .72303 Mdot
.23574 .72037 Mdot
.4341 .86244 Mdot
.36373 .33652 Mdot
.51458 .6242 Mdot
.30674 .86133 Mdot
.87941 .80947 Mdot
.33344 .89834 Mdot
.2555 .73982 Mdot
.32186 .6971 Mdot
.21583 .83788 Mdot
.38407 .86527 Mdot
.39039 .83435 Mdot
.56423 .9926 Mdot
.22742 .9169 Mdot
.9543 .72402 Mdot
.28379 .96936 Mdot
.47452 .4059 Mdot
.2146 .76076 Mdot
.22355 .91986 Mdot
.88422 .44911 Mdot
.29692 .79153 Mdot
.19575 .76484 Mdot
.32258 .86925 Mdot
.45215 .80401 Mdot
.16363 .80007 Mdot
.30954 .85403 Mdot
.33391 .6432 Mdot
.88916 .04861 Mdot
.33773 .80975 Mdot
.26332 .5523 Mdot
.35403 .16092 Mdot
.00405 .69359 Mdot
.24673 .90378 Mdot
.37035 .8414 Mdot
.34221 .86885 Mdot
.23983 .67874 Mdot
.97634 .73383 Mdot
.22582 .66685 Mdot
.22244 .86753 Mdot
.15765 .82202 Mdot
.46538 .23832 Mdot
.06778 .81145 Mdot
.43432 .78967 Mdot
.03627 .70103 Mdot
.23173 .87475 Mdot
.21642 .01656 Mdot
.07575 .17403 Mdot
.32117 .76284 Mdot
.25194 .7549 Mdot
.30237 .86043 Mdot
.21506 .26164 Mdot
.18731 .80037 Mdot
.35084 .7689 Mdot
.31765 .33607 Mdot
.44103 .64905 Mdot
.19115 .89154 Mdot
.17617 .78525 Mdot
.26567 .75002 Mdot
.20266 .90418 Mdot
.18343 .43161 Mdot
.3663 .86296 Mdot
.48528 .1597 Mdot
.23609 .94107 Mdot
.31005 .83753 Mdot
.19051 .45784 Mdot
.27773 .75241 Mdot
.382 .81744 Mdot
.26114 .83128 Mdot
.36126 .44888 Mdot
.27936 .74547 Mdot
.26967 .8635 Mdot
.06841 .61109 Mdot
.17061 .86236 Mdot
.23925 .8739 Mdot
.14174 .47506 Mdot
.30119 .88416 Mdot
.69094 .11808 Mdot
.11143 .88476 Mdot
.90978 .13576 Mdot
.4002 .83143 Mdot
.32263 .77155 Mdot
.05255 .66689 Mdot
.19472 .17275 Mdot
.40887 .46924 Mdot
.39812 .58074 Mdot
.23627 .92336 Mdot
.28004 .84286 Mdot
.32238 .8527 Mdot
.29907 .95801 Mdot
.26106 .75752 Mdot
.28955 .49182 Mdot
.38823 .11671 Mdot
.38317 .03753 Mdot
.26129 .77333 Mdot
.21881 .46401 Mdot
.15362 .44125 Mdot
.90568 .60792 Mdot
.4305 .73506 Mdot
.35535 .47525 Mdot
.96398 .38332 Mdot
.24805 .73676 Mdot
.47455 .09855 Mdot
.26352 .32031 Mdot
.30108 .82936 Mdot
.32113 .79859 Mdot
.26323 .72885 Mdot
.32055 .90984 Mdot
.1698 .32928 Mdot
.49201 .09974 Mdot
.27922 .94756 Mdot
.12902 .8036 Mdot
.39016 .75143 Mdot
.10367 .55733 Mdot
.07964 .8552 Mdot
.30546 .80554 Mdot
.28983 .20908 Mdot
.34134 .83855 Mdot
.30788 .81593 Mdot
.20156 .37461 Mdot
.20424 .8374 Mdot
.30682 .81519 Mdot
.32676 .79748 Mdot
.14945 .08778 Mdot
.449 .09279 Mdot
.21977 .93694 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00co
oooo0ol0000?ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool2o`0000ko
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool00_ooool001kooooo00?o0000ooooooooool02_ooool2o`000003oooo
ool0003ooooo00kooooo00?o0000ooooooooool01_ooool2o`0000Gooooo00?o0000ooooooooool0
3?ooool3o`0000oooooo00?o0000ooooooooool03?ooool2o`0000oooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo1?l0000>ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03_ooool2o`0000kooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
0_ooool001kooooo00?o0000ooooooooool02_ooool2o`0001[ooooo0_l00004ooooo`;o0000;ooo
ool2o`00013ooooo0_l0000/ooooo`;o00001?ooool2o`0005cooooo0_l00014ooooo`007_ooool0
0ol0003oooooooooo`0/ooooo`;o0000@Oooool2o`0003;ooooo0_l0002Rooooo`007_ooool00ol0
003oooooooooo`0Looooo`;o00009?ooool2o`0001_ooooo0_l0000?ooooo`;o0000eOooool001ko
oooo00?o0000ooooooooool07?ooool2o`0000Kooooo0_l0000Looooo`;o00001?ooool2o`0001Go
oooo0_l0000?ooooo`;o00004_ooool3o`000<3ooooo000Nooooo`03o`000?oooooooooo02Cooooo
0_l0000Rooooo`;o00009oooool2o`00017ooooo0ol0002Kooooo`;o00008oooool001kooooo00?o
0000ooooooooool0LOooool2o`000:oooooo0_l0000Sooooo`007_ooool00ol0003oooooooooo`1/
ooooo`;o00001Oooool2o`00023ooooo0_l0001looooo`;o0000<_ooool001kooooo00?o0000oooo
ooooool0K?ooool2o`0000Gooooo1?l0000Nooooo`;o0000O?ooool2o`0003;ooooo000Nooooo`03
o`000?oooooooooo07Gooooo0_l0003@ooooo`007_ooool00ol0003oooooooooo`1hooooo`;o0000
cOooool001kooooo00?o0000ooooooooool0N?ooool2o`0005Wooooo0_l0001booooo`007_ooool0
0ol0003oooooooooo`0Looooo`;o00003_ooool2o`000:Gooooo0_l0000Hooooo`;o0000F?ooool0
01kooooo00?o0000ooooooooool07?ooool2o`0000kooooo0_l0001:ooooo`;o0000Loooool2o`00
05Sooooo000Nooooo`03o`000?oooooooooo01Gooooo1?l0000Nooooo`;o0000?oooool2o`0002Wo
oooo0_l00010ooooo`;o0000=_ooool2o`0002Sooooo000Nooooo`;o00003?ooool2o`0000Sooooo
1?l0000Dooooo`;o00002?ooool2o`0001Gooooo0_l0001Cooooo`;o0000@?ooool2o`0003Kooooo
0_l0000Xooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o00008?ooool2o`0001oooooo0_l0
003gooooo`007_ooool00ol0003oooooooooo`2nooooo`;o0000Qoooool001kooooo00?o0000oooo
ooooool0V?ooool2o`0002Cooooo0_l00027ooooo`007_ooool00ol0003oooooooooo`1Uooooo`;o
00007_ooool2o`00017ooooo0_l00009ooooo`;o0000X_ooool001kooooo00?o0000ooooooooool0
IOooool2o`0001Kooooo0_l00006ooooo`;o00007?ooool2o`000:;ooooo000Nooooo`03o`000?oo
oooooooo07gooooo0_l0000Sooooo`;o0000:oooool2o`0007Kooooo000Nooooo`03o`000?oooooo
oooo07gooooo0_l0000Sooooo`;o0000:oooool2o`0007Kooooo000Nooooo`03o`000?oooooooooo
01Kooooo0_l0000Jooooo`;o0000H_ooool2o`000:oooooo000Nooooo`03o`000?oooooooooo01Ko
oooo0_l00003ooooo`;o00005Oooool2o`0000?ooooo0_l00012ooooo`;o00003?ooool2o`0000_o
oooo0_l0002_ooooo`007_ooool00ol0003oooooooooo`0Kooooo`;o00000_ooool2o`0001Kooooo
0_l0000jooooo`;o00001_ooool2o`000003ooooool0003o000000Wooooo0_l0000/ooooo`;o0000
S_ooool001kooooo00?o0000ooooooooool07oooool2o`0000_ooooo0_l00015ooooo`;o00002Ooo
ool2o`0003Oooooo0_l0002>ooooo`007_ooool00ol0003oooooooooo`0/ooooo`;o00003Oooool2
o`00047ooooo0_l00002ooooo`?o0000`_ooool001kooooo00?o0000ooooooooool0;?ooool2o`00
00gooooo0_l0000;ooooo`;o0000=?ooool2o`0000;ooooo0ol00009ooooo`;o0000]oooool001ko
oooo00?o0000ooooooooool0;Oooool2o`0001Wooooo0_l00014ooooo`;o0000]oooool001kooooo
00?o0000ooooooooool02_ooool2o`00027ooooo0_l0001Wooooo`;o00001?ooool2o`000:Wooooo
000Nooooo`;o00002oooool2o`0008Wooooo0ol00004ooooo`;o0000ZOooool001kooooo00?o0000
ooooooooool0POooool2o`0001;ooooo0_l00003ooooo`?o0000Z_ooool001kooooo00?o0000oooo
ooooool0NOooool2o`0000Kooooo0_l0000Gooooo`?o00006_ooool2o`0008kooooo000Nooooo`03
o`000?oooooooooo00Wooooo0_l0001^ooooo`;o00002_ooool2o`0000?ooooo0_l0000>ooooo`;o
00006oooool2o`0008kooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l000000ooooooo0000
o`00001fooooo`;o00000_ooool2o`0000?ooooo0ol0002jooooo`007_ooool00ol0003ooooooooo
o`06ooooo`;o0000L_ooool2o`0000Gooooo0_l00008ooooo`;o0000:Oooool2o`0002Gooooo0_l0
0003ooooo`;o0000Hoooool001kooooo00?o0000ooooooooool0N_ooool2o`0000oooooo0_l0000Y
ooooo`;o00009Oooool2o`0000?ooooo0_l0001Sooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo02Wooooo0_l0003[ooooo`;o0000;oooool001kooooo
00?o0000ooooooooool0:Oooool3o`000>[ooooo0_l0000_ooooo`007_ooool00ol0003ooooooooo
o`0Zooooo`;o0000oooooolLooooo`007_ooool00ol0003oooooooooo`0Vooooo`;o00002oooool2
o`0000Cooooo0_l0001Sooooo`;o0000Q?ooool2o`00027ooooo000Nooooo`03o`000?oooooooooo
02Kooooo0_l0000;ooooo`;o00001?ooool2o`0006?ooooo0_l00006ooooo`;o0000O?ooool2o`00
027ooooo000Nooooo`03o`000?oooooooooo0:Kooooo0_l0002Oooooo`007_ooool00ol0003ooooo
ooooo`08ooooo`;o0000;oooool2o`000?oooooo3Oooool001kooooo00?o0000ooooooooool02?oo
ool2o`00027ooooo0_l0000<ooooo`;o0000ooooool=ooooo`007_ooool2o`0002cooooo0_l0000V
ooooo`;o0000l_ooool001kooooo00?o0000ooooooooool0Doooool2o`0005?ooooo0_l0002Moooo
o`007_ooool00ol0003oooooooooo`0eooooo`;o0000LOooool2o`0009gooooo000Nooooo`03o`00
0?oooooooooo03Gooooo0_l0000hooooo`;o0000:Oooool2o`000:_ooooo000Nooooo`03o`000?oo
oooooooo05_ooooo0_l0000Booooo`;o0000:Oooool2o`000:_ooooo000Nooooo`03o`000?oooooo
oooo05_ooooo0_l0001:ooooo`;o0000W_ooool001kooooo00?o0000ooooooooool0Yoooool2o`00
01Gooooo0_l00027ooooo`007_ooool00ol0003oooooooooo`0kooooo`;o0000EOooool2o`0002[o
oooo0_l00027ooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o00009?ooool2o`0005Gooooo
0_l0002cooooo`007_ooool00ol0003oooooooooo`0Eooooo`Co0000ooooool_ooooo`007_ooool0
0ol0003oooooooooo`0?ooooo`;o00001_ooool2o`000?oooooo;oooool001kooooo00?o0000oooo
ooooool03oooool2o`0002;ooooo0_l00026ooooo`;o0000R_ooool001kooooo00?o0000oooooooo
ool03_ooool2o`0002?ooooo0_l00026ooooo`;o0000R_ooool001kooooo00?o0000ooooooooool0
3_ooool2o`000?oooooo>?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool09Oooool2o`0003Oooooo0_l00007ooooo`;o0000
g_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Q
onk^k_ooooooA4A400Kooooo00?o0000ooooooooool09Oooool2o`0002gooooo0_l00008ooooo`;o
00001oooool2o`000=kooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000Boooool2o`0000Oooooo0_l0000?ooooo`;o0000h?ooool000?ooooo
00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000oooooooo
ool0Boooool2o`0001Sooooo0_l0003Pooooo`000oooool01Ol0003ooooooooooooooooo000000ko
oooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`1Iooooo`;o0000B?ooool2o`000:;o
oooo0003ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo05Wooooo0ol00017ooooo`;o0000X_ooool000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`1Joooo
o`;o0000joooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`03ooooo`;o0000oooooom3ooooo`007_ooool00ol0
003oooooooooo`03ooooo`;o0000oooooom3ooooo`007_ooool00ol0003oooooooooo`2Vooooo`;o
0000Woooool001kooooo00?o0000ooooooooool0EOooool2o`0001[ooooo0_l0000cooooo`;o0000
Woooool001kooooo00?o0000ooooooooool0EOooool2o`0001[ooooo0_l0003Dooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo06Oooooo0_l0003Noooo
o`007_ooool00ol0003oooooooooo`1Wooooo`;o00006?ooool2o`000<Cooooo000Nooooo`03o`00
0?oooooooooo087ooooo0_l0000@ooooo`;o0000/_ooool001kooooo00?o0000ooooooooool0Tooo
ool2o`000;;ooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0Ooooool2o`000<Kooooo000Nooooo`;o0000P?ooool2o`000<Kooooo000Nooooo`03o`00
0?oooooooooo07Kooooo0_l0003?ooooo`007_ooool00ol0003oooooooooo`1_ooooo`;o00001Ooo
ool2o`000<oooooo000Nooooo`03o`000?oooooooooo04;ooooo0_l0000[ooooo`;o0000e_ooool0
01kooooo00?o0000ooooooooool0@_ooool4o`0000Sooooo0_l0003gooooo`007_ooool00ol0003o
ooooooooo`14ooooo`;o00002?ooool2o`000?Oooooo000Nooooo`03o`000?oooooooooo03oooooo
0_l0003oooooo`Oooooo000Nooooo`03o`000?oooooooooo03oooooo0_l0000;ooooo`;o0000nOoo
ool001kooooo00?o0000ooooooooool0C?ooool2o`0000Sooooo0_l0003_ooooo`007_ooool00ol0
003oooooooooo`1Fooooo`;o0000koooool001kooooo00?o0000ooooooooool0D_ooool2o`000??o
oooo000Nooooo`03o`000?oooooooooo05;ooooo0_l00002ooooo`;o00006?ooool2o`000=Gooooo
000Nooooo`03o`000?oooooooooo05Kooooo0_l0000Hooooo`;o0000eOooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`1Uooooo`;o0000h?ooool001ko
oooo00?o0000ooooooooool0Coooool2o`0001Cooooo0_l0003Pooooo`007_ooool2o`00053ooooo
0_l0003fooooo`007_ooool00ol0003oooooooooo`0eooooo`;o0000oooooolAooooo`007_ooool0
0ol0003oooooooooo`0eooooo`;o000000?oooooo`000?l00000ooooool>ooooo`007_ooool00ol0
003oooooooooo`0hooooo`;o0000ooooool>ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0D_oo
ool2o`000??ooooo000Nooooo`03o`000?oooooooooo05;ooooo0_l0003cooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo03?ooooo0_l0003ooooooa?o
oooo000Nooooo`03o`000?oooooooooo03?ooooo0_l0000Booooo`;o0000o_ooool001kooooo00?o
0000ooooooooool0Aoooool2o`0001Cooooo0_l00004ooooo`;o00003Oooool2o`000=?ooooo000N
ooooo`03o`000?oooooooooo05gooooo0_l00004ooooo`;o00003Oooool2o`000=?ooooo000Noooo
o`03o`000?oooooooooo0:7ooooo0_l0002Tooooo`007_ooool00ol0003oooooooooo`1Tooooo`;o
0000>oooool2o`000:Cooooo000Nooooo`03o`000?oooooooooo02;ooooo0_l00010ooooo`;o0000
hOooool001kooooo0_l0000Sooooo`;o0000oooooolTooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo06_ooooo0_l0003Jooooo`007_ooool00ol0003o
ooooooooo`13ooooo`;o00009_ooool2o`000=[ooooo000Nooooo`03o`000?oooooooooo04?ooooo
0_l0001:ooooo`;o0000]_ooool001kooooo00?o0000ooooooooool0Ioooool2o`0002Kooooo0_l0
002fooooo`007_ooool00ol0003oooooooooo`1Wooooo`;o00004_ooool2o`000<[ooooo000Noooo
o`03o`000?oooooooooo02?ooooo0_l0001Fooooo`;o0000b_ooool001kooooo00?o0000oooooooo
ool08oooool2o`0001Sooooo0_l0000Rooooo`;o0000EOooool2o`0008gooooo000Nooooo`03o`00
0?oooooooooo02[ooooo0_l0000Aooooo`;o00008_ooool2o`0005Gooooo0_l0002=ooooo`007_oo
ool00ol0003oooooooooo`0Zooooo`;o0000eOooool2o`0004Cooooo000Nooooo`03o`000?oooooo
oooo0?oooooo0_ooool2o`0003;ooooo0_l0000@ooooo`007_ooool00ol0003oooooooooo`0Coooo
o`;o0000F_ooool2o`000<Cooooo0_l0000@ooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o
0000F_ooool2o`0002Gooooo0_l0002_ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0Wooooo`;o
0000KOooool2o`000:oooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Eooooo`;o00004?ooool2o`0000So
oooo0_l0003ooooooaGooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Ko
oooo0ol0000Eooooo`;o00004?ooool2o`0000Sooooo0_l0003ooooooaGooooo0003ooooo`05o`00
0?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo
01Oooooo0_l0000>ooooo`?o00007Oooool2o`000?kooooo0003ooooo`05o`000?oooooooooooooo
ool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo01Oooooo0_l0000?
ooooo`;o00007Oooool2o`0000Sooooo0_l00013ooooo`;o0000[oooool000?ooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0:?ooool2
o`0002Oooooo0_l00013ooooo`;o0000[oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<
ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo073ooooo0_l0003Eooooo`007_ooool00ol0003o
ooooooooo`06ooooo`;o0000J?ooool2o`0000Gooooo0_l0003>ooooo`007_ooool00ol0003ooooo
ooooo`06ooooo`;o0000Koooool2o`000<kooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l0
0021ooooo`;o0000[?ooool001kooooo00?o0000ooooooooool05_ooool2o`00023ooooo0_l0000a
ooooo`;o0000;?ooool2o`000:cooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l0000Coooo
o`;o00005_ooool2o`00037ooooo0_l0000Oooooo`;o0000^Oooool001kooooo00?o0000oooooooo
ool02_ooool3o`0001?ooooo0_l0001Zooooo`;o0000^Oooool001kooooo00?o0000ooooooooool0
2_ooool2o`0002;ooooo0_l0003ooooooaSooooo000Nooooo`03o`000?oooooooooo02kooooo0_l0
000iooooo`;o0000g?ooool001kooooo00Co0000oooooooooooooooo0_l0001Pooooo`?o00000ooo
ool2o`000=cooooo000Nooooo`04o`000?ooooooooooooooo`;o00003Oooool2o`00057ooooo0ol0
000;ooooo`;o00004_ooool2o`000003ooooool0003o000000Oooooo0_l00028ooooo`;o0000:_oo
ool001kooooo0_l0000Aooooo`;o000000?oooooo`000?l000000_ooool2o`0005Sooooo0_l0000B
ooooo`;o000000?oooooo`000?l000001oooool2o`0000Cooooo0_l00022ooooo`;o0000:_ooool0
01kooooo00?o0000ooooooooool01?ooool3o`0000cooooo0_l00002ooooo`;o0000O_ooool2o`00
0:kooooo000Nooooo`03o`000?oooooooooo00Cooooo0ol0000cooooo`;o00000_ooool2o`0003Go
oooo0_l0003@ooooo`007_ooool00ol0003oooooooooo`0jooooo`;o00000_ooool2o`0000?ooooo
0_l0000`ooooo`;o0000d?ooool001kooooo00?o0000ooooooooool0@oooool2o`000003ooooool0
003o0000047ooooo0_l0002looooo`007_ooool00ol0003oooooooooo`13ooooo`;o000000?ooooo
o`000?l00000@Oooool2o`000;cooooo000Nooooo`03o`000?oooooooooo06gooooo0_l0000Boooo
o`;o0000a?ooool001kooooo00?o0000ooooooooool0:_ooool2o`00047ooooo0_l0000=ooooo`;o
00000oooool2o`000<Cooooo000Nooooo`03o`000?oooooooooo02[ooooo0_l00013ooooo`;o0000
2oooool2o`000<Wooooo000Nooooo`03o`000?oooooooooo06cooooo0_l000000ooooooo0000o`00
000Dooooo`;o00000oooool2o`000;_ooooo000Nooooo`03o`000?oooooooooo06cooooo0_l0000G
ooooo`;o00000oooool2o`000;_ooooo000Nooooo`03o`000?oooooooooo04Kooooo0_l0003ooooo
o`007_ooool00ol0003oooooooooo`0looooo`;o00002?ooool2o`000?oooooo000Nooooo`03o`00
0?oooooooooo00[ooooo0_l0000`ooooo`;o00007?ooool2o`0002Gooooo0_l00034ooooo`007_oo
ool00ol0003oooooooooo`0:ooooo`;o0000C_ooool2o`0002Gooooo0_l00034ooooo`007_ooool0
0ol0003oooooooooo`1]ooooo`;o00008_ooool2o`000;Cooooo000Nooooo`;o0000K_ooool2o`00
02;ooooo0_l0002dooooo`007_ooool00ol0003oooooooooo`1Yooooo`;o0000g?ooool001kooooo
00?o0000ooooooooool0JOooool2o`000=cooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
obCooooo0_l0000Rooooo`007_ooool00ol0003oooooooooo`1Kooooo`;o0000a_ooool2o`0002;o
oooo000Nooooo`03o`000?oooooooooo05_ooooo0_l0000Kooooo`;o00002oooool2o`000<3ooooo
000Nooooo`03o`000?oooooooooo07Sooooo0_l0000;ooooo`;o0000`?ooool001kooooo00?o0000
ooooooooool04?ooool2o`0001Kooooo0_l0003ooooooakooooo000Nooooo`03o`000?oooooooooo
00;ooooo0_l0000<ooooo`;o00005_ooool2o`00017ooooo0_l0001Hooooo`;o0000/?ooool001ko
oooo00?o0000ooooooooool00_ooool2o`0003Oooooo0_l0000Fooooo`;o0000@?ooool2o`000;3o
oooo000Nooooo`03o`000?oooooooooo05?ooooo1?l0000Qooooo`;o00007oooool2o`000:cooooo
000Nooooo`03o`000?oooooooooo05Gooooo0_l0000Qooooo`;o00007oooool2o`000:cooooo000N
ooooo`03o`000?oooooooooo00;o0000=Oooool2o`000?oooooo3oooool001kooooo00?o0000oooo
ooooool00_l0000eooooo`;o0000Hoooool2o`000:Wooooo000Nooooo`;o0000WOooool2o`000:Wo
oooo000Nooooo`03o`000?oooooooooo02Gooooo0_l0000Zooooo`;o0000m?ooool001kooooo00?o
0000ooooooooool07_ooool2o`0000Gooooo0_l0000Zooooo`;o0000m?ooool001kooooo00?o0000
ooooooooool07_ooool2o`00083ooooo0_l0002Uooooo`007_ooool00ol0003oooooooooo`2Poooo
o`;o0000YOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`1Sooooo`;o0000h_ooool001kooooo00?o0000ooooooooool07Oooool2o`0004Cooooo0_l0
003Rooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o0000Uoooool2o`0008oooooo000Noooo
o`03o`000?oooooooooo0:Sooooo0_l0000<ooooo`;o0000Soooool001kooooo00?o0000oooooooo
ool0OOooool2o`0001Cooooo0_l0000Cooooo`;o0000WOooool001kooooo00?o0000ooooooooool0
9oooool2o`0005Cooooo0_l0000Dooooo`;o0000/_ooool001kooooo00?o0000ooooooooool08_oo
ool2o`0000?ooooo0_l00022ooooo`;o0000V_ooool001kooooo00?o0000ooooooooool08_ooool2
o`0001oooooo0_l0001Fooooo`;o00003Oooool3o`0009[ooooo0003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oo
oooooooo04?ooooo0_l0001Fooooo`;o00003Oooool2o`0009_ooooo0003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`00
0?ooooooooooooooool000001_ooool3o`0000?ooooo0_l0000Fooooo`;o0000T?ooool2o`0009So
oooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q
00Kooooo00?o0000ooooooooool00oooool2o`0001Kooooo0_l00029ooooo`;o00001?ooool3o`00
09Sooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413o
c<c<00Kooooo00?o0000ooooooooool0W?ooool2o`0000Sooooo0_l00002ooooo`Co0000VOooool0
00?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00Co0000
oooooooooooooooo0_l0002>ooooo`;o00002Oooool2o`0000cooooo0_l0000booooo`;o0000@_oo
ool2o`0002?ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRH
V008ooooo`04o`000?ooooooooooooooo`;o00003oooool2o`0007gooooo0_l0001;ooooo`;o0000
@_ooool2o`0002?ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4
o`000?l@4106ooooo`03o`000?oooooooooo01;ooooo0_l00017ooooo`;o0000=_ooool2o`000;;o
oooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0001Fooooo`;o00006_ooool2o`0001[ooooo
0_l0002booooo`007_ooool00ol0003oooooooooo`03ooooo`;o0000L_ooool2o`000<kooooo000N
ooooo`03o`000?oooooooooo01gooooo0_l0001Oooooo`;o00008oooool2o`000:;ooooo000Noooo
o`03o`000?oooooooooo01Kooooo0_l00005ooooo`;o0000DOooool2o`0000Gooooo0_l00005oooo
o`;o00005?ooool2o`0000gooooo0_l0002;ooooo`;o00005Oooool001kooooo00?o0000oooooooo
ool05_ooool2o`0005Sooooo0_l00003ooooo`Co00006oooool2o`0009[ooooo0_l0000Eooooo`00
7_ooool00ol0003oooooooooo`0Fooooo`;o0000GOooool2o`0000oooooo0_l00004ooooo`;o0000
7Oooool2o`0009[ooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0000Aooooo`;o0000K_oo
ool2o`0000Cooooo0_l0000Mooooo`;o0000V_ooool001kooooo00?o0000ooooooooool00oooool2
o`00093ooooo0_l0002`ooooo`007_ooool00ol0003oooooooooo`1Xooooo`;o0000:oooool2o`00
0;3ooooo000Nooooo`03o`000?oooooooooo06Sooooo0_l0000Pooooo`Co0000^Oooool001kooooo
00?o0000ooooooooool0MOooool2o`0000?ooooo0_l0000>ooooo`Co00004?ooool2o`000:Oooooo
000Nooooo`;o0000M_ooool2o`0000?ooooo0_l0000>ooooo`?o00004Oooool2o`000:Oooooo000N
ooooo`03o`000?oooooooooo083ooooo0_l00008ooooo`?o00003_ooool2o`000:[ooooo000Noooo
o`03o`000?oooooooooo06Gooooo0_l0000Iooooo`;o00006Oooool2o`000:[ooooo000Nooooo`03
o`000?oooooooooo00Gooooo0_l0001=ooooo`;o00003oooool2o`000:Cooooo0_l0000jooooo`00
7_ooool00ol0003oooooooooo`05ooooo`;o00003?ooool2o`0003oooooo0_l0002eooooo`;o0000
>_ooool001kooooo00?o0000ooooooooool03Oooool2o`0000Cooooo0_l0000`ooooo`;o0000oooo
ool1ooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o0000=_ooool2o`0004_ooooo0_l0002c
ooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o0000P_ooool2o`0000oooooo0_l0002Roooo
o`007_ooool00ol0003oooooooooo`0>ooooo`;o0000B_ooool2o`0000;ooooo0_l00009ooooo`;o
0000>?ooool2o`000:;ooooo000Nooooo`03o`000?oooooooooo04[ooooo0_l0000>ooooo`;o0000
0_ooool2o`0000Cooooo0_l00003ooooo`;o0000g?ooool001kooooo00?o0000ooooooooool04_oo
ool4o`0003Cooooo1?l0000Fooooo`;o0000hOooool001kooooo00?o0000ooooooooool04_ooool4
o`0003Gooooo0ol00002ooooo`;o00005Oooool2o`0001oooooo0_l0002mooooo`007_ooool00ol0
003oooooooooo`0nooooo`;o00003_ooool4o`0000Cooooo0_l0000?ooooo`;o00007Oooool4o`00
00Cooooo0_l0002gooooo`007_ooool00ol0003oooooooooo`02o`0000Oooooo0_l0000Eooooo`;o
00007?ooool2o`0000kooooo0_l00006ooooo`;o00009oooool2o`0000Gooooo0_l00006ooooo`;o
0000]oooool001kooooo0_l000000ooooooo0000o`000005ooooo`Co00005Oooool2o`0001oooooo
0_l0000[ooooo`;o00002oooool2o`0000;ooooo0_l0000Nooooo`;o0000Y_ooool001kooooo0_l0
0008ooooo`;o00003Oooool2o`0002Wooooo0_l00003ooooo`;o00007Oooool2o`0000Oooooo0ol0
00000ooooooo0000o`000007ooooo`;o00002oooool2o`0001Gooooo0_l0002Vooooo`007_ooool2
o`0000Wooooo0_l00002ooooo`;o00002?ooool2o`0001cooooo0_l0000@ooooo`;o00007Oooool2
o`0000Sooooo0_l000000ooooooo0000o`00000Dooooo`;o0000_Oooool001kooooo0ol00008oooo
o`;o00000_ooool2o`0002Kooooo0_l0000@ooooo`;o00008oooool2o`000=[ooooo000Mooooo`Co
00002?ooool2o`0001Oooooo0_l00018ooooo`;o0000e?ooool2o`0000Cooooo000Mooooo`;o0000
1_ooool2o`0000;ooooo0_l0000Gooooo`;o00006Oooool2o`0000?ooooo0_l0000Sooooo`;o0000
d_ooool2o`0000Gooooo0_l00004ooooo`007_ooool00ol0003oooooooooo`04ooooo`;o0000=_oo
ool3o`0000;ooooo0_l0000Gooooo`;o00002_ooool2o`000=;ooooo0_l0000;ooooo`007_ooool0
0ol0003oooooooooo`0Iooooo`;o00008_ooool2o`0001Gooooo0_l00004ooooo`;o0000:_ooool2
o`0000oooooo0_l0002^ooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o00007?ooool3o`00
00oooooo0_l00009ooooo`;o0000<?ooool2o`0000oooooo0_l0002Nooooo`;o00003_ooool001ko
oooo00?o0000ooooooooool01oooool4o`0000;ooooo0_l0000Xooooo`Co00000oooool2o`0000Wo
oooo0_l00002ooooo`;o00001?ooool2o`0000Cooooo0_l0000Dooooo`;o0000`Oooool2o`0000?o
oooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`07ooooo`Co00000_ooool2o`0002[ooooo
0_l00003ooooo`?o00000_ooool2o`0000Kooooo1Ol00003ooooo`Co00000_ooool2o`0001Cooooo
0_l00031ooooo`;o00004oooool001kooooo00?o0000ooooooooool0??ooool2o`000003ooooool0
003o000000;ooooo0_l00006ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o0000
00?oooooo`000?l000001oooool2o`000=[ooooo0_l00008ooooo`007_ooool00ol0003ooooooooo
o`0looooo`;o00002?ooool2o`0000Cooooo1?l000000ooooooo0000o`000005ooooo`;o00001ooo
ool4o`0000Oooooo0_l000000ooooooo0000o`00003<ooooo`;o00002?ooool001kooooo00?o0000
ooooooooool02?ooool2o`0003Oooooo0_l00003ooooo`;o00001?ooool4o`000003ooooool0003o
0000013ooooo0_l00005ooooo`Co000000?oooooo`000?l000005oooool2o`000:?ooooo0_l0000:
ooooo`;o00003?ooool001kooooo00?o0000ooooooooool02?ooool3o`0002kooooo0_l00006oooo
o`;o00002_ooool6o`00013ooooo0_l00005ooooo`;o00007?ooool2o`000:?ooooo0_l0000:oooo
o`;o00003?ooool001kooooo00?o0000ooooooooool02Oooool2o`0002kooooo0_l0000Booooo`Go
00000_ooool4o`0000_ooooo0_l0000Sooooo`;o0000_Oooool001kooooo00?o0000ooooooooool0
1Oooool2o`000003ooooool0003o000001Cooooo0_l0000Eooooo`?o00005Oooool<o`0000Wooooo
0_l0000Tooooo`;o0000_Oooool001kooooo00?o0000ooooooooool01Oooool2o`000003ooooool0
003o000001Cooooo0_l0000Eooooo`?o00005Oooool8o`000003ooooool0003o000000;o00002?oo
ool2o`000>?ooooo000Nooooo`;o0000=oooool2o`00013ooooo0_l00003ooooo`So000000?ooooo
o`000?l000000_l0000Qooooo`;o0000b_ooool001kooooo0_l0000[ooooo`;o00001_ooool2o`00
01Cooooo0_l00003ooooo`Co000000Goooooo`000?l0003o0000ooooo`02o`0002?ooooo0_l00032
ooooo`;o00001_ooool001kooooo00?o0000ooooooooool0:_ooool2o`0000Kooooo0_l0000Ioooo
o`_o00001?ooool2o`0001Oooooo0_l00038ooooo`;o00001_ooool001kooooo00?o0000oooooooo
ool0;oooool2o`0000oooooo1?l00005ooooo`;o00000_ooool6o`000004ooooool0003o0000oooo
o`So00005_ooool2o`0001Cooooo0_l0002jooooo`007_ooool00ol0003oooooooooo`0_ooooo`;o
00003oooool4o`0000Gooooo0_l00005ooooo`?o00001?ooool8o`0000Gooooo0_l00004ooooo`;o
00000oooool2o`0001[ooooo0_l0002Kooooo`;o00007Oooool001kooooo00?o0000ooooooooool0
8?ooool2o`0001[ooooo0_l0000>ooooo`;o00002Oooool3o`000003ooooool0003o000000Oooooo
0_l00004ooooo`;o00000oooool2o`0002;ooooo0_l0001Rooooo`;o0000;oooool2o`0001Gooooo
0_l00006ooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o00006_ooool2o`000003ooooool0
003o000000_ooooo0_l00008ooooo`Co000000Coooooo`000?l0003ooooo0_l0000;ooooo`;o0000
00?oooooo`000?l000000ol0000Pooooo`;o0000H_ooool2o`0004Kooooo0_l00006ooooo`007_oo
ool00ol0003oooooooooo`03ooooo`;o0000>_ooool2o`00013ooooo0_l00003ooooo`;o00001Ooo
ool3o`0000?ooooo1?l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l0003Dooooo`007_oo
ool00ol0003oooooooooo`03ooooo`;o00006Oooool2o`0001?ooooo0_l0000Looooo`;o00001?oo
ool2o`0000;ooooo1?l00004ooooo`Co00001oooool2o`000=Oooooo000Nooooo`03o`000?oooooo
oooo01kooooo0_l0000Cooooo`;o00001Oooool2o`0001_ooooo0_l00002ooooo`;o00001Oooool3
o`000>;ooooo000Nooooo`03o`000?oooooooooo03[ooooo0_l0000Mooooo`;o00000oooool2o`00
00;ooooo0ol000000ooooooo0000o`00000Oooooo`;o0000__ooool001kooooo00?o0000oooooooo
ool0=Oooool2o`0001Oooooo0_l00009ooooo`;o00000oooool2o`0000Kooooo1?l0000Mooooo`;o
00005Oooool2o`000:Oooooo000Nooooo`03o`000?oooooooooo03Gooooo0ol0000Fooooo`;o0000
1oooool2o`0000Kooooo1_l00003ooooo`?o00007oooool2o`0001;ooooo0_l0002Wooooo`007_oo
ool00ol0003oooooooooo`0fooooo`;o000000?oooooo`000?l000000_l0000Jooooo`;o00000ooo
ool2o`000003ooooool0003o000000Co00001?ooool2o`0000;ooooo0_l0000:ooooo`;o00003_oo
ool3o`000;_ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Go
c<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo037ooooo0_l00004ooooo`Ko0000
1_ooool2o`0000Sooooo0_l0000=ooooo`;o000000?oooooo`000?l000000_l00006ooooo`?o0000
00?oooooo`000?l000002_ooool3o`0000gooooo0_l00003ooooo`;o0000]oooool000?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Ko
oooo00?o0000ooooooooool09_ooool2o`0000Wooooo0_l00004ooooo`;o000000?oooooo`000?l0
00001oooool2o`0000Sooooo0_l0000@ooooo`Go000000Goooooo`000?l0003o0000ooooo`03o`00
00kooooo0_l0000Booooo`;o0000]oooool000?ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000001_ooool3o`0002Kooooo0_l00008ooooo`?o00001_ooool5
o`0000Kooooo0_l0000@ooooo`;o00001Oooool2o`0000?ooooo1_l00002ooooo`;o0000foooool0
00?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_oo
ool00ol0003oooooooooo`0Booooo`;o00004_ooool3o`0000Oooooo0ol00006ooooo`Go00001_oo
ool2o`0000gooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000001?oo
ool4o`0002Sooooo0_l0000cooooo`;o0000POooool000?ooooo00Go0000ooooooooooooooooo`00
000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`0Booooo`;o0000
3Oooool2o`0000?ooooo0ol0000Hooooo`?o000000?oooooo`000?l000000oooool2o`0000?ooooo
0_l00002ooooo`;o00001Oooool2o`000003ooooool0003o000000;o00000_ooool4o`000003oooo
ool0003o000000?ooooo0ol0000Oooooo`;o0000<oooool2o`00087ooooo0003ooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000oooooooo
ool04Oooool2o`0000kooooo1?l0000Looooo`?o000000Coooooo`000?l0003ooooo1?l00003oooo
o`;o00001oooool2o`0000Gooooo0_l00002ooooo`;o00000_ooool5o`000004ooooool0003o0000
o`000:[ooooo0_l0000[ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000
okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo017ooooo0ol0000?ooooo`;o00006?oo
ool2o`0000;ooooo0_l00004ooooo`?o00001?ooool2o`0000Sooooo0_l00009ooooo`Ko000000Go
ooooo`000?l0003o0000ooooo`02o`000:Oooooo0_l000000ooooooo0000o`00000[ooooo`000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03
o`000?oooooooooo01;ooooo0_l0000Jooooo`;o00003Oooool2o`0000;ooooo0_l00004ooooo`;o
00001Oooool2o`0000[ooooo0_l000001?oooooo0000o`000?ooool3o`000004ooooool0003o0000
o`0000Cooooo0_l000000ooooooo0000o`00002Wooooo`;o0000;_ooool001kooooo00?o0000oooo
ooooool0;_ooool2o`0000Wooooo0_l0000Nooooo`?o000000?oooooo`000?l000001?l000001?oo
oooo0000o`000?ooool2o`0000Gooooo1?l00006ooooo`;o0000cOooool001kooooo00?o0000oooo
ooooool04oooool2o`0001[ooooo0_l00004ooooo`;o00000_ooool2o`0000?ooooo0_l0000>oooo
o`;o00002Oooool2o`0000;ooooo1_l00003ooooo`?o00001_ooool3o`0000Cooooo1?l0003=oooo
o`007_ooool00ol0003oooooooooo`0=ooooo`;o00001?ooool2o`0001[ooooo0_l00004ooooo`;o
00000oooool2o`0000;ooooo0_l00006ooooo`;o00001_ooool2o`0000Wooooo0_l00002ooooo`So
000000Coooooo`000?l0003o00000oooool2o`0000Sooooo0_l0000Jooooo`;o0000/oooool001ko
oooo00?o0000ooooooooool03Oooool2o`0002_ooooo0_l0000:ooooo`;o00004Oooool<o`000003
ooooool0003o000000;o00000_ooool2o`0002Cooooo0_l0002cooooo`007_ooool00ol0003ooooo
ooooo`0Cooooo`;o00009Oooool2o`0001Gooooo0_l00006ooooo`Co000000?oooooo`000?l00000
1Oooool5o`00017ooooo0_l000000ooooooo0000o`000037ooooo`007_ooool00ol0003ooooooooo
o`07ooooo`;o00002_ooool2o`0002gooooo1?l000001?oooooo0000o`000?l00003ooooo`;o0000
0_ooool2o`0000Kooooo0_l00003ooooo`;o00001Oooool5o`00017ooooo0_l000000ooooooo0000
o`000037ooooo`007_ooool00ol0003oooooooooo`07ooooo`;o0000;Oooool2o`0000Kooooo0_l0
00000ooooooo0000o`000003o`000004ooooool0003o0000o`0000?ooooo0_l000000ooooooo0000
o`000003ooooo`?o00002Oooool2o`0000Oooooo0_l000000ooooooo0000o`00000<ooooo`?o0000
bOooool001kooooo00?o0000ooooooooool0<oooool2o`000003ooooool0003o000000Kooooo0_l0
00001?oooooo0000o`000?l00005ooooo`;o00001Oooool2o`0000?ooooo1Ol00004ooooo`Oo0000
1Oooool5o`0000cooooo1?l00038ooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o00004Ooo
ool2o`0000cooooo0_l00002ooooo`;o00000_ooool2o`0000Sooooo1ol000000ooooooo0000o`00
0005o`000003ooooool0003o000000Kooooo0ol00006ooooo`;o00001oooool2o`000;cooooo0_l0
000:ooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o00007_ooool2o`0000?ooooo0_l00005
ooooo`;o00000oooool5o`000004ooooool0003o0000ooooo`Co000000?oooooo`000?l000000_oo
ool2o`000003ooooool0003o000000?ooooo0ol00006ooooo`;o00000oooool2o`0000Wooooo0_l0
002eooooo`;o00002_ooool001kooooo00?o0000ooooooooool08?ooool2o`0001_ooooo0_l00000
0ooooooo0000o`00000:ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000003
o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000001?ooool2
o`0000;ooooo0_l00004ooooo`Go00002Oooool2o`000<7ooooo000Nooooo`;o00007Oooool2o`00
00;ooooo0_l0000Kooooo`;o00001_ooool2o`0000Sooooo0_l00003ooooo`Go00000oooool2o`00
00Oooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Cooooo1?l00002oooo
o`;o0000Moooool2o`00053ooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l00004ooooo`;o
00005_ooool2o`0000Oooooo0_l00006ooooo`;o00000_ooool2o`0000Gooooo0_l00002ooooo`;o
000000?oooooo`000?l000001Ol00003ooooo`;o00000_ooool2o`0000;ooooo0_l00002ooooo`;o
00002Oooool2o`0000;ooooo0_l0001gooooo`;o00008oooool2o`0002_ooooo000Nooooo`03o`00
0?oooooooooo01Kooooo0_l0000Looooo`;o00001oooool2o`0000[ooooo1?l00003ooooo`;o0000
00?oooooo`000?l000000oooool6o`0000?ooooo0_l00008ooooo`Co00000_ooool2o`0001;ooooo
0_l0002Cooooo`;o0000:oooool001kooooo00?o0000ooooooooool0<oooool2o`0001Kooooo0_l0
0006ooooo`;o00001oooool8o`0000Gooooo1Ol00003ooooo`;o00004_ooool2o`0000;ooooo0_l0
000>ooooo`;o0000[?ooool001kooooo00?o0000ooooooooool0<oooool2o`0000[ooooo0_l00002
ooooo`;o000000?oooooo`000?l000000_ooool3o`0000;ooooo0_l00003ooooo`;o00002?ooool6
o`0000Gooooo0_l000000ooooooo0000o`000003ooooo`Co00001?ooool2o`0000kooooo0_l0000>
ooooo`;o0000[?ooool001kooooo00?o0000ooooooooool07Oooool2o`00023ooooo0_l00002oooo
o`Go000000?oooooo`000?l000000_l00002ooooo`;o00000oooool2o`0000;ooooo1?l00004oooo
o`;o00002Oooool2o`000003ooooool0003o000000;ooooo2Ol0000Uooooo`;o0000YOooool001ko
oooo00?o0000ooooooooool07Oooool2o`0002Gooooo2?l00003ooooo`;o00000oooool2o`0000;o
oooo1?l00009ooooo`;o00001?ooool2o`000003ooooool0003o000000co00009?ooool2o`000:Go
oooo000Nooooo`03o`000?oooooooooo02kooooo0_l0000<ooooo`;o00002?ooool6o`0000?ooooo
0ol00002ooooo`;o00000_ooool3o`0000[ooooo0_l00004ooooo`;o00000oooool5o`000003oooo
ool0003o000000Co0000:_ooool2o`0009oooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0
000Hooooo`;o00003?ooool2o`000003ooooool0003o000000?o000000?oooooo`000?l000001Ol0
0003ooooo`?o00000_ooool2o`0000Sooooo0_l00009ooooo`;o00000oooool2o`0003Kooooo0_l0
002Oooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o00000_ooool2o`0002Oooooo1ol00000
1?oooooo0000o`000?ooool3o`0000Kooooo0_l000000ooooooo0000o`000008ooooo`;o00002Ooo
ool2o`0000?ooooo0_l0003Gooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o0000:_ooool6
o`0000?ooooo0_l000000ooooooo0000o`000007ooooo`;o000000?oooooo`000?l000001_ooool4
o`0002oooooo0_l0002fooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o00006_ooool6o`00
0003ooooool0003o000000;o00001oooool2o`0000Cooooo0ol00005ooooo`Co00001_ooool2o`00
0003ooooool0003o000002Cooooo0_l0000Cooooo`Go0000UOooool2o`0000Oooooo000Nooooo`03
o`000?oooooooooo023ooooo0_l0000Looooo`Co000000Coooooo`000?l0003o00002?ooool2o`00
00Gooooo0_l00005ooooo`;o00001_ooool7o`0003Wooooo1Ol0002Eooooo`;o00001oooool001ko
oooo00?o0000ooooooooool0>_ooool2o`000003ooooool0003o000000?o00000_ooool3o`0000co
oooo0_l0000?ooooo`;o000000?oooooo`000?l00000g_ooool001kooooo00?o0000ooooooooool0
>_ooool8o`0000?ooooo0_l0000<ooooo`;o00001_ooool2o`0000Oooooo0_l0000Oooooo`;o0000
`?ooool001kooooo00?o0000ooooooooool02oooool2o`0000_ooooo0_l0000Qooooo`Ko00006Ooo
ool3o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0001_ooooo0_l00019ooooo`?o0000M?oo
ool001kooooo0_l0000<ooooo`;o00002oooool4o`0002;ooooo1?l00004ooooo`;o00004_ooool2
o`0000?ooooo0_l00007ooooo`;o0000I_ooool3o`0007Cooooo000Nooooo`03o`000?oooooooooo
01Sooooo1?l0000Oooooo`Oo00001?ooool2o`0000Cooooo0_l0000kooooo`;o0000_?ooool001ko
oooo00?o0000ooooooooool08oooool2o`0001Kooooo1_l0000;ooooo`;o00001?ooool2o`0000[o
oooo0_l0000Yooooo`;o0000_?ooool001kooooo00?o0000ooooooooool08oooool2o`0001[ooooo
0_l0000Aooooo`Co00002?ooool2o`0000Cooooo0_l0001kooooo`;o0000I?ooool001kooooo00?o
0000ooooooooool0?_ooool6o`00013ooooo0_l00008ooooo`;o00001?ooool2o`0007_ooooo0_l0
001Tooooo`007_ooool00ol0003oooooooooo`0nooooo`Ko00000_ooool2o`0000Oooooo0_l00002
ooooo`;o00003oooool2o`000>7ooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l0000Voooo
o`;o00000_ooool3o`0000Oooooo0_l00002ooooo`;o0000Yoooool2o`0004Wooooo000Nooooo`03
o`000?oooooooooo01?ooooo0_l00004ooooo`;o00009oooool2o`000005ooooool0003o0000o`00
0?ooool00_l00003ooooo`;o00000_ooool2o`0007?ooooo0_l0000@ooooo`;o00008Oooool2o`00
04Wooooo000Nooooo`03o`000?oooooooooo01?ooooo0_l0000]ooooo`Ko000000?oooooo`000?l0
00000oooool2o`0000;ooooo0_l00009ooooo`;o00009Oooool2o`00047ooooo0_l0000@ooooo`;o
0000K?ooool001kooooo00?o0000ooooooooool01oooool2o`0003[ooooo1?l00004ooooo`;o0000
2Oooool2o`0000Gooooo0_l0000Uooooo`;o0000Aoooool2o`00047ooooo0_l0000eooooo`007_oo
ool00ol0003oooooooooo`07ooooo`;o00003oooool2o`0002Wooooo0_l00002ooooo`;o00000_oo
ool2o`0000;ooooo0ol00004ooooo`;o00001oooool2o`0004Wooooo0_l0000Qooooo`;o0000@Ooo
ool2o`0003Gooooo000Nooooo`03o`000?oooooooooo01Sooooo0_l0000Yooooo`;o00000_ooool2
o`0000Kooooo0ol0000=ooooo`;o0000BOooool2o`0001cooooo0_l0001Wooooo`;o00005?ooool0
01kooooo00?o0000ooooooooool05?ooool2o`0002gooooo0_l0001Fooooo`;o00008_ooool2o`00
00Oooooo0_l0001Wooooo`;o00005?ooool001kooooo00?o0000ooooooooool05?ooool2o`0002go
oooo0_l00004ooooo`;o00006Oooool2o`0003Gooooo0_l0000Rooooo`;o0000Q_ooool001kooooo
00?o0000ooooooooool05?ooool2o`0003?ooooo0_l00008ooooo`;o00003oooool2o`000>7ooooo
000Nooooo`03o`000?oooooooooo01Cooooo0_l0000dooooo`;o00001oooool6o`000003ooooool0
003o00000>_ooooo000Nooooo`;o0000Boooool3o`0000Sooooo1?l000000ooooooo0000o`00000<
ooooo`;o0000AOooool2o`0009Kooooo000Nooooo`03o`000?oooooooooo04_ooooo0_l00008oooo
o`;o00004Oooool2o`00047ooooo0_l00002ooooo`;o0000U_ooool001kooooo00?o0000oooooooo
ool0H_ooool2o`0002Cooooo0_l0000Qooooo`;o00004?ooool3o`0008Oooooo000Nooooo`03o`00
0?oooooooooo00Sooooo0_l00004ooooo`;o0000COooool2o`0000?ooooo0_l00005ooooo`;o0000
7Oooool2o`00027ooooo0_l0000@ooooo`?o00000_ooool2o`0008?ooooo000Nooooo`03o`000?oo
oooooooo00Sooooo0_l00004ooooo`;o0000COooool2o`0000[ooooo0_l0000Xooooo`;o00005ooo
ool2o`0001Cooooo0_l00023ooooo`007_ooool00ol0003oooooooooo`04ooooo`;o00003_ooool2
o`0004oooooo0_l0000/ooooo`;o00005oooool2o`0001cooooo0_l0001kooooo`007_ooool00ol0
003oooooooooo`04ooooo`;o00003_ooool2o`0004;ooooo0_l0000;ooooo`;o0000Hoooool2o`00
07_ooooo000Nooooo`03o`000?oooooooooo00?ooooo0ol0001Booooo`;o0000kOooool001kooooo
00?o0000ooooooooool00oooool3o`0002;ooooo0_l0000looooo`;o0000<Oooool2o`000:cooooo
000Nooooo`03o`000?oooooooooo02Sooooo0_l0000jooooo`Co0000<Oooool2o`0000[ooooo0_l0
002Pooooo`007_ooool00ol0003oooooooooo`0^ooooo`;o00006_ooool2o`0001Sooooo0_l0000m
ooooo`Co0000X?ooool001kooooo00?o0000ooooooooool0;_ooool2o`0001[ooooo0_l0001:oooo
o`;o00002oooool2o`000:;ooooo000Nooooo`03o`000?oooooooooo07kooooo0_l0000Fooooo`;o
0000??ooool2o`00077ooooo000Nooooo`03o`000?oooooooooo00Gooooo0_l0000<ooooo`;o0000
Doooool2o`0001Cooooo0_l0001Dooooo`;o0000LOooool001Cooooo1?l000000ol@413ooooooooo
o`03ooooo`03o`000?oooooooooo00Gooooo0_l0000<ooooo`;o00002?ooool2o`00017ooooo0_l0
000fooooo`;o0000BOooool2o`0009;ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool07Oooool2o`00017ooooo0_l0001Rooooo`;o00004Oooool2o`000003ooooool0003o
000000Oooooo0_l0002Booooo`005_ooool00ol0003oooooooooo`05ooooo`?o00006Oooool2o`00
03gooooo0_l0000cooooo`;o00001Oooool2o`00017ooooo0_l000000ooooooo0000o`00002Koooo
o`005_ooool00ol0003oooooooooo`0Qooooo`;o0000?Oooool2o`0003?ooooo0_l0002hooooo`00
5_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?oo
ool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005?ooool00omEEEGoIVIVo`00003ooooo
oe;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.35471 .8029 Mdot
.45153 .89559 Mdot
.28636 .75421 Mdot
.39055 .84756 Mdot
.22717 .74945 Mdot
.27464 .8808 Mdot
.46656 .51307 Mdot
.24971 .75461 Mdot
.28059 .90872 Mdot
.08971 .99037 Mdot
.23623 .00829 Mdot
.17062 .93734 Mdot
.2563 .74084 Mdot
.56211 .89138 Mdot
.30956 .85206 Mdot
.49344 .08796 Mdot
.41244 .25366 Mdot
.2568 .71682 Mdot
.33146 .7829 Mdot
.37872 .89442 Mdot
.16602 .22046 Mdot
.22722 .92559 Mdot
.14993 .78901 Mdot
.33255 .62866 Mdot
.30714 .89289 Mdot
.24136 .78699 Mdot
.31298 .87416 Mdot
.48128 .03691 Mdot
.22748 .0032 Mdot
.27405 .93093 Mdot
.29659 .73928 Mdot
.29677 .85586 Mdot
.23418 .9428 Mdot
.99775 .73246 Mdot
.07563 .87985 Mdot
.36867 .87047 Mdot
.56587 .87629 Mdot
.19796 .34309 Mdot
.20174 .82167 Mdot
.32256 .85622 Mdot
.30353 .75218 Mdot
.14386 .89843 Mdot
.30424 .85952 Mdot
.30458 .31581 Mdot
.55178 .63171 Mdot
.13092 .90397 Mdot
.9045 .56846 Mdot
.18649 .72938 Mdot
.34371 .87735 Mdot
.21504 .97788 Mdot
.21892 .83759 Mdot
.14348 .7829 Mdot
.22988 .73979 Mdot
.35829 .86395 Mdot
.21026 .72643 Mdot
.15034 .34688 Mdot
.56901 .8847 Mdot
.2577 .73539 Mdot
.31431 .87429 Mdot
.30012 .8242 Mdot
.36755 .84748 Mdot
.23869 .77592 Mdot
.47265 .50196 Mdot
.29829 .90397 Mdot
.31286 .78191 Mdot
.24019 .90786 Mdot
.23907 .745 Mdot
.31376 .87485 Mdot
.27886 .87684 Mdot
.01517 .87166 Mdot
.041 .42551 Mdot
.31212 .96165 Mdot
.10066 .76758 Mdot
.24035 .41701 Mdot
.18051 .9472 Mdot
.49275 .87246 Mdot
.34953 .65201 Mdot
.18049 .31673 Mdot
.30437 .87119 Mdot
.41716 .81923 Mdot
.08461 .73315 Mdot
.08791 .57597 Mdot
.28227 .31452 Mdot
.24129 .76298 Mdot
.5199 .57656 Mdot
.01649 .40884 Mdot
.24756 .75963 Mdot
.36148 .87091 Mdot
.29172 .85971 Mdot
.3151 .90747 Mdot
.34797 .92503 Mdot
.1818 .91695 Mdot
.22421 .03029 Mdot
.06066 .37256 Mdot
.3001 .78918 Mdot
.09397 .73872 Mdot
.39885 .4293 Mdot
.11144 .82845 Mdot
.2798 .87363 Mdot
.04786 .00509 Mdot
.30315 .80482 Mdot
.22606 .79595 Mdot
.37638 .77245 Mdot
.56187 .97003 Mdot
.39672 .91497 Mdot
.15176 .78735 Mdot
.46256 .12769 Mdot
.4923 .09387 Mdot
.18479 .74817 Mdot
.2768 .39911 Mdot
.5566 .89536 Mdot
.24911 .2696 Mdot
.3728 .68539 Mdot
.27767 .71645 Mdot
.64069 .17468 Mdot
.14448 .61076 Mdot
.54628 .64055 Mdot
.24872 .75676 Mdot
.25955 .84634 Mdot
.46513 .68118 Mdot
.32414 .88394 Mdot
.20568 .76736 Mdot
.19409 .93968 Mdot
.06697 .38042 Mdot
.36652 .10676 Mdot
.08195 .13684 Mdot
.2065 .90458 Mdot
.33517 .79684 Mdot
.00046 .7636 Mdot
.06756 .78487 Mdot
.11275 .18046 Mdot
.36247 .3331 Mdot
.73773 .0998 Mdot
.21863 .76408 Mdot
.27035 .74887 Mdot
.21818 .67925 Mdot
.14883 .77822 Mdot
.38699 .08583 Mdot
.34276 .74328 Mdot
.25915 .90016 Mdot
.33084 .78205 Mdot
.29523 .90362 Mdot
.21578 .92458 Mdot
.02074 .92742 Mdot
.37028 .3225 Mdot
.16747 .94305 Mdot
.3317 .80283 Mdot
.3148 .82909 Mdot
.52596 .90272 Mdot
.20621 .49196 Mdot
.46566 .79297 Mdot
.21653 .93752 Mdot
.20602 .90406 Mdot
.37392 .90738 Mdot
.31698 .85757 Mdot
.23664 .76019 Mdot
.40923 .1078 Mdot
.91277 .76094 Mdot
.29805 .90042 Mdot
.45807 .1225 Mdot
.3585 .03689 Mdot
.07536 .95765 Mdot
.31207 .39194 Mdot
.20605 .7871 Mdot
.28531 .86247 Mdot
.20565 .75205 Mdot
.31964 .81923 Mdot
.3066 .88149 Mdot
.3093 .414 Mdot
.19553 .76834 Mdot
.21061 .94391 Mdot
.02763 .7284 Mdot
.0855 .92972 Mdot
.42836 .98178 Mdot
.34989 .80786 Mdot
.32668 .08847 Mdot
.17678 .56474 Mdot
.26036 .77317 Mdot
.42565 .46226 Mdot
.13795 .7948 Mdot
.34179 .85298 Mdot
.18296 .94654 Mdot
.31769 .87112 Mdot
.50279 .59872 Mdot
.08797 .6728 Mdot
.30073 .68331 Mdot
.45312 .121 Mdot
.34621 .90726 Mdot
.66076 .97209 Mdot
.0235 .95525 Mdot
.3428 .80597 Mdot
.06834 .37854 Mdot
.34074 .79949 Mdot
.45285 .68698 Mdot
.43701 .66766 Mdot
.32452 .87457 Mdot
.05498 .93579 Mdot
.18091 .95718 Mdot
.27893 .91136 Mdot
.19509 .9437 Mdot
.48438 .46857 Mdot
.60743 .17002 Mdot
.23096 .76513 Mdot
.52157 .6074 Mdot
.30587 .8952 Mdot
.36569 .8705 Mdot
.16502 .56162 Mdot
.34361 .87049 Mdot
.49588 .5677 Mdot
.44379 .01527 Mdot
.18412 .76906 Mdot
.34136 .79011 Mdot
.4541 .80116 Mdot
.97817 .49169 Mdot
.38277 .06811 Mdot
.02663 .42412 Mdot
.32452 .82778 Mdot
.10724 .07241 Mdot
.36654 .10833 Mdot
.23133 .79553 Mdot
.67234 .86137 Mdot
.27269 .82197 Mdot
.28964 .90194 Mdot
.29971 .88696 Mdot
.30387 .86402 Mdot
.3181 .99464 Mdot
.00755 .81869 Mdot
.15122 .74634 Mdot
.14485 .6353 Mdot
.22164 .9212 Mdot
.23203 .77499 Mdot
.29547 .85313 Mdot
.20776 .92702 Mdot
.98735 .67508 Mdot
.02499 .42957 Mdot
.17297 .89848 Mdot
.03481 .80234 Mdot
.28019 .73988 Mdot
.18233 .30888 Mdot
.43432 .98331 Mdot
.31113 .71011 Mdot
.20806 .92813 Mdot
.23639 .80323 Mdot
.37594 .69853 Mdot
.21057 .83571 Mdot
.3621 .6632 Mdot
.26827 .86039 Mdot
.22332 .94658 Mdot
.88969 .95298 Mdot
.29571 .75707 Mdot
.1576 .77065 Mdot
.18421 .74809 Mdot
.80942 .39058 Mdot
.0168 .43751 Mdot
.35898 .16545 Mdot
.25868 .75586 Mdot
.22224 .75219 Mdot
.16588 .29725 Mdot
.07545 .82344 Mdot
.63491 .19661 Mdot
.34757 .80029 Mdot
.30555 .77314 Mdot
.17638 .25807 Mdot
.19696 .38849 Mdot
.20813 .92588 Mdot
.06327 .37555 Mdot
.3159 .69429 Mdot
.47263 .34474 Mdot
.26686 .74915 Mdot
.31562 .86927 Mdot
.28241 .87244 Mdot
.04189 .82122 Mdot
.34108 .86647 Mdot
.27728 .79436 Mdot
.06894 .74059 Mdot
.16423 .75927 Mdot
.35554 .11903 Mdot
.4955 .37313 Mdot
.35769 .87031 Mdot
.25575 .77325 Mdot
.61828 .93043 Mdot
.22585 .9317 Mdot
.1825 .79351 Mdot
.55264 .8509 Mdot
.21743 .7537 Mdot
.29135 .90181 Mdot
.21405 .75718 Mdot
.12576 .10596 Mdot
.28144 .75091 Mdot
.26305 .9069 Mdot
.27917 .80124 Mdot
.25567 .89666 Mdot
.32726 .78093 Mdot
.42806 .74599 Mdot
.39123 .42077 Mdot
.10895 .04086 Mdot
.31534 .77893 Mdot
.43527 .11278 Mdot
.61884 .9841 Mdot
.13613 .54577 Mdot
.13162 .13651 Mdot
.24791 .90702 Mdot
.05013 .9031 Mdot
.25951 .87826 Mdot
.10847 .02725 Mdot
.24571 .71296 Mdot
.31156 .87284 Mdot
.32123 .86915 Mdot
.47779 .5477 Mdot
.5986 .16176 Mdot
.33453 .87847 Mdot
.60449 .01402 Mdot
.23982 .78792 Mdot
.29924 .77957 Mdot
.30718 .84124 Mdot
.36376 .79844 Mdot
.28453 .02031 Mdot
.4041 .90488 Mdot
.23489 .94131 Mdot
.25167 .27269 Mdot
.21778 .80846 Mdot
.21782 .9449 Mdot
.23039 .82528 Mdot
.35706 .92264 Mdot
.28712 .72553 Mdot
.2342 .77138 Mdot
.35714 .87185 Mdot
.3464 .79745 Mdot
.17449 .92922 Mdot
.22823 .78014 Mdot
.36714 .90283 Mdot
.26306 .88985 Mdot
.4802 .41113 Mdot
.54772 .18687 Mdot
.05448 .2241 Mdot
.33237 .32011 Mdot
.942 .92911 Mdot
.31342 .87732 Mdot
.3366 .95689 Mdot
.06412 .3903 Mdot
.28913 .87254 Mdot
.06622 .89617 Mdot
.33535 .78507 Mdot
.27208 .90416 Mdot
.54719 .7616 Mdot
.60321 .89286 Mdot
.31417 .43695 Mdot
.36414 .40895 Mdot
.20966 .29763 Mdot
.25519 .75035 Mdot
.25904 .75836 Mdot
.20612 .74935 Mdot
.01421 .94197 Mdot
.52449 .02364 Mdot
.38752 .49015 Mdot
.35274 .85893 Mdot
.12387 .90295 Mdot
.21652 .79952 Mdot
.26038 .72909 Mdot
.12038 .1769 Mdot
.22119 .9366 Mdot
.03184 .84211 Mdot
.30448 .74605 Mdot
.17441 .77212 Mdot
.27263 .90912 Mdot
.04626 .87928 Mdot
.48437 .72395 Mdot
.83016 .06627 Mdot
.32202 .9358 Mdot
.26545 .91109 Mdot
.37016 .05253 Mdot
.31015 .87103 Mdot
.28637 .76284 Mdot
.24236 .91147 Mdot
.98709 .75228 Mdot
.0515 .04316 Mdot
.55533 .61586 Mdot
.35302 .88075 Mdot
.43363 .71074 Mdot
.26086 .95795 Mdot
.29977 .87166 Mdot
.3916 .85482 Mdot
.17275 .77927 Mdot
.34739 .19414 Mdot
.44736 .06097 Mdot
.4889 .66722 Mdot
.47183 .7744 Mdot
.28067 .33159 Mdot
.31327 .87529 Mdot
.54297 .88749 Mdot
.3295 .77979 Mdot
.25296 .72944 Mdot
.31943 .7953 Mdot
.26277 .73622 Mdot
.24451 .74516 Mdot
.43507 .49139 Mdot
.4768 .27228 Mdot
.14027 .42749 Mdot
.31726 .87607 Mdot
.29789 .73809 Mdot
.28047 .88032 Mdot
.57099 .67013 Mdot
.92516 .80057 Mdot
.23773 .77288 Mdot
.51286 .83527 Mdot
.95789 .78869 Mdot
.2681 .91037 Mdot
.32426 .94165 Mdot
.25483 .90909 Mdot
.20354 .7839 Mdot
.36282 .04692 Mdot
.30689 .89373 Mdot
.36363 .04079 Mdot
.42223 .55618 Mdot
.36244 .89261 Mdot
.22844 .75012 Mdot
.38608 .76202 Mdot
.331 .01356 Mdot
.76059 .80432 Mdot
.3081 .87019 Mdot
.31571 .86673 Mdot
.85456 .07521 Mdot
.14947 .88087 Mdot
.24056 .73071 Mdot
.25081 .74239 Mdot
.59586 .64845 Mdot
.493 .47472 Mdot
.2554 .91534 Mdot
.31467 .97083 Mdot
.48674 .56762 Mdot
.4136 .93642 Mdot
.95878 .70869 Mdot
.60294 .91812 Mdot
.38594 .86694 Mdot
.72667 .99056 Mdot
.56034 .9281 Mdot
.40525 .10544 Mdot
.98418 .81706 Mdot
.38291 .72089 Mdot
.56019 .63256 Mdot
.34708 .67345 Mdot
.28682 .29543 Mdot
.33444 .30605 Mdot
.35387 .85229 Mdot
.23619 .08563 Mdot
.35114 .85473 Mdot
.21926 .95041 Mdot
.21374 .75492 Mdot
.11368 .04153 Mdot
.17741 .8237 Mdot
.14448 .08067 Mdot
.21088 .74805 Mdot
.29242 .87633 Mdot
.29944 .87722 Mdot
.28248 .86542 Mdot
.32922 .87758 Mdot
.30176 .90167 Mdot
.36178 .8692 Mdot
.97748 .75927 Mdot
.64241 .02705 Mdot
.38588 .78027 Mdot
.35897 .87025 Mdot
.29468 .87277 Mdot
.27664 .75159 Mdot
.29863 .58276 Mdot
.11398 .82809 Mdot
.22672 .94583 Mdot
.10906 .12969 Mdot
.33771 .85172 Mdot
.02155 .7759 Mdot
.26318 .91949 Mdot
.24825 .7652 Mdot
.24471 .76143 Mdot
.24315 .76192 Mdot
.32411 .73026 Mdot
.29767 .86006 Mdot
.2881 .70094 Mdot
.24248 .7518 Mdot
.63791 .87274 Mdot
.19724 .88236 Mdot
.1534 .31639 Mdot
.46906 .70291 Mdot
.21556 .92698 Mdot
.32439 .77223 Mdot
.34874 .80423 Mdot
.98562 .42064 Mdot
.99007 .45371 Mdot
.12075 .15026 Mdot
.00068 .73682 Mdot
.50922 .0105 Mdot
.28116 .7597 Mdot
.30781 .88454 Mdot
.4714 .44382 Mdot
.49608 .75783 Mdot
.35401 .94652 Mdot
.18994 .96766 Mdot
.38617 .71864 Mdot
.20943 .95531 Mdot
.22422 .61132 Mdot
.3275 .99574 Mdot
.39093 .68267 Mdot
.04519 .82194 Mdot
.03966 .72229 Mdot
.21595 .88645 Mdot
.2373 .73251 Mdot
.18917 .89978 Mdot
.2455 .77167 Mdot
.40273 .42767 Mdot
.30477 .89871 Mdot
.3086 .93699 Mdot
.30407 .7452 Mdot
.13944 .2708 Mdot
.21626 .307 Mdot
.20395 .79587 Mdot
.2351 .75072 Mdot
.99607 .66684 Mdot
.35697 .84483 Mdot
.09429 .72498 Mdot
.77409 .70715 Mdot
.29883 .73697 Mdot
.22898 .80029 Mdot
.30619 .73726 Mdot
.30189 .87205 Mdot
.18643 .94014 Mdot
.99508 .96508 Mdot
.83665 .66138 Mdot
.4771 .41406 Mdot
.56393 .1748 Mdot
.32643 .83085 Mdot
.97547 .76296 Mdot
.27599 .37988 Mdot
.36718 .2952 Mdot
.22167 .75295 Mdot
.19664 .79796 Mdot
.23749 .76318 Mdot
.30404 .8177 Mdot
.29785 .79023 Mdot
.26299 .92789 Mdot
.21963 .35372 Mdot
.38682 .33664 Mdot
.25855 .89962 Mdot
.38276 .87653 Mdot
.16857 .94334 Mdot
.30621 .86094 Mdot
.34693 .77922 Mdot
.43642 .45709 Mdot
.09683 .05892 Mdot
.23996 .79693 Mdot
.17752 .78901 Mdot
.2318 .77114 Mdot
.19275 .56382 Mdot
.46592 .48979 Mdot
.24699 .93592 Mdot
.09018 .5848 Mdot
.15953 .75667 Mdot
.75312 .85303 Mdot
.08243 .18608 Mdot
.31233 .87686 Mdot
.38608 .86205 Mdot
.60251 .16684 Mdot
.18765 .78046 Mdot
.21922 .94106 Mdot
.2155 .34113 Mdot
.0527 .98846 Mdot
.2214 .75147 Mdot
.34626 .87339 Mdot
.38128 .07121 Mdot
.28791 .88999 Mdot
.08586 .63246 Mdot
.28864 .86313 Mdot
.24348 .10651 Mdot
.54783 .98474 Mdot
.2934 .86007 Mdot
.34439 .79758 Mdot
.26025 .72429 Mdot
.2446 .92502 Mdot
.9916 .82154 Mdot
.22989 .99902 Mdot
.17909 .74595 Mdot
.37293 .68795 Mdot
.75607 .94568 Mdot
.16882 .8852 Mdot
.34372 .7125 Mdot
.32487 .76942 Mdot
.25405 .3949 Mdot
.37221 .87058 Mdot
.32269 .67718 Mdot
.33374 .57641 Mdot
.53406 .73885 Mdot
.30846 .7984 Mdot
.24529 .74795 Mdot
.23585 .70678 Mdot
.26419 .91028 Mdot
.20497 .95026 Mdot
.17815 .95626 Mdot
.23618 .78884 Mdot
.38529 .08866 Mdot
.22758 .77309 Mdot
.36758 .87296 Mdot
.21825 .82829 Mdot
.23139 .92915 Mdot
.31104 .87026 Mdot
.27434 .76225 Mdot
.10904 .83135 Mdot
.55175 .62282 Mdot
.20359 .79254 Mdot
.31755 .85235 Mdot
.23657 .93749 Mdot
.52971 .56434 Mdot
.34789 .80265 Mdot
.49861 .52612 Mdot
.39219 .42294 Mdot
.28824 .88278 Mdot
.43439 .41977 Mdot
.34601 .77503 Mdot
.41655 .13754 Mdot
.3219 .97953 Mdot
.97978 .44874 Mdot
.26546 .88557 Mdot
.00727 .74791 Mdot
.0935 .64946 Mdot
.36289 .07971 Mdot
.34305 .80283 Mdot
.10885 .50625 Mdot
.12364 .82378 Mdot
.32963 .71985 Mdot
.17907 .38675 Mdot
.04429 .41219 Mdot
.1803 .7288 Mdot
.13852 .84969 Mdot
.33803 .73005 Mdot
.30109 .8892 Mdot
.30505 .8106 Mdot
.62022 .93013 Mdot
.29147 .86078 Mdot
.06738 .37729 Mdot
.24264 .76001 Mdot
.32412 .74404 Mdot
.24467 .73932 Mdot
.3053 .85314 Mdot
.27185 .91756 Mdot
.28257 .87122 Mdot
.15154 .87731 Mdot
.19245 .88905 Mdot
.53604 .64703 Mdot
.25767 .78745 Mdot
.201 .87481 Mdot
.60281 .85171 Mdot
.23089 .77292 Mdot
.51812 .55818 Mdot
.37441 .62229 Mdot
.19531 .9554 Mdot
.19337 .66868 Mdot
.29736 .88621 Mdot
.1072 .05701 Mdot
.32029 .8638 Mdot
.24917 .72418 Mdot
.68179 .06981 Mdot
.49868 .57559 Mdot
.32262 .87702 Mdot
.56284 .62035 Mdot
.154 .85908 Mdot
.09471 .96295 Mdot
.32728 .88662 Mdot
.066 .37869 Mdot
.97504 .80045 Mdot
.31405 .86966 Mdot
.42297 .48498 Mdot
.03834 .00922 Mdot
.03205 .81336 Mdot
.06582 .57203 Mdot
.0893 .94924 Mdot
.46065 .64532 Mdot
.27008 .97248 Mdot
.39074 .00671 Mdot
.23948 .78305 Mdot
.67017 .66527 Mdot
.24873 .72799 Mdot
.1749 .50038 Mdot
.50788 .55772 Mdot
.26796 .26686 Mdot
.01793 .93611 Mdot
.32089 .87831 Mdot
.33501 .80046 Mdot
.28858 .86301 Mdot
.11648 .97843 Mdot
.19012 .84203 Mdot
.28087 .43559 Mdot
.45565 .75197 Mdot
.27181 .71691 Mdot
.19928 .72686 Mdot
.53071 .65564 Mdot
.13874 .18956 Mdot
.23061 .06223 Mdot
.22414 .93814 Mdot
.16247 .85728 Mdot
.29584 .8768 Mdot
.38237 .32013 Mdot
.00939 .09049 Mdot
.38268 .62154 Mdot
.13475 .14648 Mdot
.53367 .0212 Mdot
.23841 .75996 Mdot
.34543 .74552 Mdot
.99201 .44732 Mdot
.19427 .93705 Mdot
.14586 .4984 Mdot
.3525 .69412 Mdot
.4883 .43893 Mdot
.26774 .92011 Mdot
.12434 .85903 Mdot
.30941 .01965 Mdot
.54956 .71893 Mdot
.37823 .37219 Mdot
.14682 .75508 Mdot
.62025 .39025 Mdot
.21903 .93834 Mdot
.26162 .74244 Mdot
.96321 .68963 Mdot
.20983 .9385 Mdot
.34422 .79281 Mdot
.0076 .5723 Mdot
.22711 .79392 Mdot
.41677 .27541 Mdot
.18101 .16148 Mdot
.17066 .80427 Mdot
.50243 .1084 Mdot
.31966 .88559 Mdot
.17181 .86348 Mdot
.60556 .85076 Mdot
.23068 .97993 Mdot
.23157 .96379 Mdot
.24273 .76493 Mdot
.27483 .90259 Mdot
.98726 .66817 Mdot
.35623 .20985 Mdot
.15835 .01145 Mdot
.12506 .14175 Mdot
.20142 .87541 Mdot
.46962 .62488 Mdot
.18479 .83784 Mdot
.3893 .85317 Mdot
.34495 .7885 Mdot
.2258 .49988 Mdot
.00104 .68685 Mdot
.20171 .89147 Mdot
.26944 .96068 Mdot
.59006 .8774 Mdot
.22325 .93685 Mdot
.18987 .50712 Mdot
.23164 .84177 Mdot
.32774 .7781 Mdot
.37934 .77853 Mdot
.37262 .77308 Mdot
.24248 .78637 Mdot
.25259 .85032 Mdot
.21197 .75513 Mdot
.1086 .76149 Mdot
.27769 .70504 Mdot
.28414 .75276 Mdot
.19297 .75369 Mdot
.25026 .75634 Mdot
.45328 .59605 Mdot
.32577 .77004 Mdot
.27038 .9241 Mdot
.37149 .85883 Mdot
.01723 .96632 Mdot
.4485 .89621 Mdot
.17924 .95463 Mdot
.45162 .62565 Mdot
.30728 .87905 Mdot
.43907 .80871 Mdot
.16329 .79217 Mdot
.18414 .74824 Mdot
.17812 .5344 Mdot
.31704 .75736 Mdot
.20518 .87532 Mdot
.27968 .75805 Mdot
.27237 .87274 Mdot
.38651 .36274 Mdot
.39076 .8483 Mdot
.38782 .67653 Mdot
.51198 .02461 Mdot
.98415 .78236 Mdot
.32174 .78806 Mdot
.41253 .11416 Mdot
.50756 .03976 Mdot
.26264 .89946 Mdot
.30678 .88548 Mdot
.23971 .76672 Mdot
.107 .05304 Mdot
.32512 .93454 Mdot
.49979 .84133 Mdot
.24743 .78413 Mdot
.13197 .02123 Mdot
.24303 .72437 Mdot
.52113 .00556 Mdot
.195 .141 Mdot
.39191 .85557 Mdot
.29048 .88276 Mdot
.28216 .27231 Mdot
.25122 .93998 Mdot
.33783 .71304 Mdot
.42742 .66823 Mdot
.28076 .92229 Mdot
.24202 .73939 Mdot
.46304 .41026 Mdot
.16323 .14545 Mdot
.06844 .99305 Mdot
.24301 .80748 Mdot
.06689 .04354 Mdot
.38664 .86295 Mdot
.29859 .74077 Mdot
.32451 .74447 Mdot
.36369 .88042 Mdot
.30727 .87266 Mdot
.22471 .24188 Mdot
.54361 .90594 Mdot
.32454 .85154 Mdot
.43226 .4805 Mdot
.24172 .76037 Mdot
.23132 .76601 Mdot
.23679 .91521 Mdot
.23875 .75761 Mdot
.25518 .75631 Mdot
.39907 .09682 Mdot
.2321 .74938 Mdot
.27816 .8783 Mdot
.20356 .5278 Mdot
.20455 .83412 Mdot
.53369 .64436 Mdot
.14645 .11431 Mdot
.26524 .72054 Mdot
.0821 .61581 Mdot
.20064 .87236 Mdot
.19567 .7758 Mdot
.10152 .333 Mdot
.34388 .87827 Mdot
.26097 .92061 Mdot
.83646 .85826 Mdot
.47022 .67434 Mdot
.22758 .76959 Mdot
.31206 .87314 Mdot
.26818 .90661 Mdot
.57632 .90922 Mdot
.49285 .52674 Mdot
.07409 .11544 Mdot
.2593 .76385 Mdot
.23766 .78711 Mdot
.33007 .77759 Mdot
.20037 .34669 Mdot
.29851 .94204 Mdot
.3076 .75842 Mdot
.31867 .68198 Mdot
.32806 .86605 Mdot
.40324 .65085 Mdot
.24671 .75776 Mdot
.27941 .80664 Mdot
.19195 .87961 Mdot
.31694 .77717 Mdot
.23069 .77057 Mdot
.37922 .84768 Mdot
.26057 .92376 Mdot
.02983 .4277 Mdot
.2392 .78888 Mdot
.18075 .95521 Mdot
.33352 .78506 Mdot
.38209 .12908 Mdot
.46341 .20541 Mdot
.23985 .75365 Mdot
.59471 .09704 Mdot
.33085 .85297 Mdot
.30318 .895 Mdot
.39139 .80455 Mdot
.08586 .75877 Mdot
.25 .75169 Mdot
.472 .72885 Mdot
.32446 .42302 Mdot
.56185 .66459 Mdot
.27102 .77242 Mdot
.90454 .81746 Mdot
.34439 .89087 Mdot
.24729 .76026 Mdot
.29716 .73436 Mdot
.31084 .78418 Mdot
.35259 .804 Mdot
.37007 .77699 Mdot
.48857 .93162 Mdot
.22617 .9271 Mdot
.93571 .75613 Mdot
.19909 .84391 Mdot
.49743 .39135 Mdot
.30756 .71143 Mdot
.22196 .93143 Mdot
.85833 .49024 Mdot
.31779 .7853 Mdot
.34676 .70844 Mdot
.32336 .85683 Mdot
.43973 .81334 Mdot
.20854 .87102 Mdot
.27744 .76562 Mdot
.27524 .72116 Mdot
.88057 .9836 Mdot
.38566 .76347 Mdot
.36434 .52178 Mdot
.44145 .15373 Mdot
.98008 .76874 Mdot
.25407 .82682 Mdot
.32166 .77394 Mdot
.33188 .78436 Mdot
.20212 .7838 Mdot
.9411 .77181 Mdot
.17063 .58956 Mdot
.26331 .92649 Mdot
.13237 .87449 Mdot
.4753 .24318 Mdot
.03653 .84245 Mdot
.44993 .81408 Mdot
.08096 .70647 Mdot
.26458 .91073 Mdot
.16162 .89663 Mdot
.08354 .1682 Mdot
.29679 .68173 Mdot
.23086 .77327 Mdot
.30133 .85346 Mdot
.16313 .29078 Mdot
.13919 .68744 Mdot
.27408 .86969 Mdot
.27124 .41093 Mdot
.49839 .57191 Mdot
.28295 .83675 Mdot
.15207 .77597 Mdot
.23894 .75542 Mdot
.20839 .92599 Mdot
.11183 .39784 Mdot
.33454 .78823 Mdot
.41312 .10574 Mdot
.22637 .9579 Mdot
.31512 .86996 Mdot
.10762 .46783 Mdot
.24493 .74911 Mdot
.32875 .76672 Mdot
.30926 .88694 Mdot
.42679 .44069 Mdot
.36097 .70064 Mdot
.2842 .87201 Mdot
.08794 .68161 Mdot
.25359 .78339 Mdot
.26546 .89851 Mdot
.18426 .39261 Mdot
.3005 .86767 Mdot
.66112 .0701 Mdot
.18678 .83723 Mdot
.90314 .18628 Mdot
.4642 .79223 Mdot
.2632 .76273 Mdot
.9855 .61806 Mdot
.15268 .1558 Mdot
.4617 .48504 Mdot
.44605 .68689 Mdot
.23168 .93225 Mdot
.30131 .88045 Mdot
.32234 .85064 Mdot
.29764 .86187 Mdot
.22767 .77486 Mdot
.37873 .46011 Mdot
.36812 .10238 Mdot
.32903 .00671 Mdot
.39206 .70299 Mdot
.29835 .41174 Mdot
.13542 .39637 Mdot
.95411 .67095 Mdot
.34236 .65783 Mdot
.42937 .46554 Mdot
.9377 .41085 Mdot
.24569 .77095 Mdot
.43875 .10954 Mdot
.31017 .25845 Mdot
.31101 .87228 Mdot
.32549 .85125 Mdot
.26659 .73249 Mdot
.27811 .81725 Mdot
.17269 .39047 Mdot
.45934 .11595 Mdot
.27561 .96282 Mdot
.20958 .75243 Mdot
.31374 .84091 Mdot
.17418 .48468 Mdot
.1242 .79404 Mdot
.31177 .85775 Mdot
.20851 .23819 Mdot
.39174 .84854 Mdot
.22727 .9084 Mdot
.2515 .28746 Mdot
.26056 .91398 Mdot
.32072 .88538 Mdot
.30807 .79486 Mdot
.17552 .0417 Mdot
.40988 .09319 Mdot
.20444 .95846 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo
00?o0000ooooooooool02oooool3o`0000oooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool01_ooool2o`0000Gooooo00?o0000ooooooooool02_ooool2o`0000;ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo
0_l00008ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00;ooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0
00000ooooooo0000o`00000looooo`;o00007?ooool2o`0001;ooooo0_l0000Tooooo`;o00000_oo
ool2o`000:3ooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0000Uooooo`;o00006?ooool2
o`0001cooooo0_l0000hooooo`;o0000Y?ooool001kooooo00?o0000ooooooooool0;oooool2o`00
03Kooooo0_l0000Sooooo`;o0000<_ooool2o`0008Gooooo000Nooooo`03o`000?oooooooooo063o
oooo0_l0000Zooooo`;o0000<_ooool2o`0008Gooooo000Nooooo`03o`000?oooooooooo02Oooooo
0_l0000_ooooo`;o00001_ooool2o`0004Oooooo0_l0002Looooo`007_ooool00ol0003ooooooooo
o`0Wooooo`;o0000;oooool2o`0004Sooooo0_l00002ooooo`;o000000?oooooo`000?l00000W?oo
ool001kooooo00?o0000ooooooooool07oooool2o`00087ooooo0_l00002ooooo`;o00009Oooool2
o`0007Sooooo000Nooooo`03o`000?oooooooooo01oooooo0_l0000Tooooo`;o0000Q_ooool2o`00
07Sooooo000Nooooo`03o`000?oooooooooo04Gooooo0_l0003oooooo`7ooooo000Nooooo`03o`00
0?oooooooooo073ooooo0_l0000Vooooo`;o0000[Oooool001kooooo00?o0000ooooooooool07ooo
ool2o`0004oooooo1?l0000Tooooo`;o00001oooool2o`000:Cooooo000Nooooo`03o`000?oooooo
oooo00gooooo0_l00003ooooo`;o00002oooool4o`0001;ooooo0_l0000kooooo`;o0000;Oooool2
o`000:Cooooo000Nooooo`03o`000?oooooooooo00gooooo0_l00003ooooo`;o00003Oooool2o`00
01;ooooo0_l0000kooooo`;o0000doooool001kooooo00?o0000ooooooooool0L_ooool2o`000=?o
oooo000Nooooo`;o00008?ooool2o`0005?ooooo0_l0003Aooooo`007_ooool00ol0003ooooooooo
o`0Oooooo`;o0000Doooool2o`000=7ooooo000Nooooo`03o`000?oooooooooo01_ooooo0_l00002
ooooo`;o0000oooooolWooooo`007_ooool00ol0003oooooooooo`0Kooooo`;o00000_ooool2o`00
02Kooooo0_l00014ooooo`;o0000^?ooool001kooooo00?o0000ooooooooool0Aoooool2o`0004Co
oooo0_l0002hooooo`007_ooool00ol0003oooooooooo`1hooooo`;o0000T?ooool2o`0003_ooooo
000Nooooo`03o`000?oooooooooo07Sooooo0_l0001Iooooo`;o00001Oooool2o`0002kooooo0_l0
000kooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o0000Eoooool2o`0005Wooooo0_l00005
ooooo`;o0000=_ooool2o`0003?ooooo000Nooooo`03o`000?oooooooooo01oooooo0_l0003aoooo
o`;o0000<oooool001kooooo00?o0000ooooooooool0:oooool2o`0004Gooooo0_l0003Cooooo`00
7_ooool00ol0003oooooooooo`0[ooooo`;o0000AOooool2o`000=?ooooo000Nooooo`03o`000?oo
oooooooo04Wooooo0_l0000_ooooo`;o0000boooool001kooooo00Co0000ooooool0003o0000B?oo
ool2o`0001_ooooo0_l0000Aooooo`?o00008?ooool2o`000:Wooooo000Nooooo`04o`000?oooooo
0000o`0006Gooooo0_l0000Aooooo`;o00001_ooool2o`0001Wooooo0_l0002Yooooo`007_ooool0
0ol0003oooooooooo`21ooooo`;o00006Oooool2o`000:Wooooo000Nooooo`03o`000?oooooooooo
07kooooo0_l0000Looooo`;o00007oooool2o`0002gooooo0_l0001Iooooo`007_ooool2o`0007Go
oooo0_l00008ooooo`;o0000?Oooool2o`0002gooooo0_l0001Iooooo`007_ooool00ol0003ooooo
ooooo`0Uooooo`;o0000COooool2o`0000[ooooo1?l00033ooooo`007_ooool00ol0003ooooooooo
o`0Uooooo`;o00009?ooool2o`0002Kooooo0_l0000;ooooo`Co00006oooool2o`000:Kooooo000N
ooooo`03o`000?oooooooooo04_ooooo0_l0000Vooooo`;o00003?ooool2o`0000Sooooo0_l0000B
ooooo`;o0000Y_ooool001kooooo00?o0000ooooooooool0:oooool2o`0005Gooooo0_l00005oooo
o`Co0000^_ooool001kooooo00?o0000ooooooooool05?ooool2o`0001Gooooo0_l0001Eooooo`;o
00001Oooool2o`0000Kooooo0_l0002dooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o0000
FOooool2o`0001kooooo1?l0002dooooo`007_ooool00ol0003oooooooooo`1_ooooo`;o00007_oo
ool4o`000;Cooooo000Nooooo`03o`000?oooooooooo097ooooo0_l0002dooooo`007_ooool00ol0
003oooooooooo`0Oooooo`;o0000Eoooool2o`0001Sooooo0_l0002cooooo`007_ooool00ol0003o
ooooooooo`0Oooooo`;o0000Eoooool2o`0001Sooooo0_l0002cooooo`007_ooool00ol0003ooooo
ooooo`0Wooooo`;o0000oooooolOooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o00003_oo
ool2o`0005[ooooo0_l00032ooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o00003?ooool2
o`0001Cooooo0_l00016ooooo`;o0000`_ooool001kooooo00?o0000ooooooooool09Oooool2o`00
00[ooooo0_l00008ooooo`;o0000ooooool;ooooo`007_ooool00ol0003oooooooooo`0Xooooo`;o
00001oooool2o`000?oooooo5Oooool001kooooo0_l0000Tooooo`;o00000oooool2o`000?oooooo
7_ooool001kooooo00?o0000ooooooooool08oooool2o`0006Kooooo0_l0002jooooo`007_ooool0
0ol0003oooooooooo`0^ooooo`;o0000Foooool2o`000;[ooooo000Nooooo`03o`000?oooooooooo
02kooooo0_l0003ooooooaSooooo000Nooooo`03o`000?oooooooooo03Oooooo0_l00025ooooo`;o
0000Qoooool001kooooo00?o0000ooooooooool0=oooool2o`0003Sooooo0_l0001;ooooo`Co0000
QOooool001kooooo00?o0000ooooooooool05oooool2o`0005Sooooo0_l0001=ooooo`?o0000Q?oo
ool001kooooo00?o0000ooooooooool05oooool2o`000:Sooooo0_l00024ooooo`007_ooool00ol0
003oooooooooo`2cooooo`;o00005oooool2o`0007Wooooo000Nooooo`03o`000?oooooooooo02?o
oooo0_l0002>ooooo`;o00005oooool2o`0007Wooooo000Nooooo`03o`000?oooooooooo027ooooo
1?l0003oooooob?ooooo000Nooooo`03o`000?oooooooooo027ooooo0_l0003oooooobGooooo000N
ooooo`03o`000?oooooooooo01Oooooo0_l0002Eooooo`;o0000L_ooool2o`0002?ooooo000Noooo
o`03o`000?oooooooooo01Oooooo0_l0000@ooooo`;o0000Poooool2o`0007;ooooo0_l0000Soooo
o`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0
003oooooooooo`0Yooooo`;o0000@_ooool2o`000=Sooooo0003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooo
oooo06gooooo0_l0001Kooooo`;o0000Noooool000?ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003:ooooo`;o0000Noooool000?ooooo00Go0000oooo
ooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0oooooom8
ooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool0
0ol0003oooooooooo`2Cooooo`;o0000/_ooool000?ooooo00Go410@oooooooooooooooooa0@400?
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0L?ooool2o`00027ooooo0_l0002b
ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@
4006ooooo`03o`000?oooooooooo073ooooo0_l0003Eooooo`000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`0b
ooooo`;o0000oooooolDooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o00008_ooool2o`00
0?oooooo5?ooool001kooooo00?o0000ooooooooool03_ooool2o`000?oooooo>?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo043ooooo0_l0003oooooo`Kooooo000Nooooo`03o`000?oooooooooo
043ooooo0_l0003oooooo`Kooooo000Nooooo`03o`000?oooooooooo04Gooooo0_l0001?ooooo`;o
0000[oooool001kooooo00?o0000ooooooooool0AOooool2o`0004oooooo0_l0002_ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0
003oooooooooo`22ooooo`;o0000`oooool001kooooo00?o0000ooooooooool0=Oooool2o`0002[o
oooo0_l0000Oooooo`;o0000`oooool001kooooo00?o0000ooooooooool0=Oooool2o`0002[ooooo
0_l0003Tooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo05?ooooo0_l0003booooo`007_ooool00ol0003oooooooooo`0Yooooo`;o00008_ooool2o`00
00Cooooo0_l0003booooo`007_ooool00ol0003oooooooooo`0Yooooo`;o00008_ooool3o`0000So
oooo0_l0000mooooo`;o0000[_ooool001kooooo00?o0000ooooooooool0C_ooool2o`0000Sooooo
0_l0000Yooooo`;o00004_ooool2o`000:kooooo000Nooooo`03o`000?oooooooooo08?ooooo0_l0
0032ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
04kooooo0_l0003gooooo`007_ooool00ol0003oooooooooo`1>ooooo`;o0000moooool001kooooo
00?o0000ooooooooool0<Oooool2o`000?oooooo5Oooool001kooooo00?o0000ooooooooool0<Ooo
ool2o`0002Kooooo0_l0000Hooooo`;o0000d_ooool001kooooo00?o0000ooooooooool0<_ooool2
o`0000cooooo0_l0000Gooooo`;o00006?ooool2o`000=;ooooo000Nooooo`;o0000<oooool2o`00
00cooooo0_l0003oooooo`Kooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0=oooool2o`0000Wooooo0_l0000Uooooo`;o0000g?ooool001kooooo00?o
0000ooooooooool0=oooool2o`0000Wooooo0_l0000Uooooo`;o0000g?ooool001kooooo00?o0000
ooooooooool0F?ooool2o`000>gooooo000Nooooo`03o`000?oooooooooo02kooooo0_l00007oooo
o`;o00007oooool2o`0000Gooooo0_l0003Vooooo`007_ooool00ol0003oooooooooo`0^ooooo`;o
00001oooool2o`0002Kooooo0_l00007ooooo`;o00003_ooool2o`000<gooooo000Nooooo`03o`00
0?oooooooooo06Sooooo0_l0000:ooooo`;o00000_ooool2o`000<gooooo000Nooooo`03o`000?oo
oooooooo07Cooooo0_l0003Aooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo01gooooo0_l0000hooooo`;o00006Oooool2o`000=?ooooo000Nooooo`03
o`000?oooooooooo01gooooo0_l0000hooooo`;o00006Oooool2o`0000Kooooo0_l0003;ooooo`00
7_ooool00ol0003oooooooooo`1jooooo`;o0000boooool001kooooo00?o0000ooooooooool0@_oo
ool2o`000?oooooo1?ooool001kooooo00?o0000ooooooooool0??ooool2o`0000Cooooo0_l0001B
ooooo`;o0000[oooool001kooooo00?o0000ooooooooool0;Oooool2o`0000gooooo0ol0001Goooo
o`;o0000[oooool001kooooo0_l0000^ooooo`;o00003_ooool2o`000?oooooo2Oooool001kooooo
00?o0000ooooooooool0@oooool2o`000?oooooo0oooool001kooooo00?o0000ooooooooool0@ooo
ool2o`000?oooooo0oooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`1jooooo`;o0000boooool001kooooo00?o0000ooooooooool0N_ooool2o`000<_o
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool04?oo
ool2o`0006Gooooo0_l0000Tooooo`;o0000Z?ooool001kooooo00?o0000ooooooooool04?ooool2
o`0006Gooooo0_l0000Tooooo`;o0000Z?ooool001kooooo00?o0000ooooooooool04?ooool4o`00
0?oooooo=?ooool001kooooo00?o0000ooooooooool04Oooool3o`0004;ooooo0_l0003_ooooo`00
7_ooool00ol0003oooooooooo`0Booooo`;o0000@_ooool2o`000>oooooo000Nooooo`03o`000?oo
oooooooo03Kooooo0_l00004ooooo`;o0000ooooool:ooooo`007_ooool00ol0003oooooooooo`0A
ooooo`;o00008Oooool4o`0000Cooooo0_l0000Sooooo`;o0000>oooool2o`0002Kooooo0_l0000k
ooooo`;o0000@_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2
o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool04Oooool2o`00027ooooo0_l00002
ooooo`;o00005?ooool2o`00017ooooo0_l0000kooooo`;o00009_ooool2o`0003_ooooo0_l00012
ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool08?ooool2o`0000Kooooo0_l0000>ooooo`;o00005?ooool2
o`000?Oooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol0000P
ooooo`;o00001_ooool2o`0002cooooo0_l0003_ooooo`000oooool01Ol0003ooooooooooooooooo
000000_ooooo00CoA4A4omgMgOoooooo00001oooool00ol0003oooooooooo`1Fooooo`;o0000kooo
ool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo
00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol@413ooooooooooooooooo410@00cooooo
00?oMgMgolc<c?l000001oooool01?l0003oooooooooooooool2o`0006oooooo0_l0000Nooooo`;o
0000/oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oo
oooo00Co0000oooooooooooooooo0_l00007ooooo`;o0000B?ooool2o`0000Oooooo0_l0000Coooo
o`;o00007_ooool2o`0000Cooooo0_l0002Cooooo`;o00006?ooool000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool02_ooool2o`00
04Sooooo0_l00007ooooo`;o000000?oooooo`000?l00000=Oooool3o`0009?ooooo0_l0000Hoooo
o`007_ooool00ol0003oooooooooo`1:ooooo`;o00005?ooool2o`0003Gooooo0_l0002^ooooo`00
7_ooool00ol0003oooooooooo`1:ooooo`;o0000;oooool2o`0000cooooo0_l0002aooooo`;o0000
2Oooool001kooooo00?o0000ooooooooool01Oooool2o`0000;ooooo0_l0001Jooooo`;o00005?oo
ool2o`0000cooooo0_l0002aooooo`;o00002Oooool001kooooo00?o0000ooooooooool01Oooool3
o`000003ooooool0003o000001kooooo0_l0000jooooo`;o00005?ooool2o`0000;ooooo0_l00036
ooooo`007_ooool00ol0003oooooooooo`04ooooo`Co00008Oooool2o`0005?ooooo0ol00036oooo
o`007_ooool00ol0003oooooooooo`04ooooo`;o0000N?ooool2o`000<Oooooo000Nooooo`04o`00
0?ooooooooooooooo`;o0000E?ooool2o`0000Wooooo0_l0003Sooooo`007_ooool01?l0003ooooo
ooooooooool2o`0005Cooooo0_l00009ooooo`;o00008oooool2o`0001;ooooo0_l0002Zooooo`00
7_ooool00ol0003oooooooooo`27ooooo`;o00003?ooool2o`0000Cooooo0_l0002Zooooo`007_oo
ool00ol0003oooooooooo`2Eooooo`;o0000Yoooool2o`0000Oooooo000Nooooo`03o`000?oooooo
oooo0?oooooo>oooool2o`0000;ooooo0_l00007ooooo`007_ooool2o`000?oooooo??ooool2o`00
00_ooooo000Nooooo`03o`000?oooooooooo0?oooooo?oooool2o`0000Oooooo000Nooooo`03o`00
0?oooooooooo08[ooooo0_l0002booooo`;o00001oooool001kooooo00?o0000ooooooooool0Mooo
ool2o`0000gooooo0_l00002ooooo`;o0000^oooool001kooooo00?o0000ooooooooool0Moooool2
o`0000gooooo0ol0002nooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o0000I_ooool2o`00
013ooooo0_l0002/ooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o0000N?ooool2o`000:co
oooo000Nooooo`03o`000?oooooooooo09cooooo0_l0002Yooooo`007_ooool00ol0003ooooooooo
o`2Looooo`;o0000ZOooool001kooooo00?o0000ooooooooool0R?ooool2o`000;gooooo000Noooo
o`03o`000?oooooooooo08Sooooo0_l0002mooooo`007_ooool00ol0003oooooooooo`0eooooo`;o
0000C_ooool2o`0000_ooooo0_l0002cooooo`007_ooool00ol0003oooooooooo`0eooooo`;o0000
@oooool2o`0000Wooooo0_l0000;ooooo`?o0000O_ooool2o`0003;ooooo000Nooooo`03o`000?oo
oooooooo03oooooo0_l0000iooooo`;o00003Oooool2o`0000Sooooo0_l0001nooooo`;o00009Ooo
ool2o`0000_ooooo000Nooooo`03o`000?oooooooooo03oooooo0_l00018ooooo`;o0000[oooool2
o`0000_ooooo000Nooooo`03o`000?oooooooooo02_ooooo0_l0003ooooooa_ooooo000Nooooo`;o
0000;?ooool2o`0000Sooooo0_l0000>ooooo`;o0000Coooool2o`000:oooooo000Nooooo`03o`00
0?oooooooooo03Gooooo0_l0000>ooooo`;o0000Coooool2o`000:oooooo000Nooooo`03o`000?oo
oooooooo01oooooo0_l0000Iooooo`;o0000ooooool<ooooo`007_ooool00ol0003oooooooooo`0O
ooooo`;o00006Oooool2o`000?oooooo3?ooool001kooooo00?o0000ooooooooool0U?ooool2o`00
0;7ooooo000Nooooo`03o`000?oooooooooo09Cooooo0_l0002aooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo07;ooooo0_l0003Cooooo`007_ooool0
0ol0003oooooooooo`1booooo`;o0000:?ooool4o`000:Oooooo000Nooooo`03o`000?oooooooooo
03kooooo0_l0001Looooo`Co0000Yoooool001kooooo00?o0000ooooooooool0?_ooool2o`000?oo
oooo2?ooool001kooooo00?o0000ooooooooool0=_ooool2o`000?oooooo4?ooool001kooooo00?o
0000ooooooooool0=_ooool2o`000?oooooo4?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`0Xooooo`;o0000oooooolNooooo`007_ooool00ol0003o
ooooooooo`0Xooooo`;o0000KOooool2o`000:kooooo000Nooooo`;o0000V?ooool2o`000:kooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0QOooool2
o`0001[ooooo0_l0002Tooooo`007_ooool00ol0003oooooooooo`25ooooo`;o00006_ooool2o`00
0003ooooool0003o00000:7ooooo000Nooooo`03o`000?oooooooooo03;ooooo0_l00007ooooo`;o
0000Ioooool2o`000:7ooooo000Nooooo`03o`000?oooooooooo03;ooooo0_l000000ooooooo0000
o`000004ooooo`;o0000Joooool2o`0009gooooo000Nooooo`03o`000?oooooooooo03Gooooo0_l0
001Sooooo`;o000000?oooooo`000?l000002Oooool2o`0007Sooooo0_l0000Sooooo`007_ooool3
o`00017ooooo0_l00027ooooo`;o000000Coooooo`000?l0003o0000P_ooool2o`0002?ooooo000N
ooooo`?o00004Oooool2o`0000Gooooo0_l0001>ooooo`;o0000=?ooool2o`0000Gooooo0_l0002P
ooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o0000C_ooool2o`0003Cooooo0_l00005oooo
o`;o0000X?ooool001kooooo00?o0000ooooooooool0GOooool2o`000>Sooooo000Nooooo`03o`00
0?oooooooooo01Wooooo0_l00012ooooo`;o0000j?ooool001kooooo00?o0000ooooooooool06Ooo
ool2o`000?oooooo;Oooool001kooooo00?o0000ooooooooool0<oooool2o`000?oooooo4oooool0
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0<oooool2o`000?oooooo4oooool000?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo
00?o0000ooooooooool0Soooool2o`000;Kooooo0003ooooo`05oa0@4?ooooooooooooooool@4100
2oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0002?ooooo`;o00003_ooool2o`000:Ko
oooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q
00Kooooo00?o0000ooooooooool0Woooool2o`000:Kooooo0003ooooo`05o`000?oooooooooooooo
ool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0oooooom8
ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool0
0ol0003oooooooooo`2Uooooo`;o0000X?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0:oooool2o`0001Sooooo0_l0001N
ooooo`;o0000X?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co
0000oa0@40Kooooo00?o0000ooooooooool05oooool2o`0001;ooooo0_l0000Hooooo`;o0000JOoo
ool2o`0009Gooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0002Gooooo`;o0000R_ooool2
o`0000Wooooo000Nooooo`03o`000?oooooooooo07Kooooo1?l0000iooooo`;o0000Qoooool2o`00
00Wooooo000Nooooo`03o`000?oooooooooo07Kooooo1?l0000Eooooo`;o00001?ooool2o`0001So
oooo0_l00002ooooo`;o0000T_ooool001kooooo00?o0000ooooooooool0J?ooool2o`0002Gooooo
0_l00004ooooo`;o00006?ooool2o`0009Kooooo000Nooooo`03o`000?oooooooooo06Sooooo0_l0
0015ooooo`;o0000U_ooool001kooooo00?o0000ooooooooool06?ooool2o`0009Gooooo0_l00000
0ooooooo0000o`00002Cooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o00004Oooool2o`00
08Gooooo0_l0002Cooooo`007_ooool00ol0003oooooooooo`0[ooooo`;o0000P?ooool2o`0009So
oooo000Nooooo`03o`000?oooooooooo0:gooooo0_l0002Hooooo`007_ooool00ol0003ooooooooo
o`2Booooo`;o00005Oooool3o`0009_ooooo000Nooooo`03o`000?oooooooooo01[ooooo0_l0001f
ooooo`;o00005Oooool3o`0001;ooooo0_l00027ooooo`007_ooool2o`0001_ooooo0_l0001Boooo
o`;o00003oooool2o`0003gooooo0_l00027ooooo`007_ooool00ol0003oooooooooo`1^ooooo`;o
00003oooool2o`0002Oooooo0_l0002Mooooo`007_ooool00ol0003oooooooooo`1[ooooo`;o0000
>oooool2o`0009gooooo000Nooooo`03o`000?oooooooooo06_ooooo0_l0002Oooooo`;o0000>Ooo
ool001kooooo00?o0000ooooooooool0L_ooool2o`0003oooooo0_l0000Qooooo`;o0000=?ooool2
o`0003Wooooo000Nooooo`03o`000?oooooooooo03_ooooo0_l0000eooooo`;o00004oooool2o`00
0003ooooool0003o000000oooooo0_l0000Fooooo`;o00008Oooool2o`0006Gooooo0_l000000ooo
oooo0000o`000005ooooo`007_ooool00ol0003oooooooooo`0kooooo`;o0000B_ooool2o`000003
ooooool0003o000000oooooo0_l0000Iooooo`;o0000N_ooool2o`0000Wooooo0_l000000ooooooo
0000o`000005ooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o0000Doooool2o`0002Kooooo
0_l0000Oooooo`;o0000N_ooool2o`0001?ooooo000Nooooo`03o`000?oooooooooo01Sooooo0_l0
001;ooooo`;o00001_ooool2o`0000_ooooo0_l0000Iooooo`;o0000Y_ooool2o`0000Sooooo000N
ooooo`03o`000?oooooooooo04?ooooo0_l0000Pooooo`;o00004oooool2o`0001Oooooo0_l0002X
ooooo`;o00002?ooool001kooooo00?o0000ooooooooool06?ooool2o`0002Wooooo0_l0000Goooo
o`Co00000oooool2o`0001Kooooo0_l0000Fooooo`;o0000/_ooool001gooooo0_l0000Jooooo`;o
0000@_ooool4o`0000?ooooo0_l0000@ooooo`;o00001?ooool2o`00013ooooo1?l0002fooooo`00
7Oooool2o`0002_ooooo0_l0001:ooooo`;o00005_ooool4o`000:Cooooo0_l0000@ooooo`007_oo
ool00ol0003oooooooooo`0Yooooo`;o0000B_ooool2o`000;kooooo0_l0000@ooooo`007_ooool0
0ol0003oooooooooo`1Sooooo`;o00002Oooool2o`000=Oooooo000Nooooo`03o`000?oooooooooo
06?ooooo0_l00009ooooo`;o00001_ooool2o`000<oooooo000Nooooo`;o0000Foooool2o`0001Go
oooo0_l00003ooooo`;o0000coooool001kooooo00?o0000ooooooooool0E_ooool2o`0000;ooooo
0_l0000Eooooo`;o00002?ooool2o`0001Oooooo0_l0002aooooo`007_ooool00ol0003ooooooooo
o`0Fooooo`;o0000<Oooool2o`0000_ooooo0_l0000Eooooo`;o00003?ooool2o`0001Oooooo0_l0
001Rooooo`;o0000>_ooool2o`00017ooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l0000a
ooooo`;o00005Oooool3o`0000[ooooo0_l0000Jooooo`;o0000KOooool2o`0003[ooooo0_l0000A
ooooo`007_ooool00ol0003oooooooooo`1<ooooo`;o00004_ooool3o`0000Oooooo1?l0000Koooo
o`;o0000_?ooool001kooooo00?o0000ooooooooool0C?ooool2o`000003ooooool0003o000000?o
oooo1?l0000Booooo`Co0000fOooool001kooooo00?o0000ooooooooool0Coooool2o`000003oooo
ool0003o000000Co00003oooool2o`0000oooooo0ol0000dooooo`;o0000U_ooool001kooooo00?o
0000ooooooooool02Oooool2o`0004;ooooo0_l00003ooooo`;o000000?oooooo`000?l000004?oo
ool2o`0000oooooo0ol0000Nooooo`;o00005?ooool2o`0009Kooooo000Nooooo`03o`000?oooooo
oooo00Wooooo0_l0000@ooooo`;o00008?ooool2o`000003ooooool0003o000000Wooooo1?l00000
0ooooooo0000o`000007ooooo`;o0000?_ooool2o`000:cooooo000Nooooo`03o`000?oooooooooo
00Gooooo0_l0000Dooooo`;o00006Oooool2o`000003ooooool0003o000000;ooooo0_l000000ooo
oooo0000o`000009ooooo`So00001_ooool2o`0000[ooooo0_l00003ooooo`;o0000:Oooool2o`00
0;3ooooo000Nooooo`03o`000?oooooooooo00Gooooo0_l0000@ooooo`;o00007Oooool2o`000003
ooooool0003o000000kooooo0ol000001Ooooooo0000o`000?l0003ooooo00Co00004?ooool2o`00
00?ooooo0_l0000Yooooo`;o0000ZOooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo01Oo
oooo0_l0000`ooooo`?o00001?ooool5o`0000Oooooo0_l0003Rooooo`;o00001Oooool001gooooo
0_l0000Looooo`;o0000;oooool2o`0000?ooooo0ol00009ooooo`Go0000BOooool2o`0009_ooooo
000Mooooo`;o00005?ooool2o`0000Kooooo0_l0000[ooooo`;o00000_ooool8o`0000Cooooo0_l0
0003ooooo`Go0000BOooool2o`0009_ooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0000c
ooooo`;o000000?oooooo`000?l000001ol00004ooooo`;o00001?ooool4o`0000Cooooo0_l00004
ooooo`?o0000fOooool001kooooo0ol0000]ooooo`;o00001oooool4o`0000Kooooo0_l00008oooo
o`Co00004Oooool2o`0000Cooooo0_l00004ooooo`?o00006Oooool2o`000;kooooo000Nooooo`?o
0000;Oooool2o`0000Oooooo1?l00005ooooo`?o00000_ooool6o`000003ooooool0003o000000Co
00000_ooool6o`0000Kooooo0_l0000Vooooo`;o0000__ooool001kooooo00?o0000ooooooooool0
>oooool2o`0000;ooooo4_l00002ooooo`So00001?ooool2o`0002oooooo0_l0002[ooooo`;o0000
2?ooool001kooooo00?o0000ooooooooool0;?ooool2o`0000;ooooo0_l00009ooooo`;o00000_oo
ool7o`0000Cooooo2?l00005ooooo`Co000000Coooooo`000?l0003ooooo0_l00002ooooo`;o0000
:oooool2o`0000_ooooo0_l0002=ooooo`;o00003oooool2o`0000Sooooo000Nooooo`03o`000?oo
oooooooo01Sooooo0_l0000Booooo`;o00000_ooool3o`0000kooooo0_l00006ooooo`Wo00001Ooo
ool2o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l00000>?ooool2o`0008Kooooo0_l0
0005ooooo`;o00003?ooool2o`0000_ooooo000Mooooo`;o00006_ooool2o`0000Gooooo0_l0000@
ooooo`;o00004?ooool2o`0000Cooooo1Ol00002ooooo`?o00000_ooool6o`0000Gooooo0_l0000G
ooooo`;o0000<oooool2o`0007Gooooo0_l0000Booooo`?o00002oooool001gooooo0_l0000Qoooo
o`;o00008_ooool2o`0000;ooooo2?l000001?oooooo0000o`000?l00002ooooo`?o000000?ooooo
o`000?l000003?ooool2o`00013ooooo0_l0000cooooo`;o0000ROooool2o`0000cooooo000Noooo
o`03o`000?oooooooooo01gooooo0_l0000Iooooo`;o000000?oooooo`000?l000000_ooool2o`00
00Gooooo0ol000000ooooooo0000o`000003o`0000Oooooo0_l0000>ooooo`?o0000d_ooool2o`00
00[ooooo000Nooooo`03o`000?oooooooooo01gooooo0_l0000@ooooo`;o00001?ooool2o`000004
ooooool0003o0000ooooo`;o00000_ooool2o`0000Gooooo1Ol000001?oooooo0000o`000?ooool4
o`000003ooooool0003o000000Wooooo0_l00004ooooo`?o00003Oooool3o`000;Kooooo0_l0000;
ooooo`;o00002_ooool001kooooo00?o0000ooooooooool00oooool2o`0002Sooooo1?l00004oooo
o`;o00001?ooool2o`0000Wooooo1Ol000001?oooooo0000o`000?ooool4o`000003ooooool0003o
000000Wooooo0_l00003ooooo`?o00001Oooool2o`0000Oooooo0ol0000Mooooo`;o0000Uoooool2
o`0001Oooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0000Wooooo`?o00001Oooool2o`00
00Gooooo0_l00009ooooo`Go00004_ooool2o`0000?ooooo1ol00003ooooo`?o00001Oooool2o`00
0003ooooool0003o000001cooooo0_l0002`ooooo`007_ooool00ol0003oooooooooo`0/ooooo`;o
00001_ooool2o`0000?ooooo0_l0000;ooooo`;o00005Oooool2o`0000?ooooo0ol000001?oooooo
0000o`000?l00004ooooo`;o00001Oooool2o`000003ooooool0003o000000;o0000`Oooool2o`00
00Wooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0000Gooooo`;o00003?ooool2o`0000?o
oooo0_l00006ooooo`;o00000_ooool6o`00017ooooo1?l000000ooooooo0000o`000003o`0000ko
oooo0_l00031ooooo`;o00002Oooool001kooooo00?o0000ooooooooool04_ooool2o`0001Oooooo
1?l0000?ooooo`?o00002?ooool9o`0000oooooo1Ol00002ooooo`?o000000?oooooo`000?l00000
aOooool2o`0001;ooooo000Nooooo`03o`000?oooooooooo02gooooo0_l00007ooooo`;o00001ooo
ool2o`0000Sooooo1?l00003ooooo`;o00002oooool2o`0000Gooooo0_l00003ooooo`Go0000aOoo
ool2o`0001;ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Go
c<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo02Cooooo0_l00003ooooo`;o0000
0_ooool2o`0000;ooooo0_l00003ooooo`?o00001Oooool2o`0000Kooooo0_l000001?oooooo0000
o`000?l0000:ooooo`;o00001Oooool2o`000003ooooool0003o000000Wooooo0ol0000Uooooo`;o
0000/_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7o
V9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool09?ooool2o`0000?ooooo0_l00006oooo
o`;o00001?ooool2o`0000?ooooo1?l00005ooooo`Co000000?oooooo`000?l000002_ooool2o`00
00Sooooo0_l00002ooooo`;o00000oooool2o`000004ooooool0003o0000o`0002Cooooo0_l0002b
ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00
0006ooooo`?o0000??ooool4o`0000;ooooo0_l000000ooooooo0000o`000002o`000003ooooool0
003o000001Cooooo0_l00002ooooo`;o00000oooool6o`0000?ooooo0_l0002eooooo`;o00003_oo
ool2o`0000cooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooo
oonHV9So<S8b00Kooooo00?o0000ooooooooool01oooool2o`0003Wooooo0_l00002ooooo`;o0000
00?oooooo`000?l000003?ooool2o`0000Oooooo0_l00006ooooo`Wo000000?oooooo`000?l00000
7?ooool2o`0009Oooooo0_l0000>ooooo`;o00003?ooool000?ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`07ooooo`;o
0000:_ooool2o`0001Cooooo0_l0000<ooooo`;o00001Oooool2o`0000Sooooo0_l000000ooooooo
0000o`000004o`0000[ooooo0_l0000Cooooo`;o0000HOooool2o`0005;ooooo0003ooooo`05oa0@
4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000oooo
ooooool0<oooool2o`0000kooooo0_l00006ooooo`;o00002_ooool2o`0000Gooooo0_l0000;oooo
o`Go00002oooool2o`0000kooooo0_l0001Vooooo`;o0000D_ooool000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`06
ooooo`;o0000>oooool2o`0000Kooooo0_l0000Booooo`;o00003Oooool2o`0001_ooooo0_l0002j
ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVY
Z@06ooooo`03o`000?oooooooooo00Kooooo0_l0001Gooooo`;o0000:_ooool2o`000003ooooool0
003o00000;Oooooo000Nooooo`?o0000E_ooool2o`0000Oooooo0_l00003ooooo`;o00007_ooool2
o`0000Sooooo0_l0002Booooo`;o00006?ooool2o`0000Wooooo000Nooooo`?o00002Oooool4o`00
033ooooo0_l0000Fooooo`?o00001oooool2o`0000?ooooo0_l0000Nooooo`;o0000W?ooool2o`00
01Sooooo1?l00007ooooo`007_ooool00ol0003oooooooooo`09ooooo`Co00001oooool2o`0000ko
oooo0_l0000@ooooo`;o00001Oooool2o`0000Sooooo0_l0000<ooooo`;o00001_ooool2o`000=oo
oooo0_l00007ooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o00002_ooool3o`000003oooo
ool0003o0000013ooooo0_l0000;ooooo`;o00000_ooool2o`0000Gooooo0_l0000=ooooo`;o0000
1_ooool2o`000>3ooooo000Nooooo`03o`000?oooooooooo01oooooo1?l0000Pooooo`;o00002Ooo
ool2o`0001;ooooo0_l000001?oooooo0000o`000?l0003Oooooo`007_ooool00ol0003ooooooooo
o`0Oooooo`;o00007Oooool2o`0002;ooooo0_l00002ooooo`;o0000goooool001kooooo00?o0000
ooooooooool0>?ooool3o`0000?ooooo1?l000000ooooooo0000o`00000Cooooo`;o0000BOooool2
o`000:;ooooo000Nooooo`03o`000?oooooooooo03Sooooo0ol00005ooooo`;o000000?oooooo`00
0?l000004oooool2o`0000Sooooo0_l0000oooooo`;o0000X_ooool001kooooo00?o0000oooooooo
ool01_ooool4o`00033ooooo0_l000000ooooooo0000o`000008ooooo`;o00005oooool4o`0003[o
oooo0_l0002Wooooo`007_ooool00ol0003oooooooooo`06ooooo`Co0000<?ooool2o`000003oooo
ool0003o000000Sooooo0_l00007ooooo`;o00003_ooool2o`0000kooooo0_l0000/ooooo`;o0000
Yoooool001kooooo00?o0000ooooooooool0:Oooool2o`0002?ooooo1?l0000Nooooo`;o000000?o
ooooo`000?l000000_ooool2o`0000;ooooo0_l0003:ooooo`007_ooool2o`0002[ooooo0_l0000S
ooooo`;o00003?ooool2o`000003ooooool0003o000000So000000Coooooo`000?l0003o00000_oo
ool2o`0000;ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o0000<oooool2o`0000kooooo
0ol0000^ooooo`;o0000E?ooool001kooooo00?o0000ooooooooool0G?ooool=o`000005ooooool0
003o0000o`000?ooool00ol00009ooooo`?o0000<oooool2o`0000kooooo0ol0000^ooooo`;o0000
E?ooool001kooooo00?o0000ooooooooool09?ooool2o`0000Sooooo0_l000000ooooooo0000o`00
000Yooooo`_o00001oooool3o`0000Cooooo0_l00004ooooo`;o0000Soooool2o`0003Wooooo000N
ooooo`03o`000?oooooooooo02Cooooo0_l00008ooooo`;o000000?oooooo`000?l000008?ooool2
o`0000Cooooo3_l00008ooooo`;o00001?ooool2o`0000;ooooo0_l0001Kooooo`;o0000=?ooool2
o`0003Wooooo000Nooooo`03o`000?oooooooooo03Cooooo0_l0000Mooooo`;o00000oooool9o`00
00?ooooo0_l0000:ooooo`;o00001oooool3o`0005[ooooo0_l0001_ooooo`007_ooool00ol0003o
ooooooooo`0dooooo`;o00008_ooool4o`0000;ooooo0ol00002ooooo`?o000000?oooooo`000?l0
00000_ooool2o`0000?ooooo0_l00007ooooo`?o0000boooool001kooooo00Co0000oooooooooooo
oooo0_l0000mooooo`;o00004oooool2o`000003ooooool0003o000000?ooooo2Ol000000ooooooo
0000o`000002ooooo`?o00000_ooool7o`0000;ooooo0_l0003<ooooo`007_ooool01?l0003ooooo
ooooooooool2o`0002Cooooo0_l0000Dooooo`;o000000?oooooo`000?l000004_oooolCo`0000Go
oooo0_l00002ooooo`Oo00009Oooool2o`0002gooooo0_l0001jooooo`007_ooool00ol0003ooooo
ooooo`0Wooooo`;o00001?ooool2o`0000kooooo1?l0000Cooooo`;o000000?oooooo`000?l00000
4?l00003ooooo`;o00001Oooool2o`0000?ooooo0_l0000Rooooo`;o00005_ooool2o`0000Kooooo
0_l0000=ooooo`;o0000N_ooool001kooooo00?o0000ooooooooool02oooool2o`0000Oooooo0_l0
000Fooooo`?o00002oooool2o`000003ooooool0003o000000;o00003oooool2o`0000?ooooo1?l0
0002oooooa3o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000004ooooo`;o0000
>_ooool2o`0000Kooooo0_l00029ooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o00001ooo
ool2o`0001Kooooo0_l0000<ooooo`Co00004_ooool2o`0000?ooooo1?l000000ooooooo0000o`00
0002ooooo`Co00000_ooool3o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`000003oooo
ool0003o00000=?ooooo000Nooooo`03o`000?oooooooooo03?ooooo0_l00007ooooo`;o00001?oo
ool2o`0000kooooo0_l00006ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`Co0000
COooool2o`00093ooooo000Nooooo`03o`000?oooooooooo03?ooooo0_l00005ooooo`;o00001_oo
ool2o`0000gooooo0ol00005ooooo`;o00000_ooool5o`0000;ooooo1?l00014ooooo`;o00001ooo
ool2o`00093ooooo000Nooooo`03o`000?oooooooooo03[ooooo0_l000000ooooooo0000o`00000B
ooooo`;o00001_ooool2o`0000?ooooo1?l0000:ooooo`;o00001?ooool2o`0003Sooooo0_l00005
ooooo`;o00002oooool2o`0008Gooooo000Nooooo`03o`000?oooooooooo017ooooo0_l0000Zoooo
o`;o00007oooool4o`0000[ooooo0_l00004ooooo`;o00000oooool2o`0001Gooooo0ol0000Poooo
o`Co00002oooool2o`0008Gooooo000Nooooo`03o`000?oooooooooo017ooooo0_l0000Hooooo`;o
00000oooool2o`0000;ooooo0_l0000Iooooo`Go00002_ooool4o`0001Gooooo0_l0000Eooooo`?o
00008?ooool2o`0009Cooooo000Nooooo`;o0000;?ooool2o`0000?ooooo0_l00002ooooo`;o0000
0oooool2o`0001Cooooo1Ol000000ooooooo0000o`000003ooooo`Oo0000i_ooool001kooooo00?o
0000ooooooooool03?ooool2o`0001Kooooo1?l0000Aooooo`;o00001?ooool2o`0000oooooo0_l0
0002ooooo`?o00000oooool6o`0001?ooooo0_l0000:ooooo`;o00009_ooool2o`0009kooooo000N
ooooo`03o`000?oooooooooo00cooooo0_l0000Fooooo`Co00005oooool2o`0000Gooooo0_l00002
ooooo`Co00000oooool5o`000003ooooool0003o000000?ooooo0ol00003ooooo`;o00002?ooool2
o`0000Gooooo1?l00008ooooo`;o00009_ooool2o`0000Cooooo0_l0002Hooooo`007_ooool00ol0
003oooooooooo`16ooooo`;o00000_ooool4o`000003ooooool0003o000000So00002Oooool2o`00
00Sooooo0_l00007ooooo`;o0000=_ooool2o`0000Sooooo0_l0002>ooooo`007_ooool00ol0003o
ooooooooo`1;ooooo`;o00000_ooool:o`0005kooooo0_l0002>ooooo`007_ooool00ol0003ooooo
ooooo`0gooooo`;o00004?ooool2o`0000Cooooo1?l000000ooooooo0000o`00000Wooooo`;o0000
b?ooool001kooooo00?o0000ooooooooool0=oooool2o`00013ooooo0_l00004ooooo`Oo00009ooo
ool2o`00047ooooo0_l00025ooooo`007_ooool00ol0003oooooooooo`14ooooo`;o00002oooool5
o`000003ooooool0003o000001Oooooo0_l0001>ooooo`;o0000QOooool001kooooo00?o0000oooo
ooooool0?oooool9o`0000?ooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l0000D
ooooo`;o000000?oooooo`000?l00000eOooool001kooooo00?o0000ooooooooool00oooool2o`00
01?ooooo0_l0000Kooooo`;o00002?ooool5o`000003ooooool0003o000000;o00000_ooool2o`00
00Cooooo0_l0000Jooooo`;o0000@oooool2o`0001;ooooo0_l0001Vooooo`;o00005oooool001ko
oooo00?o0000ooooooooool00oooool2o`0001?ooooo0_l0000Kooooo`;o00002Oooool2o`0000;o
oooo1Ol00008ooooo`;o00000_ooool2o`0004Cooooo0_l0000Eooooo`;o00004Oooool3o`0006Ko
oooo0_l0000Gooooo`007_ooool00ol0003oooooooooo`02ooooo`;o00002_ooool2o`0003Cooooo
1Ol00003ooooo`;o00001oooool2o`0000kooooo0ol0000Jooooo`;o00005oooool2o`0002Sooooo
0_l00020ooooo`007_ooool00ol0003oooooooooo`02ooooo`;o00002_ooool2o`0002?ooooo0_l0
0006ooooo`;o00000oooool7o`0000;ooooo0_l000000ooooooo0000o`00000Booooo`;o00000ooo
ool3o`0001[ooooo0_l00033ooooo`007_ooool01?l0003oooooooooooooool2o`00033ooooo0_l0
0003ooooo`;o000000?oooooo`000?l000000oooool7o`000004ooooool0003o0000o`0000?ooooo
0_l0000=ooooo`;o000000?oooooo`000?l000000oooool2o`000>3ooooo000Nooooo`04o`000?oo
ooooooooooooo`;o0000;oooool3o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`;o0000
00?oooooo`000?l000000oooool2o`0000Cooooo0_l0000=ooooo`;o00001_ooool2o`0008_ooooo
0_l0001Cooooo`007_ooool00ol0003oooooooooo`0booooo`?o00000_ooool2o`0000;ooooo0_l0
0003ooooo`;o000000?oooooo`000?l000001Ol0000Uooooo`;o0000POooool2o`0005?ooooo000N
ooooo`;o00006_ooool2o`0001cooooo0_l00006ooooo`;o00000_ooool5o`0002Oooooo0_l0003F
ooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o00006oooool2o`0000Oooooo0_l00002oooo
o`;o0000f?ooool2o`0002Sooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0000>ooooo`;o
00008?ooool3o`0000;ooooo0_l00003ooooo`;o00000oooool2o`0000[ooooo0_l0000Fooooo`;o
0000/_ooool2o`0002Sooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0000>ooooo`;o0000
8?ooool3o`0000;ooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l0000:ooooo`Co0000
5?ooool2o`000=cooooo000Nooooo`03o`000?oooooooooo01_ooooo0_l0000Qooooo`;o00001ooo
ool2o`0000[ooooo1?l0000:ooooo`;o0000i?ooool001kooooo00Co0000oooooooooooooooo0_l0
000Hooooo`;o0000:_ooool2o`0000cooooo0_l0000:ooooo`;o0000g?ooool2o`0000Kooooo000N
ooooo`04o`000?ooooooooooooooo`;o0000=oooool2o`0007Oooooo0_l0002:ooooo`;o00001_oo
ool001kooooo00?o0000ooooooooool0>_ooool2o`0001Sooooo0_l0000<ooooo`;o0000Coooool2
o`0001kooooo0_l0001booooo`007_ooool00ol0003oooooooooo`1Dooooo`;o00003?ooool2o`00
06oooooo0_l0001booooo`007_ooool00ol0003oooooooooo`0Rooooo`;o00007_ooool2o`00027o
oooo0_l0003Pooooo`007_ooool00ol0003oooooooooo`0Rooooo`;o00007_ooool2o`0000?ooooo
0_l0000Looooo`;o00008?ooool2o`000;kooooo000Nooooo`03o`000?oooooooooo04Oooooo0_l0
000nooooo`Co00008oooool2o`0001Gooooo0_l0001Cooooo`;o0000:oooool001kooooo00?o0000
ooooooooool03Oooool2o`0007[ooooo0_l0000Sooooo`;o00005Oooool2o`0005?ooooo0_l0000[
ooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o00002_ooool2o`000<gooooo0_l0001Moooo
o`005?ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool04_ooool2o`0000Go
oooo0_l00018ooooo`;o0000Poooool2o`0005gooooo000Fooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool04_ooool2o`0004oooooo0_l000000ooooooo0000o`00003Oooooo`005_oo
ool00ol0003oooooooooo`05ooooo`?o0000Aoooool2o`0001gooooo0_l0003Oooooo`005_ooool0
0ol0003oooooooooo`1?ooooo`;o0000o_ooool001Kooooo00?o0000ooooooooool0oooooom@oooo
o`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?oooooo
D?ooool001Cooooo00?oEEEEofIVI_l00000oooooomBooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.293 .75452 Mdot
.36612 .99341 Mdot
.22376 .76932 Mdot
.39434 .85084 Mdot
.25996 .78983 Mdot
.28972 .86839 Mdot
.53852 .51837 Mdot
.24928 .79729 Mdot
.31723 .92137 Mdot
.09629 .11248 Mdot
.22414 .04528 Mdot
.14276 .98458 Mdot
.22603 .7541 Mdot
.56927 .89074 Mdot
.29278 .8399 Mdot
.453 .09492 Mdot
.35509 .32733 Mdot
.24253 .70101 Mdot
.25933 .73571 Mdot
.39448 .88279 Mdot
.09585 .22993 Mdot
.24367 .90617 Mdot
.14142 .79025 Mdot
.23259 .60368 Mdot
.34027 .92306 Mdot
.24495 .85811 Mdot
.30871 .90835 Mdot
.44677 .05222 Mdot
.21142 .04392 Mdot
.27019 .89827 Mdot
.24542 .71475 Mdot
.28639 .84493 Mdot
.27186 .96959 Mdot
.95219 .80945 Mdot
.11558 .80785 Mdot
.38669 .92373 Mdot
.58185 .8756 Mdot
.13549 .40359 Mdot
.1392 .88901 Mdot
.33657 .90185 Mdot
.24273 .72222 Mdot
.24065 .84829 Mdot
.40561 .88947 Mdot
.2317 .37631 Mdot
.54672 .68347 Mdot
.22872 .86744 Mdot
.91148 .62941 Mdot
.28812 .79402 Mdot
.34861 .94358 Mdot
.26519 .87081 Mdot
.19 .94862 Mdot
.22417 .72649 Mdot
.24636 .81165 Mdot
.38479 .93566 Mdot
.22859 .78913 Mdot
.14619 .2996 Mdot
.48224 .8293 Mdot
.24494 .76084 Mdot
.30709 .90678 Mdot
.28729 .72876 Mdot
.35517 .8408 Mdot
.2433 .82629 Mdot
.52194 .52451 Mdot
.34027 .93199 Mdot
.3318 .78588 Mdot
.2705 .89604 Mdot
.33557 .70458 Mdot
.30819 .90947 Mdot
.28318 .85318 Mdot
.11151 .80161 Mdot
.02409 .40521 Mdot
.25345 .86891 Mdot
.17207 .86262 Mdot
.25137 .43946 Mdot
.19401 .97197 Mdot
.41086 .78254 Mdot
.34826 .65963 Mdot
.22703 .25572 Mdot
.2987 .88477 Mdot
.30796 .78161 Mdot
.16619 .77562 Mdot
.16401 .50936 Mdot
.20823 .36987 Mdot
.24034 .80476 Mdot
.57963 .52214 Mdot
.96464 .39645 Mdot
.26852 .8261 Mdot
.36071 .90361 Mdot
.28521 .83973 Mdot
.28122 .79573 Mdot
.40345 .92956 Mdot
.30558 .81185 Mdot
.26202 .93596 Mdot
.06092 .35999 Mdot
.26613 .70917 Mdot
.18414 .75356 Mdot
.4476 .43618 Mdot
.17695 .76003 Mdot
.3424 .92526 Mdot
.03685 .94544 Mdot
.28056 .8348 Mdot
.19505 .91833 Mdot
.32146 .72083 Mdot
.54951 .978 Mdot
.30452 .01712 Mdot
.15027 .78627 Mdot
.42394 .13161 Mdot
.45485 .1025 Mdot
.28014 .71138 Mdot
.35144 .34689 Mdot
.56178 .89811 Mdot
.17605 .33217 Mdot
.29848 .76906 Mdot
.25125 .70193 Mdot
.67416 .17238 Mdot
.24905 .57376 Mdot
.5298 .6887 Mdot
.20871 .76787 Mdot
.17174 .96553 Mdot
.41434 .72566 Mdot
.3182 .92672 Mdot
.32929 .78859 Mdot
.21314 .93676 Mdot
.06686 .36764 Mdot
.43105 .02638 Mdot
.03321 .11047 Mdot
.25972 .98977 Mdot
.27456 .74094 Mdot
.95116 .83574 Mdot
.12489 .87697 Mdot
.06937 .16281 Mdot
.365 .27919 Mdot
.75424 .14258 Mdot
.21147 .71579 Mdot
.23946 .69632 Mdot
.20877 .7128 Mdot
.15596 .78386 Mdot
.35218 .04317 Mdot
.27894 .72441 Mdot
.28921 .89414 Mdot
.27998 .72321 Mdot
.34193 .93557 Mdot
.24765 .9173 Mdot
.04755 .87816 Mdot
.42122 .27043 Mdot
.15202 .98281 Mdot
.31137 .72932 Mdot
.30701 .86728 Mdot
.42398 .84021 Mdot
.29301 .44491 Mdot
.46323 .80959 Mdot
.25192 .94785 Mdot
.15505 .96311 Mdot
.39197 .89765 Mdot
.29978 .85866 Mdot
.20888 .7826 Mdot
.36885 .08297 Mdot
.97515 .71287 Mdot
.32686 .91659 Mdot
.4125 .12418 Mdot
.30583 .97512 Mdot
.08381 .88431 Mdot
.244 .36832 Mdot
.19997 .73074 Mdot
.34434 .91466 Mdot
.24183 .79991 Mdot
.31567 .85695 Mdot
.32164 .90457 Mdot
.388 .372 Mdot
.20914 .74329 Mdot
.22511 .92938 Mdot
.08582 .76049 Mdot
.10402 .8509 Mdot
.34899 .88009 Mdot
.28268 .7558 Mdot
.28183 .06494 Mdot
.09591 .61902 Mdot
.23781 .84689 Mdot
.49573 .45688 Mdot
.21277 .73258 Mdot
.42374 .89102 Mdot
.18745 .0012 Mdot
.19947 .88102 Mdot
.49515 .66456 Mdot
.04572 .60673 Mdot
.23546 .78108 Mdot
.40601 .12047 Mdot
.41196 .91412 Mdot
.68298 .01498 Mdot
.04988 .92619 Mdot
.27734 .7519 Mdot
.01292 .35448 Mdot
.28292 .74429 Mdot
.41121 .77673 Mdot
.37667 .71626 Mdot
.41694 .89322 Mdot
.07091 .86746 Mdot
.17508 .96866 Mdot
.31696 .92541 Mdot
.22049 .96205 Mdot
.49774 .50065 Mdot
.67355 .17883 Mdot
.21246 .7118 Mdot
.51849 .66997 Mdot
.34013 .92513 Mdot
.36606 .90143 Mdot
.26132 .51848 Mdot
.33412 .90014 Mdot
.53185 .50338 Mdot
.3904 .02465 Mdot
.20628 .7662 Mdot
.29485 .73071 Mdot
.44611 .68225 Mdot
.95532 .44753 Mdot
.33972 .02078 Mdot
.01805 .42053 Mdot
.33305 .86861 Mdot
.08484 .11668 Mdot
.32311 .103 Mdot
.32847 .73255 Mdot
.62654 .81103 Mdot
.22621 .73812 Mdot
.34062 .93951 Mdot
.31473 .90202 Mdot
.26023 .76341 Mdot
.25219 .91624 Mdot
.05252 .87315 Mdot
.14617 .7734 Mdot
.14217 .54367 Mdot
.25338 .91236 Mdot
.21559 .81722 Mdot
.29189 .75171 Mdot
.2399 .92261 Mdot
.98252 .75383 Mdot
.01822 .43012 Mdot
.14789 .75845 Mdot
.02965 .92508 Mdot
.23161 .73238 Mdot
.11875 .35103 Mdot
.32711 .89495 Mdot
.28236 .77443 Mdot
.23489 .91698 Mdot
.34914 .86469 Mdot
.36352 .73044 Mdot
.13363 .88232 Mdot
.38101 .64792 Mdot
.21892 .76888 Mdot
.23387 .92824 Mdot
.88838 .87788 Mdot
.23117 .73631 Mdot
.23726 .71343 Mdot
.21119 .79814 Mdot
.81974 .40355 Mdot
.9618 .42838 Mdot
.42508 .10831 Mdot
.35139 .83743 Mdot
.25082 .82091 Mdot
.1192 .32743 Mdot
.15741 .81443 Mdot
.67359 .20168 Mdot
.29898 .74369 Mdot
.31464 .73082 Mdot
.18567 .20528 Mdot
.16859 .44859 Mdot
.23899 .91876 Mdot
.00668 .36227 Mdot
.24689 .79811 Mdot
.42667 .35076 Mdot
.2191 .74895 Mdot
.32289 .90964 Mdot
.34343 .92381 Mdot
.08527 .71462 Mdot
.32132 .84364 Mdot
.29742 .74307 Mdot
.14617 .78341 Mdot
.18337 .78876 Mdot
.31816 .10637 Mdot
.50332 .36175 Mdot
.37754 .93739 Mdot
.19956 .89035 Mdot
.55329 .86883 Mdot
.24162 .9119 Mdot
.17538 .74832 Mdot
.57113 .83239 Mdot
.2522 .8089 Mdot
.34117 .93861 Mdot
.22056 .72738 Mdot
.09596 .05569 Mdot
.37823 .81215 Mdot
.23681 .00893 Mdot
.37537 .87448 Mdot
.36006 .77266 Mdot
.25674 .73386 Mdot
.35832 .83713 Mdot
.45744 .40461 Mdot
.09091 .97307 Mdot
.31626 .77953 Mdot
.3863 .1048 Mdot
.55848 .91899 Mdot
.20596 .47682 Mdot
.09901 .0973 Mdot
.31477 .96109 Mdot
.08034 .83667 Mdot
.21237 .7829 Mdot
.14979 .13286 Mdot
.33136 .68858 Mdot
.30908 .90475 Mdot
.30694 .88397 Mdot
.50168 .62981 Mdot
.66237 .1754 Mdot
.327 .91528 Mdot
.54203 .94848 Mdot
.24272 .85557 Mdot
.20039 .73737 Mdot
.35023 .8874 Mdot
.41006 .87984 Mdot
.22207 .96981 Mdot
.29763 .79617 Mdot
.27837 .98578 Mdot
.20389 .34667 Mdot
.14794 .88201 Mdot
.25119 .96488 Mdot
.19063 .94021 Mdot
.2514 .9158 Mdot
.25277 .69944 Mdot
.21232 .8088 Mdot
.3752 .93808 Mdot
.30456 .73698 Mdot
.15574 .99035 Mdot
.22173 .82566 Mdot
.40482 .89577 Mdot
.27906 .86915 Mdot
.50574 .39698 Mdot
.56009 .14273 Mdot
.03717 .26272 Mdot
.33829 .34609 Mdot
.91386 .96541 Mdot
.31087 .91837 Mdot
.20942 .88123 Mdot
.00326 .38082 Mdot
.34554 .92178 Mdot
.99381 .96028 Mdot
.2963 .72194 Mdot
.21965 .80447 Mdot
.44996 .72531 Mdot
.64758 .84931 Mdot
.39706 .3994 Mdot
.37474 .35588 Mdot
.17686 .31792 Mdot
.25629 .79464 Mdot
.21033 .76408 Mdot
.23752 .81134 Mdot
.02113 .91331 Mdot
.5008 .03615 Mdot
.4749 .47689 Mdot
.33517 .84281 Mdot
.21267 .85272 Mdot
.19907 .73265 Mdot
.24108 .74366 Mdot
.11475 .21388 Mdot
.23699 .91843 Mdot
.03319 .87327 Mdot
.24772 .71606 Mdot
.1936 .77069 Mdot
.33149 .95099 Mdot
.08254 .85292 Mdot
.53016 .80522 Mdot
.80676 .09806 Mdot
.20984 .81908 Mdot
.26759 .87645 Mdot
.32734 .9949 Mdot
.31207 .90008 Mdot
.21919 .76211 Mdot
.27732 .90585 Mdot
.03172 .79066 Mdot
.0299 .9905 Mdot
.5607 .6643 Mdot
.359 .93432 Mdot
.37429 .61879 Mdot
.25701 .93413 Mdot
.29803 .88063 Mdot
.41602 .85602 Mdot
.08502 .68993 Mdot
.41539 .14831 Mdot
.40452 .07572 Mdot
.45944 .74364 Mdot
.50238 .86498 Mdot
.35314 .39351 Mdot
.31184 .91424 Mdot
.53923 .88485 Mdot
.27848 .7207 Mdot
.2628 .74108 Mdot
.28703 .82167 Mdot
.27602 .77675 Mdot
.27076 .78602 Mdot
.4767 .45796 Mdot
.42829 .33478 Mdot
.07112 .40183 Mdot
.30823 .9087 Mdot
.25299 .70576 Mdot
.38654 .90101 Mdot
.58212 .71802 Mdot
.99177 .74774 Mdot
.24041 .81998 Mdot
.53634 .78795 Mdot
.95241 .85202 Mdot
.25793 .01452 Mdot
.27723 .84099 Mdot
.19307 .82344 Mdot
.20052 .73079 Mdot
.32169 .98412 Mdot
.33205 .9184 Mdot
.31439 .97965 Mdot
.5151 .56267 Mdot
.22646 .80184 Mdot
.22199 .7151 Mdot
.34381 .7058 Mdot
.26935 .94218 Mdot
.75492 .75779 Mdot
.29904 .88433 Mdot
.32801 .90185 Mdot
.84769 .018 Mdot
.13966 .74436 Mdot
.24737 .7281 Mdot
.23932 .77315 Mdot
.60011 .7324 Mdot
.49509 .50842 Mdot
.29264 .91943 Mdot
.25532 .88072 Mdot
.51765 .49789 Mdot
.28876 .84822 Mdot
.99326 .79966 Mdot
.59101 .87382 Mdot
.41669 .86261 Mdot
.70429 .93102 Mdot
.61222 .87265 Mdot
.36409 .10882 Mdot
.00502 .88172 Mdot
.382 .7023 Mdot
.55375 .6772 Mdot
.27836 .7579 Mdot
.21117 .36364 Mdot
.25991 .36249 Mdot
.33573 .83997 Mdot
.2373 .15985 Mdot
.3356 .86404 Mdot
.25118 .98004 Mdot
.24356 .76647 Mdot
.2055 .96125 Mdot
.13563 .78404 Mdot
.07056 .04487 Mdot
.31365 .72059 Mdot
.34593 .92252 Mdot
.30478 .88964 Mdot
.19913 .94811 Mdot
.32071 .91236 Mdot
.33399 .92478 Mdot
.38415 .93327 Mdot
.94096 .83343 Mdot
.67542 .98639 Mdot
.37973 .81156 Mdot
.35537 .89782 Mdot
.30073 .87895 Mdot
.2344 .79983 Mdot
.22157 .55109 Mdot
.17583 .75632 Mdot
.26135 .97136 Mdot
.04452 .10638 Mdot
.3161 .83634 Mdot
.05209 .7849 Mdot
.26444 .88651 Mdot
.26389 .82971 Mdot
.24536 .80525 Mdot
.24287 .80459 Mdot
.27679 .75968 Mdot
.2895 .858 Mdot
.27057 .76905 Mdot
.23306 .78512 Mdot
.57816 .82099 Mdot
.26506 .95297 Mdot
.19621 .26061 Mdot
.40833 .77267 Mdot
.2395 .91239 Mdot
.28125 .7111 Mdot
.2895 .75162 Mdot
.95141 .42613 Mdot
.97758 .46715 Mdot
.20003 .09639 Mdot
.05012 .7722 Mdot
.48235 .0247 Mdot
.21934 .75167 Mdot
.32676 .90886 Mdot
.50942 .41789 Mdot
.52461 .83652 Mdot
.3821 .95474 Mdot
.18392 .97206 Mdot
.42638 .72498 Mdot
.23725 .99193 Mdot
.13234 .59945 Mdot
.24183 .96514 Mdot
.41462 .6901 Mdot
.09888 .90196 Mdot
.103 .75382 Mdot
.15962 .74711 Mdot
.23341 .71195 Mdot
.2762 .80296 Mdot
.25724 .83375 Mdot
.46273 .42152 Mdot
.33376 .92374 Mdot
.29968 .90722 Mdot
.27147 .6922 Mdot
.17118 .18945 Mdot
.21859 .25316 Mdot
.10381 .71932 Mdot
.26569 .80198 Mdot
.99449 .74586 Mdot
.40373 .92127 Mdot
.18088 .7437 Mdot
.77668 .65431 Mdot
.25963 .69857 Mdot
.20385 .73003 Mdot
.25692 .77505 Mdot
.29886 .8835 Mdot
.20652 .94902 Mdot
.98665 .92848 Mdot
.84549 .66804 Mdot
.51222 .38614 Mdot
.53874 .23429 Mdot
.20829 .80708 Mdot
.94189 .83729 Mdot
.19526 .34717 Mdot
.40834 .24485 Mdot
.25644 .80476 Mdot
.15589 .89371 Mdot
.23397 .80181 Mdot
.28195 .85172 Mdot
.32944 .79553 Mdot
.31015 .9606 Mdot
.16613 .42366 Mdot
.42553 .31805 Mdot
.28817 .89267 Mdot
.23864 .8012 Mdot
.15813 .98541 Mdot
.29411 .86319 Mdot
.29272 .7547 Mdot
.48951 .46678 Mdot
.18483 .98516 Mdot
.15048 .78427 Mdot
.17557 .75506 Mdot
.21122 .80635 Mdot
.29439 .52866 Mdot
.48511 .52868 Mdot
.28894 .96457 Mdot
.01762 .64261 Mdot
.26372 .81519 Mdot
.71602 .78675 Mdot
.15562 .14538 Mdot
.30842 .92061 Mdot
.41287 .89949 Mdot
.6661 .15825 Mdot
.19277 .7437 Mdot
.25734 .99569 Mdot
.15932 .40713 Mdot
.01039 .94136 Mdot
.22421 .72258 Mdot
.35402 .94357 Mdot
.33356 .02785 Mdot
.34217 .93193 Mdot
.15806 .55027 Mdot
.286 .84408 Mdot
.33847 .1342 Mdot
.53128 .99454 Mdot
.28872 .85496 Mdot
.31172 .73195 Mdot
.26171 .73713 Mdot
.283 .93269 Mdot
.01095 .89437 Mdot
.21313 .04266 Mdot
.20238 .79499 Mdot
.4132 .67864 Mdot
.70662 .88093 Mdot
.30102 .79017 Mdot
.31442 .76067 Mdot
.27396 .71361 Mdot
.21134 .461 Mdot
.37895 .90961 Mdot
.25506 .765 Mdot
.44131 .593 Mdot
.53682 .79151 Mdot
.2952 .71505 Mdot
.23372 .77955 Mdot
.23613 .76844 Mdot
.21157 .81354 Mdot
.23297 .97833 Mdot
.15447 .98136 Mdot
.23822 .85043 Mdot
.33746 .08858 Mdot
.21214 .80853 Mdot
.37825 .92095 Mdot
.19212 .74937 Mdot
.2692 .93508 Mdot
.31965 .89921 Mdot
.21354 .76228 Mdot
.17324 .76242 Mdot
.59279 .66641 Mdot
.19706 .73446 Mdot
.3185 .89588 Mdot
.24338 .91489 Mdot
.55794 .6021 Mdot
.29153 .74906 Mdot
.52329 .56863 Mdot
.45608 .41045 Mdot
.281 .84576 Mdot
.46314 .37388 Mdot
.27286 .7329 Mdot
.38076 .14027 Mdot
.26402 .89133 Mdot
.94346 .44784 Mdot
.33419 .93793 Mdot
.06097 .66004 Mdot
.18918 .68319 Mdot
.46147 .08181 Mdot
.28363 .74815 Mdot
.03482 .49517 Mdot
.21295 .77243 Mdot
.25373 .82447 Mdot
.10169 .37118 Mdot
.98824 .3966 Mdot
.19254 .77402 Mdot
.24902 .8927 Mdot
.28518 .73392 Mdot
.318 .90636 Mdot
.29474 .72265 Mdot
.62007 .91508 Mdot
.28931 .8546 Mdot
.08454 .31076 Mdot
.24059 .80066 Mdot
.35128 .66669 Mdot
.26673 .76008 Mdot
.28924 .83391 Mdot
.37052 .95005 Mdot
.28856 .85587 Mdot
.25062 .82341 Mdot
.30416 .95275 Mdot
.5913 .6968 Mdot
.22026 .7173 Mdot
.22696 .97618 Mdot
.52853 .80392 Mdot
.22722 .81185 Mdot
.54809 .59757 Mdot
.28541 .58456 Mdot
.21354 .00178 Mdot
.11396 .75846 Mdot
.31265 .89816 Mdot
.19634 .98117 Mdot
.33723 .90632 Mdot
.24633 .79631 Mdot
.64727 .01458 Mdot
.54003 .51343 Mdot
.31358 .91053 Mdot
.56596 .66486 Mdot
.14867 .83719 Mdot
.15155 .07669 Mdot
.32297 .93635 Mdot
.01068 .36182 Mdot
.94117 .85928 Mdot
.30194 .88444 Mdot
.50175 .47768 Mdot
.02416 .95336 Mdot
.99272 .88362 Mdot
.08697 .63055 Mdot
.16088 .05774 Mdot
.43192 .72807 Mdot
.26532 .95466 Mdot
.28708 .90873 Mdot
.24554 .84363 Mdot
.63143 .72941 Mdot
.25603 .73296 Mdot
.25727 .44565 Mdot
.55407 .4941 Mdot
.20559 .33468 Mdot
.04384 .89065 Mdot
.19011 .78255 Mdot
.2709 .74545 Mdot
.28638 .84511 Mdot
.11405 .89313 Mdot
.21839 .95229 Mdot
.36358 .39139 Mdot
.3965 .79855 Mdot
.24937 .71403 Mdot
.30974 .77618 Mdot
.51556 .72029 Mdot
.16097 .1713 Mdot
.33841 .0855 Mdot
.25994 .95191 Mdot
.15482 .82437 Mdot
.30439 .88563 Mdot
.42768 .27395 Mdot
9e-05 .02262 Mdot
.32548 .55472 Mdot
.12923 .17892 Mdot
.50992 .03194 Mdot
.20695 .77931 Mdot
.28113 .72269 Mdot
.97107 .44738 Mdot
.22055 .94295 Mdot
.16932 .42758 Mdot
.24773 .63518 Mdot
.48021 .45907 Mdot
.30857 .93797 Mdot
.13609 .73256 Mdot
.28759 .93438 Mdot
.55821 .77172 Mdot
.29731 .38601 Mdot
.15025 .78339 Mdot
.65099 .40872 Mdot
.23466 .9209 Mdot
.27478 .79013 Mdot
.02383 .62861 Mdot
.22793 .9242 Mdot
.30286 .73166 Mdot
.01415 .62643 Mdot
.20446 .72704 Mdot
.49583 .31375 Mdot
.10106 .15312 Mdot
.31761 .73828 Mdot
.48924 .06593 Mdot
.31433 .93224 Mdot
.27475 .94266 Mdot
.5324 .80311 Mdot
.22911 .97087 Mdot
.23377 .94665 Mdot
.20416 .78758 Mdot
.30743 .90828 Mdot
.05782 .61337 Mdot
.4349 .21119 Mdot
.25668 .91521 Mdot
.20517 .0849 Mdot
.19793 .97491 Mdot
.52699 .57179 Mdot
.22553 .83741 Mdot
.40197 .8473 Mdot
.26937 .74019 Mdot
.31929 .48759 Mdot
.00622 .76892 Mdot
.24638 .98352 Mdot
.26456 .93664 Mdot
.51133 .82444 Mdot
.26538 .99494 Mdot
.11176 .49246 Mdot
.35181 .88331 Mdot
.28293 .76056 Mdot
.29753 .88194 Mdot
.3206 .73154 Mdot
.21159 .72077 Mdot
.32409 .89847 Mdot
.22944 .7419 Mdot
.20393 .81198 Mdot
.26404 .77504 Mdot
.22537 .74038 Mdot
.34483 .71071 Mdot
.25176 .8013 Mdot
.45992 .51404 Mdot
.28963 .75162 Mdot
.2614 .02776 Mdot
.36383 .84694 Mdot
.01697 .9129 Mdot
.31988 .82504 Mdot
.1738 .96759 Mdot
.45353 .53037 Mdot
.34709 .91804 Mdot
.37064 .85574 Mdot
.16108 .77449 Mdot
.21118 .79814 Mdot
.2699 .49039 Mdot
.26913 .70628 Mdot
.2783 .93716 Mdot
.21964 .75055 Mdot
.19406 .95559 Mdot
.37466 .3596 Mdot
.39717 .8497 Mdot
.31417 .73669 Mdot
.42602 .95126 Mdot
.99614 .86209 Mdot
.33601 .81258 Mdot
.37123 .09457 Mdot
.47948 .05433 Mdot
.29266 .89526 Mdot
.32513 .90879 Mdot
.20744 .79664 Mdot
.19016 .03294 Mdot
.21161 .81918 Mdot
.539 .7875 Mdot
.23935 .86353 Mdot
.11827 .94121 Mdot
.24348 .79522 Mdot
.49802 .01846 Mdot
.26953 .12418 Mdot
.41347 .87466 Mdot
.23645 .78386 Mdot
.20537 .25186 Mdot
.25168 .9137 Mdot
.30768 .7654 Mdot
.36037 .73098 Mdot
.27587 .81349 Mdot
.22819 .7059 Mdot
.49341 .37783 Mdot
.15525 .19126 Mdot
.06435 .92553 Mdot
.20716 .73013 Mdot
.04693 .9867 Mdot
.40659 .89612 Mdot
.24888 .77951 Mdot
.42888 .82776 Mdot
.42566 .88739 Mdot
.31175 .89668 Mdot
.26872 .16611 Mdot
.44865 .84385 Mdot
.30427 .84561 Mdot
.50725 .47552 Mdot
.23924 .80049 Mdot
.21992 .79919 Mdot
.29876 .97573 Mdot
.21199 .78046 Mdot
.26757 .8152 Mdot
.36352 .06188 Mdot
.25097 .82321 Mdot
.34101 .92835 Mdot
.29734 .48876 Mdot
.17736 .76154 Mdot
.51029 .69587 Mdot
.11787 .06386 Mdot
.2549 .72916 Mdot
.17143 .56015 Mdot
.31322 .82318 Mdot
.20137 .73545 Mdot
.13165 .26349 Mdot
.34865 .94361 Mdot
.31815 .96458 Mdot
.83284 .78546 Mdot
.53384 .74831 Mdot
.21394 .80218 Mdot
.30766 .90448 Mdot
.30325 .91257 Mdot
.494 .84827 Mdot
.54919 .54273 Mdot
.02439 .08435 Mdot
.20568 .77369 Mdot
.24151 .84836 Mdot
.28401 .75764 Mdot
.15158 .39791 Mdot
.28137 .83173 Mdot
.24349 .72508 Mdot
.30865 .63133 Mdot
.31825 .91783 Mdot
.34409 .56815 Mdot
.2462 .80033 Mdot
.28398 .96656 Mdot
.25782 .94467 Mdot
.29231 .77184 Mdot
.22349 .80701 Mdot
.37524 .84908 Mdot
.30128 .94083 Mdot
.02988 .36888 Mdot
.23879 .85819 Mdot
.18989 .00014 Mdot
.26094 .737 Mdot
.34503 .12472 Mdot
.50595 .16426 Mdot
.2232 .78268 Mdot
.60171 .06549 Mdot
.31615 .90179 Mdot
.34285 .92757 Mdot
.40088 .8536 Mdot
.17342 .80621 Mdot
.27308 .81044 Mdot
.47685 .60843 Mdot
.28208 .51858 Mdot
.58659 .71536 Mdot
.23572 .70669 Mdot
.94926 .82586 Mdot
.32883 .8618 Mdot
.2493 .80577 Mdot
.26329 .80642 Mdot
.38985 .75093 Mdot
.29071 .75406 Mdot
.31647 .73573 Mdot
.38025 .85865 Mdot
.2433 .90778 Mdot
.93905 .7935 Mdot
.14838 .71503 Mdot
.50759 .38293 Mdot
.3897 .70203 Mdot
.23988 .91316 Mdot
.83901 .53735 Mdot
.32045 .79855 Mdot
.47823 .68623 Mdot
.30386 .8353 Mdot
.38468 .82654 Mdot
.28319 .92832 Mdot
.24306 .70253 Mdot
.21561 .83607 Mdot
.88439 .91111 Mdot
.39754 .73427 Mdot
.45852 .51037 Mdot
.51615 .1312 Mdot
.98348 .84922 Mdot
.26993 .75354 Mdot
.25439 .72843 Mdot
.29907 .7182 Mdot
.19584 .90559 Mdot
.92901 .81398 Mdot
.12815 .53976 Mdot
.30774 .9534 Mdot
.14628 .91705 Mdot
.47363 .24121 Mdot
.04049 .87164 Mdot
.42368 .84188 Mdot
.15661 .73045 Mdot
.30098 .91693 Mdot
.14336 .75813 Mdot
.1055 .14927 Mdot
.26582 .6433 Mdot
.22759 .81249 Mdot
.28701 .83827 Mdot
.11912 .31674 Mdot
.11753 .60165 Mdot
.19668 .95529 Mdot
.22541 .49333 Mdot
.5377 .50921 Mdot
.36972 .78159 Mdot
.16371 .78116 Mdot
.22562 .78666 Mdot
.23977 .91969 Mdot
.0502 .36939 Mdot
.27917 .73065 Mdot
.32751 .03117 Mdot
.23142 .94081 Mdot
.30272 .88716 Mdot
.03639 .4883 Mdot
.22287 .77362 Mdot
.25541 .73895 Mdot
.34197 .91924 Mdot
.48248 .44257 Mdot
.42071 .68932 Mdot
.29341 .86395 Mdot
.1359 .7721 Mdot
.3448 .72382 Mdot
.29517 .89556 Mdot
.23303 .31545 Mdot
.28697 .83617 Mdot
.62026 .01365 Mdot
.29723 .78875 Mdot
.90535 .23066 Mdot
.48788 .7594 Mdot
.20745 .77921 Mdot
.93702 .58209 Mdot
.12117 .12148 Mdot
.50224 .51342 Mdot
.46568 .81328 Mdot
.24273 .91048 Mdot
.30963 .89702 Mdot
.30227 .8421 Mdot
.28455 .75352 Mdot
.21359 .81247 Mdot
.46097 .44073 Mdot
.33854 .06382 Mdot
.26275 .93599 Mdot
.4938 .66034 Mdot
.37658 .36723 Mdot
.12599 .35682 Mdot
.02219 .74473 Mdot
.24074 .61537 Mdot
.49322 .46774 Mdot
.92184 .44279 Mdot
.25463 .82735 Mdot
.38836 .10196 Mdot
.35381 .18951 Mdot
.30479 .89867 Mdot
.30881 .89724 Mdot
.27208 .76954 Mdot
.23278 .73308 Mdot
.18245 .45673 Mdot
.41139 .11538 Mdot
.2703 .93961 Mdot
.31512 .7262 Mdot
.21992 .92811 Mdot
.25273 .42621 Mdot
.20909 .74189 Mdot
.30151 .90007 Mdot
.13217 .25815 Mdot
.39987 .85398 Mdot
.16671 .97393 Mdot
.30296 .1966 Mdot
.32207 .96057 Mdot
.31555 .93396 Mdot
.2736 .81016 Mdot
.21713 .9653 Mdot
.35653 .07198 Mdot
.2111 .94766 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wo
oooo0ol00002ooooo`03o`000?oooooooooo00;o00002oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`00
7_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;o00002oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`02ooooo`007_ooool00ol0003oooooooooo`19ooooo`;o0000o?ooool001kooooo00?o0000
ooooooooool0BOooool2o`0007_ooooo0_l0001oooooo`007_ooool00ol0003oooooooooo`1@oooo
o`;o0000M?ooool2o`0000Kooooo0_l0000:ooooo`;o0000Joooool001kooooo00?o0000oooooooo
ool0D?ooool2o`0000gooooo0_l0000mooooo`;o0000;_ooool2o`0000[ooooo0_l0000cooooo`;o
0000=_ooool001gooooo0_l0001Qooooo`;o00002Oooool2o`0003;ooooo0_l0001_ooooo`;o0000
=_ooool001gooooo0_l0001/ooooo`;o00003oooool2o`0001cooooo0_l0002/ooooo`007_ooool0
0ol0003oooooooooo`1Aooooo`;o00005Oooool2o`00017ooooo0_l0000;ooooo`;o00003oooool2
o`000:cooooo000Nooooo`03o`000?oooooooooo057ooooo0_l0000Cooooo`Co00007_ooool2o`00
01Sooooo0_l0002Sooooo`007_ooool00ol0003oooooooooo`0jooooo`;o0000:_ooool2o`0003[o
oooo0_l0002Sooooo`007_ooool00ol0003oooooooooo`0jooooo`;o0000Hoooool2o`000:Kooooo
000Nooooo`03o`000?oooooooooo09oooooo0_l0002Vooooo`007_ooool00ol0003oooooooooo`11
ooooo`;o0000:oooool2o`000=Oooooo000Nooooo`03o`000?oooooooooo01?ooooo0_l0000/oooo
o`;o00000_ooool2o`0002Oooooo0_l0003Gooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o
0000<?ooool2o`000?oooooo0Oooool001kooooo0_l0002>ooooo`;o0000^?ooool001kooooo00?o
0000ooooooooool06oooool2o`00073ooooo0_l00009ooooo`;o0000[Oooool001kooooo00?o0000
ooooooooool06oooool2o`0001?ooooo0_l0001Vooooo`;o0000[Oooool001kooooo00?o0000oooo
ooooool0<?ooool2o`00043ooooo0_l0003Cooooo`007_ooool00ol0003oooooooooo`0Rooooo`;o
0000=?ooool2o`00013ooooo0_l00006ooooo`;o00009oooool2o`0002?ooooo0_l00025ooooo`00
7_ooool00ol0003oooooooooo`0Rooooo`;o0000=?ooool2o`00013ooooo0_l0000_ooooo`;o0000
8oooool2o`0008Gooooo000Nooooo`03o`000?oooooooooo073ooooo0_l0003Eooooo`007_ooool0
0ol0003oooooooooo`1`ooooo`;o0000eOooool001kooooo00?o0000ooooooooool0;Oooool2o`00
053ooooo0_l00036ooooo`007_ooool00ol0003oooooooooo`0]ooooo`;o0000D?ooool2o`000<Ko
oooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0001^ooooo`;o00007?ooool2o`000;?ooooo
000Nooooo`03o`000?oooooooooo00Cooooo0_l0000iooooo`;o0000:Oooool2o`0000Sooooo0_l0
000Looooo`;o0000/oooool001kooooo00?o0000ooooooooool0?oooool2o`0002Wooooo0_l0003K
ooooo`007_ooool00ol0003oooooooooo`1Zooooo`;o0000foooool001kooooo00?o0000oooooooo
ool0?Oooool2o`0003Kooooo0_l0000Hooooo`;o0000]_ooool001kooooo00?o0000ooooooooool0
7?ooool2o`0001oooooo0_l0000fooooo`;o00006?ooool2o`00077ooooo0_l00013ooooo`007_oo
ool2o`0001gooooo0_l0001Looooo`;o00005?ooool2o`00073ooooo0_l00013ooooo`007_ooool0
0ol0003oooooooooo`1Uooooo`;o00004_ooool3o`0001Cooooo0_l0002eooooo`007_ooool00ol0
003oooooooooo`0:ooooo`;o0000Eoooool4o`0000_ooooo0_l00005ooooo`;o00002oooool2o`00
0;oooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l000000ooooooo0000o`00001Gooooo`;o
00003Oooool2o`0001;ooooo0_l0002oooooo`007_ooool00ol0003oooooooooo`07ooooo`;o0000
4_ooool2o`000?oooooo:oooool001kooooo00?o0000ooooooooool05oooool2o`0000;ooooo0_l0
001Uooooo`;o0000`oooool001kooooo00?o0000ooooooooool05oooool2o`0006Oooooo1?l00033
ooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o0000;oooool2o`0002[ooooo1?l00033oooo
o`007_ooool00ol0003oooooooooo`0Sooooo`;o0000;oooool2o`0001Kooooo0_l0000Dooooo`;o
0000`oooool001kooooo00?o0000ooooooooool0K?ooool2o`000=Wooooo000Nooooo`03o`000?oo
oooooooo02gooooo0_l0001Gooooo`;o00007?ooool2o`000:7ooooo000Nooooo`03o`000?oooooo
oooo02gooooo0_l0000kooooo`;o00006_ooool2o`0001cooooo0_l0002Qooooo`007_ooool00ol0
003oooooooooo`1Zooooo`;o0000foooool001kooooo00?o0000ooooooooool0N?ooool2o`0003So
oooo0_l0000mooooo`;o0000E?ooool001kooooo00?o0000ooooooooool0;_ooool2o`0004Sooooo
0_l0000hooooo`;o0000?Oooool2o`0005Cooooo000Nooooo`03o`000?oooooooooo02kooooo0_l0
001Cooooo`;o0000`_ooool001kooooo0_l0000Oooooo`;o0000Hoooool2o`000<;ooooo000Noooo
o`03o`000?oooooooooo01gooooo0ol0003oooooobSooooo000Nooooo`03o`000?oooooooooo01go
oooo0_l0002eooooo`;o0000LOooool001kooooo00?o0000ooooooooool0BOooool2o`0008Wooooo
0_l0001aooooo`007_ooool00ol0003oooooooooo`0Booooo`;o0000=Oooool2o`0005Gooooo0_l0
002Uooooo`007_ooool00ol0003oooooooooo`0Booooo`;o0000?oooool2o`0004_ooooo0_l0002U
ooooo`007_ooool00ol0003oooooooooo`1Cooooo`;o0000l_ooool001kooooo00?o0000oooooooo
ool0<?ooool2o`000:Gooooo0_l0001^ooooo`007_ooool00ol0003oooooooooo`0`ooooo`;o0000
XOooool2o`0000;ooooo0_l0001^ooooo`007_ooool00ol0003oooooooooo`0Vooooo`;o0000Zooo
ool2o`0000;ooooo0_l0001^ooooo`007_ooool00ol0003oooooooooo`0Vooooo`;o0000[oooool2
o`0006kooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`0^ooooo`;o00001?ooool2o`0003Wooooo
0_l0003Fooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000
1_ooool00ol0003oooooooooo`0^ooooo`;o00001?ooool2o`0003Wooooo0_l0003Fooooo`000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01_ooool00ol0003oooooooooo`1Nooooo`;o0000ioooool000?ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0001Nooooo`;o0000ioooool000?ooooo
00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000oooooooo
ool0eoooool2o`0006kooooo0003ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOo
IVIVooooo`05ooooo`03o`000?oooooooooo03Sooooo0_l0002Mooooo`;o0000K_ooool000?ooooo
00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0>?ooool2o`000?oooooo3_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`29ooooo`;o0000_?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`0Qooooo`;o0000I_ooool2o`000;cooooo000Nooooo`03o`000?oooooooooo
027ooooo0_l0003oooooobGooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo01_ooooo0_l0003oooooo`Kooooo0_l0000Sooooo`007_ooool00ol0
003oooooooooo`0Kooooo`;o0000S_ooool2o`0007Gooooo0_l0000Sooooo`007_ooool00ol0003o
ooooooooo`2[ooooo`;o0000V_ooool001kooooo00?o0000ooooooooool0U_ooool2o`000:oooooo
000Nooooo`03o`000?oooooooooo09Kooooo0_l0002_ooooo`007_ooool00ol0003oooooooooo`21
ooooo`;o0000a?ooool001kooooo00?o0000ooooooooool0POooool2o`000<Cooooo000Nooooo`;o
0000@?ooool2o`0000;ooooo0_l0003oooooo`?ooooo000Nooooo`03o`000?oooooooooo03oooooo
0_l00002ooooo`;o000000?oooooo`000?l00000ooooool001kooooo00?o0000ooooooooool09ooo
ool2o`0001gooooo0_l0003oooooo`007_ooool00ol0003oooooooooo`08ooooo`;o00007Oooool2
o`0001?ooooo0_l0003oooooo`[ooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0000Moooo
o`;o00004oooool2o`000?oooooo2_ooool001kooooo00?o0000ooooooooool09oooool2o`000?oo
oooo7oooool001kooooo00?o0000ooooooooool0QOooool2o`000<3ooooo000Nooooo`03o`000?oo
oooooooo08Gooooo1?l0002nooooo`007_ooool00ol0003oooooooooo`27ooooo`;o0000__ooool0
01kooooo00?o0000ooooooooool0Loooool2o`000=;ooooo000Nooooo`03o`000?oooooooooo07?o
oooo0_l0003Booooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo02_ooooo0_l0003ooooooa_o
oooo000Nooooo`;o0000;?ooool2o`000?oooooo6oooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
01Oooooo0_l0003ooooooboooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l00024ooooo`;o
0000Z?ooool001kooooo00?o0000ooooooooool08oooool2o`00013ooooo0_l0000Aooooo`;o0000
??ooool2o`0001Gooooo0_l0002Xooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o00004?oo
ool2o`00017ooooo0_l0000looooo`;o0000_oooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o0000B_ooool2o`000=Kooooo000Nooooo`03
o`000?oooooooooo02?ooooo0_l0001:ooooo`;o0000e_ooool001kooooo00?o0000ooooooooool0
=Oooool2o`000?oooooo4Oooool001kooooo00?o0000ooooooooool0=Oooool2o`0000Sooooo0_l0
0016ooooo`;o0000__ooool001kooooo00?o0000ooooooooool0?oooool2o`0004Kooooo0_l0002n
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0>oooool2o`000003ooooool0003o000002[ooooo
0_l00002ooooo`;o0000eoooool001kooooo0_l0000Sooooo`;o00005oooool2o`000003ooooool0
003o000002[ooooo0_l00002ooooo`;o00005oooool2o`000;kooooo000Nooooo`03o`000?oooooo
oooo00;o00008?ooool2o`0006?ooooo0_l0002nooooo`007_ooool00ol0003oooooooooo`02o`00
02?ooooo0_l0001?ooooo`;o0000coooool001kooooo00?o0000ooooooooool04?ooool2o`0001?o
oooo0_l0001?ooooo`;o0000coooool001kooooo1?l0000?ooooo`;o0000;oooool2o`0000gooooo
0_l0000Tooooo`;o0000:?ooool2o`000:Gooooo000Nooooo`Co0000@?ooool2o`0000gooooo0_l0
000Tooooo`;o0000:?ooool2o`000:Gooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l00004
ooooo`;o00001?ooool2o`0002cooooo0_l00009ooooo`;o0000:Oooool2o`000<oooooo000Noooo
o`03o`000?oooooooooo00Kooooo0_l00004ooooo`;o00001?ooool2o`0000Wooooo0_l0000Qoooo
o`;o00002Oooool2o`0002gooooo0_l0003;ooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o
0000:?ooool2o`00037ooooo0_l0000Fooooo`;o0000/oooool001kooooo00?o0000ooooooooool0
Aoooool2o`0004Wooooo0_l00008ooooo`;o0000ZOooool001kooooo0_l0002Mooooo`;o0000ZOoo
ool001kooooo0_l0002Rooooo`;o0000Y?ooool001kooooo00?o0000ooooooooool0GOooool2o`00
04;ooooo0ol0002Sooooo`007_ooool00ol0003oooooooooo`1Mooooo`;o00004oooool2o`0002ko
oooo0_l0002Sooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o
000000?o410@ooooooooool01?ooool00ol0003oooooooooo`1_ooooo`;o000000?oooooo`000?l0
0000doooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo02gooooo0_l00010ooooo`;o0000;oooool2o`0009Co
oooo0_l00005ooooo`;o00002?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go
00001_ooool3o`0002gooooo0_l0001>ooooo`;o00008Oooool2o`0009Cooooo0_l00005ooooo`;o
00002?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`00
00Oooooo00?o0000ooooooooool04oooool2o`0001?ooooo0_l0001Cooooo`;o0000Qoooool2o`00
03oooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo00Cooooo0_l0000=ooooo`;o00004oooool2o`0000Kooooo0_l0001O
ooooo`;o0000Loooool2o`0003oooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo00Cooooo0_l0000Zooooo`;o0000G_ooool3
o`0003gooooo0_l0001eooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000001oooool00ol0003oooooooooo`2@ooooo`;o0000?_ooool2o`0007Gooooo0003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0X_ooool2o`000:?ooooo000Nooooo`03
o`000?oooooooooo00;ooooo0_l0002>ooooo`;o00003_ooool2o`000:?ooooo000Nooooo`03o`00
0?oooooooooo00;ooooo0_l0000^ooooo`;o0000G_ooool2o`000;?ooooo000Nooooo`03o`000?oo
oooooooo03;ooooo0ol0000Iooooo`;o0000hOooool2o`0000;ooooo0_l0000@ooooo`007_ooool0
0ol0003oooooooooo`02ooooo`;o0000;oooool2o`0001Wooooo0_l0003Qooooo`;o00000_ooool2
o`00013ooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0003oooooodCooooo000Nooooo`03
o`000?oooooooooo08gooooo0_l0002hooooo`007_ooool00ol0003oooooooooo`1>ooooo`;o0000
?Oooool2o`0000?ooooo0_l0002cooooo`007_ooool00ol0003oooooooooo`1>ooooo`;o0000@_oo
ool2o`0000Gooooo0_l0002=ooooo`;o00007Oooool001kooooo00?o0000ooooooooool0D?ooool2
o`0000Wooooo0_l0000looooo`;o0000SOooool2o`0000kooooo0_l0000=ooooo`007_ooool00ol0
003oooooooooo`0cooooo`;o00006oooool2o`0000Wooooo0_l0003Booooo`;o000000?oooooo`00
0?l000001?ooool2o`0000gooooo000Nooooo`;o0000=?ooool2o`000?[ooooo0_l000000ooooooo
0000o`00000Cooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo03Oooooo0_l0001Nooooo`?o00000oooool2o`000:Sooooo000Nooooo`03o`000?oooooo
oooo03Oooooo0_l00008ooooo`;o0000E?ooool3o`0000?ooooo0_l0002Xooooo`007_ooool00ol0
003oooooooooo`11ooooo`;o0000ooooool5ooooo`007_ooool00ol0003oooooooooo`2Kooooo`?o
0000W?ooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo09_ooooo0ol0002Looooo`;o0000
2oooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`0o
ooooo`;o0000EOooool2o`0000Oooooo1?l0002Tooooo`007_ooool00ol0003oooooooooo`0ooooo
o`;o0000EOooool2o`0000Oooooo1?l0002Tooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool02?oo
ool2o`0004[ooooo0_l00007ooooo`;o00001Oooool2o`000>7ooooo000Nooooo`03o`000?oooooo
oooo00Sooooo0_l0000Fooooo`;o00008oooool2o`0000gooooo0_l00007ooooo`;o00001Oooool2
o`000>7ooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0000Gooooo`;o00008oooool2o`00
06Wooooo0_l0002Eooooo`007_ooool00ol0003oooooooooo`07ooooo`;o0000Voooool2o`0000[o
oooo0_l0002Eooooo`007_ooool2o`0009oooooo0_l00004ooooo`;o0000XOooool001kooooo00?o
0000ooooooooool0W_ooool2o`0000Wooooo0_l0002Looooo`007_ooool00ol0003oooooooooo`2M
ooooo`;o00002_ooool2o`0009cooooo000Nooooo`03o`000?oooooooooo037ooooo0_l0001Noooo
o`;o00002_ooool2o`0000cooooo0_l0002Jooooo`007_ooool00ol0003oooooooooo`0aooooo`;o
0000G_ooool2o`0000cooooo0_l0000:ooooo`;o0000V_ooool001kooooo00?o0000ooooooooool0
TOooool2o`0000cooooo0_l0000:ooooo`;o0000V_ooool001kooooo00?o0000ooooooooool0DOoo
ool2o`0000Gooooo0_l0001Aooooo`;o0000V_ooool001kooooo00?o0000ooooooooool0DOooool2
o`0000Gooooo0_l0001Aooooo`;o00002oooool2o`0008gooooo000Nooooo`03o`000?oooooooooo
0:Kooooo0_l0000@ooooo`;o0000SOooool001kooooo00?o0000ooooooooool0G?ooool2o`00037o
oooo0_l00009ooooo`;o00002_ooool2o`0009oooooo000Nooooo`03o`000?oooooooooo05cooooo
0_l0000aooooo`;o00002Oooool2o`000:_ooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0ooooool>ooooo`;o0000>?ooool001kooooo00?o0000oooo
ooooool09_ooool2o`0008Kooooo0_l0001Mooooo`;o0000>?ooool001kooooo00?o0000oooooooo
ool09_ooool2o`0000;ooooo0_l00022ooooo`;o0000Uoooool001kooooo00?o0000ooooooooool0
:_ooool2o`000?oooooo7?ooool001kooooo0_l0000`ooooo`;o00004oooool2o`000?oooooo0_oo
ool001kooooo00?o0000ooooooooool0;oooool2o`0001?ooooo0_l0000Pooooo`;o0000goooool0
01kooooo00?o0000ooooooooool0I_ooool2o`000=oooooo000Nooooo`03o`000?oooooooooo03Co
oooo0_l0003ooooooa;ooooo000Nooooo`03o`000?oooooooooo03Cooooo0_l0001]ooooo`;o0000
X_ooool001kooooo00?o0000ooooooooool0Xoooool2o`000:;ooooo000Nooooo`03o`000?oooooo
oooo06cooooo0_l0000hooooo`;o0000Woooool001kooooo00?o0000ooooooooool0K?ooool2o`00
03Sooooo0ol0002Nooooo`007_ooool00ol0003oooooooooo`1=ooooo`;o0000F?ooool2o`0009ko
oooo000Nooooo`03o`000?oooooooooo04gooooo0_l0003hooooo`007_ooool00ol0003ooooooooo
o`3oooooobkooooo0_l0000Hooooo`007_ooool00ol0003oooooooooo`1Iooooo`;o0000d_ooool2
o`0001Sooooo000Nooooo`03o`000?oooooooooo05Wooooo0_l0003/ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo08_ooooo0_l0002joooo
o`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B401_ooool00ol0003oooooooooo`2;ooooo`;o00008Oooool2o`0009Oooooo0003oooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
000Wooooo`;o0000QOooool2o`0009Oooooo0003ooooo`05o`000?ooooooooooooooool000002ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool08_ooool2o`0000?ooooo
0_l0000Nooooo`;o0000J?ooool2o`0009Cooooo0003ooooo`05o`000?ooooooooooooooool00000
2oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool02oooool2o`0001Go
oooo0_l0000Sooooo`;o0000J?ooool2o`0009Cooooo0003ooooo`05oa0@4?ooooooooooooooool@
41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo00_ooooo0_l0002:ooooo`;o
0000[_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00So
oooo00?o0000ooooooooool03oooool2o`0008Kooooo0_l0002^ooooo`000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`0?oooo
o`;o0000>Oooool2o`000?_ooooo000Nooooo`03o`000?oooooooooo01_ooooo0_l0000]ooooo`;o
0000:_ooool2o`000<oooooo000Nooooo`03o`000?oooooooooo01_ooooo0_l0001Iooooo`;o0000
coooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`02
o`0000;ooooo0_l0003ooooood;ooooo000Nooooo`03o`000?oooooooooo00;o00000_ooool2o`00
01;ooooo0_l00016ooooo`;o0000?Oooool2o`0008?ooooo0_l0000Qooooo`007_ooool00ol0003o
ooooooooo`0Hooooo`;o0000A_ooool2o`0003gooooo0_l00023ooooo`;o00008Oooool001kooooo
00?o0000ooooooooool0C?ooool2o`000?Wooooo000Nooooo`03o`000?oooooooooo04cooooo0_l0
003iooooo`007_ooool00ol0003oooooooooo`02ooooo`;o0000C_ooool2o`000??ooooo000Noooo
o`03o`000?oooooooooo00;ooooo0_l0001>ooooo`;o0000loooool001kooooo00?o0000oooooooo
ool0N?ooool2o`000<gooooo000Nooooo`;o0000NOooool2o`000<gooooo000Nooooo`03o`000?oo
oooooooo0?Sooooo0_l0001=ooooo`007_ooool00ol0003oooooooooo`1]ooooo`;o0000ROooool2
o`0004gooooo000Nooooo`03o`000?oooooooooo013ooooo0_l0001Kooooo`;o0000;Oooool2o`00
0:Wooooo000Nooooo`03o`000?oooooooooo013ooooo0_l0002:ooooo`?o00004oooool4o`00097o
oooo000Nooooo`03o`000?oooooooooo06kooooo0_l0000]ooooo`;o00004oooool4o`0000Oooooo
0_l0001@ooooo`;o0000=_ooool001kooooo00?o0000ooooooooool0K_ooool2o`0003Cooooo0_l0
000Gooooo`;o0000D?ooool2o`0003Kooooo000Nooooo`03o`000?oooooooooo0:Cooooo0_l0002Q
ooooo`007_ooool00ol0003oooooooooo`2`ooooo`;o0000UOooool001kooooo00?o0000oooooooo
ool0P_ooool2o`0002cooooo0_l0002Eooooo`007_ooool00ol0003oooooooooo`0iooooo`;o0000
Aoooool2o`0000Wooooo0_l0000Oooooo`;o0000Uoooool001kooooo00?o0000ooooooooool0>Ooo
ool2o`0005;ooooo0_l00008ooooo`;o00005Oooool2o`0009Oooooo000Nooooo`03o`000?oooooo
oooo01Sooooo0_l0001>ooooo`;o00006Oooool4o`00013ooooo0_l0000?ooooo`;o0000WOooool0
01kooooo00?o0000ooooooooool06?ooool2o`0003[ooooo0_l0000Booooo`;o00006Oooool4o`00
027ooooo0_l0002Mooooo`007_ooool00ol0003oooooooooo`1:ooooo`;o00002?ooool2o`0004co
oooo0_l0002Sooooo`007_ooool00ol0003oooooooooo`1:ooooo`;o00000_ooool4o`00053ooooo
0_l0000Hooooo`;o0000ROooool001kooooo0_l0001<ooooo`;o000000?oooooo`000?l000000_l0
000Vooooo`;o000000?oooooo`000?l00000?oooool2o`0008Wooooo000Nooooo`03o`000?oooooo
oooo04_ooooo0_l000000ooooooo0000o`00000Iooooo`;o00003Oooool2o`000003ooooool0003o
00000<[ooooo000Nooooo`03o`000?oooooooooo04Kooooo0_l000000ooooooo0000o`000003oooo
o`;o00000oooool2o`0001Cooooo0_l000000ooooooo0000o`00003Iooooo`007_ooool00ol0003o
ooooooooo`11ooooo`;o00000oooool2o`000003ooooool0003o000000Oooooo0ol00002ooooo`;o
00004oooool2o`000=Wooooo000Nooooo`03o`000?oooooooooo01Sooooo0_l0000Vooooo`?o0000
1Oooool3o`000004ooooool0003o0000o`0000?ooooo0_l000000ooooooo0000o`000002o`0001?o
oooo0_l0003;ooooo`;o00003?ooool001kooooo00?o0000ooooooooool06?ooool2o`0001;ooooo
0_l0000Booooo`Ko00000_ooool3o`000004ooooool0003o0000o`0000Kooooo0_l00005ooooo`;o
00006?ooool2o`00047ooooo1?l0001looooo`;o00003?ooool001kooooo00?o0000ooooooooool0
7_ooool2o`0000cooooo0_l0000Cooooo`Go00001_ooool2o`0000Sooooo0_l00004ooooo`?o0000
0oooool4o`00013ooooo0_l0000[ooooo`;o00005?ooool4o`0008[ooooo000Nooooo`03o`000?oo
oooooooo01kooooo0_l0000Qooooo`;o00000_ooool2o`0000Cooooo0_l00009ooooo`?o00000ooo
ool3o`0000?ooooo1?l00006ooooo`;o0000=Oooool2o`000:;ooooo000Nooooo`03o`000?oooooo
oooo03kooooo0_l00005ooooo`;o00001?ooool2o`0000[ooooo0_l00003ooooo`;o00001?ooool2
o`0000Sooooo0_l0000Eooooo`;o00000_ooool2o`0000Gooooo0_l0002gooooo`007_ooool00ol0
003oooooooooo`0nooooo`?o00000oooool3o`0000Cooooo0ol000000ooooooo0000o`000006oooo
o`Co00001_ooool3o`0001oooooo0_l00002ooooo`?o00001?ooool2o`0003Wooooo0_l0001loooo
o`007_ooool00ol0003oooooooooo`0Xooooo`;o00001Oooool2o`0000cooooo1_l000001?oooooo
0000o`000?ooool3o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`Ko000000?oooooo`00
0?l000000_l000000ooooooo0000o`000003o`000003ooooool0003o000000Sooooo0ol0000Doooo
o`;o0000=Oooool2o`0000Sooooo0_l0001looooo`007_ooool00ol0003oooooooooo`0Xooooo`;o
00001Oooool2o`0000_ooooo0ol00002ooooo`;o00001?ooool3o`0000Gooooo0ol00003ooooo`Ko
000000?oooooo`000?l000000_l000000ooooooo0000o`000003o`000003ooooool0003o000000So
oooo0ol00009ooooo`;o0000@?ooool2o`0008Kooooo000Nooooo`03o`000?oooooooooo03cooooo
0ol00006ooooo`Co00001_ooool4o`0000Kooooo0_l00004ooooo`;o000000Coooooo`000?l0003o
00006?ooool2o`000<Sooooo000Nooooo`03o`000?oooooooooo03gooooo0_l000000ooooooo0000
o`000003ooooo`?o00001oooool8o`0000Sooooo0_l000001?oooooo0000o`000?l0003Rooooo`00
7_ooool00ol0003oooooooooo`03ooooo`;o00009?ooool2o`0000cooooo0_l00002ooooo`;o0000
0oooool2o`0000?ooooo0ol00002ooooo`;o00001Oooool6o`000003ooooool0003o000000?ooooo
0_l0000booooo`;o0000]?ooool001kooooo00?o0000ooooooooool00oooool2o`0002Cooooo0_l0
0005ooooo`;o00000oooool4o`0000;ooooo0_l00003ooooo`;o00002?ooool2o`0000Sooooo0_l0
0002ooooo`;o00000oooool2o`0003;ooooo0_l0000Fooooo`;o0000Toooool3o`0000Kooooo000N
ooooo`;o0000<Oooool2o`0000?ooooo0_l00003ooooo`;o00001oooool2o`00017ooooo1ol0000N
ooooo`;o0000;?ooool2o`0009?ooooo0ol00006ooooo`007_ooool00ol0003oooooooooo`0Moooo
o`;o00006Oooool4o`0000Oooooo1?l0000=ooooo`Wo00007_ooool2o`000;kooooo0_l0000:oooo
o`007_ooool00ol0003oooooooooo`0Mooooo`;o00005_ooool2o`000003ooooool0003o000000_o
oooo0_l0000=ooooo`Wo0000U?ooool2o`0004Sooooo0_l0000:ooooo`007_ooool00ol0003ooooo
ooooo`0Hooooo`;o00001oooool2o`0000Oooooo1?l00007ooooo`;o00005Oooool2o`0000Gooooo
0_l000000ooooooo0000o`000002o`0000Sooooo0_l0000fooooo`;o0000EOooool2o`0005Cooooo
000Nooooo`03o`000?oooooooooo01Sooooo0_l00007ooooo`;o00001oooool4o`0000Kooooo1?l0
0008ooooo`Go00001oooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool4o`0000Sooooo
0_l0000fooooo`;o0000Zoooool001kooooo00?o0000ooooooooool0=?ooool4o`0000Oooooo1_l0
0006ooooo`;o00000_ooool3o`0000kooooo0_l0003Uooooo`007_ooool3o`0003oooooo0ol00000
0ooooooo0000o`000002o`0000;ooooo1?l00002ooooo`;o00000oooool2o`0000Oooooo0_l00000
0ooooooo0000o`00003Uooooo`007_ooool3o`0000cooooo0_l0000Jooooo`;o000000?oooooo`00
0?l000003_ooool2o`0000?ooooo1ol00002ooooo`?o00002?ooool2o`0000Gooooo1?l0000Boooo
o`;o00003_ooool2o`0002kooooo0_l0002Dooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o
00006_ooool2o`000003ooooool0003o000000?ooooo1?l00006ooooo`?o00000_ooool4o`000003
ooooool0003o000000Cooooo0_l00003ooooo`;o000000?oooooo`000?l000001?ooool2o`000003
ooooool0003o000000Cooooo0_l0000>ooooo`;o00003_ooool2o`0002kooooo0_l0002Dooooo`00
7_ooool00ol0003oooooooooo`0`ooooo`Co00001_ooool2o`0000?ooooo0_l00003ooooo`;o0000
0_ooool2o`0000?ooooo1?l000000ooooooo0000o`000002ooooo`Co00001oooool4o`0001gooooo
0_l00033ooooo`007_ooool00ol0003oooooooooo`0aooooo`;o00001oooool2o`0000?ooooo1?l0
00000ooooooo0000o`000002ooooo`;o00000oooool2o`0000Oooooo0_l00008ooooo`;o000000?o
ooooo`000?l000003oooool2o`0000_ooooo0ol00033ooooo`007_ooool00ol0003oooooooooo`0=
ooooo`;o00006Oooool2o`000003ooooool0003o000000Ko00001oooool2o`0000Cooooo0ol00000
0ooooooo0000o`000002ooooo`?o00005Oooool2o`0001;ooooo0_l0000;ooooo`;o0000R?ooool2
o`0003[ooooo000Nooooo`03o`000?oooooooooo00gooooo0_l0000Iooooo`;o000000?oooooo`00
0?l000001?l00006ooooo`;o00001Oooool2o`000003ooooool0003o000000;ooooo0_l000001?oo
oooo0000o`000?l00009ooooo`;o00001oooool2o`0000Sooooo0ol00010ooooo`?o0000>?ooool2
o`0002Cooooo0_l0000jooooo`007_ooool00ol0003oooooooooo`06ooooo`;o00008_ooool2o`00
0003ooooool0003o000000Sooooo0_l00005ooooo`;o00001Oooool3o`0000Sooooo0_l00002oooo
o`?o00001_ooool3o`0000Oooooo0ol00010ooooo`?o0000>?ooool2o`00063ooooo0003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006
ooooo`03o`000?oooooooooo00Kooooo0_l0000Rooooo`;o00004_ooool2o`0000Kooooo0_l00007
ooooo`?o00000oooool2o`0000?ooooo0_l00002ooooo`;o0000B_ooool2o`00087ooooo0_l0000H
ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9So
oooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0nooooo`?o00002_ooool6o`0000Kooooo0_l0
00001?oooooo0000o`000?ooool2o`0000Sooooo0_l00034ooooo`;o00006?ooool000?ooooo00Go
410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`0003oo
oooo1_l00003ooooo`Oo00002?ooool2o`0000Cooooo0_l00005ooooo`;o000000?oooooo`000?l0
00005?ooool2o`000<3ooooo0_l00006ooooo`000oooool01Ol0003ooooooooooooooooo000000_o
oooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooooooo023ooooo0_l0000Ooooo
o`Co000000?oooooo`000?l000002?l00002ooooo`;o00000_ooool2o`0000cooooo0_l0000Goooo
o`;o0000:Oooool3o`0009Cooooo0_l00006ooooo`000oooool01Ol0003ooooooooooooooooo0000
00_ooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo023ooooo0_l0000B
ooooo`;o00002_oooolDo`0000;ooooo0_l0001@ooooo`?o0000W?ooool000?ooooo00Go410@oooo
oooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`0Qooooo`;o00004Oooool2o`0000[ooooo1ol00003ooooo`Wo00000_ooool2o`0003_ooooo0_l0
000Dooooo`;o0000Qoooool2o`0001Cooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool08Oooool2o`0001_ooooo
0_l000000ooooooo0000o`000003ooooo`;o000000Coooooo`000?l0003ooooo1?l00005ooooo`;o
00002?ooool2o`0000Sooooo0_l0000<ooooo`;o00006Oooool3o`0003?ooooo0_l0001Wooooo`;o
00005?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@
4?nYZJT01_ooool00ol0003oooooooooo`0_ooooo`;o00003Oooool2o`000003ooooool0003o0000
00?ooooo0_l000001?oooooo0000o`000?ooool2o`0000Cooooo1_l00007ooooo`;o00002?ooool2
o`0000cooooo0_l0000Jooooo`;o0000<oooool2o`00063ooooo0_l0000Kooooo`007_ooool00ol0
003oooooooooo`0_ooooo`;o00003oooool4o`0000kooooo0ol000000ooooooo0000o`00003Boooo
o`;o00006oooool001kooooo00?o0000ooooooooool0@?ooool4o`0000Kooooo0_l000000ooooooo
0000o`00000:ooooo`;o0000GOooool2o`0008gooooo000Nooooo`03o`000?oooooooooo02kooooo
0_l0000;ooooo`;o00001oooool2o`0000Cooooo0_l000001?oooooo0000o`000?l00009ooooo`;o
00001oooool4o`0003cooooo0_l0000Dooooo`;o0000SOooool001kooooo00?o0000ooooooooool0
;_ooool2o`0000_ooooo0_l00007ooooo`;o00001Oooool6o`0000;ooooo0_l0000=ooooo`Co0000
4oooool2o`0000cooooo0_l0000Iooooo`;o0000SOooool2o`0001Cooooo000Nooooo`03o`000?oo
oooooooo04_ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`00023ooooo
0_l0000<ooooo`;o00004?ooool2o`0009Kooooo0_l0000Dooooo`007_ooool00ol0003ooooooooo
o`1@ooooo`Co00000oooool2o`000003ooooool0003o000003gooooo0_l0000Kooooo`;o0000M_oo
ool2o`0001Oooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l0000Dooooo`;o00005?ooool2
o`000003ooooool0003o000000Wooooo0_l00005ooooo`Go00000oooool2o`0000;ooooo0_l00009
ooooo`Co0000=?ooool2o`0000kooooo0_l0001fooooo`;o000000?oooooo`000?l000005?ooool0
01kooooo00?o0000ooooooooool05_ooool2o`0001Cooooo0_l0000Dooooo`;o000000?oooooo`00
0?l000003oooool2o`000003ooooool0003o000000;o00000_ooool2o`0000;ooooo0_l00004oooo
o`;o00000oooool4o`0001Cooooo0_l0000Nooooo`;o0000Q_ooool2o`000003ooooool0003o0000
01Cooooo000Nooooo`03o`000?oooooooooo04cooooo0_l00008ooooo`;o000000?oooooo`000?l0
00000_l000000ooooooo0000o`000004ooooo`;o00000oooool2o`0000Cooooo0_l0000Eooooo`;o
00001_ooool2o`000;Oooooo000Nooooo`03o`000?oooooooooo04Wooooo0_l000000ooooooo0000
o`000009ooooo`Co00000oooool3o`0000?ooooo0_l00003ooooo`;o00001oooool2o`0001;ooooo
0_l00006ooooo`;o0000]oooool001kooooo00?o0000ooooooooool0BOooool3o`0000_ooooo1Ol0
0003ooooo`;o00004Oooool2o`0000;ooooo0_l00005ooooo`Co00006oooool2o`00033ooooo0_l0
001/ooooo`;o00002Oooool001kooooo0_l0000Hooooo`;o00001Oooool2o`00027ooooo0_l00006
ooooo`?o00003?ooool4o`0001[ooooo0_l00004ooooo`Go00006oooool2o`00033ooooo0_l0001R
ooooo`;o00002?ooool2o`0000Wooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l00005oooo
o`;o00008Oooool2o`0000Kooooo1?l0000;ooooo`Co00006?ooool2o`0000Kooooo1?l00003oooo
o`;o0000[Oooool2o`0001?ooooo000Nooooo`03o`000?oooooooooo04[ooooo1?l0000<ooooo`;o
000000?oooooo`000?l000001?ooool2o`0000oooooo0_l00002ooooo`;o00001?ooool2o`0000?o
oooo0_l0002Yooooo`;o00005oooool001kooooo00?o0000ooooooooool0=?ooool2o`0001Cooooo
1?l0000<ooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo0_l0000?ooooo`;o0000
2Oooool2o`000:Wooooo0_l0000@ooooo`;o00001Oooool001kooooo00?o0000ooooooooool0=?oo
ool2o`0001Cooooo0_l0000?ooooo`?o00002Oooool4o`0000;ooooo0_l0000Dooooo`;o00006_oo
ool2o`0009oooooo0_l00005ooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o0000<Oooool2
o`0000;ooooo0_l0000>ooooo`Co00000_ooool2o`0000Kooooo0ol00002ooooo`;o0000<?ooool2
o`000:Kooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l00008ooooo`;o0000<Oooool2o`00
00Kooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000000Cooooo0_l00006oooo
o`;o0000A_ooool2o`0009Gooooo000Nooooo`03o`000?oooooooooo00Oooooo1?l00002ooooo`;o
0000?oooool2o`0000;ooooo0_l00003ooooo`;o00007Oooool2o`0000[ooooo0_l0000/ooooo`;o
00002_ooool2o`0000Gooooo0_l00022ooooo`007_ooool00ol0003oooooooooo`07ooooo`;o0000
1?ooool2o`0001Gooooo0_l0000]ooooo`;o00008Oooool2o`0000[ooooo0_l0000eooooo`;o0000
00?oooooo`000?l000001Oooool2o`0005Sooooo0_l0000Xooooo`007_ooool00ol0003ooooooooo
o`0;ooooo`;o00005oooool2o`0001Oooooo0_l0000@ooooo`;o00000_ooool2o`0000Sooooo0ol0
000=ooooo`;o00004_ooool2o`0003Kooooo0_l0000Wooooo`;o0000>Oooool2o`0002Sooooo000N
ooooo`?o00002oooool2o`0001[ooooo0_l00003ooooo`;o00003oooool2o`000003ooooool0003o
000000gooooo0_l0000<ooooo`Go00002oooool3o`0000cooooo0_l00003ooooo`;o0000Goooool2
o`0005_ooooo0_l00006ooooo`007_ooool3o`0001Oooooo0_l0000>ooooo`;o00000oooool2o`00
01;ooooo0_l0000@ooooo`;o00002Oooool5o`0000cooooo0_l0000<ooooo`;o0000;Oooool2o`00
09;ooooo0_l00006ooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o00004?ooool2o`0002Oo
oooo0_l00009ooooo`Co00003Oooool2o`00013ooooo0_l00004ooooo`;o00008oooool2o`0009[o
oooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0000Eooooo`;o00001_ooool2o`0001;ooooo
0_l0000>ooooo`;o00000oooool2o`0000Kooooo0_l00003ooooo`;o00003Oooool2o`00013ooooo
0_l000001?oooooo0000o`000?ooool2o`0002gooooo0_l0002@ooooo`007_ooool01?l0003ooooo
o`000?l00009ooooo`;o00005Oooool2o`0000cooooo0_l0000<ooooo`;o00003_ooool2o`0000?o
oooo1?l00004ooooo`Co00001Oooool2o`000003ooooool0003o000001Oooooo0ol000001?oooooo
0000o`000?ooool2o`0002gooooo0_l0002@ooooo`007_ooool01?l0003oooooo`000?l0000^oooo
o`;o00008oooool2o`0000Cooooo1?l000000ooooooo0000o`000007o`0000Oooooo0_l0000:oooo
o`;o00000_ooool5o`0002oooooo0_l0002Booooo`007_ooool2o`0001gooooo0_l0000fooooo`;o
00002?ooool=o`0000Cooooo0_l00002ooooo`;o00001Oooool3o`0000Gooooo0_l0000_ooooo`;o
0000T_ooool001kooooo00?o0000ooooooooool07?ooool2o`0001kooooo0_l0000Pooooo`So0000
00?oooooo`000?l000000_l00006ooooo`Co00001Oooool2o`000<_ooooo000Nooooo`03o`000?oo
oooooooo03cooooo0_l0000=ooooo`;o00002Oooool2o`000003ooooool0003o000000;ooooo0_l0
00001?oooooo0000o`000?ooool5o`0000;ooooo0_l00005ooooo`;o0000e?ooool001kooooo00?o
0000ooooooooool0Boooool2o`0000Wooooo0_l000000ooooooo0000o`000002ooooo`;o000000?o
ooooo`000?l000001_l00002ooooo`;o00002oooool2o`000:;ooooo0_l0000Zooooo`007_ooool0
1?l0003oooooooooooooool4o`0004Gooooo0ol000000ooooooo0000o`00000>ooooo`[o00001?oo
ool2o`0000Wooooo0_l00009ooooo`;o0000Uoooool2o`0002[ooooo000Nooooo`04o`000?oooooo
ooooooooo`Co00009_ooool2o`0001_ooooo2Ol0000=ooooo`;o000000?oooooo`000?l000001Ol0
0004ooooo`;o00005?ooool2o`00047ooooo0_l00020ooooo`007_ooool00ol0003oooooooooo`0[
ooooo`;o00003_ooool2o`0000_ooooo2Ol0000:ooooo`;o000000?oooooo`000?l000001Ol00000
0ooooooo0000o`000002o`000003ooooool0003o000000;o00002?ooool2o`0003Sooooo0_l0000B
ooooo`;o0000P?ooool001kooooo00?o0000ooooooooool0>oooool2o`0000_ooooo1?l0000?oooo
o`;o00000oooool5o`0000?ooooo0_l000000ooooooo0000o`000002o`0000Sooooo0_l000000ooo
oooo0000o`000003ooooo`;o0000<?ooool2o`0009Cooooo000Nooooo`03o`000?oooooooooo00Ko
oooo0_l00004ooooo`;o00000oooool2o`0003?ooooo0_l00002ooooo`;o00005oooool2o`0000?o
oooo1_l0000<ooooo`;o00000oooool2o`000<Kooooo000Nooooo`03o`000?oooooooooo00Kooooo
0_l00004ooooo`;o00000oooool2o`00033ooooo1ol0000>ooooo`;o00002Oooool2o`0000?ooooo
1Ol0000Booooo`;o0000_?ooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo04?ooooo1?l0
00000ooooooo0000o`00000>ooooo`;o00002?ooool2o`0000Oooooo0_l0000<ooooo`;o00001?oo
ool2o`00063ooooo0_l0001Jooooo`;o00002?ooool001kooooo00?o0000ooooooooool0Coooool6
o`0000?ooooo0ol00007ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Cooooo0_l00006
ooooo`;o0000I_ooool2o`0006Cooooo000Nooooo`03o`000?oooooooooo047ooooo0_l0000<oooo
o`Ko000000Coooooo`000?l0003ooooo0_l00005ooooo`Co000000?oooooo`000?l000000_ooool4
o`0000Cooooo0_l00003ooooo`Go0000c?ooool001kooooo00Co0000ooooool0003o00008Oooool2
o`0001Kooooo0_l00005ooooo`;o00001?ooool2o`0000Wooooo1_l00006ooooo`Co00001oooool4
o`0000Wooooo0ol0003>ooooo`007_ooool01?l0003oooooo`000?l00007ooooo`;o00006?ooool2
o`0001Kooooo0_l00008ooooo`;o000000?oooooo`000?l000001oooool2o`000003ooooool0003o
000000;o00001oooool2o`0000gooooo1?l0003Fooooo`007_ooool00ol0003oooooooooo`08oooo
o`;o0000<?ooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000002oooo
o`;o00001?ooool4o`0000?ooooo0_l0000Fooooo`Co0000>oooool2o`0009Wooooo000Nooooo`;o
0000>oooool2o`000003ooooool0003o000000Co00001Oooool2o`0000Cooooo0_l0000Hooooo`;o
00002_ooool2o`00013ooooo0_l0000Tooooo`;o0000VOooool001kooooo00?o0000ooooooooool0
1?ooool2o`0003Wooooo0_l00002ooooo`;o00002oooool4o`0000_ooooo0ol00006ooooo`;o0000
2_ooool2o`0000;ooooo0_l0000<ooooo`;o0000_oooool001kooooo00?o0000ooooooooool01?oo
ool2o`0003Gooooo0ol00005ooooo`;o00002oooool4o`0000_ooooo0ol0000Fooooo`;o0000cOoo
ool001kooooo00?o0000ooooooooool0>oooool3o`0002?ooooo0_l00002ooooo`;o0000f?ooool2
o`0000Kooooo000Nooooo`03o`000?oooooooooo02kooooo0_l0000?ooooo`;o00000oooool2o`00
01_ooooo0ol000000ooooooo0000o`00003Hooooo`;o00001_ooool001kooooo00?o0000oooooooo
ool0;_ooool2o`0000Cooooo0_l00009ooooo`;o000000?oooooo`000?l000000_l00005ooooo`;o
000000?oooooo`000?l000002?ooool4o`0000Kooooo0ol00030ooooo`;o00008?ooool001kooooo
00?o0000ooooooooool0=?ooool3o`0000_ooooo1?l00005ooooo`;o000000?oooooo`000?l00000
1?ooool2o`0000;ooooo1?l00007ooooo`;o0000`?ooool2o`00023ooooo000Nooooo`03o`000?oo
oooooooo01Wooooo0_l0000Iooooo`?o000000Coooooo`000?l0003ooooo0_l00007ooooo`Co0000
2Oooool2o`000003ooooool0003o00000?7ooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l0
000Gooooo`;o00001?ooool2o`000004ooooool0003o0000o`0000Sooooo0_l00009ooooo`;o0000
2_ooool4o`000>Kooooo000Nooooo`03o`000?oooooooooo03;ooooo0_l00008ooooo`;o00002?oo
ool4o`0001?ooooo1?l0001>ooooo`;o0000U_ooool001kooooo00?o0000ooooooooool0;_ooool2
o`0000cooooo0_l0000:ooooo`;o00001?ooool2o`0001;ooooo0_l0001;ooooo`;o0000U_ooool0
01kooooo00?o0000ooooooooool0:_ooool2o`000003ooooool0003o000000;o00001oooool2o`00
00;ooooo0_l0000>ooooo`Co00004_ooool4o`000>7ooooo000Nooooo`03o`000?oooooooooo00_o
oooo0_l0000Mooooo`;o000000?oooooo`000?l000000_l00007ooooo`;o00004_ooool2o`0000So
oooo0_l0000<ooooo`;o0000LOooool2o`0006kooooo000Nooooo`03o`000?oooooooooo00Kooooo
0_l00003ooooo`;o00008_ooool2o`0001oooooo0_l00004ooooo`;o0000Ooooool2o`0006kooooo
000Dooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`06ooooo`;o00009ooo
ool2o`0001Sooooo0_l00005ooooo`;o00005?ooool2o`0000_ooooo0_l0000dooooo`;o0000W?oo
ool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`19ooooo`;o00001Oooool4
o`0001;ooooo0_l0000;ooooo`;o0000=?ooool2o`0009cooooo000Fooooo`03o`000?oooooooooo
00Gooooo0ol0001@ooooo`Co0000loooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`00
5_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?oo
ool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005?ooool00omEEEGoIVIVo`00003ooooo
oe;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.21866 .73508 Mdot
.25887 .05795 Mdot
.17939 .80477 Mdot
.35566 .85378 Mdot
.29461 .84784 Mdot
.29762 .84534 Mdot
.5964 .53359 Mdot
.25605 .8547 Mdot
.33959 .90774 Mdot
.12035 .21688 Mdot
.22316 .04768 Mdot
.14261 .00614 Mdot
.21212 .79213 Mdot
.54821 .88483 Mdot
.26495 .82907 Mdot
.39452 .08208 Mdot
.29293 .40054 Mdot
.23586 .7254 Mdot
.18904 .72021 Mdot
.36756 .86212 Mdot
.03766 .23103 Mdot
.27542 .86197 Mdot
.17212 .80115 Mdot
.13854 .61424 Mdot
.35176 .92935 Mdot
.2613 .92109 Mdot
.29256 .918 Mdot
.38992 .04609 Mdot
.20932 .05088 Mdot
.27028 .84255 Mdot
.20118 .72681 Mdot
.26841 .8329 Mdot
.31095 .95959 Mdot
.93212 .88916 Mdot
.19904 .74093 Mdot
.36821 .95849 Mdot
.57143 .87123 Mdot
.081 .46983 Mdot
.11487 .94196 Mdot
.32864 .92728 Mdot
.19009 .72673 Mdot
.35166 .79349 Mdot
.46272 .90925 Mdot
.16124 .44122 Mdot
.51847 .74663 Mdot
.34727 .8188 Mdot
.93213 .69878 Mdot
.37779 .87764 Mdot
.33103 .98308 Mdot
.31959 .75143 Mdot
.18988 .03142 Mdot
.32042 .70252 Mdot
.27223 .89288 Mdot
.37712 .98667 Mdot
.26396 .86699 Mdot
.14951 .24958 Mdot
.35773 .77577 Mdot
.24054 .81044 Mdot
.2885 .91487 Mdot
.26521 .66817 Mdot
.31201 .83608 Mdot
.25964 .88032 Mdot
.557 .55762 Mdot
.3613 .93441 Mdot
.32559 .80961 Mdot
.30446 .86204 Mdot
.41247 .69977 Mdot
.29095 .91926 Mdot
.2821 .82489 Mdot
.25223 .73785 Mdot
.01842 .38938 Mdot
.20427 .76426 Mdot
.27961 .94789 Mdot
.26395 .47336 Mdot
.23281 .96532 Mdot
.28831 .7071 Mdot
.33012 .70025 Mdot
.27657 .18586 Mdot
.28321 .88108 Mdot
.17972 .76637 Mdot
.28204 .83253 Mdot
.24952 .4598 Mdot
.13807 .42886 Mdot
.25138 .85796 Mdot
.62486 .47661 Mdot
.92346 .38768 Mdot
.289 .898 Mdot
.32962 .91835 Mdot
.27124 .82072 Mdot
.23874 .70194 Mdot
.41927 .91653 Mdot
.41084 .72015 Mdot
.30594 .81148 Mdot
.07179 .34954 Mdot
.23134 .66802 Mdot
.30399 .79008 Mdot
.48693 .45166 Mdot
.27373 .71087 Mdot
.38285 .95283 Mdot
.05596 .87321 Mdot
.25233 .8675 Mdot
.19668 .01529 Mdot
.24844 .70356 Mdot
.51194 .97438 Mdot
.20489 .07667 Mdot
.18634 .79616 Mdot
.37087 .11598 Mdot
.39998 .09181 Mdot
.36949 .71342 Mdot
.42155 .29613 Mdot
.53762 .89469 Mdot
.10867 .39469 Mdot
.20841 .87856 Mdot
.22934 .72765 Mdot
.70011 .16392 Mdot
.3565 .5679 Mdot
.48873 .7491 Mdot
.19366 .79865 Mdot
.11176 .05702 Mdot
.32997 .79129 Mdot
.29789 .94223 Mdot
.42818 .82919 Mdot
.25694 .90526 Mdot
.07722 .35742 Mdot
.47063 .922 Mdot
.00182 .07001 Mdot
.31742 .03546 Mdot
.20952 .71621 Mdot
.9269 .90806 Mdot
.22175 .95876 Mdot
.04078 .13256 Mdot
.36172 .21956 Mdot
.76865 .17941 Mdot
.22403 .70243 Mdot
.21705 .68398 Mdot
.21987 .78204 Mdot
.1996 .80133 Mdot
.30306 .96713 Mdot
.20927 .74107 Mdot
.31449 .86682 Mdot
.22289 .70026 Mdot
.36745 .94145 Mdot
.29236 .8834 Mdot
.10988 .82233 Mdot
.46335 .2127 Mdot
.16375 .99578 Mdot
.27441 .68967 Mdot
.28496 .89598 Mdot
.2797 .77961 Mdot
.3782 .4104 Mdot
.42206 .83245 Mdot
.29659 .92639 Mdot
.13345 .99692 Mdot
.36815 .87456 Mdot
.2699 .85352 Mdot
.20718 .8204 Mdot
.31542 .02961 Mdot
.06176 .67507 Mdot
.33799 .90858 Mdot
.35251 .10473 Mdot
.24392 .87434 Mdot
.13138 .80191 Mdot
.17755 .34836 Mdot
.21932 .7044 Mdot
.37973 .94504 Mdot
.28899 .86111 Mdot
.29385 .88975 Mdot
.32016 .9053 Mdot
.46054 .33368 Mdot
.24554 .74509 Mdot
.26053 .88689 Mdot
.18399 .80414 Mdot
.16508 .76852 Mdot
.24228 .76673 Mdot
.20727 .7317 Mdot
.23613 .00465 Mdot
.03726 .69407 Mdot
.23075 .91633 Mdot
.55372 .46043 Mdot
.30808 .70049 Mdot
.46262 .91917 Mdot
.21383 .02226 Mdot
.11563 .87345 Mdot
.46331 .74474 Mdot
.02299 .55709 Mdot
.18358 .8968 Mdot
.34453 .09793 Mdot
.436 .90633 Mdot
.69482 .05053 Mdot
.10899 .88517 Mdot
.20608 .72642 Mdot
.9689 .33244 Mdot
.21712 .7199 Mdot
.32964 .88166 Mdot
.28779 .7922 Mdot
.4658 .9012 Mdot
.12543 .79348 Mdot
.19642 .95166 Mdot
.34097 .91232 Mdot
.26511 .9481 Mdot
.49835 .54317 Mdot
.73224 .18162 Mdot
.21301 .69459 Mdot
.49172 .74542 Mdot
.35296 .93075 Mdot
.33399 .91537 Mdot
.3587 .49701 Mdot
.30343 .90966 Mdot
.55443 .44871 Mdot
.31389 .00478 Mdot
.25436 .78332 Mdot
.236 .70606 Mdot
.41101 .58358 Mdot
.94343 .40862 Mdot
.28273 .93648 Mdot
.0211 .42204 Mdot
.31896 .90085 Mdot
.07964 .14425 Mdot
.27428 .06637 Mdot
.40525 .70054 Mdot
.56008 .76219 Mdot
.19512 .68353 Mdot
.37112 .95007 Mdot
.31555 .89452 Mdot
.21819 .68732 Mdot
.19732 .81134 Mdot
.13376 .92164 Mdot
.17791 .81402 Mdot
.15217 .472 Mdot
.29589 .87766 Mdot
.22393 .8644 Mdot
.27627 .67984 Mdot
.28768 .89089 Mdot
.0049 .84018 Mdot
.02328 .43623 Mdot
.15783 .6354 Mdot
.05553 .03712 Mdot
.19595 .75602 Mdot
.06411 .3946 Mdot
.20088 .78767 Mdot
.24501 .86206 Mdot
.27986 .87947 Mdot
.43388 .91981 Mdot
.32372 .78921 Mdot
.09544 .91666 Mdot
.37982 .66055 Mdot
.18996 .69747 Mdot
.26201 .88187 Mdot
.9038 .79986 Mdot
.17992 .74559 Mdot
.32686 .69283 Mdot
.26432 .85926 Mdot
.83356 .4194 Mdot
.91774 .42394 Mdot
.47532 .02967 Mdot
.4143 .92206 Mdot
.28716 .89584 Mdot
.08152 .35724 Mdot
.27718 .80961 Mdot
.70528 .20127 Mdot
.23574 .71898 Mdot
.30633 .7216 Mdot
.20172 .13849 Mdot
.1476 .51951 Mdot
.28616 .88493 Mdot
.96159 .3514 Mdot
.18628 .91622 Mdot
.37257 .3589 Mdot
.19036 .77456 Mdot
.31346 .92677 Mdot
.38187 .95153 Mdot
.16379 .62597 Mdot
.28103 .82128 Mdot
.30358 .72371 Mdot
.26123 .83761 Mdot
.23568 .83029 Mdot
.27604 .06247 Mdot
.49964 .35434 Mdot
.36565 .98256 Mdot
.17803 .98685 Mdot
.45804 .80379 Mdot
.27313 .86644 Mdot
.19859 .72531 Mdot
.56198 .81402 Mdot
.29332 .87498 Mdot
.37029 .94865 Mdot
.2441 .72959 Mdot
.08929 .98588 Mdot
.43707 .88416 Mdot
.22065 .07261 Mdot
.43528 .9397 Mdot
.43367 .66873 Mdot
.18908 .71882 Mdot
.25676 .93148 Mdot
.51415 .39523 Mdot
.1046 .88715 Mdot
.29626 .80235 Mdot
.32404 .07155 Mdot
.46963 .84628 Mdot
.28155 .42293 Mdot
.08488 .03922 Mdot
.36967 .98039 Mdot
.15188 .76971 Mdot
.18966 .70311 Mdot
.20385 .21787 Mdot
.3997 .70091 Mdot
.29448 .91291 Mdot
.2798 .88242 Mdot
.5048 .7256 Mdot
.71797 .18272 Mdot
.30167 .92817 Mdot
.45126 .87287 Mdot
.25927 .91595 Mdot
.12743 .72327 Mdot
.36583 .91948 Mdot
.41254 .95364 Mdot
.17747 .88584 Mdot
.17443 .70677 Mdot
.32082 .98989 Mdot
.16019 .42199 Mdot
.1159 .94215 Mdot
.29309 .95025 Mdot
.18077 .02778 Mdot
.15713 .88254 Mdot
.22235 .71412 Mdot
.2165 .85382 Mdot
.3623 .98198 Mdot
.24705 .70948 Mdot
.16294 .0234 Mdot
.23738 .8736 Mdot
.39813 .87688 Mdot
.29283 .83719 Mdot
.51968 .38936 Mdot
.55787 .08825 Mdot
.03174 .29746 Mdot
.34033 .37348 Mdot
.90297 .99381 Mdot
.29601 .93302 Mdot
.11236 .78816 Mdot
.95395 .37458 Mdot
.3785 .948 Mdot
.94705 .0134 Mdot
.24476 .69574 Mdot
.18948 .71451 Mdot
.32086 .7062 Mdot
.67415 .80473 Mdot
.47356 .3679 Mdot
.37971 .30508 Mdot
.14967 .33688 Mdot
.26108 .85497 Mdot
.18554 .79068 Mdot
.28266 .88209 Mdot
.05915 .87527 Mdot
.45245 .03305 Mdot
.55098 .47388 Mdot
.29288 .8277 Mdot
.32903 .79497 Mdot
.20736 .69512 Mdot
.23128 .78678 Mdot
.12045 .24039 Mdot
.26994 .87364 Mdot
.06867 .8991 Mdot
.19705 .72241 Mdot
.24283 .78698 Mdot
.37332 .96243 Mdot
.15952 .82312 Mdot
.54372 .89005 Mdot
.78571 .12315 Mdot
.12533 .70624 Mdot
.27328 .82733 Mdot
.27118 .89752 Mdot
.30066 .90668 Mdot
.17184 .78344 Mdot
.31311 .87536 Mdot
.11213 .83508 Mdot
.03458 .92255 Mdot
.54496 .72357 Mdot
.33848 .96419 Mdot
.29981 .55496 Mdot
.2613 .88064 Mdot
.28641 .87405 Mdot
.39733 .85552 Mdot
.02945 .62054 Mdot
.47027 .08377 Mdot
.34315 .06535 Mdot
.39673 .83425 Mdot
.4959 .952 Mdot
.42124 .4615 Mdot
.29764 .92777 Mdot
.5031 .87685 Mdot
.22186 .69805 Mdot
.27309 .78321 Mdot
.2448 .85655 Mdot
.28358 .83954 Mdot
.29367 .84638 Mdot
.50719 .43386 Mdot
.37149 .39807 Mdot
.01227 .38088 Mdot
.28749 .91666 Mdot
.21204 .71271 Mdot
.45283 .90696 Mdot
.5705 .77414 Mdot
.08639 .70329 Mdot
.25587 .87289 Mdot
.52917 .74558 Mdot
.97194 .91395 Mdot
.25206 .07886 Mdot
.22663 .74036 Mdot
.16475 .7395 Mdot
.22273 .70772 Mdot
.26789 .88286 Mdot
.33793 .91911 Mdot
.25399 .87984 Mdot
.592 .58112 Mdot
.10923 .72233 Mdot
.23126 .71563 Mdot
.28029 .68365 Mdot
.21081 .83925 Mdot
.74638 .71463 Mdot
.27996 .88137 Mdot
.32139 .91586 Mdot
.84868 .9534 Mdot
.16449 .62699 Mdot
.26069 .75859 Mdot
.23911 .82433 Mdot
.5825 .82285 Mdot
.48415 .55294 Mdot
.32418 .89576 Mdot
.20535 .77422 Mdot
.53554 .43798 Mdot
.15548 .7577 Mdot
.0588 .89511 Mdot
.55394 .82613 Mdot
.40429 .85499 Mdot
.67219 .86714 Mdot
.64176 .81419 Mdot
.31257 .0854 Mdot
.0567 .94101 Mdot
.35309 .71234 Mdot
.52497 .73292 Mdot
.20327 .86951 Mdot
.1392 .43489 Mdot
.18598 .42206 Mdot
.29253 .82969 Mdot
.24243 .21189 Mdot
.29636 .86658 Mdot
.29072 .97253 Mdot
.28251 .80056 Mdot
.32178 .84967 Mdot
.13321 .75502 Mdot
.02012 .99103 Mdot
.39988 .72862 Mdot
.37594 .9456 Mdot
.2985 .88317 Mdot
.14401 .00147 Mdot
.29637 .92311 Mdot
.34673 .92291 Mdot
.37219 .97695 Mdot
.92822 .90794 Mdot
.69655 .93868 Mdot
.33522 .85374 Mdot
.32289 .90825 Mdot
.29559 .87038 Mdot
.20685 .86076 Mdot
.15068 .54608 Mdot
.26874 .70468 Mdot
.30078 .9605 Mdot
.99757 .06803 Mdot
.27498 .82425 Mdot
.12067 .80111 Mdot
.27137 .83506 Mdot
.28153 .89793 Mdot
.25552 .86074 Mdot
.25331 .85896 Mdot
.22376 .8157 Mdot
.27338 .84959 Mdot
.24997 .86097 Mdot
.23833 .83507 Mdot
.49168 .77034 Mdot
.33717 .99026 Mdot
.24411 .19702 Mdot
.30797 .85838 Mdot
.28004 .87207 Mdot
.2317 .68891 Mdot
.21925 .72842 Mdot
.92783 .43613 Mdot
.97704 .48684 Mdot
.29036 .01266 Mdot
.13627 .81617 Mdot
.42995 .02107 Mdot
.17661 .76867 Mdot
.32763 .91052 Mdot
.53559 .39923 Mdot
.51966 .91522 Mdot
.37949 .93872 Mdot
.20396 .94641 Mdot
.43364 .7512 Mdot
.2761 .99068 Mdot
.05707 .61299 Mdot
.16784 .90048 Mdot
.40928 .72165 Mdot
.19209 .96914 Mdot
.20687 .79885 Mdot
.1356 .62852 Mdot
.24083 .72829 Mdot
.35724 .72139 Mdot
.27445 .89756 Mdot
.51274 .42308 Mdot
.34326 .92398 Mdot
.28199 .85219 Mdot
.23637 .68018 Mdot
.21128 .09275 Mdot
.22457 .19026 Mdot
.04025 .66174 Mdot
.29547 .86795 Mdot
.02114 .83349 Mdot
.40949 .98145 Mdot
.29662 .78642 Mdot
.77918 .60755 Mdot
.22195 .70111 Mdot
.20255 .69021 Mdot
.21085 .83407 Mdot
.28582 .8782 Mdot
.25231 .92804 Mdot
.00496 .88314 Mdot
.86229 .68138 Mdot
.53577 .36382 Mdot
.50172 .28788 Mdot
.11815 .79118 Mdot
.93216 .91163 Mdot
.11913 .31583 Mdot
.44062 .18544 Mdot
.2952 .86939 Mdot
.1523 .97222 Mdot
.24545 .8524 Mdot
.25491 .88166 Mdot
.33573 .81878 Mdot
.34657 .95798 Mdot
.11951 .50189 Mdot
.45598 .29879 Mdot
.31335 .86501 Mdot
.10715 .73846 Mdot
.17405 .99956 Mdot
.27236 .85711 Mdot
.22599 .75905 Mdot
.5307 .4859 Mdot
.29705 .87977 Mdot
.09831 .78303 Mdot
.2046 .74154 Mdot
.21716 .84992 Mdot
.39341 .51751 Mdot
.49065 .57974 Mdot
.32665 .95632 Mdot
.96747 .71442 Mdot
.36899 .88309 Mdot
.67035 .72281 Mdot
.24049 .08502 Mdot
.29307 .9372 Mdot
.39576 .92453 Mdot
.72135 .14302 Mdot
.22548 .7323 Mdot
.30035 .01001 Mdot
.10997 .47964 Mdot
.99636 .88361 Mdot
.24235 .72723 Mdot
.33771 .98771 Mdot
.2736 .94725 Mdot
.37489 .94851 Mdot
.24216 .49031 Mdot
.27588 .82426 Mdot
.42685 .1363 Mdot
.4892 .99071 Mdot
.27618 .84473 Mdot
.26218 .69954 Mdot
.26405 .7814 Mdot
.31951 .91015 Mdot
.06144 .95998 Mdot
.21005 .05234 Mdot
.25592 .85524 Mdot
.42611 .69346 Mdot
.64721 .81389 Mdot
.41539 .71601 Mdot
.26585 .83536 Mdot
.21929 .69583 Mdot
.17362 .54046 Mdot
.34977 .93163 Mdot
.19135 .87656 Mdot
.533 .6291 Mdot
.50874 .84883 Mdot
.2702 .67023 Mdot
.23629 .82939 Mdot
.24898 .85158 Mdot
.18557 .72271 Mdot
.27448 .97094 Mdot
.15795 .97946 Mdot
.25573 .90645 Mdot
.28145 .05713 Mdot
.22285 .85165 Mdot
.35475 .94992 Mdot
.1942 .69412 Mdot
.31041 .91078 Mdot
.31217 .90684 Mdot
.17509 .78392 Mdot
.26943 .7118 Mdot
.6142 .71925 Mdot
.2167 .70494 Mdot
.30353 .91928 Mdot
.26498 .86613 Mdot
.56902 .65127 Mdot
.2234 .72562 Mdot
.53177 .62298 Mdot
.51047 .40506 Mdot
.26879 .80703 Mdot
.48213 .33249 Mdot
.1961 .72387 Mdot
.33401 .1211 Mdot
.21233 .78276 Mdot
.91775 .45206 Mdot
.38425 .96277 Mdot
.14116 .58996 Mdot
.30673 .75344 Mdot
.54038 .06465 Mdot
.21583 .72338 Mdot
.97376 .49334 Mdot
.32564 .73973 Mdot
.1844 .93415 Mdot
.03411 .3584 Mdot
.94346 .38481 Mdot
.23528 .83593 Mdot
.37248 .91468 Mdot
.22374 .77127 Mdot
.31974 .90041 Mdot
.27252 .67139 Mdot
.5993 .89448 Mdot
.279 .84348 Mdot
.11216 .24298 Mdot
.25017 .85427 Mdot
.36029 .62214 Mdot
.2875 .80667 Mdot
.26331 .81829 Mdot
.44109 .95752 Mdot
.28686 .83502 Mdot
.3577 .77475 Mdot
.40654 .98197 Mdot
.62534 .75554 Mdot
.19937 .68202 Mdot
.26854 .04284 Mdot
.42185 .75987 Mdot
.24238 .85853 Mdot
.56097 .64872 Mdot
.19394 .58061 Mdot
.2487 .01148 Mdot
.07413 .86204 Mdot
.31425 .88848 Mdot
.30933 .87255 Mdot
.33231 .92783 Mdot
.25213 .88316 Mdot
.59882 .95083 Mdot
.56748 .46102 Mdot
.29105 .91959 Mdot
.54819 .71994 Mdot
.18188 .81348 Mdot
.22523 .16507 Mdot
.30328 .95746 Mdot
.9668 .34733 Mdot
.93084 .9161 Mdot
.27873 .88226 Mdot
.56796 .47989 Mdot
.03854 .88518 Mdot
.9828 .94863 Mdot
.13178 .70909 Mdot
.2506 .13896 Mdot
.37016 .82972 Mdot
.2647 .90321 Mdot
.18003 .78527 Mdot
.26325 .90152 Mdot
.57451 .79962 Mdot
.26648 .77017 Mdot
.34078 .40313 Mdot
.58682 .43932 Mdot
.14716 .40269 Mdot
.10439 .83689 Mdot
.09097 .7009 Mdot
.20382 .72026 Mdot
.2766 .82604 Mdot
.1511 .79498 Mdot
.26768 .0317 Mdot
.44142 .35292 Mdot
.29478 .85875 Mdot
.23236 .7481 Mdot
.40105 .84897 Mdot
.47247 .7962 Mdot
.19319 .13602 Mdot
.43766 .07723 Mdot
.30191 .93281 Mdot
.18519 .79296 Mdot
.30112 .8772 Mdot
.46398 .22268 Mdot
.01327 .94117 Mdot
.26236 .51438 Mdot
.13549 .19696 Mdot
.46182 .02758 Mdot
.20219 .81486 Mdot
.21017 .73592 Mdot
.9616 .45292 Mdot
.26809 .91917 Mdot
.19958 .36551 Mdot
.14711 .61368 Mdot
.46078 .48853 Mdot
.33842 .92504 Mdot
.18172 .62721 Mdot
.2621 .81842 Mdot
.53943 .83002 Mdot
.21469 .40572 Mdot
.19095 .8233 Mdot
.67311 .4312 Mdot
.26819 .87651 Mdot
.2826 .85662 Mdot
.10576 .58212 Mdot
.26634 .8826 Mdot
.24647 .70493 Mdot
.0415 .69426 Mdot
.20515 .6915 Mdot
.56366 .35244 Mdot
.03628 .1299 Mdot
.44605 .70339 Mdot
.45406 .00679 Mdot
.29608 .95002 Mdot
.37876 .98999 Mdot
.42731 .75921 Mdot
.24297 .92772 Mdot
.25199 .89872 Mdot
.19432 .82377 Mdot
.32857 .88929 Mdot
.14891 .57604 Mdot
.50297 .20074 Mdot
.36425 .79257 Mdot
.2967 .99728 Mdot
.21903 .04213 Mdot
.56805 .53051 Mdot
.2871 .83548 Mdot
.37063 .84214 Mdot
.19151 .72296 Mdot
.40931 .49202 Mdot
.0424 .85825 Mdot
.29994 .03826 Mdot
.2648 .88225 Mdot
.39773 .77306 Mdot
.31011 .0121 Mdot
.04548 .49034 Mdot
.44382 .9123 Mdot
.22968 .76983 Mdot
.20617 .96924 Mdot
.24991 .72217 Mdot
.20077 .68865 Mdot
.37786 .92604 Mdot
.26119 .75706 Mdot
.32958 .86831 Mdot
.25029 .86682 Mdot
.18248 .75658 Mdot
.47483 .70073 Mdot
.25935 .85999 Mdot
.45487 .44483 Mdot
.24243 .76262 Mdot
.25569 .09251 Mdot
.32298 .83515 Mdot
.04745 .85035 Mdot
.16984 .7616 Mdot
.19577 .95236 Mdot
.44304 .44927 Mdot
.36263 .93489 Mdot
.26712 .90027 Mdot
.19373 .77116 Mdot
.26438 .85911 Mdot
.36193 .46381 Mdot
.21932 .69491 Mdot
.35127 .96808 Mdot
.17849 .76842 Mdot
.1433 .00889 Mdot
.35722 .35909 Mdot
.36026 .85114 Mdot
.22285 .8287 Mdot
.30472 .85907 Mdot
.03836 .93902 Mdot
.32366 .84917 Mdot
.31776 .04743 Mdot
.4286 .05108 Mdot
.31647 .86932 Mdot
.32595 .90929 Mdot
.20306 .83773 Mdot
.29168 .9806 Mdot
.12489 .7078 Mdot
.54787 .73859 Mdot
.24693 .93258 Mdot
.13901 .84279 Mdot
.25394 .88084 Mdot
.44875 .0154 Mdot
.34528 .07854 Mdot
.39149 .8875 Mdot
.19545 .70222 Mdot
.13319 .22238 Mdot
.26354 .86135 Mdot
.2595 .84385 Mdot
.26652 .82092 Mdot
.26596 .71568 Mdot
.22729 .71079 Mdot
.51256 .35055 Mdot
.15663 .22267 Mdot
.09433 .84526 Mdot
.19384 .68335 Mdot
.05461 .91366 Mdot
.38228 .91745 Mdot
.20619 .83769 Mdot
.49151 .91563 Mdot
.44473 .88539 Mdot
.30275 .89957 Mdot
.31347 .06811 Mdot
.31315 .78221 Mdot
.26874 .83907 Mdot
.56964 .47985 Mdot
.24906 .85351 Mdot
.2304 .84392 Mdot
.35333 .99635 Mdot
.20965 .81956 Mdot
.27915 .88377 Mdot
.31357 .99638 Mdot
.27766 .9024 Mdot
.38241 .95359 Mdot
.38889 .46737 Mdot
.18153 .70786 Mdot
.46046 .76065 Mdot
.11019 .99161 Mdot
.24812 .77095 Mdot
.27218 .52942 Mdot
.4061 .78257 Mdot
.2324 .72381 Mdot
.17093 .18782 Mdot
.33092 .98221 Mdot
.36263 .97354 Mdot
.83773 .71518 Mdot
.56909 .83044 Mdot
.22531 .8448 Mdot
.29163 .91198 Mdot
.3284 .89248 Mdot
.37435 .78604 Mdot
.59048 .569 Mdot
.99366 .03886 Mdot
.17887 .80126 Mdot
.25918 .90496 Mdot
.22912 .76528 Mdot
.10983 .45466 Mdot
.25796 .72543 Mdot
.18733 .72546 Mdot
.29009 .61805 Mdot
.29368 .94417 Mdot
.2769 .51222 Mdot
.2545 .8565 Mdot
.28597 .08948 Mdot
.33098 .97822 Mdot
.2546 .79122 Mdot
.23676 .85262 Mdot
.33465 .85015 Mdot
.33325 .92558 Mdot
.04102 .31274 Mdot
.25401 .9191 Mdot
.22081 .01107 Mdot
.18955 .72038 Mdot
.30038 .09397 Mdot
.53324 .11159 Mdot
.22581 .82824 Mdot
.59253 .02397 Mdot
.28674 .92824 Mdot
.36042 .9357 Mdot
.36622 .90171 Mdot
.29668 .86046 Mdot
.29229 .88119 Mdot
.46344 .50425 Mdot
.23859 .63615 Mdot
.58902 .77431 Mdot
.21065 .67937 Mdot
.01889 .83537 Mdot
.2916 .82648 Mdot
.25889 .86309 Mdot
.23011 .89124 Mdot
.43363 .73828 Mdot
.21721 .73301 Mdot
.24478 .72626 Mdot
.23387 .78266 Mdot
.27576 .86343 Mdot
.96597 .83464 Mdot
.12815 .61276 Mdot
.50619 .37996 Mdot
.44246 .72006 Mdot
.27418 .86905 Mdot
.825 .59058 Mdot
.29988 .82962 Mdot
.58294 .68044 Mdot
.26834 .81745 Mdot
.29002 .84614 Mdot
.35592 .95628 Mdot
.21613 .67924 Mdot
.18151 .94938 Mdot
.90392 .83379 Mdot
.37458 .72703 Mdot
.54128 .5116 Mdot
.57399 .09579 Mdot
.01579 .92847 Mdot
.28316 .70797 Mdot
.19087 .71626 Mdot
.25291 .68998 Mdot
.22392 .00334 Mdot
.93932 .85812 Mdot
.0991 .50828 Mdot
.34186 .94616 Mdot
.19571 .94005 Mdot
.46053 .23225 Mdot
.07946 .89549 Mdot
.35508 .87121 Mdot
.26327 .77873 Mdot
.32831 .89591 Mdot
.16069 .63625 Mdot
.14252 .11484 Mdot
.23481 .64317 Mdot
.24301 .85926 Mdot
.26425 .82475 Mdot
.08417 .34152 Mdot
.11401 .53934 Mdot
.14669 .01104 Mdot
.18391 .59287 Mdot
.56331 .45619 Mdot
.4225 .74425 Mdot
.21052 .79927 Mdot
.23064 .83349 Mdot
.28706 .88653 Mdot
.99933 .34363 Mdot
.2177 .70706 Mdot
.23101 .91881 Mdot
.25386 .8939 Mdot
.27918 .88631 Mdot
.97798 .51774 Mdot
.21969 .81718 Mdot
.18553 .7418 Mdot
.3522 .92859 Mdot
.52693 .45302 Mdot
.45171 .70138 Mdot
.29336 .84722 Mdot
.22193 .87567 Mdot
.41303 .69478 Mdot
.31759 .87075 Mdot
.28395 .23654 Mdot
.26485 .80722 Mdot
.56275 .9478 Mdot
.39152 .76131 Mdot
.9161 .27123 Mdot
.47851 .7363 Mdot
.17817 .81195 Mdot
.90205 .55527 Mdot
.1051 .06798 Mdot
.52924 .55251 Mdot
.44668 .9451 Mdot
.26916 .86327 Mdot
.30525 .89211 Mdot
.26724 .83439 Mdot
.26252 .67381 Mdot
.22508 .85652 Mdot
.53307 .43007 Mdot
.29866 .99186 Mdot
.20231 .83509 Mdot
.57176 .63218 Mdot
.44916 .32604 Mdot
.12506 .31919 Mdot
.12155 .82867 Mdot
.14412 .6092 Mdot
.54498 .47931 Mdot
.91585 .4794 Mdot
.26988 .88778 Mdot
.32428 .06899 Mdot
.39093 .10311 Mdot
.28772 .90241 Mdot
.27974 .92157 Mdot
.2738 .83039 Mdot
.19994 .67993 Mdot
.19901 .53513 Mdot
.34855 .09276 Mdot
.26782 .88528 Mdot
.40346 .73402 Mdot
.14921 .98766 Mdot
.33263 .3777 Mdot
.31668 .71699 Mdot
.28169 .91882 Mdot
.06504 .2714 Mdot
.36381 .85841 Mdot
.13329 .01156 Mdot
.35192 .08759 Mdot
.36965 .97353 Mdot
.29715 .95347 Mdot
.23498 .8376 Mdot
.27874 .85638 Mdot
.29083 .0201 Mdot
.24195 .90697 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`?o00004?ooool00ol0003o
ooooooooo`04ooooo`;o00001oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool4o`00013ooooo
00?o0000ooooooooool01?ooool2o`0000;ooooo0_l00003ooooo`03o`000?oooooooooo00gooooo
00Co0000oooooooooooooooo0_l0000:ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool03Oooool3o`0000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`00
7_ooool00ol0003oooooooooo`0Zooooo`;o00007Oooool2o`0001?ooooo0_l00002ooooo`;o0000
;?ooool2o`000;Gooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l000000ooooooo0000o`00
0002o`0001Kooooo0_l00007ooooo`;o00002oooool2o`0000;ooooo0_l000000ooooooo0000o`00
003=ooooo`;o00005Oooool001kooooo00?o0000ooooooooool09oooool2o`0000?ooooo0_l0000>
ooooo`;o00001_ooool2o`0000Oooooo0_l0000;ooooo`;o00001Oooool2o`0002_ooooo0_l0002P
ooooo`;o00005Oooool001kooooo00?o0000ooooooooool0??ooool2o`00053ooooo0_l0002goooo
o`007_ooool00ol0003oooooooooo`11ooooo`;o00005oooool2o`0002cooooo0_l0002mooooo`00
7_ooool00ol0003oooooooooo`0aooooo`;o00003_ooool2o`0001Oooooo0_l0000/ooooo`;o0000
<oooool2o`0008Sooooo000Nooooo`03o`000?oooooooooo037ooooo0_l00004ooooo`;o0000FOoo
ool2o`0002Wooooo0_l00028ooooo`007_ooool00ol0003oooooooooo`0gooooo`;o000000?ooooo
o`000?l000005oooool2o`0000gooooo0_l0000^ooooo`;o00000_ooool2o`000:oooooo000Noooo
o`03o`000?oooooooooo03[ooooo0_l0000Gooooo`;o00003Oooool2o`0002_ooooo0_l00005oooo
o`;o0000[oooool001kooooo00?o0000ooooooooool03_ooool2o`0004gooooo0_l00004ooooo`;o
0000:_ooool2o`000;Kooooo000Nooooo`03o`000?oooooooooo00kooooo0_l00007ooooo`;o0000
A?ooool2o`0000Cooooo0_l0003Jooooo`;o00001_ooool001kooooo00?o0000ooooooooool05ooo
ool2o`0002[ooooo0_l0000>ooooo`;o0000j_ooool2o`0000Kooooo000Nooooo`03o`000?oooooo
oooo04?ooooo0_l0000>ooooo`;o00003_ooool2o`0001Kooooo0_l0003:ooooo`007_ooool00ol0
003oooooooooo`14ooooo`;o00007Oooool2o`0001Kooooo0_l0001Qooooo`;o0000Ioooool001ko
oooo0_l00011ooooo`;o00000_ooool2o`00047ooooo0_l0001Eooooo`;o0000Ioooool001kooooo
00?o0000ooooooooool0@?ooool2o`0004Gooooo0_l0002nooooo`007_ooool00ol0003ooooooooo
o`0Pooooo`;o0000;_ooool2o`0000Gooooo0_l0003^ooooo`007_ooool00ol0003oooooooooo`0P
ooooo`;o0000;_ooool2o`0000Cooooo0ol0003^ooooo`007_ooool00ol0003oooooooooo`1Foooo
o`;o00004oooool2o`0003oooooo0_l0002Iooooo`007_ooool00ol0003oooooooooo`0Nooooo`;o
0000=Oooool2o`0000_ooooo0_l000000ooooooo0000o`000004ooooo`;o0000?oooool2o`0009;o
oooo0_l00005ooooo`007Oooool2o`00023ooooo0_l0000eooooo`;o00002oooool2o`000003oooo
ool0003o00000=Wooooo0_l00005ooooo`007Oooool2o`0004Kooooo0_l0000Oooooo`;o0000h?oo
ool001kooooo00?o0000ooooooooool0?_ooool2o`0000Cooooo0_l00014ooooo`;o0000^oooool0
01kooooo00?o0000ooooooooool0?_ooool2o`0000kooooo0_l0000Looooo`;o00007?ooool2o`00
0;_ooooo000Nooooo`03o`000?oooooooooo04kooooo0_l0000Looooo`;o00003_ooool2o`0001Oo
oooo0_l0002`ooooo`007_ooool00ol0003oooooooooo`1:ooooo`;o00005_ooool2o`0001Sooooo
0_l0000Gooooo`;o0000/?ooool001kooooo00?o0000ooooooooool0B_ooool2o`0000gooooo0_l0
0007ooooo`;o00002_ooool2o`00047ooooo0_l0002Dooooo`007_ooool00ol0003oooooooooo`11
ooooo`;o00003?ooool2o`0000Sooooo0_l0000Booooo`?o00003_ooool2o`00037ooooo0_l0002D
ooooo`007_ooool00ol0003oooooooooo`11ooooo`;o00003?ooool2o`0000gooooo0_l0000=oooo
o`;o00003oooool2o`0003Kooooo0_l0002?ooooo`007_ooool00ol0003oooooooooo`1Nooooo`;o
00003?ooool2o`0004Sooooo0_l0002?ooooo`007_ooool2o`0006gooooo0_l0003Iooooo`007_oo
ool00ol0003oooooooooo`1^ooooo`;o00002oooool2o`000<[ooooo000Nooooo`03o`000?oooooo
oooo06kooooo0_l0000;ooooo`;o0000b_ooool001kooooo00?o0000ooooooooool0ZOooool2o`00
09cooooo000Nooooo`03o`000?oooooooooo02[ooooo0_l0001mooooo`;o0000W?ooool001kooooo
00?o0000ooooooooool0:_ooool2o`0004Sooooo0_l0003Aooooo`007_ooool00ol0003ooooooooo
o`1Xooooo`;o00002_ooool2o`000=7ooooo000Nooooo`03o`000?oooooooooo06Sooooo0_l0002A
ooooo`;o0000B_ooool001kooooo00?o0000ooooooooool0noooool2o`0004[ooooo000Nooooo`03
o`000?oooooooooo00Sooooo0_l0003oooooockooooo000Nooooo`03o`000?oooooooooo00Sooooo
0ol0003oooooocgooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0000`ooooo`;o0000B_oo
ool2o`000;kooooo000Nooooo`03o`000?oooooooooo03_ooooo1?l0000>ooooo`;o0000>?ooool2
o`000;kooooo000Nooooo`03o`000?oooooooooo03gooooo0_l0000>ooooo`;o0000n?ooool001ko
oooo00?o0000ooooooooool05_ooool2o`000<kooooo0_l0001Oooooo`007_ooool00ol0003ooooo
ooooo`0Fooooo`;o0000c_ooool2o`0005oooooo000Nooooo`;o0000oooooom9ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3Pooooo`;o0000
IOooool001kooooo00?o0000ooooooooool0AOooool2o`0009Wooooo0_l0001Uooooo`007_ooool0
0ol0003oooooooooo`15ooooo`;o0000ooooool1ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
m_ooool2o`0004oooooo000Nooooo`03o`000?oooooooooo0>Gooooo0_l00003ooooo`;o00002_oo
ool2o`0004oooooo000Nooooo`03o`000?oooooooooo05Kooooo0_l0000cooooo`;o0000F?ooool2
o`0000?ooooo0_l0001Kooooo`007_ooool00ol0003oooooooooo`0cooooo`;o00008Oooool2o`00
03?ooooo0_l0002jooooo`007_ooool00ol0003oooooooooo`0cooooo`;o00004?ooool2o`000?oo
oooo0Oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Ko
oooo00?o0000ooooooooool0AOooool2o`000?oooooo0Oooool000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000oooo
ooooool0:?ooool2o`00027ooooo0_l0003jooooo`000oooool01Ol@413ooooooooooooooooo410@
00cooooo00?oV9RHob4Q8Oo^k^h01oooool3o`0002Sooooo0_l0000Qooooo`;o0000D_ooool2o`00
043ooooo0_l0001Tooooo`000oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q
8Oo^k^h01_ooool00ol0003oooooooooo`2Oooooo`;o0000@?ooool2o`0006Cooooo0003ooooo`05
o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo
0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo04_ooooo0_l00016
ooooo`;o0000/_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1;ooooo`;o0000A_ooool2o`000;;ooooo000N
ooooo`03o`000?oooooooooo02?ooooo0_l0000Iooooo`;o0000<Oooool2o`000=Cooooo000Noooo
o`03o`000?oooooooooo02?ooooo0_l00002ooooo`;o00001_ooool2o`0000gooooo0_l0000aoooo
o`;o00008?ooool2o`000;;ooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l00006ooooo`;o
0000H_ooool2o`000;;ooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool02?ooool2o`000?oooooo?_ooool001kooooo00?o0000ooooooooool02?ooool2
o`0008Sooooo0_l0002cooooo`007_ooool00ol0003oooooooooo`1Hooooo`;o0000>?ooool2o`00
0;?ooooo000Nooooo`03o`000?oooooooooo02?ooooo0_l0000cooooo`;o0000kOooool001kooooo
00?o0000ooooooooool08?ooool2o`000003ooooool0003o00000?oooooo8oooool001kooooo00?o
0000ooooooooool08?ooool2o`000?oooooo9_ooool001kooooo00?o0000ooooooooool0;?ooool2
o`000?oooooo6_ooool001kooooo0_l0000]ooooo`;o0000oooooolJooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool04Oooool2o`000?oo
oooo5?ooool2o`0001oooooo000Nooooo`03o`000?oooooooooo017ooooo0_l0003ooooooaCooooo
0_l0000Oooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo09oooooo0_l0002Vooooo`007_oo
ool00ol0003oooooooooo`2Oooooo`;o0000Y_ooool001kooooo00?o0000ooooooooool0QOooool2
o`000<3ooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l0001mooooo`;o00002Oooool2o`00
0;Gooooo000Nooooo`;o00001oooool2o`0008Sooooo0_l0002eooooo`007_ooool00ol0003ooooo
ooooo`1gooooo`;o0000c_ooool001kooooo00?o0000ooooooooool0Moooool2o`000<kooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool02Oooool2o`00
0?oooooo?Oooool001kooooo00?o0000ooooooooool02Oooool2o`0001Sooooo0_l0003oooooob?o
oooo000Nooooo`03o`000?oooooooooo02?ooooo1?l0003oooooob7ooooo000Nooooo`03o`000?oo
oooooooo02Gooooo0_l0003oooooob7ooooo000Nooooo`03o`000?oooooooooo08kooooo0_l0002g
ooooo`007_ooool00ol0003oooooooooo`2>ooooo`;o0000]oooool001kooooo00?o0000oooooooo
ool0VOooool2o`0009cooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`2Booooo`;o0000
1Oooool2o`0009cooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`0]ooooo`;o0000Hooo
ool2o`000;?ooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0000Dooooo`;o0000oooooolI
ooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o0000oooooolYooooo`;o00001?ooool001ko
oooo00?o0000ooooooooool0=_ooool2o`000?kooooo0_l00009ooooo`;o00001?ooool001kooooo
0_l0000Dooooo`;o00008Oooool2o`0006_ooooo0_l0002@ooooo`?o00003oooool001kooooo00?o
0000ooooooooool04oooool2o`0007Kooooo0_l0000Aooooo`;o00000oooool2o`0000kooooo0_l0
0020ooooo`;o00004?ooool001kooooo00?o0000ooooooooool05Oooool3o`0007?ooooo0_l0000A
ooooo`;o00004oooool2o`0009;ooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0000<oooo
o`?o0000F?ooool2o`0000?ooooo0_l0003@ooooo`007_ooool00ol0003oooooooooo`07ooooo`;o
0000Ioooool2o`0000?ooooo0_l0000cooooo`;o0000Voooool001kooooo00?o0000ooooooooool0
?Oooool2o`0006_ooooo0_l0002Kooooo`007_ooool00ol0003oooooooooo`0mooooo`;o0000Eooo
ool2o`000:oooooo000Nooooo`03o`000?oooooooooo06_ooooo0_l0000Yooooo`;o0000[oooool0
01kooooo00?o0000ooooooooool0Joooool2o`000<Gooooo0_l0000Cooooo`007_ooool00ol0003o
ooooooooo`1Xooooo`;o0000b?ooool2o`0001?ooooo000Nooooo`03o`000?oooooooooo00;o0000
I_ooool2o`0003Kooooo0_l0002Uooooo`007_ooool00ol0003oooooooooo`02o`0009kooooo0_l0
002=ooooo`;o00005_ooool001kooooo00?o0000ooooooooool0oooooolYooooo`;o00001Oooool2
o`0001Kooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0002Qooooo`;o0000POooool2o`00
01gooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@
413oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo0_l0000=ooooo`;o00003?ooool2o`00
08Cooooo0_l0002Pooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool2o`0000cooooo0_l0001Doooo
o`;o0000;?ooool2o`000:;ooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`00
00Kooooo0ol0001Kooooo`;o00006?ooool2o`0002cooooo0_l00005ooooo`;o0000Voooool000?o
oooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000
ooooooooool0;?ooool2o`0002gooooo0_l0000>ooooo`;o0000?Oooool2o`0009_ooooo0003oooo
o`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oo
oooooooo02cooooo0_l0000Dooooo`;o00009oooool2o`0003Gooooo0_l0002Sooooo`000oooool0
1Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003ooooooooo
o`12ooooo`;o0000<oooool2o`0002Wooooo0_l0002;ooooo`;o00005_ooool000?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0Mooo
ool2o`000;Kooooo0_l0000Fooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?o
MgMgo`000?ooool01_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?oooooo3?ooool2o`0003[ooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0000[oooo
o`;o00001_ooool2o`000=7ooooo0_l0000jooooo`007_ooool00ol0003oooooooooo`03ooooo`;o
0000:oooool2o`0000Kooooo0_l0000Mooooo`;o0000B_ooool2o`00087ooooo0_l0000Oooooo`00
7_ooool00ol0003oooooooooo`0Yooooo`;o0000;?ooool2o`0004[ooooo0_l00021ooooo`;o0000
7oooool001kooooo00?o0000ooooooooool0:Oooool2o`0007kooooo0_l0000/ooooo`;o0000K_oo
ool001kooooo00?o0000ooooooooool0:Oooool2o`0007Kooooo0_l00006ooooo`;o0000;?ooool2
o`0006kooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0000Tooooo`;o0000M_ooool2o`00
00Oooooo0_l0001nooooo`;o00006oooool001kooooo00?o0000ooooooooool00oooool2o`0002_o
oooo0_l0001hooooo`;o00003oooool2o`0006gooooo0_l0000Kooooo`007_ooool00ol0003ooooo
ooooo`0`ooooo`;o0000ROooool2o`0008[ooooo000Nooooo`03o`000?oooooooooo093ooooo0_l0
002eooooo`007_ooool00ol0003oooooooooo`2<ooooo`;o00000_ooool2o`0001kooooo0_l0002E
ooooo`007_ooool2o`0008gooooo0_l0000<ooooo`;o00002oooool2o`0000Oooooo0_l0001doooo
o`;o00003Oooool2o`00013ooooo000Nooooo`03o`000?oooooooooo023ooooo0_l0001hooooo`;o
00002oooool2o`0000[ooooo0_l0001aooooo`;o00003Oooool2o`00013ooooo000Nooooo`03o`00
0?oooooooooo023ooooo0_l0002Aooooo`;o0000T_ooool001kooooo00?o0000ooooooooool0COoo
ool2o`0003Kooooo0_l0000Yooooo`;o00000_ooool2o`00097ooooo000Nooooo`03o`000?oooooo
oooo04gooooo0_l0000Sooooo`;o00004Oooool2o`0002Wooooo0_l00002ooooo`;o0000TOooool0
01kooooo00?o0000ooooooooool0L_ooool2o`0000Kooooo0_l0003;ooooo`007_ooool00ol0003o
ooooooooo`0Fooooo`;o00005Oooool2o`0004_ooooo0_l0003;ooooo`007_ooool00ol0003ooooo
ooooo`0Fooooo`;o00005Oooool2o`0002?ooooo0_l0001Kooooo`;o0000U_ooool001kooooo00?o
0000ooooooooool0D_ooool2o`0005_ooooo0_l0000Fooooo`;o0000O_ooool001kooooo00?o0000
ooooooooool08?ooool2o`0008_ooooo0_l00006ooooo`;o00004?ooool2o`0005gooooo0_l0000O
ooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o0000Roooool2o`0000Kooooo0_l0001_oooo
o`;o00007oooool001kooooo00?o0000ooooooooool0Z?ooool2o`00093ooooo0_l0000;ooooo`00
7_ooool00ol0003oooooooooo`0;ooooo`;o0000?_ooool2o`0004Gooooo0_l0000Dooooo`;o0000
T?ooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l0000nooooo`;o0000=?oo
ool2o`0000oooooo0_l0002Tooooo`;o00003Oooool001kooooo00?o0000ooooooooool0POooool2
o`000;Gooooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`1aooooo`;o0000e?ooool001ko
oooo0_l0000Tooooo`;o0000C?ooool2o`000=Cooooo000Nooooo`03o`000?oooooooooo02?ooooo
0_l0001^ooooo`;o0000/_ooool001kooooo00?o0000ooooooooool07?ooool2o`0007Gooooo0_l0
002booooo`007_ooool00ol0003oooooooooo`0Looooo`;o0000S_ooool2o`0009Wooooo000Noooo
o`03o`000?oooooooooo057ooooo0_l00003ooooo`;o0000E?ooool2o`0009Wooooo000Nooooo`03
o`000?oooooooooo057ooooo0_l00003ooooo`;o00009?ooool2o`000;cooooo0_l0000;ooooo`00
7_ooool00ol0003oooooooooo`0/ooooo`;o0000C_ooool2o`000;cooooo0_l0000;ooooo`007_oo
ool00ol0003oooooooooo`0/ooooo`;o0000oooooolJooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo05Cooooo0_l0003aooooo`007_ooool00ol0003o
ooooooooo`1Dooooo`;o0000Goooool2o`00093ooooo000Nooooo`03o`000?oooooooooo03gooooo
0_l0001fooooo`;o00001oooool2o`0008Oooooo000Nooooo`03o`000?oooooooooo027ooooo0_l0
000Jooooo`;o0000Ooooool2o`0008Oooooo000Nooooo`03o`000?oooooooooo027ooooo0_l0000A
ooooo`;o0000oooooolBooooo`007_ooool00ol0003oooooooooo`0dooooo`;o0000J?ooool2o`00
0:Oooooo000Nooooo`03o`000?oooooooooo02gooooo0_l0001_ooooo`;o0000Yoooool001kooooo
0_l0000^ooooo`;o0000oooooolIooooo`007_ooool00ol0003oooooooooo`1Mooooo`;o0000>_oo
ool2o`0000gooooo0_l0002Mooooo`007_ooool00ol0003oooooooooo`03ooooo`;o0000F?ooool2
o`0003[ooooo0_l0000=ooooo`;o00001oooool2o`0006kooooo0_l0000Tooooo`007_ooool00ol0
003oooooooooo`03ooooo`;o0000[?ooool2o`0006kooooo0_l0000Tooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0L?ooool2o`0004[ooooo0_l00029ooooo`007_ooool00ol0003oooooooooo`1`
ooooo`;o0000B_ooool2o`0008Wooooo000Nooooo`03o`000?oooooooooo02cooooo0_l0003ooooo
oa[ooooo000Nooooo`03o`000?oooooooooo02cooooo0_l0003ooooooa[ooooo000Nooooo`03o`00
0?oooooooooo01kooooo0_l0000Kooooo`;o0000G_ooool2o`0001oooooo0_l00029ooooo`007_oo
ool00ol0003oooooooooo`0Nooooo`;o00006oooool2o`0004Gooooo0_l0000Gooooo`;o00007ooo
ool2o`0008Wooooo000Nooooo`03o`000?oooooooooo08;ooooo0_l00033ooooo`007_ooool00ol0
003oooooooooo`0Zooooo`;o0000g?ooool2o`0003gooooo0003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooo
oooo02[ooooo0_l0000<ooooo`;o0000c_ooool2o`0003gooooo0003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oo
oooooooo03Sooooo0_l0003oooooo`kooooo0003ooooo`05oa0@4?ooooooooooooooool@41002ooo
ool01Ol0003ooooooooooooooooo000000Kooooo0ol0003oooooodSooooo0003ooooo`05o`000?oo
ooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o0000oooooooo
ool0oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0
003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooo
oooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0:oooool2o`00
0<cooooo0_l0001<ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@
4?nHV9P02?ooool00ol0003oooooooooo`0>ooooo`;o00005_ooool2o`0000?ooooo0_l0003<oooo
o`;o0000C?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000
oa0@40Kooooo00?o0000ooooooooool03_ooool2o`0001Kooooo0_l000001?oooooo0000o`000?oo
ool2o`000?oooooo6_ooool001kooooo00?o0000ooooooooool0:Oooool2o`000003ooooool0003o
000002cooooo0_l0003[ooooo`007_ooool00ol0003oooooooooo`05ooooo`;o0000Doooool2o`00
01Gooooo0_l0003Dooooo`007_ooool00ol0003oooooooooo`05ooooo`;o0000J_ooool2o`0003Ko
oooo0_l0002Looooo`007_ooool00ol0003oooooooooo`0Xooooo`;o00001oooool2o`0000Cooooo
0_l0001`ooooo`;o0000W?ooool001kooooo00?o0000ooooooooool0:?ooool2o`0000Oooooo0_l0
0004ooooo`;o0000L?ooool2o`0009cooooo000Nooooo`03o`000?oooooooooo0:Wooooo0_l0000;
ooooo`;o0000Soooool001kooooo00?o0000ooooooooool0;oooool3o`0001Oooooo0_l0001[oooo
o`;o0000Soooool001kooooo00?o0000ooooooooool0;oooool3o`0001Oooooo0_l0003looooo`00
7_ooool00ol0003oooooooooo`18ooooo`;o0000oOooool001kooooo00?o0000ooooooooool0B?oo
ool2o`000?gooooo000Nooooo`03o`000?oooooooooo0;;ooooo0_l0002Cooooo`007_ooool2o`00
0;?ooooo0_l000000ooooooo0000o`00002@ooooo`007_ooool00ol0003oooooooooo`2eooooo`;o
0000T?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`09ooooo`;o0000K?ooool2o`000<kooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0001/
ooooo`;o0000c_ooool001kooooo00?o0000ooooooooool0Aoooool2o`0000Wooooo0_l0000eoooo
o`;o0000_?ooool001kooooo00?o0000ooooooooool0Aoooool2o`0000Wooooo1?l0000cooooo`;o
0000_?ooool001kooooo00?o0000ooooooooool0DOooool2o`000003ooooool0003o00000?7ooooo
000Nooooo`03o`000?oooooooooo013ooooo0_l0000oooooo`;o0000m?ooool001kooooo00?o0000
ooooooooool04?ooool2o`0002_ooooo0_l000000ooooooo0000o`000002o`0000Gooooo0_l0000;
ooooo`;o0000HOooool2o`0008cooooo000Nooooo`03o`000?oooooooooo03_ooooo1?l000000ooo
oooo0000o`000002o`0000Gooooo0_l0000;ooooo`?o0000H?ooool2o`0005Wooooo0_l0000aoooo
o`007_ooool00ol0003oooooooooo`0kooooo`Co00000oooool3o`0001;ooooo0_l0002kooooo`;o
0000<Oooool001kooooo00?o0000ooooooooool0?Oooool3o`0000?ooooo0_l00002ooooo`;o0000
1Oooool2o`0000Gooooo0_l0003`ooooo`007_ooool00ol0003oooooooooo`0mooooo`Co00001_oo
ool2o`0000Gooooo0_l00005ooooo`;o00003oooool2o`0001kooooo0_l0002oooooo`007_ooool0
0ol0003oooooooooo`08ooooo`?o0000<?ooool2o`0000;ooooo1_l00006ooooo`;o00006Oooool2
o`0001[ooooo0_l00002ooooo`;o0000_oooool001kooooo00?o0000ooooooooool02?ooool3o`00
02oooooo0ol00002ooooo`Oo00001Oooool2o`0000Cooooo0_l0000_ooooo`;o0000Yoooool2o`00
01[ooooo000Nooooo`;o00006_ooool2o`0001oooooo0ol00007ooooo`?o00000_ooool2o`0000Ko
oooo0_l0000=ooooo`;o00000_ooool2o`000003ooooool0003o000001Gooooo1_l0000;ooooo`;o
00001Oooool2o`0009?ooooo0_l0000Jooooo`007_ooool00ol0003oooooooooo`0Hooooo`?o0000
7oooool3o`0000Gooooo1Ol00002ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`0000_o
oooo0_l00002ooooo`;o000000?oooooo`000?l000005Oooool6o`0000Wooooo1?l00005ooooo`;o
0000[oooool001kooooo00?o0000ooooooooool06?ooool2o`0000[ooooo0ol0000>ooooo`Co0000
00?oooooo`000?l000001_ooool4o`0000?ooooo0_l000001?oooooo0000o`000?l00004ooooo`;o
00000oooool4o`0000Sooooo0_l0000Wooooo`;o0000^?ooool001kooooo00?o0000ooooooooool0
9?ooool5o`0000cooooo1?l0000:ooooo`Go000000Coooooo`000?l0003ooooo0_l00005ooooo`Co
000000?oooooo`000?l000000_l00008ooooo`;o0000hOooool001kooooo00?o0000ooooooooool0
9oooool2o`00013ooooo0_l00006ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o0000
1Oooool4o`0001Sooooo0_l00003ooooo`;o0000NOooool2o`0004Gooooo0_l0000?ooooo`007_oo
ool00ol0003oooooooooo`0iooooo`?o00001?ooool3o`000004ooooool0003o0000ooooo`;o0000
2Oooool2o`0000oooooo0_l0000:ooooo`;o00000oooool2o`0000gooooo0_l0001Zooooo`;o0000
6oooool2o`0002Sooooo0_l0000?ooooo`007_ooool00ol0003oooooooooo`0iooooo`?o00000_oo
ool6o`0000?ooooo1?l00007ooooo`;o00003oooool2o`0001cooooo1?l00007ooooo`;o00008?oo
ool2o`0001Cooooo0_l00016ooooo`;o0000>Oooool001kooooo00?o0000ooooooooool07oooool2
o`0000Cooooo0_l0000Aooooo`So00000_ooool2o`0000?ooooo1?l00002ooooo`;o00004?ooool2
o`0000oooooo0_l0000?ooooo`;o00002Oooool2o`0001oooooo0ol0000Dooooo`;o00004?ooool2
o`0006oooooo000Nooooo`03o`000?oooooooooo01oooooo0_l00004ooooo`;o00004Oooool9o`00
0004ooooool0003o0000ooooo`[o000000?oooooo`000?l000003Oooool2o`0000oooooo0_l00004
ooooo`;o00002Oooool2o`0001gooooo0_l0000;ooooo`;o00009oooool2o`0006oooooo000Noooo
o`03o`000?oooooooooo03Wooooo2?l00002ooooo`Go000000?oooooo`000?l000000_l00003oooo
o`;o00009?ooool2o`0000Kooooo0_l0000Pooooo`;o0000YOooool001kooooo00?o0000oooooooo
ool0?oooool2o`000003ooooool0003o000000Co00000_ooool3o`00037ooooo0_l0000Wooooo`;o
0000W_ooool001kooooo00?o0000ooooooooool0?oooool8o`0003Sooooo0_l0000Fooooo`;o0000
3_ooool2o`0009kooooo000Nooooo`03o`000?oooooooooo01oooooo0_l0000@ooooo`;o00003Ooo
ool2o`000003ooooool0003o000000Wooooo0_l0000_ooooo`;o00002?ooool2o`0000cooooo0_l0
000Eooooo`;o0000Uoooool001kooooo00?o0000ooooooooool07oooool2o`00013ooooo0_l00005
ooooo`;o00000oooool5o`0000Cooooo0_l00006ooooo`;o00005_ooool2o`00027ooooo0_l0000S
ooooo`;o0000Uoooool001kooooo00?o0000ooooooooool0=_ooool4o`0000?ooooo1Ol00004oooo
o`;o00001?ooool2o`0001Sooooo0_l0000Mooooo`;o00003?ooool2o`0000Oooooo0_l0000:oooo
o`;o0000WOooool001kooooo00?o0000ooooooooool0=_ooool2o`0000oooooo0_l00003ooooo`;o
0000=oooool2o`0000cooooo0_l00007ooooo`;o00001_ooool2o`0000;ooooo0_l0002Mooooo`00
7_ooool2o`0004Sooooo0_l0000Kooooo`;o00008oooool2o`00013ooooo0_l00007ooooo`;o0000
XOooool001kooooo00?o0000ooooooooool0H?ooool2o`0000;ooooo0_l0000Sooooo`;o00004?oo
ool2o`000:[ooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l00005ooooo`;o00001oooool2
o`0000?ooooo0_l0000Cooooo`;o00003Oooool2o`0006Gooooo0_l0001nooooo`007_ooool00ol0
003oooooooooo`0Wooooo`;o00001Oooool2o`0000Oooooo0_l00003ooooo`;o00001oooool2o`00
00[ooooo0_l0000booooo`Co00002Oooool2o`0003?ooooo0_l0001nooooo`007_ooool00ol0003o
ooooooooo`0cooooo`;o00004?ooool2o`0000Cooooo0_l00004ooooo`;o0000:?ooool2o`0000So
oooo1?l00009ooooo`;o00007_ooool2o`0009?ooooo000Nooooo`03o`000?oooooooooo03?ooooo
0_l000000ooooooo0000o`000006ooooo`;o00001_ooool2o`0000?ooooo0_l0000^ooooo`;o0000
=Oooool2o`0009?ooooo000Nooooo`03o`000?oooooooooo02gooooo0_l00003ooooo`;o000000Co
ooooo`000?l0003o00001_ooool2o`0000Kooooo0ol00002ooooo`;o00001_ooool2o`0004Oooooo
0_l0002Yooooo`007_ooool00ol0003oooooooooo`0]ooooo`;o00000oooool2o`000004ooooool0
003o0000o`0000?ooooo0_l00008ooooo`Co00001?ooool2o`0000Cooooo0_l0000Xooooo`;o0000
7Oooool2o`000:Wooooo000Nooooo`03o`000?oooooooooo03[ooooo0ol00002ooooo`;o00001?oo
ool2o`0000Kooooo0_l0000Qooooo`;o00002oooool2o`0003Kooooo0_l00004ooooo`;o0000R_oo
ool001kooooo00?o0000ooooooooool0>_ooool2o`0000?ooooo0_l0000@ooooo`;o00001?ooool2
o`0001Oooooo0_l00013ooooo`;o00001?ooool2o`0008[ooooo000Nooooo`03o`000?oooooooooo
04?ooooo0_l00003ooooo`;o00001oooool3o`0000?ooooo0_l00009ooooo`;o00007?ooool2o`00
0<Gooooo000Nooooo`03o`000?oooooooooo01cooooo0_l0000Fooooo`Co00002Oooool4o`0000?o
oooo0_l00005ooooo`;o000000Coooooo`000?l0003ooooo0_l0000;ooooo`;o00007?ooool2o`00
0<Gooooo000Nooooo`03o`000?oooooooooo01cooooo0_l00002ooooo`;o00004_ooool4o`0000Go
oooo0_l00002ooooo`;o00001?ooool2o`0000;ooooo0_l00002ooooo`;o00001?ooool2o`0000Go
oooo0_l0000Hooooo`;o0000coooool001kooooo00?o0000ooooooooool08?ooool4o`0001Cooooo
0_l00003ooooo`;o00002?ooool2o`0000;ooooo0_l00002ooooo`;o00002oooool2o`000003oooo
ool0003o000000Cooooo1?l0000=ooooo`;o0000coooool000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000oooooooo
ool08_ooool2o`000003ooooool0003o000000Kooooo0_l00009ooooo`;o00001oooool2o`0000co
oooo0_l00008ooooo`;o00001?ooool2o`0000Cooooo1?l00005ooooo`;o00000_ooool2o`000=?o
oooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?oo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo02Gooooo0_l00006ooooo`;o00002Oooool2o`00
00Oooooo0_l0000Fooooo`;o00003?ooool2o`0000Gooooo0_l00002ooooo`;o00008Oooool2o`00
0;3ooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo
000000Kooooo0ol0000Sooooo`;o00004oooool2o`000003ooooool0003o000000;ooooo0ol0000F
ooooo`;o0000>oooool2o`00023ooooo0_l0001Yooooo`;o00008oooool000?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool00ol0003ooooooooo
o`0Sooooo`;o00000_ooool2o`0000_ooooo1_l000000ooooooo0000o`000005o`0001Kooooo0_l0
0002ooooo`;o0000<oooool2o`0002Cooooo0_l0001Yooooo`;o00008oooool000?ooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003ooooo
ooooo`0Wooooo`;o00002oooool6o`0000?ooooo0_l0000Cooooo`?o00001?ooool2o`000003oooo
ool0003o000003?ooooo0_l00014ooooo`;o0000K_ooool000?ooooo00Go410@oooooooooooooooo
oa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`0fooooo`;o
00006_ooool3o`000004ooooool0003o0000ooooo`;o00002oooool2o`0006oooooo0_l0001^oooo
o`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006
ooooo`03o`000?oooooooooo03Kooooo0_l00004ooooo`;o00003?ooool2o`0000[ooooo0_l00007
ooooo`;o00001Oooool2o`000=oooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0:?ooool2o`0000cooooo0ol0
0003ooooo`Co00001Oooool2o`0000?ooooo0_l0000Cooooo`;o0000D_ooool2o`0001Sooooo0ol0
001gooooo`007_ooool00ol0003oooooooooo`0Xooooo`;o00003?ooool3o`0000Gooooo1?l00000
0ooooooo0000o`000002o`0000[ooooo1?l0000Dooooo`;o00000_ooool2o`0004Cooooo0_l0000H
ooooo`?o0000Moooool001kooooo00?o0000ooooooooool08?ooool2o`0001gooooo0ol000000ooo
oooo0000o`00000<ooooo`Go000000?oooooo`000?l000004?ooool2o`0000;ooooo0_l0003Hoooo
o`007_ooool00ol0003oooooooooo`0Pooooo`;o00003_ooool2o`0000Sooooo0ol00002ooooo`;o
00002Oooool2o`0000Kooooo2?l0001Oooooo`;o0000S?ooool001kooooo00?o0000ooooooooool0
8oooool2o`0000_ooooo0_l00008ooooo`?o00001oooool3o`0000?ooooo0_l00006ooooo`;o0000
00?oooooo`000?l000000ol000000ooooooo0000o`00001Cooooo`;o00001oooool2o`0008cooooo
000Nooooo`03o`000?oooooooooo02?ooooo0_l0000Oooooo`?o00000_ooool2o`0000Oooooo0_l0
00001?oooooo0000o`000?l00003ooooo`Co00005Oooool2o`00017ooooo0_l0000Rooooo`;o0000
0oooool2o`0000?ooooo0_l0002@ooooo`007_ooool00ol0003oooooooooo`03ooooo`;o0000>ooo
ool2o`0000Gooooo1?l00007ooooo`Go000000Coooooo`000?l0003ooooo1?l0000Eooooo`;o0000
1oooool2o`0000Kooooo1?l0000Rooooo`;o00002?ooool2o`0006_ooooo0_l0000Booooo`;o0000
3oooool001kooooo00?o0000ooooooooool00_ooool3o`0001Wooooo1?l0000Looooo`Co00001Ooo
ool4o`0000Kooooo1Ol00002ooooo`Go00001?ooool2o`0000;ooooo0_l0000Fooooo`;o00001_oo
ool2o`0009_ooooo0_l0000Booooo`;o00003oooool001kooooo0_l00003ooooo`;o00006_ooool4
o`0001cooooo1?l00006ooooo`?o00001_ooool5o`0000;ooooo1Ol00004ooooo`;o00000_ooool2
o`000>3ooooo000Nooooo`;o0000:_ooool2o`0001Gooooo0_l00005ooooo`;o00001oooool2o`00
0005ooooool0003o0000o`000?ooool00ol0000Jooooo`;o0000dOooool001kooooo00?o0000oooo
ooooool06oooool2o`0000cooooo0_l0000Jooooo`Co00001oooool2o`0000;ooooo1Ol000000ooo
oooo0000o`000003o`0001Gooooo0_l0000Oooooo`;o0000/?ooool001kooooo00?o0000oooooooo
ool02oooool2o`0000kooooo0_l0000Uooooo`;o000000?oooooo`000?l000003_ooool3o`0000;o
oooo1Ol00005ooooo`?o00000_ooool2o`0001?ooooo0_l0000Eooooo`;o00002_ooool2o`000:Co
oooo000Nooooo`;o00003?ooool2o`0003Gooooo1?l00003ooooo`;o000000Coooooo`000?l0003o
00001_ooool2o`000003ooooool0003o000000;ooooo0_l00006ooooo`?o00000_ooool2o`0000Ko
oooo0_l0000;ooooo`;o00008Oooool2o`000:Cooooo000Nooooo`03o`000?oooooooooo04;ooooo
1?l00003ooooo`;o000000?oooooo`000?l000001Ol000001?oooooo0000o`000?ooool3o`0000oo
oooo0_l00005ooooo`?o00002_ooool4o`000<Kooooo000Nooooo`03o`000?oooooooooo00[ooooo
0_l0000fooooo`;o000000?oooooo`000?l000001?ooool;o`000004ooooool0003o0000o`0000;o
oooo0_l000001?oooooo0000o`000?l00007ooooo`;o00001Oooool4o`0000Wooooo1?l0002/oooo
o`;o00006?ooool001kooooo00?o0000ooooooooool02_ooool2o`0000Sooooo0_l0000Yooooo`;o
00001?ooool2o`0000Cooooo3?l000000ooooooo0000o`000004o`000004ooooool0003o0000o`00
013ooooo0ol0002hooooo`;o00006?ooool001kooooo00?o0000ooooooooool05?ooool2o`0002Wo
oooo0_l00004ooooo`;o00001Oooool<o`0000;ooooo1?l000001?oooooo0000o`000?ooool2o`00
00oooooo0_l0003Booooo`007_ooool00ol0003oooooooooo`15ooooo`;o00001_ooool;o`0000Co
oooo0_l00004ooooo`;o00000oooool2o`0006gooooo0_l0001_ooooo`007_ooool00ol0003ooooo
ooooo`0nooooo`;o00003Oooool3o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`;o0000
1?ooool3o`0000;ooooo0_l00006ooooo`;o0000AOooool2o`0001kooooo0_l0001_ooooo`007_oo
ool00ol0003oooooooooo`0>ooooo`;o00004Oooool2o`0001_ooooo0_l00009ooooo`Co00000_oo
ool2o`0000?ooooo1ol000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000002_oo
ool2o`0000?ooooo0_l0000Iooooo`;o00009Oooool2o`0008oooooo000Nooooo`03o`000?oooooo
oooo00kooooo0ol0000@ooooo`;o00005oooool2o`0000Sooooo0_l00003ooooo`Co00000_ooool2
o`0000;ooooo0ol000000ooooooo0000o`00000;o`00013ooooo0_l000000ooooooo0000o`000004
ooooo`;o00004?ooool2o`0000kooooo0_l0002Vooooo`007_ooool00ol0003oooooooooo`0?oooo
o`;o0000:Oooool2o`0000Cooooo0_l00002ooooo`;o00002?ooool7o`0000;ooooo2Ol00002oooo
o`;o00004oooool2o`0000Cooooo0_l0000Pooooo`;o0000Y_ooool001kooooo0_l0000`ooooo`;o
00003oooool2o`0000cooooo1ol00002ooooo`So00002?ooool2o`0000_ooooo0_l0000Dooooo`;o
0000]?ooool2o`0000Gooooo000Nooooo`;o00002Oooool2o`0001Cooooo0ol0000>ooooo`;o0000
1Oooool2o`0001Kooooo1ol00002ooooo`So00002?ooool2o`0000_ooooo0_l0000Dooooo`Co0000
8?ooool2o`00093ooooo0_l00005ooooo`007_ooool00ol0003oooooooooo`08ooooo`;o00005?oo
ool3o`0001Gooooo0_l0000Iooooo`Go000000?oooooo`000?l000001?l00005ooooo`;o00000ooo
ool2o`0001;ooooo0_l0000?ooooo`;o00007oooool3o`0007_ooooo0_l0000Jooooo`007_ooool0
0ol0003oooooooooo`17ooooo`;o00002oooool2o`0000?ooooo1?l00002ooooo`;o000000?ooooo
o`000?l000000oooool2o`0001;ooooo0_l0000`ooooo`;o0000O?ooool2o`0001[ooooo000Noooo
o`03o`000?oooooooooo00oooooo0_l00005ooooo`;o0000;oooool2o`0000Gooooo0_l00004oooo
o`;o00000oooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool4o`0004;ooooo0_l0000B
ooooo`;o0000Q_ooool001kooooo00?o0000ooooooooool03oooool2o`000003ooooool0003o0000
00;ooooo0_l0000Pooooo`;o00005?ooool2o`0000Cooooo2?l00006ooooo`;o000000?oooooo`00
0?l000000_l00012ooooo`;o00004_ooool2o`0008Kooooo000Nooooo`;o00004oooool2o`0001ko
oooo0_l00004ooooo`;o00005?ooool2o`000003ooooool0003o000000Wo00000_ooool2o`0000Co
oooo0_l0000=ooooo`;o00007_ooool2o`000;;ooooo000Nooooo`03o`000?oooooooooo03;ooooo
0_l0000Kooooo`Ko000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00001?ooool2o`0000go
oooo0_l0000Nooooo`;o0000/_ooool001kooooo00?o0000ooooooooool0Boooool2o`0000;ooooo
1Ol0000:ooooo`;o000000Coooooo`000?l0003ooooo0ol00003ooooo`;o00007_ooool2o`0000?o
oooo0_l0002Hooooo`?o00006oooool001kooooo00?o0000ooooooooool0Boooool2o`0000;ooooo
0_l0000=ooooo`Go000000?oooooo`000?l000000_l00002ooooo`;o00007_ooool2o`0000?ooooo
0_l000000ooooooo0000o`00002Eooooo`Co00006_ooool001kooooo00?o0000ooooooooool03_oo
ool2o`0004[ooooo1?l000000ooooooo0000o`000002o`000003ooooool0003o000000;o00000ooo
ool2o`0000Sooooo0_l0000Eooooo`;o00001?ooool2o`0009Oooooo0_l0000;ooooo`;o00003Ooo
ool001kooooo00?o0000ooooooooool03_ooool2o`0000_ooooo0_l0000Kooooo`;o00003Oooool2
o`0000Oooooo0_l00007ooooo`Go00001_ooool2o`0000;ooooo0_l000000ooooooo0000o`000008
ooooo`;o000000?oooooo`000?l000002_ooool2o`0000Kooooo0_l0000>ooooo`;o00001oooool2
o`0008Cooooo0_l0000;ooooo`;o00003Oooool001kooooo00?o0000ooooooooool06oooool2o`00
01_ooooo0_l0000=ooooo`;o00001Oooool7o`0000;ooooo1_l00002ooooo`;o00000oooool2o`00
0003ooooool0003o000000?o00001oooool2o`0000?ooooo0_l0000:ooooo`;o00000oooool2o`00
00Oooooo0_l00008ooooo`;o00001oooool2o`0008Cooooo0_l0000Jooooo`007_ooool00ol0003o
ooooooooo`07ooooo`;o00007_ooool2o`0001kooooo0_l00005ooooo`;o000000?oooooo`000?l0
00000_l00002ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000006ooooo`;o
000000?oooooo`000?l000000ol00004ooooo`;o00003_ooool2o`0000Cooooo0_l00007ooooo`;o
000000?oooooo`000?l00000/?ooool001kooooo00?o0000ooooooooool01oooool2o`0001kooooo
0_l0000^ooooo`;o00000oooool2o`0000Cooooo0_l00004ooooo`Oo00002?ooool2o`0000Cooooo
0_l00004ooooo`;o00004?ooool2o`000;3ooooo000Nooooo`04o`000?ooooooooooooooo`;o0000
B?ooool2o`000003ooooool0003o000000Wooooo0_l000000ooooooo0000o`000002o`0000;ooooo
0_l00003ooooo`Go00000_ooool2o`0000Oooooo0_l00004ooooo`;o0000b?ooool001kooooo00Co
0000oooooooooooooooo0_l00018ooooo`Ko00002?ooool2o`000003ooooool0003o000000;o0000
1oooool3o`0000Cooooo0ol0003Fooooo`007_ooool00ol0003oooooooooo`0hooooo`;o00004_oo
ool2o`000003ooooool0003o000000_ooooo1?l0000>ooooo`Ko0000doooool001kooooo00?o0000
ooooooooool02?ooool2o`0002kooooo0_l0000Nooooo`;o000000?oooooo`000?l000005?ooool3
o`0000?ooooo0_l0001Uooooo`;o0000Ioooool001kooooo00?o0000ooooooooool00_l00006oooo
o`;o00001?ooool2o`00017ooooo0ol0000Hooooo`;o00006_ooool2o`000003ooooool0003o0000
00;o00005?ooool2o`0000;ooooo0_l0000@ooooo`;o0000Doooool2o`0006Oooooo000Nooooo`03
o`000?oooooooooo00;o00003?ooool2o`00017ooooo0ol0000Hooooo`;o00007Oooool4o`0001Co
oooo0_l000001?oooooo0000o`000?l0000@ooooo`;o00000_ooool2o`000;Sooooo000Nooooo`03
o`000?oooooooooo03kooooo0_l0000Booooo`;o000000?oooooo`000?l000000_l00002ooooo`;o
00003_ooool2o`0000Oooooo1Ol0000Dooooo`;o00009?ooool2o`0008Kooooo0_l0000:ooooo`00
7_ooool2o`0003Sooooo0_l00003ooooo`Co00004_ooool2o`000003ooooool0003o000000;o0000
0_ooool3o`0000gooooo0_l00002ooooo`;o00000oooool6o`0003Wooooo0_l0000:ooooo`;o0000
N_ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo03Oooooo0_l00003ooooo`;o00007Ooo
ool3o`00017ooooo0_l00004ooooo`;o000000?oooooo`000?l000002?ooool2o`0001Wooooo0_l0
000Pooooo`;o0000Coooool2o`0003Gooooo000Nooooo`03o`000?oooooooooo03cooooo0_l0000N
ooooo`Co00001_ooool2o`0000Gooooo0_l000000ooooooo0000o`000006ooooo`;o00002?ooool2
o`0000Oooooo0_l0000@ooooo`;o0000LOooool2o`0003Gooooo000Nooooo`03o`000?oooooooooo
013ooooo0_l0000booooo`;o00006?ooool2o`000003ooooool0003o000000?ooooo0_l00005oooo
o`;o000000?oooooo`000?l000000_ooool2o`0001Gooooo0_l0002jooooo`007_ooool00ol0003o
ooooooooo`0@ooooo`;o0000<_ooool2o`0001Sooooo0_l000000ooooooo0000o`00000Aooooo`?o
00000_ooool2o`000<cooooo000Nooooo`03o`000?oooooooooo04Sooooo0_l0000Dooooo`;o0000
2_ooool2o`0000Wooooo0_l00002ooooo`;o0000c?ooool001kooooo00?o0000ooooooooool0>_oo
ool2o`0000?ooooo0_l00007ooooo`;o00005?ooool2o`0000[ooooo0_l00002ooooo`;o0000eooo
ool001kooooo00?o0000ooooooooool0;Oooool2o`0000_ooooo0_l00003ooooo`;o00005?ooool2
o`0000?ooooo0_l0000Booooo`;o0000eoooool001kooooo00?o0000ooooooooool0;Oooool2o`00
02Kooooo0_l00003ooooo`;o00005_ooool4o`0002cooooo0_l0002Sooooo`007_ooool00ol0003o
ooooooooo`0_ooooo`;o0000=_ooool2o`0000Wooooo1Ol0000[ooooo`;o0000Xoooool001kooooo
00?o0000ooooooooool0;oooool2o`0002[ooooo0_l0000:ooooo`;o00002Oooool5o`0000Wooooo
0ol00034ooooo`007_ooool00ol0003oooooooooo`1Kooooo`;o00002_ooool3o`0000Sooooo1?l0
000:ooooo`?o0000a?ooool001kooooo00?o0000ooooooooool06Oooool2o`00017ooooo0_l00008
ooooo`;o0000<?ooool4o`0000[ooooo0_l0003?ooooo`007_ooool00ol0003oooooooooo`02oooo
o`;o00005Oooool2o`0000Gooooo0_l0000:ooooo`;o00002?ooool2o`0001kooooo0_l0000<oooo
o`;o00001?ooool2o`0000[ooooo0ol0000Rooooo`;o0000Z_ooool001Cooooo1?l000000ol@413o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0_l0000Looooo`;o0000=?ooool2o`0000Go
oooo0_l00005ooooo`;o00001?ooool2o`0000_ooooo0_l0000Rooooo`;o0000Q?ooool2o`0002Co
oooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09oooool2o`0000Sooooo
0_l0000Yooooo`?o00000oooool2o`0000_ooooo0_l0002`ooooo`;o00009?ooool001Kooooo00?o
0000ooooooooool01Oooool3o`0002Oooooo0_l00008ooooo`;o000000?oooooo`000?l000009_oo
ool2o`0000Cooooo0_l0000;ooooo`;o0000e_ooool001Kooooo00?o0000ooooooooool0??ooool2
o`000?oooooo4_ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003o
ooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Cooooo00?o
EEEEofIVI_l00000oooooomBooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.15866 .74367 Mdot
.15674 .08531 Mdot
.16753 .84706 Mdot
.28676 .85931 Mdot
.31801 .91026 Mdot
.29267 .8281 Mdot
.64133 .55643 Mdot
.27013 .90977 Mdot
.3386 .87832 Mdot
.15489 .31037 Mdot
.23543 .01517 Mdot
.16862 .0002 Mdot
.22062 .84302 Mdot
.49525 .87497 Mdot
.23816 .82669 Mdot
.31774 .04056 Mdot
.22941 .48109 Mdot
.23629 .78153 Mdot
.14063 .73366 Mdot
.3067 .84154 Mdot
.99113 .22585 Mdot
.30603 .81448 Mdot
.23631 .8197 Mdot
.06217 .65195 Mdot
.33797 .91571 Mdot
.28579 .96014 Mdot
.27105 .90498 Mdot
.3114 .0101 Mdot
.2232 .02433 Mdot
.27003 .79069 Mdot
.17705 .7676 Mdot
.25018 .82828 Mdot
.34039 .91662 Mdot
.93427 .96534 Mdot
.30482 .69873 Mdot
.3228 .96844 Mdot
.5325 .86434 Mdot
.03761 .54669 Mdot
.12622 .97722 Mdot
.30297 .9307 Mdot
.15985 .75865 Mdot
.43361 .75992 Mdot
.47916 .92069 Mdot
.09691 .51758 Mdot
.46169 .8201 Mdot
.4376 .78461 Mdot
.97185 .7761 Mdot
.42988 .95718 Mdot
.29987 .98622 Mdot
.35357 .66244 Mdot
.21037 .08162 Mdot
.3979 .71566 Mdot
.301 .95831 Mdot
.34384 .00775 Mdot
.30396 .93858 Mdot
.16047 .19063 Mdot
.20422 .74502 Mdot
.24699 .87192 Mdot
.26622 .90107 Mdot
.23931 .64525 Mdot
.25078 .84104 Mdot
.28374 .92266 Mdot
.57813 .60049 Mdot
.35449 .91678 Mdot
.2963 .85267 Mdot
.32441 .82704 Mdot
.46164 .71966 Mdot
.2691 .906 Mdot
.27373 .809 Mdot
.39459 .70451 Mdot
.02289 .37748 Mdot
.17808 .67863 Mdot
.38782 .00257 Mdot
.27623 .5234 Mdot
.2885 .92603 Mdot
.15342 .67037 Mdot
.29216 .77692 Mdot
.32592 .09379 Mdot
.2645 .86699 Mdot
.08006 .76753 Mdot
.39125 .89872 Mdot
.33579 .42491 Mdot
.07505 .49727 Mdot
.27217 .90716 Mdot
.65963 .43699 Mdot
.89126 .38188 Mdot
.30493 .95287 Mdot
.27969 .91355 Mdot
.25469 .81428 Mdot
.20079 .64536 Mdot
.39266 .89243 Mdot
.48586 .65129 Mdot
.33169 .70715 Mdot
.09157 .34096 Mdot
.20228 .66379 Mdot
.40546 .85318 Mdot
.51625 .47468 Mdot
.3633 .69896 Mdot
.39112 .95885 Mdot
.11254 .79566 Mdot
.23421 .89276 Mdot
.22015 .07784 Mdot
.17673 .72362 Mdot
.44288 .95741 Mdot
.1197 .10469 Mdot
.25307 .81542 Mdot
.30584 .07193 Mdot
.32714 .05309 Mdot
.43321 .74434 Mdot
.48463 .24173 Mdot
.47981 .88615 Mdot
.04908 .46292 Mdot
.14991 .97341 Mdot
.21713 .78408 Mdot
.72025 .15003 Mdot
.45386 .58649 Mdot
.41695 .82169 Mdot
.20832 .8384 Mdot
.07454 .12652 Mdot
.22147 .88066 Mdot
.27111 .92829 Mdot
.48664 .87686 Mdot
.31123 .8533 Mdot
.09636 .34965 Mdot
.47143 .8078 Mdot
.98976 .0166 Mdot
.3677 .04086 Mdot
.16042 .72361 Mdot
.92384 .97571 Mdot
.33993 .00961 Mdot
.02833 .08899 Mdot
.35211 .14456 Mdot
.78221 .21143 Mdot
.24618 .72546 Mdot
.2054 .70826 Mdot
.24897 .86785 Mdot
.27224 .82719 Mdot
.24709 .85487 Mdot
.15814 .78339 Mdot
.32288 .83675 Mdot
.1756 .71417 Mdot
.36403 .92637 Mdot
.32977 .83876 Mdot
.21538 .76834 Mdot
.4942 .144 Mdot
.20153 .97858 Mdot
.2302 .68881 Mdot
.26009 .90829 Mdot
.12696 .74469 Mdot
.45853 .38296 Mdot
.33987 .86201 Mdot
.33456 .87996 Mdot
.13962 .00464 Mdot
.31004 .84786 Mdot
.24077 .8479 Mdot
.23268 .86179 Mdot
.2548 .93521 Mdot
.17841 .65397 Mdot
.32643 .8844 Mdot
.2825 .05386 Mdot
.19661 .76295 Mdot
.21914 .72579 Mdot
.11556 .32988 Mdot
.25005 .71374 Mdot
.38276 .95517 Mdot
.3286 .92061 Mdot
.26455 .90922 Mdot
.30212 .88903 Mdot
.5248 .29576 Mdot
.28656 .77512 Mdot
.30383 .83026 Mdot
.31389 .85494 Mdot
.25751 .70096 Mdot
.14277 .67654 Mdot
.15021 .73552 Mdot
.20343 .90519 Mdot
.00897 .78339 Mdot
.24527 .9623 Mdot
.60057 .47062 Mdot
.38613 .70757 Mdot
.46195 .93757 Mdot
.25769 .00756 Mdot
.07315 .85773 Mdot
.40019 .84001 Mdot
.01694 .5194 Mdot
.1695 .99327 Mdot
.27386 .04251 Mdot
.4172 .88985 Mdot
.698 .07953 Mdot
.20962 .83426 Mdot
.15307 .73014 Mdot
.93468 .31147 Mdot
.16487 .7272 Mdot
.22688 .97872 Mdot
.18694 .8929 Mdot
.47329 .90205 Mdot
.22055 .72714 Mdot
.24798 .90606 Mdot
.34159 .8824 Mdot
.31583 .90389 Mdot
.48533 .59718 Mdot
.78763 .17944 Mdot
.2263 .71387 Mdot
.43465 .83305 Mdot
.34026 .91624 Mdot
.28128 .911 Mdot
.44999 .49126 Mdot
.26249 .89936 Mdot
.56603 .40033 Mdot
.22978 .94159 Mdot
.30526 .82174 Mdot
.1829 .71756 Mdot
.36169 .50625 Mdot
.94112 .37357 Mdot
.225 .8245 Mdot
.03488 .42913 Mdot
.28842 .91719 Mdot
.09031 .15699 Mdot
.22725 .99199 Mdot
.4541 .694 Mdot
.46769 .72048 Mdot
.18093 .66423 Mdot
.37266 .93815 Mdot
.30078 .87322 Mdot
.18675 .64791 Mdot
.17263 .71174 Mdot
.25233 .95253 Mdot
.24293 .85889 Mdot
.16958 .41461 Mdot
.32898 .83488 Mdot
.25539 .90279 Mdot
.25323 .64638 Mdot
.33095 .84502 Mdot
.05954 .92676 Mdot
.03943 .44864 Mdot
.18552 .54226 Mdot
.10522 .13171 Mdot
.18487 .80003 Mdot
.01854 .44314 Mdot
.10167 .69268 Mdot
.22074 .94361 Mdot
.32305 .83199 Mdot
.47752 .96386 Mdot
.26125 .87265 Mdot
.09627 .93787 Mdot
.35774 .701 Mdot
.18025 .66038 Mdot
.29692 .82337 Mdot
.93757 .72452 Mdot
.15499 .77638 Mdot
.3977 .70843 Mdot
.32128 .91712 Mdot
.85188 .43845 Mdot
.88291 .42345 Mdot
.49854 .93139 Mdot
.43536 .99439 Mdot
.31965 .95455 Mdot
.05253 .38951 Mdot
.3907 .82265 Mdot
.73219 .19607 Mdot
.17921 .72745 Mdot
.28053 .74871 Mdot
.22796 .04651 Mdot
.13625 .60963 Mdot
.32905 .83932 Mdot
.92617 .34234 Mdot
.16132 .01172 Mdot
.31394 .36897 Mdot
.18923 .81525 Mdot
.29138 .92034 Mdot
.38823 .95784 Mdot
.25805 .5683 Mdot
.23366 .81265 Mdot
.2926 .74075 Mdot
.37976 .8965 Mdot
.30277 .87599 Mdot
.23543 .98035 Mdot
.48619 .3492 Mdot
.33069 .99693 Mdot
.18288 .05237 Mdot
.3257 .74874 Mdot
.30494 .8157 Mdot
.24245 .73116 Mdot
.52467 .79887 Mdot
.326 .93392 Mdot
.37051 .93643 Mdot
.27194 .76326 Mdot
.11315 .89662 Mdot
.45313 .95176 Mdot
.21635 .10327 Mdot
.45692 .99052 Mdot
.4835 .58664 Mdot
.14316 .73309 Mdot
.16495 .9995 Mdot
.56113 .39058 Mdot
.16001 .79133 Mdot
.26055 .84908 Mdot
.25444 .00164 Mdot
.34228 .77558 Mdot
.35612 .37905 Mdot
.09553 .96138 Mdot
.40012 .97002 Mdot
.25724 .71639 Mdot
.18683 .65676 Mdot
.26343 .28745 Mdot
.44003 .7393 Mdot
.27348 .89985 Mdot
.25116 .86971 Mdot
.47982 .83403 Mdot
.76933 .18501 Mdot
.26773 .91579 Mdot
.31933 .79502 Mdot
.28496 .95352 Mdot
.08834 .72927 Mdot
.35016 .93554 Mdot
.37804 .00894 Mdot
.17032 .78625 Mdot
.07448 .64754 Mdot
.353 .9542 Mdot
.12223 .50668 Mdot
.11948 .98446 Mdot
.33068 .90402 Mdot
.19246 .08372 Mdot
.1014 .83615 Mdot
.20309 .76227 Mdot
.24637 .89285 Mdot
.32717 .9947 Mdot
.19164 .71796 Mdot
.19325 .02693 Mdot
.27063 .9107 Mdot
.34702 .85505 Mdot
.29532 .81393 Mdot
.52381 .38608 Mdot
.53773 .02086 Mdot
.03619 .33106 Mdot
.33915 .40453 Mdot
.90727 .01403 Mdot
.27498 .92083 Mdot
.05763 .70305 Mdot
.91421 .37103 Mdot
.37992 .95316 Mdot
.91875 .05591 Mdot
.19554 .70736 Mdot
.18049 .65503 Mdot
.17278 .72363 Mdot
.6861 .76198 Mdot
.54144 .33941 Mdot
.37961 .25073 Mdot
.12832 .35626 Mdot
.27085 .91337 Mdot
.19095 .82799 Mdot
.32492 .94201 Mdot
.13494 .83146 Mdot
.37785 .00758 Mdot
.61573 .478 Mdot
.2385 .82528 Mdot
.42131 .76055 Mdot
.23029 .69385 Mdot
.23479 .84703 Mdot
.13574 .25832 Mdot
.30527 .82048 Mdot
.14223 .91516 Mdot
.167 .7582 Mdot
.30021 .82209 Mdot
.38721 .94885 Mdot
.27284 .79504 Mdot
.52462 .97035 Mdot
.76508 .14257 Mdot
.07353 .61619 Mdot
.27598 .78845 Mdot
.21878 .78246 Mdot
.27984 .89406 Mdot
.15625 .81659 Mdot
.33299 .83864 Mdot
.23508 .87892 Mdot
.07173 .84482 Mdot
.50426 .79334 Mdot
.30052 .96371 Mdot
.21955 .5184 Mdot
.27259 .81545 Mdot
.2695 .86019 Mdot
.33564 .85729 Mdot
.99561 .56548 Mdot
.50431 .99913 Mdot
.27074 .02008 Mdot
.29231 .93236 Mdot
.45464 .02707 Mdot
.48148 .53964 Mdot
.27636 .91594 Mdot
.42949 .86572 Mdot
.17527 .71228 Mdot
.27788 .84941 Mdot
.21529 .88731 Mdot
.28437 .90895 Mdot
.30566 .91167 Mdot
.52744 .41613 Mdot
.31034 .46739 Mdot
.96369 .36334 Mdot
.26356 .90222 Mdot
.18579 .75285 Mdot
.47751 .90461 Mdot
.53327 .83614 Mdot
.21706 .67699 Mdot
.28023 .91663 Mdot
.4944 .71303 Mdot
.01779 .9697 Mdot
.25185 .10822 Mdot
.18775 .66721 Mdot
.1649 .6769 Mdot
.25543 .7197 Mdot
.21819 .76947 Mdot
.32215 .90096 Mdot
.20395 .76813 Mdot
.65461 .60839 Mdot
.02921 .66069 Mdot
.24863 .74983 Mdot
.20794 .70022 Mdot
.17938 .73441 Mdot
.73399 .67618 Mdot
.25922 .86769 Mdot
.29859 .91013 Mdot
.85932 .88358 Mdot
.20509 .54068 Mdot
.27313 .81618 Mdot
.25158 .88224 Mdot
.53875 .91506 Mdot
.45938 .61053 Mdot
.33708 .85851 Mdot
.17897 .68425 Mdot
.54281 .38426 Mdot
.05419 .68362 Mdot
.16146 .98192 Mdot
.48748 .78066 Mdot
.34839 .84967 Mdot
.62506 .80149 Mdot
.65255 .75732 Mdot
.2561 .0252 Mdot
.14122 .98745 Mdot
.30079 .75364 Mdot
.4691 .7996 Mdot
.16138 .96892 Mdot
.07448 .51618 Mdot
.11639 .4917 Mdot
.23758 .83123 Mdot
.25004 .24659 Mdot
.24659 .86578 Mdot
.32762 .9274 Mdot
.312 .85703 Mdot
.41794 .74219 Mdot
.16651 .74103 Mdot
.99567 .9229 Mdot
.45455 .75978 Mdot
.37487 .94783 Mdot
.28202 .86644 Mdot
.11547 .02696 Mdot
.26525 .90981 Mdot
.33517 .90215 Mdot
.33462 .99215 Mdot
.93684 .97776 Mdot
.70678 .88651 Mdot
.26671 .89847 Mdot
.27311 .90115 Mdot
.28058 .85679 Mdot
.21009 .91254 Mdot
.09078 .56374 Mdot
.35604 .69115 Mdot
.33366 .915 Mdot
.96986 .01698 Mdot
.22983 .82385 Mdot
.23122 .82345 Mdot
.27684 .79054 Mdot
.29812 .9488 Mdot
.27374 .91158 Mdot
.27269 .90915 Mdot
.18982 .87925 Mdot
.25605 .84261 Mdot
.24004 .94764 Mdot
.25755 .88786 Mdot
.37288 .72988 Mdot
.39473 .99031 Mdot
.29459 .11394 Mdot
.19222 .94466 Mdot
.31811 .82479 Mdot
.18854 .7039 Mdot
.16253 .73495 Mdot
.9139 .45052 Mdot
.98864 .51345 Mdot
.37914 .885 Mdot
.26189 .86339 Mdot
.35025 .99228 Mdot
.16325 .8013 Mdot
.30968 .89451 Mdot
.55177 .38542 Mdot
.47956 .98654 Mdot
.34369 .90383 Mdot
.25327 .89236 Mdot
.4078 .79484 Mdot
.31721 .94815 Mdot
.00337 .64356 Mdot
.13243 .81719 Mdot
.37349 .77605 Mdot
.3133 .00587 Mdot
.33624 .85415 Mdot
.13165 .53642 Mdot
.2537 .7761 Mdot
.41364 .66939 Mdot
.2939 .94383 Mdot
.55265 .43053 Mdot
.32977 .90468 Mdot
.2593 .79844 Mdot
.20593 .70537 Mdot
.26322 .96506 Mdot
.23521 .10764 Mdot
.00355 .61906 Mdot
.31523 .92992 Mdot
.08218 .92189 Mdot
.38267 .01743 Mdot
.39642 .85618 Mdot
.78205 .56681 Mdot
.19445 .74026 Mdot
.21705 .68648 Mdot
.19143 .89283 Mdot
.26811 .86388 Mdot
.3098 .88149 Mdot
.05469 .83344 Mdot
.88922 .70074 Mdot
.54934 .34431 Mdot
.4543 .33935 Mdot
.06962 .78301 Mdot
.94412 .98097 Mdot
.05037 .28331 Mdot
.46093 .11088 Mdot
.32418 .92938 Mdot
.17854 .02499 Mdot
.26899 .90042 Mdot
.23795 .89908 Mdot
.31676 .85721 Mdot
.3625 .92771 Mdot
.0835 .59541 Mdot
.4781 .27715 Mdot
.32189 .83531 Mdot
.01466 .6909 Mdot
.21486 .98163 Mdot
.2505 .84938 Mdot
.17272 .78635 Mdot
.56053 .51292 Mdot
.39948 .76549 Mdot
.08994 .78986 Mdot
.25404 .75311 Mdot
.24815 .88884 Mdot
.48338 .52248 Mdot
.48074 .64493 Mdot
.34974 .91813 Mdot
.94137 .79489 Mdot
.43955 .94485 Mdot
.6115 .66443 Mdot
.33278 .99102 Mdot
.27291 .9258 Mdot
.33786 .93566 Mdot
.77204 .12213 Mdot
.26971 .7502 Mdot
.33919 .97923 Mdot
.07106 .56496 Mdot
.01272 .82173 Mdot
.2653 .76372 Mdot
.30646 .99536 Mdot
.21655 .83638 Mdot
.37727 .94346 Mdot
.32756 .44878 Mdot
.26132 .81625 Mdot
.50014 .1172 Mdot
.41573 .96995 Mdot
.26075 .83817 Mdot
.20913 .7058 Mdot
.26485 .84878 Mdot
.34006 .86923 Mdot
.14333 .01071 Mdot
.22267 .02854 Mdot
.31688 .91295 Mdot
.41225 .73135 Mdot
.56974 .7484 Mdot
.50013 .66463 Mdot
.21842 .91619 Mdot
.17537 .7148 Mdot
.14444 .64422 Mdot
.29623 .93293 Mdot
.1636 .9741 Mdot
.60625 .67783 Mdot
.44518 .90662 Mdot
.23991 .66326 Mdot
.25327 .88379 Mdot
.27217 .93282 Mdot
.18239 .65973 Mdot
.31865 .92733 Mdot
.18998 .95021 Mdot
.28424 .94171 Mdot
.22591 .98653 Mdot
.2561 .89013 Mdot
.30736 .95432 Mdot
.21438 .6739 Mdot
.33896 .86704 Mdot
.29112 .89629 Mdot
.16789 .81745 Mdot
.35996 .698 Mdot
.61643 .77928 Mdot
.24867 .71083 Mdot
.27882 .92013 Mdot
.29066 .81152 Mdot
.56138 .71101 Mdot
.16701 .73293 Mdot
.52228 .69004 Mdot
.5551 .4049 Mdot
.25401 .78587 Mdot
.49195 .29176 Mdot
.14029 .74377 Mdot
.28026 .07129 Mdot
.18204 .68948 Mdot
.90161 .46089 Mdot
.4032 .96406 Mdot
.23608 .54649 Mdot
.40606 .85534 Mdot
.59831 .03347 Mdot
.16237 .72933 Mdot
.92488 .49857 Mdot
.41735 .7383 Mdot
.14833 .01902 Mdot
.97629 .348 Mdot
.90807 .37605 Mdot
.29345 .89999 Mdot
.46171 .92245 Mdot
.1777 .82835 Mdot
.3047 .87875 Mdot
.2443 .65808 Mdot
.55323 .86945 Mdot
.26437 .83684 Mdot
.14971 .16726 Mdot
.26976 .90512 Mdot
.35458 .60644 Mdot
.29699 .87393 Mdot
.23829 .81505 Mdot
.47602 .94804 Mdot
.27648 .82304 Mdot
.43587 .74902 Mdot
.47641 .98658 Mdot
.64019 .81932 Mdot
.19444 .68272 Mdot
.31357 .07025 Mdot
.2806 .73355 Mdot
.27155 .90014 Mdot
.55497 .7109 Mdot
.11069 .60953 Mdot
.29318 .98126 Mdot
.07422 .96132 Mdot
.30037 .86735 Mdot
.40748 .75869 Mdot
.30847 .92761 Mdot
.26943 .95675 Mdot
.52718 .87962 Mdot
.58366 .41506 Mdot
.26388 .90551 Mdot
.50591 .78557 Mdot
.24776 .79422 Mdot
.30473 .23044 Mdot
.27611 .94514 Mdot
.9327 .33451 Mdot
.94183 .96771 Mdot
.25451 .86891 Mdot
.6226 .48909 Mdot
.08807 .8108 Mdot
.99848 .00477 Mdot
.20832 .81089 Mdot
.34411 .19239 Mdot
.27415 .94112 Mdot
.27103 .83206 Mdot
.10354 .67361 Mdot
.28862 .94006 Mdot
.49111 .87398 Mdot
.274 .83296 Mdot
.42101 .36759 Mdot
.60841 .39013 Mdot
.09468 .47776 Mdot
.20837 .78233 Mdot
.02815 .63812 Mdot
.15517 .72574 Mdot
.26219 .81816 Mdot
.22459 .70517 Mdot
.32088 .07098 Mdot
.51187 .31612 Mdot
.18262 .91878 Mdot
.22539 .80839 Mdot
.44898 .92557 Mdot
.39377 .88187 Mdot
.2364 .07594 Mdot
.51616 .04509 Mdot
.33546 .88713 Mdot
.24607 .77167 Mdot
.28608 .86124 Mdot
.4893 .1615 Mdot
.05556 .84986 Mdot
.19872 .49567 Mdot
.15218 .20113 Mdot
.38668 .00195 Mdot
.22649 .85501 Mdot
.15688 .77622 Mdot
.96302 .46391 Mdot
.32088 .87199 Mdot
.23319 .30693 Mdot
.06296 .62069 Mdot
.43148 .52834 Mdot
.34702 .89177 Mdot
.24069 .55565 Mdot
.23809 .7146 Mdot
.4895 .89048 Mdot
.13465 .43376 Mdot
.26368 .8649 Mdot
.6879 .45769 Mdot
.30516 .8225 Mdot
.2855 .92265 Mdot
.2059 .55643 Mdot
.30957 .82888 Mdot
.19215 .71513 Mdot
.09961 .77673 Mdot
.22091 .69215 Mdot
.62136 .39329 Mdot
.98773 .09345 Mdot
.54686 .68913 Mdot
.38956 .92535 Mdot
.2724 .93617 Mdot
.45721 .00692 Mdot
.28796 .73257 Mdot
.27241 .85903 Mdot
.28306 .83177 Mdot
.21609 .86151 Mdot
.32922 .85951 Mdot
.25298 .56481 Mdot
.55826 .18055 Mdot
.44004 .68998 Mdot
.38478 .86467 Mdot
.25473 .07442 Mdot
.59621 .49772 Mdot
.33993 .84226 Mdot
.3047 .84304 Mdot
.13538 .73429 Mdot
.49108 .50938 Mdot
.11489 .94478 Mdot
.34986 .05052 Mdot
.27054 .81577 Mdot
.24736 .74037 Mdot
.34836 .98593 Mdot
.99155 .49834 Mdot
.4943 .93185 Mdot
.18918 .79994 Mdot
.1403 .02469 Mdot
.18097 .74629 Mdot
.20616 .69258 Mdot
.39714 .93739 Mdot
.29179 .79968 Mdot
.43352 .92174 Mdot
.24754 .95124 Mdot
.16663 .79183 Mdot
.5779 .70843 Mdot
.27315 .91468 Mdot
.44114 .38367 Mdot
.20211 .79771 Mdot
.25447 .12309 Mdot
.26093 .83304 Mdot
.11507 .78595 Mdot
.04964 .71494 Mdot
.24789 .9085 Mdot
.4242 .37681 Mdot
.34995 .93175 Mdot
.16947 .9259 Mdot
.25303 .78404 Mdot
.32136 .91689 Mdot
.4485 .44965 Mdot
.18021 .72029 Mdot
.40347 .96949 Mdot
.16636 .80211 Mdot
.11838 .03471 Mdot
.33586 .36057 Mdot
.29173 .85601 Mdot
.15214 .92376 Mdot
.16911 .76712 Mdot
.11202 .00455 Mdot
.2906 .89004 Mdot
.2572 .96102 Mdot
.35406 .02273 Mdot
.3229 .83969 Mdot
.30845 .89227 Mdot
.22928 .87645 Mdot
.39053 .88835 Mdot
.07112 .61887 Mdot
.5311 .69899 Mdot
.26821 .97509 Mdot
.19907 .74162 Mdot
.27486 .95417 Mdot
.37122 .98943 Mdot
.41046 .99899 Mdot
.32685 .89437 Mdot
.17311 .65516 Mdot
.07055 .18182 Mdot
.27976 .80486 Mdot
.21613 .92443 Mdot
.1723 .92267 Mdot
.25172 .65376 Mdot
.23552 .75023 Mdot
.52184 .32532 Mdot
.16619 .24176 Mdot
.16725 .76292 Mdot
.19763 .67165 Mdot
.09751 .83032 Mdot
.32071 .92494 Mdot
.19263 .89388 Mdot
.51593 .99533 Mdot
.4215 .87878 Mdot
.28317 .88551 Mdot
.35261 .932 Mdot
.15749 .74733 Mdot
.23332 .83757 Mdot
.62045 .49114 Mdot
.26935 .90394 Mdot
.25925 .88747 Mdot
.38977 .98087 Mdot
.2333 .86287 Mdot
.28964 .94058 Mdot
.25571 .88809 Mdot
.30532 .96261 Mdot
.39186 .95704 Mdot
.47368 .45772 Mdot
.20769 .68516 Mdot
.37769 .83937 Mdot
.13237 .89707 Mdot
.24628 .83576 Mdot
.37117 .52252 Mdot
.4609 .75884 Mdot
.2717 .74402 Mdot
.2191 .09498 Mdot
.29957 .98467 Mdot
.38374 .95336 Mdot
.85037 .64977 Mdot
.57653 .91398 Mdot
.2575 .88535 Mdot
.27042 .89845 Mdot
.33324 .86039 Mdot
.22131 .74357 Mdot
.61781 .6039 Mdot
.9839 .98064 Mdot
.18446 .83665 Mdot
.28632 .94125 Mdot
.18687 .79476 Mdot
.07769 .52213 Mdot
.23347 .65255 Mdot
.15395 .75323 Mdot
.26407 .64021 Mdot
.26433 .94059 Mdot
.20793 .47736 Mdot
.27098 .9095 Mdot
.28743 .1758 Mdot
.39015 .97668 Mdot
.21996 .83033 Mdot
.26616 .8947 Mdot
.27011 .85508 Mdot
.34578 .88928 Mdot
.06178 .25627 Mdot
.28055 .9564 Mdot
.26835 .98481 Mdot
.13997 .73273 Mdot
.25284 .02606 Mdot
.54303 .04505 Mdot
.24763 .87738 Mdot
.56325 .972 Mdot
.25477 .92917 Mdot
.35059 .92338 Mdot
.29785 .938 Mdot
.40876 .91399 Mdot
.30405 .94212 Mdot
.43957 .41125 Mdot
.198 .79024 Mdot
.56756 .8383 Mdot
.19797 .68849 Mdot
.12259 .84544 Mdot
.24279 .8042 Mdot
.27516 .91519 Mdot
.21941 .95859 Mdot
.44575 .7443 Mdot
.15842 .74039 Mdot
.17694 .74902 Mdot
.09935 .72511 Mdot
.30705 .81523 Mdot
.01994 .87651 Mdot
.12675 .53602 Mdot
.49509 .38083 Mdot
.46577 .75757 Mdot
.30851 .81872 Mdot
.81567 .64999 Mdot
.26412 .87349 Mdot
.66777 .68436 Mdot
.23132 .81302 Mdot
.18612 .87037 Mdot
.40515 .95827 Mdot
.19993 .69255 Mdot
.17872 .0362 Mdot
.94194 .75698 Mdot
.32398 .74639 Mdot
.6119 .52144 Mdot
.61535 .04852 Mdot
.07834 .99868 Mdot
.28584 .70069 Mdot
.14845 .73431 Mdot
.20637 .69975 Mdot
.26839 .06307 Mdot
.97291 .90105 Mdot
.08263 .49125 Mdot
.35571 .91362 Mdot
.27702 .93614 Mdot
.43685 .21417 Mdot
.15781 .90951 Mdot
.25651 .89747 Mdot
.36864 .85052 Mdot
.33551 .86158 Mdot
.19545 .54473 Mdot
.19497 .05789 Mdot
.20776 .67967 Mdot
.2722 .90075 Mdot
.24251 .82126 Mdot
.05785 .36756 Mdot
.12442 .49524 Mdot
.1221 .03892 Mdot
.15228 .72576 Mdot
.57774 .40955 Mdot
.44254 .72612 Mdot
.28118 .82814 Mdot
.25304 .88275 Mdot
.32979 .84099 Mdot
.95898 .31947 Mdot
.16841 .7184 Mdot
.15579 .78252 Mdot
.28789 .82984 Mdot
.25475 .87269 Mdot
.93294 .55517 Mdot
.23762 .86717 Mdot
.14055 .76769 Mdot
.33691 .91824 Mdot
.56061 .47028 Mdot
.45537 .73364 Mdot
.2826 .83503 Mdot
.33296 .96651 Mdot
.45415 .6903 Mdot
.32234 .84173 Mdot
.33398 .14285 Mdot
.24201 .79513 Mdot
.47766 .87321 Mdot
.45165 .75452 Mdot
.93532 .31026 Mdot
.43915 .72747 Mdot
.18201 .84952 Mdot
.87789 .53489 Mdot
.11106 .9935 Mdot
.54229 .6023 Mdot
.39057 .06238 Mdot
.29748 .81168 Mdot
.28881 .87361 Mdot
.23262 .83335 Mdot
.23734 .63189 Mdot
.25849 .89453 Mdot
.59471 .42534 Mdot
.25451 .87626 Mdot
.17259 .73254 Mdot
.63238 .61442 Mdot
.51388 .28446 Mdot
.13121 .28056 Mdot
.26239 .91318 Mdot
.06377 .63112 Mdot
.58537 .49828 Mdot
.91973 .52125 Mdot
.28871 .93429 Mdot
.25271 .9992 Mdot
.41259 .98834 Mdot
.26695 .88758 Mdot
.25092 .92209 Mdot
.27255 .90032 Mdot
.18276 .66287 Mdot
.22157 .63949 Mdot
.27558 .03735 Mdot
.26967 .81789 Mdot
.45965 .76403 Mdot
.1065 .02004 Mdot
.40962 .3334 Mdot
.40548 .72769 Mdot
.26125 .91449 Mdot
.00796 .28074 Mdot
.295 .86402 Mdot
.12605 .02316 Mdot
.38987 .94582 Mdot
.39187 .95839 Mdot
.27308 .94036 Mdot
.21207 .86658 Mdot
.3372 .74671 Mdot
.22349 .92491 Mdot
.29005 .84492 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?o
oooo0_l00009ooooo`03o`000?oooooooooo00gooooo0ol0000=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool02Oooool2o`0000?ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;o0000
1oooool2o`0000;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`Co0000
3?ooool01?l0003oooooooooooooool2o`0000[ooooo00?o0000ooooooooool01_ooool2o`000003
ooooool0003o000000?ooooo00?o0000ooooooooool03Oooool01?l0003oooooo`000?l0000<oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00gooooo0_l00004ooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o
00001oooool2o`0002Gooooo0_l0000?ooooo`?o00001_ooool4o`0000Wooooo0_l0000Hooooo`;o
0000[_ooool2o`0000Cooooo000Nooooo`03o`000?oooooooooo02[ooooo0_l00004ooooo`;o0000
;oooool2o`0000Oooooo1?l00009ooooo`;o0000c_ooool001kooooo00?o0000ooooooooool0:_oo
ool2o`0000Cooooo0_l0000Fooooo`;o0000fOooool2o`0001Wooooo0_l00007ooooo`007_ooool0
0ol0003oooooooooo`0/ooooo`;o00006_ooool2o`0002kooooo0_l0002Yooooo`;o00004_ooool2
o`0000Gooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o00002oooool2o`00
02Kooooo0_l0000Iooooo`;o00001oooool2o`00037ooooo0_l0002:ooooo`;o00003_ooool001ko
oooo00?o0000ooooooooool07oooool2o`0000Cooooo0_l00002ooooo`;o00002oooool2o`0000co
oooo0_l00009ooooo`;o00000oooool2o`0001Wooooo0_l0000jooooo`;o0000V_ooool001kooooo
00?o0000ooooooooool08Oooool2o`0000;ooooo0_l00002ooooo`;o00002oooool2o`0000?ooooo
0_l00007ooooo`;o00002?ooool3o`0003oooooo0_l0002eooooo`007_ooool00ol0003ooooooooo
o`0Qooooo`;o00006?ooool2o`0000Oooooo0_l00008ooooo`;o0000@?ooool2o`000;Gooooo000N
ooooo`03o`000?oooooooooo02;ooooo0_l0002Jooooo`;o0000Qoooool001kooooo00?o0000oooo
ooooool08_ooool2o`0001;ooooo0_l0000Mooooo`;o0000Ioooool2o`0008Oooooo000Nooooo`03
o`000?oooooooooo02Cooooo0_l0000@ooooo`;o00007Oooool2o`0000cooooo0_l0000>ooooo`;o
0000d_ooool001kooooo00?o0000ooooooooool09?ooool2o`0002oooooo0_l0000<ooooo`;o0000
3_ooool2o`000=;ooooo000Nooooo`03o`000?oooooooooo04Kooooo0_l0000=ooooo`;o0000COoo
ool2o`0000Kooooo0_l0002Iooooo`007_ooool00ol0003oooooooooo`16ooooo`;o00009_ooool2
o`0003Cooooo0_l00006ooooo`;o00005_ooool2o`00087ooooo000Nooooo`;o0000>?ooool2o`00
02gooooo0_l00006ooooo`;o0000E?ooool2o`00087ooooo000Nooooo`03o`000?oooooooooo03Oo
oooo0_l0000Oooooo`;o00003?ooool2o`000;oooooo0_l0000Nooooo`007_ooool00ol0003ooooo
ooooo`0kooooo`;o00006oooool2o`000<gooooo0_l0000Nooooo`007_ooool00ol0003ooooooooo
o`0kooooo`;o0000?_ooool2o`000<[ooooo000Nooooo`03o`000?oooooooooo05?ooooo0_l0000V
ooooo`;o0000b_ooool001kooooo00?o0000ooooooooool0Doooool2o`000?;ooooo000Nooooo`03
o`000?oooooooooo05Oooooo0_l00006ooooo`;o000000?oooooo`000?l000000_l0003Qooooo`00
7_ooool00ol0003oooooooooo`1?ooooo`;o00001_ooool2o`0000Kooooo0_l000000ooooooo0000
o`000002o`000>7ooooo000Nooooo`03o`000?oooooooooo04?ooooo0_l00004ooooo`;o00001?oo
ool2o`000?Kooooo000Nooooo`03o`000?oooooooooo04?ooooo0_l00004ooooo`;o0000U?ooool2
o`0006Kooooo000Nooooo`03o`000?oooooooooo03[ooooo0_l00004ooooo`;o0000WOooool2o`00
06Kooooo000Nooooo`03o`000?oooooooooo02oooooo0_l00009ooooo`;o00001?ooool2o`000?oo
oooo1_ooool001kooooo00?o0000ooooooooool01Oooool2o`0002Sooooo0_l0003ooooooaOooooo
000Nooooo`03o`000?oooooooooo00Gooooo0_l0003oooooocOooooo0_l00008ooooo`007_ooool0
0ol0003oooooooooo`13ooooo`;o00008Oooool2o`000=Gooooo0_l00008ooooo`007_ooool00ol0
003oooooooooo`13ooooo`;o00008Oooool2o`000=oooooo000Nooooo`;o0000oooooom9ooooo`00
7_ooool00ol0003oooooooooo`0Sooooo`;o00007Oooool2o`000?oooooo1?ooool001kooooo00?o
0000ooooooooool08oooool2o`0001gooooo0_l00004ooooo`;o00001?ooool2o`000?Oooooo000N
ooooo`03o`000?oooooooooo04Sooooo0_l00004ooooo`;o0000@_ooool2o`000;?ooooo000Noooo
o`03o`000?oooooooooo05cooooo0_l0000dooooo`;o0000/oooool001kooooo00?o0000oooooooo
ool0G?ooool2o`00043ooooo0_l0002Wooooo`007_ooool00ol0003oooooooooo`2Nooooo`;o0000
Yoooool001kooooo00?o0000ooooooooool0Coooool2o`000:Kooooo0_l0001>ooooo`007_ooool0
0ol0003oooooooooo`0Dooooo`;o0000>Oooool2o`000:Kooooo0_l0001>ooooo`007_ooool00ol0
003oooooooooo`0Dooooo`;o0000oooooolbooooo`007_ooool00ol0003oooooooooo`0Nooooo`;o
0000oooooolXooooo`007_ooool00ol0003oooooooooo`0Nooooo`;o0000oooooolXooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo06Sooooo0_l0002;
ooooo`;o0000D?ooool001kooooo00?o0000ooooooooool0J?ooool2o`0000Cooooo0_l0000]oooo
o`;o0000E_ooool2o`00053ooooo000Nooooo`03o`000?oooooooooo06kooooo0_l0000]ooooo`;o
0000Z?ooool001kooooo0_l0003Wooooo`;o0000Goooool001kooooo00?o0000ooooooooool0i_oo
ool2o`0005oooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l0003oooooobgooooo000Noooo
o`03o`000?oooooooooo01Wooooo0_l0003oooooobgooooo000Nooooo`03o`000?oooooooooo09_o
oooo0_l0002Zooooo`007_ooool00ol0003oooooooooo`0]ooooo`;o0000K?ooool2o`000:[ooooo
000Nooooo`03o`000?oooooooooo02gooooo0_l0003ooooooaWooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0FOooool2o`000>cooooo000Nooooo`03
o`000?oooooooooo05Wooooo0_l0002Qooooo`;o0000BOooool001kooooo00?o0000ooooooooool0
4oooool2o`0009cooooo0_l00019ooooo`;o0000BOooool001kooooo00?o0000ooooooooool04ooo
ool2o`0009cooooo0_l00013ooooo`;o0000Coooool001kooooo00?o0000ooooooooool0m_ooool2
o`0004oooooo000Nooooo`03o`000?oooooooooo033ooooo0_l0003ooooooaKooooo0003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo
033ooooo0_l0000jooooo`;o0000fOooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0K?ooool2
o`0007cooooo0_l0001Kooooo`000oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RH
ob4Q8Oo^k^h01oooool3o`0002gooooo0_l0002kooooo`;o0000Foooool000?ooooo00Go0000oooo
ooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0;Oooool2
o`000?oooooo6Oooool000?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKo
oooo00Gooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodSooooo0003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o
0000ooooooooool0n_ooool2o`0004_ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0R_ooool2o`0006kooooo
0_l0001;ooooo`007_ooool00ol0003oooooooooo`2:ooooo`;o0000^oooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooocoooooo0_l00007oooo
o`007_ooool00ol0003oooooooooo`3oooooocoooooo0_l00007ooooo`007_ooool00ol0003ooooo
ooooo`1Oooooo`;o0000i_ooool001kooooo00?o0000ooooooooool0Goooool2o`000>Kooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`0booooo`;o0000IOooool2o`000:cooooo000Nooooo`03o`00
0?oooooooooo03;ooooo0_l0000Iooooo`;o0000B_ooool2o`000:cooooo000Nooooo`03o`000?oo
oooooooo04gooooo0_l0003hooooo`007_ooool2o`0007Sooooo0_l0003>ooooo`007_ooool00ol0
003oooooooooo`0@ooooo`;o0000IOooool2o`000<kooooo000Nooooo`03o`000?oooooooooo013o
oooo0_l0000Fooooo`;o0000oooooolNooooo`007_ooool00ol0003oooooooooo`0Xooooo`;o0000
oooooolNooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo09Oooooo0_l0002^ooooo`007_oo
ool3o`0002Oooooo0_l0001^ooooo`;o0000[_ooool001kooooo0ol0000<ooooo`;o00006Oooool2
o`000?oooooo7oooool001kooooo00?o0000ooooooooool03?ooool2o`0004Cooooo0_l0001?oooo
o`;o0000X_ooool001kooooo00?o0000ooooooooool0D_ooool2o`0004oooooo0_l0002Rooooo`00
7_ooool00ol0003oooooooooo`2Looooo`;o0000ZOooool001kooooo00?o0000ooooooooool0W?oo
ool2o`0000Wooooo0_l0002Nooooo`007_ooool00ol0003oooooooooo`2Wooooo`;o0000W_ooool0
01kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0B?ooool2o`000?gooooo000Nooooo`03o`000?oooooooooo02kooooo0_l0
000Hooooo`;o0000h_ooool2o`0001Wooooo000Nooooo`03o`000?oooooooooo02kooooo0_l0003l
ooooo`;o00006Oooool001kooooo00?o0000ooooooooool0X_ooool2o`000:?ooooo000Nooooo`03
o`000?oooooooooo0:;ooooo0_l0002@ooooo`;o00004Oooool001kooooo00?o0000ooooooooool0
ooooooleooooo`;o00004Oooool001kooooo00?o0000ooooooooool0Y_ooool2o`0009oooooo000N
ooooo`03o`000?oooooooooo027ooooo0_l00023ooooo`;o0000Woooool001kooooo00?o0000oooo
ooooool02?ooool2o`0001Oooooo0_l0001Nooooo`;o0000a?ooool001kooooo00?o0000oooooooo
ool02?ooool2o`0007Oooooo0_l0002Xooooo`;o00006_ooool001kooooo00?o0000ooooooooool0
T?ooool2o`0001[ooooo0_l0001mooooo`;o00006_ooool001kooooo00?o0000ooooooooool06_oo
ool2o`0007Cooooo0_l0000Jooooo`;o0000Noooool2o`0001cooooo000Nooooo`03o`000?oooooo
oooo01[ooooo0_l0002Booooo`;o0000NOooool2o`0001cooooo000Nooooo`03o`000?oooooooooo
0:kooooo0_l00029ooooo`;o00003?ooool001kooooo0_l0000Looooo`;o0000OOooool2o`0009go
oooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`0Kooooo`;o0000OOooool2o`000:_ooooo
000Nooooo`03o`000?oooooooooo02Kooooo0_l0003oooooob3ooooo000Nooooo`03o`000?oooooo
oooo02Kooooo0_l00011ooooo`;o0000g?ooool001kooooo00?o0000ooooooooool0JOooool2o`00
0<[ooooo0_l0000@ooooo`007_ooool00ol0003oooooooooo`3oooooocKooooo0_l0000@ooooo`00
7_ooool00ol0003oooooooooo`0?ooooo`;o0000DOooool2o`00027ooooo0_l00030ooooo`007_oo
ool00ol0003oooooooooo`0?ooooo`;o0000DOooool2o`00027ooooo0_l0002Nooooo`;o00001ooo
ool2o`0001Oooooo000Nooooo`03o`000?oooooooooo0?oooooo9?ooool4o`0000Oooooo0_l0000G
ooooo`007_ooool00ol0003oooooooooo`03ooooo`;o0000Joooool2o`0001Cooooo0_l0002Koooo
o`;o00008_ooool001kooooo00?o0000ooooooooool00oooool2o`0006_ooooo0_l0000Dooooo`;o
00005Oooool2o`0007oooooo0_l0000Wooooo`007_ooool00ol0003oooooooooo`2;ooooo`;o0000
1?ooool2o`0000[ooooo0_l0000=ooooo`;o000000?oooooo`000?l00000KOooool2o`0002Oooooo
000Nooooo`03o`000?oooooooooo08_ooooo0_l00004ooooo`;o00004oooool2o`0000Cooooo0_l0
00000ooooooo0000o`00002Fooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o0000Uoooool2
o`0000[ooooo0_l0000>ooooo`;o0000Poooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool03Oooool2
o`000:?ooooo0_l0000>ooooo`;o00000_ooool2o`0007oooooo0003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`36
ooooo`;o0000Ooooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool3
o`000;Cooooo0_l0002Aooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo00001oooool00ol0003oooooooooo`2dooooo`;o0000TOooool000?ooooo00Go0000
ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0
J_ooool2o`0004Cooooo0_l0002Eooooo`000oooool01Ol@413ooooooooooooooooo410@00cooooo
00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`1Zooooo`;o0000A?ooool2o`0000Kooooo
0_l0002=ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
1oooool00ol0003oooooooooo`2;ooooo`;o0000:oooool2o`0008gooooo0003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo03?ooooo
0_l0001Fooooo`;o00006_ooool2o`00017ooooo0_l0002;ooooo`007_ooool00ol0003ooooooooo
o`0cooooo`;o0000L_ooool2o`00017ooooo0_l0002;ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo06Wooooo0_l0001Booooo`;o0000G?ooool2o`00
02[ooooo000Nooooo`03o`000?oooooooooo06Wooooo0_l0001Booooo`;o0000G?ooool2o`0002[o
oooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0002Wooooo`;o0000UOooool001kooooo00?o
0000ooooooooool01oooool2o`0001oooooo0_l00026ooooo`;o0000UOooool001kooooo00?o0000
ooooooooool0:?ooool2o`000:Sooooo0_l0001cooooo`007_ooool00ol0003oooooooooo`3Boooo
o`;o0000?Oooool2o`0003Cooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0003oooooo`ko
oooo0_l0000dooooo`007_ooool00ol0003oooooooooo`02ooooo`;o0000oooooom4ooooo`007_oo
ool00ol0003oooooooooo`09ooooo`;o0000Foooool2o`0002Kooooo0_l0002gooooo`007_ooool2
o`0000[ooooo0_l0001Kooooo`;o00009_ooool2o`0009Gooooo0_l0000Pooooo`007_ooool00ol0
003oooooooooo`3oooooobKooooo0_l0000Pooooo`007_ooool00ol0003oooooooooo`2Fooooo`;o
0000A?ooool2o`0006Wooooo000Nooooo`03o`000?oooooooooo09Kooooo0_l00014ooooo`;o0000
@oooool2o`0002Cooooo000Nooooo`03o`000?oooooooooo00cooooo0_l0003ooooooaCooooo0_l0
000Booooo`;o00004?ooool001kooooo00?o0000ooooooooool03?ooool2o`0005?ooooo0_l0003B
ooooo`;o00004?ooool001kooooo00?o0000ooooooooool0HOooool2o`0004oooooo0_l0000;oooo
o`;o0000Q_ooool001kooooo00?o0000ooooooooool0Y?ooool2o`0000cooooo0_l0000;ooooo`;o
0000Q_ooool001kooooo00?o0000ooooooooool06oooool2o`0002;ooooo0_l0001Sooooo`;o0000
7_ooool2o`00087ooooo000Nooooo`03o`000?oooooooooo01_ooooo0_l0000Rooooo`;o00001Ooo
ool2o`0007cooooo0_l00021ooooo`007_ooool00ol0003oooooooooo`16ooooo`;o0000ooooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`36ooooo`;o
0000Ooooool001kooooo00?o0000ooooooooool05oooool2o`0000Wooooo0_l0001Zooooo`;o0000
=_ooool2o`0007oooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l00009ooooo`Co00005_oo
ool2o`00053ooooo0_l0000fooooo`;o0000Ooooool001kooooo00?o0000ooooooooool05?ooool2
o`0000kooooo0_l0000Fooooo`;o0000O?ooool2o`0000;ooooo0_l0001Yooooo`;o00004oooool2
o`0000Oooooo000Nooooo`;o00005Oooool2o`000:Cooooo0_l00002ooooo`;o0000JOooool2o`00
01?ooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo02Cooooo0_l0001;ooooo`;o0000e?ooool001kooooo00?o0000ooooooooool09?oo
ool2o`0004_ooooo0_l0000Yooooo`;o0000ZOooool001kooooo00?o0000ooooooooool0W?ooool2
o`0001Cooooo0_l00029ooooo`;o00002?ooool001kooooo00?o0000ooooooooool05?ooool2o`00
00Gooooo0_l0002Eooooo`;o0000ROooool2o`0000Sooooo000Nooooo`04o`000?oooooooooooooo
o`;o00004Oooool2o`0000Gooooo0_l0000Vooooo`;o0000ooooool3ooooo`007_ooool01?l0003o
ooooooooooooool2o`0001;ooooo0_l0000/ooooo`;o00004Oooool2o`0001gooooo0_l0000Roooo
o`;o0000:?ooool2o`0006;ooooo0_l0000Nooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o
0000?oooool2o`0001gooooo0_l0000Rooooo`;o0000:?ooool2o`0006;ooooo0_l0000Nooooo`00
7_ooool00ol0003oooooooooo`28ooooo`;o0000_Oooool001kooooo00?o0000ooooooooool0R?oo
ool2o`000;gooooo000Nooooo`03o`000?oooooooooo02Gooooo1?l0003`ooooo`;o0000;?ooool0
01kooooo00?o0000ooooooooool09Oooool4o`0006oooooo0_l0001oooooo`;o0000;?ooool001ko
oooo00?o0000ooooooooool0>?ooool2o`0000Gooooo0_l0001Gooooo`;o0000[Oooool001kooooo
00?o0000ooooooooool0>?ooool2o`000003ooooool0003o000000;ooooo0_l0003oooooo`Oooooo
000Nooooo`03o`000?oooooooooo00Sooooo0_l0000aooooo`;o00003?ooool2o`000?cooooo000N
ooooo`;o00002Oooool2o`0003oooooo0_l0003looooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo03oooooo0_l00009ooooo`;o0000P?ooool2o`0005go
oooo0_l0000Jooooo`007_ooool00ol0003oooooooooo`0oooooo`;o00002Oooool2o`00083ooooo
0_l0001Mooooo`;o00006_ooool001kooooo00?o0000ooooooooool06Oooool2o`000?oooooo;Ooo
ool001kooooo00?o0000ooooooooool04oooool2o`0000Cooooo0_l0000cooooo`;o0000Z_ooool2
o`0004Cooooo0_l00005ooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o0000>Oooool4o`00
0:Sooooo0_l00014ooooo`;o00001Oooool001kooooo00?o0000ooooooooool0D?ooool2o`000?Go
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0Soooool2o`0000Sooooo0_l0002/ooooo`00
7_ooool00ol0003oooooooooo`2?ooooo`;o00002?ooool2o`000:cooooo0003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03
o`000?oooooooooo0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool05oooool2o`00
087ooooo0_l0002[ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooo
ooooooooooooo`000006ooooo`?o00005oooool2o`00087ooooo0_l0000Looooo`;o0000SOooool0
00?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_oo
ool00ol0003oooooooooo`2/ooooo`;o00002_ooool2o`0000_ooooo0_l00020ooooo`000oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`00
0?oooooooooo06oooooo0_l0000kooooo`;o00005oooool2o`00083ooooo0003ooooo`05oa0@4?oo
ooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo023ooooo
0_l00006ooooo`;o0000AOooool2o`00063ooooo0_l0001dooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0Pooooo`;o0000
1_ooool2o`0006Oooooo0_l0000nooooo`;o0000M?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool05?ooool2o`0007_o
oooo0_l0000fooooo`;o0000O?ooool001kooooo0_l0000Dooooo`?o0000/oooool2o`0007cooooo
000Nooooo`;o00004Oooool2o`000003ooooool0003o00000?oooooo<oooool001kooooo00?o0000
ooooooooool04?ooool2o`000?oooooo=_ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`0Aooooo`;o0000=_ooool2o`000?cooooo000Nooooo`03o`00
0?oooooooooo017ooooo0_l0000fooooo`;o0000o?ooool001kooooo00?o0000ooooooooool01Ooo
ool2o`000?oooooo@Oooool001kooooo00?o0000ooooooooool01Oooool2o`0003gooooo0_l0000<
ooooo`;o0000loooool001kooooo0_l0000/ooooo`;o00005oooool2o`0000cooooo0_l0003coooo
o`007_ooool2o`0002cooooo0_l0000@ooooo`;o00002oooool2o`0000;ooooo0_l00018ooooo`;o
0000[Oooool001kooooo00?o0000ooooooooool05?ooool2o`0002?ooooo0_l00002ooooo`;o0000
2oooool2o`0000;ooooo0_l00018ooooo`;o0000Joooool2o`0000Wooooo0_l0000eooooo`007_oo
ool2o`00017ooooo0_l00002ooooo`;o00008oooool2o`0000gooooo0_l0001@ooooo`;o0000JOoo
ool2o`0000Wooooo0_l0000eooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o00008_ooool5
o`0000oooooo0_l00004ooooo`;o0000B_ooool2o`000:_ooooo000Nooooo`03o`000?oooooooooo
03Cooooo1ol0000@ooooo`;o000000?oooooo`000?l00000moooool001kooooo00?o0000oooooooo
ool01Oooool2o`0002oooooo1Ol0000@ooooo`;o00008_ooool2o`000=Kooooo000Nooooo`03o`00
0?oooooooooo00Gooooo0_l0000_ooooo`?o00001Oooool2o`0000[ooooo0_l0000Sooooo`;o0000
;Oooool2o`0002?ooooo0_l00022ooooo`007_ooool00ol0003oooooooooo`0gooooo`Co00000ooo
ool2o`0000[ooooo0_l0001Booooo`;o00008oooool2o`0008;ooooo000Nooooo`03o`000?oooooo
oooo02kooooo0_l00009ooooo`;o000000?oooooo`000?l00000A?ooool2o`000<?ooooo000Noooo
o`03o`000?oooooooooo01kooooo0_l0000>ooooo`;o00003?ooool2o`0000Cooooo0_l0000noooo
o`;o0000`oooool001kooooo00?o0000ooooooooool07_ooool2o`0000[ooooo0_l00005ooooo`;o
00003oooool2o`0007gooooo0_l0000Xooooo`;o0000F_ooool001kooooo00?o0000ooooooooool0
:_ooool2o`0000Gooooo0_l00003ooooo`;o00001oooool2o`000003ooooool0003o000007gooooo
0_l0000Xooooo`;o0000F_ooool001kooooo00?o0000ooooooooool03Oooool2o`0002Oooooo0_l0
0003ooooo`;o00000_ooool2o`000?oooooo1oooool001kooooo00?o0000ooooooooool03Oooool2
o`0002Oooooo0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o0000097ooooo0_l0001`
ooooo`007_ooool00ol0003oooooooooo`0gooooo`;o00000oooool2o`000004ooooool0003o0000
ooooo`;o00000oooool2o`0004;ooooo0_l00003ooooo`;o00005?ooool2o`0000Kooooo0_l0000U
ooooo`;o0000L?ooool001kooooo00Co0000oooooooooooooooo0_l0000Jooooo`;o00006?ooool2
o`0000?ooooo1Ol00003ooooo`;o000000?oooooo`000?l000009oooool2o`0001Wooooo0_l00003
ooooo`;o00005?ooool2o`0000Kooooo0_l0002Gooooo`007_ooool01?l0003oooooooooooooool2
o`0001[ooooo0_l0000Nooooo`Co00000oooool2o`000003ooooool0003o000002Oooooo0_l0000N
ooooo`;o0000]Oooool001kooooo00?o0000ooooooooool0Aoooool2o`0001Kooooo0_l0000@oooo
o`?o00007?ooool2o`0001Oooooo0_l0002Looooo`007_ooool2o`00043ooooo0_l0000?ooooo`;o
00001oooool2o`0000Cooooo0_l0000?ooooo`Co0000=Oooool2o`0007;ooooo0_l0000Xooooo`00
7_ooool00ol0003oooooooooo`0?ooooo`;o0000:?ooool2o`0000Cooooo0_l00004ooooo`;o0000
2Oooool2o`0000Oooooo0_l0000Eooooo`;o00002_ooool2o`0009oooooo0_l0000Xooooo`007_oo
ool00ol0003oooooooooo`0?ooooo`;o0000:?ooool4o`0000;ooooo0ol00003ooooo`;o00008Ooo
ool2o`0000oooooo0_l000001?oooooo0000o`000?l0000iooooo`;o0000SOooool001kooooo00?o
0000ooooooooool0=?ooool2o`0000Gooooo0_l00002ooooo`?o00002oooool2o`0001Wooooo0_l0
000?ooooo`;o00000_ooool2o`00037ooooo1?l00004ooooo`;o0000SOooool001kooooo00?o0000
ooooooooool03?ooool2o`0002Kooooo0ol0000>ooooo`;o00000_ooool2o`0000;ooooo0_l0001>
ooooo`;o00004Oooool4o`0009?ooooo000Nooooo`03o`000?oooooooooo00cooooo0_l0000Woooo
o`Co000000?oooooo`000?l000002Oooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`00
0?l00000:oooool2o`0001kooooo0_l0002Xooooo`007_ooool00ol0003oooooooooo`0cooooo`;o
000000Goooooo`000?l0003o0000ooooo`02o`0001?ooooo0ol0000[ooooo`;o00004oooool4o`00
0;7ooooo000Nooooo`03o`000?oooooooooo033ooooo0_l000000ooooooo0000o`000003o`0001Oo
oooo0_l00011ooooo`Co0000/Oooool001kooooo00?o0000ooooooooool07?ooool2o`0000oooooo
1_l000001?oooooo0000o`000?l0000<ooooo`?o00001_ooool2o`0003kooooo0_l0002Oooooo`;o
00006?ooool001kooooo00?o0000ooooooooool06Oooool2o`000003ooooool0003o000000oooooo
0ol000000ooooooo0000o`000003ooooo`;o00002oooool3o`0000Kooooo0_l0000Wooooo`;o0000
2Oooool2o`0000Wooooo0ol0002Oooooo`;o00006?ooool001kooooo00?o0000ooooooooool06Ooo
ool2o`0000kooooo0ol00002ooooo`;o000000?oooooo`000?l000001Ol0000Cooooo`;o00003Ooo
ool2o`0001Wooooo0_l00009ooooo`Co00001oooool2o`000;[ooooo000Nooooo`03o`000?oooooo
oooo02Sooooo1ol00002ooooo`Oo00004oooool2o`0000[ooooo0_l000000ooooooo0000o`00000V
ooooo`;o00003?ooool2o`000;Gooooo000Nooooo`03o`000?oooooooooo02Sooooo1ol00002oooo
o`;o00000oooool2o`0001oooooo0_l0000[ooooo`;o00001Oooool2o`0000?ooooo0_l0002eoooo
o`007_ooool00ol0003oooooooooo`0_ooooo`;o000000?oooooo`000?l000001oooool4o`0000go
oooo0_l0000=ooooo`;o00009oooool2o`0000Gooooo0_l0002jooooo`007_ooool00ol0003ooooo
ooooo`0Uooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`000007ooooo`Go0000
1?ooool2o`0000Kooooo0_l00006ooooo`;o00001Oooool2o`0002Oooooo0_l00003ooooo`;o0000
0_ooool2o`000;Sooooo000Nooooo`03o`000?oooooooooo02Gooooo0_l00002ooooo`;o00001?oo
ool2o`0000Kooooo0_l00005ooooo`;o00001?ooool2o`0000kooooo0_l000000ooooooo0000o`00
000<ooooo`?o00000_ooool2o`0001gooooo0_l00002ooooo`;o00009_ooool2o`00093ooooo000N
ooooo`;o0000<?ooool2o`0000Cooooo1?l0000?ooooo`;o00000oooool2o`0000Gooooo0_l00000
0ooooooo0000o`00000<ooooo`?o00000_ooool2o`0001kooooo0_l0000Yooooo`;o0000T?ooool0
01kooooo00?o0000ooooooooool0;_ooool2o`0000Gooooo0_l000000ooooooo0000o`00000>oooo
o`;o00000oooool3o`0000Cooooo0_l00008ooooo`;o0000:_ooool2o`0000?ooooo0_l0002foooo
o`007_ooool00ol0003oooooooooo`0^ooooo`;o00002?ooool2o`0001Cooooo0_l0000>ooooo`;o
0000;oooool2o`0000;ooooo0_l0000kooooo`;o0000G?ooool2o`0001Oooooo000Nooooo`03o`00
0?oooooooooo033ooooo1?l0001<ooooo`;o00000oooool2o`0000;ooooo0_l00005ooooo`Go0000
>oooool2o`0005cooooo0_l0000Gooooo`007_ooool00ol0003oooooooooo`0`ooooo`Co00002?oo
ool4o`0001;ooooo1?l0000Zooooo`;o00000oooool2o`0000;ooooo0_l00005ooooo`Co0000Aooo
ool2o`0006[ooooo000Nooooo`03o`000?oooooooooo03;ooooo0ol00007ooooo`Co00004_ooool4
o`0002Sooooo0_l0000Aooooo`;o0000B?ooool2o`0006[ooooo000Nooooo`03o`000?oooooooooo
01Kooooo0_l0000Booooo`;o00001oooool4o`0000Oooooo0_l00002ooooo`?o0000>Oooool2o`00
0<Oooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l0000Booooo`;o00002Oooool2o`0000Oo
oooo0_l00002ooooo`?o00001oooool2o`000?Wooooo000Nooooo`03o`000?oooooooooo02kooooo
0ol0000Kooooo`Co00002Oooool2o`00013ooooo0_l00008ooooo`;o0000`Oooool2o`0000gooooo
000Nooooo`03o`000?oooooooooo01cooooo0_l0000@ooooo`?o00007Oooool2o`0000Wooooo1?l0
000>ooooo`;o00002?ooool2o`0004gooooo0_l0001booooo`;o00003Oooool001kooooo00?o0000
ooooooooool07?ooool2o`00017ooooo0_l0000?ooooo`;o000000?oooooo`000?l000001?ooool2
o`00013ooooo0_l0000mooooo`;o0000:?ooool2o`00087ooooo000Nooooo`04o`000?oooooo0000
o`0001;ooooo0_l0000Jooooo`;o00003oooool5o`0000Cooooo0_l00003ooooo`;o0000>_ooool2
o`0000kooooo0_l00004ooooo`;o0000YOooool001kooooo00Co0000ooooool0003o00004_ooool2
o`0000cooooo0_l0000<ooooo`;o00000_ooool3o`0000cooooo0_l0000:ooooo`;o00001_ooool2
o`0003;ooooo0_l0000Dooooo`;o0000YOooool001kooooo00?o0000ooooooooool06Oooool2o`00
00Kooooo0_l0000=ooooo`Ko00001_ooool2o`00013ooooo0_l00004ooooo`Co0000koooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool06Oooool2o`0001Gooooo1?l00005ooooo`;o000000?ooooo
o`000?l000003_ooool2o`0000Kooooo1?l0000Xooooo`;o00007_ooool2o`0008cooooo0_l0000G
ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9So
oooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0Pooooo`;o00005oooool2o`0000?ooooo0_l0
000;ooooo`?o00001oooool2o`0000gooooo0_l0000Jooooo`;o00007_ooool2o`0008cooooo0_l0
000Gooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooooooooooo
o`000006ooooo`?o00008?ooool2o`0001Kooooo0ol00003ooooo`;o00002oooool2o`0000?ooooo
0_l00003ooooo`;o00001?ooool2o`0000Oooooo0_l0000^ooooo`;o00004?ooool2o`0009oooooo
0003ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Ko
oooo00?o0000ooooooooool0<Oooool3o`0000Cooooo0ol0000@ooooo`;o00000oooool2o`0000Wo
oooo0_l0000gooooo`;o00004?ooool2o`0001oooooo0_l0001nooooo`000oooool01Ol0003ooooo
oooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo
037ooooo0ol0000Gooooo`;o00002_ooool2o`0006kooooo0_l0001nooooo`000oooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooo
oooo04Gooooo0_l0000>ooooo`Co0000??ooool2o`000;3ooooo0003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool06Ooo
ool2o`0002Gooooo0_l00003ooooo`Go00002oooool2o`0000?ooooo0_l000000ooooooo0000o`00
000fooooo`;o0000/?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@
413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`0Iooooo`;o00007_ooool2o`0000Gooooo
0_l00005ooooo`Co00000oooool5o`000004ooooool0003o0000o`0000?ooooo2?l0003Uooooo`00
7_ooool00ol0003oooooooooo`0Wooooo`;o00001_ooool2o`000003ooooool0003o000000Gooooo
0_l0000>ooooo`;o00000oooool5o`000004ooooool0003o0000o`0000Gooooo0_l000001?oooooo
0000o`000?l0001Zooooo`;o0000NOooool001kooooo00?o0000ooooooooool00_l0000Uooooo`;o
00001_ooool2o`000003ooooool0003o000001Gooooo1?l00004ooooo`;o000000?oooooo`000?l0
00001oooool5o`0001Wooooo0_l00006ooooo`;o00003Oooool2o`0003Sooooo0_l0001iooooo`00
7_ooool00ol0003oooooooooo`02o`0004?ooooo2?l00009ooooo`;o00001?ooool5o`0000;ooooo
0_l0000Fooooo`;o00001_ooool2o`0000gooooo0_l0002cooooo`007_ooool00ol0003ooooooooo
o`0fooooo`;o00000_ooool2o`0000Wooooo1_l00002ooooo`;o00001Oooool5o`0000;ooooo0ol0
0005ooooo`Co0000h?ooool001kooooo00?o0000ooooooooool07?ooool2o`0000[ooooo0_l0000<
ooooo`;o00000_ooool2o`0000Oooooo0_l00004ooooo`;o00000_ooool2o`0000Gooooo0_l00000
0ooooooo0000o`000004o`0000;ooooo1?l00002ooooo`;o0000h?ooool001kooooo00?o0000oooo
ooooool03_ooool2o`0000cooooo0_l0000:ooooo`;o00005_ooool2o`000003ooooool0003o0000
00?ooooo0ol00006ooooo`;o000000Goooooo`000?l0003o0000ooooo`03o`0000Cooooo1?l00002
ooooo`Co00008?ooool2o`0000gooooo0_l0002]ooooo`007_ooool00ol0003oooooooooo`0>oooo
o`;o00003Oooool2o`0001Wooooo0_l00006ooooo`Co00001?ooool2o`0000;ooooo0_l00003oooo
o`Ko000000?oooooo`000?l000002oooool4o`00023ooooo0_l0000=ooooo`;o00003oooool2o`00
09cooooo000Nooooo`03o`000?oooooooooo01gooooo0_l0000Iooooo`;o00001_ooool4o`0000Co
oooo0_l00002ooooo`?o00000_ooool3o`0000Cooooo0_l0000;ooooo`Go00003Oooool2o`0000Go
oooo0_l0000Yooooo`;o00002Oooool2o`00097ooooo000Nooooo`03o`000?oooooooooo043ooooo
0_l00002ooooo`;o00001oooool6o`0000cooooo0ol00003ooooo`Oo00002oooool2o`0000Gooooo
0_l0000dooooo`;o0000TOooool001kooooo00?o0000ooooooooool04oooool2o`0000oooooo0_l0
000<ooooo`;o00004?ooool2o`0000;ooooo0_l00005ooooo`;o00002Oooool2o`0000?ooooo0ol0
0003ooooo`Co000000?oooooo`000?l00000foooool001kooooo00?o0000ooooooooool03_ooool2
o`0000?ooooo0_l0000?ooooo`;o00003?ooool2o`0000?ooooo0_l0000?ooooo`Co000000?ooooo
o`000?l000000_ooool3o`0000;ooooo0_l00002ooooo`;o00001Oooool2o`0000Cooooo0_l00004
ooooo`;o0000f?ooool001kooooo0_l0000?ooooo`;o00009oooool2o`00017ooooo0_l000000ooo
oooo0000o`000002ooooo`?o00000_ooool2o`0000Cooooo0_l00003ooooo`;o00002_ooool2o`00
00Gooooo0_l0000:ooooo`;o0000aOooool001kooooo00?o0000ooooooooool0A_ooool2o`0000Co
oooo0_l00006ooooo`;o00001Oooool3o`0000?ooooo0ol00005ooooo`;o00000_ooool2o`0000Go
oooo0_l00007ooooo`;o000000?oooooo`000?l00000aOooool001kooooo00?o0000ooooooooool0
5?ooool2o`00033ooooo0_l00003ooooo`?o00001_ooool2o`000003ooooool0003o000000Co0000
1?ooool4o`0000;ooooo1?l00002ooooo`;o00003_ooool2o`000003ooooool0003o00000<Gooooo
000Nooooo`03o`000?oooooooooo01Cooooo0_l0000/ooooo`;o00001?ooool2o`000003ooooool0
003o000000Oooooo0_l000000ooooooo0000o`000002o`0000Kooooo1?l00002ooooo`Go0000fooo
ool001kooooo00?o0000ooooooooool0@_ooool2o`0000Cooooo0_l00007ooooo`Go00000oooool2
o`000003ooooool0003o000000[ooooo1?l0000=ooooo`;o00003Oooool2o`0001oooooo0_l0002L
ooooo`007_ooool00ol0003oooooooooo`11ooooo`;o00001Oooool3o`000005ooooool0003o0000
o`000?ooool01Ol00003ooooo`;o00000_ooool4o`0000[ooooo0_l0000=ooooo`;o00003Oooool2
o`0001oooooo0_l0002Looooo`007_ooool00ol0003oooooooooo`0hooooo`;o00001oooool2o`00
00Kooooo0_l000000ooooooo0000o`000006o`0000Cooooo0_l00004ooooo`;o00002_ooool2o`00
04Cooooo0_l0002Eooooo`007_ooool00ol0003oooooooooo`0hooooo`;o00004_ooool8o`0000Ko
oooo1_l00004ooooo`;o00001?ooool2o`0002_ooooo0_l00003ooooo`;o00004_ooool2o`0009Go
oooo000Nooooo`03o`000?oooooooooo00;ooooo0_l00012ooooo`;o00001?ooool2o`000003oooo
ool0003o000000?o00001_ooool6o`0000Cooooo0_l0000aooooo`;o000000?oooooo`000?l00000
0ol0002Xooooo`007_ooool00ol0003oooooooooo`02ooooo`;o0000=_ooool2o`0000Sooooo1_l0
0002ooooo`;o000000?oooooo`000?l000003Oooool3o`0000Sooooo0ol0000Iooooo`;o00004ooo
ool2o`000003ooooool0003o000000Sooooo0_l0002Nooooo`007_ooool00ol0003oooooooooo`0j
ooooo`;o00002?ooool2o`0000;ooooo0_l00004ooooo`;o00003oooool4o`0000Kooooo1?l0000?
ooooo`;o00001oooool2o`00023ooooo0_l0001Zooooo`;o0000<_ooool001kooooo00?o0000oooo
ooooool0C_ooool4o`0000Kooooo0_l00007ooooo`;o00000oooool2o`000003ooooool0003o0000
00;o00002_ooool2o`0000?ooooo0_l0000Jooooo`;o0000B?ooool2o`0002oooooo0_l0000boooo
o`007_ooool00ol0003oooooooooo`12ooooo`;o00002Oooool5o`000003ooooool0003o000000?o
oooo1?l00002ooooo`;o00001_ooool2o`000004ooooool0003o0000ooooo`;o00002Oooool2o`00
00;ooooo0_l00007ooooo`;o00004_ooool2o`0004Sooooo0_l0001Sooooo`007_ooool00ol0003o
ooooooooo`0iooooo`?o00001_ooool2o`0000Cooooo0_l00002ooooo`Ko000000?oooooo`000?l0
00001Oooool2o`0000;ooooo1?l0000:ooooo`?o00003?ooool3o`0000Kooooo0_l0000Eooooo`;o
0000Z_ooool001kooooo00?o0000ooooooooool0>Oooool4o`0000_ooooo0_l00002ooooo`So0000
0oooool2o`0000;ooooo0_l00003ooooo`?o00000oooool2o`0000Gooooo0_l0000=ooooo`;o0000
7Oooool2o`000:[ooooo000Nooooo`03o`000?oooooooooo027ooooo0_l00004ooooo`;o00004_oo
ool2o`0000cooooo0_l00004ooooo`Oo000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l0
0003ooooo`;o00003oooool2o`0000;ooooo0_l0003:ooooo`007_ooool2o`0002;ooooo0_l00004
ooooo`;o00008?ooool2o`0000Cooooo2?l00004ooooo`;o00002?ooool2o`0000;ooooo0_l0000<
ooooo`;o00000_ooool2o`0001Wooooo0_l0002Pooooo`;o00003Oooool001kooooo00?o0000oooo
ooooool0?_ooool2o`0000oooooo0_l000000ooooooo0000o`000003o`0000Cooooo0_l00006oooo
o`So000000?oooooo`000?l00000:?ooool3o`0009oooooo0_l0000=ooooo`007_ooool00ol0003o
ooooooooo`0nooooo`;o00003?ooool:o`0000gooooo0_l00002ooooo`;o00000oooool2o`0001oo
oooo0_l00008ooooo`;o0000[_ooool001kooooo00?o0000ooooooooool0;oooool2o`0001_ooooo
0ol000000ooooooo0000o`000008o`0000?ooooo1?l00002ooooo`;o0000:?ooool2o`000;Sooooo
000Nooooo`03o`000?oooooooooo02oooooo0_l0000?ooooo`;o00003oooool9o`0000?ooooo1?l0
0002ooooo`;o00002oooool2o`0000oooooo0_l0000dooooo`;o0000S_ooool001kooooo00?o0000
ooooooooool0:_ooool2o`0001Cooooo0_l000000ooooooo0000o`00000<ooooo`So000000?ooooo
o`000?l000001oooool3o`0000;ooooo1Ol00002ooooo`?o00003oooool2o`0002Sooooo0_l0000:
ooooo`;o0000S_ooool001kooooo00?o0000ooooooooool0:_ooool2o`0000_ooooo0_l0000:oooo
o`;o00003_ooool6o`000004ooooool0003o0000o`0000Oooooo0_l000000ooooooo0000o`000004
o`000004ooooool0003o0000o`0002Oooooo0_l0000Aooooo`;o0000V_ooool001kooooo00?o0000
ooooooooool05oooool2o`0001Cooooo0_l00005ooooo`;o000000?oooooo`000?l000005?ooool2
o`0000Kooooo2?l0000:ooooo`Co00000oooool2o`0001Wooooo0_l00007ooooo`;o00001?ooool2
o`000:Kooooo0_l00005ooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o00001_ooool2o`00
01Cooooo0_l00004ooooo`?o00003?ooool2o`000003ooooool0003o000000Kooooo0_l00006oooo
o`;o000000?oooooo`000?l000000_l00008ooooo`;o00002?ooool2o`0000;ooooo0_l00007oooo
o`;o00003?ooool2o`0000?ooooo0_l00002ooooo`;o0000[?ooool2o`0000Gooooo000Nooooo`03
o`000?oooooooooo00oooooo0_l0000Rooooo`;o00003Oooool2o`000003ooooool0003o000000So
oooo0_l00003ooooo`?o00000oooool2o`0000Cooooo2?l0000:ooooo`;o00001oooool2o`00017o
oooo0_l0002gooooo`007_ooool00ol0003oooooooooo`1?ooooo`;o00000oooool2o`0000Gooooo
3Ol00006ooooo`?o000000?oooooo`000?l00000:Oooool3o`000:Oooooo000Nooooo`03o`000?oo
oooooooo04oooooo0_l00003ooooo`Co00000_ooool6o`0000Kooooo0_l00002ooooo`;o00000_oo
ool3o`0000?ooooo0_l0000Wooooo`?o0000Yoooool001kooooo00?o0000ooooooooool06oooool2
o`0003;ooooo0_l00003ooooo`Co00000_ooool2o`000003ooooool0003o000000;o00001Oooool2
o`0000;ooooo0_l00002ooooo`;o00001?ooool3o`0000Kooooo0_l0000Cooooo`;o0000/oooool0
01kooooo00?o0000ooooooooool06oooool2o`0002[ooooo0_l00009ooooo`;o000000Coooooo`00
0?l0003ooooo1?l000000ooooooo0000o`000002o`0000Gooooo0_l0000=ooooo`;o00001_ooool2
o`0001?ooooo0_l0002cooooo`007_ooool00ol0003oooooooooo`0Qooooo`;o00005oooool2o`00
00Sooooo0_l000000ooooooo0000o`000009ooooo`;o000000?oooooo`000?l000001_l00002oooo
o`;o00001Oooool2o`0000oooooo0_l0000Booooo`;o0000^_ooool001kooooo00?o0000oooooooo
ool08Oooool2o`0001Oooooo0_l00008ooooo`;o00001?ooool2o`0000[ooooo0_l00003ooooo`;o
00001_ooool2o`00017ooooo0ol00002ooooo`;o00003_ooool2o`0000[ooooo0_l0002^ooooo`00
7_ooool2o`0003_ooooo0_l0000>ooooo`Co00003oooool2o`0000Cooooo0_l0000Aooooo`;o0000
0_ooool3o`0001;ooooo0_l00006ooooo`;o0000[_ooool001kooooo00?o0000ooooooooool0>_oo
ool2o`00013ooooo1?l00005ooooo`;o00000_ooool2o`0000;ooooo1Ol00002ooooo`;o00002Ooo
ool2o`0000Kooooo1Ol0000Cooooo`;o0000]_ooool001kooooo00?o0000ooooooooool0C_ooool2
o`0000?ooooo2?l00004ooooo`?o00000_ooool2o`0000Wooooo0_l00006ooooo`Ko00002oooool2
o`0000;ooooo0_l0002iooooo`007_ooool00ol0003oooooooooo`13ooooo`;o00002oooool2o`00
0003ooooool0003o000000;ooooo1?l00003ooooo`;o00006?ooool5o`0000?ooooo0_l00006oooo
o`;o00000_ooool2o`000;Wooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l00005ooooo`;o
00009_ooool2o`0000Oooooo0_l00002ooooo`;o00001oooool2o`0000?ooooo0ol0000Jooooo`;o
00000_ooool3o`0001Gooooo0_l0002^ooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o0000
1Oooool2o`0002oooooo0_l00003ooooo`;o00002oooool3o`0000Oooooo0_l0000Eooooo`;o0000
5_ooool2o`0009?ooooo0_l0000Iooooo`007_ooool00ol0003oooooooooo`02ooooo`;o0000;?oo
ool2o`0001oooooo0_l0000Booooo`;o000000?oooooo`000?l000005?ooool3o`0000;ooooo0_l0
002Wooooo`Co00005oooool001kooooo00?o0000ooooooooool00_ooool2o`0002cooooo0_l0000c
ooooo`;o00005oooool3o`0000;ooooo0_l0000Qooooo`;o00002oooool2o`0007Wooooo0_l0000G
ooooo`007_ooool00ol0003oooooooooo`0]ooooo`;o00000_ooool2o`00023ooooo0_l0001Aoooo
o`;o00002oooool2o`0007?ooooo0_l0000Mooooo`007_ooool00ol0003oooooooooo`0Uooooo`;o
00001_ooool2o`0000;ooooo0_l0000:ooooo`;o00001oooool2o`0000_ooooo0_l0000Eooooo`;o
00003oooool2o`000:_ooooo0_l00002ooooo`;o00006Oooool001kooooo00?o0000ooooooooool0
9Oooool2o`0000Wooooo0_l0000;ooooo`;o00000oooool2o`0000;ooooo1?l0000Aooooo`;o0000
3Oooool2o`0000oooooo0_l0002_ooooo`;o000000?oooooo`000?l000002oooool2o`0000Wooooo
000Nooooo`03o`000?oooooooooo02?ooooo0_l0000;ooooo`;o00004?ooool2o`0000Cooooo0_l0
0009ooooo`;o00001_ooool4o`0001cooooo0_l0002booooo`;o00002oooool2o`0000Wooooo000N
ooooo`03o`000?oooooooooo02?ooooo0_l00005ooooo`;o00006Oooool2o`0000cooooo0_l00008
ooooo`;o00003_ooool2o`0001?ooooo0_l0000Cooooo`?o0000[Oooool001kooooo00?o0000oooo
ooooool0:_ooool2o`0001Wooooo0_l0000Fooooo`;o00002Oooool2o`0000?ooooo0_l00006oooo
o`;o00001Oooool2o`0000Cooooo0_l0000<ooooo`;o00001Oooool3o`000:gooooo000Dooooo`Co
000000?o410@ooooooooool00oooool00ol0003oooooooooo`0Pooooo`;o00004Oooool2o`00017o
oooo0_l0000Nooooo`Go00000oooool2o`0000Gooooo0_l00005ooooo`;o00002oooool2o`0000Go
oooo0_l0002eooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo023ooooo
0_l0000Aooooo`;o00004Oooool2o`0001Sooooo0_l00004ooooo`Go00000oooool2o`0001Wooooo
0_l0000Iooooo`;o0000XOooool001Kooooo00?o0000ooooooooool01Oooool3o`0001Gooooo0_l0
000Kooooo`;o00006_ooool2o`00013ooooo0_l00005ooooo`;o00006?ooool2o`0001gooooo0_l0
0002ooooo`;o0000XOooool001Kooooo00?o0000ooooooooool07Oooool2o`0001_ooooo0_l0000J
ooooo`;o0000<Oooool2o`0001gooooo0_l0002Uooooo`005_ooool00ol0003oooooooooo`3ooooo
oe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0
oooooom@ooooo`005?ooool00omEEEGoIVIVo`00003ooooooe;ooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.12512 .77228 Mdot
.0716 .08454 Mdot
.19155 .88784 Mdot
.21231 .86808 Mdot
.32625 .95716 Mdot
.27757 .82808 Mdot
.67658 .58612 Mdot
.28913 .94743 Mdot
.31407 .84606 Mdot
.19443 .4009 Mdot
.26048 .94317 Mdot
.22087 .96269 Mdot
.25185 .89645 Mdot
.40303 .86346 Mdot
.2248 .83466 Mdot
.23314 .95736 Mdot
.16668 .5794 Mdot
.24676 .86032 Mdot
.12085 .76664 Mdot
.23132 .83298 Mdot
.95535 .21525 Mdot
.321 .79064 Mdot
.31407 .85081 Mdot
.01075 .70644 Mdot
.30239 .88646 Mdot
.30904 .96614 Mdot
.25409 .87597 Mdot
.22572 .92945 Mdot
.25229 .95996 Mdot
.267 .76544 Mdot
.17915 .82596 Mdot
.24029 .83507 Mdot
.34729 .85798 Mdot
.95607 .03439 Mdot
.39557 .69637 Mdot
.26478 .94485 Mdot
.45921 .85685 Mdot
.00911 .63714 Mdot
.16988 .9904 Mdot
.26854 .91058 Mdot
.15771 .80796 Mdot
.48358 .74498 Mdot
.45606 .92352 Mdot
.04418 .61042 Mdot
.36755 .90238 Mdot
.49295 .76657 Mdot
.03905 .85707 Mdot
.44549 .01858 Mdot
.26363 .94681 Mdot
.37104 .60487 Mdot
.24332 .09761 Mdot
.44931 .75526 Mdot
.32301 .99073 Mdot
.2954 .98908 Mdot
.33528 .9841 Mdot
.18019 .11386 Mdot
.06831 .73952 Mdot
.26703 .92834 Mdot
.25081 .87227 Mdot
.21431 .65731 Mdot
.19873 .85273 Mdot
.30673 .94382 Mdot
.58537 .65358 Mdot
.32023 .88462 Mdot
.25674 .90273 Mdot
.32438 .80903 Mdot
.48387 .75844 Mdot
.25269 .8764 Mdot
.26206 .8155 Mdot
.51277 .69903 Mdot
.03577 .36958 Mdot
.16708 .62414 Mdot
.46947 .02426 Mdot
.28534 .59564 Mdot
.3411 .8645 Mdot
.03745 .66133 Mdot
.24234 .88534 Mdot
.36788 .96432 Mdot
.25094 .85109 Mdot
.01826 .77718 Mdot
.45776 .95807 Mdot
.41872 .39874 Mdot
.02271 .57955 Mdot
.29698 .93976 Mdot
.68725 .40163 Mdot
.86615 .37885 Mdot
.31263 .97702 Mdot
.23034 .89037 Mdot
.24336 .82514 Mdot
.17142 .62326 Mdot
.32325 .86326 Mdot
.54075 .59965 Mdot
.33947 .63858 Mdot
.11854 .33365 Mdot
.18275 .69403 Mdot
.4648 .92129 Mdot
.53642 .50542 Mdot
.43234 .71935 Mdot
.3655 .94278 Mdot
.2094 .72453 Mdot
.23757 .90472 Mdot
.25464 .10529 Mdot
.12551 .7698 Mdot
.33754 .92333 Mdot
.05202 .10952 Mdot
.32579 .85131 Mdot
.23585 .98697 Mdot
.24507 .97467 Mdot
.46691 .79526 Mdot
.5376 .17972 Mdot
.38127 .87438 Mdot
.99956 .54125 Mdot
.12261 .04354 Mdot
.22276 .85974 Mdot
.73616 .13074 Mdot
.53747 .62358 Mdot
.30592 .90615 Mdot
.25065 .88073 Mdot
.05414 .17888 Mdot
.13922 .96016 Mdot
.24866 .89146 Mdot
.5053 .92272 Mdot
.35019 .80823 Mdot
.12256 .34398 Mdot
.43606 .70378 Mdot
.00055 .9516 Mdot
.40003 .0112 Mdot
.13495 .75494 Mdot
.93889 .03616 Mdot
.44401 .02019 Mdot
.03473 .03027 Mdot
.33412 .04176 Mdot
.79624 .23971 Mdot
.27028 .7816 Mdot
.20599 .76545 Mdot
.29039 .95025 Mdot
.34354 .86788 Mdot
.20315 .74384 Mdot
.13847 .83839 Mdot
.31196 .81993 Mdot
.14776 .7559 Mdot
.33098 .89489 Mdot
.34596 .80624 Mdot
.33751 .73633 Mdot
.5092 .05985 Mdot
.26589 .92896 Mdot
.19003 .72384 Mdot
.2448 .90338 Mdot
.00662 .72574 Mdot
.53237 .35868 Mdot
.23365 .89473 Mdot
.35036 .82997 Mdot
.1736 .98536 Mdot
.23672 .83036 Mdot
.22589 .84538 Mdot
.27739 .90057 Mdot
.20514 .81611 Mdot
.30803 .66429 Mdot
.29557 .85467 Mdot
.21219 .96151 Mdot
.1715 .67217 Mdot
.31725 .68024 Mdot
.06004 .31131 Mdot
.2807 .75836 Mdot
.3539 .94316 Mdot
.35011 .96221 Mdot
.24274 .91132 Mdot
.27347 .86423 Mdot
.5802 .25604 Mdot
.31784 .83626 Mdot
.33287 .79066 Mdot
.42773 .91189 Mdot
.34694 .67115 Mdot
.06483 .61241 Mdot
.12019 .75977 Mdot
.20689 .78776 Mdot
.01331 .87665 Mdot
.27308 .97671 Mdot
.63769 .48645 Mdot
.44048 .74334 Mdot
.42298 .94381 Mdot
.30877 .95065 Mdot
.07086 .83842 Mdot
.29572 .94379 Mdot
.02436 .49285 Mdot
.18255 .05914 Mdot
.20504 .94557 Mdot
.35408 .86939 Mdot
.6936 .1021 Mdot
.33689 .7874 Mdot
.1259 .75563 Mdot
.90831 .29079 Mdot
.13585 .75837 Mdot
.14245 .04137 Mdot
.12455 .97941 Mdot
.43902 .89702 Mdot
.32573 .69126 Mdot
.31482 .84353 Mdot
.31766 .84825 Mdot
.35175 .84605 Mdot
.45744 .66784 Mdot
.84378 .17285 Mdot
.24648 .76654 Mdot
.33824 .92882 Mdot
.30503 .88616 Mdot
.2284 .88907 Mdot
.53283 .49665 Mdot
.23018 .8745 Mdot
.56909 .35605 Mdot
.16631 .85257 Mdot
.34108 .88077 Mdot
.14827 .75723 Mdot
.3056 .44537 Mdot
.9469 .34147 Mdot
.18619 .7218 Mdot
.05783 .44368 Mdot
.25461 .91413 Mdot
.11562 .1539 Mdot
.1972 .8801 Mdot
.47891 .70867 Mdot
.34826 .69691 Mdot
.18016 .67661 Mdot
.34319 .90747 Mdot
.27498 .85027 Mdot
.16638 .64114 Mdot
.16766 .64001 Mdot
.38209 .95411 Mdot
.32223 .90311 Mdot
.19102 .36659 Mdot
.341 .80575 Mdot
.2988 .92533 Mdot
.22832 .64814 Mdot
.35276 .80883 Mdot
.15016 .00245 Mdot
.06537 .46986 Mdot
.21849 .47459 Mdot
.1713 .20711 Mdot
.20306 .85594 Mdot
.98303 .49936 Mdot
.03407 .61735 Mdot
.22048 .99908 Mdot
.34676 .79963 Mdot
.48598 .99266 Mdot
.20586 .95181 Mdot
.13574 .94484 Mdot
.31547 .77442 Mdot
.18374 .6549 Mdot
.31955 .78474 Mdot
.99241 .65492 Mdot
.16119 .8208 Mdot
.44352 .75114 Mdot
.3624 .95754 Mdot
.8757 .4614 Mdot
.85518 .42676 Mdot
.48391 .82388 Mdot
.42501 .04148 Mdot
.33948 .98373 Mdot
.03131 .42706 Mdot
.46667 .84931 Mdot
.75636 .18637 Mdot
.14319 .76164 Mdot
.24663 .80926 Mdot
.26636 .91732 Mdot
.13957 .7261 Mdot
.35093 .80566 Mdot
.89854 .33486 Mdot
.16176 .07702 Mdot
.25338 .38153 Mdot
.21828 .86385 Mdot
.2648 .89352 Mdot
.36142 .94198 Mdot
.35019 .53935 Mdot
.2003 .81865 Mdot
.2693 .79349 Mdot
.4599 .94844 Mdot
.35832 .91887 Mdot
.21024 .86277 Mdot
.46509 .34493 Mdot
.28318 .97 Mdot
.20676 .08565 Mdot
.17441 .72619 Mdot
.32145 .78819 Mdot
.28987 .76884 Mdot
.4553 .79112 Mdot
.34249 .97056 Mdot
.3402 .90568 Mdot
.29518 .82745 Mdot
.18001 .79652 Mdot
.43237 .00411 Mdot
.22146 .10055 Mdot
.44637 .01952 Mdot
.5191 .52064 Mdot
.12531 .76732 Mdot
.09973 .0366 Mdot
.59961 .38955 Mdot
.24754 .7069 Mdot
.23035 .90058 Mdot
.19325 .88952 Mdot
.19163 .73275 Mdot
.42735 .33857 Mdot
.14187 .86697 Mdot
.39579 .93595 Mdot
.36057 .69852 Mdot
.19579 .64298 Mdot
.32338 .34926 Mdot
.45103 .79736 Mdot
.25589 .87243 Mdot
.23399 .85308 Mdot
.41735 .94763 Mdot
.82024 .18285 Mdot
.23974 .88419 Mdot
.1681 .74593 Mdot
.30959 .96019 Mdot
.08433 .74936 Mdot
.31051 .93125 Mdot
.32013 .02983 Mdot
.19298 .69995 Mdot
.99918 .60641 Mdot
.36227 .89307 Mdot
.09322 .60866 Mdot
.15489 .00473 Mdot
.34808 .8452 Mdot
.2188 .1072 Mdot
.08861 .78897 Mdot
.20421 .83195 Mdot
.29198 .9191 Mdot
.28024 .96625 Mdot
.15305 .75575 Mdot
.24485 .99596 Mdot
.30857 .93011 Mdot
.26966 .83881 Mdot
.28566 .8144 Mdot
.51996 .38607 Mdot
.49157 .93857 Mdot
.04892 .36542 Mdot
.33511 .44203 Mdot
.92653 .02659 Mdot
.25665 .88799 Mdot
.03392 .63272 Mdot
.88217 .37009 Mdot
.35004 .93635 Mdot
.90445 .08985 Mdot
.16087 .75102 Mdot
.1842 .62725 Mdot
.04595 .76667 Mdot
.68606 .72232 Mdot
.60078 .31182 Mdot
.37346 .18507 Mdot
.11279 .37821 Mdot
.28519 .9533 Mdot
.22767 .86964 Mdot
.35197 .97696 Mdot
.2494 .78887 Mdot
.27973 .94764 Mdot
.67129 .48772 Mdot
.19728 .83376 Mdot
.4813 .74601 Mdot
.25739 .72859 Mdot
.25513 .91004 Mdot
.15834 .26778 Mdot
.32546 .78846 Mdot
.25532 .91576 Mdot
.16371 .81227 Mdot
.34385 .87805 Mdot
.36693 .91527 Mdot
.3824 .79347 Mdot
.47374 .03808 Mdot
.74353 .15684 Mdot
.04217 .54496 Mdot
.27342 .77744 Mdot
.18339 .68719 Mdot
.25899 .86969 Mdot
.17563 .85529 Mdot
.33073 .81393 Mdot
.37777 .91435 Mdot
.14887 .76522 Mdot
.42996 .87201 Mdot
.25621 .92833 Mdot
.14089 .50477 Mdot
.28153 .76986 Mdot
.25493 .84763 Mdot
.25121 .86399 Mdot
.97825 .52122 Mdot
.50678 .89714 Mdot
.20158 .93209 Mdot
.18339 .00616 Mdot
.38588 .0783 Mdot
.53022 .63084 Mdot
.25716 .88496 Mdot
.31396 .85592 Mdot
.14795 .75464 Mdot
.28046 .92209 Mdot
.21562 .90566 Mdot
.28354 .96151 Mdot
.30696 .96001 Mdot
.53949 .40316 Mdot
.24549 .55092 Mdot
.92349 .34847 Mdot
.24773 .87236 Mdot
.18224 .81445 Mdot
.46093 .89604 Mdot
.4631 .90081 Mdot
.35459 .68576 Mdot
.30495 .94105 Mdot
.4333 .69617 Mdot
.09202 .01406 Mdot
.25535 .10269 Mdot
.16133 .62669 Mdot
.18255 .64354 Mdot
.28685 .76649 Mdot
.18422 .67826 Mdot
.28906 .87056 Mdot
.17477 .67687 Mdot
.70705 .6429 Mdot
.9743 .61237 Mdot
.26893 .81355 Mdot
.14606 .75149 Mdot
.16936 .65393 Mdot
.71699 .64267 Mdot
.24609 .85149 Mdot
.26769 .88748 Mdot
.88158 .81154 Mdot
.24903 .48073 Mdot
.28304 .89316 Mdot
.27641 .93158 Mdot
.4609 .00111 Mdot
.41894 .68738 Mdot
.32681 .82573 Mdot
.16811 .6255 Mdot
.54182 .33377 Mdot
.98152 .62474 Mdot
.29338 .04115 Mdot
.38787 .74656 Mdot
.26587 .85179 Mdot
.55677 .73853 Mdot
.64736 .70452 Mdot
.20644 .92404 Mdot
.25566 .00834 Mdot
.23355 .83007 Mdot
.37753 .87805 Mdot
.15055 .04281 Mdot
.02175 .61237 Mdot
.05549 .57701 Mdot
.19673 .84143 Mdot
.25911 .26765 Mdot
.21004 .86214 Mdot
.34728 .86216 Mdot
.32607 .91881 Mdot
.48421 .65655 Mdot
.22448 .7485 Mdot
.00033 .84787 Mdot
.47762 .80737 Mdot
.34334 .92892 Mdot
.26262 .84956 Mdot
.11381 .02919 Mdot
.2413 .87898 Mdot
.30163 .86969 Mdot
.28308 .96812 Mdot
.96494 .03973 Mdot
.70668 .832 Mdot
.20474 .92914 Mdot
.22693 .87927 Mdot
.26265 .84691 Mdot
.24544 .945 Mdot
.04619 .60022 Mdot
.42416 .71041 Mdot
.3462 .85376 Mdot
.96305 .95527 Mdot
.20144 .83364 Mdot
.35788 .85631 Mdot
.27677 .77377 Mdot
.30853 .96981 Mdot
.29522 .94455 Mdot
.29583 .94216 Mdot
.19274 .93236 Mdot
.24571 .84239 Mdot
.24626 .00671 Mdot
.2868 .9303 Mdot
.22946 .71776 Mdot
.42217 .96087 Mdot
.34228 .99432 Mdot
.10898 .00604 Mdot
.33783 .79586 Mdot
.16086 .75062 Mdot
.13047 .76359 Mdot
.90887 .46981 Mdot
.0133 .54944 Mdot
.43032 .75369 Mdot
.39357 .90998 Mdot
.25247 .92665 Mdot
.18269 .84367 Mdot
.2787 .86801 Mdot
.55957 .37494 Mdot
.40659 .03938 Mdot
.28295 .85735 Mdot
.315 .82604 Mdot
.34471 .85677 Mdot
.34599 .87786 Mdot
.97246 .68529 Mdot
.13538 .73788 Mdot
.30814 .85444 Mdot
.42679 .99794 Mdot
.44266 .91554 Mdot
.13777 .46474 Mdot
.26944 .85006 Mdot
.44898 .6425 Mdot
.3086 .96201 Mdot
.58379 .44318 Mdot
.29647 .87251 Mdot
.2386 .76843 Mdot
.18719 .76409 Mdot
.32197 .80406 Mdot
.25215 .99108 Mdot
.98743 .5881 Mdot
.3221 .9698 Mdot
.18224 .9985 Mdot
.33225 .01988 Mdot
.45471 .93044 Mdot
.78594 .53145 Mdot
.18635 .8045 Mdot
.23886 .71792 Mdot
.2102 .93717 Mdot
.25365 .84926 Mdot
.35363 .82995 Mdot
.1425 .7834 Mdot
.93064 .7254 Mdot
.55432 .32605 Mdot
.40013 .39069 Mdot
.05933 .78093 Mdot
.97623 .04199 Mdot
.99029 .2476 Mdot
.46388 .01432 Mdot
.33724 .96832 Mdot
.22737 .04534 Mdot
.2981 .93374 Mdot
.24129 .90113 Mdot
.28091 .90083 Mdot
.34948 .88053 Mdot
.06532 .7089 Mdot
.49154 .25087 Mdot
.31136 .81948 Mdot
.94978 .65454 Mdot
.27756 .92959 Mdot
.23867 .84524 Mdot
.14887 .82714 Mdot
.57996 .54798 Mdot
.46865 .67296 Mdot
.12232 .80255 Mdot
.30476 .79434 Mdot
.29368 .91654 Mdot
.5628 .53923 Mdot
.4514 .72781 Mdot
.34717 .86461 Mdot
.93908 .87747 Mdot
.47216 .99171 Mdot
.53638 .61409 Mdot
.41149 .85786 Mdot
.25633 .89227 Mdot
.26003 .92514 Mdot
.82228 .09581 Mdot
.30961 .80007 Mdot
.36167 .91384 Mdot
.04785 .66747 Mdot
.06269 .76064 Mdot
.28609 .82977 Mdot
.26884 .95838 Mdot
.18334 .72974 Mdot
.34785 .9187 Mdot
.4092 .41881 Mdot
.24929 .82581 Mdot
.5555 .08108 Mdot
.30753 .92702 Mdot
.24985 .84062 Mdot
.16695 .74573 Mdot
.26921 .92151 Mdot
.33655 .82883 Mdot
.25203 .03394 Mdot
.25026 .96716 Mdot
.36325 .95418 Mdot
.36991 .79265 Mdot
.46799 .69073 Mdot
.56325 .62908 Mdot
.19893 .97705 Mdot
.15104 .76144 Mdot
.13281 .77481 Mdot
.23657 .9097 Mdot
.16603 .04501 Mdot
.66197 .73469 Mdot
.33894 .95719 Mdot
.21072 .69186 Mdot
.28195 .92915 Mdot
.29922 .98982 Mdot
.19199 .62868 Mdot
.34861 .86279 Mdot
.25386 .89527 Mdot
.31177 .94981 Mdot
.18826 .87981 Mdot
.30026 .91733 Mdot
.25107 .92779 Mdot
.2419 .68861 Mdot
.34378 .82461 Mdot
.26485 .87354 Mdot
.1941 .857 Mdot
.43035 .71688 Mdot
.59732 .84323 Mdot
.28075 .75235 Mdot
.25513 .90058 Mdot
.30603 .78095 Mdot
.53136 .78132 Mdot
.13417 .7633 Mdot
.48984 .77133 Mdot
.5913 .40899 Mdot
.24263 .78942 Mdot
.49313 .24815 Mdot
.11434 .78143 Mdot
.22637 .98142 Mdot
.16713 .62784 Mdot
.89432 .4745 Mdot
.38643 .94338 Mdot
.33134 .52938 Mdot
.46314 .96168 Mdot
.63634 .99215 Mdot
.13288 .75842 Mdot
.88628 .5103 Mdot
.47967 .75912 Mdot
.13773 .07577 Mdot
.92704 .33955 Mdot
.88031 .37002 Mdot
.3455 .95035 Mdot
.5109 .92063 Mdot
.1647 .8891 Mdot
.27762 .85312 Mdot
.21614 .6803 Mdot
.4752 .84306 Mdot
.25257 .84017 Mdot
.19825 .07191 Mdot
.2945 .93991 Mdot
.3371 .61881 Mdot
.29715 .93899 Mdot
.22555 .82631 Mdot
.47412 .92561 Mdot
.26263 .82816 Mdot
.48345 .7426 Mdot
.51344 .97232 Mdot
.63569 .88444 Mdot
.20195 .71693 Mdot
.35233 .05749 Mdot
.13083 .7425 Mdot
.30507 .92722 Mdot
.5262 .78415 Mdot
.04549 .66148 Mdot
.33449 .91071 Mdot
.10817 .04561 Mdot
.27526 .84713 Mdot
.47336 .66634 Mdot
.27386 .9054 Mdot
.29145 .99912 Mdot
.41978 .80602 Mdot
.59084 .37363 Mdot
.2446 .87509 Mdot
.43092 .86058 Mdot
.32011 .79737 Mdot
.38203 .27897 Mdot
.25119 .90481 Mdot
.90647 .32295 Mdot
.97324 .01177 Mdot
.24015 .8522 Mdot
.66824 .50405 Mdot
.17918 .73928 Mdot
.03878 .04901 Mdot
.30948 .9239 Mdot
.43211 .22502 Mdot
.18114 .02577 Mdot
.27692 .77362 Mdot
.05548 .58238 Mdot
.31122 .95186 Mdot
.36829 .94689 Mdot
.27983 .90847 Mdot
.49572 .33402 Mdot
.62123 .34458 Mdot
.05173 .56625 Mdot
.33342 .74596 Mdot
.988 .58909 Mdot
.13142 .75406 Mdot
.2501 .82724 Mdot
.30453 .65022 Mdot
.36662 .07096 Mdot
.57381 .27854 Mdot
.10723 .95952 Mdot
.23553 .88346 Mdot
.45677 .9915 Mdot
.2726 .9653 Mdot
.28771 .97945 Mdot
.56967 .99616 Mdot
.3466 .83523 Mdot
.31242 .77612 Mdot
.26593 .84763 Mdot
.50016 .0859 Mdot
.136 .75625 Mdot
.13785 .4972 Mdot
.17736 .18925 Mdot
.2852 .94314 Mdot
.27212 .8943 Mdot
.13438 .83038 Mdot
.97481 .48166 Mdot
.35594 .82402 Mdot
.26847 .24364 Mdot
.9998 .64533 Mdot
.39218 .5833 Mdot
.32914 .85117 Mdot
.29954 .51157 Mdot
.21758 .64499 Mdot
.39908 .94703 Mdot
.06068 .47256 Mdot
.34175 .90542 Mdot
.69651 .48858 Mdot
.32711 .78877 Mdot
.28653 .96752 Mdot
.30969 .55924 Mdot
.3369 .7924 Mdot
.15414 .75529 Mdot
.19815 .86726 Mdot
.24323 .72825 Mdot
.67077 .43778 Mdot
.95616 .04484 Mdot
.62609 .68723 Mdot
.28665 .83016 Mdot
.25246 .8971 Mdot
.50548 .00036 Mdot
.13772 .74207 Mdot
.30279 .79238 Mdot
.30841 .7792 Mdot
.26458 .89526 Mdot
.30916 .83388 Mdot
.35554 .58196 Mdot
.60145 .15118 Mdot
.49235 .61013 Mdot
.43446 .73434 Mdot
.29514 .06882 Mdot
.61437 .47126 Mdot
.36864 .85941 Mdot
.22491 .85538 Mdot
.10893 .76438 Mdot
.56292 .53727 Mdot
.22463 .01455 Mdot
.38611 .02578 Mdot
.27483 .76845 Mdot
.09966 .73853 Mdot
.36838 .92448 Mdot
.94993 .51548 Mdot
.50685 .94191 Mdot
.17726 .84234 Mdot
.09979 .05326 Mdot
.13472 .79263 Mdot
.22202 .73114 Mdot
.37734 .93271 Mdot
.31088 .8715 Mdot
.49625 .9646 Mdot
.25786 .00687 Mdot
.1819 .83897 Mdot
.65976 .72559 Mdot
.29047 .95054 Mdot
.42142 .32582 Mdot
.18747 .84684 Mdot
.25628 .12096 Mdot
.20294 .84196 Mdot
.22156 .7297 Mdot
.96088 .68103 Mdot
.31521 .84708 Mdot
.39981 .30713 Mdot
.31296 .90933 Mdot
.10834 .93214 Mdot
.31599 .82175 Mdot
.36246 .9573 Mdot
.52771 .44367 Mdot
.16045 .77292 Mdot
.42082 .94766 Mdot
.1866 .8456 Mdot
.11921 .03686 Mdot
.31181 .36345 Mdot
.21519 .86599 Mdot
.11923 .00129 Mdot
.06104 .69199 Mdot
.2155 .04731 Mdot
.25217 .92136 Mdot
.20571 .84275 Mdot
.26297 .9568 Mdot
.31009 .82213 Mdot
.27825 .86565 Mdot
.2777 .90724 Mdot
.4476 .79201 Mdot
.03814 .54845 Mdot
.49106 .67297 Mdot
.2944 .98109 Mdot
.27785 .66582 Mdot
.2985 .99682 Mdot
.26972 .93063 Mdot
.44531 .89001 Mdot
.24298 .89182 Mdot
.16474 .63876 Mdot
.02064 .12869 Mdot
.28984 .77344 Mdot
.20077 .98323 Mdot
.11489 .00534 Mdot
.23594 .62736 Mdot
.25125 .81757 Mdot
.52262 .29997 Mdot
.18222 .24903 Mdot
.2675 .69799 Mdot
.21244 .69398 Mdot
.18317 .74705 Mdot
.24406 .91246 Mdot
.21731 .93529 Mdot
.50961 .05905 Mdot
.35501 .87071 Mdot
.26142 .86343 Mdot
.36658 .7768 Mdot
.02895 .73166 Mdot
.21447 .84197 Mdot
.66214 .50826 Mdot
.29499 .93864 Mdot
.29731 .92089 Mdot
.39601 .93755 Mdot
.27597 .90326 Mdot
.29696 .97047 Mdot
.20877 .76927 Mdot
.32514 .9889 Mdot
.36693 .93896 Mdot
.55037 .45606 Mdot
.24346 .69716 Mdot
.26 .92781 Mdot
.19649 .79045 Mdot
.25514 .90871 Mdot
.46217 .53345 Mdot
.48431 .75096 Mdot
.30575 .79724 Mdot
.27688 .96789 Mdot
.26315 .94512 Mdot
.3724 .91161 Mdot
.87157 .58984 Mdot
.55479 .99231 Mdot
.29954 .9165 Mdot
.25399 .871 Mdot
.31613 .83209 Mdot
.07994 .72856 Mdot
.63265 .64704 Mdot
.99866 .91241 Mdot
.22304 .87368 Mdot
.31162 .95048 Mdot
.17286 .83738 Mdot
.05792 .60503 Mdot
.21124 .61478 Mdot
.14906 .79871 Mdot
.2341 .69741 Mdot
.24192 .91064 Mdot
.14112 .46026 Mdot
.292 .94519 Mdot
.28761 .23656 Mdot
.41838 .94841 Mdot
.20702 .87609 Mdot
.30208 .92418 Mdot
.20725 .8634 Mdot
.33228 .84646 Mdot
.09201 .19397 Mdot
.30772 .96209 Mdot
.32063 .91918 Mdot
.11903 .76469 Mdot
.21289 .91754 Mdot
.52978 .96386 Mdot
.28321 .9195 Mdot
.50651 .90967 Mdot
.23401 .90705 Mdot
.31536 .89428 Mdot
.22292 .94804 Mdot
.47746 .95779 Mdot
.30729 .9758 Mdot
.40959 .32375 Mdot
.18323 .95938 Mdot
.51701 .90373 Mdot
.19747 .7316 Mdot
.26699 .85365 Mdot
.20335 .80103 Mdot
.29405 .94835 Mdot
.23164 .99659 Mdot
.42797 .76896 Mdot
.12572 .76836 Mdot
.1329 .79298 Mdot
.00026 .68308 Mdot
.32248 .79027 Mdot
.10774 .91403 Mdot
.13586 .47928 Mdot
.47643 .38457 Mdot
.45793 .81051 Mdot
.32677 .79001 Mdot
.81105 .7144 Mdot
.23419 .91297 Mdot
.7407 .69443 Mdot
.20936 .82274 Mdot
.11845 .88679 Mdot
.41777 .93984 Mdot
.19582 .74013 Mdot
.19718 .09088 Mdot
.00262 .68432 Mdot
.2548 .79869 Mdot
.6723 .53789 Mdot
.63964 .99173 Mdot
.17094 .05006 Mdot
.27773 .73301 Mdot
.13326 .77279 Mdot
.17069 .74416 Mdot
.31531 .08312 Mdot
.03374 .939 Mdot
.07645 .48807 Mdot
.34134 .86756 Mdot
.36019 .90694 Mdot
.40354 .18313 Mdot
.27559 .90773 Mdot
.16926 .90966 Mdot
.44129 .92896 Mdot
.32005 .83059 Mdot
.23461 .47985 Mdot
.26495 .96727 Mdot
.18997 .75085 Mdot
.30542 .92756 Mdot
.2318 .83067 Mdot
.03927 .39718 Mdot
.14304 .46755 Mdot
.1225 .04263 Mdot
.14611 .8811 Mdot
.58334 .36729 Mdot
.43487 .72849 Mdot
.34669 .87266 Mdot
.28717 .92333 Mdot
.35132 .80672 Mdot
.92691 .29584 Mdot
.14054 .75575 Mdot
.1123 .65884 Mdot
.31396 .78162 Mdot
.2404 .85431 Mdot
.90064 .60033 Mdot
.27302 .91309 Mdot
.12813 .80727 Mdot
.30043 .89144 Mdot
.58486 .49406 Mdot
.43048 .78436 Mdot
.26654 .83581 Mdot
.42828 .02574 Mdot
.47162 .70696 Mdot
.30806 .82399 Mdot
.37741 .01981 Mdot
.22809 .80434 Mdot
.35252 .79751 Mdot
.48075 .76491 Mdot
.96242 .34955 Mdot
.37191 .7394 Mdot
.22039 .8851 Mdot
.86251 .5203 Mdot
.14827 .89713 Mdot
.54065 .66476 Mdot
.31448 .14788 Mdot
.31261 .78514 Mdot
.2668 .85246 Mdot
.21448 .83959 Mdot
.21317 .62453 Mdot
.30204 .91968 Mdot
.64711 .42534 Mdot
.22085 .75453 Mdot
.16531 .65385 Mdot
.681 .60443 Mdot
.56943 .23995 Mdot
.14406 .23616 Mdot
.41162 .97913 Mdot
.00573 .6705 Mdot
.61582 .52394 Mdot
.9345 .56974 Mdot
.30458 .95591 Mdot
.19016 .8875 Mdot
.40228 .84687 Mdot
.25177 .863 Mdot
.23526 .90147 Mdot
.27517 .9557 Mdot
.17857 .67777 Mdot
.24833 .77852 Mdot
.20419 .93991 Mdot
.27062 .76868 Mdot
.48385 .80958 Mdot
.09215 .03046 Mdot
.48121 .28787 Mdot
.46629 .76288 Mdot
.24968 .89121 Mdot
.96028 .28786 Mdot
.21719 .87158 Mdot
.14539 .00994 Mdot
.39236 .78513 Mdot
.37991 .92139 Mdot
.25246 .90075 Mdot
.21826 .8896 Mdot
.37496 .6683 Mdot
.18096 .80784 Mdot
.33021 .79256 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`;o00002?ooool2o`0000oo
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`06ooooo`;o00001Oooool00ol0003o
ooooooooo`02o`0000_ooooo0ol0000=ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo000Nooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooo`000003o`0000[ooooo
0ol00008ooooo`;o00001?ooool00ol0003oooooooooo`0;ooooo`?o000000?oooooo`000?l00000
3?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
1_ooool2o`0000Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00;ooooo000Nooooo`03o`000?oooooooooo01oooooo1?l00008ooooo`;o000000?o
ooooo`000?l000002?ooool2o`0001;ooooo0_l000001?oooooo0000o`000?l0003eooooo`007_oo
ool00ol0003oooooooooo`0[ooooo`;o00008_ooool2o`0002gooooo0_l0002hooooo`;o00003Ooo
ool001kooooo00?o0000ooooooooool06_ooool2o`0002Wooooo0_l0000gooooo`;o00004oooool2
o`000:?ooooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o0000:Oooool2o`00
027ooooo0_l0000=ooooo`;o00005?ooool2o`0000Cooooo0_l0002booooo`007_ooool00ol0003o
ooooooooo`1Xooooo`;o00003Oooool2o`0001?ooooo0ol0002hooooo`007_ooool00ol0003ooooo
ooooo`0gooooo`;o0000@?ooool2o`0000cooooo0_l00003ooooo`;o00001oooool2o`000;3ooooo
000Nooooo`03o`000?oooooooooo03Oooooo0_l00010ooooo`;o00003?ooool2o`0000cooooo0_l0
002Booooo`;o00007?ooool001kooooo00?o0000ooooooooool01oooool2o`00017ooooo0_l00005
ooooo`;o0000@Oooool2o`000<?ooooo0_l0000Looooo`007_ooool00ol0003oooooooooo`07oooo
o`;o00004Oooool2o`0000Gooooo0_l0000[ooooo`;o00005?ooool2o`000<gooooo0_l0000Boooo
o`007_ooool00ol0003oooooooooo`0Looooo`;o00001Oooool2o`0002Wooooo0_l00016ooooo`;o
0000UOooool2o`0000Cooooo0_l0000Booooo`007_ooool00ol0003oooooooooo`0Looooo`;o0000
1Oooool2o`0000Gooooo0_l0000_ooooo`;o00008oooool2o`0001Cooooo0_l0002Eooooo`;o0000
1oooool2o`0000oooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l00004ooooo`;o000000?o
ooooo`000?l00000;?ooool2o`0000cooooo0_l0000Eooooo`;o00001?ooool2o`000:kooooo0_l0
00000ooooooo0000o`00000<ooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o00000oooool2
o`0000Oooooo0_l00003ooooo`;o00003_ooool2o`0000;ooooo0_l0000Qooooo`;o00006oooool2
o`000:_ooooo0_l00004ooooo`;o00003?ooool001kooooo00?o0000ooooooooool02?ooool2o`00
01Gooooo0_l0000Aooooo`?o00003Oooool2o`0000;ooooo0_l0003[ooooo`;o00004_ooool001ko
oooo0_l00009ooooo`;o00004_ooool2o`0001Gooooo0_l0003ooooooa?ooooo000Nooooo`03o`00
0?oooooooooo01cooooo0_l0003oooooob[ooooo000Nooooo`03o`000?oooooooooo03Oooooo0_l0
000eooooo`;o0000<Oooool3o`000:?ooooo000Nooooo`03o`000?oooooooooo03Oooooo0_l0000e
ooooo`;o0000<Oooool3o`000:?ooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0G?ooool2o`000>Wooooo000Nooooo`03o`000?oooooooooo03cooooo
0_l0000Nooooo`;o00005Oooool2o`000=;ooooo000Nooooo`03o`000?oooooooooo03cooooo0_l0
000eooooo`;o0000d_ooool001kooooo00?o0000ooooooooool0:Oooool2o`0000Gooooo0_l00017
ooooo`;o0000c?ooool001kooooo00?o0000ooooooooool0:Oooool2o`0000Gooooo0_l00017oooo
o`;o0000=Oooool2o`0009Gooooo000Nooooo`03o`000?oooooooooo06;ooooo0_l0001<ooooo`;o
0000UOooool001kooooo00?o0000ooooooooool04oooool2o`0002[ooooo0_l0000Qooooo`;o0000
>_ooool2o`000:Oooooo000Nooooo`03o`000?oooooooooo01?ooooo0_l0000Zooooo`;o0000GOoo
ool2o`0008;ooooo0_l0000Sooooo`007_ooool00ol0003oooooooooo`0looooo`;o0000i?ooool2
o`0002?ooooo000Nooooo`03o`000?oooooooooo03cooooo0_l00039ooooo`;o0000?_ooool001ko
oooo00?o0000ooooooooool0Boooool2o`000;[ooooo0_l0000nooooo`007_ooool2o`0004Gooooo
0_l00005ooooo`;o00000_ooool2o`0008cooooo0_l0001Xooooo`007_ooool00ol0003ooooooooo
o`14ooooo`;o00002Oooool2o`0008cooooo0_l0001Xooooo`007_ooool00ol0003oooooooooo`13
ooooo`;o00002_ooool2o`000?Kooooo000Nooooo`03o`000?oooooooooo00gooooo0_l0000doooo
o`;o0000ooooool3ooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o00009oooool2o`000?oo
oooo4?ooool001kooooo00?o0000ooooooooool0=_ooool2o`000?oooooo4?ooool001kooooo00?o
0000ooooooooool0Coooool2o`000?Kooooo000Nooooo`03o`000?oooooooooo04oooooo0_l0003f
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo00?o
oooo0_l0003ooooood?ooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0003Vooooo`;o0000
F_ooool001kooooo00?o0000ooooooooool0joooool2o`0005[ooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo06;ooooo0_l0003Sooooo`007_oo
ool2o`0006?ooooo0_l0001Kooooo`;o0000Q_ooool001kooooo00?o0000ooooooooool08Oooool2
o`0009cooooo0_l00026ooooo`007_ooool00ol0003oooooooooo`0Qooooo`;o0000boooool2o`00
05Oooooo000Nooooo`03o`000?oooooooooo0>kooooo0_l0001Gooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooo`oooooo0_l0000goooo
o`007_ooool00ol0003oooooooooo`3oooooo`oooooo0_l0000gooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`;o0000W?ooool2o`0009[ooooo000Nooooo`03o`000?oooooooooo00gooooo0_l0
002Looooo`;o0000F_ooool2o`0003kooooo000Nooooo`03o`000?oooooooooo07Gooooo0_l00008
ooooo`;o0000Q_ooool2o`0003kooooo000Nooooo`03o`000?oooooooooo07Gooooo0_l00008oooo
o`;o0000LOooool2o`0005?ooooo000Nooooo`03o`000?oooooooooo03Kooooo0_l0002jooooo`;o
0000Doooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Ko
oooo00?o0000ooooooooool06_ooool2o`0001[ooooo0_l0003ooooooa3ooooo0003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006oooo
o`03o`000?oooooooooo01[ooooo0_l0003oooooobcooooo0003ooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003o
oooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3ooooo
odSooooo0003ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05oooo
o`03o`000?oooooooooo03Cooooo0_l0003ooooooa;ooooo0003ooooo`05oa0@4?oooooooooooooo
ool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Cooooo0_l0003ooooo
oa;ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oooooo<ooo
ool2o`0001?ooooo000Nooooo`03o`000?oooooooooo0?oooooo<oooool2o`0001?ooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0R?ooool2o`000;go
oooo000Nooooo`03o`000?oooooooooo08Sooooo0_l0002mooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0:oooool2o`0002cooooo0_l0003/ooooo`007_ooool00ol0003oooooooooo`0[ooooo`;o
0000;?ooool2o`0005[ooooo0_l00018ooooo`;o0000A_ooool001kooooo00?o0000ooooooooool0
Doooool2o`00063ooooo0_l00018ooooo`;o0000A_ooool001kooooo00?o0000ooooooooool0Dooo
ool2o`000?;ooooo000Nooooo`03o`000?oooooooooo03Oooooo0_l0001Sooooo`;o0000X?ooool2
o`0000Oooooo000Nooooo`;o0000>?ooool2o`0006?ooooo0_l0002Pooooo`;o00001oooool001ko
oooo00?o0000ooooooooool0W?ooool2o`0001_ooooo0_l0002<ooooo`007_ooool00ol0003ooooo
ooooo`2iooooo`;o0000S?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo02oooooo0_l0000Ooooo
o`;o0000mOooool001kooooo00?o0000ooooooooool0;oooool2o`0001oooooo0_l0003eooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0N?ooool2o`0003cooooo0_l0002?ooooo`007_ooool00ol0
003oooooooooo`1hooooo`;o0000??ooool2o`0008oooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0V?ooool2o`0009[ooooo0_l0000Aooooo`007_oo
ool00ol0003oooooooooo`2Hooooo`;o0000ROooool2o`0000oooooo0_l0000Aooooo`007_ooool0
0ol0003oooooooooo`3oooooobCooooo0_l00004ooooo`;o00007?ooool001kooooo00?o0000oooo
ooooool0oooooolZooooo`;o00007?ooool001kooooo0_l0002Wooooo`;o0000Woooool001kooooo
00?o0000ooooooooool0Y_ooool2o`0009oooooo000Nooooo`03o`000?oooooooooo07kooooo0_l0
0037ooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o0000KOooool2o`0003oooooo0_l00026
ooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o0000[_ooool2o`0008Kooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`21ooooo`;o0000X?ooool2o`0002;ooooo000Nooooo`03o`000?oooooo
oooo087ooooo0_l00002ooooo`;o0000:Oooool2o`00077ooooo0_l0000Rooooo`007_ooool00ol0
003oooooooooo`25ooooo`;o0000:Oooool2o`0009Gooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool08_ooool2o`0007Wooooo0_l0000=ooooo`;o0000
L_ooool2o`0002Gooooo000Nooooo`03o`000?oooooooooo02;ooooo0_l0001Sooooo`;o00005?oo
ool2o`0000gooooo0_l0001booooo`;o00001oooool2o`0001cooooo000Nooooo`03o`000?oooooo
oooo08Oooooo0_l0002Pooooo`;o00001Oooool2o`0001Gooooo000Nooooo`03o`000?oooooooooo
02Cooooo0_l0001]ooooo`;o0000<Oooool2o`0006Sooooo0_l0000Eooooo`007_ooool00ol0003o
ooooooooo`0Tooooo`;o0000KOooool2o`00037ooooo0_l0001Pooooo`;o00007Oooool001kooooo
0_l0001Vooooo`;o0000`Oooool2o`0000_ooooo0_l0000@ooooo`007_ooool00ol0003ooooooooo
o`1Uooooo`;o0000c_ooool2o`00013ooooo000Nooooo`03o`000?oooooooooo0;Gooooo0_l0002@
ooooo`007_ooool00ol0003oooooooooo`2Yooooo`;o00002_ooool2o`00093ooooo000Nooooo`03
o`000?oooooooooo067ooooo0_l00016ooooo`;o0000W?ooool001kooooo00?o0000ooooooooool0
3?ooool2o`0002cooooo0_l0000Uooooo`;o0000Eoooool2o`0008_ooooo000Nooooo`03o`000?oo
oooooooo00Sooooo0_l00002ooooo`;o0000;?ooool2o`0007kooooo0_l0001Nooooo`?o0000:_oo
ool001kooooo00?o0000ooooooooool02?ooool2o`000?oooooo4Oooool3o`0002[ooooo000Noooo
o`03o`000?oooooooooo0;;ooooo0_l00008ooooo`;o0000ROooool001kooooo00?o0000oooooooo
ool08Oooool2o`0008oooooo0_l00008ooooo`;o0000Eoooool2o`00033ooooo000Nooooo`03o`00
0?oooooooooo027ooooo0_l0000[ooooo`;o0000aOooool2o`00033ooooo000Nooooo`03o`000?oo
oooooooo04kooooo0_l00017ooooo`;o0000[_ooool001kooooo00?o0000ooooooooool0Uoooool2
o`0000cooooo0_l0002Pooooo`007_ooool00ol0003oooooooooo`1nooooo`;o00009Oooool2o`00
01Sooooo0_l00026ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`1nooooo`;o0000?oooool2o`00
08Kooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`09ooooo`;o0000oooooolmooooo`000oooool01Ol@413o
oooooooooooooooo410@00_ooooo1Ol00006ooooo`?o00002Oooool2o`00033ooooo0_l00017oooo
o`;o0000`Oooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgooooo
o`0000Oooooo00?o0000ooooooooool0>oooool2o`0004Oooooo0_l0000Uooooo`;o0000;_ooool2
o`0006[ooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0
0007ooooo`03o`000?oooooooooo0:_ooooo0_l0000^ooooo`;o0000J_ooool000?ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0_?oo
ool2o`0008Wooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00
0007ooooo`03o`000?oooooooooo0;cooooo0_l00029ooooo`000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo087ooooo0_l00034ooooo`007_ooool00ol0003oooooooooo`21oooo
o`;o0000a?ooool001kooooo00?o0000ooooooooool0c_ooool2o`0007Oooooo000Nooooo`03o`00
0?oooooooooo00Kooooo0_l00036ooooo`;o0000@_ooool2o`0003?ooooo000Nooooo`03o`000?oo
oooooooo00Kooooo0_l0003oooooo`_ooooo0_l0000cooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0=Kooooo0_l0001_ooooo`007_ooool00ol0003o
ooooooooo`3Fooooo`;o0000Koooool001kooooo00?o0000ooooooooool03oooool2o`0005Sooooo
0_l0000looooo`;o00004Oooool2o`0008_ooooo000Nooooo`03o`000?oooooooooo00oooooo0_l0
001>ooooo`;o00002?ooool2o`0003cooooo0_l0000Aooooo`;o0000Roooool001kooooo00?o0000
ooooooooool0Goooool2o`000>Kooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003o
ooooooooo`2_ooooo`;o0000U_ooool001kooooo00?o0000ooooooooool0[oooool2o`0009Kooooo
000Nooooo`03o`000?oooooooooo02[ooooo0_l0003]ooooo`;o0000;?ooool001kooooo00?o0000
ooooooooool0:Oooool3o`000>gooooo0_l0000/ooooo`007_ooool00ol0003oooooooooo`0Yoooo
o`?o0000oooooolLooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o00005oooool2o`0009So
oooo0_l0001Mooooo`;o00008_ooool001kooooo00?o0000ooooooooool04?ooool3o`00033ooooo
0_l0001oooooo`;o0000FOooool2o`0000;ooooo0_l0000Rooooo`007_ooool00ol0003ooooooooo
o`0@ooooo`;o0000<Oooool2o`000=[ooooo0_l0000Vooooo`007_ooool00ol0003oooooooooo`0X
ooooo`;o00007_ooool2o`0000?ooooo0_l0003hooooo`007_ooool00ol0003oooooooooo`0Xoooo
o`;o00007_ooool2o`0000?ooooo0_l0003Zooooo`;o00003?ooool001kooooo00?o0000oooooooo
ool0boooool2o`0006cooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o0000
]?ooool2o`0000Wooooo0_l00006ooooo`;o0000Ioooool001kooooo00?o0000ooooooooool01?oo
ool2o`0000oooooo0_l0002oooooo`;o00001_ooool2o`0006Oooooo000Nooooo`03o`000?oooooo
oooo00Cooooo0_l0002dooooo`;o0000Roooool001kooooo00?o0000ooooooooool0:Oooool2o`00
07kooooo0_l0000?ooooo`;o0000Ooooool2o`0000[ooooo000Nooooo`;o0000:_ooool2o`0007ko
oooo0_l0002@ooooo`;o00002_ooool001kooooo00?o0000ooooooooool0:_ooool2o`0007kooooo
0_l0000Yooooo`;o0000L?ooool001kooooo00?o0000ooooooooool0:_ooool2o`0007kooooo0_l0
000Wooooo`Co0000L?ooool001kooooo00?o0000ooooooooool0GOooool2o`0007Cooooo0_l00017
ooooo`;o0000:Oooool001kooooo00?o0000ooooooooool0GOooool2o`000;gooooo0_l0000Yoooo
o`007_ooool00ol0003oooooooooo`3ooooooc;ooooo0_l0000Dooooo`007_ooool00ol0003ooooo
ooooo`2Uooooo`;o0000KOooool2o`0001_ooooo0_l00007ooooo`;o00002oooool001kooooo00?o
0000ooooooooool0YOooool2o`0001gooooo0_l0001>ooooo`;o00009?ooool2o`0000_ooooo000N
ooooo`03o`000?oooooooooo0<Cooooo0_l00021ooooo`007_ooool00ol0003oooooooooo`1Xoooo
o`;o0000gOooool001kooooo00?o0000ooooooooool0J?ooool2o`0002Sooooo0_l0001Wooooo`;o
0000B_ooool001kooooo00?o0000ooooooooool0T_ooool2o`0006Oooooo0_l0001:ooooo`007_oo
ool00ol0003oooooooooo`1^ooooo`;o0000@oooool2o`00027ooooo0_l0001_ooooo`007_ooool0
0ol0003oooooooooo`1^ooooo`;o0000@oooool2o`00027ooooo0_l0001Yooooo`;o00001?ooool0
01kooooo00?o0000ooooooooool02_ooool2o`000?oooooo=_ooool2o`0000Cooooo000Nooooo`03
o`000?oooooooooo00Sooooo1?l0002/ooooo`;o0000SOooool001kooooo0_l000000ooooooo0000
o`000006ooooo`;o0000@_ooool2o`0006[ooooo0_l0002=ooooo`007_ooool00ol0003ooooooooo
o`02o`0004[ooooo0_l0003iooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo067ooooo0_l0003Tooooo`007_ooool00ol0003oooooooooo`1Qooooo`;o
0000i?ooool001kooooo00?o0000ooooooooool03Oooool2o`000?oooooo>Oooool001kooooo00?o
0000ooooooooool03Oooool2o`000?oooooo7_ooool2o`0001Wooooo000Nooooo`03o`000?oooooo
oooo0?oooooo;Oooool2o`0001Wooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool00oooool2o`0000Wooooo0_l0000Rooooo`;o0000oooooolDooooo`00
7_ooool00ol0003oooooooooo`03ooooo`;o00002Oooool2o`0002;ooooo0_l0000kooooo`;o0000
e_ooool001kooooo00?o0000ooooooooool03_ooool2o`0005oooooo0_l0000:ooooo`;o0000b_oo
ool001kooooo00?o0000ooooooooool0Noooool2o`0005_ooooo0_l0001Sooooo`;o00002?ooool0
01kooooo00?o0000ooooooooool0f?ooool2o`0003gooooo0_l0000Tooooo`;o00002?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413o
c<c<00Kooooo00?o0000ooooooooool0oooooolHooooo`;o00009?ooool2o`0000Sooooo0003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q
8@06ooooo`03o`000?oooooooooo05Wooooo0_l0003/ooooo`000oooool01Ol@413ooooooooooooo
oooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o00002oooool2o`0004cooooo
0_l0001Aooooo`;o0000Loooool2o`0002Cooooo0003ooooo`05o`000?ooooooooooooooool00000
2oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool02oooool2o`0009oo
oooo0_l0001cooooo`;o00009?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05
o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0?ooooo`;o0000I?ooool2o`00
06;ooooo0_l0001Vooooo`;o00001?ooool000?ooooo00Go410@oooooooooooooooooa0@400;oooo
o`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool02_ooool2o`0000?ooooo0_l00009oooo
o`;o0000FOooool2o`0002Gooooo0_l0000kooooo`;o0000I_ooool2o`0000Cooooo0003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo
00?ooooo0_l00005ooooo`;o00001Oooool2o`0000Oooooo0_l00020ooooo`;o0000Voooool2o`00
00cooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106
ooooo`03o`000?oooooooooo00?ooooo0_l0000<ooooo`;o0000;_ooool2o`0006Oooooo0_l0002=
ooooo`;o00003?ooool001kooooo00?o0000ooooooooool01oooool2o`0003Sooooo0_l0000Voooo
o`;o0000?oooool2o`0009_ooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0001Pooooo`;o
0000g?ooool001kooooo00?o0000ooooooooool0<_ooool4o`0000_ooooo0_l0001Xooooo`;o0000
S_ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo033ooooo1_l00002ooooo`Co00001Ooo
ool2o`0000Kooooo0_l0001Pooooo`;o0000S_ooool2o`0000[ooooo000Nooooo`03o`000?oooooo
oooo033ooooo1?l00004ooooo`Co00003Oooool2o`0005gooooo0_l00009ooooo`;o0000T_ooool0
01kooooo00?o0000ooooooooool01oooool2o`0009oooooo0_l00009ooooo`;o0000T_ooool001ko
oooo00Co0000ooooool0003o00001_ooool2o`000?oooooo?oooool001kooooo00Co0000ooooool0
003o0000<?ooool3o`0003Kooooo0_l0003Kooooo`007_ooool00ol0003oooooooooo`0aooooo`?o
00000oooool2o`0000?ooooo0_l0000/ooooo`;o00008_ooool2o`0005;ooooo0_l000000ooooooo
0000o`00001Pooooo`007_ooool00ol0003oooooooooo`0gooooo`;o00000oooool2o`0000Gooooo
0_l00019ooooo`;o0000>_ooool2o`0001Kooooo0_l000000ooooooo0000o`00001Jooooo`;o0000
1?ooool001kooooo00?o0000ooooooooool0@oooool2o`000003ooooool0003o000001Oooooo0_l0
001Yooooo`;o0000MOooool2o`0000Cooooo000Nooooo`;o0000Aoooool2o`0001Oooooo0_l0003V
ooooo`007_ooool00ol0003oooooooooo`0booooo`?o00000oooool2o`0005oooooo0_l0000Ooooo
o`;o0000MOooool2o`0000cooooo0_l00006ooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o
00004?ooool3o`0000?ooooo0_l00008ooooo`;o0000EOooool2o`0001oooooo0_l0001eooooo`;o
00003?ooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l000000ooooooo0000
o`00000Cooooo`;o00008?ooool2o`000?oooooo1?ooool001kooooo00?o0000ooooooooool02?oo
ool2o`000003ooooool0003o000005?ooooo0_l0001:ooooo`;o0000VOooool001kooooo00?o0000
ooooooooool02oooool2o`0004Wooooo0_l00008ooooo`;o00005?ooool2o`0001Wooooo0_l00003
ooooo`;o00005?ooool2o`0009Wooooo000Nooooo`?o00002oooool2o`0004Wooooo0_l0000Eoooo
o`;o00001oooool2o`0001Wooooo0_l00003ooooo`;o0000[oooool001kooooo0ol0000dooooo`;o
0000=oooool2o`0002Gooooo0_l00006ooooo`;o0000ZOooool001kooooo00?o0000ooooooooool0
=?ooool4o`0005cooooo0_l00006ooooo`;o0000ZOooool001kooooo00?o0000ooooooooool0=Ooo
ool5o`0000Sooooo0_l0000Oooooo`;o0000coooool2o`00017ooooo000Mooooo`;o0000>_ooool2
o`0000Sooooo0_l0000Oooooo`;o0000coooool2o`00017ooooo000Mooooo`?o0000>Oooool2o`00
03Gooooo0_l0001Fooooo`;o0000Koooool2o`0000gooooo000Nooooo`;o0000>Oooool2o`00017o
oooo0_l0000Rooooo`;o00004oooool2o`00047ooooo0_l0001_ooooo`;o00003Oooool001kooooo
00?o0000ooooooooool04?ooool2o`0002kooooo0_l00009ooooo`;o00006Oooool2o`0001cooooo
0_l0000>ooooo`;o0000/Oooool001kooooo00?o0000ooooooooool04?ooool2o`0002Gooooo0_l0
0007ooooo`?o00008oooool2o`0001Cooooo0_l0000;ooooo`;o00002Oooool2o`0005Oooooo0_l0
001Hooooo`007_ooool00ol0003oooooooooo`0gooooo`;o00002?ooool2o`0000Gooooo0_l00000
0ooooooo0000o`000006ooooo`;o00006?ooool2o`0000;ooooo0_l00009ooooo`;o00002oooool2
o`0001Sooooo0_l00018ooooo`;o0000F?ooool001kooooo0_l0000looooo`;o00002oooool2o`00
0003ooooool0003o000000Kooooo0_l0000Hooooo`;o00000_ooool2o`00033ooooo0_l0002Roooo
o`007_ooool00ol0003oooooooooo`0kooooo`;o0000COooool2o`0004;ooooo0_l0001gooooo`00
7_ooool01?l0003oooooo`000?l0001;ooooo`;o0000??ooool2o`0000Wooooo0_l000000ooooooo
0000o`00000dooooo`;o0000Moooool001kooooo00Co0000ooooool0003o00004?ooool2o`0003Wo
oooo0_l0000hooooo`;o00003Oooool2o`000003ooooool0003o00000:gooooo000Nooooo`03o`00
0?oooooooooo017ooooo0_l0001cooooo`;o0000O?ooool2o`00047ooooo000Nooooo`03o`000?oo
oooooooo03kooooo0_l00006ooooo`;o00000_ooool2o`0003cooooo0_l0001jooooo`;o0000@Ooo
ool001kooooo00?o0000ooooooooool0?_ooool2o`0000Kooooo0_l00002ooooo`;o0000??ooool2
o`000;gooooo000Nooooo`03o`000?oooooooooo03Sooooo1?l0001<ooooo`;o0000DOooool2o`00
06[ooooo000Nooooo`?o0000:Oooool2o`0000[ooooo0_l000000ooooooo0000o`000002o`0000Co
oooo0_l0002@ooooo`;o00001oooool2o`0004gooooo0_l0000Kooooo`007_ooool3o`0001Kooooo
0_l0000Aooooo`;o00002_ooool4o`0000Oooooo0_l00002ooooo`;o00001Oooool2o`0000?ooooo
0_l0000gooooo`;o00001?ooool2o`00047ooooo0_l0001Fooooo`;o00006oooool001kooooo00?o
0000ooooooooool01Oooool2o`0000oooooo0_l0000Oooooo`;o000000?oooooo`000?l000000_l0
0006ooooo`;o00001Oooool2o`0000?ooooo0_l00004ooooo`;o0000<Oooool2o`0000Cooooo0_l0
002fooooo`007_ooool00ol0003oooooooooo`05ooooo`;o0000<oooool4o`0000Kooooo0_l0000@
ooooo`;o00004_ooool2o`0001gooooo0_l00018ooooo`;o0000L_ooool001kooooo00?o0000oooo
ooooool04_ooool2o`0000Sooooo0_l0000:ooooo`;o00003?ooool2o`0003;ooooo0_l00009oooo
o`;o00004_ooool2o`0002Kooooo0_l0000Pooooo`;o0000L_ooool001kooooo00?o0000oooooooo
ool04_ooool2o`0000Sooooo0_l00008ooooo`Go00002oooool2o`0000Cooooo0_l0000gooooo`;o
00008_ooool2o`0001Kooooo0_l0002Dooooo`007_ooool00ol0003oooooooooo`0Vooooo`;o0000
00?oooooo`000?l000001oooool3o`0000Oooooo1?l0001;ooooo`;o00003?ooool2o`000:cooooo
000Nooooo`03o`000?oooooooooo03;ooooo0ol00002ooooo`;o00001Oooool2o`0000Gooooo0_l0
000Qooooo`;o00004?ooool2o`0000oooooo0_l0000;ooooo`?o0000[?ooool001kooooo0_l0000H
ooooo`;o00004_ooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o000000?ooooo
o`000?l000002Oooool2o`00027ooooo0_l0000@ooooo`;o00004?ooool2o`0000[ooooo0ol0002/
ooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o00003_ooool3o`000004ooooool0003o0000
o`0000;ooooo0_l00008ooooo`;o00002?ooool2o`00017ooooo0_l0000_ooooo`;o00000_ooool2
o`0000_ooooo0_l0002/ooooo`007_ooool00ol0003oooooooooo`0Uooooo`_o00005?ooool2o`00
017ooooo0_l0000_ooooo`;o00001?ooool2o`000;Oooooo000Nooooo`03o`000?oooooooooo013o
oooo0_l0000Aooooo`go00009oooool2o`0003Gooooo0_l00008ooooo`?o0000[?ooool001kooooo
00?o0000ooooooooool04?ooool2o`00017ooooo0_l000000ooooooo0000o`000004o`000003oooo
ool0003o000000[ooooo0_l0000Looooo`;o0000>_ooool2o`0000?ooooo0ol0002/ooooo`007_oo
ool00ol0003oooooooooo`0;ooooo`;o00004_ooool2o`0000;ooooo0_l000000ooooooo0000o`00
0007o`0000[ooooo0_l00004ooooo`;o00002oooool2o`0000Gooooo0_l00004ooooo`;o0000>?oo
ool2o`0000?ooooo0_l00002ooooo`;o0000ZOooool001kooooo00?o0000ooooooooool02oooool2
o`0001;ooooo0_l00002ooooo`Co00001Oooool2o`00017ooooo0ol00007ooooo`;o000000?ooooo
o`000?l000001Oooool9o`0002_ooooo0_l0000?ooooo`;o00000_ooool2o`000:Wooooo000Noooo
o`03o`000?oooooooooo02Gooooo1?l00007ooooo`;o00003_ooool2o`0000Oooooo0_l00009oooo
o`Go000000?oooooo`000?l00000:oooool2o`0001;ooooo0_l0002Zooooo`007_ooool00ol0003o
ooooooooo`0Uooooo`Co00001oooool2o`0002Cooooo0_l00002ooooo`;o00001Oooool3o`0003Oo
oooo0_l0002Zooooo`007_ooool00ol0003oooooooooo`02ooooo`;o00008oooool2o`0002Cooooo
0_l00006ooooo`?o00002?ooool4o`0000oooooo0_l0003Booooo`007_ooool00ol0003ooooooooo
o`02ooooo`;o00002oooool2o`00013ooooo0_l0000Zooooo`;o00001Oooool3o`0000Sooooo1Ol0
000?ooooo`;o0000=?ooool2o`0009cooooo000Nooooo`03o`000?oooooooooo00oooooo0_l0000@
ooooo`;o00001oooool2o`0002Sooooo0_l00009ooooo`;o000000?oooooo`000?l000000_l0000E
ooooo`;o00002oooool2o`0001gooooo1?l0002Looooo`007_ooool00ol0003oooooooooo`0Zoooo
o`;o00004oooool2o`00027ooooo1_l000000ooooooo0000o`00000@ooooo`;o00002oooool2o`00
01gooooo0_l0002Nooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o00008Oooool2o`000003
ooooool0003o000000[ooooo1?l0000Eooooo`Oo00009Oooool2o`000;Gooooo0003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006oooo
o`03o`000?oooooooooo01Wooooo0_l0000<ooooo`?o00004_ooool2o`0000gooooo1?l00004oooo
o`;o00002Oooool3o`0000?ooooo1ol00009ooooo`;o00000_ooool2o`0001?ooooo0_l000000ooo
oooo0000o`00002eooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0Wooooo`?o00003?ooool2
o`0001_ooooo0_l00009ooooo`?o00000oooool2o`000003ooooool0003o000000?o00000_ooool2
o`0000Cooooo0_l00002ooooo`;o00004oooool4o`0000?ooooo0_l0002aooooo`000oooool01Ol@
413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000;?oo
ool2o`0000Sooooo0_l00006ooooo`;o00003oooool2o`0000kooooo1?l000000ooooooo0000o`00
0004ooooo`;o000000Coooooo`000?l0003o00007oooool2o`0000?ooooo0_l0002aooooo`000ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03
o`000?oooooooooo02Cooooo0_l00006ooooo`;o00004?ooool2o`0000oooooo0_l0000@ooooo`;o
00000_ooool2o`0000Kooooo0_l0003Hooooo`000oooool01Ol0003ooooooooooooooooo000000_o
oooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo02Cooooo1?l0000@oooo
o`;o00003?ooool2o`0001gooooo0_l00004ooooo`Go00005?ooool2o`000<7ooooo0003ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000
ooooooooool09_ooool2o`0000Oooooo0_l00006ooooo`?o00003?ooool2o`0000Cooooo0_l0000G
ooooo`;o00001?ooool6o`0001?ooooo0_l0000Aooooo`Co0000[?ooool000?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003ooooooooo
o`0_ooooo`Co00001?ooool2o`0001?ooooo0_l0000Gooooo`;o00001oooool3o`00023ooooo0_l0
0004ooooo`Co0000Ooooool2o`0002_ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0<Oooool2o`0000Cooooo
0_l00006ooooo`;o00004?ooool4o`0000Cooooo0_l0000<ooooo`;o0000:?ooool2o`0008Oooooo
0_l0000[ooooo`007_ooool00ol0003oooooooooo`0gooooo`;o00001?ooool4o`0000gooooo0_l0
00000ooooooo0000o`000002o`0000Cooooo0_l00006ooooo`;o00001?ooool2o`000=kooooo000N
ooooo`03o`000?oooooooooo033ooooo0_l0000;ooooo`;o00003oooool2o`00017ooooo1?l0003R
ooooo`007_ooool00ol0003oooooooooo`0`ooooo`;o00003_ooool2o`0000Wooooo0_l0000Coooo
o`Go000000?oooooo`000?l000001?ooool2o`0000;ooooo0_l0000Wooooo`;o0000[?ooool001ko
oooo00?o0000ooooooooool0;?ooool2o`0000Sooooo0_l00008ooooo`;o00000oooool2o`0000Co
oooo1?l00002ooooo`;o00000oooool2o`0000Cooooo0_l00002ooooo`Co00000_ooool2o`0000Co
oooo0_l00002ooooo`;o00009oooool2o`000:cooooo000Nooooo`03o`000?oooooooooo02Sooooo
0_l00002ooooo`;o00002?ooool2o`0000gooooo1_l00002ooooo`;o00000_ooool2o`0000?ooooo
0_l000001?oooooo0000o`000?ooool2o`0000Cooooo1?l00003ooooo`;o00000oooool3o`000=Ko
oooo000Nooooo`03o`000?oooooooooo02Sooooo0_l0000Booooo`Co00001Oooool6o`0000kooooo
0_l00005ooooo`;o000000Coooooo`000?l0003o00000oooool2o`0000?ooooo0ol0001aooooo`;o
0000Hoooool001kooooo00?o0000ooooooooool0=?ooool2o`0000Kooooo1?l00005ooooo`Co0000
00?oooooo`000?l000001oooool2o`0000_ooooo0_l000000ooooooo0000o`000008ooooo`;o0000
Loooool2o`0006?ooooo000Nooooo`03o`000?oooooooooo01?ooooo0_l0000Dooooo`;o00002Ooo
ool2o`000003ooooool0003o000000Wooooo0_l00006ooooo`;o000000Coooooo`000?l0003o0000
0oooool3o`0000gooooo0_l00008ooooo`;o0000f?ooool001kooooo00?o0000ooooooooool04ooo
ool2o`0001Cooooo0_l0000;ooooo`?o00000oooool5o`000003ooooool0003o000000Sooooo1?l0
0004ooooo`;o00003?ooool2o`0003;ooooo0_l0000Vooooo`;o0000Qoooool001kooooo00?o0000
ooooooooool0=_ooool5o`000003ooooool0003o000000?o000000Coooooo`000?l0003ooooo0_l0
0002ooooo`;o000000?oooooo`000?l000000oooool2o`0000;ooooo0_l0000;ooooo`;o00001?oo
ool2o`0000?ooooo0ol0000?ooooo`;o00005Oooool2o`0002Kooooo0_l00027ooooo`007Oooool2
o`0003_ooooo0_l0000:ooooo`;o00000_ooool2o`0000?ooooo2Ol0000;ooooo`?o00000oooool2
o`0000?ooooo0ol0000?ooooo`;o00004oooool2o`000;7ooooo000Mooooo`?o0000<oooool2o`00
00Sooooo0_l0000:oooooa3o00002_ooool3o`000004ooooool0003o0000o`0002_ooooo0_l0002a
ooooo`007_ooool00ol0003oooooooooo`0booooo`;o000000?oooooo`000?l000001Oooool4o`00
00Gooooo0_l000000ooooooo0000o`000005o`0000?ooooo0ol000000ooooooo0000o`000004oooo
o`;o00000_ooool4o`0000;ooooo0ol00003ooooo`;o00000_ooool2o`000=Gooooo000Nooooo`03
o`000?oooooooooo00Wooooo0_l0000Zooooo`;o00001?ooool2o`000003ooooool0003o000000Go
oooo0_l00003ooooo`;o00001oooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool4o`0000So
oooo0ol000000ooooooo0000o`000002ooooo`;o00003?ooool2o`0000gooooo0_l0002dooooo`00
7_ooool00ol0003oooooooooo`09ooooo`;o0000<?ooool2o`0000?ooooo0_l00002ooooo`;o0000
1_ooool2o`0000[ooooo0_l0000Booooo`?o00001Oooool2o`0000cooooo0_l00004ooooo`;o0000
1oooool2o`000;Cooooo000Nooooo`03o`000?oooooooooo03oooooo0ol000001?oooooo0000o`00
0?l00006ooooo`Co000000?oooooo`000?l000000_ooool3o`0000gooooo0_l00004ooooo`Co0000
4?ooool2o`0000Oooooo0_l0002mooooo`007_ooool00ol0003oooooooooo`0Zooooo`;o00004?oo
ool2o`000003ooooool0003o000000Co00002Oooool2o`000003ooooool0003o000000;ooooo0ol0
000=ooooo`;o00001?ooool4o`00013ooooo0_l00036ooooo`007_ooool00ol0003oooooooooo`0Z
ooooo`;o00004?ooool2o`0000?ooooo0ol00002ooooo`;o00001_ooool4o`0000Cooooo0_l00002
ooooo`;o00000_ooool2o`000003ooooool0003o000000Sooooo0ol000000ooooooo0000o`00003F
ooooo`007_ooool00ol0003oooooooooo`12ooooo`Oo00000oooool8o`0000Kooooo1_l000000ooo
oooo0000o`00000:ooooo`Co00001oooool2o`0000kooooo0_l0002mooooo`007_ooool00ol0003o
ooooooooo`02o`0003gooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool6o`000003
ooooool0003o000000Sooooo0_l0000>ooooo`?o00002Oooool2o`0000kooooo0_l0002Sooooo`;o
00006?ooool001kooooo00?o0000ooooooooool00_l0000Yooooo`;o00003?ooool2o`000004oooo
ool0003o0000ooooo`;o00001Oooool2o`0000;ooooo1_l0000Kooooo`Go00001oooool2o`000;Co
oooo0_l0000Hooooo`007_ooool00ol0003oooooooooo`0[ooooo`;o00003?ooool2o`000003oooo
ool0003o000000Sooooo1_l000000ooooooo0000o`00000Looooo`Go00001oooool2o`000<kooooo
000Nooooo`03o`000?oooooooooo02;ooooo0_l0000Pooooo`;o00000_ooool5o`0000;ooooo0_l0
000=ooooo`?o00000oooool2o`0006Gooooo0_l0001jooooo`007_ooool00ol0003oooooooooo`0R
ooooo`;o00003Oooool2o`0000Oooooo0ol00006ooooo`Go00000_ooool3o`0000;ooooo0_l00002
ooooo`;o00002Oooool3o`0000?ooooo0_l0000Wooooo`;o0000??ooool2o`0007[ooooo000Noooo
o`03o`000?oooooooooo037ooooo0_l00007ooooo`?o00001_ooool2o`000004ooooool0003o0000
o`0000;ooooo1_l00002ooooo`;o00000oooool2o`0000Cooooo0_l0000Booooo`;o00006Oooool2
o`000;Sooooo000Nooooo`03o`000?oooooooooo04Oooooo0ol000000ooooooo0000o`000004o`00
0003ooooool0003o000000;o00000_ooool2o`0000Cooooo0_l00002ooooo`;o00000oooool2o`00
00Wooooo0_l0000Nooooo`;o0000/oooool001kooooo00?o0000ooooooooool0;?ooool2o`0001[o
oooo0_l00004ooooo`;o00000_ooool4o`0000cooooo0_l00003ooooo`;o00008_ooool2o`0000Go
oooo0_l0000=ooooo`;o0000Y?ooool001kooooo0_l0000]ooooo`;o00006Oooool5o`0000;ooooo
0ol00005ooooo`?o00006_ooool2o`0001Kooooo0_l00005ooooo`;o00003Oooool2o`000:Cooooo
000Nooooo`03o`000?oooooooooo04;ooooo0_l00003ooooo`Ko000000Coooooo`000?l0003o0000
1?ooool4o`0000cooooo0_l00003ooooo`?o00001_ooool2o`0001gooooo0_l0000@ooooo`;o0000
XOooool001kooooo00?o0000ooooooooool0@_ooool2o`0000Cooooo1Ol000001?oooooo0000o`00
0?l00004ooooo`Co00001_ooool2o`0000Cooooo0_l00003ooooo`?o00001?ooool2o`00037ooooo
0_l0002Qooooo`007_ooool00ol0003oooooooooo`0cooooo`;o00004oooool5o`0000;ooooo0_l0
0002ooooo`Ko00001_ooool2o`000003ooooool0003o000000Gooooo1?l00004ooooo`;o00000_oo
ool2o`0000Gooooo0_l0000Sooooo`;o0000Y?ooool001kooooo00?o0000ooooooooool07oooool2
o`0001;ooooo0_l0000Cooooo`Go00000_ooool2o`0000;ooooo1?l0000;ooooo`;o00001Oooool2
o`0000Kooooo0_l00002ooooo`Co00000oooool2o`0000Wooooo0_l0000Hooooo`;o0000W_ooool2
o`0000Cooooo000Nooooo`03o`000?oooooooooo01oooooo0_l0000Pooooo`;o00001Oooool2o`00
0003ooooool0003o000000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000Cooooo1Ol0000A
ooooo`Co00000_ooool2o`0000kooooo0_l00003ooooo`;o0000/oooool2o`0000Cooooo000Noooo
o`03o`000?oooooooooo047ooooo0_l0000<ooooo`;o000000?oooooo`000?l000001?ooool2o`00
0003ooooool0003o000000?o00001?ooool4o`0000Gooooo0_l000001?oooooo0000o`000?ooool2
o`0001Oooooo0_l0000Dooooo`;o0000Xoooool001kooooo00?o0000ooooooooool0?oooool2o`00
00gooooo0_l00003ooooo`;o00000_ooool;o`0000;ooooo1?l00002ooooo`;o000000Coooooo`00
0?l0003ooooo0_l00005ooooo`;o00005oooool2o`000003ooooool0003o000000_ooooo1?l0002S
ooooo`007_ooool00ol0003oooooooooo`0oooooo`;o00003Oooool4o`000003ooooool0003o0000
00;ooooo1?l00002ooooo`Go00002?ooool2o`0000Sooooo0_l000000ooooooo0000o`00000Goooo
o`;o000000Coooooo`000?l0003ooooo0_l00008ooooo`;o0000YOooool001kooooo00?o0000oooo
ooooool0?_ooool2o`0000Gooooo0_l00007ooooo`Oo000000?oooooo`000?l000000ol00002oooo
o`Go00002?ooool4o`0000Kooooo0_l0000Eooooo`;o00002Oooool2o`000:oooooo000Nooooo`03
o`000?oooooooooo01oooooo0_l0000Jooooo`Go00001Oooool2o`0000Oooooo3Ol00004ooooo`Co
00001oooool4o`0000Wooooo0_l0000Booooo`;o00000oooool2o`000;Gooooo000Nooooo`03o`00
0?oooooooooo01oooooo0_l0000Jooooo`Co00001?ooool2o`0000oooooo1?l00005ooooo`;o0000
0_ooool2o`0000_ooooo0_l00007ooooo`;o00001?ooool2o`00017ooooo0_l0002eooooo`007_oo
ool00ol0003oooooooooo`07ooooo`;o0000=oooool2o`000003ooooool0003o000001Oooooo0ol0
000?ooooo`;o00000oooool2o`0000Sooooo0_l0000Mooooo`;o0000ZOooool001kooooo00?o0000
ooooooooool01oooool2o`0003Gooooo1?l0000Jooooo`;o000000?oooooo`000?l000004?ooool4
o`0000Sooooo0_l00005ooooo`;o00005_ooool2o`0000?ooooo0_l0002Tooooo`007_ooool00ol0
003oooooooooo`0Xooooo`;o00005?ooool3o`0000_ooooo0_l00003ooooo`?o00001Oooool5o`00
0004ooooool0003o0000o`0000gooooo1_l00005ooooo`;o00002?ooool3o`0001[ooooo0_l0002T
ooooo`007_ooool00ol0003oooooooooo`0Xooooo`;o00005Oooool2o`0000?ooooo0_l00006oooo
o`;o00000oooool3o`0000?ooooo1ol00002ooooo`;o00003Oooool2o`0000;ooooo0ol00004oooo
o`;o00000_ooool2o`0000Cooooo0ol0000:ooooo`;o0000]?ooool001gooooo0ol00010ooooo`;o
00000oooool2o`0000cooooo0_l00003ooooo`;o000000Coooooo`000?l0003o00000oooool3o`00
00Wooooo0_l00006ooooo`;o00002?ooool2o`0000Cooooo0ol0000:ooooo`;o0000]?ooool001go
oooo0_l00011ooooo`;o00006?ooool3o`0000Cooooo0ol00009ooooo`;o00001?ooool2o`0000Co
oooo0_l0003=ooooo`007_ooool00ol0003oooooooooo`18ooooo`;o00001oooool2o`0000;ooooo
0_l00002ooooo`;o00001?ooool4o`0000?ooooo0_l00002ooooo`;o00001_ooool2o`0000Cooooo
0_l0000Mooooo`;o0000W?ooool2o`00013ooooo000Nooooo`03o`000?oooooooooo01oooooo0_l0
0008ooooo`;o00003?ooool2o`0000oooooo0_l00004ooooo`;o000000?oooooo`000?l000001?l0
0008ooooo`Co00000oooool2o`0000;ooooo0_l00006ooooo`;o00004Oooool2o`0000[ooooo0_l0
0004ooooo`;o0000W?ooool2o`00013ooooo000Nooooo`03o`000?oooooooooo01oooooo0_l00008
ooooo`;o00003?ooool2o`0000Sooooo0_l000000ooooooo0000o`000008ooooo`;o00000oooool2
o`0000?ooooo0_l00006ooooo`?o00002oooool2o`0001Gooooo0_l0000:ooooo`?o00005?ooool2
o`0009gooooo000Nooooo`03o`000?oooooooooo047ooooo0_l000000ooooooo0000o`000007oooo
o`;o00001_ooool5o`0000Kooooo0_l0000<ooooo`;o00000oooool2o`0001gooooo0_l00009oooo
o`;o00002Oooool2o`0009gooooo000Nooooo`03o`000?oooooooooo04gooooo0_l00003ooooo`;o
000000?oooooo`000?l000001?l00005ooooo`;o00000oooool2o`0000?ooooo0_l00007ooooo`;o
0000:?ooool2o`000:Sooooo000Nooooo`03o`000?oooooooooo05;ooooo0_l00002ooooo`Go0000
00?oooooo`000?l000000_ooool2o`0000?ooooo0_l00003ooooo`?o0000=_ooool2o`000:;ooooo
000Nooooo`03o`000?oooooooooo04cooooo0_l0000>ooooo`;o00000_ooool2o`0000Wooooo0_l0
000fooooo`;o0000X_ooool001kooooo00?o0000ooooooooool09?ooool2o`0001Oooooo0_l0000=
ooooo`;o00001oooool2o`0000;ooooo0_l00005ooooo`Co00002_ooool2o`0001;ooooo0_l00033
ooooo`007_ooool00ol0003oooooooooo`0Tooooo`;o00005oooool2o`0000Kooooo0_l0000>oooo
o`;o00000_ooool2o`000003ooooool0003o000000Cooooo0_l0000:ooooo`;o00004_ooool2o`00
0<?ooooo000Nooooo`03o`000?oooooooooo03Cooooo0_l00007ooooo`;o00001_ooool2o`0001Go
oooo0_l0000;ooooo`?o0000foooool001kooooo00?o0000ooooooooool0=?ooool2o`0000Oooooo
0_l0000:ooooo`;o00007_ooool3o`000=_ooooo000Nooooo`03o`000?oooooooooo03?ooooo0_l0
000Dooooo`;o00000oooool2o`0000cooooo0ol00006ooooo`?o0000:?ooool2o`0000?ooooo0_l0
000eooooo`;o0000NOooool001Cooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooo
oooo03?ooooo0_l0000Iooooo`;o00003?ooool3o`0000Kooooo0ol00003ooooo`;o00008oooool2
o`0000?ooooo0_l00003ooooo`;o00005?ooool2o`0001Wooooo0ol0001iooooo`005_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo04Oooooo0_l00002ooooo`;o00004?ooool2o`00
00cooooo0_l0000Jooooo`;o00004Oooool2o`0001Cooooo0_l00003ooooo`;o00005?ooool2o`00
07[ooooo000Fooooo`03o`000?oooooooooo00Gooooo0ol0000gooooo`;o00002oooool2o`000003
ooooool0003o000000;ooooo0_l0000>ooooo`Co0000:?ooool2o`0002cooooo0_l0002@ooooo`00
5_ooool00ol0003oooooooooo`0oooooo`;o00002oooool2o`0001Gooooo0_l0003Zooooo`005_oo
ool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool0
01Kooooo00?o0000ooooooooool0oooooom@ooooo`005?ooool00omEEEGoIVIVo`00003ooooooe;o
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.12513 .81479 Mdot
.00664 .06432 Mdot
.25206 .91766 Mdot
.16567 .87345 Mdot
.31843 .97452 Mdot
.2588 .84531 Mdot
.70463 .62233 Mdot
.30318 .95621 Mdot
.27268 .82437 Mdot
.23652 .49839 Mdot
.29216 .84431 Mdot
.29422 .89411 Mdot
.29441 .93719 Mdot
.26848 .85358 Mdot
.2306 .85262 Mdot
.16542 .84402 Mdot
.11106 .70442 Mdot
.26868 .9407 Mdot
.13446 .81375 Mdot
.17219 .8356 Mdot
.9285 .19893 Mdot
.31789 .79686 Mdot
.37497 .89048 Mdot
.98573 .77022 Mdot
.25374 .85049 Mdot
.32162 .93767 Mdot
.24616 .84266 Mdot
.16203 .82627 Mdot
.29085 .864 Mdot
.26247 .77235 Mdot
.21296 .89341 Mdot
.24297 .85299 Mdot
.3276 .80396 Mdot
.99644 .09346 Mdot
.46532 .72368 Mdot
.21161 .89379 Mdot
.34618 .8512 Mdot
.00055 .73988 Mdot
.24131 .97186 Mdot
.23744 .87352 Mdot
.18875 .86941 Mdot
.50416 .74499 Mdot
.39339 .91582 Mdot
.00802 .72008 Mdot
.23925 .97432 Mdot
.51633 .76056 Mdot
.143 .93486 Mdot
.43315 .05494 Mdot
.23268 .87937 Mdot
.37726 .57439 Mdot
.28081 .07632 Mdot
.4701 .81279 Mdot
.33256 .98259 Mdot
.24156 .92726 Mdot
.3505 .99292 Mdot
.2116 .0069 Mdot
.96377 .74609 Mdot
.29105 .96233 Mdot
.24575 .8405 Mdot
.19544 .7042 Mdot
.17862 .86579 Mdot
.31822 .93774 Mdot
.57624 .71627 Mdot
.26722 .84689 Mdot
.22625 .938 Mdot
.30486 .81604 Mdot
.47507 .81096 Mdot
.246 .84225 Mdot
.25263 .84305 Mdot
.60739 .70922 Mdot
.05576 .36531 Mdot
.16601 .59907 Mdot
.52359 .02394 Mdot
.28958 .69872 Mdot
.36879 .80533 Mdot
.9436 .6667 Mdot
.20771 .98517 Mdot
.3831 .80808 Mdot
.24635 .84076 Mdot
.98899 .79098 Mdot
.48879 .00113 Mdot
.49661 .3766 Mdot
.98515 .6765 Mdot
.31325 .9459 Mdot
.71003 .36984 Mdot
.84599 .37856 Mdot
.30946 .96356 Mdot
.20231 .85621 Mdot
.24259 .85133 Mdot
.15144 .63105 Mdot
.23427 .83723 Mdot
.58215 .56158 Mdot
.33588 .60193 Mdot
.1514 .32601 Mdot
.17688 .75756 Mdot
.48464 .97969 Mdot
.54809 .54555 Mdot
.47594 .76309 Mdot
.3112 .90544 Mdot
.3188 .68631 Mdot
.25921 .90088 Mdot
.29173 .09575 Mdot
.10741 .83033 Mdot
.20985 .87114 Mdot
.00166 .09718 Mdot
.3783 .89509 Mdot
.17987 .86368 Mdot
.17455 .86078 Mdot
.46481 .85852 Mdot
.57863 .10716 Mdot
.24522 .86132 Mdot
.96306 .63192 Mdot
.11985 .08857 Mdot
.25065 .93572 Mdot
.74897 .10593 Mdot
.60544 .67441 Mdot
.1812 .97598 Mdot
.30393 .91668 Mdot
.04605 .21837 Mdot
.0913 .01766 Mdot
.23877 .84386 Mdot
.48657 .96071 Mdot
.36324 .78554 Mdot
.15443 .33903 Mdot
.37742 .62416 Mdot
.03985 .87747 Mdot
.40391 .9506 Mdot
.13899 .80419 Mdot
.97081 .0875 Mdot
.52035 .00552 Mdot
.06593 .95613 Mdot
.30435 .89914 Mdot
.81194 .26543 Mdot
.29215 .86831 Mdot
.22553 .84897 Mdot
.32646 .00282 Mdot
.38911 .90964 Mdot
.1761 .66225 Mdot
.15698 .8957 Mdot
.28469 .8249 Mdot
.14758 .81728 Mdot
.27564 .85402 Mdot
.33734 .79732 Mdot
.44196 .73779 Mdot
.50122 .95787 Mdot
.33474 .85672 Mdot
.16631 .78973 Mdot
.24436 .8832 Mdot
.9141 .71413 Mdot
.59908 .33556 Mdot
.1475 .91489 Mdot
.33955 .79454 Mdot
.23569 .93475 Mdot
.17715 .82553 Mdot
.23062 .84885 Mdot
.32109 .92574 Mdot
.1811 .71207 Mdot
.42763 .71189 Mdot
.25394 .83205 Mdot
.16634 .83875 Mdot
.15989 .61248 Mdot
.4037 .67254 Mdot
.01153 .29115 Mdot
.30522 .83724 Mdot
.29978 .90865 Mdot
.34947 .97549 Mdot
.2364 .89587 Mdot
.24431 .84101 Mdot
.62673 .21255 Mdot
.33122 .91186 Mdot
.3411 .77957 Mdot
.49939 .95909 Mdot
.42229 .67511 Mdot
.00319 .56703 Mdot
.12265 .79907 Mdot
.23195 .69331 Mdot
.05122 .96518 Mdot
.30261 .95345 Mdot
.66806 .50815 Mdot
.46588 .79919 Mdot
.34603 .93356 Mdot
.34822 .86442 Mdot
.10861 .8184 Mdot
.18345 .01978 Mdot
.04141 .47867 Mdot
.21329 .09129 Mdot
.16529 .82234 Mdot
.262 .84936 Mdot
.68211 .11796 Mdot
.44268 .76887 Mdot
.12974 .79762 Mdot
.88836 .26944 Mdot
.13669 .80707 Mdot
.08125 .07586 Mdot
.0951 .04316 Mdot
.36174 .88561 Mdot
.41781 .69324 Mdot
.36459 .7926 Mdot
.27586 .82359 Mdot
.36016 .79695 Mdot
.40938 .76 Mdot
.90457 .16149 Mdot
.2721 .84927 Mdot
.21978 .00488 Mdot
.25588 .84954 Mdot
.19767 .85658 Mdot
.6075 .51111 Mdot
.21798 .84475 Mdot
.56477 .31315 Mdot
.13866 .76359 Mdot
.35162 .93606 Mdot
.14141 .81642 Mdot
.2468 .39596 Mdot
.95957 .31091 Mdot
.16413 .6497 Mdot
.08848 .46801 Mdot
.2306 .89287 Mdot
.15437 .13149 Mdot
.20225 .75985 Mdot
.47884 .742 Mdot
.21295 .70891 Mdot
.19207 .7214 Mdot
.28806 .86375 Mdot
.24746 .83493 Mdot
.1575 .66406 Mdot
.17394 .59812 Mdot
.47988 .93317 Mdot
.38231 .93454 Mdot
.21545 .32122 Mdot
.32945 .80099 Mdot
.33211 .92634 Mdot
.20673 .68461 Mdot
.34799 .79451 Mdot
.26854 .04811 Mdot
.0994 .50314 Mdot
.25291 .42311 Mdot
.24423 .26491 Mdot
.25203 .91232 Mdot
.95769 .56657 Mdot
.984 .55761 Mdot
.23816 .01415 Mdot
.34567 .7931 Mdot
.46287 .00284 Mdot
.17847 .00316 Mdot
.21189 .93254 Mdot
.25717 .88026 Mdot
.19776 .68165 Mdot
.32475 .77694 Mdot
.06841 .59549 Mdot
.20114 .87414 Mdot
.45929 .81284 Mdot
.37747 .97237 Mdot
.9061 .48969 Mdot
.83234 .43424 Mdot
.43206 .72274 Mdot
.39013 .06094 Mdot
.34213 .97693 Mdot
.01789 .4726 Mdot
.50357 .87897 Mdot
.7794 .17231 Mdot
.13637 .81394 Mdot
.22088 .89177 Mdot
.30909 .76908 Mdot
.16747 .86551 Mdot
.3468 .79521 Mdot
.87715 .32857 Mdot
.17918 .11202 Mdot
.19319 .39813 Mdot
.27201 .91096 Mdot
.24309 .85562 Mdot
.30703 .90466 Mdot
.43521 .53146 Mdot
.19485 .8383 Mdot
.24444 .87529 Mdot
.50349 .98589 Mdot
.38459 .94639 Mdot
.21329 .74363 Mdot
.43771 .34029 Mdot
.23372 .907 Mdot
.24231 .08344 Mdot
.04234 .73178 Mdot
.31991 .79093 Mdot
.32808 .8405 Mdot
.35051 .79731 Mdot
.33973 .97552 Mdot
.28502 .86226 Mdot
.3073 .91076 Mdot
.27543 .71445 Mdot
.38182 .02971 Mdot
.23426 .06216 Mdot
.40797 .02358 Mdot
.54526 .46556 Mdot
.14026 .81623 Mdot
.06175 .05215 Mdot
.6308 .39164 Mdot
.33643 .66044 Mdot
.2222 .93724 Mdot
.16856 .76582 Mdot
.0585 .7196 Mdot
.49311 .29678 Mdot
.228 .76796 Mdot
.35297 .88508 Mdot
.44656 .71481 Mdot
.21293 .66252 Mdot
.38118 .41057 Mdot
.42567 .86925 Mdot
.2463 .84224 Mdot
.23349 .84006 Mdot
.31729 .04352 Mdot
.87421 .17636 Mdot
.22809 .84436 Mdot
.03993 .72099 Mdot
.323 .93444 Mdot
.11366 .78171 Mdot
.2574 .90424 Mdot
.25252 .00835 Mdot
.22818 .6487 Mdot
.9411 .57797 Mdot
.33912 .82432 Mdot
.07936 .73221 Mdot
.21738 .99417 Mdot
.33903 .79561 Mdot
.25296 .09618 Mdot
.11481 .74901 Mdot
.23302 .91086 Mdot
.33024 .92591 Mdot
.23233 .9031 Mdot
.14127 .81399 Mdot
.3071 .92349 Mdot
.33356 .92702 Mdot
.19244 .8346 Mdot
.26853 .83879 Mdot
.50933 .38877 Mdot
.40859 .84566 Mdot
.0686 .40307 Mdot
.32743 .48982 Mdot
.96203 .03077 Mdot
.24683 .84607 Mdot
.02935 .57743 Mdot
.85577 .37163 Mdot
.29531 .89863 Mdot
.90149 .11604 Mdot
.15113 .817 Mdot
.19627 .63088 Mdot
.95245 .8168 Mdot
.67567 .68664 Mdot
.6522 .28403 Mdot
.35965 .09884 Mdot
.10302 .40463 Mdot
.29633 .96254 Mdot
.28526 .90814 Mdot
.35793 .97964 Mdot
.36966 .77371 Mdot
.18042 .85901 Mdot
.72116 .50301 Mdot
.1861 .85024 Mdot
.51179 .74659 Mdot
.28452 .79919 Mdot
.28514 .95605 Mdot
.18664 .2682 Mdot
.32667 .78615 Mdot
.37784 .89769 Mdot
.19309 .87799 Mdot
.36142 .9313 Mdot
.31425 .86789 Mdot
.45939 .81374 Mdot
.39706 .08423 Mdot
.71973 .16611 Mdot
.02291 .48882 Mdot
.26742 .7978 Mdot
.16104 .62511 Mdot
.24455 .84383 Mdot
.22996 .89357 Mdot
.30732 .8116 Mdot
.48451 .9369 Mdot
.25485 .70401 Mdot
.31384 .94984 Mdot
.22062 .87057 Mdot
.06811 .50899 Mdot
.28413 .75732 Mdot
.24737 .84233 Mdot
.17644 .87108 Mdot
.97225 .48795 Mdot
.47019 .79047 Mdot
.16461 .82106 Mdot
.09907 .0442 Mdot
.30028 .09744 Mdot
.56246 .73635 Mdot
.24606 .84615 Mdot
.18163 .85252 Mdot
.14807 .81687 Mdot
.28099 .9743 Mdot
.24473 .90751 Mdot
.28038 .98075 Mdot
.29775 .97568 Mdot
.54472 .39393 Mdot
.18032 .65998 Mdot
.88993 .33544 Mdot
.24369 .83934 Mdot
.20884 .88916 Mdot
.40248 .88186 Mdot
.35103 .95905 Mdot
.47631 .72851 Mdot
.31851 .93898 Mdot
.3499 .70432 Mdot
.19603 .03785 Mdot
.26137 .0597 Mdot
.14567 .615 Mdot
.20998 .64191 Mdot
.3101 .84721 Mdot
.16249 .62006 Mdot
.2485 .83989 Mdot
.15905 .61726 Mdot
.75322 .68261 Mdot
.93612 .57505 Mdot
.28857 .89982 Mdot
.11145 .82284 Mdot
.17157 .60381 Mdot
.69476 .61432 Mdot
.24412 .84036 Mdot
.23997 .85637 Mdot
.9192 .73956 Mdot
.29267 .43739 Mdot
.28896 .9598 Mdot
.30116 .95742 Mdot
.3526 .06418 Mdot
.35737 .7907 Mdot
.29627 .81102 Mdot
.16719 .59632 Mdot
.53339 .28316 Mdot
.92687 .57676 Mdot
.42149 .05632 Mdot
.26113 .73844 Mdot
.18573 .86023 Mdot
.46406 .68488 Mdot
.62812 .65774 Mdot
.18781 .80175 Mdot
.37691 .98615 Mdot
.18137 .919 Mdot
.2494 .95406 Mdot
.16212 .08731 Mdot
.98632 .72314 Mdot
.0083 .67958 Mdot
.18684 .85688 Mdot
.26901 .27751 Mdot
.20176 .85716 Mdot
.34024 .80003 Mdot
.32097 .96307 Mdot
.5308 .58938 Mdot
.29346 .78652 Mdot
.03725 .77058 Mdot
.46413 .86452 Mdot
.28823 .89069 Mdot
.24693 .8397 Mdot
.13929 .0077 Mdot
.23259 .84204 Mdot
.25504 .83792 Mdot
.22956 .90865 Mdot
.01208 .09123 Mdot
.69696 .77709 Mdot
.17394 .93746 Mdot
.20277 .85052 Mdot
.24829 .84515 Mdot
.2935 .95039 Mdot
.017 .65404 Mdot
.4683 .7549 Mdot
.3326 .79872 Mdot
.97994 .8857 Mdot
.20211 .8518 Mdot
.45492 .89408 Mdot
.27202 .78913 Mdot
.30865 .95505 Mdot
.30915 .94946 Mdot
.31104 .94792 Mdot
.2291 .96302 Mdot
.24609 .85084 Mdot
.26211 .02338 Mdot
.31144 .94956 Mdot
.09263 .74096 Mdot
.41395 .91138 Mdot
.3731 .836 Mdot
.05635 .04462 Mdot
.33519 .79428 Mdot
.15804 .81971 Mdot
.12985 .80821 Mdot
.91214 .49536 Mdot
.05113 .59876 Mdot
.45112 .64262 Mdot
.48363 .9457 Mdot
.1651 .83914 Mdot
.23511 .88968 Mdot
.24495 .84179 Mdot
.56022 .36673 Mdot
.3091 .06229 Mdot
.21716 .81597 Mdot
.3596 .77866 Mdot
.25582 .92385 Mdot
.34803 .80496 Mdot
.96366 .73501 Mdot
.16527 .67912 Mdot
.22766 .94007 Mdot
.50971 .96294 Mdot
.50802 .96714 Mdot
.14933 .40666 Mdot
.2859 .93132 Mdot
.46676 .63751 Mdot
.31247 .94705 Mdot
.6074 .46102 Mdot
.2523 .8396 Mdot
.22616 .76746 Mdot
.1912 .84693 Mdot
.36185 .67039 Mdot
.27763 .83387 Mdot
.98684 .56929 Mdot
.31507 .97564 Mdot
.30799 .03964 Mdot
.26909 .98124 Mdot
.4742 .99291 Mdot
.7914 .50141 Mdot
.20678 .88561 Mdot
.2649 .7853 Mdot
.25688 .95716 Mdot
.24686 .84115 Mdot
.36997 .79275 Mdot
.26279 .7481 Mdot
.99224 .75457 Mdot
.55172 .30743 Mdot
.34123 .44541 Mdot
.08484 .7853 Mdot
.02824 .09193 Mdot
.93924 .20718 Mdot
.43807 .89509 Mdot
.33223 .97559 Mdot
.2879 .02679 Mdot
.31788 .94264 Mdot
.26129 .88847 Mdot
.24234 .93084 Mdot
.30856 .8298 Mdot
.0747 .83786 Mdot
.49587 .21733 Mdot
.28463 .82568 Mdot
.90322 .62631 Mdot
.33966 .85467 Mdot
.24085 .84811 Mdot
.161 .87393 Mdot
.5891 .59196 Mdot
.51689 .60078 Mdot
.19288 .8241 Mdot
.34099 .86734 Mdot
.33097 .92567 Mdot
.63215 .56557 Mdot
.39516 .83095 Mdot
.31788 .81331 Mdot
.95994 .95667 Mdot
.47317 .01838 Mdot
.44641 .57762 Mdot
.4486 .72761 Mdot
.24865 .84789 Mdot
.18929 .89318 Mdot
.87668 .06362 Mdot
.33365 .88048 Mdot
.35323 .83468 Mdot
.04737 .78536 Mdot
.1463 .7086 Mdot
.29967 .91312 Mdot
.23441 .88966 Mdot
.16849 .65203 Mdot
.29241 .87793 Mdot
.4855 .39494 Mdot
.24539 .85098 Mdot
.59265 .03083 Mdot
.18649 .86254 Mdot
.24777 .85277 Mdot
.14798 .80967 Mdot
.2766 .97391 Mdot
.31015 .8045 Mdot
.36725 .01581 Mdot
.28783 .87219 Mdot
.38295 .97083 Mdot
.29802 .8775 Mdot
.34361 .65372 Mdot
.61106 .60516 Mdot
.20656 .00451 Mdot
.15466 .82736 Mdot
.15391 .92005 Mdot
.19538 .86928 Mdot
.18934 .0842 Mdot
.70415 .79584 Mdot
.21312 .97964 Mdot
.19017 .75683 Mdot
.3081 .95174 Mdot
.31967 .00317 Mdot
.20921 .62997 Mdot
.35145 .8011 Mdot
.32801 .82818 Mdot
.32674 .92916 Mdot
.18659 .7649 Mdot
.33323 .92575 Mdot
.20578 .87906 Mdot
.27134 .74109 Mdot
.32388 .79924 Mdot
.24246 .84801 Mdot
.25325 .89624 Mdot
.47571 .75959 Mdot
.55236 .90754 Mdot
.30665 .8288 Mdot
.24135 .86683 Mdot
.3071 .78335 Mdot
.47085 .85976 Mdot
.13217 .81022 Mdot
.42484 .8646 Mdot
.62026 .41696 Mdot
.23961 .8196 Mdot
.48506 .19712 Mdot
.12495 .8301 Mdot
.19003 .85532 Mdot
.16246 .59569 Mdot
.89498 .49407 Mdot
.33498 .90328 Mdot
.42074 .53303 Mdot
.48523 .05163 Mdot
.6563 .94308 Mdot
.13372 .80461 Mdot
.85609 .52865 Mdot
.51089 .79409 Mdot
.14618 .10543 Mdot
.88443 .33253 Mdot
.85811 .36646 Mdot
.37548 .97531 Mdot
.52323 .91138 Mdot
.1909 .93915 Mdot
.24774 .83406 Mdot
.19491 .73857 Mdot
.35873 .82041 Mdot
.24838 .85361 Mdot
.26157 .94113 Mdot
.31176 .94823 Mdot
.30962 .66168 Mdot
.28866 .97786 Mdot
.23095 .85079 Mdot
.43354 .89332 Mdot
.25142 .84915 Mdot
.50193 .75135 Mdot
.51832 .94465 Mdot
.61037 .94719 Mdot
.2229 .78471 Mdot
.37725 .00797 Mdot
.00939 .77063 Mdot
.32651 .9325 Mdot
.46614 .86563 Mdot
.00237 .72875 Mdot
.35324 .82565 Mdot
.16752 .10699 Mdot
.24818 .83587 Mdot
.51885 .59372 Mdot
.24002 .86796 Mdot
.30978 .99526 Mdot
.27465 .74779 Mdot
.59066 .33458 Mdot
.23873 .84026 Mdot
.31488 .93736 Mdot
.37422 .83001 Mdot
.45446 .31928 Mdot
.23796 .84895 Mdot
.88659 .3121 Mdot
.02649 .0452 Mdot
.23965 .83988 Mdot
.70794 .52494 Mdot
.29068 .69458 Mdot
.10215 .07725 Mdot
.397 .01657 Mdot
.51166 .24513 Mdot
.11034 .07574 Mdot
.27809 .74735 Mdot
.02146 .50865 Mdot
.32157 .93418 Mdot
.2165 .9977 Mdot
.28363 .96789 Mdot
.56333 .29966 Mdot
.62708 .30027 Mdot
.02192 .67129 Mdot
.44074 .7426 Mdot
.96347 .55225 Mdot
.1376 .79992 Mdot
.24588 .85143 Mdot
.37537 .63146 Mdot
.3975 .03637 Mdot
.62735 .23835 Mdot
.06892 .98235 Mdot
.26397 .95042 Mdot
.433 .03537 Mdot
.15324 .01468 Mdot
.33578 .84354 Mdot
.59794 .93555 Mdot
.33199 .79628 Mdot
.36329 .81319 Mdot
.24794 .84209 Mdot
.49075 .99135 Mdot
.24597 .68051 Mdot
.08277 .51575 Mdot
.20992 .15708 Mdot
.1802 .85697 Mdot
.3191 .92242 Mdot
.15006 .88847 Mdot
.99616 .50905 Mdot
.36309 .79227 Mdot
.30406 .1655 Mdot
.95743 .68093 Mdot
.3416 .66196 Mdot
.29009 .81839 Mdot
.35447 .48738 Mdot
.20202 .60965 Mdot
.27085 .98454 Mdot
.99497 .5235 Mdot
.39443 .93344 Mdot
.70022 .52477 Mdot
.3297 .78449 Mdot
.28431 .97697 Mdot
.40757 .58757 Mdot
.34235 .78376 Mdot
.14271 .81612 Mdot
.33028 .95398 Mdot
.26941 .7992 Mdot
.71471 .48667 Mdot
.94249 .98616 Mdot
.6899 .69245 Mdot
.1763 .75214 Mdot
.24359 .8451 Mdot
.5233 .97647 Mdot
.01467 .77182 Mdot
.3192 .75795 Mdot
.31901 .75947 Mdot
.31812 .9172 Mdot
.27356 .82431 Mdot
.44891 .62482 Mdot
.63261 .11358 Mdot
.52941 .54771 Mdot
.45652 .62567 Mdot
.33166 .02078 Mdot
.62517 .45048 Mdot
.36444 .88014 Mdot
.16604 .86985 Mdot
.11739 .80721 Mdot
.62479 .57466 Mdot
.34961 .04407 Mdot
.39887 .96815 Mdot
.27504 .75369 Mdot
.98446 .75186 Mdot
.35666 .84688 Mdot
.91881 .54208 Mdot
.48391 .94181 Mdot
.19888 .88847 Mdot
.08431 .0601 Mdot
.1235 .8512 Mdot
.24778 .80256 Mdot
.32411 .91044 Mdot
.31413 .94317 Mdot
.52474 .99377 Mdot
.27441 .01915 Mdot
.22979 .89123 Mdot
.72814 .74748 Mdot
.30242 .95646 Mdot
.39633 .26543 Mdot
.20553 .89882 Mdot
.26026 .08438 Mdot
.17426 .85638 Mdot
.33793 .70648 Mdot
.89298 .65479 Mdot
.36534 .79574 Mdot
.37054 .23276 Mdot
.26023 .87161 Mdot
.08794 .92343 Mdot
.36155 .88011 Mdot
.37747 .97219 Mdot
.59956 .44381 Mdot
.16886 .84445 Mdot
.40066 .90837 Mdot
.23952 .89231 Mdot
.14573 .01443 Mdot
.28595 .3676 Mdot
.16494 .87351 Mdot
.11674 .05424 Mdot
.9785 .63308 Mdot
.33325 .05214 Mdot
.22445 .93235 Mdot
.18242 .72992 Mdot
.17733 .85982 Mdot
.28142 .8256 Mdot
.24542 .84028 Mdot
.32508 .9223 Mdot
.469 .71035 Mdot
.01759 .49298 Mdot
.42958 .66476 Mdot
.31514 .94671 Mdot
.3514 .62751 Mdot
.31618 .99345 Mdot
.17102 .84867 Mdot
.43788 .77628 Mdot
.17444 .87816 Mdot
.16784 .65182 Mdot
.98633 .06223 Mdot
.29069 .7755 Mdot
.21139 .00697 Mdot
.0877 .06418 Mdot
.22162 .63451 Mdot
.27378 .90402 Mdot
.51573 .27218 Mdot
.20348 .24381 Mdot
.36425 .67292 Mdot
.23565 .75287 Mdot
.28972 .68998 Mdot
.1822 .88213 Mdot
.26707 .95271 Mdot
.48023 .10499 Mdot
.25923 .86261 Mdot
.24463 .84257 Mdot
.3536 .64721 Mdot
.92944 .72508 Mdot
.21992 .85276 Mdot
.6976 .53143 Mdot
.31288 .9473 Mdot
.32569 .93429 Mdot
.36392 .87709 Mdot
.31837 .92914 Mdot
.2974 .96344 Mdot
.18034 .67646 Mdot
.33183 .97554 Mdot
.31244 .90075 Mdot
.61946 .46079 Mdot
.28099 .74759 Mdot
.14939 .99399 Mdot
.28574 .70514 Mdot
.2737 .96507 Mdot
.54331 .55906 Mdot
.4776 .75741 Mdot
.32498 .88181 Mdot
.33494 .80572 Mdot
.23224 .87807 Mdot
.32646 .85736 Mdot
.90282 .53647 Mdot
.50627 .05812 Mdot
.33064 .92915 Mdot
.24635 .84126 Mdot
.28159 .8201 Mdot
.96897 .72814 Mdot
.63483 .69754 Mdot
.04402 .83736 Mdot
.285 .90578 Mdot
.32448 .93073 Mdot
.19249 .88499 Mdot
.05376 .70623 Mdot
.19336 .60971 Mdot
.17786 .85754 Mdot
.20796 .79254 Mdot
.23539 .86333 Mdot
.07953 .45637 Mdot
.30681 .95268 Mdot
.28685 .28115 Mdot
.40916 .90235 Mdot
.22517 .91525 Mdot
.32665 .93267 Mdot
.17405 .86976 Mdot
.29677 .81318 Mdot
.13342 .11746 Mdot
.3243 .9345 Mdot
.35547 .83553 Mdot
.13148 .81081 Mdot
.20177 .78952 Mdot
.48534 .87122 Mdot
.31546 .942 Mdot
.41139 .8411 Mdot
.23309 .86843 Mdot
.26293 .85545 Mdot
.1696 .93072 Mdot
.51097 .9871 Mdot
.30096 .97156 Mdot
.37452 .23333 Mdot
.19919 .10119 Mdot
.42896 .96385 Mdot
.21342 .80546 Mdot
.41337 .86749 Mdot
.18866 .81817 Mdot
.30604 .9522 Mdot
.25858 .99394 Mdot
.37758 .81265 Mdot
.12591 .8109 Mdot
.12422 .84887 Mdot
.92541 .65034 Mdot
.3195 .79522 Mdot
.23879 .93868 Mdot
.15066 .43761 Mdot
.45157 .39091 Mdot
.41291 .87426 Mdot
.32565 .79068 Mdot
.81138 .78204 Mdot
.22363 .93434 Mdot
.81018 .70862 Mdot
.21197 .8455 Mdot
.09427 .89417 Mdot
.39172 .90537 Mdot
.20964 .81686 Mdot
.22801 .11112 Mdot
.08766 .62117 Mdot
.18987 .87777 Mdot
.72622 .56052 Mdot
.64628 .92731 Mdot
.28336 .06913 Mdot
.26419 .80219 Mdot
.15042 .82627 Mdot
.1574 .81339 Mdot
.35558 .06307 Mdot
.12759 .96636 Mdot
.07846 .49884 Mdot
.30192 .8227 Mdot
.41213 .86578 Mdot
.36045 .133 Mdot
.39334 .89002 Mdot
.12048 .90587 Mdot
.47451 .99505 Mdot
.2861 .81624 Mdot
.27431 .43164 Mdot
.33954 .84233 Mdot
.19258 .84863 Mdot
.32649 .93247 Mdot
.23695 .8522 Mdot
.0277 .43274 Mdot
.16687 .45388 Mdot
.14755 .02125 Mdot
.18033 .02827 Mdot
.58157 .32708 Mdot
.40042 .75302 Mdot
.38539 .91647 Mdot
.31629 .94304 Mdot
.34671 .79523 Mdot
.90145 .27153 Mdot
.14142 .81171 Mdot
.08876 .5582 Mdot
.32398 .76527 Mdot
.23994 .83949 Mdot
.88158 .65257 Mdot
.30965 .94135 Mdot
.15329 .85542 Mdot
.25158 .85564 Mdot
.60107 .52489 Mdot
.37074 .85232 Mdot
.25182 .84963 Mdot
.49683 .05773 Mdot
.46457 .74333 Mdot
.27848 .82666 Mdot
.39846 .86247 Mdot
.2294 .83542 Mdot
.2014 .74709 Mdot
.47802 .78882 Mdot
.9966 .39088 Mdot
.28116 .78009 Mdot
.28442 .91134 Mdot
.8542 .51195 Mdot
.22687 .78838 Mdot
.51991 .74055 Mdot
.23385 .20279 Mdot
.31181 .7903 Mdot
.24679 .83742 Mdot
.2204 .85312 Mdot
.19361 .65036 Mdot
.33398 .92537 Mdot
.69342 .42953 Mdot
.19996 .66215 Mdot
.17077 .60501 Mdot
.72228 .60089 Mdot
.61571 .19029 Mdot
.1642 .17933 Mdot
.52767 .0201 Mdot
.97078 .72036 Mdot
.63784 .55658 Mdot
.96218 .62719 Mdot
.31033 .94598 Mdot
.1642 .765 Mdot
.35083 .71149 Mdot
.24592 .83924 Mdot
.2392 .8659 Mdot
.27853 .97995 Mdot
.18738 .72488 Mdot
.28064 .94622 Mdot
.16291 .81755 Mdot
.26892 .75159 Mdot
.47151 .86377 Mdot
.10548 .02012 Mdot
.5453 .23788 Mdot
.49548 .8134 Mdot
.25016 .8573 Mdot
.91988 .2934 Mdot
.16528 .87471 Mdot
.19188 .96764 Mdot
.3612 .64587 Mdot
.33224 .86986 Mdot
.24306 .84682 Mdot
.25153 .9015 Mdot
.39619 .62046 Mdot
.16811 .70586 Mdot
.35003 .76887 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo0_l00006ooooo`?o00003Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?o
oooo1?l00006ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`02o`0000Oooooo0_l00002ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool00_ooool001kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool01_ooool2o`0000Kooooo1ol00009ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool00oooool4o`0000Kooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;o00002oooool00ol0003ooooo
ooooo`03ooooo`;o00002?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooooooo
o`0Yooooo`;o00005_ooool4o`0000Wooooo0_l0000Wooooo`;o0000;?ooool2o`000:3ooooo000N
ooooo`03o`000?oooooooooo02Wooooo0_l0000Sooooo`;o00009oooool2o`000<kooooo000Noooo
o`03o`000?oooooooooo02_ooooo0_l000000ooooooo0000o`00000Iooooo`;o0000:?ooool2o`00
00Sooooo0_l00038ooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o00003oooool2o`000003
ooooool0003o000000Sooooo0_l0000?ooooo`;o00002_ooool2o`0001cooooo0_l00008ooooo`;o
00005oooool2o`000:oooooo000Nooooo`03o`000?oooooooooo01[ooooo0_l00002ooooo`;o0000
3?ooool2o`0000[ooooo0_l0000Kooooo`;o00004Oooool2o`0002cooooo0_l0000?ooooo`;o0000
W_ooool001kooooo00?o0000ooooooooool07_ooool2o`0000cooooo0_l0000Sooooo`;o00005Ooo
ool2o`0001Oooooo0_l0000Sooooo`?o0000W_ooool001kooooo00?o0000ooooooooool0=oooool2
o`0001Sooooo0_l00006ooooo`;o00009_ooool2o`0002?ooooo0_l0002Oooooo`007_ooool00ol0
003oooooooooo`0gooooo`;o00008?ooool2o`0001gooooo0_l00013ooooo`;o0000M_ooool2o`00
013ooooo000Nooooo`03o`000?oooooooooo07Sooooo0_l00013ooooo`;o0000M_ooool2o`00013o
oooo000Nooooo`03o`000?oooooooooo03cooooo0_l0000oooooo`;o00002_ooool2o`000;cooooo
000Nooooo`03o`000?oooooooooo03cooooo0_l0000Rooooo`;o00006oooool2o`0000[ooooo0_l0
002looooo`007_ooool00ol0003oooooooooo`0Kooooo`?o0000@_ooool2o`000003ooooool0003o
000000Wooooo0_l0003Gooooo`007_ooool00ol0003oooooooooo`04ooooo`;o00002?ooool2o`00
00_ooooo0ol00015ooooo`;o00002Oooool2o`000=Oooooo000Nooooo`03o`000?oooooooooo00Co
oooo0_l00008ooooo`;o0000@oooool2o`000?;ooooo000Nooooo`;o00004Oooool2o`00047ooooo
0_l0000Cooooo`;o0000<?ooool2o`000:_ooooo000Nooooo`03o`000?oooooooooo013ooooo0_l0
000@ooooo`;o0000A?ooool2o`0001_ooooo0_l00002ooooo`;o00003oooool2o`000:_ooooo000N
ooooo`03o`000?oooooooooo02;ooooo0_l0000]ooooo`;o0000<_ooool2o`0000;ooooo0_l0000B
ooooo`;o000000?oooooo`000?l00000YOooool001kooooo00?o0000ooooooooool05oooool2o`00
02oooooo0_l00007ooooo`;o00003Oooool2o`0001Wooooo0_l0000Pooooo`;o000000?oooooo`00
0?l00000Voooool2o`0000Sooooo000Nooooo`?o00005oooool3o`0002kooooo0_l0000Fooooo`;o
00003Oooool2o`0000[ooooo0_l0002Looooo`;o00008_ooool2o`0000Sooooo000Nooooo`?o0000
6?ooool2o`0005Gooooo0_l0002Xooooo`;o0000;?ooool001kooooo00?o0000ooooooooool0F?oo
ool2o`000>gooooo000Nooooo`03o`000?oooooooooo05Sooooo0_l0003]ooooo`007_ooool00ol0
003oooooooooo`0Fooooo`;o00001Oooool2o`000003ooooool0003o000003Gooooo0_l0003^oooo
o`007_ooool00ol0003oooooooooo`0Fooooo`;o00001Oooool2o`000003ooooool0003o000003Go
oooo0_l0003^ooooo`007_ooool00ol0003oooooooooo`0iooooo`;o00004?ooool2o`0000?ooooo
0_l0000[ooooo`;o0000b?ooool001kooooo00?o0000ooooooooool0<Oooool2o`0000Kooooo0_l0
000@ooooo`;o00000oooool2o`0002_ooooo0_l0002iooooo`;o00003Oooool001kooooo00?o0000
ooooooooool08oooool2o`0000cooooo0_l0003oooooo`Kooooo0_l0000=ooooo`007_ooool00ol0
003oooooooooo`02o`0000?ooooo0_l0000Looooo`;o00007?ooool2o`000?gooooo0_l00005oooo
o`007_ooool00ol0003oooooooooo`02o`0000?ooooo0_l0000jooooo`;o00002oooool2o`0000_o
oooo0_l0003Sooooo`;o00001Oooool001gooooo0_l0001@ooooo`;o00002oooool2o`000003oooo
ool0003o0000017ooooo0_l0003Dooooo`007Oooool3o`0003kooooo0_l0000Oooooo`;o00004Ooo
ool2o`000=Cooooo000Nooooo`03o`000?oooooooooo02_ooooo0_l0000@ooooo`;o0000FOooool2
o`0005Gooooo0_l0001Fooooo`007_ooool00ol0003oooooooooo`0[ooooo`;o00001Oooool2o`00
06Cooooo0_l0000Nooooo`;o0000=Oooool2o`0005Kooooo000Nooooo`03o`000?oooooooooo03;o
oooo0_l00002ooooo`;o00003_ooool2o`00073ooooo0_l0002=ooooo`007_ooool00ol0003ooooo
ooooo`0fooooo`;o00003_ooool2o`0008;ooooo0_l0001kooooo`007_ooool00ol0003ooooooooo
o`0Wooooo`;o0000XOooool2o`0000kooooo0_l00015ooooo`;o00009?ooool001kooooo00?o0000
ooooooooool09oooool2o`000;7ooooo0_l00015ooooo`;o00009?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0;_ooool2o`00047ooooo0_l0
003Dooooo`007_ooool00ol0003oooooooooo`0^ooooo`;o0000@Oooool2o`000=Cooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0@?ooool2o`000?oooooo1_ooool001kooooo00?o0000ooooooooool0
@?ooool2o`000?oooooo1_ooool001kooooo00?o0000ooooooooool0oooooolSooooo`;o00008ooo
ool001kooooo00?o0000ooooooooool0Goooool2o`0008Gooooo0_l0000jooooo`;o00008oooool0
01kooooo00?o0000ooooooooool0Goooool2o`0008Gooooo0_l0001Oooooo`007_ooool00ol0003o
ooooooooo`3iooooo`;o0000C?ooool001kooooo00?o0000ooooooooool0nOooool2o`0001gooooo
0_l0000]ooooo`007_ooool00ol0003oooooooooo`0aooooo`;o0000iOooool2o`0002gooooo000N
ooooo`03o`000?oooooooooo037ooooo0_l0003ooooooaGooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`34ooooo`;o0000POooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0a?ooool2o`00087ooooo0003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03
o`000?oooooooooo09[ooooo0_l0002[ooooo`000oooool01Ol@413ooooooooooooooooo410@00co
oooo00?oV9RHob4Q8Oo^k^h01oooool3o`0009[ooooo0_l0002>ooooo`;o00006oooool000?ooooo
00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000oooooooo
ool0B?ooool2o`000>3ooooo0_l0000Kooooo`000oooool01Ol0003ooooooooooooooooo000000ko
oooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`18ooooo`;o0000hoooool2o`0001So
oooo0003ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo0?oooooo;_ooool2o`0001Sooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0b?ooool2o`00
07gooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0b?ooool2o`0007gooooo000Nooooo`03o`000?oooooooooo
00_ooooo0_l0002@ooooo`;o0000Z?ooool001kooooo00?o0000ooooooooool02oooool2o`00093o
oooo0_l0002Xooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`1dooooo`Co0000coooool001kooooo00?o0000ooooooooool0M?ooool4o`0003Go
oooo0_l0002Hooooo`007_ooool00ol0003oooooooooo`2]ooooo`;o00006Oooool2o`0007gooooo
000Nooooo`03o`000?oooooooooo03kooooo0_l00028ooooo`;o0000OOooool001kooooo00?o0000
ooooooooool0?_ooool2o`0006;ooooo0_l0002Sooooo`007_ooool00ol0003oooooooooo`2Roooo
o`;o0000Xoooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo04_ooooo0_l0000`ooooo`;o0000QOooool2o`00
047ooooo000Nooooo`03o`000?oooooooooo03Wooooo0_l0000@ooooo`;o0000<?ooool2o`0008Go
oooo0_l00011ooooo`007_ooool00ol0003oooooooooo`0iooooo`;o0000h_ooool2o`0000;ooooo
0_l0000Tooooo`007_ooool00ol0003oooooooooo`2Tooooo`;o0000Moooool2o`0000;ooooo0_l0
000Tooooo`007_ooool00ol0003oooooooooo`1Cooooo`;o0000Coooool2o`000:7ooooo000Noooo
o`03o`000?oooooooooo05?ooooo0_l00004ooooo`;o0000k?ooool001kooooo00?o0000oooooooo
ool0FOooool2o`0004kooooo0_l0000Uooooo`;o0000MOooool001kooooo00?o0000ooooooooool0
ZOooool2o`0002Gooooo0_l0001eooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo00;o0000oooooolVooooo`;o00007_ooool001kooooo00?o0000oooo
ooooool00_l0003oooooobKooooo0_l0000Nooooo`007_ooool00ol0003oooooooooo`2Looooo`;o
00005Oooool2o`0009;ooooo000Nooooo`;o0000WOooool2o`0001Gooooo0_l0000Cooooo`;o0000
OOooool001kooooo00?o0000ooooooooool0b?ooool2o`0007gooooo000Nooooo`03o`000?oooooo
oooo0:oooooo0_l0002Fooooo`007_ooool00ol0003oooooooooo`2_ooooo`;o0000Poooool2o`00
017ooooo000Nooooo`03o`000?oooooooooo0;?ooooo0_l0001Wooooo`;o00005_ooool2o`00017o
oooo000Nooooo`03o`000?oooooooooo0;?ooooo0_l0001Wooooo`;o0000:Oooool001kooooo00?o
0000ooooooooool0@_ooool2o`0004cooooo0_l0002eooooo`007_ooool00ol0003oooooooooo`12
ooooo`;o0000C?ooool2o`000;Gooooo000Nooooo`03o`000?oooooooooo02gooooo0_l0002:oooo
o`;o0000S?ooool001kooooo00?o0000ooooooooool0;Oooool2o`0008[ooooo0_l0001Nooooo`;o
0000;?ooool001kooooo00?o0000ooooooooool0oooooolJooooo`Co0000:_ooool001kooooo00?o
0000ooooooooool0_?ooool2o`000003ooooool0003o000005[ooooo1?l0000Xooooo`007_ooool0
0ol0003oooooooooo`0^ooooo`;o0000S?ooool2o`000003ooooool0003o000005cooooo0_l0000X
ooooo`007_ooool00ol0003oooooooooo`0^ooooo`;o0000F_ooool2o`000;_ooooo000Nooooo`03
o`000?oooooooooo08[ooooo0_l0002kooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo00kooooo0_l0
002Rooooo`;o0000Goooool2o`0003;ooooo000Nooooo`03o`000?oooooooooo00kooooo0_l00019
ooooo`;o0000Eoooool2o`0002oooooo0_l0000^ooooo`;o0000<_ooool001kooooo00?o0000oooo
ooooool0FOooool2o`0008Sooooo0_l0000]ooooo`;o0000<oooool001kooooo00?o0000oooooooo
ool0WOooool2o`0007?ooooo0_l0000cooooo`007_ooool00ol0003oooooooooo`2Mooooo`;o0000
L?ooool2o`0003Kooooo000Nooooo`03o`000?oooooooooo0?oooooo4?ooool2o`0003Kooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0XOooool2o`00
0:Cooooo000Nooooo`03o`000?oooooooooo08oooooo0_l0000@ooooo`;o00009_ooool2o`0007Go
oooo0_l00005ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o
000000?o410@ooooooooool01?ooool00ol0003oooooooooo`2?ooooo`;o00002Oooool2o`00017o
oooo0_l0000Jooooo`;o0000MOooool2o`0000Gooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0kooooo`;o
00003oooool2o`0004cooooo0_l0000Aooooo`;o0000V?ooool000?ooooo00Go410@oooooooooooo
oooooa0@400;ooooo`Go00001_ooool3o`0003_ooooo0_l0000?ooooo`;o0000nOooool000?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000oooo
ooooool04_ooool2o`000?oooooo=?ooool000?ooooo00Go0000ooooooooooooooooo`00000;oooo
o`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool04_ooool2o`0000Wooooo0_l0000=
ooooo`;o0000oooooolJooooo`000oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMg
olc<c?l000001oooool00ol0003oooooooooo`0Mooooo`;o00003Oooool2o`000?oooooo6_ooool0
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000
ooooooooool0N?ooool2o`000<gooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool0
0omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo07Sooooo0_l0003=ooooo`007_ooool00ol0
003oooooooooo`36ooooo`;o0000Ooooool001kooooo00?o0000ooooooooool0a_ooool2o`0007oo
oooo000Nooooo`03o`000?oooooooooo04kooooo0_l0003gooooo`007_ooool00ol0003ooooooooo
o`1>ooooo`;o0000moooool001kooooo00?o0000ooooooooool0EOooool2o`0008Kooooo0_l0001X
ooooo`007_ooool00ol0003oooooooooo`05ooooo`;o0000C_ooool2o`0008Kooooo0_l0000[oooo
o`;o0000>oooool001kooooo00?o0000ooooooooool01Oooool2o`0002Kooooo0_l0000/ooooo`;o
0000[Oooool2o`0003_ooooo000Nooooo`03o`000?oooooooooo02gooooo0_l0000/ooooo`;o0000
j_ooool001kooooo00?o0000ooooooooool0_oooool2o`0008Kooooo000Nooooo`03o`000?oooooo
oooo06_ooooo0_l0001Booooo`;o0000Q_ooool001kooooo00?o0000ooooooooool0Joooool2o`00
05[ooooo0_l0001nooooo`007_ooool2o`000<Sooooo0_l0001nooooo`007_ooool00ol0003ooooo
ooooo`0Fooooo`;o00006_ooool2o`000?oooooo5?ooool001kooooo00?o0000ooooooooool05_oo
ool2o`0001[ooooo0_l0003ooooooaCooooo000Nooooo`03o`000?oooooooooo0<7ooooo0_l00002
ooooo`;o0000P?ooool001kooooo00?o0000ooooooooool0[Oooool2o`0001;ooooo0_l00002oooo
o`;o0000P?ooool001kooooo00?o0000ooooooooool06Oooool2o`0009;ooooo0_l0002Hooooo`00
7_ooool00ol0003oooooooooo`0Iooooo`;o0000ooooool]ooooo`007_ooool00ol0003ooooooooo
o`02ooooo`;o0000oooooom4ooooo`007_ooool00ol0003oooooooooo`02ooooo`;o0000oooooom4
ooooo`007_ooool00ol0003oooooooooo`09ooooo`;o0000oooooolmooooo`007_ooool00ol0003o
ooooooooo`09ooooo`;o0000oooooolmooooo`007_ooool00ol0003oooooooooo`1_ooooo`;o0000
Loooool2o`00067ooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0001Qooooo`;o00001ooo
ool2o`0007?ooooo0_l0000looooo`;o00005?ooool2o`0000gooooo000Nooooo`03o`000?oooooo
oooo00;ooooo0ol0001Qooooo`;o0000^_ooool2o`0001Cooooo0_l0000=ooooo`007_ooool00ol0
003oooooooooo`02ooooo`;o0000oooooolLooooo`;o00000oooool2o`00027ooooo000Nooooo`03
o`000?oooooooooo01Gooooo0_l0000booooo`;o0000e?ooool2o`0000?ooooo0_l0000Qooooo`00
7_ooool2o`0001Kooooo0_l0000booooo`;o0000/_ooool2o`0004Sooooo000Nooooo`03o`000?oo
oooooooo01cooooo0_l00038ooooo`;o00005Oooool2o`0004Sooooo000Nooooo`03o`000?oooooo
oooo00?ooooo0_l0000Gooooo`;o0000]oooool2o`0000oooooo0_l0001Oooooo`007_ooool00ol0
003oooooooooo`03ooooo`;o00003Oooool2o`000:gooooo0_l0000Booooo`;o0000>oooool2o`00
02cooooo0_l00005ooooo`007_ooool00ol0003oooooooooo`0Booooo`;o0000[Oooool2o`0004oo
oooo0_l0000/ooooo`;o00001Oooool001kooooo00?o0000ooooooooool05oooool2o`000?oooooo
;oooool001kooooo00?o0000ooooooooool05oooool2o`000?oooooo;oooool001kooooo00?o0000
ooooooooool0oooooom0ooooo`;o00001_ooool001kooooo00?o0000ooooooooool0_oooool2o`00
01oooooo1?l0001Kooooo`;o00001_ooool001kooooo00?o0000ooooooooool0_oooool2o`0001oo
oooo1?l0000^ooooo`;o0000<oooool001kooooo00?o0000ooooooooool0QOooool2o`0000;ooooo
0_l0001Dooooo`;o0000<Oooool2o`0003?ooooo000Nooooo`03o`000?oooooooooo08Gooooo0_l0
0002ooooo`;o0000E?ooool2o`00043ooooo0_l0000Tooooo`007_ooool00ol0003oooooooooo`3o
ooooob;ooooo0_l0000Tooooo`007_ooool00ol0003oooooooooo`3oooooobSooooo0_l0000Noooo
o`007_ooool00ol0003oooooooooo`2^ooooo`;o0000Moooool2o`0001kooooo000Nooooo`03o`00
0?oooooooooo0:Sooooo0_l00004ooooo`;o0000Uoooool001kooooo0_l0002Yooooo`;o0000WOoo
ool001kooooo00?o0000ooooooooool0oooooolfooooo`;o00004?ooool001kooooo00?o0000oooo
ooooool0boooool2o`0006Sooooo0_l00005ooooo`;o00002Oooool001kooooo00?o0000oooooooo
ool06Oooool2o`0009;ooooo0_l0000Looooo`;o00006oooool2o`0005;ooooo0_l00009ooooo`00
7_ooool00ol0003oooooooooo`0Iooooo`;o0000T_ooool2o`0000[ooooo0_l0000]ooooo`;o0000
GOooool001kooooo0_l0002jooooo`;o00003_ooool2o`0006Sooooo0_l0000Booooo`007_ooool2
o`000<[ooooo0_l0001Xooooo`;o00002?ooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo
0?oooooo?_ooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo07Oooooo0_l0001>ooooo`;o
0000Hoooool2o`0001Wooooo000Nooooo`03o`000?oooooooooo00Gooooo0_l0001`ooooo`;o0000
5?ooool2o`0003Sooooo0_l0001Pooooo`;o000000?oooooo`000?l000000_l0000Gooooo`007_oo
ool00ol0003oooooooooo`05ooooo`;o0000Q_ooool2o`0009[ooooo0_l00003ooooo`;o00005ooo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`20oooo
o`;o0000aOooool001kooooo00?o0000ooooooooool0P?ooool2o`0002Kooooo0_l0000Aooooo`;o
0000R_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko
<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0YOooool2o`000003ooooool0003o0000
017ooooo0_l0002:ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0Booooo`;o00007Oooool5
o`0006oooooo0_l0002Pooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`000006ooooo`?o00003Oooool2o`0000?ooooo0_l0000Mooooo`Go0000K_oo
ool2o`00047ooooo0_l0001Nooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go
0000oiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo00gooooo0_l0000Sooooo`Co0000
<oooool2o`0003Wooooo0_l00011ooooo`;o0000G_ooool000?ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0cooooo`?o
0000<oooool2o`0005Sooooo0_l00022ooooo`000oooool01Ol@413ooooooooooooooooo410@00_o
oooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`0cooooo`;o00001_ooool2o`000003
ooooool0003o000008?ooooo0_l00022ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0`ooooo`;o00002Oooool2o`000003
ooooool0003o00000?oooooo2?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04
olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0:oooool2o`0000?ooooo0_l0002/oooo
o`;o0000Ioooool001kooooo00?o0000ooooooooool0:oooool2o`0000?ooooo0_l0002/ooooo`;o
0000Ioooool001kooooo00?o0000ooooooooool06?ooool2o`0001Kooooo0ol0001:ooooo`;o0000
H_ooool2o`0006Cooooo000Nooooo`03o`000?oooooooooo01Sooooo0_l0000Fooooo`?o0000A?oo
ool2o`0000Cooooo0_l0000?ooooo`Co0000Coooool2o`0006Cooooo000Nooooo`03o`000?oooooo
oooo033ooooo0_l0000looooo`;o00001oooool2o`0001Gooooo1?l0002@ooooo`;o00004Oooool2
o`00013ooooo000Nooooo`03o`000?oooooooooo02gooooo0_l0000=ooooo`;o00000_ooool2o`00
02cooooo0_l00006ooooo`;o0000Z_ooool2o`00017ooooo0_l0000@ooooo`007_ooool00ol0003o
ooooooooo`0]ooooo`;o00003Oooool2o`0000;ooooo0_l00002ooooo`;o0000<?ooool2o`000;go
oooo0_l00003ooooo`;o00002oooool001kooooo00?o0000ooooooooool0A?ooool2o`0004kooooo
0_l0002Tooooo`;o00002oooool001kooooo00?o0000ooooooooool0U?ooool2o`000;7ooooo000N
ooooo`03o`000?oooooooooo043ooooo0_l0001=ooooo`;o0000]_ooool001kooooo00?o0000oooo
ooooool0@?ooool2o`0002gooooo1?l0000Looooo`;o0000]_ooool001kooooo00?o0000oooooooo
ool0<Oooool2o`0000Sooooo0_l00009ooooo`;o00009oooool4o`000;Kooooo0_l0000Looooo`00
7_ooool2o`0003;ooooo1?l00006ooooo`;o00002Oooool2o`000=;ooooo0_l0000=ooooo`;o0000
7?ooool001kooooo00Co0000oooooooooooooooo0_l0000_ooooo`?o0000=oooool2o`000:cooooo
0_l00002ooooo`;o00009oooool001kooooo00Co0000oooooooooooooooo0_l0001Yooooo`;o0000
F_ooool2o`0005Cooooo0_l0000Wooooo`007_ooool00ol0003oooooooooo`0eooooo`Co00001?oo
ool2o`0000;ooooo0_l0000Nooooo`;o00001_ooool4o`0005_ooooo0_l0001mooooo`007_ooool0
0ol0003oooooooooo`0_ooooo`;o00001?ooool4o`0000Cooooo0_l00002ooooo`;o00007_ooool2
o`0000Kooooo1?l0000Kooooo`;o0000_Oooool001kooooo00?o0000ooooooooool0;oooool2o`00
05Oooooo0_l0002Uooooo`;o00005_ooool001kooooo00?o0000ooooooooool00oooool2o`0006go
oooo0_l0002kooooo`;o00005_ooool001kooooo00?o0000ooooooooool00oooool2o`0006gooooo
0_l0000;ooooo`;o0000@?ooool2o`0008Cooooo000Nooooo`03o`000?oooooooooo03Oooooo0_l0
000iooooo`;o00002oooool2o`0000Cooooo0_l0000jooooo`;o0000NOooool2o`0000Wooooo000N
ooooo`04o`000?oooooo0000o`00037ooooo0_l00003ooooo`;o00004oooool2o`0003Oooooo0_l0
002/ooooo`;o00001oooool2o`0000Wooooo000Nooooo`04o`000?oooooo0000o`00037ooooo0_l0
0008ooooo`;o00003_ooool2o`000:?ooooo0_l00010ooooo`;o00004_ooool001kooooo00?o0000
ooooooooool0??ooool2o`000003ooooool0003o000002?ooooo0_l0000]ooooo`;o0000@oooool2
o`0001Oooooo0_l0001Dooooo`007_ooool00ol0003oooooooooo`0oooooo`;o00006Oooool2o`00
00Sooooo0_l0000]ooooo`;o0000@oooool2o`0006gooooo000Nooooo`03o`000?oooooooooo04Oo
oooo0_l0000Aooooo`;o0000:?ooool2o`0005Kooooo0_l0001Yooooo`007_ooool00ol0003ooooo
ooooo`17ooooo`;o00004Oooool2o`0002Sooooo0_l0001Fooooo`;o0000JOooool001kooooo00?o
0000ooooooooool0F_ooool2o`0006kooooo0_l0001kooooo`007_ooool2o`0005_ooooo0_l0001^
ooooo`;o0000Noooool001kooooo00?o0000ooooooooool08?ooool2o`0001Wooooo0_l0000Boooo
o`;o00002?ooool2o`0001?ooooo0_l0003Gooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o
00004Oooool2o`0000Wooooo0_l00006ooooo`;o00001_ooool2o`0001;ooooo0_l00008ooooo`;o
00003oooool2o`0000;ooooo0_l0002Cooooo`;o0000@_ooool001kooooo00?o0000ooooooooool0
3Oooool2o`0001cooooo0_l00006ooooo`;o00003?ooool2o`0002Oooooo0_l00002ooooo`;o0000
5oooool2o`0000_ooooo0_l0000[ooooo`;o0000@?ooool2o`0004;ooooo000Nooooo`03o`000?oo
oooooooo03Oooooo0_l00008ooooo`;o00004_ooool2o`0001Oooooo0_l0000Gooooo`;o00001?oo
ool2o`0000Gooooo0_l0000[ooooo`;o0000H_ooool2o`00023ooooo000Nooooo`03o`000?oooooo
oooo03Oooooo0_l0000Looooo`;o0000=_ooool2o`0002Sooooo0_l0001/ooooo`;o00008?ooool0
01kooooo0ol00009ooooo`;o00001?ooool2o`000:Kooooo0_l0001oooooo`;o00003Oooool001ko
oooo0ol00009ooooo`;o00001?ooool2o`0002Wooooo0_l0001<ooooo`;o00002Oooool2o`000:?o
oooo0_l00003ooooo`;o00002?ooool001kooooo00?o0000ooooooooool0>Oooool3o`0004cooooo
0_l00009ooooo`;o0000UOooool2o`00017ooooo0_l00008ooooo`007_ooool2o`0003Sooooo1?l0
001Cooooo`;o00001oooool2o`00097ooooo0_l0000;ooooo`;o00003_ooool001kooooo0_l0000;
ooooo`;o00002_ooool2o`0001oooooo0_l0001Eooooo`;o00001oooool2o`0009kooooo0_l0000>
ooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o00002_ooool2o`0009_ooooo0_l00020oooo
o`;o00004?ooool001kooooo00?o0000ooooooooool0>oooool2o`0001Cooooo0_l0000iooooo`;o
00009Oooool2o`0007;ooooo0_l0000<ooooo`;o00004?ooool001gooooo0_l0000Looooo`;o0000
7oooool2o`0001Cooooo0_l000000ooooooo0000o`00000eooooo`?o00002_ooool2o`0000_ooooo
0_l00020ooooo`;o00007_ooool001gooooo0_l0000Looooo`;o00009Oooool2o`00017ooooo0_l0
000eooooo`;o00001_ooool2o`0000?ooooo0_l00006ooooo`;o00000oooool2o`000:3ooooo000N
ooooo`03o`000?oooooooooo03gooooo0_l00002ooooo`;o00003_ooool2o`0000;ooooo1?l0000j
ooooo`;o00002oooool4o`0004Gooooo0_l0001:ooooo`;o00004?ooool001kooooo0_l0000Roooo
o`;o00006_ooool2o`0001;ooooo2?l00016ooooo`;o000000?oooooo`000?l00000AOooool2o`00
04[ooooo0_l00005ooooo`;o00002Oooool001kooooo00?o0000ooooooooool08Oooool2o`0001;o
oooo0_l0000Aooooo`;o00002Oooool4o`0002Oooooo0_l0000Dooooo`;o00002Oooool2o`0009_o
oooo1?l00007ooooo`007_ooool00ol0003oooooooooo`0eooooo`;o00000oooool2o`0000cooooo
0_l0000;ooooo`;o000000?oooooo`000?l000002_ooool2o`0001Sooooo0_l0000Dooooo`;o0000
00?oooooo`000?l00000YOooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo03Gooooo0_l0
0003ooooo`;o00000_ooool2o`0001Sooooo0_l0000:ooooo`;o00006oooool2o`0001Cooooo0_l0
000;ooooo`;o0000XOooool001kooooo00?o0000ooooooooool0:Oooool2o`0001?ooooo0_l0000T
ooooo`;o00006oooool2o`0001Cooooo0_l0000;ooooo`;o0000XOooool001kooooo00?o0000oooo
ooooool0:Oooool2o`0000Kooooo1?l00004ooooo`;o0000:_ooool2o`00033ooooo0_l0002^oooo
o`007_ooool00ol0003oooooooooo`0aooooo`Co00001?ooool2o`0000[ooooo0ol0000Hooooo`;o
00000oooool2o`0000Oooooo0_l0000Looooo`;o0000[_ooool2o`0000Wooooo000Nooooo`03o`00
0?oooooo000000?o00001Oooool2o`0003_ooooo0ol00009ooooo`;o00003Oooool2o`0000cooooo
0_l0000Looooo`;o0000[_ooool2o`0000Wooooo000Nooooo`03o`000?oooooo000000?o00001Ooo
ool2o`0004Oooooo0_l00007ooooo`;o00006?ooool2o`0001Cooooo0_l0002kooooo`007_ooool0
0ol0003oooooooooo`1Jooooo`;o00002Oooool2o`0000Cooooo0_l00004ooooo`;o000000?ooooo
o`000?l000005?ooool2o`0005;ooooo0_l0001Wooooo`007_ooool00ol0003oooooooooo`0Qoooo
o`;o0000=?ooool2o`0000cooooo0_l00004ooooo`;o00001?ooool2o`0006_ooooo0_l0000Toooo
o`;o0000@Oooool001kooooo00?o0000ooooooooool02oooool2o`0000[ooooo0_l00008ooooo`;o
00008Oooool2o`0000cooooo0_l00003ooooo`;o00001oooool2o`0000Gooooo0_l00002ooooo`;o
00001Oooool2o`00093ooooo0_l00011ooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o0000
2_ooool2o`0002_ooooo1?l0000:ooooo`;o00001oooool2o`0000?ooooo0_l00004ooooo`?o0000
0_ooool2o`0000Gooooo0_l0000Sooooo`;o0000[_ooool001kooooo00?o0000ooooooooool0<_oo
ool2o`0000Wooooo0_l00007ooooo`;o00003?ooool2o`0000Gooooo0_l00004ooooo`;o000000?o
ooooo`000?l000000_l00008ooooo`;o00008oooool4o`000:Cooooo0_l00008ooooo`000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0
1_ooool00ol0003oooooooooo`0booooo`;o00002Oooool4o`0001?ooooo0_l0000;ooooo`;o0000
00?oooooo`000?l000000_l000000ooooooo0000o`000004o`000003ooooool0003o000000Co0000
7oooool2o`0000_ooooo0_l0002Iooooo`;o00002?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000oooooooo
ool09_ooool2o`0001Oooooo0_l0000Booooo`;o00003_ooool3o`0000;ooooo2?l000000ooooooo
0000o`000003o`0002cooooo0_l0000mooooo`;o0000I?ooool000?ooooo00Go410@oooooooooooo
oooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`0002Cooooo1?l000000ooo
oooo0000o`00000Xooooo`;o00000oooool2o`0000Wooooo2Ol000001Ooooooo0000o`000?l0003o
oooo00Co00007_ooool2o`0004cooooo0_l0001Tooooo`000oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooooooo02Cooooo0_l0
0003ooooo`;o00003_ooool2o`00017ooooo0_l00004ooooo`?o00000oooool2o`0000_ooooo1ol0
0002ooooo`;o00008oooool2o`000;;ooooo0003ooooo`05o`000?ooooooooooooooool000002ooo
ool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool08_ooool2o`0000?ooooo
1?l0000>ooooo`;o00001_ooool2o`0000Wooooo0_l00004ooooo`;o00003Oooool2o`0000?ooooo
0_l000000ooooooo0000o`000002ooooo`;o00001Oooool2o`000=7ooooo0003ooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000oooooooo
ool08_ooool2o`0000;ooooo1?l00002ooooo`;o00004oooool2o`0001kooooo0_l00006ooooo`;o
00000_ooool2o`0000Gooooo0_l00002ooooo`;o0000cOooool000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`0Uoooo
o`Co000000?oooooo`000?l000000_l000000ooooooo0000o`00000[ooooo`;o00000_ooool2o`00
0003ooooool0003o000000gooooo0_l00003ooooo`?o00005oooool2o`0000;ooooo0ol00005oooo
o`;o0000Z?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000
oa0@4?nYZJT01_ooool00ol0003oooooooooo`0Uooooo`Oo00000oooool2o`00017ooooo0_l0000E
ooooo`;o000000Coooooo`000?l0003ooooo0ol000000ooooooo0000o`00000=ooooo`;o00000ooo
ool2o`0001Sooooo0_l00002ooooo`?o00001Oooool2o`000:Sooooo000Nooooo`03o`000?oooooo
oooo01oooooo0_l00004ooooo`;o000000?oooooo`000?l000001Ol00002ooooo`;o00001_ooool2
o`0000Gooooo1?l0000Eooooo`?o00000oooool2o`00033ooooo0_l0002Oooooo`;o00004oooool0
01kooooo00?o0000ooooooooool07oooool2o`0000_ooooo2?l00005ooooo`;o00001Oooool2o`00
00Sooooo0_l0000;ooooo`;o000000?oooooo`000?l000005Oooool2o`000;oooooo0_l0000Coooo
o`007_ooool00ol0003oooooooooo`0Pooooo`;o00003Oooool5o`000003ooooool0003o000000Co
oooo0_l0000=ooooo`;o00002Oooool5o`0000Cooooo0_l0000:ooooo`;o00000oooool4o`000=Co
oooo000Nooooo`03o`000?oooooooooo023ooooo0_l0000;ooooo`?o000000?oooooo`000?l00000
0_ooool2o`0000Cooooo0_l0000Hooooo`Go00001?ooool4o`0000Gooooo0_l000000ooooooo0000
o`000003ooooo`;o0000e_ooool001kooooo00?o0000ooooooooool07oooool2o`0000Cooooo0_l0
0006ooooo`?o000000?oooooo`000?l000008oooool2o`0000Sooooo0_l00005ooooo`;o00003Ooo
ool2o`0000Cooooo0_l00039ooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o00001?ooool2
o`0001?ooooo0_l0000@ooooo`Co00001_ooool2o`0000Sooooo0_l0000=ooooo`;o00001Oooool2
o`0000Cooooo0_l00039ooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o00002?ooool2o`00
01kooooo0_l00004ooooo`;o00002_ooool4o`0000;ooooo1Ol00005ooooo`;o00001oooool2o`00
00kooooo0_l00004ooooo`;o0000d?ooool001kooooo00?o0000ooooooooool02_ooool2o`0000So
oooo0_l0000Looooo`Co00001Oooool2o`0000Wooooo2ol00002ooooo`;o00002_ooool2o`0000Ko
oooo0_l00006ooooo`;o00001?ooool2o`0000_ooooo0_l00033ooooo`007_ooool00ol0003ooooo
ooooo`0booooo`;o00001oooool2o`0000[ooooo2Ol00003ooooo`;o00004_ooool5o`0001Kooooo
0_l00033ooooo`007_ooool00ol0003oooooooooo`0booooo`?o00001Oooool2o`0000Gooooo1?l0
00001Ooooooo0000o`000?l0003ooooo00So000000?oooooo`000?l000001_ooool2o`0000Cooooo
0_l00006ooooo`?o00001?ooool2o`0000oooooo0_l00034ooooo`007_ooool00ol0003ooooooooo
o`0Tooooo`;o00003Oooool2o`0000?ooooo1?l00005oooooaGo00001Oooool2o`0000Cooooo0_l0
000=ooooo`;o00003oooool2o`000<Cooooo000Nooooo`;o00009Oooool2o`0000gooooo0_l00002
ooooo`Go00000_ooool2o`0000?ooooo4?l000000ooooooo0000o`00000Fooooo`;o00001_ooool2
o`000=7ooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l00008ooooo`;o00001Oooool4o`00
0003ooooool0003o000000;ooooo0_l00003ooooo`?o000000?oooooo`000?l000001ol000000ooo
oooo0000o`000004o`0001?ooooo1?l00006ooooo`;o0000dOooool001kooooo00?o0000oooooooo
ool0;_ooool2o`0000Gooooo2ol0000:ooooo`Ko000000?oooooo`000?l000001?l0000?ooooo`;o
000000Coooooo`000?l0003o00009oooool2o`000;;ooooo000Nooooo`03o`000?oooooooooo03Go
oooo1_l000001?oooooo0000o`000?l0000=ooooo`?o000000?oooooo`000?l000001oooool2o`00
00_ooooo0_l000000ooooooo0000o`00000Booooo`;o00005?ooool4o`000;3ooooo000Nooooo`03
o`000?oooooooooo03;ooooo0_l000000ooooooo0000o`000004o`0000gooooo0_l00002ooooo`;o
00000_ooool2o`0000Oooooo0ol0000Aooooo`;o00003_ooool2o`0000Oooooo0_l0000;ooooo`Co
0000/?ooool001kooooo00?o0000ooooooooool0<_ooool2o`0000;ooooo0_l0000@ooooo`Co0000
3_ooool3o`0000Gooooo0_l00007ooooo`Co00004oooool2o`0000;ooooo0_l0000;ooooo`Co0000
/?ooool001kooooo00?o0000ooooooooool0<_ooool6o`000003ooooool0003o000000;o00000ooo
ool2o`0000;ooooo0_l00002ooooo`Co00001?ooool2o`0000Wooooo0_l00005ooooo`;o00001?oo
ool2o`000003ooooool0003o000001Gooooo0_l00002ooooo`;o00004_ooool2o`000:_ooooo000N
ooooo`03o`000?oooooooooo033ooooo1ol00002ooooo`Ko000000?oooooo`000?l000000_ooool2
o`0000?ooooo0_l00005ooooo`;o00001oooool2o`0000gooooo0_l0000Hooooo`;o00000_ooool2
o`0001;ooooo0_l0002[ooooo`007_ooool00ol0003oooooooooo`09ooooo`;o00009Oooool4o`00
00Kooooo1Ol0000:ooooo`Co00003?ooool6o`0001?ooooo0_l0000>ooooo`;o0000`oooool001ko
oooo00?o0000ooooooooool02Oooool2o`0002[ooooo0_l00003ooooo`?o00000_ooool2o`0000Ko
oooo0ol000000ooooooo0000o`000002ooooo`;o00002_ooool4o`0000Wooooo0_l00007ooooo`?o
0000;?ooool2o`000:Gooooo000Nooooo`03o`000?oooooooooo03Gooooo1?l00006ooooo`;o0000
1_ooool3o`000003ooooool0003o000000;ooooo0_l0000Eooooo`Co00001oooool3o`0000_ooooo
0_l0000Oooooo`;o0000YOooool001kooooo00?o0000ooooooooool0=oooool2o`000003ooooool0
003o000000?ooooo0_l0000:ooooo`;o00006Oooool2o`0000Oooooo1?l0000<ooooo`;o0000^Ooo
ool2o`0000_ooooo000Nooooo`03o`000?oooooooooo02gooooo0_l0000;ooooo`;o000000?ooooo
o`000?l000000ol00006ooooo`;o00001oooool2o`0001cooooo1?l00009ooooo`;o0000_?ooool2
o`0000_ooooo000Nooooo`03o`000?oooooooooo02gooooo0_l0000:ooooo`;o00000_ooool2o`00
0005ooooool0003o0000o`000?ooool00_l000000ooooooo0000o`000003o`0000Gooooo0_l00007
ooooo`;o00006_ooool2o`0000Cooooo0_l0000;ooooo`;o0000_?ooool001kooooo00?o0000oooo
ooooool06oooool2o`0001;ooooo0_l00008ooooo`;o00001_ooool2o`000004ooooool0003o0000
ooooo`Go00000_ooool2o`0000[ooooo1?l0000Hooooo`?o00004?ooool3o`0000Cooooo0_l0002e
ooooo`007_ooool00ol0003oooooooooo`0Kooooo`;o00004_ooool2o`0000kooooo1?l00004oooo
o`Co00000oooool2o`0000cooooo0_l000000ooooooo0000o`00000Fooooo`;o00004Oooool2o`00
00Cooooo0_l0002eooooo`007_ooool2o`00043ooooo0_l0000=ooooo`Co00002?ooool4o`000003
ooooool0003o000000;o00005?ooool2o`0000Sooooo0_l00034ooooo`007_ooool00ol0003ooooo
ooooo`17ooooo`;o00001Oooool4o`0000?ooooo0_l00003ooooo`;o00001?ooool3o`0000Kooooo
0_l0000@ooooo`;o00001?ooool2o`000<Cooooo000Nooooo`03o`000?oooooooooo02?ooooo0_l0
000Rooooo`?o000000?oooooo`000?l000000oooool2o`0000?ooooo0_l00002ooooo`;o00000_oo
ool2o`000004ooooool0003o0000o`0000Kooooo0_l0000@ooooo`;o000000?oooooo`000?l00000
;oooool2o`0009Kooooo000Nooooo`03o`000?oooooooooo02?ooooo0_l0000Rooooo`?o000000?o
ooooo`000?l000001oooool2o`0000;ooooo0ol00002ooooo`;o000000?oooooo`000?l000000ooo
ool2o`000003ooooool0003o0000013ooooo0_l00002ooooo`;o00000_ooool2o`0002;ooooo0_l0
0007ooooo`;o0000U_ooool001kooooo00?o0000ooooooooool0;?ooool2o`0001[ooooo0_l00004
ooooo`;o00001?ooool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000000oooool2
o`000003ooooool0003o0000013ooooo0_l00006ooooo`;o00008_ooool2o`0009oooooo000Noooo
o`03o`000?oooooooooo02cooooo0_l0000Gooooo`;o00001oooool2o`0000gooooo1?l00002oooo
o`;o00005?ooool2o`000003ooooool0003o00000<Wooooo000Nooooo`03o`000?oooooooooo02ko
oooo0_l00007ooooo`;o00003?ooool2o`0000Oooooo0_l0000?ooooo`;o00000_ooool2o`0001Co
oooo0_l000000ooooooo0000o`000039ooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o0000
5?ooool2o`0000Oooooo0_l0000Fooooo`;o00003oooool2o`0000;ooooo1?l0003Oooooo`007_oo
ool00ol0003oooooooooo`0Hooooo`;o0000=Oooool2o`0000oooooo0_l00002ooooo`Ko0000gOoo
ool001kooooo00?o0000ooooooooool0B_ooool2o`0001Oooooo1ol0001Tooooo`;o0000Moooool0
01kooooo00?o0000ooooooooool0<oooool2o`0000cooooo0_l00002ooooo`;o00000oooool3o`00
00cooooo0_l00008ooooo`Ko00002?ooool2o`0002Gooooo0_l0000dooooo`;o0000Moooool001ko
oooo00?o0000ooooooooool0:_ooool2o`0000Oooooo0_l0000<ooooo`;o00000_ooool2o`0000;o
oooo1_l0000:ooooo`;o00002Oooool4o`0000Cooooo1?l000000ooooooo0000o`000005ooooo`;o
00000_ooool2o`0001[ooooo0_l0000Tooooo`;o0000Qoooool001kooooo00?o0000ooooooooool0
:_ooool2o`0000Sooooo0_l00004ooooo`;o00002?ooool3o`0000;ooooo0ol000000ooooooo0000
o`00000=ooooo`;o00001?ooool6o`0000Cooooo1?l00008ooooo`;o00000_ooool2o`0001_ooooo
0_l0000Sooooo`;o0000Qoooool001kooooo00?o0000ooooooooool0=?ooool2o`0000Cooooo0_l0
0008ooooo`Co00000_ooool2o`0000Gooooo1?l00007ooooo`;o00000oooool5o`0003?ooooo0_l0
002/ooooo`007_ooool00ol0003oooooooooo`16ooooo`;o00002Oooool4o`0000cooooo1?l0000d
ooooo`;o00002Oooool2o`0002_ooooo0_l0001dooooo`007_ooool00ol0003oooooooooo`1Goooo
o`;o00002?ooool4o`0001Cooooo0_l0000Nooooo`;o00002Oooool2o`0001cooooo0_l0000=oooo
o`;o0000M?ooool001kooooo0_l0001Cooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`Co
00005Oooool2o`0000Cooooo0_l00011ooooo`;o0000Poooool001kooooo00?o0000ooooooooool0
COooool2o`0000?ooooo0ol00006ooooo`;o000000?oooooo`000?l000001?l00003ooooo`;o0000
5_ooool2o`000<Kooooo000Nooooo`03o`000?oooooooooo017ooooo0_l0000jooooo`Co00000_oo
ool2o`0000Cooooo0_l00003ooooo`Co00001Oooool2o`0003Kooooo0_l0002Cooooo`;o00004Ooo
ool001kooooo00?o0000ooooooooool04Oooool2o`0003cooooo0_l00008ooooo`?o00000_ooool4
o`0000cooooo0_l0000Zooooo`;o00000_ooool3o`0009?ooooo0_l0000Aooooo`007_ooool00ol0
003oooooooooo`16ooooo`;o00004_ooool5o`000003ooooool0003o000000;ooooo0_l00008oooo
o`;o00005oooool2o`00017ooooo0_l00002ooooo`;o00000_ooool2o`000:?ooooo000Nooooo`03
o`000?oooooooooo00gooooo0_l0000Fooooo`;o00007oooool2o`0000gooooo0_l00004ooooo`Co
000000?oooooo`000?l000000_ooool2o`00027ooooo0_l0000Hooooo`?o0000Xoooool001kooooo
00?o0000ooooooooool03Oooool2o`0001Kooooo0_l0000Cooooo`;o00006Oooool2o`000003oooo
ool0003o000002Cooooo0_l0000Qooooo`;o0000Y?ooool001kooooo00?o0000ooooooooool0>_oo
ool2o`0000kooooo0_l0000<ooooo`;o00001?ooool2o`0001Oooooo0ol00004ooooo`;o0000aooo
ool001kooooo00?o0000ooooooooool0=oooool2o`00017ooooo0_l0000:ooooo`?o00001?ooool3
o`0000;ooooo0ol00003ooooo`Co000000?oooooo`000?l000001oooool4o`000<gooooo000Noooo
o`03o`000?oooooooooo03Oooooo0_l0000Aooooo`;o00002_ooool6o`000003ooooool0003o0000
00?ooooo0ol00003ooooo`Oo00001oooool2o`0002kooooo0_l0002Oooooo`007_ooool00ol0003o
ooooooooo`0Booooo`;o0000;Oooool2o`00013ooooo0_l000000ooooooo0000o`000004o`0000co
oooo0_l000000ooooooo0000o`000003ooooo`;o00009oooool2o`0000_ooooo0_l0002Oooooo`00
7_ooool00ol0003oooooooooo`0Booooo`;o0000:oooool4o`00013ooooo1_l0000?ooooo`;o0000
1_ooool2o`0002Oooooo0_l0002/ooooo`007_ooool00ol0003oooooooooo`0oooooo`;o00004ooo
ool2o`00023ooooo0_l0000Xooooo`Co0000R_ooool2o`0001Oooooo000Nooooo`03o`000?oooooo
oooo07Kooooo0_l0000Sooooo`;o00000oooool4o`0008[ooooo0_l0000Gooooo`005?ooool4o`00
0003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0;?ooool2o`0001Gooooo0_l0000;oooo
o`;o00004Oooool2o`0000Wooooo0_l0000Vooooo`;o00000oooool2o`0000Wooooo0_l0002Ooooo
o`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02cooooo0_l0000Dooooo`?o
00002oooool2o`0000oooooo1?l00009ooooo`;o00009_ooool2o`0000kooooo0_l0002Oooooo`00
5_ooool00ol0003oooooooooo`05ooooo`?o0000@_ooool2o`0001gooooo0_l0000cooooo`;o0000
[oooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3o
oooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000oooooooo
ool0oooooom@ooooo`005?ooool00omEEEGoIVIVo`00003ooooooe;ooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.16342 .86705 Mdot
.9618 .03062 Mdot
.32021 .92674 Mdot
.15437 .87229 Mdot
.2975 .95756 Mdot
.24294 .87029 Mdot
.72724 .66408 Mdot
.30619 .93419 Mdot
.22776 .82018 Mdot
.279 .61435 Mdot
.31227 .75516 Mdot
.3554 .81343 Mdot
.32743 .95239 Mdot
.13282 .8483 Mdot
.25189 .87389 Mdot
.1313 .7345 Mdot
.07906 .85403 Mdot
.29157 .99439 Mdot
.1848 .87191 Mdot
.1451 .84545 Mdot
.90959 .17635 Mdot
.29581 .83102 Mdot
.40025 .92239 Mdot
.98857 .83828 Mdot
.21036 .81978 Mdot
.31683 .88541 Mdot
.24652 .81764 Mdot
.1314 .73285 Mdot
.31856 .76904 Mdot
.25786 .81077 Mdot
.27242 .94616 Mdot
.25572 .87463 Mdot
.28637 .77476 Mdot
.05416 .13955 Mdot
.50872 .76998 Mdot
.18475 .82782 Mdot
.20628 .8511 Mdot
.01838 .85014 Mdot
.32395 .91864 Mdot
.21974 .83114 Mdot
.2515 .92577 Mdot
.49585 .75777 Mdot
.29174 .895 Mdot
.99642 .83991 Mdot
.12282 .01099 Mdot
.51017 .76521 Mdot
.28263 .99266 Mdot
.39851 .06554 Mdot
.21756 .80392 Mdot
.37424 .56787 Mdot
.31704 .01527 Mdot
.45382 .87932 Mdot
.32643 .9397 Mdot
.19977 .84204 Mdot
.34701 .96675 Mdot
.26167 .85971 Mdot
.88263 .75806 Mdot
.30857 .96347 Mdot
.24906 .81794 Mdot
.19044 .78891 Mdot
.19147 .87511 Mdot
.31323 .90755 Mdot
.54688 .78791 Mdot
.2135 .81659 Mdot
.21376 .94705 Mdot
.26916 .84517 Mdot
.42939 .87241 Mdot
.24765 .81657 Mdot
.2487 .87902 Mdot
.68472 .72638 Mdot
.08222 .36411 Mdot
.17297 .60149 Mdot
.55241 .00805 Mdot
.28744 .84469 Mdot
.36518 .76592 Mdot
.86629 .68066 Mdot
.19478 .04791 Mdot
.36353 .66922 Mdot
.2499 .83955 Mdot
.98995 .80738 Mdot
.49037 .02581 Mdot
.56852 .35609 Mdot
.96707 .7842 Mdot
.31507 .9252 Mdot
.72967 .3404 Mdot
.82929 .38104 Mdot
.29434 .91783 Mdot
.20241 .8226 Mdot
.25199 .88193 Mdot
.14354 .66665 Mdot
.15846 .82127 Mdot
.61378 .53314 Mdot
.32446 .59481 Mdot
.18901 .31617 Mdot
.1943 .84819 Mdot
.47298 .02189 Mdot
.55006 .59673 Mdot
.48789 .82094 Mdot
.23938 .8526 Mdot
.4177 .68755 Mdot
.28517 .88091 Mdot
.32579 .04672 Mdot
.13115 .89498 Mdot
.10789 .81353 Mdot
.96858 .07144 Mdot
.39409 .92979 Mdot
.15652 .73745 Mdot
.13727 .74496 Mdot
.42401 .92278 Mdot
.60496 .02275 Mdot
.11858 .84849 Mdot
.94187 .73317 Mdot
.13501 .10857 Mdot
.28672 .98624 Mdot
.75962 .07526 Mdot
.65806 .73311 Mdot
.08332 .01375 Mdot
.34265 .93344 Mdot
.04748 .24744 Mdot
.0716 .05344 Mdot
.24041 .80369 Mdot
.43455 .98516 Mdot
.34831 .78682 Mdot
.1908 .33331 Mdot
.30635 .57263 Mdot
.11673 .79746 Mdot
.37195 .87068 Mdot
.17852 .86786 Mdot
.01889 .1274 Mdot
.56921 .97536 Mdot
.13161 .86677 Mdot
.2585 .74262 Mdot
.82997 .28952 Mdot
.30263 .95418 Mdot
.26258 .93714 Mdot
.35012 .01522 Mdot
.39605 .9393 Mdot
.16144 .61348 Mdot
.21339 .93907 Mdot
.24885 .84775 Mdot
.18223 .89003 Mdot
.21606 .81786 Mdot
.30522 .81397 Mdot
.51818 .75958 Mdot
.46 .84401 Mdot
.37959 .78828 Mdot
.17195 .87653 Mdot
.25456 .85383 Mdot
.83872 .70765 Mdot
.65906 .31259 Mdot
.09898 .91783 Mdot
.305 .78479 Mdot
.31208 .85879 Mdot
.14821 .83205 Mdot
.25065 .85725 Mdot
.34643 .93036 Mdot
.17365 .64243 Mdot
.52304 .78426 Mdot
.21689 .82267 Mdot
.15363 .72172 Mdot
.15797 .58049 Mdot
.471 .69276 Mdot
.96998 .26822 Mdot
.31346 .92903 Mdot
.23162 .85707 Mdot
.32842 .95798 Mdot
.2449 .86551 Mdot
.22418 .82672 Mdot
.66542 .16379 Mdot
.32214 .97136 Mdot
.32683 .79592 Mdot
.53778 .99416 Mdot
.47787 .70494 Mdot
.95408 .53456 Mdot
.16291 .85193 Mdot
.26271 .63877 Mdot
.12123 .03897 Mdot
.32103 .90013 Mdot
.69347 .53641 Mdot
.45461 .86678 Mdot
.24491 .90265 Mdot
.35999 .7789 Mdot
.18744 .80548 Mdot
.0929 .05952 Mdot
.06617 .47591 Mdot
.25361 .08825 Mdot
.15786 .71054 Mdot
.17155 .83546 Mdot
.66305 .12716 Mdot
.51568 .76737 Mdot
.16998 .85434 Mdot
.87382 .24606 Mdot
.17355 .86904 Mdot
.04072 .0895 Mdot
.09081 .08476 Mdot
.25263 .86763 Mdot
.48838 .72227 Mdot
.38516 .76459 Mdot
.22917 .81693 Mdot
.33983 .77076 Mdot
.32959 .87368 Mdot
.97417 .14399 Mdot
.29495 .93862 Mdot
.11784 .04028 Mdot
.21103 .81869 Mdot
.19646 .82433 Mdot
.67524 .53313 Mdot
.22634 .8211 Mdot
.5537 .26865 Mdot
.14067 .6953 Mdot
.33683 .97053 Mdot
.17032 .88662 Mdot
.18827 .35168 Mdot
.9784 .27966 Mdot
.15461 .60803 Mdot
.12572 .50431 Mdot
.22401 .85777 Mdot
.20514 .08365 Mdot
.22685 .66983 Mdot
.4499 .79106 Mdot
.08859 .7593 Mdot
.22046 .8009 Mdot
.22333 .82103 Mdot
.22738 .83126 Mdot
.16307 .71741 Mdot
.18755 .58437 Mdot
.54157 .9018 Mdot
.40885 .94806 Mdot
.24228 .27195 Mdot
.29596 .822 Mdot
.34418 .90746 Mdot
.19547 .75922 Mdot
.31758 .80486 Mdot
.38852 .05328 Mdot
.14029 .5516 Mdot
.28722 .38022 Mdot
.31868 .31078 Mdot
.30866 .94934 Mdot
.9439 .64444 Mdot
.94566 .50963 Mdot
.26647 .98833 Mdot
.31961 .81168 Mdot
.41071 .99136 Mdot
.17523 .01825 Mdot
.31223 .8952 Mdot
.20354 .97866 Mdot
.22345 .74572 Mdot
.31117 .79893 Mdot
.15792 .55453 Mdot
.27094 .92044 Mdot
.43767 .88436 Mdot
.36508 .96052 Mdot
.9443 .52552 Mdot
.81283 .44624 Mdot
.3543 .64466 Mdot
.33582 .04968 Mdot
.32626 .93807 Mdot
.01258 .52849 Mdot
.50301 .90643 Mdot
.80299 .15387 Mdot
.16599 .87745 Mdot
.21701 .96057 Mdot
.33693 .65363 Mdot
.22997 .00119 Mdot
.31721 .80948 Mdot
.86037 .32288 Mdot
.20811 .11692 Mdot
.13548 .42042 Mdot
.3244 .9396 Mdot
.2315 .8203 Mdot
.23621 .85185 Mdot
.5113 .54015 Mdot
.21811 .86559 Mdot
.22987 .95129 Mdot
.51648 .00831 Mdot
.37829 .95365 Mdot
.23065 .65769 Mdot
.405 .33417 Mdot
.20031 .82551 Mdot
.28322 .04395 Mdot
.93754 .75026 Mdot
.29944 .82217 Mdot
.34422 .92251 Mdot
.21916 .82751 Mdot
.31889 .94849 Mdot
.22158 .82037 Mdot
.30345 .97683 Mdot
.36725 .67276 Mdot
.30968 .02337 Mdot
.25533 .98574 Mdot
.34359 .99906 Mdot
.56455 .41776 Mdot
.19115 .87608 Mdot
.04669 .04888 Mdot
.65661 .3967 Mdot
.41413 .64879 Mdot
.23374 .94783 Mdot
.16951 .66681 Mdot
.95154 .72254 Mdot
.55237 .25078 Mdot
.32583 .69929 Mdot
.28074 .82761 Mdot
.50766 .75323 Mdot
.23781 .71851 Mdot
.43455 .47781 Mdot
.35972 .94007 Mdot
.24491 .82052 Mdot
.24663 .83585 Mdot
.20859 .09937 Mdot
.93465 .1647 Mdot
.23262 .81126 Mdot
.93751 .70983 Mdot
.31838 .88589 Mdot
.17933 .82872 Mdot
.20949 .86015 Mdot
.19187 .94506 Mdot
.26784 .63307 Mdot
.89466 .55951 Mdot
.29138 .77144 Mdot
.0944 .87271 Mdot
.29791 .94411 Mdot
.30627 .77161 Mdot
.29008 .04794 Mdot
.17168 .72825 Mdot
.27807 .97029 Mdot
.34771 .9128 Mdot
.20125 .82236 Mdot
.16515 .88395 Mdot
.35453 .83007 Mdot
.337 .90398 Mdot
.14405 .83939 Mdot
.24995 .8742 Mdot
.49274 .39395 Mdot
.28539 .75781 Mdot
.0945 .44727 Mdot
.31589 .55375 Mdot
.0168 .02453 Mdot
.24513 .811 Mdot
.03756 .53707 Mdot
.8332 .3757 Mdot
.22792 .84685 Mdot
.90905 .1351 Mdot
.17563 .89481 Mdot
.21627 .66753 Mdot
.88485 .86681 Mdot
.65586 .65617 Mdot
.69793 .25453 Mdot
.33459 .97891 Mdot
.09897 .43792 Mdot
.29908 .93881 Mdot
.33537 .92931 Mdot
.34196 .95156 Mdot
.46213 .78321 Mdot
.11338 .76923 Mdot
.76845 .52425 Mdot
.20577 .86914 Mdot
.51389 .75925 Mdot
.30289 .89868 Mdot
.31042 .97108 Mdot
.21957 .25818 Mdot
.30787 .81215 Mdot
.46369 .86971 Mdot
.2541 .93512 Mdot
.35054 .9657 Mdot
.24285 .82012 Mdot
.49896 .84365 Mdot
.30285 .1005 Mdot
.69204 .17049 Mdot
.01194 .44415 Mdot
.25953 .8463 Mdot
.14938 .5916 Mdot
.23913 .82568 Mdot
.30204 .91769 Mdot
.26714 .83307 Mdot
.55563 .94885 Mdot
.36198 .68376 Mdot
.18346 .99976 Mdot
.20588 .80807 Mdot
.0033 .52746 Mdot
.27954 .77953 Mdot
.24756 .84552 Mdot
.13527 .87243 Mdot
.97473 .46439 Mdot
.3982 .69595 Mdot
.15997 .72184 Mdot
.03989 .05968 Mdot
.21038 .07671 Mdot
.57175 .8508 Mdot
.24341 .81412 Mdot
.08095 .8505 Mdot
.18292 .89066 Mdot
.27924 .99039 Mdot
.28485 .89105 Mdot
.27544 .96208 Mdot
.28066 .9545 Mdot
.54393 .38757 Mdot
.12693 .80226 Mdot
.86144 .32332 Mdot
.24887 .81593 Mdot
.26275 .95082 Mdot
.30196 .86316 Mdot
.21635 .99074 Mdot
.57094 .78852 Mdot
.31563 .91249 Mdot
.2508 .74845 Mdot
.31856 .02444 Mdot
.27022 .97716 Mdot
.14115 .62966 Mdot
.24433 .67486 Mdot
.31582 .93635 Mdot
.15087 .59031 Mdot
.21511 .81882 Mdot
.15349 .58555 Mdot
.7983 .72656 Mdot
.90933 .54744 Mdot
.29872 .97129 Mdot
.1177 .90046 Mdot
.18172 .58206 Mdot
.6665 .59184 Mdot
.25123 .83842 Mdot
.22378 .82739 Mdot
.97547 .67147 Mdot
.3343 .4042 Mdot
.28897 .99435 Mdot
.31549 .95188 Mdot
.23109 .09211 Mdot
.26848 .91805 Mdot
.25225 .82089 Mdot
.17408 .59445 Mdot
.5177 .22836 Mdot
.88344 .53804 Mdot
.52767 .04439 Mdot
.13446 .76662 Mdot
.13714 .86717 Mdot
.34976 .65241 Mdot
.59643 .61832 Mdot
.19658 .70114 Mdot
.47257 .93415 Mdot
.16195 .98729 Mdot
.12984 .99984 Mdot
.18867 .10168 Mdot
.97437 .84218 Mdot
.9818 .79465 Mdot
.20812 .87217 Mdot
.27891 .27703 Mdot
.22191 .85231 Mdot
.30875 .76276 Mdot
.30105 .97647 Mdot
.5649 .53617 Mdot
.35075 .85569 Mdot
.10633 .70153 Mdot
.41171 .92158 Mdot
.2237 .84164 Mdot
.23909 .83944 Mdot
.19153 .95689 Mdot
.23799 .81302 Mdot
.21276 .8169 Mdot
.19393 .83016 Mdot
.07712 .1284 Mdot
.67795 .72367 Mdot
.17485 .9222 Mdot
.20616 .82473 Mdot
.24138 .85071 Mdot
.33332 .92639 Mdot
.0065 .72174 Mdot
.48184 .81508 Mdot
.29645 .76963 Mdot
.02648 .81063 Mdot
.2307 .87236 Mdot
.51166 .92596 Mdot
.26365 .83412 Mdot
.29628 .91039 Mdot
.30998 .92612 Mdot
.31254 .92605 Mdot
.28127 .96139 Mdot
.2551 .86406 Mdot
.28176 .99862 Mdot
.32241 .94077 Mdot
.98675 .78145 Mdot
.36488 .85084 Mdot
.3706 .6872 Mdot
.02728 .06496 Mdot
.30986 .81893 Mdot
.18853 .90045 Mdot
.16643 .86493 Mdot
.92342 .52888 Mdot
.1028 .66539 Mdot
.45476 .55337 Mdot
.53891 .9696 Mdot
.11108 .75714 Mdot
.3027 .92338 Mdot
.21998 .82418 Mdot
.55458 .35986 Mdot
.20506 .04486 Mdot
.17066 .79284 Mdot
.37788 .75655 Mdot
.17295 .96862 Mdot
.32369 .75422 Mdot
.9774 .79097 Mdot
.21011 .65276 Mdot
.16453 .99899 Mdot
.56065 .91593 Mdot
.5416 .00617 Mdot
.16494 .35549 Mdot
.29593 .98865 Mdot
.46758 .65265 Mdot
.30218 .90484 Mdot
.62475 .48463 Mdot
.21367 .81659 Mdot
.22601 .7968 Mdot
.22505 .93372 Mdot
.38714 .56945 Mdot
.29766 .69025 Mdot
.99863 .5626 Mdot
.29582 .94644 Mdot
.42663 .03942 Mdot
.20788 .90484 Mdot
.4635 .03617 Mdot
.79862 .477 Mdot
.25524 .95509 Mdot
.29004 .88246 Mdot
.30933 .94606 Mdot
.24799 .84201 Mdot
.35587 .77781 Mdot
.38273 .74778 Mdot
.08091 .78959 Mdot
.54238 .28663 Mdot
.27856 .51063 Mdot
.14821 .80059 Mdot
.0983 .12601 Mdot
.89623 .16044 Mdot
.37118 .76913 Mdot
.31092 .94993 Mdot
.34554 .96582 Mdot
.32172 .92604 Mdot
.28432 .86497 Mdot
.21542 .93655 Mdot
.25054 .79498 Mdot
.12471 .96784 Mdot
.49055 .17334 Mdot
.24937 .84942 Mdot
.86925 .60546 Mdot
.37651 .78421 Mdot
.25382 .85669 Mdot
.20916 .91405 Mdot
.58725 .64582 Mdot
.55156 .54409 Mdot
.29151 .85893 Mdot
.3514 .94006 Mdot
.34726 .915 Mdot
.69346 .59969 Mdot
.30027 .94376 Mdot
.26927 .78407 Mdot
.00427 .02752 Mdot
.4469 .02444 Mdot
.34484 .56067 Mdot
.45893 .61796 Mdot
.24837 .80967 Mdot
.15175 .84665 Mdot
.94123 .02455 Mdot
.33365 .95558 Mdot
.31649 .76666 Mdot
.08178 .91084 Mdot
.2501 .68608 Mdot
.29961 .97807 Mdot
.21549 .8086 Mdot
.16593 .60546 Mdot
.22554 .8321 Mdot
.55605 .37414 Mdot
.25042 .88083 Mdot
.60974 .97044 Mdot
.09703 .79567 Mdot
.25364 .86895 Mdot
.16335 .88745 Mdot
.28316 .9904 Mdot
.26632 .8067 Mdot
.46232 .9636 Mdot
.31599 .7745 Mdot
.37367 .96178 Mdot
.21213 .9577 Mdot
.20769 .65015 Mdot
.64814 .59002 Mdot
.23454 .99181 Mdot
.19257 .90206 Mdot
.21117 .0467 Mdot
.1849 .82382 Mdot
.22601 .08982 Mdot
.73765 .85772 Mdot
.10767 .96611 Mdot
.19093 .85094 Mdot
.32161 .94532 Mdot
.32924 .97538 Mdot
.23268 .66481 Mdot
.32719 .76258 Mdot
.38024 .7763 Mdot
.32219 .88746 Mdot
.2078 .67742 Mdot
.3446 .91452 Mdot
.18855 .82142 Mdot
.29789 .82997 Mdot
.28343 .80079 Mdot
.23016 .82831 Mdot
.3194 .921 Mdot
.48986 .81677 Mdot
.47627 .96708 Mdot
.31593 .92171 Mdot
.23892 .83078 Mdot
.29266 .81683 Mdot
.37181 .93891 Mdot
.16709 .86896 Mdot
.31941 .95792 Mdot
.64355 .42888 Mdot
.24674 .86764 Mdot
.46668 .13335 Mdot
.17464 .88433 Mdot
.18427 .72976 Mdot
.16597 .59036 Mdot
.90319 .52103 Mdot
.25917 .84955 Mdot
.50131 .55422 Mdot
.48384 .12185 Mdot
.66015 .88901 Mdot
.17094 .86441 Mdot
.83205 .55383 Mdot
.50817 .83742 Mdot
.16883 .10778 Mdot
.8467 .32628 Mdot
.83983 .36521 Mdot
.37883 .97269 Mdot
.50102 .8963 Mdot
.24664 .96351 Mdot
.22515 .82707 Mdot
.19198 .8294 Mdot
.21294 .81346 Mdot
.25192 .87074 Mdot
.3287 .78351 Mdot
.31514 .92891 Mdot
.27372 .74244 Mdot
.2755 .97944 Mdot
.25158 .8794 Mdot
.35174 .85451 Mdot
.24645 .87588 Mdot
.49057 .7725 Mdot
.49063 .90743 Mdot
.56273 .00404 Mdot
.25866 .88008 Mdot
.37911 .92568 Mdot
.91818 .80435 Mdot
.32881 .9158 Mdot
.36719 .9468 Mdot
.98455 .80475 Mdot
.3439 .75491 Mdot
.23948 .13893 Mdot
.22827 .83591 Mdot
.55127 .53614 Mdot
.21818 .82769 Mdot
.31887 .95009 Mdot
.12556 .72518 Mdot
.58378 .2955 Mdot
.24426 .81441 Mdot
.18319 .98985 Mdot
.39492 .874 Mdot
.52124 .35643 Mdot
.23684 .79831 Mdot
.87161 .30104 Mdot
.10217 .06339 Mdot
.25013 .83673 Mdot
.74394 .55183 Mdot
.39566 .69235 Mdot
.18622 .08255 Mdot
.45831 .07929 Mdot
.58261 .25766 Mdot
.05983 .10174 Mdot
.27425 .75693 Mdot
.99644 .44725 Mdot
.31423 .89367 Mdot
.08278 .00822 Mdot
.2839 .99297 Mdot
.62407 .26291 Mdot
.62669 .2547 Mdot
.0123 .79048 Mdot
.51913 .75921 Mdot
.94997 .52615 Mdot
.17926 .86128 Mdot
.2504 .88013 Mdot
.43335 .64142 Mdot
.40463 .97193 Mdot
.67355 .19408 Mdot
.06203 .98741 Mdot
.29544 .98805 Mdot
.38447 .0536 Mdot
.05864 .03258 Mdot
.35978 .71644 Mdot
.60184 .8695 Mdot
.29521 .78368 Mdot
.38395 .868 Mdot
.23744 .84517 Mdot
.45094 .87977 Mdot
.3584 .644 Mdot
.03579 .54952 Mdot
.24921 .09822 Mdot
.10736 .77043 Mdot
.34793 .93076 Mdot
.20419 .9353 Mdot
.02698 .54777 Mdot
.34143 .78366 Mdot
.33637 .05911 Mdot
.93325 .72555 Mdot
.2792 .77498 Mdot
.24015 .80661 Mdot
.40452 .47843 Mdot
.19222 .60603 Mdot
.14409 .98333 Mdot
.93946 .58603 Mdot
.41026 .94479 Mdot
.69971 .56699 Mdot
.31176 .8084 Mdot
.27882 .94948 Mdot
.49409 .63928 Mdot
.3246 .80184 Mdot
.16683 .88818 Mdot
.44443 .01329 Mdot
.2929 .89819 Mdot
.75573 .54124 Mdot
.9487 .91881 Mdot
.7455 .70227 Mdot
.08857 .70192 Mdot
.24421 .80022 Mdot
.51149 .9399 Mdot
.92236 .80755 Mdot
.31961 .75655 Mdot
.31351 .77258 Mdot
.3533 .92075 Mdot
.23406 .8323 Mdot
.52694 .6893 Mdot
.65253 .06738 Mdot
.55627 .49745 Mdot
.46299 .53791 Mdot
.35568 .93387 Mdot
.63024 .43493 Mdot
.32783 .89619 Mdot
.14223 .87905 Mdot
.165 .86089 Mdot
.67793 .62014 Mdot
.46027 .03767 Mdot
.37845 .88724 Mdot
.27108 .77373 Mdot
.89526 .77097 Mdot
.31546 .77598 Mdot
.89742 .57732 Mdot
.42581 .93042 Mdot
.25201 .92156 Mdot
.09149 .04585 Mdot
.15265 .90954 Mdot
.27967 .89959 Mdot
.25024 .87203 Mdot
.30244 .98885 Mdot
.52502 .00856 Mdot
.29161 .98926 Mdot
.29538 .93032 Mdot
.79177 .77167 Mdot
.30355 .93142 Mdot
.36539 .19473 Mdot
.25305 .93357 Mdot
.26647 .00955 Mdot
.1786 .8705 Mdot
.44 .72063 Mdot
.83808 .63482 Mdot
.3857 .76684 Mdot
.33565 .14326 Mdot
.21052 .83031 Mdot
.10868 .90098 Mdot
.37547 .93376 Mdot
.36499 .96045 Mdot
.66505 .44905 Mdot
.21037 .91982 Mdot
.3387 .85792 Mdot
.30568 .92575 Mdot
.19764 .96176 Mdot
.25884 .37311 Mdot
.15013 .87448 Mdot
.13684 .08218 Mdot
.91197 .58559 Mdot
.44006 .01921 Mdot
.21575 .91847 Mdot
.17794 .64907 Mdot
.12447 .76133 Mdot
.24557 .84647 Mdot
.2211 .8242 Mdot
.35269 .91803 Mdot
.46582 .64851 Mdot
.00551 .44903 Mdot
.34919 .68125 Mdot
.32101 .88544 Mdot
.41439 .61974 Mdot
.323 .95018 Mdot
.10536 .76912 Mdot
.39651 .67931 Mdot
.14024 .85615 Mdot
.18328 .69593 Mdot
.97109 .98373 Mdot
.28139 .8101 Mdot
.24072 .9905 Mdot
.08277 .10158 Mdot
.21206 .67584 Mdot
.29391 .97396 Mdot
.50123 .23892 Mdot
.22919 .22416 Mdot
.44595 .68048 Mdot
.26706 .8447 Mdot
.39006 .6748 Mdot
.15381 .8418 Mdot
.31874 .94018 Mdot
.43355 .13024 Mdot
.16667 .85477 Mdot
.23678 .82997 Mdot
.32854 .5495 Mdot
.84881 .72378 Mdot
.24554 .86635 Mdot
.72863 .56067 Mdot
.31653 .92868 Mdot
.33531 .92516 Mdot
.29965 .81296 Mdot
.34345 .93332 Mdot
.28913 .92316 Mdot
.16504 .61805 Mdot
.3223 .9292 Mdot
.23967 .84846 Mdot
.68262 .47118 Mdot
.31264 .83399 Mdot
.06643 .02987 Mdot
.36922 .66198 Mdot
.29211 .98801 Mdot
.61392 .59652 Mdot
.43999 .77832 Mdot
.3225 .96039 Mdot
.36969 .66687 Mdot
.21729 .80355 Mdot
.25868 .80684 Mdot
.94333 .49103 Mdot
.43513 .10629 Mdot
.34118 .92104 Mdot
.24686 .82042 Mdot
.23972 .82793 Mdot
.88046 .73473 Mdot
.62317 .7545 Mdot
.1267 .7624 Mdot
.33947 .92121 Mdot
.31855 .88932 Mdot
.2443 .9212 Mdot
.07372 .82445 Mdot
.18204 .63565 Mdot
.2392 .91573 Mdot
.20308 .91328 Mdot
.24272 .81497 Mdot
.02459 .4633 Mdot
.30938 .93076 Mdot
.28508 .31573 Mdot
.35767 .84672 Mdot
.26287 .93366 Mdot
.33206 .91915 Mdot
.17473 .87087 Mdot
.24758 .80354 Mdot
.18914 .01616 Mdot
.32251 .88421 Mdot
.36141 .76259 Mdot
.18099 .86849 Mdot
.21397 .68721 Mdot
.40259 .77734 Mdot
.33232 .93895 Mdot
.27633 .77869 Mdot
.2473 .82649 Mdot
.21188 .82016 Mdot
.14925 .89153 Mdot
.51461 .00177 Mdot
.28542 .93175 Mdot
.33364 .12798 Mdot
.22581 .20936 Mdot
.30721 .00447 Mdot
.24957 .9018 Mdot
.51874 .88069 Mdot
.20231 .85057 Mdot
.30595 .9267 Mdot
.29101 .95042 Mdot
.29355 .87286 Mdot
.16406 .86434 Mdot
.15568 .90518 Mdot
.86528 .62557 Mdot
.29732 .82814 Mdot
.38278 .93702 Mdot
.16961 .40622 Mdot
.42135 .40037 Mdot
.32659 .93564 Mdot
.30434 .81919 Mdot
.81757 .85036 Mdot
.23231 .93035 Mdot
.88514 .72635 Mdot
.2378 .87376 Mdot
.11517 .89108 Mdot
.32573 .85985 Mdot
.24591 .91106 Mdot
.265 .09742 Mdot
.18851 .57856 Mdot
.15702 .94841 Mdot
.77735 .58907 Mdot
.63506 .85846 Mdot
.39405 .04796 Mdot
.25011 .89806 Mdot
.20248 .88853 Mdot
.17716 .89632 Mdot
.38209 .00822 Mdot
.2547 .97092 Mdot
.08762 .52372 Mdot
.24703 .79731 Mdot
.4231 .82442 Mdot
.30788 .0538 Mdot
.4704 .86528 Mdot
.11411 .88812 Mdot
.47775 .04167 Mdot
.24291 .82363 Mdot
.31287 .39298 Mdot
.38912 .72648 Mdot
.22493 .94973 Mdot
.32841 .91542 Mdot
.25478 .87752 Mdot
.02336 .47644 Mdot
.19426 .45257 Mdot
.197 .96953 Mdot
.23546 .14013 Mdot
.57308 .28632 Mdot
.33534 .80084 Mdot
.38737 .94651 Mdot
.32991 .937 Mdot
.31665 .80848 Mdot
.88185 .24518 Mdot
.17781 .88011 Mdot
.07604 .47546 Mdot
.31642 .78037 Mdot
.25032 .83403 Mdot
.87433 .71094 Mdot
.33234 .94372 Mdot
.21456 .90304 Mdot
.20911 .8228 Mdot
.60955 .56362 Mdot
.27776 .92467 Mdot
.24318 .869 Mdot
.54243 .0712 Mdot
.42848 .79691 Mdot
.24296 .84612 Mdot
.37862 .70589 Mdot
.24588 .8771 Mdot
.06855 .72879 Mdot
.44029 .82427 Mdot
.03773 .43744 Mdot
.18354 .85217 Mdot
.34153 .91931 Mdot
.85154 .51037 Mdot
.31906 .70689 Mdot
.47219 .82827 Mdot
.15615 .23682 Mdot
.29396 .82501 Mdot
.2346 .83295 Mdot
.24631 .8693 Mdot
.18375 .71043 Mdot
.34409 .91156 Mdot
.73593 .43809 Mdot
.18905 .6058 Mdot
.18433 .58453 Mdot
.76006 .60325 Mdot
.65297 .13422 Mdot
.19291 .10147 Mdot
.61831 .0459 Mdot
.9578 .77793 Mdot
.65238 .59675 Mdot
.00482 .69529 Mdot
.30238 .90891 Mdot
.16439 .66667 Mdot
.28272 .61106 Mdot
.24834 .82523 Mdot
.25541 .82834 Mdot
.28069 .96655 Mdot
.2137 .80547 Mdot
.30942 .08573 Mdot
.15403 .70806 Mdot
.26499 .7693 Mdot
.42054 .91796 Mdot
.1467 .98624 Mdot
.60067 .18112 Mdot
.48828 .87091 Mdot
.25772 .82556 Mdot
.88522 .29758 Mdot
.14883 .87086 Mdot
.26501 .89348 Mdot
.31732 .53763 Mdot
.26105 .81711 Mdot
.24344 .79925 Mdot
.29271 .89684 Mdot
.40384 .59899 Mdot
.17252 .63718 Mdot
.34669 .77288 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01_ooool2o`0000Gooooo00?o0000ooooooooool03Oooool01?l0003o
ooooo`000?l0000<ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`04o`000?ooooooooooooooo`;o00002_ooool01?l0003ooooooooooooo
ool2o`0000_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00;ooooo000Nooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0=ooooo`04o`000?oooooo0000o`0000cooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00Co0000oooooooooooooooo
0_l00007ooooo`;o000000?oooooo`000?ooool00_ooool2o`0000_ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo000Nooooo`03o`000?oo
oooooooo01Oooooo0_l0000jooooo`;o00008oooool2o`0002[ooooo0_l000000ooooooo0000o`00
0003ooooo`;o000000?oooooo`000?l00000U_ooool001kooooo00?o0000ooooooooool05oooool2
o`0000_ooooo0_l0000]ooooo`;o00008oooool2o`0001;ooooo0_l0000Fooooo`;o000000?ooooo
o`000?l000001_ooool2o`0009Kooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0000;oooo
o`;o00004oooool2o`0002Sooooo0_l00009ooooo`;o00007?ooool2o`000;Wooooo000Nooooo`03
o`000?oooooooooo01Oooooo0_l0000Looooo`;o00000_ooool2o`0002Sooooo0_l00009ooooo`;o
00006oooool2o`000;[ooooo000Nooooo`03o`000?oooooooooo03Gooooo0_l0001Dooooo`;o0000
2Oooool2o`0002Wooooo0_l00024ooooo`007_ooool01?l0003oooooooooooooool2o`0005kooooo
1?l0000Xooooo`;o00001oooool2o`0000?ooooo0_l0000Tooooo`;o0000Joooool2o`0001Oooooo
000Nooooo`;o00000_ooool2o`0005kooooo1?l0000Xooooo`;o00003?ooool2o`00097ooooo0_l0
000Gooooo`007_ooool2o`0001;ooooo0_l0003oooooob?ooooo0_l0000@ooooo`007_ooool00ol0
003oooooooooo`0?ooooo`Co0000oooooolSooooo`;o00004?ooool001kooooo00?o0000oooooooo
ool03oooool2o`00087ooooo0ol0002booooo`007_ooool00ol0003oooooooooo`0Rooooo`?o0000
H_ooool2o`0000Wooooo0ol0002booooo`007_ooool00ol0003oooooooooo`0Rooooo`?o0000<ooo
ool2o`0002gooooo0_l0000>ooooo`;o00003_ooool2o`0009kooooo000Nooooo`03o`000?oooooo
oooo01[ooooo0_l0000Sooooo`Co00005Oooool2o`0000cooooo0_l0000_ooooo`;o00003_ooool2
o`0001cooooo0_l00020ooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o00003Oooool2o`00
01oooooo0_l00002ooooo`Co00005oooool2o`0000[ooooo0_l000000ooooooo0000o`00000Aoooo
o`;o0000Aoooool2o`00083ooooo000Nooooo`;o00003?ooool2o`0000Kooooo0_l0000Vooooo`;o
00007Oooool2o`0000gooooo0_l0000>ooooo`Go0000bOooool001kooooo00?o0000ooooooooool0
4oooool2o`0004_ooooo0_l0000Gooooo`?o0000boooool001kooooo00?o0000ooooooooool02Ooo
ool2o`0000oooooo0_l00014ooooo`;o00001oooool2o`000=cooooo000Nooooo`03o`000?oooooo
oooo00Wooooo0_l0000?ooooo`;o0000COooool2o`000=cooooo000Nooooo`03o`000?oooooooooo
00Gooooo0_l0000Fooooo`;o0000G_ooool2o`000<Sooooo000Nooooo`03o`000?oooooooooo00Go
oooo0_l0000Fooooo`;o0000G_ooool2o`00057ooooo0_l0001eooooo`007_ooool00ol0003ooooo
ooooo`2/ooooo`;o00008_ooool2o`0006Gooooo0_l0000>ooooo`007_ooool00ol0003ooooooooo
o`2/ooooo`;o0000ROooool2o`0000kooooo000Nooooo`03o`000?oooooooooo043ooooo0_l0002a
ooooo`;o0000D_ooool001kooooo00?o0000ooooooooool0@?ooool2o`0004oooooo0_l0001Poooo
o`;o0000D_ooool001kooooo00?o0000ooooooooool0:?ooool2o`0000kooooo0_l00005ooooo`;o
0000D?ooool2o`000;Cooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l0000=ooooo`;o0000
3_ooool2o`0000Gooooo0_l0000Oooooo`;o0000iOooool001kooooo00?o0000ooooooooool02Ooo
ool2o`0000kooooo0_l0000Zooooo`;o00001oooool2o`00013ooooo0_l0003Uooooo`007_ooool0
0ol0003oooooooooo`09ooooo`;o0000>_ooool4o`0000Gooooo0_l0003gooooo`007_ooool00ol0
003oooooooooo`17ooooo`;o0000o_ooool001kooooo00?o0000ooooooooool0@?ooool2o`0000_o
oooo0_l00003ooooo`;o0000loooool001kooooo0_l0000@ooooo`;o00001_ooool2o`00023ooooo
1?l00003ooooo`;o00002oooool2o`0000?ooooo0_l0000:ooooo`;o0000ioooool001kooooo00?o
0000ooooooooool03oooool2o`0000Kooooo0_l0000Pooooo`Co00008Oooool2o`000>Oooooo000N
ooooo`03o`000?oooooooooo02Sooooo0_l00009ooooo`;o0000E?ooool2o`000;cooooo000Noooo
o`03o`000?oooooooooo02Sooooo0_l00009ooooo`;o0000E?ooool2o`000;cooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0@?ooool2o`000?oooooo
1_ooool001kooooo00?o0000ooooooooool0@?ooool2o`000?oooooo1_ooool001kooooo00?o0000
ooooooooool0VOooool2o`000:cooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0000Hoooo
o`;o0000Noooool2o`0003Sooooo0_l0001booooo`007_ooool00ol0003oooooooooo`02ooooo`;o
00004Oooool2o`0000Gooooo0_l0001:ooooo`;o00007oooool2o`0004Sooooo0_l0001booooo`00
7_ooool00ol0003oooooooooo`0Eooooo`;o0000DOooool2o`0001oooooo0_l00009ooooo`;o0000
/Oooool001kooooo00?o0000ooooooooool0U?ooool2o`0003[ooooo0_l0001Aooooo`;o00008_oo
ool001kooooo00?o0000ooooooooool03Oooool2o`0003_ooooo0_l00024ooooo`;o0000DOooool2
o`0002;ooooo000Nooooo`03o`000?oooooooooo00gooooo0_l0000iooooo`Co0000noooool001ko
oooo00?o0000ooooooooool0B?ooool2o`0001oooooo0_l0003>ooooo`;o00003?ooool001kooooo
00?o0000ooooooooool0JOooool2o`000<kooooo0_l0000<ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0ooooool2ooooo`;o0000A?ooool001kooooo00?o0000oooo
ooooool0ooooool2ooooo`;o0000A?ooool001kooooo00?o0000ooooooooool0oooooolPooooo`;o
00009_ooool001kooooo00?o0000ooooooooool0e?ooool2o`0004Wooooo0_l0000Vooooo`007_oo
ool00ol0003oooooooooo`3Dooooo`;o0000E_ooool2o`0001Wooooo000Nooooo`03o`000?oooooo
oooo0=gooooo0_l0001=ooooo`;o00006Oooool001kooooo00?o0000ooooooooool0Voooool2o`00
043ooooo0_l0001Xooooo`007_ooool00ol0003oooooooooo`2Kooooo`;o0000Qoooool2o`00027o
oooo000Nooooo`03o`000?oooooooooo0?oooooo9Oooool2o`00027ooooo000Nooooo`03o`000?oo
oooooooo0;oooooo0_l00026ooooo`007_ooool00ol0003oooooooooo`2oooooo`;o0000Q_ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03
o`000?oooooooooo07?ooooo0_l0001Rooooo`;o0000K_ooool000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000oooo
ooooool0Loooool2o`0006;ooooo0_l0001^ooooo`000oooool01Ol@413ooooooooooooooooo410@
00cooooo00?oV9RHob4Q8Oo^k^h01oooool3o`000?ooooooB?ooool000?ooooo00Go0000oooooooo
ooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0oooooom8oooo
o`000oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0
003oooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo04Gooooo0_l0003oooooo`7ooooo0003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000
ooooooooool0AOooool2o`000?oooooo0Oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`16ooooo`;o0000ooooool001kooooo00?o0000ooooooooool0
A_ooool2o`0005cooooo0_l0002Qooooo`007_ooool00ol0003oooooooooo`2Tooooo`;o0000XOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`0_oooo
o`;o0000oooooolGooooo`007_ooool00ol0003oooooooooo`0_ooooo`;o0000K_ooool2o`000:Ko
oooo000Nooooo`03o`000?oooooooooo09oooooo0_l0002Vooooo`007_ooool00ol0003ooooooooo
o`0;ooooo`;o0000ooooool<ooooo`;o000000?oooooo`000?l00000:_ooool001kooooo00?o0000
ooooooooool02oooool2o`000?oooooo3?ooool2o`000003ooooool0003o000002[ooooo000Noooo
o`;o0000/?ooool2o`0009Kooooo000Nooooo`03o`000?oooooooooo0:oooooo0_l0000Gooooo`;o
00005Oooool2o`0006Kooooo000Nooooo`03o`000?oooooooooo04?ooooo0_l0001dooooo`;o0000
3Oooool2o`0001Gooooo0_l0001Vooooo`007_ooool00ol0003oooooooooo`13ooooo`;o0000M?oo
ool2o`0008cooooo000Nooooo`03o`000?oooooooooo0<Oooooo0_l0001nooooo`007_ooool00ol0
003oooooooooo`2`ooooo`;o00005Oooool2o`0006kooooo0_l0000>ooooo`007_ooool00ol0003o
ooooooooo`1;ooooo`;o0000Hoooool2o`0008Gooooo0_l0000>ooooo`007_ooool00ol0003ooooo
ooooo`1;ooooo`;o0000n_ooool001kooooo00?o0000ooooooooool0Eoooool2o`000>kooooo000N
ooooo`03o`000?oooooooooo05Oooooo0_l0003Qooooo`;o00002oooool001kooooo00?o0000oooo
ooooool0oooooolkooooo`;o00002oooool001kooooo00?o0000ooooooooool0[?ooool2o`0000So
oooo0_l0002?ooooo`007_ooool00ol0003oooooooooo`2/ooooo`;o00002?ooool2o`0005;ooooo
0_l0000kooooo`007_ooool00ol0003oooooooooo`3oooooo`_ooooo0_l0000kooooo`007_ooool0
0ol0003oooooooooo`2jooooo`;o0000Roooool001kooooo00?o0000ooooooooool0^_ooool2o`00
063ooooo0_l0000Yooooo`007_ooool2o`000?oooooo6Oooool2o`0000?ooooo0_l0000Yooooo`00
7_ooool00ol0003oooooooooo`3ooooooaSooooo0_l0000^ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo06?ooooo0_l0003Rooooo`007_ooool00ol0
003oooooooooo`1Sooooo`;o0000KOooool2o`0007?ooooo000Nooooo`03o`000?oooooooooo03Wo
oooo0_l0000Nooooo`;o0000Moooool2o`0007?ooooo000Nooooo`03o`000?oooooooooo03Wooooo
0_l0000Nooooo`;o0000k?ooool001kooooo00?o0000ooooooooool0oooooolEooooo`;o0000<Ooo
ool001kooooo00?o0000ooooooooool0ooooool@ooooo`;o00000oooool2o`00037ooooo000Noooo
o`03o`000?oooooooooo0?oooooo4?ooool2o`0003Kooooo000Nooooo`03o`000?oooooooooo03[o
oooo0_l0003oooooo`cooooo000Nooooo`03o`000?oooooooooo03[ooooo0_l00014ooooo`;o0000
aOooool001kooooo00?o0000ooooooooool0P?ooool2o`000<Gooooo000Nooooo`03o`000?oooooo
oooo0>Wooooo0_l0001Looooo`007_ooool00ol0003oooooooooo`3Yooooo`;o0000G?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`0003[ooooo0_l0003oooooo`gooooo
000Nooooo`03o`000?oooooooooo03Wooooo0_l0003oooooo`gooooo000Nooooo`03o`000?oooooo
oooo03;ooooo0_l0001aooooo`;o00003_ooool2o`00093ooooo000Nooooo`03o`000?oooooooooo
03;ooooo0_l0001aooooo`;o00002Oooool2o`0000?ooooo0_l0002@ooooo`007_ooool00ol0003o
ooooooooo`0Gooooo`;o0000Uoooool2o`0009Gooooo000Nooooo`03o`000?oooooooooo01Oooooo
0_l0003dooooo`;o0000>?ooool001kooooo00?o0000ooooooooool0ooooool>ooooo`;o0000>?oo
ool001kooooo00?o0000ooooooooool0D?ooool2o`000?Gooooo000Nooooo`03o`000?oooooooooo
053ooooo0_l0001Oooooo`;o0000F?ooool2o`0003[ooooo000Nooooo`03o`000?oooooooooo0;7o
oooo0_l0001Hooooo`;o0000>_ooool001kooooo00?o0000ooooooooool0FOooool2o`000:kooooo
0_l0000looooo`007_ooool00ol0003oooooooooo`1Iooooo`;o0000[_ooool2o`0003cooooo000N
ooooo`03o`000?oooooooooo0:gooooo0_l0002Hooooo`007_ooool00ol0003oooooooooo`2]oooo
o`;o0000V?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`00
0003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0H_ooool2o`0003Sooooo0_l0002Yoooo
o`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0H_ooool2o`0003Sooooo0_l0000cooooo`;o0000M?ooool000?o
oooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool3o`0008Gooooo0_l0001:oooo
o`;o0000M?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgooooo
o`0000Oooooo00?o0000ooooooooool0JOooool2o`0001[ooooo0_l00030ooooo`000oooool01Ol0
003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003ooooooooo
o`0cooooo`;o0000=?ooool2o`000=cooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo03?ooooo0_l0003ooooooa?ooooo0003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0
003ooooo00Kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`2c
ooooo`;o0000T_ooool001kooooo00?o0000ooooooooool0:?ooool2o`0008Wooooo0_l0002Boooo
o`007_ooool00ol0003oooooooooo`0Xooooo`;o0000oooooolNooooo`007_ooool00ol0003ooooo
ooooo`3=ooooo`;o0000N?ooool001kooooo00?o0000ooooooooool0cOooool2o`0007Sooooo000N
ooooo`03o`000?oooooooooo0<Wooooo0_l0001looooo`007_ooool00ol0003oooooooooo`08oooo
o`;o00004_ooool2o`000:_ooooo0_l0000Pooooo`;o0000F_ooool001kooooo00?o0000oooooooo
ool02?ooool2o`0001;ooooo0_l0003=ooooo`;o0000F_ooool001kooooo00?o0000ooooooooool0
0_l0003oooooodKooooo000Nooooo`03o`000?oooooooooo00;o00006Oooool2o`000>Oooooo0_l0
000jooooo`;o00001Oooool001kooooo0ol0000Kooooo`;o0000]oooool2o`0002kooooo0_l0000j
ooooo`;o00001Oooool001kooooo0ol0000kooooo`;o0000Uoooool2o`00077ooooo000Nooooo`03
o`000?oooooooooo03_ooooo0_l0003oooooo`_ooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`04
ooooo`;o0000ooooooldooooo`;o00003?ooool001kooooo00?o0000ooooooooool01?ooool2o`00
0?oooooo=?ooool2o`0000cooooo000Nooooo`03o`000?oooooooooo0=[ooooo0_l0001[ooooo`00
7_ooool00ol0003oooooooooo`3Jooooo`;o0000Joooool001kooooo00?o0000ooooooooool00ooo
ool2o`0000cooooo0_l00002ooooo`;o0000L_ooool2o`0007Gooooo0_l00015ooooo`007_ooool0
0ol0003oooooooooo`03ooooo`;o00003?ooool2o`0000;ooooo0_l0001Xooooo`;o00002?ooool2
o`0007Gooooo0_l00015ooooo`007_ooool00ol0003oooooooooo`1oooooo`;o0000a_ooool001ko
oooo00?o0000ooooooooool0aoooool2o`0007kooooo000Nooooo`03o`000?oooooooooo0<Oooooo
0_l0001nooooo`007_ooool00ol0003oooooooooo`3ooooooc3ooooo0_l0000Fooooo`007_ooool0
0ol0003oooooooooo`3ooooooc3ooooo0_l0000Fooooo`007_ooool00ol0003oooooooooo`2aoooo
o`;o0000U?ooool001kooooo0_l0002booooo`;o0000U?ooool001kooooo00?o0000ooooooooool0
9Oooool2o`000?oooooo8Oooool001kooooo00?o0000ooooooooool09Oooool2o`000?oooooo8Ooo
ool001kooooo00?o0000ooooooooool0E_ooool2o`000;Wooooo0_l0000Looooo`;o00005_ooool0
01kooooo00?o0000ooooooooool0E_ooool2o`000;Wooooo0_l0000Looooo`;o00005_ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooob?ooooo
0_l0000Sooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o0000g?ooool2o`0002[ooooo0_l0
000Sooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o0000g?ooool2o`0003Oooooo1?l0000D
ooooo`007_ooool2o`000003ooooool0003o00000?oooooo9oooool2o`0000Gooooo1?l0000Doooo
o`007_ooool2o`000003ooooool0003o00000<7ooooo0_l0000Booooo`;o0000Coooool2o`0001go
oooo000Nooooo`03o`000?oooooooooo0:oooooo0_l00003ooooo`;o00003Oooool2o`0001;ooooo
0_l00004ooooo`;o0000Doooool2o`0001?ooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0
001Iooooo`;o0000;Oooool2o`0001_ooooo0_l00003ooooo`;o00009oooool2o`0003cooooo0_l0
000Eooooo`;o00004oooool001kooooo00?o0000ooooooooool02?ooool2o`0005Wooooo0_l0000]
ooooo`;o00003_ooool2o`0004kooooo0_l0000Wooooo`;o0000:_ooool001kooooo00?o0000oooo
ooooool0X_ooool2o`0000_ooooo0_l00011ooooo`;o0000Doooool001kooooo00?o0000oooooooo
ool01Oooool2o`000:Sooooo0_l0001cooooo`;o00008Oooool001kooooo0_l00006ooooo`;o0000
00?oooooo`000?l000007oooool2o`0003cooooo0_l00025ooooo`;o0000=?ooool2o`00027ooooo
000Nooooo`03o`000?oooooooooo00Sooooo0_l0000Oooooo`;o00001?ooool2o`0003;ooooo0_l0
0002ooooo`;o00009oooool2o`0000gooooo0_l0001=ooooo`;o00006_ooool2o`0003_ooooo000N
ooooo`03o`000?oooooooooo02oooooo0_l0000booooo`;o0000:oooool2o`0000gooooo0_l0001Y
ooooo`;o0000>oooool001kooooo00?o0000ooooooooool0K?ooool2o`0007_ooooo0_l0000doooo
o`;o00009_ooool001kooooo00?o0000ooooooooool0K?ooool2o`0005Cooooo0_l0000Uooooo`;o
0000=?ooool2o`00023ooooo0_l00004ooooo`007_ooool00ol0003oooooooooo`32ooooo`;o0000
6oooool2o`00063ooooo0_l00004ooooo`007_ooool00ol0003oooooooooo`1fooooo`;o00000_oo
ool2o`0006?ooooo0_l0001Vooooo`007_ooool00ol0003oooooooooo`1Oooooo`;o00005Oooool2
o`0000;ooooo0_l0003;ooooo`007_ooool00ol0003oooooooooo`1Oooooo`;o0000i_ooool001ko
oooo00?o0000ooooooooool0>Oooool2o`000>Gooooo0_l0000Uooooo`007_ooool00ol0003ooooo
ooooo`0_ooooo`;o00001_ooool4o`000>Gooooo0_l0000Uooooo`007_ooool00ol0003ooooooooo
o`0^ooooo`?o00001_ooool4o`000>Wooooo0_l0000Qooooo`007_ooool00ol0003oooooooooo`0^
ooooo`;o00002?ooool3o`000>Wooooo0_l00007ooooo`;o00006?ooool001kooooo00?o0000oooo
ooooool0;?ooool3o`0000?ooooo0_l0002Kooooo`;o00001?ooool2o`0002;ooooo0_l0000boooo
o`;o00006?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^
k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0;?ooool3o`0000?ooooo1?l0000_
ooooo`;o0000J?ooool2o`0000Cooooo0_l0000Rooooo`;o0000C?ooool000?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o
0000ooooooooool0=?ooool2o`0002oooooo0_l00018ooooo`;o00004_ooool2o`0000_ooooo0_l0
001eooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooooooooooo
o`000006ooooo`?o0000Ooooool2o`0002kooooo0_l0000Booooo`;o00002oooool2o`0000_ooooo
0_l0001Xooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@06ooooo`03o`000?oooooooooo03Cooooo0_l00019ooooo`;o0000G?ooool2o`0001Co
oooo0_l0001Booooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0
003o410@olc<c006ooooo`03o`000?oooooooooo03;ooooo1?l00003ooooo`?o0000]oooool2o`00
027ooooo0_l0000_ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7
Qoooool02?ooool00ol0003oooooooooo`0^ooooo`;o00000_ooool2o`0000Gooooo0ol0003Joooo
o`;o0000;oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH
00Sooooo00?o0000ooooooooool0;_ooool4o`0002Kooooo0_l0003]ooooo`000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`0`
ooooo`;o00009Oooool3o`000>gooooo000Nooooo`03o`000?oooooooooo03;ooooo0_l0000Soooo
o`;o0000>?ooool2o`0002_ooooo0_l00027ooooo`007_ooool00ol0003oooooooooo`0booooo`;o
0000Coooool2o`0000cooooo0_l0000[ooooo`;o00006?ooool2o`0006gooooo000Nooooo`03o`00
0?oooooooooo08?ooooo0_l0001Cooooo`;o0000>oooool2o`00033ooooo000Nooooo`03o`000?oo
oooooooo0?oooooo5_ooool2o`00033ooooo000Nooooo`03o`000?oooooooooo02[ooooo0_l0003o
oooooacooooo000Nooooo`03o`000?oooooooooo02[ooooo0_l0000Wooooo`;o0000]oooool2o`00
03Wooooo000Nooooo`03o`000?oooooooooo03Cooooo0_l000000ooooooo0000o`00000Jooooo`;o
0000]oooool2o`0003Wooooo000Nooooo`03o`000?oooooooooo03Cooooo0_l000000ooooooo0000
o`00000Hooooo`;o0000B_ooool2o`000:Sooooo000Nooooo`03o`000?oooooooooo03Cooooo0_l0
000Kooooo`;o00007Oooool2o`0001Oooooo0_l0000Booooo`;o0000Z?ooool001kooooo00?o0000
ooooooooool0=?ooool2o`0003Wooooo0ol0000Gooooo`;o0000<?ooool2o`0007;ooooo0_l0000F
ooooo`007_ooool00ol0003oooooooooo`0fooooo`;o00001oooool2o`0002kooooo0_l0000Boooo
o`;o00003_ooool2o`0002Kooooo0_l0001booooo`;o00005_ooool001kooooo0_l0000gooooo`;o
00001oooool3o`0002cooooo0_l0000Cooooo`;o00003_ooool3o`000;7ooooo000Nooooo`03o`00
0?oooooooooo043ooooo0_l0000Wooooo`;o00000oooool2o`0002Cooooo0_l0000kooooo`;o0000
M?ooool001kooooo00?o0000ooooooooool0Aoooool2o`00023ooooo0_l0001Vooooo`;o0000M?oo
ool001kooooo00?o0000ooooooooool0Aoooool2o`0002_ooooo0_l0003Aooooo`007_ooool00ol0
003oooooooooo`0Mooooo`;o0000:Oooool2o`0002[ooooo0_l0001booooo`;o0000GOooool001ko
oooo00?o0000ooooooooool07Oooool2o`0000cooooo0_l00004ooooo`Co00003Oooool2o`0000Co
oooo0_l0000Zooooo`;o0000L_ooool2o`0005gooooo000Nooooo`03o`000?oooooooooo02_ooooo
0_l00004ooooo`Co00003Oooool2o`0000;ooooo0_l0000Zooooo`Co0000`oooool2o`0000cooooo
000Nooooo`03o`000?oooooooooo04Kooooo0_l00003ooooo`;o00009Oooool3o`0000Kooooo0_l0
002looooo`;o00003?ooool001kooooo00?o0000ooooooooool0?oooool4o`0000Sooooo0_l0000V
ooooo`;o00001_ooool2o`000<[ooooo000Nooooo`03o`000?oooooooooo03oooooo1?l0000joooo
o`;o00003_ooool2o`0008Oooooo0_l0000_ooooo`007_ooool00ol0003oooooooooo`1]ooooo`;o
00000oooool2o`0000Wooooo0_l0000>ooooo`;o0000Qoooool2o`0002oooooo000Nooooo`03o`00
0?oooooooooo047ooooo0_l0000:ooooo`;o00007_ooool2o`0000?ooooo1?l0003Aooooo`007_oo
ool00ol0003oooooooooo`11ooooo`;o00002_ooool2o`0000kooooo0_l0000Eooooo`;o00003_oo
ool2o`00027ooooo0_l0002Nooooo`007_ooool00ol0003oooooooooo`1Mooooo`;o00007_ooool2
o`0000Gooooo0_l0000?ooooo`;o00004?ooool2o`0009kooooo000Nooooo`;o0000:oooool2o`00
00_ooooo0_l00014ooooo`;o00005_ooool2o`000;3ooooo000Nooooo`;o0000:oooool2o`0000_o
oooo0_l0000]ooooo`;o00005Oooool2o`000<Sooooo000Nooooo`;o00006_ooool2o`0000?ooooo
0_l0000Looooo`;o0000:?ooool2o`0008Kooooo0_l0001Gooooo`007_ooool00ol0003ooooooooo
o`0Iooooo`;o00000oooool2o`0001cooooo0_l0001Iooooo`;o0000EOooool2o`0005Oooooo000N
ooooo`03o`000?oooooooooo02kooooo0_l0000dooooo`;o00004Oooool2o`0001kooooo0_l0001d
ooooo`;o0000>?ooool001kooooo00?o0000ooooooooool0;_ooool3o`0000Oooooo0_l0000Zoooo
o`;o00004Oooool2o`0009Cooooo0_l00009ooooo`;o00004oooool2o`0001Sooooo000Nooooo`03
o`000?oooooooooo02oooooo0_l00007ooooo`;o0000g_ooool2o`0001?ooooo0_l0000Hooooo`00
7_ooool00ol0003oooooooooo`0aooooo`;o0000?_ooool2o`000=Cooooo000Nooooo`03o`000?oo
oooooooo037ooooo0_l0000Fooooo`;o00009_ooool2o`0001Sooooo0_l0002jooooo`007_ooool3
o`0002kooooo1?l0000Gooooo`;o0000@?ooool2o`0000kooooo0_l0000kooooo`;o0000=_ooool2
o`0001oooooo0_l0000Dooooo`007_ooool3o`0002Gooooo0_l00007ooooo`Co0000B?ooool2o`00
01oooooo0_l0000kooooo`Co00008oooool2o`0000oooooo0_l0000:ooooo`;o00003Oooool2o`00
00Cooooo0_l0000Dooooo`007_ooool00ol0003oooooooooo`0Booooo`;o00004Oooool2o`0000go
oooo0_l00002ooooo`;o0000@?ooool2o`0005kooooo0_l0000Sooooo`;o00006oooool2o`0000go
oooo0_l0000Jooooo`007_ooool00ol0003oooooooooo`0Booooo`;o00004oooool2o`0000_ooooo
0_l00002ooooo`;o0000V?ooool2o`0005[ooooo0_l0000Gooooo`007_ooool00ol0003ooooooooo
o`0Wooooo`;o0000ZOooool2o`0004Kooooo0_l0000Booooo`;o00005oooool001kooooo00?o0000
ooooooooool09oooool2o`0000Kooooo0_l0003Yooooo`;o0000:oooool001kooooo00?o0000oooo
ooooool0;oooool2o`0001oooooo0_l00003ooooo`;o0000l?ooool001kooooo00?o0000oooooooo
ool0:Oooool2o`0001[ooooo0_l00009ooooo`;o00000oooool2o`000?3ooooo000Nooooo`03o`00
0?oooooooooo02Wooooo0_l0000Jooooo`;o00001_ooool2o`0002Wooooo0_l0003=ooooo`007_oo
ool2o`0004kooooo0_l0000Yooooo`;o0000/oooool2o`0001Sooooo000Nooooo`03o`000?oooooo
oooo06Gooooo0_l00005ooooo`;o0000<oooool2o`0002?ooooo0_l0001Uooooo`;o00006?ooool0
01kooooo00?o0000ooooooooool08?ooool2o`0003?ooooo0_l00002ooooo`;o00001_ooool2o`00
0004ooooool0003o0000o`0000Gooooo0_l00009ooooo`;o00009?ooool2o`0000;ooooo0_l0000S
ooooo`;o0000Doooool2o`0002[ooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l00005oooo
o`;o00006Oooool2o`0001Sooooo0_l00002ooooo`;o00001_ooool2o`000003ooooool0003o0000
017ooooo0_l0000Tooooo`;o00001?ooool4o`0007Cooooo0_l0000Zooooo`007_ooool00ol0003o
ooooooooo`0Iooooo`;o00002Oooool3o`0001Cooooo0_l0000Sooooo`;o00001?ooool2o`0000Wo
oooo0_l0000`ooooo`Co0000X?ooool001kooooo00?o0000ooooooooool09?ooool3o`000003oooo
ool0003o000003Kooooo0_l000001?oooooo0000o`000?ooool2o`0000Wooooo1?l00004ooooo`;o
00009oooool2o`000:?ooooo000Nooooo`03o`000?oooooooooo01kooooo0_l000000ooooooo0000
o`000005ooooo`;o0000:?ooool2o`0000Sooooo0_l00005ooooo`;o00003_ooool4o`0000;ooooo
0_l0000Vooooo`Go0000XOooool001kooooo00?o0000ooooooooool07_ooool5o`0002oooooo0_l0
0007ooooo`?o000000Coooooo`000?l0003ooooo0ol00005ooooo`;o000000?oooooo`000?l00000
1_ooool2o`0002Cooooo0_l00004ooooo`;o000000?oooooo`000?l00000Eoooool2o`00023ooooo
0_l0000Vooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o0000<oooool2o`000003ooooool0
003o000000Co00000_ooool2o`000004ooooool0003o0000o`0000Gooooo0_l000000ooooooo0000
o`000009ooooo`;o00008Oooool2o`00063ooooo0_l0000Pooooo`;o00009_ooool001kooooo00?o
0000ooooooooool0E?ooool7o`0000Oooooo0ol0000;ooooo`?o00001Oooool2o`0000Gooooo0_l0
000:ooooo`;o0000Y_ooool2o`0001;ooooo000Nooooo`03o`000?oooooooooo05Kooooo0ol0000:
ooooo`;o00002oooool3o`0000cooooo0_l0000:ooooo`;o0000Y_ooool2o`0000Sooooo0_l00008
ooooo`007_ooool00ol0003oooooooooo`1Cooooo`;o00001oooool2o`000003ooooool0003o0000
00;ooooo0_l00002ooooo`;o00000_ooool2o`0000Wooooo0_l0000Jooooo`;o00004_ooool2o`00
08kooooo0_l00005ooooo`;o00002?ooool001kooooo00?o0000ooooooooool0Doooool2o`0000Oo
oooo0_l000000ooooooo0000o`000006ooooo`;o00000_ooool4o`0000Oooooo0ol0000Iooooo`;o
00004_ooool2o`0000Kooooo0_l00006ooooo`;o0000O_ooool2o`0000oooooo000Nooooo`03o`00
0?oooooooooo00;o00005?ooool2o`0002;ooooo0_l0000aooooo`;o00002?ooool2o`0001Gooooo
0_l0000Nooooo`;o00001_ooool2o`0008;ooooo0_l0000;ooooo`000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003o
ooooooooo`02o`0001Cooooo0_l0000Kooooo`;o00001Oooool2o`00017ooooo0_l0000oooooo`;o
0000Z_ooool3o`0000[ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo01_ooooo0_l00005oooo
o`;o00003oooool2o`00013ooooo0_l00005ooooo`?o00005oooool2o`0001oooooo0_l0002boooo
o`;o00002_ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooo
ooooool000001_ooool3o`0001_ooooo0_l00005ooooo`;o00002?ooool2o`0001Kooooo0ol00002
ooooo`Go00002_ooool2o`0000Oooooo0_l00003ooooo`;o000000?oooooo`000?l000007?ooool2
o`000;kooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonH
V9So<S8b00Kooooo00?o0000ooooooooool09Oooool2o`0000Gooooo0_l0000Eooooo`?o00000ooo
ool5o`0000[ooooo0_l00007ooooo`;o00000_ooool2o`0000;ooooo0_l0003Looooo`000oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`00
0?oooooooooo02Gooooo0_l0000Booooo`;o00001_ooool4o`0000Gooooo1?l00002ooooo`Co0000
3oooool4o`000;oooooo0_l0000Dooooo`;o00002Oooool000?ooooo00Go410@oooooooooooooooo
oa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`0iooooo`;o
00001?ooool5o`0000Kooooo0_l000001?oooooo0000o`000?ooool4o`0000?ooooo0_l00008oooo
o`Co0000`Oooool4o`0001;ooooo1?l00007ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo00Cooooo0_l0000i
ooooo`;o000000?oooooo`000?l000001?ooool3o`000005ooooool0003o0000o`000?ooool00_l0
0005ooooo`;o00001?ooool2o`000003ooooool0003o000000Co00002Oooool2o`000;Oooooo0_l0
000Dooooo`;o00001oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@
413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`04ooooo`;o00006Oooool2o`00023ooooo
0_l00005ooooo`Oo000000?oooooo`000?l000002oooool5o`0000;ooooo0_l00009ooooo`;o0000
:?ooool2o`000:cooooo000Nooooo`03o`000?oooooooooo01oooooo0_l0000Oooooo`Co00000_oo
ool2o`0000?ooooo1?l00002ooooo`;o00002?ooool2o`0000;ooooo1?l0000fooooo`Co0000Z_oo
ool001kooooo00?o0000ooooooooool0;oooool2o`0000Sooooo0_l00002ooooo`co00000_ooool5
o`000003ooooool0003o000000Sooooo2?l0000hooooo`;o0000Z_ooool001kooooo00?o0000oooo
ooooool05?ooool2o`0001Wooooo0_l00007ooooo`?o000000?oooooo`000?l000002ol000000ooo
oooo0000o`000006o`0000Wooooo1?l0000Vooooo`;o00001?ooool2o`0000kooooo0_l0002Zoooo
o`007_ooool00ol0003oooooooooo`0Dooooo`;o00008?ooool4o`0000;ooooo1_l000000ooooooo
0000o`000004o`000003ooooool0003o000000Ko00001Oooool2o`0000;ooooo1?l0000Vooooo`;o
00001?ooool2o`0000Sooooo0_l0002`ooooo`007_ooool00ol0003oooooooooo`0fooooo`Oo0000
0oooool2o`000003ooooool0003o000000Wo000000?oooooo`000?l000001_ooool2o`0000?ooooo
0ol0000@ooooo`;o00009?ooool2o`000;3ooooo000Nooooo`03o`000?oooooooooo02cooooo0_l0
000<ooooo`?o00000oooool2o`000003ooooool0003o000000Oo000000?oooooo`000?l000000ooo
ool3o`0000Oooooo0ol00003ooooo`;o00002oooool2o`000=Kooooo000Nooooo`03o`000?oooooo
oooo02cooooo0_l00006ooooo`;o00003oooool5o`0000;ooooo0ol00003ooooo`?o00003Oooool2
o`0003gooooo0_l0002Tooooo`007_ooool00ol0003oooooooooo`0[ooooo`;o00001oooool2o`00
013ooooo0_l00002ooooo`Ko0000DOooool2o`0009[ooooo0_l000000ooooooo0000o`000005oooo
o`007_ooool00ol0003oooooooooo`0[ooooo`;o000000?oooooo`000?l000003Oooool2o`0000Ko
oooo0_l00003ooooo`;o000000Coooooo`000?l0003o0000@Oooool2o`0000_ooooo0_l0002Ioooo
o`;o00000_ooool2o`000003ooooool0003o000000Gooooo000Nooooo`03o`000?oooooooooo02_o
oooo1Ol0000=ooooo`;o00001_ooool3o`000003ooooool0003o000000Co000000Coooooo`000?l0
003ooooo0_l00004ooooo`;o00005Oooool2o`0001oooooo0_l0000;ooooo`;o0000VOooool2o`00
00cooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0000Nooooo`;o00000oooool2o`0000;o
oooo1?l0000<ooooo`;o00002Oooool2o`000003ooooool0003o000000Co000000Coooooo`000?l0
003ooooo0_l00004ooooo`;o00005Oooool2o`000=Gooooo000Nooooo`;o00000oooool2o`0001;o
oooo0_l0000:ooooo`;o00000oooool2o`0000Sooooo0_l00005ooooo`Go000000Coooooo`000?l0
003o00000oooool2o`0000?ooooo0ol000001?oooooo0000o`000?ooool2o`00027ooooo0_l00011
ooooo`;o0000C_ooool2o`0003oooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l0000Aoooo
o`;o00001_ooool4o`0000?ooooo1?l00002ooooo`?o00000oooool2o`0000?ooooo0ol00003oooo
o`;o00007Oooool2o`0000?ooooo0_l00011ooooo`;o0000C_ooool2o`0003oooooo000Nooooo`03
o`000?oooooooooo01Kooooo0_l0000Aooooo`;o00001oooool3o`00013ooooo1?l00004ooooo`Co
00002_ooool2o`0000Cooooo0_l00007ooooo`;o00000_ooool2o`0005[ooooo0_l0000Pooooo`;o
0000FOooool001kooooo00?o0000ooooooooool0<_ooool2o`0000;ooooo0_l00008ooooo`;o0000
0oooool4o`0000Cooooo0ol000000ooooooo0000o`000008ooooo`;o00001?ooool2o`0000?ooooo
0_l00002ooooo`;o0000G_ooool2o`00023ooooo0_l0001Iooooo`007_ooool00ol0003ooooooooo
o`0aooooo`Co000000?oooooo`000?l000002?ooool2o`000003ooooool0003o000000Oooooo0_l0
00000ooooooo0000o`000002o`0000Gooooo0_l00004ooooo`;o00001_ooool2o`0002gooooo0_l0
002`ooooo`007_ooool00ol0003oooooooooo`0Wooooo`?o00001oooool4o`000004ooooool0003o
0000o`0000[ooooo0_l00007ooooo`Go00001oooool2o`0000Cooooo0_l0000Iooooo`;o00005Ooo
ool2o`0000?ooooo0_l00025ooooo`;o0000:Oooool001kooooo00?o0000ooooooooool09oooool3
o`0000;ooooo0_l00003ooooo`So00001_ooool2o`0000[ooooo1Ol0000Uooooo`;o00000_ooool2
o`0001Gooooo0_l000000ooooooo0000o`000006ooooo`;o00008oooool2o`0005[ooooo0_l0000Y
ooooo`007_ooool00ol0003oooooooooo`0Kooooo`;o00002oooool2o`0000;ooooo1?l00002oooo
o`So00001Oooool3o`0000Gooooo2_l0000:ooooo`;o00002_ooool2o`0000cooooo0_l00005oooo
o`;o00002Oooool2o`0000[ooooo0_l00006ooooo`;o00008oooool2o`0008Gooooo000Nooooo`03
o`000?oooooooooo01_ooooo0_l0000;ooooo`;o00000oooool3o`0000;ooooo1?l00002ooooo`Co
00001?ooool2o`0000Gooooo1?l000000ooooooo0000o`000003o`0000[ooooo0_l0000:ooooo`;o
00004oooool2o`0000Wooooo0_l0002nooooo`007_ooool00ol0003oooooooooo`0Zooooo`;o0000
1_ooool6o`0000;ooooo0_l0000@ooooo`Ko00001oooool2o`0003?ooooo0ol0000Dooooo`;o0000
X?ooool001kooooo00?o0000ooooooooool0:_ooool2o`0000Kooooo0_l00002ooooo`;o00005Ooo
ool5o`0000Oooooo0ol0000booooo`?o00005?ooool2o`000:3ooooo000Nooooo`03o`000?oooooo
oooo03;ooooo1Ol0000Gooooo`;o00002_ooool2o`0000Oooooo1?l0000@ooooo`;o00004Oooool2
o`000;_ooooo000Nooooo`03o`000?oooooooooo027ooooo0_l0000>ooooo`So00001Oooool2o`00
02?ooooo1?l0000@ooooo`;o00004Oooool2o`0004Oooooo0_l0001booooo`007_ooool00ol0003o
ooooooooo`0Qooooo`;o00002Oooool2o`0000?ooooo0ol00003ooooo`;o00001Oooool2o`0001So
oooo0_l00009ooooo`Co0000K?ooool2o`0007;ooooo000Nooooo`03o`000?oooooooooo027ooooo
0_l00004ooooo`;o00000oooool2o`0000Oooooo1?l0000Iooooo`;o00001?ooool2o`000003oooo
ool0003o000000Cooooo0ol00002ooooo`;o0000=oooool2o`000:Kooooo000Nooooo`03o`000?oo
oooooooo02Oooooo0_l0000<ooooo`;o00005_ooool2o`0000?ooooo0_l00007ooooo`;o000000Co
ooooo`000?l0003ooooo0ol00002ooooo`;o0000=oooool2o`000:Kooooo000Nooooo`;o00008?oo
ool2o`000003ooooool0003o000001Gooooo0ol0000Aooooo`;o00002?ooool2o`0000;ooooo0_l0
00000ooooooo0000o`000004ooooo`;o0000A_ooool2o`0009Wooooo000Nooooo`03o`000?oooooo
oooo01oooooo0_l000000ooooooo0000o`00000:ooooo`;o00002Oooool3o`0000?ooooo0_l00000
0ooooooo0000o`000008ooooo`?o00002?ooool2o`0000Gooooo0_l00004ooooo`;o00000oooool2
o`00047ooooo0_l0002Iooooo`007_ooool00ol0003oooooooooo`0^ooooo`;o00003oooool2o`00
0003ooooool0003o000000Sooooo0_l0000@ooooo`;o00000_ooool2o`0000Gooooo0_l000000ooo
oooo0000o`00000]ooooo`;o00000_ooool2o`000:Kooooo000Nooooo`03o`000?oooooooooo01Ko
oooo0_l0000Fooooo`;o00007?ooool2o`0000kooooo1?l00002ooooo`;o00002?ooool2o`0002go
oooo0_l00002ooooo`;o0000Y_ooool001kooooo00?o0000ooooooooool05_ooool2o`0001Kooooo
0_l0000>ooooo`Co00002_ooool2o`0000kooooo1?l00002ooooo`;o00002?ooool3o`000=Sooooo
000Nooooo`03o`000?oooooooooo01cooooo0_l0000Pooooo`Co00002?ooool2o`00013ooooo1?l0
0002ooooo`;o00000oooool2o`0000?ooooo0ol0000Fooooo`;o0000:oooool2o`0009?ooooo000N
ooooo`03o`000?oooooooooo01cooooo0_l0000Rooooo`Co00001_ooool2o`0000Oooooo0ol00006
ooooo`Co00001?ooool6o`000003ooooool0003o000000Co00005?ooool2o`0002_ooooo0_l0001l
ooooo`;o00005Oooool001kooooo00?o0000ooooooooool0=Oooool2o`0000Wooooo1?l00007oooo
o`;o000000?oooooo`000?l000000oooool3o`0000Cooooo0_l00002ooooo`;o00000oooool4o`00
0003ooooool0003o000000Co000000?oooooo`000?l000003Oooool2o`0000;ooooo0_l00002oooo
o`;o0000Z?ooool2o`0001Gooooo000Nooooo`03o`000?oooooooooo03Gooooo0_l0000Dooooo`;o
000000?oooooo`000?l000001_ooool2o`0000;ooooo0_l00002ooooo`So00000_ooool6o`0000Wo
oooo0_l00005ooooo`;o00000_ooool2o`0000;ooooo0_l0000Jooooo`;o0000Xoooool001kooooo
00?o0000ooooooooool0C_ooool2o`0000Kooooo0_l00004ooooo`;o000000?oooooo`000?l00000
1_l000001?oooooo0000o`000?l0000<ooooo`;o00000oooool2o`0002Cooooo0_l0002Sooooo`00
7_ooool00ol0003oooooooooo`17ooooo`;o00004?ooool2o`000004ooooool0003o0000ooooo`So
00000_ooool2o`000004ooooool0003o0000o`0000gooooo0_l00008ooooo`;o0000_oooool001ko
oooo00?o0000ooooooooool0?_ooool2o`0000Gooooo1?l00005ooooo`;o000000?oooooo`000?l0
00001_ooool2o`0000Cooooo0ol000001?oooooo0000o`000?ooool2o`0000?ooooo1?l000000ooo
oooo0000o`000004ooooo`;o00003_ooool2o`0000kooooo0_l0002_ooooo`007_ooool00ol0003o
ooooooooo`0nooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000Oooooo0_l000000ooo
oooo0000o`000009ooooo`Go00000_ooool2o`000003ooooool0003o000000;o000000?oooooo`00
0?l000000oooool2o`0000?ooooo1Ol00003ooooo`;o00005oooool2o`000:oooooo000Nooooo`03
o`000?oooooooooo047ooooo0ol0000=ooooo`;o00002Oooool3o`0000Gooooo1_l00004ooooo`;o
000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000?ooooo0_l0000Sooooo`;o
0000Xoooool001kooooo00?o0000ooooooooool0>_ooool2o`00027ooooo0ol00004ooooo`Ko0000
1?ooool2o`000003ooooool0003o000000kooooo0_l0000Oooooo`;o0000Xoooool001kooooo00?o
0000ooooooooool0;oooool2o`0000Wooooo0_l00005ooooo`;o00001Oooool2o`0000[ooooo0_l0
0006ooooo`Ko00000_ooool2o`0000;ooooo0_l00009ooooo`;o00001Oooool2o`0000Gooooo0_l0
0034ooooo`007_ooool2o`00033ooooo0_l0000@ooooo`;o00000_ooool5o`0000Oooooo0_l00000
1?oooooo0000o`000?ooool2o`000003ooooool0003o000000;o00000_ooool3o`000004ooooool0
003o0000o`0000Cooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l0000^ooooo`;o0000
U?ooool001kooooo00?o0000ooooooooool0AOooool4o`0000Sooooo0_l00004ooooo`;o000000?o
ooooo`000?l000000_ooool:o`0000?ooooo0_l0000:ooooo`;o0000>?ooool2o`0009Cooooo000N
ooooo`03o`000?oooooooooo03[ooooo0_l00005ooooo`;o00003?ooool2o`0000Kooooo0_l00004
ooooo`?o00000_ooool8o`0000gooooo0_l0003>ooooo`007_ooool00ol0003oooooooooo`0joooo
o`;o00001Oooool3o`0000_ooooo0_l0000<ooooo`;o00001Oooool6o`0000Wooooo0_l0003Boooo
o`007_ooool00ol0003oooooooooo`0looooo`;o00001?ooool2o`0000Sooooo0_l00007ooooo`Co
00001oooool2o`0000?ooooo0_l0000<ooooo`Co00006oooool2o`000;?ooooo000Nooooo`03o`00
0?oooooooooo01oooooo0_l0000Kooooo`;o00003_ooool2o`0000Oooooo1?l00007ooooo`;o0000
2_ooool4o`0000Gooooo0_l0000Kooooo`;o00000oooool2o`000:kooooo000Nooooo`03o`000?oo
oooooooo01oooooo0_l00003ooooo`;o00003_ooool2o`0000Kooooo0_l0000Hooooo`?o00004ooo
ool4o`0002Oooooo0_l0000Booooo`;o0000V_ooool001kooooo00?o0000ooooooooool09?ooool2
o`0000kooooo0_l00006ooooo`;o00004Oooool2o`0000Gooooo0_l00005ooooo`;o00000_ooool2
o`0000;ooooo0_l00002ooooo`;o00003?ooool2o`0000Kooooo0_l0000Zooooo`;o00005Oooool2
o`0008?ooooo000Nooooo`03o`000?oooooooooo04oooooo0_l0000:ooooo`Co00000_ooool2o`00
00;ooooo1_l0000<ooooo`;o00001_ooool2o`0003Cooooo0_l0000;ooooo`;o0000Poooool001ko
oooo00?o0000ooooooooool0?_ooool2o`0001Cooooo0ol00004ooooo`Ko00001_ooool4o`0004[o
oooo0_l0002@ooooo`007_ooool00ol0003oooooooooo`0nooooo`;o00005?ooool3o`0000Kooooo
1?l00008ooooo`;o0000g?ooool001kooooo00?o0000ooooooooool0:oooool2o`0005cooooo0_l0
002]ooooo`;o00003Oooool001kooooo00?o0000ooooooooool04?ooool2o`0001Wooooo0ol00003
ooooo`;o00007?ooool2o`0000;ooooo0_l00004ooooo`Go0000:oooool2o`000:gooooo0_l0000=
ooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o00006_ooool2o`0000?ooooo0_l00004oooo
o`;o00002Oooool2o`0000Cooooo1?l00003ooooo`;o00000_ooool2o`0000;ooooo2Ol0000Qoooo
o`;o0000a?ooool001Cooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo03Oo
oooo0_l00009ooooo`;o00001?ooool4o`0000_ooooo1_l000000ooooooo0000o`00000Qooooo`;o
0000:?ooool2o`0009[ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
F?ooool5o`0004kooooo0_l0002Jooooo`005_ooool00ol0003oooooooooo`05ooooo`?o00009_oo
ool2o`0000Wooooo0_l00005ooooo`;o00007Oooool2o`0001?ooooo0_l0003Iooooo`005_ooool0
0ol0003oooooooooo`0^ooooo`;o00002Oooool2o`0000Gooooo0_l0000Mooooo`;o00004oooool2
o`000=Wooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000oooooooo
ool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Dooooo`03oeEEEOmV
IVKo00000?ooooooD_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.23613 .91612 Mdot
.9364 .98609 Mdot
.36905 .91715 Mdot
.17912 .86628 Mdot
.26618 .9104 Mdot
.23634 .89283 Mdot
.74703 .71067 Mdot
.29424 .89 Mdot
.19648 .83386 Mdot
.31796 .76246 Mdot
.31607 .69977 Mdot
.38688 .75164 Mdot
.34181 .94203 Mdot
.0354 .84542 Mdot
.27846 .89171 Mdot
.1234 .64895 Mdot
.08812 .00347 Mdot
.30901 .00642 Mdot
.26662 .92481 Mdot
.15418 .85896 Mdot
.89904 .14726 Mdot
.25762 .88232 Mdot
.38483 .94317 Mdot
.02102 .90639 Mdot
.18828 .80614 Mdot
.29093 .828 Mdot
.25213 .81263 Mdot
.12672 .66361 Mdot
.32739 .70546 Mdot
.25322 .87273 Mdot
.33045 .97208 Mdot
.27202 .89271 Mdot
.23407 .77819 Mdot
.12654 .1689 Mdot
.52329 .82688 Mdot
.18676 .77384 Mdot
.09139 .85461 Mdot
.06983 .95977 Mdot
.38552 .84945 Mdot
.21983 .80156 Mdot
.32097 .96062 Mdot
.45891 .78293 Mdot
.17748 .86405 Mdot
.01552 .95978 Mdot
.03388 .02108 Mdot
.47575 .78069 Mdot
.41951 .00966 Mdot
.34309 .04692 Mdot
.21966 .75265 Mdot
.36184 .58426 Mdot
.34248 .91348 Mdot
.39871 .94432 Mdot
.30066 .87487 Mdot
.18531 .76389 Mdot
.32152 .91327 Mdot
.31194 .71561 Mdot
.81543 .77283 Mdot
.31318 .93355 Mdot
.25652 .8154 Mdot
.21029 .8988 Mdot
.23499 .87775 Mdot
.28896 .86399 Mdot
.4909 .86685 Mdot
.17951 .80489 Mdot
.22294 .92846 Mdot
.22972 .88395 Mdot
.34359 .93382 Mdot
.25401 .81142 Mdot
.25177 .90919 Mdot
.7538 .74735 Mdot
.11492 .3652 Mdot
.18847 .63166 Mdot
.55741 .97957 Mdot
.27331 .00155 Mdot
.33498 .75179 Mdot
.79862 .70053 Mdot
.19893 .07434 Mdot
.3289 .56077 Mdot
.25816 .84928 Mdot
.02013 .82703 Mdot
.46587 .03264 Mdot
.63463 .33609 Mdot
.97398 .89621 Mdot
.29878 .88588 Mdot
.74766 .31176 Mdot
.81509 .38626 Mdot
.26692 .85439 Mdot
.22749 .80442 Mdot
.26698 .90568 Mdot
.15222 .7307 Mdot
.11547 .8176 Mdot
.63844 .51266 Mdot
.30568 .61631 Mdot
.23014 .30173 Mdot
.24029 .94312 Mdot
.43461 .04428 Mdot
.54033 .66038 Mdot
.46586 .88567 Mdot
.17762 .8046 Mdot
.49553 .71331 Mdot
.30122 .85639 Mdot
.34903 .95886 Mdot
.19541 .94883 Mdot
.04681 .76572 Mdot
.95276 .03404 Mdot
.37167 .95125 Mdot
.1563 .63864 Mdot
.12696 .65272 Mdot
.34396 .97681 Mdot
.61278 .92906 Mdot
.03241 .83759 Mdot
.93941 .84113 Mdot
.16481 .10217 Mdot
.31833 .99777 Mdot
.76888 .03854 Mdot
.69923 .79637 Mdot
.01362 .03031 Mdot
.35691 .93155 Mdot
.05741 .2681 Mdot
.075 .06895 Mdot
.24933 .78908 Mdot
.35084 .98844 Mdot
.30702 .81357 Mdot
.23046 .32508 Mdot
.22978 .54818 Mdot
.23207 .73186 Mdot
.305 .79139 Mdot
.25023 .92791 Mdot
.08235 .15287 Mdot
.59376 .93592 Mdot
.23651 .77456 Mdot
.21234 .62143 Mdot
.85064 .31251 Mdot
.30084 .01123 Mdot
.30187 .00092 Mdot
.35597 .99189 Mdot
.36548 .95378 Mdot
.15726 .59219 Mdot
.29209 .95667 Mdot
.21857 .87801 Mdot
.2498 .95058 Mdot
.17516 .79991 Mdot
.25365 .85465 Mdot
.56737 .79209 Mdot
.38204 .73476 Mdot
.39207 .74097 Mdot
.21124 .9566 Mdot
.26798 .82963 Mdot
.77131 .70567 Mdot
.71475 .28863 Mdot
.09292 .90863 Mdot
.25234 .80655 Mdot
.36824 .78821 Mdot
.15431 .84657 Mdot
.27582 .86916 Mdot
.34601 .91749 Mdot
.17767 .60364 Mdot
.58976 .86544 Mdot
.19842 .8295 Mdot
.16218 .63369 Mdot
.16476 .57304 Mdot
.51609 .73215 Mdot
.9355 .24109 Mdot
.30436 .0009 Mdot
.17727 .80801 Mdot
.28903 .9134 Mdot
.26155 .83484 Mdot
.21962 .82734 Mdot
.69708 .10864 Mdot
.29759 .99909 Mdot
.28915 .83964 Mdot
.55006 .01632 Mdot
.50994 .75291 Mdot
.91409 .51173 Mdot
.23687 .90685 Mdot
.29225 .61874 Mdot
.21529 .08665 Mdot
.31736 .83615 Mdot
.71523 .57119 Mdot
.40517 .93508 Mdot
.15349 .85616 Mdot
.34432 .71808 Mdot
.29337 .8136 Mdot
.02529 .07683 Mdot
.09816 .48453 Mdot
.29651 .04693 Mdot
.16954 .62988 Mdot
.11255 .82982 Mdot
.63568 .12901 Mdot
.56073 .77623 Mdot
.24295 .91241 Mdot
.86416 .21947 Mdot
.24341 .92701 Mdot
.01878 .08555 Mdot
.10629 .104 Mdot
.14819 .84888 Mdot
.53364 .76705 Mdot
.37591 .75922 Mdot
.19534 .8296 Mdot
.2967 .77284 Mdot
.22537 .98687 Mdot
.0566 .1157 Mdot
.30687 .00375 Mdot
.04006 .05005 Mdot
.18713 .80541 Mdot
.222 .80636 Mdot
.7386 .562 Mdot
.24903 .81485 Mdot
.53552 .21895 Mdot
.16199 .65648 Mdot
.30291 .97536 Mdot
.23368 .94649 Mdot
.13291 .3072 Mdot
.00413 .2448 Mdot
.15576 .59283 Mdot
.16919 .55678 Mdot
.23475 .82446 Mdot
.26716 .00026 Mdot
.25701 .61688 Mdot
.38685 .85398 Mdot
.99809 .82515 Mdot
.26465 .90601 Mdot
.17424 .79558 Mdot
.22169 .84077 Mdot
.18804 .80183 Mdot
.20771 .59799 Mdot
.57206 .86653 Mdot
.39841 .94548 Mdot
.27034 .2114 Mdot
.24606 .86396 Mdot
.32864 .87718 Mdot
.20455 .86397 Mdot
.2651 .84148 Mdot
.48759 .02808 Mdot
.18957 .62078 Mdot
.31992 .34017 Mdot
.39031 .35069 Mdot
.35107 .95971 Mdot
.94375 .73196 Mdot
.91537 .47073 Mdot
.297 .92353 Mdot
.27115 .85366 Mdot
.32701 .95498 Mdot
.19437 .99867 Mdot
.39279 .84867 Mdot
.17318 .04223 Mdot
.2598 .84342 Mdot
.27685 .85004 Mdot
.25479 .53577 Mdot
.33891 .94738 Mdot
.3759 .95339 Mdot
.32555 .92516 Mdot
.99107 .57059 Mdot
.7957 .46299 Mdot
.2641 .59663 Mdot
.26914 .00098 Mdot
.29062 .87772 Mdot
.01717 .59595 Mdot
.46676 .92881 Mdot
.82876 .1306 Mdot
.2302 .93408 Mdot
.23281 .99854 Mdot
.35352 .5707 Mdot
.30599 .09618 Mdot
.26568 .84826 Mdot
.84714 .31729 Mdot
.2452 .08919 Mdot
.0825 .45072 Mdot
.35765 .94612 Mdot
.23192 .80303 Mdot
.17686 .80401 Mdot
.57729 .56127 Mdot
.26183 .89105 Mdot
.2305 .99874 Mdot
.50282 .01557 Mdot
.34076 .94061 Mdot
.25245 .60772 Mdot
.36687 .32562 Mdot
.193 .75809 Mdot
.32168 .96289 Mdot
.85214 .77408 Mdot
.26103 .87449 Mdot
.33433 .989 Mdot
.10567 .87201 Mdot
.28116 .89614 Mdot
.17452 .79593 Mdot
.28914 .007 Mdot
.44333 .66121 Mdot
.22861 .97539 Mdot
.28217 .8714 Mdot
.26148 .93793 Mdot
.57801 .37417 Mdot
.27282 .92886 Mdot
.05449 .02787 Mdot
.67857 .40475 Mdot
.47443 .66127 Mdot
.25906 .93077 Mdot
.18416 .59987 Mdot
.86351 .73341 Mdot
.60397 .1984 Mdot
.41145 .66828 Mdot
.199 .78787 Mdot
.54133 .80349 Mdot
.2678 .81229 Mdot
.48088 .55691 Mdot
.26566 .99205 Mdot
.24962 .81751 Mdot
.26578 .84397 Mdot
.10877 .12024 Mdot
.00498 .14496 Mdot
.24819 .80008 Mdot
.85196 .70666 Mdot
.29224 .83206 Mdot
.2748 .88698 Mdot
.18568 .81602 Mdot
.1594 .85538 Mdot
.30547 .65144 Mdot
.85622 .54909 Mdot
.23093 .75182 Mdot
.15297 .00932 Mdot
.36678 .86814 Mdot
.2565 .78039 Mdot
.32318 .95792 Mdot
.24829 .73843 Mdot
.32068 .99576 Mdot
.3372 .88707 Mdot
.19565 .75709 Mdot
.22409 .94478 Mdot
.37211 .75031 Mdot
.31439 .87007 Mdot
.13171 .84967 Mdot
.23756 .90592 Mdot
.47022 .40237 Mdot
.15262 .70452 Mdot
.12685 .50142 Mdot
.29887 .64201 Mdot
.09567 .00391 Mdot
.24899 .79868 Mdot
.05601 .51001 Mdot
.81328 .38228 Mdot
.1755 .8017 Mdot
.92674 .14662 Mdot
.23427 .95899 Mdot
.24368 .74084 Mdot
.8329 .91383 Mdot
.62729 .6323 Mdot
.73979 .22227 Mdot
.29181 .82666 Mdot
.1012 .48046 Mdot
.28923 .89086 Mdot
.36249 .93234 Mdot
.30361 .89974 Mdot
.52204 .80615 Mdot
.08074 .69669 Mdot
.81643 .5517 Mdot
.25179 .884 Mdot
.48859 .78293 Mdot
.30406 .9871 Mdot
.32304 .95292 Mdot
.25535 .23507 Mdot
.26905 .86265 Mdot
.51183 .84181 Mdot
.3208 .96826 Mdot
.31667 .9735 Mdot
.17844 .7911 Mdot
.50427 .8767 Mdot
.20346 .07645 Mdot
.65886 .16943 Mdot
.0084 .40731 Mdot
.2523 .90343 Mdot
.14773 .58288 Mdot
.24261 .82374 Mdot
.35876 .92453 Mdot
.2237 .86919 Mdot
.59979 .95305 Mdot
.45321 .69493 Mdot
.07713 .01302 Mdot
.21369 .76733 Mdot
.94841 .55696 Mdot
.26621 .83349 Mdot
.25379 .857 Mdot
.13303 .86927 Mdot
.98474 .44885 Mdot
.30479 .6282 Mdot
.17577 .65262 Mdot
.00229 .05799 Mdot
.13158 .01978 Mdot
.5548 .96624 Mdot
.24723 .80342 Mdot
.02145 .84904 Mdot
.25063 .95196 Mdot
.27568 .96649 Mdot
.31549 .86573 Mdot
.26861 .9119 Mdot
.25935 .90405 Mdot
.53737 .38373 Mdot
.11076 .95934 Mdot
.83656 .31132 Mdot
.25819 .81338 Mdot
.31915 .98423 Mdot
.18373 .84823 Mdot
.09992 .98446 Mdot
.64133 .85451 Mdot
.29329 .87128 Mdot
.1538 .8269 Mdot
.43042 .97072 Mdot
.27966 .85876 Mdot
.15035 .67056 Mdot
.28113 .7457 Mdot
.30428 .00353 Mdot
.14908 .58536 Mdot
.20088 .81549 Mdot
.15728 .57845 Mdot
.84774 .77342 Mdot
.89084 .52821 Mdot
.29921 .00818 Mdot
.16653 .96682 Mdot
.19878 .58695 Mdot
.63226 .57664 Mdot
.26241 .84797 Mdot
.22339 .81302 Mdot
.04911 .6145 Mdot
.37267 .37668 Mdot
.28434 .98734 Mdot
.31412 .91964 Mdot
.11562 .08332 Mdot
.17875 .02664 Mdot
.2111 .84972 Mdot
.18906 .6198 Mdot
.49331 .16426 Mdot
.84698 .50704 Mdot
.61169 .01734 Mdot
.0385 .81529 Mdot
.12695 .8711 Mdot
.22298 .65096 Mdot
.55359 .58816 Mdot
.21836 .63922 Mdot
.53285 .8723 Mdot
.16963 .0248 Mdot
.03862 .01782 Mdot
.22612 .08311 Mdot
.99018 .96068 Mdot
.9829 .91384 Mdot
.25484 .88228 Mdot
.28775 .26567 Mdot
.26005 .85143 Mdot
.26073 .75891 Mdot
.27123 .95376 Mdot
.59046 .4928 Mdot
.37858 .9304 Mdot
.19959 .65639 Mdot
.31918 .96815 Mdot
.17577 .80118 Mdot
.24081 .84956 Mdot
.27096 .8772 Mdot
.25218 .80549 Mdot
.19055 .8143 Mdot
.18582 .76335 Mdot
.1578 .14627 Mdot
.65005 .67441 Mdot
.20813 .88703 Mdot
.23301 .81369 Mdot
.24354 .86202 Mdot
.35039 .88489 Mdot
.01955 .80081 Mdot
.46129 .88341 Mdot
.24589 .77424 Mdot
.10664 .74049 Mdot
.27431 .88892 Mdot
.53517 .95075 Mdot
.25361 .89311 Mdot
.27014 .85045 Mdot
.29411 .88346 Mdot
.29666 .88509 Mdot
.32935 .92842 Mdot
.2675 .87817 Mdot
.29926 .93128 Mdot
.31486 .90933 Mdot
.90795 .82727 Mdot
.28315 .7969 Mdot
.3509 .5688 Mdot
.01896 .0693 Mdot
.2642 .86511 Mdot
.25158 .96455 Mdot
.23685 .91919 Mdot
.94288 .57107 Mdot
.17544 .75476 Mdot
.44772 .48073 Mdot
.56671 .98303 Mdot
.08983 .69344 Mdot
.35526 .93803 Mdot
.21231 .82232 Mdot
.5431 .35368 Mdot
.11687 .98998 Mdot
.15283 .79173 Mdot
.36877 .75887 Mdot
.11807 .98458 Mdot
.28125 .73575 Mdot
.0179 .85116 Mdot
.26268 .66157 Mdot
.12704 .02453 Mdot
.58351 .86416 Mdot
.5503 .03187 Mdot
.18451 .30486 Mdot
.29869 .00597 Mdot
.44999 .68693 Mdot
.27535 .84943 Mdot
.6367 .51496 Mdot
.19469 .81218 Mdot
.239 .85289 Mdot
.27667 .99625 Mdot
.40222 .49088 Mdot
.30961 .58714 Mdot
.02208 .56749 Mdot
.26592 .89055 Mdot
.52052 .01367 Mdot
.17357 .81038 Mdot
.42777 .05822 Mdot
.80792 .45804 Mdot
.30916 .9951 Mdot
.30302 .97468 Mdot
.34709 .90939 Mdot
.25481 .85267 Mdot
.31521 .78823 Mdot
.47578 .77206 Mdot
.20752 .83621 Mdot
.52646 .26148 Mdot
.21386 .59575 Mdot
.24509 .83385 Mdot
.18429 .13881 Mdot
.86161 .10735 Mdot
.27622 .66729 Mdot
.27488 .89767 Mdot
.38143 .87761 Mdot
.30579 .89111 Mdot
.29735 .84362 Mdot
.21011 .9171 Mdot
.19518 .78849 Mdot
.20761 .07576 Mdot
.47337 .11466 Mdot
.2195 .8799 Mdot
.84269 .59218 Mdot
.38216 .73569 Mdot
.27048 .86919 Mdot
.28303 .93405 Mdot
.57202 .7093 Mdot
.57699 .49809 Mdot
.37668 .89886 Mdot
.33582 .99312 Mdot
.33591 .89109 Mdot
.75015 .64032 Mdot
.19278 .03082 Mdot
.21577 .78551 Mdot
.07193 .08523 Mdot
.39399 .00761 Mdot
.23592 .56741 Mdot
.45424 .52789 Mdot
.25218 .79493 Mdot
.14938 .80362 Mdot
.02368 .97573 Mdot
.31377 .0049 Mdot
.26148 .73056 Mdot
.15762 .02581 Mdot
.35544 .70267 Mdot
.29017 .00627 Mdot
.21496 .74963 Mdot
.17283 .58627 Mdot
.17392 .79899 Mdot
.62085 .35495 Mdot
.26172 .90422 Mdot
.60643 .90303 Mdot
.04824 .74099 Mdot
.26379 .88386 Mdot
.21423 .95495 Mdot
.28667 .96675 Mdot
.21862 .83465 Mdot
.52432 .89644 Mdot
.32511 .70795 Mdot
.33528 .92994 Mdot
.14789 .00777 Mdot
.07976 .68147 Mdot
.6783 .58266 Mdot
.27496 .94025 Mdot
.26233 .95948 Mdot
.28266 .13567 Mdot
.20303 .79193 Mdot
.26975 .05893 Mdot
.76711 .91801 Mdot
.03706 .93308 Mdot
.22096 .94814 Mdot
.31725 .91482 Mdot
.32202 .91558 Mdot
.26046 .73632 Mdot
.28329 .75492 Mdot
.40176 .74662 Mdot
.29514 .83998 Mdot
.23851 .62739 Mdot
.329 .88998 Mdot
.19919 .77859 Mdot
.30738 .93656 Mdot
.23147 .83155 Mdot
.23087 .82319 Mdot
.3659 .92874 Mdot
.47033 .8813 Mdot
.36793 .01232 Mdot
.30653 .99713 Mdot
.24572 .80877 Mdot
.26313 .87326 Mdot
.24143 .00066 Mdot
.23598 .9238 Mdot
.19788 .02315 Mdot
.66247 .44509 Mdot
.26127 .91458 Mdot
.43375 .04998 Mdot
.25803 .92887 Mdot
.19674 .63687 Mdot
.17805 .61114 Mdot
.91894 .55606 Mdot
.18431 .80307 Mdot
.57072 .589 Mdot
.46674 .17331 Mdot
.64873 .83262 Mdot
.24129 .92192 Mdot
.81241 .5858 Mdot
.47242 .88448 Mdot
.20359 .08007 Mdot
.81207 .32035 Mdot
.82443 .36603 Mdot
.35312 .94528 Mdot
.44254 .87734 Mdot
.31107 .95614 Mdot
.21773 .8349 Mdot
.21684 .93211 Mdot
.08695 .82639 Mdot
.26059 .88574 Mdot
.37349 .65435 Mdot
.30074 .88984 Mdot
.23284 .85913 Mdot
.26123 .94437 Mdot
.27788 .9022 Mdot
.24028 .8216 Mdot
.24937 .89801 Mdot
.44897 .80542 Mdot
.42633 .8647 Mdot
.49175 .0491 Mdot
.29682 .96977 Mdot
.34616 .82985 Mdot
.84701 .83915 Mdot
.30846 .88433 Mdot
.239 .00816 Mdot
.99519 .88409 Mdot
.31302 .71352 Mdot
.3148 .13981 Mdot
.2226 .84723 Mdot
.5748 .489 Mdot
.21463 .80158 Mdot
.31124 .87912 Mdot
.00201 .72678 Mdot
.57071 .25356 Mdot
.25588 .8098 Mdot
.0765 .00776 Mdot
.37475 .91781 Mdot
.58202 .39388 Mdot
.2443 .77481 Mdot
.86057 .28895 Mdot
.20033 .05814 Mdot
.2651 .84574 Mdot
.77907 .58499 Mdot
.47988 .71717 Mdot
.28367 .05423 Mdot
.50005 .11931 Mdot
.64632 .26525 Mdot
.02687 .10831 Mdot
.26466 .80072 Mdot
.979 .3935 Mdot
.28656 .84466 Mdot
.97789 .99763 Mdot
.28103 .9771 Mdot
.67862 .22248 Mdot
.62002 .20511 Mdot
.03344 .91579 Mdot
.57059 .78651 Mdot
.94519 .50946 Mdot
.25261 .92151 Mdot
.26117 .90266 Mdot
.4744 .67359 Mdot
.37763 .88603 Mdot
.714 .14436 Mdot
.08531 .97492 Mdot
.31974 .98587 Mdot
.31576 .04094 Mdot
.98904 .03168 Mdot
.36482 .62033 Mdot
.58266 .80271 Mdot
.24325 .80312 Mdot
.36674 .92415 Mdot
.23753 .85612 Mdot
.3721 .76658 Mdot
.45804 .63707 Mdot
.9998 .59694 Mdot
.2913 .00177 Mdot
.07007 .70014 Mdot
.35066 .92164 Mdot
.28465 .95704 Mdot
.06871 .59951 Mdot
.29508 .80177 Mdot
.35688 .91548 Mdot
.92653 .77689 Mdot
.20842 .92029 Mdot
.19774 .81915 Mdot
.44779 .48256 Mdot
.18957 .63234 Mdot
.04646 .95477 Mdot
.8944 .65835 Mdot
.38876 .9408 Mdot
.69538 .61559 Mdot
.27296 .85787 Mdot
.26954 .89424 Mdot
.56316 .70757 Mdot
.2834 .84647 Mdot
.22599 .94954 Mdot
.53044 .04964 Mdot
.30332 .98577 Mdot
.79665 .60205 Mdot
.97888 .845 Mdot
.79984 .716 Mdot
.02547 .67333 Mdot
.2503 .78259 Mdot
.46744 .8947 Mdot
.85063 .84429 Mdot
.30232 .78772 Mdot
.28962 .81738 Mdot
.35987 .90996 Mdot
.20603 .85341 Mdot
.58459 .76781 Mdot
.66098 .01307 Mdot
.57602 .45617 Mdot
.45957 .46524 Mdot
.35192 .82935 Mdot
.6305 .42394 Mdot
.26725 .9034 Mdot
.15661 .88157 Mdot
.24647 .91353 Mdot
.72505 .67218 Mdot
.54609 .00966 Mdot
.32079 .80239 Mdot
.26185 .8258 Mdot
.82196 .79234 Mdot
.25517 .73614 Mdot
.88456 .62073 Mdot
.32946 .90743 Mdot
.31161 .9343 Mdot
.12327 .00937 Mdot
.21842 .95235 Mdot
.30478 .98388 Mdot
.18235 .83086 Mdot
.28162 .99468 Mdot
.49933 .0088 Mdot
.30297 .9193 Mdot
.34921 .94781 Mdot
.85928 .79708 Mdot
.29014 .88486 Mdot
.32771 .10331 Mdot
.30669 .94472 Mdot
.27501 .89276 Mdot
.21526 .88001 Mdot
.51683 .75547 Mdot
.78931 .62111 Mdot
.37581 .7603 Mdot
.29367 .02369 Mdot
.18268 .80164 Mdot
.17321 .86787 Mdot
.3565 .97161 Mdot
.32539 .92521 Mdot
.72669 .45928 Mdot
.27666 .97379 Mdot
.25013 .81256 Mdot
.35624 .93963 Mdot
.27567 .87838 Mdot
.23149 .38069 Mdot
.17212 .86998 Mdot
.17427 .08243 Mdot
.85479 .54684 Mdot
.51947 .9627 Mdot
.22953 .88371 Mdot
.18496 .6001 Mdot
.10302 .68257 Mdot
.2167 .87512 Mdot
.21359 .82392 Mdot
.35157 .9001 Mdot
.44465 .60595 Mdot
.00104 .41302 Mdot
.25462 .73072 Mdot
.30468 .81913 Mdot
.4627 .6355 Mdot
.31208 .88152 Mdot
.07533 .7057 Mdot
.33545 .60895 Mdot
.14348 .83441 Mdot
.21293 .77639 Mdot
.97921 .89511 Mdot
.26176 .86986 Mdot
.28054 .9353 Mdot
.09556 .1174 Mdot
.2111 .75456 Mdot
.30629 .00857 Mdot
.47823 .1965 Mdot
.25753 .18635 Mdot
.5069 .70961 Mdot
.29568 .94627 Mdot
.47188 .68694 Mdot
.16004 .80665 Mdot
.35278 .90482 Mdot
.37264 .13246 Mdot
.10738 .84808 Mdot
.23908 .83162 Mdot
.29745 .47503 Mdot
.77751 .72646 Mdot
.27905 .8793 Mdot
.75777 .59623 Mdot
.30201 .8905 Mdot
.32152 .89906 Mdot
.21712 .77382 Mdot
.34385 .91894 Mdot
.27123 .86333 Mdot
.16023 .58779 Mdot
.29316 .86364 Mdot
.17663 .80277 Mdot
.7424 .48726 Mdot
.32359 .93564 Mdot
.00907 .04617 Mdot
.43755 .64819 Mdot
.30443 .97127 Mdot
.67556 .64278 Mdot
.36948 .81501 Mdot
.3034 .01051 Mdot
.38888 .55757 Mdot
.21966 .75334 Mdot
.19036 .78159 Mdot
.99134 .4541 Mdot
.34791 .12935 Mdot
.32633 .89758 Mdot
.2526 .81844 Mdot
.20658 .85104 Mdot
.80478 .74535 Mdot
.59502 .81649 Mdot
.24063 .70736 Mdot
.36903 .92112 Mdot
.29109 .84129 Mdot
.30596 .93688 Mdot
.13317 .94801 Mdot
.18086 .69292 Mdot
.31271 .95464 Mdot
.2267 .01383 Mdot
.25685 .78754 Mdot
.97725 .47943 Mdot
.29584 .88803 Mdot
.28191 .3449 Mdot
.27529 .79926 Mdot
.30261 .92869 Mdot
.31429 .89011 Mdot
.20834 .86729 Mdot
.20255 .81994 Mdot
.2664 .87792 Mdot
.29813 .82939 Mdot
.34188 .71578 Mdot
.26234 .92229 Mdot
.23498 .62341 Mdot
.28554 .70264 Mdot
.32796 .91474 Mdot
.13382 .74797 Mdot
.26681 .80087 Mdot
.18149 .80186 Mdot
.16666 .84146 Mdot
.49076 .00129 Mdot
.26241 .86964 Mdot
.28525 .99 Mdot
.25551 .29727 Mdot
.17637 .00257 Mdot
.29323 .98304 Mdot
.59066 .89213 Mdot
.24275 .88659 Mdot
.29027 .88137 Mdot
.31499 .87894 Mdot
.19549 .93239 Mdot
.23639 .91553 Mdot
.22384 .94649 Mdot
.81294 .60785 Mdot
.25828 .8795 Mdot
.49238 .91946 Mdot
.19193 .38137 Mdot
.3858 .41445 Mdot
.22017 .97628 Mdot
.26386 .86966 Mdot
.83065 .9168 Mdot
.25584 .90311 Mdot
.97309 .74864 Mdot
.27544 .89783 Mdot
.17873 .8792 Mdot
.23623 .819 Mdot
.29137 .9875 Mdot
.30241 .0451 Mdot
.29559 .56279 Mdot
.15596 .99609 Mdot
.82972 .62385 Mdot
.60559 .78916 Mdot
.48216 .99723 Mdot
.24319 .98016 Mdot
.28362 .93837 Mdot
.23093 .96495 Mdot
.38311 .92251 Mdot
.38764 .94165 Mdot
.10579 .5641 Mdot
.19633 .79976 Mdot
.39606 .79324 Mdot
.24787 .93352 Mdot
.5104 .84128 Mdot
.15044 .86237 Mdot
.4567 .06862 Mdot
.20683 .8483 Mdot
.34885 .35869 Mdot
.41405 .63635 Mdot
.27446 .02264 Mdot
.30775 .88367 Mdot
.27671 .89801 Mdot
.02685 .53007 Mdot
.22437 .46395 Mdot
.27196 .88549 Mdot
.29442 .22132 Mdot
.55809 .24195 Mdot
.24472 .87418 Mdot
.35497 .95888 Mdot
.32272 .91012 Mdot
.26476 .84669 Mdot
.86751 .21548 Mdot
.24719 .94028 Mdot
.07041 .4044 Mdot
.28912 .8259 Mdot
.26499 .84187 Mdot
.87845 .77446 Mdot
.33428 .92357 Mdot
.29974 .93337 Mdot
.18868 .80567 Mdot
.60988 .61082 Mdot
.18016 .97665 Mdot
.24363 .8865 Mdot
.56932 .0701 Mdot
.35639 .86567 Mdot
.21559 .87335 Mdot
.33871 .57855 Mdot
.27057 .91363 Mdot
.9635 .72729 Mdot
.36557 .86892 Mdot
.08586 .49199 Mdot
.11641 .92669 Mdot
.37299 .91244 Mdot
.85377 .51583 Mdot
.39914 .6634 Mdot
.38922 .92266 Mdot
.08493 .25672 Mdot
.26066 .8793 Mdot
.23367 .84136 Mdot
.27988 .88365 Mdot
.18968 .80581 Mdot
.32704 .88523 Mdot
.77733 .4511 Mdot
.18555 .57904 Mdot
.20469 .59115 Mdot
.79786 .61179 Mdot
.68152 .0706 Mdot
.23219 .99017 Mdot
.69324 .06256 Mdot
.96825 .83989 Mdot
.66007 .64462 Mdot
.06851 .77638 Mdot
.27819 .85736 Mdot
.17885 .59969 Mdot
.21064 .54246 Mdot
.25554 .82813 Mdot
.2734 .80678 Mdot
.27927 .92028 Mdot
.25902 .90936 Mdot
.33173 .18518 Mdot
.16439 .62941 Mdot
.25817 .81929 Mdot
.32956 .96272 Mdot
.21648 .92412 Mdot
.64652 .1166 Mdot
.44496 .92802 Mdot
.26591 .81112 Mdot
.85498 .30047 Mdot
.1692 .86273 Mdot
.33808 .80833 Mdot
.26841 .45177 Mdot
.18869 .78541 Mdot
.2496 .77908 Mdot
.32088 .88133 Mdot
.39886 .60147 Mdot
.18812 .59883 Mdot
.31907 .80401 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool02Oooool5o`0000oooooo00?o0000ooooooooool01Oooool2o`0000Oo
oooo00?o0000ooooooooool02Oooool2o`0000;ooooo00?o0000ooooooooool00_ooool4o`0000Co
oooo0_l000000ooooooo0000o`000002o`0000cooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo0_l00002ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool00_ooool001kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`09ooooo`Go00003oooool00ol0003oooooooooo`05ooooo`;o00001oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Cooooo0_l00003ooooo`[o00002_ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00;ooooo000Nooooo`03o`000?oooooooooo01Gooooo0_l0
000=ooooo`;o00001_ooool4o`0001[ooooo0_l0000>ooooo`;o000000?oooooo`000?l000001Ol0
000Hooooo`;o00001_ooool2o`0001Sooooo0_l0000=ooooo`;o0000V?ooool001kooooo00?o0000
ooooooooool05Oooool2o`0000gooooo0_l00006ooooo`Co00006_ooool2o`00017ooooo1?l0000C
ooooo`;o00001_ooool2o`0000Kooooo0_l0000Hooooo`;o00001Oooool2o`0000Kooooo0_l0000T
ooooo`;o0000L_ooool001kooooo00?o0000ooooooooool05Oooool2o`0002oooooo0_l0000Foooo
o`;o00005?ooool2o`0002Wooooo0_l00004ooooo`;o00002?ooool2o`0002;ooooo0_l0001boooo
o`007_ooool00ol0003oooooooooo`08ooooo`;o00007Oooool2o`0001gooooo0_l0001Gooooo`;o
00003_ooool2o`0001;ooooo0_l00022ooooo`007_ooool00ol0003oooooooooo`07ooooo`?o0000
7Oooool2o`0002cooooo0_l0001/ooooo`;o0000P_ooool001kooooo00?o0000ooooooooool01ooo
ool2o`0001cooooo0_l00008ooooo`;o00000_ooool2o`0000Oooooo0_l0000Gooooo`;o00001?oo
ool2o`000>[ooooo000Nooooo`03o`000?oooooooooo00kooooo0_l0000Eooooo`;o00002?ooool2
o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`;o00007Oooool2o`0003gooooo0_l0002[
ooooo`007_ooool00ol0003oooooooooo`02o`0000cooooo0_l0000Vooooo`;o00000oooool2o`00
05gooooo0_l0000Cooooo`;o0000S?ooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo00;o
0000>Oooool2o`0005Kooooo0_l0000Jooooo`;o0000POooool2o`0000Wooooo0_l00008ooooo`00
7_ooool00ol0003oooooooooo`2Cooooo`;o0000WOooool2o`0001?ooooo000Nooooo`03o`000?oo
oooooooo06?ooooo0_l0002Aooooo`;o0000Coooool001kooooo00?o0000ooooooooool0=?ooool2
o`0002gooooo0_l0000Tooooo`;o0000Joooool2o`0004oooooo000Nooooo`04o`000?oooooo0000
o`0003?ooooo0_l0000Vooooo`Co00002oooool2o`0001cooooo0_l0002looooo`007_ooool01?l0
003oooooo`000?l00008ooooo`;o0000DOooool4o`0000_ooooo0_l0000Looooo`;o00004Oooool2
o`0000[ooooo0_l0002Mooooo`007_ooool2o`0000[ooooo0_l0001nooooo`;o00004Oooool2o`00
00[ooooo0_l0002Mooooo`007_ooool00ol0003oooooooooo`1Hooooo`;o0000kOooool001kooooo
0_l0000nooooo`;o00005Oooool2o`0000;ooooo0_l0000]ooooo`;o0000__ooool001kooooo0_l0
000nooooo`;o00005Oooool2o`00037ooooo0_l0001Dooooo`;o0000J?ooool001kooooo00?o0000
ooooooooool0gOooool2o`0006Sooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0001joooo
o`;o0000]Oooool001kooooo00?o0000ooooooooool00_ooool2o`00013ooooo0_l0001jooooo`;o
00008oooool2o`0002;ooooo0_l0001/ooooo`007_ooool00ol0003oooooooooo`02ooooo`;o0000
>Oooool2o`0007Kooooo0_l0000Rooooo`;o0000K?ooool001kooooo00?o0000ooooooooool01?oo
ool2o`0003Oooooo1?l0003oooooo`Oooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0000h
ooooo`?o0000ooooool7ooooo`007_ooool00ol0003oooooooooo`0Qooooo`;o00004_ooool2o`00
00Oooooo0_l00005ooooo`;o0000ooooool1ooooo`007_ooool00ol0003oooooooooo`02ooooo`;o
00003oooool2o`0000cooooo0_l0000Booooo`;o00002oooool2o`000003ooooool0003o00000?oo
oooo0Oooool001kooooo00?o0000ooooooooool00_ooool2o`0000oooooo0_l0000]ooooo`;o0000
2?ooool2o`000?Wooooo000Nooooo`03o`000?oooooooooo04cooooo0_l0003iooooo`007_ooool0
0ol0003oooooooooo`1Oooooo`;o0000i_ooool001kooooo00?o0000ooooooooool0Goooool2o`00
0>Kooooo000Nooooo`;o0000<_ooool2o`000?oooooo5Oooool001kooooo00?o0000ooooooooool0
7_ooool2o`00017ooooo0_l0000cooooo`;o0000goooool001kooooo00?o0000ooooooooool01Ooo
ool2o`0001Oooooo0_l00016ooooo`;o0000Moooool2o`0003?ooooo0_l0000aooooo`007_ooool0
0ol0003oooooooooo`05ooooo`;o0000f?ooool2o`0003?ooooo0_l0000aooooo`007_ooool00ol0
003oooooooooo`2Fooooo`;o0000[oooool001kooooo00?o0000ooooooooool03_ooool2o`0000_o
oooo0_l0001iooooo`;o0000=_ooool2o`0007Oooooo000Nooooo`03o`000?oooooooooo00kooooo
0_l0000;ooooo`;o00000_ooool2o`0007gooooo0_l0000^ooooo`;o0000Moooool001kooooo00?o
0000ooooooooool07oooool2o`0007gooooo0_l0002Wooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo06gooooo0_l0001Looooo`;o0000??ooool2o`00
03cooooo000Nooooo`03o`000?oooooooooo06gooooo0_l00006ooooo`;o0000E?ooool2o`0003co
oooo0_l0000looooo`007_ooool00ol0003oooooooooo`1Hooooo`;o00006oooool2o`000=3ooooo
000Nooooo`03o`000?oooooooooo03Sooooo0_l0000Nooooo`;o00002?ooool2o`000>?ooooo000N
ooooo`03o`000?oooooooooo03Sooooo0_l0000Xooooo`;o0000hoooool001kooooo0_l0003Uoooo
o`;o0000HOooool001kooooo0_l0000`ooooo`;o0000/oooool2o`0003[ooooo0_l00007ooooo`;o
00007?ooool001kooooo0_l0000`ooooo`;o0000koooool2o`0000Oooooo0_l0000Looooo`007_oo
ool00ol0003oooooooooo`0Gooooo`;o0000ooooool_ooooo`007_ooool00ol0003oooooooooo`0G
ooooo`;o0000ooooool_ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo09cooooo0_l0002Yooooo`007_ooool00ol0003oooooooooo`2Looooo`;o0000
ZOooool001kooooo00?o0000ooooooooool09Oooool2o`000:_ooooo0_l0001cooooo`007_ooool0
0ol0003oooooooooo`0Uooooo`;o0000KOooool2o`0003cooooo0_l0001cooooo`007_ooool00ol0
003oooooooooo`2Dooooo`;o0000/Oooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo06Sooooo0_l0
003Mooooo`007_ooool00ol0003oooooooooo`1@ooooo`;o00005_ooool2o`000=gooooo000Noooo
o`03o`000?oooooooooo053ooooo0_l0003eooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006
ooooo`03o`000?oooooooooo09Oooooo0_l0002^ooooo`000oooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool3o`0009Oooooo0_l0000Wooooo`;o0000QOooool0
00?ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000
ooooooooool0`?ooool2o`0008Gooooo0003ooooo`05o`000?ooooooooooooooool000003_ooool0
0omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0<Gooooo0_l00020ooooo`000oooool01Ol@
413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`35
ooooo`;o0000P?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`1Dooooo`;o0000lOooool000?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`1Dooooo`;o0000`?ooool2o`0002oooooo000Nooooo`03o`000?oooooooooo0:[ooooo0_l0
001Yooooo`?o0000;oooool001kooooo00?o0000ooooooooool0G?ooool2o`0004cooooo0_l0000]
ooooo`;o00004Oooool2o`0002Oooooo0_l0000`ooooo`007_ooool00ol0003oooooooooo`1Loooo
o`;o0000Noooool2o`00017ooooo0_l0001Iooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0Cooo
ool2o`000?Kooooo000Nooooo`03o`000?oooooooooo04oooooo0_l0003fooooo`007_ooool00ol0
003oooooooooo`3oooooobgooooo0_l0000Iooooo`007_ooool00ol0003oooooooooo`2aooooo`;o
0000NOooool2o`0001Wooooo000Nooooo`;o0000/_ooool2o`0009Cooooo000Nooooo`;o0000oooo
oom9ooooo`007_ooool2o`000;Kooooo0_l0002@ooooo`007_ooool00ol0003oooooooooo`0Goooo
o`;o0000W?ooool2o`00093ooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0003ooooooboo
oooo000Nooooo`03o`000?oooooooooo0:Oooooo0_l0002Nooooo`007_ooool00ol0003ooooooooo
o`1Iooooo`;o0000C?ooool2o`0002Gooooo0_l0001gooooo`007_ooool00ol0003oooooooooo`0?
ooooo`;o0000B?ooool2o`0007?ooooo0_l0001gooooo`007_ooool00ol0003oooooooooo`0?oooo
o`;o0000oooooolgooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0i?ooool2o`0002kooooo0_l0000aooooo`007_ooool00ol0003ooooo
ooooo`3Tooooo`;o0000;_ooool2o`00037ooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0Coooool2o`000?Kooooo000Nooooo`;o0000B?ooool2o`00
00Kooooo0_l00031ooooo`;o0000<oooool001kooooo00?o0000ooooooooool0>?ooool2o`0000go
oooo0_l00039ooooo`;o0000<oooool001kooooo00?o0000ooooooooool09oooool2o`0000oooooo
0_l0003oooooo`kooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l00036ooooo`;o00006ooo
ool2o`0003Wooooo000Nooooo`03o`000?oooooooooo0>oooooo0_l0000Kooooo`;o00000_ooool2
o`0003Gooooo000Nooooo`03o`000?oooooooooo0?oooooo4?ooool3o`0003Gooooo000Nooooo`03
o`000?oooooooooo0?oooooo1Oooool2o`0000Wooooo0_l0000fooooo`007_ooool00ol0003ooooo
ooooo`3oooooo`Gooooo0_l00011ooooo`007_ooool00ol0003oooooooooo`17ooooo`;o0000:_oo
ool2o`000=;ooooo000Nooooo`03o`000?oooooooooo04Oooooo0_l0000Zooooo`;o0000d_ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3:ooooo`;o
0000Noooool001kooooo00?o0000ooooooooool0b_ooool2o`0007_ooooo000Nooooo`03o`000?oo
oooooooo06Cooooo0_l0003Qooooo`007_ooool00ol0003oooooooooo`1Hooooo`;o00002_ooool2
o`000>7ooooo000Nooooo`03o`000?oooooooooo05Sooooo0_l0003]ooooo`007_ooool2o`0007co
oooo0_l0003:ooooo`007_ooool00ol0003oooooooooo`1kooooo`;o0000;oooool2o`0001Sooooo
0_l0001oooooo`007_ooool00ol0003oooooooooo`2/ooooo`;o00006?ooool2o`0007oooooo000N
ooooo`03o`000?oooooooooo06gooooo0_l0003Hooooo`007_ooool00ol0003oooooooooo`1]oooo
o`;o0000f?ooool001kooooo00?o0000ooooooooool08Oooool2o`000>Gooooo0_l0000mooooo`00
7_ooool00ol0003oooooooooo`0Qooooo`;o0000iOooool2o`0003gooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0MOooool2o`00047ooooo0_l0002=
ooooo`007_ooool00ol0003oooooooooo`1eooooo`;o0000@Oooool2o`0008gooooo000Nooooo`03
o`000?oooooooooo03[ooooo0_l0000;ooooo`;o0000^oooool2o`00047ooooo000Nooooo`03o`00
0?oooooooooo03[ooooo0_l0000;ooooo`;o0000H_ooool2o`0005Oooooo0_l00011ooooo`007_oo
ool00ol0003oooooooooo`2[ooooo`;o0000F?ooool2o`00043ooooo000Nooooo`03o`000?oooooo
oooo0?oooooo1_ooool2o`00043ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0;Wooooo0_l0001o
ooooo`;o00002oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Wooooo0_l0001oooooo`;o00002oooool0
00?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool3o`000?ooooooB?ooool0
00?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o
0000ooooooooool0UOooool2o`000;3ooooo0003ooooo`05o`000?ooooooooooooooool000002ooo
ool01?oMgMgoEEEEooooool00007ooooo`04o`000?oooooo0000o`0001;ooooo0_l00020ooooo`;o
0000@Oooool2o`0006gooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOo
c<c<o`000007ooooo`04o`000?oooooo0000o`0001;ooooo0_l00033ooooo`;o0000KOooool000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Kooooo0_l0003ooooo
od[ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`05oooo
o`;o0000Noooool2o`000<cooooo000Nooooo`03o`000?oooooooooo07Wooooo0_l0003<ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0<Wooooo0_l0
001looooo`007_ooool00ol0003oooooooooo`39ooooo`;o0000O?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0=?ooooo0_l0001boooo
o`007_ooool00ol0003oooooooooo`3Cooooo`;o0000Ioooool2o`0000Wooooo000Nooooo`;o0000
6?ooool2o`0003[ooooo0_l0002Tooooo`;o0000@Oooool2o`0000Wooooo000Nooooo`03o`000?oo
oooooooo01Oooooo0_l0000jooooo`;o0000H_ooool2o`00043ooooo0_l00013ooooo`;o00001ooo
ool001kooooo00?o0000ooooooooool0]oooool2o`0002oooooo0_l0000Iooooo`;o0000>Oooool2
o`0000Oooooo000Nooooo`03o`000?oooooooooo0>Sooooo0_l0000Iooooo`;o0000@_ooool001ko
oooo00?o0000ooooooooool0AOooool2o`0004[ooooo0_l0001/ooooo`;o0000A_ooool001kooooo
00?o0000ooooooooool0AOooool2o`0004[ooooo0_l0001/ooooo`;o0000A_ooool001kooooo00?o
0000ooooooooool0oooooolVooooo`;o00008?ooool001kooooo00?o0000ooooooooool0GOooool2
o`000<Kooooo0_l0000Pooooo`007_ooool00ol0003oooooooooo`1Mooooo`;o0000j?ooool001ko
oooo00?o0000ooooooooool07Oooool2o`0006kooooo0_l0002[ooooo`;o00002oooool001kooooo
00?o0000ooooooooool07Oooool2o`0006kooooo0_l0002[ooooo`;o00002oooool001kooooo00?o
0000ooooooooool07?ooool2o`0006oooooo0_l0001Nooooo`;o0000F?ooool001kooooo00?o0000
ooooooooool07?ooool2o`0009Wooooo0_l0000dooooo`;o0000F?ooool001kooooo00?o0000oooo
ooooool06?ooool2o`0006Gooooo0_l0000fooooo`;o00000oooool2o`0008Wooooo000Nooooo`03
o`000?oooooooooo01Sooooo0_l0001Uooooo`;o0000>oooool2o`0008Wooooo000Nooooo`03o`00
0?oooooooooo0;Oooooo0_l0002>ooooo`007_ooool2o`0002Kooooo0_l0002@ooooo`;o0000S_oo
ool001kooooo00?o0000ooooooooool09Oooool2o`000?oooooo8Oooool001kooooo00?o0000oooo
ooooool0ooooool@ooooo`;o0000=_ooool001kooooo00?o0000ooooooooool03_ooool2o`000?oo
oooo0_l0000Dooooo`;o00002?ooool2o`0001Kooooo000Nooooo`03o`000?oooooooooo00kooooo
0_l0002kooooo`;o0000F?ooool2o`0000Sooooo0_l0000Fooooo`007_ooool00ol0003ooooooooo
o`3;ooooo`;o0000A?ooool2o`0003Cooooo000Nooooo`03o`000?oooooooooo0?oooooo4_ooool2
o`0003Cooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`05ooooo`;o0000ROooool2o`0008cooooo
0_l0000Wooooo`007_ooool00ol0003oooooooooo`05ooooo`;o0000ROooool2o`0008cooooo0_l0
000Wooooo`007_ooool00ol0003oooooooooo`1?ooooo`;o0000m_ooool001kooooo00?o0000oooo
ooooool0Coooool2o`000?Kooooo000Nooooo`03o`000?oooooooooo043ooooo0_l0003oooooo`Ko
oooo000Nooooo`03o`000?oooooooooo043ooooo0_l0003oooooo`Kooooo000Nooooo`03o`000?oo
oooooooo04Oooooo0_l00039ooooo`;o0000<oooool001kooooo0_l00018ooooo`;o0000_?ooool2
o`0000_ooooo0_l0000cooooo`007_ooool00ol0003oooooooooo`3oooooo`Kooooo0_l0000;oooo
o`;o0000<oooool001kooooo00?o0000ooooooooool0<oooool2o`0004Gooooo0_l0000Looooo`;o
0000SOooool2o`0000Oooooo0_l0000Eooooo`007_ooool00ol0003oooooooooo`0cooooo`;o0000
<_ooool2o`00017ooooo0_l0000Looooo`;o0000SOooool2o`0000Oooooo0_l0000Eooooo`007_oo
ool00ol0003oooooooooo`0Nooooo`;o0000??ooool2o`0000Wooooo0_l0001?ooooo`;o0000<_oo
ool2o`0005Wooooo000Nooooo`03o`000?oooooooooo01kooooo0_l0000looooo`;o0000F_ooool2
o`0003;ooooo0_l0001Iooooo`007_ooool00ol0003oooooooooo`03ooooo`;o0000A?ooool2o`00
02?ooooo0_l0003Gooooo`007_ooool00ol0003oooooooooo`03ooooo`;o0000;?ooool2o`0001Ko
oooo0_l0000Sooooo`?o0000Loooool2o`0004Sooooo0_l0000>ooooo`;o00001oooool001kooooo
00?o0000ooooooooool0<Oooool2o`0003cooooo0_l0001cooooo`;o0000B?ooool2o`0000kooooo
0_l00007ooooo`007_ooool00ol0003oooooooooo`0_ooooo`;o00001oooool2o`00033ooooo0_l0
001Mooooo`;o0000O?ooool001kooooo00?o0000ooooooooool0;oooool2o`0000Oooooo0_l0000`
ooooo`;o0000GOooool2o`0000gooooo0_l0001]ooooo`007_ooool00ol0003oooooooooo`0/oooo
o`;o0000A?ooool2o`0006Cooooo0_l0000Oooooo`;o00002Oooool2o`00047ooooo000Nooooo`03
o`000?oooooooooo02cooooo0_l00002ooooo`;o00000_ooool2o`0000Oooooo0_l0000Rooooo`;o
00003oooool2o`0003cooooo0_l00017ooooo`;o00002Oooool2o`00047ooooo000Nooooo`03o`00
0?oooooooooo033ooooo0_l00002ooooo`;o00001oooool3o`00027ooooo0_l0001=ooooo`;o0000
0oooool2o`00093ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo02oooooo0_l0000=ooooo`;o
0000MOooool2o`0005Oooooo0_l0000gooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool01?l0003oooooooooooooool2
o`0002cooooo0_l0000>ooooo`Co00003oooool2o`0009kooooo0_l0000Jooooo`;o0000<Oooool2
o`0000Cooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooo
oooo000000Kooooo0ol000000ooooooo0000o`00000?ooooo`;o00008_ooool5o`0000Cooooo1?l0
000?ooooo`;o0000W_ooool2o`0004gooooo0_l00004ooooo`000oooool01Ol0003ooooooooooooo
oooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo01;ooooo
0_l0000Rooooo`Go0000@oooool2o`0007oooooo0_l00016ooooo`000oooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo03Ko
oooo0_l00016ooooo`;o00003?ooool2o`00077ooooo0_l00016ooooo`000oooool01Ol@413ooooo
oooooooooooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`1>ooooo`;o
00006Oooool2o`00027ooooo0_l0001fooooo`;o0000@Oooool000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0=_ooool2o`0001Ko
oooo0_l0000Iooooo`;o0000Eoooool2o`0003_ooooo0_l00003ooooo`;o0000@Oooool000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000oooo
ooooool03?ooool2o`0002Sooooo0_l0000Wooooo`;o0000HOooool2o`0001[ooooo0_l0000Ooooo
o`;o0000A_ooool001kooooo00?o0000ooooooooool03?ooool2o`00047ooooo0_l0000:ooooo`;o
00000_ooool2o`0007gooooo0_l0001Wooooo`007_ooool00ol0003oooooooooo`0iooooo`?o0000
1Oooool2o`0000cooooo0_l0000:ooooo`;o00005Oooool2o`0008Wooooo0_l0000Looooo`;o0000
:_ooool001kooooo00?o0000ooooooooool0>Oooool3o`0000Gooooo0_l00005ooooo`;o0000:?oo
ool2o`0008Wooooo0_l0000;ooooo`;o00003oooool2o`0002[ooooo000Nooooo`03o`000?oooooo
oooo04Sooooo0ol0000Dooooo`;o0000ZOooool2o`0003_ooooo000Nooooo`03o`000?oooooooooo
037ooooo1?l00004ooooo`;o00003_ooool2o`0001Cooooo0_l0003Vooooo`007_ooool00ol0003o
ooooooooo`0aooooo`Co00001?ooool3o`0008cooooo0_l0001mooooo`007_ooool00ol0003ooooo
ooooo`0aooooo`;o00001oooool4o`0004Cooooo0_l0000=ooooo`?o0000=?ooool2o`0007gooooo
000Nooooo`03o`000?oooooooooo02oooooo0_l0000;ooooo`;o00001Oooool2o`0003gooooo0_l0
000=ooooo`?o0000G?ooool2o`0005Gooooo000Nooooo`03o`000?oooooooooo02oooooo0_l0000B
ooooo`;o00006?ooool2o`0007Wooooo0_l0000Fooooo`;o0000EOooool001kooooo00?o0000oooo
ooooool0GOooool2o`0007?ooooo0_l00004ooooo`;o0000KOooool001kooooo00?o0000oooooooo
ool09?ooool2o`0006Cooooo0_l00016ooooo`;o0000Loooool001kooooo0_l0000Uooooo`?o0000
3_ooool2o`0000gooooo0_l0000Iooooo`;o0000:Oooool2o`000;_ooooo000Nooooo`03o`000?oo
oooooooo02Gooooo0_l0000:ooooo`;o00000_ooool2o`0000Kooooo0_l00005ooooo`;o00006Ooo
ool2o`0001Cooooo0_l0003@ooooo`007_ooool00ol0003oooooooooo`0aooooo`;o00002_ooool2
o`0003Kooooo0_l0002Xooooo`;o00009_ooool001kooooo00?o0000ooooooooool0DOooool2o`00
03Wooooo0_l00008ooooo`;o00005?ooool2o`00077ooooo0_l0000Vooooo`007_ooool00ol0003o
ooooooooo`0Uooooo`;o0000:_ooool2o`0002_ooooo0_l0000<ooooo`;o00002?ooool2o`0001Co
oooo0_l0002Iooooo`007_ooool00ol0003oooooooooo`0Uooooo`;o0000;oooool2o`0002Kooooo
0_l00002ooooo`;o0000`oooool001kooooo00?o0000ooooooooool0;Oooool2o`0002Oooooo0_l0
000Zooooo`;o0000`oooool001kooooo00?o0000ooooooooool01?ooool2o`0002Oooooo0_l0001W
ooooo`;o0000=oooool2o`0001Oooooo0_l0001Mooooo`007_ooool00ol0003oooooooooo`04oooo
o`;o0000T?ooool2o`0003Oooooo0_l0000Gooooo`;o0000GOooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`0Fooooo`;o00001Oooool2o`000?oooooo
:Oooool001kooooo00?o0000ooooooooool05_ooool2o`0000Gooooo0_l0001_ooooo`;o00001Ooo
ool2o`000;3ooooo000Nooooo`03o`000?oooooooooo08kooooo0_l00005ooooo`;o0000/?ooool0
01kooooo00?o0000ooooooooool06Oooool2o`0001cooooo0_l0003oooooo`oooooo000Nooooo`03
o`000?oooooooooo01Wooooo0_l0000Looooo`;o0000E_ooool2o`000;Kooooo000Nooooo`03o`00
0?oooooooooo01Kooooo0_l0001gooooo`;o0000]_ooool001kooooo0_l0000Dooooo`;o000000?o
ooooo`000?l00000@Oooool2o`0000Sooooo0_l0000:ooooo`;o0000Soooool2o`0004Gooooo000N
ooooo`03o`000?oooooooooo01?ooooo0ol0000Gooooo`;o0000:_ooool2o`0000Sooooo0_l00000
0ooooooo0000o`000007ooooo`;o0000Q_ooool2o`0000Oooooo0_l00015ooooo`007_ooool00ol0
003oooooooooo`0Dooooo`;o00005oooool2o`0001_ooooo0_l0000Jooooo`;o0000Boooool2o`00
04;ooooo0_l0000Hooooo`;o0000=?ooool001kooooo00?o0000ooooooooool0B_ooool2o`0001[o
oooo0_l0000iooooo`;o00004?ooool2o`000003ooooool0003o000003Oooooo0_l0000Pooooo`;o
0000=?ooool001kooooo00?o0000ooooooooool0H_ooool2o`0003Wooooo0_l00002ooooo`;o0000
4oooool2o`0003Oooooo0_l0001Fooooo`007_ooool00ol0003oooooooooo`1Qooooo`?o00001ooo
ool3o`0002[ooooo0_l00003ooooo`;o0000HOooool2o`0004Gooooo000Nooooo`03o`000?oooooo
oooo067ooooo0_l00008ooooo`?o0000:_ooool2o`0006Kooooo0_l00015ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`;o0000n_ooool2o`0003[ooooo0_l0000@ooooo`00
7_ooool2o`000?[ooooo0_l0000jooooo`;o00004?ooool001kooooo00?o0000ooooooooool0;Ooo
ool2o`0001Sooooo0_l00006ooooo`Co0000DOooool2o`0006oooooo0_l0000Hooooo`;o00005_oo
ool001kooooo00?o0000ooooooooool0;Oooool2o`0001Sooooo0_l00006ooooo`Co00001?ooool2
o`0001oooooo0_l0000Zooooo`;o0000Koooool2o`0001Sooooo0_l0000Fooooo`007_ooool00ol0
003oooooooooo`1=ooooo`Ko00001?ooool2o`0001oooooo0_l0003=ooooo`007_ooool00ol0003o
ooooooooo`0<ooooo`;o00004Oooool2o`0002[ooooo1?l0000/ooooo`;o0000b_ooool001kooooo
00?o0000ooooooooool03?ooool2o`00017ooooo0_l0000Zooooo`;o00002_ooool2o`0002;ooooo
0_l00025ooooo`;o0000@oooool001kooooo00?o0000ooooooooool09oooool2o`0002kooooo0_l0
000Vooooo`;o0000L?ooool2o`0000oooooo0_l0000dooooo`;o00003Oooool001kooooo0_l0000X
ooooo`;o00006Oooool2o`0000?ooooo0_l0000Pooooo`;o00002_ooool2o`0000?ooooo0_l00003
ooooo`;o0000L?ooool2o`0004Gooooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`0eoooo
o`;o00002_ooool4o`0000;ooooo0_l0000?ooooo`;o00003oooool2o`0000[ooooo0_l00003oooo
o`;o00009_ooool2o`000:?ooooo000Nooooo`03o`000?oooooooooo03Gooooo0_l00004ooooo`;o
00001?ooool4o`0001?ooooo0_l00018ooooo`Co0000XOooool001kooooo00?o0000ooooooooool0
>oooool2o`0001Cooooo0_l0000Qooooo`Co0000;?ooool2o`000:7ooooo000Nooooo`03o`000?oo
oooooooo03Sooooo0_l000000ooooooo0000o`00000Dooooo`;o00004?ooool2o`0000oooooo1?l0
003?ooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o0000:oooool2o`0002Wooooo0_l0000@
ooooo`;o0000<_ooool2o`0009cooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l0000doooo
o`;o0000<_ooool2o`0003;ooooo0_l0000?ooooo`;o0000Roooool001kooooo00?o0000oooooooo
ool0@Oooool2o`0001Wooooo0_l0000iooooo`;o00008Oooool2o`0004Wooooo0_l00008ooooo`;o
0000=_ooool001kooooo00?o0000ooooooooool04_ooool2o`0002Gooooo0_l00006ooooo`?o0000
1Oooool5o`0000kooooo0_l0000iooooo`;o00006Oooool2o`00057ooooo0_l00008ooooo`Co0000
1_ooool2o`0002cooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0000Uooooo`;o00000_oo
ool2o`0000;ooooo0ol00004ooooo`Oo0000Hoooool2o`0005gooooo0_l00006ooooo`;o00003_oo
ool2o`0001cooooo000Nooooo`03o`000?oooooooooo03[ooooo0_l000000ooooooo0000o`000009
ooooo`;o00000oooool4o`0004Kooooo0_l0002@ooooo`;o00007?ooool001kooooo00?o0000oooo
ooooool0>Oooool3o`0000Kooooo0_l00009ooooo`Co0000@?ooool2o`0000Cooooo0_l00002oooo
o`;o0000Z_ooool001kooooo00?o0000ooooooooool0>Oooool6o`0000?ooooo0_l0000;ooooo`;o
00003Oooool2o`0000;ooooo0_l0000@ooooo`;o00006oooool2o`0000Sooooo0_l0000Hooooo`;o
0000T?ooool001kooooo00?o0000ooooooooool0;_ooool2o`0000Kooooo0_l00003ooooo`Co0000
3_ooool4o`0000gooooo0ol000000ooooooo0000o`00000@ooooo`;o0000?oooool2o`0000[ooooo
0_l00024ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<
c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0^ooooo`;o00001_ooool2o`0000Ko
oooo0_l0000=ooooo`?o00003oooool2o`0001cooooo0_l0000eooooo`;o00002oooool2o`0004Co
oooo0_l0000nooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0eooooo`;o00001oooool2o`00
00kooooo0_l00008ooooo`;o00008oooool2o`0003Gooooo0_l0000Yooooo`;o00009_ooool2o`00
00[ooooo0_l0000booooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooo
ooooooooooooo`000006ooooo`?o00000_ooool2o`00033ooooo0ol00005ooooo`;o00003oooool2
o`0000?ooooo1Ol000000ooooooo0000o`000025ooooo`;o0000<_ooool2o`0003;ooooo0003oooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o
0000ooooooooool00_ooool2o`0002Sooooo0_l00006ooooo`Oo000000?oooooo`000?l000001?oo
ool3o`0000;ooooo0_l00002ooooo`Co00000oooool5o`0000Gooooo0_l00006ooooo`;o0000A_oo
ool2o`0000_ooooo0_l0002<ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go
c<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo02cooooo0_l00002ooooo`;o0000
0oooool7o`0000Kooooo1ol00002ooooo`Go00001Oooool2o`0000Gooooo0_l00006ooooo`;o0000
:?ooool2o`0001Kooooo0_l00004ooooo`;o00002oooool2o`0008cooooo0003ooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000oooooooo
ool0<?ooool2o`0000Cooooo0_l000001?oooooo0000o`000?l00008ooooo`Co00001?ooool5o`00
00Cooooo0_l0000Cooooo`;o00008_ooool2o`0001Kooooo0_l0002Oooooo`000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooo
oooo03Cooooo1?l00003ooooo`;o00002?ooool2o`0000Gooooo2Ol0000Eooooo`;o0000foooool0
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_oo
ool00ol0003oooooooooo`08ooooo`;o0000:_ooool2o`0000;ooooo1ol00006ooooo`;o000000?o
ooooo`000?l000000oooool8o`0000Kooooo0_l00003ooooo`;o00004_ooool2o`0004Oooooo0_l0
0028ooooo`007_ooool00ol0003oooooooooo`08ooooo`;o00005oooool2o`0001Gooooo1ol00009
ooooo`?o00000_ooool5o`0000Sooooo0ol00002ooooo`?o00004_ooool2o`0004Oooooo0_l00028
ooooo`007_ooool00ol0003oooooooooo`0Qooooo`;o00006Oooool4o`000003ooooool0003o0000
00Kooooo0ol000000ooooooo0000o`000003o`0000Sooooo0_l00003ooooo`;o0000i_ooool001ko
oooo00?o0000ooooooooool0?_ooool2o`000003ooooool0003o000000Cooooo1_l0003cooooo`;o
00001Oooool001kooooo00?o0000ooooooooool00_ooool2o`0001Cooooo0_l0000Dooooo`;o0000
4Oooool4o`0000;ooooo0ol000000ooooooo0000o`000002ooooo`Co00001oooool3o`0004Wooooo
0_l0001kooooo`;o00006oooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0
000Dooooo`;o00001_ooool2o`0000cooooo0_l00007ooooo`;o00000_ooool3o`0000Gooooo0_l0
0002ooooo`;o000000?oooooo`000?l000000oooool6o`0000Gooooo1Ol0000=ooooo`Co0000=_oo
ool2o`0007_ooooo0_l0000Rooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o00002Oooool2
o`0000[ooooo0_l00002ooooo`?o00001Oooool2o`0000;ooooo0_l000000ooooooo0000o`000002
o`0000?ooooo1?l00006ooooo`Co00003Oooool4o`0005oooooo0_l0001fooooo`007_ooool00ol0
003oooooooooo`06ooooo`;o00008oooool2o`0000oooooo0_l000000ooooooo0000o`000002oooo
o`;o00001oooool2o`0000?ooooo0ol00007ooooo`;o00001_ooool2o`0006[ooooo0_l0001foooo
o`007_ooool00ol0003oooooooooo`06ooooo`;o0000=oooool2o`0000?ooooo0_l0000Dooooo`Co
00001Oooool2o`000:[ooooo0_l0000Vooooo`;o00003_ooool001kooooo00?o0000ooooooooool0
<_ooool2o`00013ooooo0_l00002ooooo`;o00001_ooool4o`0000Kooooo1Ol00013ooooo`;o0000
Joooool2o`0001cooooo0_l00008ooooo`;o00003_ooool001kooooo00?o0000ooooooooool01ooo
ool2o`0002Gooooo0_l00002ooooo`;o00004?ooool2o`0000;ooooo0_l00006ooooo`Co00001?oo
ool7o`0004?ooooo0_l0001/ooooo`;o00006oooool2o`0000_ooooo0_l0000;ooooo`007_ooool0
0ol0003oooooooooo`03ooooo`;o00000_ooool2o`0001Kooooo0_l00006ooooo`;o00000oooool4
o`0000Sooooo0_l00005ooooo`Co000000?oooooo`000?l000001?ooool2o`0000Cooooo1?l00000
0ooooooo0000o`000004o`0001kooooo0_l000000ooooooo0000o`00002Booooo`;o0000:?ooool2
o`0000_ooooo000Nooooo`;o00000oooool3o`0001[ooooo0_l00006ooooo`;o00000oooool2o`00
00[ooooo0_l00005ooooo`Co00001oooool2o`0000?ooooo2Ol0000Qooooo`;o000000?oooooo`00
0?l00000bOooool001kooooo00?o0000ooooooooool00_ooool2o`0001Kooooo0_l0000Booooo`Co
00003Oooool2o`0000Sooooo0ol00002ooooo`Co000000Coooooo`000?l0003o00002?ooool2o`00
01[ooooo0_l0001@ooooo`;o0000NOooool001kooooo00?o0000ooooooooool06_ooool2o`0001;o
oooo1?l0000Fooooo`?o00000oooool2o`0000?ooooo1_l00005ooooo`;o00006_ooool2o`00053o
oooo0_l0001iooooo`007_ooool00ol0003oooooooooo`0]ooooo`?o00006?ooool2o`000004oooo
ool0003o0000ooooo`;o00000oooool6o`000>kooooo000Nooooo`03o`000?oooooooooo02gooooo
0_l00004ooooo`;o000000?oooooo`000?l000001_ooool2o`0000_ooooo0ol00004ooooo`Co0000
1?ooool3o`0000Gooooo0_l0000<ooooo`;o00005?ooool2o`0003;ooooo1?l00029ooooo`007_oo
ool00ol0003oooooooooo`0cooooo`Go00001_ooool4o`0000[ooooo0_l00004ooooo`Co00001?oo
ool3o`0000Gooooo0_l0000<ooooo`;o000000?oooooo`000?l000004Oooool2o`0001?ooooo0_l0
000Iooooo`;o00000_ooool4o`0008Wooooo000Nooooo`03o`000?oooooooooo02Gooooo1?l0000;
ooooo`Co00002?ooool2o`0000?ooooo0_l0000:ooooo`Wo000000?oooooo`000?l000001Oooool2
o`0000oooooo0_l0000Vooooo`;o00006Oooool2o`0008oooooo000Nooooo`03o`000?oooooooooo
01kooooo0_l00005ooooo`Co00002oooool2o`0000cooooo0_l000000ooooooo0000o`000004oooo
o`;o000000Coooooo`000?l0003ooooo2Ol000001?oooooo0000o`000?ooool2o`0000;ooooo0_l0
000?ooooo`;o0000=?ooool2o`0009cooooo000Nooooo`03o`000?oooooooooo01kooooo0_l0000R
ooooo`?o00000oooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000000ol0
0004ooooo`;o00000_ooool2o`0000Oooooo0_l0000?ooooo`;o00004_ooool2o`0001;ooooo0_l0
0007ooooo`;o0000W?ooool001kooooo00?o0000ooooooooool0=_ooool2o`0000[ooooo0ol00003
ooooo`;o00001_ooool9o`000003ooooool0003o000000Gooooo0ol00003ooooo`;o00003oooool2
o`0001;ooooo0_l0000Booooo`;o0000YOooool001kooooo00?o0000ooooooooool0;oooool2o`00
00Gooooo0_l0000:ooooo`?o00000_ooool2o`0000Gooooo1ol000001Ooooooo0000o`000?l0003o
oooo00Co00000_ooool6o`0002cooooo0_l000000ooooooo0000o`00002Xooooo`;o00001_ooool0
01kooooo00?o0000ooooooooool0;oooool2o`0000oooooo0_l00005ooooo`;o00000_ooool2o`00
0003ooooool0003o000000Wo000000?oooooo`000?l000000ol000001Ooooooo0000o`000?l0003o
oooo00Co00000_ooool2o`0000;ooooo0_l00007ooooo`;o00006Oooool5o`000:Sooooo0_l00006
ooooo`007_ooool00ol0003oooooooooo`10ooooo`;o00002Oooool2o`0000Cooooo0_l000001?oo
oooo0000o`000?l00003ooooo`[o00000_ooool3o`000003ooooool0003o000000;ooooo0_l00007
ooooo`;o00006_ooool4o`000;3ooooo000Nooooo`03o`000?oooooooooo04Wooooo0_l00003oooo
o`;o000000?oooooo`000?l000001Ol00002ooooo`Oo000000?oooooo`000?l000000oooool4o`00
057ooooo0_l00029ooooo`007_ooool00ol0003oooooooooo`19ooooo`;o00000oooool2o`000003
ooooool0003o000000Ko000000?oooooo`000?l000000_ooool3o`0000Sooooo0_l0000Yooooo`;o
00004?ooool2o`0001Cooooo0_l0001kooooo`?o00002oooool001kooooo00?o0000ooooooooool0
@?ooool2o`0000_ooooo0_l00005ooooo`Go00002oooool4o`0000kooooo0_l0000Looooo`;o0000
4?ooool2o`00097ooooo0ol0000;ooooo`007_ooool2o`00047ooooo0_l0000;ooooo`;o00001_oo
ool3o`0000Oooooo0_l00003ooooo`Co00001_ooool2o`0000Kooooo0_l0003?ooooo`007_ooool0
0ol0003oooooooooo`1>ooooo`Oo000000?oooooo`000?l000001oooool2o`0000gooooo0ol0001@
ooooo`;o0000Q?ooool001kooooo00?o0000ooooooooool00oooool2o`0001Gooooo0_l0000]oooo
o`;o00000oooool7o`0001;ooooo0_l00006ooooo`;o0000D?ooool2o`0008Cooooo000Nooooo`03
o`000?oooooooooo00?ooooo0_l0000Eooooo`;o0000;Oooool2o`0000?ooooo1_l0000>ooooo`;o
000000?oooooo`000?l000000_l00004ooooo`;o00000_ooool2o`000=Cooooo000Nooooo`03o`00
0?oooooooooo04_ooooo2ol00004ooooo`;o00001_ooool7o`0000;ooooo1?l00002ooooo`;o0000
0_ooool2o`0009Cooooo0_l0000^ooooo`;o00002_ooool001kooooo00?o0000ooooooooool01ooo
ool2o`0003Oooooo0_l00007ooooo`Go00000oooool5o`0000Cooooo0_l00007ooooo`Ko00000_oo
ool3o`0000;ooooo0_l00002ooooo`Co0000OOooool2o`0001?ooooo0ol0000^ooooo`;o00002_oo
ool001kooooo00?o0000ooooooooool01oooool2o`0003Oooooo0_l00007ooooo`;o00003?ooool2
o`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l000001Oooool2o`0000;ooooo0_l00002
ooooo`Co00009?ooool2o`0005Oooooo0_l0000Cooooo`;o0000>oooool001kooooo00?o0000oooo
ooooool0@?ooool4o`0000Gooooo0ol00002ooooo`;o000000?oooooo`000?l000001?ooool2o`00
00?ooooo1?l00002ooooo`;o00001Oooool2o`000003ooooool0003o000000;o00000oooool3o`00
00;ooooo1?l0000Pooooo`;o0000ZOooool001kooooo00?o0000ooooooooool08_ooool2o`0001ko
oooo0_l00005ooooo`Co000000Coooooo`000?l0003ooooo1?l00007ooooo`;o00002?ooool2o`00
0003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000003o`0000;ooooo1?l0003;oooo
o`007_ooool00ol0003oooooooooo`0Rooooo`;o00008?ooool2o`0000Gooooo1?l000001?oooooo
0000o`000?ooool4o`0000Oooooo0_l00006ooooo`Go00001_ooool4o`0001Sooooo0_l00005oooo
o`;o0000;Oooool2o`0008;ooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0000aooooo`;o
00001Oooool4o`0000Oooooo0_l000000ooooooo0000o`000003ooooo`;o00001_ooool3o`0000Oo
oooo1?l00005ooooo`Go00000_ooool2o`0001Cooooo0_l00005ooooo`;o0000;Oooool2o`0008;o
oooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0000aooooo`;o00001Oooool2o`0000?ooooo
0_l00003ooooo`;o00000_ooool2o`0000Gooooo0ol00003ooooo`;o00000_ooool3o`000003oooo
ool0003o000000Gooooo0_l00002ooooo`Co00000oooool2o`0000Oooooo0_l0000kooooo`;o0000
R?ooool001kooooo00?o0000ooooooooool0Aoooool2o`0000?ooooo0_l00003ooooo`;o00001?oo
ool3o`0000Gooooo1Ol000000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l000003ooo
ool2o`0003_ooooo0_l00028ooooo`007_ooool00ol0003oooooooooo`1<ooooo`;o00000oooool2
o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`?o00002Oooool2o`0000;ooooo0ol00008
ooooo`;o0000boooool001kooooo00?o0000ooooooooool0AOooool2o`0000?ooooo1?l00003oooo
o`;o00000_ooool2o`0000Wooooo0_l00009ooooo`;o00000_ooool3o`0000Oooooo0ol000001?oo
oooo0000o`000?l00037ooooo`007_ooool00ol0003oooooooooo`0Wooooo`;o00006oooool3o`00
0003ooooool0003o000000;o00001Oooool2o`0000Wooooo0_l00002ooooo`;o00002?ooool2o`00
0003ooooool0003o000000?o00001oooool2o`0000;ooooo0ol00037ooooo`007_ooool2o`0002So
oooo0_l0000Booooo`;o00001oooool3o`000003ooooool0003o000000?ooooo0_l0000=ooooo`;o
00003?ooool2o`000004ooooool0003o0000ooooo`;o00000oooool2o`0003?ooooo0_l0002Koooo
o`007_ooool00ol0003oooooooooo`0;ooooo`;o0000;_ooool2o`0000Kooooo1?l00006ooooo`;o
00001Oooool2o`0000cooooo0_l000000ooooooo0000o`00000<ooooo`Go0000<_ooool2o`0001?o
oooo0_l00026ooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o0000=?ooool4o`0000Sooooo
0_l00005ooooo`;o00000_ooool2o`000003ooooool0003o000000Cooooo0ol000001?oooooo0000
o`000?l0000;ooooo`;o000000?oooooo`000?l00000Aoooool2o`0008Kooooo000Nooooo`04o`00
0?ooooooooooooooo`;o00004?ooool2o`0000_ooooo0_l0000Oooooo`?o00001?ooool2o`0000Oo
oooo0_l00005ooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000;o
00001Oooool4o`000<gooooo0_l00007ooooo`007_ooool01?l0003oooooooooooooool2o`00013o
oooo0_l0000;ooooo`;o00009_ooool2o`0000Oooooo0_l0000Aooooo`;o000000?oooooo`000?l0
00001?ooool4o`0003Cooooo0_l0002Gooooo`;o00001oooool001kooooo00?o0000ooooooooool0
<_ooool2o`0001?ooooo0_l00005ooooo`;o00001_ooool2o`000003ooooool0003o000000Wooooo
0_l000000ooooooo0000o`00000looooo`;o00002Oooool2o`0009Gooooo000Nooooo`03o`000?oo
oooooooo03;ooooo0_l0000Cooooo`;o00001Oooool2o`0000Kooooo0_l000001?oooooo0000o`00
0?ooool2o`0000Kooooo0_l0001:ooooo`;o0000UOooool001kooooo00?o0000ooooooooool0G?oo
ool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000007ooooo`;o00005_oo
ool2o`000;gooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0000Booooo`;o0000:Oooool2
o`000003ooooool0003o000000kooooo0_l00006ooooo`?o00000_ooool2o`0000;ooooo0_l00007
ooooo`;o00005_ooool2o`000;gooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0000Boooo
o`;o00007?ooool2o`0000_ooooo0_l000000ooooooo0000o`00000>ooooo`?o00001Oooool2o`00
00?ooooo0_l00007ooooo`;o0000fOooool001kooooo00?o0000ooooooooool0=_ooool2o`0001?o
oooo0_l0000:ooooo`;o00004oooool2o`0004?ooooo0_l0002Dooooo`007_ooool00ol0003ooooo
ooooo`0Looooo`;o00001?ooool2o`0002Oooooo0_l0000>ooooo`;o00000_ooool2o`0000?ooooo
0_l0001;ooooo`;o000000?oooooo`000?l00000TOooool001kooooo00?o0000ooooooooool07?oo
ool2o`0000Cooooo0_l0000Qooooo`;o00004Oooool2o`000004ooooool0003o0000ooooo`?o0000
0oooool2o`0000Sooooo0_l00014ooooo`;o0000M_ooool2o`0001Wooooo000Nooooo`03o`000?oo
oooooooo02;ooooo0_l0000Qooooo`Co00003oooool5o`000004ooooool0003o0000o`0000?ooooo
0_l00003ooooo`;o00000oooool2o`000;cooooo0_l0000Iooooo`005?ooool4o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool08_ooool2o`0002?ooooo0_l00009ooooo`;o00000ooo
ool4o`0000kooooo0_l00005ooooo`;o0000eOooool001Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0_ooooo`;o00008Oooool2o`0000;ooooo0ol00007ooooo`;o000000Cooooo
o`000?l0003o00000oooool2o`0000Gooooo0_l0000Wooooo`;o0000Woooool2o`0000_ooooo000F
ooooo`03o`000?oooooooooo00Gooooo0ol0000_ooooo`;o00002_ooool2o`0000[ooooo0ol0000<
ooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`?o0000<oooool2o`0009oooooo0_l0
000;ooooo`005_ooool00ol0003oooooooooo`13ooooo`;o00002_ooool3o`0001?ooooo0_l0003X
ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?oo
ooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005?ooool00omEEEGoIVIVo`00
003ooooooe;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.32501 .9484 Mdot
.93034 .93289 Mdot
.38267 .89781 Mdot
.23764 .85871 Mdot
.23664 .8499 Mdot
.24594 .90606 Mdot
.76564 .76155 Mdot
.2693 .84222 Mdot
.19365 .85841 Mdot
.33771 .94413 Mdot
.30769 .68125 Mdot
.3904 .71379 Mdot
.33156 .91225 Mdot
.97168 .84446 Mdot
.30004 .90399 Mdot
.13316 .58678 Mdot
.1266 .13309 Mdot
.31556 .97461 Mdot
.35008 .95963 Mdot
.19926 .87327 Mdot
.8976 .11066 Mdot
.22417 .93026 Mdot
.33266 .94832 Mdot
.08568 .9691 Mdot
.19304 .8131 Mdot
.25036 .79248 Mdot
.25979 .83212 Mdot
.14046 .61862 Mdot
.32212 .67687 Mdot
.25477 .93488 Mdot
.36967 .96727 Mdot
.28661 .90434 Mdot
.18986 .81163 Mdot
.20983 .17782 Mdot
.50943 .88892 Mdot
.21193 .74575 Mdot
.01759 .8592 Mdot
.15423 .05597 Mdot
.40847 .78904 Mdot
.23549 .79775 Mdot
.37322 .96748 Mdot
.39132 .82252 Mdot
.09698 .83232 Mdot
.06297 .06967 Mdot
.96982 .01548 Mdot
.41209 .80906 Mdot
.5255 .00107 Mdot
.27247 .9909 Mdot
.23356 .73303 Mdot
.33866 .62405 Mdot
.34041 .80153 Mdot
.30306 .99476 Mdot
.25811 .81321 Mdot
.19297 .71266 Mdot
.27491 .84857 Mdot
.34886 .60824 Mdot
.75402 .78941 Mdot
.30071 .88456 Mdot
.26426 .83666 Mdot
.26001 .99497 Mdot
.29404 .87704 Mdot
.25291 .82722 Mdot
.40056 .94697 Mdot
.17371 .8132 Mdot
.25374 .88915 Mdot
.20898 .91647 Mdot
.23188 .97859 Mdot
.26147 .83144 Mdot
.26366 .92553 Mdot
.82203 .77121 Mdot
.15339 .36808 Mdot
.21322 .69188 Mdot
.53826 .94091 Mdot
.25904 .11494 Mdot
.28429 .76923 Mdot
.73428 .72467 Mdot
.21704 .06493 Mdot
.28644 .47562 Mdot
.26846 .86917 Mdot
.08178 .85057 Mdot
.41556 .01906 Mdot
.69646 .31567 Mdot
.00743 .00448 Mdot
.26703 .84504 Mdot
.76516 .2824 Mdot
.80287 .39411 Mdot
.23772 .79979 Mdot
.26501 .81163 Mdot
.28333 .91771 Mdot
.18336 .82074 Mdot
.11171 .82345 Mdot
.65813 .49944 Mdot
.27819 .66807 Mdot
.27293 .28014 Mdot
.2994 .01365 Mdot
.37115 .04229 Mdot
.51486 .73707 Mdot
.40546 .94931 Mdot
.14433 .77648 Mdot
.55128 .75423 Mdot
.29947 .84271 Mdot
.34725 .84698 Mdot
.28985 .97716 Mdot
.01613 .72907 Mdot
.95533 .98586 Mdot
.31717 .95352 Mdot
.16931 .56671 Mdot
.13422 .58443 Mdot
.24199 .00047 Mdot
.60075 .83065 Mdot
.97946 .82958 Mdot
.9584 .94963 Mdot
.20731 .06479 Mdot
.3363 .96774 Mdot
.77781 .99554 Mdot
.73253 .86131 Mdot
.9671 .03266 Mdot
.34114 .91482 Mdot
.0753 .28141 Mdot
.0994 .06389 Mdot
.26043 .80478 Mdot
.24458 .95874 Mdot
.24484 .8682 Mdot
.27163 .31276 Mdot
.15465 .54786 Mdot
.35393 .7008 Mdot
.21786 .74618 Mdot
.33111 .9683 Mdot
.15932 .15987 Mdot
.59637 .89102 Mdot
.34838 .71291 Mdot
.17161 .53081 Mdot
.87437 .33481 Mdot
.29025 .02316 Mdot
.33174 .01944 Mdot
.33833 .93534 Mdot
.30483 .94768 Mdot
.16311 .5953 Mdot
.36226 .94533 Mdot
.21192 .90348 Mdot
.32621 .98453 Mdot
.16273 .80312 Mdot
.20667 .90289 Mdot
.59425 .83122 Mdot
.2793 .65107 Mdot
.37747 .71741 Mdot
.27495 .00869 Mdot
.27743 .8245 Mdot
.7049 .70797 Mdot
.76853 .26277 Mdot
.12785 .89121 Mdot
.20115 .85529 Mdot
.39405 .74239 Mdot
.19557 .8656 Mdot
.2959 .8846 Mdot
.31738 .89339 Mdot
.19028 .59181 Mdot
.63387 .94644 Mdot
.20765 .849 Mdot
.18298 .57295 Mdot
.17993 .58927 Mdot
.53881 .78416 Mdot
.90805 .20841 Mdot
.28525 .02794 Mdot
.15175 .7776 Mdot
.24042 .85576 Mdot
.27758 .82052 Mdot
.23325 .84343 Mdot
.72276 .04648 Mdot
.26479 .98174 Mdot
.23826 .90026 Mdot
.53994 .0257 Mdot
.51755 .81256 Mdot
.88088 .49691 Mdot
.32706 .94766 Mdot
.31461 .62964 Mdot
.31876 .09755 Mdot
.29133 .79006 Mdot
.73505 .61281 Mdot
.31404 .99141 Mdot
.09796 .8113 Mdot
.311 .68916 Mdot
.38275 .84983 Mdot
.97694 .07766 Mdot
.13819 .50665 Mdot
.33293 .96176 Mdot
.1924 .57708 Mdot
.09355 .83081 Mdot
.59898 .12204 Mdot
.58388 .79284 Mdot
.32896 .95513 Mdot
.85926 .18814 Mdot
.32559 .96536 Mdot
.0152 .06545 Mdot
.13849 .0992 Mdot
.07984 .83377 Mdot
.5553 .82144 Mdot
.33918 .77902 Mdot
.18966 .85469 Mdot
.2373 .81039 Mdot
.13782 .06383 Mdot
.15515 .06851 Mdot
.30828 .02459 Mdot
.98448 .04281 Mdot
.19019 .81286 Mdot
.2626 .81246 Mdot
.80127 .59764 Mdot
.27535 .8319 Mdot
.50853 .15953 Mdot
.19716 .64622 Mdot
.25767 .94443 Mdot
.31283 .98095 Mdot
.08327 .25774 Mdot
.03862 .20244 Mdot
.1671 .60195 Mdot
.21991 .63207 Mdot
.25644 .8092 Mdot
.3311 .87384 Mdot
.28548 .59441 Mdot
.28452 .92444 Mdot
.93621 .89443 Mdot
.31135 .99913 Mdot
.1532 .7917 Mdot
.23453 .86059 Mdot
.23946 .9084 Mdot
.23284 .64011 Mdot
.57779 .83123 Mdot
.34766 .92802 Mdot
.29791 .12993 Mdot
.20513 .90906 Mdot
.28852 .84891 Mdot
.24267 .96831 Mdot
.21082 .89206 Mdot
.561 .98521 Mdot
.24731 .71931 Mdot
.34957 .29755 Mdot
.45626 .38973 Mdot
.36798 .94605 Mdot
.96112 .82691 Mdot
.89116 .43856 Mdot
.31504 .84228 Mdot
.21884 .90514 Mdot
.22399 .89329 Mdot
.23826 .94261 Mdot
.43303 .81068 Mdot
.16295 .07304 Mdot
.29697 .95381 Mdot
.23574 .91265 Mdot
.35062 .53979 Mdot
.38357 .95286 Mdot
.28112 .00311 Mdot
.26465 .87468 Mdot
.05009 .62709 Mdot
.7804 .48506 Mdot
.17107 .57719 Mdot
.20371 .90913 Mdot
.24315 .81859 Mdot
.03614 .67706 Mdot
.39387 .94313 Mdot
.85888 .10091 Mdot
.31239 .96869 Mdot
.26203 .99659 Mdot
.36049 .51052 Mdot
.37568 .14941 Mdot
.21254 .89828 Mdot
.83689 .31126 Mdot
.2861 .02261 Mdot
.03682 .49089 Mdot
.36218 .93349 Mdot
.24266 .81214 Mdot
.14605 .77617 Mdot
.63445 .59222 Mdot
.30883 .90992 Mdot
.24531 .00639 Mdot
.46275 .00719 Mdot
.27877 .9085 Mdot
.27311 .58733 Mdot
.32384 .31314 Mdot
.2059 .7194 Mdot
.34292 .85314 Mdot
.77645 .80039 Mdot
.2251 .92692 Mdot
.30611 .01964 Mdot
.03407 .9143 Mdot
.23735 .83664 Mdot
.15551 .79305 Mdot
.26956 .99262 Mdot
.50101 .66985 Mdot
.16376 .89411 Mdot
.30096 .76021 Mdot
.18336 .85427 Mdot
.58599 .33213 Mdot
.35333 .96242 Mdot
.08732 .98921 Mdot
.69777 .41588 Mdot
.51652 .69137 Mdot
.2895 .89343 Mdot
.20651 .56019 Mdot
.7852 .74874 Mdot
.64746 .13812 Mdot
.47791 .66028 Mdot
.14019 .77394 Mdot
.54957 .86077 Mdot
.29273 .93223 Mdot
.51588 .65035 Mdot
.17398 .00373 Mdot
.2579 .83677 Mdot
.28299 .86508 Mdot
.02431 .11809 Mdot
.08924 .11178 Mdot
.26659 .8181 Mdot
.77434 .7088 Mdot
.25105 .79855 Mdot
.36681 .94135 Mdot
.19009 .7886 Mdot
.16207 .76764 Mdot
.33345 .7035 Mdot
.82286 .54603 Mdot
.17841 .76464 Mdot
.23746 .11618 Mdot
.40069 .79656 Mdot
.20591 .82085 Mdot
.33825 .84112 Mdot
.32674 .78333 Mdot
.34891 .98077 Mdot
.29964 .85986 Mdot
.20974 .72105 Mdot
.30301 .9806 Mdot
.36404 .69673 Mdot
.27104 .84105 Mdot
.15756 .8629 Mdot
.24111 .92384 Mdot
.44146 .41484 Mdot
.0385 .68024 Mdot
.16626 .57211 Mdot
.2731 .76358 Mdot
.20431 .9628 Mdot
.2553 .81578 Mdot
.08377 .49619 Mdot
.79527 .39133 Mdot
.15165 .77716 Mdot
.95487 .14912 Mdot
.30782 .99425 Mdot
.27441 .84841 Mdot
.78927 .95672 Mdot
.5898 .61706 Mdot
.7801 .18586 Mdot
.23388 .69695 Mdot
.11131 .53624 Mdot
.26895 .83857 Mdot
.35803 .92076 Mdot
.24874 .84085 Mdot
.55452 .83663 Mdot
.07168 .64344 Mdot
.86765 .58607 Mdot
.30557 .89435 Mdot
.43474 .81807 Mdot
.29439 .03548 Mdot
.31727 .90973 Mdot
.29172 .19479 Mdot
.22799 .91878 Mdot
.52945 .81764 Mdot
.37094 .9707 Mdot
.26774 .94816 Mdot
.14078 .78475 Mdot
.47605 .9094 Mdot
.11696 .01623 Mdot
.61899 .16124 Mdot
.01174 .37557 Mdot
.25375 .94853 Mdot
.15652 .59715 Mdot
.25336 .84088 Mdot
.38416 .91878 Mdot
.20054 .90445 Mdot
.62322 .9508 Mdot
.52355 .72593 Mdot
.9985 .00713 Mdot
.23667 .75616 Mdot
.90308 .59607 Mdot
.25 .90478 Mdot
.26471 .8751 Mdot
.16973 .86409 Mdot
.0022 .44032 Mdot
.20242 .59195 Mdot
.20358 .61345 Mdot
.98512 .04232 Mdot
.07867 .93651 Mdot
.5128 .0726 Mdot
.25457 .82047 Mdot
.99389 .84886 Mdot
.32679 .98624 Mdot
.27048 .91045 Mdot
.32498 .84697 Mdot
.26239 .84803 Mdot
.24319 .84189 Mdot
.52484 .38207 Mdot
.12941 .09973 Mdot
.8143 .29868 Mdot
.26688 .83561 Mdot
.36067 .98103 Mdot
.09707 .8382 Mdot
.01591 .95954 Mdot
.69574 .92047 Mdot
.25746 .83419 Mdot
.09071 .91569 Mdot
.50703 .89893 Mdot
.2815 .7485 Mdot
.17573 .7392 Mdot
.3092 .85247 Mdot
.28285 .02596 Mdot
.15773 .60367 Mdot
.21218 .83055 Mdot
.17039 .59481 Mdot
.90643 .8227 Mdot
.87864 .5166 Mdot
.29124 .99978 Mdot
.2455 .00765 Mdot
.22166 .6193 Mdot
.5914 .56981 Mdot
.27351 .86859 Mdot
.23808 .8202 Mdot
.13904 .57375 Mdot
.40615 .35122 Mdot
.27546 .94049 Mdot
.29437 .87346 Mdot
.01869 .04943 Mdot
.11093 .10144 Mdot
.19436 .88435 Mdot
.21248 .67435 Mdot
.4564 .08497 Mdot
.81467 .48314 Mdot
.67871 .98097 Mdot
.97622 .86999 Mdot
.15643 .87265 Mdot
.10115 .68276 Mdot
.50002 .56987 Mdot
.24541 .60946 Mdot
.56337 .81033 Mdot
.20006 .02993 Mdot
.97281 .01979 Mdot
.27133 .0269 Mdot
.03192 .07038 Mdot
.01111 .02789 Mdot
.30768 .88881 Mdot
.29486 .24124 Mdot
.29948 .86 Mdot
.21046 .78879 Mdot
.24133 .90335 Mdot
.60969 .45684 Mdot
.36989 .99233 Mdot
.30238 .64461 Mdot
.2105 .98384 Mdot
.15631 .78154 Mdot
.25282 .86818 Mdot
.34818 .79733 Mdot
.26784 .82536 Mdot
.19563 .82952 Mdot
.19968 .72359 Mdot
.24904 .13891 Mdot
.6133 .63257 Mdot
.27113 .84265 Mdot
.27064 .82485 Mdot
.25573 .87704 Mdot
.33653 .84277 Mdot
.06364 .88686 Mdot
.40204 .95107 Mdot
.19865 .81018 Mdot
.2172 .68847 Mdot
.31482 .90076 Mdot
.53069 .96723 Mdot
.25113 .94404 Mdot
.24042 .80124 Mdot
.26498 .83992 Mdot
.26635 .84278 Mdot
.35521 .87948 Mdot
.27947 .89142 Mdot
.30372 .84463 Mdot
.28794 .86773 Mdot
.84646 .87387 Mdot
.18888 .77589 Mdot
.32181 .47314 Mdot
.03048 .05791 Mdot
.21882 .9155 Mdot
.32245 .99776 Mdot
.32296 .95583 Mdot
.97214 .62287 Mdot
.27051 .87074 Mdot
.43291 .41909 Mdot
.57143 .98644 Mdot
.09224 .64983 Mdot
.37894 .93574 Mdot
.22568 .83725 Mdot
.52557 .3475 Mdot
.05935 .91301 Mdot
.1661 .80979 Mdot
.33329 .78743 Mdot
.09443 .97906 Mdot
.23061 .75383 Mdot
.08992 .91234 Mdot
.31299 .70515 Mdot
.11511 .02437 Mdot
.58304 .81242 Mdot
.53801 .04449 Mdot
.20798 .24805 Mdot
.29308 .97795 Mdot
.41209 .74124 Mdot
.2424 .80563 Mdot
.64357 .55261 Mdot
.20213 .82681 Mdot
.26342 .91598 Mdot
.32696 .01629 Mdot
.40947 .42592 Mdot
.31361 .51112 Mdot
.05831 .58556 Mdot
.23723 .82861 Mdot
.58928 .9734 Mdot
.1689 .73335 Mdot
.36887 .05482 Mdot
.81947 .44429 Mdot
.3515 .99293 Mdot
.30461 .03142 Mdot
.35554 .86412 Mdot
.26551 .87181 Mdot
.25299 .83136 Mdot
.54047 .80975 Mdot
.35883 .89366 Mdot
.50285 .22932 Mdot
.15323 .70921 Mdot
.34894 .88234 Mdot
.27967 .12312 Mdot
.83454 .04658 Mdot
.17638 .60098 Mdot
.23601 .83714 Mdot
.37779 .79093 Mdot
.2723 .85269 Mdot
.29353 .83825 Mdot
.23331 .87929 Mdot
.16346 .80722 Mdot
.30267 .14718 Mdot
.44021 .03587 Mdot
.213 .90491 Mdot
.82105 .58626 Mdot
.36287 .71265 Mdot
.28464 .88476 Mdot
.35127 .9333 Mdot
.5399 .78333 Mdot
.59574 .46015 Mdot
.42236 .93451 Mdot
.3019 .00922 Mdot
.29789 .86426 Mdot
.80642 .68697 Mdot
.10571 .08198 Mdot
.17823 .81459 Mdot
.15864 .12219 Mdot
.31039 .96178 Mdot
.1279 .59997 Mdot
.43981 .4519 Mdot
.257 .81026 Mdot
.18013 .77734 Mdot
.13413 .91493 Mdot
.2818 .01117 Mdot
.20435 .73046 Mdot
.25686 .11029 Mdot
.44377 .75036 Mdot
.27511 .98983 Mdot
.22756 .72235 Mdot
.18798 .59235 Mdot
.15087 .787 Mdot
.68101 .3363 Mdot
.27699 .916 Mdot
.58176 .83245 Mdot
.02701 .69949 Mdot
.27573 .89528 Mdot
.28845 .99484 Mdot
.28426 .91058 Mdot
.19028 .87507 Mdot
.55421 .82652 Mdot
.32012 .6766 Mdot
.27305 .88206 Mdot
.11011 .02893 Mdot
.97415 .73188 Mdot
.70438 .5827 Mdot
.31349 .86561 Mdot
.33567 .9874 Mdot
.35184 .19 Mdot
.24312 .78574 Mdot
.31351 .98653 Mdot
.79623 .97445 Mdot
.99863 .89139 Mdot
.27207 .01944 Mdot
.2932 .87231 Mdot
.29371 .84377 Mdot
.28634 .84334 Mdot
.22939 .78277 Mdot
.39429 .73906 Mdot
.25209 .8098 Mdot
.27068 .60866 Mdot
.2888 .86281 Mdot
.2316 .76277 Mdot
.30168 .02247 Mdot
.19261 .87721 Mdot
.2442 .83626 Mdot
.37942 .9232 Mdot
.41325 .94537 Mdot
.23557 .02402 Mdot
.28636 .02916 Mdot
.25715 .81219 Mdot
.23498 .93049 Mdot
.12148 .02143 Mdot
.32074 .95967 Mdot
.09751 .05153 Mdot
.67792 .46599 Mdot
.27995 .94653 Mdot
.37655 .94201 Mdot
.347 .95371 Mdot
.21787 .57538 Mdot
.19917 .65942 Mdot
.94284 .59963 Mdot
.13666 .77783 Mdot
.63008 .63474 Mdot
.43798 .20825 Mdot
.62271 .77741 Mdot
.32512 .96123 Mdot
.79601 .62471 Mdot
.39912 .93056 Mdot
.25074 .01626 Mdot
.7793 .31436 Mdot
.8113 .36865 Mdot
.29989 .89852 Mdot
.34382 .85905 Mdot
.36066 .92123 Mdot
.2301 .85502 Mdot
.2658 .01297 Mdot
.00102 .84533 Mdot
.27278 .89624 Mdot
.4025 .55169 Mdot
.27025 .84771 Mdot
.20689 .97977 Mdot
.25103 .8847 Mdot
.30005 .91524 Mdot
.13698 .80841 Mdot
.26236 .90976 Mdot
.37353 .85179 Mdot
.32117 .82552 Mdot
.39769 .07645 Mdot
.32528 .02551 Mdot
.28451 .7516 Mdot
.78586 .87327 Mdot
.2695 .85214 Mdot
.1215 .02892 Mdot
.03487 .96089 Mdot
.26887 .7088 Mdot
.38428 .10742 Mdot
.23564 .86635 Mdot
.59172 .44954 Mdot
.22898 .80072 Mdot
.28402 .80951 Mdot
.90143 .73894 Mdot
.55042 .20549 Mdot
.26765 .83121 Mdot
.99811 .00672 Mdot
.3177 .95203 Mdot
.63746 .43411 Mdot
.25571 .78246 Mdot
.85305 .27504 Mdot
.31455 .01651 Mdot
.27856 .86696 Mdot
.81566 .62499 Mdot
.54137 .75838 Mdot
.37791 .98323 Mdot
.526 .14224 Mdot
.70522 .26904 Mdot
.01042 .09806 Mdot
.25063 .87509 Mdot
.96794 .34368 Mdot
.24718 .81024 Mdot
.89608 .97595 Mdot
.27476 .92521 Mdot
.72867 .17701 Mdot
.6061 .14833 Mdot
.08766 .03433 Mdot
.60039 .82055 Mdot
.94811 .50158 Mdot
.33415 .96414 Mdot
.27619 .91404 Mdot
.49631 .72349 Mdot
.31163 .79939 Mdot
.75034 .08843 Mdot
.14113 .94611 Mdot
.32914 .9466 Mdot
.23649 .98645 Mdot
.94104 .01824 Mdot
.35688 .54986 Mdot
.54204 .7412 Mdot
.19655 .85005 Mdot
.3158 .96839 Mdot
.25004 .87263 Mdot
.26533 .67873 Mdot
.54119 .64882 Mdot
.97792 .65676 Mdot
.32733 .86044 Mdot
.05623 .6482 Mdot
.32419 .90027 Mdot
.35962 .94979 Mdot
.126 .66887 Mdot
.23081 .85307 Mdot
.34568 .76188 Mdot
.93789 .83262 Mdot
.16665 .04637 Mdot
.18202 .84834 Mdot
.48325 .49784 Mdot
.19609 .68886 Mdot
.98022 .9148 Mdot
.85921 .73793 Mdot
.32909 .92217 Mdot
.68748 .67102 Mdot
.22972 .91527 Mdot
.2599 .83171 Mdot
.61485 .78703 Mdot
.23209 .90465 Mdot
.30401 .98463 Mdot
.59569 .07123 Mdot
.30299 .0337 Mdot
.84004 .66965 Mdot
.03553 .77223 Mdot
.85776 .73339 Mdot
.98224 .65907 Mdot
.25809 .79591 Mdot
.38453 .84694 Mdot
.78939 .88011 Mdot
.26566 .85355 Mdot
.25109 .88835 Mdot
.33325 .891 Mdot
.20521 .87841 Mdot
.62289 .85329 Mdot
.65723 .95126 Mdot
.58962 .42088 Mdot
.44864 .40188 Mdot
.31824 .74202 Mdot
.62638 .41696 Mdot
.20788 .89966 Mdot
.20828 .87804 Mdot
.33923 .9507 Mdot
.76963 .72966 Mdot
.60857 .96878 Mdot
.23937 .74792 Mdot
.25122 .89794 Mdot
.75547 .81488 Mdot
.19459 .73154 Mdot
.87969 .67176 Mdot
.20906 .87563 Mdot
.35465 .92757 Mdot
.18286 .94804 Mdot
.30602 .96817 Mdot
.31865 .02945 Mdot
.14457 .80076 Mdot
.25774 .95823 Mdot
.44622 .99332 Mdot
.29929 .83483 Mdot
.37688 .94477 Mdot
.93794 .82414 Mdot
.26552 .83651 Mdot
.28156 .97365 Mdot
.3459 .93209 Mdot
.28036 .76972 Mdot
.2774 .88365 Mdot
.56952 .80148 Mdot
.74269 .61372 Mdot
.3383 .77887 Mdot
.24537 .85973 Mdot
.18218 .79452 Mdot
.27229 .8327 Mdot
.3118 .98247 Mdot
.26447 .87481 Mdot
.78725 .47454 Mdot
.34109 .99307 Mdot
.16452 .79153 Mdot
.37781 .93618 Mdot
.34925 .79472 Mdot
.20529 .39152 Mdot
.22896 .86273 Mdot
.22626 .05016 Mdot
.8026 .5154 Mdot
.56991 .89606 Mdot
.26208 .84276 Mdot
.19961 .57848 Mdot
.10433 .62514 Mdot
.2121 .89996 Mdot
.2267 .83991 Mdot
.3188 .87665 Mdot
.4093 .58259 Mdot
.00363 .38232 Mdot
.15993 .81587 Mdot
.26813 .77872 Mdot
.49467 .66955 Mdot
.28139 .81328 Mdot
.06976 .6606 Mdot
.26398 .56586 Mdot
.18257 .82017 Mdot
.25888 .88531 Mdot
.01451 .80284 Mdot
.24393 .93169 Mdot
.31589 .85884 Mdot
.1245 .11125 Mdot
.22504 .86417 Mdot
.30851 .99891 Mdot
.44518 .13989 Mdot
.28655 .12385 Mdot
.54661 .7533 Mdot
.31371 .02278 Mdot
.53356 .71714 Mdot
.19781 .7886 Mdot
.35527 .86253 Mdot
.30012 .10611 Mdot
.08925 .84397 Mdot
.25095 .84884 Mdot
.26309 .41585 Mdot
.70776 .73258 Mdot
.30652 .89188 Mdot
.78719 .63868 Mdot
.27106 .84902 Mdot
.28555 .86677 Mdot
.14903 .76377 Mdot
.31685 .89273 Mdot
.25009 .80904 Mdot
.16493 .58187 Mdot
.25019 .80536 Mdot
.14206 .77747 Mdot
.80182 .50938 Mdot
.31459 .01836 Mdot
.97333 .04823 Mdot
.48844 .65484 Mdot
.30474 .92051 Mdot
.73149 .696 Mdot
.26601 .87135 Mdot
.27488 .01593 Mdot
.39726 .46783 Mdot
.23389 .73471 Mdot
.14562 .78177 Mdot
.04708 .42457 Mdot
.25129 .12079 Mdot
.28777 .86864 Mdot
.26062 .83864 Mdot
.20015 .87903 Mdot
.73345 .75861 Mdot
.54623 .88212 Mdot
.35778 .68957 Mdot
.36383 .91014 Mdot
.24961 .80965 Mdot
.35287 .93166 Mdot
.22726 .05378 Mdot
.19371 .78373 Mdot
.37081 .96674 Mdot
.2644 .07489 Mdot
.27 .79123 Mdot
.93777 .50401 Mdot
.26842 .84266 Mdot
.27741 .37213 Mdot
.18371 .78379 Mdot
.32803 .90561 Mdot
.27637 .85814 Mdot
.2695 .86232 Mdot
.18278 .85313 Mdot
.34375 .73884 Mdot
.25582 .79655 Mdot
.30528 .70135 Mdot
.34733 .95866 Mdot
.25791 .59053 Mdot
.1612 .66668 Mdot
.30063 .87915 Mdot
.01894 .73859 Mdot
.28092 .80599 Mdot
.17867 .80489 Mdot
.21726 .79797 Mdot
.43821 .98423 Mdot
.24087 .80974 Mdot
.23238 .81117 Mdot
.28544 .37715 Mdot
.07091 .96699 Mdot
.32926 .02551 Mdot
.63928 .9012 Mdot
.29564 .91631 Mdot
.26312 .83572 Mdot
.31829 .80888 Mdot
.1294 .97006 Mdot
.32479 .95011 Mdot
.31196 .96235 Mdot
.76405 .59694 Mdot
.22345 .92871 Mdot
.56707 .89608 Mdot
.21723 .36014 Mdot
.34468 .4347 Mdot
.13307 .98373 Mdot
.22415 .92245 Mdot
.85171 .97904 Mdot
.28628 .86419 Mdot
.08267 .77881 Mdot
.30998 .9136 Mdot
.27727 .86125 Mdot
.15653 .79854 Mdot
.33009 .02361 Mdot
.33196 .94898 Mdot
.39677 .57222 Mdot
.18236 .01425 Mdot
.88675 .66532 Mdot
.55761 .7249 Mdot
.54078 .92928 Mdot
.24685 .02697 Mdot
.35903 .96592 Mdot
.30062 .00307 Mdot
.34531 .82647 Mdot
.48282 .89741 Mdot
.13688 .62313 Mdot
.17047 .82617 Mdot
.33328 .7824 Mdot
.19795 .79181 Mdot
.51976 .8211 Mdot
.22343 .83639 Mdot
.41442 .07327 Mdot
.19704 .87896 Mdot
.38074 .3243 Mdot
.42232 .56824 Mdot
.32326 .05262 Mdot
.26867 .85146 Mdot
.29491 .91022 Mdot
.04092 .59602 Mdot
.25583 .49019 Mdot
.34478 .79795 Mdot
.35099 .28268 Mdot
.53536 .19029 Mdot
.16456 .94641 Mdot
.29593 .94794 Mdot
.2938 .87318 Mdot
.21159 .8967 Mdot
.85816 .18081 Mdot
.32678 .97697 Mdot
.07107 .33902 Mdot
.24787 .89403 Mdot
.27793 .8635 Mdot
.89512 .84096 Mdot
.31211 .88944 Mdot
.37178 .94359 Mdot
.19498 .80937 Mdot
.60113 .66729 Mdot
.11067 .99915 Mdot
.2561 .89781 Mdot
.57967 .05641 Mdot
.25224 .93985 Mdot
.21286 .8974 Mdot
.28959 .47558 Mdot
.29495 .936 Mdot
.87768 .7344 Mdot
.25621 .91777 Mdot
.14228 .56016 Mdot
.0877 .98864 Mdot
.36749 .89736 Mdot
.86054 .52847 Mdot
.46044 .64384 Mdot
.26562 .0071 Mdot
.02201 .26721 Mdot
.23038 .93171 Mdot
.24569 .86092 Mdot
.30726 .8959 Mdot
.22218 .92207 Mdot
.28594 .85797 Mdot
.81971 .46896 Mdot
.18882 .57803 Mdot
.23026 .6257 Mdot
.83826 .62686 Mdot
.70189 .99956 Mdot
.28554 .84133 Mdot
.76069 .07232 Mdot
.00378 .90312 Mdot
.6608 .69994 Mdot
.16621 .86916 Mdot
.24702 .8144 Mdot
.20153 .55949 Mdot
.14184 .49764 Mdot
.26442 .84955 Mdot
.28345 .81419 Mdot
.27352 .85798 Mdot
.30962 .99981 Mdot
.34851 .2606 Mdot
.18646 .57805 Mdot
.25117 .89166 Mdot
.2192 .97984 Mdot
.31117 .84218 Mdot
.68329 .04333 Mdot
.36282 .97637 Mdot
.26982 .82313 Mdot
.82794 .30205 Mdot
.22413 .85427 Mdot
.38432 .74898 Mdot
.21829 .37846 Mdot
.14066 .77845 Mdot
.2577 .79011 Mdot
.32674 .86632 Mdot
.37997 .62618 Mdot
.21098 .588 Mdot
.26804 .86517 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`?o00003Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool2o`0000So
oooo00?o0000ooooooooool02_ooool2o`000003ooooool0003ooooo00Oooooo0_l00005ooooo`;o
00003_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`00
7_ooool3o`0000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00Cooooo0_l00008ooooo`03o`000?oooooooooo00_ooooo0ol00003ooooo`;o0000
0oooool2o`0000Gooooo0_l0000>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`02o`0000_ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool3o`0000Cooooo
000Nooooo`03o`000?oooooooooo04cooooo0_l00004ooooo`;o000000?oooooo`000?l000001ooo
ool2o`0003;ooooo0_l0002/ooooo`?o00001?ooool001kooooo00?o0000ooooooooool0C?ooool2
o`0000Cooooo0_l000000ooooooo0000o`000002o`0000Cooooo0ol0003Wooooo`007_ooool00ol0
003oooooooooo`0Rooooo`;o00004oooool2o`0001Cooooo0_l00003ooooo`;o000000?oooooo`00
0?l000000_l00004ooooo`;o00000oooool2o`0000;ooooo0_l0003?ooooo`;o00003_ooool001ko
oooo00?o0000ooooooooool08_ooool2o`0001?ooooo0_l0000Dooooo`;o00001Oooool3o`0000So
oooo0_l000000ooooooo0000o`000002ooooo`Co00006Oooool2o`000:Wooooo0_l00007ooooo`?o
00003Oooool001kooooo00?o0000ooooooooool08oooool2o`0002oooooo0_l00003ooooo`;o0000
0oooool3o`000003ooooool0003o000000Cooooo0_l0000Iooooo`;o0000ZOooool2o`0000Sooooo
0_l0000=ooooo`007_ooool00ol0003oooooooooo`0Qooooo`Co00008oooool2o`0000kooooo1?l0
0002ooooo`Ko00000_ooool3o`0004;ooooo0_l0002Jooooo`007_ooool01?l0003oooooo`000?l0
000Oooooo`Go00008oooool2o`0000;ooooo0_l00006ooooo`;o00000_ooool4o`0000Cooooo0_l0
0004ooooo`?o0000@_ooool2o`0009[ooooo000Nooooo`04o`000?oooooo0000o`0001oooooo0_l0
00000ooooooo0000o`00000Hooooo`;o00003Oooool2o`0000Kooooo0_l00003ooooo`;o00001?oo
ool2o`0000;ooooo0_l0003Rooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o00008oooool2
o`0001[ooooo0_l00003ooooo`?o00000_ooool2o`000=7ooooo0_l0000?ooooo`007_ooool00ol0
003oooooooooo`0Hooooo`;o0000@_ooool4o`0002_ooooo0_l0002Yooooo`;o00003oooool001ko
oooo00?o0000ooooooooool0G?ooool2o`0002gooooo0_l0002jooooo`007_ooool00ol0003ooooo
ooooo`1eooooo`;o0000=?ooool2o`0002gooooo0_l0001Pooooo`;o00002Oooool001kooooo00?o
0000ooooooooool0<_ooool2o`00047ooooo0_l0000dooooo`;o0000;Oooool2o`0000_ooooo0_l0
000Rooooo`;o0000;oooool2o`0000Wooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0000^
ooooo`;o00004Oooool2o`000:3ooooo0_l0000Rooooo`;o0000:oooool2o`0000gooooo000Noooo
o`;o00000oooool2o`0001Sooooo0_l0000Wooooo`;o00007_ooool2o`000=7ooooo0_l0000=oooo
o`007_ooool00ol0003oooooooooo`0Looooo`;o00004?ooool2o`0001Kooooo0_l0000Mooooo`;o
00003Oooool2o`0004;ooooo0_l0002=ooooo`007_ooool00ol0003oooooooooo`06ooooo`;o0000
9_ooool2o`0001Kooooo0_l0000/ooooo`;o0000@_ooool2o`0008gooooo000Nooooo`03o`000?oo
oooooooo00Kooooo0_l0003ooooood3ooooo000Nooooo`04o`000?ooooooooooooooo`;o00006Ooo
ool2o`0000_ooooo0_l0000Dooooo`;o000000?oooooo`000?l00000ooooool4ooooo`007_ooool0
1?l0003oooooooooooooool2o`0001Wooooo0_l0000;ooooo`;o00000oooool2o`0000oooooo0_l0
00000ooooooo0000o`00003oooooo`Cooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l00008
ooooo`;o00007?ooool2o`0008kooooo0_l00027ooooo`007_ooool00ol0003oooooooooo`06oooo
o`;o00002?ooool2o`0001oooooo0_l0000Oooooo`;o0000;oooool2o`0001kooooo0_l0000Ioooo
o`;o0000<oooool2o`0005;ooooo000Nooooo`03o`000?oooooooooo037ooooo0_l0000Oooooo`;o
0000:Oooool2o`0000Cooooo0_l0000Nooooo`;o0000C_ooool2o`0004Gooooo0_l0000;ooooo`00
7_ooool00ol0003oooooooooo`1mooooo`;o0000^oooool2o`0000_ooooo000Nooooo`03o`000?oo
oooooooo01kooooo0_l0003oooooobSooooo000Nooooo`03o`000?oooooooooo01kooooo0_l0001`
ooooo`;o0000]Oooool001kooooo00?o0000ooooooooool0T?ooool2o`0005kooooo0_l0001Eoooo
o`007_ooool00ol0003oooooooooo`3`ooooo`;o0000EOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool01?l0003oooooo`000?l0000Uooooo`;o000000?oooooo`000?l00000
>Oooool2o`000>7ooooo000Nooooo`Co00007oooool2o`0000Cooooo0_l000000ooooooo0000o`00
000iooooo`;o0000[Oooool2o`0003;ooooo000Nooooo`03o`000?oooooooooo023ooooo0_l0003a
ooooo`;o0000<_ooool001kooooo00?o0000ooooooooool0GOooool2o`0001[ooooo0_l0003<oooo
o`007_ooool00ol0003oooooooooo`0Iooooo`;o00002Oooool2o`0002Wooooo0_l0000<ooooo`;o
00006_ooool2o`000:Gooooo0_l0000Uooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o0000
2Oooool2o`0002Wooooo0ol0003>ooooo`;o00009Oooool001kooooo00?o0000ooooooooool01?oo
ool2o`0004?ooooo0_l00005ooooo`;o0000mOooool001kooooo00?o0000ooooooooool01?ooool2
o`0004?ooooo0_l00003ooooo`;o0000moooool001kooooo00?o0000ooooooooool0;oooool2o`00
01gooooo0_l00007ooooo`Co0000I?ooool2o`0008Kooooo000Nooooo`03o`000?oooooooooo02oo
oooo0_l0000Vooooo`Co0000I?ooool2o`0008Kooooo000Nooooo`03o`000?oooooooooo05gooooo
0_l0003Xooooo`007_ooool00ol0003oooooooooo`0Uooooo`;o0000=_ooool2o`000>Sooooo000N
ooooo`03o`000?oooooooooo02Gooooo0_l0003oooooob7ooooo000Nooooo`03o`000?oooooooooo
04gooooo0_l0001oooooo`;o0000Moooool001kooooo00?o0000ooooooooool0COooool2o`0003ko
oooo0_l0000Hooooo`;o00009Oooool2o`0007Oooooo000Nooooo`03o`000?oooooooooo08gooooo
0_l0000Hooooo`;o0000W_ooool001kooooo00?o0000ooooooooool0G_ooool2o`00067ooooo0_l0
0024ooooo`007_ooool2o`0005oooooo0_l0000Fooooo`;o0000BOooool2o`0006oooooo0_l0000C
ooooo`007_ooool00ol0003oooooooooo`1fooooo`;o0000^_ooool2o`0001?ooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0<?ooool2o`0006oooooo
0_l0000Rooooo`;o0000P?ooool001kooooo00?o0000ooooooooool0<?ooool2o`0006oooooo0_l0
000Rooooo`;o0000P?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`10ooooo`;o0000Yooo
ool2o`0005cooooo000Nooooo`03o`000?oooooooooo043ooooo0_l0002Wooooo`;o0000:?ooool2
o`0003;ooooo000Nooooo`03o`000?oooooooooo0?[ooooo0_l0000Gooooo`;o0000<_ooool001ko
oooo00?o0000ooooooooool0n_ooool2o`0001Oooooo0_l0000booooo`007_ooool00ol0003ooooo
ooooo`1^ooooo`;o0000>_ooool2o`0006Oooooo0_l0000booooo`000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`1Kooooo`;o0000
4Oooool2o`0003[ooooo0_l0002Kooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1Kooooo`;o
0000j_ooool000?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo0ol0003oooooodSooooo0003ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So
8B4Qonk^kP06ooooo`03o`000?oooooooooo00Sooooo0_l0003oooooockooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo00So
oooo0_l0002Uooooo`;o0000U_ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0R_ooool2o`0002?ooooo0_l0001booooo`;o
00008_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRH
V?l@41001_ooool00ol0003oooooooooo`2:ooooo`;o0000Uoooool2o`0002;ooooo0003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo09oooooo0_l0002V
ooooo`007_ooool00ol0003oooooooooo`2Oooooo`;o0000Y_ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`1Looooo`;o0000jOooool001kooooo00?o
0000ooooooooool0G?ooool2o`000>Wooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0?oooool2o`000?oooooo1oooool001kooooo0_l00010ooooo`;o
0000ooooool7ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo01Oooooo0_l0003ooooooboooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0001D
ooooo`;o0000Qoooool2o`0004oooooo000Nooooo`03o`000?oooooooooo06gooooo0_l00027oooo
o`;o0000Coooool001kooooo00?o0000ooooooooool00oooool2o`000?oooooo@oooool001kooooo
00?o0000ooooooooool00oooool2o`000=cooooo0_l0001Tooooo`007_ooool00ol0003ooooooooo
o`3Qooooo`;o0000;_ooool2o`0003Cooooo000Nooooo`03o`000?oooooooooo0?oooooo4_ooool2
o`0003Cooooo000Nooooo`03o`000?oooooooooo05Gooooo0_l0003`ooooo`007_ooool00ol0003o
ooooooooo`0Dooooo`;o0000?oooool2o`0001Oooooo0_l00025ooooo`;o0000D?ooool001kooooo
00?o0000ooooooooool05?ooool2o`0005Sooooo0_l00025ooooo`;o0000D?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0K_ooool2o`0009Go
oooo0_l00010ooooo`007_ooool2o`0006oooooo0_l0002Eooooo`;o00000_ooool2o`0003cooooo
000Nooooo`03o`000?oooooooooo0?oooooo2_ooool2o`0003cooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0ooooool=ooooo`;o0000>Oooool001ko
oooo00?o0000ooooooooool0E?ooool2o`0000oooooo0_l0002Booooo`;o00004Oooool2o`0003Wo
oooo000Nooooo`03o`000?oooooooooo05Cooooo0_l0000?ooooo`;o0000Moooool2o`0001Wooooo
0_l0001<ooooo`007_ooool00ol0003oooooooooo`3Nooooo`;o0000Ioooool001kooooo00?o0000
ooooooooool0N?ooool2o`000<gooooo000Nooooo`03o`000?oooooooooo07Sooooo0_l0003=oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0;[ooooo
0_l0002;ooooo`007_ooool00ol0003oooooooooo`2jooooo`;o00007Oooool2o`0003gooooo0_l0
000]ooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o0000a?ooool2o`0003gooooo0_l0000]
ooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o0000oooooolcooooo`007_ooool00ol0003o
ooooooooo`3oooooocSooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`2Wooooo`;o0000
S_ooool2o`0000kooooo000Nooooo`;o0000POooool2o`0002Gooooo0_l0002Nooooo`007_ooool0
0ol0003oooooooooo`20ooooo`;o0000aOooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`13ooooo`;o0000ooooool3ooooo`007_ooool00ol0003ooooo
ooooo`13ooooo`;o0000ooooool3ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo02kooooo0_l0003Dooooo`;o0000@Oooool001kooooo00?o0000oooo
ooooool0;_ooool2o`0002Kooooo0_l0002/ooooo`;o0000@Oooool001kooooo00?o0000oooooooo
ool00_l0001Dooooo`;o0000koooool001kooooo00?o0000ooooooooool00_l00011ooooo`;o0000
5?ooool2o`000>cooooo000Nooooo`;o0000A?ooool2o`0001Cooooo0_l0001<ooooo`;o0000W_oo
ool001kooooo0_l0002Xooooo`;o0000W_ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`0oooooo`;o0000Coooool2o`0006cooooo0_l00017ooooo`00
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@oooooooo
ool01?ooool00ol0003oooooooooo`0oooooo`;o0000Coooool2o`0006cooooo0_l000000ooooooo
0000o`000014ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0ooooool2ooooo`;o0000A?ooool000?ooooo
00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool3o`000?ooooooB?ooool000?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000oooo
ooooool0S_ooool2o`000;Oooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01?oM
gMgoEEEEooooool00007ooooo`03o`000?oooooooooo08kooooo0_l0002gooooo`000oooool01Ol@
413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3o
ooooodSooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007
ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=
ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0DOooool2o`0003Sooooo0_l0001B
ooooo`;o0000I_ooool001kooooo00?o0000ooooooooool0DOooool2o`0003Kooooo1?l0000koooo
o`;o00005Oooool2o`0006Kooooo000Nooooo`03o`000?oooooooooo08Wooooo0_l0000aooooo`;o
00002_ooool2o`0007gooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l0002_ooooo`;o0000
ROooool001kooooo00?o0000ooooooooool02oooool2o`0007Cooooo0_l00034ooooo`007_ooool0
0ol0003oooooooooo`21ooooo`;o0000a?ooool001kooooo00?o0000ooooooooool0K?ooool2o`00
05gooooo0_l0001jooooo`007_ooool00ol0003oooooooooo`1/ooooo`;o0000GOooool2o`0007[o
oooo000Nooooo`;o0000oooooolPooooo`;o00009oooool001kooooo0_l0003oooooo`Sooooo0_l0
000Fooooo`;o00009oooool001kooooo00?o0000ooooooooool0ooooool7ooooo`;o0000?oooool0
01kooooo00?o0000ooooooooool0_?ooool2o`0008Wooooo000Nooooo`;o0000S?ooool2o`0002oo
oooo0_l00029ooooo`007_ooool00ol0003oooooooooo`2;ooooo`;o0000^_ooool001kooooo00?o
0000ooooooooool0`_ooool2o`0008?ooooo000Nooooo`03o`000?oooooooooo0;kooooo0_l00002
ooooo`;o0000Poooool001kooooo00?o0000ooooooooool0__ooool2o`0008Oooooo000Nooooo`03
o`000?oooooooooo07gooooo0_l0001Iooooo`;o0000KOooool001kooooo00?o0000ooooooooool0
OOooool2o`0005Wooooo0_l0000/ooooo`;o0000?oooool001kooooo00?o0000ooooooooool0IOoo
ool2o`0009Gooooo0_l00008ooooo`;o0000?oooool001kooooo00?o0000ooooooooool0FOooool3
o`0000Wooooo0_l0002Eooooo`;o0000BOooool001kooooo00?o0000ooooooooool0FOooool3o`00
0>_ooooo000Nooooo`03o`000?oooooooooo0?oooooo1_ooool2o`00043ooooo000Nooooo`03o`00
0?oooooooooo0?[ooooo0_l00009ooooo`;o0000@?ooool001kooooo00?o0000ooooooooool0Cooo
ool2o`000:Wooooo0_l0001;ooooo`007_ooool00ol0003oooooooooo`08ooooo`;o0000AOooool2
o`000?Kooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0000=ooooo`;o0000ooooool_oooo
o`007_ooool00ol0003oooooooooo`0Gooooo`;o00004Oooool2o`0006gooooo0_l0000gooooo`;o
0000A_ooool2o`0002_ooooo000Nooooo`;o0000:oooool2o`0006gooooo0_l0000gooooo`;o0000
A_ooool2o`0001Cooooo0_l0000Eooooo`007_ooool00ol0003oooooooooo`3oooooobkooooo0_l0
00000ooooooo0000o`00000Eooooo`007_ooool00ol0003oooooooooo`0Yooooo`;o0000ooooool3
ooooo`;o00006?ooool001kooooo00?o0000ooooooooool0:Oooool2o`0003Oooooo0_l0000=oooo
o`;o0000S_ooool2o`0004Cooooo000Nooooo`03o`000?oooooooooo06;ooooo0_l0000=ooooo`;o
0000S_ooool2o`0004Cooooo000Nooooo`03o`000?oooooooooo0?oooooo0_ooool2o`0001Oooooo
0_l0000[ooooo`007_ooool00ol0003oooooooooo`3oooooo`;ooooo0_l0000Gooooo`;o0000:ooo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?oooooo5Oooool2o`00037ooooo000Nooooo`03o`00
0?oooooooooo03Cooooo0_l0003Nooooo`;o0000<Oooool001kooooo00?o0000ooooooooool08?oo
ool2o`0001;ooooo0_l0003ooooooa;ooooo000Nooooo`03o`000?oooooooooo023ooooo0_l0003o
ooooobKooooo000Nooooo`03o`000?oooooooooo06kooooo0_l0003Gooooo`007_ooool00ol0003o
ooooooooo`1^ooooo`;o0000eoooool001kooooo00?o0000ooooooooool0;_ooool2o`000=Oooooo
0_l0000nooooo`007_ooool2o`0002oooooo0_l00010ooooo`;o00003Oooool2o`0008Kooooo0_l0
000nooooo`007_ooool00ol0003oooooooooo`1`ooooo`;o00003Oooool2o`0004cooooo0_l0001h
ooooo`007_ooool00ol0003oooooooooo`3=ooooo`;o0000N?ooool001kooooo00?o0000oooooooo
ool0:_ooool2o`00017ooooo1?l0003oooooo`Oooooo000Nooooo`03o`000?oooooooooo02[ooooo
0_l0000Aooooo`Co0000ooooool7ooooo`007_ooool00ol0003oooooooooo`0cooooo`;o00007Ooo
ool2o`000??ooooo000Nooooo`03o`000?oooooooooo03?ooooo0_l0000Mooooo`;o0000<Oooool2
o`0001Oooooo0_l0000Looooo`;o0000ROooool001kooooo00?o0000ooooooooool0<_ooool2o`00
00?ooooo0_l00014ooooo`;o00001_ooool2o`0001Oooooo0_l0000Looooo`;o0000ROooool001ko
oooo00?o0000ooooooooool0:Oooool2o`0000Oooooo0_l00003ooooo`;o00002_ooool2o`0003So
oooo0_l00038ooooo`007_ooool00ol0003oooooooooo`0Yooooo`;o00002?ooool2o`0000Cooooo
0ol000000ooooooo0000o`000004ooooo`;o0000ooooool3ooooo`007_ooool00ol0003ooooooooo
o`0booooo`?o00001?ooool3o`000003ooooool0003o000004;ooooo0_l0001Nooooo`;o0000I?oo
ool001kooooo00?o0000ooooooooool03oooool2o`0001Oooooo0_l00008ooooo`;o0000COooool2
o`0005kooooo0_l0001Tooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o00005_ooool3o`00
01Kooooo0_l0000Cooooo`;o0000/?ooool2o`0000gooooo0_l0000_ooooo`007_ooool00ol0003o
ooooooooo`0Wooooo`;o00003Oooool2o`0000;ooooo0_l00002ooooo`Co00003_ooool2o`0000?o
oooo0_l0002`ooooo`;o00003Oooool2o`0002oooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo
03?ooooo0_l000001?oooooo0000o`000?ooool3o`0000;ooooo0_l0000@ooooo`;o00001oooool2
o`0006oooooo0_l0001kooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`09ooooo`;o00009?oo
ool6o`0000Cooooo0_l0000Nooooo`;o0000Koooool2o`0002Sooooo0_l0000:ooooo`;o00007ooo
ool2o`0002Cooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000000Kooooo0ol00009ooooo`;o00006_ooool2o`0000Sooooo1?l00002ooooo`;o0000
_Oooool2o`0000[ooooo0_l0000Oooooo`;o00002oooool2o`0001Oooooo0003ooooo`05o`000?oo
ooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o0000oooooooo
ool09Oooool2o`0000Sooooo0_l000001?oooooo0000o`000?ooool2o`000?Oooooo0_l0000Goooo
o`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c006
ooooo`03o`000?oooooooooo02oooooo0_l000000ooooooo0000o`00003ooooooaCooooo0003oooo
o`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooo
oooo04cooooo0_l00006ooooo`;o00005oooool2o`000=Sooooo0003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo03kooooo0_l0000<
ooooo`;o00001_ooool2o`0001Oooooo0_l0001looooo`;o0000F_ooool000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0?_oo
ool2o`000:_ooooo1?l0001Hooooo`007_ooool00ol0003oooooooooo`0Zooooo`;o00006?ooool2
o`0007Kooooo0_l0000_ooooo`;o0000F?ooool001kooooo00?o0000ooooooooool0:_ooool2o`00
01Sooooo0_l0001fooooo`;o0000ROooool001kooooo00?o0000ooooooooool07_ooool2o`0000So
oooo0_l0000Mooooo`;o00008Oooool2o`0009?ooooo0_l00004ooooo`;o0000<Oooool2o`0000go
oooo000Nooooo`03o`000?oooooooooo00cooooo0_l0000@ooooo`;o00002?ooool2o`0001gooooo
0_l0000Qooooo`;o00002oooool2o`0008Kooooo0_l00004ooooo`;o00001Oooool2o`0002[ooooo
0_l0000=ooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o0000E?ooool2o`0001?ooooo0_l0
002Cooooo`;o0000>Oooool001kooooo00?o0000ooooooooool0@oooool2o`0001gooooo0_l0001O
ooooo`;o00001?ooool2o`0007cooooo000Nooooo`03o`000?oooooooooo04?ooooo0_l0001noooo
o`;o00001?ooool2o`0007cooooo000Nooooo`03o`000?oooooooooo04Sooooo0_l0002booooo`;o
0000BOooool001kooooo00?o0000ooooooooool04oooool2o`0003?ooooo0_l00018ooooo`;o0000
J?ooool2o`0004Wooooo000Nooooo`03o`000?oooooooooo01?ooooo0_l0000Wooooo`;o00008?oo
ool2o`0003;ooooo0_l0002cooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o00002_ooool2
o`00023ooooo0_l0000Pooooo`;o0000A?ooool2o`0000Kooooo0_l0002Iooooo`007_ooool2o`00
00oooooo0_l0000:ooooo`;o0000>oooool2o`0004_ooooo0_l00006ooooo`;o0000VOooool001ko
oooo00?o0000ooooooooool0Eoooool2o`0004;ooooo0_l0002Zooooo`007_ooool00ol0003ooooo
ooooo`0mooooo`;o0000G?ooool2o`0009gooooo0ol0000:ooooo`007_ooool00ol0003ooooooooo
o`0Cooooo`;o0000:?ooool2o`0005Sooooo0_l0002Qooooo`?o00002_ooool001kooooo00?o0000
ooooooooool04oooool2o`0008;ooooo0_l00023ooooo`;o0000:Oooool001kooooo00?o0000oooo
ooooool09Oooool2o`0000Wooooo0_l0000Tooooo`;o0000Ioooool2o`0005_ooooo0_l0000Yoooo
o`007_ooool00ol0003oooooooooo`0Uooooo`;o00002Oooool2o`0002Cooooo0_l00015ooooo`Co
00007_ooool2o`0001[ooooo0_l0000`ooooo`;o00002oooool2o`0002_ooooo000Nooooo`03o`00
0?oooooooooo047ooooo0_l0001Jooooo`Co0000>_ooool2o`00033ooooo0_l0000;ooooo`;o0000
:oooool001kooooo00?o0000ooooooooool02?ooool2o`0003Oooooo0_l0000Qooooo`?o0000h?oo
ool001kooooo00?o0000ooooooooool02?ooool2o`0004Sooooo0_l0000@ooooo`?o0000h?ooool0
01kooooo00?o0000ooooooooool02?ooool2o`0001?ooooo0_l0000cooooo`;o00003?ooool2o`00
0>Gooooo000Nooooo`03o`000?oooooooooo01gooooo0_l00011ooooo`;o0000X?ooool2o`0004?o
oooo000Nooooo`03o`000?oooooooooo03cooooo0_l00004ooooo`;o00007Oooool2o`0000gooooo
0_l0002@ooooo`;o0000@oooool001kooooo00?o0000ooooooooool0??ooool2o`0000?ooooo0ol0
000Mooooo`;o00003Oooool2o`0003;ooooo0_l0002Qooooo`007_ooool00ol0003oooooooooo`11
ooooo`;o0000HOooool2o`0004Cooooo0_l0001Kooooo`007_ooool00ol0003oooooooooo`05oooo
o`;o0000@Oooool2o`0002Sooooo0_l0001fooooo`;o0000Foooool001kooooo0_l00006ooooo`;o
0000@Oooool2o`0001Gooooo0_l0000>ooooo`;o000000?oooooo`000?l00000Goooool2o`0007;o
oooo000Nooooo`03o`000?oooooooooo05oooooo0_l000000ooooooo0000o`000004ooooo`;o0000
1Oooool2o`0006;ooooo0_l0001booooo`007_ooool00ol0003oooooooooo`1Cooooo`;o00003Ooo
ool2o`0000Cooooo0_l0001gooooo`;o00005Oooool2o`0004gooooo000Nooooo`03o`000?oooooo
oooo02kooooo0_l0000Sooooo`;o0000S?ooool2o`0001Gooooo0_l0001=ooooo`007_ooool00ol0
003oooooooooo`0^ooooo`;o00002oooool2o`00033ooooo0_l00003ooooo`;o00001oooool2o`00
0<[ooooo000Nooooo`03o`000?oooooooooo03_ooooo0_l0000`ooooo`;o00000oooool2o`0000?o
oooo0_l00002ooooo`;o0000;?ooool2o`0009cooooo000Nooooo`03o`000?oooooooooo03oooooo
0ol0000:ooooo`;o0000:Oooool2o`00033ooooo0_l0002Looooo`007_ooool00ol0003ooooooooo
o`0mooooo`Go00001?ooool2o`0000Cooooo0_l0001?ooooo`;o0000Z?ooool001kooooo00?o0000
ooooooooool0?Oooool2o`0000Oooooo0_l0001Eooooo`;o00001oooool2o`0000Wooooo0_l0000h
ooooo`;o0000F_ooool001kooooo00Co0000oooooooooooooooo0_l0002Sooooo`;o00002Oooool2
o`0003Sooooo0_l00009ooooo`;o0000Coooool001kooooo00Co0000oooooooooooooooo0_l0000`
ooooo`;o00001_ooool2o`000003ooooool0003o000000Sooooo0_l0002Hooooo`;o00004_ooool2
o`0001_ooooo0_l0000Tooooo`;o00003?ooool001kooooo00?o0000ooooooooool0<oooool2o`00
00Kooooo0_l000000ooooooo0000o`000008ooooo`;o0000V?ooool2o`0002oooooo0_l00004oooo
o`;o00007_ooool2o`0000cooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0000aooooo`;o
00004Oooool2o`0002;ooooo0_l0000>ooooo`;o00009Oooool2o`0006kooooo0_l00004ooooo`;o
00001_ooool2o`0002Cooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0000aooooo`;o0000
;?ooool2o`0000Oooooo0_l0000>ooooo`;o00001?ooool2o`0001oooooo0_l00007ooooo`;o0000
IOooool2o`0000cooooo0_l0000Tooooo`007_ooool00ol0003oooooooooo`11ooooo`;o00008?oo
ool2o`0001Oooooo0_l00004ooooo`;o0000:?ooool2o`0009Wooooo000Nooooo`03o`000?oooooo
oooo047ooooo1?l00005ooooo`;o00002oooool2o`000:;ooooo0_l0001:ooooo`007_ooool2o`00
04Cooooo0_l00005ooooo`;o00002oooool3o`0001oooooo0_l0000Aooooo`;o0000KOooool2o`00
04[ooooo000Nooooo`03o`000?oooooooooo04Oooooo0_l0000?ooooo`;o00007oooool2o`00017o
oooo0_l0000Pooooo`?o0000U_ooool001kooooo00?o0000ooooooooool0Aoooool4o`0006?ooooo
0ol0002Fooooo`007_ooool00ol0003oooooooooo`19ooooo`;o00004oooool2o`0004cooooo0_l0
000looooo`;o0000Foooool001kooooo00?o0000ooooooooool0;?ooool2o`0001Wooooo0_l0000<
ooooo`;o00001oooool2o`0000cooooo0_l0000nooooo`;o0000??ooool2o`0000Wooooo0_l0001@
ooooo`007_ooool00ol0003oooooooooo`0/ooooo`;o00002?ooool2o`0000oooooo0_l0000<oooo
o`;o00005Oooool2o`0008Oooooo0_l0001@ooooo`007_ooool00ol0003oooooooooo`0aooooo`;o
00000oooool2o`0001oooooo0ol0003]ooooo`007_ooool00ol0003oooooooooo`07ooooo`;o0000
:?ooool2o`0002Cooooo0ol0002]ooooo`;o0000?_ooool001kooooo00?o0000ooooooooool01ooo
ool2o`00023ooooo1?l0000<ooooo`;o0000c?ooool2o`0003kooooo000Nooooo`03o`000?oooooo
oooo01Oooooo0_l0000?ooooo`Oo00001oooool2o`000003ooooool0003o000001Sooooo0_l0000E
ooooo`;o0000F_ooool2o`0007oooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0000?oooo
o`Wo00001Oooool2o`0001Oooooo0_l00002ooooo`;o00004oooool4o`0005[ooooo0_l0001ooooo
o`007_ooool00ol0003oooooooooo`0Zooooo`?o00000_ooool2o`0000Oooooo0_l000000ooooooo
0000o`000009ooooo`;o00000oooool2o`0000;ooooo0_l0000Eooooo`Co0000@Oooool2o`0009[o
oooo000Nooooo`03o`000?oooooooooo02[ooooo0_l000000ooooooo0000o`000009ooooo`Ko0000
0_ooool2o`0000Cooooo0_l00003ooooo`;o00006Oooool4o`00047ooooo0_l0000Gooooo`;o0000
POooool001kooooo00?o0000ooooooooool0;Oooool3o`000003ooooool0003o000000Oooooo1?l0
0002ooooo`;o00003_ooool2o`0000;ooooo0_l00005ooooo`;o00002oooool2o`0000gooooo0_l0
0008ooooo`;o0000@Oooool2o`0002_ooooo0_l0001Dooooo`000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`0^ooooo`;o000000?oooooo`000?l000001?ooool2o`0000?ooooo0_l0000?ooooo`;o0000
00?oooooo`000?l000000_ooool2o`0000Gooooo0_l0000@ooooo`;o00002?ooool2o`0000Sooooo
0_l0000gooooo`;o0000=Oooool2o`0005Cooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo02ko
oooo0_l00007ooooo`;o00002_ooool2o`0000?ooooo0_l00003ooooo`Go00006_ooool3o`0000oo
oooo0_l0000jooooo`;o0000Roooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05
o`000?ooooooooooooooool000001_ooool3o`0002_ooooo0_l00002ooooo`;o00004_ooool2o`00
0003ooooool0003o000000?o00000oooool4o`0000oooooo0_l00009ooooo`?o00003oooool2o`00
07Sooooo0_l0001=ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRH
V?ooooooV9RHoc8b<P06ooooo`04o`000?ooooooooooooooo`;o0000:?ooool2o`0000;ooooo1?l0
000Cooooo`;o000000Coooooo`000?l0003o00000_ooool2o`00017ooooo0_l00008ooooo`;o0000
B?ooool2o`00047ooooo0_l0001=ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo
00Goc<c<o`000?l0003o0000olc<c006ooooo`04o`000?ooooooooooooooo`;o0000;_ooool2o`00
00?ooooo0_l0000Booooo`Go00000_ooool2o`0000Cooooo0_l0000Booooo`;o0000B?ooool2o`00
093ooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o
410@00Kooooo00?o0000ooooooooool0:?ooool2o`0000Oooooo0ol00002ooooo`;o00000oooool3
o`0000cooooo2Ol00004ooooo`?o00002Oooool2o`0001gooooo0_l0000Xooooo`;o00001Oooool2
o`0009;ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj
^[[o000000Kooooo00?o0000ooooooooool07?ooool2o`0000[ooooo0_l00008ooooo`Co00001?oo
ool4o`0000Wooooo3Ol00003ooooo`?o00002Oooool2o`0001gooooo0_l00005ooooo`;o00006Ooo
ool2o`0000Kooooo0_l00005ooooo`;o00001?ooool2o`0008cooooo0003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0
7?ooool2o`0001;ooooo0_l00002ooooo`Co00000_ooool3o`0000[ooooo1ol000000ooooooo0000
o`000003o`0000?ooooo0ol0000_ooooo`;o00006Oooool2o`0001?ooooo0_l0000fooooo`;o0000
E?ooool001kooooo00?o0000ooooooooool0<?ooool2o`0000Cooooo0_l0000Cooooo`?o000000?o
ooooo`000?l000000_ooool2o`0000?ooooo0_l0000_ooooo`;o00007Oooool2o`0004Oooooo0_l0
001Dooooo`007_ooool00ol0003oooooooooo`0gooooo`;o00001_ooool2o`0000Sooooo1?l00002
ooooo`;o00000_ooool2o`000003ooooool0003o000002?ooooo0_l0000<ooooo`;o00006_ooool2
o`000003ooooool0003o000000Kooooo0_l0000=ooooo`;o0000Q_ooool001kooooo00?o0000oooo
ooooool08?ooool2o`0001Gooooo0_l00006ooooo`;o00002?ooool2o`0000Cooooo0_l00002oooo
o`Go00003?ooool2o`0001Gooooo0_l0000Xooooo`;o00002Oooool2o`0000gooooo0_l0001Roooo
o`;o00002?ooool2o`0001Sooooo000Nooooo`03o`000?oooooooooo023ooooo0_l0000Aooooo`;o
00002Oooool2o`0000Wooooo0_l00003ooooo`;o00000oooool5o`0000cooooo0_l00006ooooo`;o
0000@_ooool2o`00077ooooo0_l00008ooooo`;o00001Oooool2o`00017ooooo000Nooooo`03o`00
0?oooooooooo01[ooooo0_l0000Gooooo`;o00001_ooool2o`000004ooooool0003o0000ooooo`;o
00001_ooool2o`0000?ooooo2Ol0000Eooooo`;o0000@_ooool2o`0000Kooooo0_l00003ooooo`Co
0000Loooool2o`0000Cooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`0Fooooo`;o0000
0_ooool3o`0001kooooo0_l00004ooooo`;o00002oooool9o`0000Kooooo0_l0001Iooooo`?o0000
0_ooool4o`0006cooooo0_l0000;ooooo`;o00002oooool001kooooo00?o0000ooooooooool05_oo
ool2o`0000?ooooo0_l0000Xooooo`;o00000_ooool4o`0000?ooooo1_l00007ooooo`;o0000DOoo
ool2o`0000Oooooo0_l0001booooo`;o00006?ooool001kooooo00?o0000ooooooooool06oooool2
o`0002Sooooo0ol000000ooooooo0000o`00000;o`0000Gooooo0_l0000=ooooo`;o0000A?ooool2
o`0006gooooo0_l0000Vooooo`007_ooool00ol0003oooooooooo`0Iooooo`Co0000:Oooool4o`00
0003ooooool0003o000000?o000000?oooooo`000?l000000ol00003ooooo`Ko00000_ooool3o`00
00Gooooo0ol0002cooooo`;o00009_ooool001gooooo0_l0000Kooooo`;o0000;Oooool2o`000003
ooooool0003o000000Cooooo1Ol00003ooooo`_o00000_ooool2o`000003ooooool0003o000000;o
oooo0_l0000:ooooo`;o0000_Oooool2o`0000gooooo000Mooooo`;o0000>Oooool2o`0000?ooooo
0_l000000ooooooo0000o`000008ooooo`;o00000_ooool2o`0000;ooooo1_l00003ooooo`;o0000
0oooool2o`0000Gooooo0_l00005ooooo`;o00002Oooool3o`000;gooooo0_l00005ooooo`;o0000
1_ooool001kooooo0_l0000Gooooo`;o00007oooool2o`0000?ooooo0_l000000ooooooo0000o`00
0006ooooo`Co00000_ooool2o`0000;ooooo1_l00003ooooo`;o00001?ooool2o`0000Wooooo0_l0
0008ooooo`;o000000?oooooo`000?l00000C?ooool2o`0007Oooooo0_l00006ooooo`007_ooool0
0ol0003oooooooooo`0Fooooo`;o00007oooool2o`000004ooooool0003o0000ooooo`;o00001_oo
ool4o`000003ooooool0003o000000Kooooo1?l0000:ooooo`;o00002Oooool2o`0000Sooooo0_l0
001?ooooo`;o0000Ooooool001kooooo00?o0000ooooooooool00_ooool2o`0003?ooooo0_l00000
0ooooooo0000o`000003o`0000Kooooo1ol00006ooooo`;o000000Goooooo`000?l0003o0000oooo
o`02o`0000Sooooo0_l00007ooooo`;o0000fOooool001kooooo00?o0000ooooooooool00_ooool2
o`0003Oooooo0_l0000;ooooo`?o000000?oooooo`000?l000001_ooool4o`000003ooooool0003o
000000;ooooo0_l00004ooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o
000003kooooo0_l0000iooooo`;o0000Foooool001kooooo00?o0000ooooooooool0;oooool2o`00
00;ooooo0_l00006ooooo`;o00002?ooool5o`0000;ooooo0_l00005ooooo`Wo000000?oooooo`00
0?l000000oooool2o`0000;ooooo0_l00007ooooo`;o0000?_ooool2o`0003Wooooo0_l0001Koooo
o`007_ooool00ol0003oooooooooo`0_ooooo`;o00000_ooool2o`0000Kooooo0_l00008ooooo`Go
000000Coooooo`000?l0003ooooo0_l00003ooooo`Wo000000?oooooo`000?l000000oooool2o`00
00;ooooo0_l00007ooooo`;o0000e_ooool001kooooo00?o0000ooooooooool0<_ooool2o`0001Co
oooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo1_l000000ooooooo0000o`00000;oooo
o`;o0000dOooool2o`0000cooooo000Nooooo`03o`000?oooooooooo02oooooo0_l000000ooooooo
0000o`000009ooooo`;o00003_ooool2o`0000?ooooo1?l00005ooooo`?o00002_ooool2o`00097o
oooo0_l0000Booooo`;o0000:?ooool2o`0000cooooo000Nooooo`03o`000?oooooooooo02oooooo
0_l00009ooooo`Go000000?oooooo`000?l000002oooool4o`000003ooooool0003o000000Oooooo
0ol00006ooooo`;o00000_ooool2o`00097ooooo0_l0000Booooo`;o0000=_ooool001kooooo00?o
0000ooooooooool0>_ooool8o`0000Kooooo0_l00003ooooo`Co000000?oooooo`000?l000001ooo
ool2o`000003ooooool0003o000000Cooooo0_l00009ooooo`;o0000S?ooool2o`0004Sooooo000N
ooooo`03o`000?oooooooooo03cooooo1_l00006ooooo`;o00002oooool3o`0000Kooooo0_l0000=
ooooo`Co0000??ooool2o`0004kooooo0_l00018ooooo`007_ooool00ol0003oooooooooo`0Aoooo
o`;o0000:?ooool2o`00013ooooo0_l000000ooooooo0000o`000003ooooo`Go00000_ooool4o`00
00gooooo0_l0000nooooo`;o0000V?ooool001kooooo00?o0000ooooooooool04Oooool2o`0002So
oooo0_l0000@ooooo`Go00001_ooool2o`0000;ooooo1ol0000oooooo`;o0000Xoooool001kooooo
00?o0000ooooooooool09Oooool2o`0001Wooooo0_l00003ooooo`;o00001oooool2o`0000Oooooo
0_l00007ooooo`Go00000oooool2o`0003Sooooo0_l0000Jooooo`;o0000POooool2o`0000Cooooo
000Nooooo`03o`000?oooooooooo02Gooooo0_l0000:ooooo`;o00003Oooool2o`0000?ooooo0_l0
0005ooooo`Co00001Oooool4o`000003ooooool0003o000000?ooooo0ol000000ooooooo0000o`00
0003ooooo`;o00001oooool2o`00047ooooo0ol00007ooooo`;o0000K?ooool2o`0001?ooooo0_l0
0004ooooo`007_ooool00ol0003oooooooooo`0aooooo`;o00003_ooool2o`0000Wooooo1Ol00004
ooooo`?o00000_ooool2o`000003ooooool0003o000000?o00003oooool4o`0000?ooooo0_l0000O
ooooo`;o00001_ooool2o`00017ooooo0ol0001eooooo`;o00006Oooool001kooooo0_l00010oooo
o`Co00001_ooool2o`0000?ooooo0ol0000<ooooo`;o00000oooool2o`000003ooooool0003o0000
00cooooo0_l00003ooooo`;o00007oooool2o`0000Kooooo0_l0000Yooooo`;o0000NOooool001ko
oooo0_l0000nooooo`So00000_ooool5o`000003ooooool0003o000000[ooooo0_l00002ooooo`;o
00000oooool2o`000003ooooool0003o000000;o0000Hoooool2o`0007Wooooo000Nooooo`;o0000
?_ooool8o`0000;ooooo0_l000000ooooooo0000o`000003o`0000Sooooo1?l00002ooooo`;o0000
2?ooool2o`000=kooooo000Nooooo`03o`000?oooooooooo03kooooo0ol00009ooooo`Co00000ooo
ool2o`000004ooooool0003o0000ooooo`?o00000_ooool2o`0000;ooooo0_l000000ooooooo0000
o`00000=ooooo`;o00008oooool2o`000:kooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0
0006ooooo`;o00002?ooool2o`0000cooooo0_l0000Eooooo`?o00002?ooool2o`0000Kooooo0_l0
00000ooooooo0000o`000004o`0000;ooooo0_l00002ooooo`Go00000oooool2o`000003ooooool0
003o000000Gooooo0_l0000Sooooo`;o0000X_ooool2o`0000[ooooo000Nooooo`03o`000?oooooo
oooo00Oooooo0_l00006ooooo`;o00002?ooool2o`0000cooooo0_l0000Gooooo`;o000000?ooooo
o`000?l000000_ooool4o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`Co00000_ooool3
o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l00000c_ooool2o`0000[ooooo000Noooo
o`03o`000?oooooooooo01Wooooo0_l0000Uooooo`;o000000Coooooo`000?l0003ooooo0ol00006
ooooo`;o000000?oooooo`000?l000000_ooool4o`0000;ooooo1Ol0000?ooooo`;o00001oooool2
o`0006?ooooo0_l0001Wooooo`007_ooool00ol0003oooooooooo`14ooooo`Co00000_ooool2o`00
01?ooooo0_l00006ooooo`;o00001oooool3o`0000Cooooo1?l0001Sooooo`;o0000Ioooool001ko
oooo00?o0000ooooooooool0A?ooool3o`0000?ooooo0_l00006ooooo`;o000000Coooooo`000?l0
003ooooo0_l0000=ooooo`;o00002?ooool2o`0000Cooooo0_l0003>ooooo`007_ooool00ol0003o
ooooooooo`15ooooo`;o00002oooool2o`000004ooooool0003o0000ooooo`;o00004oooool4o`00
03_ooooo0_l0002Iooooo`007_ooool00ol0003oooooooooo`15ooooo`Go000000?oooooo`000?l0
00003_ooool2o`0000oooooo1Ol0000=ooooo`;o0000;?ooool2o`0007cooooo0_l0000Kooooo`00
7_ooool00ol0003oooooooooo`17ooooo`?o000000?oooooo`000?l000000_ooool2o`0000[ooooo
0ol0000<ooooo`Oo000000?oooooo`000?l000000oooool2o`0000Gooooo0_l00005ooooo`;o0000
Xoooool2o`0001_ooooo000Nooooo`03o`000?oooooooooo01Gooooo0_l0000hooooo`;o00002ooo
ool2o`0000cooooo0_l00006ooooo`;o00000oooool2o`0000cooooo0_l00030ooooo`007_ooool0
0ol0003oooooooooo`0Eooooo`;o0000<_ooool2o`0000?ooooo0_l00005ooooo`;o00007?ooool2
o`000003ooooool0003o000003?ooooo0_l0002Jooooo`007_ooool00ol0003oooooooooo`19oooo
o`;o00000oooool4o`0000?ooooo0_l0000Cooooo`;o00001_ooool6o`0000Cooooo0_l00004oooo
o`;o00009oooool2o`0009[ooooo000Nooooo`03o`000?oooooooooo02[ooooo0_l00005ooooo`;o
00001?ooool2o`0001Gooooo1?l000000ooooooo0000o`000002ooooo`;o00000oooool2o`000003
ooooool0003o000000Gooooo1_l00006ooooo`Ko00001?ooool4o`0000;ooooo0_l00016ooooo`;o
0000Noooool001kooooo0_l0000[ooooo`;o00001Oooool2o`0000Cooooo0_l0000Eooooo`;o0000
0oooool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000001?ooool7o`0000Gooooo
0_l000000ooooooo0000o`000008ooooo`Co0000AOooool2o`000003ooooool0003o000000Kooooo
0_l0001Oooooo`;o00004_ooool001kooooo00?o0000ooooooooool0G?ooool2o`0000Gooooo1?l0
00000ooooooo0000o`000002o`000003ooooool0003o000000;ooooo0_l00006ooooo`;o00001?oo
ool3o`0004Gooooo0_l00009ooooo`;o0000Goooool2o`0001;ooooo000Nooooo`03o`000?oooooo
oooo05cooooo0_l00005ooooo`Ko00001?ooool2o`0000[ooooo0_l00021ooooo`;o0000BOooool0
01kooooo00Co0000oooooooooooooooo0_l00004ooooo`;o0000@_ooool2o`0000?ooooo0_l0000B
ooooo`Go00001?ooool3o`0008cooooo0_l00019ooooo`007_ooool01?l0003oooooooooooooool2
o`0000Cooooo0_l0000eooooo`;o00002oooool2o`0000?ooooo0_l0000?ooooo`;o000000?ooooo
o`000?l000001Ol00002ooooo`Co0000e_ooool001kooooo00?o0000ooooooooool04oooool2o`00
02Wooooo0_l0000Qooooo`;o00000oooool5o`0000Cooooo1?l000000ooooooo0000o`00000boooo
o`;o0000WOooool001kooooo00?o0000ooooooooool04oooool2o`0000?ooooo0_l0000<ooooo`;o
00008oooool2o`0001;ooooo1_l000000ooooooo0000o`000003o`0000Kooooo0_l000001?oooooo
0000o`000?l0000aooooo`;o00006?ooool2o`0008?ooooo000Nooooo`03o`000?oooooooooo01So
oooo0_l0000<ooooo`;o00008oooool2o`0001;ooooo1_l00003ooooo`?o00002Oooool3o`0004_o
oooo0_l00023ooooo`007_ooool00ol0003oooooooooo`1Gooooo`;o00002Oooool2o`0000kooooo
1?l00015ooooo`;o0000@_ooool2o`0001kooooo0_l0000Vooooo`007_ooool00ol0003ooooooooo
o`0Kooooo`;o0000:_ooool2o`0000kooooo0_l000001?oooooo0000o`000?l00005ooooo`;o0000
0_ooool2o`0000[ooooo0_l00017ooooo`;o0000@_ooool2o`00013ooooo0_l0000<ooooo`;o0000
9_ooool001kooooo00?o0000ooooooooool06oooool2o`0002;ooooo0_l00002ooooo`;o00000_oo
ool2o`0000Wooooo0_l00006ooooo`?o000000Coooooo`000?l0003ooooo0ol00002ooooo`;o0000
1Oooool2o`0000;ooooo0_l0001Vooooo`;o0000=_ooool2o`0003Cooooo000Nooooo`03o`000?oo
oooooooo02Oooooo0_l0000Fooooo`?o000000?oooooo`000?l000003Oooool2o`0000[ooooo1_l0
0002ooooo`;o00001Oooool2o`0000;ooooo0_l00004ooooo`;o00004Oooool2o`0002Kooooo0_l0
000Uooooo`;o0000K?ooool001kooooo00?o0000ooooooooool06?ooool2o`0000gooooo0_l0000G
ooooo`;o00001oooool2o`0001Cooooo0_l000000ooooooo0000o`000002ooooo`;o000000?ooooo
o`000?l000003?ooool2o`00017ooooo0_l0000Vooooo`;o00000_ooool2o`0007[ooooo0_l0000C
ooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o0000;oooool2o`0000Wooooo0ol0000;oooo
o`;o00000_ooool2o`000003ooooool0003o000004_ooooo0_l0001jooooo`;o00004oooool001Co
oooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo01Sooooo0_l0000jooooo`?o
00000oooool2o`0000;ooooo1_l00007ooooo`;o000000?oooooo`000?l000001?ooool2o`0001Oo
oooo0_l0002hooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo053ooooo
0ol000000ooooooo0000o`000004ooooo`;o00000_ooool4o`0000?ooooo0_l00004ooooo`;o0000
00?oooooo`000?l000001?ooool2o`0001Oooooo0_l0001Zooooo`;o0000C?ooool001Kooooo00?o
0000ooooooooool01Oooool3o`00023ooooo0_l0000^ooooo`?o00002?ooool2o`0000?ooooo0ol0
0002ooooo`;o0000NOooool2o`0001Oooooo0_l0001<ooooo`005_ooool00ol0003oooooooooo`0X
ooooo`;o0000>Oooool2o`0000?ooooo0ol0001mooooo`;o0000IOooool001Kooooo00?o0000oooo
ooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`00
0?oooooooooo0?ooooooD?ooool001Cooooo00?oEEEEofIVI_l00000oooooomBooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.39517 .95922 Mdot
.94341 .87474 Mdot
.35618 .87534 Mdot
.30823 .85533 Mdot
.21904 .79691 Mdot
.26623 .90647 Mdot
.78405 .81573 Mdot
.24087 .80758 Mdot
.22108 .88421 Mdot
.33473 .1069 Mdot
.28803 .6995 Mdot
.37095 .70189 Mdot
.29738 .87282 Mdot
.93261 .84513 Mdot
.30625 .90769 Mdot
.15495 .54643 Mdot
.17839 .23942 Mdot
.30839 .91177 Mdot
.40881 .97227 Mdot
.27528 .88326 Mdot
.90637 .06465 Mdot
.21076 .95791 Mdot
.25959 .93279 Mdot
.18177 .01679 Mdot
.2244 .83794 Mdot
.21229 .78566 Mdot
.26776 .8679 Mdot
.16752 .5975 Mdot
.3043 .68274 Mdot
.263 .97645 Mdot
.37944 .94053 Mdot
.29233 .90636 Mdot
.17258 .86316 Mdot
.29922 .16216 Mdot
.46399 .94864 Mdot
.25106 .74855 Mdot
.97425 .86439 Mdot
.258 .12332 Mdot
.39612 .74732 Mdot
.26014 .82082 Mdot
.39505 .95279 Mdot
.28606 .87683 Mdot
.05641 .80582 Mdot
.13018 .16034 Mdot
.92557 .99875 Mdot
.31117 .85315 Mdot
.60588 .97899 Mdot
.20303 .89733 Mdot
.25372 .747 Mdot
.30374 .69168 Mdot
.31182 .71595 Mdot
.19886 .00559 Mdot
.21558 .77505 Mdot
.21528 .69456 Mdot
.22254 .79497 Mdot
.37418 .52655 Mdot
.69091 .80827 Mdot
.27187 .83449 Mdot
.27052 .87281 Mdot
.31514 .05293 Mdot
.33952 .87776 Mdot
.21999 .80806 Mdot
.27011 .01353 Mdot
.19728 .83748 Mdot
.29083 .84348 Mdot
.2159 .93135 Mdot
.13533 .99078 Mdot
.26845 .86815 Mdot
.27821 .92434 Mdot
.89602 .79806 Mdot
.19689 .37286 Mdot
.24668 .7877 Mdot
.49246 .89482 Mdot
.2463 .19217 Mdot
.22301 .82017 Mdot
.66713 .75392 Mdot
.24733 .01963 Mdot
.24124 .4051 Mdot
.27697 .89159 Mdot
.18178 .87591 Mdot
.33476 .98091 Mdot
.75638 .29405 Mdot
.06432 .10012 Mdot
.23298 .81605 Mdot
.78297 .25082 Mdot
.79218 .40454 Mdot
.21664 .77206 Mdot
.29943 .84355 Mdot
.29313 .91555 Mdot
.24307 .92505 Mdot
.14647 .83714 Mdot
.67423 .49292 Mdot
.2449 .75546 Mdot
.31543 .24749 Mdot
.35173 .04234 Mdot
.28632 .00893 Mdot
.46779 .82636 Mdot
.30565 .9991 Mdot
.1407 .76763 Mdot
.58707 .80497 Mdot
.28048 .84443 Mdot
.31676 .74641 Mdot
.37872 .97177 Mdot
.00893 .70423 Mdot
.97788 .92861 Mdot
.24663 .93187 Mdot
.18995 .51796 Mdot
.15326 .53789 Mdot
.15124 .98544 Mdot
.57001 .73459 Mdot
.95204 .82464 Mdot
.99898 .05152 Mdot
.26412 .99221 Mdot
.33417 .9115 Mdot
.78786 .94621 Mdot
.76131 .92534 Mdot
.93915 .0235 Mdot
.29888 .88824 Mdot
.10075 .28764 Mdot
.14492 .03698 Mdot
.27008 .84746 Mdot
.14914 .90157 Mdot
.19195 .92391 Mdot
.31256 .29413 Mdot
.08771 .56845 Mdot
.45881 .70182 Mdot
.1428 .73219 Mdot
.39338 .98168 Mdot
.24629 .14336 Mdot
.57862 .84319 Mdot
.44246 .68326 Mdot
.13711 .46091 Mdot
.9018 .35678 Mdot
.27569 .99381 Mdot
.34707 .00103 Mdot
.29696 .86259 Mdot
.23114 .91832 Mdot
.17822 .62314 Mdot
.40282 .91711 Mdot
.23242 .91451 Mdot
.38685 .98574 Mdot
.18063 .82435 Mdot
.18941 .93648 Mdot
.6017 .87282 Mdot
.17061 .60123 Mdot
.34095 .7214 Mdot
.33924 .02033 Mdot
.27891 .84011 Mdot
.63351 .71642 Mdot
.82272 .23394 Mdot
.20164 .86653 Mdot
.17873 .90663 Mdot
.39204 .72007 Mdot
.26749 .88324 Mdot
.30177 .89862 Mdot
.26782 .86523 Mdot
.20917 .60662 Mdot
.66284 .02152 Mdot
.2421 .87402 Mdot
.21031 .53682 Mdot
.2024 .63111 Mdot
.53852 .8446 Mdot
.88742 .16852 Mdot
.26357 .01403 Mdot
.15497 .76729 Mdot
.20238 .80367 Mdot
.28539 .82851 Mdot
.25993 .86925 Mdot
.7443 .97694 Mdot
.23551 .92993 Mdot
.20186 .94911 Mdot
.50795 .02175 Mdot
.4984 .87894 Mdot
.85247 .48925 Mdot
.39789 .96744 Mdot
.32665 .67108 Mdot
.41469 .06905 Mdot
.25084 .77633 Mdot
.75378 .66198 Mdot
.21109 .01097 Mdot
.08212 .77558 Mdot
.26583 .69743 Mdot
.43474 .89482 Mdot
.9451 .06512 Mdot
.18575 .54619 Mdot
.34962 .85181 Mdot
.22098 .5499 Mdot
.11404 .83723 Mdot
.55086 .10419 Mdot
.58763 .81555 Mdot
.39575 .97469 Mdot
.85953 .15009 Mdot
.39043 .97693 Mdot
.03077 .02999 Mdot
.18551 .06723 Mdot
.04935 .82328 Mdot
.55369 .88036 Mdot
.2785 .82735 Mdot
.2144 .88235 Mdot
.18691 .87073 Mdot
.06948 .11404 Mdot
.27144 .99235 Mdot
.30105 .00482 Mdot
.94817 .02292 Mdot
.22023 .838 Mdot
.30122 .84274 Mdot
.86673 .64048 Mdot
.29495 .86662 Mdot
.46826 .08602 Mdot
.24121 .66724 Mdot
.21798 .89019 Mdot
.37957 .98192 Mdot
.04191 .19852 Mdot
.08309 .14682 Mdot
.1876 .63656 Mdot
.27485 .73823 Mdot
.27867 .81886 Mdot
.37016 .75044 Mdot
.30756 .59982 Mdot
.17548 .97858 Mdot
.89501 .96114 Mdot
.34765 .05249 Mdot
.16262 .80655 Mdot
.261 .88363 Mdot
.30464 .0011 Mdot
.26029 .71402 Mdot
.56232 .79885 Mdot
.26979 .89727 Mdot
.32151 .01218 Mdot
.1942 .938 Mdot
.23639 .83272 Mdot
.29224 .04258 Mdot
.18381 .93197 Mdot
.61218 .93178 Mdot
.30683 .85359 Mdot
.37485 .24713 Mdot
.51539 .43125 Mdot
.35374 .91586 Mdot
.00168 .92475 Mdot
.87149 .4112 Mdot
.31204 .77574 Mdot
.19025 .94225 Mdot
.14194 .82143 Mdot
.29577 .86343 Mdot
.43802 .78621 Mdot
.16947 .07393 Mdot
.32419 .03832 Mdot
.21004 .96003 Mdot
.43805 .56292 Mdot
.39336 .94167 Mdot
.18507 .01198 Mdot
.20405 .82429 Mdot
.12641 .70015 Mdot
.76645 .51291 Mdot
.08585 .58181 Mdot
.16894 .80101 Mdot
.20263 .77959 Mdot
.0753 .77363 Mdot
.28213 .94416 Mdot
.89654 .06243 Mdot
.38121 .97382 Mdot
.29603 .95585 Mdot
.35999 .46619 Mdot
.43381 .17657 Mdot
.18634 .93537 Mdot
.8292 .30398 Mdot
.3242 .915 Mdot
.00019 .54236 Mdot
.33594 .90719 Mdot
.26016 .84384 Mdot
.14461 .76784 Mdot
.68498 .63267 Mdot
.33838 .91863 Mdot
.26991 .97525 Mdot
.39289 .97982 Mdot
.21188 .86492 Mdot
.28927 .59405 Mdot
.27777 .29441 Mdot
.2318 .71435 Mdot
.3364 .75296 Mdot
.7016 .82835 Mdot
.20896 .95994 Mdot
.26959 .00936 Mdot
.99425 .9505 Mdot
.20427 .78981 Mdot
.16679 .80904 Mdot
.25219 .94029 Mdot
.54106 .69419 Mdot
.13475 .80274 Mdot
.30391 .68422 Mdot
.13635 .77322 Mdot
.58819 .28887 Mdot
.40847 .97339 Mdot
.14929 .93302 Mdot
.71509 .43007 Mdot
.54049 .73648 Mdot
.30913 .85071 Mdot
.23276 .54525 Mdot
.70869 .7677 Mdot
.68318 .06892 Mdot
.52695 .66977 Mdot
.11128 .779 Mdot
.53248 .91854 Mdot
.30783 .03356 Mdot
.53534 .75863 Mdot
.10748 .98337 Mdot
.26759 .87036 Mdot
.29139 .89147 Mdot
.95523 .0995 Mdot
.18962 .05706 Mdot
.28153 .85845 Mdot
.69757 .71627 Mdot
.21219 .7932 Mdot
.42751 .98035 Mdot
.21904 .78485 Mdot
.19063 .70243 Mdot
.34643 .79039 Mdot
.79292 .55001 Mdot
.14907 .80246 Mdot
.32669 .1886 Mdot
.39741 .74394 Mdot
.17897 .87742 Mdot
.32684 .73802 Mdot
.38296 .85815 Mdot
.3548 .93739 Mdot
.24529 .84128 Mdot
.23596 .71864 Mdot
.3722 .98168 Mdot
.33818 .67361 Mdot
.22335 .82576 Mdot
.21797 .87571 Mdot
.25739 .9238 Mdot
.40574 .43207 Mdot
.94487 .67159 Mdot
.21377 .66615 Mdot
.24105 .91833 Mdot
.33914 .89342 Mdot
.26302 .85515 Mdot
.12084 .49646 Mdot
.77856 .40282 Mdot
.1565 .77274 Mdot
.99427 .14038 Mdot
.37149 .99083 Mdot
.29961 .9671 Mdot
.74803 .99474 Mdot
.5422 .61291 Mdot
.82144 .14382 Mdot
.18021 .60409 Mdot
.13249 .60963 Mdot
.24517 .80081 Mdot
.32271 .89869 Mdot
.19968 .79394 Mdot
.56312 .87007 Mdot
.08164 .60837 Mdot
.92498 .62857 Mdot
.34186 .89992 Mdot
.3453 .86521 Mdot
.27975 .04237 Mdot
.29154 .8569 Mdot
.326 .12991 Mdot
.20573 .95767 Mdot
.52129 .79922 Mdot
.39162 .95045 Mdot
.22031 .89855 Mdot
.13446 .79633 Mdot
.41214 .93732 Mdot
.05638 .93301 Mdot
.57043 .14391 Mdot
.02192 .34584 Mdot
.2624 .9691 Mdot
.17535 .63574 Mdot
.26783 .87037 Mdot
.37088 .90481 Mdot
.20994 .92429 Mdot
.63048 .94218 Mdot
.57376 .76989 Mdot
.94265 .98915 Mdot
.26611 .77634 Mdot
.86597 .64409 Mdot
.24254 .96387 Mdot
.27592 .89314 Mdot
.23976 .85812 Mdot
.02741 .43816 Mdot
.10496 .58313 Mdot
.23717 .60343 Mdot
.98729 .01398 Mdot
.06033 .84248 Mdot
.45103 .16306 Mdot
.26391 .8579 Mdot
.99379 .85025 Mdot
.38719 .98732 Mdot
.26438 .84183 Mdot
.31111 .84068 Mdot
.25614 .79446 Mdot
.23544 .79085 Mdot
.50552 .38208 Mdot
.16336 .21389 Mdot
.79394 .28444 Mdot
.27285 .87336 Mdot
.37662 .95101 Mdot
.05044 .83231 Mdot
.95866 .9252 Mdot
.74126 .9828 Mdot
.2231 .81239 Mdot
.06598 .99557 Mdot
.55121 .82362 Mdot
.27466 .67329 Mdot
.22136 .83541 Mdot
.31782 .97044 Mdot
.25952 .00758 Mdot
.17667 .64677 Mdot
.24512 .85853 Mdot
.19197 .63645 Mdot
.9813 .87388 Mdot
.87157 .51247 Mdot
.27878 .95003 Mdot
.33412 .00969 Mdot
.24784 .68146 Mdot
.54217 .57295 Mdot
.28042 .89236 Mdot
.26207 .84646 Mdot
.23975 .55447 Mdot
.43301 .32456 Mdot
.26461 .87187 Mdot
.26076 .83014 Mdot
.94223 .00046 Mdot
.05937 .15209 Mdot
.20998 .91067 Mdot
.24378 .76306 Mdot
.39961 .98364 Mdot
.78492 .46514 Mdot
.73599 .93795 Mdot
.9393 .92415 Mdot
.22115 .87089 Mdot
.00215 .7354 Mdot
.43469 .56526 Mdot
.27174 .60888 Mdot
.57182 .75377 Mdot
.2511 .99946 Mdot
.92679 .01037 Mdot
.31783 .93059 Mdot
.09275 .16326 Mdot
.0612 .12821 Mdot
.34229 .89275 Mdot
.3 .19944 Mdot
.32221 .87713 Mdot
.17898 .84443 Mdot
.22437 .84055 Mdot
.62352 .42623 Mdot
.33427 .02576 Mdot
.39533 .66621 Mdot
.12423 .96631 Mdot
.16547 .78215 Mdot
.27037 .88852 Mdot
.39774 .74346 Mdot
.27985 .86482 Mdot
.22832 .85676 Mdot
.22869 .71662 Mdot
.34294 .09972 Mdot
.5671 .60094 Mdot
.32983 .81137 Mdot
.30335 .85605 Mdot
.27258 .89055 Mdot
.29658 .8139 Mdot
.14431 .96903 Mdot
.30327 .0043 Mdot
.17695 .86565 Mdot
.33539 .67191 Mdot
.33531 .90578 Mdot
.49972 .97363 Mdot
.2569 .97168 Mdot
.21775 .77864 Mdot
.23423 .81006 Mdot
.23392 .81314 Mdot
.34956 .83179 Mdot
.28542 .89934 Mdot
.28987 .77246 Mdot
.25 .83074 Mdot
.79442 .91898 Mdot
.11774 .77992 Mdot
.2881 .39079 Mdot
.0621 .03024 Mdot
.19661 .94901 Mdot
.37977 .99345 Mdot
.39161 .96842 Mdot
.01531 .68644 Mdot
.36291 .9888 Mdot
.41111 .36268 Mdot
.55519 .97961 Mdot
.11474 .62598 Mdot
.36725 .92061 Mdot
.25512 .86365 Mdot
.50107 .34049 Mdot
.03674 .82889 Mdot
.20963 .84417 Mdot
.27398 .84472 Mdot
.10163 .95671 Mdot
.18838 .80311 Mdot
.20061 .96505 Mdot
.35047 .78638 Mdot
.12821 .00131 Mdot
.56241 .76522 Mdot
.50527 .04325 Mdot
.23585 .17645 Mdot
.28081 .91587 Mdot
.34636 .81709 Mdot
.21591 .78692 Mdot
.64514 .59851 Mdot
.23541 .85496 Mdot
.2904 .9644 Mdot
.36369 .99868 Mdot
.40975 .36714 Mdot
.31227 .45312 Mdot
.10925 .62014 Mdot
.21878 .78244 Mdot
.63875 .92451 Mdot
.18462 .68361 Mdot
.29059 .0194 Mdot
.8334 .43507 Mdot
.37197 .95926 Mdot
.29862 .04699 Mdot
.3328 .82465 Mdot
.27595 .89222 Mdot
.1941 .8905 Mdot
.58082 .85371 Mdot
.47718 .94826 Mdot
.46935 .18698 Mdot
.11176 .85042 Mdot
.42293 .93116 Mdot
.37355 .07116 Mdot
.81403 .9783 Mdot
.0846 .56087 Mdot
.20851 .78898 Mdot
.34182 .72667 Mdot
.23444 .82355 Mdot
.27502 .84955 Mdot
.272 .8374 Mdot
.16222 .84279 Mdot
.39357 .18552 Mdot
.38009 .93471 Mdot
.23303 .91521 Mdot
.80314 .58774 Mdot
.32408 .71957 Mdot
.29001 .898 Mdot
.39186 .91803 Mdot
.48492 .86579 Mdot
.60857 .42785 Mdot
.42867 .96013 Mdot
.26043 .98373 Mdot
.24404 .84419 Mdot
.86617 .73936 Mdot
.03739 .10998 Mdot
.16953 .85962 Mdot
.25759 .13199 Mdot
.21338 .88852 Mdot
.03317 .65469 Mdot
.41762 .38377 Mdot
.26217 .85015 Mdot
.23545 .7748 Mdot
.28153 .84197 Mdot
.24831 .9766 Mdot
.16189 .7626 Mdot
.35801 .15804 Mdot
.50485 .8159 Mdot
.26031 .93606 Mdot
.2475 .7295 Mdot
.20965 .62494 Mdot
.15797 .79396 Mdot
.73868 .31727 Mdot
.28854 .91382 Mdot
.53629 .76456 Mdot
.02704 .67263 Mdot
.28364 .89958 Mdot
.35875 .99519 Mdot
.27447 .84261 Mdot
.19394 .9107 Mdot
.56053 .76062 Mdot
.30279 .67994 Mdot
.20747 .83204 Mdot
.09705 .02781 Mdot
.88861 .79158 Mdot
.72801 .59048 Mdot
.33173 .79711 Mdot
.39093 .98306 Mdot
.41408 .22185 Mdot
.2885 .80833 Mdot
.34516 .87889 Mdot
.82851 .02542 Mdot
.98844 .84727 Mdot
.32441 .05055 Mdot
.25581 .83302 Mdot
.25082 .78647 Mdot
.301 .96444 Mdot
.18613 .8386 Mdot
.35948 .75517 Mdot
.21153 .80392 Mdot
.29836 .61924 Mdot
.23699 .84226 Mdot
.2726 .77725 Mdot
.28885 .06677 Mdot
.18569 .91724 Mdot
.26513 .86273 Mdot
.35612 .908 Mdot
.31703 .99682 Mdot
.11462 .99779 Mdot
.26332 .02018 Mdot
.26898 .83943 Mdot
.22213 .96773 Mdot
.02664 .01838 Mdot
.38901 .97001 Mdot
.01963 .0586 Mdot
.69068 .49203 Mdot
.29508 .95487 Mdot
.28532 .81939 Mdot
.41153 .95775 Mdot
.24172 .53988 Mdot
.22985 .74022 Mdot
.97762 .65392 Mdot
.11997 .77073 Mdot
.68103 .69017 Mdot
.39926 .22783 Mdot
.58174 .72783 Mdot
.39137 .975 Mdot
.78214 .67041 Mdot
.28408 .9667 Mdot
.30545 .91349 Mdot
.74731 .30748 Mdot
.79996 .37277 Mdot
.23097 .84514 Mdot
.21704 .84843 Mdot
.37868 .87589 Mdot
.25779 .88015 Mdot
.31801 .05395 Mdot
.94342 .86628 Mdot
.28242 .89902 Mdot
.42014 .46635 Mdot
.23611 .81665 Mdot
.2049 .06824 Mdot
.24819 .8202 Mdot
.30779 .91579 Mdot
.06813 .80891 Mdot
.27826 .90864 Mdot
.26286 .90683 Mdot
.19338 .80667 Mdot
.28205 .07512 Mdot
.34113 .04327 Mdot
.21304 .70832 Mdot
.72673 .90576 Mdot
.22744 .82922 Mdot
.02823 .02572 Mdot
.10279 .02691 Mdot
.22085 .74189 Mdot
.43821 .04473 Mdot
.26219 .88656 Mdot
.60273 .41527 Mdot
.25529 .82566 Mdot
.24527 .76709 Mdot
.81388 .75689 Mdot
.52075 .14722 Mdot
.27613 .86992 Mdot
.94248 .99362 Mdot
.24434 .96286 Mdot
.68872 .47848 Mdot
.26728 .82024 Mdot
.84897 .25809 Mdot
.41829 .93528 Mdot
.28538 .89237 Mdot
.85599 .67199 Mdot
.58181 .80958 Mdot
.44207 .88727 Mdot
.53826 .15117 Mdot
.76207 .26978 Mdot
.01059 .07169 Mdot
.24357 .94832 Mdot
.96302 .29356 Mdot
.21246 .79953 Mdot
.82886 .9477 Mdot
.26619 .85634 Mdot
.77669 .12533 Mdot
.58225 .08167 Mdot
.16599 .13289 Mdot
.61162 .85785 Mdot
.95832 .50249 Mdot
.39586 .98141 Mdot
.28778 .91204 Mdot
.49647 .78801 Mdot
.22465 .74353 Mdot
.78547 .02476 Mdot
.22989 .89945 Mdot
.31848 .88683 Mdot
.17055 .89717 Mdot
.91033 .99485 Mdot
.33975 .49912 Mdot
.48159 .69076 Mdot
.1791 .90138 Mdot
.25052 .98368 Mdot
.26965 .88892 Mdot
.15545 .62719 Mdot
.6102 .67413 Mdot
.97208 .72827 Mdot
.33946 .72679 Mdot
.06131 .61328 Mdot
.27487 .87265 Mdot
.40618 .92418 Mdot
.20209 .7621 Mdot
.18137 .91019 Mdot
.31138 .63716 Mdot
.96955 .8903 Mdot
.14487 .14189 Mdot
.19712 .88217 Mdot
.50986 .52335 Mdot
.21455 .77969 Mdot
.93937 .87048 Mdot
.83293 .82252 Mdot
.24712 .89066 Mdot
.67413 .73391 Mdot
.20462 .95643 Mdot
.25049 .78564 Mdot
.6504 .87185 Mdot
.19814 .94947 Mdot
.37236 .98373 Mdot
.64692 .08158 Mdot
.29552 .04021 Mdot
.88934 .74395 Mdot
.12142 .7096 Mdot
.92435 .75597 Mdot
.95551 .65667 Mdot
.26516 .83827 Mdot
.26397 .80857 Mdot
.73061 .914 Mdot
.22774 .9278 Mdot
.2201 .95307 Mdot
.28109 .86929 Mdot
.23322 .89753 Mdot
.64445 .93897 Mdot
.64096 .88374 Mdot
.59753 .38944 Mdot
.43098 .34215 Mdot
.26768 .68885 Mdot
.61778 .41344 Mdot
.17783 .88213 Mdot
.28728 .869 Mdot
.40947 .96714 Mdot
.81457 .79169 Mdot
.6538 .92014 Mdot
.16313 .72585 Mdot
.24863 .96012 Mdot
.68731 .83856 Mdot
.15081 .75805 Mdot
.8838 .73022 Mdot
.11543 .8393 Mdot
.36849 .90821 Mdot
.2726 .8637 Mdot
.38198 .9539 Mdot
.32167 .036 Mdot
.13975 .78723 Mdot
.23956 .89444 Mdot
.36092 .95843 Mdot
.2782 .76886 Mdot
.37072 .9264 Mdot
.03682 .85375 Mdot
.23885 .80322 Mdot
.23264 .81164 Mdot
.35889 .90486 Mdot
.27656 .67985 Mdot
.33417 .88485 Mdot
.60102 .85357 Mdot
.6954 .6138 Mdot
.27701 .82612 Mdot
.20559 .70018 Mdot
.20815 .8094 Mdot
.36608 .81463 Mdot
.25511 .95919 Mdot
.20393 .82444 Mdot
.84934 .49523 Mdot
.3865 .97921 Mdot
.10764 .79066 Mdot
.36438 .91968 Mdot
.39528 .7371 Mdot
.18217 .40742 Mdot
.30218 .85742 Mdot
.28983 .98105 Mdot
.75279 .49048 Mdot
.59638 .82612 Mdot
.29447 .81415 Mdot
.2193 .58313 Mdot
.1235 .58823 Mdot
.23479 .91121 Mdot
.2556 .86644 Mdot
.2645 .85525 Mdot
.36106 .57866 Mdot
.01305 .3541 Mdot
.09675 .91487 Mdot
.22686 .76975 Mdot
.50889 .71981 Mdot
.24049 .77052 Mdot
.08441 .6336 Mdot
.18966 .5477 Mdot
.25029 .82035 Mdot
.30844 .98975 Mdot
.07952 .71736 Mdot
.23748 .97351 Mdot
.33024 .79097 Mdot
.16827 .08029 Mdot
.25731 .97487 Mdot
.30106 .94911 Mdot
.39723 .06266 Mdot
.31311 .02472 Mdot
.56605 .80706 Mdot
.32173 .05954 Mdot
.57643 .76038 Mdot
.25896 .7952 Mdot
.3267 .82652 Mdot
.2228 .0391 Mdot
.11031 .84287 Mdot
.2681 .87514 Mdot
.22844 .36412 Mdot
.63259 .74377 Mdot
.31615 .90066 Mdot
.81858 .68774 Mdot
.23613 .81815 Mdot
.23964 .83928 Mdot
.10816 .77495 Mdot
.26905 .8627 Mdot
.23226 .77918 Mdot
.17822 .59989 Mdot
.21028 .77295 Mdot
.13762 .77104 Mdot
.86357 .53795 Mdot
.29519 .06148 Mdot
.9557 .03801 Mdot
.52247 .67807 Mdot
.28971 .85576 Mdot
.78489 .75546 Mdot
.16202 .92919 Mdot
.24686 .98095 Mdot
.39781 .38841 Mdot
.25436 .74952 Mdot
.13108 .8008 Mdot
.11019 .40151 Mdot
.15728 .0775 Mdot
.23831 .84394 Mdot
.26893 .87266 Mdot
.22501 .90051 Mdot
.65862 .77559 Mdot
.47089 .94601 Mdot
.45821 .70262 Mdot
.32501 .89195 Mdot
.21169 .80216 Mdot
.37151 .91251 Mdot
.33236 .1227 Mdot
.22995 .89926 Mdot
.39909 .95719 Mdot
.30373 .09678 Mdot
.27747 .82539 Mdot
.90529 .53715 Mdot
.23793 .81017 Mdot
.27214 .40088 Mdot
.11701 .79178 Mdot
.32995 .87477 Mdot
.23244 .83364 Mdot
.32806 .86264 Mdot
.19409 .88931 Mdot
.40092 .63056 Mdot
.21377 .79248 Mdot
.25704 .72596 Mdot
.40826 .97282 Mdot
.27828 .58505 Mdot
.05136 .65898 Mdot
.25679 .8446 Mdot
.9286 .7406 Mdot
.28472 .8394 Mdot
.20391 .82718 Mdot
.28466 .77976 Mdot
.35218 .94861 Mdot
.22672 .7732 Mdot
.19073 .65441 Mdot
.31414 .4591 Mdot
.99597 .91763 Mdot
.35175 .03061 Mdot
.67233 .90688 Mdot
.33623 .93296 Mdot
.23497 .80523 Mdot
.29939 .76544 Mdot
.09419 .98758 Mdot
.39469 .96266 Mdot
.38629 .95078 Mdot
.71586 .5935 Mdot
.20905 .95798 Mdot
.61742 .8694 Mdot
.24515 .33959 Mdot
.29882 .46326 Mdot
.07507 .96841 Mdot
.20483 .9569 Mdot
.88225 .03507 Mdot
.30634 .83116 Mdot
.22696 .82134 Mdot
.32705 .91804 Mdot
.36952 .84962 Mdot
.10772 .79647 Mdot
.35495 .0225 Mdot
.34087 .83191 Mdot
.48569 .60096 Mdot
.23221 .99917 Mdot
.95313 .71446 Mdot
.49201 .672 Mdot
.57258 .855 Mdot
.25857 .0352 Mdot
.40781 .9706 Mdot
.36294 .99939 Mdot
.27963 .7483 Mdot
.54267 .85001 Mdot
.18202 .70583 Mdot
.17532 .86404 Mdot
.24721 .80066 Mdot
.1718 .67436 Mdot
.50218 .80656 Mdot
.31343 .82204 Mdot
.34993 .05136 Mdot
.21891 .90321 Mdot
.40684 .28566 Mdot
.41849 .51776 Mdot
.36143 .04409 Mdot
.22683 .82873 Mdot
.30069 .91139 Mdot
.07006 .67776 Mdot
.2866 .53359 Mdot
.3905 .73682 Mdot
.40283 .33424 Mdot
.50214 .12707 Mdot
.11583 .99806 Mdot
.22689 .91312 Mdot
.25128 .83918 Mdot
.18568 .93432 Mdot
.85412 .13927 Mdot
.38977 .98337 Mdot
.07859 .27242 Mdot
.21606 .95347 Mdot
.28438 .89063 Mdot
.92681 .90809 Mdot
.27046 .85257 Mdot
.41133 .93831 Mdot
.22728 .83252 Mdot
.58053 .73437 Mdot
.06937 .00016 Mdot
.27421 .89958 Mdot
.57394 .03085 Mdot
.15588 .99195 Mdot
.23683 .90888 Mdot
.23752 .38719 Mdot
.30882 .93854 Mdot
.80245 .74702 Mdot
.15273 .95106 Mdot
.20853 .64921 Mdot
.08823 .03309 Mdot
.32636 .87869 Mdot
.87199 .5485 Mdot
.50524 .64288 Mdot
.1455 .05161 Mdot
.9671 .27076 Mdot
.21737 .96366 Mdot
.26615 .88446 Mdot
.31669 .90283 Mdot
.27599 .02 Mdot
.23438 .839 Mdot
.86469 .49226 Mdot
.19818 .60246 Mdot
.25803 .69071 Mdot
.88384 .6493 Mdot
.71518 .92165 Mdot
.32796 .70729 Mdot
.82773 .07462 Mdot
.06806 .96265 Mdot
.65315 .76342 Mdot
.29793 .95956 Mdot
.22083 .79353 Mdot
.22867 .54401 Mdot
.07997 .46972 Mdot
.27242 .88084 Mdot
.2824 .84689 Mdot
.26308 .803 Mdot
.35033 .04998 Mdot
.36028 .32312 Mdot
.21486 .55194 Mdot
.25186 .95651 Mdot
.12844 .96441 Mdot
.38574 .77521 Mdot
.71222 .96207 Mdot
.25406 .99946 Mdot
.26908 .85578 Mdot
.80319 .30204 Mdot
.29709 .85064 Mdot
.40318 .71404 Mdot
.17061 .30829 Mdot
.1231 .79006 Mdot
.26521 .83069 Mdot
.30888 .85696 Mdot
.34647 .67516 Mdot
.23757 .60427 Mdot
.21523 .93039 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool00_ooool2o`0000Wooooo00?o0000ooooooooool01_ooool2o`0000Go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo0ol0000<ooooo`;o00004?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[o
oooo0_l000000ooooooo0000ooooo`0?ooooo`03o`000?oooooooooo00;ooooo000Nooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00gooooo0_l0000?ooooo`04o`000?oooooo0000o`0000cooooo0_l0000>ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o0000ooooooooool0
?Oooool2o`00017ooooo0_l00002ooooo`;o00000oooool2o`0000?ooooo0_l00009ooooo`;o0000
__ooool2o`0001cooooo000Nooooo`03o`000?oooooooooo03Sooooo0_l00007ooooo`;o00004Ooo
ool2o`0000?ooooo0_l00009ooooo`;o00000oooool2o`000;kooooo0_l0000Looooo`007_ooool0
0ol0003oooooooooo`0gooooo`?o00001oooool2o`0000oooooo1?l0000>ooooo`;o0000eoooool2
o`0000Sooooo000Nooooo`03o`000?oooooooooo00Gooooo0_l0000`ooooo`;o00004oooool2o`00
00Cooooo0_l00006ooooo`;o0000hOooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo00Go
oooo0_l00015ooooo`;o00000oooool2o`0000?ooooo0_l00002ooooo`;o00003_ooool2o`0000?o
oooo0_l0000`ooooo`;o0000<?ooool2o`0005_ooooo0_l0000Eooooo`007_ooool00ol0003ooooo
ooooo`05ooooo`;o0000B_ooool2o`0000?ooooo0_l0000:ooooo`;o00001Oooool3o`0000?ooooo
0_l0000`ooooo`;o0000<?ooool2o`0002Kooooo0_l0000<ooooo`;o00008_ooool2o`000003oooo
ool0003o000001Gooooo000Nooooo`03o`000?oooooooooo00Gooooo0_l0000Dooooo`Co0000@ooo
ool2o`0000Gooooo0_l0002@ooooo`;o00003?ooool2o`0002;ooooo0_l0000Hooooo`007_ooool0
0ol0003oooooooooo`06ooooo`;o00002?ooool2o`0000Wooooo1?l0001?ooooo`;o0000A_ooool2
o`0008oooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l00008ooooo`;o00001oooool2o`00
03Gooooo0_l0000>ooooo`;o00003?ooool2o`0004Kooooo0_l0001Sooooo`;o0000:_ooool001ko
oooo00?o0000ooooooooool06Oooool2o`00013ooooo0_l0000Sooooo`;o00003_ooool2o`0000;o
oooo0ol0002dooooo`;o00005_ooool2o`0001;ooooo000Nooooo`03o`000?oooooooooo02_ooooo
0_l0000Gooooo`;o00005_ooool2o`0000Kooooo0ol0003<ooooo`;o00004_ooool001kooooo00?o
0000ooooooooool0A?ooool2o`00017ooooo0_l00002ooooo`?o00003Oooool2o`000004ooooool0
003o0000ooooo`;o0000;Oooool2o`000:Gooooo000Nooooo`03o`000?oooooooooo05Oooooo0_l0
0002ooooo`Co00003?ooool2o`000004ooooool0003o0000ooooo`;o00005oooool2o`0001Cooooo
0_l0002Uooooo`007_ooool00ol0003oooooooooo`1Mooooo`;o00001_ooool2o`0000Oooooo0_l0
000Jooooo`;o0000^oooool001kooooo0_l0000/ooooo`;o0000=Oooool2o`000003ooooool0003o
000000Kooooo0ol0003Aooooo`;o00001?ooool001kooooo00?o0000ooooooooool0:oooool2o`00
03Gooooo0ol00008ooooo`?o0000dOooool2o`0000Cooooo000Nooooo`03o`000?oooooooooo00;o
oooo0_l0000fooooo`;o00009oooool3o`000>7ooooo000Nooooo`03o`000?oooooooooo00;ooooo
0_l0000fooooo`;o00008?ooool2o`0000Kooooo0_l0000Gooooo`;o0000X?ooool2o`0002Kooooo
000Nooooo`03o`000?oooooooooo05cooooo0_l0000Oooooo`;o0000X?ooool2o`0000;ooooo0_l0
000:ooooo`;o00005_ooool001kooooo00?o0000ooooooooool0>?ooool2o`0000Cooooo0_l0000J
ooooo`;o00009oooool2o`0005Gooooo0_l00017ooooo`;o00002_ooool2o`0001Kooooo000Noooo
o`04o`000?oooooo0000o`0003Oooooo0_l00004ooooo`;o00006_ooool2o`0001Wooooo0_l0000<
ooooo`;o0000EOooool2o`0006_ooooo000Nooooo`04o`000?oooooo0000o`0003;ooooo0_l0000S
ooooo`;o00006oooool2o`0009;ooooo0_l0000looooo`007_ooool00ol0003oooooooooo`0_oooo
o`;o00000_ooool2o`0002?ooooo0_l0002_ooooo`;o0000??ooool001kooooo00?o0000oooooooo
ool0;oooool2o`0000;ooooo0_l0003ooooooa?ooooo000Nooooo`03o`000?oooooooooo03?ooooo
0_l00024ooooo`;o00004oooool2o`0007Oooooo000Nooooo`03o`000?oooooooooo09Cooooo0_l0
000Sooooo`;o00004oooool2o`0007Oooooo000Nooooo`03o`000?oooooooooo09Cooooo0_l0002a
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo05oo
oooo0_l0003Vooooo`007_ooool00ol0003oooooooooo`1Oooooo`;o00002_ooool2o`000<Gooooo
0_l0000Cooooo`007_ooool2o`0001;ooooo0_l0001Hooooo`;o0000aOooool2o`0001?ooooo000N
ooooo`03o`000?oooooooooo017ooooo0_l0002Looooo`;o0000U_ooool001kooooo00?o0000oooo
ooooool0JOooool2o`0004Cooooo0_l0002Fooooo`007_ooool00ol0003oooooooooo`08ooooo`;o
0000Goooool2o`000=cooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l00008ooooo`;o0000
ooooooldooooo`007_ooool00ol0003oooooooooo`0Booooo`;o0000ooooooldooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo053ooooo0_l0000Foooo
o`;o0000gOooool001kooooo00?o0000ooooooooool0D?ooool2o`0001Kooooo0_l0000eooooo`;o
0000Eoooool2o`0004gooooo000Nooooo`03o`000?oooooooooo013ooooo0_l0001Dooooo`;o0000
=oooool2o`0005Oooooo0_l0001=ooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o00008?oo
ool2o`0001cooooo0_l0000Dooooo`;o0000goooool001kooooo00?o0000ooooooooool0<_ooool2
o`0001cooooo0_l0003eooooo`007_ooool00ol0003oooooooooo`3ooooooa?ooooo0_l0000coooo
o`007_ooool00ol0003oooooooooo`0[ooooo`;o0000iOooool2o`0002_ooooo0_l00006ooooo`00
7_ooool00ol0003oooooooooo`0[ooooo`;o00007oooool2o`0006Oooooo0_l0001@ooooo`;o0000
=_ooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0000cooooo`;o0000Eooo
ool2o`0000kooooo0_l0001@ooooo`;o0000?_ooool001kooooo0_l0000@ooooo`;o00001_ooool2
o`0008cooooo0_l00004ooooo`;o0000I_ooool2o`0003;ooooo000Nooooo`03o`000?oooooooooo
00oooooo0_l0002Jooooo`;o0000I_ooool2o`0003;ooooo000Nooooo`03o`000?oooooooooo073o
oooo0_l0003Eooooo`007_ooool00ol0003oooooooooo`0Vooooo`;o0000B?ooool2o`000=Gooooo
000Nooooo`03o`000?oooooooooo01[ooooo0_l0000:ooooo`;o0000=Oooool2o`00033ooooo0_l0
002fooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o0000@Oooool2o`00033ooooo0_l0002f
ooooo`007_ooool00ol0003oooooooooo`3ooooooagooooo0_l0000Yooooo`007_ooool00ol0003o
ooooooooo`3ooooooagooooo0_l0000Yooooo`007_ooool00ol0003oooooooooo`19ooooo`;o0000
?_ooool2o`000;cooooo000Nooooo`03o`000?oooooooooo04Wooooo0_l0000nooooo`;o0000_?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`1loooo
o`;o0000bOooool001kooooo00?o0000ooooooooool0I_ooool2o`0001Cooooo0_l0000Fooooo`;o
0000/Oooool001kooooo00?o0000ooooooooool0I_ooool2o`0002cooooo0_l0002aooooo`000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003ooooo
ooooo`1<ooooo`;o0000nOooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0C?ooool2o`000?Wo
oooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`?o
00002_ooool2o`00057ooooo0_l0003Xooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`0:ooooo`;o0000DOooool2o`000>So
oooo0003ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03
o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo
0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0aooooo`;o0000oooooolEooooo`007_ooool00ol0
003oooooooooo`0aooooo`;o0000oooooolEooooo`007_ooool00ol0003oooooooooo`23ooooo`;o
0000`_ooool001kooooo00?o0000ooooooooool0Poooool2o`000<;ooooo000Nooooo`03o`000?oo
oooooooo07kooooo0_l00037ooooo`007_ooool00ol0003oooooooooo`1nooooo`;o0000aoooool0
01kooooo00?o0000ooooooooool0ooooool8ooooo`;o0000?_ooool001kooooo00?o0000oooooooo
ool0ooooool8ooooo`;o0000?_ooool001kooooo00?o0000ooooooooool0=_ooool2o`000?oooooo
4?ooool001kooooo00?o0000ooooooooool0=_ooool2o`000?oooooo4?ooool001kooooo00?o0000
ooooooooool0H_ooool2o`0001;ooooo0_l0003?ooooo`007_ooool00ol0003oooooooooo`1Roooo
o`;o00004_ooool2o`000<oooooo000Nooooo`;o0000noooool2o`0004_ooooo000Nooooo`03o`00
0?oooooooooo0?[ooooo0_l0001;ooooo`007_ooool00ol0003oooooooooo`3ooooooa7ooooo0_l0
000eooooo`007_ooool00ol0003oooooooooo`3ooooooa7ooooo0_l0000eooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0m?ooool2o`00043ooooo0_l0000?ooooo`007_ooool00ol0003ooooooooo
o`0Eooooo`;o0000gOooool2o`00043ooooo0_l0000?ooooo`007_ooool00ol0003oooooooooo`0E
ooooo`;o0000oooooolaooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0P?ooool2o`0007cooooo
0_l00017ooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o0000HOooool2o`0003Wooooo0_l0
0011ooooo`;o0000Aoooool001kooooo00?o0000ooooooooool07Oooool2o`0009cooooo0_l0001h
ooooo`;o00004?ooool001kooooo00?o0000ooooooooool0E_ooool2o`0000Wooooo0_l0002?oooo
o`;o0000@Oooool2o`00013ooooo000Nooooo`03o`000?oooooooooo05Kooooo0_l00009ooooo`;o
0000Soooool2o`0005?ooooo000Nooooo`;o0000ooooool3ooooo`;o0000A?ooool001kooooo00?o
0000ooooooooool0ooooool2ooooo`;o00001_ooool2o`0003cooooo000Nooooo`03o`000?oooooo
oooo03?ooooo0_l0002jooooo`;o00006?ooool2o`0003cooooo000Nooooo`03o`000?oooooooooo
03?ooooo0_l0002jooooo`;o0000E_ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3/ooooo`;o0000FOooool001kooooo00?o0000ooooooooool0k?oo
ool2o`0005Wooooo000Nooooo`03o`000?oooooooooo077ooooo0_l0003Dooooo`007_ooool00ol0
003oooooooooo`1aooooo`;o00005_ooool2o`000;cooooo000Nooooo`03o`000?oooooooooo08Wo
oooo0_l0002looooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo07oooooo0_l00036ooooo`007_ooool00ol0003oooooooooo`1<ooooo`;o0000<Oooool2
o`000<Kooooo000Nooooo`03o`000?oooooooooo04cooooo0_l0000jooooo`;o00005Oooool2o`00
0:Kooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l00023ooooo`;o00005Oooool2o`000:Ko
oooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0003ooooood?ooooo000Nooooo`;o0000oooo
oom9ooooo`007_ooool00ol0003oooooooooo`02o`000?ooooooA_ooool001kooooo00?o0000oooo
ooooool00_l0003oooooob3ooooo0_l0000Tooooo`007_ooool00ol0003oooooooooo`3oooooob;o
oooo0_l0000Tooooo`007_ooool00ol0003oooooooooo`16ooooo`;o0000>_ooool2o`000<?ooooo
000Nooooo`03o`000?oooooooooo04Kooooo0_l0000iooooo`?o0000`oooool001kooooo00?o0000
ooooooooool0POooool2o`000<Cooooo000Nooooo`03o`000?oooooooooo03cooooo0_l00032oooo
o`;o0000AOooool001kooooo00?o0000ooooooooool0??ooool2o`000<;ooooo0_l00015ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0:3ooooo0_l0
002Uooooo`007_ooool00ol0003oooooooooo`24ooooo`;o00006_ooool2o`000:Gooooo000Noooo
o`03o`000?oooooooooo04Wooooo0_l0000booooo`;o00001Oooool2o`000<7ooooo000Nooooo`03
o`000?oooooooooo04Wooooo0_l0000?ooooo`;o00008Oooool2o`0003oooooo0_l00027ooooo`00
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@oooooooo
ool01?ooool00ol0003oooooooooo`1Jooooo`;o0000H_ooool2o`0008Oooooo0003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Ko
oooo0ol0001Dooooo`;o0000lOooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04
odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool08?ooool2o`0003;ooooo0_l0002Soooo
o`;o0000C?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0000Oooooo00?o0000ooooooooool08?ooool2o`0001Gooooo0_l0000Aooooo`;o0000[Oooool2
o`0000;ooooo0_l00018ooooo`000oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMg
olc<c?l000001oooool00ol0003oooooooooo`0gooooo`;o00004Oooool2o`000;7ooooo0_l00018
ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool0
0ol0003oooooooooo`35ooooo`;o0000D?ooool2o`0002kooooo0003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0<3ooooo0_l00003
ooooo`;o0000D?ooool2o`0002kooooo000Nooooo`03o`000?oooooooooo0<3ooooo0_l00025oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0`_ooool2o`0000?ooooo0_l0001nooooo`007_ooool0
0ol0003oooooooooo`2Sooooo`;o00007Oooool2o`0000?ooooo0_l0000Kooooo`;o0000HOooool0
01kooooo00?o0000ooooooooool0P?ooool2o`00027ooooo0_l0000oooooo`;o00009Oooool2o`00
03[ooooo000Nooooo`03o`000?oooooooooo00Gooooo0_l0001iooooo`;o0000ROooool2o`0003[o
oooo000Nooooo`03o`000?oooooooooo00Gooooo0_l0003ooooood7ooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`;o0000H_ooool2o`000>Cooooo000Nooooo`03o`00
0?oooooooooo067ooooo0_l0003Tooooo`007_ooool00ol0003oooooooooo`1Rooooo`;o0000hooo
ool001kooooo00?o0000ooooooooool0:?ooool2o`0003Sooooo0_l0003Sooooo`007_ooool00ol0
003oooooooooo`0Xooooo`;o0000<oooool2o`0009cooooo0_l0001:ooooo`007_ooool00ol0003o
ooooooooo`1Mooooo`;o00004_ooool2o`00017ooooo0_l0001eooooo`;o0000B_ooool001kooooo
00?o0000ooooooooool05_ooool2o`0005Wooooo0_l0000Aooooo`;o0000`Oooool001kooooo00?o
0000ooooooooool05_ooool2o`000?oooooo<?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3Looooo`;o0000JOooool001kooooo00?o0000oooooooo
ool0g?ooool2o`0006Wooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0lOooool2o`0001kooooo0_l0000dooooo`007_ooool00ol0003oooooooooo`3G
ooooo`;o00000oooool2o`0001?ooooo0_l0000Nooooo`;o00000_ooool2o`00033ooooo000Noooo
o`03o`000?oooooooooo02?ooooo0_l0002booooo`;o00000oooool2o`0003;ooooo0_l00003oooo
o`;o0000<?ooool001kooooo00?o0000ooooooooool08oooool2o`0004Gooooo0_l0002Tooooo`;o
0000=Oooool001kooooo0_l0001[ooooo`;o0000aoooool2o`0001;ooooo000Nooooo`03o`000?oo
oooooooo0?oooooo=?ooool2o`0001;ooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3eooooo`;o
00008?ooool2o`0002kooooo000Nooooo`03o`000?oooooooooo03[ooooo0_l00018ooooo`;o0000
Koooool2o`00023ooooo0_l0000^ooooo`007_ooool00ol0003oooooooooo`0jooooo`;o0000B?oo
ool2o`000<7ooooo000Nooooo`03o`000?oooooooooo0:;ooooo0_l0002Sooooo`007_ooool00ol0
003oooooooooo`1fooooo`;o0000:_ooool2o`000:?ooooo000Nooooo`03o`000?oooooooooo07Ko
oooo0_l0003?ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo05Wooooo0_l0003/ooooo`007_ooool00ol0003oooooooooo`0^ooooo`;o00004?ooool2
o`0001Oooooo0_l0002jooooo`;o00002oooool2o`0002?ooooo000Mooooo`;o0000<?ooool2o`00
013ooooo0_l00008ooooo`;o0000bOooool2o`0000_ooooo0_l0000Sooooo`007Oooool2o`0004So
oooo1_l0003kooooo`007_ooool00ol0003oooooooooo`0^ooooo`;o00002?ooool4o`0000[ooooo
1?l0003=ooooo`;o0000;_ooool001kooooo0_l0000_ooooo`;o00002?ooool4o`0000Kooooo1?l0
002hooooo`;o00005oooool2o`0002kooooo000Nooooo`03o`000?oooooooooo04;ooooo1?l00004
ooooo`;o0000/_ooool2o`0004Oooooo000Nooooo`03o`000?oooooooooo04[ooooo0_l0003koooo
o`007_ooool00ol0003oooooooooo`0Gooooo`;o0000ooooool_ooooo`007_ooool00ol0003ooooo
ooooo`0Gooooo`;o0000LOooool2o`000;_ooooo000Nooooo`03o`000?oooooooooo08Wooooo0ol0
002kooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o0000Koooool2o`000;cooooo000Noooo
o`03o`000?oooooooooo01Sooooo0_l0002Booooo`;o0000VOooool001kooooo00?o0000oooooooo
ool0[?ooool2o`0009Wooooo000Nooooo`03o`000?oooooooooo077ooooo0_l0003Dooooo`007_oo
ool00ol0003oooooooooo`0Hooooo`;o0000Eoooool2o`000=Cooooo000Nooooo`03o`000?oooooo
oooo01Sooooo0_l00004ooooo`;o00008oooool2o`00017ooooo0_l0003_ooooo`007_ooool00ol0
003oooooooooo`0Nooooo`;o00001?ooool2o`0001gooooo0_l0000Aooooo`;o0000ZOooool2o`00
04Cooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l00033ooooo`;o00005_ooool2o`0004Co
oooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0
003o410@olc<c006ooooo`03o`000?oooooooooo05[ooooo0_l00029ooooo`;o00000_ooool2o`00
05cooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMg
MoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo03;ooooo0_l0000Vooooo`;o0000ROooool2
o`00063ooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooo
oooo000000Kooooo0ol0000booooo`;o00000_ooool2o`0002Sooooo0_l0000hooooo`;o00006?oo
ool2o`0001Sooooo0_l0001gooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go
0000oiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo03?ooooo0_l000000ooooooo0000
o`000004ooooo`;o00002oooool2o`0001Gooooo0_l0000hooooo`;o00006?ooool2o`0001Sooooo
0_l0001gooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o
410@olc<c006ooooo`03o`000?oooooooooo03?ooooo0_l000000ooooooo0000o`000004ooooo`;o
00000_ooool2o`0000Oooooo0_l0003looooo`000oooool01Ol@413ooooooooooooooooo410@00_o
oooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`0Fooooo`;o00003oooool2o`0001Oo
oooo0_l0000Booooo`;o0000lOooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03
omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool04?ooool2o`0000Cooooo0_l0000?ooooo`;o
0000:oooool2o`0005Kooooo0_l0002Iooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`0@ooooo`;o0000V_ooool2o`00
033ooooo0_l0001Wooooo`007_ooool00ol0003oooooooooo`1Mooooo`;o0000Ooooool2o`0006Oo
oooo000Nooooo`03o`000?oooooooooo01oooooo0_l0000looooo`;o0000j?ooool001kooooo00?o
0000ooooooooool07oooool2o`0001Gooooo0_l00008ooooo`;o0000ooooool6ooooo`007_ooool0
0ol0003oooooooooo`0Qooooo`;o00002oooool2o`0000Kooooo0_l00008ooooo`;o0000ioooool2
o`0001cooooo000Nooooo`03o`000?oooooooooo027ooooo0_l0000;ooooo`;o00003_ooool2o`00
03kooooo0_l0002Yooooo`;o00007?ooool001kooooo00?o0000ooooooooool05oooool2o`0002Go
oooo0_l0000nooooo`;o0000Foooool2o`0006[ooooo000Nooooo`03o`000?oooooooooo01Oooooo
0_l0000Looooo`;o00000_ooool3o`0002Gooooo0_l0001hooooo`;o0000J_ooool001kooooo00?o
0000ooooooooool0=Oooool2o`0000;ooooo0ol0000Uooooo`;o0000/oooool2o`0002oooooo000N
ooooo`03o`000?oooooooooo0:3ooooo0_l0001cooooo`?o0000;oooool001kooooo00?o0000oooo
ooooool0=Oooool2o`0006Wooooo0_l0001cooooo`;o0000<?ooool001kooooo00?o0000oooooooo
ool0=Oooool2o`0000Wooooo0_l0003Iooooo`;o0000:_ooool001kooooo0_l00011ooooo`;o0000
fOooool2o`0002[ooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0000aooooo`;o0000o_oo
ool2o`0000_ooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l00004ooooo`;o0000:oooool2
o`000?Oooooo0_l00005ooooo`;o00002oooool001kooooo00?o0000ooooooooool03Oooool2o`00
0>;ooooo0_l00010ooooo`;o00004_ooool001kooooo00?o0000ooooooooool0lOooool2o`0005Co
oooo000Nooooo`03o`000?oooooooooo047ooooo0_l00007ooooo`;o0000<?ooool2o`000<Wooooo
000Nooooo`03o`000?oooooooooo047ooooo0_l00007ooooo`;o00006_ooool2o`000003ooooool0
003o0000017ooooo0_l0000Yooooo`;o0000DOooool2o`0003?ooooo0_l0000Fooooo`007_ooool0
0ol0003oooooooooo`05ooooo`;o0000;Oooool2o`0001oooooo0_l0000?ooooo`;o000000Cooooo
o`000?l0003o0000<?ooool2o`0000Wooooo0_l0000Iooooo`;o0000=_ooool2o`0001Kooooo0_l0
000Kooooo`;o00005_ooool001kooooo00?o0000ooooooooool01Oooool2o`0000cooooo0_l0000O
ooooo`;o00007oooool2o`0001?ooooo0_l000000ooooooo0000o`00000]ooooo`;o00002?ooool2
o`0001[ooooo0_l0001>ooooo`;o0000<oooool001kooooo00?o0000ooooooooool04oooool2o`00
047ooooo0_l00006ooooo`;o00003Oooool2o`0003Oooooo0_l0002Oooooo`007_ooool00ol0003o
ooooooooo`0hooooo`;o00004_ooool2o`0000Sooooo0_l00006ooooo`?o0000:oooool2o`000;Wo
oooo000Nooooo`04o`000?ooooooooooooooo`;o0000=Oooool2o`0001;ooooo0_l0000Aooooo`;o
0000:oooool2o`000;Wooooo000Nooooo`04o`000?ooooooooooooooo`;o0000D?ooool2o`0008Co
oooo0_l0000[ooooo`;o0000?oooool001kooooo00?o0000ooooooooool0D?ooool2o`000003oooo
ool0003o000000[ooooo0_l0000gooooo`;o0000?oooool2o`0002_ooooo0_l0000oooooo`007_oo
ool00ol0003oooooooooo`12ooooo`;o00003?ooool2o`0000gooooo0_l0000gooooo`;o00004_oo
ool2o`0009Wooooo000Nooooo`03o`000?oooooooooo04;ooooo0_l0000>ooooo`;o00001_ooool2
o`00053ooooo0_l0002Iooooo`007_ooool2o`0002Kooooo0_l0000Cooooo`;o00000oooool2o`00
017ooooo0_l00006ooooo`;o00006?ooool2o`0001_ooooo0_l0002dooooo`007_ooool01?l0003o
ooooo`000?l0000Tooooo`;o00004oooool2o`0000?ooooo0_l0000cooooo`;o00006oooool2o`00
0;Cooooo000Nooooo`04o`000?oooooo0000o`0003Kooooo0_l00008ooooo`;o00009?ooool2o`00
0=kooooo000Nooooo`03o`000?oooooooooo02?ooooo0_l0000Booooo`;o00002?ooool2o`0002Co
oooo0_l0003Nooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o00008_ooool2o`0000Sooooo
0_l0000/ooooo`;o0000/Oooool2o`0001?ooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l0
000^ooooo`?o00002?ooool2o`0000kooooo0_l0000Looooo`;o0000BOooool2o`0001?ooooo0_l0
001Aooooo`;o00004oooool001kooooo00?o0000ooooooooool05_ooool2o`0002kooooo0_l00000
0ooooooo0000o`00000Fooooo`;o00000_ooool2o`0001Cooooo0_l0000Tooooo`;o00009oooool2
o`0001?ooooo0_l0001Vooooo`007_ooool00ol0003oooooooooo`19ooooo`;o00006_ooool2o`00
00Cooooo0_l0000>ooooo`;o00009?ooool2o`000:Cooooo000Nooooo`03o`000?oooooooooo037o
oooo0_l0000Looooo`;o00006Oooool3o`000=[ooooo000Nooooo`03o`000?oooooooooo037ooooo
0_l0000Iooooo`;o000000?oooooo`000?l000006Oooool3o`0004cooooo0_l0001Pooooo`;o0000
6oooool2o`0000gooooo000Nooooo`03o`000?oooooooooo02[ooooo0_l0000Pooooo`;o0000Jooo
ool2o`00063ooooo0_l0000Kooooo`;o00003Oooool001kooooo0_l0000[ooooo`;o0000P?ooool2
o`0000Oooooo0_l00002ooooo`;o00007?ooool2o`0006kooooo000Nooooo`;o0000E_ooool2o`00
00oooooo0_l0000Cooooo`?o0000;_ooool2o`0000Oooooo0_l00002ooooo`;o00007?ooool2o`00
03cooooo0_l0000`ooooo`007_ooool00ol0003oooooooooo`14ooooo`;o000000?oooooo`000?l0
00003?ooool2o`0000oooooo0_l0000Cooooo`?o0000Uoooool2o`0001?ooooo0_l0000Kooooo`00
7_ooool00ol0003oooooooooo`14ooooo`Go0000=?ooool2o`0004_ooooo0_l0001Aooooo`;o0000
2oooool2o`0001_ooooo000Nooooo`03o`000?oooooooooo04Gooooo0_l00007ooooo`;o00001ooo
ool2o`0000[ooooo0_l0000Hooooo`;o0000Boooool2o`0003Gooooo0_l0000Jooooo`;o0000:?oo
ool001kooooo0_l0001?ooooo`?o00001_ooool2o`0000[ooooo0_l0000?ooooo`;o00001oooool2
o`0008;ooooo0_l00014ooooo`007_ooool00ol0003oooooooooo`1?ooooo`;o00006?ooool2o`00
00Wooooo0_l00010ooooo`;o00007Oooool2o`00073ooooo000Nooooo`03o`000?oooooooooo02go
oooo0_l0000Mooooo`;o00006oooool2o`0000Kooooo0_l00013ooooo`;o00007Oooool2o`0002Co
oooo0_l00007ooooo`;o00008_ooool2o`0001gooooo000Nooooo`03o`000?oooooooooo02gooooo
0_l0000Mooooo`;o00008oooool2o`0003Oooooo0_l00006ooooo`;o00000oooool2o`0004;ooooo
0_l00007ooooo`;o00008_ooool2o`0001gooooo000Nooooo`03o`000?oooooooooo037ooooo0_l0
000;ooooo`;o00002oooool2o`0005gooooo0_l00006ooooo`;o00000oooool2o`0001Oooooo0_l0
001eooooo`007_ooool00ol0003oooooooooo`0^ooooo`;o000000?oooooo`000?l000002oooool2
o`0000_ooooo0ol0000?ooooo`;o0000Boooool2o`0000Oooooo0_l0000Kooooo`;o0000MOooool0
01kooooo00?o0000ooooooooool0:_ooool3o`000003ooooool0003o000001Kooooo0_l00004oooo
o`;o00002?ooool2o`0000Gooooo0_l0001;ooooo`;o00001oooool2o`000003ooooool0003o0000
02[ooooo0_l0001Sooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o00000oooool5o`0000;o
oooo0_l0000?ooooo`Co00000_ooool2o`0000;ooooo0_l0000:ooooo`;o00000_ooool2o`0005[o
oooo0_l0000Zooooo`;o0000Hoooool001kooooo00?o0000ooooooooool05?ooool2o`000003oooo
ool0003o000000Kooooo0_l00002ooooo`;o00000oooool3o`0000Cooooo0_l0000?ooooo`Co0000
0_ooool6o`000003ooooool0003o000000?ooooo0_l00006ooooo`;o00001Oooool2o`0001Kooooo
0_l0001Gooooo`;o0000Loooool001kooooo00?o0000ooooooooool05?ooool2o`000003ooooool0
003o000000Kooooo0ol0000Looooo`;o00000_ooool3o`0000;ooooo0ol00003ooooo`;o00000ooo
ool2o`000003ooooool0003o000000[ooooo0_l0000Fooooo`;o0000Eoooool2o`0007?ooooo000N
ooooo`03o`000?oooooooooo023ooooo1?l0000>ooooo`;o00002_ooool2o`0000;ooooo0ol00002
ooooo`;o00003?ooool2o`000003ooooool0003o00000>gooooo000Nooooo`03o`000?oooooooooo
02;ooooo0_l0000>ooooo`;o00003Oooool4o`0000Sooooo0_l00009ooooo`;o0000kOooool001ko
oooo00?o0000ooooooooool0:Oooool2o`0001Kooooo1?l00007ooooo`?o00007oooool2o`0001[o
oooo0_l0000Aooooo`;o0000Z?ooool001kooooo00?o0000ooooooooool07oooool2o`000003oooo
ool0003o000000;o00000oooool2o`0001?ooooo1_l00004ooooo`;o00000_ooool3o`0001Sooooo
0_l00004ooooo`?o00006_ooool2o`00017ooooo0_l0001Vooooo`;o00005_ooool2o`0002Sooooo
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o
8B4Qolc<c006ooooo`03o`000?oooooooooo01oooooo0_l000000ooooooo0000o`000002o`0000Wo
oooo0_l0000<ooooo`Ko000000?oooooo`000?l000000_ooool2o`0000Gooooo0_l0000Fooooo`;o
00001?ooool2o`0009Kooooo0_l0000Fooooo`;o0000:?ooool000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000oooo
ooooool07oooool2o`0000Oooooo0_l00005ooooo`;o00003?ooool2o`0000;ooooo1Ol00009oooo
o`?o00005_ooool2o`000;Gooooo0_l0000Vooooo`000oooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o00007oooool2o`0000Gooooo1?l00009
ooooo`;o00003?ooool4o`0000Oooooo0_l00002ooooo`;o00005_ooool2o`0003_ooooo0_l0000<
ooooo`;o0000J_ooool2o`0002Kooooo0003ooooo`05o`000?ooooooooooooooool000002oooool0
1Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000ooooooooool09_ooool4o`0000;ooooo0_l0
0005ooooo`;o00001?ooool2o`0000?ooooo0_l000000ooooooo0000o`000007ooooo`Co00000ooo
ool2o`0005;ooooo0_l0000<ooooo`;o0000T_ooool000?ooooo00Go0000ooooooooooooooooo`00
000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`0>ooooo`;o0000
6?ooool2o`0000;ooooo0_l00003ooooo`;o00001_ooool4o`000004ooooool0003o0000ooooo`;o
00001Oooool4o`0000Gooooo0_l0001<ooooo`;o00004oooool2o`0000Gooooo0_l0002:ooooo`00
0oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006oooo
o`03o`000?oooooooooo00kooooo0_l00002ooooo`;o00007Oooool3o`0000Oooooo0_l00003oooo
o`;o000000?oooooo`000?l000000oooool4o`0000Kooooo0_l00006ooooo`;o0000@oooool2o`00
01?ooooo0_l00003ooooo`Co00008?ooool2o`0006Sooooo0003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool04_ooool2
o`0001kooooo0_l0000<ooooo`;o000000Coooooo`000?l0003o00000_ooool4o`0000Kooooo0_l0
0006ooooo`;o00002oooool2o`00053ooooo0_l0000Rooooo`;o0000J?ooool000?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003ooooo
ooooo`14ooooo`;o00000_ooool2o`0001;ooooo0_l00009ooooo`;o00002_ooool2o`0002_ooooo
0_l0000Iooooo`;o0000?_ooool2o`0004[ooooo000Nooooo`03o`000?oooooooooo04Sooooo0ol0
000;ooooo`;o000000Coooooo`000?l0003ooooo0_l0000>ooooo`;o00001Oooool2o`0002_ooooo
0_l0000Iooooo`;o0000?_ooool2o`0004[ooooo000Nooooo`03o`000?oooooooooo02[ooooo0_l0
000Hooooo`Co000000?oooooo`000?l000000_ooool2o`000004ooooool0003o0000ooooo`;o0000
00Coooooo`000?l0003ooooo0_l00007ooooo`;o00002?ooool2o`0009gooooo0_l0000jooooo`00
7_ooool00ol0003oooooooooo`0<ooooo`;o00007?ooool2o`0000_ooooo0_l00005ooooo`;o0000
1?ooool6o`0000?ooooo1Ol000001?oooooo0000o`000?ooool2o`0000[ooooo0_l00004ooooo`;o
0000AOooool2o`0005[ooooo0_l0000Tooooo`;o00005?ooool001kooooo00?o0000ooooooooool0
3?ooool2o`0002Wooooo0_l00005ooooo`;o00001?ooool6o`0000Gooooo0_l00005ooooo`;o0000
00?oooooo`000?l000002oooool4o`0002[ooooo0_l0000Iooooo`;o00003Oooool2o`00023ooooo
0_l0001?ooooo`;o00005?ooool001kooooo00?o0000ooooooooool02?ooool2o`0003Cooooo0_l0
0004ooooo`Co00001Oooool2o`0000;ooooo0ol00002ooooo`;o000000?oooooo`000?l000001?oo
ool2o`0000Gooooo0_l00006ooooo`;o00009?ooool2o`0002Sooooo0_l0000Pooooo`;o0000IOoo
ool001kooooo00?o0000ooooooooool02?ooool2o`0000;ooooo0_l0000aooooo`;o00001Oooool5
o`0000;ooooo2Ol00009ooooo`;o00002_ooool2o`000003ooooool0003o00000=Oooooo000Noooo
o`03o`000?oooooooooo00cooooo0_l0000Cooooo`;o00002Oooool2o`0000kooooo0_l000000ooo
oooo0000o`000002ooooo`So00001?ooool2o`0000?ooooo0_l0000Eooooo`;o0000f_ooool001ko
oooo00?o0000ooooooooool08Oooool2o`0000Wooooo0_l0000:ooooo`;o00000_ooool2o`0000Go
oooo1?l000000ooooooo0000o`000002o`0000;ooooo0_l00002ooooo`Co000000Coooooo`000?l0
003o00001oooool2o`0007Sooooo0_l0001Zooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o
00003oooool3o`0000kooooo0_l00005ooooo`;o00001_ooool2o`0000?ooooo0_l000000ooooooo
0000o`00000Bo`000005ooooool0003o0000o`000?ooool00_l0001Eooooo`;o00008Oooool2o`00
06[ooooo000Nooooo`03o`000?oooooooooo00oooooo0_l0000?ooooo`;o00003oooool2o`0000?o
oooo0_l00008ooooo`;o00001Oooool7o`000003ooooool0003o000000?o000000?oooooo`000?l0
00001Ol000001?oooooo0000o`000?l0001;ooooo`;o00002oooool2o`00077ooooo0_l0000@oooo
o`;o00002?ooool001kooooo00?o0000ooooooooool0=_ooool2o`0000[ooooo0_l00003ooooo`;o
00001_ooool4o`000003ooooool0003o000000Co00006_ooool2o`0003Gooooo0ol0001mooooo`;o
00004?ooool4o`0000Kooooo000Nooooo`;o00008Oooool2o`00023ooooo0_l0000=ooooo`;o0000
00Coooooo`000?l0003o00001Oooool2o`0000;ooooo0ol0000;ooooo`;o00001?ooool2o`0003Ko
oooo0_l0002Aooooo`;o00001_ooool001kooooo00?o0000ooooooooool02?ooool2o`0001Kooooo
0_l0000Vooooo`;o00001oooool5o`0000Cooooo1?l000000ooooooo0000o`000002o`0000_ooooo
0_l00016ooooo`;o000000?oooooo`000?l000001?ooool2o`0008Kooooo000Nooooo`03o`000?oo
oooooooo00Sooooo0_l0000looooo`So00000oooool4o`0000;ooooo0_l000001Ooooooo0000o`00
0?l0003ooooo00Co00005_ooool2o`0003cooooo0_l000000ooooooo0000o`000004ooooo`;o0000
0_ooool2o`0008;ooooo000Nooooo`03o`000?oooooooooo03?ooooo0_l0000Aooooo`;o00000_oo
ool4o`0000Cooooo0_l00003ooooo`;o00000_ooool7o`0000Gooooo0_l0000?ooooo`;o0000BOoo
ool2o`0008;ooooo000Nooooo`03o`000?oooooooooo03?ooooo1?l0000:ooooo`;o00003?ooool2
o`000003ooooool0003o000000Go00000oooool2o`0000Wooooo0_l00003ooooo`;o0000boooool2
o`0000cooooo000Nooooo`03o`000?oooooooooo03Cooooo0ol00006ooooo`;o00000_ooool2o`00
00cooooo0_l000000ooooooo0000o`000005o`0000?ooooo0_l0000>ooooo`;o0000;?ooool2o`00
09?ooooo0_l00008ooooo`;o00003?ooool001kooooo00?o0000ooooooooool0>Oooool2o`0000;o
oooo0_l00005ooooo`;o00002Oooool6o`000003ooooool0003o000000?o000000?oooooo`000?l0
0000??ooool2o`0001Oooooo0_l0000@ooooo`;o00002?ooool2o`0005cooooo1?l0000Fooooo`00
7_ooool00ol0003oooooooooo`0iooooo`;o00002Oooool2o`0000Gooooo0_l00003ooooo`_o0000
0_ooool2o`0000Sooooo0_l0001:ooooo`;o00002oooool2o`0000?ooooo0_l00008ooooo`;o0000
G?ooool4o`0000[ooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0fooooo`?o00002_oo
ool2o`0000Kooooo0_l00006ooooo`Co00000_ooool2o`0000;ooooo0_l00006ooooo`Co000000?o
ooooo`000?l000001?ooool2o`0000Gooooo0_l00017ooooo`;o0000KOooool2o`0000[ooooo0_l0
000:ooooo`007_ooool00ol0003oooooooooo`0fooooo`?o00002_ooool2o`0000_ooooo0_l00000
1?oooooo0000o`000?l00003ooooo`;o00002_ooool3o`0000;ooooo1?l00002ooooo`;o00001Ooo
ool2o`0002Gooooo0_l0000@ooooo`;o0000UOooool001kooooo00?o0000ooooooooool0=_ooool2
o`0000Cooooo0_l00004ooooo`;o00003?ooool7o`0000oooooo0_l00004ooooo`;o0000<?ooool2
o`00013ooooo0_l0000Jooooo`;o0000NOooool001kooooo00?o0000ooooooooool0=_ooool2o`00
00Cooooo0_l00004ooooo`Co00002oooool6o`0000cooooo0_l00004ooooo`;o0000HOooool2o`00
07Wooooo000Nooooo`03o`000?oooooooooo03_ooooo0_l00004ooooo`Go00002oooool5o`0000Oo
oooo0_l00004ooooo`;o00001?ooool2o`00027ooooo0_l0002Yooooo`;o00003_ooool001kooooo
00?o0000ooooooooool0>oooool2o`0000Cooooo1?l00007ooooo`;o00001_ooool;o`0000Oooooo
0_l00003ooooo`;o00007oooool2o`000:Wooooo0_l0000>ooooo`007_ooool00ol0003ooooooooo
o`0kooooo`;o00003Oooool4o`0000Oooooo2?l00009ooooo`;o00000_ooool3o`0001cooooo0_l0
000Aooooo`;o0000ZOooool001kooooo00?o0000ooooooooool0<oooool2o`0000Wooooo0_l00004
ooooo`;o000000?oooooo`000?l000000ol00008ooooo`;o00000_ooool4o`0000;ooooo0_l00005
ooooo`;o00000oooool2o`0001gooooo0_l0000Aooooo`;o0000ZOooool001kooooo0_l0000]oooo
o`;o00001Oooool2o`000003ooooool0003o000000Kooooo0_l00004ooooo`Ko00002_ooool3o`00
0003ooooool0003o000000;o00000_ooool2o`0000?ooooo1?l00004ooooo`;o0000f_ooool001ko
oooo00?o0000ooooooooool0;?ooool2o`0000Sooooo0_l0000;ooooo`Co00003_ooool2o`000003
ooooool0003o000000Wooooo0_l00006ooooo`;o00001?ooool2o`000003ooooool0003o00000=7o
oooo000Nooooo`03o`000?oooooooooo03Kooooo0_l0000;ooooo`;o00003?ooool3o`0000;ooooo
0_l00003ooooo`;o00000_ooool2o`0000;ooooo0_l00004ooooo`;o00001Oooool3o`000003oooo
ool0003o0000063ooooo0_l0000@ooooo`;o0000?oooool2o`0001cooooo000Nooooo`03o`000?oo
oooooooo03Kooooo0ol00002ooooo`;o00000oooool2o`0000Kooooo0ol00006ooooo`?o00000_oo
ool2o`0000?ooooo0_l000000ooooooo0000o`000002o`0000Oooooo0_l00005ooooo`;o00000_oo
ool2o`00063ooooo0_l0000@ooooo`;o0000?oooool2o`0001cooooo000Nooooo`03o`000?oooooo
oooo01_ooooo0_l0000Jooooo`;o00000_ooool2o`0000?ooooo0_l00004ooooo`Go00003_ooool3
o`0000;ooooo1?l00007ooooo`;o00002_ooool2o`0007;ooooo0_l0001Looooo`007_ooool00ol0
003oooooooooo`0Kooooo`;o00006oooool2o`0000cooooo1?l0000=ooooo`Ko00000_ooool3o`00
00?ooooo0_l00008ooooo`;o00001?ooool2o`0000Sooooo0_l0001Xooooo`;o0000EOooool2o`00
00Gooooo000Nooooo`03o`000?oooooooooo03Sooooo0_l0000=ooooo`Go00002oooool2o`0000;o
oooo0_l00003ooooo`;o00000oooool3o`0000;ooooo0_l00003ooooo`;o000000Coooooo`000?l0
003o00001_ooool2o`0000;ooooo0_l0000Xooooo`;o00009Oooool2o`0002cooooo0_l00010oooo
o`;o00001Oooool001kooooo00?o0000ooooooooool0>_ooool2o`0000_ooooo0_l000000ooooooo
0000o`000004ooooo`;o00005?ooool2o`0000;ooooo0_l00006ooooo`?o00001_ooool2o`0002co
oooo0_l0000Uooooo`;o00004_ooool2o`0001Sooooo0_l0000]ooooo`;o00006?ooool001gooooo
0_l0000looooo`;o00001?ooool2o`0000Wooooo0_l00003ooooo`;o00001?ooool2o`0001cooooo
0_l0000:ooooo`;o0000B_ooool2o`0001Kooooo0_l0000=ooooo`;o0000>?ooool2o`0000Gooooo
0_l0000Aooooo`007Oooool2o`0003?ooooo0_l0000=ooooo`;o00001?ooool4o`000003ooooool0
003o000000Wooooo0_l0000Looooo`;o00002_ooool2o`0004[ooooo0_l0000Uooooo`;o0000?ooo
ool2o`0000Cooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o00007?ooool2
o`0000?ooooo0_l00005ooooo`;o00002?ooool2o`0000;ooooo1?l00002ooooo`;o00000_ooool2
o`00017ooooo0_l00004ooooo`;o00006_ooool2o`0003cooooo0_l0001eooooo`;o00002oooool0
01kooooo00?o0000ooooooooool03_ooool2o`0001cooooo0_l0000:ooooo`;o00002?ooool2o`00
00Sooooo0_l00002ooooo`?o00004?ooool2o`0000Cooooo0_l0000<ooooo`;o00002oooool3o`00
03cooooo0_l00022ooooo`007_ooool00ol0003oooooooooo`0hooooo`Go00005?ooool2o`0000go
oooo0_l0000=ooooo`;o00001_ooool2o`0000Wooooo1?l00017ooooo`;o00007?ooool2o`0005[o
oooo000Nooooo`03o`000?oooooooooo03Wooooo1?l0000Aooooo`;o00004?ooool2o`0000gooooo
0_l00006ooooo`;o00000oooool2o`0000Cooooo0_l00015ooooo`;o00000_ooool2o`0001cooooo
0_l0001Jooooo`007_ooool00ol0003oooooooooo`0jooooo`;o00004_ooool2o`0000Sooooo0_l0
000Mooooo`;o00000oooool2o`0004_ooooo0_l0001looooo`007_ooool00ol0003oooooooooo`1;
ooooo`;o00002oooool2o`0001Cooooo0_l0000Sooooo`Ko0000Hoooool2o`0000_ooooo0_l0000l
ooooo`007_ooool2o`0002oooooo0_l0000<ooooo`Co00002oooool2o`0000[ooooo0_l00005oooo
o`;o00003_ooool2o`0000Kooooo0_l000000ooooooo0000o`000002o`0001Kooooo1_l0001Soooo
o`;o00002oooool2o`0003Cooooo0_l00006ooooo`007_ooool00ol0003oooooooooo`0^ooooo`;o
00003?ooool4o`0000;ooooo0ol0000Booooo`;o00000oooool4o`0001Kooooo2?l00031ooooo`;o
00001_ooool001kooooo00?o0000ooooooooool07Oooool2o`0001oooooo1ol00009ooooo`;o0000
3?ooool2o`0001[ooooo0_l00002ooooo`Co00000_ooool2o`000<?ooooo000Nooooo`03o`000?oo
oooooooo01gooooo0_l0000Oooooo`Co00002oooool4o`0000_ooooo0ol0000Booooo`;o00000_oo
ool2o`0000Gooooo1?l00002ooooo`;o00000oooool2o`000;kooooo000Nooooo`03o`000?oooooo
oooo01;ooooo0_l0000/ooooo`;o000000?oooooo`000?l000001_ooool6o`0000cooooo0_l0000B
ooooo`;o00000_ooool2o`0000Gooooo0_l00009ooooo`;o0000F_ooool2o`0003[ooooo0_l0000V
ooooo`007_ooool00ol0003oooooooooo`0Booooo`;o00004?ooool4o`0001Gooooo0_l00004oooo
o`;o00001_ooool2o`0000_ooooo1?l000001?oooooo0000o`000?l0000Looooo`;o00000oooool2
o`00063ooooo0_l0000jooooo`;o00009_ooool001kooooo00?o0000ooooooooool05?ooool2o`00
00kooooo1?l00003ooooo`;o00004?ooool2o`0000Gooooo0_l0000;ooooo`;o00001Oooool4o`00
0004ooooool0003o0000o`0001[ooooo1Ol00002ooooo`;o0000a?ooool001kooooo00?o0000oooo
ooooool05?ooool2o`0001Gooooo0_l0000Gooooo`;o00002Oooool4o`00013ooooo0_l0000Boooo
o`;o000000?oooooo`000?l000000ol000001?oooooo0000o`000?l00034ooooo`007_ooool00ol0
003oooooooooo`19ooooo`;o00001?ooool4o`000003ooooool0003o000000gooooo0_l0000Boooo
o`?o000000?oooooo`000?l000000_l000001?oooooo0000o`000?l0000Kooooo`;o0000Yoooool0
01kooooo00?o0000ooooooooool0=Oooool2o`0001;ooooo0_l00002ooooo`;o000000Goooooo`00
0?l0003o0000ooooo`02o`0002;ooooo1ol00002ooooo`;o00006oooool2o`00027ooooo0_l0000[
ooooo`;o00005Oooool2o`00043ooooo000Nooooo`03o`000?oooooooooo03Gooooo0_l0000Eoooo
o`?o00002oooool2o`0000gooooo0_l0000:ooooo`Co000000?oooooo`000?l000000ol00008oooo
o`;o00009oooool2o`0000oooooo0_l0000[ooooo`;o00005Oooool2o`00043ooooo000Nooooo`03
o`000?oooooooooo01oooooo0_l0000<ooooo`;o00007Oooool3o`0000;ooooo0_l00007ooooo`;o
00003Oooool2o`0000[ooooo1?l00002ooooo`Go00001oooool2o`0002Oooooo0_l0000kooooo`;o
0000F?ooool001kooooo00?o0000ooooooooool06oooool2o`0000;ooooo0_l0000<ooooo`;o0000
7_ooool2o`0000;ooooo0_l0000Rooooo`;o00000oooool3o`000003ooooool0003o000006gooooo
0_l0001Hooooo`007_ooool00ol0003oooooooooo`0Kooooo`;o00002oooool2o`0003Kooooo0_l0
000@ooooo`;o000000?oooooo`000?l000000oooool2o`000;;ooooo0_l0000Gooooo`005?ooool4
o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool2o`0000Gooooo0_l0000Q
ooooo`Ko00002?ooool2o`00013ooooo0_l000000ooooooo0000o`000002o`0007Kooooo0_l0000c
ooooo`;o00002?ooool2o`0001Oooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool04Oooool2o`0000kooooo0_l0000<ooooo`;o00008Oooool6o`0000_ooooo0_l0000<oooo
o`;o00001?ooool2o`0007Kooooo0_l0000cooooo`;o00002?ooool2o`0001Oooooo000Fooooo`03
o`000?oooooooooo00Gooooo0ol0000Aooooo`;o00003_ooool3o`0002?ooooo0_l00005ooooo`;o
00003oooool2o`0000;ooooo0_l0000<ooooo`?o0000]Oooool2o`0001cooooo000Fooooo`03o`00
0?oooooooooo02[ooooo0_l0000Sooooo`;o00001Oooool2o`0000oooooo0_l0000Aooooo`;o0000
]Oooool2o`0001cooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000
ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Dooooo`03
oeEEEOmVIVKo00000?ooooooD_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.43177 .95434 Mdot
.97712 .81597 Mdot
.29983 .85509 Mdot
.35965 .85964 Mdot
.21551 .76831 Mdot
.28651 .89416 Mdot
.80395 .87235 Mdot
.21803 .79535 Mdot
.26768 .90274 Mdot
.32375 .2355 Mdot
.26006 .75615 Mdot
.33223 .71883 Mdot
.24774 .83431 Mdot
.9128 .8474 Mdot
.29606 .90035 Mdot
.18493 .52691 Mdot
.23608 .33093 Mdot
.28465 .83688 Mdot
.43458 .96728 Mdot
.34617 .88908 Mdot
.92696 .00826 Mdot
.21808 .95838 Mdot
.18989 .89713 Mdot
.29816 .03099 Mdot
.27033 .87293 Mdot
.19024 .80439 Mdot
.27315 .90491 Mdot
.20354 .60256 Mdot
.27548 .72512 Mdot
.27427 .98602 Mdot
.35744 .90093 Mdot
.28653 .89685 Mdot
.18588 .91413 Mdot
.38608 .11773 Mdot
.38583 .99818 Mdot
.29079 .78335 Mdot
.95527 .86979 Mdot
.36396 .15762 Mdot
.35555 .72802 Mdot
.28296 .86244 Mdot
.38261 .92396 Mdot
.17056 .92995 Mdot
.05003 .78774 Mdot
.20844 .22985 Mdot
.89717 .97285 Mdot
.19038 .90571 Mdot
.66963 .94767 Mdot
.16181 .7907 Mdot
.27362 .79327 Mdot
.25757 .79669 Mdot
.26931 .66588 Mdot
.1148 .98004 Mdot
.18705 .76403 Mdot
.24612 .71323 Mdot
.18269 .76622 Mdot
.39079 .46139 Mdot
.61858 .83058 Mdot
.2369 .79847 Mdot
.27323 .90849 Mdot
.36258 .07392 Mdot
.35911 .87933 Mdot
.2015 .80994 Mdot
.14118 .04171 Mdot
.24633 .87062 Mdot
.31404 .8095 Mdot
.24343 .92537 Mdot
.06538 .97821 Mdot
.27256 .90604 Mdot
.28838 .90588 Mdot
.98447 .82905 Mdot
.24412 .37975 Mdot
.28265 .9106 Mdot
.41394 .84629 Mdot
.23596 .24635 Mdot
.17571 .88781 Mdot
.59 .78986 Mdot
.2847 .93674 Mdot
.1973 .34043 Mdot
.28001 .90679 Mdot
.31199 .8964 Mdot
.23745 .91373 Mdot
.81651 .27009 Mdot
.13697 .17516 Mdot
.20838 .80586 Mdot
.80208 .21516 Mdot
.7827 .41726 Mdot
.20894 .77192 Mdot
.31623 .88759 Mdot
.29177 .89918 Mdot
.31274 .01082 Mdot
.21412 .85736 Mdot
.68729 .49268 Mdot
.21433 .87378 Mdot
.35525 .19913 Mdot
.38888 .03836 Mdot
.19887 .93663 Mdot
.38989 .92402 Mdot
.19799 .01053 Mdot
.16522 .77874 Mdot
.60427 .86127 Mdot
.25214 .85691 Mdot
.2689 .67785 Mdot
.43948 .94554 Mdot
.02259 .6933 Mdot
.02389 .86591 Mdot
.18456 .89 Mdot
.21545 .48925 Mdot
.1803 .51135 Mdot
.0864 .94416 Mdot
.52241 .64952 Mdot
.94624 .82315 Mdot
.05794 .13938 Mdot
.32401 .8833 Mdot
.30876 .84563 Mdot
.80027 .89245 Mdot
.78925 .98576 Mdot
.92702 .00377 Mdot
.24114 .8568 Mdot
.13358 .28652 Mdot
.21122 .98213 Mdot
.27506 .8992 Mdot
.0888 .83329 Mdot
.16746 .96076 Mdot
.35143 .26638 Mdot
.03435 .60722 Mdot
.54296 .72261 Mdot
.09106 .74278 Mdot
.42511 .97367 Mdot
.3366 .097 Mdot
.54056 .79726 Mdot
.5168 .6746 Mdot
.10938 .40282 Mdot
.93362 .37896 Mdot
.261 .92743 Mdot
.34497 .95001 Mdot
.23987 .79461 Mdot
.17249 .87174 Mdot
.20294 .67976 Mdot
.40394 .88388 Mdot
.26756 .90931 Mdot
.41899 .96368 Mdot
.22561 .85806 Mdot
.19961 .94872 Mdot
.59089 .9129 Mdot
.07075 .57813 Mdot
.28645 .75662 Mdot
.38925 .99803 Mdot
.27151 .86803 Mdot
.55064 .73457 Mdot
.87992 .19999 Mdot
.30197 .84016 Mdot
.18772 .94382 Mdot
.36598 .72249 Mdot
.33776 .89632 Mdot
.29165 .90404 Mdot
.21551 .83932 Mdot
.23304 .65107 Mdot
.68223 .08713 Mdot
.28568 .89665 Mdot
.24121 .52308 Mdot
.23236 .7045 Mdot
.51355 .90776 Mdot
.87393 .11968 Mdot
.24507 .96194 Mdot
.18411 .77878 Mdot
.18588 .77324 Mdot
.28097 .85355 Mdot
.28756 .89539 Mdot
.76384 .90091 Mdot
.21914 .85813 Mdot
.19006 .97273 Mdot
.44993 .00278 Mdot
.44809 .94473 Mdot
.82782 .48777 Mdot
.43544 .96988 Mdot
.32597 .74533 Mdot
.48957 .01406 Mdot
.21115 .79126 Mdot
.77176 .71889 Mdot
.12483 .99378 Mdot
.10008 .75282 Mdot
.21757 .74353 Mdot
.44861 .93896 Mdot
.92741 .04047 Mdot
.23918 .60833 Mdot
.33819 .75061 Mdot
.25217 .54644 Mdot
.17215 .84859 Mdot
.48769 .07164 Mdot
.57263 .84273 Mdot
.43062 .97487 Mdot
.866 .10326 Mdot
.4249 .96789 Mdot
.06777 .9787 Mdot
.2475 .00213 Mdot
.05233 .81842 Mdot
.52772 .93767 Mdot
.20848 .89279 Mdot
.26116 .90309 Mdot
.16574 .9279 Mdot
.01615 .14413 Mdot
.38872 .87967 Mdot
.28729 .94584 Mdot
.92838 .9921 Mdot
.26666 .87304 Mdot
.32168 .88545 Mdot
.93978 .69205 Mdot
.29989 .90447 Mdot
.40856 .99151 Mdot
.28715 .72314 Mdot
.19926 .82631 Mdot
.41912 .95959 Mdot
.01059 .1256 Mdot
.14073 .07226 Mdot
.21765 .70181 Mdot
.32307 .87841 Mdot
.29108 .84884 Mdot
.38414 .65234 Mdot
.32141 .63403 Mdot
.09106 .00429 Mdot
.86768 .02209 Mdot
.37032 .07254 Mdot
.20097 .83797 Mdot
.28874 .90163 Mdot
.36234 .05504 Mdot
.28578 .82428 Mdot
.52627 .77353 Mdot
.18997 .8568 Mdot
.33423 .85813 Mdot
.21012 .94478 Mdot
.19332 .82928 Mdot
.33826 .07827 Mdot
.18522 .95204 Mdot
.64644 .87229 Mdot
.34744 .9962 Mdot
.39351 .18272 Mdot
.56682 .47748 Mdot
.31161 .87665 Mdot
.06847 .01692 Mdot
.85541 .38689 Mdot
.28961 .73898 Mdot
.18848 .95669 Mdot
.09281 .76005 Mdot
.33812 .78864 Mdot
.41234 .7777 Mdot
.19123 .04377 Mdot
.3413 .08687 Mdot
.20516 .97972 Mdot
.51377 .60271 Mdot
.36802 .91886 Mdot
.10957 .98678 Mdot
.16581 .78801 Mdot
.22396 .79931 Mdot
.75312 .54699 Mdot
.01497 .60529 Mdot
.16174 .71186 Mdot
.18136 .76649 Mdot
.14735 .88297 Mdot
.16556 .92232 Mdot
.94543 .01399 Mdot
.42155 .95791 Mdot
.32101 .88897 Mdot
.35341 .43268 Mdot
.47991 .18496 Mdot
.18799 .95167 Mdot
.82398 .2945 Mdot
.34195 .79585 Mdot
.97482 .6057 Mdot
.28553 .87263 Mdot
.2771 .88543 Mdot
.17074 .77994 Mdot
.73029 .68202 Mdot
.34428 .91611 Mdot
.29534 .91238 Mdot
.2924 .93147 Mdot
.1669 .82078 Mdot
.2993 .62941 Mdot
.23154 .26669 Mdot
.26319 .74496 Mdot
.30917 .68186 Mdot
.61855 .8583 Mdot
.21401 .96529 Mdot
.23477 .96064 Mdot
.97856 .97895 Mdot
.19074 .76753 Mdot
.20645 .84126 Mdot
.24112 .86565 Mdot
.5645 .73303 Mdot
.13912 .72599 Mdot
.29584 .64492 Mdot
.11887 .71091 Mdot
.58377 .24166 Mdot
.43077 .96644 Mdot
.24296 .86014 Mdot
.731 .44779 Mdot
.54546 .79367 Mdot
.30926 .81736 Mdot
.26036 .55344 Mdot
.62554 .7918 Mdot
.71237 .99017 Mdot
.56 .69427 Mdot
.11665 .79905 Mdot
.48794 .9709 Mdot
.31587 .0969 Mdot
.53419 .87769 Mdot
.07071 .94351 Mdot
.27491 .90424 Mdot
.28783 .91139 Mdot
.89902 .06725 Mdot
.30573 .9685 Mdot
.28734 .90432 Mdot
.61429 .73118 Mdot
.18996 .81237 Mdot
.45658 .00129 Mdot
.2613 .80711 Mdot
.23298 .67245 Mdot
.33321 .90205 Mdot
.76487 .5608 Mdot
.15071 .85658 Mdot
.41153 .2375 Mdot
.36619 .7138 Mdot
.18268 .92868 Mdot
.29752 .66648 Mdot
.40366 .9401 Mdot
.33478 .87932 Mdot
.19669 .83274 Mdot
.26672 .75145 Mdot
.41594 .95854 Mdot
.29835 .68211 Mdot
.18987 .82511 Mdot
.29835 .88426 Mdot
.27778 .90598 Mdot
.36281 .45536 Mdot
.86564 .6741 Mdot
.26869 .79465 Mdot
.21989 .0562 Mdot
.44822 .82006 Mdot
.26956 .9003 Mdot
.16617 .5119 Mdot
.76258 .41658 Mdot
.18768 .78964 Mdot
.04638 .11777 Mdot
.41089 .96073 Mdot
.31553 .05628 Mdot
.70546 .0254 Mdot
.48258 .62288 Mdot
.86699 .09374 Mdot
.13463 .53895 Mdot
.16691 .70689 Mdot
.22473 .78825 Mdot
.26595 .8697 Mdot
.17235 .77074 Mdot
.54888 .90289 Mdot
.10768 .59301 Mdot
.99349 .68169 Mdot
.35171 .89974 Mdot
.22862 .91716 Mdot
.26428 .01107 Mdot
.25222 .81071 Mdot
.35412 .03335 Mdot
.20597 .96941 Mdot
.489 .78934 Mdot
.37862 .91625 Mdot
.19337 .83629 Mdot
.161 .82363 Mdot
.31167 .95566 Mdot
.02756 .84033 Mdot
.50975 .11441 Mdot
.03917 .3151 Mdot
.27411 .95968 Mdot
.20498 .70362 Mdot
.27981 .90017 Mdot
.32409 .88626 Mdot
.24283 .92476 Mdot
.62297 .92716 Mdot
.60573 .82236 Mdot
.90441 .96201 Mdot
.29061 .82593 Mdot
.83649 .70081 Mdot
.2447 .9944 Mdot
.28222 .90332 Mdot
.31897 .85559 Mdot
.06044 .44257 Mdot
.02166 .59451 Mdot
.27164 .62289 Mdot
.00957 .97336 Mdot
.07691 .75139 Mdot
.37597 .23492 Mdot
.27183 .90012 Mdot
.02046 .85326 Mdot
.41918 .96479 Mdot
.25578 .78408 Mdot
.277 .84734 Mdot
.24861 .76768 Mdot
.23477 .76591 Mdot
.47858 .38328 Mdot
.20436 .3106 Mdot
.77514 .26749 Mdot
.27427 .91055 Mdot
.36268 .90516 Mdot
.03746 .83076 Mdot
.92292 .88609 Mdot
.78455 .0383 Mdot
.20215 .81019 Mdot
.0679 .0582 Mdot
.5729 .75306 Mdot
.26287 .63391 Mdot
.28271 .94255 Mdot
.31301 .06016 Mdot
.24055 .95101 Mdot
.20706 .72001 Mdot
.28493 .89009 Mdot
.22265 .70918 Mdot
.08137 .9244 Mdot
.86934 .51553 Mdot
.26305 .87569 Mdot
.40888 .97719 Mdot
.27482 .77979 Mdot
.48255 .58875 Mdot
.28035 .90879 Mdot
.28483 .88172 Mdot
.34105 .55931 Mdot
.45267 .29365 Mdot
.25278 .80283 Mdot
.22558 .80189 Mdot
.88298 .94152 Mdot
.02051 .18556 Mdot
.25008 .92081 Mdot
.2783 .88172 Mdot
.31101 .86129 Mdot
.7564 .4517 Mdot
.78976 .89042 Mdot
.92181 .97402 Mdot
.3041 .86684 Mdot
.9261 .79925 Mdot
.35755 .57767 Mdot
.2941 .6384 Mdot
.56264 .70687 Mdot
.30892 .93102 Mdot
.89624 .99133 Mdot
.34711 .81761 Mdot
.16579 .23774 Mdot
.12538 .20983 Mdot
.35035 .89314 Mdot
.30316 .13438 Mdot
.32319 .8946 Mdot
.17609 .90574 Mdot
.22218 .78693 Mdot
.63257 .39926 Mdot
.28578 .02456 Mdot
.46936 .7123 Mdot
.06827 .92946 Mdot
.20067 .80396 Mdot
.28526 .90245 Mdot
.41939 .71207 Mdot
.28378 .90731 Mdot
.27513 .88734 Mdot
.26411 .74494 Mdot
.42748 .02611 Mdot
.51049 .58236 Mdot
.36411 .80207 Mdot
.31799 .89466 Mdot
.28588 .897 Mdot
.23896 .80824 Mdot
.25324 .02881 Mdot
.19744 .01863 Mdot
.18542 .91974 Mdot
.43998 .68719 Mdot
.33165 .90288 Mdot
.43863 .96832 Mdot
.26757 .96867 Mdot
.20848 .7828 Mdot
.21201 .8013 Mdot
.21037 .80345 Mdot
.31592 .79861 Mdot
.28247 .89752 Mdot
.2624 .73124 Mdot
.21514 .80801 Mdot
.74526 .96108 Mdot
.07996 .7996 Mdot
.25318 .31193 Mdot
.1166 .98422 Mdot
.2 .95767 Mdot
.41115 .96295 Mdot
.42862 .96264 Mdot
.07842 .76483 Mdot
.43285 .07952 Mdot
.38262 .30549 Mdot
.51602 .96205 Mdot
.15363 .62481 Mdot
.32472 .89648 Mdot
.28732 .89223 Mdot
.46844 .33145 Mdot
.04613 .74932 Mdot
.27456 .88558 Mdot
.20817 .91232 Mdot
.14229 .91922 Mdot
.17058 .87285 Mdot
.3349 .98892 Mdot
.36156 .89229 Mdot
.16729 .95311 Mdot
.52288 .72729 Mdot
.44853 .02625 Mdot
.26741 .07989 Mdot
.26264 .83903 Mdot
.25332 .91192 Mdot
.20411 .79376 Mdot
.64018 .65463 Mdot
.27959 .8875 Mdot
.31095 .98412 Mdot
.37884 .95124 Mdot
.40338 .30802 Mdot
.30736 .40596 Mdot
.17663 .67673 Mdot
.21359 .76257 Mdot
.67395 .87048 Mdot
.21346 .66744 Mdot
.20874 .9451 Mdot
.85 .42956 Mdot
.3646 .9071 Mdot
.2878 .02383 Mdot
.28527 .80267 Mdot
.28141 .90512 Mdot
.16495 .93926 Mdot
.60086 .89841 Mdot
.56346 .99322 Mdot
.42382 .12909 Mdot
.10852 .99368 Mdot
.46043 .97196 Mdot
.45105 .98826 Mdot
.79889 .90399 Mdot
.0059 .53832 Mdot
.19879 .76572 Mdot
.2872 .69309 Mdot
.2059 .81049 Mdot
.2498 .86939 Mdot
.30466 .80846 Mdot
.19186 .88395 Mdot
.47428 .20336 Mdot
.2874 .82223 Mdot
.26742 .90914 Mdot
.78787 .59676 Mdot
.26956 .76007 Mdot
.28434 .90224 Mdot
.39498 .89677 Mdot
.39832 .94997 Mdot
.61605 .39931 Mdot
.40152 .97191 Mdot
.22294 .9243 Mdot
.19666 .83301 Mdot
.93575 .79824 Mdot
.98397 .11994 Mdot
.19161 .9052 Mdot
.3587 .10996 Mdot
.13928 .806 Mdot
.9569 .72578 Mdot
.38872 .31698 Mdot
.26626 .89765 Mdot
.29731 .80038 Mdot
.419 .78075 Mdot
.22245 .91014 Mdot
.14374 .81802 Mdot
.45065 .17999 Mdot
.53936 .88856 Mdot
.24865 .86128 Mdot
.26898 .77083 Mdot
.23727 .68862 Mdot
.19372 .81971 Mdot
.79594 .2969 Mdot
.29077 .89776 Mdot
.46994 .70702 Mdot
.04654 .66163 Mdot
.28345 .89397 Mdot
.40827 .96591 Mdot
.25784 .78576 Mdot
.22704 .93019 Mdot
.54804 .70438 Mdot
.27471 .71972 Mdot
.16336 .79344 Mdot
.10878 .00561 Mdot
.81651 .85565 Mdot
.74991 .60638 Mdot
.32541 .75433 Mdot
.4164 .95667 Mdot
.46699 .23828 Mdot
.31937 .85578 Mdot
.34957 .77201 Mdot
.86725 .06854 Mdot
.00437 .80501 Mdot
.36726 .04572 Mdot
.21913 .80744 Mdot
.2088 .75663 Mdot
.30578 .05695 Mdot
.17006 .90236 Mdot
.3005 .79748 Mdot
.18867 .82015 Mdot
.31788 .66098 Mdot
.19458 .83093 Mdot
.30619 .82135 Mdot
.27352 .07298 Mdot
.20843 .94038 Mdot
.28435 .89224 Mdot
.30349 .8861 Mdot
.21007 .01223 Mdot
.02111 .94895 Mdot
.24341 .97313 Mdot
.27619 .87869 Mdot
.22556 .97547 Mdot
.95402 .00021 Mdot
.42647 .96126 Mdot
.96033 .04981 Mdot
.7011 .52415 Mdot
.30144 .93735 Mdot
.18146 .71727 Mdot
.44164 .9476 Mdot
.26599 .52684 Mdot
.26766 .8533 Mdot
.02829 .72097 Mdot
.13503 .78062 Mdot
.72491 .75441 Mdot
.35173 .23196 Mdot
.52501 .68918 Mdot
.42681 .96877 Mdot
.76979 .72352 Mdot
.16488 .97348 Mdot
.34451 .79788 Mdot
.71522 .29883 Mdot
.79012 .37783 Mdot
.17426 .79958 Mdot
.10874 .84365 Mdot
.36148 .8335 Mdot
.28799 .90139 Mdot
.36206 .05827 Mdot
.90645 .88728 Mdot
.28449 .89204 Mdot
.4297 .39007 Mdot
.21012 .80434 Mdot
.21598 .12163 Mdot
.24858 .7738 Mdot
.29948 .90304 Mdot
.03485 .8178 Mdot
.28897 .89473 Mdot
.15367 .94891 Mdot
.08945 .80756 Mdot
.16523 .03608 Mdot
.3439 .02709 Mdot
.15153 .70109 Mdot
.66249 .93538 Mdot
.19806 .81988 Mdot
.95662 .00703 Mdot
.19555 .07122 Mdot
.18283 .80674 Mdot
.46792 .95922 Mdot
.28964 .9007 Mdot
.60824 .38415 Mdot
.28212 .86705 Mdot
.20928 .7542 Mdot
.73105 .77987 Mdot
.47686 .07449 Mdot
.27844 .90953 Mdot
.9043 .97104 Mdot
.18 .94539 Mdot
.73757 .52841 Mdot
.27395 .87717 Mdot
.84855 .23663 Mdot
.48563 .84507 Mdot
.28298 .91068 Mdot
.90384 .72727 Mdot
.60308 .86605 Mdot
.46926 .7915 Mdot
.5373 .14665 Mdot
.81934 .26717 Mdot
.02804 .02973 Mdot
.24598 .99702 Mdot
.96442 .23904 Mdot
.19474 .81249 Mdot
.76852 .91491 Mdot
.25511 .79298 Mdot
.8262 .06546 Mdot
.54391 .0022 Mdot
.25524 .2047 Mdot
.60578 .89509 Mdot
.97622 .51246 Mdot
.42639 .97769 Mdot
.29024 .89665 Mdot
.47107 .86298 Mdot
.14659 .71937 Mdot
.82312 .95353 Mdot
.33487 .84027 Mdot
.28719 .82389 Mdot
.13741 .79653 Mdot
.89428 .96317 Mdot
.3168 .46365 Mdot
.40187 .65815 Mdot
.19354 .93962 Mdot
.19219 .96518 Mdot
.28695 .89862 Mdot
.05784 .60242 Mdot
.66763 .71094 Mdot
.98589 .81017 Mdot
.33323 .6241 Mdot
.08252 .59672 Mdot
.22007 .84484 Mdot
.41435 .89191 Mdot
.29597 .88364 Mdot
.16273 .95223 Mdot
.26716 .54416 Mdot
.02497 .94589 Mdot
.13452 .2134 Mdot
.241 .90851 Mdot
.52675 .55986 Mdot
.24771 .89699 Mdot
.91867 .82588 Mdot
.81389 .90936 Mdot
.17306 .85078 Mdot
.65195 .80423 Mdot
.20251 .97071 Mdot
.24208 .7671 Mdot
.67259 .9555 Mdot
.1896 .96917 Mdot
.41546 .95811 Mdot
.68884 .08128 Mdot
.28372 .00801 Mdot
.95092 .82485 Mdot
.23044 .67125 Mdot
.00723 .78557 Mdot
.94325 .66602 Mdot
.26921 .89288 Mdot
.13929 .79357 Mdot
.66731 .9446 Mdot
.20591 .98237 Mdot
.20686 .99183 Mdot
.22053 .84899 Mdot
.27582 .90502 Mdot
.65263 .01872 Mdot
.61027 .81398 Mdot
.59985 .35982 Mdot
.40625 .27979 Mdot
.21361 .6728 Mdot
.60424 .41296 Mdot
.17885 .85778 Mdot
.35512 .86179 Mdot
.4462 .96715 Mdot
.86451 .85737 Mdot
.68626 .86688 Mdot
.10672 .73197 Mdot
.25362 .99473 Mdot
.60957 .86362 Mdot
.13244 .807 Mdot
.89928 .79586 Mdot
.05927 .80753 Mdot
.34982 .88319 Mdot
.3574 .78243 Mdot
.42704 .92368 Mdot
.31495 .00629 Mdot
.16573 .79116 Mdot
.23291 .82048 Mdot
.25041 .90394 Mdot
.24796 .73368 Mdot
.33344 .89788 Mdot
.16776 .88462 Mdot
.21833 .79385 Mdot
.19303 .67005 Mdot
.34151 .87199 Mdot
.26736 .62642 Mdot
.36639 .88444 Mdot
.61446 .90601 Mdot
.64402 .62251 Mdot
.20696 .89085 Mdot
.17692 .57765 Mdot
.25365 .84415 Mdot
.42907 .81478 Mdot
.20377 .9086 Mdot
.16582 .78812 Mdot
.91515 .52229 Mdot
.40275 .94366 Mdot
.08728 .80301 Mdot
.32074 .89414 Mdot
.41458 .70267 Mdot
.16327 .42971 Mdot
.35765 .85902 Mdot
.34836 .87834 Mdot
.70308 .47122 Mdot
.60475 .75932 Mdot
.31009 .80853 Mdot
.24207 .61509 Mdot
.15541 .57327 Mdot
.27119 .90715 Mdot
.28721 .89412 Mdot
.20838 .83968 Mdot
.30244 .59733 Mdot
.02952 .32555 Mdot
.0719 .00449 Mdot
.1951 .78915 Mdot
.50299 .7846 Mdot
.20415 .75664 Mdot
.11727 .62679 Mdot
.12095 .55253 Mdot
.32036 .83868 Mdot
.34864 .05901 Mdot
.17036 .65057 Mdot
.24212 .98432 Mdot
.32087 .74951 Mdot
.22667 .0185 Mdot
.29438 .05406 Mdot
.28233 .87535 Mdot
.32796 .95727 Mdot
.33118 .88822 Mdot
.56495 .86691 Mdot
.32119 .06006 Mdot
.60171 .81266 Mdot
.31768 .82866 Mdot
.27451 .80774 Mdot
.15724 .93567 Mdot
.16964 .84535 Mdot
.2829 .89996 Mdot
.19593 .31308 Mdot
.54493 .76315 Mdot
.30615 .90132 Mdot
.85465 .74427 Mdot
.20946 .80548 Mdot
.2018 .82228 Mdot
.10147 .80119 Mdot
.21783 .83593 Mdot
.22234 .77672 Mdot
.1995 .64519 Mdot
.18616 .76771 Mdot
.16224 .78377 Mdot
.93039 .57416 Mdot
.272 .06619 Mdot
.95434 .01607 Mdot
.53977 .71653 Mdot
.26184 .79798 Mdot
.83996 .81996 Mdot
.08888 .96983 Mdot
.22689 .91296 Mdot
.39199 .31082 Mdot
.27436 .79634 Mdot
.15048 .83454 Mdot
.18008 .38331 Mdot
.07885 .00466 Mdot
.19778 .82791 Mdot
.27439 .90618 Mdot
.26831 .90891 Mdot
.57244 .79838 Mdot
.36305 .00036 Mdot
.53782 .73543 Mdot
.26403 .86926 Mdot
.19128 .81743 Mdot
.35731 .88686 Mdot
.4303 .15942 Mdot
.28238 .00234 Mdot
.3926 .93291 Mdot
.33882 .08092 Mdot
.27594 .87734 Mdot
.87973 .57872 Mdot
.21443 .79897 Mdot
.26646 .4346 Mdot
.08545 .81397 Mdot
.30823 .84535 Mdot
.19933 .82134 Mdot
.36326 .86828 Mdot
.23507 .91554 Mdot
.44184 .54508 Mdot
.18766 .81312 Mdot
.20761 .78545 Mdot
.43627 .96918 Mdot
.29421 .60712 Mdot
.96084 .66909 Mdot
.21389 .81948 Mdot
.85435 .75061 Mdot
.27709 .88571 Mdot
.25178 .86251 Mdot
.33995 .79149 Mdot
.24208 .89499 Mdot
.22229 .76457 Mdot
.15952 .52993 Mdot
.33906 .55256 Mdot
.94702 .8634 Mdot
.35809 .00325 Mdot
.69429 .90901 Mdot
.35515 .93416 Mdot
.21473 .7977 Mdot
.26397 .75411 Mdot
.08839 .9866 Mdot
.43155 .95863 Mdot
.4283 .92455 Mdot
.66521 .59834 Mdot
.21596 .96005 Mdot
.65113 .84161 Mdot
.27442 .31636 Mdot
.24982 .5043 Mdot
.04715 .93835 Mdot
.20838 .96438 Mdot
.92371 .08215 Mdot
.30678 .8147 Mdot
.38361 .88037 Mdot
.32332 .91034 Mdot
.42944 .84719 Mdot
.09625 .80699 Mdot
.36233 .98949 Mdot
.32349 .72968 Mdot
.5615 .6464 Mdot
.29399 .9467 Mdot
.03663 .77404 Mdot
.40865 .6359 Mdot
.58311 .78152 Mdot
.27422 .0058 Mdot
.42342 .95794 Mdot
.40395 .9656 Mdot
.20528 .7032 Mdot
.57807 .80461 Mdot
.24235 .82206 Mdot
.21044 .90107 Mdot
.16362 .8443 Mdot
.15959 .58817 Mdot
.45834 .80041 Mdot
.38218 .82718 Mdot
.27132 .99642 Mdot
.26181 .91343 Mdot
.42568 .23831 Mdot
.40504 .48103 Mdot
.38272 .00402 Mdot
.19791 .81972 Mdot
.29184 .89992 Mdot
.12055 .77894 Mdot
.31344 .59833 Mdot
.41015 .6995 Mdot
.44801 .38209 Mdot
.45255 .04752 Mdot
.09443 .02687 Mdot
.1749 .8622 Mdot
.21179 .81632 Mdot
.1878 .95143 Mdot
.85625 .08878 Mdot
.42328 .96749 Mdot
.09398 .19746 Mdot
.20341 .98681 Mdot
.28198 .91126 Mdot
.97702 .97228 Mdot
.22423 .82286 Mdot
.41437 .92321 Mdot
.27255 .86799 Mdot
.54381 .81201 Mdot
.05447 .98312 Mdot
.28851 .89097 Mdot
.55003 .99295 Mdot
.08437 .01594 Mdot
.2737 .90573 Mdot
.187 .30237 Mdot
.30849 .92114 Mdot
.73072 .7649 Mdot
.07871 .96408 Mdot
.28227 .77131 Mdot
.11252 .05702 Mdot
.26251 .86001 Mdot
.88915 .57654 Mdot
.53458 .65774 Mdot
.04451 .06805 Mdot
.91922 .26835 Mdot
.22246 .9671 Mdot
.28563 .90291 Mdot
.30655 .90106 Mdot
.32982 .07949 Mdot
.19314 .83034 Mdot
.9139 .52204 Mdot
.21375 .656 Mdot
.28447 .79286 Mdot
.93851 .68074 Mdot
.72232 .83991 Mdot
.3554 .60744 Mdot
.90045 .06806 Mdot
.16241 .00862 Mdot
.63405 .83348 Mdot
.42029 .02271 Mdot
.20778 .79761 Mdot
.25759 .55155 Mdot
.02681 .45273 Mdot
.27644 .90874 Mdot
.2713 .88954 Mdot
.2486 .77343 Mdot
.37673 .0672 Mdot
.36746 .38054 Mdot
.24655 .54981 Mdot
.25902 .99474 Mdot
.06785 .92941 Mdot
.42987 .72997 Mdot
.73544 .87476 Mdot
.15129 .98451 Mdot
.26454 .8943 Mdot
.78019 .29999 Mdot
.35375 .85631 Mdot
.39798 .70293 Mdot
.12776 .23218 Mdot
.13944 .81681 Mdot
.26927 .88638 Mdot
.27177 .85469 Mdot
.2981 .75486 Mdot
.26501 .6501 Mdot
.18336 .97497 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l00002ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0;ooooo`?o00002Oooool2o`0000Co
oooo00?o0000ooooooooool03Oooool00ol0003oooooo`000003o`0000Cooooo0_l00005ooooo`03
o`000?oooooooooo00cooooo1?l0000=ooooo`03o`000?oooooooooo00_ooooo0ol0000@ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00Gooooo0_l00006ooooo`?o00003_ooool00ol0003oooooooooo`02ooooo`00
7_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo0_l000001?oooooo0000
o`000?ooool2o`0000;ooooo00Co0000ooooool0003o00003?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00_ooooo0ol00006ooooo`;o000000?oooooo`000?l000001?ooool01?l0
003oooooooooooooool2o`0000[ooooo00Co0000ooooool0003o00001_ooool2o`0000Gooooo00?o
0000ooooooooool03?ooool2o`0000oooooo00?o0000ooooooooool02oooool3o`00013ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool01Oooool2o`0000Kooooo00Co0000ooooool0003o00003Oooool00ol0003ooooo
ooooo`02ooooo`007_ooool00ol0003oooooooooo`0Fooooo`;o00001oooool2o`00013ooooo0_l0
0009ooooo`;o00005oooool2o`000003ooooool0003o000000Sooooo0_l00035ooooo`;o00002?oo
ool2o`0001;ooooo000Nooooo`03o`000?oooooooooo037ooooo0_l00009ooooo`;o00000_ooool2
o`00013ooooo0_l00004ooooo`;o00002?ooool2o`000<Gooooo0_l0000Looooo`007_ooool00ol0
003oooooooooo`0Gooooo`;o00009oooool2o`00013ooooo0_l0000>ooooo`;o0000=oooool2o`00
09;ooooo0_l000000ooooooo0000o`00000Cooooo`007_ooool00ol0003oooooooooo`0Booooo`;o
00000oooool2o`0002?ooooo0_l00008ooooo`;o0000Doooool2o`0003?ooooo0_l0001Mooooo`;o
000000?oooooo`000?l000004oooool001kooooo00?o0000ooooooooool04_ooool2o`0002Sooooo
0_l00008ooooo`;o0000?Oooool2o`0004Wooooo0_l00014ooooo`;o0000;oooool001kooooo00?o
0000ooooooooool0FOooool2o`0002[ooooo0_l0001Jooooo`;o0000<oooool2o`0002oooooo000N
ooooo`03o`000?oooooooooo01_ooooo0_l0000aooooo`;o00002Oooool2o`00017ooooo0_l0000I
ooooo`;o00001Oooool2o`00057ooooo0_l0001Tooooo`007_ooool00ol0003oooooooooo`05oooo
o`;o00005?ooool2o`00037ooooo0_l0000=ooooo`;o00003Oooool2o`0001Wooooo0_l00005oooo
o`;o0000]oooool001kooooo00?o0000ooooooooool01Oooool2o`0005Kooooo0_l0000@ooooo`;o
0000e_ooool001kooooo00?o0000ooooooooool0<_ooool2o`0003_ooooo0_l0002:ooooo`;o0000
B_ooool001kooooo00?o0000ooooooooool0<_ooool2o`0004Kooooo0_l0001oooooo`;o0000;?oo
ool2o`0001cooooo000Nooooo`03o`000?oooooooooo02[ooooo0_l0000>ooooo`;o0000?_ooool2
o`000:gooooo0_l0000Looooo`007_ooool00ol0003oooooooooo`0Zooooo`;o00003_ooool2o`00
03Oooooo0_l0000Jooooo`;o0000]_ooool001kooooo00?o0000ooooooooool0Loooool2o`0001[o
oooo0_l0002Sooooo`;o00004Oooool001kooooo0_l0003oooooocKooooo0_l0000Aooooo`007_oo
ool00ol0003oooooooooo`13ooooo`;o00005oooool2o`0000Cooooo0_l0000>ooooo`;o0000dooo
ool001kooooo00?o0000ooooooooool04_ooool2o`0000cooooo0_l0000Qooooo`;o00005oooool2
o`000004ooooool0003o0000ooooo`;o00002Oooool2o`0000?ooooo0_l0003Cooooo`007_ooool0
0ol0003oooooooooo`0Booooo`;o00003?ooool2o`0003gooooo0_l000000ooooooo0000o`000002
o`0000Oooooo0_l00003ooooo`;o0000doooool001kooooo00?o0000ooooooooool0H_ooool4o`00
0:;ooooo0_l0000mooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o0000B?ooool2o`00023o
oooo0_l0002@ooooo`;o00003?ooool2o`0000Sooooo0ol0000Tooooo`007_ooool00ol0003ooooo
ooooo`0:ooooo`;o0000;oooool2o`0001Oooooo0_l0000Pooooo`;o00008_ooool2o`0007[ooooo
0_l00008ooooo`?o00009?ooool001kooooo00?o0000ooooooooool0:_ooool2o`0000oooooo0_l0
000Hooooo`;o00006oooool4o`00027ooooo0_l000000ooooooo0000o`00002[ooooo`007_ooool0
0ol0003oooooooooo`0Zooooo`;o0000:Oooool2o`0001?ooooo0_l00006ooooo`Co00008Oooool2
o`000:kooooo000Nooooo`03o`000?oooooooooo05?ooooo0_l0000Booooo`;o000000?oooooo`00
0?l000007Oooool2o`00057ooooo0_l0001Yooooo`007_ooool00ol0003oooooooooo`1Cooooo`;o
00004_ooool2o`000003ooooool0003o000001gooooo0_l0001Aooooo`;o0000B_ooool2o`0001go
oooo000Nooooo`03o`000?oooooooooo06_ooooo0_l0001]ooooo`;o0000C?ooool2o`0001gooooo
000Nooooo`03o`000?oooooooooo06_ooooo0_l0001]ooooo`;o0000=_ooool2o`0003?ooooo000N
ooooo`03o`000?oooooooooo0?oooooo4oooool2o`0003?ooooo000Nooooo`03o`000?oooooooooo
0?oooooo5oooool2o`0002oooooo000Nooooo`03o`000?oooooooooo06?ooooo0_l00004ooooo`;o
0000Zoooool2o`0002oooooo000Nooooo`;o0000I?ooool2o`0000Cooooo0_l0003Looooo`007_oo
ool00ol0003oooooooooo`3ooooooaKooooo0_l0000`ooooo`007_ooool00ol0003oooooooooo`3o
oooooaKooooo0_l0000`ooooo`007_ooool00ol0003oooooooooo`1aooooo`;o0000e?ooool001ko
oooo00?o0000ooooooooool0LOooool2o`0002oooooo0_l0002Sooooo`007_ooool00ol0003ooooo
ooooo`0;ooooo`;o0000K?ooool2o`0002Oooooo0_l0002Sooooo`007_ooool00ol0003ooooooooo
o`0;ooooo`;o0000K?ooool2o`0009gooooo0_l0000Rooooo`;o00002Oooool001kooooo00?o0000
ooooooooool0@_ooool2o`000=Cooooo0_l0000Rooooo`;o00002Oooool001kooooo00Co0000oooo
ool0003o0000@Oooool2o`000?oooooo1?ooool001kooooo00Co0000ooooool0003o0000QOooool2
o`000;oooooo000Nooooo`03o`000?oooooooooo08Kooooo0_l0002oooooo`007_ooool00ol0003o
ooooooooo`1Nooooo`;o0000ioooool001kooooo00?o0000ooooooooool03oooool2o`0004gooooo
0_l0003Wooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o0000oooooolgooooo`007_ooool0
1?l0003oooooooooooooool2o`000?ooooooAOooool001kooooo00Co0000oooooooooooooooo0_l0
002Xooooo`;o0000V_ooool001kooooo0_l0002/ooooo`;o0000V_ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`1booooo`;o0000doooool001kooooo
00?o0000ooooooooool0L_ooool2o`0001Cooooo0_l0002mooooo`007_ooool00ol0003ooooooooo
o`28ooooo`;o0000_Oooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0:?ooool2o`000?oooooo7_ooool001kooooo00?o0000ooooooooool0:?oo
ool2o`000?oooooo7_ooool001kooooo00?o0000ooooooooool0O?ooool2o`00013ooooo0_l0002g
ooooo`007_ooool00ol0003oooooooooo`03ooooo`;o0000Moooool2o`00013ooooo0_l00008oooo
o`;o0000[Oooool001kooooo00?o0000ooooooooool00oooool2o`0009?ooooo0_l0002]ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Ko
oooo00?o0000ooooooooool06_ooool2o`000?oooooo;?ooool000?ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0000Jooooo`;o0000Doooool2o`000:Wo
oooo0_l0000[ooooo`000oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^
k^h01_ooool00ol0003oooooooooo`1_ooooo`;o00009Oooool2o`0008;ooooo0_l0000[ooooo`00
0oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003o
ooooooooo`1?ooooo`;o0000AOooool2o`000:oooooo0003ooooo`05oa0@4?ooooooooooooooool@
41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Gooooo0_l0000Xooooo`;o
0000m_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRH
V?l@41001_ooool00ol0003oooooooooo`0Uooooo`;o000000?oooooo`000?l00000oooooolNoooo
o`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006
ooooo`03o`000?oooooooooo02Sooooo0_l0003Gooooo`;o0000A?ooool001kooooo00?o0000oooo
ooooool0ooooool2ooooo`;o0000A?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0@?ooool2o`0002cooooo0_l0003Gooooo`007_ooool00ol0
003oooooooooo`0Uooooo`;o00006Oooool2o`0002cooooo0_l00006ooooo`;o0000coooool001ko
oooo00?o0000ooooooooool09Oooool2o`0000_ooooo0_l0000aooooo`;o00003oooool2o`0000[o
oooo0_l0002<ooooo`;o0000=Oooool001kooooo00?o0000ooooooooool0<_ooool2o`00037ooooo
0_l0000Kooooo`;o00000_ooool2o`0000cooooo0_l0001jooooo`;o00008oooool2o`00013ooooo
000Nooooo`03o`000?oooooooooo08Kooooo0_l0000<ooooo`;o00009?ooool2o`0007Wooooo0_l0
000@ooooo`007_ooool00ol0003oooooooooo`19ooooo`;o0000Koooool2o`0008_ooooo000Noooo
o`03o`000?oooooooooo04Wooooo0_l0003looooo`007_ooool2o`000?ooooooBOooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`17ooooo`;o00009Oooool2o`0008Sooooo0_l0000<ooooo`;o
00007oooool2o`0001kooooo000Nooooo`03o`000?oooooooooo04Oooooo0_l0000Uooooo`;o0000
R?ooool2o`0000_ooooo0ol0000Oooooo`;o00007_ooool001kooooo00?o0000ooooooooool0oooo
ool6ooooo`;o0000@?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`20ooooo`;o0000aOooool001kooooo00?o0000ooooooooool0P?ooool2o`000<Go
oooo000Nooooo`03o`000?oooooooooo02Oooooo0_l0003ooooooaoooooo000Nooooo`03o`000?oo
oooooooo02Oooooo0_l0003ooooooaoooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0Soooool2o`0007Oooooo0_l0000mooooo`007_ooool00ol0003o
ooooooooo`2?ooooo`;o0000Doooool2o`0001Wooooo0_l00007ooooo`;o0000?Oooool001kooooo
0_l0000jooooo`;o0000ZOooool2o`0001Cooooo0_l00003ooooo`;o0000A_ooool001kooooo00?o
0000ooooooooool0>Oooool2o`0003gooooo0_l00020ooooo`;o0000Boooool001kooooo00?o0000
ooooooooool0N?ooool2o`0000Gooooo0_l00036ooooo`007_ooool00ol0003oooooooooo`0noooo
o`;o00003_ooool2o`0002_ooooo0_l00002ooooo`;o0000a_ooool001kooooo00?o0000oooooooo
ool02Oooool2o`00037ooooo1?l0000>ooooo`;o0000:oooool2o`000<[ooooo000Nooooo`03o`00
0?oooooooooo00Wooooo0_l0000aooooo`;o00005oooool2o`0002?ooooo0_l0003;ooooo`007_oo
ool00ol0003oooooooooo`1Eooooo`;o00008oooool2o`000<_ooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool01Oooool2o`000?oooooo@Oooool001ko
oooo00?o0000ooooooooool01Oooool2o`000?oooooo@Oooool001kooooo00?o0000ooooooooool0
BOooool2o`0004Wooooo0_l0002aooooo`007_ooool00ol0003oooooooooo`19ooooo`;o0000BOoo
ool2o`000;7ooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0??ooool2o`000?oooooo2_ooool001kooooo00?o0000ooooooooool0??ooool2o`000?oo
oooo2_ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0;oooooo0_l00026ooooo`007_ooool00ol0003ooooo
ooooo`2oooooo`;o0000Q_ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`1;ooooo`;o0000
/?ooool2o`0002cooooo0_l0000Jooooo`007_ooool00ol0003oooooooooo`1;ooooo`;o00009_oo
ool2o`0001Wooooo0_l0001]ooooo`;o0000;?ooool2o`0001[ooooo000Nooooo`03o`000?oooooo
oooo03Kooooo0_l0000kooooo`;o00006Oooool2o`0000Oooooo0_l0000Yooooo`;o0000Poooool0
01kooooo00?o0000ooooooooool0=_ooool2o`0005oooooo0_l0000Yooooo`;o0000C_ooool2o`00
03?ooooo000Nooooo`03o`000?oooooooooo08Sooooo0_l00028ooooo`;o0000<oooool000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Co
oooo00?o0000ooooooooool0R?ooool2o`000;gooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodSo
oooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol00034ooooo`;o
00001?ooool2o`0007_ooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4Co
gMgMooooool00007ooooo`03o`000?oooooooooo01oooooo0_l0002Sooooo`;o00001?ooool2o`00
07_ooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo01oooooo0_l0000oooooo`;o0000iOooool000?ooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0H?ooool2
o`000>Gooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007
ooooo`03o`000?oooooooooo0<3ooooo0_l00025ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`30ooooo`;o0000<_ooool2
o`00057ooooo000Nooooo`03o`000?oooooooooo0?Cooooo0_l00004ooooo`;o0000Boooool001ko
oooo00?o0000ooooooooool0n_ooool2o`0004_ooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`0a
ooooo`;o0000gOooool2o`0003Gooooo000Nooooo`03o`000?oooooooooo037ooooo0_l0000Poooo
o`;o00006_ooool2o`0009oooooo0_l0000eooooo`007_ooool00ol0003oooooooooo`1Cooooo`;o
00006_ooool2o`000=Kooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool04?ooool2o`000?oooooo=_ooool001kooooo00?o0000ooooooooool04?ooool2
o`000?oooooo=_ooool001kooooo00?o0000ooooooooool0j_ooool2o`0005_ooooo000Nooooo`;o
00001_ooool2o`000>?ooooo0_l00006ooooo`;o0000Doooool001kooooo00?o0000ooooooooool0
1Oooool2o`0006_ooooo0_l0001nooooo`;o0000Doooool001kooooo00?o0000ooooooooool0L_oo
ool2o`000=?ooooo000Nooooo`03o`000?oooooooooo07_ooooo0_l0003:ooooo`007_ooool00ol0
003oooooooooo`1Sooooo`;o00005_ooool2o`000<[ooooo000Nooooo`03o`000?oooooooooo06?o
oooo0_l0003Rooooo`007_ooool00ol0003oooooooooo`3Pooooo`;o0000IOooool001kooooo00?o
0000ooooooooool0h?ooool2o`0006Gooooo000Nooooo`03o`000?oooooooooo0;Cooooo0_l0002A
ooooo`007_ooool00ol0003oooooooooo`20ooooo`;o0000<_ooool2o`00097ooooo000Nooooo`03
o`000?oooooooooo083ooooo0_l00035ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo04;ooooo0_l00035ooooo`;o0000??ooool001kooooo00?o0000
ooooooooool0@_ooool2o`0009Oooooo0_l0000/ooooo`;o0000??ooool001kooooo00?o0000oooo
ooooool0foooool2o`0006[ooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo04gooooo0_l0003hooooo`007_ooool0
0ol0003oooooooooo`1=ooooo`;o0000n?ooool001kooooo00?o0000ooooooooool0<_ooool2o`00
00;ooooo0_l0003ooooooa3ooooo000Nooooo`03o`000?oooooooooo03;ooooo0_l00002ooooo`;o
0000ooooool2ooooo`;o00003?ooool001kooooo00?o0000ooooooooool0oooooolHooooo`;o0000
8?ooool2o`0000cooooo000Nooooo`03o`000?oooooooooo0?oooooo6?ooool2o`0002kooooo000N
ooooo`03o`000?oooooooooo04[ooooo0_l0002Dooooo`;o0000@oooool2o`00023ooooo000Noooo
o`03o`000?oooooooooo03Sooooo0_l0000@ooooo`;o00001_ooool2o`0008cooooo0_l00013oooo
o`;o00008?ooool001kooooo00?o0000ooooooooool0<?ooool2o`0000Kooooo0_l0000Hooooo`;o
0000V?ooool2o`0005Wooooo000Nooooo`03o`000?oooooooooo033ooooo0_l0002jooooo`;o0000
FOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`0002Sooooo0_l0003o
oooooakooooo000Nooooo`?o0000:?ooool2o`000?oooooo7_ooool001kooooo00?o0000oooooooo
ool0Doooool2o`0003Oooooo0_l0002iooooo`007_ooool00ol0003oooooooooo`1>ooooo`;o0000
0oooool2o`0003Oooooo0_l0001Sooooo`;o0000E?ooool001kooooo0_l0001=ooooo`Ko0000Wooo
ool2o`0005Cooooo000Nooooo`03o`000?oooooooooo02?ooooo0_l0000Wooooo`;o00000_ooool3
o`0001Oooooo0_l0003Kooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o0000;?ooool2o`00
01Oooooo0_l0003Kooooo`007_ooool00ol0003oooooooooo`1[ooooo`;o0000>_ooool2o`0004co
oooo0_l0001@ooooo`007_ooool00ol0003oooooooooo`1[ooooo`;o0000>_ooool2o`0004cooooo
0_l0001@ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0;_ooool2o`000?oooooo6?ooool001ko
oooo00?o0000ooooooooool0;_ooool2o`000>gooooo0_l0000;ooooo`;o00006oooool001kooooo
00?o0000ooooooooool04oooool2o`00023ooooo0_l0000iooooo`;o0000Z?ooool2o`000003oooo
ool0003o000000_ooooo0_l0000Kooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o00008?oo
ool2o`0003Wooooo0_l0000`ooooo`;o0000M_ooool2o`0002_ooooo000Nooooo`03o`000?oooooo
oooo0:;ooooo0_l0002Sooooo`007_ooool00ol0003oooooooooo`0`ooooo`;o0000Ioooool2o`00
0:cooooo000Nooooo`03o`000?oooooooooo033ooooo0_l0001Wooooo`;o0000[?ooool000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
00Kooooo00?o0000ooooooooool00oooool2o`0001[ooooo0_l0003oooooobOooooo0003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06
ooooo`03o`000?oooooooooo00?ooooo0_l0000Booooo`;o00001_ooool2o`0003gooooo0_l0002L
ooooo`;o0000BOooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooo
ooooooooool000001_ooool3o`0001Oooooo0_l00015ooooo`;o00000_ooool2o`00073ooooo0_l0
000Vooooo`;o0000BOooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0?ooooo`;o0000;Oooool2o`0002;ooooo
0_l0000oooooo`;o0000;oooool2o`00077ooooo0003ooooo`05o`000?ooooooooooooooool00000
2oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00Co0000oooooooooooooooo0_l00004oooo
o`;o00001_ooool2o`0002gooooo0_l0000Looooo`;o0000AOooool2o`0004_ooooo0_l00017oooo
o`;o00003?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo
00Sooooo00Co0000oooooooooooooooo0_l00004ooooo`;o0000@Oooool2o`00013ooooo0_l0000A
ooooo`;o0000Ooooool2o`0004Oooooo0_l0000<ooooo`000oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`1:ooooo`;o00008oooool2
o`000=Kooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@
4106ooooo`03o`000?oooooooooo04_ooooo0_l0003jooooo`007_ooool00ol0003oooooooooo`1;
ooooo`;o0000n_ooool001kooooo00?o0000ooooooooool0cOooool2o`0007Sooooo000Nooooo`03
o`000?oooooooooo02kooooo0_l0000Tooooo`;o00004_ooool2o`0002oooooo0_l0000booooo`;o
0000N?ooool001kooooo00?o0000ooooooooool08_ooool2o`0000[ooooo0_l0000Sooooo`?o0000
4_ooool2o`0002oooooo0_l0002/ooooo`007_ooool00ol0003oooooooooo`0Rooooo`;o0000;ooo
ool2o`0000Sooooo0_l0003Xooooo`007_ooool00ol0003oooooooooo`1Aooooo`;o00002_ooool2
o`0000Gooooo0_l0003Qooooo`007_ooool00ol0003oooooooooo`1Aooooo`;o00004Oooool2o`00
01_ooooo0_l00034ooooo`007_ooool00ol0003oooooooooo`1Kooooo`;o00009?ooool2o`000<Co
oooo000Nooooo`03o`000?oooooooooo05_ooooo0_l0003Zooooo`007_ooool00ol0003ooooooooo
o`0mooooo`;o00007Oooool2o`0005Cooooo0_l0002Cooooo`007_ooool00ol0003oooooooooo`0m
ooooo`;o00004oooool2o`0000Sooooo0_l00018ooooo`;o00002_ooool2o`0009?ooooo000Noooo
o`;o0000=?ooool2o`0001?ooooo0_l00008ooooo`;o00009Oooool2o`0002_ooooo0_l0002Ooooo
o`007_ooool00ol0003oooooooooo`0cooooo`;o00003?ooool2o`0000Gooooo0_l0000_ooooo`;o
0000DOooool2o`0007Wooooo000Nooooo`03o`000?oooooooooo047ooooo0_l0000looooo`;o0000
:Oooool2o`00023ooooo0_l0001iooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o0000E_oo
ool2o`0001[ooooo0_l0000Yooooo`;o0000Voooool001kooooo00?o0000ooooooooool02oooool2
o`0005Kooooo0_l0003Rooooo`007_ooool00ol0003oooooooooo`11ooooo`;o00004?ooool2o`00
00Sooooo0_l0003@ooooo`;o00005_ooool001kooooo00?o0000ooooooooool0>oooool2o`0000Co
oooo0_l00004ooooo`;o00002_ooool2o`0000Sooooo0_l0003@ooooo`;o00000oooool2o`00017o
oooo000Nooooo`03o`000?oooooooooo03_ooooo0_l00004ooooo`;o00001?ooool3o`0005[ooooo
0_l0001_ooooo`;o00007Oooool2o`00017ooooo000Nooooo`03o`000?oooooooooo03Gooooo0_l0
000:ooooo`;o00001Oooool2o`0000Wooooo0_l0001?ooooo`;o0000Koooool2o`00033ooooo000N
ooooo`03o`000?oooooooooo03Gooooo0_l00007ooooo`;o00004oooool2o`000=Sooooo0_l0000H
ooooo`007_ooool00ol0003oooooooooo`0nooooo`;o00007Oooool2o`000003ooooool0003o0000
08Oooooo0_l00012ooooo`;o00004?ooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo05go
oooo0_l000000ooooooo0000o`00000Yooooo`;o0000G?ooool2o`0005Cooooo0_l00006ooooo`00
7_ooool00ol0003oooooooooo`19ooooo`;o0000@?ooool2o`0001[ooooo0_l0002Nooooo`007_oo
ool00ol0003oooooooooo`03ooooo`;o0000A?ooool2o`0000kooooo0_l0001<ooooo`;o0000Q?oo
ool2o`0001Sooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0001Dooooo`;o0000Eoooool2
o`0007Wooooo0_l0000Hooooo`007_ooool00ol0003oooooooooo`21ooooo`;o0000;oooool2o`00
09?ooooo000Nooooo`;o0000;_ooool2o`0001Cooooo0_l0000looooo`Co0000Qoooool2o`0003Wo
oooo000Nooooo`03o`000?oooooooooo02gooooo0_l0000@ooooo`;o00000_ooool2o`0000;ooooo
0_l0000dooooo`;o00001?ooool2o`0002Wooooo0_l0001Looooo`;o0000>Oooool001kooooo00?o
0000ooooooooool0<_ooool2o`0000_ooooo0_l00006ooooo`;o0000=?ooool2o`0001Kooooo0_l0
000Gooooo`;o00000oooool2o`0009;ooooo000Nooooo`03o`000?oooooooooo02?ooooo0_l0000;
ooooo`Co00004?ooool2o`0004oooooo0_l0000Looooo`;o00008?ooool2o`00073ooooo000Noooo
o`03o`000?oooooooooo02?ooooo0_l0000;ooooo`;o00004_ooool2o`0000Kooooo0_l0000Uoooo
o`;o00003oooool2o`0000kooooo0_l0000oooooo`;o0000L?ooool001kooooo00?o0000oooooooo
ool0=oooool2o`0001?ooooo0_l0000Uooooo`;o00003oooool2o`0000kooooo0_l0000Eooooo`;o
0000V_ooool001kooooo00?o0000ooooooooool01Oooool2o`0002Gooooo0_l00009ooooo`;o0000
1_ooool2o`0001Cooooo0_l0000Aooooo`;o0000@Oooool2o`0004[ooooo0_l0001>ooooo`007_oo
ool00ol0003oooooooooo`05ooooo`;o00009Oooool2o`00017ooooo0_l0000Dooooo`;o00000_oo
ool2o`0000gooooo0_l00009ooooo`;o0000=oooool2o`0004Sooooo0ol0001>ooooo`007_ooool0
0ol0003oooooooooo`0Yooooo`;o0000:_ooool2o`0000;ooooo0_l0000Hooooo`;o0000<Oooool2
o`0000Cooooo0_l00018ooooo`;o0000:_ooool2o`0000oooooo0_l0000Booooo`007_ooool00ol0
003oooooooooo`0Yooooo`;o0000:_ooool2o`0000kooooo0_l00008ooooo`;o00005oooool2o`00
01cooooo0_l0001jooooo`;o00003oooool2o`0001;ooooo000Nooooo`03o`000?oooooooooo01oo
oooo0_l0000`ooooo`;o00004_ooool2o`0000Sooooo0_l0000Gooooo`;o0000:Oooool2o`0000oo
oooo0_l00021ooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o0000:oooool2o`0000?ooooo
0_l0001Hooooo`;o00000_ooool2o`0000;ooooo0_l0000?ooooo`;o0000POooool001kooooo00?o
0000ooooooooool0C?ooool2o`0000cooooo0_l0001?ooooo`;o00000_ooool2o`0009Kooooo000N
ooooo`03o`000?oooooooooo05[ooooo0_l0003[ooooo`007_ooool00ol0003oooooooooo`0Ioooo
o`;o0000:?ooool2o`0000cooooo0ol0000Booooo`;o0000Z_ooool2o`0003?ooooo000Nooooo`03
o`000?oooooooooo01Wooooo0_l0000Xooooo`;o00003?ooool3o`0001;ooooo0_l0002Zooooo`;o
0000<oooool001kooooo0_l0000<ooooo`;o00002?ooool2o`0003cooooo0_l0000?ooooo`;o0000
1?ooool2o`000:Kooooo0_l0000cooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o00002?oo
ool2o`0000Gooooo0_l0000Rooooo`;o00004?ooool3o`0000Sooooo0_l00005ooooo`Co00000_oo
ool2o`0004[ooooo0_l0000`ooooo`;o0000:?ooool2o`0003?ooooo000Nooooo`03o`000?oooooo
oooo01cooooo0_l0000Pooooo`Co00003_ooool4o`0000Gooooo0_l00002ooooo`;o00001oooool2
o`0004kooooo0_l0000`ooooo`;o0000GOooool001kooooo00?o0000ooooooooool06_ooool2o`00
02;ooooo1?l0000>ooooo`;o00000_ooool2o`0000?ooooo0_l0001Uooooo`;o0000QOooool001ko
oooo00?o0000ooooooooool06_ooool2o`0001gooooo0_l00006ooooo`;o00004Oooool2o`0005Oo
oooo0_l0000Aooooo`;o0000QOooool001kooooo00?o0000ooooooooool05Oooool2o`00023ooooo
1?l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000
o`00001Pooooo`;o0000>_ooool2o`0005cooooo000Nooooo`03o`000?oooooooooo01Gooooo0_l0
000Pooooo`Go000000?oooooo`000?l000000oooool4o`0000;ooooo0_l000000ooooooo0000o`00
0002o`0009[ooooo0_l0001Looooo`007_ooool00ol0003oooooooooo`0dooooo`;o00000_ooool4
o`0000Cooooo1?l00009ooooo`;o00001?ooool2o`0000?ooooo0_l0000Dooooo`;o0000eoooool0
01kooooo00?o0000ooooooooool02?ooool2o`0002[ooooo0_l00002ooooo`;o00001_ooool2o`00
00_ooooo0_l00004ooooo`;o00000oooool2o`0001Cooooo0_l0000gooooo`;o0000W_ooool001ko
oooo00?o0000ooooooooool02?ooool2o`0001Wooooo0_l0000=ooooo`;o00001?ooool2o`0000[o
oooo0_l00007ooooo`;o0000<oooool2o`0002?ooooo0_l0002Nooooo`007_ooool00ol0003ooooo
ooooo`0Sooooo`;o00000oooool2o`0000Sooooo0ol00003ooooo`;o00002_ooool2o`0000oooooo
0_l0000Iooooo`;o00004?ooool4o`0003?ooooo0_l0000_ooooo`;o0000Foooool001kooooo0ol0
000Xooooo`;o00001oooool4o`0000[ooooo0ol0000=ooooo`?o00000oooool2o`0000?ooooo0_l0
000Dooooo`;o00004_ooool2o`0001Wooooo0_l0000Hooooo`;o0000;oooool2o`0005_ooooo000N
ooooo`?o00003?ooool2o`0002?ooooo0ol0000;ooooo`?o00000_ooool3o`0000Sooooo0ol00008
ooooo`;o00003_ooool2o`0003?ooooo0_l0002Vooooo`007_ooool00ol0003oooooooooo`0<oooo
o`;o00008_ooool4o`0000Gooooo1?l00004ooooo`;o000000Coooooo`000?l0003o00008oooool2
o`0002Sooooo0_l00005ooooo`;o00007oooool2o`0000Wooooo0_l0001nooooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_oo
ool00ol0003oooooooooo`0Yooooo`;o00001Oooool4o`0000Gooooo1?l000001?oooooo0000o`00
0?ooool4o`0000Gooooo0_l00003ooooo`;o00000_ooool4o`000003ooooool0003o0000013ooooo
0_l0000Xooooo`;o00001Oooool2o`00013ooooo0_l0000=ooooo`;o00002Oooool2o`0007kooooo
0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?oooooo
V9RHob4Q8@06ooooo`03o`000?oooooooooo02Wooooo0_l00006ooooo`;o00002oooool3o`000004
ooooool0003o0000o`0000Gooooo0_l00003ooooo`So000000?oooooo`000?l000001?ooool2o`00
00_ooooo0ol0000nooooo`?o0000LOooool2o`0002Gooooo0003ooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0000Fooooo`;o00002_ooool2
o`0000Gooooo0_l0000:ooooo`;o00002?ooool2o`000003ooooool0003o000000?o00000_ooool2
o`0000Gooooo0ol00002ooooo`;o00001_ooool3o`0000?ooooo0_l00006ooooo`?o00008oooool2
o`0001Wooooo0_l00008ooooo`;o0000J?ooool2o`0000Oooooo0_l000000ooooooo0000o`00000I
ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo01Kooooo1?l00003ooooo`;o00000oooool2o`00017ooooo0_l0
0006ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000002ooooo`;o00000ooo
ool2o`0000Wooooo0_l00002ooooo`;o00001?ooool2o`0000gooooo0_l0000Mooooo`;o00008ooo
ool2o`00077ooooo0_l000000ooooooo0000o`00000Iooooo`000oooool01Ol0003ooooooooooooo
oooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`;o00006Oooool2o`000003oooo
ool0003o000000;o00002?ooool4o`0000cooooo0_l000001?oooooo0000o`000?ooool2o`000004
ooooool0003o0000o`0000;ooooo0_l00007ooooo`;o000000?oooooo`000?l000001_ooool2o`00
01Oooooo0_l00014ooooo`;o00005_ooool2o`0007Gooooo0003ooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo0_l0000@ooooo`;o00002?ooool4
o`0000[ooooo1?l0000<ooooo`;o000000Coooooo`000?l0003ooooo2?l00005ooooo`;o00001Ooo
ool2o`0000;ooooo0_l00008ooooo`Go0000E?ooool2o`0001Kooooo0_l0001Zooooo`;o00002Ooo
ool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`0?ooooo`;o00002?ooool2o`0001kooooo2?l000001?oooooo0000
o`000?l00005ooooo`;o00000_ooool2o`0000Gooooo0_l00008ooooo`Go0000BOooool2o`00017o
oooo0_l0001jooooo`;o00002Oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`0Hooooo`;o00007oooool4o`00
00;ooooo1?l0000;ooooo`;o00004?ooool2o`0002Gooooo0_l0000Tooooo`;o00004Oooool4o`00
07Kooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`07ooooo`;o00001?ooool2o`0000Wo
oooo0_l0000?ooooo`Co00003Oooool2o`0000Gooooo0_l0000Mooooo`;o00002oooool2o`0001So
oooo0_l0000iooooo`;o0000M_ooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo00Oooooo
0_l00004ooooo`;o00006_ooool4o`0000Gooooo0_l00005ooooo`Ko00000_ooool2o`0000Gooooo
0_l000000ooooooo0000o`00000<ooooo`;o00001?ooool3o`0000_ooooo0_l0000Oooooo`;o0000
<Oooool2o`0004[ooooo0_l0000hooooo`007_ooool00ol0003oooooooooo`0`ooooo`Co00001Ooo
ool6o`0000Kooooo0_l000001?oooooo0000o`000?ooool2o`0000cooooo0_l00004ooooo`;o0000
;Oooool2o`00037ooooo0_l0001:ooooo`;o00008Oooool3o`0001Cooooo000Nooooo`03o`000?oo
oooooooo033ooooo0_l00008ooooo`Go00001_ooool2o`0001;ooooo0ol00007ooooo`;o00004ooo
ool2o`000:gooooo0_l00007ooooo`?o00005?ooool001kooooo00?o0000ooooooooool02?ooool2
o`00037ooooo1?l0000Kooooo`;o00001oooool2o`0001?ooooo0_l0001;ooooo`;o0000H?ooool2
o`0001?ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`08ooooo`;o00003oooool2o`00
01;ooooo0_l0000<ooooo`?o00003_ooool2o`0002?ooooo0_l0001Booooo`;o00000oooool2o`00
073ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o00004_ooool2o`0000co
oooo1?l00004ooooo`;o00001oooool2o`0000[ooooo0_l0000Gooooo`;o0000Eoooool2o`0007_o
oooo000Nooooo`03o`000?oooooooooo00Gooooo0_l0000dooooo`Co000000?oooooo`000?l00000
0ol0000<ooooo`;o00001Oooool2o`0000Cooooo0_l00004ooooo`;o00000oooool2o`0007cooooo
0_l0001Nooooo`007_ooool00ol0003oooooooooo`05ooooo`;o00006?ooool2o`0001kooooo1Ol0
000:ooooo`;o000000?oooooo`000?l000002oooool2o`0000Cooooo0_l00003ooooo`;o0000Booo
ool2o`0001Sooooo0_l0000Eooooo`;o0000G_ooool001kooooo00?o0000ooooooooool07oooool2
o`00013ooooo1?l0000:ooooo`;o00000_ooool2o`0000Wooooo0_l0000@ooooo`;o00008?ooool2
o`0000?ooooo0_l0000Aooooo`;o00006_ooool2o`0001Sooooo0_l0001eooooo`007_ooool00ol0
003oooooooooo`0aooooo`Go00003Oooool3o`00013ooooo0_l00003ooooo`;o00000oooool2o`00
023ooooo0_l00003ooooo`;o00004Oooool2o`0008Wooooo0_l0000Pooooo`007_ooool2o`0000Co
oooo0_l0000_ooooo`;o00003_ooool2o`0000gooooo0_l000000ooooooo0000o`000003ooooo`;o
0000b?ooool2o`00023ooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0000_ooooo`;o0000
7Oooool3o`000003ooooool0003o000000Cooooo0_l00005ooooo`;o00002Oooool2o`0009Cooooo
0_l00010ooooo`007_ooool00ol0003oooooooooo`0]ooooo`;o00001oooool2o`0000;ooooo0_l0
0005ooooo`Ko00000oooool2o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l000001?oo
ool2o`0000Gooooo0_l00003ooooo`;o00001?ooool3o`0005?ooooo0_l0000nooooo`;o00003_oo
ool2o`00033ooooo000Nooooo`03o`000?oooooooooo02gooooo0_l00006ooooo`?o00000_ooool2
o`0000Gooooo1_l00003ooooo`Ko000000?oooooo`000?l000001Oooool2o`0000Oooooo0_l00006
ooooo`;o00001?ooool4o`0004gooooo0_l00003ooooo`;o0000C_ooool2o`00033ooooo000Noooo
o`03o`000?oooooooooo03Gooooo0_l0000Cooooo`Ko000000?oooooo`000?l000001Oooool2o`00
00Oooooo0_l0000<ooooo`Co00008_ooool2o`0002Wooooo1?l0001/ooooo`;o00005Oooool001ko
oooo00?o0000ooooooooool01?ooool2o`0004Cooooo0_l00008ooooo`;o00000_ooool2o`0000Go
oooo0_l0000Aooooo`;o00008Oooool2o`0001gooooo0_l0000:ooooo`Co00005oooool2o`0005?o
oooo0_l0000Eooooo`007_ooool00ol0003oooooooooo`04ooooo`;o0000;_ooool2o`0001Kooooo
0ol00003ooooo`Co00000_ooool2o`0000Gooooo0_l0000Aooooo`;o0000@?ooool2o`0000[ooooo
0_l0000Eooooo`;o00000_ooool2o`0005Gooooo0_l0000Cooooo`007_ooool00ol0003ooooooooo
o`0cooooo`?o00003?ooool2o`0000Sooooo0ol00003ooooo`Co00000oooool2o`00013ooooo0_l0
001Qooooo`;o00001oooool2o`0001;ooooo0_l0000Dooooo`;o0000;oooool2o`0001?ooooo000N
ooooo`03o`000?oooooooooo03?ooooo0_l0000=ooooo`;o00003Oooool:o`0000Kooooo0_l00008
ooooo`;o0000?Oooool2o`0002;ooooo0_l0000Kooooo`;o00005?ooool2o`0004Cooooo000Noooo
o`03o`000?oooooooooo057ooooo0_l00002ooooo`Go00001oooool2o`0000;ooooo0_l00002oooo
o`;o00000_ooool2o`0000;ooooo0_l00006ooooo`?o0000;_ooool2o`0009_ooooo000Nooooo`03
o`000?oooooooooo02cooooo0_l0000<ooooo`;o00006_ooool4o`0000;ooooo0_l00007ooooo`;o
00000_ooool2o`0000;ooooo0ol000000ooooooo0000o`000006ooooo`?o00000oooool2o`000<Ko
oooo000Nooooo`03o`000?oooooooooo02cooooo0_l00004ooooo`;o00001_ooool2o`0001Oooooo
1ol00002ooooo`Go00000oooool3o`0000Oooooo1?l000000ooooooo0000o`00000:ooooo`;o0000
Yoooool2o`0001gooooo000Nooooo`03o`000?oooooooooo03;ooooo0_l000001?oooooo0000o`00
0?ooool2o`0001Wooooo2?l00002ooooo`Co00000_ooool4o`000003ooooool0003o000000;ooooo
0_l00002ooooo`;o000000?oooooo`000?l00000=_ooool2o`0007Kooooo0_l00003ooooo`;o0000
7Oooool001kooooo00?o0000ooooooooool0=Oooool2o`000003ooooool0003o000000Gooooo0ol0
000Aooooo`Wo00001oooool3o`0000;ooooo0_l00002ooooo`Co000000?oooooo`000?l000004?oo
ool2o`0002Kooooo0_l0001@ooooo`;o000000?oooooo`000?l000008Oooool2o`0002;ooooo000N
ooooo`03o`000?oooooooooo03oooooo0ol00009ooooo`;o00001Oooool3o`0000?ooooo1?l00005
ooooo`Ko00000oooool2o`0000;ooooo0_l000000ooooooo0000o`00000@ooooo`;o0000??ooool2
o`0003[ooooo0_l000000ooooooo0000o`000015ooooo`007_ooool00ol0003oooooooooo`0joooo
o`;o00003oooool3o`0000Cooooo0_l000001?oooooo0000o`000?ooool5o`0000Cooooo1_l00000
0ooooooo0000o`000002o`00013ooooo0_l00011ooooo`Co0000Q?ooool001kooooo0_l0000doooo
o`;o00001Oooool2o`0000Cooooo0_l0000:ooooo`;o00001?ooool<o`000004ooooool0003o0000
o`0000Kooooo0_l00004ooooo`Co00002_ooool2o`00047ooooo0_l0000cooooo`;o0000DOooool0
01kooooo00?o0000ooooooooool0<oooool2o`0000Gooooo0_l00004ooooo`;o00002oooool2o`00
00;ooooo4Ol00006ooooo`;o00001?ooool6o`0003[ooooo0_l00014ooooo`;o00002_ooool2o`00
04Gooooo000Nooooo`03o`000?oooooooooo03Gooooo0_l00003ooooo`;o00000_ooool2o`0000[o
oooo0_l000000ooooooo0000o`000002ooooo`ko00002Oooool2o`0000Sooooo0_l0000_ooooo`;o
00002Oooool2o`0001Cooooo0_l0000jooooo`;o0000AOooool001kooooo00?o0000ooooooooool0
=Oooool2o`0000Oooooo0_l00004ooooo`;o00001?ooool2o`0000Oooooo2Ol00009ooooo`;o0000
2oooool2o`0002oooooo0_l0000Oooooo`;o00006?ooool2o`0002Cooooo0_l00011ooooo`007_oo
ool00ol0003oooooooooo`0hooooo`;o00001_ooool2o`0000;ooooo1?l000000ooooooo0000o`00
0003ooooo`;o000000?oooooo`000?l000002?l000000ooooooo0000o`000007ooooo`;o0000EOoo
ool2o`00023ooooo0_l0000Fooooo`;o00003?ooool2o`00047ooooo000Nooooo`03o`000?oooooo
oooo03Sooooo0_l00006ooooo`;o00001?ooool5o`0000?ooooo0_l000000ooooooo0000o`000009
ooooo`;o00003_ooool2o`0000Wooooo0_l00013ooooo`;o0000>?ooool2o`0004oooooo000Noooo
o`03o`000?oooooooooo02[ooooo0_l0000<ooooo`;o00003?ooool4o`0000?ooooo0_l0000Moooo
o`;o00001_ooool2o`000003ooooool0003o00000<kooooo000Nooooo`03o`000?oooooooooo02[o
oooo0_l00006ooooo`;o00001?ooool2o`0001?ooooo0_l0000Aooooo`;o00004_ooool2o`0000;o
oooo0_l000000ooooooo0000o`000006ooooo`;o00000_ooool2o`000;kooooo000Nooooo`03o`00
0?oooooooooo01Kooooo0_l0000Jooooo`;o00004?ooool2o`0000Gooooo0_l0000Cooooo`;o0000
5_ooool2o`000003ooooool0003o000000Kooooo0_l00002ooooo`;o0000?Oooool2o`0007oooooo
000Nooooo`03o`000?oooooooooo01;ooooo0_l00002ooooo`;o00006_ooool3o`0000;ooooo0_l0
000;ooooo`Co00000oooool2o`0000Cooooo0_l0000dooooo`;o0000?Oooool2o`0007oooooo000N
ooooo`03o`000?oooooooooo01;ooooo0_l0000Nooooo`?o00000_ooool2o`0000gooooo0_l00009
ooooo`;o00002?ooool2o`0000?ooooo0_l0000Jooooo`;o0000bOooool001kooooo00?o0000oooo
ooooool0;oooool2o`0002[ooooo0_l00003ooooo`;o00003Oooool2o`0000_ooooo0_l0001Eoooo
o`;o0000L_ooool001kooooo00?o0000ooooooooool02oooool2o`0002;ooooo0_l000000ooooooo
0000o`000009ooooo`;o00006Oooool2o`0000Cooooo0_l0000?ooooo`;o00007Oooool2o`0001Oo
oooo0_l0000Zooooo`;o0000L_ooool001kooooo00?o0000ooooooooool02oooool2o`0002Gooooo
0_l00007ooooo`Co000000?oooooo`000?l000005_ooool2o`0000Cooooo0_l0000Oooooo`;o0000
3Oooool2o`0001Oooooo0_l0001booooo`;o0000:_ooool001kooooo00?o0000ooooooooool04ooo
ool2o`0000?ooooo0_l0000Looooo`;o000000?oooooo`000?l000000_l00003ooooo`;o00005_oo
ool2o`0002Gooooo0_l0000:ooooo`;o000000?oooooo`000?l00000AOooool2o`0004Cooooo0_l0
000Zooooo`007_ooool00ol0003oooooooooo`04ooooo`;o00003Oooool2o`0000?ooooo0_l0000L
ooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000001Oooooo1?l0000R
ooooo`;o00002_ooool2o`000003ooooool0003o000004Gooooo0ol0001_ooooo`007_ooool2o`00
00Cooooo0ol0000Xooooo`;o00002Oooool2o`0000;ooooo0_l0000;ooooo`;o00003Oooool4o`00
00oooooo0_l00009ooooo`;o00001?ooool2o`0000cooooo0_l00019ooooo`;o0000Koooool001ko
oooo00?o0000ooooooooool00oooool2o`0002Wooooo0_l000001?oooooo0000o`000?l00004oooo
o`?o00003oooool2o`00023ooooo0_l00009ooooo`;o00001?ooool2o`0000Wooooo0_l0001moooo
o`;o0000?_ooool001kooooo00?o0000ooooooooool0<Oooool3o`0000Cooooo0ol00002ooooo`;o
00008_ooool2o`0000Cooooo0_l0000Jooooo`Oo0000COooool2o`0002kooooo0_l0000nooooo`00
7_ooool00ol0003oooooooooo`0booooo`;o00001Oooool2o`0000;ooooo0_l00003ooooo`?o0000
0oooool2o`0000_ooooo0_l0000:ooooo`;o00001?ooool2o`0001Sooooo2Ol0000:ooooo`;o0000
@Oooool2o`0001Gooooo0_l0001Gooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o00006ooo
ool2o`0000kooooo0ol00003ooooo`;o00000_ooool2o`0000Oooooo0_l0000Zooooo`Go000000Co
ooooo`000?l0003o00002_ooool2o`0000kooooo0_l00018ooooo`;o0000;oooool2o`000003oooo
ool0003o000002?ooooo000Nooooo`03o`000?oooooooooo01Gooooo0_l0000Sooooo`;o00001?oo
ool3o`000003ooooool0003o000000Kooooo0_l0000aooooo`Oo000000Coooooo`000?l0003o0000
0oooool2o`0001Gooooo0_l0001iooooo`;o000000?oooooo`000?l000008oooool001kooooo00?o
0000ooooooooool06Oooool2o`0001oooooo0_l00003ooooo`Co000000?oooooo`000?l000003Ooo
ool2o`0000[ooooo0_l0000Nooooo`Co000000?oooooo`000?l000001_l000000ooooooo0000o`00
002hooooo`007_ooool01?l0003oooooo`000?l0000Hooooo`;o00007oooool2o`0000;ooooo0ol0
000:ooooo`;o00001_ooool2o`0000[ooooo0_l0000Mooooo`;o00001Oooool7o`0000Kooooo0_l0
0007ooooo`;o0000Poooool4o`0001Kooooo0_l0000;ooooo`007_ooool01?l0003oooooo`000?l0
000`ooooo`;o00001?ooool2o`000003ooooool0003o000000;ooooo0_l00005ooooo`;o00001?oo
ool2o`00037ooooo0_l00006ooooo`Co00002?ooool2o`0000Oooooo0_l00023ooooo`Co00001?oo
ool2o`00013ooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`0Aooooo`?o00007Oooool2
o`0000Cooooo0_l0000<ooooo`;o0000>_ooool2o`0000?ooooo1?l0002Nooooo`;o00004?ooool2
o`0000_ooooo000Nooooo`03o`000?oooooooooo017ooooo0ol0000=ooooo`;o00007?ooool4o`00
03kooooo0_l00004ooooo`;o0000/Oooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo00ko
oooo0_l0000Aooooo`?o00002Oooool2o`00013ooooo1?l00008ooooo`;o00005?ooool2o`000>Co
oooo000Nooooo`03o`000?oooooooooo00kooooo0_l00009ooooo`;o00001Oooool4o`0000Wooooo
0_l0000?ooooo`;o00002oooool2o`0000Sooooo0_l0000:ooooo`;o0000;?ooool2o`0006_ooooo
0_l00019ooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o00001Oooool2o`0001cooooo0ol0
000Dooooo`;o00004_ooool2o`0000Oooooo0_l0000=ooooo`;o00003?ooool2o`0005;ooooo0_l0
000Gooooo`;o00008Oooool2o`0002Kooooo000Dooooo`Co000000?o410@ooooooooool00oooool0
0ol0003oooooooooo`0Oooooo`;o00000oooool2o`0001Wooooo0_l0000:ooooo`;o000000?ooooo
o`000?l000000_l0000Gooooo`;o00001oooool2o`0000gooooo0_l0000/ooooo`;o00000_ooool2
o`0002kooooo0_l0000jooooo`;o00002Oooool2o`0001_ooooo000Fooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool07oooool2o`0000?ooooo0_l0000Uooooo`Oo00000_ooool2o`00
01Oooooo0_l00010ooooo`;o00000_ooool2o`0007Gooooo0_l0000Kooooo`005_ooool00ol0003o
ooooooooo`05ooooo`?o0000C?ooool2o`0000Kooooo0_l0000Gooooo`;o00002_ooool3o`000<_o
oooo000Fooooo`03o`000?oooooooooo087ooooo0ol0003;ooooo`005_ooool00ol0003ooooooooo
o`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000oooo
ooooool0oooooom@ooooo`005?ooool00omEEEGoIVIVo`00003ooooooe;ooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.43642 .93592 Mdot
.03605 .7626 Mdot
.22647 .84267 Mdot
.38114 .87039 Mdot
.22394 .76906 Mdot
.29776 .87253 Mdot
.82813 .92904 Mdot
.20763 .80874 Mdot
.31408 .90794 Mdot
.30982 .3476 Mdot
.2289 .84547 Mdot
.2771 .76853 Mdot
.20167 .8091 Mdot
.91016 .85178 Mdot
.2729 .88152 Mdot
.22077 .52767 Mdot
.29567 .41848 Mdot
.24928 .77657 Mdot
.4301 .94624 Mdot
.38982 .89146 Mdot
.963 .9415 Mdot
.24187 .92982 Mdot
.15116 .84794 Mdot
.40939 .00447 Mdot
.31303 .90669 Mdot
.19029 .84401 Mdot
.27596 .92815 Mdot
.24615 .63784 Mdot
.23986 .80347 Mdot
.28441 .9579 Mdot
.30516 .85502 Mdot
.27184 .87689 Mdot
.22894 .94771 Mdot
.46078 .04533 Mdot
.28469 .01947 Mdot
.31543 .84989 Mdot
.95846 .8751 Mdot
.46202 .16721 Mdot
.29507 .73817 Mdot
.29641 .90785 Mdot
.33655 .88524 Mdot
.08424 .9637 Mdot
.07558 .78104 Mdot
.2911 .28315 Mdot
.88261 .94005 Mdot
.10002 .94238 Mdot
.72259 .91016 Mdot
.14658 .70488 Mdot
.28436 .86934 Mdot
.2084 .93003 Mdot
.22324 .65111 Mdot
.05905 .93271 Mdot
.17759 .78074 Mdot
.27813 .76906 Mdot
.16284 .76433 Mdot
.40009 .40559 Mdot
.52975 .85619 Mdot
.20708 .78903 Mdot
.27341 .92935 Mdot
.39763 .06308 Mdot
.34837 .88131 Mdot
.20329 .83166 Mdot
.031 .04097 Mdot
.30243 .90226 Mdot
.31564 .80141 Mdot
.28058 .89904 Mdot
.02306 .94903 Mdot
.27436 .92981 Mdot
.28933 .87391 Mdot
.09895 .86409 Mdot
.2926 .38866 Mdot
.31211 .01837 Mdot
.29891 .80681 Mdot
.22813 .28593 Mdot
.16007 .9461 Mdot
.49468 .83354 Mdot
.31588 .83081 Mdot
.15724 .27319 Mdot
.27753 .90791 Mdot
.42404 .90818 Mdot
.15277 .82914 Mdot
.87908 .24184 Mdot
.21891 .23014 Mdot
.20089 .8176 Mdot
.82367 .17313 Mdot
.77398 .43237 Mdot
.2157 .80026 Mdot
.31348 .92674 Mdot
.27931 .8716 Mdot
.37375 .05638 Mdot
.30154 .87964 Mdot
.69747 .49851 Mdot
.20501 .9877 Mdot
.38962 .13064 Mdot
.40652 .0056 Mdot
.13681 .84063 Mdot
.27654 .01257 Mdot
.10653 .98419 Mdot
.2139 .81277 Mdot
.60308 .9177 Mdot
.22727 .87377 Mdot
.21731 .64566 Mdot
.46747 .90794 Mdot
.05687 .69972 Mdot
.10043 .80288 Mdot
.15336 .83755 Mdot
.244 .47681 Mdot
.21297 .50312 Mdot
.05478 .88927 Mdot
.45973 .58048 Mdot
.96187 .82597 Mdot
.12948 .20869 Mdot
.36226 .77162 Mdot
.26401 .79144 Mdot
.81652 .83743 Mdot
.82054 .03902 Mdot
.93057 .97384 Mdot
.19157 .82916 Mdot
.17304 .27722 Mdot
.29357 .89257 Mdot
.27644 .93903 Mdot
.06628 .7706 Mdot
.16835 .97227 Mdot
.38593 .22649 Mdot
.99536 .6634 Mdot
.60896 .75734 Mdot
.06907 .77238 Mdot
.42733 .94759 Mdot
.41963 .01717 Mdot
.48005 .76046 Mdot
.5744 .68234 Mdot
.08847 .34907 Mdot
.97073 .40228 Mdot
.24896 .84044 Mdot
.32178 .87765 Mdot
.18669 .75391 Mdot
.14458 .82142 Mdot
.23786 .77387 Mdot
.36472 .85196 Mdot
.30262 .88887 Mdot
.42012 .92528 Mdot
.28551 .8942 Mdot
.23349 .93438 Mdot
.55965 .94798 Mdot
.98386 .57338 Mdot
.22016 .82543 Mdot
.41562 .94808 Mdot
.26003 .8968 Mdot
.44942 .76557 Mdot
.94289 .15708 Mdot
.38406 .82789 Mdot
.22228 .95688 Mdot
.3195 .75348 Mdot
.38298 .90285 Mdot
.27077 .89664 Mdot
.18065 .82267 Mdot
.26029 .72995 Mdot
.69556 .14216 Mdot
.32074 .90888 Mdot
.27325 .52978 Mdot
.26675 .81623 Mdot
.45824 .96728 Mdot
.86809 .05975 Mdot
.23413 .87962 Mdot
.23415 .81538 Mdot
.18948 .76898 Mdot
.26748 .88599 Mdot
.30575 .91174 Mdot
.78284 .82281 Mdot
.22046 .78837 Mdot
.19969 .9655 Mdot
.36566 .96263 Mdot
.36528 .9997 Mdot
.80602 .49204 Mdot
.44308 .95581 Mdot
.30697 .8514 Mdot
.53835 .94167 Mdot
.18635 .83192 Mdot
.7903 .78363 Mdot
.06402 .9511 Mdot
.1498 .74857 Mdot
.17928 .8226 Mdot
.42937 .9734 Mdot
.92357 .0043 Mdot
.29443 .70097 Mdot
.30646 .67948 Mdot
.28346 .56619 Mdot
.25918 .86406 Mdot
.40412 .01961 Mdot
.53632 .8728 Mdot
.43618 .95715 Mdot
.88009 .04509 Mdot
.42905 .942 Mdot
.13249 .91054 Mdot
.31498 .89651 Mdot
.08895 .8208 Mdot
.47435 .98762 Mdot
.16416 .94609 Mdot
.31062 .91014 Mdot
.17453 .9666 Mdot
.97485 .15854 Mdot
.46841 .76876 Mdot
.26686 .86105 Mdot
.92479 .95176 Mdot
.31146 .90662 Mdot
.32114 .92443 Mdot
.02801 .75593 Mdot
.29047 .92968 Mdot
.322 .87351 Mdot
.32323 .81526 Mdot
.20324 .77572 Mdot
.42708 .92184 Mdot
.99205 .03642 Mdot
.21411 .96902 Mdot
.25551 .80597 Mdot
.34977 .0176 Mdot
.28985 .88878 Mdot
.38193 .57992 Mdot
.32551 .69858 Mdot
.03288 .00816 Mdot
.8505 .07384 Mdot
.37941 .06152 Mdot
.2627 .87827 Mdot
.30687 .90745 Mdot
.40615 .07695 Mdot
.29843 .95448 Mdot
.46807 .75944 Mdot
.13728 .81776 Mdot
.32258 .71083 Mdot
.24663 .92588 Mdot
.17422 .83767 Mdot
.37555 .07998 Mdot
.21135 .94647 Mdot
.66663 .81206 Mdot
.37198 .10479 Mdot
.40299 .09774 Mdot
.61126 .53075 Mdot
.2507 .83662 Mdot
.15894 .08903 Mdot
.84236 .36384 Mdot
.25556 .73725 Mdot
.21047 .94406 Mdot
.07592 .71578 Mdot
.3563 .74155 Mdot
.35629 .78944 Mdot
.22741 .97808 Mdot
.34986 .10199 Mdot
.2183 .96546 Mdot
.57672 .65867 Mdot
.31202 .88593 Mdot
.06204 .93951 Mdot
.15257 .77337 Mdot
.33181 .92398 Mdot
.7395 .58834 Mdot
.95816 .64479 Mdot
.17234 .65488 Mdot
.18033 .78004 Mdot
.25394 .98581 Mdot
.07971 .88314 Mdot
.01085 .95416 Mdot
.43012 .92709 Mdot
.32524 .81697 Mdot
.34192 .40638 Mdot
.5139 .17783 Mdot
.21412 .94207 Mdot
.82115 .28172 Mdot
.33426 .70353 Mdot
.96222 .68288 Mdot
.22525 .83772 Mdot
.28866 .92092 Mdot
.2202 .81543 Mdot
.77242 .74019 Mdot
.32527 .90178 Mdot
.30895 .83423 Mdot
.18255 .86179 Mdot
.1495 .78981 Mdot
.30164 .69659 Mdot
.1879 .22702 Mdot
.29065 .80947 Mdot
.27064 .64601 Mdot
.51865 .88873 Mdot
.23613 .93997 Mdot
.21086 .88215 Mdot
.98387 .99687 Mdot
.19599 .77288 Mdot
.26754 .88142 Mdot
.23894 .79125 Mdot
.5705 .78425 Mdot
.16594 .67631 Mdot
.27994 .63879 Mdot
.12474 .67485 Mdot
.57112 .187 Mdot
.42264 .94335 Mdot
.34429 .78982 Mdot
.74579 .46945 Mdot
.52858 .86003 Mdot
.28882 .80715 Mdot
.28717 .58564 Mdot
.5272 .82269 Mdot
.73637 .90334 Mdot
.57726 .73345 Mdot
.15726 .83378 Mdot
.41417 .01043 Mdot
.31921 .12527 Mdot
.50612 .99648 Mdot
.06572 .89111 Mdot
.27885 .92462 Mdot
.27558 .9161 Mdot
.85378 .02378 Mdot
.41127 .84778 Mdot
.28431 .93712 Mdot
.51691 .7567 Mdot
.19064 .84945 Mdot
.45909 .00179 Mdot
.29953 .8547 Mdot
.27904 .67886 Mdot
.2964 .00489 Mdot
.73716 .57916 Mdot
.18487 .91198 Mdot
.48821 .27231 Mdot
.3155 .71272 Mdot
.2145 .95966 Mdot
.25903 .62993 Mdot
.38923 .01031 Mdot
.2904 .82048 Mdot
.17187 .83489 Mdot
.29227 .81764 Mdot
.42786 .92001 Mdot
.24843 .72693 Mdot
.18051 .83764 Mdot
.36388 .88819 Mdot
.29359 .87425 Mdot
.31403 .48827 Mdot
.79511 .68628 Mdot
.31632 .95247 Mdot
.20813 .15733 Mdot
.52572 .75862 Mdot
.27503 .9329 Mdot
.21788 .54512 Mdot
.74663 .43281 Mdot
.24011 .83039 Mdot
.11202 .07595 Mdot
.41867 .91444 Mdot
.32468 .10819 Mdot
.6576 .04691 Mdot
.40836 .6508 Mdot
.92049 .03239 Mdot
.09821 .49281 Mdot
.21794 .83777 Mdot
.21385 .80276 Mdot
.20764 .84059 Mdot
.16716 .77247 Mdot
.50861 .93215 Mdot
.14707 .59955 Mdot
.08054 .74968 Mdot
.33274 .89308 Mdot
.12802 .95056 Mdot
.2504 .93906 Mdot
.2128 .78773 Mdot
.36793 .90341 Mdot
.22526 .94962 Mdot
.43071 .7917 Mdot
.33185 .8737 Mdot
.19108 .78321 Mdot
.21632 .86278 Mdot
.19823 .94666 Mdot
.02971 .75092 Mdot
.43245 .0671 Mdot
.06373 .28015 Mdot
.28412 .92035 Mdot
.24552 .81031 Mdot
.28612 .91788 Mdot
.25571 .86382 Mdot
.28561 .90502 Mdot
.59901 .90641 Mdot
.62008 .8791 Mdot
.88087 .92856 Mdot
.30038 .89509 Mdot
.81371 .76654 Mdot
.25327 .98593 Mdot
.28188 .90054 Mdot
.37706 .8607 Mdot
.10137 .45447 Mdot
.95182 .62205 Mdot
.30305 .67387 Mdot
.0558 .9211 Mdot
.12337 .67725 Mdot
.29459 .29142 Mdot
.27765 .92994 Mdot
.07726 .85769 Mdot
.42033 .9257 Mdot
.24504 .75588 Mdot
.23512 .86375 Mdot
.24161 .77187 Mdot
.23935 .77151 Mdot
.44428 .38524 Mdot
.24903 .40107 Mdot
.75724 .24638 Mdot
.27276 .93235 Mdot
.3176 .85234 Mdot
.05655 .83407 Mdot
.90526 .84588 Mdot
.83065 .08513 Mdot
.20125 .82777 Mdot
.089 .09981 Mdot
.57673 .69326 Mdot
.24923 .6271 Mdot
.33887 .02489 Mdot
.302 .11256 Mdot
.23109 .86717 Mdot
.24899 .82953 Mdot
.31616 .91396 Mdot
.26027 .81974 Mdot
.21649 .96428 Mdot
.87216 .52607 Mdot
.24745 .79861 Mdot
.45456 .92456 Mdot
.29278 .90923 Mdot
.41022 .6215 Mdot
.27468 .91055 Mdot
.29855 .9128 Mdot
.43452 .58625 Mdot
.46448 .2553 Mdot
.24003 .76024 Mdot
.20025 .79843 Mdot
.83651 .87797 Mdot
.99186 .20528 Mdot
.2973 .91196 Mdot
.30667 .99589 Mdot
.20321 .74428 Mdot
.72774 .44225 Mdot
.84611 .84169 Mdot
.9204 .01602 Mdot
.36963 .86572 Mdot
.8692 .8692 Mdot
.27083 .61307 Mdot
.30922 .70055 Mdot
.53717 .67412 Mdot
.35225 .84252 Mdot
.87918 .96407 Mdot
.3496 .72483 Mdot
.24503 .29804 Mdot
.19789 .2755 Mdot
.33004 .88906 Mdot
.30379 .0384 Mdot
.30297 .90497 Mdot
.20506 .95226 Mdot
.23044 .76039 Mdot
.63718 .37435 Mdot
.23445 .98265 Mdot
.52265 .77746 Mdot
.04537 .88201 Mdot
.25586 .84786 Mdot
.29212 .90381 Mdot
.41883 .70413 Mdot
.28057 .9357 Mdot
.31755 .91094 Mdot
.29532 .8072 Mdot
.48871 .9283 Mdot
.44184 .57899 Mdot
.36932 .81628 Mdot
.31281 .92574 Mdot
.29059 .89292 Mdot
.18638 .82582 Mdot
.36607 .04935 Mdot
.10728 .99558 Mdot
.22293 .95524 Mdot
.52513 .72456 Mdot
.30492 .89075 Mdot
.34746 .94704 Mdot
.27872 .9332 Mdot
.21455 .81378 Mdot
.205 .81654 Mdot
.20288 .81677 Mdot
.26022 .79497 Mdot
.27248 .8848 Mdot
.23156 .72529 Mdot
.19488 .80686 Mdot
.69416 .9972 Mdot
.07852 .83106 Mdot
.21931 .22666 Mdot
.19866 .91549 Mdot
.22582 .93762 Mdot
.41125 .91577 Mdot
.43468 .94138 Mdot
.17324 .8588 Mdot
.48482 .14508 Mdot
.34855 .24093 Mdot
.44911 .93402 Mdot
.20465 .65146 Mdot
.26062 .86467 Mdot
.31 .91233 Mdot
.42806 .31862 Mdot
.08292 .68464 Mdot
.33524 .92072 Mdot
.16746 .96198 Mdot
.21645 .86709 Mdot
.18385 .93852 Mdot
.45469 .97884 Mdot
.34134 .99484 Mdot
.23281 .88115 Mdot
.46379 .70381 Mdot
.36795 .98722 Mdot
.3003 .94671 Mdot
.24217 .7745 Mdot
.16627 .9903 Mdot
.21006 .82547 Mdot
.62585 .72202 Mdot
.31741 .91319 Mdot
.32122 .9676 Mdot
.36536 .88648 Mdot
.39047 .24188 Mdot
.30015 .36376 Mdot
.25732 .76753 Mdot
.22068 .77279 Mdot
.69801 .81605 Mdot
.24983 .68745 Mdot
.14794 .84503 Mdot
.86975 .42739 Mdot
.32585 .84763 Mdot
.2737 .95984 Mdot
.22382 .80967 Mdot
.28067 .90449 Mdot
.16431 .96733 Mdot
.60152 .93924 Mdot
.62814 .02549 Mdot
.3645 .04727 Mdot
.13245 .11397 Mdot
.4685 .9977 Mdot
.50075 .88655 Mdot
.78744 .82765 Mdot
.93791 .52828 Mdot
.20637 .77133 Mdot
.22446 .69693 Mdot
.19592 .81737 Mdot
.23001 .8884 Mdot
.31711 .8067 Mdot
.25099 .91638 Mdot
.54409 .20668 Mdot
.18108 .73066 Mdot
.30178 .88786 Mdot
.77444 .61421 Mdot
.20862 .83322 Mdot
.27105 .89393 Mdot
.35773 .87358 Mdot
.27846 .01965 Mdot
.61856 .37283 Mdot
.34439 .96423 Mdot
.20326 .84437 Mdot
.17308 .83241 Mdot
.02557 .86347 Mdot
.94284 .11475 Mdot
.24406 .9349 Mdot
.45043 .0573 Mdot
.09666 .73882 Mdot
.89907 .80834 Mdot
.35395 .24403 Mdot
.2706 .93353 Mdot
.34034 .85681 Mdot
.52619 .73899 Mdot
.21584 .82673 Mdot
.15693 .88576 Mdot
.53181 .18434 Mdot
.54706 .95952 Mdot
.24229 .78891 Mdot
.28387 .84377 Mdot
.26792 .79012 Mdot
.25244 .86092 Mdot
.85473 .27359 Mdot
.28225 .87104 Mdot
.38332 .66883 Mdot
.085 .66976 Mdot
.27558 .87898 Mdot
.42694 .91908 Mdot
.23828 .7584 Mdot
.27586 .92776 Mdot
.51866 .66307 Mdot
.24027 .79595 Mdot
.14524 .77541 Mdot
.14618 .95936 Mdot
.75019 .92096 Mdot
.77112 .63095 Mdot
.29997 .74286 Mdot
.40978 .91534 Mdot
.51018 .24284 Mdot
.32904 .9108 Mdot
.33002 .69258 Mdot
.91471 .1011 Mdot
.04881 .76993 Mdot
.39469 .00936 Mdot
.1954 .80397 Mdot
.18027 .75756 Mdot
.30527 .11115 Mdot
.18692 .95249 Mdot
.22174 .87111 Mdot
.18967 .85131 Mdot
.32643 .73542 Mdot
.1761 .83087 Mdot
.3199 .88718 Mdot
.25854 .04198 Mdot
.25289 .93888 Mdot
.29539 .91313 Mdot
.23449 .85909 Mdot
.11675 .98921 Mdot
.9542 .89011 Mdot
.23112 .89286 Mdot
.27798 .91462 Mdot
.24166 .94978 Mdot
.89941 .97073 Mdot
.43274 .93719 Mdot
.91639 .02774 Mdot
.7088 .56313 Mdot
.29565 .89692 Mdot
.09329 .64928 Mdot
.4393 .92577 Mdot
.2891 .53462 Mdot
.30205 .97312 Mdot
.10235 .80412 Mdot
.17971 .80968 Mdot
.76396 .82544 Mdot
.29941 .2198 Mdot
.45111 .66665 Mdot
.43207 .94564 Mdot
.75778 .7843 Mdot
.06962 .95268 Mdot
.35756 .7087 Mdot
.68177 .2875 Mdot
.78132 .38353 Mdot
.14215 .77488 Mdot
.03841 .8428 Mdot
.31469 .80545 Mdot
.3089 .91049 Mdot
.39252 .03057 Mdot
.88553 .90738 Mdot
.27829 .87654 Mdot
.43258 .31516 Mdot
.2004 .81468 Mdot
.23413 .14357 Mdot
.24951 .75766 Mdot
.27687 .87808 Mdot
.03332 .83342 Mdot
.28957 .87135 Mdot
.07288 .96965 Mdot
.02301 .81916 Mdot
.06565 .96479 Mdot
.33361 .976 Mdot
.10797 .7261 Mdot
.58643 .95949 Mdot
.19093 .82625 Mdot
.90282 .97669 Mdot
.30043 .0805 Mdot
.16848 .89091 Mdot
.46719 .86137 Mdot
.30702 .90297 Mdot
.60842 .35425 Mdot
.30022 .91026 Mdot
.18648 .77247 Mdot
.64373 .80865 Mdot
.41316 .98111 Mdot
.27599 .93419 Mdot
.88066 .94149 Mdot
.14181 .9043 Mdot
.78541 .58517 Mdot
.27608 .93129 Mdot
.85207 .20879 Mdot
.52287 .76027 Mdot
.27393 .91383 Mdot
.96549 .79176 Mdot
.60576 .92214 Mdot
.46878 .70973 Mdot
.52285 .12754 Mdot
.87916 .2601 Mdot
.06604 .97096 Mdot
.25438 .00595 Mdot
.97344 .1759 Mdot
.19909 .84373 Mdot
.70836 .8792 Mdot
.24203 .75816 Mdot
.88164 .99603 Mdot
.48238 .90856 Mdot
.34606 .25621 Mdot
.58116 .92888 Mdot
.00284 .53275 Mdot
.42796 .95514 Mdot
.28214 .87105 Mdot
.41304 .94136 Mdot
.08918 .72419 Mdot
.86738 .87711 Mdot
.41522 .79418 Mdot
.24246 .78115 Mdot
.13536 .71318 Mdot
.8919 .92529 Mdot
.29004 .44035 Mdot
.30418 .64975 Mdot
.23352 .95404 Mdot
.15609 .91724 Mdot
.29527 .89714 Mdot
.97441 .59663 Mdot
.71585 .7576 Mdot
.02601 .89823 Mdot
.31687 .55005 Mdot
.11772 .60056 Mdot
.18132 .82439 Mdot
.38254 .85908 Mdot
.37602 .00071 Mdot
.17111 .97122 Mdot
.2215 .47405 Mdot
.10759 .99155 Mdot
.13204 .26903 Mdot
.29626 .91894 Mdot
.53298 .60955 Mdot
.28939 .00214 Mdot
.91603 .78511 Mdot
.80027 .99384 Mdot
.12797 .81428 Mdot
.61669 .88005 Mdot
.22032 .95321 Mdot
.23643 .77929 Mdot
.68446 .0325 Mdot
.20303 .95887 Mdot
.42666 .91717 Mdot
.72513 .07069 Mdot
.26912 .93408 Mdot
.03447 .90997 Mdot
.34368 .66922 Mdot
.11775 .82426 Mdot
.94518 .68784 Mdot
.27186 .93795 Mdot
.045 .79647 Mdot
.5929 .96917 Mdot
.20156 .00233 Mdot
.20971 .99369 Mdot
.17621 .83442 Mdot
.31466 .8988 Mdot
.64971 .08794 Mdot
.56254 .74933 Mdot
.59633 .33005 Mdot
.37446 .20755 Mdot
.16722 .69344 Mdot
.58525 .41527 Mdot
.20862 .83445 Mdot
.39397 .86031 Mdot
.45285 .95196 Mdot
.92583 .92431 Mdot
.70888 .81358 Mdot
.07814 .76 Mdot
.26281 .98989 Mdot
.51396 .88858 Mdot
.14683 .87036 Mdot
.93056 .86722 Mdot
.03741 .78512 Mdot
.30305 .85688 Mdot
.41608 .72709 Mdot
.43588 .88616 Mdot
.29896 .93645 Mdot
.21705 .81626 Mdot
.2348 .76442 Mdot
.14734 .83511 Mdot
.21845 .73332 Mdot
.27229 .8619 Mdot
.33102 .90759 Mdot
.21008 .81035 Mdot
.16452 .5642 Mdot
.29813 .8412 Mdot
.25569 .60486 Mdot
.36633 .88331 Mdot
.61014 .95416 Mdot
.58469 .6422 Mdot
.16309 .94414 Mdot
.15616 .48071 Mdot
.30101 .88856 Mdot
.45925 .82938 Mdot
.17987 .84083 Mdot
.15273 .77343 Mdot
.9881 .55805 Mdot
.3844 .89546 Mdot
.10412 .82688 Mdot
.25654 .86149 Mdot
.41266 .69268 Mdot
.14959 .45996 Mdot
.38363 .86724 Mdot
.37921 .77585 Mdot
.65113 .457 Mdot
.59723 .70169 Mdot
.30468 .82956 Mdot
.26631 .67813 Mdot
.19653 .58193 Mdot
.30592 .8886 Mdot
.30947 .91253 Mdot
.17272 .83278 Mdot
.23739 .64484 Mdot
.05323 .2938 Mdot
.07225 .07403 Mdot
.1832 .83331 Mdot
.47248 .86079 Mdot
.18282 .77338 Mdot
.16557 .64432 Mdot
.06282 .57681 Mdot
.36858 .87115 Mdot
.3773 .09478 Mdot
.27353 .61517 Mdot
.25425 .95894 Mdot
.2934 .74019 Mdot
.29479 .91791 Mdot
.32788 .09425 Mdot
.25527 .79994 Mdot
.24225 .82621 Mdot
.32586 .74756 Mdot
.54096 .92708 Mdot
.31324 .02415 Mdot
.60915 .87028 Mdot
.35478 .88023 Mdot
.21302 .815 Mdot
.12146 .81307 Mdot
.25802 .85298 Mdot
.29062 .91287 Mdot
.16747 .25617 Mdot
.43702 .79374 Mdot
.27982 .89091 Mdot
.90004 .80838 Mdot
.19942 .81496 Mdot
.18539 .82032 Mdot
.133 .84011 Mdot
.18276 .8199 Mdot
.22238 .80277 Mdot
.22996 .72469 Mdot
.18159 .78951 Mdot
.21207 .81836 Mdot
.00671 .62134 Mdot
.24931 .03332 Mdot
.97005 .98227 Mdot
.53909 .76947 Mdot
.22926 .76871 Mdot
.90371 .88822 Mdot
.04605 .99312 Mdot
.22405 .82744 Mdot
.38012 .22643 Mdot
.28479 .87274 Mdot
.20108 .87616 Mdot
.25429 .36766 Mdot
.02596 .9111 Mdot
.18036 .82448 Mdot
.27675 .9256 Mdot
.3112 .9022 Mdot
.46631 .82904 Mdot
.23674 .02222 Mdot
.59826 .78155 Mdot
.2023 .84653 Mdot
.19403 .84884 Mdot
.31306 .85921 Mdot
.51613 .17548 Mdot
.33216 .06339 Mdot
.35142 .89761 Mdot
.36528 .03123 Mdot
.26902 .92651 Mdot
.86137 .62976 Mdot
.20498 .8126 Mdot
.26041 .47732 Mdot
.09106 .84545 Mdot
.26727 .82773 Mdot
.18841 .82428 Mdot
.36746 .87783 Mdot
.28956 .92381 Mdot
.47188 .47521 Mdot
.18493 .85119 Mdot
.17401 .8713 Mdot
.43429 .94923 Mdot
.30428 .65916 Mdot
.88583 .6925 Mdot
.18721 .81132 Mdot
.78953 .76792 Mdot
.26409 .92581 Mdot
.30371 .89991 Mdot
.37053 .83054 Mdot
.14287 .82979 Mdot
.22732 .78612 Mdot
.13569 .42483 Mdot
.35653 .66751 Mdot
.91927 .80976 Mdot
.34712 .94261 Mdot
.70752 .90802 Mdot
.34865 .91969 Mdot
.20837 .81521 Mdot
.22413 .77579 Mdot
.11083 .96598 Mdot
.43699 .94014 Mdot
.43429 .89086 Mdot
.60868 .61326 Mdot
.23986 .9327 Mdot
.67145 .8159 Mdot
.30359 .28712 Mdot
.20118 .5635 Mdot
.04921 .89783 Mdot
.23085 .94147 Mdot
.97674 .11644 Mdot
.28696 .82267 Mdot
.50388 .94073 Mdot
.29951 .89041 Mdot
.45414 .85281 Mdot
.12299 .82865 Mdot
.34995 .92671 Mdot
.2896 .66056 Mdot
.624 .7062 Mdot
.3468 .86818 Mdot
.14937 .8455 Mdot
.3091 .6228 Mdot
.57526 .71658 Mdot
.28918 .93494 Mdot
.40732 .93049 Mdot
.41396 .91401 Mdot
.14173 .69698 Mdot
.59379 .76625 Mdot
.30749 .95619 Mdot
.27098 .92296 Mdot
.10989 .89327 Mdot
.15685 .52745 Mdot
.38517 .80869 Mdot
.41785 .8474 Mdot
.19255 .90083 Mdot
.3071 .90704 Mdot
.43598 .1775 Mdot
.38334 .45537 Mdot
.38226 .93469 Mdot
.19124 .82647 Mdot
.27189 .87692 Mdot
.20297 .89783 Mdot
.33303 .69126 Mdot
.40884 .68713 Mdot
.48622 .43057 Mdot
.38117 .94573 Mdot
.09677 .03307 Mdot
.15256 .81078 Mdot
.18906 .81154 Mdot
.21445 .94272 Mdot
.86579 .02745 Mdot
.42639 .93473 Mdot
.11908 .10651 Mdot
.20837 .98457 Mdot
.27337 .91653 Mdot
.04841 .02659 Mdot
.1903 .80949 Mdot
.38028 .90062 Mdot
.3133 .9044 Mdot
.48422 .89703 Mdot
.06594 .94975 Mdot
.29268 .87446 Mdot
.50314 .94192 Mdot
.0374 .01846 Mdot
.30777 .8886 Mdot
.1409 .21048 Mdot
.29292 .8867 Mdot
.65468 .78916 Mdot
.03488 .96129 Mdot
.34476 .92562 Mdot
.1562 .05569 Mdot
.19792 .84501 Mdot
.914 .61417 Mdot
.5489 .68816 Mdot
.961 .06518 Mdot
.87702 .26 Mdot
.24183 .93927 Mdot
.29695 .90866 Mdot
.27995 .88833 Mdot
.37614 .10428 Mdot
.17601 .8331 Mdot
.9702 .56047 Mdot
.2364 .74467 Mdot
.29758 .9256 Mdot
.00775 .72443 Mdot
.72372 .76029 Mdot
.37205 .53344 Mdot
.9842 .05021 Mdot
.27666 .02221 Mdot
.59993 .90646 Mdot
.51918 .06101 Mdot
.21133 .82624 Mdot
.28601 .58289 Mdot
.98168 .44337 Mdot
.27654 .92185 Mdot
.25764 .92412 Mdot
.23464 .77417 Mdot
.38819 .05398 Mdot
.36979 .43884 Mdot
.27893 .57131 Mdot
.26903 .99331 Mdot
.04027 .88385 Mdot
.45012 .7062 Mdot
.75464 .78705 Mdot
.07242 .94174 Mdot
.26078 .92249 Mdot
.75814 .29516 Mdot
.38183 .86943 Mdot
.37137 .71773 Mdot
.09272 .14235 Mdot
.18778 .85589 Mdot
.27146 .93522 Mdot
.22959 .85883 Mdot
.2343 .86868 Mdot
.28999 .72991 Mdot
.17332 .98913 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo0_l0000?ooooo`03o`000?oooooooooo00Wooooo0_l00002ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool01Oooool2o`0000Oooooo00Co0000ooooool0003o00003?ooool01?l0
003oooooo`000?l0000<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`04ooooo`;o00001oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00;ooooo000Nooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo0_l0000?ooooo`?o00002Oooool5o`00
00oooooo00?o0000ooooooooool03_ooool4o`0000cooooo00Co0000ooooool0003o00003?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool2
o`0000Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0
003oooooooooo`07ooooo`;o0000A_ooool2o`0000_ooooo0_l0000Looooo`Co00000_ooool2o`00
0003ooooool0003o00000<;ooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0001=ooooo`;o
00008_ooool4o`0000Gooooo0_l00032ooooo`007_ooool00ol0003oooooooooo`1Fooooo`;o0000
coooool2o`0001kooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0001<ooooo`Co00001ooo
ool2o`0000_ooooo0_l0000?ooooo`;o00000oooool2o`000:7ooooo0_l0000Nooooo`007_ooool0
0ol0003oooooooooo`08ooooo`;o0000?oooool2o`0000_ooooo1?l00007ooooo`;o00002oooool2
o`0000oooooo0_l00003ooooo`;o0000`Oooool001kooooo00?o0000ooooooooool0BOooool2o`00
00_ooooo0_l0000:ooooo`;o00001_ooool2o`0005cooooo0_l00017ooooo`;o0000=?ooool001ko
oooo00?o0000ooooooooool03?ooool2o`0005Cooooo0_l00006ooooo`;o0000G?ooool2o`0004Oo
oooo0_l00002ooooo`;o00003oooool2o`0001oooooo000Nooooo`03o`000?oooooooooo00cooooo
0_l0001Uooooo`;o00001_ooool2o`0009Sooooo0_l0000?ooooo`;o00007oooool001kooooo00?o
0000ooooooooool06oooool2o`00033ooooo0_l0000Tooooo`;o00001_ooool2o`0005gooooo0_l0
001;ooooo`;o00007_ooool001kooooo00?o0000ooooooooool06oooool2o`00033ooooo0_l0002;
ooooo`;o0000Boooool2o`0001Gooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`06oooo
o`;o0000Eoooool2o`000:Kooooo0_l0000eooooo`;o00001oooool001kooooo00?o0000oooooooo
ool01_ooool2o`0004Sooooo0_l0000=ooooo`;o0000Y_ooool2o`0003kooooo000Nooooo`03o`00
0?oooooooooo053ooooo0_l0000Pooooo`;o00007_ooool2o`0003kooooo0_l00016ooooo`;o0000
:oooool001kooooo00?o0000ooooooooool0L_ooool3o`0001gooooo0_l0000nooooo`;o0000A_oo
ool2o`00023ooooo0_l00009ooooo`007_ooool2o`0007Cooooo0_l00037ooooo`;o00002Oooool0
01kooooo00?o0000ooooooooool0;oooool2o`0004Cooooo0_l00003ooooo`;o0000boooool001ko
oooo00?o0000ooooooooool0;oooool2o`0004Cooooo0_l00003ooooo`;o00004_ooool2o`0008Ko
oooo0_l0000_ooooo`007_ooool00ol0003oooooooooo`1gooooo`;o00005Oooool2o`0001Gooooo
0_l0001_ooooo`;o0000;oooool001kooooo00?o0000ooooooooool0J?ooool2o`0000gooooo0_l0
0004ooooo`;o00009_ooool2o`0008gooooo0_l0000Aooooo`007_ooool00ol0003oooooooooo`1X
ooooo`;o00004oooool2o`0000Wooooo0_l0002Zooooo`;o00004Oooool001kooooo00?o0000oooo
ooooool0R?ooool2o`0005kooooo0_l0001Mooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o
0000doooool2o`0002Kooooo0_l0000eooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o0000
2oooool2o`0005kooooo0_l0002>ooooo`;o0000=Oooool001kooooo00?o0000ooooooooool08?oo
ool2o`0003cooooo0_l0000Fooooo`;o00002?ooool2o`000<Gooooo000Nooooo`03o`000?oooooo
oooo05kooooo0_l0000Fooooo`;o0000coooool001kooooo00?o0000ooooooooool0ooooool;oooo
o`;o0000>oooool001kooooo00?o0000ooooooooool0<?ooool2o`0009gooooo0_l0000iooooo`;o
0000>oooool001kooooo00?o0000ooooooooool0<?ooool2o`0009gooooo0_l0001fooooo`007_oo
ool00ol0003oooooooooo`1Vooooo`;o00003oooool2o`000<kooooo000Nooooo`03o`000?oooooo
oooo01Wooooo0_l0001;ooooo`;o00003oooool2o`0000Kooooo0_l00036ooooo`007_ooool2o`00
01[ooooo0_l0001Cooooo`;o00003oooool2o`000:Cooooo0_l0000Pooooo`007_ooool00ol0003o
ooooooooo`1^ooooo`;o00001Oooool3o`000:gooooo0_l0000Pooooo`007_ooool00ol0003ooooo
ooooo`0Sooooo`;o0000@?ooool2o`0000kooooo0ol0003?ooooo`007_ooool00ol0003ooooooooo
o`0Sooooo`;o0000>_ooool2o`0000Cooooo0_l0003Pooooo`007_ooool00ol0003oooooooooo`0W
ooooo`;o0000=Oooool3o`000<gooooo0_l0000Gooooo`007_ooool00ol0003oooooooooo`0Woooo
o`;o0000=Oooool2o`000<kooooo0_l00009ooooo`;o00003?ooool001kooooo00?o0000oooooooo
ool0ooooooljooooo`;o00003?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`1Tooooo`;o0000@?ooool2o`0009oooooo000Nooooo`03o`000?oooooo
oooo06Cooooo0_l00010ooooo`;o0000Woooool001kooooo00?o0000ooooooooool0Noooool2o`00
0<[ooooo000Nooooo`03o`000?oooooooooo07_ooooo0_l0003:ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo01[ooooo0_l00032ooooo`;o0000Iooo
ool001kooooo00?o0000ooooooooool06_ooool2o`0002cooooo0_l0001@ooooo`;o0000@_ooool2
o`0006Oooooo000Nooooo`03o`000?oooooooooo04Sooooo0_l0001@ooooo`;o0000Zoooool001ko
oooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0@?ooool2o`000>cooooo0_l0000Gooooo`007_ooool00ol0003oooooooooo`10
ooooo`;o0000k?ooool2o`0000Wooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`3ooooo
oc[ooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`2Booooo`;o0000/oooool001kooooo
00?o0000ooooooooool0T_ooool2o`000;?ooooo000Nooooo`03o`000?oooooooooo0?oooooo2Ooo
ool2o`0003gooooo000Nooooo`03o`000?oooooooooo0:Cooooo0_l0001Rooooo`;o0000;_ooool2
o`0000gooooo000Nooooo`03o`000?oooooooooo08[ooooo0_l0000Gooooo`?o0000T_ooool2o`00
00gooooo000Nooooo`03o`000?oooooooooo08[ooooo0_l0000Gooooo`;o0000X_ooool001kooooo
00?o0000ooooooooool0ZOooool2o`0009cooooo000Nooooo`03o`000?oooooooooo0:Wooooo0_l0
000;ooooo`;o0000Soooool001kooooo00?o0000ooooooooool0]_ooool2o`0008oooooo0003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooo
oooo0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool0
1Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool3o`000?ooooooB?oo
ool000?ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o
0000ooooooooool0oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool01Oooool00ol0003oooooooooo`2]ooooo`;o0000Soooool2o`0000Oooooo0003
ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo02Kooooo0_l00002ooooo`;o0000B_ooool2o`0003Gooooo0_l0001Rooooo`;o0000:ooo
ool2o`0000Oooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooo
oonHV9So410@00Kooooo00?o0000ooooooooool09_ooool2o`0000;ooooo0_l0001:ooooo`;o0000
VOooool2o`0003Cooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@
o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`1Mooooo`;o0000j?ooool001kooooo00?o0000ooooooooool0GOooool2o`000>Sooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0>Oooool2o`00
00Sooooo0_l0000booooo`Co0000c?ooool001kooooo00?o0000ooooooooool0>Oooool2o`0000So
oooo0_l0000booooo`Co0000c?ooool001kooooo00?o0000ooooooooool0@oooool2o`000?oooooo
0oooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`1]
ooooo`;o0000f?ooool001kooooo00?o0000ooooooooool0KOooool4o`0000[ooooo0_l0000Uoooo
o`;o0000M_ooool2o`0002_ooooo000Nooooo`03o`000?oooooooooo06oooooo0_l0000:ooooo`;o
00009Oooool2o`0004kooooo0_l0000Vooooo`;o0000:oooool001kooooo00?o0000ooooooooool0
l_ooool2o`0005?ooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`0b
ooooo`;o0000>?ooool2o`0002Gooooo0_l0002booooo`007_ooool00ol0003oooooooooo`0boooo
o`;o0000>?ooool2o`0002Gooooo0_l0002booooo`007_ooool00ol0003oooooooooo`3ooooooa[o
oooo0ol0000[ooooo`007_ooool00ol0003oooooooooo`3ooooooa[ooooo0ol0000[ooooo`007_oo
ool00ol0003oooooooooo`0Wooooo`;o0000oooooolOooooo`007_ooool00ol0003oooooooooo`0W
ooooo`;o0000oooooolOooooo`007_ooool00ol0003oooooooooo`0_ooooo`;o0000J_ooool2o`00
07Gooooo0_l0000cooooo`007_ooool00ol0003oooooooooo`0_ooooo`;o00000oooool2o`0000Ko
oooo0_l0001Mooooo`;o0000MOooool2o`0003?ooooo000Nooooo`03o`000?oooooooooo017ooooo
0_l0000Qooooo`;o00001_ooool2o`000?oooooo2_ooool001kooooo00?o0000ooooooooool04Ooo
ool2o`0004Sooooo0_l0002Zooooo`;o0000?_ooool001kooooo00?o0000ooooooooool0A_ooool2
o`0001?ooooo0_l00002ooooo`;o0000Y_ooool2o`0003kooooo000Nooooo`03o`000?oooooooooo
04Kooooo0_l0000Gooooo`;o0000NOooool2o`0006_ooooo000Nooooo`03o`000?oooooooooo05co
oooo0_l0001looooo`;o0000Joooool001kooooo00?o0000ooooooooool03Oooool2o`0004gooooo
0_l0002Dooooo`;o0000Doooool001kooooo00?o0000ooooooooool03Oooool2o`0003gooooo0_l0
002Tooooo`;o0000Doooool001kooooo0_l0001=ooooo`;o0000nOooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0ROooool2o`000;cooooo000N
ooooo`03o`000?oooooooooo08Wooooo0_l0002looooo`007_ooool00ol0003oooooooooo`27oooo
o`;o0000__ooool001kooooo00?o0000ooooooooool0Qoooool2o`000;kooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0__ooool2o`0008Oooooo000N
ooooo`03o`000?oooooooooo0;kooooo0_l00027ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo067ooooo0_l0003Tooooo`007_ooool2o`0001[ooooo0_l00016ooooo`;o0000i?ooool001ko
oooo00?o0000ooooooooool06Oooool2o`000:Oooooo0_l00023ooooo`007_ooool00ol0003ooooo
ooooo`32ooooo`;o0000Poooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`1Mooooo`;o0000[oooool2o`0003Oooooo000Nooooo`03o`000?oooooooooo
05gooooo0_l0002_ooooo`;o0000=oooool001kooooo00?o0000ooooooooool0Coooool2o`000?Ko
oooo000Nooooo`03o`000?oooooooooo04oooooo0_l0001dooooo`;o0000P?ooool001kooooo00?o
0000ooooooooool0aOooool2o`0000Cooooo0_l0001jooooo`007_ooool00ol0003oooooooooo`3;
ooooo`;o0000N_ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`2<ooooo`;o0000K?ooool2o`0004_ooooo000Nooooo`03o`000?oooooooooo05_ooooo
0_l0000_ooooo`;o0000K?ooool2o`0004_ooooo000Nooooo`03o`000?oooooooooo05_ooooo0_l0
003Zooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o
410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol0
001=ooooo`;o0000n?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oM
gMgoooooo`0000Oooooo00?o0000ooooooooool0COooool2o`000>Sooooo0_l0000>ooooo`000ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003o
ooooooooo`1[ooooo`;o00004Oooool2o`000;Oooooo0_l0000>ooooo`000oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`1[ooooo`;o
00004Oooool2o`000<Oooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^ko
A4A4o`000007ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0^_ooool2o`0008_o
oooo000Nooooo`03o`000?oooooooooo05cooooo0_l0001Looooo`;o0000Roooool001kooooo00?o
0000ooooooooool0G?ooool2o`000>Wooooo000Nooooo`03o`000?oooooooooo02Sooooo0_l0003o
oooooakooooo000Nooooo`03o`000?oooooooooo02Sooooo0_l0003]ooooo`;o0000;_ooool001ko
oooo00?o0000ooooooooool0V_ooool2o`0007_ooooo0_l0000^ooooo`007_ooool00ol0003ooooo
ooooo`2Jooooo`;o0000Doooool2o`0000Oooooo0_l0001=ooooo`007_ooool00ol0003ooooooooo
o`3_ooooo`;o00001oooool2o`0004gooooo000Nooooo`03o`000?oooooooooo05[ooooo0_l0000H
ooooo`;o0000dOooool001kooooo00?o0000ooooooooool0F_ooool2o`0001Sooooo0_l0001boooo
o`;o0000DOooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo0>Sooooo0_l0001Aooooo`;o
00002_ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool07Oooool2o`0005[ooooo0_l0003<ooooo`007_ooool00ol0
003oooooooooo`0Mooooo`;o0000F_ooool2o`0005Gooooo0_l0001eooooo`007_ooool00ol0003o
ooooooooo`0]ooooo`;o0000XOooool2o`0007Gooooo000Nooooo`03o`000?oooooooooo02gooooo
0_l0003ooooooaWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0k_ooool2o`0005Oooooo000Nooooo`03o`000?oooooooooo04Cooooo0_l0002Xoooo
o`;o0000Eoooool001kooooo00?o0000ooooooooool0A?ooool2o`0000Gooooo0_l00004ooooo`;o
0000@_ooool2o`000;3ooooo000Nooooo`03o`000?oooooooooo02oooooo0_l0000Jooooo`;o0000
1?ooool2o`0004;ooooo0_l0002`ooooo`007_ooool00ol0003oooooooooo`0_ooooo`;o0000oooo
oolGooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
06;ooooo0_l0003Sooooo`007_ooool00ol0003oooooooooo`0Looooo`;o0000A?ooool2o`0009ko
oooo0_l00013ooooo`007_ooool00ol0003oooooooooo`0Looooo`;o0000i?ooool2o`0004?ooooo
000Nooooo`03o`000?oooooooooo0=oooooo0_l0001Vooooo`007_ooool2o`000>3ooooo0_l0001V
ooooo`007_ooool00ol0003oooooooooo`11ooooo`;o0000ooooool5ooooo`007_ooool00ol0003o
ooooooooo`11ooooo`;o0000ooooool5ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooolHooooo`;o0000;_ooool001kooooo00?o
0000ooooooooool0;oooool2o`0001?ooooo0_l0000?ooooo`;o0000`?ooool2o`0001Cooooo0_l0
000Hooooo`007_ooool2o`00033ooooo0_l0000Cooooo`;o00003oooool2o`0001kooooo0_l0001<
ooooo`;o0000J?ooool2o`0001Sooooo000Nooooo`;o0000Foooool2o`0001Wooooo0_l0001<oooo
o`;o0000P_ooool001kooooo00?o0000ooooooooool0F_ooool2o`000>_ooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0@oooool2o`000?oooooo0ooo
ool001kooooo00?o0000ooooooooool0@oooool2o`000?oooooo0oooool001kooooo0_l0001Toooo
o`;o0000h_ooool001kooooo00?o0000ooooooooool0Hoooool2o`000>;ooooo000Nooooo`03o`00
0?oooooooooo0?oooooo?_ooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo0?oooooo>?oo
ool2o`0000Cooooo0_l00008ooooo`007_ooool00ol0003oooooooooo`0aooooo`;o00002_ooool2
o`000:?ooooo0_l0001Cooooo`;o00003_ooool001kooooo00?o0000ooooooooool0<Oooool2o`00
00[ooooo0_l0000Iooooo`;o0000R?ooool2o`0006?ooooo000Nooooo`03o`000?oooooooooo05So
oooo0_l0003]ooooo`007_ooool00ol0003oooooooooo`1Gooooo`;o0000hoooool2o`0000Wooooo
000Nooooo`03o`000?oooooooooo05Oooooo0_l0003Sooooo`;o00002Oooool001kooooo00?o0000
ooooooooool04?ooool2o`0007[ooooo0_l0001Nooooo`;o0000FOooool001kooooo00?o0000oooo
ooooool04?ooool2o`0002[ooooo0_l0000jooooo`;o00004_ooool2o`0000?ooooo0_l0001Ioooo
o`;o0000FOooool001kooooo00?o0000ooooooooool0??ooool2o`0001_ooooo0_l0000Mooooo`;o
00005oooool2o`0006Sooooo0_l0001:ooooo`007_ooool00ol0003oooooooooo`1Iooooo`;o0000
;_ooool2o`00067ooooo0_l0000=ooooo`;o0000B_ooool001kooooo00?o0000ooooooooool0ROoo
ool2o`00067ooooo0_l0001Iooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`3oooooodSooooo
0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMooooooo
V9RHob4Q8@06ooooo`03o`000?oooooooooo0?oooooo>_ooool2o`0000cooooo0003ooooo`05oa0@
4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0000Roooo
o`;o00002?ooool2o`000?oooooo3?ooool2o`0000cooooo0003ooooo`05o`000?oooooooooooooo
ool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool08_ooool2
o`0000Sooooo0_l0003ooooooa[ooooo0003ooooo`05o`000?ooooooooooooooool000002oooool0
1Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0Coooool2o`000?Kooooo0003
ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo04oooooo0_l0001Hooooo`;o0000W?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0E?ooool2o`0005?ooooo0_l0
000Gooooo`;o0000Poooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0E?ooool3o`0006_ooooo0_l0000dooooo`;o0000
:oooool2o`00023ooooo000Nooooo`03o`000?oooooooooo05Gooooo0_l0002Qooooo`;o0000:ooo
ool2o`00023ooooo000Nooooo`?o0000POooool2o`000:kooooo0_l0000Dooooo`007_ooool3o`00
063ooooo0_l0000Oooooo`;o0000[_ooool2o`0001Cooooo000Nooooo`03o`000?oooooooooo04go
oooo0_l0000Aooooo`;o0000iOooool001kooooo00?o0000ooooooooool0COooool2o`000003oooo
ool0003o00000:Gooooo0_l0000Kooooo`;o0000<Oooool001kooooo00?o0000ooooooooool0D?oo
ool2o`000:Gooooo0_l0000Kooooo`;o0000<Oooool001kooooo00?o0000ooooooooool0C?ooool2
o`000?Wooooo000Nooooo`03o`000?oooooooooo04cooooo0_l00009ooooo`;o0000k_ooool001ko
oooo00?o0000ooooooooool0Eoooool2o`00067ooooo0_l0002;ooooo`007_ooool00ol0003ooooo
ooooo`0booooo`;o00003oooool2o`0000Cooooo0_l00009ooooo`;o0000I?ooool2o`0007Oooooo
0_l0000Booooo`007_ooool00ol0003oooooooooo`0Jooooo`;o00005_ooool2o`0000oooooo0_l0
0004ooooo`;o00002Oooool2o`0000Wooooo0_l0003Booooo`;o00004_ooool001kooooo0_l0000K
ooooo`;o00008_ooool2o`0000Cooooo0_l0000Iooooo`;o00008?ooool2o`000<Cooooo000Noooo
o`03o`000?oooooooooo03Cooooo0_l00008ooooo`;o00001?ooool2o`0003_ooooo0_l00034oooo
o`007_ooool00ol0003oooooooooo`0dooooo`;o0000:Oooool2o`0005Kooooo0_l0002>ooooo`00
7_ooool00ol0003oooooooooo`1Jooooo`;o00000oooool2o`0005Kooooo0_l0002>ooooo`007_oo
ool00ol0003oooooooooo`1Jooooo`;o0000BOooool2o`0009Sooooo0_l00006ooooo`007_ooool0
0ol0003oooooooooo`1`ooooo`;o00001oooool2o`0001Cooooo0_l0000Dooooo`;o0000V?ooool2
o`0000Kooooo000Nooooo`03o`000?oooooooooo01Sooooo0_l0001Booooo`;o00000_ooool2o`00
00Oooooo0_l0000Dooooo`;o0000]_ooool001kooooo00?o0000ooooooooool06?ooool2o`0000[o
oooo0_l0000hooooo`;o00003?ooool2o`0003gooooo0_l0002Jooooo`007_ooool00ol0003ooooo
ooooo`0Tooooo`;o00003?ooool2o`0002[ooooo0_l0001;ooooo`;o0000V_ooool001kooooo00?o
0000ooooooooool09?ooool2o`0000cooooo0_l0000Nooooo`;o00000oooool2o`0000Oooooo0_l0
003Uooooo`007_ooool00ol0003oooooooooo`1Booooo`;o00000oooool2o`0000Oooooo0_l0001E
ooooo`;o0000O?ooool2o`00013ooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0001Xoooo
o`;o0000=?ooool2o`0004Gooooo0_l0000eooooo`;o00004?ooool001kooooo00?o0000oooooooo
ool05oooool2o`0003Cooooo0_l0000booooo`;o0000:oooool2o`0004kooooo0_l0000_ooooo`;o
00005_ooool001kooooo00?o0000ooooooooool0<_ooool2o`0001Wooooo0_l0000Hooooo`?o0000
6?ooool2o`0002[ooooo0_l00007ooooo`;o0000Hoooool2o`00017ooooo0_l0000Fooooo`007_oo
ool00ol0003oooooooooo`0booooo`;o0000<oooool3o`0001Sooooo0_l0000cooooo`;o0000Hooo
ool2o`0002Wooooo000Nooooo`03o`000?oooooooooo02[ooooo0_l0000Iooooo`;o00005oooool2
o`0000Kooooo0_l0003Oooooo`007_ooool2o`0000oooooo0_l0000Jooooo`;o00006Oooool2o`00
01Gooooo1_l00004ooooo`;o0000E_ooool2o`0008Oooooo000Nooooo`03o`000?oooooooooo00ko
oooo0_l0000Looooo`;o0000;_ooool2o`0000;ooooo0_l00007ooooo`;o00006Oooool2o`0000go
oooo0_l0000Yooooo`;o0000Qoooool001kooooo00?o0000ooooooooool0;?ooool2o`0003_ooooo
0_l00005ooooo`;o00004_ooool2o`0000Sooooo0_l00003ooooo`;o0000<_ooool2o`0007kooooo
000Nooooo`03o`000?oooooooooo06Gooooo0_l00009ooooo`;o00007?ooool2o`0000Cooooo0_l0
000aooooo`;o0000O_ooool001kooooo00?o0000ooooooooool0:?ooool2o`0003Sooooo0_l00000
0ooooooo0000o`00000]ooooo`;o0000/Oooool001kooooo00?o0000ooooooooool05Oooool2o`00
017ooooo0_l0000hooooo`;o00004Oooool2o`00043ooooo0_l0002>ooooo`007_ooool00ol0003o
ooooooooo`0Eooooo`;o0000G_ooool2o`00043ooooo0_l0002>ooooo`007_ooool00ol0003ooooo
ooooo`0Iooooo`;o0000[?ooool2o`0007kooooo000Nooooo`?o00006Oooool2o`0000Cooooo0_l0
000Vooooo`;o00001?ooool2o`0001oooooo0_l0000Cooooo`;o00008_ooool2o`0001kooooo0_l0
001nooooo`007_ooool3o`0001oooooo0_l0000Vooooo`;o00001?ooool2o`0000;ooooo0_l00007
ooooo`;o00004_ooool2o`0001?ooooo0_l0000Rooooo`;o0000W_ooool001kooooo00?o0000oooo
ooooool0=oooool2o`0000[ooooo0_l0000<ooooo`;o00001oooool2o`0005cooooo0_l0002=oooo
o`007_ooool00ol0003oooooooooo`0gooooo`;o00002_ooool2o`00027ooooo0_l0001@ooooo`;o
0000SOooool001kooooo00?o0000ooooooooool06oooool2o`0003;ooooo0_l0000;ooooo`;o0000
2?ooool2o`0003oooooo0_l0002Nooooo`007_ooool00ol0003oooooooooo`0Kooooo`;o0000<_oo
ool2o`0000[ooooo0ol0000Booooo`;o0000=Oooool2o`0004kooooo0_l0001>ooooo`007_ooool0
0ol0003oooooooooo`0nooooo`;o00002Oooool2o`00013ooooo1?l0000Aooooo`;o0000QOooool2
o`0004kooooo000Nooooo`03o`000?oooooooooo02gooooo0_l0000?ooooo`;o00002Oooool2o`00
01;ooooo0_l00007ooooo`;o0000goooool001kooooo0_l00007ooooo`;o00003_ooool2o`0001Go
oooo0_l0000gooooo`;o0000Boooool2o`0009;ooooo000Nooooo`03o`000?oooooooooo00Kooooo
0_l0000>ooooo`;o00008Oooool2o`0002Wooooo0_l0001=ooooo`;o0000T_ooool001kooooo00?o
0000ooooooooool01Oooool2o`0002oooooo0_l000000ooooooo0000o`00000Aooooo`?o00005Ooo
ool2o`0003kooooo0_l0000Looooo`;o00008Oooool2o`00063ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo0_l0000>ooooo`;o00007oooool2o`0000oooooo2?l00015ooooo`;o00000_ooool2
o`0000[ooooo1Ol0000Iooooo`;o00008Oooool4o`0005kooooo000Nooooo`03o`000?oooooooooo
00Sooooo0_l0000;ooooo`;o0000<?ooool6o`0004Oooooo0_l00002ooooo`;o00003?ooool3o`00
03kooooo0_l0001Nooooo`007_ooool00ol0003oooooooooo`08ooooo`;o00009oooool2o`0001Go
oooo0_l00014ooooo`;o0000;Oooool2o`0004Gooooo0_l00011ooooo`007_ooool00ol0003ooooo
ooooo`0<ooooo`;o00008oooool2o`0000Kooooo0_l0000:ooooo`Go00001_ooool2o`0000Cooooo
0_l0000fooooo`;o00001?ooool2o`0001Gooooo0_l0000@ooooo`;o0000?_ooool2o`0000Gooooo
0_l00011ooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o00000oooool3o`0001Wooooo0ol0
0002ooooo`;o00000oooool4o`000004ooooool0003o0000ooooo`;o00000oooool4o`0000;ooooo
0_l00004ooooo`;o00001?ooool2o`0001[ooooo0_l0000Pooooo`;o00005Oooool2o`00053ooooo
0_l00018ooooo`007_ooool00ol0003oooooooooo`0Aooooo`?o00005_ooool6o`0000;ooooo0_l0
0003ooooo`Co000000?oooooo`000?l000000ol00003ooooo`?o000000?oooooo`000?l000000ol0
000Uooooo`;o00000oooool2o`000<kooooo000Nooooo`03o`000?oooooooooo02[ooooo0ol0000A
ooooo`;o00001Oooool2o`000003ooooool0003o000000Go0000:?ooool2o`0002gooooo0_l0002O
ooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o00008?ooool3o`00013ooooo1_l0001Goooo
o`;o00005_ooool2o`0008Oooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0000:ooooo`;o
00008?ooool3o`000003ooooool0003o000000oooooo0_l0001Xooooo`;o00001oooool2o`0003;o
oooo0_l00009ooooo`;o00009oooool2o`0001oooooo000Nooooo`03o`000?oooooooooo00Sooooo
0_l0000`ooooo`;o00001Oooool2o`000003ooooool0003o000000;o0000KOooool2o`0003[ooooo
0ol00009ooooo`;o00009oooool2o`0001oooooo000Nooooo`03o`000?oooooooooo02cooooo0_l0
0009ooooo`;o00001_ooool4o`000003ooooool0003o000000;o00000_ooool3o`0000Gooooo0ol0
000Gooooo`;o00000_ooool2o`0001Kooooo0_l00017ooooo`;o00007_ooool2o`0004?ooooo0_l0
000?ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ
8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0/ooooo`;o00002Oooool2o`0000Kooooo
0_l00009ooooo`?o00000oooool5o`0001Oooooo0_l00002ooooo`;o00004Oooool2o`0000?ooooo
1?l00015ooooo`;o0000Hoooool2o`0000oooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo00_o
oooo0_l0000mooooo`;o00001?ooool2o`00037ooooo0_l00005ooooo`;o0000^oooool000?ooooo
00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`00
00_ooooo0_l0000`ooooo`;o00000oooool2o`0000Kooooo1?l000000ooooooo0000o`00003foooo
o`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06
ooooo`03o`000?oooooooooo01gooooo0_l0000Looooo`Co00000_ooool5o`0000Cooooo1?l00000
0ooooooo0000o`00000Booooo`;o0000h_ooool000?ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`0Mooooo`;o00007?oo
ool2o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`;o00000oooool2o`0000Wooooo1Ol0
0003ooooo`?o0000h_ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj
^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`0fooooo`;o00000_ooool8o`0000?ooooo
0_l00005ooooo`;o000000?oooooo`000?l000002Oooool5o`0000?ooooo0ol0000Dooooo`;o0000
D_ooool2o`00057ooooo0ol00004ooooo`;o00007_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`0Sooooo`;o
00002?ooool2o`0000Oooooo0_l000001Ooooooo0000o`000?l0003ooooo00Ko00000_ooool2o`00
00Gooooo0_l0000<ooooo`;o00007Oooool2o`0005;ooooo0_l00006ooooo`;o0000BOooool3o`00
00Cooooo0_l0000Nooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@
4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo02?ooooo1?l00006ooooo`;o00002_ooool2
o`0000;ooooo2?l00003ooooo`;o00002Oooool2o`00013ooooo0_l0000=ooooo`;o0000Goooool3
o`0000Oooooo0_l000000ooooooo0000o`00001Sooooo`007_ooool00ol0003oooooooooo`03oooo
o`;o00008?ooool2o`0000;ooooo0_l0000Aooooo`Wo00000oooool2o`0000Wooooo0_l00006oooo
o`;o00002?ooool3o`0000cooooo0_l0001Pooooo`;o00001oooool2o`000003ooooool0003o0000
06?ooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0000Dooooo`;o00003_ooool4o`0000Wo
oooo1?l00002ooooo`Oo00003Oooool2o`0000Oooooo1?l00009ooooo`;o0000goooool001kooooo
00?o0000ooooooooool06Oooool2o`0000Oooooo0_l00007ooooo`;o00002Oooool5o`0000Gooooo
0_l000000ooooooo0000o`00000;ooooo`;o00001oooool3o`0004_ooooo0_l0001;ooooo`;o0000
1?ooool2o`0004_ooooo000Nooooo`03o`000?oooooooooo01kooooo0_l00002ooooo`Co00004Ooo
ool5o`000004ooooool0003o0000ooooo`Oo00001?ooool2o`0000Kooooo0_l0000Tooooo`;o0000
;?ooool2o`0004_ooooo0_l00004ooooo`Co0000=oooool2o`00013ooooo000Nooooo`03o`000?oo
oooooooo01Gooooo0_l00007ooooo`;o00001?ooool2o`0000Cooooo0_l00002ooooo`;o00001Ooo
ool2o`000003ooooool0003o000000;o000000Goooooo`000?l0003o0000ooooo`03o`000003oooo
ool0003o000000?ooooo1Ol00004ooooo`;o00002_ooool2o`0000;ooooo0_l0000?ooooo`;o0000
0oooool2o`0001Kooooo1?l0001Wooooo`;o0000=oooool2o`00013ooooo000Nooooo`03o`000?oo
oooooooo00Oooooo0_l00005ooooo`;o00001Oooool2o`0001?ooooo0_l00002ooooo`?o00000ooo
ool8o`0000;ooooo1?l00008ooooo`;o000000?oooooo`000?l000004?ooool3o`000003ooooool0
003o000000oooooo0_l0000Kooooo`Co00002?ooool2o`000:Sooooo000Nooooo`03o`000?oooooo
oooo00Oooooo0_l00005ooooo`;o00007?ooool5o`0000?ooooo1_l00006ooooo`;o000000?ooooo
o`000?l000000_l00006ooooo`;o00004Oooool2o`0003_ooooo0_l0001Vooooo`;o0000@?ooool0
01kooooo00?o0000ooooooooool09oooool3o`0000;ooooo1?l00005ooooo`Co00001_ooool2o`00
00;ooooo1?l00006ooooo`;o0000]_ooool2o`00043ooooo000Nooooo`03o`000?oooooooooo00So
oooo0_l0000Mooooo`?o00003?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000Go
oooo0_l00005ooooo`;o00002Oooool2o`0000?ooooo0_l0000?ooooo`;o0000Woooool2o`0003Ko
oooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0000?ooooo`;o00004Oooool2o`0000cooooo
1_l00006ooooo`;o00004?ooool2o`0000?ooooo0_l0000?ooooo`;o0000Woooool2o`00017ooooo
0_l0000Sooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o00004Oooool3o`0000_ooooo1_l0
0006ooooo`;o00001oooool2o`00017ooooo0_l00002ooooo`;o00006_ooool4o`0009cooooo0_l0
000Sooooo`007_ooool2o`0002kooooo0_l00009ooooo`Go00004_ooool3o`0000kooooo1Ol00000
0ooooooo0000o`00000:ooooo`;o00003_ooool4o`0000[ooooo0_l0002Booooo`;o00008Oooool0
01kooooo00?o0000ooooooooool0>?ooool4o`0001Cooooo0_l0000;ooooo`Go000000?oooooo`00
0?l000003Oooool2o`0001cooooo0_l0000Fooooo`;o0000N_ooool2o`00027ooooo000Nooooo`03
o`000?oooooooooo01Gooooo0_l0000Mooooo`;o00000oooool2o`0000cooooo0ol0000Cooooo`Co
000000?oooooo`000?l000001oooool2o`0000_ooooo0_l0000^ooooo`;o0000WOooool001kooooo
00?o0000ooooooooool05Oooool2o`0001gooooo0_l000000ooooooo0000o`00000>ooooo`?o0000
1?ooool3o`0000;ooooo0ol00008ooooo`;o00000_ooool2o`0000Oooooo0_l00009ooooo`Co0000
0_ooool2o`0001Kooooo0ol0000Aooooo`;o0000WOooool001kooooo00?o0000ooooooooool01?oo
ool2o`0001Kooooo0_l0000Iooooo`;o00002Oooool2o`0000Cooooo0_l00004ooooo`So00007_oo
ool4o`0000Cooooo0_l0000Fooooo`?o00004Oooool2o`0009gooooo000Nooooo`03o`000?oooooo
oooo00Cooooo0_l0000Fooooo`;o00009?ooool2o`0000?ooooo0ol00005ooooo`Co00006_ooool2
o`0000Gooooo0_l00003ooooo`;o0000[oooool2o`0001_ooooo000Nooooo`03o`000?oooooooooo
02cooooo0_l00006ooooo`;o00003?ooool4o`000004ooooool0003o0000o`0000gooooo1Ol0000A
ooooo`;o00001Oooool2o`0000;ooooo0ol00017ooooo`;o0000D_ooool2o`0001;ooooo0_l0000K
ooooo`007_ooool00ol0003oooooooooo`0/ooooo`;o00001_ooool2o`0000kooooo1?l0000?oooo
o`So00001_ooool2o`000003ooooool0003o000000Kooooo0_l00002ooooo`;o00000_ooool2o`00
033ooooo0_l0000Fooooo`;o0000D_ooool2o`0002oooooo000Nooooo`03o`000?oooooooooo03go
oooo0_l00007ooooo`;o00003?ooool;o`0000Gooooo0ol000000ooooooo0000o`000006ooooo`;o
000000?oooooo`000?l00000=Oooool2o`00063ooooo0_l00008ooooo`;o00006oooool2o`0001;o
oooo000Nooooo`03o`000?oooooooooo03gooooo0_l00009ooooo`;o00001oooool2o`000003oooo
ool0003o000000;o00001_ooool2o`0000Cooooo0_l00009ooooo`;o00000_ooool2o`0004oooooo
0ol0000Kooooo`;o0000:?ooool2o`0000Sooooo0_l0000Kooooo`;o00004_ooool001kooooo00?o
0000ooooooooool02Oooool4o`0000Wooooo0_l0000Xooooo`;o00001_ooool2o`0000Oooooo1ol0
0006ooooo`;o00003Oooool4o`0000;ooooo0_l0001?ooooo`?o00006oooool2o`0006?ooooo000N
ooooo`03o`000?oooooooooo00Wooooo1?l00009ooooo`;o00005oooool2o`0000oooooo0_l00006
ooooo`;o00002Oooool4o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l000000oooool2
o`0000;ooooo0_l00004ooooo`;o00005Oooool2o`0001?ooooo0_l0002Vooooo`007_ooool00ol0
003oooooooooo`0>ooooo`;o00007oooool2o`0001Kooooo0_l0000:ooooo`?o000000Coooooo`00
0?l0003ooooo0ol000000ooooooo0000o`000003o`000004ooooool0003o0000ooooo`Co00001ooo
ool3o`0001Gooooo0_l0000Cooooo`;o00000_ooool4o`0007_ooooo0_l0000>ooooo`;o00004ooo
ool001kooooo00?o0000ooooooooool03_ooool2o`000003ooooool0003o000000gooooo0_l0000A
ooooo`;o00004_ooool2o`0000kooooo0_l000000ooooooo0000o`000006o`0000Gooooo0ol00008
ooooo`;o00001oooool2o`0000cooooo0_l0000Hooooo`Co0000Noooool2o`0000kooooo0_l0000C
ooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o00003Oooool2o`00017ooooo0_l0000Boooo
o`;o00002oooool2o`000003ooooool0003o000000So00001oooool2o`0000oooooo1?l0000<oooo
o`;o0000_?ooool001kooooo00?o0000ooooooooool01?ooool2o`0000Kooooo0_l0000`ooooo`;o
00004?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000;o
00000_ooool2o`0000[ooooo0_l00009ooooo`;o00007_ooool2o`000:cooooo000Nooooo`;o0000
1Oooool2o`0000Kooooo0_l0000/ooooo`;o00000_ooool2o`00013ooooo0_l00002ooooo`;o0000
00Coooooo`000?l0003o00000_ooool8o`0000;ooooo0_l00006ooooo`;o00002?ooool2o`0001oo
oooo0_l0002/ooooo`007_ooool00ol0003oooooooooo`0Zooooo`;o00003_ooool2o`0001_ooooo
1_l000000ooooooo0000o`000004o`0000;ooooo0_l0000<ooooo`;o00000_ooool2o`00077ooooo
0_l0001Jooooo`007_ooool00ol0003oooooooooo`0Zooooo`;o0000:_ooool>o`0000Cooooo0_l0
000:ooooo`;o00000_ooool2o`0000cooooo0_l0000<ooooo`;o00000oooool2o`0002Cooooo0_l0
000Qooooo`;o00001oooool2o`0002oooooo0_l0000Yooooo`007_ooool00ol0003oooooooooo`04
ooooo`;o000000?oooooo`000?l000007_ooool2o`0002cooooo0ol00003ooooo`_o000000Cooooo
o`000?l0003o00007?ooool2o`0000cooooo0_l00003ooooo`;o00009?ooool2o`00027ooooo0_l0
0003ooooo`;o0000<oooool2o`0002Wooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l00000
0ooooooo0000o`00000Nooooo`;o00003oooool2o`0001_ooooo0ol00002ooooo`co000000?ooooo
o`000?l000006Oooool4o`00067ooooo0_l0001Nooooo`007_ooool00ol0003oooooooooo`0_oooo
o`;o00001oooool2o`0000;ooooo0_l0000?ooooo`;o00001_ooool3o`000003ooooool0003o0000
00Co000000?oooooo`000?l000000ol0000Looooo`Go000000?oooooo`000?l00000=oooool2o`00
08Gooooo000Nooooo`03o`000?oooooooooo02oooooo0_l0000;ooooo`;o00003oooool2o`0000Ko
oooo0_l000000ooooooo0000o`000004o`0000_ooooo0_l00002ooooo`;o00004_ooool3o`0000?o
oooo0_l0000gooooo`;o0000;_ooool2o`0005Gooooo000Nooooo`03o`000?oooooooooo00kooooo
0_l00010ooooo`?o000000?oooooo`000?l000002?l0000:ooooo`?o00000_ooool2o`0001Sooooo
0_l0000hooooo`;o0000;Oooool2o`0005Gooooo000Nooooo`03o`000?oooooooooo00kooooo0_l0
000looooo`;o00000_ooool9o`000004ooooool0003o0000ooooo`;o00000oooool4o`0000;ooooo
0_l00002ooooo`Co00005?ooool6o`000003ooooool0003o000000?ooooo0_l0000Jooooo`;o0000
4oooool2o`0005_ooooo0_l00009ooooo`;o00007?ooool001kooooo00?o0000ooooooooool0@?oo
ool2o`0000Wooooo0ol00004ooooo`Oo000000Coooooo`000?l0003ooooo0_l00003ooooo`Co0000
1_ooool4o`0001Cooooo0ol000001?oooooo0000o`000?ooool2o`0000?ooooo0_l00009ooooo`;o
00003oooool2o`0000_ooooo0_l0001>ooooo`;o00003oooool2o`0000;ooooo0_l00009ooooo`;o
00007?ooool001kooooo00?o0000ooooooooool03oooool2o`0002oooooo0_l00008ooooo`?o0000
2?ooool3o`0000;ooooo0_l0000Tooooo`;o00006Oooool2o`0000Cooooo0_l0000Fooooo`;o0000
C_ooool2o`0000oooooo0_l0000[ooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o0000=ooo
ool5o`0000Kooooo1_l000001?oooooo0000o`000?ooool2o`0001Wooooo0_l00006ooooo`;o0000
1Oooool2o`000003ooooool0003o000000;ooooo0_l0000Aooooo`;o0000Y?ooool001kooooo00?o
0000ooooooooool04?ooool2o`0002Kooooo0_l0000;ooooo`;o000000Coooooo`000?l0003ooooo
1Ol00003ooooo`Wo000000?oooooo`000?l000006Oooool2o`0000gooooo1Ol00002ooooo`;o0000
;oooool2o`0008Kooooo000Nooooo`03o`000?oooooooooo013ooooo0_l000000ooooooo0000o`00
0007ooooo`;o00006_ooool2o`0000Oooooo0_l00002ooooo`_o00001?ooool6o`0001?ooooo0_l0
000Cooooo`;o00000oooool5o`0001?ooooo0ol00009ooooo`;o00004_ooool2o`0005Wooooo0ol0
000Hooooo`;o00004?ooool001kooooo00?o0000ooooooooool04oooool2o`0000Oooooo0_l0000C
ooooo`;o00003Oooool4o`0000?ooooo1?l0000Rooooo`;o00004oooool2o`000003ooooool0003o
000000Go00004oooool3o`0000Wooooo0_l0001]ooooo`?o00006?ooool2o`00013ooooo000Noooo
o`03o`000?oooooooooo033ooooo0ol00009ooooo`;o00000_ooool4o`0000;ooooo0_l0000Foooo
o`;o00003Oooool2o`0000Wooooo0_l00009ooooo`Oo0000:?ooool2o`0009?ooooo000Nooooo`;o
00001?ooool2o`0000cooooo0_l0000Cooooo`;o00002?ooool3o`0000Wooooo0_l00003ooooo`;o
00000_ooool3o`0000;ooooo0_l0000Booooo`;o00003Oooool2o`0000Wooooo0_l00009ooooo`;o
00000_ooool4o`0002Oooooo0_l0001eooooo`;o00007?ooool001kooooo00Co0000ooooool0003o
00000_ooool2o`0000cooooo1?l0000Aooooo`;o00004Oooool2o`0000Cooooo0_l00003ooooo`?o
000000?oooooo`000?l000000_l0000Aooooo`;o00001?ooool2o`0002Cooooo0_l00004ooooo`;o
0000<Oooool2o`0006Gooooo0_l0000Looooo`007_ooool01?l0003oooooo`000?l0000Booooo`;o
00009?ooool2o`0000Cooooo0_l00003ooooo`;o00000_ooool2o`0000kooooo0_l00003ooooo`;o
000000Coooooo`000?l0003ooooo0_l0000Rooooo`;o000000?oooooo`000?l000000_l000000ooo
oooo0000o`00000aooooo`;o0000Poooool001kooooo00?o0000ooooooooool0:oooool2o`00017o
oooo0_l00002ooooo`Co00002Oooool2o`0000Cooooo0_l000000ooooooo0000o`000006ooooo`;o
00009Oooool2o`000003ooooool0003o000000;o00008?ooool2o`0000_ooooo0_l0002:ooooo`00
7_ooool00ol0003oooooooooo`07ooooo`;o00003_ooool2o`0001;ooooo0_l00005ooooo`;o0000
2_ooool2o`0000;ooooo0_l0000;ooooo`;o00001?ooool2o`0001cooooo0_l0000iooooo`;o0000
2oooool2o`0005gooooo0_l0000[ooooo`007_ooool00ol0003oooooooooo`07ooooo`;o00002?oo
ool2o`0000Cooooo0_l00007ooooo`;o00004?ooool2o`000003ooooool0003o000000Kooooo0_l0
0003ooooo`?o00009oooool2o`0000Gooooo0_l0002Uooooo`;o0000:oooool001kooooo00?o0000
ooooooooool04Oooool2o`000003ooooool0003o000000[ooooo0_l0000?ooooo`;o00000_ooool2
o`0000Kooooo0_l00002ooooo`Co00007oooool2o`0000Kooooo0_l0000Sooooo`;o0000:_ooool2
o`0008Sooooo000Nooooo`03o`000?oooooooooo017ooooo0_l000000ooooooo0000o`00000Koooo
o`Go00002oooool2o`0001_ooooo0_l00004ooooo`;o0000:oooool2o`0002[ooooo0_l0001Qoooo
o`;o00009Oooool001kooooo00?o0000ooooooooool04Oooool2o`00023ooooo0ol0000Xooooo`;o
00002?ooool2o`0001gooooo0_l0002Gooooo`;o00002?ooool2o`0001_ooooo000Nooooo`03o`00
0?oooooooooo04Kooooo0_l0000Pooooo`;o00007Oooool2o`0000Oooooo0_l0002?ooooo`;o0000
1oooool2o`0001_ooooo000Nooooo`03o`000?oooooooooo04Kooooo0_l0000jooooo`;o00003?oo
ool2o`0008oooooo0_l0000Dooooo`;o00003_ooool001kooooo00?o0000ooooooooool07oooool2
o`0001oooooo0_l00006ooooo`;o0000>?ooool2o`000;?ooooo0_l0000>ooooo`007_ooool00ol0
003oooooooooo`0Oooooo`;o00007_ooool3o`0000Kooooo0_l00004ooooo`;o00009?ooool2o`00
023ooooo0_l0002_ooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o000000?oooooo`000?l0
00003_ooool4o`0000Wooooo0_l0000=ooooo`;o000000?oooooo`000?l000008Oooool2o`00023o
oooo0_l0002_ooooo`005?ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0
2oooool2o`0001;ooooo0_l000000ooooooo0000o`00000>ooooo`Co00002_ooool2o`0000oooooo
1?l0000Fooooo`;o0000Toooool2o`0004Gooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool02oooool2o`0001;ooooo0_l0000Oooooo`;o00004Oooool2o`0000_ooooo0_l0
0009ooooo`;o00009oooool2o`0000[ooooo0_l0000looooo`;o00008?ooool2o`0001Wooooo0_l0
000Oooooo`;o00002Oooool001Kooooo00?o0000ooooooooool01Oooool3o`0001oooooo0_l0000o
ooooo`;o00004Oooool2o`0001oooooo0_l0000:ooooo`;o0000??ooool2o`0003_ooooo0_l0000O
ooooo`;o00002Oooool001Kooooo00?o0000ooooooooool0Noooool2o`000=;ooooo000Fooooo`03
o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_oo
ool00ol0003oooooooooo`3ooooooe3ooooo000Dooooo`03oeEEEOmVIVKo00000?ooooooD_ooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.40657 .90659 Mdot
.12388 .72359 Mdot
.16601 .83869 Mdot
.36796 .88482 Mdot
.24092 .80081 Mdot
.29511 .85202 Mdot
.86053 .98163 Mdot
.21408 .8435 Mdot
.3443 .90092 Mdot
.29377 .45731 Mdot
.20995 .94223 Mdot
.21261 .85174 Mdot
.17483 .80461 Mdot
.92521 .85851 Mdot
.24702 .85806 Mdot
.26003 .54943 Mdot
.3535 .51258 Mdot
.21381 .74754 Mdot
.39223 .91176 Mdot
.39539 .89195 Mdot
.02078 .86719 Mdot
.27666 .87833 Mdot
.14409 .80212 Mdot
.49508 .95043 Mdot
.33973 .92856 Mdot
.21569 .88922 Mdot
.277 .9302 Mdot
.29018 .70724 Mdot
.20786 .90805 Mdot
.29081 .89921 Mdot
.23561 .81791 Mdot
.25449 .85422 Mdot
.28667 .95335 Mdot
.51335 .95026 Mdot
.18187 .99794 Mdot
.32028 .92722 Mdot
.98522 .87996 Mdot
.54788 .1583 Mdot
.22198 .78471 Mdot
.2991 .93974 Mdot
.26691 .84395 Mdot
.02758 .9793 Mdot
.13559 .78942 Mdot
.37281 .32606 Mdot
.88192 .90208 Mdot
.04321 .96277 Mdot
.77021 .86943 Mdot
.15003 .65239 Mdot
.28656 .94688 Mdot
.1827 .03922 Mdot
.18262 .67224 Mdot
.03447 .87339 Mdot
.1899 .82276 Mdot
.3004 .8584 Mdot
.16585 .78872 Mdot
.40255 .35315 Mdot
.41257 .88505 Mdot
.19271 .80646 Mdot
.2728 .92854 Mdot
.41446 .02292 Mdot
.31092 .88261 Mdot
.2262 .86466 Mdot
.93994 .02144 Mdot
.3452 .92271 Mdot
.29496 .82367 Mdot
.31321 .86111 Mdot
.00733 .90843 Mdot
.27504 .9318 Mdot
.28003 .84182 Mdot
.2526 .89781 Mdot
.33981 .40031 Mdot
.33426 .08427 Mdot
.16457 .79692 Mdot
.22315 .3159 Mdot
.17248 .98089 Mdot
.36885 .885 Mdot
.32623 .74335 Mdot
.12338 .19579 Mdot
.27213 .89429 Mdot
.49734 .9148 Mdot
.09843 .75428 Mdot
.94665 .20644 Mdot
.30493 .26874 Mdot
.2139 .8464 Mdot
.84899 .12228 Mdot
.76556 .45068 Mdot
.23521 .85423 Mdot
.29623 .94737 Mdot
.2606 .84413 Mdot
.41958 .06985 Mdot
.37425 .90019 Mdot
.70485 .51068 Mdot
.21413 .06447 Mdot
.4127 .03512 Mdot
.39878 .945 Mdot
.10831 .75002 Mdot
.1632 .05821 Mdot
.04267 .93446 Mdot
.27739 .86696 Mdot
.58083 .96968 Mdot
.21817 .88588 Mdot
.17205 .64884 Mdot
.45943 .86589 Mdot
.11372 .7286 Mdot
.21654 .75332 Mdot
.1529 .79201 Mdot
.27376 .47874 Mdot
.2493 .51276 Mdot
.05744 .82902 Mdot
.38447 .5297 Mdot
.00161 .83404 Mdot
.20934 .26165 Mdot
.37509 .68747 Mdot
.21342 .76781 Mdot
.83931 .78488 Mdot
.85786 .08295 Mdot
.95142 .9345 Mdot
.16563 .81319 Mdot
.2181 .25791 Mdot
.36532 .79516 Mdot
.27615 .95425 Mdot
.076 .72358 Mdot
.19339 .95425 Mdot
.41354 .16984 Mdot
.97437 .73545 Mdot
.65894 .80134 Mdot
.07977 .81764 Mdot
.39624 .90762 Mdot
.47838 .91077 Mdot
.39398 .74045 Mdot
.61698 .70427 Mdot
.07491 .29392 Mdot
.01427 .42846 Mdot
.24046 .7646 Mdot
.27863 .80504 Mdot
.15131 .74411 Mdot
.14807 .78292 Mdot
.27666 .89899 Mdot
.29526 .82925 Mdot
.32334 .86279 Mdot
.38463 .87774 Mdot
.33838 .92119 Mdot
.28125 .89564 Mdot
.50369 .97474 Mdot
.90863 .58239 Mdot
.16753 .90951 Mdot
.40841 .88349 Mdot
.25265 .91343 Mdot
.32082 .81583 Mdot
.01519 .10152 Mdot
.43306 .83132 Mdot
.27308 .93969 Mdot
.25501 .8178 Mdot
.39196 .90395 Mdot
.24937 .87796 Mdot
.17072 .81966 Mdot
.28508 .84571 Mdot
.70427 .18791 Mdot
.33783 .9091 Mdot
.30378 .55761 Mdot
.29532 .95089 Mdot
.37266 .01079 Mdot
.87136 .98881 Mdot
.23667 .79057 Mdot
.29124 .87266 Mdot
.21162 .79338 Mdot
.25395 .91147 Mdot
.31038 .91392 Mdot
.8042 .74803 Mdot
.23222 .7465 Mdot
.23174 .92617 Mdot
.25765 .89885 Mdot
.26349 .0205 Mdot
.78606 .50235 Mdot
.41887 .927 Mdot
.27008 .96777 Mdot
.55977 .86117 Mdot
.18634 .8829 Mdot
.81183 .85407 Mdot
.03281 .89362 Mdot
.22286 .77145 Mdot
.16616 .91526 Mdot
.38029 .98836 Mdot
.93524 .95658 Mdot
.34064 .83253 Mdot
.26481 .64471 Mdot
.31177 .61177 Mdot
.34773 .88136 Mdot
.29682 .93935 Mdot
.47147 .90371 Mdot
.40989 .92398 Mdot
.90474 .97595 Mdot
.39923 .90355 Mdot
.23207 .82801 Mdot
.36518 .78279 Mdot
.16396 .83198 Mdot
.39282 .01917 Mdot
.14754 .97543 Mdot
.34504 .90397 Mdot
.20765 .9761 Mdot
.94385 .15922 Mdot
.52124 .67521 Mdot
.24448 .77997 Mdot
.93887 .90425 Mdot
.3407 .92821 Mdot
.30389 .94639 Mdot
.14385 .83418 Mdot
.27389 .93372 Mdot
.21524 .7569 Mdot
.33652 .93152 Mdot
.22322 .75403 Mdot
.39831 .87593 Mdot
.99147 .93162 Mdot
.30523 .83265 Mdot
.29108 .93654 Mdot
.36205 .12057 Mdot
.27931 .92223 Mdot
.36849 .53008 Mdot
.3166 .79892 Mdot
.99673 .99354 Mdot
.84069 .11472 Mdot
.37293 .01912 Mdot
.32574 .91457 Mdot
.31081 .90066 Mdot
.4328 .07028 Mdot
.30261 .05528 Mdot
.38389 .76328 Mdot
.11719 .79119 Mdot
.29703 .59909 Mdot
.29249 .88531 Mdot
.18246 .85366 Mdot
.39968 .05011 Mdot
.25826 .91304 Mdot
.67542 .75659 Mdot
.38598 .18231 Mdot
.3978 .98367 Mdot
.64865 .59317 Mdot
.19226 .80951 Mdot
.26231 .13062 Mdot
.83203 .34058 Mdot
.22015 .77156 Mdot
.25377 .90412 Mdot
.08432 .6942 Mdot
.35322 .7244 Mdot
.27358 .82834 Mdot
.27675 .87679 Mdot
.35054 .084 Mdot
.24824 .91887 Mdot
.62601 .72866 Mdot
.23899 .84905 Mdot
.04521 .87913 Mdot
.16505 .78238 Mdot
.42006 .03278 Mdot
.72453 .63861 Mdot
.91564 .6983 Mdot
.19527 .63148 Mdot
.20049 .81934 Mdot
.36606 .05013 Mdot
.03086 .83881 Mdot
.1015 .88327 Mdot
.4028 .88705 Mdot
.30643 .7683 Mdot
.3265 .38439 Mdot
.53555 .15605 Mdot
.26049 .90569 Mdot
.82066 .26456 Mdot
.31211 .64589 Mdot
.96653 .77441 Mdot
.17786 .81326 Mdot
.29331 .93808 Mdot
.28225 .87046 Mdot
.81534 .80602 Mdot
.28636 .87809 Mdot
.30319 .77348 Mdot
.10089 .79055 Mdot
.16029 .77962 Mdot
.29378 .8021 Mdot
.15009 .17124 Mdot
.30226 .90175 Mdot
.22941 .64475 Mdot
.38719 .918 Mdot
.27088 .88884 Mdot
.21052 .79411 Mdot
.00937 .00071 Mdot
.21889 .80698 Mdot
.32817 .91659 Mdot
.24036 .74562 Mdot
.55597 .84508 Mdot
.20705 .66142 Mdot
.25995 .66645 Mdot
.14919 .66811 Mdot
.54814 .12075 Mdot
.3805 .90709 Mdot
.42051 .74794 Mdot
.75982 .49605 Mdot
.48299 .92914 Mdot
.25308 .82556 Mdot
.31026 .64616 Mdot
.40213 .86153 Mdot
.75684 .81373 Mdot
.57708 .78477 Mdot
.22773 .87688 Mdot
.31545 .02288 Mdot
.31884 .12151 Mdot
.45096 .09828 Mdot
.09617 .83247 Mdot
.27984 .92504 Mdot
.26143 .90338 Mdot
.81769 .97049 Mdot
.48006 .7363 Mdot
.27672 .94612 Mdot
.39637 .79648 Mdot
.21717 .88991 Mdot
.435 .98006 Mdot
.3218 .91125 Mdot
.32009 .72279 Mdot
.25484 .06318 Mdot
.70798 .60619 Mdot
.24911 .94818 Mdot
.5561 .29809 Mdot
.25156 .7479 Mdot
.26481 .95973 Mdot
.21994 .62655 Mdot
.35217 .05025 Mdot
.23113 .78465 Mdot
.17454 .84559 Mdot
.30196 .90819 Mdot
.40285 .87375 Mdot
.19929 .80896 Mdot
.19746 .85799 Mdot
.39852 .88983 Mdot
.29738 .84257 Mdot
.26133 .5364 Mdot
.72739 .70775 Mdot
.35087 .08357 Mdot
.20318 .23251 Mdot
.58059 .71081 Mdot
.27919 .94277 Mdot
.27358 .60157 Mdot
.72992 .45229 Mdot
.29868 .88588 Mdot
.19439 .00808 Mdot
.38824 .86146 Mdot
.32921 .12592 Mdot
.59961 .05777 Mdot
.31662 .70354 Mdot
.98788 .9589 Mdot
.07082 .45998 Mdot
.28484 .97851 Mdot
.21672 .84167 Mdot
.16968 .81932 Mdot
.1849 .79969 Mdot
.43708 .95396 Mdot
.19721 .63254 Mdot
.19795 .83679 Mdot
.29139 .88075 Mdot
.05759 .96327 Mdot
.24412 .84182 Mdot
.18663 .79221 Mdot
.34986 .76677 Mdot
.26034 .90138 Mdot
.34136 .81354 Mdot
.26246 .8327 Mdot
.20818 .75655 Mdot
.29083 .90102 Mdot
.10957 .9098 Mdot
.05907 .67647 Mdot
.33609 .99395 Mdot
.09618 .23739 Mdot
.28898 .86266 Mdot
.28811 .94076 Mdot
.28638 .91812 Mdot
.19025 .84305 Mdot
.322 .872 Mdot
.55306 .8822 Mdot
.61568 .93498 Mdot
.87128 .89087 Mdot
.29689 .95582 Mdot
.79639 .83897 Mdot
.26755 .93892 Mdot
.27656 .88568 Mdot
.40189 .87227 Mdot
.1505 .47582 Mdot
.89457 .6632 Mdot
.32517 .76109 Mdot
.13413 .85859 Mdot
.18876 .63242 Mdot
.21202 .33862 Mdot
.28113 .93805 Mdot
.17096 .86259 Mdot
.38493 .87736 Mdot
.23581 .76129 Mdot
.20472 .88029 Mdot
.2372 .80751 Mdot
.2473 .80851 Mdot
.4029 .38812 Mdot
.29495 .49603 Mdot
.73908 .2196 Mdot
.27076 .93152 Mdot
.2524 .80927 Mdot
.11051 .84268 Mdot
.90464 .80858 Mdot
.88245 .12142 Mdot
.22186 .85813 Mdot
.12467 .11745 Mdot
.56508 .64755 Mdot
.23651 .65328 Mdot
.38316 .06967 Mdot
.28915 .12976 Mdot
.23514 .78169 Mdot
.2934 .95487 Mdot
.33112 .92379 Mdot
.29496 .95119 Mdot
.36907 .97214 Mdot
.88046 .54481 Mdot
.23217 .75002 Mdot
.46521 .86402 Mdot
.30157 .02445 Mdot
.32269 .67787 Mdot
.26733 .89657 Mdot
.30097 .9288 Mdot
.51515 .63334 Mdot
.46752 .2058 Mdot
.23037 .75055 Mdot
.19358 .81971 Mdot
.79929 .81396 Mdot
.97215 .21298 Mdot
.33366 .88824 Mdot
.32758 .06744 Mdot
.10932 .66157 Mdot
.69759 .4365 Mdot
.9125 .79552 Mdot
.93369 .04631 Mdot
.40344 .86951 Mdot
.82528 .9397 Mdot
.18201 .67992 Mdot
.31306 .80042 Mdot
.49536 .65761 Mdot
.36806 .76661 Mdot
.8751 .92978 Mdot
.33352 .66372 Mdot
.326 .35015 Mdot
.27517 .33052 Mdot
.28798 .88067 Mdot
.29957 .90082 Mdot
.26947 .90327 Mdot
.25633 .96954 Mdot
.2449 .76637 Mdot
.63714 .34973 Mdot
.19404 .90376 Mdot
.55171 .85532 Mdot
.05579 .83096 Mdot
.31246 .90028 Mdot
.2898 .89274 Mdot
.39657 .72168 Mdot
.2741 .94064 Mdot
.34306 .92162 Mdot
.30866 .89858 Mdot
.51691 .82306 Mdot
.36067 .59473 Mdot
.34442 .85062 Mdot
.29325 .93858 Mdot
.286 .88061 Mdot
.158 .85614 Mdot
.46429 .03677 Mdot
.04319 .94731 Mdot
.27659 .96088 Mdot
.59004 .7776 Mdot
.26337 .87231 Mdot
.23508 .90444 Mdot
.28722 .87503 Mdot
.23529 .86455 Mdot
.21674 .84962 Mdot
.21501 .84767 Mdot
.2 .82124 Mdot
.26024 .86601 Mdot
.20595 .75682 Mdot
.19529 .82679 Mdot
.63542 .02478 Mdot
.1143 .86878 Mdot
.18953 .12458 Mdot
.30917 .8256 Mdot
.26809 .89214 Mdot
.37291 .86143 Mdot
.40687 .90796 Mdot
.29728 .95241 Mdot
.5224 .19235 Mdot
.31007 .1608 Mdot
.348 .89602 Mdot
.26436 .71434 Mdot
.19748 .83453 Mdot
.31799 .91842 Mdot
.38064 .29996 Mdot
.14151 .64474 Mdot
.37507 .94132 Mdot
.15222 .98424 Mdot
.31021 .81224 Mdot
.22408 .97961 Mdot
.54543 .95023 Mdot
.30647 .06073 Mdot
.31251 .80172 Mdot
.38392 .70188 Mdot
.26625 .91797 Mdot
.32359 .78684 Mdot
.2241 .74112 Mdot
.10132 .03593 Mdot
.23374 .87164 Mdot
.5983 .80017 Mdot
.33855 .92521 Mdot
.31856 .92003 Mdot
.32064 .82005 Mdot
.3706 .16084 Mdot
.29129 .32122 Mdot
.33533 .89104 Mdot
.23757 .8133 Mdot
.7142 .76556 Mdot
.287 .74662 Mdot
.11913 .74923 Mdot
.8934 .42859 Mdot
.26504 .79961 Mdot
.25933 .86469 Mdot
.17293 .83894 Mdot
.2756 .89043 Mdot
.18875 .96734 Mdot
.58167 .9737 Mdot
.67877 .04648 Mdot
.29065 .93211 Mdot
.16882 .20799 Mdot
.44942 .00265 Mdot
.51689 .78415 Mdot
.77896 .75428 Mdot
.87814 .52827 Mdot
.22857 .80675 Mdot
.16799 .74167 Mdot
.20754 .84104 Mdot
.22633 .89663 Mdot
.30733 .83303 Mdot
.31802 .93001 Mdot
.60378 .19821 Mdot
.09143 .67318 Mdot
.32198 .86134 Mdot
.7619 .64086 Mdot
.16682 .91742 Mdot
.25689 .87552 Mdot
.29145 .8526 Mdot
.15826 .04685 Mdot
.61578 .34647 Mdot
.26865 .92965 Mdot
.20614 .77035 Mdot
.1766 .84134 Mdot
.14675 .92883 Mdot
.91262 .09529 Mdot
.30651 .94037 Mdot
.52154 .98076 Mdot
.08375 .69345 Mdot
.8572 .89714 Mdot
.31447 .15597 Mdot
.27527 .94634 Mdot
.35841 .92106 Mdot
.61219 .71199 Mdot
.22476 .75771 Mdot
.20324 .94391 Mdot
.6015 .1752 Mdot
.52933 .0204 Mdot
.23827 .74585 Mdot
.28836 .92915 Mdot
.29132 .92257 Mdot
.31517 .90479 Mdot
.91713 .2451 Mdot
.26622 .84491 Mdot
.27936 .65845 Mdot
.14389 .70234 Mdot
.26365 .86066 Mdot
.40849 .8647 Mdot
.22237 .76412 Mdot
.32295 .90425 Mdot
.47273 .63891 Mdot
.20894 .90045 Mdot
.15444 .77989 Mdot
.21113 .88876 Mdot
.68237 .98254 Mdot
.79296 .66478 Mdot
.26005 .76754 Mdot
.36457 .86692 Mdot
.54364 .23682 Mdot
.3186 .95386 Mdot
.2973 .64799 Mdot
.97245 .12012 Mdot
.12397 .7494 Mdot
.39832 .9436 Mdot
.19192 .82282 Mdot
.17093 .78799 Mdot
.30253 .13017 Mdot
.2288 .97482 Mdot
.16079 .9407 Mdot
.21687 .88507 Mdot
.31803 .8435 Mdot
.18407 .84106 Mdot
.31453 .94892 Mdot
.24731 .97107 Mdot
.30405 .91226 Mdot
.29642 .91866 Mdot
.17676 .83414 Mdot
.04958 .94061 Mdot
.91034 .82918 Mdot
.23491 .79999 Mdot
.27686 .93372 Mdot
.26803 .89575 Mdot
.85962 .93342 Mdot
.40454 .90178 Mdot
.88632 .99386 Mdot
.71348 .61036 Mdot
.2787 .84692 Mdot
.02376 .60579 Mdot
.40134 .89531 Mdot
.30913 .56413 Mdot
.3283 .0574 Mdot
.21557 .90062 Mdot
.24834 .85735 Mdot
.80309 .89961 Mdot
.24574 .18859 Mdot
.35896 .66617 Mdot
.40392 .90929 Mdot
.74505 .85085 Mdot
.00424 .91642 Mdot
.35289 .65123 Mdot
.64481 .27212 Mdot
.77303 .3901 Mdot
.13786 .77242 Mdot
.00097 .84546 Mdot
.24596 .80621 Mdot
.31527 .90611 Mdot
.40194 .97306 Mdot
.87958 .92491 Mdot
.26669 .85895 Mdot
.42835 .23412 Mdot
.21104 .84329 Mdot
.25709 .13685 Mdot
.25051 .77507 Mdot
.24959 .85027 Mdot
.06421 .85413 Mdot
.27961 .84898 Mdot
.02027 .97235 Mdot
.98804 .83796 Mdot
.9943 .87673 Mdot
.30837 .8929 Mdot
.09113 .77595 Mdot
.48899 .97491 Mdot
.20724 .84544 Mdot
.86394 .93788 Mdot
.4028 .051 Mdot
.18642 .96298 Mdot
.43232 .76772 Mdot
.30982 .89416 Mdot
.60283 .32333 Mdot
.30619 .93936 Mdot
.18305 .81847 Mdot
.54249 .84288 Mdot
.32061 .86513 Mdot
.27191 .93575 Mdot
.87067 .90669 Mdot
.13844 .84915 Mdot
.83479 .65067 Mdot
.27648 .96323 Mdot
.85999 .17262 Mdot
.53715 .68918 Mdot
.26358 .90018 Mdot
.05127 .86512 Mdot
.58788 .97341 Mdot
.44704 .64873 Mdot
.4933 .09168 Mdot
.94369 .24683 Mdot
.13162 .89455 Mdot
.26787 .97268 Mdot
.992 .09983 Mdot
.22741 .88087 Mdot
.64098 .84245 Mdot
.23142 .75658 Mdot
.94955 .91701 Mdot
.38581 .81059 Mdot
.43273 .29405 Mdot
.53331 .95689 Mdot
.04003 .56556 Mdot
.39725 .91706 Mdot
.26657 .84602 Mdot
.32039 .00655 Mdot
.05884 .75199 Mdot
.92448 .80056 Mdot
.46339 .76885 Mdot
.20002 .76874 Mdot
.15444 .66031 Mdot
.90476 .8834 Mdot
.26157 .42648 Mdot
.19822 .67545 Mdot
.28627 .93894 Mdot
.15193 .85164 Mdot
.29262 .88597 Mdot
.90316 .60526 Mdot
.75875 .81132 Mdot
.09723 .98077 Mdot
.2949 .49883 Mdot
.16568 .62883 Mdot
.16754 .81695 Mdot
.3163 .83317 Mdot
.43505 .08532 Mdot
.20353 .96054 Mdot
.17874 .41802 Mdot
.21676 .01256 Mdot
.1367 .31453 Mdot
.34153 .91206 Mdot
.5265 .67526 Mdot
.32789 .06292 Mdot
.93093 .75238 Mdot
.79172 .07058 Mdot
.11712 .79062 Mdot
.56221 .95493 Mdot
.25529 .90635 Mdot
.23522 .82169 Mdot
.68847 .09993 Mdot
.23867 .91787 Mdot
.40048 .8691 Mdot
.75831 .05048 Mdot
.25539 .83688 Mdot
.14911 .98759 Mdot
.44364 .69897 Mdot
.26461 .87225 Mdot
.96299 .72319 Mdot
.27445 .95864 Mdot
.98423 .81104 Mdot
.49815 .98437 Mdot
.21493 .98272 Mdot
.22914 .95684 Mdot
.15863 .82875 Mdot
.33645 .88353 Mdot
.63749 .14561 Mdot
.49551 .69674 Mdot
.58651 .29768 Mdot
.33631 .11608 Mdot
.13605 .75063 Mdot
.56015 .4203 Mdot
.25766 .82166 Mdot
.39574 .8654 Mdot
.42744 .9234 Mdot
.00599 .98653 Mdot
.72496 .76438 Mdot
.08125 .80574 Mdot
.27515 .94499 Mdot
.38624 .91244 Mdot
.19466 .92969 Mdot
.98207 .93931 Mdot
.04704 .77505 Mdot
.2396 .8386 Mdot
.45036 .69618 Mdot
.40671 .84842 Mdot
.2731 .84341 Mdot
.2823 .86029 Mdot
.24153 .74049 Mdot
.07586 .77379 Mdot
.19792 .76923 Mdot
.207 .82967 Mdot
.4733 .91978 Mdot
.21788 .84772 Mdot
.14441 .482 Mdot
.23833 .82507 Mdot
.24408 .614 Mdot
.33484 .88154 Mdot
.58691 .99477 Mdot
.51292 .6755 Mdot
.14725 .97396 Mdot
.1418 .39754 Mdot
.33445 .92739 Mdot
.45701 .85465 Mdot
.18267 .77963 Mdot
.16532 .78239 Mdot
.07224 .60701 Mdot
.32925 .84396 Mdot
.15974 .8586 Mdot
.19471 .83156 Mdot
.38997 .70867 Mdot
.14232 .50138 Mdot
.37451 .88006 Mdot
.38197 .69881 Mdot
.59482 .44757 Mdot
.57485 .65685 Mdot
.28038 .87018 Mdot
.28808 .77894 Mdot
.24461 .61834 Mdot
.32541 .86469 Mdot
.31719 .91681 Mdot
.16425 .83525 Mdot
.17526 .72734 Mdot
.08453 .25561 Mdot
.08966 .12098 Mdot
.19676 .88709 Mdot
.40822 .94113 Mdot
.18162 .81727 Mdot
.22618 .6937 Mdot
.01737 .61974 Mdot
.38516 .90683 Mdot
.39402 .0993 Mdot
.37418 .61141 Mdot
.27229 .90271 Mdot
.25361 .7671 Mdot
.35343 .80029 Mdot
.35586 .09904 Mdot
.22547 .7535 Mdot
.16142 .71186 Mdot
.30238 .63988 Mdot
.48906 .98103 Mdot
.29807 .94694 Mdot
.59671 .92793 Mdot
.36352 .93171 Mdot
.16693 .84141 Mdot
.12115 .70314 Mdot
.34737 .86709 Mdot
.29026 .91023 Mdot
.14513 .187 Mdot
.29818 .8431 Mdot
.24862 .87234 Mdot
.96151 .87872 Mdot
.21005 .84251 Mdot
.19284 .83323 Mdot
.19867 .88446 Mdot
.17199 .81874 Mdot
.23282 .85391 Mdot
.26606 .84177 Mdot
.1988 .83562 Mdot
.27803 .87058 Mdot
.09818 .68493 Mdot
.23229 .96038 Mdot
.0058 .93653 Mdot
.51609 .83464 Mdot
.20344 .77074 Mdot
.98463 .95555 Mdot
.02731 .99765 Mdot
.23352 .75666 Mdot
.36174 .12517 Mdot
.28677 .94919 Mdot
.27871 .91004 Mdot
.32952 .35236 Mdot
.00319 .81042 Mdot
.18809 .83398 Mdot
.27698 .92466 Mdot
.33826 .88497 Mdot
.32824 .86998 Mdot
.11903 .00388 Mdot
.6407 .83588 Mdot
.16376 .82871 Mdot
.22207 .88392 Mdot
.25003 .83857 Mdot
.58954 .17688 Mdot
.37383 .08784 Mdot
.28268 .8562 Mdot
.37563 .94794 Mdot
.26292 .95471 Mdot
.85033 .69122 Mdot
.21386 .84574 Mdot
.25435 .53443 Mdot
.13512 .88008 Mdot
.22129 .82815 Mdot
.20117 .84069 Mdot
.34009 .88849 Mdot
.33694 .91284 Mdot
.49326 .41439 Mdot
.20907 .89188 Mdot
.17055 .9521 Mdot
.39942 .91542 Mdot
.30562 .74607 Mdot
.822 .72698 Mdot
.18316 .82176 Mdot
.7275 .79163 Mdot
.25378 .94497 Mdot
.34178 .92703 Mdot
.37033 .88526 Mdot
.07575 .77363 Mdot
.24018 .83635 Mdot
.11827 .32662 Mdot
.35951 .81287 Mdot
.91013 .76255 Mdot
.31452 .86195 Mdot
.71333 .90388 Mdot
.31757 .89221 Mdot
.21927 .8514 Mdot
.193 .82749 Mdot
.16287 .92423 Mdot
.4085 .90988 Mdot
.4018 .85593 Mdot
.54231 .64077 Mdot
.27539 .88158 Mdot
.68086 .79456 Mdot
.33106 .24798 Mdot
.15867 .64831 Mdot
.08488 .8506 Mdot
.26773 .89226 Mdot
.04189 .13509 Mdot
.25379 .85241 Mdot
.59294 .99227 Mdot
.26241 .86401 Mdot
.44446 .86476 Mdot
.18523 .8587 Mdot
.31343 .84895 Mdot
.24924 .62704 Mdot
.67361 .77767 Mdot
.37327 .79348 Mdot
.29392 .92111 Mdot
.20214 .64113 Mdot
.55067 .66486 Mdot
.29772 .84112 Mdot
.35476 .8922 Mdot
.38544 .85574 Mdot
.09663 .7239 Mdot
.59175 .73721 Mdot
.36197 .06126 Mdot
.33154 .92506 Mdot
.09431 .93319 Mdot
.16167 .48583 Mdot
.27978 .83797 Mdot
.41721 .87666 Mdot
.14454 .78774 Mdot
.33809 .88819 Mdot
.43558 .09723 Mdot
.35464 .43893 Mdot
.35024 .85136 Mdot
.20798 .84597 Mdot
.24926 .8512 Mdot
.31404 .99993 Mdot
.3392 .81859 Mdot
.38713 .70087 Mdot
.51651 .48377 Mdot
.28006 .82686 Mdot
.12127 .01475 Mdot
.15957 .77527 Mdot
.18863 .82541 Mdot
.26116 .90708 Mdot
.88536 .95592 Mdot
.39446 .89091 Mdot
.1576 .98966 Mdot
.23119 .94576 Mdot
.26375 .90412 Mdot
.14084 .06074 Mdot
.17822 .81572 Mdot
.31039 .87297 Mdot
.33779 .9297 Mdot
.38918 .97969 Mdot
.10732 .90161 Mdot
.28524 .85785 Mdot
.42504 .88187 Mdot
.01176 .00192 Mdot
.3261 .8662 Mdot
.10265 .10206 Mdot
.26657 .8469 Mdot
.56639 .81999 Mdot
.01745 .9447 Mdot
.38437 .06478 Mdot
.21616 .02303 Mdot
.1576 .83534 Mdot
.94911 .66363 Mdot
.54663 .73424 Mdot
.89184 .04748 Mdot
.83945 .24548 Mdot
.27184 .88596 Mdot
.29735 .90065 Mdot
.24822 .86857 Mdot
.4114 .09827 Mdot
.18553 .84525 Mdot
.0371 .6115 Mdot
.26317 .8682 Mdot
.30061 .03883 Mdot
.10045 .78335 Mdot
.72065 .68758 Mdot
.38007 .47767 Mdot
.0845 .01678 Mdot
.39101 .9936 Mdot
.54394 .97598 Mdot
.59774 .0816 Mdot
.23217 .86909 Mdot
.31092 .64221 Mdot
.94405 .44002 Mdot
.2745 .91577 Mdot
.24915 .93799 Mdot
.22569 .80571 Mdot
.38189 .01036 Mdot
.36615 .5048 Mdot
.30877 .61931 Mdot
.28063 .95051 Mdot
.04544 .83454 Mdot
.44907 .70504 Mdot
.77276 .70499 Mdot
.02488 .8848 Mdot
.261 .93059 Mdot
.73582 .28682 Mdot
.37512 .88651 Mdot
.32441 .76216 Mdot
.07014 .03178 Mdot
.26305 .89573 Mdot
.27369 .96051 Mdot
.20069 .86475 Mdot
.1828 .98046 Mdot
.30449 .84665 Mdot
.18497 .96977 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooo000000;o
00002oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo0_l00008ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0<ooooo`;o
00003oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo000Nooooo`03o`00
0?oooooooooo00;o00002oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo
0_l00008ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00?ooooo0_l00008ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool03?ooool2o`0000oooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`02ooooo`007_ooool00ol0003oooooooooo`0kooooo`;o00009oooool2o`0001;ooooo0_l0
003=ooooo`007_ooool00ol0003oooooooooo`0kooooo`;o00001Oooool2o`00037ooooo0_l00000
0ooooooo0000o`00003=ooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o00002_ooool2o`00
01gooooo0_l0000aooooo`;o0000d?ooool001kooooo00?o0000ooooooooool05oooool2o`0000[o
oooo0_l0001@ooooo`;o00001Oooool2o`000<Wooooo000Nooooo`03o`000?oooooooooo05;ooooo
0_l0000>ooooo`;o00004Oooool2o`0000Gooooo0_l00005ooooo`;o00008oooool2o`0008?ooooo
0_l0000Hooooo`007_ooool00ol0003oooooooooo`12ooooo`;o00003_ooool2o`0000[ooooo0_l0
0002ooooo`;o00007oooool2o`0002?ooooo0_l0000Pooooo`;o0000HOooool2o`0001Sooooo000N
ooooo`03o`000?oooooooooo04;ooooo0_l0000Jooooo`;o0000J_ooool2o`0007_ooooo000Noooo
o`03o`000?oooooooooo01?ooooo0_l0003ooooooc?ooooo000Nooooo`03o`000?oooooooooo01?o
oooo0_l0001]ooooo`Co0000`Oooool001kooooo00?o0000ooooooooool07Oooool2o`0006?ooooo
1?l0000=ooooo`;o0000/_ooool001kooooo00?o0000ooooooooool07Oooool2o`0001Sooooo0_l0
000Uooooo`;o0000<oooool2o`000;;ooooo000Nooooo`03o`000?oooooooooo03Oooooo0_l0000U
ooooo`;o0000ioooool001kooooo00?o0000ooooooooool0;oooool2o`000:Sooooo0_l00013oooo
o`;o00002oooool2o`0001[ooooo000Nooooo`03o`000?oooooooooo02oooooo0_l0000mooooo`;o
00000oooool2o`0000Wooooo0_l0001Iooooo`;o00005oooool2o`0002[ooooo0_l0000;ooooo`;o
00006_ooool001kooooo0_l0001_ooooo`;o00000oooool2o`0000Wooooo0ol0001aooooo`;o0000
Doooool001kooooo00?o0000ooooooooool0G_ooool2o`0001oooooo0_l00036ooooo`007_ooool0
0ol0003oooooooooo`0aooooo`;o0000:oooool2o`0000Oooooo0_l0001Fooooo`;o0000Q_ooool0
01kooooo00?o0000ooooooooool0:_ooool2o`0000Gooooo0_l0000]ooooo`;o00001?ooool3o`00
00Wooooo0_l0001;ooooo`;o0000Q_ooool001kooooo00?o0000ooooooooool0:_ooool2o`0001Go
oooo0_l0000<ooooo`;o00003oooool2o`0000Cooooo0_l0000:ooooo`;o00001Oooool2o`000<co
oooo000Nooooo`03o`000?oooooooooo047ooooo0_l0000<ooooo`;o00005Oooool2o`00017ooooo
0_l0003<ooooo`007_ooool00ol0003oooooooooo`1Vooooo`;o00004?ooool2o`0000[ooooo0_l0
0003ooooo`;o0000L_ooool2o`0004Sooooo000Nooooo`03o`000?oooooooooo07Sooooo0_l0000:
ooooo`;o00000oooool2o`0007;ooooo0_l00018ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
JOooool2o`0000?ooooo0_l0001>ooooo`;o0000Doooool2o`0003;ooooo000Nooooo`03o`000?oo
oooooooo06Wooooo0_l00003ooooo`;o00006Oooool2o`0003?ooooo0_l0001Cooooo`;o0000<_oo
ool001kooooo00?o0000ooooooooool0MOooool2o`0001;ooooo0_l0002looooo`007_ooool00ol0
003oooooooooo`1eooooo`;o00009Oooool2o`000:Wooooo000Nooooo`03o`000?oooooooooo09co
oooo0_l00027ooooo`;o00008?ooool001kooooo00?o0000ooooooooool0L?ooool2o`0000[ooooo
0_l00004ooooo`;o00001Oooool2o`0000?ooooo0_l0002Eooooo`;o00005oooool2o`0000Oooooo
000Nooooo`;o00000_ooool2o`0001[ooooo0_l0001Aooooo`;o00002_ooool2o`0000Cooooo0_l0
0005ooooo`;o00000oooool2o`0004cooooo0_l0001Pooooo`;o00001oooool001kooooo00Co0000
oooooooooooooooo0_l0000Jooooo`;o0000_Oooool2o`0006Wooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooo`kooooo0_l0000hooooo`007_ooool00ol0003oooooooooo`0Tooooo`;o0000
@oooool2o`000:;ooooo0_l0000hooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o00002Ooo
ool2o`0004?ooooo0_l00007ooooo`;o0000>_ooool2o`0008Sooooo0_l0000=ooooo`007_ooool0
0ol0003oooooooooo`0Iooooo`;o0000BOooool2o`0000cooooo0_l0000jooooo`;o0000H?ooool2
o`0000Wooooo0_l0000Kooooo`;o00003Oooool001kooooo00?o0000ooooooooool0>_ooool2o`00
02Sooooo0_l000000ooooooo0000o`000008ooooo`;o0000WOooool2o`0000Wooooo0_l0000Zoooo
o`007_ooool00ol0003oooooooooo`0jooooo`;o00005Oooool2o`0000Oooooo0_l00002ooooo`;o
00001oooool2o`0000Sooooo0_l0003Dooooo`007_ooool00ol0003oooooooooo`1Aooooo`;o0000
1oooool2o`0000;ooooo0_l0003Wooooo`007_ooool00ol0003oooooooooo`09ooooo`;o0000oooo
oolmooooo`007_ooool00ol0003oooooooooo`09ooooo`;o0000A?ooool2o`000?Kooooo000Noooo
o`03o`000?oooooooooo04oooooo0_l0003fooooo`007_ooool00ol0003oooooooooo`3;ooooo`;o
0000N_ooool001kooooo00?o0000ooooooooool0boooool2o`0007[ooooo000Nooooo`;o0000oooo
oom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
06;ooooo0_l00016ooooo`;o00000_ooool2o`0009Oooooo000Nooooo`03o`000?oooooooooo067o
oooo0ol0000@ooooo`;o0000=?ooool2o`0000;ooooo0_l0001oooooo`;o00005_ooool001kooooo
00?o0000ooooooooool0HOooool2o`00017ooooo0_l0002iooooo`;o00005_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`22ooooo`;o0000`oooool0
01kooooo00?o0000ooooooooool0;Oooool2o`0005?ooooo0_l0002?ooooo`;o0000<_ooool001ko
oooo00?o0000ooooooooool0;Oooool2o`00093ooooo0_l0001Booooo`;o0000<_ooool001kooooo
00?o0000ooooooooool0_?ooool2o`000003ooooool0003o000008Kooooo000Nooooo`03o`000?oo
oooooooo07Wooooo0_l00011ooooo`;o0000ROooool001kooooo00?o0000ooooooooool0NOooool2
o`000<cooooo000Nooooo`03o`000?oooooooooo02_ooooo0_l0000Oooooo`;o0000Toooool2o`00
06Cooooo000Nooooo`03o`000?oooooooooo02_ooooo0_l0000Oooooo`;o0000Toooool2o`0006Co
oooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03
o`000?oooooooooo0:Kooooo0_l0002Oooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`0Toooo
o`;o0000P?ooool2o`0001Sooooo0_l00025ooooo`000oooool01Ol@413ooooooooooooooooo410@
00cooooo00?oV9RHob4Q8Oo^k^h01oooool3o`0002Cooooo0_l0002Jooooo`;o0000QOooool000?o
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000oooo
ooooool0oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool01Oooool00ol0003oooooooooo`2Dooooo`;o0000V_ooool2o`0001Gooooo0003ooooo`05
oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
03?ooooo0_l0001Oooooo`;o0000V_ooool2o`0001Gooooo0003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0<oooool2
o`000?oooooo1?ooool2o`0000gooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0ooooooliooooo`;o00003Ooo
ool001kooooo00?o0000ooooooooool0k?ooool2o`0005Wooooo000Nooooo`03o`000?oooooooooo
0>cooooo0_l0001Iooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`0nooooo`;o0000Aoooool2o`000;kooooo000Nooooo`03o`000?oooooooooo
01_ooooo0_l0000Qooooo`;o0000Aoooool2o`0002Cooooo0_l0002Hooooo`007_ooool00ol0003o
ooooooooo`0Kooooo`;o0000T?ooool2o`0009Sooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0ooooool>ooooo`;o00005oooool2o`0000Oooooo0_l0
000Fooooo`007_ooool00ol0003oooooooooo`1Xooooo`;o0000Xoooool2o`0001Oooooo0_l00007
ooooo`;o00005_ooool001kooooo0_l0001Yooooo`;o0000gOooool001kooooo00?o0000oooooooo
ool05oooool2o`000?oooooo;oooool001kooooo00?o0000ooooooooool05oooool2o`0002[ooooo
0_l0003oooooo`?ooooo000Nooooo`03o`000?oooooooooo043ooooo0_l000000ooooooo0000o`00
003oooooo`?ooooo000Nooooo`03o`000?oooooooooo043ooooo0_l00035ooooo`;o0000?_ooool0
01kooooo00?o0000ooooooooool0Goooool2o`000:Kooooo0_l0000nooooo`007_ooool00ol0003o
ooooooooo`1Oooooo`;o0000i_ooool001kooooo00?o0000ooooooooool0c_ooool2o`0007Oooooo
000Nooooo`03o`000?oooooooooo0<kooooo0_l0001gooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0joooool2o`0005[ooooo000Nooooo`03o`000?oooooooooo0>_ooooo0_l0001Jooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0001c
ooooo`;o0000_?ooool001kooooo00?o0000ooooooooool05?ooool2o`0007?ooooo0_l0000Voooo
o`;o00002?ooool2o`0008[ooooo000Nooooo`;o0000NOooool2o`0003Oooooo0_l00008ooooo`;o
0000R_ooool001kooooo00?o0000ooooooooool0N?ooool2o`000<gooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`0Xooooo`;o0000oooooolNooooo`007_ooool00ol0003oooooooooo`0Xooooo`;o
00006_ooool2o`000?oooooo0_ooool001kooooo00?o0000ooooooooool0A?ooool2o`0001Gooooo
0_l0003Zooooo`007_ooool00ol0003oooooooooo`1Kooooo`;o0000Hoooool2o`0008Gooooo000N
ooooo`03o`000?oooooooooo02;ooooo0_l0001Aooooo`;o0000BOooool2o`0008Gooooo000Noooo
o`03o`000?oooooooooo02;ooooo0_l0000aooooo`;o00007_ooool2o`000=3ooooo000Nooooo`03
o`000?oooooooooo05Gooooo0_l0003`ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo047ooooo0_l0003oooooo`Gooooo000Nooooo`03o`000?oooooo
oooo047ooooo0_l00037ooooo`;o0000>oooool001kooooo00?o0000ooooooooool0ooooool;oooo
o`;o0000>oooool001kooooo00?o0000ooooooooool0a?ooool2o`00087ooooo000Nooooo`;o0000
Ioooool2o`0005cooooo0_l00005ooooo`;o0000N_ooool001kooooo00?o0000ooooooooool0I_oo
ool3o`0001Kooooo0_l0001:ooooo`;o0000N_ooool001kooooo00?o0000ooooooooool0Ioooool2
o`0001Kooooo0_l00036ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0I_oo
ool2o`000=oooooo000Nooooo`03o`000?oooooooooo06Kooooo0_l0000Gooooo`;o0000a_ooool0
01kooooo00?o0000ooooooooool0Ooooool2o`0007Kooooo0_l0001>ooooo`000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0
003oooooooooo`3gooooo`;o0000C_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02[ooooo0_l0003ooooo
oacooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol0000Zoooo
o`;o0000?_ooool2o`000=_ooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01?m4
A4CogMgMooooool00007ooooo`03o`000?oooooooooo06[ooooo0_l0003Kooooo`000oooool01Ol0
003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003ooooooooo
o`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00
0007ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom8ooooo`000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooooooo
o`2Looooo`;o0000ZOooool001kooooo00?o0000ooooooooool0=_ooool2o`0006Cooooo0_l0002Y
ooooo`007_ooool00ol0003oooooooooo`0fooooo`;o0000N_ooool2o`0009?ooooo000Nooooo`03
o`000?oooooooooo0;;ooooo0_l0002Cooooo`007_ooool01?l0003oooooooooooooool2o`0004ko
oooo0_l0003;ooooo`;o00009oooool001kooooo00Co0000oooooooooooooooo0_l0001>ooooo`;o
0000boooool2o`0002Oooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0goooool2o`0006Kooooo000Nooooo`03o`000?oooooooooo06oooooo0_l0001^
ooooo`;o0000C_ooool2o`0001Kooooo000Nooooo`03o`000?oooooooooo06oooooo0_l0002noooo
o`;o00005_ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`2mooooo`;o0000R?ooool001kooooo0_l0002nooooo`;o0000:_ooool2o`0000[ooooo0_l0
001@ooooo`007_ooool00ol0003oooooooooo`3Yooooo`;o00002_ooool2o`00053ooooo000Noooo
o`03o`000?oooooooooo05_ooooo0_l0003Zooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o
0000A_ooool2o`000>[ooooo000Nooooo`03o`000?oooooooooo01?ooooo0_l0003ooooooc?ooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo02go
oooo0_l00018ooooo`;o0000c_ooool001kooooo00?o0000ooooooooool0;Oooool2o`0002Kooooo
0_l0000Pooooo`;o0000c_ooool001kooooo00?o0000ooooooooool0:oooool2o`0002Sooooo0_l0
001=ooooo`;o0000XOooool001kooooo00?o0000ooooooooool0:oooool2o`0000?ooooo0_l0001b
ooooo`;o0000XOooool001kooooo00?o0000ooooooooool0<?ooool2o`000?oooooo5_ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`1Looooo`;o0000
UOooool2o`0005;ooooo000Nooooo`03o`000?oooooooooo05cooooo0_l0002Eooooo`;o0000D_oo
ool001kooooo0_l0000[ooooo`;o0000<?ooool2o`0009gooooo0_l0001:ooooo`007_ooool00ol0
003oooooooooo`0Zooooo`;o0000Aoooool2o`0008Kooooo0_l0001:ooooo`007_ooool00ol0003o
ooooooooo`1cooooo`;o0000d_ooool001kooooo00?o0000ooooooooool0hOooool2o`0006Cooooo
000Nooooo`03o`000?oooooooooo04gooooo0_l0000Pooooo`;o0000L?ooool2o`0006Cooooo000N
ooooo`03o`000?oooooooooo04gooooo0_l0000Pooooo`;o0000e_ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0M?ooool2o`0000?ooooo0_l0
002Nooooo`;o0000;?ooool001kooooo00?o0000ooooooooool0M?ooool2o`0000?ooooo0_l0002N
ooooo`;o0000;?ooool001kooooo00?o0000ooooooooool0Coooool4o`000?Cooooo000Nooooo`03
o`000?oooooooooo04oooooo1?l0003dooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?oooooo6oooool2o`0002_ooooo000Nooooo`03o`000?oooooo
oooo0?oooooo6oooool2o`0002_ooooo000Nooooo`;o0000DOooool2o`000?Gooooo000Nooooo`03
o`000?oooooooooo053ooooo0_l0003eooooo`007_ooool00ol0003oooooooooo`1Oooooo`;o0000
i_ooool001kooooo00?o0000ooooooooool0Goooool2o`000>Kooooo000Nooooo`03o`000?oooooo
oooo063ooooo0_l0003Uooooo`007_ooool00ol0003oooooooooo`09ooooo`;o0000EOooool2o`00
0>Gooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0003oooooocgooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo9?ooool2o`00
02;ooooo000Nooooo`03o`000?oooooooooo0?oooooo9?ooool2o`0002;ooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0
1_ooool00ol0003oooooooooo`1aooooo`;o0000G?ooool2o`0007Kooooo0003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03
o`000?oooooooooo077ooooo0_l0001Looooo`;o0000M_ooool000?ooooo00Go410@oooooooooooo
oooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`0005cooooo0_l0003Yoooo
o`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06
ooooo`03o`000?oooooooooo05Gooooo0_l00005ooooo`;o0000jOooool000?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003ooooooooo
o`04ooooo`;o00003Oooool2o`00043ooooo0_l0002;ooooo`;o0000?_ooool2o`0002?ooooo0003
ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo00Cooooo0_l0000=ooooo`;o0000cOooool4o`0003cooooo0_l0000Sooooo`000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003ooooooooo
o`08ooooo`;o0000Eoooool2o`0001?ooooo0_l0001/ooooo`;o0000HOooool000?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0
2?ooool2o`00047ooooo0_l0000Dooooo`;o00004oooool2o`000<oooooo000Nooooo`03o`000?oo
oooooooo04_ooooo0_l0000Cooooo`;o0000iOooool001kooooo00?o0000ooooooooool00_ooool2
o`0004Oooooo0_l0000Cooooo`;o0000iOooool001kooooo00?o0000ooooooooool00_ooool2o`00
0?ooooooA?ooool001kooooo00?o0000ooooooooool0<_ooool2o`0000oooooo0_l00008ooooo`;o
0000n?ooool001kooooo00?o0000ooooooooool0<_ooool2o`0000Oooooo0_l00006ooooo`;o0000
2?ooool2o`000?Sooooo000Nooooo`03o`000?oooooooooo03Wooooo1Ol0001Uooooo`;o0000X_oo
ool001kooooo00?o0000ooooooooool0>Oooool2o`000003ooooool0003o000006Gooooo0_l0002R
ooooo`007_ooool00ol0003oooooooooo`0nooooo`;o00007_ooool2o`0003Kooooo0_l0000Doooo
o`;o0000>Oooool2o`0000_ooooo0_l0001Aooooo`007_ooool00ol0003oooooooooo`0nooooo`;o
00007_ooool2o`000003ooooool0003o000003?ooooo0_l0000Dooooo`;o0000>Oooool2o`0000_o
oooo0_l0001Aooooo`007_ooool00ol0003oooooooooo`0Zooooo`;o00006_ooool2o`0000[ooooo
0_l0000=ooooo`;o0000i?ooool001kooooo00?o0000ooooooooool0:_ooool2o`0000?ooooo0_l0
0003ooooo`;o00004?ooool2o`0000[ooooo0_l00009ooooo`;o00000_ooool2o`0002[ooooo0_l0
000Uooooo`;o0000TOooool001kooooo0_l0000^ooooo`Co00000oooool2o`0001?ooooo0_l0000B
ooooo`;o00004?ooool2o`0001cooooo0_l0000Uooooo`;o0000EOooool2o`0003[ooooo000Noooo
o`03o`000?oooooooooo02gooooo0_l0000Jooooo`;o00009?ooool2o`0009[ooooo0_l0000joooo
o`007_ooool00ol0003oooooooooo`1Gooooo`;o0000A?ooool2o`0001Sooooo0_l0002>ooooo`00
7_ooool00ol0003oooooooooo`0Oooooo`;o00003Oooool2o`0000oooooo0_l0000Fooooo`;o0000
A?ooool2o`0001Sooooo0_l0002>ooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o00003Ooo
ool2o`0000oooooo0_l0000Wooooo`;o0000AOooool2o`0004gooooo0_l0000Oooooo`;o00003ooo
ool2o`0001Gooooo000Nooooo`03o`000?oooooooooo02cooooo0_l0000Rooooo`;o00005_ooool2
o`0000Oooooo0_l0000looooo`;o0000COooool2o`0001oooooo0_l0000?ooooo`;o00005Oooool0
01kooooo00?o0000ooooooooool0;?ooool2o`0002;ooooo0_l0000Oooooo`;o0000e?ooool001ko
oooo00?o0000ooooooooool06_ooool2o`0001_ooooo0_l0003oooooo`oooooo000Nooooo`03o`00
0?oooooooooo00oooooo0_l00009ooooo`;o00006oooool2o`0000?ooooo0_l0000Wooooo`;o0000
??ooool6o`0009kooooo000Nooooo`03o`000?oooooooooo00oooooo0_l0000Vooooo`;o00000ooo
ool2o`0002Oooooo0_l0000looooo`Ko0000W_ooool001kooooo00?o0000ooooooooool0=oooool2
o`000?oooooo3oooool001kooooo00?o0000ooooooooool07?ooool2o`000?oooooo:_ooool001ko
oooo00?o0000ooooooooool07?ooool2o`0005Sooooo0_l0000cooooo`;o0000>Oooool2o`0005oo
oooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0001Mooooo`;o0000<oooool2o`0003Wooooo
0_l0000Xooooo`;o0000=Oooool001kooooo00?o0000ooooooooool05oooool2o`0002cooooo0_l0
0017ooooo`;o0000P?ooool2o`0003Gooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0000/
ooooo`;o0000<Oooool2o`0001;ooooo1?l0000=ooooo`;o0000Qoooool2o`0001oooooo000Noooo
o`;o0000;?ooool2o`0004_ooooo1?l0000@ooooo`;o00003oooool2o`0008Oooooo0_l0000Ooooo
o`007_ooool00ol0003oooooooooo`0Sooooo`;o00001_ooool2o`0003Kooooo0_l0000Dooooo`?o
00004_ooool2o`0003Cooooo0_l0000aooooo`;o0000C_ooool001kooooo00?o0000ooooooooool0
8oooool2o`0003Gooooo0_l00007ooooo`;o00005_ooool2o`00017ooooo0_l0000dooooo`;o0000
8_ooool2o`0000gooooo0_l0001>ooooo`007_ooool00ol0003oooooooooo`0`ooooo`;o0000:?oo
ool2o`0001oooooo0_l0000looooo`;o0000;Oooool2o`0005gooooo000Nooooo`03o`000?oooooo
oooo033ooooo0_l0000Pooooo`;o0000IOooool2o`0000Sooooo0_l00022ooooo`007_ooool00ol0
003oooooooooo`1Booooo`;o0000Koooool2o`0008;ooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool05Oooool2o`0000Cooooo0_l00007ooooo`;o0000
?_ooool2o`0001Oooooo0_l0002fooooo`;o00004?ooool001kooooo00?o0000ooooooooool05Ooo
ool2o`0000Cooooo0_l00007ooooo`;o0000?_ooool2o`0000Wooooo0_l0000<ooooo`;o0000R?oo
ool2o`0002cooooo0_l0000@ooooo`007_ooool00ol0003oooooooooo`0Qooooo`;o00004_ooool2
o`0003Sooooo0_l0001Fooooo`;o0000?_ooool2o`0003kooooo000Nooooo`03o`000?oooooooooo
027ooooo0_l0000Booooo`;o0000T?ooool2o`0007kooooo000Nooooo`03o`000?oooooooooo09So
oooo0_l0000Dooooo`;o0000ROooool2o`0000cooooo000Nooooo`03o`000?oooooooooo09Sooooo
0_l0000Dooooo`;o00003?ooool2o`0007_ooooo0_l0000<ooooo`007_ooool00ol0003ooooooooo
o`0booooo`;o00004Oooool2o`0000?ooooo0_l0000`ooooo`;o0000?_ooool2o`0008Wooooo000N
ooooo`03o`000?oooooooooo02gooooo0_l00003ooooo`;o00004Oooool2o`0000?ooooo0_l0000J
ooooo`;o00005?ooool2o`000<Wooooo000Nooooo`03o`000?oooooooooo02gooooo0_l0000Boooo
o`;o00001?ooool5o`0000;ooooo0_l00009ooooo`;o00001?ooool2o`0000Gooooo0_l0000Moooo
o`;o0000N_ooool2o`0004Cooooo000Nooooo`;o00008?ooool2o`0000;ooooo0ol00002ooooo`;o
00005oooool2o`0000Cooooo1?l00003ooooo`;o00002Oooool2o`0000Cooooo0_l0000Tooooo`;o
0000N_ooool2o`0004Cooooo000Nooooo`03o`000?oooooooooo00oooooo0_l0000;ooooo`;o0000
00?oooooo`000?l000000_ooool3o`0000;ooooo0_l0000Hooooo`Oo0000/?ooool2o`00033ooooo
0_l0000Jooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o00002oooool2o`00027ooooo2ol0
002=ooooo`;o00008?ooool2o`00033ooooo0_l0000Jooooo`007_ooool00ol0003oooooooooo`0o
ooooo`Go000000?oooooo`000?l000000ol0000Looooo`;o0000Koooool2o`0006kooooo000Noooo
o`03o`000?oooooooooo04Cooooo0_l00003ooooo`;o00006_ooool3o`00017ooooo0_l0002Yoooo
o`;o00008Oooool001kooooo00?o0000ooooooooool0A?ooool2o`0000?ooooo1ol0000Eooooo`;o
00001oooool2o`0000Cooooo0_l00003ooooo`;o0000JOooool2o`0000;ooooo0_l0000jooooo`;o
00008Oooool001kooooo00?o0000ooooooooool0??ooool7o`0000Oooooo2?l0000>ooooo`;o0000
3?ooool2o`0000Cooooo0_l0000Booooo`;o00002Oooool2o`0004oooooo0_l00002ooooo`;o0000
GOooool001kooooo00?o0000ooooooooool0:Oooool2o`00017ooooo2_l0000:ooooo`;o00003_oo
ool2o`0002Kooooo0_l00009ooooo`;o0000/_ooool001kooooo00?o0000ooooooooool02oooool2
o`0000Sooooo0_l00003ooooo`;o00003Oooool2o`0000Gooooo0_l0000<ooooo`;o00000oooool3
o`0000Oooooo0_l0000?ooooo`;o0000e_ooool2o`0000oooooo000Nooooo`03o`000?oooooooooo
00_ooooo0_l00008ooooo`;o00000oooool2o`0001Cooooo0_l0000Kooooo`;o00002oooool2o`00
00;ooooo0_l0001Looooo`;o00006Oooool2o`0005gooooo0_l0000?ooooo`007_ooool00ol0003o
ooooooooo`0^ooooo`Ko00000oooool2o`0000oooooo0_l000000ooooooo0000o`00000=ooooo`;o
0000H?ooool2o`0001Wooooo0_l0001^ooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o0000
3Oooool8o`0000?ooooo0_l0000;ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0002Ko
oooo0_l0000_ooooo`;o00004_ooool2o`0005?ooooo0_l0000hooooo`007_ooool00ol0003ooooo
ooooo`0Mooooo`;o00003?ooool3o`0000Cooooo0ol0000?ooooo`;o000000?oooooo`000?l00000
7?ooool2o`0000cooooo0_l0000_ooooo`;o00004_ooool2o`0005?ooooo0_l0000hooooo`007_oo
ool00ol0003oooooooooo`0Mooooo`;o00000oooool2o`0000Cooooo0_l000000ooooooo0000o`00
0005ooooo`?o00005?ooool2o`0001[ooooo0_l00021ooooo`;o0000GOooool000?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo
00?o0000ooooooooool07Oooool2o`0000?ooooo0_l00004ooooo`;o00001?ooool2o`0000Wooooo
0_l00005ooooo`?o00001_ooool2o`0002[ooooo0_l0001Rooooo`;o00003Oooool2o`0005gooooo
0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?oooooo
V9RHob4Q8@06ooooo`03o`000?oooooooooo02kooooo0_l000000ooooooo0000o`000006ooooo`;o
00001Oooool3o`00033ooooo1?l00006ooooo`;o0000F_ooool2o`0004[ooooo0_l0000Pooooo`00
0oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006oooo
o`?o0000<Oooool2o`0000Gooooo0_l0000>ooooo`Co00001_ooool2o`0000kooooo0ol0000:oooo
o`;o00000_ooool2o`0000Sooooo0_l0000oooooo`;o0000IOooool2o`000003ooooool0003o0000
01gooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b00Kooooo00?o0000ooooooooool0:oooool2o`0000_ooooo0_l0000>ooooo`Co00001_ooool2
o`0000Oooooo0_l00004ooooo`Co00002_ooool2o`0004gooooo0_l0000Booooo`;o0000E?ooool2
o`0001gooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0
003oc<c<00Kooooo00?o0000ooooooooool05_ooool2o`0001?ooooo0_l00008ooooo`;o00001?oo
ool2o`0000Kooooo1Ol00004ooooo`;o00002?ooool2o`0000?ooooo0_l00004ooooo`;o0000Kooo
ool2o`00037ooooo0_l00010ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo01Kooooo0_l0000Mooooo`;o0000
0oooool5o`0000Cooooo1Ol000001?oooooo0000o`000?ooool4o`0000Kooooo0_l0002]ooooo`;o
00006oooool2o`0002?ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o
^[Zjoooooonj^[[o000000Kooooo0_l0000cooooo`;o00000_ooool2o`0000;ooooo0_l000000ooo
oooo0000o`00000:ooooo`;o000000?oooooo`000?l000000_l0000Aooooo`;o00003_ooool2o`00
00Kooooo0_l0001hooooo`;o0000;Oooool2o`0001Sooooo0_l00009ooooo`000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`;o0000<oooool2
o`0000;ooooo0_l0000Aooooo`;o00005_ooool2o`000003ooooool0003o000000Gooooo0_l00004
ooooo`;o00001_ooool2o`0007Oooooo0ol0000;ooooo`;o0000>_ooool2o`0000Wooooo000Noooo
o`03o`000?oooooooooo01Kooooo0_l0000Jooooo`Oo00001?ooool2o`0000Wooooo0_l00005oooo
o`;o00004oooool2o`0000Cooooo0ol00025ooooo`;o00003?ooool2o`0004Gooooo000Nooooo`03
o`000?oooooooooo01Kooooo0_l0000Jooooo`Co000000?oooooo`000?l000000_ooool4o`0000Wo
oooo0_l00005ooooo`?o00004_ooool2o`0000Cooooo0_l00018ooooo`;o0000TOooool001kooooo
00?o0000ooooooooool0<oooool2o`0000;ooooo2?l00009ooooo`?o00000oooool4o`0000[ooooo
0_l00002ooooo`;o00000_ooool2o`0003kooooo0_l0000>ooooo`;o0000TOooool001kooooo00?o
0000ooooooooool0;oooool4o`0000Kooooo1?l00007ooooo`;o000000?oooooo`000?l000000_l0
0003ooooo`;o00001Oooool4o`0000?ooooo0_l00002ooooo`;o0000@_ooool2o`000:7ooooo000N
ooooo`03o`000?oooooooooo00kooooo0ol0000Nooooo`Co00002?ooool2o`0000;ooooo0_l00003
ooooo`;o000000?oooooo`000?l000003?ooool4o`0000?ooooo0_l0000[ooooo`;o0000VOooool2
o`00027ooooo000Mooooo`;o00003Oooool2o`000004ooooool0003o0000o`0000[ooooo0_l0000>
ooooo`;o00001?ooool2o`0000;ooooo0_l00002ooooo`Go000000?oooooo`000?l000004?ooool2
o`0000Wooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00001_ooool2o`0001cooooo0_l0
000Iooooo`;o0000O_ooool2o`00027ooooo000Mooooo`;o00003Oooool2o`0000kooooo0_l0000>
ooooo`;o00000_ooool4o`0000;ooooo0_l00002ooooo`Ko00002oooool2o`0000?ooooo1?l00004
ooooo`;o00001_ooool3o`000003ooooool0003o000000Kooooo0_l0000gooooo`;o00009_ooool2
o`0006oooooo0_l00008ooooo`007_ooool00ol0003oooooooooo`06ooooo`;o00009oooool7o`00
00;ooooo0_l00002ooooo`Go00002Oooool2o`000003ooooool0003o000000;o00001_ooool2o`00
00Cooooo0_l0001]ooooo`;o0000<Oooool2o`0003cooooo0_l00008ooooo`007_ooool00ol0003o
ooooooooo`06ooooo`;o00006?ooool2o`00013ooooo1Ol000000ooooooo0000o`000002o`000003
ooooool0003o000000Go00001_ooool5o`0000;ooooo2?l00004ooooo`;o00001?ooool2o`0000;o
oooo0_l00013ooooo`;o00007_ooool2o`00037ooooo0_l00016ooooo`007Oooool2o`0002;ooooo
0_l0000@ooooo`;o000000Coooooo`000?l0003ooooo1?l00003ooooo`Go00001oooool2o`0000Co
oooo2_l00002ooooo`Co00000_ooool2o`0000;ooooo0_l00013ooooo`;o00000oooool2o`0001Wo
oooo0_l0001iooooo`007Oooool2o`0002_ooooo0_l0000:ooooo`;o000000?oooooo`000?l00000
1Oooool6o`0000Gooooo0_l000000ooooooo0000o`000003ooooo`?o000000?oooooo`000?l00000
0ol00004ooooo`;o000000?oooooo`000?l000007?ooool2o`0002oooooo0_l0002Dooooo`007_oo
ool2o`0001Sooooo0_l0000@ooooo`;o00000_ooool2o`0001;ooooo1?l00005ooooo`;o000000Co
ooooo`000?l0003o00001oooool2o`0000;ooooo0ol00004ooooo`;o00002?ooool4o`00013ooooo
0_l0001/ooooo`;o0000Eoooool001kooooo00?o0000ooooooooool04Oooool2o`0000Cooooo0_l0
000Dooooo`Co00001_ooool2o`0000Sooooo1?l00003ooooo`;o00000oooool4o`0000Oooooo0_l0
00001?oooooo0000o`000?l0000>ooooo`Co00002Oooool2o`0000Cooooo0_l0000?ooooo`;o0000
7Oooool2o`0003gooooo0_l0000Dooooo`;o0000@Oooool001kooooo00?o0000ooooooooool04Ooo
ool2o`0001Cooooo0_l00006ooooo`?o00001Oooool3o`0000;ooooo0_l00006ooooo`;o00000_oo
ool2o`0000;ooooo1Ol00002ooooo`;o00000oooool3o`0000?ooooo0_l0000Iooooo`;o00001?oo
ool2o`0000oooooo0_l0000Mooooo`;o0000Doooool2o`0002?ooooo0_l0000Looooo`007_ooool0
0ol0003oooooooooo`0Wooooo`;o00001oooool2o`000003ooooool0003o000000?ooooo0_l00002
ooooo`;o00001_ooool2o`0000Kooooo0ol00003ooooo`?o00000oooool3o`0000?ooooo0_l00002
ooooo`;o000000?oooooo`000?l000003_ooool2o`0000?ooooo0_l00003ooooo`;o0000<Oooool2
o`0007Gooooo0_l0000Looooo`007_ooool00ol0003oooooooooo`0=ooooo`;o00009?ooool2o`00
00Sooooo0_l00006ooooo`;o000000?oooooo`000?l000001_ooool4o`0000Cooooo1?l00006oooo
o`Ko00003Oooool2o`0000?ooooo0_l000000ooooooo0000o`000004o`0000Wooooo0_l00005oooo
o`;o00007Oooool2o`0009?ooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l00008ooooo`;o
00004_ooool2o`0001[ooooo0_l00006ooooo`;o000000?oooooo`000?l000000oooool2o`000004
ooooool0003o0000o`0000?ooooo0_l00002ooooo`;o00002?ooool4o`0000Gooooo0_l00003oooo
o`;o00002Oooool2o`0000;ooooo0_l00009ooooo`;o00000oooool4o`000;;ooooo000Nooooo`03
o`000?oooooooooo00?ooooo0_l0000Looooo`;o00009?ooool3o`0000?ooooo0_l000001?oooooo
0000o`000?l00003ooooo`Co00003?ooool3o`0000Cooooo0_l00003ooooo`;o00002_ooool3o`00
013ooooo0_l0001Sooooo`;o0000Coooool001kooooo00?o0000ooooooooool01oooool2o`0003ko
oooo0ol00003ooooo`;o00000oooool2o`0000;ooooo1?l000000ooooooo0000o`000004ooooo`;o
00000_ooool4o`0001Gooooo0ol0001eooooo`;o0000Coooool001kooooo00?o0000ooooooooool0
1oooool2o`0003gooooo0_l00005ooooo`Co000000?oooooo`000?l000000_ooool2o`000003oooo
ool0003o000000;o00001?ooool2o`0000;ooooo0_l0000Booooo`;o00000_ooool4o`0000?ooooo
0_l0002iooooo`;o00001_ooool001kooooo00?o0000ooooooooool02oooool2o`0001_ooooo0_l0
000Dooooo`;o00001_ooool2o`0000Gooooo1?l00005ooooo`;o000000?oooooo`000?l000000_l0
000Iooooo`;o000000?oooooo`000?l000000_ooool2o`0000Gooooo0_l0002^ooooo`;o00001_oo
ool2o`000003ooooool0003o000000Kooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l0000@
ooooo`;o00002Oooool2o`0000kooooo0_l00004ooooo`;o00001?ooool4o`0000gooooo0ol00000
0ooooooo0000o`000002o`0000Cooooo0_l00006ooooo`;o00000_ooool2o`0000Oooooo0_l00009
ooooo`;o00000oooool2o`0002Sooooo0_l0001`ooooo`;o00004?ooool2o`0000Kooooo0_l00009
ooooo`007_ooool00ol0003oooooooooo`04ooooo`;o00005oooool2o`0001Wooooo0_l00002oooo
o`;o00001?ooool4o`0000kooooo1?l00003ooooo`Co00000_ooool2o`0000Kooooo0ol000000ooo
oooo0000o`000005ooooo`Co00001oooool5o`0000;ooooo0_l0000Xooooo`;o0000L?ooool2o`00
02?ooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0000fooooo`;o00000oooool4o`0000oo
oooo1?l00003ooooo`Co00002Oooool4o`0000Sooooo1?l00005ooooo`Co000000?oooooo`000?l0
0000`oooool001kooooo00?o0000ooooooooool0@?ooool4o`0000oooooo1?l00003ooooo`;o0000
1?ooool2o`000003ooooool0003o000000?ooooo1?l00003ooooo`;o00002oooool3o`0009Sooooo
0_l0000^ooooo`007_ooool00ol0003oooooooooo`07ooooo`;o00007_ooool2o`0001Oooooo0_l0
000?ooooo`So000000?oooooo`000?l000001?ooool5o`0000Cooooo0_l00002ooooo`Co00002ooo
ool4o`0009Oooooo0_l0000^ooooo`007_ooool00ol0003oooooooooo`07ooooo`;o00007_ooool2
o`0001cooooo0_l00007ooooo`_o000000?oooooo`000?l000001?ooool3o`0000[ooooo0_l0000?
ooooo`;o0000Toooool2o`0003;ooooo000Nooooo`;o00008?ooool2o`0001oooooo1?l000000ooo
oooo0000o`000007ooooo`Oo000000?oooooo`000?l000000_ooool2o`000003ooooool0003o0000
00Co00002Oooool2o`0000Sooooo0_l00007ooooo`;o0000P?ooool2o`00013ooooo0_l00006oooo
o`;o0000:_ooool001kooooo00?o0000ooooooooool07oooool2o`0001[ooooo0_l00003ooooo`Co
00001?ooool2o`0000Cooooo0_l000000ooooooo0000o`000003o`0000Cooooo0_l000001Ooooooo
0000o`000?l0003ooooo00?o000000?oooooo`000?l000001Oooool2o`0000Sooooo0_l00003oooo
o`;o000000Coooooo`000?l0003o00005?ooool2o`0004gooooo0_l0000Kooooo`;o00006?ooool2
o`00013ooooo0_l0000Hooooo`007_ooool3o`0003_ooooo0_l00002ooooo`;o00001oooool2o`00
00Cooooo2?l00008ooooo`;o00000_ooool2o`000003ooooool0003o000000Gooooo0_l0000:oooo
o`[o00004oooool2o`0004gooooo0_l0000aooooo`;o00005?ooool2o`0001Sooooo000Nooooo`?o
00008?ooool2o`00013ooooo0_l0000;ooooo`;o00003Oooool5o`0000?ooooo0_l00002ooooo`;o
00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o00003?ooool;o`0001Co
oooo0_l0001nooooo`;o0000;_ooool001kooooo00?o0000ooooooooool08?ooool2o`00013ooooo
0_l0000Jooooo`Co00001?ooool2o`0000;ooooo0_l00003ooooo`Co00000_ooool3o`000003oooo
ool0003o000000;o00003?ooool4o`0000;ooooo1?l0000Dooooo`;o00001Oooool2o`000:Oooooo
000Nooooo`;o0000<oooool2o`0001Gooooo0_l00003ooooo`Ko000000?oooooo`000?l000002?oo
ool6o`000003ooooool0003o000000Go00003?ooool3o`000004ooooool0003o0000o`0001kooooo
0_l0002Aooooo`;o00005?ooool001kooooo0_l0000cooooo`;o00005Oooool2o`0000;ooooo0_l0
0003ooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000Gooooo0_l0
0002ooooo`;o00001oooool2o`0000Sooooo0_l000001?oooooo0000o`000?l0000Fooooo`;o0000
VOooool2o`0001Cooooo000Nooooo`03o`000?oooooooooo04gooooo0_l00008ooooo`Oo00001Ooo
ool2o`0000?ooooo1_l00002ooooo`;o00003oooool2o`0000Cooooo0_l0000=ooooo`;o0000[ooo
ool001kooooo00?o0000ooooooooool0<Oooool2o`0001Cooooo0_l0000=ooooo`?o00000_ooool2
o`0000Oooooo0_l00002ooooo`Ko00004oooool2o`000004ooooool0003o0000ooooo`;o0000TOoo
ool2o`0002_ooooo000Nooooo`03o`000?oooooooooo02cooooo0_l00003ooooo`;o00002?ooool2
o`0000[ooooo0_l0000:ooooo`Ko000000?oooooo`000?l000000_ooool2o`0000?ooooo0ol00002
ooooo`Go00005oooool2o`0001?ooooo0_l0000Sooooo`;o0000F?ooool4o`0002_ooooo000Noooo
o`03o`000?oooooooooo01_ooooo0_l0000?ooooo`;o00003Oooool2o`0001Cooooo1ol00002oooo
o`;o00000_ooool2o`0000?ooooo0_l00004ooooo`Co00001Oooool2o`0002Gooooo0_l0000Soooo
o`;o0000F?ooool2o`0002Cooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o
00003oooool2o`0003Cooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l0000=ooooo`;o
00001oooool2o`00053ooooo0_l0001=ooooo`;o00007?ooool2o`0000_ooooo0_l00007ooooo`00
7_ooool3o`0000[ooooo0_l00011ooooo`;o00001?ooool;o`000003ooooool0003o000006?ooooo
0_l0001=ooooo`Co00006_ooool2o`0000Sooooo0_l0000:ooooo`007_ooool3o`0000cooooo0_l0
000Rooooo`;o00003_ooool2o`0000_ooooo0_l00004ooooo`oo00005?ooool2o`0000Wooooo0_l0
0025ooooo`;o00002oooool2o`0002Cooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`02
ooooo`;o00002?ooool2o`0002;ooooo0_l0000<ooooo`Co00003?ooool2o`0000Gooooo1?l00000
1?oooooo0000o`000?ooool2o`000003ooooool0003o000001Cooooo0_l00005ooooo`?o000000?o
ooooo`000?l00000QOooool2o`0003gooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l00006
ooooo`;o0000<_ooool2o`0000Oooooo0_l00004ooooo`?o00001Oooool6o`000003ooooool0003o
000000?o00005Oooool2o`0000Gooooo0ol00037ooooo`007_ooool2o`0000_ooooo0_l0000koooo
o`;o00001?ooool2o`0000Kooooo1_l000000ooooooo0000o`000003o`000003ooooool0003o0000
01;ooooo0_l0000Uooooo`;o00001?ooool2o`0000Sooooo0_l0002Hooooo`007_ooool00ol0003o
ooooooooo`0cooooo`;o00001_ooool2o`0001Cooooo0_l00003ooooo`Wo00000oooool3o`0002Go
oooo0_l0000Aooooo`;o00001?ooool2o`0000Sooooo0_l00004ooooo`;o0000T_ooool001kooooo
00?o0000ooooooooool0<oooool2o`0000Kooooo0_l00009ooooo`;o00002Oooool2o`0000?ooooo
0_l000000ooooooo0000o`000004o`0000Cooooo0_l0000Uooooo`;o00007Oooool2o`0000Sooooo
0_l0001Wooooo`;o00003_ooool2o`0000kooooo0_l00009ooooo`007_ooool00ol0003ooooooooo
o`0nooooo`;o00001_ooool3o`0000Wooooo0_l000001?oooooo0000o`000?l00004ooooo`;o0000
Boooool2o`00077ooooo0_l0000>ooooo`;o00003_ooool3o`0000Sooooo000Nooooo`03o`000?oo
oooooooo00[ooooo0_l00003ooooo`;o00009oooool2o`0000Cooooo0_l00007ooooo`;o00002Ooo
ool2o`000004ooooool0003o0000o`000>Gooooo0_l00008ooooo`007_ooool00ol0003ooooooooo
o`0:ooooo`;o00000oooool2o`0002Oooooo0_l0000Looooo`;o0000koooool001kooooo00?o0000
ooooooooool0>?ooool3o`0001Cooooo0_l00003ooooo`;o0000Hoooool2o`0008cooooo000Noooo
o`03o`000?oooooooooo00;ooooo0_l0000dooooo`?o00004Oooool2o`000003ooooool0003o0000
00;ooooo0ol0000Nooooo`;o00002Oooool2o`0003Sooooo0_l0001;ooooo`;o0000?oooool001ko
oooo00?o0000ooooooooool00_ooool2o`0002Sooooo0_l0000Aooooo`;o00001Oooool2o`0000Co
oooo0_l00005ooooo`;o00007oooool2o`0000Wooooo0_l0000Jooooo`;o00000oooool2o`0000_o
oooo0_l0000:ooooo`Co0000BOooool2o`0001[ooooo0_l0000Sooooo`007_ooool00ol0003ooooo
ooooo`05ooooo`;o00009Oooool2o`00017ooooo0_l00005ooooo`;o00004?ooool2o`00047ooooo
0_l00003ooooo`;o00002oooool2o`0000[ooooo1?l0001Uooooo`;o00008oooool001kooooo00?o
0000ooooooooool01Oooool2o`0001Cooooo0_l0000Gooooo`;o000000?oooooo`000?l000003?oo
ool2o`00017ooooo0_l0000Pooooo`;o00003Oooool2o`00013ooooo0_l00008ooooo`;o0000<ooo
ool2o`0003Sooooo0_l0000aooooo`007_ooool00ol0003oooooooooo`0Kooooo`;o00004?ooool2
o`0000Gooooo0_l000000ooooooo0000o`000009ooooo`;o000000?oooooo`000?l00000<oooool2
o`000003ooooool0003o000000[ooooo0_l0000@ooooo`;o000000?oooooo`000?l000001Oooool2
o`0003?ooooo0_l0000hooooo`;o0000<Oooool001kooooo0ol0000/ooooo`?o00004oooool2o`00
03Cooooo0_l00003ooooo`;o00007oooool2o`000:Oooooo000Nooooo`?o0000;?ooool2o`000003
ooooool0003o000004Oooooo0_l0002Mooooo`;o0000;_ooool001Cooooo1?l000000ol@413ooooo
ooooo`03ooooo`03o`000?oooooooooo02oooooo0_l0000hooooo`;o00004?ooool2o`0003kooooo
1?l0001Hooooo`;o00000oooool2o`0002;ooooo0_l00005ooooo`005_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo0_l0000`ooooo`;o0000<?ooool2o`00013ooooo0_l0
000nooooo`Co0000GOooool2o`0002;ooooo0_l00005ooooo`005_ooool00ol0003oooooooooo`05
ooooo`?o00001Oooool2o`00033ooooo0_l0000Yooooo`;o0000hoooool001Kooooo00?o0000oooo
ooooool0J_ooool2o`000>?ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo
00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000D
ooooo`03oeEEEOmVIVKo00000?ooooooD_ooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.33198 .87064 Mdot
.23661 .71258 Mdot
.13663 .84174 Mdot
.31992 .89731 Mdot
.26263 .86248 Mdot
.27901 .84226 Mdot
.90416 .02569 Mdot
.24124 .88602 Mdot
.3473 .88456 Mdot
.27582 .57926 Mdot
.21548 .0106 Mdot
.17045 .93886 Mdot
.17448 .82115 Mdot
.9608 .86628 Mdot
.22918 .83848 Mdot
.2991 .59569 Mdot
.40457 .62389 Mdot
.18991 .75406 Mdot
.31269 .86847 Mdot
.35679 .88945 Mdot
.11026 .79202 Mdot
.30824 .82349 Mdot
.16908 .77456 Mdot
.54685 .88626 Mdot
.34391 .93198 Mdot
.26652 .92157 Mdot
.27707 .90864 Mdot
.32505 .81819 Mdot
.20521 .99242 Mdot
.28924 .82815 Mdot
.17478 .80227 Mdot
.24154 .83783 Mdot
.34046 .92777 Mdot
.53388 .84598 Mdot
.10091 .93801 Mdot
.30848 .98462 Mdot
.03943 .88286 Mdot
.6212 .13527 Mdot
.16025 .86178 Mdot
.29259 .94524 Mdot
.19535 .81485 Mdot
.99593 .97849 Mdot
.2277 .81734 Mdot
.44941 .36353 Mdot
.89702 .86104 Mdot
.01411 .9675 Mdot
.81968 .8281 Mdot
.16811 .632 Mdot
.28461 .99541 Mdot
.17484 .1119 Mdot
.15402 .73107 Mdot
.04314 .81167 Mdot
.22798 .8798 Mdot
.30745 .95581 Mdot
.19526 .83665 Mdot
.39845 .29835 Mdot
.25118 .91327 Mdot
.20171 .8462 Mdot
.27289 .90455 Mdot
.40613 .95392 Mdot
.25665 .88062 Mdot
.26701 .89681 Mdot
.86512 .98848 Mdot
.36306 .92707 Mdot
.25879 .87041 Mdot
.32722 .82989 Mdot
.02071 .8613 Mdot
.27556 .90962 Mdot
.26298 .8241 Mdot
.41574 .91726 Mdot
.38346 .41592 Mdot
.3492 .11337 Mdot
.05786 .80908 Mdot
.22121 .33956 Mdot
.20967 .98231 Mdot
.20787 .93449 Mdot
.31834 .69228 Mdot
.09897 .10045 Mdot
.26693 .86939 Mdot
.53275 .91671 Mdot
.07727 .69939 Mdot
.02216 .1602 Mdot
.38938 .29391 Mdot
.24805 .88164 Mdot
.88012 .0608 Mdot
.75703 .47318 Mdot
.26751 .91287 Mdot
.27131 .93887 Mdot
.24269 .82822 Mdot
.44586 .05527 Mdot
.40942 .91374 Mdot
.7095 .52983 Mdot
.23536 .10352 Mdot
.41214 .91057 Mdot
.35332 .8675 Mdot
.11105 .68126 Mdot
.06691 .07099 Mdot
.00937 .87267 Mdot
.33638 .92328 Mdot
.53626 .01303 Mdot
.23299 .88683 Mdot
.13883 .68629 Mdot
.41205 .82738 Mdot
.19776 .78327 Mdot
.3438 .73856 Mdot
.18165 .76783 Mdot
.30286 .49586 Mdot
.28674 .54222 Mdot
.09609 .77466 Mdot
.29967 .49661 Mdot
.07126 .84682 Mdot
.2937 .30143 Mdot
.36954 .63518 Mdot
.17611 .77657 Mdot
.87139 .73847 Mdot
.90271 .11578 Mdot
.99402 .88778 Mdot
.16862 .81391 Mdot
.26715 .2248 Mdot
.40648 .72678 Mdot
.27565 .93796 Mdot
.11315 .69898 Mdot
.24548 .90576 Mdot
.43014 .09062 Mdot
.97559 .82102 Mdot
.69714 .85034 Mdot
.12884 .87155 Mdot
.32143 .86025 Mdot
.4976 .7995 Mdot
.28038 .74883 Mdot
.64639 .73789 Mdot
.06921 .23172 Mdot
.06574 .46004 Mdot
.23582 .72337 Mdot
.22526 .76424 Mdot
.13929 .76304 Mdot
.1805 .76658 Mdot
.314 .01089 Mdot
.21061 .82833 Mdot
.32267 .84265 Mdot
.30944 .83126 Mdot
.36832 .93194 Mdot
.32515 .84559 Mdot
.41711 .98849 Mdot
.84229 .60303 Mdot
.14986 .9753 Mdot
.35684 .8187 Mdot
.25456 .91077 Mdot
.16973 .89302 Mdot
.10195 .0272 Mdot
.44391 .84754 Mdot
.32459 .89571 Mdot
.19118 .90553 Mdot
.35798 .89828 Mdot
.23697 .85406 Mdot
.18943 .83133 Mdot
.30027 .97441 Mdot
.70865 .22554 Mdot
.33082 .89692 Mdot
.32937 .6104 Mdot
.31674 .05518 Mdot
.26638 .01903 Mdot
.88677 .90858 Mdot
.24525 .73258 Mdot
.33813 .9304 Mdot
.24973 .84606 Mdot
.2492 .91831 Mdot
.3004 .89984 Mdot
.83028 .6805 Mdot
.24987 .74112 Mdot
.28124 .86306 Mdot
.15691 .82066 Mdot
.16548 .99734 Mdot
.7671 .51935 Mdot
.35421 .88716 Mdot
.23518 .04833 Mdot
.55403 .78265 Mdot
.21937 .92329 Mdot
.84035 .92518 Mdot
.03454 .83013 Mdot
.30617 .82683 Mdot
.18731 .98858 Mdot
.30582 .97223 Mdot
.96609 .9 Mdot
.36035 .98243 Mdot
.22103 .64598 Mdot
.33257 .68831 Mdot
.40787 .89725 Mdot
.18116 .83281 Mdot
.36574 .93073 Mdot
.34217 .88001 Mdot
.94523 .89765 Mdot
.32393 .85899 Mdot
.34294 .76195 Mdot
.38642 .69875 Mdot
.26977 .85261 Mdot
.2873 .0188 Mdot
.15807 .97608 Mdot
.35236 .88756 Mdot
.26208 .94903 Mdot
.92238 .14723 Mdot
.55599 .5986 Mdot
.22492 .73193 Mdot
.97496 .85257 Mdot
.34708 .93156 Mdot
.27639 .94005 Mdot
.29372 .9199 Mdot
.25764 .91293 Mdot
.12031 .67447 Mdot
.3286 .02806 Mdot
.25228 .76737 Mdot
.32578 .83202 Mdot
.01668 .81841 Mdot
.37818 .71658 Mdot
.32033 .04171 Mdot
.3652 .19254 Mdot
.2667 .93479 Mdot
.34657 .49871 Mdot
.28548 .93382 Mdot
.98255 .96339 Mdot
.83633 .14504 Mdot
.34657 .94176 Mdot
.36922 .93568 Mdot
.29895 .88224 Mdot
.43964 .03708 Mdot
.30309 .11351 Mdot
.27035 .79558 Mdot
.13289 .78153 Mdot
.26596 .51774 Mdot
.32856 .8392 Mdot
.22097 .87129 Mdot
.40229 .98968 Mdot
.31202 .86071 Mdot
.67526 .70821 Mdot
.39133 .23688 Mdot
.36222 .84249 Mdot
.67919 .66662 Mdot
.15763 .80334 Mdot
.36855 .13957 Mdot
.82395 .31577 Mdot
.19595 .83818 Mdot
.30613 .84773 Mdot
.1166 .69881 Mdot
.33033 .7414 Mdot
.18473 .88745 Mdot
.3227 .77288 Mdot
.3415 .03084 Mdot
.28916 .85119 Mdot
.66209 .80867 Mdot
.17655 .81956 Mdot
.06286 .81485 Mdot
.2033 .81586 Mdot
.48428 .11349 Mdot
.70679 .6986 Mdot
.88727 .7645 Mdot
.22707 .64305 Mdot
.24411 .87604 Mdot
.46276 .07957 Mdot
.01506 .79842 Mdot
.23302 .80509 Mdot
.33041 .84575 Mdot
.26998 .75705 Mdot
.30822 .36453 Mdot
.54411 .11938 Mdot
.31285 .85279 Mdot
.82231 .24201 Mdot
.28062 .62287 Mdot
.99485 .87642 Mdot
.15726 .80669 Mdot
.29087 .92933 Mdot
.33794 .92631 Mdot
.86514 .87625 Mdot
.23986 .85189 Mdot
.27987 .75026 Mdot
.05798 .73421 Mdot
.19738 .79372 Mdot
.26932 .94239 Mdot
.12201 .09367 Mdot
.30107 .98142 Mdot
.19206 .68001 Mdot
.21679 .93635 Mdot
.30593 .82894 Mdot
.22664 .73413 Mdot
.05701 .98725 Mdot
.25618 .8659 Mdot
.36865 .93611 Mdot
.24517 .73694 Mdot
.51463 .9098 Mdot
.25637 .6852 Mdot
.23833 .73268 Mdot
.18944 .6945 Mdot
.51038 .03898 Mdot
.29979 .86235 Mdot
.46794 .7309 Mdot
.77366 .52909 Mdot
.40043 .99056 Mdot
.21955 .86356 Mdot
.32419 .74151 Mdot
.23421 .90664 Mdot
.77721 .72752 Mdot
.55612 .8448 Mdot
.31678 .91362 Mdot
.20894 .9918 Mdot
.3148 .08364 Mdot
.37868 .17538 Mdot
.16682 .77918 Mdot
.27859 .90364 Mdot
.25286 .8749 Mdot
.78863 .91023 Mdot
.52348 .64327 Mdot
.26857 .92628 Mdot
.23946 .86155 Mdot
.26855 .9173 Mdot
.37972 .93665 Mdot
.32548 .95339 Mdot
.3458 .80496 Mdot
.21833 .0816 Mdot
.67526 .64307 Mdot
.32289 .95473 Mdot
.61678 .31783 Mdot
.18762 .82024 Mdot
.31888 .9266 Mdot
.18601 .65779 Mdot
.30221 .05353 Mdot
.17979 .78014 Mdot
.20772 .861 Mdot
.2994 .98382 Mdot
.33394 .83015 Mdot
.17263 .91293 Mdot
.24332 .87836 Mdot
.38815 .88929 Mdot
.28606 .82643 Mdot
.20845 .60733 Mdot
.65651 .73829 Mdot
.37561 .1795 Mdot
.20363 .29092 Mdot
.61908 .67594 Mdot
.2818 .92494 Mdot
.32677 .68905 Mdot
.71161 .47602 Mdot
.3447 .93599 Mdot
.29681 .89988 Mdot
.31813 .81487 Mdot
.32886 .11092 Mdot
.52582 .05694 Mdot
.21185 .79599 Mdot
.0789 .87414 Mdot
.05207 .43677 Mdot
.34931 .0795 Mdot
.23895 .88942 Mdot
.1605 .81278 Mdot
.22671 .85108 Mdot
.33026 .95997 Mdot
.25608 .7008 Mdot
.34156 .93334 Mdot
.2404 .86499 Mdot
.0159 .95912 Mdot
.24548 .75577 Mdot
.18338 .82234 Mdot
.30736 .66245 Mdot
.30154 .83793 Mdot
.22524 .86144 Mdot
.19201 .80881 Mdot
.23937 .76374 Mdot
.35748 .92616 Mdot
.05994 .85941 Mdot
.10998 .62516 Mdot
.22541 .88093 Mdot
.13785 .18183 Mdot
.28388 .81009 Mdot
.32572 .0443 Mdot
.28146 .89914 Mdot
.15285 .82862 Mdot
.33769 .84083 Mdot
.47771 .85769 Mdot
.59213 .98596 Mdot
.87617 .85108 Mdot
.28598 .98443 Mdot
.78403 .91306 Mdot
.28465 .86529 Mdot
.26869 .86394 Mdot
.3829 .88693 Mdot
.20656 .51077 Mdot
.84826 .7161 Mdot
.32738 .88389 Mdot
.24912 .79527 Mdot
.2637 .62203 Mdot
.13307 .38252 Mdot
.2822 .92005 Mdot
.29723 .86543 Mdot
.30975 .83022 Mdot
.2319 .80145 Mdot
.20363 .88721 Mdot
.23974 .86959 Mdot
.25816 .8725 Mdot
.3549 .39259 Mdot
.33839 .60842 Mdot
.71893 .18572 Mdot
.2703 .9065 Mdot
.1881 .79336 Mdot
.20369 .85455 Mdot
.92165 .77721 Mdot
.94224 .14617 Mdot
.26151 .89027 Mdot
.17405 .10973 Mdot
.53951 .61626 Mdot
.22651 .71684 Mdot
.41113 .08222 Mdot
.27621 .11314 Mdot
.24549 .72827 Mdot
.33157 .04844 Mdot
.32572 .91587 Mdot
.32265 .05217 Mdot
.49651 .95183 Mdot
.89506 .57306 Mdot
.22295 .73746 Mdot
.43708 .80725 Mdot
.30548 .09419 Mdot
.22303 .77114 Mdot
.26259 .86989 Mdot
.29282 .92243 Mdot
.5802 .69744 Mdot
.46051 .14015 Mdot
.22736 .77673 Mdot
.21171 .85763 Mdot
.76711 .75348 Mdot
.96105 .20957 Mdot
.34615 .85971 Mdot
.34119 .10037 Mdot
.03538 .60671 Mdot
.66449 .43418 Mdot
.99727 .75661 Mdot
.96138 .06313 Mdot
.39377 .87719 Mdot
.78975 .00494 Mdot
.10565 .78514 Mdot
.29525 .93501 Mdot
.43542 .65953 Mdot
.35656 .72087 Mdot
.88521 .89042 Mdot
.30499 .63699 Mdot
.40422 .39996 Mdot
.35252 .38086 Mdot
.23782 .86864 Mdot
.28345 .75077 Mdot
.23792 .88635 Mdot
.31403 .95075 Mdot
.26176 .80704 Mdot
.63198 .32339 Mdot
.1875 .80567 Mdot
.55275 .93601 Mdot
.10202 .78539 Mdot
.35267 .94132 Mdot
.27947 .87234 Mdot
.34929 .76824 Mdot
.26797 .9185 Mdot
.3442 .91635 Mdot
.30681 .97908 Mdot
.51432 .72588 Mdot
.26888 .63648 Mdot
.29214 .8958 Mdot
.26665 .92534 Mdot
.27419 .86455 Mdot
.16321 .88676 Mdot
.53836 .00178 Mdot
.0084 .88532 Mdot
.33001 .93285 Mdot
.63602 .83904 Mdot
.22402 .85236 Mdot
.14018 .84416 Mdot
.2875 .81588 Mdot
.26989 .91523 Mdot
.24877 .88792 Mdot
.24795 .88453 Mdot
.16369 .86401 Mdot
.251 .84844 Mdot
.19517 .82204 Mdot
.22108 .86039 Mdot
.56279 .04251 Mdot
.18941 .90269 Mdot
.1703 .99235 Mdot
.40018 .75908 Mdot
.31222 .83611 Mdot
.29919 .81351 Mdot
.33458 .8676 Mdot
.41355 .01511 Mdot
.54894 .22557 Mdot
.26928 .05169 Mdot
.21832 .8508 Mdot
.32076 .81817 Mdot
.16033 .8148 Mdot
.30927 .90736 Mdot
.32775 .27277 Mdot
.21511 .63545 Mdot
.38345 .94332 Mdot
.16261 .97548 Mdot
.38349 .78692 Mdot
.28025 .98272 Mdot
.60829 .91352 Mdot
.26748 .08501 Mdot
.37073 .75647 Mdot
.28348 .73151 Mdot
.16792 .82867 Mdot
.32461 .66136 Mdot
.21408 .74465 Mdot
.05904 .05628 Mdot
.27273 .91433 Mdot
.55174 .88489 Mdot
.33715 .91972 Mdot
.29916 .85481 Mdot
.25363 .77867 Mdot
.3424 .0539 Mdot
.2816 .27267 Mdot
.38897 .00864 Mdot
.26187 .8776 Mdot
.7255 .72108 Mdot
.31338 .8446 Mdot
.11967 .67689 Mdot
.92188 .4336 Mdot
.19911 .78444 Mdot
.24823 .77131 Mdot
.15213 .87548 Mdot
.26882 .86715 Mdot
.23878 .93457 Mdot
.5398 .99919 Mdot
.72066 .05834 Mdot
.21046 .79306 Mdot
.21248 .28347 Mdot
.40257 .98359 Mdot
.50539 .69393 Mdot
.77259 .68769 Mdot
.82413 .53712 Mdot
.26118 .86807 Mdot
.13188 .81787 Mdot
.24238 .87302 Mdot
.24408 .88937 Mdot
.2789 .87934 Mdot
.36934 .92255 Mdot
.65457 .17964 Mdot
.02376 .64197 Mdot
.3211 .8414 Mdot
.74945 .67722 Mdot
.15895 .9818 Mdot
.24813 .8536 Mdot
.21335 .84178 Mdot
.0565 .04129 Mdot
.6072 .31799 Mdot
.19529 .87142 Mdot
.22503 .72782 Mdot
.20992 .85675 Mdot
.30166 .97409 Mdot
.89299 .06266 Mdot
.35754 .91995 Mdot
.56458 .89133 Mdot
.09461 .67418 Mdot
.82822 .98329 Mdot
.27218 .03845 Mdot
.27991 .93024 Mdot
.34718 .97094 Mdot
.68429 .69637 Mdot
.24247 .72327 Mdot
.27636 .97318 Mdot
.66118 .15529 Mdot
.4878 .06586 Mdot
.23828 .73962 Mdot
.28729 .99161 Mdot
.30766 .03447 Mdot
.36097 .93593 Mdot
.98587 .20882 Mdot
.24864 .83046 Mdot
.17037 .68549 Mdot
.22184 .76915 Mdot
.25272 .84635 Mdot
.34734 .81548 Mdot
.21643 .80337 Mdot
.35042 .86878 Mdot
.40995 .63489 Mdot
.20738 .98665 Mdot
.19103 .80784 Mdot
.30353 .8052 Mdot
.60489 .03696 Mdot
.81749 .70827 Mdot
.21734 .82778 Mdot
.28615 .82294 Mdot
.56801 .22051 Mdot
.29435 .9678 Mdot
.25676 .63939 Mdot
.04241 .12366 Mdot
.22771 .75297 Mdot
.36411 .86124 Mdot
.21389 .85682 Mdot
.18695 .84274 Mdot
.29818 .11519 Mdot
.28556 .96027 Mdot
.13095 .98648 Mdot
.26847 .90796 Mdot
.28891 .96625 Mdot
.22076 .85817 Mdot
.29608 .98273 Mdot
.24535 .86385 Mdot
.34255 .86944 Mdot
.28804 .9052 Mdot
.1481 .81858 Mdot
.01297 .87866 Mdot
.88502 .77225 Mdot
.24579 .7368 Mdot
.2749 .92805 Mdot
.29662 .82947 Mdot
.83218 .8909 Mdot
.33058 .8609 Mdot
.86976 .94997 Mdot
.71492 .66743 Mdot
.25501 .80872 Mdot
.96891 .58092 Mdot
.3175 .86113 Mdot
.32361 .6191 Mdot
.34646 .10244 Mdot
.3555 .9792 Mdot
.32435 .90933 Mdot
.8487 .97096 Mdot
.19517 .1337 Mdot
.25164 .69768 Mdot
.33135 .86556 Mdot
.73084 .9181 Mdot
.96702 .87292 Mdot
.33464 .62513 Mdot
.60218 .25089 Mdot
.76473 .39784 Mdot
.16295 .79241 Mdot
.99321 .85112 Mdot
.18046 .8349 Mdot
.30479 .88856 Mdot
.37852 .89174 Mdot
.88847 .9377 Mdot
.25461 .84644 Mdot
.41563 .13782 Mdot
.24368 .87949 Mdot
.28338 .09861 Mdot
.25207 .82657 Mdot
.22844 .83019 Mdot
.13183 .87544 Mdot
.26268 .83751 Mdot
.99278 .96008 Mdot
.98127 .86074 Mdot
.95147 .78707 Mdot
.26772 .80158 Mdot
.11018 .84224 Mdot
.36036 .97587 Mdot
.24743 .87093 Mdot
.83779 .89352 Mdot
.48367 .99133 Mdot
.23069 .00353 Mdot
.36637 .69645 Mdot
.29679 .87661 Mdot
.59091 .28871 Mdot
.30075 .9429 Mdot
.20606 .8807 Mdot
.41263 .88167 Mdot
.20752 .75405 Mdot
.26895 .91178 Mdot
.87499 .86849 Mdot
.17071 .79628 Mdot
.89 .72662 Mdot
.27672 .96072 Mdot
.87321 .12672 Mdot
.53341 .6342 Mdot
.25787 .8719 Mdot
.17229 .93712 Mdot
.54867 .01606 Mdot
.40759 .61035 Mdot
.44464 .03575 Mdot
.01531 .22532 Mdot
.23581 .80611 Mdot
.28409 .90208 Mdot
.02453 .00638 Mdot
.27489 .90981 Mdot
.55863 .80784 Mdot
.22738 .7901 Mdot
.03996 .83235 Mdot
.25358 .73554 Mdot
.5123 .32333 Mdot
.4566 .97556 Mdot
.08985 .61567 Mdot
.32419 .86919 Mdot
.2494 .83217 Mdot
.21796 .02774 Mdot
.05869 .79734 Mdot
.00176 .73135 Mdot
.48179 .76207 Mdot
.17556 .78766 Mdot
.1882 .64063 Mdot
.93598 .8401 Mdot
.2336 .42079 Mdot
.1025 .74121 Mdot
.33467 .89752 Mdot
.1818 .78783 Mdot
.28017 .86894 Mdot
.8413 .62597 Mdot
.80178 .86861 Mdot
.19773 .04088 Mdot
.27043 .46542 Mdot
.2252 .68897 Mdot
.18269 .82495 Mdot
.22931 .82669 Mdot
.47596 .14361 Mdot
.26052 .91708 Mdot
.14104 .36883 Mdot
.34115 .99169 Mdot
.14783 .35435 Mdot
.36182 .89213 Mdot
.50224 .75761 Mdot
.35873 .08481 Mdot
.96429 .7301 Mdot
.78586 .13805 Mdot
.14198 .78394 Mdot
.48233 .02181 Mdot
.29857 .84246 Mdot
.24329 .88378 Mdot
.68587 .15748 Mdot
.28941 .85564 Mdot
.33066 .82511 Mdot
.79098 .02145 Mdot
.24399 .75419 Mdot
.2891 .03404 Mdot
.522 .75344 Mdot
.41311 .91887 Mdot
.00097 .77236 Mdot
.27749 .9464 Mdot
.95145 .83335 Mdot
.37342 .98476 Mdot
.24666 .92467 Mdot
.26473 .88793 Mdot
.17242 .83339 Mdot
.33339 .86555 Mdot
.61624 .19275 Mdot
.40751 .663 Mdot
.56988 .25977 Mdot
.29217 .99109 Mdot
.13162 .83341 Mdot
.5281 .42826 Mdot
.30663 .83072 Mdot
.35539 .87565 Mdot
.36142 .88511 Mdot
.10921 .03332 Mdot
.73732 .72128 Mdot
.12283 .8629 Mdot
.2875 .8716 Mdot
.21894 .92681 Mdot
.27279 .96393 Mdot
.05797 .00247 Mdot
.08875 .7792 Mdot
.18538 .83259 Mdot
.4633 .68914 Mdot
.33614 .82059 Mdot
.2426 .76336 Mdot
.34034 .91003 Mdot
.25116 .75418 Mdot
.0387 .72839 Mdot
.1958 .83613 Mdot
.16375 .81083 Mdot
.57692 .92534 Mdot
.24525 .89127 Mdot
.13158 .41397 Mdot
.18689 .82737 Mdot
.2339 .65601 Mdot
.279 .87783 Mdot
.5432 .02484 Mdot
.42253 .72622 Mdot
.15879 .9754 Mdot
.13348 .31824 Mdot
.34687 .94761 Mdot
.41624 .88589 Mdot
.20772 .74565 Mdot
.20363 .81586 Mdot
.17164 .67859 Mdot
.25054 .80652 Mdot
.24893 .88974 Mdot
.15892 .81319 Mdot
.34502 .75514 Mdot
.14278 .55925 Mdot
.32867 .89286 Mdot
.36474 .65358 Mdot
.53197 .44248 Mdot
.53858 .62592 Mdot
.25053 .91161 Mdot
.29671 .91641 Mdot
.29405 .68809 Mdot
.32296 .84589 Mdot
.30833 .90442 Mdot
.18681 .84597 Mdot
.13066 .84465 Mdot
.12459 .20664 Mdot
.12152 .14567 Mdot
.24291 .92802 Mdot
.30549 .0063 Mdot
.20697 .87776 Mdot
.29192 .78511 Mdot
.98772 .68094 Mdot
.36157 .93446 Mdot
.39623 .07323 Mdot
.46207 .63419 Mdot
.29098 .83163 Mdot
.21325 .82918 Mdot
.38301 .71273 Mdot
.37466 .06988 Mdot
.204 .74228 Mdot
.09834 .63282 Mdot
.27078 .56703 Mdot
.4067 .01956 Mdot
.27452 .84076 Mdot
.56223 .98109 Mdot
.34284 .96615 Mdot
.15202 .87385 Mdot
.14321 .62391 Mdot
.4085 .88544 Mdot
.28271 .89126 Mdot
.13187 .09799 Mdot
.14391 .90781 Mdot
.22619 .85112 Mdot
.04775 .94753 Mdot
.243 .87792 Mdot
.22682 .85685 Mdot
.29643 .91705 Mdot
.18956 .83272 Mdot
.25706 .90967 Mdot
.30039 .97199 Mdot
.24194 .89172 Mdot
.33951 .92325 Mdot
.21297 .77584 Mdot
.23009 .85439 Mdot
.06837 .88112 Mdot
.46133 .90632 Mdot
.19461 .804 Mdot
.08911 .01211 Mdot
.03186 .98358 Mdot
.24889 .72108 Mdot
.33446 .99343 Mdot
.28461 .99582 Mdot
.35423 .92704 Mdot
.40182 .33501 Mdot
.01079 .71805 Mdot
.22316 .85358 Mdot
.27615 .90194 Mdot
.33992 .8645 Mdot
.16756 .91376 Mdot
.0264 .95713 Mdot
.66829 .89289 Mdot
.15579 .82157 Mdot
.27204 .90901 Mdot
.19179 .83116 Mdot
.65266 .16699 Mdot
.40263 .07959 Mdot
.20622 .82249 Mdot
.3554 .84425 Mdot
.26127 .95131 Mdot
.84731 .76339 Mdot
.2438 .88561 Mdot
.2488 .61413 Mdot
.21679 .90706 Mdot
.19114 .84398 Mdot
.23983 .865 Mdot
.28677 .89454 Mdot
.36093 .88818 Mdot
.50672 .35681 Mdot
.26198 .91804 Mdot
.19597 .00567 Mdot
.32121 .87243 Mdot
.29144 .8717 Mdot
.76435 .77015 Mdot
.20588 .84709 Mdot
.6619 .82003 Mdot
.25141 .93545 Mdot
.3565 .93638 Mdot
.33451 .93798 Mdot
.04291 .7334 Mdot
.2618 .89996 Mdot
.10789 .22425 Mdot
.33202 .98286 Mdot
.91756 .72433 Mdot
.26297 .78761 Mdot
.71336 .89679 Mdot
.268 .85734 Mdot
.24957 .89222 Mdot
.18769 .89239 Mdot
.24816 .86167 Mdot
.33597 .87224 Mdot
.32694 .82894 Mdot
.46122 .68389 Mdot
.30855 .82546 Mdot
.68121 .7781 Mdot
.35528 .19284 Mdot
.1296 .76586 Mdot
.15959 .80445 Mdot
.30664 .83243 Mdot
.1202 .13529 Mdot
.22516 .88924 Mdot
.662 .03387 Mdot
.22716 .83995 Mdot
.39452 .88088 Mdot
.27795 .88833 Mdot
.25762 .7835 Mdot
.2095 .62778 Mdot
.71366 .85513 Mdot
.36794 .74696 Mdot
.43024 .97677 Mdot
.10359 .69594 Mdot
.51038 .6284 Mdot
.2909 .76357 Mdot
.27143 .8486 Mdot
.31838 .80573 Mdot
.07995 .77503 Mdot
.57289 .71888 Mdot
.40283 .13139 Mdot
.37174 .90903 Mdot
.1145 .95751 Mdot
.17312 .4594 Mdot
.16643 .88343 Mdot
.37341 .90758 Mdot
.12674 .69559 Mdot
.34377 .86476 Mdot
.41842 .99065 Mdot
.32084 .43088 Mdot
.2893 .77846 Mdot
.24835 .87159 Mdot
.23301 .83274 Mdot
.41636 .05649 Mdot
.31908 .9701 Mdot
.34465 .74584 Mdot
.53782 .54568 Mdot
.16996 .72952 Mdot
.16958 .96788 Mdot
.19246 .76465 Mdot
.21448 .85307 Mdot
.31354 .85453 Mdot
.9195 .87726 Mdot
.31876 .84437 Mdot
.22065 .83995 Mdot
.27026 .87786 Mdot
.25866 .87587 Mdot
.25121 .06494 Mdot
.19312 .83887 Mdot
.22333 .84652 Mdot
.34047 .93599 Mdot
.26516 .03499 Mdot
.18907 .84132 Mdot
.2691 .84836 Mdot
.30389 .82207 Mdot
.0083 .96786 Mdot
.32234 .84826 Mdot
.07991 .96897 Mdot
.2387 .81787 Mdot
.4541 .85707 Mdot
.02726 .91663 Mdot
.4069 .17174 Mdot
.29076 .94933 Mdot
.14933 .83352 Mdot
.99942 .72755 Mdot
.52378 .79384 Mdot
.83433 .01834 Mdot
.80502 .22443 Mdot
.30146 .82531 Mdot
.28686 .88009 Mdot
.22505 .84788 Mdot
.4308 .06338 Mdot
.22402 .86263 Mdot
.11932 .68235 Mdot
.29186 .99214 Mdot
.29959 .10774 Mdot
.23085 .85817 Mdot
.71397 .62438 Mdot
.3807 .43408 Mdot
.20896 .95945 Mdot
.47834 .93419 Mdot
.46189 .03438 Mdot
.66175 .08975 Mdot
.26875 .90952 Mdot
.32679 .73585 Mdot
.91294 .4419 Mdot
.27229 .89071 Mdot
.25056 .9252 Mdot
.22819 .86334 Mdot
.35288 .93294 Mdot
.35527 .58658 Mdot
.33096 .69931 Mdot
.29034 .87744 Mdot
.0853 .78997 Mdot
.42574 .72772 Mdot
.79202 .63221 Mdot
.00938 .82384 Mdot
.26665 .91452 Mdot
.71159 .2742 Mdot
.33119 .90136 Mdot
.25755 .84219 Mdot
.06963 .89855 Mdot
.34281 .92298 Mdot
.27666 .95227 Mdot
.20094 .86774 Mdot
.15549 .05743 Mdot
.30188 .97704 Mdot
.22212 .9176 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00Co0000ooooool0003o00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool01_ooool2o`0000Gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo0_l00002ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00;ooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`04o`000?oooooo0000o`00
00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`?o00002?ooool2o`00
00Gooooo00?o0000ooooooooool03Oooool3o`0000gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02Oooool2o`00
00;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`;o00000_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo000Nooooo`03o`000?oooooooooo00Co
oooo0_l0000fooooo`;o00001?ooool2o`0001_ooooo0_l0000Iooooo`;o0000POooool2o`0004So
oooo000Nooooo`03o`000?oooooooooo01Wooooo0_l0000Wooooo`;o00007_ooool2o`0001Kooooo
0_l0000^ooooo`;o0000Voooool001kooooo00?o0000ooooooooool06Oooool2o`0004Oooooo0_l0
000Nooooo`;o00009_ooool2o`0000;ooooo0_l0002Gooooo`007_ooool00ol0003oooooooooo`1B
ooooo`;o00001Oooool2o`0002Gooooo1?l0000Zooooo`;o0000Foooool2o`0003[ooooo000Noooo
o`03o`000?oooooooooo05;ooooo0_l00005ooooo`;o00009Oooool2o`0001Oooooo0_l0001Roooo
o`;o00003?ooool2o`0003[ooooo000Nooooo`03o`000?oooooooooo09Wooooo0_l0000Aooooo`;o
0000Coooool2o`0002?ooooo0_l0000Sooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o0000
9?ooool2o`0002;ooooo0_l00013ooooo`;o0000M?ooool2o`0002?ooooo000Nooooo`03o`000?oo
oooooooo01gooooo0_l0000Tooooo`;o00008_ooool2o`0000;ooooo0_l0003Jooooo`007_ooool0
0ol0003oooooooooo`0Oooooo`;o0000<Oooool2o`0000Kooooo0_l00004ooooo`;o00002Oooool2
o`0002Gooooo0_l0000oooooo`;o0000L_ooool001kooooo00?o0000ooooooooool07oooool2o`00
037ooooo0_l00006ooooo`;o00001?ooool2o`0002Wooooo0ol00004ooooo`;o0000;Oooool2o`00
013ooooo0_l0001booooo`007_ooool00ol0003oooooooooo`0>ooooo`;o0000;?ooool2o`0001Ko
oooo0_l0000eooooo`?o00005?ooool2o`0001gooooo0_l00024ooooo`007_ooool00ol0003ooooo
ooooo`0>ooooo`;o0000;?ooool2o`0001Kooooo0_l0000>ooooo`Co0000>_ooool2o`0000oooooo
0_l0002Booooo`007_ooool00ol0003oooooooooo`1Tooooo`Co0000Boooool2o`0009;ooooo000N
ooooo`03o`000?oooooooooo04Sooooo0_l0000Nooooo`;o0000gOooool001kooooo0_l00019oooo
o`;o00002Oooool2o`0000Wooooo0_l00005ooooo`;o000000?oooooo`000?l00000gOooool001ko
oooo00?o0000ooooooooool03oooool2o`0004;ooooo0_l00009ooooo`;o00000oooool4o`0000Co
oooo0_l0000Fooooo`;o00002?ooool2o`000;Sooooo000Nooooo`03o`000?oooooooooo00oooooo
0_l0000Mooooo`;o0000<oooool2o`0000Kooooo0_l0000Fooooo`;o00002?ooool2o`0001Sooooo
0_l0000mooooo`;o0000Goooool001kooooo00?o0000ooooooooool0;_ooool2o`0007Oooooo0_l0
000mooooo`;o0000<_ooool2o`0000;ooooo0_l0000Wooooo`007_ooool00ol0003oooooooooo`1>
ooooo`;o0000>?ooool2o`00013ooooo0_l0001nooooo`;o00000_ooool2o`0001Cooooo0_l0000A
ooooo`007_ooool00ol0003oooooooooo`1>ooooo`;o0000>?ooool2o`00013ooooo0_l0002Hoooo
o`;o00004Oooool001kooooo00?o0000ooooooooool04_ooool2o`0006;ooooo0_l0003?ooooo`00
7_ooool00ol0003oooooooooo`0Booooo`;o0000H_ooool2o`0000Gooooo0_l00038ooooo`007_oo
ool00ol0003oooooooooo`1mooooo`;o0000b?ooool001kooooo00?o0000ooooooooool0KOooool2
o`00013ooooo0_l0000Aooooo`;o0000/oooool001kooooo00?o0000ooooooooool0@oooool2o`00
01gooooo0_l00009ooooo`;o00004?ooool2o`000003ooooool0003o000000kooooo0_l0002coooo
o`007_ooool00ol0003oooooooooo`13ooooo`;o00003_ooool2o`0000gooooo0_l0000=ooooo`;o
00003oooool2o`000<?ooooo000Nooooo`03o`000?oooooooooo05?ooooo0_l0000Looooo`;o0000
5Oooool2o`0004Wooooo0_l0001booooo`007_ooool00ol0003oooooooooo`0Tooooo`;o0000H_oo
ool2o`0004Wooooo0_l0001booooo`007_ooool00ol0003oooooooooo`0Tooooo`;o0000>Oooool2
o`000>Kooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l0000_ooooo`;o00001Oooool2o`00
0>Kooooo000Nooooo`;o00007Oooool2o`0000Wooooo0_l0000_ooooo`;o00004Oooool4o`000=So
oooo000Nooooo`03o`000?oooooooooo01cooooo0_l0000Zooooo`;o00008Oooool4o`000=Sooooo
000Nooooo`03o`000?oooooooooo04Sooooo0_l0000Cooooo`;o0000j?ooool001kooooo00?o0000
ooooooooool0=?ooool3o`0002Kooooo0_l00008ooooo`;o0000g_ooool001kooooo00?o0000oooo
ooooool0=?ooool3o`0001oooooo0_l00005ooooo`?o00001oooool2o`0000Cooooo0_l0000Zoooo
o`;o0000[?ooool001kooooo00?o0000ooooooooool0E_ooool2o`0000Gooooo0ol0000=ooooo`;o
0000:_ooool2o`0008Kooooo0_l0000Tooooo`007_ooool00ol0003oooooooooo`2]ooooo`;o0000
L_ooool2o`0002Cooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0002Qooooo`;o0000V?oo
ool001kooooo00?o0000ooooooooool02_ooool2o`000?oooooo3Oooool2o`0002gooooo000Noooo
o`03o`000?oooooooooo0?oooooo6Oooool2o`0002gooooo000Nooooo`03o`000?oooooooooo07oo
oooo0_l00036ooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o00005_ooool2o`0004;ooooo
0_l00015ooooo`;o0000Ooooool001kooooo00?o0000ooooooooool08oooool2o`0001Kooooo0_l0
000gooooo`;o00003Oooool2o`00047ooooo0_l0000cooooo`;o0000B_ooool001kooooo00?o0000
ooooooooool0M?ooool2o`0000gooooo0_l0000=ooooo`;o0000Ioooool2o`0004[ooooo000Noooo
o`03o`000?oooooooooo02?ooooo0_l0001]ooooo`;o00000oooool2o`0007?ooooo0_l0000ioooo
o`007_ooool00ol0003oooooooooo`0Sooooo`;o0000L_ooool2o`0007?ooooo0_l0000Jooooo`;o
00001?ooool2o`0001Oooooo000Nooooo`;o0000oooooolZooooo`;o00001?ooool2o`0001Oooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0doooool2
o`0000Kooooo0_l0001Zooooo`007_ooool00ol0003oooooooooo`03ooooo`;o0000c_ooool2o`00
00Kooooo0_l0001Zooooo`007_ooool00ol0003oooooooooo`03ooooo`;o0000oooooom3ooooo`00
7_ooool00ol0003oooooooooo`3@ooooo`;o0000MOooool001kooooo00?o0000ooooooooool0d?oo
ool2o`0007Gooooo000Nooooo`03o`000?oooooooooo083ooooo0_l00035ooooo`007_ooool00ol0
003oooooooooo`1gooooo`;o00001oooool2o`000<Gooooo000Nooooo`03o`000?oooooooooo07Ko
oooo0ol0001Hooooo`;o0000M?ooool001kooooo00?o0000ooooooooool0:Oooool2o`0004_ooooo
0_l0001Iooooo`;o0000M?ooool001kooooo00?o0000ooooooooool0:Oooool2o`000;_ooooo0_l0
001Oooooo`007_ooool00ol0003oooooooooo`3Vooooo`;o0000Goooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00001_ooool00ol0003oooooooooo`1_ooooo`;o00000_ooool2o`0004oooooo0_l00021oooo
o`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@01_ooool00ol0003oooooooooo`1_ooooo`;o00000_ooool2o`0004oooooo0_l00021
ooooo`000oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool3
o`000?ooooooB?ooool000?ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo
000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`0Tooooo`;o0000oooooolR
ooooo`000oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Tooooo`;o0000ooooool?ooooo`;o00001_ooool2o`0000Wooooo0003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o
0000ooooooooool0ooooooleooooo`;o00001_ooool2o`0000Wooooo0003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0;Gooooo0_l0002@ooooo`007_ooool01?l0003oooooooooooooool2o`0001cooooo0_l0000b
ooooo`;o0000FOooool2o`0000Gooooo0_l0000[ooooo`;o00007_ooool2o`0004?ooooo000Noooo
o`04o`000?ooooooooooooooo`;o00007?ooool2o`0003;ooooo0_l0001Iooooo`;o0000<_ooool2
o`0001kooooo0_l00013ooooo`007_ooool00ol0003oooooooooo`0Booooo`;o0000ooooooldoooo
o`007_ooool00ol0003oooooooooo`0Booooo`;o0000ooooooldooooo`007_ooool00ol0003ooooo
ooooo`1kooooo`;o0000b_ooool001kooooo00?o0000ooooooooool0Noooool2o`000<[ooooo000N
ooooo`03o`000?oooooooooo0?oooooo2?ooool2o`0003kooooo000Nooooo`03o`000?oooooooooo
0?oooooo2?ooool2o`0003kooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
0_l00031ooooo`;o0000QOooool001kooooo00?o0000ooooooooool0`?ooool2o`0008Gooooo000N
ooooo`03o`000?oooooooooo0;Gooooo0_l0002@ooooo`007_ooool00ol0003oooooooooo`2eoooo
o`;o0000T?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0Eoooool2o`0000gooooo0_l0001kooooo`;o0000H_ooool001kooooo00?o0000oooo
ooooool0Eoooool2o`0000gooooo0_l0001kooooo`;o0000H_ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`11ooooo`;o0000ooooool5ooooo`007_oo
ool00ol0003oooooooooo`11ooooo`;o0000ooooool5ooooo`007_ooool00ol0003oooooooooo`2l
ooooo`;o0000ROooool001kooooo00?o0000ooooooooool0?_ooool2o`0007cooooo0_l00029oooo
o`007_ooool00ol0003oooooooooo`0nooooo`;o0000>_ooool2o`000<_ooooo000Nooooo`03o`00
0?oooooooooo07[ooooo0_l000000ooooooo0000o`000038ooooo`007_ooool2o`0005cooooo0_l0
000Pooooo`;o0000b?ooool001kooooo00?o0000ooooooooool0Foooool2o`000>[ooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l0
002Hooooo`;o000000?oooooo`000?l00000@_ooool2o`0003gooooo000Nooooo`03o`000?oooooo
oooo02Oooooo0_l0002Hooooo`;o000000?oooooo`000?l00000@_ooool2o`0003gooooo000Noooo
o`03o`000?oooooooooo0:;ooooo0_l0000Uooooo`;o0000O?ooool001kooooo00?o0000oooooooo
ool0X_ooool2o`0002Gooooo0_l0001looooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0Ooooool2
o`000<Kooooo000Nooooo`03o`000?oooooooooo04Cooooo0_l0000iooooo`;o0000a_ooool001ko
oooo00?o0000ooooooooool0A?ooool2o`000?oooooo0_ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9
ooooo`007_ooool00ol0003oooooooooo`0/ooooo`;o0000oooooolJooooo`007_ooool00ol0003o
ooooooooo`0/ooooo`;o0000Loooool2o`000:Cooooo000Nooooo`03o`000?oooooooooo0:7ooooo
0_l0002Tooooo`007_ooool00ol0003oooooooooo`2>ooooo`;o0000]oooool001kooooo00?o0000
ooooooooool0H?ooool2o`0002cooooo0_l0002gooooo`007_ooool00ol0003oooooooooo`0Zoooo
o`;o0000=?ooool2o`000>Gooooo000Nooooo`03o`000?oooooooooo02[ooooo0_l0003ooooooaco
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`0Wooooo`;o0000AOooool2o`000=Oooooo000Noooo
o`03o`000?oooooooooo02Oooooo0_l00015ooooo`;o0000eoooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`00
0?oooooooooo06oooooo0_l0003Fooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Koooool2o`0008Cooooo
0_l0001@ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`?o0000
Ooooool2o`0007Cooooo0_l0001@ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo
00CoA4A4omgMgOoooooo00001oooool00ol0003oooooooooo`1oooooo`;o0000a_ooool000?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000oooo
ooooool0oooooom8ooooo`000oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<
c?l000001oooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000oooo
ooooool09oooool2o`00053ooooo0_l0003<ooooo`007_ooool00ol0003oooooooooo`0Wooooo`;o
0000D?ooool2o`000<cooooo000Nooooo`03o`000?oooooooooo04Sooooo0_l0003mooooo`007_oo
ool00ol0003oooooooooo`18ooooo`;o0000oOooool001kooooo00?o0000ooooooooool0Z?ooool2
o`0009gooooo000Nooooo`03o`000?oooooooooo06Cooooo0_l00012ooooo`;o0000WOooool001ko
oooo00?o0000ooooooooool0I?ooool2o`0001;ooooo0_l0001Jooooo`;o0000D_ooool2o`0001go
oooo000Nooooo`03o`000?oooooooooo00gooooo0_l0001Yooooo`;o0000F_ooool2o`0005;ooooo
0_l0000Mooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o0000ooooooliooooo`007_ooool0
0ol0003oooooooooo`2Yooooo`;o0000N_ooool2o`00023ooooo000Nooooo`03o`000?oooooooooo
0:Wooooo0_l0001jooooo`;o00008?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`0dooooo`;o0000oooooolBooooo`007_ooool00ol0003oooooooooo`0Aoooo
o`;o00008Oooool2o`000?oooooo4_ooool001kooooo00?o0000ooooooooool04Oooool2o`00047o
oooo0_l0003aooooo`007_ooool00ol0003oooooooooo`1Dooooo`;o0000lOooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3booooo`;o0000Doooool0
01kooooo00?o0000ooooooooool0hoooool2o`0000gooooo0_l0001Cooooo`007_ooool00ol0003o
ooooooooo`3Sooooo`;o0000H_ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`1Mooooo`?o
0000ioooool001kooooo00?o0000ooooooooool0GOooool3o`0000gooooo0_l0003Hooooo`007_oo
ool2o`0006kooooo0_l0003Hooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0?oooool2o`000?oo
oooo1oooool001kooooo00?o0000ooooooooool0?oooool2o`000?oooooo1oooool001kooooo00?o
0000ooooooooool0D_ooool2o`000??ooooo000Nooooo`03o`000?oooooooooo05;ooooo0_l0002Q
ooooo`;o0000D?ooool001kooooo00?o0000ooooooooool0mOooool2o`00053ooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0hoooool2o`0001;ooooo
0_l0001>ooooo`007_ooool00ol0003oooooooooo`3Sooooo`;o00004_ooool2o`0004kooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0ooooool9oooo
o`;o0000?Oooool001kooooo00?o0000ooooooooool0FOooool2o`000:gooooo0_l0000mooooo`00
7_ooool00ol0003oooooooooo`1Iooooo`;o0000D?ooool2o`0009[ooooo000Nooooo`03o`000?oo
oooooooo0:_ooooo0_l0002Jooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo02[ooooo0_l0003ooooooacooooo000Nooooo`03o`000?oooooooooo02[ooooo0_l0
003ooooooacooooo000Nooooo`03o`000?oooooooooo05Cooooo0_l0003aooooo`007_ooool00ol0
003oooooooooo`1Dooooo`;o0000lOooool001kooooo00?o0000ooooooooool0oooooolPooooo`;o
00009_ooool001kooooo00?o0000ooooooooool0oooooolPooooo`;o00009_ooool001kooooo00?o
0000ooooooooool0E_ooool2o`000>oooooo000Nooooo`03o`000?oooooooooo05Kooooo0_l0003O
ooooo`;o00003_ooool001kooooo00?o0000ooooooooool0oooooolhooooo`;o00003_ooool001ko
oooo00?o0000ooooooooool0Koooool2o`000=Kooooo000Nooooo`03o`000?oooooooooo06oooooo
0_l0003Fooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^
k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06oooo
o`03o`000?oooooooooo05gooooo0_l0003Xooooo`000oooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000GOooool2o`0005;ooooo0_l0002D
ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q
8@06ooooo`03o`000?oooooooooo0;7ooooo0_l0001Kooooo`;o0000=oooool000?ooooo00Go0000
ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003ooooo
ooooo`07ooooo`;o0000=oooool2o`000<cooooo0_l0000gooooo`000oooool01Ol@413ooooooooo
oooooooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`07ooooo`;o0000
=oooool2o`0002Gooooo0_l000000ooooooo0000o`00000Dooooo`;o0000aOooool000?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0
Ioooool2o`000003ooooool0003o000001Cooooo0_l00035ooooo`000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`0Iooooo`;o
0000<_ooool2o`0005cooooo0_l0002Jooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o0000
<_ooool2o`0001Kooooo0_l00014ooooo`;o0000V_ooool001kooooo00?o0000ooooooooool0D_oo
ool2o`00017ooooo0_l0003Pooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o00002?ooool2
o`0002Kooooo0_l00003ooooo`;o00004?ooool2o`0001Cooooo0_l0001Sooooo`;o0000HOooool0
01kooooo00?o0000ooooooooool08?ooool2o`0000Sooooo0_l0000Dooooo`;o00005Oooool2o`00
013ooooo0_l0000Dooooo`;o00008Oooool2o`0000Oooooo0_l0000gooooo`;o00009oooool2o`00
03Sooooo000Nooooo`03o`000?oooooooooo043ooooo0_l0001Pooooo`;o00001oooool2o`00063o
oooo0_l0000hooooo`007_ooool00ol0003oooooooooo`0Looooo`;o00005Oooool2o`0004cooooo
0_l0000?ooooo`;o00005Oooool2o`0005;ooooo0_l00018ooooo`007_ooool00ol0003ooooooooo
o`0Looooo`;o00005Oooool2o`0000gooooo0_l0000?ooooo`;o00002_ooool2o`0001?ooooo0_l0
000;ooooo`;o00003oooool2o`0001Gooooo0_l0001Booooo`;o0000B?ooool001kooooo00?o0000
ooooooooool0>Oooool2o`0000Oooooo0_l0000;ooooo`;o00000_ooool2o`0000[ooooo0_l0000C
ooooo`;o0000dOooool001kooooo00?o0000ooooooooool01?ooool2o`0003?ooooo0_l0000;oooo
o`;o00001oooool2o`0005Gooooo0_l0000_ooooo`;o0000K_ooool001kooooo00?o0000oooooooo
ool01?ooool2o`0003kooooo1?l0001Nooooo`;o0000;oooool2o`0006kooooo000Nooooo`03o`00
0?oooooooooo04Cooooo0_l0003oooooo`;ooooo000Nooooo`;o0000oooooom9ooooo`007_ooool0
0ol0003oooooooooo`18ooooo`;o0000:?ooool2o`000=?ooooo000Nooooo`03o`000?oooooooooo
03Sooooo0_l0000>ooooo`;o0000:?ooool2o`0001Gooooo0_l0002looooo`007_ooool00ol0003o
ooooooooo`0hooooo`;o00009_ooool2o`0000?ooooo0_l0000Rooooo`;o0000_?ooool001kooooo
00?o0000ooooooooool0H?ooool2o`0000?ooooo0_l0000Iooooo`;o0000aOooool001kooooo00?o
0000ooooooooool0P?ooool2o`0005Oooooo0_l00009ooooo`;o0000HOooool001kooooo00?o0000
ooooooooool0fOooool2o`0000Wooooo0_l0001Qooooo`007_ooool00ol0003oooooooooo`0Koooo
o`;o00001_ooool2o`000?oooooo8oooool001kooooo00?o0000ooooooooool06oooool2o`0000Ko
oooo0_l0002Pooooo`;o0000:Oooool2o`0005Gooooo000Nooooo`03o`000?oooooooooo02?ooooo
0_l0000?ooooo`;o00001?ooool2o`0008Wooooo0_l0000Yooooo`;o00006?ooool2o`00037ooooo
0_l00008ooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o000000?oooooo`000?l000003ooo
ool2o`0000Cooooo0_l0001Fooooo`;o0000M_ooool2o`00037ooooo0_l00008ooooo`007_ooool0
0ol0003oooooooooo`0Pooooo`;o000000?oooooo`000?l000001?ooool2o`0000Sooooo0_l0000J
ooooo`;o0000@Oooool2o`000;?ooooo000Nooooo`03o`000?oooooooooo02Wooooo0_l00008oooo
o`;o00004?ooool2o`0000Sooooo0_l0000:ooooo`;o00002Oooool4o`0002Wooooo0_l0001Roooo
o`;o0000C_ooool001kooooo00?o0000ooooooooool0AOooool2o`0001Cooooo0_l00006ooooo`;o
000000?oooooo`000?l000000_l0000Yooooo`;o0000H_ooool2o`0004kooooo000Nooooo`03o`00
0?oooooooooo01kooooo0_l00005ooooo`;o00004_ooool2o`0002Sooooo0_l0000>ooooo`;o0000
:oooool2o`0003Sooooo0_l0001[ooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o00001ooo
ool2o`000005ooooool0003o0000o`000?ooool00_l0000Booooo`;o00004oooool2o`0001Oooooo
0_l0000:ooooo`;o00001Oooool2o`0002Cooooo0_l0000Gooooo`;o00007oooool2o`0000Kooooo
0_l0001Sooooo`007_ooool2o`0001Kooooo0_l0000:ooooo`?o0000:_ooool3o`0001Kooooo0_l0
000Aooooo`;o0000?Oooool2o`0002Oooooo0_l0001Sooooo`007_ooool00ol0003oooooooooo`1?
ooooo`;o0000m_ooool001kooooo00?o0000ooooooooool0eoooool2o`0002gooooo0_l0000ooooo
o`007_ooool00ol0003oooooooooo`3Gooooo`;o0000;Oooool2o`0003oooooo000Nooooo`03o`00
0?oooooooooo04Wooooo0_l0000]ooooo`;o0000cOooool001kooooo00Co0000ooooool0003o0000
AOooool2o`000003ooooool0003o000002cooooo0ol0002Fooooo`;o0000=Oooool001kooooo00Co
0000ooooool0003o0000AOooool2o`0000Gooooo0_l0000Qooooo`;o00001Oooool2o`0003gooooo
0_l0000`ooooo`;o00009_ooool2o`0003Gooooo000Nooooo`03o`000?oooooooooo04Wooooo1_l0
000Qooooo`;o0000A?ooool2o`00033ooooo0_l00002ooooo`;o0000FOooool001kooooo00?o0000
ooooooooool0BOooool4o`0003?ooooo0_l00003ooooo`;o00007?ooool2o`0004Oooooo0_l0000_
ooooo`;o00001oooool2o`0001oooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0000Yoooo
o`;o00004?ooool2o`0000Gooooo0_l0000booooo`;o00000oooool3o`0001_ooooo0_l0001Doooo
o`;o00008_ooool2o`0000Oooooo0_l0000=ooooo`;o00002_ooool2o`0000Cooooo000Mooooo`;o
00002_ooool4o`0002;ooooo0_l00003ooooo`;o00004?ooool2o`0000;ooooo0_l000000ooooooo
0000o`00000:ooooo`;o0000;?ooool2o`0000cooooo0_l0001Sooooo`;o0000>_ooool2o`0000[o
oooo0_l00004ooooo`007Oooool2o`0000cooooo0_l00003ooooo`;o00007Oooool2o`0001Gooooo
0ol000001?oooooo0000o`000?ooool4o`0000Sooooo0_l0000<ooooo`;o0000;?ooool2o`000;7o
oooo000Nooooo`03o`000?oooooooooo00oooooo0_l0000cooooo`Co000000Coooooo`000?l0003o
oooo1?l0000Fooooo`;o00001?ooool2o`00063ooooo0_l000000ooooooo0000o`000014ooooo`;o
0000;_ooool001kooooo00?o0000ooooooooool07Oooool2o`0001oooooo0_l00004ooooo`;o0000
0oooool2o`000004ooooool0003o0000o`0001Kooooo1?l00003ooooo`;o0000H?ooool2o`000003
ooooool0003o000004Cooooo0_l0000^ooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o0000
7oooool5o`0000[ooooo0_l0000Fooooo`Co0000g_ooool001kooooo00?o0000ooooooooool0?ooo
ool4o`0001Cooooo0_l0000Cooooo`;o00001_ooool2o`000=7ooooo000Nooooo`;o0000F?ooool3
o`0001;ooooo0_l00006ooooo`;o0000dOooool001kooooo00?o0000ooooooooool0>_ooool2o`00
00?ooooo0_l00005ooooo`;o00000oooool2o`000003ooooool0003o000000Oooooo0ol0001<oooo
o`;o0000COooool2o`00053ooooo000Nooooo`03o`000?oooooooooo03[ooooo0_l00003ooooo`;o
00001Oooool2o`0000?ooooo1Ol00004ooooo`;o00005_ooool2o`0000Kooooo0_l0000Yooooo`;o
00001Oooool2o`0004gooooo0_l00019ooooo`;o00001Oooool001kooooo00?o0000ooooooooool0
C?ooool2o`0000Kooooo0_l0000Fooooo`;o00001_ooool2o`0000Sooooo0_l0000Oooooo`;o0000
Woooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo02Wooooo0_l0000Oooooo`?o00003Ooo
ool2o`0000oooooo0_l0000Aooooo`;o00006Oooool2o`0007Cooooo0_l0000fooooo`007_ooool0
0ol0003oooooooooo`0Vooooo`;o000000?oooooo`000?l000003?ooool2o`000003ooooool0003o
000000Wooooo0_l00003ooooo`?o00003Oooool2o`0000oooooo0_l0000/ooooo`;o0000M?ooool2
o`0000_ooooo0_l0000Yooooo`007_ooool00ol0003oooooooooo`0Vooooo`;o00003oooool2o`00
0003ooooool0003o000000Sooooo0ol00007ooooo`;o00007Oooool2o`0008Gooooo0_l0000Voooo
o`;o0000:Oooool001gooooo0_l0000iooooo`;o00002oooool2o`0000Oooooo0ol0000Eooooo`;o
00001_ooool2o`0008Gooooo0_l0000Vooooo`;o0000:Oooool001gooooo0_l0000Hooooo`;o0000
0oooool2o`0001Kooooo0_l0000<ooooo`;o000000?oooooo`000?l000001oooool2o`0001Kooooo
0_l0002eooooo`;o0000:Oooool001kooooo00?o0000ooooooooool05_ooool2o`000003ooooool0
003o000000;o00005Oooool5o`0000[ooooo0_l00003ooooo`;o00001_ooool2o`0000[ooooo0_l0
001mooooo`;o0000COooool2o`0001gooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l0000<
ooooo`;o00002Oooool2o`000004ooooool0003o0000o`0000kooooo0_l00006ooooo`;o00002_oo
ool2o`0005Cooooo0_l0000Wooooo`;o0000COooool2o`0001gooooo000Nooooo`03o`000?oooooo
oooo01gooooo0ol00007ooooo`;o000000?oooooo`000?l000002_ooool2o`0000Cooooo0ol0000A
ooooo`;o00002Oooool2o`0005?ooooo0_l0002Eooooo`007_ooool00ol0003oooooooooo`0Moooo
o`?o00002_ooool2o`0000Wooooo1?l00003ooooo`?o00004Oooool3o`0000Sooooo0_l0000Loooo
o`;o0000]_ooool2o`0001Cooooo000Nooooo`03o`000?oooooooooo01Sooooo0_l0000Kooooo`Co
00003Oooool2o`0000Wooooo0_l0000Vooooo`;o0000]_ooool2o`0001Cooooo0003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006oooo
o`03o`000?oooooooooo01Sooooo0_l00006ooooo`;o00003oooool2o`0000Kooooo0_l000000ooo
oooo0000o`000002ooooo`;o00001?ooool2o`0005kooooo0_l0002Oooooo`000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool0
0ol0003oooooooooo`0?ooooo`;o00003oooool2o`0000oooooo1?l00004ooooo`;o000000?ooooo
o`000?l000000_ooool3o`0000[ooooo0_l00005ooooo`;o0000D?ooool2o`0009oooooo0003oooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
00000ooooooo0000o`00000<ooooo`;o00008_ooool2o`0000cooooo0_l0000:ooooo`;o00001Ooo
ool2o`0004Sooooo0_l0002Wooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go
<S8boiRHV?ooooooV9RHoc8b<P06ooooo`04o`000?ooooooooooooooo`;o0000;?ooool2o`0000Co
oooo0_l00004ooooo`;o00001Oooool2o`0000?ooooo0_l0000:ooooo`;o0000BOooool2o`000:Oo
oooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<
00Kooooo00?o0000ooooooooool0;oooool3o`0000?ooooo0_l00002ooooo`Co00001Oooool2o`00
00?ooooo1?l00002ooooo`;o00000_ooool4o`0000[ooooo0_l00002ooooo`;o00001oooool2o`00
01cooooo0_l0002kooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj
^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo00oooooo0_l0000Nooooo`?o00001oooool3
o`0000cooooo0ol00002ooooo`Ko00001Oooool2o`0000Gooooo0_l00002ooooo`;o00001oooool2
o`0001cooooo0_l0000Vooooo`;o00007oooool2o`0007;ooooo0003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool02_oo
ool2o`0000?ooooo0_l0000Oooooo`?o00001oooool2o`0001?ooooo0_l00007ooooo`;o0000F?oo
ool2o`0001oooooo0_l0001booooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
ZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo00[ooooo0_l00004ooooo`;o0000
7_ooool5o`0000Kooooo0_l000000ooooooo0000o`00000Iooooo`;o00000_ooool2o`0000Cooooo
0_l00008ooooo`;o0000f?ooool001kooooo00Co0000oooooooooooooooo0_l0000=ooooo`;o0000
5Oooool2o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o0000
00?oooooo`000?l000001_ooool2o`000003ooooool0003o000000kooooo0_l00002ooooo`;o0000
1?ooool5o`0000Gooooo0_l000000ooooooo0000o`00003Eooooo`007_ooool01?l0003ooooooooo
ooooool2o`0002Cooooo0_l00003ooooo`;o000000?oooooo`000?l000001?ooool2o`000003oooo
ool0003o000000?o00000_ooool2o`0000Gooooo0_l000000ooooooo0000o`00000Dooooo`;o0000
0oooool4o`000003ooooool0003o000000Gooooo0_l0001Qooooo`;o0000I?ooool2o`0000cooooo
000Nooooo`04o`000?oooooo0000o`0002kooooo0_l00004ooooo`So00000_ooool2o`00013ooooo
0_l00006ooooo`;o00000oooool4o`0000Gooooo1?l0001Xooooo`;o0000I?ooool2o`0000cooooo
000Nooooo`04o`000?oooooo0000o`0002gooooo0_l00002ooooo`;o00000oooool4o`0000Gooooo
0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`00
00Kooooo0ol00002ooooo`Co00001Oooool2o`0001Wooooo0_l00022ooooo`;o0000?oooool001ko
oooo00?o0000ooooooooool01oooool2o`0002Gooooo0_l00002ooooo`;o00001Oooool3o`0000Co
oooo1Ol000000ooooooo0000o`000003ooooo`Go00002Oooool5o`000003ooooool0003o000000;o
00000oooool4o`0001Sooooo0_l00022ooooo`;o0000?oooool001kooooo00?o0000ooooooooool0
1oooool4o`0001cooooo0_l00003ooooo`;o00001_ooool2o`000003ooooool0003o000000?o0000
1Oooool2o`0000?ooooo1?l00003ooooo`;o00002oooool4o`000003ooooool0003o000000;o0000
0oooool4o`000<Oooooo0_l0000Dooooo`007_ooool00ol0003oooooooooo`09ooooo`;o00007?oo
ool2o`0000?ooooo0_l00006ooooo`;o000000?oooooo`000?l000001Ol0000:ooooo`Co000000?o
ooooo`000?l000000_ooool2o`0000_ooooo1Ol00003ooooo`;o0000bOooool2o`0001Cooooo000N
ooooo`03o`000?oooooooooo03_ooooo0ol00006ooooo`Co00000_ooool2o`0000Gooooo0_l00002
ooooo`;o00001oooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`00001O
ooooo`;o0000Goooool2o`0001Wooooo000Nooooo`03o`000?oooooooooo023ooooo0_l00006oooo
o`?o00003_ooool5o`0000?ooooo0_l000000ooooooo0000o`000002o`0000Sooooo0_l00003oooo
o`Co00001?ooool2o`0000Gooooo1Ol000000ooooooo0000o`000006ooooo`;o0000Eoooool2o`00
05oooooo0_l0000Iooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o00002oooool2o`0000Co
oooo1Ol0000>ooooo`?o000000?oooooo`000?l000001?l000000ooooooo0000o`000007ooooo`Go
00001Oooool2o`0000Cooooo0_l00003ooooo`Oo00001_ooool2o`000003ooooool0003o000003Go
oooo0_l00006ooooo`;o0000U?ooool001kooooo00?o0000ooooooooool04oooool2o`00017ooooo
0_l0000Aooooo`;o00000_ooool4o`0000?ooooo0ol00006ooooo`Co00000_ooool3o`0000Wooooo
0_l000000ooooooo0000o`000005o`0000Kooooo0_l0000Kooooo`;o00006oooool2o`0000Kooooo
0_l0000/ooooo`;o0000I_ooool001kooooo0_l00013ooooo`Ko00000_ooool2o`000003ooooool0
003o000000Cooooo0ol00004ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`;o0000
9Oooool2o`00057ooooo0_l0000hooooo`;o00007_ooool2o`0000Cooooo0_l00006ooooo`007_oo
ool00ol0003oooooooooo`0nooooo`;o00000_ooool:o`000003ooooool0003o000000Gooooo0_l0
0004ooooo`;o000000?oooooo`000?l000000oooool2o`00083ooooo0_l0000cooooo`;o00007_oo
ool2o`0000Cooooo0_l00006ooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o0000;Oooool5
o`000003ooooool0003o000000Go00000_ooool2o`0000Cooooo0_l00005ooooo`;o000000?ooooo
o`000?l000000oooool2o`000003ooooool0003o000002Wooooo0_l00005ooooo`;o0000Boooool2
o`00067ooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0000:ooooo`;o00007oooool2o`00
00gooooo1?l000000ooooooo0000o`000003o`000004ooooool0003o0000ooooo`;o00000_ooool4
o`0000Sooooo0_l00002ooooo`So00000oooool2o`0000Cooooo0_l0000Looooo`;o00001Oooool2
o`0008Oooooo0_l0000Iooooo`;o00002_ooool001kooooo00?o0000ooooooooool00oooool2o`00
01oooooo0_l0000:ooooo`?o00003?ooool2o`0000;ooooo1Ol00002ooooo`Go00000_ooool9o`00
00?ooooo0_l00002ooooo`Go000000?oooooo`000?l000001Ol00004ooooo`;o0000[?ooool2o`00
01Wooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0Tooooo`;o00002oooool2o`0000[o
oooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo1Ol000000ooooooo0000o`000009o`00
00?ooooo0_l00003ooooo`;o00001?ooool9o`00093ooooo0_l0000Eooooo`;o00006_ooool2o`00
017ooooo000Nooooo`03o`000?oooooooooo02Kooooo0_l0000Cooooo`Co00001Oooool2o`0000?o
oooo3?l00002ooooo`Ko00001Oooool2o`000004ooooool0003o0000ooooo`Go000000Coooooo`00
0?l0003o0000T?ooool2o`0001Gooooo0_l0000Jooooo`;o00004Oooool001kooooo00Co0000oooo
ool0003o00005Oooool2o`0000kooooo0_l00005ooooo`;o00003?ooool2o`0000Oooooo0_l00004
ooooo`_o00000_ooool6o`0000Oooooo0ol000000ooooooo0000o`000003o`000<Wooooo0_l0000?
ooooo`007_ooool01?l0003oooooo`000?l0000Eooooo`;o00003oooool2o`0000Cooooo0_l0000@
ooooo`;o00002_ooool2o`000003ooooool0003o000000?o000000Coooooo`000?l0003ooooo0_l0
00000ooooooo0000o`000002o`0000Kooooo0_l00003ooooo`;o00001?ooool2o`0000_ooooo0_l0
002Gooooo`;o00004?ooool2o`0000gooooo0_l00007ooooo`;o00001_ooool001kooooo00?o0000
ooooooooool00_l0000Uooooo`;o00001?ooool2o`00013ooooo0_l00004ooooo`?o00000oooool2
o`0000;ooooo1?l000001?oooooo0000o`000?ooool7o`0000gooooo0_l00002ooooo`;o00002ooo
ool2o`0009Oooooo0_l0000@ooooo`;o00005_ooool2o`0000Kooooo000Nooooo`03o`000?oooooo
oooo00;o00001oooool2o`0000Oooooo0_l0000Nooooo`;o00002oooool2o`0000Cooooo0ol00003
ooooo`Ko00001_ooool4o`0000;ooooo0_l00007ooooo`;o00000oooool2o`0000oooooo0_l00004
ooooo`;o0000`oooool001kooooo00Co0000ooooool0003o00002?ooool2o`0000Oooooo0_l0000M
ooooo`?o00002_ooool2o`0000Sooooo1ol0000>ooooo`;o00001oooool2o`0000Gooooo1_l00005
ooooo`;o00001oooool4o`0002Wooooo0ol0002Fooooo`007_ooool01?l0003oooooo`000?l0000`
ooooo`;o00001Oooool2o`0000Cooooo0_l00005ooooo`;o000000?oooooo`000?l000001Ol00002
ooooo`?o00000_ooool2o`0000Oooooo0_l0000<ooooo`Ko00001Oooool4o`0000Gooooo1?l0000Y
ooooo`?o0000S_ooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo03?ooooo0_l00003oooo
o`?o00002_ooool2o`0000?ooooo1Ol00002ooooo`Wo00001Oooool2o`0000Kooooo0_l00005oooo
o`Ko00000oooool2o`000003ooooool0003o000003Oooooo0_l0000Pooooo`;o0000<oooool2o`00
013ooooo0_l0000Qooooo`;o00001_ooool001kooooo00?o0000ooooooooool0<oooool2o`0000Co
oooo0_l0000@ooooo`Co00001Oooool2o`0000;ooooo1Ol00008ooooo`Co00002Oooool2o`0000?o
oooo0_l0000jooooo`;o00008?ooool2o`0003?ooooo1?l0000>ooooo`;o0000:Oooool001kooooo
00?o0000ooooooooool04oooool2o`0003kooooo0_l00002ooooo`Ko00001oooool7o`0000Gooooo
0_l0000>ooooo`;o0000H_ooool2o`0002Kooooo0_l0000Qooooo`;o00005_ooool001kooooo0_l0
000Dooooo`;o0000??ooool4o`000003ooooool0003o000000;o00000_ooool4o`0000Cooooo0_l0
00000ooooooo0000o`000002o`0000Gooooo0_l0000>ooooo`;o0000H_ooool2o`0004Wooooo0_l0
0005ooooo`;o00003oooool001kooooo00?o0000ooooooooool0>Oooool3o`0001Gooooo0_l00002
ooooo`go00001_ooool2o`000<cooooo0_l0000?ooooo`007_ooool00ol0003oooooooooo`0[oooo
o`;o00003?ooool3o`0000Kooooo0_l00004ooooo`;o00000_ooool2o`0000Gooooo1Ol00002oooo
o`;o00001?ooool2o`0001?ooooo0_l0000Kooooo`;o0000R?ooool2o`0002Wooooo000Nooooo`03
o`000?oooooooooo02_ooooo0_l0000Eooooo`;o00001?ooool2o`0000;ooooo1Ol00002ooooo`Go
00002?ooool2o`0000?ooooo0_l00004ooooo`;o00002?ooool2o`0000_ooooo0_l0000>ooooo`;o
00003oooool2o`0005Oooooo0_l0000Nooooo`;o0000:Oooool001kooooo00?o0000ooooooooool0
<_ooool4o`0001Oooooo1Ol000000ooooooo0000o`000002o`0000cooooo1?l00004ooooo`;o0000
2?ooool2o`0000[ooooo0ol0000Oooooo`;o00007Oooool2o`0003Oooooo0ol00019ooooo`007_oo
ool00ol0003oooooooooo`05ooooo`;o0000:oooool4o`0000kooooo0_l00008ooooo`Wo00001Ooo
ool2o`0000Gooooo0_l000000ooooooo0000o`000004ooooo`;o00004oooool4o`0002Cooooo0_l0
000Gooooo`;o0000=oooool2o`0004[ooooo000Nooooo`03o`000?oooooooooo00Gooooo0_l0000m
ooooo`;o00001oooool2o`0000;ooooo1Ol00002ooooo`;o000000Coooooo`000?l0003o00002?oo
ool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`00013ooooo0ol0000Tooooo`;o0000
?_ooool2o`0005cooooo000Nooooo`03o`000?oooooooooo04?ooooo0_l00008ooooo`;o00000_oo
ool4o`0000?ooooo0_l000000ooooooo0000o`00000<ooooo`Co00000oooool2o`0000;ooooo0_l0
000<ooooo`;o0000IOooool2o`0005cooooo000Nooooo`03o`000?oooooooooo04?ooooo0_l00007
ooooo`?o00001?ooool2o`0000;ooooo0_l00002ooooo`;o00001oooool2o`0000?ooooo1?l00002
ooooo`Oo0000@Oooool2o`0005Cooooo0_l0000hooooo`007_ooool00ol0003oooooooooo`13oooo
o`;o00001_ooool4o`0000Cooooo1_l000000ooooooo0000o`000008ooooo`;o00001?ooool3o`00
00;ooooo1Ol00013ooooo`;o0000E?ooool2o`0003Sooooo000Nooooo`03o`000?oooooooooo04_o
oooo0_l00008ooooo`Co000000?oooooo`000?l000002oooool2o`000003ooooool0003o000000Go
00000_ooool3o`000=7ooooo000Nooooo`03o`000?oooooooooo03oooooo0_l000000ooooooo0000
o`000006ooooo`;o00000_ooool2o`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l00000
2Oooool2o`000003ooooool0003o000000[o00008Oooool2o`0001Oooooo0_l0002Eooooo`007_oo
ool00ol0003oooooooooo`0Mooooo`;o00005?ooool3o`0000Wooooo0_l000000ooooooo0000o`00
0006ooooo`;o00000_ooool2o`0000?ooooo1?l00002ooooo`;o000000?oooooo`000?l000002ooo
ool5o`0000;ooooo0ol000001?oooooo0000o`000?ooool2o`0001kooooo0_l0000Gooooo`;o0000
Joooool2o`0002Sooooo000Nooooo`03o`000?oooooooooo01gooooo0_l0000Dooooo`?o00007Ooo
ool5o`00017ooooo0_l00002ooooo`Co00001_ooool2o`000:Cooooo0_l0000Xooooo`007_ooool0
0ol0003oooooooooo`1Cooooo`;o000000?oooooo`000?l000000oooool2o`000003ooooool0003o
000000gooooo1?l00008ooooo`;o0000c?ooool001kooooo00?o0000ooooooooool02oooool2o`00
04Wooooo0_l00003ooooo`;o000000?oooooo`000?l000003Oooool2o`0000[ooooo0_l0003<oooo
o`007_ooool2o`0000cooooo0_l00014ooooo`;o00000oooool2o`0000;ooooo0_l00006ooooo`;o
00002Oooool2o`0002kooooo0_l0001hooooo`;o0000;_ooool001kooooo00?o0000ooooooooool0
DOooool2o`0000?ooooo0_l00002ooooo`;o00001_ooool2o`000004ooooool0003o0000o`0001So
oooo0_l0000Kooooo`;o0000N?ooool2o`0002kooooo000Nooooo`03o`000?oooooooooo00Cooooo
0_l0000Kooooo`;o0000<oooool2o`0000Sooooo0_l00003ooooo`?o00006?ooool2o`000<Gooooo
000Nooooo`04o`000?ooooooooooooooo`;o000000?oooooo`000?l000006oooool2o`0001gooooo
0_l0000Dooooo`;o000000?oooooo`000?l000001Oooool2o`0000Gooooo0_l0003Fooooo`;o0000
1_ooool001kooooo00Co0000oooooooooooooooo0_l0000mooooo`;o00004oooool3o`000003oooo
ool0003o000000cooooo0_l0003Booooo`;o00000_ooool2o`0000Kooooo000Nooooo`03o`000?oo
oooooooo05Gooooo0_l00003ooooo`;o00003oooool2o`000<kooooo0_l0000:ooooo`007_ooool0
0ol0003oooooo`000002o`0001Cooooo0_l0000Kooooo`;o00009Oooool4o`0000Kooooo0_l00005
ooooo`;o0000f_ooool001kooooo00?o0000ooooool000000_l0000Dooooo`;o00006oooool2o`00
027ooooo0_l00004ooooo`Go00000oooool2o`0000Oooooo0_l0002Qooooo`;o0000=Oooool001ko
oooo00?o0000ooooooooool0;Oooool6o`0002?ooooo0_l00006ooooo`?o00003?ooool2o`0000;o
oooo0_l0000Mooooo`;o0000O_ooool2o`0003Gooooo000Nooooo`03o`000?oooooooooo02gooooo
1_l0000[ooooo`Co00003Oooool4o`0001Gooooo0_l00006ooooo`;o0000[_ooool2o`0000Gooooo
000Nooooo`03o`000?oooooooooo033ooooo0_l0000>ooooo`;o00007?ooool4o`0000gooooo1?l0
000Eooooo`;o0000:Oooool2o`0008_ooooo0_l00005ooooo`007_ooool00ol0003oooooooooo`06
ooooo`;o0000:?ooool2o`0000kooooo0_l0000Eooooo`Co000000?oooooo`000?l000001?l00006
ooooo`;o00001oooool2o`0000;ooooo0_l00008ooooo`;o0000<_ooool2o`0005Cooooo0_l0000l
ooooo`007_ooool00ol0003oooooooooo`06ooooo`;o00001_ooool2o`0001Kooooo0_l0000Aoooo
o`;o00001?ooool2o`0001Kooooo1?l000001Ooooooo0000o`000?l0003ooooo00;o00001_ooool2
o`0000_ooooo0_l00008ooooo`;o00000_ooool2o`0003Oooooo0_l0001;ooooo`;o00002_ooool2
o`00033ooooo000Nooooo`03o`000?oooooooooo00kooooo0_l0000Fooooo`;o00004Oooool2o`00
00Cooooo0ol0000Gooooo`Co00003_ooool2o`00017ooooo0ol00002ooooo`?o00004oooool2o`00
027ooooo0_l0001Gooooo`;o0000<?ooool001Cooooo1?l000000ol@413oooooooooo`03ooooo`03
o`000?oooooooooo03?ooooo0_l0000:ooooo`?o00005oooool4o`0000cooooo1?l0000Aooooo`?o
00000oooool2o`0001?ooooo0_l0002/ooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo03;ooooo0ol0000:ooooo`;o00005oooool2o`000003ooooool0003o000000cooooo
0_l0003Looooo`005_ooool00ol0003oooooooooo`05ooooo`?o0000<_ooool2o`0002Cooooo0_l0
001Aooooo`;o0000V_ooool001Kooooo00?o0000ooooooooool0/oooool2o`0009[ooooo000Foooo
o`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`00
5_ooool00ol0003oooooooooo`3ooooooe3ooooo000Dooooo`03oeEEEOmVIVKo00000?ooooooD_oo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.22973 .83685 Mdot
.3533 .74474 Mdot
.14494 .84914 Mdot
.24851 .89993 Mdot
.28425 .92672 Mdot
.25335 .84613 Mdot
.96143 .05825 Mdot
.28103 .91826 Mdot
.318 .86532 Mdot
.25559 .73171 Mdot
.23866 .03583 Mdot
.1611 .00053 Mdot
.20454 .85219 Mdot
.02226 .8729 Mdot
.22554 .8301 Mdot
.33258 .67462 Mdot
.43856 .76084 Mdot
.1863 .7942 Mdot
.21112 .82798 Mdot
.28279 .88276 Mdot
.23877 .73268 Mdot
.31718 .79246 Mdot
.22032 .77393 Mdot
.56851 .82167 Mdot
.32119 .91657 Mdot
.31868 .93206 Mdot
.27285 .86992 Mdot
.33328 .95378 Mdot
.22496 .03523 Mdot
.27232 .7784 Mdot
.14261 .80893 Mdot
.23677 .83401 Mdot
.36784 .88426 Mdot
.52415 .74586 Mdot
.05817 .86087 Mdot
.28638 .00083 Mdot
.12927 .88028 Mdot
.68373 .10163 Mdot
.13437 .93666 Mdot
.27711 .92188 Mdot
.15011 .80498 Mdot
.98863 .96329 Mdot
.33266 .86629 Mdot
.51885 .39948 Mdot
.93035 .81991 Mdot
.0117 .95766 Mdot
.87765 .78914 Mdot
.19843 .64585 Mdot
.28038 .9981 Mdot
.18012 .15293 Mdot
.14839 .82213 Mdot
.0878 .75833 Mdot
.28486 .92849 Mdot
.30137 .02182 Mdot
.25341 .89389 Mdot
.38809 .23444 Mdot
.0984 .92138 Mdot
.23902 .89122 Mdot
.2706 .86445 Mdot
.35818 .86796 Mdot
.20671 .87207 Mdot
.30807 .91542 Mdot
.80163 .94633 Mdot
.34738 .91628 Mdot
.22506 .91562 Mdot
.3143 .81811 Mdot
.06734 .81313 Mdot
.27258 .86986 Mdot
.24275 .82734 Mdot
.53353 .92879 Mdot
.42124 .43638 Mdot
.35533 .10825 Mdot
.98877 .83066 Mdot
.22253 .35971 Mdot
.26887 .94445 Mdot
.07451 .95633 Mdot
.29649 .68243 Mdot
.09214 .98025 Mdot
.26002 .84409 Mdot
.53614 .91481 Mdot
.08146 .67079 Mdot
.11038 .09807 Mdot
.46795 .30935 Mdot
.29098 .90918 Mdot
.92127 .98817 Mdot
.748 .50117 Mdot
.30042 .95242 Mdot
.24609 .9032 Mdot
.23156 .82953 Mdot
.44845 .01679 Mdot
.39801 .91991 Mdot
.71145 .55672 Mdot
.26388 .10529 Mdot
.36471 .77948 Mdot
.27398 .79368 Mdot
.13654 .64227 Mdot
.99054 .06129 Mdot
.00779 .80812 Mdot
.36964 .9626 Mdot
.46679 .04302 Mdot
.26473 .87649 Mdot
.12531 .75797 Mdot
.32163 .80279 Mdot
.30414 .86733 Mdot
.44826 .75862 Mdot
.23369 .77357 Mdot
.32893 .53109 Mdot
.32138 .59669 Mdot
.17248 .73717 Mdot
.21203 .48186 Mdot
.1804 .86105 Mdot
.37748 .33185 Mdot
.34882 .61268 Mdot
.1641 .81291 Mdot
.916 .70093 Mdot
.95712 .13667 Mdot
.06627 .83634 Mdot
.20236 .83149 Mdot
.31759 .17103 Mdot
.41824 .68481 Mdot
.27293 .8949 Mdot
.17456 .70514 Mdot
.30914 .839 Mdot
.42785 .98475 Mdot
.00484 .91168 Mdot
.72824 .9 Mdot
.21808 .92013 Mdot
.22182 .8194 Mdot
.48408 .69954 Mdot
.15673 .79688 Mdot
.66467 .77969 Mdot
.07322 .15648 Mdot
.12602 .50144 Mdot
.23577 .72366 Mdot
.18204 .75818 Mdot
.15699 .80658 Mdot
.23626 .78022 Mdot
.34196 .07798 Mdot
.148 .84178 Mdot
.29645 .83671 Mdot
.21164 .80487 Mdot
.36387 .92679 Mdot
.34293 .80837 Mdot
.29744 .97851 Mdot
.78141 .63473 Mdot
.16162 .01136 Mdot
.27148 .77523 Mdot
.26342 .88893 Mdot
.05599 .95553 Mdot
.21452 .92724 Mdot
.41344 .87117 Mdot
.35114 .84292 Mdot
.16273 .97286 Mdot
.28801 .88533 Mdot
.23644 .83466 Mdot
.23718 .85433 Mdot
.30628 .06407 Mdot
.70898 .25627 Mdot
.29682 .87587 Mdot
.34577 .69504 Mdot
.33081 .11752 Mdot
.16342 .98212 Mdot
.91876 .82404 Mdot
.25578 .715 Mdot
.3597 .96913 Mdot
.29278 .90809 Mdot
.25397 .90346 Mdot
.27362 .87318 Mdot
.86281 .62292 Mdot
.26807 .77511 Mdot
.32144 .80374 Mdot
.08941 .75558 Mdot
.09295 .93769 Mdot
.74829 .54388 Mdot
.25502 .84381 Mdot
.21043 .08743 Mdot
.52425 .71354 Mdot
.2758 .93924 Mdot
.87935 .99166 Mdot
.07127 .77126 Mdot
.36747 .90463 Mdot
.23374 .02355 Mdot
.22042 .91874 Mdot
.02319 .83764 Mdot
.35584 .101 Mdot
.18319 .68639 Mdot
.3379 .80352 Mdot
.41903 .9096 Mdot
.09596 .73642 Mdot
.22622 .94187 Mdot
.24376 .83468 Mdot
.00955 .81445 Mdot
.22311 .82148 Mdot
.42812 .72897 Mdot
.38441 .64581 Mdot
.37124 .88112 Mdot
.17947 .9722 Mdot
.19738 .94559 Mdot
.32574 .86739 Mdot
.32037 .89144 Mdot
.91039 .12326 Mdot
.57849 .5362 Mdot
.21367 .72382 Mdot
.03873 .80154 Mdot
.32553 .91658 Mdot
.24646 .90626 Mdot
.43193 .98557 Mdot
.24683 .87248 Mdot
.04632 .62289 Mdot
.30908 .08326 Mdot
.28115 .81662 Mdot
.22671 .80673 Mdot
.07488 .71155 Mdot
.42628 .63176 Mdot
.34069 .1048 Mdot
.36168 .24103 Mdot
.25567 .92134 Mdot
.31893 .484 Mdot
.24758 .04358 Mdot
.99244 .92098 Mdot
.83623 .16575 Mdot
.29387 .84293 Mdot
.37864 .93995 Mdot
.27003 .85969 Mdot
.42048 .9797 Mdot
.30115 .13279 Mdot
.14858 .86158 Mdot
.18204 .79251 Mdot
.23449 .45792 Mdot
.33752 .80848 Mdot
.28098 .88404 Mdot
.37165 .90341 Mdot
.34366 .81475 Mdot
.66772 .66877 Mdot
.38924 .27459 Mdot
.29091 .71381 Mdot
.70347 .74973 Mdot
.15485 .81684 Mdot
.4648 .11924 Mdot
.81753 .28799 Mdot
.20055 .91345 Mdot
.33743 .80387 Mdot
.17265 .73473 Mdot
.28643 .79504 Mdot
.13127 .93333 Mdot
.34524 .70407 Mdot
.31825 .93863 Mdot
.31614 .79366 Mdot
.68689 .89269 Mdot
.14405 .80542 Mdot
.11874 .75892 Mdot
.26566 .86887 Mdot
.53056 .17401 Mdot
.68477 .76731 Mdot
.87437 .83847 Mdot
.26363 .6934 Mdot
.29803 .92741 Mdot
.53856 .08641 Mdot
.03203 .76764 Mdot
.37373 .75421 Mdot
.23053 .81701 Mdot
.22683 .78403 Mdot
.28836 .34398 Mdot
.53695 .0674 Mdot
.34255 .80987 Mdot
.82595 .21306 Mdot
.24495 .63595 Mdot
.05302 .97542 Mdot
.16881 .81848 Mdot
.2789 .89717 Mdot
.36781 .9644 Mdot
.92915 .94512 Mdot
.20363 .83145 Mdot
.2466 .76652 Mdot
.04422 .69774 Mdot
.25807 .83523 Mdot
.24553 .05435 Mdot
.11117 .98861 Mdot
.2912 .01971 Mdot
.16725 .75706 Mdot
.06989 .92684 Mdot
.31913 .79046 Mdot
.25067 .71377 Mdot
.13266 .9536 Mdot
.29685 .92525 Mdot
.37531 .9386 Mdot
.25203 .76804 Mdot
.4378 .97132 Mdot
.30453 .75231 Mdot
.22085 .83911 Mdot
.24337 .76372 Mdot
.44774 .94128 Mdot
.20053 .82321 Mdot
.48805 .733 Mdot
.78802 .56997 Mdot
.28474 .02569 Mdot
.20743 .90019 Mdot
.31805 .87441 Mdot
.08352 .93252 Mdot
.79982 .64874 Mdot
.50832 .90858 Mdot
.38515 .93449 Mdot
.12372 .91916 Mdot
.30546 .0051 Mdot
.29748 .22783 Mdot
.2647 .75169 Mdot
.27201 .86682 Mdot
.25008 .8423 Mdot
.76405 .84692 Mdot
.55004 .56622 Mdot
.26092 .88318 Mdot
.09388 .92779 Mdot
.32016 .92427 Mdot
.28735 .87743 Mdot
.31056 .96754 Mdot
.34032 .91482 Mdot
.19318 .06185 Mdot
.63637 .68999 Mdot
.37898 .93248 Mdot
.67113 .33347 Mdot
.15187 .90866 Mdot
.35311 .87347 Mdot
.16408 .72775 Mdot
.24763 .0126 Mdot
.15355 .80309 Mdot
.26791 .87529 Mdot
.28887 .01705 Mdot
.2365 .80539 Mdot
.18198 .99654 Mdot
.30008 .89223 Mdot
.33234 .88646 Mdot
.26078 .83216 Mdot
.16228 .71326 Mdot
.57556 .77672 Mdot
.39198 .25104 Mdot
.20872 .3395 Mdot
.64595 .65212 Mdot
.27873 .88482 Mdot
.36519 .81615 Mdot
.69085 .50523 Mdot
.36415 .96616 Mdot
.38423 .77881 Mdot
.22283 .79508 Mdot
.32243 .05924 Mdot
.43011 .04048 Mdot
.12514 .91684 Mdot
.21068 .78451 Mdot
.04169 .42068 Mdot
.40243 .14405 Mdot
.27528 .9251 Mdot
.18337 .82268 Mdot
.28515 .90754 Mdot
.20431 .93657 Mdot
.31366 .81398 Mdot
.45919 .01036 Mdot
.20058 .84884 Mdot
.00174 .94116 Mdot
.24911 .70685 Mdot
.20921 .86726 Mdot
.25427 .59773 Mdot
.3224 .7919 Mdot
.12749 .90941 Mdot
.1478 .80651 Mdot
.27528 .80657 Mdot
.39219 .93576 Mdot
.04852 .80779 Mdot
.17805 .60146 Mdot
.13494 .75883 Mdot
.18979 .10516 Mdot
.26483 .78709 Mdot
.35349 .10673 Mdot
.26947 .86655 Mdot
.1499 .82405 Mdot
.32397 .82392 Mdot
.36386 .8374 Mdot
.54801 .02837 Mdot
.8967 .81213 Mdot
.27161 .97085 Mdot
.77552 .98395 Mdot
.2909 .79463 Mdot
.25783 .84456 Mdot
.3203 .89972 Mdot
.26743 .5664 Mdot
.81117 .77846 Mdot
.30352 .00311 Mdot
.36542 .76381 Mdot
.33717 .64779 Mdot
.06064 .4285 Mdot
.2771 .88141 Mdot
.4064 .87218 Mdot
.21186 .80364 Mdot
.23736 .87051 Mdot
.23453 .88049 Mdot
.2542 .92905 Mdot
.27195 .93392 Mdot
.30288 .3995 Mdot
.37197 .75168 Mdot
.69505 .14386 Mdot
.26885 .86458 Mdot
.14903 .80367 Mdot
.32515 .86797 Mdot
.9588 .75391 Mdot
.0125 .1581 Mdot
.30377 .9116 Mdot
.23674 .07018 Mdot
.49984 .60008 Mdot
.22349 .82278 Mdot
.41943 .06613 Mdot
.26456 .05845 Mdot
.25765 .71588 Mdot
.35902 .10201 Mdot
.29703 .89222 Mdot
.34166 .11194 Mdot
.58959 .92249 Mdot
.91767 .61257 Mdot
.22302 .76386 Mdot
.36989 .76689 Mdot
.30612 .12275 Mdot
.1348 .89788 Mdot
.25834 .84224 Mdot
.27367 .89509 Mdot
.62943 .77409 Mdot
.43823 .05347 Mdot
.23437 .83577 Mdot
.25451 .89632 Mdot
.73641 .69913 Mdot
.95873 .19517 Mdot
.3269 .83778 Mdot
.34659 .09654 Mdot
.97697 .57258 Mdot
.62706 .43507 Mdot
.10939 .73051 Mdot
.00487 .06493 Mdot
.33775 .88629 Mdot
.75737 .06205 Mdot
.06806 .90663 Mdot
.26643 .04436 Mdot
.35505 .68529 Mdot
.32269 .70942 Mdot
.91204 .84825 Mdot
.26779 .6473 Mdot
.47609 .4523 Mdot
.42599 .43221 Mdot
.20044 .85429 Mdot
.25609 .64032 Mdot
.22072 .85874 Mdot
.35613 .90323 Mdot
.27471 .87673 Mdot
.621 .29345 Mdot
.20766 .73003 Mdot
.52603 .01121 Mdot
.1877 .75555 Mdot
.36467 .96183 Mdot
.26134 .85111 Mdot
.27438 .84645 Mdot
.26238 .87554 Mdot
.31619 .89706 Mdot
.29451 .02002 Mdot
.48776 .64367 Mdot
.17441 .71598 Mdot
.22705 .92976 Mdot
.2414 .88906 Mdot
.25669 .85099 Mdot
.20587 .90553 Mdot
.58676 .95396 Mdot
.00509 .81854 Mdot
.36092 .88406 Mdot
.66679 .90293 Mdot
.20273 .83666 Mdot
.0826 .78757 Mdot
.27251 .78383 Mdot
.304 .94622 Mdot
.28974 .91559 Mdot
.28997 .91231 Mdot
.16298 .90374 Mdot
.24627 .83919 Mdot
.21154 .9032 Mdot
.26719 .89424 Mdot
.47 .04749 Mdot
.30042 .91698 Mdot
.17691 .82381 Mdot
.45608 .71745 Mdot
.33326 .79775 Mdot
.2046 .79491 Mdot
.23386 .83068 Mdot
.50076 .05074 Mdot
.56587 .24801 Mdot
.23096 .89954 Mdot
.10935 .8101 Mdot
.35148 .94707 Mdot
.15542 .81074 Mdot
.28161 .88183 Mdot
.27223 .23212 Mdot
.29539 .66419 Mdot
.35477 .92825 Mdot
.20155 .93501 Mdot
.42011 .78692 Mdot
.33475 .94438 Mdot
.65105 .87408 Mdot
.23121 .06865 Mdot
.39925 .74063 Mdot
.17301 .80277 Mdot
.10171 .75031 Mdot
.31315 .57312 Mdot
.21684 .78561 Mdot
.03788 .05478 Mdot
.30982 .93776 Mdot
.47596 .9693 Mdot
.30931 .89844 Mdot
.26111 .79881 Mdot
.1859 .77177 Mdot
.3018 .90881 Mdot
.27212 .21047 Mdot
.41511 .0954 Mdot
.28761 .93718 Mdot
.73403 .68426 Mdot
.31667 .9563 Mdot
.14145 .63542 Mdot
.9563 .44331 Mdot
.15541 .79864 Mdot
.23856 .71304 Mdot
.16912 .90484 Mdot
.25921 .84471 Mdot
.30273 .87503 Mdot
.47222 .01209 Mdot
.7581 .06186 Mdot
.14868 .68282 Mdot
.26039 .34795 Mdot
.32134 .94018 Mdot
.47193 .62083 Mdot
.76764 .63002 Mdot
.77332 .55455 Mdot
.29484 .92918 Mdot
.13296 .90582 Mdot
.28811 .90096 Mdot
.27331 .87044 Mdot
.24342 .9214 Mdot
.38445 .90189 Mdot
.69808 .15202 Mdot
.97465 .63091 Mdot
.29505 .83628 Mdot
.73643 .72263 Mdot
.17903 .01381 Mdot
.24571 .83731 Mdot
.15743 .83929 Mdot
.97722 .01406 Mdot
.592 .28533 Mdot
.1545 .80669 Mdot
.25197 .72589 Mdot
.2687 .87321 Mdot
.44697 .98066 Mdot
.8844 .01851 Mdot
.37568 .88582 Mdot
.58027 .80093 Mdot
.12871 .68229 Mdot
.80689 .06151 Mdot
.2317 .87683 Mdot
.28005 .89002 Mdot
.31357 .99064 Mdot
.75008 .68991 Mdot
.2628 .73051 Mdot
.34866 .96422 Mdot
.71328 .12614 Mdot
.42344 .09215 Mdot
.24266 .77256 Mdot
.28285 .0094 Mdot
.31734 .10181 Mdot
.37524 .94914 Mdot
.06432 .16079 Mdot
.2352 .83268 Mdot
.07697 .75154 Mdot
.31156 .86968 Mdot
.24529 .8415 Mdot
.25456 .78974 Mdot
.22715 .86918 Mdot
.34484 .83648 Mdot
.32897 .65641 Mdot
.22814 .03258 Mdot
.25393 .85771 Mdot
.37351 .75461 Mdot
.51058 .08125 Mdot
.84785 .76068 Mdot
.19342 .90324 Mdot
.19352 .80254 Mdot
.58307 .1939 Mdot
.26239 .94506 Mdot
.21561 .66896 Mdot
.12745 .10801 Mdot
.34003 .79322 Mdot
.29307 .78484 Mdot
.25937 .89216 Mdot
.23357 .90367 Mdot
.2921 .06129 Mdot
.33733 .91169 Mdot
.13021 .00356 Mdot
.32006 .91336 Mdot
.25397 .05292 Mdot
.2777 .87654 Mdot
.27067 .97462 Mdot
.252 .75717 Mdot
.35028 .82943 Mdot
.26962 .87642 Mdot
.15398 .81608 Mdot
.00852 .81287 Mdot
.87525 .72257 Mdot
.25851 .71343 Mdot
.27059 .8988 Mdot
.30641 .78451 Mdot
.81487 .84613 Mdot
.22927 .82623 Mdot
.86631 .8993 Mdot
.71303 .73364 Mdot
.23066 .79813 Mdot
.92615 .57108 Mdot
.20999 .83311 Mdot
.3288 .7073 Mdot
.35571 .11158 Mdot
.47201 .02655 Mdot
.37672 .94758 Mdot
.90446 .03465 Mdot
.15543 .04797 Mdot
.14415 .77396 Mdot
.23126 .82608 Mdot
.71353 .982 Mdot
.95637 .82729 Mdot
.30558 .63173 Mdot
.55165 .22212 Mdot
.75592 .40717 Mdot
.21768 .83536 Mdot
.01537 .85763 Mdot
.14572 .87282 Mdot
.27552 .86415 Mdot
.31261 .8068 Mdot
.91304 .94415 Mdot
.24511 .84351 Mdot
.38858 .01618 Mdot
.28712 .90868 Mdot
.30993 .01977 Mdot
.25582 .89689 Mdot
.22104 .82515 Mdot
.23947 .89013 Mdot
.24374 .84056 Mdot
.9906 .93539 Mdot
.00287 .88299 Mdot
.93296 .70582 Mdot
.22 .74245 Mdot
.17071 .91155 Mdot
.20651 .94738 Mdot
.2958 .89376 Mdot
.82246 .84664 Mdot
.53353 .91576 Mdot
.28875 .99968 Mdot
.27998 .65932 Mdot
.26749 .8575 Mdot
.57169 .24804 Mdot
.28278 .91863 Mdot
.25908 .9325 Mdot
.23556 .92088 Mdot
.11036 .67845 Mdot
.26585 .86915 Mdot
.89478 .82957 Mdot
.23171 .76676 Mdot
.95922 .81266 Mdot
.27539 .92404 Mdot
.89364 .06994 Mdot
.51405 .59465 Mdot
.25518 .84132 Mdot
.3262 .98382 Mdot
.48601 .04597 Mdot
.35247 .59685 Mdot
.36981 .95633 Mdot
.09676 .19225 Mdot
.348 .74475 Mdot
.29207 .81695 Mdot
.08118 .89402 Mdot
.31922 .92107 Mdot
.45133 .78064 Mdot
.23409 .85437 Mdot
.16602 .75197 Mdot
.12066 .70075 Mdot
.58394 .34789 Mdot
.34616 .97771 Mdot
.15662 .69122 Mdot
.22574 .82396 Mdot
.23615 .83425 Mdot
.13114 .00692 Mdot
.09586 .8544 Mdot
.10467 .67764 Mdot
.47006 .77079 Mdot
.17787 .8321 Mdot
.23274 .65825 Mdot
.99023 .79897 Mdot
.20793 .42261 Mdot
.03913 .82961 Mdot
.35482 .84729 Mdot
.23737 .75038 Mdot
.25934 .85277 Mdot
.78544 .65749 Mdot
.85112 .92544 Mdot
.31718 .0612 Mdot
.24569 .4459 Mdot
.29081 .79297 Mdot
.2273 .84657 Mdot
.15531 .83698 Mdot
.50149 .18247 Mdot
.3216 .85285 Mdot
.10965 .32013 Mdot
.44764 .93326 Mdot
.16511 .39292 Mdot
.34502 .86737 Mdot
.44977 .85359 Mdot
.37719 .07156 Mdot
.01945 .72139 Mdot
.78091 .19671 Mdot
.19906 .79877 Mdot
.37478 .07052 Mdot
.32284 .79374 Mdot
.26275 .93679 Mdot
.67719 .20641 Mdot
.32635 .80144 Mdot
.23303 .8023 Mdot
.82669 .98404 Mdot
.23538 .70877 Mdot
.42672 .0352 Mdot
.57476 .82072 Mdot
.51629 .95708 Mdot
.06799 .83301 Mdot
.27794 .90467 Mdot
.94363 .85878 Mdot
.22141 .95548 Mdot
.28902 .84295 Mdot
.30109 .80957 Mdot
.21805 .84739 Mdot
.30222 .85184 Mdot
.58633 .23024 Mdot
.29837 .65605 Mdot
.54495 .21381 Mdot
.24308 .82143 Mdot
.16517 .92296 Mdot
.48803 .44001 Mdot
.33366 .86032 Mdot
.28038 .88664 Mdot
.25865 .84443 Mdot
.23714 .05338 Mdot
.74804 .68586 Mdot
.20493 .91743 Mdot
.28796 .79836 Mdot
.07497 .91581 Mdot
.35099 .96298 Mdot
.16021 .04381 Mdot
.16824 .79912 Mdot
.16097 .83711 Mdot
.45349 .70362 Mdot
.23646 .81532 Mdot
.2156 .7192 Mdot
.3696 .94731 Mdot
.26098 .80551 Mdot
.02891 .70196 Mdot
.22228 .9126 Mdot
.15185 .80954 Mdot
.65594 .9269 Mdot
.28366 .92234 Mdot
.12549 .3518 Mdot
.16448 .84257 Mdot
.2274 .73818 Mdot
.21595 .8706 Mdot
.47623 .04153 Mdot
.3035 .80155 Mdot
.19915 .94572 Mdot
.132 .23354 Mdot
.33369 .94465 Mdot
.3283 .91653 Mdot
.24782 .74866 Mdot
.26591 .86889 Mdot
.28603 .7888 Mdot
.17307 .79731 Mdot
.34714 .90939 Mdot
.15549 .81094 Mdot
.27492 .83492 Mdot
.15351 .64148 Mdot
.25649 .89836 Mdot
.33117 .63989 Mdot
.46096 .4423 Mdot
.48753 .61014 Mdot
.22962 .93339 Mdot
.29194 .03519 Mdot
.33351 .80139 Mdot
.29497 .83986 Mdot
.28051 .87849 Mdot
.24032 .86146 Mdot
.12473 .96512 Mdot
.17406 .13974 Mdot
.1668 .14706 Mdot
.30133 .94418 Mdot
.19518 .02479 Mdot
.26156 .92925 Mdot
.3406 .91317 Mdot
.97837 .75963 Mdot
.30605 .94466 Mdot
.37832 .01686 Mdot
.53212 .67769 Mdot
.29369 .78033 Mdot
.19376 .90547 Mdot
.38767 .65595 Mdot
.37671 .0075 Mdot
.1985 .76852 Mdot
.05415 .5804 Mdot
.2377 .52291 Mdot
.29584 .03004 Mdot
.24348 .74855 Mdot
.50354 .02466 Mdot
.30031 .97117 Mdot
.1748 .89971 Mdot
.17924 .57568 Mdot
.42165 .90327 Mdot
.26694 .86256 Mdot
.13487 .98051 Mdot
.02875 .95571 Mdot
.22064 .83491 Mdot
.16565 .00155 Mdot
.28697 .90702 Mdot
.27793 .88283 Mdot
.38099 .93071 Mdot
.2363 .85744 Mdot
.28701 .94673 Mdot
.32526 .06406 Mdot
.29786 .93489 Mdot
.37428 .95928 Mdot
.34359 .89875 Mdot
.24317 .75218 Mdot
.1704 .81959 Mdot
.36422 .97394 Mdot
.21105 .86134 Mdot
.22065 .04419 Mdot
.06307 .9518 Mdot
.26495 .72762 Mdot
.29122 .82234 Mdot
.2802 .99649 Mdot
.39897 .92789 Mdot
.46779 .31281 Mdot
.04331 .64331 Mdot
.27684 .87679 Mdot
.27115 .86417 Mdot
.31159 .84876 Mdot
.04321 .93747 Mdot
.96242 .89601 Mdot
.6843 .9482 Mdot
.18131 .82711 Mdot
.32023 .91651 Mdot
.16222 .83532 Mdot
.70802 .14781 Mdot
.41153 .04174 Mdot
.15325 .80548 Mdot
.30116 .75273 Mdot
.26385 .91667 Mdot
.85503 .84244 Mdot
.28503 .91559 Mdot
.2442 .72922 Mdot
.32445 .9136 Mdot
.19113 .86562 Mdot
.28995 .88887 Mdot
.22334 .88958 Mdot
.34824 .86002 Mdot
.51218 .29724 Mdot
.3183 .92322 Mdot
.24412 .01723 Mdot
.21856 .83061 Mdot
.2634 .99774 Mdot
.70803 .81865 Mdot
.25498 .87763 Mdot
.58484 .85169 Mdot
.25737 .89929 Mdot
.34113 .92712 Mdot
.27546 .96887 Mdot
.03826 .71189 Mdot
.28661 .94815 Mdot
.10714 .10663 Mdot
.28783 .11641 Mdot
.9417 .6976 Mdot
.20666 .74731 Mdot
.70809 .8875 Mdot
.2153 .82794 Mdot
.28877 .92042 Mdot
.21797 .94175 Mdot
.34048 .80092 Mdot
.23463 .83617 Mdot
.22519 .82182 Mdot
.35782 .74868 Mdot
.31909 .7922 Mdot
.6733 .76688 Mdot
.3737 .11377 Mdot
.13227 .90616 Mdot
.26589 .7778 Mdot
.3237 .79233 Mdot
.2127 .1114 Mdot
.21769 .91306 Mdot
.72021 .06675 Mdot
.20723 .82623 Mdot
.29772 .89742 Mdot
.3647 .90931 Mdot
.1994 .7522 Mdot
.17713 .66574 Mdot
.7487 .93291 Mdot
.33477 .73098 Mdot
.53199 .01277 Mdot
.03028 .77985 Mdot
.45352 .6086 Mdot
.26917 .7247 Mdot
.18265 .81494 Mdot
.22583 .78656 Mdot
.09963 .84203 Mdot
.53631 .71251 Mdot
.42917 .17443 Mdot
.37277 .88378 Mdot
.16904 .96014 Mdot
.19036 .44549 Mdot
.08995 .9182 Mdot
.28967 .92982 Mdot
.13104 .63626 Mdot
.31835 .84597 Mdot
.36859 .86003 Mdot
.28414 .43112 Mdot
.21293 .74267 Mdot
.29649 .89432 Mdot
.22856 .82852 Mdot
.49535 .08553 Mdot
.28417 .08714 Mdot
.27828 .82492 Mdot
.54833 .61969 Mdot
.08024 .66716 Mdot
.24696 .88979 Mdot
.24646 .7861 Mdot
.26315 .88386 Mdot
.34315 .81116 Mdot
.97452 .79662 Mdot
.21857 .81143 Mdot
.30215 .70003 Mdot
.30655 .80576 Mdot
.2565 .84348 Mdot
.36765 .02799 Mdot
.23732 .87021 Mdot
.15408 .827 Mdot
.31787 .92181 Mdot
.14465 .04632 Mdot
.30096 .78793 Mdot
.24864 .84873 Mdot
.16104 .78713 Mdot
.03101 .91964 Mdot
.29326 .84207 Mdot
.08918 .81613 Mdot
.21857 .81061 Mdot
.30088 .89927 Mdot
.06953 .87857 Mdot
.41796 .25552 Mdot
.35748 .84534 Mdot
.17638 .83955 Mdot
.07488 .80716 Mdot
.47211 .86368 Mdot
.78418 .97985 Mdot
.77179 .19649 Mdot
.31012 .78817 Mdot
.26534 .85552 Mdot
.219 .83363 Mdot
.42768 .00257 Mdot
.2816 .87944 Mdot
.22336 .78425 Mdot
.31577 .07105 Mdot
.29655 .13648 Mdot
.37653 .93506 Mdot
.70422 .57092 Mdot
.37516 .39765 Mdot
.358 .86843 Mdot
.52823 .86696 Mdot
.35353 .07153 Mdot
.71644 .08808 Mdot
.30521 .932 Mdot
.32285 .86713 Mdot
.88759 .44886 Mdot
.26717 .85543 Mdot
.26078 .88875 Mdot
.24779 .92039 Mdot
.29436 .83748 Mdot
.33431 .69547 Mdot
.33706 .81925 Mdot
.28709 .8019 Mdot
.16421 .7594 Mdot
.37367 .77455 Mdot
.81374 .56907 Mdot
.02599 .76815 Mdot
.27336 .8788 Mdot
.68378 .25646 Mdot
.26036 .90566 Mdot
.19151 .93407 Mdot
.10891 .75528 Mdot
.39477 .93403 Mdot
.27767 .91262 Mdot
.23233 .86593 Mdot
.14767 .1016 Mdot
.28992 .06773 Mdot
.28181 .84259 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`06ooooo`;o00001Oooool00ol0003o
ooooooooo`04o`0000[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`08ooooo`;o
00000oooool3o`0000gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`05ooooo`;o
00001_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool00_ooool001kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00Kooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo0_l0000:ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03Oooool3o`0000gooooo00?o0000ooooooooool0
1Oooool2o`0000Oooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo000Nooooo`03o`000?oo
oooooooo02Oooooo0_l0000_ooooo`;o00001Oooool2o`0001Gooooo0_l0000Iooooo`;o0000]?oo
ool001kooooo00?o0000ooooooooool0<?ooool2o`0001[ooooo0_l0000:ooooo`;o0000=oooool2
o`0000;ooooo0_l0000@ooooo`Co0000W?ooool001kooooo00?o0000ooooooooool0<?ooool2o`00
00Cooooo0_l0000Dooooo`;o0000;?ooool2o`0001;ooooo0_l00005ooooo`;o00004?ooool4o`00
08oooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`0fooooo`;o00004oooool2o`0000go
oooo0ol00004ooooo`;o00005?ooool2o`000003ooooool0003o000001;ooooo0_l0002;ooooo`;o
00007Oooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo04_ooooo0_l0000=ooooo`Ko0000
00?oooooo`000?l000005?ooool2o`000:;ooooo0_l0000Zooooo`007_ooool00ol0003ooooooooo
o`0kooooo`;o00002oooool2o`0000kooooo0_l00002ooooo`Co0000@?ooool2o`000:Gooooo000N
ooooo`03o`000?oooooooooo03_ooooo0_l0000;ooooo`;o00003_ooool2o`0001Wooooo0_l0000P
ooooo`;o00002Oooool2o`0000cooooo0_l0002Gooooo`007_ooool00ol0003oooooooooo`1Loooo
o`;o00005Oooool2o`00023ooooo0_l0000Gooooo`;o0000Uoooool001kooooo00?o0000oooooooo
ool0AOooool3o`0001?ooooo0ol0000Yooooo`;o0000VOooool2o`0002?ooooo000Nooooo`03o`00
0?oooooooooo04Gooooo0ol000000ooooooo0000o`00000@ooooo`;o0000:_ooool2o`0009Wooooo
0_l0000Sooooo`007_ooool00ol0003oooooooooo`19ooooo`;o0000?Oooool2o`000;gooooo000N
ooooo`03o`000?oooooooooo033ooooo0_l0000Booooo`;o00001_ooool2o`0000Gooooo0_l0000]
ooooo`;o00001?ooool2o`0000[ooooo0_l000000ooooooo0000o`00002^ooooo`007_ooool00ol0
003oooooooooo`0[ooooo`;o00000oooool2o`0001;ooooo0_l00006ooooo`;o00001Oooool2o`00
02gooooo0_l0000@ooooo`Go000000?oooooo`000?l00000Zoooool001kooooo00?o0000oooooooo
ool0:oooool2o`000003ooooool0003o000006Gooooo0_l00003ooooo`;o0000Zoooool001kooooo
0_l0000_ooooo`;o00006Oooool2o`0000?ooooo0_l0000jooooo`;o00004oooool2o`000:Kooooo
000Nooooo`03o`000?oooooooooo00Sooooo0_l0000oooooo`;o000000?oooooo`000?l000000_l0
000jooooo`;o00004oooool2o`000:Kooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l00012
ooooo`;o00001?ooool2o`00017ooooo0_l0003=ooooo`;o00004Oooool001kooooo00?o0000oooo
ooooool0>oooool2o`0001Gooooo0_l00007ooooo`;o00001_ooool4o`0008_ooooo0_l0000>oooo
o`;o0000<?ooool2o`0000Sooooo0_l00007ooooo`007_ooool2o`0003cooooo0_l0000Nooooo`;o
00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`00002:ooooo`;o00003_ooool2o`0003[o
oooo0_l00007ooooo`007_ooool2o`0004Sooooo0_l0000Aooooo`;o00000oooool2o`0000Gooooo
0_l0000Looooo`;o00009?ooool2o`0003[ooooo0_l0001Oooooo`007_ooool00ol0003ooooooooo
o`17ooooo`Co00003oooool2o`0000Oooooo0_l0000:ooooo`;o00001Oooool3o`0000_ooooo0_l0
000Tooooo`;o0000>_ooool2o`0003Kooooo0_l0000Wooooo`007_ooool00ol0003oooooooooo`19
ooooo`;o00006?ooool2o`0000[ooooo0_l00005ooooo`?o0000YOooool2o`0002Oooooo000Noooo
o`03o`000?oooooooooo06_ooooo0_l0003Jooooo`007_ooool00ol0003oooooooooo`1[ooooo`;o
0000=Oooool2o`000:?ooooo000Nooooo`03o`000?oooooooooo063ooooo0_l00010ooooo`;o0000
Xoooool001kooooo00?o0000ooooooooool0@?ooool2o`0001Kooooo0_l00006ooooo`;o0000>ooo
ool2o`0000cooooo0_l0002Jooooo`007_ooool00ol0003oooooooooo`10ooooo`;o00005_ooool2
o`0004?ooooo0_l0000<ooooo`;o0000>?ooool2o`00063ooooo000Nooooo`03o`000?oooooooooo
08Kooooo0_l0001Mooooo`;o0000H?ooool001kooooo00?o0000ooooooooool0KOooool2o`0001Co
oooo0_l000000ooooooo0000o`00002oooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o0000
Boooool2o`0001Cooooo0_l00032ooooo`007_ooool2o`00027ooooo0_l0000:ooooo`;o0000=Ooo
ool2o`0000_ooooo0ol0001Wooooo`;o0000Joooool001kooooo00?o0000ooooooooool0;?ooool2
o`0000cooooo0_l0000Fooooo`;o00003oooool2o`0000Kooooo0_l00003ooooo`?o0000Ioooool2
o`0006_ooooo000Nooooo`03o`000?oooooooooo01oooooo0_l00004ooooo`;o00004oooool2o`00
01Kooooo0_l0000Gooooo`;o00000_ooool2o`000=Kooooo000Nooooo`03o`000?oooooooooo01oo
oooo0_l00004ooooo`;o00006_ooool2o`0002Sooooo0_l00002ooooo`?o0000eOooool001kooooo
00?o0000ooooooooool0@Oooool2o`0002Sooooo0_l00003ooooo`;o00000oooool2o`000=3ooooo
000Nooooo`03o`000?oooooooooo05Wooooo0_l0000<ooooo`;o00003?ooool2o`000=3ooooo000N
ooooo`03o`000?oooooooooo05Wooooo0_l0000<ooooo`;o0000:_ooool2o`000;;ooooo000Noooo
o`03o`000?oooooooooo05oooooo0_l0000booooo`;o0000Soooool2o`00027ooooo000Nooooo`03
o`000?oooooooooo05oooooo0_l00023ooooo`;o0000?_ooool2o`00027ooooo000Nooooo`03o`00
0?oooooooooo0>Cooooo0_l0001Qooooo`007_ooool00ol0003oooooooooo`1Nooooo`;o0000iooo
ool001kooooo00?o0000ooooooooool0G?ooool4o`000=?ooooo0_l0000Booooo`007_ooool00ol0
003oooooooooo`0dooooo`;o00009_ooool2o`000=Gooooo0_l0000Booooo`007_ooool00ol0003o
ooooooooo`0dooooo`;o0000oooooolBooooo`007_ooool00ol0003oooooooooo`1oooooo`;o0000
GOooool2o`0006Oooooo000Nooooo`03o`000?oooooooooo03;ooooo0_l0001;ooooo`;o0000GOoo
ool2o`0000;ooooo0_l0001Sooooo`007_ooool2o`0003?ooooo0_l0002[ooooo`;o000000?ooooo
o`000?l00000Hoooool001kooooo00?o0000ooooooooool0=_ooool2o`000:Oooooo0_l0001Voooo
o`007_ooool00ol0003oooooooooo`02o`0001;ooooo0_l0000Pooooo`;o0000ooooool@ooooo`00
7_ooool00ol0003oooooooooo`02o`0000oooooo0_l000000ooooooo0000o`00003ooooooc;ooooo
000Nooooo`03o`000?oooooooooo017ooooo0_l0003oooooocGooooo000Nooooo`03o`000?oooooo
oooo0?oooooo3Oooool2o`0003Wooooo000Nooooo`03o`000?oooooooooo0?oooooo3Oooool2o`00
03Wooooo000Nooooo`03o`000?oooooooooo06?ooooo0_l0003Rooooo`007_ooool00ol0003ooooo
ooooo`1Sooooo`;o00008_ooool2o`0001oooooo0_l0002Mooooo`007_ooool00ol0003ooooooooo
o`27ooooo`;o00007oooool2o`0009gooooo000Nooooo`03o`000?oooooooooo09oooooo0_l0002V
ooooo`007_ooool00ol0003oooooooooo`2Oooooo`;o0000Y_ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo01_ooooo
0_l0002Looooo`;o0000NOooool2o`00017ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo01_o
oooo0_l0002Looooo`;o0000??ooool2o`000003ooooool0003o000003Sooooo0_l0000Aooooo`00
0oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool3o`000?Oo
oooo0_l000000ooooooo0000o`00001;ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0=So
oooo0_l0001]ooooo`000oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`1Dooooo`;o0000P_ooool2o`0006gooooo0003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000oooo
ooooool0E?ooool2o`000;;ooooo0_l0000mooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0:gooooo0_l0001I
ooooo`;o0000?Oooool001kooooo00?o0000ooooooooool0[Oooool2o`0009Sooooo000Nooooo`03
o`000?oooooooooo0:oooooo0_l0002Fooooo`007_ooool00ol0003oooooooooo`2_ooooo`;o0000
U_ooool001kooooo00?o0000ooooooooool0GOooool2o`000>Sooooo000Nooooo`03o`000?oooooo
oooo05Cooooo0_l00007ooooo`;o0000G?ooool2o`0008[ooooo000Nooooo`03o`000?oooooooooo
02Oooooo0_l0000[ooooo`;o00009?ooool2o`0003oooooo0_l0002:ooooo`007_ooool00ol0003o
ooooooooo`0Wooooo`;o0000DOooool2o`000<_ooooo000Nooooo`03o`000?oooooooooo077ooooo
0_l0003Dooooo`007_ooool00ol0003oooooooooo`1aooooo`;o0000e?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`2dooooo`Co0000Soooool001ko
oooo0_l0001looooo`;o0000=oooool4o`0008oooooo000Nooooo`03o`000?oooooooooo07_ooooo
0_l00007ooooo`;o0000E?ooool2o`0000Kooooo0_l0001Sooooo`007_ooool00ol0003ooooooooo
o`24ooooo`;o0000E?ooool2o`0000Kooooo0_l0001Sooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo07[ooooo0_l0003;ooooo`007_ooool00ol0003oooooooooo`1jooooo`;o0000boooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0;cooooo0_l00029ooooo`007_ooool00ol0003ooooooooo
o`2looooo`;o0000B?ooool2o`0003oooooo000Nooooo`03o`000?oooooooooo0<Kooooo0_l0000n
ooooo`;o0000?oooool001kooooo00?o0000ooooooooool0a_ooool2o`0007oooooo000Nooooo`03
o`000?oooooooooo0:;ooooo0_l0002Sooooo`007_ooool2o`000:?ooooo0_l0002Sooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0U?ooool2o`000;7ooooo000Nooooo`03o`000?oooooooooo09Co
oooo0_l0002aooooo`007_ooool00ol0003oooooooooo`2Dooooo`;o0000/Oooool001kooooo00?o
0000ooooooooool08?ooool2o`000?oooooo9_ooool001kooooo00?o0000ooooooooool08?ooool2
o`000?oooooo9_ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo07Oooooo0_l0001Mooooo`;o0000
Koooool001kooooo00?o0000ooooooooool0Moooool2o`0005gooooo0_l0001_ooooo`007_ooool0
0ol0003oooooooooo`10ooooo`;o0000ooooool6ooooo`007_ooool00ol0003oooooooooo`10oooo
o`;o0000ooooool6ooooo`007_ooool00ol0003oooooooooo`1Jooooo`;o0000joooool001kooooo
00?o0000ooooooooool0DOooool2o`0000Oooooo0_l0001Nooooo`;o0000Roooool001kooooo0_l0
000Vooooo`;o0000:_ooool2o`0006Oooooo0_l0002;ooooo`007_ooool00ol0003oooooooooo`0U
ooooo`;o0000oooooolQooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo04Cooooo0_l0003oooooo`;ooooo000Nooooo`03o`000?oooooooooo04Cooooo
0_l0003oooooo`;ooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413o
ooooooooo`04ooooo`03o`000?oooooooooo03;ooooo0_l0003ooooooaCooooo0003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0booooo`;o0000@_ooool2o`000<oooooo0003ooooo`05oa0@4?ooooooooooooooool@
41002oooool5o`0000Kooooo0ol0001Nooooo`;o00005_ooool2o`0002gooooo0_l0002Pooooo`00
0oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool00ol0
003oooooooooo`1Nooooo`;o0000AOooool2o`000:3ooooo0003ooooo`05o`000?oooooooooooooo
ool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo0?;ooooo0_l0001C
ooooo`000oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool0
0ol0003oooooooooo`3booooo`;o0000Doooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<
ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool02Oooool2o`0003Cooooo0_l0003oooooo`Oooooo000Nooooo`03o`000?oooooooooo00Wooooo
0_l0000dooooo`;o0000ooooool7ooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o0000oooo
oolfooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o0000A_ooool2o`000>gooooo000Noooo
o`03o`000?oooooooooo05Sooooo0_l0000/ooooo`;o0000@?ooool2o`0007gooooo000Nooooo`03
o`000?oooooooooo08Gooooo0ol00010ooooo`;o0000OOooool001kooooo00?o0000ooooooooool0
QOooool2o`0001Cooooo0_l0002Zooooo`007_ooool00ol0003oooooooooo`2Booooo`;o00001ooo
ool2o`0009Kooooo0_l0000Booooo`007_ooool00ol0003oooooooooo`0jooooo`;o00004?ooool2
o`0004Cooooo0_l0002Oooooo`;o00004_ooool001kooooo00?o0000ooooooooool0>_ooool2o`00
013ooooo0_l0003>ooooo`;o0000:Oooool001kooooo0_l0002Hooooo`;o0000Poooool2o`0002Wo
oooo000Nooooo`03o`000?oooooooooo09Oooooo0_l0002^ooooo`007_ooool00ol0003ooooooooo
o`18ooooo`;o0000oOooool001kooooo00?o0000ooooooooool0B?ooool2o`000?gooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo047ooooo0_l0000Qooooo`;o0000hOooool001kooooo
00?o0000ooooooooool0@Oooool2o`00027ooooo0_l0003Qooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000
9_ooool2o`000<Sooooo0_l0001Fooooo`007_ooool00ol0003oooooooooo`0Uooooo`;o0000]Ooo
ool2o`00017ooooo0_l0001Fooooo`007_ooool00ol0003oooooooooo`3Looooo`;o0000JOooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`19ooooo`;o0000o?ooool001kooooo00?o0000oooo
ooooool0BOooool2o`000?cooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0Ioooool2o`000=kooooo000Nooooo`03o`000?oooooooooo06Oooooo0_l0
001?ooooo`;o0000SOooool001kooooo00?o0000ooooooooool0^?ooool2o`0008gooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0koooool2o`0005Ko
oooo000Nooooo`03o`000?oooooooooo0>oooooo0_l0001Fooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0moooool2o`0004kooooo000Nooooo`03o`000?oooooooooo
0>?ooooo0_l0000Booooo`;o0000C_ooool001kooooo00?o0000ooooooooool0hoooool2o`0006;o
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0Dooo
ool2o`0005[ooooo0_l0002Fooooo`007_ooool00ol0003oooooooooo`1Cooooo`;o0000F_ooool2
o`0004_ooooo0_l00006ooooo`;o0000@Oooool001kooooo00?o0000ooooooooool0H_ooool2o`00
07gooooo0_l0000Iooooo`;o00001_ooool2o`0002?ooooo0_l0000?ooooo`;o00002oooool001ko
oooo00?o0000ooooooooool0=_ooool2o`0002[ooooo0_l0001mooooo`;o0000A_ooool2o`0000oo
oooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`0fooooo`;o0000ooooool@ooooo`007_oo
ool00ol0003oooooooooo`0=ooooo`;o0000ooooooliooooo`007_ooool00ol0003oooooooooo`0=
ooooo`;o0000ooooooliooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0Xoooool2o`00
0:;ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMg
MoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo04oooooo0_l0000Cooooo`;o00002?ooool2
o`0003?ooooo0_l0002Rooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`000006ooooo`?o0000Coooool2o`0001?ooooo0_l00008ooooo`;o0000;_oo
ool2o`000:Oooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooo
oonHV9So8B4Q00Kooooo00?o0000ooooooooool0=_ooool2o`0006Kooooo0_l0002Wooooo`000ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03
o`000?oooooooooo03Kooooo0_l0003ooooooa3ooooo0003ooooo`05oa0@4?ooooooooooooooool@
41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo08oooooo0_l00009ooooo`;o
0000Zoooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00So
oooo00?o0000ooooooooool0KOooool2o`00023ooooo0_l00009ooooo`;o0000R_ooool2o`0001oo
oooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106oooo
o`03o`000?oooooooooo06gooooo0_l0002gooooo`;o00007oooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`2Eooooo`;o00005oooool2o`0009Oooooo
000Nooooo`03o`000?oooooooooo00_ooooo0_l00028ooooo`;o00005oooool2o`0006Cooooo0_l0
000aooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o0000ooooool8ooooo`;o0000<Oooool0
01kooooo00?o0000ooooooooool0Goooool2o`0002Gooooo0_l0001]ooooo`;o0000@_ooool2o`00
00cooooo000Nooooo`03o`000?oooooooooo05oooooo0_l0000Uooooo`;o0000KOooool2o`0000?o
oooo0_l0000mooooo`;o00003?ooool001kooooo00?o0000ooooooooool09_ooool2o`0000;ooooo
0_l0000Pooooo`;o0000[?ooool2o`0004_ooooo000Nooooo`03o`000?oooooooooo02Kooooo0_l0
0002ooooo`;o00008?ooool2o`000003ooooool0003o000001Oooooo0_l0003Mooooo`007_ooool0
0ol0003oooooooooo`0:ooooo`;o00007?ooool2o`0000Cooooo0_l0000Oooooo`;o00005oooool2
o`00033ooooo0_l0002[ooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o00007?ooool2o`00
00Cooooo0_l0000<ooooo`;o00005Oooool2o`0002Cooooo0_l0000Oooooo`;o0000Zoooool001ko
oooo00?o0000ooooooooool0??ooool2o`0001Gooooo0_l0000Eooooo`;o00003Oooool2o`0008Go
oooo0_l00015ooooo`007_ooool2o`0006_ooooo0_l0001Rooooo`;o0000<?ooool2o`0004Gooooo
000Nooooo`03o`000?oooooooooo05gooooo0_l00008ooooo`;o00004Oooool2o`0005;ooooo0_l0
001gooooo`007_ooool00ol0003oooooooooo`18ooooo`;o00003Oooool2o`0000Cooooo0_l00008
ooooo`;o00004Oooool2o`0007oooooo0_l0001:ooooo`007_ooool00ol0003oooooooooo`18oooo
o`;o00003Oooool2o`000:;ooooo0_l0001:ooooo`007_ooool00ol0003oooooooooo`0eooooo`;o
00009Oooool2o`000>Wooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l0000Mooooo`;o0000
9Oooool2o`0007Oooooo0_l0001`ooooo`007_ooool00ol0003oooooooooo`0Fooooo`;o0000:_oo
ool2o`00097ooooo0_l0001`ooooo`007_ooool00ol0003oooooooooo`0Fooooo`;o0000:_ooool2
o`0002Cooooo0_l0003Mooooo`007_ooool00ol0003oooooooooo`0Nooooo`;o0000B?ooool2o`00
03oooooo0_l0002Looooo`007_ooool00ol0003oooooooooo`0Nooooo`Co0000Qoooool2o`0009co
oooo000Nooooo`03o`000?oooooooooo023ooooo0_l00004ooooo`;o00001?ooool2o`0002kooooo
0_l0002=ooooo`;o0000F_ooool001kooooo00?o0000ooooooooool09_ooool2o`0000Cooooo0_l0
0009ooooo`;o00008oooool2o`00017ooooo0_l0000Cooooo`;o0000IOooool2o`0000;ooooo0_l0
001Fooooo`007_ooool00ol0003oooooooooo`0gooooo`;o0000=_ooool2o`0001?ooooo0_l00015
ooooo`;o00008_ooool3o`0005Gooooo000Nooooo`03o`000?oooooooooo02oooooo0_l0000Qoooo
o`;o0000Moooool2o`0002?ooooo0_l0001Eooooo`007_ooool00ol0003oooooooooo`0_ooooo`;o
00008Oooool2o`0001Gooooo0_l000000ooooooo0000o`00003Iooooo`007_ooool00ol0003ooooo
ooooo`0:ooooo`;o0000GOooool2o`000003ooooool0003o000002_ooooo0_l0001@ooooo`;o0000
@Oooool2o`0001Oooooo000Nooooo`;o00001_ooool2o`0000?ooooo0_l0000Gooooo`;o0000>Ooo
ool2o`0003Wooooo0_l0001@ooooo`;o0000>Oooool2o`0000Kooooo0_l0000Gooooo`007_ooool0
0ol0003oooooooooo`05ooooo`;o00007?ooool2o`00013ooooo0_l0000Wooooo`;o00003?ooool2
o`00027ooooo0_l0002Eooooo`;o00007oooool001kooooo00?o0000ooooooooool0=Oooool2o`00
017ooooo0_l00003ooooo`;o00006?ooool2o`0000?ooooo0_l0000Qooooo`;o0000V_ooool2o`00
01[ooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0000:ooooo`;o0000<_ooool2o`0000?o
oooo0_l0000Fooooo`Co0000`_ooool2o`0001[ooooo000Nooooo`03o`000?oooooooooo00Sooooo
0_l0000:ooooo`;o00006oooool2o`0001Kooooo0_l00002ooooo`Go00002?ooool2o`0000Wooooo
0_l0000oooooo`;o00000_ooool2o`0009_ooooo000Nooooo`03o`000?oooooooooo037ooooo0_l0
0002ooooo`;o00004_ooool2o`0000;ooooo1Ol00008ooooo`;o0000=?ooool2o`0001Cooooo0_l0
0002ooooo`;o0000Voooool001kooooo00?o0000ooooooooool0=Oooool2o`0000_ooooo0_l0000<
ooooo`;o0000?_ooool2o`000;Gooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0000moooo
o`?o00001Oooool2o`000:3ooooo0_l0000[ooooo`;o0000;Oooool001kooooo00?o0000oooooooo
ool00_ooool2o`0003gooooo0_l00006ooooo`;o00000oooool2o`0000?ooooo0_l0002Fooooo`;o
0000:oooool2o`0002gooooo000Nooooo`03o`000?oooooooooo037ooooo0_l0000<ooooo`;o0000
2_ooool2o`000003ooooool0003o000000;ooooo0ol0000booooo`;o0000__ooool001kooooo00?o
0000ooooooooool07oooool2o`00013ooooo0_l0000<ooooo`;o00002Oooool3o`0000;ooooo1Ol0
000Eooooo`;o00007?ooool2o`0001;ooooo0_l0002Zooooo`007_ooool00ol0003oooooooooo`0K
ooooo`;o00000_ooool2o`0001?ooooo0_l0000Dooooo`;o00000oooool4o`0001Kooooo0_l0000`
ooooo`;o0000Aoooool2o`00067ooooo000Nooooo`03o`000?oooooooooo01_ooooo0_l0000Goooo
o`;o00004?ooool2o`0009cooooo0_l0001Qooooo`007_ooool00ol0003oooooooooo`0dooooo`;o
00002oooool4o`000003ooooool0003o000003Kooooo0_l00037ooooo`007_ooool00ol0003ooooo
ooooo`11ooooo`Co0000:?ooool4o`0000gooooo0_l00037ooooo`007_ooool00ol0003ooooooooo
o`0oooooo`;o00002_ooool3o`0001oooooo1Ol0000dooooo`;o0000Woooool001kooooo0_l0000F
ooooo`;o00001_ooool2o`00023ooooo0_l00008ooooo`Go00001?ooool2o`0001cooooo0_l00003
ooooo`;o0000;oooool2o`0003Wooooo0_l0001Tooooo`007_ooool00ol0003oooooooooo`0Eoooo
o`;o00001_ooool2o`0001?ooooo0_l00009ooooo`;o00002_ooool4o`0000Gooooo0_l0000:oooo
o`?o00005?ooool2o`0006[ooooo0_l0001Aooooo`;o00004Oooool001kooooo00?o0000oooooooo
ool06Oooool2o`0000Cooooo0_l00004ooooo`;o00002oooool2o`0000Gooooo0_l00002ooooo`;o
00003?ooool2o`000003ooooool0003o000000kooooo0ol0000Dooooo`;o0000_Oooool2o`00017o
oooo000Nooooo`03o`000?oooooooooo01Sooooo0ol00004ooooo`;o000000Coooooo`000?l0003o
oooo0_l000000ooooooo0000o`000007ooooo`?o00000oooool4o`0001?ooooo0_l0000jooooo`;o
00000_ooool2o`00083ooooo0_l0000Xooooo`;o00002oooool001kooooo00?o0000ooooooooool0
6?ooool2o`0000Sooooo0_l00004ooooo`;o00001oooool2o`0000Cooooo0_l0000;ooooo`;o0000
1Oooool2o`0002Kooooo0_l0000Eooooo`;o00000_ooool2o`00083ooooo0_l0000Xooooo`;o0000
2oooool001kooooo00?o0000ooooooooool0A?ooool2o`000003ooooool0003o000000;ooooo0ol0
000Uooooo`?o0000HOooool2o`0006kooooo000Nooooo`03o`000?oooooooooo00Cooooo1?l0000d
ooooo`;o00002Oooool2o`0000?ooooo1?l0000Tooooo`;o0000HOooool2o`0000;ooooo0_l0001Z
ooooo`007_ooool00ol0003oooooooooo`04ooooo`Co00002oooool2o`0002?ooooo0_l00002oooo
o`;o00003Oooool2o`000003ooooool0003o000004Gooooo0_l00014ooooo`;o0000J_ooool001ko
oooo00?o0000ooooooooool04oooool2o`0001Kooooo0_l0000;ooooo`;o00002_ooool2o`0000;o
oooo0_l000000ooooooo0000o`000006ooooo`?o00007oooool2o`0001kooooo0_l0000booooo`;o
0000O?ooool001kooooo00?o0000ooooooooool0:oooool2o`0001Oooooo0_l00002ooooo`;o0000
2?ooool4o`0001cooooo0_l000000ooooooo0000o`000002ooooo`;o0000??ooool2o`00013ooooo
0_l0000iooooo`;o0000@Oooool001kooooo00?o0000ooooooooool01_ooool2o`00047ooooo0_l0
0007ooooo`Co00001Oooool2o`0001Gooooo0_l00005ooooo`;o00005?ooool2o`0002Kooooo0_l0
000Kooooo`;o0000;_ooool2o`00047ooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l0000h
ooooo`So000000?oooooo`000?l000002Oooool2o`0000Gooooo0_l00003ooooo`;o0000;Oooool2
o`0004?ooooo0_l0001aooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o00005oooool2o`00
00kooooo2?l00004ooooo`;o00001?ooool4o`0000?ooooo1?l000000ooooooo0000o`000003o`00
027ooooo0_l00031ooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o00005oooool2o`0001?o
oooo0_l00005ooooo`;o000000Coooooo`000?l0003ooooo0_l00005ooooo`;o00000oooool2o`00
0004ooooool0003o0000ooooo`?o00007Oooool2o`0009?ooooo0_l0000/ooooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_oo
ool00ol0003oooooooooo`0gooooo`?o00001?ooool2o`0000oooooo0_l00004ooooo`;o00000ooo
ool2o`0000Oooooo1?l00003ooooo`;o0000[Oooool2o`0002cooooo0003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`00
0?oooooooooo02oooooo0_l00003ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`0000Co
oooo0_l0000?ooooo`;o00000_ooool3o`0000Oooooo1?l000000ooooooo0000o`000002o`000<go
oooo0_l0000<ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooo
ooooooooo`000006ooooo`?o0000;_ooool3o`0000;ooooo0ol00007ooooo`;o00001Oooool2o`00
0003ooooool0003o000000Sooooo0_l00006ooooo`?o00003?ooool2o`000003ooooool0003o0000
04cooooo0_l0001nooooo`;o00000oooool2o`0000Oooooo0003ooooo`05o`000?oooooooooooooo
ool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000ooooooooool02?ooool2
o`0002;ooooo1?l00003ooooo`?o00001Oooool4o`0000;ooooo0_l00004ooooo`?o00001oooool2
o`0000Kooooo0ol00003ooooo`;o00000oooool9o`0004cooooo0_l00023ooooo`;o00001oooool0
00?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_oo
ool00ol0003oooooooooo`08ooooo`;o00002_ooool2o`0001Gooooo1_l00003ooooo`;o00001Ooo
ool2o`0000Cooooo0_l00003ooooo`Go00001_ooool2o`0000;ooooo0_l00002ooooo`;o00001?oo
ool=o`000=_ooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooo
oonj^[[o410@00Kooooo0ol0000<ooooo`;o00001_ooool2o`0000Wooooo0_l00009ooooo`Oo0000
4?ooool2o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`;o00000_ooool2o`0000Oooooo
1_l00006ooooo`?o0000f_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l000001_ooool4o`0000_ooooo0_l00004ooooo`;o00002oooool2o`0000Wo
oooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00004?ooool2o`0001Wooooo0_l0000:oooo
o`?o0000/_ooool2o`0001?ooooo0_l0000Aooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`04o`000?oooooo0000o`00017ooooo0_l0
0005ooooo`;o00004oooool2o`000003ooooool0003o000000Cooooo0_l0000:ooooo`;o00001?oo
ool2o`0001Oooooo0_l00007ooooo`?o00001Oooool2o`000:[ooooo0_l0000Cooooo`;o00004Ooo
ool001kooooo1?l0000Hooooo`;o00004oooool2o`0000?ooooo0_l00002ooooo`;o00002oooool2
o`000003ooooool0003o000000;o00003?ooool2o`0000;ooooo0_l00005ooooo`;o00001Oooool2
o`000003ooooool0003o000000Gooooo0_l0001]ooooo`;o0000Hoooool001kooooo0ol0000/oooo
o`Co00000oooool2o`0000oooooo1Ol00002ooooo`;o00002_ooool2o`0000;ooooo0_l00005oooo
o`;o00001Oooool2o`0004[ooooo1?l0000Yooooo`;o0000A_ooool2o`0001_ooooo000Nooooo`03
o`000?oooooooooo02cooooo0ol00006ooooo`Co00001?ooool2o`0000Gooooo0ol00004ooooo`;o
00002Oooool2o`0000?ooooo0_l00008ooooo`;o0000C_ooool4o`0006kooooo0_l000000ooooooo
0000o`00000Kooooo`007_ooool00ol0003oooooooooo`0]ooooo`?o00001Oooool4o`0000Cooooo
3?l00002ooooo`;o00002Oooool2o`0000gooooo0_l00030ooooo`;o00002_ooool2o`0001;ooooo
000Nooooo`03o`000?oooooooooo00Wooooo0_l0000Sooooo`;o00001oooool2o`0000Gooooo3?l0
00000ooooooo0000o`00000Qooooo`;o0000[oooool2o`0001;ooooo0_l00008ooooo`;o00002?oo
ool001kooooo00?o0000ooooooooool02Oooool2o`0000Oooooo0_l0000Rooooo`;o00001_ooool4
o`000003ooooool0003o000000So00001?ooool2o`0000;ooooo0_l0000Gooooo`;o0000[oooool2
o`0001cooooo0_l00008ooooo`007_ooool00ol0003oooooooooo`03ooooo`;o00003?ooool3o`00
01[ooooo1Ol00003ooooo`;o00001_ooool4o`000005ooooool0003o0000o`000?ooool01ol00002
ooooo`?o00000_ooool2o`0000Gooooo0_l00008ooooo`;o00001?ooool2o`0000Cooooo0_l0003C
ooooo`007_ooool00ol0003oooooooooo`03ooooo`;o00003?ooool2o`0001_ooooo1Ol00002oooo
o`;o00001oooool2o`0000?ooooo0ol000001Ooooooo0000o`000?l0003ooooo00?o00000_ooool2
o`0000[ooooo0_l00002ooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`;o0000Y?ooool2
o`0002gooooo000Nooooo`03o`000?oooooooooo01cooooo0_l0000>ooooo`;o000000?oooooo`00
0?l000000_l00002ooooo`;o00003Oooool2o`0000Gooooo1ol00006ooooo`Ko00000_ooool2o`00
00cooooo0_l0002Rooooo`;o00001?ooool2o`0002gooooo000Nooooo`03o`000?oooooooooo01co
oooo0_l0000>ooooo`;o00000oooool2o`0001?ooooo0_l00004ooooo`Ko00000oooool2o`000003
ooooool0003o000000?o00001_ooool2o`0000Wooooo1?l00022ooooo`;o00003oooool4o`0000Wo
oooo0_l0000cooooo`007_ooool00ol0003oooooooooo`0[ooooo`;o00004?ooool2o`0000Cooooo
0_l000000ooooooo0000o`000005ooooo`Go00000oooool2o`0000[ooooo1?l0000:ooooo`?o0000
P_ooool2o`0000oooooo1?l0000Kooooo`;o00008Oooool001kooooo0_l0000/ooooo`;o00004?oo
ool3o`0000?ooooo0_l00008ooooo`Ko00002oooool2o`000004ooooool0003o0000ooooo`;o0000
2Oooool2o`0004Wooooo0_l0001Xooooo`;o00008Oooool001kooooo00?o0000ooooooooool06ooo
ool2o`00023ooooo0ol00008ooooo`?o00001?ooool6o`0000Wooooo0_l00004ooooo`;o0000:?oo
ool2o`0002[ooooo0_l0002;ooooo`007_ooool01?l0003oooooooooooooool2o`0001Sooooo0_l0
000Pooooo`;o00001Oooool2o`0000;ooooo0ol00003ooooo`;o00000_ooool3o`0003Wooooo0_l0
002Oooooo`;o00005_ooool001kooooo00Co0000oooooooooooooooo0_l0000<ooooo`;o00006ooo
ool2o`0000Wooooo0_l00007ooooo`;o00000_ooool2o`0000?ooooo0ol00002ooooo`;o00000ooo
ool3o`0001;ooooo0_l00003ooooo`;o00001Oooool2o`000;Wooooo0_l0000Fooooo`007_ooool0
0ol0003oooooooooo`0?ooooo`;o00006oooool2o`0000Wooooo0_l000000ooooooo0000o`000004
ooooo`;o00002?ooool2o`0000Oooooo1?l0000<ooooo`;o00000oooool2o`0000?ooooo0_l00005
ooooo`;o00007oooool2o`000;3ooooo000Nooooo`03o`000?oooooooooo03[ooooo0_l00004oooo
o`;o00001Oooool2o`0000[ooooo1?l00008ooooo`;o00000_ooool7o`0000;ooooo0_l00002oooo
o`;o00008oooool2o`00017ooooo0_l0002Mooooo`007_ooool00ol0003oooooooooo`10ooooo`Co
00000_ooool5o`0000Oooooo1Ol00008ooooo`Co00000_ooool5o`0000;ooooo0_l00002ooooo`;o
00004?ooool2o`0002Cooooo0_l0002Mooooo`007_ooool00ol0003oooooooooo`03ooooo`;o0000
9_ooool2o`0001;ooooo0_l000000ooooooo0000o`000002ooooo`;o000000Coooooo`000?l0003o
oooo0_l00004ooooo`Go00002_ooool4o`0000[ooooo0_l0000?ooooo`Co0000C?ooool2o`0007Go
oooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0000Vooooo`;o00004_ooool2o`0000Kooooo
0_l00003ooooo`;o000000?oooooo`000?l000001ol000001?oooooo0000o`000?ooool4o`0000?o
oooo0_l0000:ooooo`;o00003oooool2o`0004kooooo0_l0001eooooo`007_ooool00ol0003ooooo
ooooo`0Booooo`;o00004_ooool2o`0001oooooo0ol00005ooooo`co000000?oooooo`000?l00000
0_l0003Wooooo`007_ooool2o`0001?ooooo0_l0000Booooo`;o00008?ooool2o`0000Oooooo0_l0
0002ooooo`Go00005oooool2o`0000;ooooo0_l0003@ooooo`007_ooool2o`0005;ooooo0_l00003
ooooo`Ko00003?ooool4o`0000Gooooo1ol0003?ooooo`007_ooool00ol0003oooooooooo`14oooo
o`;o00001?ooool4o`0000?ooooo0ol00003ooooo`;o000000?oooooo`000?l000003?ooool4o`00
00Oooooo0_l000000ooooooo0000o`00001Zooooo`;o0000Hoooool001kooooo00?o0000oooooooo
ool0A?ooool2o`0000Cooooo1?l00002ooooo`Co00000oooool2o`000003ooooool0003o000000?o
00001Oooool2o`0007Gooooo0_l00005ooooo`;o0000Hoooool001kooooo00?o0000ooooooooool0
5_ooool2o`0003;ooooo0_l00002ooooo`Co000000?oooooo`000?l000000_l00005ooooo`?o0000
1Oooool2o`0007Gooooo0_l0001Hooooo`;o00004?ooool001kooooo00?o0000ooooooooool05_oo
ool2o`00013ooooo0_l0000Mooooo`;o00001Oooool4o`000003ooooool0003o000000Co00000ooo
ool6o`000003ooooool0003o000000Oooooo0_l0002Xooooo`;o00007Oooool2o`00013ooooo000N
ooooo`;o0000:Oooool2o`0000_ooooo0_l00008ooooo`;o00001_ooool2o`0000Cooooo1Ol00002
ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000003o`000004ooooool0
003o0000o`0000Kooooo0_l0000;ooooo`;o0000K_ooool2o`0002_ooooo0_l0000_ooooo`007_oo
ool00ol0003oooooooooo`0aooooo`Ko00001?ooool2o`0000;ooooo1?l00005ooooo`;o00000_oo
ool4o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o00002?ooool2o`0000[ooooo0_l0
00000ooooooo0000o`000002o`0000;ooooo0_l0000:ooooo`;o0000C_ooool2o`0001;ooooo0_l0
001Looooo`007_ooool00ol0003oooooooooo`0Booooo`;o00004oooool2o`0000Cooooo0_l00002
ooooo`Co00001_ooool2o`0000;ooooo1?l00005ooooo`;o00000_ooool4o`000003ooooool0003o
000000?ooooo0_l000000ooooooo0000o`000002o`0001?ooooo0_l000000ooooooo0000o`000002
o`0000kooooo0_l0000Jooooo`;o0000<_ooool2o`00073ooooo000Nooooo`;o00004oooool2o`00
017ooooo1?l00004ooooo`;o00001?ooool2o`0001Oooooo0_l0000;ooooo`Co000000Coooooo`00
0?l0003o00002Oooool2o`000003ooooool0003o000000?ooooo0_l0000@ooooo`;o00006oooool2
o`000:Cooooo000Nooooo`;o00009_ooool2o`0000cooooo0_l00008ooooo`;o00001?ooool3o`00
013ooooo0_l00002ooooo`;o00000_ooool3o`0000?ooooo0ol00003ooooo`Go00000oooool2o`00
013ooooo0_l0000Tooooo`;o0000Voooool001kooooo00?o0000ooooooooool05?ooool2o`0000oo
oooo0_l0000Fooooo`Co00000_ooool4o`0000_ooooo0_l00002ooooo`;o000000Coooooo`000?l0
003o00000_ooool4o`0000;ooooo1Ol00002ooooo`Co0000>_ooool3o`0009_ooooo000Nooooo`03
o`000?oooooooooo00Kooooo0_l0000<ooooo`;o00000oooool2o`0000Wooooo0ol0000Hooooo`;o
00000_ooool4o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o00000oooool5o`0000;o
oooo1?l00002ooooo`Go00001?ooool2o`0000kooooo0_l0000Zooooo`;o0000U?ooool2o`0000Ko
oooo000Nooooo`03o`000?oooooooooo00Kooooo0_l0000Aooooo`;o000000?oooooo`000?l00000
1_ooool2o`0000cooooo0_l0000?ooooo`?o00000_ooool2o`000005ooooool0003o0000o`000?oo
ool00_l00004ooooo`Oo00001oooool3o`0001Oooooo0_l0000mooooo`;o0000POooool2o`0000Ko
oooo000Nooooo`03o`000?oooooooooo01?ooooo0_l00007ooooo`;o00005?ooool2o`0000kooooo
0_l00007ooooo`;o00000_ooool2o`0000Cooooo1Ol00002ooooo`;o00001Oooool3o`0000Gooooo
0_l00005ooooo`;o0000B?ooool2o`0001?ooooo0_l0000nooooo`;o0000=?ooool001kooooo00?o
0000ooooooooool04oooool2o`0000Gooooo0_l0000Vooooo`;o00000_ooool2o`0000Oooooo1?l0
0002ooooo`;o000000?oooooo`000?l000001Ol00005ooooo`;o00001Oooool2o`0000;ooooo0_l0
00000ooooooo0000o`00000:ooooo`;o0000:Oooool2o`0002Kooooo0_l0000nooooo`;o0000=?oo
ool001kooooo00?o0000ooooooooool05oooool2o`000003ooooool0003o000000_ooooo0_l0000M
ooooo`?o00001_ooool4o`0000Gooooo2Ol00002ooooo`;o00002_ooool2o`0000Kooooo0ol00004
ooooo`;o00003Oooool2o`0001[ooooo0_l00014ooooo`;o0000E_ooool001kooooo00?o0000oooo
ooooool05oooool2o`0000kooooo0_l0000Aooooo`;o000000?oooooo`000?l000002?ooool2o`00
00Oooooo0_l00002ooooo`;o00001oooool4o`0000;ooooo0_l0000Aooooo`So00003oooool2o`00
063ooooo0_l0001=ooooo`;o00001oooool001kooooo00?o0000ooooooooool02_ooool2o`0000ko
oooo0_l0000<ooooo`;o00004?ooool2o`000004ooooool0003o0000o`00017ooooo0_l000000ooo
oooo0000o`000002o`000003ooooool0003o000000;ooooo0_l00002ooooo`Co00004Oooool2o`00
0003ooooool0003o000000?o0000`?ooool2o`0000Oooooo000Mooooo`;o00003?ooool2o`0000ko
oooo0_l0000<ooooo`;o00005?ooool2o`0000?ooooo1?l0000:ooooo`;o00000oooool2o`000003
ooooool0003o000000Kooooo1Ol0000@ooooo`?o00005?ooool2o`000;Sooooo000Mooooo`;o0000
?_ooool2o`0000Gooooo1?l0000:ooooo`Co00002Oooool3o`0000?ooooo0_l00002ooooo`?o0000
3?ooool2o`0001Cooooo0_l0002Fooooo`;o00000oooool2o`0001_ooooo000Nooooo`03o`000?oo
oooooooo03cooooo1Ol0000@ooooo`Co00001?ooool2o`0000?ooooo0ol00007ooooo`?o00000ooo
ool2o`0000Cooooo1?l0001Rooooo`;o00009Oooool2o`0002;ooooo0_l00003ooooo`;o00006ooo
ool001kooooo0_l0000Aooooo`;o0000:oooool4o`0001Sooooo0_l00004ooooo`;o00003Oooool2
o`0000Cooooo1?l0001Rooooo`;o00009Oooool2o`0004Cooooo000Nooooo`03o`000?oooooooooo
013ooooo0_l0000Eooooo`;o0000=Oooool2o`0000Sooooo0_l0000<ooooo`;o0000@oooool2o`00
08[ooooo000Nooooo`03o`000?oooooooooo00;o00000oooool2o`0000Oooooo0_l00004ooooo`;o
00004Oooool2o`0001_ooooo0_l0000Hooooo`;o00000oooool2o`0000?ooooo0_l0000:ooooo`;o
0000;_ooool2o`0001Gooooo0_l0002:ooooo`007_ooool00ol0003oooooooooo`02o`0000?ooooo
0_l00007ooooo`;o00001?ooool2o`0001gooooo0_l0000?ooooo`;o00007Oooool2o`0000oooooo
1?l0000/ooooo`;o0000XOooool001kooooo00?o0000ooooooooool0<oooool2o`0003Wooooo0_l0
0002ooooo`Ko0000aOooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l00017
ooooo`?o00000_ooool4o`000<Oooooo0_l00008ooooo`007_ooool00ol0003oooooooooo`0Toooo
o`;o0000;oooool2o`0000[ooooo0_l0000:ooooo`;o00000_ooool4o`0002;ooooo0_l0002^oooo
o`007_ooool00ol0003oooooooooo`0aooooo`;o00000oooool2o`0001cooooo0ol00007ooooo`;o
000000?oooooo`000?l000003_ooool2o`0001Oooooo0_l0000;ooooo`;o0000[_ooool001kooooo
00?o0000ooooooooool03Oooool2o`0002;ooooo0_l00003ooooo`;o00007?ooool2o`0000Sooooo
0_l0000Booooo`;o00005_ooool2o`000;_ooooo000Nooooo`03o`000?oooooooooo00gooooo0_l0
0015ooooo`;o00001oooool2o`0000gooooo0_l00004ooooo`;o0000doooool001kooooo00?o0000
ooooooooool06_ooool2o`0000cooooo0_l00007ooooo`;o0000:_ooool2o`0000gooooo0_l0000G
ooooo`;o00001_ooool2o`0005Gooooo0_l0000Eooooo`;o0000B_ooool001kooooo00?o0000oooo
ooooool06_ooool2o`0000cooooo0_l00007ooooo`;o0000<oooool2o`0001gooooo1Ol00003oooo
o`;o0000EOooool2o`0001;ooooo0_l000000ooooooo0000o`00000<ooooo`;o0000??ooool001ko
oooo00?o0000ooooooooool08?ooool2o`0004Cooooo0_l0000Oooooo`?o0000K_ooool2o`0000oo
oooo0_l0000Looooo`;o00007_ooool001kooooo00?o0000ooooooooool08?ooool2o`00043ooooo
0_l0002fooooo`;o00002oooool2o`0001kooooo000Dooooo`Co000000?o410@ooooooooool00ooo
ool00ol0003oooooooooo`1Rooooo`;o0000]_ooool2o`0002_ooooo000Fooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0=oooool2o`0001Wooooo0_l00003ooooo`;o0000k_ooool0
01Kooooo00?o0000ooooooooool01Oooool3o`0003Oooooo0_l0000Iooooo`;o00000oooool2o`00
0003ooooool0003o00000>_ooooo000Fooooo`03o`000?oooooooooo05oooooo0_l000000ooooooo
0000o`00003[ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oo
oooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005?ooool00omE
EEGoIVIVo`00003ooooooe;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.14077 .81384 Mdot
.44317 .80997 Mdot
.19009 .8585 Mdot
.18503 .88423 Mdot
.29735 .9664 Mdot
.22995 .85789 Mdot
.03558 .07564 Mdot
.31323 .92831 Mdot
.26356 .8477 Mdot
.23392 .92607 Mdot
.27071 .01935 Mdot
.17632 .02597 Mdot
.26142 .88519 Mdot
.11899 .87596 Mdot
.23676 .83542 Mdot
.35079 .79298 Mdot
.43754 .91754 Mdot
.20935 .85978 Mdot
.13128 .80118 Mdot
.19832 .86775 Mdot
.37139 .71451 Mdot
.30035 .79402 Mdot
.28486 .80586 Mdot
.56594 .76244 Mdot
.27524 .88253 Mdot
.35024 .91916 Mdot
.2625 .82867 Mdot
.31957 .06197 Mdot
.25699 .03688 Mdot
.24668 .76377 Mdot
.14601 .83158 Mdot
.24165 .84281 Mdot
.35532 .83694 Mdot
.48885 .65837 Mdot
.05451 .78204 Mdot
.26025 .97107 Mdot
.25921 .86923 Mdot
.73929 .05891 Mdot
.14375 .99006 Mdot
.25609 .8752 Mdot
.13897 .81331 Mdot
.00768 .93528 Mdot
.40826 .91675 Mdot
.58063 .43679 Mdot
.98755 .78276 Mdot
.03824 .93402 Mdot
.95212 .75574 Mdot
.23878 .69995 Mdot
.27375 .95558 Mdot
.19635 .1659 Mdot
.17792 .92499 Mdot
.1677 .72478 Mdot
.33307 .95212 Mdot
.28799 .04281 Mdot
.31663 .93595 Mdot
.37037 .15293 Mdot
.98639 .91399 Mdot
.28858 .92166 Mdot
.26303 .82438 Mdot
.27347 .78346 Mdot
.18402 .85633 Mdot
.32979 .91419 Mdot
.74352 .8994 Mdot
.30042 .89002 Mdot
.21037 .9377 Mdot
.27593 .82989 Mdot
.15367 .77421 Mdot
.26361 .82759 Mdot
.22882 .8468 Mdot
.62072 .93546 Mdot
.45168 .46326 Mdot
.35064 .06968 Mdot
.95113 .85575 Mdot
.22695 .37896 Mdot
.32717 .87678 Mdot
.97509 .95954 Mdot
.2638 .71808 Mdot
.11733 .83665 Mdot
.25196 .8281 Mdot
.50852 .90952 Mdot
.10853 .66933 Mdot
.21695 .00876 Mdot
.53906 .31797 Mdot
.32085 .91753 Mdot
.9801 .90447 Mdot
.73815 .53617 Mdot
.3202 .95996 Mdot
.23002 .84824 Mdot
.23232 .84523 Mdot
.42239 .95713 Mdot
.34049 .9158 Mdot
.71079 .59192 Mdot
.29505 .06892 Mdot
.28303 .67579 Mdot
.18457 .75269 Mdot
.17821 .63577 Mdot
.93303 .03468 Mdot
.03993 .7512 Mdot
.37249 .97799 Mdot
.37169 .05312 Mdot
.2948 .85998 Mdot
.14374 .85395 Mdot
.20364 .80795 Mdot
.38946 .95177 Mdot
.51884 .79753 Mdot
.2934 .81278 Mdot
.34911 .58852 Mdot
.34829 .68369 Mdot
.2705 .73453 Mdot
.12805 .48346 Mdot
.322 .87289 Mdot
.45633 .35676 Mdot
.31671 .62169 Mdot
.18416 .86583 Mdot
.9769 .67633 Mdot
.0235 .14348 Mdot
.17827 .78877 Mdot
.26239 .86051 Mdot
.36442 .08795 Mdot
.40545 .66983 Mdot
.26537 .83707 Mdot
.25312 .75271 Mdot
.34931 .78628 Mdot
.3922 .85843 Mdot
.06645 .9936 Mdot
.75592 .94755 Mdot
.32937 .94432 Mdot
.13814 .79704 Mdot
.44631 .61851 Mdot
.06534 .86631 Mdot
.67274 .82712 Mdot
.09139 .06135 Mdot
.1947 .5596 Mdot
.24044 .76667 Mdot
.16166 .7842 Mdot
.20766 .86845 Mdot
.29888 .82628 Mdot
.35873 .10873 Mdot
.12147 .85991 Mdot
.2508 .84611 Mdot
.13361 .80302 Mdot
.32477 .90553 Mdot
.32825 .7959 Mdot
.16835 .92854 Mdot
.72267 .67561 Mdot
.19689 .01154 Mdot
.17788 .76731 Mdot
.27197 .85479 Mdot
.97485 .00098 Mdot
.35022 .80115 Mdot
.33553 .8965 Mdot
.34312 .80087 Mdot
.16216 .00884 Mdot
.20504 .86306 Mdot
.24576 .82755 Mdot
.29571 .88028 Mdot
.30623 .11203 Mdot
.70539 .28105 Mdot
.24493 .85066 Mdot
.34333 .81884 Mdot
.33787 .14499 Mdot
.08711 .91201 Mdot
.97309 .74281 Mdot
.26484 .74215 Mdot
.35453 .98068 Mdot
.32178 .95131 Mdot
.26389 .86957 Mdot
.24051 .84243 Mdot
.90328 .5766 Mdot
.27949 .84446 Mdot
.33413 .77375 Mdot
.05684 .71085 Mdot
.05839 .86057 Mdot
.72885 .57654 Mdot
.15713 .80958 Mdot
.19798 .08913 Mdot
.47174 .65904 Mdot
.32819 .9269 Mdot
.9315 .04873 Mdot
.14395 .72902 Mdot
.38941 .97214 Mdot
.29072 .01626 Mdot
.15607 .84125 Mdot
.11559 .77819 Mdot
.34004 .18541 Mdot
.15973 .76928 Mdot
.31193 .94607 Mdot
.38365 .91501 Mdot
.04308 .6639 Mdot
.10369 .92362 Mdot
.15162 .80213 Mdot
.10776 .73788 Mdot
.13773 .80158 Mdot
.4826 .7197 Mdot
.36393 .62248 Mdot
.43184 .90708 Mdot
.09808 .89215 Mdot
.26456 .88501 Mdot
.27178 .8481 Mdot
.35346 .82373 Mdot
.90829 .08706 Mdot
.59185 .48351 Mdot
.21403 .75777 Mdot
.1393 .7609 Mdot
.27943 .88348 Mdot
.22545 .85242 Mdot
.53705 .03112 Mdot
.24313 .82684 Mdot
.98958 .59389 Mdot
.28408 .09819 Mdot
.2971 .89009 Mdot
.14032 .80629 Mdot
.1607 .63024 Mdot
.4561 .57117 Mdot
.35213 .13252 Mdot
.35282 .27184 Mdot
.24907 .88418 Mdot
.28737 .48506 Mdot
.21618 .11172 Mdot
.03248 .86949 Mdot
.83971 .17727 Mdot
.2233 .75617 Mdot
.35131 .92697 Mdot
.23587 .83946 Mdot
.3669 .90198 Mdot
.29648 .11639 Mdot
.06368 .92511 Mdot
.2584 .82875 Mdot
.20506 .41096 Mdot
.31529 .80311 Mdot
.33149 .88775 Mdot
.30012 .80759 Mdot
.34267 .79094 Mdot
.65295 .63882 Mdot
.38092 .2998 Mdot
.20798 .6308 Mdot
.72264 .839 Mdot
.18591 .8446 Mdot
.54343 .07758 Mdot
.81237 .25572 Mdot
.23618 .96531 Mdot
.33753 .78726 Mdot
.24998 .806 Mdot
.2266 .88225 Mdot
.11383 .95863 Mdot
.348 .67448 Mdot
.27534 .82109 Mdot
.31744 .76871 Mdot
.70289 .97517 Mdot
.14673 .80866 Mdot
.20778 .72622 Mdot
.32546 .91947 Mdot
.564 .2206 Mdot
.6552 .84176 Mdot
.87783 .91401 Mdot
.29687 .79029 Mdot
.33723 .95429 Mdot
.59559 .07809 Mdot
.08146 .75109 Mdot
.48241 .73213 Mdot
.1422 .80853 Mdot
.19486 .84207 Mdot
.26795 .31963 Mdot
.50935 .00086 Mdot
.3399 .79117 Mdot
.83173 .17628 Mdot
.21058 .6885 Mdot
.14129 .05517 Mdot
.21196 .84506 Mdot
.25915 .84939 Mdot
.36806 .97782 Mdot
.01407 .00561 Mdot
.19305 .82256 Mdot
.21545 .81829 Mdot
.05537 .685 Mdot
.31806 .89023 Mdot
.22849 .12543 Mdot
.13068 .85664 Mdot
.27658 .013 Mdot
.16752 .86436 Mdot
.96026 .90289 Mdot
.30635 .78457 Mdot
.27471 .73824 Mdot
.24149 .89581 Mdot
.32313 .96074 Mdot
.34594 .92369 Mdot
.25883 .83471 Mdot
.32589 .01593 Mdot
.33382 .85925 Mdot
.22117 .95466 Mdot
.30066 .86875 Mdot
.34626 .83274 Mdot
.12779 .79922 Mdot
.48034 .75122 Mdot
.8042 .6198 Mdot
.16621 .01648 Mdot
.22431 .91659 Mdot
.287 .00478 Mdot
.97064 .9423 Mdot
.82615 .57895 Mdot
.42454 .96951 Mdot
.41393 .94024 Mdot
.07722 .82901 Mdot
.28707 .8813 Mdot
.21528 .25838 Mdot
.35772 .76316 Mdot
.25957 .82894 Mdot
.25093 .81923 Mdot
.74107 .78458 Mdot
.56529 .50152 Mdot
.2539 .83045 Mdot
.98773 .9779 Mdot
.34979 .91029 Mdot
.18194 .81277 Mdot
.28146 .94674 Mdot
.30551 .00877 Mdot
.18476 .00444 Mdot
.58678 .74705 Mdot
.39693 .89474 Mdot
.72073 .34646 Mdot
.15321 .97884 Mdot
.35202 .81961 Mdot
.16378 .83311 Mdot
.20016 .92813 Mdot
.16072 .8453 Mdot
.32476 .88416 Mdot
.27414 .00522 Mdot
.14695 .80688 Mdot
.21464 .04142 Mdot
.33801 .89392 Mdot
.24752 .8766 Mdot
.2333 .85304 Mdot
.13605 .85705 Mdot
.47336 .82348 Mdot
.40124 .30721 Mdot
.21782 .38454 Mdot
.66411 .63844 Mdot
.26734 .83516 Mdot
.36577 .96274 Mdot
.66663 .54135 Mdot
.35522 .97062 Mdot
.43344 .68238 Mdot
.14126 .80395 Mdot
.30677 .96791 Mdot
.30856 .99973 Mdot
.07732 .02044 Mdot
.36083 .72471 Mdot
.03949 .41032 Mdot
.44143 .18293 Mdot
.30709 .93649 Mdot
.2357 .84673 Mdot
.33328 .94507 Mdot
.10513 .88478 Mdot
.34583 .95269 Mdot
.54749 .06781 Mdot
.18928 .83595 Mdot
.01716 .91178 Mdot
.25311 .70393 Mdot
.26068 .90737 Mdot
.20122 .56778 Mdot
.31639 .7778 Mdot
.06938 .94113 Mdot
.13817 .82161 Mdot
.30059 .87812 Mdot
.38551 .93093 Mdot
.07488 .76577 Mdot
.25516 .61125 Mdot
.075 .66221 Mdot
.25514 .99393 Mdot
.2401 .79729 Mdot
.37063 .13537 Mdot
.25288 .83289 Mdot
.18195 .8307 Mdot
.28256 .82709 Mdot
.21214 .82933 Mdot
.48129 .05831 Mdot
.93674 .77723 Mdot
.25631 .92007 Mdot
.76886 .04834 Mdot
.27918 .75795 Mdot
.24692 .83412 Mdot
.23271 .89864 Mdot
.32697 .65171 Mdot
.78159 .84575 Mdot
.27095 .07658 Mdot
.44974 .76138 Mdot
.39719 .70967 Mdot
.99654 .4813 Mdot
.26434 .83482 Mdot
.4672 .88037 Mdot
.13353 .80219 Mdot
.25456 .93481 Mdot
.27925 .86408 Mdot
.2738 .96271 Mdot
.2831 .96851 Mdot
.24904 .41038 Mdot
.37425 .9243 Mdot
.66559 .0935 Mdot
.26301 .82252 Mdot
.14419 .83253 Mdot
.41946 .882 Mdot
.02014 .74184 Mdot
.09605 .15412 Mdot
.3276 .91374 Mdot
.30761 .99108 Mdot
.44514 .60067 Mdot
.23581 .94574 Mdot
.40519 .0237 Mdot
.25541 .96232 Mdot
.26778 .74811 Mdot
.37478 .12186 Mdot
.25106 .85625 Mdot
.35193 .13727 Mdot
.66051 .88951 Mdot
.95146 .66553 Mdot
.23456 .82492 Mdot
.26937 .75454 Mdot
.30319 .11472 Mdot
.0866 .01004 Mdot
.25367 .82469 Mdot
.2493 .85293 Mdot
.66435 .85742 Mdot
.39167 .94307 Mdot
.25231 .90643 Mdot
.30196 .91871 Mdot
.70437 .65312 Mdot
.96565 .16881 Mdot
.27947 .82965 Mdot
.34168 .05735 Mdot
.93085 .55371 Mdot
.58373 .43919 Mdot
.25169 .73102 Mdot
.0678 .0488 Mdot
.25104 .8888 Mdot
.72412 .11083 Mdot
.07007 .0164 Mdot
.23964 .11131 Mdot
.25553 .74781 Mdot
.27164 .74048 Mdot
.96024 .80682 Mdot
.22751 .69853 Mdot
.53946 .51147 Mdot
.49213 .48941 Mdot
.19208 .84066 Mdot
.22798 .5699 Mdot
.22278 .83099 Mdot
.36226 .84457 Mdot
.28096 .94065 Mdot
.60332 .25812 Mdot
.24193 .69504 Mdot
.4731 .07339 Mdot
.29499 .7591 Mdot
.34746 .95777 Mdot
.24181 .83585 Mdot
.19137 .93373 Mdot
.25625 .82673 Mdot
.26444 .86471 Mdot
.27659 .01584 Mdot
.44221 .57956 Mdot
.09851 .83475 Mdot
.17927 .93724 Mdot
.22705 .83934 Mdot
.24008 .84317 Mdot
.27778 .90283 Mdot
.61338 .9001 Mdot
.03523 .75755 Mdot
.35404 .83109 Mdot
.68593 .96467 Mdot
.20794 .83001 Mdot
.06428 .74598 Mdot
.24851 .78606 Mdot
.32334 .94759 Mdot
.31879 .92212 Mdot
.31968 .91992 Mdot
.19876 .9252 Mdot
.24686 .84072 Mdot
.25453 .96364 Mdot
.31136 .91337 Mdot
.35208 .0328 Mdot
.39459 .91006 Mdot
.21411 .66848 Mdot
.48442 .69704 Mdot
.3243 .78908 Mdot
.1322 .8036 Mdot
.14398 .80776 Mdot
.56309 .07023 Mdot
.5739 .26174 Mdot
.20955 .72847 Mdot
.04172 .78173 Mdot
.35428 .05307 Mdot
.18395 .82327 Mdot
.24402 .84838 Mdot
.21765 .17085 Mdot
.36623 .73611 Mdot
.29436 .89554 Mdot
.26864 .86647 Mdot
.41582 .80639 Mdot
.36563 .88143 Mdot
.68032 .83445 Mdot
.20429 .01288 Mdot
.39347 .75094 Mdot
.09247 .8956 Mdot
.07002 .69423 Mdot
.29542 .51454 Mdot
.23533 .85663 Mdot
.03819 .03242 Mdot
.32956 .93494 Mdot
.36656 .04108 Mdot
.25996 .86279 Mdot
.21889 .77381 Mdot
.14211 .79476 Mdot
.24309 .74516 Mdot
.26364 .12422 Mdot
.42254 .15447 Mdot
.30411 .96919 Mdot
.74105 .65596 Mdot
.30285 .03732 Mdot
.17828 .62657 Mdot
.998 .45925 Mdot
.14446 .83372 Mdot
.23238 .69948 Mdot
.22178 .91522 Mdot
.24889 .83121 Mdot
.34635 .81203 Mdot
.37562 .00702 Mdot
.79475 .05704 Mdot
.10539 .60945 Mdot
.30932 .40949 Mdot
.21975 .87142 Mdot
.42155 .56721 Mdot
.76377 .58157 Mdot
.72333 .58048 Mdot
.3154 .96521 Mdot
.17357 .97765 Mdot
.32155 .91202 Mdot
.29621 .84875 Mdot
.21807 .93942 Mdot
.35432 .87337 Mdot
.7363 .11601 Mdot
.94151 .63668 Mdot
.25025 .84663 Mdot
.72202 .77534 Mdot
.22103 .00752 Mdot
.24878 .83266 Mdot
.13604 .84274 Mdot
.91928 .9712 Mdot
.56917 .24654 Mdot
.14711 .75998 Mdot
.27861 .76673 Mdot
.32362 .8853 Mdot
.55892 .9697 Mdot
.88834 .96395 Mdot
.35146 .84789 Mdot
.57404 .71732 Mdot
.18377 .72422 Mdot
.78916 .13094 Mdot
.20623 .70712 Mdot
.27146 .83776 Mdot
.26768 .96912 Mdot
.81579 .69189 Mdot
.27934 .78009 Mdot
.39635 .92751 Mdot
.76091 .08843 Mdot
.33978 .09178 Mdot
.25092 .8397 Mdot
.27564 .98192 Mdot
.32134 .13094 Mdot
.35532 .94247 Mdot
.15652 .09374 Mdot
.23208 .84804 Mdot
.01709 .83751 Mdot
.37814 .96965 Mdot
.24381 .84626 Mdot
.16072 .79601 Mdot
.25465 .9303 Mdot
.30636 .81767 Mdot
.23472 .71605 Mdot
.26052 .03706 Mdot
.31949 .9099 Mdot
.41143 .73281 Mdot
.39512 .10867 Mdot
.8898 .81972 Mdot
.20268 .95802 Mdot
.12719 .8061 Mdot
.58807 .15679 Mdot
.23225 .89232 Mdot
.18225 .74173 Mdot
.22912 .06421 Mdot
.42144 .86277 Mdot
.20387 .74399 Mdot
.30677 .91342 Mdot
.29564 .94468 Mdot
.28263 .96496 Mdot
.36026 .84769 Mdot
.15628 .98917 Mdot
.34837 .90093 Mdot
.2239 .09825 Mdot
.32643 .88939 Mdot
.24482 .92828 Mdot
.25854 .6879 Mdot
.32373 .80532 Mdot
.24704 .84175 Mdot
.19381 .82806 Mdot
.03785 .75393 Mdot
.87872 .68249 Mdot
.26897 .73512 Mdot
.26285 .85276 Mdot
.29363 .77472 Mdot
.80578 .80228 Mdot
.14074 .80735 Mdot
.87782 .84517 Mdot
.70726 .80671 Mdot
.21654 .81623 Mdot
.89319 .57393 Mdot
.12516 .81629 Mdot
.31616 .8372 Mdot
.35428 .08767 Mdot
.56108 .05531 Mdot
.39421 .96652 Mdot
.97392 .0869 Mdot
.13624 .92861 Mdot
.06786 .87424 Mdot
.14297 .80261 Mdot
.69106 .03988 Mdot
.97296 .78521 Mdot
.26773 .67676 Mdot
.49127 .18263 Mdot
.74619 .41862 Mdot
.29149 .88899 Mdot
.07203 .86343 Mdot
.14872 .90426 Mdot
.23849 .84019 Mdot
.22132 .75089 Mdot
.95669 .94304 Mdot
.24178 .8492 Mdot
.33498 .86512 Mdot
.31937 .91868 Mdot
.32725 .89733 Mdot
.26357 .95068 Mdot
.23034 .83584 Mdot
.35906 .89078 Mdot
.23144 .85356 Mdot
.01719 .90036 Mdot
.05763 .90048 Mdot
.93262 .63827 Mdot
.18332 .72195 Mdot
.26591 .96044 Mdot
.0774 .88812 Mdot
.32759 .90345 Mdot
.81639 .80064 Mdot
.55201 .83667 Mdot
.34204 .94979 Mdot
.18765 .66467 Mdot
.23409 .84163 Mdot
.54367 .19887 Mdot
.25642 .87212 Mdot
.31511 .95766 Mdot
.0723 .93597 Mdot
.03605 .63374 Mdot
.26011 .82399 Mdot
.93375 .79308 Mdot
.30086 .77184 Mdot
.0561 .90422 Mdot
.26943 .86337 Mdot
.92512 .00156 Mdot
.48059 .57078 Mdot
.25356 .82107 Mdot
.46392 .9936 Mdot
.39799 .05822 Mdot
.287 .61297 Mdot
.26349 .85448 Mdot
.19002 .14063 Mdot
.43431 .71731 Mdot
.28186 .75669 Mdot
.17966 .77159 Mdot
.34146 .91218 Mdot
.30727 .77016 Mdot
.25311 .92138 Mdot
.31668 .70265 Mdot
.01169 .69931 Mdot
.64843 .37 Mdot
.21373 .94815 Mdot
.24158 .80551 Mdot
.14164 .79535 Mdot
.23287 .84879 Mdot
.07072 .95457 Mdot
.17605 .91111 Mdot
.23104 .65393 Mdot
.42468 .79497 Mdot
.21115 .88634 Mdot
.28112 .71794 Mdot
.07609 .76617 Mdot
.18601 .43238 Mdot
.01269 .92279 Mdot
.33936 .80606 Mdot
.29817 .75083 Mdot
.23819 .84165 Mdot
.73229 .69789 Mdot
.91255 .97755 Mdot
.42846 .04121 Mdot
.22225 .43748 Mdot
.33862 .93119 Mdot
.28705 .8742 Mdot
.11605 .85401 Mdot
.5139 .20605 Mdot
.35622 .79592 Mdot
.08606 .26643 Mdot
.51418 .86532 Mdot
.18784 .43517 Mdot
.29529 .84395 Mdot
.35512 .95462 Mdot
.37793 .02652 Mdot
.10129 .73124 Mdot
.77568 .24739 Mdot
.2811 .83962 Mdot
.2498 .0871 Mdot
.31992 .77666 Mdot
.28369 .96206 Mdot
.66281 .24722 Mdot
.3346 .77696 Mdot
.14475 .80694 Mdot
.86998 .93921 Mdot
.23097 .70878 Mdot
.53785 .01183 Mdot
.60428 .89324 Mdot
.58823 .98705 Mdot
.17494 .89833 Mdot
.2715 .84456 Mdot
.9613 .88371 Mdot
.08749 .89356 Mdot
.31588 .77299 Mdot
.31486 .76024 Mdot
.28344 .86642 Mdot
.24992 .84612 Mdot
.54747 .25892 Mdot
.17969 .69129 Mdot
.50979 .15633 Mdot
.19975 .67084 Mdot
.23258 .9904 Mdot
.43953 .45712 Mdot
.33099 .89396 Mdot
.19631 .88728 Mdot
.15541 .8128 Mdot
.37372 .03285 Mdot
.75849 .65892 Mdot
.31552 .94782 Mdot
.27155 .75833 Mdot
.97016 .89151 Mdot
.40378 .93497 Mdot
.28307 .05076 Mdot
.27823 .84135 Mdot
.17043 .84856 Mdot
.41793 .74075 Mdot
.14534 .83157 Mdot
.19919 .71807 Mdot
.36592 .9643 Mdot
.26698 .88496 Mdot
.04405 .69735 Mdot
.26934 .96658 Mdot
.17395 .82494 Mdot
.72208 .92492 Mdot
.31352 .93012 Mdot
.1265 .28821 Mdot
.1757 .8627 Mdot
.22908 .8601 Mdot
.1754 .85738 Mdot
.38345 .03956 Mdot
.16101 .90959 Mdot
.26719 .88573 Mdot
.13951 .13302 Mdot
.29723 .91684 Mdot
.21496 .92939 Mdot
.28928 .79037 Mdot
.3255 .91952 Mdot
.3851 .93348 Mdot
.12501 .81134 Mdot
.41312 .91535 Mdot
.1855 .82522 Mdot
.19585 .92948 Mdot
.1786 .75816 Mdot
.18807 .88665 Mdot
.28549 .66233 Mdot
.38188 .44832 Mdot
.4206 .61227 Mdot
.22469 .92786 Mdot
.28282 .1099 Mdot
.34265 .94348 Mdot
.24842 .84751 Mdot
.24315 .84623 Mdot
.30351 .87667 Mdot
.15117 .06053 Mdot
.23561 .04375 Mdot
.22404 .12076 Mdot
.34551 .93096 Mdot
.10459 .00325 Mdot
.31798 .95503 Mdot
.35964 .02579 Mdot
.99586 .84997 Mdot
.23502 .92602 Mdot
.33617 .9292 Mdot
.58295 .73621 Mdot
.27834 .76526 Mdot
.20717 .96058 Mdot
.3723 .6289 Mdot
.3538 .91358 Mdot
.21444 .82697 Mdot
.02384 .54907 Mdot
.20646 .50142 Mdot
.17944 .99597 Mdot
.21539 .69485 Mdot
.41764 .05343 Mdot
.24664 .93842 Mdot
.2332 .90718 Mdot
.22335 .5572 Mdot
.3875 .91549 Mdot
.24761 .83461 Mdot
.16725 .83407 Mdot
.94405 .98865 Mdot
.23269 .82978 Mdot
.30765 .0187 Mdot
.31969 .9174 Mdot
.32104 .90021 Mdot
.4265 .92956 Mdot
.29446 .88356 Mdot
.3087 .95341 Mdot
.34071 .11708 Mdot
.33988 .9513 Mdot
.37684 .9729 Mdot
.44176 .01055 Mdot
.25941 .68783 Mdot
.30383 .77251 Mdot
.23998 .01397 Mdot
.25175 .91675 Mdot
.36506 .03583 Mdot
.12788 .90287 Mdot
.27659 .77703 Mdot
.23047 .67338 Mdot
.27335 .95242 Mdot
.39884 .91688 Mdot
.52631 .28413 Mdot
.09514 .59123 Mdot
.32276 .89431 Mdot
.26058 .8266 Mdot
.25944 .84235 Mdot
.95242 .94722 Mdot
.92631 .82928 Mdot
.69139 .99904 Mdot
.23692 .84476 Mdot
.34548 .90529 Mdot
.16624 .84717 Mdot
.75872 .12024 Mdot
.39479 .97732 Mdot
.13384 .80683 Mdot
.22862 .7015 Mdot
.26693 .85979 Mdot
.87646 .9227 Mdot
.31659 .92427 Mdot
.24183 .88627 Mdot
.40751 .90273 Mdot
.22243 .8828 Mdot
.32624 .90175 Mdot
.18003 .87007 Mdot
.3017 .83612 Mdot
.50949 .23066 Mdot
.35307 .90751 Mdot
.30025 .98572 Mdot
.13422 .80177 Mdot
.23802 .0794 Mdot
.64635 .86997 Mdot
.30739 .90093 Mdot
.48537 .88557 Mdot
.26669 .84551 Mdot
.29791 .89877 Mdot
.21401 .96305 Mdot
.05998 .71202 Mdot
.30343 .96553 Mdot
.12424 .96272 Mdot
.24259 .21239 Mdot
.98427 .68564 Mdot
.1666 .74413 Mdot
.69692 .87692 Mdot
.18229 .81254 Mdot
.31689 .92602 Mdot
.26873 .96167 Mdot
.40088 .76822 Mdot
.14412 .81155 Mdot
.13791 .83228 Mdot
.22618 .84537 Mdot
.30346 .7913 Mdot
.6565 .76168 Mdot
.37909 .00369 Mdot
.1745 .03034 Mdot
.36624 .78594 Mdot
.31355 .78392 Mdot
.31571 .05221 Mdot
.23299 .91412 Mdot
.77424 .09145 Mdot
.21079 .82674 Mdot
.18352 .89909 Mdot
.41372 .91856 Mdot
.16052 .75661 Mdot
.15845 .74327 Mdot
.78282 .00689 Mdot
.27986 .75273 Mdot
.6083 .03601 Mdot
.99066 .87639 Mdot
.38097 .60979 Mdot
.24176 .72931 Mdot
.12293 .7987 Mdot
.14507 .79791 Mdot
.16259 .91194 Mdot
.47827 .72015 Mdot
.44333 .1963 Mdot
.33239 .85519 Mdot
.25246 .93304 Mdot
.21239 .44263 Mdot
.05383 .93844 Mdot
.19519 .9267 Mdot
.1515 .60843 Mdot
.26721 .83765 Mdot
.27914 .73381 Mdot
.24631 .44012 Mdot
.15011 .74518 Mdot
.32772 .90365 Mdot
.2374 .83896 Mdot
.55297 .09624 Mdot
.24829 .1637 Mdot
.20079 .92392 Mdot
.54474 .70784 Mdot
.01297 .63172 Mdot
.33246 .79818 Mdot
.303 .8396 Mdot
.31136 .9048 Mdot
.34025 .79142 Mdot
.05893 .72399 Mdot
.1353 .80049 Mdot
.37045 .60749 Mdot
.31883 .76392 Mdot
.25489 .82047 Mdot
.46334 .95784 Mdot
.29326 .89692 Mdot
.11929 .81788 Mdot
.27368 .88709 Mdot
.04561 .02535 Mdot
.3911 .77002 Mdot
.23292 .85544 Mdot
.04836 .77592 Mdot
.08801 .86028 Mdot
.24656 .84835 Mdot
.14038 .67269 Mdot
.2153 .82573 Mdot
.12889 .92585 Mdot
.15221 .83458 Mdot
.42113 .32547 Mdot
.38791 .751 Mdot
.23509 .85218 Mdot
.19076 .89777 Mdot
.38051 .93639 Mdot
.73691 .935 Mdot
.73778 .16056 Mdot
.29502 .78518 Mdot
.24067 .83502 Mdot
.23126 .83096 Mdot
.39401 .91838 Mdot
.32914 .8895 Mdot
.34013 .91693 Mdot
.33239 .10993 Mdot
.29146 .13007 Mdot
.48523 .99554 Mdot
.6914 .52614 Mdot
.36459 .3638 Mdot
.47034 .77869 Mdot
.54607 .80148 Mdot
.23147 .07371 Mdot
.7667 .07786 Mdot
.32502 .92932 Mdot
.29242 .99933 Mdot
.86735 .46129 Mdot
.258 .82439 Mdot
.27201 .83996 Mdot
.2755 .95377 Mdot
.21748 .75684 Mdot
.29604 .84557 Mdot
.31217 .96015 Mdot
.26735 .75832 Mdot
.269 .75822 Mdot
.28628 .84802 Mdot
.83881 .51522 Mdot
.07466 .72619 Mdot
.27417 .83623 Mdot
.651 .23257 Mdot
.1915 .8906 Mdot
.15527 .99895 Mdot
.18235 .63448 Mdot
.40428 .93136 Mdot
.27237 .8523 Mdot
.27768 .86125 Mdot
.15581 .115 Mdot
.27526 .11649 Mdot
.32953 .77903 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool3o`0000gooooo00?o0000ooooooooool02?ooool2o`0000Co
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool01_ooool2o`0000Kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`04o`000?oooooo0000o`0000cooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`;o00001oooool00ol0
003oooooooooo`02ooooo`007_ooool00ol0003oooooooooo`02o`0000_ooooo00?o0000oooooooo
ool03Oooool3o`0000gooooo00?o0000ooooooooool02?ooool2o`0000Cooooo00?o0000oooooooo
ool00oooool2o`0000Sooooo00?o0000ooooooooool01?ooool2o`0000;ooooo0_l00003ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool3o`0000Kooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`07ooooo`;o00001Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003oooooooooo`02o`0001Kooooo
0_l0000Gooooo`;o00003oooool4o`0000oooooo0_l00002ooooo`;o00001?ooool2o`0001Gooooo
0_l0000Dooooo`;o0000K?ooool2o`0004_ooooo000Nooooo`03o`000?oooooooooo01Sooooo0_l0
000Gooooo`;o00002Oooool4o`0000;ooooo0_l0000Booooo`;o00001oooool2o`0002_ooooo0_l0
000Mooooo`;o0000V_ooool001kooooo00?o0000ooooooooool04oooool2o`0001gooooo0_l00008
ooooo`Co00002_ooool2o`0000[ooooo0_l00002ooooo`;o00002_ooool2o`0004?ooooo0_l0002J
ooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o00007Oooool2o`0001Kooooo0_l00008oooo
o`Co00000_ooool2o`0000Cooooo0_l00004ooooo`;o0000goooool001kooooo00?o0000oooooooo
ool05Oooool2o`0003gooooo0_l0000:ooooo`;o0000iOooool001kooooo00?o0000ooooooooool0
2oooool2o`0000Sooooo0_l0000Nooooo`;o0000>_ooool2o`0000gooooo0_l00035ooooo`007_oo
ool00ol0003oooooooooo`0;ooooo`;o0000:?ooool2o`0003[ooooo0_l00004ooooo`;o00001ooo
ool2o`000<Gooooo000Nooooo`03o`000?oooooooooo03Gooooo0_l00010ooooo`;o0000<Oooool2
o`0009_ooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0000[ooooo`;o0000=oooool2o`00
00Gooooo0_l0000cooooo`;o0000Ooooool2o`0001[ooooo000Nooooo`03o`000?oooooooooo00So
oooo0_l00015ooooo`Co00002oooool2o`0000kooooo0_l00003ooooo`Co0000Boooool2o`0006Oo
oooo0_l0000Jooooo`007_ooool00ol0003oooooooooo`12ooooo`;o00002oooool4o`0000_ooooo
0_l0000Cooooo`;o00001?ooool2o`0000cooooo0_l0000iooooo`;o00006Oooool2o`0006Sooooo
000Nooooo`03o`000?oooooooooo04;ooooo0_l00004ooooo`;o00004?ooool2o`0001Oooooo0_l0
0004ooooo`;o00003?ooool2o`0005Cooooo0_l0001Xooooo`007_ooool00ol0003oooooooooo`18
ooooo`;o00004?ooool2o`000>_ooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0003Roooo
o`;o0000<oooool2o`0001[ooooo000Nooooo`;o00004oooool2o`0004Cooooo0_l00009ooooo`;o
00002_ooool2o`0000Cooooo0_l0000=ooooo`;o0000L?ooool2o`0003?ooooo0_l0000Jooooo`00
7_ooool00ol0003oooooooooo`0Zooooo`;o0000;?ooool2o`0000Wooooo0_l0000:ooooo`;o0000
1?ooool2o`0000gooooo0_l0000/ooooo`;o0000Toooool001kooooo00?o0000ooooooooool0:_oo
ool2o`0003oooooo0_l0000@ooooo`;o00006Oooool2o`0001Sooooo0_l0000hooooo`;o00004?oo
ool2o`0004Oooooo000Nooooo`03o`000?oooooooooo01[ooooo0_l0000Aooooo`;o0000=Oooool2
o`0000Gooooo0_l0000@ooooo`;o00006Oooool2o`0005;ooooo0_l0000@ooooo`;o0000Aoooool0
01kooooo00?o0000ooooooooool06_ooool2o`00017ooooo0_l0000Gooooo`;o00007?ooool2o`00
0>7ooooo000Nooooo`03o`000?oooooooooo04Kooooo0_l0000Dooooo`;o0000D?ooool2o`0009Oo
oooo000Nooooo`03o`000?oooooooooo05cooooo0_l0000@ooooo`;o0000?_ooool2o`0000?ooooo
0_l0002Booooo`007_ooool00ol0003oooooooooo`17ooooo`;o00009Oooool2o`0002Kooooo0_l0
000Kooooo`;o0000T_ooool001kooooo00?o0000ooooooooool01oooool2o`0003kooooo0_l0000;
ooooo`;o0000@?ooool2o`0001Gooooo0_l0000?ooooo`;o0000=Oooool2o`00053ooooo000Noooo
o`03o`000?oooooooooo00Oooooo0_l00010ooooo`;o00002Oooool2o`0005Oooooo0_l0000?oooo
o`;o0000=Oooool2o`00053ooooo000Nooooo`03o`000?oooooooooo04Wooooo0_l0003looooo`00
7_ooool00ol0003oooooooooo`1=ooooo`;o0000e?ooool2o`0001Cooooo0_l0000<ooooo`007_oo
ool00ol0003oooooooooo`0looooo`;o00003oooool2o`00023ooooo0_l000000ooooooo0000o`00
001oooooo`;o0000;_ooool2o`0001Cooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`0l
ooooo`;o0000;?ooool2o`0000?ooooo0_l000000ooooooo0000o`00001Pooooo`;o00007Oooool2
o`0000?ooooo0_l0001=ooooo`007_ooool00ol0003oooooooooo`0_ooooo`;o0000>Oooool2o`00
04Cooooo0_l0000Rooooo`;o00008_ooool2o`0004gooooo000Nooooo`03o`000?oooooooooo02oo
oooo0_l0000Dooooo`;o00004Oooool2o`0005Kooooo0_l0002Eooooo`007_ooool2o`0004Kooooo
0_l0000Aooooo`;o0000kOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`1aooooo`;o00002Oooool2o`000<Wooooo000Nooooo`03o`000?oooooooooo
04;ooooo0_l00006ooooo`;o00003?ooool2o`0000Gooooo0_l00007ooooo`;o00001oooool2o`00
00Wooooo0_l0001Yooooo`;o0000G_ooool001kooooo00?o0000ooooooooool0;oooool2o`00017o
oooo0_l00006ooooo`;o00003?ooool2o`0000Cooooo0ol00007ooooo`;o0000OOooool2o`0005ko
oooo000Nooooo`03o`000?oooooooooo02oooooo0_l0000Tooooo`;o00001Oooool4o`0000_ooooo
0_l0001nooooo`;o0000F_ooool001kooooo00?o0000ooooooooool0AOooool2o`0000kooooo0_l0
0005ooooo`;o00003Oooool2o`0007kooooo0_l00006ooooo`;o0000D_ooool001kooooo00?o0000
ooooooooool0AOooool2o`0000_ooooo0_l0000Rooooo`;o0000Noooool2o`0005;ooooo000Noooo
o`03o`000?oooooooooo04Kooooo0_l0000:ooooo`;o00008_ooool2o`000<oooooo000Nooooo`03
o`000?oooooooooo04Kooooo0_l0000Cooooo`;o0000j_ooool001kooooo00?o0000ooooooooool0
:Oooool2o`00033ooooo0_l00007ooooo`;o00002?ooool2o`0008cooooo0_l00019ooooo`007_oo
ool00ol0003oooooooooo`0Yooooo`;o0000>Oooool2o`0000Sooooo0_l00004ooooo`;o0000Q_oo
ool2o`0004Wooooo000Nooooo`03o`000?oooooooooo06kooooo0_l00004ooooo`;o0000dOooool0
01kooooo00?o0000ooooooooool0>_ooool2o`0003;ooooo0_l0003Gooooo`007_ooool00ol0003o
ooooooooo`04ooooo`;o0000=?ooool2o`0002kooooo0_l0003Kooooo`007_ooool00ol0003ooooo
ooooo`04ooooo`;o0000I?ooool2o`000=_ooooo000Nooooo`;o0000oooooom9ooooo`007_ooool0
0ol0003oooooooooo`0Kooooo`;o0000Eoooool2o`0000oooooo0_l00030ooooo`007_ooool00ol0
003oooooooooo`0Kooooo`;o0000Eoooool2o`0000oooooo0_l0000Kooooo`;o00005oooool2o`00
08[ooooo000Nooooo`03o`000?oooooooooo0:;ooooo0_l0000Gooooo`;o0000;oooool2o`0005Wo
oooo000Nooooo`03o`000?oooooooooo04gooooo0_l0002Mooooo`;o0000FOooool001kooooo00?o
0000ooooooooool0??ooool2o`0000oooooo0_l0003hooooo`007_ooool00ol0003oooooooooo`0l
ooooo`;o0000n?ooool2o`0000oooooo000Nooooo`03o`000?oooooooooo04?ooooo0_l0003aoooo
o`;o00003oooool001kooooo00?o0000ooooooooool0@oooool2o`000<Gooooo0_l0000kooooo`00
7_ooool00ol0003oooooooooo`3oooooo`_ooooo0_l000000ooooooo0000o`00000hooooo`007_oo
ool00ol0003oooooooooo`2Looooo`;o0000Koooool2o`0003Sooooo000Nooooo`03o`000?oooooo
oooo06[ooooo0_l0000Oooooo`;o00003oooool2o`000:Wooooo000Nooooo`03o`000?oooooooooo
06[ooooo0_l0000Oooooo`;o0000^_ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo08cooooo0_l0002ioooo
o`000oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool3o`00
08cooooo0_l0000Oooooo`;o0000V?ooool000?ooooo00Go0000ooooooooooooooooo`00000=oooo
o`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0[Oooool2o`0009Sooooo0003ooooo`05
o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo
0:?ooooo0_l0002Rooooo`000oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`2Sooooo`;o0000X_ooool000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`1;
ooooo`;o0000n_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1;ooooo`;o0000n_ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`2cooooo`;o0000T_ooool001ko
oooo00?o0000ooooooooool0/oooool2o`0009;ooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0X_ooool2o`000:?ooooo000Nooooo`03o`000?oooooo
oooo0:;ooooo0_l0000/ooooo`;o0000MOooool001kooooo00?o0000ooooooooool0d?ooool2o`00
07Gooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`2eooooo`;o00007?ooool2o`0002?ooooo0_l0
001=ooooo`007_ooool00ol0003oooooooooo`2eooooo`;o00007?ooool2o`0002?ooooo0_l0001=
ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0ooooool5ooooo`;o
0000@Oooool001kooooo00?o0000ooooooooool0@_ooool2o`0006[ooooo0_l0000@ooooo`;o0000
@_ooool2o`00047ooooo000Nooooo`03o`000?oooooooooo04;ooooo0_l0001Zooooo`;o00001_oo
ool2o`0000Sooooo0_l00025ooooo`007_ooool00ol0003oooooooooo`2fooooo`;o0000Soooool0
01kooooo00?o0000ooooooooool06?ooool2o`000?oooooo;_ooool001kooooo00?o0000oooooooo
ool06?ooool2o`0005Gooooo0_l0003Fooooo`007_ooool00ol0003oooooooooo`1_ooooo`;o0000
e_ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3Q
ooooo`;o0000I?ooool001kooooo00?o0000ooooooooool0Yoooool2o`0003Sooooo0_l0001Toooo
o`007_ooool00ol0003oooooooooo`2Wooooo`;o0000W_ooool001kooooo00?o0000ooooooooool0
9Oooool2o`000?oooooo8Oooool001kooooo00?o0000ooooooooool09Oooool2o`000?oooooo8Ooo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`;o0000NOooool2o`000<gooooo000Nooooo`03o`000?oooooooooo07Sooooo
0_l0003=ooooo`007_ooool00ol0003oooooooooo`1nooooo`;o0000aoooool001kooooo00?o0000
ooooooooool0O_ooool2o`000<Oooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0Zoooool2o`0009[ooooo000Nooooo`03o`000?oooooooooo05?ooooo
0_l0001Fooooo`;o0000V_ooool001kooooo00?o0000ooooooooool0Doooool2o`000?;ooooo000N
ooooo`03o`000?oooooooooo08Gooooo0_l00030ooooo`007_ooool00ol0003oooooooooo`25oooo
o`;o0000`?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0>Kooooo0_l0001Oooooo`007_ooool2o`000>Oooooo0_l0001Oooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo093ooooo0_l0002e
ooooo`007_ooool00ol0003oooooooooo`2@ooooo`;o0000]Oooool001kooooo00?o0000oooooooo
ool0L_ooool2o`000=?ooooo000Nooooo`03o`000?oooooooooo07;ooooo0_l0003Cooooo`007_oo
ool00ol0003oooooooooo`3?ooooo`;o0000M_ooool001kooooo00?o0000ooooooooool0coooool2
o`0007Kooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0A_ooool2o`000?oooooo000Nooooo`03o`000?oooooooooo04Kooooo0_l0003oooooo`007_oo
ool00ol0003oooooooooo`13ooooo`;o0000ooooool3ooooo`007_ooool00ol0003oooooooooo`13
ooooo`;o0000ooooool3ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04oooo
o`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool3o`000?ooooooB?ooool000?o
oooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000
ooooooooool0oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgM
oeEEEOoooooo00001oooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo00Wooooo0_l0
0012ooooo`;o00004Oooool2o`000>Gooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo00Wooooo0_l0000dooooo`;o00003?oo
ool2o`00017ooooo0_l0003Uooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?o
MgMgo`000?ooool01_ooool00ol0003oooooooooo`0oooooo`;o0000ooooool7ooooo`007_ooool0
0ol0003oooooooooo`3^ooooo`;o0000Eoooool001kooooo00?o0000ooooooooool0k_ooool2o`00
05Oooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo03Sooooo0_l0003oooooo`kooooo000Nooooo`03o`000?oooooooooo03Sooooo0ol00009oooo
o`;o0000Loooool2o`0008cooooo000Nooooo`03o`000?oooooooooo03Wooooo0_l00009ooooo`;o
00001_ooool2o`0006_ooooo0ol0002;ooooo`007_ooool00ol0003oooooooooo`11ooooo`;o0000
2Oooool2o`0006cooooo0_l0002;ooooo`007_ooool00ol0003oooooooooo`11ooooo`;o0000oooo
ool5ooooo`007_ooool00ol0003oooooooooo`1hooooo`;o0000cOooool001kooooo0_l0001ioooo
o`;o0000cOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`2;ooooo`;o0000/oooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo08_ooooo0_l0
0029ooooo`;o0000:?ooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo08oooooo0_l00025
ooooo`;o0000;oooool001kooooo00?o0000ooooooooool0Soooool2o`000;Kooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool09_ooool2o`0009Cooooo0_l00022ooooo`;o00001Oooool001ko
oooo00?o0000ooooooooool09_ooool2o`00037ooooo0_l0001Qooooo`;o0000P_ooool2o`0000Go
oooo000Nooooo`03o`000?oooooooooo05Wooooo0_l00011ooooo`;o0000ZOooool001kooooo00?o
0000ooooooooool0W?ooool2o`000:Wooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`00043ooooo0_l0001cooooo`;o
0000TOooool001kooooo00?o0000ooooooooool0?oooool2o`0007?ooooo0_l0002Aooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0:_ooooo0_l0002J
ooooo`007_ooool00ol0003oooooooooo`1Looooo`;o0000COooool2o`0009[ooooo000Nooooo`03
o`000?oooooooooo05cooooo0_l0002_ooooo`;o0000>?ooool001kooooo00?o0000ooooooooool0
ooooool>ooooo`;o0000>?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3Mooooo`;o0000J?ooool001kooooo00?o0000ooooooooool0gOooool2o`00
06Sooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
k?ooool2o`0005Wooooo000Nooooo`03o`000?oooooooooo0>cooooo0_l0001Iooooo`007_ooool0
0ol0003oooooooooo`3Eooooo`;o0000L?ooool001kooooo00?o0000ooooooooool0eOooool2o`00
073ooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l00005ooooo`;o0000
oooooom2ooooo`007_ooool00ol0003oooooooooo`04ooooo`;o0000oooooolVooooo`;o00006_oo
ool001kooooo00?o0000ooooooooool0A?ooool2o`000>Gooooo0_l0000Jooooo`007_ooool00ol0
003oooooooooo`0kooooo`;o00001oooool2o`000?oooooo0_ooool001kooooo00?o0000oooooooo
ool0>oooool2o`000?oooooo2oooool001kooooo00?o0000ooooooooool0QOooool2o`000<3ooooo
000Nooooo`03o`000?oooooooooo03gooooo0_l00007ooooo`;o0000?Oooool2o`000<3ooooo000N
ooooo`03o`000?oooooooooo03gooooo0_l00007ooooo`;o0000B?ooool2o`0000Kooooo0_l0002]
ooooo`007_ooool00ol0003oooooooooo`2@ooooo`;o00001_ooool2o`0004oooooo0_l0000coooo
o`;o00000_ooool2o`0002?ooooo000Nooooo`03o`000?oooooooooo08cooooo0_l0001Kooooo`;o
00007Oooool2o`0001Cooooo0_l00002ooooo`;o00008oooool001kooooo00?o0000ooooooooool0
S?ooool2o`0005Wooooo0_l0000;ooooo`;o00004_ooool2o`0003gooooo000Nooooo`03o`000?oo
oooooooo0>Oooooo0_l0000;ooooo`;o0000DOooool001kooooo00?o0000ooooooooool0KOooool2
o`000=Sooooo000Nooooo`03o`000?oooooooooo01_ooooo0_l0001@ooooo`;o0000M?ooool2o`00
06;ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b
<_l0003o410@olc<c006ooooo`03o`000?oooooooooo01_ooooo0_l00036ooooo`;o0000FOooool2
o`0000Oooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEE
ogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?oooooo?oooool2o`0000Oooooo0003
ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo
0ol0002=ooooo`;o0000^?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?nHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2=ooooo`;o0000^?ooool000?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0
003oooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool00omE
EEGoQhN7ooooo`08ooooo`03o`000?oooooooooo01kooooo0_l0000=ooooo`;o0000AOooool2o`00
00;ooooo0_l0003=ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@
4?nHV9P02?ooool00ol0003oooooooooo`0Nooooo`;o00003Oooool2o`00023ooooo0_l00008oooo
o`;o00006Oooool2o`0000;ooooo0_l0000;ooooo`;o0000`?ooool000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0Coooool2
o`0000Sooooo0_l0000Zooooo`;o0000`?ooool001kooooo00?o0000ooooooooool0SOooool2o`00
0;Sooooo000Nooooo`03o`000?oooooooooo06?ooooo0_l0000=ooooo`;o00006Oooool2o`0007;o
oooo0_l00014ooooo`007_ooool00ol0003oooooooooo`1Sooooo`;o00003Oooool2o`0008gooooo
0_l00014ooooo`007_ooool00ol0003oooooooooo`0fooooo`;o0000ooooool@ooooo`007_ooool0
0ol0003oooooooooo`02o`0002kooooo0_l00004ooooo`;o00001oooool2o`0003Cooooo0_l0003@
ooooo`007_ooool00ol0003oooooooooo`02o`0000Kooooo0_l0000Vooooo`;o00001Oooool2o`00
00Kooooo0_l0000dooooo`;o0000d?ooool001kooooo00?o0000ooooooooool02?ooool2o`0002co
oooo0ol0003eooooo`;o00005oooool001kooooo00?o0000ooooooooool0=_ooool2o`0009Sooooo
0_l00002ooooo`;o0000EOooool2o`000003ooooool0003o000001Oooooo000Nooooo`03o`000?oo
oooooooo0=3ooooo0_l00002ooooo`;o0000EOooool2o`0001[ooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`0006Oo
oooo0_l0001iooooo`;o0000I?ooool001kooooo00?o0000ooooooooool0Aoooool2o`0001gooooo
0_l0001iooooo`;o00002_ooool2o`0005Sooooo000Nooooo`03o`000?oooooooooo04Oooooo0_l0
001<ooooo`;o00001?ooool2o`00053ooooo0_l00003ooooo`;o0000Doooool001kooooo00?o0000
ooooooooool05?ooool2o`0004?ooooo0_l0000jooooo`;o00001?ooool2o`0005Gooooo0_l0001C
ooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o00002?ooool2o`0002?ooooo0_l0000Noooo
o`;o0000e_ooool2o`0001Cooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0000]ooooo`;o
00001_ooool2o`000>kooooo0_l0000Dooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o0000
7?ooool2o`0000;ooooo0_l0000mooooo`;o0000aOooool001kooooo00?o0000ooooooooool07ooo
ool2o`0000Wooooo0_l0000Aooooo`;o00002?ooool2o`0002Cooooo0_l0000Aooooo`;o0000aOoo
ool001kooooo00?o0000ooooooooool0:_ooool2o`0001_ooooo0_l0000:ooooo`;o00000oooool2
o`0001?ooooo0_l0001hooooo`;o0000D?ooool2o`0000cooooo000Nooooo`03o`000?oooooooooo
05?ooooo0_l00003ooooo`;o0000SOooool2o`00053ooooo0_l0000<ooooo`007_ooool00ol0003o
ooooooooo`1]ooooo`;o00006_ooool2o`0008oooooo0_l0000[ooooo`007_ooool00ol0003ooooo
ooooo`0>ooooo`;o0000GOooool2o`0001[ooooo0_l0002?ooooo`;o00008?ooool2o`0000Wooooo
000Nooooo`03o`000?oooooooooo00kooooo0_l0000`ooooo`;o00003_ooool2o`000>[ooooo0_l0
0009ooooo`007_ooool00ol0003oooooooooo`0fooooo`;o00002?ooool2o`0000kooooo0_l0002c
ooooo`;o0000@?ooool001kooooo00?o0000ooooooooool04oooool2o`00027ooooo0_l0000:oooo
o`;o00001oooool2o`000;Sooooo0_l00010ooooo`007_ooool00ol0003oooooooooo`02o`0000So
oooo0_l00007ooooo`;o0000;Oooool2o`0000;ooooo0ol00002ooooo`;o0000C?ooool2o`0004oo
oooo0_l0001Kooooo`007_ooool2o`000003ooooool0003o000000Sooooo0_l0000jooooo`?o0000
00?oooooo`000?l000005oooool2o`0003Cooooo0_l0001?ooooo`;o0000Foooool001kooooo00?o
0000ooooooooool0A_ooool2o`0000;ooooo0_l00002ooooo`;o00004oooool2o`000>;ooooo000N
ooooo`03o`000?oooooooooo03oooooo0_l00006ooooo`;o00001Oooool2o`0005gooooo0_l0002H
ooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o0000;oooool2o`0000Kooooo0_l0000doooo
o`;o0000;_ooool2o`0009Sooooo000Nooooo`03o`000?oooooooooo00kooooo0ol0001Tooooo`;o
00001_ooool2o`000<Sooooo000Nooooo`03o`000?oooooooooo00oooooo0_l0000/ooooo`;o0000
2Oooool2o`0000Sooooo0_l00003ooooo`;o00007?ooool2o`0001;ooooo0_l0000/ooooo`;o0000
S_ooool001kooooo00?o0000ooooooooool0?Oooool2o`0000Wooooo0_l00008ooooo`;o00000ooo
ool2o`00033ooooo0_l0000<ooooo`Co00007?ooool2o`0008kooooo000Nooooo`03o`000?oooooo
oooo00oooooo0_l0000Vooooo`?o0000GOooool4o`000:cooooo000Nooooo`03o`000?oooooooooo
00oooooo0_l00003ooooo`;o00007?ooool2o`0000?ooooo0ol00005ooooo`;o0000<?ooool2o`00
0=Cooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0000Eooooo`;o00001Oooool2o`0000_o
oooo0ol00008ooooo`;o00009Oooool2o`000=Cooooo000Nooooo`03o`000?oooooooooo01gooooo
0_l0000<ooooo`;o00004oooool2o`0000Sooooo0_l00002ooooo`;o0000<_ooool2o`0001Gooooo
0_l0002/ooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o0000;oooool2o`0000?ooooo0ol0
00000ooooooo0000o`00000Jooooo`;o00003Oooool2o`0001Gooooo0_l0000Nooooo`;o0000S?oo
ool001kooooo00?o0000ooooooooool07oooool2o`0003;ooooo1_l0000Jooooo`;o0000A?ooool2
o`0008cooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0000Kooooo`;o00005_ooool2o`00
01Wooooo1Ol0000]ooooo`;o0000`Oooool001kooooo00?o0000ooooooooool00_ooool2o`0002Wo
oooo1?l000000ooooooo0000o`000003ooooo`;o00001Oooool2o`0000_ooooo0_l00005ooooo`Co
0000;_ooool2o`000;;ooooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o0000
6_ooool4o`000003ooooool0003o000000[ooooo0_l0000;ooooo`;o00000_ooool2o`0000;ooooo
0_l0001Vooooo`;o0000Noooool2o`0000gooooo000Nooooo`;o00002_ooool2o`0000Kooooo0_l0
0003ooooo`;o0000;?ooool2o`0000Wooooo0_l00002ooooo`;o00002?ooool2o`0001_ooooo1?l0
000Jooooo`;o00008Oooool2o`0008[ooooo000Nooooo`03o`000?oooooooooo00Sooooo0ol0000;
ooooo`;o00008?ooool2o`0000[ooooo0_l00008ooooo`;o00000oooool2o`0000;ooooo0_l00004
ooooo`;o00006oooool4o`0001[ooooo0_l0002]ooooo`007_ooool00ol0003oooooooooo`07oooo
o`?o00009_ooool2o`0000Kooooo0_l00007ooooo`Go00002?ooool2o`0000?ooooo0_l00002oooo
o`?o0000eoooool2o`0001Cooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0000Pooooo`;o
000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l00009ooooo`Go00003Oooool3o`000004
ooooool0003o0000o`0000;ooooo0_l00004ooooo`;o0000cOooool2o`0001Cooooo000Nooooo`03
o`000?oooooooooo02Wooooo0_l000000ooooooo0000o`000008ooooo`;o00005?ooool2o`0000Go
oooo0ol00006ooooo`;o00001?ooool4o`0000[ooooo0_l0000Looooo`;o00009?ooool2o`0001_o
oooo0_l0001dooooo`007_ooool00ol0003oooooooooo`0Dooooo`?o0000<oooool4o`0000Sooooo
0_l0000<ooooo`;o00002_ooool2o`0001cooooo0_l0000Tooooo`;o00006oooool2o`0007Cooooo
000Nooooo`03o`000?oooooooooo01Cooooo0ol0000Iooooo`;o00001?ooool2o`0001;ooooo0_l0
000:ooooo`;o00002?ooool2o`000003ooooool0003o000001Kooooo0_l000000ooooooo0000o`00
0037ooooo`007_ooool00ol0003oooooooooo`0`ooooo`;o00001?ooool2o`0002Kooooo1?l00000
0ooooooo0000o`00000Fooooo`;o000000?oooooo`000?l00000aoooool001kooooo00?o0000oooo
ooooool03?ooool2o`00023ooooo0_l00006ooooo`;o00002oooool2o`0001Kooooo0_l000001?oo
oooo0000o`000?l00002ooooo`;o00001?ooool2o`0007cooooo0_l0001Nooooo`007_ooool00ol0
003oooooooooo`0<ooooo`;o00004oooool2o`0000_ooooo0_l0000Cooooo`;o00004Oooool2o`00
00?ooooo0_l00006ooooo`?o000000?oooooo`000?l000000_l0000Zooooo`;o0000D?ooool2o`00
04?ooooo0_l0000Iooooo`007_ooool00ol0003oooooooooo`09ooooo`;o00000oooool2o`00017o
oooo0_l0000cooooo`?o00002_ooool3o`000003ooooool0003o000000;o0000:_ooool2o`0009Go
oooo0_l0000Iooooo`007_ooool00ol0003oooooooooo`09ooooo`;o00000oooool2o`00023ooooo
0_l0000Sooooo`Co00000oooool2o`000004ooooool0003o0000ooooo`;o0000ROooool2o`0004Wo
oooo0_l00003ooooo`;o00002?ooool001kooooo00?o0000ooooooooool0<?ooool2o`0000Cooooo
0_l0000Eooooo`;o00001_ooool2o`0000Gooooo0_l000001?oooooo0000o`000?ooool2o`0000Ko
oooo0_l000000ooooooo0000o`000004ooooo`;o0000N?ooool2o`0004Wooooo0_l00003ooooo`;o
00002?ooool001kooooo00?o0000ooooooooool0=_ooool2o`0001Gooooo0_l0000;ooooo`Co0000
00?oooooo`000?l000001?ooool2o`0000?ooooo1Ol00004ooooo`;o0000d_ooool000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Ko
oooo00?o0000ooooooooool0:_ooool2o`0002kooooo1ol00004ooooo`;o00000oooool3o`000003
ooooool0003o000001Kooooo0_l0002Sooooo`;o00006_ooool000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000oooo
ooooool0:Oooool4o`0000?ooooo0_l0000Hooooo`;o00004_ooool2o`0000Oooooo0_l00005oooo
o`Co00005?ooool2o`0001gooooo0_l00024ooooo`;o00006_ooool000?ooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`0002Cooooo0ol00000
0ooooooo0000o`000003o`0000?ooooo0_l0000Hooooo`;o00006oooool3o`000003ooooool0003o
000000?ooooo0_l0000cooooo`;o0000G_ooool2o`00043ooooo0003ooooo`05o`000?oooooooooo
ooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000ooooooooool09?oo
ool8o`000003ooooool0003o000003?ooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo
0_l0000mooooo`;o0000Doooool2o`000003ooooool0003o0000043ooooo0003ooooo`05o`000?oo
ooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000oooooooo
ool09Oooool:o`0001_ooooo0_l000000ooooooo0000o`000009ooooo`;o00002?ooool2o`000003
ooooool0003o000000?ooooo0_l00002ooooo`;o00004oooool2o`0002Sooooo0_l0000cooooo`;o
00007_ooool2o`00033ooooo0_l0000Aooooo`000oooool01Ol@413ooooooooooooooooo410@00_o
oooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo02Gooooo1?l000000ooo
oooo0000o`000002o`000003ooooool0003o000000gooooo0_l0000:ooooo`;o000000?oooooo`00
0?l000002Oooool2o`0000?ooooo0_l00006ooooo`;o00000oooool2o`0001Oooooo0_l00007oooo
o`;o0000E?ooool2o`00053ooooo0_l0000Aooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo02Gooooo0_l00002
ooooo`So00001_ooool2o`0000Gooooo0_l0000Kooooo`Co00003Oooool2o`0001kooooo0_l0002i
ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVY
Z@06ooooo`03o`000?oooooooooo02Gooooo0_l00002ooooo`Co000000?oooooo`000?l000001ooo
ool2o`0000Wooooo0_l0000Gooooo`;o00003oooool2o`000=Wooooo000Nooooo`03o`000?oooooo
oooo02?ooooo1?l00003ooooo`;o00005_ooool2o`0000Wooooo0_l0000@ooooo`;o00002oooool2
o`000=Wooooo000Nooooo`03o`000?oooooooooo02?ooooo0_l00004ooooo`;o00004?ooool2o`00
00Gooooo0_l00009ooooo`Ko00000_ooool2o`0000Sooooo0_l0000;ooooo`Co0000[Oooool2o`00
02Sooooo000Nooooo`03o`000?oooooooooo02Wooooo0_l00009ooooo`;o00000_ooool2o`000003
ooooool0003o000000Gooooo0_l00004ooooo`;o00001?ooool5o`0000;ooooo0_l0000Gooooo`?o
00009Oooool2o`0008Gooooo0_l0000Xooooo`007_ooool00ol0003oooooooooo`0dooooo`;o0000
0_ooool2o`000003ooooool0003o000000?ooooo1?l00004ooooo`;o000000?oooooo`000?l00000
1ol00004ooooo`;o00000oooool2o`00013ooooo0_l0000Uooooo`;o0000?oooool2o`0006kooooo
000Nooooo`03o`000?oooooooooo01Gooooo0_l0000Dooooo`;o00002_ooool2o`0000;ooooo0_l0
0002ooooo`Oo000000Goooooo`000?l0003o0000ooooo`09o`0000;ooooo1?l00003ooooo`;o0000
4?ooool2o`0006Kooooo0_l0001@ooooo`;o00007?ooool001kooooo00?o0000ooooooooool05Ooo
ool2o`0000Gooooo0_l0000;ooooo`Ko00000_ooool3o`0000?ooooo0_l00006ooooo`Co000000Co
ooooo`000?l0003ooooo0ol00002ooooo`So00000_ooool3o`0001?ooooo0_l000000ooooooo0000
o`00001Xooooo`;o0000C_ooool2o`0001cooooo000Nooooo`04o`000?ooooooooooooooo`;o0000
6Oooool2o`0000Cooooo0_l00005ooooo`Ko00000_ooool3o`0000Gooooo0_l0000<oooooa3o0000
1oooool2o`0000?ooooo0_l00007ooooo`;o000000?oooooo`000?l00000?_ooool2o`0002Sooooo
0_l0001/ooooo`007_ooool01?l0003oooooooooooooool2o`0001oooooo0_l0000Eooooo`?o0000
2_ooool9o`0000?ooooo1ol00005ooooo`;o00000oooool2o`0000[ooooo0_l0000nooooo`;o0000
=_ooool2o`0005kooooo000Nooooo`03o`000?oooooooooo02Sooooo0_l00005ooooo`;o00002Ooo
ool3o`0000Wooooo2Ol000000ooooooo0000o`000002ooooo`Go00000oooool4o`00077ooooo0_l0
000Dooooo`;o0000G_ooool001kooooo00?o0000ooooooooool0:?ooool2o`0000Gooooo1Ol00004
ooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo2_l000001?oooooo0000o`000?oo
ool6o`0000?ooooo0_l0000Dooooo`;o0000GOooool2o`0002Oooooo0_l0000Mooooo`;o0000;?oo
ool001kooooo00?o0000ooooooooool0<?ooool5o`0000?ooooo0_l00007ooooo`;o00000_ooool:
o`000003ooooool0003o000000Co000000?oooooo`000?l000000_l000000ooooooo0000o`00000@
ooooo`;o000000Coooooo`000?l0003o0000Q_ooool2o`0001gooooo0_l0000Uooooo`;o00001Ooo
ool001kooooo0_l0000dooooo`;o00004?ooool:o`000003ooooool0003o000000Co00000oooool2
o`000003ooooool0003o0000013ooooo0_l000000ooooooo0000o`00003=ooooo`;o00001Oooool0
01kooooo00?o0000ooooooooool08_ooool2o`0000Oooooo0_l0000;ooooo`;o00002oooool5o`00
00;ooooo1?l000000ooooooo0000o`000003o`0001;ooooo0_l00037ooooo`;o00005?ooool001ko
oooo00?o0000ooooooooool08_ooool2o`0000;ooooo1?l000000ooooooo0000o`000008ooooo`;o
000000?oooooo`000?l000000_l0000;ooooo`?o00001?ooool2o`0000;ooooo1?l0000Booooo`;o
00004Oooool2o`0005Oooooo0_l0001Kooooo`;o00005?ooool001kooooo00?o0000ooooooooool0
3oooool2o`0000Oooooo0_l00009ooooo`;o000000?oooooo`000?l000000_l0000;ooooo`;o0000
0oooool2o`0000Cooooo0_l00004ooooo`Co00001oooool4o`000003ooooool0003o000000Cooooo
0_l0000:ooooo`;o00004Oooool2o`0005Oooooo0_l0001aooooo`007_ooool00ol0003ooooooooo
o`0?ooooo`;o00000_ooool2o`0000?ooooo0_l00009ooooo`;o00003Oooool2o`000003ooooool0
003o000000Sooooo0ol00004ooooo`;o00002?ooool5o`000004ooooool0003o0000o`0000?ooooo
0_l0000;ooooo`;o00006_ooool2o`0001cooooo0_l0002Rooooo`007_ooool00ol0003ooooooooo
o`0Aooooo`Co00007Oooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`000003oooo
ool0003o000000oooooo1Ol00002ooooo`?o00001?ooool2o`0000Wooooo0_l0000Jooooo`;o0000
7?ooool2o`000:;ooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l00009ooooo`;o00008ooo
ool4o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00002oooool5o`0000?ooooo0_l0
0004ooooo`;o0000K_ooool2o`0007Oooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l0000:
ooooo`;o00008_ooool2o`0000_ooooo0_l0000:ooooo`Go00001Oooool2o`0000[ooooo0_l00008
ooooo`;o0000GOooool2o`0007Oooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0000?oooo
o`;o00009oooool2o`000003ooooool0003o000000Sooooo0_l00004ooooo`;o00001?ooool3o`00
00Oooooo0_l0001]ooooo`;o0000G_ooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo02?o
oooo0_l0000Wooooo`;o000000?oooooo`000?l000002oooool5o`0000Gooooo0_l0000/ooooo`;o
0000B?ooool2o`0005kooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`14ooooo`Co0000
1Oooool2o`0000Kooooo1_l000000ooooooo0000o`000002o`0000Gooooo0_l0000<ooooo`;o0000
3oooool2o`0000kooooo0_l0002Nooooo`;o00004Oooool001kooooo00?o0000ooooooooool07_oo
ool2o`0001Sooooo0ol00006ooooo`;o000000?oooooo`000?l000000_l00003ooooo`Co00000_oo
ool:o`000003ooooool0003o000000Oooooo0_l0000<ooooo`;o00003oooool2o`0001Cooooo0_l0
002Hooooo`;o00004Oooool001kooooo00?o0000ooooooooool05Oooool2o`0000Oooooo0_l0000H
ooooo`?o000000?oooooo`000?l000000oooool2o`0000Sooooo1?l00002ooooo`Ko00001?ooool5
o`0000?ooooo1ol0000`ooooo`;o0000=oooool2o`0007;ooooo000Nooooo`03o`000?oooooooooo
01Gooooo0_l00005ooooo`;o00007?ooool4o`0000Wooooo0_l00004ooooo`;o00003?ooool5o`00
00?ooooo0_l000000ooooooo0000o`000002o`0000Oooooo0_l0001=ooooo`;o00004Oooool2o`00
06;ooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`0Hooooo`Ko00007?ooool2o`0000_o
oooo0_l000000ooooooo0000o`00000@ooooo`;o00001oooool4o`000003ooooool0003o000000Go
oooo0_l0000:ooooo`;o0000@Oooool2o`0007Gooooo0_l0000>ooooo`007_ooool00ol0003ooooo
ooooo`0Hooooo`Co00006Oooool2o`000003ooooool0003o000000;o00003?ooool4o`0000oooooo
1?l00006ooooo`Oo00004Oooool2o`0006oooooo0_l0001Gooooo`007_ooool2o`0000;ooooo0_l0
000<ooooo`;o00009?ooool2o`000003ooooool0003o000000;o00003?ooool2o`00017ooooo1?l0
00000ooooooo0000o`000002ooooo`Co000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l0
001>ooooo`;o0000:Oooool2o`0005Oooooo000Nooooo`04o`000?ooooooooooooooo`;o00002ooo
ool3o`0001Cooooo0_l00005ooooo`;o0000:?ooool2o`0000Sooooo0ol000000ooooooo0000o`00
0002o`0000Cooooo0ol00004ooooo`;o00002oooool2o`00047ooooo0_l0001_ooooo`;o00001Ooo
ool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00kooooo0_l0000Eooooo`;o00001Oooool2
o`0001[ooooo0_l00004ooooo`;o000000?oooooo`000?l000000oooool2o`0000Wooooo0_l00002
ooooo`?o00001?ooool2o`000003ooooool0003o000000oooooo0_l00006ooooo`;o0000Z_ooool2
o`0000Gooooo0_l0000:ooooo`007_ooool01?l0003oooooooooooooool2o`0002gooooo0_l00003
ooooo`;o00004Oooool2o`0000Cooooo0_l000000ooooooo0000o`00000Aooooo`;o00002?ooool3
o`0000_ooooo0_l0000:ooooo`;o00005oooool2o`000:Cooooo000Nooooo`04o`000?oooooooooo
ooooo`;o00005Oooool2o`0001Kooooo0ol00002ooooo`;o00004Oooool2o`0001Kooooo0ol00000
0ooooooo0000o`000003o`0000;ooooo0_l000001?oooooo0000o`000?l0000;ooooo`;o00008ooo
ool2o`0007Kooooo0_l0000Rooooo`;o00002?ooool001kooooo00?o0000ooooooooool06?ooool2
o`0001Oooooo0_l0000Aooooo`?o000000?oooooo`000?l000001?ooool2o`0000gooooo0_l00000
1Ooooooo0000o`000?l0003ooooo00Go000000Coooooo`000?l0003o00000_ooool2o`0000Sooooo
0ol00002ooooo`;o000000Coooooo`000?l0003o00001_ooool2o`0008gooooo0_l0000Rooooo`;o
00002?ooool001kooooo00?o0000ooooooooool0A?ooool3o`0000Oooooo0ol0000<ooooo`?o0000
1?ooool4o`0000;ooooo0ol000000ooooooo0000o`000009ooooo`Oo000000Coooooo`000?l0003o
00001_ooool2o`000;_ooooo000Nooooo`03o`000?oooooooooo00;o00007?ooool2o`0001gooooo
0_l0000?ooooo`?o00002Oooool2o`0000;ooooo0_l00004ooooo`Co00001?ooool4o`0000cooooo
0_l00004ooooo`;o0000UOooool2o`0002cooooo000Nooooo`03o`000?oooooooooo00;o00003ooo
ool2o`0000_ooooo0_l00006ooooo`;o00003_ooool2o`0000?ooooo1?l00009ooooo`;o00001?oo
ool2o`0000[ooooo0_l00007ooooo`?o000000?oooooo`000?l000000oooool4o`0000Kooooo0_l0
001_ooooo`;o0000<?ooool2o`0002cooooo000Nooooo`03o`000?oooooooooo017ooooo0_l0000C
ooooo`Co00002Oooool2o`000003ooooool0003o000000?ooooo1?l00003ooooo`;o000000Cooooo
o`000?l0003ooooo0_l000000ooooooo0000o`000002ooooo`;o00004Oooool3o`000003ooooool0
003o000000?o00000oooool2o`0000Kooooo0_l00005ooooo`;o00002?ooool2o`0005kooooo0_l0
001Nooooo`007_ooool00ol0003oooooooooo`0Xooooo`;o00002Oooool2o`0000Oooooo0ol00003
ooooo`;o000000?oooooo`000?l000001?ooool2o`000004ooooool0003o0000o`00017ooooo0_l0
0002ooooo`;o000000?oooooo`000?l000000ol0000;ooooo`;o00000_ooool4o`0000Kooooo0_l0
002nooooo`007_ooool3o`0000Sooooo0_l00009ooooo`;o00009Oooool2o`0001;ooooo0ol0000B
ooooo`;o00000_ooool2o`000003ooooool0003o000000;o00002_ooool3o`0000Cooooo0_l00015
ooooo`;o00008oooool2o`0005[ooooo000Nooooo`?o00002?ooool2o`0000?ooooo0_l00004oooo
o`;o00008Oooool2o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l000001oooool2o`00
0003ooooool0003o000000oooooo0_l000000ooooooo0000o`000002ooooo`;o00003oooool3o`00
00Cooooo0_l00015ooooo`;o00008oooool2o`0002[ooooo0_l0000^ooooo`007_ooool00ol0003o
ooooooooo`0=ooooo`;o00000oooool2o`0002;ooooo0_l00008ooooo`;o000000?oooooo`000?l0
00001oooool2o`0000Wooooo0_l00007ooooo`;o00003Oooool2o`00017ooooo0_l0002Cooooo`;o
00007_ooool2o`0000kooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l00013ooooo`;o0000
0oooool2o`0000Wooooo0ol000000ooooooo0000o`000002ooooo`;o00002_ooool2o`0000Gooooo
0_l0002_ooooo`;o00000_ooool2o`0000kooooo000Nooooo`03o`000?oooooooooo047ooooo0_l0
0006ooooo`;o00003?ooool2o`0000?ooooo0_l00003ooooo`?o000000?oooooo`000?l000000ol0
00000ooooooo0000o`00000>ooooo`;o0000MOooool2o`0003kooooo0ol0000Booooo`007_ooool2
o`0004;ooooo0_l00006ooooo`;o00001oooool2o`0000?ooooo0_l00008ooooo`Ko00000oooool3
o`0000kooooo0_l0001eooooo`;o0000?_ooool2o`0001?ooooo000Nooooo`03o`000?oooooooooo
01?ooooo0_l0000_ooooo`;o00003?ooool2o`000003ooooool0003o000000Wooooo0_l00002oooo
o`;o00000_ooool6o`000003ooooool0003o000000[ooooo0_l0003:ooooo`007_ooool00ol0003o
ooooooooo`0Cooooo`;o0000;oooool2o`0000oooooo0_l00009ooooo`Go00000oooool9o`0001Co
oooo0_l0000<ooooo`;o0000/_ooool001kooooo00?o0000ooooooooool08Oooool2o`0001_ooooo
0ol0000Aooooo`;o000000?oooooo`000?l000002_ooool6o`0000Kooooo0_l0000Fooooo`;o0000
3?ooool2o`000:Cooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`0Qooooo`;o000000?o
ooooo`000?l000006?ooool5o`0000cooooo0_l000000ooooooo0000o`000003o`000003ooooool0
003o000000Oooooo0_l000001?oooooo0000o`000?l0000<ooooo`;o0000Z?ooool2o`0001[ooooo
0_l0000<ooooo`007_ooool00ol0003oooooooooo`0Tooooo`;o00006oooool2o`0000Kooooo0_l0
0004ooooo`;o00000_ooool4o`000003ooooool0003o000000?ooooo1?l000000ooooooo0000o`00
000?ooooo`;o00001oooool2o`0005gooooo0_l00010ooooo`;o0000:?ooool001kooooo00?o0000
ooooooooool0BOooool2o`0000Sooooo0_l00003ooooo`;o00000oooool7o`0000oooooo0_l00002
ooooo`;o00000oooool2o`0000Sooooo0_l0000Zooooo`;o00009oooool2o`0006[ooooo000Noooo
o`03o`000?oooooooooo053ooooo0_l000000ooooooo0000o`000003ooooo`;o00001Oooool3o`00
00gooooo0_l00005ooooo`?o000000?oooooo`000?l000002_ooool2o`0002[ooooo0_l0001coooo
o`;o00007_ooool001kooooo00?o0000ooooooooool0D?ooool2o`0001gooooo0_l00005ooooo`;o
00000_ooool2o`0006Cooooo0_l00015ooooo`;o00007_ooool001kooooo00?o0000ooooooooool0
;_ooool2o`0000Cooooo0_l0000nooooo`?o00001Oooool2o`0006;ooooo0_l00013ooooo`;o0000
5_ooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo02kooooo0_l00004ooooo`;o00007ooo
ool2o`0001Sooooo0_l00003ooooo`?o00001Oooool2o`000:Oooooo0_l0000Fooooo`;o00002?oo
ool001kooooo00?o0000ooooooooool0EOooool2o`0001Sooooo0_l0003Fooooo`007_ooool00ol0
003oooooooooo`1Mooooo`;o0000G?ooool2o`0007;ooooo0_l0000Fooooo`007_ooool00ol0003o
ooooooooo`0[ooooo`;o00000_ooool2o`0001Kooooo0_l0000Dooooo`;o000000?oooooo`000?l0
0000FOooool2o`0007;ooooo0_l0000Fooooo`005?ooool4o`000003oa0@4?oooooooooo00?ooooo
00?o0000ooooooooool04Oooool2o`0001Sooooo0_l00002ooooo`;o00005_ooool2o`0000Kooooo
0_l0000?ooooo`;o0000<Oooool2o`000;;ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool04Oooool2o`0002?ooooo0_l0000Gooooo`;o0000@_ooool2o`0000Gooooo0_l0
002[ooooo`005_ooool00ol0003oooooooooo`05ooooo`?o0000;_ooool2o`0000Kooooo0_l0000S
ooooo`;o00000oooool2o`0003Sooooo0_l00011ooooo`;o0000J?ooool001Kooooo00?o0000oooo
ooooool0=_ooool2o`0002_ooooo0_l00003ooooo`;o0000Noooool2o`0006Sooooo000Fooooo`03
o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_oo
ool00ol0003oooooooooo`3ooooooe3ooooo000Dooooo`03oeEEEOmVIVKo00000?ooooooD_ooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.08576 .80472 Mdot
.49321 .88954 Mdot
.26265 .8669 Mdot
.15136 .85692 Mdot
.30022 .97248 Mdot
.21886 .87073 Mdot
.12919 .07163 Mdot
.3271 .9173 Mdot
.20571 .83762 Mdot
.22489 .09678 Mdot
.3032 .96103 Mdot
.21212 .01495 Mdot
.31805 .90873 Mdot
.2548 .87198 Mdot
.25579 .85218 Mdot
.33676 .93828 Mdot
.39467 .06701 Mdot
.25412 .92446 Mdot
.08691 .79167 Mdot
.14059 .84786 Mdot
.47913 .72906 Mdot
.26181 .82796 Mdot
.33419 .86561 Mdot
.54174 .71295 Mdot
.22261 .84093 Mdot
.35173 .89173 Mdot
.24811 .80346 Mdot
.29676 .13117 Mdot
.29294 .99775 Mdot
.22183 .78345 Mdot
.18297 .86231 Mdot
.25263 .86005 Mdot
.3087 .80243 Mdot
.43321 .58884 Mdot
.08707 .71743 Mdot
.23684 .90665 Mdot
.38897 .8558 Mdot
.79247 .00793 Mdot
.17971 .01204 Mdot
.23666 .82328 Mdot
.16211 .83556 Mdot
.05755 .89635 Mdot
.43951 .95888 Mdot
.63537 .4778 Mdot
.07618 .75536 Mdot
.09792 .89714 Mdot
.05118 .73284 Mdot
.28117 .79965 Mdot
.26458 .88249 Mdot
.22193 .15091 Mdot
.23688 .00518 Mdot
.26688 .727 Mdot
.35991 .95053 Mdot
.2711 .02218 Mdot
.36131 .9552 Mdot
.34222 .04384 Mdot
.90482 .89915 Mdot
.32782 .93113 Mdot
.25093 .80231 Mdot
.17886 .73137 Mdot
.18959 .84047 Mdot
.32689 .8976 Mdot
.68399 .8509 Mdot
.23576 .85404 Mdot
.21736 .93294 Mdot
.22761 .85798 Mdot
.2677 .76003 Mdot
.25004 .80191 Mdot
.22698 .87218 Mdot
.69097 .93833 Mdot
.47388 .49885 Mdot
.33195 .99604 Mdot
.94084 .88132 Mdot
.23379 .40004 Mdot
.35948 .80673 Mdot
.9012 .95115 Mdot
.22647 .79665 Mdot
.18127 .69809 Mdot
.24449 .82774 Mdot
.44492 .90076 Mdot
.15703 .69868 Mdot
.33888 .87889 Mdot
.60256 .3215 Mdot
.32908 .90865 Mdot
.06935 .81453 Mdot
.72721 .57877 Mdot
.3229 .93845 Mdot
.22559 .79863 Mdot
.2435 .86775 Mdot
.35877 .88166 Mdot
.25536 .89701 Mdot
.70751 .63586 Mdot
.32196 .9915 Mdot
.19343 .61549 Mdot
.11481 .74413 Mdot
.23038 .66552 Mdot
.89185 .9946 Mdot
.10355 .71123 Mdot
.34688 .96697 Mdot
.25714 .03086 Mdot
.30811 .8472 Mdot
.19686 .9501 Mdot
.10627 .83449 Mdot
.43809 .01833 Mdot
.55885 .84619 Mdot
.3345 .87722 Mdot
.35943 .67421 Mdot
.35704 .80754 Mdot
.36144 .77224 Mdot
.05185 .49998 Mdot
.43896 .88371 Mdot
.52805 .37936 Mdot
.27515 .66584 Mdot
.23303 .91473 Mdot
.05826 .66825 Mdot
.10422 .13234 Mdot
.31504 .76582 Mdot
.32028 .89124 Mdot
.39673 .97137 Mdot
.3699 .68224 Mdot
.25297 .79167 Mdot
.33007 .83685 Mdot
.35843 .76147 Mdot
.31259 .73784 Mdot
.15646 .05224 Mdot
.78351 .99102 Mdot
.41944 .94493 Mdot
.08811 .79359 Mdot
.39179 .55894 Mdot
.01304 .93263 Mdot
.6708 .8779 Mdot
.13218 .93996 Mdot
.26917 .64586 Mdot
.24827 .84316 Mdot
.1687 .83395 Mdot
.28141 .92554 Mdot
.34117 .89174 Mdot
.36358 .10625 Mdot
.13338 .87596 Mdot
.20737 .86302 Mdot
.09062 .81809 Mdot
.26162 .87075 Mdot
.28575 .81251 Mdot
.0695 .85592 Mdot
.66148 .72485 Mdot
.25228 .97219 Mdot
.10672 .78817 Mdot
.27374 .82546 Mdot
.916 .03076 Mdot
.45289 .70085 Mdot
.22962 .91219 Mdot
.3036 .78545 Mdot
.18478 .00954 Mdot
.14595 .83821 Mdot
.2584 .83592 Mdot
.33812 .90072 Mdot
.3016 .12198 Mdot
.69804 .30094 Mdot
.19816 .83058 Mdot
.30957 .96256 Mdot
.33763 .14142 Mdot
.05017 .82771 Mdot
.05337 .67416 Mdot
.26843 .80817 Mdot
.32577 .96252 Mdot
.33239 .96809 Mdot
.27154 .8334 Mdot
.21398 .82022 Mdot
.95342 .54175 Mdot
.28018 .92374 Mdot
.32034 .77501 Mdot
.05102 .6901 Mdot
.0624 .78183 Mdot
.70793 .61764 Mdot
.08989 .79211 Mdot
.19944 .05436 Mdot
.39861 .62436 Mdot
.3578 .89557 Mdot
.99893 .09215 Mdot
.24015 .71869 Mdot
.37773 .01706 Mdot
.34273 .96641 Mdot
.12388 .7688 Mdot
.24334 .73858 Mdot
.31869 .24366 Mdot
.16223 .87851 Mdot
.26972 .06239 Mdot
.30781 .91044 Mdot
.01159 .61442 Mdot
.01965 .88833 Mdot
.09091 .78854 Mdot
.23661 .68709 Mdot
.08654 .79947 Mdot
.51071 .72829 Mdot
.3296 .62912 Mdot
.44872 .92756 Mdot
.05847 .80098 Mdot
.33006 .81522 Mdot
.21076 .83664 Mdot
.35288 .77353 Mdot
.91737 .03784 Mdot
.59781 .43721 Mdot
.22683 .82561 Mdot
.26843 .74581 Mdot
.22479 .8426 Mdot
.21841 .80181 Mdot
.61926 .0636 Mdot
.24387 .79684 Mdot
.94698 .58218 Mdot
.25775 .07344 Mdot
.2968 .95363 Mdot
.08774 .82229 Mdot
.25843 .58298 Mdot
.47269 .52844 Mdot
.35393 .12899 Mdot
.33964 .2889 Mdot
.24779 .83741 Mdot
.25341 .50251 Mdot
.19446 .14444 Mdot
.10896 .81516 Mdot
.84677 .17935 Mdot
.16175 .70404 Mdot
.29457 .89756 Mdot
.21017 .82881 Mdot
.27606 .81573 Mdot
.28873 .06209 Mdot
.01477 .97449 Mdot
.33254 .88073 Mdot
.17926 .37055 Mdot
.2677 .82631 Mdot
.35502 .88493 Mdot
.20679 .73981 Mdot
.3114 .79523 Mdot
.63051 .61858 Mdot
.36748 .31545 Mdot
.13167 .58575 Mdot
.7381 .93045 Mdot
.2442 .87711 Mdot
.60361 .02173 Mdot
.8085 .21741 Mdot
.28277 .98409 Mdot
.30886 .79978 Mdot
.32744 .90266 Mdot
.1822 .95959 Mdot
.12943 .96087 Mdot
.33349 .681 Mdot
.22225 .72382 Mdot
.29602 .77776 Mdot
.71247 .05224 Mdot
.18204 .82809 Mdot
.30885 .73343 Mdot
.36248 .95281 Mdot
.58772 .25679 Mdot
.61322 .91877 Mdot
.89798 .98573 Mdot
.31012 .91997 Mdot
.35418 .95592 Mdot
.6382 .05875 Mdot
.1641 .75541 Mdot
.56332 .72705 Mdot
.08737 .81588 Mdot
.18843 .90623 Mdot
.24807 .28818 Mdot
.45289 .92068 Mdot
.30751 .80084 Mdot
.84065 .13022 Mdot
.18485 .78503 Mdot
.25016 .10329 Mdot
.27463 .87733 Mdot
.23806 .80813 Mdot
.34094 .96423 Mdot
.12377 .04725 Mdot
.20702 .828 Mdot
.20044 .88771 Mdot
.09021 .69719 Mdot
.35512 .93672 Mdot
.21868 .16233 Mdot
.18707 .72374 Mdot
.26076 .96405 Mdot
.19911 .96824 Mdot
.87864 .87355 Mdot
.27148 .81177 Mdot
.29018 .8026 Mdot
.35982 .82287 Mdot
.33163 .96737 Mdot
.28831 .89261 Mdot
.26357 .91447 Mdot
.20071 .02158 Mdot
.33485 .97097 Mdot
.23814 .03964 Mdot
.33911 .97381 Mdot
.21291 .73883 Mdot
.09107 .7927 Mdot
.44258 .78533 Mdot
.82435 .67868 Mdot
.06987 .97173 Mdot
.25818 .91131 Mdot
.25168 .09232 Mdot
.88412 .94243 Mdot
.85722 .51856 Mdot
.30503 .01238 Mdot
.40227 .93299 Mdot
.07084 .74478 Mdot
.25654 .7511 Mdot
.1377 .27342 Mdot
.42114 .80414 Mdot
.24441 .80679 Mdot
.2523 .81569 Mdot
.71698 .72728 Mdot
.57233 .44511 Mdot
.24675 .79242 Mdot
.90692 .0138 Mdot
.34839 .884 Mdot
.10256 .7657 Mdot
.24649 .89784 Mdot
.26164 .06048 Mdot
.19804 .90875 Mdot
.51891 .81362 Mdot
.36835 .85319 Mdot
.76764 .35798 Mdot
.18143 .01846 Mdot
.31759 .78481 Mdot
.19394 .94688 Mdot
.17916 .8187 Mdot
.19942 .89121 Mdot
.35651 .8875 Mdot
.25879 .95096 Mdot
.08994 .8252 Mdot
.2613 .04713 Mdot
.34715 .88719 Mdot
.16826 .86044 Mdot
.21631 .87734 Mdot
.14585 .99985 Mdot
.33381 .87958 Mdot
.40438 .35494 Mdot
.22987 .43229 Mdot
.6755 .63421 Mdot
.25013 .79891 Mdot
.33755 .0857 Mdot
.63742 .58541 Mdot
.32127 .94803 Mdot
.45901 .61061 Mdot
.09324 .83015 Mdot
.27833 .84347 Mdot
.17679 .91707 Mdot
.05565 .09889 Mdot
.48618 .69825 Mdot
.04529 .40508 Mdot
.46868 .20237 Mdot
.3231 .9238 Mdot
.29703 .87713 Mdot
.3592 .95931 Mdot
.04714 .82365 Mdot
.35324 .06769 Mdot
.61689 .11162 Mdot
.20407 .83154 Mdot
.06628 .8734 Mdot
.25553 .74614 Mdot
.31328 .92942 Mdot
.15361 .56754 Mdot
.28694 .79657 Mdot
.04585 .95617 Mdot
.1632 .84774 Mdot
.30755 .94541 Mdot
.34016 .91258 Mdot
.13629 .74184 Mdot
.33137 .65687 Mdot
.03655 .59222 Mdot
.32522 .84221 Mdot
.21939 .83538 Mdot
.37607 .13466 Mdot
.23677 .81278 Mdot
.24109 .84763 Mdot
.2281 .84827 Mdot
.07877 .83387 Mdot
.39069 .06972 Mdot
.00094 .75063 Mdot
.24429 .84779 Mdot
.76262 .10472 Mdot
.25649 .75814 Mdot
.23922 .83631 Mdot
.15883 .88074 Mdot
.37362 .77404 Mdot
.75576 .91452 Mdot
.23914 .11017 Mdot
.50062 .77754 Mdot
.42947 .80048 Mdot
.94164 .54464 Mdot
.24707 .80162 Mdot
.48755 .88863 Mdot
.09024 .81792 Mdot
.27595 .97377 Mdot
.31444 .84869 Mdot
.29116 .96386 Mdot
.28909 .96897 Mdot
.19606 .42732 Mdot
.34014 .08371 Mdot
.62794 .03328 Mdot
.25253 .7993 Mdot
.17327 .86904 Mdot
.46868 .89578 Mdot
.11105 .74588 Mdot
.19452 .12822 Mdot
.32741 .90041 Mdot
.36766 .87238 Mdot
.37554 .62233 Mdot
.25961 .04035 Mdot
.36225 .95401 Mdot
.25049 .83381 Mdot
.27132 .81833 Mdot
.37736 .11138 Mdot
.2078 .82326 Mdot
.35287 .13185 Mdot
.71916 .8558 Mdot
.00296 .73336 Mdot
.25422 .90194 Mdot
.16152 .77918 Mdot
.29617 .06874 Mdot
.06599 .0961 Mdot
.24862 .8244 Mdot
.22824 .81513 Mdot
.68787 .94218 Mdot
.30652 .81709 Mdot
.27512 .95892 Mdot
.33344 .92153 Mdot
.66853 .61563 Mdot
.98331 .12885 Mdot
.22051 .83818 Mdot
.32332 .98192 Mdot
.89462 .54695 Mdot
.53338 .44711 Mdot
.39284 .77186 Mdot
.15377 .00848 Mdot
.16905 .87974 Mdot
.68733 .1504 Mdot
.09832 .10172 Mdot
.21879 .14189 Mdot
.15359 .84786 Mdot
.21294 .81094 Mdot
.03749 .77194 Mdot
.19206 .79505 Mdot
.59361 .58028 Mdot
.54902 .55634 Mdot
.20963 .83364 Mdot
.20237 .5294 Mdot
.23859 .81577 Mdot
.33252 .79594 Mdot
.28119 .97814 Mdot
.57767 .21556 Mdot
.27742 .70515 Mdot
.39801 .11552 Mdot
.38553 .80008 Mdot
.30566 .92889 Mdot
.22787 .83215 Mdot
.13545 .99554 Mdot
.24873 .79444 Mdot
.20988 .83229 Mdot
.2575 .96951 Mdot
.38306 .53504 Mdot
.06429 .9583 Mdot
.15965 .91951 Mdot
.2251 .79873 Mdot
.2303 .84355 Mdot
.34297 .884 Mdot
.62132 .84477 Mdot
.09744 .7123 Mdot
.31337 .79301 Mdot
.69657 .0214 Mdot
.23343 .83541 Mdot
.07773 .72437 Mdot
.2248 .81873 Mdot
.32347 .92375 Mdot
.32728 .90993 Mdot
.32834 .90953 Mdot
.26145 .92241 Mdot
.2511 .85193 Mdot
.30208 .99136 Mdot
.33628 .91545 Mdot
.21656 .98315 Mdot
.44432 .89542 Mdot
.25834 .55507 Mdot
.48891 .69561 Mdot
.28911 .81082 Mdot
.09514 .82887 Mdot
.08724 .8011 Mdot
.60796 .07695 Mdot
.57353 .26763 Mdot
.19984 .5969 Mdot
.00952 .76669 Mdot
.3409 .12444 Mdot
.23876 .84925 Mdot
.21182 .82104 Mdot
.16997 .08145 Mdot
.4098 .83932 Mdot
.21924 .85028 Mdot
.33112 .79728 Mdot
.36908 .84357 Mdot
.35951 .8164 Mdot
.7005 .79761 Mdot
.19595 .91712 Mdot
.35352 .78717 Mdot
.05324 .9767 Mdot
.06319 .66515 Mdot
.27412 .47676 Mdot
.26363 .92959 Mdot
.06194 .98866 Mdot
.327 .91111 Mdot
.23744 .0799 Mdot
.20971 .82769 Mdot
.18839 .77981 Mdot
.13088 .83748 Mdot
.18615 .61901 Mdot
.25717 .00236 Mdot
.41612 .1905 Mdot
.30865 .96735 Mdot
.74733 .63619 Mdot
.28185 .07653 Mdot
.22498 .65316 Mdot
.04852 .48396 Mdot
.16741 .87605 Mdot
.22983 .73137 Mdot
.29259 .90415 Mdot
.24072 .83177 Mdot
.35788 .77124 Mdot
.25364 .97063 Mdot
.83407 .04398 Mdot
.07739 .56375 Mdot
.35551 .47633 Mdot
.13597 .79721 Mdot
.3585 .53366 Mdot
.76065 .54178 Mdot
.67152 .61492 Mdot
.32067 .97008 Mdot
.23925 .01684 Mdot
.33259 .90745 Mdot
.30114 .83602 Mdot
.21128 .93033 Mdot
.29045 .84495 Mdot
.77187 .07083 Mdot
.92328 .65683 Mdot
.20793 .86421 Mdot
.7043 .83351 Mdot
.27731 .96049 Mdot
.25413 .84141 Mdot
.15029 .85001 Mdot
.88034 .91881 Mdot
.53745 .19895 Mdot
.16679 .73991 Mdot
.29406 .843 Mdot
.35382 .89133 Mdot
.64649 .95065 Mdot
.90823 .90185 Mdot
.29418 .819 Mdot
.54972 .64543 Mdot
.25552 .80412 Mdot
.77246 .1913 Mdot
.1916 .5811 Mdot
.25536 .79799 Mdot
.22192 .91341 Mdot
.88808 .70254 Mdot
.28375 .86298 Mdot
.40175 .87931 Mdot
.80784 .04168 Mdot
.24574 .0552 Mdot
.26095 .91722 Mdot
.26646 .9167 Mdot
.3194 .12592 Mdot
.30678 .9159 Mdot
.26482 .99443 Mdot
.23968 .86897 Mdot
.99281 .92662 Mdot
.41365 .04603 Mdot
.24767 .85804 Mdot
.09591 .82369 Mdot
.28625 .96723 Mdot
.24514 .82184 Mdot
.14407 .81826 Mdot
.29595 .00065 Mdot
.36304 .94685 Mdot
.41779 .73623 Mdot
.2627 .10649 Mdot
.95061 .88257 Mdot
.23512 .98142 Mdot
.09724 .82497 Mdot
.58155 .10848 Mdot
.21562 .82553 Mdot
.16774 .84882 Mdot
.34034 .98163 Mdot
.45871 .9365 Mdot
.1295 .73933 Mdot
.3363 .91715 Mdot
.3463 .95832 Mdot
.26794 .83549 Mdot
.34784 .79272 Mdot
.2079 .94199 Mdot
.34494 .87847 Mdot
.2028 .10634 Mdot
.34972 .8947 Mdot
.22709 .85804 Mdot
.26235 .66316 Mdot
.27004 .80803 Mdot
.2281 .81632 Mdot
.25842 .85207 Mdot
.09893 .71142 Mdot
.89503 .65304 Mdot
.27282 .797 Mdot
.25231 .81194 Mdot
.2634 .79989 Mdot
.80369 .76252 Mdot
.08597 .80458 Mdot
.90651 .79265 Mdot
.69609 .88401 Mdot
.21794 .85296 Mdot
.86923 .58781 Mdot
.07731 .81134 Mdot
.27922 .98107 Mdot
.33988 .02913 Mdot
.63146 .07165 Mdot
.37598 .96484 Mdot
.05905 .12221 Mdot
.15108 .78902 Mdot
.03085 .96947 Mdot
.08785 .79709 Mdot
.66156 .08984 Mdot
.01921 .75215 Mdot
.22532 .76515 Mdot
.4181 .12761 Mdot
.73525 .43269 Mdot
.35155 .93292 Mdot
.16833 .86664 Mdot
.18681 .91883 Mdot
.20881 .82565 Mdot
.13945 .73052 Mdot
.02507 .93287 Mdot
.24488 .86049 Mdot
.25292 .71657 Mdot
.33054 .91099 Mdot
.3191 .7642 Mdot
.27236 .97515 Mdot
.25035 .85738 Mdot
.44354 .88579 Mdot
.23051 .86963 Mdot
.07858 .85765 Mdot
.15064 .90744 Mdot
.94677 .58451 Mdot
.16317 .73981 Mdot
.36158 .97743 Mdot
.98832 .81998 Mdot
.33425 .90046 Mdot
.81881 .75899 Mdot
.54343 .76212 Mdot
.37126 .87646 Mdot
.10664 .70997 Mdot
.21009 .83428 Mdot
.50487 .13728 Mdot
.23131 .82178 Mdot
.35518 .95375 Mdot
.94443 .93481 Mdot
.98002 .61085 Mdot
.2511 .79681 Mdot
.99749 .76369 Mdot
.35017 .81256 Mdot
.19067 .98488 Mdot
.25834 .80351 Mdot
.97442 .92088 Mdot
.43369 .56289 Mdot
.2514 .8197 Mdot
.57018 .98547 Mdot
.28624 .0414 Mdot
.21606 .66506 Mdot
.15419 .75712 Mdot
.29443 .05852 Mdot
.49254 .71363 Mdot
.25978 .73362 Mdot
.30072 .67729 Mdot
.33539 .88965 Mdot
.14229 .79476 Mdot
.27678 .96644 Mdot
.45152 .6966 Mdot
.92726 .71742 Mdot
.70789 .39163 Mdot
.10105 .88947 Mdot
.33032 .94484 Mdot
.09027 .78631 Mdot
.23999 .8686 Mdot
.04342 .88366 Mdot
.28717 .94801 Mdot
.36062 .67072 Mdot
.33878 .83787 Mdot
.26716 .92814 Mdot
.31994 .82099 Mdot
.19712 .75149 Mdot
.16872 .45155 Mdot
.01859 .00606 Mdot
.29332 .78989 Mdot
.34178 .7901 Mdot
.22462 .83928 Mdot
.67746 .74647 Mdot
.99197 .02 Mdot
.51355 .99648 Mdot
.20134 .43917 Mdot
.36115 .05046 Mdot
.33429 .89866 Mdot
.11601 .87072 Mdot
.51517 .21636 Mdot
.35706 .765 Mdot
.0718 .20231 Mdot
.54647 .79924 Mdot
.21513 .48722 Mdot
.22775 .83163 Mdot
.23344 .03263 Mdot
.35499 .95026 Mdot
.21378 .76717 Mdot
.76999 .29175 Mdot
.35144 .8927 Mdot
.12956 .06498 Mdot
.29298 .79218 Mdot
.29886 .95499 Mdot
.64263 .28117 Mdot
.3159 .78326 Mdot
.08943 .82819 Mdot
.92789 .88901 Mdot
.23092 .75264 Mdot
.62453 .97609 Mdot
.614 .96484 Mdot
.64042 .00886 Mdot
.31388 .94676 Mdot
.25792 .79387 Mdot
.00747 .90553 Mdot
.99445 .82077 Mdot
.31989 .73663 Mdot
.30726 .74643 Mdot
.33754 .88564 Mdot
.20023 .84785 Mdot
.49973 .27882 Mdot
.07508 .76793 Mdot
.46 .08362 Mdot
.16662 .56227 Mdot
.31158 .01876 Mdot
.38305 .48266 Mdot
.30163 .91857 Mdot
.14064 .87466 Mdot
.0833 .7966 Mdot
.48822 .98044 Mdot
.7697 .6405 Mdot
.40906 .95194 Mdot
.2469 .75475 Mdot
.89493 .86287 Mdot
.41467 .89444 Mdot
.40374 .0165 Mdot
.3779 .89485 Mdot
.20995 .86273 Mdot
.34987 .80169 Mdot
.08791 .85585 Mdot
.19648 .75817 Mdot
.33361 .95731 Mdot
.27019 .95534 Mdot
.08402 .71647 Mdot
.31587 .98702 Mdot
.22426 .85249 Mdot
.784 .92013 Mdot
.32514 .91636 Mdot
.13516 .21562 Mdot
.21688 .88008 Mdot
.24361 .98207 Mdot
.16456 .8435 Mdot
.26739 .00697 Mdot
.05149 .99905 Mdot
.33239 .81632 Mdot
.16139 .0053 Mdot
.2464 .86972 Mdot
.12193 .91736 Mdot
.31394 .86436 Mdot
.3623 .95287 Mdot
.44599 .064 Mdot
.11387 .8388 Mdot
.43494 .91348 Mdot
.24162 .85224 Mdot
.1437 .9991 Mdot
.22498 .90549 Mdot
.14917 .86223 Mdot
.23204 .7266 Mdot
.29631 .46331 Mdot
.33765 .63803 Mdot
.23616 .89803 Mdot
.2727 .14638 Mdot
.32681 .06386 Mdot
.20524 .8619 Mdot
.21144 .82098 Mdot
.34743 .88841 Mdot
.19703 .12337 Mdot
.30606 .90796 Mdot
.28935 .05988 Mdot
.36242 .89963 Mdot
.04249 .95363 Mdot
.35742 .95285 Mdot
.35883 .10455 Mdot
.04691 .94141 Mdot
.17617 .88378 Mdot
.26921 .82282 Mdot
.61562 .80498 Mdot
.25198 .78585 Mdot
.24195 .98375 Mdot
.34164 .6313 Mdot
.29907 .80692 Mdot
.24755 .8992 Mdot
.00571 .5344 Mdot
.17895 .49913 Mdot
.08591 .92495 Mdot
.19502 .68587 Mdot
.30707 .05576 Mdot
.20033 .87928 Mdot
.30499 .89554 Mdot
.27036 .56666 Mdot
.31182 .91801 Mdot
.23122 .81911 Mdot
.22952 .69584 Mdot
.8797 .00906 Mdot
.254 .83834 Mdot
.44058 .99419 Mdot
.33111 .91048 Mdot
.34066 .90518 Mdot
.4309 .91835 Mdot
.33723 .90261 Mdot
.31573 .93137 Mdot
.34716 .13605 Mdot
.35859 .94359 Mdot
.34912 .96196 Mdot
.51003 .10021 Mdot
.27271 .66801 Mdot
.41677 .7606 Mdot
.12451 .01293 Mdot
.29764 .95136 Mdot
.48949 .99433 Mdot
.23064 .83851 Mdot
.27734 .86009 Mdot
.17337 .56703 Mdot
.26396 .87862 Mdot
.35405 .89705 Mdot
.57647 .24763 Mdot
.16123 .56462 Mdot
.34447 .90199 Mdot
.2467 .80588 Mdot
.20542 .84564 Mdot
.88561 .94774 Mdot
.91423 .76591 Mdot
.69086 .04308 Mdot
.30086 .86971 Mdot
.3404 .88263 Mdot
.20095 .86217 Mdot
.80836 .08353 Mdot
.34385 .88989 Mdot
.14954 .82384 Mdot
.16074 .69544 Mdot
.26578 .8052 Mdot
.91403 .99858 Mdot
.32845 .9134 Mdot
.24821 .03243 Mdot
.44404 .88653 Mdot
.27109 .88967 Mdot
.33764 .90229 Mdot
.16642 .84483 Mdot
.23442 .82712 Mdot
.49642 .15228 Mdot
.35548 .88055 Mdot
.34688 .91501 Mdot
.08477 .79031 Mdot
.21982 .12253 Mdot
.57075 .92196 Mdot
.34056 .91032 Mdot
.34695 .91874 Mdot
.27108 .80044 Mdot
.23853 .85656 Mdot
.17137 .92474 Mdot
.10867 .73635 Mdot
.30813 .95003 Mdot
.17282 .79409 Mdot
.20058 .28514 Mdot
.04867 .69068 Mdot
.14827 .77287 Mdot
.67842 .86634 Mdot
.17524 .81485 Mdot
.3254 .91161 Mdot
.319 .94938 Mdot
.42304 .75899 Mdot
.08685 .80187 Mdot
.08565 .85016 Mdot
.10773 .94846 Mdot
.26571 .82284 Mdot
.62892 .76343 Mdot
.35791 .86287 Mdot
.23708 .1184 Mdot
.43212 .82006 Mdot
.2799 .80787 Mdot
.40977 .95333 Mdot
.26161 .89439 Mdot
.82858 .10703 Mdot
.23314 .8409 Mdot
.10022 .8831 Mdot
.4191 .91934 Mdot
.14591 .78985 Mdot
.16275 .85189 Mdot
.81938 .07395 Mdot
.214 .81222 Mdot
.66929 .04988 Mdot
.98351 .97022 Mdot
.29441 .63832 Mdot
.21624 .77425 Mdot
.10013 .79952 Mdot
.09669 .8287 Mdot
.25809 .96275 Mdot
.39362 .74612 Mdot
.44685 .19974 Mdot
.26405 .83296 Mdot
.34089 .88103 Mdot
.23761 .45068 Mdot
.0515 .94362 Mdot
.12793 .89927 Mdot
.183 .61214 Mdot
.21044 .84161 Mdot
.17992 .64834 Mdot
.20937 .45942 Mdot
.11192 .7774 Mdot
.3338 .90027 Mdot
.25399 .8593 Mdot
.59428 .09274 Mdot
.21597 .21029 Mdot
.14985 .99889 Mdot
.52087 .80995 Mdot
.96369 .61578 Mdot
.38898 .73489 Mdot
.33864 .9064 Mdot
.33949 .91112 Mdot
.30752 .79999 Mdot
.17192 .67382 Mdot
.08666 .80747 Mdot
.42589 .5432 Mdot
.30862 .75657 Mdot
.25212 .81669 Mdot
.52366 .87528 Mdot
.33506 .9104 Mdot
.12262 .8197 Mdot
.22377 .84267 Mdot
.97095 .9823 Mdot
.44432 .77665 Mdot
.22802 .86448 Mdot
.97074 .77928 Mdot
.18592 .79881 Mdot
.2041 .86089 Mdot
.20935 .56414 Mdot
.22873 .85523 Mdot
.9921 .93322 Mdot
.26746 .7979 Mdot
.41778 .38941 Mdot
.38513 .68335 Mdot
.30343 .86871 Mdot
.3365 .9709 Mdot
.25245 .99372 Mdot
.68727 .88677 Mdot
.70126 .11589 Mdot
.2611 .81564 Mdot
.22205 .82637 Mdot
.25349 .84136 Mdot
.31733 .82451 Mdot
.35045 .89218 Mdot
.42952 .03459 Mdot
.34078 .1131 Mdot
.28428 .0878 Mdot
.56314 .04051 Mdot
.67493 .48866 Mdot
.34937 .32846 Mdot
.54864 .70397 Mdot
.53704 .74435 Mdot
.11808 .03739 Mdot
.81684 .05887 Mdot
.32322 .90664 Mdot
.25598 .08857 Mdot
.85179 .47983 Mdot
.24653 .81102 Mdot
.27561 .8027 Mdot
.29994 .95707 Mdot
.15174 .71042 Mdot
.23971 .00606 Mdot
.27234 .07088 Mdot
.24088 .751 Mdot
.36647 .7934 Mdot
.18532 .93019 Mdot
.86805 .46954 Mdot
.15265 .70813 Mdot
.26618 .807 Mdot
.61171 .201 Mdot
.15193 .86104 Mdot
.14368 .02938 Mdot
.26579 .55024 Mdot
.37135 .917 Mdot
.25998 .79795 Mdot
.31405 .85878 Mdot
.17857 .09794 Mdot
.26084 .12818 Mdot
.35107 .7466 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool3o`0000_ooooo0ol0000?ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool00_ooool001kooooo00?o0000ooooooooool00_ooool2o`0000Wooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;o0000
3?ooool00ol0003oooooooooo`08ooooo`?o00000_ooool3o`0000;ooooo0_l00009ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_oo
ool00ol0003oooooooooo`02ooooo`;o0000:_ooool4o`0000Kooooo0_l0000?ooooo`?o00001ooo
ool2o`0007Oooooo0_l0000`ooooo`;o00006_ooool2o`0002_ooooo000Nooooo`03o`000?oooooo
oooo02Cooooo0_l00008ooooo`;o00001_ooool4o`0002Gooooo0_l0001[ooooo`;o0000<?ooool2
o`0001[ooooo0_l0000[ooooo`007_ooool00ol0003oooooooooo`0Tooooo`;o00004?ooool2o`00
00Wooooo0_l0000Looooo`;o00007_ooool2o`000:;ooooo0_l0000Rooooo`007_ooool00ol0003o
ooooooooo`0gooooo`;o00002?ooool2o`0000Oooooo0_l0000Eooooo`;o00005?ooool2o`0000Ko
oooo0_l00009ooooo`;o0000Uoooool2o`0002;ooooo000Nooooo`03o`000?oooooooooo03Oooooo
0_l00004ooooo`;o00002oooool2o`0000Sooooo0_l0000;ooooo`;o00005?ooool2o`00017ooooo
0_l0000dooooo`;o00007?ooool2o`0005kooooo0_l00007ooooo`007_ooool00ol0003ooooooooo
o`0mooooo`;o00005Oooool2o`0006[ooooo0_l0000Looooo`;o0000G_ooool2o`0000Oooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0:oooool2o`00
02;ooooo0_l0000Iooooo`;o0000^_ooool2o`0001oooooo000Nooooo`03o`000?oooooooooo02_o
oooo0_l0000Kooooo`;o00000oooool4o`0001Wooooo0_l0000Looooo`;o0000?_ooool2o`0005co
oooo0_l0000Oooooo`007_ooool00ol0003oooooooooo`0Rooooo`;o00009?ooool2o`0000?ooooo
0_l0000iooooo`;o0000?_ooool2o`0005cooooo0_l0000Oooooo`007_ooool00ol0003ooooooooo
o`0Rooooo`;o00009Oooool2o`0000Gooooo0_l00007ooooo`;o0000F?ooool2o`00077ooooo0_l0
000Oooooo`007_ooool00ol0003oooooooooo`19ooooo`;o00001Oooool2o`0000Oooooo0_l0000@
ooooo`;o0000A_ooool2o`0002Oooooo0_l0000Uooooo`;o00001_ooool2o`0003[ooooo000Noooo
o`03o`000?oooooooooo02Cooooo0_l0000[ooooo`;o00006?ooool2o`0001Gooooo0_l0001Hoooo
o`;o00009Oooool2o`0000Kooooo0_l0000jooooo`007_ooool00ol0003oooooooooo`0Tooooo`;o
0000:oooool2o`0001kooooo0_l0000?ooooo`;o0000DOooool2o`00073ooooo000Nooooo`;o0000
<?ooool2o`00043ooooo0_l0001Rooooo`;o00003Oooool2o`00067ooooo000Nooooo`03o`000?oo
oooooooo02oooooo0_l0000<ooooo`;o00003Oooool2o`0001;ooooo0_l00022ooooo`;o0000HOoo
ool001kooooo00?o0000ooooooooool0?Oooool2o`0000gooooo0_l0000>ooooo`;o00000_ooool2
o`0006Wooooo0_l0000hooooo`;o0000@?ooool001kooooo00?o0000ooooooooool0DOooool2o`00
0003ooooool0003o000000Cooooo1?l0001]ooooo`;o0000>?ooool2o`00043ooooo000Nooooo`03
o`000?oooooooooo02Kooooo0_l0000Yooooo`;o000000?oooooo`000?l000001?ooool2o`0000[o
oooo0_l0000Uooooo`;o0000=_ooool2o`00083ooooo000Nooooo`03o`000?oooooooooo02Kooooo
0_l0000dooooo`;o00002?ooool2o`0000Oooooo0_l0000;ooooo`;o00003oooool2o`0003Kooooo
0_l00020ooooo`007_ooool00ol0003oooooooooo`0Vooooo`;o0000;?ooool2o`0000Kooooo0_l0
000Aooooo`;o00002_ooool3o`0004_ooooo0_l0000/ooooo`;o0000C_ooool001kooooo00?o0000
ooooooooool09_ooool2o`0002Sooooo0_l00002ooooo`;o00009Oooool2o`0004cooooo0_l0000/
ooooo`;o00003Oooool2o`0003oooooo000Nooooo`03o`000?oooooooooo053ooooo0_l00006oooo
o`;o0000J?ooool2o`0004;ooooo0_l0000oooooo`007_ooool00ol0003oooooooooo`19ooooo`;o
00003Oooool2o`0006Sooooo0_l00023ooooo`007_ooool00ol0003oooooooooo`0cooooo`;o0000
5?ooool2o`0001oooooo0_l0000Uooooo`;o0000L?ooool2o`0004;ooooo000Nooooo`03o`000?oo
oooooooo03?ooooo0_l0000eooooo`;o00009Oooool2o`00073ooooo0_l00012ooooo`007_ooool0
0ol0003oooooooooo`1?ooooo`;o00001oooool2o`00013ooooo0_l0001Wooooo`;o0000L_ooool0
01kooooo00?o0000ooooooooool0C_ooool3o`0000Oooooo0_l0001Sooooo`;o00005?ooool2o`00
06cooooo0_l00004ooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o0000<_ooool2o`0000Oo
oooo0_l0001]ooooo`;o0000P_ooool2o`0000Cooooo000Nooooo`03o`000?oooooooooo00kooooo
0_l000000ooooooo0000o`00000Sooooo`;o00003Oooool2o`000?oooooo0Oooool001kooooo0_l0
000?ooooo`;o00003?ooool2o`0001Sooooo0_l0001Zooooo`;o0000Xoooool001kooooo00?o0000
ooooooooool07?ooool2o`0002oooooo0_l0000Rooooo`;o0000;oooool2o`00053ooooo0_l0001A
ooooo`007_ooool00ol0003oooooooooo`0nooooo`;o00003Oooool2o`0000;ooooo0_l0000Noooo
o`?o0000AOooool2o`0003Wooooo0_l0000Cooooo`;o0000??ooool001kooooo00?o0000oooooooo
ool0?_ooool2o`0000[ooooo0_l00005ooooo`;o00007oooool2o`0000?ooooo0_l00010ooooo`;o
00002Oooool2o`0004?ooooo0_l0000looooo`007_ooool00ol0003oooooooooo`1:ooooo`;o0000
7oooool2o`0000[ooooo0_l0001;ooooo`;o0000POooool001kooooo00?o0000ooooooooool0Jooo
ool2o`00013ooooo0_l0001Qooooo`;o0000IOooool001kooooo00?o0000ooooooooool0BOooool2
o`0003;ooooo0_l0001Qooooo`;o0000IOooool001kooooo00?o0000ooooooooool03oooool2o`00
02_ooooo0_l00005ooooo`;o00001?ooool2o`0001?ooooo0_l0000;ooooo`;o0000f_ooool001ko
oooo00?o0000ooooooooool03oooool2o`0002_ooooo0_l00005ooooo`;o00006Oooool2o`0000Co
oooo0_l00005ooooo`;o0000f_ooool001kooooo00?o0000ooooooooool0>oooool2o`0001Cooooo
0_l0000Aooooo`;o00002Oooool2o`0001?ooooo0_l00027ooooo`;o0000;Oooool2o`0000Wooooo
000Nooooo`03o`000?oooooooooo01kooooo0_l0000Kooooo`;o00005?ooool2o`0000Wooooo0_l0
000Aooooo`;o00004oooool2o`0008Oooooo0_l0000]ooooo`;o00002Oooool001kooooo00?o0000
ooooooooool07_ooool2o`0003cooooo0_l0000?ooooo`Co00001Oooool2o`000<oooooo000Noooo
o`03o`000?oooooooooo06gooooo0_l00007ooooo`;o0000:?ooool2o`000:Gooooo000Nooooo`03
o`000?oooooooooo04?ooooo0_l0000Uooooo`;o0000=?ooool2o`000:Gooooo000Nooooo`03o`00
0?oooooooooo03_ooooo0_l00006ooooo`;o00009Oooool2o`000=_ooooo000Nooooo`03o`000?oo
oooooooo03_ooooo0_l0000Hooooo`;o0000l?ooool001kooooo0_l00015ooooo`;o00003oooool2
o`0008Cooooo0_l0001Zooooo`007_ooool00ol0003oooooooooo`14ooooo`;o0000Eoooool2o`00
03cooooo0_l0001Zooooo`007_ooool00ol0003oooooooooo`2Mooooo`;o0000Z?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`13ooooo`;o0000oooo
ool3ooooo`007_ooool00ol0003oooooooooo`13ooooo`;o0000ooooool3ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooooa3ooooo0_l0
000fooooo`007_ooool00ol0003oooooooooo`3ooooooa3ooooo0_l0000fooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0Poooool2o`0007;ooooo0_l0001>ooooo`000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`23ooooo`;o0000
L_ooool2o`0004kooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo
00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0002=ooooo`;o
00007?ooool2o`0001Kooooo0_l00022ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`0Cooooo`;o0000N?ooool2o`0000Go
oooo0_l0000Eooooo`;o00005_ooool2o`0008;ooooo0003ooooo`05o`000?ooooooooooooooool0
00003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo01?ooooo0_l0001oooooo`;o
0000/Oooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0@_ooool2o`000?oooooo1?ooool000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`12oooo
o`;o0000ooooool4ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo02Sooooo0_l0001iooooo`;o00004oooool2
o`0008gooooo000Nooooo`03o`000?oooooooooo02Sooooo0_l0001iooooo`;o00004oooool2o`00
04Wooooo0_l00012ooooo`007_ooool00ol0003oooooooooo`3oooooo`Cooooo0_l00012ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`1Sooooo`;o0000h_ooool001kooooo00?o0000
ooooooooool0Hoooool2o`000>;ooooo000Nooooo`03o`000?oooooooooo0;Oooooo0_l0002>oooo
o`007_ooool2o`000;Sooooo0_l0002>ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0;_ooooo0_l0002:ooooo`007_ooool00ol0003oooooooooo`2k
ooooo`;o0000R_ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`2fooooo`;o0000Soooool001kooooo00?o0000ooooooooool0]_ooool2o`0008oooooo
000Nooooo`03o`000?oooooooooo02Wooooo0_l0003ooooooagooooo000Nooooo`03o`000?oooooo
oooo02Wooooo0_l0003ooooooagooooo000Nooooo`03o`000?oooooooooo09kooooo0_l0000]oooo
o`;o0000N?ooool001kooooo00?o0000ooooooooool0W_ooool2o`0002gooooo0_l0001hooooo`00
7_ooool00ol0003oooooooooo`0mooooo`;o0000ooooool9ooooo`007_ooool00ol0003ooooooooo
o`0mooooo`;o00003_ooool2o`0001_ooooo0_l0003Kooooo`007_ooool00ol0003oooooooooo`1=
ooooo`;o00006oooool2o`0008[ooooo0_l0001?ooooo`007_ooool00ol0003oooooooooo`3foooo
o`;o0000Coooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000>3ooooo
0_l0001Vooooo`007_ooool00ol0003oooooooooo`3Oooooo`;o0000I_ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0Loooool2o`000=;ooooo
000Nooooo`03o`000?oooooooooo07?ooooo0_l0003Booooo`007_ooool00ol0003oooooooooo`30
ooooo`;o0000QOooool001kooooo00?o0000ooooooooool0`?ooool2o`0008Gooooo000Nooooo`03
o`000?oooooooooo06gooooo0_l0003Hooooo`007_ooool00ol0003oooooooooo`1]ooooo`;o0000
f?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooo
oom9ooooo`007_ooool00ol0003oooooooooo`1oooooo`;o0000a_ooool001kooooo00?o0000oooo
ooooool0Ooooool2o`0007Cooooo0_l0001@ooooo`007_ooool00ol0003oooooooooo`3eooooo`;o
0000D?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0=_ooool2o`000?oooooo4?ooool001kooooo00?o0000ooooooooool0=_ooool2o`000?oo
oooo4?ooool001kooooo00?o0000ooooooooool0Z?ooool2o`0009gooooo000Nooooo`03o`000?oo
oooooooo0:Sooooo0_l0002Mooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0Q?ooool2o`0005co
oooo0_l0001Sooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o
000000?o410@ooooooooool01?ooool00ol0003oooooooooo`24ooooo`;o0000G?ooool2o`0006?o
oooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@
41002oooool5o`0000Kooooo0ol00018ooooo`;o0000oOooool000?ooooo00Go0000oooooooooooo
ooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0B?ooool2o`00
0?gooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo00_ooooo0_l0003ooooooc_ooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo00_ooooo0_l0003o
oooooc_ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007
ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=
ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`0looooo`;o0000oooo
ool:ooooo`007_ooool00ol0003oooooooooo`0looooo`;o0000ooooool:ooooo`007_ooool00ol0
003oooooooooo`17ooooo`;o0000X_ooool2o`0005[ooooo000Nooooo`03o`000?oooooooooo04Oo
oooo0_l0001eooooo`;o0000:oooool2o`0005[ooooo000Nooooo`03o`000?oooooooooo03gooooo
0_l0001oooooo`;o0000Qoooool001kooooo00?o0000ooooooooool0?Oooool2o`000?oooooo2Ooo
ool001kooooo00?o0000ooooooooool0ZOooool2o`0000_ooooo0_l0002?ooooo`007_ooool00ol0
003oooooooooo`2Yooooo`;o00002oooool2o`0008oooooo000Nooooo`;o0000=?ooool2o`0001Co
oooo0_l0003looooo`007_ooool00ol0003oooooooooo`0cooooo`;o00005?ooool2o`000?cooooo
000Nooooo`03o`000?oooooooooo043ooooo0_l0003oooooo`Kooooo000Nooooo`03o`000?oooooo
oooo043ooooo0_l0003oooooo`Kooooo000Nooooo`03o`000?oooooooooo05cooooo0_l0003Yoooo
o`007_ooool00ol0003oooooooooo`1Looooo`;o0000jOooool001kooooo00?o0000ooooooooool0
oooooolGooooo`;o0000;oooool001kooooo00?o0000ooooooooool0oooooolGooooo`;o0000;ooo
ool001kooooo00?o0000ooooooooool0EOooool2o`0001Sooooo0_l0001Iooooo`;o0000Noooool0
01kooooo00?o0000ooooooooool0EOooool2o`0001Sooooo0_l0001Iooooo`;o0000AOooool2o`00
03Cooooo000Nooooo`03o`000?oooooooooo00cooooo0_l0001Zooooo`;o0000Uoooool2o`0003Co
oooo000Nooooo`03o`000?oooooooooo00cooooo0_l0000dooooo`;o0000=?ooool2o`000<gooooo
000Nooooo`03o`000?oooooooooo04;ooooo0_l0002Cooooo`;o0000K_ooool001kooooo00?o0000
ooooooooool0eoooool2o`0006kooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0=_ooool2o`0005kooooo0_l0002_ooooo`007_ooool2o`0000kooooo
0_l0000Wooooo`;o00005_ooool2o`0004Kooooo0_l0002_ooooo`007_ooool00ol0003ooooooooo
o`0=ooooo`;o0000?oooool2o`000?Oooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oolDooooo`;o0000<_ooool001kooooo00?o0000ooooooooool0oooooolDooooo`;o0000<_ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`0nooooo`;o
0000E_ooool2o`000:oooooo000Nooooo`03o`000?oooooooooo03kooooo0_l0001Fooooo`;o0000
[oooool001kooooo0ol0001`ooooo`;o00001_ooool2o`000<gooooo000Nooooo`?o0000L?ooool2
o`0000Kooooo0_l0003=ooooo`007_ooool00ol0003oooooooooo`3cooooo`;o0000?Oooool2o`00
01?ooooo000Nooooo`03o`000?oooooooooo08Kooooo0_l0001[ooooo`;o0000>Oooool2o`0000;o
oooo0_l0000Cooooo`007_ooool00ol0003oooooooooo`26ooooo`;o0000Uoooool2o`0000gooooo
0_l0000Gooooo`007_ooool2o`0005?ooooo0_l0003;ooooo`;o00009_ooool001kooooo00?o0000
ooooooooool0D?ooool4o`000??ooooo000Nooooo`03o`000?oooooooooo053ooooo0_l0001Loooo
o`;o0000Uoooool001kooooo00?o0000ooooooooool0Noooool2o`00037ooooo0_l0002Gooooo`00
7_ooool00ol0003oooooooooo`0Eooooo`;o00006oooool2o`0000cooooo0_l0000iooooo`;o0000
3?ooool2o`000;cooooo000Nooooo`03o`000?oooooooooo01Gooooo0_l0000Iooooo`Ko00002_oo
ool2o`0001;ooooo0_l0000cooooo`;o0000_?ooool001kooooo00?o0000ooooooooool0;_ooool4
o`0000;ooooo0_l0000Nooooo`;o0000lOooool001kooooo00?o0000ooooooooool0;_ooool2o`00
0?oooooo6?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3Xooooo`;o0000GOooool001kooooo00?o0000ooooooooool0>_ooool2o`00087ooooo0_l0
000Yooooo`;o0000A_ooool2o`0001Gooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l0000A
ooooo`;o00005?ooool2o`0006_ooooo0_l0000<ooooo`;o0000Hoooool2o`0001Gooooo000Noooo
o`03o`000?oooooooooo02Oooooo0_l0000Wooooo`;o0000=oooool2o`00043ooooo0_l00019oooo
o`;o00006?ooool2o`0001Gooooo000Nooooo`03o`000?oooooooooo08Wooooo0_l0002;ooooo`;o
0000;oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko
<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool02?ooool2o`000?oooooo?_ooool000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So
8B4Q00Kooooo00?o0000ooooooooool02?ooool2o`0003?ooooo0_l0003oooooo`Wooooo0003oooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
000mooooo`;o0000ooooool9ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go
0000oiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go
0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGo
QhN7ooooo`08ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0=oooool2o`0005So
oooo0_l0002Xooooo`;o00002_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04
olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool00_l0000eooooo`;o00000_ooool2o`00
05Cooooo0_l00012ooooo`?o0000GOooool2o`0000Cooooo0_l0000:ooooo`007_ooool00ol0003o
ooooooooo`02o`0003Kooooo0_l000000ooooooo0000o`00002<ooooo`;o00002_ooool3o`0000[o
oooo0_l0001Aooooo`;o00004?ooool001kooooo00?o0000ooooooooool0>?ooool2o`0003cooooo
0_l0001Aooooo`;o00005oooool2o`0006?ooooo000Nooooo`03o`000?oooooooooo07Kooooo0_l0
0005ooooo`;o0000b?ooool001kooooo00?o0000ooooooooool0OOooool2o`000<Sooooo000Noooo
o`03o`000?oooooooooo06Oooooo0_l00002ooooo`;o0000f_ooool001kooooo00?o0000oooooooo
ool0Ioooool2o`0000;ooooo0_l0001Zooooo`;o0000K_ooool001kooooo00?o0000ooooooooool0
J_ooool2o`0006_ooooo0_l00009ooooo`;o00002oooool2o`0005Kooooo000Nooooo`03o`000?oo
oooooooo05cooooo0_l0000<ooooo`;o0000M_ooool2o`0000_ooooo0_l00005ooooo`;o0000Cooo
ool001kooooo00?o0000ooooooooool0G?ooool2o`0009Sooooo0_l0001?ooooo`007_ooool00ol0
003oooooooooo`1Cooooo`;o0000F_ooool2o`0009Kooooo000Nooooo`03o`000?oooooooooo03Ko
oooo0_l0000Kooooo`;o0000F_ooool2o`0009Kooooo000Nooooo`;o0000=oooool2o`0000gooooo
0_l0003Hooooo`;o00009_ooool001kooooo00?o0000ooooooooool0AOooool2o`000=Sooooo0_l0
000Vooooo`007_ooool00ol0003oooooooooo`1Xooooo`;o0000__ooool2o`0001gooooo000Noooo
o`03o`000?oooooooooo06Sooooo0_l0002nooooo`;o00007Oooool001kooooo00?o0000oooooooo
ool04?ooool2o`00033ooooo0_l00003ooooo`;o00002?ooool2o`000?Cooooo000Nooooo`03o`00
0?oooooooooo00oooooo0ol0000`ooooo`;o00000oooool2o`0000Sooooo0_l00002ooooo`;o0000
l?ooool001kooooo00?o0000ooooooooool03oooool2o`0004Cooooo0_l0000Jooooo`;o0000e?oo
ool001kooooo00?o0000ooooooooool03Oooool2o`0002Gooooo0_l0000kooooo`;o0000e?ooool0
01kooooo00?o0000ooooooooool03Oooool2o`0002Gooooo0_l0000Xooooo`;o00004Oooool2o`00
0=Cooooo000Nooooo`03o`000?oooooooooo05kooooo0_l00008ooooo`;o0000W_ooool2o`0003go
oooo000Nooooo`03o`000?oooooooooo06Sooooo0_l0000:ooooo`;o00000oooool2o`0008gooooo
0_l0000mooooo`007_ooool00ol0003oooooooooo`0kooooo`;o00003?ooool2o`0002Wooooo0_l0
0003ooooo`;o0000c?ooool001kooooo00?o0000ooooooooool03?ooool2o`0002gooooo0_l0000<
ooooo`;o0000o?ooool001kooooo00?o0000ooooooooool03?ooool2o`000?oooooo>_ooool001ko
oooo00?o0000ooooooooool03?ooool2o`0002;ooooo0_l0000Eooooo`;o0000D_ooool2o`000:[o
oooo000Nooooo`03o`000?oooooooooo01Wooooo0_l0000Dooooo`?o00001Oooool2o`0000kooooo
0_l00016ooooo`;o00002Oooool3o`000:[ooooo000Nooooo`;o00006_ooool2o`0001Cooooo0_l0
0006ooooo`;o0000E_ooool2o`0000Wooooo0_l00021ooooo`;o0000:?ooool001kooooo00?o0000
ooooooooool0<?ooool2o`0002Cooooo0_l0000gooooo`;o00007Oooool2o`0006gooooo0_l0000X
ooooo`007_ooool00ol0003oooooooooo`0^ooooo`Co00009?ooool2o`0005Kooooo0_l0002Goooo
o`007_ooool00ol0003oooooooooo`0Looooo`Go00003?ooool3o`000?oooooo6?ooool001kooooo
00?o0000ooooooooool07?ooool5o`0000cooooo0_l0001]ooooo`;o00003_ooool2o`0009Wooooo
000Nooooo`03o`000?oooooooooo01Oooooo0ol00002ooooo`;o0000<?ooool2o`0004cooooo0_l0
000>ooooo`;o0000Noooool2o`0001cooooo000Nooooo`03o`000?oooooooooo01Oooooo0ol0000`
ooooo`;o00000_ooool2o`000=Wooooo0_l0000Looooo`007_ooool00ol0003oooooooooo`0ioooo
o`;o00002Oooool2o`0000Cooooo0_l0003kooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o
00008_ooool2o`0000Wooooo0_l000000ooooooo0000o`00000:ooooo`;o0000G_ooool2o`0001ko
oooo0_l0000@ooooo`;o0000H?ooool001kooooo00?o0000ooooooooool05Oooool2o`00033ooooo
0_l0000:ooooo`;o0000@oooool2o`0000Sooooo0_l0000?ooooo`;o00007_ooool2o`00013ooooo
0_l0001Pooooo`007_ooool2o`0000kooooo0_l0000Jooooo`;o00002oooool2o`0000oooooo0_l0
000Gooooo`;o0000=_ooool2o`0000Sooooo0_l0002Sooooo`007_ooool2o`0000kooooo0_l0000@
ooooo`;o00002?ooool2o`0000_ooooo0_l0000?ooooo`;o00001oooool2o`0000kooooo0_l0000H
ooooo`;o00002?ooool2o`000<7ooooo000Nooooo`03o`000?oooooooooo01oooooo0_l00005oooo
o`;o00006Oooool2o`0000Sooooo0_l00003ooooo`;o00004?ooool4o`0001Cooooo0_l00008oooo
o`;o0000`Oooool001kooooo00?o0000ooooooooool09_ooool4o`0000Oooooo0ol0000;ooooo`Co
00002?ooool2o`0001Gooooo1?l0003Qooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o0000
3?ooool2o`0000Gooooo0_l00007ooooo`?o00002oooool2o`0006Wooooo0_l0002Kooooo`007_oo
ool00ol0003oooooooooo`0Cooooo`;o00002oooool3o`0002cooooo0_l00002ooooo`;o00002ooo
ool2o`0000cooooo0_l0000<ooooo`;o0000;?ooool2o`0002cooooo0_l0001]ooooo`007Oooool3
o`00027ooooo0_l0000Jooooo`;o00003?ooool2o`0000?ooooo0_l00002ooooo`;o00002oooool2
o`0000cooooo0_l0000<ooooo`;o0000F_ooool2o`0006gooooo000Mooooo`;o00001?ooool2o`00
03Sooooo0_l00009ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`00003foooo
o`007_ooool00ol0003oooooooooo`02ooooo`;o00004Oooool2o`0001Oooooo0_l000000ooooooo
0000o`00000Dooooo`;o00000oooool2o`0001;ooooo0_l0003Uooooo`007_ooool00ol0003ooooo
ooooo`0Eooooo`;o00005oooool2o`000003ooooool0003o000000Wooooo0_l0000Aooooo`;o0000
0_ooool2o`0000_ooooo0_l0000Qooooo`Co0000Ooooool2o`0003oooooo000Nooooo`03o`000?oo
oooooooo03cooooo0_l0000Aooooo`;o00000_ooool2o`0000oooooo0_l0000:ooooo`;o00004Ooo
ool4o`0002Kooooo0_l0000Iooooo`;o0000=oooool2o`0000?ooooo0_l0000hooooo`;o00001Ooo
ool001kooooo00Co0000ooooool0003o00007?ooool2o`0002;ooooo0_l00002ooooo`;o00006ooo
ool4o`0000[ooooo0_l0000kooooo`;o00006Oooool2o`0003Oooooo0_l0000Rooooo`;o00006Ooo
ool2o`0000Gooooo000Nooooo`04o`000?oooooo0000o`0001?ooooo0_l00007ooooo`;o00001Ooo
ool2o`0001_ooooo0_l00002ooooo`;o00006oooool2o`0000cooooo0_l0002cooooo`;o00008?oo
ool001kooooo00?o0000ooooooooool02?ooool2o`0000[ooooo0_l0000>ooooo`;o00001_ooool2
o`0004;ooooo0ol00009ooooo`;o0000bOooool001kooooo00?o0000ooooooooool02?ooool2o`00
02;ooooo0_l0000Dooooo`;o00008?ooool2o`0000Wooooo1?l00002ooooo`;o00001Oooool2o`00
0<Wooooo000Nooooo`03o`000?oooooooooo023ooooo0_l0000>ooooo`;o00004?ooool2o`0001So
oooo0_l00006ooooo`;o00002Oooool2o`0000Cooooo0_l0000Eooooo`;o00004Oooool2o`0009Ko
oooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o00003_ooool2o`0000kooooo
0_l00007ooooo`;o00008Oooool2o`0002kooooo0_l0000Aooooo`;o0000U_ooool2o`0000kooooo
000Nooooo`03o`000?oooooooooo013ooooo0_l0000Vooooo`?o00002Oooool2o`0001Wooooo0_l0
0002ooooo`;o00009oooool2o`000;Wooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l00004
ooooo`;o00005oooool2o`0000[ooooo0_l00008ooooo`;o00003oooool2o`0000;ooooo0_l0000:
ooooo`;o00006oooool2o`000;Wooooo000Nooooo`03o`000?oooooooooo01Oooooo1?l00004oooo
o`;o00002_ooool4o`0001oooooo0_l0000;ooooo`;o00003_ooool2o`0000;ooooo0_l0003Foooo
o`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000
ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0Gooooo`Co00003oooool5o`0000Gooooo0_l0000F
ooooo`Ko00002Oooool2o`0000Gooooo0_l00007ooooo`Co00001?ooool2o`000:kooooo0_l0000R
ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9So
oooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0Gooooo`Co00003Oooool4o`0000Sooooo0_l0
0004ooooo`;o00002_ooool2o`0000?ooooo1ol000000ooooooo0000o`000002o`0000;ooooo1?l0
0004ooooo`?o00001?ooool2o`0000?ooooo0_l00004ooooo`;o0000Joooool2o`00047ooooo0_l0
000Rooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooooooooooo
o`000006ooooo`?o00003oooool2o`0000Kooooo0ol00002ooooo`;o00002_ooool2o`0000kooooo
1?l00009ooooo`?o00000oooool@o`0000Gooooo0ol00005ooooo`;o00003oooool2o`0000gooooo
0_l0000Tooooo`;o0000<?ooool2o`0006Gooooo0003ooooo`05o`000?ooooooooooooooool00000
2oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000ooooooooool03oooool2o`0000Oo
oooo0_l00002ooooo`;o00006_ooool2o`0000Wooooo1?l00005ooooo`go000000?oooooo`000?l0
00001?ooool2o`0000cooooo0_l00009ooooo`;o00002_ooool2o`000003ooooool0003o000002Co
oooo0_l0002Gooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0
003o0000olc<c006ooooo`03o`000?oooooooooo01Sooooo0_l0000Yooooo`;o00001_ooool9o`00
0003ooooool0003o000000?ooooo0_l000001?oooooo0000o`000?ooool2o`0000cooooo0_l00000
0ooooooo0000o`00000Booooo`;o0000?Oooool2o`00087ooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool06?oo
ool2o`0002oooooo1Ol00004ooooo`Co000000?oooooo`000?l000001?ooool2o`00017ooooo0ol0
000booooo`;o00007Oooool2o`00087ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool05Oooool2o`000003oooo
ool0003o000002Oooooo0_l00006ooooo`;o000000?oooooo`000?l000000_l00003ooooo`?o0000
00?oooooo`000?l000000ol0000Booooo`Co0000<oooool2o`000:3ooooo0003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000oooooooo
ool04_ooool2o`000004ooooool0003o0000ooooo`;o00001Oooool2o`0001Cooooo0_l0000:oooo
o`;o00000oooool2o`000004ooooool0003o0000ooooo`Co000000Coooooo`000?l0003ooooo1?l0
00001?oooooo0000o`000?l0000;ooooo`?o00001?ooool2o`000003ooooool0003o000003;ooooo
0_l0002Pooooo`007_ooool00ol0003oooooooooo`0Booooo`;o00001?ooool3o`0000Cooooo0_l0
000:ooooo`;o00002?ooool3o`0000gooooo1_l00003ooooo`;o000000Coooooo`000?l0003ooooo
1?l00004ooooo`;o00000_ooool2o`0000Gooooo0ol00007ooooo`;o0000<_ooool2o`000:3ooooo
000Nooooo`03o`000?oooooooooo01Sooooo0ol00009ooooo`;o00001Oooool2o`0000Wooooo0_l0
0009ooooo`;o00000_ooool4o`0000?ooooo1?l00004ooooo`;o00001_ooool2o`0000;ooooo0_l0
0002ooooo`;o00008_ooool2o`000;?ooooo1?l00006ooooo`007_ooool00ol0003oooooooooo`0;
ooooo`;o00002oooool5o`0000Oooooo0_l00006ooooo`;o00004Oooool5o`0000;ooooo1Ol00000
0ooooooo0000o`000002o`0000;ooooo1Ol0000<ooooo`?o00002oooool2o`0001Gooooo0_l0002c
ooooo`Co00001_ooool001kooooo00?o0000ooooooooool02oooool3o`0000_ooooo1?l0000?oooo
o`;o00002Oooool2o`0000Kooooo4?l00002ooooo`Ko00003?ooool2o`0000cooooo0_l0003Doooo
o`007_ooool00ol0003oooooooooo`0<ooooo`;o00002oooool4o`0001[ooooo0_l00003ooooo`Ko
00000_ooool9o`0000Cooooo1?l0003booooo`007_ooool00ol0003oooooooooo`0Eooooo`;o0000
0oooool3o`000003ooooool0003o000001?ooooo0_l00007ooooo`Ko00001?ooool2o`0000;ooooo
0_l000000ooooooo0000o`000003ooooo`Co0000Roooool2o`0006Cooooo000Nooooo`03o`000?oo
oooooooo01Gooooo0_l00007ooooo`;o00001_ooool2o`0000Wooooo1?l0000:ooooo`?o000000Co
ooooo`000?l0003ooooo2Ol000000ooooooo0000o`000004o`0000Sooooo0_l00007ooooo`;o0000
00?oooooo`000?l00000MOooool2o`0006Cooooo000Nooooo`03o`000?oooooooooo027ooooo0_l0
0003ooooo`;o00000oooool2o`0000Cooooo0_l00007ooooo`;o00000oooool3o`000003ooooool0
003o000000go000000?oooooo`000?l000002Oooool2o`0000Oooooo0_l000000ooooooo0000o`00
000Eooooo`;o0000a?ooool001kooooo00?o0000ooooooooool08Oooool2o`0000Sooooo0_l00004
ooooo`;o00001oooool2o`0000Cooooo0_l00002ooooo`Ko00000oooool4o`0000Gooooo0_l00003
ooooo`;o00002Oooool2o`0000cooooo0_l0000;ooooo`;o0000a?ooool001kooooo00?o0000oooo
ooooool0<Oooool3o`0000_ooooo0ol00003ooooo`Co00001?ooool4o`0000Gooooo0_l00002oooo
o`?o00000oooool2o`0000Cooooo0_l0000<ooooo`;o0000??ooool2o`0001;ooooo0_l0001ooooo
o`007_ooool00ol0003oooooooooo`0Hooooo`;o00004?ooool2o`000005ooooool0003o0000o`00
0?ooool00ol00009ooooo`Co00000_ooool2o`000003ooooool0003o000000;ooooo0ol0000=oooo
o`;o00001?ooool4o`0004kooooo0_l0000Booooo`;o0000Ooooool001kooooo0_l0000Iooooo`;o
00004?ooool2o`000005ooooool0003o0000o`000?ooool00ol00009ooooo`;o00001?ooool5o`00
00;ooooo0ol000000ooooooo0000o`000002o`00013ooooo0_l0000@ooooo`;o0000I?ooool2o`00
06_ooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l00004ooooo`;o00005oooool2o`00013o
oooo1Ol000001?oooooo0000o`000?l00002ooooo`Co00008_ooool2o`0000Cooooo0_l0001Noooo
o`;o00002_ooool2o`0005oooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l000001?oooooo
0000o`000?ooool2o`0001?ooooo0_l0000Gooooo`;o000000Coooooo`000?l0003ooooo1?l0000B
ooooo`;o00005_ooool2o`0006[ooooo0_l0001Oooooo`007_ooool00ol0003oooooooooo`0Eoooo
o`;o00005Oooool3o`0000Cooooo0_l00002ooooo`;o00001?ooool4o`0000Gooooo0_l000000ooo
oooo0000o`000005o`0000Kooooo0_l0000:ooooo`;o0000hoooool001kooooo00?o0000oooooooo
ool0;?ooool3o`0000Cooooo0_l00002ooooo`;o00001?ooool5o`0000Cooooo0_l00003ooooo`;o
000000?oooooo`000?l000001_ooool4o`0000Sooooo0_l00005ooooo`;o00001Oooool2o`000:go
oooo0_l0000Vooooo`007_ooool00ol0003oooooooooo`0cooooo`;o00002_ooool3o`0000Cooooo
0_l00002ooooo`?o00001?ooool2o`0000Gooooo0_l00005ooooo`;o000000?oooooo`000?l00000
1Oooool2o`0000Gooooo0_l0001Vooooo`;o0000AOooool2o`0002Kooooo000Nooooo`03o`000?oo
oooooooo02;ooooo0_l0000?ooooo`?o00003Oooool2o`0000;ooooo0_l000000ooooooo0000o`00
0002o`0000?ooooo0_l0000;ooooo`?o0000Moooool2o`0006gooooo000Nooooo`03o`000?oooooo
oooo017ooooo0_l0000?ooooo`;o00001_ooool2o`0000Sooooo0_l0000=ooooo`;o000000Gooooo
o`000?l0003o0000ooooo`04o`000003ooooool0003o000000;o00002oooool2o`0001?ooooo0_l0
002Uooooo`;o0000:oooool001kooooo00?o0000ooooooooool04Oooool2o`0001Cooooo0_l00000
0ooooooo0000o`000006ooooo`;o00003_ooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2
o`0000Cooooo0_l00005ooooo`;o00002oooool2o`0000Sooooo1?l0000_ooooo`;o0000;_ooool2
o`0004;ooooo0_l0000[ooooo`007_ooool00ol0003oooooooooo`0Wooooo`;o00001oooool5o`00
00Sooooo0_l00003ooooo`;o00001oooool2o`0000Gooooo0_l000000ooooooo0000o`000005oooo
o`;o00002_ooool6o`000003ooooool0003o000000Cooooo0_l00007ooooo`;o00009_ooool2o`00
02kooooo0_l0001_ooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o00004?ooool2o`0001;o
oooo1ol00006ooooo`;o00000oooool2o`0000kooooo0_l0000Dooooo`_o00002oooool2o`0000_o
oooo0_l0001Aooooo`;o0000C_ooool2o`000003ooooool0003o000001Cooooo000Nooooo`03o`00
0?oooooooooo00[ooooo0_l0000@ooooo`;o00005oooool2o`0001_ooooo0_l0000Fooooo`Wo0000
6?ooool3o`0004gooooo0_l000000ooooooo0000o`00001>ooooo`;o000000?oooooo`000?l00000
5?ooool001kooooo00?o0000ooooooooool00_ooool2o`0001Wooooo0_l0000Nooooo`;o00005Ooo
ool2o`0001?ooooo2Ol0000Jooooo`;o00003?ooool4o`0003gooooo0_l0001=ooooo`;o00006ooo
ool001kooooo00?o0000ooooooooool00_ooool2o`0001Wooooo0_l0000Nooooo`;o00005Oooool2
o`0000Cooooo0_l00008ooooo`;o00000oooool9o`0002Sooooo1?l0002<ooooo`;o00006oooool0
01kooooo00?o0000ooooooooool03oooool2o`0002cooooo0_l0000Booooo`;o00001oooool2o`00
00?ooooo0_l00003ooooo`;o00001Oooool2o`000003ooooool0003o000000;o00001Oooool2o`00
00[ooooo0_l00007ooooo`;o00001_ooool2o`000;7ooooo000Nooooo`03o`000?oooooooooo00oo
oooo0_l0000;ooooo`;o00001oooool2o`0002;ooooo0_l000001?oooooo0000o`000?ooool4o`00
00Wooooo0_l000000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l000000oooool4o`00
00Gooooo0_l0000:ooooo`;o00001oooool2o`0000Kooooo0_l0002<ooooo`;o00008oooool001ko
oooo0_l0000Mooooo`;o00001oooool2o`0002;ooooo0_l000001?oooooo0000o`000?ooool2o`00
00_ooooo0_l00008ooooo`So000000Coooooo`000?l0003ooooo0_l0000Iooooo`;o0000Toooool3
o`0002;ooooo000Nooooo`?o0000AOooool2o`0000Sooooo0_l0000:ooooo`;o00002Oooool8o`00
00Cooooo0_l0000Iooooo`;o0000U?ooool2o`0002;ooooo000Nooooo`?o0000;Oooool2o`0000[o
oooo0_l000000ooooooo0000o`000007ooooo`;o00000_ooool2o`00013ooooo0_l00002ooooo`;o
00000_ooool:o`000=[ooooo000Nooooo`03o`000?oooooooooo02gooooo0_l0000:ooooo`;o0000
00?oooooo`000?l000002oooool2o`0000Gooooo0_l0000=ooooo`?o000000?oooooo`000?l00000
2?l0003Jooooo`007_ooool00ol0003oooooooooo`14ooooo`;o000000Coooooo`000?l0003o0000
1_ooool4o`0000cooooo0_l00004ooooo`Oo00007?ooool2o`0006Oooooo0_l0001Cooooo`007_oo
ool00ol0003oooooooooo`0Tooooo`;o00003oooool2o`0000Gooooo0_l00006ooooo`;o000000Co
ooooo`000?l0003o00001oooool4o`0000_ooooo0ol00003ooooo`Ko000000?oooooo`000?l00000
1_ooool2o`0001;ooooo0_l0001Wooooo`;o0000Doooool001kooooo00?o0000ooooooooool09?oo
ool2o`0000[ooooo0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o000001?ooooo1?l0
0009ooooo`Go00000oooool2o`000003ooooool0003o000000;ooooo0_l00006ooooo`;o00003Ooo
ool2o`0000;ooooo0_l00005ooooo`;o0000<_ooool2o`0003Kooooo0_l0000Mooooo`;o00007Ooo
ool2o`0000cooooo000Nooooo`03o`000?oooooooooo033ooooo0_l00007ooooo`;o00005_ooool2
o`0000Cooooo0_l00005ooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o
000000?ooooo0_l0000Eooooo`;o00000_ooool2o`0000Gooooo0_l0000Tooooo`;o00003?ooool2
o`0003Kooooo0_l0000Mooooo`;o00007Oooool2o`0000cooooo000Nooooo`03o`000?oooooooooo
01Sooooo0_l0000Jooooo`;o00006?ooool2o`000003ooooool0003o000000Cooooo0_l0000<oooo
o`;o000000?oooooo`000?l00000Boooool2o`0008Sooooo0_l00006ooooo`007_ooool00ol0003o
ooooooooo`0Hooooo`;o00006_ooool2o`0000;ooooo0_l0000Dooooo`;o00000_ooool3o`0000;o
oooo0_l00006ooooo`;o000000?oooooo`000?l00000:_ooool2o`000:oooooo0_l00006ooooo`00
7_ooool00ol0003oooooooooo`02o`0000;ooooo0_l0000booooo`;o00001oooool4o`0000gooooo
0ol0000:ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000Kooooo0_l0000?ooooo`;o
00003Oooool2o`0005cooooo0_l0001@ooooo`;o00001oooool001kooooo00?o0000ooooooooool0
0_l00002ooooo`;o0000>oooool4o`0001kooooo0_l000000ooooooo0000o`000006ooooo`;o0000
3oooool2o`0006_ooooo0_l00011ooooo`;o00003Oooool2o`0000Oooooo000Nooooo`03o`000?oo
oooooooo06Gooooo0_l00002ooooo`;o00001?ooool2o`00023ooooo0_l0001:ooooo`;o0000D?oo
ool2o`0001Kooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l0000Jooooo`;o00005_ooool2
o`0002Cooooo0_l00002ooooo`;o00001?ooool2o`00023ooooo0_l00019ooooo`?o0000??ooool2
o`0002[ooooo000Nooooo`03o`000?oooooooooo00_ooooo1?l0000Hooooo`;o00005_ooool2o`00
01oooooo0_l00005ooooo`;o00001oooool2o`0001;ooooo0_l0001Fooooo`;o0000?Oooool2o`00
02[ooooo000Nooooo`03o`000?oooooooooo00gooooo0_l0000@ooooo`;o00006_ooool2o`0001co
oooo0_l00005ooooo`Ko000000?oooooo`000?l000001oooool4o`00013ooooo0_l0002Fooooo`;o
0000:Oooool001kooooo0_l0000Pooooo`;o00006_ooool3o`0001;ooooo0_l00007ooooo`;o0000
0_ooool2o`000003ooooool0003o000000Co00002Oooool5o`0005[ooooo0_l0001<ooooo`;o0000
0oooool2o`0002Cooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0000`ooooo`;o00004_oo
ool2o`0000[ooooo0ol000000ooooooo0000o`000002ooooo`;o00002Oooool5o`0000gooooo0_l0
001;ooooo`;o0000DOooool2o`0002Cooooo000Nooooo`03o`000?oooooooooo00[ooooo0ol00017
ooooo`;o00001_ooool3o`0000Wooooo0_l00005ooooo`Go00003Oooool2o`000<Cooooo000Noooo
o`03o`000?oooooooooo00_ooooo0_l00004ooooo`;o00004oooool2o`0000oooooo0_l0000Koooo
o`Co00001Oooool3o`0000Sooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l0000Hoooo
o`;o0000^_ooool001kooooo00?o0000ooooooooool04Oooool2o`0001?ooooo0_l0000?ooooo`;o
00005oooool3o`0000;ooooo0ol00003ooooo`;o000000Coooooo`000?l0003ooooo0_l00003oooo
o`;o00001?ooool3o`0000;ooooo0_l0000Hooooo`;o0000^_ooool001kooooo00?o0000oooooooo
ool0D?ooool3o`0000?ooooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l00003ooooo`;o
00000oooool4o`0000Oooooo0_l0001<ooooo`;o0000POooool001kooooo00?o0000ooooooooool0
1_ooool2o`0003Gooooo0_l0000Aooooo`;o00001?ooool2o`000004ooooool0003o0000o`0000Co
oooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000;o00001oooool2o`0004co
oooo0_l0001fooooo`;o00002Oooool001kooooo00?o0000ooooooooool01_ooool2o`0000_ooooo
0_l0000Xooooo`;o00003oooool4o`0000Sooooo0_l000001?oooooo0000o`000?ooool2o`0000;o
oooo0_l00002ooooo`?o00004_ooool2o`000;gooooo0_l00009ooooo`007_ooool01?l0003ooooo
ooooooooool2o`00013ooooo0_l0000iooooo`;o00001?ooool4o`0000Gooooo0_l0000:ooooo`?o
00004Oooool2o`0004Sooooo0_l0001nooooo`007_ooool01?l0003oooooooooooooool2o`0000[o
oooo0_l00015ooooo`Go00004Oooool2o`0000Gooooo0_l0001Dooooo`;o0000O_ooool001kooooo
00?o0000ooooooooool03Oooool2o`0003Wooooo0_l000000ooooooo0000o`00000:ooooo`;o0000
3?ooool2o`0000Cooooo0_l00004ooooo`;o0000:?ooool2o`0009_ooooo0_l0000=ooooo`007_oo
ool00ol0003oooooooooo`0jooooo`;o00001_ooool2o`0000Cooooo0_l000000ooooooo0000o`00
000:ooooo`?o00002oooool2o`0000Cooooo0_l0000^ooooo`;o00006?ooool2o`00087ooooo0_l0
000=ooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o0000:?ooool2o`0000Kooooo0_l00007
ooooo`;o00002oooool2o`0000Wooooo0_l0001@ooooo`;o0000JOooool2o`0002Gooooo000Noooo
o`03o`000?oooooooooo013ooooo0_l0001<ooooo`;o00000oooool4o`0009Cooooo0_l0000Soooo
o`;o00009Oooool001Cooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo04ko
oooo0_l00002ooooo`;o00002_ooool2o`0000Gooooo0_l0000Tooooo`;o00003_ooool2o`0005ko
oooo0_l0000Qooooo`;o00009oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Xooooo`;o00009?ooool2o`0000;ooooo0_l00007ooooo`;o00002oooool2o`00027ooooo
0_l0000>ooooo`;o00001_ooool2o`0007Wooooo0_l0000Wooooo`005_ooool00ol0003ooooooooo
o`05ooooo`?o00003Oooool2o`0001Wooooo0_l000000ooooooo0000o`000002o`0002cooooo0_l0
000;ooooo`;o0000>Oooool2o`00083ooooo0_l0000Pooooo`005_ooool00ol0003oooooooooo`0E
ooooo`;o00007?ooool4o`000?Kooooo0_l0000Pooooo`005_ooool00ol0003oooooooooo`3ooooo
oe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0
oooooom@ooooo`005?ooool00omEEEGoIVIVo`00003ooooooe;ooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.07065 .80673 Mdot
.50568 .96748 Mdot
.3334 .87431 Mdot
.14933 .82793 Mdot
.29253 .94515 Mdot
.22451 .87817 Mdot
.24237 .03865 Mdot
.31921 .89044 Mdot
.16747 .83553 Mdot
.22398 .23116 Mdot
.32363 .8728 Mdot
.26372 .96624 Mdot
.35485 .91793 Mdot
.39243 .86428 Mdot
.27477 .87395 Mdot
.30007 .06322 Mdot
.32975 .18733 Mdot
.30317 .96739 Mdot
.08124 .79602 Mdot
.11605 .82913 Mdot
.56044 .76162 Mdot
.21894 .87795 Mdot
.35699 .92785 Mdot
.49724 .67752 Mdot
.18284 .80705 Mdot
.32256 .85777 Mdot
.23321 .80403 Mdot
.27008 .1649 Mdot
.32207 .91843 Mdot
.206 .83165 Mdot
.24664 .88984 Mdot
.26545 .87866 Mdot
.23846 .79719 Mdot
.36377 .5398 Mdot
.14682 .6797 Mdot
.22476 .82378 Mdot
.47789 .84863 Mdot
.84927 .95013 Mdot
.23661 .99894 Mdot
.22292 .78769 Mdot
.21409 .86427 Mdot
.14413 .84685 Mdot
.43566 .98581 Mdot
.68466 .52463 Mdot
.19764 .74725 Mdot
.19738 .84645 Mdot
.17943 .73026 Mdot
.30927 .92916 Mdot
.25391 .80167 Mdot
.25403 .10558 Mdot
.30525 .0466 Mdot
.35961 .76982 Mdot
.35908 .92789 Mdot
.25391 .96187 Mdot
.37845 .95241 Mdot
.29897 .89945 Mdot
.84366 .88178 Mdot
.34624 .92122 Mdot
.23708 .80673 Mdot
.09997 .71461 Mdot
.21924 .83051 Mdot
.30077 .8706 Mdot
.61558 .80459 Mdot
.17952 .82096 Mdot
.24256 .90345 Mdot
.19141 .88675 Mdot
.37409 .78111 Mdot
.23506 .80284 Mdot
.23861 .89204 Mdot
.75334 .93811 Mdot
.4866 .5456 Mdot
.29684 .88666 Mdot
.95583 .90475 Mdot
.24201 .42627 Mdot
.35789 .75978 Mdot
.84477 .93615 Mdot
.19708 .90153 Mdot
.25689 .6013 Mdot
.23983 .84231 Mdot
.33983 .88733 Mdot
.22098 .76681 Mdot
.43345 .74656 Mdot
.65975 .32114 Mdot
.31427 .88634 Mdot
.19755 .73268 Mdot
.71465 .62972 Mdot
.30671 .89516 Mdot
.22956 .77489 Mdot
.26092 .8877 Mdot
.26232 .80357 Mdot
.17368 .86358 Mdot
.7007 .68838 Mdot
.33441 .87823 Mdot
.11035 .5892 Mdot
.0739 .76079 Mdot
.28455 .7357 Mdot
.86507 .94475 Mdot
.19282 .70131 Mdot
.29861 .92942 Mdot
.14588 .96958 Mdot
.30065 .84442 Mdot
.27395 .01813 Mdot
.0481 .86484 Mdot
.45855 .0618 Mdot
.57287 .89844 Mdot
.34941 .93967 Mdot
.35212 .79354 Mdot
.33241 .95441 Mdot
.422 .83805 Mdot
.98533 .53084 Mdot
.51447 .89341 Mdot
.59265 .40199 Mdot
.22726 .75065 Mdot
.29463 .94324 Mdot
.16109 .68525 Mdot
.2013 .09725 Mdot
.43031 .7771 Mdot
.35659 .9137 Mdot
.39439 .83303 Mdot
.31493 .72747 Mdot
.23783 .77536 Mdot
.38044 .93475 Mdot
.33921 .76624 Mdot
.21476 .65552 Mdot
.26579 .07897 Mdot
.81401 .02845 Mdot
.47165 .93135 Mdot
.07715 .80373 Mdot
.32565 .51989 Mdot
.99101 .98782 Mdot
.6581 .92922 Mdot
.20471 .79688 Mdot
.339 .77019 Mdot
.25851 .92812 Mdot
.20328 .89114 Mdot
.34887 .96154 Mdot
.35586 .95002 Mdot
.35514 .0715 Mdot
.18035 .8837 Mdot
.18487 .87713 Mdot
.08764 .84093 Mdot
.19735 .83323 Mdot
.22794 .85367 Mdot
.00893 .7815 Mdot
.59088 .78244 Mdot
.31274 .89991 Mdot
.07285 .82501 Mdot
.26608 .81412 Mdot
.8718 .04824 Mdot
.53196 .62366 Mdot
.13787 .90789 Mdot
.2427 .80287 Mdot
.22814 .97456 Mdot
.11879 .81805 Mdot
.2687 .85661 Mdot
.35413 .91047 Mdot
.2922 .09527 Mdot
.68713 .31679 Mdot
.17314 .82101 Mdot
.26223 .07667 Mdot
.32923 .10684 Mdot
.05091 .74811 Mdot
.15575 .63014 Mdot
.26353 .8994 Mdot
.27931 .91657 Mdot
.32408 .95639 Mdot
.27123 .81154 Mdot
.20227 .81406 Mdot
.01406 .51941 Mdot
.275 .98236 Mdot
.28314 .80869 Mdot
.06892 .69409 Mdot
.10269 .7171 Mdot
.68373 .66745 Mdot
.06156 .78859 Mdot
.2169 .98339 Mdot
.30878 .61508 Mdot
.35504 .85676 Mdot
.08318 .1173 Mdot
.33692 .74972 Mdot
.34133 .03124 Mdot
.37307 .88969 Mdot
.12253 .71791 Mdot
.37118 .73686 Mdot
.29394 .28318 Mdot
.19558 .97826 Mdot
.22761 .13976 Mdot
.21525 .89022 Mdot
.99648 .58391 Mdot
.96969 .84672 Mdot
.0686 .7896 Mdot
.36632 .67941 Mdot
.07525 .80984 Mdot
.51434 .75188 Mdot
.28393 .66856 Mdot
.42742 .93893 Mdot
.05751 .72061 Mdot
.3681 .76769 Mdot
.16718 .83393 Mdot
.32326 .75226 Mdot
.9408 .97606 Mdot
.59735 .39448 Mdot
.24956 .90807 Mdot
.39012 .76831 Mdot
.18224 .80886 Mdot
.22292 .77551 Mdot
.68918 .08585 Mdot
.24552 .79438 Mdot
.91645 .5843 Mdot
.23399 .01044 Mdot
.28593 .98892 Mdot
.07496 .84489 Mdot
.35438 .5656 Mdot
.47838 .49905 Mdot
.34506 .09455 Mdot
.32257 .29454 Mdot
.24868 .80158 Mdot
.21895 .53878 Mdot
.18285 .1473 Mdot
.22412 .77041 Mdot
.85789 .17161 Mdot
.11551 .6906 Mdot
.22482 .85554 Mdot
.20153 .83025 Mdot
.17413 .75192 Mdot
.27693 .96804 Mdot
.99244 .00835 Mdot
.38115 .92929 Mdot
.15801 .3314 Mdot
.21323 .8667 Mdot
.34683 .87817 Mdot
.12433 .70839 Mdot
.2563 .83022 Mdot
.59956 .60865 Mdot
.34902 .32368 Mdot
.06629 .56774 Mdot
.75148 .01933 Mdot
.30913 .90302 Mdot
.64833 .95685 Mdot
.80616 .17109 Mdot
.32496 .96657 Mdot
.25642 .84264 Mdot
.38183 .98731 Mdot
.16258 .00832 Mdot
.17497 .93878 Mdot
.30357 .72548 Mdot
.17457 .66653 Mdot
.25606 .82089 Mdot
.71737 .12104 Mdot
.24201 .85804 Mdot
.39268 .78 Mdot
.3714 .96481 Mdot
.60366 .28509 Mdot
.55323 .99341 Mdot
.93359 .04818 Mdot
.30665 .03161 Mdot
.34552 .93457 Mdot
.6699 .02971 Mdot
.26799 .7885 Mdot
.62488 .73392 Mdot
.0724 .83151 Mdot
.21002 .95069 Mdot
.22961 .24522 Mdot
.35774 .83277 Mdot
.25164 .84059 Mdot
.85421 .07348 Mdot
.1797 .9067 Mdot
.36253 .11438 Mdot
.33123 .90476 Mdot
.22095 .78989 Mdot
.2924 .92412 Mdot
.25561 .06025 Mdot
.23929 .84565 Mdot
.21123 .94332 Mdot
.14923 .73962 Mdot
.36438 .96501 Mdot
.21534 .17031 Mdot
.25693 .62871 Mdot
.24715 .88405 Mdot
.25321 .04046 Mdot
.81414 .84416 Mdot
.22712 .86283 Mdot
.28784 .89623 Mdot
.44437 .76748 Mdot
.32135 .94562 Mdot
.21995 .85074 Mdot
.26876 .97524 Mdot
.09393 .99014 Mdot
.31659 .05375 Mdot
.26292 .08651 Mdot
.35747 .04971 Mdot
.08857 .6817 Mdot
.09341 .8001 Mdot
.36875 .83746 Mdot
.85188 .74643 Mdot
.00345 .90667 Mdot
.29464 .88756 Mdot
.2198 .14222 Mdot
.81341 .93713 Mdot
.89395 .46662 Mdot
.17613 .01502 Mdot
.35021 .91287 Mdot
.09561 .68105 Mdot
.22216 .65712 Mdot
.06765 .27722 Mdot
.44425 .86334 Mdot
.2305 .80871 Mdot
.25235 .8329 Mdot
.6893 .67724 Mdot
.57235 .39319 Mdot
.23932 .78292 Mdot
.84096 .0384 Mdot
.31713 .85379 Mdot
.05773 .73836 Mdot
.21876 .83343 Mdot
.21966 .07353 Mdot
.23795 .79244 Mdot
.42021 .88845 Mdot
.30418 .81876 Mdot
.81417 .36881 Mdot
.22992 .02294 Mdot
.25921 .78145 Mdot
.2486 .03333 Mdot
.18278 .72334 Mdot
.26447 .92181 Mdot
.35615 .88608 Mdot
.24618 .86878 Mdot
.07282 .8494 Mdot
.31005 .01397 Mdot
.32685 .8753 Mdot
.11801 .84162 Mdot
.21765 .89323 Mdot
.18032 .11115 Mdot
.16835 .93275 Mdot
.40103 .40035 Mdot
.24346 .48959 Mdot
.681 .63917 Mdot
.23132 .7903 Mdot
.2981 .17293 Mdot
.60112 .63922 Mdot
.26962 .90097 Mdot
.46923 .55865 Mdot
.08525 .86095 Mdot
.23986 .72937 Mdot
.07367 .81343 Mdot
.05189 .15466 Mdot
.58884 .69097 Mdot
.05895 .40482 Mdot
.48534 .20559 Mdot
.319 .8932 Mdot
.34291 .90414 Mdot
.35855 .95029 Mdot
.02675 .76802 Mdot
.34554 .14872 Mdot
.67561 .14402 Mdot
.23867 .83762 Mdot
.15317 .8292 Mdot
.25446 .82537 Mdot
.34895 .93118 Mdot
.11451 .59327 Mdot
.24104 .84605 Mdot
.05245 .95476 Mdot
.21746 .87587 Mdot
.30027 .98751 Mdot
.26889 .8807 Mdot
.22232 .74609 Mdot
.39412 .73814 Mdot
.01245 .54277 Mdot
.3701 .70224 Mdot
.21245 .88336 Mdot
.3687 .10561 Mdot
.22551 .81356 Mdot
.30593 .8706 Mdot
.18481 .87435 Mdot
.98457 .84192 Mdot
.27904 .05147 Mdot
.09572 .73715 Mdot
.23667 .78169 Mdot
.75575 .1513 Mdot
.22991 .79336 Mdot
.23715 .84934 Mdot
.11639 .85258 Mdot
.38746 .92291 Mdot
.73013 .98163 Mdot
.21255 .10804 Mdot
.52097 .80595 Mdot
.42232 .90953 Mdot
.89697 .62008 Mdot
.22959 .79492 Mdot
.46994 .89532 Mdot
.08693 .84146 Mdot
.29474 .97919 Mdot
.32739 .84258 Mdot
.30045 .93398 Mdot
.28796 .93703 Mdot
.14678 .45339 Mdot
.29427 .20766 Mdot
.57761 .96407 Mdot
.23948 .80382 Mdot
.23101 .89962 Mdot
.47822 .90645 Mdot
.23178 .77436 Mdot
.30404 .07072 Mdot
.30397 .87566 Mdot
.39237 .7545 Mdot
.29133 .67154 Mdot
.28596 .09603 Mdot
.2914 .86267 Mdot
.24635 .718 Mdot
.2659 .90949 Mdot
.36522 .07054 Mdot
.18214 .80458 Mdot
.34343 .09573 Mdot
.77345 .82386 Mdot
.08318 .81624 Mdot
.27803 .96249 Mdot
.07836 .82756 Mdot
.28368 .98279 Mdot
.06379 .1587 Mdot
.24443 .84079 Mdot
.21571 .7966 Mdot
.70317 .02359 Mdot
.19911 .71421 Mdot
.29511 .98166 Mdot
.34172 .90797 Mdot
.62678 .58759 Mdot
.0147 .07264 Mdot
.17507 .85547 Mdot
.28942 .87332 Mdot
.86703 .55028 Mdot
.47518 .4603 Mdot
.49811 .83727 Mdot
.26301 .93588 Mdot
.11695 .86066 Mdot
.645 .18047 Mdot
.14539 .16125 Mdot
.20522 .14122 Mdot
.08257 .94951 Mdot
.16875 .90136 Mdot
.14881 .75076 Mdot
.17676 .91544 Mdot
.63839 .65971 Mdot
.59544 .63488 Mdot
.24485 .83659 Mdot
.18077 .51183 Mdot
.25873 .82028 Mdot
.27472 .77583 Mdot
.27728 .9809 Mdot
.54297 .16251 Mdot
.30467 .75956 Mdot
.30594 .1297 Mdot
.43686 .86393 Mdot
.24902 .87916 Mdot
.22393 .84031 Mdot
.10544 .02762 Mdot
.24015 .79046 Mdot
.17277 .81044 Mdot
.24176 .89084 Mdot
.31404 .50913 Mdot
.06108 .06353 Mdot
.17055 .88136 Mdot
.23174 .78395 Mdot
.2304 .85101 Mdot
.37981 .86097 Mdot
.61238 .79243 Mdot
.18605 .69615 Mdot
.24871 .78574 Mdot
.70074 .07078 Mdot
.26687 .85164 Mdot
.1194 .72735 Mdot
.21133 .86886 Mdot
.30339 .88205 Mdot
.31334 .88383 Mdot
.31425 .88541 Mdot
.32556 .89863 Mdot
.25721 .86796 Mdot
.33984 .9807 Mdot
.33666 .90294 Mdot
.0973 .89869 Mdot
.45258 .8772 Mdot
.30111 .4677 Mdot
.47097 .713 Mdot
.23711 .8581 Mdot
.09823 .85911 Mdot
.07051 .80658 Mdot
.64021 .07273 Mdot
.56544 .26585 Mdot
.1954 .49754 Mdot
.00991 .76387 Mdot
.31814 .16319 Mdot
.30038 .88041 Mdot
.19538 .80923 Mdot
.13815 .9593 Mdot
.411 .95276 Mdot
.15912 .80847 Mdot
.36565 .75658 Mdot
.28653 .89102 Mdot
.3196 .77116 Mdot
.71418 .76594 Mdot
.21394 .79931 Mdot
.28255 .85078 Mdot
.04249 .03849 Mdot
.07748 .66165 Mdot
.25093 .45412 Mdot
.2926 .97988 Mdot
.11339 .92347 Mdot
.3022 .87303 Mdot
.11481 .08146 Mdot
.17662 .80512 Mdot
.17717 .8124 Mdot
.15432 .88438 Mdot
.13663 .52675 Mdot
.25436 .84097 Mdot
.39899 .20593 Mdot
.30018 .93449 Mdot
.75342 .62499 Mdot
.25852 .07649 Mdot
.27453 .71866 Mdot
.10843 .52134 Mdot
.22031 .90978 Mdot
.23101 .80203 Mdot
.35161 .87814 Mdot
.23722 .84525 Mdot
.33979 .75906 Mdot
.13628 .90166 Mdot
.88003 .02165 Mdot
.0621 .53942 Mdot
.39537 .55628 Mdot
.08463 .74043 Mdot
.28701 .51986 Mdot
.75804 .50954 Mdot
.61399 .65875 Mdot
.31012 .9446 Mdot
.31325 .01742 Mdot
.31945 .89005 Mdot
.28626 .83836 Mdot
.22513 .89686 Mdot
.21162 .82702 Mdot
.80794 .01675 Mdot
.92053 .68972 Mdot
.18641 .87852 Mdot
.68038 .89479 Mdot
.33008 .8833 Mdot
.25933 .85978 Mdot
.19611 .858 Mdot
.85772 .86289 Mdot
.49533 .13842 Mdot
.20533 .752 Mdot
.29292 .93087 Mdot
.35273 .8911 Mdot
.72101 .92732 Mdot
.94885 .83683 Mdot
.21858 .81239 Mdot
.51037 .58753 Mdot
.32379 .91006 Mdot
.75545 .24284 Mdot
.18269 .48468 Mdot
.23554 .7864 Mdot
.19339 .8371 Mdot
.97533 .72351 Mdot
.27726 .94793 Mdot
.36299 .83094 Mdot
.85909 .98668 Mdot
.15723 .98053 Mdot
.27251 .97497 Mdot
.25661 .83207 Mdot
.31069 .08643 Mdot
.2422 .87211 Mdot
.37449 .85665 Mdot
.2552 .88655 Mdot
.99761 .00665 Mdot
.42376 .09581 Mdot
.2553 .87176 Mdot
.07135 .85775 Mdot
.3116 .97225 Mdot
.18602 .84356 Mdot
.08506 .93193 Mdot
.32383 .92334 Mdot
.37771 .96395 Mdot
.39409 .76418 Mdot
.13161 .0671 Mdot
.03791 .94282 Mdot
.27805 .97004 Mdot
.10758 .8499 Mdot
.56207 .04732 Mdot
.21353 .77262 Mdot
.18171 .95764 Mdot
.43189 .86807 Mdot
.45939 .00026 Mdot
.08061 .76254 Mdot
.34143 .90586 Mdot
.37362 .94753 Mdot
.24694 .71918 Mdot
.30474 .76509 Mdot
.28081 .86809 Mdot
.31246 .85395 Mdot
.19317 .07986 Mdot
.34299 .89229 Mdot
.22169 .78841 Mdot
.26228 .67868 Mdot
.20718 .83614 Mdot
.21784 .80962 Mdot
.32188 .88133 Mdot
.18626 .69835 Mdot
.92458 .63465 Mdot
.2659 .8885 Mdot
.24018 .7935 Mdot
.22615 .85351 Mdot
.80795 .72867 Mdot
.07112 .81299 Mdot
.95674 .74657 Mdot
.67744 .96146 Mdot
.23508 .8919 Mdot
.85359 .61219 Mdot
.06886 .81551 Mdot
.23887 .08947 Mdot
.30974 .93497 Mdot
.69083 .07772 Mdot
.32752 .94047 Mdot
.16062 .13602 Mdot
.19403 .67009 Mdot
.02179 .04822 Mdot
.07234 .80454 Mdot
.62388 .12952 Mdot
.09659 .73372 Mdot
.18965 .88576 Mdot
.32876 .04763 Mdot
.72299 .44995 Mdot
.38441 .95925 Mdot
.29395 .86483 Mdot
.25221 .91156 Mdot
.1965 .82446 Mdot
.08006 .74091 Mdot
.1245 .91053 Mdot
.2531 .87247 Mdot
.16819 .61004 Mdot
.31843 .88937 Mdot
.28893 .66504 Mdot
.27975 .96577 Mdot
.27295 .88131 Mdot
.48684 .87927 Mdot
.24137 .88151 Mdot
.17879 .8125 Mdot
.27634 .89632 Mdot
.97307 .54467 Mdot
.16252 .78944 Mdot
.43199 .96707 Mdot
.93273 .75693 Mdot
.31564 .88656 Mdot
.82953 .72366 Mdot
.5109 .69867 Mdot
.36416 .80272 Mdot
.05057 .78594 Mdot
.20361 .83665 Mdot
.4507 .05951 Mdot
.21399 .78803 Mdot
.36916 .92749 Mdot
.83961 .92621 Mdot
.93916 .60453 Mdot
.2401 .79771 Mdot
.0929 .74596 Mdot
.36763 .87509 Mdot
.34739 .03168 Mdot
.24254 .77016 Mdot
.05115 .83257 Mdot
.37434 .57327 Mdot
.2486 .83726 Mdot
.65546 .96835 Mdot
.17058 .98463 Mdot
.14977 .75747 Mdot
.06823 .68704 Mdot
.39345 .93637 Mdot
.52657 .72747 Mdot
.23308 .74985 Mdot
.4101 .62519 Mdot
.30331 .86039 Mdot
.00805 .83794 Mdot
.29732 .97983 Mdot
.56317 .71378 Mdot
.86253 .7472 Mdot
.7647 .41421 Mdot
.02822 .81892 Mdot
.39871 .06147 Mdot
.07692 .79227 Mdot
.25488 .88525 Mdot
.05206 .80585 Mdot
.39082 .95807 Mdot
.47274 .7207 Mdot
.22426 .89383 Mdot
.32246 .94774 Mdot
.33377 .94464 Mdot
.33274 .77019 Mdot
.15661 .48262 Mdot
.04848 .07078 Mdot
.22877 .80585 Mdot
.35622 .85765 Mdot
.22295 .84547 Mdot
.61441 .80227 Mdot
.09286 .04591 Mdot
.57168 .93822 Mdot
.18389 .45161 Mdot
.36564 .13672 Mdot
.35616 .91284 Mdot
.15361 .88083 Mdot
.50616 .21404 Mdot
.32929 .76346 Mdot
.06888 .12136 Mdot
.55236 .74201 Mdot
.24498 .55635 Mdot
.17023 .8314 Mdot
.12101 .07257 Mdot
.30566 .85249 Mdot
.33713 .83431 Mdot
.76372 .33175 Mdot
.39121 .93889 Mdot
.02946 .0138 Mdot
.24749 .83949 Mdot
.30281 .91931 Mdot
.61689 .30939 Mdot
.27373 .82139 Mdot
.07396 .85452 Mdot
.00926 .8363 Mdot
.23518 .83133 Mdot
.69626 .93409 Mdot
.60725 .03083 Mdot
.68029 .02275 Mdot
.437 .9703 Mdot
.23962 .77223 Mdot
.08591 .91941 Mdot
.93577 .75301 Mdot
.30472 .73771 Mdot
.28139 .77043 Mdot
.36488 .89977 Mdot
.17323 .85282 Mdot
.44352 .29008 Mdot
.00515 .86169 Mdot
.38999 .9891 Mdot
.14081 .47961 Mdot
.38005 .00782 Mdot
.31886 .52121 Mdot
.25787 .9248 Mdot
.1189 .85411 Mdot
.0505 .79322 Mdot
.57219 .91425 Mdot
.78261 .63062 Mdot
.46506 .93964 Mdot
.22149 .78634 Mdot
.8392 .83494 Mdot
.38192 .84991 Mdot
.495 .95487 Mdot
.43931 .94246 Mdot
.26931 .87439 Mdot
.24981 .88837 Mdot
.06993 .87793 Mdot
.20917 .8302 Mdot
.28114 .92475 Mdot
.27221 .99683 Mdot
.15103 .76228 Mdot
.34903 .97201 Mdot
.28764 .88285 Mdot
.84967 .91332 Mdot
.31548 .88682 Mdot
.15324 .12452 Mdot
.27636 .8879 Mdot
.26595 .06897 Mdot
.18249 .83325 Mdot
.15204 .93457 Mdot
.96809 .06696 Mdot
.36968 .76859 Mdot
.20621 .8444 Mdot
.20073 .81936 Mdot
.06416 .88735 Mdot
.31734 .94104 Mdot
.37105 .96485 Mdot
.48425 .17148 Mdot
.14053 .86919 Mdot
.41605 .90432 Mdot
.30359 .88333 Mdot
.11645 .03757 Mdot
.28763 .03401 Mdot
.14246 .83421 Mdot
.18151 .83059 Mdot
.20738 .49142 Mdot
.24203 .69669 Mdot
.25923 .85202 Mdot
.26233 .15023 Mdot
.29999 .14717 Mdot
.18378 .87383 Mdot
.19565 .81127 Mdot
.36186 .89457 Mdot
.25405 .15387 Mdot
.36013 .75707 Mdot
.35043 .95918 Mdot
.34564 .85977 Mdot
.01057 .88815 Mdot
.37009 .92878 Mdot
.34524 .15036 Mdot
.12964 .01788 Mdot
.14641 .82985 Mdot
.19449 .73527 Mdot
.63116 .8797 Mdot
.22325 .83646 Mdot
.28505 .97151 Mdot
.29846 .66548 Mdot
.22317 .72828 Mdot
.28756 .95539 Mdot
.99918 .53429 Mdot
.15642 .51508 Mdot
.02841 .83746 Mdot
.18373 .71898 Mdot
.18852 .01863 Mdot
.17919 .80994 Mdot
.35989 .87282 Mdot
.31446 .60368 Mdot
.21879 .90318 Mdot
.22245 .82136 Mdot
.29419 .60173 Mdot
.82781 .0195 Mdot
.27497 .85786 Mdot
.54257 .9483 Mdot
.31904 .88981 Mdot
.33355 .89853 Mdot
.39489 .89877 Mdot
.35405 .91043 Mdot
.3053 .88874 Mdot
.34411 .12425 Mdot
.34927 .91636 Mdot
.29768 .926 Mdot
.56071 .17279 Mdot
.28007 .68912 Mdot
.49561 .77146 Mdot
.03424 .98288 Mdot
.33252 .95834 Mdot
.5848 .93742 Mdot
.34275 .78344 Mdot
.26965 .94609 Mdot
.12319 .48752 Mdot
.25306 .79877 Mdot
.27801 .86896 Mdot
.61842 .20242 Mdot
.23513 .56397 Mdot
.33802 .89915 Mdot
.23307 .80978 Mdot
.17176 .85347 Mdot
.83457 .94237 Mdot
.92329 .71068 Mdot
.6836 .07895 Mdot
.34736 .89477 Mdot
.30765 .85617 Mdot
.25921 .87432 Mdot
.86125 .03718 Mdot
.26446 .79613 Mdot
.19598 .85078 Mdot
.10754 .72834 Mdot
.25701 .77692 Mdot
.96788 .0632 Mdot
.31784 .88781 Mdot
.26011 .13994 Mdot
.43941 .86864 Mdot
.31605 .88604 Mdot
.32292 .8917 Mdot
.18131 .82278 Mdot
.17406 .83263 Mdot
.46884 .05766 Mdot
.32597 .8512 Mdot
.36589 .83072 Mdot
.07374 .79284 Mdot
.20954 .13217 Mdot
.47091 .97042 Mdot
.34749 .90678 Mdot
.18124 .93741 Mdot
.26533 .78417 Mdot
.18659 .81633 Mdot
.1574 .86449 Mdot
.18612 .78664 Mdot
.29875 .90815 Mdot
.24554 .64746 Mdot
.16317 .34658 Mdot
.13687 .72017 Mdot
.1565 .82512 Mdot
.65022 .857 Mdot
.19337 .83242 Mdot
.31217 .8827 Mdot
.35227 .91202 Mdot
.41174 .77195 Mdot
.06956 .80411 Mdot
.07277 .86736 Mdot
.02276 .03057 Mdot
.22165 .87295 Mdot
.58721 .77277 Mdot
.3039 .72589 Mdot
.30501 .1718 Mdot
.45816 .86763 Mdot
.23303 .85801 Mdot
.4665 .8378 Mdot
.29085 .86153 Mdot
.88713 .11187 Mdot
.26398 .86349 Mdot
.05693 .85705 Mdot
.38342 .911 Mdot
.16061 .84302 Mdot
.19656 .96093 Mdot
.86036 .13129 Mdot
.16231 .89121 Mdot
.72178 .05496 Mdot
.00089 .05125 Mdot
.19939 .70394 Mdot
.20122 .84915 Mdot
.11784 .81349 Mdot
.08855 .86453 Mdot
.35669 .98282 Mdot
.27735 .79871 Mdot
.43999 .1853 Mdot
.19082 .82474 Mdot
.40148 .82583 Mdot
.2638 .47068 Mdot
.08092 .93321 Mdot
.09696 .85611 Mdot
.22191 .64878 Mdot
.17164 .85217 Mdot
.09017 .59933 Mdot
.17538 .4921 Mdot
.10826 .82822 Mdot
.31473 .88599 Mdot
.27181 .88143 Mdot
.62273 .07723 Mdot
.18862 .23386 Mdot
.12333 .04205 Mdot
.46659 .9207 Mdot
.92925 .61538 Mdot
.41646 .69979 Mdot
.34824 .9611 Mdot
.34176 .90421 Mdot
.25126 .83899 Mdot
.29673 .66187 Mdot
.07795 .8249 Mdot
.46993 .49596 Mdot
.27894 .78546 Mdot
.24818 .83321 Mdot
.55144 .79324 Mdot
.35223 .91047 Mdot
.16192 .83082 Mdot
.18638 .80529 Mdot
.91871 .92602 Mdot
.46285 .80176 Mdot
.23556 .87139 Mdot
.92279 .79189 Mdot
.3057 .7598 Mdot
.18377 .87133 Mdot
.28207 .48323 Mdot
.2536 .88666 Mdot
.88376 .9309 Mdot
.37408 .79029 Mdot
.40781 .45508 Mdot
.36117 .6464 Mdot
.35358 .88586 Mdot
.46253 .0153 Mdot
.12944 .0131 Mdot
.62897 .83853 Mdot
.65968 .06159 Mdot
.22225 .8675 Mdot
.21539 .83169 Mdot
.27582 .86136 Mdot
.21642 .74994 Mdot
.34147 .88809 Mdot
.49247 .12778 Mdot
.33921 .08239 Mdot
.27448 .00635 Mdot
.62272 .07343 Mdot
.65455 .45732 Mdot
.3299 .28727 Mdot
.60791 .64339 Mdot
.50476 .69971 Mdot
.02816 .97294 Mdot
.87162 .03076 Mdot
.29992 .87057 Mdot
.22224 .1399 Mdot
.84083 .50516 Mdot
.23576 .82002 Mdot
.26738 .79358 Mdot
.31292 .9312 Mdot
.10372 .70019 Mdot
.19195 .1277 Mdot
.23208 .14268 Mdot
.21552 .77925 Mdot
.42954 .85398 Mdot
.11101 .98862 Mdot
.90245 .43041 Mdot
.24793 .72684 Mdot
.25052 .80334 Mdot
.56401 .15918 Mdot
.14406 .82835 Mdot
.15434 .02891 Mdot
.34704 .49132 Mdot
.30399 .89065 Mdot
.24198 .77212 Mdot
.32883 .86135 Mdot
.21522 .04767 Mdot
.24791 .10543 Mdot
.34752 .74628 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`04o`000?oooooo0000o`00
00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool2o`0000Oo
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`?o00001?ooool001kooooo
00?o0000ooooooooool0<Oooool2o`0001Gooooo0_l0000;ooooo`;o00008?ooool2o`000<Kooooo
0ol00005ooooo`007_ooool00ol0003oooooooooo`0Vooooo`;o00002Oooool2o`0001Gooooo0_l0
000]ooooo`;o0000a_ooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo00Gooooo0_l0000O
ooooo`;o00003Oooool2o`0002[ooooo0_l0000_ooooo`;o0000Koooool2o`0004;ooooo000Noooo
o`03o`000?oooooooooo00Gooooo0_l0000Oooooo`;o00003Oooool2o`0000;ooooo0_l0000Joooo
o`;o00002_ooool3o`0002kooooo0_l0001Looooo`;o00004Oooool2o`0000Cooooo0_l0000loooo
o`007_ooool00ol0003oooooooooo`0Vooooo`;o00004Oooool2o`0000cooooo0_l0000<ooooo`;o
00002oooool2o`0007Gooooo0_l0000Eooooo`;o00005oooool2o`0000oooooo0_l0000[ooooo`00
7_ooool00ol0003oooooooooo`17ooooo`;o0000T?ooool2o`0000Gooooo0_l0000hooooo`;o0000
:oooool001kooooo00?o0000ooooooooool07_ooool2o`0000kooooo0_l0002`ooooo`;o00008ooo
ool2o`00043ooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0000Iooooo`;o00003_ooool2
o`00033ooooo0_l00009ooooo`Co0000D_ooool2o`0001?ooooo0_l0000]ooooo`;o00004?ooool2
o`0002kooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l00018ooooo`;o00002_ooool2o`00
00Gooooo0_l00009ooooo`Co0000D_ooool2o`0001?ooooo0_l0000oooooo`;o0000;_ooool001ko
oooo00?o0000ooooooooool08_ooool2o`0002Wooooo0_l0000:ooooo`;o0000^Oooool2o`00037o
oooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0000Fooooo`;o00009oooool2o`000003oooo
ool0003o00000;gooooo0_l00005ooooo`;o0000<Oooool001kooooo00?o0000ooooooooool02_oo
ool2o`0001Sooooo0_l0000Uooooo`;o000000?oooooo`000?l00000_Oooool2o`0003Sooooo000N
ooooo`03o`000?oooooooooo01[ooooo0_l00008ooooo`;o0000>Oooool2o`0005;ooooo0_l0002B
ooooo`007_ooool00ol0003oooooooooo`03ooooo`;o00005Oooool2o`0002Kooooo0_l0000Koooo
o`;o00001_ooool2o`0000Oooooo0_l00011ooooo`;o0000H_ooool2o`0001;ooooo0_l0000Joooo
o`007Oooool3o`0000Cooooo0_l0000mooooo`;o00004oooool2o`0000kooooo0_l00007ooooo`;o
0000YOooool2o`0001;ooooo0_l0000Jooooo`007Oooool2o`0005Wooooo0_l0000:ooooo`;o0000
P_ooool2o`0005kooooo000Nooooo`03o`000?oooooooooo06?ooooo0_l0000Yooooo`;o00001?oo
ool2o`00057ooooo0_l0001Nooooo`007_ooool00ol0003oooooooooo`1?ooooo`;o0000;Oooool2
o`0000kooooo0_l000001?oooooo0000o`000?ooool2o`0003cooooo0_l0001cooooo`007_ooool0
0ol0003oooooooooo`0@ooooo`;o0000?Oooool2o`0000cooooo0_l0000Oooooo`;o00004Oooool2
o`0003oooooo0_l0001Sooooo`;o00003_ooool001kooooo00?o0000ooooooooool04?ooool2o`00
01Gooooo0_l0000Yooooo`;o00002Oooool2o`000=Sooooo0_l0000>ooooo`007_ooool00ol0003o
ooooooooo`0<ooooo`;o00006Oooool2o`0002Wooooo0_l0000;ooooo`;o00003_ooool2o`0000;o
oooo0_l0001[ooooo`;o0000EOooool2o`0000kooooo000Nooooo`04o`000?ooooooooooooooo`;o
00002Oooool2o`0001Gooooo0_l0000Nooooo`;o00006_ooool2o`0000kooooo0_l00002ooooo`;o
0000DOooool2o`0000Cooooo0_l0000Booooo`;o0000<?ooool2o`0003?ooooo000Nooooo`04o`00
0?ooooooooooooooo`;o00008?ooool2o`0001kooooo0_l0000;ooooo`?o0000Loooool2o`0000Co
oooo0_l0000>ooooo`;o0000=?ooool2o`0003?ooooo000Nooooo`03o`000?oooooooooo03_ooooo
0_l0000Cooooo`Co0000L_ooool2o`0001;ooooo1?l0001Yooooo`007_ooool00ol0003ooooooooo
o`0Qooooo`;o00006?ooool2o`0001Gooooo0_l0000Fooooo`;o0000K_ooool2o`0006_ooooo000N
ooooo`03o`000?oooooooooo027ooooo0_l0000^ooooo`;o00003_ooool2o`0000Oooooo0_l0001`
ooooo`;o0000JOooool001kooooo00?o0000ooooooooool0B_ooool2o`0000Gooooo0_l0000>oooo
o`;o0000NOooool2o`0006Wooooo000Nooooo`03o`000?oooooooooo04[ooooo0_l0003kooooo`00
7_ooool00ol0003oooooooooo`1Iooooo`Co00003oooool2o`0001Sooooo0_l0002oooooo`007_oo
ool00ol0003oooooooooo`0mooooo`;o00006_ooool4o`0000oooooo0_l0000Hooooo`;o0000_ooo
ool001kooooo0_l0000nooooo`;o0000ooooool9ooooo`007_ooool00ol0003oooooooooo`1<oooo
o`Co00009?ooool2o`000=7ooooo000Nooooo`03o`000?oooooooooo047ooooo0_l00009ooooo`Co
00005oooool2o`0000_ooooo0_l0003Aooooo`007_ooool00ol0003oooooooooo`0gooooo`;o0000
2?ooool2o`0002Cooooo0_l0002cooooo`;o0000:Oooool001kooooo00?o0000ooooooooool0=ooo
ool2o`0003Wooooo0_l0002Xooooo`;o0000:Oooool001kooooo00?o0000ooooooooool05oooool2
o`0005Wooooo0_l0003Cooooo`007_ooool00ol0003oooooooooo`0Booooo`;o00000oooool2o`00
0<cooooo0_l0001Pooooo`007_ooool00ol0003oooooooooo`0Booooo`;o0000F?ooool2o`0007Oo
oooo0_l0001Pooooo`007_ooool00ol0003oooooooooo`0^ooooo`;o0000??ooool2o`000=Wooooo
000Nooooo`03o`000?oooooooooo02kooooo0_l0000:ooooo`;o00008oooool2o`0003_ooooo0_l0
000Yooooo`;o0000O_ooool001kooooo00?o0000ooooooooool0>_ooool2o`0000Cooooo0_l0000M
ooooo`;o0000>oooool2o`0002Wooooo0_l0001;ooooo`;o0000<Oooool001kooooo00?o0000oooo
ooooool0<?ooool2o`0000kooooo0_l0000aooooo`;o0000Woooool2o`00037ooooo000Nooooo`03
o`000?oooooooooo033ooooo0_l0000Dooooo`;o0000:oooool2o`0002Sooooo0_l0002Xooooo`00
7_ooool00ol0003oooooooooo`0oooooo`;o00000_ooool6o`0000Oooooo0_l0001;ooooo`;o0000
Z?ooool001kooooo00?o0000ooooooooool0?oooool2o`0000;ooooo0ol000000ooooooo0000o`00
0007ooooo`;o0000Q_ooool2o`0006gooooo000Nooooo`03o`000?oooooooooo03Oooooo0_l0000T
ooooo`;o00003Oooool2o`0006[ooooo0_l0001]ooooo`007_ooool2o`0003Sooooo0_l0000Hoooo
o`;o00002_ooool2o`0000gooooo0_l00024ooooo`;o0000Doooool001kooooo00?o0000oooooooo
ool03Oooool2o`0003oooooo0_l000000ooooooo0000o`00000Iooooo`;o0000Q?ooool2o`0005?o
oooo000Nooooo`03o`000?oooooooooo00gooooo0_l0000oooooo`;o0000moooool001kooooo00?o
0000ooooooooool04Oooool2o`0001Sooooo0_l00026ooooo`;o0000T_ooool001kooooo00?o0000
ooooooooool04Oooool2o`0001Sooooo0_l0000fooooo`;o0000Aoooool2o`0000Gooooo0_l0002B
ooooo`007_ooool00ol0003oooooooooo`1Dooooo`;o00003Oooool2o`0004Oooooo0_l0002Ioooo
o`007_ooool00ol0003oooooooooo`12ooooo`;o00004?ooool2o`000?7ooooo000Nooooo`03o`00
0?oooooooooo04;ooooo0_l0000Iooooo`Co0000>?ooool2o`0001Oooooo0_l0001>ooooo`;o0000
3oooool2o`0003;ooooo000Nooooo`03o`000?oooooooooo05gooooo1?l0000hooooo`;o00005ooo
ool2o`0004kooooo0_l0000?ooooo`;o0000<_ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3>ooooo`;o0000Moooool001kooooo00?o0000oooooooo
ool0Roooool2o`00047ooooo0_l0001gooooo`007_ooool00ol0003oooooooooo`1Wooooo`;o0000
8_ooool2o`000;[ooooo000Nooooo`03o`000?oooooooooo06Oooooo0_l0003Nooooo`000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003ooooooooo
o`3oooooodSooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go
410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodSooooo
0003ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`03o`00
0?oooooooooo0<Gooooo0_l00020ooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo
00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`1nooooo`;o00006_ooool2o`0002Wooooo
0_l00020ooooo`000oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1Looooo`;o00008?ooool2o`0001[ooooo0_l0002[ooooo`000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03
o`000?oooooooooo05cooooo0_l0003Yooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0:3ooooo0_l0002Uoooo
o`007_ooool00ol0003oooooooooo`2Pooooo`;o0000YOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0AOooool2o`000?oooooo0Oooool001ko
oooo00?o0000ooooooooool0>Oooool2o`0000[ooooo0_l0003oooooo`7ooooo000Nooooo`03o`00
0?oooooooooo03Wooooo0_l0003oooooo`gooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0lOooool2o`0005Cooooo000Nooooo`03o`000?oooooooooo
04Oooooo0_l0002Xooooo`;o0000E?ooool001kooooo00?o0000ooooooooool0Aoooool2o`000?ko
oooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`2dooooo`;o0000TOooool001kooooo00?o0000ooooooooool0
]?ooool2o`00097ooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`0Booooo`;o0000ooooooldoooo
o`007_ooool00ol0003oooooooooo`0Booooo`;o0000ooooooldooooo`007_ooool00ol0003ooooo
ooooo`1Kooooo`;o0000j_ooool001kooooo00?o0000ooooooooool0Foooool2o`0000[ooooo0_l0
001Gooooo`;o0000QOooool001kooooo00?o0000ooooooooool0Ioooool2o`0002?ooooo0_l0000b
ooooo`;o0000QOooool001kooooo00?o0000ooooooooool0S?ooool2o`000;Wooooo000Nooooo`03
o`000?oooooooooo06Gooooo0_l0003Pooooo`007_ooool00ol0003oooooooooo`1Uooooo`;o0000
h?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`34ooooo`;o
0000POooool001kooooo00?o0000ooooooooool0a?ooool2o`00087ooooo000Nooooo`03o`000?oo
oooooooo0=_ooooo0_l0001Zooooo`007_ooool00ol0003oooooooooo`3Booooo`;o00001oooool2
o`0006[ooooo000Nooooo`03o`000?oooooooooo06gooooo0_l0001Sooooo`;o0000Loooool001ko
oooo00?o0000ooooooooool0KOooool2o`000=Sooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0;oooool2o`000<?ooooo0_l0001Aooooo`007_ooool0
0ol0003oooooooooo`0_ooooo`;o0000`oooool2o`00057ooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo037ooooo0_l0003ooooooaGooooo000N
ooooo`;o0000<_ooool2o`000?oooooo5Oooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo1_ooool2o`00043ooooo000Nooooo`03
o`000?oooooooooo0?oooooo1_ooool2o`00043ooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`00
0?oooooooooo0;Kooooo0_l00006ooooo`;o0000Qoooool000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Kooooo
0_l00006ooooo`;o0000Qoooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000
1_ooool3o`0007kooooo0_l00037ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo
00CoA4A4omgMgOoooooo00001oooool00ol0003oooooooooo`1nooooo`;o0000?Oooool2o`0008So
oooo0003ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007oooo
o`03o`000?oooooooooo00oooooo0_l0002/ooooo`;o0000R?ooool000?ooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool03oooool2o`00
0?oooooo=oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co0000
00Oooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00gooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`3dooooo`;o0000DOooool001ko
oooo00?o0000ooooooooool0m?ooool2o`00057ooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`1;
ooooo`;o0000n_ooool001kooooo00?o0000ooooooooool0Boooool2o`000=Cooooo0_l0000Toooo
o`007_ooool00ol0003oooooooooo`3oooooob;ooooo0_l0000Tooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0>Oooooo0_l0001Nooooo`007_ooool2o`0002gooooo0_l0000:ooooo`;o0000
[Oooool2o`0005kooooo000Nooooo`03o`000?oooooooooo02cooooo0_l0000:ooooo`;o00004ooo
ool2o`00037ooooo0_l00035ooooo`007_ooool00ol0003oooooooooo`1=ooooo`;o0000<Oooool2
o`0004oooooo0_l0001dooooo`007_ooool00ol0003oooooooooo`2Fooooo`;o0000>Oooool2o`00
07Cooooo000Nooooo`03o`000?oooooooooo09Kooooo0_l0002_ooooo`007_ooool00ol0003ooooo
ooooo`1Nooooo`;o0000_oooool2o`0002Kooooo000Nooooo`03o`000?oooooooooo05;ooooo0_l0
000:ooooo`;o0000_oooool2o`0002Kooooo000Nooooo`03o`000?oooooooooo05;ooooo0_l0003c
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo02[o
oooo0_l0003ooooooacooooo000Nooooo`03o`000?oooooooooo02[ooooo0_l00003ooooo`;o0000
9oooool2o`000>gooooo000Nooooo`03o`000?oooooooooo02oooooo0_l00006ooooo`;o00007ooo
ool2o`000>gooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l0000Aooooo`;o00004_ooool2
o`000?[ooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l0000?ooooo`;o00002?ooool2o`00
00[ooooo0_l0000Pooooo`;o0000f?ooool001kooooo00?o0000ooooooooool0=Oooool2o`0000So
oooo0_l0000/ooooo`;o00009_ooool2o`000;3ooooo000Nooooo`03o`000?oooooooooo03_ooooo
0_l0001Hooooo`Co0000[_ooool001kooooo0_l0000looooo`;o0000F_ooool2o`000:kooooo000N
ooooo`03o`000?oooooooooo0?oooooo3_ooool2o`0003Sooooo000Nooooo`03o`000?oooooooooo
0?oooooo3_ooool2o`0003Sooooo000Nooooo`03o`000?oooooooooo03Oooooo0_l0000Yooooo`;o
0000S_ooool2o`0005?ooooo000Nooooo`03o`000?oooooooooo02oooooo0_l00006ooooo`;o0000
:Oooool2o`0008kooooo0_l0001Cooooo`007_ooool00ol0003oooooooooo`0_ooooo`;o0000oooo
oolGooooo`007_ooool00ol0003oooooooooo`02o`0005Oooooo0_l00009ooooo`Co0000goooool0
01kooooo00?o0000ooooooooool00_l0000Mooooo`;o0000>?ooool2o`0000Wooooo1?l0003Ooooo
o`007_ooool00ol0003oooooooooo`0Oooooo`;o00001oooool2o`000;3ooooo0_l0001[ooooo`00
7_ooool00ol0003oooooooooo`0Xooooo`;o0000/?ooool2o`0006_ooooo000Nooooo`03o`000?oo
oooooooo0?oooooo?Oooool2o`0000Wooooo000Nooooo`03o`000?oooooooooo0?oooooo?Oooool2
o`0000?ooooo0_l00004ooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o0000<Oooool2o`00
0?cooooo0_l00004ooooo`007_ooool00ol0003oooooooooo`02o`0000kooooo0_l0000aooooo`;o
0000;Oooool2o`000=?ooooo000Nooooo`03o`000?oooooooooo00;o0000L?ooool2o`0002Kooooo
0_l0002Looooo`;o00003Oooool001kooooo00?o0000ooooooooool0V_ooool2o`0009cooooo0_l0
000=ooooo`007_ooool2o`000?oooooo6?ooool2o`0002oooooo000Nooooo`03o`000?oooooooooo
0?oooooo5oooool2o`0002oooooo000Nooooo`03o`000?oooooooooo04cooooo0_l0000^ooooo`;o
0000bOooool001kooooo00?o0000ooooooooool0C?ooool2o`0002kooooo0_l0000Fooooo`;o0000
/Oooool001kooooo00?o0000ooooooooool0B?ooool2o`0004[ooooo0_l0002aooooo`007_ooool0
0ol0003oooooooooo`18ooooo`;o00009Oooool2o`000=Kooooo000Nooooo`03o`000?oooooooooo
017ooooo0_l0001Looooo`;o0000e_ooool001kooooo00?o0000ooooooooool04Oooool2o`0006?o
oooo0_l0003?ooooo`007_ooool00ol0003oooooooooo`1fooooo`;o0000coooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?oooooo9oooool2o`0001Sooooo0_l00005ooooo`007_ooool00ol0003o
ooooooooo`2Rooooo`;o00009?ooool2o`0005cooooo0_l0000Hooooo`;o00001Oooool001kooooo
00?o0000ooooooooool08?ooool2o`00083ooooo0_l0000Tooooo`;o0000OOooool000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Ko
oooo00?o0000ooooooooool08?ooool3o`000?oooooo9Oooool000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000oooo
ooooool08Oooool2o`000?oooooo9Oooool000?ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000001_ooool3o`0001Wooooo0_l0003oooooobgooooo0003oooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o
0000ooooooooool06Oooool2o`0003Cooooo0_l0000;ooooo`;o00001?ooool2o`000>?ooooo0003
ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo
00?o0000ooooooooool0Coooool2o`0000_ooooo0_l00004ooooo`;o0000bOooool2o`0001Sooooo
0003ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`00
0?oooooooooo03?ooooo0_l0002:ooooo`;o0000K?ooool2o`0001Sooooo0003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo03?ooooo
0_l0002:ooooo`;o0000D?ooool2o`0003Cooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo063ooooo0_l0002_ooooo`;o
00005oooool2o`0001_ooooo000Nooooo`03o`000?oooooooooo063ooooo0_l00038ooooo`;o0000
6oooool001kooooo00?o0000ooooooooool0oooooolQooooo`;o00009Oooool001kooooo00?o0000
ooooooooool0POooool2o`0002Kooooo0_l00016ooooo`;o0000;Oooool2o`0002Gooooo000Noooo
o`03o`000?oooooooooo04oooooo0_l0000`ooooo`;o00009_ooool2o`0004Kooooo0_l0001Doooo
o`007_ooool00ol0003oooooooooo`0_ooooo`;o00007_ooool2o`0009?ooooo0_l0000Dooooo`;o
0000Boooool001kooooo00?o0000ooooooooool0;oooool2o`0008cooooo0_l0000Uooooo`;o0000
5?ooool2o`0002cooooo0_l0000Mooooo`007_ooool00ol0003oooooooooo`2mooooo`;o0000JOoo
ool2o`0001gooooo000Nooooo`03o`000?oooooooooo0;oooooo0_l0000Hooooo`;o0000K?ooool0
01kooooo00?o0000ooooooooool0_oooool2o`000003ooooool0003o000001Gooooo0_l0001/oooo
o`007_ooool00ol0003oooooooooo`1aooooo`;o0000Coooool2o`0008?ooooo000Nooooo`03o`00
0?oooooooooo04Cooooo0_l00006ooooo`;o00008oooool2o`000=Cooooo000Nooooo`;o0000AOoo
ool2o`0000Kooooo0_l0003iooooo`007_ooool00ol0003oooooooooo`12ooooo`;o0000ooooool4
ooooo`007_ooool00ol0003oooooooooo`12ooooo`Co0000O_ooool2o`00087ooooo000Nooooo`03
o`000?oooooooooo01Gooooo0_l0000]ooooo`;o00005_ooool2o`0006Kooooo0_l00005ooooo`;o
0000N_ooool001kooooo00?o0000ooooooooool05Oooool2o`0004?ooooo1Ol0001/ooooo`;o0000
N_ooool001kooooo00?o0000ooooooooool0=Oooool2o`00027ooooo1?l000000ooooooo0000o`00
001kooooo`;o0000Joooool001kooooo00?o0000ooooooooool0=Oooool2o`0000Cooooo0_l0000K
ooooo`;o000000?oooooo`000?l00000OOooool2o`0006_ooooo000Nooooo`03o`000?oooooooooo
03_ooooo0_l0000Nooooo`;o0000j_ooool001kooooo00?o0000ooooooooool0W_ooool2o`0003co
oooo0_l0001Yooooo`007_ooool00ol0003oooooooooo`0Kooooo`;o00003oooool2o`0002?ooooo
0_l0000Pooooo`;o0000:Oooool2o`0003cooooo0_l0001Yooooo`007_ooool00ol0003ooooooooo
o`0Iooooo`Co00003oooool2o`0002?ooooo0_l0000Pooooo`;o0000d_ooool001kooooo00?o0000
ooooooooool04_ooool2o`0000Gooooo0_l0000Eooooo`;o0000oooooolFooooo`007_ooool00ol0
003oooooooooo`0Booooo`;o00007?ooool2o`0002Gooooo0_l00027ooooo`;o0000AOooool2o`00
01kooooo000Nooooo`03o`000?oooooooooo027ooooo0_l0000dooooo`;o0000H_ooool2o`0002?o
oooo0_l00015ooooo`;o00007_ooool001kooooo00?o0000ooooooooool04_ooool2o`0000gooooo
0_l0000Eooooo`;o0000POooool2o`0008[ooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0
000Tooooo`;o00004Oooool2o`0005Gooooo0_l0002Sooooo`007_ooool2o`0001oooooo0_l0000H
ooooo`;o000000?oooooo`000?l000003_ooool2o`0002Oooooo0_l0000=ooooo`;o00006oooool4
o`000:?ooooo000Nooooo`03o`000?oooooooooo01kooooo0_l0000Kooooo`Co0000=Oooool2o`00
00gooooo0_l0000Kooooo`;o0000YOooool001kooooo00?o0000ooooooooool09?ooool2o`0001Oo
oooo0_l0003oooooo`Wooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l0003oooooo`?ooooo
0_l0000Mooooo`007_ooool00ol0003oooooooooo`0Looooo`;o00007oooool2o`0005Kooooo0_l0
000Looooo`;o0000Loooool2o`0001gooooo000Nooooo`03o`000?oooooooooo01cooooo0ol00005
ooooo`;o00005oooool2o`0000gooooo0_l00017ooooo`;o00007?ooool2o`0009;ooooo000Noooo
o`03o`000?oooooooooo00oooooo0_l0000<ooooo`;o00001Oooool2o`0000;ooooo0_l0000>oooo
o`;o00004_ooool2o`0000Oooooo0_l0000oooooo`;o0000[oooool001kooooo00?o0000oooooooo
ool03oooool2o`0001Oooooo0_l0000=ooooo`?o00004_ooool2o`0000Oooooo0_l0000oooooo`;o
0000L_ooool2o`0002gooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`0gooooo`;o0000
4oooool2o`00017ooooo0_l0002Yooooo`;o0000;Oooool2o`0000cooooo000Nooooo`03o`000?oo
oooooooo01oooooo0_l00002ooooo`;o00004Oooool2o`0000cooooo0_l00004ooooo`Co00004Ooo
ool2o`000003ooooool0003o000004?ooooo0_l0001Jooooo`;o0000@_ooool001kooooo00?o0000
ooooooooool07oooool2o`0000;ooooo0_l0000Aooooo`;o00001?ooool2o`0000Kooooo0_l00004
ooooo`;o00005_ooool2o`0004?ooooo0_l0001Jooooo`;o0000@_ooool001kooooo00?o0000oooo
ooooool06oooool2o`0001kooooo0ol0000Jooooo`;o0000KOooool2o`0007kooooo000Nooooo`03
o`000?oooooooooo00oooooo0_l0000:ooooo`;o00003oooool2o`0000gooooo0_l0000Kooooo`;o
00001Oooool2o`0001Cooooo0_l00005ooooo`;o0000BOooool2o`0007kooooo000Nooooo`03o`00
0?oooooooooo00oooooo0_l00005ooooo`?o00000_ooool2o`0000oooooo0_l0000aooooo`;o0000
5?ooool2o`0000Gooooo0_l0000aooooo`;o0000U_ooool001kooooo00?o0000ooooooooool05_oo
ool3o`0009Kooooo0_l0002Fooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o00003?ooool2
o`00023ooooo0_l00006ooooo`;o00009oooool2o`0001[ooooo0_l00026ooooo`;o000000?ooooo
o`000?l000007Oooool2o`0001;ooooo000Nooooo`;o00003Oooool2o`0000cooooo0_l0000@oooo
o`;o00001_ooool2o`0000Kooooo0_l00004ooooo`So00007oooool2o`0000;ooooo0_l0000Joooo
o`;o00006?ooool2o`0006cooooo0_l000000ooooooo0000o`00000Mooooo`;o00004_ooool001ko
oooo00?o0000ooooooooool0;?ooool2o`0000Kooooo0_l00009ooooo`;o000000?oooooo`000?l0
00000_ooool4o`0001_ooooo0_l00002ooooo`;o00004?ooool2o`0002Kooooo0_l00027ooooo`;o
00006Oooool001kooooo00?o0000ooooooooool0;Oooool2o`00013ooooo0_l0000Tooooo`;o0000
2_ooool4o`0000Kooooo0_l0002^ooooo`?o00006Oooool001kooooo00?o0000ooooooooool05?oo
ool2o`0001Oooooo0_l0000`ooooo`;o00002Oooool2o`0000Cooooo1Ol0002fooooo`;o00006_oo
ool001kooooo00Co0000ooooool0003o00004oooool4o`0001Gooooo0_l0000`ooooo`;o00001_oo
ool2o`000003ooooool0003o000000Cooooo0_l0000:ooooo`;o0000=?ooool2o`0009?ooooo000N
ooooo`04o`000?oooooo0000o`0001Gooooo0_l0000Eooooo`;o00005Oooool2o`0001Wooooo0_l0
0006ooooo`;o000000?oooooo`000?l000004?ooool2o`0003Cooooo0_l0000`ooooo`;o0000HOoo
ool001kooooo00?o0000ooooooooool01Oooool2o`0003gooooo0_l00005ooooo`;o00004_ooool2
o`0000Oooooo1?l00005ooooo`;o000000?oooooo`000?l000001Oooool2o`0000oooooo0_l0001F
ooooo`;o0000HOooool001kooooo00?o0000ooooooooool01Oooool2o`0003[ooooo0_l00002oooo
o`;o00000oooool3o`0000[ooooo0_l0000;ooooo`;o00000_ooool4o`0000Gooooo0_l000000ooo
oooo0000o`000005ooooo`;o00001Oooool2o`0000Sooooo0_l0000?ooooo`;o00007?ooool2o`00
08[ooooo000Nooooo`03o`000?oooooooooo047ooooo0_l000000ooooooo0000o`000007o`0000So
oooo1?l0000;ooooo`;o00007?ooool2o`0001Wooooo0_l0000Looooo`;o0000R_ooool001kooooo
00?o0000ooooooooool0@_ooool4o`000003ooooool0003o000000;o00001?ooool2o`0000Cooooo
0_l0000aooooo`;o0000_Oooool001kooooo00Co0000ooooool0003o0000@Oooool2o`0000Gooooo
0_l00004ooooo`?o00009?ooool2o`0000Cooooo0_l0000:ooooo`;o0000<_ooool2o`0008Wooooo
000Nooooo`04o`000?oooooo0000o`0004Kooooo1Ol000001?oooooo0000o`000?ooool4o`0000?o
oooo0_l0000Booooo`;o00002Oooool2o`0000Cooooo0_l0000nooooo`;o0000ROooool001kooooo
00?o0000ooooooooool03?ooool2o`0000;ooooo0_l0000Vooooo`;o00001oooool2o`000004oooo
ool0003o0000ooooo`Go000000?oooooo`000?l000000oooool3o`0000;ooooo0_l0000Booooo`;o
0000f_ooool001kooooo00?o0000ooooooooool03?ooool2o`0000;ooooo1?l0000Mooooo`;o0000
1Oooool2o`0000Oooooo0_l000001?oooooo0000o`000?ooool5o`0000Oooooo0_l0000Qooooo`;o
0000/?ooool2o`0001gooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo00cooooo0_l00004oooo
o`Go00006_ooool2o`00017ooooo0_l000000ooooooo0000o`000005o`0000Gooooo0_l0000Ioooo
o`;o00001_ooool2o`0003Oooooo0_l0000Booooo`;o0000Hoooool2o`0001gooooo0003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06
ooooo`03o`000?oooooooooo00cooooo0_l00006ooooo`Co00009_ooool2o`0000;ooooo0_l00003
ooooo`Oo00001?ooool3o`0001Wooooo0_l0000oooooo`;o00004_ooool2o`0008;ooooo0003oooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
000Fooooo`;o00000_ooool2o`0002;ooooo0_l000001?oooooo0000o`000?l00005ooooo`?o0000
0_ooool2o`0000;ooooo0_l00002ooooo`;o0000koooool000?ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool00ol0003oooooooooo`0Booooo`;o
000000?oooooo`000?l000000oooool2o`0002Gooooo0_l00004ooooo`Wo000000?oooooo`000?l0
00000oooool2o`0001[ooooo0_l0000Nooooo`;o0000<?ooool2o`00087ooooo0003ooooo`05o`00
0?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000oooo
ooooool03Oooool2o`0000?ooooo1Ol0000Nooooo`Go00003?ooool:o`000003ooooool0003o0000
01oooooo0_l0000Nooooo`;o00004Oooool2o`0001gooooo0_l00021ooooo`000oooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooo
oooo00gooooo0_l00004ooooo`?o00006_ooool2o`0000?ooooo1Ol000000ooooooo0000o`000006
ooooo`;o000000?oooooo`000?l000000ol0000=ooooo`;o0000Boooool2o`0001gooooo0_l00021
ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00
0006ooooo`03o`000?oooooooooo01?ooooo0ol0000Jooooo`;o00000_ooool5o`0000;ooooo0_l0
0006ooooo`;o00000_ooool3o`0000[ooooo0_l00002ooooo`;o0000kOooool000?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003ooooo
ooooo`0Booooo`Co000000?oooooo`000?l000002Oooool2o`00013ooooo1?l000000ooooooo0000
o`000002o`000003ooooool0003o000000?ooooo1?l0000;ooooo`Co0000lOooool001kooooo00?o
0000ooooooooool01Oooool2o`0000_ooooo0_l00003ooooo`;o00002Oooool3o`0001Cooooo0_l0
0002ooooo`?o00001Oooool2o`0000_ooooo0_l0000;ooooo`;o0000i_ooool001kooooo00?o0000
ooooooooool01Oooool2o`0001cooooo0_l0000?ooooo`Co00001Oooool2o`0000Gooooo0_l00003
ooooo`;o00001?ooool3o`0000?ooooo0_l00008ooooo`;o0000i_ooool001kooooo00?o0000oooo
ooooool05?ooool3o`0001Sooooo0_l00003ooooo`Go000000?oooooo`000?l000000_l00006oooo
o`?o00000_ooool2o`0000Cooooo0ol00003ooooo`;o0000X?ooool2o`0004kooooo000Nooooo`03
o`000?oooooooooo01Cooooo0ol00008ooooo`;o00002_ooool3o`000003ooooool0003o000000Ko
oooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l00002ooooo`;o00002?ooool2o`0002go
oooo0_l0001gooooo`;o0000C_ooool001kooooo00?o0000ooooooooool04oooool4o`0000Sooooo
0_l000000ooooooo0000o`000007ooooo`Go000000?oooooo`000?l000000_l00002ooooo`;o0000
1?ooool8o`0000?ooooo0_l00005ooooo`;o00008Oooool3o`0000Wooooo0_l00037ooooo`007_oo
ool00ol0003oooooooooo`0=ooooo`;o00001?ooool2o`0000gooooo0_l00006ooooo`?o000000Co
ooooo`000?l0003ooooo1Ol000000ooooooo0000o`000002ooooo`[o00000oooool2o`0000?ooooo
1?l0000Hooooo`;o00001Oooool5o`0000Oooooo0_l0002?ooooo`;o0000>?ooool001kooooo1?l0
0004ooooo`;o00001_ooool2o`0001_ooooo0_l00006ooooo`Co000000?oooooo`000?l000000_oo
ool6o`0000;ooooo0ol00003ooooo`So00006?ooool2o`0000Gooooo0_l00002ooooo`;o00001_oo
ool2o`0000Oooooo0_l0000=ooooo`;o00002?ooool2o`0006gooooo0_l0000Qooooo`;o00005Ooo
ool001kooooo1?l00004ooooo`;o00004Oooool2o`0001Sooooo0_l00007ooooo`;o000000Cooooo
o`000?l0003o00000oooool3o`0000;ooooo2?l00008ooooo`;o00006Oooool2o`0000oooooo0_l0
000=ooooo`;o00002?ooool2o`0002Sooooo0_l0001Vooooo`;o00005Oooool001kooooo00?o0000
ooooooooool06?ooool2o`0000Sooooo0_l0000<ooooo`;o00001_ooool2o`0000_ooooo0_l00003
ooooo`Oo00002?ooool2o`0000_ooooo0_l0001Pooooo`;o0000>oooool2o`0003Gooooo0_l00009
ooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o00000_ooool2o`0000Sooooo0_l00007oooo
o`;o00000oooool2o`0000Kooooo0_l00002ooooo`;o000000?oooooo`000?l000000oooool2o`00
00?ooooo0ol00003ooooo`;o00003Oooool2o`0000Kooooo0_l0002Mooooo`;o0000<?ooool2o`00
00?ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o00002Oooool2o`0000[o
oooo0_l0000?ooooo`Go00000oooool2o`0000?ooooo0ol0000Booooo`;o00006?ooool2o`0001go
oooo0_l0002Nooooo`;o00003_ooool001kooooo0_l0000Eooooo`;o00002Oooool2o`000003oooo
ool0003o0000013ooooo0_l00006ooooo`?o00001?ooool2o`0000;ooooo1?l00005ooooo`;o0000
00?oooooo`000?l000000oooool2o`0000Gooooo0_l00005ooooo`;o00004?ooool2o`0001gooooo
0_l0002^ooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o00001Oooool2o`0000Gooooo0ol0
000?ooooo`?o00001Oooool2o`0000Gooooo1_l00007ooooo`;o000000?oooooo`000?l000000ooo
ool2o`0000Gooooo1_l000000ooooooo0000o`00000Pooooo`;o0000_Oooool001kooooo00?o0000
ooooooooool03_ooool2o`0000?ooooo0ol00005ooooo`?o00001Oooool2o`0000oooooo0ol00005
ooooo`;o00001oooool8o`0000Kooooo1?l00009ooooo`Oo00002?ooool3o`0000Cooooo0_l0000@
ooooo`;o0000AOooool2o`0007Kooooo000Nooooo`?o00003_ooool2o`0000?ooooo0_l00003oooo
o`;o00000_ooool2o`0000Cooooo0_l0000Hooooo`;o00002_ooool5o`0000?ooooo0_l000000ooo
oooo0000o`000003o`0000;ooooo0_l00002ooooo`;o00001Oooool4o`0000?ooooo0_l000001?oo
oooo0000o`000?l00004ooooo`?o0000E_ooool2o`0007Kooooo000Nooooo`?o00003?ooool2o`00
00[ooooo0ol00007ooooo`;o00002oooool2o`0000?ooooo0_l0000;ooooo`;o00000oooool2o`00
00Sooooo1?l00002ooooo`;o00000_ooool3o`000003ooooool0003o000000Oooooo0_l00003oooo
o`;o00002Oooool2o`0000;ooooo0_l0000=ooooo`Co0000QOooool2o`0003;ooooo000Nooooo`03
o`000?oooooooooo00cooooo0_l00006ooooo`;o00000oooool2o`0001Cooooo0_l00003ooooo`;o
00002oooool2o`000003ooooool0003o000000;o00001?ooool2o`0000;ooooo1?l00003ooooo`;o
00000_ooool2o`0001kooooo0_l0000;ooooo`Ko00000oooool2o`00083ooooo0_l0000booooo`00
7_ooool00ol0003oooooooooo`0Dooooo`;o00005?ooool2o`0000cooooo0_l00007ooooo`;o0000
00?oooooo`000?l000000_ooool2o`0000;ooooo0_l000001?oooooo0000o`000?l00004ooooo`?o
00001?ooool4o`0002Oooooo0_l000000ooooooo0000o`000004ooooo`;o0000]?ooool001kooooo
00?o0000ooooooooool0:_ooool2o`0000cooooo0_l00007ooooo`;o000000?oooooo`000?l00000
0_ooool2o`000004ooooool0003o0000ooooo`Co000000?oooooo`000?l000000ol00002ooooo`;o
000000?oooooo`000?l000000_l00004ooooo`;o000000?oooooo`000?l000001oooool2o`000=Co
oooo000Nooooo`03o`000?oooooooooo01?ooooo0_l0000Sooooo`;o00002Oooool3o`0000Gooooo
0_l000000ooooooo0000o`000002o`000003ooooool0003o000000;o00000oooool2o`0000;ooooo
0ol00004ooooo`Go00001oooool4o`0001[ooooo0_l0002fooooo`007_ooool00ol0003ooooooooo
o`0Cooooo`;o00006Oooool2o`0000Sooooo0_l00009ooooo`Co00001_ooool2o`0000?ooooo0ol0
0009ooooo`?o00001Oooool2o`000003ooooool0003o000000;ooooo0ol00003ooooo`;o00006_oo
ool2o`0000Wooooo0_l0000]ooooo`;o0000O?ooool001kooooo00?o0000ooooooooool0;_ooool2
o`0000?ooooo0_l00002ooooo`?o00001oooool2o`0000;ooooo0_l00003ooooo`Go00000oooool5
o`0000;ooooo0_l00003ooooo`Ko000000?oooooo`000?l000001?l00002ooooo`?o0000:_ooool2
o`0002gooooo0_l00013ooooo`;o0000=oooool001kooooo00?o0000ooooooooool0;_ooool2o`00
00?ooooo0_l00002ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Oooooo1ol00003oooo
o`?o00000_ooool2o`000004ooooool0003o0000ooooo`[o00001_ooool3o`0009cooooo0_l0000g
ooooo`007_ooool01?l0003oooooo`000?l0000@ooooo`;o00006oooool2o`0000[ooooo0_l00006
ooooo`;o00002?ooool8o`0000;ooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo1?l0
0004ooooo`?o00000_ooool3o`0000?ooooo0_l0000=ooooo`;o0000`Oooool001kooooo00Co0000
ooooool0003o00004?ooool2o`0001kooooo0_l0000;ooooo`;o00000_ooool3o`0000?ooooo1ol0
0002ooooo`?o00000_ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l00000
0_ooool4o`0000?ooooo0ol00002ooooo`;o00001?ooool2o`0000gooooo0_l0000Mooooo`;o0000
X_ooool001kooooo00?o0000ooooooooool0<Oooool2o`0000_ooooo0_l00003ooooo`Co000000?o
ooooo`000?l000000_l0000:ooooo`;o000000?oooooo`000?l000001?ooool3o`0000;ooooo0ol0
0004ooooo`Ko000000?oooooo`000?l000008Oooool2o`0000cooooo0_l0000dooooo`;o0000K?oo
ool001kooooo00?o0000ooooooooool07?ooool2o`0002Oooooo0_l0000;ooooo`;o00000_ooool2
o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000004ooooo`Ko000000?ooooo
o`000?l000000oooool2o`0000Sooooo0_l0000Gooooo`;o00007oooool2o`00027ooooo0_l0001/
ooooo`007_ooool2o`0001gooooo0_l0000:ooooo`;o00002Oooool2o`0000Oooooo0_l00007oooo
o`Co00002Oooool4o`0000Oooooo0_l00003ooooo`;o00000_ooool6o`0000Oooooo0_l00007oooo
o`;o0000>?ooool2o`0008oooooo000Nooooo`03o`000?oooooooooo02Sooooo0_l00009ooooo`;o
00001oooool2o`0000Gooooo0_l00002ooooo`;o00000_ooool2o`0000Oooooo0_l0000:ooooo`Co
00001?ooool5o`0000Kooooo0_l0000>ooooo`;o0000[_ooool2o`0001;ooooo000Nooooo`;o0000
:_ooool2o`0000_ooooo0_l0000;ooooo`;o00001_ooool4o`0000kooooo0_l000000ooooooo0000
o`000006ooooo`Oo00005?ooool2o`0001;ooooo0_l0002Jooooo`;o00004_ooool001kooooo0_l0
000Uooooo`;o00000oooool2o`0000_ooooo0_l0000<ooooo`;o00001oooool3o`0000;ooooo0_l0
0009ooooo`;o00001_ooool2o`0000Cooooo1_l00008ooooo`;o00002_ooool2o`00013ooooo0_l0
002^ooooo`007_ooool00ol0003oooooooooo`0Tooooo`;o00007_ooool2o`0000Sooooo0_l00002
ooooo`;o00004Oooool2o`0000Oooooo1?l00007ooooo`;o00002_ooool2o`0002oooooo0_l0001H
ooooo`;o0000=Oooool001kooooo00?o0000ooooooooool0=Oooool2o`00023ooooo0_l0000Doooo
o`Go0000A?ooool2o`0005Sooooo0_l0000eooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o
00006oooool2o`00023ooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo1?l0000Sooooo`;o
0000/Oooool001kooooo00?o0000ooooooooool06?ooool2o`0000Oooooo0_l0000_ooooo`;o0000
1oooool2o`000003ooooool0003o000000Gooooo0_l00005ooooo`;o00003?ooool2o`0001Sooooo
0_l0002aooooo`007_ooool00ol0003oooooooooo`0Qooooo`;o0000;Oooool4o`0000?ooooo0_l0
0002ooooo`Co00001_ooool2o`0000Gooooo0_l0000<ooooo`;o0000TOooool2o`0001Sooooo0_l0
000Nooooo`007_ooool00ol0003oooooooooo`1@ooooo`;o00001Oooool2o`0000Cooooo0_l00000
0ooooooo0000o`00000>ooooo`?o000000?oooooo`000?l000000_ooool2o`0005Sooooo0_l0000B
ooooo`;o00009Oooool2o`0001Sooooo0_l0000Nooooo`007_ooool00ol0003oooooooooo`0Foooo
o`Co00006Oooool2o`0001_ooooo0_l00009ooooo`Co000000?oooooo`000?l000000_l00009oooo
o`;o000000Goooooo`000?l0003o0000ooooo`02o`0000;ooooo0_l0000Kooooo`;o0000>oooool2
o`0001;ooooo0_l0000cooooo`;o0000:_ooool001kooooo00?o0000ooooooooool05_ooool4o`00
01?ooooo0_l00004ooooo`;o00007?ooool2o`0000Sooooo1Ol000001?oooooo0000o`000?l00008
ooooo`?o00002Oooool2o`0000;ooooo0_l0000Gooooo`;o0000Aoooool2o`0002oooooo0_l0000:
ooooo`;o0000:_ooool001kooooo00?o0000ooooooooool0;Oooool2o`0000Kooooo1?l0000Hoooo
o`;o00001oooool2o`000005ooooool0003o0000o`000?ooool00_l00009ooooo`;o00002_ooool2
o`000004ooooool0003o0000o`0000Wooooo0_l0000]ooooo`;o00000_ooool2o`0002;ooooo0_l0
000Aooooo`;o00004Oooool2o`0000Wooooo0_l0000fooooo`007_ooool00ol0003oooooooooo`0e
ooooo`Co00008Oooool2o`0000Oooooo0_l000000ooooooo0000o`000005ooooo`;o00003?ooool2
o`0000[ooooo0_l00002ooooo`;o00001_ooool2o`00027ooooo0_l00002ooooo`;o0000=Oooool2
o`00017ooooo0_l00005ooooo`;o0000>_ooool001kooooo00?o0000ooooooooool02?ooool2o`00
03Oooooo0_l0000Hooooo`?o00000oooool9o`0000?ooooo0_l0000Looooo`;o00001_ooool2o`00
07Kooooo0_l00008ooooo`;o0000<?ooool001kooooo00?o0000ooooooooool02?ooool2o`0003Oo
oooo0_l0000Aooooo`Co00000oooool3o`0000?ooooo0_l000001Ooooooo0000o`000?l0003ooooo
00;o00002oooool2o`0003Gooooo0_l0001Wooooo`;o0000<?ooool001kooooo0_l0000Hooooo`;o
00009oooool2o`0001;ooooo1?l0000=ooooo`;o00002Oooool2o`0000?ooooo0_l0000eooooo`;o
0000H_ooool2o`0003Gooooo000Nooooo`03o`000?oooooooooo00gooooo0_l00008ooooo`;o0000
9oooool2o`0002Kooooo0_l00006ooooo`;o00001Oooool2o`0000Wooooo0_l0000Iooooo`;o0000
LOooool2o`0003Gooooo000Nooooo`03o`000?oooooooooo00gooooo0_l0000Xooooo`;o00008?oo
ool2o`0000[ooooo0_l000000ooooooo0000o`00000=ooooo`;o00002Oooool2o`0001Wooooo0_l0
000`ooooo`;o0000M_ooool001kooooo00?o0000ooooooooool0:Oooool2o`0000cooooo0_l00003
ooooo`;o00006oooool2o`0000[ooooo0_l000000ooooooo0000o`000004ooooo`;o00002Oooool4
o`0005;ooooo0_l0001fooooo`007_ooool00ol0003oooooooooo`0Yooooo`;o00004Oooool2o`00
013ooooo0_l00006ooooo`;o00004?ooool2o`0000?ooooo0ol00007ooooo`Ko0000>oooool2o`00
01kooooo0_l0001]ooooo`007_ooool00ol0003oooooooooo`1>ooooo`;o00000_ooool2o`0000;o
oooo0ol0000=ooooo`;o00001Oooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`0000oo
oooo0_l0000^ooooo`;o00007_ooool2o`0006gooooo000Nooooo`03o`000?oooooooooo02_ooooo
0_l0000Uooooo`;o00000_ooool3o`0000Gooooo0_l00006ooooo`;o00002_ooool2o`000003oooo
ool0003o0000017ooooo1?l0000Dooooo`;o0000;oooool2o`0007Cooooo000Nooooo`03o`000?oo
oooooooo00Gooooo0_l0000Tooooo`;o0000:Oooool2o`000003ooooool0003o000000?ooooo0_l0
00000ooooooo0000o`00000:ooooo`;o00006oooool2o`0000Wooooo0_l00009ooooo`;o0000;ooo
ool2o`0007Cooooo000Nooooo`03o`000?oooooooooo00Gooooo0_l0000oooooo`;o00002oooool3
o`0000?ooooo0_l00006ooooo`;o00002_ooool2o`0002Kooooo0_l0002Gooooo`;o00005oooool0
01kooooo00?o0000ooooooooool0>oooool2o`0000Wooooo0_l0000;ooooo`?o00001_ooool2o`00
0=3ooooo0_l0000Gooooo`007_ooool00ol0003oooooooooo`0_ooooo`;o00002_ooool2o`0001So
oooo0ol00003ooooo`Co00002oooool2o`0007gooooo0_l0001Looooo`007_ooool00ol0003ooooo
ooooo`07ooooo`;o00009_ooool2o`0000;ooooo0_l0000=ooooo`;o00004Oooool5o`000003oooo
ool0003o000000;o00002oooool2o`0000Cooooo0_l0001gooooo`;o0000G?ooool001kooooo00?o
0000ooooooooool01oooool2o`0001Oooooo0_l0000Aooooo`;o00003Oooool2o`0001Cooooo0_l0
0004ooooo`;o00004?ooool2o`0000Kooooo0_l0000@ooooo`;o0000Qoooool2o`0002Wooooo0_l0
0007ooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o00001?ooool2o`0003Oooooo0_l00003
ooooo`;o00006?ooool2o`000003ooooool0003o000000gooooo0_l00027ooooo`;o0000:Oooool2
o`0000Oooooo000Dooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`0Joooo
o`;o0000?Oooool2o`00023ooooo0_l0000cooooo`;o0000UOooool001Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`1Dooooo`;o0000F_ooool2o`0009Gooooo000Fooooo`03o`00
0?oooooooooo00Gooooo0ol00019ooooo`;o00002Oooool2o`000?7ooooo000Fooooo`03o`000?oo
oooooooo057ooooo0_l0003looooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Foooo
o`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`00
5?ooool00omEEEGoIVIVo`00003ooooooe;ooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.09405 .81876 Mdot
.48872 .03412 Mdot
.37828 .88126 Mdot
.17734 .80719 Mdot
.27549 .89176 Mdot
.2447 .87631 Mdot
.36156 .96809 Mdot
.28989 .85614 Mdot
.15605 .83975 Mdot
.22683 .34625 Mdot
.32064 .78449 Mdot
.31642 .88542 Mdot
.3625 .91358 Mdot
.48962 .86043 Mdot
.28692 .89252 Mdot
.25697 .1496 Mdot
.25892 .28271 Mdot
.3412 .97835 Mdot
.11417 .81319 Mdot
.12842 .81643 Mdot
.62055 .80451 Mdot
.19292 .91826 Mdot
.35123 .97421 Mdot
.43322 .65972 Mdot
.16444 .79201 Mdot
.26954 .82983 Mdot
.22225 .82911 Mdot
.24299 .17025 Mdot
.33113 .82282 Mdot
.20774 .88978 Mdot
.31664 .90473 Mdot
.27573 .89119 Mdot
.16965 .81916 Mdot
.28503 .51028 Mdot
.22201 .67722 Mdot
.22188 .75591 Mdot
.53133 .84652 Mdot
.91673 .88718 Mdot
.30228 .94661 Mdot
.2163 .77985 Mdot
.28358 .88902 Mdot
.26266 .79871 Mdot
.40152 .99166 Mdot
.73032 .57878 Mdot
.33189 .77352 Mdot
.31885 .79852 Mdot
.32236 .76321 Mdot
.32171 .0383 Mdot
.23874 .74812 Mdot
.2882 .02609 Mdot
.36594 .04919 Mdot
.42389 .84093 Mdot
.32914 .88953 Mdot
.24092 .87043 Mdot
.36459 .92975 Mdot
.24072 .74255 Mdot
.79417 .86389 Mdot
.33825 .89622 Mdot
.22587 .83478 Mdot
.04782 .72558 Mdot
.26097 .83209 Mdot
.25684 .84402 Mdot
.52999 .76394 Mdot
.14653 .8007 Mdot
.27667 .85567 Mdot
.18211 .90071 Mdot
.44848 .82797 Mdot
.22316 .82896 Mdot
.26015 .89759 Mdot
.81538 .9349 Mdot
.48783 .60607 Mdot
.24665 .77028 Mdot
.99676 .92255 Mdot
.25064 .46115 Mdot
.32937 .74217 Mdot
.79888 .91702 Mdot
.19497 .98523 Mdot
.3305 .53582 Mdot
.24 .86486 Mdot
.20753 .86868 Mdot
.29181 .86648 Mdot
.499 .63611 Mdot
.71266 .31752 Mdot
.27916 .85806 Mdot
.33733 .68825 Mdot
.69907 .68952 Mdot
.27287 .84176 Mdot
.23776 .78165 Mdot
.27846 .89715 Mdot
.15819 .75258 Mdot
.11971 .82547 Mdot
.68875 .74919 Mdot
.32087 .76301 Mdot
.03967 .58803 Mdot
.06612 .79523 Mdot
.32623 .84406 Mdot
.85099 .88975 Mdot
.29176 .73469 Mdot
.23769 .87055 Mdot
.06073 .88108 Mdot
.27347 .85367 Mdot
.35 .04625 Mdot
.02636 .89201 Mdot
.4574 .08366 Mdot
.56198 .94864 Mdot
.33913 .98255 Mdot
.31449 .93994 Mdot
.28848 .07614 Mdot
.44343 .9138 Mdot
.93017 .57466 Mdot
.55603 .90098 Mdot
.6514 .42611 Mdot
.18357 .87021 Mdot
.34601 .9463 Mdot
.27762 .73985 Mdot
.30953 .02942 Mdot
.51229 .80846 Mdot
.36276 .92382 Mdot
.35267 .70746 Mdot
.24215 .81009 Mdot
.22401 .78991 Mdot
.39689 .01715 Mdot
.29483 .80188 Mdot
.12118 .61188 Mdot
.37547 .06935 Mdot
.84938 .05751 Mdot
.48859 .90901 Mdot
.10509 .82491 Mdot
.25294 .49997 Mdot
.99232 .02872 Mdot
.63345 .97764 Mdot
.29187 .67842 Mdot
.38324 .92505 Mdot
.27118 .99012 Mdot
.26259 .93144 Mdot
.39375 .97228 Mdot
.3449 .98671 Mdot
.3322 .00414 Mdot
.25557 .8784 Mdot
.18938 .88078 Mdot
.124 .8657 Mdot
.15377 .80431 Mdot
.18089 .89675 Mdot
.98138 .71749 Mdot
.50107 .84762 Mdot
.35412 .81585 Mdot
.07748 .86758 Mdot
.25014 .82549 Mdot
.83731 .05524 Mdot
.59718 .56151 Mdot
.08031 .88567 Mdot
.18186 .8461 Mdot
.28351 .90564 Mdot
.12778 .80748 Mdot
.27324 .88131 Mdot
.34032 .90851 Mdot
.27845 .03201 Mdot
.67273 .32934 Mdot
.17274 .82381 Mdot
.21595 .15444 Mdot
.31187 .03884 Mdot
.0823 .68621 Mdot
.26896 .618 Mdot
.25865 .97515 Mdot
.22693 .85179 Mdot
.29872 .91812 Mdot
.26036 .81398 Mdot
.20782 .82539 Mdot
.08586 .5107 Mdot
.26792 .00469 Mdot
.23039 .86891 Mdot
.11061 .72434 Mdot
.16965 .68005 Mdot
.65338 .72624 Mdot
.0697 .79787 Mdot
.24922 .87688 Mdot
.21012 .63737 Mdot
.32086 .82418 Mdot
.18394 .11973 Mdot
.41074 .8134 Mdot
.29015 .01017 Mdot
.36711 .80851 Mdot
.14453 .69727 Mdot
.47337 .76483 Mdot
.26713 .30981 Mdot
.24951 .04412 Mdot
.19102 .18738 Mdot
.14228 .85454 Mdot
.99547 .56942 Mdot
.949 .80619 Mdot
.08327 .80373 Mdot
.47753 .70348 Mdot
.10273 .82968 Mdot
.49299 .78894 Mdot
.22978 .74677 Mdot
.36922 .93747 Mdot
.08369 .66241 Mdot
.37678 .7477 Mdot
.15037 .83815 Mdot
.27218 .76499 Mdot
.98368 .90383 Mdot
.59111 .3527 Mdot
.27825 .97175 Mdot
.4793 .81586 Mdot
.16134 .79316 Mdot
.23402 .77921 Mdot
.7533 .09832 Mdot
.24584 .82014 Mdot
.89688 .59846 Mdot
.21924 .90865 Mdot
.27035 .98594 Mdot
.10067 .86842 Mdot
.44058 .57105 Mdot
.47443 .48064 Mdot
.32465 .02718 Mdot
.30205 .28933 Mdot
.24713 .79263 Mdot
.18664 .59848 Mdot
.18131 .1231 Mdot
.34526 .75667 Mdot
.87411 .15375 Mdot
.09031 .70907 Mdot
.16729 .81434 Mdot
.21212 .84187 Mdot
.09008 .71861 Mdot
.26213 .84144 Mdot
.99197 .02663 Mdot
.39492 .96371 Mdot
.14221 .28837 Mdot
.17688 .90195 Mdot
.30941 .86986 Mdot
.06359 .70919 Mdot
.19824 .87995 Mdot
.55861 .61052 Mdot
.32591 .3255 Mdot
.01366 .56979 Mdot
.764 .10082 Mdot
.35628 .91601 Mdot
.68064 .88706 Mdot
.80579 .11564 Mdot
.35085 .91978 Mdot
.20205 .89471 Mdot
.40919 .04424 Mdot
.16361 .02381 Mdot
.24693 .89123 Mdot
.25736 .80896 Mdot
.13757 .64665 Mdot
.21242 .88289 Mdot
.71872 .17999 Mdot
.30735 .88914 Mdot
.44195 .85046 Mdot
.3527 .95321 Mdot
.61322 .30761 Mdot
.47151 .05655 Mdot
.98396 .09751 Mdot
.29485 .10386 Mdot
.31211 .89459 Mdot
.69326 .99247 Mdot
.36207 .85233 Mdot
.67307 .74971 Mdot
.09585 .8513 Mdot
.25078 .96566 Mdot
.21421 .18487 Mdot
.23056 .75941 Mdot
.19562 .89006 Mdot
.87509 .00595 Mdot
.20357 .00759 Mdot
.46232 .09553 Mdot
.36388 .92033 Mdot
.21179 .79884 Mdot
.23323 .86388 Mdot
.39009 .03631 Mdot
.27691 .86975 Mdot
.24129 .97082 Mdot
.2296 .81182 Mdot
.34772 .96888 Mdot
.21819 .15188 Mdot
.32419 .56827 Mdot
.23912 .79403 Mdot
.31085 .07478 Mdot
.7577 .81694 Mdot
.19473 .91164 Mdot
.27496 .97784 Mdot
.49774 .73133 Mdot
.2937 .89999 Mdot
.16536 .81144 Mdot
.27369 .00162 Mdot
.01458 .93446 Mdot
.28899 .0993 Mdot
.2885 .09755 Mdot
.3594 .09274 Mdot
.98671 .65263 Mdot
.13563 .82027 Mdot
.26062 .90209 Mdot
.89149 .82164 Mdot
.96885 .83359 Mdot
.31702 .85622 Mdot
.19445 .16288 Mdot
.74942 .92832 Mdot
.93727 .42141 Mdot
.0663 .98316 Mdot
.26971 .88013 Mdot
.14279 .64618 Mdot
.19078 .60186 Mdot
.00641 .27247 Mdot
.42851 .92577 Mdot
.22205 .83282 Mdot
.25128 .86332 Mdot
.65571 .63592 Mdot
.56618 .34235 Mdot
.23279 .80309 Mdot
.78217 .05362 Mdot
.26307 .83126 Mdot
.04244 .73069 Mdot
.20359 .77922 Mdot
.18696 .05178 Mdot
.27941 .70411 Mdot
.27941 .96073 Mdot
.21773 .80749 Mdot
.86265 .37989 Mdot
.2879 .98948 Mdot
.19448 .80925 Mdot
.30801 .08167 Mdot
.19981 .66536 Mdot
.32959 .93131 Mdot
.32414 .88062 Mdot
.23819 .78331 Mdot
.094 .87346 Mdot
.34928 .94099 Mdot
.2824 .8624 Mdot
.10447 .82513 Mdot
.23787 .89251 Mdot
.22675 .19236 Mdot
.03065 .96198 Mdot
.39091 .44911 Mdot
.25697 .56363 Mdot
.68074 .65343 Mdot
.21655 .80955 Mdot
.25495 .23196 Mdot
.55349 .7046 Mdot
.21549 .83842 Mdot
.46741 .52222 Mdot
.11635 .88855 Mdot
.20143 .65395 Mdot
.00918 .71833 Mdot
.06195 .19199 Mdot
.67694 .69567 Mdot
.08032 .40992 Mdot
.49126 .19427 Mdot
.29367 .85401 Mdot
.36143 .92028 Mdot
.33163 .91988 Mdot
.03865 .72558 Mdot
.32889 .20185 Mdot
.72845 .16643 Mdot
.27813 .85367 Mdot
.26939 .79301 Mdot
.25075 .92135 Mdot
.35859 .9155 Mdot
.0876 .6448 Mdot
.19981 .90193 Mdot
.08904 .93684 Mdot
.28898 .89512 Mdot
.28419 .99145 Mdot
.1938 .84211 Mdot
.31388 .7858 Mdot
.42821 .84624 Mdot
.00059 .50818 Mdot
.39406 .59492 Mdot
.2256 .9187 Mdot
.34751 .04631 Mdot
.22216 .83397 Mdot
.35168 .89408 Mdot
.16829 .89115 Mdot
.92178 .85163 Mdot
.16519 .99489 Mdot
.22071 .74715 Mdot
.2309 .74531 Mdot
.7479 .18846 Mdot
.208 .8558 Mdot
.24165 .86699 Mdot
.11115 .8234 Mdot
.36386 .05967 Mdot
.70158 .04328 Mdot
.19475 .07362 Mdot
.51242 .84372 Mdot
.37392 .0113 Mdot
.86386 .70691 Mdot
.21694 .81515 Mdot
.41368 .89883 Mdot
.12293 .86679 Mdot
.3057 .9489 Mdot
.31477 .84852 Mdot
.29681 .88155 Mdot
.27863 .88114 Mdot
.10354 .49111 Mdot
.24572 .30772 Mdot
.50664 .88733 Mdot
.22785 .83346 Mdot
.3026 .91187 Mdot
.45019 .91237 Mdot
.35594 .83354 Mdot
.40672 .97546 Mdot
.26228 .84916 Mdot
.38626 .66243 Mdot
.19708 .75972 Mdot
.30904 .11545 Mdot
.20589 .77454 Mdot
.2405 .64272 Mdot
.25975 .98273 Mdot
.337 .99807 Mdot
.1778 .80571 Mdot
.32274 .02655 Mdot
.83054 .79533 Mdot
.20259 .90729 Mdot
.29828 .99197 Mdot
.03402 .88115 Mdot
.26681 .86029 Mdot
.07534 .20242 Mdot
.24305 .86622 Mdot
.2135 .8036 Mdot
.71313 .09776 Mdot
.10142 .65282 Mdot
.30735 .96797 Mdot
.32339 .88243 Mdot
.57725 .57019 Mdot
.06436 .99792 Mdot
.15649 .87133 Mdot
.24252 .76302 Mdot
.84669 .56303 Mdot
.40831 .48124 Mdot
.57004 .90857 Mdot
.37311 .83863 Mdot
.10208 .83811 Mdot
.59581 .20059 Mdot
.20396 .19724 Mdot
.20027 .11167 Mdot
.04381 .03262 Mdot
.15552 .97261 Mdot
.28291 .75718 Mdot
.18999 .01389 Mdot
.67372 .7495 Mdot
.63043 .72527 Mdot
.28233 .85049 Mdot
.16399 .51363 Mdot
.27406 .84415 Mdot
.2052 .78856 Mdot
.27076 .94772 Mdot
.49651 .09591 Mdot
.31218 .84938 Mdot
.20831 .11112 Mdot
.44874 .93103 Mdot
.19674 .82173 Mdot
.23112 .85602 Mdot
.099 .03338 Mdot
.23226 .81495 Mdot
.15958 .80516 Mdot
.2345 .79867 Mdot
.23933 .50157 Mdot
.07791 .14657 Mdot
.21097 .8315 Mdot
.24209 .79817 Mdot
.23999 .86179 Mdot
.37936 .84272 Mdot
.58626 .74651 Mdot
.28512 .72215 Mdot
.18151 .8083 Mdot
.69977 .11118 Mdot
.29488 .87394 Mdot
.18631 .75847 Mdot
.21697 .91273 Mdot
.26566 .83579 Mdot
.27922 .85278 Mdot
.27981 .85572 Mdot
.36681 .86444 Mdot
.26329 .88199 Mdot
.35924 .93871 Mdot
.31134 .87944 Mdot
.01789 .80056 Mdot
.42185 .85916 Mdot
.33969 .39382 Mdot
.42964 .75042 Mdot
.19251 .90609 Mdot
.14133 .88635 Mdot
.09229 .82211 Mdot
.6628 .05814 Mdot
.54975 .25637 Mdot
.19466 .41606 Mdot
.04147 .77342 Mdot
.28958 .17373 Mdot
.34502 .90762 Mdot
.19767 .81647 Mdot
.13439 .81216 Mdot
.37641 .04935 Mdot
.12585 .78279 Mdot
.37261 .74461 Mdot
.19359 .92866 Mdot
.25672 .7585 Mdot
.7233 .74019 Mdot
.24308 .70637 Mdot
.19963 .92215 Mdot
.05324 .07982 Mdot
.1122 .68416 Mdot
.22736 .44363 Mdot
.31442 .99429 Mdot
.20009 .84021 Mdot
.25942 .83432 Mdot
.01059 .05656 Mdot
.16616 .80162 Mdot
.18903 .86114 Mdot
.20989 .91905 Mdot
.09524 .45421 Mdot
.25032 .68936 Mdot
.37177 .202 Mdot
.27888 .87892 Mdot
.7598 .62265 Mdot
.23695 .04027 Mdot
.31526 .82443 Mdot
.17819 .57692 Mdot
.2911 .9222 Mdot
.23681 .89791 Mdot
.38017 .85074 Mdot
.23988 .86517 Mdot
.2973 .77834 Mdot
.05406 .81574 Mdot
.93746 .98939 Mdot
.05838 .53261 Mdot
.42338 .65567 Mdot
.06374 .70554 Mdot
.21143 .52644 Mdot
.7559 .48404 Mdot
.54522 .71365 Mdot
.28498 .89442 Mdot
.37722 .97875 Mdot
.28479 .86537 Mdot
.25693 .85429 Mdot
.25506 .84579 Mdot
.1476 .82156 Mdot
.84853 .95484 Mdot
.9346 .73491 Mdot
.19179 .88174 Mdot
.64688 .95568 Mdot
.35817 .80204 Mdot
.2629 .87996 Mdot
.26531 .86363 Mdot
.84889 .80757 Mdot
.43823 .06109 Mdot
.25493 .79793 Mdot
.28138 .99674 Mdot
.32096 .8849 Mdot
.7914 .90184 Mdot
.01611 .77416 Mdot
.15355 .82535 Mdot
.45835 .54475 Mdot
.37072 .00215 Mdot
.73748 .28773 Mdot
.17815 .40428 Mdot
.21807 .80364 Mdot
.18671 .76752 Mdot
.08683 .75866 Mdot
.26688 .00565 Mdot
.29116 .79749 Mdot
.92092 .92387 Mdot
.09256 .87583 Mdot
.28267 .99838 Mdot
.24383 .76138 Mdot
.29463 .01059 Mdot
.18419 .82321 Mdot
.44823 .72502 Mdot
.27315 .89368 Mdot
.02482 .07082 Mdot
.41551 .11997 Mdot
.26402 .88161 Mdot
.08491 .8897 Mdot
.32432 .94487 Mdot
.15076 .86898 Mdot
.06076 .02882 Mdot
.33161 .82853 Mdot
.36312 .95836 Mdot
.33794 .81703 Mdot
.01891 .9995 Mdot
.15572 .98901 Mdot
.3177 .92558 Mdot
.1567 .87445 Mdot
.52543 .97333 Mdot
.22119 .74976 Mdot
.21952 .03738 Mdot
.48338 .75688 Mdot
.43219 .04329 Mdot
.06535 .80379 Mdot
.31981 .88313 Mdot
.37051 .91755 Mdot
.22407 .6432 Mdot
.24136 .7723 Mdot
.34388 .7941 Mdot
.25828 .8371 Mdot
.19661 .02031 Mdot
.30829 .88295 Mdot
.22389 .74631 Mdot
.25754 .73467 Mdot
.16185 .87226 Mdot
.21818 .82368 Mdot
.36275 .90699 Mdot
.28412 .72771 Mdot
.96802 .62909 Mdot
.25707 .96957 Mdot
.22876 .80303 Mdot
.20038 .90897 Mdot
.81869 .70224 Mdot
.09474 .82995 Mdot
.0312 .71163 Mdot
.64989 .03436 Mdot
.26361 .9163 Mdot
.84594 .6469 Mdot
.09874 .82756 Mdot
.20356 .16318 Mdot
.26429 .81882 Mdot
.74442 .07435 Mdot
.25961 .89423 Mdot
.27414 .12326 Mdot
.24517 .59127 Mdot
.03296 .10823 Mdot
.09544 .82262 Mdot
.57709 .15809 Mdot
.20367 .73944 Mdot
.18106 .99206 Mdot
.22775 .93151 Mdot
.70919 .47117 Mdot
.38574 .96473 Mdot
.40403 .86548 Mdot
.32246 .88489 Mdot
.20417 .8357 Mdot
.0511 .77269 Mdot
.25948 .8709 Mdot
.26338 .88009 Mdot
.09176 .53444 Mdot
.28505 .86071 Mdot
.24953 .60413 Mdot
.28315 .92444 Mdot
.29008 .89861 Mdot
.49367 .8725 Mdot
.26001 .88401 Mdot
.30174 .78359 Mdot
.39638 .87217 Mdot
.01091 .51794 Mdot
.18623 .8608 Mdot
.46951 .9388 Mdot
.89942 .70305 Mdot
.27637 .86665 Mdot
.84909 .69638 Mdot
.45804 .65215 Mdot
.32402 .75336 Mdot
.03008 .87442 Mdot
.21617 .84652 Mdot
.3746 .95929 Mdot
.20715 .78136 Mdot
.35127 .88649 Mdot
.74497 .91423 Mdot
.91106 .61197 Mdot
.22989 .82586 Mdot
.21981 .74997 Mdot
.35049 .93771 Mdot
.48822 .04398 Mdot
.22638 .7688 Mdot
.1649 .7479 Mdot
.30368 .60604 Mdot
.24659 .86578 Mdot
.72946 .94573 Mdot
.07713 .89572 Mdot
.10688 .87631 Mdot
.00534 .64287 Mdot
.45538 .79954 Mdot
.5389 .75557 Mdot
.20876 .80113 Mdot
.50299 .59696 Mdot
.25206 .83607 Mdot
.90794 .88339 Mdot
.30933 .95729 Mdot
.6571 .74379 Mdot
.81121 .78457 Mdot
.82167 .43916 Mdot
.99117 .75428 Mdot
.44495 .14982 Mdot
.10137 .81139 Mdot
.27221 .89199 Mdot
.09812 .73744 Mdot
.4612 .94825 Mdot
.56065 .79 Mdot
.12589 .93348 Mdot
.36031 .94299 Mdot
.32697 .0459 Mdot
.44365 .82012 Mdot
.15036 .5289 Mdot
.09754 .1143 Mdot
.1701 .84514 Mdot
.33896 .9311 Mdot
.2333 .85682 Mdot
.53405 .86393 Mdot
.216 .04688 Mdot
.6069 .87442 Mdot
.17051 .47606 Mdot
.3585 .19537 Mdot
.34792 .91486 Mdot
.22325 .88004 Mdot
.48673 .19884 Mdot
.27804 .79416 Mdot
.08198 .01891 Mdot
.53766 .69667 Mdot
.27441 .65101 Mdot
.13869 .83922 Mdot
.02729 .08536 Mdot
.23606 .7631 Mdot
.43262 .91637 Mdot
.7571 .36965 Mdot
.39485 .96962 Mdot
.95236 .9436 Mdot
.20345 .89666 Mdot
.29206 .86556 Mdot
.58555 .33331 Mdot
.22082 .87963 Mdot
.09682 .87947 Mdot
.12488 .78613 Mdot
.24514 .92251 Mdot
.76098 .8896 Mdot
.58645 .08701 Mdot
.71267 .02895 Mdot
.52785 .9758 Mdot
.22198 .78209 Mdot
.20075 .91786 Mdot
.89944 .69485 Mdot
.27194 .77639 Mdot
.24178 .82831 Mdot
.35806 .90565 Mdot
.17321 .85742 Mdot
.37963 .29246 Mdot
.96864 .95395 Mdot
.29137 .86747 Mdot
.12174 .41149 Mdot
.42435 .96602 Mdot
.24841 .57936 Mdot
.21676 .90883 Mdot
.13394 .8321 Mdot
.05422 .80134 Mdot
.63194 .84461 Mdot
.79833 .62952 Mdot
.48634 .91688 Mdot
.20366 .84583 Mdot
.79509 .80965 Mdot
.31175 .81356 Mdot
.55468 .88281 Mdot
.46494 .97737 Mdot
.32414 .88219 Mdot
.1546 .96332 Mdot
.08981 .89314 Mdot
.23798 .91307 Mdot
.2224 .87127 Mdot
.27358 .99835 Mdot
.24176 .83375 Mdot
.36076 .92905 Mdot
.33953 .90714 Mdot
.92718 .90378 Mdot
.28522 .85117 Mdot
.18433 .00638 Mdot
.32949 .88644 Mdot
.28872 .11897 Mdot
.22409 .8309 Mdot
.06612 .83937 Mdot
.90083 .11938 Mdot
.37726 .74815 Mdot
.2698 .68775 Mdot
.1735 .78398 Mdot
.04374 .84854 Mdot
.30399 .99473 Mdot
.35227 .95319 Mdot
.50971 .26267 Mdot
.20072 .89316 Mdot
.3547 .88873 Mdot
.34794 .9093 Mdot
.1111 .0487 Mdot
.34608 .12293 Mdot
.16748 .81189 Mdot
.15462 .94354 Mdot
.12125 .53671 Mdot
.14563 .79847 Mdot
.28004 .81128 Mdot
.25256 .12435 Mdot
.26866 .19928 Mdot
.18922 .87673 Mdot
.19871 .81973 Mdot
.34304 .89405 Mdot
.31275 .15526 Mdot
.38731 .63549 Mdot
.38827 .83399 Mdot
.29966 .82508 Mdot
.01189 .81669 Mdot
.3508 .88973 Mdot
.3228 .16842 Mdot
.23485 .0652 Mdot
.14739 .78333 Mdot
.13214 .6842 Mdot
.63058 .95449 Mdot
.20555 .89628 Mdot
.32278 .92578 Mdot
.24425 .73776 Mdot
.1518 .6884 Mdot
.32054 .98255 Mdot
.0046 .54785 Mdot
.14037 .55006 Mdot
.00639 .75243 Mdot
.18527 .7905 Mdot
.08781 .94575 Mdot
.18048 .75792 Mdot
.38218 .85079 Mdot
.35007 .67057 Mdot
.14464 .86821 Mdot
.22357 .8395 Mdot
.35224 .53845 Mdot
.78235 .02149 Mdot
.2877 .88135 Mdot
.61832 .89485 Mdot
.28556 .86196 Mdot
.30129 .88202 Mdot
.31611 .87322 Mdot
.34105 .90654 Mdot
.27717 .83871 Mdot
.33111 .08201 Mdot
.31216 .87555 Mdot
.23371 .86966 Mdot
.60074 .23289 Mdot
.27879 .7515 Mdot
.54586 .79579 Mdot
.96998 .93516 Mdot
.34846 .93913 Mdot
.659 .87545 Mdot
.42718 .75732 Mdot
.26066 .00511 Mdot
.08088 .42305 Mdot
.23785 .74704 Mdot
.19337 .84016 Mdot
.65275 .14731 Mdot
.30965 .58998 Mdot
.30516 .88651 Mdot
.22397 .83561 Mdot
.16539 .86064 Mdot
.79266 .93269 Mdot
.95065 .66719 Mdot
.67004 .10519 Mdot
.3647 .91225 Mdot
.25443 .83648 Mdot
.31715 .8818 Mdot
.92326 .98095 Mdot
.17636 .73179 Mdot
.26511 .87853 Mdot
.08189 .78764 Mdot
.24278 .78035 Mdot
.0381 .11243 Mdot
.28603 .8558 Mdot
.27294 .2167 Mdot
.39526 .85289 Mdot
.34021 .87665 Mdot
.2858 .87335 Mdot
.21923 .81292 Mdot
.139 .84589 Mdot
.41937 .94265 Mdot
.27155 .83048 Mdot
.35126 .76129 Mdot
.10041 .80824 Mdot
.20762 .11194 Mdot
.34011 .00412 Mdot
.32605 .892 Mdot
.04138 .93027 Mdot
.25091 .79906 Mdot
.156 .79137 Mdot
.17395 .79931 Mdot
.28231 .8618 Mdot
.27511 .85113 Mdot
.31721 .53789 Mdot
.13088 .40619 Mdot
.24623 .78146 Mdot
.19314 .88709 Mdot
.60865 .8494 Mdot
.2329 .85876 Mdot
.279 .84927 Mdot
.35643 .86242 Mdot
.36672 .80733 Mdot
.09074 .81695 Mdot
.09804 .88011 Mdot
.95934 .0941 Mdot
.19282 .91584 Mdot
.52639 .7904 Mdot
.23352 .62781 Mdot
.36855 .19713 Mdot
.44617 .91728 Mdot
.19523 .90855 Mdot
.48749 .72982 Mdot
.30558 .83234 Mdot
.95436 .10457 Mdot
.29159 .88663 Mdot
.05078 .82931 Mdot
.30975 .89299 Mdot
.20396 .89936 Mdot
.2524 .03888 Mdot
.90754 .17758 Mdot
.142 .95502 Mdot
.77077 .05156 Mdot
.03776 .1153 Mdot
.1132 .81325 Mdot
.20749 .92576 Mdot
.17184 .83837 Mdot
.11972 .89615 Mdot
.43333 .97311 Mdot
.1472 .88139 Mdot
.42146 .15228 Mdot
.13879 .82847 Mdot
.42209 .78504 Mdot
.2885 .50486 Mdot
.14461 .90621 Mdot
.10593 .81079 Mdot
.26374 .72312 Mdot
.16005 .86259 Mdot
.01425 .57499 Mdot
.14625 .54154 Mdot
.14311 .88491 Mdot
.27522 .8659 Mdot
.28464 .89677 Mdot
.64038 .05083 Mdot
.16762 .2394 Mdot
.11784 .05725 Mdot
.3755 .02406 Mdot
.90778 .62816 Mdot
.42071 .69172 Mdot
.33536 .99058 Mdot
.31702 .88633 Mdot
.19486 .8884 Mdot
.41104 .68765 Mdot
.10805 .84819 Mdot
.50443 .45973 Mdot
.2355 .84624 Mdot
.24484 .86246 Mdot
.55479 .72021 Mdot
.3401 .8987 Mdot
.22884 .84982 Mdot
.16939 .78783 Mdot
.88642 .8642 Mdot
.44735 .84158 Mdot
.25237 .87296 Mdot
.89811 .81093 Mdot
.40558 .75604 Mdot
.19012 .87378 Mdot
.35176 .41801 Mdot
.28158 .90745 Mdot
.79089 .92396 Mdot
.44745 .80774 Mdot
.38958 .52969 Mdot
.3219 .63921 Mdot
.37277 .89894 Mdot
.56229 .03917 Mdot
.02933 .00324 Mdot
.55474 .79331 Mdot
.60962 .99773 Mdot
.19784 .91462 Mdot
.22249 .84769 Mdot
.28984 .88385 Mdot
.12302 .70994 Mdot
.30485 .87857 Mdot
.53974 .20351 Mdot
.32616 .01783 Mdot
.26353 .88436 Mdot
.67136 .09558 Mdot
.62979 .43055 Mdot
.30649 .23438 Mdot
.65613 .59415 Mdot
.45165 .6724 Mdot
.96505 .89235 Mdot
.93672 .99267 Mdot
.25904 .83492 Mdot
.19477 .16169 Mdot
.83463 .53807 Mdot
.2294 .84661 Mdot
.24938 .81446 Mdot
.30944 .8847 Mdot
.07957 .7207 Mdot
.15462 .21992 Mdot
.19664 .1849 Mdot
.19957 .83637 Mdot
.45316 .92031 Mdot
.06362 .02114 Mdot
.94298 .39609 Mdot
.34106 .78466 Mdot
.23185 .82591 Mdot
.50522 .10469 Mdot
.16734 .80347 Mdot
.18471 .99688 Mdot
.42153 .4473 Mdot
.21941 .856 Mdot
.22383 .77792 Mdot
.31844 .86848 Mdot
.26347 .96137 Mdot
.23807 .04873 Mdot
.32006 .77766 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00Go
oooo0_l00006ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool2o`0000Oo
oooo00?o0000ooooooooool01oooool4o`0000;ooooo00?o0000ooooooooool00oooool2o`0000Wo
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool00_ooool001kooooo00?o0000ooooooooool01Oooool2o`0000Kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo
0_l00004ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01_l00007ooooo`03o`00
0?oooooooooo00Oooooo1?l00002ooooo`03o`000?oooooooooo00?ooooo0_l00009ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003oooooooooo`0hooooo`;o00001?oo
ool2o`00017ooooo1?l00005ooooo`Co0000^_ooool2o`0002gooooo000Nooooo`03o`000?oooooo
oooo03kooooo0_l0000Jooooo`Co00005oooool2o`000=3ooooo000Nooooo`03o`000?oooooooooo
03[ooooo0_l0000iooooo`;o0000d?ooool001kooooo00?o0000ooooooooool05oooool2o`00027o
oooo0_l0000Zooooo`;o00005Oooool2o`000<Sooooo000Nooooo`03o`000?oooooooooo017ooooo
0_l00004ooooo`;o00008oooool2o`0002Sooooo0_l0000Eooooo`;o0000Noooool2o`0004_ooooo
000Nooooo`03o`000?oooooooooo017ooooo0_l0000Nooooo`;o00002Oooool2o`0003Sooooo0_l0
0022ooooo`;o0000Boooool001kooooo00?o0000ooooooooool04?ooool2o`0001oooooo0_l0000W
ooooo`;o00002Oooool2o`0000oooooo0_l0001/ooooo`;o0000F?ooool3o`0000Kooooo000Noooo
o`03o`000?oooooooooo013ooooo0_l00014ooooo`;o00000_ooool2o`0000Gooooo0_l00002oooo
o`;o0000OOooool2o`0005Sooooo0ol00006ooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o
00004?ooool2o`0003Sooooo0_l00009ooooo`;o0000>?ooool2o`0003;ooooo0_l0001fooooo`00
7_ooool00ol0003oooooooooo`0:ooooo`;o00004?ooool2o`0002Gooooo0_l0000Oooooo`;o0000
5Oooool2o`0001kooooo0_l0000booooo`;o0000M_ooool001kooooo00?o0000ooooooooool0@ooo
ool2o`0000Cooooo0_l00003ooooo`;o00004Oooool2o`000003ooooool0003o000001Gooooo0_l0
000fooooo`;o0000T_ooool001kooooo00?o0000ooooooooool0BOooool2o`0000;ooooo0ol0000A
ooooo`;o00007_ooool2o`0000Gooooo0_l0000Aooooo`;o00005_ooool2o`0002_ooooo0_l0001U
ooooo`007_ooool00ol0003oooooooooo`12ooooo`;o00002Oooool2o`0001Oooooo0_l00005oooo
o`?o00004Oooool2o`0000Gooooo0_l0000Aooooo`;o0000@oooool2o`0006Gooooo000Nooooo`03
o`000?oooooooooo023ooooo0_l0000Pooooo`;o00001Oooool2o`0001_ooooo0_l00005ooooo`?o
00000oooool2o`000003ooooool0003o00000<oooooo000Nooooo`;o00008Oooool2o`0001Oooooo
0_l0000>ooooo`;o0000:?ooool2o`000003ooooool0003o000005Cooooo0_l0000Xooooo`;o0000
0_ooool2o`0004_ooooo000Nooooo`04o`000?oooooo0000o`0003Sooooo0_l0001Jooooo`;o0000
=Oooool2o`0002Sooooo0_l00002ooooo`;o00004?ooool2o`0003Wooooo000Nooooo`04o`000?oo
oooo0000o`00027ooooo0_l0001>ooooo`;o00008Oooool2o`0003cooooo0_l0000gooooo`;o0000
0_ooool2o`0003Gooooo000Nooooo`03o`000?oooooooooo02;ooooo0_l0001>ooooo`;o00005_oo
ool2o`0004Oooooo0_l0000kooooo`;o0000=Oooool001kooooo00?o0000ooooooooool0B?ooool2
o`00043ooooo0_l0002kooooo`007_ooool00ol0003oooooooooo`18ooooo`;o0000oOooool001ko
oooo00?o0000ooooooooool01?ooool2o`00073ooooo0_l0003?ooooo`007_ooool00ol0003ooooo
ooooo`04ooooo`;o0000=Oooool2o`0002Cooooo0_l0000Cooooo`;o0000M_ooool2o`0005Oooooo
000Nooooo`03o`000?oooooooooo03_ooooo0_l0000Mooooo`;o00001Oooool2o`0008_ooooo0_l0
001Gooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o0000Boooool2o`000>_ooooo000Noooo
o`03o`000?oooooooooo00gooooo0_l0001Aooooo`;o00001_ooool2o`0002Oooooo0_l0002doooo
o`007_ooool00ol0003oooooooooo`05ooooo`;o0000FOooool2o`0000Kooooo0_l0000Wooooo`;o
0000:?ooool2o`0008[ooooo000Nooooo`03o`000?oooooooooo00Gooooo0_l0002dooooo`;o0000
R_ooool001kooooo00?o0000ooooooooool0LOooool2o`000=Cooooo000Nooooo`03o`000?oooooo
oooo077ooooo0_l0000Oooooo`;o00002Oooool2o`0003Oooooo0_l0001Looooo`;o00004Oooool0
01kooooo00?o0000ooooooooool0F_ooool2o`0003Kooooo0_l00009ooooo`;o0000=oooool2o`00
00cooooo0_l0000;ooooo`;o0000@Oooool2o`0000Kooooo0_l00009ooooo`007_ooool2o`0005_o
oooo0_l00028ooooo`;o00002oooool2o`000003ooooool0003o000004Kooooo0_l00009ooooo`00
7_ooool00ol0003oooooooooo`1Looooo`;o0000@_ooool2o`0003Cooooo0_l0000Looooo`;o0000
??ooool2o`0001?ooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0001Cooooo`;o0000@_oo
ool2o`0003Cooooo0_l0001Jooooo`;o00004oooool001kooooo00?o0000ooooooooool01oooool2
o`0003Cooooo1Ol0002Mooooo`;o0000I_ooool001kooooo00?o0000ooooooooool02?ooool2o`00
01;ooooo0_l0000Oooooo`Go0000WOooool2o`0006Kooooo000Nooooo`03o`000?oooooooooo00So
oooo0_l0000Booooo`;o0000@_ooool2o`000:3ooooo0_l00013ooooo`007_ooool00ol0003ooooo
ooooo`08ooooo`;o0000;_ooool2o`00023ooooo0_l00004ooooo`;o00008Oooool2o`0007gooooo
0_l0000Mooooo`;o00009?ooool001kooooo00?o0000ooooooooool0=oooool3o`0001Cooooo0_l0
0005ooooo`;o00000oooool2o`00013ooooo0_l0000Eooooo`;o0000W?ooool2o`0002Cooooo000N
ooooo`03o`000?oooooooooo03Oooooo0_l0000Eooooo`;o00001Oooool2o`0001Gooooo0_l0003I
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o0000^Oooool2o`0007Go
oooo000Nooooo`;o00005_ooool2o`0002cooooo0_l0000:ooooo`;o0000??ooool2o`00047ooooo
0_l0001eooooo`007_ooool00ol0003oooooooooo`12ooooo`?o00002_ooool2o`0003Cooooo0_l0
0006ooooo`;o0000ROooool2o`0002gooooo000Nooooo`03o`000?oooooooooo04;ooooo0_l0000N
ooooo`;o00008Oooool2o`00037ooooo0_l0001Nooooo`;o0000;Oooool001kooooo00?o0000oooo
ooooool0H_ooool2o`0005Cooooo0_l0002=ooooo`007_ooool00ol0003oooooooooo`0kooooo`;o
000000?oooooo`000?l00000ooooool8ooooo`007_ooool00ol0003oooooooooo`0kooooo`;o0000
00?oooooo`000?l00000ZOooool2o`0005cooooo000Nooooo`03o`000?oooooooooo04_ooooo0_l0
000Hooooo`;o0000P_ooool2o`0005cooooo000Nooooo`03o`000?oooooooooo04_ooooo0_l0000H
ooooo`;o0000h?ooool001kooooo00?o0000ooooooooool0F_ooool2o`000>_ooooo000Nooooo`03
o`000?oooooooooo05[ooooo0_l00037ooooo`;o00008_ooool001kooooo00?o0000ooooooooool0
i_ooool2o`0003_ooooo0_l0000Rooooo`007_ooool00ol0003oooooooooo`0looooo`;o00001?oo
ool2o`000:;ooooo0_l0001Oooooo`007_ooool00ol0003oooooooooo`0jooooo`Co00001?ooool2
o`000:_ooooo0_l0001Fooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o0000:?ooool2o`00
0;?ooooo0_l0001Fooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00001_ooool00ol0003oooooooooo`0@ooooo`;o0000=?ooool2o`0005Cooooo0_l0002Yoooo
o`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@01_ooool00ol0003oooooooooo`0nooooo`;o00001_ooool2o`0002Sooooo0_l00002
ooooo`;o00009_ooool2o`000:Wooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0onHV9So8B4Qonk^kP07ooooo`?o0000?_ooool2o`0001?ooooo0_l0000Kooooo`;o00000_ooool2
o`0002Cooooo0_l0000Rooooo`;o0000Qoooool000?ooooo00Go0000ooooooooooooooooo`00000=
ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool05?ooool2o`0003gooooo0_l0000B
ooooo`;o00003?ooool2o`0002?ooooo0_l0000?ooooo`;o00004Oooool2o`0008Oooooo0003oooo
o`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooo
oooo01Cooooo0_l0001Aooooo`;o00003?ooool2o`0003Cooooo0_l0002Jooooo`000oooool01Ol@
413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3o
ooooodSooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonH
V9So410@00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo05Gooooo
0_l0003`ooooo`007_ooool00ol0003oooooooooo`1Eooooo`;o0000l?ooool001kooooo00?o0000
ooooooooool0;_ooool2o`000?oooooo6?ooool001kooooo00?o0000ooooooooool0;_ooool2o`00
0?oooooo6?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`1?ooooo`;o0000m_ooool001kooooo00?o0000ooooooooool0Coooool2o`0000oooooo0_l0
001Mooooo`;o0000Q_ooool001kooooo00?o0000ooooooooool0H?ooool2o`0005gooooo0_l00026
ooooo`007_ooool00ol0003oooooooooo`0booooo`;o0000oooooolDooooo`007_ooool00ol0003o
ooooooooo`0booooo`;o0000oooooolDooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Noooo
o`03o`000?oooooooooo0:oooooo0_l0002Fooooo`007_ooool00ol0003oooooooooo`2_ooooo`;o
0000U_ooool001kooooo00?o0000ooooooooool0X_ooool2o`000:?ooooo000Nooooo`03o`000?oo
oooooooo0:;ooooo0_l0002Sooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`?o0000
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo053ooooo0_l0003eooooo`007_ooool00ol0003oooooooooo`1@ooooo`;o0000mOooool001ko
oooo00?o0000ooooooooool0:_ooool2o`0003;ooooo0_l0002<ooooo`;o0000FOooool001kooooo
00?o0000ooooooooool0:_ooool2o`0003;ooooo0_l0000Gooooo`;o0000Loooool2o`0005Wooooo
000Nooooo`03o`000?oooooooooo07Oooooo0_l0003>ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo04cooooo0_l0001eooooo`;o0000P_ooool001kooooo00?o
0000ooooooooool0C?ooool2o`0000Gooooo0_l0001^ooooo`;o0000P_ooool001kooooo00?o0000
ooooooooool0Doooool2o`000?;ooooo000Nooooo`03o`000?oooooooooo0>Cooooo0_l0001Qoooo
o`007_ooool00ol0003oooooooooo`3Tooooo`;o0000HOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`1Vooooo`;o0000goooool001kooooo00?o0000
ooooooooool0I_ooool2o`0006oooooo0_l0001^ooooo`007_ooool00ol0003oooooooooo`2joooo
o`;o00006oooool2o`0006kooooo000Nooooo`03o`000?oooooooooo0;[ooooo0_l0002;ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0;Cooooo0_l0
002Aooooo`007_ooool00ol0003oooooooooo`2dooooo`;o0000TOooool001kooooo00?o0000oooo
ooooool0A_ooool2o`000?oooooo000Nooooo`;o0000Aoooool2o`000?oooooo000Nooooo`03o`00
0?oooooooooo0;cooooo0_l00029ooooo`007_ooool00ol0003oooooooooo`2looooo`;o0000ROoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
l_ooool2o`0005?ooooo000Nooooo`03o`000?oooooooooo0?;ooooo0_l0001Cooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooolEooooo`;o0000<Oooool001kooooo00?o0000ooooooooool0
oooooolEooooo`;o0000<Oooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo06[ooooo0_l0003K
ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0J_ooool2o`000<;ooooo0_l0000Gooooo`000oooool01Ol@
413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`?o0000ooooool_ooooo`;o00005oooool0
00?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o
0000ooooooooool0=_ooool2o`000?oooooo4?ooool000?ooooo00Go0000ooooooooooooooooo`00
000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool09_ooool2o`0000kooooo
0_l0003ooooooa3ooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`000007ooooo`03o`000?oooooooooo01Kooooo0_l0000>ooooo`;o0000oooooolPooooo`000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0003ooooo
ooooo`0Fooooo`;o00002oooool2o`000?oooooo8oooool000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool08oooool2o`0001Kooooo
0_l0003oooooo`_ooooo000Nooooo`03o`000?oooooooooo03_ooooo0_l0000aooooo`;o0000eooo
ool001kooooo00?o0000ooooooooool0K_ooool2o`000;gooooo0_l0000Hooooo`007_ooool00ol0
003oooooooooo`0Fooooo`;o0000oooooolFooooo`;o00006?ooool001kooooo00?o0000oooooooo
ool05_ooool2o`000;Sooooo0_l0001eooooo`007_ooool00ol0003oooooooooo`39ooooo`;o0000
1Oooool2o`0007Gooooo000Nooooo`03o`000?oooooooooo0<Wooooo0_l0001looooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo2?ooool2o`00
03kooooo000Nooooo`03o`000?oooooooooo04Kooooo0_l0002oooooo`;o0000?_ooool001kooooo
00?o0000ooooooooool0A_ooool2o`0003gooooo0_l00030ooooo`007_ooool00ol0003ooooooooo
o`1kooooo`;o00002?ooool2o`000<3ooooo000Nooooo`;o0000O?ooool2o`000<[ooooo000Noooo
o`03o`000?oooooooooo01_ooooo0_l0003oooooob_ooooo000Nooooo`03o`000?oooooooooo01_o
oooo0_l00023ooooo`;o0000YOooool001kooooo00?o0000ooooooooool0COooool2o`00057ooooo
0_l0002Uooooo`007_ooool00ol0003oooooooooo`1=ooooo`;o0000n?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3Rooooo`;o0000Hoooool001ko
oooo00?o0000ooooooooool0h_ooool2o`0006?ooooo000Nooooo`03o`000?oooooooooo03?ooooo
0_l0003ooooooa?ooooo000Nooooo`03o`000?oooooooooo03?ooooo0_l0001<ooooo`;o00004ooo
ool2o`000:oooooo000Nooooo`03o`000?oooooooooo087ooooo0_l0000Cooooo`;o0000F_ooool2
o`0005?ooooo000Nooooo`03o`000?oooooooooo0?;ooooo0_l0001Cooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo01kooooo0_l0003oooooobSooooo
000Nooooo`03o`000?oooooooooo01kooooo0_l0003oooooobSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo0_l0001;ooooo`;o00000_ooool2o`000?Oooooo000Nooooo`03
o`000?oooooooooo04[ooooo0_l00002ooooo`;o00002_ooool2o`000>_ooooo000Mooooo`;o0000
G?ooool2o`000>_ooooo000Mooooo`;o00006_ooool2o`0003oooooo0_l0003/ooooo`007_ooool0
0ol0003oooooooooo`0Hooooo`;o00005oooool2o`0002Kooooo0_l0003/ooooo`007_ooool01?l0
003oooooo`000?l0000`ooooo`;o0000oooooolEooooo`007_ooool01?l0003oooooo`000?l0003o
ooooodOooooo000Nooooo`03o`000?oooooooooo09Cooooo0_l0002aooooo`007_ooool00ol0003o
ooooooooo`11ooooo`;o0000DOooool2o`000;7ooooo000Nooooo`03o`000?oooooooooo02gooooo
0_l0000Booooo`;o0000>?ooool2o`000<[ooooo000Nooooo`03o`000?oooooooooo00oooooo0_l0
000Looooo`;o0000C?ooool2o`000<[ooooo000Nooooo`03o`000?oooooooooo00oooooo0_l00009
ooooo`;o0000Boooool2o`000=kooooo000Nooooo`03o`000?oooooooooo01[ooooo0_l00007oooo
o`;o0000?_ooool2o`0000;ooooo0_l00005ooooo`;o0000Voooool2o`0003[ooooo000Nooooo`03
o`000?oooooooooo02?ooooo0_l00006ooooo`;o0000=_ooool2o`0000Wooooo0_l0002Kooooo`;o
0000>_ooool001kooooo00?o0000ooooooooool0:oooool2o`0006Cooooo0_l0002dooooo`007_oo
ool2o`0009;ooooo0_l0002dooooo`007_ooool2o`0002_ooooo0_l0003ooooooacooooo000Noooo
o`03o`000?oooooooooo02[ooooo0_l0003ooooooacooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`1?ooooo`;o0000KOooool2o`0004oooooo0_l0000fooooo`007_ooool00ol0003oooooooooo`1?
ooooo`;o0000KOooool2o`0004oooooo0_l0000fooooo`007_ooool00ol0003oooooooooo`02o`00
06?ooooo0_l0001Aooooo`;o0000Q_ooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo00;o
0000Hoooool2o`0002Cooooo0_l0000[ooooo`;o0000Q_ooool2o`0000Gooooo000Nooooo`04o`00
0?ooooooooooooooo`;o0000R?ooool2o`0009gooooo0_l0000Kooooo`007_ooool01?l0003ooooo
ooooooooool2o`0003?ooooo0_l0000Eooooo`;o0000V_ooool2o`0003oooooo0_l0000Kooooo`00
7_ooool00ol0003oooooooooo`0fooooo`;o00005Oooool2o`0009[ooooo0_l0001Looooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0003o
ooooocgooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l00011ooooo`;o00004oooool2o`00
0>Cooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b
<_l0003o410@olc<c006ooooo`03o`000?oooooooooo04cooooo0_l0000Cooooo`;o00006Oooool2
o`0005?ooooo0_l0001dooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1looooo`;o00008Ooo
ool2o`00033ooooo0_l0001dooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000>Oooool2o`0006Cooooo0_l0001nooooo`;o0000
9_ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ
8B401_ooool00ol0003oooooooooo`0iooooo`?o00004Oooool2o`000=3ooooo0_l0000Vooooo`00
0oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c006oooo
o`03o`000?oooooooooo03[ooooo0_l0000Aooooo`;o00004?ooool2o`0003Wooooo0_l0002[oooo
o`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0
003oooooooooo`1Oooooo`;o0000>Oooool2o`000:_ooooo0003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo02?ooooo0_l0002<oooo
o`;o0000LOooool2o`00027ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<
c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo02?ooooo0_l0002<ooooo`;o0000LOooool2
o`00027ooooo000Nooooo`03o`000?oooooooooo05?ooooo0_l0003booooo`007_ooool00ol0003o
ooooooooo`1Cooooo`;o0000W_ooool2o`0005;ooooo000Nooooo`03o`000?oooooooooo0??ooooo
0_l0001Booooo`007_ooool00ol0003oooooooooo`18ooooo`;o0000fOooool2o`0002;ooooo000N
ooooo`03o`000?oooooooooo04Sooooo0_l0002eooooo`;o00008_ooool2o`0001;ooooo0_l0000>
ooooo`007_ooool00ol0003oooooooooo`3oooooo`;o0000=_ooool2o`0000kooooo000Nooooo`03
o`000?oooooooooo043ooooo0_l0000hooooo`;o00008_ooool2o`00037ooooo0_l0001dooooo`00
7_ooool00ol0003oooooooooo`10ooooo`;o00008oooool2o`0001?ooooo0_l0000Rooooo`;o0000
<Oooool2o`0007Cooooo000Nooooo`?o0000AOooool2o`0000?ooooo0_l0000Iooooo`;o0000h?oo
ool001kooooo0ol0000Hooooo`;o00003oooool3o`0001Wooooo0_l00003ooooo`;o0000`oooool2
o`0003Kooooo000Nooooo`03o`000?oooooooooo01Sooooo0_l0000?ooooo`?o0000hoooool2o`00
03Kooooo000Nooooo`;o00007_ooool2o`0003Kooooo0_l0000jooooo`;o0000A_ooool2o`0006;o
oooo0_l00008ooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o00007_ooool2o`0001Kooooo
0_l0000_ooooo`;o00002Oooool2o`0004Kooooo0_l0001Rooooo`;o00002?ooool001kooooo00?o
0000ooooooooool0?Oooool2o`0004Oooooo0_l0002oooooo`007_ooool00ol0003oooooooooo`0G
ooooo`;o0000H?ooool2o`0000kooooo0_l0002looooo`007_ooool00ol0003oooooooooo`0Goooo
o`;o00009?ooool2o`0003[ooooo0_l0000>ooooo`;o0000_?ooool001kooooo00?o0000oooooooo
ool0?Oooool2o`000?;ooooo0_l0000Dooooo`007_ooool00ol0003oooooooooo`1^ooooo`;o0000
`Oooool2o`0001Cooooo000Nooooo`03o`000?oooooooooo06kooooo0_l0000Oooooo`;o0000]_oo
ool001kooooo00?o0000ooooooooool0A?ooool2o`0004Wooooo0_l0002fooooo`007_ooool00ol0
003oooooooooo`0cooooo`;o00003oooool2o`0001Gooooo0_l0003Zooooo`007_ooool00ol0003o
ooooooooo`0Pooooo`;o00001Oooool2o`0000[ooooo0_l0000Vooooo`;o0000j_ooool001kooooo
00?o0000ooooooooool05oooool2o`0000Oooooo0_l00005ooooo`;o0000oooooolOooooo`007_oo
ool00ol0003oooooooooo`0Gooooo`;o00005?ooool2o`0001kooooo0_l00005ooooo`;o00005?oo
ool2o`0001Kooooo0_l0001Kooooo`;o0000I_ooool001kooooo00?o0000ooooooooool0;Oooool2
o`0001kooooo0_l00005ooooo`;o00005?ooool2o`0001Kooooo0_l000000ooooooo0000o`00001H
ooooo`;o0000I_ooool001kooooo00?o0000ooooooooool0QOooool2o`00057ooooo0_l0000foooo
o`;o00003_ooool2o`0002Gooooo000Nooooo`03o`000?oooooooooo02_ooooo0_l0001nooooo`;o
0000:oooool2o`0003Kooooo0_l0000>ooooo`;o00009Oooool001kooooo0_l0000/ooooo`;o0000
O_ooool2o`0005Wooooo0_l0000oooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o0000A?oo
ool2o`0003kooooo0_l0000Gooooo`;o0000E?ooool2o`0001Sooooo0_l0000Uooooo`007_ooool0
0ol0003oooooooooo`0Aooooo`;o0000>?ooool2o`0000[ooooo0_l0000Fooooo`;o00009_ooool2
o`0001Oooooo0_l0001Sooooo`;o00002Oooool2o`0002Gooooo000Nooooo`03o`000?oooooooooo
00Kooooo0_l00009ooooo`;o00001_ooool2o`0000Wooooo0_l0000Uooooo`;o00008_ooool2o`00
0:Cooooo0_l0000`ooooo`007_ooool00ol0003oooooooooo`06ooooo`;o00002Oooool2o`0000Ko
oooo0_l00009ooooo`;o0000Qoooool2o`0009Sooooo000Nooooo`03o`000?oooooooooo0:gooooo
0_l0002<ooooo`;o00002_ooool001kooooo00Co0000ooooool0003o00005Oooool2o`000003oooo
ool0003o000009Gooooo0_l00029ooooo`;o00002_ooool001kooooo00Co0000ooooool0003o0000
5Oooool2o`000003ooooool0003o000003Oooooo0_l00005ooooo`;o0000EOooool2o`0009Gooooo
000Nooooo`03o`000?oooooooooo00Sooooo0_l000000ooooooo0000o`00000Cooooo`;o0000<?oo
ool2o`0000Gooooo0_l0000cooooo`;o0000>Oooool2o`0000Gooooo0_l0001eooooo`007_ooool0
0ol0003oooooooooo`08ooooo`;o000000?oooooo`000?l000004oooool2o`0003Kooooo0_l0000d
ooooo`;o00002_ooool2o`0002gooooo0_l00005ooooo`;o0000MOooool001kooooo00?o0000oooo
ooooool02_ooool2o`0002Wooooo0_l0000Qooooo`;o0000@?ooool2o`0000;ooooo0_l0002Woooo
o`007_ooool00ol0003oooooooooo`0:ooooo`;o0000:Oooool2o`0001Wooooo0_l00009ooooo`;o
0000@Oooool2o`0008cooooo0_l0000Iooooo`007_ooool00ol0003oooooooooo`0Looooo`;o0000
8?ooool2o`0000_ooooo0_l00003ooooo`;o00002Oooool2o`000<oooooo0_l0000Iooooo`007_oo
ool00ol0003oooooooooo`0Looooo`;o00008?ooool2o`0000[ooooo0ol00009ooooo`;o00003ooo
ool2o`0007kooooo0_l0001Nooooo`007_ooool00ol0003oooooooooo`17ooooo`;o000000?ooooo
o`000?l000002_ooool2o`0000oooooo0_l0000<ooooo`;o0000Foooool2o`0001?ooooo0_l0001N
ooooo`007_ooool00ol0003oooooooooo`0aooooo`;o00004Oooool7o`0002[ooooo1?l00011oooo
o`;o00005_ooool2o`0007?ooooo000Nooooo`;o0000<_ooool2o`00013ooooo2?l0000<ooooo`;o
00007Oooool3o`0000oooooo0_l0000`ooooo`;o00006oooool2o`0000?ooooo0_l0001Yooooo`00
7_ooool3o`0002oooooo0_l0000Booooo`?o00004Oooool2o`0000cooooo0_l0000Qooooo`;o0000
COooool2o`0000?ooooo0_l0001Pooooo`;o00001oooool001kooooo0ol0000_ooooo`;o00001_oo
ool2o`0000_ooooo0_l0000Booooo`;o00002oooool2o`0000Gooooo0_l0000Booooo`;o00001Ooo
ool2o`00013ooooo0_l0000@ooooo`;o0000TOooool2o`0000Oooooo000Nooooo`03o`000?oooooo
oooo01Sooooo0_l0000Mooooo`?o00000_ooool2o`0000Kooooo0_l000000ooooooo0000o`000006
ooooo`;o00001oooool2o`0001;ooooo0_l0000Booooo`;o00001Oooool2o`00013ooooo0_l0000@
ooooo`;o0000V_ooool001kooooo00?o0000ooooooooool06?ooool2o`0001kooooo0_l00002oooo
o`;o00002Oooool6o`0000;ooooo0_l0000Cooooo`?o00001oooool2o`0003Sooooo0_l0002Moooo
o`007_ooool00ol0003oooooooooo`19ooooo`Co00001oooool2o`0000kooooo0ol00007ooooo`;o
00009_ooool2o`00013ooooo0_l0002Mooooo`007_ooool00ol0003oooooooooo`0iooooo`;o0000
2_ooool2o`0000Gooooo0_l00006ooooo`;o0000@?ooool2o`000:oooooo000Nooooo`03o`000?oo
oooooooo00Wooooo0_l000000ooooooo0000o`00000[ooooo`;o00002_ooool2o`0000?ooooo1?l0
003iooooo`007_ooool01?l0003oooooooooooooool2o`0000Kooooo0_l000000ooooooo0000o`00
000aooooo`;o00002Oooool2o`0000Sooooo0_l0000Booooo`;o0000gOooool001kooooo00Co0000
oooooooooooooooo0_l0000kooooo`?o00001?ooool2o`000003ooooool0003o000000[ooooo0_l0
0007ooooo`;o00001Oooool2o`0000;ooooo0_l0003Mooooo`007_ooool00ol0003oooooooooo`0n
ooooo`?o000000?oooooo`000?l000000ol000000ooooooo0000o`000004o`0000oooooo0_l00005
ooooo`;o0000hOooool001kooooo00?o0000ooooooooool09Oooool2o`0000Gooooo0_l00006oooo
o`;o00002Oooool2o`000003ooooool0003o000000;o00000oooool5o`00013ooooo0_l00004oooo
o`;o00001Oooool2o`0001Sooooo0_l0001mooooo`;o0000@Oooool001kooooo00?o0000oooooooo
ool05oooool2o`0000_ooooo0ol00005ooooo`;o00001Oooool3o`0000Wooooo0_l00008ooooo`;o
00004oooool2o`0000;ooooo1?l00005ooooo`;o00006?ooool2o`0007gooooo0_l00011ooooo`00
7_ooool00ol0003oooooooooo`0Gooooo`;o00002oooool2o`0000Wooooo0_l00002ooooo`;o0000
0oooool2o`0000Gooooo0_l00004ooooo`;o00006oooool2o`0003Sooooo0_l00009ooooo`;o0000
2Oooool2o`0009?ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo02oooooo1?l00005ooooo`;o
00002oooool2o`0000?ooooo1?l00005ooooo`;o000000?oooooo`000?l000005?ooool2o`0002ko
oooo0_l00009ooooo`;o00001oooool4o`0009?ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo
017ooooo1?l0000Kooooo`?o00005oooool4o`000003ooooool0003o000000;ooooo0_l000000ooo
oooo0000o`000003ooooo`;o00003oooool2o`0003oooooo0_l000000ooooooo0000o`00001Hoooo
o`;o0000>oooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooo
ooooool000001_ooool3o`0000;ooooo0_l0000=ooooo`Co00005_ooool3o`0000Kooooo0_l0000:
ooooo`?o00001Oooool2o`000003ooooool0003o000000Ko00002?ooool2o`0000Oooooo0_l0000Z
ooooo`;o00006oooool2o`0005_ooooo0_l0000kooooo`000oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooooooo00;ooooo0_l0
000:ooooo`;o000000?oooooo`000?l000001?ooool2o`0001;ooooo0ol00004ooooo`Co00002_oo
ool5o`000003ooooool0003o000000;o000000?oooooo`000?l000000_l00002ooooo`;o00002Ooo
ool2o`0000Kooooo0_l0000:ooooo`;o00007_ooool2o`000;Gooooo0003ooooo`05o`000?oooooo
ooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0
3_ooool2o`000003ooooool0003o000000Cooooo0_l0000Eooooo`Ko00000_ooool2o`0000Wooooo
1?l000000ooooooo0000o`000002o`0001;ooooo0_l0000Booooo`;o0000E?ooool2o`0006Sooooo
0_l0000Eooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo
^[Zjoa0@4006ooooo`03o`000?oooooooooo01gooooo0_l00006ooooo`;o00001oooool4o`0000Co
oooo0ol00002ooooo`;o00001Oooool3o`0000Kooooo0_l00003ooooo`;o00008Oooool2o`0001So
oooo0_l0000Cooooo`;o00008_ooool2o`0003Kooooo0_l0000@ooooo`;o00007_ooool2o`0001Go
oooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o0000
00Kooooo00?o0000ooooooooool07Oooool3o`000003ooooool0003o000000;ooooo0_l000000ooo
oooo0000o`000008ooooo`;o00000oooool2o`0000;ooooo0_l00005ooooo`?o00000_ooool2o`00
00;ooooo0_l00003ooooo`;o00001Oooool2o`0001[ooooo0_l0000<ooooo`;o00002_ooool2o`00
01?ooooo0_l0001Jooooo`;o00004?ooool2o`0000kooooo0_l0000Uooooo`000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooo
oooo00gooooo0_l0000>ooooo`?o000000?oooooo`000?l000000oooool4o`0000Sooooo0_l00008
ooooo`;o00001?ooool3o`0000;ooooo0_l00004ooooo`;o00000_ooool2o`0000Cooooo0_l00008
ooooo`;o00003?ooool2o`00013ooooo0_l0000Eooooo`;o0000Q_ooool2o`0002Gooooo000Noooo
o`03o`000?oooooooooo00;o00002oooool2o`0000[ooooo0ol0000:ooooo`;o00002_ooool3o`00
00Oooooo0_l00004ooooo`;o00000oooool2o`0000Cooooo0_l00002ooooo`?o00003Oooool2o`00
00Oooooo0_l00003ooooo`;o00009oooool2o`0005Sooooo0_l0001Cooooo`007_ooool00ol0003o
ooooooooo`02o`0001Oooooo1?l0000;ooooo`;o00000_ooool2o`0000Gooooo0_l00007ooooo`;o
00003_ooool2o`0000Cooooo0_l0000Fooooo`;o00008?ooool2o`0006Cooooo0_l0000Zooooo`;o
00009oooool001kooooo00?o0000ooooooooool06_ooool3o`000003ooooool0003o000000;o0000
00?oooooo`000?l000000oooool2o`0000;ooooo1?l00004ooooo`;o00000_ooool2o`0000;ooooo
0_l000000ooooooo0000o`000002ooooo`;o00001oooool3o`0000kooooo0_l00003ooooo`Co0000
0_ooool2o`0002;ooooo0_l0002@ooooo`;o00009oooool001kooooo00?o0000ooooooooool07?oo
ool6o`000003ooooool0003o000000Cooooo0_l00003ooooo`;o00001?ooool2o`0000;ooooo0_l0
0005ooooo`;o00000_ooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000kooooo
0_l00003ooooo`Co00000_ooool2o`0002Cooooo0_l0002gooooo`007_ooool00ol0003ooooooooo
o`0<ooooo`;o00003Oooool4o`0000[ooooo0_l0000Eooooo`;o00000_ooool5o`000003ooooool0
003o000000Gooooo0_l000000ooooooo0000o`00000Booooo`;o00009?ooool2o`000;Oooooo000N
ooooo`03o`000?oooooooooo00cooooo0_l0000=ooooo`Co00002?ooool2o`0001Oooooo0_l00002
ooooo`Co00000_ooool2o`0000Cooooo0ol000000ooooooo0000o`000009ooooo`;o00003oooool2
o`0000Sooooo0_l0002kooooo`;o00003_ooool001kooooo00?o0000ooooooooool09oooool2o`00
01Cooooo0ol00004ooooo`Co00000_ooool2o`0000;ooooo1_l0000;ooooo`;o00003oooool2o`00
00Sooooo0_l0002kooooo`;o00003_ooool001kooooo00?o0000ooooooooool04Oooool2o`0000[o
oooo0_l0000:ooooo`;o00000_ooool4o`0000?ooooo0_l00005ooooo`Go00000_ooool2o`000003
ooooool0003o000000Oooooo1_l00002ooooo`;o00007Oooool2o`0000oooooo0_l0002oooooo`00
7_ooool00ol0003oooooooooo`0Aooooo`;o00002_ooool2o`0000[ooooo0_l00002ooooo`Co0000
0oooool2o`0000Gooooo1?l00002ooooo`?o000000?oooooo`000?l000002?ooool4o`0000;ooooo
0ol0000>ooooo`;o00003Oooool4o`0000gooooo0_l00005ooooo`;o00004oooool2o`000:?ooooo
000Nooooo`03o`000?oooooooooo02Wooooo0_l00008ooooo`;o00000_ooool2o`0000;ooooo0_l0
00001?oooooo0000o`000?ooool3o`0000;ooooo1?l00005ooooo`Co00000_ooool2o`0000oooooo
0_l0000?ooooo`;o00003_ooool2o`0000Cooooo0_l0000Cooooo`;o00001Oooool2o`0001kooooo
0_l0001looooo`007_ooool00ol0003oooooooooo`0:ooooo`;o00004oooool2o`0000Sooooo0_l0
0008ooooo`;o00000_ooool2o`0000Gooooo0_l00002ooooo`So00001Oooool4o`0000Cooooo0_l0
0008ooooo`?o00008oooool2o`0001Kooooo0_l00008ooooo`;o00005oooool2o`0000Gooooo0_l0
001looooo`007_ooool2o`0000_ooooo0_l0000?ooooo`;o00000_ooool2o`0002?ooooo1?l00009
ooooo`;o00000_ooool6o`0000Kooooo0ol0000>ooooo`;o00000oooool3o`0000;ooooo0_l0000>
ooooo`;o00004Oooool2o`00027ooooo0_l0001Tooooo`;o00007Oooool001kooooo00?o0000oooo
ooooool06oooool2o`0000gooooo0_l0000Dooooo`;o000000Coooooo`000?l0003ooooo0ol00006
ooooo`;o00001?ooool8o`0000Kooooo0_l0000=ooooo`;o00000oooool3o`0000;ooooo0_l0000>
ooooo`;o0000V_ooool2o`0001gooooo000Nooooo`03o`000?oooooooooo02[ooooo0_l00008oooo
o`;o00002_ooool2o`000003ooooool0003o000000;ooooo0ol00005ooooo`;o00001?ooool8o`00
00Kooooo0_l0000Pooooo`;o0000`?ooool001kooooo00?o0000ooooooooool0<?ooool6o`0000;o
oooo0ol0000=ooooo`Go00001_ooool2o`0000;ooooo1?l0000Eooooo`;o00004oooool2o`0001Co
oooo0_l0002Zooooo`007_ooool00ol0003oooooooooo`0Tooooo`;o00002_ooool4o`0000Cooooo
0ol0000=ooooo`Go000000?oooooo`000?l000000_ooool3o`0000?ooooo1Ol0000Cooooo`;o0000
00?oooooo`000?l000002_ooool2o`0001[ooooo0_l0000=ooooo`;o0000D_ooool2o`0001cooooo
0_l0000Yooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o00001_ooool2o`0000Gooooo0_l0
0005ooooo`;o00004_ooool2o`0000Oooooo2?l00002ooooo`;o000000?oooooo`000?l000000ol0
00000ooooooo0000o`000006ooooo`;o00003_ooool2o`0000[ooooo0_l0000Yooooo`;o0000D_oo
ool2o`0001cooooo0_l0000Yooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o00001_ooool2
o`0000Gooooo0_l00005ooooo`Ko00001oooool2o`0000Gooooo0_l00003ooooo`;o000000?ooooo
o`000?l000001Ol00002ooooo`;o00000oooool3o`0000?ooooo0_l00003ooooo`;o000000?ooooo
o`000?l00000h_ooool001kooooo00?o0000ooooooooool01_ooool2o`0001;ooooo0_l0000Aoooo
o`Ko00001Oooool4o`0000Sooooo0_l000000ooooooo0000o`000003o`0000;ooooo1?l00004oooo
o`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o000000?oooooo`000?l000006?ooool2
o`0001gooooo0_l0000Sooooo`;o0000Q?ooool001kooooo00?o0000ooooooooool01_ooool2o`00
01;ooooo0_l00003ooooo`;o00003_ooool4o`0000Kooooo0ol0000?ooooo`Go00002Oooool2o`00
0003ooooool0003o000000?ooooo1?l00005ooooo`;o00004Oooool2o`0001gooooo0_l0000Soooo
o`;o00003oooool2o`0007?ooooo000Nooooo`03o`000?oooooooooo013ooooo0_l00008ooooo`Co
000000?oooooo`000?l000006?ooool2o`000003ooooool0003o000000Kooooo0_l00005ooooo`_o
000000?oooooo`000?l000001_ooool4o`0000;ooooo0_l00003ooooo`;o0000I_ooool2o`0007?o
oooo000Nooooo`03o`000?oooooooooo00Oooooo0_l00007ooooo`;o00002Oooool3o`0000kooooo
0_l0000;ooooo`Go00000oooool2o`000003ooooool0003o000000Wooooo6?l0000@ooooo`;o0000
=oooool2o`00077ooooo0_l0000Rooooo`007_ooool00ol0003oooooooooo`07ooooo`;o00003Ooo
ool2o`0001;ooooo1?l0000<ooooo`?o00001?ooool2o`0000gooooo1?l000001Ooooooo0000o`00
0?l0003ooooo00Wo000000?oooooo`000?l000001?l00005ooooo`;o00001oooool2o`0003Oooooo
0_l0000Wooooo`;o0000B?ooool2o`000003ooooool0003o000001oooooo000Nooooo`03o`000?oo
oooooooo01Kooooo0ol00009ooooo`;o00001_ooool2o`0000oooooo0_l00002ooooo`;o00004Ooo
ool2o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`?o000000?oooooo`000?l000001?l0
0005ooooo`?o0000<?ooool2o`0003Kooooo0_l0000Hooooo`;o00007?ooool2o`0001?ooooo0_l0
000Oooooo`007_ooool00ol0003oooooooooo`04ooooo`;o00004Oooool4o`0000Oooooo0_l0000?
ooooo`;o00001_ooool6o`0000Sooooo0_l000000ooooooo0000o`000006ooooo`Oo00001Oooool3
o`0000?ooooo0ol00005ooooo`?o0000<?ooool2o`00053ooooo0_l0000Looooo`;o00008oooool2
o`0000oooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0000?ooooo`;o00000_ooool2o`00
00Sooooo0_l0000>ooooo`;o00002?ooool4o`0000Sooooo0_l000000ooooooo0000o`000002oooo
o`;o00000_ooool4o`000004ooooool0003o0000o`0000Gooooo0_l00003ooooo`;o00000_ooool3
o`000003ooooool0003o000005Gooooo0_l0001_ooooo`;o00003oooool001kooooo00?o0000oooo
ooooool05Oooool2o`0000cooooo0_l0000Booooo`;o00001Oooool3o`0000Sooooo0_l00005oooo
o`;o00000oooool7o`0000Gooooo0_l00007ooooo`?o000000?oooooo`000?l000001Oooool2o`00
00_ooooo0_l00011ooooo`;o0000P?ooool001kooooo0_l0000fooooo`Co00001?ooool3o`0000Wo
oooo0_l00005ooooo`?o00000oooool7o`0000gooooo0_l00009ooooo`;o00002oooool2o`0002go
oooo0_l0001:ooooo`;o0000B?ooool001kooooo00?o0000ooooooooool0=Oooool4o`0000Cooooo
0_l0000Booooo`;o00001Oooool2o`000003ooooool0003o000000Kooooo0_l0000;ooooo`;o0000
?oooool2o`0004[ooooo0_l0000Zooooo`;o00004Oooool2o`0000Wooooo000Nooooo`03o`000?oo
oooooooo02_ooooo0_l0000=ooooo`?o000000?oooooo`000?l000000oooool2o`0001;ooooo0ol0
0009ooooo`;o00001Oooool4o`0000;ooooo1?l00011ooooo`;o0000L_ooool2o`00017ooooo0_l0
0009ooooo`007_ooool00ol0003oooooooooo`0[ooooo`;o00003Oooool6o`0000;ooooo0ol0000B
ooooo`;o00001Oooool2o`0000[ooooo1Ol00003ooooo`;o00009oooool2o`0001Sooooo0_l0002@
ooooo`007_ooool00ol0003oooooooooo`0kooooo`Co00000oooool2o`0000Gooooo0_l0000Coooo
o`;o00003Oooool2o`0000?ooooo0_l0000Hooooo`Co00002oooool2o`00057ooooo0_l0001Goooo
o`007_ooool00ol0003oooooooooo`0kooooo`Co00000oooool2o`0000Gooooo0_l00007ooooo`;o
00006Oooool2o`000003ooooool0003o000000Co00004oooool2o`000003ooooool0003o000000;o
00002_ooool2o`0005;ooooo0_l0000@ooooo`;o0000AOooool001kooooo00?o0000ooooooooool0
>oooool4o`000003ooooool0003o000000?ooooo0_l0000;ooooo`;o00002Oooool2o`0000Wooooo
0_l00004ooooo`So00004oooool2o`0000;ooooo1?l00009ooooo`;o0000I?ooool2o`0004Gooooo
000Nooooo`03o`000?oooooooooo03_ooooo1?l000000ooooooo0000o`000003ooooo`;o00001Ooo
ool3o`0000cooooo1?l00009ooooo`;o00001?ooool2o`000004ooooool0003o0000o`0001_ooooo
0_l0001/ooooo`;o0000:?ooool2o`0001Oooooo0_l00005ooooo`007_ooool00ol0003ooooooooo
o`0mooooo`Co00002oooool3o`0000Wooooo0_l000000ooooooo0000o`000006ooooo`Co00002ooo
ool2o`0000Cooooo0_l0000=ooooo`;o0000M?ooool2o`0002Sooooo0_l0000Gooooo`;o00001Ooo
ool001kooooo00?o0000ooooooooool02Oooool2o`00033ooooo0_l00002ooooo`;o00005oooool2
o`0000Wooooo1?l0000:ooooo`?o00001?ooool2o`0000gooooo0_l0001Wooooo`;o0000EOooool0
01kooooo00?o0000ooooooooool02Oooool2o`00033ooooo0_l00009ooooo`;o00002Oooool2o`00
01Cooooo0_l000000ooooooo0000o`000005ooooo`?o00006_ooool2o`00063ooooo0_l0000<oooo
o`;o0000Aoooool001kooooo00Co0000oooooooooooooooo0_l0000Rooooo`;o00007oooool2o`00
00Wooooo0_l0000Dooooo`;o000000?oooooo`000?l000008_ooool2o`0006kooooo0_l00005oooo
o`;o0000<?ooool2o`0000kooooo000Nooooo`04o`000?ooooooooooooooo`;o00005_ooool2o`00
00[ooooo0_l00016ooooo`?o000000Coooooo`000?l0003ooooo0_l0000Oooooo`;o0000K_ooool2
o`00033ooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o0000Aoooool2o`00
00Wooooo0ol000001?oooooo0000o`000?ooool2o`0001oooooo0_l0002`ooooo`007_ooool00ol0
003oooooooooo`0^ooooo`;o0000<_ooool2o`000003ooooool0003o000000Kooooo0_l00002oooo
o`;o00004Oooool2o`000:cooooo0_l0000Cooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o
00005?ooool2o`0002Cooooo0_l00008ooooo`;o00001Oooool2o`0000Gooooo0_l00003ooooo`;o
00004Oooool2o`0000cooooo0_l0000Oooooo`;o0000=?ooool2o`0004Oooooo0_l0000Cooooo`00
7_ooool2o`0001Wooooo0_l0000jooooo`;o00002?ooool3o`0000_ooooo0_l0000Tooooo`;o0000
7oooool2o`0003Cooooo0_l0001Looooo`007_ooool00ol0003oooooooooo`1Oooooo`;o00003Ooo
ool3o`0005Sooooo0_l00015ooooo`;o00009Oooool2o`0000kooooo000Nooooo`03o`000?oooooo
oooo02[ooooo0_l0000dooooo`;o00003?ooool3o`0005Sooooo0_l00003ooooo`;o0000@?ooool2
o`0002Gooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`0Zooooo`;o0000:oooool2o`00
00Oooooo0_l0000@ooooo`;o00000_ooool2o`0005Kooooo0_l0001gooooo`007_ooool00ol0003o
ooooooooo`06ooooo`;o00009_ooool2o`0002;ooooo0_l00003ooooo`;o00006Oooool2o`0000;o
oooo0_l00004ooooo`;o0000bOooool001kooooo00?o0000ooooooooool01_ooool2o`0002Kooooo
0_l0000Mooooo`;o00000oooool2o`0002Gooooo0_l000000ooooooo0000o`000008ooooo`;o0000
_oooool001kooooo00?o0000ooooooooool0COooool4o`0000oooooo0_l0000;ooooo`;o00000_oo
ool2o`0000Kooooo0_l000000ooooooo0000o`000008ooooo`;o0000_oooool001kooooo00?o0000
ooooooooool0;_ooool2o`0001[ooooo0_l00003ooooo`;o00001Oooool2o`0000Sooooo0_l0000;
ooooo`;o00000_ooool2o`0000Wooooo0_l0000;ooooo`;o00007?ooool2o`0009kooooo000Noooo
o`03o`000?oooooooooo02kooooo0_l0000Jooooo`;o00001?ooool2o`0000Cooooo0_l0000Foooo
o`;o00003?ooool2o`0000;ooooo0_l00007ooooo`;o00007?ooool2o`0009kooooo000Nooooo`03
o`000?oooooooooo053ooooo0_l00003ooooo`;o00005?ooool2o`000003ooooool0003o000000Oo
oooo0_l00007ooooo`;o00004Oooool2o`0001;ooooo0_l0000Qooooo`;o0000Noooool001kooooo
00?o0000ooooooooool0EOooool2o`0000gooooo0_l00004ooooo`?o00002_ooool2o`0001[ooooo
0_l0000eooooo`;o0000G?ooool2o`0001gooooo000Nooooo`03o`000?oooooooooo017ooooo0_l0
000Xooooo`;o00004oooool2o`0001;ooooo0_l00004ooooo`;o0000_?ooool2o`0001gooooo000N
ooooo`03o`000?oooooooooo017ooooo0_l0000Xooooo`;o00004oooool2o`0000;ooooo0_l0000F
ooooo`;o0000fOooool001kooooo00?o0000ooooooooool0;oooool2o`0002?ooooo0_l00002oooo
o`?o00003_ooool2o`000003ooooool0003o0000013ooooo0_l0002]ooooo`;o00006?ooool001Co
oooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo02oooooo0_l000000ooooooo
0000o`000003ooooo`;o00006oooool2o`0000;ooooo0ol00002ooooo`Co000000?oooooo`000?l0
00001Oooool2o`0001?ooooo0_l0001Mooooo`;o0000COooool3o`0001Sooooo000Fooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool04Oooool2o`0001oooooo0_l00003ooooo`?o0000
7Oooool2o`0000Cooooo1?l000000ooooooo0000o`00001Nooooo`;o00006Oooool2o`0004gooooo
0_l0000Iooooo`005_ooool00ol0003oooooooooo`05ooooo`?o00000_ooool2o`0000gooooo0_l0
000Uooooo`;o00006oooool5o`0000oooooo0_l0001Gooooo`;o0000Poooool001Kooooo00?o0000
ooooooooool02_ooool2o`00057ooooo0_l000000ooooooo0000o`00000?ooooo`;o0000g?ooool0
01Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3o
oooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Cooooo00?oEEEEofIVI_l00000oooo
oomBooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.15719 .83947 Mdot
.44805 .08333 Mdot
.38636 .88651 Mdot
.22755 .8066 Mdot
.25016 .8269 Mdot
.26872 .86784 Mdot
.45613 .87272 Mdot
.24433 .82716 Mdot
.17339 .84936 Mdot
.23124 .45841 Mdot
.29338 .72627 Mdot
.34632 .79847 Mdot
.33836 .89752 Mdot
.5533 .85849 Mdot
.28592 .90008 Mdot
.21482 .20764 Mdot
.18807 .36614 Mdot
.36023 .95938 Mdot
.18397 .84216 Mdot
.17454 .81576 Mdot
.66427 .85284 Mdot
.19127 .93499 Mdot
.32384 .99297 Mdot
.35065 .66484 Mdot
.1699 .80006 Mdot
.20721 .81773 Mdot
.22107 .86773 Mdot
.21825 .14993 Mdot
.313 .74582 Mdot
.22995 .93265 Mdot
.36475 .90626 Mdot
.27757 .89252 Mdot
.12554 .85559 Mdot
.20281 .49948 Mdot
.3005 .7152 Mdot
.22498 .72215 Mdot
.55665 .84758 Mdot
.00505 .82137 Mdot
.35388 .86808 Mdot
.21862 .80199 Mdot
.34118 .90408 Mdot
.37292 .77959 Mdot
.33786 .97263 Mdot
.77502 .6418 Mdot
.44165 .82971 Mdot
.41471 .7794 Mdot
.44324 .82826 Mdot
.32355 .11085 Mdot
.22421 .73019 Mdot
.3178 .90692 Mdot
.40948 .02065 Mdot
.45041 .92037 Mdot
.27356 .84412 Mdot
.23296 .7748 Mdot
.32052 .89174 Mdot
.18249 .62214 Mdot
.74999 .84639 Mdot
.30257 .86223 Mdot
.2234 .87397 Mdot
.0221 .75656 Mdot
.297 .84802 Mdot
.20962 .82618 Mdot
.42063 .73492 Mdot
.14256 .79984 Mdot
.30001 .8126 Mdot
.20029 .89508 Mdot
.48766 .88454 Mdot
.22067 .86874 Mdot
.28031 .88799 Mdot
.88453 .92749 Mdot
.47487 .68392 Mdot
.19463 .68635 Mdot
.06741 .93168 Mdot
.25862 .50856 Mdot
.2804 .75796 Mdot
.75848 .89498 Mdot
.21193 .03234 Mdot
.39719 .49075 Mdot
.24519 .8857 Mdot
.09413 .84449 Mdot
.34613 .96701 Mdot
.54825 .54269 Mdot
.76315 .31093 Mdot
.23237 .83358 Mdot
.46166 .67927 Mdot
.6787 .75807 Mdot
.22903 .79905 Mdot
.24726 .81886 Mdot
.28673 .89295 Mdot
.07466 .73064 Mdot
.10167 .79571 Mdot
.66999 .8168 Mdot
.28549 .68008 Mdot
.98252 .60594 Mdot
.09551 .84237 Mdot
.342 .96302 Mdot
.84927 .83274 Mdot
.37676 .80598 Mdot
.18317 .80724 Mdot
.0131 .78549 Mdot
.23672 .86833 Mdot
.41123 .04138 Mdot
.03921 .91183 Mdot
.43754 .08387 Mdot
.52807 .99147 Mdot
.31079 .99415 Mdot
.25933 .06328 Mdot
.2408 .16121 Mdot
.42733 .98226 Mdot
.88618 .63099 Mdot
.57119 .90519 Mdot
.706 .45303 Mdot
.16509 .98317 Mdot
.37349 .92805 Mdot
.38375 .83163 Mdot
.4089 .92308 Mdot
.56535 .84859 Mdot
.33839 .91982 Mdot
.29224 .61559 Mdot
.16981 .91598 Mdot
.21676 .83307 Mdot
.38757 .07215 Mdot
.22954 .86712 Mdot
.03995 .59489 Mdot
.46839 .02982 Mdot
.89227 .07653 Mdot
.47085 .8812 Mdot
.17213 .8536 Mdot
.17923 .49767 Mdot
.01383 .05387 Mdot
.59545 .01891 Mdot
.3692 .59933 Mdot
.39232 .06746 Mdot
.28266 .01362 Mdot
.32082 .94786 Mdot
.40764 .96131 Mdot
.31518 .99186 Mdot
.29492 .90022 Mdot
.33017 .86627 Mdot
.21881 .87309 Mdot
.19645 .88583 Mdot
.13769 .79423 Mdot
.16137 .92184 Mdot
.97705 .66777 Mdot
.37929 .91628 Mdot
.3645 .75128 Mdot
.12095 .90567 Mdot
.23246 .85358 Mdot
.80933 .05252 Mdot
.65356 .50967 Mdot
.0619 .85418 Mdot
.14487 .89314 Mdot
.328 .82064 Mdot
.1704 .81189 Mdot
.26986 .89906 Mdot
.29937 .89418 Mdot
.26241 .92963 Mdot
.65462 .3393 Mdot
.19664 .83937 Mdot
.17566 .20548 Mdot
.2856 .9331 Mdot
.13522 .65131 Mdot
.37825 .63833 Mdot
.25553 .01612 Mdot
.18409 .79044 Mdot
.25737 .8613 Mdot
.24293 .83888 Mdot
.2287 .85117 Mdot
.16703 .51762 Mdot
.26099 .98634 Mdot
.18698 .92496 Mdot
.17749 .78212 Mdot
.24818 .68044 Mdot
.61309 .79378 Mdot
.11563 .81975 Mdot
.28351 .76381 Mdot
.11588 .6953 Mdot
.26124 .81032 Mdot
.29506 .09342 Mdot
.44714 .89276 Mdot
.23365 .94843 Mdot
.32819 .74812 Mdot
.18266 .71247 Mdot
.54739 .80842 Mdot
.23965 .32803 Mdot
.30732 .07233 Mdot
.16157 .2125 Mdot
.10152 .81827 Mdot
.00768 .57009 Mdot
.95469 .77128 Mdot
.13688 .83008 Mdot
.56726 .7473 Mdot
.16985 .85546 Mdot
.44224 .83797 Mdot
.17891 .8607 Mdot
.28076 .91931 Mdot
.12916 .63028 Mdot
.35862 .75463 Mdot
.16341 .8481 Mdot
.21089 .81159 Mdot
.05619 .82503 Mdot
.5789 .3093 Mdot
.30261 .00169 Mdot
.53623 .87317 Mdot
.16515 .79998 Mdot
.24773 .81361 Mdot
.81661 .10113 Mdot
.2458 .86482 Mdot
.88798 .62448 Mdot
.22051 .78588 Mdot
.25358 .94552 Mdot
.16688 .88654 Mdot
.51441 .59454 Mdot
.46137 .47198 Mdot
.29258 .9231 Mdot
.27851 .27267 Mdot
.24344 .81286 Mdot
.16001 .68817 Mdot
.19014 .07067 Mdot
.44223 .77293 Mdot
.89716 .1255 Mdot
.08943 .75486 Mdot
.13471 .78936 Mdot
.23759 .8606 Mdot
.03192 .71116 Mdot
.24172 .72505 Mdot
.01181 .0292 Mdot
.37626 .97843 Mdot
.133 .23644 Mdot
.16874 .91772 Mdot
.25019 .86165 Mdot
.02706 .73398 Mdot
.16346 .91847 Mdot
.50563 .62619 Mdot
.29881 .32112 Mdot
.97419 .58806 Mdot
.77644 .17259 Mdot
.37341 .91615 Mdot
.70386 .81643 Mdot
.8081 .05046 Mdot
.34847 .85873 Mdot
.17099 .92884 Mdot
.41339 .07492 Mdot
.18337 .00548 Mdot
.32275 .83047 Mdot
.20548 .91699 Mdot
.11397 .6575 Mdot
.18673 .93312 Mdot
.71723 .23015 Mdot
.3521 .91206 Mdot
.4544 .92633 Mdot
.30944 .91935 Mdot
.61719 .32584 Mdot
.36825 .09998 Mdot
.04914 .13041 Mdot
.27877 .14115 Mdot
.2572 .84444 Mdot
.71008 .9488 Mdot
.42337 .92316 Mdot
.71274 .77265 Mdot
.15944 .87064 Mdot
.29549 .94807 Mdot
.204 .10104 Mdot
.10674 .71977 Mdot
.16415 .9238 Mdot
.90771 .92877 Mdot
.24353 .06895 Mdot
.54463 .05533 Mdot
.36527 .9227 Mdot
.21431 .83436 Mdot
.18184 .80195 Mdot
.50214 .984 Mdot
.30442 .89229 Mdot
.2783 .96441 Mdot
.31554 .90586 Mdot
.30953 .94602 Mdot
.22682 .10639 Mdot
.38385 .53234 Mdot
.23202 .73263 Mdot
.36116 .07305 Mdot
.70215 .79312 Mdot
.18696 .93801 Mdot
.25912 .02411 Mdot
.52742 .71088 Mdot
.25038 .84052 Mdot
.13598 .78935 Mdot
.27731 .98704 Mdot
.96524 .86763 Mdot
.25794 .10959 Mdot
.3107 .07323 Mdot
.34876 .10467 Mdot
.90309 .63974 Mdot
.21012 .85175 Mdot
.15112 .95 Mdot
.94914 .90003 Mdot
.96312 .76313 Mdot
.31557 .83074 Mdot
.17705 .15839 Mdot
.68493 .91628 Mdot
.98774 .38099 Mdot
.98373 .93003 Mdot
.18272 .84073 Mdot
.20273 .64252 Mdot
.16482 .57727 Mdot
.9541 .26052 Mdot
.37564 .9783 Mdot
.22374 .86876 Mdot
.25044 .89344 Mdot
.61497 .60495 Mdot
.55357 .28907 Mdot
.22994 .84925 Mdot
.7251 .0602 Mdot
.20241 .82357 Mdot
.0542 .74182 Mdot
.20185 .75464 Mdot
.16893 .99554 Mdot
.31234 .65745 Mdot
.13319 .00219 Mdot
.14125 .81944 Mdot
.91539 .39229 Mdot
.34008 .9176 Mdot
.14817 .85801 Mdot
.36072 .09404 Mdot
.22383 .6467 Mdot
.37276 .9216 Mdot
.26745 .87134 Mdot
.23136 .72805 Mdot
.15537 .89089 Mdot
.36323 .84836 Mdot
.22515 .85158 Mdot
.13016 .81603 Mdot
.26592 .87737 Mdot
.27682 .25065 Mdot
.92104 .97585 Mdot
.3733 .50663 Mdot
.26871 .66343 Mdot
.67483 .67726 Mdot
.21237 .85102 Mdot
.21227 .27254 Mdot
.48842 .78415 Mdot
.1746 .78477 Mdot
.45517 .49901 Mdot
.18546 .90427 Mdot
.16931 .61639 Mdot
.96973 .63956 Mdot
.0837 .21332 Mdot
.75817 .70973 Mdot
.10916 .42097 Mdot
.4859 .16833 Mdot
.25043 .82131 Mdot
.34926 .923 Mdot
.28096 .87342 Mdot
.07684 .7021 Mdot
.3065 .23307 Mdot
.77896 .17991 Mdot
.30609 .87542 Mdot
.37497 .78694 Mdot
.25021 .99532 Mdot
.3376 .88731 Mdot
.07829 .72199 Mdot
.1831 .93692 Mdot
.16039 .90081 Mdot
.34661 .90235 Mdot
.26347 .95646 Mdot
.13984 .80956 Mdot
.38196 .85621 Mdot
.42461 .96126 Mdot
.99958 .4859 Mdot
.4051 .51038 Mdot
.25188 .93127 Mdot
.31191 .95374 Mdot
.229 .86568 Mdot
.36654 .91027 Mdot
.18104 .89293 Mdot
.88094 .86187 Mdot
.07237 .90367 Mdot
.35168 .79269 Mdot
.22804 .74489 Mdot
.73886 .21695 Mdot
.20376 .91867 Mdot
.25064 .88206 Mdot
.14366 .80261 Mdot
.32433 .16522 Mdot
.66799 .097 Mdot
.1894 .00563 Mdot
.47349 .88534 Mdot
.30351 .08254 Mdot
.84262 .80331 Mdot
.21516 .85503 Mdot
.31597 .89727 Mdot
.19524 .88713 Mdot
.30207 .89215 Mdot
.27853 .8635 Mdot
.27528 .82364 Mdot
.25909 .81874 Mdot
.06858 .54321 Mdot
.19791 .39923 Mdot
.40268 .80832 Mdot
.22405 .87497 Mdot
.35641 .90762 Mdot
.38497 .91142 Mdot
.44868 .90611 Mdot
.47773 .85921 Mdot
.21538 .82942 Mdot
.36225 .59784 Mdot
.11654 .88054 Mdot
.32624 .10179 Mdot
.13267 .71695 Mdot
.23449 .60332 Mdot
.25528 .01934 Mdot
.293 .89009 Mdot
.19546 .82766 Mdot
.29069 .92042 Mdot
.89779 .77172 Mdot
.34502 .97655 Mdot
.31013 .98229 Mdot
.02501 .92898 Mdot
.24351 .73982 Mdot
.09821 .23034 Mdot
.24551 .88951 Mdot
.22263 .83539 Mdot
.71954 .16237 Mdot
.02183 .61893 Mdot
.30665 .92276 Mdot
.28059 .85231 Mdot
.51793 .56431 Mdot
.13929 .9005 Mdot
.16818 .88038 Mdot
.19517 .68616 Mdot
.83288 .5853 Mdot
.33279 .51391 Mdot
.61796 .97614 Mdot
.44861 .75246 Mdot
.12709 .81898 Mdot
.53831 .21078 Mdot
.26837 .21122 Mdot
.20496 .05142 Mdot
.02666 .09518 Mdot
.16655 .01411 Mdot
.40384 .7987 Mdot
.22055 .07462 Mdot
.70061 .84644 Mdot
.65322 .82508 Mdot
.30641 .87175 Mdot
.15244 .53398 Mdot
.27905 .87773 Mdot
.14921 .82935 Mdot
.26094 .88687 Mdot
.43242 .01145 Mdot
.2966 .94793 Mdot
.11917 .06149 Mdot
.42538 .98817 Mdot
.16337 .77979 Mdot
.24642 .87349 Mdot
.11551 .01319 Mdot
.22911 .86 Mdot
.17258 .819 Mdot
.23001 .73418 Mdot
.16459 .51191 Mdot
.10877 .20997 Mdot
.26593 .79346 Mdot
.25223 .84053 Mdot
.25442 .87225 Mdot
.34303 .83412 Mdot
.54265 .71041 Mdot
.37303 .78754 Mdot
.13562 .85095 Mdot
.69445 .14208 Mdot
.30546 .894 Mdot
.26896 .82112 Mdot
.23941 .93462 Mdot
.22053 .80248 Mdot
.23311 .82789 Mdot
.2333 .8309 Mdot
.37414 .83337 Mdot
.2657 .88808 Mdot
.3508 .87869 Mdot
.26417 .85206 Mdot
.97342 .71118 Mdot
.3523 .84533 Mdot
.37372 .32292 Mdot
.35964 .80878 Mdot
.17329 .93285 Mdot
.21808 .90151 Mdot
.15371 .84532 Mdot
.67729 .03426 Mdot
.52602 .23851 Mdot
.19663 .34157 Mdot
.10584 .79657 Mdot
.25799 .15797 Mdot
.36128 .92308 Mdot
.21822 .84168 Mdot
.1629 .67904 Mdot
.32299 .116 Mdot
.12389 .77719 Mdot
.35367 .76035 Mdot
.12414 .94068 Mdot
.18888 .78025 Mdot
.72956 .72136 Mdot
.27152 .65536 Mdot
.13982 .96869 Mdot
.08178 .10001 Mdot
.16653 .73728 Mdot
.20464 .44353 Mdot
.32466 .97094 Mdot
.30645 .76412 Mdot
.21169 .80887 Mdot
.92529 .01411 Mdot
.18016 .81937 Mdot
.22441 .90726 Mdot
.2848 .93001 Mdot
.06185 .39218 Mdot
.24417 .57919 Mdot
.33608 .17783 Mdot
.24715 .81783 Mdot
.76737 .62956 Mdot
.22203 .9664 Mdot
.33152 .94917 Mdot
.25382 .65928 Mdot
.34929 .91453 Mdot
.25126 .97684 Mdot
.37245 .83062 Mdot
.24764 .88323 Mdot
.23499 .83062 Mdot
.00895 .73759 Mdot
.01321 .94566 Mdot
.06549 .54203 Mdot
.43311 .77867 Mdot
.06653 .69514 Mdot
.13812 .55435 Mdot
.75416 .46438 Mdot
.45777 .78265 Mdot
.24763 .83225 Mdot
.41461 .91479 Mdot
.2365 .8416 Mdot
.22491 .87435 Mdot
.28253 .80257 Mdot
.11328 .82786 Mdot
.89958 .88686 Mdot
.96886 .79054 Mdot
.22173 .87312 Mdot
.60098 .01112 Mdot
.35474 .74454 Mdot
.26284 .8931 Mdot
.32891 .86971 Mdot
.85266 .75648 Mdot
.36 .96043 Mdot
.29932 .87264 Mdot
.26633 .0223 Mdot
.26532 .87302 Mdot
.86662 .87433 Mdot
.11513 .72289 Mdot
.11709 .8491 Mdot
.39501 .51715 Mdot
.39543 .06319 Mdot
.718 .32824 Mdot
.17706 .32939 Mdot
.21016 .84589 Mdot
.19653 .72793 Mdot
.23073 .81336 Mdot
.25691 .02276 Mdot
.20001 .7946 Mdot
.00287 .85514 Mdot
.06797 .76389 Mdot
.28911 .98103 Mdot
.23018 .72439 Mdot
.27217 .89403 Mdot
.14795 .78818 Mdot
.49729 .61442 Mdot
.28391 .88831 Mdot
.07009 .11611 Mdot
.39176 .11946 Mdot
.26874 .88376 Mdot
.13803 .91103 Mdot
.31784 .89417 Mdot
.14672 .88853 Mdot
.05883 .10347 Mdot
.31222 .75012 Mdot
.32233 .93047 Mdot
.25339 .8902 Mdot
.92977 .91411 Mdot
.29604 .00272 Mdot
.33752 .86226 Mdot
.2362 .89098 Mdot
.46281 .88809 Mdot
.23478 .76201 Mdot
.26787 .07967 Mdot
.50807 .66092 Mdot
.38188 .06258 Mdot
.08793 .85614 Mdot
.27455 .85538 Mdot
.33422 .87564 Mdot
.2036 .60341 Mdot
.17795 .81152 Mdot
.37828 .74666 Mdot
.19979 .83219 Mdot
.21636 .92274 Mdot
.25254 .86813 Mdot
.23109 .73992 Mdot
.24819 .82841 Mdot
.14585 .90115 Mdot
.22954 .85354 Mdot
.37092 .92254 Mdot
.37064 .7958 Mdot
.02695 .63873 Mdot
.25032 .01721 Mdot
.22261 .83838 Mdot
.19844 .94218 Mdot
.83656 .68466 Mdot
.15825 .85247 Mdot
.13006 .69638 Mdot
.61243 .09827 Mdot
.29006 .92064 Mdot
.84678 .6917 Mdot
.16875 .84595 Mdot
.17543 .21137 Mdot
.21101 .72317 Mdot
.7966 .06197 Mdot
.19035 .83431 Mdot
.38647 .07857 Mdot
.29564 .54187 Mdot
.05958 .14908 Mdot
.15842 .84834 Mdot
.51985 .17493 Mdot
.32119 .78183 Mdot
.19231 .06221 Mdot
.13873 .78994 Mdot
.69342 .49739 Mdot
.35677 .94917 Mdot
.47355 .8693 Mdot
.36852 .85261 Mdot
.22948 .85643 Mdot
.05526 .81895 Mdot
.39173 .82807 Mdot
.26985 .88063 Mdot
.02566 .4768 Mdot
.23769 .83504 Mdot
.20889 .57424 Mdot
.27723 .86202 Mdot
.29303 .90242 Mdot
.46676 .86568 Mdot
.2765 .87745 Mdot
.40313 .787 Mdot
.47598 .84949 Mdot
.05981 .50441 Mdot
.23398 .92967 Mdot
.47379 .90038 Mdot
.8815 .65967 Mdot
.22705 .84654 Mdot
.87872 .67873 Mdot
.38745 .62623 Mdot
.26277 .7369 Mdot
.04464 .95859 Mdot
.24231 .86159 Mdot
.2699 .83792 Mdot
.21262 .80408 Mdot
.30261 .84079 Mdot
.64936 .8998 Mdot
.89487 .63181 Mdot
.22614 .86946 Mdot
.35309 .78904 Mdot
.30738 .98163 Mdot
.60631 .0386 Mdot
.2152 .79954 Mdot
.29743 .69392 Mdot
.22539 .6692 Mdot
.24692 .89259 Mdot
.80062 .91909 Mdot
.02261 .79515 Mdot
.10345 .98734 Mdot
.96059 .61615 Mdot
.48402 .67747 Mdot
.52893 .79539 Mdot
.19748 .87811 Mdot
.58233 .58492 Mdot
.19898 .8238 Mdot
.82752 .92653 Mdot
.30683 .90639 Mdot
.74096 .78161 Mdot
.76739 .82719 Mdot
.88182 .46827 Mdot
.982 .70117 Mdot
.47742 .21811 Mdot
.16557 .84167 Mdot
.28267 .88694 Mdot
.17336 .69293 Mdot
.49884 .92641 Mdot
.62596 .86779 Mdot
.05995 .95227 Mdot
.37062 .91929 Mdot
.30909 .11151 Mdot
.51934 .8817 Mdot
.15069 .59499 Mdot
.16241 .13479 Mdot
.1376 .88825 Mdot
.29758 .98633 Mdot
.25092 .8697 Mdot
.42533 .92653 Mdot
.34989 .01121 Mdot
.62322 .81033 Mdot
.16142 .51474 Mdot
.34349 .23255 Mdot
.3115 .90358 Mdot
.30603 .86953 Mdot
.45635 .16895 Mdot
.21279 .8552 Mdot
.11893 .8919 Mdot
.50496 .66675 Mdot
.29815 .78206 Mdot
.13947 .85184 Mdot
.95051 .07902 Mdot
.16812 .70697 Mdot
.49012 .99038 Mdot
.75031 .40763 Mdot
.36689 .97936 Mdot
.89797 .86475 Mdot
.18228 .9351 Mdot
.26464 .81308 Mdot
.54808 .35431 Mdot
.18205 .92817 Mdot
.16015 .89596 Mdot
.27252 .75538 Mdot
.26048 .99112 Mdot
.82679 .84398 Mdot
.55281 .13088 Mdot
.7408 .02758 Mdot
.59316 .96992 Mdot
.21134 .82175 Mdot
.33865 .89233 Mdot
.87816 .64743 Mdot
.22843 .84746 Mdot
.204 .90118 Mdot
.31951 .90135 Mdot
.19951 .86083 Mdot
.30916 .28524 Mdot
.95591 .03602 Mdot
.17648 .74624 Mdot
.10888 .34974 Mdot
.43633 .90658 Mdot
.17697 .66537 Mdot
.1927 .87169 Mdot
.18204 .81713 Mdot
.0951 .82044 Mdot
.67639 .7771 Mdot
.81839 .63756 Mdot
.47344 .88761 Mdot
.2045 .9101 Mdot
.75657 .78828 Mdot
.2173 .80095 Mdot
.58819 .80943 Mdot
.46088 .99619 Mdot
.35433 .88555 Mdot
.08474 .01013 Mdot
.14969 .89649 Mdot
.27502 .97515 Mdot
.17651 .81203 Mdot
.27358 .95922 Mdot
.33469 .91775 Mdot
.34308 .87053 Mdot
.36429 .91933 Mdot
.02666 .88954 Mdot
.24041 .82276 Mdot
.23381 .85068 Mdot
.35684 .87914 Mdot
.30822 .13607 Mdot
.27486 .84137 Mdot
.01812 .74679 Mdot
.84322 .16009 Mdot
.35789 .75453 Mdot
.32746 .57199 Mdot
.16721 .77413 Mdot
.0596 .81025 Mdot
.28125 .00905 Mdot
.30903 .91921 Mdot
.52648 .3448 Mdot
.28467 .89982 Mdot
.26179 .86787 Mdot
.36342 .92334 Mdot
.12641 .03304 Mdot
.39491 .18226 Mdot
.21725 .80679 Mdot
.15515 .03158 Mdot
.04395 .60147 Mdot
.07824 .92007 Mdot
.28629 .79522 Mdot
.24462 .06737 Mdot
.23657 .22852 Mdot
.21931 .87008 Mdot
.22008 .84474 Mdot
.29538 .88567 Mdot
.36588 .12857 Mdot
.39877 .53969 Mdot
.38892 .72061 Mdot
.23195 .81001 Mdot
.04758 .75099 Mdot
.30085 .84484 Mdot
.29424 .16048 Mdot
.34622 .07677 Mdot
.17501 .75936 Mdot
.08669 .66626 Mdot
.61565 .02355 Mdot
.20979 .93769 Mdot
.33951 .86161 Mdot
.18906 .84728 Mdot
.09493 .68454 Mdot
.33936 .97593 Mdot
.02242 .57593 Mdot
.13229 .60675 Mdot
.01325 .6801 Mdot
.20577 .88779 Mdot
.02053 .8538 Mdot
.1986 .7368 Mdot
.3678 .836 Mdot
.37031 .76976 Mdot
.10281 .82767 Mdot
.23471 .8665 Mdot
.40212 .49484 Mdot
.73903 .01563 Mdot
.28639 .89884 Mdot
.67648 .83949 Mdot
.23794 .83656 Mdot
.24953 .8601 Mdot
.21423 .84654 Mdot
.30051 .89083 Mdot
.23712 .80098 Mdot
.30839 .00592 Mdot
.25287 .83252 Mdot
.17774 .80902 Mdot
.63331 .28484 Mdot
.26602 .84962 Mdot
.57153 .82891 Mdot
.93111 .87873 Mdot
.33906 .90064 Mdot
.72126 .8133 Mdot
.48189 .75184 Mdot
.25364 .02359 Mdot
.04627 .3658 Mdot
.22354 .73108 Mdot
.12981 .81825 Mdot
.68026 .08226 Mdot
.37679 .64402 Mdot
.25211 .86669 Mdot
.22444 .87211 Mdot
.18704 .86521 Mdot
.75524 .91928 Mdot
.99511 .63777 Mdot
.65006 .12123 Mdot
.34956 .91852 Mdot
.19844 .82878 Mdot
.352 .88467 Mdot
.00274 .9146 Mdot
.10322 .70238 Mdot
.3296 .90003 Mdot
.09311 .86184 Mdot
.22804 .81461 Mdot
.12362 .14239 Mdot
.23958 .82902 Mdot
.28461 .27278 Mdot
.3118 .84366 Mdot
.33607 .86558 Mdot
.23503 .85242 Mdot
.26694 .82387 Mdot
.13645 .86158 Mdot
.33438 .81413 Mdot
.20704 .82543 Mdot
.31113 .72068 Mdot
.16703 .83564 Mdot
.21425 .06078 Mdot
.19339 .00238 Mdot
.27974 .86901 Mdot
.93384 .91002 Mdot
.23283 .84237 Mdot
.15111 .78861 Mdot
.21295 .75705 Mdot
.36571 .9393 Mdot
.24108 .80076 Mdot
.3826 .44961 Mdot
.1043 .47158 Mdot
.35384 .87353 Mdot
.25451 .93476 Mdot
.54868 .84364 Mdot
.28 .88572 Mdot
.23374 .82354 Mdot
.32883 .81649 Mdot
.28884 .86392 Mdot
.15142 .83883 Mdot
.16389 .88416 Mdot
.90963 .14252 Mdot
.18856 .93562 Mdot
.43933 .81803 Mdot
.16397 .56386 Mdot
.42364 .20159 Mdot
.39724 .95914 Mdot
.1822 .9372 Mdot
.48457 .63866 Mdot
.2978 .81932 Mdot
.03449 .08248 Mdot
.30378 .9017 Mdot
.08148 .80623 Mdot
.21508 .86531 Mdot
.27017 .93576 Mdot
.31162 .07874 Mdot
.96281 .21331 Mdot
.14943 .99331 Mdot
.82055 .03964 Mdot
.08978 .16026 Mdot
.0641 .93427 Mdot
.23367 .97717 Mdot
.25123 .86992 Mdot
.18851 .9133 Mdot
.47884 .94519 Mdot
.04946 .95362 Mdot
.38945 .09755 Mdot
.11866 .84083 Mdot
.40888 .76326 Mdot
.30959 .55704 Mdot
.24126 .86103 Mdot
.1536 .77724 Mdot
.2997 .83681 Mdot
.17762 .8696 Mdot
.9517 .56721 Mdot
.12437 .61202 Mdot
.21124 .92998 Mdot
.22609 .84587 Mdot
.28554 .89906 Mdot
.6478 .01476 Mdot
.15346 .22945 Mdot
.1317 .04527 Mdot
.26333 .0972 Mdot
.89886 .65298 Mdot
.40359 .70898 Mdot
.30616 .98621 Mdot
.26935 .86198 Mdot
.163 .92286 Mdot
.50419 .73952 Mdot
.17695 .87215 Mdot
.53022 .43069 Mdot
.19768 .91349 Mdot
.24435 .89139 Mdot
.53972 .6603 Mdot
.29987 .87716 Mdot
.30438 .87326 Mdot
.17468 .79475 Mdot
.87116 .80203 Mdot
.39588 .88841 Mdot
.26957 .86993 Mdot
.89242 .83408 Mdot
.47483 .77513 Mdot
.22074 .86799 Mdot
.41612 .35863 Mdot
.29963 .91155 Mdot
.70244 .91376 Mdot
.4865 .83908 Mdot
.36156 .62137 Mdot
.27171 .66445 Mdot
.35596 .90467 Mdot
.64443 .05039 Mdot
.95281 .97436 Mdot
.45706 .75665 Mdot
.54428 .92474 Mdot
.19734 .93851 Mdot
.24066 .86874 Mdot
.28904 .89938 Mdot
.05056 .70145 Mdot
.24779 .86528 Mdot
.57723 .26719 Mdot
.30069 .91639 Mdot
.24896 .7534 Mdot
.71351 .10761 Mdot
.60006 .40692 Mdot
.27917 .16295 Mdot
.69832 .55525 Mdot
.37917 .66684 Mdot
.92944 .80707 Mdot
.01987 .94292 Mdot
.2134 .81223 Mdot
.17527 .15819 Mdot
.83372 .5795 Mdot
.23119 .87914 Mdot
.22924 .85701 Mdot
.28472 .83202 Mdot
.08153 .76552 Mdot
.12533 .29491 Mdot
.16813 .20408 Mdot
.2031 .90241 Mdot
.44065 .97858 Mdot
.03936 .03104 Mdot
.99035 .36495 Mdot
.4071 .87026 Mdot
.21886 .86402 Mdot
.42979 .03308 Mdot
.21491 .79923 Mdot
.23419 .92735 Mdot
.48803 .41121 Mdot
.1478 .82239 Mdot
.21186 .81427 Mdot
.28429 .87649 Mdot
.31149 .84377 Mdot
.23434 .95498 Mdot
.2692 .83991 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`;o00001?ooool00ol0003o
ooooooooo`0;ooooo`;o000000?oooooo`000?ooool03_ooool00ol0003oooooooooo`0;ooooo`Co
00003_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo000Nooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`;o0000
1?ooool00ol0003oooooooooo`07ooooo`Ko000000?oooooo`000?ooool03_ooool00ol0003ooooo
ooooo`0;ooooo`Ko00003?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo
000Nooooo`03o`000?oooooooooo01Oooooo0_l0000Nooooo`Co00007?ooool2o`0000Oooooo0_l0
003Uooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o00002?ooool2o`0003Cooooo0ol0000D
ooooo`;o00006?ooool2o`0003Gooooo0_l00026ooooo`007_ooool00ol0003oooooooooo`0Qoooo
o`;o00003oooool2o`0001_ooooo0_l00007ooooo`;o00005?ooool2o`0001Sooooo0_l0000eoooo
o`;o00003Oooool2o`0001cooooo0_l0000kooooo`;o00007?ooool001kooooo00?o0000oooooooo
ool0<_ooool2o`0001Wooooo1?l0001/ooooo`;o00003oooool2o`0001cooooo0_l0000kooooo`;o
00007?ooool001kooooo00?o0000ooooooooool0COooool4o`000003ooooool0003o000002gooooo
0_l0000jooooo`;o0000R?ooool001kooooo00?o0000ooooooooool0C_ooool6o`0002gooooo0_l0
0011ooooo`;o0000POooool001kooooo00?o0000ooooooooool0C_ooool4o`0007;ooooo0_l0000W
ooooo`;o0000F?ooool001kooooo00?o0000ooooooooool00_l00007ooooo`;o00008oooool2o`00
06Cooooo0_l0001Gooooo`;o0000F?ooool001kooooo00?o0000ooooooooool00_l00007ooooo`;o
00006_ooool2o`0000Oooooo0_l0000Aooooo`;o0000AOooool2o`0000[ooooo0_l00012ooooo`;o
0000KOooool001kooooo00?o0000ooooooooool09Oooool2o`0001[ooooo0_l00015ooooo`;o0000
C_ooool2o`0005Wooooo0_l0000Booooo`007_ooool00ol0003oooooooooo`22ooooo`;o0000?Ooo
ool2o`0004Cooooo0_l0000Zooooo`;o00004_ooool001kooooo00?o0000ooooooooool0P_ooool2
o`0003gooooo0_l00014ooooo`;o0000?_ooool001kooooo00?o0000ooooooooool09oooool2o`00
0?oooooo7oooool001kooooo00?o0000ooooooooool09oooool2o`000:Cooooo0_l0000dooooo`;o
0000@_ooool001kooooo0_l00010ooooo`;o0000S?ooool2o`0003Cooooo0_l00012ooooo`007_oo
ool00ol0003oooooooooo`02o`0003gooooo0_l0001/ooooo`;o0000E?ooool2o`0004;ooooo000N
ooooo`03o`000?oooooooooo00;o0000Zoooool2o`0009Sooooo000Nooooo`03o`000?oooooooooo
02?ooooo0_l0000Eooooo`;o00001_ooool2o`0003Cooooo0_l0001^ooooo`;o00005Oooool2o`00
04Kooooo000Nooooo`03o`000?oooooooooo02?ooooo0_l0000Eooooo`;o00001_ooool2o`0000co
oooo0_l0000Vooooo`;o00000_ooool2o`0006[ooooo0_l0000Eooooo`;o0000A_ooool001kooooo
00?o0000ooooooooool0Boooool2o`0000?ooooo0_l0000Yooooo`?o0000bOooool001kooooo00?o
0000ooooooooool0>_ooool2o`0000oooooo0_l0000]ooooo`?o0000b_ooool001kooooo00?o0000
ooooooooool0>_ooool2o`0000Sooooo0_l0000Jooooo`?o00003_ooool2o`0000Oooooo0_l00006
ooooo`;o0000`oooool001kooooo00?o0000ooooooooool0A?ooool2o`0001[ooooo0ol00009oooo
o`;o00000oooool2o`0000oooooo0_l0002Jooooo`;o00009oooool001kooooo00?o0000oooooooo
ool0Doooool2o`0000cooooo0_l00009ooooo`;o00003?ooool2o`000:;ooooo0_l0000Aooooo`;o
00005?ooool001kooooo00?o0000ooooooooool01oooool2o`0004[ooooo0_l0000:ooooo`Co0000
5oooool2o`0000kooooo0_l00002ooooo`;o0000BOooool2o`0005Kooooo0_l0000Dooooo`007_oo
ool00ol0003oooooooooo`07ooooo`;o0000E_ooool2o`0002Wooooo0_l00002ooooo`;o0000BOoo
ool2o`0006cooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0G?ooool2o`000>Wooooo000Nooooo`03o`000?oooooooooo00Gooooo0_l0001Eooooo`;o
00004oooool2o`000=Cooooo000Nooooo`03o`000?oooooooooo00Gooooo0_l0001:ooooo`;o0000
7_ooool2o`0000Oooooo0_l00017ooooo`;o00004?ooool2o`00073ooooo000Nooooo`;o00005ooo
ool2o`0002Kooooo0_l0000Aooooo`;o00004oooool2o`0000cooooo0_l00004ooooo`;o0000Aooo
ool2o`00013ooooo0_l0000^ooooo`;o0000@?ooool001kooooo00?o0000ooooooooool03oooool2
o`0000Gooooo0_l0000Vooooo`;o00009_ooool2o`0000Gooooo0_l00005ooooo`;o0000Soooool2
o`00043ooooo000Nooooo`03o`000?oooooooooo00oooooo0_l0000eooooo`;o00009Oooool2o`00
07Gooooo0_l0001Qooooo`007_ooool00ol0003oooooooooo`16ooooo`;o00002?ooool2o`0000ko
oooo0_l00003ooooo`;o0000OOooool2o`00067ooooo000Nooooo`03o`000?oooooooooo053ooooo
0_l0000>ooooo`;o00000oooool2o`000>3ooooo000Nooooo`03o`000?oooooooooo01?ooooo0_l0
001@ooooo`;o0000h?ooool001kooooo00?o0000ooooooooool04oooool2o`00053ooooo0_l0000D
ooooo`;o0000D_ooool2o`0007Kooooo000Nooooo`03o`000?oooooooooo07_ooooo0_l0001Boooo
o`;o0000M_ooool001kooooo00?o0000ooooooooool0oooooolQooooo`;o00009Oooool001kooooo
00?o0000ooooooooool03?ooool2o`0006Gooooo0_l0002[ooooo`;o00009Oooool001kooooo00?o
0000ooooooooool03?ooool2o`0006Gooooo0_l0000kooooo`;o0000UOooool001kooooo00?o0000
ooooooooool0<Oooool2o`0002gooooo0_l0001>ooooo`;o0000UOooool001kooooo00?o0000oooo
ooooool0<Oooool2o`0002gooooo0_l0003Uooooo`007_ooool00ol0003oooooooooo`0Tooooo`;o
0000<Oooool2o`0008Gooooo0_l00014ooooo`;o00008Oooool001kooooo00?o0000ooooooooool0
9?ooool2o`00037ooooo0_l00025ooooo`;o0000A?ooool2o`00027ooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo0_l0000@ooooo`;o0000<_ooool2o`000?oooooo0oooool0
01kooooo00?o0000ooooooooool03oooool2o`0003;ooooo0_l0003oooooo`?ooooo000Nooooo`03
o`000?oooooooooo03Gooooo0_l0000Iooooo`;o0000mOooool001kooooo00?o0000ooooooooool0
6Oooool2o`0001[ooooo0_l0000Cooooo`;o00001?ooool2o`0000[ooooo0_l0002`ooooo`;o0000
=oooool001kooooo00?o0000ooooooooool06Oooool2o`0001[ooooo0_l0000Cooooo`;o00002ooo
ool2o`0000?ooooo0_l00028ooooo`;o00009_ooool2o`0003Oooooo000Nooooo`03o`000?oooooo
oooo05Oooooo0_l0000<ooooo`;o0000Ooooool2o`0005oooooo000Nooooo`03o`000?oooooooooo
06Gooooo0_l0000Yooooo`;o00002?ooool2o`000:_ooooo000Nooooo`03o`000?oooooooooo093o
oooo0_l00008ooooo`;o0000G?ooool2o`0004gooooo000Nooooo`03o`000?oooooooooo0:Gooooo
0_l0001Aooooo`;o0000COooool001kooooo00?o0000ooooooooool0JOooool2o`0003[ooooo0_l0
002Pooooo`007_ooool00ol0003oooooooooo`1Yooooo`;o00004Oooool2o`0007_ooooo0_l0001<
ooooo`007_ooool00ol0003oooooooooo`1looooo`;o0000Noooool2o`0004cooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003ooooo
ooooo`3oooooodSooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo
00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodSo
oooo0003ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`03
o`000?oooooooooo03?ooooo0_l0001Aooooo`;o0000_oooool000?ooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0<oooool4o`0004oo
oooo0_l0002oooooo`000oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Oooooo`;o00005?ooool2o`0000_ooooo0_l0003oooooo`Co
oooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@
00Kooooo00?o0000ooooooooool05oooool2o`0000Kooooo0_l0000?ooooo`;o00000oooool2o`00
00_ooooo0_l0000?ooooo`;o0000E_ooool2o`0008Sooooo0_l0000@ooooo`000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooo
oooo01Oooooo0_l0000Gooooo`;o00000oooool2o`0001cooooo0_l0001Fooooo`;o0000R?ooool2
o`00013ooooo000Nooooo`03o`000?oooooooooo09Oooooo0_l0001Cooooo`;o0000FOooool001ko
oooo00?o0000ooooooooool0Uoooool2o`0005?ooooo0_l0001Iooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo04Wooooo0_l0003looooo`007_ooool0
0ol0003oooooooooo`0Looooo`;o00004?ooool2o`0001Wooooo0_l0002Jooooo`;o0000H?ooool0
01kooooo00?o0000ooooooooool07?ooool2o`00013ooooo0_l0000`ooooo`;o00002_ooool2o`00
07Oooooo0_l0001Pooooo`007_ooool00ol0003oooooooooo`0Wooooo`;o0000=oooool2o`0000[o
oooo0_l0003Iooooo`007_ooool00ol0003oooooooooo`0Wooooo`;o0000O_ooool2o`0009kooooo
000Nooooo`03o`000?oooooooooo0:Oooooo0_l0002Nooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0001Gooooo`;o
0000koooool001kooooo00?o0000ooooooooool0E_ooool2o`000>oooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooolcooooo`;o00004oooool0
01kooooo00?o0000ooooooooool0oooooolcooooo`;o00004oooool001kooooo00?o0000oooooooo
ool0^?ooool2o`0008gooooo000Nooooo`03o`000?oooooooooo0;Sooooo0_l0002=ooooo`007_oo
ool00ol0003oooooooooo`11ooooo`;o00004oooool4o`000>gooooo000Nooooo`03o`000?oooooo
oooo047ooooo0_l0000Cooooo`Co0000kOooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo063ooooo
0_l0001Xooooo`;o0000Noooool001kooooo00?o0000ooooooooool0H?ooool2o`0004kooooo0_l0
000Hooooo`;o0000Noooool001kooooo00?o0000ooooooooool0/?ooool2o`0009Gooooo000Noooo
o`03o`000?oooooooooo02Gooooo0_l0003oooooob7ooooo000Nooooo`03o`000?oooooooooo02Go
oooo0_l0003oooooob7ooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0^?ooool2o`0003[ooooo0_l0001Aooooo`007_ooool00ol0003oooooooooo`2hooooo`;o
0000>_ooool2o`00057ooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0GOooool2o`000>Sooooo000Nooooo`03o`000?oooooooooo05gooooo0_l0000F
ooooo`;o0000d?ooool001kooooo00?o0000ooooooooool0MOooool2o`0004kooooo0_l00020oooo
o`007_ooool00ol0003oooooooooo`0eooooo`;o00004oooool2o`0007Wooooo0_l0000Nooooo`;o
0000H?ooool001kooooo00?o0000ooooooooool0=Oooool2o`0001?ooooo0_l0002Iooooo`;o0000
H?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3A
ooooo`;o0000M?ooool001kooooo00?o0000ooooooooool0??ooool2o`0009?ooooo0_l0001doooo
o`007_ooool00ol0003oooooooooo`0looooo`;o0000JOooool2o`0009kooooo000Nooooo`03o`00
0?oooooooooo0:Oooooo0_l0002Nooooo`007_ooool2o`00023ooooo0_l0003oooooobOooooo000N
ooooo`03o`000?oooooooooo01oooooo0_l0002=ooooo`;o0000Uoooool001kooooo00?o0000oooo
ooooool0[_ooool2o`0009Oooooo000Nooooo`03o`000?oooooooooo08?ooooo0_l00032ooooo`00
7_ooool00ol0003oooooooooo`23ooooo`;o0000`_ooool001kooooo00?o0000ooooooooool02ooo
ool2o`0002cooooo0_l0003oooooo`Cooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`0;
ooooo`;o0000;?ooool2o`000?oooooo1?ooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo?_ooool2o`0000Sooooo000N
ooooo`03o`000?oooooooooo0?oooooo?_ooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003o
ooooooooo`0@ooooo`;o0000oooooolDooooo`;o00008?ooool000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo013o
oooo0_l0003ooooooaCooooo0_l0000Pooooo`000oooool01Ol@413ooooooooooooooooo410@00_o
oooo1Ol00006ooooo`?o0000??ooool2o`000?oooooo2_ooool000?ooooo00Go0000oooooooooooo
ooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0??ooool2o`00
0?oooooo2_ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0000Oooooo00?o0000ooooooooool0_oooool2o`0008Kooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo0;oooooo0_l0000_
ooooo`;o0000EOooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co
000000Oooooo00?o0000ooooooooool0Voooool2o`0005?ooooo0_l0001Eooooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`2K
ooooo`;o0000Z_ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`0Oooooo`;o0000oooooolWooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o0000
oooooolWooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0:Sooooo0_l0002Mooooo`007_ooool00ol0003oooooooooo`2Xooooo`;o0000WOooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo03kooooo0_l0003oooooo`Sooooo000Nooooo`03o`000?oooooo
oooo03kooooo0_l0003oooooo`Sooooo000Nooooo`03o`000?oooooooooo07Sooooo0_l0003=oooo
o`007_ooool2o`0007Wooooo0_l0001Wooooo`;o0000I?ooool001kooooo00?o0000ooooooooool0
hOooool2o`0006Cooooo000Nooooo`03o`000?oooooooooo04Oooooo0_l0003nooooo`007_ooool0
0ol0003oooooooooo`17ooooo`;o0000o_ooool001kooooo00?o0000ooooooooool0lOooool2o`00
05Cooooo000Nooooo`03o`000?oooooooooo0?7ooooo0_l0000Xooooo`;o0000:_ooool001kooooo
00?o0000ooooooooool07_ooool2o`0007;ooooo0_l00027ooooo`;o0000:_ooool001kooooo00?o
0000ooooooooool07_ooool2o`0007;ooooo0_l0002cooooo`007_ooool00ol0003oooooooooo`04
ooooo`;o0000oooooom2ooooo`007_ooool00ol0003oooooooooo`04ooooo`;o0000oooooom2oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
@_ooool2o`0000Cooooo000Nooooo`03o`000?oooooooooo0?oooooo@_ooool2o`0000Cooooo000N
ooooo`03o`000?oooooooooo07gooooo0_l00038ooooo`007_ooool00ol0003oooooooooo`1moooo
o`Co0000a_ooool001kooooo00?o0000ooooooooool0=_ooool2o`0000Kooooo0_l0000oooooo`;o
00003oooool2o`0004_ooooo0_l0001Xooooo`007_ooool2o`0003Oooooo0_l00006ooooo`;o0000
D?ooool2o`0004_ooooo0_l0001Xooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o0000oooo
oolgooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o0000?oooool2o`0002?ooooo0_l0003@
ooooo`007_ooool00ol0003oooooooooo`0aooooo`;o00007Oooool2o`0002?ooooo0_l00009oooo
o`;o0000C_ooool2o`0007Gooooo000Nooooo`03o`000?oooooooooo033ooooo0ol0000eooooo`;o
00005_ooool2o`0004kooooo0_l0001eooooo`007_ooool00ol0003oooooooooo`0`ooooo`Co0000
=?ooool2o`0001;ooooo0_l00039ooooo`007_ooool00ol0003oooooooooo`0booooo`;o0000B?oo
ool2o`000<Wooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo07Wooooo0_l0003<ooooo`007_ooool00ol0003oooooooooo`0]ooooo`;o0000B_oo
ool2o`000<cooooo000Nooooo`03o`000?oooooooooo02gooooo0_l0001?ooooo`;o0000aoooool0
01kooooo00?o0000ooooooooool04Oooool2o`0004Wooooo0_l0000Pooooo`;o0000;_ooool2o`00
09Oooooo000Nooooo`03o`000?oooooooooo017ooooo0ol00018ooooo`;o0000D?ooool2o`0009Oo
oooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0003oooooocCooooo000Nooooo`;o0000oooo
oom9ooooo`007_ooool00ol0003oooooooooo`0Yooooo`;o0000oooooolMooooo`007_ooool00ol0
003oooooooooo`0Yooooo`;o0000=_ooool2o`0007cooooo0_l0001Vooooo`007_ooool00ol0003o
ooooooooo`1Qooooo`;o0000O?ooool2o`0006Kooooo000Nooooo`03o`000?oooooooooo037ooooo
0_l0003ooooooaGooooo000Nooooo`03o`000?oooooooooo037ooooo0_l0001aooooo`;o0000Rooo
ool2o`0001Cooooo000Nooooo`?o0000Y?ooool2o`0008_ooooo0_l0000Dooooo`007_ooool3o`00
06Kooooo0_l0003Oooooo`007_ooool00ol0003oooooooooo`03ooooo`;o0000>oooool2o`0002Co
oooo0_l0003Oooooo`007_ooool00ol0003oooooooooo`03ooooo`;o0000;?ooool2o`0000gooooo
0_l00009ooooo`;o0000__ooool2o`0003[ooooo000Nooooo`03o`000?oooooooooo037ooooo0_l0
000Hooooo`;o0000__ooool2o`0003[ooooo000Nooooo`03o`000?oooooooooo0;Wooooo0_l0001@
ooooo`;o0000>_ooool001kooooo00?o0000ooooooooool0^Oooool2o`00053ooooo0_l0000/oooo
o`;o00003?ooool001kooooo00?o0000ooooooooool0ooooooljooooo`;o00003?ooool000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
00Kooooo00?o0000ooooooooool02Oooool2o`0002;ooooo0_l0001dooooo`;o0000X_ooool000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So
8B4Q00Kooooo00?o0000ooooooooool02Oooool2o`0002;ooooo0_l00013ooooo`;o0000;oooool2
o`000:;ooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooo
oooo000000Kooooo0ol0001booooo`Co0000dOooool000?ooooo00Go0000ooooooooooooooooo`00
000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0:ooooo`;o0000
<_ooool2o`0000Sooooo0_l0000Zooooo`;o0000dOooool000?ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0:ooooo`;o
00006oooool2o`0001Gooooo0_l00008ooooo`;o0000N_ooool2o`0007Gooooo0_l0000:ooooo`00
0oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003o
ooooooooo`0Wooooo`;o0000Voooool2o`0007Gooooo0_l0000:ooooo`000oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0Tooooo`;o
0000oooooolRooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0
003o410@1_ooool00ol0003oooooooooo`0Tooooo`;o00003Oooool2o`0002Kooooo0_l00011oooo
o`;o0000U?ooool2o`00017ooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0000^ooooo`;o
00009_ooool2o`00047ooooo0_l0002Dooooo`;o00004Oooool001kooooo00?o0000ooooooooool0
0oooool2o`0003;ooooo0_l0000hooooo`;o0000e?ooool001kooooo00?o0000ooooooooool0=ooo
ool2o`0003Sooooo0_l0002Zooooo`;o0000:?ooool001kooooo00?o0000ooooooooool0N_ooool2
o`0002Cooooo0_l0001kooooo`;o0000:?ooool001kooooo00?o0000ooooooooool09_ooool2o`00
05;ooooo0_l0000Tooooo`;o0000Doooool2o`0002Gooooo0_l000000ooooooo0000o`00000Voooo
o`007_ooool00ol0003oooooooooo`0Vooooo`;o0000cOooool2o`0002Gooooo0_l000000ooooooo
0000o`00000Vooooo`007_ooool00ol0003oooooooooo`3oooooo`Oooooo0_l0000gooooo`;o0000
1_ooool001kooooo00?o0000ooooooooool01Oooool2o`00073ooooo0_l0000Pooooo`;o0000Jooo
ool2o`0001Wooooo0_l0000Dooooo`;o00001_ooool2o`0000Kooooo000Nooooo`03o`000?oooooo
oooo00Gooooo0_l0000gooooo`;o0000=_ooool3o`00023ooooo0_l0001Mooooo`;o00009oooool2
o`0001Cooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`0nooooo`;o00001Oooool2o`00
02oooooo0_l00020ooooo`;o0000COooool001kooooo00?o0000ooooooooool0AOooool2o`000=;o
oooo0_l0000/ooooo`007_ooool2o`0002Wooooo0_l0003_ooooo`;o00001Oooool2o`0002Gooooo
000Nooooo`03o`000?oooooooooo02Sooooo0_l0000Zooooo`;o0000b_ooool2o`0002Gooooo000N
ooooo`03o`000?oooooooooo027ooooo0_l0000[ooooo`;o00001?ooool2o`0000_ooooo0_l0003T
ooooo`007_ooool00ol0003oooooooooo`0Qooooo`;o0000:oooool2o`00017ooooo0_l0000noooo
o`;o00002?ooool2o`0006gooooo0_l0000[ooooo`007_ooool00ol0003oooooooooo`0eooooo`;o
00007?ooool3o`0001Sooooo0_l0000aooooo`;o00002?ooool2o`0006gooooo0_l0000[ooooo`00
7_ooool00ol0003oooooooooo`0Hooooo`;o00006oooool2o`0001cooooo0ol0000Hooooo`;o0000
1oooool2o`0002Oooooo0_l0002Hooooo`;o00002oooool001kooooo00?o0000ooooooooool06?oo
ool2o`0002_ooooo0_l0000`ooooo`;o00009oooool2o`0009Sooooo0_l0000;ooooo`007_ooool0
0ol0003oooooooooo`15ooooo`;o0000ooooool1ooooo`007_ooool00ol0003oooooooooo`2Ioooo
o`;o0000??ooool2o`0006kooooo000Nooooo`03o`000?oooooooooo00;o0000;oooool2o`0001[o
oooo0_l0000:ooooo`;o0000=oooool2o`0000Gooooo0_l0000looooo`;o0000@Oooool2o`0002_o
oooo000Nooooo`03o`000?oooooooooo00;o0000;oooool2o`0001[ooooo0_l0000:ooooo`;o0000
=oooool2o`0000;ooooo0_l00022ooooo`;o0000:oooool001kooooo00?o0000ooooooooool06ooo
ool2o`0001kooooo0_l0001Iooooo`;o0000M?ooool2o`0003Wooooo000Nooooo`03o`000?oooooo
oooo01_ooooo0_l0000Cooooo`;o00002Oooool2o`000<oooooo0_l0000iooooo`007_ooool00ol0
003oooooooooo`0`ooooo`;o00000_ooool2o`000=Wooooo0_l0000fooooo`007_ooool00ol0003o
ooooooooo`0Booooo`;o00003_ooool2o`0000;ooooo0_l0000<ooooo`;o00009oooool2o`000;3o
oooo0_l0000fooooo`007_ooool00ol0003oooooooooo`0Booooo`;o00003_ooool2o`0000;ooooo
0_l0000eooooo`;o0000j?ooool001kooooo0_l0000=ooooo`;o00001oooool2o`0000Kooooo0_l0
003ooooooagooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o00001oooool2
o`0000Kooooo0_l0003ooooooagooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0coooo
o`;o0000oooooolCooooo`007_ooool00ol0003oooooooooo`06ooooo`;o0000:oooool2o`0004[o
oooo0_l0000Vooooo`;o00000oooool2o`0004Cooooo0_l00014ooooo`;o00003Oooool001kooooo
00?o0000ooooooooool01_ooool2o`0002oooooo0_l00016ooooo`;o00009_ooool2o`0000?ooooo
0_l00014ooooo`;o0000A?ooool2o`0000gooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l0
000>ooooo`;o00009Oooool2o`000>Oooooo000Nooooo`03o`000?oooooooooo01oooooo0_l00006
ooooo`;o0000=Oooool2o`000003ooooool0003o000001Oooooo0_l0003;ooooo`007_ooool00ol0
003oooooooooo`0Eooooo`;o00002?ooool4o`0001gooooo0_l00003ooooo`;o00006_ooool2o`00
01Oooooo0_l0001]ooooo`;o0000G?ooool001kooooo00?o0000ooooooooool05Oooool2o`0000[o
oooo0_l0000Mooooo`;o00000oooool4o`000003ooooool0003o000000oooooo0_l0002<ooooo`;o
0000G?ooool001kooooo00?o0000ooooooooool0??ooool2o`0000Oooooo1?l000000ooooooo0000
o`00000?ooooo`;o0000j_ooool001kooooo00?o0000ooooooooool05?ooool2o`0002Kooooo0_l0
0007ooooo`Co0000o_ooool001kooooo00?o0000ooooooooool01Oooool2o`0000gooooo0_l0000_
ooooo`Co0000??ooool2o`000<3ooooo000Nooooo`04o`000?oooooo0000o`0000Cooooo0_l0000[
ooooo`;o00002?ooool2o`0000Wooooo0_l00008ooooo`;o0000<_ooool2o`0001Wooooo0_l0002U
ooooo`007_ooool01?l0003oooooo`000?l0000=ooooo`;o00008_ooool2o`0000Sooooo0_l00009
ooooo`;o00000_ooool2o`0000Cooooo0_l0001=ooooo`;o0000YOooool001kooooo00?o0000oooo
ooooool03_ooool2o`0003Kooooo0ol00002ooooo`;o00008_ooool2o`000=Kooooo000Nooooo`03
o`000?oooooooooo00;ooooo0_l0000aooooo`;o00003oooool2o`0001[ooooo0_l00003ooooo`;o
00001_ooool2o`0000Kooooo0_l0000kooooo`;o0000TOooool001kooooo0_l00003ooooo`;o0000
1oooool2o`0002Sooooo0_l0000Zooooo`?o00000oooool2o`0000Wooooo0_l00003ooooo`;o0000
8?ooool2o`0001Wooooo0_l0002Aooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o00003?oo
ool2o`0002?ooooo0_l0000=ooooo`;o00004_ooool2o`0000gooooo1?l0000Jooooo`;o00002Ooo
ool2o`000:cooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0000Dooooo`;o00008oooool2
o`000003ooooool0003o000000[ooooo0_l00005ooooo`;o000000?oooooo`000?l000005oooool2
o`0001cooooo1?l00017ooooo`;o0000=_ooool2o`0003Cooooo000Nooooo`03o`000?oooooooooo
00?ooooo0_l0000`ooooo`;o00002_ooool2o`00017ooooo0_l000000ooooooo0000o`00000Foooo
o`;o00007oooool2o`0004Oooooo0_l0000fooooo`;o0000=?ooool001kooooo00?o0000oooooooo
ool04_ooool2o`00027ooooo0_l0000Aooooo`;o00003_ooool2o`0000Kooooo0_l0000=ooooo`;o
00004?ooool2o`000;;ooooo0_l0000@ooooo`007_ooool00ol0003oooooooooo`0Booooo`;o0000
0_ooool2o`00033ooooo0_l0000>ooooo`;o00001_ooool2o`0001oooooo0_l0002booooo`;o0000
4?ooool001kooooo00?o0000ooooooooool05_ooool2o`0005cooooo0_l0003Aooooo`007_ooool0
0ol0003oooooooooo`1dooooo`;o00005_ooool2o`0005Kooooo0_l0000jooooo`;o00004?ooool2
o`0001?ooooo000Nooooo`03o`000?oooooooooo03;ooooo0_l0000Dooooo`;o0000@_ooool2o`00
00Sooooo0_l0001<ooooo`;o0000>_ooool2o`00013ooooo0_l0000Cooooo`007_ooool00ol0003o
ooooooooo`0Tooooo`;o00002?ooool2o`0000;ooooo0_l0000Dooooo`;o0000:oooool2o`0000co
oooo0_l00004ooooo`;o00002oooool2o`00043ooooo0_l0001]ooooo`007_ooool00ol0003ooooo
ooooo`0Tooooo`;o00002?ooool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000
o`00000Rooooo`;o00001Oooool2o`0000oooooo0_l0000<ooooo`;o00001?ooool2o`0000Kooooo
0_l00015ooooo`;o00004oooool2o`0005Sooooo000Nooooo`03o`000?oooooooooo00;o0000;ooo
ool2o`0000;ooooo0ol000000ooooooo0000o`00000Rooooo`;o00001Oooool2o`0002_ooooo0_l0
0008ooooo`;o0000D?ooool2o`0005Sooooo000Nooooo`03o`000?oooooooooo00;o0000:_ooool3
o`0000Kooooo0_l0000=ooooo`;o0000;oooool3o`0000Oooooo0_l0000Jooooo`;o0000EOooool2
o`0005?ooooo000Nooooo`03o`000?oooooooooo02Sooooo0ol000001?oooooo0000o`000?l00009
ooooo`;o00002_ooool2o`0002Wooooo0_l00004ooooo`?o00001oooool2o`00077ooooo0_l00013
ooooo`;o00003_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool0
1Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0:?ooool3o`0000[ooooo0_l0
00000ooooooo0000o`000003ooooo`;o00004oooool2o`0001[ooooo0ol0001Booooo`;o00006ooo
ool2o`0005Gooooo0_l0000>ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`03ooooo`;o0000
6?ooool3o`0000Wooooo0_l0000:ooooo`;o00001_ooool2o`0001?ooooo0_l00005ooooo`;o0000
4oooool2o`0000Cooooo0_l0000booooo`;o00006Oooool2o`0001_ooooo0_l0001Uooooo`000ooo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o
00000oooool2o`0001Sooooo0ol0000:ooooo`;o00001_ooool3o`0000gooooo0ol000001?oooooo
0000o`000?ooool3o`0000gooooo0_l0000Aooooo`;o00001_ooool2o`0000Wooooo0_l0000Woooo
o`;o0000WOooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9Sooooo
oiRHV?lb<S801_ooool00ol0003oooooooooo`0Zooooo`?o00001Oooool3o`0000;ooooo0_l00008
ooooo`Oo000000Coooooo`000?l0003o00003?ooool2o`0001;ooooo0_l0000Aooooo`;o0000SOoo
ool2o`0000Oooooo0_l0000^ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go
c<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo01Kooooo0_l0000Cooooo`;o0000
2_ooool2o`0000Sooooo1ol0000@ooooo`;o00007?ooool2o`0009Kooooo0_l00007ooooo`;o0000
4Oooool2o`0001_ooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zj
oooooonj^[[o410@00Kooooo00?o0000ooooooooool03oooool2o`0000Gooooo0_l0000Aooooo`;o
00002oooool3o`0000Sooooo1?l000001?oooooo0000o`000?l00008ooooo`;o00007_ooool2o`00
00?ooooo0_l00007ooooo`;o0000;Oooool2o`0000_ooooo0_l0000:ooooo`;o0000HOooool2o`00
01_ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o
000000Kooooo00?o0000ooooooooool03oooool2o`0001Sooooo0_l00008ooooo`Go00002?ooool3
o`0000Cooooo0_l00002ooooo`;o00001?ooool3o`0000Wooooo0_l0000Booooo`;o00003?ooool2
o`0002gooooo0_l0000;ooooo`;o00002_ooool2o`0001gooooo0_l0001Oooooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oo
oooooooo02Kooooo0_l0000;ooooo`Go00002?ooool3o`0000?ooooo0ol00002ooooo`?o00001?oo
ool2o`0000Wooooo0_l00008ooooo`Co0000M_ooool2o`0000?ooooo0_l0001Oooooo`007_ooool0
0ol0003oooooooooo`0>ooooo`;o00003Oooool2o`0000Kooooo0ol00002ooooo`;o00002?ooool5
o`0000Kooooo1?l00003ooooo`;o00001?ooool2o`0000;ooooo0_l0000;ooooo`;o00002?ooool4
o`00023ooooo0_l00019ooooo`;o00002Oooool2o`0006Cooooo000Nooooo`?o00003_ooool2o`00
00_ooooo1?l00002ooooo`;o00000_ooool3o`0000;ooooo1?l00006ooooo`Go00001_ooool4o`00
00Wooooo0ol000001?oooooo0000o`000?ooool2o`0000Sooooo0_l00008ooooo`;o00008_ooool2
o`0004Wooooo0_l0001_ooooo`007_ooool3o`0000kooooo0_l0000;ooooo`;o00001?ooool2o`00
00Wooooo0_l0000?ooooo`Ko00001Oooool4o`000003ooooool0003o000000Cooooo1?l0000@oooo
o`;o0000Ioooool2o`0007Gooooo000Nooooo`03o`000?oooooooooo00kooooo0_l0000=ooooo`;o
00000_ooool2o`0001Sooooo1ol00006ooooo`Oo00001?ooool4o`0002Cooooo0_l0000?ooooo`;o
0000@_ooool2o`0002?ooooo0_l0001@ooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o0000
0_ooool2o`0000Gooooo0_l00002ooooo`;o00003Oooool3o`0000;ooooo1?l00004ooooo`Oo0000
4oooool2o`000003ooooool0003o000000kooooo0_l00002ooooo`Co00003_ooool3o`0002Sooooo
0_l0000mooooo`;o0000D?ooool001kooooo00?o0000ooooooooool0:?ooool2o`0000;ooooo0_l0
000<ooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo2Ol00008ooooo`;o00002?oo
ool2o`000003ooooool0003o000000Cooooo0_l00008ooooo`?o000000?oooooo`000?l000004?oo
ool2o`0002Wooooo0_l0001Hooooo`;o00003?ooool2o`0002Oooooo000Nooooo`03o`000?oooooo
oooo03;ooooo0_l00006ooooo`;o000000?oooooo`000?l000000oooool4o`000003ooooool0003o
000000;o000000?oooooo`000?l000000_l00004ooooo`;o00000_ooool2o`0000?ooooo0_l0000<
ooooo`;o00001_ooool2o`000003ooooool0003o000001Cooooo0_l00022ooooo`;o00003?ooool2
o`0002Oooooo000Nooooo`03o`000?oooooooooo02;ooooo0_l00009ooooo`Co000000?oooooo`00
0?l000000oooool2o`0000?ooooo0_l00006ooooo`;o00000oooool7o`0000?ooooo0ol00007oooo
o`?o00004oooool2o`0001Oooooo0_l0000<ooooo`;o0000??ooool2o`0006gooooo000Nooooo`03
o`000?oooooooooo01_ooooo0_l00005ooooo`;o00002Oooool4o`000003ooooool0003o000000?o
oooo0ol00002ooooo`;o00001Oooool3o`0000;ooooo2?l00003ooooo`Co00001oooool2o`000003
ooooool0003o000003Oooooo0_l0000Booooo`;o0000:?ooool2o`0002oooooo0_l0000looooo`00
7_ooool00ol0003oooooooooo`0Jooooo`?o00004Oooool2o`0000;ooooo0ol00003ooooo`;o0000
1_ooool;o`0000Gooooo0_l00003ooooo`;o00001oooool2o`000003ooooool0003o000000_ooooo
0_l0000nooooo`;o0000<?ooool2o`0000kooooo0_l0000Gooooo`;o0000??ooool001kooooo00?o
0000ooooooooool06_ooool2o`0000Kooooo0_l0000:ooooo`So00000oooool2o`0000Gooooo2Ol0
0007ooooo`Co00002?ooool4o`0000kooooo0_l00002ooooo`;o00008oooool2o`0001Sooooo0_l0
00000ooooooo0000o`00000Zooooo`;o00003_ooool2o`0005Gooooo000Nooooo`;o00008oooool2
o`0000Cooooo0ol00004ooooo`Co000000?oooooo`000?l000000oooool2o`0000Gooooo0ol00002
ooooo`Go00002?ooool2o`0000?ooooo0_l00003ooooo`;o00005?ooool4o`00027ooooo0_l0000H
ooooo`;o000000?oooooo`000?l000007_ooool2o`00077ooooo000Nooooo`;o00001?ooool2o`00
00_ooooo0_l00006ooooo`;o00002oooool2o`000004ooooool0003o0000o`0000Cooooo0_l00002
ooooo`?o00002_ooool4o`000003ooooool0003o000000?o00002?ooool2o`000003ooooool0003o
000000;o00006oooool2o`0000;ooooo0_l0001Jooooo`;o0000LOooool001kooooo0_l00004oooo
o`;o00002oooool2o`0000Kooooo0_l0000;ooooo`;o00001Oooool2o`0000Gooooo0ol0000;oooo
o`?o00000_ooool3o`0000cooooo0_l0000Fooooo`;o00002Oooool2o`0001gooooo0_l0000Goooo
o`;o0000UOooool001kooooo00?o0000ooooooooool06_ooool2o`0000cooooo0_l00002ooooo`;o
00002?ooool2o`0000Gooooo0_l00007ooooo`;o000000?oooooo`000?l000001?l000001?oooooo
0000o`000?ooool2o`000003ooooool0003o000000Kooooo0_l0000:ooooo`;o000000?oooooo`00
0?l00000:?ooool2o`0001Oooooo0_l0001Xooooo`;o0000:oooool001kooooo00?o0000oooooooo
ool06_ooool2o`0000cooooo0_l0000<ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?o
oooo0ol000001?oooooo0000o`000?ooool6o`000004ooooool0003o0000ooooo`;o000000?ooooo
o`000?l000000_ooool2o`0000;ooooo0_l00009ooooo`?o0000:?ooool2o`0008Cooooo0_l00004
ooooo`;o00009Oooool001kooooo00?o0000ooooooooool0>Oooool2o`0000Oooooo3_l000000ooo
oooo0000o`000002o`000003ooooool0003o000000;ooooo0_l0000;ooooo`Co00001?ooool2o`00
02?ooooo0_l0000aooooo`;o0000Eoooool2o`0001Cooooo0_l0000?ooooo`007_ooool00ol0003o
ooooooooo`0`ooooo`;o00001?ooool2o`0000?ooooo0_l00006ooooo`Wo000000Goooooo`000?l0
003o0000ooooo`05o`000003ooooool0003o000000Kooooo0ol00005ooooo`;o00000_ooool2o`00
00;ooooo0_l0000?ooooo`;o00005?ooool2o`0002oooooo0_l0001]ooooo`;o00003oooool001ko
oooo00?o0000ooooooooool0<?ooool2o`0000?ooooo0ol00003ooooo`;o00001_ooool4o`0000Go
oooo1Ol000000ooooooo0000o`000002o`000003ooooool0003o000000Cooooo1Ol00005ooooo`;o
00000_ooool2o`0000;ooooo0_l0000?ooooo`;o00003_ooool2o`0000Cooooo0_l0000Booooo`;o
0000J_ooool2o`0002oooooo000Nooooo`03o`000?oooooooooo03Gooooo0_l0000<ooooo`Co0000
1Oooool2o`000004ooooool0003o0000ooooo`;o00000_ooool4o`0000?ooooo1?l00008ooooo`;o
00001?ooool2o`0001oooooo0_l0000Hooooo`;o0000J_ooool2o`0002oooooo000Nooooo`03o`00
0?oooooooooo02;ooooo0_l0000?ooooo`;o00001oooool2o`0000Oooooo1?l00009ooooo`So0000
0oooool4o`0000Sooooo0_l00003ooooo`Co0000^Oooool2o`0001[ooooo000Nooooo`03o`000?oo
oooooooo02;ooooo0_l0000=ooooo`Co00001oooool2o`0000Wooooo0_l00003ooooo`?o00001?oo
ool3o`0001Sooooo1?l0000Sooooo`;o00003_ooool2o`0008Cooooo0_l0000Jooooo`007_ooool0
0ol0003oooooooooo`0aooooo`?o00001oooool3o`0000kooooo0ol00002ooooo`Co00000_ooool3
o`0000;ooooo0_l0000@ooooo`?o00002?ooool2o`0001[ooooo0ol00002ooooo`;o00002Oooool2
o`0007Wooooo0_l0000Uooooo`007_ooool00ol0003oooooooooo`05ooooo`;o00008_ooool2o`00
0003ooooool0003o000000Cooooo0_l00007ooooo`?o000000?oooooo`000?l000002oooool4o`00
0004ooooool0003o0000o`0000?ooooo0ol000001?oooooo0000o`000?l0000<ooooo`;o00000_oo
ool3o`0000Sooooo0_l00002ooooo`;o00004oooool2o`0000;ooooo0_l00002ooooo`;o0000Q?oo
ool2o`0002Gooooo000Nooooo`03o`000?oooooooooo00Gooooo0_l0000Looooo`;o00001?ooool7
o`0000Oooooo0_l00006ooooo`;o00002?ooool7o`000004ooooool0003o0000o`0000;ooooo1ol0
00001?oooooo0000o`000?l00003ooooo`;o00001?ooool2o`00017ooooo0_l0000>ooooo`;o0000
0oooool2o`0000;ooooo0_l0002_ooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o00001_oo
ool7o`0000Gooooo0_l00004ooooo`;o00002_ooool6o`0000;ooooo0_l000000ooooooo0000o`00
0002o`000003ooooool0003o000000;ooooo1?l00002ooooo`?o00001?ooool2o`00027ooooo0_l0
001Sooooo`;o0000Doooool001kooooo00?o0000ooooooooool0;Oooool2o`000003ooooool0003o
000000_ooooo0_l0000>ooooo`;o00001Oooool2o`0000?ooooo0ol000000ooooooo0000o`000002
o`0000;ooooo0_l00005ooooo`;o0000Q_ooool2o`0005?ooooo000Nooooo`;o0000:_ooool4o`00
00?ooooo0_l0000<ooooo`;o00000oooool2o`0000oooooo0_l00002ooooo`Ko000000?oooooo`00
0?l000000_ooool3o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000009oooool2
o`0003Oooooo0_l0001Oooooo`;o00005Oooool001kooooo00?o0000ooooooooool04oooool2o`00
00kooooo0_l00004ooooo`Co00000oooool2o`0000Kooooo0_l00004ooooo`;o00000oooool2o`00
01?ooooo1_l000000ooooooo0000o`000002o`000004ooooool0003o0000ooooo`;o000000?ooooo
o`000?l000000ol000000ooooooo0000o`00000Tooooo`;o00007_ooool2o`0001Oooooo0_l0001O
ooooo`;o00005Oooool001kooooo00?o0000ooooooooool04oooool2o`0000kooooo0_l0000Coooo
o`;o00002oooool2o`0001Wooooo1Ol00006ooooo`;o00000oooool4o`0001Kooooo0_l00002oooo
o`;o00009_ooool2o`0008oooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0000Nooooo`;o
00004oooool2o`0000Gooooo0_l0000Fooooo`;o000000?oooooo`000?l000000ol0000;ooooo`Go
00001?ooool2o`0000oooooo0_l00002ooooo`;o0000Voooool2o`0001[ooooo000Nooooo`;o0000
2_ooool2o`0001kooooo0_l0000>ooooo`;o000000?oooooo`000?l000000_l0000Mooooo`;o0000
3_ooool3o`0000?ooooo0_l00004ooooo`;o00002?ooool2o`0005_ooooo0_l00018ooooo`?o0000
6_ooool001kooooo0_l0000dooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`;o0000
7Oooool2o`0000Wooooo0ol000001?oooooo0000o`000?l00005ooooo`Co00002_ooool2o`0005Ko
oooo0_l00003ooooo`;o0000B?ooool2o`0001_ooooo000Nooooo`03o`000?oooooooooo01Gooooo
0_l0000Jooooo`Co00002Oooool3o`0001Kooooo0_l000000ooooooo0000o`000002ooooo`Co0000
1oooool3o`0000;ooooo0_l00002ooooo`Oo00005Oooool2o`0004_ooooo0_l0000Dooooo`;o0000
3Oooool2o`0004Gooooo000Nooooo`03o`000?oooooooooo01Gooooo0_l0000Iooooo`?o00002ooo
ool2o`0000;ooooo0_l0000Cooooo`;o000000Coooooo`000?l0003o00000oooool2o`0000Sooooo
0_l000001Ooooooo0000o`000?l0003ooooo00Ko00002_ooool2o`0000?ooooo0_l00006ooooo`;o
0000HOooool2o`0000gooooo0_l00015ooooo`007_ooool00ol0003oooooooooo`0`ooooo`?o0000
1_ooool2o`0000Oooooo0_l0000Gooooo`;o00000oooool2o`0000_ooooo0_l00002ooooo`Ko0000
2_ooool2o`0000?ooooo0_l00008ooooo`;o00003?ooool2o`0000gooooo0_l0001Jooooo`;o0000
??ooool001kooooo00?o0000ooooooooool01?ooool2o`0002gooooo0_l00002ooooo`Co00001_oo
ool2o`0000Gooooo0_l00007ooooo`;o00001Oooool2o`0001_ooooo0_l0000?ooooo`;o00002?oo
ool2o`0000cooooo0_l0000=ooooo`;o0000F_ooool2o`00013ooooo0_l00006ooooo`;o00005ooo
ool2o`0000Wooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0000<ooooo`;o00007oooool3
o`000003ooooool0003o000000;o00001_ooool2o`0000Cooooo0ol00004ooooo`;o000000?ooooo
o`000?l000001Oooool3o`0000[ooooo0_l0000>ooooo`;o0000Y?ooool2o`0000Kooooo0_l0000G
ooooo`;o00002Oooool001kooooo00?o0000ooooooooool04Oooool3o`00023ooooo0_l000000ooo
oooo0000o`000003o`0000_ooooo0_l000000ooooooo0000o`000002ooooo`?o00000oooool2o`00
00?ooooo0_l0000:ooooo`;o0000h?ooool001kooooo00?o0000ooooooooool04Oooool2o`0002Co
oooo1ol00002ooooo`;o00002?ooool2o`0000?ooooo0_l00003ooooo`;o00007Oooool2o`000=;o
oooo000Nooooo`03o`000?oooooooooo02Cooooo0_l0000Aooooo`Co000000?oooooo`000?l00000
0_ooool2o`00037ooooo0_l0003Booooo`007_ooool00ol0003oooooooooo`04o`00023ooooo0_l0
000Fooooo`;o00004?ooool2o`0004Sooooo0_l0002]ooooo`007_ooool00ol0003oooooooooo`04
o`0004Cooooo0_l00004ooooo`;o00003?ooool2o`0000?ooooo0_l000000ooooooo0000o`00000b
ooooo`;o0000[Oooool001kooooo0_l0000^ooooo`;o00006Oooool2o`0001;ooooo0_l00003oooo
o`;o000000?oooooo`000?l000000_ooool2o`0000Kooooo0_l0001aooooo`;o0000H_ooool001ko
oooo00?o0000ooooooooool03?ooool2o`000003ooooool0003o000001cooooo0_l0000booooo`;o
00001Oooool2o`0000Kooooo0_l0001aooooo`;o0000H_ooool001kooooo00?o0000ooooooooool0
3?ooool2o`000003ooooool0003o000003Oooooo0_l00008ooooo`;o00003Oooool2o`000>Cooooo
000Nooooo`03o`000?oooooooooo00[ooooo0_l0000looooo`;o00002?ooool2o`000003ooooool0
003o000001[ooooo0_l0000:ooooo`;o0000b?ooool001kooooo00?o0000ooooooooool02_ooool2
o`0004Wooooo0_l0000Dooooo`;o00001?ooool2o`0000[ooooo0_l000000ooooooo0000o`000004
ooooo`;o0000_oooool001kooooo00?o0000ooooooooool0A?ooool2o`00013ooooo0_l0000Coooo
o`?o00004_ooool2o`0000Cooooo0_l0002oooooo`007_ooool00ol0003oooooooooo`0Yooooo`;o
00006Oooool2o`00013ooooo0_l0000Dooooo`;o0000Coooool2o`0008Sooooo000Nooooo`03o`00
0?oooooooooo02Wooooo0_l0000jooooo`;o00000oooool2o`00057ooooo0_l00028ooooo`007_oo
ool00ol0003oooooooooo`1Eooooo`;o00003_ooool2o`0000?ooooo0_l0001Iooooo`;o0000H?oo
ool2o`0000Wooooo0_l0000Cooooo`007_ooool00ol0003oooooooooo`18ooooo`;o00001?ooool2
o`0000Gooooo0_l0000Cooooo`Co00001Oooool2o`000003ooooool0003o000001?ooooo0_l0000h
ooooo`;o0000H?ooool2o`0000Wooooo0_l0000Cooooo`007_ooool00ol0003oooooooooo`18oooo
o`;o00001?ooool2o`0000[ooooo0_l00004ooooo`?o00002Oooool2o`0000Gooooo0_l000000ooo
oooo0000o`00000?ooooo`;o00000_ooool2o`000;[ooooo000Nooooo`03o`000?oooooooooo03;o
oooo0_l0000Vooooo`;o00001?ooool3o`0002Cooooo0_l0000Fooooo`;o0000Y_ooool001kooooo
00?o0000ooooooooool07_ooool2o`0001;ooooo0_l0000Mooooo`;o00000oooool2o`0000Gooooo
1?l0000Uooooo`;o00005oooool2o`000:Kooooo000Nooooo`03o`000?oooooooooo01kooooo0_l0
000aooooo`;o00000oooool2o`0000Gooooo1?l0000Uooooo`;o00004oooool2o`0000_ooooo0_l0
002Mooooo`005?ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0;?ooool2
o`0002?ooooo0_l0000>ooooo`?o000000?oooooo`000?l00000=?ooool2o`0000_ooooo0_l0002M
ooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02cooooo0_l00005oooo
o`;o00006?ooool2o`0001;ooooo0ol000000ooooooo0000o`00000[ooooo`;o0000/oooool001Ko
oooo00?o0000ooooooooool01Oooool3o`0003?ooooo0_l0000Hooooo`;o0000@oooool2o`000;?o
oooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooo
oom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo
0?ooooooD?ooool001Cooooo00?oEEEEofIVI_l00000oooooomBooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.24896 .86678 Mdot
.38856 .11058 Mdot
.35573 .88805 Mdot
.28336 .83162 Mdot
.22267 .77928 Mdot
.28476 .85906 Mdot
.51444 .77744 Mdot
.19899 .81503 Mdot
.21651 .86237 Mdot
.23598 .58263 Mdot
.25225 .70603 Mdot
.34743 .73761 Mdot
.28518 .87198 Mdot
.5918 .85809 Mdot
.27051 .89402 Mdot
.17639 .24519 Mdot
.12019 .44963 Mdot
.35322 .91751 Mdot
.27673 .87809 Mdot
.24377 .83264 Mdot
.69714 .90222 Mdot
.21261 .92523 Mdot
.28123 .97585 Mdot
.25323 .70091 Mdot
.19844 .83161 Mdot
.15934 .82522 Mdot
.23247 .90331 Mdot
.19876 .10232 Mdot
.27598 .70339 Mdot
.26221 .95015 Mdot
.37893 .89748 Mdot
.2685 .88303 Mdot
.11776 .89162 Mdot
.1227 .50646 Mdot
.36451 .792 Mdot
.2311 .72782 Mdot
.55758 .85144 Mdot
.12594 .75954 Mdot
.37385 .79109 Mdot
.22968 .85153 Mdot
.36961 .90787 Mdot
.45339 .78502 Mdot
.25404 .92486 Mdot
.82303 .71391 Mdot
.51637 .89543 Mdot
.47824 .7803 Mdot
.52928 .90307 Mdot
.31767 .15184 Mdot
.21321 .75058 Mdot
.32355 .77428 Mdot
.4277 .96669 Mdot
.44112 .99109 Mdot
.20701 .80929 Mdot
.22741 .71142 Mdot
.2512 .84563 Mdot
.1304 .5339 Mdot
.70549 .82978 Mdot
.24482 .83219 Mdot
.23295 .90737 Mdot
.02526 .80025 Mdot
.3124 .874 Mdot
.17658 .82409 Mdot
.28509 .72873 Mdot
.16825 .8188 Mdot
.30071 .7953 Mdot
.24239 .87233 Mdot
.49248 .93907 Mdot
.23101 .90499 Mdot
.28817 .86976 Mdot
.96918 .91428 Mdot
.44201 .78127 Mdot
.15003 .64327 Mdot
.1734 .92592 Mdot
.26508 .57442 Mdot
.21879 .80864 Mdot
.71861 .87043 Mdot
.24026 .04046 Mdot
.45571 .45864 Mdot
.25359 .89669 Mdot
.02155 .82219 Mdot
.37805 .04119 Mdot
.58757 .46015 Mdot
.81351 .30145 Mdot
.19105 .82246 Mdot
.56638 .69094 Mdot
.65091 .83369 Mdot
.18974 .78518 Mdot
.25533 .87685 Mdot
.28 .87833 Mdot
.01819 .72968 Mdot
.12244 .78076 Mdot
.64154 .88827 Mdot
.24099 .63562 Mdot
.93954 .63992 Mdot
.1658 .89198 Mdot
.33566 .05614 Mdot
.85962 .77719 Mdot
.42853 .89787 Mdot
.14907 .7661 Mdot
.99708 .69897 Mdot
.20583 .88058 Mdot
.4493 .01121 Mdot
.08714 .92094 Mdot
.3989 .06113 Mdot
.47061 .02091 Mdot
.26967 .96768 Mdot
.2049 .14992 Mdot
.1954 .21989 Mdot
.38184 .03028 Mdot
.85376 .69853 Mdot
.56264 .90583 Mdot
.75852 .48407 Mdot
.16861 .06282 Mdot
.36814 .89527 Mdot
.45443 .93575 Mdot
.46993 .80578 Mdot
.59512 .89128 Mdot
.28735 .90043 Mdot
.22465 .55483 Mdot
.12591 .0012 Mdot
.22132 .88909 Mdot
.35988 .09948 Mdot
.17314 .9301 Mdot
.97201 .59754 Mdot
.53773 .97071 Mdot
.94566 .08447 Mdot
.41757 .85183 Mdot
.26552 .88388 Mdot
.10903 .51244 Mdot
.05516 .06167 Mdot
.54183 .04975 Mdot
.43529 .54442 Mdot
.38193 .18265 Mdot
.28888 .99666 Mdot
.35921 .94004 Mdot
.38854 .93209 Mdot
.27164 .96019 Mdot
.23916 .78325 Mdot
.37762 .85631 Mdot
.2622 .85973 Mdot
.29283 .8933 Mdot
.15164 .80412 Mdot
.1711 .92581 Mdot
.99119 .63293 Mdot
.22188 .97342 Mdot
.34972 .71459 Mdot
.20284 .92852 Mdot
.22152 .88582 Mdot
.78547 .04121 Mdot
.70538 .46488 Mdot
.08153 .82199 Mdot
.14225 .92675 Mdot
.34588 .75564 Mdot
.23681 .83501 Mdot
.25928 .90253 Mdot
.23778 .86973 Mdot
.24361 .80424 Mdot
.63227 .34747 Mdot
.2405 .86385 Mdot
.14191 .23714 Mdot
.24765 .80455 Mdot
.20132 .64655 Mdot
.47265 .68484 Mdot
.2539 .01676 Mdot
.15992 .75604 Mdot
.21262 .80646 Mdot
.22697 .8752 Mdot
.25775 .88201 Mdot
.25285 .54367 Mdot
.25368 .93002 Mdot
.16816 .95706 Mdot
.2637 .86721 Mdot
.32437 .72037 Mdot
.55689 .86793 Mdot
.19855 .85179 Mdot
.30378 .68506 Mdot
.04103 .78344 Mdot
.19421 .8217 Mdot
.40141 .03211 Mdot
.44549 .96802 Mdot
.18544 .85763 Mdot
.26849 .72027 Mdot
.23182 .76641 Mdot
.5971 .85973 Mdot
.21265 .34068 Mdot
.35753 .06477 Mdot
.13933 .21968 Mdot
.10094 .79119 Mdot
.03277 .5868 Mdot
.98447 .74416 Mdot
.22312 .8651 Mdot
.6383 .80199 Mdot
.26395 .88199 Mdot
.35604 .8947 Mdot
.15349 .97337 Mdot
.18154 .8819 Mdot
.18687 .62633 Mdot
.31554 .78986 Mdot
.2043 .86158 Mdot
.16211 .88082 Mdot
.16569 .75172 Mdot
.56029 .26181 Mdot
.31635 .99082 Mdot
.5652 .93025 Mdot
.19318 .82969 Mdot
.25953 .8712 Mdot
.88377 .0944 Mdot
.24751 .90922 Mdot
.89054 .66187 Mdot
.22896 .69351 Mdot
.23785 .87756 Mdot
.26281 .89277 Mdot
.57517 .633 Mdot
.43961 .47251 Mdot
.24518 .79937 Mdot
.2531 .24275 Mdot
.23948 .85645 Mdot
.14582 .81399 Mdot
.21144 .98389 Mdot
.50908 .80711 Mdot
.92938 .08642 Mdot
.12005 .81996 Mdot
.13215 .78465 Mdot
.26807 .88052 Mdot
.99747 .72217 Mdot
.22031 .64747 Mdot
.0534 .01463 Mdot
.33111 .96792 Mdot
.13199 .17034 Mdot
.18903 .91255 Mdot
.19067 .85486 Mdot
.01694 .77429 Mdot
.15795 .93634 Mdot
.43725 .6579 Mdot
.26862 .30966 Mdot
.94774 .62156 Mdot
.78958 .23614 Mdot
.35611 .90437 Mdot
.72142 .74917 Mdot
.81445 .97674 Mdot
.31567 .80252 Mdot
.16682 .93965 Mdot
.39789 .08043 Mdot
.22082 .94821 Mdot
.37275 .78619 Mdot
.17436 .00206 Mdot
.10666 .69645 Mdot
.18492 .9577 Mdot
.71333 .27371 Mdot
.36636 .92248 Mdot
.432 .99273 Mdot
.24546 .86801 Mdot
.61567 .34134 Mdot
.25167 .11434 Mdot
.12925 .14512 Mdot
.26065 .14901 Mdot
.19814 .80389 Mdot
.72155 .9001 Mdot
.44734 .98365 Mdot
.74844 .80138 Mdot
.25318 .88456 Mdot
.3261 .90388 Mdot
.20287 .98451 Mdot
.00748 .70637 Mdot
.16125 .93579 Mdot
.9586 .84515 Mdot
.28715 .09422 Mdot
.60927 .00094 Mdot
.3348 .91108 Mdot
.22974 .88202 Mdot
.15079 .76434 Mdot
.58746 .91764 Mdot
.31005 .90579 Mdot
.30849 .92628 Mdot
.37799 .98658 Mdot
.25352 .89828 Mdot
.24098 .0284 Mdot
.43433 .51361 Mdot
.22651 .70913 Mdot
.39672 .04099 Mdot
.641 .77423 Mdot
.20257 .93766 Mdot
.24392 .03066 Mdot
.53739 .70552 Mdot
.20554 .7921 Mdot
.13633 .78771 Mdot
.27586 .93455 Mdot
.9433 .79849 Mdot
.22786 .08715 Mdot
.3249 .01356 Mdot
.32729 .08639 Mdot
.83254 .63835 Mdot
.30064 .88702 Mdot
.0693 .97254 Mdot
.03196 .97263 Mdot
.98185 .70138 Mdot
.28944 .82208 Mdot
.16824 .12942 Mdot
.61186 .90069 Mdot
.04618 .343 Mdot
.92869 .8677 Mdot
.11884 .80884 Mdot
.26736 .67497 Mdot
.14501 .57866 Mdot
.91001 .24197 Mdot
.29639 .00556 Mdot
.23694 .90134 Mdot
.25087 .91053 Mdot
.56532 .58481 Mdot
.53387 .23006 Mdot
.23461 .90142 Mdot
.66494 .05827 Mdot
.15862 .83254 Mdot
.09414 .77041 Mdot
.21142 .76483 Mdot
.17113 .90302 Mdot
.33385 .64508 Mdot
.01062 .0121 Mdot
.09582 .84414 Mdot
.97464 .40739 Mdot
.36497 .83101 Mdot
.13356 .90606 Mdot
.40051 .07659 Mdot
.24949 .66418 Mdot
.38238 .89872 Mdot
.20349 .86009 Mdot
.22618 .71133 Mdot
.24896 .8952 Mdot
.34442 .76379 Mdot
.17759 .84543 Mdot
.1893 .81973 Mdot
.28761 .85746 Mdot
.32512 .29288 Mdot
.82898 .97973 Mdot
.3481 .57943 Mdot
.27483 .80025 Mdot
.66302 .711 Mdot
.22322 .89675 Mdot
.17248 .30065 Mdot
.39438 .87656 Mdot
.15397 .75761 Mdot
.43365 .48757 Mdot
.28136 .90056 Mdot
.14437 .60932 Mdot
.94638 .57572 Mdot
.1163 .22021 Mdot
.84117 .73211 Mdot
.14457 .43894 Mdot
.46751 .12701 Mdot
.20463 .8084 Mdot
.30858 .9104 Mdot
.21722 .82486 Mdot
.13762 .70352 Mdot
.28002 .24585 Mdot
.83029 .18528 Mdot
.31156 .89543 Mdot
.44954 .80456 Mdot
.25252 .02887 Mdot
.28785 .85341 Mdot
.09474 .82167 Mdot
.1905 .9458 Mdot
.2635 .84771 Mdot
.37368 .89908 Mdot
.24056 .89143 Mdot
.11673 .79308 Mdot
.41369 .93176 Mdot
.38877 .05928 Mdot
.00843 .47466 Mdot
.40709 .44031 Mdot
.2796 .91989 Mdot
.25887 .83439 Mdot
.24485 .89577 Mdot
.34763 .91537 Mdot
.22125 .87953 Mdot
.85621 .87112 Mdot
.01914 .80061 Mdot
.45386 .86417 Mdot
.22824 .78072 Mdot
.72848 .2383 Mdot
.22087 .9581 Mdot
.26021 .88929 Mdot
.20573 .80083 Mdot
.27838 .24506 Mdot
.62765 .14063 Mdot
.20107 .8978 Mdot
.39903 .92466 Mdot
.22656 .11831 Mdot
.83263 .90337 Mdot
.22754 .89746 Mdot
.194 .88514 Mdot
.29182 .89425 Mdot
.27705 .82631 Mdot
.22993 .88067 Mdot
.24131 .78556 Mdot
.23338 .77767 Mdot
.04427 .61303 Mdot
.1522 .49521 Mdot
.26235 .74663 Mdot
.23206 .91025 Mdot
.37826 .89222 Mdot
.28224 .90037 Mdot
.50382 .97214 Mdot
.5148 .74529 Mdot
.18058 .82417 Mdot
.32746 .55778 Mdot
.07523 .99319 Mdot
.33515 .05583 Mdot
.07923 .6899 Mdot
.22834 .59465 Mdot
.25236 .01587 Mdot
.23111 .77337 Mdot
.23234 .86386 Mdot
.24386 .79528 Mdot
.98252 .75403 Mdot
.46646 .017 Mdot
.30801 .93773 Mdot
.04788 .96532 Mdot
.21885 .65626 Mdot
.13132 .24485 Mdot
.25125 .90124 Mdot
.24135 .87924 Mdot
.72332 .21857 Mdot
.95769 .6036 Mdot
.28618 .85891 Mdot
.22418 .82949 Mdot
.44681 .57161 Mdot
.24995 .78744 Mdot
.20891 .88001 Mdot
.15515 .6502 Mdot
.8258 .6176 Mdot
.25129 .56408 Mdot
.65075 .03597 Mdot
.49666 .68509 Mdot
.18642 .81138 Mdot
.47113 .21006 Mdot
.33169 .20426 Mdot
.22148 .95392 Mdot
.02617 .13943 Mdot
.19648 .01981 Mdot
.48918 .85973 Mdot
.25881 .10002 Mdot
.72123 .94455 Mdot
.6642 .92834 Mdot
.30786 .89285 Mdot
.14693 .57481 Mdot
.27195 .90717 Mdot
.12302 .88002 Mdot
.24739 .81664 Mdot
.34248 .90392 Mdot
.2665 .01996 Mdot
.04944 .98488 Mdot
.37333 .02364 Mdot
.15222 .76352 Mdot
.26369 .88676 Mdot
.15658 .96457 Mdot
.23454 .90604 Mdot
.20936 .84884 Mdot
.22769 .70741 Mdot
.09453 .54065 Mdot
.15005 .25752 Mdot
.31142 .7862 Mdot
.26009 .89402 Mdot
.26726 .87955 Mdot
.27764 .83941 Mdot
.48052 .6886 Mdot
.4301 .87681 Mdot
.12371 .89504 Mdot
.68477 .16416 Mdot
.29396 .90432 Mdot
.34159 .90446 Mdot
.26818 .93111 Mdot
.18345 .79642 Mdot
.19179 .819 Mdot
.1917 .82073 Mdot
.34747 .81467 Mdot
.26232 .88457 Mdot
.31108 .81646 Mdot
.21028 .83121 Mdot
.9504 .63511 Mdot
.25195 .84096 Mdot
.40177 .24623 Mdot
.25866 .8886 Mdot
.18016 .93526 Mdot
.31104 .89808 Mdot
.2449 .87272 Mdot
.68413 .00179 Mdot
.49314 .21109 Mdot
.20147 .26379 Mdot
.20818 .83497 Mdot
.22676 .11513 Mdot
.34657 .92414 Mdot
.25064 .8758 Mdot
.20291 .58164 Mdot
.26203 .15159 Mdot
.15257 .79212 Mdot
.30965 .8045 Mdot
.08772 .93174 Mdot
.13761 .83118 Mdot
.73454 .71062 Mdot
.29413 .64038 Mdot
.10705 .9879 Mdot
.12716 .09787 Mdot
.23741 .82296 Mdot
.18378 .45375 Mdot
.31698 .91764 Mdot
.39276 .72177 Mdot
.17594 .80735 Mdot
.856 .95971 Mdot
.21623 .8537 Mdot
.27295 .93385 Mdot
.3481 .91898 Mdot
.03576 .33377 Mdot
.23698 .49657 Mdot
.29341 .12985 Mdot
.21397 .77798 Mdot
.77756 .64566 Mdot
.21885 .85874 Mdot
.32601 .05042 Mdot
.32638 .77855 Mdot
.37789 .89358 Mdot
.26802 .02009 Mdot
.3311 .82384 Mdot
.25738 .89273 Mdot
.1769 .89774 Mdot
.99017 .67269 Mdot
.11819 .88974 Mdot
.08325 .56894 Mdot
.41155 .92002 Mdot
.09114 .70854 Mdot
.07245 .60434 Mdot
.75276 .4497 Mdot
.33986 .86742 Mdot
.20944 .78477 Mdot
.41291 .84165 Mdot
.19249 .82769 Mdot
.20428 .88852 Mdot
.29396 .78886 Mdot
.1168 .84169 Mdot
.96909 .81559 Mdot
.03033 .8529 Mdot
.26436 .859 Mdot
.53957 .05659 Mdot
.32807 .71666 Mdot
.2585 .89418 Mdot
.36558 .87662 Mdot
.86828 .71167 Mdot
.25591 .83661 Mdot
.32263 .94669 Mdot
.25019 .00801 Mdot
.20341 .85829 Mdot
.9561 .84493 Mdot
.23782 .69867 Mdot
.11848 .87421 Mdot
.32263 .50497 Mdot
.3998 .0973 Mdot
.69648 .36666 Mdot
.1799 .24985 Mdot
.21778 .89468 Mdot
.21651 .72675 Mdot
.37943 .89067 Mdot
.24809 5e-05 Mdot
.12418 .82019 Mdot
.11721 .78548 Mdot
.07537 .66809 Mdot
.28656 .92761 Mdot
.21836 .72645 Mdot
.24127 .76561 Mdot
.1385 .77542 Mdot
.53151 .52018 Mdot
.28078 .87441 Mdot
.13122 .14096 Mdot
.35312 .09331 Mdot
.26613 .87843 Mdot
.22578 .91503 Mdot
.28668 .83426 Mdot
.17642 .89623 Mdot
.07332 .15767 Mdot
.27357 .70599 Mdot
.25942 .88313 Mdot
.16865 .952 Mdot
.86242 .82251 Mdot
.42728 .97529 Mdot
.32885 .8026 Mdot
.32321 .89466 Mdot
.36366 .79993 Mdot
.24989 .80824 Mdot
.31553 .0864 Mdot
.51512 .58132 Mdot
.31304 .0535 Mdot
.15109 .90733 Mdot
.21833 .83322 Mdot
.26995 .83234 Mdot
.18643 .59487 Mdot
.13652 .87045 Mdot
.38662 .72579 Mdot
.15993 .83975 Mdot
.25199 .80148 Mdot
.19582 .85191 Mdot
.24034 .77046 Mdot
.23756 .93861 Mdot
.16428 .91386 Mdot
.24887 .88741 Mdot
.34605 .92456 Mdot
.42556 .88737 Mdot
.10296 .66739 Mdot
.24632 .02459 Mdot
.22627 .88439 Mdot
.21771 .94659 Mdot
.86354 .6763 Mdot
.25099 .87662 Mdot
.24631 .71351 Mdot
.5645 .15052 Mdot
.302 .90587 Mdot
.85781 .74579 Mdot
.2653 .86895 Mdot
.15373 .24087 Mdot
.16419 .66702 Mdot
.85166 .04108 Mdot
.14201 .78522 Mdot
.48121 .00614 Mdot
.34112 .51469 Mdot
.10021 .17221 Mdot
.25032 .87729 Mdot
.45065 .17849 Mdot
.41501 .85466 Mdot
.2164 .09704 Mdot
.07887 .66911 Mdot
.67505 .52978 Mdot
.30111 .91272 Mdot
.50831 .87373 Mdot
.38075 .82687 Mdot
.26298 .87983 Mdot
.09621 .87194 Mdot
.48746 .79809 Mdot
.26837 .87519 Mdot
.9688 .43015 Mdot
.1937 .82231 Mdot
.17064 .57177 Mdot
.25946 .80237 Mdot
.27856 .89244 Mdot
.40475 .86021 Mdot
.28201 .86673 Mdot
.47052 .81089 Mdot
.52195 .83091 Mdot
.11793 .50534 Mdot
.29026 .97411 Mdot
.44189 .85696 Mdot
.87582 .62685 Mdot
.18627 .83354 Mdot
.92103 .67121 Mdot
.30234 .62489 Mdot
.19496 .75761 Mdot
.08942 .02663 Mdot
.2715 .87767 Mdot
.15549 .72972 Mdot
.22932 .853 Mdot
.23148 .80836 Mdot
.54035 .88267 Mdot
.89091 .66303 Mdot
.2329 .90951 Mdot
.45785 .85419 Mdot
.25073 .99049 Mdot
.71069 .02277 Mdot
.21391 .85856 Mdot
.4179 .67958 Mdot
.14878 .77117 Mdot
.25006 .90651 Mdot
.87723 .88865 Mdot
.00144 .70344 Mdot
.12921 .07303 Mdot
.92999 .60426 Mdot
.49331 .57388 Mdot
.49304 .84504 Mdot
.20926 .94599 Mdot
.65162 .58423 Mdot
.16399 .82788 Mdot
.7557 .96502 Mdot
.28275 .84147 Mdot
.82389 .82452 Mdot
.72541 .87191 Mdot
.9485 .50439 Mdot
.99407 .66266 Mdot
.49954 .27343 Mdot
.25671 .87815 Mdot
.27975 .87388 Mdot
.25938 .68693 Mdot
.50459 .89713 Mdot
.67537 .9457 Mdot
.02609 .95432 Mdot
.34751 .88276 Mdot
.28512 .14452 Mdot
.56445 .94187 Mdot
.15879 .68822 Mdot
.23803 .12941 Mdot
.14059 .91998 Mdot
.24519 .00413 Mdot
.26834 .88038 Mdot
.27983 .97828 Mdot
.46572 .94206 Mdot
.62438 .75144 Mdot
.15729 .57204 Mdot
.32234 .25241 Mdot
.25219 .87934 Mdot
.36623 .8598 Mdot
.41317 .12163 Mdot
.16271 .91858 Mdot
.19513 .75316 Mdot
.45405 .65341 Mdot
.30145 .94597 Mdot
.17345 .86572 Mdot
.88806 .05888 Mdot
.11292 .68822 Mdot
.52094 .04853 Mdot
.74335 .44784 Mdot
.31429 .96245 Mdot
.86188 .78454 Mdot
.18552 .94788 Mdot
.2286 .78473 Mdot
.50388 .37397 Mdot
.1684 .95252 Mdot
.25512 .89714 Mdot
.41007 .75974 Mdot
.27574 .0205 Mdot
.90178 .79904 Mdot
.50645 .1613 Mdot
.76703 .01829 Mdot
.64045 .9561 Mdot
.21383 .87931 Mdot
.44751 .85926 Mdot
.86844 .61071 Mdot
.19294 .92529 Mdot
.18879 .95459 Mdot
.2561 .88518 Mdot
.24699 .86322 Mdot
.23501 .26633 Mdot
.9605 .10434 Mdot
.07726 .65764 Mdot
.10289 .28677 Mdot
.4098 .84014 Mdot
.1144 .78757 Mdot
.19213 .82847 Mdot
.25159 .81991 Mdot
.17618 .84777 Mdot
.71267 .71577 Mdot
.84523 .65512 Mdot
.4249 .85563 Mdot
.22702 .95291 Mdot
.71883 .77152 Mdot
.13204 .81618 Mdot
.60236 .74217 Mdot
.43001 .99548 Mdot
.35237 .88441 Mdot
.04088 .03226 Mdot
.24322 .88492 Mdot
.30696 .0025 Mdot
.15299 .77212 Mdot
.26804 .88965 Mdot
.40147 .9866 Mdot
.29576 .81261 Mdot
.35696 .91821 Mdot
.1611 .8684 Mdot
.19713 .81304 Mdot
.28927 .70053 Mdot
.3517 .86961 Mdot
.32214 .12329 Mdot
.31402 .86372 Mdot
.99772 .66752 Mdot
.79043 .19171 Mdot
.31369 .7893 Mdot
.3773 .48039 Mdot
.18164 .79136 Mdot
.11246 .78077 Mdot
.25347 .98258 Mdot
.24514 .86777 Mdot
.53617 .42481 Mdot
.35474 .89288 Mdot
.1639 .84628 Mdot
.34752 .92309 Mdot
.1632 .98826 Mdot
.43259 .22092 Mdot
.27666 .82682 Mdot
.17439 .08658 Mdot
.9802 .68649 Mdot
.04877 .02741 Mdot
.27531 .81044 Mdot
.24016 .97418 Mdot
.20604 .23951 Mdot
.26291 .8592 Mdot
.25277 .87734 Mdot
.22867 .87066 Mdot
.40737 .07514 Mdot
.39999 .46102 Mdot
.36593 .6346 Mdot
.16833 .81914 Mdot
.11249 .70104 Mdot
.2288 .81152 Mdot
.26186 .1251 Mdot
.44512 .05664 Mdot
.22002 .76581 Mdot
.06023 .6737 Mdot
.58715 .08273 Mdot
.23163 .9516 Mdot
.3274 .80134 Mdot
.15612 .96172 Mdot
.05877 .70755 Mdot
.33815 .93993 Mdot
.05309 .62128 Mdot
.13428 .69038 Mdot
.04083 .62523 Mdot
.24712 .97174 Mdot
.98733 .76115 Mdot
.2273 .75302 Mdot
.32033 .8331 Mdot
.36235 .8946 Mdot
.10118 .79388 Mdot
.25247 .89181 Mdot
.44358 .46445 Mdot
.69356 .00207 Mdot
.2704 .90328 Mdot
.72546 .78611 Mdot
.1937 .82342 Mdot
.19765 .84027 Mdot
.12623 .82632 Mdot
.23887 .86654 Mdot
.19857 .79181 Mdot
.27428 .89014 Mdot
.19061 .8043 Mdot
.14361 .76914 Mdot
.66057 .33199 Mdot
.24564 .95546 Mdot
.57527 .86663 Mdot
.91498 .81922 Mdot
.30053 .85163 Mdot
.77994 .75459 Mdot
.51046 .762 Mdot
.24854 .00231 Mdot
.01939 .30953 Mdot
.21298 .75333 Mdot
.09988 .80837 Mdot
.70151 .00774 Mdot
.42868 .72478 Mdot
.19819 .84611 Mdot
.23634 .90373 Mdot
.23281 .86664 Mdot
.71781 .90214 Mdot
.05667 .6246 Mdot
.62268 .12706 Mdot
.30526 .91056 Mdot
.16109 .83506 Mdot
.35521 .88328 Mdot
.11335 .83964 Mdot
.0522 .70115 Mdot
.36692 .91061 Mdot
.14556 .93339 Mdot
.21924 .87079 Mdot
.22212 .15005 Mdot
.19537 .81802 Mdot
.29399 .31554 Mdot
.20438 .84609 Mdot
.30369 .85693 Mdot
.18985 .83631 Mdot
.30557 .85417 Mdot
.16824 .8751 Mdot
.22187 .70757 Mdot
.15769 .83636 Mdot
.25494 .71709 Mdot
.25985 .87174 Mdot
.23036 .97314 Mdot
.06344 .95994 Mdot
.22074 .84582 Mdot
.84883 .8837 Mdot
.2206 .89501 Mdot
.17235 .80851 Mdot
.26007 .74925 Mdot
.41936 .99906 Mdot
.207 .77919 Mdot
.44126 .37034 Mdot
.08532 .5494 Mdot
.42969 .96526 Mdot
.31637 .95771 Mdot
.46341 .84126 Mdot
.31487 .90505 Mdot
.19274 .81586 Mdot
.2745 .79211 Mdot
.19418 .92309 Mdot
.24198 .86722 Mdot
.25989 .87739 Mdot
.86929 .18008 Mdot
.20767 .92903 Mdot
.31772 .8579 Mdot
.10034 .52428 Mdot
.46826 .18852 Mdot
.31518 .98231 Mdot
.19339 .93977 Mdot
.46512 .56517 Mdot
.2684 .82902 Mdot
.13247 .0414 Mdot
.29454 .90387 Mdot
.15087 .79426 Mdot
.13539 .83538 Mdot
.33086 .94789 Mdot
.36303 .08365 Mdot
.02765 .23905 Mdot
.17964 .99863 Mdot
.87571 .019 Mdot
.15532 .18648 Mdot
.04973 .04033 Mdot
.26758 .99247 Mdot
.33032 .89919 Mdot
.2827 .90888 Mdot
.49297 .90639 Mdot
.98287 .00984 Mdot
.34135 .01546 Mdot
.13569 .85717 Mdot
.36527 .76329 Mdot
.32435 .63271 Mdot
.34138 .81706 Mdot
.22535 .7684 Mdot
.31367 .96561 Mdot
.22156 .87154 Mdot
.90076 .57281 Mdot
.11373 .70918 Mdot
.2969 .94941 Mdot
.18586 .83321 Mdot
.27215 .88814 Mdot
.64431 .96978 Mdot
.14654 .20378 Mdot
.16537 .00406 Mdot
.1514 .13618 Mdot
.90331 .68885 Mdot
.36344 .75279 Mdot
.26414 .94534 Mdot
.2132 .83998 Mdot
.16002 .93586 Mdot
.57335 .80588 Mdot
.27257 .88995 Mdot
.54849 .40595 Mdot
.18362 .95843 Mdot
.24776 .90782 Mdot
.50892 .61506 Mdot
.23841 .85302 Mdot
.35771 .89587 Mdot
.20131 .82665 Mdot
.87083 .74379 Mdot
.30365 .93133 Mdot
.27852 .8657 Mdot
.90436 .85855 Mdot
.51529 .80893 Mdot
.2641 .85902 Mdot
.47368 .2981 Mdot
.29826 .89968 Mdot
.6076 .90017 Mdot
.49317 .8759 Mdot
.3211 .73948 Mdot
.21538 .72676 Mdot
.3069 .89992 Mdot
.71658 .05186 Mdot
.8972 .93409 Mdot
.33179 .73768 Mdot
.45274 .8458 Mdot
.21854 .93454 Mdot
.26301 .88742 Mdot
.27238 .9018 Mdot
.00062 .71472 Mdot
.19164 .85163 Mdot
.6075 .3244 Mdot
.256 .79767 Mdot
.23146 .65763 Mdot
.75216 .11049 Mdot
.56449 .38508 Mdot
.24977 .06463 Mdot
.73795 .52419 Mdot
.28943 .68929 Mdot
.91646 .72608 Mdot
.13305 .88069 Mdot
.17934 .81197 Mdot
.16449 .13032 Mdot
.83946 .63085 Mdot
.24195 .90396 Mdot
.21743 .90195 Mdot
.24401 .79587 Mdot
.1164 .82751 Mdot
.10287 .36204 Mdot
.14665 .20406 Mdot
.22951 .94865 Mdot
.39873 .01819 Mdot
.03755 .02114 Mdot
.0458 .33491 Mdot
.43321 .95686 Mdot
.21912 .90069 Mdot
.33058 .93804 Mdot
.27247 .8233 Mdot
.29215 .83395 Mdot
.54704 .37857 Mdot
.1059 .80109 Mdot
.21222 .87204 Mdot
.23572 .88123 Mdot
.33561 .73779 Mdot
.23853 .83059 Mdot
.20901 .91441 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003o
ooooooooo`02ooooo`;o000000?oooooo`000?l000001oooool00ol0003oooooooooo`0;ooooo`?o
00003oooool01?l0003oooooo`000?l0000<ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool01?l0003oooooo`000?l0000<ooooo`03o`000?oooooooooo00Oooooo0_l00000
1Ooooooo0000o`000?oooooo000000oooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00;ooooo000Nooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo0_l00000
0ooooooo0000o`000007ooooo`03o`000?oooooooooo00_ooooo0ol0000=ooooo`?o000000?ooooo
o`000?l000003?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool01_ooool2o`0000Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool2o`000005ooooool0003o
0000ooooool000003oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool00_ooool001kooooo00?o0000ooooooooool0COooool2o`0000gooooo0_l0000j
ooooo`;o0000A_ooool2o`0005Wooooo0_l0000:ooooo`007_ooool01?l0003oooooo`000?l0001<
ooooo`;o00005oooool2o`0002Kooooo0_l0001@ooooo`;o0000FOooool2o`0000[ooooo000Noooo
o`04o`000?oooooo0000o`0000cooooo0_l0000oooooo`;o00005_ooool2o`0000?ooooo0_l0000Q
ooooo`;o0000]oooool001kooooo00?o0000ooooooooool03Oooool2o`0002gooooo0_l0000@oooo
o`;o00006oooool2o`00017ooooo0_l0000Dooooo`;o0000Goooool2o`0002;ooooo0_l0000/oooo
o`007_ooool00ol0003oooooooooo`08ooooo`;o0000<_ooool2o`0001Gooooo0_l000000ooooooo
0000o`00000Vooooo`;o00005?ooool3o`0004cooooo0_l0000@ooooo`;o00008_ooool2o`0002co
oooo000Nooooo`03o`000?oooooooooo00Sooooo0_l00012ooooo`;o00001Oooool2o`000003oooo
ool0003o000001gooooo0_l0000Nooooo`;o0000C?ooool2o`0006;ooooo000Nooooo`03o`000?oo
oooooooo00cooooo0_l0000;ooooo`;o0000;oooool6o`0002Gooooo0_l0003@ooooo`007_ooool0
0ol0003oooooooooo`0<ooooo`;o00002oooool2o`0002oooooo0ol000000ooooooo0000o`00000X
ooooo`;o00001?ooool2o`000<Oooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l00010oooo
o`;o0000:oooool2o`0000Cooooo0_l00037ooooo`007_ooool00ol0003oooooooooo`09ooooo`;o
0000a?ooool2o`0007Kooooo000Nooooo`03o`000?oooooooooo00cooooo0_l0000Iooooo`;o0000
8Oooool2o`0002_ooooo0_l00004ooooo`;o0000D?ooool2o`0002[ooooo0_l0000Dooooo`;o0000
=?ooool001kooooo00?o0000ooooooooool03?ooool2o`0001Wooooo0_l0000Qooooo`;o0000:ooo
ool2o`0000Cooooo0_l0001looooo`;o00005?ooool2o`0003Cooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0I_ooool2o`0003gooooo0_l00005oooo
o`;o0000VOooool001kooooo0_l0001Sooooo`;o00000_ooool2o`0003gooooo0_l00005ooooo`;o
0000=oooool2o`00063ooooo000Nooooo`03o`000?oooooooooo06;ooooo0_l00005ooooo`;o0000
8_ooool2o`0001cooooo0_l0000hooooo`;o0000H?ooool001kooooo00?o0000ooooooooool0JOoo
ool2o`0000oooooo0_l0000Aooooo`;o00007?ooool2o`0002Oooooo0_l00017ooooo`;o0000:?oo
ool001kooooo00?o0000ooooooooool03_ooool2o`0002?ooooo0_l00015ooooo`;o00000_ooool2
o`0005Cooooo0_l00017ooooo`;o0000:?ooool001kooooo00?o0000ooooooooool03_ooool2o`00
02?ooooo0_l0000Hooooo`;o00008Oooool2o`0000cooooo0_l00037ooooo`007_ooool00ol0003o
ooooooooo`1=ooooo`;o00008Oooool2o`000=Gooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool09_ooool2o`0005Sooooo0_l00035ooooo`007_ooool0
0ol0003oooooooooo`0Vooooo`;o0000E_ooool4o`000<Gooooo000Nooooo`03o`000?oooooooooo
07gooooo0ol00037ooooo`007_ooool00ol0003oooooooooo`1booooo`;o00002Oooool2o`0003co
oooo0_l0001booooo`;o00005_ooool001kooooo00?o0000ooooooooool0=Oooool2o`0000oooooo
0_l0000Jooooo`;o00000_ooool2o`0000[ooooo0_l00017ooooo`;o0000KOooool2o`0000?ooooo
0_l0000Fooooo`007_ooool00ol0003oooooooooo`0eooooo`;o00003oooool2o`0001[ooooo0_l0
0002ooooo`;o0000`_ooool2o`0001_ooooo000Nooooo`03o`000?oooooooooo06oooooo0_l0003F
ooooo`007_ooool00ol0003oooooooooo`1Iooooo`;o00005?ooool2o`000:[ooooo0_l0000Zoooo
o`007_ooool00ol0003oooooooooo`0Uooooo`;o00006oooool2o`0001Gooooo0_l0000Fooooo`;o
00002oooool2o`0009_ooooo0_l0000Zooooo`007_ooool2o`0002Kooooo0_l0000Fooooo`;o0000
0oooool2o`0000cooooo0_l0000Oooooo`;o00002oooool2o`000<Oooooo000Nooooo`03o`000?oo
oooooooo03gooooo0_l0000Aooooo`;o0000h_ooool2o`00017ooooo000Nooooo`03o`000?oooooo
oooo0?oooooo=Oooool2o`00017ooooo000Nooooo`03o`000?oooooooooo07[ooooo0_l0001doooo
o`;o0000EOooool001kooooo00?o0000ooooooooool0A_ooool2o`0000Kooooo0_l0000Zooooo`;o
0000M?ooool2o`0005Gooooo000Nooooo`03o`000?oooooooooo04Kooooo0_l00006ooooo`;o0000
moooool001kooooo00?o0000ooooooooool0A_ooool2o`000?oooooo000Nooooo`03o`000?oooooo
oooo06Gooooo0_l0000Kooooo`;o0000`oooool001kooooo00?o0000ooooooooool0DOooool2o`00
01;ooooo0_l0000Kooooo`;o00004?ooool2o`00033ooooo0_l0001oooooo`007_ooool00ol0003o
ooooooooo`0aooooo`Co00005?ooool2o`0000Kooooo0_l00008ooooo`;o0000=oooool2o`00033o
oooo0_l0001oooooo`007_ooool00ol0003oooooooooo`0aooooo`Co00005?ooool2o`00013ooooo
0_l0003Zooooo`007_ooool00ol0003oooooooooo`0]ooooo`;o0000oooooolIooooo`007_ooool0
0ol0003oooooooooo`04ooooo`;o00009oooool2o`000?oooooo6Oooool001kooooo00?o0000oooo
ooooool01?ooool2o`00027ooooo0_l0002Oooooo`;o0000OOooool001kooooo00?o0000oooooooo
ool09_ooool3o`00033ooooo0_l0001]ooooo`;o0000OOooool001kooooo00?o0000ooooooooool0
9_ooool2o`0002Wooooo0_l00006ooooo`;o0000k?ooool001kooooo0_l0000oooooo`;o00001?oo
ool2o`0000_ooooo0_l0000@ooooo`;o0000C_ooool2o`0009;ooooo000Nooooo`03o`000?oooooo
oooo03kooooo0_l00004ooooo`;o00002oooool2o`00013ooooo0_l0001>ooooo`;o0000T_ooool0
01kooooo00?o0000ooooooooool05?ooool2o`000?oooooo<_ooool001kooooo00?o0000oooooooo
ool05?ooool2o`0008_ooooo0_l0002Tooooo`007_ooool00ol0003oooooooooo`2Qooooo`;o0000
>?ooool2o`0006[ooooo000Nooooo`03o`000?oooooooooo0=_ooooo0_l0001Zooooo`007_ooool0
0ol0003oooooooooo`0Wooooo`;o0000oooooolOooooo`007_ooool00ol0003oooooooooo`0Loooo
o`;o00002Oooool2o`000?oooooo7oooool001kooooo00?o0000ooooooooool07?ooool2o`000?oo
oooo:_ooool001kooooo00?o0000ooooooooool0S_ooool2o`000;Oooooo000Nooooo`03o`000?oo
oooooooo07Sooooo0_l0000Dooooo`;o0000Qoooool2o`0002kooooo000Nooooo`03o`000?oooooo
oooo07Sooooo0_l0002@ooooo`;o00002oooool2o`0002kooooo000Nooooo`03o`000?oooooooooo
02kooooo0_l0001Tooooo`;o0000M?ooool2o`0003_ooooo000Nooooo`03o`000?oooooooooo02ko
oooo0_l0001Tooooo`;o0000Ioooool2o`0004Sooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0?gooooo0_l00018ooooo`00
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003o
oooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`0/oooo
o`;o0000>_ooool2o`000=gooooo0003ooooo`05o`000?ooooooooooooooool000003_ooool00omg
MgOoIVIVooooo`05ooooo`03o`000?oooooooooo02cooooo0_l0000jooooo`;o0000gOooool000?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0UOooool2o`000;3ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0UOooool2o`0000Gooooo0_l0002Y
ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c006ooooo`03o`000?oooooooooo09cooooo0_l0002Yooooo`007_ooool00ol0003oooooooooo`0Y
ooooo`;o0000_?ooool2o`0005kooooo000Nooooo`03o`000?oooooooooo02;ooooo0_l00005oooo
o`;o00004?ooool2o`0004cooooo0_l0001Looooo`;o0000G_ooool001kooooo00?o0000oooooooo
ool08_ooool2o`0001Oooooo0_l0001<ooooo`;o0000_?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`2Yooooo`;o0000W?ooool001kooooo00?o0000
ooooooooool0ZOooool2o`0009cooooo000Nooooo`03o`000?oooooooooo02[ooooo0_l0003Aoooo
o`;o0000B?ooool001kooooo00?o0000ooooooooool01Oooool2o`0002?ooooo0_l00002ooooo`;o
00003oooool2o`000:Sooooo0_l0000Booooo`;o0000B?ooool001kooooo00?o0000ooooooooool0
1Oooool2o`0002Oooooo0_l0000?ooooo`;o00003Oooool2o`0009Wooooo0_l0000iooooo`;o0000
8Oooool001kooooo00?o0000ooooooooool09oooool2o`0000cooooo0_l0000Gooooo`;o00001_oo
ool3o`0002Kooooo0_l0002Sooooo`;o00008Oooool001kooooo00?o0000ooooooooool09oooool2
o`0000cooooo0ol0000Nooooo`?o00009_ooool2o`000<Kooooo000Nooooo`;o0000=oooool2o`00
02gooooo0_l0003Pooooo`007_ooool00ol0003oooooooooo`1Uooooo`;o0000h?ooool001kooooo
00?o0000ooooooooool0;Oooool2o`000?oooooo6Oooool001kooooo00?o0000ooooooooool0;Ooo
ool2o`0008?ooooo0_l0002Cooooo`007_ooool00ol0003oooooooooo`0mooooo`;o0000Loooool2
o`0009?ooooo000Nooooo`03o`000?oooooooooo03gooooo0_l00009ooooo`;o0000oOooool001ko
oooo00?o0000ooooooooool0B?ooool2o`000?gooooo000Nooooo`03o`000?oooooooooo09kooooo
0_l00014ooooo`;o0000HOooool001kooooo00?o0000ooooooooool0W_ooool2o`0004Cooooo0_l0
001Qooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool07Oooool2o`000?oooooo:Oooool001kooooo
00?o0000ooooooooool07Oooool2o`000?oooooo:Oooool001kooooo00?o0000ooooooooool0I_oo
ool2o`000=oooooo000Nooooo`03o`000?oooooooooo06Kooooo0_l0003Oooooo`007_ooool00ol0
003oooooooooo`2Fooooo`;o0000[oooool001kooooo0_l0000eooooo`;o0000H?ooool2o`0006co
oooo0_l00011ooooo`007_ooool00ol0003oooooooooo`0dooooo`;o0000c_ooool2o`00047ooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool00_ooool2
o`0004oooooo0_l0003booooo`007_ooool00ol0003oooooooooo`02ooooo`;o0000Coooool2o`00
0?;ooooo000Nooooo`03o`000?oooooooooo05_ooooo0_l0003Zooooo`007_ooool00ol0003ooooo
ooooo`1Kooooo`;o0000j_ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`31ooooo`;o0000Q?ooool001kooooo00?o0000ooooooooool0`Oooool2o`00
08Cooooo000Nooooo`03o`000?oooooooooo0=?ooooo0_l0001booooo`007_ooool00ol0003ooooo
ooooo`08ooooo`;o000000?oooooo`000?l00000a_ooool2o`0007;ooooo000Nooooo`03o`000?oo
oooooooo00Sooooo0_l000000ooooooo0000o`00003ooooooc_ooooo000Nooooo`03o`000?oooooo
oooo047ooooo0_l00021ooooo`;o0000POooool001kooooo00?o0000ooooooooool02oooool2o`00
03Cooooo0_l00021ooooo`;o0000POooool001kooooo00?o0000ooooooooool02oooool2o`000;co
oooo0_l0001looooo`007_ooool2o`000<[ooooo0_l0001looooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o0000oooooolYooooo`00
7_ooool00ol0003oooooooooo`0Mooooo`;o0000_oooool2o`0006Oooooo000Nooooo`03o`000?oo
oooooooo08_ooooo0_l0001Aooooo`;o0000Ioooool001kooooo00?o0000ooooooooool0Roooool2
o`000;[ooooo000Nooooo`03o`000?oooooooooo0:3ooooo0_l0002Uooooo`007_ooool00ol0003o
ooooooooo`2Pooooo`;o00003?ooool2o`0009Oooooo000Nooooo`03o`000?oooooooooo0:kooooo
0_l0002Gooooo`007_ooool00ol0003oooooooooo`2cooooo`;o0000T_ooool001kooooo00?o0000
ooooooooool0/oooool2o`0009;ooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo
00Cooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom8oooo
o`000oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`?o0000oooooom8oooo
o`000oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool0
0ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo0:kooooo0_l00029ooooo`;o00003?oo
ool000?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o
0000ooooooooool0[_ooool2o`0008Wooooo0_l0000<ooooo`000oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`3oooooodSooooo0003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0:[ooooo0_l0002Kooooo`00
7_ooool00ol0003oooooooooo`2Zooooo`;o0000Voooool001kooooo00?o0000ooooooooool0oooo
oolhooooo`;o00003_ooool001kooooo00?o0000ooooooooool0oooooolhooooo`;o00003_ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`0[ooooo`;o
0000Doooool2o`000<Gooooo000Nooooo`03o`000?oooooooooo02_ooooo0_l0001Cooooo`;o0000
aOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`0S
ooooo`;o0000bOooool2o`000003ooooool0003o000005Cooooo000Nooooo`;o00009?ooool2o`00
0<Wooooo0_l000000ooooooo0000o`00001Dooooo`007_ooool00ol0003oooooooooo`0hooooo`;o
0000ooooool>ooooo`007_ooool00ol0003oooooooooo`0hooooo`;o0000E_ooool2o`000;Gooooo
000Nooooo`03o`000?oooooooooo07kooooo0_l0000@ooooo`;o0000:Oooool2o`0008[ooooo000N
ooooo`03o`000?oooooooooo07kooooo0_l0000<ooooo`;o0000;Oooool2o`0002Cooooo0_l0001T
ooooo`007_ooool00ol0003oooooooooo`2<ooooo`;o0000Doooool2o`0006Cooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00Co0000ooooool0003o0000R_ooool2o`000;[o
oooo000Nooooo`04o`000?oooooo0000o`0008[ooooo0_l0002jooooo`007_ooool00ol0003ooooo
ooooo`1gooooo`;o0000c_ooool001kooooo00?o0000ooooooooool0Moooool2o`0007Wooooo0_l0
001Cooooo`007_ooool00ol0003oooooooooo`3booooo`;o0000Doooool001kooooo00?o0000oooo
ooooool0ROooool2o`000;cooooo000Nooooo`03o`000?oooooooooo08Wooooo0_l0002looooo`00
7_ooool00ol0003oooooooooo`0]ooooo`;o00006_ooool2o`000?cooooo000Nooooo`03o`000?oo
oooooooo02gooooo0_l0000Jooooo`;o0000o?ooool001kooooo0_l0003oooooodWooooo000Noooo
o`03o`000?oooooooooo02;ooooo0_l00011ooooo`;o0000bOooool2o`0001Gooooo000Nooooo`03
o`000?oooooooooo02;ooooo1?l0000oooooo`;o0000bOooool2o`0001Gooooo000Nooooo`03o`00
0?oooooooooo02Cooooo0_l0003oooooob;ooooo000Nooooo`03o`000?oooooooooo01oooooo0_l0
001:ooooo`;o00007?ooool2o`000;cooooo000Nooooo`03o`000?oooooooooo01oooooo0_l0001:
ooooo`;o00007?ooool2o`000;cooooo000Nooooo`03o`000?oooooooooo0:Wooooo0_l0002Loooo
o`007_ooool00ol0003oooooooooo`0Mooooo`;o0000R_ooool2o`00047ooooo0_l0001Iooooo`00
7_ooool00ol0003oooooooooo`0Mooooo`;o0000cOooool2o`0005Wooooo000Nooooo`03o`000?oo
oooooooo0=Oooooo0_l0001^ooooo`007_ooool00ol0003oooooooooo`3Gooooo`;o0000K_ooool0
01kooooo00?o0000ooooooooool09_ooool2o`000?oooooo8?ooool001kooooo00?o0000oooooooo
ool09_ooool2o`000?oooooo8?ooool001kooooo00?o0000ooooooooool06oooool2o`000?oooooo
:oooool001kooooo00?o0000ooooooooool06oooool2o`00037ooooo0_l0000iooooo`;o0000_?oo
ool001kooooo00?o0000ooooooooool0C_ooool2o`0003Wooooo0_l0002looooo`007_ooool2o`00
01Wooooo0_l0003oooooobkooooo000Nooooo`03o`000?oooooooooo01Sooooo0_l0000[ooooo`;o
0000ooooool1ooooo`007_ooool00ol0003oooooooooo`15ooooo`;o00007oooool2o`000=oooooo
000Nooooo`03o`000?oooooooooo06Kooooo0_l0003Oooooo`007_ooool00ol0003oooooooooo`1>
ooooo`;o0000moooool001kooooo00?o0000ooooooooool0C_ooool2o`0004?ooooo0_l0002boooo
o`007_ooool00ol0003oooooooooo`0Gooooo`;o0000N_ooool2o`000;;ooooo000Nooooo`03o`00
0?oooooooooo01Oooooo0_l0000Fooooo`;o00000_ooool2o`0005Sooooo0_l0002Booooo`;o0000
9?ooool001kooooo00?o0000ooooooooool0;?ooool2o`000003ooooool0003o000000;ooooo0_l0
000Mooooo`;o0000>Oooool2o`0000gooooo0_l00023ooooo`;o00003Oooool2o`0001Gooooo000N
ooooo`03o`000?oooooooooo02_ooooo0ol0000Tooooo`;o00006Oooool2o`0002gooooo0_l0002B
ooooo`;o00005Oooool001kooooo00?o0000ooooooooool0:oooool2o`00017ooooo0_l00009oooo
o`;o00008_ooool2o`0003Cooooo0_l0002Rooooo`007_ooool00ol0003oooooooooo`0nooooo`;o
00002Oooool2o`0005Sooooo0_l0000?ooooo`;o00006_ooool2o`0007Gooooo000Nooooo`03o`00
0?oooooooooo00Oooooo0_l0002[ooooo`;o00006_ooool2o`0007Gooooo000Nooooo`03o`000?oo
oooooooo00Oooooo0_l0003oooooocoooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo03Sooooo
0_l0000<ooooo`;o0000ooooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0>?ooool2o`0000co
oooo0_l0003`ooooo`;o00003Oooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05
o`000?ooooooooooooooool000001_ooool3o`000?oooooo>Oooool2o`0000gooooo0003ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o0000
ooooooooool0ooooool[ooooo`;o00001oooool2o`0001;ooooo0003ooooo`05o`000?oooooooooo
ooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool04ooo
ool2o`000?oooooo5_ooool2o`0000Oooooo0_l0000Booooo`000oooool01Ol@413ooooooooooooo
oooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`0Cooooo`;o00005_oo
ool2o`000?oooooo6oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@
413oV9RH00Sooooo00?o0000ooooooooool02_ooool2o`0001oooooo0_l0003Yooooo`;o0000;ooo
ool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo
00?o0000ooooooooool02_ooool2o`0009Gooooo0_l0001cooooo`;o0000;oooool001kooooo00?o
0000ooooooooool0XOooool2o`0006Gooooo0_l0000mooooo`007_ooool00ol0003oooooooooo`0=
ooooo`;o0000nOooool2o`0002Kooooo0_l0000Eooooo`007_ooool00ol0003oooooooooo`09oooo
o`;o00000_ooool3o`0004kooooo0_l0003@ooooo`;o00005Oooool001kooooo00?o0000oooooooo
ool02Oooool2o`0000?ooooo0_l0000Yooooo`;o00008oooool2o`000;Wooooo0_l0000/ooooo`00
7_ooool00ol0003oooooooooo`0iooooo`;o0000d_ooool2o`0000[ooooo0_l0000/ooooo`007_oo
ool00ol0003oooooooooo`1Uooooo`;o00003?ooool2o`0004;ooooo0_l0001Dooooo`;o0000;ooo
ool2o`0000Oooooo000Nooooo`03o`000?oooooooooo04[ooooo0_l0000Iooooo`;o00003?ooool2
o`0004;ooooo0_l0001hooooo`;o00002oooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo
04[ooooo0_l0000@ooooo`;o0000[Oooool2o`00023ooooo0_l00002ooooo`;o00005?ooool001ko
oooo00?o0000ooooooooool0;Oooool2o`0002gooooo0_l0002]ooooo`;o00008?ooool2o`0001So
oooo000Nooooo`03o`000?oooooooooo02gooooo0_l0000>ooooo`;o0000:Oooool2o`0008oooooo
0_l0001<ooooo`007_ooool00ol0003oooooooooo`0^ooooo`;o00003Oooool2o`0000Gooooo0_l0
000Rooooo`;o0000Soooool2o`0004cooooo000Nooooo`;o0000;oooool2o`0001Cooooo0_l0001:
ooooo`;o0000]Oooool001kooooo00?o0000ooooooooool0@oooool2o`0004_ooooo0_l0001moooo
o`;o0000=_ooool001kooooo00?o0000ooooooooool05Oooool2o`0002cooooo0_l00002ooooo`;o
0000@Oooool2o`0008?ooooo0_l0000fooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o0000
<?ooool2o`00047ooooo0_l0002Aooooo`;o00008?ooool2o`0000Kooooo000Nooooo`03o`000?oo
oooooooo04gooooo0_l0003>ooooo`?o00007oooool2o`0000Kooooo000Nooooo`03o`000?oooooo
oooo01Cooooo0_l00007ooooo`;o00004_ooool2o`0001[ooooo0_l0003?ooooo`;o00008?ooool2
o`0000Gooooo000Nooooo`03o`000?oooooooooo01Cooooo1?l00005ooooo`;o00004_ooool2o`00
0?Cooooo0_l0000Gooooo`;o00001Oooool001kooooo00?o0000ooooooooool03oooool2o`0000Go
oooo0_l0000kooooo`;o0000d_ooool2o`0001Gooooo0_l00007ooooo`007_ooool00ol0003ooooo
ooooo`0?ooooo`;o0000@_ooool2o`000<3ooooo0_l0000Wooooo`;o00001oooool001kooooo00?o
0000ooooooooool0Q?ooool2o`0008oooooo0_l0000`ooooo`007_ooool00ol0003oooooooooo`24
ooooo`;o0000`Oooool001kooooo00?o0000ooooooooool0D?ooool2o`0000gooooo0_l0000eoooo
o`;o00001Oooool2o`0009cooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0Fooooo`;o
00002Oooool2o`0000Gooooo0_l00006ooooo`;o00007_ooool2o`0000Sooooo0_l00003ooooo`;o
0000=Oooool4o`0000?ooooo0_l00023ooooo`;o00005oooool2o`0000[ooooo000Nooooo`03o`00
0?oooooooooo01Kooooo0_l00009ooooo`;o00001Oooool2o`0000Kooooo0_l0000Xooooo`;o0000
??ooool2o`0001[ooooo0_l0001/ooooo`;o00008oooool001kooooo00?o0000ooooooooool07ooo
ool2o`0002Gooooo0_l0001/ooooo`;o0000TOooool001kooooo00?o0000ooooooooool07oooool2
o`0002Gooooo0_l000000ooooooo0000o`000036ooooo`;o0000;Oooool2o`0000Gooooo000Noooo
o`;o00003_ooool2o`00017ooooo0_l0000Wooooo`;o00000oooool2o`0000[ooooo0_l0002eoooo
o`;o0000:?ooool2o`0000?ooooo0_l00005ooooo`007Oooool2o`0000oooooo0_l0000Aooooo`;o
00001oooool2o`0002?ooooo0_l00006ooooo`;o00000_ooool2o`0004oooooo0_l0002>ooooo`;o
00002_ooool001gooooo1?l0000?ooooo`;o00002Oooool2o`0000gooooo0_l0000Iooooo`Co0000
1_ooool2o`0000Gooooo0ol0001Cooooo`;o0000V_ooool001kooooo0ol0000?ooooo`;o00002Ooo
ool2o`0000Gooooo0_l0000Qooooo`Co00001_ooool2o`0000Gooooo0_l0001looooo`;o00005_oo
ool2o`0002Wooooo0_l0000_ooooo`007Oooool2o`0002?ooooo0_l0000Rooooo`?o00001?ooool2
o`00023ooooo0_l0001Sooooo`;o00005_ooool2o`0001[ooooo0_l0000=ooooo`;o0000;oooool0
01gooooo0_l0001>ooooo`;o000000?oooooo`000?l000005_ooool2o`0000Gooooo0_l0001doooo
o`;o00008Oooool2o`0003kooooo000Nooooo`03o`000?oooooooooo04oooooo0_l00002ooooo`;o
00004?ooool4o`0007_ooooo0_l0001Qooooo`007_ooool00ol0003oooooooooo`1Cooooo`;o0000
4?ooool2o`0001Gooooo0_l00032ooooo`;o00001Oooool001kooooo00?o0000ooooooooool0@_oo
ool3o`0003Gooooo1?l00009ooooo`;o0000WOooool2o`0001Sooooo0_l00005ooooo`007_ooool0
0ol0003oooooooooo`02ooooo`;o0000:_ooool2o`0001;ooooo0ol00002ooooo`;o00004?ooool2
o`0001oooooo0_l0000;ooooo`;o0000WOooool2o`0001oooooo000Nooooo`03o`000?oooooooooo
00;ooooo0_l0000Zooooo`;o00005oooool2o`00013ooooo0_l0002booooo`;o0000>?ooool001ko
oooo00?o0000ooooooooool0ooooool>ooooo`;o0000>?ooool001kooooo00?o0000ooooooooool0
I?ooool2o`0000;ooooo0ol00002ooooo`;o0000f?ooool001kooooo00?o0000ooooooooool0I?oo
ool2o`0000;ooooo0ol00002ooooo`;o0000DOooool2o`0008Gooooo000Nooooo`03o`000?oooooo
oooo0:?ooooo0_l0000Kooooo`;o0000EOooool2o`0002?ooooo0_l00009ooooo`007_ooool00ol0
003oooooooooo`1Aooooo`;o0000D?ooool2o`0006kooooo0_l00002ooooo`;o00008oooool2o`00
00Wooooo000Nooooo`;o0000<oooool2o`0000gooooo0_l0000=ooooo`?o0000M?ooool2o`0001go
oooo0_l0000[ooooo`;o0000<_ooool001kooooo00?o0000ooooooooool0<_ooool2o`0000Oooooo
0_l00004ooooo`;o00000oooool2o`0000Sooooo0_l0000Pooooo`;o0000Doooool2o`0001gooooo
0_l0000Aooooo`;o0000@?ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo02kooooo1?l0
0009ooooo`;o00001?ooool2o`0000?ooooo0_l0000Tooooo`;o00001?ooool2o`0008Gooooo0_l0
0010ooooo`;o00002_ooool001kooooo00?o0000ooooooooool09Oooool2o`0000Oooooo1?l00009
ooooo`;o0000;oooool2o`0001?ooooo0_l0002jooooo`;o00002?ooool001kooooo00?o0000oooo
ooooool09Oooool2o`0000Kooooo0_l0000mooooo`;o00001Oooool2o`0000cooooo0_l0000Ooooo
o`;o0000VOooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo02cooooo0ol0000Booooo`Co
00000_ooool2o`000003ooooool0003o0000023ooooo0_l00005ooooo`;o0000;Oooool2o`000:?o
oooo000Nooooo`03o`000?oooooooooo02_ooooo1?l0000Booooo`So000000?oooooo`000?l00000
noooool001kooooo00?o0000ooooooooool06_ooool2o`0000oooooo1Ol0000Eooooo`Co000000?o
ooooo`000?l00000V_ooool2o`0005oooooo000Nooooo`04o`000?ooooooooooooooo`;o00005ooo
ool2o`0000gooooo0_l000000ooooooo0000o`000002o`0001Oooooo0_l000000ooooooo0000o`00
000Iooooo`;o0000IOooool2o`0001Sooooo0_l0001Oooooo`007_ooool01?l0003ooooooooooooo
ool2o`0002Kooooo0_l0000Dooooo`Co000000?oooooo`000?l000000_ooool2o`0001_ooooo0ol0
000kooooo`;o00009oooool2o`0004Gooooo0_l0000booooo`007_ooool00ol0003oooooooooo`0P
ooooo`;o00000_ooool2o`0001Wooooo1?l000000ooooooo0000o`000004o`0001cooooo0_l0000T
ooooo`;o00002Oooool2o`0000[ooooo0_l0001^ooooo`;o0000<_ooool001kooooo00?o0000oooo
ooooool02Oooool2o`0001Gooooo1_l000001?oooooo0000o`000?ooool2o`0000kooooo0_l00004
ooooo`;o00001?ooool2o`0000;ooooo0_l00010ooooo`;o000000?oooooo`000?l000001_ooool2
o`0007_ooooo0_l0000aooooo`007_ooool00ol0003oooooooooo`09ooooo`;o00005_ooool3o`00
00?ooooo1Ol0000>ooooo`;o00001?ooool2o`0000Cooooo0_l00002ooooo`;o000000?oooooo`00
0?l000004_ooool2o`0001;ooooo0_l0000Hooooo`;o0000Eoooool2o`0002[ooooo0_l0000aoooo
o`007_ooool00ol0003oooooooooo`0Mooooo`;o00000_ooool2o`0000Gooooo0_l0000=ooooo`;o
00000oooool2o`0000oooooo0_l0000<ooooo`;o00001?ooool3o`00017ooooo0_l0001aooooo`;o
0000GOooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co
8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool07Oooool2o`0000?ooooo0_l00009oooo
o`;o00002?ooool2o`0000?ooooo0_l000000ooooooo0000o`00000Dooooo`;o00001?ooool2o`00
00Gooooo0_l0000>ooooo`;o000000?oooooo`000?l00000d?ooool000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000
ooooooooool07Oooool2o`0000?ooooo0_l00009ooooo`;o00002Oooool2o`0000Gooooo0_l0000:
ooooo`;o00000_ooool2o`0000Cooooo0_l00007ooooo`;o00004_ooool2o`000=?ooooo0003oooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
0002ooooo`Co00006?ooool2o`0001Sooooo0_l00005ooooo`;o00002_ooool3o`000003ooooool0
003o000000Cooooo0_l00007ooooo`;o00004_ooool2o`0002Kooooo0_l00025ooooo`;o00003?oo
ool2o`0001Kooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooo
oonHV9So<S8b00Kooooo00?o0000ooooooooool00_ooool4o`0001Sooooo0_l0000=ooooo`;o0000
3Oooool2o`000003ooooool0003o000000_ooooo1_l00003ooooo`;o00003?ooool2o`000004oooo
ool0003o0000o`0000Wooooo0_l0000Vooooo`;o0000;oooool2o`0002;ooooo0_l0000`ooooo`;o
00003?ooool2o`0001Kooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co
0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0;Oooool2o`0000_ooooo1?l00003oooo
o`;o00002?ooool7o`0000oooooo1?l000001?oooooo0000o`000?l0000Uooooo`;o00001Oooool2
o`0000[ooooo0_l0000Cooooo`;o00004oooool2o`0002;ooooo0_l0001Fooooo`000oooool01Ol@
413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oo
oooooooo01cooooo0_l00005ooooo`;o00003oooool3o`0000?ooooo0_l00002ooooo`Oo00000_oo
ool2o`0000;ooooo1?l0000Booooo`;o0000:oooool2o`0000Gooooo0_l0000:ooooo`Co00004Ooo
ool2o`0008oooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooo
oonj^[[o000000Kooooo00?o0000ooooooooool07?ooool2o`0000Gooooo0_l0000?ooooo`Ko0000
0_ooool5o`0000;ooooo0_l000001?oooooo0000o`000?l00004ooooo`;o00001_ooool2o`0000Go
oooo0_l0000gooooo`;o00003?ooool2o`000:;ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool09oooool2o`00
00;ooooo0_l00009ooooo`Co000000?oooooo`000?l000000_l00007ooooo`;o00003Oooool2o`00
00Gooooo0_l00003ooooo`;o00002_ooool2o`0002Kooooo0_l0002Pooooo`;o00003_ooool001ko
oooo00?o0000ooooooooool09oooool2o`0000;ooooo0_l00006ooooo`;o00001Oooool5o`0000go
oooo0_l0000Cooooo`;o00002?ooool4o`000;Kooooo0_l0000@ooooo`;o00003_ooool001kooooo
00?o0000ooooooooool00oooool2o`00017ooooo0_l00003ooooo`;o00001_ooool3o`0000gooooo
0_l00004ooooo`Co00003oooool4o`0000[ooooo0_l0000?ooooo`;o0000Yoooool2o`0000oooooo
0_l0000Pooooo`007_ooool00ol0003oooooooooo`03ooooo`;o00004Oooool2o`0000?ooooo0_l0
0006ooooo`?o00002_ooool2o`0000?ooooo2?l00006ooooo`;o00001?ooool2o`0000?ooooo0_l0
0004ooooo`;o00001?ooool2o`0000cooooo0_l0002Nooooo`;o00002_ooool2o`00037ooooo000N
ooooo`03o`000?oooooooooo02;ooooo0_l000000ooooooo0000o`000009ooooo`?o00000_ooool4
o`000003ooooool0003o000000?o00001?ooool2o`0000Cooooo0_l00009ooooo`Co00004?ooool2
o`0000kooooo0_l0002>ooooo`;o0000?Oooool001kooooo00?o0000ooooooooool08_ooool2o`00
0003ooooool0003o000000;ooooo0_l00006ooooo`;o00001oooool5o`000003ooooool0003o0000
00?ooooo0_l00002ooooo`;o00002?ooool2o`000003ooooool0003o000000;o00006Oooool2o`00
00?ooooo0_l0000/ooooo`;o0000>Oooool2o`0006Cooooo000Nooooo`03o`000?oooooooooo02Wo
oooo0_l00004ooooo`;o00001oooool2o`000004ooooool0003o0000o`0000;ooooo0_l000000ooo
oooo0000o`000002o`0000;ooooo1?l00003ooooo`;o000000Coooooo`000?l0003o00000_ooool5
o`0000Oooooo0_l0000=ooooo`;o0000<Oooool2o`0002Sooooo0_l0000?ooooo`;o0000I?ooool0
01kooooo00?o0000ooooooooool0:?ooool2o`0000Gooooo0ol00006ooooo`Co00001?ooool2o`00
0003ooooool0003o000000Cooooo1?l00002ooooo`?o00000_ooool2o`0000?ooooo1?l00007oooo
o`;o0000J_ooool2o`0007Gooooo000Nooooo`03o`000?oooooooooo027ooooo0_l00005ooooo`;o
00001Oooool3o`0000Sooooo1?l00003ooooo`;o00001_ooool2o`0000?ooooo0ol00005ooooo`;o
0000:Oooool2o`000<Cooooo000Nooooo`03o`000?oooooooooo01_ooooo0_l00004ooooo`?o0000
3?ooool2o`0000[ooooo0_l00003ooooo`;o00002oooool2o`0000Kooooo1?l0000Wooooo`?o0000
3oooool2o`000;;ooooo000Nooooo`03o`000?oooooooooo01_ooooo0_l00005ooooo`;o00003Ooo
ool2o`0000?ooooo0_l00004ooooo`Co00001?ooool2o`0000Sooooo0_l00008ooooo`;o0000:?oo
ool2o`0000_ooooo0_l00002ooooo`;o00001oooool2o`0009Gooooo0ol0000Aooooo`007_ooool0
0ol0003oooooooooo`0aooooo`;o00000_ooool3o`0000Cooooo1_l00002ooooo`;o00002?ooool2
o`0000;ooooo0_l0000kooooo`;o00002oooool2o`0009Gooooo0ol0000Aooooo`007_ooool2o`00
00Oooooo0_l0000]ooooo`;o00000oooool4o`0000;ooooo0_l00004ooooo`Go00001oooool2o`00
00Gooooo0_l00003ooooo`;o00009?ooool2o`0002_ooooo0_l0002Dooooo`007_ooool00ol0003o
ooooooooo`06ooooo`;o0000<_ooool4o`0000Cooooo0_l00002ooooo`Ko00003Oooool2o`0000?o
oooo0ol0000Fooooo`;o00002_ooool5o`0000Wooooo0_l0000Nooooo`;o0000U?ooool001kooooo
00?o0000ooooooooool0:?ooool2o`0000kooooo1?l00002ooooo`;o000000?oooooo`000?l00000
0_l00005ooooo`;o00001Oooool3o`0000Cooooo0ol00004ooooo`;o00000_ooool2o`0001;ooooo
0_l0000:ooooo`;o000000?oooooo`000?l000001?ooool3o`0000;ooooo0_l0000Yooooo`;o0000
I?ooool2o`0002?ooooo000Nooooo`03o`000?oooooooooo02Sooooo0_l0000>ooooo`;o00001?oo
ool2o`000003ooooool0003o000000;o00003?ooool3o`0000Cooooo0ol00004ooooo`;o00000_oo
ool2o`0000kooooo0_l0000:ooooo`;o00002oooool3o`0000cooooo0_l0000Oooooo`Co0000H_oo
ool2o`0002?ooooo000Nooooo`03o`000?oooooooooo03Cooooo0_l00008ooooo`;o00000_ooool4
o`000004ooooool0003o0000ooooo`Co00000oooool2o`0000?ooooo0_l0000:ooooo`;o00003ooo
ool2o`0000[ooooo0_l0000>ooooo`;o00002_ooool2o`00027ooooo0_l00027ooooo`007_ooool0
0ol0003oooooooooo`0`ooooo`;o00000_ooool2o`0000kooooo0_l000000ooooooo0000o`000006
o`0000?ooooo0_l00002ooooo`Co00002?ooool2o`0000Kooooo0_l0000Sooooo`;o00008?ooool2
o`0000Cooooo0_l0001aooooo`;o00006oooool001kooooo00?o0000ooooooooool0:?ooool2o`00
00Kooooo0_l0000Aooooo`co000000?oooooo`000?l000000_l00004ooooo`Co00003_ooool2o`00
00;ooooo0_l00011ooooo`;o00001?ooool2o`0002gooooo0_l0000Zooooo`;o00005_ooool2o`00
01_ooooo000Nooooo`03o`000?oooooooooo01_ooooo0_l00005ooooo`;o00001?ooool2o`0001Oo
oooo1ol000000ooooooo0000o`000003o`0000;ooooo1?l00003ooooo`Go00001Oooool2o`0000_o
oooo0_l0000aooooo`;o0000@oooool4o`0002Sooooo0_l0000cooooo`007_ooool00ol0003ooooo
ooooo`0Kooooo`;o00001Oooool2o`0000oooooo0_l0000<ooooo`;o00000oooool2o`000003oooo
ool0003o000000Oo000000Goooooo`000?l0003o0000ooooo`04o`0000Kooooo0_l0000@ooooo`;o
00001oooool2o`0000[ooooo0_l0000Booooo`;o00000oooool2o`0004Gooooo0_l0001Mooooo`00
7_ooool00ol0003oooooooooo`0Tooooo`;o000000?oooooo`000?l000002?ooool4o`0000[ooooo
1?l000000ooooooo0000o`000006o`000003ooooool0003o000000[o00006_ooool2o`0000Oooooo
0_l0000:ooooo`;o00004_ooool2o`000:Wooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l0
00000ooooooo0000o`000008ooooo`;o00001?ooool2o`0000Kooooo1?l000001?oooooo0000o`00
0?ooool5o`0000;ooooo1ol000001?oooooo0000o`000?l0000Dooooo`Co0000>oooool2o`0006;o
oooo0_l0000eooooo`007_ooool00ol0003oooooooooo`0gooooo`;o00000_ooool2o`0000Oooooo
2Ol000000ooooooo0000o`000005o`0000Wooooo0_l0000=ooooo`Co0000>oooool2o`0006;ooooo
0_l0000eooooo`007_ooool00ol0003oooooooooo`0Rooooo`;o00005oooool2o`000003ooooool0
003o000000Cooooo0ol00004ooooo`co00001oooool2o`0000kooooo1?l0000Dooooo`;o0000A?oo
ool2o`0004_ooooo0_l0000/ooooo`007_ooool00ol0003oooooooooo`0Rooooo`;o00003_ooool2
o`0000[ooooo0_l00004ooooo`;o00001?ooool2o`000003ooooool0003o000000Wo00000oooool2
o`0000?ooooo0_l0000=ooooo`?o00001Oooool2o`0000gooooo0_l0000eooooo`;o00003Oooool2
o`0004_ooooo0_l0000/ooooo`007_ooool00ol0003oooooooooo`0Rooooo`Co00003?ooool2o`00
0003ooooool0003o000000cooooo0ol00004ooooo`Wo000000?oooooo`000?l000000_l00003oooo
o`;o00000oooool3o`0000;ooooo0_l00008ooooo`Oo000000?oooooo`000?l00000:oooool2o`00
01Oooooo0_l00028ooooo`007_ooool00ol0003oooooooooo`0Tooooo`;o00003oooool2o`0000Ko
oooo0_l00004ooooo`Go00000oooool7o`0000;ooooo0_l00005ooooo`;o00001?ooool2o`0000;o
oooo1?l00007ooooo`[o00003Oooool2o`0001Oooooo0_l00002ooooo`;o0000XOooool001kooooo
0_l0000fooooo`;o00001_ooool2o`0000Cooooo2?l00003ooooo`Co00000_ooool2o`000003oooo
ool0003o000000;o00000_ooool2o`000004ooooool0003o0000o`0000Cooooo0_l0000<ooooo`Go
00003Oooool2o`0001Oooooo0_l0000Oooooo`Co00006_ooool2o`0000Cooooo0ol0001Oooooo`00
7_ooool00ol0003oooooooooo`0dooooo`;o00003Oooool2o`0000;ooooo1_l000000ooooooo0000
o`000002o`0000;ooooo0_l000000ooooooo0000o`000006o`000003ooooool0003o000000;o0000
0_ooool2o`0000?ooooo0_l00003ooooo`;o0000=_ooool2o`0001Oooooo1?l0000Jooooo`;o0000
1?ooool3o`0002?ooooo0_l0000jooooo`007_ooool00ol0003oooooooooo`0Wooooo`;o00001?oo
ool2o`0000Gooooo0_l0000Aooooo`So00001Oooool2o`0000Gooooo1Ol000001?oooooo0000o`00
0?l00002ooooo`;o00000oooool2o`0000?ooooo0_l00002ooooo`;o00009_ooool2o`0000[ooooo
0_l00009ooooo`;o0000E_ooool2o`0003[ooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l0
0004ooooo`;o00006?ooool3o`0000;ooooo0ol00005ooooo`;o00000_ooool2o`0000Cooooo1Ol0
0006ooooo`;o00002?ooool3o`0002Kooooo0_l0000Eooooo`;o0000T_ooool001kooooo00?o0000
ooooooooool0<Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool3o`0000;ooooo0ol00009
ooooo`;o00001?ooool4o`0000Oooooo0_l00008ooooo`;o0000`_ooool2o`0000kooooo000Noooo
o`03o`000?oooooooooo037ooooo0_l00006ooooo`;o00001Oooool2o`0000?ooooo0_l0000Goooo
o`;o00000oooool2o`0000Sooooo1?l0001:ooooo`;o0000N_ooool2o`0000kooooo000Nooooo`03
o`000?oooooooooo01Sooooo0_l0000@ooooo`;o00001Oooool2o`0001;ooooo0_l0000@ooooo`;o
00002_ooool2o`0000Sooooo1Ol0000@ooooo`;o0000=oooool2o`0008[ooooo000Nooooo`03o`00
0?oooooooooo01Sooooo0_l0000@ooooo`;o00001Oooool2o`0000Sooooo0_l0000Jooooo`;o0000
5?ooool2o`000004ooooool0003o0000ooooo`;o00003Oooool2o`000<?ooooo000Nooooo`03o`00
0?oooooooooo02[ooooo0_l00008ooooo`;o00001Oooool2o`0000Cooooo0_l0000;ooooo`;o0000
4?ooool2o`0000[ooooo0ol00004ooooo`;o00002Oooool2o`000<Oooooo000Nooooo`03o`000?oo
oooooooo02[ooooo0_l00008ooooo`;o00001Oooool2o`000003ooooool0003o000000?o00002ooo
ool2o`0000Wooooo0_l00005ooooo`;o00002_ooool2o`00013ooooo0_l0000dooooo`;o00007_oo
ool2o`00077ooooo000Nooooo`03o`000?oooooooooo01Sooooo0_l0000Aooooo`;o00001oooool2
o`0000Sooooo0ol0000=ooooo`;o00000oooool2o`0000Cooooo0_l00004ooooo`;o00006Oooool2
o`0000Kooooo0_l0000`ooooo`;o00007_ooool2o`00077ooooo000Nooooo`03o`000?oooooooooo
01Sooooo0_l0000Aooooo`;o00000_ooool3o`0000Cooooo0_l0000;ooooo`;o00003_ooool5o`00
00Oooooo0_l0000Iooooo`;o00001_ooool2o`0000cooooo0_l0002>ooooo`;o00009Oooool001ko
oooo00?o0000ooooooooool0;oooool3o`0000Cooooo0_l00006ooooo`;o00000oooool2o`0000Co
oooo0_l0000:ooooo`?o00002?ooool2o`0000Gooooo0_l0000Wooooo`;o00002_ooool2o`0008;o
oooo0_l0000Uooooo`007_ooool00ol0003oooooooooo`0booooo`;o00001oooool2o`000003oooo
ool0003o000000Wooooo0_l0000Eooooo`;o00001Oooool2o`000003ooooool0003o000000Gooooo
0_l0000Pooooo`;o00001oooool2o`0001Gooooo0_l0002Booooo`007_ooool00ol0003ooooooooo
o`0booooo`;o00001oooool2o`0001Gooooo0_l0000Fooooo`;o00001Oooool2o`00023ooooo0_l0
000Nooooo`;o00008_ooool2o`0000gooooo0_l0001Oooooo`007_ooool00ol0003oooooooooo`0h
ooooo`Co00001?ooool2o`000003ooooool0003o000000?o00002_ooool2o`0000[ooooo0_l00005
ooooo`Co0000K_ooool2o`0000gooooo0_l0001Oooooo`007_ooool2o`0003Wooooo1?l00004oooo
o`;o000000?oooooo`000?l000001?l00008ooooo`;o00002Oooool4o`0000Gooooo1?l0003Noooo
o`007_ooool00ol0003oooooooooo`04ooooo`;o0000;Oooool2o`0000Cooooo0_l00009ooooo`Go
00002?ooool2o`0000Wooooo0_l0003Yooooo`007_ooool00ol0003oooooooooo`04ooooo`;o0000
;Oooool2o`0000?ooooo0ol00009ooooo`Co00001?ooool2o`0001Gooooo0_l0000Tooooo`;o0000
@Oooool2o`0007Wooooo000Nooooo`03o`000?oooooooooo017ooooo0_l0000Pooooo`;o00000ooo
ool2o`0000[ooooo0_l00006ooooo`;o00001_ooool2o`0000gooooo0_l0000Tooooo`;o0000@Ooo
ool2o`0004Cooooo0_l0000cooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o00007?ooool2
o`0000Oooooo0_l0000:ooooo`;o00003_ooool2o`0000cooooo0_l0002^ooooo`;o0000<oooool0
01kooooo00?o0000ooooooooool02oooool2o`0002;ooooo0_l0000aooooo`;o00008oooool3o`00
06Sooooo0_l0001Cooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o00008_ooool2o`0002?o
oooo0_l0000<ooooo`;o00001?ooool2o`0001gooooo0ol00003ooooo`;o0000?_ooool2o`0002?o
oooo0_l0001Cooooo`007_ooool00ol0003oooooooooo`06ooooo`;o00002_ooool2o`0001[ooooo
0_l0000Gooooo`;o00000oooool2o`0000Kooooo0_l0000Booooo`;o00008oooool2o`00017ooooo
0_l00009ooooo`;o00008?ooool2o`0007Sooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l0
000:ooooo`;o00006_ooool2o`0001Cooooo0_l000001?oooooo0000o`000?ooool4o`0000Wooooo
0_l000000ooooooo0000o`00000[ooooo`;o00005oooool2o`0000Wooooo0_l0002Jooooo`007_oo
ool00ol0003oooooooooo`14ooooo`;o00001?ooool2o`0000_ooooo0_l000000ooooooo0000o`00
000[ooooo`;o0000O?ooool2o`00043ooooo000Nooooo`03o`000?oooooooooo04kooooo0_l00007
ooooo`;o00002Oooool2o`000:7ooooo0_l00002ooooo`;o0000??ooool001kooooo00?o0000oooo
ooooool03?ooool2o`00033ooooo0_l000000ooooooo0000o`00000;ooooo`;o00004_ooool2o`00
02Wooooo0_l0001jooooo`;o0000??ooool001kooooo00?o0000ooooooooool03?ooool2o`00017o
oooo0_l0000@ooooo`;o00002oooool2o`000003ooooool0003o000003Cooooo0_l00005ooooo`;o
00003Oooool2o`000;Sooooo000Nooooo`03o`000?oooooooooo01oooooo0_l0000@ooooo`;o0000
6_ooool2o`0001Cooooo0_l0000Booooo`;o00001Oooool2o`0000_ooooo0_l0002jooooo`005?oo
ool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool05?ooool2o`0003Oooooo0_l0
0004ooooo`;o00003_ooool2o`0002?ooooo0_l000000ooooooo0000o`00002jooooo`005_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Cooooo0_l0000mooooo`;o00001Oooool2
o`0002cooooo0_l0002mooooo`005_ooool00ol0003oooooooooo`05ooooo`?o0000=_ooool2o`00
02;ooooo0_l0000Xooooo`;o00000_ooool2o`000;gooooo000Fooooo`03o`000?oooooooooo03ko
oooo0_l0001<ooooo`;o0000`Oooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_oo
ool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool0
01Cooooo00?oEEEEofIVI_l00000oooooomBooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.33999 .89401 Mdot
.31425 .11148 Mdot
.29074 .88531 Mdot
.32154 .8737 Mdot
.20049 .76391 Mdot
.28321 .85531 Mdot
.54768 .6942 Mdot
.17077 .82473 Mdot
.27362 .87579 Mdot
.23943 .73564 Mdot
.20659 .72653 Mdot
.32542 .70737 Mdot
.21451 .84581 Mdot
.61063 .85952 Mdot
.24531 .87678 Mdot
.14299 .26752 Mdot
.05823 .54356 Mdot
.31436 .86291 Mdot
.35616 .91026 Mdot
.3126 .86474 Mdot
.72215 .94958 Mdot
.25126 .8916 Mdot
.22969 .92342 Mdot
.15112 .77826 Mdot
.24589 .87717 Mdot
.13922 .84558 Mdot
.25306 .92187 Mdot
.18822 .02125 Mdot
.22918 .70122 Mdot
.29087 .93915 Mdot
.35406 .88281 Mdot
.25021 .86715 Mdot
.15228 .91687 Mdot
.0492 .53061 Mdot
.39725 .89323 Mdot
.23808 .77221 Mdot
.5349 .85826 Mdot
.27439 .72051 Mdot
.36165 .73748 Mdot
.24786 .90709 Mdot
.36176 .90258 Mdot
.50344 .80664 Mdot
.16928 .85533 Mdot
.88019 .79342 Mdot
.56094 .95855 Mdot
.51355 .79556 Mdot
.58686 .97445 Mdot
.30506 .16543 Mdot
.20927 .80695 Mdot
.30438 .67234 Mdot
.41455 .89608 Mdot
.40408 .04198 Mdot
.15387 .79932 Mdot
.22318 .68887 Mdot
.17896 .80911 Mdot
.08531 .46574 Mdot
.65547 .81583 Mdot
.18621 .8176 Mdot
.25134 .92268 Mdot
.06252 .85038 Mdot
.30126 .89947 Mdot
.16701 .83715 Mdot
.13581 .76016 Mdot
.21898 .85414 Mdot
.27667 .80971 Mdot
.28714 .84664 Mdot
.46702 .98504 Mdot
.25119 .92368 Mdot
.27709 .85202 Mdot
.08084 .89367 Mdot
.37835 .89602 Mdot
.11578 .6313 Mdot
.30735 .89791 Mdot
.26744 .66746 Mdot
.16565 .8848 Mdot
.67404 .8457 Mdot
.27232 .00922 Mdot
.5063 .43397 Mdot
.26063 .89431 Mdot
.98315 .80286 Mdot
.38985 .08674 Mdot
.62027 .38246 Mdot
.86612 .28891 Mdot
.16953 .8288 Mdot
.65626 .71589 Mdot
.61099 .91259 Mdot
.16699 .8008 Mdot
.26019 .93052 Mdot
.25839 .86002 Mdot
.98712 .74232 Mdot
.17499 .78505 Mdot
.5988 .95861 Mdot
.1945 .62598 Mdot
.91154 .68729 Mdot
.26803 .9287 Mdot
.316 .11559 Mdot
.88334 .72559 Mdot
.44031 .98555 Mdot
.13855 .75059 Mdot
.0028 .62696 Mdot
.19559 .8842 Mdot
.46193 .96038 Mdot
.17658 .91587 Mdot
.33951 .01241 Mdot
.38892 .0316 Mdot
.223 .90796 Mdot
.15652 .20882 Mdot
.15431 .25962 Mdot
.31463 .05011 Mdot
.83318 .77474 Mdot
.53006 .90321 Mdot
.81196 .52109 Mdot
.18693 .10914 Mdot
.32587 .85658 Mdot
.49167 .02999 Mdot
.49995 .70132 Mdot
.60496 .9325 Mdot
.21844 .86807 Mdot
.15696 .51941 Mdot
.10782 .0562 Mdot
.23981 .93335 Mdot
.31969 .09713 Mdot
.14426 .96993 Mdot
.91754 .6164 Mdot
.5835 .90107 Mdot
.01328 .07934 Mdot
.32613 .82871 Mdot
.35116 .90722 Mdot
.04659 .54453 Mdot
.11772 .04904 Mdot
.46985 .06636 Mdot
.49059 .50447 Mdot
.36158 .27684 Mdot
.28564 .93844 Mdot
.36784 .91456 Mdot
.33332 .89009 Mdot
.22144 .89748 Mdot
.18272 .69825 Mdot
.38843 .85232 Mdot
.29837 .85009 Mdot
.36847 .8912 Mdot
.1935 .83376 Mdot
.20925 .90776 Mdot
.02183 .61435 Mdot
.07523 .99448 Mdot
.31428 .71 Mdot
.30604 .92621 Mdot
.22415 .90783 Mdot
.76352 .0216 Mdot
.7553 .42461 Mdot
.14126 .79615 Mdot
.17352 .94075 Mdot
.33869 .72009 Mdot
.30602 .87201 Mdot
.24478 .89077 Mdot
.18084 .84331 Mdot
.22277 .707 Mdot
.60495 .35442 Mdot
.28736 .88917 Mdot
.11566 .25417 Mdot
.20601 .7041 Mdot
.27179 .67886 Mdot
.54727 .75066 Mdot
.25285 .97612 Mdot
.15571 .75042 Mdot
.17871 .77796 Mdot
.22113 .9065 Mdot
.28269 .90634 Mdot
.33627 .59311 Mdot
.24569 .85048 Mdot
.17453 .96068 Mdot
.34232 .95274 Mdot
.38149 .79521 Mdot
.47653 .94312 Mdot
.30235 .88839 Mdot
.30989 .64413 Mdot
.9994 .88138 Mdot
.14614 .85123 Mdot
.48374 .94533 Mdot
.41352 .02767 Mdot
.16171 .76821 Mdot
.19992 .73119 Mdot
.28262 .85428 Mdot
.62775 .91266 Mdot
.1871 .34916 Mdot
.39243 .02645 Mdot
.1253 .21059 Mdot
.1391 .77841 Mdot
.07087 .62259 Mdot
.03917 .72651 Mdot
.32051 .89957 Mdot
.69629 .86284 Mdot
.35097 .90236 Mdot
.23519 .94498 Mdot
.15363 .05619 Mdot
.10994 .83528 Mdot
.24972 .65587 Mdot
.24669 .85549 Mdot
.26473 .87527 Mdot
.14513 .94164 Mdot
.29342 .70874 Mdot
.53377 .20738 Mdot
.31421 .94319 Mdot
.57159 .98178 Mdot
.2412 .8738 Mdot
.26587 .92723 Mdot
.96041 .07705 Mdot
.25109 .93585 Mdot
.90673 .7097 Mdot
.23793 .64266 Mdot
.22726 .80404 Mdot
.35267 .88794 Mdot
.62428 .68362 Mdot
.40978 .4821 Mdot
.19485 .70583 Mdot
.22718 .19599 Mdot
.23854 .90422 Mdot
.16178 .9552 Mdot
.24622 .85807 Mdot
.54826 .85127 Mdot
.97463 .03504 Mdot
.18759 .89532 Mdot
.15972 .8002 Mdot
.28944 .89515 Mdot
.98703 .74539 Mdot
.20024 .60654 Mdot
.12084 .97957 Mdot
.26477 .92918 Mdot
.14202 .08367 Mdot
.23569 .88693 Mdot
.15416 .85088 Mdot
.03725 .82316 Mdot
.18207 .93123 Mdot
.35045 .71099 Mdot
.2368 .28964 Mdot
.93552 .66948 Mdot
.80408 .29405 Mdot
.30459 .88333 Mdot
.73707 .68837 Mdot
.82617 .89613 Mdot
.25599 .77485 Mdot
.19021 .92586 Mdot
.36384 .0597 Mdot
.27075 .86145 Mdot
.39129 .7658 Mdot
.16216 .04848 Mdot
.1199 .76334 Mdot
.20536 .95153 Mdot
.70714 .31301 Mdot
.34706 .92014 Mdot
.38181 .03821 Mdot
.18244 .81587 Mdot
.60858 .3552 Mdot
.13602 .09611 Mdot
.22209 .13719 Mdot
.2419 .12844 Mdot
.15531 .79028 Mdot
.72811 .84928 Mdot
.44287 .0261 Mdot
.78436 .8338 Mdot
.34513 .89058 Mdot
.32807 .84836 Mdot
.21785 .82862 Mdot
.9309 .70785 Mdot
.18743 .92458 Mdot
.03583 .76064 Mdot
.3263 .08438 Mdot
.65881 .93636 Mdot
.275 .88684 Mdot
.2545 .92166 Mdot
.14271 .75287 Mdot
.65237 .84734 Mdot
.2903 .90623 Mdot
.31611 .86899 Mdot
.4143 .04128 Mdot
.19627 .83645 Mdot
.25887 .91 Mdot
.47549 .50756 Mdot
.22246 .7268 Mdot
.40965 .98281 Mdot
.56818 .76264 Mdot
.23877 .90981 Mdot
.23171 .99703 Mdot
.52961 .71493 Mdot
.17324 .77395 Mdot
.16627 .80657 Mdot
.2645 .85854 Mdot
.94559 .73269 Mdot
.20289 .02945 Mdot
.32406 .91667 Mdot
.2958 .03496 Mdot
.77062 .64674 Mdot
.36674 .9159 Mdot
.01948 .97599 Mdot
.144 .02964 Mdot
.02161 .65316 Mdot
.24285 .8349 Mdot
.16974 .07299 Mdot
.52077 .88283 Mdot
.11261 .30365 Mdot
.89567 .80254 Mdot
.09142 .79031 Mdot
.32497 .7457 Mdot
.13237 .60548 Mdot
.87325 .21686 Mdot
.20623 .99107 Mdot
.25717 .91769 Mdot
.2516 .90967 Mdot
.50553 .57617 Mdot
.50476 .16139 Mdot
.24747 .9372 Mdot
.59648 .04654 Mdot
.14337 .8515 Mdot
.1688 .81551 Mdot
.22951 .80908 Mdot
.20447 .79345 Mdot
.34179 .66345 Mdot
.91224 .00604 Mdot
.09321 .87058 Mdot
.04176 .42694 Mdot
.35625 .75848 Mdot
.15757 .9389 Mdot
.42108 .03318 Mdot
.27164 .71933 Mdot
.35223 .86982 Mdot
.1593 .84972 Mdot
.22261 .7355 Mdot
.3434 .88655 Mdot
.29974 .70821 Mdot
.1552 .84555 Mdot
.26841 .84192 Mdot
.29037 .84341 Mdot
.36892 .3248 Mdot
.74388 .97627 Mdot
.31291 .67581 Mdot
.26601 .96777 Mdot
.64421 .75407 Mdot
.24767 .92729 Mdot
.13667 .31983 Mdot
.25977 .96947 Mdot
.15474 .75805 Mdot
.40377 .4867 Mdot
.36236 .8835 Mdot
.12795 .6305 Mdot
.93501 .526 Mdot
.15869 .21197 Mdot
.93515 .76106 Mdot
.18446 .46622 Mdot
.43359 .067 Mdot
.17313 .82071 Mdot
.24336 .88328 Mdot
.16398 .7942 Mdot
.21516 .73753 Mdot
.25097 .24199 Mdot
.88552 .18282 Mdot
.29064 .90606 Mdot
.49157 .83684 Mdot
.25578 .02213 Mdot
.21897 .82717 Mdot
.15259 .92853 Mdot
.22044 .92609 Mdot
.35829 .80378 Mdot
.36262 .8891 Mdot
.22237 .81466 Mdot
.12883 .79318 Mdot
.4083 .99632 Mdot
.33325 .13012 Mdot
.0269 .47414 Mdot
.40215 .37714 Mdot
.29474 .88943 Mdot
.19896 .73001 Mdot
.2636 .91239 Mdot
.29759 .90779 Mdot
.27466 .8588 Mdot
.8438 .8782 Mdot
.99947 .7034 Mdot
.52058 .93838 Mdot
.23176 .84868 Mdot
.71641 .25397 Mdot
.24991 .96544 Mdot
.26483 .88687 Mdot
.28093 .82785 Mdot
.22997 .30818 Mdot
.57857 .17404 Mdot
.23736 .77298 Mdot
.28542 .95376 Mdot
.154 .12221 Mdot
.83149 .99966 Mdot
.25145 .92462 Mdot
.09722 .86207 Mdot
.36818 .89133 Mdot
.23697 .77967 Mdot
.19046 .89045 Mdot
.20586 .77921 Mdot
.20902 .76916 Mdot
.03437 .70345 Mdot
.11094 .60786 Mdot
.11386 .72109 Mdot
.24926 .92663 Mdot
.36145 .8724 Mdot
.16416 .87608 Mdot
.53195 .0261 Mdot
.52933 .6452 Mdot
.16829 .83448 Mdot
.28461 .54033 Mdot
.06331 .0837 Mdot
.33079 .97613 Mdot
.04675 .68711 Mdot
.22164 .61649 Mdot
.25041 .97102 Mdot
.17129 .68973 Mdot
.27602 .90052 Mdot
.19461 .70076 Mdot
.09284 .74478 Mdot
.56325 .03835 Mdot
.28482 .87062 Mdot
.10204 .98532 Mdot
.19597 .61037 Mdot
.17238 .24596 Mdot
.25698 .89761 Mdot
.26365 .91696 Mdot
.72507 .26828 Mdot
.90698 .60377 Mdot
.24747 .80023 Mdot
.17564 .82264 Mdot
.36358 .59528 Mdot
.35586 .70602 Mdot
.26876 .87143 Mdot
.12536 .64643 Mdot
.82646 .65998 Mdot
.1672 .64032 Mdot
.67345 .08605 Mdot
.52557 .63488 Mdot
.26562 .82562 Mdot
.39342 .19556 Mdot
.38881 .1764 Mdot
.24993 .82546 Mdot
.04069 .16781 Mdot
.24105 .98461 Mdot
.54269 .92354 Mdot
.29712 .09101 Mdot
.73721 .03798 Mdot
.66392 .02766 Mdot
.28362 .90543 Mdot
.1483 .64078 Mdot
.25499 .9208 Mdot
.13719 .92319 Mdot
.23096 .76903 Mdot
.2208 .78625 Mdot
.23382 .05108 Mdot
.00871 .88974 Mdot
.30011 .02962 Mdot
.16362 .77374 Mdot
.2742 .89171 Mdot
.22386 .88742 Mdot
.24809 .93444 Mdot
.2622 .8851 Mdot
.22649 .72198 Mdot
.03414 .58853 Mdot
.1977 .29222 Mdot
.33197 .81014 Mdot
.26327 .93572 Mdot
.27135 .88195 Mdot
.19734 .85811 Mdot
.39855 .68549 Mdot
.44863 .9665 Mdot
.15304 .92708 Mdot
.67033 .17778 Mdot
.26173 .90093 Mdot
.38274 .97744 Mdot
.29009 .90473 Mdot
.16555 .81725 Mdot
.16976 .82923 Mdot
.16958 .82887 Mdot
.29 .81672 Mdot
.25275 .87364 Mdot
.245 .77752 Mdot
.17044 .82505 Mdot
.9425 .57315 Mdot
.14809 .84833 Mdot
.42125 .15571 Mdot
.15345 .95899 Mdot
.21264 .91267 Mdot
.37772 .88415 Mdot
.33758 .89714 Mdot
.68315 .96094 Mdot
.44949 .17122 Mdot
.20938 .172 Mdot
.32581 .88623 Mdot
.19999 .04004 Mdot
.30212 .9102 Mdot
.28203 .90584 Mdot
.24498 .51349 Mdot
.20025 .15907 Mdot
.20754 .82955 Mdot
.23943 .87705 Mdot
.09117 .9072 Mdot
.11981 .89068 Mdot
.73981 .70784 Mdot
.30658 .65939 Mdot
.10488 .98192 Mdot
.18829 .06918 Mdot
.31002 .92805 Mdot
.16531 .47559 Mdot
.28412 .84844 Mdot
.45373 .70546 Mdot
.1623 .82792 Mdot
.79721 .89838 Mdot
.26567 .89247 Mdot
.31275 .937 Mdot
.38068 .8944 Mdot
.01793 .27327 Mdot
.22903 .43138 Mdot
.24592 .05078 Mdot
.18921 .77046 Mdot
.7922 .6706 Mdot
.22828 .75329 Mdot
.30798 .11654 Mdot
.37326 .92784 Mdot
.36784 .8678 Mdot
.28182 .02243 Mdot
.26081 .83582 Mdot
.26371 .89087 Mdot
.14889 .94909 Mdot
.99078 .62276 Mdot
.26526 .82356 Mdot
.11213 .61667 Mdot
.35097 .05255 Mdot
.13917 .74663 Mdot
.01981 .67692 Mdot
.75166 .43934 Mdot
.19092 .95463 Mdot
.18177 .76863 Mdot
.37329 .7773 Mdot
.16844 .82903 Mdot
.20579 .89025 Mdot
.28371 .80738 Mdot
.15948 .85915 Mdot
.06639 .74644 Mdot
.12756 .91395 Mdot
.29875 .84902 Mdot
.46007 .08761 Mdot
.2824 .72352 Mdot
.25026 .88331 Mdot
.36661 .88329 Mdot
.89725 .67499 Mdot
.14635 .72664 Mdot
.32343 .99726 Mdot
.2356 .95166 Mdot
.16113 .84528 Mdot
.07156 .81467 Mdot
.35919 .71623 Mdot
.16083 .89359 Mdot
.2447 .50945 Mdot
.38722 .10522 Mdot
.67224 .40512 Mdot
.18745 .15548 Mdot
.24152 .92892 Mdot
.24124 .76469 Mdot
.48935 .96407 Mdot
.24142 .9346 Mdot
.08427 .85646 Mdot
.26535 .73355 Mdot
.10169 .59584 Mdot
.26898 .8532 Mdot
.21076 .76764 Mdot
.20878 .67126 Mdot
.15632 .78526 Mdot
.55649 .43547 Mdot
.26231 .85859 Mdot
.20514 .14264 Mdot
.30217 .03672 Mdot
.25526 .86864 Mdot
.32547 .89851 Mdot
.2365 .79037 Mdot
.23616 .88881 Mdot
.10206 .19414 Mdot
.22553 .70195 Mdot
.19165 .82886 Mdot
.10962 .98635 Mdot
.80878 .73191 Mdot
.52827 .92963 Mdot
.29182 .76997 Mdot
.38168 .88996 Mdot
.23237 .73572 Mdot
.2606 .88095 Mdot
.35447 .05884 Mdot
.51023 .51504 Mdot
.23356 .00784 Mdot
.24904 .9419 Mdot
.17283 .8251 Mdot
.1939 .80532 Mdot
.17304 .61644 Mdot
.13176 .92484 Mdot
.36965 .73146 Mdot
.14891 .85467 Mdot
.282 .70982 Mdot
.16063 .84007 Mdot
.24835 .83449 Mdot
.23303 .02254 Mdot
.21395 .90768 Mdot
.26866 .91184 Mdot
.2916 .91144 Mdot
.44082 .97703 Mdot
.19724 .72255 Mdot
.24479 .99129 Mdot
.2411 .9211 Mdot
.25077 .92182 Mdot
.90252 .6774 Mdot
.34257 .89633 Mdot
.35936 .77071 Mdot
.50493 .19067 Mdot
.29009 .87743 Mdot
.88163 .80576 Mdot
.35359 .89169 Mdot
.13865 .25562 Mdot
.12755 .64554 Mdot
.91488 .01088 Mdot
.12154 .7579 Mdot
.55061 .91619 Mdot
.37988 .50443 Mdot
.15426 .17707 Mdot
.34142 .90146 Mdot
.36946 .16498 Mdot
.47025 .93317 Mdot
.24709 .09757 Mdot
.03802 .57221 Mdot
.65336 .56928 Mdot
.22258 .86047 Mdot
.51273 .87859 Mdot
.35748 .81542 Mdot
.28977 .89797 Mdot
.18163 .91985 Mdot
.55402 .78062 Mdot
.25744 .86684 Mdot
.92015 .38972 Mdot
.16886 .8274 Mdot
.13716 .59554 Mdot
.23307 .7721 Mdot
.25031 .87244 Mdot
.30282 .85935 Mdot
.27139 .85754 Mdot
.50672 .84666 Mdot
.54081 .81859 Mdot
.18295 .52321 Mdot
.33446 .98397 Mdot
.3738 .81798 Mdot
.8814 .6052 Mdot
.1675 .83258 Mdot
.97915 .67512 Mdot
.20699 .65563 Mdot
.13998 .81256 Mdot
.16028 .07059 Mdot
.28984 .8899 Mdot
.05853 .65332 Mdot
.25341 .90725 Mdot
.16357 .80188 Mdot
.40468 .86477 Mdot
.90065 .70467 Mdot
.24848 .9309 Mdot
.52807 .9239 Mdot
.19539 .95925 Mdot
.8101 .99862 Mdot
.22748 .91965 Mdot
.51763 .68922 Mdot
.09651 .89799 Mdot
.25384 .90356 Mdot
.9686 .8545 Mdot
.00261 .62617 Mdot
.17305 .13092 Mdot
.91209 .60644 Mdot
.49036 .48418 Mdot
.42631 .89964 Mdot
.2382 .98451 Mdot
.71565 .59275 Mdot
.15585 .84426 Mdot
.68304 .99757 Mdot
.24156 .78925 Mdot
.91579 .8686 Mdot
.67953 .91626 Mdot
.02448 .55193 Mdot
.02499 .63962 Mdot
.51301 .32102 Mdot
.34405 .90979 Mdot
.26195 .85908 Mdot
.33966 .72073 Mdot
.4786 .86488 Mdot
.71512 .01862 Mdot
.02289 .943 Mdot
.29167 .84342 Mdot
.25753 .14832 Mdot
.58744 .99534 Mdot
.17918 .81705 Mdot
.31618 .09342 Mdot
.17877 .93349 Mdot
.19572 .9795 Mdot
.27652 .88584 Mdot
.12606 .99398 Mdot
.54961 .86261 Mdot
.61292 .70123 Mdot
.15908 .65481 Mdot
.29619 .25693 Mdot
.1913 .84949 Mdot
.39141 .85509 Mdot
.35464 .05079 Mdot
.1436 .9622 Mdot
.28372 .64931 Mdot
.38542 .65993 Mdot
.28581 .08416 Mdot
.23537 .87723 Mdot
.83666 .02847 Mdot
.07659 .69808 Mdot
.53174 .09138 Mdot
.73622 .49218 Mdot
.24259 .91657 Mdot
.83951 .70782 Mdot
.21197 .93215 Mdot
.19586 .788 Mdot
.45249 .39366 Mdot
.18045 .94934 Mdot
.34801 .88483 Mdot
.5173 .78569 Mdot
.2861 .00907 Mdot
.9955 .75656 Mdot
.44666 .17747 Mdot
.79347 .00096 Mdot
.67452 .93608 Mdot
.23304 .92925 Mdot
.52057 .83003 Mdot
.86894 .58545 Mdot
.1817 .97926 Mdot
.19549 .97751 Mdot
.18953 .86098 Mdot
.29443 .86705 Mdot
.16153 .23354 Mdot
.97917 .15883 Mdot
.99597 .59266 Mdot
.10507 .21541 Mdot
.34517 .78298 Mdot
.08667 .92674 Mdot
.21168 .8001 Mdot
.31668 .84394 Mdot
.28297 .8803 Mdot
.74686 .66243 Mdot
.88202 .68233 Mdot
.33865 .82883 Mdot
.25941 .96522 Mdot
.67839 .76032 Mdot
.08047 .84429 Mdot
.60195 .68456 Mdot
.37166 .97318 Mdot
.31678 .88007 Mdot
.02066 .03523 Mdot
.33978 .86473 Mdot
.32577 .98906 Mdot
.15299 .75762 Mdot
.25375 .8107 Mdot
.4387 .03296 Mdot
.22518 .7805 Mdot
.31718 .90451 Mdot
.3265 .84365 Mdot
.17124 .82584 Mdot
.33221 .59047 Mdot
.31352 .86187 Mdot
.32821 .0802 Mdot
.32638 .8898 Mdot
.99672 .60376 Mdot
.73923 .21609 Mdot
.24397 .85474 Mdot
.42016 .40051 Mdot
.21518 .8359 Mdot
.19943 .76893 Mdot
.22603 .91828 Mdot
.18234 .81562 Mdot
.53879 .50831 Mdot
.39048 .88002 Mdot
.09445 .82978 Mdot
.30157 .9082 Mdot
.22213 .9091 Mdot
.46058 .24466 Mdot
.3212 .86581 Mdot
.20592 .10932 Mdot
.93632 .78551 Mdot
.0437 .1148 Mdot
.24951 .85184 Mdot
.24034 .84515 Mdot
.17867 .2336 Mdot
.29895 .85231 Mdot
.2835 .90527 Mdot
.17094 .8528 Mdot
.42948 .99641 Mdot
.39385 .39142 Mdot
.32816 .57523 Mdot
.12975 .84452 Mdot
.1976 .67994 Mdot
.16131 .80262 Mdot
.22888 .05834 Mdot
.52283 .0149 Mdot
.27068 .80624 Mdot
.05333 .7031 Mdot
.54528 .12953 Mdot
.26163 .93551 Mdot
.28711 .76874 Mdot
.14984 .04826 Mdot
.04567 .75149 Mdot
.31084 .884 Mdot
.09872 .68786 Mdot
.15224 .806 Mdot
.08392 .5906 Mdot
.29077 .0207 Mdot
.98085 .67641 Mdot
.25874 .80485 Mdot
.24525 .84608 Mdot
.31858 .01339 Mdot
.13872 .77404 Mdot
.26917 .9059 Mdot
.47712 .44231 Mdot
.64119 .98035 Mdot
.24508 .89294 Mdot
.77221 .73754 Mdot
.16871 .8276 Mdot
.16573 .83033 Mdot
.07409 .81511 Mdot
.18117 .8418 Mdot
.17505 .81262 Mdot
.22841 .76512 Mdot
.14651 .80167 Mdot
.13469 .75356 Mdot
.68377 .37728 Mdot
.22806 .03074 Mdot
.55715 .90542 Mdot
.91924 .76083 Mdot
.23726 .81156 Mdot
.84313 .70124 Mdot
.5148 .78526 Mdot
.24546 .93849 Mdot
.00126 .24929 Mdot
.20971 .81119 Mdot
.11106 .80929 Mdot
.71671 .92513 Mdot
.45541 .8278 Mdot
.16468 .83273 Mdot
.25554 .91844 Mdot
.28535 .86727 Mdot
.67503 .8828 Mdot
.13343 .63295 Mdot
.58585 .12218 Mdot
.23708 .88779 Mdot
.1519 .85058 Mdot
.32431 .87917 Mdot
.26379 .76864 Mdot
.02329 .72084 Mdot
.36886 .91125 Mdot
.23037 .98377 Mdot
.22387 .9236 Mdot
.32461 .12981 Mdot
.16948 .82702 Mdot
.30027 .35048 Mdot
.11499 .85601 Mdot
.24612 .85489 Mdot
.16609 .8313 Mdot
.31871 .89223 Mdot
.22998 .88239 Mdot
.11183 .64251 Mdot
.13742 .85576 Mdot
.1934 .75294 Mdot
.34709 .90606 Mdot
.25441 .84971 Mdot
.96678 .90038 Mdot
.17244 .83091 Mdot
.77504 .85451 Mdot
.22313 .93311 Mdot
.2167 .8495 Mdot
.29964 .77734 Mdot
.44577 .03557 Mdot
.18397 .7897 Mdot
.49328 .29083 Mdot
.0766 .64662 Mdot
.47409 .04072 Mdot
.35818 .95331 Mdot
.3448 .84567 Mdot
.32336 .91189 Mdot
.17049 .82884 Mdot
.20579 .79931 Mdot
.12376 .95884 Mdot
.33507 .89499 Mdot
.35054 .8663 Mdot
.83523 .20907 Mdot
.24595 .89736 Mdot
.16875 .90384 Mdot
.04555 .50276 Mdot
.50133 .16008 Mdot
.21636 .97097 Mdot
.22724 .9149 Mdot
.43383 .50659 Mdot
.22777 .85643 Mdot
.25134 .97073 Mdot
.26423 .89249 Mdot
.24726 .80421 Mdot
.09001 .81243 Mdot
.36777 .93715 Mdot
.40017 .05883 Mdot
.10317 .25507 Mdot
.22835 .96452 Mdot
.94203 .98885 Mdot
.22923 .1922 Mdot
.05852 .12638 Mdot
.29786 .9674 Mdot
.37946 .91879 Mdot
.36201 .88875 Mdot
.47439 .86322 Mdot
.93849 .0521 Mdot
.27594 .89881 Mdot
.18858 .87334 Mdot
.29376 .78978 Mdot
.32702 .73903 Mdot
.41139 .79354 Mdot
.30103 .79321 Mdot
.30903 .06446 Mdot
.2779 .86988 Mdot
.86052 .59041 Mdot
.12451 .83424 Mdot
.36548 .94181 Mdot
.16771 .8327 Mdot
.24797 .86875 Mdot
.62835 .91766 Mdot
.14779 .15984 Mdot
.21907 .92592 Mdot
.05084 .14986 Mdot
.92347 .73463 Mdot
.29685 .82407 Mdot
.21757 .87739 Mdot
.1706 .82869 Mdot
.18634 .92577 Mdot
.62189 .87998 Mdot
.35725 .89851 Mdot
.5602 .38337 Mdot
.19195 .97261 Mdot
.25291 .90688 Mdot
.46425 .58473 Mdot
.18023 .83458 Mdot
.37604 .91175 Mdot
.24542 .87509 Mdot
.88461 .69165 Mdot
.19033 .95313 Mdot
.27292 .86329 Mdot
.93487 .88108 Mdot
.5287 .85224 Mdot
.29934 .85417 Mdot
.52366 .23095 Mdot
.27357 .87579 Mdot
.49421 .88433 Mdot
.46769 .9129 Mdot
.25977 .8914 Mdot
.1641 .8282 Mdot
.23234 .88361 Mdot
.78463 .04456 Mdot
.85771 .88726 Mdot
.18484 .75132 Mdot
.32665 .77319 Mdot
.25391 .90456 Mdot
.27897 .89745 Mdot
.24534 .88997 Mdot
.97413 .74117 Mdot
.15797 .84229 Mdot
.63185 .37903 Mdot
.20404 .70957 Mdot
.2136 .59934 Mdot
.79005 .10427 Mdot
.52256 .36399 Mdot
.22188 .92901 Mdot
.77782 .50025 Mdot
.18773 .75079 Mdot
.92144 .65334 Mdot
.28443 .81059 Mdot
.16696 .83233 Mdot
.16429 .07541 Mdot
.85412 .69232 Mdot
.25726 .91213 Mdot
.22224 .92933 Mdot
.20084 .79027 Mdot
.18958 .89715 Mdot
.08712 .42927 Mdot
.13332 .1858 Mdot
.26499 .9656 Mdot
.33145 .03213 Mdot
.0603 .99241 Mdot
.10935 .30274 Mdot
.42698 .02893 Mdot
.23524 .92023 Mdot
.20635 .82276 Mdot
.31683 .86775 Mdot
.32871 .75692 Mdot
.59944 .34627 Mdot
.10319 .79337 Mdot
.22942 .92551 Mdot
.19355 .87864 Mdot
.33768 .66392 Mdot
.24448 .72216 Mdot
.16858 .96766 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_o
oooo0_l000000ooooooo0000ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo000Nooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00;o00002oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo
000Nooooo`03o`000?oooooooooo04Sooooo0_l0000:ooooo`;o00000oooool2o`000<Wooooo0_l0
000Qooooo`007_ooool00ol0003oooooooooo`18ooooo`;o00002_ooool2o`0000?ooooo0_l00008
ooooo`;o00001Oooool2o`000;Wooooo0_l0000Pooooo`007_ooool00ol0003oooooooooo`1Soooo
o`;o00001Oooool2o`0003[ooooo0_l0001mooooo`;o00008?ooool001kooooo00?o0000oooooooo
ool0Y_ooool2o`0003cooooo0_l0001Qooooo`007_ooool00ol0003oooooooooo`0iooooo`;o0000
3Oooool2o`0000Gooooo0_l00007ooooo`Co0000R?ooool2o`0000kooooo0_l0001Aooooo`007_oo
ool00ol0003oooooooooo`0iooooo`;o00003Oooool2o`0000Gooooo0_l00007ooooo`Co0000V?oo
ool2o`00057ooooo000Nooooo`03o`000?oooooooooo07_ooooo0_l00005ooooo`;o00000oooool2
o`0000?ooooo0_l0000Kooooo`;o0000:Oooool2o`0003Kooooo0_l0000iooooo`007_ooool00ol0
003oooooooooo`0[ooooo`;o00004Oooool2o`0000Kooooo0_l0000Eooooo`;o00002Oooool2o`00
013ooooo0ol00005ooooo`;o00000oooool2o`0000?ooooo0_l0000>ooooo`;o00002oooool2o`00
02Wooooo0_l0000fooooo`;o0000>Oooool001kooooo00?o0000ooooooooool00oooool2o`0002Ko
oooo0_l0000Aooooo`;o00001_ooool2o`0001Cooooo0ol00009ooooo`;o00004?ooool2o`0000Wo
oooo0_l00004ooooo`;o00003oooool2o`0009_ooooo0_l0000<ooooo`007_ooool00ol0003ooooo
ooooo`03ooooo`;o0000Eoooool4o`0001Sooooo0_l0000;ooooo`;o00001?ooool4o`0005gooooo
0_l0001;ooooo`;o00003?ooool001kooooo00?o0000ooooooooool0?Oooool2o`0001oooooo0_l0
000Hooooo`;o00002Oooool2o`0000Sooooo0_l00007ooooo`;o00006oooool2o`0003Oooooo0_l0
001Iooooo`007_ooool00ol0003oooooooooo`0mooooo`;o0000@?ooool2o`0000;ooooo0_l0000A
ooooo`;o00006oooool2o`0009;ooooo000Nooooo`03o`000?oooooooooo07oooooo0_l0000moooo
o`;o0000>oooool2o`0004[ooooo000Nooooo`03o`000?oooooooooo02;ooooo0_l00009ooooo`;o
00000_ooool2o`0002oooooo0_l0001Jooooo`;o0000>oooool2o`0004[ooooo000Nooooo`;o0000
8oooool2o`0000Wooooo0_l00002ooooo`;o00005Oooool2o`0000;ooooo0_l0000Dooooo`;o0000
2_ooool3o`000;cooooo0_l0000Hooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o00003Ooo
ool2o`0001Sooooo0_l00002ooooo`;o00008?ooool3o`000;cooooo0_l0000Hooooo`007_ooool0
0ol0003oooooooooo`0Oooooo`;o00003Oooool2o`0001Kooooo0_l0000Wooooo`;o000000?ooooo
o`000?l000002_ooool2o`000<Oooooo000Nooooo`03o`000?oooooooooo04Kooooo0_l0000Woooo
o`;o000000?oooooo`000?l000002_ooool2o`000<Oooooo000Nooooo`03o`000?oooooooooo063o
oooo0_l0003Uooooo`007_ooool00ol0003oooooooooo`1Pooooo`;o00009oooool2o`0000[ooooo
0_l0002`ooooo`007_ooool00ol0003oooooooooo`0`ooooo`;o00001oooool2o`0004kooooo0_l0
000:ooooo`;o0000/?ooool001kooooo00?o0000ooooooooool0<?ooool2o`000003ooooool0003o
000000Cooooo0_l0003oooooo`gooooo000Nooooo`03o`000?oooooooooo037ooooo1?l0003ooooo
o`;o00004Oooool001kooooo00?o0000ooooooooool00_l0000_ooooo`;o0000=?ooool2o`000<_o
oooo0_l0000Aooooo`007_ooool00ol0003oooooooooo`02o`0000kooooo0_l0000Hooooo`;o0000
;Oooool2o`0000_ooooo0ol0003Nooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o00006?oo
ool2o`0002gooooo0_l0000;ooooo`;o00004oooool2o`0005[ooooo0_l0001^ooooo`007_ooool0
0ol0003oooooooooo`1kooooo`;o00005?ooool2o`0004Cooooo0_l0001^ooooo`007_ooool00ol0
003oooooooooo`1Looooo`;o00001Oooool2o`0002cooooo0_l0000Fooooo`;o0000W?ooool001ko
oooo00?o0000ooooooooool0:?ooool2o`0003;ooooo0_l00005ooooo`;o0000A?ooool2o`0009co
oooo000Nooooo`03o`000?oooooooooo02Sooooo0_l0000Rooooo`;o00005_ooool2o`000>7ooooo
000Nooooo`;o0000COooool2o`0001Kooooo0_l0003Qooooo`007_ooool00ol0003oooooooooo`1j
ooooo`;o0000POooool2o`0004Sooooo000Nooooo`03o`000?oooooooooo07[ooooo0_l00021oooo
o`;o0000B?ooool001kooooo00?o0000ooooooooool0>Oooool2o`0000Cooooo0_l0000Qooooo`;o
0000hoooool001kooooo00?o0000ooooooooool02_ooool2o`0002gooooo0_l00004ooooo`;o0000
8Oooool2o`000>?ooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0001Dooooo`;o000000?o
ooooo`000?l00000h_ooool001kooooo00?o0000ooooooooool0H?ooool2o`000003ooooool0003o
00000>;ooooo000Nooooo`03o`000?oooooooooo02kooooo0_l0002:ooooo`;o0000Roooool001ko
oooo00?o0000ooooooooool03oooool2o`0001gooooo0_l0002:ooooo`;o0000Roooool001kooooo
00?o0000ooooooooool03oooool2o`0003[ooooo0_l0000Hooooo`;o000000?oooooo`000?l00000
@oooool2o`0009Sooooo000Nooooo`03o`000?oooooooooo03Cooooo0_l0000Eooooo`;o00006?oo
ool2o`000003ooooool0003o000004?ooooo0_l0002Hooooo`007_ooool00ol0003oooooooooo`0d
ooooo`;o0000oooooolBooooo`007_ooool00ol0003oooooooooo`14ooooo`;o0000ooooool2oooo
o`007_ooool00ol0003oooooooooo`0oooooo`;o00000oooool2o`000?oooooo0_ooool001kooooo
00?o0000ooooooooool0?oooool2o`000?oooooo1oooool001kooooo00?o0000ooooooooool0D?oo
ool2o`000?Gooooo000Nooooo`;o00003Oooool2o`0004;ooooo0_l0003eooooo`007_ooool00ol0
003oooooooooo`0<ooooo`;o0000ooooooljooooo`007_ooool00ol0003oooooooooo`0iooooo`;o
0000B_ooool2o`000<3ooooo000Nooooo`03o`000?oooooooooo02cooooo0_l0000;ooooo`;o0000
0_ooool2o`0004Kooooo0_l0000Hooooo`;o0000VOooool2o`0000_ooooo000Nooooo`03o`000?oo
oooooooo02cooooo0_l0000?ooooo`;o0000H?ooool3o`0009Sooooo0_l0000;ooooo`007_ooool0
0ol0003oooooooooo`1Oooooo`;o00004oooool2o`0002[ooooo0_l0002Uooooo`007_ooool00ol0
003oooooooooo`09ooooo`;o0000E?ooool2o`0001?ooooo0_l0003Aooooo`007_ooool00ol0003o
ooooooooo`09ooooo`;o0000=Oooool2o`0004cooooo0_l0002gooooo`007_ooool00ol0003ooooo
ooooo`10ooooo`;o0000>?ooool2o`0001;ooooo0_l0000Xooooo`;o0000SOooool001kooooo00?o
0000ooooooooool0;_ooool2o`0004[ooooo0_l0000Aooooo`;o0000:Oooool2o`0001cooooo0_l0
001_ooooo`007_ooool00ol0003oooooooooo`0^ooooo`;o0000GOooool2o`0004Oooooo0_l00014
ooooo`;o0000:Oooool001kooooo00?o0000ooooooooool09oooool2o`000??ooooo0_l0000Yoooo
o`007_ooool00ol0003oooooooooo`0Wooooo`;o0000oooooolOooooo`007_ooool00ol0003ooooo
ooooo`2Pooooo`;o0000YOooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool07Oooool2o`0002Oooooo0_l0001Hooooo`;o0000
YOooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Q
onk^k_ooooooA4A400Kooooo00?o0000ooooooooool07Oooool2o`0002Oooooo0_l0000dooooo`;o
0000bOooool000?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo0ol00016ooooo`;o0000=?ooool2o`000<Wooooo0003ooooo`05o`000?ooooooooooooooool0
00003Oooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo
00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000oooooooo
ool0ZOooool2o`0009cooooo0003ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo02Gooooo0_l00008ooooo`;o0000N?ooool2o`00063o
oooo0_l0000jooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oo
ooooV9RHoa0@4006ooooo`03o`000?oooooooooo02Gooooo0_l00008ooooo`;o0000f_ooool2o`00
03[ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool07_ooool2o`0000oooooo0_l0002kooooo`;o0000FOooool0
01kooooo00?o0000ooooooooool07_ooool2o`000<cooooo0_l0000Zooooo`;o0000;Oooool001ko
oooo00?o0000ooooooooool0oooooolIooooo`;o0000;Oooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0:Kooooo0_l0002Oooooo`007_ooool00ol0003oooooooooo`0`ooooo`;o00001?ooool2o`00
06kooooo0_l0002Oooooo`007_ooool00ol0003oooooooooo`0`ooooo`;o00001?ooool2o`000?oo
oooo4?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`1=ooooo`;o0000n?ooool001kooooo00?o0000ooooooooool0=?ooool2o`0001Oooooo0_l00013
ooooo`;o0000/oooool001gooooo0_l0000fooooo`;o0000G?ooool2o`000;?ooooo000Mooooo`?o
0000oooooom9ooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o00000_ooool2o`0000Kooooo
0_l0002jooooo`;o0000H?ooool001kooooo00?o0000ooooooooool07Oooool2o`0000;ooooo0_l0
0006ooooo`;o00000oooool2o`0002cooooo0_l00027ooooo`;o0000H?ooool001kooooo00?o0000
ooooooooool0;_ooool2o`0002cooooo0_l0003Yooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo02[ooooo0_l0002looooo`;o0000GOooool001kooooo
00?o0000ooooooooool0:_ooool2o`000;cooooo0_l0001Mooooo`007_ooool00ol0003ooooooooo
o`02ooooo`;o0000oooooom4ooooo`007_ooool00ol0003oooooooooo`02ooooo`;o0000KOooool2
o`000=Cooooo000Nooooo`03o`000?oooooooooo077ooooo0_l0003Dooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0BOooool2o`000<[ooooo0_l0000`ooooo`007_ooool00ol0003oooooooooo`0l
ooooo`;o00002oooool2o`00057ooooo0_l0001gooooo`;o0000<?ooool001kooooo00?o0000oooo
ooooool0??ooool2o`0005kooooo0_l0001Sooooo`;o0000A?ooool001kooooo00?o0000oooooooo
ool0ooooool2ooooo`;o0000A?ooool001kooooo0_l0000Pooooo`;o0000oooooolWooooo`007_oo
ool00ol0003oooooooooo`0Oooooo`?o0000oooooolVooooo`007_ooool00ol0003oooooooooo`0P
ooooo`;o00009Oooool2o`000?kooooo000Nooooo`03o`000?oooooooooo04Oooooo0_l0003noooo
o`007_ooool00ol0003oooooooooo`3Rooooo`;o0000Hoooool001kooooo00?o0000ooooooooool0
h_ooool2o`0006?ooooo000Nooooo`03o`000?oooooooooo02Sooooo0_l0001iooooo`;o0000X_oo
ool001kooooo00?o0000ooooooooool0:?ooool2o`0007Wooooo0_l0002Rooooo`007_ooool00ol0
003oooooooooo`1dooooo`;o0000dOooool001kooooo00?o0000ooooooooool0M?ooool2o`000=7o
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`2oooooo`;o0000Q_ooool001kooooo0_l0000jooooo`;o00008oooool2o`0005oooooo0_l0
0026ooooo`007_ooool00ol0003oooooooooo`0iooooo`;o00008oooool2o`00067ooooo0_l00024
ooooo`007_ooool00ol0003oooooooooo`31ooooo`?o0000Poooool001kooooo00?o0000oooooooo
ool0`_ooool2o`0008?ooooo000Nooooo`03o`000?oooooooooo0:Kooooo0_l0002Oooooo`007_oo
ool00ol0003oooooooooo`2Vooooo`;o0000Woooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0Ooooool2o`0004Sooooo0_l0000?ooooo`;o0000
Joooool001kooooo00?o0000ooooooooool0Ooooool2o`0004Gooooo0_l000000ooooooo0000o`00
000?ooooo`;o0000Joooool001kooooo00?o0000ooooooooool0/_ooool2o`0001;ooooo0_l0001o
ooooo`007_ooool00ol0003oooooooooo`2booooo`;o0000Toooool001kooooo00?o0000oooooooo
ool0O?ooool2o`000:Wooooo0_l0000Nooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`1looooo`;o
00004Oooool2o`0009Kooooo0_l0000Nooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Soooool2o`000;Ko
oooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol00024ooooo`;o
0000`Oooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`00
00Oooooo00?o0000ooooooooool0Q?ooool2o`000<7ooooo0003ooooo`05o`000?oooooooooooooo
ool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo0=Kooooo0_l0001_
ooooo`000oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool0
0ol0003oooooooooo`3Fooooo`;o0000Koooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<
ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3aooooo`;o0000E?ooool001kooooo00?o
0000ooooooooool02Oooool2o`000>Kooooo0_l0001Dooooo`007_ooool00ol0003oooooooooo`09
ooooo`;o00003Oooool2o`0002cooooo0_l0003oooooo`007_ooool00ol0003oooooooooo`0Hoooo
o`;o0000;?ooool2o`0005Sooooo0_l0002Uooooo`007_ooool00ol0003oooooooooo`2Pooooo`;o
00003oooool2o`0009Cooooo000Nooooo`03o`000?oooooooooo0;7ooooo0_l0000mooooo`;o0000
EOooool001kooooo00?o0000ooooooooool0Uoooool2o`0005Oooooo0_l0001Eooooo`007_ooool0
0ol0003oooooooooo`2Gooooo`;o0000[_ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool06?ooool2o`000?oooooo;_ooool001kooooo00?o0000oooooooo
ool06?ooool2o`0001kooooo0_l0003oooooo`kooooo000Nooooo`03o`000?oooooooooo03Sooooo
0_l0003oooooo`kooooo000Nooooo`03o`000?oooooooooo00Gooooo0_l0003ooooood7ooooo000N
ooooo`03o`000?oooooooooo00Gooooo0_l0000[ooooo`;o0000oooooolDooooo`007_ooool00ol0
003oooooooooo`0booooo`;o0000oooooolDooooo`007_ooool00ol0003oooooooooo`21ooooo`;o
00006?ooool2o`000:[ooooo000Nooooo`03o`000?oooooooooo07oooooo1?l0000Hooooo`;o0000
Z_ooool001kooooo00?o0000ooooooooool0Ooooool2o`000<Kooooo000Nooooo`03o`000?oooooo
oooo0>_ooooo0_l0001Jooooo`007_ooool00ol0003oooooooooo`3[ooooo`;o0000F_ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`0000cooooo0_l0003/ooooo`;o0000
C?ooool001kooooo00?o0000ooooooooool02oooool2o`0006[ooooo0_l0000Rooooo`;o0000G?oo
ool2o`0004cooooo000Nooooo`03o`000?oooooooooo07Oooooo0_l0000@ooooo`;o00002oooool2
o`0000?ooooo0_l0000>ooooo`;o0000V_ooool001kooooo00?o0000ooooooooool0Boooool2o`00
03cooooo0_l0000;ooooo`;o00004oooool2o`0009[ooooo000Nooooo`03o`000?oooooooooo04_o
oooo0ol0001Dooooo`;o0000Xoooool001kooooo00?o0000ooooooooool0C?ooool2o`0005Cooooo
0_l0002Sooooo`007_ooool00ol0003oooooooooo`0_ooooo`;o0000doooool2o`00047ooooo000N
ooooo`03o`000?oooooooooo02oooooo0_l00006ooooo`;o0000boooool2o`00047ooooo000Noooo
o`03o`000?oooooooooo03Oooooo0_l0003cooooo`;o00006Oooool001kooooo00?o0000oooooooo
ool0ooooool]ooooo`;o00006Oooool001kooooo00?o0000ooooooooool03?ooool2o`000?oooooo
>_ooool001kooooo00?o0000ooooooooool03?ooool2o`000?oooooo>_ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`1Hooooo`;o0000kOooool001ko
oooo00?o0000ooooooooool02oooool2o`0000;ooooo0_l00017ooooo`;o0000kOooool001kooooo
00?o0000ooooooooool02oooool2o`0000;ooooo0_l0003oooooocOooooo000Nooooo`;o00001Ooo
ool2o`000?oooooo@_ooool001kooooo00?o0000ooooooooool01?ooool2o`000?oooooo@_ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3@ooooo`;o0000MOooool001kooooo00?o0000oooo
ooooool02?ooool2o`000<Kooooo0_l0001Looooo`;o00005oooool001kooooo00?o0000oooooooo
ool02?ooool2o`0005gooooo0_l0000gooooo`;o0000S?ooool2o`0001Oooooo000Nooooo`03o`00
0?oooooooooo06Oooooo0_l0000gooooo`;o0000YOooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`2Cooooo`;o0000POooool2o`0002oooooo000Noooo
o`03o`000?oooooooooo00Oooooo0_l0002:ooooo`;o0000POooool2o`0002oooooo000Nooooo`03
o`000?oooooooooo00Oooooo0_l0000>ooooo`;o0000Coooool2o`000:[ooooo0_l0000aooooo`00
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@
4?o<c<`01_ooool00ol0003oooooooooo`0Gooooo`;o0000Coooool3o`0007[ooooo0_l0000]oooo
o`;o0000:_ooool2o`0000Gooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo01gooooo0_l00009
ooooo`;o0000?oooool2o`0000Oooooo0_l0001aooooo`;o0000FOooool2o`0000Gooooo0003oooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
000Mooooo`;o00002Oooool2o`0001Oooooo0_l0000_ooooo`;o0000doooool000?ooooo00Go0000
ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`11ooooo`;o0000h?ooool2o`0001_ooooo0_l00005ooooo`000oooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo02Oo
oooo0_l0000Dooooo`;o0000foooool2o`0000Oooooo0ol0000Jooooo`;o00001Oooool000?ooooo
00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000oooooooo
ool08?ooool2o`0000Gooooo0_l0000Cooooo`?o0000foooool2o`0000Sooooo0_l0000Qooooo`00
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003o
ooooooooo`0Pooooo`;o00006_ooool2o`000?oooooo2_ooool000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool00oooool2o`00
02oooooo0_l0000>ooooo`;o0000h?ooool2o`0001oooooo000Nooooo`03o`000?oooooooooo00?o
oooo0_l0000Kooooo`;o00004_ooool2o`0000kooooo0_l0003Pooooo`;o00007oooool001kooooo
00?o0000ooooooooool04oooool2o`0000_ooooo0_l0003oooooobKooooo000Nooooo`03o`000?oo
oooooooo01?ooooo0_l0003oooooob[ooooo0_l00007ooooo`007_ooool2o`0003cooooo0_l0003o
ooooo`;ooooo0_l00007ooooo`007_ooool2o`0002?ooooo0_l000000ooooooo0000o`00000Doooo
o`;o0000ooooool;ooooo`007_ooool00ol0003oooooooooo`0Rooooo`;o000000?oooooo`000?l0
00000_l0001nooooo`;o0000W_ooool001kooooo00?o0000ooooooooool09oooool2o`0007kooooo
0_l0002Nooooo`007_ooool00ol0003oooooooooo`04ooooo`;o00009_ooool2o`0000Cooooo0_l0
003ooooooaCooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0000Jooooo`;o00002_ooool2
o`0000Cooooo0_l0000Eooooo`;o00005_ooool2o`000>Cooooo000Nooooo`03o`000?oooooooooo
01Gooooo0_l00009ooooo`;o00000oooool2o`0002;ooooo0_l0000Fooooo`;o0000AOooool2o`00
04cooooo0_l0001?ooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o00003_ooool2o`00037o
oooo0_l0001>ooooo`;o0000C?ooool2o`0004oooooo000Nooooo`;o00001?ooool2o`0000[ooooo
0_l00017ooooo`;o0000cOooool2o`0001kooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0
000:ooooo`;o00007oooool2o`0000gooooo0_l0000<ooooo`;o0000f?ooool2o`0001kooooo000N
ooooo`03o`000?oooooooooo033ooooo0_l0000=ooooo`;o00003?ooool2o`00017ooooo0_l0003U
ooooo`007_ooool00ol0003oooooooooo`1Pooooo`;o00005oooool2o`0007Cooooo0_l0000Hoooo
o`;o0000??ooool001kooooo00?o0000ooooooooool0J_ooool3o`0000cooooo0_l0001dooooo`;o
00006?ooool2o`0003cooooo000Nooooo`03o`000?oooooooooo05?ooooo0_l0000Eooooo`?o0000
f_ooool001kooooo00?o0000ooooooooool0@?ooool2o`00017ooooo0_l0002Xooooo`;o0000;Ooo
ool2o`0001Wooooo000Nooooo`03o`000?oooooooooo043ooooo0_l0000Mooooo`;o0000W?ooool2
o`00027ooooo0_l0000:ooooo`;o00006Oooool001kooooo00?o0000ooooooooool00_ooool2o`00
05_ooooo0_l000000ooooooo0000o`00002looooo`?o00005oooool3o`0000[ooooo000Nooooo`03
o`000?oooooooooo00;ooooo0_l0000hooooo`;o00005_ooool2o`0000cooooo0_l0002mooooo`;o
00005oooool3o`0000[ooooo000Nooooo`03o`000?oooooooooo03cooooo0_l0000Fooooo`;o0000
LOooool2o`0005;ooooo0_l0000Zooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o0000L?oo
ool2o`00047ooooo0_l00005ooooo`;o0000D_ooool2o`0000Oooooo0_l0000Qooooo`007_ooool0
0ol0003oooooooooo`0;ooooo`;o00003oooool2o`0001Kooooo0_l0000>ooooo`;o0000=oooool2
o`0002Gooooo0_l0000Jooooo`;o0000:_ooool2o`0003Kooooo0_l0000Qooooo`007_ooool00ol0
003oooooooooo`0Looooo`;o00005_ooool2o`0000kooooo0_l0001Nooooo`;o0000A_ooool2o`00
02Cooooo0_l00007ooooo`;o0000:_ooool001kooooo00?o0000ooooooooool0[_ooool2o`0006;o
oooo0_l00007ooooo`;o0000:_ooool001kooooo00?o0000ooooooooool05Oooool2o`00023ooooo
0_l0001eooooo`;o0000Uoooool001kooooo0_l0000Fooooo`;o00008?ooool2o`0000;ooooo0_l0
0008ooooo`?o0000E_ooool2o`0002?ooooo0_l00019ooooo`;o0000=oooool001kooooo00?o0000
ooooooooool01oooool2o`0000Cooooo0_l0000/ooooo`;o00000_ooool2o`0000Cooooo0ol00017
ooooo`;o00003Oooool2o`0002?ooooo0_l00019ooooo`;o00004Oooool2o`0001kooooo0_l00004
ooooo`007_ooool00ol0003oooooooooo`07ooooo`;o00001?ooool2o`0002cooooo0_l00002oooo
o`;o00000oooool2o`0001Gooooo1?l00007ooooo`;o00002?ooool2o`0001gooooo0_l0001Koooo
o`;o00007oooool2o`0001;ooooo0_l00008ooooo`;o00005?ooool2o`0000Cooooo000Nooooo`03
o`000?oooooooooo03_ooooo0_l000000ooooooo0000o`000004ooooo`;o00004_ooool2o`000003
ooooool0003o000000;o00000oooool2o`0000;ooooo0_l00006ooooo`Co0000N_ooool2o`0001oo
oooo0_l0000Dooooo`;o00001_ooool2o`0001[ooooo000Nooooo`03o`000?oooooooooo03kooooo
0_l0000Hooooo`;o00002?ooool2o`0000[ooooo0_l0000hooooo`;o0000NOooool2o`0002;ooooo
000Nooooo`03o`000?oooooooooo077ooooo0_l0000eooooo`;o00009oooool2o`0007Cooooo000N
ooooo`03o`000?oooooooooo00?ooooo0_l0000Looooo`;o0000<Oooool3o`0001?ooooo0_l00005
ooooo`;o0000G_ooool2o`0007Cooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0000Loooo
o`;o00006Oooool2o`0000Sooooo0_l00003ooooo`;o00001oooool3o`000003ooooool0003o0000
013ooooo0_l0003Kooooo`007_ooool00ol0003oooooooooo`09ooooo`;o00008?ooool2o`0000oo
oooo0_l000000ooooooo0000o`000003ooooo`Co00000oooool2o`0000_ooooo0_l00031ooooo`;o
0000:_ooool001kooooo00?o0000ooooooooool02Oooool2o`00023ooooo0_l0000@ooooo`Co0000
0oooool2o`000=Gooooo0_l0000Zooooo`007_ooool00ol0003oooooooooo`0mooooo`;o0000=Ooo
ool2o`0008gooooo0_l0000Zooooo`;o00005_ooool001kooooo00?o0000ooooooooool0?Oooool2
o`0000Gooooo0_l000001?oooooo0000o`000?ooool2o`0000Kooooo0_l0000Pooooo`;o0000SOoo
ool2o`0002?ooooo0_l00005ooooo`;o00005_ooool001kooooo00?o0000ooooooooool0@_ooool4
o`000004ooooool0003o0000ooooo`;o00001_ooool2o`0001;ooooo0_l00009ooooo`;o0000Q?oo
ool2o`0002oooooo0_l0000Mooooo`007_ooool00ol0003oooooooooo`12ooooo`;o00008_ooool2
o`0000Wooooo0_l00024ooooo`;o0000@?ooool2o`0000;ooooo0_l00008ooooo`007_ooool00ol0
003oooooooooo`0Jooooo`;o0000B_ooool2o`000=7ooooo0_l00002ooooo`;o00002?ooool001ko
oooo00?o0000ooooooooool04Oooool2o`0000Oooooo0_l0000=ooooo`;o0000>oooool2o`000=Go
oooo0_l00008ooooo`007_ooool2o`0000cooooo0_l00004ooooo`;o00005_ooool2o`0000Cooooo
0_l00007ooooo`?o0000Loooool2o`0009Oooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l0
000Kooooo`Co00000oooool2o`0000Oooooo1Ol00009ooooo`;o0000I_ooool2o`0001gooooo0_l0
001hooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o00000oooool4o`0000;ooooo0_l0000;
ooooo`;o00002Oooool2o`0001oooooo0_l0001Tooooo`;o0000LOooool2o`0000Gooooo000Noooo
o`03o`000?oooooooooo00Sooooo0_l0000Iooooo`;o00000oooool2o`0000Cooooo0_l0000goooo
o`;o00001oooool2o`0006Kooooo0_l0001=ooooo`;o00000oooool2o`0001;ooooo0_l00005oooo
o`007_ooool00ol0003oooooooooo`08ooooo`;o00006Oooool2o`0000?ooooo0_l0000Cooooo`;o
0000<Oooool2o`0004?ooooo0_l0000Qooooo`;o0000COooool2o`0000?ooooo0_l0000Iooooo`00
7_ooool00ol0003oooooooooo`0Sooooo`;o00006?ooool2o`0000Oooooo0_l00002ooooo`;o0000
;oooool2o`0003Sooooo0_l0002@ooooo`007_ooool00ol0003oooooooooo`0`ooooo`;o00001Ooo
ool2o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`?o000000?oooooo`000?l000001_oo
ool2o`0000Gooooo1?l0000Nooooo`;o0000b_ooool001kooooo00?o0000ooooooooool0<?ooool2
o`0000Gooooo1?l00002ooooo`;o000000?oooooo`000?l000001Oooool4o`0000Oooooo0_l00005
ooooo`Co00002Oooool2o`0000Wooooo0_l0003Dooooo`007_ooool00ol0003oooooooooo`0Yoooo
o`;o00001_ooool2o`000003ooooool0003o000000?ooooo0_l0000=ooooo`?o00001?ooool2o`00
01Gooooo0_l00009ooooo`;o0000V?ooool2o`0003[ooooo000Nooooo`03o`000?oooooooooo02Wo
oooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000;o00001oooool2o`0000_o
oooo0_l000000ooooooo0000o`00000<ooooo`;o00005_ooool2o`0009Cooooo0_l0000jooooo`00
7_ooool00ol0003oooooooooo`0Yooooo`;o00000_ooool2o`0000Oooooo0_l00007ooooo`;o0000
1?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000?ooooo`;o00005_ooool2o`0003Wooooo
0_l0002Eooooo`007_ooool00ol0003oooooooooo`0_ooooo`;o00001?ooool2o`0000kooooo0_l0
0002ooooo`;o00008Oooool2o`0003Gooooo0ol0000:ooooo`;o0000N_ooool2o`0001Wooooo000N
ooooo`03o`000?oooooooooo02oooooo0_l00004ooooo`;o00001Oooool2o`0000Kooooo0_l0000V
ooooo`;o0000=Oooool3o`0008Kooooo0_l0000Iooooo`007_ooool00ol0003oooooooooo`0Joooo
o`;o00004_ooool2o`0000Sooooo0_l00002ooooo`?o00001Oooool2o`0000?ooooo0ol0000?oooo
o`;o0000j_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<
c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool06_ooool2o`000003ooooool0003o
000000Oooooo0_l00006ooooo`;o000000?oooooo`000?l000001Oooool2o`0000?ooooo0ol00009
ooooo`?o00003oooool2o`000003ooooool0003o000002;ooooo0_l0002Fooooo`;o0000:oooool0
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonH
V9So8B4Q00Kooooo00?o0000ooooooooool07Oooool2o`0000Oooooo0_l00002ooooo`;o00001Ooo
ool2o`0000_ooooo0_l0000Nooooo`;o00006?ooool2o`0000Sooooo0_l0000Oooooo`;o0000MOoo
ool2o`0002_ooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000000Kooooo0ol0000Zooooo`;o00000_ooool6o`0000_ooooo1?l00009ooooo`;o0000
:_ooool2o`0002Wooooo0_l0002Rooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo
00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooooooo02cooooo2?l0000;ooooo`Co
00000oooool2o`0000Cooooo0_l0000Rooooo`;o0000[Oooool2o`0001_ooooo0_l00009ooooo`00
0oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006oooo
o`03o`000?oooooooooo02cooooo0ol000000ooooooo0000o`000002o`0000Oooooo0_l00003oooo
o`;o00001?ooool2o`0000Cooooo0_l00002ooooo`;o00000_ooool2o`0001[ooooo0_l0000^oooo
o`;o0000NOooool2o`0000;ooooo0_l0000Kooooo`;o00002Oooool000?ooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`0P
ooooo`;o00002oooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000?ooooo0_l00004
ooooo`;o00002?ooool2o`0000;ooooo1_l0000>ooooo`;o0000=_ooool2o`0007Wooooo0_l0000Z
ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00
0006ooooo`03o`000?oooooooooo01Wooooo0_l00005ooooo`;o00001oooool2o`0000[ooooo0ol0
0008ooooo`;o00001?ooool2o`000003ooooool0003o000000?ooooo0_l00006ooooo`Co00003_oo
ool2o`000=gooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`00
0?l@413oZJVY00Kooooo00?o0000ooooooooool04oooool3o`0000?ooooo0_l0000>ooooo`;o0000
2?ooool6o`0000Oooooo0_l00002ooooo`;o00000oooool2o`0000?ooooo0_l00008ooooo`;o0000
5_ooool2o`0005oooooo0_l0001dooooo`007_ooool00ol0003oooooooooo`0Cooooo`?o00007?oo
ool3o`000003ooooool0003o000000;o00002_ooool2o`0001Cooooo0_l0000Dooooo`;o00000ooo
ool2o`0003Gooooo0_l0000Sooooo`;o0000M?ooool001kooooo00?o0000ooooooooool0<_ooool8
o`00023ooooo0_l0000Iooooo`;o0000=Oooool2o`0009Wooooo000Nooooo`03o`000?oooooooooo
00Sooooo0_l0000Yooooo`Co00002?ooool2o`0000cooooo0_l00003ooooo`;o00002?ooool2o`00
0>Wooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0000Wooooo`Go00002Oooool2o`0000;o
oooo0_l00008ooooo`;o00000oooool2o`0000?ooooo0_l00003ooooo`;o00002?ooool2o`0002So
oooo0_l0002eooooo`007_ooool00ol0003oooooooooo`0Kooooo`;o00005?ooool5o`0000Cooooo
0_l00003ooooo`;o00000_ooool2o`0001;ooooo0_l0000=ooooo`;o00000_ooool2o`0002Cooooo
0_l0000Cooooo`;o0000X?ooool001kooooo00?o0000ooooooooool06oooool2o`0000Oooooo0_l0
000;ooooo`Oo00000_ooool3o`0000;ooooo0_l0000:ooooo`Co00006oooool2o`0003Wooooo0_l0
001Dooooo`;o0000B_ooool001kooooo00?o0000ooooooooool08?ooool2o`0000;ooooo0_l0000;
ooooo`Co000000?oooooo`000?l000000oooool3o`0000Cooooo0_l00007ooooo`Co00000_ooool2
o`0004Wooooo0_l0001Mooooo`;o0000B_ooool001kooooo00?o0000ooooooooool08?ooool2o`00
00kooooo1?l00008ooooo`;o00001?ooool2o`0000gooooo0_l00019ooooo`;o0000ZOooool001ko
oooo00?o0000ooooooooool0;oooool3o`0000Gooooo0_l0000Jooooo`;o00001Oooool3o`0000Ko
oooo0_l000000ooooooo0000o`00003Oooooo`007_ooool00ol0003oooooooooo`0Fooooo`;o0000
3_ooool2o`000003ooooool0003o000000?ooooo1?l00005ooooo`;o00002Oooool2o`0000Kooooo
1?l00005ooooo`;o00001?ooool4o`0000Kooooo0_l000000ooooooo0000o`000004ooooo`;o0000
<oooool2o`0003Cooooo0_l0001^ooooo`007_ooool00ol0003oooooooooo`0Fooooo`;o00003_oo
ool2o`000004ooooool0003o0000ooooo`Ko00002?ooool2o`0000Kooooo0_l00003ooooo`;o0000
00?oooooo`000?l000000_l000000ooooooo0000o`000007ooooo`?o00000_ooool2o`0000Sooooo
0_l00003ooooo`;o0000<oooool2o`0002gooooo0_l00005ooooo`;o00004?ooool2o`0005cooooo
000Nooooo`;o00004Oooool2o`0001Sooooo2?l000000ooooooo0000o`000005ooooo`;o00001_oo
ool2o`0000?ooooo0_l00003ooooo`Go00000_ooool2o`000003ooooool0003o000000;o00000ooo
ool2o`0000Sooooo0_l0000Aooooo`;o0000;?ooool2o`0000Cooooo0_l0000Pooooo`;o00005ooo
ool2o`0005cooooo000Nooooo`03o`000?oooooooooo013ooooo0_l00005ooooo`;o00002?ooool2
o`0000Kooooo1ol00003ooooo`;o00003_ooool2o`000003ooooool0003o000000?ooooo1?l00004
ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o00006oooool3o`0002_ooooo0_l00004
ooooo`;o0000B?ooool2o`0003gooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`0Goooo
o`;o00002?ooool2o`0000Kooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`00
0?l000001oooool2o`0000Gooooo0_l000000ooooooo0000o`000003ooooo`?o00000oooool6o`00
0003ooooool0003o000000?ooooo0ol00006ooooo`;o00004oooool2o`0002gooooo0_l0000Foooo
o`;o0000=?ooool2o`0003gooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`0Kooooo`;o
00004oooool2o`0000Sooooo1?l00006ooooo`;o00001_ooool2o`0000;ooooo1ol00007ooooo`;o
00000_ooool2o`0000;ooooo0_l00012ooooo`;o00000oooool2o`00017ooooo0_l00023ooooo`00
7_ooool00ol0003oooooooooo`0Kooooo`;o00007Oooool2o`0000Sooooo0_l0000:ooooo`;o0000
0_ooool3o`0000_ooooo0_l00006ooooo`;o00004oooool2o`0001Gooooo0ol0000Fooooo`;o0000
;Oooool2o`0006Oooooo000Nooooo`03o`000?oooooooooo04?ooooo0_l00008ooooo`Go00000ooo
ool2o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`Co00001?ooool2o`0000;ooooo0_l0
0003ooooo`;o00002_ooool2o`0001Gooooo0ol00015ooooo`;o0000A_ooool2o`0001oooooo000N
ooooo`03o`000?oooooooooo01[ooooo0_l0000Wooooo`;o00002?ooool5o`000004ooooool0003o
0000ooooo`Go000000?oooooo`000?l000001Oooool3o`0000Sooooo0_l00003ooooo`;o0000/Ooo
ool2o`0001oooooo000Nooooo`03o`000?oooooooooo01[ooooo0_l0000Mooooo`;o00003oooool2
o`000004ooooool0003o0000o`0000?ooooo0_l000000ooooooo0000o`000002o`0000Gooooo0_l0
0002ooooo`?o00002?ooool2o`000003ooooool0003o00000=Cooooo000Nooooo`03o`000?oooooo
oooo037ooooo0_l00006ooooo`;o00002?ooool2o`0000?ooooo2?l00002ooooo`;o000000?ooooo
o`000?l000000oooool2o`0000?ooooo0_l00003ooooo`;o00002oooool2o`000=Cooooo000Noooo
o`03o`000?oooooooooo037ooooo0_l00008ooooo`;o00001_ooool2o`0000?ooooo1_l00003oooo
o`?o000000Coooooo`000?l0003ooooo1?l00007ooooo`Co00005?ooool2o`0002Kooooo0_l0000Q
ooooo`;o0000A_ooool2o`0001cooooo0_l0000Iooooo`007_ooool00ol0003oooooooooo`0koooo
o`;o00002_ooool2o`0000;ooooo1?l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`00
00Gooooo2?l00008ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0000;ooooo0_l0000V
ooooo`Co00007oooool2o`0000oooooo0_l0000eooooo`;o00007?ooool2o`0001?ooooo0_l00004
ooooo`007_ooool00ol0003oooooooooo`0booooo`;o00001oooool2o`0000[ooooo2?l00002oooo
o`Oo00000_ooool2o`0000?ooooo1?l00003ooooo`;o00001?ooool5o`000004ooooool0003o0000
o`0000;ooooo0_l0000Tooooo`;o00001_ooool2o`00033ooooo0_l0000jooooo`;o0000;?ooool2
o`0000Cooooo000Nooooo`04o`000?oooooo0000o`00037ooooo0_l00007ooooo`;o00000_ooool2
o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l000000oooool3o`000005ooooool0003o
0000o`000?ooool01ol00006ooooo`Co00000_ooool5o`000003ooooool0003o000000Cooooo0_l0
000Sooooo`;o0000M?ooool2o`0003;ooooo000Nooooo`04o`000?oooooo0000o`0002;ooooo0_l0
000Eooooo`;o00000oooool2o`0000Cooooo0_l00002ooooo`_o000000?oooooo`000?l000000_oo
ool7o`0000?ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l000001?oooooo0000o`00
0?ooool4o`0000;ooooo0_l00003ooooo`;o0000b?ooool001kooooo00?o0000ooooooooool05_oo
ool2o`0000_ooooo0_l0000;ooooo`;o00001oooool3o`0000oooooo2Ol000000ooooooo0000o`00
0003ooooo`;o00001oooool2o`0000Cooooo1Ol000000ooooooo0000o`000003ooooo`;o000000Co
ooooo`000?l0003o00000oooool2o`0000Cooooo0_l00023ooooo`;o0000?Oooool001kooooo00?o
0000ooooooooool05_ooool2o`0000?ooooo0_l0000Cooooo`;o00001oooool3o`0000Sooooo0_l0
0006ooooo`;o000000?oooooo`000?l000000_l00003ooooo`?o000000?oooooo`000?l000000_oo
ool4o`0000Cooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l00005ooooo`?o00002Ooo
ool2o`0007[ooooo0_l00007ooooo`;o0000?Oooool001kooooo0_l0000Looooo`;o00007Oooool2
o`0000Sooooo0_l00006ooooo`;o000000?oooooo`000?l000000_l00003ooooo`?o000000?ooooo
o`000?l000000_ooool4o`0000;ooooo1?l00002ooooo`?o000000?oooooo`000?l000000ol0000C
ooooo`;o0000<_ooool2o`0004?ooooo0_l0000eooooo`;o00003oooool001kooooo00?o0000oooo
ooooool0<oooool2o`0001Cooooo0_l00003ooooo`;o000000?oooooo`000?l000000oooool6o`00
00Oooooo0ol00005ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Cooooo`;o00008?ooool2
o`0000Oooooo0_l00007ooooo`;o0000N_ooool2o`0000oooooo000Nooooo`03o`000?oooooooooo
01[ooooo0_l0000Gooooo`;o00002oooool3o`000004ooooool0003o0000o`0000;ooooo0_l00000
0ooooooo0000o`000002o`0000?ooooo0_l00003ooooo`Co000000Coooooo`000?l0003o00000ooo
ool2o`0000Sooooo0ol0000hooooo`;o00001oooool2o`0009Cooooo000Nooooo`03o`000?oooooo
oooo01[ooooo0_l0000Tooooo`?o000000Coooooo`000?l0003o00000oooool8o`000003ooooool0
003o000000?ooooo2?l0000<ooooo`Ko00000_ooool4o`000<oooooo000Nooooo`03o`000?oooooo
oooo02Gooooo0_l0000Jooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00000_ooool7
o`0000Kooooo0_l000000ooooooo0000o`000005ooooo`;o00001Oooool2o`0000;ooooo0_l00000
0ooooooo0000o`000003o`0001cooooo0_l0000]ooooo`;o00000oooool2o`0007gooooo000Noooo
o`03o`000?oooooooooo02Gooooo0_l00006ooooo`;o00001_ooool2o`0000[ooooo0_l00003oooo
o`;o00000oooool2o`0000;ooooo1Ol0000Aooooo`;o00003?ooool2o`0001oooooo0_l0000Ioooo
o`;o00004_ooool2o`0000?ooooo0_l0000?ooooo`;o0000K?ooool001kooooo00?o0000oooooooo
ool0;Oooool2o`0000Kooooo1?l0000<ooooo`Go000000?oooooo`000?l000000_ooool2o`000003
ooooool0003o0000017ooooo0_l00006ooooo`;o00001?ooool2o`0000;ooooo0_l0000fooooo`;o
00005oooool2o`0000oooooo0_l0001/ooooo`007_ooool00ol0003oooooooooo`0Xooooo`;o0000
3Oooool2o`0000cooooo1ol000000ooooooo0000o`000002o`0001cooooo0_l00008ooooo`;o0000
;oooool2o`0000;ooooo0_l0002Iooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o00003Ooo
ool3o`0000Cooooo0_l00008ooooo`Co00001oooool6o`000004ooooool0003o0000ooooo`Co0000
00?oooooo`000?l000002oooool2o`0004Oooooo0_l00002ooooo`;o0000=oooool2o`00063ooooo
000Nooooo`03o`000?oooooooooo01Sooooo0_l0000=ooooo`;o00001?ooool3o`0000Sooooo1?l0
0007ooooo`go00000_ooool3o`0000[ooooo1?l0000Booooo`;o0000<Oooool2o`0003_ooooo0_l0
001Pooooo`007_ooool00ol0003oooooooooo`0]ooooo`;o00002?ooool2o`0000Sooooo0_l00000
0ooooooo0000o`000002ooooo`Oo000000?oooooo`000?l000000ol0000<ooooo`;o00004_ooool2
o`0001kooooo0_l0000Aooooo`;o00005oooool2o`0008Cooooo000Nooooo`03o`000?oooooooooo
03Kooooo0ol00008ooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o0000
00Co0000@_ooool2o`0002[ooooo0_l0000?ooooo`;o00000oooool2o`0006kooooo000Nooooo`03
o`000?oooooooooo02oooooo0_l00005ooooo`;o00004_ooool6o`000003ooooool0003o000000Ko
oooo0ol00006ooooo`;o00003oooool2o`00033ooooo0_l0000[ooooo`;o00000oooool2o`0006ko
oooo000Nooooo`03o`000?oooooooooo02_ooooo0_l00002ooooo`;o00000oooool2o`0001Kooooo
0ol0000:ooooo`?o00001_ooool2o`0000oooooo0_l0000`ooooo`;o0000X?ooool001kooooo00?o
0000ooooooooool00oooool2o`0002Kooooo0_l00007ooooo`;o00004_ooool2o`0000?ooooo0_l0
000Cooooo`;o00003oooool2o`0002;ooooo1?l0002/ooooo`007_ooool00ol0003oooooooooo`03
ooooo`;o0000@oooool2o`0001Sooooo0_l0000cooooo`Co0000[?ooool001kooooo0_l0000]oooo
o`;o00002Oooool2o`0000Kooooo0_l00007ooooo`;o0000WOooool2o`0005kooooo000Nooooo`03
o`000?oooooooooo02cooooo0_l00009ooooo`;o000000?oooooo`000?l000000oooool2o`0000Oo
oooo0_l0000?ooooo`;o00004?ooool2o`0000?ooooo0_l0001eooooo`;o0000G_ooool001kooooo
00?o0000ooooooooool0<?ooool2o`0000Sooooo0_l0000Mooooo`;o00004?ooool2o`0000?ooooo
0_l0003Eooooo`007_ooool00ol0003oooooooooo`0Tooooo`;o00002?ooool4o`0000?ooooo0_l0
0004ooooo`;o0000EOooool2o`0001kooooo0_l0000;ooooo`;o00006Oooool2o`0006_ooooo000N
ooooo`03o`000?oooooooooo02Cooooo0_l00005ooooo`;o000000?oooooo`000?l000001Oooool2
o`0000Cooooo0_l0001Eooooo`;o00001oooool2o`0001Gooooo0_l0000;ooooo`;o00006Oooool2
o`0006_ooooo000Nooooo`03o`000?oooooooooo02_ooooo0_l0000Iooooo`;o00001Oooool2o`00
0003ooooool0003o000000;o0000>_ooool2o`0000_ooooo0_l0002Zooooo`007_ooool00ol0003o
ooooooooo`0[ooooo`;o00001_ooool2o`00017ooooo0_l00005ooooo`;o000000?oooooo`000?l0
00000_l00009ooooo`;o0000;oooool2o`000;Oooooo000Nooooo`03o`000?oooooooooo02_ooooo
0_l00006ooooo`;o00001Oooool2o`0000Kooooo0_l00009ooooo`Oo00002Oooool2o`0001Kooooo
0_l0003@ooooo`007_ooool00ol0003oooooooooo`02ooooo`;o0000=_ooool2o`0000Kooooo0_l0
0009ooooo`?o00005oooool2o`0000cooooo0_l00014ooooo`;o0000<Oooool2o`0005Oooooo000N
ooooo`03o`000?oooooooooo00;ooooo0_l0000cooooo`;o00000_ooool3o`00013ooooo0_l0000G
ooooo`;o00003oooool2o`00017ooooo0_l0000^ooooo`;o0000<Oooool2o`0005Oooooo000Noooo
o`03o`000?oooooooooo01kooooo0_l00003ooooo`;o00004_ooool2o`0000;ooooo0ol0000joooo
o`;o00004Oooool2o`0002Wooooo0_l0000Dooooo`;o0000NOooool001kooooo00?o0000oooooooo
ool07Oooool3o`0000?ooooo0_l0000Rooooo`Go00007Oooool2o`0001Kooooo0_l00008ooooo`;o
00001oooool2o`00023ooooo0_l0000Dooooo`;o0000NOooool001kooooo00?o0000ooooooooool0
7Oooool2o`000003ooooool0003o000002Gooooo1Ol0000Mooooo`;o00005_ooool2o`0000Sooooo
0_l00007ooooo`;o0000/Oooool001kooooo00?o0000ooooooooool08?ooool2o`0001gooooo0_l0
000:ooooo`;o00006Oooool2o`000<Kooooo0_l0000Gooooo`005?ooool4o`000003oa0@4?oooooo
oooo00?ooooo00?o0000ooooooooool03oooool2o`0000?ooooo0_l0000?ooooo`;o00006?ooool2
o`0000[ooooo0_l0000Iooooo`;o0000a_ooool2o`0001Oooooo000Fooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool03oooool2o`0000?ooooo0_l0000?ooooo`;o00008?ooool2o`00
01cooooo0_l0000Jooooo`;o00001Oooool2o`00037ooooo0_l0000Mooooo`;o0000Joooool001Ko
oooo00?o0000ooooooooool01Oooool3o`0004Oooooo0_l0000Looooo`;o00006_ooool2o`0000Go
oooo0_l0000aooooo`;o00007Oooool2o`0002Oooooo0_l00005ooooo`;o0000>oooool001Kooooo
00?o0000ooooooooool0ooooool<ooooo`;o00001Oooool2o`0003_ooooo000Fooooo`03o`000?oo
oooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0
003oooooooooo`3ooooooe3ooooo000Dooooo`03oeEEEOmVIVKo00000?ooooooD_ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.39911 .91558 Mdot
.23209 .07971 Mdot
.20624 .87778 Mdot
.33152 .91699 Mdot
.18906 .78141 Mdot
.26449 .85933 Mdot
.5653 .62494 Mdot
.16639 .84804 Mdot
.31894 .8875 Mdot
.24034 .92565 Mdot
.16727 .78547 Mdot
.28421 .7124 Mdot
.15664 .8276 Mdot
.61243 .86314 Mdot
.22173 .8557 Mdot
.11592 .27786 Mdot
.00648 .65573 Mdot
.24849 .81375 Mdot
.40162 .9331 Mdot
.35475 .90152 Mdot
.74248 .99217 Mdot
.28981 .84801 Mdot
.18836 .84965 Mdot
.07278 .87913 Mdot
.29472 .91875 Mdot
.15243 .86961 Mdot
.27345 .92061 Mdot
.19341 .90172 Mdot
.18194 .74042 Mdot
.30388 .9047 Mdot
.29475 .86698 Mdot
.23051 .85193 Mdot
.21991 .92409 Mdot
.9856 .57174 Mdot
.38641 .99233 Mdot
.24325 .84928 Mdot
.48609 .8685 Mdot
.41103 .71967 Mdot
.32405 .71258 Mdot
.26821 .94678 Mdot
.31768 .89037 Mdot
.52604 .83911 Mdot
.11185 .78748 Mdot
.95388 .87496 Mdot
.58376 .01414 Mdot
.52315 .82231 Mdot
.62593 .03753 Mdot
.28664 .15188 Mdot
.21603 .88815 Mdot
.27033 .60649 Mdot
.3588 .82303 Mdot
.34402 .0678 Mdot
.12637 .81021 Mdot
.21963 .70699 Mdot
.12683 .7933 Mdot
.0474 .40972 Mdot
.59469 .80663 Mdot
.14681 .8211 Mdot
.2703 .91786 Mdot
.13887 .89999 Mdot
.26628 .91468 Mdot
.18346 .85872 Mdot
.01146 .81548 Mdot
.28138 .89402 Mdot
.23618 .85132 Mdot
.31261 .83271 Mdot
.41407 .0153 Mdot
.27202 .92195 Mdot
.25145 .84313 Mdot
.2354 .86299 Mdot
.27479 .00679 Mdot
.09448 .64656 Mdot
.41615 .86071 Mdot
.26172 .79772 Mdot
.1436 .95135 Mdot
.62014 .82325 Mdot
.29957 .93624 Mdot
.54932 .41338 Mdot
.26319 .88136 Mdot
.97513 .78698 Mdot
.38456 .10529 Mdot
.64786 .30519 Mdot
.92356 .27286 Mdot
.17256 .84705 Mdot
.7389 .74981 Mdot
.55339 .9892 Mdot
.1666 .83877 Mdot
.26185 .96218 Mdot
.23113 .84597 Mdot
.98129 .76431 Mdot
.24623 .81535 Mdot
.53825 .02251 Mdot
.15134 .65114 Mdot
.89983 .74467 Mdot
.36362 .94428 Mdot
.28844 .14297 Mdot
.92244 .68079 Mdot
.42357 .055 Mdot
.15105 .76074 Mdot
.02498 .57183 Mdot
.21017 .87801 Mdot
.44413 .89735 Mdot
.29465 .89144 Mdot
.26237 .9285 Mdot
.28449 .01527 Mdot
.19037 .8307 Mdot
.1152 .249 Mdot
.11904 .28613 Mdot
.2358 .03295 Mdot
.82354 .85447 Mdot
.46923 .89866 Mdot
.87024 .56621 Mdot
.21489 .12367 Mdot
.25463 .82573 Mdot
.50599 .10795 Mdot
.51039 .61345 Mdot
.59697 .96967 Mdot
.16291 .8341 Mdot
.09336 .50409 Mdot
.11249 .08564 Mdot
.2638 .95398 Mdot
.27059 .06115 Mdot
.14313 .98246 Mdot
.87655 .64847 Mdot
.60787 .83008 Mdot
.10026 .05773 Mdot
.20574 .82407 Mdot
.40342 .92164 Mdot
.99475 .59433 Mdot
.20266 .00935 Mdot
.37773 .06374 Mdot
.53675 .4736 Mdot
.33517 .35944 Mdot
.26885 .8568 Mdot
.34075 .87962 Mdot
.24759 .84349 Mdot
.18623 .82036 Mdot
.13514 .65294 Mdot
.36029 .85642 Mdot
.31038 .85135 Mdot
.4065 .88595 Mdot
.25466 .87533 Mdot
.26803 .87144 Mdot
.0675 .61465 Mdot
.95849 .99322 Mdot
.26024 .74197 Mdot
.38729 .90551 Mdot
.24027 .91241 Mdot
.74134 .9939 Mdot
.80557 .38751 Mdot
.22952 .78981 Mdot
.23113 .93013 Mdot
.30993 .71726 Mdot
.34983 .91063 Mdot
.23326 .86901 Mdot
.1473 .82393 Mdot
.20317 .65058 Mdot
.57185 .36029 Mdot
.31649 .90782 Mdot
.09797 .25893 Mdot
.16945 .64537 Mdot
.33293 .74928 Mdot
.60266 .82841 Mdot
.2521 .90006 Mdot
.17084 .77308 Mdot
.16188 .77707 Mdot
.23031 .92055 Mdot
.29306 .91704 Mdot
.40892 .66856 Mdot
.23708 .77864 Mdot
.20476 .93521 Mdot
.39547 .0161 Mdot
.40456 .89298 Mdot
.36504 .0097 Mdot
.38181 .91955 Mdot
.30285 .6362 Mdot
.99096 .97406 Mdot
.13027 .88292 Mdot
.53573 .85004 Mdot
.35713 .06334 Mdot
.15805 .70534 Mdot
.13985 .77992 Mdot
.31647 .95033 Mdot
.64265 .9633 Mdot
.16399 .35454 Mdot
.40359 .96165 Mdot
.12063 .18462 Mdot
.20393 .78736 Mdot
.12352 .68132 Mdot
.11947 .72493 Mdot
.38999 .92507 Mdot
.74712 .92453 Mdot
.40398 .91507 Mdot
.12147 .96825 Mdot
.17107 .10747 Mdot
.07783 .79343 Mdot
.30796 .7221 Mdot
.17715 .92668 Mdot
.31754 .88695 Mdot
.15941 .98029 Mdot
.40537 .70447 Mdot
.49704 .14152 Mdot
.29048 .87278 Mdot
.55829 .02374 Mdot
.29252 .91512 Mdot
.26645 .96247 Mdot
.05335 .04625 Mdot
.25541 .93858 Mdot
.9398 .76602 Mdot
.24433 .62762 Mdot
.21981 .75759 Mdot
.40821 .88019 Mdot
.66419 .7447 Mdot
.37228 .50179 Mdot
.15197 .65312 Mdot
.20293 .12632 Mdot
.24429 .93638 Mdot
.20439 .0699 Mdot
.28074 .73665 Mdot
.56319 .89944 Mdot
.04003 .96988 Mdot
.28287 .95632 Mdot
.2115 .83728 Mdot
.29228 .90064 Mdot
.00211 .77767 Mdot
.18193 .59906 Mdot
.2185 .91867 Mdot
.19322 .86902 Mdot
.16805 .96818 Mdot
.2894 .85242 Mdot
.14798 .84956 Mdot
.09352 .87565 Mdot
.23206 .9029 Mdot
.24217 .79581 Mdot
.20502 .25828 Mdot
.93992 .72931 Mdot
.82053 .34899 Mdot
.22817 .85909 Mdot
.75412 .63561 Mdot
.84617 .81244 Mdot
.18815 .7801 Mdot
.23858 .88947 Mdot
.31296 .00874 Mdot
.30946 .77906 Mdot
.37843 .76873 Mdot
.16692 .06183 Mdot
.1621 .85128 Mdot
.24424 .91576 Mdot
.69858 .35 Mdot
.297 .90506 Mdot
.31049 .05563 Mdot
.1394 .7821 Mdot
.59584 .36806 Mdot
.03574 .05025 Mdot
.31907 .0993 Mdot
.22489 .07664 Mdot
.13667 .79905 Mdot
.73173 .7996 Mdot
.41433 .04751 Mdot
.82462 .86718 Mdot
.40419 .89242 Mdot
.30074 .80375 Mdot
.24234 .68845 Mdot
.87263 .71915 Mdot
.23923 .89128 Mdot
.14311 .68795 Mdot
.35493 .04087 Mdot
.69652 .86773 Mdot
.20333 .85618 Mdot
.2784 .94161 Mdot
.15706 .76736 Mdot
.7054 .77956 Mdot
.25231 .89354 Mdot
.29648 .81469 Mdot
.42764 .0719 Mdot
.15797 .78561 Mdot
.27371 .77554 Mdot
.50753 .51135 Mdot
.22043 .78268 Mdot
.39239 .90415 Mdot
.47733 .76146 Mdot
.28143 .86481 Mdot
.22611 .9221 Mdot
.5035 .73873 Mdot
.15894 .78321 Mdot
.21935 .84549 Mdot
.2446 .78781 Mdot
.96874 .67532 Mdot
.19076 .93212 Mdot
.29659 .80597 Mdot
.25454 .9435 Mdot
.71318 .66367 Mdot
.39754 .9349 Mdot
.9982 .9646 Mdot
.27705 .05518 Mdot
.07952 .62288 Mdot
.19564 .86207 Mdot
.18522 .98394 Mdot
.40077 .86552 Mdot
.1861 .25686 Mdot
.88114 .73863 Mdot
.10162 .78534 Mdot
.35944 .84938 Mdot
.1284 .66008 Mdot
.84271 .18478 Mdot
.13061 .93694 Mdot
.27529 .91563 Mdot
.25272 .89242 Mdot
.43392 .58012 Mdot
.46217 .07808 Mdot
.26257 .94855 Mdot
.51311 .02353 Mdot
.16098 .87239 Mdot
.26683 .87755 Mdot
.2503 .8783 Mdot
.2492 .71249 Mdot
.33311 .71272 Mdot
.82926 .9895 Mdot
.13373 .8921 Mdot
.11652 .45364 Mdot
.32022 .71412 Mdot
.21097 .94896 Mdot
.41794 .96647 Mdot
.28275 .81283 Mdot
.28838 .844 Mdot
.14416 .84268 Mdot
.22133 .79675 Mdot
.40538 .87504 Mdot
.2378 .69121 Mdot
.16241 .85028 Mdot
.33626 .87685 Mdot
.27231 .8427 Mdot
.40719 .35082 Mdot
.65654 .96639 Mdot
.26201 .80753 Mdot
.2528 .10247 Mdot
.6155 .80505 Mdot
.27432 .93622 Mdot
.10632 .333 Mdot
.12299 .02899 Mdot
.17597 .7855 Mdot
.36618 .49655 Mdot
.40729 .86536 Mdot
.12295 .68014 Mdot
.93354 .48847 Mdot
.20788 .18525 Mdot
.05074 .79563 Mdot
.22644 .50695 Mdot
.37947 .98437 Mdot
.16446 .84843 Mdot
.1812 .84935 Mdot
.13316 .7866 Mdot
.29724 .80836 Mdot
.22126 .22074 Mdot
.94838 .17198 Mdot
.25131 .90362 Mdot
.50343 .87639 Mdot
.2588 .97475 Mdot
.15897 .81736 Mdot
.24202 .01507 Mdot
.26455 .8839 Mdot
.42073 .78414 Mdot
.31521 .87631 Mdot
.21036 .76002 Mdot
.17225 .8114 Mdot
.37487 .03748 Mdot
.26876 .17186 Mdot
.05408 .48539 Mdot
.39118 .31407 Mdot
.28858 .85264 Mdot
.14765 .66346 Mdot
.27714 .91249 Mdot
.22597 .88701 Mdot
.31492 .84382 Mdot
.84232 .8828 Mdot
.00193 .61986 Mdot
.56007 .00634 Mdot
.24071 .92433 Mdot
.70204 .26488 Mdot
.28021 .94039 Mdot
.26247 .87739 Mdot
.33876 .87442 Mdot
.18189 .36235 Mdot
.51902 .1965 Mdot
.27209 .68073 Mdot
.15952 .95468 Mdot
.09341 .09893 Mdot
.83723 .08762 Mdot
.27589 .9311 Mdot
.04354 .83617 Mdot
.40698 .8852 Mdot
.19555 .7648 Mdot
.1776 .88784 Mdot
.18035 .8036 Mdot
.19286 .79296 Mdot
.04692 .81194 Mdot
.08078 .74659 Mdot
.98889 .72169 Mdot
.26796 .92165 Mdot
.30921 .85496 Mdot
.07662 .84548 Mdot
.53941 .06621 Mdot
.52968 .55909 Mdot
.18143 .85441 Mdot
.23631 .54536 Mdot
.07119 .15339 Mdot
.30595 .86608 Mdot
.03517 .70453 Mdot
.21441 .67213 Mdot
.24956 .89219 Mdot
.12162 .64338 Mdot
.308 .92494 Mdot
.15246 .64782 Mdot
.23312 .75544 Mdot
.64241 .04701 Mdot
.24436 .80472 Mdot
.18856 .9813 Mdot
.17548 .59796 Mdot
.21839 .23165 Mdot
.26023 .88175 Mdot
.28085 .93682 Mdot
.72505 .31384 Mdot
.86894 .61719 Mdot
.20347 .77135 Mdot
.14952 .8307 Mdot
.26822 .6428 Mdot
.44041 .6559 Mdot
.31887 .86276 Mdot
.10879 .67148 Mdot
.8364 .71121 Mdot
.09057 .74971 Mdot
.68872 .12604 Mdot
.54065 .59862 Mdot
.33383 .85953 Mdot
.30603 .16147 Mdot
.43525 .12728 Mdot
.27399 .71589 Mdot
.06918 .18096 Mdot
.28972 .91153 Mdot
.57066 .98322 Mdot
.32863 .0461 Mdot
.75054 .12296 Mdot
.65405 .11774 Mdot
.24429 .90472 Mdot
.15951 .73786 Mdot
.23694 .91501 Mdot
.18647 .94817 Mdot
.21514 .75429 Mdot
.10392 .6989 Mdot
.20586 .04393 Mdot
.00232 .78804 Mdot
.21578 .99516 Mdot
.19528 .80998 Mdot
.27347 .88806 Mdot
.30394 .80044 Mdot
.26363 .93923 Mdot
.30921 .9149 Mdot
.22608 .77534 Mdot
.98672 .65591 Mdot
.24768 .31595 Mdot
.32293 .85904 Mdot
.26207 .95402 Mdot
.26505 .87983 Mdot
.13834 .87841 Mdot
.29417 .70766 Mdot
.43664 .042 Mdot
.21406 .93904 Mdot
.65022 .1831 Mdot
.22487 .88428 Mdot
.39517 .02761 Mdot
.29373 .86568 Mdot
.17203 .854 Mdot
.17228 .85123 Mdot
.17201 .8489 Mdot
.21092 .84366 Mdot
.24107 .86069 Mdot
.17467 .77086 Mdot
.15454 .83235 Mdot
.94671 .52527 Mdot
.07573 .85894 Mdot
.42767 .04456 Mdot
.07585 .00305 Mdot
.26373 .87074 Mdot
.40532 .86954 Mdot
.3988 .91464 Mdot
.67331 .91449 Mdot
.39346 .11358 Mdot
.2216 .0546 Mdot
.41445 .93399 Mdot
.18607 .92614 Mdot
.23476 .88259 Mdot
.29912 .92238 Mdot
.28524 .46501 Mdot
.14439 .13948 Mdot
.27652 .88174 Mdot
.17362 .94528 Mdot
.13803 .86972 Mdot
.14298 .93956 Mdot
.74659 .71262 Mdot
.30494 .7131 Mdot
.13512 .95196 Mdot
.26164 .00536 Mdot
.36011 .01458 Mdot
.15001 .51198 Mdot
.23339 .79004 Mdot
.49261 .70973 Mdot
.1749 .86008 Mdot
.74286 .83448 Mdot
.30806 .92179 Mdot
.33052 .91911 Mdot
.37299 .86644 Mdot
.00994 .20569 Mdot
.22104 .37434 Mdot
.2005 .93331 Mdot
.17837 .79321 Mdot
.81361 .70357 Mdot
.23884 .68264 Mdot
.28281 .15003 Mdot
.38535 .06491 Mdot
.3214 .84589 Mdot
.28873 .98395 Mdot
.18221 .86277 Mdot
.26384 .88013 Mdot
.15052 .9765 Mdot
.00734 .58918 Mdot
.40136 .77795 Mdot
.1529 .69085 Mdot
.27449 .15304 Mdot
.20956 .81107 Mdot
.98725 .76665 Mdot
.75094 .43276 Mdot
.06373 .0123 Mdot
.16959 .78195 Mdot
.30259 .7379 Mdot
.16923 .84209 Mdot
.22914 .87979 Mdot
.25404 .85449 Mdot
.23207 .87648 Mdot
.19296 .69407 Mdot
.26296 .95901 Mdot
.30879 .85043 Mdot
.3623 .09807 Mdot
.22262 .7682 Mdot
.24179 .86604 Mdot
.33075 .88912 Mdot
.94123 .64819 Mdot
.05507 .64699 Mdot
.30752 .01012 Mdot
.22778 .86648 Mdot
.14706 .83734 Mdot
.22548 .79174 Mdot
.45779 .76405 Mdot
.23612 .90019 Mdot
.16505 .53305 Mdot
.35953 .08627 Mdot
.64467 .44525 Mdot
.20219 .03459 Mdot
.27011 .94083 Mdot
.26301 .83628 Mdot
.57093 .02668 Mdot
.23955 .84523 Mdot
.08586 .89118 Mdot
.40356 .71872 Mdot
.13907 .54838 Mdot
.24053 .78664 Mdot
.21068 .84139 Mdot
.1794 .61636 Mdot
.19747 .81836 Mdot
.57471 .35428 Mdot
.2363 .84789 Mdot
.28517 .11521 Mdot
.24027 .94051 Mdot
.24075 .85916 Mdot
.39622 .87376 Mdot
.18528 .77696 Mdot
.3029 .87172 Mdot
.14271 .21359 Mdot
.17792 .7393 Mdot
.14306 .78847 Mdot
.08162 .99543 Mdot
.76364 .64713 Mdot
.60237 .8789 Mdot
.23432 .77171 Mdot
.39994 .88316 Mdot
.10058 .70851 Mdot
.26599 .94893 Mdot
.37762 .99987 Mdot
.49597 .45781 Mdot
.15987 .92064 Mdot
.34858 .95077 Mdot
.15069 .83065 Mdot
.13368 .80253 Mdot
.16485 .66997 Mdot
.1629 .96116 Mdot
.32731 .76515 Mdot
.16976 .87068 Mdot
.29891 .65709 Mdot
.15325 .83519 Mdot
.25334 .91338 Mdot
.23408 .06604 Mdot
.282 .88352 Mdot
.28083 .92019 Mdot
.21875 .88361 Mdot
.42647 .05002 Mdot
.29988 .8164 Mdot
.24611 .91823 Mdot
.26109 .93764 Mdot
.28465 .87715 Mdot
.95694 .68845 Mdot
.40166 .90972 Mdot
.44342 .85498 Mdot
.43365 .21736 Mdot
.25869 .84756 Mdot
.92223 .86694 Mdot
.40726 .91033 Mdot
.13053 .25735 Mdot
.10377 .65308 Mdot
.99359 .97003 Mdot
.12884 .75267 Mdot
.59508 .82303 Mdot
.41107 .50766 Mdot
.2171 .16014 Mdot
.4004 .91755 Mdot
.27814 .12815 Mdot
.49282 .00427 Mdot
.27931 .0632 Mdot
.00928 .49414 Mdot
.62727 .61728 Mdot
.15476 .81019 Mdot
.48741 .88459 Mdot
.30152 .8246 Mdot
.29798 .90578 Mdot
.29429 .94718 Mdot
.60008 .77348 Mdot
.24174 .85972 Mdot
.87802 .35224 Mdot
.1686 .84489 Mdot
.11125 .64675 Mdot
.20662 .77439 Mdot
.221 .8508 Mdot
.17577 .86546 Mdot
.24904 .85445 Mdot
.51394 .88783 Mdot
.53582 .8142 Mdot
.25032 .56247 Mdot
.35859 .96181 Mdot
.27092 .79738 Mdot
.8984 .5958 Mdot
.17417 .8419 Mdot
.05627 .69289 Mdot
.11451 .72436 Mdot
.11541 .88211 Mdot
.24638 .08292 Mdot
.28927 .8953 Mdot
.97929 .59867 Mdot
.27701 .9459 Mdot
.11902 .81684 Mdot
.22771 .85165 Mdot
.92673 .75487 Mdot
.26589 .9297 Mdot
.57103 .98922 Mdot
.16055 .89687 Mdot
.91408 .96666 Mdot
.25241 .96031 Mdot
.59984 .71433 Mdot
.08922 .01301 Mdot
.25689 .88611 Mdot
.08845 .81822 Mdot
.02019 .5658 Mdot
.22665 .16077 Mdot
.9071 .622 Mdot
.4788 .40222 Mdot
.31816 .95123 Mdot
.27215 .98517 Mdot
.77954 .60999 Mdot
.17704 .86577 Mdot
.60194 .02201 Mdot
.19739 .76786 Mdot
.02839 .90952 Mdot
.62386 .95808 Mdot
.11205 .61643 Mdot
.07292 .63516 Mdot
.51909 .36441 Mdot
.39984 .93126 Mdot
.23681 .84916 Mdot
.39822 .78708 Mdot
.41956 .83608 Mdot
.74989 .08336 Mdot
.05167 .91937 Mdot
.21444 .81748 Mdot
.22935 .1231 Mdot
.59267 .03857 Mdot
.2205 .96341 Mdot
.38552 .02325 Mdot
.24316 .92353 Mdot
.16457 .91872 Mdot
.27204 .8854 Mdot
.99969 .98078 Mdot
.609 .78589 Mdot
.59063 .66185 Mdot
.17038 .77078 Mdot
.26619 .24573 Mdot
.15207 .8247 Mdot
.37696 .8577 Mdot
.2796 .94833 Mdot
.15334 .98002 Mdot
.36208 .58051 Mdot
.29772 .69202 Mdot
.26497 .18605 Mdot
.30365 .88411 Mdot
.79223 .98923 Mdot
.0623 .73188 Mdot
.52607 .11873 Mdot
.72939 .54248 Mdot
.17545 .85187 Mdot
.82841 .63858 Mdot
.25584 .892 Mdot
.17687 .8199 Mdot
.39463 .41498 Mdot
.21664 .91896 Mdot
.40757 .87046 Mdot
.59995 .82342 Mdot
.28789 .95578 Mdot
.11672 .7224 Mdot
.37494 .17604 Mdot
.82272 .97593 Mdot
.69849 .9121 Mdot
.26076 .95642 Mdot
.56703 .808 Mdot
.8794 .5718 Mdot
.19102 .99907 Mdot
.22075 .9648 Mdot
.14636 .83688 Mdot
.32001 .87422 Mdot
.09408 .18445 Mdot
.01125 .20097 Mdot
.92883 .54478 Mdot
.11797 .12868 Mdot
.25155 .75394 Mdot
.09906 .05079 Mdot
.24019 .79972 Mdot
.3542 .88099 Mdot
.37377 .90973 Mdot
.78343 .61742 Mdot
.93291 .71883 Mdot
.22175 .81962 Mdot
.28966 .94535 Mdot
.63148 .7558 Mdot
.06946 .87358 Mdot
.59027 .63807 Mdot
.28573 .92742 Mdot
.25391 .8743 Mdot
.02372 .02114 Mdot
.40495 .84928 Mdot
.3265 .94074 Mdot
.1738 .76992 Mdot
.23243 .7573 Mdot
.45244 .05775 Mdot
.15756 .77963 Mdot
.25073 .88007 Mdot
.46287 .83167 Mdot
.16918 .85186 Mdot
.3647 .50646 Mdot
.24847 .85998 Mdot
.32323 .00344 Mdot
.30962 .91103 Mdot
.01048 .55732 Mdot
.68676 .2342 Mdot
.17473 .92592 Mdot
.45697 .32311 Mdot
.26015 .8928 Mdot
.29783 .7891 Mdot
.21068 .83384 Mdot
.13952 .78193 Mdot
.53302 .59979 Mdot
.38495 .86806 Mdot
.06609 .81841 Mdot
.2326 .88023 Mdot
.29544 .81206 Mdot
.47941 .25672 Mdot
.33757 .90908 Mdot
.24498 .09889 Mdot
.91559 .88817 Mdot
.0557 .18394 Mdot
.22149 .90057 Mdot
.24184 .72585 Mdot
.15609 .21059 Mdot
.31063 .85539 Mdot
.29918 .91995 Mdot
.13991 .83768 Mdot
.42418 .89638 Mdot
.38202 .32348 Mdot
.28088 .54042 Mdot
.12663 .87335 Mdot
.2883 .69908 Mdot
.11784 .81458 Mdot
.20149 .9539 Mdot
.57842 .95916 Mdot
.30715 .87506 Mdot
.06897 .75307 Mdot
.48967 .16235 Mdot
.28794 .89602 Mdot
.22808 .77048 Mdot
.16206 .10338 Mdot
.0618 .80935 Mdot
.25745 .82484 Mdot
.16538 .78103 Mdot
.1969 .94002 Mdot
.13852 .57908 Mdot
.32515 .02862 Mdot
.99353 .60556 Mdot
.28072 .88504 Mdot
.1694 .86866 Mdot
.26008 .0936 Mdot
.20244 .77651 Mdot
.27778 .90571 Mdot
.50308 .4253 Mdot
.57593 .95098 Mdot
.22277 .87166 Mdot
.82348 .69484 Mdot
.16835 .84407 Mdot
.15945 .83139 Mdot
.06062 .81132 Mdot
.14661 .82472 Mdot
.17303 .85225 Mdot
.18393 .6734 Mdot
.13022 .81817 Mdot
.15002 .76265 Mdot
.70394 .42301 Mdot
.21708 .06627 Mdot
.51438 .94223 Mdot
.94344 .70749 Mdot
.17376 .79578 Mdot
.91785 .65582 Mdot
.49434 .82043 Mdot
.24545 .8498 Mdot
.99394 .18087 Mdot
.21744 .89203 Mdot
.1598 .82222 Mdot
.72649 .83929 Mdot
.44886 .94143 Mdot
.1573 .82935 Mdot
.27338 .91444 Mdot
.32023 .87061 Mdot
.62215 .86323 Mdot
.22119 .67043 Mdot
.53668 .105 Mdot
.17535 .85584 Mdot
.17354 .86876 Mdot
.26471 .87422 Mdot
.40354 .7314 Mdot
.0189 .75533 Mdot
.33438 .90335 Mdot
.32269 .99646 Mdot
.24129 .95475 Mdot
.41886 .07976 Mdot
.16797 .84861 Mdot
.3033 .38209 Mdot
.06525 .86523 Mdot
.18809 .85865 Mdot
.16797 .83695 Mdot
.30428 .92411 Mdot
.3011 .88245 Mdot
.01635 .6046 Mdot
.15172 .87542 Mdot
.14339 .82232 Mdot
.40163 .93145 Mdot
.27389 .73481 Mdot
.8984 .83416 Mdot
.1482 .82736 Mdot
.70396 .82536 Mdot
.23826 .94698 Mdot
.27327 .89696 Mdot
.31533 .83953 Mdot
.44905 .05116 Mdot
.17782 .82685 Mdot
.53732 .20441 Mdot
.08472 .76744 Mdot
.4962 .09794 Mdot
.37179 .9286 Mdot
.19435 .86142 Mdot
.30479 .90627 Mdot
.17256 .8538 Mdot
.14833 .83432 Mdot
.08598 .97166 Mdot
.39724 .91647 Mdot
.4079 .85944 Mdot
.80537 .23122 Mdot
.28717 .85288 Mdot
.05131 .93346 Mdot
.99951 .49637 Mdot
.5207 .1168 Mdot
.1304 .92523 Mdot
.27277 .87087 Mdot
.39386 .45939 Mdot
.19508 .88788 Mdot
.37098 .86619 Mdot
.22758 .87157 Mdot
.33876 .84221 Mdot
.08443 .79859 Mdot
.37235 .91134 Mdot
.4161 .00837 Mdot
.18805 .2594 Mdot
.28607 .89792 Mdot
.02786 .94745 Mdot
.30472 .17453 Mdot
.08377 .1937 Mdot
.31251 .91011 Mdot
.39121 .92893 Mdot
.4051 .8659 Mdot
.42237 .82384 Mdot
.91 .08217 Mdot
.1988 .7706 Mdot
.26649 .88438 Mdot
.19941 .84931 Mdot
.30707 .87844 Mdot
.4467 .78977 Mdot
.35105 .85098 Mdot
.2944 .12652 Mdot
.32016 .86934 Mdot
.82995 .61946 Mdot
.17121 .96552 Mdot
.40286 .91771 Mdot
.17495 .84245 Mdot
.22354 .8492 Mdot
.5968 .86283 Mdot
.15936 .09291 Mdot
.28754 .82528 Mdot
.96531 .14669 Mdot
.96277 .78772 Mdot
.20602 .91743 Mdot
.18577 .80365 Mdot
.15228 .82945 Mdot
.23835 .89338 Mdot
.65421 .95448 Mdot
.40632 .90096 Mdot
.5656 .36127 Mdot
.21992 .95282 Mdot
.25781 .89043 Mdot
.40692 .56995 Mdot
.14462 .82668 Mdot
.35656 .91954 Mdot
.29097 .92043 Mdot
.913 .64847 Mdot
.09902 .94582 Mdot
.25522 .86457 Mdot
.98886 .89929 Mdot
.51549 .89979 Mdot
.3101 .85852 Mdot
.56397 .15356 Mdot
.23711 .85018 Mdot
.34852 .86889 Mdot
.4072 .94556 Mdot
.19419 .03396 Mdot
.13863 .9413 Mdot
.16615 .85967 Mdot
.85445 .02886 Mdot
.83084 .83713 Mdot
.05111 .79745 Mdot
.1744 .73162 Mdot
.28852 .8598 Mdot
.28163 .89668 Mdot
.22094 .86852 Mdot
.97161 .77652 Mdot
.15295 .83891 Mdot
.65144 .43395 Mdot
.15798 .66243 Mdot
.19574 .5734 Mdot
.82995 .08892 Mdot
.4737 .34202 Mdot
.20735 .7702 Mdot
.82025 .48323 Mdot
.09859 .84529 Mdot
.94167 .59249 Mdot
.41624 .76773 Mdot
.18012 .86303 Mdot
.17848 .98866 Mdot
.88097 .76222 Mdot
.27032 .90352 Mdot
.24024 .93345 Mdot
.17022 .8136 Mdot
.29032 .9516 Mdot
.07811 .50424 Mdot
.12995 .14794 Mdot
.29636 .95037 Mdot
.24907 .01049 Mdot
.11237 .94318 Mdot
.18016 .26308 Mdot
.39669 .07833 Mdot
.25919 .91956 Mdot
.09584 .72516 Mdot
.33381 .9157 Mdot
.34063 .71166 Mdot
.64582 .31245 Mdot
.13838 .80001 Mdot
.25685 .95705 Mdot
.17596 .86866 Mdot
.32336 .62146 Mdot
.24645 .65224 Mdot
.15219 .99102 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`04ooooo`;o00001oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool02_ooool2o`000003ooooool0003ooooo00kooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool00_ooool001kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`;o0000
1_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`02o`0000;ooooo0_l00007ooooo`03o`000?oooooooooo00Cooooo
0_l00007ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0:ooooo`;o000000?oooooo`000?ooool03_ooool00ol0003oooooooooo`02o`0000cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo
000Nooooo`03o`000?oooooooooo03kooooo0_l0000=ooooo`;o00000_ooool2o`0000;ooooo0_l0
0009ooooo`Co00003oooool2o`0000kooooo0_l0000]ooooo`;o0000Toooool001kooooo00?o0000
ooooooooool04Oooool2o`0000Kooooo0_l0000Sooooo`;o00003Oooool2o`00017ooooo1?l0000?
ooooo`;o00003_ooool2o`000<;ooooo000Nooooo`03o`000?oooooooooo017ooooo0_l00006oooo
o`;o0000<?ooool2o`0000_ooooo0_l0000Gooooo`;o00002Oooool2o`0000Gooooo0_l0000eoooo
o`;o0000Roooool001kooooo00?o0000ooooooooool0Boooool2o`0000_ooooo0_l0000Gooooo`;o
00002Oooool2o`0000Gooooo0_l0000eooooo`;o0000Roooool001kooooo00?o0000ooooooooool0
1?ooool2o`000:Gooooo0_l0000Cooooo`;o0000QOooool001kooooo00?o0000ooooooooool01?oo
ool2o`0007?ooooo0_l0000Xooooo`;o00001_ooool2o`0000Cooooo0_l0000=ooooo`;o0000QOoo
ool001kooooo00?o0000ooooooooool09?ooool2o`00043ooooo0_l0000Aooooo`;o000000?ooooo
o`000?l000009Oooool2o`0000cooooo0_l00003ooooo`;o0000F_ooool2o`0003?ooooo000Noooo
o`03o`000?oooooooooo02Cooooo0_l00010ooooo`;o00005?ooool2o`0003Sooooo0_l0001Joooo
o`;o0000<oooool001kooooo00?o0000ooooooooool0>oooool2o`000003ooooool0003o000000Wo
oooo0_l0003looooo`007_ooool00ol0003oooooooooo`0kooooo`;o000000?oooooo`000?l00000
2Oooool2o`0002_ooooo0_l0001?ooooo`;o0000O_ooool001kooooo00?o0000ooooooooool0Kooo
ool2o`0000Gooooo0_l00015ooooo`;o00002?ooool2o`0007kooooo000Nooooo`03o`000?oooooo
oooo03oooooo0_l0000^ooooo`;o00006Oooool2o`00037ooooo0_l00028ooooo`007_ooool00ol0
003oooooooooo`0=ooooo`;o0000<?ooool2o`0002Kooooo0_l0000Jooooo`;o00000_ooool2o`00
0003ooooool0003o0000047ooooo0_l0001hooooo`007_ooool00ol0003oooooooooo`07ooooo`;o
00001?ooool2o`0005Sooooo0_l0000Jooooo`;o00000_ooool2o`0004Cooooo0_l0001hooooo`00
7_ooool2o`0000Sooooo0_l0000Cooooo`;o0000JOooool2o`0000Gooooo0_l0002gooooo`007_oo
ool00ol0003oooooooooo`0Looooo`;o00009_ooool2o`00013ooooo0_l00009ooooo`;o00008ooo
ool2o`0000Kooooo0_l0002gooooo`007_ooool00ol0003oooooooooo`0Looooo`;o00009_ooool2
o`00013ooooo0_l00009ooooo`;o00008oooool2o`0000Oooooo0_l0002fooooo`007_ooool00ol0
003oooooooooo`0Looooo`;o00005?ooool2o`00023ooooo0_l0000iooooo`;o0000]_ooool001ko
oooo00?o0000ooooooooool0<_ooool2o`00023ooooo0_l000000ooooooo0000o`00000Gooooo`;o
00001Oooool4o`000<cooooo000Nooooo`03o`000?oooooooooo04;ooooo0_l00004ooooo`;o0000
3Oooool2o`0001?ooooo0_l00002ooooo`;o00001Oooool4o`00033ooooo0_l0002Jooooo`007_oo
ool00ol0003oooooooooo`0nooooo`;o00000_ooool2o`0000Cooooo0_l0000Rooooo`;o00006Ooo
ool2o`0002;ooooo0_l0002Jooooo`007_ooool00ol0003oooooooooo`0nooooo`;o0000Aoooool2
o`000;kooooo000Nooooo`03o`000?oooooooooo04Gooooo0_l0000fooooo`;o00004oooool2o`00
0;?ooooo000Nooooo`03o`000?oooooooooo04Gooooo1?l0000dooooo`;o00001Oooool2o`0000co
oooo0_l0002cooooo`007_ooool00ol0003oooooooooo`17ooooo`;o00000oooool2o`0003Kooooo
0_l0001Zooooo`;o0000<_ooool2o`00027ooooo000Nooooo`03o`000?oooooooooo023ooooo0_l0
000Zooooo`;o00008oooool2o`0007gooooo0_l0000booooo`;o00008Oooool001kooooo00?o0000
ooooooooool08?ooool2o`0004oooooo0_l0002Gooooo`Co0000>Oooool001kooooo00?o0000oooo
ooooool0<?ooool2o`0001kooooo0_l0002hooooo`Co0000>Oooool001kooooo00?o0000oooooooo
ool0<?ooool2o`0001kooooo0_l0003eooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o0000
<?ooool2o`0001Kooooo0_l0000<ooooo`;o0000:Oooool2o`000:Sooooo000Nooooo`;o00006ooo
ool2o`00033ooooo1?l0000Dooooo`;o00003?ooool2o`0002Wooooo0_l0002Xooooo`007_ooool0
0ol0003oooooooooo`0aooooo`;o00006oooool2o`0002Wooooo0_l0000_ooooo`;o0000Voooool0
01kooooo00?o0000ooooooooool0<Oooool4o`0004Cooooo0_l0000Uooooo`;o00002?ooool2o`00
09_ooooo000Nooooo`03o`000?oooooooooo03?ooooo0_l0001[ooooo`;o0000YOooool001kooooo
00?o0000ooooooooool0FOooool2o`00027ooooo0_l00039ooooo`007_ooool00ol0003ooooooooo
o`1Iooooo`;o00008Oooool2o`0002Oooooo0_l0000Zooooo`;o0000M?ooool001kooooo00?o0000
ooooooooool0YOooool4o`0002Sooooo0_l0001dooooo`007_ooool00ol0003oooooooooo`12oooo
o`;o00000_ooool2o`0005oooooo0_l00017ooooo`;o0000EOooool001kooooo00?o0000oooooooo
ool0?_ooool2o`0000;ooooo0_l00002ooooo`;o00005?ooool2o`0002_ooooo0_l0001Aooooo`;o
00004_ooool2o`0005Gooooo000Nooooo`03o`000?oooooooooo02;ooooo0_l0000Jooooo`;o0000
5_ooool2o`0000Cooooo0_l0000[ooooo`;o0000DOooool2o`0006Wooooo000Nooooo`03o`000?oo
oooooooo02;ooooo0_l0000booooo`;o0000koooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`0[ooooo`;o0000oooooolKooooo`007_ooool00ol0003o
ooooooooo`0[ooooo`;o0000L?ooool2o`000:Sooooo000Nooooo`03o`000?oooooooooo05[ooooo
0_l00011ooooo`;o0000Z?ooool001kooooo00?o0000ooooooooool09_ooool2o`0003;ooooo0_l0
003Jooooo`;o00003oooool001kooooo0_l0000Wooooo`;o0000<?ooool3o`000=_ooooo0_l0000?
ooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o0000@?ooool2o`000004ooooool0003o0000
o`0005Sooooo0_l0002Booooo`007_ooool00ol0003oooooooooo`0Cooooo`;o0000@?ooool2o`00
05cooooo0_l0002Booooo`007_ooool00ol0003oooooooooo`12ooooo`;o00000_ooool2o`000?oo
oooo000Nooooo`03o`000?oooooooooo04;ooooo0_l00002ooooo`;o00005oooool2o`0003[ooooo
0_l0002Zooooo`007_ooool00ol0003oooooooooo`1Oooooo`;o0000>_ooool2o`000:[ooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0Doooool2o`00
0=_ooooo0_l0000Eooooo`007_ooool00ol0003oooooooooo`1Cooooo`;o00002_ooool2o`0001Go
oooo0_l0002hooooo`;o00005Oooool001kooooo00?o0000ooooooooool0Goooool2o`0001Gooooo
0_l0003?ooooo`007_ooool00ol0003oooooooooo`0Booooo`;o0000ooooool/ooooo`;o00001_oo
ool001kooooo00?o0000ooooooooool03_ooool2o`0000;ooooo0_l00006ooooo`;o00001oooool2
o`0001[ooooo0_l0002>ooooo`;o0000?Oooool2o`0002oooooo0_l00006ooooo`007_ooool00ol0
003oooooooooo`0>ooooo`;o00002_ooool2o`0000Oooooo0_l0000Jooooo`;o00004Oooool2o`00
07_ooooo0_l0000mooooo`;o0000=oooool001kooooo00?o0000ooooooooool0D_ooool2o`000??o
oooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03
o`000?oooooooooo01Oooooo0_l0003ooooooboooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo
01Oooooo0_l0002<ooooo`;o0000X?ooool000?ooooo00Go410@oooooooooooooooooa0@400<oooo
o`03oiRHV?lQ8B7ok^k^00Oooooo1Ol0002Sooooo`;o0000X?ooool000?ooooo00Go0000oooooooo
ooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool00_l0002Yoooo
o`;o0000V_ooool000?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo
00Gooooo00Co0000ooooool0003o0000Z_ooool2o`0009[ooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41003oooool00ol0003oooooooooo`04ooooo`04o`000?oooooo0000o`0002kooooo0_l0
003ooooooaOooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooo
oonHV9So410@00Kooooo00?o0000ooooooooool0:_ooool2o`0000?ooooo0_l0003ooooooaOooooo
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Ko
oooo00?o0000ooooooooool0:_ooool2o`000?oooooo7?ooool001kooooo00?o0000ooooooooool0
ROooool2o`000;cooooo000Nooooo`03o`000?oooooooooo04Cooooo0_l00013ooooo`;o0000_?oo
ool001kooooo00?o0000ooooooooool0A?ooool2o`000?oooooo0_ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`13ooooo`;o0000_Oooool2o`0004?o
oooo000Nooooo`03o`000?oooooooooo04?ooooo0_l0002Fooooo`;o00009Oooool2o`0004?ooooo
000Nooooo`03o`000?oooooooooo0=_ooooo0_l0001Zooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0D_ooool2o`000??ooooo000Nooooo`03o`000?oooooooooo027ooooo0_l0000_ooooo`;o0000
loooool001kooooo0_l0000Rooooo`;o0000oooooolUooooo`007_ooool00ol0003oooooooooo`2H
ooooo`;o0000[Oooool001kooooo00?o0000ooooooooool07?ooool2o`0000Sooooo0_l0000@oooo
o`?o00001?ooool2o`0005Oooooo0_l0002]ooooo`007_ooool00ol0003oooooooooo`0Looooo`;o
00002?ooool2o`00013ooooo0ol00004ooooo`;o0000ooooool7ooooo`007_ooool00ol0003ooooo
ooooo`0fooooo`;o0000Z?ooool2o`0006Gooooo000Nooooo`03o`000?oooooooooo03Kooooo0_l0
002Xooooo`;o0000IOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooobWooooo0_l0000Mooooo`007_ooool00ol0003oooooooooo`0Rooooo`;o
0000ooooool5ooooo`;o00007Oooool001kooooo00?o0000ooooooooool08_ooool2o`000?oooooo
9?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`0S
ooooo`;o0000oooooolSooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o0000oooooolSoooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool0
01kooooo00?o0000ooooooooool0coooool2o`0007Kooooo000Nooooo`03o`000?oooooooooo0<oo
oooo0_l0001fooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo07_ooooo0_l0001Aooooo`;o00006?ooool2o`0005gooooo000Nooooo`03o`000?oooooo
oooo04cooooo0_l0000]ooooo`;o0000DOooool2o`0001Sooooo0_l0001Mooooo`007_ooool00ol0
003oooooooooo`1<ooooo`;o0000nOooool001kooooo00?o0000ooooooooool0N?ooool2o`0001Ko
oooo0_l0002eooooo`007_ooool00ol0003oooooooooo`1hooooo`;o00005_ooool2o`000;Gooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool07_ooool2
o`000?oooooo:?ooool001kooooo00?o0000ooooooooool07_ooool2o`000?oooooo:?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`2Fooooo`;o0000
[oooool001kooooo00?o0000ooooooooool0U_ooool2o`000:oooooo000Nooooo`03o`000?oooooo
oooo0?oooooo2?ooool2o`0003kooooo000Nooooo`;o0000POooool2o`0005gooooo0_l0000Voooo
o`;o0000?_ooool001kooooo00?o0000ooooooooool0<Oooool2o`0004gooooo0_l0000eooooo`;o
00009_ooool2o`0003Sooooo0_l0000/ooooo`007_ooool00ol0003oooooooooo`0aooooo`;o0000
Q?ooool2o`00063ooooo0_l0000/ooooo`007_ooool00ol0003oooooooooo`1Yooooo`;o0000BOoo
ool4o`0008oooooo000Nooooo`03o`000?oooooooooo03Oooooo0_l0000`ooooo`;o0000BOooool4
o`0008oooooo000Nooooo`03o`000?oooooooooo03Oooooo0_l0001/ooooo`;o0000X?ooool001ko
oooo00?o0000ooooooooool0YOooool2o`0001Oooooo0_l00027ooooo`007_ooool00ol0003ooooo
ooooo`2nooooo`;o0000Qoooool001kooooo00?o0000ooooooooool0A?ooool2o`000?oooooo0_oo
ool001kooooo00?o0000ooooooooool0A?ooool2o`000?oooooo0_ooool001kooooo00?o0000oooo
ooooool0G_ooool2o`000>Oooooo000Nooooo`03o`000?oooooooooo05kooooo0_l0003Wooooo`00
7_ooool00ol0003oooooooooo`3oooooo`?ooooo0_l00013ooooo`007_ooool00ol0003ooooooooo
o`3oooooo`?ooooo0_l00013ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodSooooo0003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0000Kooooo0ol0003oooooodSooooo0003ooooo`05o`000?ooooooooooooooool000002ooo
ool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo09Sooooo0_l0002]ooooo`000ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003o
ooooooooo`2Hooooo`;o0000[Oooool000?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03
ogMgMoo<c<co000000Oooooo00?o0000ooooooooool02oooool2o`000?oooooo>oooool000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000oooooooo
ool02oooool2o`000:7ooooo0_l0002Gooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00go
oooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`1looooo`;o0000<?ooool2o`0009Oo
oooo000Nooooo`03o`000?oooooooooo07cooooo0_l00039ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo09oooooo0_l00010ooooo`;o0000I?ooool0
01kooooo00?o0000ooooooooool0Woooool2o`00043ooooo0_l0001Tooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0=3ooooo0_l0000Nooooo`;o0000
EOooool001kooooo00?o0000ooooooooool0d?ooool2o`0001kooooo0_l0001Eooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0cOooool2o`0007Sooooo000Nooooo`03o`000?oooooooooo0<gooooo
0_l0001hooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool08_ooool2
o`000?oooooo9?ooool001kooooo00?o0000ooooooooool08_ooool2o`0005Sooooo0_l0000Ooooo
o`;o0000Z?ooool001kooooo00?o0000ooooooooool0O?ooool2o`0001oooooo0_l0002Xooooo`00
7_ooool00ol0003oooooooooo`1Iooooo`;o0000k?ooool001kooooo00?o0000ooooooooool0FOoo
ool2o`000>cooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0Z_ooool2o`0009_ooooo000Nooooo`03o`000?oooooooooo0:[ooooo0_l0002Kooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo2?oo
ool2o`0003kooooo000Nooooo`03o`000?oooooooooo00gooooo0_l0003hooooo`;o0000?_ooool0
01kooooo00?o0000ooooooooool03Oooool2o`000?oooooo7Oooool2o`0001[ooooo000Nooooo`03
o`000?oooooooooo0?oooooo;?ooool2o`0001[ooooo000Nooooo`04o`000?oooooo0000o`0007;o
oooo0_l0003<ooooo`;o00001?ooool001kooooo00Co0000ooooool0003o0000L_ooool2o`000<co
oooo0_l00004ooooo`007_ooool2o`0007Kooooo0_l0003@ooooo`007_ooool00ol0003ooooooooo
o`0Eooooo`;o00000oooool2o`0005Wooooo0_l0003@ooooo`007_ooool00ol0003oooooooooo`0E
ooooo`;o00000oooool2o`0002[ooooo0_l0000Zooooo`;o00003_ooool2o`000<?ooooo000Noooo
o`03o`000?oooooooooo02gooooo0_l0000Gooooo`;o0000:_ooool2o`0000kooooo0_l0000Moooo
o`;o0000Y?ooool001kooooo00?o0000ooooooooool0;Oooool2o`0007;ooooo0_l0002Tooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
oc7ooooo0_l0000Eooooo`007_ooool00ol0003oooooooooo`3ooooooc7ooooo0_l0000Eooooo`00
7_ooool00ol0003oooooooooo`0booooo`;o0000oooooolDooooo`007_ooool00ol0003ooooooooo
o`0booooo`;o0000oooooolDooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo05Oooooo0_l0002@ooooo`;o0000G?ooool001kooooo00?o0000oooooooo
ool0BOooool2o`0000cooooo0_l0002@ooooo`;o0000?oooool2o`0001_ooooo000Nooooo`03o`00
0?oooooooooo02Wooooo0_l0000Nooooo`;o0000goooool2o`0001_ooooo000Nooooo`;o0000:_oo
ool2o`000?oooooo7Oooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool01?l0
003oooooo`000?l0003oooooodOooooo000Nooooo`04o`000?oooooo0000o`000:Oooooo0_l0002M
ooooo`007_ooool00ol0003oooooooooo`1=ooooo`;o0000FOooool2o`0009gooooo000Nooooo`03
o`000?oooooooooo00;ooooo0_l00019ooooo`;o0000b?ooool2o`0002kooooo000Nooooo`03o`00
0?oooooooooo00;ooooo0_l0001looooo`;o0000UOooool2o`0002kooooo000Nooooo`03o`000?oo
oooooooo00Cooooo0_l0000fooooo`;o0000@_ooool2o`0009Sooooo0_l0000Pooooo`;o00002Ooo
ool001kooooo00?o0000ooooooooool01?ooool2o`0003Kooooo0_l0003Looooo`;o00008?ooool2
o`0000Wooooo000Nooooo`03o`000?oooooooooo02Wooooo0_l0003ooooooagooooo000Nooooo`03
o`000?oooooooooo02Wooooo0_l00017ooooo`;o00005Oooool2o`000;cooooo000Nooooo`03o`00
0?oooooooooo07;ooooo0_l0000Eooooo`;o0000_?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool3o`000?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo0ol0003ooooooboooooo0_l0
000?ooooo`;o00001_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0=Oooool2o`000>Wooooo
0_l0000<ooooo`;o00003oooool2o`0000Kooooo0003ooooo`05oa0@4?ooooooooooooooool@4100
2oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0000eooooo`Co0000L?ooool2o`000003
ooooool0003o000007;ooooo0_l0000Hooooo`;o00002oooool000?ooooo00Go0000oooooooooooo
ooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0goooo
o`;o0000L?ooool2o`000003ooooool0003o000008cooooo0_l0000;ooooo`000oooool01Ol0003o
oooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`04o`000?oooooo
ooooooooo`;o0000DOooool2o`000>Wooooo0_l00006ooooo`000oooool01Ol@413ooooooooooooo
oooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool01?l0003oooooooooooooool2o`00057ooooo
0_l0002Sooooo`;o0000A?ooool2o`0000Kooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo0:;ooooo0_l0001Eooooo`;o0000
C?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Ko
oooo00?o0000ooooooooool04_ooool2o`0000cooooo0_l0000Dooooo`;o0000J_ooool2o`000:?o
oooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0000<ooooo`;o00005?ooool2o`00093ooooo
0_l0000aooooo`;o00003Oooool2o`0000[ooooo0_l0000_ooooo`007_ooool2o`0006Kooooo0_l0
001Qooooo`;o0000<Oooool2o`0000gooooo0_l0000:ooooo`;o00002oooool2o`0002;ooooo000N
ooooo`;o00005oooool2o`0004gooooo0_l0001=ooooo`;o0000KOooool2o`0002;ooooo000Noooo
o`03o`000?oooooooooo01Kooooo0_l0000cooooo`;o0000Ioooool2o`00097ooooo000Nooooo`03
o`000?oooooooooo04_ooooo0_l0003jooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo01Cooooo0_l00018ooooo`;o0000G?ooool2o`0003?ooooo0_l0
001Dooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o0000B?ooool2o`0005cooooo0_l0000c
ooooo`;o00005_ooool2o`0003cooooo000Nooooo`03o`000?oooooooooo02?ooooo0_l0000^oooo
o`;o0000]?ooool2o`0003cooooo000Nooooo`03o`000?oooooooooo00kooooo0_l0000;ooooo`;o
00000oooool2o`000003ooooool0003o000000kooooo0_l0000Nooooo`;o0000Woooool2o`00057o
oooo000Nooooo`03o`000?oooooooooo00kooooo0_l0000;ooooo`;o00000oooool2o`0000_ooooo
0_l00004ooooo`;o0000_oooool2o`0002?ooooo0_l0000:ooooo`;o00001oooool2o`0001Oooooo
000Nooooo`;o00007oooool2o`0000Sooooo0_l00003ooooo`;o00003oooool2o`0000cooooo0_l0
003;ooooo`;o00002_ooool2o`0000Oooooo0_l0000Gooooo`007_ooool3o`0001kooooo0_l00008
ooooo`;o00000oooool2o`0000oooooo0_l0000<ooooo`;o0000?Oooool2o`0009Wooooo0_l0000E
ooooo`;o00002?ooool001kooooo0ol0001Mooooo`;o0000;?ooool2o`0009Wooooo0_l0000Eoooo
o`;o00002?ooool001kooooo00?o0000ooooooooool09_ooool2o`0000Oooooo0_l0000/ooooo`;o
0000GOooool2o`0008Wooooo000Nooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`;o0000
00?oooooo`000?l00000Roooool2o`0002Kooooo0_l0001Qooooo`007_ooool00ol0003ooooooooo
o`0/ooooo`;o0000Doooool2o`00067ooooo0_l0001Qooooo`007_ooool00ol0003oooooooooo`0O
ooooo`;o00004?ooool2o`00017ooooo0_l0000kooooo`;o0000a?ooool001kooooo00?o0000oooo
ooooool07oooool2o`00013ooooo0_l00005ooooo`;o00002?ooool4o`000?oooooo0_ooool001ko
oooo00?o0000ooooooooool0>?ooool2o`0000Sooooo0_l0003cooooo`;o00003_ooool001kooooo
00?o0000ooooooooool09?ooool2o`0002kooooo0_l0003Booooo`;o00003Oooool2o`0000kooooo
000Nooooo`03o`000?oooooooooo02Cooooo0_l0000Tooooo`;o00002?ooool2o`000=;ooooo0_l0
000Mooooo`007_ooool00ol0003oooooooooo`0Tooooo`;o00009?ooool2o`000?_ooooo000Noooo
o`03o`000?oooooooooo02[ooooo0_l0000Oooooo`;o0000i_ooool2o`0001;ooooo000Nooooo`03
o`000?oooooooooo00kooooo0_l0000Jooooo`;o00000_ooool2o`0001Wooooo1?l0000@ooooo`;o
0000e?ooool2o`0001;ooooo000Nooooo`03o`000?oooooooooo00kooooo0_l0000Nooooo`;o0000
2oooool2o`0000cooooo0_l0000Booooo`;o0000ZOooool2o`0003gooooo000Nooooo`03o`000?oo
oooooooo01kooooo0_l0000Kooooo`;o00007Oooool2o`000:cooooo0_l0000mooooo`007_ooool2
o`0001oooooo0_l0000jooooo`;o0000joooool001kooooo00?o0000ooooooooool01oooool2o`00
02Kooooo0_l0001?ooooo`;o0000P_ooool2o`00047ooooo000Nooooo`03o`000?oooooooooo00Oo
oooo0_l0000Dooooo`;o00004?ooool2o`0001;ooooo0_l0000Gooooo`;o00008_ooool2o`0008;o
oooo0_l0000Yooooo`;o00005_ooool001kooooo00?o0000ooooooooool07Oooool2o`0002Cooooo
0_l0000Gooooo`;o00003Oooool2o`0002oooooo0_l0001^ooooo`;o00008Oooool2o`0001Kooooo
000Nooooo`03o`000?oooooooooo04gooooo0_l00009ooooo`;o00001Oooool2o`0000?ooooo0ol0
00001?oooooo0000o`000?ooool2o`0002oooooo0_l0000Qooooo`;o0000;_ooool2o`0001_ooooo
0_l0000iooooo`007_ooool00ol0003oooooooooo`1=ooooo`;o00001_ooool2o`000003ooooool0
003o000000Gooooo1?l000001Ooooooo0000o`000?l0003ooooo00;o0000EOooool2o`0002kooooo
0_l0001Fooooo`007_ooool00ol0003oooooooooo`1Eooooo`;o00002_ooool2o`0001cooooo0_l0
00000ooooooo0000o`00002Dooooo`;o00004Oooool2o`0001[ooooo000Nooooo`03o`000?oooooo
oooo02;ooooo0_l0000looooo`;o00007Oooool2o`000003ooooool0003o000009Cooooo0_l0000A
ooooo`;o00004?ooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo01_ooooo0_l00004oooo
o`Co00009_ooool2o`0001?ooooo0_l0003Kooooo`;o00002?ooool001kooooo00?o0000oooooooo
ool06oooool2o`0000Cooooo1?l0000Vooooo`;o0000h?ooool2o`0001Sooooo000Nooooo`03o`00
0?oooooooooo013ooooo0_l0000Sooooo`;o0000B?ooool2o`000:cooooo0_l0000Hooooo`007_oo
ool00ol0003oooooooooo`0@ooooo`;o00008oooool2o`0001kooooo0_l0000Xooooo`;o0000a_oo
ool001kooooo00?o0000ooooooooool0<?ooool2o`0000Cooooo0_l0000Mooooo`Co00001Oooool2
o`00043ooooo0_l0001hooooo`;o0000:oooool001kooooo00?o0000ooooooooool0<?ooool2o`00
00Cooooo0ol0000Gooooo`;o00001Oooool2o`0000Gooooo0_l00010ooooo`;o0000N?ooool2o`00
02_ooooo000Nooooo`03o`000?oooooooooo03Oooooo0_l0000Gooooo`;o0000P_ooool2o`0004[o
oooo0_l0000Uooooo`007_ooool00ol0003oooooooooo`0Fooooo`;o0000_?ooool2o`0004[ooooo
0_l0000Uooooo`007_ooool2o`0001Oooooo0_l000000ooooooo0000o`00001=ooooo`;o0000P_oo
ool2o`0005Wooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l00005ooooo`;o00002oooool2
o`0001[ooooo0_l0000:ooooo`;o00006?ooool2o`0008;ooooo0_l0000kooooo`;o00007?ooool0
01kooooo00?o0000ooooooooool00_ooool2o`0000kooooo0_l0000Booooo`;o00006_ooool3o`00
00;ooooo0ol00004ooooo`;o0000NOooool2o`0005kooooo0_l0000Looooo`007_ooool00ol0003o
ooooooooo`02ooooo`;o0000:Oooool2o`00017ooooo0_l000000ooooooo0000o`000002ooooo`?o
0000Ooooool2o`0007cooooo000Nooooo`03o`000?oooooooooo02gooooo0_l0000Aooooo`;o0000
Coooool2o`0000Cooooo0_l00021ooooo`;o0000:oooool001kooooo00?o0000ooooooooool0;Ooo
ool2o`0000cooooo0_l0000Yooooo`;o0000:Oooool2o`0000Cooooo0_l00021ooooo`;o00004Ooo
ool2o`0000cooooo1?l00008ooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o00005_ooool2
o`0000?ooooo0_l00005ooooo`?o000000?oooooo`000?l000000oooool2o`00023ooooo0_l0000?
ooooo`;o00002_ooool2o`000:Sooooo0_l0000<ooooo`Co00002?ooool001kooooo00?o0000oooo
ooooool05oooool2o`0001Kooooo0_l00002ooooo`Co00001Oooool5o`0000?ooooo1_l0000]oooo
o`;o00002_ooool2o`000<;ooooo000Nooooo`03o`000?oooooooooo03?ooooo1?l00006ooooo`Co
00001?ooool5o`0000_ooooo0_l0001Xooooo`;o0000Moooool2o`0000gooooo000Nooooo`;o0000
<_ooool2o`0000Gooooo0_l00004ooooo`?o00001?ooool2o`0000;ooooo0_l0000:ooooo`;o0000
2Oooool2o`0001cooooo0_l0000oooooo`;o00008?ooool2o`0005Gooooo0_l0000=ooooo`007_oo
ool2o`0002[ooooo0_l00004ooooo`Ko00000oooool3o`0000Wooooo0_l00003ooooo`;o00005Ooo
ool2o`0001cooooo0_l0001Qooooo`;o0000I?ooool001kooooo00?o0000ooooooooool07Oooool2
o`0000[ooooo0_l00004ooooo`So00000_ooool2o`0000Wooooo0_l0000oooooo`;o0000`?ooool0
01kooooo0_l0000Nooooo`;o000000?oooooo`000?l000001Oooool2o`000003ooooool0003o0000
00?ooooo1Ol000000ooooooo0000o`000007ooooo`;o00002_ooool3o`00033ooooo0_l00006oooo
o`;o0000>oooool2o`00077ooooo0_l00002ooooo`;o00003?ooool001kooooo0_l0000Qooooo`;o
00001Oooool2o`000003ooooool0003o000001;ooooo0_l00005ooooo`So00004?ooool2o`0001ko
oooo0_l0000>ooooo`;o0000<oooool2o`00077ooooo0_l00002ooooo`;o00003?ooool000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<
00Kooooo00?o0000ooooooooool05Oooool2o`0000kooooo0_l0000?ooooo`;o00000oooool2o`00
00Sooooo1Ol0000Cooooo`;o0000;_ooool2o`000;Sooooo0003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooo
oooo00cooooo0_l00007ooooo`;o00003_ooool2o`0000gooooo1?l00003ooooo`;o00001oooool2
o`0000Gooooo0_l00004ooooo`;o000000?oooooo`000?l00000lOooool000?ooooo00Go410@oooo
oooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`0000cooooo0_l0
0009ooooo`;o00003oooool3o`0000Wooooo0_l0000>ooooo`;o00001?ooool3o`0000Cooooo0_l0
00000ooooooo0000o`000009ooooo`;o0000ROooool2o`0005_ooooo0003ooooo`05o`000?oooooo
ooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000ooooooooool0
5oooool2o`0000kooooo1?l0000<ooooo`?o00004?ooool2o`0001;ooooo0ol00029ooooo`;o0000
Foooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<
c<`01_ooool00ol0003oooooooooo`0Wooooo`;o00003_ooool3o`00017ooooo0_l0000?ooooo`Co
0000GOooool2o`0000Gooooo0_l00021ooooo`000oooool01Ol@413ooooooooooooooooo410@00_o
oooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo013ooooo0_l0000Coooo
o`;o00001oooool2o`0000_ooooo0_l0000>ooooo`;o00001?ooool2o`0000Wooooo0ol0001Eoooo
o`;o00001oooool2o`0000Gooooo0_l00021ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo00_ooooo0_l00003
ooooo`;o00004oooool2o`0000Oooooo0_l00004ooooo`;o00001Oooool2o`0000?ooooo0_l0000?
ooooo`;o00001Oooool2o`0000;ooooo0ol0001Eooooo`;o0000FOooool2o`0003Kooooo0003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o
0000ooooooooool00_l00009ooooo`;o00000oooool2o`00013ooooo0_l0000?ooooo`?o00002_oo
ool2o`0000[ooooo0ol00009ooooo`;o00000_ooool3o`0004_ooooo0_l0001Sooooo`;o0000=_oo
ool001kooooo00?o0000ooooooooool00_l0000?ooooo`;o00001_ooool2o`0000Oooooo0ol00000
0ooooooo0000o`000008ooooo`;o000000?oooooo`000?l000001oooool2o`0000Cooooo0_l00008
ooooo`?o00003Oooool3o`0004_ooooo0_l0002Kooooo`007_ooool00ol0003oooooooooo`0Aoooo
o`;o00001_ooool2o`0000Sooooo0_l000000ooooooo0000o`000002ooooo`Co00000_ooool2o`00
00?ooooo0_l000000ooooooo0000o`000002ooooo`;o00001?ooool4o`0005Oooooo0_l00007oooo
o`;o0000Woooool001kooooo00?o0000ooooooooool0:_ooool5o`000003ooooool0003o000000?o
oooo0_l000000ooooooo0000o`000005ooooo`;o00000oooool2o`0000Wooooo0ol00007ooooo`;o
00000oooool2o`00017ooooo0_l0000Booooo`;o00005_ooool2o`0000Oooooo0_l0000Eooooo`Co
00001Oooool2o`0001Wooooo0_l0001Tooooo`007_ooool00ol0003oooooooooo`0[ooooo`Ko0000
1Oooool2o`0000Oooooo0_l0000>ooooo`?o00001oooool2o`0000?ooooo0_l0000Aooooo`;o0000
4_ooool2o`0003Kooooo1Ol00004ooooo`;o00006Oooool2o`0006Cooooo000Nooooo`03o`000?oo
oooooooo02_ooooo1ol00004ooooo`;o00000_ooool2o`0005Kooooo0_l0000/ooooo`Co0000Pooo
ool001kooooo00?o0000ooooooooool0;?ooool7o`0000Oooooo0_l00004ooooo`;o00008?ooool2
o`0002kooooo0_l0000^ooooo`;o0000:Oooool2o`00037ooooo0_l0000Uooooo`007_ooool00ol0
003oooooooooo`0:ooooo`;o00007Oooool7o`000004ooooool0003o0000o`0000cooooo0ol0000>
ooooo`;o00003oooool2o`00023ooooo0_l0001Wooooo`;o00006oooool2o`0001Cooooo0_l0000U
ooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o00007Oooool7o`0000;ooooo0_l0000=oooo
o`;o00003_ooool2o`0000oooooo0_l0000Pooooo`;o00008Oooool2o`0003oooooo0_l0000Poooo
o`;o0000>oooool001kooooo00?o0000ooooooooool0:oooool2o`000003ooooool0003o000000;o
oooo1Ol00009ooooo`;o00002_ooool4o`0000Cooooo0_l00004ooooo`;o00001_ooool2o`0000Ko
oooo0_l0000kooooo`;o0000?oooool2o`0005gooooo000Nooooo`03o`000?oooooooooo01Gooooo
0_l00005ooooo`;o00003Oooool2o`0000Kooooo1?l00009ooooo`;o000000?oooooo`000?l00000
0_ooool2o`000003ooooool0003o000000Co00001?ooool2o`0000Cooooo0_l00006ooooo`Co0000
1?ooool2o`000=_ooooo000Nooooo`03o`000?oooooooooo01Gooooo0_l00005ooooo`;o00003_oo
ool2o`0000?ooooo1Ol000000ooooooo0000o`000002o`0000;ooooo0_l00004ooooo`_o00000_oo
ool2o`0000Sooooo0_l00008ooooo`;o00002oooool2o`0000gooooo0_l0000Xooooo`;o0000Vooo
ool001kooooo0_l0000]ooooo`;o00000oooool:o`0000;ooooo0_l00005ooooo`[o00000_ooool2
o`0000Oooooo0ol00004ooooo`?o00002oooool2o`000003ooooool0003o000000gooooo0_l0000X
ooooo`;o0000Voooool001kooooo00?o0000ooooooooool0<Oooool8o`0000Gooooo0_l00004oooo
o`Oo00000_ooool3o`0000Wooooo0ol00004ooooo`?o00002oooool2o`000003ooooool0003o0000
01Wooooo0_l0001jooooo`;o0000?Oooool001kooooo00?o0000ooooooooool05Oooool2o`0001go
oooo1ol00003ooooo`;o00001?ooool4o`0000;ooooo0_l000001?oooooo0000o`000?l00002oooo
o`?o00002oooool3o`0000;ooooo0_l000000ooooooo0000o`000007ooooo`;o00000oooool2o`00
00Sooooo0_l0000:ooooo`;o0000N_ooool2o`0003gooooo000Nooooo`03o`000?oooooooooo01Go
oooo0_l0000Kooooo`;o000000Coooooo`000?l0003ooooo1Ol00009ooooo`;o00000_ooool2o`00
0003ooooool0003o000000?ooooo0ol00005ooooo`;o00001Oooool2o`0000;ooooo0_l000000ooo
oooo0000o`00000<ooooo`;o00002?ooool2o`000003ooooool0003o00000<;ooooo000Nooooo`03
o`000?oooooooooo017ooooo0_l0000Oooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o
00002oooool4o`000003ooooool0003o000000;o00001_ooool2o`000004ooooool0003o0000o`00
00Oooooo0_l0000Hooooo`Co000000?oooooo`000?l00000>Oooool2o`0000?ooooo0_l000000ooo
oooo0000o`00001oooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o00008?ooool6o`0000_o
oooo2?l00003ooooo`;o00001_ooool2o`0000;ooooo0ol000000ooooooo0000o`000003ooooo`;o
00003_ooool3o`0000;ooooo0_l00003ooooo`Co00006?ooool2o`0002;ooooo0_l00003ooooo`;o
000000?oooooo`000?l000005_ooool2o`0002Sooooo0_l0000Nooooo`;o00007Oooool001kooooo
00?o0000ooooooooool0:Oooool2o`0000;ooooo0_l00004ooooo`Co00001?ooool2o`0000Oooooo
2?l00006ooooo`Go00001Oooool5o`0000?ooooo0_l00007ooooo`;o00001Oooool3o`0000;ooooo
0_l00005ooooo`;o00006?ooool2o`0004;ooooo0_l0000Xooooo`;o00007_ooool2o`0001gooooo
000Nooooo`03o`000?oooooooooo01;ooooo0_l0000Aooooo`;o00000_ooool2o`0000;ooooo0_l0
00001?oooooo0000o`000?ooool2o`0000Kooooo0_l00007ooooo`Ko00001?ooool2o`0000;ooooo
1Ol00003ooooo`;o00000_ooool2o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l00000
3_ooool2o`000003ooooool0003o00000;3ooooo0_l0000Cooooo`007_ooool00ol0003ooooooooo
o`0Booooo`;o00001_ooool2o`0000Wooooo0_l00006ooooo`;o000000?oooooo`000?l000003Ooo
ool3o`0000Gooooo0_l00005ooooo`Oo00000oooool4o`0000Cooooo1_l00003ooooo`?o00004Ooo
ool2o`000003ooooool0003o000001kooooo0_l0002@ooooo`;o00004oooool001kooooo00?o0000
ooooooooool05?ooool2o`0000Cooooo0_l0000=ooooo`;o00000_ooool2o`00013ooooo0ol00004
ooooo`Co00000oooool8o`0000?ooooo0_l00006ooooo`Co00001Oooool4o`0000;ooooo0_l0000?
ooooo`?o00007Oooool2o`0001kooooo0_l00025ooooo`007_ooool00ol0003oooooooooo`0Doooo
o`;o00002oooool2o`0000?ooooo0_l000000ooooooo0000o`00000Hooooo`;o000000?oooooo`00
0?l000000_l00003ooooo`;o000000?oooooo`000?l000000_l00002ooooo`Co00001?ooool4o`00
00Wooooo0_l00002ooooo`;o00003Oooool2o`000003ooooool0003o000003gooooo0_l0001<oooo
o`;o0000=oooool001kooooo00?o0000ooooooooool08Oooool2o`0000?ooooo0_l0000Kooooo`Co
000000?oooooo`000?l000001Oooool;o`0000Cooooo0ol00002ooooo`;o00006Oooool4o`0001So
oooo0_l0001booooo`;o0000=oooool001kooooo00?o0000ooooooooool0=_ooool2o`0000?ooooo
0_l00005ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l00002ooooo`Ko0000
2_ooool3o`000003ooooool0003o000001Oooooo0_l0000Hooooo`;o00001oooool2o`00087ooooo
0_l0000Oooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o00003Oooool2o`0000gooooo0_l0
0003ooooo`;o00001Oooool3o`0000Cooooo0ol000000ooooooo0000o`000003o`0000?ooooo0_l0
0005ooooo`;o00001Oooool3o`000003ooooool0003o000001Kooooo0_l0000Rooooo`;o0000POoo
ool2o`0001oooooo000Nooooo`03o`000?oooooooooo01Sooooo0_l0000=ooooo`;o00006_ooool2
o`0000Cooooo0ol000000ooooooo0000o`000003o`0000Gooooo1ol00005ooooo`;o00006_ooool2
o`0000Gooooo0_l0002oooooo`007_ooool00ol0003oooooooooo`0`ooooo`;o00007?ooool2o`00
00Gooooo1ol0000Zooooo`;o00001?ooool2o`0000Kooooo0_l0000Mooooo`;o0000R?ooool2o`00
00Sooooo000Nooooo`;o0000:_ooool2o`0000Gooooo0_l00009ooooo`;o00001oooool2o`0000?o
oooo0_l00003ooooo`;o00001Oooool8o`0001;ooooo0_l0000?ooooo`;o00002_ooool2o`0000Ko
oooo0_l0000=ooooo`;o00003_ooool2o`0008Sooooo0_l00008ooooo`007_ooool00ol0003ooooo
ooooo`0Yooooo`;o00004?ooool2o`0000Oooooo0_l000000ooooooo0000o`000004o`000003oooo
ool0003o000000Cooooo1?l00003ooooo`?o000000?oooooo`000?l000002?ooool2o`0000Cooooo
0_l00009ooooo`?o00000oooool2o`00027ooooo0_l0002Rooooo`007_ooool00ol0003ooooooooo
o`17ooooo`;o00000_ooool2o`000003ooooool0003o000000Cooooo1?l00004ooooo`Go00000_oo
ool2o`0000Cooooo0_l0000?ooooo`?o0000b_ooool001kooooo00?o0000ooooooooool01Oooool2
o`0005?ooooo0_l000000ooooooo0000o`000006o`0000Gooooo0_l00002ooooo`;o00001Oooool2
o`0000Oooooo1?l00035ooooo`007_ooool00ol0003oooooooooo`05ooooo`;o0000@oooool2o`00
00;ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0000Cooooo0ol00007
ooooo`;o00000_ooool2o`0000Gooooo0_l00007ooooo`Co0000EOooool2o`0000Kooooo0_l0001V
ooooo`007_ooool00ol0003oooooooooo`0oooooo`;o00002?ooool4o`000003ooooool0003o0000
00;ooooo1_l00003ooooo`;o00000oooool2o`0000Kooooo0_l0000Cooooo`Co0000E_ooool2o`00
00Kooooo0_l0001Vooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o00008Oooool3o`0000co
oooo0_l000001?oooooo0000o`000?l00002ooooo`Oo00000_ooool2o`0000;ooooo1Ol000000ooo
oooo0000o`000003o`0000Sooooo0ol00006ooooo`;o00001_ooool2o`0000?ooooo1?l00036oooo
o`007_ooool00ol0003oooooooooo`0=ooooo`;o00008Oooool3o`0000oooooo1ol00002ooooo`?o
00000_ooool2o`000003ooooool0003o000000Co000000?oooooo`000?l000001_l00005ooooo`;o
00001oooool2o`0000Kooooo0_l00005ooooo`;o0000a_ooool001kooooo00?o0000ooooooooool0
9_ooool2o`0000gooooo0_l000000ooooooo0000o`000009ooooo`Co00000oooool3o`0000Kooooo
0ol00007ooooo`Go00006Oooool2o`0000;ooooo0_l0001^ooooo`;o0000E_ooool001kooooo00?o
0000ooooooooool09_ooool2o`0000gooooo0_l000000ooooooo0000o`00000=ooooo`;o000000?o
ooooo`000?l000001Oooool3o`0000Gooooo0_l00005ooooo`;o00004oooool2o`0000Cooooo0_l0
001booooo`;o0000E_ooool001kooooo00?o0000ooooooooool0>_ooool2o`000003ooooool0003o
000000Sooooo0_l00008ooooo`?o00000_ooool2o`000003ooooool0003o000001[ooooo0_l00004
ooooo`;o000000?oooooo`000?l00000aoooool001kooooo00?o0000ooooooooool03Oooool2o`00
02_ooooo0_l000001?oooooo0000o`000?l0000:ooooo`?o00002?ooool3o`0000Gooooo0_l0000N
ooooo`?o00000oooool2o`000<;ooooo000Nooooo`03o`000?oooooooooo00gooooo0_l0000Goooo
o`;o00005_ooool2o`000003ooooool0003o000000Oooooo0ol00002ooooo`Go000000?oooooo`00
0?l000000_l00004ooooo`;o00007_ooool2o`0000Cooooo0_l00032ooooo`007_ooool00ol0003o
ooooooooo`0Vooooo`;o000000Coooooo`000?l0003o00004?ooool2o`0000?ooooo0_l00007oooo
o`;o00000oooool:o`0000gooooo0_l0000Vooooo`;o00004oooool2o`000:;ooooo000Nooooo`03
o`000?oooooooooo023ooooo0_l00007ooooo`?o00002?ooool2o`0000Kooooo0_l0000<ooooo`;o
00000oooool2o`0000?ooooo1Ol000000ooooooo0000o`00000:ooooo`;o00002_ooool2o`0000co
oooo0_l0000<ooooo`;o00004oooool2o`000:;ooooo000Nooooo`03o`000?oooooooooo00Gooooo
0_l0000Eooooo`;o00000_ooool2o`0001;ooooo0_l00003ooooo`;o00003_ooool2o`0000Cooooo
1_l000001Ooooooo0000o`000?l0003ooooo00Co00005?ooool2o`0000cooooo0_l00035ooooo`00
7_ooool2o`0000Kooooo0_l0000Eooooo`;o00003Oooool2o`0000cooooo0_l00005ooooo`;o0000
1oooool2o`0000Kooooo1?l000001Ooooooo0000o`000?l0003ooooo00Co00001Oooool2o`0000So
oooo0_l00018ooooo`;o0000S_ooool001kooooo00?o0000ooooooooool0:?ooool2o`000003oooo
ool0003o000000?ooooo0_l0000;ooooo`;o000000Coooooo`000?l0003ooooo0_l00005ooooo`;o
00001Oooool3o`0000Kooooo1?l00005ooooo`;o00002?ooool2o`0004Sooooo0_l0000Hooooo`;o
0000M?ooool001kooooo00?o0000ooooooooool0:?ooool2o`0000Kooooo0_l0000;ooooo`;o0000
1?ooool2o`0000Gooooo0_l00003ooooo`Go00001?ooool3o`0007Kooooo0_l0001dooooo`007_oo
ool00ol0003oooooooooo`1>ooooo`Go00001Oooool3o`0005gooooo0_l0000=ooooo`;o0000O_oo
ool001kooooo00?o0000ooooooooool0<Oooool2o`00017ooooo0_l00008ooooo`;o000000?ooooo
o`000?l000000_l0000Kooooo`;o00003Oooool2o`0003Oooooo0_l0000=ooooo`;o00001?ooool2
o`0007Sooooo000Nooooo`03o`000?oooooooooo037ooooo0_l000000ooooooo0000o`00000>oooo
o`;o00002oooool4o`0001_ooooo0_l0000=ooooo`;o00000oooool2o`0004Oooooo0_l00002oooo
o`;o0000D_ooool2o`0001Wooooo0_l00005ooooo`007_ooool00ol0003oooooooooo`09ooooo`;o
00006?ooool2o`0000kooooo0ol0000>ooooo`;o0000?_ooool2o`0003Sooooo0_l0000Aooooo`;o
0000D_ooool2o`0001Sooooo0ol00005ooooo`007_ooool00ol0003oooooooooo`09ooooo`;o0000
3Oooool2o`0000Wooooo0_l0000>ooooo`;o0000ROooool2o`0007oooooo0_l00006ooooo`007_oo
ool00ol0003oooooooooo`0Hooooo`;o0000=_ooool2o`000;Gooooo0_l0000eooooo`;o00001ooo
ool001kooooo00?o0000ooooooooool0;Oooool2o`00027ooooo0_l0002eooooo`;o0000=Oooool2
o`0000Oooooo000Nooooo`03o`000?oooooooooo02[ooooo0_l000000ooooooo0000o`000003o`00
00Oooooo0_l0003oooooo`Oooooo0_l00004ooooo`007_ooool00ol0003oooooooooo`0Zooooo`;o
00000_ooool4o`0000Kooooo0ol0000Iooooo`;o00001?ooool2o`0001_ooooo0_l0000looooo`;o
0000R_ooool2o`0000Cooooo000Nooooo`03o`000?oooooooooo03Kooooo1?l0000Jooooo`;o0000
1?ooool2o`0001_ooooo0_l0000looooo`;o0000T?ooool001kooooo00?o0000ooooooooool0;Ooo
ool2o`0000Oooooo0_l0001hooooo`;o00001?ooool2o`0004Gooooo0_l0000:ooooo`;o0000??oo
ool001Cooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo02gooooo0_l0001;
ooooo`;o0000=?ooool2o`0000Cooooo0_l0000eooooo`;o00003_ooool2o`0000[ooooo0_l0000Y
ooooo`;o00004Oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Foooo
o`;o0000:_ooool2o`00027ooooo0_l0000Cooooo`;o0000LOooool2o`0004Gooooo0_l0000Aoooo
o`005_ooool00ol0003oooooooooo`05ooooo`?o00005_ooool2o`0002;ooooo0_l00006ooooo`;o
00008Oooool2o`00013ooooo0_l0003>ooooo`005_ooool00ol0003oooooooooo`12ooooo`;o0000
>oooool2o`000<kooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000
ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Dooooo`03
oeEEEOmVIVKo00000?ooooooD_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.41687 .93068 Mdot
.15452 .01201 Mdot
.13971 .8637 Mdot
.31479 .94815 Mdot
.19001 .82828 Mdot
.23721 .86896 Mdot
.57221 .56789 Mdot
.18703 .8758 Mdot
.33812 .89613 Mdot
.24629 .09475 Mdot
.14632 .86999 Mdot
.22922 .7562 Mdot
.12418 .82089 Mdot
.59735 .86841 Mdot
.20703 .83902 Mdot
.09636 .27788 Mdot
.97374 .78491 Mdot
.17684 .78907 Mdot
.40844 .94557 Mdot
.3632 .93221 Mdot
.76039 .02787 Mdot
.30867 .81652 Mdot
.16694 .78094 Mdot
.0349 .97284 Mdot
.32596 .94481 Mdot
.19603 .88935 Mdot
.28521 .9019 Mdot
.22327 .76495 Mdot
.14534 .81413 Mdot
.29483 .85985 Mdot
.2146 .85554 Mdot
.21568 .84335 Mdot
.30092 .90959 Mdot
.93465 .62852 Mdot
.34852 .06533 Mdot
.24782 .93497 Mdot
.40387 .88195 Mdot
.52246 .74359 Mdot
.26733 .72305 Mdot
.28322 .96094 Mdot
.24777 .8739 Mdot
.52185 .87769 Mdot
.08755 .7368 Mdot
.05516 .95256 Mdot
.58881 .05931 Mdot
.50664 .85737 Mdot
.65179 .09083 Mdot
.2644 .10911 Mdot
.23769 .95887 Mdot
.22972 .57133 Mdot
.2706 .7694 Mdot
.27065 .06093 Mdot
.13074 .83521 Mdot
.21641 .76653 Mdot
.10474 .79596 Mdot
.01648 .35927 Mdot
.51676 .80446 Mdot
.13477 .83746 Mdot
.28182 .89622 Mdot
.25121 .93466 Mdot
.22541 .91374 Mdot
.22202 .88124 Mdot
.92193 .87491 Mdot
.33017 .92583 Mdot
.19817 .9002 Mdot
.31183 .83734 Mdot
.33502 .02114 Mdot
.28488 .90228 Mdot
.22133 .84605 Mdot
.39388 .83439 Mdot
.16657 .07667 Mdot
.08891 .68866 Mdot
.48562 .83015 Mdot
.24427 .95932 Mdot
.15046 .99355 Mdot
.55138 .80563 Mdot
.30895 .84245 Mdot
.58594 .3948 Mdot
.25933 .86441 Mdot
.9967 .77701 Mdot
.36478 .0958 Mdot
.67102 .22446 Mdot
.98842 .25173 Mdot
.19902 .87052 Mdot
.82193 .78951 Mdot
.47411 .05559 Mdot
.19023 .88482 Mdot
.26098 .96356 Mdot
.20788 .84124 Mdot
.00361 .79453 Mdot
.31269 .86932 Mdot
.45673 .07366 Mdot
.11727 .7091 Mdot
.90634 .8081 Mdot
.42942 .94307 Mdot
.25678 .14008 Mdot
.97849 .64709 Mdot
.38524 .10041 Mdot
.18321 .79789 Mdot
.0592 .53476 Mdot
.24104 .86545 Mdot
.38677 .83266 Mdot
.39306 .86105 Mdot
.18145 .82415 Mdot
.17317 .95856 Mdot
.17489 .76686 Mdot
.08238 .27607 Mdot
.09083 .30303 Mdot
.1619 .97668 Mdot
.82346 .93342 Mdot
.37115 .89249 Mdot
.93792 .62203 Mdot
.24862 .10662 Mdot
.17625 .81446 Mdot
.50339 .16914 Mdot
.50806 .53967 Mdot
.57093 .9999 Mdot
.13185 .80972 Mdot
.03662 .50558 Mdot
.13581 .08906 Mdot
.28433 .94678 Mdot
.21899 .98769 Mdot
.16727 .9651 Mdot
.84817 .69073 Mdot
.61583 .76363 Mdot
.21016 .01072 Mdot
.097 .83704 Mdot
.41538 .92838 Mdot
.95678 .66102 Mdot
.30158 .92896 Mdot
.26775 .03199 Mdot
.57543 .44865 Mdot
.30459 .43967 Mdot
.24151 .78216 Mdot
.28304 .8453 Mdot
.15898 .80832 Mdot
.16802 .7607 Mdot
.099 .63889 Mdot
.29842 .86914 Mdot
.29699 .86376 Mdot
.40227 .88144 Mdot
.31263 .9149 Mdot
.31759 .83575 Mdot
.12644 .63834 Mdot
.86372 .97901 Mdot
.19678 .81059 Mdot
.42819 .87985 Mdot
.26158 .8997 Mdot
.71661 .95922 Mdot
.85817 .35224 Mdot
.31759 .81431 Mdot
.2974 .89686 Mdot
.26265 .75124 Mdot
.3622 .94033 Mdot
.22715 .84652 Mdot
.14123 .81645 Mdot
.18556 .63175 Mdot
.53257 .36491 Mdot
.3211 .91597 Mdot
.08941 .25218 Mdot
.1392 .62079 Mdot
.37034 .85199 Mdot
.64111 .91098 Mdot
.25129 .81104 Mdot
.20219 .82371 Mdot
.16393 .80225 Mdot
.24873 .91445 Mdot
.28638 .91267 Mdot
.46163 .76806 Mdot
.22555 .73925 Mdot
.25374 .88437 Mdot
.42308 .05274 Mdot
.38463 .98974 Mdot
.23212 .04514 Mdot
.42422 .94191 Mdot
.28385 .66071 Mdot
.00946 .05344 Mdot
.15082 .90552 Mdot
.56151 .75929 Mdot
.28542 .06763 Mdot
.16624 .67891 Mdot
.10458 .85107 Mdot
.33051 .02285 Mdot
.64416 .00802 Mdot
.1445 .35778 Mdot
.3807 .88011 Mdot
.12672 .13919 Mdot
.27738 .82653 Mdot
.19172 .77152 Mdot
.22145 .75133 Mdot
.42153 .94111 Mdot
.79656 .98257 Mdot
.4157 .92162 Mdot
.03819 .96659 Mdot
.19975 .12821 Mdot
.08215 .76425 Mdot
.34734 .82509 Mdot
.13318 .9758 Mdot
.34448 .8957 Mdot
.19675 .98742 Mdot
.49369 .72615 Mdot
.44538 .05943 Mdot
.24802 .80401 Mdot
.52567 .05383 Mdot
.32686 .94193 Mdot
.26296 .96746 Mdot
.16945 .99435 Mdot
.25892 .91758 Mdot
.99648 .82864 Mdot
.24672 .64629 Mdot
.21442 .74586 Mdot
.42212 .87459 Mdot
.69666 .81352 Mdot
.32738 .53461 Mdot
.11824 .63343 Mdot
.18597 .02553 Mdot
.25348 .94488 Mdot
.25702 .14827 Mdot
.30064 .65221 Mdot
.5532 .94626 Mdot
.13588 .88756 Mdot
.36811 .98947 Mdot
.27424 .88635 Mdot
.27698 .89616 Mdot
.049 .81786 Mdot
.16626 .62247 Mdot
.33039 .83736 Mdot
.14277 .80567 Mdot
.21707 .8226 Mdot
.3238 .82812 Mdot
.17141 .85103 Mdot
.19183 .92129 Mdot
.29098 .85926 Mdot
.12925 .91129 Mdot
.17593 .21154 Mdot
.96545 .79841 Mdot
.83974 .40387 Mdot
.15831 .83817 Mdot
.77416 .59144 Mdot
.87932 .73034 Mdot
.13282 .81479 Mdot
.29201 .84371 Mdot
.24888 .91894 Mdot
.32348 .72987 Mdot
.33561 .79789 Mdot
.18671 .04213 Mdot
.23069 .94217 Mdot
.2866 .86205 Mdot
.6876 .38608 Mdot
.22709 .87897 Mdot
.22921 .03621 Mdot
.12154 .77036 Mdot
.57733 .38021 Mdot
.95787 .98502 Mdot
.40787 .02752 Mdot
.21384 .98878 Mdot
.14618 .82685 Mdot
.7337 .75367 Mdot
.36333 .04401 Mdot
.87442 .89903 Mdot
.42025 .89339 Mdot
.24765 .79045 Mdot
.26246 .58848 Mdot
.82896 .73784 Mdot
.29598 .84786 Mdot
.26332 .64964 Mdot
.36651 .96532 Mdot
.72698 .79915 Mdot
.14821 .8285 Mdot
.29293 .93803 Mdot
.19041 .8087 Mdot
.75402 .71685 Mdot
.21364 .87073 Mdot
.25295 .78698 Mdot
.42121 .0786 Mdot
.14048 .75897 Mdot
.27367 .67483 Mdot
.53054 .52397 Mdot
.22115 .87 Mdot
.33346 .82121 Mdot
.36077 .77655 Mdot
.30877 .82422 Mdot
.23143 .82635 Mdot
.45541 .77732 Mdot
.16493 .81718 Mdot
.28116 .8932 Mdot
.21925 .74872 Mdot
.01108 .63196 Mdot
.20117 .81057 Mdot
.2448 .72553 Mdot
.2129 .82686 Mdot
.65497 .68905 Mdot
.39036 .9428 Mdot
.00549 .94029 Mdot
.40617 .04283 Mdot
.15116 .61729 Mdot
.16812 .8892 Mdot
.21951 .85931 Mdot
.23962 .85412 Mdot
.2635 .19507 Mdot
.88265 .68099 Mdot
.14727 .79638 Mdot
.36055 .96395 Mdot
.1374 .74564 Mdot
.81724 .14486 Mdot
.08796 .86204 Mdot
.28376 .89775 Mdot
.25289 .86559 Mdot
.35011 .60106 Mdot
.40027 .97432 Mdot
.27446 .93361 Mdot
.40684 .9866 Mdot
.20732 .88811 Mdot
.3566 .93751 Mdot
.27004 .94391 Mdot
.2879 .67134 Mdot
.3046 .79625 Mdot
.75395 .96532 Mdot
.21066 .90147 Mdot
.19671 .49136 Mdot
.2652 .70551 Mdot
.27985 .9305 Mdot
.38219 .88316 Mdot
.27506 .93299 Mdot
.20522 .83189 Mdot
.15895 .84064 Mdot
.22296 .88761 Mdot
.42587 .86697 Mdot
.17233 .71487 Mdot
.19583 .85836 Mdot
.3744 .91326 Mdot
.24133 .85527 Mdot
.43913 .37382 Mdot
.55732 .95055 Mdot
.19977 .96713 Mdot
.24048 .20264 Mdot
.57193 .8625 Mdot
.29283 .92306 Mdot
.08277 .34225 Mdot
.00937 .05942 Mdot
.21331 .8398 Mdot
.32158 .51922 Mdot
.4117 .85301 Mdot
.13349 .76112 Mdot
.94058 .46136 Mdot
.2612 .13417 Mdot
.20205 .84033 Mdot
.2677 .56624 Mdot
.29831 .87659 Mdot
.18132 .88033 Mdot
.14064 .82021 Mdot
.12976 .79943 Mdot
.35486 .90848 Mdot
.1936 .17929 Mdot
.02261 .15015 Mdot
.21232 .88716 Mdot
.48309 .9177 Mdot
.26064 .89335 Mdot
.1228 .82315 Mdot
.33522 .06128 Mdot
.30183 .83672 Mdot
.45092 .78558 Mdot
.24217 .86471 Mdot
.20335 .73966 Mdot
.23535 .84914 Mdot
.32126 .04907 Mdot
.20248 .18693 Mdot
.08897 .51031 Mdot
.37396 .24392 Mdot
.26346 .8259 Mdot
.1068 .63018 Mdot
.28005 .89784 Mdot
.16473 .85699 Mdot
.32887 .84289 Mdot
.85259 .8846 Mdot
.02033 .55347 Mdot
.57941 .06309 Mdot
.25457 .97945 Mdot
.6847 .27129 Mdot
.30037 .89227 Mdot
.25371 .86557 Mdot
.36641 .92341 Mdot
.13649 .41517 Mdot
.44862 .20561 Mdot
.29713 .62671 Mdot
.05945 .92913 Mdot
.05125 .05179 Mdot
.84921 .16609 Mdot
.2913 .91712 Mdot
.0268 .81226 Mdot
.40362 .87999 Mdot
.16363 .78274 Mdot
.19145 .87396 Mdot
.17149 .85179 Mdot
.18897 .84495 Mdot
.09595 .92734 Mdot
.07969 .90503 Mdot
.88853 .73492 Mdot
.28035 .89858 Mdot
.23185 .84722 Mdot
.02842 .81564 Mdot
.52882 .0921 Mdot
.52019 .48388 Mdot
.21668 .87702 Mdot
.18608 .57397 Mdot
.09367 .20452 Mdot
.25693 .7612 Mdot
.04665 .74161 Mdot
.20782 .7673 Mdot
.24915 .80364 Mdot
.08438 .62643 Mdot
.31914 .93288 Mdot
.11903 .62755 Mdot
.3715 .80123 Mdot
.71013 .04605 Mdot
.19887 .76705 Mdot
.29361 .94189 Mdot
.15825 .61592 Mdot
.26653 .19853 Mdot
.25839 .8615 Mdot
.28743 .93473 Mdot
.7235 .35706 Mdot
.84193 .64152 Mdot
.16725 .77501 Mdot
.15092 .84846 Mdot
.16522 .7248 Mdot
.50713 .62644 Mdot
.34239 .86063 Mdot
.10913 .72579 Mdot
.85737 .76973 Mdot
.0436 .87943 Mdot
.69818 .15711 Mdot
.54518 .57495 Mdot
.37279 .90119 Mdot
.21294 .09946 Mdot
.4666 .05608 Mdot
.28635 .64509 Mdot
.11046 .17744 Mdot
.32229 .82487 Mdot
.57835 .0339 Mdot
.34713 .96606 Mdot
.76274 .19941 Mdot
.63574 .19762 Mdot
.20843 .88915 Mdot
.18588 .86663 Mdot
.22547 .89101 Mdot
.25762 .94557 Mdot
.20264 .77469 Mdot
.00751 .64117 Mdot
.18911 .99855 Mdot
.0289 .69324 Mdot
.14273 .92058 Mdot
.24029 .86929 Mdot
.26227 .8783 Mdot
.3578 .74583 Mdot
.27526 .9205 Mdot
.33406 .93147 Mdot
.22632 .86125 Mdot
.95787 .73879 Mdot
.2972 .33157 Mdot
.28654 .91592 Mdot
.25802 .9444 Mdot
.25141 .87451 Mdot
.11365 .89114 Mdot
.17421 .76862 Mdot
.40173 .09519 Mdot
.29001 .92513 Mdot
.62337 .17965 Mdot
.19859 .85953 Mdot
.38343 .05089 Mdot
.27691 .8315 Mdot
.2028 .89313 Mdot
.19873 .87674 Mdot
.19819 .87337 Mdot
.14377 .87969 Mdot
.23072 .8512 Mdot
.1194 .79308 Mdot
.16505 .84918 Mdot
.96093 .48987 Mdot
.04324 .8671 Mdot
.41139 .91003 Mdot
.02631 .02308 Mdot
.3074 .82944 Mdot
.39188 .85973 Mdot
.41858 .92585 Mdot
.65297 .86531 Mdot
.32254 .02926 Mdot
.2412 .89965 Mdot
.4655 .97183 Mdot
.1961 .78972 Mdot
.17348 .84836 Mdot
.29715 .92252 Mdot
.32214 .4282 Mdot
.10029 .09482 Mdot
.33329 .93073 Mdot
.13219 .98769 Mdot
.21854 .82762 Mdot
.19657 .96625 Mdot
.75539 .72469 Mdot
.28558 .80446 Mdot
.19565 .89834 Mdot
.33374 .90056 Mdot
.39 .0693 Mdot
.13863 .5672 Mdot
.18112 .76261 Mdot
.51118 .73102 Mdot
.21177 .89229 Mdot
.68774 .77206 Mdot
.32926 .93562 Mdot
.32206 .88839 Mdot
.32893 .84397 Mdot
.01398 .12614 Mdot
.21377 .31725 Mdot
.17563 .79071 Mdot
.18371 .842 Mdot
.84393 .74381 Mdot
.24574 .65172 Mdot
.25427 .15414 Mdot
.37877 .17367 Mdot
.24767 .83703 Mdot
.28577 .90919 Mdot
.12649 .88892 Mdot
.25717 .86597 Mdot
.17699 .97421 Mdot
.03735 .57315 Mdot
.50446 .75566 Mdot
.20519 .80088 Mdot
.19563 .22459 Mdot
.28858 .89916 Mdot
.98375 .86465 Mdot
.75077 .42956 Mdot
.96327 .04738 Mdot
.17482 .82173 Mdot
.21189 .73495 Mdot
.19374 .86213 Mdot
.26075 .86354 Mdot
.21978 .90863 Mdot
.31132 .8897 Mdot
.32455 .68324 Mdot
.39535 .97475 Mdot
.29364 .86338 Mdot
.25182 .07818 Mdot
.1644 .84626 Mdot
.23484 .84993 Mdot
.2663 .89177 Mdot
.00123 .6345 Mdot
.98066 .58985 Mdot
.27935 .9834 Mdot
.22744 .78131 Mdot
.16172 .8365 Mdot
.38068 .79926 Mdot
.52908 .83001 Mdot
.31857 .89253 Mdot
.08871 .57839 Mdot
.31834 .03657 Mdot
.61313 .48875 Mdot
.22951 .87482 Mdot
.2924 .92906 Mdot
.27516 .92335 Mdot
.63433 .07789 Mdot
.23821 .76603 Mdot
.12959 .91534 Mdot
.51631 .72944 Mdot
.18196 .52356 Mdot
.20803 .75172 Mdot
.22237 .92524 Mdot
.15369 .59387 Mdot
.25244 .87104 Mdot
.58678 .2715 Mdot
.21239 .84598 Mdot
.36134 .0543 Mdot
.18332 .81931 Mdot
.22756 .8538 Mdot
.42581 .85278 Mdot
.14703 .79304 Mdot
.34623 .85742 Mdot
.19118 .21508 Mdot
.14171 .81076 Mdot
.11952 .76967 Mdot
.0828 .98036 Mdot
.72235 .57077 Mdot
.65795 .82861 Mdot
.17476 .80664 Mdot
.37557 .87781 Mdot
.9914 .70917 Mdot
.26694 .99065 Mdot
.37632 .9116 Mdot
.47371 .40607 Mdot
.11562 .81369 Mdot
.42213 .93948 Mdot
.15578 .84601 Mdot
.10276 .81735 Mdot
.16501 .75923 Mdot
.2186 .96937 Mdot
.26006 .8309 Mdot
.2172 .88233 Mdot
.3028 .63921 Mdot
.17287 .83869 Mdot
.25792 .9756 Mdot
.23969 .07268 Mdot
.33555 .85581 Mdot
.28131 .91168 Mdot
.1591 .84753 Mdot
.39 .0994 Mdot
.3774 .93629 Mdot
.25013 .82667 Mdot
.27809 .93101 Mdot
.30253 .83183 Mdot
.0308 .71249 Mdot
.41843 .9181 Mdot
.49111 .94618 Mdot
.35258 .22802 Mdot
.22025 .82804 Mdot
.98585 .92527 Mdot
.41918 .92395 Mdot
.12971 .2462 Mdot
.09575 .68866 Mdot
.09987 .91607 Mdot
.15988 .77246 Mdot
.6219 .73541 Mdot
.43354 .52296 Mdot
.28409 .11583 Mdot
.41817 .92679 Mdot
.18398 .05946 Mdot
.48975 .06071 Mdot
.30737 .99141 Mdot
.98963 .42939 Mdot
.59449 .67546 Mdot
.11119 .77767 Mdot
.42763 .89132 Mdot
.22055 .85629 Mdot
.28597 .90242 Mdot
.3921 .94995 Mdot
.63106 .77487 Mdot
.22699 .85654 Mdot
.84099 .31509 Mdot
.19249 .86819 Mdot
.09946 .72651 Mdot
.18712 .80886 Mdot
.20034 .8357 Mdot
.07338 .86946 Mdot
.22417 .85809 Mdot
.48966 .92916 Mdot
.50667 .81861 Mdot
.31428 .62727 Mdot
.35629 .91764 Mdot
.153 .80857 Mdot
.92742 .59861 Mdot
.20331 .85863 Mdot
.15476 .73371 Mdot
.04459 .82045 Mdot
.13043 .94289 Mdot
.33455 .0594 Mdot
.27161 .89269 Mdot
.91382 .56032 Mdot
.29201 .95967 Mdot
.10877 .84296 Mdot
.05673 .84512 Mdot
.97429 .81166 Mdot
.27816 .90789 Mdot
.59399 .04502 Mdot
.15694 .81999 Mdot
.03659 .92564 Mdot
.27798 .97092 Mdot
.66978 .75056 Mdot
.1094 .10275 Mdot
.25664 .86213 Mdot
.24711 .78988 Mdot
.04969 .52286 Mdot
.28329 .16319 Mdot
.91551 .64957 Mdot
.4605 .32194 Mdot
.18996 .97919 Mdot
.30123 .94896 Mdot
.8484 .63627 Mdot
.22264 .88507 Mdot
.50491 .03655 Mdot
.16249 .77908 Mdot
.17704 .94006 Mdot
.55272 .99417 Mdot
.21067 .70832 Mdot
.13602 .65497 Mdot
.51824 .40654 Mdot
.41661 .94269 Mdot
.21368 .84751 Mdot
.42271 .87673 Mdot
.32347 .81949 Mdot
.78331 .13939 Mdot
.11746 .88285 Mdot
.14474 .81258 Mdot
.20499 .06605 Mdot
.5819 .07099 Mdot
.27321 .0779 Mdot
.43165 .9249 Mdot
.31147 .89342 Mdot
.16216 .8383 Mdot
.25755 .87987 Mdot
.90067 .95331 Mdot
.65365 .71688 Mdot
.55752 .63417 Mdot
.19779 .91501 Mdot
.23461 .21712 Mdot
.13916 .81203 Mdot
.32588 .8684 Mdot
.19516 .82035 Mdot
.1871 .96712 Mdot
.42948 .53363 Mdot
.19492 .76246 Mdot
.24264 .26297 Mdot
.34883 .88865 Mdot
.75115 .94312 Mdot
.0747 .78533 Mdot
.50503 .13061 Mdot
.72318 .60013 Mdot
.13157 .7906 Mdot
.82623 .57859 Mdot
.29733 .84269 Mdot
.17728 .86842 Mdot
.33069 .43994 Mdot
.26781 .86798 Mdot
.42622 .86061 Mdot
.66552 .86647 Mdot
.27784 .87499 Mdot
.25976 .71622 Mdot
.29331 .15187 Mdot
.85916 .94404 Mdot
.71491 .88547 Mdot
.28616 .95493 Mdot
.59318 .79411 Mdot
.89995 .56925 Mdot
.21695 .97904 Mdot
.25725 .91986 Mdot
.13205 .82 Mdot
.319 .88349 Mdot
.03896 .11749 Mdot
.05551 .23074 Mdot
.87225 .50922 Mdot
.1456 .01813 Mdot
.15066 .76033 Mdot
.13512 .1494 Mdot
.2648 .82946 Mdot
.35841 .9186 Mdot
.4278 .93221 Mdot
.82534 .58132 Mdot
.00364 .76503 Mdot
.10983 .83089 Mdot
.30662 .90131 Mdot
.57346 .7596 Mdot
.09842 .89708 Mdot
.56866 .60296 Mdot
.18661 .86287 Mdot
.1881 .86693 Mdot
.0515 .98873 Mdot
.43069 .84367 Mdot
.30436 .87283 Mdot
.20979 .81111 Mdot
.20943 .73879 Mdot
.44494 .06161 Mdot
.11019 .80382 Mdot
.18319 .85128 Mdot
.56641 .83004 Mdot
.19187 .88098 Mdot
.38983 .43639 Mdot
.18159 .86236 Mdot
.30305 .88913 Mdot
.2702 .92027 Mdot
.03609 .52728 Mdot
.63032 .24631 Mdot
.13159 .97534 Mdot
.48669 .24055 Mdot
.30089 .94053 Mdot
.3722 .84281 Mdot
.20622 .7629 Mdot
.12183 .77032 Mdot
.51633 .7042 Mdot
.34078 .86124 Mdot
.07538 .81371 Mdot
.17043 .84652 Mdot
.34513 .74265 Mdot
.48928 .25836 Mdot
.32498 .94298 Mdot
.28617 .05367 Mdot
.91677 .98626 Mdot
.0804 .23736 Mdot
.20721 .93379 Mdot
.23892 .64507 Mdot
.14051 .16862 Mdot
.29698 .86799 Mdot
.29553 .91902 Mdot
.13942 .82897 Mdot
.37747 .7947 Mdot
.3643 .24935 Mdot
.22841 .52739 Mdot
.16 .89617 Mdot
.36532 .75766 Mdot
.10883 .83823 Mdot
.19263 .81936 Mdot
.61358 .89683 Mdot
.31951 .94538 Mdot
.11455 .82055 Mdot
.4206 .17913 Mdot
.2978 .8481 Mdot
.16894 .80542 Mdot
.18658 .12841 Mdot
.11504 .87561 Mdot
.19574 .78581 Mdot
.25044 .90018 Mdot
.26231 .0475 Mdot
.19945 .59358 Mdot
.34578 .00029 Mdot
.0208 .55166 Mdot
.28885 .96095 Mdot
.12 .88768 Mdot
.20138 .13848 Mdot
.27459 .81074 Mdot
.27508 .89287 Mdot
.52167 .41139 Mdot
.48963 .91568 Mdot
.21061 .84774 Mdot
.88443 .65992 Mdot
.19213 .86668 Mdot
.17824 .84278 Mdot
.08429 .81542 Mdot
.13979 .8192 Mdot
.19488 .89502 Mdot
.14509 .61999 Mdot
.14539 .84668 Mdot
.18549 .79828 Mdot
.72241 .47111 Mdot
.21389 .06508 Mdot
.44263 .97274 Mdot
.98751 .66536 Mdot
.12792 .80497 Mdot
.00799 .62196 Mdot
.44468 .86548 Mdot
.24398 .76965 Mdot
.99969 .10003 Mdot
.23989 .96076 Mdot
.23263 .849 Mdot
.73332 .75488 Mdot
.40809 .04557 Mdot
.17534 .83688 Mdot
.2823 .89485 Mdot
.32842 .87745 Mdot
.5535 .84514 Mdot
.3084 .74699 Mdot
.47179 .07245 Mdot
.13732 .82569 Mdot
.2207 .88343 Mdot
.19752 .86846 Mdot
.51624 .71918 Mdot
.04404 .80174 Mdot
.27094 .88749 Mdot
.39925 .97244 Mdot
.26318 .95703 Mdot
.49424 .00472 Mdot
.19116 .87452 Mdot
.30322 .41425 Mdot
.05483 .87061 Mdot
.15109 .86357 Mdot
.19334 .85151 Mdot
.26971 .93945 Mdot
.34958 .88078 Mdot
.93494 .58543 Mdot
.1971 .88867 Mdot
.12173 .90377 Mdot
.41728 .94685 Mdot
.28065 .65711 Mdot
.84993 .7677 Mdot
.15152 .83458 Mdot
.62723 .79885 Mdot
.25901 .93399 Mdot
.32002 .93445 Mdot
.30453 .91745 Mdot
.43043 .0456 Mdot
.19158 .87785 Mdot
.57129 .10586 Mdot
.12531 .90533 Mdot
.50047 .13752 Mdot
.35175 .89197 Mdot
.06381 .87737 Mdot
.26411 .88981 Mdot
.19879 .88125 Mdot
.11902 .87762 Mdot
.08084 .96281 Mdot
.41859 .93111 Mdot
.42527 .8598 Mdot
.77785 .24777 Mdot
.31002 .81826 Mdot
.9692 .94873 Mdot
.96288 .50322 Mdot
.52434 .05773 Mdot
.07893 .86068 Mdot
.30704 .82805 Mdot
.34678 .42023 Mdot
.18539 .90782 Mdot
.45464 .76721 Mdot
.19901 .84838 Mdot
.40027 .8941 Mdot
.11637 .79722 Mdot
.34071 .87806 Mdot
.40519 .93386 Mdot
.27667 .24897 Mdot
.32827 .82194 Mdot
.1458 .89214 Mdot
.37484 .13034 Mdot
.12081 .24438 Mdot
.30376 .84132 Mdot
.36534 .92879 Mdot
.40743 .84875 Mdot
.33452 .79928 Mdot
.89408 .10092 Mdot
.13078 .67478 Mdot
.33676 .89036 Mdot
.12227 .91468 Mdot
.26315 .01797 Mdot
.45122 .80418 Mdot
.36903 .91929 Mdot
.27474 .15631 Mdot
.33571 .8728 Mdot
.808 .65827 Mdot
.24067 .06692 Mdot
.39928 .8868 Mdot
.20454 .85942 Mdot
.20655 .83705 Mdot
.54653 .80993 Mdot
.18428 .99544 Mdot
.33605 .74626 Mdot
.89306 .13093 Mdot
.03013 .84619 Mdot
.1347 .98988 Mdot
.16915 .75445 Mdot
.16066 .84061 Mdot
.2959 .84989 Mdot
.67425 .02374 Mdot
.41212 .90048 Mdot
.56474 .33792 Mdot
.25997 .90389 Mdot
.25934 .86565 Mdot
.3377 .57291 Mdot
.13743 .82944 Mdot
.30537 .91649 Mdot
.32062 .94948 Mdot
.95624 .61681 Mdot
.04483 .91898 Mdot
.23323 .86857 Mdot
.0755 .91003 Mdot
.47023 .94597 Mdot
.29571 .87112 Mdot
.5923 .06355 Mdot
.20264 .83242 Mdot
.17087 .85794 Mdot
.31038 .96535 Mdot
.14244 .13838 Mdot
.14415 .03225 Mdot
.12622 .83562 Mdot
.93373 .00402 Mdot
.81474 .78717 Mdot
.95338 .8535 Mdot
.03357 .72481 Mdot
.30457 .82205 Mdot
.27072 .88673 Mdot
.20714 .84571 Mdot
.99727 .81859 Mdot
.17534 .84253 Mdot
.66733 .4917 Mdot
.12081 .64966 Mdot
.17912 .57569 Mdot
.87544 .06421 Mdot
.41772 .31673 Mdot
.1993 .64419 Mdot
.8673 .47314 Mdot
.05025 .941 Mdot
.97468 .54586 Mdot
.51741 .7471 Mdot
.21667 .89275 Mdot
.21202 .86618 Mdot
.92458 .83687 Mdot
.27526 .88236 Mdot
.26325 .91451 Mdot
.16007 .85532 Mdot
.37803 .97994 Mdot
.07643 .59553 Mdot
.13903 .0869 Mdot
.31243 .90965 Mdot
.16872 .9482 Mdot
.19983 .87365 Mdot
.2551 .20939 Mdot
.34786 .10049 Mdot
.2804 .90086 Mdot
.01092 .65224 Mdot
.32344 .95208 Mdot
.33227 .69981 Mdot
.68775 .2755 Mdot
.20139 .82578 Mdot
.28334 .95963 Mdot
.18334 .85527 Mdot
.2971 .60813 Mdot
.2438 .61855 Mdot
.15874 .98171 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_o
oooo0ol0000@ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool2o`0000Co
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0;ooooo`?o00003oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo
0_l00004ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0WOooool2o`0002kooooo0_l0001hooooo`007_ooool00ol0003oooooooooo`0^
ooooo`;o00004?ooool2o`0008_ooooo0_l0001hooooo`007_ooool00ol0003oooooooooo`0^oooo
o`;o00004?ooool2o`000?oooooo1_ooool001kooooo00?o0000ooooooooool0:oooool2o`0002Co
oooo0_l0003dooooo`007_ooool00ol0003oooooooooo`0[ooooo`;o00009?ooool2o`0001Cooooo
1?l0003Looooo`007_ooool00ol0003oooooooooo`04ooooo`;o0000<_ooool2o`0002gooooo1?l0
001/ooooo`;o0000K_ooool001kooooo00?o0000ooooooooool01?ooool2o`0003;ooooo0_l00016
ooooo`;o0000EOooool2o`0001[ooooo0_l0001Booooo`007_ooool00ol0003oooooooooo`1Coooo
o`;o00004?ooool2o`0001Wooooo0_l0001aooooo`;o0000D_ooool001kooooo00?o0000oooooooo
ool0:oooool2o`0002Kooooo0_l0000@ooooo`;o0000DOooool2o`0008gooooo000Nooooo`03o`00
0?oooooooooo02_ooooo0_l0000Iooooo`;o00006oooool2o`0003_ooooo0_l0000Fooooo`;o0000
SOooool001kooooo00?o0000ooooooooool0A_ooool2o`0001_ooooo0_l0000kooooo`;o0000YOoo
ool001kooooo00?o0000ooooooooool0>Oooool2o`0003Oooooo0_l0000<ooooo`;o0000aOooool0
01kooooo00?o0000ooooooooool0>Oooool2o`0000cooooo0_l00008ooooo`;o00007oooool2o`00
00cooooo0ol00005ooooo`;o0000<oooool2o`0002Cooooo0_l0001@ooooo`;o00004?ooool001ko
oooo00?o0000ooooooooool0Aoooool2o`0000Sooooo0_l0000Aooooo`;o00006oooool2o`0000Go
oooo0_l0000cooooo`;o00009?ooool2o`00053ooooo0_l0000@ooooo`007_ooool4o`0000cooooo
0_l0001:ooooo`;o00002Oooool2o`0001?ooooo0_l0000:ooooo`;o0000`?ooool001kooooo00Co
0000ooooool0003o00003?ooool2o`0004[ooooo0_l0000Fooooo`;o00001_ooool2o`0000[ooooo
0_l0000=ooooo`Co00003oooool2o`0009kooooo000Nooooo`04o`000?oooooo0000o`0003Oooooo
0_l0000_ooooo`;o00001_ooool2o`0001[ooooo0_l00005ooooo`Co00003_ooool3o`0001;ooooo
0_l0002:ooooo`007_ooool01?l0003oooooo`000?l0000gooooo`;o00006_ooool2o`0001?ooooo
0_l0000Rooooo`;o00003?ooool2o`0000Wooooo0_l0000Cooooo`;o0000R_ooool001kooooo00?o
0000ooooooooool0@Oooool2o`00017ooooo0_l0000Cooooo`;o00000_ooool2o`0001kooooo0_l0
000<ooooo`;o00006oooool2o`0000;ooooo0_l0001Kooooo`;o0000;?ooool001kooooo00?o0000
ooooooooool0?oooool4o`0000Oooooo0_l0000=ooooo`;o00004_ooool2o`0004Wooooo0_l00002
ooooo`;o0000Foooool2o`0002cooooo000Nooooo`03o`000?oooooooooo03oooooo0_l00009oooo
o`;o00003Oooool2o`00023ooooo0_l0000looooo`;o0000S?ooool001kooooo00?o0000oooooooo
ool0B_ooool2o`0002oooooo0_l0000Cooooo`;o00000oooool2o`0002;ooooo0_l0002<ooooo`00
7_ooool00ol0003oooooooooo`0booooo`;o00005_ooool2o`0000;ooooo0_l00005ooooo`;o0000
>Oooool2o`0000?ooooo0_l0000cooooo`;o0000Noooool001kooooo00?o0000ooooooooool0<_oo
ool2o`0001[ooooo0_l00005ooooo`;o0000;_ooool2o`0004?ooooo0_l0001kooooo`007_ooool0
0ol0003oooooooooo`25ooooo`;o0000`?ooool001kooooo00?o0000ooooooooool0:Oooool2o`00
0?oooooo7Oooool001kooooo00?o0000ooooooooool0:?ooool3o`000?oooooo7Oooool001kooooo
00?o0000ooooooooool0:?ooool2o`0007kooooo0_l0000Vooooo`;o0000MOooool001kooooo00?o
0000ooooooooool07?ooool2o`0002kooooo0_l0000Tooooo`;o00002_ooool2o`0002Sooooo0_l0
000Vooooo`;o0000MOooool001kooooo00?o0000ooooooooool07?ooool2o`0002?ooooo0_l00009
ooooo`;o00009?ooool2o`0000Oooooo0_l000000ooooooo0000o`000037ooooo`007_ooool2o`00
023ooooo0_l0000Pooooo`;o0000:_ooool2o`0000[ooooo1?l0002Rooooo`;o00008?ooool2o`00
00Cooooo000Nooooo`03o`000?oooooooooo01oooooo0_l0001<ooooo`;o00002_ooool2o`0003_o
oooo0_l0001Wooooo`;o00008?ooool2o`0000Cooooo000Nooooo`03o`000?oooooooooo04gooooo
0_l0001Wooooo`;o0000Soooool001kooooo00?o0000ooooooooool0COooool2o`0000?ooooo0_l0
003cooooo`007_ooool00ol0003oooooooooo`1Booooo`;o0000loooool001kooooo00?o0000oooo
ooooool02Oooool2o`0004gooooo0_l0003]ooooo`007_ooool00ol0003oooooooooo`09ooooo`;o
0000COooool2o`000>gooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool00_l0003oooooodKooooo000Nooooo`03o`000?oooooooooo00;o0000=oooool2
o`0000;ooooo0_l0000gooooo`;o0000:?ooool2o`000:Gooooo000Nooooo`03o`000?oooooooooo
03Wooooo0_l00002ooooo`;o0000=oooool2o`0002Sooooo0_l0001looooo`;o00009oooool001ko
oooo00?o0000ooooooooool0DOooool2o`000<_ooooo0_l0000Wooooo`007_ooool00ol0003ooooo
ooooo`0Uooooo`;o00000oooool2o`00017ooooo0_l0000Booooo`;o0000C?ooool2o`0005[ooooo
0_l0001:ooooo`007_ooool00ol0003oooooooooo`0Uooooo`;o00000oooool2o`00017ooooo0_l0
000@ooooo`;o0000C_ooool2o`0005[ooooo0_l0001:ooooo`007_ooool00ol0003oooooooooo`1?
ooooo`;o0000]Oooool2o`0003oooooo000Nooooo`03o`000?oooooooooo04oooooo0_l0002eoooo
o`;o0000?oooool001kooooo0_l00004ooooo`;o00008oooool2o`0002Gooooo0_l0000:ooooo`;o
0000j_ooool001kooooo00?o0000ooooooooool00oooool2o`0002?ooooo0_l0000Uooooo`;o0000
2_ooool2o`000>[ooooo000Nooooo`03o`000?oooooooooo04oooooo0_l00004ooooo`;o0000R?oo
ool2o`0006Kooooo000Nooooo`03o`000?oooooooooo05Gooooo0_l00028ooooo`;o0000I_ooool0
01kooooo00?o0000ooooooooool0F?ooool2o`000>gooooo000Nooooo`03o`000?oooooooooo05So
oooo0_l0002fooooo`;o0000=Oooool001kooooo00?o0000ooooooooool0:_ooool2o`0007Cooooo
0_l0001^ooooo`;o0000=Oooool001kooooo00?o0000ooooooooool0:_ooool2o`0004_ooooo0_l0
000Wooooo`;o0000YOooool001kooooo00?o0000ooooooooool0Moooool2o`000<kooooo000Noooo
o`03o`000?oooooooooo023ooooo0_l0000Iooooo`;o0000B?ooool2o`00043ooooo0_l0001noooo
o`007_ooool00ol0003oooooooooo`0Pooooo`;o00006Oooool2o`0004Sooooo0_l00010ooooo`;o
0000O_ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`0nooooo`;o0000ooooool8ooooo`007_ooool00ol0003oooooooooo`0nooooo`;o0000ooooool8
ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool0
0ol0003oooooooooo`1Booooo`;o0000loooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0D_oo
ool2o`0007Oooooo0_l0001jooooo`000oooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h01oooool3o`0005?ooooo0_l0001fooooo`;o00009oooool2o`00057ooooo0003
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oo
oooooooo04[ooooo0_l00007ooooo`;o0000Woooool2o`00057ooooo0003ooooo`05o`000?oooooo
ooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo01[ooooo0_l0
000^ooooo`;o0000@_ooool2o`000;Oooooo0003ooooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01[ooooo0_l0000cooooo`;o0000?Ooo
ool2o`000;Oooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooo
oonHV9So410@00Kooooo00?o0000ooooooooool0=Oooool2o`0001Sooooo0_l0003fooooo`000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03
o`000?oooooooooo03Gooooo0_l00003ooooo`;o0000ooooool<ooooo`007_ooool00ol0003ooooo
ooooo`0jooooo`;o00003?ooool2o`000?gooooo000Nooooo`03o`000?oooooooooo04Sooooo0_l0
003mooooo`007_ooool00ol0003oooooooooo`0kooooo`;o0000VOooool2o`0006oooooo000Noooo
o`03o`000?oooooooooo03_ooooo0_l0000booooo`;o0000IOooool2o`0006oooooo000Nooooo`03
o`000?oooooooooo00kooooo0_l0001Oooooo`;o0000e_ooool001kooooo00?o0000ooooooooool0
3_ooool2o`000?oooooo>?ooool001kooooo00?o0000ooooooooool05_ooool2o`000?oooooo<?oo
ool001kooooo00?o0000ooooooooool05_ooool2o`0008;ooooo0_l0002[ooooo`007_ooool00ol0
003oooooooooo`0Sooooo`;o0000D?ooool2o`0002?ooooo0_l0002[ooooo`007_ooool00ol0003o
ooooooooo`0Sooooo`;o000000?oooooo`000?l00000COooool2o`0005;ooooo0_l0001looooo`00
7_ooool00ol0003oooooooooo`0Vooooo`;o0000;_ooool2o`0001[ooooo0_l0001Eooooo`;o0000
;_ooool2o`0004cooooo000Nooooo`;o00006_ooool2o`0003_ooooo0_l0000Jooooo`;o0000QOoo
ool2o`0004;ooooo0_l00008ooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o0000oooooolS
ooooo`;o00002?ooool001kooooo00?o0000ooooooooool0Voooool2o`000:[ooooo000Nooooo`03
o`000?oooooooooo09_ooooo0_l0002Zooooo`007_ooool00ol0003oooooooooo`1;ooooo`;o0000
n_ooool001kooooo00?o0000ooooooooool0Boooool2o`000?[ooooo000Nooooo`03o`000?oooooo
oooo0;_ooooo0_l0000Mooooo`;o0000Joooool001kooooo00?o0000ooooooooool0^oooool2o`00
01gooooo0_l0001[ooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o00000_ooool2o`000;ko
oooo0_l0001Zooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o00000_ooool2o`000;kooooo
0_l0001Zooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000oooo
ooooool06Oooool2o`000?oooooo;Oooool001kooooo00?o0000ooooooooool06Oooool2o`000?oo
oooo;Oooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooo`kooooo0_l0000hooooo`007_ooool00ol0003oooooooooo`11ooooo`;o0000@Oooool2
o`0008Oooooo0_l0000hooooo`007_ooool00ol0003oooooooooo`11ooooo`;o0000@Oooool2o`00
0<7ooooo000Nooooo`03o`000?oooooooooo09;ooooo0_l0002cooooo`007_ooool00ol0003ooooo
ooooo`2Booooo`;o0000/oooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`1Mooooo`;o0000j?ooool001kooooo00?o0000ooooooooool0GOooool2o`00
0>Sooooo000Nooooo`03o`000?oooooooooo0;?ooooo0_l0002Booooo`007_ooool00ol0003ooooo
ooooo`0Gooooo`;o0000V_ooool2o`0009;ooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0
003ooooooboooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003ooooo
odWooooo000Nooooo`03o`000?oooooooooo0?oooooo5?ooool2o`0003;ooooo000Nooooo`03o`00
0?oooooooooo02_ooooo0_l0002jooooo`;o0000:_ooool2o`0003;ooooo000Nooooo`04o`000?oo
ooooooooooooo`;o0000:?ooool2o`000;[ooooo0_l0001Nooooo`007_ooool01?l0003ooooooooo
ooooool2o`000?ooooooAOooool001kooooo00?o0000ooooooooool0ZOooool2o`0009cooooo000N
ooooo`03o`000?oooooooooo0:Wooooo0_l0002Looooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo08_ooooo0_l0002jooooo`007_ooool00ol0003ooooo
ooooo`2;ooooo`;o0000^_ooool001kooooo00?o0000ooooooooool0^?ooool2o`0008gooooo000N
ooooo`03o`000?oooooooooo0;Sooooo0_l0002=ooooo`007_ooool00ol0003oooooooooo`3Koooo
o`;o0000J_ooool001kooooo00?o0000ooooooooool0foooool2o`0006[ooooo0003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03
o`000?oooooooooo0;[ooooo0_l0002;ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^_ooool2o`0008_o
oooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol0003oooooodSo
oooo0003ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00007oooo
o`03o`000?oooooooooo0?oooooo3_ooool2o`0003Sooooo0003ooooo`05o`000?oooooooooooooo
ool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo09Kooooo0_l0000<
ooooo`;o0000Ioooool2o`0003Sooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo09Kooooo0_l0000<ooooo`;o0000XOooool0
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000
ooooooooool0YOooool2o`000:3ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool0
0omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo02Sooooo0_l0000dooooo`;o0000AOooool2
o`000:3ooooo000Nooooo`03o`000?oooooooooo02Sooooo0_l0000dooooo`;o0000ioooool001ko
oooo00?o0000ooooooooool0KOooool2o`000=Sooooo000Nooooo`03o`000?oooooooooo06gooooo
0_l0003Hooooo`007_ooool00ol0003oooooooooo`1Uooooo`;o0000h?ooool001kooooo00?o0000
ooooooooool0IOooool2o`0008Wooooo0_l0001<ooooo`;o00001oooool001kooooo00?o0000oooo
ooooool0l?ooool2o`0004cooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`1kooooo`;o
0000b_ooool001kooooo00?o0000ooooooooool0Goooool2o`0000Kooooo0_l0000Booooo`;o0000
b_ooool001kooooo00?o0000ooooooooool0Goooool2o`0000Kooooo0_l0003Nooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0;Oooooo0_l0002>oooo
o`007_ooool2o`000;Sooooo0_l0002>ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0ooooool_
ooooo`;o00005oooool001kooooo00?o0000ooooooooool0ooooool_ooooo`;o00005oooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3Wooooo`;o0000
G_ooool001kooooo00?o0000ooooooooool0ioooool2o`0002gooooo0_l0000_ooooo`007_ooool0
0ol0003oooooooooo`3ooooooaOooooo0_l0000_ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0:Gooooo0_l0002Pooooo`007_ooool00ol0003ooooo
ooooo`2Uooooo`;o0000X?ooool001kooooo00?o0000ooooooooool0`oooool2o`0006oooooo0_l0
000Aooooo`007_ooool00ol0003oooooooooo`0looooo`;o0000QOooool2o`00013ooooo0_l0001M
ooooo`;o00004Oooool001kooooo00?o0000ooooooooool0??ooool2o`0009Oooooo0_l0001`oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_oo
ool00ol0003oooooooooo`08ooooo`;o0000ooooool/ooooo`;o00004?ooool001kooooo00?o0000
ooooooooool02?ooool2o`000?oooooo;?ooool2o`00013ooooo000Nooooo`03o`000?oooooooooo
01Wooooo0_l0003looooo`;o0000;_ooool001kooooo00?o0000ooooooooool06Oooool2o`000?co
oooo0_l0000^ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo06Cooooo0_l0003Qooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o0000:Oooool2
o`0002_ooooo0_l0000Sooooo`;o00007Oooool2o`0009gooooo000Nooooo`03o`000?oooooooooo
00Sooooo0_l00002ooooo`;o0000:Oooool2o`0000gooooo0_l00011ooooo`;o00007Oooool2o`00
09gooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0000looooo`;o0000ooooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o0000EOoo
ool2o`00023ooooo0_l0002mooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o0000EOooool2
o`00023ooooo0_l0000Gooooo`;o0000Y?ooool001kooooo00?o0000ooooooooool0XOooool2o`00
0:Cooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
ooooooljooooo`;o00003?ooool001kooooo0_l00004ooooo`;o0000ooooooleooooo`;o00003?oo
ool001kooooo00?o0000ooooooooool00_ooool3o`000?oooooo@oooool001kooooo00?o0000oooo
ooooool00_ooool2o`000?ooooooA?ooool001kooooo00?o0000ooooooooool0oooooolVooooo`;o
00008?ooool001kooooo00?o0000ooooooooool0oooooolVooooo`;o00008?ooool001kooooo00?o
0000ooooooooool0:Oooool2o`0002Sooooo0_l0003booooo`007_ooool00ol0003oooooooooo`0Y
ooooo`;o0000:?ooool2o`00067ooooo0_l0001Xooooo`;o00009Oooool001kooooo00?o0000oooo
ooooool02?ooool2o`0003gooooo0_l0000Qooooo`;o0000B_ooool2o`0002oooooo0_l0000goooo
o`;o00009Oooool001kooooo00?o0000ooooooooool02?ooool2o`0002cooooo1?l0000=ooooo`;o
00008Oooool2o`00047ooooo0_l0000hooooo`;o0000G_ooool001kooooo00?o0000ooooooooool0
6Oooool2o`0001_ooooo1?l0001cooooo`;o0000F_ooool2o`0003cooooo000Nooooo`03o`000?oo
oooooooo01Wooooo0_l0003]ooooo`?o0000??ooool001kooooo00?o0000ooooooooool0ooooool9
ooooo`;o00008_ooool2o`0001Wooooo000Nooooo`03o`000?oooooooooo057ooooo0_l0003Ioooo
o`;o00006Oooool001kooooo00?o0000ooooooooool0DOooool2o`000:Gooooo0_l00011ooooo`;o
00002_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko
<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0;_ooool2o`0000gooooo0_l0002ioooo
o`;o0000@Oooool2o`0000[ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo01Gooooo0_l0000G
ooooo`;o00003Oooool2o`000?oooooo2Oooool000?ooooo00Go410@oooooooooooooooooa0@400;
ooooo`05o`000?ooooooooooooooool000001_ooool3o`0001Gooooo0_l0001Gooooo`;o0000Mooo
ool2o`00043ooooo0_l0000Looooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go
0000oiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo06kooooo0_l00015ooooo`;o0000
<?ooool2o`00043ooooo0_l0000Looooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo
00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0;Gooooo0_l0002@ooooo`00
0oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003o
ooooooooo`1Looooo`;o0000jOooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03
omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0G?ooool2o`000>Wooooo0003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo
02oooooo0_l0003ooooooaOooooo000Nooooo`03o`000?oooooooooo02gooooo1?l0000Jooooo`;o
0000i_ooool2o`0001;ooooo000Nooooo`?o0000:Oooool6o`0000?ooooo0_l0000Gooooo`;o0000
h?ooool2o`0000Cooooo0_l0000Booooo`007_ooool3o`0002Wooooo1?l00005ooooo`;o0000nOoo
ool2o`0001Sooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0000:ooooo`;o0000=oooool2
o`0000Cooooo0_l0000mooooo`;o0000ROooool2o`0001Wooooo000Nooooo`04o`000?oooooo0000
o`0001Kooooo0_l00006ooooo`;o00000_ooool2o`0001?ooooo0_l0000Rooooo`;o00001?ooool2
o`0003gooooo0_l00029ooooo`;o00006Oooool001gooooo0_l000000ooooooo0000o`00000Noooo
o`;o000000?oooooo`000?l000005?ooool2o`0007Oooooo0_l0002Dooooo`007Oooool2o`0002Co
oooo0_l0002=ooooo`;o0000GOooool2o`0003Gooooo000Nooooo`?o00007?ooool2o`0000Oooooo
0_l0000gooooo`;o0000/?ooool2o`0003Gooooo000Nooooo`?o00007?ooool2o`0000Oooooo0_l0
000Fooooo`;o00007oooool2o`000:kooooo0_l0000gooooo`007_ooool00ol0003oooooooooo`0m
ooooo`;o00002oooool4o`0000_ooooo0_l0002cooooo`;o0000:_ooool2o`0000_ooooo000Noooo
o`03o`000?oooooooooo02?ooooo0_l0000Uooooo`Co00000oooool2o`0000Kooooo0_l0003;oooo
o`;o00004_ooool2o`0000_ooooo000Nooooo`Co00008_ooool2o`0002Oooooo0_l00003ooooo`;o
00002oooool2o`000<Kooooo0_l0000Oooooo`007_ooool01?l0003oooooo`000?l0000Wooooo`;o
00008_ooool2o`00013ooooo0_l0003Wooooo`007_ooool00ol0003oooooooooo`0Xooooo`;o0000
;Oooool2o`000:[ooooo0_l00012ooooo`007_ooool00ol0003oooooooooo`1Gooooo`?o0000ZOoo
ool2o`0001Kooooo0_l0000Fooooo`;o00004_ooool001kooooo00?o0000ooooooooool0F?ooool2
o`000<7ooooo0_l0000Fooooo`;o00002?ooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo
0?oooooo?_ooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo05Wooooo0_l0003/ooooo`00
7_ooool00ol0003oooooooooo`0Vooooo`;o0000;Oooool2o`0000;ooooo0_l0003/ooooo`007_oo
ool00ol0003oooooooooo`0Vooooo`;o0000;Oooool2o`0006Kooooo0_l00028ooooo`007_ooool0
0ol0003oooooooooo`0booooo`;o0000ROooool2o`0005cooooo0_l0000Zooooo`007_ooool00ol0
003oooooooooo`0booooo`;o0000<Oooool2o`000;Cooooo0_l0000Zooooo`007_ooool00ol0003o
ooooooooo`1Uooooo`;o0000h?ooool001kooooo00?o0000ooooooooool06Oooool4o`000;Cooooo
0_l0001dooooo`007_ooool00ol0003oooooooooo`05ooooo`;o00004_ooool4o`000;Cooooo0_l0
000mooooo`;o0000=Oooool001kooooo00?o0000ooooooooool01Oooool2o`000?oooooo2_ooool2
o`0003Gooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0001Yooooo`;o
0000gOooool001kooooo00?o0000ooooooooool0D_ooool2o`0001Cooooo0_l0000jooooo`;o0000
XOooool001kooooo00?o0000ooooooooool0@?ooool2o`00013ooooo0_l0001@ooooo`;o0000XOoo
ool001kooooo00?o0000ooooooooool08_ooool2o`0001cooooo0_l0003looooo`;o00001oooool0
01kooooo00?o0000ooooooooool01_ooool2o`0001[ooooo0_l0000@ooooo`;o0000ooooool9oooo
o`;o00001oooool001kooooo00?o0000ooooooooool01_ooool2o`0002cooooo0_l0000Jooooo`;o
0000O_ooool2o`0001oooooo0_l0001Dooooo`007_ooool00ol0003oooooooooo`1@ooooo`;o0000
D_ooool2o`0002[ooooo0_l0000Oooooo`;o0000E?ooool001kooooo00?o0000ooooooooool0Dooo
ool2o`0004oooooo0_l0002Qooooo`007_ooool00ol0003oooooooooo`07ooooo`;o00004oooool2
o`000003ooooool0003o0000017ooooo0_l0000Gooooo`;o00001_ooool2o`0004Oooooo0_l0001C
ooooo`;o0000E?ooool001kooooo00?o0000ooooooooool01oooool2o`0001?ooooo0_l000000ooo
oooo0000o`00000Aooooo`;o00005oooool2o`0001Sooooo0_l0000eooooo`;o00001_ooool2o`00
04_ooooo0_l0000Wooooo`;o0000:oooool001kooooo00?o0000ooooooooool0IOooool2o`0003_o
oooo1?l0001dooooo`;o0000:oooool001kooooo00?o0000ooooooooool0;_ooool2o`00017ooooo
0_l0001Oooooo`;o00008_ooool2o`0005Gooooo0_l0000Xooooo`007_ooool00ol0003ooooooooo
o`0Hooooo`;o00005?ooool2o`00013ooooo0ol00002ooooo`;o0000Ooooool2o`00047ooooo0_l0
000Booooo`;o00005?ooool2o`0001;ooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l0000;
ooooo`;o00009?ooool4o`0000?ooooo0_l0000Uooooo`;o0000Voooool2o`0002Sooooo0_l0000B
ooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o00007?ooool2o`0001?ooooo0_l0000/oooo
o`;o0000>?ooool2o`0006Kooooo0_l0000gooooo`007_ooool00ol0003oooooooooo`0Yooooo`;o
00005oooool3o`0001_ooooo0_l00007ooooo`;o00001Oooool2o`0003;ooooo1?l0001Vooooo`;o
0000=oooool001kooooo0_l00011ooooo`Ko00002oooool2o`0000gooooo0_l00007ooooo`;o0000
1Oooool2o`0003;ooooo0_l0000`ooooo`;o0000Koooool001kooooo00?o0000ooooooooool0<ooo
ool2o`0000_ooooo0_l00002ooooo`;o00002oooool2o`0008?ooooo0_l0000Booooo`;o0000Fooo
ool001kooooo00?o0000ooooooooool0<oooool2o`00017ooooo0_l0000[ooooo`;o0000:oooool2
o`0004Sooooo0_l0001Kooooo`007_ooool00ol0003oooooooooo`0Wooooo`;o000000Coooooo`00
0?l0003ooooo0_l00003ooooo`?o00004Oooool2o`0002_ooooo0_l0000[ooooo`;o00004?ooool2
o`0000;ooooo0_l0002?ooooo`007_ooool00ol0003oooooooooo`0Wooooo`;o000000Coooooo`00
0?l0003ooooo0_l00003ooooo`?o00000_ooool2o`0000;ooooo0_l00002ooooo`;o00003_ooool2
o`00067ooooo0_l00002ooooo`;o00003?ooool2o`00087ooooo000Nooooo`;o00006?ooool2o`00
01cooooo1?l00002ooooo`Ko000000?oooooo`000?l000000_l00003ooooo`;o00001?ooool2o`00
03oooooo0_l0000booooo`;o0000POooool001kooooo0_l0000Hooooo`;o00002_ooool2o`00013o
oooo0_l00006ooooo`Co000000?oooooo`000?l000000_l00003ooooo`Co00001oooool2o`0003[o
oooo1?l0001looooo`;o000000?oooooo`000?l00000<_ooool001kooooo00?o0000ooooooooool0
8oooool2o`0000_ooooo0_l00003ooooo`;o00000oooool2o`0000oooooo0_l00007ooooo`;o0000
??ooool2o`0004Oooooo0_l0000cooooo`;o000000?oooooo`000?l00000<_ooool001kooooo00?o
0000ooooooooool0<?ooool4o`0000Kooooo0_l00002ooooo`;o0000ROooool2o`00013ooooo0_l0
001Zooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o00003oooool3o`0000[ooooo0_l0000a
ooooo`;o00007Oooool2o`0003Oooooo0_l0001eooooo`;o00001Oooool001kooooo00?o0000oooo
ooooool08?ooool2o`0000oooooo0ol0000Booooo`;o00000_ooool2o`0002Gooooo0_l0000Moooo
o`;o0000[_ooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0000Kooooo`?o
00004_ooool2o`0000;ooooo0_l00012ooooo`;o0000Z?ooool2o`0000gooooo000Nooooo`03o`00
0?oooooooooo01Cooooo0_l0000Kooooo`;o00002Oooool2o`00013ooooo0_l0000nooooo`;o0000
MOooool2o`00037ooooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`0Wooooo`;o00003?oo
ool2o`0000Gooooo0_l0000>ooooo`Co0000]Oooool4o`0003kooooo0003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`;o0000
9?ooool2o`0000;ooooo0_l00003ooooo`;o00001oooool2o`0000Gooooo0_l0000>ooooo`;o0000
:Oooool2o`0004Cooooo0_l00018ooooo`;o0000?_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo0_l0000Oooooo`;o
00000_ooool3o`0000Oooooo0_l00009ooooo`;o00009_ooool2o`0000Sooooo0_l0000<ooooo`;o
0000A?ooool2o`0008Sooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003o
oooooooooooooooo000000Kooooo0ol0000Nooooo`;o00000_ooool2o`0000;ooooo0_l00004oooo
o`;o00002Oooool3o`0000Gooooo0_l0000Nooooo`;o00002?ooool2o`0000gooooo0_l0001>oooo
o`;o00007_ooool2o`0004cooooo0_l0000?ooooo`000oooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooooooo00[ooooo0_l0000D
ooooo`;o00001?ooool2o`0000Wooooo0_l00005ooooo`;o00001Oooool2o`0000cooooo0_l0000J
ooooo`;o00002_ooool2o`000003ooooool0003o000001Gooooo0_l0000gooooo`;o00007_ooool2
o`0004cooooo0_l0000?ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<
o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo00[ooooo0_l0000Dooooo`;o00000ooo
ool2o`0000?ooooo0_l00005ooooo`Ko00005_ooool2o`0000[ooooo0_l0000Jooooo`;o00006?oo
ool2o`0001?ooooo0_l00009ooooo`;o0000U_ooool000?ooooo00Go410@oooooooooooooooooa0@
400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`0Uooooo`Co0000
00?oooooo`000?l000000_ooool4o`000003ooooool0003o000000;o00000_ooool3o`0001gooooo
0_l00019ooooo`;o00002?ooool3o`0007;ooooo0_l0000Rooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo00Go
oooo0_l0000Pooooo`Ko000000?oooooo`000?l000000_l00007ooooo`Ko000000?oooooo`000?l0
00003?ooool2o`0000Gooooo0_l0001Gooooo`;o0000Loooool2o`0001Cooooo0_l0000<ooooo`00
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06oooo
o`03o`000?oooooooooo00Gooooo0_l0000=ooooo`;o000000?oooooo`000?l000002?ooool2o`00
00Cooooo1_l00008ooooo`;o00001Oooool3o`000003ooooool0003o000000cooooo0_l00005oooo
o`;o00002Oooool2o`000003ooooool0003o000007Wooooo0_l0001Iooooo`;o00003?ooool001ko
oooo00?o0000ooooooooool01Oooool2o`0000Gooooo0_l00006ooooo`;o000000?oooooo`000?l0
00001?ooool2o`0000;ooooo0_l00004ooooo`Ko00001Oooool2o`000003ooooool0003o000000;o
00000_ooool2o`0002?ooooo1ol0000jooooo`;o0000>oooool2o`00063ooooo0_l00005ooooo`00
7_ooool00ol0003oooooooooo`0:ooooo`Co00003oooool2o`0000;ooooo0_l000001?oooooo0000
o`000?ooool5o`0000?ooooo0_l000001?oooooo0000o`000?ooool4o`0000;ooooo0_l00005oooo
o`;o00006oooool4o`0000;ooooo1Ol0000gooooo`;o0000WOooool2o`0000Gooooo000Nooooo`03
o`000?oooooooooo00[ooooo0_l0000Eooooo`;o000000Coooooo`000?l0003ooooo1Ol00003oooo
o`;o00001?ooool4o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00006oooool3o`00
00?ooooo1Ol00003ooooo`;o0000f?ooool001kooooo00?o0000ooooooooool09?ooool2o`0000?o
oooo1Ol00009ooooo`;o000000Coooooo`000?l0003ooooo0ol000000ooooooo0000o`000002o`00
00;ooooo0_l00004ooooo`;o00000oooool2o`0000;ooooo0_l00008ooooo`;o00000oooool2o`00
00Kooooo0_l0001Sooooo`;o0000K?ooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo023o
oooo0_l00007ooooo`Go00003?ooool2o`000003ooooool0003o000000Ko00000_ooool2o`0000Co
oooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00006ooooo`Co00000oooool2o`0003?o
oooo0_l0000<ooooo`;o00002_ooool2o`0001cooooo0_l0001/ooooo`;o00001Oooool001kooooo
00?o0000ooooooooool08?ooool2o`0000Oooooo0_l00002ooooo`;o00003oooool3o`0000oooooo
1?l00002ooooo`;o00001_ooool4o`0001Sooooo1?l0000Looooo`;o00003?ooool2o`0000[ooooo
0_l0002Aooooo`007_ooool00ol0003oooooooooo`0Kooooo`;o00002?ooool5o`0000?ooooo0_l0
00000ooooooo0000o`000003ooooo`;o00001_ooool4o`0000_ooooo0_l0000@ooooo`;o000000?o
ooooo`000?l000000_l00002ooooo`;o00004Oooool4o`000:[ooooo0_l0000Mooooo`007_ooool0
0ol0003oooooooooo`0Kooooo`;o00000_ooool2o`0000Cooooo1Ol00005ooooo`Co000000Cooooo
o`000?l0003o00001_ooool6o`0000Wooooo0_l0000@ooooo`;o000000?oooooo`000?l000000_l0
0002ooooo`;o0000_oooool2o`0001gooooo000Nooooo`03o`000?oooooooooo01oooooo0_l0000>
ooooo`Co000000?oooooo`000?l000001?l00004ooooo`Ko00005oooool7o`0000Gooooo0_l0000<
ooooo`;o00004Oooool2o`000;gooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l00006oooo
o`;o00003oooool2o`0000[ooooo0_l00002ooooo`co00001?ooool:o`0000oooooo0_l000000ooo
oooo0000o`000005o`0000Gooooo0_l0000<ooooo`;o00004Oooool2o`0002Kooooo0_l0002Eoooo
o`007_ooool00ol0003oooooooooo`06ooooo`;o00001_ooool2o`0001_ooooo2ol00003ooooo`;o
00000_ooool6o`000003ooooool0003o000000Co00003_ooool2o`0000;ooooo0ol0000Qooooo`;o
0000;_ooool2o`0009Gooooo000Nooooo`;o00007oooool2o`0000gooooo0_l000000ooooooo0000
o`000004o`000003ooooool0003o000000;ooooo1?l000001?oooooo0000o`000?l00004ooooo`?o
00004_ooool3o`0001Gooooo0_l0000:ooooo`Co00000_ooool2o`000;oooooo000Nooooo`03o`00
0?oooooooooo01kooooo0_l0000@ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo
0_l00005ooooo`Oo000000?oooooo`000?l000007Oooool2o`0000Wooooo0_l0000<ooooo`;o0000
0_ooool2o`000:[ooooo0_l0000Cooooo`007_ooool00ol0003oooooooooo`0`ooooo`Go00000_oo
ool2o`0000?ooooo1?l00002ooooo`Ko00000_ooool2o`0000kooooo0_l0000=ooooo`;o000000?o
ooooo`000?l00000<oooool2o`0008oooooo0_l0000Cooooo`007_ooool00ol0003oooooooooo`0F
ooooo`Co00005oooool4o`0000;ooooo0_l00002ooooo`Go00000oooool5o`0000Oooooo0ol00007
ooooo`Go00003Oooool3o`0000gooooo0ol00008ooooo`;o00006Oooool2o`0001?ooooo0_l0002?
ooooo`007_ooool00ol0003oooooooooo`0Fooooo`Co00003oooool2o`0000;ooooo0_l00008oooo
o`Ko00002?ooool2o`0000?ooooo0ol000000ooooooo0000o`000003o`0000Kooooo1Ol0000=oooo
o`;o00003_ooool3o`0000Sooooo0_l00004ooooo`;o0000:?ooool2o`0001Sooooo0_l0001Zoooo
o`;o00002Oooool001kooooo00?o0000ooooooooool02_ooool2o`0001gooooo0_l00002ooooo`;o
00001oooool8o`0000?ooooo0_l00005ooooo`Go000000?oooooo`000?l000001Ol00006ooooo`?o
00002?ooool2o`0001kooooo0_l00004ooooo`;o0000<?ooool2o`00013ooooo0_l00002ooooo`;o
0000I_ooool2o`0000Wooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l00002ooooo`;o0000
1?ooool2o`0001Gooooo0_l00009ooooo`Wo00000_ooool2o`000003ooooool0003o000000;ooooo
1?l00002ooooo`?o00000_ooool2o`0000Oooooo0ol00003ooooo`;o00000_ooool2o`0001kooooo
0_l0000fooooo`;o00005?ooool2o`00077ooooo000Nooooo`03o`000?oooooooooo00kooooo0_l0
0004ooooo`;o00005Oooool2o`0000gooooo1Ol00002ooooo`;o000000?oooooo`000?l000000_l0
00000ooooooo0000o`000005o`0000cooooo1Ol000000ooooooo0000o`000005ooooo`;o00006_oo
ool2o`000:7ooooo0_l0000Mooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o00003_ooool4
o`0001Cooooo1_l00003ooooo`;o00000_ooool2o`0000Cooooo1?l00006ooooo`;o00001Oooool4
o`0000Kooooo1?l0000;ooooo`;o00003Oooool2o`0001oooooo0_l00020ooooo`;o00007Oooool0
01kooooo00?o0000ooooooooool02_ooool2o`0000Gooooo0_l0000>ooooo`Co00001_ooool2o`00
00[ooooo1ol00004ooooo`;o00000_ooool2o`0000Sooooo0ol00003ooooo`;o00001Oooool2o`00
00Sooooo0_l00002ooooo`;o000000?oooooo`000?l000001_ooool4o`0000Gooooo0_l00004oooo
o`Co00007Oooool2o`0009oooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0000Fooooo`;o
00001oooool2o`0000[ooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo1_l00008oooo
o`?o00000_ooool2o`0000gooooo0_l00005ooooo`;o000000?oooooo`000?l000002?ooool2o`00
00Gooooo0_l00006ooooo`;o0000__ooool001kooooo00?o0000ooooooooool08_ooool2o`0001Ko
oooo0_l000000ooooooo0000o`000002ooooo`Go00002?ooool2o`0000Cooooo0ol0000=ooooo`;o
00004_ooool2o`0000Cooooo0ol0001Sooooo`;o0000:oooool2o`0003Cooooo000Nooooo`03o`00
0?oooooooooo02?ooooo1?l000000ooooooo0000o`000009ooooo`;o00001Oooool4o`000003oooo
ool0003o000000;o000000?oooooo`000?l000002?ooool2o`0000;ooooo1Ol00007ooooo`;o0000
00?oooooo`000?l000000_ooool2o`0000Kooooo0_l0000?ooooo`;o0000I?ooool2o`0002_ooooo
0_l0000dooooo`007_ooool00ol0003oooooooooo`0Qooooo`Ko000000Coooooo`000?l0003ooooo
0_l00006ooooo`;o00001oooool;o`0000[ooooo2?l00005ooooo`;o000000?oooooo`000?l00000
1?l00002ooooo`;o00000_ooool3o`0000Gooooo0_l0000>ooooo`Co0000__ooool001kooooo00?o
0000ooooooooool08Oooool2o`0000Sooooo0_l00003ooooo`;o00002Oooool2o`000004ooooool0
003o0000ooooo`?o000000?oooooo`000?l000002_ooool9o`0000Cooooo0_l000000ooooooo0000
o`000002o`0000Cooooo1ol00005ooooo`;o00001oooool2o`0000Gooooo1?l0002nooooo`007_oo
ool00ol0003oooooooooo`0Looooo`;o00004_ooool2o`0000Wooooo0_l0000Iooooo`Ko000000?o
ooooo`000?l000000_ooool2o`0000Oooooo1?l0000@ooooo`;o0000@oooool2o`0005?ooooo0_l0
000]ooooo`007_ooool2o`0001gooooo0_l0000Mooooo`?o00000_ooool2o`0000Sooooo0_l00000
0ooooooo0000o`000002ooooo`;o00001?ooool5o`000004ooooool0003o0000ooooo`;o00001_oo
ool2o`0000_ooooo0_l0000;ooooo`;o0000?oooool2o`0005?ooooo0_l0000]ooooo`007_ooool0
0ol0003oooooooooo`0Fooooo`;o00002oooool4o`0000Kooooo0_l0000=ooooo`;o00000_ooool2
o`0000Sooooo0_l000001?oooooo0000o`000?ooool3o`0000Cooooo1?l00005ooooo`;o00001_oo
ool2o`0000_ooooo0_l0000;ooooo`;o0000`oooool001kooooo00?o0000ooooooooool05_ooool2
o`0000_ooooo1?l00006ooooo`;o00002Oooool2o`0000Wooooo0_l0000;ooooo`;o00001?ooool2
o`0001Oooooo0_l0003Fooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o00004?ooool2o`00
013ooooo0_l00009ooooo`;o00004Oooool5o`0000?ooooo0_l000000ooooooo0000o`00000<oooo
o`;o00001Oooool2o`0000[ooooo0_l00018ooooo`;o0000NOooool001kooooo00?o0000oooooooo
ool05?ooool2o`0000kooooo1?l0000Mooooo`;o00001_ooool2o`0000;ooooo0_l00004ooooo`Co
00000oooool2o`000004ooooool0003o0000o`0001;ooooo0_l0000:ooooo`;o0000B?ooool2o`00
07Wooooo000Nooooo`03o`000?oooooooooo01cooooo0_l00006ooooo`Co00005?ooool2o`0000Oo
oooo0_l00006ooooo`;o000000Coooooo`000?l0003o00001_ooool4o`0000;ooooo0_l000000ooo
oooo0000o`000002o`0000[ooooo0_l00004ooooo`;o00008Oooool4o`000:[ooooo000Nooooo`03
o`000?oooooooooo00[ooooo0_l0000@ooooo`;o00002?ooool2o`0000;ooooo0_l0000@ooooo`;o
00003oooool2o`000003ooooool0003o000000;ooooo0ol00002ooooo`Go000000?oooooo`000?l0
00000oooool2o`0000[ooooo0_l00002ooooo`;o00003_ooool2o`0001?ooooo1?l0002Zooooo`00
7_ooool00ol0003oooooooooo`0:ooooo`;o00007_ooool2o`0000kooooo0_l0000Aooooo`;o0000
00?oooooo`000?l000000_ooool3o`0000Cooooo0ol0000Booooo`;o000000Coooooo`000?l0003o
00003Oooool3o`000<7ooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0000`ooooo`;o0000
2?ooool2o`0000oooooo0_l00003ooooo`Co00002Oooool2o`0000[ooooo0_l0000>ooooo`?o0000
0_ooool2o`000;;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`08ooooo`;o00001Ooo
ool2o`0000[ooooo0_l0000Wooooo`;o00005?ooool3o`000003ooooool0003o000000Oooooo0_l0
000:ooooo`;o00003_ooool3o`0000;ooooo0_l0000Aooooo`;o0000Woooool2o`0000Wooooo000N
ooooo`03o`000?oooooooooo00oooooo0_l0000:ooooo`;o0000>?ooool4o`0000;ooooo0_l00000
0ooooooo0000o`000004ooooo`;o00000_ooool2o`0000Sooooo0ol0000>ooooo`?o000000?ooooo
o`000?l000004_ooool2o`000:[ooooo000Nooooo`03o`000?oooooooooo03oooooo0_l0000;oooo
o`Ko00000oooool6o`0000Wooooo0_l000001?oooooo0000o`000?l00008ooooo`;o00000oooool2
o`0000Oooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o0000Ooooool2o`0003gooooo000N
ooooo`03o`000?oooooooooo03oooooo0_l0000;ooooo`Ko00000_ooool3o`0000;ooooo1?l00007
ooooo`;o000000?oooooo`000?l000001oooool2o`0000Gooooo0_l00007ooooo`;o00000oooool2
o`00087ooooo0_l0000mooooo`007_ooool3o`0000cooooo0_l0000Wooooo`;o00004?ooool2o`00
00_ooooo0_l00005ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Sooooo1?l0000Aoooo
o`?o0000_oooool001kooooo0ol0000<ooooo`;o00006?ooool2o`0000gooooo0_l0000@ooooo`;o
00001Oooool4o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l000001?ooool4o`0000[o
oooo0_l00007ooooo`;o00001?ooool8o`0006Oooooo0_l0000Qooooo`;o0000<_ooool001kooooo
00?o0000ooooooooool09_ooool2o`0000_ooooo0_l0000Iooooo`Co00000_ooool2o`0000;ooooo
0_l00008ooooo`Ko00004oooool2o`0000Cooooo1Ol000000ooooooo0000o`00000<ooooo`;o0000
1Oooool2o`0001;ooooo0_l0000nooooo`;o00008Oooool2o`0002;ooooo0_l0000>ooooo`007_oo
ool2o`0003Cooooo0_l0000Sooooo`;o00001?ooool2o`0000;ooooo1?l0000Eooooo`;o00001ooo
ool2o`0000oooooo0_l00005ooooo`;o00004_ooool3o`0008Cooooo0_l0000>ooooo`007_ooool0
0ol0003oooooooooo`0>ooooo`;o0000BOooool2o`0000?ooooo0_l00004ooooo`?o00005?ooool2
o`0003Cooooo0_l0001^ooooo`;o00009?ooool001kooooo00?o0000ooooooooool03_ooool2o`00
047ooooo0_l00006ooooo`;o00002_ooool2o`000;[ooooo0_l0000Tooooo`007_ooool00ol0003o
ooooooooo`0dooooo`;o00004oooool4o`0000Cooooo0_l00005ooooo`Go0000R?ooool2o`00063o
oooo000Nooooo`03o`000?oooooooooo01Kooooo0_l0000Looooo`;o00004oooool4o`0000Cooooo
0_l00005ooooo`Go00005?ooool2o`0007;ooooo0_l0001Pooooo`007_ooool00ol0003ooooooooo
o`08ooooo`;o00003?ooool2o`0001[ooooo0_l00005ooooo`;o000000Coooooo`000?l0003o0000
4_ooool2o`0000kooooo0_l0000:ooooo`;o00000_ooool4o`0007cooooo0_l0001Dooooo`007_oo
ool00ol0003oooooooooo`08ooooo`;o0000:?ooool2o`0000Gooooo0_l000001?oooooo0000o`00
0?l00004ooooo`;o00003?ooool2o`0000kooooo0_l0000:ooooo`;o00001?ooool2o`0007cooooo
0_l0001Dooooo`007_ooool00ol0003oooooooooo`07ooooo`;o0000>_ooool2o`0000cooooo0_l0
0003ooooo`;o00009_ooool2o`0000cooooo0_l00005ooooo`;o0000/_ooool001kooooo00?o0000
ooooooooool01oooool2o`0001kooooo0_l0000<ooooo`;o00006Oooool2o`0000Cooooo0_l0000T
ooooo`Co00003?ooool2o`0000Gooooo0_l0002booooo`007_ooool00ol0003oooooooooo`0Woooo
o`;o00002?ooool2o`0000;ooooo0_l00003ooooo`;o00001_ooool2o`0000_ooooo0ol0000Zoooo
o`Co0000UOooool2o`00033ooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0000Fooooo`Co
00001oooool2o`0000Kooooo0_l0000;ooooo`;o00009_ooool2o`0008Kooooo0_l0000Dooooo`;o
0000<?ooool001kooooo00?o0000ooooooooool05oooool2o`0001Kooooo0_l0000Vooooo`;o0000
7_ooool2o`0008Kooooo0_l0000booooo`;o00004_ooool001kooooo00?o0000ooooooooool03Ooo
ool2o`0001Sooooo0_l0000Cooooo`;o00001Oooool2o`0001;ooooo0_l0000Wooooo`;o0000Y?oo
ool2o`0000_ooooo0_l0000Booooo`007_ooool00ol0003oooooooooo`0=ooooo`;o00006?ooool3
o`0001;ooooo0_l00003ooooo`Co00003_ooool2o`0000_ooooo0_l0000Booooo`;o00000oooool2
o`0000Gooooo0_l0002Tooooo`;o00007oooool001Cooooo1?l000000ol@413oooooooooo`03oooo
o`03o`000?oooooooooo02Sooooo0_l00003ooooo`;o00001?ooool2o`0000cooooo0_l0000@oooo
o`;o00002oooool2o`0001;ooooo0_l00003ooooo`;o0000=Oooool2o`0009Gooooo000Fooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0;Oooool2o`0000Cooooo0_l00003ooooo`;o
0000M_ooool2o`0009Gooooo000Fooooo`03o`000?oooooooooo00Gooooo0ol0000hooooo`?o0000
Noooool2o`0008oooooo000Fooooo`03o`000?oooooooooo047ooooo0_l0001kooooo`;o0000Sooo
ool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooo
oe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Cooooo00?oEEEEofIVI_l00000
oooooomBooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.39713 .93671 Mdot
.09692 .90885 Mdot
.10499 .8474 Mdot
.27854 .95643 Mdot
.20623 .89083 Mdot
.21205 .87823 Mdot
.57092 .52108 Mdot
.22894 .89703 Mdot
.32715 .89966 Mdot
.25421 .22889 Mdot
.15604 .95001 Mdot
.17262 .83635 Mdot
.12463 .82665 Mdot
.56249 .87457 Mdot
.20341 .8341 Mdot
.08493 .26812 Mdot
.9712 .92176 Mdot
.1203 .79301 Mdot
.37953 .94522 Mdot
.3407 .94937 Mdot
.77859 .05605 Mdot
.30078 .81118 Mdot
.16262 .74067 Mdot
.0268 .04859 Mdot
.33513 .95016 Mdot
.26029 .89616 Mdot
.28137 .87225 Mdot
.25338 .6635 Mdot
.13518 .90508 Mdot
.26393 .82284 Mdot
.14438 .84844 Mdot
.20904 .84498 Mdot
.36068 .88307 Mdot
.89816 .69843 Mdot
.29692 .10597 Mdot
.25348 .99709 Mdot
.28024 .89764 Mdot
.61336 .78156 Mdot
.19982 .77239 Mdot
.2884 .94582 Mdot
.17608 .85558 Mdot
.48688 .91742 Mdot
.09057 .71022 Mdot
.18969 .01242 Mdot
.5781 .0935 Mdot
.45868 .89657 Mdot
.66817 .13431 Mdot
.24137 .03257 Mdot
.26429 .99884 Mdot
.18744 .56292 Mdot
.16814 .75093 Mdot
.19495 .01661 Mdot
.16719 .86813 Mdot
.21555 .86116 Mdot
.1192 .81637 Mdot
.99323 .3093 Mdot
.41243 .81311 Mdot
.15387 .86122 Mdot
.27881 .86557 Mdot
.36338 .94607 Mdot
.19433 .89336 Mdot
.27017 .89647 Mdot
.85665 .93152 Mdot
.35371 .94297 Mdot
.18154 .93094 Mdot
.28458 .85938 Mdot
.24075 .99181 Mdot
.28232 .87152 Mdot
.1975 .85825 Mdot
.51536 .82097 Mdot
.07183 .11395 Mdot
.10318 .75956 Mdot
.52384 .80886 Mdot
.22961 .09036 Mdot
.17951 .00132 Mdot
.45991 .79677 Mdot
.29241 .76405 Mdot
.61689 .37705 Mdot
.24823 .85079 Mdot
.05051 .77642 Mdot
.33205 .05593 Mdot
.68946 .13675 Mdot
.06326 .22248 Mdot
.24323 .89008 Mdot
.91523 .83267 Mdot
.37306 .10304 Mdot
.23536 .92016 Mdot
.25762 .93391 Mdot
.19563 .84726 Mdot
.06092 .833 Mdot
.35346 .92762 Mdot
.35542 .10349 Mdot
.1024 .79903 Mdot
.93498 .87468 Mdot
.46006 .93081 Mdot
.22509 .107 Mdot
.05194 .62895 Mdot
.33229 .1171 Mdot
.22936 .86327 Mdot
.10255 .51518 Mdot
.27217 .85442 Mdot
.29343 .78395 Mdot
.45261 .8385 Mdot
.11773 .73658 Mdot
.08384 .87202 Mdot
.17314 .73456 Mdot
.05796 .29368 Mdot
.06984 .31276 Mdot
.1102 .88793 Mdot
.83269 .0075 Mdot
.23632 .8843 Mdot
.0198 .69128 Mdot
.28383 .0557 Mdot
.11554 .82378 Mdot
.48767 .21509 Mdot
.49632 .47653 Mdot
.52441 .02007 Mdot
.13075 .80268 Mdot
.98826 .52167 Mdot
.1746 .06365 Mdot
.29345 .91472 Mdot
.17763 .87521 Mdot
.21383 .91709 Mdot
.83107 .74172 Mdot
.61021 .70514 Mdot
.33168 .92227 Mdot
.02858 .85492 Mdot
.38943 .9265 Mdot
.93622 .74179 Mdot
.3813 .83042 Mdot
.1556 .96085 Mdot
.60802 .42764 Mdot
.27005 .52786 Mdot
.20873 .74112 Mdot
.20741 .82438 Mdot
.0924 .79432 Mdot
.16469 .73252 Mdot
.07757 .65233 Mdot
.21368 .88596 Mdot
.26107 .88247 Mdot
.35656 .87932 Mdot
.34756 .94168 Mdot
.3399 .81789 Mdot
.19672 .69194 Mdot
.78191 .95676 Mdot
.1447 .90394 Mdot
.42969 .85657 Mdot
.27728 .87461 Mdot
.6873 .91952 Mdot
.91523 .31716 Mdot
.37793 .86522 Mdot
.34249 .85569 Mdot
.20438 .82186 Mdot
.34496 .95421 Mdot
.22508 .83343 Mdot
.16295 .82486 Mdot
.17168 .64727 Mdot
.48667 .36821 Mdot
.30108 .91164 Mdot
.09015 .23351 Mdot
.11748 .62576 Mdot
.37297 .96535 Mdot
.66495 .99093 Mdot
.24223 .74909 Mdot
.24472 .89322 Mdot
.18601 .85178 Mdot
.26744 .89059 Mdot
.26454 .89411 Mdot
.4873 .8859 Mdot
.21323 .73825 Mdot
.29929 .82739 Mdot
.42896 .06492 Mdot
.3381 .06053 Mdot
.10457 .04201 Mdot
.43107 .95317 Mdot
.25397 .72064 Mdot
.04921 .11504 Mdot
.20287 .91067 Mdot
.56883 .67944 Mdot
.20882 .03484 Mdot
.1828 .69018 Mdot
.10926 .9231 Mdot
.33013 .05966 Mdot
.6331 .04484 Mdot
.12931 .35946 Mdot
.31985 .80073 Mdot
.14587 .06973 Mdot
.33397 .88703 Mdot
.26969 .89489 Mdot
.32394 .81472 Mdot
.41729 .94606 Mdot
.85097 .03413 Mdot
.38856 .92105 Mdot
.98558 .94728 Mdot
.23598 .11811 Mdot
.11849 .75479 Mdot
.35579 .94848 Mdot
.11602 .99587 Mdot
.33997 .89987 Mdot
.25011 .95554 Mdot
.56107 .76481 Mdot
.37256 .95519 Mdot
.19791 .76538 Mdot
.47267 .06938 Mdot
.3386 .94898 Mdot
.25652 .94038 Mdot
.30498 .90536 Mdot
.25871 .87873 Mdot
.0883 .89421 Mdot
.24449 .70039 Mdot
.21134 .7719 Mdot
.39659 .87271 Mdot
.72312 .88547 Mdot
.2748 .5861 Mdot
.09645 .64259 Mdot
.18395 .8862 Mdot
.26199 .92736 Mdot
.30952 .19737 Mdot
.30754 .60145 Mdot
.51817 .98704 Mdot
.26627 .79403 Mdot
.42956 .99443 Mdot
.32508 .93011 Mdot
.24922 .88226 Mdot
.13342 .86581 Mdot
.15618 .67766 Mdot
.41337 .77277 Mdot
.11881 .76253 Mdot
.27157 .69716 Mdot
.33004 .82438 Mdot
.21746 .85666 Mdot
.31148 .94407 Mdot
.32958 .82346 Mdot
.05186 .00922 Mdot
.15271 .14458 Mdot
.02143 .87372 Mdot
.86292 .46181 Mdot
.11333 .82605 Mdot
.79829 .55613 Mdot
.92807 .65569 Mdot
.10753 .86506 Mdot
.32393 .81259 Mdot
.18514 .81013 Mdot
.31683 .71553 Mdot
.26348 .85751 Mdot
.22026 .98509 Mdot
.30666 .00646 Mdot
.31054 .81465 Mdot
.67416 .42284 Mdot
.16442 .84707 Mdot
.15417 .97754 Mdot
.13147 .78236 Mdot
.55294 .39229 Mdot
.90282 .90697 Mdot
.47219 .93001 Mdot
.21442 .8615 Mdot
.18291 .86701 Mdot
.73529 .71338 Mdot
.29483 .00938 Mdot
.94155 .92682 Mdot
.39521 .89362 Mdot
.18692 .81005 Mdot
.27731 .51643 Mdot
.79567 .76272 Mdot
.32987 .81753 Mdot
.37632 .64641 Mdot
.35118 .86776 Mdot
.75547 .73418 Mdot
.11989 .81272 Mdot
.29216 .91283 Mdot
.23675 .87491 Mdot
.80495 .6613 Mdot
.18692 .84497 Mdot
.20008 .79263 Mdot
.39593 .06016 Mdot
.14442 .76029 Mdot
.26384 .61162 Mdot
.54529 .54571 Mdot
.23067 .95527 Mdot
.2452 .76091 Mdot
.21542 .82051 Mdot
.30962 .80658 Mdot
.23721 .74968 Mdot
.37884 .83454 Mdot
.19206 .86931 Mdot
.32855 .93317 Mdot
.19497 .74698 Mdot
.07013 .6067 Mdot
.2216 .71419 Mdot
.18744 .6845 Mdot
.17876 .72813 Mdot
.59008 .72427 Mdot
.34851 .93705 Mdot
.04475 .90409 Mdot
.51254 .00431 Mdot
.22977 .64183 Mdot
.16774 .90394 Mdot
.26216 .73757 Mdot
.07831 .84939 Mdot
.33971 .10926 Mdot
.89814 .63301 Mdot
.21722 .83095 Mdot
.33563 .05617 Mdot
.1668 .86064 Mdot
.79579 .09661 Mdot
.08627 .78446 Mdot
.27695 .87035 Mdot
.24851 .84108 Mdot
.25448 .64643 Mdot
.30676 .85043 Mdot
.2775 .89722 Mdot
.27095 .92732 Mdot
.27016 .89205 Mdot
.41744 .98188 Mdot
.2832 .98472 Mdot
.31449 .66658 Mdot
.24955 .91337 Mdot
.67865 .93564 Mdot
.30391 .8933 Mdot
.27814 .54604 Mdot
.20075 .73728 Mdot
.33764 .8919 Mdot
.30802 .80115 Mdot
.25826 .03192 Mdot
.13302 .83487 Mdot
.19866 .84643 Mdot
.23442 .96826 Mdot
.40783 .86432 Mdot
.11657 .77715 Mdot
.24639 .86829 Mdot
.37667 .94208 Mdot
.20961 .87409 Mdot
.46449 .39578 Mdot
.43378 .92837 Mdot
.15436 .09227 Mdot
.22901 .27988 Mdot
.50536 .92193 Mdot
.29458 .89298 Mdot
.06597 .34903 Mdot
.9165 .07207 Mdot
.25939 .90585 Mdot
.27023 .55914 Mdot
.37766 .85006 Mdot
.16746 .8688 Mdot
.95551 .44253 Mdot
.314 .05219 Mdot
.36652 .89586 Mdot
.30381 .65052 Mdot
.19467 .76971 Mdot
.22131 .90362 Mdot
.12832 .80545 Mdot
.15617 .83295 Mdot
.37995 .00084 Mdot
.1718 .11302 Mdot
.1115 .11217 Mdot
.18761 .85979 Mdot
.42756 .95466 Mdot
.25683 .80234 Mdot
.12006 .84047 Mdot
.41607 .07365 Mdot
.31392 .80758 Mdot
.45141 .80578 Mdot
.16887 .85506 Mdot
.20132 .75808 Mdot
.29953 .89558 Mdot
.25631 .02485 Mdot
.14104 .17759 Mdot
.13099 .5522 Mdot
.34933 .15785 Mdot
.22669 .82007 Mdot
.07897 .62459 Mdot
.26929 .87331 Mdot
.12842 .82827 Mdot
.31416 .85662 Mdot
.87718 .88371 Mdot
.04998 .50351 Mdot
.58256 .10817 Mdot
.26851 .99874 Mdot
.66388 .27292 Mdot
.29797 .83848 Mdot
.24007 .85615 Mdot
.36125 .9615 Mdot
.09528 .47393 Mdot
.36775 .19799 Mdot
.31117 .60379 Mdot
.99594 .88823 Mdot
.03116 .9827 Mdot
.86698 .23594 Mdot
.28997 .88797 Mdot
.04663 .7958 Mdot
.35901 .87754 Mdot
.14989 .8284 Mdot
.2253 .85444 Mdot
.18531 .9038 Mdot
.20248 .90477 Mdot
.18413 .02462 Mdot
.11985 .04961 Mdot
.80494 .75549 Mdot
.27899 .86533 Mdot
.15676 .84885 Mdot
.01692 .79269 Mdot
.50113 .10227 Mdot
.50316 .4155 Mdot
.2633 .89391 Mdot
.13821 .62991 Mdot
.12744 .23913 Mdot
.19817 .69212 Mdot
.08629 .79718 Mdot
.20624 .89742 Mdot
.24066 .74544 Mdot
.06108 .63485 Mdot
.30807 .92305 Mdot
.09695 .63579 Mdot
.47726 .87349 Mdot
.77279 .03744 Mdot
.16105 .76417 Mdot
.38352 .87968 Mdot
.14715 .66438 Mdot
.31318 .14177 Mdot
.24946 .84583 Mdot
.28043 .91169 Mdot
.72079 .39977 Mdot
.82452 .67533 Mdot
.14748 .808 Mdot
.18004 .87038 Mdot
.07425 .84303 Mdot
.56064 .6122 Mdot
.33522 .86642 Mdot
.13294 .80854 Mdot
.89277 .83313 Mdot
.03535 .0029 Mdot
.70306 .18031 Mdot
.54035 .56282 Mdot
.37448 .93827 Mdot
.12667 .00325 Mdot
.47628 .96511 Mdot
.2882 .60786 Mdot
.16382 .15423 Mdot
.32683 .76013 Mdot
.56816 .07382 Mdot
.34235 .86149 Mdot
.77487 .26879 Mdot
.61053 .26848 Mdot
.18871 .86139 Mdot
.23282 .99309 Mdot
.22311 .8554 Mdot
.32666 .91699 Mdot
.1971 .82897 Mdot
.92871 .60118 Mdot
.1887 .91254 Mdot
.07713 .61917 Mdot
.10126 .82609 Mdot
.2862 .9283 Mdot
.24363 .86582 Mdot
.38681 .72168 Mdot
.27682 .88432 Mdot
.3336 .93205 Mdot
.23238 .9496 Mdot
.95279 .83232 Mdot
.34387 .34082 Mdot
.23522 .95762 Mdot
.25166 .90916 Mdot
.23454 .86734 Mdot
.1289 .89177 Mdot
.0683 .86077 Mdot
.35011 .12099 Mdot
.3505 .89345 Mdot
.58831 .16657 Mdot
.18889 .83617 Mdot
.35213 .04536 Mdot
.24371 .81643 Mdot
.25255 .91768 Mdot
.24374 .89534 Mdot
.24267 .89255 Mdot
.10869 .90744 Mdot
.22346 .84916 Mdot
.096 .83547 Mdot
.19966 .87063 Mdot
.98377 .46536 Mdot
.04916 .87176 Mdot
.35427 .77085 Mdot
.001 .02346 Mdot
.32491 .809 Mdot
.33988 .85813 Mdot
.40027 .92912 Mdot
.62022 .8166 Mdot
.23884 .90845 Mdot
.26398 .73046 Mdot
.48614 .99601 Mdot
.21585 .68447 Mdot
.13404 .81954 Mdot
.27667 .90622 Mdot
.35477 .39746 Mdot
.07441 .02491 Mdot
.36481 .96389 Mdot
.11627 .99909 Mdot
.3045 .80334 Mdot
.2676 .95904 Mdot
.76658 .74354 Mdot
.24507 .9272 Mdot
.27795 .8275 Mdot
.37667 .78878 Mdot
.40144 .09584 Mdot
.13346 .64671 Mdot
.14066 .76817 Mdot
.50947 .76771 Mdot
.26371 .9111 Mdot
.62656 .71513 Mdot
.32662 .9318 Mdot
.28662 .85465 Mdot
.25621 .83576 Mdot
.03395 .02976 Mdot
.20791 .252 Mdot
.16634 .67633 Mdot
.20752 .89965 Mdot
.88641 .79017 Mdot
.24806 .65691 Mdot
.22585 .12968 Mdot
.36189 .2594 Mdot
.16916 .84319 Mdot
.2676 .82128 Mdot
.1076 .9035 Mdot
.24426 .85428 Mdot
.2235 .93827 Mdot
.07905 .57574 Mdot
.58441 .74786 Mdot
.26494 .94093 Mdot
.121 .27644 Mdot
.35033 .97757 Mdot
.01359 .96029 Mdot
.75121 .42958 Mdot
.88165 .06782 Mdot
.19886 .87872 Mdot
.12378 .77122 Mdot
.23634 .88215 Mdot
.28448 .8511 Mdot
.19773 .9442 Mdot
.36573 .89887 Mdot
.43988 .70687 Mdot
.49701 .96962 Mdot
.25731 .88257 Mdot
.14252 .0221 Mdot
.13019 .93015 Mdot
.22922 .84212 Mdot
.19367 .886 Mdot
.07846 .63788 Mdot
.91962 .54836 Mdot
.24432 .92039 Mdot
.22629 .72957 Mdot
.20019 .8454 Mdot
.50263 .83277 Mdot
.57367 .90294 Mdot
.37481 .88005 Mdot
.02263 .64642 Mdot
.26543 .95017 Mdot
.57632 .53802 Mdot
.26266 .71137 Mdot
.2987 .89845 Mdot
.27748 .99212 Mdot
.68642 .11912 Mdot
.23262 .72209 Mdot
.20828 .92123 Mdot
.60931 .75534 Mdot
.22706 .51961 Mdot
.17981 .75385 Mdot
.24481 .98641 Mdot
.13353 .59934 Mdot
.30348 .92354 Mdot
.59181 .18223 Mdot
.19825 .85282 Mdot
.42121 .96218 Mdot
.14254 .71727 Mdot
.21896 .85446 Mdot
.418 .84054 Mdot
.13274 .83309 Mdot
.35829 .85217 Mdot
.2444 .19595 Mdot
.1327 .90034 Mdot
.12417 .77443 Mdot
.11469 .94122 Mdot
.68125 .50244 Mdot
.70253 .7813 Mdot
.13249 .86543 Mdot
.31431 .87516 Mdot
.90564 .72508 Mdot
.26497 .99361 Mdot
.33852 .81631 Mdot
.44475 .35612 Mdot
.10625 .72077 Mdot
.4597 .9175 Mdot
.18711 .8668 Mdot
.11057 .84359 Mdot
.18064 .87977 Mdot
.28521 .94326 Mdot
.18281 .91512 Mdot
.27634 .88578 Mdot
.2944 .6534 Mdot
.21352 .8518 Mdot
.26145 .00321 Mdot
.24864 .0428 Mdot
.35952 .83779 Mdot
.26863 .88889 Mdot
.12495 .81644 Mdot
.33834 .1204 Mdot
.42179 .04292 Mdot
.24758 .75499 Mdot
.28469 .90395 Mdot
.29494 .80661 Mdot
.12865 .75625 Mdot
.39599 .92021 Mdot
.5067 .02945 Mdot
.26472 .22025 Mdot
.18665 .82623 Mdot
.08079 .97409 Mdot
.39279 .93006 Mdot
.13655 .22087 Mdot
.10741 .75397 Mdot
.24724 .84527 Mdot
.20904 .82093 Mdot
.63711 .65696 Mdot
.44659 .55058 Mdot
.34754 .03827 Mdot
.39797 .92787 Mdot
.10271 .95508 Mdot
.46529 .09973 Mdot
.32231 .88237 Mdot
.97776 .37147 Mdot
.55047 .74533 Mdot
.09928 .76642 Mdot
.32746 .89778 Mdot
.1472 .89235 Mdot
.25808 .88802 Mdot
.45599 .93751 Mdot
.64962 .78322 Mdot
.21734 .85806 Mdot
.80762 .27586 Mdot
.23548 .88859 Mdot
.11312 .83331 Mdot
.18157 .86772 Mdot
.19296 .83358 Mdot
.01136 .86888 Mdot
.20566 .86551 Mdot
.43166 .96478 Mdot
.44896 .83245 Mdot
.36618 .7219 Mdot
.32241 .8633 Mdot
.05885 .84011 Mdot
.96906 .61455 Mdot
.24724 .87744 Mdot
.26837 .80805 Mdot
.0121 .92344 Mdot
.1768 .9806 Mdot
.41032 .0019 Mdot
.24358 .88172 Mdot
.85918 .53345 Mdot
.29419 .94495 Mdot
.13696 .87279 Mdot
.92437 .84021 Mdot
.05375 .87331 Mdot
.27829 .87268 Mdot
.60083 .0906 Mdot
.17698 .75926 Mdot
.19463 .87155 Mdot
.29615 .94899 Mdot
.7324 .79381 Mdot
.14625 .16684 Mdot
.25006 .84232 Mdot
.39833 .79448 Mdot
.08804 .49612 Mdot
.33672 .13778 Mdot
.93876 .68879 Mdot
.43506 .23608 Mdot
.07937 .97091 Mdot
.31345 .88819 Mdot
.9272 .67228 Mdot
.27795 .89532 Mdot
.38451 .03598 Mdot
.14571 .81838 Mdot
.34855 .94446 Mdot
.45906 .01972 Mdot
.31117 .843 Mdot
.21045 .7069 Mdot
.51078 .4503 Mdot
.39758 .94242 Mdot
.19998 .85396 Mdot
.40763 .96958 Mdot
.19912 .82685 Mdot
.81831 .1874 Mdot
.2218 .83699 Mdot
.10152 .82546 Mdot
.19046 .97212 Mdot
.55554 .09163 Mdot
.32345 .15603 Mdot
.44031 .8193 Mdot
.35502 .85774 Mdot
.18362 .7669 Mdot
.2377 .87055 Mdot
.82021 .91825 Mdot
.69058 .65697 Mdot
.51312 .61952 Mdot
.24572 .03755 Mdot
.20426 .16745 Mdot
.15428 .81669 Mdot
.24685 .88399 Mdot
.12367 .71227 Mdot
.23981 .92109 Mdot
.4869 .50012 Mdot
.1005 .86781 Mdot
.22054 .32458 Mdot
.3618 .89133 Mdot
.70991 .89252 Mdot
.12254 .85491 Mdot
.46843 .12604 Mdot
.71736 .66662 Mdot
.11572 .75152 Mdot
.83123 .52797 Mdot
.31518 .80877 Mdot
.20057 .91364 Mdot
.26196 .47223 Mdot
.30855 .81934 Mdot
.40687 .85765 Mdot
.7203 .90974 Mdot
.25369 .79419 Mdot
.39406 .74976 Mdot
.20725 .09846 Mdot
.90925 .90602 Mdot
.72679 .85738 Mdot
.30023 .92616 Mdot
.60174 .78748 Mdot
.93142 .57774 Mdot
.25397 .92216 Mdot
.29079 .8563 Mdot
.14838 .8167 Mdot
.29151 .89156 Mdot
.00029 .03141 Mdot
.1103 .2481 Mdot
.82317 .48272 Mdot
.19384 .87365 Mdot
.06887 .79588 Mdot
.183 .22424 Mdot
.27749 .87859 Mdot
.33075 .94595 Mdot
.44513 .94578 Mdot
.87445 .55464 Mdot
.10554 .82228 Mdot
.03539 .8499 Mdot
.30018 .84828 Mdot
.49802 .77357 Mdot
.17065 .90702 Mdot
.53776 .57985 Mdot
.10746 .79775 Mdot
.14233 .85715 Mdot
.10772 .93475 Mdot
.42012 .84862 Mdot
.2581 .80765 Mdot
.25271 .87758 Mdot
.1898 .75905 Mdot
.41651 .04319 Mdot
.09869 .84467 Mdot
.13524 .82711 Mdot
.64774 .83385 Mdot
.23524 .90117 Mdot
.40835 .3718 Mdot
.13589 .86426 Mdot
.25964 .77061 Mdot
.22271 .91175 Mdot
.07117 .51308 Mdot
.56776 .25155 Mdot
.11558 .99596 Mdot
.50678 .14622 Mdot
.32387 .96635 Mdot
.41194 .90999 Mdot
.20705 .72751 Mdot
.13184 .78249 Mdot
.48217 .82512 Mdot
.26617 .8621 Mdot
.12309 .81955 Mdot
.13071 .81886 Mdot
.37123 .70518 Mdot
.4901 .2498 Mdot
.29029 .95661 Mdot
.32184 .97051 Mdot
.93655 .07391 Mdot
.11512 .27789 Mdot
.20913 .94111 Mdot
.23255 .59991 Mdot
.13526 .10422 Mdot
.261 .88507 Mdot
.27365 .90265 Mdot
.16817 .83121 Mdot
.29837 .71949 Mdot
.33979 .15967 Mdot
.17489 .5355 Mdot
.22304 .90386 Mdot
.41552 .84543 Mdot
.13798 .86715 Mdot
.19732 .70492 Mdot
.63027 .83289 Mdot
.31111 .99416 Mdot
.1957 .89963 Mdot
.33989 .17565 Mdot
.28409 .81329 Mdot
.12868 .86401 Mdot
.21975 .12366 Mdot
.20699 .93498 Mdot
.14363 .77846 Mdot
.33474 .00573 Mdot
.32687 .11662 Mdot
.26167 .63863 Mdot
.34787 .9377 Mdot
.05921 .5141 Mdot
.28532 .00783 Mdot
.10886 .89567 Mdot
.14959 .15362 Mdot
.32994 .87315 Mdot
.26054 .8719 Mdot
.53365 .39943 Mdot
.36838 .87649 Mdot
.20912 .83162 Mdot
.95875 .6351 Mdot
.23492 .88708 Mdot
.21703 .86234 Mdot
.14677 .8302 Mdot
.16136 .82837 Mdot
.2383 .92218 Mdot
.11407 .5965 Mdot
.18958 .87976 Mdot
.23431 .86242 Mdot
.74048 .52401 Mdot
.21895 .0269 Mdot
.34002 .98735 Mdot
.05085 .63926 Mdot
.11285 .83273 Mdot
.11405 .60587 Mdot
.35797 .91564 Mdot
.23645 .72441 Mdot
.02269 .00216 Mdot
.26656 .99833 Mdot
.30759 .88437 Mdot
.7397 .67606 Mdot
.34489 .12373 Mdot
.21356 .85499 Mdot
.27642 .86689 Mdot
.3083 .88576 Mdot
.46028 .83135 Mdot
.37408 .85919 Mdot
.38682 .02018 Mdot
.12888 .80754 Mdot
.27822 .88967 Mdot
.14821 .85977 Mdot
.61011 .72268 Mdot
.10616 .85917 Mdot
.19707 .86553 Mdot
.44402 .9286 Mdot
.28154 .93028 Mdot
.54285 .91479 Mdot
.23448 .89452 Mdot
.29979 .45109 Mdot
.08364 .87148 Mdot
.14304 .86664 Mdot
.23571 .87106 Mdot
.2284 .9313 Mdot
.36584 .88002 Mdot
.86576 .57942 Mdot
.26281 .88928 Mdot
.13821 .96926 Mdot
.39776 .94969 Mdot
.2772 .61457 Mdot
.81492 .70616 Mdot
.18123 .85155 Mdot
.53656 .77824 Mdot
.27669 .89843 Mdot
.34459 .95377 Mdot
.27263 .98113 Mdot
.38925 .01655 Mdot
.22575 .9214 Mdot
.59106 .99406 Mdot
.20304 .02685 Mdot
.48944 .16064 Mdot
.29885 .85246 Mdot
.97329 .88692 Mdot
.21604 .86563 Mdot
.24407 .89963 Mdot
.12757 .91337 Mdot
.10883 .93241 Mdot
.40261 .93667 Mdot
.40464 .86728 Mdot
.75116 .25921 Mdot
.30604 .80899 Mdot
.91415 .95335 Mdot
.93524 .52189 Mdot
.50785 .98392 Mdot
.06784 .79388 Mdot
.31514 .80669 Mdot
.29484 .38571 Mdot
.19939 .90834 Mdot
.51093 .6874 Mdot
.18561 .83197 Mdot
.41912 .94506 Mdot
.18169 .81501 Mdot
.27852 .84637 Mdot
.35665 .84905 Mdot
.36317 .22131 Mdot
.34173 .76865 Mdot
.29632 .82369 Mdot
.43284 .05921 Mdot
.16612 .28107 Mdot
.26976 .78857 Mdot
.30764 .91624 Mdot
.37134 .84231 Mdot
.2173 .80523 Mdot
.88922 .10826 Mdot
.0763 .61211 Mdot
.37717 .89328 Mdot
.08172 .96227 Mdot
.21795 .11715 Mdot
.42407 .83582 Mdot
.35309 .978 Mdot
.25282 .15757 Mdot
.32164 .87965 Mdot
.79338 .70548 Mdot
.31339 .13137 Mdot
.35375 .85688 Mdot
.24851 .87819 Mdot
.20061 .83759 Mdot
.47278 .76556 Mdot
.22644 .85869 Mdot
.36119 .69998 Mdot
.83075 .10463 Mdot
.13474 .90554 Mdot
.08827 .03061 Mdot
.16655 .73777 Mdot
.19352 .85973 Mdot
.33071 .8186 Mdot
.68531 .08528 Mdot
.37575 .89749 Mdot
.55752 .31173 Mdot
.29529 .84115 Mdot
.25371 .84363 Mdot
.25856 .59816 Mdot
.16006 .84279 Mdot
.23279 .89958 Mdot
.3298 .95586 Mdot
.01392 .59969 Mdot
.02754 .87914 Mdot
.21496 .87209 Mdot
.2024 .90655 Mdot
.39196 .98298 Mdot
.25966 .88677 Mdot
.60529 .96263 Mdot
.18018 .82934 Mdot
.01667 .84812 Mdot
.19687 .95643 Mdot
.10251 .21747 Mdot
.16925 .09028 Mdot
.11961 .81899 Mdot
.03217 .96675 Mdot
.80794 .74071 Mdot
.88453 .90879 Mdot
.91848 .73674 Mdot
.29452 .80841 Mdot
.24941 .87099 Mdot
.20513 .83145 Mdot
.05815 .86515 Mdot
.21849 .85424 Mdot
.68033 .55508 Mdot
.09662 .66708 Mdot
.16548 .60516 Mdot
.93191 .02912 Mdot
.35497 .28455 Mdot
.19364 .55531 Mdot
.92077 .47032 Mdot
.03638 .02076 Mdot
.01881 .51301 Mdot
.59731 .74064 Mdot
.26625 .90928 Mdot
.25767 .74278 Mdot
.99289 .9124 Mdot
.26762 .85773 Mdot
.28067 .87896 Mdot
.17588 .89885 Mdot
.43885 .9839 Mdot
.08621 .70996 Mdot
.16345 .9966 Mdot
.30487 .85774 Mdot
.11206 .85869 Mdot
.30521 .79872 Mdot
.32956 .1335 Mdot
.28822 .09108 Mdot
.28798 .87109 Mdot
.94448 .59744 Mdot
.29237 .96529 Mdot
.3061 .72318 Mdot
.72637 .23397 Mdot
.27611 .86939 Mdot
.29984 .93333 Mdot
.21071 .84468 Mdot
.26099 .62388 Mdot
.23734 .61706 Mdot
.18748 .93929 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00?o
oooo0_l00002ooooo`;o00001?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Go
oooo0_l00006ooooo`03o`000?oooooooooo00Kooooo0_l00006ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool00_l0000;ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool01_ooool2o`0000Kooooo00Co0000ooooool0003o00003?ooool00ol0003oooooooooo`0=oooo
o`04o`000?ooooooooooooooo`;o00002_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0
003oooooooooo`03ooooo`;o00000_ooool2o`0000Cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool00_l0000;ooooo`04o`000?oooooo0000o`0000Oooooo0_l00003
ooooo`03o`000?oooooooooo00kooooo00Co0000ooooool0003o00003?ooool00ol0003ooooooooo
o`0=ooooo`04o`000?ooooooooooooooo`;o00002_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool01oooool2o`0000Cooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
0_ooool001kooooo00?o0000ooooooooool03Oooool2o`0004[ooooo0_l000000ooooooo0000o`00
0002ooooo`;o00001oooool2o`000:3ooooo0_l0000jooooo`007_ooool00ol0003oooooooooo`0=
ooooo`;o0000:oooool2o`0001gooooo0_l000000ooooooo0000o`00003Yooooo`007_ooool00ol0
003oooooooooo`0jooooo`?o0000?Oooool2o`000<_ooooo000Nooooo`03o`000?oooooooooo03_o
oooo0_l0000mooooo`;o00005Oooool2o`000;Cooooo000Nooooo`03o`000?oooooooooo00Sooooo
0_l0000Pooooo`;o0000C_ooool2o`0001Gooooo0_l0000Cooooo`;o0000Woooool001gooooo0_l0
000:ooooo`;o00002_ooool2o`0001Cooooo0_l0000<ooooo`;o00005Oooool2o`0002Wooooo0_l0
000Zooooo`;o0000Woooool001gooooo0_l0000Fooooo`;o00008_ooool2o`0000Cooooo0_l00003
ooooo`;o00002_ooool2o`000=[ooooo0_l0000Jooooo`007Oooool2o`0000Wooooo0_l0000@oooo
o`;o00008oooool2o`0000?ooooo0_l0000;ooooo`;o0000Coooool2o`0008Sooooo0_l0000Joooo
o`007Oooool2o`0000Wooooo0_l0000@ooooo`;o00009Oooool2o`0000Sooooo0_l00004ooooo`;o
0000Coooool2o`0006kooooo0_l0000dooooo`007_ooool00ol0003oooooooooo`10ooooo`;o0000
2?ooool4o`0001oooooo0_l0000:ooooo`;o0000O?ooool2o`0001Sooooo0_l0000dooooo`007_oo
ool00ol0003oooooooooo`1<ooooo`;o00007oooool2o`0000[ooooo0_l0001looooo`;o0000C_oo
ool001kooooo00?o0000ooooooooool07_ooool2o`0002gooooo0_l0000dooooo`Co0000`?ooool0
01kooooo00?o0000ooooooooool07_ooool2o`0002gooooo0_l0000Oooooo`;o00004oooool4o`00
04?ooooo0_l0001kooooo`007_ooool00ol0003oooooooooo`05ooooo`;o00007?ooool2o`0004Wo
oooo0_l0001Jooooo`;o0000Noooool001kooooo0_l00006ooooo`;o00007?ooool2o`0003gooooo
0_l0003Sooooo`007_ooool00ol0003oooooooooo`1Hooooo`;o00002?ooool2o`0000Cooooo0ol0
002>ooooo`;o0000C?ooool001kooooo00?o0000ooooooooool0F?ooool2o`0000gooooo1?l0000N
ooooo`;o0000K_ooool2o`0004cooooo000Nooooo`03o`000?oooooooooo06Oooooo0_l000000ooo
oooo0000o`00000Aooooo`;o00002_ooool2o`000;cooooo000Nooooo`03o`000?oooooooooo03Go
oooo0_l0000cooooo`;o00004Oooool2o`0000Sooooo0_l0002nooooo`007_ooool00ol0003ooooo
ooooo`0eooooo`;o0000D?ooool2o`0009;ooooo0_l0000Zooooo`007_ooool00ol0003ooooooooo
o`0[ooooo`;o0000JOooool2o`0008?ooooo0_l00009ooooo`;o00007oooool001kooooo00?o0000
ooooooooool0:oooool2o`0005Kooooo0_l0000Aooooo`;o00007Oooool2o`0006oooooo0_l00004
ooooo`;o00006Oooool001kooooo00?o0000ooooooooool0Poooool2o`00033ooooo0_l0001eoooo
o`;o00006Oooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0=_ooooo0_l0001Zooooo`007_ooool0
0ol0003oooooooooo`0cooooo`;o00004_ooool2o`0007Kooooo0_l0000Jooooo`;o0000J_ooool0
01kooooo00?o0000ooooooooool0;_ooool2o`0000?ooooo0_l0000Booooo`;o00004Oooool2o`00
05Cooooo0_l00006ooooo`;o00001Oooool2o`0008Kooooo000Nooooo`03o`000?oooooooooo02ko
oooo0_l0000Zooooo`;o00008_ooool2o`00033ooooo0_l00006ooooo`;o0000AOooool2o`0004Ko
oooo000Nooooo`03o`000?oooooooooo03oooooo0_l0000mooooo`;o00004oooool2o`0006[ooooo
0_l00016ooooo`007_ooool2o`00043ooooo0_l0001Booooo`;o00002_ooool2o`000:Kooooo000N
ooooo`03o`000?oooooooooo02Sooooo0_l0000booooo`;o00004Oooool2o`0000Cooooo0_l0000X
ooooo`;o0000JOooool2o`0003_ooooo000Nooooo`03o`000?oooooooooo02Sooooo0_l0000Koooo
o`;o00005Oooool2o`00017ooooo0_l00004ooooo`;o0000@_ooool2o`0004oooooo0_l0000Aoooo
o`;o0000:?ooool001kooooo00?o0000ooooooooool0AOooool2o`0002?ooooo0_l0001=ooooo`;o
0000H_ooool2o`0002Sooooo000Nooooo`03o`000?oooooooooo00cooooo0_l00005ooooo`;o0000
2oooool2o`0001;ooooo0_l0000dooooo`;o0000foooool001kooooo00?o0000ooooooooool03?oo
ool2o`0000Gooooo0_l0000;ooooo`;o00004_ooool2o`0000gooooo0_l00004ooooo`;o00006ooo
ool4o`000=gooooo000Nooooo`03o`000?oooooooooo04?ooooo0_l00004ooooo`;o00006oooool6
o`0000;ooooo0_l0001[ooooo`;o0000J_ooool001kooooo00?o0000ooooooooool0@oooool2o`00
02Gooooo1_l0001[ooooo`;o0000J_ooool001kooooo00?o0000ooooooooool0@oooool2o`0002Oo
oooo0_l0000Vooooo`;o0000/Oooool001kooooo00?o0000ooooooooool0AOooool2o`0004gooooo
0_l0002aooooo`007_ooool00ol0003oooooooooo`15ooooo`;o00006oooool2o`0000?ooooo0_l0
003Nooooo`007_ooool00ol0003oooooooooo`1Rooooo`;o00000oooool2o`0006cooooo0_l00005
ooooo`;o0000JOooool001kooooo00?o0000ooooooooool0JOooool2o`0006[ooooo0_l00005oooo
o`;o0000JOooool001kooooo00?o0000ooooooooool0H_ooool2o`0000Gooooo0_l0003Looooo`00
7_ooool00ol0003oooooooooo`0^ooooo`;o0000<_ooool2o`000>?ooooo000Nooooo`03o`000?oo
oooooooo02kooooo0_l0001aooooo`;o0000Y?ooool001kooooo0_l0002Rooooo`;o0000Y?ooool0
01kooooo00?o0000ooooooooool0;Oooool2o`0000;ooooo0_l0003ooooooaGooooo000Nooooo`03
o`000?oooooooooo02gooooo0_l00002ooooo`;o00006oooool2o`0001Gooooo0_l00006ooooo`;o
0000f?ooool001kooooo00?o0000ooooooooool0C_ooool2o`0001Gooooo0_l00003ooooo`;o0000
00?oooooo`000?l00000;?ooool2o`000:[ooooo000Nooooo`03o`000?oooooooooo06[ooooo0_l0
000_ooooo`;o0000Z_ooool001kooooo00?o0000ooooooooool0:oooool2o`00017ooooo0_l0001k
ooooo`;o0000R_ooool001kooooo00?o0000ooooooooool0:oooool2o`00017ooooo0_l0001koooo
o`;o0000R_ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`1Zooooo`;o0000foooool001kooooo00?o0000ooooooooool0:_ooool2o`0003kooooo0_l0
003Kooooo`007_ooool00ol0003oooooooooo`0Zooooo`;o0000T?ooool2o`0002;ooooo0_l0001U
ooooo`007_ooool00ol0003oooooooooo`2looooo`;o00008_ooool2o`0006Gooooo000Nooooo`03
o`000?oooooooooo0?oooooo1oooool2o`0003oooooo000Nooooo`03o`000?oooooooooo0?oooooo
1oooool2o`0003oooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol00006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000oooooooo
ool0Boooool2o`0001Cooooo0_l0000@ooooo`;o0000d_ooool000?ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0001;ooooo`;o00005?ooool2o`00013o
oooo0_l0003Booooo`000oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^
k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`000?ooooooooooooooool0
00003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo
00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oo
ooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2J
ooooo`;o0000Zoooool001kooooo00?o0000ooooooooool07Oooool2o`0007_ooooo0_l0002[oooo
o`007_ooool00ol0003oooooooooo`0@ooooo`;o00002oooool2o`0000Wooooo0_l0000Xooooo`;o
00007_ooool2o`000=?ooooo000Nooooo`03o`000?oooooooooo013ooooo0_l0000Fooooo`;o0000
3Oooool2o`0001Wooooo0_l0000Nooooo`;o0000doooool001kooooo00?o0000ooooooooool0=ooo
ool2o`0001Kooooo0_l0003fooooo`007_ooool00ol0003oooooooooo`1?ooooo`;o0000m_ooool0
01kooooo00?o0000ooooooooool06Oooool2o`000<gooooo0_l0001Mooooo`007_ooool00ol0003o
ooooooooo`0Iooooo`;o0000K_ooool2o`0005gooooo0_l0000/ooooo`;o0000;oooool001kooooo
00?o0000ooooooooool09Oooool2o`0006;ooooo0_l0002;ooooo`;o0000;oooool001kooooo00?o
0000ooooooooool09Oooool2o`000?oooooo8Oooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o0000NOooool2o`000:[ooooo000Nooooo`;o
00008Oooool2o`0001gooooo0_l0001Jooooo`;o00005oooool2o`00097ooooo000Nooooo`03o`00
0?oooooooooo03oooooo0_l0001cooooo`;o0000TOooool001kooooo00?o0000ooooooooool0L_oo
ool2o`0007cooooo0_l0001Eooooo`007_ooool00ol0003oooooooooo`1booooo`;o0000O?ooool2
o`0005Gooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool05oooool2o`000:Wooooo0_l0000dooooo`;o0000COooool001kooooo00?o0000ooooooooool0
5oooool2o`000:Wooooo0_l0000dooooo`;o0000COooool001kooooo00?o0000ooooooooool0e?oo
ool2o`00077ooooo000Nooooo`03o`000?oooooooooo027ooooo1?l0002_ooooo`;o0000;?ooool2
o`0004?ooooo000Nooooo`03o`000?oooooooooo027ooooo1?l0000=ooooo`;o00004_ooool2o`00
0;[ooooo0_l00013ooooo`007_ooool00ol0003oooooooooo`0booooo`;o00004_ooool2o`000?oo
oooo000Nooooo`03o`000?oooooooooo06oooooo0_l0003Fooooo`007_ooool00ol0003ooooooooo
o`1_ooooo`;o0000e_ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`0?ooooo`;o0000oooooolgooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o
0000oooooolgooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0;7ooooo0_l0002<ooooo`;o00001_ooool001kooooo00?o0000ooooooooool04oooool2o`0009co
oooo0_l0002<ooooo`;o00001_ooool001kooooo00?o0000ooooooooool04oooool2o`000?oooooo
4Oooool2o`00023ooooo000Nooooo`03o`000?oooooooooo0?oooooo9_ooool2o`00023ooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0A?ooool2o`00
0?oooooo0_ooool001kooooo00?o0000ooooooooool0A?ooool2o`000?oooooo0_ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0K?ooool2o`00
0=Wooooo000Nooooo`03o`000?oooooooooo06cooooo0_l0003Iooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`;o00004_ooool2o`000?oooooo=Oooool001kooooo00?o0000
ooooooooool04Oooool2o`000?oooooo=Oooool001kooooo00?o0000ooooooooool0S?ooool2o`00
0;Wooooo000Nooooo`03o`000?oooooooooo02Kooooo0_l0001Tooooo`;o0000^Oooool001kooooo
00?o0000ooooooooool09_ooool2o`000?oooooo8?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`2Jooooo`;o0000Zoooool001kooooo00?o0000oooo
ooooool0POooool2o`0001Oooooo0_l0002Nooooo`;o00002oooool001kooooo00?o0000oooooooo
ool0POooool2o`000;Oooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`34ooooo`;o0000
POooool001kooooo00?o0000ooooooooool0a?ooool2o`00087ooooo000Nooooo`03o`000?oooooo
oooo05cooooo0_l0003Yooooo`007_ooool00ol0003oooooooooo`1Looooo`;o0000jOooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`2`ooooo`;o
0000UOooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo06oooooo0_l0000Rooooo`;o00006oooool2o`0009Go
oooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol0001_ooooo`;o
00008_ooool2o`0001Cooooo0_l0000kooooo`;o0000Goooool000?ooooo00Go0000oooooooooooo
ooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0ZOooool2o`00
03_ooooo0_l0001Oooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEE
EOoooooo00001oooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo0?ooooooB?ooool0
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000
ooooooooool0oooooom8ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMg
o`000?ooool01_ooool00ol0003oooooooooo`2Oooooo`;o0000Y_ooool001kooooo00?o0000oooo
ooooool0Woooool2o`000:Kooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0eoooool2o`0006kooooo000Nooooo`03o`000?oooooooooo0<;ooooo0_l0
000Cooooo`;o0000K_ooool001kooooo00?o0000ooooooooool0`_ooool2o`0002cooooo0_l0001E
ooooo`007_ooool00ol0003oooooooooo`3`ooooo`;o0000EOooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?oooooo=?ooool2o`0001;ooooo000Nooooo`03o`000?oooooooooo0?oooooo=?ooool2
o`0001;ooooo000Nooooo`03o`000?oooooooooo0:;ooooo0_l0002Sooooo`007_ooool2o`0005ko
oooo0_l00013ooooo`;o0000Xoooool001kooooo00?o0000ooooooooool0GOooool2o`000>Sooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooolE
ooooo`;o0000<Oooool001kooooo00?o0000ooooooooool0oooooolEooooo`;o00009_ooool2o`00
00Wooooo000Nooooo`03o`000?oooooooooo0?oooooo?Oooool2o`0000Wooooo000Nooooo`03o`00
0?oooooooooo0?oooooo:?ooool2o`0001kooooo000Nooooo`03o`000?oooooooooo01_ooooo0_l0
000dooooo`;o0000e?ooool2o`0001kooooo000Nooooo`03o`000?oooooooooo01_ooooo0_l0000d
ooooo`;o0000B_ooool2o`000:Sooooo000Nooooo`03o`000?oooooooooo09gooooo0_l0002Xoooo
o`007_ooool00ol0003oooooooooo`3oooooo`Wooooo0_l0000mooooo`007_ooool00ol0003ooooo
ooooo`3oooooo`Wooooo0_l0000mooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool06Oooool2o`00
0?oooooo;Oooool001kooooo00?o0000ooooooooool06Oooool2o`000?oooooo;Oooool001kooooo
0_l0002Kooooo`;o0000?Oooool2o`0006cooooo000Nooooo`03o`000?oooooooooo00cooooo0_l0
002<ooooo`;o0000?Oooool2o`0006cooooo000Nooooo`03o`000?oooooooooo00cooooo0_l0003o
oooooc[ooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool00_ooool2o`0000_ooooo0_l00002ooooo`;o0000oooooolcooooo`007_ooool00ol0003ooooo
ooooo`02ooooo`;o00002oooool2o`0000;ooooo0_l00008ooooo`;o0000=oooool2o`000>oooooo
000Nooooo`03o`000?oooooooooo01gooooo0_l0000Wooooo`;o00003_ooool2o`0005gooooo0_l0
002@ooooo`007_ooool00ol0003oooooooooo`16ooooo`;o0000KOooool2o`0003Kooooo0_l0000m
ooooo`;o00003oooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo0>gooooo0_l0000moooo
o`;o00003oooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo05Cooooo0_l0002dooooo`;o
0000>oooool001kooooo00?o0000ooooooooool0E?ooool2o`000;Cooooo0_l00007ooooo`;o0000
<_ooool001kooooo00?o0000ooooooooool0=Oooool2o`000=cooooo0_l0000booooo`007_ooool0
0ol0003oooooooooo`0eooooo`;o0000P?ooool2o`0008kooooo000Nooooo`03o`000?oooooooooo
0;Oooooo0_l0002>ooooo`007_ooool00ol0003oooooooooo`2]ooooo`;o0000V?ooool001kooooo
00?o0000ooooooooool0E_ooool2o`0005Gooooo0_l0001hooooo`;o00007_ooool001kooooo0_l0
001Gooooo`;o0000=Oooool2o`0009Sooooo0_l0000Nooooo`007_ooool00ol0003oooooooooo`0V
ooooo`;o0000IOooool2o`0008Wooooo0_l0000]ooooo`007_ooool00ol0003oooooooooo`0Voooo
o`;o00004oooool2o`0009cooooo0_l0000Tooooo`;o00005oooool2o`0002gooooo000Nooooo`03
o`000?oooooooooo03_ooooo0_l0000Gooooo`;o0000Poooool2o`0002Cooooo0_l00016ooooo`00
7_ooool00ol0003oooooooooo`0iooooo`;o00006Oooool2o`0005Kooooo0_l0002Iooooo`007_oo
ool00ol0003oooooooooo`0iooooo`;o0000LOooool2o`0009Wooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`0Fooooo`;o0000ooooool`ooooo`007_ooool00ol0003oooooooooo`0Fooooo`;o0000
oOooool2o`0001Cooooo0_l0000Jooooo`007_ooool00ol0003oooooooooo`2[ooooo`;o0000J?oo
ool2o`0001Cooooo0_l0000Jooooo`007_ooool00ol0003oooooooooo`2[ooooo`;o0000V_ooool0
01kooooo00?o0000ooooooooool0EOooool2o`000?3ooooo000Nooooo`03o`000?oooooooooo05Go
oooo0_l0003`ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06
ooooo`03o`000?oooooooooo027ooooo0_l0003oooooo`gooooo0_l0000Fooooo`000oooool01Ol@
413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`Go00007ooo
ool2o`0000Cooooo0_l0000Nooooo`;o00001oooool2o`000=Sooooo0_l00003ooooo`;o00005_oo
ool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40
1_ooool00ol0003oooooooooo`02o`0002Gooooo0_l0000Nooooo`;o00001oooool2o`0000kooooo
0ol00037ooooo`;o00006oooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0Cooooo`;o00003?ooool2o`0000oo
oooo0_l0000/ooooo`?o0000i?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03
oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool04oooool2o`0000cooooo0_l0000?ooooo`;o
00009_ooool2o`000>_ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo
410@oiRHV008ooooo`03o`000?oooooooooo01Gooooo0_l0000kooooo`;o00001_ooool2o`0005Ko
oooo0_l0002Cooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0
003o410@1_ooool00ol0003oooooooooo`0Eooooo`;o0000>oooool2o`0000;ooooo0_l0001Joooo
o`;o0000Poooool2o`0000kooooo000Nooooo`03o`000?oooooooooo01Gooooo0_l0000booooo`;o
00002oooool2o`0004_ooooo0_l0002Booooo`;o00003_ooool001kooooo00?o0000ooooooooool0
5Oooool2o`0003;ooooo0_l0001Hooooo`;o0000X_ooool001kooooo00?o0000ooooooooool05_oo
ool2o`0000[ooooo0_l0000]ooooo`;o0000m?ooool001kooooo00?o0000ooooooooool05_ooool2
o`0000[ooooo0_l0000]ooooo`;o0000m?ooool001kooooo00?o0000ooooooooool03Oooool2o`00
01[ooooo0_l0003ooooooagooooo000Nooooo`03o`000?oooooooooo00gooooo0_l000000ooooooo
0000o`00000Gooooo`;o0000mOooool2o`0002Gooooo000Nooooo`03o`000?oooooooooo013ooooo
0_l00003ooooo`;o00001?ooool2o`000?oooooo1?ooool2o`0001;ooooo0_l0000Aooooo`007_oo
ool00ol0003oooooooooo`0<ooooo`;o00001oooool2o`0000Cooooo0_l0000dooooo`;o0000hOoo
ool2o`00017ooooo000Nooooo`03o`000?oooooooooo00cooooo0_l0000=ooooo`;o0000:_ooool2
o`0000Sooooo0_l0003dooooo`007_ooool00ol0003oooooooooo`03ooooo`;o00005_ooool2o`00
00[ooooo0_l0000;ooooo`;o00004Oooool2o`0000Kooooo0_l0000Uooooo`;o0000coooool001ko
oooo00?o0000ooooooooool00oooool2o`0002;ooooo0_l0000;ooooo`;o00006Oooool2o`0002Go
oooo0_l0003?ooooo`007_ooool2o`0001Kooooo0_l00015ooooo`;o000000?oooooo`000?l00000
i_ooool001kooooo00?o0000ooooooooool05Oooool2o`0004Gooooo0_l000000ooooooo0000o`00
0039ooooo`;o00006oooool001kooooo00?o0000ooooooooool0COooool2o`0007cooooo0_l0000?
ooooo`;o0000C?ooool2o`0001_ooooo000Nooooo`03o`000?oooooooooo04gooooo0_l0001loooo
o`;o00003oooool2o`0002Cooooo0_l00013ooooo`007_ooool00ol0003oooooooooo`0/ooooo`;o
00008?ooool2o`000;;ooooo0_l00013ooooo`007_ooool00ol0003oooooooooo`0Kooooo`;o0000
3oooool2o`00023ooooo0_l0000Booooo`;o0000POooool2o`00063ooooo000Nooooo`03o`000?oo
oooooooo01_ooooo0_l00015ooooo`;o0000POooool2o`00063ooooo000Nooooo`03o`000?oooooo
oooo0?oooooo:_ooool2o`0001cooooo000Nooooo`03o`000?oooooooooo02oooooo0_l000000ooo
oooo0000o`00002hooooo`;o00006_ooool2o`0001oooooo0_l0000Looooo`007_ooool00ol0003o
ooooooooo`0_ooooo`;o000000?oooooo`000?l00000POooool2o`0003Gooooo0_l0000Jooooo`;o
0000?Oooool001kooooo00?o0000ooooooooool0]Oooool2o`00093ooooo000Nooooo`03o`000?oo
oooooooo03Wooooo0_l00007ooooo`;o0000ooooool4ooooo`007_ooool00ol0003oooooooooo`0g
ooooo`Co00001oooool2o`0005kooooo0_l00029ooooo`;o00006?ooool001kooooo00?o0000oooo
ooooool00_ooool2o`0003?ooooo0_l00003ooooo`;o0000I?ooool2o`0008Wooooo0_l0000Hoooo
o`007_ooool00ol0003oooooooooo`02ooooo`;o0000>?ooool2o`000?oooooo2_ooool001kooooo
00?o0000ooooooooool0E?ooool2o`000<[ooooo0_l0000Uooooo`007_ooool2o`0004cooooo0_l0
0007ooooo`;o00006oooool2o`000:gooooo0_l0000Uooooo`007_ooool00ol0003oooooooooo`0l
ooooo`;o00003Oooool2o`0002Cooooo0_l00002ooooo`;o0000Boooool2o`0003[ooooo0_l00017
ooooo`007_ooool00ol0003oooooooooo`0looooo`;o00000_ooool2o`0003?ooooo0_l0000Doooo
o`;o0000=Oooool2o`0003[ooooo0_l00005ooooo`;o0000@?ooool001kooooo00?o0000oooooooo
ool06?ooool3o`0002Gooooo0_l0000?ooooo`;o0000>?ooool2o`0007Sooooo0_l00010ooooo`00
7_ooool00ol0003oooooooooo`0Hooooo`?o00002Oooool2o`0001kooooo0_l0000;ooooo`;o0000
V?ooool2o`0005[ooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l00004ooooo`;o00006?oo
ool2o`0001gooooo0_l0001Sooooo`;o00008Oooool2o`0005[ooooo000Nooooo`03o`000?oooooo
oooo01kooooo0_l0000:ooooo`;o00008_ooool2o`0000gooooo0_l00004ooooo`;o0000Hoooool2
o`0007gooooo000Nooooo`03o`000?oooooooooo01kooooo0_l0000Xooooo`;o00001?ooool2o`00
00gooooo1?l0000Booooo`;o00001Oooool2o`0004Kooooo0_l00023ooooo`007_ooool00ol0003o
ooooooooo`18ooooo`?o00005?ooool2o`0001;ooooo0_l00005ooooo`;o0000@?ooool2o`0000Co
oooo0_l0001Nooooo`;o00008oooool001kooooo00?o0000ooooooooool0=_ooool2o`0000Oooooo
0_l00004ooooo`;o00000_ooool2o`00077ooooo0_l0001Tooooo`;o00008oooool001kooooo00?o
0000ooooooooool0<Oooool2o`0000?ooooo0_l00007ooooo`;o00001?ooool2o`0000_ooooo0_l0
003cooooo`007_ooool00ol0003oooooooooo`0aooooo`;o000000?oooooo`000?l000007?ooool2
o`0009gooooo0_l0001Dooooo`007_ooool00ol0003oooooooooo`0Rooooo`;o00003_ooool4o`00
00Oooooo0_l00002ooooo`;o00003_ooool2o`0009kooooo0_l0000cooooo`;o00007oooool001ko
oooo00?o0000ooooooooool08_ooool2o`0000gooooo0ol00009ooooo`;o000000Coooooo`000?l0
003o00003_ooool2o`0006_ooooo0_l00013ooooo`;o00001Oooool2o`0001[ooooo0_l00004oooo
o`;o00006Oooool001kooooo00?o0000ooooooooool0<Oooool2o`0000gooooo0_l00008ooooo`;o
00001?ooool2o`0005gooooo0_l0000=ooooo`;o0000=Oooool2o`0000cooooo0_l00005ooooo`;o
00008?ooool2o`0001Wooooo000Nooooo`03o`000?oooooooooo03_ooooo0_l0000=ooooo`;o0000
1?ooool2o`0005gooooo0_l00009ooooo`;o0000>Oooool2o`00053ooooo000Nooooo`;o00008ooo
ool2o`0000oooooo0_l00006ooooo`;o00003?ooool4o`0002oooooo0_l0000looooo`;o0000Rooo
ool001kooooo00?o0000ooooooooool07oooool2o`000003ooooool0003o000000oooooo0_l00000
0ooooooo0000o`00000Aooooo`Go0000;_ooool2o`000<Wooooo000Nooooo`03o`000?oooooooooo
01oooooo0_l000000ooooooo0000o`000002ooooo`;o00003_ooool2o`0000Gooooo0_l0000=oooo
o`;o0000M?ooool2o`0003kooooo0_l00013ooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o
00001oooool2o`0000?ooooo0_l00008ooooo`;o00000oooool2o`000003ooooool0003o000000go
oooo0_l0000Hooooo`;o0000F_ooool2o`0003kooooo0_l00013ooooo`007_ooool00ol0003ooooo
ooooo`0Mooooo`;o00001?ooool2o`0000Kooooo0_l00003ooooo`;o00000oooool2o`0000?ooooo
0_l0000@ooooo`;o00003Oooool2o`0000Wooooo0_l0002Gooooo`;o0000A_ooool001kooooo00?o
0000ooooooooool07?ooool2o`0000Gooooo0_l0000;ooooo`;o00001_ooool2o`0000;ooooo0_l0
000Mooooo`;o0000>Oooool2o`0001[ooooo0_l0001;ooooo`;o0000A_ooool001kooooo00?o0000
ooooooooool07?ooool2o`0000cooooo0_l0000<ooooo`;o000000Coooooo`000?l0003o0000;Ooo
ool2o`0002Wooooo0_l0000:ooooo`;o00003_ooool2o`0009?ooooo000Nooooo`03o`000?oooooo
oooo02Cooooo0_l00004ooooo`;o00003oooool4o`0000;ooooo0_l0000=ooooo`;o00006Oooool2
o`0000;ooooo0_l0000Aooooo`;o00007_ooool2o`000:?ooooo000Nooooo`03o`000?oooooooooo
00cooooo0_l0000Fooooo`;o00005oooool2o`0000;ooooo0_l0000=ooooo`;o00007Oooool2o`00
017ooooo0_l0000Jooooo`;o0000Yoooool001kooooo00?o0000ooooooooool03?ooool2o`0001Co
oooo1?l00005ooooo`;o0000LOooool2o`0000[ooooo0_l0002Kooooo`007_ooool00ol0003ooooo
ooooo`0Rooooo`;o00000oooool2o`0000;ooooo0_l0001mooooo`;o00005oooool2o`0001_ooooo
0_l0001Uooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o00003Oooool2o`0003;ooooo0_l0
001Vooooo`;o00002_ooool2o`0000oooooo0_l0001Uooooo`007_ooool00ol0003oooooooooo`0H
ooooo`;o0000>_ooool2o`0000Gooooo0_l0000Iooooo`;o0000B?ooool2o`0000gooooo0_l0001f
ooooo`007_ooool00ol0003oooooooooo`1Dooooo`;o00008?ooool2o`0004Sooooo0_l0001Joooo
o`;o0000:Oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<
c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00Co0000oooooooooooooooo0_l0000?ooooo`;o00001_oo
ool2o`0000Oooooo0_l0000Hooooo`;o00003oooool2o`0000;ooooo0_l0000Yooooo`;o0000Jooo
ool2o`00033ooooo0_l0000Yooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool01?l0003oooooooooooooool2o`0000So
oooo0_l00005ooooo`;o00001?ooool4o`0000?ooooo0_l00002ooooo`;o00006?ooool2o`0000oo
oooo0_l00002ooooo`;o0000:Oooool2o`0001;ooooo0_l0001Gooooo`;o0000Foooool000?ooooo
00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`00
00_ooooo0_l00005ooooo`;o00001?ooool2o`0000?ooooo1?l0000nooooo`;o00000oooool2o`00
02_ooooo0_l0002dooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRH
V?ooooooV9RHoc8b<P06ooooo`03o`000?oooooooooo01gooooo0_l00007ooooo`;o00009oooool2
o`0000kooooo0ol00002ooooo`;o0000hOooool000?ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`0Vooooo`;o00006ooo
ool2o`0000[ooooo0_l0000;ooooo`;o000000?oooooo`000?l000000ol0000[ooooo`;o0000]_oo
ool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@4100
1_ooool00ol0003oooooooooo`0Vooooo`?o00000oooool2o`0000[ooooo0ol00008ooooo`;o0000
2oooool2o`000003ooooool0003o000000Oooooo0_l000000ooooooo0000o`000003o`0000;ooooo
0_l0000Wooooo`;o00005Oooool2o`0009oooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool08oooool2o`000004
ooooool0003o0000o`0000?ooooo0_l0000:ooooo`?o00005Oooool2o`000003ooooool0003o0000
00?ooooo0_l00002ooooo`Go000000Coooooo`000?l0003ooooo0ol0000Jooooo`;o00008_ooool2
o`0009oooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00Kooooo00?o0000ooooooooool08oooool4o`00013ooooo0_l0000Booooo`;o00002ooo
ool2o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool2o`0001Kooooo0_l0
0033ooooo`007_ooool00ol0003oooooooooo`0Sooooo`Ko00000_ooool5o`0000Oooooo0_l0000B
ooooo`;o00004oooool3o`0000;ooooo1?l000000ooooooo0000o`00000Oooooo`;o0000>Oooool2
o`0007oooooo000Nooooo`03o`000?oooooooooo01kooooo0_l00003ooooo`Ko00000_ooool5o`00
00kooooo1_l00002ooooo`;o00002oooool2o`0000_ooooo0_l00005ooooo`;o000000?oooooo`00
0?l000007oooool2o`0001Kooooo0_l0000Qooooo`;o0000Ooooool001kooooo00?o0000oooooooo
ool07Oooool3o`000003ooooool0003o000000kooooo0_l0000;ooooo`Ko00000_ooool2o`0000[o
oooo0ol00007ooooo`;o00002Oooool2o`00033ooooo0_l00008ooooo`;o0000X_ooool001kooooo
00?o0000ooooooooool07Oooool2o`0000;ooooo0_l000000ooooooo0000o`000004o`0000?ooooo
0_l000001?oooooo0000o`000?l00006ooooo`;o00000_ooool4o`00017ooooo0_l00002ooooo`;o
00001?ooool3o`0000Sooooo0_l0000`ooooo`;o0000[?ooool001kooooo00?o0000ooooooooool0
7Oooool2o`0000;ooooo0_l000000ooooooo0000o`000004o`0000;ooooo0ol000001?oooooo0000
o`000?ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000001?l000000ooo
oooo0000o`00000Aooooo`;o00001Oooool2o`0001Wooooo0_l0000Hooooo`;o0000/oooool001ko
oooo00?o0000ooooooooool04?ooool2o`0000oooooo0_l00004ooooo`;o00000oooool2o`000003
ooooool0003o000000;ooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000Go
000000?oooooo`000?l000000_l0000`ooooo`?o00005?ooool2o`0000;ooooo0_l0000;ooooo`;o
0000:?ooool2o`0000?ooooo0_l0001>ooooo`;o00001Oooool2o`0000_ooooo0_l0000Cooooo`00
7_ooool00ol0003oooooooooo`0@ooooo`;o00002Oooool2o`0000Cooooo0_l00004ooooo`;o0000
1_ooool2o`0000?ooooo0_l00002ooooo`So00001?ooool3o`0000Sooooo0_l0000Pooooo`;o0000
1?ooool2o`0000gooooo0_l00006ooooo`;o00003oooool2o`0002Sooooo0_l00003ooooo`;o0000
C_ooool2o`0000Gooooo0_l0000;ooooo`;o00004oooool001kooooo00?o0000ooooooooool03ooo
ool2o`0000[ooooo0_l00006ooooo`;o00003oooool2o`0000?ooooo0_l00002ooooo`;o00001Ooo
ool2o`0000Oooooo1?l0000<ooooo`;o00004_ooool2o`00017ooooo1?l00007ooooo`;o0000Uooo
ool2o`0001gooooo000Nooooo`03o`000?oooooooooo00oooooo0_l00003ooooo`;o00002_ooool2
o`000003ooooool0003o000000_ooooo0_l000000ooooooo0000o`00000Aooooo`;o00001Oooool3
o`0000cooooo0ol00002ooooo`;o00004_ooool2o`0000gooooo0_l00009ooooo`;o0000Uoooool2
o`0001gooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l00006ooooo`;o00000_ooool2o`00
00kooooo1Ol00004ooooo`Ko000000?oooooo`000?l000001?ooool2o`0000Cooooo1?l00006oooo
o`;o00001?ooool2o`0000?ooooo0_l0000Booooo`;o00003?ooool2o`000<;ooooo000Nooooo`04
o`000?ooooooooooooooo`;o00001?ooool2o`0000cooooo0_l00005ooooo`Co00002oooool2o`00
00;ooooo1?l00006ooooo`Ko000000?oooooo`000?l000000oooool2o`0000Gooooo0ol00007oooo
o`;o00001Oooool2o`00017ooooo0_l00005ooooo`;o00002_ooool3o`000<7ooooo000Nooooo`;o
00000_ooool2o`0000Cooooo0_l0000<ooooo`;o00001oooool2o`0000_ooooo0_l00002ooooo`;o
00001_ooool3o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000Kooooo0_l00009ooooo`;o
00000oooool2o`000003ooooool0003o000000kooooo0_l00005ooooo`;o00002oooool2o`000<7o
oooo000Nooooo`03o`000?oooooooooo00Gooooo0_l0000Mooooo`;o00003Oooool7o`0000;ooooo
0ol00002ooooo`Ko00000oooool5o`0000Gooooo0_l00002ooooo`Co000000Coooooo`000?l0003o
oooo0_l00009ooooo`;o00000oooool2o`000=Gooooo000Nooooo`03o`000?oooooooooo00Gooooo
0_l0000Gooooo`Co00000_ooool2o`0000Cooooo0_l00007ooooo`Co00001Oooool3o`0000;ooooo
1ol00002ooooo`?o00001Oooool4o`0000;ooooo1?l00003ooooo`;o000000?oooooo`000?l00000
1_ooool3o`0000;ooooo0_l00005ooooo`;o00002?ooool2o`0000Kooooo0_l0001Nooooo`;o0000
GOooool001kooooo00?o0000ooooooooool04_ooool2o`0000[ooooo1?l00008ooooo`Ko00000_oo
ool2o`0000Gooooo1Ol00004ooooo`?o000000?oooooo`000?l000000_l00008ooooo`?o00000ooo
ool2o`0000Gooooo0_l000000ooooooo0000o`000006ooooo`?o00000_ooool2o`0000Gooooo0_l0
0008ooooo`;o00001_ooool2o`0005kooooo0_l0001Mooooo`007_ooool00ol0003oooooooooo`0?
ooooo`;o000000?oooooo`000?l000002oooool2o`0000Gooooo1?l00002ooooo`Co00000_ooool2
o`0000Gooooo1Ol000001?oooooo0000o`000?ooool2o`0000;ooooo1?l00008ooooo`;o00000ooo
ool2o`0000cooooo0_l00004ooooo`;o00002_ooool2o`0000Oooooo0_l00035ooooo`007_ooool0
0ol0003oooooooooo`0?ooooo`;o00003?ooool4o`0000Gooooo1_l00006ooooo`;o00000oooool4
o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000000_ooool4o`000004ooooool0
003o0000o`0000Sooooo0ol0000<ooooo`;o00000_ooool2o`0000?ooooo0_l00007ooooo`;o0000
1_ooool3o`000<Gooooo000Nooooo`03o`000?oooooooooo00;o00002_ooool2o`0000Wooooo0_l0
0004ooooo`;o00002?ooool5o`0000Kooooo0_l00002ooooo`Wo00002Oooool7o`0000Oooooo1_l0
000=ooooo`;o00000oooool2o`0000oooooo0_l00036ooooo`007_ooool00ol0003oooooooooo`02
o`000003ooooool0003o000000Oooooo0ol00008ooooo`;o00003oooool2o`0000cooooo0_l00002
ooooo`Go000000?oooooo`000?l000000_l00005ooooo`;o00000_ooool2o`0000;ooooo1?l00000
0ooooooo0000o`000004o`0000_ooooo0_l0000Dooooo`;o00006?ooool2o`0001[ooooo0_l0001g
ooooo`;o00006Oooool001kooooo00?o0000ooooooooool00oooool2o`0000Sooooo0_l00008oooo
o`;o00003oooool2o`0000cooooo0_l00003ooooo`;o00000oooool4o`0000Gooooo0_l000000ooo
oooo0000o`000002o`000003ooooool0003o000000;o000000Coooooo`000?l0003o00002Oooool2
o`0000?ooooo0_l00008ooooo`;o000000?oooooo`000?l000001oooool2o`0001Sooooo0_l0000J
ooooo`;o0000Moooool2o`0001Wooooo000Nooooo`03o`000?oooooooooo00Gooooo0_l0000_oooo
o`?o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00002Oooool6o`0000Cooooo0ol00009
ooooo`Co00002_ooool8o`000003ooooool0003o00000<cooooo000Nooooo`03o`000?oooooooooo
00Gooooo0_l0000`ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00001_ooool6
o`000004ooooool0003o0000o`0000?ooooo0ol0000;ooooo`?o00002Oooool5o`000004ooooool0
003o0000ooooo`;o0000W_ooool2o`0002cooooo000Nooooo`03o`000?oooooooooo03Sooooo0_l0
00000ooooooo0000o`000004ooooo`;o00001Oooool7o`000004ooooool0003o0000o`0000?ooooo
0_l00008ooooo`;o00000oooool2o`000003ooooool0003o000000Oooooo0_l0000Wooooo`;o0000
Boooool2o`00033ooooo0_l0000Mooooo`;o00003Oooool001kooooo00?o0000ooooooooool08?oo
ool2o`0001Kooooo0_l000000ooooooo0000o`000004ooooo`;o00001Oooool5o`0000?ooooo1Ol0
00000ooooooo0000o`000002ooooo`;o00001?ooool4o`0000Cooooo0_l0000`ooooo`;o0000Booo
ool2o`0004oooooo0_l00006ooooo`;o00001Oooool001kooooo00?o0000ooooooooool08?ooool2
o`0000Cooooo0_l00004ooooo`;o00003Oooool2o`0000;ooooo0_l00007ooooo`;o000000?ooooo
o`000?l000000oooool8o`0000;ooooo1?l000001?oooooo0000o`000?ooool2o`0000Kooooo0_l0
0006ooooo`;o00000oooool2o`0006[ooooo0_l0001Kooooo`;o00001Oooool001kooooo00?o0000
ooooooooool06Oooool2o`0000Cooooo0_l00005ooooo`;o00001?ooool2o`0000gooooo0_l00002
ooooo`;o00001oooool2o`000003ooooool0003o000000Cooooo1ol00003ooooo`Ko00002Oooool2
o`0000;ooooo0_l00002ooooo`?o00000_ooool2o`0000?ooooo0_l0001Uooooo`;o0000H_ooool0
01kooooo00?o0000ooooooooool06Oooool2o`0000Cooooo0_l0000Dooooo`;o00002?ooool2o`00
00Gooooo1?l000000ooooooo0000o`000004ooooo`So00001?ooool2o`0000Oooooo0_l00006oooo
o`;o00000oooool2o`000003ooooool0003o000000Cooooo0_l0000Cooooo`;o0000]?ooool001ko
oooo0_l0000Xooooo`;o00003?ooool2o`0000Gooooo0_l000000ooooooo0000o`000005ooooo`Co
000000?oooooo`000?l000002Oooool3o`0000Cooooo0_l00007ooooo`;o00000_ooool2o`0000Oo
oooo0_l000000ooooooo0000o`00000Iooooo`;o0000]?ooool001kooooo00?o0000ooooooooool0
2_ooool2o`0001?ooooo0_l00006ooooo`?o000000?oooooo`000?l000001Oooool2o`0000Cooooo
0_l00002ooooo`Go00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000008ooooo`;o0000
00?oooooo`000?l000001Oooool2o`0000Gooooo0_l00002ooooo`;o0000B_ooool2o`0008oooooo
000Nooooo`03o`000?oooooooooo00[ooooo0_l0000Cooooo`;o00001oooool2o`000003ooooool0
003o000000Gooooo0ol00003ooooo`;o00000oooool3o`0000Cooooo0_l00004ooooo`;o00001?oo
ool2o`0000?ooooo1Ol00005ooooo`;o0000EOooool2o`0006?ooooo0_l00004ooooo`Co00008_oo
ool001kooooo00?o0000ooooooooool06oooool2o`0000;ooooo0_l0000Booooo`;o00002?ooool3
o`0000Cooooo0_l00004ooooo`;o00000_ooool6o`0000;ooooo0ol00005ooooo`;o00008_ooool2
o`0006;ooooo0_l0000cooooo`;o00001?ooool4o`0002;ooooo000Nooooo`03o`000?oooooooooo
01_ooooo0_l00008ooooo`;o00004_ooool2o`0000;ooooo0ol00004ooooo`;o00001oooool3o`00
00;ooooo0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o000002;ooooo0_l0000Xoooo
o`;o0000>?ooool2o`0005Oooooo0_l00006ooooo`007_ooool00ol0003oooooooooo`0Uooooo`;o
00004?ooool4o`0000;ooooo0_l00002ooooo`;o00002_ooool3o`0000_ooooo0_l00003ooooo`;o
00001?ooool2o`0000Sooooo0_l0000Oooooo`;o00001oooool2o`00013ooooo0_l0002Aooooo`;o
00001_ooool001kooooo00?o0000ooooooooool0=oooool2o`0000Sooooo0_l00005ooooo`Go0000
00?oooooo`000?l000004?ooool2o`0000Cooooo0_l00008ooooo`;o00002?ooool2o`000003oooo
ool0003o000001;ooooo0_l00007ooooo`;o0000?oooool2o`0002[ooooo0_l0000nooooo`007_oo
ool00ol0003oooooooooo`02o`0001gooooo0_l0000Oooooo`;o00000oooool2o`000003ooooool0
003o000000?o000000?oooooo`000?l000003oooool3o`0000Kooooo0_l0000@ooooo`;o000000?o
ooooo`000?l000008Oooool2o`0003Wooooo0_l0000Zooooo`;o0000;oooool2o`0000gooooo000N
ooooo`03o`000?oooooooooo00;o00007Oooool2o`0001oooooo0_l00003ooooo`;o00000_ooool2
o`000003ooooool0003o000000;o00003Oooool5o`0000Kooooo0_l0000@ooooo`;o00009?ooool2
o`0008cooooo0_l00008ooooo`;o00003Oooool001kooooo00?o0000ooooooooool09_ooool2o`00
02Cooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo1?l00002ooooo`;o00001oooool2
o`0000Oooooo0_l00009ooooo`Ko00002Oooool2o`000003ooooool0003o000000Oooooo0_l0002G
ooooo`;o00005oooool001kooooo00?o0000ooooooooool07oooool2o`0000Gooooo0_l0000?oooo
o`;o00003Oooool2o`0000Wooooo0_l000001?oooooo0000o`000?ooool4o`0000;ooooo0_l00007
ooooo`Co00001Oooool2o`0000_ooooo1?l00009ooooo`;o000000?oooooo`000?l000000oooool2
o`0000;ooooo0_l0001kooooo`;o0000<oooool001kooooo00?o0000ooooooooool07oooool2o`00
01Kooooo0_l00006ooooo`;o00001Oooool2o`0000Sooooo0_l0000;ooooo`;o00001oooool4o`00
02Oooooo0_l00016ooooo`;o0000=oooool2o`0003?ooooo000Nooooo`03o`000?oooooooooo01oo
oooo0_l0000Hooooo`;o00001?ooool2o`0000Cooooo0_l00009ooooo`;o00006oooool2o`0000Oo
oooo0_l00005ooooo`Co00003oooool2o`0004Oooooo0_l0001/ooooo`007_ooool00ol0003ooooo
ooooo`0Qooooo`;o00005_ooool2o`0000Gooooo0_l00003ooooo`;o00002?ooool2o`000003oooo
ool0003o000001Wooooo0_l00007ooooo`;o00001Oooool4o`0000oooooo0_l0002eooooo`007_oo
ool00ol0003oooooooooo`0Qooooo`;o00006Oooool2o`0000;ooooo0_l0000=ooooo`;o000000?o
ooooo`000?l000001Oooool2o`000003ooooool0003o000000?ooooo0_l0000:ooooo`Co00001Ooo
ool3o`0000Cooooo0_l00005ooooo`;o0000`Oooool001kooooo00?o0000ooooooooool0??ooool2
o`0001_ooooo1Ol00003ooooo`;o00001?ooool2o`0000Cooooo1ol00003ooooo`;o00002oooool2
o`0000Oooooo0_l0002]ooooo`;o00002Oooool001kooooo0_l0000`ooooo`;o00005_ooool2o`00
00Wooooo0_l00006ooooo`Co00002Oooool6o`0000?ooooo1?l00009ooooo`;o00001Oooool2o`00
00Oooooo0_l0002]ooooo`;o00002Oooool001kooooo00?o0000ooooooooool0;oooool2o`0001Ko
oooo0_l00009ooooo`;o00002?ooool2o`0000_ooooo1Ol0000?ooooo`;o00002?ooool3o`0009_o
oooo0_l0000Pooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o00007Oooool2o`0000Wooooo
0ol00003ooooo`;o00001oooool2o`0000;ooooo0_l0000;ooooo`;o00000oooool2o`0000Oooooo
0_l0000@ooooo`?o0000L?ooool2o`0002Wooooo0_l0000Pooooo`007_ooool00ol0003ooooooooo
o`02o`0001_ooooo0_l0000?ooooo`;o00003?ooool2o`0000Wooooo0ol00003ooooo`;o00001?oo
ool2o`000003ooooool0003o000000;ooooo0_l0000;ooooo`;o00003?ooool2o`0008?ooooo0_l0
001;ooooo`007_ooool00ol0003oooooooooo`02o`0001Cooooo0_l0000Fooooo`;o00008oooool2
o`0001cooooo0ol0000Aooooo`;o0000>_ooool2o`0008Cooooo000Nooooo`03o`000?oooooooooo
00Kooooo0_l0000>ooooo`;o0000@oooool2o`0000Sooooo0_l0000:ooooo`?o000000?oooooo`00
0?l000003_ooool2o`000003ooooool0003o000000gooooo0_l0000Xooooo`;o0000Q?ooool001ko
oooo00?o0000ooooooooool01_ooool2o`00027ooooo0_l0000Mooooo`;o00004Oooool2o`0000So
oooo0_l0000>ooooo`;o00002Oooool2o`0000Kooooo0_l0000=ooooo`;o00001?ooool2o`000:So
oooo000Nooooo`03o`000?oooooooooo01Kooooo0_l0000Aooooo`;o00003oooool2o`0000cooooo
0_l0000Kooooo`;o00006Oooool2o`0001_ooooo0_l0002Xooooo`007_ooool00ol0003ooooooooo
o`0Fooooo`;o00008_ooool2o`0002Wooooo0_l0003Pooooo`007_ooool00ol0003oooooooooo`0F
ooooo`;o00005_ooool2o`0003kooooo0ol0003Fooooo`007_ooool00ol0003oooooooooo`0^oooo
o`;o00001Oooool2o`0001kooooo0_l0000Gooooo`?o00004oooool2o`000<7ooooo000Nooooo`03
o`000?oooooooooo00Kooooo0_l0000]ooooo`;o00003?ooool2o`00013ooooo0_l000000ooooooo
0000o`00000Qooooo`;o00001oooool2o`0000Gooooo0_l0000Dooooo`;o0000Y?ooool001kooooo
00?o0000ooooooooool01_ooool2o`0003_ooooo0_l00006ooooo`;o00002oooool2o`00013ooooo
0_l0000?ooooo`;o00003_ooool2o`0001Cooooo0_l000000ooooooo0000o`00002Qooooo`007_oo
ool00ol0003oooooooooo`1:ooooo`?o00007Oooool2o`0003Sooooo0_l0000^ooooo`;o0000LOoo
ool001Cooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo04Sooooo1?l00006
ooooo`;o00000_ooool2o`0000Wooooo0_l0000Uooooo`;o0000<_ooool2o`0001Kooooo0_l0001a
ooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo027ooooo0ol0000=oooo
o`;o00005Oooool2o`0000Cooooo0_l00002ooooo`;o00000_ooool2o`0000Wooooo0_l0000Uoooo
o`;o00004?ooool2o`00023ooooo0_l00029ooooo`005_ooool00ol0003oooooooooo`05ooooo`?o
00008Oooool3o`0000gooooo0_l0000Kooooo`;o00000_ooool3o`0004Gooooo0_l0002[ooooo`00
5_ooool00ol0003oooooooooo`0Zooooo`;o0000;_ooool3o`000?;ooooo000Fooooo`03o`000?oo
oooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0
003oooooooooo`3ooooooe3ooooo000Dooooo`03oeEEEOmVIVKo00000?ooooooD_ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.33971 .93121 Mdot
.08136 .79142 Mdot
.10935 .83447 Mdot
.23339 .93665 Mdot
.2394 .94264 Mdot
.20026 .88282 Mdot
.56248 .4824 Mdot
.27859 .90605 Mdot
.28759 .89588 Mdot
.26187 .34311 Mdot
.19129 .00431 Mdot
.13719 .92834 Mdot
.15776 .84403 Mdot
.50242 .88153 Mdot
.21252 .84421 Mdot
.08208 .24801 Mdot
.999 .05113 Mdot
.09477 .81806 Mdot
.31768 .92948 Mdot
.29344 .94591 Mdot
.79922 .07633 Mdot
.26949 .83462 Mdot
.17332 .73322 Mdot
.041 .10398 Mdot
.32073 .93407 Mdot
.31873 .89302 Mdot
.26212 .84428 Mdot
.27787 .59899 Mdot
.15988 .98116 Mdot
.22282 .8083 Mdot
.10347 .84656 Mdot
.21403 .85692 Mdot
.38552 .85687 Mdot
.87669 .77821 Mdot
.24003 .11132 Mdot
.26006 .01797 Mdot
.14226 .90393 Mdot
.68933 .82609 Mdot
.14128 .85539 Mdot
.28035 .90635 Mdot
.12643 .84124 Mdot
.41616 .9531 Mdot
.11766 .71158 Mdot
.3393 .03148 Mdot
.5529 .11517 Mdot
.37155 .9345 Mdot
.67789 .16884 Mdot
.22196 .91595 Mdot
.28912 .99729 Mdot
.14756 .58083 Mdot
.08044 .76472 Mdot
.13341 .93113 Mdot
.22895 .89951 Mdot
.22518 .95906 Mdot
.16703 .85136 Mdot
.97855 .25549 Mdot
.27173 .84057 Mdot
.20096 .88576 Mdot
.26127 .83937 Mdot
.4459 .94017 Mdot
.18441 .8608 Mdot
.30827 .9022 Mdot
.80585 .98311 Mdot
.34905 .94265 Mdot
.18726 .93883 Mdot
.24036 .88885 Mdot
.15057 .92254 Mdot
.26394 .84281 Mdot
.19066 .87417 Mdot
.60813 .81625 Mdot
.99381 .12842 Mdot
.14804 .85367 Mdot
.53516 .79733 Mdot
.21964 .1855 Mdot
.2257 .96883 Mdot
.33684 .80489 Mdot
.25746 .72135 Mdot
.64277 .3593 Mdot
.23408 .84664 Mdot
.13771 .79172 Mdot
.28685 .9813 Mdot
.70277 .04068 Mdot
.14876 .17962 Mdot
.28862 .90138 Mdot
.03175 .87821 Mdot
.25822 .12047 Mdot
.28574 .93644 Mdot
.25127 .88221 Mdot
.19977 .86189 Mdot
.1563 .8777 Mdot
.36396 .97265 Mdot
.24227 .10198 Mdot
.1241 .90699 Mdot
.99021 .93952 Mdot
.45471 .91139 Mdot
.19832 .03961 Mdot
.14163 .63263 Mdot
.27048 .1021 Mdot
.28066 .93165 Mdot
.15334 .51356 Mdot
.29109 .85239 Mdot
.18005 .76969 Mdot
.47681 .82601 Mdot
.07816 .67693 Mdot
.03546 .78146 Mdot
.18362 .73708 Mdot
.04159 .3042 Mdot
.05626 .31697 Mdot
.09896 .7898 Mdot
.85113 .07334 Mdot
.10521 .87004 Mdot
.12429 .77977 Mdot
.31417 .96645 Mdot
.08965 .84486 Mdot
.4611 .24732 Mdot
.4768 .42024 Mdot
.45371 .02681 Mdot
.15899 .81626 Mdot
.95043 .55034 Mdot
.22691 .00301 Mdot
.28416 .86836 Mdot
.1597 .75845 Mdot
.27429 .84976 Mdot
.82409 .79902 Mdot
.59339 .6573 Mdot
.4266 .82016 Mdot
.99763 .87369 Mdot
.32577 .91484 Mdot
.93718 .83242 Mdot
.42531 .74832 Mdot
.06795 .86156 Mdot
.63525 .40937 Mdot
.23123 .63673 Mdot
.18069 .73737 Mdot
.14212 .82309 Mdot
.06222 .798 Mdot
.17518 .7384 Mdot
.07406 .69122 Mdot
.14231 .8947 Mdot
.21843 .89731 Mdot
.27692 .87861 Mdot
.35533 .95072 Mdot
.33322 .82311 Mdot
.27179 .78641 Mdot
.70433 .92949 Mdot
.12545 .9824 Mdot
.39278 .84075 Mdot
.27931 .84996 Mdot
.65009 .87682 Mdot
.97897 .27975 Mdot
.40103 .92239 Mdot
.35709 .82392 Mdot
.15733 .91314 Mdot
.30279 .94658 Mdot
.22764 .83657 Mdot
.20732 .84901 Mdot
.16469 .69698 Mdot
.43373 .37027 Mdot
.25937 .89445 Mdot
.1008 .20101 Mdot
.10824 .65878 Mdot
.34689 .05744 Mdot
.67845 .06417 Mdot
.22927 .72364 Mdot
.28796 .95316 Mdot
.22731 .90739 Mdot
.27707 .85966 Mdot
.23499 .86676 Mdot
.47675 .00434 Mdot
.20435 .77483 Mdot
.32189 .79227 Mdot
.4136 .05275 Mdot
.27859 .09733 Mdot
.00016 .01026 Mdot
.40333 .95145 Mdot
.21738 .81953 Mdot
.10561 .15567 Mdot
.27358 .89771 Mdot
.56313 .61256 Mdot
.14279 .96185 Mdot
.2065 .7406 Mdot
.15203 .97784 Mdot
.3178 .0616 Mdot
.60965 .07278 Mdot
.119 .36001 Mdot
.23308 .75266 Mdot
.18108 .96841 Mdot
.36082 .94537 Mdot
.33776 .00943 Mdot
.39977 .90358 Mdot
.37694 .93863 Mdot
.91558 .07638 Mdot
.32306 .91195 Mdot
.96292 .91734 Mdot
.27536 .07488 Mdot
.18124 .77103 Mdot
.33642 .05312 Mdot
.12529 .98504 Mdot
.30416 .8975 Mdot
.30396 .89479 Mdot
.60907 .81376 Mdot
.26962 .83224 Mdot
.1568 .76099 Mdot
.3985 .06517 Mdot
.32593 .9353 Mdot
.24779 .88925 Mdot
.41725 .80579 Mdot
.25262 .83753 Mdot
.22257 .94924 Mdot
.23772 .79541 Mdot
.21375 .83185 Mdot
.32985 .87525 Mdot
.74663 .95606 Mdot
.21583 .66552 Mdot
.09114 .67889 Mdot
.20487 .73792 Mdot
.26555 .88998 Mdot
.35733 .22228 Mdot
.30438 .57921 Mdot
.45564 .01623 Mdot
.38494 .73354 Mdot
.46181 .97791 Mdot
.35168 .95731 Mdot
.21968 .86393 Mdot
.25119 .91217 Mdot
.15705 .76806 Mdot
.46463 .73144 Mdot
.12222 .74416 Mdot
.31617 .6117 Mdot
.30858 .84198 Mdot
.27288 .86767 Mdot
.41139 .94473 Mdot
.34055 .80937 Mdot
.00084 .08371 Mdot
.14012 .05148 Mdot
.11489 .94644 Mdot
.89195 .5259 Mdot
.1039 .82474 Mdot
.82717 .52885 Mdot
.99218 .59321 Mdot
.12184 .91323 Mdot
.32922 .80776 Mdot
.13695 .7255 Mdot
.29192 .73798 Mdot
.18265 .92436 Mdot
.26351 .88955 Mdot
.37112 .03088 Mdot
.30972 .79379 Mdot
.65793 .46212 Mdot
.12594 .82206 Mdot
.10213 .88705 Mdot
.1682 .81822 Mdot
.52234 .40516 Mdot
.86953 .82469 Mdot
.50108 .82601 Mdot
.22597 .73727 Mdot
.24104 .90652 Mdot
.73695 .68045 Mdot
.21736 .93397 Mdot
.03466 .94767 Mdot
.32769 .89263 Mdot
.14127 .85407 Mdot
.28768 .46346 Mdot
.76887 .79229 Mdot
.3362 .81114 Mdot
.4725 .67005 Mdot
.30337 .77539 Mdot
.78595 .67551 Mdot
.1245 .81282 Mdot
.2733 .87386 Mdot
.28604 .93927 Mdot
.8624 .61405 Mdot
.17855 .82831 Mdot
.15736 .82965 Mdot
.34968 .0139 Mdot
.16946 .78983 Mdot
.24808 .57963 Mdot
.5515 .57745 Mdot
.24713 .011 Mdot
.15223 .73605 Mdot
.07719 .88616 Mdot
.28586 .81888 Mdot
.24045 .70945 Mdot
.26669 .9071 Mdot
.23858 .92001 Mdot
.35142 .956 Mdot
.17915 .78124 Mdot
.14272 .60432 Mdot
.24258 .65787 Mdot
.13619 .68258 Mdot
.15515 .66566 Mdot
.5112 .77007 Mdot
.27868 .91497 Mdot
.12315 .8582 Mdot
.59212 .95222 Mdot
.30671 .7017 Mdot
.19496 .90317 Mdot
.2958 .65331 Mdot
.95651 .84698 Mdot
.40601 .99149 Mdot
.9263 .59579 Mdot
.2945 .88255 Mdot
.29776 .11403 Mdot
.22096 .97715 Mdot
.7777 .03969 Mdot
.11947 .72523 Mdot
.25648 .84524 Mdot
.24047 .83037 Mdot
.15337 .72692 Mdot
.18898 .73844 Mdot
.26735 .85145 Mdot
.12666 .84865 Mdot
.3228 .88842 Mdot
.44727 .00611 Mdot
.2885 .9888 Mdot
.32649 .69642 Mdot
.19391 .0142 Mdot
.59436 .90214 Mdot
.37345 .87898 Mdot
.3541 .62351 Mdot
.14288 .80679 Mdot
.36483 .84952 Mdot
.20946 .75149 Mdot
.24141 .09092 Mdot
.09196 .84728 Mdot
.25392 .86138 Mdot
.2516 .01571 Mdot
.34916 .86808 Mdot
.09066 .86206 Mdot
.29558 .87982 Mdot
.3461 .95601 Mdot
.19189 .88999 Mdot
.4833 .41878 Mdot
.27255 .89833 Mdot
.12239 .18605 Mdot
.21838 .34402 Mdot
.40503 .97718 Mdot
.27575 .85636 Mdot
.05614 .35432 Mdot
.83781 .07222 Mdot
.30049 .95843 Mdot
.21372 .6237 Mdot
.30731 .85787 Mdot
.22673 .97467 Mdot
.97819 .43037 Mdot
.35664 .93331 Mdot
.4943 .94788 Mdot
.327 .76875 Mdot
.10107 .69617 Mdot
.27248 .91187 Mdot
.14619 .81005 Mdot
.20765 .87841 Mdot
.38024 .06402 Mdot
.16066 .01576 Mdot
.21625 .04809 Mdot
.18247 .83507 Mdot
.33751 .9781 Mdot
.24444 .74258 Mdot
.15214 .86435 Mdot
.47677 .06008 Mdot
.30083 .80758 Mdot
.41889 .84258 Mdot
.11933 .84928 Mdot
.20696 .81186 Mdot
.34101 .93465 Mdot
.19172 .96021 Mdot
.08932 .14625 Mdot
.17993 .61657 Mdot
.31577 .04533 Mdot
.19296 .83655 Mdot
.06622 .64345 Mdot
.24807 .84937 Mdot
.12393 .81094 Mdot
.27388 .87961 Mdot
.92005 .88066 Mdot
.088 .46811 Mdot
.57226 .14098 Mdot
.2796 .97661 Mdot
.63889 .26946 Mdot
.27316 .80174 Mdot
.22688 .85343 Mdot
.32905 .97794 Mdot
.06069 .54582 Mdot
.27843 .16865 Mdot
.31484 .60936 Mdot
.96817 .84324 Mdot
.04003 .8948 Mdot
.8904 .29925 Mdot
.26995 .85417 Mdot
.10241 .79294 Mdot
.28007 .87715 Mdot
.16246 .88724 Mdot
.26527 .84169 Mdot
.22274 .93985 Mdot
.23515 .94811 Mdot
.28733 .08274 Mdot
.18065 .16412 Mdot
.72885 .78117 Mdot
.26301 .83664 Mdot
.10792 .85624 Mdot
.04055 .78108 Mdot
.45533 .0946 Mdot
.47917 .34958 Mdot
.30272 .90201 Mdot
.10057 .71581 Mdot
.16914 .25882 Mdot
.14395 .66407 Mdot
.16267 .86954 Mdot
.22221 .0138 Mdot
.22867 .72408 Mdot
.05435 .66622 Mdot
.27531 .89731 Mdot
.09063 .67089 Mdot
.54693 .94845 Mdot
.83753 .02128 Mdot
.14084 .79109 Mdot
.43423 .8196 Mdot
.14754 .74612 Mdot
.35354 .05471 Mdot
.23675 .84188 Mdot
.26005 .8746 Mdot
.71705 .44418 Mdot
.81534 .71768 Mdot
.15301 .86169 Mdot
.23157 .89013 Mdot
.0223 .96525 Mdot
.6039 .61046 Mdot
.29856 .8777 Mdot
.18595 .91011 Mdot
.9481 .89847 Mdot
.05381 .10485 Mdot
.70436 .19584 Mdot
.52628 .56176 Mdot
.3432 .96122 Mdot
.0645 .87407 Mdot
.45413 .86247 Mdot
.28136 .60074 Mdot
.22646 .10511 Mdot
.30822 .72853 Mdot
.54155 .1012 Mdot
.30691 .76425 Mdot
.78797 .33372 Mdot
.57884 .33326 Mdot
.18844 .83562 Mdot
.28596 .07904 Mdot
.22779 .82603 Mdot
.36942 .87589 Mdot
.2058 .90024 Mdot
.86257 .57388 Mdot
.21051 .80816 Mdot
.13993 .56914 Mdot
.09845 .74131 Mdot
.31797 .96836 Mdot
.2246 .85592 Mdot
.39125 .72623 Mdot
.26515 .84433 Mdot
.30745 .9163 Mdot
.24483 .01013 Mdot
.97658 .92914 Mdot
.38595 .34492 Mdot
.18934 .96927 Mdot
.24371 .85901 Mdot
.22103 .8616 Mdot
.18049 .8816 Mdot
.00198 .95223 Mdot
.28796 .11676 Mdot
.37772 .85812 Mdot
.54278 .1426 Mdot
.19622 .82591 Mdot
.30465 .00712 Mdot
.20724 .82592 Mdot
.30064 .92481 Mdot
.29 .90338 Mdot
.2887 .90234 Mdot
.11413 .92066 Mdot
.22262 .85618 Mdot
.11203 .88448 Mdot
.25196 .89024 Mdot
.01522 .44975 Mdot
.09407 .87344 Mdot
.26996 .66132 Mdot
1e-05 .00632 Mdot
.31572 .81617 Mdot
.25776 .86507 Mdot
.34254 .92294 Mdot
.57201 .77211 Mdot
.15887 .7722 Mdot
.27749 .59933 Mdot
.47794 .00494 Mdot
.23663 .61929 Mdot
.12432 .80573 Mdot
.24394 .87736 Mdot
.38273 .36852 Mdot
.07364 .92923 Mdot
.36896 .97517 Mdot
.12629 .97897 Mdot
.36653 .81084 Mdot
.33351 .92255 Mdot
.78094 .76819 Mdot
.20609 .0293 Mdot
.3451 .77765 Mdot
.38773 .70336 Mdot
.39544 .09441 Mdot
.14047 .75695 Mdot
.12308 .80051 Mdot
.48293 .81786 Mdot
.30913 .9151 Mdot
.55513 .66785 Mdot
.29965 .91107 Mdot
.23333 .8305 Mdot
.17667 .84402 Mdot
.07807 .9122 Mdot
.20479 .17028 Mdot
.16627 .59812 Mdot
.24854 .94262 Mdot
.94717 .84158 Mdot
.24576 .6985 Mdot
.20166 .07358 Mdot
.33855 .33037 Mdot
.1133 .85812 Mdot
.23785 .75666 Mdot
.13004 .90427 Mdot
.23004 .85032 Mdot
.27964 .87743 Mdot
.13208 .59988 Mdot
.64838 .74974 Mdot
.31939 .05713 Mdot
.05326 .31751 Mdot
.38935 .02858 Mdot
.07435 .04182 Mdot
.75228 .43282 Mdot
.81168 .07745 Mdot
.24156 .93015 Mdot
.06299 .83179 Mdot
.28253 .89707 Mdot
.29112 .84969 Mdot
.19393 .9523 Mdot
.38346 .90352 Mdot
.53321 .75419 Mdot
.56775 .95395 Mdot
.21583 .89763 Mdot
.05361 .93192 Mdot
.12878 .99432 Mdot
.22731 .8468 Mdot
.14165 .87136 Mdot
.17211 .66622 Mdot
.86881 .51775 Mdot
.21098 .83873 Mdot
.22503 .71624 Mdot
.2537 .86403 Mdot
.59345 .87403 Mdot
.59377 .9738 Mdot
.39353 .86933 Mdot
.97511 .73344 Mdot
.20759 .83712 Mdot
.53208 .5961 Mdot
.28733 .58751 Mdot
.28268 .85919 Mdot
.27415 .0217 Mdot
.73285 .15174 Mdot
.22526 .71725 Mdot
.30291 .90633 Mdot
.68832 .78927 Mdot
.27121 .53619 Mdot
.16396 .78933 Mdot
.27015 .00934 Mdot
.12179 .6323 Mdot
.33382 .95959 Mdot
.58721 .08253 Mdot
.20038 .86589 Mdot
.44737 .85448 Mdot
.11849 .64852 Mdot
.21896 .86158 Mdot
.37214 .84005 Mdot
.14952 .88318 Mdot
.33725 .85734 Mdot
.29848 .15279 Mdot
.15971 .97607 Mdot
.15645 .80312 Mdot
.18095 .88125 Mdot
.6379 .44019 Mdot
.74244 .73858 Mdot
.12377 .92273 Mdot
.22732 .87427 Mdot
.837 .74996 Mdot
.26075 .95664 Mdot
.27196 .74478 Mdot
.409 .30342 Mdot
.12118 .65643 Mdot
.45982 .89061 Mdot
.2388 .88714 Mdot
.15581 .87474 Mdot
.2194 .99412 Mdot
.33947 .89347 Mdot
.12887 .98053 Mdot
.32249 .88476 Mdot
.274 .70237 Mdot
.26465 .87232 Mdot
.26402 .98908 Mdot
.25958 .97362 Mdot
.3508 .8349 Mdot
.2463 .85983 Mdot
.12268 .8005 Mdot
.27732 .11047 Mdot
.44253 .12495 Mdot
.23966 .71931 Mdot
.27543 .8655 Mdot
.26578 .81203 Mdot
.25078 .82677 Mdot
.33355 .91461 Mdot
.49739 .09785 Mdot
.17584 .19132 Mdot
.16971 .84173 Mdot
.20721 .9998 Mdot
.32854 .92583 Mdot
.15142 .17827 Mdot
.14788 .84373 Mdot
.39166 .78635 Mdot
.26765 .89066 Mdot
.64495 .5886 Mdot
.4489 .59251 Mdot
.39493 .92734 Mdot
.33854 .91959 Mdot
.05599 .82839 Mdot
.42296 .11723 Mdot
.30991 .77246 Mdot
.97343 .31501 Mdot
.48756 .82718 Mdot
.11971 .77703 Mdot
.19867 .89768 Mdot
.10596 .9172 Mdot
.22497 .86713 Mdot
.48443 .91656 Mdot
.65734 .79723 Mdot
.2172 .86433 Mdot
.77679 .23251 Mdot
.28283 .90095 Mdot
.16288 .94853 Mdot
.19782 .92558 Mdot
.20132 .84603 Mdot
.98617 .86684 Mdot
.20197 .87371 Mdot
.34059 .98513 Mdot
.35608 .85781 Mdot
.39519 .8475 Mdot
.26143 .81555 Mdot
.003 .87609 Mdot
.02576 .6452 Mdot
.28995 .89385 Mdot
.36966 .91152 Mdot
.01439 .01684 Mdot
.24236 .9832 Mdot
.45785 .91945 Mdot
.21608 .86624 Mdot
.81181 .51541 Mdot
.28102 .90639 Mdot
.19815 .89861 Mdot
.81667 .83714 Mdot
.17252 .93147 Mdot
.26427 .83881 Mdot
.59436 .12523 Mdot
.21047 .73089 Mdot
.37166 .81508 Mdot
.29875 .90203 Mdot
.7938 .84084 Mdot
.19305 .20751 Mdot
.23929 .83582 Mdot
.51426 .8229 Mdot
.13348 .48496 Mdot
.38158 .08313 Mdot
.97988 .74058 Mdot
.4001 .13563 Mdot
.00068 .94018 Mdot
.30003 .82388 Mdot
.02214 .72025 Mdot
.31983 .89705 Mdot
.24218 .00659 Mdot
.15553 .87429 Mdot
.49308 .93045 Mdot
.33903 .0256 Mdot
.38669 .99255 Mdot
.28756 .79986 Mdot
.49606 .49886 Mdot
.34166 .9293 Mdot
.20224 .8662 Mdot
.35957 .04411 Mdot
.08829 .85234 Mdot
.85685 .22765 Mdot
.33227 .80561 Mdot
.09686 .84827 Mdot
.19362 .84378 Mdot
.51325 .09831 Mdot
.36688 .20605 Mdot
.41415 .72859 Mdot
.3658 .83067 Mdot
.21757 .72779 Mdot
.22014 .86139 Mdot
.74967 .87952 Mdot
.7242 .60571 Mdot
.45595 .61946 Mdot
.29629 .12041 Mdot
.17944 .09089 Mdot
.19363 .83948 Mdot
.16712 .89424 Mdot
.07195 .63589 Mdot
.296 .85595 Mdot
.53622 .47545 Mdot
.04756 .96999 Mdot
.1993 .37917 Mdot
.33926 .89168 Mdot
.66391 .84021 Mdot
.2056 .9263 Mdot
.41569 .10158 Mdot
.71037 .74141 Mdot
.12647 .73823 Mdot
.84206 .48542 Mdot
.30766 .8034 Mdot
.2433 .93979 Mdot
.19069 .51791 Mdot
.32478 .79545 Mdot
.34735 .86281 Mdot
.77166 .95039 Mdot
.222 .74607 Mdot
.4995 .8098 Mdot
.12897 .01 Mdot
.98208 .86366 Mdot
.73637 .82953 Mdot
.29457 .87983 Mdot
.59372 .78736 Mdot
.97465 .59844 Mdot
.28893 .84658 Mdot
.30487 .8018 Mdot
.19048 .83091 Mdot
.24472 .89353 Mdot
.98523 .92783 Mdot
.17369 .25217 Mdot
.7787 .46264 Mdot
.26147 .72584 Mdot
.02337 .84691 Mdot
.23592 .27999 Mdot
.27652 .92644 Mdot
.27981 .95261 Mdot
.42748 .94873 Mdot
.93221 .53761 Mdot
.24477 .89082 Mdot
.99859 .87083 Mdot
.27059 .80819 Mdot
.39606 .80154 Mdot
.26955 .90061 Mdot
.49696 .56882 Mdot
.06336 .75149 Mdot
.12705 .84926 Mdot
.20061 .86155 Mdot
.37105 .86328 Mdot
.20307 .77142 Mdot
.29217 .94187 Mdot
.18063 .81329 Mdot
.3645 .99959 Mdot
.12729 .88941 Mdot
.11728 .81532 Mdot
.7167 .84019 Mdot
.28383 .90786 Mdot
.42055 .30568 Mdot
.12281 .86521 Mdot
.20719 .68688 Mdot
.18564 .88593 Mdot
.11454 .51514 Mdot
.49712 .24866 Mdot
.12603 .98574 Mdot
.51196 .03604 Mdot
.32756 .96466 Mdot
.41009 .97248 Mdot
.21234 .73091 Mdot
.16858 .81855 Mdot
.41579 .95638 Mdot
.18198 .86831 Mdot
.20337 .83929 Mdot
.12153 .80611 Mdot
.376 .69901 Mdot
.48131 .23042 Mdot
.24284 .94257 Mdot
.33916 .85834 Mdot
.97178 .14777 Mdot
.15699 .30796 Mdot
.22579 .92207 Mdot
.2241 .58569 Mdot
.14429 .01099 Mdot
.21845 .89713 Mdot
.24052 .87463 Mdot
.21879 .84706 Mdot
.20241 .68274 Mdot
.30723 .04319 Mdot
.12437 .56595 Mdot
.29651 .89654 Mdot
.42712 .94392 Mdot
.19946 .89412 Mdot
.20727 .63165 Mdot
.63237 .77182 Mdot
.28934 .00525 Mdot
.29832 .96369 Mdot
.2517 .14701 Mdot
.25269 .80585 Mdot
.12278 .92151 Mdot
.2581 .08664 Mdot
.31473 .96963 Mdot
.11483 .797 Mdot
.40259 .07549 Mdot
.38311 .15362 Mdot
.31752 .7178 Mdot
.32219 .85851 Mdot
.1063 .49227 Mdot
.27505 .01368 Mdot
.139 .89181 Mdot
.10821 .14377 Mdot
.35664 .93847 Mdot
.23906 .85168 Mdot
.53923 .38878 Mdot
.21103 .83996 Mdot
.218 .8319 Mdot
.04903 .62437 Mdot
.28222 .90009 Mdot
.26583 .88469 Mdot
.2365 .85722 Mdot
.2063 .85172 Mdot
.28581 .92984 Mdot
.09335 .59895 Mdot
.25476 .90673 Mdot
.28625 .93018 Mdot
.75943 .58376 Mdot
.23271 .94799 Mdot
.21792 .97042 Mdot
.13144 .63515 Mdot
.13391 .86907 Mdot
.23113 .61639 Mdot
.23838 .95618 Mdot
.2263 .71801 Mdot
.07227 .8843 Mdot
.29087 .99457 Mdot
.3581 .91751 Mdot
.74684 .6054 Mdot
.27179 .17176 Mdot
.26253 .87907 Mdot
.257 .84269 Mdot
.26358 .89129 Mdot
.3328 .82848 Mdot
.40354 .97945 Mdot
.27789 .93955 Mdot
.15063 .80807 Mdot
.32205 .88985 Mdot
.12815 .85221 Mdot
.69183 .73592 Mdot
.20783 .91631 Mdot
.141 .84398 Mdot
.45169 .8773 Mdot
.28772 .88374 Mdot
.56279 .82172 Mdot
.28299 .90378 Mdot
.29213 .49782 Mdot
.15337 .86849 Mdot
.16606 .8681 Mdot
.2812 .89044 Mdot
.195 .90048 Mdot
.34633 .88073 Mdot
.8055 .58345 Mdot
.32135 .88312 Mdot
.1812 .00644 Mdot
.34243 .93797 Mdot
.26609 .60317 Mdot
.78777 .6523 Mdot
.23134 .87446 Mdot
.4229 .76878 Mdot
.28156 .85291 Mdot
.34424 .95166 Mdot
.23557 .0089 Mdot
.32333 .95952 Mdot
.26896 .94502 Mdot
.59159 .8739 Mdot
.29302 .10746 Mdot
.46433 .16726 Mdot
.2233 .82405 Mdot
.91514 .89287 Mdot
.17864 .84271 Mdot
.29072 .90555 Mdot
.17164 .93283 Mdot
.17361 .88314 Mdot
.34848 .93112 Mdot
.34292 .88052 Mdot
.72422 .26573 Mdot
.27794 .82897 Mdot
.88002 .95001 Mdot
.91708 .55128 Mdot
.46249 .89837 Mdot
.09275 .7427 Mdot
.29789 .81472 Mdot
.24009 .35213 Mdot
.23352 .89126 Mdot
.55003 .62412 Mdot
.18968 .83026 Mdot
.40181 .98395 Mdot
.26393 .85448 Mdot
.20144 .82748 Mdot
.2754 .77573 Mdot
.44215 .17443 Mdot
.32961 .74646 Mdot
.42494 .77857 Mdot
.46893 .96431 Mdot
.21574 .30607 Mdot
.22309 .76937 Mdot
.22747 .88987 Mdot
.30043 .84914 Mdot
.10526 .83986 Mdot
.89473 .10431 Mdot
.03572 .57312 Mdot
.37883 .89408 Mdot
.07439 .98849 Mdot
.17837 .18331 Mdot
.35968 .87994 Mdot
.31398 .00957 Mdot
.2314 .13016 Mdot
.28039 .88669 Mdot
.78462 .76009 Mdot
.37956 .16438 Mdot
.27571 .83585 Mdot
.29078 .89429 Mdot
.20878 .85144 Mdot
.37183 .73835 Mdot
.27458 .72686 Mdot
.3663 .68639 Mdot
.77441 .06872 Mdot
.27426 .94994 Mdot
.06654 .04418 Mdot
.17786 .75475 Mdot
.24449 .88175 Mdot
.33783 .81079 Mdot
.69 .13828 Mdot
.30068 .89103 Mdot
.5435 .2809 Mdot
.30925 .79421 Mdot
.24257 .83451 Mdot
.17447 .65334 Mdot
.20761 .86449 Mdot
.16647 .86954 Mdot
.31719 .93854 Mdot
.08629 .6001 Mdot
.0482 .83546 Mdot
.20834 .87388 Mdot
.34838 .88609 Mdot
.28407 .99675 Mdot
.21766 .89657 Mdot
.59997 .85586 Mdot
.17634 .84166 Mdot
.89926 .84042 Mdot
.101 .91676 Mdot
.07287 .28061 Mdot
.20654 .11545 Mdot
.14645 .81611 Mdot
.16148 .91264 Mdot
.80879 .70013 Mdot
.8348 .96 Mdot
.82258 .75779 Mdot
.26306 .82462 Mdot
.22565 .85582 Mdot
.21497 .8335 Mdot
.15828 .91007 Mdot
.2704 .87248 Mdot
.69063 .62621 Mdot
.09148 .7129 Mdot
.15726 .66472 Mdot
.00652 .98107 Mdot
.28666 .24044 Mdot
.18977 .49204 Mdot
.98203 .47528 Mdot
.04755 .079 Mdot
.07269 .49375 Mdot
.66284 .74341 Mdot
.30815 .9117 Mdot
.29538 .65645 Mdot
.09537 .98079 Mdot
.24967 .84043 Mdot
.28312 .84215 Mdot
.21766 .92812 Mdot
.4692 .96948 Mdot
.12005 .85178 Mdot
.20761 .86894 Mdot
.27339 .8147 Mdot
.09347 .76928 Mdot
.38667 .75697 Mdot
.39597 .02747 Mdot
.22414 .0453 Mdot
.27743 .84386 Mdot
.89108 .55606 Mdot
.24881 .94817 Mdot
.26191 .7841 Mdot
.7633 .18641 Mdot
.33749 .91565 Mdot
.29759 .88716 Mdot
.24902 .84461 Mdot
.21899 .67223 Mdot
.22819 .64814 Mdot
.23677 .87145 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[o
oooo0_l00002ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`02ooooo`007Oooool2o`0000oooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Oooooo0_l000000ooooooo0000o`000002ooooo`03o`00
0?oooooooooo00Gooooo0_l00003ooooo`;o000000?oooooo`000?ooool02_ooool2o`0000;ooooo
0ol0000=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02oooool3o`0000Oooooo
0_l00006ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001gooooo0_l0
000Xooooo`;o00003oooool2o`0000oooooo0_l000000ooooooo0000o`000007ooooo`;o00001?oo
ool2o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`;o00008Oooool2o`0000Sooooo0_l0
002^ooooo`007Oooool2o`0002Sooooo0_l00003ooooo`;o00006oooool2o`000004ooooool0003o
0000o`0000Kooooo0ol0000;ooooo`;o00001_ooool2o`000=_ooooo000Nooooo`03o`000?oooooo
oooo02_ooooo0_l00003ooooo`;o00002Oooool2o`0000Oooooo0_l00006ooooo`Co00001Oooool2
o`0001Oooooo0_l0000Pooooo`;o0000]Oooool001kooooo00Co0000oooooooooooooooo0_l0000]
ooooo`;o00002Oooool2o`0000Oooooo0_l00008ooooo`Co00007?ooool2o`00023ooooo0_l0002e
ooooo`007_ooool01?l0003oooooooooooooool2o`0004gooooo0_l00003ooooo`;o0000]Oooool2
o`0003Wooooo000Nooooo`03o`000?oooooooooo05Gooooo0_l0000Cooooo`;o0000X?ooool2o`00
03Wooooo000Nooooo`03o`000?oooooooooo06[ooooo0_l0000>ooooo`;o000000?oooooo`000?l0
00004?ooool2o`000;Kooooo000Nooooo`03o`000?oooooooooo03oooooo0_l0000Yooooo`;o0000
2Oooool2o`0000?ooooo0_l000000ooooooo0000o`00000@ooooo`;o0000]_ooool001kooooo00?o
0000ooooooooool0?oooool2o`0002Wooooo0_l00009ooooo`;o0000d?ooool001kooooo00?o0000
ooooooooool0X_ooool2o`000:?ooooo000Nooooo`03o`000?oooooooooo03cooooo0_l0001Toooo
o`;o0000??ooool2o`0001Oooooo0_l0001<ooooo`007_ooool00ol0003oooooooooo`0Booooo`Co
00009_ooool2o`0002;ooooo0_l0000?ooooo`;o0000KOooool2o`0001Oooooo0_l0001<ooooo`00
7_ooool00ol0003oooooooooo`0Booooo`Co0000;oooool2o`0001Wooooo0_l000000ooooooo0000
o`00000<ooooo`;o0000e?ooool001kooooo00?o0000ooooooooool0@_ooool2o`000003ooooool0
003o000001cooooo0_l0003Rooooo`007_ooool2o`0002[ooooo0_l0000Gooooo`;o00009Oooool2
o`0001Oooooo0_l0002mooooo`;o00001?ooool001kooooo00?o0000ooooooooool0:Oooool2o`00
03kooooo0_l00004ooooo`;o00004Oooool2o`000;gooooo0_l00004ooooo`007_ooool00ol0003o
ooooooooo`1Tooooo`;o00001oooool4o`000=Kooooo000Nooooo`03o`000?oooooooooo06?ooooo
0ol00007ooooo`;o0000:?ooool2o`000:kooooo000Nooooo`03o`000?oooooooooo06?ooooo0_l0
000Cooooo`;o00000oooool2o`0001Sooooo0_l0000oooooo`;o0000KOooool001kooooo00?o0000
ooooooooool0N?ooool2o`0000?ooooo0_l0001Iooooo`;o00007_ooool2o`0004gooooo000Noooo
o`03o`000?oooooooooo0?Sooooo0_l0001=ooooo`007_ooool00ol0003oooooooooo`0mooooo`;o
00005_ooool2o`0006_ooooo0_l00018ooooo`;o00000oooool2o`0003Cooooo000Nooooo`03o`00
0?oooooooooo03gooooo0_l0000Fooooo`;o0000:?ooool2o`00047ooooo0_l0000looooo`;o0000
0_ooool2o`0000Kooooo0_l00003ooooo`;o00004oooool2o`0001oooooo000Nooooo`03o`000?oo
oooooooo00_ooooo0_l0001<ooooo`;o00009?ooool2o`0007oooooo0_l00002ooooo`;o00008?oo
ool2o`0001oooooo000Mooooo`;o00003Oooool2o`0004cooooo0_l0000Mooooo`;o0000@Oooool2
o`0008[ooooo000Mooooo`;o0000D_ooool2o`0000Oooooo0_l0000Mooooo`;o0000@Oooool2o`00
08[ooooo000Nooooo`03o`000?oooooooooo053ooooo0_l0003eooooo`007_ooool00ol0003ooooo
ooooo`0fooooo`;o00004_ooool2o`000?_ooooo000Nooooo`03o`000?oooooooooo03Kooooo0_l0
000Booooo`;o0000<?ooool2o`0001;ooooo0_l0002eooooo`007_ooool00ol0003oooooooooo`1F
ooooo`;o00009?ooool2o`0001;ooooo0_l0000<ooooo`;o00000oooool2o`000:;ooooo000Noooo
o`;o0000C?ooool2o`0000Oooooo1?l0000[ooooo`;o00006Oooool2o`0000?ooooo0_l00007oooo
o`;o0000VOooool001kooooo00?o0000ooooooooool02Oooool2o`0000;ooooo0_l0000gooooo`;o
00000oooool2o`0000Oooooo0_l0000]ooooo`;o00009oooool2o`00077ooooo0_l0000Vooooo`00
7_ooool00ol0003oooooooooo`09ooooo`;o00000_ooool2o`0003Oooooo0_l0000Cooooo`;o0000
`_ooool2o`0002Kooooo000Nooooo`03o`000?oooooooooo04[ooooo0_l0000:ooooo`;o00000ooo
ool2o`000>[ooooo000Nooooo`03o`000?oooooooooo04[ooooo0_l0000:ooooo`;o00001Oooool2
o`00057ooooo0_l0002Eooooo`007_ooool00ol0003oooooooooo`0oooooo`;o00006Oooool2o`00
0003ooooool0003o000002Kooooo0_l0000Yooooo`;o0000UOooool001kooooo00?o0000oooooooo
ool0?oooool2o`0000oooooo0_l00008ooooo`Co00009oooool2o`000<3ooooo000Nooooo`03o`00
0?oooooooooo053ooooo0_l0000:ooooo`;o0000jOooool001kooooo00?o0000ooooooooool0S?oo
ool2o`0002oooooo0_l00028ooooo`007_ooool00ol0003oooooooooo`17ooooo`;o0000@oooool2
o`0002oooooo0_l00020ooooo`;o00001_ooool001kooooo00?o0000ooooooooool0Aoooool2o`00
0?Kooooo0_l00006ooooo`007_ooool00ol0003oooooooooo`1nooooo`;o0000aoooool001kooooo
00?o0000ooooooooool0O_ooool2o`0005cooooo0_l0001Yooooo`007_ooool00ol0003ooooooooo
o`2/ooooo`;o00002?ooool2o`0002Cooooo0_l0001Yooooo`007_ooool00ol0003oooooooooo`0O
ooooo`;o0000Roooool2o`0000Sooooo0_l0002?ooooo`007_ooool00ol0003oooooooooo`0Ioooo
o`;o00001?ooool2o`0002gooooo0_l0003Xooooo`;o00003Oooool001kooooo0_l0000Jooooo`;o
0000<oooool2o`0009[ooooo0_l0001<ooooo`;o00003Oooool001kooooo00?o0000ooooooooool0
GOooool2o`0001Wooooo0_l0001`ooooo`;o0000Foooool001kooooo00?o0000ooooooooool07_oo
ool2o`0003gooooo0_l0000Iooooo`;o0000cOooool001kooooo00?o0000ooooooooool07_ooool2
o`000?oooooo:?ooool001kooooo00?o0000ooooooooool0=oooool2o`0003kooooo0_l0003>oooo
o`007_ooool00ol0003oooooooooo`0gooooo`;o0000?_ooool2o`0001[ooooo0_l0002booooo`00
7_ooool00ol0003oooooooooo`0nooooo`;o00005_ooool2o`0003_ooooo0_l00013ooooo`;o0000
KOooool001kooooo00?o0000ooooooooool0?_ooool2o`0001Cooooo1?l00020ooooo`;o0000KOoo
ool001kooooo00?o0000ooooooooool0E?ooool2o`0003Kooooo0_l0002iooooo`007_ooool00ol0
003oooooooooo`0/ooooo`?o0000GOooool2o`000;Wooooo000Nooooo`03o`000?oooooooooo02co
oooo0ol0003ooooooaWooooo000Nooooo`03o`000?oooooooooo03Kooooo0_l0000;ooooo`;o0000
ooooool3ooooo`007_ooool00ol0003oooooooooo`0Tooooo`;o00004?ooool2o`0000_ooooo0_l0
002_ooooo`;o0000DOooool001kooooo00?o0000ooooooooool09?ooool2o`0000oooooo0_l0002m
ooooo`;o0000DOooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0000Kooooo00?o0000ooooooooool0=Oooool2o`000?oooooo4Oooool000?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o
0000ooooooooool0hOooool2o`0006Cooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00onHV9So8B4Qonk^kP07ooooo`?o00007Oooool2o`000<;ooooo0_l0001Tooooo`000oooool0
1Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003ooooooooo
o`0Mooooo`;o0000oooooolYooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool01Oooool00ol0003oooooooooo`0kooooo`;o0000=_ooool2o`000=;ooooo0003
ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo03_ooooo0_l0000fooooo`;o0000d_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodSooooo
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo073ooooo0_l0003Eooooo`007_ooool00ol0003oooooooooo`1`
ooooo`;o0000eOooool001kooooo00?o0000ooooooooool0oooooolCooooo`;o0000<oooool001ko
oooo00?o0000ooooooooool0V?ooool2o`0007Sooooo0_l0000cooooo`007_ooool00ol0003ooooo
ooooo`2Hooooo`;o0000G_ooool2o`0004gooooo000Nooooo`03o`000?oooooooooo0?Sooooo0_l0
001=ooooo`007_ooool00ol0003oooooooooo`1Iooooo`;o0000k?ooool001kooooo00?o0000oooo
ooooool0FOooool2o`000>cooooo000Nooooo`03o`000?oooooooooo09;ooooo0_l0002cooooo`00
7_ooool00ol0003oooooooooo`0Gooooo`;o0000NOooool2o`0000[ooooo0_l0002Wooooo`007_oo
ool2o`0001Sooooo0_l0000Kooooo`;o0000J?ooool2o`000:Oooooo000Nooooo`03o`000?oooooo
oooo03Cooooo0_l0003oooooo`Gooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`0coooo
o`;o0000ooooool6ooooo`;o00002oooool001kooooo00?o0000ooooooooool0<oooool2o`000?oo
oooo4oooool001kooooo00?o0000ooooooooool0ioooool2o`0005kooooo000Nooooo`03o`000?oo
oooooooo0>Oooooo0_l0001Nooooo`007_ooool00ol0003oooooooooo`3<ooooo`;o0000NOooool0
01kooooo00?o0000ooooooooool0c?ooool2o`0007Wooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool05?ooool2o`0003?ooooo0_l0001Rooooo`;o0000
Roooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0000cooooo`;o0000H_oo
ool2o`0008_ooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo7_oo
ool2o`0002Sooooo000Nooooo`;o0000oooooolOooooo`;o0000:?ooool001kooooo00?o0000oooo
ooooool02Oooool2o`0007Kooooo0_l00002ooooo`;o0000`?ooool001kooooo00?o0000oooooooo
ool02Oooool2o`0002Cooooo0_l0000Aooooo`;o0000?Oooool2o`0000;ooooo0_l00030ooooo`00
7_ooool00ol0003oooooooooo`0_ooooo`;o00004Oooool2o`000?oooooo1?ooool001kooooo00?o
0000ooooooooool0ooooooliooooo`;o00003Oooool001kooooo00?o0000ooooooooool03Oooool3
o`000?oooooo:Oooool2o`0000gooooo000Nooooo`03o`000?oooooooooo00gooooo0ol0003ooooo
ocSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`1Zooooo`;o0000foooool001kooooo00?o0000
ooooooooool0J_ooool2o`0004cooooo0_l0002=ooooo`007_ooool00ol0003oooooooooo`2hoooo
o`;o0000@_ooool2o`0004Wooooo000Nooooo`03o`000?oooooooooo0?cooooo0_l00019ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo04?ooooo0_l0
000<ooooo`;o00009_ooool2o`000<cooooo000Nooooo`03o`000?oooooooooo04?ooooo0_l0000<
ooooo`;o00009_ooool2o`000<cooooo000Nooooo`;o0000VOooool2o`000:gooooo000Nooooo`03
o`000?oooooooooo00kooooo0_l0000jooooo`;o0000C?ooool2o`000:gooooo000Nooooo`03o`00
0?oooooooooo00kooooo0_l0000jooooo`;o0000noooool001kooooo00?o0000ooooooooool08ooo
ool2o`000:Sooooo0_l0001hooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o0000Z?ooool2
o`0007Sooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0N?ooool2o`0000oooooo0_l0002looooo`007_ooool00ol0003oooooooooo`1hooooo`;o0000
3oooool2o`000;cooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0?Oooool2o`000?oooooo2Oooool001kooooo00?o0000ooooooooool0?Oooool2o`00
0?oooooo2Oooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`2[ooooo`;o0000V_ooool001kooooo00?o0000ooooooooool0Zoooool2o`0009[ooooo0003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413ooooooooo
o`04ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB?oo
ool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool3o`000?ooooooB?oo
ool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo
00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo
00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`2Vooooo`;o0000Woooool000?ooooo
00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooooooo
ool0Y_ooool2o`0002;ooooo0_l0001kooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00co
oooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`3:ooooo`;o0000Noooool000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`2Iooooo`;o0000[?ooool001kooooo00?o
0000ooooooooool0Uoooool4o`000:cooooo000Nooooo`03o`000?oooooooooo09Oooooo0_l0002^
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
oooo>oooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo0?3ooooo0_l00018ooooo`;o0000
2oooool001kooooo00?o0000ooooooooool0l?ooool2o`0005Gooooo000Nooooo`03o`000?oooooo
oooo0<_ooooo0_l0001jooooo`007_ooool00ol0003oooooooooo`3;ooooo`;o00006?ooool2o`00
063ooooo000Nooooo`03o`000?oooooooooo0>Gooooo0_l0001Pooooo`007_ooool01?l0003ooooo
ooooooooool2o`000?ooooooAOooool001kooooo0_l00002ooooo`;o0000oooooom5ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0d_ooool2o`0002Gooooo0_l0001<ooooo`007_ooool00ol0003o
ooooooooo`1Iooooo`;o0000Moooool2o`0002Gooooo0_l0001<ooooo`007_ooool00ol0003ooooo
ooooo`0Hooooo`;o0000?oooool2o`000>cooooo000Nooooo`03o`000?oooooooooo01Sooooo0_l0
003oooooobkooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0Z_ooool2o`0008oooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`2Zooooo`;o
0000Soooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo0;?ooooo0_l0002Booooo`007_oo
ool00ol0003oooooooooo`0Wooooo`;o0000R_ooool2o`0005Wooooo0_l0000gooooo`007_ooool0
0ol0003oooooooooo`0Wooooo`;o0000iOooool2o`0003Oooooo000Nooooo`03o`000?oooooooooo
01kooooo0_l0000Jooooo`;o0000ooooool<ooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o
00002?ooool2o`0001[ooooo0_l0003oooooo`cooooo000Nooooo`03o`000?oooooooooo01Cooooo
0_l00015ooooo`;o0000@?ooool2o`000:Sooooo000Nooooo`;o0000G?ooool2o`00043ooooo0_l0
002Xooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`0^ooooo`;o0000oooooolHooooo`007_ooool00ol0003oooooooooo`0Qooooo`;o00002ooo
ool2o`0000[ooooo0_l00038ooooo`;o00004?ooool2o`0002oooooo000Nooooo`03o`000?oooooo
oooo027ooooo0_l0000Gooooo`;o0000b?ooool2o`00013ooooo0_l0000_ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo7oooool2o`0002Oo
oooo000Nooooo`03o`000?oooooooooo0?oooooo2_ooool2o`0001?ooooo0_l0000Wooooo`007_oo
ool00ol0003oooooooooo`3oooooo`[ooooo0_l0000looooo`007_ooool00ol0003oooooooooo`1D
ooooo`;o0000lOooool001kooooo00?o0000ooooooooool0E?ooool2o`000=Gooooo0_l0000Joooo
o`007_ooool00ol0003oooooooooo`3oooooobcooooo0_l0000Jooooo`007_ooool00ol0003ooooo
ooooo`0@ooooo`;o0000oooooolfooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o0000oooo
oolfooooo`007_ooool2o`000?oooooo:?ooool2o`0000Wooooo0_l0000Dooooo`007_ooool00ol0
003oooooooooo`3oooooobOooooo0_l00009ooooo`;o00005?ooool001kooooo00?o0000oooooooo
ool0oooooolOooooo`;o00009oooool001kooooo00?o0000ooooooooool0oooooolOooooo`;o0000
9oooool001kooooo00?o0000ooooooooool0Yoooool2o`0009kooooo000Nooooo`03o`000?oooooo
oooo02Cooooo0_l00021ooooo`;o0000W_ooool001kooooo00?o0000ooooooooool09?ooool2o`00
00?ooooo0_l0001booooo`;o0000Z?ooool001kooooo00?o0000ooooooooool01oooool2o`00023o
oooo0_l0001booooo`;o0000Z?ooool001kooooo00?o0000ooooooooool01oooool2o`000?oooooo
3?ooool2o`00037ooooo000Nooooo`03o`000?oooooooooo04gooooo0_l0000@ooooo`;o0000C_oo
ool2o`0006?ooooo0_l0000aooooo`007_ooool00ol0003oooooooooo`0/ooooo`;o00007oooool2
o`00013ooooo0_l0001>ooooo`;o0000U_ooool001kooooo00?o0000ooooooooool0;?ooool2o`00
01Oooooo0_l0002/ooooo`;o00003Oooool2o`0004?ooooo000Nooooo`03o`000?oooooooooo04Go
oooo0_l0000Booooo`;o0000Loooool2o`0002?ooooo0_l0000=ooooo`;o0000@oooool001kooooo
00?o0000ooooooooool0FOooool2o`0007?ooooo0_l0001gooooo`000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003o
ooooooooo`2>ooooo`;o0000[_ooool2o`0000Oooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo
03;ooooo0_l0001Jooooo`;o00006Oooool2o`0007kooooo0_l0000Cooooo`;o00001oooool000?o
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3
o`0001Sooooo1?l0000;ooooo`;o00002Oooool2o`0002;ooooo0ol0001@ooooo`;o0000O_ooool2
o`0000kooooo0_l0000<ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000
oiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo01Sooooo1?l0000;ooooo`;o0000:Ooo
ool2o`0000;ooooo0ol0003Pooooo`;o00003?ooool000?ooooo00Go0000ooooooooooooooooo`00
000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0Zooooo`;o0000
9_ooool2o`0009?ooooo0_l00006ooooo`;o0000E_ooool000?ooooo00Go410@oooooooooooooooo
oa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0:_ooool2o`0003Kooooo
0_l00023ooooo`;o00001_ooool2o`0005Kooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo06;ooooo0ol0001>ooooo`;o0000
2oooool2o`0008Gooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4
o`000?l@4106ooooo`03o`000?oooooooooo03Kooooo0_l0000?ooooo`;o00006_ooool2o`0004ko
oooo0_l0000;ooooo`;o0000D_ooool2o`00037ooooo000Nooooo`03o`000?oooooooooo03Kooooo
0_l0000?ooooo`Co0000AOooool2o`0008;ooooo0_l0000aooooo`007_ooool00ol0003ooooooooo
o`19ooooo`;o0000AOooool2o`000;Gooooo000Nooooo`03o`000?oooooooooo00cooooo0_l0000c
ooooo`;o0000;?ooool2o`0003kooooo0_l0002Fooooo`007_ooool00ol0003oooooooooo`0<oooo
o`;o0000<oooool2o`0002cooooo0_l0000nooooo`;o0000:oooool2o`0006Wooooo000Nooooo`03
o`000?oooooooooo03oooooo0_l0002Kooooo`;o0000JOooool001kooooo00?o0000ooooooooool0
8oooool2o`0000Gooooo0_l0000Cooooo`;o0000ooooool7ooooo`007_ooool00ol0003ooooooooo
o`0Cooooo`;o00003_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000Kooooo`;o0000o_oo
ool001kooooo00?o0000ooooooooool04oooool2o`0001;ooooo0_l0000Nooooo`;o0000o_ooool0
01kooooo00?o0000ooooooooool04Oooool2o`000?oooooo=Oooool001kooooo00?o0000oooooooo
ool01?ooool2o`0000_ooooo0_l0003oooooocGooooo000Nooooo`03o`000?oooooooooo00Cooooo
0_l0000Looooo`;o00008_ooool2o`000?oooooo000Nooooo`;o00008oooool2o`00017ooooo0_l0
000?ooooo`;o00005?ooool2o`0009kooooo0_l00019ooooo`007_ooool00ol0003oooooooooo`0S
ooooo`;o00004?ooool2o`0002Gooooo0_l0002Nooooo`;o0000BOooool001kooooo00?o0000oooo
ooooool07oooool2o`0000;ooooo0_l0000Vooooo`;o00003oooool2o`0005oooooo0_l00028oooo
o`007_ooool00ol0003oooooooooo`0Oooooo`;o0000:_ooool2o`0000Oooooo0_l0001Wooooo`;o
0000R?ooool001kooooo00?o0000ooooooooool0:oooool2o`000004ooooool0003o0000o`00017o
oooo0_l0000@ooooo`;o0000lOooool001kooooo00?o0000ooooooooool03_ooool2o`0001_ooooo
0_l000001?oooooo0000o`000?l00003ooooo`;o00003?ooool2o`0006cooooo0_l0002Eooooo`00
7_ooool00ol0003oooooooooo`0>ooooo`;o00002Oooool2o`0001Wooooo0_l0001Oooooo`;o0000
6Oooool2o`0009Gooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l0000Xooooo`;o0000D?oo
ool2o`000;3ooooo000Nooooo`03o`000?oooooooooo01Gooooo0_l0000/ooooo`;o0000]_ooool2
o`0004[ooooo000Nooooo`03o`000?oooooooooo01Gooooo0_l00003ooooo`;o0000coooool2o`00
00kooooo0_l0001:ooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o00003?ooool2o`0001Co
oooo0_l0002[ooooo`;o0000F_ooool001kooooo00?o0000ooooooooool0:?ooool2o`0001Cooooo
0ol0000booooo`;o0000d_ooool001kooooo00?o0000ooooooooool0?oooool2o`0003;ooooo0_l0
003Booooo`007_ooool00ol0003oooooooooo`0Dooooo`;o0000oooooolbooooo`007_ooool00ol0
003oooooooooo`0Dooooo`;o00001oooool2o`0004Oooooo0_l0003Oooooo`007_ooool00ol0003o
ooooooooo`0Mooooo`;o00004_ooool2o`0001Wooooo0_l0000Hooooo`;o00003_ooool2o`000<oo
oooo000Nooooo`;o0000<_ooool2o`0001Wooooo0_l00007ooooo`;o00002Oooool2o`0001Cooooo
0_l0002;ooooo`;o0000@_ooool001kooooo00?o0000ooooooooool0EOooool2o`0000Wooooo0_l0
000Hooooo`;o0000Qoooool2o`0004;ooooo000Nooooo`03o`000?oooooooooo07[ooooo0_l0003;
ooooo`007_ooool00ol0003oooooooooo`0Rooooo`;o00009_ooool2o`000?_ooooo000Nooooo`03
o`000?oooooooooo01[ooooo0_l00006ooooo`;o00009_ooool2o`000?_ooooo000Nooooo`03o`00
0?oooooooooo01[ooooo0_l000000ooooooo0000o`00000Vooooo`;o00007?ooool2o`000:3ooooo
0_l00010ooooo`007_ooool00ol0003oooooooooo`03ooooo`;o00006?ooool2o`0002Kooooo0_l0
0003ooooo`;o00005oooool2o`000:3ooooo0_l00010ooooo`007_ooool00ol0003oooooooooo`03
ooooo`;o0000@Oooool2o`0000;ooooo0_l00004ooooo`;o0000mOooool001kooooo00?o0000oooo
ooooool08oooool2o`0000?ooooo0_l00004ooooo`;o00005_ooool2o`0000Sooooo0ol00002oooo
o`;o00009?ooool2o`000<[ooooo000Nooooo`03o`000?oooooooooo02?ooooo0_l00003ooooo`;o
00001?ooool2o`0001?ooooo0_l0000<ooooo`;o00000_ooool2o`0000Wooooo0_l0000Iooooo`;o
00001_ooool2o`000<;ooooo000Nooooo`03o`000?oooooooooo03Cooooo0_l0000:ooooo`Go0000
6oooool2o`00027ooooo0_l0000>ooooo`;o0000Y?ooool2o`0000cooooo000Nooooo`03o`000?oo
oooooooo02gooooo0_l00005ooooo`;o00002_ooool3o`0003Kooooo0_l0000Hooooo`;o0000B?oo
ool2o`0005[ooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`0Uooooo`;o00001_ooool2
o`0000Kooooo1_l00003ooooo`;o00001Oooool2o`0001Cooooo0_l0000Hooooo`;o00000_ooool2
o`0006;ooooo0_l0000>ooooo`;o0000F?ooool001kooooo00?o0000ooooooooool06_ooool4o`00
00Oooooo0_l0000>ooooo`Ko00000oooool3o`0000Cooooo0_l00004ooooo`;o00003_ooool2o`00
01Sooooo0_l0001/ooooo`;o00002?ooool2o`0004_ooooo0_l0000;ooooo`007_ooool00ol0003o
ooooooooo`0Jooooo`Co00001_ooool2o`0001Wooooo0_l0000:ooooo`;o00001oooool2o`0007go
oooo0_l0000>ooooo`;o0000EOooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo02Cooooo
0_l00006ooooo`;o00005_ooool2o`0000kooooo0_l0000Aooooo`;o00007Oooool2o`0004_ooooo
0_l0001booooo`007_ooool2o`00017ooooo0_l0000Jooooo`;o00004_ooool2o`0000;ooooo0_l0
000Qooooo`;o00007Oooool2o`0004Oooooo0_l0000kooooo`;o0000>Oooool001kooooo00?o0000
ooooooooool04?ooool2o`0002Cooooo0_l00008ooooo`;o00001_ooool2o`0005oooooo0_l0000T
ooooo`;o0000>oooool2o`0003Wooooo000Nooooo`03o`000?oooooooooo02[ooooo0_l0000:oooo
o`;o00004?ooool3o`0002oooooo0_l0000]ooooo`;o0000G?ooool2o`0003kooooo000Nooooo`03
o`000?oooooooooo02[ooooo0_l00003ooooo`?o00005oooool2o`0002oooooo0_l0001oooooo`;o
00002_ooool2o`0003kooooo000Nooooo`03o`000?oooooooooo02oooooo0ol00039ooooo`;o0000
B_ooool001kooooo00?o0000ooooooooool05_ooool2o`0004Sooooo0_l0003Uooooo`007_ooool0
0ol0003oooooooooo`0Fooooo`;o00000_ooool2o`0001?ooooo0_l00005ooooo`;o00003?ooool2
o`0001[ooooo0_l00004ooooo`;o00007Oooool2o`0001_ooooo0_l0001Fooooo`;o0000Boooool0
01kooooo00?o0000ooooooooool06_ooool2o`0001?ooooo0ol00004ooooo`?o00001Oooool2o`00
00Cooooo0_l0000Kooooo`;o00000oooool2o`0001gooooo0_l0000Kooooo`;o00004_ooool2o`00
017ooooo0_l0000_ooooo`;o0000Boooool001kooooo00?o0000ooooooooool0<?ooool2o`0000Go
oooo0_l00005ooooo`;o00005Oooool2o`0000Sooooo1?l0001Cooooo`;o00004Oooool2o`0007co
oooo000Nooooo`03o`000?oooooooooo02?ooooo0_l0000Iooooo`;o00005Oooool2o`0000Sooooo
0_l0000;ooooo`;o00006?ooool2o`00097ooooo0_l0000/ooooo`007_ooool00ol0003ooooooooo
o`07ooooo`Co00006?ooool3o`00013ooooo0_l0000dooooo`;o00006?ooool2o`00067ooooo0_l0
000^ooooo`;o0000;?ooool001kooooo00?o0000ooooooooool01oooool4o`0001Wooooo0_l0000@
ooooo`;o00006Oooool2o`0009Kooooo0_l0001Looooo`007_ooool00ol0003oooooooooo`1Aoooo
o`;o000000?oooooo`000?l000009Oooool2o`00043ooooo0_l00028ooooo`007_ooool00ol0003o
ooooooooo`0Fooooo`;o00001?ooool2o`0000_ooooo0ol00005ooooo`Co00007oooool2o`0002Go
oooo0_l00010ooooo`;o00007Oooool2o`0006Wooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo
01Kooooo0_l00004ooooo`?o00002_ooool3o`0000Gooooo1?l0000[ooooo`?o00000_ooool2o`00
07Gooooo0_l0000Hooooo`;o0000Coooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool04?ooool2
o`0000_ooooo0_l00002ooooo`;o00009_ooool2o`0001Gooooo0ol00002ooooo`;o0000@oooool2
o`0002Kooooo0_l0000Rooooo`;o0000Coooool000?ooooo00Go410@oooooooooooooooooa0@400;
ooooo`05o`000?ooooooooooooooool000001_ooool3o`00013ooooo0_l0000?ooooo`;o000000?o
ooooo`000?l000008oooool2o`0000kooooo0_l0000:ooooo`;o0000@oooool2o`0002Kooooo0_l0
000dooooo`;o0000?Oooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nH
V9SooooooiRHV?lb<S801_ooool00ol0003oooooooooo`0Tooooo`;o00002Oooool2o`0002Cooooo
0_l00002ooooo`;o00001?ooool3o`0001_ooooo0_l00029ooooo`;o0000?Oooool000?ooooo00Go
0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003o
ooooooooo`0Sooooo`?o00001?ooool2o`0000?ooooo0_l0000Mooooo`;o00001Oooool2o`0000So
oooo0ol00006ooooo`?o00004_ooool2o`0000Gooooo0_l00031ooooo`000oooool01Ol@413ooooo
oooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo
02?ooooo0ol00004ooooo`Go00004Oooool2o`0000;ooooo0_l00008ooooo`;o00001?ooool2o`00
00Sooooo0_l00007ooooo`Ko00005oooool2o`0001Sooooo0_l0002Wooooo`000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooo
oooo02Cooooo0_l00005ooooo`Co00002?ooool2o`0000Kooooo0ol00002ooooo`;o00003?ooool4
o`0000Sooooo0_l00007ooooo`Ko00001_ooool2o`0002Wooooo0_l0002Wooooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oo
oooooooo02;ooooo1?l00005ooooo`;o00000oooool2o`0000Gooooo0_l00006ooooo`;o00004?oo
ool3o`000003ooooool0003o000000Kooooo0_l00004ooooo`;o00001?ooool3o`0000Oooooo1?l0
001;ooooo`;o0000Poooool001kooooo00?o0000ooooooooool06oooool2o`0000Gooooo0_l00007
ooooo`;o00000oooool2o`000003ooooool0003o000000kooooo0_l0000<ooooo`;o00000_ooool2
o`0000;ooooo0_l00002ooooo`;o00001?ooool2o`00013ooooo0_l0000Rooooo`;o00009oooool2
o`0008?ooooo000Nooooo`03o`000?oooooooooo01_ooooo0_l00008ooooo`;o00003?ooool2o`00
00kooooo0_l0000Dooooo`;o0000;?ooool4o`0000kooooo0_l0000Hooooo`;o0000T_ooool001ko
oooo00?o0000ooooooooool07_ooool2o`0000Gooooo0_l00003ooooo`;o00006?ooool2o`0000_o
oooo0_l0000:ooooo`;o00002Oooool2o`0000Kooooo0_l0000Eooooo`Co00006?ooool2o`0000ko
oooo0_l0001Rooooo`;o0000;_ooool001kooooo00?o0000ooooooooool03_ooool2o`0000kooooo
0_l0000:ooooo`;o00002_ooool2o`0000Cooooo1Ol00003ooooo`Co00001Oooool2o`0000;ooooo
0_l0000:ooooo`;o00002Oooool2o`0000Kooooo0_l0000Uooooo`;o000000?oooooo`000?l00000
0oooool2o`0000;ooooo0_l0000gooooo`;o0000>Oooool2o`0002kooooo000Nooooo`03o`000?oo
oooooooo00kooooo1?l0000Mooooo`;o00001Oooool2o`0000;ooooo2ol000000ooooooo0000o`00
0004o`000003ooooool0003o000000Oooooo0_l0000@ooooo`;o00002Oooool2o`0002;ooooo0_l0
00000ooooooo0000o`000003ooooo`;o0000>oooool2o`0000gooooo0_l0001Jooooo`007_ooool0
0ol0003oooooooooo`0@ooooo`;o00003Oooool2o`0000kooooo0_l00009ooooo`;o00001Oooool4
o`0000?ooooo1Ol00006ooooo`Go00005_ooool2o`0000?ooooo0_l0001fooooo`;o0000@?ooool2
o`0001Sooooo000Nooooo`03o`000?oooooooooo00cooooo0_l0000Aooooo`;o00005_ooool6o`00
00;ooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool3o`000004ooooool0003o0000
ooooo`Oo00005_ooool2o`0009Gooooo0_l0000Vooooo`;o00006?ooool001kooooo00?o0000oooo
ooooool03?ooool2o`00013ooooo0_l0000Gooooo`Ko000000?oooooo`000?l000000_l00004oooo
o`;o00000_ooool2o`000005ooooool0003o0000o`000?ooool01ol0000Mooooo`;o00001Oooool2
o`0005Kooooo0_l0000?ooooo`;o00005oooool2o`0000Gooooo0_l0000Iooooo`;o00009Oooool0
01kooooo00?o0000ooooooooool07_ooool2o`0000Gooooo0_l00003ooooo`Co000000?oooooo`00
0?l000000_ooool5o`0000?ooooo0_l000000ooooooo0000o`000002o`0000Oooooo0_l00002oooo
o`go00001_ooool2o`0001?ooooo0_l00005ooooo`;o00001_ooool2o`0004kooooo0_l0000?oooo
o`;o00005oooool2o`00023ooooo0_l0000>ooooo`;o00001Oooool2o`0000kooooo000Nooooo`03
o`000?oooooooooo00?ooooo0_l0000Dooooo`;o00000oooool2o`0000Gooooo0_l00003ooooo`Co
000000?oooooo`000?l000000_ooool5o`0000?ooooo1?l00002ooooo`Co000000?oooooo`000?l0
00000ol00002ooooo`Oo00000_ooool6o`0000Cooooo0_l0000Rooooo`;o0000Z_ooool2o`000003
ooooool0003o000000;ooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`03ooooo`;o0000
5?ooool4o`000003ooooool0003o000000?ooooo1?l0000Fooooo`So000000?oooooo`000?l00000
0_l00003ooooo`Oo000000?oooooo`000?l000000_l000001Ooooooo0000o`000?l0003ooooo00;o
00004_ooool2o`0000Sooooo0_l0002eooooo`;o00004_ooool001kooooo0_l0000Jooooo`Co0000
1_ooool5o`0000[ooooo0_l0000;ooooo`?o00001?ooool3o`000004ooooool0003o0000ooooo`;o
00001?ooool6o`0000;ooooo0_l000000ooooooo0000o`00000Booooo`;o00002?ooool2o`000<Wo
oooo000Nooooo`03o`000?oooooooooo01Wooooo0_l00004ooooo`;o00000_ooool2o`000003oooo
ool0003o000000;ooooo1?l00004ooooo`;o00002oooool3o`0000;ooooo1?l00002ooooo`;o0000
1_ooool7o`0000;ooooo0ol0000_ooooo`;o0000<?ooool2o`0008Kooooo000Nooooo`03o`000?oo
oooooooo01oooooo1?l000000ooooooo0000o`000004ooooo`Co00004oooool2o`000004ooooool0
003o0000o`0000;ooooo1?l00005ooooo`So00000_ooool2o`0000;ooooo0_l00003ooooo`;o0000
0oooool2o`0000Cooooo0_l00005ooooo`Co00004_ooool2o`00033ooooo0_l00026ooooo`007_oo
ool00ol0003oooooooooo`0Booooo`;o00001Oooool2o`0000Kooooo0_l000000ooooooo0000o`00
0008ooooo`;o00002?ooool2o`0000?ooooo0_l00002ooooo`Go00000oooool7o`0000Kooooo1?l0
0006ooooo`;o00000oooool2o`0000?ooooo0_l00004ooooo`;o00001Oooool4o`0001Gooooo0_l0
002eooooo`007_ooool00ol0003oooooooooo`0Booooo`;o00001Oooool2o`0000Wooooo0_l00007
ooooo`?o00002?ooool2o`0000?ooooo1?l000000ooooooo0000o`000002o`0000Kooooo1_l00003
ooooo`?o00005Oooool2o`0000Kooooo0_l0000Iooooo`;o0000ZOooool2o`0000[ooooo000Noooo
o`03o`000?oooooooooo02Cooooo0_l00007ooooo`?o00000_ooool2o`0000?ooooo0_l00004oooo
o`Co000000?oooooo`000?l000000ol000000ooooooo0000o`000004ooooo`Co00000oooool2o`00
0003ooooool0003o000001?ooooo0_l00006ooooo`;o0000a?ooool4o`0000Sooooo000Nooooo`03
o`000?oooooooooo01kooooo0_l00007ooooo`;o000000?oooooo`000?l000000_ooool2o`000004
ooooool0003o0000o`0000?ooooo0_l00004ooooo`Co000000Coooooo`000?l0003ooooo0_l00000
1?oooooo0000o`000?l0000:ooooo`;o000000?oooooo`000?l000004oooool2o`0000gooooo0_l0
002oooooo`;o00000_ooool2o`0000Cooooo000Nooooo`03o`000?oooooooooo017ooooo0_l00007
ooooo`;o00000_ooool2o`0000Oooooo0_l000000ooooooo0000o`000002ooooo`Ko00001_ooool2
o`0000;ooooo1?l00004ooooo`Ko00001?ooool7o`0002Gooooo0_l0000nooooo`?o0000POooool3
o`0000Cooooo000Nooooo`;o00004_ooool2o`0000Oooooo0_l0000Booooo`?o00002Oooool2o`00
00;ooooo1?l00004ooooo`?o000000Coooooo`000?l0003o00000oooool9o`0000Cooooo0_l00008
ooooo`;o00002oooool2o`0001Wooooo0_l0000[ooooo`?o00004?ooool2o`0006oooooo0_l00005
ooooo`007_ooool2o`0000Oooooo0_l0000Wooooo`;o00003_ooool2o`0000[ooooo0_l00004oooo
o`;o00000_ooool4o`0000?ooooo0ol00008ooooo`;o00000_ooool3o`0000?ooooo0_l000001?oo
oooo0000o`000?l0000Hooooo`;o0000?_ooool2o`0001oooooo0_l0000eooooo`;o00007_ooool0
01kooooo00?o0000ooooooooool01_ooool2o`0002Cooooo0_l00006ooooo`;o000000?oooooo`00
0?l000001?ooool4o`0000[ooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0ol00000
1?oooooo0000o`000?ooool2o`0000Kooooo0_l00005ooooo`?o00000oooool2o`0000;ooooo0_l0
000Xooooo`;o0000Coooool2o`0003Gooooo0_l0000Nooooo`007_ooool00ol0003oooooooooo`0C
ooooo`Co00001_ooool2o`000003ooooool0003o000000[ooooo0_l00003ooooo`;o000000Cooooo
o`000?l0003ooooo0ol00003ooooo`;o00002oooool3o`000003ooooool0003o000000;ooooo0_l0
0003ooooo`Co000000Coooooo`000?l0003o00001Oooool3o`0000Kooooo0_l0000`ooooo`;o0000
Y_ooool001kooooo00?o0000ooooooooool04oooool4o`0000Kooooo0_l000000ooooooo0000o`00
0003ooooo`;o00002_ooool2o`0000Gooooo1?l000000ooooooo0000o`000007ooooo`?o000000?o
ooooo`000?l000001?l00002ooooo`;o00000oooool2o`0000Cooooo0_l00006ooooo`;o00001_oo
ool2o`000=Sooooo000Nooooo`03o`000?oooooooooo02Gooooo0_l00002ooooo`;o00003oooool2
o`0000[ooooo2_l00002ooooo`?o00000_ooool2o`0000Gooooo0_l00004ooooo`Co00000_ooool2
o`0002Gooooo0_l0002Booooo`;o00008?ooool001kooooo00?o0000ooooooooool02Oooool2o`00
01kooooo0ol00006ooooo`;o00002Oooool2o`0000Wooooo0_l000000ooooooo0000o`000003oooo
o`Go00000_ooool5o`0000;ooooo0ol00003ooooo`Co00000_ooool2o`0000_ooooo0_l0000Hoooo
o`;o0000T_ooool2o`00023ooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0000Oooooo`;o
00001_ooool2o`0000Sooooo0ol00003ooooo`?o000000?oooooo`000?l000000oooool2o`0000?o
oooo0_l00002ooooo`?o000000?oooooo`000?l000001?l000000ooooooo0000o`000003ooooo`;o
00001?ooool2o`0000_ooooo0_l0000Iooooo`;o0000W?ooool2o`0001Gooooo000Nooooo`;o0000
??ooool3o`000004ooooool0003o0000ooooo`?o000000?oooooo`000?l000003?ooool3o`000003
ooooool0003o000000So00000_ooool2o`0002cooooo0_l0000Yooooo`;o0000LOooool2o`0001Go
oooo000Nooooo`03o`000?oooooooooo02Kooooo0_l00002ooooo`;o00003oooool2o`0000;ooooo
0_l0000Cooooo`;o00000_ooool4o`000003ooooool0003o000000?o00005oooool2o`0000?ooooo
0_l0000mooooo`;o0000R?ooool001kooooo00?o0000ooooooooool09?ooool4o`0000;ooooo0_l0
000?ooooo`;o00002Oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`000003ooooool0
003o000000Co00000_ooool2o`0001Wooooo0_l00003ooooo`;o0000aoooool001kooooo00?o0000
ooooooooool09?ooool2o`0000Wooooo0_l00007ooooo`;o00003?ooool2o`0000;ooooo0_l00003
ooooo`;o00000_ooool7o`0000?ooooo1Ol0000Booooo`;o00006_ooool2o`000;Gooooo000Noooo
o`03o`000?oooooooooo01Gooooo0_l0000<ooooo`;o00002_ooool3o`0000Kooooo0_l0000Doooo
o`;o00001?ooool2o`0000Oooooo0_l000000ooooooo0000o`000003ooooo`Go00002_ooool2o`00
01[ooooo0_l0002eooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o00001_ooool3o`0000?o
oooo0_l0000:ooooo`?o00003Oooool2o`0000?ooooo0_l00008ooooo`;o00001_ooool2o`0000So
oooo0_l00003ooooo`Oo00001?ooool2o`0002Oooooo0_l0002Jooooo`;o00004?ooool001kooooo
00?o0000ooooooooool07Oooool3o`000003ooooool0003o000001cooooo0_l00003ooooo`;o0000
0oooool2o`0000_ooooo0_l00008ooooo`;o00002?ooool2o`0000Cooooo0_l0000Oooooo`;o0000
1_ooool2o`0009[ooooo0_l0000@ooooo`007_ooool00ol0003oooooooooo`0Qooooo`;o000000?o
ooooo`000?l000001oooool2o`0001Kooooo0_l00002ooooo`;o00007Oooool5o`00017ooooo0_l0
000Aooooo`;o0000]?ooool001kooooo00?o0000ooooooooool09?ooool2o`0000Oooooo0_l00008
ooooo`;o00000oooool2o`000003ooooool0003o000000Cooooo0_l0000?ooooo`;o00001_ooool2
o`0000Oooooo0ol000000ooooooo0000o`00000Aooooo`;o0000aoooool001kooooo00?o0000oooo
ooooool05?ooool2o`0001;ooooo0_l0000=ooooo`;o00000oooool2o`000003ooooool0003o0000
00;ooooo0_l00005ooooo`;o00002_ooool2o`000003ooooool0003o000000?ooooo0_l00003oooo
o`;o00000_ooool2o`0000;ooooo0_l0000?ooooo`;o0000Hoooool2o`0005Kooooo0_l000000ooo
oooo0000o`000009ooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o00001Oooool2o`00017o
oooo0ol0000:ooooo`;o00003Oooool2o`0000Gooooo0_l0000;ooooo`Co00002?ooool2o`0000Go
oooo1Ol000000ooooooo0000o`00000:ooooo`;o00007_ooool2o`0004?ooooo0_l0001Fooooo`;o
000000?oooooo`000?l000002Oooool001kooooo00?o0000ooooooooool03Oooool2o`0001Sooooo
0_l0000;ooooo`;o00003Oooool2o`0001;ooooo1?l00009ooooo`Co00000_ooool5o`000003oooo
ool0003o000000?ooooo0_l0000Uooooo`;o0000ZOooool001kooooo00?o0000ooooooooool0>Ooo
ool2o`0000Sooooo0_l00003ooooo`;o00003?ooool2o`000003ooooool0003o000000Sooooo1Ol0
0003ooooo`;o00000oooool2o`0000?ooooo0ol00036ooooo`;o00001oooool001gooooo0_l0000k
ooooo`;o00002Oooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000Oooooo0_l00000
0ooooooo0000o`000002o`0000Kooooo0_l00006ooooo`;o00000oooool2o`0000Cooooo0_l0000E
ooooo`;o0000[oooool2o`0000Oooooo000Mooooo`;o0000A_ooool2o`0000Cooooo1Ol00004oooo
o`;o00001_ooool2o`00013ooooo0_l00002ooooo`;o00003oooool2o`0000?ooooo0_l00004oooo
o`;o0000^?ooool001kooooo00?o0000ooooooooool01oooool2o`0001Sooooo0_l0000>ooooo`;o
00005Oooool4o`000003ooooool0003o000000Cooooo0_l00006ooooo`;o000000?oooooo`000?l0
00003Oooool2o`0000;ooooo0_l0000?ooooo`;o00000oooool2o`0001Cooooo0_l0000?ooooo`;o
0000Uoooool001kooooo0_l00008ooooo`;o00006?ooool2o`0000kooooo0_l0000Aooooo`;o0000
0_ooool2o`0000?ooooo0_l00006ooooo`;o00001?ooool2o`000003ooooool0003o000000cooooo
0_l000000ooooooo0000o`00000>ooooo`;o00001_ooool2o`0001Cooooo0_l0000?ooooo`;o0000
Aoooool2o`00027ooooo0_l0000[ooooo`007_ooool2o`0003cooooo0_l00007ooooo`;o00003ooo
ool4o`000003ooooool0003o0000013ooooo0_l000000ooooooo0000o`00000>ooooo`;o00000_oo
ool2o`0002oooooo0_l00006ooooo`;o0000>Oooool2o`00027ooooo0_l0000[ooooo`007_ooool2
o`0003cooooo0_l0000<ooooo`;o00001_ooool2o`0000Cooooo0_l000000ooooooo0000o`00000@
ooooo`Co00004oooool2o`0002oooooo0_l00006ooooo`;o0000<Oooool2o`0005Kooooo000Noooo
o`03o`000?oooooooooo03[ooooo0_l00009ooooo`;o00000_ooool2o`0000Kooooo0_l0000;oooo
o`;o00001Oooool2o`000003ooooool0003o000000;ooooo1?l0000Cooooo`;o0000J_ooool2o`00
01[ooooo0_l0000jooooo`007_ooool00ol0003oooooooooo`0Zooooo`;o00003_ooool2o`0000Wo
oooo0_l0000Fooooo`?o00001Oooool2o`000004ooooool0003o0000ooooo`;o0000W_ooool2o`00
03[ooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0000Uooooo`;o0000<Oooool2o`0000?o
oooo0_l00002ooooo`;o00000oooool2o`0002Oooooo0_l0002aooooo`007_ooool00ol0003ooooo
ooooo`03ooooo`;o00001_ooool2o`0002[ooooo1?l0000:ooooo`;o00006oooool3o`000003oooo
ool0003o000002cooooo0_l0002aooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o0000:_oo
ool4o`0000Sooooo1?l0000Kooooo`?o00003Oooool2o`0000gooooo0_l0000Aooooo`;o0000/Ooo
ool001kooooo00?o0000ooooooooool0<?ooool2o`00017ooooo0_l000000ooooooo0000o`000008
ooooo`;o00008?ooool4o`0000_ooooo0_l0000jooooo`;o0000R?ooool001kooooo00?o0000oooo
ooooool09Oooool2o`0000Kooooo0_l000000ooooooo0000o`00000Booooo`Co00002?ooool2o`00
00Gooooo0_l0000>ooooo`;o000000?oooooo`000?l000002?ooool2o`0000Wooooo0ol0000@oooo
o`;o0000:Oooool2o`0008Sooooo000Nooooo`?o00006oooool2o`0000Sooooo0ol00005ooooo`;o
000000?oooooo`000?l000004_ooool2o`00017ooooo1?l0000<ooooo`;o000000?oooooo`000?l0
00004oooool3o`00013ooooo0_l0002cooooo`007_ooool3o`0001_ooooo0_l00008ooooo`?o0000
2?ooool2o`0001Wooooo0_l0000<ooooo`;o00004?ooool2o`0001;ooooo0_l00021ooooo`;o0000
@oooool001kooooo00?o0000ooooooooool05?ooool2o`0000oooooo0_l0000Tooooo`;o00007_oo
ool2o`0001;ooooo0_l00021ooooo`;o0000@oooool001kooooo00?o0000ooooooooool05?ooool2
o`0000oooooo0_l0000[ooooo`;o00001_ooool2o`0002Cooooo0_l00035ooooo`005?ooool4o`00
0003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool09_ooool2o`0001_ooooo0_l0000=oooo
o`;o00001_ooool2o`0001kooooo0_l00004ooooo`;o0000aOooool001Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Vooooo`;o00006oooool2o`0001?ooooo1?l0000Nooooo`;o
0000boooool001Kooooo00?o0000ooooooooool01Oooool3o`0003oooooo0_l0000Gooooo`Co0000
5_ooool2o`000=?ooooo000Fooooo`03o`000?oooooooooo04Oooooo0_l0000aooooo`;o0000dooo
ool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooo
oe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Cooooo00?oEEEEofIVI_l00000
oooooomBooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.25301 .91046 Mdot
.1024 .69084 Mdot
.15182 .8295 Mdot
.19498 .89348 Mdot
.27695 .96947 Mdot
.20922 .88092 Mdot
.54714 .45024 Mdot
.31419 .90345 Mdot
.22922 .88472 Mdot
.26823 .45271 Mdot
.24376 .01712 Mdot
.13466 .0015 Mdot
.21809 .86945 Mdot
.40854 .88902 Mdot
.23365 .86551 Mdot
.08884 .21576 Mdot
.04894 .16328 Mdot
.10844 .85487 Mdot
.23102 .89699 Mdot
.22965 .91834 Mdot
.82414 .08824 Mdot
.22642 .87618 Mdot
.19745 .76031 Mdot
.07274 .13837 Mdot
.28144 .90006 Mdot
.34854 .88524 Mdot
.23436 .8299 Mdot
.29522 .56471 Mdot
.20808 .02432 Mdot
.1869 .82124 Mdot
.10279 .84863 Mdot
.23143 .87451 Mdot
.37006 .83863 Mdot
.87123 .86395 Mdot
.18617 .08124 Mdot
.26583 .99735 Mdot
.03886 .89657 Mdot
.75866 .87287 Mdot
.1147 .94141 Mdot
.25747 .85525 Mdot
.11122 .83393 Mdot
.30786 .97533 Mdot
.16686 .74319 Mdot
.47172 .01562 Mdot
.51271 .1232 Mdot
.24887 .9593 Mdot
.68262 .19521 Mdot
.21436 .7817 Mdot
.30431 .95445 Mdot
.11519 .62533 Mdot
.02566 .79829 Mdot
.10516 .82645 Mdot
.29953 .91863 Mdot
.24452 .02652 Mdot
.24047 .89209 Mdot
.97357 .19383 Mdot
.11847 .88367 Mdot
.26875 .90255 Mdot
.23541 .82885 Mdot
.49141 .92495 Mdot
.19687 .8309 Mdot
.32017 .89924 Mdot
.76172 .02833 Mdot
.31472 .92474 Mdot
.21544 .92226 Mdot
.19902 .91136 Mdot
.0913 .83505 Mdot
.23625 .82841 Mdot
.20597 .88725 Mdot
.68451 .81626 Mdot
.93151 .12701 Mdot
.22314 .95172 Mdot
.52165 .79565 Mdot
.21307 .25514 Mdot
.28127 .90297 Mdot
.18453 .84084 Mdot
.2154 .71771 Mdot
.66432 .34085 Mdot
.22317 .85367 Mdot
.25271 .83013 Mdot
.23112 .87065 Mdot
.71131 .93725 Mdot
.24356 .11419 Mdot
.31487 .90315 Mdot
.18685 .92054 Mdot
.14351 .10328 Mdot
.32167 .93145 Mdot
.24251 .82705 Mdot
.22285 .87926 Mdot
.2819 .91769 Mdot
.34592 .99383 Mdot
.13201 .06377 Mdot
.18388 .00118 Mdot
.0772 .99476 Mdot
.41006 .8878 Mdot
.1855 .93219 Mdot
.24255 .6667 Mdot
.20702 .04987 Mdot
.31916 .98014 Mdot
.20882 .53116 Mdot
.28951 .86186 Mdot
.08199 .78654 Mdot
.46791 .8232 Mdot
.06038 .6433 Mdot
.0213 .705 Mdot
.20575 .77496 Mdot
.03336 .30897 Mdot
.05047 .31639 Mdot
.12456 .7101 Mdot
.87854 .12943 Mdot
.01535 .85281 Mdot
.25838 .89109 Mdot
.32509 .8483 Mdot
.10421 .87003 Mdot
.4247 .26744 Mdot
.45002 .36701 Mdot
.35593 .01383 Mdot
.21193 .84852 Mdot
.92382 .59072 Mdot
.2877 .89985 Mdot
.25743 .82629 Mdot
.16066 .67155 Mdot
.3213 .79424 Mdot
.82691 .86013 Mdot
.56567 .62045 Mdot
.48419 .7325 Mdot
.00283 .89098 Mdot
.23368 .89164 Mdot
.9644 .92645 Mdot
.44009 .68821 Mdot
.02043 .76196 Mdot
.65811 .39307 Mdot
.19101 .78067 Mdot
.16492 .76857 Mdot
.10621 .83629 Mdot
.06898 .81633 Mdot
.1992 .77843 Mdot
.09383 .75606 Mdot
.10554 .89254 Mdot
.1894 .90026 Mdot
.18318 .87738 Mdot
.33323 .94065 Mdot
.29719 .84993 Mdot
.33391 .91507 Mdot
.62136 .89836 Mdot
.1347 .03162 Mdot
.31554 .83681 Mdot
.26578 .83728 Mdot
.60035 .83334 Mdot
.05171 .23618 Mdot
.38083 .97188 Mdot
.33847 .8114 Mdot
.14075 .98813 Mdot
.24106 .91514 Mdot
.23545 .85498 Mdot
.26629 .88197 Mdot
.16941 .78383 Mdot
.37393 .37085 Mdot
.21199 .86892 Mdot
.12271 .15098 Mdot
.11729 .72052 Mdot
.30478 .11591 Mdot
.68501 .12915 Mdot
.2162 .7371 Mdot
.31752 .98641 Mdot
.27815 .9482 Mdot
.27225 .83639 Mdot
.20948 .84182 Mdot
.43708 .10641 Mdot
.20513 .84458 Mdot
.31827 .78915 Mdot
.37379 .01558 Mdot
.21601 .09635 Mdot
.92185 .96156 Mdot
.33687 .93584 Mdot
.1889 .9407 Mdot
.17593 .1744 Mdot
.33206 .8758 Mdot
.54684 .55771 Mdot
.10492 .86222 Mdot
.23687 .82806 Mdot
.21981 .00133 Mdot
.29409 .02621 Mdot
.57287 .09057 Mdot
.11439 .35973 Mdot
.14596 .74069 Mdot
.23761 .83513 Mdot
.35592 .98665 Mdot
.38698 .08854 Mdot
.42937 .98884 Mdot
.30052 .91757 Mdot
.99439 .10651 Mdot
.22934 .89201 Mdot
.97023 .88096 Mdot
.31154 .99287 Mdot
.25916 .81838 Mdot
.30221 .1227 Mdot
.16275 .94445 Mdot
.24283 .88797 Mdot
.33235 .82801 Mdot
.64086 .86761 Mdot
.15479 .72845 Mdot
.13549 .7858 Mdot
.30162 .03387 Mdot
.28745 .90383 Mdot
.23854 .83139 Mdot
.49252 .72457 Mdot
.24167 .81238 Mdot
.3677 .97671 Mdot
.22999 .92261 Mdot
.22666 .9085 Mdot
.23265 .88025 Mdot
.77007 .02165 Mdot
.15832 .78308 Mdot
.10762 .74282 Mdot
.23272 .62697 Mdot
.26044 .84654 Mdot
.39768 .22773 Mdot
.29204 .58385 Mdot
.36485 .0263 Mdot
.47645 .70053 Mdot
.46197 .94697 Mdot
.35008 .96317 Mdot
.20067 .84845 Mdot
.36771 .94351 Mdot
.17842 .88685 Mdot
.49091 .70899 Mdot
.15109 .75266 Mdot
.34938 .55594 Mdot
.26143 .87554 Mdot
.3158 .88268 Mdot
.47219 .93338 Mdot
.32157 .82108 Mdot
.96893 .14055 Mdot
.14694 .92588 Mdot
.24316 .99807 Mdot
.92917 .59882 Mdot
.13331 .83387 Mdot
.8613 .50936 Mdot
.07149 .54624 Mdot
.17392 .94645 Mdot
.3063 .83061 Mdot
.10882 .67181 Mdot
.25034 .79837 Mdot
.12624 .97094 Mdot
.29902 .78804 Mdot
.41299 .02517 Mdot
.28421 .80643 Mdot
.63824 .50599 Mdot
.12072 .81038 Mdot
.09304 .78854 Mdot
.22751 .87294 Mdot
.48487 .41978 Mdot
.85251 .74519 Mdot
.49918 .73002 Mdot
.23871 .65057 Mdot
.30241 .93223 Mdot
.73878 .65577 Mdot
.15319 .83535 Mdot
.16175 .9544 Mdot
.22961 .88753 Mdot
.12747 .90156 Mdot
.29396 .42263 Mdot
.74503 .82559 Mdot
.31316 .8304 Mdot
.54985 .71252 Mdot
.23327 .71841 Mdot
.82061 .62496 Mdot
.1621 .82914 Mdot
.24188 .83623 Mdot
.32103 .98145 Mdot
.92891 .57655 Mdot
.19109 .82743 Mdot
.1408 .88011 Mdot
.28283 .93421 Mdot
.21426 .84677 Mdot
.22908 .57607 Mdot
.54796 .62054 Mdot
.26627 .02479 Mdot
.07738 .74278 Mdot
.9808 .94504 Mdot
.24359 .85685 Mdot
.2406 .70942 Mdot
.14604 .96705 Mdot
.2896 .95264 Mdot
.34595 .95781 Mdot
.17992 .84515 Mdot
.22436 .63064 Mdot
.26023 .63845 Mdot
.10076 .71355 Mdot
.14302 .63702 Mdot
.4069 .82838 Mdot
.19549 .87835 Mdot
.23791 .81361 Mdot
.65195 .89433 Mdot
.36713 .80083 Mdot
.24556 .8875 Mdot
.31713 .60449 Mdot
.86415 .84657 Mdot
.4397 .85143 Mdot
.96661 .57047 Mdot
.34978 .93288 Mdot
.25405 .13566 Mdot
.28595 .05771 Mdot
.76238 .97518 Mdot
.17623 .69483 Mdot
.22988 .83301 Mdot
.23213 .83826 Mdot
.06916 .84022 Mdot
.08183 .66231 Mdot
.24671 .81641 Mdot
.01728 .77457 Mdot
.34605 .88211 Mdot
.44749 .01064 Mdot
.28349 .95441 Mdot
.32075 .7628 Mdot
.15446 .07385 Mdot
.48937 .86617 Mdot
.40346 .86648 Mdot
.4158 .72846 Mdot
.11298 .89667 Mdot
.35602 .81786 Mdot
.11743 .73769 Mdot
.22775 .11247 Mdot
.09159 .86315 Mdot
.30474 .88207 Mdot
.27024 .02151 Mdot
.25647 .87692 Mdot
.10619 .94631 Mdot
.32229 .89132 Mdot
.28828 .94827 Mdot
.19751 .89627 Mdot
.49482 .44467 Mdot
.09959 .85902 Mdot
.10115 .25961 Mdot
.20875 .40399 Mdot
.26993 .01311 Mdot
.24296 .82877 Mdot
.05374 .35866 Mdot
.76695 .06302 Mdot
.32394 .98298 Mdot
.1583 .72244 Mdot
.21129 .87513 Mdot
.29496 .04545 Mdot
.00911 .4237 Mdot
.36673 .80018 Mdot
.58942 .99205 Mdot
.32552 .91971 Mdot
.03072 .65211 Mdot
.31283 .90628 Mdot
.19145 .83423 Mdot
.27615 .91972 Mdot
.36031 .09784 Mdot
.16977 .88173 Mdot
.3305 .94427 Mdot
.19789 .82364 Mdot
.22491 .97236 Mdot
.22829 .72001 Mdot
.21434 .88841 Mdot
.51433 .02814 Mdot
.26371 .83863 Mdot
.34646 .88945 Mdot
.10646 .84749 Mdot
.22408 .89083 Mdot
.35342 .95761 Mdot
.14731 .86484 Mdot
.05258 .09334 Mdot
.23419 .71325 Mdot
.26996 .89476 Mdot
.1774 .86647 Mdot
.07212 .68596 Mdot
.2244 .8361 Mdot
.15245 .81037 Mdot
.2209 .90149 Mdot
.98743 .87565 Mdot
.13358 .44473 Mdot
.54938 .16185 Mdot
.28211 .91987 Mdot
.60852 .26061 Mdot
.23444 .79751 Mdot
.22038 .85856 Mdot
.27595 .96399 Mdot
.03745 .63558 Mdot
.18647 .11056 Mdot
.30734 .64451 Mdot
.97156 .80091 Mdot
.08857 .79997 Mdot
.9202 .35899 Mdot
.23841 .83005 Mdot
.19492 .80852 Mdot
.18559 .87705 Mdot
.20463 .93777 Mdot
.29534 .8438 Mdot
.27116 .95115 Mdot
.27387 .96465 Mdot
.38535 .10228 Mdot
.24936 .25212 Mdot
.65128 .81128 Mdot
.23793 .8249 Mdot
.09886 .86489 Mdot
.09845 .78403 Mdot
.39019 .06501 Mdot
.44761 .28082 Mdot
.31716 .90116 Mdot
.08895 .82936 Mdot
.21587 .26409 Mdot
.10288 .6686 Mdot
.26716 .94042 Mdot
.2476 .08828 Mdot
.21673 .74158 Mdot
.06873 .72051 Mdot
.2295 .86289 Mdot
.10529 .73327 Mdot
.59068 .01686 Mdot
.91165 .99666 Mdot
.14758 .8416 Mdot
.44836 .7735 Mdot
.16817 .85766 Mdot
.37662 .9349 Mdot
.2259 .85132 Mdot
.23302 .83782 Mdot
.71239 .49234 Mdot
.81346 .76744 Mdot
.18825 .91657 Mdot
.2901 .90188 Mdot
.0018 .07225 Mdot
.63865 .61906 Mdot
.23809 .89002 Mdot
.26375 .99512 Mdot
.03252 .9595 Mdot
.08982 .18477 Mdot
.70269 .204 Mdot
.50208 .57217 Mdot
.28597 .96065 Mdot
.04282 .74161 Mdot
.39413 .7644 Mdot
.26689 .62397 Mdot
.29444 .02002 Mdot
.27068 .73444 Mdot
.49851 .11389 Mdot
.24967 .7026 Mdot
.80291 .39735 Mdot
.54056 .39534 Mdot
.20734 .82335 Mdot
.33403 .12626 Mdot
.23696 .81656 Mdot
.37368 .83747 Mdot
.23424 .95765 Mdot
.80445 .55588 Mdot
.24214 .73076 Mdot
.21058 .54399 Mdot
.12546 .68083 Mdot
.32979 .97943 Mdot
.2134 .85265 Mdot
.36888 .7579 Mdot
.24372 .81805 Mdot
.25703 .88718 Mdot
.26059 .02867 Mdot
.03125 .01795 Mdot
.42178 .34456 Mdot
.16339 .94791 Mdot
.2356 .81511 Mdot
.21729 .85982 Mdot
.25719 .86536 Mdot
.96754 .03207 Mdot
.2215 .07685 Mdot
.36599 .8306 Mdot
.48331 .10513 Mdot
.21993 .834 Mdot
.24423 .92787 Mdot
.18337 .85442 Mdot
.32696 .91521 Mdot
.31669 .90128 Mdot
.31566 .90228 Mdot
.15793 .9178 Mdot
.23048 .86962 Mdot
.16866 .92621 Mdot
.30186 .90292 Mdot
.05542 .44193 Mdot
.18125 .8712 Mdot
.17745 .58852 Mdot
.02549 .97229 Mdot
.28013 .84923 Mdot
.16967 .87634 Mdot
.25382 .90414 Mdot
.5051 .73672 Mdot
.09942 .66409 Mdot
.28391 .49848 Mdot
.44071 .99763 Mdot
.25523 .58736 Mdot
.14716 .81043 Mdot
.21186 .84675 Mdot
.40471 .33774 Mdot
.11128 .81876 Mdot
.34395 .96267 Mdot
.1651 .93022 Mdot
.39464 .84074 Mdot
.37033 .87281 Mdot
.79951 .79763 Mdot
.18001 .09046 Mdot
.38441 .75765 Mdot
.37535 .64695 Mdot
.37092 .06465 Mdot
.17052 .89482 Mdot
.13803 .85292 Mdot
.42437 .87851 Mdot
.32977 .90625 Mdot
.46974 .63367 Mdot
.24954 .87815 Mdot
.18261 .82454 Mdot
.11984 .8615 Mdot
.16314 .78225 Mdot
.20731 .06138 Mdot
.17226 .54968 Mdot
.29034 .96095 Mdot
.03586 .8955 Mdot
.23913 .78092 Mdot
.18868 .97955 Mdot
.31052 .39494 Mdot
.09609 .87396 Mdot
.2064 .72786 Mdot
.18964 .89166 Mdot
.22097 .85573 Mdot
.32045 .81672 Mdot
.19503 .65174 Mdot
.70295 .75897 Mdot
.36189 .13607 Mdot
.99335 .35389 Mdot
.40245 .05226 Mdot
.15951 .098 Mdot
.75398 .43954 Mdot
.74708 .07837 Mdot
.28761 .96053 Mdot
.04077 .89923 Mdot
.31229 .90382 Mdot
.27725 .86094 Mdot
.21047 .93171 Mdot
.35856 .9036 Mdot
.60485 .81362 Mdot
.61557 .93175 Mdot
.1892 .90052 Mdot
.0016 .82819 Mdot
.15394 .02638 Mdot
.23147 .86225 Mdot
.12267 .8541 Mdot
.27457 .73017 Mdot
.82491 .49541 Mdot
.18984 .77059 Mdot
.22444 .74257 Mdot
.30298 .88723 Mdot
.66421 .9153 Mdot
.59487 .03749 Mdot
.3694 .86321 Mdot
.95322 .83348 Mdot
.1632 .73814 Mdot
.4767 .66715 Mdot
.30412 .49219 Mdot
.24979 .82809 Mdot
.26637 .01001 Mdot
.77777 .17646 Mdot
.21855 .75197 Mdot
.37303 .88105 Mdot
.76116 .82769 Mdot
.3107 .57507 Mdot
.16916 .85157 Mdot
.29181 .99037 Mdot
.12394 .69394 Mdot
.33989 .97142 Mdot
.56793 .97141 Mdot
.22161 .87996 Mdot
.43557 .75308 Mdot
.11023 .60898 Mdot
.22961 .87256 Mdot
.28959 .85278 Mdot
.19845 .92649 Mdot
.28492 .87148 Mdot
.34736 .07845 Mdot
.21074 .02014 Mdot
.21302 .85517 Mdot
.27218 .81537 Mdot
.59024 .38149 Mdot
.78265 .7022 Mdot
.15123 .9631 Mdot
.14824 .8721 Mdot
.7787 .78123 Mdot
.2532 .89102 Mdot
.1939 .71054 Mdot
.36605 .24212 Mdot
.15221 .62195 Mdot
.4207 .86312 Mdot
.29399 .90119 Mdot
.23113 .90228 Mdot
.26905 .06744 Mdot
.36059 .83978 Mdot
.10313 .01668 Mdot
.33941 .88246 Mdot
.2432 .79175 Mdot
.30703 .89439 Mdot
.26385 .93604 Mdot
.26842 .87036 Mdot
.30934 .84813 Mdot
.22275 .83679 Mdot
.15303 .80459 Mdot
.21357 .06426 Mdot
.44647 .18502 Mdot
.22898 .72292 Mdot
.25252 .83211 Mdot
.22572 .84517 Mdot
.36834 .91795 Mdot
.24096 .89813 Mdot
.46885 .14873 Mdot
.0937 .13946 Mdot
.17695 .86691 Mdot
.3479 .98269 Mdot
.2367 .90693 Mdot
.17549 .1128 Mdot
.21788 .94103 Mdot
.5011 .75071 Mdot
.31663 .95416 Mdot
.64741 .52948 Mdot
.43795 .65225 Mdot
.40076 .80715 Mdot
.24854 .89934 Mdot
.0474 .70915 Mdot
.3634 .11035 Mdot
.27464 .69727 Mdot
.9773 .25506 Mdot
.39248 .91779 Mdot
.17048 .81023 Mdot
.09245 .88451 Mdot
.1052 .92699 Mdot
.20031 .84797 Mdot
.4771 .89135 Mdot
.65506 .81619 Mdot
.2287 .87316 Mdot
.74721 .18317 Mdot
.31373 .90359 Mdot
.2387 .03853 Mdot
.23541 .96206 Mdot
.22651 .86832 Mdot
.9953 .86435 Mdot
.21741 .87954 Mdot
.22732 .97472 Mdot
.22836 .89153 Mdot
.38287 .98318 Mdot
.19132 .79381 Mdot
.98389 .91012 Mdot
.10207 .69516 Mdot
.31275 .90388 Mdot
.43251 .00754 Mdot
.04248 .09153 Mdot
.31178 .94842 Mdot
.46723 .83158 Mdot
.20086 .85242 Mdot
.7688 .50464 Mdot
.25271 .85623 Mdot
.28211 .91096 Mdot
.7181 .83525 Mdot
.31709 .96806 Mdot
.2407 .82099 Mdot
.5757 .14886 Mdot
.24896 .74066 Mdot
.51372 .7792 Mdot
.27754 .84588 Mdot
.86131 .88868 Mdot
.24477 .22626 Mdot
.229 .84548 Mdot
.60132 .8592 Mdot
.18437 .48899 Mdot
.40828 .99893 Mdot
.04783 .80519 Mdot
.3495 .00999 Mdot
.955 .89932 Mdot
.26257 .78373 Mdot
.14417 .78621 Mdot
.33274 .8926 Mdot
.10394 .935 Mdot
.19546 .92675 Mdot
.60367 .91068 Mdot
.20135 .99644 Mdot
.43214 .11677 Mdot
.34542 .92669 Mdot
.4729 .55634 Mdot
.25579 .90166 Mdot
.22282 .8794 Mdot
.29222 .08671 Mdot
.01823 .87986 Mdot
.90096 .26102 Mdot
.41413 .80235 Mdot
.1332 .8743 Mdot
.21545 .72581 Mdot
.45257 .08855 Mdot
.40185 .23507 Mdot
.36072 .66224 Mdot
.34155 .82003 Mdot
.25452 .72716 Mdot
.21271 .85622 Mdot
.67968 .83933 Mdot
.75737 .5631 Mdot
.38366 .63798 Mdot
.34135 .1679 Mdot
.16682 .97968 Mdot
.25125 .87449 Mdot
.11654 .8934 Mdot
.03802 .58354 Mdot
.32961 .80105 Mdot
.57815 .45726 Mdot
.02658 .05365 Mdot
.17978 .43466 Mdot
.2837 .88876 Mdot
.60787 .78964 Mdot
.30717 .97623 Mdot
.3446 .05089 Mdot
.7005 .82254 Mdot
.16101 .75306 Mdot
.85808 .44964 Mdot
.27517 .83001 Mdot
.28882 .94198 Mdot
.12146 .58449 Mdot
.31411 .80299 Mdot
.25439 .87484 Mdot
.82602 .98624 Mdot
.19294 .73456 Mdot
.57489 .88013 Mdot
.07553 .88862 Mdot
.08854 .82129 Mdot
.745 .80337 Mdot
.26689 .8334 Mdot
.56868 .79447 Mdot
.03252 .63387 Mdot
.30428 .78491 Mdot
.2944 .78031 Mdot
.25081 .8608 Mdot
.19904 .88673 Mdot
.00235 .81608 Mdot
.24203 .24084 Mdot
.7364 .44753 Mdot
.32092 .61672 Mdot
.01511 .9008 Mdot
.28938 .32259 Mdot
.26405 .95592 Mdot
.21819 .9325 Mdot
.37244 .93979 Mdot
.99999 .5311 Mdot
.38494 .95179 Mdot
.99806 .89072 Mdot
.22818 .7977 Mdot
.25654 .85097 Mdot
.3582 .88383 Mdot
.44479 .57071 Mdot
.05022 .72476 Mdot
.14663 .84578 Mdot
.31209 .79128 Mdot
.28396 .88437 Mdot
.15787 .76871 Mdot
.31516 .98336 Mdot
.19055 .88968 Mdot
.28768 .92518 Mdot
.19342 .92525 Mdot
.13427 .81817 Mdot
.78224 .84762 Mdot
.31613 .9026 Mdot
.42542 .2315 Mdot
.14664 .86516 Mdot
.15827 .64346 Mdot
.17292 .85224 Mdot
.16552 .5354 Mdot
.41622 .23543 Mdot
.16449 .94552 Mdot
.49287 .91157 Mdot
.30892 .93641 Mdot
.37304 .01709 Mdot
.22215 .77246 Mdot
.22783 .87338 Mdot
.31224 .07352 Mdot
.12139 .87397 Mdot
.299 .87195 Mdot
.14564 .81141 Mdot
.35881 .72344 Mdot
.46181 .1985 Mdot
.19841 .90369 Mdot
.32479 .75474 Mdot
.02064 .20783 Mdot
.20323 .32993 Mdot
.25246 .88374 Mdot
.21506 .60124 Mdot
.17609 .88287 Mdot
.18947 .89738 Mdot
.20944 .84587 Mdot
.27905 .87315 Mdot
.11082 .68599 Mdot
.26361 .88737 Mdot
.08308 .62011 Mdot
.34701 .88206 Mdot
.40068 .03142 Mdot
.283 .90959 Mdot
.21941 .59347 Mdot
.62253 .7175 Mdot
.25837 .9744 Mdot
.38461 .99784 Mdot
.16423 .08732 Mdot
.21513 .82825 Mdot
.15342 .96235 Mdot
.2967 .01167 Mdot
.40334 .97444 Mdot
.1202 .83507 Mdot
.44888 .11829 Mdot
.42661 .16561 Mdot
.3545 .83391 Mdot
.26802 .78819 Mdot
.16068 .48598 Mdot
.25987 .97788 Mdot
.20427 .87812 Mdot
.08133 .11072 Mdot
.35149 .98814 Mdot
.21903 .84067 Mdot
.53812 .37873 Mdot
.06597 .81641 Mdot
.2357 .84904 Mdot
.15644 .635 Mdot
.31327 .90362 Mdot
.30568 .9033 Mdot
.32908 .8909 Mdot
.2665 .88264 Mdot
.31823 .91842 Mdot
.08624 .62626 Mdot
.31689 .92058 Mdot
.32293 .97876 Mdot
.78029 .65184 Mdot
.25346 .84223 Mdot
.10784 .91947 Mdot
.22484 .6607 Mdot
.1896 .90342 Mdot
.34678 .66 Mdot
.12368 .96754 Mdot
.21657 .75108 Mdot
.1633 .76037 Mdot
.30473 .95046 Mdot
.37352 .94079 Mdot
.75508 .5434 Mdot
.19682 .19157 Mdot
.30388 .90165 Mdot
.23113 .83251 Mdot
.21114 .89009 Mdot
.17586 .84527 Mdot
.39852 .07977 Mdot
.15795 .83635 Mdot
.19851 .82942 Mdot
.33661 .88676 Mdot
.14289 .84814 Mdot
.76895 .75601 Mdot
.32753 .95502 Mdot
.11611 .82945 Mdot
.42018 .82788 Mdot
.27497 .83506 Mdot
.5603 .73465 Mdot
.31521 .90239 Mdot
.27939 .56154 Mdot
.25325 .86418 Mdot
.2163 .8687 Mdot
.31081 .90442 Mdot
.18514 .85553 Mdot
.29277 .8822 Mdot
.75011 .59595 Mdot
.35094 .87629 Mdot
.24256 .00362 Mdot
.25817 .90931 Mdot
.24916 .62273 Mdot
.76481 .60673 Mdot
.28757 .89623 Mdot
.27723 .78032 Mdot
.26997 .8182 Mdot
.31643 .92888 Mdot
.20441 .99456 Mdot
.23525 .87697 Mdot
.30507 .94397 Mdot
.57179 .75379 Mdot
.37779 .15109 Mdot
.42529 .15614 Mdot
.15388 .8162 Mdot
.88098 .89569 Mdot
.16338 .82966 Mdot
.31769 .90066 Mdot
.24155 .93042 Mdot
.26518 .82714 Mdot
.26321 .91116 Mdot
.24787 .89452 Mdot
.69589 .26753 Mdot
.23455 .8699 Mdot
.86282 .94029 Mdot
.90896 .59092 Mdot
.37767 .81085 Mdot
.14764 .71505 Mdot
.25749 .85074 Mdot
.18514 .31534 Mdot
.27382 .86579 Mdot
.57726 .5736 Mdot
.21212 .84445 Mdot
.35061 .00177 Mdot
.3372 .9032 Mdot
.1394 .82663 Mdot
.1804 .7375 Mdot
.50798 .10856 Mdot
.29471 .75799 Mdot
.52043 .75366 Mdot
.47201 .85765 Mdot
.26676 .3216 Mdot
.17967 .78443 Mdot
.15618 .85539 Mdot
.20521 .8693 Mdot
.03263 .88053 Mdot
.91156 .08913 Mdot
.00865 .552 Mdot
.33878 .89256 Mdot
.09764 .99037 Mdot
.14581 .22542 Mdot
.25853 .92535 Mdot
.26037 .00176 Mdot
.21379 .0699 Mdot
.22359 .88991 Mdot
.78042 .81987 Mdot
.43398 .17309 Mdot
.18339 .83271 Mdot
.31276 .90387 Mdot
.23114 .8731 Mdot
.24446 .73997 Mdot
.3112 .63364 Mdot
.35129 .70372 Mdot
.72019 .02468 Mdot
.40498 .96826 Mdot
.06881 .03331 Mdot
.20363 .8043 Mdot
.29609 .90014 Mdot
.31534 .82858 Mdot
.68998 .18308 Mdot
.2009 .88001 Mdot
.52132 .24336 Mdot
.29855 .7808 Mdot
.23051 .84227 Mdot
.09818 .74336 Mdot
.27098 .88818 Mdot
.12739 .8381 Mdot
.28101 .90156 Mdot
.17251 .62482 Mdot
.10692 .7974 Mdot
.21803 .87356 Mdot
.45964 .86462 Mdot
.16797 .96937 Mdot
.18957 .89476 Mdot
.57608 .75056 Mdot
.1951 .86413 Mdot
.80248 .83452 Mdot
.04668 .86231 Mdot
.05166 .33497 Mdot
.25185 .10638 Mdot
.20106 .83066 Mdot
.32045 .84221 Mdot
.81601 .66762 Mdot
.79583 .0052 Mdot
.7355 .78453 Mdot
.22212 .86298 Mdot
.20927 .84738 Mdot
.23496 .85158 Mdot
.28898 .93941 Mdot
.311 .89251 Mdot
.69796 .70608 Mdot
.1121 .78564 Mdot
.16012 .75825 Mdot
.1103 .91758 Mdot
.21542 .17721 Mdot
.18771 .44614 Mdot
.05245 .48926 Mdot
.07874 .11519 Mdot
.13491 .48883 Mdot
.72066 .75345 Mdot
.32506 .90231 Mdot
.32065 .60589 Mdot
.23019 .02369 Mdot
.22819 .83777 Mdot
.26834 .82086 Mdot
.27279 .93592 Mdot
.46702 .94255 Mdot
.19055 .99682 Mdot
.26796 .74131 Mdot
.22815 .79856 Mdot
.10865 .7003 Mdot
.4377 .74099 Mdot
.43519 .89515 Mdot
.16785 .95957 Mdot
.25203 .83113 Mdot
.84678 .52412 Mdot
.20606 .90467 Mdot
.20824 .87907 Mdot
.80074 .13132 Mdot
.36799 .95101 Mdot
.27192 .83791 Mdot
.28427 .85733 Mdot
.17796 .7593 Mdot
.21817 .71545 Mdot
.2896 .80408 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`08ooooo`;o00000oooool00ol0003o
ooooooooo`08ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`;o00001_ooool2o`000004
ooooool0003oooooooooo`;o00002oooool00ol0003oooooooooo`0=ooooo`;o00003oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`02ooooo`007_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool02?ooool2o`0000?ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0:ooooo`;o000000Coooooo`000?oooooooooo0_l0000;ooooo`03o`000?oooooooooo
00gooooo0_l0000?ooooo`03o`000?oooooooooo00Kooooo0_l00005ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00cooooo0ol0000?ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo000Nooooo`03o`000?oooooooooo05;o
oooo0_l0000Jooooo`;o00006?ooool2o`0000?ooooo0_l0001`ooooo`;o0000A_ooool001kooooo
00?o0000ooooooooool0D_ooool4o`0000Kooooo0_l0000@ooooo`;o00007Oooool2o`000;Sooooo
000Nooooo`03o`000?oooooooooo01gooooo0_l0000eooooo`;o00001_ooool2o`0001;ooooo0_l0
0003ooooo`;o00007_ooool2o`000;3ooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l0000E
ooooo`;o0000;?ooool2o`0002?ooooo0_l00003ooooo`;o00007_ooool2o`0002Gooooo0_l00029
ooooo`007_ooool00ol0003oooooooooo`06ooooo`;o0000>?ooool2o`0000Wooooo0_l00007oooo
o`;o00001_ooool2o`0001Oooooo0_l00015ooooo`;o0000>?ooool2o`0004oooooo000Nooooo`03
o`000?oooooooooo043ooooo0_l00005ooooo`;o00002Oooool4o`0000Kooooo0_l0000Tooooo`;o
0000H_ooool2o`0000kooooo0_l0001?ooooo`007_ooool00ol0003oooooooooo`0^ooooo`;o0000
4?ooool2o`0000Gooooo0_l00002ooooo`;o00001?ooool3o`0000Oooooo0_l0000Fooooo`;o0000
3Oooool2o`0001oooooo0_l00011ooooo`;o00003?ooool2o`00057ooooo000Nooooo`03o`000?oo
oooooooo02Sooooo0_l00004ooooo`;o00006oooool2o`0000Cooooo0_l00008ooooo`;o00005_oo
ool2o`0000Wooooo0_l0000Sooooo`;o0000Coooool2o`00043ooooo0_l0000?ooooo`007_ooool0
0ol0003oooooooooo`0Booooo`;o00005?ooool2o`0003Cooooo0_l0000Nooooo`;o0000]_ooool2
o`0000oooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0001:ooooo`;o0000GOooool2o`00
08Sooooo000Nooooo`03o`000?oooooooooo04Wooooo0_l0001booooo`;o0000R?ooool001kooooo
00?o0000ooooooooool0BOooool2o`000?cooooo000Nooooo`03o`000?oooooooooo05cooooo0_l0
003Yooooo`007_ooool00ol0003oooooooooo`0oooooo`;o00006oooool2o`000>Wooooo000Noooo
o`;o00001_ooool2o`0003Sooooo0_l0000[ooooo`;o00004Oooool2o`000<Kooooo000Nooooo`03
o`000?oooooooooo00Gooooo0_l0001Uooooo`;o00004Oooool2o`000<Kooooo000Nooooo`03o`00
0?oooooooooo05Wooooo0_l0003/ooooo`007_ooool00ol0003oooooooooo`0oooooo`;o00006?oo
ool2o`000>cooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l0000Fooooo`Co0000<Oooool2
o`0000Gooooo0_l0001hooooo`;o0000D?ooool001kooooo00?o0000ooooooooool09oooool2o`00
01Sooooo0_l0000@ooooo`;o00007oooool2o`0000Gooooo0_l0001hooooo`;o0000D?ooool001ko
oooo00?o0000ooooooooool0@Oooool2o`00013ooooo0_l0003booooo`007Oooool2o`00033ooooo
0_l0000Aooooo`;o00007_ooool2o`000>Cooooo000Mooooo`;o0000<?ooool2o`0001Cooooo0_l0
000Kooooo`;o0000i?ooool001kooooo00?o0000ooooooooool0>?ooool2o`0000[ooooo0_l0000W
ooooo`;o00003_ooool2o`00073ooooo0_l0001Fooooo`007_ooool00ol0003oooooooooo`0hoooo
o`;o0000<oooool2o`0000kooooo0_l0001`ooooo`;o0000E_ooool001kooooo00?o0000oooooooo
ool0<Oooool2o`0002Sooooo0_l0003Zooooo`007_ooool00ol0003oooooooooo`0aooooo`;o0000
0oooool2o`0001Cooooo0_l0000=ooooo`;o00007Oooool2o`0001?ooooo0_l0000Uooooo`;o0000
D?ooool2o`0001[ooooo0_l0000Qooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o000000?o
ooooo`000?l000009oooool2o`0001Cooooo0_l0000/ooooo`;o00004oooool2o`0002Gooooo0_l0
001@ooooo`;o00006_ooool2o`00027ooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l00000
0ooooooo0000o`00000cooooo`;o0000ooooool4ooooo`007_ooool00ol0003oooooooooo`0`oooo
o`;o00004?ooool2o`0002gooooo0_l0003Dooooo`007_ooool2o`00037ooooo0_l0000oooooo`;o
00001_ooool2o`000<cooooo000Nooooo`03o`000?oooooooooo02_ooooo0_l0001<ooooo`;o0000
7_ooool2o`000:cooooo000Nooooo`03o`000?oooooooooo02_ooooo0_l0000Qooooo`;o0000>_oo
ool2o`0000gooooo0_l00006ooooo`;o0000W?ooool2o`0000Kooooo000Nooooo`03o`000?oooooo
oooo01Kooooo0_l0000Qooooo`;o00004oooool2o`0002;ooooo0_l0000Fooooo`;o00005Oooool2
o`0009cooooo0_l00006ooooo`007_ooool00ol0003oooooooooo`0Eooooo`?o00007Oooool2o`00
00;ooooo0_l0000;ooooo`;o00000oooool2o`0002Gooooo0_l0000Zooooo`;o0000Yoooool001ko
oooo00?o0000ooooooooool05Oooool2o`0001kooooo0_l0000?ooooo`;o00000oooool2o`0001;o
oooo0_l0000Wooooo`;o00001?ooool2o`0000kooooo0_l0002Wooooo`007_ooool00ol0003ooooo
ooooo`1Oooooo`;o00009oooool2o`0000Cooooo0_l0002gooooo`007_ooool00ol0003ooooooooo
o`1Nooooo`;o0000@oooool2o`000:;ooooo000Nooooo`03o`000?oooooooooo05kooooo0_l00008
ooooo`;o0000>Oooool2o`0008Kooooo0_l0000Jooooo`007_ooool00ol0003oooooooooo`1Xoooo
o`;o0000LOooool2o`0003gooooo0_l0000?ooooo`;o00006_ooool001kooooo00?o0000oooooooo
ool0foooool2o`0002?ooooo0_l0000Hooooo`;o0000:oooool001kooooo00?o0000ooooooooool0
C_ooool2o`0002;ooooo0_l0002<ooooo`;o0000AOooool001kooooo00?o0000ooooooooool05?oo
ool2o`0000Cooooo0_l0000booooo`;o00008_ooool2o`000=?ooooo000Nooooo`03o`000?oooooo
oooo01Cooooo0_l00004ooooo`;o0000oooooolLooooo`;o00003_ooool001kooooo00?o0000oooo
ooooool0oooooolhooooo`;o00003_ooool001kooooo00?o0000ooooooooool0U?ooool2o`00027o
oooo0_l0002>ooooo`007_ooool2o`0002Gooooo0_l0001Aooooo`;o00006oooool2o`00027ooooo
0_l0002>ooooo`007_ooool00ol0003oooooooooo`0Tooooo`;o0000DOooool2o`000<kooooo000N
ooooo`03o`000?oooooooooo08Kooooo0_l0002oooooo`007_ooool00ol0003oooooooooo`26oooo
o`;o0000_oooool001kooooo00?o0000ooooooooool03?ooool2o`000:3ooooo0_l0002Gooooo`00
7_ooool00ol0003oooooooooo`0<ooooo`;o0000NOooool2o`0002Gooooo0_l0002Gooooo`007_oo
ool00ol0003oooooooooo`1[ooooo`;o00006_ooool2o`000;kooooo000Nooooo`03o`000?oooooo
oooo06_ooooo0_l0000Looooo`;o0000_?ooool001kooooo00?o0000ooooooooool0=Oooool2o`00
05;ooooo0_l0001^ooooo`;o0000C?ooool001kooooo00?o0000ooooooooool0=Oooool2o`0000_o
oooo0_l0002eooooo`;o0000C?ooool001kooooo00?o0000ooooooooool0@_ooool2o`000?oooooo
1?ooool001kooooo00?o0000ooooooooool06Oooool2o`0007;ooooo0_l0001=ooooo`;o00004Ooo
ool2o`0005Kooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l0001booooo`;o0000COooool2
o`00017ooooo0_l0001Fooooo`007_ooool00ol0003oooooooooo`0looooo`;o0000ooooool:oooo
o`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0
003oooooooooo`0looooo`;o0000W?ooool2o`0005cooooo0_l0000=ooooo`000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool0
0ol0003oooooooooo`3Jooooo`;o0000G?ooool2o`0000gooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`?o0000T_ooool2o`000;?ooooo0003oooo
o`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooo
oooo09;ooooo0_l0001<ooooo`;o0000IOooool000?ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0h?ooool2o`0006Gooooo0003oooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo0_l0003ooooood?ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool00oooool2o`000?oooooo@ooo
ool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
1_ooool00ol0003oooooooooo`0Iooooo`;o0000ooooool]ooooo`007_ooool00ol0003ooooooooo
o`0Iooooo`;o0000ooooool]ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo02_ooooo0_l0003ooooooa_ooooo000Nooooo`03o`000?oooooooooo02_o
oooo0_l0000Nooooo`;o0000<?ooool2o`000<Sooooo000Nooooo`03o`000?oooooooooo04_ooooo
0_l0000`ooooo`;o00001oooool2o`000;oooooo000Nooooo`03o`000?oooooooooo07oooooo0_l0
0005ooooo`;o0000_oooool001kooooo00?o0000ooooooooool03Oooool2o`00073ooooo0_l00002
ooooo`;o0000`_ooool001kooooo00?o0000ooooooooool03Oooool2o`0003cooooo0_l0000foooo
o`;o0000`_ooool001kooooo00?o0000ooooooooool0Boooool2o`0002Kooooo0_l0000`ooooo`;o
0000X?ooool001kooooo00?o0000ooooooooool0Loooool2o`00033ooooo0_l0002Pooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000C_ooool2o`000?Sooooo000Noooo
o`03o`000?oooooooooo047ooooo0_l0000:ooooo`;o0000joooool2o`0000_ooooo000Nooooo`03
o`000?oooooooooo01gooooo0_l0000Rooooo`;o0000moooool2o`0000_ooooo000Nooooo`03o`00
0?oooooooooo01gooooo0_l0002Sooooo`;o0000GOooool2o`0002Cooooo000Nooooo`03o`000?oo
oooooooo04;ooooo0_l0001nooooo`;o0000GOooool2o`0002Cooooo000Nooooo`03o`000?oooooo
oooo04;ooooo0_l00012ooooo`;o0000E_ooool2o`0006Oooooo000Nooooo`03o`000?oooooooooo
08Kooooo0_l0001Fooooo`;o0000Ioooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo08gooooo0_l0
002hooooo`007_ooool00ol0003oooooooooo`2=ooooo`;o0000^?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0003oooooocoooooo
000Nooooo`03o`000?oooooooooo00Oooooo0_l0003oooooocoooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool03?ooool2o`0002[ooooo0_l0003ooooo
o`kooooo000Nooooo`03o`000?oooooooooo00cooooo0_l0000Zooooo`;o0000ooooool>ooooo`00
7_ooool00ol0003oooooooooo`1Cooooo`;o00001Oooool2o`000>_ooooo000Nooooo`03o`000?oo
oooooooo05?ooooo0_l00005ooooo`;o0000joooool001kooooo00?o0000ooooooooool0?_ooool2
o`000?oooooo2?ooool001kooooo00?o0000ooooooooool0?_ooool2o`000?oooooo2?ooool001ko
oooo00?o0000ooooooooool03Oooool2o`000?oooooo>Oooool001kooooo00?o0000ooooooooool0
3Oooool2o`00073ooooo0_l00036ooooo`007_ooool00ol0003oooooooooo`1oooooo`;o0000Dooo
ool2o`00077ooooo000Nooooo`03o`000?oooooooooo08Gooooo0_l0001=ooooo`;o0000LOooool0
01kooooo00?o0000ooooooooool0QOooool2o`000<3ooooo000Nooooo`;o0000oooooom9ooooo`00
7_ooool00ol0003oooooooooo`3ooooood3ooooo0_l00006ooooo`007_ooool00ol0003ooooooooo
o`3ooooood3ooooo0_l00006ooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o00004_ooool2
o`000?oooooo1Oooool2o`0001kooooo000Nooooo`03o`000?oooooooooo00gooooo0_l0000Boooo
o`;o0000ooooool5ooooo`;o00007_ooool001kooooo00?o0000ooooooooool0S_ooool2o`000;Oo
oooo000Nooooo`03o`000?oooooooooo08kooooo0_l0002gooooo`007_ooool00ol0003ooooooooo
o`1eooooo`;o0000d?ooool001kooooo00?o0000ooooooooool0MOooool2o`000=3ooooo000Noooo
o`03o`000?oooooooooo0:_ooooo0_l0002Jooooo`007_ooool00ol0003oooooooooo`2[ooooo`;o
00003oooool2o`0008Wooooo000Nooooo`03o`000?oooooooooo0;cooooo0_l00029ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooo
oooo00Cooooo00?o0000ooooooooool0HOooool2o`0006oooooo0_l0001cooooo`000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0HOooool2o`0004Wooooo0_l0000Tooooo`;o0000;Oooool2o`0004Cooooo0003oooo
o`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol0002/ooooo`;o0000Doooool2
o`0004Cooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool0
0007ooooo`03o`000?oooooooooo043ooooo0_l0003oooooo`Kooooo0003ooooo`05o`000?oooooo
ooooooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo043ooooo
0_l0003oooooo`Kooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`000007ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom8ooooo`000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0Foooool2o`0003gooooo0_l0002[ooooo`007_ooool01?l0003oooooo`000?l0001J
ooooo`;o0000?Oooool2o`000:_ooooo000Nooooo`04o`000?oooooo0000o`000?ooooooAoooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`0fooooo`;o
0000ooooool@ooooo`007_ooool00ol0003oooooooooo`0fooooo`;o0000ooooool@ooooo`007_oo
ool00ol0003oooooooooo`3aooooo`;o0000E?ooool001kooooo00?o0000ooooooooool03_ooool2
o`000>7ooooo0_l0001Dooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o00005oooool2o`00
013ooooo0_l0001Rooooo`;o0000Z?ooool001kooooo00?o0000ooooooooool09oooool2o`00013o
oooo0_l0001Rooooo`;o00003oooool2o`0003_ooooo0_l0000Vooooo`;o0000<_ooool001kooooo
0_l0001Dooooo`;o0000FOooool2o`0003_ooooo0_l0000Vooooo`;o0000<_ooool001kooooo00?o
0000ooooooooool0Doooool2o`000?;ooooo000Nooooo`03o`000?oooooooooo0;Sooooo0_l0002=
ooooo`007_ooool00ol0003oooooooooo`2hooooo`;o0000SOooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`0`ooooo`;o0000oooo
oolFooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o00006Oooool2o`0000Kooooo0_l00006
ooooo`;o0000ooooool>ooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o00006Oooool2o`00
00kooooo0_l0000Uooooo`;o0000P_ooool2o`0006;ooooo000Nooooo`03o`000?oooooooooo05oo
oooo0_l00022ooooo`;o00008oooool2o`0003gooooo000Nooooo`03o`000?oooooooooo05Sooooo
0_l0002^ooooo`;o0000?Oooool001kooooo0_l0001Iooooo`;o0000kOooool001kooooo00?o0000
ooooooooool0m_ooool2o`0004oooooo000Nooooo`03o`000?oooooooooo0<_ooooo0_l0000Yoooo
o`;o0000Coooool001kooooo00?o0000ooooooooool0boooool2o`0004Oooooo0_l0000aooooo`00
7_ooool00ol0003oooooooooo`3ooooooaGooooo0_l0000aooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0ooooool@ooooo`;o0000=_ooool001kooooo00?o0000ooooooooool0ooooool@ooooo`;o
0000=_ooool001kooooo00?o0000ooooooooool0c_ooool2o`0007Oooooo000Nooooo`03o`000?oo
oooooooo043ooooo0_l0002<ooooo`;o0000LOooool2o`0000Cooooo000Nooooo`03o`000?oooooo
oooo03;ooooo0_l0000<ooooo`;o0000ooooool2o`0000Cooooo000Nooooo`03o`000?oooooooooo
03;ooooo0_l0003ooooooaCooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0@?ooool2o`000:oooooo0_l0001Dooooo`007_ooool00ol0003ooooooooo
o`0Cooooo`;o0000:oooool2o`000:oooooo0_l0001Dooooo`007_ooool4o`0001;ooooo0_l0000O
ooooo`;o0000oooooolBooooo`007_ooool01?l0003oooooo`000?l0000cooooo`;o0000oooooolB
ooooo`007_ooool00ol0003oooooooooo`1]ooooo`;o00009oooool2o`0001Kooooo0_l0001Aoooo
o`;o0000A?ooool001kooooo00?o0000ooooooooool0KOooool2o`0002Oooooo0_l0000Fooooo`;o
0000DOooool2o`0004Cooooo000Nooooo`03o`000?oooooooooo05Oooooo0_l0002Iooooo`;o0000
Doooool001kooooo00?o0000ooooooooool0Eoooool2o`0000?ooooo0_l0002Dooooo`;o0000Dooo
ool001kooooo00?o0000ooooooooool0G?ooool2o`000>Wooooo000Nooooo`03o`000?oooooooooo
08cooooo0_l0000Aooooo`;o0000UOooool2o`0000oooooo000Nooooo`03o`000?oooooooooo04Ko
oooo0_l0000Iooooo`;o0000:Oooool2o`00017ooooo0_l0000Gooooo`;o0000L?ooool2o`0000[o
oooo0_l0000?ooooo`007_ooool00ol0003oooooooooo`16ooooo`;o00006Oooool2o`0005Gooooo
0_l0001`ooooo`;o00006oooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`08ooooo`;o00006Oooool2o`0003Kooooo0_l0003Zooooo`007_ooool00ol0
003oooooooooo`08ooooo`;o00006Oooool2o`00017ooooo0_l0000Gooooo`;o00002_ooool2o`00
0>[ooooo000Nooooo`03o`000?oooooooooo03Kooooo0_l0000Gooooo`;o0000d_ooool2o`0000?o
oooo0_l0000Mooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`13ooooo`;o0000g_ooool2o`00
00?ooooo0_l0000Mooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`13ooooo`;o0000Zoooool2
o`0005Gooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooo
oooo000000Kooooo0ol0003`ooooo`;o0000>?ooool2o`0001_ooooo0003ooooo`05o`000?oooooo
ooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0
@_ooool2o`000>Kooooo0_l0000Kooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo
00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo04;ooooo0_l0000Oooooo`?o
0000Soooool2o`00053ooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGo
QhN7ooooo`08ooooo`03o`000?oooooooooo023ooooo0_l00011ooooo`?o0000Soooool2o`00053o
oooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03
o`000?oooooooooo023ooooo0_l0003oooooobKooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0I?ooool2o`0006Kooooo0_l0001iooooo`007_ooool00ol0003ooooo
ooooo`0Gooooo`;o00005?ooool2o`0001kooooo0_l0000Eooooo`;o0000B?ooool2o`0000Cooooo
0_l0000Fooooo`;o0000NOooool001kooooo00?o0000ooooooooool05oooool2o`0000Sooooo0_l0
000:ooooo`;o00001Oooool2o`0001Oooooo0_l00004ooooo`;o0000FOooool2o`0000Cooooo0_l0
001Aooooo`;o0000?_ooool001kooooo00?o0000ooooooooool06?ooool2o`0000Oooooo0_l0000A
ooooo`;o00004_ooool2o`0000Wooooo0_l0002booooo`;o0000?_ooool001kooooo00?o0000oooo
ooooool06?ooool2o`0002_ooooo0_l000000ooooooo0000o`00003mooooo`007_ooool00ol0003o
ooooooooo`06ooooo`;o00009oooool2o`0001Cooooo0_l0000Jooooo`;o0000<_ooool2o`000;3o
oooo000Nooooo`03o`000?oooooooooo00Kooooo1?l0000Pooooo`;o00000oooool2o`00033ooooo
0_l0000Fooooo`;o00006_ooool2o`000;3ooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0
000Pooooo`;o00009?ooool2o`0002Oooooo0_l0003<ooooo`007_ooool00ol0003oooooooooo`0@
ooooo`;o00007Oooool2o`0001oooooo0_l0003eooooo`007_ooool00ol0003oooooooooo`0@oooo
o`;o00007Oooool2o`0002oooooo0_l0000Dooooo`;o0000coooool001kooooo00?o0000oooooooo
ool0H?ooool2o`0001Cooooo0_l0003?ooooo`007_ooool2o`0000Oooooo0_l0000cooooo`;o0000
3?ooool2o`0003oooooo0_l0001^ooooo`;o0000Boooool001kooooo00?o0000ooooooooool01_oo
ool2o`0003?ooooo0_l0000<ooooo`;o0000?oooool2o`00063ooooo0_l0000<ooooo`;o0000Booo
ool001kooooo00?o0000ooooooooool0k?ooool2o`0005Wooooo000Nooooo`03o`000?oooooooooo
01Kooooo0_l0000]ooooo`;o00009_ooool2o`0000;ooooo0_l0003Dooooo`007_ooool00ol0003o
ooooooooo`0Fooooo`;o00001?ooool2o`0002Oooooo0_l0000Vooooo`;o00000_ooool2o`000=Co
oooo000Nooooo`03o`000?oooooooooo01cooooo0ol0000/ooooo`;o0000B_ooool2o`0006cooooo
0_l00010ooooo`007_ooool00ol0003oooooooooo`0Mooooo`Co00003oooool2o`0001Wooooo0_l0
001:ooooo`;o0000K?ooool2o`00043ooooo000Nooooo`03o`000?oooooooooo01oooooo0_l0000?
ooooo`;o0000oooooolFooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo02Gooooo0_l0003oooooob7ooooo000Nooooo`03o`000?oooooooooo02Gooooo
0_l0003oooooob7ooooo000Nooooo`03o`000?oooooooooo01?ooooo0_l0000;ooooo`;o0000oooo
oolVooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o00002oooool2o`0006Wooooo0_l0002j
ooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o0000K?ooool2o`000;[ooooo000Nooooo`03
o`000?oooooooooo01gooooo0_l00005ooooo`;o00003oooool2o`000?oooooo4Oooool001kooooo
00?o0000ooooooooool07Oooool2o`0000Gooooo0_l0000?ooooo`;o00007_ooool2o`000?3ooooo
000Nooooo`;o00008?ooool2o`0002cooooo0_l00006ooooo`;o0000@?ooool2o`00067ooooo0_l0
001;ooooo`007_ooool00ol0003oooooooooo`03ooooo`;o00006_ooool2o`0002cooooo0_l0000O
ooooo`;o00009oooool2o`00067ooooo0_l0001;ooooo`007_ooool00ol0003oooooooooo`03oooo
o`;o0000JOooool2o`0006oooooo0_l0001Vooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o
00005oooool2o`0001Gooooo0_l0000=ooooo`;o0000Coooool2o`0004;ooooo0_l0001Vooooo`00
7_ooool00ol0003oooooooooo`0;ooooo`;o00004?ooool2o`0000Gooooo0_l0000Eooooo`;o0000
2oooool4o`0004oooooo0_l0000Booooo`;o0000U_ooool001kooooo00?o0000ooooooooool07Ooo
ool2o`0000gooooo0_l0000Dooooo`?o00000oooool2o`0006Gooooo0_l0000Eooooo`;o0000Oooo
ool001kooooo00?o0000ooooooooool04_ooool2o`0000kooooo0_l00008ooooo`;o00005?ooool3
o`000003ooooool0003o000000;o0000O?ooool2o`0007oooooo000Nooooo`03o`000?oooooooooo
01;ooooo0_l0000>ooooo`;o00002oooool2o`0001Gooooo1?l0000Wooooo`;o0000e?ooool001ko
oooo00?o0000ooooooooool03?ooool2o`00027ooooo0_l0000Aooooo`;o00000_ooool2o`0000Oo
oooo0_l0000Pooooo`;o0000:Oooool2o`000:Wooooo000Nooooo`03o`000?oooooooooo00cooooo
0_l0000Pooooo`;o00003oooool2o`000003ooooool0003o000000_ooooo0_l00004ooooo`;o0000
;?ooool2o`0001Oooooo1?l0002Wooooo`007_ooool00ol0003oooooooooo`0Nooooo`;o00003_oo
ool2o`0000oooooo0_l0000:ooooo`;o00002?ooool2o`0002cooooo0_l0000Dooooo`;o00000ooo
ool2o`000:Oooooo000Nooooo`03o`000?oooooooooo01kooooo0_l0000Kooooo`;o00003_ooool2
o`0000Oooooo0_l00013ooooo`;o00005oooool2o`0009?ooooo000Nooooo`03o`000?oooooooooo
02;ooooo0_l0000=ooooo`;o00001?ooool2o`0000;ooooo0_l00005ooooo`;o00004?ooool2o`00
04[ooooo0_l0000@ooooo`;o0000Toooool001kooooo00?o0000ooooooooool02_ooool2o`0001Ko
oooo0_l00007ooooo`;o00001?ooool2o`0000Cooooo0_l00009ooooo`;o000000?oooooo`000?l0
00001?ooool4o`0000Cooooo0_l0000eooooo`;o00005?ooool2o`000:Gooooo000Nooooo`03o`00
0?oooooooooo00[ooooo0_l00009ooooo`;o00001Oooool2o`000003ooooool0003o000000[ooooo
0_l00005ooooo`;o00003_ooool2o`000003ooooool0003o000000Cooooo1?l00004ooooo`;o0000
=Oooool2o`0008Gooooo0_l0000dooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o00001Ooo
ool2o`000003ooooool0003o0000017ooooo0_l0003Mooooo`;o0000=?ooool001kooooo0_l00013
ooooo`;o0000Foooool2o`0001Kooooo0_l0002>ooooo`007_ooool00ol0003oooooooooo`0]oooo
o`;o000000?oooooo`000?l000004?ooool3o`00023ooooo0_l0000Rooooo`;o00005?ooool2o`00
00Cooooo0_l0000?ooooo`?o0000;Oooool2o`0005oooooo000Nooooo`03o`000?oooooooooo01[o
oooo0_l0000Aooooo`;o000000?oooooo`000?l000004Oooool2o`0001Oooooo0_l00007ooooo`;o
00003Oooool2o`0000?ooooo0_l0000>ooooo`;o00006_ooool2o`0000oooooo0_l0000^ooooo`;o
00003_ooool2o`0004oooooo000Nooooo`03o`000?oooooooooo01[ooooo0_l0000Dooooo`?o0000
0oooool2o`0000Cooooo0_l0000Nooooo`;o00005_ooool2o`0000?ooooo0_l0001Uooooo`;o0000
5?ooool2o`0004oooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0000[ooooo`?o00000ooo
ool2o`0000Cooooo0_l0000Vooooo`;o0000N_ooool2o`0006Gooooo000Nooooo`03o`000?oooooo
oooo00?ooooo0_l0001Oooooo`;o00005_ooool2o`000<Wooooo000Nooooo`03o`000?oooooooooo
02oooooo1?l00019ooooo`;o0000Q_ooool2o`00047ooooo000Nooooo`03o`000?oooooooooo02oo
oooo1?l00007ooooo`;o00002?ooool2o`000;kooooo0_l00011ooooo`007_ooool01?l0003ooooo
ooooooooool2o`0003Oooooo0_l00003ooooo`;o00000oooool2o`0004Sooooo0_l0002gooooo`00
7_ooool01?l0003oooooooooooooool2o`0003[ooooo1?l0001=ooooo`;o00004oooool2o`000:;o
oooo000Nooooo`03o`000?oooooooooo037ooooo0_l00007ooooo`;o000000?oooooo`000?l00000
0oooool2o`0000Kooooo0_l0000:ooooo`;o00001?ooool3o`0004Cooooo0_l0001Dooooo`;o0000
C?ooool001kooooo00?o0000ooooooooool07?ooool2o`0000;ooooo0_l0000=ooooo`Ko000000?o
ooooo`000?l000000_ooool2o`0000Kooooo0_l00006ooooo`;o00001Oooool2o`0000?ooooo0_l0
0004ooooo`Go0000R_ooool2o`0000cooooo0_l0001<ooooo`007_ooool00ol0003oooooooooo`0G
ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00001_ooool2o`000003ooooool0003o
000000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000006Oooool4o`0000Sooooo1?l0002:
ooooo`;o0000F_ooool001kooooo00?o0000ooooooooool05oooool2o`000003ooooool0003o0000
00cooooo0_l000000ooooooo0000o`00000Nooooo`;o00001_ooool2o`0000Sooooo0_l00002oooo
o`Co0000GOooool2o`0008?ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo03[ooooo0_l0000?
ooooo`;o00005?ooool5o`0004oooooo0_l0000;ooooo`;o0000Poooool000?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o
0000ooooooooool07oooool2o`0001Wooooo0_l0000:ooooo`Co00006_ooool2o`0003oooooo0_l0
000>ooooo`;o0000BOooool2o`0004Gooooo0003ooooo`05oa0@4?ooooooooooooooool@41002ooo
ool01Ol0003ooooooooooooooooo000000Kooooo0ol00004ooooo`;o00004oooool2o`0000Cooooo
0_l0000Uooooo`Co00000oooool2o`0001Sooooo0_l0000:ooooo`;o0000<?ooool2o`0005Wooooo
0_l0000fooooo`;o00003Oooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b
<_nHV9SooooooiRHV?lb<S801_ooool00ol0003oooooooooo`04ooooo`;o00004oooool2o`0002_o
oooo0_l00005ooooo`;o00002oooool2o`0000Kooooo0_l00003ooooo`;o00002_ooool2o`0000ko
oooo0_l0001Yooooo`;o0000B?ooool2o`0000gooooo0003ooooo`05o`000?ooooooooooooooool0
00002oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool02oooool2o`00
027ooooo0_l0000>ooooo`;o00006?ooool4o`0000Kooooo0_l0000Jooooo`;o00000oooool2o`00
06Wooooo0_l0001Gooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj
^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo00_ooooo0_l0000Qooooo`;o00000oooool2
o`0000Kooooo0_l000000ooooooo0000o`00000Hooooo`;o00009?ooool2o`000<Oooooo0003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o
0000ooooooooool08oooool2o`0000Kooooo1?l00004ooooo`;o00001_ooool2o`0000gooooo0_l0
000Nooooo`;o00002oooool2o`0005Oooooo0_l0001eooooo`000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`;o00004_ooool3o`0000oooooo
0_l00006ooooo`Go00006?ooool6o`0000Kooooo0_l0000Dooooo`;o00002oooool2o`0004Sooooo
0_l0000=ooooo`?o00001oooool2o`0006_ooooo000Nooooo`;o00004_ooool3o`0000cooooo0_l0
0006ooooo`;o00001?ooool2o`0001Sooooo1_l00002ooooo`;o00000_ooool2o`0000kooooo0_l0
000:ooooo`;o0000Coooool2o`0000kooooo0_l00007ooooo`;o0000Joooool001kooooo00?o0000
ooooooooool06Oooool2o`0000Gooooo0_l00006ooooo`;o00003oooool2o`0000kooooo1?l00003
ooooo`;o000000Coooooo`000?l0003o00003_ooool2o`0000Gooooo0_l00003ooooo`;o0000K_oo
ool2o`0001Sooooo0_l0001;ooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o00007?ooool4
o`000004ooooool0003o0000ooooo`;o00002?ooool3o`0000Oooooo0_l0000?ooooo`;o00001Ooo
ool2o`0002Oooooo0_l0001:ooooo`;o00003?ooool2o`0000[ooooo0_l0001;ooooo`007Oooool2
o`00023ooooo0_l00009ooooo`;o00003?ooool2o`000003ooooool0003o000000;o000000Cooooo
o`000?l0003ooooo0_l00005ooooo`Ko000000?oooooo`000?l000000_l0000>ooooo`;o00001?oo
ool2o`0001Kooooo0_l00002ooooo`;o00003_ooool2o`0005Sooooo0_l00003ooooo`;o0000D_oo
ool001gooooo0_l0000Kooooo`;o00000oooool2o`0000;ooooo0_l00005ooooo`;o00000_ooool2
o`0000;ooooo0_l00007ooooo`Go00000oooool2o`0000Cooooo3?l000000ooooooo0000o`000008
ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Wooooo0_l0000;ooooo`;o00000_ooool2
o`0000kooooo0_l0001Mooooo`;o0000D_ooool001kooooo00?o0000ooooooooool06Oooool2o`00
00Gooooo1?l00003ooooo`;o00001?ooool2o`0000;ooooo0_l00005ooooo`Oo00001?ooool2o`00
00;ooooo1?l00003ooooo`;o00000oooool4o`0000Sooooo0_l000000ooooooo0000o`00000;oooo
o`;o00000_ooool2o`0001oooooo0_l0000Yooooo`;o0000@?ooool2o`0002oooooo0_l0000Coooo
o`007_ooool00ol0003oooooooooo`0Jooooo`;o00000_ooool4o`000003ooooool0003o000000;o
oooo0_l00005ooooo`?o00001oooool4o`0000Oooooo2_l000000ooooooo0000o`000002ooooo`Go
00002oooool2o`0000_ooooo0_l00004ooooo`;o0000B?ooool2o`0002Cooooo0_l0000Jooooo`;o
0000;oooool2o`0001?ooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l00006ooooo`;o0000
0_ooool2o`0000?ooooo1?l00007ooooo`?o00001oooool2o`0000Wooooo2_l00005ooooo`Go0000
2oooool2o`0000gooooo0_l000001?oooooo0000o`000?l00005ooooo`;o0000Foooool2o`0000[o
oooo0_l0001Pooooo`007_ooool00ol0003oooooooooo`0Booooo`;o00004Oooool2o`0000Gooooo
0_l0000:ooooo`;o00001_ooool2o`000003ooooool0003o000000;ooooo0_l00005ooooo`;o0000
0_ooool2o`0000Sooooo0_l00006ooooo`;o00002oooool2o`000003ooooool0003o000000Kooooo
0_l0001Kooooo`;o0000K?ooool001kooooo00?o0000ooooooooool0;?ooool2o`0000Oooooo0ol0
0007ooooo`Go000000?oooooo`000?l000000_l00005ooooo`;o000000?oooooo`000?l000000ooo
ool2o`0000Cooooo0_l00006ooooo`;o0000[oooool2o`00033ooooo000Nooooo`03o`000?oooooo
oooo01gooooo0ol0000:ooooo`Co00001oooool3o`0000Gooooo1ol000001Ooooooo0000o`000?l0
003ooooo00;o00001_ooool2o`0000?ooooo0ol00004ooooo`;o000000?oooooo`000?l000001?oo
ool2o`0009;ooooo0_l0000Iooooo`;o0000<?ooool001kooooo0_l00002ooooo`;o00006_ooool3
o`0000Wooooo0ol00007ooooo`?o00001oooool2o`000004ooooool0003o0000o`0000;ooooo0_l0
00001?oooooo0000o`000?l00004ooooo`?o00001Oooool2o`000004ooooool0003o0000ooooo`;o
000000?oooooo`000?l000001?ooool2o`0002?ooooo0_l0001]ooooo`;o0000Boooool001kooooo
00Co0000oooooooooooooooo0_l0000Looooo`;o00000oooool2o`0000?ooooo0_l00004ooooo`;o
00000_ooool3o`000004ooooool0003o0000o`0000?ooooo0_l00002ooooo`;o000000Goooooo`00
0?l0003o0000ooooo`02o`0000Cooooo1?l00008ooooo`;o0000;oooool2o`000;[ooooo000Noooo
o`03o`000?oooooooooo01cooooo0_l000000ooooooo0000o`000003ooooo`;o00002Oooool2o`00
00;ooooo0_l00002ooooo`?o00001oooool2o`000003ooooool0003o000000;ooooo0_l000001?oo
oooo0000o`000?ooool4o`0000Kooooo0_l0000kooooo`;o0000:?ooool2o`0008Kooooo000Noooo
o`03o`000?oooooooooo00_ooooo0_l0000?ooooo`Co00000oooool2o`0000kooooo0_l0000>oooo
o`?o000000?oooooo`000?l000000_ooool4o`0000Oooooo1_l0000iooooo`;o0000:?ooool2o`00
04Sooooo0_l0000looooo`007_ooool00ol0003oooooooooo`0;ooooo`;o00003Oooool6o`0000?o
oooo0_l00007ooooo`;o00003Oooool2o`0000Kooooo1ol00003ooooo`Co00001Oooool2o`0000;o
oooo0_l0000Hooooo`;o00003oooool2o`0000[ooooo0_l0001fooooo`;o00003?ooool2o`0002Ko
oooo0_l00006ooooo`007_ooool00ol0003oooooooooo`0Jooooo`Co00003_ooool2o`0000Oooooo
0ol00003ooooo`;o00001Oooool8o`0000Cooooo0ol00004ooooo`;o00007Oooool2o`0000Wooooo
0_l00004ooooo`;o00002_ooool2o`0000Sooooo0_l0000_ooooo`;o0000BOooool2o`0002Kooooo
0_l00006ooooo`007_ooool00ol0003oooooooooo`0Nooooo`;o00005Oooool4o`0000Kooooo1_l0
00000ooooooo0000o`000002o`0000Wooooo1?l00002ooooo`;o00009?ooool2o`0001[ooooo0_l0
000_ooooo`;o0000NOooool001kooooo00?o0000ooooooooool06oooool2o`000003ooooool0003o
000000?ooooo0_l00002ooooo`;o00000oooool2o`0000Wooooo0_l00006ooooo`Ko000000?ooooo
o`000?l000000_l00004ooooo`?o00000_ooool2o`0000;ooooo1?l00002ooooo`;o00005Oooool2
o`0007gooooo0_l0001Booooo`007_ooool00ol0003oooooooooo`0Kooooo`;o00001_ooool2o`00
00;ooooo0_l00003ooooo`;o00001Oooool2o`0000;ooooo0ol00007ooooo`Wo00001?ooool5o`00
00Cooooo0_l00004ooooo`;o00002Oooool2o`0000Cooooo0_l00004ooooo`;o0000OOooool2o`00
04Sooooo0_l00008ooooo`007_ooool00ol0003oooooooooo`02ooooo`;o00000_ooool2o`0002;o
oooo0_l00007ooooo`;o00000_ooool3o`000003ooooool0003o000000[o000000?oooooo`000?l0
00000oooool6o`0001Gooooo0_l00004ooooo`;o00001Oooool2o`0000oooooo0_l0000_ooooo`;o
0000O_ooool2o`0000Cooooo0_l00008ooooo`007_ooool00ol0003oooooooooo`02ooooo`;o0000
0_ooool2o`0001[ooooo0_l00006ooooo`;o00001oooool4o`0000Cooooo1ol000001?oooooo0000
o`000?l00002ooooo`;o00000oooool3o`0000;ooooo0ol00006ooooo`;o00000_ooool2o`0000;o
oooo0_l00005ooooo`Go000000?oooooo`000?l000000oooool2o`0000oooooo0_l0000_ooooo`;o
0000O_ooool2o`0000kooooo000Nooooo`03o`000?oooooooooo01[ooooo0_l00006ooooo`;o0000
3oooool5o`0000Gooooo1?l00005ooooo`;o00001_ooool3o`000004ooooool0003o0000o`0000?o
oooo0_l000001?oooooo0000o`000?ooool3o`0000;ooooo0_l00004ooooo`Ko000000?oooooo`00
0?l00000eOooool001kooooo00?o0000ooooooooool05?ooool2o`0000Cooooo0_l0000Jooooo`;o
00000_ooool2o`000003ooooool0003o000000Go000000?oooooo`000?l000001ol000001?oooooo
0000o`000?ooool4o`0000;ooooo0_l00004ooooo`;o00002Oooool2o`0000;ooooo0_l0000Boooo
o`;o0000TOooool2o`00037ooooo000Nooooo`;o00005Oooool2o`0000Sooooo0_l00002ooooo`;o
00005_ooool2o`0000Gooooo0ol000000ooooooo0000o`00000?o`0000;ooooo0_l00007ooooo`;o
00000_ooool7o`000003ooooool0003o000001;ooooo0_l0000Dooooo`;o0000Noooool2o`0002[o
oooo0_l00005ooooo`007_ooool2o`0000Wooooo0_l0000Dooooo`;o00000_ooool2o`0000oooooo
0_l00005ooooo`Co00001oooool=o`0000;ooooo0_l00003ooooo`;o00001Oooool3o`0000;ooooo
1ol0000Mooooo`;o00003?ooool2o`0003Oooooo0_l00018ooooo`;o00009?ooool2o`0000Gooooo
000Nooooo`03o`000?oooooooooo00Sooooo0ol0000Fooooo`;o00004?ooool2o`0000Cooooo1Ol0
0009ooooo`;o000000?oooooo`000?l000000ol00005ooooo`;o00000oooool2o`0000Gooooo0_l0
0002ooooo`;o00008oooool2o`0003_ooooo0_l00008ooooo`;o0000B?ooool2o`0001Kooooo0_l0
000Cooooo`007_ooool2o`0000;ooooo0_l00006ooooo`;o00005_ooool2o`0000;ooooo0_l0000B
ooooo`;o00002Oooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000000_l0
0002ooooo`;o00000_ooool7o`000004ooooool0003o0000ooooo`Ko0000G_ooool2o`0006[ooooo
0_l0000Cooooo`007_ooool01?l0003oooooooooooooool2o`0002;ooooo0_l0000Booooo`Go0000
00?oooooo`000?l000000oooool2o`000003ooooool0003o000000Gooooo0ol00002ooooo`;o0000
0_ooool>o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o0000eOooool001kooooo00?o
0000ooooooooool0>_ooool4o`000003ooooool0003o000000Gooooo0_l000000ooooooo0000o`00
0003ooooo`;o00001oooool4o`0000?ooooo1_l00003ooooo`;o000000?oooooo`000?l000001?oo
ool2o`000=Gooooo000Nooooo`03o`000?oooooooooo03gooooo0_l00007ooooo`;o000000?ooooo
o`000?l000000oooool5o`0000Gooooo0_l00008ooooo`;o00000oooool2o`0003?ooooo0_l0000R
ooooo`;o0000N_ooool2o`0000Wooooo000Nooooo`03o`000?oooooooooo03gooooo0_l0000?oooo
o`Go00001Oooool2o`0004;ooooo0_l0000Rooooo`;o0000N_ooool2o`0000Wooooo000Nooooo`03
o`000?oooooooooo023ooooo0_l0000=ooooo`;o00002?ooool2o`0000oooooo0_l0000<ooooo`;o
00001?ooool2o`0000Kooooo1?l0000:ooooo`;o00001Oooool2o`0005Oooooo0_l0001aooooo`00
7_ooool00ol0003oooooooooo`0Oooooo`?o00003Oooool2o`0000Sooooo0_l0000<ooooo`;o0000
00?oooooo`000?l000002_ooool4o`0000?ooooo0ol00003ooooo`;o000000?oooooo`000?l00000
0_l0000:ooooo`;o00001Oooool2o`0005Oooooo0_l0001aooooo`007_ooool00ol0003ooooooooo
o`0Oooooo`;o00006?ooool2o`0000Oooooo0_l00003ooooo`;o00003Oooool4o`0000?ooooo0_l0
0004ooooo`;o000000?oooooo`000?l00000goooool001kooooo00?o0000ooooooooool07_ooool2
o`0000cooooo0_l00005ooooo`;o00001_ooool3o`0000Cooooo0_l00003ooooo`;o00001oooool2
o`0000Oooooo0_l00007ooooo`;o00002?ooool2o`0002kooooo0_l0002Gooooo`;o00004?ooool0
01kooooo00?o0000ooooooooool07_ooool2o`0000cooooo0_l00004ooooo`?o00001_ooool3o`00
00gooooo0_l00003ooooo`;o00001oooool2o`0000Oooooo0ol00007ooooo`;o0000;_ooool2o`00
09Oooooo0_l0000@ooooo`007_ooool00ol0003oooooooooo`0booooo`;o00001?ooool2o`0000Ko
oooo0_l000000ooooooo0000o`000005ooooo`?o00004Oooool2o`0000?ooooo0ol00008ooooo`;o
00009Oooool2o`0002gooooo0_l00021ooooo`007_ooool00ol0003oooooooooo`0Nooooo`;o0000
6?ooool2o`0000Kooooo0_l000000ooooooo0000o`000005ooooo`;o00001_ooool2o`000004oooo
ool0003o0000ooooo`;o00001?ooool4o`0000;ooooo0_l00003ooooo`;o00000oooool2o`0000Ko
oooo0_l0000Mooooo`;o0000;Oooool2o`00087ooooo000Nooooo`03o`000?oooooooooo01kooooo
0_l0000Nooooo`;o00004_ooool2o`000004ooooool0003o0000ooooo`Co00001?ooool2o`0000Oo
oooo0_l0000;ooooo`;o0000Joooool2o`0006;ooooo000Nooooo`03o`000?oooooooooo027ooooo
0_l0000Fooooo`;o00000oooool2o`0000?ooooo0_l0000>ooooo`;o00001Oooool2o`0000cooooo
0_l0000;ooooo`;o00007Oooool2o`0004gooooo0_l0000_ooooo`;o0000<Oooool001kooooo00?o
0000ooooooooool08Oooool2o`0000kooooo0_l00006ooooo`;o00002?ooool2o`0000kooooo0_l0
0005ooooo`;o00000oooool2o`0000Kooooo0ol00009ooooo`Co00007Oooool2o`0007kooooo0_l0
000Uooooo`;o00002_ooool001kooooo00?o0000ooooooooool07_ooool2o`00017ooooo0_l00000
0ooooooo0000o`00000Pooooo`;o00000_ooool2o`0000?ooooo1?l00004ooooo`;o00002_ooool2
o`0001gooooo0_l0002Wooooo`;o00002_ooool001kooooo0_l0000Oooooo`;o00004Oooool2o`00
0003ooooool0003o000000kooooo0_l0000>ooooo`Co00000_ooool2o`0000?ooooo1?l0000Aoooo
o`;o00000oooool2o`0001Oooooo0_l0002cooooo`007_ooool00ol0003oooooooooo`0`ooooo`;o
00004_ooool2o`0000kooooo0_l00002ooooo`Co00000oooool2o`0000;ooooo0_l0000?ooooo`;o
00000oooool2o`000<cooooo000Nooooo`03o`000?oooooooooo033ooooo0_l0000Fooooo`;o0000
2?ooool2o`0000Cooooo1?l00003ooooo`;o00000_ooool2o`000003ooooool0003o000000Cooooo
0_l000000ooooooo0000o`00003Fooooo`007_ooool00ol0003oooooooooo`06ooooo`;o0000:_oo
ool2o`0001Cooooo0_l00003ooooo`;o00000oooool2o`0000Gooooo0ol0000:ooooo`;o00001?oo
ool2o`000003ooooool0003o00000=Kooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l0000U
ooooo`?o00000_ooool2o`0001Cooooo0_l00003ooooo`;o00001oooool2o`000004ooooool0003o
0000o`00013ooooo1?l0002hooooo`;o00007Oooool001kooooo00?o0000ooooooooool0:oooool5
o`0001Sooooo0_l0000;ooooo`?o00005?ooool4o`000;Sooooo0_l0000Mooooo`007_ooool00ol0
003oooooooooo`0Tooooo`;o00001Oooool2o`0000Gooooo0_l0000Qooooo`?o00002oooool2o`00
01_ooooo0_l00035ooooo`007_ooool00ol0003oooooooooo`04ooooo`;o00007_ooool3o`0000_o
oooo0_l0000Aooooo`;o00003oooool2o`0000_ooooo0_l00005ooooo`;o00003?ooool2o`0000Ko
oooo0_l0000cooooo`;o0000T?ooool001kooooo00?o0000ooooooooool01?ooool2o`0001oooooo
0_l0000Nooooo`?o00002?ooool2o`0000kooooo0_l00008ooooo`;o00003?ooool2o`0000Gooooo
0_l0000dooooo`;o0000?Oooool2o`00057ooooo000Nooooo`03o`000?oooooooooo04Kooooo0_l0
0008ooooo`;o00003_ooool2o`0000?ooooo1?l0000:ooooo`;o00002_ooool2o`0007?ooooo0_l0
001Aooooo`007_ooool00ol0003oooooooooo`0booooo`;o00001Oooool2o`0001Gooooo0_l0000B
ooooo`Go00002_ooool2o`000=;ooooo000Nooooo`03o`000?oooooooooo03;ooooo0_l00005oooo
o`;o00009oooool5o`0000Kooooo0_l00009ooooo`;o0000cOooool001kooooo00?o0000oooooooo
ool0:_ooool2o`0003Kooooo1Ol00006ooooo`Go00001_ooool2o`0008kooooo0_l0000mooooo`00
7_ooool00ol0003oooooooooo`0Looooo`;o00003?ooool2o`0002oooooo0_l00006ooooo`;o0000
2Oooool4o`0001Gooooo0_l0001oooooo`;o0000?Oooool001Cooooo1?l000000ol@413ooooooooo
o`03ooooo`03o`000?oooooooooo01Gooooo0_l00005ooooo`;o00008?ooool2o`0001_ooooo0_l0
0004ooooo`;o00002Oooool2o`0001Wooooo0_l0000cooooo`;o0000ROooool001Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Eooooo`;o00008oooool2o`000004ooooool0003o
0000o`0001;ooooo0_l0000=ooooo`;o00002Oooool2o`0000_ooooo0_l0000@ooooo`;o0000;ooo
ool2o`0006Kooooo0_l0000Qooooo`005_ooool00ol0003oooooooooo`05ooooo`?o0000>_ooool2
o`000003ooooool0003o000000cooooo0_l00005ooooo`;o00009Oooool2o`0000Kooooo0_l00008
ooooo`;o0000Uoooool2o`00027ooooo000Fooooo`03o`000?oooooooooo05?ooooo0_l0000doooo
o`;o0000a?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003ooooo
ooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Cooooo00?oEEEE
ofIVI_l00000oooooomBooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.16285 .87459 Mdot
.14632 .62034 Mdot
.22333 .83798 Mdot
.18069 .8378 Mdot
.30472 .96281 Mdot
.23521 .87306 Mdot
.52463 .42287 Mdot
.31902 .89235 Mdot
.17821 .8672 Mdot
.27203 .5732 Mdot
.29943 .98658 Mdot
.15838 .04027 Mdot
.2901 .89497 Mdot
.268 .89611 Mdot
.25868 .88973 Mdot
.1061 .16743 Mdot
.113 .25775 Mdot
.16438 .89308 Mdot
.15163 .8525 Mdot
.174 .87154 Mdot
.85547 .09085 Mdot
.19148 .91519 Mdot
.23207 .82419 Mdot
.12023 .15165 Mdot
.22346 .85652 Mdot
.34084 .87689 Mdot
.2079 .83511 Mdot
.30499 .55533 Mdot
.26918 .02426 Mdot
.16992 .8549 Mdot
.14542 .85364 Mdot
.25439 .89067 Mdot
.31642 .83399 Mdot
.88264 .94947 Mdot
.1442 .01405 Mdot
.26801 .93355 Mdot
.97651 .88144 Mdot
.82965 .9186 Mdot
.12592 .00716 Mdot
.22671 .81321 Mdot
.13614 .83465 Mdot
.18044 .96408 Mdot
.2321 .80907 Mdot
.57571 .98318 Mdot
.4553 .1163 Mdot
.12659 .95289 Mdot
.68303 .21402 Mdot
.21315 .68237 Mdot
.29807 .88483 Mdot
.09732 .69838 Mdot
.00796 .84334 Mdot
.11814 .73146 Mdot
.34465 .92304 Mdot
.26672 .05123 Mdot
.31604 .92382 Mdot
.98028 .12024 Mdot
.00699 .91937 Mdot
.32462 .90798 Mdot
.21033 .83846 Mdot
.50263 .90428 Mdot
.22658 .81828 Mdot
.29959 .88954 Mdot
.71898 .06591 Mdot
.25259 .89128 Mdot
.25846 .88433 Mdot
.18076 .91479 Mdot
.07459 .75401 Mdot
.20895 .83439 Mdot
.24054 .89112 Mdot
.75404 .81941 Mdot
.88226 .11333 Mdot
.30896 .01983 Mdot
.48205 .80316 Mdot
.20904 .30871 Mdot
.31853 .82657 Mdot
.0537 .88836 Mdot
.17584 .75584 Mdot
.68215 .32096 Mdot
.22028 .86857 Mdot
.361 .88886 Mdot
.18084 .76036 Mdot
.71567 .82935 Mdot
.3401 .01267 Mdot
.31016 .89655 Mdot
.36709 .94187 Mdot
.04296 .05532 Mdot
.32937 .90935 Mdot
.23133 .79318 Mdot
.25605 .89239 Mdot
.39041 .94213 Mdot
.30405 .98224 Mdot
.04133 .99419 Mdot
.26297 .0529 Mdot
.1954 .02484 Mdot
.31907 .86406 Mdot
.19719 .80063 Mdot
.33991 .73948 Mdot
.15491 .95637 Mdot
.33702 .99537 Mdot
.26582 .5713 Mdot
.26509 .87928 Mdot
.02188 .82049 Mdot
.4251 .82989 Mdot
.06178 .63325 Mdot
.03339 .64804 Mdot
.23693 .84837 Mdot
.03354 .30844 Mdot
.05278 .31091 Mdot
.17112 .66268 Mdot
.91563 .17538 Mdot
.96333 .83682 Mdot
.38542 .99518 Mdot
.30434 .74331 Mdot
.16314 .89191 Mdot
.37947 .27578 Mdot
.41572 .31219 Mdot
.23488 .9683 Mdot
.27764 .89048 Mdot
.9091 .64287 Mdot
.32653 .78771 Mdot
.2218 .80651 Mdot
.17258 .62087 Mdot
.33949 .77138 Mdot
.84019 .92112 Mdot
.52649 .59581 Mdot
.51785 .66062 Mdot
.04543 .90331 Mdot
.14715 .85915 Mdot
.02112 .01291 Mdot
.43386 .6502 Mdot
.00564 .67671 Mdot
.67733 .37818 Mdot
.16472 .958 Mdot
.16853 .83063 Mdot
.1119 .85636 Mdot
.11591 .84512 Mdot
.23483 .85339 Mdot
.14708 .84293 Mdot
.1143 .8804 Mdot
.18646 .88774 Mdot
.11483 .87117 Mdot
.28193 .91177 Mdot
.2348 .89038 Mdot
.36291 .03282 Mdot
.52239 .86473 Mdot
.16683 .04773 Mdot
.20848 .85121 Mdot
.24002 .84227 Mdot
.53336 .79292 Mdot
.1348 .18027 Mdot
.32666 .00034 Mdot
.28778 .82455 Mdot
.15116 .03027 Mdot
.1819 .86625 Mdot
.24564 .88134 Mdot
.31394 .9124 Mdot
.19404 .90036 Mdot
.30803 .3701 Mdot
.17919 .84336 Mdot
.15746 .07681 Mdot
.15038 .81213 Mdot
.25555 .1381 Mdot
.68648 .18581 Mdot
.20645 .79025 Mdot
.32767 .98406 Mdot
.31669 .96282 Mdot
.25228 .8315 Mdot
.19726 .82967 Mdot
.37903 .18586 Mdot
.22141 .92557 Mdot
.28677 .81941 Mdot
.30769 .94913 Mdot
.15996 .05752 Mdot
.86485 .90437 Mdot
.23977 .90325 Mdot
.18358 .0351 Mdot
.25356 .16748 Mdot
.3566 .85646 Mdot
.52084 .51373 Mdot
.11071 .76163 Mdot
.26734 .93609 Mdot
.29846 .98005 Mdot
.25975 .94845 Mdot
.5208 .09628 Mdot
.11609 .35865 Mdot
.07939 .76021 Mdot
.29433 .71917 Mdot
.32418 .999 Mdot
.41764 .13932 Mdot
.42552 .05534 Mdot
.19816 .88224 Mdot
.09083 .12039 Mdot
.14342 .86229 Mdot
.00984 .84181 Mdot
.33042 .87204 Mdot
.32715 .89169 Mdot
.26139 .1567 Mdot
.2282 .8785 Mdot
.1822 .87153 Mdot
.32875 .78154 Mdot
.65972 .92131 Mdot
.057 .65898 Mdot
.14331 .83477 Mdot
.19276 .96086 Mdot
.22758 .86198 Mdot
.22885 .79263 Mdot
.54505 .65877 Mdot
.22787 .81529 Mdot
.48218 .97986 Mdot
.23021 .02926 Mdot
.24924 .96877 Mdot
.14078 .88121 Mdot
.79579 .07967 Mdot
.12355 .92869 Mdot
.15375 .83228 Mdot
.25921 .55042 Mdot
.24577 .8163 Mdot
.42857 .21624 Mdot
.27181 .61582 Mdot
.25068 .00541 Mdot
.54703 .68617 Mdot
.42648 .90654 Mdot
.31925 .9457 Mdot
.19959 .84212 Mdot
.44854 .95909 Mdot
.22725 .99646 Mdot
.49586 .70313 Mdot
.20082 .79191 Mdot
.37258 .52091 Mdot
.2052 .90917 Mdot
.32759 .89743 Mdot
.49716 .9149 Mdot
.27236 .85683 Mdot
.95136 .18372 Mdot
.18698 .78063 Mdot
.37506 .00586 Mdot
.97888 .68409 Mdot
.19702 .85305 Mdot
.90151 .4976 Mdot
.16238 .51802 Mdot
.25162 .95274 Mdot
.25506 .87513 Mdot
.10052 .64823 Mdot
.20176 .89296 Mdot
.10136 .99028 Mdot
.30921 .72267 Mdot
.42567 .99611 Mdot
.23811 .85132 Mdot
.61401 .55653 Mdot
.15141 .81531 Mdot
.12266 .70777 Mdot
.29419 .92671 Mdot
.43968 .43751 Mdot
.8475 .67288 Mdot
.47435 .64841 Mdot
.24884 .60085 Mdot
.33955 .93869 Mdot
.74072 .6395 Mdot
.11821 .74803 Mdot
.31602 .93342 Mdot
.13888 .87478 Mdot
.15428 .9357 Mdot
.29654 .3883 Mdot
.72124 .86105 Mdot
.26081 .8708 Mdot
.60977 .76782 Mdot
.16132 .70266 Mdot
.86154 .5832 Mdot
.22601 .86008 Mdot
.20882 .81561 Mdot
.33521 .99026 Mdot
.00696 .55063 Mdot
.22206 .84488 Mdot
.16029 .92434 Mdot
.20021 .83336 Mdot
.27061 .91438 Mdot
.20955 .60066 Mdot
.53208 .67671 Mdot
.28232 .99591 Mdot
.03369 .77153 Mdot
.91462 .99396 Mdot
.20001 .90236 Mdot
.23704 .75122 Mdot
.05401 .99811 Mdot
.32406 .95809 Mdot
.31127 .93725 Mdot
.20379 .91837 Mdot
.30584 .6921 Mdot
.27208 .65383 Mdot
.09171 .77293 Mdot
.14255 .63999 Mdot
.26166 .89999 Mdot
.13476 .83637 Mdot
.35146 .79636 Mdot
.69983 .83415 Mdot
.39256 .92512 Mdot
.29546 .86532 Mdot
.32782 .58394 Mdot
.78744 .84733 Mdot
.43413 .71781 Mdot
.01985 .55849 Mdot
.37137 .96842 Mdot
.21048 .12403 Mdot
.34402 .09736 Mdot
.74881 .90451 Mdot
.24218 .7048 Mdot
.20675 .83873 Mdot
.22663 .86173 Mdot
.02628 .95808 Mdot
.99539 .61276 Mdot
.22132 .80775 Mdot
.94194 .71343 Mdot
.33243 .87625 Mdot
.4178 .99608 Mdot
.26462 .89194 Mdot
.28994 .86353 Mdot
.131 .09977 Mdot
.35019 .83213 Mdot
.38835 .8588 Mdot
.45068 .85666 Mdot
.12711 .9751 Mdot
.31248 .80753 Mdot
.05202 .75155 Mdot
.21824 .09795 Mdot
.13551 .87769 Mdot
.32656 .90258 Mdot
.28461 .98448 Mdot
.15717 .88486 Mdot
.16046 .01021 Mdot
.31634 .89929 Mdot
.21393 .9148 Mdot
.22693 .88863 Mdot
.49822 .47553 Mdot
.97129 .81949 Mdot
.08868 .32115 Mdot
.20062 .46871 Mdot
.13047 .00576 Mdot
.20766 .82169 Mdot
.05909 .36234 Mdot
.69777 .04566 Mdot
.32623 .97416 Mdot
.11843 .85677 Mdot
.13074 .88935 Mdot
.3535 .07474 Mdot
.04868 .42221 Mdot
.34191 .69247 Mdot
.66627 .02746 Mdot
.29333 .05766 Mdot
.98104 .62849 Mdot
.32309 .89117 Mdot
.25573 .87361 Mdot
.33052 .94441 Mdot
.32616 .09987 Mdot
.20798 .74079 Mdot
.41662 .82021 Mdot
.22953 .83307 Mdot
.12202 .93038 Mdot
.21155 .73864 Mdot
.29167 .9033 Mdot
.52715 .98297 Mdot
.21532 .88664 Mdot
.23669 .93427 Mdot
.13588 .84922 Mdot
.2516 .96019 Mdot
.33511 .95926 Mdot
.13608 .76904 Mdot
.03505 .01851 Mdot
.28627 .85161 Mdot
.21129 .73614 Mdot
.18761 .89617 Mdot
.10136 .75458 Mdot
.20684 .83907 Mdot
.20823 .83079 Mdot
.18062 .90873 Mdot
.08978 .86838 Mdot
.18486 .43109 Mdot
.51357 .17052 Mdot
.26766 .84684 Mdot
.57104 .24575 Mdot
.19504 .82709 Mdot
.22358 .86909 Mdot
.21294 .91838 Mdot
.03308 .74625 Mdot
.1042 .01801 Mdot
.28695 .71302 Mdot
.00646 .76681 Mdot
.17744 .72107 Mdot
.95705 .41866 Mdot
.20641 .82565 Mdot
.30291 .85178 Mdot
.11588 .87213 Mdot
.26591 .96164 Mdot
.29996 .86213 Mdot
.31046 .93492 Mdot
.30356 .94922 Mdot
.46676 .09324 Mdot
.31816 .32341 Mdot
.56298 .84545 Mdot
.21229 .83524 Mdot
.13478 .87166 Mdot
.19454 .80574 Mdot
.30277 .00803 Mdot
.40726 .20235 Mdot
.29987 .89273 Mdot
.11941 .95085 Mdot
.26481 .25457 Mdot
.08235 .7024 Mdot
.36338 .98716 Mdot
.27436 .12389 Mdot
.20821 .79829 Mdot
.11094 .79851 Mdot
.1894 .83237 Mdot
.14859 .8221 Mdot
.61724 .07568 Mdot
.00391 .96163 Mdot
.18551 .90053 Mdot
.43162 .74435 Mdot
.21609 .97243 Mdot
.3609 .80246 Mdot
.22162 .8699 Mdot
.2084 .81688 Mdot
.70671 .54626 Mdot
.81917 .82265 Mdot
.24861 .95148 Mdot
.32565 .90412 Mdot
.00218 .16234 Mdot
.6665 .63735 Mdot
.18084 .89412 Mdot
.33848 .03766 Mdot
.15038 .00506 Mdot
.13801 .24576 Mdot
.69796 .20514 Mdot
.46589 .59603 Mdot
.21459 .92997 Mdot
.05177 .62766 Mdot
.30149 .68984 Mdot
.24616 .68011 Mdot
.35132 .89228 Mdot
.2213 .77951 Mdot
.43686 .1106 Mdot
.18672 .68306 Mdot
.82036 .4634 Mdot
.4954 .45864 Mdot
.23873 .83263 Mdot
.3724 .14166 Mdot
.24549 .83303 Mdot
.33929 .81272 Mdot
.26886 .98377 Mdot
.75047 .54556 Mdot
.26978 .69328 Mdot
.28265 .54311 Mdot
.17021 .65294 Mdot
.31879 .95924 Mdot
.21466 .85719 Mdot
.31733 .81716 Mdot
.21888 .81728 Mdot
.2001 .85252 Mdot
.27486 .00471 Mdot
.11269 .08653 Mdot
.45018 .34004 Mdot
.16497 .90027 Mdot
.22734 .79777 Mdot
.22481 .86266 Mdot
.32651 .85355 Mdot
.95459 .09736 Mdot
.16162 .99762 Mdot
.31728 .81941 Mdot
.40481 .04984 Mdot
.25158 .8591 Mdot
.18519 .8273 Mdot
.18261 .88829 Mdot
.32161 .89413 Mdot
.31178 .89155 Mdot
.31137 .89419 Mdot
.23345 .89646 Mdot
.24404 .88386 Mdot
.25384 .94668 Mdot
.32344 .90658 Mdot
.10386 .44198 Mdot
.29369 .86673 Mdot
.09014 .54517 Mdot
.0825 .92194 Mdot
.22603 .89532 Mdot
.11021 .88299 Mdot
.16094 .87233 Mdot
.41516 .71494 Mdot
.06053 .58468 Mdot
.28589 .41456 Mdot
.37169 .9712 Mdot
.27015 .58432 Mdot
.19871 .83536 Mdot
.19244 .82669 Mdot
.41942 .30179 Mdot
.18798 .72102 Mdot
.29086 .92611 Mdot
.23283 .85944 Mdot
.38063 .88195 Mdot
.36636 .82662 Mdot
.82413 .83092 Mdot
.16563 .11587 Mdot
.39308 .76299 Mdot
.34581 .61714 Mdot
.32679 .00468 Mdot
.23068 .02021 Mdot
.18755 .90893 Mdot
.32227 .94079 Mdot
.31684 .88892 Mdot
.36815 .61745 Mdot
.1963 .84331 Mdot
.15229 .83734 Mdot
.10286 .87879 Mdot
.2696 .6812 Mdot
.22029 .9121 Mdot
.18316 .52539 Mdot
.3163 .94923 Mdot
.16527 .94203 Mdot
.22981 .89879 Mdot
.19598 .84789 Mdot
.2786 .46204 Mdot
.1242 .88539 Mdot
.18038 .73991 Mdot
.27446 .86751 Mdot
.22111 .86791 Mdot
.33133 .78191 Mdot
.26263 .74157 Mdot
.75347 .77407 Mdot
.3925 .18703 Mdot
.94194 .38949 Mdot
.39002 .05064 Mdot
.25768 .12121 Mdot
.75627 .45012 Mdot
.68228 .07099 Mdot
.31884 .9609 Mdot
.05988 .95825 Mdot
.31172 .90183 Mdot
.24634 .87982 Mdot
.24379 .8866 Mdot
.29378 .89767 Mdot
.6602 .8777 Mdot
.64716 .90504 Mdot
.18869 .88787 Mdot
.98606 .72954 Mdot
.20005 .02223 Mdot
.24035 .88202 Mdot
.14228 .83921 Mdot
.36435 .83351 Mdot
.78517 .47984 Mdot
.18199 .73686 Mdot
.22507 .80794 Mdot
.32349 .908 Mdot
.72471 .95304 Mdot
.58007 .09133 Mdot
.30537 .86349 Mdot
.96035 .93697 Mdot
.13512 .67351 Mdot
.40283 .75625 Mdot
.31523 .41254 Mdot
.21137 .81812 Mdot
.25521 .95482 Mdot
.82431 .19349 Mdot
.21524 .82479 Mdot
.40123 .85695 Mdot
.83589 .8681 Mdot
.34118 .63928 Mdot
.20084 .91966 Mdot
.30076 .93116 Mdot
.1452 .78875 Mdot
.31997 .95602 Mdot
.52705 .85228 Mdot
.25364 .88938 Mdot
.39463 .67129 Mdot
.11557 .59684 Mdot
.24659 .8829 Mdot
.18417 .87748 Mdot
.26959 .94632 Mdot
.21196 .88902 Mdot
.38143 .97055 Mdot
.2742 .0207 Mdot
.28245 .91382 Mdot
.34792 .77731 Mdot
.53644 .32327 Mdot
.82669 .67397 Mdot
.20685 .97485 Mdot
.10271 .86676 Mdot
.72413 .81713 Mdot
.24124 .81782 Mdot
.12272 .71845 Mdot
.31587 .16439 Mdot
.19271 .61871 Mdot
.33896 .84056 Mdot
.32411 .90627 Mdot
.31388 .91572 Mdot
.31579 .10045 Mdot
.3449 .80003 Mdot
.10621 .024 Mdot
.3207 .88038 Mdot
.20823 .91569 Mdot
.31972 .91111 Mdot
.25656 .86015 Mdot
.26462 .76997 Mdot
.23875 .87544 Mdot
.2061 .82958 Mdot
.20999 .832 Mdot
.15874 .97786 Mdot
.43779 .22747 Mdot
.21763 .76743 Mdot
.22306 .81812 Mdot
.19186 .89034 Mdot
.44621 1 Mdot
.15058 .86987 Mdot
.42461 .18204 Mdot
.02714 .06491 Mdot
.21013 .89167 Mdot
.46271 .93637 Mdot
.14946 .87288 Mdot
.21015 .01427 Mdot
.30105 .01141 Mdot
.5859 .72796 Mdot
.3417 .99255 Mdot
.64537 .47767 Mdot
.40874 .73307 Mdot
.36711 .70565 Mdot
.15689 .86734 Mdot
.06524 .61229 Mdot
.29019 .07306 Mdot
.22856 .66313 Mdot
.99104 .18701 Mdot
.25276 .00119 Mdot
.24357 .86693 Mdot
.03186 .86409 Mdot
.14636 .91988 Mdot
.1937 .83817 Mdot
.43235 .86475 Mdot
.64242 .83876 Mdot
.24701 .88101 Mdot
.71723 .12634 Mdot
.31396 .89765 Mdot
.31867 .08652 Mdot
.27875 .9659 Mdot
.25922 .89177 Mdot
.04048 .86123 Mdot
.2457 .88063 Mdot
.12285 .92742 Mdot
.1089 .91563 Mdot
.33792 .09547 Mdot
.13626 .80396 Mdot
.99856 .93741 Mdot
.20177 .77534 Mdot
.30514 .90519 Mdot
.46445 .08291 Mdot
.08992 .14527 Mdot
.35742 .88983 Mdot
.44204 .75193 Mdot
.20389 .84583 Mdot
.72747 .50035 Mdot
.21879 .81441 Mdot
.34817 .91009 Mdot
.61646 .83492 Mdot
.43967 .97502 Mdot
.21516 .8272 Mdot
.54476 .16131 Mdot
.28154 .78939 Mdot
.63005 .75385 Mdot
.23897 .80411 Mdot
.94454 .93429 Mdot
.29707 .2246 Mdot
.22344 .86719 Mdot
.67065 .89638 Mdot
.23829 .50951 Mdot
.40184 .89183 Mdot
.15433 .88162 Mdot
.27639 .85058 Mdot
.93948 .85363 Mdot
.21376 .77922 Mdot
.29308 .87762 Mdot
.31087 .88452 Mdot
.00665 .84522 Mdot
.25821 .95587 Mdot
.69613 .88767 Mdot
.08059 .92315 Mdot
.46006 .21844 Mdot
.36954 .04009 Mdot
.4381 .62778 Mdot
.16463 .86198 Mdot
.25354 .88829 Mdot
.2182 .08974 Mdot
.98682 .90372 Mdot
.95283 .2886 Mdot
.4583 .81749 Mdot
.207 .89613 Mdot
.24021 .64875 Mdot
.37149 .05783 Mdot
.42741 .24809 Mdot
.28981 .62515 Mdot
.28441 .83163 Mdot
.28422 .76651 Mdot
.21839 .85713 Mdot
.60201 .8007 Mdot
.79199 .52812 Mdot
.29444 .68172 Mdot
.37819 .18912 Mdot
.178 .83383 Mdot
.30473 .90937 Mdot
.1089 .88205 Mdot
.01841 .55033 Mdot
.3327 .77685 Mdot
.61356 .44392 Mdot
.02865 .11778 Mdot
.16336 .4991 Mdot
.2082 .88149 Mdot
.53654 .74533 Mdot
.38988 .99226 Mdot
.25619 .96595 Mdot
.68564 .90614 Mdot
.2141 .80007 Mdot
.87928 .41888 Mdot
.22614 .87801 Mdot
.31683 .92065 Mdot
.06307 .67698 Mdot
.27471 .84277 Mdot
.15577 .88679 Mdot
.88925 .0148 Mdot
.17314 .76222 Mdot
.62808 .94976 Mdot
.06637 .75957 Mdot
.23658 .78905 Mdot
.75372 .78087 Mdot
.22638 .80645 Mdot
.52342 .80897 Mdot
.10917 .68964 Mdot
.2938 .75892 Mdot
.2611 .79526 Mdot
.30663 .89682 Mdot
.1758 .87056 Mdot
.05583 .71138 Mdot
.31105 .21121 Mdot
.69395 .43651 Mdot
.36866 .5368 Mdot
.04553 .94748 Mdot
.3403 .35822 Mdot
.24573 .95596 Mdot
.16983 .88808 Mdot
.28019 .91657 Mdot
.07989 .53752 Mdot
.48724 .99704 Mdot
.03434 .90586 Mdot
.18759 .82082 Mdot
.10941 .91136 Mdot
.40756 .86714 Mdot
.38001 .58915 Mdot
.06554 .71912 Mdot
.19798 .84906 Mdot
.39614 .75521 Mdot
.17677 .90307 Mdot
.13382 .79576 Mdot
.31876 .98985 Mdot
.22527 .95543 Mdot
.19186 .83301 Mdot
.28292 .93833 Mdot
.18409 .83674 Mdot
.85219 .85566 Mdot
.31713 .88924 Mdot
.42028 .14216 Mdot
.20385 .86453 Mdot
.11919 .63357 Mdot
.18577 .82433 Mdot
.22167 .5777 Mdot
.32563 .20695 Mdot
.23048 .87951 Mdot
.43878 .78318 Mdot
.26533 .88812 Mdot
.31003 .03226 Mdot
.23511 .85001 Mdot
.29433 .92708 Mdot
.19808 .15211 Mdot
.10116 .8754 Mdot
.36716 .90871 Mdot
.19895 .83637 Mdot
.31814 .77889 Mdot
.43036 .1506 Mdot
.1777 .84799 Mdot
.28592 .6853 Mdot
.08121 .25465 Mdot
.25173 .34645 Mdot
.2748 .84112 Mdot
.20711 .64875 Mdot
.23554 .74734 Mdot
.18633 .88345 Mdot
.19203 .82796 Mdot
.32155 .90152 Mdot
.04007 .72024 Mdot
.21018 .72639 Mdot
.0581 .69964 Mdot
.36045 .86807 Mdot
.3456 .09405 Mdot
.34805 .91236 Mdot
.23211 .58607 Mdot
.60122 .67266 Mdot
.22488 .90777 Mdot
.4402 .00548 Mdot
.09037 .9935 Mdot
.18713 .87018 Mdot
.21191 .97451 Mdot
.32303 .8937 Mdot
.45484 .96092 Mdot
.16342 .88161 Mdot
.47754 .14029 Mdot
.45641 .15745 Mdot
.35596 .96631 Mdot
.20027 .75331 Mdot
.21959 .49526 Mdot
.24184 .90521 Mdot
.28876 .85949 Mdot
.07221 .05387 Mdot
.32059 .00769 Mdot
.20787 .84347 Mdot
.5299 .3687 Mdot
.96091 .80315 Mdot
.2553 .87692 Mdot
.27349 .67829 Mdot
.31376 .89854 Mdot
.31648 .91297 Mdot
.38767 .92145 Mdot
.3153 .91074 Mdot
.32121 .89382 Mdot
.09601 .67947 Mdot
.35017 .92042 Mdot
.33804 .99515 Mdot
.80455 .72824 Mdot
.26767 .75128 Mdot
.04027 .85278 Mdot
.31791 .7249 Mdot
.2711 .92141 Mdot
.44601 .73426 Mdot
.04143 .95266 Mdot
.21081 .82236 Mdot
.27316 .66806 Mdot
.29651 .88099 Mdot
.35167 .94965 Mdot
.76454 .4886 Mdot
.12684 .18657 Mdot
.31632 .91577 Mdot
.20815 .84056 Mdot
.1756 .87869 Mdot
.04308 .87103 Mdot
.37223 .1535 Mdot
.06603 .74446 Mdot
.26306 .86892 Mdot
.31589 .8823 Mdot
.19057 .84971 Mdot
.84873 .7819 Mdot
.42128 .96976 Mdot
.12975 .82482 Mdot
.34922 .79084 Mdot
.24586 .80548 Mdot
.53994 .65863 Mdot
.3163 .89291 Mdot
.26085 .65018 Mdot
.34759 .8646 Mdot
.27901 .86965 Mdot
.31048 .90939 Mdot
.19805 .81554 Mdot
.21471 .88286 Mdot
.69587 .61674 Mdot
.34307 .87191 Mdot
.30772 .95656 Mdot
.1678 .86628 Mdot
.22856 .67566 Mdot
.74401 .56954 Mdot
.3219 .91061 Mdot
.11499 .82802 Mdot
.24386 .80996 Mdot
.26108 .88934 Mdot
.1893 .9367 Mdot
.15102 .79208 Mdot
.3181 .91985 Mdot
.53421 .64314 Mdot
.45018 .16957 Mdot
.37185 .1242 Mdot
.11183 .82724 Mdot
.8655 .89566 Mdot
.17412 .83115 Mdot
.31275 .88838 Mdot
.31414 .90571 Mdot
.3445 .79338 Mdot
.16945 .87657 Mdot
.15128 .89894 Mdot
.6646 .26467 Mdot
.19491 .91177 Mdot
.86031 .9251 Mdot
.91202 .64149 Mdot
.25578 .74412 Mdot
.21943 .72236 Mdot
.20904 .89789 Mdot
.13344 .27132 Mdot
.29878 .84557 Mdot
.59541 .53349 Mdot
.24689 .8703 Mdot
.2758 .98598 Mdot
.37493 .94481 Mdot
.10948 .83904 Mdot
.09774 .73624 Mdot
.55532 .02715 Mdot
.23903 .80711 Mdot
.59298 .74056 Mdot
.43928 .75483 Mdot
.31653 .33015 Mdot
.15353 .83067 Mdot
.11502 .82451 Mdot
.12788 .88882 Mdot
.99997 .91697 Mdot
.94195 .06215 Mdot
.99475 .54557 Mdot
.26275 .88763 Mdot
.15367 .96539 Mdot
.12048 .24979 Mdot
.15201 .95112 Mdot
.20508 .94989 Mdot
.20471 .96988 Mdot
.17736 .88392 Mdot
.78028 .88211 Mdot
.47514 .16264 Mdot
.11206 .84472 Mdot
.30431 .90473 Mdot
.25911 .89397 Mdot
.11248 .78066 Mdot
.33546 .57224 Mdot
.31602 .7542 Mdot
.6631 .97317 Mdot
.49778 .96965 Mdot
.09733 .99802 Mdot
.2416 .88441 Mdot
.3214 .91009 Mdot
.26328 .86805 Mdot
.68593 .22032 Mdot
.12219 .8629 Mdot
.48874 .19606 Mdot
.26347 .80388 Mdot
.22227 .86367 Mdot
.05335 .8575 Mdot
.32083 .90686 Mdot
.12449 .81474 Mdot
.22651 .85449 Mdot
.26571 .68261 Mdot
.2042 .77754 Mdot
.23976 .87138 Mdot
.53305 .84637 Mdot
.07646 .90982 Mdot
.18703 .87998 Mdot
.53499 .65471 Mdot
.23495 .88798 Mdot
.71245 .8301 Mdot
.03294 .80714 Mdot
.0384 .3863 Mdot
.2977 .05997 Mdot
.27161 .86295 Mdot
.44869 .78759 Mdot
.82979 .64369 Mdot
.76204 .04304 Mdot
.64753 .8159 Mdot
.1904 .90475 Mdot
.20679 .84905 Mdot
.25735 .87916 Mdot
.40179 .94613 Mdot
.32116 .90813 Mdot
.7014 .79431 Mdot
.16802 .87893 Mdot
.18235 .88319 Mdot
.25634 .83853 Mdot
.14806 .08689 Mdot
.18837 .41087 Mdot
.13209 .51585 Mdot
.12735 .12813 Mdot
.20331 .49927 Mdot
.77628 .76956 Mdot
.3088 .88541 Mdot
.33501 .58348 Mdot
.37186 .02353 Mdot
.21126 .85074 Mdot
.2398 .82477 Mdot
.31681 .92141 Mdot
.42928 .90701 Mdot
.27976 .09911 Mdot
.31691 .6524 Mdot
.18477 .81595 Mdot
.14647 .66262 Mdot
.46132 .74516 Mdot
.43087 .76099 Mdot
.13712 .84417 Mdot
.22026 .83824 Mdot
.80823 .5 Mdot
.18352 .84446 Mdot
.17192 .9689 Mdot
.84196 .06778 Mdot
.36389 .96872 Mdot
.23128 .80634 Mdot
.29913 .8797 Mdot
.15207 .88034 Mdot
.20985 .8247 Mdot
.31962 .77018 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool2o`0000kooooo00?o0000ooooooooool01Oooool2o`0000Ko
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool3o`0000Gooooo
0_l0000?ooooo`03o`000?oooooooooo00cooooo0_l00006ooooo`;o00001oooool00ol0003ooooo
ooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`;o00001oooool00ol0003ooooo
ooooo`09ooooo`;o00000_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool00_ooool001kooooo00?o0000ooooooooool09Oooool3o`0000Gooooo0_l0
00000ooooooo0000o`00000Kooooo`;o00001_ooool2o`0000Oooooo0_l00004ooooo`Co00003_oo
ool2o`0001?ooooo0_l0002jooooo`007_ooool00ol0003oooooooooo`03ooooo`;o0000:oooool2
o`0002cooooo0_l00004ooooo`;o00001?ooool2o`000=_ooooo000Nooooo`03o`000?oooooooooo
00?ooooo0_l0000Vooooo`;o00004oooool2o`0001cooooo0_l0000:ooooo`;o0000/Oooool2o`00
02Sooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0000Eooooo`;o00002oooool2o`0001?o
oooo0_l0000Nooooo`;o0000^oooool2o`0002Sooooo000Nooooo`03o`000?oooooooooo00Oooooo
0_l0000Eooooo`;o00007Oooool2o`0000Sooooo0_l0000<ooooo`;o00002Oooool2o`000>Gooooo
000Nooooo`03o`000?oooooooooo01kooooo0_l0000Kooooo`Co00002?ooool2o`0000[ooooo1?l0
000Nooooo`;o0000d?ooool001kooooo00?o0000ooooooooool07_ooool2o`0001_ooooo0_l0000F
ooooo`;o00008?ooool2o`0003Wooooo0_l0000Rooooo`;o0000LOooool001kooooo00?o0000oooo
ooooool0;Oooool2o`0001Sooooo0_l0001Wooooo`;o00008_ooool2o`00077ooooo000Nooooo`03
o`000?oooooooooo02gooooo0_l00009ooooo`;o00003Oooool2o`0001Sooooo0_l0000?ooooo`;o
0000doooool001kooooo00?o0000ooooooooool0>?ooool2o`0002Oooooo0_l00007ooooo`;o0000
1_ooool2o`000=?ooooo000Nooooo`03o`000?oooooooooo02oooooo0_l0000iooooo`;o00002?oo
ool2o`000=7ooooo000Nooooo`03o`000?oooooooooo02oooooo0_l00013ooooo`;o0000O_ooool2
o`00057ooooo000Nooooo`03o`000?oooooooooo0=oooooo0_l0000Cooooo`;o0000DOooool001ko
oooo00?o0000ooooooooool0<_ooool2o`0004Oooooo0_l00002ooooo`;o0000G_ooool2o`0006Ko
oooo000Nooooo`;o0000<oooool2o`0001gooooo1?l0000Vooooo`;o00000_ooool2o`000<Kooooo
000Nooooo`03o`000?oooooooooo00[ooooo0_l00007ooooo`;o0000??ooool4o`00037ooooo0_l0
002oooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o00001oooool2o`0001_ooooo0_l0000Y
ooooo`;o00006?ooool2o`0000oooooo0_l0002oooooo`007_ooool00ol0003oooooooooo`0`oooo
o`;o0000:Oooool4o`0001Kooooo0_l0002gooooo`;o00005oooool001kooooo00?o0000oooooooo
ool01Oooool2o`0005Kooooo0_l00027ooooo`;o0000A_ooool2o`0001Oooooo000Nooooo`03o`00
0?oooooooooo00Gooooo0_l0003Oooooo`;o00009_ooool2o`0003Oooooo000Nooooo`03o`000?oo
oooooooo0=[ooooo0_l0000booooo`;o0000=oooool001kooooo00?o0000ooooooooool0F_ooool2
o`0001?ooooo0_l0001Yooooo`;o0000Joooool001kooooo00?o0000ooooooooool0;oooool2o`00
02Wooooo0_l0000Cooooo`;o0000E?ooool2o`00083ooooo000Nooooo`03o`000?oooooooooo02oo
oooo0_l0002Dooooo`;o0000>?ooool2o`0004Kooooo000Nooooo`03o`000?oooooooooo09?ooooo
0_l0001Zooooo`;o0000A_ooool001kooooo00?o0000ooooooooool08Oooool2o`0000Wooooo0_l0
000eooooo`;o0000;_ooool2o`000;;ooooo000Nooooo`03o`000?oooooooooo027ooooo0_l00009
ooooo`;o00005Oooool2o`0001kooooo0_l0003Rooooo`007_ooool00ol0003oooooooooo`13oooo
o`;o0000Coooool2o`0002;ooooo0_l0001Hooooo`;o0000<oooool001kooooo00?o0000oooooooo
ool0J_ooool4o`0002Kooooo0_l0000?ooooo`;o00004Oooool2o`0005Sooooo0_l0000cooooo`00
7_ooool00ol0003oooooooooo`0Vooooo`;o00006oooool2o`0001;ooooo0_l0000Aooooo`Co0000
=oooool2o`0008_ooooo0_l0000Cooooo`007_ooool2o`0002Oooooo0_l0000Kooooo`;o00004_oo
ool2o`0000[ooooo0_l000000ooooooo0000o`000004ooooo`;o0000a?ooool2o`0001?ooooo000N
ooooo`03o`000?oooooooooo06?ooooo0_l000000ooooooo0000o`00003Oooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo08[ooooo0_l0002kooooo`00
7_ooool00ol0003oooooooooo`2:ooooo`;o0000Soooool2o`0002[ooooo000Nooooo`03o`000?oo
oooooooo00Gooooo0_l0000[ooooo`;o0000G?ooool2o`0008Wooooo0_l0000Zooooo`007_ooool0
0ol0003oooooooooo`05ooooo`;o00004_ooool2o`0001Oooooo0_l0000Looooo`;o0000?_ooool2
o`000:Wooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o00009Oooool2o`00
00kooooo0_l00003ooooo`;o00007_ooool2o`000<Cooooo0_l0000:ooooo`007_ooool00ol0003o
ooooooooo`10ooooo`;o00004oooool2o`0001kooooo0_l0001^ooooo`;o0000H?ooool001kooooo
00?o0000ooooooooool09Oooool2o`000;kooooo0_l0001Pooooo`007_ooool00ol0003ooooooooo
o`0Uooooo`;o0000oooooolQooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo04oooooo0_l0000cooooo`;o0000`Oooool001kooooo00?o0000oooooooo
ool0Coooool2o`0002Cooooo0_l0000=ooooo`?o00004?ooool2o`000:kooooo000Nooooo`03o`00
0?oooooooooo01Wooooo0_l0001Jooooo`;o00003_ooool2o`00013ooooo0_l0002^ooooo`007_oo
ool00ol0003oooooooooo`0Iooooo`;o0000ooooool]ooooo`007_ooool2o`0002Cooooo0_l0000G
ooooo`;o0000B_ooool2o`000;gooooo000Nooooo`03o`000?oooooooooo02?ooooo0_l0000Goooo
o`;o0000=oooool2o`00017ooooo0_l0002mooooo`007_ooool00ol0003oooooooooo`1Aooooo`;o
00008_ooool2o`0001Wooooo0_l0002eooooo`007_ooool00ol0003oooooooooo`1Aooooo`;o0000
?Oooool2o`0001_ooooo0_l0002Hooooo`007_ooool2o`0006Cooooo0_l0000aooooo`;o00005Ooo
ool2o`0009Sooooo000Nooooo`;o00007oooool2o`0002kooooo0_l0000Cooooo`;o0000<Oooool2
o`000:oooooo000Nooooo`03o`000?oooooooooo01kooooo0_l0000^ooooo`;o0000?_ooool2o`00
01?ooooo0_l0002Rooooo`007_ooool00ol0003oooooooooo`2>ooooo`;o00004oooool2o`000:;o
oooo000Nooooo`03o`000?oooooooooo0?oooooo9oooool2o`0001oooooo000Nooooo`03o`000?oo
oooooooo0?oooooo9oooool2o`0001oooooo000Nooooo`03o`000?oooooooooo02Sooooo0_l0001L
ooooo`;o0000_oooool001kooooo00?o0000ooooooooool0:?ooool2o`0004gooooo0_l0000=oooo
o`;o0000Doooool2o`0005Cooooo0_l0000Dooooo`007_ooool00ol0003oooooooooo`0Uooooo`;o
0000D?ooool2o`0000;ooooo0_l0001Nooooo`;o0000E?ooool2o`0000_ooooo0_l00007ooooo`00
7_ooool00ol0003oooooooooo`0Uooooo`;o0000D?ooool2o`0000;ooooo0_l00031ooooo`;o0000
1oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo
00?o0000ooooooooool0Moooool2o`0008oooooo0_l0000mooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`2Kooooo`;o0000Joooool2o`0003gooooo0003ooooo`05oa0@4?ooooooooooooooool@
41003?ooool00onHV9So8B4Qonk^kP07ooooo`?o0000Voooool2o`000:[ooooo0003ooooo`05o`00
0?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo083o
oooo0_l00035ooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_oo
ool01Oooool00ol0003oooooooooo`1Vooooo`;o00006?ooool2o`0005gooooo0_l0001Vooooo`00
0oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`1Vooooo`;o0000Moooool2o`0006Kooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0HOooool2o`00
0>Cooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0HOooool2o`0002Cooooo0_l0001Aooooo`;o0000Joooool0
01kooooo00?o0000ooooooooool0Qoooool2o`0000Sooooo0_l00017ooooo`;o0000Joooool001ko
oooo00?o0000ooooooooool0TOooool2o`0004Sooooo0_l0001Zooooo`007_ooool00ol0003ooooo
ooooo`1Looooo`;o0000OOooool2o`0006[ooooo000Nooooo`03o`000?oooooooooo05cooooo0_l0
000/ooooo`;o0000^oooool001kooooo00?o0000ooooooooool0R_ooool2o`000;_ooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0:Oooool2o`0008_ooooo0_l0002?ooooo`007_ooool00ol0
003oooooooooo`0Sooooo`;o00001?ooool2o`0005cooooo0_l0000]ooooo`;o0000Soooool001ko
oooo0_l0000Tooooo`;o0000H_ooool2o`000;kooooo000Nooooo`03o`000?oooooooooo01Kooooo
0_l0000jooooo`;o0000loooool001kooooo00?o0000ooooooooool05_ooool2o`0000Wooooo0_l0
000_ooooo`;o0000loooool001kooooo00?o0000ooooooooool08Oooool2o`000?oooooo9Oooool0
01kooooo00?o0000ooooooooool0e?ooool2o`00077ooooo000Nooooo`03o`000?oooooooooo0=Co
oooo0_l0001aooooo`007_ooool00ol0003oooooooooo`0Wooooo`;o0000oooooolOooooo`007_oo
ool00ol0003oooooooooo`0Wooooo`;o0000oooooolOooooo`007_ooool00ol0003oooooooooo`1g
ooooo`;o0000c_ooool001kooooo00?o0000ooooooooool0Moooool2o`000<kooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3ooooooc?ooooo0_l0000Cooooo`007_ooool00ol0003oooooooooo`3o
oooooc?ooooo0_l0000Cooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo0_l00025ooooo`;o0000`Oooool001kooooo00?o
0000ooooooooool0Q?ooool2o`000<7ooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0000g
ooooo`;o0000ooooool6ooooo`007_ooool00ol0003oooooooooo`07ooooo`;o00001?ooool2o`00
037ooooo0_l0003oooooo`Kooooo000Nooooo`03o`000?oooooooooo00gooooo0_l0001dooooo`;o
0000`_ooool001kooooo00?o0000ooooooooool0Poooool2o`000<;ooooo000Nooooo`03o`000?oo
oooooooo01Wooooo0_l0002oooooo`;o0000Joooool001kooooo00?o0000ooooooooool06Oooool2
o`0004Sooooo0_l00015ooooo`;o0000;_ooool2o`0006_ooooo000Nooooo`03o`000?oooooooooo
06?ooooo0_l00015ooooo`;o0000Voooool001kooooo00?o0000ooooooooool0Hoooool2o`000>;o
oooo000Nooooo`03o`000?oooooooooo06?ooooo0_l0003Rooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0S_ooool2o`000;Oooooo000Nooooo`03o`000?oooooooooo08kooooo0_l0002gooooo`00
7_ooool00ol0003oooooooooo`1>ooooo`;o0000moooool001kooooo0_l0001?ooooo`;o0000mooo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`1[oooo
o`;o0000f_ooool001kooooo00?o0000ooooooooool08_ooool2o`0004Oooooo0_l0003Jooooo`00
7_ooool00ol0003oooooooooo`0?ooooo`;o00004Oooool2o`000?oooooo9?ooool001kooooo00?o
0000ooooooooool03oooool2o`000?oooooo=oooool001kooooo00?o0000ooooooooool0H?ooool2
o`0004Kooooo0_l0002Mooooo`007_ooool00ol0003oooooooooo`1Pooooo`;o0000A_ooool2o`00
09gooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
f?ooool2o`0006gooooo000Nooooo`03o`000?oooooooooo0=Sooooo0_l0001]ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0001Boooo
o`;o0000jOooool001kooooo00?o0000ooooooooool02?ooool2o`0005;ooooo0_l0003@ooooo`;o
00005oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003
oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0ooooool_ooooo`;o00005oooool000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go
00001_ooool3o`000?ooooooB?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04
odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol0003o
oooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`3o
ooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007
ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<
ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0>Oooool2o`0002Oooooo0_l0003S
ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool0
0ol0003oooooooooo`0iooooo`;o00007_ooool2o`0000Oooooo0_l0003Sooooo`007_ooool00ol0
003oooooooooo`1Iooooo`;o0000_oooool2o`0001Oooooo0_l0000Booooo`007_ooool00ol0003o
ooooooooo`0<ooooo`;o0000ooooool=ooooo`;o00005oooool2o`0001;ooooo000Nooooo`03o`00
0?oooooooooo00cooooo0_l0002Hooooo`;o0000Woooool001kooooo00?o0000ooooooooool0Y_oo
ool2o`0009oooooo000Nooooo`03o`000?oooooooooo03Sooooo0_l0003oooooo`kooooo000Noooo
o`03o`000?oooooooooo03Sooooo0_l0003oooooo`kooooo000Nooooo`03o`000?oooooooooo08_o
oooo0_l0001@ooooo`;o0000J?ooool001kooooo00?o0000ooooooooool0Roooool2o`00053ooooo
0_l0001Xooooo`007_ooool00ol0003oooooooooo`0Nooooo`;o0000Xoooool2o`0008;ooooo000N
ooooo`03o`000?oooooooooo01kooooo0_l0002Sooooo`;o0000P_ooool001kooooo00?o0000oooo
ooooool0l_ooool2o`0005?ooooo000Nooooo`;o0000loooool2o`0005?ooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0WOooool2o`000:Sooooo000N
ooooo`03o`000?oooooooooo05Kooooo0_l00015ooooo`;o0000Z?ooool001kooooo00?o0000oooo
ooooool0E_ooool2o`000:oooooo0_l0000nooooo`007_ooool00ol0003oooooooooo`0mooooo`;o
0000b?ooool2o`0003kooooo000Nooooo`03o`000?oooooooooo03gooooo0_l0003oooooo`Wooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0W_ooool2
o`0002kooooo0_l0001gooooo`007_ooool00ol0003oooooooooo`2Nooooo`;o0000;_ooool2o`00
02_ooooo0_l0001:ooooo`007_ooool00ol0003oooooooooo`3kooooo`;o0000B_ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3dooooo`;o0000DOoo
ool001kooooo00?o0000ooooooooool0m?ooool2o`00057ooooo000Nooooo`03o`000?oooooooooo
04?ooooo0_l0003oooooo`?ooooo000Nooooo`03o`000?oooooooooo037ooooo0_l0000;ooooo`;o
00000oooool2o`000=cooooo0_l0000Tooooo`007_ooool2o`0003;ooooo0_l0000;ooooo`;o0000
Z?ooool2o`0001Wooooo0_l0000Looooo`;o00009?ooool001kooooo00?o0000ooooooooool0j?oo
ool2o`0001Wooooo0_l00012ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo04Wooooo0_l0003looooo`007_ooool00ol0003oooooooooo`19ooooo`;o
0000F_ooool2o`000:3ooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l00008ooooo`;o0000
L_ooool2o`000:3ooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l00008ooooo`;o0000@_oo
ool2o`000=3ooooo000Nooooo`03o`000?oooooooooo07Gooooo0_l0003@ooooo`007_ooool00ol0
003oooooooooo`0gooooo`;o0000ooooool?ooooo`007_ooool00ol0003oooooooooo`0gooooo`;o
0000a?ooool2o`0004Sooooo000Nooooo`03o`000?oooooooooo0;gooooo0_l0000nooooo`;o0000
B?ooool001kooooo00?o0000ooooooooool0_Oooool2o`0008Sooooo000Nooooo`03o`000?oooooo
oooo01Kooooo0_l0001Looooo`;o0000dOooool001kooooo00?o0000ooooooooool05_ooool2o`00
05cooooo0_l0003Aooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o0000?Oooool2o`0009Ko
oooo0_l0001=ooooo`;o00001_ooool001kooooo00?o0000ooooooooool06Oooool2o`0003gooooo
0_l00028ooooo`;o00003?ooool2o`0004gooooo0_l00006ooooo`007_ooool3o`0000;ooooo0_l0
001<ooooo`;o0000T?ooool2o`0006?ooooo000Nooooo`?o00000_ooool2o`0004cooooo0_l0003e
ooooo`007_ooool00ol0003oooooooooo`1Oooooo`;o0000Hoooool2o`00087ooooo000Nooooo`03
o`000?oooooooooo00;ooooo0_l0001Kooooo`;o0000Hoooool2o`00087ooooo000Nooooo`03o`00
0?oooooooooo00;ooooo0_l0003oooooodCooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0k_ooool2o`0005Oooooo000Nooooo`03o`000?oooooooooo
05;ooooo1?l0000Cooooo`;o0000Poooool2o`0005Oooooo000Nooooo`03o`000?oooooooooo05;o
oooo1?l0000Cooooo`;o0000g?ooool001kooooo00?o0000ooooooooool0A?ooool2o`000?oooooo
0_ooool001kooooo00?o0000ooooooooool0A?ooool2o`000?oooooo0_ooool001kooooo00?o0000
ooooooooool04?ooool2o`0004;ooooo0_l0000@ooooo`;o000000?oooooo`000?l00000ZOooool2
o`00037ooooo000Nooooo`03o`000?oooooooooo013ooooo0_l0000eooooo`;o00002oooool2o`00
013ooooo0_l000000ooooooo0000o`00002Yooooo`;o0000<Oooool001kooooo00?o0000oooooooo
ool0Aoooool2o`0002kooooo0_l0003>ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`1goooo
o`;o0000c_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmE
EEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool08Oooool2o`00073ooooo0_l0000B
ooooo`;o0000W_ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooo
ooooooooool000001_ooool3o`00027ooooo0_l0000Mooooo`;o00002oooool2o`0004Cooooo0_l0
000Booooo`;o0000W_ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`10ooooo`;o00002oooool2o`000?Sooooo
0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Ko
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol@413ooooooooooooooooo410@00_o
oooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo017o
oooo0_l0003oooooobkooooo0_l00005ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`0Aooooo`;o0000@Oooool2o`00
0>[ooooo0_l00005ooooo`007_ooool00ol0003oooooooooo`0kooooo`;o00005oooool2o`0001Ko
oooo0_l00006ooooo`;o0000J?ooool2o`0006Oooooo000Nooooo`03o`000?oooooooooo02_ooooo
0_l00007ooooo`;o00001Oooool2o`0002oooooo0_l00006ooooo`;o0000J?ooool2o`0006Oooooo
000Nooooo`03o`000?oooooooooo02_ooooo0_l00007ooooo`;o00009?ooool2o`000>_ooooo000N
ooooo`03o`000?oooooooooo00gooooo0_l0001;ooooo`;o0000;_ooool2o`000:oooooo0_l0000:
ooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o0000Noooool2o`000:oooooo0_l0000:oooo
o`007_ooool00ol0003oooooooooo`0@ooooo`;o00004Oooool2o`000?oooooo8oooool001kooooo
00?o0000ooooooooool04?ooool2o`00017ooooo0_l0002`ooooo`;o0000L?ooool001kooooo00?o
0000ooooooooool0:_ooool2o`0003oooooo0_l0001Xooooo`;o00005_ooool2o`0005Sooooo000N
ooooo`03o`000?oooooooooo02[ooooo0_l0000oooooo`;o0000?Oooool2o`00047ooooo0_l0000K
ooooo`;o00005oooool3o`00027ooooo000Nooooo`03o`000?oooooooooo0:[ooooo0_l0001Noooo
o`;o00005oooool3o`00027ooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0000Dooooo`;o
00008?ooool2o`0000Wooooo0_l00005ooooo`;o0000=_ooool2o`0000_ooooo0_l0002_ooooo`00
7_ooool2o`0000Sooooo0_l0000Dooooo`;o00005?ooool2o`0000[ooooo0_l00009ooooo`;o0000
1Oooool2o`00013ooooo0_l0000Tooooo`;o00002oooool2o`000:oooooo000Nooooo`03o`000?oo
oooooooo03?ooooo0_l0000Oooooo`;o00003Oooool2o`0004Gooooo0_l0002Kooooo`007_ooool0
0ol0003oooooooooo`0>ooooo`;o0000A?ooool2o`0005Cooooo1Ol0002Hooooo`007_ooool00ol0
003oooooooooo`0>ooooo`;o00007?ooool2o`0000Kooooo0_l0001^ooooo`;o00001Oooool4o`00
09Sooooo000Nooooo`03o`000?oooooooooo02cooooo0_l00006ooooo`;o00004?ooool2o`0005co
oooo0_l0002Qooooo`007_ooool00ol0003oooooooooo`16ooooo`;o00003Oooool2o`000?3ooooo
000Nooooo`03o`000?oooooooooo05Gooooo0_l0000Uooooo`;o0000bOooool001kooooo00?o0000
ooooooooool0:?ooool2o`0005;ooooo0_l00011ooooo`;o0000B?ooool2o`0000Cooooo0_l0000f
ooooo`007_ooool3o`00013ooooo0_l0000Fooooo`;o00007?ooool2o`00067ooooo0_l0000Doooo
o`;o0000B?ooool2o`0000Cooooo0_l0000fooooo`007_ooool3o`00013ooooo0_l00009ooooo`;o
0000:Oooool2o`0000Cooooo0_l00007ooooo`;o0000D_ooool2o`0009cooooo000Nooooo`03o`00
0?oooooooooo01_ooooo0_l0000Looooo`;o00001_ooool2o`0000Wooooo0_l00004ooooo`Go0000
1Oooool2o`000=cooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`0iooooo`;o00001_oo
ool2o`0000oooooo1?l00003ooooo`;o000000?oooooo`000?l00000D?ooool2o`0008[ooooo0_l0
000;ooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o0000>?ooool2o`0000?ooooo0_l0001>
ooooo`;o0000Uoooool001kooooo00?o0000ooooooooool07oooool2o`0003?ooooo0_l00008oooo
o`?o00002_ooool2o`000=[ooooo000Nooooo`03o`000?oooooooooo05Cooooo0_l00009ooooo`;o
00002_ooool2o`000=[ooooo000Nooooo`03o`000?oooooooooo00oooooo0_l0000;ooooo`;o0000
oooooolZooooo`007_ooool2o`00013ooooo0_l00006ooooo`;o00000oooool2o`0001;ooooo0_l0
003ooooooaKooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0000Gooooo`;o00006Oooool2
o`0002Kooooo0_l0000Xooooo`;o0000Z?ooool001kooooo00?o0000ooooooooool09?ooool2o`00
02Gooooo0_l0000Vooooo`;o0000:?ooool2o`000:Sooooo000Nooooo`03o`000?oooooooooo00ko
oooo0_l0000Dooooo`;o0000oooooolRooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o0000
BOooool2o`0002Sooooo0_l0002Yooooo`;o00005oooool001kooooo00?o0000ooooooooool0FOoo
ool2o`0002Sooooo0_l00004ooooo`;o0000Xoooool2o`0001Oooooo000Nooooo`03o`000?oooooo
oooo00Wooooo0_l00006ooooo`;o00004Oooool2o`00013ooooo0_l000000ooooooo0000o`00000Q
ooooo`;o0000:oooool2o`000;cooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l00006oooo
o`;o00004Oooool2o`00013ooooo0_l000000ooooooo0000o`000008ooooo`;o00005oooool2o`00
00;ooooo0_l0003Uooooo`007_ooool00ol0003oooooooooo`10ooooo`;o000000?oooooo`000?l0
00006oooool2o`000003ooooool0003o00000>;ooooo000Nooooo`03o`000?oooooooooo043ooooo
0_l0000Qooooo`;o0000EOooool2o`0004Gooooo0_l0000iooooo`;o00002Oooool001kooooo00?o
0000ooooooooool08_ooool2o`0005gooooo0_l0000gooooo`;o0000AOooool2o`0003Wooooo0_l0
0009ooooo`007_ooool00ol0003oooooooooo`0Looooo`;o00001?ooool2o`0001gooooo0_l0000n
ooooo`;o00002_ooool2o`000;Sooooo000Nooooo`03o`000?oooooooooo01cooooo0_l0000Ioooo
o`;o00002?ooool2o`0002Oooooo0_l0000Qooooo`;o0000^?ooool001kooooo00?o0000oooooooo
ool0=oooool2o`0000Kooooo1?l0000>ooooo`;o00005oooool2o`00057ooooo0_l00028ooooo`00
7_ooool00ol0003oooooooooo`0Aooooo`;o00009?ooool2o`0000Kooooo0_l0000>ooooo`Co0000
3?ooool2o`0002Oooooo0_l00008ooooo`;o00005_ooool2o`00017ooooo0_l00028ooooo`007_oo
ool00ol0003oooooooooo`07ooooo`;o00002?ooool2o`0000oooooo0_l0000Tooooo`;o00001Ooo
ool2o`0000kooooo0_l0000Wooooo`;o00002?ooool2o`0001Kooooo0_l0002Kooooo`007_ooool2
o`0000Sooooo0_l00004ooooo`;o00004oooool2o`0002Cooooo0ol00008ooooo`;o0000l_ooool0
01kooooo00?o0000ooooooooool03Oooool2o`0000Gooooo0_l00007ooooo`;o00007_ooool2o`00
00[ooooo0_l00008ooooo`;o00003_ooool2o`0002Kooooo0ol0000kooooo`;o0000O?ooool001ko
oooo00?o0000ooooooooool05?ooool2o`0000Oooooo0_l0000Fooooo`;o00001_ooool2o`0002Co
oooo0_l0000Hooooo`Co00002_ooool3o`0003_ooooo0_l0001looooo`007_ooool00ol0003ooooo
ooooo`0Aooooo`;o00000oooool2o`0001gooooo1?l0000Rooooo`;o00008?ooool4o`0000Oooooo
0_l0002mooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o00000oooool2o`0000Sooooo0_l0
000Booooo`;o000000?oooooo`000?l000008_ooool2o`0001oooooo0_l0000:ooooo`;o0000_Ooo
ool001kooooo0ol0000Pooooo`;o00004_ooool2o`0002;ooooo0_l0000Rooooo`;o0000bOooool0
01kooooo0ol0000Xooooo`;o00006Oooool2o`0000gooooo0_l00004ooooo`;o00002_ooool2o`00
05cooooo0_l0000dooooo`;o0000COooool001kooooo00?o0000ooooooooool01oooool2o`00017o
oooo0_l0000<ooooo`;o00006Oooool2o`0000gooooo0_l0000@ooooo`;o00001?ooool2o`0005Ko
oooo0_l0000dooooo`;o0000COooool001kooooo00?o0000ooooooooool01oooool2o`00017ooooo
0_l0000Qooooo`;o0000:oooool2o`0008Gooooo0_l0001Dooooo`007_ooool00ol0003ooooooooo
o`0mooooo`?o000000Coooooo`000?l0003ooooo0_l0000Mooooo`;o00000oooool2o`0000?ooooo
0_l00022ooooo`;o0000E?ooool001kooooo00?o0000ooooooooool08?ooool2o`0001Oooooo0_l0
0003ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Mooooo`;o00000_ooool3o`0000?ooooo
0_l00022ooooo`;o00007Oooool2o`0003Gooooo000Nooooo`03o`000?oooooooooo023ooooo0_l0
000Gooooo`;o0000;?ooool3o`00027ooooo0_l0001Tooooo`;o00007Oooool2o`0003Gooooo000N
ooooo`03o`000?oooooooooo02_ooooo0_l0000iooooo`;o00008oooool2o`000003ooooool0003o
00000;Oooooo000Nooooo`03o`000?oooooooooo02_ooooo0_l0000@ooooo`Co00002?ooool2o`00
00cooooo0_l0000=ooooo`;o00001Oooool2o`0001oooooo0_l0002gooooo`000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`0]ooooo`;o00003_ooool4o`0000Gooooo1Ol0000<ooooo`;o00004oooool3
o`0003[ooooo0_l0000eooooo`;o0000IOooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool09ooo
ool2o`0000Cooooo0_l0000Gooooo`?o00002?ooool2o`0001Wooooo1?l0000iooooo`;o0000=Ooo
ool2o`0006Gooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000000Kooooo0ol0000Pooooo`;o00001Oooool2o`0001?ooooo0_l00002ooooo`?o0000
0oooool2o`0000Wooooo0_l0000Iooooo`Co0000D?ooool2o`0008Gooooo0003ooooo`05o`000?oo
ooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000oooooooo
ool08?ooool2o`0000Kooooo0_l0000Booooo`;o00000_ooool3o`0000Oooooo0_l00006ooooo`;o
00006?ooool2o`0000?ooooo0_l0000Vooooo`;o00009Oooool2o`0007;ooooo0_l0000Aooooo`00
0oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006oooo
o`03o`000?oooooooooo00Oooooo0_l0000Oooooo`;o00004Oooool2o`0000Oooooo1Ol000000ooo
oooo0000o`000002o`0000Cooooo0_l0000Mooooo`;o00009_ooool2o`0009Wooooo0_l0000Aoooo
o`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006
ooooo`03o`000?oooooooooo00Oooooo0_l0000booooo`;o00001oooool5o`000003ooooool0003o
000000;o00004oooool2o`0004?ooooo0_l0002Oooooo`000oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo02gooooo0_l0
000Eooooo`Go00000_ooool2o`0001Cooooo0_l00007ooooo`;o0000>_ooool2o`0009oooooo0003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo
00?o0000ooooooooool09?ooool2o`0000Oooooo0_l00009ooooo`;o00000_ooool2o`0000;ooooo
0_l000001?oooooo0000o`000?ooool2o`0000Cooooo0_l0000Looooo`;o0000H_ooool2o`0007Oo
oooo000Nooooo`03o`000?oooooooooo02Cooooo0_l00007ooooo`;o00002Oooool2o`0000;ooooo
0_l00002ooooo`So00000_ooool4o`0000_ooooo0_l00008ooooo`;o0000;?ooool2o`0003_ooooo
0_l0000Gooooo`;o00002?ooool2o`0004Gooooo0_l0000=ooooo`007_ooool00ol0003ooooooooo
o`03ooooo`;o00009oooool2o`0000_ooooo0_l00004ooooo`Wo00000_ooool2o`0000gooooo0_l0
0008ooooo`;o00007_ooool2o`0000cooooo0_l0001Dooooo`;o00002?ooool2o`0001?ooooo0_l0
000`ooooo`;o00003Oooool001kooooo00?o0000ooooooooool00oooool2o`0001cooooo0_l00003
ooooo`;o00001?ooool2o`0000[ooooo0ol00004ooooo`Go00000oooool2o`000003ooooool0003o
000000gooooo0_l0000Xooooo`;o0000POooool2o`0003oooooo000Nooooo`03o`000?oooooooooo
023ooooo0ol00003ooooo`;o00004?ooool5o`0000;ooooo1Ol00003ooooo`;o000000?oooooo`00
0?l000003Oooool2o`0000Sooooo0_l0000>ooooo`;o0000d_ooool001kooooo00?o0000oooooooo
ool08?ooool3o`0000_ooooo0_l00003ooooo`?o00000_ooool6o`000003ooooool0003o000000?o
00002_ooool2o`0000Sooooo0_l00009ooooo`;o00003_ooool2o`00017ooooo0_l0001Looooo`?o
00008Oooool2o`0003gooooo000Nooooo`03o`000?oooooooooo02Sooooo1?l00002ooooo`;o0000
0oooool5o`000003ooooool0003o000000Oo00001Oooool4o`000003ooooool0003o000000;o0000
2?ooool2o`0000Wooooo0_l00009ooooo`;o00000_ooool2o`0001;ooooo0_l0000looooo`;o0000
6Oooool2o`0000?ooooo0ol0000Qooooo`;o0000?Oooool001kooooo00?o0000ooooooooool0:?oo
ool4o`000004ooooool0003o0000o`0000Kooooo3Ol000001?oooooo0000o`000?ooool4o`000003
ooooool0003o000001Gooooo0_l00009ooooo`;o00000_ooool2o`00053ooooo0_l0000Iooooo`;o
0000E?ooool2o`00013ooooo000Nooooo`03o`000?oooooooooo01oooooo0_l00007ooooo`Co0000
00?oooooo`000?l000002?ooool3o`000003ooooool0003o000000Wo00002Oooool2o`0000Cooooo
0_l0000Cooooo`;o0000HOooool2o`0006Kooooo0_l0000@ooooo`007_ooool4o`0001kooooo0_l0
0007ooooo`Ko00002?ooool2o`0000?ooooo1ol000000ooooooo0000o`000005ooooo`;o00000ooo
ool2o`0000Cooooo0_l0000Cooooo`;o0000HOooool2o`0007Sooooo000Nooooo`Co00007oooool4
o`0000Cooooo0_l00002ooooo`;o00002?ooool4o`0000;ooooo1Ol00003ooooo`;o00001?ooool2
o`0000Oooooo1?l00006ooooo`;o0000B_ooool2o`0000Sooooo0_l0002Booooo`007_ooool3o`00
023ooooo1?l00004ooooo`;o00003?ooool;o`0000?ooooo0_l00002ooooo`?o00002?ooool2o`00
00Sooooo0_l0001:ooooo`;o00002?ooool2o`0004Oooooo0_l00019ooooo`007_ooool2o`0000[o
oooo0_l0000Mooooo`;o00000oooool2o`0000Oooooo0_l00002ooooo`Wo00001Oooool3o`0000_o
oooo0_l000000ooooooo0000o`000003ooooo`;o0000Aoooool2o`0005?ooooo0_l00019ooooo`00
7_ooool00ol0003oooooooooo`09ooooo`;o00005Oooool2o`0000Wooooo1?l00004ooooo`;o0000
1oooool3o`000004ooooool0003o0000o`0000?ooooo1Ol0000;ooooo`;o000000?oooooo`000?l0
00000oooool2o`0000Kooooo0_l00008ooooo`;o0000=Oooool2o`0006Sooooo0_l0000Jooooo`;o
00006?ooool001kooooo00?o0000ooooooooool03Oooool2o`00017ooooo1?l00007ooooo`?o0000
1Oooool2o`0000gooooo2?l00004ooooo`;o00001?ooool2o`0000Cooooo0_l0000:ooooo`;o0000
2?ooool2o`0000Sooooo0_l00002ooooo`;o00003_ooool2o`00087ooooo0_l0000Jooooo`;o0000
6?ooool001kooooo00?o0000ooooooooool02Oooool2o`0000;ooooo0_l0000Cooooo`;o00001ooo
ool3o`0000?ooooo0_l0000?ooooo`So00001?ooool3o`0000?ooooo0_l00004ooooo`;o000000?o
ooooo`000?l000006oooool2o`0000;ooooo0_l0000>ooooo`;o0000E_ooool2o`0005oooooo000N
ooooo`03o`000?oooooooooo00Kooooo0_l000000ooooooo0000o`00000Iooooo`;o00001Oooool2
o`0000Cooooo0_l0000;ooooo`;o00001?ooool4o`0000Oooooo0_l00003ooooo`;o00001?ooool7
o`0000?ooooo0_l00007ooooo`;o00006Oooool2o`0001cooooo0_l0000nooooo`;o0000Goooool0
01kooooo00?o0000ooooooooool01_ooool2o`00017ooooo0_l00002ooooo`;o00001Oooool2o`00
00Wooooo0_l000000ooooooo0000o`000002ooooo`?o00001Oooool2o`0000?ooooo1?l00004oooo
o`;o00001?ooool2o`000004ooooool0003o0000o`0000?ooooo1?l000000ooooooo0000o`000003
ooooo`;o00001oooool2o`0000;ooooo0_l0000=ooooo`;o00001_ooool2o`0001cooooo0_l0001T
ooooo`;o0000>Oooool001kooooo00?o0000ooooooooool02_ooool2o`0000gooooo0_l00002oooo
o`;o00000_ooool2o`0000Gooooo0_l00003ooooo`Co000000?oooooo`000?l000001ol00008oooo
o`Co00000oooool4o`0000?ooooo0_l00002ooooo`Co00000_ooool2o`0001Cooooo0_l0000=oooo
o`;o0000R_ooool2o`0003Wooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0000Eooooo`?o
00001?ooool3o`000005ooooool0003o0000o`000?ooool00ol000000ooooooo0000o`000005o`00
00Wooooo0ol000000ooooooo0000o`000004o`000003ooooool0003o000000;o00001?ooool2o`00
00kooooo0_l00002ooooo`;o0000f_ooool001kooooo00?o0000ooooooooool07Oooool2o`0000?o
oooo0_l00004ooooo`?o000000?oooooo`000?l000000_ooool5o`0000?ooooo0_l0000;ooooo`;o
000000?oooooo`000?l000000_l00003ooooo`;o00002_ooool2o`0000[ooooo0ol000000ooooooo
0000o`00001Vooooo`;o0000L_ooool001kooooo00?o0000ooooooooool07Oooool2o`0000;ooooo
0_l00005ooooo`;o00000oooool2o`0000Cooooo1?l000001?oooooo0000o`000?l0000:ooooo`Co
000000?oooooo`000?l000000_l000000ooooooo0000o`000003o`0000Oooooo1?l00005ooooo`;o
00000_ooool2o`000003ooooool0003o000006Kooooo0_l0001booooo`007_ooool00ol0003ooooo
ooooo`0Mooooo`Ko00001oooool2o`000005ooooool0003o0000o`000?ooool02_l000000ooooooo
0000o`000002ooooo`Co00000_ooool3o`000003ooooool0003o000000;o00000_ooool4o`0000So
oooo0ol00004ooooo`?o00004_ooool2o`00083ooooo0_l0000mooooo`;o00003?ooool001kooooo
00?o0000ooooooooool07oooool3o`0000;ooooo0_l00004ooooo`;o00000_ooool5o`0000?ooooo
1?l00002ooooo`;o00000_ooool4o`0000Kooooo1?l00002ooooo`;o00002oooool2o`000003oooo
ool0003o000000?o00004oooool2o`00083ooooo0_l0000mooooo`;o00003?ooool001kooooo00?o
0000ooooooooool03Oooool2o`0001Gooooo1?l00007ooooo`;o00000_ooool2o`0000;ooooo1Ol0
0005ooooo`?o00000_ooool7o`000003ooooool0003o000000Co00002Oooool2o`000003ooooool0
003o000000?o00002oooool3o`0006_ooooo0_l0001Wooooo`007_ooool00ol0003oooooooooo`0=
ooooo`;o00005_ooool3o`0000Wooooo1?l00002ooooo`Go000000Coooooo`000?l0003ooooo0ol0
0003ooooo`Ko00000_ooool6o`0000;ooooo0_l00005ooooo`;o00000_ooool7o`0000Kooooo1Ol0
000<ooooo`;o0000GOooool2o`0006Oooooo000Nooooo`03o`000?oooooooooo037ooooo0_l00004
ooooo`Co00000_ooool5o`0000?ooooo0_l000000ooooooo0000o`000002o`0000;ooooo1ol00000
0ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000_ooool7o`0000Kooooo0_l0000?
ooooo`;o0000EOooool2o`0003gooooo0_l0000`ooooo`007_ooool00ol0003oooooooooo`0]oooo
o`;o00002?ooool4o`0000Cooooo0ol00003ooooo`Go00001_ooool2o`000003ooooool0003o0000
00Gooooo0ol00003ooooo`So0000K_ooool2o`0003gooooo0_l0000`ooooo`007_ooool2o`0002ko
oooo0_l00003ooooo`;o00001?ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l0
00001Oooool2o`0000Sooooo0_l00008ooooo`;o00000oooool8o`000=oooooo000Nooooo`03o`00
0?oooooooooo00_ooooo0_l0000Uooooo`;o000000Coooooo`000?l0003ooooo1ol0000;ooooo`?o
00001?ooool2o`0000Sooooo0_l00002ooooo`Wo0000=oooool2o`0002gooooo0_l0000Oooooo`;o
00009?ooool2o`0002Kooooo0_l00008ooooo`007_ooool00ol0003oooooooooo`07ooooo`;o0000
0_ooool2o`0002Sooooo1?l000000ooooooo0000o`000009ooooo`;o00000oooool3o`0000kooooo
0_l00002ooooo`;o000000?oooooo`000?l000001?l0000;ooooo`;o00004_ooool2o`0001Kooooo
0_l0000]ooooo`;o00002oooool2o`0001;ooooo0_l0000Tooooo`;o00009_ooool2o`0000Sooooo
000Nooooo`03o`000?oooooooooo00Oooooo0_l0000<ooooo`;o00002?ooool2o`0001Kooooo1_l0
0002ooooo`;o00001?ooool2o`00017ooooo0_l00005ooooo`[o00001?ooool2o`0000Cooooo0_l0
000Booooo`;o0000D_ooool2o`0006[ooooo000Nooooo`03o`000?oooooooooo01Gooooo0_l00008
ooooo`;o00005_ooool6o`0000;ooooo1?l000000ooooooo0000o`00000>ooooo`;o00000_ooool2
o`0000Gooooo2_l00004ooooo`;o0000;oooool2o`000:Oooooo000Nooooo`03o`000?oooooooooo
01oooooo0_l0000Fooooo`;o000000?oooooo`000?l000001?ooool3o`000003ooooool0003o0000
00kooooo0_l000001?oooooo0000o`000?l00008ooooo`?o00002?ooool2o`0002oooooo0_l0002Q
ooooo`;o00001?ooool001kooooo0ol0000Oooooo`;o00002_ooool2o`0000gooooo0_l000000ooo
oooo0000o`000004o`0001Cooooo0_l00009ooooo`?o00002Oooool2o`0009[ooooo0_l0000eoooo
o`;o00001?ooool001kooooo0ol0000Fooooo`?o00004_ooool2o`00013ooooo0ol000000ooooooo
0000o`00000Aooooo`;o00003Oooool2o`0000Oooooo1?l0000:ooooo`;o0000E_ooool2o`0003Ko
oooo0_l000000ooooooo0000o`00000hooooo`007_ooool00ol0003oooooooooo`0Fooooo`?o0000
5oooool2o`0001;ooooo0_l0000>ooooo`;o00001?ooool4o`0000Gooooo0_l00007ooooo`;o0000
3?ooool4o`0005Cooooo0_l0000iooooo`;o00001Oooool2o`00037ooooo000Nooooo`03o`000?oo
oooooooo02Cooooo0_l0000:ooooo`;o00004?ooool4o`0001Cooooo1?l0000Nooooo`;o0000U_oo
ool2o`00037ooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l0000Looooo`;o00006_ooool2
o`000>Oooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l00008ooooo`;o00006Oooool2o`00
00Sooooo0_l00009ooooo`;o000000?oooooo`000?l000000_l0000]ooooo`;o0000Voooool2o`00
01Kooooo000Nooooo`03o`000?oooooooooo02kooooo0_l00009ooooo`;o00003_ooool2o`0000So
oooo0_l00003ooooo`;o00001oooool4o`0000Gooooo0_l0000Vooooo`;o0000Voooool2o`0000?o
oooo0_l0000;ooooo`;o00001?ooool001kooooo00?o0000ooooooooool0<_ooool2o`0000Gooooo
0_l0000Mooooo`;o00001oooool2o`0000;ooooo0_l00003ooooo`;o00001oooool2o`0000Kooooo
0_l0002gooooo`;o00002oooool2o`0000Cooooo000Nooooo`03o`000?oooooooooo03;ooooo0_l0
000`ooooo`Go00002_ooool2o`000003ooooool0003o000000?ooooo0_l0003:ooooo`007_ooool0
0ol0003oooooooooo`0;ooooo`;o0000@Oooool4o`0000;ooooo0_l0000>ooooo`;o000000?ooooo
o`000?l000003Oooool2o`0000Oooooo0_l00036ooooo`007_ooool2o`0000cooooo0_l0000Foooo
o`;o00002?ooool2o`00013ooooo0_l0000<ooooo`Go00000_ooool2o`0000Wooooo0ol000000ooo
oooo0000o`000009ooooo`;o00003oooool2o`0004Oooooo0_l0001Aooooo`;o0000:_ooool001ko
oooo00?o0000ooooooooool02Oooool2o`0001Sooooo1?l00006ooooo`;o00004?ooool2o`0000co
oooo1?l0000>ooooo`?o000000?oooooo`000?l000002Oooool2o`0005Sooooo0_l0000Mooooo`;o
0000<_ooool2o`0002[ooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0000Jooooo`;o0000
1oooool2o`000003ooooool0003o000001;ooooo0_l00005ooooo`Ko00003_ooool2o`0000;ooooo
0_l00021ooooo`;o0000G_ooool001kooooo00?o0000ooooooooool01?ooool2o`0000Wooooo0_l0
000Mooooo`;o000000?oooooo`000?l000002?ooool2o`0000Sooooo0_l00005ooooo`Ko00003_oo
ool2o`0000;ooooo0ol00002ooooo`;o00008oooool4o`000;Gooooo000Nooooo`;o00001Oooool2
o`0000Wooooo0_l0000Vooooo`;o00000_ooool2o`00017ooooo0_l00002ooooo`;o00002oooool2
o`0000;ooooo1?l00002ooooo`;o00008oooool4o`000;Gooooo000Nooooo`;o0000;oooool2o`00
00Oooooo0_l0000Fooooo`;o000000?oooooo`000?l000000oooool2o`0000Kooooo0_l00002oooo
o`;o00002oooool2o`000=Gooooo000Nooooo`03o`000?oooooooooo02kooooo0_l00004ooooo`;o
00002?ooool2o`0000Sooooo0_l00003ooooo`Co00001_ooool2o`0001Oooooo1?l000000ooooooo
0000o`00000>ooooo`;o00005oooool2o`000:Oooooo000Nooooo`03o`000?oooooooooo03Cooooo
0_l00008ooooo`;o00000_ooool2o`0000Cooooo0_l00003ooooo`;o00008oooool2o`000004oooo
ool0003o0000ooooo`;o00002oooool2o`0001Oooooo0_l0000cooooo`;o0000L_ooool001kooooo
00?o0000ooooooooool09Oooool2o`0001Sooooo1Ol0000Rooooo`;o00003Oooool2o`000003oooo
ool0003o0000017ooooo0_l00016ooooo`;o0000L_ooool001kooooo00?o0000ooooooooool09Ooo
ool2o`0000Sooooo0_l0000>ooooo`Co00008oooool2o`0002?ooooo0_l0002jooooo`007_ooool0
0ol0003oooooooooo`0_ooooo`;o0000;?ooool4o`0003Sooooo0_l0002/ooooo`007_ooool00ol0
003oooooooooo`1Cooooo`;o00000oooool2o`0000?ooooo1?l00005ooooo`;o0000<Oooool2o`00
00cooooo0_l0000>ooooo`;o0000S_ooool001kooooo00?o0000ooooooooool0Doooool2o`000003
ooooool0003o000000;o00000oooool2o`0000Oooooo0_l0000:ooooo`;o0000<oooool2o`0000ko
oooo0_l0002>ooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o0000=oooool2o`0000Gooooo
0_l00005ooooo`;o00000oooool2o`0000Oooooo0_l0003Cooooo`005?ooool4o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool02Oooool2o`0000kooooo0_l00002ooooo`;o0000AOoo
ool2o`0000?ooooo1?l0000>ooooo`;o0000Z?ooool2o`00023ooooo000Fooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool2o`0000kooooo0_l0000Eooooo`;o00005?ooool2
o`00013ooooo0_l0000?ooooo`Co00003?ooool4o`0000Oooooo1?l0000Booooo`;o0000ROooool2
o`00023ooooo000Fooooo`03o`000?oooooooooo00Gooooo0ol0000=ooooo`;o00003Oooool2o`00
01;ooooo0_l0000Dooooo`;o00004?ooool2o`0000_ooooo0_l00002ooooo`?o00003Oooool2o`00
00Wooooo1?l00005ooooo`;o00002oooool2o`000:_ooooo000Fooooo`03o`000?oooooooooo01Go
oooo0_l0000=ooooo`;o0000Aoooool2o`0002Kooooo0_l0002hooooo`005_ooool00ol0003ooooo
ooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000
ooooooooool0oooooom@ooooo`005?ooool00omEEEGoIVIVo`00003ooooooe;ooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.10215 .83503 Mdot
.20081 .57989 Mdot
.30067 .86191 Mdot
.18811 .79553 Mdot
.31166 .92655 Mdot
.26346 .86416 Mdot
.4944 .39874 Mdot
.29067 .87705 Mdot
.15197 .84922 Mdot
.27137 .72027 Mdot
.33905 .91735 Mdot
.19984 .04175 Mdot
.33748 .91366 Mdot
.11413 .89393 Mdot
.27497 .9068 Mdot
.13583 .09735 Mdot
.18517 .33974 Mdot
.25082 .91951 Mdot
.10307 .8135 Mdot
.1446 .82229 Mdot
.89597 .08304 Mdot
.17942 .93313 Mdot
.26779 .91052 Mdot
.18022 .14067 Mdot
.17241 .81929 Mdot
.2967 .87041 Mdot
.19401 .85667 Mdot
.30742 .56949 Mdot
.32597 .98131 Mdot
.17897 .8936 Mdot
.22065 .86348 Mdot
.27082 .89889 Mdot
.2318 .84794 Mdot
.91154 .02869 Mdot
.12433 .91005 Mdot
.2598 .84746 Mdot
.94803 .86398 Mdot
.91172 .9605 Mdot
.16254 .03873 Mdot
.19875 .79888 Mdot
.19486 .84701 Mdot
.07431 .91908 Mdot
.29761 .90475 Mdot
.65978 .94248 Mdot
.38016 .08983 Mdot
.03732 .92244 Mdot
.67914 .22585 Mdot
.21556 .6253 Mdot
.26326 .81339 Mdot
.10277 .80113 Mdot
.02742 .89187 Mdot
.15661 .66594 Mdot
.3551 .91494 Mdot
.28599 .03483 Mdot
.36251 .94039 Mdot
.00297 .03083 Mdot
.93227 .94691 Mdot
.34726 .90401 Mdot
.19699 .86281 Mdot
.4798 .88092 Mdot
.25945 .83089 Mdot
.2496 .87614 Mdot
.67349 .09533 Mdot
.18485 .84945 Mdot
.29271 .84172 Mdot
.18801 .89816 Mdot
.0905 .69444 Mdot
.19369 .85711 Mdot
.27561 .88569 Mdot
.82502 .82577 Mdot
.84359 .08865 Mdot
.3806 .04724 Mdot
.41129 .82143 Mdot
.20743 .35432 Mdot
.32476 .77145 Mdot
.96564 .93048 Mdot
.15219 .82946 Mdot
.69666 .29862 Mdot
.22663 .88364 Mdot
.42858 .94591 Mdot
.14569 .6858 Mdot
.71704 .72408 Mdot
.41638 .87588 Mdot
.27382 .88375 Mdot
.51141 .94775 Mdot
.96525 .98504 Mdot
.30314 .87772 Mdot
.22023 .79413 Mdot
.28193 .89692 Mdot
.45864 .95365 Mdot
.24451 .93422 Mdot
.98023 .90306 Mdot
.34001 .06358 Mdot
.3278 .01097 Mdot
.19579 .84706 Mdot
.22279 .70245 Mdot
.41324 .84385 Mdot
.12976 .83449 Mdot
.33316 .97581 Mdot
.31911 .6379 Mdot
.22848 .89485 Mdot
.99921 .86258 Mdot
.34334 .84752 Mdot
.08083 .64641 Mdot
.06501 .61177 Mdot
.2683 .93273 Mdot
.0423 .30262 Mdot
.06329 .30001 Mdot
.22749 .65207 Mdot
.96304 .21069 Mdot
.94203 .82444 Mdot
.48173 .07364 Mdot
.26242 .67473 Mdot
.25278 .90259 Mdot
.32718 .27195 Mdot
.37367 .24955 Mdot
.11846 .88703 Mdot
.32504 .92653 Mdot
.90854 .70649 Mdot
.33603 .70659 Mdot
.19062 .81767 Mdot
.19219 .60238 Mdot
.32929 .77847 Mdot
.86599 .97807 Mdot
.47476 .58462 Mdot
.53451 .6031 Mdot
.13009 .90745 Mdot
.09314 .82934 Mdot
.10489 .07957 Mdot
.40883 .63302 Mdot
.01343 .6094 Mdot
.69346 .36394 Mdot
.16329 .10528 Mdot
.19663 .90849 Mdot
.15948 .87932 Mdot
.20293 .88062 Mdot
.27187 .93677 Mdot
.2317 .93895 Mdot
.16581 .86334 Mdot
.2078 .86483 Mdot
.08851 .86307 Mdot
.21155 .86909 Mdot
.17577 .9214 Mdot
.37001 .11967 Mdot
.39403 .83265 Mdot
.215 .02591 Mdot
.115 .87381 Mdot
.21273 .86126 Mdot
.44181 .76098 Mdot
.22764 .10217 Mdot
.25345 .99061 Mdot
.21378 .86134 Mdot
.18116 .03551 Mdot
.14645 .81736 Mdot
.25334 .90345 Mdot
.33111 .9313 Mdot
.242 .99993 Mdot
.23876 .36877 Mdot
.16896 .82851 Mdot
.20672 .96793 Mdot
.21167 .92556 Mdot
.20664 .12798 Mdot
.68354 .23479 Mdot
.20659 .87859 Mdot
.31604 .94871 Mdot
.33216 .94951 Mdot
.22482 .84614 Mdot
.20144 .83616 Mdot
.31118 .24404 Mdot
.24801 .98333 Mdot
.23242 .87553 Mdot
.21805 .85817 Mdot
.11989 .98236 Mdot
.82434 .84401 Mdot
.14405 .85601 Mdot
.19326 .08822 Mdot
.33184 .1324 Mdot
.34336 .84541 Mdot
.48546 .47929 Mdot
.14867 .68609 Mdot
.28791 .02094 Mdot
.36039 .92234 Mdot
.21965 .84286 Mdot
.45051 .0874 Mdot
.12419 .35664 Mdot
.04661 .8011 Mdot
.33495 .64164 Mdot
.27367 .97299 Mdot
.4328 .16834 Mdot
.39729 .09952 Mdot
.11654 .83883 Mdot
.20353 .10938 Mdot
.09126 .83395 Mdot
.08672 .80646 Mdot
.31487 .7548 Mdot
.36048 .96133 Mdot
.22034 .16097 Mdot
.29965 .80838 Mdot
.14563 .85257 Mdot
.29644 .76606 Mdot
.66844 .97152 Mdot
.97936 .61298 Mdot
.18296 .89587 Mdot
.10311 .85338 Mdot
.17304 .82399 Mdot
.22023 .78876 Mdot
.58239 .60599 Mdot
.2165 .8449 Mdot
.56579 .9708 Mdot
.23611 .09242 Mdot
.27125 .99393 Mdot
.08472 .87624 Mdot
.82573 .129 Mdot
.12605 .05598 Mdot
.22862 .93565 Mdot
.283 .49778 Mdot
.22589 .81258 Mdot
.44878 .18877 Mdot
.24604 .67951 Mdot
.1369 .93971 Mdot
.60101 .68481 Mdot
.34667 .86205 Mdot
.26217 .90624 Mdot
.21537 .84823 Mdot
.49405 .96267 Mdot
.28337 .0611 Mdot
.47957 .71299 Mdot
.26275 .86619 Mdot
.38643 .502 Mdot
.1676 .92325 Mdot
.30441 .90641 Mdot
.48795 .89254 Mdot
.20706 .90135 Mdot
.94514 .21505 Mdot
.24227 .66975 Mdot
.47966 .98489 Mdot
.05029 .78528 Mdot
.27923 .879 Mdot
.94922 .49368 Mdot
.25882 .50909 Mdot
.3271 .92927 Mdot
.19646 .91898 Mdot
.11055 .65238 Mdot
.17349 .97406 Mdot
.10798 .98124 Mdot
.30053 .69401 Mdot
.40622 .94675 Mdot
.19179 .9058 Mdot
.58249 .61568 Mdot
.21025 .8409 Mdot
.17315 .65975 Mdot
.33794 .96251 Mdot
.3862 .46065 Mdot
.85257 .61003 Mdot
.43171 .58413 Mdot
.25692 .5817 Mdot
.34548 .92758 Mdot
.74277 .63135 Mdot
.11139 .68837 Mdot
.44271 .89412 Mdot
.08401 .85859 Mdot
.21058 .94673 Mdot
.29614 .35597 Mdot
.69508 .89686 Mdot
.19817 .91292 Mdot
.65526 .83002 Mdot
.10284 .72616 Mdot
.9107 .55094 Mdot
.29587 .89572 Mdot
.18638 .82122 Mdot
.32719 .96549 Mdot
.09805 .53937 Mdot
.25987 .87433 Mdot
.2092 .94776 Mdot
.13347 .74949 Mdot
.31367 .96634 Mdot
.19296 .65662 Mdot
.49913 .7466 Mdot
.28895 .92439 Mdot
.02372 .81576 Mdot
.86797 .03218 Mdot
.17808 .9299 Mdot
.23167 .83157 Mdot
.99131 .0054 Mdot
.3333 .93816 Mdot
.25052 .89662 Mdot
.24648 .96916 Mdot
.37233 .79107 Mdot
.27683 .70503 Mdot
.11912 .85366 Mdot
.15437 .67442 Mdot
.10643 .95998 Mdot
.10833 .8053 Mdot
.43195 .80595 Mdot
.74288 .77631 Mdot
.37452 .04044 Mdot
.31828 .84949 Mdot
.32884 .58884 Mdot
.71612 .8492 Mdot
.40341 .60526 Mdot
.08633 .56247 Mdot
.36052 .98236 Mdot
.17314 .07841 Mdot
.39008 .10426 Mdot
.73611 .8311 Mdot
.3056 .75713 Mdot
.197 .85891 Mdot
.22689 .88913 Mdot
.01701 .06124 Mdot
.9257 .58 Mdot
.20066 .82942 Mdot
.88741 .66498 Mdot
.28386 .87245 Mdot
.35563 .96037 Mdot
.23406 .8218 Mdot
.23472 .97105 Mdot
.12237 .09508 Mdot
.17566 .8145 Mdot
.33038 .85765 Mdot
.44722 .98955 Mdot
.1709 .02443 Mdot
.23917 .82668 Mdot
.01819 .78464 Mdot
.21457 .04582 Mdot
.21637 .88776 Mdot
.31391 .9155 Mdot
.28748 .90884 Mdot
.08962 .88487 Mdot
.23491 .03444 Mdot
.27752 .90025 Mdot
.1537 .86082 Mdot
.26358 .87176 Mdot
.49258 .51387 Mdot
.87452 .78605 Mdot
.08372 .37772 Mdot
.19509 .54737 Mdot
.0159 .96341 Mdot
.18397 .83775 Mdot
.07219 .36571 Mdot
.62365 .02041 Mdot
.30545 .9352 Mdot
.11871 .994 Mdot
.08921 .89496 Mdot
.39636 .07213 Mdot
.09636 .42636 Mdot
.29889 .61764 Mdot
.73466 .05477 Mdot
.25277 .15525 Mdot
.9487 .62083 Mdot
.29946 .87244 Mdot
.31227 .91308 Mdot
.35631 .94881 Mdot
.28237 .06704 Mdot
.25311 .64041 Mdot
.46382 .70967 Mdot
.26392 .86057 Mdot
.0565 .86986 Mdot
.20059 .79792 Mdot
.34399 .90818 Mdot
.51385 .92784 Mdot
.17988 .92547 Mdot
.13036 .95427 Mdot
.20019 .85713 Mdot
.27726 .99737 Mdot
.28969 .93666 Mdot
.15193 .70128 Mdot
.04423 .92215 Mdot
.31569 .00176 Mdot
.15836 .61844 Mdot
.22252 .91133 Mdot
.16374 .84761 Mdot
.20265 .85633 Mdot
.27609 .86974 Mdot
.16641 .89761 Mdot
.23707 .86016 Mdot
.23948 .42612 Mdot
.46342 .1659 Mdot
.23914 .78685 Mdot
.52448 .22304 Mdot
.17245 .87642 Mdot
.23447 .87974 Mdot
.1644 .85109 Mdot
.05909 .87451 Mdot
.04911 .89516 Mdot
.25299 .82067 Mdot
.07341 .74575 Mdot
.2787 .68182 Mdot
.00175 .48253 Mdot
.18688 .84234 Mdot
.38141 .90728 Mdot
.08798 .86499 Mdot
.31998 .95368 Mdot
.27538 .88844 Mdot
.32346 .89931 Mdot
.3105 .90874 Mdot
.52846 .06523 Mdot
.38345 .38793 Mdot
.45208 .88235 Mdot
.19726 .86201 Mdot
.20743 .87622 Mdot
.30574 .85787 Mdot
.20132 .90861 Mdot
.35637 .10547 Mdot
.253 .87927 Mdot
.18464 .04961 Mdot
.31342 .22905 Mdot
.08588 .76383 Mdot
.43166 .00622 Mdot
.29887 .12505 Mdot
.20925 .88932 Mdot
.19155 .89755 Mdot
.16812 .8185 Mdot
.22132 .92852 Mdot
.63174 .12475 Mdot
.12825 .91363 Mdot
.24895 .94305 Mdot
.38629 .73487 Mdot
.27537 .04918 Mdot
.31049 .69449 Mdot
.22602 .88807 Mdot
.19467 .82153 Mdot
.69919 .60701 Mdot
.83434 .88087 Mdot
.30789 .95685 Mdot
.32716 .89824 Mdot
.01699 .23742 Mdot
.68856 .66446 Mdot
.14987 .88507 Mdot
.39578 .04527 Mdot
.29034 .01228 Mdot
.19339 .29207 Mdot
.68968 .19919 Mdot
.41559 .63685 Mdot
.1565 .87419 Mdot
.07804 .5358 Mdot
.19438 .65314 Mdot
.22244 .77636 Mdot
.36904 .76149 Mdot
.17571 .86078 Mdot
.35732 .08569 Mdot
.1321 .7048 Mdot
.84136 .5346 Mdot
.44145 .52817 Mdot
.26871 .86047 Mdot
.39852 .13148 Mdot
.24962 .86809 Mdot
.27196 .81204 Mdot
.29709 .9708 Mdot
.69717 .5422 Mdot
.28925 .69604 Mdot
.34977 .56482 Mdot
.22443 .66067 Mdot
.28376 .91259 Mdot
.22706 .86725 Mdot
.23519 .90149 Mdot
.20045 .84208 Mdot
.16078 .82499 Mdot
.28257 .93674 Mdot
.21216 .12583 Mdot
.4705 .33128 Mdot
.19739 .83772 Mdot
.22079 .81482 Mdot
.23902 .86887 Mdot
.36276 .85223 Mdot
.95747 .14754 Mdot
.12293 .87844 Mdot
.23792 .83241 Mdot
.30089 .97015 Mdot
.27701 .89079 Mdot
.14572 .74549 Mdot
.2072 .91167 Mdot
.28254 .86827 Mdot
.27506 .87769 Mdot
.27528 .88089 Mdot
.31334 .86263 Mdot
.256 .89253 Mdot
.33559 .93951 Mdot
.3118 .90122 Mdot
.15986 .45074 Mdot
.3799 .8679 Mdot
.01411 .52113 Mdot
.18193 .85809 Mdot
.18002 .92882 Mdot
.09474 .88401 Mdot
.09785 .83784 Mdot
.29964 .71635 Mdot
.0354 .52609 Mdot
.28515 .33627 Mdot
.27061 .92253 Mdot
.28065 .6093 Mdot
.26676 .87614 Mdot
.19051 .82635 Mdot
.42629 .25699 Mdot
.27504 .66454 Mdot
.21627 .87153 Mdot
.30325 .79406 Mdot
.32293 .92383 Mdot
.32533 .79707 Mdot
.85895 .86666 Mdot
.16213 .10929 Mdot
.36928 .79101 Mdot
.3035 .61446 Mdot
.264 .9067 Mdot
.29661 .10136 Mdot
.26139 .94598 Mdot
.19255 .98299 Mdot
.27124 .86866 Mdot
.25222 .62643 Mdot
.16092 .82013 Mdot
.1515 .86186 Mdot
.13156 .89196 Mdot
.36836 .61908 Mdot
.24438 .74368 Mdot
.19831 .52203 Mdot
.31711 .91401 Mdot
.3211 .96264 Mdot
.22686 .00272 Mdot
.22162 .72556 Mdot
.24367 .54124 Mdot
.19277 .88989 Mdot
.16782 .78994 Mdot
.34231 .84745 Mdot
.23004 .88065 Mdot
.31318 .77769 Mdot
.32086 .86986 Mdot
.80535 .79474 Mdot
.41229 .2176 Mdot
.89787 .42715 Mdot
.35372 .02251 Mdot
.35581 .10971 Mdot
.75917 .46492 Mdot
.61134 .05515 Mdot
.32629 .93428 Mdot
.1143 .99929 Mdot
.27942 .89171 Mdot
.21253 .89523 Mdot
.27577 .8346 Mdot
.20247 .88407 Mdot
.70554 .9411 Mdot
.66689 .87572 Mdot
.21189 .86467 Mdot
.99695 .64522 Mdot
.25992 .97317 Mdot
.2494 .89681 Mdot
.19431 .83465 Mdot
.41682 .95164 Mdot
.74749 .46974 Mdot
.187 .7417 Mdot
.22887 .90358 Mdot
.31099 .91929 Mdot
.78302 .9857 Mdot
.55083 .13375 Mdot
.21125 .87105 Mdot
.99628 .03235 Mdot
.12268 .64229 Mdot
.29697 .86717 Mdot
.32217 .33778 Mdot
.18267 .83316 Mdot
.24051 .86942 Mdot
.87513 .20248 Mdot
.22046 .91936 Mdot
.3851 .83936 Mdot
.92276 .90818 Mdot
.35754 .73261 Mdot
.25266 .9647 Mdot
.28468 .85292 Mdot
.1938 .91077 Mdot
.27529 .91537 Mdot
.45803 .73596 Mdot
.27946 .8914 Mdot
.33271 .61468 Mdot
.13296 .6107 Mdot
.26066 .88833 Mdot
.10278 .8968 Mdot
.33077 .93968 Mdot
.15382 .89592 Mdot
.38152 .84205 Mdot
.33192 .97826 Mdot
.33279 .958 Mdot
.39361 .76767 Mdot
.47457 .26089 Mdot
.87884 .65469 Mdot
.277 .94737 Mdot
.10218 .86092 Mdot
.66755 .85652 Mdot
.22608 .77034 Mdot
.07406 .75794 Mdot
.26012 .05892 Mdot
.23861 .64899 Mdot
.22292 .83245 Mdot
.32082 .90245 Mdot
.36666 .91651 Mdot
.35413 .09741 Mdot
.29632 .78789 Mdot
.13548 .00087 Mdot
.26891 .87874 Mdot
.1901 .01838 Mdot
.30061 .9171 Mdot
.24072 .79064 Mdot
.24906 .70597 Mdot
.16881 .9008 Mdot
.20238 .84146 Mdot
.27834 .87738 Mdot
.12772 .85707 Mdot
.41856 .25537 Mdot
.21109 .84942 Mdot
.19828 .82937 Mdot
.18109 .9236 Mdot
.49333 .06332 Mdot
.09258 .84001 Mdot
.36793 .19669 Mdot
.98233 .9698 Mdot
.25924 .9043 Mdot
.54111 .88229 Mdot
.09513 .83601 Mdot
.25634 .87037 Mdot
.37076 .0392 Mdot
.65514 .71485 Mdot
.34373 .99787 Mdot
.63901 .43128 Mdot
.35117 .83659 Mdot
.31162 .63388 Mdot
.09574 .83477 Mdot
.09867 .5383 Mdot
.21023 .99629 Mdot
.18301 .66793 Mdot
.01742 .10567 Mdot
.1128 .03953 Mdot
.31458 .92607 Mdot
.0111 .84378 Mdot
.22072 .89437 Mdot
.20523 .84245 Mdot
.34634 .84201 Mdot
.61789 .8636 Mdot
.26213 .88487 Mdot
.68457 .06128 Mdot
.28182 .88524 Mdot
.38868 .09823 Mdot
.31048 .93721 Mdot
.28298 .90717 Mdot
.1261 .85886 Mdot
.27143 .8778 Mdot
.05601 .86216 Mdot
.03222 .92554 Mdot
.28149 .17421 Mdot
.11284 .83727 Mdot
.04739 .95497 Mdot
.3123 .89241 Mdot
.26759 .89686 Mdot
.47556 .13935 Mdot
.15192 .17639 Mdot
.36293 .82917 Mdot
.38796 .69043 Mdot
.22219 .84998 Mdot
.68563 .50207 Mdot
.19113 .79959 Mdot
.37682 .90067 Mdot
.4998 .83725 Mdot
.52817 .96671 Mdot
.19836 .85395 Mdot
.5005 .16165 Mdot
.29447 .87307 Mdot
.73452 .73581 Mdot
.19753 .79458 Mdot
.05455 .97267 Mdot
.34688 .20251 Mdot
.22552 .88995 Mdot
.73117 .93149 Mdot
.2918 .54896 Mdot
.34753 .78347 Mdot
.29309 .95156 Mdot
.18522 .70293 Mdot
.95133 .80924 Mdot
.17155 .81104 Mdot
.41597 .96994 Mdot
.25753 .87511 Mdot
.94646 .75856 Mdot
.31631 .95462 Mdot
.78315 .86319 Mdot
.00191 .83625 Mdot
.47658 .30601 Mdot
.37158 .12375 Mdot
.38643 .71909 Mdot
.10148 .82409 Mdot
.27808 .89028 Mdot
.15038 .05443 Mdot
.99109 .92203 Mdot
.01314 .31081 Mdot
.46802 .84336 Mdot
.29869 .9033 Mdot
.2635 .6083 Mdot
.27022 .99771 Mdot
.44333 .24782 Mdot
.21031 .62022 Mdot
.20545 .86369 Mdot
.29556 .84211 Mdot
.23344 .86379 Mdot
.50809 .76744 Mdot
.82945 .49992 Mdot
.19254 .76304 Mdot
.40552 .1893 Mdot
.2113 .70307 Mdot
.32901 .93315 Mdot
.14555 .8654 Mdot
.01163 .53246 Mdot
.30732 .78331 Mdot
.64338 .43453 Mdot
.04765 .16232 Mdot
.15192 .58055 Mdot
.14881 .86708 Mdot
.44414 .71205 Mdot
.44056 .98415 Mdot
.16451 .84721 Mdot
.66393 .98707 Mdot
.2744 .88119 Mdot
.90625 .39166 Mdot
.18411 .92192 Mdot
.31509 .88527 Mdot
.02642 .79417 Mdot
.21794 .89772 Mdot
.08941 .89005 Mdot
.96825 .03324 Mdot
.17049 .82424 Mdot
.66739 .01418 Mdot
.09045 .65055 Mdot
.38263 .79198 Mdot
.76382 .76368 Mdot
.1884 .81051 Mdot
.45145 .83099 Mdot
.20679 .77637 Mdot
.26256 .76936 Mdot
.21586 .84483 Mdot
.33147 .92638 Mdot
.17825 .85238 Mdot
.13503 .63011 Mdot
.37651 .15972 Mdot
.64929 .42886 Mdot
.40649 .47477 Mdot
.11199 .97921 Mdot
.38648 .39143 Mdot
.22765 .92484 Mdot
.15016 .83383 Mdot
.17026 .87776 Mdot
.17089 .56192 Mdot
.56029 .0285 Mdot
.11132 .91302 Mdot
.16536 .86607 Mdot
.00564 .95842 Mdot
.41233 .85452 Mdot
.3021 .62986 Mdot
.10775 .73734 Mdot
.26723 .86117 Mdot
.44855 .74186 Mdot
.09713 .90528 Mdot
.14124 .84756 Mdot
.30315 .95992 Mdot
.26825 .98893 Mdot
.11425 .75736 Mdot
.356 .92856 Mdot
.25458 .86945 Mdot
.93653 .8644 Mdot
.2854 .87283 Mdot
.39981 .03147 Mdot
.27792 .86509 Mdot
.09478 .65243 Mdot
.21779 .81667 Mdot
.27912 .6481 Mdot
.23036 .15669 Mdot
.30141 .809 Mdot
.3518 .67133 Mdot
.20962 .83396 Mdot
.23367 .00749 Mdot
.24918 .93763 Mdot
.33788 .96268 Mdot
.09067 .20089 Mdot
.12686 .87375 Mdot
.39405 .9385 Mdot
.26879 .87668 Mdot
.25017 .86702 Mdot
.38402 .08267 Mdot
.18035 .80077 Mdot
.23588 .65429 Mdot
.15097 .2897 Mdot
.30009 .35979 Mdot
.27971 .81441 Mdot
.20335 .73426 Mdot
.29369 .65074 Mdot
.20715 .8612 Mdot
.19234 .82909 Mdot
.33038 .92238 Mdot
.99631 .77517 Mdot
.16239 .60742 Mdot
.05707 .80393 Mdot
.33472 .85869 Mdot
.27797 .12405 Mdot
.37607 .90593 Mdot
.24489 .60766 Mdot
.56768 .63812 Mdot
.2003 .82374 Mdot
.46547 .99359 Mdot
.04741 .87208 Mdot
.18177 .91022 Mdot
.28317 .94779 Mdot
.3154 .77116 Mdot
.47175 .93555 Mdot
.2365 .92141 Mdot
.48976 .14569 Mdot
.47131 .13166 Mdot
.32753 .07539 Mdot
.14252 .75784 Mdot
.27962 .52182 Mdot
.22418 .81743 Mdot
.3494 .84934 Mdot
.08626 .9714 Mdot
.27242 .98815 Mdot
.20997 .85838 Mdot
.51397 .35787 Mdot
.88545 .79778 Mdot
.26747 .90332 Mdot
.3822 .75998 Mdot
.28188 .88662 Mdot
.2964 .9111 Mdot
.40313 .94344 Mdot
.33309 .92795 Mdot
.29056 .86454 Mdot
.12728 .76136 Mdot
.34732 .90896 Mdot
.3312 .97702 Mdot
.83552 .81197 Mdot
.27034 .69794 Mdot
.01277 .78861 Mdot
.39101 .82451 Mdot
.33971 .92143 Mdot
.51866 .82737 Mdot
.99427 .92242 Mdot
.21534 .9165 Mdot
.37516 .61306 Mdot
.26054 .81123 Mdot
.29807 .93919 Mdot
.77515 .43952 Mdot
.06674 .16051 Mdot
.29835 .91741 Mdot
.19806 .8622 Mdot
.16647 .86153 Mdot
.95137 .89545 Mdot
.33451 .20268 Mdot
.00497 .67404 Mdot
.31617 .91116 Mdot
.26286 .87747 Mdot
.25822 .85947 Mdot
.9415 .8137 Mdot
.47897 .96862 Mdot
.1783 .83492 Mdot
.24621 .78128 Mdot
.21105 .80754 Mdot
.50408 .59588 Mdot
.2847 .87892 Mdot
.23728 .77473 Mdot
.40505 .87096 Mdot
.32258 .87403 Mdot
.27985 .9036 Mdot
.22592 .80145 Mdot
.14963 .87618 Mdot
.63837 .6456 Mdot
.29866 .8711 Mdot
.3505 .88246 Mdot
.10494 .82317 Mdot
.20846 .76912 Mdot
.72353 .53976 Mdot
.32393 .91458 Mdot
.992 .88799 Mdot
.2131 .83122 Mdot
.19577 .84302 Mdot
.19593 .85176 Mdot
.09295 .73492 Mdot
.30102 .88205 Mdot
.48169 .54597 Mdot
.50866 .17051 Mdot
.30504 .06506 Mdot
.10987 .85054 Mdot
.8667 .8931 Mdot
.20784 .84866 Mdot
.27591 .87328 Mdot
.35514 .87171 Mdot
.39189 .78765 Mdot
.10355 .83731 Mdot
.08904 .8899 Mdot
.62867 .25659 Mdot
.17756 .93327 Mdot
.87303 .90544 Mdot
.92933 .70372 Mdot
.12646 .71591 Mdot
.29427 .77165 Mdot
.17758 .92967 Mdot
.08844 .21583 Mdot
.29534 .84031 Mdot
.60596 .50161 Mdot
.2781 .8972 Mdot
.19253 .93066 Mdot
.37574 .97112 Mdot
.12103 .85976 Mdot
.04515 .76091 Mdot
.58245 .9347 Mdot
.1806 .88704 Mdot
.65017 .73612 Mdot
.37713 .67026 Mdot
.36281 .33282 Mdot
.15607 .89147 Mdot
.11289 .80706 Mdot
.09028 .90006 Mdot
.00375 .94598 Mdot
.98993 .02131 Mdot
.99355 .55283 Mdot
.17587 .87685 Mdot
.23585 .9099 Mdot
.10312 .26054 Mdot
.07364 .95018 Mdot
.16629 .86621 Mdot
.21117 .83201 Mdot
.15749 .8697 Mdot
.78479 .94302 Mdot
.50138 .1362 Mdot
.08185 .86337 Mdot
.26602 .89606 Mdot
.27824 .90578 Mdot
.01544 .84458 Mdot
.35005 .53445 Mdot
.257 .8389 Mdot
.59656 .91537 Mdot
.56002 .96133 Mdot
.15614 .93338 Mdot
.27921 .95849 Mdot
.31441 .90976 Mdot
.19966 .91066 Mdot
.67779 .25087 Mdot
.083 .8467 Mdot
.44306 .13484 Mdot
.21527 .85946 Mdot
.22201 .88778 Mdot
.04986 .97333 Mdot
.33799 .91627 Mdot
.15731 .80912 Mdot
.17739 .81489 Mdot
.35196 .77971 Mdot
.31156 .79429 Mdot
.26145 .86927 Mdot
.57947 .83141 Mdot
.02884 .83933 Mdot
.20798 .85855 Mdot
.47833 .57234 Mdot
.27797 .90356 Mdot
.61906 .82827 Mdot
.0569 .76351 Mdot
.03306 .4397 Mdot
.33443 .97338 Mdot
.32651 .90121 Mdot
.54433 .74825 Mdot
.85119 .62879 Mdot
.72971 .0728 Mdot
.54853 .8512 Mdot
.18262 .92855 Mdot
.2185 .85995 Mdot
.27137 .90437 Mdot
.47332 .94027 Mdot
.29878 .91408 Mdot
.70032 .88751 Mdot
.25238 .96653 Mdot
.22957 8e-05 Mdot
.39328 .77587 Mdot
.09521 .96354 Mdot
.1921 .38164 Mdot
.21928 .56045 Mdot
.18939 .1138 Mdot
.27413 .52772 Mdot
.83576 .79135 Mdot
.26141 .86678 Mdot
.33928 .58596 Mdot
.48901 .99401 Mdot
.20659 .8723 Mdot
.20902 .85105 Mdot
.33121 .89261 Mdot
.34766 .86737 Mdot
.3654 .16348 Mdot
.35264 .59615 Mdot
.16014 .85752 Mdot
.19756 .65883 Mdot
.45799 .76596 Mdot
.39581 .64554 Mdot
.14058 .73689 Mdot
.19572 .86055 Mdot
.77292 .4823 Mdot
.18244 .79466 Mdot
.15801 .02482 Mdot
.89193 .99453 Mdot
.32879 .96364 Mdot
.19111 .80588 Mdot
.28496 .90253 Mdot
.15894 .99548 Mdot
.21242 .95561 Mdot
.32338 .76919 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`08ooooo`;o00000oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo0ol00005ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool00_ooool2o`0000Wooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`02ooooo`007_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo
1?l00004ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool2o`0000Wooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`06ooooo`;o00001Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00[ooooo0_l00002ooooo`03o`000?oooooooooo00;ooooo
000Nooooo`03o`000?oooooooooo04Sooooo0_l0000nooooo`;o0000]?ooool2o`0000Oooooo000N
ooooo`03o`000?oooooooooo05[ooooo0_l0000:ooooo`;o0000goooool001kooooo00?o0000oooo
ooooool0F_ooool2o`0000[ooooo0_l0001]ooooo`;o0000L?ooool001kooooo00?o0000oooooooo
ool0>_ooool2o`0009Wooooo0_l0001`ooooo`007_ooool00ol0003oooooooooo`0jooooo`;o0000
7Oooool2o`0001Cooooo0_l0001Fooooo`;o0000MOooool2o`0000Oooooo000Nooooo`03o`000?oo
oooooooo02oooooo0_l00002ooooo`;o00003Oooool2o`0001Gooooo0_l0000Dooooo`;o0000E_oo
ool2o`0007Gooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`0_ooooo`;o00000_ooool2
o`0000gooooo0_l0001^ooooo`;o0000L?ooool2o`00027ooooo000Nooooo`;o0000Ooooool2o`00
03;ooooo0_l0001Rooooo`;o00003?ooool2o`00027ooooo000Nooooo`;o0000BOooool2o`0000oo
oooo0_l0000Sooooo`;o0000U_ooool2o`0001oooooo0_l00007ooooo`;o00001Oooool001kooooo
00?o0000ooooooooool0=oooool2o`0000oooooo0_l0000?ooooo`;o0000g?ooool2o`0000Oooooo
0_l00005ooooo`007_ooool00ol0003oooooooooo`0Qooooo`;o00003_ooool2o`0000Cooooo0_l0
000kooooo`Co0000coooool001kooooo00?o0000ooooooooool08Oooool2o`0000kooooo0_l0000:
ooooo`;o0000=Oooool4o`000<oooooo000Nooooo`03o`000?oooooooooo03gooooo0_l00003oooo
o`;o0000=?ooool2o`0000?ooooo0_l00038ooooo`007_ooool00ol0003oooooooooo`0hooooo`;o
00002?ooool2o`00017ooooo0_l0000Qooooo`;o00000oooool2o`000<Sooooo000Nooooo`;o0000
>Oooool2o`0001_ooooo0_l0003`ooooo`007_ooool00ol0003oooooooooo`0Uooooo`;o00001_oo
ool2o`0009Cooooo0_l0000Vooooo`;o0000F_ooool001kooooo00?o0000ooooooooool09Oooool2
o`0000Kooooo0_l0000Qooooo`;o0000LOooool2o`0002Kooooo0_l0001Jooooo`007_ooool01?l0
003oooooooooooooool2o`0004gooooo0_l00006ooooo`;o0000P?ooool2o`0006_ooooo000Noooo
o`04o`000?ooooooooooooooo`;o0000EOooool2o`0000Gooooo0_l00009ooooo`;o0000<?ooool2
o`0000[ooooo0_l0000`ooooo`;o0000Joooool001kooooo00?o0000ooooooooool0F?ooool2o`00
00Gooooo0_l00009ooooo`;o0000<?ooool2o`0000[ooooo0_l0002Mooooo`007_ooool00ol0003o
ooooooooo`1Hooooo`;o00008oooool2o`000<Sooooo000Nooooo`03o`000?oooooooooo07gooooo
0_l0000Jooooo`;o0000C_ooool2o`0005cooooo000Nooooo`03o`000?oooooooooo06Kooooo0_l0
000aooooo`;o0000C_ooool2o`0005cooooo000Nooooo`03o`000?oooooooooo01kooooo0_l0000D
ooooo`;o0000<?ooool2o`000=oooooo000Nooooo`03o`000?oooooooooo01kooooo0_l0000Doooo
o`;o0000@oooool2o`000:Cooooo0_l0000Vooooo`007_ooool00ol0003oooooooooo`1`ooooo`;o
00001oooool2o`0001?ooooo0_l0002?ooooo`;o00009_ooool001kooooo00?o0000ooooooooool0
>oooool2o`0003?ooooo0_l00005ooooo`;o00005Oooool2o`0007kooooo0_l0000gooooo`007_oo
ool00ol0003oooooooooo`0kooooo`;o00003?ooool2o`0002cooooo0_l0002Eooooo`;o0000=ooo
ool001kooooo00?o0000ooooooooool09?ooool2o`0002?ooooo0_l0002<ooooo`;o0000K_ooool0
01kooooo00?o0000ooooooooool09?ooool2o`0000;ooooo0_l00015ooooo`;o00002Oooool2o`00
0003ooooool0003o000005Sooooo0_l0001^ooooo`007_ooool2o`0002Wooooo0_l0000Looooo`;o
00005?ooool2o`00017ooooo0_l00009ooooo`;o000000?oooooo`000?l00000b?ooool001kooooo
00?o0000ooooooooool00_ooool2o`0002gooooo0_l0000Cooooo`;o00005?ooool2o`0001;ooooo
0_l00009ooooo`;o0000b_ooool001kooooo00?o0000ooooooooool00_ooool2o`0002gooooo0_l0
000mooooo`;o00002Oooool2o`000<[ooooo000Nooooo`03o`000?oooooooooo037ooooo0_l0000;
ooooo`;o0000<?ooool2o`000=Gooooo000Nooooo`03o`000?oooooooooo037ooooo0_l00006oooo
o`;o00000oooool2o`00033ooooo0_l0003Eooooo`007_ooool00ol0003oooooooooo`0iooooo`;o
0000ooooool=ooooo`007_ooool00ol0003oooooooooo`1dooooo`;o0000dOooool001kooooo00?o
0000ooooooooool0E_ooool2o`0001cooooo0ol0003@ooooo`007_ooool00ol0003oooooooooo`11
ooooo`;o00004oooool2o`0000Gooooo0_l0000Fooooo`;o0000D_ooool2o`0007cooooo000Noooo
o`03o`000?oooooooooo03oooooo1?l0000Jooooo`;o0000J_ooool2o`0003gooooo0_l0000moooo
o`007_ooool00ol0003oooooooooo`0oooooo`;o00009oooool2o`0001?ooooo0_l0000Fooooo`;o
0000LOooool2o`0003gooooo000Nooooo`03o`000?oooooooooo06Sooooo0_l0000Cooooo`;o0000
3Oooool2o`0000Oooooo0_l00008ooooo`;o00003_ooool2o`0009Kooooo000Nooooo`03o`000?oo
oooooooo08cooooo0_l00008ooooo`;o00001oooool2o`0000kooooo0_l0002Fooooo`007_ooool0
0ol0003oooooooooo`0fooooo`;o0000G_ooool2o`000:oooooo000Nooooo`03o`000?oooooooooo
03Kooooo0_l0001Sooooo`;o0000Z_ooool001kooooo00?o0000ooooooooool0Voooool2o`0009Ko
oooo0_l0000Booooo`007_ooool2o`000?oooooo=Oooool2o`0001;ooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0Aoooool2o`0000Gooooo0_l0003g
ooooo`007_ooool00ol0003oooooooooo`0Booooo`;o0000<?ooool2o`000003ooooool0003o0000
00Gooooo0_l0000Vooooo`;o0000coooool001kooooo00?o0000ooooooooool02oooool2o`0000Go
oooo0_l0000`ooooo`;o0000;Oooool2o`000003ooooool0003o000002Oooooo0_l0002Vooooo`00
7_ooool00ol0003oooooooooo`0;ooooo`;o0000I_ooool2o`0001kooooo0_l0000:ooooo`;o0000
Y_ooool001kooooo00?o0000ooooooooool0ROooool2o`0000Sooooo0_l0000<ooooo`;o0000Y?oo
ool001kooooo00?o0000ooooooooool0ROooool2o`0001Kooooo0_l0002Tooooo`007_ooool00ol0
003oooooooooo`0]ooooo`;o0000:?ooool2o`000>kooooo000Nooooo`03o`000?oooooooooo02go
oooo0_l0000Xooooo`;o0000k_ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo08kooooo0_l0002g
ooooo`007_ooool00ol0003oooooooooo`20ooooo`;o00003?ooool2o`000;Oooooo0003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo
083ooooo0_l00035ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1dooooo`;o0000dOooool0
00?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0000I
ooooo`;o0000FOooool2o`0006Kooooo0_l0001Yooooo`000oooool01Ol0003ooooooooooooooooo
000000gooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`0Iooooo`;o0000C_ooool2
o`0000;ooooo0_l0001]ooooo`;o0000>_ooool2o`0002gooooo0003ooooo`05o`000?oooooooooo
ooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo06Wooooo0_l00002
ooooo`;o0000ZOooool2o`0002gooooo0003ooooo`05oa0@4?ooooooooooooooool@41003oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003ooooooooo
o`3oooooocKooooo0_l0000@ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo01Wooooo0_l0003ooooooaGooooo
0_l00004ooooo`;o00004?ooool001kooooo00?o0000ooooooooool06Oooool2o`0006Oooooo0_l0
002[ooooo`;o00005_ooool001kooooo00?o0000ooooooooool0P_ooool2o`000<?ooooo000Noooo
o`03o`000?oooooooooo0:Kooooo0_l0000aooooo`;o0000K?ooool001kooooo00?o0000oooooooo
ool0Y_ooool2o`00037ooooo0_l0001/ooooo`007_ooool00ol0003oooooooooo`1Rooooo`;o0000
hoooool001kooooo00?o0000ooooooooool0H_ooool2o`0007Kooooo0_l0001[ooooo`007_ooool0
1?l0003oooooooooooooool2o`000=Oooooo0_l0001[ooooo`007_ooool01?l0003ooooooooooooo
ool2o`000?ooooooAOooool001kooooo00?o0000ooooooooool0HOooool2o`000>Cooooo000Noooo
o`03o`000?oooooooooo067ooooo0_l0003Tooooo`007_ooool00ol0003oooooooooo`1eooooo`;o
00005Oooool2o`000;Wooooo000Nooooo`;o0000M_ooool2o`0001Gooooo0_l0001:ooooo`;o0000
KOooool001kooooo00?o0000ooooooooool0Q?ooool2o`0004;ooooo0_l0000>ooooo`;o0000KOoo
ool001kooooo00?o0000ooooooooool0Q?ooool4o`00043ooooo0_l0001mooooo`007_ooool00ol0
003oooooooooo`0Mooooo`;o0000Ioooool2o`0000kooooo0_l0002_ooooo`007_ooool00ol0003o
ooooooooo`0Mooooo`;o0000Moooool2o`000:oooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0I_ooool2o`000=oooooo000Nooooo`03o`000?oooooo
oooo06Kooooo0_l0003Oooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo02gooooo0_l0003o
oooooaWooooo000Nooooo`03o`000?oooooooooo02gooooo0_l0000<ooooo`;o0000ooooool;oooo
o`007_ooool00ol0003oooooooooo`0kooooo`;o0000ooooool;ooooo`007_ooool00ol0003ooooo
ooooo`3Nooooo`;o0000Ioooool001kooooo0_l0000;ooooo`;o00001?ooool2o`000<cooooo0_l0
001Wooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o00001?ooool2o`000?oooooo=_ooool0
01kooooo00?o0000ooooooooool0Uoooool2o`000:kooooo000Nooooo`03o`000?oooooooooo00;o
0000UOooool2o`000:kooooo000Nooooo`03o`000?oooooooooo00;o0000oooooom6ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0L_oo
ool2o`00027ooooo0_l0002`ooooo`007_ooool00ol0003oooooooooo`1Iooooo`;o00005oooool2
o`00027ooooo0_l0002`ooooo`007_ooool00ol0003oooooooooo`0hooooo`;o00007oooool2o`00
00[ooooo0_l0003Pooooo`007_ooool00ol0003oooooooooo`0hooooo`;o0000:oooool2o`000>3o
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0?oooool2o`00
0?oooooo1oooool001kooooo00?o0000ooooooooool09?ooool2o`0001Wooooo0_l0000Kooooo`;o
0000AOooool2o`000:;ooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l0000fooooo`?o0000
A?ooool2o`000:;ooooo000Nooooo`03o`000?oooooooooo05gooooo0_l0001nooooo`;o0000J?oo
ool001kooooo00?o0000ooooooooool04oooool2o`000<Sooooo0_l0001Xooooo`007_ooool00ol0
003oooooooooo`0Cooooo`;o0000=Oooool2o`000?_ooooo000Nooooo`03o`000?oooooooooo04[o
oooo0_l0003kooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo01Oooooo0_l0003ooooooboooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0000Q
ooooo`;o0000ooooool<ooooo`007_ooool00ol0003oooooooooo`0jooooo`;o0000ooooool<oooo
o`007_ooool00ol0003oooooooooo`1iooooo`;o0000c?ooool001kooooo00?o0000ooooooooool0
NOooool3o`000:Oooooo0_l0000Rooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`1jooooo`;o0000
Yoooool2o`0002;ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05oa0@4?oo
ooooooooooooool@41002oooool5o`0000Kooooo0ol0002Mooooo`;o0000Z?ooool000?ooooo00Go
0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000oooooooo
ool0WOooool2o`000:Sooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgo
EEEEooooool00007ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0oooooom8oooo
o`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0
003oooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omg
MgOo0000ooooo`06ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool06oooool2o`0002gooooo0_l00023
ooooo`;o0000Coooool2o`0002Gooooo000Nooooo`03o`000?oooooooooo01_ooooo0_l0000]oooo
o`;o0000P?ooool2o`000003ooooool0003o000004oooooo0_l0000Uooooo`007_ooool00ol0003o
ooooooooo`3<ooooo`?o0000N?ooool001kooooo00?o0000ooooooooool0cOooool2o`0007Sooooo
000Nooooo`03o`000?oooooooooo00Oooooo0_l0003_ooooo`;o0000COooool001kooooo00?o0000
ooooooooool01oooool2o`000>oooooo0_l0001=ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0000aooooo`;o0000
oooooolFooooo`007_ooool00ol0003oooooooooo`0`ooooo`;o0000oooooolFooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo07Wooooo0_l0003<oooo
o`007_ooool00ol0003oooooooooo`1iooooo`;o0000N?ooool2o`0005;ooooo000Nooooo`03o`00
0?oooooooooo0??ooooo0_l0001Booooo`007_ooool00ol0003oooooooooo`3_ooooo`;o0000E_oo
ool001kooooo00?o0000ooooooooool0P?ooool2o`0006gooooo0_l0001Fooooo`007_ooool00ol0
003oooooooooo`20ooooo`;o0000aOooool001kooooo00?o0000ooooooooool0V_ooool2o`000:_o
oooo000Mooooo`;o0000W?ooool2o`0005_ooooo0_l0001>ooooo`007Oooool2o`000?Wooooo0_l0
001>ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooolaooooo`;o00005Oooool001kooooo
00?o0000ooooooooool0F?ooool2o`000=Kooooo0_l0000Eooooo`007_ooool2o`0005Wooooo0_l0
000Pooooo`;o0000AOooool2o`0001Sooooo0_l0000]ooooo`;o0000>oooool001kooooo00?o0000
ooooooooool0N_ooool2o`0004Gooooo0_l0000Hooooo`;o0000;Oooool2o`0003_ooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0D?ooool2o`000?Go
oooo000Nooooo`03o`000?oooooooooo053ooooo0_l0001:ooooo`;o0000ZOooool001kooooo00?o
0000ooooooooool0W?ooool2o`000:Wooooo000Nooooo`03o`000?oooooooooo00;o0000oooooom6
ooooo`007_ooool00ol0003oooooooooo`02o`0003[ooooo0_l0000Iooooo`;o0000k_ooool001ko
oooo00?o0000ooooooooool01oooool2o`0003?ooooo0_l0000Iooooo`;o0000k_ooool001kooooo
00?o0000ooooooooool01oooool2o`0004cooooo0_l0000dooooo`;o0000^_ooool001kooooo00?o
0000ooooooooool00_l0001Cooooo`;o0000=?ooool2o`000;[ooooo000Nooooo`03o`000?oooooo
oooo00;o00004oooool2o`0005Oooooo0_l0002Mooooo`;o0000>?ooool001kooooo00?o0000oooo
ooooool05Oooool2o`0000Gooooo0_l0001@ooooo`;o0000WOooool2o`0003Sooooo000Nooooo`03
o`000?oooooooooo01cooooo0_l0000]ooooo`;o0000T_ooool2o`0000Kooooo0_l0001Nooooo`00
7_ooool00ol0003oooooooooo`1;ooooo`;o0000T_ooool2o`0000Kooooo0_l0001Nooooo`007_oo
ool00ol0003oooooooooo`0kooooo`;o0000Foooool2o`000:gooooo000Nooooo`;o0000??ooool2
o`0001kooooo0_l0000kooooo`;o0000R_ooool2o`00027ooooo000Nooooo`03o`000?oooooooooo
05_ooooo0_l00037ooooo`;o00006Oooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo0?oo
oooo@?ooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo04?ooooo0_l0003oooooo`?ooooo
000Nooooo`03o`000?oooooooooo01Sooooo0_l0000Iooooo`;o00003_ooool2o`000?oooooo0ooo
ool001kooooo00?o0000ooooooooool06?ooool2o`0001Wooooo0_l0000iooooo`;o0000eoooool0
01kooooo00?o0000ooooooooool0H?ooool2o`0000cooooo0_l0003Gooooo`007_ooool00ol0003o
ooooooooo`1Pooooo`;o0000=Oooool2o`000:kooooo000Nooooo`03o`000?oooooooooo09Oooooo
0_l0002^ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo02gooooo0_l0000>ooooo`;o00004?ooool2o`000=Sooooo0_l0000Looooo`007_ooool00ol0
003oooooooooo`0]ooooo`;o00003_ooool2o`00013ooooo0_l0000gooooo`;o00003?ooool2o`00
097ooooo0_l0000Looooo`007_ooool00ol0003oooooooooo`1Wooooo`;o000000?oooooo`000?l0
00007?ooool2o`0000cooooo0_l0002_ooooo`007_ooool00ol0003oooooooooo`1Wooooo`;o0000
00?oooooo`000?l00000foooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0oooooom8ooooo`00
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRH
V?lQ8B401_ooool00ol0003oooooooooo`1_ooooo`;o0000;oooool2o`000:Gooooo0003ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0001_
ooooo`;o0000;oooool2o`000:Gooooo0003ooooo`05o`000?ooooooooooooooool000002oooool0
1Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0>_ooool2o`0006kooooo0_l0
002Kooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@
olc<c006ooooo`03o`000?oooooooooo03[ooooo0_l00013ooooo`;o0000:Oooool2o`0000gooooo
0_l0000Tooooo`;o0000I_ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEE
EOn7QhOooooo00Sooooo00?o0000ooooooooool00_l0000_ooooo`;o00006?ooool2o`0000Gooooo
0_l00003ooooo`;o00009_ooool2o`0003Sooooo0_l0000Tooooo`;o0000<?ooool2o`0003Cooooo
0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`00
0?oooooooooo00;o00003oooool2o`0001Cooooo0_l00008ooooo`;o00006?ooool2o`0000Gooooo
0_l00003ooooo`;o00007Oooool2o`0009Wooooo0_l0000Wooooo`;o00002oooool000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000oooooooo
ool04Oooool2o`0001Cooooo0_l0000fooooo`;o00001oooool2o`0000cooooo0_l00011ooooo`;o
0000Ooooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo02oooooo0_l0000/ooooo`Co0000
1oooool2o`0000[ooooo0_l00013ooooo`;o0000S?ooool001kooooo00?o0000ooooooooool0;ooo
ool2o`0000oooooo0_l0000Kooooo`;o00005Oooool2o`000;[ooooo0_l0000Eooooo`007_ooool0
0ol0003oooooooooo`10ooooo`Co0000k?ooool2o`0001Gooooo000Nooooo`03o`000?oooooooooo
04;ooooo0_l0000:ooooo`;o0000`Oooool2o`0003Cooooo000Nooooo`03o`000?oooooooooo02So
oooo0_l0000Tooooo`;o00003_ooool2o`0008gooooo0_l0000Rooooo`;o0000=?ooool001kooooo
00?o0000ooooooooool0:?ooool2o`0003Cooooo0_l000000ooooooo0000o`00000Nooooo`;o0000
J_ooool2o`0005Sooooo000Nooooo`03o`000?oooooooooo067ooooo0_l000000ooooooo0000o`00
000Kooooo`Co0000;oooool2o`00097ooooo000Nooooo`03o`000?oooooooooo04kooooo0_l0000D
ooooo`;o00007Oooool2o`0002oooooo0_l0002Aooooo`007_ooool00ol0003oooooooooo`0Toooo
o`;o0000:?ooool2o`0001Wooooo0_l0003Looooo`007_ooool00ol0003oooooooooo`0Fooooo`;o
00003?ooool2o`0004?ooooo0_l0000Booooo`;o0000C?ooool2o`0007?ooooo0_l00005ooooo`00
7_ooool00ol0003oooooooooo`0Fooooo`;o0000<Oooool2o`0000cooooo0_l0000Tooooo`;o0000
C?ooool2o`0007?ooooo0_l00005ooooo`007_ooool2o`0001[ooooo1?l00003ooooo`;o00006Ooo
ool2o`0000Wooooo0_l000000ooooooo0000o`00000<ooooo`;o00000_ooool2o`000>[ooooo000N
ooooo`03o`000?oooooooooo01Wooooo1?l00003ooooo`;o00006Oooool2o`0000Wooooo0_l00000
0ooooooo0000o`00000@ooooo`;o0000_Oooool2o`0002_ooooo000Nooooo`03o`000?oooooooooo
03_ooooo0ol0000;ooooo`;o0000coooool2o`0002_ooooo000Nooooo`03o`000?oooooooooo03Co
oooo0_l00005ooooo`?o00001oooool2o`000?oooooo0Oooool001kooooo00?o0000ooooooooool0
=?ooool2o`0000oooooo0_l0000>ooooo`;o0000QOooool2o`0003kooooo0_l0000Yooooo`007_oo
ool00ol0003oooooooooo`0_ooooo`;o00001_ooool2o`0001cooooo0_l00025ooooo`;o0000?_oo
ool2o`0002Wooooo000Nooooo`03o`000?oooooooooo02oooooo0_l00006ooooo`;o00004_ooool2
o`00027ooooo0_l00006ooooo`;o0000coooool001kooooo0_l0000_ooooo`;o00006oooool2o`00
00Cooooo0_l0000Kooooo`;o00001_ooool2o`000<oooooo000Nooooo`;o0000;oooool2o`00027o
oooo0_l0003dooooo`007_ooool00ol0003oooooooooo`1<ooooo`;o0000nOooool001kooooo00?o
0000ooooooooool0C?ooool2o`0000Sooooo0_l0003_ooooo`007_ooool00ol0003oooooooooo`0[
ooooo`?o0000:?ooool2o`0006Oooooo0_l00026ooooo`007_ooool00ol0003oooooooooo`0Poooo
o`;o00002Oooool3o`00097ooooo0_l00026ooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o
0000F?ooool2o`000<_ooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l0000oooooo`;o0000
0_ooool2o`000003ooooool0003o000001Oooooo0_l0003;ooooo`007_ooool00ol0003ooooooooo
o`0Iooooo`;o0000>Oooool2o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l00000i?oo
ool001kooooo0_l0000^ooooo`;o00005Oooool2o`0000kooooo0_l0003aooooo`007_ooool00ol0
003oooooooooo`0Wooooo`;o00001?ooool2o`0000Wooooo0_l00007ooooo`;o000000?oooooo`00
0?l000004?ooool2o`000=;ooooo0_l0000Kooooo`007_ooool00ol0003oooooooooo`0Wooooo`;o
00003oooool2o`0000Oooooo0_l0000:ooooo`;o00001oooool2o`00017ooooo0_l0002hooooo`;o
00001Oooool2o`0001_ooooo000Nooooo`03o`000?oooooooooo04gooooo0_l0000Jooooo`;o0000
:?ooool2o`0008kooooo0_l0000Rooooo`007_ooool00ol0003oooooooooo`2<ooooo`;o00001Ooo
ool2o`0000?ooooo0_l0000gooooo`;o0000M?ooool001kooooo00?o0000ooooooooool09Oooool2
o`0003Kooooo0_l0000]ooooo`;o00002_ooool2o`0003Oooooo0_l0001dooooo`007_ooool00ol0
003oooooooooo`0Uooooo`;o0000;Oooool2o`0000Oooooo0_l0000Kooooo`;o0000boooool001ko
oooo00?o0000ooooooooool0E?ooool2o`0002Cooooo0_l0001Yooooo`;o0000H?ooool001kooooo
00?o0000ooooooooool07Oooool2o`0002Gooooo0_l0002Oooooo`;o0000H?ooool001kooooo00?o
0000ooooooooool07Oooool2o`0002Gooooo0_l0003oooooo`;ooooo000Nooooo`03o`000?oooooo
oooo073ooooo0_l0003Eooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o00008_ooool2o`00
033ooooo0_l00007ooooo`;o00005_ooool2o`0003cooooo0_l0000Jooooo`;o0000F_ooool001ko
oooo00?o0000ooooooooool06_ooool2o`0000?ooooo0_l00009ooooo`;o00004_ooool2o`0003Wo
oooo0_l0000Fooooo`;o0000??ooool2o`0001[ooooo0_l0001Jooooo`007_ooool00ol0003ooooo
ooooo`0Oooooo`;o00002Oooool2o`0000gooooo0_l0001Cooooo`;o0000]oooool001kooooo00?o
0000ooooooooool05?ooool2o`0001Gooooo0_l0000<ooooo`;o00004?ooool2o`00047ooooo0_l0
002gooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o00005Oooool2o`0001kooooo0_l0001A
ooooo`;o00003Oooool2o`0009Sooooo000Nooooo`;o0000:?ooool2o`0007Gooooo0_l0000=oooo
o`;o0000V?ooool001kooooo00?o0000ooooooooool09oooool2o`0003Wooooo0_l0003Sooooo`00
7_ooool00ol0003oooooooooo`0Dooooo`;o00002oooool2o`0000Oooooo0_l0000cooooo`;o0000
00?oooooo`000?l00000hoooool001kooooo00?o0000ooooooooool02oooool2o`0000Oooooo0_l0
000;ooooo`;o00001oooool2o`0003?ooooo0_l0000Gooooo`;o00004_ooool2o`000:;ooooo0_l0
000Eooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o000000?oooooo`000?l000002?ooool2
o`0000_ooooo0_l0000Cooooo`;o0000>?ooool2o`0000;ooooo0_l0000Booooo`;o0000I_ooool2
o`0003[ooooo0_l0000Eooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o00002?ooool2o`00
00_ooooo0_l0000Cooooo`;o00008?ooool2o`0001Kooooo0_l0000Kooooo`;o0000HOooool2o`00
057ooooo000Nooooo`03o`000?oooooooooo043ooooo0_l00003ooooo`;o00002_ooool2o`0000Wo
oooo0_l00007ooooo`;o00005Oooool2o`0001?ooooo0_l0000>ooooo`;o0000Y?ooool001kooooo
00?o0000ooooooooool0@?ooool2o`0000?ooooo0_l0000:ooooo`;o00002Oooool2o`0000Cooooo
0_l000000ooooooo0000o`00000Eooooo`;o00008oooool2o`000:Cooooo000Nooooo`03o`000?oo
oooooooo03oooooo0_l00003ooooo`;o00000oooool2o`00017ooooo0_l00004ooooo`;o000000?o
ooooo`000?l000005Oooool2o`0006oooooo0_l0001Aooooo`;o00001Oooool001kooooo00?o0000
ooooooooool0?oooool2o`0000?ooooo0_l00003ooooo`;o00005oooool2o`0000?ooooo0_l0000C
ooooo`;o0000Koooool2o`00057ooooo0_l00005ooooo`007_ooool00ol0003oooooooooo`1<oooo
o`;o00005?ooool2o`0000?ooooo0_l00005ooooo`;o0000eoooool001kooooo00?o0000oooooooo
ool00_ooool2o`0000Sooooo0_l0000nooooo`;o00004_ooool2o`0000_ooooo0ol0003Gooooo`00
7_ooool00ol0003oooooooooo`04o`0000Sooooo0_l0000eooooo`;o00001Oooool2o`00013ooooo
0_l00002ooooo`;o00002oooool2o`0000cooooo0_l0002Kooooo`;o0000;Oooool001kooooo00?o
0000ooooooooool00_l0000`ooooo`;o00003oooool2o`0000Gooooo0_l0000@ooooo`;o00005_oo
ool3o`0000Cooooo0_l0002?ooooo`;o00002_ooool2o`0002gooooo0003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`00
0?oooooooooo00Cooooo0_l0000/ooooo`;o00000oooool2o`0000?ooooo0_l00005ooooo`;o0000
1Oooool2o`0001;ooooo0_l000000ooooooo0000o`00000Aooooo`?o000000?oooooo`000?l00000
R?ooool2o`0000Sooooo0_l0000iooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`04ooooo`;o
0000<Oooool4o`000004ooooool0003o0000o`0000Cooooo0_l0000Iooooo`;o000000?oooooo`00
0?l000000oooool2o`00013ooooo0_l00028ooooo`;o00006?ooool2o`0002Wooooo0003ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0000;
ooooo`;o00004?ooool2o`0001Sooooo2?l0000Wooooo`;o0000]?ooool2o`0002Wooooo0003oooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o
0000ooooooooool02oooool2o`000003ooooool0003o000000gooooo0_l0000Hooooo`;o000000?o
ooooo`000?l000000_l00007ooooo`;o0000ooooool1ooooo`000oooool01Ol0003ooooooooooooo
oooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo00kooooo
0_l00008ooooo`;o00001Oooool4o`0001Oooooo0_l00009ooooo`;o0000@Oooool2o`000;gooooo
0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Ko
oooo00?o0000ooooooooool06?ooool2o`0000Gooooo1?l0000<ooooo`;o00002Oooool2o`0000Co
oooo0_l0000Kooooo`?o0000:?ooool2o`000:Oooooo0_l0000Dooooo`000oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo
02oooooo0_l00003ooooo`;o00000oooool2o`0000Gooooo0_l00003ooooo`;o00002_ooool2o`00
0003ooooool0003o000000Oooooo0ol0002/ooooo`;o00008oooool2o`0001Cooooo0003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000
ooooooooool01?ooool2o`0001Oooooo0_l0000Eooooo`Co000000?oooooo`000?l000002Oooool3
o`0000[ooooo0_l000001?oooooo0000o`000?ooool2o`000;?ooooo0_l0000Pooooo`;o00005ooo
ool001kooooo00?o0000ooooooooool01?ooool2o`0001Oooooo0_l0000<ooooo`;o00001_ooool5
o`0000;ooooo0_l00007ooooo`Co00004?ooool2o`000=Gooooo0_l0000Gooooo`007_ooool00ol0
003oooooooooo`0[ooooo`;o00000oooool2o`000004ooooool0003o0000o`0000;ooooo1Ol00006
ooooo`Co000000?oooooo`000?l000001?ooool2o`0003;ooooo0_l00033ooooo`007_ooool00ol0
003oooooooooo`0Mooooo`?o00002oooool2o`0000?ooooo0_l000001?oooooo0000o`000?l00002
ooooo`;o000000?oooooo`000?l000000_l00009ooooo`;o00001?ooool2o`0002_ooooo0_l00005
ooooo`;o0000Z_ooool2o`0001Oooooo000Nooooo`03o`000?oooooooooo01gooooo0ol0000@oooo
o`;o000000Coooooo`000?l0003o00001?ooool2o`000003ooooool0003o000000_ooooo0_l0000_
ooooo`;o0000:?ooool2o`0001kooooo0_l00011ooooo`;o00009?ooool2o`0001Oooooo000Noooo
o`03o`000?oooooooooo01[ooooo0_l0000Aooooo`;o00001?ooool2o`0000Gooooo1Ol00002oooo
o`;o00001?ooool2o`000003ooooool0003o000000Cooooo0_l0000Pooooo`;o00006oooool2o`00
01Cooooo0_l0000Aooooo`;o00002oooool2o`0000[ooooo0_l0000Hooooo`;o00006oooool2o`00
03gooooo000Nooooo`03o`000?oooooooooo01[ooooo0ol00009ooooo`;o00001Oooool2o`0000Oo
oooo0ol000000ooooooo0000o`000003o`000005ooooool0003o0000o`000?ooool00_l000000ooo
oooo0000o`000002o`0000Gooooo0_l00004ooooo`;o00006_ooool2o`0000Sooooo0_l0000Aoooo
o`;o00009oooool2o`0001Oooooo0_l0000Hooooo`;o0000F_ooool001kooooo0_l0000Kooooo`Ko
000000?oooooo`000?l000000oooool2o`0000Gooooo0_l00007ooooo`Co000000?oooooo`000?l0
00000_l000001Ooooooo0000o`000?l0003ooooo00;o00000oooool2o`0000_ooooo0_l0000Foooo
o`;o00003?ooool2o`00023ooooo0_l0002Wooooo`007_ooool2o`0000Kooooo0_l0000Cooooo`Ko
000000Coooooo`000?l0003o00005?ooool2o`0000;ooooo0ol000000ooooooo0000o`00000=oooo
o`;o00002oooool2o`00013ooooo0_l00009ooooo`;o00008oooool2o`000:Oooooo000Nooooo`04
o`000?oooooo0000o`0000Cooooo0_l0000Cooooo`;o00001_ooool2o`0001Gooooo0_l000000ooo
oooo0000o`000004o`000003ooooool0003o000000[ooooo0_l0000:ooooo`?o00003_ooool2o`00
00[ooooo0ol00007ooooo`;o00004?ooool2o`0007;ooooo0_l0000mooooo`007_ooool00ol0003o
ooooo`000003o`0001Cooooo0_l0000Hooooo`;o00001_ooool8o`000003ooooool0003o000000?o
00005?ooool3o`0000kooooo0_l0000:ooooo`;o00002?ooool2o`00013ooooo0_l0001booooo`;o
0000?Oooool001kooooo00Co0000oooooooooooooooo0_l0000Dooooo`;o00004Oooool2o`000003
ooooool0003o000000;ooooo0_l00005ooooo`;o000000Goooooo`000?l0003o0000ooooo`0:o`00
00Oooooo0_l0000Aooooo`;o00001_ooool4o`0007Kooooo0_l0001Pooooo`007_ooool2o`0001ko
oooo0_l000000ooooooo0000o`000008ooooo`Go00000_ooool2o`0000?ooooo1?l00002ooooo`;o
000000?oooooo`000?l000001Ol000000ooooooo0000o`000007ooooo`;o00001_ooool2o`0000Wo
oooo0_l00006ooooo`Co00000oooool2o`0003[ooooo0_l0000eooooo`;o0000H?ooool001kooooo
00?o0000ooooooooool07Oooool2o`000004ooooool0003o0000ooooo`;o00001_ooool2o`0000Co
oooo0_l00003ooooo`;o00001?ooool6o`0001Kooooo0_l0000Hooooo`;o00003_ooool2o`0002[o
oooo0_l0002Gooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o00002_ooool4o`0000Cooooo
0_l00003ooooo`;o00001Oooool2o`0000;ooooo2_l0000;ooooo`;o00003Oooool2o`0000Kooooo
1?l0000Gooooo`;o0000DOooool2o`00073ooooo000Nooooo`03o`000?oooooooooo00kooooo0_l0
0007ooooo`;o00001?ooool2o`0000Cooooo1?l00006ooooo`Oo000000?oooooo`000?l000000_l0
0002ooooo`[o00001?ooool2o`0000Gooooo1Ol00009ooooo`?o000000?oooooo`000?l000000ooo
ool4o`0000;ooooo0_l0001Vooooo`;o0000J_ooool2o`0000Cooooo000Nooooo`03o`000?oooooo
oooo00kooooo0_l00006ooooo`Go00000_ooool2o`0000Cooooo0_l00006ooooo`Go00000_ooool2
o`000003ooooool0003o000000Gooooo0_l000000ooooooo0000o`000005o`0000;ooooo0ol00007
ooooo`?o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00002ooooo`;o00002Oooool2
o`0005Kooooo0_l0000cooooo`;o0000<?ooool2o`0000;ooooo0_l0000?ooooo`;o00001?ooool0
01kooooo00?o0000ooooooooool05_ooool5o`00013ooooo0ol00004ooooo`;o00002?ooool2o`00
0003ooooool0003o000000;o000000?oooooo`000?l000001?l00003ooooo`;o00000_ooool=o`00
00oooooo0_l00008ooooo`;o0000C?ooool2o`0003?ooooo0_l0000Gooooo`;o00005oooool2o`00
00;ooooo0_l0000Eooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o00007?ooool2o`000004
ooooool0003o0000ooooo`;o00003Oooool3o`0000;ooooo0_l00002ooooo`;o000000?oooooo`00
0?l000002ol00002ooooo`?o00001Oooool2o`0000Oooooo1?l00006ooooo`;o00001oooool2o`00
097ooooo0_l0000booooo`007_ooool00ol0003oooooooooo`0;ooooo`;o000000Coooooo`000?l0
003o00004?ooool2o`0000;ooooo0_l00008ooooo`;o00003_ooool5o`0000Kooooo0_l00003oooo
o`Go00000_ooool5o`000004ooooool0003o0000o`0000Gooooo0ol00008ooooo`;o00003oooool2
o`000<Gooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l00002ooooo`;o00001_ooool2o`00
00Sooooo0_l00002ooooo`;o00001_ooool4o`0000;ooooo1?l00008ooooo`;o00001_ooool2o`00
00Cooooo0_l000000ooooooo0000o`00000>o`0000Gooooo0_l0000Looooo`;o0000D?ooool2o`00
073ooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0000;ooooo`;o00001oooool2o`000004
ooooool0003o0000ooooo`Co00001oooool3o`0000Kooooo0ol00003ooooo`oo00000_ooool2o`00
02?ooooo0_l0000Cooooo`;o0000>oooool2o`0003Cooooo0_l0000jooooo`007_ooool00ol0003o
ooooooooo`0Kooooo`;o00001oooool2o`0000[ooooo0_l0000<ooooo`?o00001Oooool4o`0000Co
oooo0_l00003ooooo`Oo00001?ooool2o`0000kooooo0_l0000Oooooo`;o00001oooool2o`0001;o
oooo0_l0001Mooooo`;o0000>_ooool001kooooo00?o0000ooooooooool06Oooool4o`0000Gooooo
0_l00009ooooo`;o00002?ooool2o`0000Gooooo0_l00006ooooo`;o00002Oooool2o`0000;ooooo
0_l000000ooooooo0000o`000004ooooo`;o00000_ooool2o`0000[ooooo0_l0000Oooooo`;o0000
6oooool2o`0009Wooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l00007ooooo`;o00002Ooo
ool2o`0000Sooooo0_l00002ooooo`;o00000oooool8o`0000Wooooo0_l00002ooooo`Go00002?oo
ool2o`0007cooooo0_l0001Looooo`;o00001oooool001kooooo00?o0000ooooooooool01Oooool2
o`0001;ooooo0_l0000<ooooo`;o00001_ooool2o`0000[ooooo0_l00003ooooo`So00001oooool4
o`0000;ooooo1?l00008ooooo`;o00001Oooool2o`00037ooooo0_l00013ooooo`;o0000=?ooool2
o`0002Kooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`05ooooo`;o00001Oooool2o`00
00_ooooo0_l00006ooooo`;o00001?ooool2o`0000Gooooo0ol00005ooooo`?o00002?ooool2o`00
0003ooooool0003o000000;o00001oooool2o`000003ooooool0003o000000;ooooo0ol00003oooo
o`;o00000oooool2o`0000Gooooo0_l0000Rooooo`;o00003Oooool2o`0007Wooooo0_l0000Ioooo
o`;o00005?ooool001kooooo00?o0000ooooooooool03?ooool2o`0000_ooooo0_l00002ooooo`;o
00000_ooool2o`0000_ooooo0_l00002ooooo`;o00000_ooool6o`0000Gooooo1ol00005ooooo`;o
00000oooool8o`0000;ooooo0_l00007ooooo`?o00009?ooool2o`00053ooooo0_l0001Aooooo`;o
00005?ooool001kooooo0_l0000Jooooo`;o00000_ooool2o`0001?ooooo0ol00004ooooo`?o0000
0oooool2o`0000;ooooo0_l00003ooooo`;o00000oooool3o`0000?ooooo2?l00006ooooo`;o0000
00?oooooo`000?l000000_l0000>ooooo`;o0000I_ooool2o`0006Oooooo000Nooooo`03o`000?oo
oooooooo01Wooooo1?l0000Fooooo`;o00002_ooool2o`0000Gooooo1?l00004ooooo`Co000000?o
ooooo`000?l000001_l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000;o00001Ooo
ool2o`0000Oooooo0_l0002Pooooo`;o00008Oooool2o`0000[ooooo000Nooooo`03o`000?oooooo
oooo01_ooooo0_l00009ooooo`;o00004_ooool5o`0000Oooooo0_l00006ooooo`co00000oooool6
o`0000Wooooo0ol00007ooooo`Co0000W_ooool2o`0000kooooo0_l0000Aooooo`;o00002_ooool0
01kooooo00?o0000ooooooooool09?ooool4o`0000oooooo0_l000000ooooooo0000o`000005o`00
00?ooooo0_l00003ooooo`;o00001_ooool:o`000004ooooool0003o0000ooooo`Ko00001oooool3
o`0000Oooooo1?l0002^ooooo`;o00007Oooool001kooooo00?o0000ooooooooool08?ooool2o`00
00;ooooo1?l0000?ooooo`;o00000_ooool6o`0000?ooooo0_l00003ooooo`;o00002?ooool2o`00
00?ooooo0ol000001?oooooo0000o`000?l00002ooooo`Ko00000oooool2o`000003ooooool0003o
000000;o0000e_ooool001kooooo00?o0000ooooooooool08?ooool2o`0000Cooooo0_l0000Doooo
o`;o00001?ooool2o`00017ooooo0_l000000ooooooo0000o`000003ooooo`?o000000?oooooo`00
0?l000001?l00003ooooo`;o00000oooool2o`0000;ooooo0_l00019ooooo`;o0000Qoooool001ko
oooo00?o0000ooooooooool05?ooool2o`0002Kooooo0_l00004ooooo`Co00001oooool2o`0000Ko
oooo0_l00006ooooo`?o000000Coooooo`000?l0003o00001_ooool2o`0000Oooooo0_l00019oooo
o`;o0000Qoooool001kooooo00?o0000ooooooooool02?ooool4o`0000Sooooo0_l0000Looooo`;o
000000?oooooo`000?l000000ol00002ooooo`;o00001_ooool2o`0000?ooooo0_l00002ooooo`;o
00001Oooool2o`0000_ooooo0_l00002ooooo`Co000000?oooooo`000?l000001Oooool2o`000<_o
oooo0ol00006ooooo`007_ooool00ol0003oooooooooo`06ooooo`Ko00009_ooool2o`000003oooo
ool0003o000000?o00001oooool2o`0000?ooooo0_l000000ooooooo0000o`000009ooooo`;o0000
1?ooool2o`0000Gooooo0ol000000ooooooo0000o`000005o`0000Gooooo0_l0003;ooooo`?o0000
1_ooool001kooooo00?o0000ooooooooool01_ooool2o`0002kooooo0ol00008ooooo`;o000000?o
ooooo`000?l000000_l0000Booooo`;o00001Oooool3o`0000;ooooo1?l00002ooooo`;o00000_oo
ool2o`00037ooooo0_l0002Rooooo`007_ooool00ol0003oooooooooo`0_ooooo`;o00001Oooool3
o`000003ooooool0003o000000Sooooo0_l0000=ooooo`;o00004Oooool4o`0000;ooooo0_l00002
ooooo`;o0000<Oooool2o`0004Gooooo0_l0001:ooooo`;o00003oooool001kooooo00?o0000oooo
ooooool0;oooool2o`0000Gooooo0_l00002ooooo`;o00002_ooool2o`0000?ooooo0_l00006oooo
o`;o00002_ooool2o`0000Gooooo1?l0000[ooooo`;o00008_ooool2o`0002oooooo0_l0001:oooo
o`;o00003oooool001kooooo00?o0000ooooooooool0A_ooool3o`0000;ooooo1?l00005ooooo`;o
00000_ooool4o`000003ooooool0003o000000Co00000oooool5o`00017ooooo0_l0000Gooooo`;o
00008_ooool2o`0008cooooo000Nooooo`03o`000?oooooooooo02Sooooo0_l0000Mooooo`;o0000
1?ooool2o`0000Gooooo0_l00002ooooo`Co000000?oooooo`000?l000000_ooool2o`0000Cooooo
1?l00007ooooo`;o00002?ooool2o`0001Sooooo0_l0000jooooo`;o00003Oooool2o`0006Cooooo
000Nooooo`03o`000?oooooooooo02Sooooo0_l0000Sooooo`;o00006?ooool2o`0000Wooooo0_l0
000;ooooo`;o00005Oooool2o`0003[ooooo0_l0000=ooooo`;o00006?ooool2o`0004[ooooo000N
ooooo`;o0000@Oooool2o`0000_ooooo0_l00002ooooo`;o00000oooool4o`0000Wooooo0_l0000J
ooooo`?o00001Oooool2o`0001Wooooo0_l0001Gooooo`;o0000;_ooool2o`0001[ooooo000Noooo
o`;o00005Oooool2o`0002[ooooo0_l0000?ooooo`;o00000oooool4o`000003ooooool0003o0000
00Kooooo0_l00003ooooo`;o00001_ooool2o`0000kooooo0_l000000ooooooo0000o`000002oooo
o`;o00006Oooool2o`0008Oooooo0_l0000Jooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o
00004?ooool2o`0003?ooooo0_l00006ooooo`?o00000_ooool2o`0000Kooooo0_l0000Aooooo`;o
00003?ooool2o`000;Cooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l0000Iooooo`;o0000
6Oooool2o`0001gooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00009oooool2o`000;Co
oooo000Nooooo`?o00002oooool2o`00017ooooo0_l0000Qooooo`;o00005?ooool2o`0000Gooooo
1?l00006ooooo`;o00001_ooool2o`000;;ooooo0_l0000Qooooo`007_ooool3o`000003ooooool0
003o000001Sooooo0_l000000ooooooo0000o`00000gooooo`;o00001Oooool2o`0000Cooooo0_l0
00001?oooooo0000o`000?ooool2o`0000Cooooo0ol0000Zooooo`;o00004oooool2o`00073ooooo
0_l0000Qooooo`007_ooool01?l0003oooooooooooooool2o`0001Sooooo0_l0000aooooo`;o0000
4_ooool7o`000003ooooool0003o000000Gooooo0_l0000Zooooo`;o00002Oooool2o`0000Sooooo
0_l0002Cooooo`007_ooool00ol0003oooooooooo`0oooooo`;o00002oooool4o`0000kooooo0_l0
0002ooooo`;o00000_ooool2o`0001_ooooo0_l0000Cooooo`;o00003_ooool2o`00097ooooo0_l0
000:ooooo`007_ooool00ol0003oooooooooo`0<ooooo`Co00002?ooool2o`0002Gooooo0_l00007
ooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o00001Oooool4o`0000Wooooo0_l0000;
ooooo`;o00002oooool2o`0001?ooooo0_l0000Jooooo`;o00007oooool2o`0006Cooooo0_l0000:
ooooo`007_ooool00ol0003oooooooooo`0<ooooo`Co00002?ooool2o`0001[ooooo0_l0000Boooo
o`;o00001_ooool2o`0000?ooooo0_l00005ooooo`;o00002_ooool3o`0000_ooooo0_l0000loooo
o`;o00007oooool2o`00073ooooo000Nooooo`03o`000?oooooooooo023ooooo0_l0000Booooo`;o
0000<_ooool2o`000:_ooooo0_l0000`ooooo`007_ooool00ol0003oooooooooo`0Oooooo`?o0000
00?oooooo`000?l00000@Oooool4o`0000Oooooo0_l0002Rooooo`;o0000<?ooool001kooooo00?o
0000ooooooooool07oooool2o`0000;ooooo0_l0000Eooooo`;o00004Oooool2o`0001Oooooo0_l0
0009ooooo`;o00006?ooool2o`0000_ooooo0_l0002Looooo`;o00003oooool001kooooo00?o0000
ooooooooool0>_ooool2o`00017ooooo0_l00005ooooo`;o0000=Oooool2o`0000_ooooo0_l0000j
ooooo`;o00009?ooool2o`0003[ooooo0_l0000?ooooo`007_ooool00ol0003oooooooooo`1>oooo
o`;o00000oooool3o`0003Oooooo0_l00015ooooo`;o00009?ooool2o`0004_ooooo000Dooooo`Co
000000?o410@ooooooooool00oooool00ol0003oooooooooo`0Rooooo`;o0000:_ooool2o`0000?o
oooo0ol0000gooooo`;o00001?ooool2o`0000Kooooo0_l00021ooooo`;o00009oooool001Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Rooooo`;o00003?ooool2o`0000kooooo
0_l0000Booooo`Co00005?ooool2o`0002Gooooo0_l00006ooooo`;o0000POooool2o`0002Oooooo
000Fooooo`03o`000?oooooooooo00Gooooo0ol0000Qooooo`;o00003Oooool2o`0000kooooo0_l0
0009ooooo`;o00001oooool4o`0001Cooooo0_l0003Iooooo`005_ooool00ol0003oooooooooo`0Y
ooooo`;o0000:?ooool2o`000?[ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Ko
oooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo
000Dooooo`03oeEEEOmVIVKo00000?ooooooD_ooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001
\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.08153 .80523 Mdot
.25987 .56747 Mdot
.34997 .89434 Mdot
.20944 .78621 Mdot
.29122 .87435 Mdot
.28019 .86107 Mdot
.45576 .37609 Mdot
.23827 .86339 Mdot
.15391 .83889 Mdot
.2611 .90473 Mdot
.34475 .8372 Mdot
.25348 .00116 Mdot
.35066 .92242 Mdot
.00174 .88219 Mdot
.27521 .91222 Mdot
.18044 .99621 Mdot
.26113 .41825 Mdot
.33346 .92834 Mdot
.09272 .79132 Mdot
.14303 .79098 Mdot
.94953 .06309 Mdot
.19035 .92744 Mdot
.29124 .98342 Mdot
.24909 .09988 Mdot
.14153 .804 Mdot
.22588 .86871 Mdot
.19807 .8844 Mdot
.30236 .60818 Mdot
.36115 .90633 Mdot
.21324 .92114 Mdot
.30363 .87737 Mdot
.2726 .89799 Mdot
.14905 .87374 Mdot
.95791 .09568 Mdot
.14245 .79173 Mdot
.24139 .77448 Mdot
.94902 .847 Mdot
.01527 .9939 Mdot
.21608 .03261 Mdot
.18202 .81865 Mdot
.2704 .87023 Mdot
.00884 .86088 Mdot
.33585 .99111 Mdot
.7336 .89799 Mdot
.28833 .0359 Mdot
.98595 .88085 Mdot
.67059 .2311 Mdot
.22111 .60119 Mdot
.21625 .77036 Mdot
.14559 .92466 Mdot
.08666 .93502 Mdot
.2073 .63443 Mdot
.32823 .89768 Mdot
.29709 .97722 Mdot
.37439 .94173 Mdot
.0498 .92259 Mdot
.88228 .9661 Mdot
.33232 .89345 Mdot
.20141 .89046 Mdot
.42087 .85858 Mdot
.28195 .86401 Mdot
.19475 .86243 Mdot
.6211 .11555 Mdot
.13676 .8168 Mdot
.30275 .81587 Mdot
.21864 .86799 Mdot
.12896 .66405 Mdot
.19651 .88578 Mdot
.29366 .87724 Mdot
.90772 .83531 Mdot
.81315 .05342 Mdot
.43016 .04743 Mdot
.30173 .85337 Mdot
.20844 .39825 Mdot
.30564 .74784 Mdot
.90779 .96448 Mdot
.15496 .91883 Mdot
.70811 .27283 Mdot
.2393 .89355 Mdot
.45831 .9923 Mdot
.12535 .64592 Mdot
.71661 .62595 Mdot
.44898 .74117 Mdot
.22133 .86868 Mdot
.62617 .9473 Mdot
.91278 .90063 Mdot
.24794 .84797 Mdot
.21256 .82973 Mdot
.28767 .894 Mdot
.49267 .95517 Mdot
.18454 .86331 Mdot
.95399 .80647 Mdot
.40244 .04098 Mdot
.44221 .95996 Mdot
.08908 .84095 Mdot
.25047 .64499 Mdot
.44569 .95706 Mdot
.13737 .72461 Mdot
.30558 .92713 Mdot
.36036 .73411 Mdot
.19797 .90009 Mdot
.01334 .90553 Mdot
.22752 .87711 Mdot
.11843 .68506 Mdot
.11246 .59777 Mdot
.28898 .9961 Mdot
.05961 .29093 Mdot
.08206 .2826 Mdot
.2851 .67693 Mdot
.02091 .23501 Mdot
.94844 .81761 Mdot
.55656 .13539 Mdot
.21501 .64238 Mdot
.33689 .90145 Mdot
.27089 .25496 Mdot
.32445 .17206 Mdot
.0419 .7985 Mdot
.34257 .94777 Mdot
.92518 .78182 Mdot
.32691 .65739 Mdot
.17458 .85338 Mdot
.21762 .61416 Mdot
.29238 .81621 Mdot
.90687 .02671 Mdot
.40862 .5881 Mdot
.53783 .5579 Mdot
.25171 .8976 Mdot
.07906 .81062 Mdot
.20832 .11735 Mdot
.36541 .63705 Mdot
.03754 .55979 Mdot
.7068 .34949 Mdot
.17373 .21975 Mdot
.24561 .96901 Mdot
.23591 .89763 Mdot
.30727 .91093 Mdot
.29706 .99799 Mdot
.32138 .00979 Mdot
.24315 .84854 Mdot
.24281 .8447 Mdot
.10424 .85563 Mdot
.15348 .82732 Mdot
.14151 .93239 Mdot
.36407 .17944 Mdot
.22546 .81298 Mdot
.27246 .96087 Mdot
.06122 .89376 Mdot
.19659 .88499 Mdot
.32038 .74644 Mdot
.32501 .98753 Mdot
.1789 .93962 Mdot
.15047 .90288 Mdot
.22603 .00047 Mdot
.13792 .78855 Mdot
.25527 .91349 Mdot
.31801 .93443 Mdot
.29242 .0548 Mdot
.17024 .36745 Mdot
.18062 .83122 Mdot
.27011 .8234 Mdot
.28682 .01693 Mdot
.16465 .08483 Mdot
.67627 .27763 Mdot
.22214 .96296 Mdot
.27958 .89044 Mdot
.32 .91497 Mdot
.20212 .87323 Mdot
.21944 .85913 Mdot
.24007 .28509 Mdot
.27466 .00208 Mdot
.18118 .93063 Mdot
.13695 .77366 Mdot
.10835 .87695 Mdot
.79553 .78543 Mdot
.07912 .81336 Mdot
.21303 .10413 Mdot
.40173 .06773 Mdot
.29619 .84701 Mdot
.44026 .45291 Mdot
.20101 .64556 Mdot
.29897 .06369 Mdot
.38519 .85389 Mdot
.18629 .7511 Mdot
.36031 .05841 Mdot
.13865 .35367 Mdot
.05025 .85763 Mdot
.36192 .5925 Mdot
.21392 .91244 Mdot
.43456 .17859 Mdot
.35165 .11823 Mdot
.0715 .80493 Mdot
.32415 .06283 Mdot
.07926 .8152 Mdot
.20166 .78874 Mdot
.27706 .67091 Mdot
.36298 .01005 Mdot
.18376 .13666 Mdot
.34501 .76922 Mdot
.13918 .83963 Mdot
.24329 .78583 Mdot
.66814 .01619 Mdot
.91755 .58247 Mdot
.24703 .94465 Mdot
.05466 .74979 Mdot
.13891 .80591 Mdot
.21498 .81988 Mdot
.60886 .56353 Mdot
.21335 .88725 Mdot
.62794 .95464 Mdot
.24536 .11813 Mdot
.28671 .97725 Mdot
.0714 .86804 Mdot
.86139 .16879 Mdot
.1483 .15101 Mdot
.30983 .01474 Mdot
.3037 .46257 Mdot
.2082 .83718 Mdot
.45659 .14453 Mdot
.21781 .7807 Mdot
.05435 .85191 Mdot
.64262 .69303 Mdot
.23132 .82454 Mdot
.19518 .85441 Mdot
.24011 .86545 Mdot
.50908 .95755 Mdot
.33341 .08625 Mdot
.44007 .73895 Mdot
.31352 .94533 Mdot
.39119 .49705 Mdot
.15645 .91728 Mdot
.2522 .90588 Mdot
.44304 .86969 Mdot
.15876 .9311 Mdot
.94872 .23626 Mdot
.29599 .59555 Mdot
.5547 .95126 Mdot
.15626 .90395 Mdot
.34274 .90507 Mdot
.00605 .49899 Mdot
.35386 .51911 Mdot
.37275 .89031 Mdot
.15811 .94229 Mdot
.13806 .68523 Mdot
.16586 .02044 Mdot
.14522 .94367 Mdot
.27799 .70134 Mdot
.34699 .88523 Mdot
.16769 .94397 Mdot
.53973 .68517 Mdot
.27965 .88094 Mdot
.23334 .6467 Mdot
.35505 .97389 Mdot
.32467 .49319 Mdot
.86627 .557 Mdot
.37447 .5373 Mdot
.26281 .5897 Mdot
.31791 .90309 Mdot
.74531 .63121 Mdot
.12476 .65988 Mdot
.52749 .85349 Mdot
.07064 .8444 Mdot
.28043 .92897 Mdot
.29332 .3215 Mdot
.66326 .93157 Mdot
.15577 .93628 Mdot
.6907 .89563 Mdot
.0707 .77806 Mdot
.97008 .52879 Mdot
.33875 .92542 Mdot
.18056 .84928 Mdot
.29491 .91386 Mdot
.20017 .54698 Mdot
.28799 .90485 Mdot
.27218 .94199 Mdot
.08993 .69554 Mdot
.33499 .9892 Mdot
.18336 .74902 Mdot
.44084 .82928 Mdot
.27498 .83602 Mdot
.05007 .87055 Mdot
.8343 .05998 Mdot
.17969 .93484 Mdot
.22731 .93143 Mdot
.9543 .99496 Mdot
.31295 .90058 Mdot
.18512 .84641 Mdot
.28918 .98558 Mdot
.40566 .91386 Mdot
.27188 .79391 Mdot
.1836 .93886 Mdot
.17913 .74341 Mdot
.98547 .99608 Mdot
.11809 .79436 Mdot
.4769 .83081 Mdot
.78713 .72397 Mdot
.33445 .12758 Mdot
.31076 .84636 Mdot
.32005 .61874 Mdot
.64241 .85273 Mdot
.35657 .51336 Mdot
.16528 .58666 Mdot
.32222 .96989 Mdot
.14858 .9968 Mdot
.41991 .08512 Mdot
.7237 .76041 Mdot
.34749 .84404 Mdot
.20464 .88428 Mdot
.23368 .90879 Mdot
.0292 .14399 Mdot
.86787 .55904 Mdot
.19351 .87086 Mdot
.84636 .62751 Mdot
.21447 .87187 Mdot
.26333 .90331 Mdot
.20302 .77579 Mdot
.1837 .04309 Mdot
.13008 .06047 Mdot
.01998 .82129 Mdot
.23977 .86558 Mdot
.41303 .10601 Mdot
.23164 .03395 Mdot
.16358 .8678 Mdot
.01804 .83217 Mdot
.21953 .95218 Mdot
.30875 .89005 Mdot
.2718 .91637 Mdot
.26851 .82172 Mdot
.06573 .87893 Mdot
.31351 .01653 Mdot
.22075 .89201 Mdot
.12219 .80981 Mdot
.28878 .85732 Mdot
.476 .56232 Mdot
.79529 .75932 Mdot
.08628 .43579 Mdot
.194 .64994 Mdot
.93298 .90576 Mdot
.17906 .86837 Mdot
.09304 .36932 Mdot
.53611 .98683 Mdot
.25973 .87676 Mdot
.14598 .09854 Mdot
.092 .89158 Mdot
.41824 .04441 Mdot
.15171 .43744 Mdot
.24686 .57257 Mdot
.80167 .07394 Mdot
.21316 .22343 Mdot
.93129 .6271 Mdot
.24782 .8578 Mdot
.33929 .94121 Mdot
.34999 .93506 Mdot
.23304 .99511 Mdot
.29534 .57331 Mdot
.48758 .61688 Mdot
.28652 .89549 Mdot
.03156 .80832 Mdot
.20027 .89155 Mdot
.36002 .90511 Mdot
.47007 .86856 Mdot
.16795 .94285 Mdot
.05464 .94928 Mdot
.28085 .87121 Mdot
.29491 .9917 Mdot
.2249 .89295 Mdot
.18249 .67002 Mdot
.09175 .81419 Mdot
.32828 .112 Mdot
.11521 .5305 Mdot
.26666 .90967 Mdot
.25109 .94957 Mdot
.21366 .88027 Mdot
.32673 .91268 Mdot
.18092 .87393 Mdot
.38456 .85832 Mdot
.29454 .429 Mdot
.39894 .14455 Mdot
.20741 .76191 Mdot
.46646 .18949 Mdot
.17517 .92237 Mdot
.24773 .88754 Mdot
.14097 .79126 Mdot
.12611 .00052 Mdot
.0355 .76518 Mdot
.21102 .95331 Mdot
.16995 .74795 Mdot
.37107 .67867 Mdot
.05654 .55638 Mdot
.1858 .87165 Mdot
.41636 .9571 Mdot
.10224 .85794 Mdot
.34926 .92165 Mdot
.2339 .91053 Mdot
.30286 .8575 Mdot
.2876 .8583 Mdot
.57019 .02391 Mdot
.44222 .45366 Mdot
.30144 .92003 Mdot
.19985 .89247 Mdot
.2949 .878 Mdot
.38821 .91999 Mdot
.1193 .79175 Mdot
.29305 .9788 Mdot
.19976 .86427 Mdot
.26337 .10883 Mdot
.35853 .18449 Mdot
.12176 .84816 Mdot
.47063 .00539 Mdot
.31807 .09266 Mdot
.22537 .97134 Mdot
.29459 .98322 Mdot
.16808 .82648 Mdot
.30359 .01254 Mdot
.6365 .16404 Mdot
.28916 .85029 Mdot
.31044 .96001 Mdot
.31354 .74975 Mdot
.32968 .08552 Mdot
.24519 .62135 Mdot
.23731 .89895 Mdot
.19538 .84928 Mdot
.68871 .67555 Mdot
.8628 .93802 Mdot
.34504 .93554 Mdot
.2944 .8867 Mdot
.04245 .30167 Mdot
.70639 .69955 Mdot
.15068 .86906 Mdot
.42857 .02814 Mdot
.41958 .9769 Mdot
.25262 .32845 Mdot
.67705 .18582 Mdot
.34668 .69846 Mdot
.12758 .8159 Mdot
.11543 .46135 Mdot
.09401 .65262 Mdot
.20126 .90844 Mdot
.35775 .65624 Mdot
.15317 .94571 Mdot
.26332 .03038 Mdot
.09581 .76043 Mdot
.86829 .61359 Mdot
.376 .61099 Mdot
.28478 .89601 Mdot
.40948 .09788 Mdot
.2486 .9065 Mdot
.18906 .84046 Mdot
.30767 .92499 Mdot
.64128 .54542 Mdot
.29701 .73561 Mdot
.40671 .60784 Mdot
.28042 .70492 Mdot
.22909 .85289 Mdot
.24457 .87989 Mdot
.15614 .97309 Mdot
.19683 .88044 Mdot
.14522 .81582 Mdot
.27391 .84722 Mdot
.31788 .13181 Mdot
.48225 .31795 Mdot
.24507 .79067 Mdot
.21855 .85907 Mdot
.25296 .87752 Mdot
.36163 .86029 Mdot
.97349 .18376 Mdot
.12229 .75501 Mdot
.15706 .8647 Mdot
.17806 .85812 Mdot
.28475 .91735 Mdot
.12642 .6955 Mdot
.24825 .91707 Mdot
.22331 .84736 Mdot
.22158 .86428 Mdot
.22234 .86667 Mdot
.3631 .83661 Mdot
.26052 .89386 Mdot
.38753 .91452 Mdot
.26893 .88849 Mdot
.22087 .47033 Mdot
.42461 .87345 Mdot
.94942 .51013 Mdot
.30257 .79931 Mdot
.15723 .9399 Mdot
.1232 .87917 Mdot
.07552 .81197 Mdot
.16811 .75397 Mdot
.02154 .48192 Mdot
.28274 .25326 Mdot
.15696 .85651 Mdot
.28516 .66381 Mdot
.32194 .91759 Mdot
.20458 .84642 Mdot
.42391 .19976 Mdot
.35463 .64277 Mdot
.15201 .81693 Mdot
.34803 .76279 Mdot
.23533 .95159 Mdot
.25577 .79821 Mdot
.9105 .90246 Mdot
.1704 .07049 Mdot
.31266 .84331 Mdot
.25193 .64094 Mdot
.19046 .79632 Mdot
.35672 .14578 Mdot
.32841 .95715 Mdot
.07966 .98554 Mdot
.21064 .8526 Mdot
.13386 .66735 Mdot
.14883 .81737 Mdot
.18009 .88887 Mdot
.19722 .89582 Mdot
.45235 .58102 Mdot
.2647 .61259 Mdot
.2172 .53969 Mdot
.28762 .86745 Mdot
.45332 .95642 Mdot
.2307 .06173 Mdot
.24975 .64247 Mdot
.20839 .64323 Mdot
.28276 .88464 Mdot
.17416 .87071 Mdot
.37628 .83943 Mdot
.2435 .88983 Mdot
.27023 .80649 Mdot
.34739 .003 Mdot
.86615 .82041 Mdot
.42201 .23139 Mdot
.86057 .46897 Mdot
.29646 .96241 Mdot
.44182 .06875 Mdot
.76279 .48425 Mdot
.52679 .02989 Mdot
.30482 .89051 Mdot
.19558 .0071 Mdot
.22825 .87622 Mdot
.19268 .89899 Mdot
.2907 .80191 Mdot
.12901 .86358 Mdot
.74646 .00085 Mdot
.67742 .84676 Mdot
.24689 .84453 Mdot
.02708 .57802 Mdot
.31532 .88895 Mdot
.25435 .90186 Mdot
.26212 .84685 Mdot
.43124 .05735 Mdot
.70999 .46431 Mdot
.20327 .78377 Mdot
.23889 .98534 Mdot
.27015 .91705 Mdot
.84605 .01162 Mdot
.50704 .16359 Mdot
.12974 .87855 Mdot
.0559 .1095 Mdot
.12547 .6401 Mdot
.16438 .98426 Mdot
.3255 .25837 Mdot
.17268 .86479 Mdot
.22489 .78628 Mdot
.93315 .20259 Mdot
.23575 .9944 Mdot
.32936 .83329 Mdot
.03566 .94384 Mdot
.34981 .85421 Mdot
.30208 .97711 Mdot
.24764 .78634 Mdot
.2638 .0149 Mdot
.21523 .86013 Mdot
.36267 .63671 Mdot
.2864 .88818 Mdot
.25919 .58484 Mdot
.16232 .65195 Mdot
.26493 .88861 Mdot
.06593 .90593 Mdot
.36304 .91467 Mdot
.12739 .89136 Mdot
.34227 .72464 Mdot
.36652 .90574 Mdot
.35671 .97843 Mdot
.40678 .77979 Mdot
.40246 .18825 Mdot
.94331 .64612 Mdot
.33419 .89434 Mdot
.14366 .8565 Mdot
.60214 .89748 Mdot
.21226 .75902 Mdot
.05672 .81966 Mdot
.20302 .91356 Mdot
.28387 .71396 Mdot
.11154 .84321 Mdot
.28477 .89128 Mdot
.38021 .90851 Mdot
.37971 .06378 Mdot
.2245 .8105 Mdot
.18842 .94132 Mdot
.20326 .87675 Mdot
.18681 .07819 Mdot
.25477 .90959 Mdot
.22102 .75596 Mdot
.22982 .68107 Mdot
.12713 .91225 Mdot
.21259 .86727 Mdot
.32841 .92355 Mdot
.13182 .73986 Mdot
.39023 .27038 Mdot
.21546 .94178 Mdot
.18772 .86025 Mdot
.19372 .93587 Mdot
.51808 .11139 Mdot
.07524 .81792 Mdot
.30324 .1905 Mdot
.96595 .86125 Mdot
.29975 .90501 Mdot
.5922 .82883 Mdot
.08129 .80824 Mdot
.29437 .72912 Mdot
.41884 .03817 Mdot
.71637 .70984 Mdot
.32368 .96941 Mdot
.62785 .3879 Mdot
.25913 .95507 Mdot
.24498 .59212 Mdot
.07502 .81172 Mdot
.14305 .48311 Mdot
.14207 .87508 Mdot
.1461 .70949 Mdot
.06125 .00435 Mdot
.99576 .04643 Mdot
.35759 .96968 Mdot
.02721 .82787 Mdot
.30496 .85821 Mdot
.22957 .86027 Mdot
.2262 .83285 Mdot
.5778 .88996 Mdot
.26668 .88523 Mdot
.64559 .98793 Mdot
.22969 .87041 Mdot
.44209 .08346 Mdot
.31666 .88885 Mdot
.28686 .91137 Mdot
.2474 .85935 Mdot
.28212 .87518 Mdot
.02929 .79783 Mdot
.99271 .9242 Mdot
.22325 .22607 Mdot
.12686 .88037 Mdot
.13024 .95538 Mdot
.39164 .00555 Mdot
.21698 .88007 Mdot
.47028 .17903 Mdot
.22311 .18398 Mdot
.33289 .78473 Mdot
.31164 .65431 Mdot
.24664 .86466 Mdot
.64095 .50961 Mdot
.17679 .8178 Mdot
.3617 .88688 Mdot
.35165 .84565 Mdot
.59041 .95052 Mdot
.19812 .88835 Mdot
.44074 .14778 Mdot
.28168 .9603 Mdot
.83906 .7246 Mdot
.16746 .81935 Mdot
.19636 .99023 Mdot
.3905 .15927 Mdot
.23484 .90449 Mdot
.7906 .96324 Mdot
.33995 .61135 Mdot
.26384 .70292 Mdot
.41303 .99531 Mdot
.10346 .5955 Mdot
.99181 .77277 Mdot
.14898 .86835 Mdot
.50354 .04641 Mdot
.1956 .86629 Mdot
.91071 .68322 Mdot
.35043 .92853 Mdot
.87629 .83909 Mdot
.9594 .75483 Mdot
.48422 .38679 Mdot
.36068 .18082 Mdot
.3094 .83548 Mdot
.07776 .79943 Mdot
.28441 .88743 Mdot
.09965 .98394 Mdot
.02979 .93226 Mdot
.08236 .32842 Mdot
.44263 .8759 Mdot
.36237 .90175 Mdot
.28322 .5977 Mdot
.16304 .89442 Mdot
.44931 .235 Mdot
.13469 .64782 Mdot
.14111 .89896 Mdot
.28148 .93438 Mdot
.25051 .87496 Mdot
.38808 .74562 Mdot
.8714 .47841 Mdot
.10179 .88055 Mdot
.42168 .16998 Mdot
.24916 .61361 Mdot
.3237 .94039 Mdot
.2134 .84967 Mdot
.01683 .52815 Mdot
.25712 .82352 Mdot
.66857 .42828 Mdot
.08044 .18855 Mdot
.1493 .68757 Mdot
.11994 .85299 Mdot
.32741 .69827 Mdot
.45946 .95984 Mdot
.09756 .73761 Mdot
.63274 .06148 Mdot
.31827 .9612 Mdot
.93982 .36665 Mdot
.16492 .94514 Mdot
.28195 .84883 Mdot
.02482 .92586 Mdot
.17266 .94023 Mdot
.06706 .88579 Mdot
.06873 .0354 Mdot
.18895 .90583 Mdot
.69793 .07102 Mdot
.13334 .56821 Mdot
.49422 .81715 Mdot
.77744 .75248 Mdot
.16548 .84226 Mdot
.3436 .86246 Mdot
.31214 .89909 Mdot
.22096 .81549 Mdot
.17911 .90715 Mdot
.32522 .94172 Mdot
.20234 .84173 Mdot
.22719 .57792 Mdot
.43087 .08492 Mdot
.60026 .42409 Mdot
.43518 .42301 Mdot
.20873 .98236 Mdot
.426 .42623 Mdot
.21634 .87288 Mdot
.15781 .79338 Mdot
.08631 .83497 Mdot
.26854 .61082 Mdot
.61388 .04928 Mdot
.22893 .90584 Mdot
.16932 .91239 Mdot
.93369 .99187 Mdot
.37506 .84852 Mdot
.2141 .70113 Mdot
.17697 .78347 Mdot
.32323 .88059 Mdot
.47354 .74619 Mdot
.06186 .89547 Mdot
.17948 .90714 Mdot
.26671 .90159 Mdot
.30518 .98222 Mdot
.06504 .7085 Mdot
.39378 .90605 Mdot
.3177 .90515 Mdot
.04869 .87354 Mdot
.23214 .85957 Mdot
.35238 .89698 Mdot
.33394 .87176 Mdot
.08927 .69853 Mdot
.25541 .83529 Mdot
.32908 .75155 Mdot
.13854 .07726 Mdot
.34593 .76901 Mdot
.24754 .588 Mdot
.16415 .79759 Mdot
.1621 .93838 Mdot
.26098 .00151 Mdot
.35483 .97381 Mdot
.9941 .23213 Mdot
.18924 .86956 Mdot
.38026 .95678 Mdot
.3248 .91753 Mdot
.17677 .95901 Mdot
.31963 .98782 Mdot
.19934 .78475 Mdot
.18562 .65864 Mdot
.22651 .31538 Mdot
.3458 .37148 Mdot
.26607 .81588 Mdot
.20696 .85908 Mdot
.34172 .58687 Mdot
.24161 .84346 Mdot
.20842 .8495 Mdot
.30771 .93016 Mdot
.98428 .84324 Mdot
.12346 .51743 Mdot
.09295 .92408 Mdot
.2756 .85786 Mdot
.2078 .12041 Mdot
.36133 .89385 Mdot
.25668 .6595 Mdot
.5211 .61462 Mdot
.18882 .76225 Mdot
.46132 .96648 Mdot
.0446 .74919 Mdot
.20071 .93312 Mdot
.33906 .8957 Mdot
.28349 .68148 Mdot
.4538 .90353 Mdot
.31235 .94205 Mdot
.48567 .13564 Mdot
.4694 .08848 Mdot
.28727 .14981 Mdot
.1069 .79267 Mdot
.33624 .56853 Mdot
.20968 .75567 Mdot
.37494 .85019 Mdot
.13338 .86489 Mdot
.21683 .9288 Mdot
.2242 .87928 Mdot
.48951 .3452 Mdot
.82948 .79879 Mdot
.26694 .91873 Mdot
.46065 .86542 Mdot
.22998 .8717 Mdot
.25052 .89757 Mdot
.37797 .95374 Mdot
.31973 .93059 Mdot
.23617 .84222 Mdot
.18451 .87129 Mdot
.30766 .88951 Mdot
.30118 .92907 Mdot
.87957 .9001 Mdot
.26515 .68262 Mdot
.01927 .73807 Mdot
.42514 .93878 Mdot
.37493 .90937 Mdot
.56288 .92714 Mdot
.98196 .88394 Mdot
.23235 .99168 Mdot
.4623 .58125 Mdot
.21338 .77081 Mdot
.22193 .90719 Mdot
.78711 .39408 Mdot
.02044 .11476 Mdot
.25457 .90529 Mdot
.20541 .88747 Mdot
.18284 .84742 Mdot
.89038 .91609 Mdot
.29153 .23022 Mdot
.96563 .6221 Mdot
.33873 .94293 Mdot
.19879 .87249 Mdot
.31662 .87689 Mdot
.06168 .8524 Mdot
.50557 .95688 Mdot
.24687 .86047 Mdot
.13769 .80703 Mdot
.18373 .84018 Mdot
.45362 .5465 Mdot
.23182 .86542 Mdot
.21137 .93503 Mdot
.41794 .88055 Mdot
.33395 .88166 Mdot
.23047 .88763 Mdot
.25526 .82094 Mdot
.11563 .86616 Mdot
.57278 .68335 Mdot
.22664 .87488 Mdot
.35568 .80866 Mdot
.08052 .79392 Mdot
.19535 .8991 Mdot
.70208 .51657 Mdot
.29447 .90746 Mdot
.90557 .94456 Mdot
.19092 .87168 Mdot
.14665 .80953 Mdot
.21955 .77544 Mdot
.06305 .70416 Mdot
.25518 .84434 Mdot
.4167 .46104 Mdot
.55254 .15784 Mdot
.2284 .96758 Mdot
.14713 .87895 Mdot
.88602 .88827 Mdot
.25381 .87678 Mdot
.22192 .86061 Mdot
.35851 .8414 Mdot
.40433 .80298 Mdot
.07753 .80718 Mdot
.07075 .87341 Mdot
.58595 .24243 Mdot
.18359 .93125 Mdot
.90467 .88248 Mdot
.96534 .77924 Mdot
.01775 .7199 Mdot
.34835 .85608 Mdot
.16979 .93895 Mdot
.05387 .14449 Mdot
.26662 .85248 Mdot
.60976 .47639 Mdot
.29107 .91625 Mdot
.12961 .8515 Mdot
.3446 .9763 Mdot
.16964 .88286 Mdot
.02384 .80455 Mdot
.58913 .83853 Mdot
.14637 .95876 Mdot
.69842 .7392 Mdot
.29541 .61141 Mdot
.40354 .33016 Mdot
.18938 .9426 Mdot
.14585 .80972 Mdot
.09742 .9007 Mdot
.04068 .9632 Mdot
.0621 .96275 Mdot
.00538 .57377 Mdot
.11347 .86251 Mdot
.32092 .83897 Mdot
.09455 .2597 Mdot
.03115 .93043 Mdot
.15346 .78355 Mdot
.22708 .71291 Mdot
.16615 .85486 Mdot
.79491 .99946 Mdot
.51055 .09494 Mdot
.09334 .88262 Mdot
.21543 .87917 Mdot
.27964 .90652 Mdot
.95552 .91287 Mdot
.35591 .51518 Mdot
.18879 .94045 Mdot
.51112 .85551 Mdot
.59972 .94657 Mdot
.24288 .84674 Mdot
.30416 .00329 Mdot
.277 .89933 Mdot
.15607 .93513 Mdot
.66522 .27582 Mdot
.08446 .83598 Mdot
.38139 .05404 Mdot
.17695 .92076 Mdot
.23054 .90447 Mdot
.07794 .06875 Mdot
.32127 .915 Mdot
.21344 .82817 Mdot
.1467 .79972 Mdot
.40879 .9041 Mdot
.3923 .8439 Mdot
.27263 .87058 Mdot
.60573 .821 Mdot
.01877 .77467 Mdot
.24196 .84295 Mdot
.40788 .50377 Mdot
.30316 .90883 Mdot
.51093 .83041 Mdot
.11268 .73984 Mdot
.0365 .50028 Mdot
.34684 .8586 Mdot
.34736 .93277 Mdot
.61927 .71948 Mdot
.88173 .6237 Mdot
.69547 .09414 Mdot
.4244 .89003 Mdot
.1975 .92983 Mdot
.23868 .87647 Mdot
.27086 .91852 Mdot
.51062 .92719 Mdot
.2499 .90748 Mdot
.69439 .98015 Mdot
.33455 .02089 Mdot
.28284 .0719 Mdot
.49666 .73463 Mdot
.07703 .81673 Mdot
.19906 .35442 Mdot
.30868 .63045 Mdot
.26061 .06545 Mdot
.34189 .57705 Mdot
.90802 .81885 Mdot
.20347 .85269 Mdot
.3331 .61241 Mdot
.57784 .95159 Mdot
.21678 .89293 Mdot
.19017 .88683 Mdot
.31088 .86032 Mdot
.22999 .83295 Mdot
.44119 .20406 Mdot
.37645 .56383 Mdot
.16229 .90366 Mdot
.25509 .69215 Mdot
.42521 .80244 Mdot
.34152 .55284 Mdot
.16437 .66157 Mdot
.18905 .88722 Mdot
.73911 .4699 Mdot
.19675 .77714 Mdot
.16269 .04267 Mdot
.95943 .91101 Mdot
.26886 .93251 Mdot
.16485 .83562 Mdot
.24942 .91591 Mdot
.18671 .07193 Mdot
.22751 .05501 Mdot
.30222 .79996 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool00_l0000;ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool01?ooool2o`0000Oooooo0_l000000ooooooo
0000o`000002ooooo`;o00001oooool3o`0000cooooo0_l0000@ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00co
oooo0_l0000@ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`02o`0000_ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0;ooooo`;o000000?oooooo`000?ooool03_ooool00ol0003ooooo
ooooo`02o`0000;ooooo0_l00007ooooo`?o00003?ooool2o`0000cooooo0_l00002ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool00oooool2o`0000Sooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003oooooooooo`0kooooo`;o00009ooo
ool2o`0000cooooo0_l00007ooooo`;o00006?ooool2o`000;3ooooo000Nooooo`03o`000?oooooo
oooo05oooooo0_l00003ooooo`;o00003?ooool2o`0009_ooooo0_l0000fooooo`007_ooool00ol0
003oooooooooo`1Booooo`;o00002oooool5o`00077ooooo0_l0000hooooo`;o0000=_ooool001ko
oooo00?o0000ooooooooool0D_ooool2o`0000Gooooo0_l00006ooooo`?o0000LOooool2o`00073o
oooo000Nooooo`03o`000?oooooooooo03;ooooo0_l0000Uooooo`;o00003_ooool2o`000=cooooo
000Nooooo`03o`000?oooooooooo03;ooooo0_l0000eooooo`;o0000B_ooool2o`00093ooooo000N
ooooo`03o`000?oooooooooo08Oooooo0_l0000/ooooo`;o0000K?ooool2o`0002;ooooo000Noooo
o`03o`000?oooooooooo057ooooo0_l0000dooooo`;o00007_ooool2o`0007[ooooo0_l0000Roooo
o`007_ooool00ol0003oooooooooo`12ooooo`;o00000oooool2o`0000Sooooo0_l0001Dooooo`;o
0000W_ooool001kooooo00?o0000ooooooooool04_ooool2o`0002kooooo0_l00003ooooo`;o0000
4Oooool2o`0002Sooooo0_l00031ooooo`007_ooool00ol0003oooooooooo`0Booooo`;o0000A_oo
ool2o`0002?ooooo0_l00003ooooo`;o0000`Oooool001kooooo00?o0000ooooooooool0<Oooool2
o`0000Gooooo0_l00015ooooo`;o00000oooool2o`000<7ooooo000Nooooo`03o`000?oooooooooo
037ooooo0_l00005ooooo`;o0000B_ooool2o`0000;ooooo0_l0000Fooooo`;o0000W_ooool2o`00
00Gooooo000Nooooo`03o`000?oooooooooo08Sooooo0_l0000Fooooo`;o00008Oooool2o`0007_o
oooo0_l00005ooooo`007_ooool2o`000<Cooooo0_l0000oooooo`;o0000@Oooool001kooooo00?o
0000ooooooooool0A_ooool2o`0001?ooooo0_l0000Kooooo`;o0000R_ooool2o`00047ooooo000N
ooooo`03o`000?oooooooooo04Kooooo0_l0000Cooooo`;o00005?ooool2o`0000Gooooo0_l0000>
ooooo`;o0000_Oooool001kooooo00?o0000ooooooooool09_ooool2o`0001oooooo0_l0000Loooo
o`;o00002_ooool2o`0001Gooooo0_l00010ooooo`;o0000?oooool2o`0003[ooooo000Nooooo`03
o`000?oooooooooo02Kooooo0_l0000Oooooo`;o00002?ooool2o`0000[ooooo0_l00006ooooo`;o
00004?ooool2o`00057ooooo0_l0000oooooo`;o00009?ooool2o`0001Cooooo000Nooooo`03o`00
0?oooooooooo01Gooooo0_l0000jooooo`;o00002_ooool2o`0001Sooooo0_l00005ooooo`;o0000
3?ooool2o`000:?ooooo0_l0000Dooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o00007?oo
ool2o`0000Cooooo0_l0000Mooooo`;o00009?ooool2o`0000cooooo0_l0001Aooooo`;o0000I_oo
ool001kooooo00?o0000ooooooooool0<oooool2o`0000Cooooo0_l0000Mooooo`;o0000QOooool2
o`00023ooooo0_l00014ooooo`007_ooool00ol0003oooooooooo`0Yooooo`;o00003_ooool2o`00
0<Kooooo0_l00014ooooo`007_ooool00ol0003oooooooooo`0Yooooo`;o00003_ooool2o`000?oo
oooo3Oooool001kooooo00?o0000ooooooooool0S?ooool2o`000;Wooooo000Nooooo`03o`000?oo
oooooooo037ooooo0_l0000dooooo`?o00006_ooool2o`0000;ooooo0_l00002ooooo`;o0000^Ooo
ool001kooooo00?o0000ooooooooool0<Oooool2o`0003Cooooo0ol0000Jooooo`;o00000_ooool2
o`0000[ooooo0_l0002aooooo`007_ooool00ol0003oooooooooo`1Sooooo`;o0000;oooool2o`00
0;7ooooo000Nooooo`03o`000?oooooooooo06?ooooo0_l0000mooooo`;o0000>_ooool2o`0005?o
oooo0_l0000Booooo`007_ooool00ol0003oooooooooo`0[ooooo`;o0000E?ooool2o`0001oooooo
0_l0000jooooo`;o0000Doooool2o`0001;ooooo000Nooooo`;o0000;?ooool2o`00023ooooo0_l0
000booooo`;o0000a?ooool001kooooo00?o0000ooooooooool0@Oooool2o`0000[ooooo0_l0000c
ooooo`;o0000`oooool001kooooo00?o0000ooooooooool0@Oooool2o`0000oooooo0_l0000^oooo
o`;o0000`oooool001kooooo00?o0000ooooooooool03_ooool2o`0004;ooooo0_l0000Cooooo`;o
0000>oooool2o`000:7ooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l00009ooooo`;o0000
Eoooool2o`0003_ooooo0_l0002Qooooo`007_ooool00ol0003oooooooooo`03ooooo`;o0000>ooo
ool2o`0000[ooooo0_l0000Pooooo`;o0000E_ooool2o`0007oooooo000Nooooo`03o`000?oooooo
oooo03oooooo0ol0000:ooooo`;o00008?ooool2o`0005Kooooo0_l0001oooooo`007_ooool00ol0
003oooooooooo`0oooooo`;o0000ooooool7ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo06Wooooo0_l0003Looooo`007_ooool00ol0003ooooooooo
o`1Sooooo`;o00001?ooool2o`000=cooooo000Nooooo`03o`000?oooooooooo03Sooooo0_l0000Y
ooooo`;o0000=Oooool2o`0001Gooooo0_l0002Dooooo`007_ooool00ol0003oooooooooo`0hoooo
o`;o0000H?ooool2o`0001Gooooo0_l0002Dooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`;o0000HOooool2o`0000cooooo
0_l0000@ooooo`;o0000]Oooool001kooooo00?o0000ooooooooool01Oooool2o`0000Kooooo0_l0
001Qooooo`;o00003?ooool2o`0000_ooooo0_l00003ooooo`;o0000]Oooool001kooooo0_l0000]
ooooo`;o0000:oooool2o`00033ooooo0_l0002jooooo`007_ooool00ol0003oooooooooo`0/oooo
o`;o0000:oooool2o`000>cooooo000Nooooo`03o`000?oooooooooo0;3ooooo0_l0002Eooooo`00
7_ooool00ol0003oooooooooo`1kooooo`;o0000<oooool2o`0009Gooooo000Nooooo`03o`000?oo
oooooooo07_ooooo0_l0000Tooooo`;o0000:?ooool2o`0007[ooooo000Nooooo`03o`000?oooooo
oooo0:7ooooo0_l0000Xooooo`;o0000N_ooool001kooooo00?o0000ooooooooool0QOooool2o`00
08gooooo0_l0000aooooo`007_ooool00ol0003oooooooooo`1Uooooo`;o00007_ooool2o`0008go
oooo0_l0000aooooo`007_ooool00ol0003oooooooooo`1Uooooo`;o0000h?ooool001kooooo00?o
0000ooooooooool0L_ooool2o`0001Gooooo0_l0000:ooooo`;o0000/?ooool001kooooo00?o0000
ooooooooool0LOooool3o`0001Gooooo0_l0000:ooooo`;o0000/?ooool001kooooo00?o0000oooo
ooooool0A?ooool2o`0002[ooooo0ol0001Uooooo`;o0000G_ooool2o`0000gooooo000Nooooo`03
o`000?oooooooooo01Kooooo0_l0000/ooooo`;o0000:_ooool2o`0000gooooo0_l0001Gooooo`;o
0000G_ooool2o`0000gooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l00016ooooo`;o0000
7oooool2o`0001?ooooo0_l0002aooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`1Nooooo`;o0000=?ooool2o`000;7ooooo
0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol00026ooooo`;o0000_oooool000?ooooo
00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000oooooooo
ool0Q_ooool2o`0000?ooooo0_l0002Nooooo`;o00006_ooool000?ooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0Roooool2o`0009ko
oooo0_l0000Jooooo`000oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0oooooom8oooo
o`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0=?ooool2o`00
0?oooooo4_ooool001kooooo00?o0000ooooooooool0=?ooool2o`000?oooooo4_ooool001kooooo
00?o0000ooooooooool0@Oooool2o`000?oooooo1Oooool001kooooo00?o0000ooooooooool0@Ooo
ool2o`000003ooooool0003o00000?oooooo0_ooool001kooooo00?o0000ooooooooool0A?ooool2
o`0001Gooooo0_l0000Xooooo`;o0000Coooool2o`0006oooooo000Nooooo`03o`000?oooooooooo
00?ooooo0_l0001Fooooo`;o0000:?ooool2o`0000Oooooo0_l00016ooooo`;o0000Ioooool2o`00
00Kooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l00029ooooo`;o0000X?ooool2o`0000go
oooo0_l00006ooooo`007_ooool00ol0003oooooooooo`3ooooooc7ooooo0_l0000Eooooo`007_oo
ool00ol0003oooooooooo`2jooooo`;o0000Roooool001kooooo00?o0000ooooooooool0^_ooool2
o`0008_ooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0001Iooooo`;o
0000kOooool001kooooo00?o0000ooooooooool0E?ooool2o`0000;ooooo0_l0003]ooooo`007_oo
ool00ol0003oooooooooo`0Kooooo`;o0000=oooool2o`00013ooooo0_l0003Oooooo`007_ooool0
0ol0003oooooooooo`0Kooooo`;o0000BOooool2o`000=oooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`1kooooo`;o0000b_ooool001kooooo00?o0000ooooooooool0Noooool2o`0006Gooooo0_l0
001Sooooo`007_ooool00ol0003oooooooooo`3Dooooo`;o00000_ooool2o`0000Sooooo0_l0001S
ooooo`007_ooool00ol0003oooooooooo`3Dooooo`;o00000_ooool2o`0006gooooo000Nooooo`03
o`000?oooooooooo01Oooooo0_l0003ooooooboooooo000Nooooo`03o`000?oooooooooo01Oooooo
0_l0000aooooo`;o0000noooool001kooooo00?o0000ooooooooool0B_ooool2o`000?_ooooo000N
ooooo`03o`000?oooooooooo00oooooo0_l0003oooooocOooooo000Nooooo`03o`000?oooooooooo
00oooooo0_l0003oooooocOooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
0_l0000;ooooo`;o0000oooooollooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o0000oooo
oollooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`16ooooo`;o0000DOooool2o`000:cooooo000Nooooo`03o`000?oooooooooo04Kooooo0_l0
001Aooooo`;o0000[?ooool001kooooo00?o0000ooooooooool0Foooool2o`000>[ooooo000Noooo
o`03o`000?oooooooooo05_ooooo0_l0003Zooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o
0000=Oooool2o`0002oooooo0_l00036ooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o0000
=Oooool2o`0002oooooo0_l00036ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`2Kooooo`;o0000Z_ooool001kooooo00?o0000ooooooooool0
Voooool2o`000:[ooooo000Nooooo`;o0000hoooool2o`0006?ooooo000Nooooo`03o`000?oooooo
oooo02Wooooo0_l0000Booooo`;o0000Xoooool2o`0006?ooooo000Nooooo`03o`000?oooooooooo
02Wooooo0_l0000Booooo`;o0000ooooool9ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0<ooo
ool2o`000?Sooooo0_l0000Hooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o00005oooool2
o`000?Sooooo0_l0000Hooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o0000D?ooool2o`00
0=Wooooo000Nooooo`03o`000?oooooooooo06cooooo0_l0000Rooooo`;o0000]Oooool001kooooo
00?o0000ooooooooool0T?ooool2o`000;Gooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`2Ioooo
o`;o0000;Oooool2o`0007gooooo000Nooooo`03o`000?oooooooooo09Wooooo0_l0000]ooooo`;o
0000OOooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003
oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0o?ooool2o`0004Wooooo0003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`3looooo`;o0000BOooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go
00001_ooool3o`00043ooooo0_l0003oooooo`Kooooo0003ooooo`05o`000?ooooooooooooooool0
00002oooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo043ooooo0_l0003ooooo
o`Kooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`3o
ooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0DOooool2o`00
0?Cooooo000Nooooo`03o`000?oooooooooo057ooooo0_l0003dooooo`007_ooool00ol0003ooooo
ooooo`29ooooo`;o0000=?ooool2o`0008Kooooo000Nooooo`03o`000?oooooooooo08Kooooo0_l0
00000ooooooo0000o`00000dooooo`;o00005?ooool2o`00073ooooo000Nooooo`03o`000?oooooo
oooo05cooooo0_l0000Xooooo`;o0000COooool2o`00073ooooo000Nooooo`03o`000?oooooooooo
05cooooo0_l0003Yooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o00004oooool2o`000?oo
oooo6Oooool001kooooo00?o0000ooooooooool06?ooool2o`0001?ooooo0_l0003ooooooaWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000S?ooool2o`000;[o
oooo000Nooooo`03o`000?oooooooooo08_ooooo0ol0002iooooo`007_ooool00ol0003ooooooooo
o`2<ooooo`;o0000^Oooool001kooooo00?o0000ooooooooool08Oooool2o`0003cooooo0_l0000R
ooooo`;o0000`_ooool001kooooo00?o0000ooooooooool08Oooool2o`0003cooooo0_l0000Roooo
o`;o0000G_ooool2o`0006;ooooo000Nooooo`03o`000?oooooooooo0>?ooooo0_l0001Rooooo`00
7_ooool00ol0003oooooooooo`14ooooo`;o0000Y_ooool2o`0002Kooooo0_l0000aooooo`007_oo
ool00ol0003oooooooooo`14ooooo`;o0000Y_ooool2o`0002Kooooo0_l0000aooooo`007_ooool0
0ol0003oooooooooo`32ooooo`;o0000Poooool001kooooo00?o0000ooooooooool0`_ooool2o`00
05?ooooo0_l0000^ooooo`007_ooool00ol0003oooooooooo`03ooooo`;o00009Oooool2o`000<So
oooo0_l0000Qooooo`;o0000;_ooool001kooooo00?o0000ooooooooool00oooool2o`0002Gooooo
0_l00038ooooo`;o0000DOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`1Uooooo`;o0000h?ooool001kooooo00?o0000ooooooooool0IOooool2o`00
0>3ooooo000Nooooo`?o0000Noooool2o`000<[ooooo000Nooooo`?o00002?ooool2o`00077ooooo
0_l0003:ooooo`007_ooool00ol0003oooooooooo`08ooooo`;o0000M_ooool2o`000<Gooooo000N
ooooo`03o`000?oooooooooo083ooooo0_l00035ooooo`007_ooool00ol0003oooooooooo`3<oooo
o`;o0000Hoooool2o`0001Cooooo000Nooooo`03o`000?oooooooooo073ooooo0_l0001Jooooo`;o
0000Hoooool2o`0001Cooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l0001:ooooo`;o0000
K_ooool2o`0006Gooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l00019ooooo`?o0000K_oo
ool2o`0006Gooooo000Nooooo`03o`000?oooooooooo06oooooo0_l0003Fooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`04o`000?ooooooooooooooo`;o0000ooooooleoooo
o`;o00003_ooool001kooooo00Co0000oooooooooooooooo0_l0000Nooooo`;o0000oooooolEoooo
o`;o00003_ooool001kooooo00?o0000ooooooooool08Oooool2o`000?oooooo9Oooool001kooooo
00?o0000ooooooooool0@_ooool2o`0003;ooooo0_l0003?ooooo`007_ooool00ol0003ooooooooo
o`12ooooo`;o0000<_ooool2o`000<oooooo000Nooooo`03o`000?oooooooooo0<cooooo0_l0001i
ooooo`007_ooool00ol0003oooooooooo`0mooooo`;o0000D?ooool2o`0003_ooooo0_l0001ioooo
o`007_ooool2o`0003kooooo0_l0001@ooooo`;o0000]_ooool001kooooo00?o0000ooooooooool0
Joooool2o`000=[ooooo000Nooooo`03o`000?oooooooooo00kooooo0_l0001Kooooo`;o0000?_oo
ool2o`0006Wooooo0_l0000_ooooo`007_ooool00ol0003oooooooooo`08ooooo`;o00001?ooool2
o`0009_ooooo0_l0001Yooooo`;o0000;oooool001kooooo00?o0000ooooooooool02?ooool2o`00
06cooooo0_l0000Oooooo`;o0000:Oooool2o`0005;ooooo0_l0000_ooooo`007_ooool00ol0003o
ooooooooo`1fooooo`;o00007oooool2o`0002Wooooo0_l00023ooooo`007_ooool00ol0003ooooo
ooooo`0Wooooo`;o00009oooool2o`0001Oooooo0_l0003Looooo`007_ooool00ol0003ooooooooo
o`0Wooooo`;o00008oooool2o`0000;ooooo0_l0000:ooooo`;o00002oooool2o`000=cooooo000N
ooooo`?o0000C?ooool2o`0000kooooo0_l0003Yooooo`007_ooool3o`0000Gooooo0_l0000ooooo
o`;o00008oooool2o`000=[ooooo000Nooooo`03o`000?oooooooooo00Gooooo0_l0000oooooo`;o
00008oooool2o`0002;ooooo0_l000000ooooooo0000o`00002Booooo`;o00007oooool001kooooo
00?o0000ooooooooool0D?ooool2o`0003gooooo0_l000000ooooooo0000o`00002Booooo`;o0000
7oooool001kooooo00?o0000ooooooooool0<_ooool2o`0001Sooooo0_l00002ooooo`;o00006Ooo
ool2o`0001Cooooo0_l00034ooooo`007_ooool00ol0003oooooooooo`0booooo`;o00006?ooool2
o`0000?ooooo0_l0000Hooooo`;o00005?ooool2o`000<Cooooo0003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oo
oooooooo04cooooo0_l00003ooooo`;o00007oooool2o`000=?ooooo0003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`00
0?oooooooooo01kooooo1?l0000Zooooo`;o00002_ooool2o`0000;ooooo0_l0000Dooooo`;o0000
doooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
00001_ooool3o`0001kooooo1?l0000Rooooo`;o00004_ooool2o`0000;ooooo0_l0003Yooooo`00
0oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06oooo
o`03o`000?oooooooooo04Cooooo0_l0003oooooo`;ooooo0003ooooo`05o`000?oooooooooooooo
ool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0oooooom8
ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool0
0ol0003oooooooooo`1Nooooo`;o00008?ooool2o`000<Gooooo0003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo05;ooooo0ol00007
ooooo`Co00002?ooool4o`0000[ooooo0_l00008ooooo`;o0000aOooool000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0@ooo
ool2o`0000Sooooo0_l00003ooooo`?o00001oooool2o`0000[ooooo1?l0000:ooooo`;o0000;Ooo
ool2o`0006oooooo0_l0000_ooooo`007_ooool00ol0003oooooooooo`13ooooo`;o00002?ooool2
o`0001Gooooo0_l0000dooooo`;o00002Oooool2o`0006oooooo0_l0000_ooooo`007_ooool00ol0
003oooooooooo`1<ooooo`;o00005_ooool2o`0003Cooooo0_l0002Jooooo`;o00003oooool001ko
oooo00?o0000ooooooooool0C?ooool2o`000<gooooo0_l0000Iooooo`;o00003oooool001kooooo
00?o0000ooooooooool0iOooool2o`0002Sooooo0_l0000:ooooo`;o00003_ooool2o`0001[ooooo
000Nooooo`03o`000?oooooooooo063ooooo0_l00023ooooo`;o00001oooool2o`0001oooooo0_l0
000Jooooo`;o00006_ooool001kooooo00?o0000ooooooooool0?oooool2o`0001oooooo0_l0002<
ooooo`;o0000Eoooool001kooooo00?o0000ooooooooool0?oooool2o`00037ooooo0ol0003Boooo
o`007_ooool00ol0003oooooooooo`0Uooooo`;o00009oooool2o`0002;ooooo0ol0003Booooo`00
7_ooool00ol0003oooooooooo`0Uooooo`;o00006Oooool4o`0000Wooooo0ol0000Oooooo`;o0000
e_ooool001kooooo00?o0000ooooooooool09Oooool2o`0001Kooooo0_l000000ooooooo0000o`00
0002o`0000Cooooo0_l00003ooooo`;o00008?ooool2o`000;kooooo0_l0000Fooooo`007_ooool0
0ol0003oooooooooo`0Uooooo`;o000000?oooooo`000?l000004Oooool4o`0000Wooooo0_l00003
ooooo`;o0000h?ooool2o`0001Kooooo000Nooooo`;o00006oooool2o`0000cooooo0_l00007oooo
o`;o00002?ooool2o`000?oooooo2oooool001kooooo00?o0000ooooooooool06_ooool2o`0001Go
oooo0_l0000^ooooo`;o00003Oooool2o`000=Gooooo000Nooooo`03o`000?oooooooooo03Sooooo
0_l0000Eooooo`;o00004?ooool2o`0000?ooooo0_l00008ooooo`;o0000eOooool001kooooo00?o
0000ooooooooool09?ooool2o`0000_ooooo0_l00005ooooo`;o00005Oooool2o`0001Gooooo0_l0
003Oooooo`007_ooool00ol0003oooooooooo`0Tooooo`Co00002Oooool2o`0002Kooooo0_l0003/
ooooo`007_ooool00ol0003oooooooooo`0Vooooo`?o0000<?ooool2o`000>cooooo000Nooooo`03
o`000?oooooooooo02Oooooo0_l0000>ooooo`;o00007Oooool2o`000>oooooo000Nooooo`03o`00
0?oooooooooo03Oooooo0_l0000Mooooo`;o0000koooool001kooooo00?o0000ooooooooool0FOoo
ool2o`00087ooooo0_l0001Yooooo`007_ooool00ol0003oooooooooo`17ooooo`;o00004?ooool2
o`0001[ooooo0_l0001Uooooo`;o0000JOooool001kooooo00?o0000ooooooooool0Aoooool2o`00
00Wooooo0_l00004ooooo`;o00006oooool2o`0003oooooo0_l0001/ooooo`;o00008Oooool001ko
oooo00?o0000ooooooooool08_ooool2o`0000Gooooo0_l0000Wooooo`;o00001?ooool2o`00057o
oooo0_l00009ooooo`;o0000K?ooool2o`00027ooooo000Nooooo`03o`000?oooooooooo02;ooooo
0_l00005ooooo`;o000000?oooooo`000?l00000OOooool2o`0009[ooooo000Nooooo`03o`000?oo
oooooooo02cooooo0_l0000Qooooo`;o0000O?ooool2o`0007Sooooo000Nooooo`03o`000?oooooo
oooo01Wooooo0_l0000:ooooo`;o0000:?ooool2o`0007cooooo0_l0001hooooo`007_ooool00ol0
003oooooooooo`0Iooooo`;o00002_ooool2o`0003oooooo0_l00005ooooo`;o0000Loooool2o`00
06?ooooo000Nooooo`;o00006_ooool2o`0002Kooooo0_l0000Cooooo`;o00003_ooool2o`0000Go
oooo0_l0001cooooo`;o0000Hoooool001kooooo00?o0000ooooooooool04?ooool2o`0002oooooo
0_l0000?ooooo`;o00000_ooool3o`000>kooooo000Nooooo`03o`000?oooooooooo013ooooo0ol0
000oooooo`;o00000oooool2o`000>kooooo000Nooooo`03o`000?oooooooooo017ooooo0_l0000H
ooooo`;o0000^?ooool2o`00063ooooo000Nooooo`03o`000?oooooooooo02_ooooo0_l0000Ioooo
o`;o00004?ooool2o`0008_ooooo0_l0001Pooooo`007_ooool00ol0003oooooooooo`16ooooo`;o
00004?ooool2o`000>gooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l00031ooooo`;o0000
P?ooool001kooooo00?o0000ooooooooool00_ooool2o`000<7ooooo0_l0000eooooo`;o0000BOoo
ool001kooooo00?o0000ooooooooool0:Oooool2o`00043ooooo0_l0002?ooooo`;o00003oooool2
o`0003Sooooo000Nooooo`03o`000?oooooooooo02Wooooo0_l0000aooooo`;o00003Oooool2o`00
0:3ooooo0_l0000hooooo`007_ooool00ol0003oooooooooo`1Looooo`;o0000jOooool001kooooo
00?o0000ooooooooool0G?ooool2o`0001?ooooo0_l0000Zooooo`;o0000Z?ooool001kooooo00?o
0000ooooooooool00_ooool2o`0001Sooooo0_l0000nooooo`;o00004oooool2o`0001Sooooo0_l0
000@ooooo`;o0000@?ooool2o`0006Kooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0000H
ooooo`;o00000oooool2o`0000Cooooo0_l0001Rooooo`;o000000?oooooo`000?l00000Coooool2
o`0006Kooooo000Nooooo`03o`000?oooooooooo027ooooo0_l00004ooooo`;o00003Oooool2o`00
04;ooooo0_l0000Booooo`;o0000]oooool001kooooo00?o0000ooooooooool0<oooool2o`000003
ooooool0003o000002Oooooo0_l00003ooooo`;o00005?ooool2o`0001[ooooo0_l0002_ooooo`00
7_ooool2o`0000_ooooo0_l00002ooooo`;o00008oooool2o`0000;ooooo0ol0000Uooooo`;o0000
00?oooooo`000?l000000_l000000ooooooo0000o`00000]ooooo`;o0000[oooool001kooooo00?o
0000ooooooooool02_ooool2o`0000;ooooo0_l0000Sooooo`;o00000_ooool3o`0002Sooooo0_l0
0003ooooo`;o0000T?ooool2o`0003Wooooo0_l0000Aooooo`007_ooool00ol0003oooooooooo`0T
ooooo`;o00003Oooool2o`0000_ooooo0_l00002ooooo`;o0000/oooool2o`0003Wooooo0_l0000A
ooooo`007_ooool00ol0003oooooooooo`0Kooooo`;o00001oooool2o`0001[ooooo0ol000000ooo
oooo0000o`00002Qooooo`;o00005Oooool2o`0004Oooooo000Nooooo`03o`000?oooooooooo01_o
oooo0_l0000Looooo`;o00001?ooool4o`0002[ooooo0_l0001hooooo`;o00005Oooool2o`0004Oo
oooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0000`ooooo`;o00001?ooool2o`0002cooooo
0_l0003Hooooo`007_ooool00ol0003oooooooooo`07ooooo`;o0000>Oooool2o`0002Sooooo0_l0
003Iooooo`007_ooool00ol0003oooooooooo`11ooooo`?o0000:?ooool2o`000=3ooooo0_l00007
ooooo`007_ooool00ol0003oooooooooo`02ooooo`;o00009?ooool2o`0001Cooooo0_l000000ooo
oooo0000o`000002o`0000Gooooo0_l0003booooo`;o00001oooool001kooooo00?o0000oooooooo
ool00_ooool2o`0000oooooo0_l0000Cooooo`;o00004_ooool4o`0000?ooooo0_l00005ooooo`;o
0000j_ooool2o`0000oooooo000Nooooo`03o`000?oooooooooo01?ooooo0_l0000Wooooo`;o0000
1Oooool2o`0003_ooooo0_l0002Wooooo`;o00002oooool2o`0000oooooo000Nooooo`03o`000?oo
oooooooo02kooooo0_l00005ooooo`;o00001_ooool3o`0000?ooooo0_l0000Sooooo`;o00005_oo
ool2o`0007gooooo0_l0000Xooooo`;o00007?ooool001kooooo00?o0000ooooooooool0:Oooool2
o`0000?ooooo0_l00005ooooo`;o00001_ooool5o`0000?ooooo0_l00004ooooo`?o00006_ooool2
o`0009Gooooo0_l00016ooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o00001oooool2o`00
00Cooooo0ol0000Aooooo`;o000000?oooooo`000?l000000oooool2o`0000Cooooo0ol0003ioooo
o`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000
ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0Fooooo`;o00000_ooool2o`0000?ooooo0_l00000
1?oooooo0000o`000?l00005ooooo`;o00000oooool2o`0001_ooooo0_l00006ooooo`;o0000lOoo
ool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooo
oonHV9So8B4Q00Kooooo00?o0000ooooooooool01Oooool2o`0000oooooo0_l00007ooooo`;o0000
00?oooooo`000?l000002oooool4o`0000Oooooo0_l0000Hooooo`;o0000lOooool000?ooooo00Go
410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`0000Go
oooo0_l00003ooooo`;o00002Oooool2o`0001Gooooo0_l00003ooooo`;o00001oooool2o`0001?o
oooo0_l0000=ooooo`;o0000Z_ooool2o`0003_ooooo0003ooooo`05o`000?ooooooooooooooool0
00002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000ooooooooool02_ooool2o`00
00Wooooo0_l0000Cooooo`Co00008Oooool2o`0000Wooooo0_l00002ooooo`;o00007oooool2o`00
00Gooooo0_l00022ooooo`;o0000>oooool000?ooooo00Go0000ooooooooooooooooo`00000;oooo
o`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`04ooooo`;o00003Oooool5
o`00017ooooo0ol0000Xooooo`;o00001?ooool2o`0002?ooooo0_l00005ooooo`;o0000Z_ooool2
o`0001?ooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj
^[[o410@00Kooooo00?o0000ooooooooool01?ooool4o`0000_ooooo1Ol0000<ooooo`;o00000ooo
ool5o`0002Kooooo0_l0000Jooooo`;o0000`?ooool2o`0001?ooooo0003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0
1_ooool2o`0000cooooo1?l0000<ooooo`;o00001Oooool3o`0001Oooooo0_l0000Yooooo`;o0000
eOooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT01_ooool00ol0003oooooooooo`0Dooooo`Co00000_ooool2o`0000Wooooo0_l00004ooooo`;o
00005oooool3o`0000_ooooo0_l00007ooooo`;o000000?oooooo`000?l00000ioooool001kooooo
00?o0000ooooooooool05?ooool4o`0000;ooooo0_l00009ooooo`;o000000Coooooo`000?l0003o
oooo1?l00003ooooo`;o000000?oooooo`000?l000000_l0000;ooooo`;o00003?ooool2o`0000Oo
oooo0_l000000ooooooo0000o`00000mooooo`;o0000Q?ooool2o`0000_ooooo0_l0000Eooooo`00
7_ooool00ol0003oooooooooo`02ooooo`;o00002_ooool2o`0000Cooooo0ol0000Aooooo`;o0000
0_ooool3o`0000?ooooo0_l000000ooooooo0000o`000002o`0000Wooooo0_l0000;ooooo`;o0000
0_ooool2o`0004Sooooo0_l0000Rooooo`;o0000D_ooool2o`0000cooooo0_l0000;ooooo`;o0000
5Oooool001kooooo00?o0000ooooooooool00_ooool2o`0000[ooooo0_l0000booooo`;o00000ooo
ool2o`0000Kooooo0_l00002ooooo`?o0000Joooool2o`0005;ooooo0_l0000`ooooo`007_ooool0
0ol0003oooooooooo`05ooooo`;o00009oooool2o`0000?ooooo0_l0000<ooooo`;o00001?ooool2
o`0000Kooooo0_l00003ooooo`;o0000lOooool001kooooo00?o0000ooooooooool01Oooool2o`00
02Oooooo0_l00003ooooo`;o00000_ooool2o`0000Sooooo0_l00018ooooo`;o00002_ooool2o`00
00Wooooo0_l0000Hooooo`;o0000ROooool001kooooo00?o0000ooooooooool00_ooool2o`0001Co
oooo0_l0000Mooooo`;o00002?ooool2o`0000;ooooo1?l0000Nooooo`;o00008_ooool2o`0000[o
oooo0_l00009ooooo`;o00006?ooool2o`0008Wooooo000Nooooo`03o`000?oooooooooo00;ooooo
0_l0000Cooooo`?o00005oooool2o`0000gooooo0_l00003ooooo`Co00001_ooool2o`0000Cooooo
0_l00009ooooo`;o00001Oooool2o`0000?ooooo0_l00004ooooo`;o0000[oooool2o`0002;ooooo
000Nooooo`03o`000?oooooooooo01Oooooo1?l0000>ooooo`;o00000oooool2o`000003ooooool0
003o000000Gooooo0ol00005ooooo`;o00003Oooool2o`0000Cooooo0_l00009ooooo`;o00000_oo
ool2o`0000Kooooo0_l00004ooooo`;o00000_ooool2o`0004?ooooo0_l0001Looooo`;o00002?oo
ool2o`0002;ooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l00005ooooo`;o00001oooool2
o`0000?ooooo0_l00002ooooo`;o00001?ooool3o`0000?ooooo0_l00009ooooo`Co00005Oooool4
o`0000Oooooo0_l000000ooooooo0000o`000004ooooo`;o00000oooool2o`0003kooooo0_l0001L
ooooo`;o00008Oooool2o`0000Wooooo000Nooooo`03o`000?oooooooooo01?ooooo0_l0000;oooo
o`;o00004?ooool2o`0000Cooooo0_l00004ooooo`;o00002Oooool5o`000003ooooool0003o0000
00;o00000_ooool2o`0000Gooooo0_l00003ooooo`?o00002Oooool5o`0000Wooooo0_l0001Koooo
o`;o0000E_ooool2o`0000[ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o
00003_ooool2o`0001;ooooo0ol000001?oooooo0000o`000?ooool5o`000003ooooool0003o0000
00Gooooo0ol000000ooooooo0000o`000002o`0000;ooooo0_l000000ooooooo0000o`000004o`00
00?ooooo0_l0000;ooooo`;o00001_ooool2o`00063ooooo0_l0001Fooooo`;o00005Oooool001ko
oooo0_l0000?ooooo`Co00004Oooool2o`000003ooooool0003o000000gooooo1?l00002ooooo`;o
000000?oooooo`000?l000000ol000000ooooooo0000o`000002o`0000?ooooo0ol00005ooooo`;o
00000oooool4o`0000;ooooo0_l0000Fooooo`;o0000EOooool2o`0007Sooooo000Nooooo`03o`00
0?oooooooooo00kooooo1?l0000<ooooo`;o00000oooool2o`000003ooooool0003o000000?ooooo
0_l00005ooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000;o0000
1?ooool2o`0000_ooooo0_l00009ooooo`;o00003Oooool3o`0000Wooooo0_l0000Wooooo`;o0000
0oooool2o`0002Cooooo0_l0001hooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o00003ooo
ool3o`0000_ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l0
0002ooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o00001oooool2o`0000;ooooo0ol0
0002ooooo`?o00003?ooool3o`0000Wooooo0_l0000:ooooo`;o00006oooool2o`0000?ooooo0_l0
002Nooooo`007_ooool01?l0003oooooo`000?l0000;ooooo`;o00003oooool2o`0000;ooooo0_l0
000<ooooo`;o00001Oooool2o`000003ooooool0003o000000;o00000_ooool2o`000003ooooool0
003o000000;o000000?oooooo`000?l000000oooool2o`0000Oooooo1ol00002ooooo`Go00002Ooo
ool3o`0000;ooooo0_l00006ooooo`;o00002_ooool2o`000:oooooo0_l0000?ooooo`007_ooool0
1?l0003oooooo`000?l0000Pooooo`;o00000oooool3o`0000Kooooo0_l00003ooooo`;o00000_oo
ool7o`0000?ooooo1?l000000ooooooo0000o`000005o`0000Wooooo0ol00007ooooo`;o00002Ooo
ool2o`0000?ooooo0_l0000Oooooo`;o0000X_ooool2o`0000oooooo000Nooooo`03o`000?oooooo
oooo01?ooooo0_l0000<ooooo`;o00000oooool3o`0000?ooooo0_l000000ooooooo0000o`000002
o`000003ooooool0003o000000Co000000?oooooo`000?l000000_l00002ooooo`go00002_ooool3
o`0003Oooooo0_l000000ooooooo0000o`00002`ooooo`007_ooool00ol0003oooooooooo`0<oooo
o`;o00001Oooool2o`0000cooooo0_l00009ooooo`?o00000_ooool2o`0000;ooooo2?l00004oooo
o`So00002oooool7o`0000gooooo0_l0000Rooooo`;o00001oooool2o`000;3ooooo000Nooooo`03
o`000?oooooooooo00cooooo0_l00005ooooo`;o00005oooool3o`0000Kooooo2ol00002ooooo`;o
00000_ooool3o`0000Cooooo0_l00005ooooo`Go00000_ooool2o`0000_ooooo0_l0000Looooo`;o
00001?ooool2o`000;Wooooo000Nooooo`03o`000?oooooooooo00cooooo0_l00005ooooo`;o0000
2_ooool2o`0000Wooooo1?l00009ooooo`;o00001?ooool3o`0000;ooooo0_l00002ooooo`;o0000
00?oooooo`000?l000000_ooool5o`0000Kooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o
00000_ooool2o`00027ooooo0_l00004ooooo`;o0000^Oooool001kooooo00?o0000ooooooooool0
4Oooool2o`0000[ooooo1?l00003ooooo`Co00000_ooool4o`0000kooooo1?l000001Ooooooo0000
o`000?l0003ooooo00?o000000?oooooo`000?l000000_l000000ooooooo0000o`000002o`0000Go
oooo0ol000001Ooooooo0000o`000?l0003ooooo00;o00000_ooool4o`0001gooooo0_l00006oooo
o`;o0000[_ooool2o`0000Wooooo000Mooooo`;o00004oooool2o`0000Oooooo0_l000000ooooooo
0000o`000005ooooo`Co00001?ooool2o`0000Gooooo0_l00007ooooo`;o00000oooool3o`000003
ooooool0003o000000Cooooo0_l0000:ooooo`;o00003?ooool2o`000003ooooool0003o000001[o
oooo0_l0002Looooo`;o00005oooool3o`0000Wooooo000Mooooo`;o00005?ooool2o`0000Kooooo
0_l0000Gooooo`;o00001?ooool7o`000003ooooool0003o0000013ooooo0_l00003ooooo`;o0000
0_ooool2o`0000[ooooo0_l00003ooooo`;o00000_ooool2o`000:oooooo0_l0000Gooooo`;o0000
2_ooool001kooooo00?o0000ooooooooool04_ooool2o`0002;ooooo0_l000000ooooooo0000o`00
0008o`0000Cooooo0_l00002ooooo`?o00001?ooool3o`0000?ooooo0ol000000ooooooo0000o`00
0002ooooo`Go00002?ooool2o`0000;ooooo0_l00002ooooo`;o00003oooool2o`00033ooooo0_l0
001Rooooo`;o0000:Oooool001kooooo00?o0000ooooooooool06_ooool2o`0000Wooooo0_l0000?
ooooo`;o00001?ooool5o`000003ooooool0003o000000Go00000_ooool3o`0000Cooooo0ol00002
ooooo`Co00001?ooool6o`00013ooooo0_l0000?ooooo`;o0000<?ooool2o`0006;ooooo0_l0000Y
ooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o00002?ooool2o`0000Wooooo0_l0000:oooo
o`;o00002Oooool3o`0000?ooooo1Ol00003ooooo`;o00001Oooool2o`0000Cooooo1?l00004oooo
o`;o00001oooool4o`0000;ooooo0_l000000ooooooo0000o`00001Yooooo`;o0000JOooool001ko
oooo00?o0000ooooooooool04?ooool2o`0001Sooooo0_l00005ooooo`;o00002?ooool3o`0000_o
oooo0ol000001Ooooooo0000o`000?l0003ooooo00;o00000_ooool6o`0000Kooooo0_l00004oooo
o`Go00000_ooool2o`000003ooooool0003o000004gooooo0_l0000Jooooo`;o00003?ooool2o`00
05_ooooo000Nooooo`;o00007Oooool2o`0000cooooo0_l0000?ooooo`?o00002oooool2o`0000;o
oooo1?l00002ooooo`Go00002Oooool3o`0000?ooooo1?l00003ooooo`;o00000_ooool2o`0004co
oooo0_l0000Xooooo`;o0000;_ooool2o`0000Sooooo0ol0000Pooooo`007_ooool00ol0003ooooo
ooooo`02o`0001[ooooo0_l0000?ooooo`Ko00002Oooool2o`0000Wooooo0ol00005ooooo`Ko0000
1Oooool2o`000003ooooool0003o000000?ooooo0ol00004ooooo`Co00001?ooool3o`0000gooooo
0_l0000<ooooo`;o0000ROooool2o`0000Sooooo0ol0000Pooooo`007_ooool00ol0003ooooooooo
o`02o`0000oooooo0_l0000Jooooo`Ko00000oooool2o`000003ooooool0003o000000;ooooo0_l0
0005ooooo`Ko00000oooool6o`0000Cooooo0_l000000ooooooo0000o`000003o`0000Cooooo0_l0
0006ooooo`;o00001?ooool4o`0000;ooooo0_l00003ooooo`;o00000oooool2o`0000cooooo0_l0
002Jooooo`;o00006_ooool001kooooo00?o0000ooooooooool04Oooool2o`0002?ooooo0_l00000
0ooooooo0000o`000002ooooo`;o00001Oooool6o`0000?ooooo1?l00002ooooo`;o00000_ooool4
o`000003ooooool0003o000000Co00003oooool4o`000004ooooool0003o0000o`0000?ooooo0_l0
002]ooooo`;o00001oooool2o`00017ooooo000Nooooo`03o`000?oooooooooo02Gooooo0_l0000<
ooooo`;o00002Oooool2o`000003ooooool0003o000000Gooooo0_l00005ooooo`;o00000_ooool4
o`0000;ooooo0_l000000ooooooo0000o`000004o`0000Cooooo0_l0000:ooooo`;o00000_ooool2
o`0000;ooooo0_l00004ooooo`;o0000/Oooool3o`00017ooooo000Nooooo`03o`000?oooooooooo
02Gooooo0_l00008ooooo`;o00000_ooool2o`0000Wooooo0_l000000ooooooo0000o`00000:oooo
o`Co00000oooool3o`000004ooooool0003o0000ooooo`?o00001_ooool4o`0000[ooooo0_l00006
ooooo`;o00001?ooool2o`0009_ooooo0_l0000Dooooo`;o00004_ooool001kooooo00?o0000oooo
ooooool0;_ooool3o`0000Cooooo0_l0000Fooooo`;o00001?ooool3o`0000;ooooo0_l000001?oo
oooo0000o`000?ooool2o`0000Cooooo0ol0000Cooooo`;o0000XOooool2o`0002Sooooo000Noooo
o`03o`000?oooooooooo00cooooo0_l0000<ooooo`;o00004_ooool2o`0000Gooooo0_l0000:oooo
o`;o00004?ooool3o`0000Sooooo0_l00007ooooo`;o00001?ooool3o`0000[ooooo0_l0003;oooo
o`007_ooool00ol0003oooooooooo`04ooooo`;o00001_ooool2o`0000cooooo0_l0000?ooooo`;o
00002?ooool2o`0000[ooooo0_l0000Looooo`?o00001Oooool2o`000004ooooool0003o0000oooo
o`?o0000<_ooool2o`0000oooooo0_l0002:ooooo`;o00001_ooool001kooooo00?o0000oooooooo
ool01?ooool2o`0002Gooooo0_l0000=ooooo`Co00001?ooool2o`0001?ooooo0_l00005ooooo`Co
00001_ooool4o`0000;ooooo0_l0000booooo`;o00003oooool2o`0008[ooooo0_l00006ooooo`00
7_ooool00ol0003oooooooooo`06ooooo`;o00008_ooool2o`0000?ooooo0_l00006ooooo`So0000
0oooool2o`0000;ooooo0_l0000;ooooo`;o00000_ooool2o`0000Gooooo1?l00002ooooo`;o0000
0_ooool2o`0000?ooooo0ol0001Tooooo`;o0000LOooool001kooooo00?o0000ooooooooool01_oo
ool2o`00013ooooo0_l0000@ooooo`;o00000oooool2o`0000Gooooo1?l000000ooooooo0000o`00
0002o`0000;ooooo0_l00003ooooo`;o00002oooool2o`0000;ooooo0_l0000:ooooo`?o00001_oo
ool4o`0006Cooooo0_l0001aooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o00005Oooool6
o`000003ooooool0003o000000;o000000?oooooo`000?l000001?ooool2o`0001Cooooo0_l0000:
ooooo`;o00001oooool4o`0001Kooooo0_l0002<ooooo`;o0000<Oooool001kooooo00?o0000oooo
ooooool0;oooool<o`0000Oooooo0_l0000@ooooo`;o00002oooool2o`0000;ooooo0ol00002oooo
o`;o00002_ooool2o`0000kooooo0_l0002<ooooo`;o0000<Oooool001kooooo00?o0000oooooooo
ool01oooool2o`0002;ooooo0_l00002ooooo`Wo000000?oooooo`000?l000001oooool2o`0000So
oooo0_l00006ooooo`;o00002oooool3o`000004ooooool0003o0000o`0000;ooooo0_l0000:oooo
o`;o0000Z_ooool2o`0002?ooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0000Rooooo`;o
000000Coooooo`000?l0003ooooo0ol0000Hooooo`;o00005?ooool2o`0000Kooooo0ol0001Boooo
o`;o00001_ooool2o`0005Wooooo0_l0000Sooooo`007_ooool2o`0000oooooo0_l0000Nooooo`;o
00006?ooool2o`0000Cooooo0_l0000Kooooo`;o0000@oooool2o`0000Kooooo0_l00002ooooo`;o
000000?oooooo`000?l000001_ooool2o`0007kooooo000Nooooo`03o`000?oooooooooo00kooooo
0_l0000`ooooo`;o000000?oooooo`000?l000000oooool2o`0000Cooooo0_l0000Wooooo`;o0000
=oooool2o`0000Kooooo0_l00002ooooo`;o00002_ooool2o`0007gooooo000Nooooo`03o`000?oo
oooooooo02Kooooo0_l0000Hooooo`;o000000?oooooo`000?l000002oooool2o`0001Gooooo0_l0
000>ooooo`?o00002Oooool2o`0000Sooooo1?l0000;ooooo`;o00000_ooool3o`0002Gooooo0_l0
001mooooo`007_ooool00ol0003oooooooooo`0Vooooo`;o00000oooool2o`0000Sooooo0_l0000I
ooooo`;o00000_ooool2o`000003ooooool0003o000000Sooooo0_l00004ooooo`;o00003oooool2
o`0000Wooooo0_l00007ooooo`Oo00002Oooool2o`0000;ooooo0ol0002Tooooo`007_ooool00ol0
003oooooooooo`09ooooo`;o00001Oooool2o`0001Wooooo0_l00008ooooo`;o00003Oooool2o`00
00kooooo0_l000000ooooooo0000o`000003ooooo`;o00000oooool4o`0002Oooooo0_l00003oooo
o`;o0000J_ooool2o`0004Sooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l00005ooooo`;o
0000<_ooool2o`0001Kooooo0_l00005ooooo`;o0000;Oooool2o`0006Wooooo0_l0000Looooo`;o
00001_ooool2o`0002;ooooo000Nooooo`03o`000?oooooooooo04Kooooo0_l00004ooooo`;o0000
5oooool2o`0000Wooooo0_l0000Pooooo`;o0000Qoooool2o`0000Kooooo0_l0000Rooooo`007_oo
ool00ol0003oooooooooo`0_ooooo`;o00005?ooool3o`0000Cooooo0_l0000Gooooo`;o00002Ooo
ool2o`000=Gooooo000Nooooo`03o`000?oooooooooo02oooooo0_l0000Dooooo`;o00009Oooool2
o`000003ooooool0003o00000=Kooooo000Nooooo`03o`000?oooooooooo05Wooooo1ol0000<oooo
o`;o000000Coooooo`000?l0003o00004_ooool2o`000<7ooooo000Nooooo`03o`000?oooooooooo
043ooooo0_l0000Gooooo`So00003oooool2o`0001;ooooo0_l0001Hooooo`;o0000Ioooool001ko
oooo00?o0000ooooooooool05_ooool2o`0000Cooooo0_l0000Cooooo`;o00003Oooool2o`0000So
oooo0_l0000>ooooo`Co000000?oooooo`000?l00000OOooool2o`0006Oooooo000Nooooo`03o`00
0?oooooooooo01Kooooo0_l00004ooooo`;o00004oooool2o`0001Oooooo0_l0000>ooooo`Co0000
1_ooool4o`0004;ooooo0_l0000Rooooo`;o0000Moooool001kooooo00?o0000ooooooooool0??oo
ool2o`0000Wooooo0_l0000Cooooo`;o00001_ooool4o`000003ooooool0003o000003oooooo0_l0
000Rooooo`;o0000Moooool001Cooooo1?l000000ol@413oooooooooo`03ooooo`04o`000?oooooo
ooooooooo`;o0000>Oooool2o`0000Wooooo1?l0000Aooooo`;o00002oooool2o`0002Kooooo0_l0
002Hooooo`;o00006_ooool001Kooooo00?o0000ooooooooool01Oooool01?l0003ooooooooooooo
ool2o`0002Wooooo0_l00009ooooo`;o00003oooool3o`0000oooooo1?l0000Tooooo`;o00003Ooo
ool2o`0009Sooooo0_l00005ooooo`;o00002?ooool2o`0000Wooooo000Fooooo`03o`000?oooooo
oooo00Gooooo0ol0000/ooooo`;o00002Oooool2o`0000oooooo0_l0000@ooooo`Co00009?ooool2
o`0007[ooooo0_l0000booooo`;o00002?ooool2o`0000Wooooo000Fooooo`03o`000?oooooooooo
0?oooooo1oooool2o`0004Oooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo
00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000D
ooooo`03oeEEEOmVIVKo00000?ooooooD_ooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.09614 .79217 Mdot
.31662 .57969 Mdot
.36221 .92557 Mdot
.23541 .81161 Mdot
.24692 .82661 Mdot
.27792 .86714 Mdot
.4089 .35316 Mdot
.18465 .85607 Mdot
.18024 .84061 Mdot
.24121 .07973 Mdot
.31781 .77334 Mdot
.30666 .91768 Mdot
.3296 .92183 Mdot
.92601 .8666 Mdot
.25999 .90658 Mdot
.24325 .85363 Mdot
.33639 .50348 Mdot
.38579 .92474 Mdot
.11602 .78933 Mdot
.16392 .78643 Mdot
.02061 .02776 Mdot
.22143 .9007 Mdot
.30102 .02101 Mdot
.31979 .02226 Mdot
.13468 .81294 Mdot
.15949 .87043 Mdot
.21995 .90694 Mdot
.28812 .67392 Mdot
.35784 .82716 Mdot
.25996 .93021 Mdot
.35822 .89504 Mdot
.25894 .89095 Mdot
.09559 .89755 Mdot
.01991 .14671 Mdot
.18325 .70003 Mdot
.21779 .73619 Mdot
.97952 .83238 Mdot
.1464 .00749 Mdot
.27891 .98437 Mdot
.1801 .86174 Mdot
.33117 .89846 Mdot
.97995 .80284 Mdot
.35252 .04584 Mdot
.80712 .85255 Mdot
.18817 .94224 Mdot
.96929 .83601 Mdot
.65677 .22977 Mdot
.22909 .60617 Mdot
.17164 .76271 Mdot
.21884 .02971 Mdot
.18432 .96044 Mdot
.26219 .63574 Mdot
.26796 .87743 Mdot
.29177 .88681 Mdot
.35071 .93049 Mdot
.13443 .80132 Mdot
.84987 .97702 Mdot
.28347 .88144 Mdot
.22317 .91024 Mdot
.32186 .84362 Mdot
.28469 .90521 Mdot
.15615 .85349 Mdot
.55755 .12562 Mdot
.11529 .80296 Mdot
.2864 .81712 Mdot
.25675 .8412 Mdot
.18258 .66457 Mdot
.21769 .9086 Mdot
.28673 .87227 Mdot
.01464 .84826 Mdot
.78925 .00925 Mdot
.45535 .02671 Mdot
.16479 .89823 Mdot
.21186 .44637 Mdot
.26581 .75718 Mdot
.87058 .98926 Mdot
.18656 .99091 Mdot
.71669 .24261 Mdot
.25199 .89679 Mdot
.45814 .02354 Mdot
.11967 .63535 Mdot
.71516 .53563 Mdot
.45497 .62401 Mdot
.17521 .85682 Mdot
.72613 .94331 Mdot
.88568 .81223 Mdot
.18672 .83158 Mdot
.21143 .88579 Mdot
.2709 .88761 Mdot
.49551 .94975 Mdot
.14357 .79627 Mdot
.95735 .71825 Mdot
.43934 .9948 Mdot
.52225 .89787 Mdot
.02079 .84127 Mdot
.27503 .61953 Mdot
.44369 .05993 Mdot
.16288 .64683 Mdot
.25245 .86422 Mdot
.37705 .85693 Mdot
.18702 .89291 Mdot
.06476 .94003 Mdot
.11603 .90648 Mdot
.17391 .75537 Mdot
.17311 .60881 Mdot
.29829 .01952 Mdot
.08566 .2721 Mdot
.10953 .25681 Mdot
.33194 .73471 Mdot
.08945 .2483 Mdot
.98393 .81735 Mdot
.61706 .18472 Mdot
.17049 .6433 Mdot
.38614 .89644 Mdot
.21415 .2223 Mdot
.2696 .06895 Mdot
.0001 .72502 Mdot
.33103 .95149 Mdot
.9665 .86624 Mdot
.30312 .63628 Mdot
.17907 .8967 Mdot
.24583 .6564 Mdot
.23212 .88115 Mdot
.96452 .06294 Mdot
.32657 .60891 Mdot
.52945 .5223 Mdot
.36774 .88024 Mdot
.10064 .80688 Mdot
.31923 .12071 Mdot
.3054 .6643 Mdot
.07473 .52709 Mdot
.71771 .33402 Mdot
.19083 .31542 Mdot
.29504 .99686 Mdot
.31419 .90727 Mdot
.38344 .93282 Mdot
.3087 .01896 Mdot
.3942 .04392 Mdot
.31644 .84667 Mdot
.2737 .83915 Mdot
.15904 .85053 Mdot
.11871 .80214 Mdot
.13782 .92313 Mdot
.34941 .21665 Mdot
.0573 .82146 Mdot
.32023 .86748 Mdot
.04856 .90522 Mdot
.19871 .90323 Mdot
.17692 .76311 Mdot
.40217 .8406 Mdot
.1263 .86439 Mdot
.11854 .93141 Mdot
.27844 .92127 Mdot
.15295 .78603 Mdot
.25084 .91061 Mdot
.27822 .92188 Mdot
.33488 .07089 Mdot
.10617 .36642 Mdot
.20884 .8516 Mdot
.31825 .70298 Mdot
.3528 .06766 Mdot
.13613 .00713 Mdot
.66469 .31588 Mdot
.24633 .01541 Mdot
.22437 .82956 Mdot
.27797 .87135 Mdot
.19458 .90046 Mdot
.24385 .88951 Mdot
.17028 .31488 Mdot
.29471 .97895 Mdot
.15196 .96409 Mdot
.0783 .71669 Mdot
.1369 .76704 Mdot
.77527 .73169 Mdot
.05009 .78489 Mdot
.23998 .08376 Mdot
.44976 .97875 Mdot
.22361 .86393 Mdot
.38575 .43338 Mdot
.25857 .63922 Mdot
.30137 .06817 Mdot
.37042 .79508 Mdot
.16264 .6946 Mdot
.25246 .99952 Mdot
.15907 .34947 Mdot
.09214 .91524 Mdot
.37572 .56445 Mdot
.16644 .83637 Mdot
.42354 .17046 Mdot
.29514 .10783 Mdot
.06166 .78708 Mdot
.43255 .98135 Mdot
.10329 .81011 Mdot
.32377 .80569 Mdot
.23032 .6199 Mdot
.34176 .02927 Mdot
.15635 .08194 Mdot
.36339 .75811 Mdot
.16104 .83719 Mdot
.18401 .83987 Mdot
.65897 .05378 Mdot
.86757 .56364 Mdot
.30992 .9692 Mdot
.03503 .66714 Mdot
.12972 .81099 Mdot
.21448 .87598 Mdot
.62725 .5288 Mdot
.22174 .924 Mdot
.67562 .93442 Mdot
.25694 .10951 Mdot
.28923 .92722 Mdot
.098 .85815 Mdot
.90431 .19903 Mdot
.18154 .22012 Mdot
.37653 .05528 Mdot
.32061 .43983 Mdot
.19943 .87876 Mdot
.44883 .08202 Mdot
.19155 .91675 Mdot
.00987 .76669 Mdot
.67631 .70994 Mdot
.11509 .81013 Mdot
.14345 .81106 Mdot
.26295 .88821 Mdot
.49475 .94589 Mdot
.37236 .07819 Mdot
.37371 .78328 Mdot
.33996 .00468 Mdot
.38631 .50491 Mdot
.17392 .8944 Mdot
.19459 .89484 Mdot
.3594 .85159 Mdot
.13736 .94012 Mdot
.96176 .24872 Mdot
.342 .54774 Mdot
.60584 .91276 Mdot
.29207 .00928 Mdot
.37087 .92643 Mdot
.07345 .51585 Mdot
.44045 .54553 Mdot
.37768 .8519 Mdot
.14585 .94187 Mdot
.18046 .75133 Mdot
.17668 .02773 Mdot
.21108 .88282 Mdot
.24472 .74374 Mdot
.2518 .8252 Mdot
.16758 .95734 Mdot
.48039 .76689 Mdot
.33027 .92218 Mdot
.29328 .66655 Mdot
.34475 .96173 Mdot
.25766 .54135 Mdot
.88836 .51314 Mdot
.30633 .5069 Mdot
.26559 .62445 Mdot
.25913 .87337 Mdot
.74917 .63908 Mdot
.15364 .6617 Mdot
.58441 .81764 Mdot
.09539 .83515 Mdot
.33426 .89459 Mdot
.28835 .28026 Mdot
.62127 .96387 Mdot
.14046 .93765 Mdot
.71959 .96085 Mdot
.07068 .84959 Mdot
.04076 .51844 Mdot
.34996 .94401 Mdot
.19325 .88713 Mdot
.23846 .85198 Mdot
.30657 .5782 Mdot
.29396 .92783 Mdot
.32381 .91448 Mdot
.06807 .67129 Mdot
.33462 .98088 Mdot
.18402 .87649 Mdot
.34699 .9238 Mdot
.24404 .76673 Mdot
.11541 .92316 Mdot
.80893 .07792 Mdot
.20339 .91694 Mdot
.22938 .01031 Mdot
.94017 .96953 Mdot
.26192 .85841 Mdot
.13673 .80758 Mdot
.31915 .96581 Mdot
.39528 .03285 Mdot
.25117 .91654 Mdot
.26909 .99978 Mdot
.21479 .84739 Mdot
.89007 .01494 Mdot
.15712 .80642 Mdot
.48942 .86501 Mdot
.83756 .67886 Mdot
.28581 .18487 Mdot
.27481 .85838 Mdot
.29986 .6749 Mdot
.55654 .85886 Mdot
.30141 .43728 Mdot
.2523 .63731 Mdot
.26163 .93047 Mdot
.14682 .878 Mdot
.43006 .04298 Mdot
.71082 .69536 Mdot
.35594 .94499 Mdot
.22749 .90485 Mdot
.24373 .91559 Mdot
.05631 .20869 Mdot
.81858 .54735 Mdot
.20386 .91319 Mdot
.81448 .59985 Mdot
.15472 .87272 Mdot
.16026 .83745 Mdot
.17843 .76515 Mdot
.14724 .07541 Mdot
.15694 .99359 Mdot
.90004 .83662 Mdot
.14741 .87897 Mdot
.3616 .19873 Mdot
.2978 .00193 Mdot
.11289 .90988 Mdot
.05395 .88587 Mdot
.23411 .83009 Mdot
.37146 .89145 Mdot
.21615 .90448 Mdot
.23484 .75937 Mdot
.08223 .86836 Mdot
.37716 .96075 Mdot
.17252 .87651 Mdot
.12047 .77836 Mdot
.29141 .8539 Mdot
.44547 .62303 Mdot
.72394 .73847 Mdot
.09703 .50176 Mdot
.19907 .78679 Mdot
.87768 .84291 Mdot
.19512 .90038 Mdot
.12163 .37373 Mdot
.42409 .94429 Mdot
.20405 .82007 Mdot
.18726 .17124 Mdot
.1379 .87908 Mdot
.41525 .99464 Mdot
.2125 .45753 Mdot
.19399 .55294 Mdot
.87359 .08415 Mdot
.1778 .27206 Mdot
.92848 .64667 Mdot
.19065 .85231 Mdot
.33684 .95347 Mdot
.31141 .90827 Mdot
.18911 .88095 Mdot
.33086 .53062 Mdot
.49477 .53777 Mdot
.28714 .92627 Mdot
.04196 .75892 Mdot
.21794 .97673 Mdot
.33758 .89813 Mdot
.39053 .81362 Mdot
.18004 .93571 Mdot
.01357 .92678 Mdot
.34222 .89044 Mdot
.29881 .94793 Mdot
.1668 .84184 Mdot
.22094 .67416 Mdot
.17534 .72101 Mdot
.33228 .19006 Mdot
.0816 .4612 Mdot
.29899 .89722 Mdot
.33592 .02586 Mdot
.23542 .90178 Mdot
.34598 .9477 Mdot
.21652 .84929 Mdot
.49217 .86507 Mdot
.34678 .43991 Mdot
.32029 .10048 Mdot
.18056 .77299 Mdot
.39554 .14003 Mdot
.20176 .9494 Mdot
.25683 .89182 Mdot
.14055 .7579 Mdot
.21878 .09177 Mdot
.05276 .65279 Mdot
.18187 .05662 Mdot
.27957 .78378 Mdot
.44332 .70029 Mdot
.12397 .64808 Mdot
.20431 .90119 Mdot
.41474 .99461 Mdot
.1563 .85236 Mdot
.34444 .88041 Mdot
.19562 .91918 Mdot
.25459 .82701 Mdot
.24261 .81843 Mdot
.5929 .97284 Mdot
.49163 .52625 Mdot
.12497 .9457 Mdot
.22069 .91404 Mdot
.35682 .88303 Mdot
.42941 .97602 Mdot
.06595 .69834 Mdot
.21488 .81856 Mdot
.16168 .85345 Mdot
.34185 .13243 Mdot
.39565 .11751 Mdot
.19139 .93852 Mdot
.48147 .98932 Mdot
.32864 .02536 Mdot
.24902 .0188 Mdot
.38286 .03381 Mdot
.18739 .85291 Mdot
.37218 .05685 Mdot
.63264 .19423 Mdot
.42743 .80074 Mdot
.35026 .95179 Mdot
.2191 .79664 Mdot
.37328 .08818 Mdot
.17838 .57837 Mdot
.24987 .90068 Mdot
.21074 .88787 Mdot
.67466 .75187 Mdot
.90787 .98959 Mdot
.35088 .90059 Mdot
.23614 .875 Mdot
.07662 .36007 Mdot
.72215 .7422 Mdot
.17987 .85297 Mdot
.43462 .99051 Mdot
.51517 .92547 Mdot
.31208 .35936 Mdot
.65884 .16453 Mdot
.25845 .78852 Mdot
.12762 .77567 Mdot
.16035 .39818 Mdot
.01205 .67957 Mdot
.19823 .02543 Mdot
.32917 .57597 Mdot
.15743 .0063 Mdot
.16689 .93429 Mdot
.08917 .83997 Mdot
.90549 .70303 Mdot
.29497 .71481 Mdot
.27967 .92707 Mdot
.40258 .03993 Mdot
.24388 .93392 Mdot
.1215 .88323 Mdot
.29204 .86588 Mdot
.57963 .55553 Mdot
.28664 .80898 Mdot
.44638 .66928 Mdot
.32489 .78405 Mdot
.17635 .80375 Mdot
.25898 .89208 Mdot
.10089 .01281 Mdot
.21091 .91541 Mdot
.15393 .82682 Mdot
.24878 .7722 Mdot
.41695 .1069 Mdot
.48506 .29904 Mdot
.2859 .77773 Mdot
.22308 .91072 Mdot
.25997 .88721 Mdot
.3239 .87706 Mdot
.00132 .2072 Mdot
.14563 .65912 Mdot
.10246 .89891 Mdot
.07535 .75187 Mdot
.27329 .9317 Mdot
.12434 .6786 Mdot
.28629 .90782 Mdot
.16794 .83926 Mdot
.17403 .85607 Mdot
.17519 .85661 Mdot
.3778 .82586 Mdot
.25518 .88988 Mdot
.39749 .8847 Mdot
.21221 .87323 Mdot
.28366 .50401 Mdot
.42828 .88343 Mdot
.89474 .50943 Mdot
.39739 .77368 Mdot
.16092 .92794 Mdot
.18815 .86952 Mdot
.08894 .80045 Mdot
.0504 .82457 Mdot
.01765 .44843 Mdot
.27903 .15424 Mdot
.06874 .7957 Mdot
.27963 .75025 Mdot
.34728 .94922 Mdot
.22994 .87914 Mdot
.41047 .12453 Mdot
.41815 .64555 Mdot
.11035 .78288 Mdot
.36624 .75928 Mdot
.15133 .95205 Mdot
.17554 .83313 Mdot
.987 .93419 Mdot
.1927 .99554 Mdot
.22745 .91178 Mdot
.19715 .69902 Mdot
.12732 .71888 Mdot
.40691 .16413 Mdot
.37021 .94629 Mdot
.99762 .9621 Mdot
.1595 .84656 Mdot
.03015 .73981 Mdot
.16023 .83462 Mdot
.23159 .90839 Mdot
.28217 .88922 Mdot
.52125 .55742 Mdot
.28091 .51024 Mdot
.23854 .57988 Mdot
.23593 .82787 Mdot
.55156 .94049 Mdot
.23975 .08116 Mdot
.27496 .59119 Mdot
.17709 .77886 Mdot
.35256 .8793 Mdot
.20297 .95166 Mdot
.37318 .84508 Mdot
.25484 .89424 Mdot
.21175 .86629 Mdot
.35201 .10387 Mdot
.94547 .85032 Mdot
.42168 .23008 Mdot
.82921 .51672 Mdot
.22097 .87477 Mdot
.50604 .00741 Mdot
.76755 .50871 Mdot
.41956 .99275 Mdot
.25436 .84559 Mdot
.29224 .97073 Mdot
.18102 .86095 Mdot
.19363 .89085 Mdot
.28311 .802 Mdot
.08898 .84406 Mdot
.78759 .05391 Mdot
.68056 .82018 Mdot
.27615 .83917 Mdot
.07138 .52823 Mdot
.33997 .8044 Mdot
.25266 .89794 Mdot
.31819 .87333 Mdot
.42249 .14197 Mdot
.67069 .4628 Mdot
.22608 .86077 Mdot
.25223 .02849 Mdot
.21655 .90169 Mdot
.92037 .02805 Mdot
.44814 .1793 Mdot
.08298 .88163 Mdot
.13259 .16398 Mdot
.14258 .66679 Mdot
.0533 .06547 Mdot
.32474 .16403 Mdot
.18491 .89906 Mdot
.20898 .73765 Mdot
.0009 .19229 Mdot
.2556 .02758 Mdot
.24323 .84581 Mdot
.18285 .96438 Mdot
.30766 .98666 Mdot
.33375 .95723 Mdot
.20308 .75398 Mdot
.33076 .07739 Mdot
.16343 .81167 Mdot
.25099 .56093 Mdot
.27147 .8837 Mdot
.18314 .58138 Mdot
.20192 .7255 Mdot
.25719 .88605 Mdot
.07017 .9037 Mdot
.35773 .88329 Mdot
.13761 .87772 Mdot
.28126 .63604 Mdot
.36158 .82946 Mdot
.35362 .97428 Mdot
.38657 .81243 Mdot
.31908 .09571 Mdot
.02417 .65183 Mdot
.3571 .83962 Mdot
.21403 .8565 Mdot
.51801 .93861 Mdot
.20191 .78375 Mdot
.07551 .89243 Mdot
.16308 .75154 Mdot
.31614 .81352 Mdot
.03609 .86093 Mdot
.22758 .8775 Mdot
.35218 .89672 Mdot
.38562 .00295 Mdot
.15324 .86234 Mdot
.26122 .85644 Mdot
.15264 .87334 Mdot
.19536 .10067 Mdot
.20256 .89047 Mdot
.20232 .75722 Mdot
.21024 .69239 Mdot
.12156 .90872 Mdot
.23283 .8965 Mdot
.34836 .95842 Mdot
.15634 .65275 Mdot
.35403 .27313 Mdot
.23111 .00893 Mdot
.19501 .89653 Mdot
.22536 .92424 Mdot
.52523 .14468 Mdot
.09412 .80846 Mdot
.23543 .15982 Mdot
.98141 .75294 Mdot
.31266 .89899 Mdot
.62517 .78056 Mdot
.10292 .79632 Mdot
.31558 .62182 Mdot
.44125 .01534 Mdot
.77645 .71214 Mdot
.281 .91437 Mdot
.61128 .34508 Mdot
.16186 .04647 Mdot
.17756 .57783 Mdot
.09003 .80305 Mdot
.19375 .44242 Mdot
.10513 .75113 Mdot
.1242 .78533 Mdot
.1329 .87688 Mdot
.90073 .03506 Mdot
.37213 .99127 Mdot
.07941 .81946 Mdot
.36121 .83304 Mdot
.25616 .88542 Mdot
.10768 .84303 Mdot
.51558 .91715 Mdot
.25835 .88425 Mdot
.59471 .90839 Mdot
.18046 .85845 Mdot
.47538 .04786 Mdot
.29185 .84022 Mdot
.26991 .90563 Mdot
.36341 .86833 Mdot
.27294 .87619 Mdot
.0373 .74754 Mdot
.98668 .91331 Mdot
.16842 .25866 Mdot
.17655 .91832 Mdot
.24341 .93075 Mdot
.44192 .09426 Mdot
.17562 .86114 Mdot
.45132 .20268 Mdot
.29847 .16646 Mdot
.2754 .7697 Mdot
.22221 .64759 Mdot
.26637 .88552 Mdot
.59101 .52303 Mdot
.17856 .85909 Mdot
.30801 .87433 Mdot
.16936 .86739 Mdot
.63332 .93025 Mdot
.21613 .91575 Mdot
.36598 .11457 Mdot
.25577 .0199 Mdot
.95531 .72194 Mdot
.15614 .86547 Mdot
.35431 .96609 Mdot
.42177 .09358 Mdot
.24678 .90772 Mdot
.85654 .98987 Mdot
.37552 .69782 Mdot
.17226 .65824 Mdot
.50156 .01865 Mdot
.03558 .51244 Mdot
.06347 .74941 Mdot
.15516 .92577 Mdot
.56767 .10931 Mdot
.15012 .86054 Mdot
.89153 .62028 Mdot
.35125 .89132 Mdot
.98945 .81766 Mdot
.94293 .68602 Mdot
.48329 .46804 Mdot
.34142 .21526 Mdot
.20451 .97109 Mdot
.08879 .7928 Mdot
.26979 .88348 Mdot
.08075 .88551 Mdot
.10383 .92946 Mdot
.15965 .34245 Mdot
.37795 .91213 Mdot
.38666 .89732 Mdot
.29688 .61407 Mdot
.08373 .78113 Mdot
.44469 .20867 Mdot
.07267 .70549 Mdot
.1107 .92239 Mdot
.25152 .0082 Mdot
.26162 .88813 Mdot
.23947 .74696 Mdot
.91999 .46353 Mdot
.05317 .99221 Mdot
.4248 .131 Mdot
.28516 .5535 Mdot
.29156 .9305 Mdot
.28931 .84538 Mdot
.03383 .53755 Mdot
.19645 .88761 Mdot
.69001 .42448 Mdot
.12508 .19704 Mdot
.15993 .82895 Mdot
.12577 .84311 Mdot
.19313 .7151 Mdot
.4452 .92568 Mdot
.05731 .65467 Mdot
.5899 .12689 Mdot
.33927 .01661 Mdot
.98094 .34222 Mdot
.17019 .94341 Mdot
.22911 .82651 Mdot
.05898 .04575 Mdot
.1506 .9587 Mdot
.08567 .87499 Mdot
.19388 .01131 Mdot
.22898 .97322 Mdot
.72325 .1199 Mdot
.18624 .50897 Mdot
.5758 .85222 Mdot
.79674 .74737 Mdot
.16428 .88565 Mdot
.20174 .90243 Mdot
.3869 .01772 Mdot
.18157 .88861 Mdot
.16628 .95498 Mdot
.29206 .93964 Mdot
.23811 .84581 Mdot
.32091 .55219 Mdot
.46542 .98817 Mdot
.54462 .42163 Mdot
.45543 .37563 Mdot
.3185 .94638 Mdot
.4571 .46591 Mdot
.21394 .82199 Mdot
.18428 .78153 Mdot
.04017 .80035 Mdot
.36159 .68818 Mdot
.65359 .06105 Mdot
.35194 .88646 Mdot
.19923 .94284 Mdot
.88299 .01204 Mdot
.30014 .85392 Mdot
.12864 .81124 Mdot
.25952 .86153 Mdot
.3475 .90273 Mdot
.47279 .7658 Mdot
.06789 .87668 Mdot
.24156 .95223 Mdot
.21777 .8353 Mdot
.32455 .94187 Mdot
.03943 .68583 Mdot
.38718 .881 Mdot
.34994 .93492 Mdot
.19994 .87977 Mdot
.18 .85404 Mdot
.2673 .76058 Mdot
.35692 .88411 Mdot
.10568 .77443 Mdot
.28359 .87282 Mdot
.3556 .88514 Mdot
.06336 .96553 Mdot
.36338 .75696 Mdot
.1422 .53167 Mdot
.13611 .79037 Mdot
.11611 .84636 Mdot
.27014 .02285 Mdot
.3444 .96139 Mdot
.90834 .25304 Mdot
.27008 .86667 Mdot
.33213 .95937 Mdot
.35047 .94877 Mdot
.12452 .02113 Mdot
.23599 .85972 Mdot
.22609 .80356 Mdot
.14268 .69753 Mdot
.3039 .33405 Mdot
.38664 .38299 Mdot
.23851 .84449 Mdot
.22219 .9908 Mdot
.37854 .54526 Mdot
.27237 .84081 Mdot
.23456 .88125 Mdot
.25955 .92283 Mdot
.00615 .91455 Mdot
.09292 .4451 Mdot
.16925 .02804 Mdot
.19938 .86729 Mdot
.1451 .08278 Mdot
.30759 .88106 Mdot
.26376 .7443 Mdot
.4596 .60318 Mdot
.18692 .73562 Mdot
.4248 .92859 Mdot
.07066 .64629 Mdot
.23713 .93273 Mdot
.35974 .84164 Mdot
.24086 .62516 Mdot
.39626 .87058 Mdot
.3636 .94389 Mdot
.46478 .10933 Mdot
.44761 .02692 Mdot
.2443 .19417 Mdot
.10327 .84914 Mdot
.38302 .63651 Mdot
.19934 .73019 Mdot
.36272 .86201 Mdot
.21292 .75909 Mdot
.17207 .84867 Mdot
.2444 .89882 Mdot
.45616 .3294 Mdot
.78694 .80492 Mdot
.25522 .9202 Mdot
.50258 .9759 Mdot
.18095 .85908 Mdot
.1996 .87645 Mdot
.31841 .94881 Mdot
.27882 .91897 Mdot
.18015 .83537 Mdot
.26162 .98157 Mdot
.23854 .86935 Mdot
.24666 .86586 Mdot
.94444 .98509 Mdot
.25273 .70174 Mdot
.0537 .70592 Mdot
.42096 .04487 Mdot
.36964 .89302 Mdot
.58334 .02444 Mdot
.00389 .84176 Mdot
.25491 .02577 Mdot
.53444 .56337 Mdot
.16948 .76582 Mdot
.15443 .86202 Mdot
.80059 .35025 Mdot
.99084 .04973 Mdot
.20424 .88302 Mdot
.22794 .90651 Mdot
.21692 .84408 Mdot
.85082 .93213 Mdot
.24667 .23854 Mdot
.94217 .58541 Mdot
.33218 .95825 Mdot
.15105 .86785 Mdot
.34453 .89829 Mdot
.22023 .89367 Mdot
.50233 .93859 Mdot
.31043 .89399 Mdot
.05455 .85535 Mdot
.1731 .88684 Mdot
.38997 .50978 Mdot
.18058 .85708 Mdot
.19848 .07211 Mdot
.38839 .89327 Mdot
.31175 .89174 Mdot
.18483 .86698 Mdot
.27472 .86537 Mdot
.11877 .85556 Mdot
.49337 .73182 Mdot
.15917 .87939 Mdot
.32872 .75875 Mdot
.09014 .78351 Mdot
.20237 .01711 Mdot
.67851 .49904 Mdot
.24019 .89235 Mdot
.84079 .99372 Mdot
.187 .91255 Mdot
.12078 .79883 Mdot
.24458 .7342 Mdot
.05626 .69982 Mdot
.2003 .82174 Mdot
.34242 .38443 Mdot
.58299 .133 Mdot
.1582 .83697 Mdot
.21472 .90329 Mdot
.92702 .88136 Mdot
.29244 .90632 Mdot
.17342 .85478 Mdot
.32709 .8253 Mdot
.38054 .83804 Mdot
.0869 .79291 Mdot
.09275 .85372 Mdot
.5342 .22045 Mdot
.21106 .90728 Mdot
.96052 .85778 Mdot
.03028 .86604 Mdot
.93493 .74369 Mdot
.3681 .95085 Mdot
.18591 .92472 Mdot
.03414 .05337 Mdot
.22445 .87677 Mdot
.60704 .4559 Mdot
.28191 .92393 Mdot
.09874 .77773 Mdot
.28823 .95572 Mdot
.2432 .90086 Mdot
.03771 .86058 Mdot
.57698 .74693 Mdot
.13904 .00328 Mdot
.74344 .74857 Mdot
.20516 .58019 Mdot
.43666 .32209 Mdot
.24229 .96794 Mdot
.20229 .83498 Mdot
.14874 .88923 Mdot
.10981 .96207 Mdot
.16751 .88385 Mdot
.03145 .61036 Mdot
.0884 .84873 Mdot
.37646 .78527 Mdot
.09518 .2478 Mdot
.0243 .89781 Mdot
.15985 .7297 Mdot
.24271 .6314 Mdot
.19767 .84648 Mdot
.8111 .04874 Mdot
.50062 .03847 Mdot
.1472 .89549 Mdot
.1747 .86046 Mdot
.26297 .89852 Mdot
.92554 .97438 Mdot
.3534 .5119 Mdot
.14041 .01693 Mdot
.39545 .80055 Mdot
.62121 .92822 Mdot
.32559 .77382 Mdot
.31455 .00812 Mdot
.22206 .88254 Mdot
.13961 .9379 Mdot
.64782 .29595 Mdot
.12376 .83306 Mdot
.29859 .94639 Mdot
.1622 .96354 Mdot
.24369 .90953 Mdot
.1272 .13785 Mdot
.27446 .90473 Mdot
.27563 .86841 Mdot
.13823 .81106 Mdot
.42085 .02682 Mdot
.43339 .90517 Mdot
.26807 .87688 Mdot
.61586 .81594 Mdot
.04083 .72516 Mdot
.27208 .84266 Mdot
.32688 .44774 Mdot
.30061 .90618 Mdot
.37393 .84018 Mdot
.1928 .74419 Mdot
.04998 .57367 Mdot
.32498 .75344 Mdot
.33608 .95171 Mdot
.6833 .69937 Mdot
.92388 .62947 Mdot
.65592 .10689 Mdot
.2577 .93011 Mdot
.23083 .90897 Mdot
.2582 .89369 Mdot
.25743 .91908 Mdot
.51683 .9111 Mdot
.19677 .88964 Mdot
.68241 .06765 Mdot
.39881 .04102 Mdot
.33121 .10558 Mdot
.57654 .70696 Mdot
.095 .683 Mdot
.20922 .32564 Mdot
.38684 .72849 Mdot
.33101 .97827 Mdot
.39892 .64787 Mdot
.0044 .8516 Mdot
.15794 .8483 Mdot
.31486 .66359 Mdot
.64576 .90474 Mdot
.23743 .90562 Mdot
.19143 .91617 Mdot
.2616 .83807 Mdot
.11249 .8179 Mdot
.50559 .22801 Mdot
.38763 .54957 Mdot
.19279 .93649 Mdot
.307 .76127 Mdot
.35789 .85686 Mdot
.27782 .47982 Mdot
.1984 .61954 Mdot
.20283 .90726 Mdot
.70506 .46187 Mdot
.21925 .79456 Mdot
.18442 .02334 Mdot
.05752 .82074 Mdot
.19809 .88276 Mdot
.15975 .87969 Mdot
.21027 .91511 Mdot
.22675 .11055 Mdot
.24861 .11428 Mdot
.25521 .86394 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`09ooooo`;o00000_ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool2o`0000oo
oooo00?o0000ooooooooool02?ooool2o`0000Cooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo
1_l000000ooooooo0000o`00000=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3?ooool2o`0000_ooooo0_l00002ooooo`03o`000?oooooooooo00Sooooo0_l00004ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03Oooool3o`0000gooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
0_ooool001kooooo00?o0000ooooooooool0:?ooool2o`000003ooooool0003o000000;ooooo0_l0
000Eooooo`?o00001Oooool2o`0000_ooooo0_l00005ooooo`;o00001_ooool2o`0003Cooooo0_l0
001Jooooo`;o0000BOooool001kooooo00?o0000ooooooooool07Oooool2o`0001cooooo0_l00009
ooooo`?o00001Oooool2o`0000_ooooo0_l00005ooooo`;o0000V?ooool2o`0001gooooo0_l0000Z
ooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o00007?ooool2o`0000oooooo0_l0000Loooo
o`;o00007oooool2o`0008kooooo1?l0000Xooooo`007_ooool00ol0003oooooooooo`0Zooooo`;o
00004_ooool2o`0000cooooo0ol0000>ooooo`;o000000?oooooo`000?l000002?ooool2o`0000ko
oooo0_l0000?ooooo`;o00004_ooool2o`0007cooooo0_l0000Xooooo`007_ooool00ol0003ooooo
ooooo`0Tooooo`;o00001?ooool2o`0001;ooooo0_l0000=ooooo`Co00000oooool2o`0000Oooooo
1Ol00002ooooo`;o00005?ooool2o`0002?ooooo0_l0002Vooooo`007_ooool00ol0003ooooooooo
o`0Tooooo`;o00004_ooool2o`0000;ooooo0_l0000Aooooo`;o00000oooool2o`0000Sooooo0_l0
0004ooooo`;o000000?oooooo`000?l000000_l0000Vooooo`;o00009oooool2o`0008_ooooo000N
ooooo`03o`000?oooooooooo00?ooooo0_l0000^ooooo`Co000000?oooooo`000?l000000_ooool2
o`00013ooooo0ol0000Fooooo`Co00006_ooool2o`0000Kooooo0_l000001?oooooo0000o`000?l0
000Wooooo`;o0000Joooool2o`0001kooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0000^
ooooo`Co00003?ooool2o`0000Wooooo0ol0000Jooooo`;o00006?ooool2o`0000Kooooo0_l00000
0ooooooo0000o`00002Eooooo`;o00007_ooool001kooooo00?o0000ooooooooool0@oooool2o`00
02Kooooo0_l0000;ooooo`;o00000_ooool2o`000:?ooooo0_l0000Tooooo`007_ooool00ol0003o
ooooooooo`1hooooo`;o00000_ooool2o`000:?ooooo0_l0000Tooooo`007_ooool00ol0003ooooo
ooooo`1nooooo`?o00007_ooool2o`000:Kooooo000Nooooo`03o`000?oooooooooo07cooooo1Ol0
0007ooooo`;o00005Oooool2o`000:Kooooo000Nooooo`03o`000?oooooooooo00oooooo0_l0000P
ooooo`;o0000>oooool2o`0000cooooo0_l00007ooooo`;o000000?oooooo`000?l00000_Oooool0
01kooooo00?o0000ooooooooool03oooool2o`00023ooooo0_l0000kooooo`;o00005Oooool2o`00
00oooooo0_l0001/ooooo`;o0000>?ooool2o`0000Oooooo000Nooooo`;o00002?ooool2o`0008go
oooo0_l0001/ooooo`;o0000>?ooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo00Oooooo
0_l0000^ooooo`;o0000?Oooool2o`0005[ooooo0_l0000Xooooo`;o0000BOooool001kooooo00?o
0000ooooooooool0=oooool2o`0003cooooo0ol0001Jooooo`;o0000:?ooool2o`0004Wooooo000N
ooooo`03o`000?oooooooooo07Gooooo0_l0000Eooooo`;o0000@_ooool2o`0006?ooooo0_l0000@
ooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o0000OOooool2o`0004;ooooo0_l0001Soooo
o`;o00004?ooool001kooooo00?o0000ooooooooool03Oooool2o`0004Gooooo0_l00008ooooo`;o
00003oooool2o`0006Wooooo0_l0001[ooooo`007_ooool00ol0003oooooooooo`0looooo`;o0000
5_ooool2o`0000Sooooo0_l00009ooooo`;o00001?ooool2o`0006Wooooo0_l0001[ooooo`007_oo
ool00ol0003oooooooooo`0looooo`;o0000:oooool2o`000=cooooo000Nooooo`03o`000?oooooo
oooo02cooooo0_l0000iooooo`;o00003?ooool2o`0008cooooo0_l00012ooooo`007_ooool00ol0
003oooooooooo`0/ooooo`;o00007?ooool2o`0001_ooooo0_l0000<ooooo`;o0000S?ooool2o`00
04;ooooo000Nooooo`03o`000?oooooooooo02_ooooo0_l00002ooooo`;o00006Oooool2o`0004;o
oooo0_l00028ooooo`;o0000;Oooool001kooooo00?o0000ooooooooool0:oooool2o`0000;ooooo
0_l0000Iooooo`;o0000@_ooool2o`0008Sooooo0_l0000]ooooo`007_ooool00ol0003ooooooooo
o`1eooooo`;o0000d?ooool001kooooo00?o0000ooooooooool0@oooool2o`00033ooooo0_l0000>
ooooo`;o0000`?ooool001kooooo00?o0000ooooooooool0@oooool2o`0001oooooo0_l0000Ooooo
o`;o00001Oooool2o`000;Wooooo000Nooooo`03o`000?oooooooooo06Cooooo0_l0000Vooooo`;o
0000^Oooool001kooooo0_l0000looooo`;o00009oooool2o`000>7ooooo000Nooooo`03o`000?oo
oooooooo03_ooooo0_l0000Wooooo`;o00000_ooool2o`0000Cooooo0_l0003Gooooo`007_ooool0
0ol0003oooooooooo`1Looooo`;o00002_ooool2o`0000Cooooo0_l0000Cooooo`;o0000C?ooool2
o`0007Cooooo000Nooooo`03o`000?oooooooooo04Kooooo0_l00007ooooo`;o00002oooool2o`00
02Gooooo0_l0000>ooooo`;o00007oooool2o`0001_ooooo0_l0001dooooo`007_ooool00ol0003o
ooooooooo`16ooooo`;o00001Oooool4o`0002;ooooo0_l0000Nooooo`;o00007oooool2o`00097o
oooo000Nooooo`03o`000?oooooooooo04gooooo0_l0000Tooooo`;o00002?ooool2o`000<Sooooo
000Nooooo`03o`000?oooooooooo06Cooooo0_l0000Gooooo`;o0000J?ooool2o`0005kooooo000N
ooooo`03o`000?oooooooooo06Cooooo0_l00021ooooo`;o0000G_ooool001kooooo00?o0000oooo
ooooool0POooool2o`0002kooooo0_l00009ooooo`;o0000ROooool001kooooo00?o0000oooooooo
ool0POooool2o`0002kooooo0_l00009ooooo`;o0000ROooool001kooooo00?o0000ooooooooool0
Joooool2o`0001Wooooo0_l0000aooooo`;o0000S?ooool001kooooo00?o0000ooooooooool0Jooo
ool2o`0001Wooooo0_l0000aooooo`;o0000S?ooool001kooooo00?o0000ooooooooool09Oooool2
o`000?oooooo8Oooool001kooooo00?o0000ooooooooool09Oooool2o`0005Gooooo0_l00007oooo
o`;o0000`?ooool001kooooo00?o0000ooooooooool0O?ooool2o`0000Oooooo0_l0000Pooooo`;o
0000W_ooool001kooooo00?o0000ooooooooool00_ooool2o`000:?ooooo0_l0002Nooooo`007_oo
ool2o`0000?ooooo0_l0003oooooodCooooo000Nooooo`03o`000?oooooooooo05Oooooo0_l0003^
ooooo`007_ooool00ol0003oooooooooo`1Gooooo`;o0000k_ooool001kooooo00?o0000oooooooo
ool0B?ooool2o`000?gooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l0000Oooooo`;o0000
6oooool2o`0001Wooooo0_l00035ooooo`007_ooool00ol0003oooooooooo`0Wooooo`;o0000=?oo
ool2o`0000Kooooo0_l0000Iooooo`;o0000D?ooool2o`0007?ooooo000Nooooo`03o`000?oooooo
oooo05gooooo0_l0000Wooooo`;o0000B_ooool2o`0007?ooooo000Nooooo`03o`000?oooooooooo
03Wooooo0_l0001;ooooo`;o0000_oooool001kooooo00?o0000ooooooooool0>Oooool2o`000?oo
oooo3Oooool001kooooo00?o0000ooooooooool0S_ooool2o`000;Oooooo000Nooooo`03o`000?oo
oooooooo08kooooo0_l0002gooooo`007_ooool00ol0003oooooooooo`1Iooooo`;o0000JOooool2
o`00087ooooo000Nooooo`03o`000?oooooooooo05Wooooo0_l0001Yooooo`;o0000POooool001ko
oooo00?o0000ooooooooool0J?ooool2o`000=gooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo1Ol00005ooooo`;o0000COooool2o`0001_ooooo0_l0001Pooooo`;o
0000Noooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Gooooo0_l0000Wooooo`;o00009?ooool2o`0007gooooo0_l0001koooo
o`000oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool3o`00
02Gooooo0_l0001:ooooo`;o0000[oooool2o`0002?ooooo0003ooooo`05o`000?oooooooooooooo
ool000003Oooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo077ooooo0_l0000Loooo
o`;o0000TOooool2o`0002?ooooo0003ooooo`05o`000?ooooooooooooooool000003_ooool00omg
MgOoIVIVooooo`04ooooo`;o0000TOooool2o`000;Kooooo0003ooooo`05oa0@4?oooooooooooooo
ool@41003oooool00ol0003oooooooooo`03ooooo`;o00004?ooool2o`0007cooooo0_l0002ioooo
o`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006
ooooo`03o`000?oooooooooo00kooooo0_l0001looooo`;o0000^Oooool000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooooooo
o`1[ooooo`Co0000f?ooool001kooooo00?o0000ooooooooool0Joooool4o`000=Sooooo000Noooo
o`03o`000?oooooooooo03Oooooo0_l00009ooooo`;o0000I_ooool2o`0009_ooooo000Nooooo`03
o`000?oooooooooo03Oooooo0_l00009ooooo`;o0000I_ooool2o`0009_ooooo000Nooooo`03o`00
0?oooooooooo0:3ooooo0_l0002Uooooo`007_ooool00ol0003oooooooooo`25ooooo`;o00006Ooo
ool2o`0002oooooo0_l0001dooooo`007_ooool00ol0003oooooooooo`25ooooo`;o0000B_ooool2
o`0007Cooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0C?ooool2o`000?Wooooo000Nooooo`03o`000?oooooooooo04cooooo0_l0002Gooooo`;o0000
H?ooool001kooooo00?o0000ooooooooool0iOooool2o`00063ooooo000Nooooo`03o`000?oooooo
oooo01Wooooo1?l0003ooooooaWooooo0_l0000@ooooo`007_ooool2o`0001[ooooo1?l0003ooooo
o`Oooooo0_l0000@ooooo`;o00004?ooool001kooooo00?o0000ooooooooool0oooooolTooooo`;o
00008_ooool001kooooo00?o0000ooooooooool07oooool2o`0001;ooooo0_l0003ooooooa?ooooo
000Nooooo`03o`000?oooooooooo01oooooo0_l0000Booooo`;o0000oooooolCooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool06?ooool2o`0001cooooo0_l0003ooooooa3ooooo000Nooooo`03o`00
0?oooooooooo01Sooooo0_l0000Looooo`;o0000=oooool2o`000=Kooooo000Nooooo`03o`000?oo
oooooooo06oooooo0_l0003Fooooo`007_ooool00ol0003oooooooooo`1Jooooo`;o0000joooool0
01kooooo00?o0000ooooooooool0F_ooool2o`000>_ooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0<kooooo0_l0001gooooo`007_ooool00ol0
003oooooooooo`2Jooooo`;o0000<_ooool2o`0007Oooooo000Nooooo`;o0000Voooool2o`000:_o
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
03?ooooo0_l0003ooooooa?ooooo000Nooooo`03o`000?oooooooooo03?ooooo0_l00005ooooo`;o
0000V?ooool2o`00077ooooo000Nooooo`03o`000?oooooooooo03[ooooo0_l0002Hooooo`;o0000
LOooool001kooooo00?o0000ooooooooool0R_ooool2o`000;_ooooo000Nooooo`03o`000?oooooo
oooo043ooooo0_l00018ooooo`;o0000^oooool001kooooo00?o0000ooooooooool0@?ooool2o`00
04kooooo0_l0002eooooo`007_ooool00ol0003oooooooooo`2@ooooo`;o0000]Oooool001kooooo
00?o0000ooooooooool0Goooool2o`0008Cooooo0_l0001Pooooo`007_ooool00ol0003ooooooooo
o`1Oooooo`;o0000Q?ooool2o`00063ooooo000Nooooo`03o`000?oooooooooo033ooooo0_l0003o
ooooo`[ooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0`ooooo`;o0000TOooool2o`00
07Kooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`33ooooo`;o0000P_ooool001kooooo
0_l0000aooooo`;o0000c_ooool2o`0004Gooooo000Nooooo`03o`000?oooooooooo033ooooo0_l0
001?ooooo`;o0000OOooool2o`0004Gooooo000Nooooo`03o`000?oooooooooo087ooooo0_l00034
ooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o0000B_ooool2o`000>Cooooo000Nooooo`03
o`000?oooooooooo01Gooooo0_l0001:ooooo`;o0000i?ooool001kooooo00?o0000ooooooooool0
7_ooool2o`000?oooooo:?ooool001kooooo00?o0000ooooooooool07_ooool2o`000?oooooo:?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`0Soooo
o`;o0000Joooool2o`000;Gooooo000Nooooo`03o`000?oooooooooo02?ooooo0_l0001[ooooo`;o
0000]Oooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`1[ooooo`;o00003Oooool2o`000<_ooooo000Nooooo`03o`000?oooooooooo06_ooooo0_l0000=
ooooo`;o0000boooool001kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0
003oooooooooo`3oooooodSooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0`ooooo`;o0000oooooolFoooo
o`000oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`?o0000<?ooool2o`00
0?oooooo5_ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgooooo
o`0000Oooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo
000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`3oooooodSooooo0003
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000000Oooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0[Oooool2o`00
09Sooooo000Nooooo`03o`000?oooooooooo0:gooooo0_l0000]ooooo`;o0000JOooool001kooooo
00?o0000ooooooooool0g?ooool2o`0006Wooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0NOooool2o`000<cooooo000Nooooo`03o`000?oooooooooo
05kooooo0_l0000Iooooo`;o0000c?ooool001kooooo00?o0000ooooooooool0G_ooool2o`0000Co
oooo0_l00007ooooo`;o0000f?ooool001kooooo00?o0000ooooooooool0>oooool2o`0002Oooooo
0_l00007ooooo`;o0000f?ooool001kooooo00?o0000ooooooooool06_ooool2o`0001oooooo0_l0
0004ooooo`;o0000ooooool5ooooo`007_ooool00ol0003oooooooooo`02ooooo`;o00005_ooool2
o`0002Gooooo0_l0000Sooooo`;o0000goooool001kooooo0_l00003ooooo`;o0000H_ooool2o`00
0=oooooo000Nooooo`03o`000?oooooooooo0<7ooooo0_l00024ooooo`007_ooool00ol0003ooooo
ooooo`11ooooo`;o0000O_ooool2o`0008Cooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l0
000Yooooo`;o0000Toooool2o`0000Wooooo0_l0001Tooooo`007_ooool00ol0003oooooooooo`0F
ooooo`;o0000__ooool2o`0000Wooooo0_l00014ooooo`;o00007_ooool001kooooo00?o0000oooo
ooooool0T?ooool2o`0000Oooooo0_l0002<ooooo`;o00007_ooool001kooooo00?o0000oooooooo
ool0T?ooool2o`0000Oooooo0_l0002/ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0E_ooool2
o`000>oooooo000Nooooo`03o`000?oooooooooo05Kooooo0_l0003_ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0=Sooooo0_l0001]ooooo`007_ooool2o`0001cooooo0_l0002kooooo`;o
0000KOooool001kooooo00?o0000ooooooooool06oooool2o`0003_ooooo0_l0000?ooooo`;o0000
3_ooool2o`000<cooooo000Nooooo`03o`000?oooooooooo05Sooooo0_l00005ooooo`;o00002?oo
ool2o`0000kooooo0_l0001jooooo`;o0000D?ooool001kooooo00?o0000ooooooooool0>?ooool2
o`0001gooooo0_l00006ooooo`;o00003_ooool2o`0000[ooooo0_l0001hooooo`;o0000:?ooool2
o`0002Kooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0000_ooooo`;o00007Oooool2o`00
01Kooooo0_l0000:ooooo`;o0000X?ooool4o`0002Kooooo000Nooooo`03o`000?oooooooooo00Oo
oooo0_l0000;ooooo`;o0000loooool2o`0001;ooooo0_l0000Xooooo`007_ooool00ol0003ooooo
ooooo`09ooooo`;o00002Oooool2o`000??ooooo0_l0000looooo`007_ooool00ol0003ooooooooo
o`09ooooo`;o0000WOooool2o`0001;ooooo0_l00029ooooo`007_ooool00ol0003oooooooooo`0D
ooooo`;o0000Q_ooool2o`0000[ooooo0_l0000Booooo`;o0000ROooool001kooooo00?o0000oooo
ooooool04oooool3o`0008Kooooo0_l0000Zooooo`;o0000OOooool001kooooo00?o0000oooooooo
ool04oooool2o`0001Gooooo0_l0000kooooo`;o0000Goooool2o`0007gooooo000Nooooo`03o`00
0?oooooooooo02[ooooo0_l0000kooooo`;o0000Noooool2o`00067ooooo000Nooooo`03o`000?oo
oooooooo00Oooooo0_l0002Dooooo`;o0000AOooool2o`00067ooooo000Nooooo`03o`000?oooooo
oooo00Oooooo0_l00017ooooo`;o0000Boooool2o`000:Sooooo000Nooooo`03o`000?oooooooooo
053ooooo0_l0000Uooooo`;o00004_ooool2o`000;[ooooo000Nooooo`03o`000?oooooooooo06_o
oooo0_l0000:ooooo`;o00004_ooool2o`0007Wooooo0_l0000oooooo`007_ooool2o`0006cooooo
0_l0000=ooooo`;o0000R_ooool2o`0003oooooo000Nooooo`03o`000?oooooooooo03_ooooo0_l0
000Looooo`;o00002Oooool2o`0001Cooooo0_l0003;ooooo`007_ooool00ol0003oooooooooo`0k
ooooo`;o00007?ooool2o`0000Wooooo0_l0000oooooo`;o00004Oooool2o`0008gooooo000Noooo
o`03o`000?oooooooooo04gooooo0_l0001Fooooo`;o00004Oooool2o`0008gooooo000Nooooo`03
o`000?oooooooooo04gooooo0_l0001Kooooo`;o0000J_ooool2o`0002oooooo000Nooooo`03o`00
0?oooooooooo07Kooooo0_l0000booooo`;o0000J_ooool2o`0002oooooo000Nooooo`03o`000?oo
oooooooo07Kooooo0_l0003?ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo00cooooo0_l0001Iooooo`;o0000g_ooool001kooooo00?o0000oooooooo
ool03?ooool2o`0002Sooooo0_l0000Xooooo`;o00001Oooool2o`000=kooooo000Nooooo`03o`00
0?oooooooooo03Kooooo0ol00006ooooo`;o00002?ooool2o`0001Gooooo0_l000000ooooooo0000
o`00003Rooooo`007_ooool00ol0003oooooooooo`0gooooo`;o00001_ooool2o`0000Sooooo0_l0
000Hooooo`;o0000bOooool2o`0001Oooooo000Nooooo`03o`000?oooooooooo0?oooooo;oooool2
o`0001Oooooo000Nooooo`03o`000?oooooooooo05Gooooo0_l0003`ooooo`000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool0
0ol0003oooooooooo`1Eooooo`;o0000l?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0oooo
oom8ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooooooooooo
o`000006ooooo`?o0000ooooool6ooooo`;o0000@?ooool000?ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2Aooooo`;o
0000L_ooool2o`00043ooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003o
EEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0A_ooool2o`0004Wooooo0_l0002doooo
o`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0
003oooooooooo`06ooooo`;o0000;?ooool2o`00013ooooo0_l0000Nooooo`;o0000goooool000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000oooo
ooooool01_ooool2o`0002cooooo0_l0000`ooooo`;o0000goooool000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0G?ooool2
o`000>Wooooo000Nooooo`03o`000?oooooooooo03cooooo0_l0000Gooooo`;o00001Oooool2o`00
0>Wooooo000Nooooo`03o`000?oooooooooo03cooooo0_l00009ooooo`;o00003?ooool2o`0000_o
oooo0_l0002jooooo`;o00009oooool001kooooo00?o0000ooooooooool0Aoooool2o`000003oooo
ool0003o000000Kooooo0_l0000>ooooo`;o0000:Oooool2o`000003ooooool0003o000008cooooo
0_l0000Wooooo`007_ooool00ol0003oooooooooo`1:ooooo`;o00001_ooool2o`0003Wooooo0_l0
00000ooooooo0000o`00002eooooo`007_ooool00ol0003oooooooooo`1;ooooo`;o0000foooool2
o`0001gooooo000Nooooo`03o`000?oooooooooo04_ooooo0_l0003Kooooo`;o00007Oooool001ko
oooo00?o0000ooooooooool08oooool2o`0002Wooooo0_l000000ooooooo0000o`000004ooooo`;o
00001Oooool2o`0001Sooooo0_l0003=ooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o0000
:Oooool5o`0000Cooooo0_l00005ooooo`;o00006?ooool2o`0007Gooooo0_l0001Fooooo`007_oo
ool00ol0003oooooooooo`0cooooo`;o00006oooool2o`0009gooooo0_l0001Fooooo`007_ooool0
0ol0003oooooooooo`0Cooooo`;o00007?ooool4o`0004oooooo0_l0002Tooooo`;o00006oooool0
01kooooo00?o0000ooooooooool04oooool2o`0000oooooo0_l0000;ooooo`;o00004Oooool2o`00
03Sooooo0_l00004ooooo`;o0000Y?ooool2o`0001_ooooo000Nooooo`;o00001Oooool2o`0000Oo
oooo0_l0000Eooooo`;o00002Oooool2o`0001?ooooo0_l0000hooooo`;o0000aoooool001kooooo
00?o0000ooooooooool01?ooool2o`0000Oooooo1?l0000Nooooo`;o00006oooool2o`000?Wooooo
000Nooooo`03o`000?oooooooooo00oooooo0_l0000Jooooo`;o00001oooool2o`0001Kooooo0_l0
003iooooo`007_ooool00ol0003oooooooooo`0[ooooo`;o000000?oooooo`000?l000001?ooool2
o`000?oooooo4_ooool001kooooo00?o0000ooooooooool0;_ooool2o`0000Oooooo0_l0000Voooo
o`;o000000?oooooo`000?l00000hoooool001kooooo00?o0000ooooooooool01oooool2o`00027o
oooo0_l0000;ooooo`;o00008_ooool2o`0000;ooooo0_l000000ooooooo0000o`00003Sooooo`00
7_ooool00ol0003oooooooooo`07ooooo`;o00002Oooool2o`0001Kooooo0_l0000_ooooo`;o0000
<?ooool2o`000;Sooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0000`ooooo`;o00005?oo
ool2o`000003ooooool0003o000002kooooo0_l0002hooooo`007_ooool00ol0003oooooooooo`14
ooooo`;o00005?ooool2o`000003ooooool0003o00000>Sooooo000Nooooo`03o`000?oooooooooo
00;o00008_ooool2o`000>Kooooo0_l0000iooooo`007_ooool00ol0003oooooooooo`02o`0001Wo
oooo0_l00007ooooo`;o0000i_ooool2o`0003Wooooo000Nooooo`03o`000?oooooooooo00Wooooo
0_l0000@ooooo`;o0000oooooolBooooo`;o00005oooool001kooooo00?o0000ooooooooool02Ooo
ool2o`0006Kooooo0_l0002kooooo`;o00005oooool001kooooo00?o0000ooooooooool0@?ooool2
o`0002oooooo0_l0003Dooooo`007_ooool00ol0003oooooooooo`0aooooo`;o00003Oooool2o`00
0:7ooooo0_l0001Rooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o00005oooool2o`0000Go
oooo0_l00009ooooo`;o0000>?ooool2o`0006;ooooo0_l00007ooooo`;o0000H_ooool001kooooo
0_l0000?ooooo`;o000000?oooooo`000?l000005oooool2o`0000_ooooo0_l00003ooooo`;o0000
4?ooool2o`0002Kooooo0_l0000Dooooo`;o0000C?ooool2o`0006_ooooo000Nooooo`03o`000?oo
oooooooo00kooooo0_l00004ooooo`;o00008Oooool2o`0001Gooooo0_l0000Cooooo`;o00009ooo
ool2o`0009Cooooo0_l0000Sooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o00001Oooool2
o`0004gooooo0_l0001Booooo`;o0000JOooool2o`0002?ooooo000Nooooo`03o`000?oooooooooo
00gooooo0_l0002Xooooo`;o00007oooool2o`0006gooooo000Nooooo`03o`000?oooooooooo05co
oooo0_l0001jooooo`;o00007_ooool2o`0004gooooo000Nooooo`03o`000?oooooooooo01Gooooo
0_l0000Tooooo`;o00007oooool2o`0009[ooooo0_l0001=ooooo`007_ooool00ol0003ooooooooo
o`0Eooooo`;o00003_ooool2o`0000kooooo0_l00004ooooo`;o0000m_ooool2o`0001;ooooo000N
ooooo`03o`000?oooooooooo02Gooooo0_l0000>ooooo`;o0000noooool3o`0001;ooooo000Moooo
o`;o00002oooool2o`0003?ooooo0_l0003booooo`;o00004oooool001gooooo0_l0000;ooooo`;o
00009Oooool2o`0000_ooooo0ol0000jooooo`;o0000boooool001kooooo00?o0000ooooooooool0
<?ooool2o`0000_ooooo0_l0000kooooo`;o00008?ooool2o`0005[ooooo0_l0001=ooooo`007_oo
ool00ol0003oooooooooo`0iooooo`;o00002?ooool2o`0000Kooooo0_l0000Kooooo`;o0000<_oo
ool2o`0005[ooooo0_l0001=ooooo`007_ooool00ol0003oooooooooo`0iooooo`;o00001Oooool2
o`000003ooooool0003o000000Kooooo0_l0000Kooooo`;o0000OOooool2o`0005kooooo000Noooo
o`03o`000?oooooooooo00Kooooo0_l0000hooooo`;o0000YOooool2o`0005kooooo000Nooooo`03
o`000?oooooooooo00Kooooo0_l0000cooooo`;o00003_ooool2o`0000Gooooo0_l0002Cooooo`;o
0000@oooool2o`0001Wooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0000aooooo`;o0000
3Oooool3o`0000Gooooo0_l0001Sooooo`;o0000=Oooool2o`0000oooooo0_l0000[ooooo`;o0000
6Oooool001kooooo0_l00009ooooo`;o00001oooool2o`000003ooooool0003o000000Sooooo0_l0
000Aooooo`;o00001?ooool2o`00017ooooo0_l0000;ooooo`;o0000G_ooool2o`0001kooooo0_l0
000Eooooo`;o00003oooool2o`0004Kooooo000Nooooo`03o`000?oooooooooo017ooooo0_l00000
0ooooooo0000o`000008ooooo`;o00004Oooool2o`0000Cooooo0_l00005ooooo`;o00005oooool2
o`0000gooooo0_l0001_ooooo`;o0000H_ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo
02[ooooo0_l00008ooooo`;o00002?ooool2o`0001;ooooo0_l0000Booooo`;o00002_ooool2o`00
0<Oooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o00007_ooool2o`0000So
oooo0_l00008ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Sooooo0ol0000Booooo`;o
00002Oooool3o`000=;ooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0000Xooooo`?o0000
2_ooool2o`0000Gooooo0_l00009ooooo`;o00002oooool2o`0000Gooooo0_l00009ooooo`?o0000
d_ooool001kooooo00Co0000ooooool0003o00009oooool2o`0000Wooooo1Ol0000Cooooo`;o0000
4oooool2o`0003Cooooo1?l0002]ooooo`007_ooool01?l0003oooooo`000?l0000Wooooo`;o0000
2Oooool2o`000003ooooool0003o000001?ooooo0_l00008ooooo`;o0000?oooool4o`000:gooooo
000Nooooo`03o`000?oooooooooo03Oooooo0_l0000Dooooo`;o00001_ooool2o`0000cooooo0_l0
003Rooooo`007_ooool00ol0003oooooooooo`0Nooooo`;o00001Oooool2o`00013ooooo0_l0000D
ooooo`;o00005?ooool2o`000003ooooool0003o000001Gooooo0_l00038ooooo`007_ooool00ol0
003oooooooooo`0Looooo`Co00000oooool4o`0000kooooo0_l0000Rooooo`;o00002oooool2o`00
01Gooooo0_l00038ooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o00000oooool2o`0000Go
oooo0_l0000@ooooo`;o000000?oooooo`000?l000007oooool2o`0006cooooo0_l0001nooooo`00
7_ooool00ol0003oooooooooo`0<ooooo`;o00002Oooool4o`0000Gooooo0_l00002ooooo`;o0000
4_ooool2o`0000Cooooo0_l0000Gooooo`;o00003Oooool2o`0000gooooo0ol0001?ooooo`;o0000
O_ooool001kooooo00?o0000ooooooooool03?ooool2o`0000;ooooo0_l00007ooooo`;o00001Ooo
ool2o`0000;ooooo0_l00008ooooo`;o000000?oooooo`000?l000002_ooool3o`00013ooooo0_l0
0005ooooo`;o00003Oooool2o`0000gooooo0ol0003?ooooo`007_ooool00ol0003oooooooooo`0@
ooooo`;o00004?ooool2o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l000002_ooool2
o`00017ooooo0_l0003eooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0Hooooo`Go00001Ooo
ool2o`0000Cooooo0_l0000Iooooo`;o0000ooooool3ooooo`000oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`0Booooo`;o00001?ooool7o`0000cooooo0_l0000Fooooo`;o0000;oooool2o`000=7ooooo
0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Ko
oooo0ol00009ooooo`;o00001oooool2o`0000Gooooo0_l00002ooooo`;o00001?ooool2o`0000Ko
oooo0_l0000Fooooo`;o0000;oooool2o`0000Kooooo0_l00009ooooo`;o0000__ooool000?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool00ol0
003oooooooooo`09ooooo`;o00003_ooool2o`0000Kooooo1?l00003ooooo`;o00002oooool2o`00
00kooooo0_l0000Aooooo`;o00008_ooool2o`0000Wooooo0_l0002aooooo`;o00002oooool000?o
oooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool0
0ol0003oooooooooo`0Iooooo`;o00000_ooool2o`0000;ooooo0ol00004ooooo`;o00001Oooool2
o`0000Cooooo0_l0000>ooooo`;o00004Oooool2o`0000_ooooo0_l00003ooooo`;o0000T?ooool2
o`0003cooooo0_l0000;ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@
okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo01[ooooo0_l000000ooooooo0000o`00
0002ooooo`;o00001Oooool2o`0000Gooooo0_l0000Xooooo`;o00002_ooool2o`0000?ooooo0_l0
002@ooooo`;o0000BOooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj
^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`0Jooooo`;o000000?oooooo`000?l00000
0_ooool2o`0000?ooooo1ol00004ooooo`;o00005Oooool2o`0000oooooo0_l0000Oooooo`;o0000
X?ooool2o`0002Wooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@
o`000?l@413oZJVY00Kooooo00?o0000ooooooooool09_ooool7o`0000Cooooo0_l0000Eooooo`;o
00006Oooool2o`0001Gooooo0ol00017ooooo`;o0000E_ooool2o`0002Wooooo000Nooooo`03o`00
0?oooooooooo01Kooooo0_l00008ooooo`;o00008?ooool2o`0000Oooooo0_l0000<ooooo`;o0000
2?ooool2o`0001Kooooo0_l0000mooooo`;o00002?ooool2o`0007Kooooo1?l00007ooooo`007_oo
ool00ol0003oooooooooo`0?ooooo`;o00001Oooool2o`0000Sooooo0_l0000Kooooo`?o000000Co
ooooo`000?l0003o00001oooool2o`0000cooooo0_l0001Oooooo`;o00007Oooool2o`00067ooooo
1?l00007ooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o000000?oooooo`000?l00000;?oo
ool3o`000003ooooool0003o000000_ooooo0_l0000Fooooo`;o0000LOooool2o`0006cooooo000N
ooooo`03o`000?oooooooooo00cooooo0_l0000Pooooo`;o00005_ooool2o`000004ooooool0003o
0000ooooo`Go00005Oooool2o`0000Sooooo0_l00005ooooo`;o0000c_ooool001kooooo00?o0000
ooooooooool0;_ooool4o`0000Oooooo0_l0000:ooooo`Ko000000Coooooo`000?l0003ooooo0_l0
000Oooooo`?o00001?ooool2o`000<kooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l0000:
ooooo`;o00000oooool2o`0000;ooooo0_l0000:ooooo`;o000000?oooooo`000?l000009oooool2
o`000<Oooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`0Kooooo`;o00001oooool2o`00
00Wooooo1Ol000001?oooooo0000o`000?l00006ooooo`;o00000oooool2o`0002cooooo0_l00005
ooooo`;o0000Yoooool2o`0001Cooooo0_l000000ooooooo0000o`00000;ooooo`007_ooool00ol0
003oooooooooo`0Iooooo`Co00004_ooool5o`0000;ooooo1?l00004ooooo`;o00000oooool2o`00
00cooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l0000Cooooo`;o00000oooool2o`00
0003ooooool0003o000000Gooooo0_l0002Pooooo`;o00005?ooool2o`0000kooooo000Nooooo`;o
00001?ooool2o`0001Cooooo0_l00004ooooo`;o00001?ooool2o`0000_ooooo0_l00002ooooo`Co
00002?ooool2o`0000_ooooo1?l000000ooooooo0000o`000002o`0000?ooooo0_l00008ooooo`;o
00002Oooool3o`0000;ooooo0_l00008ooooo`;o0000V?ooool2o`0002cooooo000Nooooo`;o0000
1?ooool2o`0001Cooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l00009ooooo`Co
00002?ooool2o`0000Cooooo0_l00005ooooo`Co00000_ooool2o`0000?ooooo0_l00004ooooo`;o
00001oooool4o`0000[ooooo0_l00002ooooo`;o0000X_ooool2o`0002cooooo000Nooooo`04o`00
0?ooooooooooooooo`;o00004?ooool2o`0000Cooooo0_l00002ooooo`;o00000oooool2o`0000_o
oooo0ol00002ooooo`;o00001_ooool2o`0000Cooooo0_l00005ooooo`Co00000_ooool2o`0000Wo
oooo0_l00007ooooo`;o00004?ooool2o`000;Sooooo0_l0000Fooooo`007_ooool2o`0000;ooooo
0_l0000@ooooo`;o00001?ooool2o`0000;ooooo0_l0000@ooooo`?o00000_ooool4o`000004oooo
ool0003o0000o`0000Cooooo1?l00005ooooo`;o00009_ooool2o`0000Cooooo0_l0000nooooo`;o
0000BOooool2o`0002_ooooo0_l0000Fooooo`007_ooool2o`0000oooooo0_l0000:ooooo`;o0000
1_ooool2o`0000_ooooo0ol00002ooooo`So00001?ooool3o`0000Kooooo1?l00004ooooo`;o0000
2?ooool4o`0001;ooooo0_l00004ooooo`;o0000?_ooool2o`0004Wooooo0_l00013ooooo`007_oo
ool00ol0003oooooooooo`0>ooooo`;o00002_ooool4o`0000Cooooo0_l0000;ooooo`?o00000_oo
ool6o`0000Oooooo0_l00008ooooo`;o00001?ooool2o`0000;ooooo0_l00004ooooo`Co00004Ooo
ool2o`0000Cooooo0_l0000iooooo`;o0000POooool2o`00017ooooo000Nooooo`03o`000?oooooo
oooo00Sooooo0_l0000Booooo`;o00003oooool3o`0000Gooooo1?l0000<ooooo`;o00000_ooool2
o`0000Gooooo0ol00002ooooo`;o00006Oooool4o`0000;ooooo0_l0000iooooo`;o0000POooool2
o`00017ooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0000Kooooo`;o00001_ooool4o`00
00Cooooo1?l0000<ooooo`;o00000_ooool2o`0000?ooooo1?l00003ooooo`;o00006oooool2o`00
02Oooooo0ol0002Yooooo`007_ooool00ol0003oooooooooo`06ooooo`;o00003oooool2o`0000co
oooo0_l00006ooooo`Co00000_ooool2o`0000?ooooo0_l00003ooooo`;o00000_ooool2o`0000;o
oooo0_l00005ooooo`Go00000oooool4o`0000?ooooo0_l00007ooooo`;o00003?ooool2o`0002Oo
oooo0ol0002;ooooo`;o00002oooool2o`0000oooooo000Nooooo`03o`000?oooooooooo00Kooooo
0_l0000?ooooo`;o00005?ooool2o`000004ooooool0003o0000ooooo`;o00000oooool3o`0000;o
oooo0_l00002ooooo`;o00001_ooool2o`000003ooooool0003o000000Kooooo1?l00003ooooo`;o
00001oooool2o`0000cooooo0_l00009ooooo`;o0000Z_ooool2o`0000_ooooo0_l0000?ooooo`00
7_ooool00ol0003oooooooooo`0^ooooo`Co00001oooool2o`0000Kooooo0_l000000ooooooo0000
o`000003ooooo`;o00001Oooool2o`0000Cooooo1Ol00005ooooo`;o000000?oooooo`000?l00000
6?ooool2o`000<Sooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l00004ooooo`;o00003Ooo
ool4o`000003ooooool0003o000000;o00001?ooool2o`0000;ooooo0_l00003ooooo`;o00000_oo
ool7o`000003ooooool0003o000000Gooooo0_l000000ooooooo0000o`000002o`000004ooooool0
003o0000o`0000Gooooo0_l000000ooooooo0000o`000002o`000>3ooooo000Nooooo`03o`000?oo
oooooooo01;ooooo0_l00004ooooo`;o00003Oooool4o`000003ooooool0003o000000;ooooo0_l0
0002ooooo`;o00000_ooool3o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000001?l0
0008ooooo`Co00002Oooool2o`0000?ooooo0_l00005ooooo`;o000000?oooooo`000?l000000_oo
ool2o`0000Gooooo0_l0003;ooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o00002_ooool2
o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`Co00001Oooool2o`000003ooooool0003o
000000;o000000Coooooo`000?l0003ooooo0_l000001?oooooo0000o`000?l0000:ooooo`;o0000
0_ooool2o`0000Kooooo0_l0000:ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000Go
oooo0_l0000;ooooo`;o0000X?ooool2o`0001cooooo000Nooooo`03o`000?oooooooooo00gooooo
0_l00007ooooo`?o00002_ooool2o`0000cooooo1Ol00005ooooo`Go000000Coooooo`000?l0003o
oooo0_l000001?oooooo0000o`000?l00005ooooo`Oo00000_ooool2o`000003ooooool0003o0000
017ooooo1?l0000;ooooo`;o00002?ooool2o`000:3ooooo0_l0000Looooo`007_ooool00ol0003o
ooooooooo`0=ooooo`;o00001oooool2o`0001Cooooo0_l00003ooooo`;o000000Coooooo`000?l0
003ooooo0_l00002ooooo`?o00000_ooool3o`0000Sooooo0_l00002ooooo`Oo00000_ooool2o`00
0003ooooool0003o0000017ooooo0ol0000<ooooo`;o0000b?ooool001kooooo00?o0000oooooooo
ool05?ooool2o`0001Kooooo0_l00009ooooo`_o00002?ooool3o`0000;ooooo1?l000000ooooooo
0000o`000002ooooo`;o00001oooool2o`0000Sooooo0_l000000ooooooo0000o`000004ooooo`?o
00000oooool2o`000<_ooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0000Fooooo`;o0000
1_ooool2o`0000?ooooo1?l000000ooooooo0000o`000003ooooo`;o00001Oooool2o`0000?ooooo
0ol0000?ooooo`;o00001_ooool4o`000003ooooool0003o000000;o00000_ooool3o`0000;ooooo
0ol0003;ooooo`007_ooool00ol0003oooooooooo`04ooooo`;o00005Oooool4o`0000gooooo0_l0
0003ooooo`;o000000?oooooo`000?l000001?l000000ooooooo0000o`000006ooooo`;o00000ooo
ool2o`000004ooooool0003o0000ooooo`Go00002_ooool2o`0000;ooooo0ol00004ooooo`[o0000
1oooool3o`0002[ooooo0_l0002Oooooo`007_ooool2o`0000Gooooo0_l0000Eooooo`Co00004_oo
ool2o`0000?ooooo1?l000000ooooooo0000o`000003o`0000;ooooo1?l00002ooooo`;o000000?o
ooooo`000?l000000ol000000ooooooo0000o`00000:ooooo`;o00000oooool2o`0000Cooooo2?l0
000:ooooo`;o0000:_ooool2o`0009oooooo000Nooooo`03o`000?oooooooooo00cooooo0_l00005
ooooo`;o00009_ooool5o`0000;ooooo3Ol00005ooooo`?o000000?oooooo`000?l000004oooool3
o`0001Wooooo0_l00013ooooo`;o0000Moooool001kooooo00?o0000ooooooooool03?ooool2o`00
00Gooooo0_l0000=ooooo`?o00005oooool9o`000003ooooool0003o000000?o000000?oooooo`00
0?l000000_ooool2o`0000;ooooo0ol000000ooooooo0000o`000003o`000004ooooool0003o0000
ooooo`?o00002Oooool2o`0001[ooooo0_l0000booooo`;o00003oooool2o`0007Oooooo000Noooo
o`03o`000?oooooooooo027ooooo1?l0000Iooooo`Co000000?oooooo`000?l000001?l00002oooo
o`Co000000?oooooo`000?l000001oooool4o`000004ooooool0003o0000ooooo`?o0000@?ooool2
o`0001Oooooo0_l00028ooooo`007_ooool3o`00027ooooo0_l0000Fooooo`;o00000oooool2o`00
00Cooooo1Ol00002ooooo`Co00002?ooool2o`0000cooooo0_l0000@ooooo`;o0000:oooool2o`00
01_ooooo0_l0001jooooo`;o00002?ooool001kooooo0ol0000Jooooo`;o00007Oooool3o`0000;o
oooo2?l00005ooooo`;o000000?oooooo`000?l000001oooool2o`0000Oooooo0_l00003ooooo`;o
00004?ooool2o`0002_ooooo0_l0000Kooooo`;o0000N_ooool2o`0000Sooooo000Nooooo`03o`00
0?oooooooooo01[ooooo0_l0000Iooooo`;o00000oooool3o`000003ooooool0003o000000Co0000
1oooool2o`000003ooooool0003o000000;o00001Oooool2o`0000Oooooo0_l00012ooooo`;o0000
XOooool001kooooo00?o0000ooooooooool08?ooool3o`0000Kooooo0_l0000:ooooo`;o00001?oo
ool2o`0000Oooooo0_l00009ooooo`?o00001?ooool4o`0000gooooo0_l00004ooooo`;o0000f?oo
ool001kooooo00?o0000ooooooooool00_l0000Nooooo`?o00001_ooool2o`0000?ooooo0_l00008
ooooo`;o00002_ooool3o`0000Wooooo0_l00004ooooo`Ko00002oooool2o`0000Cooooo0_l00003
ooooo`Co00000oooool2o`0001;ooooo0_l0000Dooooo`;o0000X_ooool001kooooo00?o0000oooo
ooooool00_l0000Looooo`;o00003_ooool4o`0000Kooooo0_l0000;ooooo`;o00002Oooool2o`00
00Gooooo1_l0000Eooooo`Co00000oooool2o`0000_ooooo0_l00005ooooo`;o00005?ooool2o`00
027ooooo0_l00002ooooo`;o0000Noooool001kooooo00?o0000ooooooooool07_ooool2o`0000;o
oooo0_l0000<ooooo`;o00005oooool4o`0000?ooooo0ol00002ooooo`;o00001?ooool2o`00017o
oooo0_l00009ooooo`;o00002oooool2o`0003kooooo0_l00002ooooo`;o0000A?ooool2o`0003Go
oooo000Nooooo`03o`000?oooooooooo02;ooooo0_l0000>ooooo`;o00000_ooool2o`00017ooooo
1?l00004ooooo`;o00000_ooool2o`0000Cooooo0_l0000Aooooo`;o00002Oooool2o`0005gooooo
0_l0000fooooo`;o0000:oooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo02Wooooo0ol0
0006ooooo`;o00000_ooool2o`0000;ooooo0ol0000>ooooo`;o00008Oooool2o`0002oooooo0_l0
0003ooooo`;o0000<_ooool2o`0006?ooooo0_l00008ooooo`007_ooool00ol0003oooooooooo`0A
ooooo`;o00005_ooool4o`0000cooooo1?l0000Nooooo`;o00002?ooool2o`0003Sooooo0_l00003
ooooo`;o00002Oooool2o`0009Kooooo000Nooooo`03o`000?oooooooooo017ooooo0_l0000Boooo
o`;o00000_ooool4o`0000Kooooo0_l00004ooooo`;o00000_ooool2o`0001cooooo0_l00008oooo
o`;o00001oooool6o`0001;ooooo0_l0000Wooooo`;o0000=oooool2o`0005gooooo000Nooooo`03
o`000?oooooooooo02Gooooo0_l0000<ooooo`;o00002?ooool2o`0001kooooo0_l00004ooooo`;o
00001oooool:o`00013ooooo0_l0000Eooooo`;o0000BOooool2o`0005gooooo000Nooooo`;o0000
?_ooool3o`0001gooooo0_l00004ooooo`;o00000oooool3o`000003ooooool0003o000000;o0000
1?ooool2o`0002Oooooo0_l0002Xooooo`007_ooool00ol0003oooooooooo`0]ooooo`;o00003_oo
ool3o`0000[ooooo0_l0000Gooooo`;o00000oooool3o`0000;ooooo0ol00004ooooo`;o00009ooo
ool2o`000:Sooooo000Nooooo`03o`000?oooooooooo02gooooo0_l00003ooooo`;o00005_ooool2
o`0000kooooo0_l0000<ooooo`?o0000g?ooool001kooooo00?o0000ooooooooool0;Oooool2o`00
00?ooooo0_l00004ooooo`;o00008?ooool2o`0000cooooo0_l00003ooooo`;o00002?ooool2o`00
06gooooo0_l0001Oooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o00002oooool2o`0000;o
oooo0_l00005ooooo`;o0000;_ooool2o`0000;ooooo0ol00008ooooo`;o0000COooool2o`0001ko
oooo0_l0001Hooooo`;o00001Oooool001kooooo00?o0000ooooooooool04?ooool2o`0000kooooo
0_l0000;ooooo`;o00000_ooool2o`0000Cooooo0_l0000[ooooo`;o00001_ooool2o`000003oooo
ool0003o000005Gooooo0_l0001hooooo`;o00001Oooool001kooooo00?o0000ooooooooool04?oo
ool2o`0002Gooooo0_l0000Booooo`;o00005?ooool2o`000003ooooool0003o000000Wooooo0_l0
002mooooo`;o00005oooool001kooooo00?o0000ooooooooool0?_ooool2o`0000Kooooo0_l00003
ooooo`;o00003_ooool2o`0000Cooooo0_l0001Jooooo`;o0000Koooool2o`0001Oooooo000Noooo
o`03o`000?oooooooooo03kooooo0_l00006ooooo`;o00004oooool2o`0001;ooooo0_l0000Foooo
o`;o00005_ooool2o`0001cooooo0_l0001Zooooo`;o00007?ooool001kooooo00?o0000oooooooo
ool0@oooool2o`0001Oooooo0_l00009ooooo`;o00001_ooool2o`0001Kooooo0_l00005ooooo`;o
00003oooool2o`0006oooooo0_l0000Gooooo`;o00007?ooool001kooooo00?o0000ooooooooool0
@oooool2o`0000cooooo0_l00009ooooo`;o00002Oooool4o`0001kooooo0_l00003ooooo`;o0000
P?ooool2o`0003Gooooo000Nooooo`03o`000?oooooooooo057ooooo0_l00004ooooo`;o00004?oo
ool2o`0001kooooo0_l0002Tooooo`;o00005_ooool001kooooo00?o0000ooooooooool0Eoooool2
o`0000Oooooo0_l0000aooooo`;o0000V_ooool2o`0001Kooooo000Nooooo`03o`000?oooooooooo
03Wooooo0_l00009ooooo`;o00006_ooool2o`0001?ooooo0_l0000Booooo`;o00002?ooool2o`00
00?ooooo0_l0001hooooo`;o00000oooool2o`0000[ooooo0_l0000Rooooo`005?ooool4o`000003
oa0@4?oooooooooo00?ooooo00?o0000ooooooooool03Oooool2o`00023ooooo0_l00008ooooo`;o
00002Oooool2o`0002oooooo0_l0000<ooooo`?o00000oooool4o`0000_ooooo0_l0001cooooo`;o
00000oooool2o`0000?ooooo0_l0000:ooooo`;o00008_ooool001Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0=ooooo`;o00008?ooool2o`0000[ooooo0_l0000Oooooo`;o0000
9Oooool3o`0000Gooooo0_l00020ooooo`;o0000>?ooool001Kooooo00?o0000ooooooooool01Ooo
ool3o`0003_ooooo0_l0000Aooooo`;o00000oooool2o`0000Oooooo0_l0003Yooooo`005_ooool0
0ol0003oooooooooo`1Fooooo`;o00000oooool2o`000?;ooooo000Fooooo`03o`000?oooooooooo
0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003ooooo
ooooo`3ooooooe3ooooo000Dooooo`03oeEEEOmVIVKo00000?ooooooD_ooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.14387 .79892 Mdot
.3638 .61398 Mdot
.3399 .94887 Mdot
.25609 .86497 Mdot
.1942 .80061 Mdot
.25639 .87981 Mdot
.35403 .32736 Mdot
.1463 .8558 Mdot
.2215 .85566 Mdot
.2245 .21767 Mdot
.26602 .73958 Mdot
.33236 .82463 Mdot
.27829 .91197 Mdot
.87779 .85036 Mdot
.23394 .89155 Mdot
.30009 .72165 Mdot
.40452 .60329 Mdot
.39991 .9152 Mdot
.16747 .81007 Mdot
.19942 .81136 Mdot
.11644 .97178 Mdot
.25833 .86359 Mdot
.29877 .02198 Mdot
.37569 .91079 Mdot
.15316 .84128 Mdot
.11725 .87169 Mdot
.24843 .91694 Mdot
.26147 .77139 Mdot
.32146 .76592 Mdot
.29795 .9221 Mdot
.3754 .91251 Mdot
.23414 .88019 Mdot
.08637 .90931 Mdot
.09707 .1809 Mdot
.22999 .64649 Mdot
.1937 .73435 Mdot
.04463 .82147 Mdot
.29931 .98398 Mdot
.33206 .90253 Mdot
.19539 .90914 Mdot
.35821 .92441 Mdot
.98528 .75301 Mdot
.35176 .07114 Mdot
.89089 .80808 Mdot
.10553 .82347 Mdot
.98588 .7942 Mdot
.6369 .22153 Mdot
.23679 .63984 Mdot
.13828 .78744 Mdot
.30018 .09359 Mdot
.29974 .95536 Mdot
.311 .66686 Mdot
.19251 .85932 Mdot
.26118 .79641 Mdot
.29492 .90914 Mdot
.24321 .70368 Mdot
.83077 .98087 Mdot
.21296 .87092 Mdot
.25021 .91664 Mdot
.19299 .84373 Mdot
.26568 .93935 Mdot
.1409 .85062 Mdot
.47904 .12328 Mdot
.12373 .80949 Mdot
.2482 .84389 Mdot
.28343 .8304 Mdot
.24203 .69985 Mdot
.24648 .91816 Mdot
.25692 .87237 Mdot
.15947 .86283 Mdot
.7709 .95837 Mdot
.45411 .98909 Mdot
.05339 .9316 Mdot
.2174 .50483 Mdot
.2131 .80009 Mdot
.84845 .00545 Mdot
.23442 .02287 Mdot
.72258 .20679 Mdot
.25675 .8935 Mdot
.43123 .0383 Mdot
.12766 .65341 Mdot
.71267 .45132 Mdot
.444 .52227 Mdot
.14722 .85103 Mdot
.82432 .93626 Mdot
.88024 .72798 Mdot
.13761 .83303 Mdot
.21931 .93724 Mdot
.23778 .8796 Mdot
.46676 .93929 Mdot
.12365 .75502 Mdot
.98433 .64422 Mdot
.44637 .93244 Mdot
.57171 .8372 Mdot
.99024 .84477 Mdot
.29242 .62184 Mdot
.41872 .14308 Mdot
.1968 .60101 Mdot
.19017 .80794 Mdot
.3564 .98931 Mdot
.19451 .87689 Mdot
.15322 .95717 Mdot
.04377 .92166 Mdot
.23972 .85887 Mdot
.24024 .6489 Mdot
.29602 .00603 Mdot
.12118 .24387 Mdot
.14621 .21935 Mdot
.35658 .8218 Mdot
.16809 .24971 Mdot
.05439 .82319 Mdot
.66828 .22497 Mdot
.13328 .6763 Mdot
.39387 .89198 Mdot
.1613 .17009 Mdot
.21247 .92903 Mdot
.9861 .66819 Mdot
.29353 .93732 Mdot
.04106 .94941 Mdot
.26722 .64288 Mdot
.20473 .92939 Mdot
.26972 .73119 Mdot
.17178 .94472 Mdot
.04081 .08335 Mdot
.23269 .6535 Mdot
.51057 .49464 Mdot
.44599 .86677 Mdot
.15682 .8202 Mdot
.42293 .0928 Mdot
.23117 .72132 Mdot
.12281 .51105 Mdot
.72666 .31674 Mdot
.21158 .40438 Mdot
.33179 .98821 Mdot
.36227 .9111 Mdot
.42291 .94669 Mdot
.30696 .00442 Mdot
.44337 .05414 Mdot
.36038 .85909 Mdot
.28698 .85072 Mdot
.23602 .85288 Mdot
.11275 .79809 Mdot
.16548 .89578 Mdot
.32806 .23419 Mdot
.92585 .83945 Mdot
.33726 .78144 Mdot
.07681 .90571 Mdot
.21652 .90863 Mdot
.04342 .81274 Mdot
.44067 .70592 Mdot
.10695 .78915 Mdot
.12201 .94052 Mdot
.31377 .82923 Mdot
.18559 .81156 Mdot
.23985 .89631 Mdot
.2215 .89627 Mdot
.36479 .05511 Mdot
.04976 .36583 Mdot
.24402 .88239 Mdot
.34843 .61384 Mdot
.4035 .0886 Mdot
.131 .89365 Mdot
.64871 .35094 Mdot
.27187 .02746 Mdot
.1687 .78901 Mdot
.21665 .83273 Mdot
.20399 .91572 Mdot
.2636 .91576 Mdot
.10521 .33824 Mdot
.29953 .9252 Mdot
.1471 .96855 Mdot
.04344 .68684 Mdot
.18574 .68497 Mdot
.76054 .68436 Mdot
.05458 .77244 Mdot
.27035 .02654 Mdot
.46653 .8773 Mdot
.15329 .88639 Mdot
.32312 .41963 Mdot
.31044 .6632 Mdot
.29551 .03693 Mdot
.32362 .76018 Mdot
.14847 .67425 Mdot
.14402 .90003 Mdot
.18459 .34331 Mdot
.17608 .95753 Mdot
.37689 .55352 Mdot
.1375 .77413 Mdot
.39913 .14237 Mdot
.23401 .06303 Mdot
.08528 .78617 Mdot
.50948 .88554 Mdot
.1615 .82137 Mdot
.41757 .84978 Mdot
.18278 .59882 Mdot
.30305 .01781 Mdot
.14366 .99374 Mdot
.35442 .77251 Mdot
.20311 .84772 Mdot
.13851 .90791 Mdot
.64039 .08369 Mdot
.82664 .55427 Mdot
.35285 .968 Mdot
.03606 .60701 Mdot
.14709 .83554 Mdot
.22086 .93195 Mdot
.6394 .50024 Mdot
.23632 .94271 Mdot
.71469 .91182 Mdot
.26946 .06636 Mdot
.27107 .86321 Mdot
.16484 .84867 Mdot
.95636 .21985 Mdot
.22095 .27037 Mdot
.42338 .0692 Mdot
.33259 .42534 Mdot
.20397 .91817 Mdot
.42033 .99918 Mdot
.18269 .03562 Mdot
.99788 .69519 Mdot
.70541 .73441 Mdot
.02959 .8136 Mdot
.11429 .78892 Mdot
.27288 .9086 Mdot
.44857 .92966 Mdot
.39452 .04229 Mdot
.27632 .85144 Mdot
.34683 .03329 Mdot
.37133 .52511 Mdot
.21383 .86176 Mdot
.15339 .87426 Mdot
.24095 .84485 Mdot
.14575 .92702 Mdot
.98467 .25308 Mdot
.37837 .51779 Mdot
.63874 .87349 Mdot
.41713 .07708 Mdot
.36327 .94031 Mdot
.15124 .54829 Mdot
.5141 .5844 Mdot
.34554 .82422 Mdot
.16118 .9185 Mdot
.23144 .85167 Mdot
.20338 .99548 Mdot
.28583 .81864 Mdot
.20443 .82103 Mdot
.14646 .78751 Mdot
.18897 .94234 Mdot
.39413 .86273 Mdot
.3506 .95408 Mdot
.34038 .71721 Mdot
.30793 .93028 Mdot
.1882 .61037 Mdot
.91894 .47784 Mdot
.23264 .49281 Mdot
.2623 .68786 Mdot
.18874 .84693 Mdot
.75526 .6547 Mdot
.19261 .6962 Mdot
.62295 .78815 Mdot
.15795 .83354 Mdot
.35412 .85924 Mdot
.28113 .2267 Mdot
.56365 .99189 Mdot
.15444 .91736 Mdot
.74579 .02221 Mdot
.10953 .92369 Mdot
.12262 .52256 Mdot
.33118 .94874 Mdot
.22194 .91884 Mdot
.17778 .80123 Mdot
.40413 .63201 Mdot
.27744 .937 Mdot
.34494 .8795 Mdot
.06604 .67342 Mdot
.31219 .94653 Mdot
.20228 .00214 Mdot
.2206 .00973 Mdot
.20554 .73142 Mdot
.218 .95814 Mdot
.78913 .08692 Mdot
.24077 .88195 Mdot
.23715 .04735 Mdot
.94994 .93318 Mdot
.19787 .82555 Mdot
.11249 .79039 Mdot
.3272 .9225 Mdot
.3598 .12858 Mdot
.22419 .02583 Mdot
.34945 .02127 Mdot
.25481 .96379 Mdot
.81049 .02341 Mdot
.21424 .8433 Mdot
.46896 .90451 Mdot
.89886 .64281 Mdot
.23504 .21696 Mdot
.22084 .8802 Mdot
.26514 .76219 Mdot
.44685 .86912 Mdot
.24236 .3697 Mdot
.3347 .71843 Mdot
.19167 .87391 Mdot
.17375 .75519 Mdot
.4155 .98064 Mdot
.69686 .63776 Mdot
.33364 .03239 Mdot
.25359 .91414 Mdot
.25056 .9088 Mdot
.09496 .25898 Mdot
.775 .54336 Mdot
.22774 .9397 Mdot
.78934 .581 Mdot
.12076 .87196 Mdot
.07764 .78438 Mdot
.16351 .78749 Mdot
.12694 .07476 Mdot
.20496 .88944 Mdot
.80386 .85425 Mdot
.08366 .888 Mdot
.30223 .27004 Mdot
.35115 .93262 Mdot
.10188 .93707 Mdot
.13086 .93263 Mdot
.24486 .7282 Mdot
.39511 .89404 Mdot
.16871 .88056 Mdot
.19623 .73165 Mdot
.13952 .85506 Mdot
.40911 .88972 Mdot
.14528 .85867 Mdot
.14445 .77148 Mdot
.26968 .86252 Mdot
.39787 .69977 Mdot
.65254 .72373 Mdot
.11708 .58288 Mdot
.20906 .95778 Mdot
.8429 .78175 Mdot
.22797 .92045 Mdot
.15706 .37932 Mdot
.27594 .89388 Mdot
.15404 .7878 Mdot
.2361 .21833 Mdot
.21521 .8618 Mdot
.382 .92647 Mdot
.2754 .48942 Mdot
.14504 .55691 Mdot
.9563 .08305 Mdot
.14753 .30866 Mdot
.94212 .67954 Mdot
.14661 .85595 Mdot
.30785 .94788 Mdot
.2432 .87519 Mdot
.16176 .76323 Mdot
.35825 .505 Mdot
.48962 .46821 Mdot
.26777 .94323 Mdot
.08284 .72754 Mdot
.24415 .02621 Mdot
.2805 .88924 Mdot
.27539 .7773 Mdot
.21185 .90583 Mdot
.00866 .89284 Mdot
.36871 .91021 Mdot
.28141 .88409 Mdot
.1277 .80235 Mdot
.25884 .71392 Mdot
.26726 .6638 Mdot
.33026 .24477 Mdot
.05691 .40233 Mdot
.3026 .8815 Mdot
.40381 .07065 Mdot
.25682 .91362 Mdot
.3364 .96745 Mdot
.25599 .8363 Mdot
.56704 .87704 Mdot
.39275 .45834 Mdot
.23364 .02307 Mdot
.16318 .81675 Mdot
.31008 .06675 Mdot
.24231 .94851 Mdot
.25572 .8919 Mdot
.15871 .75373 Mdot
.31835 .14631 Mdot
.08893 .56428 Mdot
.16628 .12195 Mdot
.37086 .85199 Mdot
.49324 .741 Mdot
.20516 .76959 Mdot
.23625 .91889 Mdot
.38286 .01366 Mdot
.23355 .8533 Mdot
.30501 .84266 Mdot
.17358 .90981 Mdot
.19527 .81815 Mdot
.1903 .80366 Mdot
.59645 .91654 Mdot
.52917 .60804 Mdot
.98062 .9486 Mdot
.24795 .92078 Mdot
.38227 .89104 Mdot
.43843 .01848 Mdot
.03458 .63238 Mdot
.13863 .68339 Mdot
.14533 .84912 Mdot
.41106 .1277 Mdot
.41669 .02531 Mdot
.27787 .0048 Mdot
.46271 .96179 Mdot
.32334 .9255 Mdot
.2734 .02621 Mdot
.44798 .05937 Mdot
.22083 .88794 Mdot
.4217 .07395 Mdot
.62068 .21576 Mdot
.53213 .76913 Mdot
.36122 .92763 Mdot
.12372 .87683 Mdot
.40106 .0628 Mdot
.11711 .56139 Mdot
.25559 .8942 Mdot
.23559 .92088 Mdot
.65497 .83445 Mdot
.972 .0309 Mdot
.32014 .86364 Mdot
.17577 .86473 Mdot
.11916 .41831 Mdot
.73764 .79082 Mdot
.2254 .8449 Mdot
.41025 .93704 Mdot
.58021 .87234 Mdot
.36784 .38869 Mdot
.63345 .13486 Mdot
.15776 .91137 Mdot
.15119 .76122 Mdot
.21 .33904 Mdot
.95262 .72672 Mdot
.20817 .10004 Mdot
.29038 .51663 Mdot
.18185 .02827 Mdot
.0935 .81636 Mdot
.12079 .92543 Mdot
.9613 .80376 Mdot
.19731 .85185 Mdot
.25767 .94348 Mdot
.3707 .95928 Mdot
.23698 .94171 Mdot
.0906 .91909 Mdot
.25151 .81444 Mdot
.50868 .57334 Mdot
.25448 .91087 Mdot
.4659 .74841 Mdot
.34281 .89231 Mdot
.13582 .78314 Mdot
.26226 .90013 Mdot
.07384 .0216 Mdot
.23554 .93437 Mdot
.18382 .8542 Mdot
.21463 .73082 Mdot
.49831 .05807 Mdot
.47867 .27292 Mdot
.30707 .79713 Mdot
.23293 .94881 Mdot
.25532 .89475 Mdot
.2545 .8981 Mdot
.04124 .21854 Mdot
.18017 .5952 Mdot
.09179 .92044 Mdot
.00111 .66818 Mdot
.24801 .92939 Mdot
.13757 .69383 Mdot
.30221 .89075 Mdot
.13097 .84394 Mdot
.14487 .85415 Mdot
.14614 .85269 Mdot
.35733 .83199 Mdot
.2403 .88236 Mdot
.36526 .8583 Mdot
.16307 .85894 Mdot
.34275 .55432 Mdot
.39217 .89698 Mdot
.84875 .51731 Mdot
.46007 .76954 Mdot
.18956 .8961 Mdot
.26876 .86127 Mdot
.13675 .8069 Mdot
.96965 .90347 Mdot
.02362 .42277 Mdot
.27354 .02634 Mdot
.01488 .75155 Mdot
.25816 .8699 Mdot
.34383 .9653 Mdot
.256 .9112 Mdot
.38071 .02579 Mdot
.46247 .66725 Mdot
.09765 .77156 Mdot
.35673 .78093 Mdot
.0928 .92666 Mdot
.11084 .88411 Mdot
.09639 .95546 Mdot
.23008 .87826 Mdot
.14573 .96667 Mdot
.14583 .7962 Mdot
.082 .67335 Mdot
.44362 .16095 Mdot
.37927 .92297 Mdot
.94659 .9246 Mdot
.12998 .84959 Mdot
.95495 .83099 Mdot
.19178 .8658 Mdot
.28469 .91577 Mdot
.34593 .88112 Mdot
.57806 .54331 Mdot
.29343 .42516 Mdot
.2588 .64561 Mdot
.17967 .80944 Mdot
.62475 .92141 Mdot
.25225 .06358 Mdot
.29434 .56514 Mdot
.15643 .94629 Mdot
.38671 .87788 Mdot
.24529 .00404 Mdot
.33407 .86326 Mdot
.25691 .89335 Mdot
.16043 .9301 Mdot
.34491 .17468 Mdot
.05491 .88126 Mdot
.411 .21327 Mdot
.80336 .5717 Mdot
.14959 .78788 Mdot
.54285 .93477 Mdot
.77419 .53914 Mdot
.28192 .93799 Mdot
.19345 .81485 Mdot
.37325 .90627 Mdot
.15064 .85038 Mdot
.21087 .87492 Mdot
.25494 .83327 Mdot
.08759 .8292 Mdot
.83292 .09911 Mdot
.67734 .79711 Mdot
.2869 .85096 Mdot
.12669 .49505 Mdot
.33476 .74571 Mdot
.24276 .88707 Mdot
.34352 .90525 Mdot
.39839 .20505 Mdot
.62778 .46493 Mdot
.24995 .94477 Mdot
.2657 .03228 Mdot
.17096 .87526 Mdot
.01245 .03199 Mdot
.37593 .17722 Mdot
.07825 .87804 Mdot
.22093 .19552 Mdot
.17162 .72589 Mdot
.96382 .12304 Mdot
.31766 .04335 Mdot
.21686 .92177 Mdot
.19466 .72579 Mdot
.08135 .16895 Mdot
.27476 .02156 Mdot
.15079 .87216 Mdot
.34797 .95333 Mdot
.24862 .08746 Mdot
.33992 .91808 Mdot
.16176 .75771 Mdot
.38633 .10753 Mdot
.12843 .78675 Mdot
.13712 .50823 Mdot
.23993 .87915 Mdot
.11222 .60444 Mdot
.24455 .83685 Mdot
.23894 .88162 Mdot
.11683 .88945 Mdot
.31581 .85485 Mdot
.17918 .85977 Mdot
.21124 .57632 Mdot
.32301 .77024 Mdot
.32447 .94852 Mdot
.33127 .86432 Mdot
.22745 .96964 Mdot
.12477 .67845 Mdot
.34624 .79954 Mdot
.28981 .8649 Mdot
.40432 .97651 Mdot
.19562 .84289 Mdot
.13691 .95564 Mdot
.13584 .62183 Mdot
.32052 .93839 Mdot
.99951 .87792 Mdot
.17196 .86365 Mdot
.28749 .88404 Mdot
.36447 .91869 Mdot
.10711 .91657 Mdot
.32125 .78163 Mdot
.1285 .86797 Mdot
.21386 .08735 Mdot
.16361 .86406 Mdot
.18711 .79443 Mdot
.19175 .74174 Mdot
.15337 .89054 Mdot
.25357 .91792 Mdot
.34073 .97534 Mdot
.19031 .59772 Mdot
.31176 .26328 Mdot
.252 .03426 Mdot
.21876 .92252 Mdot
.26173 .89478 Mdot
.51677 .16419 Mdot
.14807 .81496 Mdot
.1708 .10105 Mdot
.02615 .65749 Mdot
.29449 .8897 Mdot
.64614 .739 Mdot
.15728 .80446 Mdot
.32481 .54009 Mdot
.43599 .9748 Mdot
.842 .72159 Mdot
.21933 .84896 Mdot
.58833 .30013 Mdot
.08124 .10141 Mdot
.11575 .58946 Mdot
.13966 .81167 Mdot
.24771 .41157 Mdot
.09453 .65315 Mdot
.12776 .88546 Mdot
.23718 .74521 Mdot
.82149 .01245 Mdot
.36018 .98952 Mdot
.16796 .82257 Mdot
.38363 .82403 Mdot
.27267 .90888 Mdot
.02558 .85919 Mdot
.42248 .94363 Mdot
.23899 .88218 Mdot
.52398 .82849 Mdot
.14799 .85222 Mdot
.48429 .99622 Mdot
.24285 .80864 Mdot
.23771 .89156 Mdot
.44303 .88421 Mdot
.24652 .88009 Mdot
.07454 .71598 Mdot
.0158 .89412 Mdot
.11952 .27782 Mdot
.24764 .93879 Mdot
.3544 .88751 Mdot
.47287 .16136 Mdot
.15272 .84648 Mdot
.42052 .20991 Mdot
.37005 .12146 Mdot
.20172 .78755 Mdot
.13255 .67385 Mdot
.27167 .90528 Mdot
.53299 .54286 Mdot
.19771 .90572 Mdot
.2249 .86683 Mdot
.00802 .89042 Mdot
.6619 .90793 Mdot
.24249 .92741 Mdot
.27838 .05342 Mdot
.22892 .03994 Mdot
.09535 .73301 Mdot
.16944 .91291 Mdot
.48488 .92262 Mdot
.43404 .00437 Mdot
.25371 .90018 Mdot
.936 .00838 Mdot
.3893 .80973 Mdot
.08798 .64708 Mdot
.56319 .02992 Mdot
.9787 .44317 Mdot
.1637 .74756 Mdot
.18793 .96405 Mdot
.61659 .16013 Mdot
.13051 .85767 Mdot
.88523 .56849 Mdot
.31587 .85468 Mdot
.13833 .80241 Mdot
.94642 .63164 Mdot
.47222 .55549 Mdot
.31603 .22959 Mdot
.11241 .07184 Mdot
.13323 .80516 Mdot
.23927 .87944 Mdot
.10413 .77932 Mdot
.21726 .90809 Mdot
.24204 .35364 Mdot
.27442 .94485 Mdot
.36928 .89327 Mdot
.30061 .65671 Mdot
.03644 .68776 Mdot
.42856 .16605 Mdot
.0332 .79092 Mdot
.11888 .92845 Mdot
.22144 .04159 Mdot
.26038 .89888 Mdot
.08504 .78328 Mdot
.97705 .45548 Mdot
.034 .07978 Mdot
.41174 .0701 Mdot
.31546 .51463 Mdot
.23826 .90573 Mdot
.34184 .85619 Mdot
.06304 .56256 Mdot
.1509 .94544 Mdot
.70868 .42284 Mdot
.17983 .18668 Mdot
.19021 .9865 Mdot
.16274 .84076 Mdot
.06344 .76986 Mdot
.39417 .88794 Mdot
.03597 .59615 Mdot
.53395 .18174 Mdot
.34195 .04108 Mdot
.03109 .31639 Mdot
.19718 .9171 Mdot
.17396 .82587 Mdot
.11691 .14088 Mdot
.15363 .94966 Mdot
.1458 .85943 Mdot
.33329 .94422 Mdot
.27396 .00691 Mdot
.74577 .16065 Mdot
.24322 .46799 Mdot
.63651 .89139 Mdot
.82416 .74805 Mdot
.18743 .92263 Mdot
.07444 .92998 Mdot
.43607 .11253 Mdot
.16178 .95461 Mdot
.17539 .97521 Mdot
.23886 .91971 Mdot
.26947 .86359 Mdot
.40608 .5459 Mdot
.46994 .87871 Mdot
.48086 .42157 Mdot
.46712 .32772 Mdot
.40345 .89276 Mdot
.47823 .51234 Mdot
.21406 .79467 Mdot
.21956 .80222 Mdot
.02976 .77901 Mdot
.4346 .79176 Mdot
.68348 .06485 Mdot
.43894 .86902 Mdot
.24402 .94744 Mdot
.84754 .02216 Mdot
.19756 .87162 Mdot
.07008 .9406 Mdot
.33005 .94759 Mdot
.336 .92211 Mdot
.44479 .80023 Mdot
.11487 .85298 Mdot
.30338 .97149 Mdot
.17112 .78679 Mdot
.31749 .88584 Mdot
.03586 .6868 Mdot
.34011 .85998 Mdot
.35086 .9533 Mdot
.36447 .88339 Mdot
.14428 .8561 Mdot
.16876 .65758 Mdot
.34336 .89916 Mdot
.15124 .87349 Mdot
.29016 .91507 Mdot
.34569 .02112 Mdot
.02164 .83259 Mdot
.35362 .77044 Mdot
.04439 .49489 Mdot
.13071 .8085 Mdot
.10442 .75991 Mdot
.2749 .00565 Mdot
.30745 .92973 Mdot
.83072 .26737 Mdot
.33479 .87019 Mdot
.25907 .94187 Mdot
.34679 .96491 Mdot
.09609 .04973 Mdot
.14947 .73944 Mdot
.25001 .85385 Mdot
.1128 .77134 Mdot
.37802 .34774 Mdot
.42019 .39515 Mdot
.20632 .88735 Mdot
.24494 .08251 Mdot
.40356 .51922 Mdot
.286 .8546 Mdot
.25959 .91173 Mdot
.20217 .90072 Mdot
.06524 .97636 Mdot
.07087 .38174 Mdot
.26245 .09338 Mdot
.1353 .87973 Mdot
.09819 .01286 Mdot
.22421 .87097 Mdot
.25918 .86315 Mdot
.38256 .60615 Mdot
.19153 .745 Mdot
.35031 .88588 Mdot
.11457 .56879 Mdot
.27393 .91261 Mdot
.34621 .80155 Mdot
.19575 .59875 Mdot
.29786 .84395 Mdot
.38278 .93323 Mdot
.42532 .06365 Mdot
.39939 .94769 Mdot
.2031 .21485 Mdot
.13799 .9092 Mdot
.41206 .72569 Mdot
.19269 .74228 Mdot
.3146 .88239 Mdot
.29322 .68874 Mdot
.14548 .77778 Mdot
.2601 .91044 Mdot
.41416 .30866 Mdot
.75209 .81452 Mdot
.23584 .90744 Mdot
.51486 .07834 Mdot
.14858 .85196 Mdot
.16171 .85422 Mdot
.23442 .9255 Mdot
.22038 .89531 Mdot
.13856 .84407 Mdot
.334 .05785 Mdot
.16604 .8531 Mdot
.18535 .80836 Mdot
.03233 .05747 Mdot
.23306 .75693 Mdot
.11149 .69906 Mdot
.3923 .12981 Mdot
.32543 .87742 Mdot
.58528 .11319 Mdot
.06342 .80208 Mdot
.27689 .02053 Mdot
.5949 .5548 Mdot
.13754 .79269 Mdot
.11169 .81944 Mdot
.81629 .30585 Mdot
.98283 .9672 Mdot
.16572 .85693 Mdot
.25359 .91376 Mdot
.25431 .85467 Mdot
.82652 .94389 Mdot
.20287 .2292 Mdot
.93194 .56224 Mdot
.30053 .95383 Mdot
.12967 .86331 Mdot
.3368 .91804 Mdot
.38464 .92745 Mdot
.46746 .91696 Mdot
.34345 .92586 Mdot
.0104 .90443 Mdot
.18438 .92689 Mdot
.31574 .48557 Mdot
.14592 .85507 Mdot
.1965 .17069 Mdot
.31724 .90733 Mdot
.25891 .90098 Mdot
.15555 .84866 Mdot
.27621 .91692 Mdot
.15643 .84756 Mdot
.39071 .79405 Mdot
.1169 .87984 Mdot
.27739 .73803 Mdot
.1319 .79339 Mdot
.22187 .09198 Mdot
.65173 .48654 Mdot
.18297 .87169 Mdot
.78766 .03509 Mdot
.20186 .93759 Mdot
.12277 .81043 Mdot
.26293 .72824 Mdot
.07197 .72176 Mdot
.15251 .82279 Mdot
.26294 .30922 Mdot
.60022 .09729 Mdot
.10901 .71915 Mdot
.29113 .91589 Mdot
.99573 .87221 Mdot
.30609 .92901 Mdot
.14334 .85575 Mdot
.26608 .82981 Mdot
.32038 .88695 Mdot
.12974 .79744 Mdot
.15442 .83578 Mdot
.47123 .18756 Mdot
.24899 .86999 Mdot
.04865 .83306 Mdot
.13417 .95098 Mdot
.87595 .77824 Mdot
.3561 .03181 Mdot
.22069 .8909 Mdot
.03694 .94042 Mdot
.1851 .90111 Mdot
.59776 .43891 Mdot
.25456 .91816 Mdot
.09899 .72585 Mdot
.21546 .91169 Mdot
.31289 .91008 Mdot
.09047 .91597 Mdot
.54884 .66462 Mdot
.15498 .01142 Mdot
.79057 .76369 Mdot
.11785 .57582 Mdot
.46139 .3081 Mdot
.29559 .96232 Mdot
.26649 .87794 Mdot
.22937 .86948 Mdot
.21235 .93576 Mdot
.29615 .79938 Mdot
.07359 .66737 Mdot
.10243 .83816 Mdot
.40048 .75503 Mdot
.10587 .22378 Mdot
.05746 .85678 Mdot
.17827 .70969 Mdot
.25539 .5803 Mdot
.23966 .85036 Mdot
.834 .08976 Mdot
.46542 .96887 Mdot
.23148 .89763 Mdot
.15263 .84625 Mdot
.23353 .88411 Mdot
.9175 .02555 Mdot
.34234 .52306 Mdot
.11392 .05766 Mdot
.24473 .76651 Mdot
.62672 .90797 Mdot
.3827 .73014 Mdot
.30972 .97822 Mdot
.17137 .86319 Mdot
.15261 .91899 Mdot
.62516 .31167 Mdot
.19372 .84104 Mdot
.19432 .81915 Mdot
.16972 .97665 Mdot
.25328 .903 Mdot
.19008 .18151 Mdot
.21032 .88678 Mdot
.31947 .91465 Mdot
.15385 .84294 Mdot
.40642 .12926 Mdot
.43452 .96626 Mdot
.24829 .88554 Mdot
.61168 .8163 Mdot
.08918 .69722 Mdot
.28519 .85811 Mdot
.24048 .40066 Mdot
.26968 .89734 Mdot
.20117 .86362 Mdot
.2784 .78459 Mdot
.07702 .66641 Mdot
.27962 .67796 Mdot
.2981 .95323 Mdot
.7436 .687 Mdot
.98114 .64823 Mdot
.60776 .11067 Mdot
.08314 .95288 Mdot
.26611 .87573 Mdot
.26697 .90606 Mdot
.23532 .90593 Mdot
.49206 .89501 Mdot
.15888 .86464 Mdot
.66362 .14754 Mdot
.4384 .03798 Mdot
.37044 .10744 Mdot
.64241 .6896 Mdot
.13269 .57945 Mdot
.22194 .29128 Mdot
.43897 .85026 Mdot
.37952 .86533 Mdot
.43623 .73921 Mdot
.1386 .88513 Mdot
.13468 .85218 Mdot
.28176 .74364 Mdot
.70085 .85736 Mdot
.25702 .90753 Mdot
.21015 .92851 Mdot
.19906 .83314 Mdot
.02732 .81776 Mdot
.55816 .24047 Mdot
.38621 .55066 Mdot
.23985 .94582 Mdot
.33621 .86185 Mdot
.25562 .92128 Mdot
.21127 .42067 Mdot
.23615 .60878 Mdot
.23063 .91336 Mdot
.66905 .45742 Mdot
.24079 .84538 Mdot
.2212 .96318 Mdot
.19227 .74019 Mdot
.14145 .82898 Mdot
.17971 .9196 Mdot
.18194 .89835 Mdot
.27207 .11454 Mdot
.27181 .13956 Mdot
.19794 .93477 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo0_l0000<ooooo`?o00003oooool01?l0003oooooo`000?l0000<ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool01oooool2o`0000Cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo0_l0000<ooooo`?o00001_ooool3o`0000Cooooo0ol000000ooooooo0000o`00000<ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool01oooool2o`0000Cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0<ooooo`;o00003oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o0000ooooooooool0
A?ooool2o`0000oooooo0ol00004ooooo`;o0000/_ooool2o`0001[ooooo0_l0000Iooooo`007_oo
ool00ol0003oooooooooo`0Looooo`;o00004?ooool2o`0001Cooooo0_l0000booooo`;o0000SOoo
ool2o`0002?ooooo0_l0000Iooooo`007_ooool00ol0003oooooooooo`0Looooo`;o00004?ooool2
o`0004Sooooo0_l0002=ooooo`;o0000?_ooool001kooooo00?o0000ooooooooool0G_ooool2o`00
02[ooooo0_l0002kooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o0000<_ooool2o`0000_o
oooo0ol00005ooooo`?o00003?ooool3o`0001_ooooo0_l0001Rooooo`;o00007oooool2o`0003Ko
oooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0000_ooooo`;o000000?oooooo`000?l00000
2oooool3o`0000Gooooo0_l0000=ooooo`?o00002Oooool2o`0000Wooooo0_l0001Yooooo`;o0000
4oooool2o`0000[ooooo0_l0000Eooooo`;o00007oooool001kooooo00?o0000ooooooooool0=ooo
ool2o`0000cooooo0_l000001?oooooo0000o`000?ooool2o`0000Oooooo0ol0000Qooooo`;o0000
2Oooool2o`0007kooooo0_l0000Qooooo`;o00007oooool001kooooo00?o0000ooooooooool00_l0
000eooooo`;o00004_ooool2o`0000Oooooo0ol0000Iooooo`;o0000@Oooool2o`0008?ooooo0_l0
000=ooooo`007_ooool00ol0003oooooooooo`02o`0004cooooo0_l00002ooooo`;o00005?ooool2
o`0000?ooooo0_l000000ooooooo0000o`000011ooooo`;o0000Aoooool2o`0003[ooooo0_l0000=
ooooo`007_ooool00ol0003oooooooooo`0gooooo`;o00005Oooool2o`0000;ooooo0_l00008oooo
o`;o00002_ooool2o`0000?ooooo0_l0000Iooooo`Co0000L?ooool2o`0004Wooooo000Nooooo`03
o`000?oooooooooo03Oooooo0_l0000=ooooo`;o00005?ooool2o`0000gooooo0_l0000Kooooo`Co
0000^oooool001kooooo00?o0000ooooooooool0A?ooool4o`0001_ooooo0_l00006ooooo`;o0000
3oooool2o`000<Wooooo000Nooooo`03o`000?oooooooooo04Cooooo0_l00003ooooo`;o00006?oo
ool2o`0001Oooooo0_l00039ooooo`007_ooool00ol0003oooooooooo`0Kooooo`;o0000;?ooool2
o`000?cooooo000Nooooo`;o00007?ooool2o`0003Wooooo0_l0003_ooooo`007_ooool00ol0003o
ooooooooo`1Fooooo`;o00006_ooool2o`0001Sooooo0_l0002iooooo`007_ooool00ol0003ooooo
ooooo`06ooooo`;o00006Oooool2o`0004Gooooo0_l00008ooooo`;o00006?ooool4o`0000kooooo
0_l0002Wooooo`007_ooool00ol0003oooooooooo`06ooooo`;o00006Oooool2o`0004Gooooo0_l0
000Dooooo`;o00003_ooool2o`0000kooooo0_l0002Wooooo`007_ooool00ol0003oooooooooo`18
ooooo`;o00001?ooool2o`0002kooooo0_l00006ooooo`;o0000D_ooool2o`0006_ooooo000Noooo
o`03o`000?oooooooooo04Sooooo0_l00004ooooo`;o00000oooool2o`0000cooooo0_l0000Soooo
o`;o0000D_ooool2o`0006_ooooo000Nooooo`03o`000?oooooooooo023ooooo0_l0000aooooo`;o
00003?ooool2o`0000_ooooo0_l0000?ooooo`;o000000?oooooo`000?l000000_ooool2o`000;oo
oooo000Nooooo`03o`000?oooooooooo023ooooo0_l00003ooooo`;o0000Aoooool2o`0000oooooo
0_l000001?oooooo0000o`000?ooool3o`000;oooooo000Nooooo`03o`000?oooooooooo02Gooooo
0_l0001Looooo`Co0000`?ooool001kooooo00?o0000ooooooooool01oooool2o`0007[ooooo0_l0
000Nooooo`;o0000X_ooool001kooooo00?o0000ooooooooool01oooool4o`00047ooooo0_l0001E
ooooo`;o00009oooool2o`0006Gooooo0_l0000Booooo`007_ooool00ol0003oooooooooo`09oooo
o`;o0000=_ooool2o`0000Wooooo0ol0001mooooo`;o0000;_ooool2o`0003Gooooo0_l0000Boooo
o`007_ooool00ol0003oooooooooo`11ooooo`;o00002_ooool2o`00033ooooo0_l0001kooooo`;o
00003Oooool2o`0003[ooooo000Nooooo`03o`000?oooooooooo04Cooooo0_l0000;ooooo`;o0000
2_ooool2o`00023ooooo0_l00004ooooo`;o0000Q?ooool2o`0003[ooooo000Nooooo`03o`000?oo
oooooooo04Cooooo0_l0000;ooooo`;o00002_ooool2o`0002Kooooo0_l00030ooooo`007_ooool0
0ol0003oooooooooo`2oooooo`;o0000B_ooool2o`0003[ooooo000Nooooo`;o00005oooool2o`00
01_ooooo0_l0000;ooooo`;o0000OOooool2o`0004[ooooo0_l0000jooooo`007_ooool00ol0003o
ooooooooo`0Fooooo`;o00006oooool2o`0000_ooooo0_l0003oooooo`Kooooo000Nooooo`03o`00
0?oooooooooo07Cooooo0_l00003ooooo`;o0000c?ooool001kooooo00?o0000ooooooooool0M?oo
ool2o`0000?ooooo0_l00016ooooo`;o0000Q?ooool001kooooo00?o0000ooooooooool0E?ooool2
o`0003Cooooo0_l0000^ooooo`;o00001Oooool2o`0008Cooooo000Nooooo`03o`000?oooooooooo
05Cooooo0_l0000dooooo`;o0000;_ooool2o`0008_ooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0<_ooool2o`00043ooooo0_l0000Rooooo`;o0000
Voooool2o`00013ooooo000Nooooo`03o`000?oooooooooo03;ooooo0_l00010ooooo`;o00008_oo
ool2o`0009_ooooo0_l0000@ooooo`007_ooool00ol0003oooooooooo`1aooooo`;o00002?ooool2
o`0000?ooooo1?l00033ooooo`007_ooool00ol0003oooooooooo`1aooooo`;o00002?ooool2o`00
00?ooooo1?l00033ooooo`007_ooool00ol0003oooooooooo`3:ooooo`;o0000Noooool001kooooo
00?o0000ooooooooool0E?ooool2o`0007Cooooo0_l0001kooooo`007_ooool00ol0003ooooooooo
o`0Rooooo`;o0000<?ooool2o`0002Sooooo0_l00037ooooo`007_ooool00ol0003oooooooooo`0R
ooooo`;o0000F_ooool2o`0000Cooooo0_l00031ooooo`007_ooool00ol0003oooooooooo`1Soooo
o`;o00007oooool2o`0004kooooo0_l0001aooooo`007_ooool2o`0006Cooooo0_l0001_ooooo`;o
0000LOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo08cooooo0_l00008ooooo`;o0000;?ooool2
o`0002Sooooo0_l0001Gooooo`007_ooool00ol0003oooooooooo`2<ooooo`;o00002?ooool2o`00
00cooooo0_l0000Nooooo`;o0000:?ooool2o`0005Oooooo000Nooooo`03o`000?oooooooooo08Oo
oooo0_l0000Kooooo`;o0000XOooool001kooooo00?o0000ooooooooool05_ooool2o`0001Sooooo
0_l0001Eooooo`;o0000__ooool001kooooo00?o0000ooooooooool05_ooool2o`0001Sooooo0_l0
000:ooooo`;o0000ooooool:ooooo`007_ooool00ol0003oooooooooo`0looooo`;o0000;_ooool2
o`000=Wooooo000Nooooo`03o`000?oooooooooo06cooooo0_l00008ooooo`;o0000coooool001ko
oooo00?o0000ooooooooool06oooool2o`0001gooooo0_l0000jooooo`;o0000<Oooool2o`0009co
oooo000Nooooo`03o`000?oooooooooo01_ooooo0_l0000Mooooo`;o0000KOooool2o`0009cooooo
000Nooooo`03o`000?oooooooooo03Kooooo0_l0001Mooooo`;o0000/?ooool001kooooo00?o0000
ooooooooool0=_ooool2o`0005gooooo0_l0002`ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`3oooooodSooooo0003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4
A006ooooo`03o`000?oooooooooo04Cooooo0_l0003oooooo`;ooooo0003ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`?o0000A?ooool2o`000?oooooo0_oo
ool000?ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o
0000ooooooooool0oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool01Oooool00ol0003oooooooooo`1mooooo`;o0000J?ooool2o`0005kooooo0003
ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo07gooooo0_l00006ooooo`;o0000H?ooool2o`0005kooooo0003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
P_ooool2o`000003ooooool0003o00000<3ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0?_ooool2o`0004;o
oooo0_l00012ooooo`;o0000Ooooool001kooooo00?o0000ooooooooool02Oooool2o`00023ooooo
0_l0000Aooooo`;o00001Oooool2o`000004ooooool0003o0000o`0007_ooooo0_l0001oooooo`00
7_ooool00ol0003oooooooooo`09ooooo`;o00008?ooool2o`0001Sooooo0_l000001?oooooo0000
o`000?l00020ooooo`;o0000I_ooool2o`0001;ooooo000Nooooo`03o`000?oooooooooo01kooooo
0_l0002[ooooo`;o00002?ooool2o`0005cooooo0_l0000Booooo`007_ooool00ol0003ooooooooo
o`0Nooooo`;o0000=oooool2o`0007cooooo0_l0001`ooooo`007_ooool00ol0003oooooooooo`0n
ooooo`;o00005oooool2o`0000[ooooo0_l0003Rooooo`007_ooool00ol0003oooooooooo`0noooo
o`;o00008oooool2o`0000;ooooo0_l0003Nooooo`007_ooool00ol0003oooooooooo`1Wooooo`;o
0000g_ooool001kooooo00?o0000ooooooooool0/Oooool2o`0009Cooooo000Nooooo`03o`000?oo
oooooooo02?ooooo0_l0002<ooooo`;o0000U?ooool001kooooo00?o0000ooooooooool08oooool2
o`0004;ooooo0_l0003Nooooo`007_ooool00ol0003oooooooooo`0cooooo`;o0000<_ooool2o`00
0=kooooo000Nooooo`;o0000=?ooool2o`000?oooooo2?ooool2o`0000Wooooo000Nooooo`03o`00
0?oooooooooo0?oooooo?Oooool2o`0000Wooooo000Nooooo`03o`000?oooooooooo01_ooooo0_l0
003oooooob_ooooo000Nooooo`03o`000?oooooooooo01_ooooo0_l0003oooooob_ooooo000Noooo
o`03o`000?oooooooooo067ooooo0_l0003Tooooo`007_ooool00ol0003oooooooooo`1Qooooo`;o
0000Yoooool2o`0003_ooooo000Nooooo`03o`000?oooooooooo04Cooooo0_l0000Hooooo`;o0000
Z_ooool2o`0003_ooooo000Nooooo`03o`000?oooooooooo04Cooooo0_l0000Hooooo`;o0000>?oo
ool2o`000:gooooo000Nooooo`03o`000?oooooooooo02?ooooo0_l0001cooooo`;o0000[Oooool0
01kooooo00?o0000ooooooooool08oooool2o`000?oooooo8oooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0A?ooool2o`000?oooooo0_ooool0
01kooooo00?o0000ooooooooool0A?ooool2o`000?oooooo0_ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool2o`000;cooooo0_l0002:ooooo`007_ooool00ol0003ooooooooo
o`2kooooo`;o0000B?ooool2o`00043ooooo000Nooooo`03o`000?oooooooooo02cooooo0_l0001E
ooooo`;o00003Oooool2o`00077ooooo0_l00010ooooo`007_ooool00ol0003oooooooooo`0/oooo
o`;o00008oooool2o`00033ooooo0_l0000=ooooo`;o0000<oooool2o`0007kooooo000Nooooo`03
o`000?oooooooooo057ooooo0_l0001dooooo`;o0000O_ooool001kooooo00?o0000ooooooooool0
1_ooool2o`000>3ooooo0_l0001Mooooo`007_ooool00ol0003oooooooooo`06ooooo`;o0000h?oo
ool2o`0005gooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0Koooool2o`000=Kooooo000Nooooo`03o`000?oooooooooo06oooooo0_l0000Sooooo`;o
0000/Oooool001kooooo00?o0000ooooooooool0U?ooool2o`000;7ooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool07_ooool2o`00023ooooo0_l0003o
ooooo`Kooooo000Nooooo`03o`000?oooooooooo01kooooo0_l0000Pooooo`;o0000ooooool6oooo
o`007_ooool00ol0003oooooooooo`0hooooo`;o0000ooooool>ooooo`007_ooool00ol0003ooooo
ooooo`0hooooo`;o0000?Oooool2o`000<kooooo000Nooooo`;o0000N?ooool2o`0005Kooooo0_l0
001fooooo`007_ooool00ol0003oooooooooo`1;ooooo`;o0000P_ooool2o`0007Kooooo000Noooo
o`03o`000?oooooooooo04_ooooo0_l0003jooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool03?oo
ool2o`000?oooooo>_ooool001kooooo00?o0000ooooooooool03?ooool2o`0003gooooo0_l0003j
ooooo`007_ooool00ol0003oooooooooo`1;ooooo`;o0000n_ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`0_ooooo`;o0000oooooolGooooo`007_oo
ool00ol0003oooooooooo`0Cooooo`;o00006_ooool2o`000?oooooo5oooool001kooooo00?o0000
ooooooooool04oooool2o`000?oooooo<oooool001kooooo00?o0000ooooooooool0Loooool2o`00
0=;ooooo000Nooooo`03o`000?oooooooooo07?ooooo0_l0003Booooo`000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`24ooooo`;o0000`Oooool000?ooooo
00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool3o`0004[ooooo0_l0000hooooo`;o
0000`Oooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`00
00Oooooo00?o0000ooooooooool03_ooool2o`0003[ooooo0_l0003kooooo`000oooool01Ol0003o
oooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`0>
ooooo`;o0000<Oooool2o`000?oooooo1Oooool000?ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0@Oooool2o`000?oooooo1Oooool0
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000
ooooooooool0C?ooool2o`000?Wooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool0
0omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo04cooooo0_l0003iooooo`007_ooool00ol0
003oooooooooo`0Sooooo`;o0000@?ooool2o`000>3ooooo000Nooooo`03o`000?oooooooooo00Co
oooo0_l0000Mooooo`;o00007?ooool2o`0002;ooooo0_l0000aooooo`;o0000[Oooool001kooooo
00?o0000ooooooooool01?ooool2o`0003_ooooo0_l0000Hooooo`;o00002oooool2o`0002kooooo
0_l00018ooooo`;o0000Hoooool001kooooo00?o0000ooooooooool0Foooool2o`0000_ooooo0_l0
001hooooo`;o0000Hoooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0__ooool2o`0008Oooooo000Nooooo`03o`000?oooooooooo0;kooooo0_l0
001jooooo`;o00002oooool001kooooo00?o0000ooooooooool0oooooolkooooo`;o00002oooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000>Gooooo0_l0001Qooooo`00
7_ooool00ol0003oooooooooo`3Tooooo`;o0000E?ooool2o`0000_ooooo000Nooooo`03o`000?oo
oooooooo07cooooo0_l0001Gooooo`;o0000Hoooool2o`0000_ooooo000Nooooo`03o`000?oooooo
oooo07cooooo0_l0001Gooooo`;o0000L?ooool001kooooo00?o0000ooooooooool0b?ooool2o`00
07gooooo000Nooooo`03o`000?oooooooooo04_ooooo0_l0001>ooooo`;o0000:oooool2o`0007go
oooo000Nooooo`03o`000?oooooooooo04_ooooo0_l0001>ooooo`;o0000Z_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooobSooooo0_l0000N
ooooo`007_ooool00ol0003oooooooooo`3oooooobSooooo0_l0000Nooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo06?ooooo0_l0001[ooooo`;o0000
MOooool001kooooo00?o0000ooooooooool0EOooool2o`0000cooooo0_l0001[ooooo`;o0000MOoo
ool001kooooo00?o0000ooooooooool0B?ooool2o`0000_ooooo0_l0003`ooooo`007_ooool00ol0
003oooooooooo`0:ooooo`;o00006Oooool2o`00027ooooo0_l0001Hooooo`;o0000Xoooool001ko
oooo00?o0000ooooooooool02_ooool2o`0001Wooooo0_l0001kooooo`;o0000Xoooool001kooooo
0_l0003=ooooo`;o0000NOooool001kooooo00?o0000ooooooooool0@oooool2o`0002_ooooo0_l0
001Jooooo`;o0000NOooool001kooooo00?o0000ooooooooool0:?ooool2o`0001Wooooo0_l0000[
ooooo`;o0000eOooool001kooooo00?o0000ooooooooool09?ooool2o`0000;ooooo0_l0003ooooo
oakooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l0000looooo`;o0000<oooool2o`000:ko
oooo000Nooooo`03o`000?oooooooooo05[ooooo0_l00006ooooo`;o00004oooool2o`0001kooooo
0_l0001gooooo`;o0000=Oooool001kooooo00?o0000ooooooooool0F_ooool2o`0001_ooooo0_l0
0006ooooo`;o0000Soooool2o`0003Gooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l00015
ooooo`;o00004_ooool2o`0000_ooooo0_l0002iooooo`007_ooool00ol0003oooooooooo`0Toooo
o`;o0000AOooool2o`0000Sooooo0_l0000Eooooo`;o0000^Oooool001kooooo00?o0000oooooooo
ool0MOooool2o`000=3ooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3hooooo`;o0000COooool0
01kooooo00?o0000ooooooooool0IOooool2o`00097ooooo0_l0001=ooooo`007_ooool00ol0003o
ooooooooo`1Uooooo`;o0000@_ooool2o`0000gooooo0_l0000nooooo`;o0000COooool001kooooo
00?o0000ooooooooool0;Oooool2o`00057ooooo0_l0000Wooooo`;o00003Oooool2o`0003kooooo
0_l0001=ooooo`007_ooool2o`0002kooooo0_l0001:ooooo`;o00001Oooool2o`000<Gooooo000N
ooooo`03o`000?oooooooooo06_ooooo0_l00009ooooo`;o000000?oooooo`000?l00000@_ooool2
o`0004[ooooo0_l0000looooo`007_ooool00ol0003oooooooooo`0[ooooo`;o0000?_ooool2o`00
00Wooooo0_l0000Mooooo`;o00009_ooool2o`0004[ooooo0_l0000looooo`007_ooool00ol0003o
ooooooooo`0[ooooo`;o0000J?ooool2o`000;3ooooo000Nooooo`03o`000?oooooooooo013ooooo
0_l00007ooooo`;o00001oooool2o`000?oooooo2?ooool2o`0001[ooooo000Nooooo`03o`000?oo
oooooooo013ooooo0_l00007ooooo`;o00001oooool2o`0003Sooooo0_l0003=ooooo`;o00006_oo
ool001kooooo00?o0000ooooooooool08Oooool2o`0003Wooooo0_l0002nooooo`;o0000:Oooool0
01kooooo00?o0000ooooooooool08Oooool2o`0007kooooo0_l0001Nooooo`;o00006Oooool2o`00
02Wooooo000Nooooo`03o`000?oooooooooo02;ooooo0_l0000Mooooo`;o0000G_ooool2o`0005ko
oooo0_l00014ooooo`007_ooool00ol0003oooooooooo`0Rooooo`;o00000oooool2o`0001Sooooo
0_l0003oooooo`Gooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l0000Vooooo`;o0000[?oo
ool2o`0004Sooooo000Nooooo`03o`000?oooooooooo02;ooooo0_l0000[ooooo`;o0000D_ooool2
o`0005Sooooo0_l00018ooooo`007_ooool00ol0003oooooooooo`0Rooooo`;o0000Ooooool2o`00
0:;ooooo000Nooooo`03o`000?oooooooooo02;ooooo0_l0003oooooobCooooo0003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006oooo
o`03o`000?oooooooooo02;ooooo0_l0003oooooobCooooo0003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooo
oooo00Sooooo0_l0000/ooooo`;o00000_ooool2o`000?oooooo3?ooool000?ooooo00Go410@oooo
oooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`0000Sooooo0_l0
000/ooooo`?o000000?oooooo`000?l000000_l0003oooooo`[ooooo0003ooooo`05o`000?oooooo
ooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0
=oooool2o`0000?ooooo0_l00011ooooo`;o0000a_ooool000?ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`08ooooo`;o
00005_ooool2o`0005Kooooo0_l00005ooooo`;o0000a_ooool000?ooooo00Go410@oooooooooooo
oooooa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool02?ooool2o`0001Ko
oooo0_l0000Gooooo`;o00003_ooool2o`0002gooooo0_l0000^ooooo`;o0000WOooool000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000oooooooo
ool0>Oooool2o`0000kooooo0_l0001Mooooo`;o0000WOooool000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0KOooool2o`00
00?ooooo0_l0003Cooooo`007_ooool00ol0003oooooooooo`1]ooooo`;o00000oooool2o`000=?o
oooo000Nooooo`03o`000?oooooooooo02Sooooo0_l0000aooooo`;o0000j_ooool001kooooo00?o
0000ooooooooool0:?ooool2o`00037ooooo0_l0003Zooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo<Oooool2o`0001Gooooo000Nooooo`03
o`000?oooooooooo00Oooooo0_l0001fooooo`;o0000[oooool2o`0001Gooooo000Nooooo`03o`00
0?oooooooooo00Oooooo0_l0001fooooo`;o0000GOooool2o`0006Oooooo000Nooooo`03o`000?oo
oooooooo04Wooooo0_l0002Cooooo`;o0000Ioooool001kooooo00?o0000ooooooooool0BOooool2
o`0000Sooooo0_l0003;ooooo`;o00006_ooool2o`0000Wooooo000Nooooo`03o`000?oooooooooo
01Sooooo0_l0000]ooooo`;o00001oooool2o`000003ooooool0003o00000<_ooooo0_l0000Joooo
o`;o00002Oooool001kooooo00?o0000ooooooooool06?ooool2o`0002gooooo0_l000000ooooooo
0000o`000004ooooo`;o0000jOooool2o`0000[ooooo000Nooooo`;o00007?ooool2o`0000Sooooo
0_l0000Qooooo`Co0000koooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo01_ooooo0_l0
0008ooooo`;o00008Oooool2o`000:Oooooo0_l0001Dooooo`007_ooool00ol0003oooooooooo`04
ooooo`;o0000;Oooool2o`0002Wooooo0_l0002Aooooo`;o0000E?ooool001kooooo00?o0000oooo
ooooool01?ooool2o`0002gooooo0_l0000Yooooo`;o0000ioooool001kooooo00?o0000oooooooo
ool0Doooool2o`0000cooooo0_l0001;ooooo`;o0000Uoooool001gooooo0_l0000Fooooo`?o0000
??ooool2o`0000cooooo0_l0000_ooooo`;o00006_ooool2o`0008cooooo0_l00009ooooo`007Ooo
ool2o`0001Kooooo0ol0001:ooooo`;o0000;oooool2o`000:Sooooo0_l00009ooooo`007_ooool0
0ol0003oooooooooo`0Aooooo`;o00001?ooool2o`0000kooooo0_l00003ooooo`;o0000oooooolJ
ooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o00001?ooool2o`0000kooooo0_l00003oooo
o`;o0000:Oooool2o`000>kooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l000000ooooooo
0000o`00000^ooooo`;o0000eOooool2o`0001Oooooo000Nooooo`03o`000?oooooooooo02Cooooo
0_l00003ooooo`;o0000ooooool4ooooo`;o00005oooool001kooooo00?o0000ooooooooool02?oo
ool4o`0001gooooo0_l0000=ooooo`;o0000]?ooool2o`0000?ooooo0_l0001Booooo`007_ooool0
0ol0003oooooooooo`08ooooo`Co0000;?ooool2o`0001Oooooo0_l00008ooooo`;o0000L?ooool2
o`0001oooooo0_l00003ooooo`;o0000D_ooool001kooooo00?o0000ooooooooool02?ooool2o`00
04Oooooo0_l00008ooooo`;o0000L?ooool2o`0007Sooooo000Nooooo`03o`000?oooooooooo02Wo
oooo0_l0000@ooooo`;o0000ooooool4ooooo`;o00001Oooool001kooooo00?o0000ooooooooool0
6Oooool2o`0000Gooooo0_l00007ooooo`;o00004?ooool2o`000?oooooo1?ooool2o`0000Gooooo
000Nooooo`;o00006_ooool2o`0000Gooooo0_l0000Yooooo`;o0000<?ooool2o`000<Sooooo000N
ooooo`03o`000?oooooooooo04_ooooo0_l0000`ooooo`;o0000b?ooool001kooooo00?o0000oooo
ooooool0Boooool2o`0003kooooo0_l0002jooooo`007_ooool00ol0003oooooooooo`0fooooo`;o
0000Doooool2o`000;[ooooo000Nooooo`03o`000?oooooooooo03Kooooo0_l0000Hooooo`;o0000
mOooool001kooooo00?o0000ooooooooool05?ooool2o`0003[ooooo0_l0000Iooooo`;o0000f_oo
ool001kooooo00?o0000ooooooooool05?ooool2o`0000Wooooo0_l00018ooooo`Co0000f_ooool0
01kooooo00?o0000ooooooooool04oooool2o`0000[ooooo0_l0000Vooooo`;o00005?ooool2o`00
00[ooooo0_l0001Uooooo`;o0000??ooool2o`0003Oooooo000Nooooo`03o`000?oooooooooo01?o
oooo0_l00007ooooo`;o00005_ooool2o`0000Gooooo0_l0000:ooooo`;o00005?ooool2o`0002?o
oooo0_l0001<ooooo`;o0000??ooool2o`0002;ooooo0_l0000Cooooo`007_ooool00ol0003ooooo
ooooo`0Gooooo`;o00000oooool2o`0001Kooooo0_l00005ooooo`;o00003_ooool2o`0000Cooooo
0_l0000Uooooo`;o00002?ooool2o`0009Kooooo0_l0000Fooooo`;o00004oooool001kooooo00?o
0000ooooooooool05oooool2o`0000;ooooo0_l0000Oooooo`;o000000Coooooo`000?l0003ooooo
0_l00007ooooo`;o00001?ooool2o`000003ooooool0003o000002;ooooo0_l0002Pooooo`;o0000
:oooool001kooooo00?o0000ooooooooool06oooool2o`0001kooooo0ol000001?oooooo0000o`00
0?ooool2o`00013ooooo0_l0002;ooooo`;o0000I?ooool001kooooo00?o0000ooooooooool0;?oo
ool2o`0000gooooo0_l0000Eooooo`;o00000_ooool2o`0003;ooooo0_l00012ooooo`;o00004Ooo
ool2o`0006Cooooo000Nooooo`03o`000?oooooooooo02cooooo0_l0000<ooooo`?o00005Oooool2
o`0000;ooooo0_l0000booooo`;o00004?ooool2o`00033ooooo0_l0001gooooo`007_ooool00ol0
003oooooooooo`0jooooo`?o00003?ooool2o`0000cooooo0_l0000@ooooo`;o0000<Oooool2o`00
0:Wooooo000Nooooo`03o`000?oooooooooo037ooooo0_l00007ooooo`;o00003Oooool2o`0000co
oooo0_l0000@ooooo`;o0000:?ooool2o`0007?ooooo0_l0000mooooo`007_ooool2o`0000;ooooo
0_l0000^ooooo`;o0000H?ooool2o`0007?ooooo0_l0000mooooo`007_ooool01?l0003ooooooooo
ooooool2o`0002cooooo0_l0003oooooo`cooooo0_l00009ooooo`007_ooool00ol0003ooooooooo
o`0Tooooo`;o00002Oooool3o`0000;ooooo0_l0000Booooo`;o0000=?ooool2o`000;cooooo0_l0
0009ooooo`007_ooool00ol0003oooooooooo`0Nooooo`;o00001?ooool2o`0000[ooooo0_l00002
ooooo`;o00004_ooool2o`0001_ooooo0_l0000Gooooo`;o0000aoooool001kooooo00?o0000oooo
ooooool07_ooool2o`0000gooooo0_l000000ooooooo0000o`00000Pooooo`;o00004Oooool2o`00
09Kooooo0_l00018ooooo`007_ooool00ol0003oooooooooo`0]ooooo`;o000000?oooooo`000?l0
00006Oooool2o`0000Gooooo0_l0000@ooooo`;o0000Uoooool2o`0004Sooooo000Nooooo`03o`00
0?oooooooooo017ooooo0_l0000/ooooo`;o00002_ooool2o`0001Oooooo0ol0000Zooooo`;o0000
5_ooool2o`0009cooooo000Nooooo`03o`000?oooooooooo00kooooo0_l000000ooooooo0000o`00
0009ooooo`;o00000oooool2o`0000Sooooo0_l0000Booooo`;o00004?ooool2o`0001;ooooo0_l0
0008ooooo`;o00008?ooool2o`0001Kooooo0_l0002Looooo`007_ooool00ol0003oooooooooo`0>
ooooo`;o00003?ooool2o`0000?ooooo0_l00006ooooo`Co00009?ooool2o`0001cooooo0_l0003F
ooooo`007_ooool00ol0003oooooooooo`06ooooo`;o00005_ooool2o`0000Wooooo1?l0000Xoooo
o`;o0000`_ooool2o`0002cooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l0000Fooooo`;o
00002oooool2o`0002Sooooo0_l0000=ooooo`;o00001?ooool2o`0000Cooooo0_l0002Looooo`;o
00002Oooool2o`0002cooooo000Nooooo`03o`000?oooooooooo01Gooooo0_l000000ooooooo0000
o`00000>ooooo`;o0000;?ooool2o`0000cooooo0_l00004ooooo`;o00001?ooool2o`0009cooooo
0_l0000gooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o000000?oooooo`000?l000003?oo
ool:o`000004ooooool0003o0000ooooo`;o00001oooool2o`0001Oooooo0_l0001^ooooo`;o0000
Ooooool001kooooo00?o0000ooooooooool01oooool2o`0000oooooo0_l00005ooooo`Co00000ooo
ool2o`000003ooooool0003o000000Go000000?oooooo`000?l000000ol00007ooooo`;o0000B_oo
ool2o`0003_ooooo0_l0000Tooooo`;o0000FOooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0
1oooool2o`0001Kooooo1?l00004ooooo`Co00002?ooool2o`0000Cooooo0_l00006ooooo`;o0000
>?ooool2o`0000cooooo0_l0001Qooooo`;o0000C_ooool2o`0000Wooooo0003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03
o`000?oooooooooo02Kooooo1ol0000<ooooo`;o00001_ooool2o`0000kooooo0_l0000=ooooo`;o
00006Oooool2o`0005_ooooo0_l0001Rooooo`;o00002Oooool000?ooooo00Go410@oooooooooooo
oooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`00027ooooo0_l00003oooo
o`;o00000oooool2o`0000kooooo0_l00004ooooo`;o00003_ooool2o`0000Wooooo0_l00002oooo
o`;o00002_ooool2o`0001kooooo0_l0001:ooooo`;o0000KOooool000?ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool00ol0003oooooooooo`0@
ooooo`;o00003oooool2o`0000;ooooo0_l00002ooooo`Co00002Oooool2o`0000;ooooo0ol00004
ooooo`Co00005oooool2o`0000kooooo0_l0000Nooooo`;o0000Y_ooool2o`00017ooooo0003oooo
o`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o
0000ooooooooool04?ooool2o`0001?ooooo1_l00004ooooo`;o00001Oooool2o`0000;ooooo0_l0
0007ooooo`;o00009oooool2o`000<Kooooo0_l0000Aooooo`000oooool01Ol@413ooooooooooooo
oooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo02Cooooo
1_l00005ooooo`;o000000?oooooo`000?l000000_ooool6o`0000oooooo0_l0000]ooooo`;o0000
X_ooool2o`0002Oooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zj
oooooonj^[[o000000Kooooo00?o0000ooooooooool02_ooool2o`0001Sooooo1?l000000ooooooo
0000o`000007ooooo`;o00000_ooool6o`000003ooooool0003o000000cooooo0_l0000]ooooo`;o
0000X_ooool2o`0002Oooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo
410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool01_ooool2o`0000;ooooo0_l0000>oooo
o`;o00002?ooool2o`0000?ooooo0_l000000ooooooo0000o`00000:ooooo`;o000000?oooooo`00
0?l000000_l0000?ooooo`;o0000Loooool2o`0002_ooooo0_l0001Eooooo`007_ooool00ol0003o
ooooooooo`05ooooo`?o00004_ooool2o`0000Cooooo0_l0000:ooooo`;o00000oooool2o`0000So
oooo0_l0000Aooooo`;o00002Oooool2o`0006Sooooo0_l0000[ooooo`;o0000EOooool001kooooo
00?o0000ooooooooool01Oooool2o`0000?ooooo0_l0000Dooooo`;o00003Oooool5o`0000Oooooo
0_l000000ooooooo0000o`00000Iooooo`;o00005Oooool2o`000=Gooooo000Nooooo`03o`000?oo
oooooooo00[ooooo0_l00002ooooo`;o00003_ooool2o`0000gooooo1ol00008ooooo`Co0000:?oo
ool2o`0000;ooooo0_l00002ooooo`;o00001oooool2o`000<cooooo000Nooooo`03o`000?oooooo
oooo00kooooo0_l0000>ooooo`;o00003Oooool2o`0000Gooooo0_l00006ooooo`;o0000:_ooool2
o`0000;ooooo0_l0000;ooooo`;o0000:oooool2o`0009oooooo000Nooooo`03o`000?oooooooooo
01Sooooo0_l0000@ooooo`;o00002?ooool2o`0001cooooo0_l00004ooooo`;o00002?ooool2o`00
04;ooooo0_l0002:ooooo`;o00004oooool001kooooo00?o0000ooooooooool00oooool2o`0000Oo
oooo0_l0000:ooooo`;o00003oooool3o`0000?ooooo0_l0000<ooooo`;o00000oooool2o`0000_o
oooo0_l000000ooooooo0000o`000004ooooo`;o00002?ooool2o`0000cooooo0_l0001Oooooo`;o
0000Goooool2o`0001?ooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l00007ooooo`;o0000
6oooool2o`000003ooooool0003o000000?o00003?ooool2o`0000?ooooo0_l00007ooooo`;o0000
0_ooool2o`0001oooooo0_l00014ooooo`;o00006Oooool2o`0007Cooooo000Nooooo`03o`000?oo
oooooooo01gooooo0_l0000=ooooo`Co000000?oooooo`000?l000002?ooool2o`0000kooooo0_l0
0002ooooo`;o0000IOooool2o`00077ooooo0_l0000Looooo`007_ooool00ol0003oooooooooo`0M
ooooo`;o00001oooool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000008
ooooo`;o00001Oooool2o`0000Wooooo0_l0000>ooooo`Co0000b?ooool2o`0001cooooo000Noooo
o`03o`000?oooooooooo02Kooooo0_l000000ooooooo0000o`000003ooooo`;o00002Oooool4o`00
00Gooooo0_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000003_ooool4o`00
0=gooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`0Vooooo`;o00000oooool2o`000003
ooooool0003o000000?o00001_ooool2o`0000?ooooo0_l00003ooooo`Co00000oooool2o`0003So
oooo0_l00005ooooo`;o0000/Oooool2o`0000Oooooo000Nooooo`;o00008_ooool2o`0000?ooooo
3_l00008ooooo`Co00000oooool2o`0000;ooooo1Ol0000:ooooo`;o000000?oooooo`000?l00000
6Oooool2o`0000kooooo0_l00005ooooo`;o0000S?ooool2o`0002cooooo000Nooooo`03o`000?oo
oooooooo027ooooo0_l00005ooooo`Oo000000?oooooo`000?l000000_l00004ooooo`;o00000_oo
ool2o`0000Kooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000;o00001Ooo
ool2o`000003ooooool0003o000000Sooooo0_l00006ooooo`;o00001oooool2o`0008_ooooo0_l0
000Fooooo`;o0000;?ooool001kooooo00?o0000ooooooooool01?ooool2o`0000Wooooo0_l0000E
ooooo`;o000000?oooooo`000?l000000ol00002ooooo`Co00001?ooool4o`0000Sooooo0_l00004
ooooo`;o000000?oooooo`000?l000000_l00008ooooo`;o00002?ooool2o`0000Kooooo0_l00002
ooooo`Ko0000Joooool2o`0001oooooo0_l00014ooooo`007_ooool00ol0003oooooooooo`04oooo
o`;o00002Oooool2o`0001Gooooo0_l00003ooooo`;o00001?ooool3o`0000;ooooo0_l00002oooo
o`;o00001Oooool3o`0000Kooooo0_l00007ooooo`?o00000oooool2o`0000kooooo0ol00003oooo
o`Ko0000Joooool2o`0006Gooooo000Nooooo`03o`000?oooooooooo02Kooooo0_l00008ooooo`?o
000000?oooooo`000?l000000_l00005ooooo`;o00000_ooool3o`0000_ooooo0ol000001?oooooo
0000o`000?l00004ooooo`;o00002?ooool2o`0000;ooooo1?l0000;ooooo`;o00000oooool2o`00
0<Wooooo000Nooooo`03o`000?oooooooooo02Kooooo0_l00008ooooo`?o000000Coooooo`000?l0
003o00000oooool2o`000003ooooool0003o000000Kooooo0_l00008ooooo`?o000000Coooooo`00
0?l0003o00001?ooool2o`0000Sooooo0_l00002ooooo`;o00003Oooool2o`0000?ooooo0_l0000?
ooooo`;o0000^?ooool001kooooo00?o0000ooooooooool08_ooool2o`0000;ooooo0_l0000?oooo
o`;o000000?oooooo`000?l000000_l00003ooooo`;o00000_ooool3o`0000Gooooo0_l000000ooo
oooo0000o`00000Gooooo`;o00008?ooool4o`000;Sooooo000Nooooo`03o`000?oooooooooo02;o
oooo0ol00008ooooo`?o00001oooool2o`000003ooooool0003o000000;o00000_ooool3o`0000;o
oooo0ol00005ooooo`Go00005oooool2o`00023ooooo1?l0000Zooooo`;o00004Oooool2o`0007;o
oooo0_l00005ooooo`007_ooool00ol0003oooooooooo`0Sooooo`?o00001oooool3o`0000?ooooo
0_l00005ooooo`?o00000oooool2o`0000Wooooo0_l00002ooooo`;o000000Coooooo`000?l0003o
00004Oooool2o`0001;ooooo0_l0000Hooooo`;o00007_ooool2o`0000?ooooo0_l0000Aooooo`;o
0000L_ooool3o`0000Cooooo000Nooooo`03o`000?oooooooooo01Gooooo0_l0000;ooooo`Co0000
0_ooool2o`0000Wooooo0_l00006ooooo`;o00001oooool2o`000003ooooool0003o000000Go0000
00Coooooo`000?l0003ooooo0ol0000Aooooo`;o00001?ooool2o`0000cooooo0_l0000Hooooo`?o
00007Oooool2o`0008_ooooo0_l00004ooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o0000
1Oooool2o`0000Wooooo1?l00004ooooo`;o00002Oooool2o`0000oooooo0_l000000ooooooo0000
o`000005o`000003ooooool0003o000000Kooooo1?l00003ooooo`;o00000_ooool2o`0000Sooooo
0_l00004ooooo`;o00008Oooool2o`000;3ooooo000Nooooo`03o`000?oooooooooo00kooooo0_l0
000@ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00004?ooool2o`0000Kooooo1ol0
0008ooooo`Co00000oooool2o`0000;ooooo1?l00006ooooo`Co00000_ooool2o`0001Sooooo0_l0
000Dooooo`;o0000Xoooool001kooooo00?o0000ooooooooool05oooool2o`0000Wooooo0_l00000
0ooooooo0000o`000002ooooo`;o00000oooool2o`0000oooooo0ol00002ooooo`;o00001Oooool4
o`0000Sooooo0_l00003ooooo`;o00001Oooool3o`0000Sooooo0ol0000;ooooo`;o00000oooool2
o`0000Wooooo0_l0000Dooooo`;o0000Xoooool001kooooo1?l0000Fooooo`;o00002Oooool2o`00
00[ooooo0_l0000?ooooo`;o00000oooool2o`0000;ooooo0ol00004ooooo`;o00001_ooool2o`00
00?ooooo1?l0000;ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`00
0003ooooool0003o000000;o0000B?ooool2o`0007[ooooo000Nooooo`Ko00008oooool2o`0000Ko
oooo0_l00002ooooo`;o00001_ooool2o`0000Sooooo0_l00002ooooo`Co00000oooool4o`0000?o
oooo0_l00006ooooo`;o00002oooool2o`0000Oooooo0_l00002ooooo`;o00000_ooool2o`000003
ooooool0003o000001_ooooo0_l0000]ooooo`;o0000N_ooool001kooooo00Co0000oooooooooooo
oooo0_l0000Sooooo`;o00002_ooool2o`0000?ooooo0_l000000ooooooo0000o`000008ooooo`;o
000000Coooooo`000?l0003ooooo0_l00003ooooo`Co000000?oooooo`000?l000000_l0000Doooo
o`;o00003Oooool3o`0001kooooo0_l0002Yooooo`007_ooool2o`0002cooooo0_l0000:ooooo`?o
00001?ooool2o`0000Oooooo0_l00005ooooo`Go000000?oooooo`000?l000004_ooool2o`0000;o
oooo0_l0000=ooooo`;o0000b_ooool001kooooo00Co0000ooooool0003o00005?ooool2o`0001Co
oooo0_l0000;ooooo`;o00001?ooool2o`0000kooooo1Ol000000ooooooo0000o`00000Booooo`;o
00000_ooool2o`0002Kooooo0_l0002Qooooo`;o00003_ooool001kooooo00Co0000ooooool0003o
00005?ooool2o`0001;ooooo0_l0000Aooooo`;o00000oooool4o`0000?ooooo0ol00003ooooo`?o
00000_ooool4o`0000cooooo0_l00007ooooo`;o00001oooool2o`0001gooooo0_l0000booooo`;o
00002Oooool2o`0006;ooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o0000
3oooool2o`0000Cooooo0_l00003ooooo`;o00001Oooool3o`0000?ooooo1?l00003ooooo`?o0000
0_ooool5o`000003ooooool0003o000000;o00001Oooool2o`0000Cooooo0ol0000=ooooo`Ko0000
D?ooool2o`0000Wooooo0_l0000?ooooo`;o0000HOooool001kooooo00?o0000ooooooooool06?oo
ool2o`0000oooooo0_l00004ooooo`;o00000_ooool3o`0000Gooooo0_l00005ooooo`;o00000ooo
ool2o`0000Cooooo1Ol00003ooooo`?o00001?ooool2o`0000Cooooo1?l0000<ooooo`Ko0000K?oo
ool2o`00067ooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l00004ooooo`;o00003Oooool2
o`0000?ooooo0_l00007ooooo`Co00001oooool2o`0000Cooooo1?l000001?oooooo0000o`000?oo
ool8o`0000Oooooo0_l0000@ooooo`;o00001_ooool2o`0001Cooooo0_l0000Xooooo`;o0000Qooo
ool001kooooo00?o0000ooooooooool06Oooool3o`0000?ooooo0_l0000<ooooo`Go00001?ooool2
o`0000Cooooo1?l00004ooooo`go000000?oooooo`000?l000000_ooool7o`0000cooooo0ol00006
ooooo`;o00002_ooool2o`0001Cooooo0_l0000Xooooo`;o0000Qoooool001kooooo00?o0000oooo
ooooool02_ooool2o`0000gooooo0ol00003ooooo`;o00003?ooool2o`000003ooooool0003o0000
00Cooooo0_l000000ooooooo0000o`000003ooooo`;o00000_ooool<o`000003ooooool0003o0000
00cooooo0_l00007ooooo`;o000000Coooooo`000?l0003o00001_ooool2o`0000?ooooo0_l0000Q
ooooo`;o0000:oooool2o`0007kooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0000>oooo
o`;o00000oooool2o`0000;ooooo0_l00006ooooo`;o00002oooool3o`0000Oooooo0ol00003oooo
o`;o00001Oooool2o`0000cooooo0_l00006ooooo`?o000000Coooooo`000?l0003ooooo0_l00002
ooooo`;o00001Oooool3o`00023ooooo0_l0000[ooooo`;o0000Ioooool2o`0001Gooooo000Noooo
o`03o`000?oooooooooo01Cooooo0_l00004ooooo`;o00001oooool2o`0000Kooooo0_l00003oooo
o`;o00001_ooool2o`0000Cooooo1Ol00005ooooo`;o000000?oooooo`000?l000000_l0000>oooo
o`Go00000oooool2o`0000Gooooo0_l00002ooooo`?o00001Oooool3o`0001?ooooo0_l0002Poooo
o`;o00005Oooool001kooooo00?o0000ooooooooool03Oooool2o`0000Gooooo0_l0000=ooooo`;o
000000?oooooo`000?l000002?ooool2o`0000cooooo1Ol000000ooooooo0000o`000005ooooo`Co
00004?ooool3o`0000cooooo0_l000000ooooooo0000o`000005ooooo`?o00004_ooool3o`000:7o
oooo0_l0000Dooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o00005oooool2o`0001Cooooo
0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`0002Cooooo0_l00008ooooo`;o0000
4oooool2o`0001gooooo0_l0001Jooooo`;o00009oooool2o`0001Cooooo000Nooooo`03o`000?oo
oooooooo01gooooo0_l0000Mooooo`Co000000?oooooo`000?l000000_l00003ooooo`;o00000_oo
ool2o`0000Cooooo0_l00002ooooo`Co000000?oooooo`000?l000001oooool2o`0001_ooooo0_l0
000Aooooo`;o00005_ooool2o`0005[ooooo0_l0000mooooo`007_ooool00ol0003oooooooooo`08
ooooo`;o00002Oooool2o`0000Sooooo0_l00005ooooo`;o00004oooool2o`0000?ooooo0_l00003
ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000002ooooo`Co00000_oo
ool4o`000003ooooool0003o000000Oooooo0_l0000<ooooo`;o00003Oooool2o`00017ooooo0_l0
002aooooo`007_ooool00ol0003oooooooooo`08ooooo`;o00002Oooool2o`0000oooooo0_l00007
ooooo`;o00001Oooool2o`0000?ooooo0_l0000;ooooo`;o000000?oooooo`000?l000000_ooool2
o`000004ooooool0003o0000ooooo`Co00004Oooool2o`0000Sooooo0_l0000Aooooo`;o0000P_oo
ool2o`0003cooooo000Nooooo`03o`000?oooooooooo02gooooo1?l00003ooooo`;o00004oooool6
o`000004ooooool0003o0000ooooo`Co00002Oooool3o`0000;ooooo1Ol0000Dooooo`;o00001Ooo
ool2o`0008;ooooo0_l0000`ooooo`;o00002_ooool001kooooo0_l0000:ooooo`;o00007Oooool2
o`0000Cooooo0ol0000Gooooo`Go00004oooool3o`0000;ooooo1ol0000Booooo`;o00001Oooool2
o`000;Cooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`09ooooo`;o00003?ooool2o`00
00oooooo0_l00004ooooo`Co00005_ooool2o`0001?ooooo0ol0000:ooooo`;o000000Coooooo`00
0?l0003o0000eoooool001kooooo00?o0000ooooooooool05oooool2o`0000;ooooo0_l0000;oooo
o`;o00001?ooool4o`0000?ooooo0_l00009ooooo`;o00006oooool3o`0000gooooo0ol0003Goooo
o`007_ooool00ol0003oooooooooo`0Kooooo`;o00002oooool2o`0000Cooooo0_l00005ooooo`;o
00002Oooool2o`000003ooooool0003o000001Sooooo0_l0000Eooooo`;o0000POooool2o`0004ko
oooo000Nooooo`03o`000?oooooooooo03Wooooo0_l00008ooooo`?o00002Oooool2o`0000_ooooo
0_l0000Fooooo`;o00007?ooool2o`0006?ooooo0_l0001>ooooo`007_ooool00ol0003ooooooooo
o`0[ooooo`;o00003?ooool2o`0000Wooooo0_l00009ooooo`;o00002oooool2o`0000kooooo0ol0
000Jooooo`;o00001oooool2o`000:Oooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0[
ooooo`?o00006?ooool2o`00027ooooo0_l000000ooooooo0000o`000003o`0001Sooooo0_l00008
ooooo`;o0000Y_ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo02;ooooo0_l00008oooo
o`;o00006?ooool2o`0001Oooooo0_l00008ooooo`;o00001?ooool2o`0002;ooooo0_l0002boooo
o`007_ooool00ol0003oooooooooo`0Aooooo`;o00003oooool2o`00017ooooo0_l0000Xooooo`;o
00002_ooool2o`0001gooooo0_l0002kooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o0000
8?ooool4o`0002[ooooo0_l00008ooooo`;o00004_ooool2o`0000Wooooo0_l0002kooooo`007_oo
ool00ol0003oooooooooo`0cooooo`;o0000;?ooool2o`0001cooooo0_l00002ooooo`;o0000QOoo
ool2o`0003_ooooo000Nooooo`03o`000?oooooooooo05gooooo0_l0000Tooooo`;o0000QOooool2
o`0003_ooooo000Nooooo`03o`000?oooooooooo03[ooooo0_l0000Qooooo`;o00002Oooool2o`00
0=gooooo000Nooooo`03o`000?oooooooooo03[ooooo0_l0000/ooooo`;o00001_ooool3o`0001go
oooo0_l0002eooooo`005?ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0
:oooool2o`0004?ooooo0ol0000Mooooo`;o00008Oooool2o`0009;ooooo000Fooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0:oooool2o`00017ooooo0_l0001Iooooo`;o00006?oo
ool2o`0009;ooooo000Fooooo`03o`000?oooooooooo00Gooooo0ol0000nooooo`;o0000AOooool2
o`0001;ooooo0_l0002/ooooo`005_ooool00ol0003oooooooooo`2=ooooo`;o0000`?ooool001Ko
oooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo
000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Cooooo00?oEEEEofIVI_l00000oooooomB
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.21286 .83077 Mdot
.39683 .66948 Mdot
.28976 .95617 Mdot
.26607 .92499 Mdot
.14719 .80636 Mdot
.22465 .89326 Mdot
.29293 .29534 Mdot
.13417 .8596 Mdot
.2647 .87943 Mdot
.2105 .33577 Mdot
.20142 .74044 Mdot
.32772 .7527 Mdot
.20944 .89285 Mdot
.84979 .83484 Mdot
.20761 .87079 Mdot
.33806 .62322 Mdot
.45749 .72066 Mdot
.37203 .90276 Mdot
.23398 .85497 Mdot
.2402 .86391 Mdot
.24295 .88835 Mdot
.28362 .83382 Mdot
.28454 .98617 Mdot
.39286 .79617 Mdot
.19431 .8798 Mdot
.11151 .86965 Mdot
.272 .91348 Mdot
.22136 .90245 Mdot
.26013 .73517 Mdot
.31167 .90302 Mdot
.35412 .92639 Mdot
.2082 .86849 Mdot
.11946 .90716 Mdot
.18778 .19623 Mdot
.27375 .62566 Mdot
.1734 .76948 Mdot
.14733 .81903 Mdot
.43609 .92866 Mdot
.35229 .81781 Mdot
.2268 .94138 Mdot
.35115 .94268 Mdot
.021 .71563 Mdot
.3357 .06681 Mdot
.99666 .76774 Mdot
.05841 .71666 Mdot
.03741 .76142 Mdot
.60981 .20598 Mdot
.24069 .70518 Mdot
.1268 .83768 Mdot
.37503 .12228 Mdot
.39487 .92819 Mdot
.34477 .72786 Mdot
.12974 .8468 Mdot
.21587 .73864 Mdot
.21434 .88092 Mdot
.34556 .64333 Mdot
.8224 .97821 Mdot
.14905 .86202 Mdot
.27161 .90982 Mdot
.07495 .85634 Mdot
.23676 .95411 Mdot
.15299 .8534 Mdot
.38237 .10429 Mdot
.16075 .83486 Mdot
.20131 .88542 Mdot
.28859 .84066 Mdot
.29537 .77266 Mdot
.27122 .91369 Mdot
.21639 .87625 Mdot
.32728 .87954 Mdot
.75643 .90322 Mdot
.42201 .93737 Mdot
.97997 .95002 Mdot
.22366 .58003 Mdot
.16022 .87571 Mdot
.8382 .01339 Mdot
.28632 .0149 Mdot
.72594 .16428 Mdot
.2517 .88559 Mdot
.3784 .03342 Mdot
.14829 .70176 Mdot
.70863 .37021 Mdot
.42172 .43113 Mdot
.14469 .85119 Mdot
.9337 .92522 Mdot
.89217 .65225 Mdot
.11509 .84639 Mdot
.23443 .96629 Mdot
.20201 .87114 Mdot
.40349 .92335 Mdot
.12618 .74094 Mdot
.03131 .58687 Mdot
.41688 .86496 Mdot
.60038 .7815 Mdot
.99676 .85003 Mdot
.29949 .65137 Mdot
.37822 .20512 Mdot
.23219 .5843 Mdot
.13566 .77963 Mdot
.31069 .09637 Mdot
.21602 .85877 Mdot
.26611 .94729 Mdot
.01041 .92407 Mdot
.3008 .97064 Mdot
.30286 .72142 Mdot
.28125 .95526 Mdot
.16619 .20211 Mdot
.19143 .1647 Mdot
.34864 .92899 Mdot
.25305 .23661 Mdot
.16246 .8377 Mdot
.714 .25861 Mdot
.10905 .74167 Mdot
.35928 .88945 Mdot
.11781 .09428 Mdot
.16509 .76876 Mdot
.99416 .62823 Mdot
.23552 .90668 Mdot
.15088 .01623 Mdot
.22319 .67991 Mdot
.24313 .94098 Mdot
.28046 .84073 Mdot
.13242 .98345 Mdot
.13733 .08215 Mdot
.13531 .73137 Mdot
.48155 .47398 Mdot
.48726 .85917 Mdot
.2324 .85234 Mdot
.50717 .04232 Mdot
.15247 .81538 Mdot
.1786 .51198 Mdot
.73406 .29682 Mdot
.23407 .4973 Mdot
.34747 .95096 Mdot
.3738 .91101 Mdot
.42584 .95192 Mdot
.29035 .95388 Mdot
.46843 .0453 Mdot
.3691 .88137 Mdot
.27757 .87594 Mdot
.3093 .86581 Mdot
.13765 .8149 Mdot
.21776 .85754 Mdot
.30107 .23406 Mdot
.82173 .8593 Mdot
.3265 .72389 Mdot
.14745 .89352 Mdot
.24226 .90047 Mdot
.94708 .87278 Mdot
.45663 .59057 Mdot
.11902 .73504 Mdot
.15862 .92821 Mdot
.32047 .75814 Mdot
.22782 .8629 Mdot
.22638 .87481 Mdot
.17013 .86189 Mdot
.37585 .01151 Mdot
.00242 .36571 Mdot
.27417 .91203 Mdot
.3653 .54709 Mdot
.43455 .08523 Mdot
.16041 .76958 Mdot
.62793 .38444 Mdot
.29237 .00161 Mdot
.12597 .7779 Mdot
.15701 .81259 Mdot
.22652 .91409 Mdot
.2722 .93023 Mdot
.0484 .35874 Mdot
.27989 .85955 Mdot
.16707 .94367 Mdot
.03098 .68033 Mdot
.23861 .64025 Mdot
.74948 .64452 Mdot
.09161 .7774 Mdot
.29602 .93131 Mdot
.44727 .77953 Mdot
.1102 .90145 Mdot
.25528 .4106 Mdot
.34756 .71679 Mdot
.27962 .9691 Mdot
.25231 .75562 Mdot
.14456 .68729 Mdot
.06691 .78775 Mdot
.21392 .33364 Mdot
.27943 .97116 Mdot
.36652 .55829 Mdot
.12935 .73869 Mdot
.35961 .0915 Mdot
.17685 .98079 Mdot
.14239 .80433 Mdot
.5542 .79162 Mdot
.23778 .85152 Mdot
.47345 .90391 Mdot
.13836 .60609 Mdot
.25124 .97 Mdot
.15433 .87051 Mdot
.31731 .81368 Mdot
.25317 .86966 Mdot
.12522 .9613 Mdot
.61147 .10531 Mdot
.79218 .55284 Mdot
.36843 .94681 Mdot
.05322 .56742 Mdot
.18841 .87196 Mdot
.2338 .96733 Mdot
.64636 .4769 Mdot
.25202 .93863 Mdot
.75058 .88736 Mdot
.27915 .98677 Mdot
.23637 .80739 Mdot
.25156 .84738 Mdot
.01923 .23112 Mdot
.26264 .30751 Mdot
.44796 .06151 Mdot
.33886 .41602 Mdot
.22163 .93992 Mdot
.36117 .89725 Mdot
.18817 .11584 Mdot
.01106 .6415 Mdot
.73244 .76516 Mdot
.98151 .82623 Mdot
.11433 .78893 Mdot
.26715 .92039 Mdot
.36578 .90885 Mdot
.39195 .98277 Mdot
.16018 .93252 Mdot
.33514 .03195 Mdot
.34643 .55904 Mdot
.25914 .8348 Mdot
.13816 .85102 Mdot
.11648 .85221 Mdot
.18272 .89467 Mdot
.01863 .24946 Mdot
.40481 .5007 Mdot
.65864 .83512 Mdot
.52092 .12235 Mdot
.32289 .94268 Mdot
.23515 .60225 Mdot
.57478 .63389 Mdot
.28179 .81681 Mdot
.20166 .87767 Mdot
.28033 .96288 Mdot
.24285 .92131 Mdot
.3382 .77993 Mdot
.16884 .92171 Mdot
.06058 .77642 Mdot
.22739 .90233 Mdot
.26808 .96686 Mdot
.34207 .96957 Mdot
.3663 .79713 Mdot
.2459 .88584 Mdot
.12135 .70915 Mdot
.95853 .45006 Mdot
.1587 .49359 Mdot
.24971 .78636 Mdot
.13082 .83125 Mdot
.76425 .67792 Mdot
.23449 .7698 Mdot
.64896 .76509 Mdot
.24093 .8456 Mdot
.33953 .83385 Mdot
.27165 .15399 Mdot
.48417 .01207 Mdot
.19545 .88 Mdot
.77227 .07707 Mdot
.18673 .98017 Mdot
.21252 .54484 Mdot
.286 .93666 Mdot
.25651 .93421 Mdot
.12801 .77969 Mdot
.48415 .70495 Mdot
.24639 .9285 Mdot
.33177 .84882 Mdot
.0842 .7012 Mdot
.26615 .89426 Mdot
.23347 .08457 Mdot
.10194 .05413 Mdot
.16807 .73373 Mdot
.32864 .964 Mdot
.77286 .08755 Mdot
.27443 .84575 Mdot
.24828 .04608 Mdot
.98849 .88865 Mdot
.14115 .81376 Mdot
.11818 .79493 Mdot
.30586 .87001 Mdot
.31249 .19758 Mdot
.20373 .09489 Mdot
.4096 .01328 Mdot
.29069 .05197 Mdot
.73815 .02455 Mdot
.27487 .89396 Mdot
.41136 .94376 Mdot
.97517 .61774 Mdot
.18606 .22902 Mdot
.17114 .90011 Mdot
.21649 .88331 Mdot
.30005 .88484 Mdot
.18327 .30148 Mdot
.39617 .82941 Mdot
.13623 .81645 Mdot
.21024 .66541 Mdot
.36798 .90248 Mdot
.68078 .58753 Mdot
.29473 .08801 Mdot
.2725 .91132 Mdot
.25109 .89137 Mdot
.14404 .29822 Mdot
.73441 .54612 Mdot
.25578 .9437 Mdot
.76884 .5698 Mdot
.12228 .86796 Mdot
.02849 .7498 Mdot
.16298 .83871 Mdot
.12494 .04381 Mdot
.26468 .77814 Mdot
.71698 .87262 Mdot
.06244 .88839 Mdot
.23905 .32774 Mdot
.37263 .85289 Mdot
.12934 .94438 Mdot
.23961 .9593 Mdot
.24806 .66232 Mdot
.37606 .89815 Mdot
.14334 .85205 Mdot
.16074 .74137 Mdot
.22501 .84565 Mdot
.39884 .82116 Mdot
.14485 .84375 Mdot
.18703 .79255 Mdot
.23194 .87951 Mdot
.32712 .79984 Mdot
.57383 .71663 Mdot
.14747 .68827 Mdot
.23015 .09909 Mdot
.82273 .72561 Mdot
.26432 .92418 Mdot
.19748 .38616 Mdot
.10986 .8403 Mdot
.12126 .78311 Mdot
.28664 .24557 Mdot
.29738 .85025 Mdot
.3111 .85172 Mdot
.335 .53484 Mdot
.10293 .58321 Mdot
.05619 .067 Mdot
.12347 .3382 Mdot
.97577 .72618 Mdot
.12871 .86362 Mdot
.25614 .92351 Mdot
.16987 .84386 Mdot
.14763 .6764 Mdot
.37733 .49199 Mdot
.47446 .40439 Mdot
.23806 .93969 Mdot
.14905 .72185 Mdot
.27201 .03642 Mdot
.20353 .87932 Mdot
.1426 .77408 Mdot
.25352 .86285 Mdot
.04364 .8525 Mdot
.35751 .92663 Mdot
.24367 .8212 Mdot
.11526 .78475 Mdot
.28687 .78961 Mdot
.35011 .63905 Mdot
.32257 .28317 Mdot
.04092 .34751 Mdot
.2779 .86908 Mdot
.44977 .09186 Mdot
.26967 .91381 Mdot
.30212 .96539 Mdot
.28363 .84137 Mdot
.61871 .89075 Mdot
.42967 .48396 Mdot
.15122 .90571 Mdot
.16287 .88144 Mdot
.21459 .95891 Mdot
.2821 .92342 Mdot
.24519 .88791 Mdot
.1902 .78096 Mdot
.41106 .17273 Mdot
.13699 .49695 Mdot
.1618 .15764 Mdot
.42611 .93161 Mdot
.51959 .79541 Mdot
.28811 .92604 Mdot
.26831 .92147 Mdot
.32454 .00834 Mdot
.30804 .86452 Mdot
.23762 .82177 Mdot
.17376 .88519 Mdot
.14326 .83337 Mdot
.14526 .81875 Mdot
.58064 .85865 Mdot
.55361 .7007 Mdot
.86773 .94028 Mdot
.27073 .91277 Mdot
.36723 .9009 Mdot
.41934 .04277 Mdot
.02153 .58742 Mdot
.07477 .58157 Mdot
.15482 .85133 Mdot
.46384 .10041 Mdot
.41017 .91253 Mdot
.35667 .03265 Mdot
.41105 .92514 Mdot
.28969 .81529 Mdot
.29231 .99574 Mdot
.48956 .06614 Mdot
.25921 .91774 Mdot
.44953 .06909 Mdot
.60054 .22945 Mdot
.61488 .74832 Mdot
.33801 .89514 Mdot
.06341 .95221 Mdot
.40592 .01385 Mdot
.06552 .56647 Mdot
.25202 .88271 Mdot
.2609 .93805 Mdot
.62541 .92016 Mdot
.05871 .0565 Mdot
.2591 .83597 Mdot
.13368 .85674 Mdot
.1687 .48268 Mdot
.75433 .8437 Mdot
.27055 .85034 Mdot
.34739 .87633 Mdot
.6242 .82108 Mdot
.41672 .41886 Mdot
.59844 .09661 Mdot
.08361 .01863 Mdot
.19064 .77657 Mdot
.262 .27555 Mdot
.91768 .78639 Mdot
.22576 .13951 Mdot
.24639 .47352 Mdot
.22117 .01113 Mdot
.05677 .7116 Mdot
.18759 .99264 Mdot
.04922 .91149 Mdot
.11006 .99812 Mdot
.22903 .93853 Mdot
.30735 .86298 Mdot
.23091 .92708 Mdot
.10082 .93908 Mdot
.19972 .78973 Mdot
.42487 .6015 Mdot
.21454 .0018 Mdot
.45987 .8436 Mdot
.32613 .0011 Mdot
.11746 .78817 Mdot
.25363 .90141 Mdot
.07384 .00352 Mdot
.26122 .93315 Mdot
.22845 .88883 Mdot
.17949 .72668 Mdot
.55583 .99547 Mdot
.46201 .23755 Mdot
.30118 .84809 Mdot
.24537 .96188 Mdot
.24152 .89704 Mdot
.17645 .91248 Mdot
.09342 .2171 Mdot
.21813 .5591 Mdot
.12211 .92578 Mdot
.94979 .60245 Mdot
.21875 .90953 Mdot
.16389 .74314 Mdot
.28973 .87372 Mdot
.12369 .85596 Mdot
.14219 .85684 Mdot
.14305 .85403 Mdot
.30361 .8554 Mdot
.22191 .87344 Mdot
.29725 .84185 Mdot
.13542 .84857 Mdot
.39201 .62227 Mdot
.31355 .91132 Mdot
.80948 .5328 Mdot
.49494 .78153 Mdot
.23578 .85356 Mdot
.33368 .86183 Mdot
.20885 .83481 Mdot
.92342 .97599 Mdot
.03924 .40274 Mdot
.26255 .86057 Mdot
.99231 .72252 Mdot
.22539 .99439 Mdot
.31416 .96107 Mdot
.27366 .93233 Mdot
.32631 .90202 Mdot
.48776 .70528 Mdot
.11596 .78236 Mdot
.31799 .82896 Mdot
.07441 .88392 Mdot
.08572 .92735 Mdot
.24197 .95399 Mdot
.26783 .76055 Mdot
.08928 .99279 Mdot
.11493 .91902 Mdot
.05607 .65534 Mdot
.46553 .13946 Mdot
.35065 .89372 Mdot
.92461 .87982 Mdot
.13101 .85785 Mdot
.91131 .92545 Mdot
.23694 .89966 Mdot
.31804 .91318 Mdot
.37517 .87686 Mdot
.62595 .53644 Mdot
.30214 .34581 Mdot
.27201 .74246 Mdot
.1346 .81698 Mdot
.68255 .90034 Mdot
.26516 .00903 Mdot
.30611 .56045 Mdot
.16025 .08926 Mdot
.38078 .88143 Mdot
.28875 .01599 Mdot
.26287 .89063 Mdot
.2491 .8879 Mdot
.1337 .97345 Mdot
.32952 .22183 Mdot
.20542 .90643 Mdot
.38927 .17897 Mdot
.78293 .63435 Mdot
.09678 .72797 Mdot
.55309 .85887 Mdot
.78371 .57622 Mdot
.12818 .86559 Mdot
.14005 .80944 Mdot
.41532 .83966 Mdot
.14463 .84626 Mdot
.23591 .85871 Mdot
.21519 .88379 Mdot
.12401 .82321 Mdot
.88519 .13455 Mdot
.66785 .77884 Mdot
.275 .87632 Mdot
.18909 .47715 Mdot
.30574 .71641 Mdot
.22862 .87304 Mdot
.33449 .93397 Mdot
.36334 .2491 Mdot
.57927 .47082 Mdot
.27009 .00637 Mdot
.2758 .99809 Mdot
.14621 .8465 Mdot
.12968 .01673 Mdot
.29296 .15322 Mdot
.11509 .86889 Mdot
.31265 .20442 Mdot
.20908 .82035 Mdot
.8896 .16613 Mdot
.29741 .88875 Mdot
.25676 .9268 Mdot
.18365 .75166 Mdot
.17618 .12661 Mdot
.28789 .97755 Mdot
.08488 .89655 Mdot
.48455 .92581 Mdot
.19105 .15249 Mdot
.31405 .87185 Mdot
.13327 .79284 Mdot
.4259 .1117 Mdot
.11816 .7861 Mdot
.02984 .47239 Mdot
.20484 .87449 Mdot
.05305 .65364 Mdot
.27941 .96571 Mdot
.21769 .87599 Mdot
.20179 .86581 Mdot
.24439 .83869 Mdot
.23748 .8464 Mdot
.14141 .54233 Mdot
.25892 .74128 Mdot
.26998 .90538 Mdot
.2442 .9251 Mdot
.14098 .81148 Mdot
.23995 .73695 Mdot
.30497 .78666 Mdot
.34183 .88191 Mdot
.25675 .99857 Mdot
.19926 .91512 Mdot
.22644 .9933 Mdot
.11836 .52052 Mdot
.29879 .04867 Mdot
.00208 .89136 Mdot
.13566 .85232 Mdot
.19997 .87279 Mdot
.30743 .82865 Mdot
.10092 .95458 Mdot
.3547 .73707 Mdot
.13713 .86115 Mdot
.23954 .03793 Mdot
.14653 .83955 Mdot
.17954 .86309 Mdot
.17774 .82728 Mdot
.21282 .86334 Mdot
.2674 .926 Mdot
.30876 .96868 Mdot
.22653 .57117 Mdot
.2651 .23909 Mdot
.27279 .02112 Mdot
.24973 .93075 Mdot
.28624 .86061 Mdot
.49335 .17063 Mdot
.22359 .8413 Mdot
.11778 .00973 Mdot
.0917 .58269 Mdot
.25058 .88032 Mdot
.65872 .70476 Mdot
.22927 .8377 Mdot
.32577 .47561 Mdot
.39787 .92113 Mdot
.9203 .73884 Mdot
.15982 .79507 Mdot
.55785 .2501 Mdot
.01901 .13156 Mdot
.06464 .62599 Mdot
.21314 .84034 Mdot
.30102 .38529 Mdot
.10114 .58306 Mdot
.16601 .97785 Mdot
.33518 .64903 Mdot
.75097 .98237 Mdot
.32257 .96295 Mdot
.27272 .8448 Mdot
.3707 .8325 Mdot
.27365 .92362 Mdot
.98274 .87495 Mdot
.29245 .96203 Mdot
.21663 .87869 Mdot
.42657 .75607 Mdot
.14087 .85154 Mdot
.4637 .9322 Mdot
.18505 .8061 Mdot
.20364 .87208 Mdot
.48399 .90315 Mdot
.21392 .88397 Mdot
.13586 .71041 Mdot
.08516 .86793 Mdot
.07919 .28714 Mdot
.31547 .93864 Mdot
.4293 .84642 Mdot
.48845 .21242 Mdot
.15315 .83995 Mdot
.37838 .1999 Mdot
.42832 .05002 Mdot
.1311 .83911 Mdot
.05587 .73226 Mdot
.26151 .91743 Mdot
.4642 .57113 Mdot
.23238 .93824 Mdot
.14334 .86344 Mdot
.88648 .90749 Mdot
.68005 .88419 Mdot
.26691 .92171 Mdot
.18557 .95557 Mdot
.20729 .0209 Mdot
.26094 .77064 Mdot
.20595 .94428 Mdot
.58099 .87659 Mdot
.41652 .89712 Mdot
.25242 .8851 Mdot
.03633 .01402 Mdot
.36838 .94191 Mdot
.02074 .6628 Mdot
.60487 .03176 Mdot
.9318 .38044 Mdot
.27557 .77825 Mdot
.23735 .97093 Mdot
.65543 .20219 Mdot
.14207 .85716 Mdot
.88951 .5266 Mdot
.25099 .83038 Mdot
.31056 .81049 Mdot
.96688 .59141 Mdot
.44849 .65411 Mdot
.28573 .2254 Mdot
.04057 .14353 Mdot
.20286 .83914 Mdot
.20548 .87513 Mdot
.1584 .69508 Mdot
.33829 .87339 Mdot
.32453 .36215 Mdot
.15829 .95706 Mdot
.31322 .8902 Mdot
.29064 .72931 Mdot
.01197 .61689 Mdot
.3983 .10419 Mdot
.02934 .88961 Mdot
.16239 .91571 Mdot
.19822 .03574 Mdot
.24799 .90319 Mdot
.96369 .83898 Mdot
.04428 .45488 Mdot
.03542 .14635 Mdot
.37661 .98641 Mdot
.33913 .49091 Mdot
.18366 .87024 Mdot
.36161 .87814 Mdot
.10501 .60693 Mdot
.13118 .97932 Mdot
.72547 .42327 Mdot
.24177 .15371 Mdot
.23609 .10577 Mdot
.21942 .84962 Mdot
.96567 .84326 Mdot
.30112 .85301 Mdot
.03 .55773 Mdot
.46488 .22463 Mdot
.32761 .03489 Mdot
.09096 .28658 Mdot
.23966 .87318 Mdot
.13352 .84362 Mdot
.18935 .21206 Mdot
.18154 .91547 Mdot
.23268 .84654 Mdot
.44532 .86188 Mdot
.31242 .00201 Mdot
.7674 .19397 Mdot
.29938 .43859 Mdot
.68342 .93032 Mdot
.86289 .7549 Mdot
.22855 .9405 Mdot
.98612 .94109 Mdot
.46723 .18633 Mdot
.1647 .9937 Mdot
.20327 .96189 Mdot
.18477 .88459 Mdot
.28491 .88932 Mdot
.4789 .55326 Mdot
.43864 .77268 Mdot
.40792 .42425 Mdot
.46974 .27471 Mdot
.4454 .84104 Mdot
.48839 .5676 Mdot
.21368 .80045 Mdot
.25288 .85466 Mdot
.05354 .77178 Mdot
.47606 .91344 Mdot
.70696 .06149 Mdot
.48817 .85729 Mdot
.28737 .92833 Mdot
.82321 .0237 Mdot
.1075 .8897 Mdot
.0489 .05221 Mdot
.3742 .01707 Mdot
.29365 .93299 Mdot
.38507 .85156 Mdot
.19728 .83223 Mdot
.34655 .96363 Mdot
.13655 .76823 Mdot
.27985 .83182 Mdot
.05506 .71017 Mdot
.26032 .84901 Mdot
.32277 .95552 Mdot
.49168 .89043 Mdot
.13543 .86199 Mdot
.07655 .58796 Mdot
.29478 .91275 Mdot
.22334 .97011 Mdot
.27468 .94806 Mdot
.31616 .12706 Mdot
.01816 .70447 Mdot
.31601 .81081 Mdot
.95695 .47098 Mdot
.15163 .84671 Mdot
.12083 .69779 Mdot
.27283 .94988 Mdot
.24529 .88523 Mdot
.75707 .27697 Mdot
.36704 .88078 Mdot
.17874 .90365 Mdot
.31635 .9612 Mdot
.09185 .04991 Mdot
.07744 .6509 Mdot
.26506 .91495 Mdot
.11028 .86915 Mdot
.4448 .35754 Mdot
.4453 .40849 Mdot
.18505 .9241 Mdot
.26972 .13811 Mdot
.41749 .50511 Mdot
.27732 .88058 Mdot
.27478 .93141 Mdot
.15879 .86626 Mdot
.15676 .01536 Mdot
.05739 .32041 Mdot
.35505 .12333 Mdot
.10312 .88675 Mdot
.0797 .91265 Mdot
.14298 .86318 Mdot
.24264 .98955 Mdot
.29098 .6284 Mdot
.20079 .79029 Mdot
.24042 .84571 Mdot
.16865 .51404 Mdot
.29505 .88263 Mdot
.30214 .78821 Mdot
.15224 .60116 Mdot
.17282 .83387 Mdot
.36507 .91443 Mdot
.36292 .99678 Mdot
.31347 .85847 Mdot
.16655 .21552 Mdot
.20497 .95432 Mdot
.41536 .83641 Mdot
.19032 .79062 Mdot
.23642 .90588 Mdot
.35882 .6517 Mdot
.13778 .73433 Mdot
.26564 .91173 Mdot
.36356 .28001 Mdot
.72008 .82721 Mdot
.21625 .88319 Mdot
.50621 .1672 Mdot
.14137 .85054 Mdot
.14524 .83771 Mdot
.15155 .88476 Mdot
.16769 .86318 Mdot
.12436 .86069 Mdot
.39218 .10242 Mdot
.11353 .84333 Mdot
.13336 .77803 Mdot
.14304 .10867 Mdot
.20787 .84711 Mdot
.18759 .72436 Mdot
.34841 .19071 Mdot
.24978 .86664 Mdot
.57328 .19176 Mdot
.15908 .77716 Mdot
.29226 .97736 Mdot
.64693 .55335 Mdot
.12822 .84443 Mdot
.1022 .79082 Mdot
.83499 .25851 Mdot
.00459 .87149 Mdot
.14769 .83574 Mdot
.27201 .90902 Mdot
.28125 .87594 Mdot
.81349 .95121 Mdot
.16346 .20166 Mdot
.93419 .55085 Mdot
.24819 .92791 Mdot
.14026 .85904 Mdot
.29752 .93055 Mdot
.5111 .9546 Mdot
.39632 .8932 Mdot
.34493 .94864 Mdot
.0059 .94522 Mdot
.21427 .94665 Mdot
.23573 .47341 Mdot
.13752 .85738 Mdot
.20106 .24369 Mdot
.21619 .91639 Mdot
.19568 .90288 Mdot
.14898 .83784 Mdot
.26152 .95739 Mdot
.21641 .84755 Mdot
.25472 .87869 Mdot
.112 .87418 Mdot
.21073 .75152 Mdot
.19807 .82729 Mdot
.24714 .13115 Mdot
.62043 .47864 Mdot
.14263 .85072 Mdot
.7391 .06932 Mdot
.23049 .93873 Mdot
.15373 .84042 Mdot
.26979 .75744 Mdot
.11268 .76871 Mdot
.12571 .84118 Mdot
.18241 .22563 Mdot
.60384 .05221 Mdot
.08123 .63104 Mdot
.3452 .91904 Mdot
.1029 .86048 Mdot
.29465 .939 Mdot
.14038 .86061 Mdot
.18951 .8552 Mdot
.22918 .93756 Mdot
.19809 .82525 Mdot
.23781 .8303 Mdot
.39474 .13934 Mdot
.27924 .83693 Mdot
.17499 .8143 Mdot
.26726 .01159 Mdot
.83592 .81853 Mdot
.32397 .08412 Mdot
.26072 .85056 Mdot
.07599 .81272 Mdot
.16503 .91269 Mdot
.58172 .42458 Mdot
.21991 .89905 Mdot
.12358 .70184 Mdot
.15109 .85304 Mdot
.35376 .91322 Mdot
.18479 .95603 Mdot
.50629 .5935 Mdot
.19101 .98238 Mdot
.84514 .78386 Mdot
.04059 .59503 Mdot
.47702 .28712 Mdot
.33097 .93195 Mdot
.31633 .92313 Mdot
.31 .85298 Mdot
.32472 .88696 Mdot
.39923 .74723 Mdot
.13507 .75065 Mdot
.15429 .83446 Mdot
.39493 .74686 Mdot
.12773 .18469 Mdot
.13027 .81609 Mdot
.20284 .72708 Mdot
.26373 .5537 Mdot
.27642 .86602 Mdot
.86426 .1212 Mdot
.39804 .88924 Mdot
.31695 .89129 Mdot
.1539 .84024 Mdot
.20347 .86707 Mdot
.92747 .06502 Mdot
.32292 .54904 Mdot
.10901 .06846 Mdot
.08524 .76664 Mdot
.61695 .88652 Mdot
.41428 .7109 Mdot
.28612 .9198 Mdot
.14012 .84652 Mdot
.19303 .88264 Mdot
.59639 .32351 Mdot
.27398 .86278 Mdot
.09777 .71544 Mdot
.19704 .95634 Mdot
.25504 .88797 Mdot
.25959 .20138 Mdot
.15537 .86328 Mdot
.33407 .95369 Mdot
.19211 .88442 Mdot
.37576 .20882 Mdot
.40185 .01568 Mdot
.22188 .89209 Mdot
.59267 .8219 Mdot
.15842 .69888 Mdot
.27629 .8844 Mdot
.15397 .35686 Mdot
.22356 .88348 Mdot
.03886 .89124 Mdot
.34496 .85782 Mdot
.12315 .78576 Mdot
.2225 .6356 Mdot
.24011 .93326 Mdot
.80596 .6821 Mdot
.05854 .68347 Mdot
.54715 .10522 Mdot
.94471 .95468 Mdot
.28712 .84555 Mdot
.26234 .91014 Mdot
.21316 .88174 Mdot
.43231 .87993 Mdot
.14433 .84104 Mdot
.63777 .21951 Mdot
.45208 .01602 Mdot
.39556 .08184 Mdot
.70083 .68072 Mdot
.17893 .50032 Mdot
.2366 .24646 Mdot
.45486 .98094 Mdot
.38992 .76032 Mdot
.44744 .84957 Mdot
.30425 .91135 Mdot
.14079 .86068 Mdot
.23188 .85757 Mdot
.75153 .811 Mdot
.26752 .89978 Mdot
.23951 .92047 Mdot
.14431 .84598 Mdot
.97978 .82576 Mdot
.60075 .2443 Mdot
.37292 .56673 Mdot
.28689 .93163 Mdot
.33312 .97201 Mdot
.14585 .97142 Mdot
.1464 .36757 Mdot
.27088 .6265 Mdot
.26062 .90561 Mdot
.62939 .45633 Mdot
.25639 .91008 Mdot
.26503 .87252 Mdot
.33133 .69601 Mdot
.10983 .789 Mdot
.21979 .94143 Mdot
.17367 .86982 Mdot
.31565 .08526 Mdot
.2934 .13473 Mdot
.15567 .9825 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`04o`000?ooooooooooooooo`;o00002_ooool00ol0003oooooooooo`0:oooo
o`;o000000Coooooo`000?oooooooooo0_l00003ooooo`;o00001_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00;ooooo000Nooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool01?ooool2o`0000Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>oooo
o`04o`000?ooooooooooooooo`;o00002_ooool00ol0003oooooooooo`03ooooo`;o00001Oooool2
o`000004ooooool0003oooooooooo`;o00002oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00;ooooo000Nooooo`03o`000?oooooooooo02;ooooo0_l0000^ooooo`Co00003oooool2
o`000>3ooooo000Nooooo`03o`000?oooooooooo02;ooooo0_l0000Pooooo`;o00003?ooool3o`00
013ooooo0_l0000?ooooo`;o00002Oooool2o`0001Kooooo0_l0001aooooo`;o0000>Oooool001ko
oooo00?o0000ooooooooool02?ooool2o`0001cooooo0_l00005ooooo`Co00004oooool2o`0000go
oooo0_l00004ooooo`?o00006_ooool2o`0000Oooooo1?l0000<ooooo`;o00002?ooool2o`00077o
oooo0_l0000iooooo`007_ooool00ol0003oooooooooo`08ooooo`;o00003Oooool2o`0000gooooo
0_l00005ooooo`Co0000:?ooool3o`0001[ooooo0_l00007ooooo`?o00003Oooool2o`000;Kooooo
000Nooooo`03o`000?oooooooooo01Oooooo0_l0000Vooooo`;o00005?ooool2o`0001oooooo0_l0
003?ooooo`007_ooool00ol0003oooooooooo`0oooooo`;o00005?ooool2o`0009Gooooo0_l0000J
ooooo`;o0000?Oooool001kooooo00?o0000ooooooooool0k?ooool2o`0001[ooooo0_l0000moooo
o`007_ooool00ol0003oooooooooo`1Yooooo`;o0000E_ooool2o`0008Cooooo000Nooooo`03o`00
0?oooooooooo06Kooooo0_l000000ooooooo0000o`000005ooooo`;o00001Oooool2o`0004Sooooo
0_l00024ooooo`007_ooool00ol0003oooooooooo`0looooo`;o00003?ooool2o`0000Sooooo0_l0
000@ooooo`;o00002?ooool2o`0000Gooooo0_l0003>ooooo`007_ooool00ol0003oooooooooo`0l
ooooo`;o00003?ooool2o`0000Sooooo0_l0003aooooo`007_ooool00ol0003oooooooooo`0Uoooo
o`;o0000GOooool2o`0001_ooooo0_l0002Tooooo`007_ooool00ol0003oooooooooo`0Uooooo`;o
00009_ooool2o`0003Gooooo0_l0000>ooooo`;o00002oooool2o`000:Cooooo000Nooooo`03o`00
0?oooooooooo01[ooooo0_l0000aooooo`;o00003_ooool2o`0002Sooooo0_l0000;ooooo`;o0000
/Oooool001kooooo0_l0000=ooooo`;o00003?ooool2o`0003kooooo0_l000000ooooooo0000o`00
000Xooooo`;o0000=oooool2o`0008Gooooo000Nooooo`03o`000?oooooooooo00cooooo0_l00000
0ooooooo0000o`00000<ooooo`;o0000>oooool2o`0006Cooooo0_l00025ooooo`007_ooool00ol0
003oooooooooo`0?ooooo`;o00003?ooool2o`000?oooooo:Oooool001kooooo00?o0000oooooooo
ool0S_ooool2o`0005;ooooo0_l0001Sooooo`007_ooool00ol0003oooooooooo`2>ooooo`;o0000
D_ooool2o`0004Gooooo0_l0000Looooo`007_ooool00ol0003oooooooooo`0>ooooo`;o00003ooo
ool2o`0004Sooooo0_l0000Sooooo`;o00002oooool2o`0008cooooo0_l0000Looooo`007_ooool0
0ol0003oooooooooo`0>ooooo`;o00003oooool2o`0004Sooooo0_l0000Sooooo`;o00002oooool2
o`0004oooooo0_l0001Iooooo`007_ooool00ol0003oooooooooo`3/ooooo`;o0000FOooool001ko
oooo00?o0000ooooooooool0moooool2o`0004kooooo000Nooooo`03o`000?oooooooooo0?Oooooo
0_l0001>ooooo`007_ooool00ol0003oooooooooo`0Yooooo`;o0000>_ooool2o`0001Gooooo0_l0
0039ooooo`007_ooool00ol0003oooooooooo`0Yooooo`;o00007Oooool2o`0001Wooooo1?l0000E
ooooo`;o00002oooool2o`0006cooooo0_l0001>ooooo`007_ooool00ol0003oooooooooo`0`oooo
o`;o00005_ooool2o`0001;ooooo0_l00005ooooo`;o00009?ooool2o`0006cooooo0_l0001>oooo
o`007_ooool00ol0003oooooooooo`0`ooooo`;o0000:_ooool2o`0001?ooooo0_l0000Kooooo`;o
0000]oooool001kooooo00?o0000ooooooooool08_ooool2o`0001[ooooo0_l0000Qooooo`;o0000
3_ooool2o`0001_ooooo0_l0000^ooooo`;o0000Qoooool001kooooo00?o0000ooooooooool08_oo
ool2o`0001[ooooo0_l00007ooooo`;o00006?ooool2o`0005_ooooo0_l00027ooooo`007_ooool2
o`0004Sooooo0_l0000booooo`;o00005_ooool2o`000;;ooooo000Nooooo`03o`000?oooooooooo
04Wooooo0_l0000]ooooo`;o000000?oooooo`000?l000000_l0000Dooooo`;o00006Oooool2o`00
01?ooooo0_l00022ooooo`007_ooool00ol0003oooooooooo`0Zooooo`;o00007Oooool2o`0002go
oooo0_l00003ooooo`;o0000;oooool2o`0001?ooooo0_l00022ooooo`007_ooool00ol0003ooooo
ooooo`0Zooooo`;o0000F_ooool2o`000;oooooo000Nooooo`03o`000?oooooooooo08Kooooo0_l0
002oooooo`007_ooool00ol0003oooooooooo`0iooooo`;o0000ooooool=ooooo`007_ooool00ol0
003oooooooooo`0iooooo`;o0000f_ooool2o`00033ooooo000Nooooo`03o`000?oooooooooo06oo
oooo0_l00005ooooo`;o0000;Oooool2o`0006kooooo0_l0000`ooooo`007_ooool00ol0003ooooo
ooooo`0eooooo`;o0000;?ooool2o`0000[ooooo0_l00005ooooo`;o0000;Oooool2o`000:3ooooo
000Nooooo`03o`000?oooooooooo03Gooooo0_l0000/ooooo`;o0000h_ooool001kooooo00?o0000
ooooooooool00_ooool2o`0004Sooooo0_l0003iooooo`007_ooool00ol0003oooooooooo`02oooo
o`;o0000B?ooool2o`0000gooooo0_l0002oooooo`;o0000:Oooool001kooooo00?o0000oooooooo
ool0AOooool2o`0000gooooo0_l00005ooooo`;o00007oooool2o`0001Gooooo0_l00027ooooo`;o
0000:Oooool001kooooo00?o0000ooooooooool0AOooool2o`0000gooooo0_l0000Vooooo`;o0000
5Oooool2o`000;;ooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0003oooooocgooooo000N
ooooo`03o`000?oooooooooo00Oooooo1?l0003oooooocgooooo000Nooooo`;o00002?ooool2o`00
0?oooooo?oooool001kooooo00?o0000ooooooooool0>_ooool2o`0000kooooo0_l00008ooooo`;o
00001Oooool2o`000>[ooooo000Nooooo`03o`000?oooooooooo033ooooo0_l00008ooooo`;o0000
3_ooool2o`0000Sooooo0_l00005ooooo`;o0000j_ooool001kooooo00?o0000ooooooooool0<?oo
ool2o`000?oooooo5_ooool001kooooo00?o0000ooooooooool0j?ooool2o`0005gooooo000Noooo
o`03o`000?oooooooooo03[ooooo0_l0001Tooooo`;o0000A_ooool2o`0003?ooooo0_l0000Xoooo
o`007_ooool00ol0003oooooooooo`0jooooo`;o0000I?ooool2o`0007_ooooo0_l0000Xooooo`00
7_ooool00ol0003oooooooooo`22ooooo`;o00006?ooool2o`000:Wooooo000Nooooo`03o`000?oo
oooooooo08;ooooo0_l0000Hooooo`;o0000ZOooool001kooooo00?o0000ooooooooool0N_ooool2
o`000<_ooooo000Nooooo`03o`000?oooooooooo07[ooooo0_l0003;ooooo`007_ooool00ol0003o
ooooooooo`0Uooooo`;o0000oooooolQooooo`007_ooool00ol0003oooooooooo`0Uooooo`;o0000
KOooool2o`000;7ooooo000Nooooo`03o`000?oooooooooo06gooooo0_l0000Uooooo`;o00008?oo
ool2o`0008oooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0
0006ooooo`03o`000?oooooooooo06gooooo0_l00017ooooo`;o0000?Oooool2o`00053ooooo0003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A006ooooo`03o`000?oooooooooo03Wooooo0_l0000Vooooo`;o0000T_ooool2o`00053ooooo
0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`?o0000
>Oooool2o`0002Kooooo0_l0000Dooooo`;o0000c_ooool000?ooooo00Go0000oooooooooooooooo
o`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0<Oooool3o`0001cooooo
0_l0000@ooooo`;o00004oooool2o`0005Sooooo0_l0001dooooo`000oooool01Ol0003ooooooooo
oooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`0aooooo`?o0000
7?ooool2o`00013ooooo0_l0000Cooooo`;o0000BOooool2o`0000gooooo0_l0001dooooo`000ooo
ool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1fooooo`?o0000BOooool2o`0008?ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0>Oooool2o`0003_o
oooo0_l0000Sooooo`;o0000Z_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0booooo`;o00001Oooool2o`00
063ooooo0_l0002Zooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o00005_ooool2o`0009Oo
oooo0_l0001jooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o0000Boooool2o`0006;ooooo
0_l0001jooooo`007_ooool00ol0003oooooooooo`0gooooo`;o00008?ooool2o`0000cooooo0_l0
000Zooooo`;o0000/_ooool001kooooo00?o0000ooooooooool0=oooool3o`0001oooooo0_l0000h
ooooo`;o0000/_ooool001kooooo00?o0000ooooooooool00_ooool2o`0003Cooooo0_l00025oooo
o`;o0000Q_ooool001kooooo00?o0000ooooooooool00_ooool2o`0005[ooooo0_l0001Oooooo`;o
0000Q_ooool001kooooo00?o0000ooooooooool0C_ooool2o`0000kooooo0_l0000booooo`;o0000
/oooool001kooooo00?o0000ooooooooool0C_ooool2o`0000;ooooo0_l0000nooooo`;o0000/ooo
ool001kooooo00?o0000ooooooooool0?Oooool2o`0001?ooooo0_l0001[ooooo`;o0000Q_ooool0
01kooooo00?o0000ooooooooool0?Oooool2o`0000[ooooo0_l0000>ooooo`;o0000I?ooool2o`00
08Kooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l00015ooooo`;o00003_ooool2o`0001Oo
oooo0_l0000mooooo`;o0000U?ooool001kooooo0_l00003ooooo`;o0000K_ooool2o`0003gooooo
0_l0002Dooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0>Cooooo0_l0000Uooooo`;o0000>_ooool001kooooo00?o0000ooooooooool0i?ooool2o`00
02Gooooo0_l0000jooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`2Eooooo`;o0000/?ooool001kooooo00?o0000ooooooooool0DOooool2o`00
04;ooooo0_l0001Kooooo`;o0000Doooool001kooooo00?o0000ooooooooool0DOooool2o`0001oo
oooo0_l0001nooooo`;o0000Doooool001kooooo00?o0000ooooooooool0IOooool2o`0000_ooooo
0_l0003Cooooo`007_ooool00ol0003oooooooooo`0Fooooo`;o000000?oooooo`000?l00000B_oo
ool2o`00033ooooo0_l0002^ooooo`007_ooool00ol0003oooooooooo`0Fooooo`;o000000?ooooo
o`000?l00000O?ooool2o`000:kooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0Foooool2o`000>[ooooo000Nooooo`03o`000?oooooooooo02_ooooo
0_l0000^ooooo`;o0000S_ooool2o`0005[ooooo000Nooooo`;o0000;?ooool2o`0000[ooooo0_l0
002booooo`;o0000F_ooool001kooooo00?o0000ooooooooool0=oooool2o`000?oooooo3oooool0
01kooooo00?o0000ooooooooool0DOooool2o`000?Cooooo000Nooooo`03o`000?oooooooooo057o
oooo0_l0003dooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool03oooool2o`000?oooooo=oooool0
01kooooo00?o0000ooooooooool03oooool2o`000:gooooo0_l00027ooooo`007_ooool00ol0003o
ooooooooo`2nooooo`;o0000Qoooool001kooooo00?o0000ooooooooool0B_ooool2o`000?_ooooo
000Nooooo`03o`000?oooooooooo04[ooooo0_l0003kooooo`007_ooool00ol0003oooooooooo`10
ooooo`?o0000ooooool5ooooo`007_ooool00ol0003oooooooooo`0Tooooo`;o00006_ooool3o`00
0?oooooo1Oooool001kooooo00?o0000ooooooooool09?ooool2o`000?oooooo8_ooool001kooooo
00?o0000ooooooooool0G_ooool2o`000>Oooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0
001Cooooo`;o0000ioooool001kooooo0_l0000:ooooo`;o0000oooooolmooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo02kooooo0_l0001Looooo`;o
0000^Oooool001kooooo00?o0000ooooooooool03?ooool2o`00023ooooo0_l0001Looooo`;o0000
^Oooool001kooooo00?o0000ooooooooool03?ooool2o`0005Oooooo0_l0003Pooooo`007_ooool2
o`0006Kooooo0_l0003Pooooo`007_ooool2o`0002cooooo0_l0002eooooo`;o0000Hoooool001ko
oooo00?o0000ooooooooool0:oooool2o`000;Gooooo0_l0001Sooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0ooooool/ooooo`;o00006_ooool001kooooo00?o0000ooooooooool0G_ooool2o`00
06Sooooo0_l0001Qooooo`;o00006_ooool001kooooo00?o0000ooooooooool0??ooool2o`00023o
oooo0_l0001Xooooo`;o0000OOooool001kooooo00?o0000ooooooooool0??ooool2o`000?oooooo
2_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@
4?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
oooooom8ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`?o0000
oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo
00001oooool00ol0003oooooooooo`09ooooo`;o0000oooooolmooooo`000oooool01Ol0003ooooo
oooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`09oooo
o`;o0000Roooool2o`000:oooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omg
MgOoc<c<o`000007ooooo`03o`000?oooooooooo08gooooo0_l00007ooooo`;o0000[oooool000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000oooo
ooooool0Coooool2o`0003cooooo0_l0002hooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00gooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`1?ooooo`;o00006Oooool2o`00
0=_ooooo000Nooooo`03o`000?oooooooooo06[ooooo0_l0000Gooooo`;o0000`_ooool001kooooo
00?o0000ooooooooool0Poooool2o`000<;ooooo000Nooooo`03o`000?oooooooooo087ooooo0_l0
000fooooo`;o0000;Oooool2o`0005gooooo000Nooooo`03o`000?oooooooooo087ooooo0_l0000f
ooooo`;o0000;Oooool2o`0005gooooo000Nooooo`03o`000?oooooooooo08Gooooo0_l00030oooo
o`007_ooool00ol0003oooooooooo`25ooooo`;o0000`?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`1Mooooo`;o0000j?ooool001kooooo00?o0000
ooooooooool0GOooool2o`000>Sooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0ooooooleooooo`;o00004Oooool001kooooo0_l0003oooooocKooooo
0_l0000Aooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o0000_Oooool2o`0007cooooo000N
ooooo`03o`000?oooooooooo00[ooooo0_l0002mooooo`;o0000O?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0^?ooool2o`0007Wooooo0_l0
000Booooo`007_ooool00ol0003oooooooooo`06ooooo`;o0000@Oooool2o`000003ooooool0003o
000004[ooooo0_l0000Nooooo`;o0000NOooool2o`0001;ooooo000Nooooo`03o`000?oooooooooo
00Kooooo0_l0000aooooo`;o00003_ooool2o`000003ooooool0003o000001Sooooo0_l0000`oooo
o`;o0000=?ooool2o`0007Oooooo000Nooooo`03o`000?oooooooooo03Wooooo0_l0000[ooooo`;o
0000G_ooool2o`0000Kooooo0_l0001gooooo`007_ooool00ol0003oooooooooo`0cooooo`;o0000
Doooool2o`0003cooooo0_l0001oooooo`007_ooool00ol0003oooooooooo`0cooooo`;o0000Dooo
ool2o`000;gooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0J_ooool2o`0000_ooooo0_l0003>ooooo`007_ooool00ol0003oooooooooo`0_ooooo`;o
0000>Oooool2o`0000_ooooo0_l0003>ooooo`007_ooool00ol0003oooooooooo`0Xooooo`;o0000
1Oooool2o`0001Oooooo0_l0003mooooo`007_ooool2o`0002Wooooo0_l0000<ooooo`;o00004?oo
ool2o`0003Gooooo0_l00036ooooo`007_ooool00ol0003oooooooooo`0fooooo`;o0000Aoooool2
o`0000?ooooo0_l00031ooooo`007_ooool00ol0003oooooooooo`24ooooo`;o0000`Oooool001ko
oooo00?o0000ooooooooool0=_ooool2o`000?oooooo4?ooool001kooooo00?o0000ooooooooool0
<oooool2o`000003ooooool0003o00000?oooooo4?ooool001kooooo00?o0000ooooooooool0<ooo
ool2o`000?oooooo4oooool001kooooo00?o0000ooooooooool08_ooool2o`000?oooooo9?ooool0
01kooooo00?o0000ooooooooool08_ooool2o`000?oooooo9?ooool001kooooo00?o0000oooooooo
ool0oooooolNooooo`;o0000:?ooool001kooooo00?o0000ooooooooool0oooooolNooooo`;o0000
:?ooool001kooooo00?o0000ooooooooool0ooooool4ooooo`;o0000@_ooool001kooooo00?o0000
ooooooooool0JOooool2o`0005cooooo0_l0000jooooo`;o0000@_ooool001kooooo00?o0000oooo
ooooool0JOooool2o`0005cooooo0_l0001nooooo`007_ooool00ol0003oooooooooo`0Zooooo`;o
0000oooooolLooooo`007_ooool00ol0003oooooooooo`0Zooooo`;o00005Oooool2o`000?oooooo
1Oooool001kooooo00?o0000ooooooooool0@Oooool2o`00033ooooo0_l0001fooooo`;o0000F_oo
ool001kooooo0_l0001Vooooo`;o00003?ooool2o`0007Kooooo0_l0000oooooo`;o00006Oooool0
01kooooo00?o0000ooooooooool0D_ooool2o`00017ooooo0_l0000aooooo`;o0000=?ooool2o`00
02gooooo0_l0000]ooooo`;o00006Oooool001kooooo00?o0000ooooooooool01_ooool2o`0004[o
oooo0_l00014ooooo`;o0000=?ooool2o`0002gooooo0_l00018ooooo`007_ooool00ol0003ooooo
ooooo`06ooooo`;o0000>oooool2o`0001[ooooo0_l0000<ooooo`;o00001?ooool2o`000=;ooooo
000Nooooo`03o`000?oooooooooo04?ooooo0_l0000Jooooo`;o00003?ooool2o`0000Cooooo0_l0
003Booooo`007_ooool00ol0003oooooooooo`0Aooooo`;o0000H_ooool2o`000=3ooooo000Noooo
o`03o`000?oooooooooo00gooooo0_l00002ooooo`;o0000H_ooool2o`0002Cooooo0_l0001Ioooo
o`;o0000Coooool001kooooo00?o0000ooooooooool03Oooool2o`0003Oooooo0_l0001;ooooo`;o
00001_ooool2o`0005Wooooo0_l0001?ooooo`007_ooool00ol0003oooooooooo`16ooooo`;o0000
Boooool2o`0006Kooooo0_l0001:ooooo`007_ooool00ol0003oooooooooo`3kooooo`;o0000B_oo
ool001kooooo00?o0000ooooooooool05?ooool2o`0000Cooooo0_l0000Yooooo`;o0000ooooool1
ooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o00001?ooool2o`000003ooooool0003o0000
02Kooooo1?l0003nooooo`007_ooool00ol0003oooooooooo`03ooooo`;o000000?oooooo`000?l0
00003Oooool2o`0000Kooooo0_l0000Xooooo`;o0000T?ooool2o`0006cooooo000Nooooo`03o`00
0?oooooooooo00?ooooo0_l000000ooooooo0000o`00000=ooooo`;o0000NOooool2o`0004Oooooo
0_l0001Kooooo`;o00003oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool02Oooool2o`0008Go
oooo0_l0000>ooooo`;o0000U?ooool2o`0000oooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo
00Wooooo0_l0002Eooooo`;o0000YOooool000?ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000001_ooool3o`0002gooooo0_l0003ooooooaWooooo0003oooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o
0000ooooooooool0;Oooool2o`0001Wooooo0_l0000looooo`;o0000ZOooool2o`0001Cooooo0003
ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo
00?o0000ooooooooool07_ooool2o`0000Wooooo0_l0000Mooooo`;o0000??ooool2o`000:Wooooo
0_l0000Dooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
2?ooool00ol0003oooooooooo`0Nooooo`;o00002Oooool2o`000?oooooo7Oooool000?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0
oooooom8ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o
410@1_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo00;o0000
oooooolhooooo`;o00003?ooool001kooooo00?o0000ooooooooool00_l0001iooooo`;o0000_?oo
ool2o`0000cooooo000Nooooo`03o`000?oooooooooo05Gooooo0_l0000Cooooo`;o00003oooool2
o`000<[ooooo000Nooooo`03o`000?oooooooooo017ooooo0_l00011ooooo`?o00000oooool2o`00
00kooooo0_l0003Cooooo`;o00001_ooool001kooooo00?o0000ooooooooool04Oooool2o`0000?o
oooo0_l0000looooo`;o00001?ooool2o`000>?ooooo0_l00006ooooo`007_ooool00ol0003ooooo
ooooo`0Fooooo`;o0000Woooool2o`00047ooooo0_l0001;ooooo`007_ooool00ol0003ooooooooo
o`14ooooo`;o0000LOooool2o`00047ooooo0_l0001;ooooo`007_ooool00ol0003oooooooooo`14
ooooo`;o00000oooool2o`0002?ooooo0_l0003Gooooo`007_ooool01?l0003oooooo`000?l00018
ooooo`;o00008Oooool4o`000=Oooooo000Nooooo`04o`000?oooooo0000o`0006_ooooo0_l00022
ooooo`;o0000EOooool001kooooo00?o0000ooooooooool0JOooool2o`0008Gooooo0_l0001Eoooo
o`007_ooool2o`0001Kooooo0_l00016ooooo`;o00002_ooool2o`0000Kooooo0_l0002[ooooo`;o
00009oooool001kooooo00?o0000ooooooooool03Oooool3o`0000Gooooo0_l00016ooooo`;o0000
4_ooool2o`0001_ooooo0_l0002>ooooo`;o00009oooool001kooooo00?o0000ooooooooool03Ooo
ool3o`0007kooooo0_l0002gooooo`007_ooool00ol0003oooooooooo`1=ooooo`;o0000n?ooool0
01kooooo00?o0000ooooooooool00oooool2o`0003_ooooo0_l0000;ooooo`;o0000n?ooool001ko
oooo00?o0000ooooooooool00oooool2o`0003_ooooo0_l0003oooooo`Kooooo000Nooooo`03o`00
0?oooooooooo07gooooo0_l00038ooooo`007_ooool00ol0003oooooooooo`1mooooo`;o0000b?oo
ool001kooooo00?o0000ooooooooool0;?ooool2o`000<Kooooo0_l0001Aooooo`007_ooool00ol0
003oooooooooo`06ooooo`;o00009?ooool2o`0001Kooooo0_l0002Jooooo`;o00004_ooool2o`00
057ooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l00007ooooo`;o0000<oooool2o`0009[o
oooo0_l0000Pooooo`;o0000@oooool001kooooo00?o0000ooooooooool03oooool2o`0001[ooooo
0_l0003Eooooo`;o0000@oooool001kooooo00?o0000ooooooooool0:oooool3o`000?oooooo6_oo
ool001kooooo00?o0000ooooooooool0;?ooool2o`000?oooooo6_ooool001kooooo00?o0000oooo
ooooool0;oooool2o`0003Oooooo0_l0003Mooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o
00002_ooool2o`0003Oooooo0_l0003Mooooo`007_ooool2o`0001Sooooo0_l0000:ooooo`?o0000
1_ooool2o`000003ooooool0003o000007oooooo0_l0002Eooooo`007_ooool00ol0003ooooooooo
o`02ooooo`;o00004oooool2o`0000_ooooo0_l00006ooooo`;o00007?ooool2o`0004gooooo0ol0
000Dooooo`;o00008?ooool2o`0007?ooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l00016
ooooo`;o0000COooool3o`0003Kooooo0_l0001cooooo`007_ooool00ol0003oooooooooo`0>oooo
o`;o00004oooool2o`0000?ooooo0_l0001Iooooo`;o0000`_ooool001kooooo00?o0000oooooooo
ool03_ooool2o`0001?ooooo0_l00003ooooo`;o0000FOooool2o`000<;ooooo000Nooooo`03o`00
0?oooooooooo00?ooooo0_l0000:ooooo`;o00002oooool2o`00047ooooo0_l0000<ooooo`;o0000
Aoooool2o`0008oooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0000:ooooo`;o00002ooo
ool2o`00047ooooo0_l0000<ooooo`;o00008_ooool2o`0002?ooooo0_l0002?ooooo`007_ooool0
0ol0003oooooooooo`0/ooooo`;o0000<?ooool2o`0000Kooooo0_l0000Yooooo`;o0000[?ooool2
o`0000Kooooo000Nooooo`03o`000?oooooooooo02cooooo0_l00008ooooo`;o000000?oooooo`00
0?l000000oooool2o`0001kooooo0_l00006ooooo`;o0000Woooool2o`00033ooooo0_l00004oooo
o`;o00001_ooool001kooooo00?o0000ooooooooool06oooool2o`0001Wooooo0_l000000ooooooo
0000o`000003ooooo`;o00006_ooool2o`00013ooooo0_l0002Iooooo`;o0000<?ooool2o`0000co
oooo000Nooooo`03o`000?oooooooooo00kooooo0_l0000;ooooo`;o00002oooool2o`00033ooooo
0_l0000@ooooo`;o0000fOooool001kooooo00?o0000ooooooooool03_ooool2o`0001?ooooo0_l0
0003ooooo`?o00002?ooool2o`0001_ooooo0_l0003eooooo`007_ooool00ol0003oooooooooo`0S
ooooo`;o000000Coooooo`000?l0003ooooo0_l00008ooooo`;o00003Oooool2o`0000Kooooo0_l0
0004ooooo`;o00007Oooool2o`000;Kooooo0_l0000Nooooo`007_ooool00ol0003oooooooooo`0O
ooooo`;o00001?ooool3o`0000Sooooo0_l0000;ooooo`;o00000oooool2o`0000Kooooo0_l00004
ooooo`;o00000_ooool2o`0001Wooooo0_l0002fooooo`;o00007_ooool001kooooo00?o0000oooo
ooooool07oooool2o`0000Cooooo0_l00009ooooo`?o00002_ooool2o`00017ooooo0_l00002oooo
o`;o0000lOooool001kooooo00?o0000ooooooooool0<Oooool2o`0004Wooooo1?l00014ooooo`;o
0000POooool001kooooo0_l00006ooooo`;o00008Oooool2o`0000kooooo0_l00006ooooo`;o0000
>_ooool4o`0004Cooooo0_l00021ooooo`007_ooool00ol0003oooooooooo`05ooooo`;o00008Ooo
ool2o`0000kooooo0_l00006ooooo`;o00009?ooool2o`000:cooooo0_l0000aooooo`007_ooool0
0ol0003oooooooooo`1>ooooo`;o00001?ooool2o`00013ooooo0_l0000Oooooo`;o0000Roooool2
o`00037ooooo000Nooooo`03o`000?oooooooooo04kooooo0_l00003ooooo`?o00003_ooool2o`00
01Gooooo0_l0000:ooooo`;o0000__ooool001kooooo00?o0000ooooooooool02?ooool2o`0004Wo
oooo0_l0000?ooooo`;o00005Oooool2o`000<[ooooo000Nooooo`03o`000?oooooooooo00Sooooo
0_l0000>ooooo`;o0000]Oooool2o`0001Wooooo0_l0001Kooooo`007_ooool00ol0003ooooooooo
o`0Hooooo`;o00001oooool2o`0000Gooooo0_l00006ooooo`Ko00004_ooool2o`0008Gooooo0_l0
000Iooooo`;o0000E?ooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo00gooooo0_l0000B
ooooo`;o00001Oooool2o`0000Kooooo1_l0000Booooo`;o00001oooool2o`0000Wooooo0_l0000/
ooooo`;o0000]?ooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo00gooooo0_l000000ooo
oooo0000o`00000Hooooo`;o00009Oooool2o`0000Wooooo0_l0000/ooooo`;o0000^oooool001ko
oooo00?o0000ooooooooool04?ooool2o`0000Sooooo0_l00009ooooo`Co000000?oooooo`000?l0
00001?ooool2o`0000Sooooo0_l0000Fooooo`;o000000?oooooo`000?l00000=_ooool2o`0004Ko
oooo0_l0001`ooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o00001_ooool2o`000003oooo
ool0003o000000?o00001_ooool2o`0000Sooooo0_l0000Fooooo`;o000000?oooooo`000?l00000
4oooool2o`00027ooooo0_l0000>ooooo`;o00008?ooool2o`0001Cooooo0_l0001`ooooo`007_oo
ool00ol0003oooooooooo`0Qooooo`Ko000000?oooooo`000?l000004?ooool2o`0002kooooo0_l0
000aooooo`;o00008?ooool2o`0004kooooo0_l0000fooooo`007_ooool00ol0003oooooooooo`0B
ooooo`;o00003Oooool5o`0002Oooooo0_l0000?ooooo`?o0000[_ooool2o`0001Gooooo0_l0000O
ooooo`007_ooool00ol0003oooooooooo`0Booooo`;o00002Oooool2o`000003ooooool0003o0000
00;o00005_ooool2o`000003ooooool0003o000000kooooo0_l0000:ooooo`;o00000oooool3o`00
04oooooo0_l0001dooooo`;o00007oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool07Oooool2
o`000003ooooool0003o000000;o00000oooool2o`00013ooooo0ol000000ooooooo0000o`00000J
ooooo`;o0000EOooool2o`0009Gooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo02;ooooo0_l0
0003ooooo`;o00001oooool2o`0000Oooooo0_l0000hooooo`;o00001oooool2o`0002Oooooo0_l0
002Pooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooooooooooo
o`000006ooooo`?o0000<?ooool2o`0000oooooo0_l0000Sooooo`;o00002oooool2o`0000Oooooo
0_l0000Wooooo`;o0000X?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b
<_nHV9SooooooiRHV?lb<S801_ooool00ol0003oooooooooo`11ooooo`;o00008oooool2o`000=oo
oooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<
00Kooooo00?o0000ooooooooool0:_ooool4o`0000[ooooo0_l0003oooooo`kooooo0003ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000
ooooooooool0:Oooool5o`0000[ooooo0_l0000?ooooo`;o0000o?ooool000?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003ooooooooo
o`0Eooooo`;o00004_ooool3o`0000?ooooo0_l0000Hooooo`;o00005_ooool4o`0008_ooooo0_l0
001Eooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@06ooooo`03o`000?oooooooooo01Gooooo0_l0000?ooooo`Ko000000?oooooo`000?l00000
0_l00004ooooo`;o00008oooool2o`0000Gooooo1?l0002;ooooo`;o0000EOooool001kooooo00?o
0000ooooooooool09_ooool9o`0000Kooooo0_l0000Pooooo`;o000000?oooooo`000?l000001ooo
ool2o`0000Wooooo0_l0002Looooo`;o0000>Oooool001kooooo00?o0000ooooooooool0:?ooool2
o`000004ooooool0003o0000o`0001;ooooo0_l00007ooooo`Co00002_ooool2o`0001Gooooo0_l0
000>ooooo`;o0000?Oooool2o`0000Sooooo0_l00013ooooo`;o0000>Oooool001kooooo00?o0000
ooooooooool09?ooool2o`0001Kooooo0_l00002ooooo`;o00001oooool4o`00037ooooo0_l0000m
ooooo`;o00002?ooool2o`0007kooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l0000@oooo
o`;o00001?ooool2o`0002;ooooo0_l00024ooooo`;o0000D_ooool3o`0000[ooooo000Nooooo`03
o`000?oooooooooo02Kooooo0_l0000>ooooo`;o00001?ooool2o`0000?ooooo0_l00006ooooo`;o
00000_ooool2o`0000Sooooo0_l00007ooooo`;o000000?oooooo`000?l000006?ooool2o`0006Oo
oooo0_l0001Booooo`?o00002_ooool001kooooo00?o0000ooooooooool09_ooool2o`0000;ooooo
0_l00002ooooo`Co00000_ooool2o`0000Kooooo0_l00002ooooo`?o00001_ooool2o`0000;ooooo
0_l000000ooooooo0000o`000005ooooo`?o00002Oooool2o`0000Gooooo0_l00008ooooo`;o0000
1oooool2o`00097ooooo0_l0000eooooo`007_ooool00ol0003oooooooooo`0Uooooo`;o00000ooo
ool9o`000003ooooool0003o000000Kooooo0_l00002ooooo`;o00001?ooool2o`0000Sooooo0_l0
0005ooooo`?o00004?ooool2o`0000Sooooo0_l0000=ooooo`;o0000COooool2o`0003cooooo0_l0
000eooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o00000oooool4o`0000;ooooo1Ol00000
0ooooooo0000o`00000;ooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo0_l00003
ooooo`;o00001Oooool2o`000003ooooool0003o000002Oooooo0_l00008ooooo`;o0000@oooool2
o`00067ooooo0_l0000@ooooo`007_ooool00ol0003oooooooooo`0Pooooo`?o00000_ooool4o`00
00;ooooo1Ol000000ooooooo0000o`000002o`0000Wooooo0_l000000ooooooo0000o`000002oooo
o`;o00001?ooool2o`0000[ooooo1Ol000000ooooooo0000o`00000Tooooo`;o00002?ooool2o`00
00;ooooo0_l0001Nooooo`;o0000@_ooool3o`0000oooooo000Nooooo`03o`000?oooooooooo027o
oooo0_l00002ooooo`[o00001?ooool2o`0000[ooooo0_l00004ooooo`;o000000?oooooo`000?l0
00000_l00009ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0002Sooooo0_l00008oooo
o`;o0000G_ooool2o`0004?ooooo0_l0000?ooooo`007_ooool00ol0003oooooooooo`0Qooooo`;o
00000oooool9o`00013ooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000;o
00000_ooool2o`000004ooooool0003o0000ooooo`?o00000_ooool2o`0000;ooooo0ol00008oooo
o`;o00007Oooool2o`0000Cooooo0_l0002aooooo`;o00001Oooool001kooooo0_l0000;ooooo`;o
00005_ooool2o`0000Cooooo2?l0000Booooo`?o00000_ooool4o`0000?ooooo0_l000001?oooooo
0000o`000?ooool2o`0000Oooooo0ol000000ooooooo0000o`000005ooooo`;o00002oooool2o`00
00;ooooo0_l0000Booooo`;o0000/Oooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo00[o
oooo0_l00008ooooo`;o00003?ooool4o`0000;ooooo2?l00009ooooo`;o00003?ooool4o`0000?o
oooo0_l000000ooooooo0000o`00000;ooooo`Go00004_ooool2o`0000;ooooo0_l0003<ooooo`00
7_ooool00ol0003oooooooooo`0Dooooo`;o00003_ooool8o`0000gooooo0_l00007ooooo`?o0000
0_ooool4o`0000?ooooo0_l00007ooooo`;o00001_ooool2o`000003ooooool0003o000000Sooooo
0_l0000/ooooo`?o00004oooool2o`0000Oooooo0_l0001<ooooo`;o0000?_ooool001kooooo00?o
0000ooooooooool07Oooool2o`0000Gooooo2_l00005ooooo`;o00003Oooool3o`0000;ooooo1?l0
0006ooooo`;o00001?ooool4o`0000Oooooo0_l00004ooooo`;o00000_ooool2o`0001oooooo0_l0
000;ooooo`?o00004oooool2o`0000Oooooo0_l0001<ooooo`;o0000?_ooool001kooooo00?o0000
ooooooooool07Oooool2o`0000Gooooo3?l00002ooooo`?o000000?oooooo`000?l000002Oooool2
o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo0_l00002
ooooo`;o00001Oooool2o`0000Kooooo0_l0000Iooooo`;o00002?ooool2o`000;Sooooo000Noooo
o`03o`000?oooooooooo01Sooooo0_l0000:ooooo`Co00000_ooool2o`0000;ooooo1_l00002oooo
o`;o00001Oooool6o`0000?ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00001Oooool3
o`0000Sooooo0_l0000Qooooo`;o0000`_ooool001kooooo0_l0000Iooooo`;o00001_ooool3o`00
0003ooooool0003o000000Sooooo1?l00002ooooo`;o00000_ooool2o`0000?ooooo1Ol0000;oooo
o`?o00001_ooool2o`0000Oooooo1Ol0003Sooooo`007_ooool2o`00027ooooo0ol0000;ooooo`;o
00001?ooool2o`0000;ooooo0ol00002ooooo`Co00000oooool4o`0000;ooooo0_l00002ooooo`;o
00000_ooool2o`0000;ooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000000Ko
oooo0_l0001iooooo`;o0000BOooool2o`0000Wooooo0_l0000:ooooo`007_ooool00ol0003ooooo
ooooo`0Pooooo`;o00003_ooool2o`0000Oooooo0_l00002ooooo`Co000000?oooooo`000?l00000
1?l00002ooooo`;o00001_ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l00000
3_ooool2o`000003ooooool0003o000000Oooooo0_l00011ooooo`;o0000:_ooool2o`0004Wooooo
0_l00009ooooo`;o00002_ooool001kooooo00?o0000ooooooooool0<?ooool2o`0000Wooooo1_l0
00001?oooooo0000o`000?l00002ooooo`;o00001?ooool4o`000004ooooool0003o0000ooooo`Co
00003Oooool2o`0000Gooooo0_l00002ooooo`Co000000?oooooo`000?l000004?ooool2o`0002oo
oooo0_l0001]ooooo`;o00007Oooool001kooooo00?o0000ooooooooool05?ooool2o`0001_ooooo
0_l00008ooooo`;o000000Coooooo`000?l0003ooooo0ol000000ooooooo0000o`000002o`0000Co
oooo1?l000000ooooooo0000o`000002ooooo`;o00001?ooool2o`0000Sooooo0_l00003ooooo`;o
00001?ooool5o`0000;ooooo0_l0000>ooooo`;o0000W_ooool2o`0001gooooo000Nooooo`03o`00
0?oooooooooo01Cooooo0_l00007ooooo`;o00003_ooool2o`0000;ooooo0_l000000ooooooo0000
o`000002ooooo`Oo00000_ooool3o`000003ooooool0003o000000Gooooo1?l00006ooooo`;o0000
1?ooool3o`0000Kooooo0_l00004ooooo`;o00001oooool2o`0000;ooooo0_l0001:ooooo`;o0000
4oooool2o`0006cooooo000Nooooo`03o`000?oooooooooo00Gooooo0_l00009ooooo`;o00002ooo
ool4o`0000cooooo0_l00005ooooo`;o00000_ooool4o`000003ooooool0003o000000Oooooo0_l0
0003ooooo`Ko00001Oooool2o`000003ooooool0003o000000;ooooo0_l00003ooooo`;o000000?o
ooooo`000?l000002_ooool2o`0000[ooooo0_l00015ooooo`;o00004oooool2o`0001Gooooo0_l0
001;ooooo`;o00002?ooool001kooooo0_l00006ooooo`;o00000_ooool2o`0000Gooooo0_l0000=
ooooo`;o00007oooool2o`0000;ooooo1?l00003ooooo`So00001_ooool2o`0000;ooooo0_l00003
ooooo`?o00003?ooool2o`0000[ooooo0_l0000Mooooo`;o00009oooool2o`0002Wooooo0_l0001;
ooooo`;o00002?ooool001kooooo0_l0000:ooooo`;o00008Oooool2o`0000Wooooo0_l00007oooo
o`;o00000_ooool3o`0000Oooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00003?ooool2
o`0000Gooooo0_l00002ooooo`;o00003Oooool2o`0001gooooo0_l0000Wooooo`;o0000P?ooool0
01kooooo00?o0000ooooooooool05oooool2o`0001?ooooo0_l00009ooooo`;o00002_ooool2o`00
00Gooooo0_l00006ooooo`;o000000?oooooo`000?l000004oooool2o`0000;ooooo0_l000000ooo
oooo0000o`000003ooooo`;o00002oooool2o`000<;ooooo000Nooooo`;o00006?ooool2o`0000Oo
oooo0_l0000Booooo`;o00003Oooool5o`000003ooooool0003o000000;o000000?oooooo`000?l0
00000oooool2o`00017ooooo0_l00009ooooo`Oo00002oooool2o`0005Gooooo0_l0001[ooooo`00
7_ooool00ol0003oooooooooo`0Pooooo`;o00002oooool2o`0000Gooooo1?l00003ooooo`;o0000
1oooool4o`000003ooooool0003o000000Go000000?oooooo`000?l000000ol0000;ooooo`;o0000
0oooool2o`0000_ooooo1?l0000Oooooo`;o000000?oooooo`000?l00000?oooool2o`0001Kooooo
0_l0001Cooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o00002?ooool2o`0000Oooooo0_l0
0003ooooo`;o00000_ooool2o`0000Oooooo0ol00002ooooo`;o00000_ooool2o`000003ooooool0
003o000000_ooooo0_l0000Booooo`;o00007oooool2o`000003ooooool0003o000005Oooooo0_l0
000Xooooo`;o0000:Oooool001kooooo00?o0000ooooooooool03?ooool2o`0001Gooooo0_l0000J
ooooo`;o00000_ooool2o`0000?ooooo0ol00004ooooo`Oo00002Oooool2o`000003ooooool0003o
000000oooooo1?l0002Uooooo`;o0000:Oooool001kooooo00?o0000ooooooooool03?ooool2o`00
00Sooooo0_l0000Jooooo`;o000000?oooooo`000?l000003?ooool2o`000003ooooool0003o0000
00Oooooo2?l00005ooooo`;o000000Coooooo`000?l0003ooooo0ol0000:ooooo`;o00000_ooool4
o`0000[ooooo0_l0000Dooooo`;o0000[_ooool001kooooo00?o0000ooooooooool05_ooool2o`00
01Wooooo0ol000000ooooooo0000o`000002o`0000Cooooo0_l00003ooooo`;o00000_ooool2o`00
00Sooooo1ol00005ooooo`;o00001Oooool2o`0000[ooooo0_l00002ooooo`;o00003?ooool2o`00
01Cooooo0_l0002^ooooo`007_ooool00ol0003oooooooooo`0Qooooo`;o00003_ooool2o`0000Co
oooo0_l00004ooooo`;o00000oooool2o`0000Kooooo0_l00004ooooo`Go00001?ooool2o`00017o
oooo0_l0001Iooooo`;o0000O_ooool001kooooo00Co0000ooooool0003o00008?ooool2o`00013o
oooo0_l00003ooooo`;o00004?ooool3o`0000;ooooo0_l00002ooooo`Co000000Coooooo`000?l0
003o00002?ooool2o`0000Oooooo0_l0000?ooooo`Co0000A_ooool2o`0007kooooo000Nooooo`04
o`000?oooooo0000o`0002?ooooo0_l0000=ooooo`;o00000oooool2o`0000gooooo0_l00002oooo
o`;o00000_ooool2o`000003ooooool0003o000000?o000000?oooooo`000?l000000_l00007oooo
o`;o00002_ooool3o`0000_ooooo1?l000000ooooooo0000o`00000Eooooo`;o0000ROooool2o`00
00Gooooo0_l0000Jooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o00002_ooool2o`0000Wo
oooo0_l0000Fooooo`;o00000_ooool6o`000003ooooool0003o000000;o00000oooool3o`00017o
oooo1Ol0000:ooooo`;o00001?ooool2o`0000Kooooo0_l0000=ooooo`;o0000?oooool2o`0004So
oooo0_l00005ooooo`;o00006_ooool001kooooo00?o0000ooooooooool06?ooool2o`0001Gooooo
0ol0000Hooooo`Go00000_ooool2o`000004ooooool0003o0000o`0000;ooooo1_l00008ooooo`;o
00001?ooool2o`0000gooooo0_l00008ooooo`;o00000_ooool2o`0000Oooooo0_l00015ooooo`;o
0000Joooool001kooooo00?o0000ooooooooool0<?ooool2o`0001Sooooo0_l000000ooooooo0000
o`000004o`0000;ooooo0_l00002ooooo`Ko00002?ooool4o`0001_ooooo0_l0000;ooooo`;o0000
/_ooool001kooooo00?o0000ooooooooool07Oooool2o`0002Oooooo0ol00005ooooo`Go00001_oo
ool2o`000003ooooool0003o000000Cooooo0_l00005ooooo`;o00006_ooool2o`000<3ooooo000N
ooooo`03o`000?oooooooooo01gooooo0_l0000Tooooo`[o000000Coooooo`000?l0003ooooo0_l0
0006ooooo`;o000000?oooooo`000?l000001?ooool2o`00013ooooo0_l0000?ooooo`;o0000Sooo
ool2o`0002Cooooo0_l00009ooooo`007_ooool3o`0002Kooooo0_l0000:ooooo`;o00002oooool2
o`0000;ooooo1Ol000000ooooooo0000o`000002o`0000;ooooo0_l0000Dooooo`;o00001oooool2
o`0000Cooooo0_l0000<ooooo`;o0000T_ooool2o`0002Cooooo0_l00009ooooo`007_ooool3o`00
02Kooooo0_l0000:ooooo`;o00002oooool2o`000003ooooool0003o000000_ooooo0_l000001?oo
oooo0000o`000?ooool2o`0000kooooo0_l00005ooooo`Co00001?ooool2o`0000cooooo0_l00033
ooooo`007_ooool2o`0004?ooooo0_l0000>ooooo`;o000000?oooooo`000?l000005Oooool3o`00
00Gooooo0_l0002>ooooo`;o0000=?ooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo013o
oooo0_l0000;ooooo`;o00008?ooool2o`0000Sooooo1?l00008ooooo`;o00000oooool2o`0000co
oooo0_l00003ooooo`;o00005oooool2o`0001[ooooo0_l0001Pooooo`;o0000:Oooool2o`0000Wo
oooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o00002oooool2o`00013ooooo
0_l00007ooooo`;o00000_ooool2o`000003ooooool0003o000000Sooooo1?l00004ooooo`;o0000
1?ooool2o`000003ooooool0003o000000Wooooo0_l000000ooooooo0000o`00000Looooo`;o0000
6_ooool2o`0008_ooooo0_l0000Fooooo`007_ooool00ol0003oooooooooo`0_ooooo`;o00001ooo
ool2o`0000;ooooo0_l00004ooooo`;o00001_ooool2o`0000Gooooo0_l00004ooooo`;o000000?o
ooooo`000?l000001_ooool2o`000003ooooool0003o00000>3ooooo000Nooooo`03o`000?oooooo
oooo02Gooooo0_l0000Gooooo`;o00000_ooool2o`0000Kooooo1?l00009ooooo`;o00000_ooool2
o`0000Gooooo1ol00004ooooo`;o0000f?ooool001kooooo00?o0000ooooooooool09Oooool2o`00
01Oooooo0_l00008ooooo`;o00000_ooool2o`0000Gooooo0_l00002ooooo`;o00000_ooool2o`00
0003ooooool0003o000000?ooooo1_l00004ooooo`;o0000f?ooool001kooooo00?o0000oooooooo
ool0A?ooool2o`0000;ooooo0_l00004ooooo`;o00000oooool2o`0000;ooooo0_l00005ooooo`Co
00002Oooool2o`000=[ooooo000Nooooo`03o`000?oooooooooo02_ooooo0_l0000Gooooo`;o0000
0_ooool3o`0000?ooooo0_l00007ooooo`;o00001Oooool4o`0000Kooooo0_l000000ooooooo0000
o`00003Jooooo`007_ooool00ol0003oooooooooo`0Wooooo`;o00000_ooool2o`0001cooooo0_l0
000<ooooo`;o00001Oooool2o`0000Sooooo0_l0002nooooo`;o00007Oooool001kooooo00?o0000
ooooooooool09oooool2o`0000Wooooo0_l0000Uooooo`Co0000Z_ooool2o`0001oooooo0_l0000M
ooooo`007_ooool00ol0003oooooooooo`0Wooooo`;o00001Oooool2o`0000;ooooo0_l000000ooo
oooo0000o`000002ooooo`?o00007Oooool4o`0003?ooooo0_l0001Nooooo`;o00005Oooool2o`00
03kooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l00005ooooo`;o00001Oooool2o`0000;o
oooo0ol0000oooooo`;o00004oooool2o`0005kooooo0_l0001Eooooo`007_ooool00ol0003ooooo
ooooo`0Wooooo`;o0000;_ooool3o`0001cooooo0_l00003ooooo`;o0000b_ooool001kooooo00?o
0000ooooooooool0Boooool2o`0000[ooooo0ol0000Looooo`;o0000coooool001Cooooo1?l00000
0ol@413oooooooooo`03ooooo`03o`000?oooooooooo01Wooooo0_l0000Fooooo`;o00001_ooool2
o`0000[ooooo0ol00003ooooo`;o0000n_ooool001Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Iooooo`;o00005_ooool2o`0000Kooooo0_l0000:ooooo`?o00004oooool2o`00
01Gooooo0_l0000mooooo`;o0000U?ooool001Kooooo00?o0000ooooooooool01Oooool3o`00023o
oooo0_l0000]ooooo`;o00001Oooool2o`0000?ooooo0_l0000Eooooo`;o0000?Oooool2o`0009Co
oooo000Fooooo`03o`000?oooooooooo02Sooooo0_l0000]ooooo`;o00001Oooool2o`000>oooooo
000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@
ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Dooooo`03oeEEEOmVIVKo00000?oo
ooooD_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.28664 .88332 Mdot
.40993 .74714 Mdot
.22164 .93948 Mdot
.26463 .97029 Mdot
.12254 .83585 Mdot
.19837 .90039 Mdot
.22833 .25204 Mdot
.15375 .86605 Mdot
.29476 .9053 Mdot
.19907 .44822 Mdot
.13991 .77966 Mdot
.2996 .71229 Mdot
.15295 .86653 Mdot
.83724 .82137 Mdot
.19216 .85263 Mdot
.36348 .54913 Mdot
.4873 .85562 Mdot
.30296 .88789 Mdot
.29913 .91068 Mdot
.27764 .92371 Mdot
.36629 .80194 Mdot
.28775 .82524 Mdot
.25745 .91565 Mdot
.37524 .70326 Mdot
.25223 .91618 Mdot
.14495 .86537 Mdot
.28063 .89964 Mdot
.18879 .02319 Mdot
.18854 .74116 Mdot
.29462 .87958 Mdot
.29785 .93083 Mdot
.19266 .86044 Mdot
.19165 .89146 Mdot
.28543 .18982 Mdot
.31023 .63352 Mdot
.16473 .83737 Mdot
.27369 .83554 Mdot
.53396 .86755 Mdot
.33997 .75508 Mdot
.26377 .95084 Mdot
.31176 .94679 Mdot
.08312 .69664 Mdot
.30456 .03085 Mdot
.13565 .73866 Mdot
.03593 .63328 Mdot
.12062 .74491 Mdot
.57361 .18245 Mdot
.23927 .80927 Mdot
.14692 .89771 Mdot
.43511 .12594 Mdot
.44828 .89382 Mdot
.35657 .81862 Mdot
.09865 .84114 Mdot
.17028 .71888 Mdot
.14275 .85115 Mdot
.4334 .60841 Mdot
.82362 .96922 Mdot
.11282 .85589 Mdot
.27792 .89386 Mdot
.99739 .86995 Mdot
.20977 .94246 Mdot
.19073 .86256 Mdot
.26908 .05975 Mdot
.21917 .8746 Mdot
.16964 .92257 Mdot
.27067 .86958 Mdot
.32674 .88044 Mdot
.28139 .89872 Mdot
.18353 .88077 Mdot
.46225 .90021 Mdot
.74447 .84618 Mdot
.35062 .87778 Mdot
.93767 .95762 Mdot
.22909 .68005 Mdot
.1333 .9494 Mdot
.83831 .01313 Mdot
.32726 .96815 Mdot
.72702 .11477 Mdot
.23944 .87643 Mdot
.30052 .00284 Mdot
.18022 .78593 Mdot
.70237 .2888 Mdot
.39055 .34394 Mdot
.16997 .8579 Mdot
.06969 .9077 Mdot
.91894 .58687 Mdot
.12844 .86546 Mdot
.25269 .96474 Mdot
.17954 .86482 Mdot
.29734 .90164 Mdot
.1491 .75619 Mdot
.09267 .54811 Mdot
.34648 .80349 Mdot
.61395 .73258 Mdot
.04103 .85646 Mdot
.29454 .71146 Mdot
.32726 .24846 Mdot
.26589 .5927 Mdot
.10391 .77778 Mdot
.25594 .16941 Mdot
.24373 .84902 Mdot
.36925 .91508 Mdot
.01415 .91662 Mdot
.34177 .05403 Mdot
.34757 .82917 Mdot
.25161 .88031 Mdot
.21951 .14032 Mdot
.2443 .08405 Mdot
.307 .02566 Mdot
.338 .20568 Mdot
.29174 .86563 Mdot
.75711 .28751 Mdot
.10924 .8342 Mdot
.2861 .88782 Mdot
.0922 .99019 Mdot
.13148 .64015 Mdot
.02106 .60479 Mdot
.17862 .86536 Mdot
.28201 .04716 Mdot
.17717 .7543 Mdot
.28052 .93093 Mdot
.27122 .96865 Mdot
.12064 .99151 Mdot
.25084 .05029 Mdot
.0551 .8407 Mdot
.44256 .45941 Mdot
.49552 .85607 Mdot
.30708 .89634 Mdot
.56758 .9796 Mdot
.09553 .93046 Mdot
.23777 .52967 Mdot
.74022 .27343 Mdot
.25602 .60466 Mdot
.33253 .8969 Mdot
.34494 .90651 Mdot
.39149 .94681 Mdot
.25526 .88018 Mdot
.4685 .02063 Mdot
.33827 .90679 Mdot
.24938 .90543 Mdot
.35305 .88786 Mdot
.18863 .85094 Mdot
.27543 .82829 Mdot
.26944 .21559 Mdot
.7291 .87951 Mdot
.2957 .69853 Mdot
.24956 .87205 Mdot
.2658 .8842 Mdot
.88098 .93118 Mdot
.45871 .48939 Mdot
.15231 .71005 Mdot
.22214 .89688 Mdot
.30371 .71943 Mdot
.27176 .92133 Mdot
.21615 .85515 Mdot
.1404 .83174 Mdot
.35942 .94197 Mdot
.96484 .36608 Mdot
.28828 .93196 Mdot
.37187 .49604 Mdot
.44467 .06167 Mdot
.20488 .67645 Mdot
.60163 .41791 Mdot
.29918 .93668 Mdot
.10843 .79205 Mdot
.11748 .81518 Mdot
.25435 .89868 Mdot
.2672 .92859 Mdot
.00069 .3787 Mdot
.24048 .8048 Mdot
.21083 .89527 Mdot
.04061 .69469 Mdot
.28798 .62728 Mdot
.74045 .61226 Mdot
.16106 .80303 Mdot
.29826 .82116 Mdot
.39807 .69841 Mdot
.10945 .90405 Mdot
.18646 .40502 Mdot
.36383 .80002 Mdot
.25082 .87222 Mdot
.17174 .78727 Mdot
.15182 .73477 Mdot
.02437 .69232 Mdot
.2456 .31801 Mdot
.37014 .95501 Mdot
.34533 .57968 Mdot
.14057 .7332 Mdot
.3048 .01221 Mdot
.13919 .86378 Mdot
.22309 .84628 Mdot
.57804 .70629 Mdot
.31098 .8941 Mdot
.49217 .95674 Mdot
.10178 .64009 Mdot
.19669 .89127 Mdot
.19209 .7471 Mdot
.2517 .88215 Mdot
.29475 .89708 Mdot
.14334 .98954 Mdot
.57045 .11815 Mdot
.76189 .55848 Mdot
.34927 .91193 Mdot
.08297 .54654 Mdot
.24727 .90942 Mdot
.25013 .97173 Mdot
.64861 .45772 Mdot
.26302 .91427 Mdot
.78831 .86192 Mdot
.27782 .87198 Mdot
.19636 .78285 Mdot
.32958 .86079 Mdot
.09444 .23182 Mdot
.30319 .33503 Mdot
.4489 .03553 Mdot
.33942 .41003 Mdot
.2469 .93904 Mdot
.26254 .79405 Mdot
.20314 .16396 Mdot
.04396 .60584 Mdot
.7597 .80117 Mdot
.96847 .84338 Mdot
.1443 .81124 Mdot
.24918 .9191 Mdot
.24368 .88385 Mdot
.35541 .90391 Mdot
.07024 .9934 Mdot
.30476 .99834 Mdot
.31176 .61075 Mdot
.29239 .82799 Mdot
.15261 .83385 Mdot
.02806 .86345 Mdot
.2414 .85329 Mdot
.06435 .23671 Mdot
.42118 .49394 Mdot
.66905 .79955 Mdot
.60772 .15478 Mdot
.25499 .92842 Mdot
.31679 .6834 Mdot
.62402 .69337 Mdot
.19761 .83728 Mdot
.25632 .83599 Mdot
.31544 .04723 Mdot
.28065 .83209 Mdot
.36297 .77082 Mdot
.15803 .00489 Mdot
.00777 .78272 Mdot
.27055 .85249 Mdot
.13306 .04207 Mdot
.30628 .96229 Mdot
.35989 .90242 Mdot
.17926 .83969 Mdot
.07173 .84024 Mdot
.00768 .42877 Mdot
.08949 .50883 Mdot
.22751 .91988 Mdot
.10267 .82805 Mdot
.7768 .70862 Mdot
.2715 .87932 Mdot
.66585 .74842 Mdot
.31924 .87273 Mdot
.29287 .82678 Mdot
.25989 .05316 Mdot
.37695 .01895 Mdot
.25293 .84046 Mdot
.80097 .1242 Mdot
.2816 .00104 Mdot
.30298 .58788 Mdot
.22214 .90714 Mdot
.28429 .93109 Mdot
.1031 .7835 Mdot
.54346 .79354 Mdot
.21247 .90278 Mdot
.28669 .83218 Mdot
.12332 .75776 Mdot
.20663 .83814 Mdot
.26814 .13082 Mdot
.00769 .07019 Mdot
.14081 .77111 Mdot
.41357 .94711 Mdot
.75869 .08028 Mdot
.29043 .82573 Mdot
.25969 .00642 Mdot
.06408 .83961 Mdot
.10937 .82208 Mdot
.15354 .82167 Mdot
.25536 .82518 Mdot
.25935 .24447 Mdot
.1917 .12838 Mdot
.439 .98425 Mdot
.31709 .10306 Mdot
.66523 .01901 Mdot
.31803 .94152 Mdot
.31426 .97346 Mdot
.06859 .60804 Mdot
.14331 .22321 Mdot
.14697 .90855 Mdot
.17611 .00196 Mdot
.12454 .90269 Mdot
.12881 .22368 Mdot
.41906 .95497 Mdot
.10746 .77746 Mdot
.2468 .61175 Mdot
.27994 .82183 Mdot
.66163 .5446 Mdot
.24824 .10804 Mdot
.27606 .89891 Mdot
.24492 .87025 Mdot
.19998 .32859 Mdot
.69415 .5553 Mdot
.2779 .92594 Mdot
.75121 .56583 Mdot
.15975 .86291 Mdot
.0098 .73153 Mdot
.18362 .903 Mdot
.1454 .98155 Mdot
.31073 .70204 Mdot
.62765 .89101 Mdot
.08347 .88157 Mdot
.17642 .37855 Mdot
.35639 .78374 Mdot
.18917 .92996 Mdot
.34938 .958 Mdot
.2459 .6305 Mdot
.31493 .90108 Mdot
.14626 .82965 Mdot
.13775 .78461 Mdot
.312 .85075 Mdot
.35053 .76875 Mdot
.17141 .83819 Mdot
.23899 .84655 Mdot
.19536 .89663 Mdot
.22751 .93068 Mdot
.48027 .71985 Mdot
.18857 .82846 Mdot
.25512 .2052 Mdot
.81273 .67655 Mdot
.28993 .91335 Mdot
.24082 .39401 Mdot
.98058 .79394 Mdot
.11565 .80241 Mdot
.33395 .25582 Mdot
.35289 .85395 Mdot
.21093 .79115 Mdot
.38634 .59625 Mdot
.0715 .63298 Mdot
.17879 .02795 Mdot
.10677 .364 Mdot
.03579 .78612 Mdot
.14449 .87214 Mdot
.19715 .88425 Mdot
.11628 .82417 Mdot
.14363 .62327 Mdot
.38759 .48936 Mdot
.4505 .34183 Mdot
.20934 .91464 Mdot
.22845 .75012 Mdot
.294 .00836 Mdot
.14011 .86791 Mdot
.03005 .79889 Mdot
.2863 .82821 Mdot
.11804 .81368 Mdot
.31078 .93375 Mdot
.19893 .78379 Mdot
.13189 .79007 Mdot
.2938 .90004 Mdot
.41849 .63896 Mdot
.30949 .30933 Mdot
.03428 .29119 Mdot
.23426 .86366 Mdot
.47556 .09417 Mdot
.26864 .90334 Mdot
.24683 .93696 Mdot
.29007 .86467 Mdot
.65465 .90383 Mdot
.45672 .51778 Mdot
.09941 .77521 Mdot
.1884 .94203 Mdot
.12944 .82178 Mdot
.30345 .88524 Mdot
.23045 .88128 Mdot
.22953 .84244 Mdot
.48964 .18006 Mdot
.19127 .44441 Mdot
.1677 .16827 Mdot
.44178 .00458 Mdot
.52074 .8599 Mdot
.35034 .06889 Mdot
.2877 .91067 Mdot
.24675 .96859 Mdot
.35323 .88538 Mdot
.16538 .82602 Mdot
.19711 .85532 Mdot
.11761 .86167 Mdot
.12446 .85264 Mdot
.54467 .80301 Mdot
.5624 .80521 Mdot
.77141 .92658 Mdot
.27908 .89454 Mdot
.31158 .90865 Mdot
.37375 .04636 Mdot
.02334 .56035 Mdot
.02302 .50114 Mdot
.18921 .86087 Mdot
.49729 .05539 Mdot
.36009 .79629 Mdot
.4136 .0315 Mdot
.31752 .88258 Mdot
.2329 .73365 Mdot
.29693 .92761 Mdot
.50852 .05859 Mdot
.28861 .93481 Mdot
.4546 .0459 Mdot
.57134 .23583 Mdot
.68535 .73518 Mdot
.27939 .86154 Mdot
.03947 .0095 Mdot
.37997 .94348 Mdot
.02594 .591 Mdot
.24098 .87121 Mdot
.27788 .93571 Mdot
.58108 .00346 Mdot
.16931 .0586 Mdot
.18606 .82798 Mdot
.12315 .8524 Mdot
.22232 .56019 Mdot
.77357 .89811 Mdot
.29961 .86996 Mdot
.24875 .82039 Mdot
.65472 .77403 Mdot
.45694 .45202 Mdot
.54995 .04935 Mdot
.03808 .09851 Mdot
.23757 .82655 Mdot
.31299 .19868 Mdot
.90696 .85279 Mdot
.24737 .14905 Mdot
.20126 .44173 Mdot
.26826 .95237 Mdot
.04405 .63058 Mdot
.27137 .02035 Mdot
.17789 .00822 Mdot
.0526 .11334 Mdot
.20501 .91187 Mdot
.21487 .77691 Mdot
.22846 .89467 Mdot
.15069 .93977 Mdot
.1535 .80007 Mdot
.32656 .64629 Mdot
.18464 .05013 Mdot
.41923 .94676 Mdot
.28899 .07558 Mdot
.12805 .81606 Mdot
.23756 .89511 Mdot
.10396 .95885 Mdot
.2781 .9141 Mdot
.27647 .91933 Mdot
.15157 .75952 Mdot
.59147 .92428 Mdot
.43377 .1901 Mdot
.26749 .91514 Mdot
.25681 .94645 Mdot
.22569 .89258 Mdot
.12176 .91187 Mdot
.15802 .2004 Mdot
.25602 .54538 Mdot
.18863 .91366 Mdot
.91342 .5506 Mdot
.19824 .87684 Mdot
.20214 .8262 Mdot
.25326 .8625 Mdot
.15075 .87114 Mdot
.16863 .86377 Mdot
.16854 .86071 Mdot
.22155 .89202 Mdot
.20856 .86671 Mdot
.20283 .84387 Mdot
.13799 .84493 Mdot
.42545 .71007 Mdot
.20493 .9186 Mdot
.77511 .55524 Mdot
.50306 .80549 Mdot
.27984 .8225 Mdot
.36572 .87207 Mdot
.2876 .88151 Mdot
.899 .03859 Mdot
.06363 .38631 Mdot
.23889 .70449 Mdot
.9973 .708 Mdot
.19933 .07848 Mdot
.26087 .93335 Mdot
.27731 .93672 Mdot
.23848 .77465 Mdot
.49244 .75864 Mdot
.16283 .81646 Mdot
.25002 .89883 Mdot
.09857 .8347 Mdot
.10134 .95452 Mdot
.38749 .92646 Mdot
.29207 .67855 Mdot
.06476 .99145 Mdot
.12287 .02592 Mdot
.04864 .66068 Mdot
.47064 .10159 Mdot
.28457 .86403 Mdot
.92938 .83295 Mdot
.16447 .86916 Mdot
.89097 .01433 Mdot
.28234 .92531 Mdot
.32086 .90312 Mdot
.3643 .87689 Mdot
.66764 .53591 Mdot
.30689 .26141 Mdot
.27182 .87545 Mdot
.11673 .84259 Mdot
.73309 .87781 Mdot
.27295 .91456 Mdot
.31022 .57588 Mdot
.17784 .19984 Mdot
.33345 .88806 Mdot
.32064 .98929 Mdot
.1796 .91541 Mdot
.23535 .88008 Mdot
.13534 .98825 Mdot
.30743 .25022 Mdot
.37077 .91882 Mdot
.35482 .12459 Mdot
.76724 .70476 Mdot
.06844 .69537 Mdot
.53924 .78582 Mdot
.7972 .62077 Mdot
.00847 .79332 Mdot
.11146 .82559 Mdot
.41878 .78419 Mdot
.16592 .85054 Mdot
.25907 .85178 Mdot
.18432 .93153 Mdot
.19139 .83174 Mdot
.94768 .16002 Mdot
.651 .76614 Mdot
.24543 .90564 Mdot
.25427 .47173 Mdot
.25913 .72205 Mdot
.21661 .86175 Mdot
.29482 .94969 Mdot
.3199 .27833 Mdot
.52321 .48096 Mdot
.28354 .02812 Mdot
.27701 .92464 Mdot
.14834 .82618 Mdot
.27148 .96827 Mdot
.20484 .10094 Mdot
.19003 .85795 Mdot
.39864 .19201 Mdot
.25163 .94008 Mdot
.8249 .19993 Mdot
.2495 .73462 Mdot
.28931 .91585 Mdot
.18049 .81307 Mdot
.28128 .05446 Mdot
.2861 .90199 Mdot
.0631 .91049 Mdot
.58688 .89439 Mdot
.14155 .18995 Mdot
.25772 .83244 Mdot
.12978 .8527 Mdot
.44717 .09503 Mdot
.13635 .80865 Mdot
.9327 .44657 Mdot
.1822 .8706 Mdot
.01239 .72579 Mdot
.30111 .06668 Mdot
.20352 .87119 Mdot
.29955 .84672 Mdot
.1666 .84065 Mdot
.29251 .84763 Mdot
.07805 .52822 Mdot
.18456 .74888 Mdot
.20078 .85449 Mdot
.15504 .96966 Mdot
.07926 .67425 Mdot
.34936 .83279 Mdot
.23843 .80781 Mdot
.3586 .90202 Mdot
.10623 .98031 Mdot
.22015 .97138 Mdot
.32235 .99099 Mdot
.10882 .43646 Mdot
.26542 .12191 Mdot
.0437 .89951 Mdot
.12989 .84638 Mdot
.1268 .86281 Mdot
.22243 .76153 Mdot
.13218 .97053 Mdot
.36428 .7208 Mdot
.17678 .85662 Mdot
.26761 .94937 Mdot
.1555 .82613 Mdot
.19106 .93612 Mdot
.17935 .9322 Mdot
.28022 .84234 Mdot
.2693 .9191 Mdot
.25508 .93533 Mdot
.26177 .56828 Mdot
.21726 .19729 Mdot
.28679 .96897 Mdot
.27653 .92121 Mdot
.28837 .8372 Mdot
.4549 .16357 Mdot
.30081 .88399 Mdot
.09195 .88641 Mdot
.16859 .53062 Mdot
.19973 .87184 Mdot
.66472 .67869 Mdot
.30054 .88903 Mdot
.3206 .42121 Mdot
.31658 .86194 Mdot
.02038 .76555 Mdot
.1178 .76974 Mdot
.5176 .19221 Mdot
.97404 .14475 Mdot
.02901 .68573 Mdot
.29222 .88546 Mdot
.35055 .35883 Mdot
.1186 .53638 Mdot
.22599 .03744 Mdot
.41894 .57976 Mdot
.68163 .94672 Mdot
.26014 .91324 Mdot
.36048 .88352 Mdot
.32198 .85706 Mdot
.25985 .92462 Mdot
.97583 .8883 Mdot
.1441 .95455 Mdot
.20206 .87477 Mdot
.30057 .70302 Mdot
.16269 .85697 Mdot
.40727 .86277 Mdot
.13833 .83297 Mdot
.18229 .85439 Mdot
.48898 .92095 Mdot
.19078 .88491 Mdot
.21177 .73852 Mdot
.19626 .83951 Mdot
.04881 .28838 Mdot
.35652 .92252 Mdot
.46632 .81441 Mdot
.49135 .25105 Mdot
.17776 .84502 Mdot
.32563 .17068 Mdot
.46123 .95861 Mdot
.09097 .90039 Mdot
.00616 .81213 Mdot
.24135 .91713 Mdot
.38233 .61204 Mdot
.2703 .94937 Mdot
.09125 .86191 Mdot
.78556 .92087 Mdot
.69077 .85998 Mdot
.27929 .90247 Mdot
.11175 .82966 Mdot
.197 .96044 Mdot
.41432 .84376 Mdot
.25632 .95061 Mdot
.65638 .83132 Mdot
.35493 .78948 Mdot
.24358 .86903 Mdot
.16474 .99803 Mdot
.31207 .06164 Mdot
.97461 .69784 Mdot
.6315 .02597 Mdot
.8931 .31915 Mdot
.37062 .84403 Mdot
.289 .94583 Mdot
.68769 .23695 Mdot
.18281 .86075 Mdot
.90327 .4932 Mdot
.1769 .82786 Mdot
.45512 .84782 Mdot
.0023 .56571 Mdot
.40669 .77004 Mdot
.25222 .20191 Mdot
.98527 .19731 Mdot
.28187 .88979 Mdot
.18394 .87134 Mdot
.22176 .64732 Mdot
.42512 .84452 Mdot
.40205 .36775 Mdot
.06695 .94269 Mdot
.22611 .88734 Mdot
.26413 .83773 Mdot
.00497 .56401 Mdot
.34962 .01852 Mdot
.06598 .98217 Mdot
.23276 .88719 Mdot
.18776 .98963 Mdot
.23086 .8989 Mdot
.87481 .89722 Mdot
.12102 .46298 Mdot
.05321 .1956 Mdot
.3106 .88027 Mdot
.35579 .47859 Mdot
.14777 .83628 Mdot
.34327 .90418 Mdot
.15843 .67696 Mdot
.1397 .98359 Mdot
.74119 .42581 Mdot
.30541 .09266 Mdot
.28482 .19065 Mdot
.28012 .87104 Mdot
.90071 .91865 Mdot
.18013 .83232 Mdot
.03719 .53582 Mdot
.38378 .25468 Mdot
.29601 .99535 Mdot
.16068 .24828 Mdot
.27957 .83254 Mdot
.12333 .86972 Mdot
.26821 .2633 Mdot
.23133 .86538 Mdot
.31815 .84802 Mdot
.51973 .78516 Mdot
.33281 .96049 Mdot
.78961 .22046 Mdot
.35128 .41548 Mdot
.72331 .96634 Mdot
.91735 .76853 Mdot
.2745 .93599 Mdot
.93062 .94198 Mdot
.48462 .24531 Mdot
.18852 .9958 Mdot
.24565 .91766 Mdot
.15067 .84487 Mdot
.27832 .91447 Mdot
.53934 .57154 Mdot
.37757 .68433 Mdot
.32629 .43049 Mdot
.462 .2125 Mdot
.45153 .79849 Mdot
.48564 .63411 Mdot
.21486 .84043 Mdot
.27724 .91882 Mdot
.10992 .78164 Mdot
.48142 .03259 Mdot
.72653 .05116 Mdot
.50462 .85025 Mdot
.31057 .89476 Mdot
.80734 .01739 Mdot
.05973 .89887 Mdot
.05196 .14132 Mdot
.39185 .0603 Mdot
.22905 .92822 Mdot
.28604 .91315 Mdot
.29015 .83091 Mdot
.36092 .93526 Mdot
.12317 .77745 Mdot
.22246 .79969 Mdot
.09816 .75719 Mdot
.16845 .85238 Mdot
.26886 .93699 Mdot
.58425 .89792 Mdot
.15817 .86974 Mdot
.99657 .54042 Mdot
.22104 .91784 Mdot
.30261 .03424 Mdot
.24616 .95896 Mdot
.27819 .20285 Mdot
.03982 .59532 Mdot
.25015 .87966 Mdot
.87939 .455 Mdot
.19787 .89377 Mdot
.15318 .66878 Mdot
.25861 .87129 Mdot
.17876 .83924 Mdot
.68337 .28247 Mdot
.36012 .89469 Mdot
.12164 .853 Mdot
.26192 .9342 Mdot
.11267 .02273 Mdot
.02236 .58799 Mdot
.26836 .96468 Mdot
.14725 .96482 Mdot
.50269 .3646 Mdot
.46175 .42365 Mdot
.18433 .9423 Mdot
.29232 .16354 Mdot
.42111 .50126 Mdot
.24999 .90896 Mdot
.2754 .93474 Mdot
.14077 .83355 Mdot
.26875 .01767 Mdot
.0534 .25475 Mdot
.43503 .12642 Mdot
.11417 .88567 Mdot
.1036 .79924 Mdot
.0913 .85733 Mdot
.22717 .07802 Mdot
.18994 .67901 Mdot
.21532 .87062 Mdot
.12607 .82055 Mdot
.22684 .47622 Mdot
.28971 .85533 Mdot
.23291 .80928 Mdot
.11489 .6303 Mdot
.06556 .83985 Mdot
.30891 .88998 Mdot
.27331 .90268 Mdot
.1977 .78089 Mdot
.1379 .19761 Mdot
.28597 .97109 Mdot
.38037 .95893 Mdot
.19627 .87252 Mdot
.15892 .91902 Mdot
.40842 .6395 Mdot
.14704 .72231 Mdot
.25894 .9028 Mdot
.30525 .23965 Mdot
.68636 .84253 Mdot
.20503 .85649 Mdot
.48249 .24324 Mdot
.16286 .85563 Mdot
.155 .83287 Mdot
.09806 .83821 Mdot
.13748 .8346 Mdot
.14479 .87889 Mdot
.43253 .12241 Mdot
.09704 .84014 Mdot
.10456 .774 Mdot
.26801 .13061 Mdot
.19099 .95053 Mdot
.26905 .78772 Mdot
.29568 .23036 Mdot
.16694 .86243 Mdot
.5502 .26076 Mdot
.27084 .78231 Mdot
.29119 .90295 Mdot
.69383 .55859 Mdot
.15077 .90373 Mdot
.12641 .78247 Mdot
.85812 .20611 Mdot
.06514 .77359 Mdot
.15497 .82721 Mdot
.27511 .89545 Mdot
.28783 .90168 Mdot
.80959 .95382 Mdot
.13257 .15416 Mdot
.94851 .55054 Mdot
.1922 .88509 Mdot
.18075 .85806 Mdot
.23409 .9285 Mdot
.60814 .97548 Mdot
.28014 .86984 Mdot
.31593 .95501 Mdot
.03598 .97416 Mdot
.25471 .94111 Mdot
.15532 .47273 Mdot
.15963 .86339 Mdot
.2105 .29996 Mdot
.12503 .91019 Mdot
.15104 .89272 Mdot
.16757 .83901 Mdot
.23958 .9718 Mdot
.28141 .8609 Mdot
.10993 .96515 Mdot
.1466 .86483 Mdot
.14529 .8024 Mdot
.27389 .88294 Mdot
.27345 .13926 Mdot
.58317 .47502 Mdot
.13064 .8363 Mdot
.68969 .09621 Mdot
.26314 .91819 Mdot
.20874 .88188 Mdot
.26283 .82241 Mdot
.18088 .84008 Mdot
.13119 .86803 Mdot
.10844 .12392 Mdot
.59297 .99911 Mdot
.06848 .56802 Mdot
.36484 .91427 Mdot
.25083 .84893 Mdot
.26129 .93129 Mdot
.16744 .86819 Mdot
.12827 .88907 Mdot
.14252 .9668 Mdot
.27585 .87574 Mdot
.31682 .84631 Mdot
.3025 .069 Mdot
.28995 .82372 Mdot
.31631 .82003 Mdot
.39471 .0325 Mdot
.80935 .86193 Mdot
.28003 .10366 Mdot
.28854 .82394 Mdot
.15221 .69795 Mdot
.17133 .90929 Mdot
.55854 .41215 Mdot
.19338 .87074 Mdot
.16402 .71118 Mdot
.11288 .80074 Mdot
.35796 .91049 Mdot
.29826 .96794 Mdot
.45023 .53412 Mdot
.24381 .91659 Mdot
.91401 .80922 Mdot
.97759 .63411 Mdot
.48267 .258 Mdot
.33606 .88894 Mdot
.33722 .9575 Mdot
.36148 .85026 Mdot
.40431 .8396 Mdot
.47343 .71731 Mdot
.21604 .86334 Mdot
.2294 .8446 Mdot
.36091 .7615 Mdot
.16145 .1255 Mdot
.23147 .79321 Mdot
.22968 .78365 Mdot
.26812 .5477 Mdot
.29487 .88984 Mdot
.90352 .1429 Mdot
.28574 .8109 Mdot
.37071 .88483 Mdot
.17915 .8458 Mdot
.18564 .85408 Mdot
.954 .09195 Mdot
.29534 .59304 Mdot
.12591 .05074 Mdot
.95669 .78802 Mdot
.59129 .86475 Mdot
.42224 .71354 Mdot
.24198 .84981 Mdot
.13751 .83775 Mdot
.25089 .84282 Mdot
.56043 .33183 Mdot
.33691 .89385 Mdot
.02366 .64072 Mdot
.24086 .90693 Mdot
.24818 .87092 Mdot
.32861 .19931 Mdot
.12644 .84248 Mdot
.3207 .97374 Mdot
.24828 .92161 Mdot
.3349 .26995 Mdot
.33844 .04321 Mdot
.2021 .89264 Mdot
.55628 .83231 Mdot
.2369 .73743 Mdot
.24922 .91151 Mdot
.07295 .31097 Mdot
.1826 .8675 Mdot
.91765 .91196 Mdot
.37728 .94155 Mdot
.19628 .92909 Mdot
.164 .62505 Mdot
.18206 .89406 Mdot
.87587 .68489 Mdot
.15676 .74334 Mdot
.47018 .08805 Mdot
.83229 .94706 Mdot
.28555 .83206 Mdot
.24683 .90431 Mdot
.2006 .85556 Mdot
.33194 .86762 Mdot
.15662 .82775 Mdot
.60466 .28445 Mdot
.43709 .97734 Mdot
.39976 .03222 Mdot
.75689 .67921 Mdot
.22852 .43652 Mdot
.25273 .18503 Mdot
.43864 .09849 Mdot
.37052 .67841 Mdot
.42231 .96756 Mdot
.4415 .93011 Mdot
.17682 .8719 Mdot
.18168 .98109 Mdot
.80457 .76806 Mdot
.26401 .88605 Mdot
.26862 .89742 Mdot
.11694 .86729 Mdot
.96699 .83831 Mdot
.63467 .24138 Mdot
.34811 .5998 Mdot
.31434 .90181 Mdot
.30461 .05752 Mdot
.06224 .99237 Mdot
.08725 .31377 Mdot
.29863 .67312 Mdot
.2802 .88937 Mdot
.58427 .45852 Mdot
.26379 .96446 Mdot
.29543 .78681 Mdot
.45303 .68345 Mdot
.10944 .77064 Mdot
.26823 .94002 Mdot
.1869 .84246 Mdot
.34855 .02222 Mdot
.30936 .09925 Mdot
.13675 .99727 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Go
oooo0_l00007ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01_ooool2o`0000Go
oooo0_l0000>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool2o`0000Go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;o
oooo000Nooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`04o`000?oooooo0000o`0000Cooooo0_l00007ooooo`03o`000?oooooooooo00go
oooo00Co0000ooooool0003o00003?ooool2o`0000kooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0:ooooo`;o000000?oooooo`000?ooool03_ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00Oooooo0_l00005ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003oooooooooo`09ooooo`;o
00009?ooool2o`0000Gooooo0_l0000Hooooo`;o00002Oooool2o`0002oooooo0_l0002iooooo`00
7_ooool00ol0003oooooooooo`09ooooo`;o0000:oooool2o`0002?ooooo0_l00002ooooo`;o0000
Zoooool2o`0003Wooooo000Nooooo`03o`000?oooooooooo05oooooo0_l0002[ooooo`;o00004?oo
ool2o`0002Oooooo000Nooooo`03o`000?oooooooooo05?ooooo0_l0000Iooooo`;o00001_ooool2
o`0005cooooo0_l0000/ooooo`;o00006_ooool2o`0002Oooooo000Nooooo`03o`000?oooooooooo
027ooooo0_l0000`ooooo`?o00005oooool3o`0000Kooooo0_l0000Looooo`;o0000?_ooool2o`00
02cooooo0_l00013ooooo`007_ooool00ol0003oooooooooo`0Qooooo`;o000000?oooooo`000?l0
00004oooool2o`0001Wooooo0_l0000:ooooo`;o00002oooool2o`0002Gooooo0_l0000cooooo`;o
0000O?ooool001kooooo00?o0000ooooooooool09?ooool2o`00013ooooo0_l000000ooooooo0000
o`00000Mooooo`;o00001_ooool2o`0006Oooooo0_l0001looooo`007_ooool00ol0003ooooooooo
o`0fooooo`;o00008?ooool2o`0000Gooooo0_l0000Qooooo`;o0000`oooool001kooooo00?o0000
ooooooooool0G_ooool3o`0001_ooooo1?l00002ooooo`;o00005?ooool2o`000:gooooo000Noooo
o`03o`000?oooooooooo04Gooooo0_l0000Gooooo`;o00007?ooool4o`0000kooooo0_l00008oooo
o`;o0000[Oooool001kooooo00?o0000ooooooooool0AOooool2o`0004Oooooo0_l0002@ooooo`;o
00009Oooool001kooooo00?o0000ooooooooool09oooool2o`00047ooooo0_l0002dooooo`;o0000
9Oooool001kooooo00?o0000ooooooooool09oooool2o`0002oooooo0_l00008ooooo`;o00001_oo
ool2o`0000Wooooo0_l0000Iooooo`;o0000]Oooool001kooooo00?o0000ooooooooool0>?ooool2
o`0001?ooooo0_l00009ooooo`;o00002?ooool2o`00017ooooo0_l0000Iooooo`;o00007Oooool2
o`0009Kooooo000Nooooo`;o00009_ooool2o`00017ooooo0_l0000Cooooo`;o000000?oooooo`00
0?l00000GOooool2o`0003Oooooo0_l0001Mooooo`007_ooool00ol0003oooooooooo`0Uooooo`;o
0000:Oooool2o`0000Gooooo0_l0000Booooo`;o0000<Oooool2o`0004Sooooo0_l0001Mooooo`00
7_ooool00ol0003oooooooooo`0cooooo`;o00007_ooool2o`0000;ooooo0_l00006ooooo`;o0000
2_ooool2o`00037ooooo0_l000000ooooooo0000o`00002Tooooo`007_ooool00ol0003ooooooooo
o`0cooooo`;o00007_ooool2o`0000[ooooo1?l0000Hooooo`;o00003oooool2o`0001?ooooo0_l0
002Tooooo`007_ooool00ol0003oooooooooo`1Qooooo`;o00006?ooool2o`0000oooooo0_l0002i
ooooo`007_ooool00ol0003oooooooooo`1Nooooo`;o00003_ooool2o`000=Oooooo000Nooooo`?o
0000G_ooool2o`0000kooooo0_l0003Gooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0A_ooool2o`0001;ooooo0_l0003[ooooo`007_ooool00ol0003oooooooooo`0m
ooooo`;o00001oooool2o`0001;ooooo0_l0002Gooooo`;o0000D_ooool001kooooo00?o0000oooo
ooooool0?Oooool2o`0000cooooo0_l0002Vooooo`;o0000D_ooool001kooooo00?o0000oooooooo
ool0Boooool2o`000?[ooooo000Nooooo`03o`000?oooooooooo09Gooooo0_l0002`ooooo`007_oo
ool00ol0003oooooooooo`1Oooooo`;o0000=?ooool2o`0009_ooooo0_l0000Cooooo`007_ooool0
0ol0003oooooooooo`1Oooooo`;o0000;?ooool2o`0000Oooooo0_l00014ooooo`;o0000E?ooool2
o`0001?ooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0001Fooooo`;o0000:?ooool2o`00
0003ooooool0003o000000Oooooo0_l00014ooooo`;o0000JOooool001kooooo0_l00009ooooo`;o
0000=?ooool2o`00023ooooo0_l0000Xooooo`;o00002Oooool2o`000;3ooooo000Nooooo`03o`00
0?oooooooooo03kooooo0_l0000Gooooo`;o00002_ooool2o`00033ooooo0_l0002`ooooo`007_oo
ool00ol0003oooooooooo`1=ooooo`;o00002?ooool2o`0000[ooooo0_l0003Rooooo`007_ooool0
0ol0003oooooooooo`1=ooooo`;o0000n?ooool001kooooo00?o0000ooooooooool03Oooool2o`00
0=Wooooo0_l0001Mooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o0000Y_ooool2o`00037o
oooo0_l0001Mooooo`007_ooool00ol0003oooooooooo`2eooooo`;o0000T?ooool001kooooo00?o
0000ooooooooool07oooool2o`00037ooooo0_l0000eooooo`;o0000MOooool2o`0004Gooooo000N
ooooo`03o`000?oooooooooo01oooooo0_l0000?ooooo`;o00008?ooool2o`0001_ooooo0_l0000H
ooooo`;o0000MOooool2o`0004Gooooo000Nooooo`03o`000?oooooooooo033ooooo0_l00008oooo
o`;o00005oooool2o`0001[ooooo0_l0000Hooooo`;o0000_?ooool001kooooo00?o0000oooooooo
ool0>_ooool2o`0001Oooooo0_l0003booooo`007_ooool00ol0003oooooooooo`1Cooooo`;o0000
l_ooool001kooooo00?o0000ooooooooool0EOooool2o`000?3ooooo000Nooooo`03o`000?oooooo
oooo00gooooo0_l0000dooooo`;o00004?ooool2o`000<_ooooo0_l0000Sooooo`007_ooool00ol0
003oooooooooo`0=ooooo`;o0000=?ooool2o`000=gooooo0_l0000Eooooo`;o00003?ooool001ko
oooo00?o0000ooooooooool0C?ooool2o`000>_ooooo0_l0000<ooooo`007_ooool2o`0004gooooo
0_l0003iooooo`007_ooool00ol0003oooooooooo`0Wooooo`;o0000V?ooool2o`0008Cooooo000N
ooooo`03o`000?oooooooooo02Oooooo0_l0002Hooooo`;o0000Q?ooool001kooooo00?o0000oooo
ooooool0oooooolaooooo`;o00005Oooool001kooooo00?o0000ooooooooool0?_ooool2o`0001_o
oooo0_l0000cooooo`;o0000W_ooool2o`0001Gooooo000Nooooo`03o`000?oooooooooo03kooooo
0_l0000Kooooo`;o0000<oooool2o`000;Gooooo000Nooooo`03o`000?oooooooooo03;ooooo0_l0
000Kooooo`;o0000m_ooool001kooooo00?o0000ooooooooool0<_ooool2o`0001_ooooo0_l0000E
ooooo`;o0000goooool001kooooo00?o0000ooooooooool0I_ooool2o`000=oooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0Voooool2o`0001Wooooo
0_l0002?ooooo`007_ooool00ol0003oooooooooo`1>ooooo`;o0000Boooool2o`0001Wooooo0_l0
002?ooooo`007_ooool00ol0003oooooooooo`1>ooooo`;o0000moooool001kooooo00?o0000oooo
ooooool0:_ooool2o`0002cooooo0ol0000Rooooo`;o00002_ooool2o`000;cooooo0003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo
02[ooooo0_l0000/ooooo`?o00008_ooool2o`0000[ooooo0_l0000Iooooo`;o0000XOooool000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400Kooooo00?o0000ooooooooool03Oooool2o`0001[ooooo0_l0000Hooooo`;o0000Goooool2
o`0009Kooooo0_l00009ooooo`000oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RH
ob4Q8Oo^k^h01oooool3o`0000gooooo0_l0000Jooooo`;o00001?ooool2o`0000Gooooo0_l0000;
ooooo`;o00007Oooool2o`0000?ooooo0_l0002Oooooo`;o0000<_ooool2o`0000Wooooo0003oooo
o`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooo
oooo02oooooo0_l00005ooooo`;o00005_ooool2o`0000Kooooo0_l0000:ooooo`;o00000oooool2
o`0009oooooo0_l0000mooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMg
ofIVI_ooool01Oooool00ol0003oooooooooo`1>ooooo`?o00001Oooool2o`0001;ooooo0_l0002W
ooooo`;o0000<_ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0Coooool2o`0001Wooooo0_l0002Wooooo`;o0000<_ooool0
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_oo
ool00ol0003oooooooooo`2Booooo`;o0000/oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Cooooo`;o0000
?Oooool2o`000;?ooooo000Nooooo`03o`000?oooooooooo05?ooooo0_l0003booooo`007_ooool0
0ol0003oooooooooo`3mooooo`;o0000B?ooool001kooooo00?o0000ooooooooool09_ooool2o`00
00;ooooo0_l0003Aooooo`;o0000B?ooool001kooooo00?o0000ooooooooool09_ooool2o`0000;o
oooo0_l0003ooooooacooooo000Nooooo`03o`000?oooooooooo01_ooooo0_l0000oooooo`;o0000
jOooool001kooooo00?o0000ooooooooool06oooool2o`0003oooooo0_l0003Yooooo`007_ooool0
0ol0003oooooooooo`0Aooooo`;o0000Xoooool2o`0002?ooooo0_l0001Zooooo`007_ooool00ol0
003oooooooooo`0Aooooo`;o0000C?ooool2o`0005Gooooo0_l0000Sooooo`;o0000J_ooool001ko
oooo00?o0000ooooooooool0Goooool2o`0003Sooooo0_l0000_ooooo`;o0000Noooool001kooooo
00?o0000ooooooooool0D?ooool2o`0004Oooooo0_l0000_ooooo`;o0000Noooool001kooooo00?o
0000ooooooooool0<?ooool2o`0001kooooo0_l0000>ooooo`;o00001?ooool2o`00037ooooo0_l0
002/ooooo`007_ooool2o`00037ooooo0_l0000Dooooo`;o00006?ooool2o`0000Cooooo0_l0000d
ooooo`;o0000ZOooool001kooooo00?o0000ooooooooool03Oooool2o`0003Oooooo0_l0000Poooo
o`;o00003oooool2o`00027ooooo0_l0002Yooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o
0000FOooool2o`0000oooooo0_l0000Nooooo`;o0000[?ooool001kooooo00?o0000ooooooooool0
H?ooool2o`0003Oooooo0_l0000Dooooo`;o0000U_ooool001kooooo00?o0000ooooooooool0Dooo
ool2o`0000_ooooo0_l0001=ooooo`;o0000U_ooool001kooooo00?o0000ooooooooool0Doooool2
o`000?;ooooo000Nooooo`03o`000?oooooooooo06Wooooo0_l0003Looooo`007_ooool00ol0003o
ooooooooo`1Yooooo`;o0000P_ooool2o`0005Sooooo000Nooooo`03o`000?oooooooooo0>gooooo
0_l0001Hooooo`007_ooool00ol0003oooooooooo`1Tooooo`;o0000hOooool001kooooo00?o0000
ooooooooool0I?ooool2o`0007Cooooo0_l0001[ooooo`007_ooool00ol0003oooooooooo`30oooo
o`;o00006?ooool2o`0006_ooooo000Nooooo`03o`000?oooooooooo00cooooo0_l0002booooo`;o
00007_ooool2o`00013ooooo0_l0001Cooooo`007_ooool00ol0003oooooooooo`07ooooo`;o0000
0oooool2o`000=;ooooo0_l0000@ooooo`;o0000Doooool001kooooo00?o0000ooooooooool01ooo
ool2o`000?oooooo?oooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`00
047ooooo0_l0003oooooo`Kooooo000Nooooo`03o`000?oooooooooo043ooooo0_l0003oooooo`Ko
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool05?oo
ool2o`0004_ooooo0_l0003Tooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o00000_ooool2
o`0004Oooooo0_l0003Tooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o0000<_ooool2o`00
0?Wooooo000Nooooo`03o`000?oooooooooo04cooooo0_l0003@ooooo`;o00009oooool001kooooo
00?o0000ooooooooool0oooooolOooooo`;o00009oooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`0mooooo`;o0000ooooool9ooooo`007_ooool00ol0
003oooooooooo`0mooooo`;o0000Loooool2o`0009?ooooo000Nooooo`03o`000?oooooooooo05ko
oooo0_l0001Booooo`;o0000Toooool001kooooo00?o0000ooooooooool0G_ooool2o`000>Oooooo
000Nooooo`03o`000?oooooooooo08kooooo0_l0002gooooo`007_ooool00ol0003oooooooooo`1k
ooooo`;o00004Oooool2o`000;Oooooo000Nooooo`03o`000?oooooooooo07_ooooo0_l0003:oooo
o`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo06kooooo0_l0003G
ooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o0000COooool2o`000=Oooooo000Nooooo`03
o`000?oooooooooo01oooooo0_l0001nooooo`;o0000UOooool2o`0000oooooo000Nooooo`03o`00
0?oooooooooo07oooooo0_l0000Nooooo`;o0000UOooool2o`0000oooooo000Nooooo`03o`000?oo
oooooooo07oooooo0_l00036ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Moooo
o`;o0000=oooool2o`000?oooooo4Oooool001gooooo0_l0000gooooo`;o0000oooooolAooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo017ooooo0_l0
003oooooocGooooo000Nooooo`03o`000?oooooooooo017ooooo0_l0003oooooocGooooo0003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04
ooooo`03o`000?oooooooooo04[ooooo0_l0003kooooo`000oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0B_ooool2
o`000?_ooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol0003o
ooooodSooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool0
0007ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go0000ooooooooooooooooo`00
000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0>Oooool2o`000?oooooo
3Oooool000?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo
00?o0000ooooooooool0>Oooool2o`0002oooooo0_l0003Kooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`1Zooooo`;o0000
AOooool2o`0009Cooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000
ooooo`06ooooo`03o`000?oooooooooo06kooooo0_l00011ooooo`;o0000U?ooool001kooooo00?o
0000ooooooooool0K_ooool2o`0004oooooo0_l00026ooooo`007_ooool00ol0003oooooooooo`1T
ooooo`;o0000FOooool2o`0008Kooooo000Nooooo`03o`000?oooooooooo06Cooooo0_l0000/oooo
o`;o0000FOooool2o`0005Sooooo000Nooooo`?o0000T_ooool2o`0005Wooooo0_l0001Hooooo`00
7_ooool3o`0006Kooooo0_l0003Oooooo`007_ooool00ol0003oooooooooo`1Vooooo`;o0000gooo
ool001kooooo00?o0000ooooooooool07oooool2o`0002Gooooo0_l0003oooooo`007_ooool00ol0
003oooooooooo`0Oooooo`;o00009Oooool2o`000?oooooo000Nooooo`03o`000?oooooooooo03go
oooo0_l0003oooooo`Wooooo000Nooooo`03o`000?oooooooooo03[ooooo0_l000000ooooooo0000
o`00003/ooooo`;o00006_ooool001kooooo00?o0000ooooooooool0>_ooool2o`000003ooooool0
003o00000>cooooo0_l0000Jooooo`007_ooool2o`0003kooooo0_l0001Aooooo`;o0000]Oooool0
01kooooo00?o0000ooooooooool0T?ooool2o`0008Sooooo0_l0000[ooooo`007_ooool00ol0003o
ooooooooo`2<ooooo`;o0000;?ooool2o`0001?ooooo0_l00019ooooo`;o0000:oooool001kooooo
00?o0000ooooooooool0S?ooool2o`0002cooooo0_l0000Cooooo`;o0000M_ooool001kooooo00?o
0000ooooooooool08oooool2o`000?oooooo8oooool001kooooo00?o0000ooooooooool08oooool2
o`000?oooooo8oooool001kooooo00?o0000ooooooooool0Coooool2o`000?Kooooo000Nooooo`03
o`000?oooooooooo02kooooo0_l0000Oooooo`;o0000J?ooool2o`0008cooooo000Nooooo`03o`00
0?oooooooooo02kooooo0_l0000Fooooo`;o0000LOooool2o`0008cooooo000Nooooo`03o`000?oo
oooooooo04Kooooo0_l0000Xooooo`;o0000=?ooool2o`0009oooooo000Nooooo`03o`000?oooooo
oooo073ooooo0_l0000dooooo`;o0000Woooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`1jooooo`;o00005Oooool2o`000;Cooooo000Nooooo`03o`00
0?oooooooooo07[ooooo0_l0000Eooooo`;o0000Soooool2o`0002?ooooo000Nooooo`03o`000?oo
oooooooo07Gooooo0_l0000>ooooo`;o0000Voooool2o`0002?ooooo000Nooooo`03o`000?oooooo
oooo07Gooooo0_l0000>ooooo`;o0000`?ooool001kooooo0_l00004ooooo`;o0000P?ooool2o`00
0<3ooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l00020ooooo`;o0000`?ooool001kooooo
00?o0000ooooooooool06Oooool2o`000?oooooo;Oooool001kooooo00?o0000ooooooooool06Ooo
ool2o`000?oooooo;Oooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`2@ooooo`;o0000]Oooool001kooooo00?o0000ooooooooool0T?ooool2o`000;Go
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o0000<_ooool2o`000?cooooo000Noooo
o`03o`000?oooooooooo01Gooooo0_l0000Looooo`;o00005?ooool2o`000?cooooo000Nooooo`03
o`000?oooooooooo00Sooooo0_l0000Hooooo`;o00003oooool2o`0005Wooooo0_l00015ooooo`;o
0000L?ooool001kooooo00?o0000ooooooooool02?ooool2o`0001Sooooo0_l0001Zooooo`;o0000
AOooool2o`00073ooooo000Nooooo`03o`000?oooooooooo0?oooooo@Oooool2o`0000Gooooo000N
ooooo`03o`000?oooooooooo04oooooo0_l00022ooooo`;o0000Joooool2o`0000Gooooo000Noooo
o`03o`000?oooooooooo01Oooooo0_l000000ooooooo0000o`00000cooooo`;o00000_ooool2o`00
07kooooo0_l0001booooo`007_ooool2o`0001Sooooo0_l000000ooooooo0000o`00000gooooo`;o
00007Oooool2o`000;7ooooo0_l00009ooooo`;o00005Oooool001kooooo00?o0000ooooooooool0
L_ooool2o`000;7ooooo0_l00009ooooo`;o00005Oooool001kooooo00?o0000ooooooooool0g_oo
ool2o`0001Sooooo0_l0001=ooooo`007_ooool00ol0003oooooooooo`03ooooo`;o0000?oooool2
o`0009Oooooo0ol0000Dooooo`;o00000_ooool2o`0004gooooo000Nooooo`;o00001?ooool2o`00
03oooooo0_l0002Gooooo`;o00005Oooool2o`00057ooooo000Nooooo`;o0000lOooool2o`0005Go
oooo000Nooooo`;o00004oooool2o`0003gooooo0_l0002Mooooo`;o0000EOooool001kooooo00?o
0000ooooooooool04_ooool2o`0003gooooo0_l0001Hooooo`;o0000V_ooool001kooooo00?o0000
ooooooooool0HOooool2o`0004Sooooo0_l0002Jooooo`007_ooool00ol0003oooooooooo`1Qoooo
o`;o00002Oooool2o`000=Wooooo000Nooooo`03o`000?oooooooooo06cooooo0_l0000Fooooo`;o
0000`Oooool001kooooo00?o0000ooooooooool0Q?ooool2o`000<7ooooo000Nooooo`03o`000?oo
oooooooo00?ooooo0_l0001Iooooo`;o0000aoooool2o`0001kooooo000Nooooo`03o`000?oooooo
oooo00?ooooo0ol0001Hooooo`;o0000aoooool2o`0001kooooo0003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oo
oooooooo00Cooooo0_l0001<ooooo`;o00002?ooool2o`000>Wooooo0003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`00
0?oooooooooo00Wooooo0_l00017ooooo`;o00002?ooool2o`0001_ooooo0_l0003<ooooo`000ooo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o
00002Oooool2o`0006;ooooo0_l0000:ooooo`;o0000c?ooool000?ooooo00Go0000oooooooooooo
ooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1]oooo
o`;o0000f?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000
oa0@4?o<c<`01_ooool00ol0003oooooooooo`03ooooo`;o00001Oooool2o`0004?ooooo0_l0003f
ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool0
0ol0003oooooooooo`03ooooo`;o00001Oooool2o`0000Kooooo0_l0000kooooo`;o0000>?ooool2
o`000;cooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008
ooooo`03o`000?oooooooooo01;ooooo0_l0000hooooo`;o00004oooool2o`0001Gooooo0_l0000?
ooooo`;o0000H_ooool2o`0005Sooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool0
1?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo04cooooo0_l0000Cooooo`;o00005Ooo
ool2o`0007?ooooo0_l0001Hooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?oooooo0_l00016ooooo`007_ooool00ol0003oooooooooo`0[ooooo`;o
00001?ooool2o`000<cooooo0_l00016ooooo`007_ooool00ol0003oooooooooo`0[ooooo`;o0000
1?ooool2o`0002Oooooo0_l0003[ooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o00005Ooo
ool2o`0002Wooooo0_l0000<ooooo`;o0000joooool001kooooo00?o0000ooooooooool02?ooool4
o`0000Oooooo0_l0000<ooooo`;o0000:Oooool2o`0001?ooooo0_l0000gooooo`;o0000W_ooool2
o`0000_ooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l00009ooooo`;o0000C?ooool2o`00
03Oooooo0_l0002Nooooo`;o00002oooool001kooooo00?o0000ooooooooool01?ooool2o`0001Oo
oooo0_l00008ooooo`;o0000F?ooool2o`000003ooooool0003o00000<7ooooo000Nooooo`03o`00
0?oooooooooo00Cooooo0_l0000Gooooo`;o00002?ooool2o`0005Sooooo0_l000000ooooooo0000
o`000031ooooo`007_ooool00ol0003oooooooooo`14ooooo`;o00008?ooool2o`000=oooooo000N
ooooo`03o`000?oooooooooo04Cooooo0_l0000Pooooo`;o0000goooool001kooooo0_l0003ooooo
odWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o0000ooooooljooooo`007_ooool0
0ol0003oooooooooo`0<ooooo`;o0000ooooooljooooo`007_ooool00ol0003oooooooooo`0^oooo
o`;o0000oooooolHooooo`007_ooool00ol0003oooooooooo`0^ooooo`;o0000oooooolHooooo`00
7_ooool00ol0003oooooooooo`0Fooooo`;o0000AOooool2o`000>Sooooo000Nooooo`03o`000?oo
oooooooo01Kooooo0_l0000Gooooo`;o00003Oooool2o`0001gooooo0_l0002Uooooo`;o0000@Ooo
ool001kooooo00?o0000ooooooooool0;oooool2o`0000Wooooo0_l00002ooooo`;o00001_ooool2
o`0001?ooooo0_l0000Gooooo`;o0000G_ooool2o`0001cooooo0_l0000@ooooo`;o0000@Oooool0
01kooooo00?o0000ooooooooool0>_ooool2o`0000[ooooo0_l0000Cooooo`;o00001_ooool2o`00
00oooooo0_l0000Iooooo`;o0000@oooool2o`0001cooooo0_l0001Cooooo`007_ooool00ol0003o
ooooooooo`05ooooo`;o0000G?ooool2o`0001;ooooo0_l0000Fooooo`;o0000R?ooool2o`0002co
oooo000Nooooo`03o`000?oooooooooo00Gooooo0_l0001`ooooo`;o0000X?ooool2o`0002cooooo
000Nooooo`03o`000?oooooooooo00Cooooo0_l00031ooooo`;o0000O_ooool001kooooo00?o0000
ooooooooool01?ooool2o`0000?ooooo0_l00007ooooo`;o0000/oooool2o`0007kooooo000Noooo
o`03o`000?oooooooooo00Wooooo0_l00007ooooo`;o00000oooool2o`0001Cooooo0_l0000]oooo
o`;o00007oooool2o`000;[ooooo0_l0000<ooooo`007_ooool2o`0001Sooooo0_l0000Dooooo`;o
0000;Oooool2o`0000?ooooo0_l0000Jooooo`;o0000^_ooool2o`0000cooooo000Nooooo`03o`00
0?oooooooooo04[ooooo0_l0000Booooo`;o000000?oooooo`000?l000004oooool2o`0007gooooo
0_l0001@ooooo`007_ooool00ol0003oooooooooo`1:ooooo`;o00004_ooool2o`0001Kooooo0_l0
0010ooooo`;o0000>oooool2o`000003ooooool0003o000004Kooooo0_l00005ooooo`007_ooool0
0ol0003oooooooooo`0]ooooo`;o00000_ooool2o`0002Wooooo0_l0000Xooooo`;o0000<?ooool2
o`0003kooooo0_l00016ooooo`;o00001Oooool001kooooo00?o0000ooooooooool0;Oooool2o`00
00;ooooo0_l0000Yooooo`?o00009_ooool3o`000;oooooo000Nooooo`03o`000?oooooooooo05go
oooo0_l0000Vooooo`;o00003oooool2o`000:oooooo000Nooooo`03o`000?oooooooooo03?ooooo
0_l0000Zooooo`;o00004Oooool2o`0002;ooooo1?l0002]ooooo`007_ooool00ol0003ooooooooo
o`0/ooooo`;o00001Oooool2o`0001_ooooo0_l0000=ooooo`;o00004Oooool2o`0002Cooooo0_l0
002]ooooo`007_ooool00ol0003oooooooooo`02o`0002[ooooo0_l0000Rooooo`;o0000mOooool0
01kooooo00?o0000ooooooooool00_l0003oooooodKooooo000Nooooo`04o`000?oooooo0000o`00
02Wooooo0_l0002Gooooo`;o0000P_ooool001kooooo00Co0000ooooool0003o0000:Oooool2o`00
0003ooooool0003o000001Wooooo0_l00003ooooo`;o0000M?ooool2o`0001Kooooo0_l0001Zoooo
o`007_ooool00ol0003oooooooooo`0Xooooo`;o00000oooool2o`0001;ooooo0_l00005ooooo`?o
00000_ooool2o`0008cooooo0_l0001Zooooo`007_ooool00ol0003oooooooooo`0Xooooo`;o0000
3oooool2o`0000Kooooo0_l00006ooooo`;o0000o?ooool001kooooo00?o0000ooooooooool08ooo
ool2o`0000[ooooo0_l00008ooooo`;o0000ooooool=ooooo`007_ooool00ol0003oooooooooo`0S
ooooo`;o00002_ooool2o`0000Wooooo0_l00015ooooo`;o0000DOooool2o`00077ooooo000Noooo
o`;o0000>Oooool4o`0000[ooooo0_l0000iooooo`;o0000DOooool2o`00077ooooo000Nooooo`03
o`000?oooooooooo03Gooooo0_l000000ooooooo0000o`00000<ooooo`;o0000ooooool001kooooo
00?o0000ooooooooool07?ooool2o`0000Kooooo0_l00006ooooo`;o00001oooool2o`0003?ooooo
0_l0003Kooooo`007_ooool00ol0003oooooooooo`0Looooo`;o00001_ooool2o`0000Kooooo0ol0
000kooooo`;o0000<?ooool2o`000:Wooooo000Nooooo`03o`000?oooooooooo02gooooo0_l0000E
ooooo`;o0000:oooool2o`0002Wooooo0_l0002Yooooo`007_ooool00ol0003oooooooooo`03oooo
o`;o0000?oooool2o`0002_ooooo0_l0001Mooooo`;o0000MOooool001kooooo00?o0000oooooooo
ool00oooool2o`0001gooooo0_l0001:ooooo`;o00004?ooool2o`0004kooooo0_l0000_ooooo`;o
00008oooool2o`0001oooooo000Nooooo`03o`000?oooooooooo01oooooo0_l000000ooooooo0000
o`000006ooooo`;o0000@_ooool2o`0000;ooooo0_l0000<ooooo`;o0000Ooooool2o`0002?ooooo
0_l0000Oooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o00002Oooool5o`0000Wooooo0_l0
000Mooooo`;o00009oooool2o`0005gooooo0_l0001dooooo`007_ooool00ol0003oooooooooo`0A
ooooo`;o00002Oooool5o`0000?ooooo0_l0000Looooo`;o00001Oooool2o`0008Kooooo0_l0001d
ooooo`007_ooool00ol0003oooooooooo`0Nooooo`Co00000_ooool3o`0000;ooooo0_l0000Aoooo
o`;o00001?ooool2o`00013ooooo0_l0003aooooo`007_ooool3o`0001gooooo0_l000000ooooooo
0000o`000003ooooo`;o00000_ooool2o`00017ooooo0ol00008ooooo`;o00002oooool2o`0001[o
oooo0_l0000Booooo`;o00007oooool2o`000:3ooooo000Nooooo`?o00002?ooool2o`0001?ooooo
0_l0000:ooooo`;o00002Oooool4o`0000Cooooo0ol00008ooooo`;o00002_ooool2o`0000Oooooo
0_l0000Booooo`;o00004_ooool2o`0001oooooo0_l00004ooooo`;o0000Q_ooool2o`0001;ooooo
000Nooooo`03o`000?oooooooooo00Sooooo0_l0000Mooooo`;o00002oooool4o`0000Sooooo0_l0
000Aooooo`;o00001oooool2o`00017ooooo0_l0000jooooo`;o0000Q_ooool2o`0001;ooooo0003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Q
olc<c006ooooo`04o`000?oooooo0000o`0001kooooo0_l00006ooooo`;o00005oooool2o`0000Go
oooo0_l00008ooooo`;o00007?ooool2o`0003cooooo0_l0002<ooooo`;o00002_ooool000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q
00Kooooo00Co0000ooooool0003o00007_ooool2o`0002Kooooo0_l00008ooooo`;o00007_ooool2
o`0003[ooooo0_l0002<ooooo`;o00002_ooool000?ooooo00Go410@oooooooooooooooooa0@400;
ooooo`05o`000?ooooooooooooooool000001_ooool3o`0000Kooooo0_l0000Fooooo`;o000000?o
ooooo`000?l000002oooool2o`0001Cooooo0_l0000[ooooo`?o00006oooool2o`0004Cooooo0_l0
001`ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RH
oc8b<P06ooooo`03o`000?oooooooooo00Kooooo0_l0000Fooooo`;o000000?oooooo`000?l00000
2?ooool2o`000003ooooool0003o000000;o00004_ooool2o`0002Oooooo0_l00003ooooo`?o0000
6_ooool2o`0001cooooo0_l0000Vooooo`;o00007?ooool2o`0005;ooooo0003ooooo`05o`000?oo
ooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000oooooooo
ool08Oooool2o`0000Sooooo0_l00003ooooo`;o00006?ooool2o`00027ooooo0_l00004ooooo`;o
0000:_ooool2o`0000cooooo0_l00004ooooo`;o0000?_ooool2o`0005;ooooo0003ooooo`05oa0@
4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000oooo
ooooool0:?ooool2o`0001kooooo1?l0001Cooooo`;o00004_ooool2o`00073ooooo0_l0000Poooo
o`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006
ooooo`?o0000:?ooool2o`000003ooooool0003o000000[ooooo0_l0000?ooooo`Co00003Oooool2
o`000<[ooooo0_l0000Pooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVY
oa0@4?l0003o410@ojVYZ@06ooooo`?o00008_ooool2o`0000;ooooo0_l00003ooooo`;o00001?oo
ool2o`0000Cooooo0_l0000Pooooo`;o0000>?ooool2o`000;;ooooo000Nooooo`03o`000?oooooo
oooo02;ooooo0_l00002ooooo`;o00002Oooool2o`0003gooooo0_l0000Qooooo`;o0000/_ooool0
01kooooo00?o0000ooooooooool07oooool2o`0000Cooooo0ol00006ooooo`;o00007Oooool2o`00
00;ooooo0_l00004ooooo`;o00001?ooool2o`0000Cooooo0_l0000;ooooo`;o0000V_ooool2o`00
03Wooooo000Nooooo`03o`000?oooooooooo01oooooo1Ol000001?oooooo0000o`000?l00006oooo
o`;o00007Oooool6o`0000Cooooo1Ol000000ooooooo0000o`000004ooooo`;o0000Yoooool2o`00
03Wooooo000Nooooo`03o`000?oooooooooo01gooooo0_l000000ooooooo0000o`000002o`0000So
oooo1Ol000001?oooooo0000o`000?ooool2o`000004ooooool0003o0000o`0000?ooooo0_l00009
ooooo`;o00001?ooool2o`0000Cooooo0_l00002ooooo`Co0000j_ooool001kooooo00?o0000oooo
ooooool07Oooool2o`000003ooooool0003o000000Sooooo1ol000001?oooooo0000o`000?ooool2
o`000003ooooool0003o000000;o00000_ooool2o`0000Wooooo0_l0000:ooooo`;o00000_ooool4
o`00013ooooo0_l0001Rooooo`;o0000M?ooool001kooooo00?o0000ooooooooool07?ooool2o`00
0004ooooool0003o0000o`0000Oooooo1ol00006ooooo`;o00000_ooool2o`0001Cooooo0_l00005
ooooo`Go00004Oooool2o`0004;ooooo0_l0000Nooooo`;o0000Eoooool2o`0001_ooooo000Noooo
o`03o`000?oooooooooo01cooooo0_l000000ooooooo0000o`000003ooooo`Co000000?oooooo`00
0?l000001Ol000000ooooooo0000o`000003ooooo`;o00001?ooool2o`00017ooooo1Ol000000ooo
oooo0000o`000005o`00017ooooo0_l00012ooooo`;o0000Moooool2o`0001_ooooo000Nooooo`03
o`000?oooooooooo00kooooo0_l000000ooooooo0000o`000002o`0000Kooooo0ol00006ooooo`Co
000000Coooooo`000?l0003ooooo0_l00003ooooo`So00000oooool2o`000004ooooool0003o0000
ooooo`;o00002_ooool3o`000004ooooool0003o0000ooooo`;o00000oooool2o`0002?ooooo0_l0
002eooooo`;o00003oooool001kooooo00?o0000ooooooooool03_ooool2o`000003ooooool0003o
000000;o00001_ooool3o`0000Cooooo0_l000000ooooooo0000o`00000;ooooo`Wo000000?ooooo
o`000?l000000ol000000ooooooo0000o`000003ooooo`;o00001?ooool3o`0000Oooooo0_l0000K
ooooo`;o00002Oooool2o`0000;ooooo0_l0001Fooooo`;o0000FOooool3o`0000kooooo000Noooo
o`03o`000?oooooooooo01cooooo0_l00004ooooo`;o000000Goooooo`000?l0003o0000ooooo`02
o`0000;ooooo0_l00007ooooo`;o000000?oooooo`000?l000000oooool2o`0000Cooooo1Ol00000
1?oooooo0000o`000?ooool2o`0000Sooooo0_l00004ooooo`;o00001?ooool2o`0000oooooo0_l0
000=ooooo`;o000000?oooooo`000?l00000Doooool2o`00017ooooo0_l00017ooooo`;o00003_oo
ool001kooooo00?o0000ooooooooool09_ooool2o`000003ooooool0003o000000;ooooo0_l00007
ooooo`;o00003?ooool4o`0000;ooooo1Ol0000<ooooo`Co00001?ooool2o`0000cooooo0_l0000C
ooooo`;o00002?ooool2o`0000kooooo0_l0001<ooooo`;o0000Eoooool001kooooo0_l0000Toooo
o`Go00000_ooool2o`0000Kooooo0ol00004ooooo`?o00003_ooool5o`000003ooooool0003o0000
00;ooooo0_l00005ooooo`;o00001?ooool4o`0000cooooo0_l0000Mooooo`;o00003_ooool2o`00
087ooooo0_l0000Rooooo`007_ooool00ol0003oooooooooo`09ooooo`;o00005_ooool7o`0000;o
oooo0_l00005ooooo`Co00000_ooool:o`000003ooooool0003o000000Kooooo0_l00004ooooo`;o
00000_ooool2o`0000Cooooo0_l00005ooooo`;o00003?ooool2o`0002Wooooo0_l000000ooooooo
0000o`000024ooooo`;o00008_ooool001kooooo00?o0000ooooooooool02Oooool2o`0000oooooo
0_l00005ooooo`;o00003_ooool@o`000003ooooool0003o000001Kooooo0_l00009ooooo`;o0000
2?ooool2o`0002Wooooo0_l000000ooooooo0000o`00002Xooooo`007_ooool00ol0003ooooooooo
o`0Jooooo`;o00001_ooool2o`0000gooooo3?l00005ooooo`;o00002_ooool2o`0000Oooooo0_l0
000:ooooo`Ko0000??ooool2o`0003Gooooo0_l0000Nooooo`;o00001Oooool2o`0004;ooooo000N
ooooo`03o`000?oooooooooo00Gooooo0_l0000Cooooo`;o00001_ooool2o`000005ooooool0003o
0000o`000?ooool01Ol00002ooooo`Go000000?oooooo`000?l000001Ol00005ooooo`;o00000ooo
ool3o`0000Cooooo0_l00007ooooo`Ko00001_ooool2o`0000;ooooo0_l0000Gooooo`;o00008ooo
ool2o`0001Gooooo0_l0000Nooooo`;o00007_ooool2o`0000Gooooo0_l00012ooooo`007_ooool0
0ol0003oooooooooo`05ooooo`;o00006oooool2o`000003ooooool0003o000000ko000000Cooooo
o`000?l0003o00001oooool4o`0000?ooooo0ol0000>ooooo`Go00002oooool2o`0001Kooooo0_l0
000Wooooo`;o00004Oooool2o`0008Wooooo000Nooooo`03o`000?oooooooooo02;ooooo1?l00000
0ooooooo0000o`000002o`0000;ooooo1ol00003ooooo`?o000000?oooooo`000?l000001ol00006
ooooo`Go000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000Cooooo0_l00009
ooooo`;o0000?oooool2o`0009Gooooo0_l00005ooooo`007_ooool00ol0003oooooooooo`0Toooo
o`;o00001Oooool8o`0000;ooooo1Ol000000ooooooo0000o`000003o`0000;ooooo0ol00005oooo
o`Go000000?oooooo`000?l000000_ooool5o`0000Cooooo0_l00005ooooo`;o00003Oooool2o`00
0<_ooooo0_l00005ooooo`007_ooool00ol0003oooooooooo`0[ooooo`;o00002?ooool2o`0000Go
oooo1?l00003ooooo`;o00001Oooool2o`000003ooooool0003o000000Gooooo1?l0000<ooooo`;o
00002?ooool2o`0000;ooooo0ol0001eooooo`;o0000Foooool001kooooo00?o0000ooooooooool0
:oooool2o`0000_ooooo0_l00002ooooo`;o00002_ooool4o`000003ooooool0003o000000;o0000
0oooool4o`0000Cooooo0_l00003ooooo`;o00000oooool2o`0000Kooooo0_l00002ooooo`;o0000
MOooool3o`0005_ooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0000Booooo`;o00002ooo
ool2o`0000Kooooo0_l00005ooooo`?o000000?oooooo`000?l000001?l00003ooooo`?o00000_oo
ool2o`000003ooooool0003o000000;o000000?oooooo`000?l000000_l000000ooooooo0000o`00
0009ooooo`;o0000M_ooool2o`0005cooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l00000
0ooooooo0000o`000005ooooo`;o00005oooool4o`0000;ooooo0_l00005ooooo`?o000000Cooooo
o`000?l0003ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool4o`000004ooooool0
003o0000o`0000;ooooo0_l0000:ooooo`Co000000?oooooo`000?l00000dOooool001kooooo00?o
0000ooooooooool06_ooool2o`0000Gooooo0_l00003ooooo`;o00004_ooool4o`0000Oooooo0_l0
00000ooooooo0000o`000008ooooo`;o00000oooool;o`0000Kooooo0ol00004ooooo`;o00000ooo
ool2o`000<?ooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`0Vooooo`;o00001Oooool2
o`0000_ooooo1_l00004ooooo`?o00004?ooool4o`000003ooooool0003o000000Co00001_ooool3
o`0000Cooooo0_l0001Gooooo`;o0000Koooool2o`0000cooooo000Nooooo`03o`000?oooooooooo
02gooooo0_l00008ooooo`;o000000?oooooo`000?l000001_l00002ooooo`Co000000?oooooo`00
0?l000002_ooool4o`0000Oooooo0ol00006ooooo`;o00001_ooool2o`0001_ooooo0_l0000[oooo
o`;o00002oooool2o`0007gooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l00003ooooo`;o
00006oooool2o`0000Wooooo0_l00002ooooo`?o00000_ooool2o`0000;ooooo1ol00002ooooo`Co
00000_ooool6o`0000?ooooo0_l00002ooooo`?o00001Oooool3o`0000Kooooo0_l0000Kooooo`;o
0000:_ooool3o`0003[ooooo0_l0000Oooooo`;o0000;Oooool001kooooo0_l0000;ooooo`;o0000
0oooool2o`0000Sooooo0_l0000Aooooo`;o00003Oooool3o`0000Kooooo0_l000000ooooooo0000
o`000004ooooo`Co00000_ooool2o`000003ooooool0003o000000Oo00000oooool2o`0000Cooooo
0_l00006ooooo`?o00007oooool2o`0002Kooooo0_l0000kooooo`;o00007oooool2o`0002gooooo
000Nooooo`03o`000?oooooooooo01Wooooo0_l00004ooooo`;o00000oooool2o`0000Oooooo0_l0
0009ooooo`;o00000_ooool2o`0000?ooooo0_l00009ooooo`?o000000Coooooo`000?l0003ooooo
3?l00003ooooo`Co00001Oooool2o`0000;ooooo1?l0000Oooooo`;o0000?Oooool2o`0007Cooooo
000Nooooo`03o`000?oooooooooo01?ooooo0_l0000:ooooo`;o00000oooool2o`0000Kooooo0ol0
0009ooooo`;o00001oooool2o`000003ooooool0003o000000Cooooo1Ol000001?oooooo0000o`00
0?ooool4o`0000Cooooo0ol00003ooooo`;o000000?oooooo`000?l000001?ooool4o`000003oooo
ool0003o0000063ooooo0_l0001dooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o000000?o
ooooo`000?l000003_ooool4o`0000Gooooo0_l00006ooooo`;o00002Oooool2o`0000?ooooo0_l0
0004ooooo`Go00002_ooool2o`0000;ooooo0_l00002ooooo`;o00001oooool4o`0000;ooooo0_l0
003Eooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o00004Oooool4o`0000gooooo0_l00003
ooooo`;o00001?ooool3o`0000[ooooo0ol000001?oooooo0000o`000?l00002ooooo`?o000000Go
ooooo`000?l0003o0000ooooo`02o`0000kooooo0_l000000ooooooo0000o`000002o`000;;ooooo
0_l0000Oooooo`007_ooool00ol0003oooooooooo`02o`0003Cooooo0_l000000ooooooo0000o`00
0005ooooo`;o00000_ooool2o`0000Cooooo3_l000001?oooooo0000o`000?l0000Aooooo`;o0000
0oooool4o`000;3ooooo0_l0000Oooooo`007_ooool00ol0003oooooooooo`02o`0002kooooo0_l0
0004ooooo`;o00001oooool2o`0000?ooooo1?l00002ooooo`_o000000?oooooo`000?l000000_oo
ool2o`0001Sooooo0_l0000Uooooo`;o0000G_ooool2o`0002Cooooo0_l0000Tooooo`007_ooool0
0ol0003oooooooooo`0`ooooo`;o000000?oooooo`000?l000002_ooool2o`0000Gooooo0_l00005
ooooo`;o00000_ooool7o`0001Sooooo0_l00002ooooo`;o00009Oooool2o`0005kooooo0_l0000T
ooooo`;o00009?ooool001kooooo00?o0000ooooooooool0<oooool2o`0001Sooooo0_l000000ooo
oooo0000o`000002ooooo`Ko00005_ooool2o`0000Sooooo0_l00010ooooo`;o0000>Oooool2o`00
04kooooo000Nooooo`03o`000?oooooooooo03Wooooo0_l000000ooooooo0000o`000008ooooo`Co
00001Oooool3o`000004ooooool0003o0000ooooo`Co00000_ooool2o`0001cooooo0_l0000?oooo
o`;o0000;oooool2o`0003Wooooo0_l0001>ooooo`007_ooool00ol0003oooooooooo`0Kooooo`;o
00006Oooool5o`000003ooooool0003o000000Sooooo1?l00005ooooo`Ko00000_ooool8o`0002co
oooo0_l0002=ooooo`;o0000:oooool001kooooo00?o0000ooooooooool06oooool2o`0001Wooooo
1_l0000:ooooo`;o00001oooool4o`0000;ooooo1ol000000ooooooo0000o`000002ooooo`;o0000
3_ooool2o`000:Oooooo0_l0000[ooooo`007_ooool00ol0003oooooooooo`0jooooo`;o00002?oo
ool2o`0000Kooooo0_l000000ooooooo0000o`000007o`0000;ooooo0_l000000ooooooo0000o`00
0002ooooo`;o00003_ooool2o`000=Cooooo000Nooooo`03o`000?oooooooooo02gooooo0_l00009
ooooo`?o00001Oooool2o`0000;ooooo0_l00006ooooo`Go00000_ooool2o`000003ooooool0003o
000000Gooooo0_l00004ooooo`;o00003?ooool2o`0000Cooooo0_l0002aooooo`;o00006oooool0
01kooooo00?o0000ooooooooool04_ooool2o`0001Wooooo0_l00009ooooo`?o00001Oooool2o`00
00cooooo0ol00002ooooo`;o00003_ooool2o`0000cooooo0_l00004ooooo`;o0000/Oooool2o`00
01_ooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0000kooooo`;o00002Oooool2o`0000Go
oooo0_l0000Dooooo`;o00000_ooool2o`0000Gooooo1?l0001Cooooo`;o0000;oooool2o`0003_o
oooo000Nooooo`;o0000:?ooool2o`00017ooooo0_l0000Cooooo`;o000000?oooooo`000?l00000
0_l00004ooooo`Co00000oooool2o`0001Sooooo0_l00005ooooo`Co0000Doooool2o`0002oooooo
0_l0000kooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o00002?ooool2o`0000;ooooo0_l0
000=ooooo`;o00004oooool2o`000003ooooool0003o000000;o00001_ooool2o`000:Gooooo0_l0
0012ooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o00003?ooool2o`0002Kooooo0_l0000>
ooooo`;o00001Oooool2o`000003ooooool0003o000000Gooooo0_l0000>ooooo`;o00005_ooool2
o`0006Gooooo0_l0000Xooooo`;o00006?ooool001kooooo00?o0000ooooooooool07_ooool2o`00
01cooooo0_l0000>ooooo`;o00005Oooool2o`0000?ooooo1?l000000ooooooo0000o`000005oooo
o`;o00000_ooool2o`0000[ooooo0_l0000<ooooo`;o00002?ooool2o`0008oooooo0_l0000Hoooo
o`007_ooool00ol0003oooooooooo`0Nooooo`;o00007?ooool2o`0000kooooo0_l0000Aooooo`;o
00001oooool2o`0000kooooo0_l0000Hooooo`;o0000/oooool001kooooo00?o0000ooooooooool0
8?ooool2o`0000Sooooo1?l0000Pooooo`;o00000_ooool3o`0000[ooooo0_l00026ooooo`;o0000
G_ooool001kooooo00?o0000ooooooooool08?ooool2o`0000Sooooo1_l0000Looooo`Co00000_oo
ool4o`0000?ooooo0_l00002ooooo`;o00001oooool2o`0001gooooo0_l0001Pooooo`;o00007ooo
ool2o`0003gooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l00005ooooo`;o00004oooool2
o`0000Gooooo1Ol00003ooooo`Co00000oooool2o`0000;ooooo0_l00007ooooo`;o00007Oooool2
o`00087ooooo0_l0000mooooo`007_ooool00ol0003oooooooooo`08ooooo`;o00007Oooool2o`00
01[ooooo0_l00005ooooo`;o000000?oooooo`000?l000002_ooool2o`0000Oooooo1?l0001Loooo
o`;o0000Poooool001kooooo00?o0000ooooooooool02?ooool2o`0005Sooooo1?l0000Tooooo`;o
0000=_ooool2o`0008?ooooo000Nooooo`03o`000?oooooooooo017ooooo0_l0000;ooooo`;o0000
2oooool2o`0000[ooooo0_l0001Aooooo`;o0000:?ooool2o`00097ooooo000Nooooo`03o`000?oo
oooooooo017ooooo0_l0000;ooooo`;o00002Oooool4o`0000[ooooo0_l0001Booooo`;o00009ooo
ool2o`00097ooooo000Nooooo`03o`000?oooooooooo02Sooooo0ol0001Pooooo`;o0000^_ooool0
01kooooo00?o0000ooooooooool04Oooool2o`0000Oooooo0_l00007ooooo`;o00000oooool4o`00
00gooooo0_l0000Yooooo`?o0000h?ooool001Cooooo1?l000000ol@413oooooooooo`03ooooo`03
o`000?oooooooooo013ooooo1Ol00005ooooo`;o00001oooool2o`0000Gooooo0_l0000=ooooo`;o
0000:Oooool3o`000>3ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
4?ooool2o`000003ooooool0003o000001?ooooo0_l0000?ooooo`;o00008Oooool2o`000>Wooooo
000Fooooo`03o`000?oooooooooo00Gooooo0ol0000Xooooo`;o00001oooool2o`0000Kooooo0_l0
000Qooooo`;o000000?oooooo`000?l00000G?ooool2o`0008Sooooo000Fooooo`03o`000?oooooo
oooo03Wooooo0_l0000/ooooo`;o0000G?ooool2o`0008Sooooo000Fooooo`03o`000?oooooooooo
0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003ooooo
ooooo`3ooooooe3ooooo000Dooooo`03oeEEEOmVIVKo00000?ooooooD_ooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.33696 .93731 Mdot
.39436 .84553 Mdot
.1622 .89946 Mdot
.25567 .9841 Mdot
.13169 .87648 Mdot
.19267 .89544 Mdot
.16618 .19238 Mdot
.20184 .87443 Mdot
.29765 .92427 Mdot
.19004 .56883 Mdot
.10099 .84743 Mdot
.25587 .70873 Mdot
.12524 .84191 Mdot
.8378 .81126 Mdot
.19304 .8446 Mdot
.37909 .49127 Mdot
.48478 .99499 Mdot
.20334 .87341 Mdot
.3357 .95785 Mdot
.29822 .96893 Mdot
.4563 .74035 Mdot
.26905 .84272 Mdot
.22231 .83203 Mdot
.3366 .63703 Mdot
.30462 .93892 Mdot
.20924 .86285 Mdot
.26856 .87991 Mdot
.17131 .10363 Mdot
.12474 .78541 Mdot
.25041 .85965 Mdot
.2164 .91942 Mdot
.19428 .85892 Mdot
.28516 .8678 Mdot
.37936 .15954 Mdot
.33611 .66976 Mdot
.17818 .91988 Mdot
.38263 .8733 Mdot
.60524 .80857 Mdot
.30295 .72298 Mdot
.29215 .93547 Mdot
.2464 .93067 Mdot
.16564 .70682 Mdot
.25895 .95698 Mdot
.29346 .7415 Mdot
.03034 .56987 Mdot
.22669 .75782 Mdot
.526 .14942 Mdot
.23254 .9454 Mdot
.20102 .94681 Mdot
.47734 .11063 Mdot
.46082 .85899 Mdot
.33454 .93084 Mdot
.10818 .84266 Mdot
.13473 .73687 Mdot
.101 .82855 Mdot
.50614 .59016 Mdot
.83444 .9543 Mdot
.11522 .85309 Mdot
.26492 .87429 Mdot
.9578 .88191 Mdot
.19645 .90585 Mdot
.24642 .87714 Mdot
.1515 .97793 Mdot
.28564 .91564 Mdot
.16422 .94155 Mdot
.23682 .9049 Mdot
.32384 .99141 Mdot
.27048 .87831 Mdot
.17284 .88207 Mdot
.55803 .91944 Mdot
.73356 .79077 Mdot
.24112 .82197 Mdot
.91971 .95636 Mdot
.23332 .81815 Mdot
.13811 .99998 Mdot
.84852 .00462 Mdot
.34263 .89606 Mdot
.72622 .05751 Mdot
.22592 .86889 Mdot
.20649 .93193 Mdot
.22448 .90398 Mdot
.69324 .20353 Mdot
.35129 .25219 Mdot
.21835 .87088 Mdot
.24893 .87886 Mdot
.95841 .53251 Mdot
.17716 .88539 Mdot
.26755 .93304 Mdot
.17837 .86229 Mdot
.16223 .87452 Mdot
.18978 .80343 Mdot
.16375 .5276 Mdot
.24464 .76969 Mdot
.61567 .69215 Mdot
.12514 .86408 Mdot
.27508 .80864 Mdot
.27008 .27551 Mdot
.29558 .6266 Mdot
.10393 .79954 Mdot
.20103 .2163 Mdot
.2667 .85347 Mdot
.4313 .8765 Mdot
.05606 .90022 Mdot
.36503 .10636 Mdot
.35863 .95623 Mdot
.21517 .80595 Mdot
.27819 .04901 Mdot
.29883 .96772 Mdot
.25008 .08453 Mdot
.41494 .15453 Mdot
.3956 .90275 Mdot
.80031 .31252 Mdot
.14678 .93712 Mdot
.18965 .8857 Mdot
.09876 .85882 Mdot
.10885 .5407 Mdot
.06307 .59911 Mdot
.14334 .82753 Mdot
.40513 .04013 Mdot
.14224 .86453 Mdot
.30047 .90395 Mdot
.2519 .06595 Mdot
.13751 .96842 Mdot
.3641 .98014 Mdot
.01427 .95536 Mdot
.39434 .45057 Mdot
.47247 .85701 Mdot
.35009 .93739 Mdot
.60763 .90974 Mdot
.08016 .02857 Mdot
.29624 .56543 Mdot
.74555 .24569 Mdot
.27468 .73927 Mdot
.28121 .84022 Mdot
.27815 .89682 Mdot
.31701 .92981 Mdot
.21164 .80735 Mdot
.44164 .98102 Mdot
.2708 .92666 Mdot
.21656 .92474 Mdot
.35743 .91054 Mdot
.2567 .89763 Mdot
.31497 .82346 Mdot
.23621 .17628 Mdot
.63547 .89941 Mdot
.25157 .71007 Mdot
.34548 .85474 Mdot
.27588 .86769 Mdot
.83278 .98476 Mdot
.45095 .39586 Mdot
.19812 .72156 Mdot
.29432 .85667 Mdot
.27003 .71703 Mdot
.30134 .96564 Mdot
.21342 .8457 Mdot
.13898 .81607 Mdot
.30783 .85845 Mdot
.93602 .36663 Mdot
.28161 .93505 Mdot
.37047 .45597 Mdot
.43115 .01976 Mdot
.2521 .62207 Mdot
.56858 .45277 Mdot
.28104 .85388 Mdot
.12368 .82887 Mdot
.11097 .83565 Mdot
.27476 .87588 Mdot
.25051 .91001 Mdot
.96237 .39992 Mdot
.19506 .78413 Mdot
.26876 .83794 Mdot
.07228 .73187 Mdot
.32943 .64335 Mdot
.73237 .58776 Mdot
.24962 .85728 Mdot
.2738 .73903 Mdot
.32646 .64094 Mdot
.15228 .89408 Mdot
.12093 .40233 Mdot
.3472 .90903 Mdot
.21526 .77949 Mdot
.10589 .85145 Mdot
.17411 .81651 Mdot
.00435 .61727 Mdot
.27771 .29363 Mdot
.42579 .92273 Mdot
.31416 .62133 Mdot
.16897 .76075 Mdot
.23392 .89397 Mdot
.13376 .74884 Mdot
.3075 .90286 Mdot
.58791 .63181 Mdot
.3519 .93468 Mdot
.48042 .00226 Mdot
.07962 .70124 Mdot
.16208 .80472 Mdot
.23714 .66198 Mdot
.17933 .9504 Mdot
.30856 .92071 Mdot
.18645 .98425 Mdot
.51533 .1203 Mdot
.73363 .57108 Mdot
.29221 .8705 Mdot
.12274 .54326 Mdot
.3027 .9352 Mdot
.26433 .94349 Mdot
.64614 .44183 Mdot
.26322 .87766 Mdot
.8325 .8371 Mdot
.25729 .76296 Mdot
.16417 .79475 Mdot
.37413 .88434 Mdot
.18123 .21858 Mdot
.34007 .35538 Mdot
.42354 .99224 Mdot
.33463 .40624 Mdot
.27001 .91644 Mdot
.1505 .72746 Mdot
.22525 .18548 Mdot
.091 .58983 Mdot
.79 .84149 Mdot
.98827 .86281 Mdot
.19916 .85646 Mdot
.22725 .90298 Mdot
.11874 .85737 Mdot
.27862 .82096 Mdot
.01137 .02935 Mdot
.25704 .92563 Mdot
.26792 .68831 Mdot
.30096 .84621 Mdot
.19216 .83158 Mdot
.97922 .87422 Mdot
.29656 .8241 Mdot
.1217 .21173 Mdot
.42802 .49637 Mdot
.67164 .76898 Mdot
.68382 .17852 Mdot
.1809 .89652 Mdot
.38394 .79745 Mdot
.66371 .76222 Mdot
.1263 .87554 Mdot
.3005 .8148 Mdot
.33591 .09629 Mdot
.29827 .76582 Mdot
.35881 .78837 Mdot
.16826 .0503 Mdot
.98976 .80045 Mdot
.2977 .81645 Mdot
.0195 .08505 Mdot
.24774 .92879 Mdot
.31215 .00417 Mdot
.13093 .80852 Mdot
.06191 .97755 Mdot
.06635 .41287 Mdot
.02885 .53849 Mdot
.21151 .03689 Mdot
.11309 .83661 Mdot
.79379 .7467 Mdot
.29228 .99107 Mdot
.6757 .73854 Mdot
.36499 .90603 Mdot
.22137 .84525 Mdot
.24577 .91443 Mdot
.24281 .99992 Mdot
.30145 .81931 Mdot
.8338 .16333 Mdot
.36592 .98078 Mdot
.38601 .65486 Mdot
.16714 .86495 Mdot
.29297 .91121 Mdot
.1111 .81015 Mdot
.58059 .891 Mdot
.19232 .86512 Mdot
.21905 .83862 Mdot
.18645 .84275 Mdot
.15674 .79987 Mdot
.30064 .14632 Mdot
.93508 .06904 Mdot
.13492 .83798 Mdot
.45844 .91986 Mdot
.7455 .06517 Mdot
.28256 .83163 Mdot
.26744 .92532 Mdot
.17923 .79661 Mdot
.11363 .84489 Mdot
.21233 .86834 Mdot
.19439 .8056 Mdot
.20571 .27388 Mdot
.18913 .13152 Mdot
.43578 .94028 Mdot
.33348 .122 Mdot
.58379 .00643 Mdot
.33334 .97124 Mdot
.19461 .97422 Mdot
.1752 .62013 Mdot
.10983 .20048 Mdot
.15609 .90302 Mdot
.15407 .08016 Mdot
.98884 .90816 Mdot
.08448 .12967 Mdot
.40365 .06907 Mdot
.10949 .76261 Mdot
.28088 .58648 Mdot
.17206 .76848 Mdot
.63822 .50812 Mdot
.20282 .09464 Mdot
.26123 .88058 Mdot
.23461 .85385 Mdot
.25953 .35207 Mdot
.65153 .57099 Mdot
.28326 .89284 Mdot
.73496 .56891 Mdot
.22372 .8614 Mdot
.01908 .7291 Mdot
.22857 .95447 Mdot
.19139 .88745 Mdot
.34142 .66133 Mdot
.52421 .90886 Mdot
.14826 .86933 Mdot
.11787 .42908 Mdot
.31014 .74202 Mdot
.27004 .89449 Mdot
.4282 .93727 Mdot
.24092 .62952 Mdot
.22065 .89945 Mdot
.17559 .82316 Mdot
.13849 .85563 Mdot
.36873 .87078 Mdot
.27473 .74505 Mdot
.2183 .84753 Mdot
.28804 .91568 Mdot
.17977 .90339 Mdot
.13408 .04144 Mdot
.36448 .73882 Mdot
.24398 .98966 Mdot
.28007 .28938 Mdot
.81017 .63562 Mdot
.29175 .8924 Mdot
.28435 .40279 Mdot
.88477 .75651 Mdot
.14222 .84378 Mdot
.37479 .25083 Mdot
.37195 .86872 Mdot
.11435 .76707 Mdot
.42417 .67665 Mdot
.05535 .70629 Mdot
.31764 .95025 Mdot
.09773 .38874 Mdot
.13074 .86054 Mdot
.192 .87973 Mdot
.1571 .8405 Mdot
.097 .81907 Mdot
.14828 .59828 Mdot
.38921 .49656 Mdot
.41754 .27518 Mdot
.19552 .87359 Mdot
.30611 .81685 Mdot
.30217 .94005 Mdot
.10914 .85702 Mdot
.95428 .83636 Mdot
.29675 .81833 Mdot
.22512 .79333 Mdot
.23637 .92501 Mdot
.16135 .78315 Mdot
.17451 .82178 Mdot
.27336 .00537 Mdot
.46933 .65789 Mdot
.29238 .32526 Mdot
.03761 .22805 Mdot
.19089 .86539 Mdot
.48151 .0802 Mdot
.25325 .88479 Mdot
.18933 .8875 Mdot
.27186 .89749 Mdot
.67992 .91542 Mdot
.473 .56124 Mdot
.07999 .66799 Mdot
.23433 .97793 Mdot
.0746 .70165 Mdot
.29428 .84854 Mdot
.21903 .87352 Mdot
.26959 .92057 Mdot
.5538 .17419 Mdot
.2484 .39956 Mdot
.18341 .15481 Mdot
.42743 .06027 Mdot
.4938 .9275 Mdot
.39525 .18225 Mdot
.28407 .89056 Mdot
.16795 .89711 Mdot
.35924 .90764 Mdot
.11373 .84977 Mdot
.23576 .83467 Mdot
.12989 .8916 Mdot
.13873 .8918 Mdot
.48614 .75563 Mdot
.55066 .91707 Mdot
.67907 .90988 Mdot
.26753 .87249 Mdot
.2245 .90915 Mdot
.30506 .02356 Mdot
.03799 .54867 Mdot
.98151 .43249 Mdot
.24177 .87653 Mdot
.50801 .99727 Mdot
.27798 .70657 Mdot
.44225 .00962 Mdot
.19116 .84249 Mdot
.17347 .69109 Mdot
.27634 .84473 Mdot
.50578 .03846 Mdot
.29743 .93407 Mdot
.43468 .00572 Mdot
.53233 .23443 Mdot
.75104 .72884 Mdot
.20091 .83826 Mdot
.04392 .0452 Mdot
.3154 .86078 Mdot
.00043 .63299 Mdot
.22766 .86377 Mdot
.27906 .9146 Mdot
.51863 .07848 Mdot
.29537 .02558 Mdot
.12799 .84093 Mdot
.14802 .85332 Mdot
.27632 .65997 Mdot
.79737 .95099 Mdot
.29953 .89739 Mdot
.14194 .79167 Mdot
.67639 .73314 Mdot
.4879 .49002 Mdot
.48258 .99149 Mdot
.01149 .15825 Mdot
.28091 .90069 Mdot
.35772 .09955 Mdot
.91919 .92028 Mdot
.27005 .13005 Mdot
.15843 .41727 Mdot
.30508 .86849 Mdot
.04763 .57024 Mdot
.34859 .00798 Mdot
.32421 .06478 Mdot
.01321 .20795 Mdot
.19808 .86981 Mdot
.12451 .72812 Mdot
.23133 .85484 Mdot
.22958 .91858 Mdot
.12824 .83909 Mdot
.21555 .71918 Mdot
.16884 .061 Mdot
.33913 .03991 Mdot
.24404 .11409 Mdot
.16871 .86288 Mdot
.2223 .88183 Mdot
.17064 .8913 Mdot
.27695 .88388 Mdot
.30774 .9367 Mdot
.14117 .82438 Mdot
.60843 .85037 Mdot
.39184 .12648 Mdot
.22093 .96994 Mdot
.26225 .90732 Mdot
.21638 .88147 Mdot
.10637 .89694 Mdot
.2317 .1637 Mdot
.29159 .55148 Mdot
.27741 .88546 Mdot
.88825 .5083 Mdot
.19545 .84321 Mdot
.25035 .93265 Mdot
.20854 .85989 Mdot
.20773 .88606 Mdot
.21924 .87436 Mdot
.21785 .87237 Mdot
.148 .92197 Mdot
.20729 .86438 Mdot
.12028 .86088 Mdot
.17102 .85048 Mdot
.43567 .81876 Mdot
.11312 .90831 Mdot
.74359 .58464 Mdot
.48358 .83908 Mdot
.3041 .81846 Mdot
.35769 .88745 Mdot
.34248 .93048 Mdot
.88991 .09096 Mdot
.09631 .3715 Mdot
.21194 .58845 Mdot
.02732 .70964 Mdot
.18408 .12618 Mdot
.19905 .88666 Mdot
.2655 .92195 Mdot
.14569 .68453 Mdot
.47218 .82494 Mdot
.22987 .87379 Mdot
.17682 .96092 Mdot
.16271 .79471 Mdot
.15473 .95983 Mdot
.49037 .89106 Mdot
.30482 .63136 Mdot
.07144 .96621 Mdot
.15529 .10092 Mdot
.05992 .6885 Mdot
.45652 .04687 Mdot
.19631 .84384 Mdot
.96066 .78928 Mdot
.22388 .88163 Mdot
.88625 .09349 Mdot
.30889 .93612 Mdot
.28972 .88802 Mdot
.31313 .88071 Mdot
.70545 .54155 Mdot
.30703 .16131 Mdot
.25521 .01236 Mdot
.13501 .87642 Mdot
.78314 .85506 Mdot
.26522 .8084 Mdot
.30681 .61339 Mdot
.20324 .28935 Mdot
.25019 .89516 Mdot
.3312 .92943 Mdot
.12074 .92378 Mdot
.22249 .87197 Mdot
.16352 .9708 Mdot
.2805 .26171 Mdot
.49531 .92401 Mdot
.30712 .04396 Mdot
.75505 .78267 Mdot
.061 .68969 Mdot
.50322 .72214 Mdot
.81585 .67338 Mdot
.92496 .7317 Mdot
.1187 .85529 Mdot
.38939 .74716 Mdot
.21055 .86396 Mdot
.27109 .85847 Mdot
.17552 .95795 Mdot
.27269 .86005 Mdot
.02303 .17397 Mdot
.6251 .75994 Mdot
.2132 .92443 Mdot
.31817 .4769 Mdot
.20442 .76619 Mdot
.21256 .8576 Mdot
.23382 .94264 Mdot
.27137 .29415 Mdot
.45773 .49657 Mdot
.28747 .01065 Mdot
.26173 .83625 Mdot
.1759 .82338 Mdot
.40307 .88932 Mdot
.12552 .01435 Mdot
.28254 .85454 Mdot
.47124 .16151 Mdot
.29004 .03801 Mdot
.76483 .22647 Mdot
.19503 .61899 Mdot
.29868 .89387 Mdot
.19206 .90148 Mdot
.37897 .94483 Mdot
.26106 .82008 Mdot
.08369 .91308 Mdot
.66947 .86234 Mdot
.1027 .20716 Mdot
.19024 .81512 Mdot
.15989 .9182 Mdot
.44846 .05943 Mdot
.18142 .85401 Mdot
.84434 .42608 Mdot
.18086 .86804 Mdot
.99886 .81461 Mdot
.31181 .13137 Mdot
.20425 .8684 Mdot
.36911 .84506 Mdot
.11079 .85601 Mdot
.32226 .86565 Mdot
.02427 .52986 Mdot
.11927 .79368 Mdot
.14564 .81345 Mdot
.09087 .98435 Mdot
.03611 .56412 Mdot
.4246 .94658 Mdot
.1668 .86166 Mdot
.33422 .91865 Mdot
.98854 .93488 Mdot
.24985 .99378 Mdot
.39688 .95527 Mdot
.10651 .35932 Mdot
.23023 .16337 Mdot
.12762 .89907 Mdot
.15699 .84842 Mdot
.08917 .85457 Mdot
.13727 .73242 Mdot
.19275 .95863 Mdot
.35143 .73226 Mdot
.23749 .85936 Mdot
.28544 .8367 Mdot
.18787 .83105 Mdot
.22276 .98611 Mdot
.20412 .01583 Mdot
.32754 .83988 Mdot
.25781 .89869 Mdot
.19552 .88199 Mdot
.29383 .58796 Mdot
.17386 .13288 Mdot
.28497 .88678 Mdot
.28674 .89789 Mdot
.26718 .83481 Mdot
.40102 .14055 Mdot
.34802 .92869 Mdot
.11088 .75598 Mdot
.24977 .49668 Mdot
.16555 .86485 Mdot
.66507 .66096 Mdot
.34163 .94028 Mdot
.31081 .3704 Mdot
.20375 .81311 Mdot
.15275 .80666 Mdot
.10279 .77085 Mdot
.46428 .12271 Mdot
.94396 .1447 Mdot
.01512 .76633 Mdot
.34511 .93148 Mdot
.39411 .32882 Mdot
.14388 .50754 Mdot
.29197 .05721 Mdot
.48914 .52617 Mdot
.60522 .9073 Mdot
.18823 .85144 Mdot
.40796 .92418 Mdot
.24118 .89352 Mdot
.23742 .90959 Mdot
.00356 .89772 Mdot
.02458 .92196 Mdot
.2035 .87108 Mdot
.15996 .68672 Mdot
.20951 .8686 Mdot
.30736 .79929 Mdot
.12064 .87363 Mdot
.18021 .84534 Mdot
.46056 .93519 Mdot
.18838 .88092 Mdot
.29007 .80614 Mdot
.32089 .82772 Mdot
.02832 .28214 Mdot
.35996 .89736 Mdot
.47156 .79372 Mdot
.48282 .28003 Mdot
.22175 .86257 Mdot
.26454 .11707 Mdot
.46065 .85774 Mdot
.09676 .95035 Mdot
.99382 .89985 Mdot
.22084 .90214 Mdot
.28611 .6733 Mdot
.29687 .93653 Mdot
.08155 .86083 Mdot
.69044 .93149 Mdot
.69581 .83676 Mdot
.27189 .87621 Mdot
.0741 .71594 Mdot
.20412 .86898 Mdot
.52735 .92639 Mdot
.30112 .9318 Mdot
.72209 .78925 Mdot
.2627 .70938 Mdot
.23114 .85815 Mdot
.31364 .94354 Mdot
.24287 .14634 Mdot
.95068 .74816 Mdot
.6461 .01255 Mdot
.86147 .25517 Mdot
.42764 .92244 Mdot
.32122 .89902 Mdot
.71596 .26613 Mdot
.24346 .87015 Mdot
.92608 .46701 Mdot
.12035 .84533 Mdot
.56389 .89201 Mdot
.05165 .55447 Mdot
.33298 .90607 Mdot
.21903 .15615 Mdot
.94278 .23954 Mdot
.33965 .93884 Mdot
.18331 .86861 Mdot
.28526 .63353 Mdot
.47282 .82449 Mdot
.47127 .37134 Mdot
.01373 .91172 Mdot
.14488 .88029 Mdot
.22404 .96614 Mdot
.0117 .52567 Mdot
.2783 .90215 Mdot
.13515 .05209 Mdot
.30577 .85497 Mdot
.19459 .90445 Mdot
.21818 .88542 Mdot
.80419 .95297 Mdot
.20441 .48095 Mdot
.0843 .22986 Mdot
.21306 .77756 Mdot
.3655 .47588 Mdot
.13862 .81577 Mdot
.28697 .92562 Mdot
.22138 .78231 Mdot
.17454 .95617 Mdot
.75672 .43053 Mdot
.35967 .99744 Mdot
.32991 .25175 Mdot
.32058 .89874 Mdot
.85679 .9897 Mdot
.07631 .82999 Mdot
.05565 .52844 Mdot
.29291 .27132 Mdot
.24872 .91674 Mdot
.23786 .19496 Mdot
.29972 .81462 Mdot
.15037 .89489 Mdot
.3458 .29909 Mdot
.28281 .82149 Mdot
.37262 .86505 Mdot
.56985 .71866 Mdot
.32554 .89676 Mdot
.81412 .24083 Mdot
.39722 .39517 Mdot
.76111 .99759 Mdot
.99435 .79017 Mdot
.30616 .9124 Mdot
.89949 .93556 Mdot
.49039 .29403 Mdot
.22906 .95686 Mdot
.28566 .85885 Mdot
.1435 .81542 Mdot
.25363 .92833 Mdot
.5886 .59943 Mdot
.29691 .62144 Mdot
.23967 .44139 Mdot
.44157 .13694 Mdot
.42586 .77081 Mdot
.46658 .71481 Mdot
.2226 .89747 Mdot
.28445 .97008 Mdot
.19711 .81554 Mdot
.46155 .13776 Mdot
.74417 .0336 Mdot
.49128 .84769 Mdot
.30153 .85893 Mdot
.7982 .00362 Mdot
.05544 .89876 Mdot
.07147 .21179 Mdot
.3856 .07976 Mdot
.16995 .90427 Mdot
.16507 .96444 Mdot
.35913 .85332 Mdot
.33882 .89482 Mdot
.13648 .81304 Mdot
.1649 .80365 Mdot
.1707 .82937 Mdot
.09943 .8643 Mdot
.20319 .89871 Mdot
.65661 .90451 Mdot
.20863 .87813 Mdot
.92931 .50579 Mdot
.15655 .90666 Mdot
.36798 .06035 Mdot
.21651 .94136 Mdot
.23756 .25632 Mdot
.07511 .50494 Mdot
.17816 .9493 Mdot
.80913 .44385 Mdot
.26407 .93183 Mdot
.19541 .67367 Mdot
.23401 .79769 Mdot
.13063 .80837 Mdot
.60583 .28374 Mdot
.31195 .90725 Mdot
.10043 .8073 Mdot
.19856 .88801 Mdot
.1598 .96476 Mdot
.98138 .5421 Mdot
.26233 .98504 Mdot
.21125 .03258 Mdot
.55144 .36975 Mdot
.46931 .44144 Mdot
.20489 .93597 Mdot
.3097 .162 Mdot
.41503 .50721 Mdot
.21787 .926 Mdot
.26122 .91949 Mdot
.15115 .81465 Mdot
.37481 .97964 Mdot
.06045 .17879 Mdot
.4972 .11054 Mdot
.16662 .87775 Mdot
.16279 .70698 Mdot
.08159 .85333 Mdot
.21684 .13018 Mdot
.09393 .76805 Mdot
.23928 .95388 Mdot
.04286 .81243 Mdot
.28547 .44979 Mdot
.26009 .84146 Mdot
.16063 .86228 Mdot
.08968 .68657 Mdot
.99791 .85188 Mdot
.22105 .86513 Mdot
.16696 .80106 Mdot
.08932 .74008 Mdot
.11976 .16044 Mdot
.3517 .95703 Mdot
.30913 .06561 Mdot
.21991 .95546 Mdot
.11061 .91528 Mdot
.44031 .64707 Mdot
.17101 .7451 Mdot
.24271 .88527 Mdot
.24204 .18114 Mdot
.64653 .85993 Mdot
.20626 .83888 Mdot
.44712 .30882 Mdot
.20913 .86749 Mdot
.18908 .84356 Mdot
.0849 .79974 Mdot
.13672 .8191 Mdot
.19764 .89353 Mdot
.4548 .12304 Mdot
.12104 .84437 Mdot
.10676 .79409 Mdot
.39082 .12178 Mdot
.19338 .0265 Mdot
.33542 .88787 Mdot
.23871 .25064 Mdot
.10858 .86236 Mdot
.5174 .32242 Mdot
.36736 .82435 Mdot
.26443 .82221 Mdot
.73836 .57043 Mdot
.20614 .95024 Mdot
.17712 .80044 Mdot
.8878 .14613 Mdot
.15836 .69492 Mdot
.18592 .83652 Mdot
.2603 .87738 Mdot
.27025 .9213 Mdot
.81392 .95166 Mdot
.11481 .08328 Mdot
.97488 .56141 Mdot
.15658 .83727 Mdot
.24138 .86396 Mdot
.17389 .9075 Mdot
.6895 .9905 Mdot
.14372 .85328 Mdot
.26142 .93885 Mdot
.09858 .98522 Mdot
.28974 .91359 Mdot
.07963 .48311 Mdot
.20834 .87273 Mdot
.22315 .34556 Mdot
.07256 .88997 Mdot
.13872 .87363 Mdot
.20766 .85437 Mdot
.21936 .95307 Mdot
.32567 .88493 Mdot
.99953 .027 Mdot
.21152 .85753 Mdot
.10345 .87979 Mdot
.33237 .93941 Mdot
.29685 .11761 Mdot
.53836 .47566 Mdot
.15021 .83365 Mdot
.6351 .11516 Mdot
.28521 .88405 Mdot
.27746 .92059 Mdot
.24248 .91403 Mdot
.26699 .92641 Mdot
.17156 .89493 Mdot
.05128 .9976 Mdot
.5651 .9383 Mdot
.06708 .52365 Mdot
.34407 .9031 Mdot
.39101 .85192 Mdot
.21908 .90535 Mdot
.21952 .87748 Mdot
.10503 .91514 Mdot
.0836 .96808 Mdot
.33532 .93027 Mdot
.3651 .87862 Mdot
.19927 .96271 Mdot
.27703 .83726 Mdot
.4284 .85213 Mdot
.49422 .03043 Mdot
.79199 .90591 Mdot
.23158 .08926 Mdot
.29325 .82394 Mdot
.23989 .62032 Mdot
.20462 .89139 Mdot
.5276 .40097 Mdot
.18511 .84418 Mdot
.21503 .7582 Mdot
.10746 .77068 Mdot
.32243 .90202 Mdot
.39152 .95071 Mdot
.38271 .48571 Mdot
.29508 .83647 Mdot
.00691 .83993 Mdot
.93217 .6882 Mdot
.47718 .21933 Mdot
.30469 .84613 Mdot
.32923 .97111 Mdot
.3756 .85914 Mdot
.44286 .80311 Mdot
.52536 .70385 Mdot
.30537 .9824 Mdot
.30546 .8704 Mdot
.29938 .80336 Mdot
.20734 .03789 Mdot
.32953 .80679 Mdot
.25408 .87712 Mdot
.26915 .5616 Mdot
.28571 .91289 Mdot
.95406 .15449 Mdot
.1516 .76463 Mdot
.3823 .87989 Mdot
.22349 .8636 Mdot
.18612 .85009 Mdot
.99697 .105 Mdot
.26083 .66189 Mdot
.16436 .00208 Mdot
.85752 .81786 Mdot
.54721 .84463 Mdot
.40644 .73722 Mdot
.19387 .7936 Mdot
.16469 .84086 Mdot
.30073 .82027 Mdot
.51639 .33672 Mdot
.36287 .92345 Mdot
.96764 .58492 Mdot
.28431 .84623 Mdot
.23571 .85846 Mdot
.39018 .17588 Mdot
.13092 .83079 Mdot
.28371 .96571 Mdot
.30101 .94307 Mdot
.28784 .31731 Mdot
.25668 .03885 Mdot
.20051 .8849 Mdot
.49768 .84782 Mdot
.31172 .81476 Mdot
.21785 .92636 Mdot
.00096 .25898 Mdot
.16243 .85426 Mdot
.82058 .92817 Mdot
.37117 .01314 Mdot
.28883 .05133 Mdot
.11212 .64401 Mdot
.14821 .84561 Mdot
.95966 .69748 Mdot
.26978 .83732 Mdot
.37275 .05426 Mdot
.73106 .93459 Mdot
.26188 .84168 Mdot
.22791 .88849 Mdot
.20229 .8387 Mdot
.19727 .86294 Mdot
.19219 .83227 Mdot
.56403 .34441 Mdot
.38847 .92466 Mdot
.37523 .96045 Mdot
.81537 .6854 Mdot
.27875 .37914 Mdot
.26914 .09933 Mdot
.40276 .19625 Mdot
.33257 .62241 Mdot
.36095 .07206 Mdot
.53982 .94263 Mdot
.23576 .88363 Mdot
.15045 .06882 Mdot
.86569 .73062 Mdot
.24794 .87116 Mdot
.28309 .86857 Mdot
.12828 .88823 Mdot
.98676 .85381 Mdot
.66171 .2323 Mdot
.31231 .65493 Mdot
.30885 .86717 Mdot
.26387 .1067 Mdot
.00963 .9896 Mdot
.03692 .25383 Mdot
.31417 .75361 Mdot
.27937 .87159 Mdot
.53171 .46414 Mdot
.26357 .98932 Mdot
.30241 .73793 Mdot
.55464 .68923 Mdot
.13829 .77745 Mdot
.30543 .91777 Mdot
.21665 .82951 Mdot
.35938 .92837 Mdot
.31603 .0304 Mdot
.14303 .9775 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`04o`000?oooooooooooooo
o`;o00002oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool00_l0000;ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`06ooooo`;o00001Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03?ooool3o`0000oooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00Co0000oooooooooooooooo0_l0000;ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool01?ooool2o`0000Oooooo00?o0000ooooooooool00_l0000;ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool01oooool2o`0000Cooooo00?o0000ooooooooool01_ooool2o`00
00Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`08ooooo`;o00001?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0<ooooo`?o00003_ooool2o`0000oooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo000Nooooo`03o`000?oooooooooo05Go
oooo0_l00002ooooo`;o00004_ooool2o`0001[ooooo0_l000000ooooooo0000o`00000/ooooo`;o
0000E?ooool2o`0003Gooooo000Nooooo`03o`000?oooooooooo04oooooo0_l00008ooooo`;o0000
4_ooool2o`0000Kooooo0_l0000Eooooo`;o0000@?ooool2o`0007Oooooo000Nooooo`03o`000?oo
oooooooo02Gooooo0_l0000Gooooo`;o00003oooool2o`0002Cooooo0_l0001Gooooo`;o0000Mooo
ool001kooooo00?o0000ooooooooool09Oooool2o`0001Oooooo0_l00018ooooo`;o0000_Oooool0
01kooooo00?o0000ooooooooool0R?ooool2o`000;gooooo000Nooooo`03o`000?oooooooooo05co
oooo0_l000000ooooooo0000o`00003Vooooo`007_ooool00ol0003oooooooooo`0Fooooo`;o0000
8oooool2o`0001oooooo0_l000000ooooooo0000o`00003Pooooo`;o00001?ooool001kooooo00?o
0000ooooooooool00_l0000Dooooo`;o00008oooool2o`0002Kooooo0_l0000hooooo`;o0000X_oo
ool2o`0000Cooooo000Nooooo`03o`000?oooooooooo00;o0000?oooool2o`00023ooooo0_l0000h
ooooo`;o0000Coooool2o`0005Oooooo000Nooooo`03o`000?oooooooooo03oooooo1?l0000Goooo
o`;o0000T_ooool2o`0005Oooooo000Nooooo`03o`000?oooooooooo03oooooo1?l0000<ooooo`;o
00002Oooool2o`0000kooooo0_l0000Dooooo`;o00007_ooool2o`000:Gooooo000Nooooo`03o`00
0?oooooooooo02Oooooo0_l0000Vooooo`;o00003oooool2o`0000Sooooo0_l0000Dooooo`;o0000
7_ooool2o`000:Gooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0000Kooooo`;o0000=ooo
ool2o`0002kooooo0_l0002eooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o00009oooool2
o`00027ooooo0_l0000hooooo`;o0000]Oooool001kooooo0_l0000Yooooo`;o00002Oooool2o`00
027ooooo0_l00002ooooo`;o0000joooool001kooooo00?o0000ooooooooool0:?ooool2o`00033o
oooo0_l0000Iooooo`;o0000d?ooool001kooooo00?o0000ooooooooool0Foooool2o`0001Sooooo
0_l0000Gooooo`;o0000F?ooool2o`0005gooooo000Nooooo`03o`000?oooooooooo03?ooooo0_l0
000Vooooo`;o00005oooool2o`00017ooooo0_l00005ooooo`;o0000F?ooool2o`0005gooooo000N
ooooo`03o`000?oooooooooo03?ooooo0_l0000Iooooo`;o00004?ooool2o`0000?ooooo0_l0000=
ooooo`;o00004Oooool2o`0006Gooooo0_l0001Gooooo`007_ooool00ol0003oooooooooo`0]oooo
o`;o00007oooool2o`00013ooooo0_l00003ooooo`;o00006?ooool2o`0006gooooo0_l0000loooo
o`;o00006Oooool001kooooo00?o0000ooooooooool0;Oooool2o`0004;ooooo0_l0000<ooooo`;o
0000Zoooool2o`0001Wooooo000Nooooo`03o`000?oooooooooo077ooooo0_l0003Dooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo02kooooo0_l00019
ooooo`;o00007Oooool2o`0000[ooooo0_l0002Qooooo`007_ooool00ol0003oooooooooo`0Qoooo
o`;o00002oooool2o`0004Wooooo0_l0000Mooooo`;o00002_ooool2o`000:7ooooo000Nooooo`03
o`000?oooooooooo00;ooooo0_l0000Mooooo`;o0000:_ooool2o`000?Sooooo000Nooooo`03o`00
0?oooooooooo00;ooooo0_l00013ooooo`;o00001?ooool2o`000?Sooooo000Nooooo`03o`000?oo
oooooooo04Oooooo0_l0003Cooooo`?o0000:?ooool001kooooo00?o0000ooooooooool0?_ooool2
o`0002Wooooo0_l0002aooooo`?o0000:?ooool001kooooo00?o0000ooooooooool0?_ooool2o`00
01?ooooo0_l0000Dooooo`;o00001Oooool2o`000=Gooooo000Nooooo`;o0000;oooool2o`0002?o
oooo0_l0000Kooooo`;o0000eOooool001kooooo00?o0000ooooooooool0;_ooool2o`0000Cooooo
0_l0003oooooo`_ooooo0_l00005ooooo`007_ooool00ol0003oooooooooo`0dooooo`;o00007?oo
ool2o`0001oooooo0_l0003;ooooo`;o00001Oooool001kooooo00?o0000ooooooooool0D_ooool2
o`0001oooooo0_l0000Rooooo`;o00001Oooool2o`000:Oooooo000Nooooo`03o`000?oooooooooo
04_ooooo0_l0001:ooooo`;o00001Oooool2o`0002[ooooo0_l0001kooooo`007_ooool00ol0003o
ooooooooo`1;ooooo`;o00001Oooool2o`0000Sooooo0_l0001/ooooo`;o0000Noooool001kooooo
00?o0000ooooooooool0D_ooool2o`0000Sooooo0_l00015ooooo`;o0000X_ooool001kooooo00?o
0000ooooooooool0J?ooool2o`00017ooooo0_l0000Cooooo`;o000000?oooooo`000?l000003_oo
ool2o`000:;ooooo000Nooooo`03o`000?oooooooooo03Sooooo0_l0000^ooooo`;o00004Oooool2
o`0001?ooooo0_l000000ooooooo0000o`00002booooo`007_ooool00ol0003oooooooooo`0Goooo
o`;o00007oooool2o`0000Sooooo0_l0000@ooooo`;o00009Oooool2o`000<[ooooo000Nooooo`03
o`000?oooooooooo01Oooooo0_l0000Kooooo`;o00000oooool2o`0000Oooooo0_l0000@ooooo`;o
00002oooool2o`000>Cooooo000Nooooo`03o`000?oooooooooo03Cooooo0_l00003ooooo`;o0000
9_ooool2o`000>Cooooo000Nooooo`03o`000?oooooooooo08_ooooo0_l00005ooooo`;o0000/ooo
ool001kooooo00?o0000ooooooooool0O_ooool2o`0000_ooooo0_l00005ooooo`;o0000/oooool0
01kooooo00?o0000ooooooooool0O_ooool2o`000:oooooo0_l0000Fooooo`007_ooool00ol0003o
ooooooooo`1;ooooo`;o00004Oooool2o`000;gooooo0_l0000@ooooo`;o00005_ooool001kooooo
0_l0001<ooooo`;o00004Oooool2o`0004Oooooo0_l0001dooooo`;o0000:?ooool001kooooo00?o
0000ooooooooool0>?ooool2o`0004Wooooo0_l0000Rooooo`;o0000ROooool2o`0001?ooooo000N
ooooo`03o`000?oooooooooo00;o0000=_ooool2o`0000Wooooo0_l0000nooooo`;o0000[Oooool2
o`0001?ooooo000Nooooo`03o`000?oooooooooo00;o00008Oooool2o`0001kooooo0_l0000Koooo
o`;o00005Oooool2o`000<kooooo000Nooooo`03o`000?oooooooooo02?ooooo0_l0000Rooooo`;o
00005oooool3o`0001Cooooo0_l0000Looooo`;o0000M?ooool2o`0003[ooooo000Nooooo`03o`00
0?oooooooooo04Oooooo0_l0000Hooooo`;o0000<_ooool2o`0007Cooooo0_l0000jooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool00oooool2o`0004Cooooo0_l0000`ooooo`;o0000<oooool2o`00
09Gooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0000;ooooo`;o0000=oooool2o`00033o
oooo0_l0000cooooo`;o0000:?ooool2o`0006_ooooo000Nooooo`03o`000?oooooooooo013ooooo
0_l0000iooooo`;o0000;oooool2o`0005cooooo0_l0001[ooooo`007_ooool00ol0003ooooooooo
o`15ooooo`;o00001?ooool2o`0002oooooo0_l00039ooooo`007_ooool00ol0003oooooooooo`15
ooooo`;o0000ooooool1ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo
03;ooooo0_l0000Eooooo`;o0000o?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0<_ooool2
o`0001Gooooo0_l0000dooooo`;o0000a_ooool000?ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0000Pooooo`;o0000GOooool2o`000<Kooooo0003oooo
o`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooo
oooo023ooooo0_l0002kooooo`;o0000J?ooool000?ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool07Oooool2o`000;kooooo0_l0001X
ooooo`000oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02o`0001_ooooo0_l0003oooooobWooooo0003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool00_l0
000Aooooo`;o00003_ooool2o`000?oooooo8oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0Cooooo`;o0000
3_ooool2o`0001Sooooo0_l0003oooooo`Wooooo000Nooooo`03o`000?oooooooooo03Oooooo0_l0
0004ooooo`;o0000F?ooool2o`000:kooooo000Nooooo`03o`000?oooooooooo03Oooooo0_l0001N
ooooo`;o0000[_ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`08ooooo`;o0000joooool2o`00053ooooo000Nooooo`03o`000?oooooooooo00Sooooo
0_l0000=ooooo`;o0000g?ooool2o`00053ooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0
002@ooooo`;o0000:?ooool2o`0007;ooooo000Nooooo`03o`000?oooooooooo0:Wooooo0_l0000X
ooooo`;o0000L_ooool001kooooo00?o0000ooooooooool0ooooool6ooooo`;o00009oooool2o`00
01Oooooo000Nooooo`03o`000?oooooooooo0?oooooo1_ooool2o`0002Oooooo0_l0000Gooooo`00
7_ooool00ol0003oooooooooo`3^ooooo`;o0000Eoooool001kooooo00?o0000ooooooooool0k_oo
ool2o`0005Oooooo000Nooooo`;o0000B_ooool2o`0001cooooo0_l00005ooooo`;o00001_ooool2
o`000<oooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0000oooooo`;o00007?ooool2o`00
00Gooooo0_l00006ooooo`;o0000W?ooool2o`00037ooooo000Mooooo`;o00002_ooool2o`0003oo
oooo0_l00039ooooo`;o0000<Oooool001gooooo0_l0001Iooooo`;o0000k_ooool001kooooo00?o
0000ooooooooool0Eoooool2o`000>kooooo000Nooooo`03o`000?oooooooooo0>Gooooo0_l0001P
ooooo`007_ooool00ol0003oooooooooo`1Kooooo`;o0000R?ooool2o`00063ooooo000Nooooo`03
o`000?oooooooooo03oooooo0_l0000Jooooo`;o00009oooool2o`000<7ooooo000Nooooo`03o`00
0?oooooooooo03oooooo0_l0000Cooooo`;o0000;_ooool2o`000<7ooooo000Nooooo`03o`000?oo
oooooooo05Cooooo0_l00013ooooo`;o0000[?ooool001kooooo00?o0000ooooooooool01Oooool2
o`0009;ooooo0_l0000Vooooo`;o0000Q?ooool001kooooo00?o0000ooooooooool01Oooool2o`00
0;[ooooo0_l00024ooooo`007_ooool00ol0003oooooooooo`0nooooo`;o00005oooool2o`000>ko
oooo000Nooooo`03o`000?oooooooooo03kooooo0_l0000Fooooo`?o0000k_ooool001kooooo00?o
0000ooooooooool0E?ooool4o`0004?ooooo0_l0002Zooooo`007_ooool00ol0003oooooooooo`1D
ooooo`;o00005_ooool2o`0002gooooo0_l0002Zooooo`007_ooool2o`0006gooooo0_l0003Ioooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo08gooooo
0_l0002hooooo`007_ooool00ol0003oooooooooo`2=ooooo`;o0000^?ooool001kooooo00?o0000
ooooooooool0ooooool1ooooo`;o0000AOooool001kooooo00?o0000ooooooooool0FOooool2o`00
0:Gooooo0_l00015ooooo`007_ooool00ol0003oooooooooo`1Iooooo`;o0000k?ooool001kooooo
00?o0000ooooooooool0Y?ooool2o`000:7ooooo000Nooooo`03o`000?oooooooooo05_ooooo0_l0
0017ooooo`;o0000XOooool001kooooo00?o0000ooooooooool0Foooool2o`0001oooooo0_l00039
ooooo`007_ooool00ol0003oooooooooo`1looooo`;o0000bOooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`2Tooooo`;o0000XOooool001kooooo00?o
0000ooooooooool0Y?ooool2o`000:7ooooo000Nooooo`03o`000?oooooooooo04Cooooo0_l0001]
ooooo`;o0000T_ooool001kooooo00?o0000ooooooooool0A?ooool2o`0006gooooo0_l0002Boooo
o`007_ooool2o`00057ooooo0_l0003eooooo`007_ooool00ol0003oooooooooo`1@ooooo`;o0000
mOooool001kooooo00?o0000ooooooooool0J_ooool2o`000=_ooooo000Nooooo`03o`000?oooooo
oooo01oooooo0_l00019ooooo`;o0000foooool001kooooo00?o0000ooooooooool07oooool2o`00
0?oooooo9oooool001kooooo00?o0000ooooooooool0ooooool]ooooo`;o00006Oooool001kooooo
00?o0000ooooooooool0HOooool2o`0004cooooo0_l0001kooooo`;o00006Oooool001kooooo00?o
0000ooooooooool06oooool2o`0004Cooooo0_l0000booooo`;o00006?ooool2o`0009Kooooo000N
ooooo`03o`000?oooooooooo01_ooooo0_l0001hooooo`;o0000/?ooool001kooooo00?o0000oooo
ooooool0Eoooool2o`000>kooooo000Nooooo`03o`000?oooooooooo05Oooooo0_l0003^ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo01cooooo0_l0
003oooooob[ooooo000Nooooo`03o`000?oooooooooo01cooooo0_l0003oooooob[ooooo0003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07gooooo0_l0000?
ooooo`;o0000]oooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool3
o`0004gooooo0_l0000^ooooo`;o00003oooool2o`0001Oooooo0_l0002<ooooo`;o00004?ooool0
00?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o
0000ooooooooool08oooool2o`0002Sooooo0_l00009ooooo`;o0000COooool2o`0008cooooo0_l0
000@ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo0000
1oooool00ol0003oooooooooo`0Sooooo`;o0000<oooool2o`0000oooooo0_l0003Looooo`000ooo
ool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003ooooo
ooooo`1Yooooo`;o0000g?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^
k_m4A4Co000000Oooooo00?o0000ooooooooool04Oooool2o`000?oooooo=Oooool000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0
4Oooool2o`000?oooooo=Oooool001kooooo00?o0000ooooooooool0;oooool2o`000?oooooo5ooo
ool001kooooo00?o0000ooooooooool0;oooool2o`000?oooooo5oooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooo`oooooo0_l0000gooooo`00
7_ooool00ol0003oooooooooo`0Rooooo`;o0000c_ooool2o`0001[ooooo0_l0000gooooo`007_oo
ool00ol0003oooooooooo`0Rooooo`;o0000c_ooool2o`0004Oooooo0_l0000:ooooo`007_ooool0
0ol0003oooooooooo`3ooooooccooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo04[ooooo0_l00018ooooo`;o0000>?ooool2o`0003?o
oooo0_l00012ooooo`007_ooool00ol0003oooooooooo`1:ooooo`;o0000B?ooool2o`0003Sooooo
0_l0000cooooo`;o0000@_ooool001kooooo00?o0000ooooooooool0FOooool2o`000>cooooo000N
ooooo`;o0000F_ooool2o`00027ooooo0_l0000gooooo`;o0000T?ooool001kooooo00?o0000oooo
ooooool0M?ooool2o`0000Kooooo0_l0000gooooo`;o0000T?ooool001kooooo00?o0000oooooooo
ool0M?ooool2o`000=7ooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0ZOooool2o`0009cooooo000Nooooo`03o`000?oooooooooo0:Wooooo0_l0001n
ooooo`;o00007?ooool001kooooo00?o0000ooooooooool0oooooolZooooo`;o00007?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`1Sooooo`;o0000
3_ooool2o`0003Kooooo0_l0002Jooooo`007_ooool00ol0003oooooooooo`0nooooo`;o00008ooo
ool2o`0000kooooo0_l0000fooooo`;o0000V_ooool001kooooo00?o0000ooooooooool05_ooool2
o`0002Kooooo0_l0003oooooo`Sooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l0001Poooo
o`;o0000cOooool001kooooo00?o0000ooooooooool0N?ooool2o`00027ooooo0_l0002Zooooo`00
7_ooool00ol0003oooooooooo`1gooooo`;o00008_ooool2o`000:[ooooo000Nooooo`03o`000?oo
oooooooo07Oooooo0_l000000ooooooo0000o`00000;ooooo`;o00002?ooool2o`000;Cooooo000N
ooooo`03o`000?oooooooooo04gooooo0_l0000[ooooo`;o00002oooool2o`0000Sooooo0_l0002d
ooooo`007_ooool2o`0004kooooo0_l0003hooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o
0000oooooolEooooo`;o00006oooool001kooooo00?o0000ooooooooool05?ooool2o`0001Gooooo
0_l0001Fooooo`;o0000A_ooool2o`00053ooooo0_l0000;ooooo`;o00006oooool001kooooo00?o
0000ooooooooool0:oooool2o`0005Kooooo0_l00016ooooo`;o0000D?ooool2o`0002Sooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo01;ooooo
0_l0003oooooocCooooo000Nooooo`03o`000?oooooooooo00;o00004?ooool2o`0008Oooooo0_l0
002Zooooo`007_ooool00ol0003oooooooooo`02o`0000;ooooo0_l00008ooooo`;o00008Oooool2
o`0006Sooooo0_l0002Zooooo`007_ooool00ol0003oooooooooo`04ooooo`;o00002?ooool2o`00
027ooooo0_l0003oooooo`7ooooo0_l0000Booooo`007_ooool00ol0003oooooooooo`3oooooocCo
oooo0_l0000Booooo`007_ooool00ol0003oooooooooo`05ooooo`;o0000oooooom1ooooo`007_oo
ool00ol0003oooooooooo`05ooooo`;o00006?ooool2o`000<3ooooo0_l0001Hooooo`;o00002_oo
ool001kooooo00?o0000ooooooooool07oooool2o`0000?ooooo0_l0002kooooo`;o0000F?ooool2
o`0000[ooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0000Jooooo`;o0000oooooolRoooo
o`007_ooool2o`0000Wooooo0_l0001Aooooo`;o0000j_ooool001kooooo00?o0000ooooooooool0
3Oooool2o`0004cooooo0_l0003Zooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o0000oooo
ooliooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
00Sooooo0_l00019ooooo`;o0000@Oooool2o`000:7ooooo0_l0000<ooooo`007_ooool00ol0003o
ooooooooo`08ooooo`;o0000BOooool2o`0000Oooooo0_l0000hooooo`;o0000XOooool2o`0000co
oooo000Nooooo`03o`000?oooooooooo00Kooooo0_l00003ooooo`;o0000;Oooool2o`00023ooooo
0_l0002=ooooo`?o0000FOooool001kooooo00?o0000ooooooooool01_ooool2o`0000?ooooo0_l0
000]ooooo`;o0000U?ooool2o`0001Sooooo1?l0001Iooooo`007_ooool00ol0003oooooooooo`3@
ooooo`;o00006?ooool2o`0005_ooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3^ooooo`;o0000
A_ooool2o`0000oooooo000Nooooo`03o`000?oooooooooo047ooooo0_l0000Dooooo`;o00000_oo
ool2o`0008gooooo0_l00002ooooo`;o0000A_ooool2o`0000oooooo000Nooooo`03o`000?oooooo
oooo01Wooooo0_l0000Vooooo`;o00005?ooool2o`0000;ooooo0_l00013ooooo`;o0000B?ooool2
o`0005_ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo01Wooooo0_l00025ooooo`;o0000YOoo
ool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooo
oonHV9So8B4Q00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol@413ooooooooo
oooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o00004?ooool2o`0001[o
oooo0_l0002=ooooo`;o0000R_ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05
o`000?nHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0@ooooo`;o00006_ooool2o`00
08gooooo0_l0002:ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEE
EOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooo
oooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0oooooom8
ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool0
0ol0003oooooooooo`1Pooooo`;o0000iOooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0H?ooool2o`000>Gooooo000N
ooooo`;o0000??ooool2o`000?oooooo2oooool001kooooo0_l0000fooooo`;o00001?ooool2o`00
00gooooo0_l00002ooooo`;o00003?ooool2o`0000Cooooo0_l00004ooooo`;o0000gOooool001ko
oooo00?o0000ooooooooool0=Oooool2o`0001?ooooo0_l00002ooooo`;o00003?ooool2o`0000Co
oooo0_l00004ooooo`;o0000gOooool001kooooo00?o0000ooooooooool0G?ooool2o`000>Wooooo
000Nooooo`03o`000?oooooooooo04[ooooo0_l0000@ooooo`;o000000?oooooo`000?l00000F_oo
ool2o`0008[ooooo000Mooooo`;o0000C?ooool2o`0000gooooo0_l00004ooooo`;o0000F_ooool2
o`0008[ooooo000Mooooo`;o0000Foooool2o`0000kooooo0_l0002Hooooo`;o0000@_ooool001ko
oooo00?o0000ooooooooool0I_ooool2o`000003ooooool0003o000009Sooooo0_l00012ooooo`00
7_ooool00ol0003oooooooooo`0Pooooo`;o0000A?ooool3o`000=kooooo000Nooooo`03o`000?oo
oooooooo023ooooo0_l00015ooooo`;o00008_ooool2o`000;[ooooo000Nooooo`03o`000?oooooo
oooo08_ooooo0_l0002jooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000oooooooo
ool0HOooool2o`0001Kooooo0_l0003<ooooo`007_ooool00ol0003oooooooooo`1Qooooo`;o0000
5_ooool2o`0001Wooooo0_l0002aooooo`007_ooool00ol0003oooooooooo`19ooooo`;o00001_oo
ool2o`0000?ooooo0_l0000Cooooo`;o00009oooool2o`0003kooooo0_l0001aooooo`007_ooool0
0ol0003oooooooooo`19ooooo`;o00001_ooool2o`0000?ooooo0_l0000Cooooo`;o0000Ioooool2
o`00077ooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l0003ooooooc3ooooo000Nooooo`03
o`000?oooooooooo01Kooooo0_l0001Aooooo`;o0000g?ooool001kooooo00?o0000ooooooooool0
>oooool2o`0001cooooo0_l0000>ooooo`;o0000V_ooool2o`00043ooooo000Nooooo`03o`000?oo
oooooooo03_ooooo0_l0000Looooo`;o0000:oooool2o`0007gooooo0_l00010ooooo`007_ooool0
0ol0003oooooooooo`26ooooo`;o0000_oooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`0Iooooo`;o00004?ooool2o`0000?ooooo0_l0003Cooooo`;o
0000@?ooool001kooooo00?o0000ooooooooool03oooool3o`0000Oooooo0_l0000@ooooo`;o0000
0oooool2o`00027ooooo0_l0001Kooooo`;o0000Doooool2o`0002Cooooo0_l0000Jooooo`007_oo
ool00ol0003oooooooooo`0?ooooo`?o00008_ooool2o`0001gooooo0_l0001Kooooo`;o00004_oo
ool2o`0006Gooooo0_l0000Jooooo`007_ooool00ol0003oooooooooo`0_ooooo`;o00000oooool2
o`0008kooooo0_l00021ooooo`007_ooool00ol0003oooooooooo`0_ooooo`;o0000ooooool4oooo
o`;o00004Oooool001kooooo0_l0000Eooooo`Co0000oooooolMooooo`;o00004Oooool001kooooo
00?o0000ooooooooool05?ooool4o`0008oooooo0_l0002Nooooo`007_ooool00ol0003ooooooooo
o`0>ooooo`;o00008Oooool3o`0001_ooooo0_l00005ooooo`;o0000Coooool2o`0009kooooo000N
ooooo`03o`000?oooooooooo00Gooooo0_l00007ooooo`;o00008Oooool3o`0001[ooooo1Ol00003
ooooo`;o0000koooool001kooooo00?o0000ooooooooool01Oooool2o`0004Oooooo0_l000000ooo
oooo0000o`000011ooooo`;o0000/Oooool001kooooo00?o0000ooooooooool05?ooool2o`0003ko
oooo0_l0000nooooo`;o0000/Oooool001kooooo00?o0000ooooooooool05?ooool2o`0002cooooo
0_l0000@ooooo`;o0000Goooool2o`00093ooooo000Nooooo`03o`000?oooooooooo03cooooo0_l0
0004ooooo`;o00006_ooool2o`0003oooooo0_l0000Dooooo`;o0000T?ooool001kooooo00?o0000
ooooooooool0??ooool2o`00023ooooo0_l0000oooooo`;o0000Y_ooool001kooooo00?o0000oooo
ooooool00_ooool2o`00023ooooo0_l00007ooooo`;o0000`Oooool2o`0005Gooooo000Nooooo`03
o`000?oooooooooo00;ooooo0_l0000?ooooo`;o00003oooool2o`0000?ooooo0_l00002ooooo`;o
0000?oooool2o`0006Sooooo0_l0000Fooooo`;o00008oooool2o`0001;ooooo0_l0000Looooo`00
7_ooool00ol0003oooooooooo`0Cooooo`;o00005?ooool2o`0004?ooooo0_l0001Xooooo`;o0000
>oooool2o`0001;ooooo0_l0000Looooo`007_ooool00ol0003oooooooooo`0Xooooo`;o0000:ooo
ool2o`0000Oooooo0_l0000Booooo`;o00003?ooool2o`0005Kooooo0_l0001]ooooo`007_ooool0
0ol0003oooooooooo`0Iooooo`;o00003Oooool2o`0002_ooooo0_l00004ooooo`;o000000Cooooo
o`000?l0003ooooo0_l0000?ooooo`;o00003?ooool2o`0000kooooo0_l00016ooooo`;o0000KOoo
ool001kooooo00?o0000ooooooooool06Oooool2o`0001Sooooo0_l0000Pooooo`;o00001?ooool2
o`0000Cooooo0_l0000]ooooo`;o0000]Oooool001kooooo00?o0000ooooooooool09oooool2o`00
00[ooooo0_l0000Pooooo`;o00008oooool2o`0008;ooooo0_l0000aooooo`;o00005?ooool001ko
oooo0_l0000Xooooo`;o0000DOooool2o`0008;ooooo0_l0000aooooo`;o00005?ooool001kooooo
00?o0000ooooooooool0H_ooool2o`000>?ooooo000Nooooo`03o`000?oooooooooo023ooooo0_l0
000Tooooo`;o00006_ooool2o`0003Kooooo0_l00020ooooo`;o0000:Oooool001kooooo00?o0000
ooooooooool08?ooool2o`00017ooooo0_l0000=ooooo`;o00000_ooool2o`0005;ooooo0_l0000[
ooooo`;o0000Doooool2o`0002Wooooo000Nooooo`03o`000?oooooooooo01oooooo0_l0000Boooo
o`;o00003Oooool2o`0000cooooo0_l0001eooooo`;o00002oooool2o`00077ooooo000Nooooo`04
o`000?ooooooooooooooo`;o00007?ooool4o`0000[ooooo0_l0000?ooooo`;o00004?ooool2o`00
00_ooooo0_l0001eooooo`;o0000LOooool001kooooo00Co0000oooooooooooooooo0_l0000Goooo
o`;o00001Oooool2o`0000[ooooo0_l00005ooooo`;o00002?ooool2o`0000_ooooo0_l0000@oooo
o`;o0000Moooool2o`0006oooooo000Nooooo`03o`000?oooooooooo01[ooooo0_l000000ooooooo
0000o`000002o`0001?ooooo0_l0000Eooooo`;o0000>Oooool2o`0004kooooo0_l0001_ooooo`00
7_ooool00ol0003oooooooooo`0Mooooo`Co0000IOooool2o`000;oooooo000Nooooo`03o`000?oo
oooooooo02Wooooo0_l0000Fooooo`?o0000ooooool4ooooo`007_ooool00ol0003oooooooooo`0Y
ooooo`;o00005_ooool5o`000:_ooooo0_l0001Dooooo`007_ooool00ol0003oooooooooo`0Toooo
o`;o00002_ooool2o`0000Wooooo0_l00007ooooo`;o0000Zoooool2o`0005Cooooo000Nooooo`03
o`000?oooooooooo02Cooooo0_l0000:ooooo`;o00002Oooool2o`0003Cooooo0_l0003Dooooo`00
7_ooool00ol0003oooooooooo`0Zooooo`;o0000AOooool2o`0007Cooooo0_l000000ooooooo0000
o`000018ooooo`;o00002Oooool2o`0000Kooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo01oo
oooo0_l00002ooooo`;o00001Oooool2o`0000Gooooo0_l00008ooooo`;o00002?ooool2o`0004ko
oooo0_l0001@ooooo`;o000000?oooooo`000?l00000B?ooool2o`0000Wooooo0_l00006ooooo`00
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRH
V?lQ8B401_ooool00ol0003oooooooooo`0Oooooo`;o00000_ooool2o`0000cooooo0_l00003oooo
o`;o00000oooool2o`0000Sooooo0_l000000ooooooo0000o`00000_ooooo`;o00006_ooool2o`00
0;3ooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo
000000Kooooo0ol0000Gooooo`;o00001Oooool2o`0000oooooo0_l000001?oooooo0000o`000?oo
ool3o`00013ooooo0_l0000Fooooo`;o00005oooool2o`000<?ooooo0_l00007ooooo`000oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`00
0?oooooooooo01Oooooo0_l00005ooooo`;o00003oooool5o`000003ooooool0003o000000?ooooo
0_l0000Qooooo`;o000000?oooooo`000?l00000:_ooool2o`000;3ooooo0_l00007ooooo`000ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03
o`000?oooooooooo02kooooo0_l000000ooooooo0000o`000007ooooo`?o00001Oooool2o`0001Ko
oooo0_l000000ooooooo0000o`000008ooooo`;o00008oooool2o`000;Wooooo0003ooooo`05oa0@
4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000oooo
ooooool07Oooool2o`000003ooooool0003o000000Cooooo0_l00006ooooo`;o000000?oooooo`00
0?l000002?ooool2o`0000Cooooo0ol0000>ooooo`;o000000?oooooo`000?l000000oooool2o`00
00_ooooo0_l0001Hooooo`;o0000Q?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`0:ooooo`;o00004Oooool2
o`000003ooooool0003o000000Cooooo1?l0000Dooooo`;o000000?oooooo`000?l000003oooool2
o`000003ooooool0003o000006[ooooo0_l00019ooooo`;o0000>Oooool000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003ooooooooo
o`0:ooooo`;o00007?ooool7o`0000Gooooo0_l00004ooooo`Ko00007Oooool3o`000003ooooool0
003o00000:Wooooo0_l0000cooooo`;o00001?ooool001kooooo00?o0000ooooooooool06oooool2
o`0000_ooooo1ol00005ooooo`;o00001?ooool4o`0000[ooooo0_l0000Booooo`Oo00009oooool2
o`0008Oooooo0_l0000/ooooo`;o00001?ooool001kooooo00?o0000ooooooooool06oooool2o`00
00_ooooo0_l0000;ooooo`;o00004Oooool4o`0000Gooooo0ol00002ooooo`Co00000_ooool5o`00
02Wooooo0_l00027ooooo`;o0000<_ooool001kooooo00?o0000ooooooooool0:_ooool2o`0000Wo
oooo0_l0000Cooooo`;o00001Oooool3o`0000;ooooo1?l000000ooooooo0000o`000003o`0000;o
oooo0_l0000?ooooo`;o00008?ooool3o`000:oooooo000Nooooo`03o`000?oooooooooo01gooooo
0_l0000;ooooo`;o00002Oooool2o`0002Cooooo0ol00004ooooo`Co00003Oooool2o`00023ooooo
0ol0002_ooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o00001_ooool2o`0000Gooooo1?l0
0002ooooo`;o00001oooool2o`0000Cooooo0ol00006ooooo`;o00005?ooool2o`0000[ooooo0_l0
003Qooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o00003Oooool4o`0000Gooooo0_l00004
ooooo`;o00001?ooool3o`0000Kooooo1?l00003ooooo`;o00002?ooool2o`0000?ooooo0_l0003]
ooooo`007_ooool00ol0003oooooooooo`0Pooooo`?o00001Oooool2o`0000?ooooo1?l00007oooo
o`Co00002?ooool2o`0000?ooooo0_l00006ooooo`Oo000000Coooooo`000?l0003ooooo0_l00020
ooooo`;o0000:oooool2o`0002Gooooo0_l0000Cooooo`007_ooool3o`00023ooooo0ol00002oooo
o`Go00001Oooool4o`0000Gooooo0_l00003ooooo`Co00000_ooool2o`0000cooooo2_l000000ooo
oooo0000o`000008ooooo`;o0000<Oooool2o`0004?ooooo0_l0000[ooooo`;o00009Oooool2o`00
01?ooooo000Nooooo`?o00007oooool2o`0000Cooooo0ol00002ooooo`;o00000oooool4o`0000Go
oooo2Ol00002ooooo`;o00002oooool5o`0000;ooooo0_l0000=ooooo`;o0000<Oooool2o`0006;o
oooo0_l00018ooooo`007_ooool00ol0003oooooooooo`0Oooooo`So00000oooool4o`0000Sooooo
2?l00003ooooo`;o000000?oooooo`000?l000002_ooool5o`000003ooooool0003o000000;o0000
1?ooool3o`0001?ooooo0_l00006ooooo`;o0000<?ooool2o`0004gooooo0_l00018ooooo`007_oo
ool00ol0003oooooooooo`0Mooooo`;o00000_ooool4o`0000Oooooo0_l000000ooooooo0000o`00
0005ooooo`Co000000?oooooo`000?l000001?ooool5o`00013ooooo1?l00002ooooo`Go00004ooo
ool2o`0000Kooooo0_l0000Nooooo`Co00003_ooool2o`0009Oooooo000Nooooo`;o00005oooool2
o`0000Gooooo0ol000000ooooooo0000o`000008ooooo`?o000000?oooooo`000?l000000_ooool2
o`0000?ooooo0ol00008ooooo`;o00005oooool2o`0001?ooooo0_l00008ooooo`;o00002_ooool2
o`0001?ooooo1?l0000Rooooo`;o0000O?ooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo
01Kooooo0_l000000ooooooo0000o`000003ooooo`Ko00001Oooool5o`0000?ooooo1?l00002oooo
o`Co00000_ooool4o`0000Kooooo0ol00009ooooo`;o00000_ooool3o`0000Gooooo0_l0000;oooo
o`;o00000oooool2o`0000Sooooo0_l0000:ooooo`;o0000>Oooool2o`0003Kooooo0_l00011oooo
o`;o000000?oooooo`000?l000001Oooool001kooooo00?o0000ooooooooool06Oooool2o`000004
ooooool0003o0000ooooo`Go00001Oooool2o`0000Kooooo0_l00004ooooo`;o00000_ooool8o`00
00Cooooo1?l00002ooooo`;o00001?ooool3o`000003ooooool0003o000000;o000000?oooooo`00
0?l000001?l0000:ooooo`;o00002?ooool2o`0001[ooooo0_l000000ooooooo0000o`00001Soooo
o`;o0000@Oooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l00004ooooo`;o
000000Coooooo`000?l0003ooooo0ol000000ooooooo0000o`000008ooooo`Co00000_ooool2o`00
00?ooooo0_l00003ooooo`?o000000?oooooo`000?l000001Ol00002ooooo`;o00001Oooool3o`00
00;ooooo0_l000000ooooooo0000o`000006o`0001;ooooo0_l0000Jooooo`;o000000?oooooo`00
0?l00000=oooool2o`0000Kooooo0_l0001_ooooo`007_ooool00ol0003oooooooooo`0Fooooo`;o
00001?ooool2o`000003ooooool0003o000000;ooooo1Ol00002ooooo`;o00001?ooool5o`000003
ooooool0003o000000;ooooo1?l000001?oooooo0000o`000?l00002ooooo`Co00000_ooool2o`00
0003ooooool0003o000000Kooooo0_l0000;ooooo`;o000000?oooooo`000?l000003_ooool2o`00
05Oooooo0_l00006ooooo`;o0000IOooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo01co
oooo0_l00007ooooo`;o00000oooool2o`0000Kooooo0ol00002ooooo`;o000000?oooooo`000?l0
00001ol000000ooooooo0000o`000002o`0000;ooooo0_l0000:ooooo`Go00001?ooool3o`0000?o
oooo0_l0000>ooooo`;o0000a_ooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo02cooooo
0_l00009ooooo`;o00000oooool;o`0000Cooooo0ol00008ooooo`Oo00000_ooool3o`0001;ooooo
0ol0003@ooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o00001?ooool2o`000003ooooool0
003o000000?ooooo0_l00008ooooo`Oo000000?oooooo`000?l000001?l00002ooooo`?o00001?oo
ool3o`0000;ooooo0_l00002ooooo`;o00000_ooool2o`0001?ooooo0_l00002ooooo`;o0000`?oo
ool2o`0000_ooooo000Nooooo`03o`000?oooooooooo02?ooooo2?l00006ooooo`?o00001oooool2
o`000003ooooool0003o000000;o000000Goooooo`000?l0003o0000ooooo`02o`000003ooooool0
003o000000Co000000?oooooo`000?l000001?l0000Qooooo`;o00003_ooool2o`000;3ooooo0_l0
000;ooooo`007_ooool00ol0003oooooooooo`0Nooooo`;o00001Oooool5o`000003ooooool0003o
000000Gooooo0_l00005ooooo`?o00001?ooool2o`000003ooooool0003o000000Gooooo1_l00000
0ooooooo0000o`000004o`0000_ooooo0_l0000?ooooo`;o00000oooool2o`0000kooooo0_l0002m
ooooo`007_ooool00ol0003oooooooooo`0Nooooo`;o00002oooool2o`0000Oooooo0_l00003oooo
o`Co00000oooool7o`0000;ooooo0_l00002ooooo`;o00000_ooool7o`000003ooooool0003o0000
00Oooooo0_l0000?ooooo`;o00000oooool2o`000;Wooooo0_l0000Booooo`007_ooool00ol0003o
ooooooooo`0dooooo`?o00000oooool7o`000003ooooool0003o000000?o00000_ooool4o`000003
ooooool0003o000000Kooooo0_l000000ooooooo0000o`00000;ooooo`;o00003_ooool2o`000;_o
oooo0_l0000Booooo`007_ooool00ol0003oooooooooo`0Cooooo`;o00004Oooool2o`0000gooooo
0_l00002ooooo`So00000_ooool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000
o`000006ooooo`;o000000Coooooo`000?l0003o00002_ooool2o`000003ooooool0003o000000Go
oooo0_l00004ooooo`;o00001oooool2o`000<Kooooo000Nooooo`03o`000?oooooooooo01?ooooo
0_l0000Aooooo`;o000000?oooooo`000?l000002?ooool2o`0000Cooooo1ol00006ooooo`;o0000
4?ooool5o`0000cooooo0_l00005ooooo`;o00003Oooool2o`0001[ooooo0_l0000Fooooo`;o0000
1?ooool2o`0008cooooo000Nooooo`03o`000?oooooooooo02Kooooo0_l000000ooooooo0000o`00
0002ooooo`;o00001?ooool3o`0000Gooooo1Ol00008ooooo`Co000000?oooooo`000?l000001Ooo
ool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000_ooooo0ol0000^ooooo`;o00005_oo
ool2o`0000Cooooo0_l0002<ooooo`007_ooool2o`0000oooooo0_l0000>ooooo`;o00001Oooool2
o`0000Kooooo0_l00002ooooo`Go000000?oooooo`000?l000000_ooool5o`0000Cooooo0_l00002
ooooo`Co000000?oooooo`000?l000000ol00002ooooo`Co000000?oooooo`000?l000000_ooool2
o`0000Gooooo1?l00002ooooo`?o00001?ooool2o`0005Oooooo0_l0001kooooo`007_ooool2o`00
00oooooo0_l0000>ooooo`;o00001Oooool2o`0000[ooooo0ol00003ooooo`;o000000?oooooo`00
0?l000000_ooool2o`0000Cooooo0_l00009ooooo`?o00000_ooool7o`0000;ooooo0_l00005oooo
o`Co00002Oooool2o`0005Oooooo0_l0001cooooo`;o00001_ooool001kooooo00?o0000oooooooo
ool03_ooool2o`0001oooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool3o`0000Ko
oooo1Ol000000ooooooo0000o`00000;ooooo`?o00001Oooool4o`0000?ooooo0_l00005ooooo`;o
00003_ooool2o`0005?ooooo0_l0001/ooooo`;o00001_ooool001kooooo00?o0000ooooooooool0
8Oooool2o`0000cooooo0_l00002ooooo`Go00000oooool3o`0000Gooooo1Ol000000ooooooo0000
o`000006ooooo`;o00002oooool5o`0000Gooooo0_l00002ooooo`;o00000oooool4o`0000Oooooo
0_l00013ooooo`;o00003_ooool2o`0002[ooooo0_l0000nooooo`;o00002?ooool001kooooo00?o
0000ooooooooool00_l0000Oooooo`;o00003?ooool2o`0000?ooooo0_l00006ooooo`;o00001ooo
ool2o`0000;ooooo0_l00002ooooo`;o00000_ooool2o`0000Sooooo0_l00004ooooo`;o00001Ooo
ool2o`0000?ooooo0_l000000ooooooo0000o`000003o`00037ooooo0_l0000Iooooo`;o00005_oo
ool2o`0002;ooooo0_l0000nooooo`;o00002?ooool001kooooo00?o0000ooooooooool00_l0000E
ooooo`;o0000;?ooool2o`0000;ooooo1_l00008ooooo`Ko00000_ooool2o`0000cooooo0_l00000
0ooooooo0000o`00000dooooo`;o00006Oooool2o`0001Kooooo0_l0001/ooooo`007_ooool00ol0
003oooooooooo`0Gooooo`;o00001Oooool4o`0002Wooooo1?l00005ooooo`;o000000?oooooo`00
0?l000000ol00003ooooo`;o0000C_ooool2o`0002Sooooo0_l0001/ooooo`007_ooool00ol0003o
ooooooooo`0Nooooo`Co00003_ooool2o`0000Cooooo0_l0000:ooooo`;o00000oooool2o`0000Co
oooo0_l00002ooooo`;o000000?oooooo`000?l000000_l000001?oooooo0000o`000?l00003oooo
o`?o00001oooool2o`0002Kooooo0_l0000Looooo`Co00009_ooool2o`0004cooooo0_l0000Noooo
o`007_ooool00ol0003oooooooooo`04ooooo`;o00007Oooool2o`0000Oooooo0_l00002ooooo`;o
00001?ooool2o`0000[ooooo0_l00003ooooo`;o00002?ooool7o`0000Sooooo0_l00007ooooo`;o
00001oooool2o`0001;ooooo0ol00008ooooo`;o00002_ooool2o`0001;ooooo0_l0001dooooo`;o
00007_ooool001kooooo00?o0000ooooooooool01?ooool2o`0001gooooo0_l00007ooooo`;o0000
4oooool4o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o0000
0_ooool2o`0001?ooooo0_l00006ooooo`;o00001Oooool2o`0000?ooooo0ol0000Dooooo`;o0000
2?ooool2o`0009kooooo000Nooooo`03o`000?oooooooooo047ooooo1?l00004ooooo`;o000000?o
ooooo`000?l000000ol00002ooooo`?o00000oooool2o`0000;ooooo0_l00004ooooo`;o00000ooo
ool3o`0000;ooooo0_l00002ooooo`;o00001oooool2o`0000Gooooo0_l0000Iooooo`;o00002Ooo
ool2o`0005kooooo0_l0000nooooo`007_ooool00ol0003oooooooooo`0oooooo`;o00002oooool4
o`0000;ooooo0ol00009ooooo`;o00000oooool2o`0000?ooooo1ol00002ooooo`;o0000:Oooool2
o`0003kooooo0_l0000Yooooo`;o0000?_ooool001kooooo00?o0000ooooooooool0?_ooool3o`00
00_ooooo0ol00003ooooo`?o00000_ooool2o`0000;ooooo1ol00007ooooo`Oo00008_ooool2o`00
04Sooooo0_l0000<ooooo`;o0000=?ooool2o`0001_ooooo0_l00008ooooo`007_ooool00ol0003o
ooooooooo`0/ooooo`;o00004?ooool2o`00017ooooo0_l00004ooooo`;o00000_ooool7o`0000Ko
oooo1?l00002ooooo`;o00005oooool2o`0000Wooooo0_l0000Pooooo`;o0000=?ooool2o`0003Co
oooo0_l0000Kooooo`;o00002?ooool001kooooo00?o0000ooooooooool0;?ooool2o`0000?ooooo
0_l0000?ooooo`;o00003Oooool2o`0000Wooooo1_l00006ooooo`Go000000?oooooo`000?l00000
5oooool2o`000003ooooool0003o000002Sooooo0_l0002Aooooo`007_ooool00ol0003ooooooooo
o`0aooooo`;o00003oooool2o`0000?ooooo0ol00008ooooo`;o00002_ooool2o`0000;ooooo0_l0
0007ooooo`;o00002_ooool2o`00017ooooo0_l0000Oooooo`;o0000V_ooool001kooooo00?o0000
ooooooooool0?Oooool2o`0000Sooooo0ol00008ooooo`;o00002_ooool2o`0000;ooooo0_l0000C
ooooo`;o00003Oooool2o`0002?ooooo0_l0002Jooooo`007_ooool2o`0001cooooo0_l0000Ioooo
o`;o00001Oooool4o`0002;ooooo0_l0000Fooooo`;o00002Oooool2o`0007Oooooo0_l00004oooo
o`;o0000@?ooool001kooooo00?o0000ooooooooool06oooool2o`0001Wooooo0_l00007ooooo`;o
00000_ooool2o`000003ooooool0003o000000;ooooo0_l0000Gooooo`;o00005_ooool2o`0008;o
oooo1?l00002ooooo`;o00001?ooool2o`0003[ooooo000Nooooo`04o`000?ooooooooooooooo`;o
0000<_ooool2o`0000cooooo0_l000000ooooooo0000o`000002ooooo`;o00001?ooool2o`0001Oo
oooo0_l00003ooooo`Co00002oooool2o`0008;ooooo0_l00008ooooo`;o00006_ooool2o`0001ko
oooo000Nooooo`04o`000?ooooooooooooooo`;o0000:oooool2o`0000Gooooo0_l00004ooooo`;o
00001_ooool2o`000003ooooool0003o000000Sooooo0_l0000Gooooo`;o00000oooool4o`0000Co
oooo0_l00005ooooo`;o0000Z?ooool2o`0001kooooo000Nooooo`03o`000?oooooooooo02kooooo
0_l00005ooooo`;o00001?ooool4o`0003Oooooo0_l0003?ooooo`007_ooool00ol0003ooooooooo
o`0Cooooo`;o00006oooool4o`0000Wooooo0_l00006ooooo`;o00004Oooool2o`0000Cooooo0_l0
003Wooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o00000_ooool2o`00013ooooo0_l00005
ooooo`Co00004?ooool3o`00017ooooo0_l00003ooooo`?o0000ioooool001kooooo00?o0000oooo
ooooool05oooool2o`00013ooooo0_l00006ooooo`;o00004Oooool2o`0001;ooooo0_l00003oooo
o`;o00002?ooool3o`000=gooooo000Nooooo`03o`000?oooooooooo037ooooo0_l00008ooooo`;o
0000:_ooool3o`000=gooooo000Nooooo`03o`000?oooooooooo013ooooo0_l0000Hooooo`;o0000
00?oooooo`000?l000003?ooool2o`0000_ooooo0_l0003mooooo`007_ooool00ol0003ooooooooo
o`0@ooooo`;o00006?ooool2o`000003ooooool0003o000001Wooooo0_l0000Eooooo`;o00004Ooo
ool3o`000003ooooool0003o000001?ooooo0_l0002jooooo`007_ooool00ol0003oooooooooo`0I
ooooo`;o000000?oooooo`000?l000006_ooool2o`0001Gooooo1?l0000<ooooo`;o00004Oooool3
o`000003ooooool0003o000001?ooooo0_l0001nooooo`;o0000>_ooool001kooooo00?o0000oooo
ooooool06Oooool2o`000003ooooool0003o000001[ooooo0_l0000:ooooo`;o00002Oooool4o`00
0;Sooooo0_l0000jooooo`007_ooool01?l0003oooooo`000?l00013ooooo`;o00001Oooool2o`00
00Gooooo0_l00007ooooo`;o00002?ooool2o`0003;ooooo0_l00011ooooo`;o0000=?ooool2o`00
03?ooooo000Dooooo`Co000000?o410@ooooooooool00oooool01?l0003oooooo`000?l0001:oooo
o`Co00000oooool2o`0000Oooooo0_l00008ooooo`;o00007oooool2o`00017ooooo0_l00011oooo
o`;o0000=?ooool2o`0003?ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool03Oooool2o`0003kooooo0_l0000Rooooo`;o00004oooool2o`00017ooooo0_l00006ooooo`;o
0000D?ooool2o`0005;ooooo000Fooooo`03o`000?oooooooooo00Gooooo0ol0000=ooooo`;o0000
6_ooool2o`00023ooooo0_l0000Tooooo`;o00009_ooool2o`0000Kooooo0_l0001@ooooo`;o0000
D_ooool001Kooooo00?o0000ooooooooool0<Oooool2o`00023ooooo0_l0003jooooo`005_ooool0
0ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Ko
oooo00?o0000ooooooooool0oooooom@ooooo`005?ooool00omEEEGoIVIVo`00003ooooooe;ooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.35676 .97659 Mdot
.33864 .95517 Mdot
.13192 .84758 Mdot
.24334 .96169 Mdot
.17652 .9143 Mdot
.20708 .88015 Mdot
.11182 .11105 Mdot
.26507 .88285 Mdot
.27478 .92907 Mdot
.18481 .71306 Mdot
.10382 .92102 Mdot
.20561 .74454 Mdot
.13183 .82695 Mdot
.85086 .80551 Mdot
.20902 .85068 Mdot
.38676 .44297 Mdot
.45422 .1218 Mdot
.11808 .85955 Mdot
.34504 .98429 Mdot
.29936 .98523 Mdot
.52135 .69635 Mdot
.2346 .87701 Mdot
.19011 .76946 Mdot
.28488 .59711 Mdot
.3317 .94325 Mdot
.28432 .86631 Mdot
.24125 .86084 Mdot
.16533 .1526 Mdot
.08945 .85596 Mdot
.19873 .84859 Mdot
.14515 .89028 Mdot
.21203 .86468 Mdot
.35591 .8507 Mdot
.46054 .1075 Mdot
.34663 .73545 Mdot
.21488 .98436 Mdot
.45055 .916 Mdot
.6612 .75585 Mdot
.24819 .72699 Mdot
.29873 .90189 Mdot
.17823 .89511 Mdot
.25893 .75567 Mdot
.20698 .85589 Mdot
.43316 .7807 Mdot
.03751 .52207 Mdot
.33211 .80914 Mdot
.46319 .10367 Mdot
.22922 .0565 Mdot
.27111 .96855 Mdot
.50094 .0784 Mdot
.4383 .83018 Mdot
.28138 .02996 Mdot
.15696 .85214 Mdot
.11892 .78714 Mdot
.09926 .81788 Mdot
.5663 .58332 Mdot
.85616 .93449 Mdot
.15584 .85521 Mdot
.2383 .85765 Mdot
.94944 .89212 Mdot
.20232 .85482 Mdot
.29703 .89253 Mdot
.05809 .86458 Mdot
.3306 .94459 Mdot
.18378 .93725 Mdot
.20356 .92845 Mdot
.30059 .07006 Mdot
.24343 .85934 Mdot
.18662 .87912 Mdot
.62998 .93645 Mdot
.72241 .74046 Mdot
.12657 .79197 Mdot
.9234 .94793 Mdot
.23532 .98384 Mdot
.16695 .01544 Mdot
.86992 .98809 Mdot
.3212 .82147 Mdot
.72361 .99265 Mdot
.21622 .86508 Mdot
.12673 .83871 Mdot
.27524 .00974 Mdot
.68052 .11142 Mdot
.30489 .14586 Mdot
.27408 .88634 Mdot
.42199 .85017 Mdot
.009 .48829 Mdot
.24944 .89963 Mdot
.27072 .88243 Mdot
.1982 .86462 Mdot
.05391 .84621 Mdot
.24254 .88411 Mdot
.2396 .52455 Mdot
.13655 .77309 Mdot
.6072 .66116 Mdot
.24564 .87325 Mdot
.23738 .93736 Mdot
.21173 .28918 Mdot
.31611 .68938 Mdot
.14041 .84298 Mdot
.15098 .24259 Mdot
.27501 .87002 Mdot
.45345 .84167 Mdot
.14124 .87522 Mdot
.37388 .13168 Mdot
.3387 .06581 Mdot
.18252 .76512 Mdot
.33027 .92036 Mdot
.33351 .8229 Mdot
.19351 .1079 Mdot
.47683 .08375 Mdot
.45466 .93823 Mdot
.84619 .3346 Mdot
.21385 .01907 Mdot
.11323 .87788 Mdot
.14836 .72951 Mdot
.09491 .45863 Mdot
.11802 .61359 Mdot
.13581 .8066 Mdot
.50254 .01114 Mdot
.13885 .97694 Mdot
.2905 .86972 Mdot
.23231 .12642 Mdot
.18233 .91765 Mdot
.44915 .88718 Mdot
.00663 .05743 Mdot
.33799 .44711 Mdot
.41584 .86387 Mdot
.36056 .96498 Mdot
.63035 .83844 Mdot
.09128 .10078 Mdot
.34843 .62282 Mdot
.75064 .21256 Mdot
.28035 .91114 Mdot
.20912 .80163 Mdot
.19161 .88105 Mdot
.21394 .89846 Mdot
.17323 .76742 Mdot
.38344 .92719 Mdot
.18965 .9299 Mdot
.1938 .92463 Mdot
.32409 .92746 Mdot
.31545 .93651 Mdot
.32492 .84243 Mdot
.20481 .1117 Mdot
.528 .91851 Mdot
.20175 .76117 Mdot
.40664 .8483 Mdot
.26735 .85743 Mdot
.79453 .03166 Mdot
.43478 .30266 Mdot
.24988 .77459 Mdot
.33992 .82797 Mdot
.22627 .75289 Mdot
.31014 .98239 Mdot
.21827 .85065 Mdot
.16548 .82127 Mdot
.22612 .78568 Mdot
.91506 .36708 Mdot
.25751 .91943 Mdot
.36204 .4223 Mdot
.39016 .95886 Mdot
.29619 .5975 Mdot
.52759 .49098 Mdot
.24209 .78338 Mdot
.17246 .87995 Mdot
.14226 .8667 Mdot
.27705 .85577 Mdot
.22812 .87892 Mdot
.93231 .42358 Mdot
.15913 .80042 Mdot
.31103 .7995 Mdot
.13044 .79368 Mdot
.35788 .68704 Mdot
.72417 .5707 Mdot
.33097 .92144 Mdot
.2366 .69421 Mdot
.24224 .61116 Mdot
.22657 .87459 Mdot
.06163 .40258 Mdot
.29419 .01202 Mdot
.18269 .72434 Mdot
.08078 .92047 Mdot
.21425 .92345 Mdot
.00076 .55815 Mdot
.30825 .25802 Mdot
.44182 .88564 Mdot
.27259 .68982 Mdot
.21195 .82317 Mdot
.16459 .76813 Mdot
.14979 .66493 Mdot
.36073 .95294 Mdot
.5876 .56703 Mdot
.3596 .96271 Mdot
.44105 .03407 Mdot
.07892 .791 Mdot
.14767 .74689 Mdot
.28038 .61257 Mdot
.12779 .99178 Mdot
.29371 .93216 Mdot
.24674 .94144 Mdot
.4428 .10843 Mdot
.7053 .59072 Mdot
.20917 .8348 Mdot
.17037 .55808 Mdot
.33256 .9436 Mdot
.26905 .89272 Mdot
.63881 .42862 Mdot
.25063 .84242 Mdot
.88851 .81486 Mdot
.22696 .69101 Mdot
.15066 .83814 Mdot
.37799 .90988 Mdot
.27417 .18586 Mdot
.37189 .37187 Mdot
.3673 .93122 Mdot
.32522 .40405 Mdot
.27886 .88049 Mdot
.05396 .69601 Mdot
.25026 .1828 Mdot
.14964 .5953 Mdot
.82641 .88405 Mdot
.04393 .88286 Mdot
.26852 .91045 Mdot
.21047 .87508 Mdot
.03139 .83452 Mdot
.18221 .76426 Mdot
.97746 .04787 Mdot
.2016 .83576 Mdot
.21616 .80341 Mdot
.2807 .88031 Mdot
.24581 .84959 Mdot
.96501 .88401 Mdot
.32508 .81985 Mdot
.18918 .16926 Mdot
.42546 .50725 Mdot
.6674 .74479 Mdot
.75543 .19486 Mdot
.13036 .85385 Mdot
.41634 .93462 Mdot
.69588 .83781 Mdot
.09212 .91121 Mdot
.31694 .8223 Mdot
.34442 .11474 Mdot
.29352 .73514 Mdot
.32345 .83279 Mdot
.19403 .06019 Mdot
.00638 .82807 Mdot
.29798 .80849 Mdot
.92571 .10992 Mdot
.18571 .87653 Mdot
.2475 .0691 Mdot
.11214 .80001 Mdot
.08452 .09397 Mdot
.13288 .40101 Mdot
.97963 .58159 Mdot
.20478 .11367 Mdot
.1608 .85563 Mdot
.81689 .79121 Mdot
.29873 .06625 Mdot
.67971 .73583 Mdot
.37117 .93519 Mdot
.1541 .8785 Mdot
.22837 .76144 Mdot
.11011 .9389 Mdot
.32199 .8249 Mdot
.87272 .19418 Mdot
.42183 .93781 Mdot
.45101 .74449 Mdot
.13661 .8259 Mdot
.27616 .88118 Mdot
.1545 .8561 Mdot
.59674 .98865 Mdot
.18945 .83166 Mdot
.15613 .86296 Mdot
.26639 .94219 Mdot
.12813 .79152 Mdot
.3267 .13318 Mdot
.87896 .05551 Mdot
.16019 .91684 Mdot
.46699 .88918 Mdot
.73233 .04223 Mdot
.25345 .85926 Mdot
.26287 .82781 Mdot
.30895 .78727 Mdot
.1558 .87536 Mdot
.281 .91846 Mdot
.14437 .81909 Mdot
.15607 .28951 Mdot
.19519 .10479 Mdot
.39609 .88872 Mdot
.33945 .11235 Mdot
.48419 .98494 Mdot
.32382 .97606 Mdot
.09118 .93954 Mdot
.28798 .6619 Mdot
.08762 .15971 Mdot
.19586 .8847 Mdot
.14699 .12666 Mdot
.88908 .90792 Mdot
.05683 .01385 Mdot
.36596 .16035 Mdot
.14055 .77411 Mdot
.30954 .58575 Mdot
.07862 .74985 Mdot
.60946 .47725 Mdot
.16604 .04625 Mdot
.23457 .86225 Mdot
.22343 .84849 Mdot
.3187 .37115 Mdot
.60384 .59409 Mdot
.26642 .85567 Mdot
.71874 .57899 Mdot
.292 .86707 Mdot
.0553 .74445 Mdot
.27862 .97777 Mdot
.25707 .78682 Mdot
.35695 .64867 Mdot
.39186 .92554 Mdot
.24334 .8576 Mdot
.06576 .4854 Mdot
.24312 .73501 Mdot
.33508 .85343 Mdot
.46949 .90918 Mdot
.23413 .65972 Mdot
.13468 .8868 Mdot
.22298 .83906 Mdot
.171 .9321 Mdot
.38655 .89644 Mdot
.18545 .75841 Mdot
.27087 .87049 Mdot
.31449 .97287 Mdot
.18816 .89681 Mdot
.06146 .12019 Mdot
.22363 .78529 Mdot
.30006 .11223 Mdot
.30322 .36184 Mdot
.81353 .60295 Mdot
.26732 .86808 Mdot
.32587 .41296 Mdot
.80592 .72676 Mdot
.19839 .89552 Mdot
.40697 .23181 Mdot
.35183 .88966 Mdot
.0463 .76957 Mdot
.44195 .77758 Mdot
.0621 .80427 Mdot
.43089 .85194 Mdot
.09602 .41515 Mdot
.26015 .93811 Mdot
.2583 .88451 Mdot
.14207 .8097 Mdot
.11706 .82863 Mdot
.16061 .59872 Mdot
.38229 .51343 Mdot
.37486 .19804 Mdot
.19888 .83277 Mdot
.35537 .91083 Mdot
.28558 .85271 Mdot
.11849 .84932 Mdot
.90834 .87773 Mdot
.28064 .83576 Mdot
.33196 .80954 Mdot
.1633 .89801 Mdot
.14219 .81448 Mdot
.23537 .87637 Mdot
.24558 .07056 Mdot
.50278 .69294 Mdot
.27271 .33363 Mdot
.05257 .15269 Mdot
.16524 .87112 Mdot
.46645 .04996 Mdot
.22985 .86396 Mdot
.15213 .83148 Mdot
.23695 .92353 Mdot
.6973 .92509 Mdot
.47714 .61596 Mdot
.07898 .58724 Mdot
.28368 .97846 Mdot
.04143 .60937 Mdot
.25874 .82671 Mdot
.21485 .86701 Mdot
.29595 .98398 Mdot
.60539 .15746 Mdot
.30558 .35601 Mdot
.20728 .11455 Mdot
.38994 .09551 Mdot
.43498 .99163 Mdot
.42753 .27634 Mdot
.25788 .8674 Mdot
.11645 .81472 Mdot
.3268 .92499 Mdot
.1004 .87949 Mdot
.27207 .83397 Mdot
.17977 .91303 Mdot
.18811 .92239 Mdot
.40305 .72261 Mdot
.514 .02691 Mdot
.57867 .89158 Mdot
.24116 .85427 Mdot
.14393 .89572 Mdot
.22205 .96359 Mdot
.06422 .5516 Mdot
.94917 .36868 Mdot
.29135 .89306 Mdot
.4923 .92801 Mdot
.18495 .655 Mdot
.44269 .97011 Mdot
.08024 .81738 Mdot
.1227 .68746 Mdot
.23697 .77793 Mdot
.47934 .00545 Mdot
.28202 .9159 Mdot
.38589 .94728 Mdot
.48217 .22378 Mdot
.81843 .72948 Mdot
.13456 .83278 Mdot
.07238 .05975 Mdot
.21965 .78773 Mdot
.99282 .69086 Mdot
.21706 .86253 Mdot
.26164 .88132 Mdot
.43634 .13982 Mdot
.4092 .95451 Mdot
.10332 .86414 Mdot
.20173 .86123 Mdot
.32221 .79336 Mdot
.82747 .99978 Mdot
.26932 .91989 Mdot
.05973 .79128 Mdot
.69236 .69954 Mdot
.50887 .53441 Mdot
.38684 .92131 Mdot
3e-05 .20319 Mdot
.30321 .96736 Mdot
.38845 .97215 Mdot
.95521 .9833 Mdot
.29024 .08032 Mdot
.12018 .39709 Mdot
.31178 .79143 Mdot
.06341 .52665 Mdot
.40376 .96516 Mdot
.45711 .0885 Mdot
.98638 .29 Mdot
.20723 .82991 Mdot
.05479 .71112 Mdot
.2348 .82551 Mdot
.3127 .88076 Mdot
.13614 .88907 Mdot
.10654 .83315 Mdot
.16774 .03711 Mdot
.2414 .10166 Mdot
.20052 .1199 Mdot
.23319 .91383 Mdot
.21337 .866 Mdot
.2633 .81539 Mdot
.25667 .85303 Mdot
.3129 .93669 Mdot
.15884 .90713 Mdot
.60931 .7795 Mdot
.33397 .03982 Mdot
.18235 .99119 Mdot
.25627 .85732 Mdot
.21612 .86768 Mdot
.13578 .87173 Mdot
.30794 .10022 Mdot
.32181 .57759 Mdot
.34684 .85599 Mdot
.87154 .47293 Mdot
.20693 .82456 Mdot
.29416 .01924 Mdot
.17466 .86469 Mdot
.27818 .89563 Mdot
.27705 .88581 Mdot
.27486 .88577 Mdot
.10533 .93461 Mdot
.21781 .86724 Mdot
.07521 .88036 Mdot
.22602 .86577 Mdot
.41111 .94158 Mdot
.06323 .88497 Mdot
.71268 .62145 Mdot
.43291 .88057 Mdot
.30012 .84124 Mdot
.31114 .90355 Mdot
.36495 .96718 Mdot
.89308 .13281 Mdot
.13658 .35649 Mdot
.18703 .49882 Mdot
.08145 .73169 Mdot
.17815 .14379 Mdot
.15467 .83389 Mdot
.24195 .89175 Mdot
.06543 .62958 Mdot
.42042 .90179 Mdot
.29924 .93273 Mdot
.12423 .99336 Mdot
.24593 .78598 Mdot
.23348 .93787 Mdot
.55973 .85665 Mdot
.30716 .61297 Mdot
.11264 .92078 Mdot
.2009 .14561 Mdot
.09203 .74152 Mdot
.41821 .97473 Mdot
.12215 .8384 Mdot
.02107 .7549 Mdot
.28885 .89173 Mdot
.89339 .16215 Mdot
.30905 .92984 Mdot
.23338 .87124 Mdot
.23025 .88662 Mdot
.74141 .55344 Mdot
.30063 .03478 Mdot
.23663 .10875 Mdot
.18801 .90755 Mdot
.83843 .83377 Mdot
.24291 .73399 Mdot
.29404 .67755 Mdot
.2327 .36691 Mdot
.16069 .89515 Mdot
.31093 .8566 Mdot
.0995 .91565 Mdot
.2152 .866 Mdot
.21422 .92231 Mdot
.2514 .2582 Mdot
.58792 .92619 Mdot
.24645 .92737 Mdot
.74504 .86588 Mdot
.07446 .70945 Mdot
.44661 .67254 Mdot
.8417 .7344 Mdot
.86149 .6807 Mdot
.16336 .88936 Mdot
.33164 .73404 Mdot
.26549 .88288 Mdot
.2666 .8752 Mdot
.18782 .95568 Mdot
.33678 .89778 Mdot
.11257 .17306 Mdot
.58769 .76135 Mdot
.19252 .9237 Mdot
.37736 .49217 Mdot
.15579 .84905 Mdot
.21742 .86209 Mdot
.17565 .91152 Mdot
.22174 .2988 Mdot
.38253 .51982 Mdot
.28033 .95399 Mdot
.23364 .76739 Mdot
.22145 .8429 Mdot
.49015 .81184 Mdot
.07085 .89529 Mdot
.35359 .86318 Mdot
.52847 .11551 Mdot
.31841 .09834 Mdot
.7057 .247 Mdot
.14476 .53413 Mdot
.27843 .86833 Mdot
.22425 .97691 Mdot
.44082 .82285 Mdot
.22319 .76483 Mdot
.14777 .90321 Mdot
.7433 .83178 Mdot
.07539 .20732 Mdot
.13583 .82574 Mdot
.21816 .96685 Mdot
.4267 .0053 Mdot
.24582 .90821 Mdot
.76104 .40825 Mdot
.20035 .86782 Mdot
.0217 .91155 Mdot
.31455 .16657 Mdot
.21847 .86871 Mdot
.40162 .85611 Mdot
.09473 .875 Mdot
.31969 .89137 Mdot
.98168 .54417 Mdot
.08517 .86314 Mdot
.11625 .79519 Mdot
.05918 .97353 Mdot
.00528 .46956 Mdot
.46315 .05115 Mdot
.11941 .92007 Mdot
.27692 .92568 Mdot
.90392 .88099 Mdot
.27858 .97652 Mdot
.4344 .90693 Mdot
.11162 .28051 Mdot
.1978 .17799 Mdot
.2505 .88737 Mdot
.2099 .86008 Mdot
.09367 .84961 Mdot
.07077 .73633 Mdot
.27072 .91626 Mdot
.31553 .77314 Mdot
.29636 .87069 Mdot
.2808 .74366 Mdot
.23552 .85607 Mdot
.2618 .99749 Mdot
.24097 .05698 Mdot
.3431 .8542 Mdot
.23646 .87007 Mdot
.15397 .82481 Mdot
.31902 .63206 Mdot
.1404 .03994 Mdot
.26022 .80318 Mdot
.27301 .86861 Mdot
.23094 .85265 Mdot
.33135 .09612 Mdot
.36169 .96209 Mdot
.15747 .65276 Mdot
.33005 .47647 Mdot
.15628 .86098 Mdot
.65998 .65156 Mdot
.35192 .97644 Mdot
.29752 .31719 Mdot
.09956 .79445 Mdot
.30818 .8743 Mdot
.11978 .79649 Mdot
.39322 .03571 Mdot
.92716 .13265 Mdot
.03317 .86144 Mdot
.36534 .96518 Mdot
.42957 .29274 Mdot
.17458 .49329 Mdot
.3487 .04045 Mdot
.54839 .48108 Mdot
.51113 .86662 Mdot
.13347 .80012 Mdot
.41408 .95924 Mdot
.15841 .92305 Mdot
.21542 .88133 Mdot
.07022 .90211 Mdot
.94299 .87993 Mdot
.21902 .86914 Mdot
.02988 .70736 Mdot
.26749 .88344 Mdot
.17963 .76956 Mdot
.14152 .91222 Mdot
.19698 .84903 Mdot
.39749 .94371 Mdot
.20591 .87347 Mdot
.34462 .90615 Mdot
.4151 .83759 Mdot
.01772 .2681 Mdot
.32386 .87008 Mdot
.44749 .78744 Mdot
.46385 .30098 Mdot
.271 .88668 Mdot
.20169 .03116 Mdot
.42508 .76309 Mdot
.14085 .98019 Mdot
.01913 .98258 Mdot
.20859 .87521 Mdot
.17945 .76927 Mdot
.29979 .90541 Mdot
.1141 .86108 Mdot
.58892 .93926 Mdot
.69575 .81629 Mdot
.2477 .85237 Mdot
.0604 .62863 Mdot
.22485 .78033 Mdot
.61272 .006 Mdot
.32009 .89658 Mdot
.78627 .75233 Mdot
.1625 .66823 Mdot
.21957 .85622 Mdot
.43655 .87008 Mdot
.17499 .20219 Mdot
.95084 .80967 Mdot
.64982 .99146 Mdot
.836 .18539 Mdot
.4452 .99615 Mdot
.31975 .84768 Mdot
.74232 .29053 Mdot
.3001 .8834 Mdot
.95762 .44665 Mdot
.09982 .87083 Mdot
.6493 .93646 Mdot
.11239 .55901 Mdot
.22464 .03607 Mdot
.19015 .08265 Mdot
.91015 .27353 Mdot
.36672 .973 Mdot
.20288 .86806 Mdot
.34063 .64981 Mdot
.4891 .81503 Mdot
.53157 .37334 Mdot
.99892 .87336 Mdot
.09593 .86925 Mdot
.19082 .06239 Mdot
.02982 .49921 Mdot
.18738 .77765 Mdot
.22399 .09053 Mdot
.34906 .83493 Mdot
.22118 .80533 Mdot
.21399 .86747 Mdot
.7407 .00443 Mdot
.28982 .51111 Mdot
.12649 .25002 Mdot
.11919 .7126 Mdot
.36816 .48169 Mdot
.15747 .8162 Mdot
.20979 .93178 Mdot
.28534 .92491 Mdot
.23084 .90065 Mdot
.77306 .43761 Mdot
.389 .87428 Mdot
.36919 .29759 Mdot
.32746 .922 Mdot
.82542 .05326 Mdot
.0121 .83768 Mdot
.08425 .53501 Mdot
.19899 .27413 Mdot
.19691 .82334 Mdot
.31645 .1186 Mdot
.29229 .82551 Mdot
.2095 .91021 Mdot
.41767 .32513 Mdot
.31306 .80362 Mdot
.38809 .88922 Mdot
.60501 .66299 Mdot
.28403 .82953 Mdot
.84241 .25548 Mdot
.43558 .37527 Mdot
.80081 .02221 Mdot
.10547 .82263 Mdot
.30829 .87915 Mdot
.88833 .92437 Mdot
.48611 .33587 Mdot
.27455 .88902 Mdot
.30282 .81039 Mdot
.16289 .80768 Mdot
.22288 .92394 Mdot
.62889 .63664 Mdot
.20724 .5868 Mdot
.15324 .45902 Mdot
.4046 .04275 Mdot
.36963 .76248 Mdot
.42576 .81301 Mdot
.23757 .94457 Mdot
.27724 .99128 Mdot
.29542 .87806 Mdot
.42494 .22583 Mdot
.76181 .00877 Mdot
.44706 .85154 Mdot
.26318 .83382 Mdot
.79484 .98291 Mdot
.09432 .89043 Mdot
.10283 .26714 Mdot
.36005 .07412 Mdot
.13751 .86694 Mdot
.06688 .98623 Mdot
.39171 .88654 Mdot
.28057 .85212 Mdot
.17815 .87035 Mdot
.12662 .83721 Mdot
.2633 .92062 Mdot
.07398 .87652 Mdot
.15431 .84863 Mdot
.71792 .90989 Mdot
.27147 .88507 Mdot
.87162 .47917 Mdot
.12222 .88175 Mdot
.41404 .05929 Mdot
.19674 .89906 Mdot
.19835 .29402 Mdot
.11893 .42723 Mdot
.12734 .99248 Mdot
.7425 .4358 Mdot
.31995 .95116 Mdot
.24267 .71734 Mdot
.206 .76023 Mdot
.11211 .80019 Mdot
.52061 .28 Mdot
.23258 .91217 Mdot
.11743 .78033 Mdot
.15291 .83507 Mdot
.23075 .87774 Mdot
.95244 .5077 Mdot
.25083 .96923 Mdot
.28476 .05971 Mdot
.59194 .37367 Mdot
.46773 .46271 Mdot
.24027 .90595 Mdot
.32035 .13428 Mdot
.3993 .52285 Mdot
.19523 .92331 Mdot
.23701 .88934 Mdot
.18582 .81878 Mdot
.45093 .92054 Mdot
.08117 .08595 Mdot
.5405 .07937 Mdot
.2449 .86736 Mdot
.23326 .65304 Mdot
.11352 .85286 Mdot
.21179 .15151 Mdot
.03015 .88081 Mdot
.26422 .00978 Mdot
.99713 .81645 Mdot
.3415 .43073 Mdot
.21842 .84481 Mdot
.11443 .91927 Mdot
.08423 .77198 Mdot
.96741 .86622 Mdot
.13892 .8456 Mdot
.07904 .73048 Mdot
.00853 .7253 Mdot
.11464 .1013 Mdot
.38761 .92444 Mdot
.22639 .13753 Mdot
.25197 .0094 Mdot
.10383 .89717 Mdot
.45479 .67242 Mdot
.20786 .80424 Mdot
.22343 .86467 Mdot
.17995 .09796 Mdot
.59513 .87923 Mdot
.21748 .83884 Mdot
.40252 .36754 Mdot
.26664 .88309 Mdot
.2393 .86854 Mdot
.10913 .78073 Mdot
.16482 .82302 Mdot
.26899 .89871 Mdot
.45947 .10544 Mdot
.18076 .85702 Mdot
.14373 .83687 Mdot
.4975 .08953 Mdot
.20939 .06172 Mdot
.36653 .98799 Mdot
.18305 .25449 Mdot
.09118 .86365 Mdot
.47522 .37959 Mdot
.42856 .88496 Mdot
.22356 .76719 Mdot
.78314 .58931 Mdot
.27535 .96862 Mdot
.24329 .85131 Mdot
.9278 .07641 Mdot
.26271 .65401 Mdot
.23324 .86316 Mdot
.23402 .86067 Mdot
.23875 .926 Mdot
.82662 .94513 Mdot
.11603 .98487 Mdot
.01393 .58441 Mdot
.14582 .80371 Mdot
.29868 .87647 Mdot
.139 .87213 Mdot
.76491 .99933 Mdot
.03735 .84343 Mdot
.19825 .9015 Mdot
.1938 .96963 Mdot
.30112 .87494 Mdot
.01201 .50426 Mdot
.26908 .88323 Mdot
.23784 .3861 Mdot
.06399 .86297 Mdot
.15981 .85302 Mdot
.25851 .8798 Mdot
.20778 .90609 Mdot
.33623 .9097 Mdot
.91402 .07286 Mdot
.2858 .85887 Mdot
.10566 .95257 Mdot
.36134 .98009 Mdot
.31352 .0638 Mdot
.48466 .48113 Mdot
.19613 .84615 Mdot
.57085 .12489 Mdot
.28428 .84965 Mdot
.32894 .94508 Mdot
.22035 .99131 Mdot
.34107 .99594 Mdot
.23799 .91185 Mdot
.0233 .84872 Mdot
.51493 .87358 Mdot
.07525 .4933 Mdot
.28651 .88737 Mdot
.49089 .86483 Mdot
.18596 .86634 Mdot
.27891 .88615 Mdot
.12481 .92706 Mdot
.05947 .94752 Mdot
.36346 .97193 Mdot
.37442 .91435 Mdot
.11187 .82406 Mdot
.24506 .87009 Mdot
.50226 .89262 Mdot
.56879 .01498 Mdot
.78079 .94837 Mdot
.18687 .03956 Mdot
.27262 .84895 Mdot
.32608 .57268 Mdot
.25332 .86536 Mdot
.48818 .39036 Mdot
.19418 .83129 Mdot
.26877 .84404 Mdot
.13286 .76584 Mdot
.2533 .88811 Mdot
.44789 .92121 Mdot
.30715 .4462 Mdot
.31997 .77619 Mdot
.13729 .8751 Mdot
.90451 .75493 Mdot
.4593 .16828 Mdot
.24404 .81904 Mdot
.29701 .95928 Mdot
.35079 .87667 Mdot
.44857 .78293 Mdot
.55983 .70395 Mdot
.37584 .069 Mdot
.35129 .90226 Mdot
.21076 .87862 Mdot
.26349 .91 Mdot
.39727 .84863 Mdot
.26988 .97177 Mdot
.26661 .5972 Mdot
.25467 .92478 Mdot
.01791 .15391 Mdot
.03658 .75048 Mdot
.35238 .87824 Mdot
.27239 .88754 Mdot
.20421 .85709 Mdot
.05775 .10216 Mdot
.22063 .76533 Mdot
.22245 .91462 Mdot
.77358 .85177 Mdot
.47944 .82956 Mdot
.36311 .78309 Mdot
.15602 .77353 Mdot
.21475 .85742 Mdot
.32263 .82415 Mdot
.46308 .33802 Mdot
.35222 .94437 Mdot
.92503 .542 Mdot
.30564 .80115 Mdot
.22214 .85495 Mdot
.43909 .1325 Mdot
.16702 .83342 Mdot
.23205 .92902 Mdot
.32962 .94437 Mdot
.23854 .35622 Mdot
.17309 .99587 Mdot
.21569 .87198 Mdot
.40891 .86944 Mdot
.35765 .91953 Mdot
.19596 .92136 Mdot
.93993 .19841 Mdot
.16706 .84854 Mdot
.73318 .94128 Mdot
.34019 .05812 Mdot
.37247 .13665 Mdot
.07449 .69087 Mdot
.14241 .80727 Mdot
.0638 .72459 Mdot
.36671 .95047 Mdot
.25473 .99396 Mdot
.6284 .91908 Mdot
.22542 .86845 Mdot
.21311 .86729 Mdot
.21559 .83945 Mdot
.07827 .86375 Mdot
.24191 .85675 Mdot
.51523 .4018 Mdot
.29948 .8651 Mdot
.31778 .87223 Mdot
.88127 .69999 Mdot
.32732 .32042 Mdot
.28291 .97925 Mdot
.35476 .27599 Mdot
.28287 .5917 Mdot
.28238 .1485 Mdot
.6128 .95056 Mdot
.29484 .89268 Mdot
.13553 .12441 Mdot
.94055 .7016 Mdot
.22588 .85986 Mdot
.27571 .84588 Mdot
.17736 .90192 Mdot
.04192 .87125 Mdot
.68348 .21688 Mdot
.26397 .74066 Mdot
.27279 .83983 Mdot
.22142 .12234 Mdot
.98591 .97077 Mdot
.99734 .18366 Mdot
.30711 .86799 Mdot
.25834 .85854 Mdot
.47018 .47398 Mdot
.25783 .97669 Mdot
.28981 .72488 Mdot
.64165 .70699 Mdot
.19103 .81333 Mdot
.31401 .88406 Mdot
.25142 .83877 Mdot
.33488 .82431 Mdot
.30741 .92639 Mdot
.17512 .9273 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`;o000000?oooooo`000?oo
ool03oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo000Nooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`05ooooo`;o0000
1_ooool00ol0003oooooooooo`06ooooo`;o00001Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool00_l0000;ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool02_ooool2o`000003ooooool0003ooooo00oooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003oooooooooo`1>ooooo`;o00000_oo
ool2o`000003ooooool0003o0000033ooooo0_l0000?ooooo`;o0000:Oooool2o`0002oooooo0_l0
001Aooooo`007_ooool00ol0003oooooooooo`1>ooooo`;o00000_ooool2o`000003ooooool0003o
000000Gooooo0_l00011ooooo`;o0000Doooool2o`00057ooooo000Nooooo`03o`000?oooooooooo
00kooooo0_l0000Rooooo`;o0000:?ooool2o`00047ooooo0_l0000Dooooo`;o0000T?ooool001ko
oooo00?o0000ooooooooool03_ooool2o`0002;ooooo0_l0000=ooooo`;o00006Oooool2o`0005Oo
oooo0_l0002@ooooo`007_ooool00ol0003oooooooooo`11ooooo`;o00006Oooool2o`000:;ooooo
0_l00015ooooo`007_ooool00ol0003oooooooooo`3oooooo`7ooooo0_l00015ooooo`007_ooool0
0ol0003oooooooooo`2Sooooo`;o0000X_ooool001kooooo00?o0000ooooooooool0?Oooool2o`00
01Sooooo0_l0001:ooooo`;o0000FOooool2o`0004Oooooo000Nooooo`03o`000?oooooooooo03go
oooo0_l0000Hooooo`;o00001Oooool2o`0002_ooooo0_l0001aooooo`;o0000Aoooool001kooooo
00?o0000ooooooooool0<_ooool2o`00017ooooo0_l0000Gooooo`;o00007?ooool2o`0000gooooo
0_l0002jooooo`007_ooool00ol0003oooooooooo`0Zooooo`;o00001_ooool2o`0000Gooooo0_l0
000:ooooo`;o00008Oooool2o`0000?ooooo0_l0000=ooooo`;o0000bOooool001kooooo00?o0000
ooooooooool0:_ooool2o`0000gooooo0_l0000]ooooo`;o00000oooool2o`00013ooooo0_l0001Y
ooooo`;o0000Foooool001kooooo00?o0000ooooooooool0<_ooool2o`0004_ooooo0_l0001Yoooo
o`;o0000Foooool001kooooo00?o0000ooooooooool0<_ooool2o`00063ooooo0_l0002Tooooo`;o
00002oooool001kooooo0_l0002Cooooo`Co0000L_ooool2o`00033ooooo0_l0000;ooooo`007_oo
ool00ol0003oooooooooo`16ooooo`;o0000B_ooool2o`0007Cooooo0_l0000@ooooo`;o0000:ooo
ool001kooooo0ol0000Cooooo`;o0000<Oooool2o`0000;ooooo0_l0000<ooooo`;o00004?ooool2
o`0001Kooooo0_l0002Fooooo`;o0000:oooool001kooooo0ol0000Cooooo`;o00009Oooool3o`00
00?ooooo0_l00008ooooo`;o00003?ooool2o`00013ooooo0_l0000Fooooo`;o0000`oooool001ko
oooo00?o0000ooooooooool0>_ooool3o`0000?ooooo0_l0000Pooooo`;o00001_ooool2o`000=_o
oooo000Nooooo`03o`000?oooooooooo04cooooo0_l0000?ooooo`;o00000oooool2o`0000Kooooo
0_l0000:ooooo`;o0000coooool001kooooo00?o0000ooooooooool0C?ooool2o`0000oooooo0ol0
000Fooooo`;o0000coooool001kooooo00?o0000ooooooooool0C?ooool2o`00013ooooo0_l0000A
ooooo`;o0000/_ooool2o`00023ooooo000Nooooo`03o`000?oooooooooo077ooooo0_l0002boooo
o`;o00000oooool2o`0001_ooooo000Nooooo`03o`000?oooooooooo05[ooooo0_l00013ooooo`;o
00002oooool2o`0007cooooo0_l0000Kooooo`007_ooool00ol0003oooooooooo`0jooooo`;o0000
7_ooool2o`0003_ooooo0_l00006ooooo`;o00002oooool2o`0009Wooooo000Nooooo`03o`000?oo
oooooooo01Kooooo0_l0000Rooooo`;o0000Foooool2o`000:kooooo000Nooooo`03o`000?oooooo
oooo01Kooooo0_l0000]ooooo`;o0000BOooool2o`0000cooooo0_l0002Wooooo`007_ooool00ol0
003oooooooooo`15ooooo`;o0000BOooool2o`0000cooooo0_l0002Wooooo`007_ooool00ol0003o
ooooooooo`0Gooooo`;o0000Coooool2o`00017ooooo0_l0003:ooooo`007_ooool00ol0003ooooo
ooooo`0Gooooo`;o00007Oooool2o`0002_ooooo0_l00003ooooo`;o00004Oooool2o`000<[ooooo
000Nooooo`;o00004?ooool2o`0000Wooooo0_l00005ooooo`;o00004oooool2o`0001;ooooo0_l0
000Dooooo`;o000000?oooooo`000?l00000h_ooool001kooooo00?o0000ooooooooool03oooool2
o`0000Wooooo0_l00005ooooo`;o00006?ooool2o`0000gooooo0_l0000Dooooo`;o0000;oooool3
o`000;?ooooo000Nooooo`03o`000?oooooooooo03_ooooo0_l0000<ooooo`;o0000@Oooool2o`00
00?ooooo0ol0002cooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o00006Oooool2o`000003
ooooool0003o000000Wooooo0_l00011ooooo`;o00001?ooool2o`0004Gooooo0_l0001>ooooo`;o
00007?ooool001kooooo00?o0000ooooooooool08?ooool2o`0001cooooo0ol0000Looooo`;o0000
2oooool4o`0006_ooooo0_l0001>ooooo`;o00007?ooool001kooooo00?o0000ooooooooool0?_oo
ool3o`0001cooooo0_l0000;ooooo`Co0000>_ooool2o`0009gooooo000Nooooo`03o`000?oooooo
oooo013ooooo0_l0000[ooooo`;o00009?ooool2o`0004?ooooo0_l0002Mooooo`007_ooool00ol0
003oooooooooo`0@ooooo`;o00005_ooool2o`0001?ooooo0_l00005ooooo`;o00007Oooool2o`00
02_ooooo0_l0002eooooo`007_ooool00ol0003oooooooooo`0Xooooo`;o00000_ooool2o`0001Ko
oooo0_l000000ooooooo0000o`000017ooooo`;o00008oooool2o`00093ooooo000Nooooo`03o`00
0?oooooooooo02cooooo0_l0000Iooooo`;o0000K?ooool2o`00093ooooo000Nooooo`03o`000?oo
oooooooo06Kooooo0_l0000=ooooo`;o00005?ooool2o`00097ooooo0_l00009ooooo`;o00007?oo
ool001kooooo00?o0000ooooooooool0I?ooool4o`0000gooooo0_l0000Dooooo`;o0000TOooool2
o`0000Wooooo0_l0000Looooo`007_ooool00ol0003oooooooooo`15ooooo`;o00007Oooool2o`00
00oooooo0_l0000Cooooo`;o0000^oooool001kooooo00?o0000ooooooooool0AOooool2o`0004?o
oooo0_l0002kooooo`007_ooool00ol0003oooooooooo`0fooooo`;o00001Oooool2o`00023ooooo
0_l0003Vooooo`007_ooool00ol0003oooooooooo`0fooooo`;o00001Oooool2o`0001Wooooo0_l0
0005ooooo`;o0000i_ooool001kooooo0_l00012ooooo`;o00005Oooool2o`000>gooooo000Noooo
o`03o`000?oooooooooo00;ooooo0_l00009ooooo`;o00008oooool2o`0000gooooo0_l0003ooooo
o`Gooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l00009ooooo`;o00008oooool2o`0008go
oooo0_l00024ooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o0000FOooool2o`0004cooooo
0_l00024ooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o0000FOooool2o`000:Wooooo0_l0
000Wooooo`007_ooool00ol0003oooooooooo`1Rooooo`;o0000^_ooool2o`0002Oooooo000Noooo
o`03o`000?oooooooooo03Wooooo0_l0000Wooooo`;o0000;Oooool2o`000;Cooooo000Nooooo`03
o`000?oooooooooo023ooooo0_l0000Gooooo`;o0000E_ooool2o`000;Cooooo000Nooooo`03o`00
0?oooooooooo023ooooo0_l0003oooooobKooooo000Nooooo`03o`000?oooooooooo03cooooo0_l0
003oooooo`[ooooo000Nooooo`03o`000?oooooooooo03cooooo0_l0000?ooooo`;o0000n?ooool0
01kooooo00?o0000ooooooooool0COooool2o`0000Kooooo0_l0002eooooo`;o0000<_ooool2o`00
00Gooooo000Nooooo`03o`000?oooooooooo05Gooooo0_l0002eooooo`;o0000<_ooool2o`0000Go
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0lOooool2o`0002Gooooo
0_l0000]ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1fooooo`;o0000NOooool2o`0002Go
oooo0_l0000]ooooo`000oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^
k^h01oooool3o`0007Kooooo0_l0002eooooo`;o00006?ooool000?ooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Gooooo0_l0000gooooo`;o0000m_ooool2o`0001So
oooo0003ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`04ooooo`;o
00005_ooool2o`0001oooooo0_l0003ooooooa7ooooo0003ooooo`05oa0@4?ooooooooooooooool@
41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Cooooo0_l0003ooooooc;o
oooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@
00Kooooo00?o0000ooooooooool0l?ooool2o`0005Gooooo0003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0l?ooool2
o`0005Gooooo000Nooooo`03o`000?oooooooooo0=[ooooo0_l0001[ooooo`007_ooool00ol0003o
ooooooooo`3Jooooo`;o0000Joooool001kooooo00?o0000ooooooooool0Q_ooool2o`00017ooooo
0_l0002/ooooo`007_ooool00ol0003oooooooooo`26ooooo`;o00004Oooool2o`000:cooooo000N
ooooo`03o`000?oooooooooo083ooooo0_l00035ooooo`007_ooool00ol0003oooooooooo`20oooo
o`;o0000aOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo02gooooo0_l0003ooooooaWooooo000N
ooooo`03o`000?oooooooooo02gooooo0_l0002booooo`;o0000I?ooool001kooooo00?o0000oooo
ooooool09Oooool2o`000;[ooooo0_l0001Tooooo`007_ooool2o`0002Kooooo0_l0003oooooob7o
oooo000Nooooo`03o`000?oooooooooo03Oooooo0_l0003Eooooo`;o0000=oooool001kooooo00?o
0000ooooooooool0=oooool2o`0001Gooooo0_l0000@ooooo`;o0000[?ooool2o`0003Oooooo000N
ooooo`03o`000?oooooooooo04kooooo0_l0000@ooooo`;o0000iOooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`02ooooo`;o00006Oooool2o`000?oo
oooo:Oooool001kooooo00?o0000ooooooooool00_ooool2o`0001Wooooo0_l0003oooooobWooooo
000Nooooo`03o`000?oooooooooo03gooooo0_l0003Uooooo`;o00008Oooool001kooooo00?o0000
ooooooooool0?Oooool2o`00033ooooo0_l0000Fooooo`;o0000Voooool2o`00027ooooo000Noooo
o`03o`000?oooooooooo023ooooo0_l0001=ooooo`;o00005_ooool2o`0001cooooo0_l0002Poooo
o`007_ooool00ol0003oooooooooo`0Pooooo`;o0000Poooool2o`000:3ooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0;oooool2o`00013ooooo0_l0
002Zooooo`;o0000C_ooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo02oooooo0_l0000@
ooooo`;o0000AOooool2o`0006?ooooo0_l0001>ooooo`;o00002?ooool001kooooo00?o0000oooo
ooooool0??ooool2o`0004[ooooo0_l0002mooooo`007_ooool00ol0003oooooooooo`0looooo`;o
00001_ooool2o`0002kooooo0_l0003Aooooo`007_ooool2o`0004Gooooo0_l0000^ooooo`;o0000
4oooool2o`0000Sooooo0_l0002booooo`007_ooool00ol0003oooooooooo`29ooooo`;o00002?oo
ool2o`000;;ooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo05gooooo0_l0003Xooooo`007_ooool00ol0003oooooooooo`1Mooooo`;o00001ooo
ool2o`000=oooooo000Nooooo`03o`000?oooooooooo06Kooooo0_l0003Oooooo`007_ooool00ol0
003oooooooooo`24ooooo`;o0000`Oooool001kooooo00?o0000ooooooooool0Q?ooool2o`000<7o
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0EOoo
ool2o`0004?ooooo0_l0001cooooo`;o0000=_ooool001kooooo00?o0000ooooooooool0EOooool2
o`0003_ooooo0_l00006ooooo`;o0000Loooool2o`0003Kooooo000Nooooo`03o`000?oooooooooo
09;ooooo0_l0002cooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0:?ooool2o`0001oooooo0_l0000Doooo
o`;o0000i_ooool001kooooo00?o0000ooooooooool0:?ooool2o`0001oooooo0_l0000Dooooo`;o
0000i_ooool001kooooo00?o0000ooooooooool0G_ooool2o`000>Oooooo000Nooooo`03o`000?oo
oooooooo04Sooooo0_l0000Dooooo`;o0000aOooool2o`00023ooooo000Nooooo`03o`000?oooooo
oooo04Sooooo0_l0000eooooo`;o0000Y?ooool2o`0000Wooooo0_l0000Eooooo`007_ooool00ol0
003oooooooooo`1Sooooo`;o00004?ooool2o`0000Sooooo0_l0000Xooooo`;o0000QOooool2o`00
01Gooooo000Nooooo`03o`000?oooooooooo06?ooooo0_l0000@ooooo`;o00004_ooool2o`0001ko
oooo0_l0000Aooooo`;o0000ROooool001kooooo00?o0000ooooooooool0ROooool2o`0000_ooooo
0_l0000Tooooo`;o0000ROooool001kooooo00?o0000ooooooooool0U_ooool2o`000:oooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0BOooool2o`00
0?cooooo000Nooooo`03o`000?oooooooooo04Wooooo0_l0001@ooooo`;o0000Z_ooool000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Co
oooo00?o0000ooooooooool0Voooool2o`000:[ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Sooooo`;o
0000oooooolSooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`?o
00008oooool2o`0000;ooooo0_l0003ooooooaoooooo0003ooooo`05o`000?ooooooooooooooool0
00002oooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo013ooooo0_l0000Eoooo
o`;o0000?Oooool2o`0003_ooooo0_l0002Rooooo`000oooool01Ol0003ooooooooooooooooo0000
00_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`0@ooooo`;o0000E?ooool2
o`0003_ooooo0_l0002Rooooo`000oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMg
olc<c?l000001oooool00ol0003oooooooooo`3cooooo`;o0000D_ooool000?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0I_ooool2
o`0008_ooooo0_l0001Booooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMg
o`000?ooool01_ooool00ol0003oooooooooo`0Kooooo`;o0000BOooool2o`000=oooooo000Noooo
o`03o`000?oooooooooo01_ooooo0_l0003oooooob_ooooo000Nooooo`03o`000?oooooooooo07;o
oooo0_l0003Cooooo`007_ooool00ol0003oooooooooo`1booooo`;o0000]oooool2o`0001[ooooo
000Nooooo`03o`000?oooooooooo02?ooooo0_l0002Wooooo`;o0000GOooool2o`0001[ooooo000N
ooooo`03o`000?oooooooooo02?ooooo0_l00016ooooo`;o0000Goooool2o`0007Wooooo000Noooo
o`03o`000?oooooooooo06_ooooo0_l0003Jooooo`007_ooool00ol0003oooooooooo`3]ooooo`;o
00002?ooool2o`0004kooooo000Nooooo`03o`000?oooooooooo0>gooooo0_l00008ooooo`;o0000
C_ooool001kooooo00?o0000ooooooooool0N_ooool2o`000<_ooooo000Nooooo`03o`000?oooooo
oooo063ooooo0_l00008ooooo`;o00003_ooool2o`000;Oooooo0_l0000Booooo`007_ooool00ol0
003oooooooooo`1Pooooo`;o00002?ooool2o`000<Oooooo0_l0000Booooo`007_ooool2o`000?oo
ooooBOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`0Kooooo`;o00004Oooool2o`000?oooooo6?ooool001kooooo00?o0000ooooooooool06oooool2
o`00017ooooo0_l0001Tooooo`;o0000/Oooool001kooooo00?o0000ooooooooool0U?ooool2o`00
0;7ooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo
000Nooooo`?o0000UOooool2o`00083ooooo0_l0000^ooooo`007_ooool00ol0003oooooooooo`1W
ooooo`;o0000;?ooool2o`0002_ooooo0_l0001Cooooo`;o0000;_ooool001kooooo00?o0000oooo
ooooool0Ioooool2o`00033ooooo0_l0000Cooooo`;o00004_ooool2o`0005?ooooo0_l0000^oooo
o`007_ooool00ol0003oooooooooo`1dooooo`;o00008oooool2o`0001?ooooo0_l0001Wooooo`;o
0000;_ooool001kooooo00?o0000ooooooooool04Oooool2o`00067ooooo0_l0003Aooooo`007_oo
ool01?l0003oooooo`000?l0000@ooooo`;o0000ooooooleooooo`007_ooool01?l0003oooooo`00
0?l0000Cooooo`;o00007oooool2o`00043ooooo0_l0000^ooooo`;o0000W_ooool001kooooo00?o
0000ooooooooool05?ooool2o`0001oooooo0_l00010ooooo`;o0000;_ooool2o`0009kooooo000N
ooooo`03o`000?oooooooooo00Kooooo0_l0000aooooo`;o0000ooooool=ooooo`007_ooool2o`00
00Oooooo0_l0000aooooo`;o0000ooooool=ooooo`007_ooool00ol0003oooooooooo`02o`000?oo
ooooA_ooool001kooooo00?o0000ooooooooool00_l00024ooooo`;o0000Z_ooool2o`0001?ooooo
000Nooooo`03o`000?oooooooooo05[ooooo0_l0000Zooooo`;o0000Z_ooool2o`0001?ooooo000N
ooooo`03o`000?oooooooooo05[ooooo0_l0000Looooo`;o0000cOooool001kooooo00?o0000oooo
ooooool0N?ooool2o`000<gooooo000Nooooo`03o`000?oooooooooo07Sooooo0_l0003=ooooo`00
7_ooool00ol0003oooooooooo`08ooooo`;o0000K_ooool2o`0000Cooooo0_l00037ooooo`007_oo
ool00ol0003oooooooooo`08ooooo`;o00001_ooool2o`0003Sooooo0_l0000booooo`;o0000aooo
ool001kooooo00?o0000ooooooooool04?ooool2o`0003Sooooo0_l0003kooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0000Booooo`;o
0000M?ooool2o`000:Cooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0000Booooo`;o0000
M?ooool2o`000:Cooooo000Nooooo`03o`000?oooooooooo0?oooooo:_ooool2o`0001cooooo000N
ooooo`03o`000?oooooooooo0?oooooo:_ooool2o`00013ooooo0_l0000:ooooo`007_ooool00ol0
003oooooooooo`3ooooooccooooo0_l0000:ooooo`007_ooool2o`0001;ooooo0_l0003oooooocGo
oooo000Nooooo`03o`000?oooooooooo017ooooo0_l0003Jooooo`;o0000F?ooool001gooooo0_l0
000eooooo`;o0000^?ooool2o`0005Sooooo000Mooooo`;o00008_ooool2o`00017ooooo0_l0003o
oooooa?ooooo000Nooooo`03o`000?oooooooooo023ooooo0_l0003oooooobKooooo000Nooooo`03
o`000?oooooooooo0;_ooooo0_l0002:ooooo`007_ooool00ol0003oooooooooo`2kooooo`;o0000
R_ooool001kooooo00?o0000ooooooooool0I_ooool2o`0007oooooo0_l0001Nooooo`007_ooool0
0ol0003oooooooooo`1Vooooo`;o0000Ooooool2o`0005kooooo000Nooooo`03o`000?oooooooooo
06Gooooo0_l0001oooooo`;o0000Goooool001kooooo00?o0000ooooooooool0IOooool2o`0007oo
oooo0_l0001Booooo`;o00002oooool001kooooo00?o0000ooooooooool00_l0001Oooooo`;o0000
DOooool2o`0008Cooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`02o`0001Cooooo0_l0
000Wooooo`;o00008?ooool2o`00057ooooo0_l0002Aooooo`007_ooool00ol0003oooooooooo`0F
ooooo`;o00009oooool2o`0001Oooooo0_l00027ooooo`;o00005oooool2o`0004_ooooo0003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<
c006ooooo`03o`000?oooooooooo05Sooooo0_l0001Vooooo`;o00007oooool2o`0001Oooooo0_l0
001;ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0]ooooo`;o00009?ooool2o`0000Cooooo
0_l000000ooooooo0000o`00001Rooooo`;o0000QOooool000?ooooo00Go410@oooooooooooooooo
oa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`0002gooooo0_l000000ooooooo
0000o`00000Qooooo`;o00001?ooool2o`000003ooooool0003o00000>Wooooo0003ooooo`05o`00
0?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o0000oooo
ooooool0<?ooool2o`000=;ooooo0_l00011ooooo`000oooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo1Oooool2
o`00047ooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08
ooooo`03o`000?oooooooooo00Wooooo0_l0003oooooocgooooo0003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo00Wooooo0_l00010
ooooo`;o00002_ooool2o`0000Oooooo0_l0003Uooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`0Rooooo`;o00009ooo
ool2o`0000[ooooo0_l00007ooooo`;o0000=Oooool2o`000:kooooo000Nooooo`03o`000?oooooo
oooo02;ooooo0_l0001cooooo`;o0000[_ooool001kooooo00?o0000ooooooooool0i?ooool2o`00
067ooooo000Nooooo`03o`000?oooooooooo06gooooo0_l0001eooooo`;o0000HOooool001kooooo
00?o0000ooooooooool04?ooool2o`0005_ooooo0_l0003Hooooo`007_ooool00ol0003ooooooooo
o`0@ooooo`?o0000ooooooleooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o0000DOooool2
o`000>7ooooo000Nooooo`03o`000?oooooooooo06Cooooo0_l0001Rooooo`;o0000OOooool001ko
oooo00?o0000ooooooooool0b?ooool2o`0007gooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`1[
ooooo`;o00000oooool2o`000=Gooooo000Nooooo`;o0000<?ooool2o`0001Oooooo0_l0000Qoooo
o`;o00000oooool2o`00063ooooo0_l0001cooooo`007_ooool00ol0003oooooooooo`0_ooooo`;o
00001oooool2o`0000kooooo0_l00007ooooo`;o0000Ooooool2o`0007?ooooo000Nooooo`03o`00
0?oooooooooo03Sooooo0_l0000Gooooo`;o0000m?ooool001kooooo00?o0000ooooooooool0B?oo
ool2o`00013ooooo0_l0001Uooooo`;o0000Q?ooool001kooooo00?o0000ooooooooool0;Oooool2
o`0001Wooooo0_l0000@ooooo`;o0000IOooool2o`0008Cooooo000Nooooo`03o`000?oooooooooo
02gooooo0_l00002ooooo`;o0000S_ooool2o`0008Cooooo000Nooooo`03o`000?oooooooooo037o
oooo0_l0003ooooooaGooooo000Nooooo`03o`000?oooooooooo08gooooo0_l000000ooooooo0000
o`00002eooooo`007_ooool00ol0003oooooooooo`1Kooooo`;o0000<?ooool2o`000003ooooool0
003o00000;Gooooo000Nooooo`03o`000?oooooooooo05_ooooo0_l0002gooooo`;o0000<Oooool0
01kooooo00?o0000ooooooooool0oooooolEooooo`;o0000<Oooool001kooooo00?o0000oooooooo
ool0L?ooool2o`000=Gooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l0000_ooooo`;o0000
3?ooool2o`0000_ooooo0_l0003Eooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o00003_oo
ool2o`00023ooooo0_l0000=ooooo`;o00003?ooool2o`0003[ooooo0_l0002Nooooo`;o00001_oo
ool001kooooo00?o0000ooooooooool03Oooool2o`0000Gooooo0_l0000`ooooo`;o000000?ooooo
o`000?l00000E?ooool2o`0000Cooooo0_l0002Hooooo`;o00001_ooool001kooooo00?o0000oooo
ooooool03Oooool2o`0003[ooooo0_l0001Jooooo`;o0000=_ooool2o`0006Sooooo000Nooooo`;o
0000g_ooool2o`0003_ooooo0_l0000Booooo`;o00005oooool001kooooo00?o0000ooooooooool0
/_ooool2o`0006Kooooo0_l0000Booooo`;o00005oooool001kooooo00?o0000ooooooooool01_oo
ool2o`000:[ooooo0_l0000Hooooo`;o0000NOooool001kooooo00?o0000ooooooooool01_ooool2
o`0000Kooooo0_l00004ooooo`;o0000]_ooool2o`0007Wooooo000Nooooo`03o`000?oooooooooo
00kooooo0_l00004ooooo`;o00003Oooool2o`0001?ooooo0_l0003oooooo`kooooo000Nooooo`03
o`000?oooooooooo02?ooooo0_l0000Cooooo`;o00004Oooool2o`000?[ooooo000Nooooo`03o`00
0?oooooooooo04_ooooo0_l0003jooooo`007_ooool00ol0003oooooooooo`1oooooo`;o0000a_oo
ool001kooooo00Co0000ooooool0003o00004?ooool2o`0002Cooooo0_l0000Dooooo`;o00002ooo
ool2o`0002?ooooo0_l00021ooooo`;o0000@oooool001kooooo00Co0000ooooool0003o00004?oo
ool2o`0001Wooooo0_l00009ooooo`;o00005?ooool2o`0000_ooooo0_l0002Vooooo`;o00000_oo
ool2o`0003oooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l0000Dooooo`;o0000f?ooool2
o`0003oooooo000Nooooo`03o`000?oooooooooo01?ooooo0_l000000ooooooo0000o`00000coooo
o`;o00003_ooool2o`0000_ooooo0_l00003ooooo`;o0000J_ooool2o`0003?ooooo0_l0000goooo
o`007_ooool00ol0003oooooooooo`0Cooooo`;o0000=_ooool2o`0000kooooo0_l0000;ooooo`;o
00000oooool2o`0006[ooooo0_l0000cooooo`;o0000=oooool001kooooo00?o0000ooooooooool0
6_ooool2o`0003Kooooo0_l0002Cooooo`;o0000G_ooool001kooooo00?o0000ooooooooool03_oo
ool2o`0000[ooooo0_l0000Sooooo`;o00004Oooool2o`0000?ooooo0_l0000fooooo`;o0000A?oo
ool2o`00013ooooo0_l0001Nooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o00007?ooool2
o`00017ooooo0_l0000Fooooo`;o0000=_ooool2o`0004Cooooo0_l0001`ooooo`007_ooool2o`00
00Wooooo0_l0000;ooooo`;o00005Oooool2o`000?oooooo6_ooool001kooooo00?o0000oooooooo
ool00oooool2o`0000?ooooo0_l0000;ooooo`;o0000;_ooool2o`000;Gooooo0_l0000Tooooo`;o
00008oooool001kooooo00?o0000ooooooooool00oooool2o`00043ooooo0_l00009ooooo`;o0000
POooool2o`0002Oooooo0_l0000Tooooo`;o00008oooool001kooooo00?o0000ooooooooool0>?oo
ool2o`0000Gooooo0_l0000?ooooo`;o0000POooool2o`0007;ooooo000Nooooo`03o`000?oooooo
oooo03Sooooo0_l00003ooooo`Co00001Oooool2o`0002cooooo0_l0000@ooooo`;o0000<oooool2
o`0008[ooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l0000>ooooo`;o00001?ooool2o`00
00Gooooo1?l0000/ooooo`;o00004?ooool2o`0003?ooooo0_l0002:ooooo`007_ooool00ol0003o
ooooooooo`0;ooooo`;o00006_ooool2o`0000Sooooo0_l000000ooooooo0000o`000003o`000003
ooooool0003o000000Sooooo0ol000000ooooooo0000o`00003mooooo`007_ooool00ol0003ooooo
ooooo`0;ooooo`;o00002_ooool2o`0000oooooo0_l00007ooooo`;o000000?oooooo`000?l00000
0_l00002ooooo`;o00003?ooool2o`0001Sooooo0_l0003Sooooo`007_ooool00ol0003ooooooooo
o`0Gooooo`;o00003oooool4o`0000?ooooo0_l0000Looooo`;o00004oooool4o`000>7ooooo000N
ooooo`03o`000?oooooooooo02[ooooo0_l00003ooooo`;o00002?ooool2o`0000kooooo0_l00002
ooooo`;o00005Oooool2o`0002Kooooo0_l0000dooooo`;o0000Poooool001kooooo00?o0000oooo
ooooool07oooool2o`000003ooooool0003o000001Gooooo0_l0000:ooooo`;o00000_ooool2o`00
03kooooo0_l000000ooooooo0000o`00000dooooo`;o0000Poooool001kooooo00?o0000oooooooo
ool07oooool2o`000003ooooool0003o0000027ooooo0_l00004ooooo`;o00009Oooool2o`0001Go
oooo0_l00003ooooo`;o0000]oooool001kooooo00?o0000ooooooooool08oooool2o`0001kooooo
1?l00004ooooo`?o000000?oooooo`000?l000003oooool2o`00013ooooo0_l0000Iooooo`?o0000
]oooool001kooooo00?o0000ooooooooool03oooool2o`0000Gooooo0_l0000;ooooo`;o000000?o
ooooo`000?l000006oooool2o`0000Oooooo0_l000000ooooooo0000o`00000?ooooo`?o0000:_oo
ool2o`0007Kooooo0_l00010ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0?ooooo`;o0000
1Oooool2o`0000Cooooo0_l00007ooooo`?o0000>Oooool2o`0000;ooooo0_l0002Nooooo`;o0000
@?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RH
oooooonHV9So8B4Q00Kooooo00?o0000ooooooooool07?ooool2o`0000Cooooo1_l0000mooooo`;o
0000h?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool000001_ooool3o`00023ooooo1Ol00002ooooo`;o00001oooool2o`0002oooooo0_l0003Toooo
o`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06
ooooo`03o`000?oooooooooo023ooooo0_l00005ooooo`;o00000_ooool2o`0000?ooooo0_l0000>
ooooo`Co00003?ooool2o`0000gooooo1Ol0003Sooooo`000oooool01Ol0003ooooooooooooooooo
000000_ooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo013ooooo0_l0
000Fooooo`Go00004_ooool7o`0000[ooooo0_l0000=ooooo`;o000000?oooooo`000?l00000[Ooo
ool2o`0003Cooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooo
oonj^[[o410@00Kooooo00?o0000ooooooooool04?ooool2o`0001Kooooo1?l00005ooooo`;o0000
3?ooool2o`0000?ooooo0_l0000Gooooo`;o00002Oooool2o`000:Oooooo0_l0000Nooooo`;o0000
5?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l0
00001_ooool00ol0003oooooooooo`0Zooooo`;o00001Oooool2o`0000Oooooo0_l0000Qooooo`?o
00002?ooool2o`0001cooooo0_l0000Cooooo`;o0000U?ooool2o`0001Cooooo0003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000oooo
ooooool08_ooool2o`0000Kooooo0_l00003ooooo`;o00002Oooool2o`0001Gooooo0_l0000;oooo
o`;o00009_ooool2o`0001?ooooo0_l00011ooooo`;o0000?Oooool2o`00027ooooo0_l00005oooo
o`007_ooool00ol0003oooooooooo`0Fooooo`;o00001?ooool2o`0000Cooooo0_l00006ooooo`?o
00000_ooool2o`0000Oooooo0_l0000Aooooo`;o00001?ooool2o`0004Sooooo0_l00011ooooo`;o
0000?Oooool2o`00027ooooo0_l00005ooooo`007_ooool00ol0003oooooooooo`0Fooooo`;o0000
1?ooool4o`0000_ooooo0_l00005ooooo`;o00001?ooool2o`00017ooooo0_l0000Fooooo`Go0000
goooool001kooooo00?o0000ooooooooool07_ooool4o`0000Kooooo0_l00004ooooo`;o000000Co
ooooo`000?l0003o00002?ooool2o`000003ooooool0003o000000;o00001Oooool2o`00017ooooo
0_l00006ooooo`So00008?ooool2o`000;[ooooo000Nooooo`?o00008?ooool4o`0000?ooooo0ol0
0004ooooo`;o000000?oooooo`000?l000002Oooool2o`000003ooooool0003o000000;o00001Ooo
ool2o`0000Kooooo0ol00008ooooo`;o00002?ooool2o`000003ooooool0003o000000;o00007ooo
ool2o`000;[ooooo000Nooooo`?o00008_ooool2o`0000?ooooo0ol00003ooooo`;o00002_ooool4
o`0000;ooooo0_l0000?ooooo`?o00001Oooool2o`00013ooooo0_l0000Nooooo`;o00003?ooool2
o`0005Cooooo0_l0001Gooooo`007_ooool00ol0003oooooooooo`06ooooo`;o00005oooool2o`00
00Oooooo0_l00003ooooo`?o00000_ooool2o`0000Gooooo2Ol0000?ooooo`;o000000?oooooo`00
0?l000000_ooool2o`0000_ooooo0_l00006ooooo`;o00006oooool2o`0000cooooo0_l0001Doooo
o`;o00007?ooool2o`0003Wooooo000Nooooo`03o`000?oooooooooo00;o00001?ooool2o`0001Oo
oooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000002oooo
o`;o00002Oooool2o`000003ooooool0003o000000oooooo0_l000001?oooooo0000o`000?ooool2
o`0000cooooo0_l00006ooooo`;o00005?ooool2o`0005Wooooo0_l0000/ooooo`;o0000>Oooool0
01kooooo00?o0000ooooooooool00_l0000Rooooo`?o00001?ooool5o`0000gooooo0_l00003oooo
o`Co00002?ooool2o`0000Gooooo1?l0000Zooooo`;o0000A?ooool2o`0001?ooooo0_l0001Woooo
o`007_ooool00ol0003oooooooooo`08ooooo`;o00006_ooool3o`0000?ooooo0_l000000ooooooo
0000o`00000Cooooo`Co00001oooool3o`0000?ooooo1?l00006ooooo`;o00001oooool2o`0002Oo
oooo0_l0000hooooo`;o0000O?ooool001kooooo00?o0000ooooooooool02?ooool2o`0000?ooooo
0_l0000Jooooo`?o00004?ooool2o`0000Gooooo0ol00007ooooo`;o00001?ooool2o`000003oooo
ool0003o000000Gooooo0_l00007ooooo`;o00009oooool2o`000;Kooooo000Nooooo`03o`000?oo
oooooooo00?ooooo0_l00008ooooo`;o00002oooool2o`0000Kooooo0_l00003ooooo`Co00000ooo
ool3o`000003ooooool0003o000000Sooooo0_l00005ooooo`Co00001Oooool2o`0000Oooooo1Ol0
000:ooooo`;o00005oooool2o`000003ooooool0003o000000?ooooo0_l00030ooooo`007_ooool2
o`0000Cooooo0_l0000Eooooo`;o00001Oooool3o`0000?ooooo0_l00005ooooo`Ko00002?ooool2
o`0000;ooooo0_l000000ooooooo0000o`000004o`0000;ooooo0ol000000ooooooo0000o`000004
ooooo`Ko00002Oooool2o`0000?ooooo0_l00005ooooo`;o00002oooool2o`000003ooooool0003o
000000?ooooo0_l000000ooooooo0000o`000003ooooo`;o0000J?ooool2o`0004kooooo000Noooo
o`03o`000?oooooooooo01Wooooo0_l00006ooooo`;o00000oooool2o`0000Kooooo1?l0000<oooo
o`Co000000Goooooo`000?l0003o0000ooooo`07o`000004ooooool0003o0000ooooo`;o00000_oo
ool5o`0000kooooo1_l000000ooooooo0000o`00000<ooooo`;o00002?ooool2o`0000?ooooo0_l0
001Xooooo`;o0000C_ooool001kooooo00?o0000ooooooooool06Oooool2o`0000Oooooo0_l00002
ooooo`;o00001_ooool4o`0000Gooooo0_l00005ooooo`?o000000?oooooo`000?l000000_l00002
ooooo`Go000000?oooooo`000?l000001Ol000001?oooooo0000o`000?ooool2o`0000Kooooo0_l0
0008ooooo`Co00003oooool2o`0003;ooooo0_l0002Cooooo`007_ooool00ol0003oooooooooo`07
ooooo`;o00006?ooool3o`0000_ooooo0_l00006ooooo`;o00001?ooool:o`000003ooooool0003o
000000?o000000?oooooo`000?l000000_l000000ooooooo0000o`000004ooooo`;o00001_ooool2
o`0004oooooo0_l0002Cooooo`007_ooool00ol0003oooooooooo`07ooooo`;o00001_ooool4o`00
00;ooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000;ooooo0_l0000<oooo
o`;o00001?ooool2o`0000Gooooo0ol000000ooooooo0000o`00000:o`0000;ooooo0_l0000=oooo
o`;o00004?ooool2o`0001;ooooo0_l0000Fooooo`;o0000Z_ooool001kooooo00?o0000oooooooo
ool03oooool4o`0000;ooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000[o
oooo0ol00003ooooo`;o00001?ooool2o`000003ooooool0003o000000;ooooo1?l000000ooooooo
0000o`00000?o`000003ooooool0003o000000Go000000?oooooo`000?l000000_l000000ooooooo
0000o`00000=ooooo`;o00004_ooool2o`0001Kooooo0_l00005ooooo`;o0000B_ooool2o`0004Ko
oooo0_l0000?ooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o00003oooool3o`0000[ooooo
1?l00006ooooo`;o00000_ooool4o`0000?ooooo0ol000000ooooooo0000o`000004o`000003oooo
ool0003o000000Co00000_ooool2o`000003ooooool0003o000000Wo00000_ooool2o`0000?ooooo
0_l0000Jooooo`;o00001oooool2o`0001Kooooo0_l0001:ooooo`;o0000A_ooool2o`0000oooooo
000Nooooo`03o`000?oooooooooo00[ooooo0_l0000?ooooo`?o00002_ooool3o`0000Oooooo0_l0
0002ooooo`;o00001oooool2o`000005ooooool0003o0000o`000?ooool01Ol000000ooooooo0000
o`000006ooooo`?o00000oooool8o`000003ooooool0003o000000;o00004oooool2o`0000Gooooo
0_l00007ooooo`;o00005oooool2o`0009cooooo0_l00004ooooo`007_ooool00ol0003ooooooooo
o`0Dooooo`;o00001Oooool2o`0000Cooooo0_l00006ooooo`?o00000oooool2o`0000Oooooo0_l0
0005ooooo`Go00000_ooool4o`0000;ooooo0_l00005ooooo`;o00002?ooool5o`000003ooooool0
003o000000Wooooo0_l0000:ooooo`;o00009oooool2o`0007kooooo0_l0000Looooo`;o00001?oo
ool001kooooo00?o0000ooooooooool01_ooool2o`0000cooooo0_l00005ooooo`Co00000_ooool2
o`0000Kooooo0ol00002ooooo`?o00000oooool2o`0000;ooooo1?l00003ooooo`?o00001?ooool4
o`0000Kooooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool3o`000003ooooool0003o
000000;o00002_ooool2o`0001Wooooo0_l0000booooo`;o0000Hoooool3o`0000Wooooo0_l0000G
ooooo`007_ooool00ol0003oooooooooo`06ooooo`;o00000_ooool2o`0000Sooooo0_l00007oooo
o`;o00001Oooool2o`0000Sooooo0_l00004ooooo`;o00000oooool3o`0000?ooooo1Ol00002oooo
o`;o00000oooool2o`0000?ooooo2Ol00003ooooo`?o000000?oooooo`000?l000000_l0000:oooo
o`;o00006Oooool2o`0003;ooooo0_l0001:ooooo`;o00005oooool2o`0000[ooooo0_l00006oooo
o`;o00003oooool001kooooo00?o0000ooooooooool02_ooool2o`0000Cooooo0_l0000Booooo`;o
00000_ooool2o`0001;ooooo0_l00004ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`Wo
00001?ooool2o`0000?ooooo0_l0000Gooooo`;o00002_ooool2o`0000?ooooo1?l0001iooooo`;o
0000:oooool2o`0000oooooo000Nooooo`03o`000?oooooooooo013ooooo0_l0000Fooooo`;o0000
00?oooooo`000?l000001?ooool2o`0000Wooooo0_l00009ooooo`Co00000_ooool5o`0000;ooooo
1ol0000Cooooo`;o00002_ooool5o`0000Sooooo0_l00003ooooo`Co00001?ooool2o`000;7ooooo
000Nooooo`03o`000?oooooooooo01_ooooo0_l0000;ooooo`;o000000?oooooo`000?l000001?oo
ool2o`0001Kooooo1ol00003ooooo`Co00000_ooool5o`0000Kooooo0_l00008ooooo`;o00002_oo
ool2o`000003ooooool0003o000001Gooooo0_l00009ooooo`;o00005oooool2o`0007Oooooo0_l0
000Dooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o00001_ooool2o`0000kooooo0_l00003
ooooo`;o00001?ooool2o`0000Cooooo0_l0000=ooooo`;o00001_ooool2o`000003ooooool0003o
000000;ooooo1?l00006ooooo`;o00005?ooool2o`0002?ooooo0_l0000Gooooo`;o0000Moooool2
o`0001Cooooo000Nooooo`03o`000?oooooooooo01?ooooo0_l00009ooooo`;o00002oooool2o`00
00?ooooo0ol00003ooooo`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00004?ooool2
o`000003ooooool0003o000000cooooo0_l00003ooooo`;o00003oooool2o`000<_ooooo000Noooo
o`;o00005?ooool2o`0000Wooooo0_l0000Aooooo`;o00000oooool2o`000004ooooool0003o0000
ooooo`;o00000oooool2o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`0000Sooooo0_l00005
ooooo`;o00000oooool2o`0000?ooooo0_l0000Eooooo`;o0000`?ooool001kooooo00?o0000oooo
ooooool04oooool2o`0001Oooooo0_l00008ooooo`;o00001?ooool2o`0000Wooooo0_l00004oooo
o`;o00003_ooool2o`0000;ooooo0_l0000;ooooo`;o00005Oooool2o`000<3ooooo000Nooooo`03
o`000?oooooooooo02cooooo0_l00002ooooo`;o00001oooool2o`0000Cooooo0_l00009ooooo`Co
00003oooool2o`0000;ooooo0_l00009ooooo`;o00006oooool2o`0009;ooooo0_l0000Xooooo`00
7_ooool00ol0003oooooooooo`03ooooo`;o00005Oooool2o`0001Cooooo0_l00003ooooo`;o0000
0_ooool2o`0000Cooooo0ol00007ooooo`Go00001?ooool3o`0000;ooooo0_l0000@ooooo`;o0000
00Coooooo`000?l0003ooooo0_l00006ooooo`;o00004?ooool2o`0000[ooooo0_l0001>ooooo`;o
0000=_ooool2o`0002Sooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0000Eooooo`;o0000
3_ooool2o`0000Wooooo0ol00008ooooo`;o00000_ooool2o`000003ooooool0003o000000;o0000
1oooool3o`0000;ooooo0_l0000@ooooo`;o00001?ooool2o`0000Gooooo0ol0000Looooo`;o0000
C_ooool2o`00063ooooo000Nooooo`03o`000?oooooooooo01cooooo0_l0000<ooooo`;o00001?oo
ool2o`0000?ooooo1?l0000;ooooo`;o000000Coooooo`000?l0003o00002_ooool2o`0000;ooooo
0_l0000Looooo`;o00005_ooool2o`000;Oooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l0
0004ooooo`Co000000?oooooo`000?l000000_l0000;ooooo`;o00001Oooool2o`0001Oooooo1_l0
00001?oooooo0000o`000?l0000=ooooo`;o00001oooool2o`0001cooooo0_l0000Hooooo`;o0000
7_ooool2o`0007gooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l00006ooooo`;o000000?o
ooooo`000?l000000_l0000:ooooo`;o00002?ooool5o`0000Cooooo1?l00003ooooo`;o00001Ooo
ool5o`0000;ooooo0_l0000=ooooo`?o00001oooool2o`0000Sooooo0_l0000Aooooo`?o00006?oo
ool2o`0001kooooo0_l0001mooooo`007_ooool00ol0003oooooooooo`0Tooooo`;o00002Oooool2
o`0000Sooooo1Ol00004ooooo`Co00000oooool3o`0000?ooooo0_l00005ooooo`;o000000?ooooo
o`000?l000001Oooool2o`0000Cooooo0ol0000@ooooo`Co00004?ooool2o`0002cooooo0_l0000R
ooooo`;o0000??ooool2o`0002Sooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l0000?oooo
o`;o00000oooool3o`000003ooooool0003o000000Oooooo0_l000000ooooooo0000o`000002o`00
0003ooooool0003o000000Cooooo0ol000000ooooooo0000o`000005ooooo`;o00000oooool3o`00
017ooooo1?l0000Oooooo`;o00007Oooool2o`0002;ooooo0_l0000looooo`;o0000:?ooool001ko
oooo00?o0000ooooooooool0<oooool4o`0000?ooooo0_l00002ooooo`Co00001Oooool2o`0000?o
oooo0_l00007ooooo`;o00001?ooool4o`000003ooooool0003o000000?ooooo0_l0000<ooooo`;o
00009oooool2o`000:Wooooo000Nooooo`03o`000?oooooooooo01kooooo0_l0000Cooooo`;o0000
2oooool2o`0001Wooooo1?l0000Dooooo`Co00003?ooool2o`0004Cooooo0_l00004ooooo`;o0000
@Oooool2o`0003?ooooo000Nooooo`03o`000?oooooooooo01[ooooo0_l00002ooooo`Co00005_oo
ool2o`0000kooooo0ol00005ooooo`;o00004?ooool2o`00017ooooo0_l0000<ooooo`Co00002Ooo
ool2o`0002Wooooo0_l0000<ooooo`;o00001?ooool2o`00047ooooo0_l0000cooooo`007_ooool0
0ol0003oooooooooo`0Jooooo`;o00001?ooool2o`0001Kooooo0_l0000>ooooo`?o000000?ooooo
o`000?l000000_ooool4o`0000kooooo0_l0000Nooooo`;o000000?oooooo`000?l000002Oooool2
o`0002Wooooo0_l0000]ooooo`;o0000Foooool001kooooo00?o0000ooooooooool0BOooool2o`00
0003ooooool0003o000000Cooooo0_l0000Cooooo`?o00001?ooool2o`0000gooooo0_l00003oooo
o`;o0000I_ooool2o`0001gooooo0_l0000looooo`007_ooool00ol0003oooooooooo`0?ooooo`;o
0000>?ooool2o`0001cooooo0ol00004ooooo`;o00002Oooool2o`0000;ooooo0_l0001kooooo`;o
00003Oooool2o`0001gooooo0_l0000Mooooo`007_ooool2o`00013ooooo0_l0001Cooooo`;o0000
3Oooool2o`0000Cooooo0_l00018ooooo`;o0000=Oooool2o`0002cooooo0_l0000Mooooo`007_oo
ool00ol0003oooooooooo`0Nooooo`;o0000=oooool2o`0000_ooooo0_l0000;ooooo`Co00003?oo
ool2o`00043ooooo0_l00022ooooo`007_ooool00ol0003oooooooooo`0Nooooo`;o00006Oooool2
o`0001cooooo0_l0000Aooooo`;o00001Oooool2o`0000kooooo0_l00034ooooo`007_ooool00ol0
003oooooooooo`0iooooo`;o00008Oooool2o`0000cooooo0_l0000?ooooo`;o00001_ooool2o`00
0<;ooooo000Nooooo`03o`000?oooooooooo04Cooooo0_l00005ooooo`;o00003oooool2o`0001?o
oooo0_l00008ooooo`;o00001_ooool2o`000<;ooooo000Nooooo`03o`000?oooooooooo04?ooooo
0ol00005ooooo`;o00009?ooool4o`0000[ooooo0_l00036ooooo`007_ooool00ol0003ooooooooo
o`0kooooo`;o00001_ooool2o`0000Sooooo0_l00005ooooo`?o00001oooool2o`00017ooooo1?l0
000:ooooo`;o00002oooool2o`000;Wooooo000Nooooo`03o`000?oooooooooo03_ooooo0_l0000@
ooooo`;o00001Oooool3o`0000Oooooo0_l00002ooooo`;o00003_ooool3o`0000Gooooo0_l0000@
ooooo`;o0000[_ooool2o`0000Wooooo000Nooooo`03o`000?oooooooooo00oooooo0_l00013oooo
o`;o00003?ooool2o`000003ooooool0003o000000Oooooo0_l00002ooooo`?o00001Oooool2o`00
00Sooooo0_l0002fooooo`;o00002Oooool001kooooo00?o0000ooooooooool03oooool2o`0001So
oooo0_l0000Jooooo`;o00002Oooool2o`0000Cooooo1?l0000;ooooo`;o00001oooool4o`0001;o
oooo0_l00031ooooo`007_ooool00ol0003oooooooooo`02ooooo`;o00009Oooool3o`0001Wooooo
0_l00009ooooo`;o00001?ooool4o`0000Oooooo0_l0000=ooooo`?o0000e?ooool001kooooo00?o
0000ooooooooool00_ooool2o`0001kooooo0_l00006ooooo`;o00005_ooool2o`0000Cooooo0_l0
000Booooo`?o00000_ooool2o`0000Wooooo0_l00003ooooo`;o00009_ooool2o`0006?ooooo0_l0
000booooo`;o00004oooool001kooooo00?o0000ooooooooool04_ooool2o`0000kooooo0_l0000N
ooooo`;o00001?ooool2o`0001;ooooo0ol0000=ooooo`;o00001Oooool2o`0002Cooooo0_l0000S
ooooo`;o0000?_ooool2o`0001Oooooo0_l0000Iooooo`;o00004oooool001kooooo00?o0000oooo
ooooool04_ooool2o`00017ooooo0_l0000@ooooo`;o00002oooool2o`00013ooooo0_l0000Koooo
o`;o00005?ooool2o`0003?ooooo0_l0000?ooooo`;o0000A_ooool2o`0002kooooo000Dooooo`Co
000000?o410@ooooooooool00oooool00ol0003oooooooooo`0Tooooo`?o00004?ooool2o`0000_o
oooo0_l00009ooooo`;o00001Oooool2o`00037ooooo0_l00014ooooo`;o00005_ooool2o`0005ko
oooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09?ooool3o`0000gooooo
0_l0000Iooooo`Co00006?ooool2o`00023ooooo0_l0001Hooooo`;o0000G_ooool001Kooooo00?o
0000ooooooooool01Oooool3o`0003Cooooo0_l0000Kooooo`;o00006?ooool2o`00023ooooo0_l0
001Vooooo`;o00004_ooool2o`0003cooooo000Fooooo`03o`000?oooooooooo0?gooooo0_l0000B
ooooo`;o0000??ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003o
ooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Cooooo00?o
EEEEofIVI_l00000oooooomBooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.35102 .99287 Mdot
.25752 .04538 Mdot
.13311 .80339 Mdot
.2318 .91109 Mdot
.24409 .93587 Mdot
.23427 .8616 Mdot
.0744 .00461 Mdot
.31696 .88986 Mdot
.23931 .91697 Mdot
.18736 .89725 Mdot
.14659 .97954 Mdot
.16051 .81925 Mdot
.16832 .82738 Mdot
.87823 .80499 Mdot
.23478 .86744 Mdot
.387 .39921 Mdot
.40626 .22943 Mdot
.06897 .84833 Mdot
.33184 .9842 Mdot
.28573 .96868 Mdot
.56952 .6667 Mdot
.2013 .9109 Mdot
.16799 .74266 Mdot
.22726 .58242 Mdot
.33294 .93074 Mdot
.33991 .87627 Mdot
.21162 .8489 Mdot
.16888 .17596 Mdot
.09446 .92939 Mdot
.16052 .84885 Mdot
.10514 .85288 Mdot
.23939 .87468 Mdot
.39319 .84541 Mdot
.5233 .03614 Mdot
.33514 .83183 Mdot
.26162 .01291 Mdot
.48147 .95542 Mdot
.70932 .70997 Mdot
.18825 .76964 Mdot
.2799 .86115 Mdot
.13284 .84904 Mdot
.34325 .84117 Mdot
.16599 .76296 Mdot
.5421 .83949 Mdot
.05484 .48647 Mdot
.40874 .88751 Mdot
.38171 .03865 Mdot
.23063 .13131 Mdot
.33332 .96134 Mdot
.50355 .03096 Mdot
.38087 .81406 Mdot
.22116 .09229 Mdot
.23081 .86898 Mdot
.13266 .86243 Mdot
.13541 .82256 Mdot
.61709 .58604 Mdot
.89204 .91085 Mdot
.22205 .86338 Mdot
.21039 .84946 Mdot
.97044 .89949 Mdot
.22091 .81229 Mdot
.32279 .90428 Mdot
.00414 .75148 Mdot
.35008 .95623 Mdot
.22303 .91047 Mdot
.1853 .93124 Mdot
.26782 .11373 Mdot
.21313 .84825 Mdot
.21964 .87287 Mdot
.68759 .95049 Mdot
.70988 .69666 Mdot
.04022 .78752 Mdot
.94917 .93282 Mdot
.24132 .11457 Mdot
.21358 .99507 Mdot
.90493 .96394 Mdot
.27189 .7705 Mdot
.71873 .92177 Mdot
.21447 .86548 Mdot
.07918 .75611 Mdot
.31989 .07768 Mdot
.66212 .01039 Mdot
.25154 .01092 Mdot
.31473 .89938 Mdot
.55735 .83109 Mdot
.06949 .45299 Mdot
.31753 .90423 Mdot
.26016 .83088 Mdot
.23297 .87066 Mdot
.98392 .82274 Mdot
.29347 .9616 Mdot
.31498 .53844 Mdot
.05174 .80517 Mdot
.58901 .63962 Mdot
.36256 .88422 Mdot
.20179 .04466 Mdot
.15625 .29096 Mdot
.3221 .78655 Mdot
.2057 .89643 Mdot
.10815 .25312 Mdot
.26764 .8911 Mdot
.44116 .81651 Mdot
.25754 .84781 Mdot
.36903 .13209 Mdot
.3043 .14442 Mdot
.16148 .75946 Mdot
.35368 .78117 Mdot
.33878 .70021 Mdot
.14584 .09928 Mdot
.51823 .99536 Mdot
.47927 .96689 Mdot
.89693 .3545 Mdot
.29034 .06195 Mdot
.07564 .86616 Mdot
.21374 .63447 Mdot
.0882 .38486 Mdot
.18406 .65307 Mdot
.15551 .80914 Mdot
.57376 .96963 Mdot
.16098 .06094 Mdot
.25853 .84084 Mdot
.21554 .15612 Mdot
.24827 .84957 Mdot
.4963 .79592 Mdot
.02074 .14285 Mdot
.27657 .44955 Mdot
.31997 .87767 Mdot
.34329 .97299 Mdot
.63953 .77084 Mdot
.1212 .14888 Mdot
.38834 .7041 Mdot
.75619 .17265 Mdot
.26949 .07185 Mdot
.14314 .79672 Mdot
.12313 .86115 Mdot
.12208 .8557 Mdot
.14876 .76131 Mdot
.28844 .86518 Mdot
.12724 .91228 Mdot
.18904 .9049 Mdot
.26408 .93135 Mdot
.35019 .959 Mdot
.30596 .87712 Mdot
.18077 .01497 Mdot
.39171 .9354 Mdot
.15879 .84992 Mdot
.42892 .85259 Mdot
.24602 .85675 Mdot
.7613 .07119 Mdot
.4097 .20218 Mdot
.29452 .86338 Mdot
.35514 .8192 Mdot
.18242 .82643 Mdot
.30193 .96853 Mdot
.22931 .86657 Mdot
.21226 .84736 Mdot
.14452 .74827 Mdot
.9014 .36715 Mdot
.22691 .88878 Mdot
.34769 .39162 Mdot
.31563 .88317 Mdot
.33314 .59791 Mdot
.47747 .53498 Mdot
.19819 .74821 Mdot
.24434 .92716 Mdot
.20372 .89867 Mdot
.26269 .8463 Mdot
.20967 .84623 Mdot
.91018 .45045 Mdot
.14354 .84559 Mdot
.3271 .79379 Mdot
.21599 .88136 Mdot
.36879 .75998 Mdot
.71508 .56083 Mdot
.38368 .97481 Mdot
.19726 .68946 Mdot
.15644 .6097 Mdot
.3052 .8554 Mdot
.00994 .40568 Mdot
.23028 .07788 Mdot
.159 .70792 Mdot
.09552 .97608 Mdot
.2653 .01165 Mdot
.01005 .51176 Mdot
.33452 .20723 Mdot
.41939 .8506 Mdot
.22255 .796 Mdot
.2616 .90919 Mdot
.1113 .67497 Mdot
.17649 .61407 Mdot
.38455 .98649 Mdot
.57898 .51062 Mdot
.3394 .97162 Mdot
.37647 .04647 Mdot
.11313 .90063 Mdot
.15104 .7216 Mdot
.3175 .59051 Mdot
.10195 .00285 Mdot
.25931 .92683 Mdot
.30582 .87652 Mdot
.35213 .07573 Mdot
.67482 .61803 Mdot
.13467 .81722 Mdot
.22284 .59397 Mdot
.33648 .93515 Mdot
.26093 .83654 Mdot
.62636 .41766 Mdot
.23133 .82278 Mdot
.96391 .79768 Mdot
.19627 .65916 Mdot
.1628 .89416 Mdot
.34359 .93089 Mdot
.36456 .12863 Mdot
.39743 .38643 Mdot
.27756 .85972 Mdot
.31196 .40331 Mdot
.27055 .84486 Mdot
.97851 .68962 Mdot
.27527 .1553 Mdot
.21561 .6255 Mdot
.87409 .92645 Mdot
.13922 .89892 Mdot
.32622 .95275 Mdot
.20469 .84648 Mdot
.98113 .81832 Mdot
.09743 .74278 Mdot
.96416 .05181 Mdot
.15762 .76341 Mdot
.16821 .95132 Mdot
.24252 .9149 Mdot
.29488 .8799 Mdot
.98249 .89166 Mdot
.3253 .8395 Mdot
.26347 .10125 Mdot
.41343 .52718 Mdot
.65621 .72762 Mdot
.82782 .2039 Mdot
.11221 .81646 Mdot
.41129 .06399 Mdot
.72284 .91616 Mdot
.09981 .93419 Mdot
.306 .85343 Mdot
.34113 .10446 Mdot
.27245 .74102 Mdot
.25965 .89652 Mdot
.23119 .03433 Mdot
.05916 .86223 Mdot
.27379 .8311 Mdot
.84542 .12282 Mdot
.14295 .82213 Mdot
.18368 .09865 Mdot
.12657 .81433 Mdot
.12652 .18665 Mdot
.20495 .39148 Mdot
.94366 .63775 Mdot
.20535 .15849 Mdot
.23281 .88076 Mdot
.84956 .84108 Mdot
.29577 .10625 Mdot
.67813 .74013 Mdot
.34373 .95323 Mdot
.11475 .90824 Mdot
.21033 .64548 Mdot
.01332 .85928 Mdot
.31447 .85279 Mdot
.91944 .21633 Mdot
.44107 .88666 Mdot
.49069 .85313 Mdot
.1346 .80308 Mdot
.24334 .85103 Mdot
.22394 .90767 Mdot
.59558 .07907 Mdot
.20117 .81674 Mdot
.11935 .89018 Mdot
.33798 .02033 Mdot
.12724 .80894 Mdot
.34343 .09168 Mdot
.8351 .03235 Mdot
.21208 .97936 Mdot
.43916 .85977 Mdot
.7179 .01186 Mdot
.2171 .89519 Mdot
.24657 .7525 Mdot
.41407 .81136 Mdot
.22518 .90363 Mdot
.33359 .95525 Mdot
.12023 .85222 Mdot
.11234 .29451 Mdot
.21011 .04563 Mdot
.31451 .83868 Mdot
.33399 .07334 Mdot
.35576 .95163 Mdot
.29417 .95389 Mdot
.02538 .8875 Mdot
.39106 .73704 Mdot
.08001 .09901 Mdot
.25285 .86059 Mdot
.15247 .14656 Mdot
.80898 .90505 Mdot
.0557 .87526 Mdot
.31687 .22854 Mdot
.19404 .81468 Mdot
.33051 .6078 Mdot
.01371 .75508 Mdot
.57407 .45099 Mdot
.14505 .96405 Mdot
.20832 .85017 Mdot
.21629 .85526 Mdot
.37425 .38818 Mdot
.54827 .62617 Mdot
.23712 .82881 Mdot
.70127 .59646 Mdot
.33768 .87925 Mdot
.11941 .7813 Mdot
.31927 .96967 Mdot
.31293 .72115 Mdot
.35778 .66169 Mdot
.22106 .93509 Mdot
.33512 .85452 Mdot
.02184 .55187 Mdot
.17189 .76635 Mdot
.36947 .82386 Mdot
.47474 .87927 Mdot
.2261 .72529 Mdot
.08249 .86724 Mdot
.27401 .8714 Mdot
.22643 .98809 Mdot
.36352 .9213 Mdot
.10666 .80791 Mdot
.30945 .89761 Mdot
.32194 .00284 Mdot
.21682 .87886 Mdot
.00611 .17856 Mdot
.08369 .86718 Mdot
.34856 .20212 Mdot
.32347 .4312 Mdot
.82199 .57867 Mdot
.23031 .84879 Mdot
.36338 .42554 Mdot
.73401 .70436 Mdot
.272 .93636 Mdot
.42856 .19809 Mdot
.29706 .91023 Mdot
.00984 .79026 Mdot
.42993 .89734 Mdot
.1052 .91834 Mdot
.50708 .76247 Mdot
.10133 .44565 Mdot
.38322 .99526 Mdot
.31613 .88679 Mdot
.1528 .80194 Mdot
.17118 .85163 Mdot
.17945 .62488 Mdot
.36674 .54135 Mdot
.32224 .10142 Mdot
.21436 .81077 Mdot
.37039 .99857 Mdot
.24896 .77756 Mdot
.16308 .84789 Mdot
.8851 .91867 Mdot
.24632 .87232 Mdot
.41001 .85267 Mdot
.11724 .85945 Mdot
.14914 .86701 Mdot
.29702 .93088 Mdot
.21901 .10043 Mdot
.51828 .74333 Mdot
.25186 .33568 Mdot
.08261 .05941 Mdot
.16393 .87664 Mdot
.42788 .00232 Mdot
.20885 .8484 Mdot
.13965 .79089 Mdot
.20395 .93214 Mdot
.70905 .9327 Mdot
.46741 .68495 Mdot
.08969 .52639 Mdot
.32217 .94759 Mdot
.02247 .53577 Mdot
.21296 .82749 Mdot
.21931 .86376 Mdot
.30839 .0148 Mdot
.64639 .13098 Mdot
.35972 .30873 Mdot
.23802 .04242 Mdot
.33479 .10478 Mdot
.3465 .03831 Mdot
.45027 .36064 Mdot
.22293 .84914 Mdot
.09811 .75057 Mdot
.2669 .93024 Mdot
.12947 .90459 Mdot
.29337 .85299 Mdot
.25167 .91842 Mdot
.25695 .93419 Mdot
.29521 .71392 Mdot
.45347 .12413 Mdot
.45622 .87375 Mdot
.21221 .84611 Mdot
.09535 .8719 Mdot
.14694 .87389 Mdot
.10107 .57033 Mdot
.92477 .30471 Mdot
.31853 .90538 Mdot
.44391 .85491 Mdot
.09775 .63826 Mdot
.41135 .91766 Mdot
.00676 .80631 Mdot
.08772 .71675 Mdot
.19435 .74689 Mdot
.4256 .95789 Mdot
.24986 .88523 Mdot
.30268 .87624 Mdot
.41987 .20103 Mdot
.89417 .73771 Mdot
.09781 .84075 Mdot
.12338 .0508 Mdot
.1261 .74997 Mdot
.00682 .76582 Mdot
.2139 .86673 Mdot
.23426 .84711 Mdot
.33803 .18154 Mdot
.48774 .87122 Mdot
.11912 .88784 Mdot
.26891 .87458 Mdot
.34143 .95839 Mdot
.8663 .04126 Mdot
.22788 .92792 Mdot
.01231 .80865 Mdot
.70442 .67373 Mdot
.51929 .58718 Mdot
.25292 .84456 Mdot
.00074 .2358 Mdot
.30767 .00711 Mdot
.38778 .82675 Mdot
.01448 .035 Mdot
.3033 .99588 Mdot
.08802 .37897 Mdot
.29312 .74731 Mdot
.08874 .49669 Mdot
.42479 .90754 Mdot
.57007 .09261 Mdot
.96886 .36578 Mdot
.22529 .8104 Mdot
.00811 .71855 Mdot
.23675 .819 Mdot
.36781 .84452 Mdot
.1776 .93128 Mdot
.03478 .95811 Mdot
.18283 .97866 Mdot
.14538 .12995 Mdot
.16472 .09442 Mdot
.30088 .94991 Mdot
.2136 .85384 Mdot
.34378 .76703 Mdot
.22768 .8333 Mdot
.29451 .92 Mdot
.20428 .97589 Mdot
.59594 .7159 Mdot
.26036 .92134 Mdot
.1608 .97603 Mdot
.24187 .81656 Mdot
.22403 .8569 Mdot
.1975 .84532 Mdot
.37542 .00342 Mdot
.34394 .62469 Mdot
.38386 .83688 Mdot
.86172 .44243 Mdot
.22701 .8288 Mdot
.32739 .06895 Mdot
.16207 .87232 Mdot
.33189 .8991 Mdot
.31852 .89524 Mdot
.31645 .89705 Mdot
.10026 .9297 Mdot
.23578 .87337 Mdot
.07137 .8956 Mdot
.28507 .88536 Mdot
.34966 .05496 Mdot
.05416 .85648 Mdot
.67999 .66614 Mdot
.34332 .92518 Mdot
.27058 .88132 Mdot
.23695 .91271 Mdot
.35924 .98425 Mdot
.90712 .16452 Mdot
.18279 .33882 Mdot
.16487 .42303 Mdot
.16124 .77974 Mdot
.18105 .13411 Mdot
.13452 .79579 Mdot
.21714 .85493 Mdot
.00036 .59668 Mdot
.3274 .97748 Mdot
.34702 .97501 Mdot
.09773 .99558 Mdot
.32293 .81238 Mdot
.31581 .89412 Mdot
.60573 .82605 Mdot
.30058 .62079 Mdot
.19167 .85998 Mdot
.25322 .16167 Mdot
.15122 .82091 Mdot
.34765 .88689 Mdot
.0814 .84335 Mdot
.11111 .73695 Mdot
.33249 .89801 Mdot
.91048 .22118 Mdot
.28541 .9086 Mdot
.1784 .8566 Mdot
.15085 .88753 Mdot
.77758 .57208 Mdot
.28291 .87212 Mdot
.22044 .17248 Mdot
.26122 .92384 Mdot
.90647 .81561 Mdot
.21647 .698 Mdot
.2697 .77679 Mdot
.2633 .44194 Mdot
.09866 .8848 Mdot
.26338 .79464 Mdot
.11992 .89356 Mdot
.21634 .86377 Mdot
.27586 .8554 Mdot
.22234 .2391 Mdot
.66035 .92597 Mdot
.18408 .79276 Mdot
.73569 .95025 Mdot
.11026 .75646 Mdot
.37167 .64226 Mdot
.87857 .80342 Mdot
.80922 .63952 Mdot
.23431 .9155 Mdot
.25336 .75346 Mdot
.3089 .90039 Mdot
.24996 .89388 Mdot
.21802 .92579 Mdot
.36843 .9318 Mdot
.21475 .15158 Mdot
.5346 .77146 Mdot
.19018 .90364 Mdot
.42892 .51671 Mdot
.13228 .94047 Mdot
.22954 .87223 Mdot
.14063 .86487 Mdot
.17424 .29283 Mdot
.29836 .55472 Mdot
.26092 .8732 Mdot
.20338 .73504 Mdot
.27145 .87706 Mdot
.54769 .74606 Mdot
.05805 .76797 Mdot
.39093 .8798 Mdot
.56895 .05532 Mdot
.33684 .12623 Mdot
.64432 .26199 Mdot
.10042 .46654 Mdot
.24109 .84819 Mdot
.26369 .01891 Mdot
.46847 .71478 Mdot
.18618 .74648 Mdot
.24285 .88051 Mdot
.8178 .80422 Mdot
.05966 .19152 Mdot
.11014 .85258 Mdot
.28559 .98467 Mdot
.3766 .93118 Mdot
.30798 .94996 Mdot
.67874 .39179 Mdot
.23442 .86987 Mdot
.08212 .00043 Mdot
.31028 .17601 Mdot
.23998 .87166 Mdot
.39424 .87633 Mdot
.12056 .89093 Mdot
.28775 .91489 Mdot
.95091 .56969 Mdot
.09167 .93327 Mdot
.11826 .80078 Mdot
.05894 .9432 Mdot
.98416 .38253 Mdot
.47829 .13793 Mdot
.10831 .96297 Mdot
.20588 .91696 Mdot
.84134 .82645 Mdot
.29781 .92824 Mdot
.43255 .85661 Mdot
.12519 .19143 Mdot
.17114 .16746 Mdot
.3683 .87149 Mdot
.27294 .87804 Mdot
.13821 .84959 Mdot
.03079 .76443 Mdot
.3366 .8606 Mdot
.256 .84714 Mdot
.33085 .88723 Mdot
.2622 .68725 Mdot
.2829 .89016 Mdot
.29793 .97091 Mdot
.28008 .06202 Mdot
.32685 .87955 Mdot
.21516 .84425 Mdot
.13611 .78593 Mdot
.33326 .70361 Mdot
.12653 .91556 Mdot
.22407 .7524 Mdot
.2444 .84437 Mdot
.19606 .88095 Mdot
.25023 .02038 Mdot
.34703 .97677 Mdot
.21319 .58177 Mdot
.40527 .46551 Mdot
.17295 .86081 Mdot
.64916 .65062 Mdot
.33747 .98903 Mdot
.28144 .25588 Mdot
.03102 .79753 Mdot
.43644 .94595 Mdot
.1674 .84632 Mdot
.29769 .92433 Mdot
.92304 .10905 Mdot
.0894 .95749 Mdot
.35706 .97981 Mdot
.45597 .24839 Mdot
.20871 .492 Mdot
.38769 .9937 Mdot
.59913 .4411 Mdot
.38658 .82972 Mdot
.10607 .77442 Mdot
.38577 .98142 Mdot
.1022 .93486 Mdot
.20281 .84971 Mdot
.17869 .89666 Mdot
.88957 .83668 Mdot
.24163 .86967 Mdot
.92287 .74936 Mdot
.31311 .89674 Mdot
.06449 .77426 Mdot
.19412 .93615 Mdot
.22773 .86372 Mdot
.29754 .94155 Mdot
.2362 .86587 Mdot
.36612 .00049 Mdot
.47195 .8601 Mdot
.01724 .24551 Mdot
.25826 .84852 Mdot
.39282 .79913 Mdot
.43537 .31519 Mdot
.30647 .90806 Mdot
.15067 .90676 Mdot
.36046 .68937 Mdot
.20977 .98073 Mdot
.07336 .04915 Mdot
.20813 .84743 Mdot
.0854 .89969 Mdot
.27732 .86612 Mdot
.18398 .86327 Mdot
.46775 .94358 Mdot
.69073 .79976 Mdot
.21829 .83965 Mdot
.06195 .56283 Mdot
.24606 .72744 Mdot
.6831 .07766 Mdot
.30948 .85724 Mdot
.85575 .72172 Mdot
.07144 .66168 Mdot
.21403 .86273 Mdot
.5216 .80172 Mdot
.11359 .23655 Mdot
.97936 .8786 Mdot
.64266 .96376 Mdot
.81645 .10744 Mdot
.43386 .05261 Mdot
.28995 .81035 Mdot
.7686 .3109 Mdot
.33071 .89689 Mdot
.99792 .43129 Mdot
.12114 .89452 Mdot
.72288 .97802 Mdot
.18208 .58253 Mdot
.12256 .1284 Mdot
.17185 .97542 Mdot
.88544 .30167 Mdot
.36611 .9863 Mdot
.23601 .86977 Mdot
.38235 .69346 Mdot
.47558 .81693 Mdot
.58317 .37435 Mdot
.02092 .83389 Mdot
.08852 .85695 Mdot
.16927 .12337 Mdot
.05736 .48306 Mdot
.10768 .68787 Mdot
.31769 .09485 Mdot
.36052 .83195 Mdot
.24997 .73814 Mdot
.21883 .85253 Mdot
.67677 .04931 Mdot
.37161 .55571 Mdot
.17717 .25621 Mdot
.04431 .6802 Mdot
.36377 .4961 Mdot
.19839 .8388 Mdot
.14514 .9166 Mdot
.33216 .05246 Mdot
.29109 .83392 Mdot
.79115 .44732 Mdot
.3786 .75601 Mdot
.40177 .33435 Mdot
.30637 .93404 Mdot
.80165 .10839 Mdot
.98448 .85051 Mdot
.12212 .55689 Mdot
.10899 .26317 Mdot
.15698 .75302 Mdot
.3861 .01161 Mdot
.26232 .85998 Mdot
.28167 .91024 Mdot
.48115 .34541 Mdot
.31676 .81685 Mdot
.36294 .91449 Mdot
.63023 .61681 Mdot
.22301 .78409 Mdot
.87599 .26434 Mdot
.46565 .35395 Mdot
.84626 .03967 Mdot
.25334 .86949 Mdot
.28313 .84801 Mdot
.89591 .90944 Mdot
.47224 .37384 Mdot
.3048 .81766 Mdot
.29445 .79145 Mdot
.20218 .82628 Mdot
.19961 .90117 Mdot
.66168 .68281 Mdot
.11991 .57811 Mdot
.0714 .48539 Mdot
.34301 .92531 Mdot
.28582 .7812 Mdot
.35024 .92826 Mdot
.25479 .96816 Mdot
.26233 .97693 Mdot
.36968 .94274 Mdot
.37724 .29943 Mdot
.78123 .97719 Mdot
.36719 .86361 Mdot
.21312 .82832 Mdot
.7971 .95658 Mdot
.17619 .87418 Mdot
.14353 .31116 Mdot
.31812 .03982 Mdot
.13653 .83027 Mdot
.99865 .98577 Mdot
.38326 .92165 Mdot
.20425 .82171 Mdot
.24063 .92812 Mdot
.12044 .88193 Mdot
.34715 .99683 Mdot
.08945 .88562 Mdot
.13092 .80719 Mdot
.77616 .91404 Mdot
.3203 .88998 Mdot
.82091 .45771 Mdot
.12462 .8517 Mdot
.43733 .03545 Mdot
.19515 .84421 Mdot
.16285 .32043 Mdot
.1689 .35475 Mdot
.10221 .00527 Mdot
.67599 .43028 Mdot
.35303 .95024 Mdot
.28621 .80047 Mdot
.18362 .7604 Mdot
.12683 .81476 Mdot
.42515 .26932 Mdot
.15663 .90266 Mdot
.16339 .77889 Mdot
.13206 .79618 Mdot
.30448 .78978 Mdot
.93336 .48171 Mdot
.23801 .92336 Mdot
.35143 .05131 Mdot
.62512 .37706 Mdot
.4569 .4888 Mdot
.27567 .86379 Mdot
.32228 .07785 Mdot
.37357 .54962 Mdot
.1903 .90129 Mdot
.21355 .85336 Mdot
.23502 .84698 Mdot
.49055 .85742 Mdot
.12202 .96945 Mdot
.56563 .03492 Mdot
.31968 .86136 Mdot
.3027 .63356 Mdot
.18232 .85714 Mdot
.21181 .14478 Mdot
.00516 .99043 Mdot
.28591 .02752 Mdot
.98672 .82841 Mdot
.39252 .41579 Mdot
.18249 .86183 Mdot
.10583 .9611 Mdot
.11075 .87974 Mdot
.96868 .88081 Mdot
.08623 .83496 Mdot
.01662 .6857 Mdot
.95362 .72765 Mdot
.12684 .01609 Mdot
.38564 .88462 Mdot
.14712 .17988 Mdot
.28395 .02479 Mdot
.13986 .86865 Mdot
.45116 .71639 Mdot
.25144 .89584 Mdot
.20917 .84877 Mdot
.12861 .983 Mdot
.52446 .89982 Mdot
.23441 .85523 Mdot
.35015 .42399 Mdot
.31214 .89725 Mdot
.28833 .89713 Mdot
.16447 .78612 Mdot
.21352 .84702 Mdot
.32763 .89592 Mdot
.44561 .06832 Mdot
.2595 .87615 Mdot
.20813 .89227 Mdot
.58403 .04136 Mdot
.23406 .06081 Mdot
.37205 .06351 Mdot
.13248 .24272 Mdot
.1147 .86547 Mdot
.4241 .43583 Mdot
.45012 .94785 Mdot
.18347 .74889 Mdot
.83085 .61597 Mdot
.33533 .95821 Mdot
.30591 .91362 Mdot
.98301 .99471 Mdot
.36159 .6465 Mdot
.28155 .89559 Mdot
.20831 .8509 Mdot
.20851 .91266 Mdot
.84944 .93465 Mdot
.14576 .85881 Mdot
.06659 .6225 Mdot
.15933 .79599 Mdot
.33059 .89195 Mdot
.13558 .83547 Mdot
.84247 .00164 Mdot
.96862 .83854 Mdot
.15288 .85072 Mdot
.30511 .92218 Mdot
.28639 .83995 Mdot
.95456 .53551 Mdot
.3168 .89237 Mdot
.25332 .42635 Mdot
.09507 .83666 Mdot
.20525 .83957 Mdot
.30068 .90478 Mdot
.21006 .84486 Mdot
.31567 .92731 Mdot
.84293 .10755 Mdot
.33997 .86986 Mdot
.14279 .00457 Mdot
.3645 .99747 Mdot
.31872 .97624 Mdot
.42133 .49231 Mdot
.25602 .87095 Mdot
.49266 .12274 Mdot
.26382 .82868 Mdot
.35529 .95195 Mdot
.20665 .0309 Mdot
.39485 .03526 Mdot
.30559 .91477 Mdot
.03263 .70326 Mdot
.43445 .81174 Mdot
.0914 .47407 Mdot
.20861 .8695 Mdot
.55807 .88222 Mdot
.17121 .82981 Mdot
.32116 .89276 Mdot
.17871 .92188 Mdot
.07031 .91118 Mdot
.36432 .99261 Mdot
.3467 .94425 Mdot
.05959 .69996 Mdot
.20963 .90609 Mdot
.54291 .9338 Mdot
.62408 .98974 Mdot
.77409 .98725 Mdot
.15565 .95339 Mdot
.23697 .88733 Mdot
.40411 .5452 Mdot
.29504 .84494 Mdot
.43972 .3796 Mdot
.21652 .83752 Mdot
.3089 .94524 Mdot
.18154 .78992 Mdot
.17793 .86986 Mdot
.46759 .88749 Mdot
.22806 .41314 Mdot
.32043 .74842 Mdot
.29982 .90782 Mdot
.89584 .83046 Mdot
.42692 .10067 Mdot
.17823 .81778 Mdot
.24741 .9225 Mdot
.29208 .89791 Mdot
.42429 .78075 Mdot
.57965 .71611 Mdot
.42755 .12863 Mdot
.3624 .92986 Mdot
.13328 .95154 Mdot
.31006 .77024 Mdot
.42592 .90154 Mdot
.27846 .03645 Mdot
.26012 .65854 Mdot
.21858 .91989 Mdot
.09677 .13791 Mdot
.95048 .75499 Mdot
.28823 .87983 Mdot
.30694 .90846 Mdot
.23447 .87158 Mdot
.137 .07825 Mdot
.18203 .90568 Mdot
.28817 .81141 Mdot
.69394 .88757 Mdot
.38017 .82452 Mdot
.29016 .85612 Mdot
.13677 .78456 Mdot
.27283 .88171 Mdot
.31641 .85056 Mdot
.40062 .33529 Mdot
.31242 .95012 Mdot
.89278 .50805 Mdot
.30127 .78896 Mdot
.21351 .86056 Mdot
.47148 .0693 Mdot
.22396 .85193 Mdot
.18434 .87301 Mdot
.33289 .92833 Mdot
.19008 .39135 Mdot
.10769 .91636 Mdot
.2395 .86005 Mdot
.27988 .89698 Mdot
.37013 .01601 Mdot
.19167 .89754 Mdot
.88933 .12732 Mdot
.19373 .85226 Mdot
.64462 .95133 Mdot
.29398 .07223 Mdot
.44282 .19736 Mdot
.05698 .76521 Mdot
.16209 .79295 Mdot
.1928 .77611 Mdot
.43289 .04833 Mdot
.13554 .89647 Mdot
.51084 .90185 Mdot
.1934 .89827 Mdot
.20766 .84914 Mdot
.23534 .85629 Mdot
.9996 .86504 Mdot
.28887 .89021 Mdot
.45762 .45983 Mdot
.18489 .81317 Mdot
.23171 .78889 Mdot
.96097 .72507 Mdot
.37156 .25432 Mdot
.28612 .82749 Mdot
.30027 .34397 Mdot
.22764 .5856 Mdot
.19969 .19634 Mdot
.66951 .95442 Mdot
.33002 .89788 Mdot
.13438 .15408 Mdot
.0341 .68629 Mdot
.20758 .85555 Mdot
.25208 .83795 Mdot
.24975 .90247 Mdot
.13609 .88742 Mdot
.70149 .19462 Mdot
.2061 .86371 Mdot
.22152 .82973 Mdot
.18348 .10684 Mdot
.99016 .94 Mdot
.9709 .10048 Mdot
.27314 .98884 Mdot
.22811 .85427 Mdot
.39927 .48937 Mdot
.24898 .9321 Mdot
.26275 .74894 Mdot
.72033 .73344 Mdot
.25644 .87634 Mdot
.29431 .8507 Mdot
.27905 .86525 Mdot
.28076 .74178 Mdot
.27481 .80832 Mdot
.22948 .85761 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  AnimationDisplayTime->0.169,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool01oooool2o`0000Cooooo0_l0000>ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Co
oooo0_l00007ooooo`03o`000?oooooooooo00;ooooo0_l000000ooooooo0000o`000007ooooo`03
o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool02_ooool2o`000003ooooool0003ooooo00kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo000Nooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool01?ooool2o`0000Oooooo0_l0000;ooooo`;o000000?oooooo`000?ooool0
3oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00Co0000ooooool0003o
00000oooool2o`0000Oooooo00?o0000ooooooooool01Oooool2o`0000Oooooo00?o0000oooooooo
ool01Oooool2o`0000Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0:ooooo`;o
000000?oooooo`000?ooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool00_ooool001kooooo00?o0000ooooooooool05?ooool2o`0000Oooooo
0_l0000;ooooo`;o0000=?ooool2o`00077ooooo0_l0001booooo`007_ooool00ol0003ooooooooo
o`1>ooooo`;o000000Coooooo`000?l0003o00009Oooool2o`0005Sooooo0_l0000@ooooo`;o0000
H?ooool001kooooo00?o0000ooooooooool09Oooool2o`00013ooooo0_l0000Eooooo`;o000000Co
ooooo`000?l0003o00003?ooool2o`0001;ooooo0_l00003ooooo`;o0000J_ooool2o`00063ooooo
000Nooooo`03o`000?oooooooooo02Gooooo0_l0000@ooooo`;o00006Oooool2o`0000cooooo0_l0
000Booooo`;o0000dOooool001kooooo00?o0000ooooooooool0COooool2o`0000?ooooo0_l0000F
ooooo`;o0000foooool001kooooo00?o0000ooooooooool0COooool2o`0000Wooooo0_l0000@oooo
o`;o0000foooool001kooooo00?o0000ooooooooool0F?ooool3o`000>cooooo000Nooooo`03o`00
0?oooooooooo03oooooo0_l0000Hooooo`;o0000AOooool2o`000:Gooooo000Nooooo`04o`000?oo
ooooooooooooo`;o0000??ooool2o`0000Kooooo0_l0000cooooo`;o00008_ooool2o`0001;ooooo
0_l0001Eooooo`;o0000>_ooool001kooooo00Co0000oooooooooooooooo0_l00014ooooo`;o0000
3Oooool2o`0001Gooooo0_l0000=ooooo`;o00003?ooool2o`0001[ooooo0_l0000<ooooo`;o0000
EOooool2o`0003[ooooo000Nooooo`03o`000?oooooooooo05Kooooo0_l0000;ooooo`;o00002?oo
ool2o`0000Wooooo0_l0000@ooooo`;o00006_ooool2o`0001;ooooo0_l0001Cooooo`;o00001Ooo
ool2o`0002oooooo000Nooooo`03o`000?oooooooooo04Wooooo0_l0000Hooooo`;o00004oooool2
o`00043ooooo0_l0001Cooooo`;o00001Oooool2o`0002oooooo000Nooooo`03o`000?oooooooooo
03gooooo0_l000000ooooooo0000o`000007ooooo`;o00001Oooool2o`0002Cooooo0_l0003?oooo
o`007_ooool00ol0003oooooooooo`0Dooooo`;o00009oooool2o`000003ooooool0003o000000ko
oooo0_l0000Tooooo`;o00004Oooool2o`0004gooooo0_l0001]ooooo`007_ooool2o`0001Gooooo
0_l0000>ooooo`;o0000@_ooool2o`0000Cooooo0_l0000Iooooo`;o0000COooool2o`0005_ooooo
0_l0000@ooooo`007_ooool00ol0003oooooooooo`0Tooooo`;o0000@_ooool2o`0000Cooooo0_l0
000Iooooo`;o0000:_ooool2o`0007kooooo0_l0000@ooooo`007_ooool00ol0003oooooooooo`0G
ooooo`;o0000EOooool2o`0004Gooooo0_l0002@ooooo`007_ooool00ol0003oooooooooo`0Goooo
o`;o00005oooool2o`0001Kooooo0_l0000=ooooo`;o000000?oooooo`000?l00000joooool001ko
oooo00?o0000ooooooooool0<?ooool2o`0001Kooooo0_l0000=ooooo`;o000000?oooooo`000?l0
00006Oooool2o`0000_ooooo0_l00033ooooo`007_ooool00ol0003oooooooooo`1Vooooo`;o0000
3Oooool2o`0000_ooooo0_l00009ooooo`;o0000^?ooool001kooooo00?o0000ooooooooool0Dooo
ool2o`00017ooooo0_l0000Uooooo`;o00001_ooool2o`0005cooooo0_l0001Booooo`007_ooool0
0ol0003oooooooooo`1Cooooo`;o00001_ooool2o`0000_ooooo0_l0000[ooooo`;o0000G?ooool2
o`0005;ooooo000Nooooo`03o`000?oooooooooo02Sooooo0_l0000Mooooo`;o00004_ooool2o`00
00Oooooo0ol000000ooooooo0000o`000004ooooo`;o0000J_ooool2o`0006_ooooo000Nooooo`03
o`000?oooooooooo02Sooooo0_l0000Mooooo`;o00006oooool3o`0000Oooooo0_l0001>ooooo`;o
00006_ooool2o`0006_ooooo000Nooooo`03o`000?oooooooooo0;kooooo0_l00027ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0A?ooool2o`0002Kooooo0_l00017ooooo`;o0000T?ooool001ko
oooo00?o0000ooooooooool0<Oooool2o`00017ooooo0_l0000Mooooo`;o00001oooool2o`0004Oo
oooo0_l0002@ooooo`007_ooool00ol0003oooooooooo`0Fooooo`;o00004oooool2o`0000Cooooo
0_l00005ooooo`;o0000:Oooool2o`000>;ooooo000Nooooo`;o00005oooool2o`0001?ooooo0_l0
000;ooooo`;o00002Oooool2o`0000gooooo0_l0000Aooooo`;o00008?ooool2o`000:oooooo0_l0
000=ooooo`007_ooool00ol0003oooooooooo`13ooooo`;o00003Oooool2o`00017ooooo0_l00002
ooooo`Co00006_ooool2o`000:oooooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`0hoooo
o`;o00008_ooool2o`0000_ooooo1?l0002Dooooo`;o00000_ooool2o`0000Oooooo0_l0000Hoooo
o`;o00007Oooool001kooooo00?o0000ooooooooool0>?ooool2o`0002;ooooo0_l0002Sooooo`;o
00000_ooool2o`0000Oooooo0_l0000Hooooo`;o00007Oooool001kooooo00?o0000ooooooooool0
B_ooool2o`0000Oooooo0_l0003booooo`007_ooool00ol0003oooooooooo`1:ooooo`;o00001ooo
ool2o`000?;ooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0<oooool2o`0005[ooooo0_l0000;ooooo`;o0000LOooool2o`0003Kooooo000Nooooo`03
o`000?oooooooooo03?ooooo0_l0000dooooo`;o00009?ooool2o`0000_ooooo0_l0001aooooo`;o
00003?ooool2o`0002Sooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l00005ooooo`;o0000
??ooool2o`0000Oooooo0_l0000Cooooo`;o0000U?ooool2o`0002Sooooo000Nooooo`03o`000?oo
oooooooo02Cooooo0_l00005ooooo`;o00006_ooool2o`0002Wooooo1?l0000Aooooo`;o0000AOoo
ool2o`0007Oooooo000Nooooo`03o`000?oooooooooo03Oooooo0_l0000>ooooo`;o0000:oooool2
o`0005Sooooo0_l0001gooooo`007_ooool00ol0003oooooooooo`0Kooooo`;o00006_ooool2o`00
05kooooo0_l0002^ooooo`007_ooool00ol0003oooooooooo`03ooooo`;o00005_ooool2o`0007[o
oooo0_l0002^ooooo`007_ooool00ol0003oooooooooo`03ooooo`;o0000??ooool2o`0001cooooo
0_l0003Vooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o00002?ooool2o`0001;ooooo0_l0
000Looooo`;o0000i_ooool001kooooo0_l0000Tooooo`;o00002?ooool2o`0001?ooooo0_l0003o
ooooo`Cooooo000Nooooo`03o`000?oooooooooo02Sooooo0_l0000Hooooo`;o0000ooooool4oooo
o`007_ooool00ol0003oooooooooo`0Xooooo`;o00006?ooool2o`00017ooooo0_l0003`ooooo`00
7_ooool00ol0003oooooooooo`0oooooo`;o000000?oooooo`000?l000004Oooool2o`000?3ooooo
000Nooooo`03o`000?oooooooooo03oooooo0_l0000=ooooo`;o0000moooool001kooooo00?o0000
ooooooooool0=?ooool2o`0001Sooooo0_l0003Cooooo`;o00008_ooool001kooooo00?o0000oooo
ooooool0=?ooool2o`000>gooooo0_l0000Rooooo`007_ooool00ol0003oooooooooo`14ooooo`;o
0000[?ooool2o`0005?ooooo000Nooooo`03o`000?oooooooooo03?ooooo0_l0000?ooooo`;o0000
6oooool2o`0008oooooo0_l0001Cooooo`007_ooool3o`0003?ooooo0_l0000/ooooo`;o0000i?oo
ool001kooooo0ol0000/ooooo`;o0000??ooool2o`000=_ooooo000Nooooo`03o`000?oooooooooo
02cooooo0_l0000looooo`;o0000foooool001kooooo00?o0000ooooooooool09Oooool2o`000?oo
oooo8Oooool001kooooo00?o0000ooooooooool03oooool2o`0001Cooooo0_l0003oooooob7ooooo
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`00
0?oooooooooo00oooooo0_l0000Dooooo`;o0000^Oooool2o`0006Gooooo0003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03
o`000?oooooooooo03gooooo0_l00018ooooo`;o00000oooool2o`0005;ooooo0_l0001Uooooo`00
0oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool3o`0003go
oooo0_l00015ooooo`;o000000?oooooo`000?l000000oooool2o`000;Wooooo0003ooooo`05o`00
0?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo06go
oooo0_l0000Booooo`;o000000?oooooo`000?l00000Poooool2o`0003cooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo06Wo
oooo0_l00002ooooo`;o00004_ooool2o`0008Kooooo0_l0000looooo`000oooool01Ol@413ooooo
oooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Yooooo`;o
0000g?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRH
V?l@41001_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooolX
ooooo`;o00007_ooool001kooooo00?o0000ooooooooool0oooooolXooooo`;o00007_ooool001ko
oooo00?o0000ooooooooool0oooooolUooooo`;o00008Oooool001kooooo00?o0000ooooooooool0
oooooolUooooo`;o00008Oooool001kooooo00?o0000ooooooooool0Hoooool2o`000>;ooooo000N
ooooo`03o`000?oooooooooo06?ooooo0_l0000Kooooo`;o0000aOooool001kooooo00?o0000oooo
ooooool0P?ooool2o`000<Gooooo000Mooooo`;o00008oooool2o`000?oooooo9Oooool001gooooo
0_l0000Sooooo`;o00008Oooool2o`000?oooooo0_ooool001kooooo00?o0000ooooooooool09ooo
ool2o`0001_ooooo0_l0003oooooo`;ooooo000Nooooo`04o`000?ooooooooooooooo`;o00009?oo
ool2o`000?oooooo7oooool001kooooo00Co0000oooooooooooooooo0_l0002=ooooo`;o0000]Ooo
ool001kooooo0_l0000Pooooo`;o0000Koooool2o`000;Gooooo000Nooooo`03o`000?oooooooooo
01oooooo0_l0000Dooooo`;o00008?ooool2o`0001cooooo0_l0003@ooooo`007_ooool00ol0003o
ooooooooo`0eooooo`;o00008?ooool2o`0001cooooo0_l0003@ooooo`007_ooool00ol0003ooooo
ooooo`3=ooooo`;o0000N?ooool001kooooo00?o0000ooooooooool07oooool2o`000:cooooo0_l0
001:ooooo`;o0000;?ooool001kooooo00?o0000ooooooooool07oooool2o`000?Sooooo0_l0000/
ooooo`007_ooool00ol0003oooooooooo`26ooooo`;o0000_oooool001kooooo00?o0000oooooooo
ool0Q_ooool2o`000;oooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`0_ooooo`;o00001?ooool2o`000?oooooo4Oooool001kooooo00?o
0000ooooooooool08?ooool2o`0000gooooo0_l00004ooooo`;o0000oooooolAooooo`007_ooool0
0ol0003oooooooooo`0Pooooo`;o0000EOooool2o`000<kooooo000Nooooo`;o0000N?ooool2o`00
0:?ooooo0_l0000Yooooo`007_ooool00ol0003oooooooooo`3ooooooagooooo0_l0000;ooooo`;o
00007?ooool001kooooo00?o0000ooooooooool0LOooool2o`000;Kooooo0_l0000Looooo`007_oo
ool00ol0003oooooooooo`0[ooooo`;o0000A?ooool2o`0008?ooooo0_l0001?ooooo`007_ooool0
0ol0003oooooooooo`0[ooooo`;o0000bOooool2o`0004oooooo000Nooooo`03o`000?oooooooooo
08Wooooo0_l0002looooo`007_ooool00ol0003oooooooooo`0aooooo`;o0000E_ooool2o`000;co
oooo000Nooooo`03o`000?oooooooooo037ooooo0_l0003ooooooaGooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo04kooooo0_l0000^ooooo`?o
0000a_ooool001kooooo00?o0000ooooooooool0=oooool2o`0001Gooooo0_l0000^ooooo`?o0000
a_ooool001kooooo00?o0000ooooooooool0=oooool2o`000?oooooo3oooool001kooooo00?o0000
ooooooooool0G_ooool2o`0003Sooooo0_l0002]ooooo`007_ooool00ol0003oooooooooo`1Noooo
o`;o0000>?ooool2o`000:gooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooo
ooooo`0cooooo`;o0000G_ooool2o`0008[ooooo0_l0000Vooooo`007_ooool00ol0003ooooooooo
o`0cooooo`;o0000G_ooool2o`0008[ooooo0_l0000Vooooo`007_ooool00ol0003oooooooooo`2>
ooooo`;o0000]oooool001kooooo00?o0000ooooooooool0S_ooool2o`000;Oooooo000Nooooo`03
o`000?oooooooooo0?oooooo8_ooool2o`0001Cooooo0_l0000>ooooo`007_ooool00ol0003ooooo
ooooo`3oooooob;ooooo0_l0000Dooooo`;o00003_ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`2Eooooo`;o00008_ooool2o`0008cooooo000Noooo
o`03o`000?oooooooooo01Sooooo0_l0001aooooo`;o00002?ooool2o`0002;ooooo0_l0000<oooo
o`;o0000O_ooool001kooooo00?o0000ooooooooool06?ooool2o`00077ooooo0_l0000jooooo`;o
0000Loooool2o`0000Wooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l0003oooooob;ooooo
0_l00009ooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o0000Foooool2o`0000Gooooo0_l0
0038ooooo`007_ooool00ol0003oooooooooo`0jooooo`;o00000oooool2o`0002cooooo0_l00007
ooooo`;o00001Oooool2o`0005[ooooo0_l0001/ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0j
ooooo`;o00000oooool2o`0002cooooo0_l0001Zooooo`;o0000K?ooool000?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool3
o`0007[ooooo0_l0003;ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo00001oooool00ol0003oooooooooo`1Qooooo`;o00005oooool2o`000<_ooooo0003
ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`04o`00
0?oooooo0000o`00063ooooo0_l0003Tooooo`000oooool01Ol@413ooooooooooooooooo410@00co
oooo00?oMgMgolc<c?l000001oooool01?l0003oooooo`000?l0003oooooodOooooo0003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo
04Kooooo0_l0003oooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`00
0?ooool01_ooool00ol0003oooooooooo`16ooooo`;o0000<oooool2o`000<[ooooo000Nooooo`03
o`000?oooooooooo07_ooooo0_l0001;ooooo`;o0000OOooool001kooooo00?o0000ooooooooool0
b?ooool2o`0007gooooo000Nooooo`03o`000?oooooooooo037ooooo0_l0000kooooo`;o00000_oo
ool2o`000=?ooooo000Nooooo`03o`000?oooooooooo037ooooo0_l0000Kooooo`;o00007_ooool2
o`0000;ooooo0_l0003Cooooo`007_ooool00ol0003oooooooooo`1>ooooo`;o00005Oooool2o`00
077ooooo0_l0001Vooooo`;o00001Oooool001kooooo00?o0000ooooooooool0IOooool2o`00077o
oooo0_l0001Vooooo`;o00001Oooool001kooooo00?o0000ooooooooool0Q_ooool2o`000;oooooo
000Nooooo`03o`000?oooooooooo08Kooooo0_l0000gooooo`;o0000Q_ooool001kooooo00?o0000
ooooooooool0DOooool2o`0006cooooo0_l0001Cooooo`;o0000<Oooool001kooooo00?o0000oooo
ooooool07Oooool2o`0003;ooooo0_l0002Zooooo`;o00005Oooool2o`00037ooooo000Nooooo`03
o`000?oooooooooo01gooooo0_l0000gooooo`;o0000YOooool2o`0002Gooooo0_l0000Qooooo`00
7_ooool2o`0001?ooooo0_l00012ooooo`;o0000Goooool2o`0006_ooooo0_l0000Qooooo`007_oo
ool00ol0003oooooooooo`0Booooo`;o0000Xoooool2o`0008kooooo000Nooooo`03o`000?oooooo
oooo0?oooooo2?ooool2o`0003kooooo000Nooooo`03o`000?oooooooooo097ooooo0_l0001doooo
o`;o0000?_ooool001kooooo00?o0000ooooooooool0P?ooool2o`0000oooooo0_l0002dooooo`00
7_ooool00ol0003oooooooooo`0Mooooo`;o0000HOooool2o`000<Gooooo000Nooooo`03o`000?oo
oooooooo01gooooo0_l0003oooooobWooooo000Nooooo`03o`000?oooooooooo01[ooooo0_l0003o
ooooobcooooo000Nooooo`03o`000?oooooooooo01[ooooo0_l0003oooooobcooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool03oooool2o`000?oooooo
6oooool2o`0001[ooooo000Nooooo`03o`000?oooooooooo00kooooo0ol00002ooooo`;o0000oooo
oolGooooo`;o00006_ooool001kooooo00?o0000ooooooooool03_ooool2o`0000?ooooo0_l0001Y
ooooo`;o00004?ooool2o`000;Gooooo000Nooooo`03o`000?oooooooooo043ooooo0_l0000loooo
o`;o00001Oooool2o`0000Wooooo0_l0002eooooo`007_ooool00ol0003oooooooooo`10ooooo`;o
0000<?ooool2o`00017ooooo0_l00030ooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o0000
Eoooool2o`000=?ooooo000Nooooo`;o00006_ooool2o`000?oooooo;Oooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooooaoooooo0_l0000Woooo
o`007_ooool01?l0003oooooo`000?l0002gooooo`;o0000I?ooool2o`0002Oooooo000Nooooo`04
o`000?oooooo0000o`000;Oooooo0_l0002=ooooo`007_ooool00ol0003oooooooooo`27ooooo`;o
0000__ooool001kooooo00?o0000ooooooooool0Qoooool2o`000;kooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool06Oooool2o`0006Oooooo0_l00033
ooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o0000Ioooool2o`000<?ooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool00oooool2o`0009;ooooo
0_l0002Iooooo`;o00004oooool001kooooo00?o0000ooooooooool00oooool2o`0005gooooo0_l0
000cooooo`;o0000VOooool2o`0001?ooooo000Nooooo`03o`000?oooooooooo06;ooooo0_l0000?
ooooo`;o0000d_ooool001kooooo00?o0000ooooooooool0Loooool2o`0000[ooooo0_l00036oooo
o`007_ooool00ol0003oooooooooo`1oooooo`;o0000a_ooool001kooooo0_l00004ooooo`;o0000
L?ooool2o`000=3ooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0001Hooooo`;o00005_oo
ool2o`000=3ooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l0000gooooo`;o00005_ooool2
o`000=3ooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l0001?ooooo`;o0000KOooool2o`00
067ooooo000Nooooo`03o`000?oooooooooo013ooooo0_l0003Booooo`;o0000HOooool001kooooo
00?o0000ooooooooool04?ooool2o`000?oooooo=_ooool001kooooo00?o0000ooooooooool07Ooo
ool2o`000?oooooo4oooool2o`0001Cooooo000Nooooo`03o`000?oooooooooo01gooooo0_l0003J
ooooo`;o0000=_ooool2o`0001Cooooo000Nooooo`03o`000?oooooooooo0?Wooooo0_l0001<oooo
o`007_ooool00ol0003oooooooooo`0Sooooo`;o0000h_ooool2o`0003kooooo000Nooooo`03o`00
0?oooooooooo02?ooooo0_l0000Booooo`;o00002?ooool2o`0000?ooooo0_l0002oooooo`;o0000
?_ooool001kooooo00?o0000ooooooooool0=oooool2o`0000Sooooo0_l00003ooooo`;o0000oooo
ool001kooooo00?o0000ooooooooool0A_ooool2o`0005gooooo0_l0000Nooooo`;o0000P?ooool0
01kooooo00?o0000ooooooooool0Hoooool2o`00043ooooo0_l0000Nooooo`;o0000P?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413o
c<c<00Kooooo00?o0000ooooooooool0A?ooool2o`0001gooooo0_l0003Rooooo`000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401Ooo
ool2o`0004Kooooo0_l0000Rooooo`;o0000M_ooool2o`0006Gooooo0003ooooo`05oa0@4?oooooo
ooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Gooooo1?l0001Xooooo`;o0000
M_ooool2o`0006Gooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RH
oooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol0003ooooo
oooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo
0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo
00Sooooo00?o0000ooooooooool0;oooool2o`0003Kooooo0_l0003Nooooo`000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0_oooo
o`;o0000=_ooool2o`000=kooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<
c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo03Gooooo0_l0003Cooooo`;o0000>oooool0
01kooooo00?o0000ooooooooool0=Oooool2o`0009;ooooo0_l0000<ooooo`;o0000<Oooool2o`00
03_ooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0001:ooooo`;o0000JOooool2o`0000co
oooo0_l0001^ooooo`007_ooool00ol0003oooooooooo`0Booooo`;o00008_ooool2o`0000[ooooo
0_l0000Jooooo`;o00003?ooool2o`000=Wooooo000Nooooo`03o`000?oooooooooo03Kooooo0_l0
000:ooooo`;o0000:?ooool2o`00043ooooo0_l0002Gooooo`007_ooool00ol0003oooooooooo`2^
ooooo`;o0000Uoooool001kooooo00?o0000ooooooooool0@Oooool2o`0001_ooooo0_l0003Woooo
o`007_ooool00ol0003oooooooooo`11ooooo`;o00006oooool2o`000<oooooo0_l0000Fooooo`00
7_ooool00ol0003oooooooooo`0Looooo`;o0000WOooool2o`0004Kooooo0_l0000Zooooo`;o0000
5_ooool001kooooo00?o0000ooooooooool07?ooool2o`0005Oooooo0_l00014ooooo`;o0000A_oo
ool2o`0004;ooooo000Nooooo`03o`000?oooooooooo043ooooo0_l0000_ooooo`;o00000_ooool2
o`000=3ooooo000Nooooo`03o`000?oooooooooo043ooooo0_l0000_ooooo`;o0000e?ooool001ko
oooo0_l0000iooooo`;o0000UOooool2o`0007Kooooo000Nooooo`03o`000?oooooooooo03Sooooo
0_l0002Eooooo`;o0000M_ooool001kooooo00?o0000ooooooooool0??ooool2o`0001;ooooo0_l0
003eooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o00009oooool2o`0001;ooooo0_l0000N
ooooo`;o0000eOooool001kooooo00?o0000ooooooooool04oooool2o`0005_ooooo0_l0003Eoooo
o`007_ooool00ol0003oooooooooo`2eooooo`;o00008_ooool2o`0006cooooo000Nooooo`03o`00
0?oooooooooo0;Gooooo0_l0000Rooooo`;o0000K?ooool001kooooo00?o0000ooooooooool08?oo
ool2o`000;oooooo0_l0001Tooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o0000_oooool2
o`0006Cooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0003ooooooccooooo000Nooooo`03
o`000?oooooooooo00[ooooo0_l00037ooooo`;o0000L_ooool001kooooo00Co0000oooooooooooo
oooo0_l00004ooooo`;o0000B?ooool2o`00047ooooo0_l0000mooooo`;o0000L_ooool001kooooo
00Co0000oooooooooooooooo0_l00004ooooo`;o00005_ooool2o`0001_ooooo0_l0000Cooooo`;o
00007_ooool2o`00027ooooo0_l0002Tooooo`;o00002oooool001kooooo00?o0000ooooooooool0
7oooool2o`0001_ooooo0_l0000cooooo`;o00001Oooool2o`000<3ooooo0_l0000;ooooo`007_oo
ool00ol0003oooooooooo`1hooooo`;o0000cOooool001kooooo00?o0000ooooooooool0@_ooool2
o`0009oooooo0_l0001Rooooo`007_ooool2o`00013ooooo0_l0000aooooo`;o00009_ooool2o`00
07Oooooo0_l0001Rooooo`007_ooool00ol0003oooooooooo`06ooooo`;o00001oooool2o`0005Oo
oooo1?l0000>ooooo`;o0000Koooool2o`0005[ooooo000Nooooo`03o`000?oooooooooo00Kooooo
0_l0000Xooooo`;o0000=_ooool2o`00013ooooo0_l0001_ooooo`;o0000F_ooool001kooooo00?o
0000ooooooooool0<?ooool2o`000;3ooooo0_l0001Sooooo`007_ooool00ol0003oooooooooo`1L
ooooo`;o0000=_ooool2o`0004cooooo0_l0001Sooooo`007_ooool00ol0003oooooooooo`0Hoooo
o`;o0000@_ooool2o`00037ooooo0_l00003ooooo`;o00008_ooool2o`0000Cooooo0_l00027oooo
o`007_ooool01?l0003oooooo`000?l0000Gooooo`;o0000B?ooool2o`0002_ooooo0_l0000Woooo
o`;o00001?ooool2o`0008Oooooo000Nooooo`04o`000?oooooo0000o`0002cooooo0_l0000coooo
o`;o0000[_ooool2o`0003?ooooo000Nooooo`03o`000?oooooooooo02gooooo0_l0000Fooooo`;o
0000boooool2o`00023ooooo0_l0000Aooooo`007_ooool00ol0003oooooooooo`15ooooo`;o0000
1Oooool2o`0008?ooooo0_l0001Oooooo`Co00004Oooool001kooooo00?o0000ooooooooool0C?oo
ool2o`0008?ooooo0_l0000Cooooo`;o0000B_ooool2o`0001?ooooo000Nooooo`03o`000?oooooo
oooo03kooooo0_l0002Vooooo`;o0000Goooool001kooooo00?o0000ooooooooool08?ooool2o`00
01cooooo0_l0000=ooooo`;o0000;?ooool2o`000:;ooooo0_l0000Vooooo`007_ooool00ol0003o
ooooooooo`0Pooooo`;o00004?ooool2o`0001Wooooo0_l00005ooooo`;o000000?oooooo`000?l0
00008_ooool2o`0005_ooooo0_l00015ooooo`;o00009_ooool001kooooo00?o0000ooooooooool0
7?ooool2o`0001Cooooo0_l0000Pooooo`;o000000?oooooo`000?l00000Boooool2o`0003;ooooo
0_l0001]ooooo`007_ooool00ol0003oooooooooo`0Looooo`;o00003Oooool2o`0000_ooooo0_l0
00001?oooooo0000o`000?l0000Mooooo`;o00001oooool2o`0003kooooo0_l00008ooooo`;o0000
Uoooool001kooooo0_l0000Mooooo`;o00001oooool2o`0000Cooooo0_l0000;ooooo`;o000000Co
ooooo`000?l0003o00004oooool2o`0000Sooooo0_l00007ooooo`;o0000B?ooool2o`0007Sooooo
0_l0000Mooooo`007_ooool2o`0001gooooo0_l00007ooooo`;o00002?ooool2o`0000Oooooo0_l0
000;ooooo`;o00001Oooool4o`000003ooooool0003o00000=Gooooo0_l00007ooooo`;o00005?oo
ool001kooooo00?o0000ooooooooool00_l0000Dooooo`;o00002?ooool2o`0000gooooo0_l0000D
ooooo`;o00001Oooool4o`0002Oooooo0_l0002hooooo`;o00005?ooool001kooooo00?o0000oooo
ooooool00_l0000Dooooo`;o00002?ooool2o`0000kooooo0_l00006ooooo`;o0000>_ooool2o`00
0003ooooool0003o00000<kooooo000Nooooo`03o`000?oooooooooo02cooooo0_l000000ooooooo
0000o`000003o`0000Cooooo0_l0000jooooo`;o0000:oooool2o`000:Cooooo000Nooooo`?o0000
1_ooool2o`0000Kooooo0_l0000Looooo`;o000000Coooooo`000?l0003ooooo1?l0000fooooo`;o
0000<oooool2o`000:Cooooo000Nooooo`?o00001_ooool2o`0000Kooooo0ol0000Sooooo`;o0000
0oooool2o`0002Kooooo0_l00009ooooo`;o0000fOooool001kooooo00?o0000ooooooooool03ooo
ool2o`0002Sooooo0_l0000Iooooo`;o00002oooool2o`0004Oooooo0_l0000Pooooo`;o0000NOoo
ool001kooooo00?o0000ooooooooool04Oooool2o`0000_ooooo0_l0000Kooooo`;o00005oooool2
o`0005Cooooo0_l0000Pooooo`;o0000NOooool001kooooo00?o0000ooooooooool04Oooool2o`00
00_ooooo0_l0000Aooooo`;o00002?ooool2o`00013ooooo0_l00005ooooo`;o0000lOooool001ko
oooo00?o0000ooooooooool08oooool2o`0000_ooooo0ol0000Jooooo`;o00001Oooool2o`0000?o
oooo0_l0000Dooooo`;o00005Oooool2o`000;oooooo000Nooooo`03o`000?oooooooooo02?ooooo
0_l00003ooooo`;o00001_ooool2o`0001;ooooo0_l0000Cooooo`;o00005?ooool2o`0001Gooooo
0_l0002oooooo`007_ooool00ol0003oooooooooo`09ooooo`;o00007Oooool2o`0000Oooooo0_l0
000Aooooo`;o00007oooool2o`000>3ooooo000Nooooo`04o`000?oooooo0000o`0000Sooooo0_l0
000Mooooo`?o00001_ooool2o`0000Cooooo0_l0000>ooooo`;o00004oooool5o`0000Cooooo0_l0
003Pooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ
8B7o0000ob4Q8Oo<c<`01_ooool01?l0003oooooo`000?l0000Xooooo`;o00001_ooool2o`0000Co
oooo0ol0000=ooooo`;o00002Oooool2o`0000Sooooo1Ol00005ooooo`;o0000goooool000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q
00Kooooo00?o0000ooooooooool01_ooool2o`0001oooooo1Ol00004ooooo`?o00001Oooool2o`00
00[ooooo0_l0000<ooooo`;o00004_ooool2o`0003Gooooo0_l0002Fooooo`;o00004?ooool000?o
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3
o`0000Kooooo0_l0000Jooooo`;o00000oooool5o`0000Cooooo0_l0000Booooo`;o00004oooool2
o`00027ooooo0_l0000Oooooo`;o0000?Oooool2o`0005Oooooo0_l0000@ooooo`000oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oo
oooooooo02;ooooo0_l00003ooooo`?o00001?ooool2o`0002Wooooo0_l0000Qooooo`;o00009ooo
ool2o`0003Gooooo0_l0000looooo`;o0000:oooool000?ooooo00Go0000ooooooooooooooooo`00
000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool3o`0000gooooo0_l0000Gooooo`Co0000
1?ooool2o`0007Gooooo0_l0001Oooooo`;o00004Oooool3o`0002_ooooo0003ooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo1Ol0000;ooooo`;o
00004?ooool2o`0000Cooooo0ol00006ooooo`;o00009Oooool2o`0000?ooooo0_l0002Zooooo`;o
00004Oooool2o`0002cooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o
^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool00_l0000Mooooo`;o00001?ooool2o`00
00Oooooo0_l00008ooooo`;o00002?ooool5o`0000kooooo0_l00003ooooo`;o00002Oooool2o`00
01cooooo0_l00004ooooo`;o0000_?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`0Pooooo`;o00000oooool2
o`00017ooooo0_l000000ooooooo0000o`000005ooooo`Go00004oooool2o`0000Wooooo0_l0000A
ooooo`;o00002Oooool2o`0000Cooooo1?l0002Fooooo`;o00008_ooool001kooooo00?o0000oooo
ooooool08?ooool2o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`;o00001?ooool2o`00
00?ooooo1?l0000:ooooo`Co00004_ooool2o`0000;ooooo0_l0000:ooooo`;o00001oooool2o`00
017ooooo0_l0000:ooooo`;o0000R_ooool2o`0001Kooooo0_l0000:ooooo`007_ooool00ol0003o
ooooooooo`0Xooooo`Co000000Coooooo`000?l0003ooooo0_l00004ooooo`;o00001Oooool3o`00
00Wooooo1?l0000Booooo`;o00000_ooool2o`0000[ooooo0_l0000Vooooo`;o0000X_ooool2o`00
00[ooooo000Nooooo`03o`000?oooooooooo02Sooooo1?l000000ooooooo0000o`00000?ooooo`;o
00001oooool2o`0002_ooooo0_l000000ooooooo0000o`000033ooooo`;o00002Oooool001kooooo
00?o0000ooooooooool0<oooool2o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l00000
0oooool5o`0000Oooooo0_l00005ooooo`;o00006Oooool2o`000004ooooool0003o0000ooooo`;o
0000AOooool2o`0004[ooooo0_l0000]ooooo`?o00002?ooool001kooooo00?o0000ooooooooool0
:?ooool2o`0000Wooooo0ol000000ooooooo0000o`000005ooooo`;o000000Coooooo`000?l0003o
oooo1?l000000ooooooo0000o`000005ooooo`Co000000?oooooo`000?l000000_ooool2o`0000ko
oooo0_l0000?ooooo`;o0000=Oooool2o`0000kooooo0_l0001:ooooo`;o00004?ooool2o`0001co
oooo0_l00008ooooo`007_ooool00ol0003oooooooooo`03ooooo`;o00004oooool2o`0000kooooo
0_l0000:ooooo`;o00003_ooool4o`0000Sooooo0_l00003ooooo`;o00001?ooool2o`0000cooooo
0_l00006ooooo`;o00001oooool2o`0003Gooooo0_l0001/ooooo`;o00009_ooool001kooooo00?o
0000ooooooooool00oooool2o`0001?ooooo0_l000000ooooooo0000o`00000;ooooo`;o00006?oo
ool2o`0000;ooooo0_l00006ooooo`;o000000?oooooo`000?l000002?ooool2o`0001Cooooo0_l0
0006ooooo`;o0000X_ooool2o`0002Sooooo000Nooooo`03o`000?oooooooooo01_ooooo0ol0000:
ooooo`;o00004_ooool2o`000004ooooool0003o0000ooooo`?o00002Oooool5o`0000Kooooo0_l0
0007ooooo`;o00000_ooool2o`00017ooooo0_l0000aooooo`;o0000H_ooool2o`0000_ooooo0_l0
000Hooooo`;o00003_ooool001kooooo00?o0000ooooooooool05_ooool2o`0000Cooooo0_l0000N
ooooo`;o000000?oooooo`000?l000000_ooool2o`0000_ooooo0_l00007ooooo`;o00001oooool2
o`0000;ooooo0_l00003ooooo`;o0000?oooool2o`0006;ooooo0_l0000Uooooo`;o00003_ooool0
01kooooo00?o0000ooooooooool05_ooool2o`0001?ooooo0_l00005ooooo`;o00001oooool9o`00
00Cooooo0_l000001?oooooo0000o`000?ooool5o`000003ooooool0003o000000Kooooo0_l0000=
ooooo`;o00001_ooool2o`0000Oooooo0_l00039ooooo`007_ooool00ol0003oooooooooo`0Boooo
o`;o00004oooool6o`0000?ooooo1?l00007ooooo`_o000000?oooooo`000?l000002_l000000ooo
oooo0000o`000002ooooo`;o00000_ooool2o`0001Gooooo0_l00007ooooo`;o0000bOooool001ko
oooo0_l0000Cooooo`;o00002_ooool4o`000005ooooool0003o0000o`000?ooool01?l00003oooo
o`Go000000?oooooo`000?l000001Oooool2o`000003ooooool0003o000000Wo000000?oooooo`00
0?l000000ol000000ooooooo0000o`000006ooooo`;o000000Goooooo`000?l0003o0000ooooo`02
o`000004ooooool0003o0000o`0001cooooo0_l000001?oooooo0000o`000?ooool2o`0001;ooooo
0_l0002Oooooo`;o00002Oooool001kooooo00?o0000ooooooooool03Oooool2o`0000oooooo1?l0
00001?oooooo0000o`000?l00008ooooo`;o00001?ooool2o`0000Gooooo0_l00002ooooo`_o0000
00?oooooo`000?l000002Oooool2o`0000;ooooo1?l000001?oooooo0000o`000?ooool3o`0000Co
oooo0_l0000Fooooo`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00003Oooool2o`00
09oooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`02o`0000_ooooo0_l0000:ooooo`;o
00001oooool4o`0000Gooooo0_l00009ooooo`?o00001_ooool5o`000003ooooool0003o000000?o
00000_ooool2o`0000Sooooo0_l00002ooooo`;o00000oooool3o`0000Oooooo0_l0000Nooooo`;o
000000?oooooo`000?l000003Oooool2o`000:[ooooo000Nooooo`03o`000?oooooooooo00;o0000
3Oooool2o`0000Sooooo0_l00007ooooo`Co000000?oooooo`000?l000000_ooool2o`0000Oooooo
1Ol000000ooooooo0000o`000005ooooo`;o00000_ooool;o`000003ooooool0003o000000?ooooo
0ol00007ooooo`;o00000_ooool2o`0000?ooooo0_l0000Nooooo`Co00002?ooool2o`0000Cooooo
0_l0002Zooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o00004?ooool2o`000004ooooool0
003o0000ooooo`;o000000?oooooo`000?l000002?ooool2o`000003ooooool0003o000000?o0000
0oooool=o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`?o000000?oooooo`000?l00000
0_l00006ooooo`;o00000oooool2o`0000Sooooo0_l0000Fooooo`;o00002?ooool2o`000:[ooooo
0_l00004ooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o000000?oooooo`000?l000002?oo
ool2o`0000Kooooo1Ol0000:ooooo`;o00001Oooool<o`0000_ooooo0ol000000ooooooo0000o`00
0002o`0001Gooooo0_l0003<ooooo`;o00001?ooool001kooooo00?o0000ooooooooool05?ooool2
o`000003ooooool0003o0000013ooooo0_l000000ooooooo0000o`000008ooooo`;o00002?ooool3
o`0000?ooooo1_l00002ooooo`?o00001?ooool3o`0001;ooooo0_l00008ooooo`;o00009?ooool2
o`000:_ooooo000Nooooo`03o`000?oooooooooo01_ooooo0_l0000?ooooo`;o00000oooool2o`00
00;ooooo1Ol00006ooooo`;o000000?oooooo`000?l000000_ooool@o`000003ooooool0003o0000
013ooooo0_l00008ooooo`;o00006_ooool2o`0000Sooooo0_l0002[ooooo`007_ooool00ol0003o
ooooooooo`0>ooooo`;o00002oooool2o`0000oooooo0_l00003ooooo`;o00000_ooool2o`000003
ooooool0003o000000Wooooo0_l00002ooooo`Oo000000?oooooo`000?l000001Ol00002ooooo`;o
00001?ooool3o`0000?ooooo0_l00004ooooo`;o00004?ooool2o`0001;ooooo0_l0002eooooo`00
7_ooool00ol0003oooooooooo`0>ooooo`;o00004?ooool2o`0000oooooo0_l00009ooooo`;o0000
1?ooool2o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`?o00000_ooool3o`0000?ooooo
1ol00003ooooo`Co00000_ooool2o`0000oooooo0ol0000Hooooo`;o0000Woooool2o`000003oooo
ool0003o000000_ooooo000Nooooo`03o`000?oooooooooo023ooooo0_l000000ooooooo0000o`00
000Gooooo`;o00001?ooool2o`0000Cooooo0_l000000ooooooo0000o`000007ooooo`?o00000ooo
ool4o`0000Cooooo0_l00002ooooo`;o00000_ooool2o`0000oooooo0_l0000Iooooo`;o00006Ooo
ool2o`0008Cooooo0_l000000ooooooo0000o`00000;ooooo`007_ooool00ol0003oooooooooo`0I
ooooo`;o000000?oooooo`000?l000001Oooool2o`0001gooooo0_l00009ooooo`;o00001Oooool3
o`0000;ooooo0_l00007ooooo`?o00000_ooool2o`0000Cooooo0_l00003ooooo`;o00001Oooool2
o`00013ooooo0_l0000Tooooo`;o0000U?ooool001kooooo00?o0000ooooooooool01?ooool2o`00
01?ooooo0_l000000ooooooo0000o`000005ooooo`;o00000oooool2o`0000?ooooo0_l0000Goooo
o`;o000000?oooooo`000?l000000_ooool2o`0000Wooooo1?l00007ooooo`?o000000?oooooo`00
0?l000001?ooool2o`0000?ooooo0_l00005ooooo`;o00001_ooool2o`0000Sooooo0_l00007oooo
o`;o0000Aoooool2o`0006Sooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0000Mooooo`;o
00000oooool2o`0000?ooooo0_l0000Aooooo`;o00001?ooool2o`000003ooooool0003o000000So
oooo0_l00003ooooo`Co00001oooool3o`000003ooooool0003o000001Sooooo0_l0000Aooooo`;o
0000Aoooool2o`0005cooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o0000
3_ooool2o`0000?ooooo0_l00007ooooo`;o00003?ooool5o`0000Wooooo0ol00003ooooo`;o0000
0_ooool2o`0000[ooooo1_l0003Booooo`;o00002_ooool001kooooo00?o0000ooooooooool04ooo
ool2o`0000kooooo0_l00003ooooo`?o00001_ooool2o`0000?ooooo0_l000000ooooooo0000o`00
0002o`000005ooooool0003o0000o`000?ooool00_l00009ooooo`Go00001Oooool2o`000004oooo
ool0003o0000o`0000?ooooo1Ol000000ooooooo0000o`000002o`0001kooooo0_l0002]ooooo`;o
00003_ooool001kooooo0_l0000Iooooo`;o00001oooool2o`0000Kooooo0_l0000;ooooo`;o0000
00?oooooo`000?l000001Ol0000=ooooo`;o000000?oooooo`000?l000001Oooool2o`000004oooo
ool0003o0000o`0000?ooooo1Ol00002ooooo`?o00007?ooool4o`0001Sooooo0_l00002ooooo`;o
0000Soooool2o`0000kooooo000Nooooo`03o`000?oooooooooo01Sooooo0_l00007ooooo`;o0000
0oooool2o`0000Oooooo0_l00006ooooo`Go000000?oooooo`000?l000001_ooool2o`0000Kooooo
0_l0000?ooooo`Co000000?oooooo`000?l000000_l0000Oooooo`;o00006_ooool2o`0000;ooooo
0_l0001Kooooo`;o0000@_ooool001kooooo00?o0000ooooooooool08Oooool2o`0000?ooooo0_l0
0005ooooo`Co00001_ooool5o`0000Cooooo0_l00003ooooo`;o00004_ooool2o`0000;ooooo1Ol0
00000ooooooo0000o`000002o`0001oooooo0_l0001kooooo`;o0000@_ooool001kooooo00?o0000
ooooooooool04oooool2o`0000cooooo0_l0000:ooooo`;o00003_ooool2o`000003ooooool0003o
000000;ooooo1Ol00008ooooo`;o00001?ooool4o`000005ooooool0003o0000o`000?ooool00_l0
000Tooooo`;o0000U_ooool3o`0002Kooooo000Nooooo`03o`000?oooooooooo01?ooooo0_l0000@
ooooo`;o00005_ooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000004
o`0000Cooooo0_l00004ooooo`Co000000Coooooo`000?l0003ooooo0_l0000Aooooo`;o0000Q?oo
ool2o`0002Cooooo0ol0000Vooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o00001?ooool2
o`0000Cooooo0_l0000Booooo`?o00001_ooool5o`0000cooooo0_l00004ooooo`;o00004Oooool2
o`0000kooooo0_l0001Sooooo`;o00003oooool2o`0004gooooo000Nooooo`03o`000?oooooooooo
01kooooo0ol00004ooooo`;o00001?ooool2o`0001;ooooo0_l00002ooooo`;o00000oooool4o`00
00;ooooo0_l0000<ooooo`;o00009?ooool2o`0006?ooooo0_l0000cooooo`;o0000:Oooool001ko
oooo00?o0000ooooooooool07_ooool2o`0001Kooooo0_l0000;ooooo`;o00001?ooool2o`000003
ooooool0003o000000;o000000?oooooo`000?l000002Oooool2o`000003ooooool0003o0000017o
oooo0_l00004ooooo`;o0000K?ooool2o`0003Cooooo0_l0000Yooooo`007_ooool00ol0003ooooo
ooooo`0fooooo`;o00002oooool2o`0000Cooooo1Ol00002ooooo`?o00002_ooool4o`0000[ooooo
0ol00004ooooo`;o00001?ooool2o`0005Wooooo0_l0000Aooooo`;o0000<?ooool2o`0002gooooo
000Nooooo`03o`000?oooooooooo01_ooooo0ol0000Uooooo`;o000000?oooooo`000?l000000_oo
ool3o`0000?ooooo0_l000000ooooooo0000o`000008ooooo`;o00001?ooool2o`0000?ooooo0_l0
00000ooooooo0000o`000003o`0000;ooooo0_l0001Oooooo`;o0000@oooool2o`0002gooooo000N
ooooo`03o`000?oooooooooo01[ooooo1?l0000Hooooo`Co00001?ooool2o`0000Kooooo0_l00002
ooooo`;o000000?oooooo`000?l000000oooool3o`0000Oooooo0ol00004ooooo`;o00000oooool2
o`0000;ooooo1?l00002ooooo`Ko0000J_ooool2o`0004cooooo0_l0000Eooooo`007_ooool00ol0
003oooooooooo`0Jooooo`Go00005oooool4o`000004ooooool0003o0000ooooo`;o00001?ooool2
o`0000Gooooo1_l000000ooooooo0000o`000002o`0000Kooooo0_l000000ooooooo0000o`000007
ooooo`?o000000?oooooo`000?l000001_ooool4o`0000?ooooo0_l0000_ooooo`;o0000=?ooool2
o`0002cooooo0_l0000Nooooo`;o00005Oooool001kooooo00?o0000ooooooooool07?ooool3o`00
01cooooo0_l00007ooooo`;o00001Oooool2o`0000;ooooo0_l00003ooooo`;o00002Oooool2o`00
00Sooooo0_l0000@ooooo`;o0000;oooool2o`0006;ooooo0_l0000eooooo`007_ooool00ol0003o
ooooooooo`0Wooooo`;o0000=?ooool2o`000=oooooo0_l00007ooooo`007_ooool00ol0003ooooo
ooooo`0?ooooo`;o00005_ooool2o`0003Cooooo0_l000000ooooooo0000o`00000;ooooo`;o0000
1Oooool2o`0001kooooo0_l0002Xooooo`;o00001oooool001kooooo00?o0000ooooooooool03ooo
ool2o`0004oooooo0_l00003ooooo`;o00001_ooool2o`0000Gooooo0_l0000Dooooo`;o00000_oo
ool2o`0000Cooooo0_l0002aooooo`007_ooool2o`0002Sooooo0_l0000:ooooo`;o0000:Oooool5
o`0000;ooooo0_l00008ooooo`?o00006?ooool2o`0000;ooooo0_l0000mooooo`;o00003?ooool2
o`0000kooooo0_l0001Jooooo`007_ooool00ol0003oooooooooo`0Wooooo`;o00001Oooool2o`00
00?ooooo0_l0000Wooooo`Oo00000oooool2o`0000Cooooo0_l000001?oooooo0000o`000?l0001K
ooooo`;o00001oooool2o`0000?ooooo0_l0000>ooooo`;o0000F_ooool001kooooo00?o0000oooo
ooooool06Oooool2o`0001?ooooo0_l0000/ooooo`;o00002?ooool4o`0000;ooooo1Ol0000Eoooo
o`;o00004?ooool2o`0003cooooo0_l0000Wooooo`;o0000A_ooool001kooooo00?o0000oooooooo
ool01oooool2o`00013ooooo0_l0001=ooooo`Go000000?oooooo`000?l000005_ooool2o`00013o
oooo0_l0001Uooooo`;o0000A_ooool001kooooo00?o0000ooooooooool01oooool2o`0001Gooooo
0ol0000:ooooo`;o0000;_ooool2o`0000_ooooo1Ol000000ooooooo0000o`00001Mooooo`;o0000
Doooool2o`0002?ooooo000Nooooo`03o`000?oooooooooo01kooooo0ol0000:ooooo`;o0000;_oo
ool2o`0000_ooooo0_l0000^ooooo`;o0000<oooool2o`0005?ooooo0_l0000Sooooo`007_ooool0
0ol0003oooooooooo`0Tooooo`;o0000:Oooool2o`0000Sooooo0_l00003ooooo`;o00001?ooool2
o`0003;ooooo0_l0000Looooo`;o0000Soooool001kooooo00?o0000ooooooooool09?ooool2o`00
02Wooooo0_l00008ooooo`;o00000_ooool3o`0000Cooooo0_l00004ooooo`?o0000BOooool2o`00
08oooooo000Nooooo`03o`000?oooooooooo01_ooooo0_l0000Cooooo`;o00000_ooool2o`0000So
oooo0_l0000Mooooo`;o00001Oooool2o`0000Cooooo1Ol0000:ooooo`;o0000c?ooool001kooooo
00?o0000ooooooooool06oooool2o`0001?ooooo0_l00002ooooo`;o000000?oooooo`000?l00000
1Oooool2o`000003ooooool0003o000000kooooo0_l0000Aooooo`Co00001Oooool2o`0000[ooooo
0_l0001/ooooo`;o00004Oooool2o`0004_ooooo000Nooooo`03o`000?oooooooooo02cooooo0_l0
0009ooooo`;o00001oooool3o`0000kooooo0_l0000Cooooo`;o00001Oooool2o`000003ooooool0
003o000000Oooooo0_l0001/ooooo`;o00004Oooool2o`0004_ooooo000Nooooo`03o`000?oooooo
oooo02Kooooo0_l00004ooooo`;o00004_ooool2o`0001Oooooo0_l0000=ooooo`;o00001_ooool3
o`0000Kooooo0_l0003<ooooo`007_ooool00ol0003oooooooooo`0Vooooo`;o00007Oooool2o`00
01;ooooo0_l0000=ooooo`;o00001oooool4o`0000Cooooo0_l0001mooooo`;o0000Aoooool2o`00
00Cooooo000Nooooo`?o0000AOooool2o`0000kooooo0_l0000Cooooo`;o00001oooool2o`0000Co
oooo0_l0001<ooooo`;o0000;oooool2o`0004Oooooo0_l00004ooooo`005?ooool4o`000003oa0@
4?oooooooooo00?ooooo0ol0001Eooooo`;o00004oooool2o`0000;ooooo0_l00002ooooo`;o0000
1_ooool2o`0004_ooooo0_l0001booooo`;o00002_ooool001Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Looooo`;o00008oooool2o`0001_ooooo0_l0000=ooooo`?o00000_oo
ool2o`0000Cooooo1?l0000Xooooo`;o0000UOooool2o`0000[ooooo000Fooooo`03o`000?oooooo
oooo00Gooooo0ol0000Looooo`;o00008oooool2o`0001_ooooo0_l0000=ooooo`;o00000oooool4
o`0000;ooooo0_l0000Zooooo`;o0000XOooool001Kooooo00?o0000ooooooooool0O?ooool2o`00
0=7ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0
oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Dooooo`03oeEEEOmVIVKo
00000?ooooooD_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "\tSmall fluctuations in the initial density are amplified by the Jeans \
instability, resulting in collapse of the gas cloud, followed by approach to \
something like an equilibrium state that consists of a single density peak,  \
surrounded by a hot gas of particles.   If one runs the simulation several \
times, one will find that qualitatively similar behavior occurs each time.\n\t\
  In Cell ",
  ButtonBox["7.86",
    ButtonData:>"Cell 7.86",
    ButtonStyle->"Hyperlink"],
  " we calculate the kinetic energy of the cloud."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[Table[{n\ \[CapitalDelta]t, kineticenergy[n]}, {n, 0, 60}], 
        PlotJoined \[Rule] True];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.86"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 5.29101 0.0147151 1.78653e-06 [
[.15608 .00222 -15 -9 ]
[.15608 .00222 15 0 ]
[.28836 .00222 -12 -9 ]
[.28836 .00222 12 0 ]
[.42063 .00222 -15 -9 ]
[.42063 .00222 15 0 ]
[.55291 .00222 -9 -9 ]
[.55291 .00222 9 0 ]
[.68519 .00222 -15 -9 ]
[.68519 .00222 15 0 ]
[.81746 .00222 -12 -9 ]
[.81746 .00222 12 0 ]
[.94974 .00222 -15 -9 ]
[.94974 .00222 15 0 ]
[.01131 .10404 -30 -4.5 ]
[.01131 .10404 0 4.5 ]
[.01131 .19337 -36 -4.5 ]
[.01131 .19337 0 4.5 ]
[.01131 .28269 -36 -4.5 ]
[.01131 .28269 0 4.5 ]
[.01131 .37202 -36 -4.5 ]
[.01131 .37202 0 4.5 ]
[.01131 .46135 -36 -4.5 ]
[.01131 .46135 0 4.5 ]
[.01131 .55067 -36 -4.5 ]
[.01131 .55067 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15608 .01472 m
.15608 .02097 L
s
[(0.025)] .15608 .00222 0 1 Mshowa
.28836 .01472 m
.28836 .02097 L
s
[(0.05)] .28836 .00222 0 1 Mshowa
.42063 .01472 m
.42063 .02097 L
s
[(0.075)] .42063 .00222 0 1 Mshowa
.55291 .01472 m
.55291 .02097 L
s
[(0.1)] .55291 .00222 0 1 Mshowa
.68519 .01472 m
.68519 .02097 L
s
[(0.125)] .68519 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(0.15)] .81746 .00222 0 1 Mshowa
.94974 .01472 m
.94974 .02097 L
s
[(0.175)] .94974 .00222 0 1 Mshowa
.125 Mabswid
.05026 .01472 m
.05026 .01847 L
s
.07672 .01472 m
.07672 .01847 L
s
.10317 .01472 m
.10317 .01847 L
s
.12963 .01472 m
.12963 .01847 L
s
.18254 .01472 m
.18254 .01847 L
s
.20899 .01472 m
.20899 .01847 L
s
.23545 .01472 m
.23545 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.31481 .01472 m
.31481 .01847 L
s
.34127 .01472 m
.34127 .01847 L
s
.36772 .01472 m
.36772 .01847 L
s
.39418 .01472 m
.39418 .01847 L
s
.44709 .01472 m
.44709 .01847 L
s
.47354 .01472 m
.47354 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.52646 .01472 m
.52646 .01847 L
s
.57937 .01472 m
.57937 .01847 L
s
.60582 .01472 m
.60582 .01847 L
s
.63228 .01472 m
.63228 .01847 L
s
.65873 .01472 m
.65873 .01847 L
s
.71164 .01472 m
.71164 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.76455 .01472 m
.76455 .01847 L
s
.79101 .01472 m
.79101 .01847 L
s
.84392 .01472 m
.84392 .01847 L
s
.87037 .01472 m
.87037 .01847 L
s
.89683 .01472 m
.89683 .01847 L
s
.92328 .01472 m
.92328 .01847 L
s
.97619 .01472 m
.97619 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .10404 m
.03006 .10404 L
s
[(50000)] .01131 .10404 1 0 Mshowa
.02381 .19337 m
.03006 .19337 L
s
[(100000)] .01131 .19337 1 0 Mshowa
.02381 .28269 m
.03006 .28269 L
s
[(150000)] .01131 .28269 1 0 Mshowa
.02381 .37202 m
.03006 .37202 L
s
[(200000)] .01131 .37202 1 0 Mshowa
.02381 .46135 m
.03006 .46135 L
s
[(250000)] .01131 .46135 1 0 Mshowa
.02381 .55067 m
.03006 .55067 L
s
[(300000)] .01131 .55067 1 0 Mshowa
.125 Mabswid
.02381 .03258 m
.02756 .03258 L
s
.02381 .05045 m
.02756 .05045 L
s
.02381 .06831 m
.02756 .06831 L
s
.02381 .08618 m
.02756 .08618 L
s
.02381 .12191 m
.02756 .12191 L
s
.02381 .13977 m
.02756 .13977 L
s
.02381 .15764 m
.02756 .15764 L
s
.02381 .1755 m
.02756 .1755 L
s
.02381 .21123 m
.02756 .21123 L
s
.02381 .2291 m
.02756 .2291 L
s
.02381 .24696 m
.02756 .24696 L
s
.02381 .26483 m
.02756 .26483 L
s
.02381 .30056 m
.02756 .30056 L
s
.02381 .31842 m
.02756 .31842 L
s
.02381 .33629 m
.02756 .33629 L
s
.02381 .35415 m
.02756 .35415 L
s
.02381 .38989 m
.02756 .38989 L
s
.02381 .40775 m
.02756 .40775 L
s
.02381 .42562 m
.02756 .42562 L
s
.02381 .44348 m
.02756 .44348 L
s
.02381 .47921 m
.02756 .47921 L
s
.02381 .49708 m
.02756 .49708 L
s
.02381 .51494 m
.02756 .51494 L
s
.02381 .53281 m
.02756 .53281 L
s
.02381 .56854 m
.02756 .56854 L
s
.02381 .5864 m
.02756 .5864 L
s
.02381 .60427 m
.02756 .60427 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.03968 .01488 L
.05556 .01562 L
.07143 .01716 L
.0873 .02006 L
.10317 .02542 L
.11905 .03522 L
.13492 .05296 L
.15079 .08422 L
.16667 .13461 L
.18254 .20091 L
.19841 .26528 L
.21429 .31619 L
.23016 .36094 L
.24603 .43214 L
.2619 .54195 L
.27778 .60332 L
.29365 .57446 L
.30952 .51724 L
.3254 .47161 L
.34127 .45509 L
.35714 .46579 L
.37302 .47697 L
.38889 .48823 L
.40476 .4995 L
.42063 .50382 L
.43651 .50557 L
.45238 .50308 L
.46825 .49907 L
.48413 .49101 L
.5 .47922 L
.51587 .46906 L
.53175 .45276 L
.54762 .43595 L
.56349 .43584 L
.57937 .4634 L
.59524 .51085 L
.61111 .55203 L
.62698 .56265 L
.64286 .55028 L
.65873 .52492 L
.6746 .50241 L
.69048 .48597 L
.70635 .48059 L
.72222 .48359 L
.7381 .48699 L
.75397 .48978 L
.76984 .49613 L
.78571 .50514 L
.80159 .52063 L
Mistroke
.81746 .53638 L
.83333 .53504 L
.84921 .52118 L
.86508 .50544 L
.88095 .4963 L
.89683 .4978 L
.9127 .50567 L
.92857 .50688 L
.94444 .49664 L
.96032 .48334 L
.97619 .47593 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00B_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgM
g@07ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003ok^k^oooo
o`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`Co000000?o410@ooooooooool02_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`Co000000?o410@ooooooooool01Ol00004ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000Go
410@ooooooooooooooooodA4A002o`000003oc8b<_oMgMgooooo00Kooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000onk^k_oo
ool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM007ooooo001:ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01oooool00omgMgOo<S8booooo`06ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`03ogMgMolb<S;ooooo00Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`0:ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool03?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00;ooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A007ooooo`03ogMgMolb<S;ooooo00Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1oooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`04ooooo`03oeEEEOnYZJWo
oooo00Oooooo0OmgMgL1oc8b<P7ooooo001:ooooo`05oa0@4?ooooooooooooooool@41002oooool0
1Ol@413ooooooooooooooooo410@00Cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003ooooooooo
o`05ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00So
oooo00?o0000ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooo
oooooooooooooa0@4005ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool02Oooool0
1Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool03?ooool01Ol@413ooooooooo
oooooooo410@00kooooo00?o0000ooooooooool00oooool00onHV9So8B4Qonk^kP09ooooo`03o`00
0?oooooooooo00Gooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000oooo
ooooool01?ooool00onYZJWoEEEEooooo`08ooooo`7o00000Oooool004[ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`05o`000?ooooooooooooooool000001Oooool00onHV9So8B4Qonk^kP07
ooooo`03ogMgMolb<S;ooooo00Kooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?oo
ooooooooooooool000001oooool00omgMgOo<S8booooo`06ooooo`05o`000?ooooooooooooooool0
00002oooool01Ol0003ooooooooooooooooo000000Kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`0:ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`0<
ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`04ooooo`03oiRHV?lQ
8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01_ooool01Ol0003ooooooooooooooooo000000kooooo
00?o0000ooooooooool01_ooool00omgMgOo<S8booooo`06ooooo`05o`000?ooooooooooooooool0
00003_ooool00ol0003oooooooooo`05ooooo`03ob4Q8Ooooooooooo00Kooooo0OmgMgL1oc8b<P7o
oooo001:ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo0000
00Kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Oooooo00Go0000
ooooooooooooooooo`00000;ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?oooooooooo
ooooool000001_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`02ooo
ool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool03?ooool01Ol0003ooooo
oooooooooooo000000kooooo00?o0000ooooooooool01Oooool00omgMgOoIVIVooooo`03ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000
ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Oooooo00Go0000oooooooooooooooo
o`00000>ooooo`03o`000?oooooooooo00Gooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<007ooooo001:ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o
oooooooooooooooo410@00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09oooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Cooooo00?o
0000ooooooooool02Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooo
oooooa0@4006ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool03Oooool01Ol@413o
oooooooooooooooo410@00kooooo00?o0000ooooooooool03?ooool01Ol@413ooooooooooooooooo
410@00kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Wooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0
1Oooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00?ooooo001:ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go0000okZj^_oo
ooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`09ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go410@oooooooo
oooooooooc8b<P04ooooo`03o`000?oooooooooo00gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>
ooooo`03o`000?oooooooooo00cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oo
oooooooo00;ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Wooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool00oooool004[ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01OnHV9So410@o`00
0?lQ8B7oc<c<00Cooooo1?l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Cooooo1?l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo1Ol00004ooooo`Co00003?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo00?oEEEEofIVI_l000001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00008oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`000005ooooo`Co00002?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001?ooool5o`0000Cooooo1?l0
0002ooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo000dooooo`03o`000?oooooooooo
0?oooooo<_ooool003Cooooo00?o0000ooooooooool0oooooolbooooo`00=?ooool00ol0003ooooo
ooooo`3ooooooc;ooooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool002goooooool0000h
o`0000Cooooo000dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03o`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool003Cooooo00?o0000oooooooo
ool04oooool3o`00013ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool04Oooool003Cooooo00?o0000ooooooooool0
5_ooool2o`000?oooooo6_ooool003Cooooo00?o0000ooooooooool06?ooool2o`000?oooooo6?oo
ool003Cooooo0_l0000Kooooo`03o`000?oooooooooo0?oooooo5Oooool003Cooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`3ooooooaCooooo000dooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool0oooooolDooooo`00=?ooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo0?oooooo4oooool003Cooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`3ooooooa;ooooo000dooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0oooooolB
ooooo`00=?ooool2o`0001oooooo00?o0000ooooooooool0oooooolAooooo`00=?ooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo0?oooooo4?ooool003Cooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`3ooooooa3ooooo000dooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool0ooooool?ooooo`00=?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo0?oooooo3oooool003Cooooo0_l0000Rooooo`03o`000?oooooooooo0?oooooo3_ooool003Co
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`3oooooo`gooooo000dooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool0ooooool=ooooo`00=?ooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo0?oooooo3?ooool003Cooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`3oooooo`cooooo000dooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool0ooooool;ooooo`00=?ooool2o`0002Gooooo00?o0000ooooooooool0ooooool;ooooo`00
=?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo0?oooooo2oooool003Cooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`3oooooo`[ooooo000:ooooo`05odA4A?l0003o
0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`3oooooo`[ooooo000=oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`3oooooo`[ooooo000>oooo
o`04o`000?oooooooooooa0@40?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oo
ooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooooooo
ool01?ooool3o`0002Kooooo00?o0000ooooooooool0ooooool9ooooo`003Oooool01OmgMgOo<S8b
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo0?oooooo2Oooool000[ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo0?oooooo2Oooool0
00[ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@
oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooo
oooooooooooo410@00Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`3oooooo`So
oooo000:ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0oooo
ool8ooooo`002_ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP06ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0ooooool8oooo
o`00=?ooool2o`0002Wooooo00?o0000ooooooooool0ooooool7ooooo`00=?ooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo0?oooooo1oooool003Cooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`3oooooo`Oooooo000dooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool0ooooool6ooooo`00=?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
0?oooooo1_ooool003Cooooo0_l0000Zooooo`03o`000?oooooooooo0?oooooo1_ooool003Cooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3oooooo`Kooooo000dooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool0ooooool5ooooo`00=?ooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo0?oooooo1Oooool003Cooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`3oooooo`Gooooo000dooooo`03o`000?oooooooooo02[ooooo00?o0000oooooooo
ool0ooooool5ooooo`00=?ooool2o`0002cooooo00?o0000ooooooooool0ooooool4ooooo`00=?oo
ool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo0?oooooo1?ooool003Cooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`3oooooo`Cooooo000dooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool0ooooool4ooooo`00=?ooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo0?oooooo0oooool003Cooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`3oooooo`?ooooo000dooooo`;o0000;Oooool00ol0003oooooooooo`3oooooo`?ooooo000d
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0ooooool3ooooo`00=?ooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo0?oooooo0_ooool000;ooooo1?l000002?l@413o
ooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`3o
ooooo`;ooooo0004ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo0?oooooo0_ooool000Cooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooooooooa0@4006ooooo`?o0000;Oooool00ol0003oooooooooo`3oooooo`;o
oooo0004ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo0?oooooo0Oooool000Cooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0oooo
ool1ooooo`001?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`3oooooo`7ooooo0004ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
0?oooooo0Oooool000;ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool0ooooool003Cooooo0_l0000`ooooo`03o`00
0?oooooooooo0?oooooo000dooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0oooo
ool003Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`3oooooo`00=?ooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo0?kooooo000dooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool0o_ooool003Cooooo0_l0000aooooo`03o`000?oooooooooo0?kooooo
000dooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0o_ooool003Cooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`3mooooo`00=?ooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo0?gooooo000dooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool0oOooool003Cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`3mooooo`00=?oo
ool2o`0003?ooooo00?o0000ooooooooool0o?ooool003Cooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`3looooo`00=?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
0?cooooo000dooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0o?ooool003Cooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`3kooooo`00=?ooool2o`0003Cooooo00?o
0000ooooooooool0noooool003Cooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`3k
ooooo`00=?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo0?_ooooo0002ooooo`Co
000000Go410@ooooooooooooooooodA4A002o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`3jooooo`001?ooool00ol0003oooooooooo`06ooooo`09ogMgMolb<S;ooooo
oooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`3jooooo`001?ooool00ol0003oooooooooo`07oooo
o`04o`000?oooooooooooa0@40?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oo
ooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooooooo
ool01?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo0?[ooooo0004ooooo`03o`00
0?oooooooooo00Kooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo00Cooooo0ol0000eooooo`03o`000?oooooooooo0?Wooooo0004
ooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo0?Wooooo0004ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Ko
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`3iooooo`001?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0n?oo
ool000;ooooo00?oEEEEofIVI_l000001Oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool0n?ooool003Cooooo0_l0000gooooo`03o`000?oooooooooo0?Sooooo000dooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool0moooool003Cooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`3gooooo`00=?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooo
oooo0?Oooooo000dooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0m_ooool003Co
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`3fooooo`00=?ooool2o`0003Wooooo
00?o0000ooooooooool0m_ooool003Cooooo00?o0000ooooooooool0>Oooool00ol0003ooooooooo
o`3eooooo`00=?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo0?Gooooo000doooo
o`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0mOooool003Cooooo00?o0000oooooooo
ool0>_ooool00ol0003oooooooooo`3dooooo`00=?ooool00ol0003oooooooooo`0jooooo`03o`00
0?oooooooooo0?Cooooo000dooooo`;o0000>oooool00ol0003oooooooooo`3dooooo`00=?ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo0??ooooo000dooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0loooool003Cooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`3cooooo`00=?ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo0?;ooooo
000dooooo`;o0000?Oooool00ol0003oooooooooo`3booooo`00=?ooool00ol0003oooooooooo`0l
ooooo`03o`000?oooooooooo0?;ooooo000dooooo`03o`000?oooooooooo03gooooo00?o0000oooo
ooooool0lOooool00003ooooool0003o000000?o00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool0lOooool00006oooooonHV9So8B4Qonk^k_oo
ooooA4A40oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo03gooooo00?o0000oooo
ooooool0lOooool000;ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool0l?ooool000?ooooo00?oV9RHob4Q8Oo^k^h0
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000?_ooool00ol0003oooooooooo`3`ooooo`001?oo
ool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`3`ooooo`001Oooool01Ol0003ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooo
oooo00Cooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`3`ooooo`0000Koooooo`00
0?nj^[[ooooooiRHV?l@4103ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`3`ooooo`0000KooooooiRHV?l@413o0000ob4Q8Oo<c<`3ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`3_ooooo`00=?oo
ool2o`00043ooooo00?o0000ooooooooool0koooool003Cooooo00?o0000ooooooooool0?oooool0
0ol0003oooooooooo`3_ooooo`00=?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
0>oooooo000dooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0k_ooool003Cooooo
00?o0000ooooooooool0@?ooool00ol0003oooooooooo`3^ooooo`00=?ooool00ol0003ooooooooo
o`10ooooo`03o`000?oooooooooo0>kooooo000dooooo`;o0000@Oooool00ol0003oooooooooo`3^
ooooo`00=?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo0>gooooo000dooooo`03
o`000?oooooooooo047ooooo00?o0000ooooooooool0kOooool003Cooooo00?o0000ooooooooool0
@Oooool00ol0003oooooooooo`3]ooooo`00=?ooool00ol0003oooooooooo`11ooooo`03o`000?oo
oooooooo0>gooooo000dooooo`;o0000@_ooool00ol0003oooooooooo`3]ooooo`00=?ooool00ol0
003oooooooooo`12ooooo`03o`000?oooooooooo0>cooooo000dooooo`03o`000?oooooooooo04;o
oooo00?o0000ooooooooool0k?ooool003Cooooo00?o0000ooooooooool0@_ooool00ol0003ooooo
ooooo`3/ooooo`00=?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo05_ooooo1_l0
002;ooooo`00=?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo05[ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`29ooooo`00=?ooool2o`0004Cooooo00?o0000oooo
ooooool0F?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08Sooooo000dooooo`03
o`000?oooooooooo04?ooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo08Oooooo000dooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0
E_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo08Oooooo00000ooooooo0000o`00
0003o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`13ooooo`03o`000?oo
oooooooo01[ooooo0_l0000iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Q_oo
ool00006oooooonHV9So8B4Qonk^k_ooooooA4A41oooool02OmgMgOo<S8booooooooooooMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo04?o
oooo00?o0000ooooooooool06_ooool00ol0003oooooo`00000gooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0Q_ooool000;ooooo00?oV9RHob4Q8Oo^k^h02Oooool01?l0003ooooo
ooooool@4103ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo
410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo0ol0
0013ooooo`03o`000?oooooooooo01Wooooo00Go0000ooooooooooooooooo`00000eooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool0QOooool000?ooooo00?oV9RHob4Q8Oo^k^h01ooo
ool01OmgMgOo<S8boooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0Q?ooool000Cooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo04Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`05oooo
o`;o0000<?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Cooooo0005ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0A?ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0:oooool2o`0001Cooooo
00?o0000ooooooooool0Poooool00006ooooool0003o^[ZjoooooonHV9So410@1?ooool00ol0003o
ooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Xooooo`;o00005_ooool00ol0003oooooooooo`23ooooo`0000Ko
oooooiRHV?l@413o0000ob4Q8Oo<c<`4ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0A?ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo00_ooooo0_l0000Wooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool0M_ooool2o`0000_ooooo000dooooo`;o0000AOooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool08_ooool2o`0001[ooooo00?o
0000ooooooooool08Oooool5o`0004cooooo0ol0000=ooooo`00=?ooool00ol0003oooooooooo`14
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool07_ooool3o`0000Gooooo1Ol00015
ooooo`;o00004?ooool003Cooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool02oooool5o`0003oooooo00?o0000oooo
ooooool04?ooool003Cooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo01;ooooo0_l0000Mooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Aooooo`?o0000>oooool00ol0003oooooooooo`0Aooooo`00
=?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
5?ooool2o`0001Wooooo0_l0000Pooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
5Oooool3o`0003Oooooo00?o0000ooooooooool04_ooool003Cooooo00?o0000ooooooooool0AOoo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool04ooo
ool3o`0002;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`;o00007ooo
ool5o`0000oooooo0_l0000Eooooo`00=?ooool2o`0004Kooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0Hooooo`;o00004?ooool3o`0002Kooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0Looooo`;o00006oooool2o`0000Gooooo0ol0000;ooooo`03o`000?oooooo
oooo01Gooooo000dooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Jooooo`?o00002?ooool5o`0002Wooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02?ooool3o`00
00Oooooo00?o0000ooooooooool05_ooool003Cooooo00?o0000ooooooooool0AOooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo01gooooo2?l0000^ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00co
oooo1?l00002ooooo`03o`000?oooooooooo01Oooooo000dooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo013ooooo
0_l0000Jooooo`00=?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool0EOooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0]ooooo`00=?ooool2o`0004Oooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02kooooo000doooo
o`03o`000?oooooooooo04Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Foooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo02oooooo000dooooo`03o`000?oooooooooo04Kooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`0;ooooo`;o0000<_ooool003Cooooo00?o0000ooooooooool0
A_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
<_ooool003Cooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo05Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0<oooool003Cooooo00?o0000ooooooooool0A_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=?ooool0
03Cooooo0_l00018ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0FOooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo033ooooo00Co0000oooooooooooooooo0ol0000g
ooooo`00=?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0F_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo037ooooo0ol0000joooo
o`00=?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0Foooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo06oooooo00001_ooooooV9RH
oa0@4?l0003o<S8bolc<c0?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`17oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo06oooooo00001_oooooo410@okZj^_ooooooMgMgoc8b<P?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01_ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0Foooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo073ooooo0005oooo
o`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@00?ooooo00?o410@ooooooooool01?ooool3o`0004Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo00Kooooo0_l0001coooo
o`001?ooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool0B?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05gooooo0_l00006ooooo`03
o`000?oooooooooo07?ooooo0003ooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
Goooool2o`0000?ooooo00?o0000ooooooooool0M?ooool000Cooooo00?o^[Zjob4Q8Oooool00_oo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@
oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`1Qooooo`03o`000?oooooo000007Oooooo00001_oooooo410@oiRHV?oo
oooo^[Zjo`0000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`19ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`1fooooo`0000Ko
ooooojVYZOl@413o0000oa0@4?nYZJT3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooooooo
ool0BOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0=cooooo000dooooo`;o0000
B_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0=cooooo000dooooo`03o`000?oo
oooooooo04Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3Mooooo`00=?ooool0
0ol0003oooooooooo`1:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0gOooool0
03Cooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
0=gooooo000dooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`3Nooooo`00=?ooool2o`0004_ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`3Nooooo`00=?ooool00ol0003oooooooooo`1;ooooo`05o`000?ooooooooooooooool00000
hOooool003Cooooo00?o0000ooooooooool0Boooool01?l0003oooooooooool0003Rooooo`00=?oo
ool00ol0003oooooooooo`1;ooooo`04o`000?ooooooooooo`000>;ooooo000dooooo`03o`000?oo
oooooooo04_ooooo00?o0000ooooool00000hoooool003Cooooo00?o0000ooooooooool0C?ooool2
o`000>?ooooo000dooooo`;o0000COooool00ol0003oooooooooo`3Rooooo`00=?ooool00ol0003o
ooooooooo`3ooooooc;ooooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Cooooo00?o
0000ooooooooool0oooooolbooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {221.375, 0}} -> {-0.0318924, -44107.6, \
0.000760081, 2251.07}}]
}, Open  ]],

Cell["\<\
\tAfter a rapid increase, the kinetic energy begins to fluctuate \
about some equilibrium value. Evidently, the heating of the gas results in an \
arrest of the collapse.  The outward thermal pressure of the gas can balance \
the gravitational attraction, allowing a steady state to be achieved. This \
steady state can be thought of as a crude approximation to the nebulae from \
which stars, planets, or galaxies might form. Loss of kinetic energy though \
various mechanisms that are not included in our simulation allows the \
collapse to continue in real clouds, until a compact object forms such as a \
star,  planet, or black hole. These loss mechanisms include the formation of \
collisional shock waves, radiation,  and evaporation (where hot particles \
achieve escape velocity and leave the cloud, lowering the average kinetic \
energy per particle of the remainder).\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Stability of a Hot Gas to Gravitational Collapse", "Section",
  CellTags->{"i:57", "c:38"}],

Cell[TextData[{
  " If a uniform gas is sufficiently hot initially, gravitational collapse \
does not occur, because the gas pressure can balance the force of gravity. \
One can see this in the simulation (Cells ",
  ButtonBox["7.87",
    ButtonData:>"Cell 7.87",
    ButtonStyle->"Hyperlink"],
  "-",
  ButtonBox["7.89",
    ButtonData:>"Cell 7.89",
    ButtonStyle->"Hyperlink"],
  ") by giving the particles large random initial velocities:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(m = 1; M = 10; 
    L = 1; \[CapitalDelta]x\  = \ \(\[CapitalDelta]y\  = \ 
        L/M\); \[CapitalDelta]t\  = \ 0.0015;\), "\n", 
    \(\(Clear[r, p];\)\), "\n", 
    \(\(r0\  = \ Table[{Random[], Random[]}, {1000}];\)\), "\n", 
    \(\(p0 = \ 
        Table[60 {Random[] -  .5, Random[] -  .5}, {1000}];\)\), "\n", 
    \(Timing[leapfrog[r0, p0, 60, \[CapitalDelta]t]]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.87"],

Cell[BoxData[
    \({32.27999999999999`\ Second, Null}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Table[
        ListPlot[r[n], PlotRange \[Rule] {{0, 1}, {0, 1}}, 
          AspectRatio \[Rule] 1], {n, 0, 60, 1}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.88"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.5339 .01956 Mdot
.81718 .57788 Mdot
.12948 .56504 Mdot
.58016 .71822 Mdot
.66256 .67852 Mdot
.86276 .05983 Mdot
.62546 .92713 Mdot
.90239 .74799 Mdot
.55237 .18317 Mdot
.16494 .88736 Mdot
.27606 .28216 Mdot
.32076 .19419 Mdot
.74216 .2626 Mdot
.50358 .6163 Mdot
.61268 .69756 Mdot
.92341 .89809 Mdot
.95012 .01904 Mdot
.06065 .83826 Mdot
.32466 .09191 Mdot
.15826 .09026 Mdot
.77228 .90874 Mdot
.99332 .20291 Mdot
.49622 .62658 Mdot
.67257 .00872 Mdot
.75406 .36398 Mdot
.16899 .39242 Mdot
.14138 .66641 Mdot
.24558 .49433 Mdot
.19127 .64737 Mdot
.18493 .65607 Mdot
.86661 .55546 Mdot
.02667 .56581 Mdot
.09433 .64672 Mdot
.03334 .3629 Mdot
.59811 .02014 Mdot
.36077 .35418 Mdot
.84405 .65616 Mdot
.19179 .96176 Mdot
.70266 .98975 Mdot
.94621 .46742 Mdot
.5114 .34238 Mdot
.76128 .81135 Mdot
.64479 .78692 Mdot
.73462 .24554 Mdot
.55046 .1402 Mdot
.70127 .88265 Mdot
.95235 .12006 Mdot
.3405 .52847 Mdot
.10831 .4639 Mdot
.14871 .56671 Mdot
.40564 .47416 Mdot
.20251 .09929 Mdot
.89424 .13178 Mdot
.44123 .28794 Mdot
.24945 .34486 Mdot
.70661 .0424 Mdot
.69899 .20466 Mdot
.00534 .15975 Mdot
.74664 .08459 Mdot
.66484 .63128 Mdot
.63833 .62069 Mdot
.51612 .06456 Mdot
.23269 .14654 Mdot
.31362 .96527 Mdot
.33845 .01476 Mdot
.87239 .67733 Mdot
.08899 .6699 Mdot
.16578 .63494 Mdot
.39 .46524 Mdot
.16044 .47519 Mdot
.64336 .38065 Mdot
.49561 .84391 Mdot
.00503 .75996 Mdot
.97948 .77935 Mdot
.77234 .61342 Mdot
.66587 .81408 Mdot
.4339 .59866 Mdot
.79348 .13674 Mdot
.3449 .92876 Mdot
.62769 .5018 Mdot
.9549 .46352 Mdot
.46725 .02661 Mdot
.31154 .08287 Mdot
.97164 .1827 Mdot
.30651 .32292 Mdot
.99216 .40336 Mdot
.53416 .70949 Mdot
.32629 .58928 Mdot
.10027 .11083 Mdot
.53281 .45254 Mdot
.75536 .18207 Mdot
.90512 .95073 Mdot
.80046 .71855 Mdot
.43787 .92412 Mdot
.48892 .63568 Mdot
.46623 .74142 Mdot
.18242 .31276 Mdot
.47407 .33806 Mdot
.64825 .60327 Mdot
.14778 .74878 Mdot
.54799 .49243 Mdot
.61497 .29624 Mdot
.79262 .31036 Mdot
.70985 .34551 Mdot
.99216 .59182 Mdot
.27198 .42139 Mdot
.50324 .95614 Mdot
.80575 .67997 Mdot
.32082 .64338 Mdot
.33168 .34191 Mdot
.67257 .04011 Mdot
.1839 .59313 Mdot
.12459 .54768 Mdot
.56893 .29688 Mdot
.33196 .23731 Mdot
.85908 .95137 Mdot
.3398 .6455 Mdot
.5871 .52998 Mdot
.83656 .68936 Mdot
.78135 .85001 Mdot
.51574 .04598 Mdot
.44968 .5081 Mdot
.84316 .00587 Mdot
.26578 .91497 Mdot
.71858 .45819 Mdot
.69685 .61809 Mdot
.38661 .22088 Mdot
.83777 .66671 Mdot
.04681 .57538 Mdot
.25067 .13673 Mdot
.21025 .88602 Mdot
.46932 .28672 Mdot
.69452 .84004 Mdot
.01964 .77862 Mdot
.85135 .83417 Mdot
.75386 .86365 Mdot
.13277 .37597 Mdot
.05701 .24557 Mdot
.74616 .1551 Mdot
.21924 .57885 Mdot
.69935 .57972 Mdot
.96857 .44212 Mdot
.48909 .6937 Mdot
.49925 .1554 Mdot
.79458 .85366 Mdot
.47961 .37677 Mdot
.94322 .01949 Mdot
.72575 .51312 Mdot
.81045 .64351 Mdot
.66874 .26755 Mdot
.06429 .48842 Mdot
.4495 .6887 Mdot
.36495 .9087 Mdot
.48093 .24658 Mdot
.87585 .21501 Mdot
.98168 .09119 Mdot
.08128 .36135 Mdot
.50207 .71442 Mdot
.13805 .34186 Mdot
.77632 .2013 Mdot
.3276 .69835 Mdot
.10758 .93374 Mdot
.26331 .20993 Mdot
.65808 .24504 Mdot
.89836 .30122 Mdot
.17715 .99846 Mdot
.02251 .08622 Mdot
.19548 .90727 Mdot
.94124 .72487 Mdot
.69341 .19285 Mdot
.80318 .383 Mdot
.91709 .99155 Mdot
.47558 .68466 Mdot
.80951 .05781 Mdot
.21228 .47473 Mdot
.15143 .81277 Mdot
.31391 .1735 Mdot
.97428 .81431 Mdot
.2914 .08729 Mdot
.77881 .90704 Mdot
.35017 .36242 Mdot
.0854 .71419 Mdot
.54698 .97942 Mdot
.1683 .72264 Mdot
.0714 .29476 Mdot
.35879 .66483 Mdot
.85912 .82003 Mdot
.20736 .85206 Mdot
.54521 .64653 Mdot
.23307 .03776 Mdot
.25381 .55924 Mdot
.45427 .13072 Mdot
.90364 .19682 Mdot
.36887 .41653 Mdot
.35666 .2174 Mdot
.20056 .69389 Mdot
.28527 .92264 Mdot
.84177 .02906 Mdot
.42615 .1026 Mdot
.63442 .177 Mdot
.88094 .45607 Mdot
.40134 .13924 Mdot
.62713 .89683 Mdot
.94708 .00852 Mdot
.72348 .70001 Mdot
.57821 .59199 Mdot
.36682 .48261 Mdot
.37765 .8981 Mdot
.08155 .55997 Mdot
.53587 .86904 Mdot
.65541 .45737 Mdot
.90145 .69205 Mdot
.77447 .00129 Mdot
.50011 .55281 Mdot
.14734 .10446 Mdot
.55303 .54429 Mdot
.42386 .40445 Mdot
.97482 .95229 Mdot
.05704 .92184 Mdot
.59718 .05419 Mdot
.97549 .36187 Mdot
.06131 .18514 Mdot
.32008 .90451 Mdot
.15985 .49309 Mdot
.5456 .90322 Mdot
.65974 .94028 Mdot
.39826 .79875 Mdot
.10671 .39599 Mdot
.9744 .3943 Mdot
.13189 .4437 Mdot
.91736 .47246 Mdot
.53471 .38951 Mdot
.94187 .11059 Mdot
.47341 .20437 Mdot
.6218 .20608 Mdot
.31356 .71127 Mdot
.07619 .30287 Mdot
.65381 .77099 Mdot
.67793 .50411 Mdot
.5471 .375 Mdot
.70353 .10981 Mdot
.41521 .93129 Mdot
.78617 .63735 Mdot
.88049 .54178 Mdot
.8443 .52676 Mdot
.40709 .33741 Mdot
.2225 .32067 Mdot
.09353 .62614 Mdot
.14631 .01781 Mdot
.43971 .85515 Mdot
.46838 .51369 Mdot
.89261 .48016 Mdot
.76484 .40388 Mdot
.4774 .54886 Mdot
.97867 .76654 Mdot
.59691 .00708 Mdot
.13437 .23978 Mdot
.18982 .66966 Mdot
.91187 .9191 Mdot
.0963 .04352 Mdot
.76556 .9013 Mdot
.65658 .18837 Mdot
.29719 .3876 Mdot
.76397 .70822 Mdot
.53234 .98372 Mdot
.28656 .15935 Mdot
.55367 .21718 Mdot
.68965 .15228 Mdot
.4193 .97741 Mdot
.49983 .48261 Mdot
.50743 .0583 Mdot
.40353 .43909 Mdot
.74187 .157 Mdot
.74695 .25072 Mdot
.44469 .7694 Mdot
.98299 .5425 Mdot
.91234 .78568 Mdot
.69643 .38315 Mdot
.35867 .5685 Mdot
.00677 .23087 Mdot
.93937 .59109 Mdot
.50694 .74826 Mdot
.43193 .53279 Mdot
.10341 .30917 Mdot
.69006 .37578 Mdot
.35645 .05846 Mdot
.24537 .60638 Mdot
.37347 .51595 Mdot
.33303 .8207 Mdot
.67704 .13281 Mdot
.97436 .25221 Mdot
.67027 .90193 Mdot
.03499 .66112 Mdot
.16332 .15367 Mdot
.60306 .12833 Mdot
.05992 .8445 Mdot
.913 .75255 Mdot
.70346 .78605 Mdot
.66763 .14616 Mdot
.33 .27009 Mdot
.3346 .32546 Mdot
.65296 .13729 Mdot
.36024 .07325 Mdot
.98269 .23535 Mdot
.32525 .41213 Mdot
.81936 .08168 Mdot
.72219 .2838 Mdot
.75945 .23718 Mdot
.80919 .53126 Mdot
.05598 .45113 Mdot
.14156 .38509 Mdot
.72599 .18104 Mdot
.80696 .05964 Mdot
.07303 .04375 Mdot
.44672 .98639 Mdot
.09034 .8084 Mdot
.12147 .57425 Mdot
.27098 .72672 Mdot
.39928 .29045 Mdot
.51153 .48954 Mdot
.59009 .7592 Mdot
.45555 .03841 Mdot
.44854 .3741 Mdot
.72956 .85737 Mdot
.64158 .31447 Mdot
.65653 .81362 Mdot
.19486 .32808 Mdot
.56618 .00522 Mdot
.07339 .75383 Mdot
.29521 .2785 Mdot
.67411 .46337 Mdot
.78368 .78895 Mdot
.08402 .70418 Mdot
.32813 .75054 Mdot
.63548 .33007 Mdot
.59857 .89317 Mdot
.9939 .01561 Mdot
.94205 .07955 Mdot
.79904 .68752 Mdot
.37586 .07433 Mdot
.72565 .9337 Mdot
.08066 .79583 Mdot
.05154 .47032 Mdot
.29698 .00688 Mdot
.96752 .76614 Mdot
.96885 .25634 Mdot
.33204 .43607 Mdot
.37028 .36317 Mdot
.33814 .42046 Mdot
.42823 .28362 Mdot
.5391 .73294 Mdot
.05236 .20929 Mdot
.81345 .79925 Mdot
.97171 .41345 Mdot
.76191 .32893 Mdot
.67473 .40658 Mdot
.79439 .56278 Mdot
.70588 .15024 Mdot
.46235 .12671 Mdot
.3356 .78707 Mdot
.12421 .70625 Mdot
.90737 .50346 Mdot
.58511 .97331 Mdot
.85501 .29417 Mdot
.77166 .17406 Mdot
.8833 .88071 Mdot
.00975 .84513 Mdot
.20858 .47414 Mdot
.21536 .28235 Mdot
.5027 .3239 Mdot
.75301 .15564 Mdot
.1671 .53682 Mdot
.6288 .44939 Mdot
.25973 .03337 Mdot
.04369 .47608 Mdot
.40472 .7392 Mdot
.27203 .30202 Mdot
.52141 .85849 Mdot
.26228 .45689 Mdot
.31284 .38435 Mdot
.04692 .17454 Mdot
.81013 .06045 Mdot
.29391 .0189 Mdot
.64303 .52363 Mdot
.66511 .56951 Mdot
.3833 .49026 Mdot
.62142 .09342 Mdot
.97858 .75106 Mdot
.34939 .7914 Mdot
.45717 .89257 Mdot
.08711 .33451 Mdot
.14433 .50822 Mdot
.04019 .15998 Mdot
.3342 .44777 Mdot
.74628 .14108 Mdot
.69117 .92414 Mdot
.08117 .57157 Mdot
.30786 .43388 Mdot
.45975 .47815 Mdot
.32928 .68282 Mdot
.11036 .68674 Mdot
.87211 .79024 Mdot
.02324 .35223 Mdot
.72778 .28202 Mdot
.98305 .19225 Mdot
.39358 .83425 Mdot
.23676 .05118 Mdot
.70241 .91011 Mdot
.15559 .47961 Mdot
.39454 .47623 Mdot
.69584 .00146 Mdot
.06526 .79341 Mdot
.58548 .31472 Mdot
.19315 .00316 Mdot
.56224 .96249 Mdot
.46538 .72114 Mdot
.57919 .77023 Mdot
.0718 .88689 Mdot
.34243 .71905 Mdot
.36939 .97679 Mdot
.18684 .23945 Mdot
.97484 .50056 Mdot
.491 .23799 Mdot
.90958 .70715 Mdot
.90551 .92327 Mdot
.71643 .70399 Mdot
.34327 .96079 Mdot
.25105 .98285 Mdot
.76408 .19056 Mdot
.17925 .09595 Mdot
.42165 .4715 Mdot
.80986 .11916 Mdot
.23481 .23205 Mdot
.83502 .6186 Mdot
.74382 .99407 Mdot
.92544 .91145 Mdot
.8383 .0708 Mdot
.20901 .20746 Mdot
.49503 .11001 Mdot
.95796 .22462 Mdot
.73096 .91946 Mdot
.77871 .12866 Mdot
.30931 .44795 Mdot
.96885 .0095 Mdot
.0745 .2159 Mdot
.13383 .3909 Mdot
.33068 .22183 Mdot
.2084 .47945 Mdot
.49238 .15104 Mdot
.99939 .27199 Mdot
.99734 .04102 Mdot
.04143 .04737 Mdot
.26638 .12157 Mdot
.26272 .91871 Mdot
.95708 .67361 Mdot
.29387 .90921 Mdot
.88258 .45771 Mdot
.16004 .51831 Mdot
.5519 .23588 Mdot
.95164 .03886 Mdot
.05953 .08485 Mdot
.95226 .76687 Mdot
.06218 .04382 Mdot
.91083 .7195 Mdot
.7958 .92225 Mdot
.64811 .80079 Mdot
.83872 .24864 Mdot
.35424 .89158 Mdot
.95614 .79092 Mdot
.1942 .37327 Mdot
.40424 .55504 Mdot
.24255 .33441 Mdot
.34472 .4702 Mdot
.29029 .56754 Mdot
.28253 .42637 Mdot
.37947 .84805 Mdot
.48673 .50412 Mdot
.73136 .04726 Mdot
.64801 .25549 Mdot
.37712 .15568 Mdot
.69186 .46456 Mdot
.18292 .7824 Mdot
.28762 .90952 Mdot
.94037 .44799 Mdot
.9429 .43933 Mdot
.65008 .88045 Mdot
.66037 .01295 Mdot
.27061 .0324 Mdot
.17364 .50883 Mdot
.53926 .98514 Mdot
.52563 .25334 Mdot
.16213 .82947 Mdot
.83377 .78878 Mdot
.97921 .04706 Mdot
.54614 .87926 Mdot
.03884 .59907 Mdot
.60324 .43993 Mdot
.38876 .71862 Mdot
.94287 .42698 Mdot
.11815 .68622 Mdot
.76923 .91815 Mdot
.57889 .70108 Mdot
.2436 .66481 Mdot
.41676 .87161 Mdot
.40984 .87603 Mdot
.43755 .82455 Mdot
.86369 .99677 Mdot
.39871 .22548 Mdot
.26045 .55684 Mdot
.00995 .50686 Mdot
.31758 .12986 Mdot
.8918 .82064 Mdot
.54835 .2117 Mdot
.31291 .11956 Mdot
.30475 .54689 Mdot
.89615 .24795 Mdot
.89491 .67087 Mdot
.45861 .42339 Mdot
.03122 .6741 Mdot
.0599 .19791 Mdot
.77077 .11726 Mdot
.04995 .69105 Mdot
.45319 .9874 Mdot
.15815 .87041 Mdot
.90484 .7757 Mdot
.84524 .75085 Mdot
.60009 .22881 Mdot
.94908 .50291 Mdot
.70518 .55794 Mdot
.49047 .07951 Mdot
.67396 .88384 Mdot
.43057 .8816 Mdot
.90319 .76658 Mdot
.38062 .19055 Mdot
.45 .77918 Mdot
.22247 .32014 Mdot
.54516 .00348 Mdot
.37724 .56929 Mdot
.94506 .77467 Mdot
.42815 .06638 Mdot
.23988 .21673 Mdot
.93768 .98687 Mdot
.56593 .33289 Mdot
.50711 .10527 Mdot
.66274 .56631 Mdot
.12649 .91471 Mdot
.21275 .78713 Mdot
.90401 .59457 Mdot
.66759 .78365 Mdot
.52678 .02528 Mdot
.72253 .00898 Mdot
.09862 .9589 Mdot
.48264 .79225 Mdot
.16094 .97203 Mdot
.91671 .45936 Mdot
.65384 .86677 Mdot
.25397 .89306 Mdot
.52735 .95205 Mdot
.04123 .10593 Mdot
.62334 .35748 Mdot
.37364 .32228 Mdot
.09656 .33219 Mdot
.65111 .31329 Mdot
.99794 .37329 Mdot
.16847 .52104 Mdot
.83699 .40126 Mdot
.25175 .06168 Mdot
.18316 .53449 Mdot
.99778 .16862 Mdot
.65581 .58244 Mdot
.95655 .06269 Mdot
.03247 .22496 Mdot
.58292 .74042 Mdot
.93591 .89277 Mdot
.93181 .42712 Mdot
.93797 .51948 Mdot
.76334 .90608 Mdot
.10098 .11822 Mdot
.51159 .8444 Mdot
.91782 .58373 Mdot
.51381 .67578 Mdot
.26201 .00129 Mdot
.55725 .61308 Mdot
.22954 .77632 Mdot
.97434 .87266 Mdot
.29363 .88355 Mdot
.04253 .44554 Mdot
.35565 .36407 Mdot
.27919 .53946 Mdot
.25467 .24585 Mdot
.7676 .69506 Mdot
.33685 .66212 Mdot
.25379 .01929 Mdot
.07484 .66083 Mdot
.69654 .40621 Mdot
.8453 .8845 Mdot
.7222 .53354 Mdot
.55167 .00095 Mdot
.67968 .088 Mdot
.19602 .63688 Mdot
.40049 .54854 Mdot
.94134 .39104 Mdot
.63289 .85347 Mdot
.60449 .72892 Mdot
.3791 .83419 Mdot
.52965 .06809 Mdot
.68256 .42798 Mdot
.68435 .18359 Mdot
.96035 .89444 Mdot
.13267 .18264 Mdot
.28068 .80643 Mdot
.93665 .54576 Mdot
.88019 .2579 Mdot
.99531 .15472 Mdot
.2473 .40442 Mdot
.39082 .4258 Mdot
.8682 .57024 Mdot
.86117 .35771 Mdot
.18564 .14226 Mdot
.17683 .17411 Mdot
.22529 .24782 Mdot
.04415 .99148 Mdot
.94461 .44139 Mdot
.1075 .44572 Mdot
.06442 .18349 Mdot
.11219 .291 Mdot
.81712 .77907 Mdot
.72137 .8652 Mdot
.94892 .20883 Mdot
.8602 .50749 Mdot
.76328 .06657 Mdot
.68337 .33338 Mdot
.538 .81875 Mdot
.63922 .3419 Mdot
.59339 .37736 Mdot
.53172 .89618 Mdot
.52897 .19387 Mdot
.41952 .60519 Mdot
.71185 .4148 Mdot
.69815 .73999 Mdot
.76293 .20597 Mdot
.83795 .2325 Mdot
.99964 .1394 Mdot
.15458 .89912 Mdot
.46165 .32064 Mdot
.51536 .55722 Mdot
.86826 .94328 Mdot
.98364 .66104 Mdot
.33929 .74941 Mdot
.56412 .05585 Mdot
.62744 .3346 Mdot
.86597 .31586 Mdot
.86451 .12863 Mdot
.02802 .08337 Mdot
.86486 .98923 Mdot
.87344 .18424 Mdot
.40322 .66859 Mdot
.35808 .62702 Mdot
.53496 .72531 Mdot
.37443 .96598 Mdot
.19567 .9759 Mdot
.81031 .91013 Mdot
.56824 .6413 Mdot
.94435 .59426 Mdot
.70373 .51267 Mdot
.91633 .5109 Mdot
.83886 .52343 Mdot
.04289 .32665 Mdot
.43565 .85484 Mdot
.68482 .69963 Mdot
.90069 .12953 Mdot
.31038 .73365 Mdot
.70501 .15363 Mdot
.50007 .82352 Mdot
.13678 .51233 Mdot
.55572 .22926 Mdot
.43305 .99966 Mdot
.63939 .71836 Mdot
.59419 .47623 Mdot
.5965 .3917 Mdot
.15854 .62138 Mdot
.91168 .69207 Mdot
.25785 .49185 Mdot
.6013 .95842 Mdot
.55284 .33822 Mdot
.10123 .1349 Mdot
.41606 .82589 Mdot
.54551 .90564 Mdot
.98301 .82622 Mdot
.90611 .18729 Mdot
.38883 .35 Mdot
.30961 .79558 Mdot
.23029 .72862 Mdot
.39793 .10351 Mdot
.97244 .23677 Mdot
.79663 .14509 Mdot
.4196 .89855 Mdot
.6954 .01019 Mdot
.00353 .07267 Mdot
.14989 .10455 Mdot
.02052 .24644 Mdot
.24377 .91726 Mdot
.63169 .89645 Mdot
.93416 .12168 Mdot
.4014 .16783 Mdot
.53623 .01817 Mdot
.42897 .93106 Mdot
.7396 .87308 Mdot
.00937 .03251 Mdot
.0442 .86289 Mdot
.00584 .95984 Mdot
.89431 .75834 Mdot
.98532 .71339 Mdot
.65054 .84108 Mdot
.35362 .81695 Mdot
.71638 .7194 Mdot
.95222 .64912 Mdot
.18015 .70123 Mdot
.52325 .71806 Mdot
.44055 .82816 Mdot
.51388 .68555 Mdot
.39635 .96527 Mdot
.50804 .72571 Mdot
.50203 .20692 Mdot
.52273 .01232 Mdot
.85149 .36584 Mdot
.1691 .19537 Mdot
.13512 .64644 Mdot
.21688 .54626 Mdot
.95497 .9452 Mdot
.69363 .8282 Mdot
.51442 .11705 Mdot
.17975 .14265 Mdot
.11807 .15178 Mdot
.6717 .41694 Mdot
.61604 .94486 Mdot
.14898 .40462 Mdot
.76454 .57902 Mdot
.97987 .20924 Mdot
.62943 .93258 Mdot
.76299 .66298 Mdot
.67446 .98737 Mdot
.06936 .83478 Mdot
.16004 .87033 Mdot
.88961 .69213 Mdot
.04197 .71855 Mdot
.2179 .27519 Mdot
.42594 .77369 Mdot
.06893 .87058 Mdot
.66139 .19467 Mdot
.08906 .66134 Mdot
.03197 .2621 Mdot
.32607 .99835 Mdot
.35751 .27472 Mdot
.25671 .16357 Mdot
.19746 .40439 Mdot
.3671 .47144 Mdot
.15549 .68585 Mdot
.1492 .19625 Mdot
.72955 .91216 Mdot
.08027 .32567 Mdot
.06816 .71748 Mdot
.99121 .66433 Mdot
.03619 .45539 Mdot
.66515 .66598 Mdot
.67869 .18067 Mdot
.40844 .5024 Mdot
.48122 .77627 Mdot
.04134 .03096 Mdot
.32573 .09043 Mdot
.89214 .83471 Mdot
.59618 .17827 Mdot
.81187 .50904 Mdot
.52802 .46079 Mdot
.82066 .84471 Mdot
.49182 .0054 Mdot
.15551 .17873 Mdot
.81314 .82473 Mdot
.74707 .67633 Mdot
.33191 .04846 Mdot
.70574 .64537 Mdot
.00618 .95804 Mdot
.8136 .81065 Mdot
.41 .77977 Mdot
.00172 .30161 Mdot
.88198 .31898 Mdot
.18106 .4569 Mdot
.39016 .31358 Mdot
.02555 .27816 Mdot
.57702 .48885 Mdot
.27848 .60184 Mdot
.24511 .44039 Mdot
.57274 .95647 Mdot
.23893 .48235 Mdot
.75914 .14582 Mdot
.82892 .70258 Mdot
.75742 .84421 Mdot
.94694 .3836 Mdot
.57636 .38731 Mdot
.55678 .07002 Mdot
.5508 .10915 Mdot
.97976 .58117 Mdot
.27233 .50732 Mdot
.73465 .14078 Mdot
.69959 .55085 Mdot
.49572 .65843 Mdot
.94044 .40503 Mdot
.6668 .95585 Mdot
.18302 .56082 Mdot
.71986 .57225 Mdot
.60667 .1735 Mdot
.16308 .50224 Mdot
.05586 .06435 Mdot
.18333 .92107 Mdot
.78354 .55704 Mdot
.44868 .78029 Mdot
.08395 .00619 Mdot
.95296 .12186 Mdot
.14351 .60116 Mdot
.28616 .16601 Mdot
.96048 .04035 Mdot
.5663 .59375 Mdot
.35382 .86684 Mdot
.40322 .09151 Mdot
.29796 .80249 Mdot
.21989 .17044 Mdot
.51442 .24545 Mdot
.77121 .39015 Mdot
.43047 .23926 Mdot
.81826 .26829 Mdot
.28697 .6381 Mdot
.5321 .10229 Mdot
.32648 .59775 Mdot
.9658 .50854 Mdot
.97267 .7309 Mdot
.56258 .41702 Mdot
.67471 .92841 Mdot
.34268 .24658 Mdot
.16029 .68296 Mdot
.57147 .85643 Mdot
.72982 .4437 Mdot
.75321 .58814 Mdot
.44285 .8056 Mdot
.22112 .48585 Mdot
.11637 .20785 Mdot
.25532 .97732 Mdot
.1437 .47695 Mdot
.69275 .56029 Mdot
.46899 .54853 Mdot
.35006 .31371 Mdot
.3087 .86557 Mdot
.77859 .45728 Mdot
.57889 .42188 Mdot
.02538 .86914 Mdot
.13604 .61628 Mdot
.80426 .38329 Mdot
.01967 .40843 Mdot
.54894 .40598 Mdot
.87597 .93148 Mdot
.85619 .84568 Mdot
.40697 .38295 Mdot
.50613 .53197 Mdot
.09827 .51737 Mdot
.72754 .07469 Mdot
.51939 .0955 Mdot
.70216 .20555 Mdot
.38335 .47922 Mdot
.8979 .82226 Mdot
.36368 .07079 Mdot
.34897 .41628 Mdot
.48772 .13931 Mdot
.49277 .5706 Mdot
.08074 .75637 Mdot
.98664 .03862 Mdot
.98247 .23899 Mdot
.2591 .96393 Mdot
.46309 .1435 Mdot
.55694 .75838 Mdot
.07973 .66428 Mdot
.65904 .93612 Mdot
.71605 .59349 Mdot
.31007 .51984 Mdot
.22833 .45418 Mdot
.8173 .94925 Mdot
.14759 .69781 Mdot
.83065 .91063 Mdot
.16512 .45881 Mdot
.57155 .9467 Mdot
.70203 .31532 Mdot
.01461 .18832 Mdot
.6223 .65104 Mdot
.35557 .25219 Mdot
.90625 .05755 Mdot
.0455 .73235 Mdot
.67791 .60337 Mdot
.2282 .7831 Mdot
.53032 .90556 Mdot
.39755 .87248 Mdot
.3652 .44675 Mdot
.826 .92578 Mdot
.66317 .13143 Mdot
.81139 .73746 Mdot
.04087 .4804 Mdot
.45582 .48527 Mdot
.13462 .42285 Mdot
.41032 .75292 Mdot
.45671 .81948 Mdot
.18211 .96982 Mdot
.92639 .91391 Mdot
.78456 .09734 Mdot
.56118 .46716 Mdot
.95856 .17156 Mdot
.89801 .33573 Mdot
.14717 .43409 Mdot
.85714 .85534 Mdot
.69135 .94882 Mdot
.72251 .43249 Mdot
.28103 .19591 Mdot
.26581 .61301 Mdot
.09892 .22609 Mdot
.33942 .6991 Mdot
.31435 .12875 Mdot
.77824 .23193 Mdot
.35579 .95719 Mdot
.88023 .8962 Mdot
.20863 .5231 Mdot
.02309 .04086 Mdot
.51728 .57427 Mdot
.30058 .60838 Mdot
.23625 .37837 Mdot
.03477 .99537 Mdot
.13733 .15228 Mdot
.69535 .29627 Mdot
.82298 .02353 Mdot
.91711 .06434 Mdot
.46718 .06633 Mdot
.03688 .16814 Mdot
.25856 .54323 Mdot
.01379 .12728 Mdot
.74128 .96896 Mdot
.71321 .5189 Mdot
.50503 .59059 Mdot
.67844 .52354 Mdot
.3677 .43831 Mdot
.98308 .22726 Mdot
.54472 .41479 Mdot
.06597 .16292 Mdot
.07754 .34845 Mdot
.02909 .99478 Mdot
.81899 .80522 Mdot
.0153 .8675 Mdot
.07771 .83626 Mdot
.30208 .34859 Mdot
.57268 .24567 Mdot
.62365 .82506 Mdot
.20498 .80735 Mdot
.64056 .59779 Mdot
.66025 .39257 Mdot
.57459 .43487 Mdot
.58271 .04411 Mdot
.54551 .44009 Mdot
.76373 .23889 Mdot
.53021 .57259 Mdot
.68602 .40263 Mdot
.22813 .224 Mdot
.11334 .15697 Mdot
.60448 .39894 Mdot
.90836 .34961 Mdot
.96392 .80115 Mdot
.24811 .95704 Mdot
.38933 .36628 Mdot
.6654 .91293 Mdot
.84382 .92619 Mdot
.90167 .67404 Mdot
.31361 .3536 Mdot
.21565 .2714 Mdot
.08548 .1296 Mdot
.10231 .11443 Mdot
.481 .73066 Mdot
.19395 .76482 Mdot
.51708 .92951 Mdot
.94584 .80778 Mdot
.12775 .56324 Mdot
.28045 .89485 Mdot
.28393 .63705 Mdot
.37878 .22081 Mdot
.97033 .28345 Mdot
.16312 .94941 Mdot
.88485 .15385 Mdot
.06081 .83498 Mdot
.40386 .42319 Mdot
.86685 .07016 Mdot
.88678 .49368 Mdot
.92101 .26238 Mdot
.75903 .93044 Mdot
.64056 .36753 Mdot
.47509 .29339 Mdot
.26179 .14671 Mdot
.50476 .00994 Mdot
.09867 .1973 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_o
oooo0_l000000ooooooo0000ooooo`0>ooooo`03o`000?oooooooooo00;o00002oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo1?l0000?ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool02oooool3o`0000oooooo00?o0000ooooooooool01Oooool2o`0000Oo
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Oooooo0_l00004ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool02oooool2o`000003ooooool0003ooooo00kooooo00?o0000ooooooooool0
2oooool3o`0000oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00[ooooo0_l000000ooooooo0000ooooo`0<ooooo`?o00001?ooool2o`0000Sooooo
0ol0000?ooooo`03o`000?oooooooooo00_ooooo0ol0000?ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool02_ooool2o`000003ooooool0003ooooo00kooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo000Nooooo`03o`000?oo
oooooooo01Oooooo0_l00013ooooo`;o0000?_ooool2o`0000;ooooo0_l0000Booooo`;o00002?oo
ool2o`0001Oooooo0_l00005ooooo`;o00001oooool2o`0002Gooooo0_l0000Pooooo`;o00001Ooo
ool2o`0000kooooo000Nooooo`03o`000?oooooooooo0:3ooooo0_l00004ooooo`;o0000:oooool2
o`0000;ooooo0_l00005ooooo`;o00001oooool2o`0004Oooooo0_l00005ooooo`;o00003_ooool0
01kooooo00?o0000ooooooooool0J_ooool2o`0003[ooooo0_l0000[ooooo`;o0000J_ooool2o`00
00Kooooo000Nooooo`03o`000?oooooooooo02_ooooo0_l0000Qooooo`;o00002oooool2o`0000go
oooo0_l0000mooooo`?o0000Poooool4o`0000cooooo0_l00006ooooo`007_ooool00ol0003ooooo
ooooo`0[ooooo`;o00008Oooool2o`0000_ooooo0_l0001<ooooo`?o00004_ooool2o`0006oooooo
1?l0000Dooooo`007_ooool00ol0003oooooooooo`2Wooooo`;o00005Oooool2o`0004Oooooo0_l0
000nooooo`007_ooool00ol0003oooooooooo`2Dooooo`;o00004Oooool2o`0005kooooo0_l00005
ooooo`;o0000=oooool001kooooo00?o0000ooooooooool02Oooool2o`0008Wooooo0_l0001hoooo
o`;o0000=oooool001kooooo00Co0000ooooool0003o00002?ooool2o`0004Gooooo0_l00002oooo
o`;o0000lOooool001kooooo00Co0000ooooool0003o0000Aoooool2o`0000Kooooo0_l00002oooo
o`;o0000lOooool001kooooo00?o0000ooooooooool00oooool2o`0004?ooooo0_l00016ooooo`;o
0000AOooool2o`0005Sooooo0_l000000ooooooo0000o`000007ooooo`;o000000?oooooo`000?l0
00001Oooool001kooooo00?o0000ooooooooool00oooool2o`0000_ooooo0_l00002ooooo`;o0000
1Oooool2o`0007?ooooo0_l0000Wooooo`;o00007?ooool2o`0000Wooooo0_l0001=ooooo`;o0000
00?oooooo`000?l000001oooool2o`000003ooooool0003o000000Gooooo000Nooooo`03o`000?oo
oooooooo00Wooooo0_l00005ooooo`;o00000_ooool2o`0000Gooooo0_l00027ooooo`;o00004ooo
ool2o`0002Oooooo0_l00006ooooo`;o0000C_ooool2o`0000_ooooo000Nooooo`03o`000?oooooo
oooo00Wooooo0_l0001Mooooo`;o0000>_ooool2o`0004Cooooo0_l0001>ooooo`;o00002oooool0
01kooooo0_l0001:ooooo`;o00007Oooool2o`000=gooooo000Nooooo`03o`000?oooooooooo04Wo
oooo0_l0001Xooooo`;o00002Oooool2o`0008Oooooo000Nooooo`03o`000?oooooooooo073ooooo
0_l0000_ooooo`;o00004?ooool2o`0000Wooooo0_l00012ooooo`?o00003oooool2o`0000gooooo
0_l0000Rooooo`007_ooool00ol0003oooooooooo`1>ooooo`;o00008?ooool2o`0002oooooo0_l0
001Oooooo`?o00003oooool2o`0000gooooo0_l0000>ooooo`;o00004_ooool001kooooo00?o0000
ooooooooool03_ooool2o`0003kooooo0_l0001Dooooo`;o0000GOooool2o`00027ooooo0_l0000;
ooooo`;o00004_ooool001kooooo00?o0000ooooooooool03_ooool2o`0007Oooooo0_l0000;oooo
o`;o00003_ooool2o`0000;ooooo0_l0001:ooooo`;o0000<?ooool2o`0001oooooo000Nooooo`03
o`000?oooooooooo07;ooooo0_l0000Cooooo`;o00002oooool2o`0001;ooooo0_l00007ooooo`;o
0000@Oooool2o`0001Kooooo0_l00008ooooo`;o0000;oooool001kooooo0_l0001booooo`?o0000
0_ooool2o`0003Wooooo0_l0000eooooo`;o00008_ooool2o`0000Sooooo0_l0000_ooooo`007_oo
ool2o`0007;ooooo0_l00003ooooo`;o0000L?ooool2o`0005gooooo000Nooooo`03o`000?oooooo
oooo09_ooooo0_l0002Aooooo`;o00005oooool001kooooo00?o0000ooooooooool01Oooool2o`00
05[ooooo0_l0000hooooo`;o0000JOooool2o`0002Kooooo0_l0000Gooooo`007_ooool00ol0003o
ooooooooo`03ooooo`Co00002?ooool2o`0004[ooooo0_l00004ooooo`;o0000S?ooool2o`0001Go
oooo0_l0000oooooo`007_ooool00ol0003oooooooooo`03ooooo`;o00002_ooool2o`0001kooooo
0_l0000Zooooo`;o00002Oooool2o`00077ooooo0_l0000Dooooo`;o0000E_ooool001kooooo00?o
0000ooooooooool0;oooool2o`0003Cooooo0ol0000Gooooo`;o0000AOooool2o`00017ooooo0_l0
001Pooooo`;o00002_ooool001kooooo00?o0000ooooooooool0=_ooool2o`0002gooooo0_l0000H
ooooo`;o00009?ooool2o`0001oooooo0_l0001cooooo`;o00002_ooool001kooooo00?o0000oooo
ooooool0=_ooool2o`0000Kooooo0_l0001Uooooo`;o0000E?ooool2o`0004[ooooo000Nooooo`;o
0000?oooool2o`0004Kooooo0_l0000Qooooo`;o0000D?ooool2o`0004[ooooo000Nooooo`03o`00
0?oooooooooo00Wooooo0_l0000Qooooo`?o0000C_ooool2o`0000Oooooo0_l0000Iooooo`;o0000
1_ooool2o`0009cooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0000Qooooo`?o0000C_oo
ool2o`0002;ooooo0_l0002Tooooo`007_ooool00ol0003oooooooooo`0Looooo`;o0000Ooooool2
o`00013ooooo0_l0000`ooooo`;o0000Boooool2o`0001Oooooo000Nooooo`03o`000?oooooooooo
01cooooo0ol0001nooooo`;o00004?ooool2o`00033ooooo0_l0001;ooooo`;o00005oooool001ko
oooo00?o0000ooooooooool07Oooool2o`0008Cooooo0_l0001Aooooo`;o0000Coooool001kooooo
00?o0000ooooooooool07Oooool2o`0004?ooooo0_l0000oooooo`;o0000DOooool2o`0000_ooooo
0_l0000]ooooo`;o00004oooool001kooooo00?o0000ooooooooool0D_ooool2o`0000kooooo0_l0
002Oooooo`;o00009oooool2o`0000Cooooo0_l0000Cooooo`007_ooool00ol0003oooooooooo`02
o`00053ooooo0_l0000nooooo`;o0000V?ooool2o`0000Cooooo0_l0000Cooooo`007_ooool00ol0
003oooooooooo`02o`0001Kooooo0_l00018ooooo`?o0000;Oooool2o`0002cooooo0_l0000goooo
o`;o00006_ooool2o`0000[ooooo0_l0000Tooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o
0000B?ooool3o`0002_ooooo0_l0000^ooooo`;o00004Oooool2o`0000?ooooo0_l0000Oooooo`;o
00006_ooool2o`0000Sooooo1?l0000Tooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o0000
;_ooool2o`00047ooooo0_l00011ooooo`;o00000oooool2o`0002Cooooo0_l0000Oooooo`;o0000
9_ooool001kooooo00?o0000ooooooooool07Oooool2o`0002kooooo0_l0000_ooooo`;o00006_oo
ool2o`0003Cooooo0_l0000/ooooo`;o0000@Oooool2o`0000Cooooo000Nooooo`03o`000?oooooo
oooo03Kooooo1?l00014ooooo`;o00006_ooool2o`0001?ooooo0_l0000Oooooo`;o00006Oooool2
o`0000;ooooo0_l0001@ooooo`;o00001?ooool001kooooo00?o0000ooooooooool0=_ooool4o`00
05Sooooo0_l0000Kooooo`;o0000>_ooool2o`0000;ooooo0_l00002ooooo`;o00002_ooool2o`00
04Kooooo000Nooooo`03o`000?oooooooooo04Sooooo0_l00007ooooo`;o0000?oooool2o`00047o
oooo0_l0000Looooo`;o00002_ooool2o`0004Kooooo000Nooooo`;o00008oooool2o`0002Cooooo
0_l00007ooooo`;o0000BOooool2o`0003Oooooo0_l0000:ooooo`;o0000I?ooool001kooooo00?o
0000ooooooooool08_ooool2o`0000Gooooo0_l00006ooooo`;o0000JOooool2o`0003kooooo0_l0
0003ooooo`;o00002oooool2o`0002cooooo0_l0000Qooooo`;o00001_ooool001kooooo00?o0000
ooooooooool08Oooool2o`0000Kooooo0_l00006ooooo`;o0000@oooool2o`0002Kooooo0_l0000l
ooooo`;o00000oooool2o`0000[ooooo0ol000000ooooooo0000o`00000Yooooo`;o00008Oooool2
o`0000Kooooo000Nooooo`?o00002Oooool2o`0001Kooooo0_l0000fooooo`;o00006oooool2o`00
02Kooooo0_l0001=ooooo`;o00000_ooool2o`0005Cooooo000Nooooo`?o00002Oooool2o`0000Ko
oooo0_l0000looooo`;o00002?ooool2o`000>cooooo000Nooooo`03o`000?oooooooooo017ooooo
0_l0000looooo`;o00002?ooool2o`000>cooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0
000iooooo`;o00005?ooool2o`0002?ooooo0_l00030ooooo`;o00001Oooool001kooooo00?o0000
ooooooooool02?ooool2o`0003Wooooo0_l0000Mooooo`;o00006_ooool2o`00047ooooo0_l0001a
ooooo`;o00002_ooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l0000Xoooo
o`;o0000:oooool2o`0005gooooo0_l0000dooooo`;o0000>oooool2o`00017ooooo000Nooooo`03
o`000?oooooooooo00_ooooo0_l0000Qooooo`;o00001Oooool2o`0008Oooooo0_l0000:ooooo`;o
0000:oooool2o`0004kooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l00005ooooo`;o0000
S_ooool2o`0000[ooooo0_l0000=ooooo`;o00003Oooool2o`0000Oooooo0_l00015ooooo`;o0000
3Oooool001kooooo00?o0000ooooooooool04?ooool3o`0001Cooooo0_l00026ooooo`;o0000:?oo
ool3o`0000cooooo0_l00007ooooo`;o00009Oooool2o`0001kooooo0_l0000=ooooo`007_ooool0
1?l0003oooooooooooooool2o`0000gooooo0ol0002Looooo`;o00008?ooool2o`0000Oooooo0_l0
000looooo`;o00002?ooool2o`0002?ooooo000Nooooo`04o`000?ooooooooooooooo`;o0000MOoo
ool2o`0005Oooooo0_l0000Qooooo`;o0000;?ooool2o`0002?ooooo0003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo06Cooooo0_l0
000Booooo`;o0000;_ooool2o`0002Wooooo0_l00008ooooo`;o00005Oooool2o`0004Gooooo0_l0
000:ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`0?ooooo`;o00002oooool2o`0000kooooo
0_l00005ooooo`;o00008_ooool2o`0000_ooooo0_l00012ooooo`;o0000:Oooool2o`0000Sooooo
0_l00013ooooo`;o00005oooool2o`0000[ooooo0003ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00onHV9So8B4Qonk^kP07ooooo`?o00003oooool2o`0000_ooooo0_l0000>ooooo`;o0000
1Oooool2o`0002;ooooo0_l0002Oooooo`;o0000:?ooool2o`0002?ooooo0003ooooo`05o`000?oo
ooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo09Kooooo
0_l0001Pooooo`;o0000AOooool2o`0000Kooooo0003ooooo`05o`000?ooooooooooooooool00000
3_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo043ooooo0_l0001Dooooo`;o0000
1oooool2o`0002Gooooo0_l0000Gooooo`?o00004_ooool2o`0004Wooooo0_l00006ooooo`000ooo
ool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0=ooooo`;o00004oooool2o`0001cooooo0_l0000?ooooo`;o0000C?ooool2o`0002Gooooo
0_l0000Gooooo`?o00004_ooool2o`0003[ooooo0_l00008ooooo`;o00002oooool000?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003o
ooooooooo`0=ooooo`;o00004oooool2o`0002gooooo0_l0001Kooooo`;o0000P?ooool2o`0000So
oooo0_l0000;ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c006ooooo`03o`000?oooooooooo01Cooooo0_l0000dooooo`;o0000H_ooool2o`00
06Wooooo0_l0000/ooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o0000=?ooool2o`0002Co
oooo0_l0000nooooo`;o0000Ioooool2o`0002cooooo000Nooooo`03o`000?oooooooooo06Oooooo
0_l00007ooooo`;o00001Oooool2o`000003ooooool0003o000003Cooooo0_l0002Eooooo`007_oo
ool00ol0003oooooooooo`06ooooo`;o0000?_ooool2o`0001oooooo0_l0000>ooooo`;o000000?o
ooooo`000?l000000_ooool2o`000;?ooooo0_l0000Booooo`007_ooool00ol0003oooooooooo`06
ooooo`;o00005?ooool2o`0002Sooooo0_l0000fooooo`;o0000?oooool2o`0007;ooooo0_l00006
ooooo`;o00002_ooool001kooooo0ol0000Looooo`;o0000:_ooool2o`0006Oooooo0_l0000<oooo
o`;o0000>?ooool2o`00043ooooo0_l0000:ooooo`007_ooool3o`0004Sooooo0_l0001Wooooo`;o
0000A_ooool2o`00017ooooo0_l0000iooooo`007_ooool00ol0003oooooooooo`1Xooooo`;o0000
<_ooool2o`00017ooooo0_l00012ooooo`;o00005oooool2o`0002[ooooo0_l000000ooooooo0000
o`00000:ooooo`007_ooool00ol0003oooooooooo`0Xooooo`;o00003oooool2o`0002gooooo0_l0
000Nooooo`;o00004_ooool2o`00017ooooo0_l00012ooooo`?o0000@_ooool2o`000003ooooool0
003o000000[ooooo000Nooooo`03o`000?oooooooooo02Sooooo0_l0000?ooooo`;o0000COooool2
o`0006[ooooo0_l00015ooooo`;o00002_ooool001kooooo00?o0000ooooooooool00oooool2o`00
00Wooooo0_l0000oooooo`;o00006_ooool2o`0002_ooooo0_l00009ooooo`;o00004Oooool2o`00
01[ooooo0_l0000Gooooo`;o0000F_ooool001kooooo00?o0000ooooooooool00oooool2o`0000Wo
oooo0_l0000eooooo`;o00002?ooool2o`0001[ooooo0_l0000[ooooo`;o00002Oooool2o`00017o
oooo0_l0000Jooooo`;o00005oooool2o`00023ooooo0_l0000@ooooo`;o00009_ooool001kooooo
0_l00016ooooo`;o0000:?ooool2o`0003Kooooo0_l00016ooooo`;o00007?ooool2o`00013ooooo
0_l0000Hooooo`;o00003?ooool001kooooo00?o0000ooooooooool0Koooool2o`0003Kooooo0_l0
000Vooooo`;o00007_ooool2o`0004Kooooo1?l0000<ooooo`007_ooool00ol0003oooooooooo`3?
ooooo`;o0000BOooool2o`0001_ooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`06oooo
o`;o0000iOooool2o`0002_ooooo0_l0000;ooooo`;o00007_ooool001kooooo00?o0000oooooooo
ool01_ooool2o`000>Gooooo0_l0000hooooo`;o00007_ooool001kooooo00?o0000ooooooooool0
eOooool2o`0002oooooo0_l0000oooooo`007_ooool00ol0003oooooooooo`12ooooo`;o00008ooo
ool2o`0006cooooo0_l0000_ooooo`;o0000>Oooool2o`0000Cooooo000Nooooo`03o`000?oooooo
oooo04;ooooo0_l0000Sooooo`;o00001oooool2o`000<oooooo0_l00004ooooo`007_ooool00ol0
003oooooooooo`04ooooo`;o0000?Oooool2o`0002_ooooo0_l0003Eooooo`007_ooool00ol0003o
ooooooooo`04ooooo`;o0000?Oooool2o`0001Oooooo0_l0003Yooooo`007_ooool00ol0003ooooo
ooooo`12ooooo`;o00004_ooool2o`0000Cooooo0_l0000Yooooo`;o0000G_ooool3o`0004gooooo
0_l0000>ooooo`007_ooool00ol0003oooooooooo`12ooooo`;o00004_ooool2o`0002oooooo0_l0
000;ooooo`;o0000DOooool3o`0004gooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`1n
ooooo`;o00002oooool2o`0000Oooooo0_l0002aooooo`007_ooool00ol0003oooooooooo`0Poooo
o`;o0000G?ooool2o`0000_ooooo0_l00009ooooo`;o0000[oooool001kooooo00?o0000oooooooo
ool04oooool2o`0000_ooooo0_l0001dooooo`;o0000;?ooool2o`0001Sooooo0_l0000booooo`;o
0000<oooool001kooooo00?o0000ooooooooool04oooool2o`000:3ooooo0_l0000=ooooo`;o0000
6?ooool2o`0003;ooooo0_l0000cooooo`007Oooool3o`0005Gooooo0_l0001Oooooo`;o0000JOoo
ool2o`0002Gooooo000Mooooo`;o00005oooool2o`0003gooooo0_l0003:ooooo`;o00009Oooool0
01kooooo00?o0000ooooooooool05Oooool2o`000?oooooo<Oooool001kooooo00?o0000oooooooo
ool07_ooool2o`000=kooooo0_l00017ooooo`007_ooool00ol0003oooooooooo`0Nooooo`;o0000
5oooool2o`0003Gooooo0_l0000;ooooo`;o0000?Oooool2o`00013ooooo0_l00002ooooo`;o0000
;?ooool2o`0004Oooooo000Nooooo`03o`000?oooooooooo03Oooooo0_l0000eooooo`;o00002ooo
ool2o`0003gooooo0_l0000@ooooo`;o00000_ooool2o`0000kooooo0_l0000cooooo`;o0000<?oo
ool001kooooo00?o0000ooooooooool0A?ooool2o`0004cooooo0_l0001<ooooo`;o0000<oooool2
o`0000Cooooo0_l0000Zooooo`007_ooool00ol0003oooooooooo`14ooooo`;o00006_ooool2o`00
01?ooooo0_l0000Kooooo`;o00002oooool2o`0007[ooooo0_l0000Zooooo`007_ooool00ol0003o
ooooooooo`0:ooooo`;o00002_ooool2o`0004Sooooo0_l00007ooooo`;o00002_ooool2o`0002So
oooo0_l0002Vooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o00002_ooool2o`0002?ooooo
0_l0000/ooooo`;o0000Goooool2o`0002Sooooo0_l0001Aooooo`007_ooool00ol0003ooooooooo
o`0Kooooo`;o00007_ooool2o`0007Oooooo0_l0000Dooooo`;o00003_ooool2o`0001Sooooo0_l0
001Aooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o000000?oooooo`000?l00000;_ooool2
o`0006Oooooo0_l0000Booooo`;o00004?ooool2o`0004Cooooo0_l0000Uooooo`007_ooool00ol0
003oooooooooo`0Hooooo`;o0000<Oooool2o`0003?ooooo0_l0000Dooooo`;o00006?ooool2o`00
01Kooooo0_l0001Fooooo`;o00009Oooool001kooooo00?o0000ooooooooool0:Oooool2o`0003go
oooo0_l0000Fooooo`;o00005?ooool2o`0000[ooooo0_l0000<ooooo`;o00006_ooool2o`0007Wo
oooo000Nooooo`03o`000?oooooooooo02Wooooo0_l0000Rooooo`;o00006Oooool2o`0003Sooooo
0_l0000Xooooo`;o00005Oooool2o`0006;ooooo000Nooooo`03o`000?oooooooooo01Gooooo0_l0
000fooooo`;o00003oooool2o`0008?ooooo0_l0001Rooooo`007_ooool2o`0001Kooooo0_l00017
ooooo`;o00006_ooool2o`000:Oooooo0_l0000Rooooo`007_ooool00ol0003oooooooooo`03oooo
o`;o0000GOooool2o`0000gooooo0_l00007ooooo`;o0000Yoooool2o`0002;ooooo000Nooooo`03
o`000?oooooooooo00?ooooo0_l0001Mooooo`;o00003Oooool2o`0005Cooooo0_l0001;ooooo`;o
0000<Oooool001kooooo00?o0000ooooooooool0aoooool2o`0004_ooooo0_l0000aooooo`007_oo
ool00ol0003oooooooooo`07ooooo`;o00003Oooool2o`0005Kooooo1?l00002ooooo`;o0000Nooo
ool2o`0004Kooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`07ooooo`;o00003Oooool2
o`0005Kooooo1?l00002ooooo`;o00001?ooool2o`0007Gooooo0_l0000Nooooo`;o00009_ooool2
o`0000cooooo000Nooooo`03o`000?oooooooooo07[ooooo0_l0001@ooooo`;o0000@oooool2o`00
03Cooooo000Nooooo`03o`000?oooooooooo03_ooooo0_l0002?ooooo`;o0000L_ooool2o`0000Go
oooo000Nooooo`03o`000?oooooooooo02Oooooo0_l0000Booooo`;o0000DOooool2o`0001kooooo
0_l0000/ooooo`;o0000H_ooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l0
000Pooooo`;o0000@oooool2o`0000Sooooo0_l0000Dooooo`;o00003Oooool2o`0001gooooo0_l0
001Yooooo`007_ooool00ol0003oooooooooo`19ooooo`;o0000COooool2o`0002?ooooo0_l0000>
ooooo`;o0000N?ooool001kooooo00?o0000ooooooooool0:_ooool2o`0003Kooooo0_l0000Loooo
o`;o0000Boooool2o`0000oooooo0_l0000Qooooo`;o0000;Oooool2o`0001Gooooo000Nooooo`03
o`000?oooooooooo02[ooooo0_l0000aooooo`;o00000oooool2o`0001cooooo0_l0000eooooo`;o
00009Oooool2o`00027ooooo0_l0000]ooooo`;o00005Oooool001kooooo00?o0000ooooooooool0
9oooool2o`0003Cooooo0_l0001;ooooo`;o00002oooool2o`0000Gooooo0_l0000gooooo`;o0000
=Oooool2o`0001Oooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo
0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo02Oooooo0_l0000:ooooo`;o0000
MOooool2o`0001;ooooo0_l0000Cooooo`;o00008_ooool2o`0003Gooooo0_l00009ooooo`;o0000
3?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo01oooooo0_l0000Booooo`;o0000W_ooool2o`0006Cooooo
0_l0000<ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`?o0000
7oooool2o`0009oooooo0_l0001:ooooo`;o0000>Oooool000?ooooo00Go0000oooooooooooooooo
o`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0`?ooool2o`0001Wo
oooo0_l0000Hooooo`;o00005Oooool2o`00033ooooo0_l00007ooooo`000oooool01Ol0003ooooo
oooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`0/oooo
o`;o00003_ooool2o`0000kooooo0_l0000hooooo`;o00009_ooool2o`0002Oooooo0_l00002oooo
o`;o000000?oooooo`000?l000005Oooool2o`0003Oooooo0_l0000>ooooo`;o00001oooool000?o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool00_ooool2o`0002Sooooo0_l0000>ooooo`;o00003_ooool2o`0003Sooooo0_l0000Voooo
o`;o00009oooool2o`0000Gooooo0_l0001>ooooo`;o00005oooool000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool00_ooool2o`00
06;ooooo0_l0003@ooooo`;o00003Oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=oooo
o`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0I_ooool2o`0000Gooooo0_l00005oooo
o`;o0000=oooool2o`0003Cooooo0_l0001Cooooo`;o00003Oooool001kooooo00?o0000oooooooo
ool0KOooool2o`0000Gooooo0_l0000gooooo`;o00001?ooool2o`00027ooooo0_l0000;ooooo`;o
0000H_ooool001kooooo00?o0000ooooooooool0E?ooool2o`0001Cooooo0_l00017ooooo`;o0000
0oooool2o`0001cooooo0_l0001_ooooo`007_ooool00ol0003oooooooooo`0Xooooo`;o0000:_oo
ool2o`0001Cooooo0_l0000?ooooo`;o00000_ooool2o`00013ooooo0_l0000Uooooo`;o0000SOoo
ool001kooooo00?o0000ooooooooool0:?ooool2o`0002kooooo0_l0000Qooooo`;o00000_ooool2
o`00013ooooo0_l00017ooooo`;o0000Coooool2o`000003ooooool0003o000001Oooooo000Noooo
o`03o`000?oooooooooo05Sooooo0_l00020ooooo`;o0000Coooool2o`000003ooooool0003o0000
01Oooooo000Nooooo`03o`000?oooooooooo02cooooo0_l0000booooo`;o0000EOooool2o`0002ko
oooo0_l0001Nooooo`007_ooool00ol0003oooooooooo`0/ooooo`;o0000<_ooool2o`0000Kooooo
0_l0001=ooooo`;o0000;_ooool2o`0005kooooo000Nooooo`03o`000?oooooooooo04cooooo0_l0
000Jooooo`;o00002Oooool2o`0000[ooooo0_l0000/ooooo`;o00004Oooool2o`0006cooooo0_l0
000Gooooo`007_ooool00ol0003oooooooooo`0Wooooo`;o00008oooool2o`0002Gooooo0_l0000:
ooooo`;o0000;?ooool2o`00017ooooo0_l0000Wooooo`;o0000@oooool3o`0000Kooooo0_l0000>
ooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o00004oooool2o`0000Kooooo0_l0001:oooo
o`;o0000M?ooool2o`0004Cooooo0_l00006ooooo`;o00003_ooool001kooooo00?o0000oooooooo
ool02_ooool2o`0001?ooooo0_l0000oooooo`;o00001oooool2o`0000Sooooo0_l0001Cooooo`;o
0000I?ooool2o`0001Oooooo000Nooooo`;o00003oooool2o`00053ooooo0_l00007ooooo`;o0000
?_ooool2o`0001gooooo0_l0001Tooooo`;o00005oooool001kooooo00?o0000ooooooooool02?oo
ool2o`0000Cooooo0_l0000fooooo`;o0000HOooool2o`0006oooooo0_l0000[ooooo`007_ooool0
0ol0003oooooooooo`08ooooo`;o0000:?ooool2o`0000?ooooo0_l0000=ooooo`;o00002Oooool2
o`0007kooooo0_l0000Cooooo`;o00004Oooool2o`0001oooooo0ol00009ooooo`;o00007oooool0
01kooooo00?o0000ooooooooool0<_ooool2o`0000?ooooo0_l0000Hooooo`;o0000EOooool2o`00
02Oooooo0_l0000Cooooo`;o00004Oooool2o`00023ooooo0_l00009ooooo`;o00007oooool001ko
oooo00?o0000ooooooooool07oooool2o`0005[ooooo0_l0000[ooooo`;o0000;Oooool2o`0000Co
oooo0_l0001Cooooo`;o00004oooool001kooooo00?o0000ooooooooool07oooool2o`0005[ooooo
0_l0000eooooo`;o00008oooool2o`0000Cooooo0_l0001Aooooo`Co00004oooool001kooooo00?o
0000ooooooooool03Oooool2o`0005gooooo0_l00005ooooo`;o00004?ooool2o`0002_ooooo0_l0
001looooo`;o00005Oooool001kooooo00?o0000ooooooooool03Oooool2o`00037ooooo0ol0000Y
ooooo`;o00001Oooool2o`0000_ooooo0_l00003ooooo`;o0000Woooool2o`0001oooooo000Noooo
o`03o`000?oooooooooo00[ooooo0_l0000Oooooo`;o00000oooool2o`0000kooooo0ol0000ioooo
o`;o00000_ooool2o`0000oooooo0_l0000Zooooo`;o0000Ioooool2o`0001oooooo000Nooooo`03
o`000?oooooooooo00Wooooo0ol0000Oooooo`;o000000?oooooo`000?l000000_l0000>ooooo`;o
0000=oooool2o`000003ooooool0003o000001?ooooo0_l0000Zooooo`;o0000Goooool2o`0002Oo
oooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0000Sooooo`;o00004?ooool2o`0000Sooooo
0_l0000Wooooo`;o00001?ooool2o`0002?ooooo0_l0001nooooo`;o00009oooool001kooooo00?o
0000ooooooooool0A?ooool2o`0000Cooooo0_l0000Wooooo`;o00006oooool2o`0000cooooo0_l0
002Wooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o0000<Oooool2o`0003;ooooo0_l0000F
ooooo`;o00004?ooool2o`0001?ooooo0_l0002>ooooo`007_ooool00ol0003oooooooooo`0Aoooo
o`;o00007Oooool2o`0001kooooo0_l0000Vooooo`;o0000:?ooool2o`0000[ooooo0_l00007oooo
o`;o0000S_ooool001kooooo00?o0000ooooooooool0<?ooool2o`0001[ooooo0_l00002ooooo`;o
0000G?ooool2o`0006cooooo0_l0000Yooooo`007_ooool00ol0003oooooooooo`1<ooooo`;o0000
c_ooool2o`0002Wooooo000Nooooo`;o0000<_ooool2o`0004kooooo0_l00015ooooo`;o0000Kooo
ool2o`0000cooooo000Nooooo`03o`000?oooooooooo037ooooo0_l0001>ooooo`;o00005oooool2
o`0002cooooo0_l0000>ooooo`;o0000BOooool2o`0000_ooooo0_l00007ooooo`;o00003?ooool0
01kooooo00Co0000ooooool0003o0000:_ooool2o`0000Oooooo0_l0000Nooooo`;o0000>?ooool2
o`0000[ooooo0_l0000looooo`;o0000>_ooool2o`0000gooooo0_l0000;ooooo`;o00001?ooool2
o`0000oooooo000Nooooo`04o`000?oooooo0000o`0002[ooooo0_l00007ooooo`;o00007_ooool2
o`0003Sooooo0_l0001dooooo`;o00003_ooool2o`00013ooooo0_l0000>ooooo`;o00003oooool0
01kooooo00?o0000ooooooooool0:?ooool2o`0006[ooooo0_l0001;ooooo`;o00001Oooool2o`00
01[ooooo0_l0000Pooooo`;o00007oooool001kooooo00?o0000ooooooooool07?ooool2o`0000[o
oooo0_l0001;ooooo`;o00007Oooool2o`0004_ooooo0_l00005ooooo`;o0000GOooool001kooooo
00?o0000ooooooooool07?ooool2o`0001;ooooo0_l000000ooooooo0000o`00000/ooooo`;o0000
4_ooool2o`0006gooooo0_l00017ooooo`;o00006?ooool001kooooo00?o0000ooooooooool0<?oo
ool2o`000003ooooool0003o000000_ooooo0_l0000Oooooo`;o0000J_ooool2o`0000Wooooo0_l0
000:ooooo`;o00009oooool2o`0001kooooo0_l0000Hooooo`007_ooool00ol0003oooooooooo`10
ooooo`;o0000Roooool2o`0000Wooooo0_l0000cooooo`?o0000=oooool001kooooo00?o0000oooo
ooooool0Joooool2o`0004kooooo0_l0001Aooooo`;o0000=oooool001kooooo00?o0000oooooooo
ool0Joooool2o`0001_ooooo0_l0000Fooooo`;o00006Oooool2o`0002[ooooo0_l0000Jooooo`;o
0000@_ooool001kooooo00?o0000ooooooooool0=oooool2o`0004oooooo0_l0000Fooooo`;o0000
AOooool2o`0001[ooooo0_l00012ooooo`007_ooool00ol0003oooooooooo`0booooo`;o00000ooo
ool2o`0001kooooo0_l0003^ooooo`007_ooool00ol0003oooooooooo`0booooo`;o00008oooool2
o`000<7ooooo0_l0000Oooooo`;o00002_ooool001kooooo00?o0000ooooooooool0D?ooool2o`00
05kooooo0_l0001Xooooo`;o00004?ooool2o`0000gooooo0_l0000:ooooo`007_ooool00ol0003o
ooooooooo`0Tooooo`;o00007?ooool2o`0000cooooo0_l0000=ooooo`;o00007Oooool2o`0001Co
oooo0_l000000ooooooo0000o`00000Gooooo`;o0000N_ooool2o`0001Wooooo000Nooooo`;o0000
9Oooool2o`0001cooooo0_l0000Kooooo`;o00007Oooool2o`0001Cooooo0_l000000ooooooo0000
o`000016ooooo`;o0000I_ooool001kooooo00?o0000ooooooooool0Ooooool2o`0001gooooo0_l0
000oooooo`;o0000I_ooool001kooooo00?o0000ooooooooool0DOooool2o`0002cooooo0_l0000M
ooooo`;o00000oooool2o`0003cooooo0_l0000Hooooo`;o00006Oooool2o`0002oooooo000Noooo
o`03o`000?oooooooooo01Kooooo0_l0000Oooooo`;o00005Oooool2o`000003ooooool0003o0000
053ooooo0_l0000hooooo`;o00000_ooool2o`0001Sooooo0_l0000Iooooo`;o0000;oooool001ko
oooo00?o0000ooooooooool05_ooool2o`0000gooooo0_l0000@ooooo`;o00005Oooool2o`0008go
oooo0_l0000Oooooo`;o0000Aoooool001kooooo00?o0000ooooooooool01Oooool2o`0001kooooo
0ol00004ooooo`;o0000YOooool2o`0002Wooooo0_l00017ooooo`007_ooool00ol0003ooooooooo
o`05ooooo`;o00007oooool2o`0000Cooooo0_l0000/ooooo`;o00005?ooool2o`0000Gooooo0_l0
001Jooooo`?o0000@?ooool2o`0002oooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l00012
ooooo`;o00005?ooool2o`0000Gooooo0_l0000Sooooo`;o00002_ooool2o`0002[ooooo0_l0000@
ooooo`;o0000;_ooool2o`0002oooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l00009oooo
o`;o00002oooool2o`0007Oooooo0_l00006ooooo`;o00000_ooool2o`0003cooooo0_l0001Ooooo
o`007_ooool00ol0003oooooooooo`0;ooooo`;o00005_ooool2o`0001kooooo0_l0001Oooooo`;o
0000C_ooool2o`00013ooooo0_l0000oooooo`007_ooool00ol0003oooooooooo`13ooooo`;o0000
S?ooool2o`0000cooooo0_l0000Cooooo`;o00004?ooool2o`0003;ooooo0_l0000;ooooo`007_oo
ool00ol0003oooooooooo`3Aooooo`;o00003?ooool2o`0004Gooooo0_l0000Booooo`;o00002ooo
ool001kooooo00?o0000ooooooooool0lOooool2o`0003?ooooo0_l0000Oooooo`007_ooool00ol0
003oooooooooo`1Vooooo`;o0000>?ooool2o`0004oooooo0_l0000jooooo`;o00003oooool2o`00
00Oooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b
<_l0003o410@olc<c006ooooo`03o`000?oooooooooo03Sooooo0_l0000/ooooo`;o0000>?ooool2
o`0001;ooooo0_l00002ooooo`;o0000:oooool2o`0003_ooooo0_l00009ooooo`Co00003Oooool2
o`0000Oooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEE
ogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo03Sooooo0_l0000/ooooo`;o0000C?oo
ool2o`0000;ooooo0_l0000Booooo`;o00005oooool2o`0003_ooooo0_l0000;ooooo`;o00005_oo
ool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000
1_ooool3o`0000Wooooo0_l0000Pooooo`;o0000>Oooool2o`00027ooooo0_l00011ooooo`;o0000
NOooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ
8B401_ooool00ol0003oooooooooo`09ooooo`;o00008?ooool2o`0002Wooooo0_l0000aooooo`;o
0000A?ooool2o`0000Oooooo0_l0001]ooooo`000oooool01Ol0003ooooooooooooooooo000000_o
oooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo04cooooo0_l00008oooo
o`;o0000;?ooool2o`0004Wooooo0_l00007ooooo`;o0000KOooool000?ooooo00Go410@oooooooo
oooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0C?ooool2o`00
013ooooo0_l0000Tooooo`;o0000`Oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0D_ooool2o`0000[ooooo0_l0001Aoooo
o`;o0000A?ooool2o`0004kooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<
c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo02Sooooo0_l0000Xooooo`;o0000C?ooool2
o`0000oooooo0_l00014ooooo`;o0000C_ooool001kooooo00?o0000ooooooooool0:?ooool2o`00
07Kooooo0_l0000looooo`;o0000:oooool2o`0003[ooooo000Nooooo`03o`000?oooooooooo02oo
oooo0_l0002Jooooo`;o00004Oooool2o`0002_ooooo0_l0000jooooo`007_ooool00ol0003ooooo
ooooo`0_ooooo`;o0000V_ooool2o`0007[ooooo000Nooooo`03o`000?oooooooooo01[ooooo0_l0
001Dooooo`;o0000:oooool2o`000:Sooooo000Nooooo`03o`000?oooooooooo01[ooooo0_l0001D
ooooo`;o0000:oooool2o`0003Gooooo0_l0001aooooo`007_ooool00ol0003oooooooooo`0boooo
o`;o0000X?ooool2o`00077ooooo000Nooooo`03o`000?oooooooooo03;ooooo0_l00008ooooo`;o
00006_ooool3o`00043ooooo0_l0001Nooooo`;o0000B_ooool001kooooo00?o0000ooooooooool0
??ooool2o`0001[ooooo0ol00010ooooo`;o0000G_ooool2o`0004[ooooo000Nooooo`03o`000?oo
oooooooo06Cooooo0_l0001?ooooo`;o0000C?ooool2o`0004;ooooo000Nooooo`03o`000?oooooo
oooo01_ooooo0_l0000;ooooo`;o0000>_ooool2o`0000Cooooo0_l00011ooooo`;o00001_ooool2
o`0002[ooooo0_l0000Pooooo`;o0000@_ooool001kooooo00?o0000ooooooooool06oooool2o`00
00_ooooo0_l0000@ooooo`;o0000;_ooool2o`00047ooooo0_l0000booooo`;o0000C_ooool2o`00
01Cooooo000Nooooo`;o0000>oooool2o`0008[ooooo0_l0001Yooooo`;o00005?ooool001kooooo
00?o0000ooooooooool0>?ooool2o`0008cooooo0_l00016ooooo`;o0000=oooool001kooooo00?o
0000ooooooooool0>?ooool2o`0006?ooooo0_l0001_ooooo`;o0000=oooool001kooooo00?o0000
ooooooooool01oooool2o`0000_ooooo0_l00003ooooo`;o0000C_ooool2o`0003;ooooo0_l0002M
ooooo`;o00002Oooool001kooooo00?o0000ooooooooool01oooool2o`0000_ooooo1?l000000ooo
oooo0000o`00000`ooooo`;o00007?ooool2o`0000Kooooo0_l00021ooooo`;o0000A_ooool4o`00
00Oooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l0000Booooo`;o00007oooool2o`0002Co
oooo0_l0000<ooooo`;o0000Doooool2o`0001kooooo0_l0000Fooooo`;o0000<?ooool2o`0000Oo
oooo000Nooooo`03o`000?oooooooooo01Wooooo0_l0000?ooooo`;o00003_ooool2o`0004?ooooo
0_l0001Cooooo`;o0000=_ooool2o`00017ooooo0_l0000Vooooo`007_ooool00ol0003ooooooooo
o`06ooooo`;o00004Oooool2o`0001oooooo0_l0003Sooooo`Co00004?ooool2o`0001;ooooo000N
ooooo`03o`000?oooooooooo00Kooooo0_l0002Kooooo`;o0000B_ooool2o`0002Oooooo0_l00007
ooooo`;o00004?ooool2o`0001;ooooo000Nooooo`03o`000?oooooooooo0:?ooooo0_l0000^oooo
o`;o00006_ooool2o`00017ooooo0_l0000Dooooo`;o0000;Oooool001kooooo00?o0000oooooooo
ool0<?ooool2o`0003Gooooo0_l0001Zooooo`;o0000;Oooool2o`0004?ooooo000Nooooo`03o`00
0?oooooooooo023ooooo1?l0000:ooooo`Co0000=Oooool2o`0002kooooo0_l0000:ooooo`;o0000
X_ooool001kooooo00?o0000ooooooooool08?ooool4o`0000[ooooo0_l0001Nooooo`;o00001ooo
ool2o`0000[ooooo0_l0001Kooooo`;o00002_ooool2o`0003Wooooo000Nooooo`03o`000?oooooo
oooo00cooooo0_l00020ooooo`;o0000L?ooool2o`0000[ooooo0_l0000?ooooo`;o00000_ooool2
o`000003ooooool0003o0000027ooooo000Nooooo`03o`000?oooooooooo00cooooo0_l0000_oooo
o`;o0000G?ooool2o`0005Sooooo0_l0000Vooooo`;o00000_ooool2o`000003ooooool0003o0000
027ooooo000Nooooo`03o`000?oooooooooo02cooooo0_l0000?ooooo`;o00009oooool2o`0000;o
oooo0_l0000_ooooo`;o00009_ooool2o`0001Kooooo0_l0000Hooooo`;o0000D?ooool001kooooo
0_l0000]ooooo`;o00002?ooool2o`0002kooooo0_l00002ooooo`;o0000C?ooool2o`0000Wooooo
0_l0000Fooooo`;o00002_ooool2o`00023ooooo0_l0000looooo`007_ooool00ol0003ooooooooo
o`0Gooooo`;o00007Oooool2o`00083ooooo0_l0000[ooooo`Co00008?ooool2o`0003cooooo000N
ooooo`03o`000?oooooooooo01Oooooo0_l0000;ooooo`;o0000_oooool2o`0000gooooo0_l0000^
ooooo`;o00008Oooool001kooooo00?o0000ooooooooool09?ooool2o`0003cooooo0_l00016oooo
o`;o0000B?ooool2o`0002kooooo0_l0000Qooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o
0000B?ooool2o`0003_ooooo0_l00009ooooo`;o0000T?ooool2o`0000Wooooo000Nooooo`03o`00
0?oooooooooo01;ooooo0_l00004ooooo`;o0000QOooool2o`0000Gooooo0_l0002Dooooo`;o0000
2Oooool001kooooo00?o0000ooooooooool02_ooool2o`0000Kooooo0_l0001Gooooo`;o00003Ooo
ool2o`0001Oooooo0_l0000Aooooo`;o00004Oooool2o`00017ooooo0_l0000Gooooo`;o00006Ooo
ool2o`0002;ooooo0_l0000Qooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o00009oooool2
o`0003Kooooo0_l0000=ooooo`;o00005oooool2o`0002Cooooo0_l0000Aooooo`;o00005oooool2
o`0001Wooooo0_l0000Rooooo`;o00008Oooool001kooooo00?o0000ooooooooool0<oooool2o`00
01oooooo0_l0001;ooooo`;o00001oooool2o`0008;ooooo0_l0000Gooooo`007_ooool00ol0003o
ooooooooo`17ooooo`;o00002oooool2o`0004_ooooo0_l00007ooooo`;o00005?ooool2o`0006co
oooo0_l0000Gooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o0000>_ooool2o`0004oooooo
0_l0000Aooooo`;o00004oooool2o`0007Kooooo0_l0000=ooooo`007_ooool00ol0003ooooooooo
o`0;ooooo`;o0000E?ooool2o`0003Gooooo0_l0000Aooooo`;o0000Roooool2o`0000gooooo000N
ooooo`03o`000?oooooooooo067ooooo0_l0000Looooo`;o0000Poooool2o`00047ooooo000Noooo
o`03o`000?oooooooooo07oooooo0_l0000Booooo`;o00009?ooool2o`0002Cooooo0_l0000Soooo
o`;o0000@Oooool001kooooo00?o0000ooooooooool0Toooool2o`0002Cooooo0_l0000Tooooo`;o
0000I_ooool001kooooo00?o0000ooooooooool0;?ooool2o`0007?ooooo0_l0001nooooo`;o0000
9?ooool001kooooo0_l0000]ooooo`;o0000>Oooool2o`000003ooooool0003o000003Gooooo0_l0
001/ooooo`;o00004?ooool2o`0001Oooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`0D
ooooo`;o0000DOooool2o`000003ooooool0003o000001Gooooo0_l0002<ooooo`;o00005?ooool2
o`0001?ooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`0Dooooo`Co0000JOooool2o`00
0:;ooooo0_l0000Pooooo`007_ooool3o`0001Kooooo0_l0002Iooooo`;o00002Oooool2o`00067o
oooo0_l0000Vooooo`007_ooool3o`000;7ooooo0_l00009ooooo`;o0000HOooool2o`0002Kooooo
000Nooooo`03o`000?oooooooooo03_ooooo0_l0003Uooooo`;o00003Oooool2o`0000?ooooo0_l0
0002ooooo`;o00002oooool001kooooo00?o0000ooooooooool0>oooool2o`0004oooooo0_l0000Z
ooooo`;o0000J?ooool2o`0000gooooo0_l00003ooooo`;o00000_ooool2o`0000_ooooo000Noooo
o`03o`000?oooooooooo08cooooo0_l0000Zooooo`;o00005_ooool2o`0007Gooooo000Nooooo`03
o`000?oooooooooo04Oooooo0_l0000mooooo`;o00004?ooool2o`0003Kooooo0_l0001@ooooo`;o
00002oooool2o`0001Kooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l00013ooooo`;o0000
?Oooool2o`0000Kooooo0_l00008ooooo`;o0000K?ooool2o`0001[ooooo0_l0000;ooooo`;o0000
2Oooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0000cooooo`;o0000B?oo
ool2o`0000_ooooo0_l0001fooooo`;o0000<_ooool2o`0000_ooooo000Nooooo`03o`000?oooooo
oooo03Oooooo0_l0000=ooooo`;o0000>Oooool2o`0000_ooooo0_l00015ooooo`;o0000C_ooool2
o`00023ooooo000Nooooo`03o`000?oooooooooo047ooooo0_l00003ooooo`;o00008Oooool2o`00
06?ooooo0_l00005ooooo`;o00002_ooool2o`0002Sooooo0_l0000Hooooo`;o00008?ooool001ko
oooo00?o0000ooooooooool0@Oooool2o`0002Kooooo0_l00002ooooo`;o0000Goooool2o`00017o
oooo0_l0000Hooooo`;o00003_ooool2o`0000[ooooo0_l0000Jooooo`;o00004_ooool000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<
00Kooooo00?o0000ooooooooool04Oooool2o`0005[ooooo0_l0000Zooooo`;o0000H?ooool2o`00
01[ooooo0_l0000Jooooo`;o00004_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool04Oooool2
o`0000?ooooo0_l00019ooooo`;o0000=_ooool2o`000:cooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0000Fooooo`;o0000BOoo
ool2o`0001[ooooo0_l0001@ooooo`;o0000<oooool2o`00047ooooo0003ooooo`05o`000?oooooo
ooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000ooooooooool0
GOooool2o`0001kooooo0_l0001@ooooo`;o0000<oooool2o`0002oooooo0_l0000@ooooo`000ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03
o`000?oooooooooo05Oooooo0_l00004ooooo`;o0000;Oooool2o`0007Sooooo0_l0000]ooooo`;o
00004?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj
^_l@41001_ooool00ol0003oooooooooo`0Iooooo`;o00009?ooool2o`0001Kooooo0_l0000coooo
o`;o0000N?ooool2o`0002Oooooo0_l0000Fooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo01Wooooo0_l0000B
ooooo`;o00004?ooool2o`000;;ooooo0_l0000?ooooo`;o0000:Oooool2o`0001Kooooo0003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o
0000ooooooooool0;Oooool2o`000:;ooooo0_l000000ooooooo0000o`00000Mooooo`;o00003ooo
ool2o`0003?ooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`1_ooooo`;o00007oooool2
o`0001Wooooo0_l0000Tooooo`;o000000?oooooo`000?l00000Hoooool2o`0000cooooo000Noooo
o`03o`000?oooooooooo06Sooooo0_l00005ooooo`;o00007oooool2o`0001Wooooo0_l0001Voooo
o`;o00002Oooool4o`0002Gooooo000Nooooo`03o`000?oooooooooo06Sooooo0_l0000Pooooo`;o
00004_ooool2o`0002Oooooo0_l0000kooooo`;o00003Oooool2o`0000Wooooo1?l0000Uooooo`00
7_ooool00ol0003oooooooooo`23ooooo`;o00001Oooool3o`00017ooooo0_l0000Wooooo`;o0000
5?ooool2o`0002Gooooo0_l0000eooooo`;o00002_ooool001kooooo00?o0000ooooooooool0<Ooo
ool2o`00053ooooo0_l00006ooooo`;o0000D?ooool2o`0005cooooo0_l0000:ooooo`007_ooool0
0ol0003oooooooooo`0Booooo`;o00007Oooool2o`0004Cooooo0_l00003ooooo`;o0000Toooool2
o`0000_ooooo0_l0000Wooooo`007_ooool00ol0003oooooooooo`0@ooooo`Co000000?oooooo`00
0?l00000H?ooool2o`0000?ooooo0_l0002Cooooo`;o00002oooool2o`0002Oooooo000Nooooo`03
o`000?oooooooooo013ooooo0_l00003ooooo`;o0000^?ooool2o`0000gooooo0_l0001Wooooo`00
7_ooool00ol0003oooooooooo`0@ooooo`;o0000Roooool2o`00033ooooo0_l0000=ooooo`;o0000
Ioooool001kooooo00Co0000ooooool0003o00003_ooool2o`0008cooooo0_l00003ooooo`;o0000
C_ooool2o`0001?ooooo0_l00009ooooo`;o0000<oooool001kooooo00Co0000ooooool0003o0000
3_ooool2o`0006Kooooo0_l0000Yooooo`;o0000C_ooool2o`0000Kooooo0_l0000;ooooo`;o0000
2Oooool2o`0003?ooooo000Nooooo`;o0000@?ooool2o`0003Kooooo0_l00021ooooo`;o0000Booo
ool001kooooo00?o0000ooooooooool0?oooool2o`0004Wooooo0ol0000Yooooo`;o00004_ooool2
o`0003;ooooo0_l0000Cooooo`;o0000<_ooool001kooooo00?o0000ooooooooool0R_ooool3o`00
01Sooooo0_l0000?ooooo`;o00004_ooool2o`0001gooooo0_l0000Cooooo`;o00004oooool2o`00
03;ooooo000Nooooo`03o`000?oooooooooo0:Gooooo0_l00012ooooo`;o0000G?ooool001kooooo
00?o0000ooooooooool02_ooool2o`0005Cooooo0_l00024ooooo`;o00002Oooool2o`0005Cooooo
000Nooooo`04o`000?ooooooooooooooo`;o00001oooool2o`0005Cooooo0_l0000=ooooo`;o0000
Goooool2o`0001Cooooo0_l00009ooooo`;o0000E?ooool001kooooo00Co0000oooooooooooooooo
0_l000000ooooooo0000o`00000<ooooo`;o00006oooool3o`0003gooooo0_l0000Booooo`;o0000
9Oooool2o`0002Cooooo0_l0001eooooo`007_ooool00ol0003oooooooooo`04ooooo`;o00003?oo
ool2o`0001_ooooo0ol0001;ooooo`;o00001?ooool2o`0002Gooooo0_l00010ooooo`;o0000Booo
ool2o`0000cooooo000Nooooo`03o`000?oooooooooo07gooooo0_l00002ooooo`;o0000JOooool2
o`0004_ooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`21ooooo`;o0000:_ooool2o`00
023ooooo0_l0001:ooooo`;o0000:_ooool001kooooo00?o0000ooooooooool0Foooool2o`0002_o
oooo0_l0000Sooooo`;o00008?ooool2o`0000Kooooo0_l00007ooooo`;o0000>Oooool2o`0002[o
oooo000Nooooo`03o`000?oooooooooo01?ooooo0_l0000[ooooo`;o00006Oooool2o`0002_ooooo
0_l0001=ooooo`;o00001oooool2o`0002gooooo0_l0000fooooo`007_ooool00ol0003ooooooooo
o`0Cooooo`;o00007Oooool2o`0000cooooo0_l0003=ooooo`;o0000=_ooool001kooooo00?o0000
ooooooooool0<_ooool2o`0001[ooooo0_l0000Oooooo`;o00008?ooool2o`0002_ooooo0_l0001/
ooooo`;o00006Oooool001kooooo00?o0000ooooooooool0C_ooool2o`0000Oooooo0_l0000Foooo
o`;o00008?ooool2o`0001Kooooo0_l0000Cooooo`;o00002Oooool2o`0004oooooo0_l0000@oooo
o`;o00001_ooool2o`00017ooooo000Nooooo`03o`000?oooooooooo02kooooo0_l0000Wooooo`;o
00007_ooool2o`0000_ooooo0_l0000Sooooo`;o00007Oooool3o`0004oooooo0_l0000<ooooo`;o
00002_ooool2o`00017ooooo000Nooooo`;o0000;oooool2o`0004Oooooo0_l0000;ooooo`;o0000
@_ooool2o`0000cooooo0_l0000Mooooo`;o0000<Oooool2o`0001gooooo000Nooooo`03o`000?oo
oooooooo06Cooooo0_l00012ooooo`;o00000oooool2o`0002Oooooo0_l0000Mooooo`;o0000D?oo
ool001kooooo00?o0000ooooooooool0>oooool2o`0002Oooooo0_l0000=ooooo`;o0000<oooool2
o`0000?ooooo0_l00015ooooo`;o000000?oooooo`000?l000000_l0001<ooooo`007_ooool00ol0
003oooooooooo`0kooooo`;o00007?ooool4o`0001Kooooo0_l0001[ooooo`;o00004_ooool2o`00
0003ooooool0003o000000;o00002?ooool2o`0000Gooooo0_l0000Mooooo`;o00007?ooool001ko
oooo00?o0000ooooooooool09Oooool2o`0003;ooooo1?l0001gooooo`;o00002_ooool2o`0000Oo
oooo0_l0000Hooooo`;o00001Oooool2o`0001gooooo0_l0000Looooo`007_ooool00ol0003ooooo
ooooo`0Uooooo`;o00009?ooool2o`0000Gooooo0_l00020ooooo`;o00004oooool2o`0003kooooo
0_l0000Looooo`007_ooool00ol0003oooooooooo`0gooooo`;o00004_ooool2o`0000Cooooo0ol0
002Fooooo`;o00002_ooool2o`0002cooooo0_l0000Qooooo`007_ooool00ol0003oooooooooo`0>
ooooo`;o00009oooool2o`0001Sooooo0_l00006ooooo`;o0000;oooool2o`00057ooooo0_l0000;
ooooo`;o00002_ooool2o`0000Oooooo0_l0000Qooooo`Co00008Oooool001kooooo00?o0000oooo
ooooool03_ooool2o`0004Wooooo0_l0000_ooooo`;o0000>oooool2o`0001Cooooo0_l0000Poooo
o`;o00001oooool2o`0000Cooooo0_l0000Booooo`;o00008oooool001kooooo00?o0000oooooooo
ool0K?ooool2o`0003Kooooo0_l0000Qooooo`;o00003_ooool2o`0002oooooo0_l00004ooooo`;o
0000=oooool001kooooo00?o0000ooooooooool0K?ooool2o`0001Gooooo0_l00002ooooo`;o0000
6oooool2o`0002?ooooo0_l0000<ooooo`;o00006_ooool2o`0002Cooooo0_l0000/ooooo`007_oo
ool00ol0003oooooooooo`0Oooooo`;o0000H_ooool2o`0000;ooooo0_l00010ooooo`;o00001ooo
ool2o`0001Cooooo0_l00009ooooo`;o00009?ooool2o`0002cooooo000Nooooo`03o`000?oooooo
oooo01oooooo0_l0002aooooo`;o00005?ooool2o`0005gooooo000Nooooo`03o`000?oooooooooo
0=;ooooo0_l0001cooooo`007_ooool00ol0003oooooooooo`34ooooo`;o00003?ooool2o`0004;o
oooo0_l0000Jooooo`;o00004oooool001kooooo00?o0000ooooooooool0]_ooool2o`0000cooooo
0_l0001@ooooo`;o00006_ooool2o`0001?ooooo000Nooooo`;o0000<_ooool2o`0008?ooooo0_l0
000Uooooo`;o00009oooool2o`0000_ooooo0_l0000=ooooo`;o00008oooool001kooooo00?o0000
ooooooooool0<Oooool2o`0007Cooooo0_l0000dooooo`;o00009oooool2o`0000_ooooo0_l0000=
ooooo`;o00005Oooool2o`0000cooooo000Nooooo`03o`000?oooooooooo04gooooo0_l0000Qoooo
o`;o0000;Oooool2o`0000Kooooo0_l0000=ooooo`;o00007Oooool2o`0006;ooooo0_l0000<oooo
o`007_ooool3o`0001cooooo0_l0000_ooooo`;o00007?ooool2o`0000?ooooo0_l0000]ooooo`;o
00005Oooool2o`0000Oooooo0_l0000Dooooo`;o0000L?ooool001kooooo0ol0000Looooo`;o0000
7?ooool2o`0001Cooooo0_l0000Iooooo`;o0000A_ooool2o`0000[ooooo0_l00026ooooo`007_oo
ool00ol0003oooooooooo`0jooooo`;o00005?ooool2o`00013ooooo0_l0000Booooo`;o00001Ooo
ool2o`0003Cooooo0_l0002Booooo`007_ooool00ol0003oooooooooo`0gooooo`;o0000:Oooool2
o`0001;ooooo0_l00005ooooo`;o0000K_ooool2o`0005Sooooo000Nooooo`03o`000?oooooooooo
033ooooo0_l00005ooooo`;o0000POooool2o`00037ooooo0_l0001Hooooo`007_ooool00ol0003o
ooooooooo`0`ooooo`;o00002Oooool2o`0007gooooo0_l0002;ooooo`007_ooool00ol0003ooooo
ooooo`0kooooo`;o00004_ooool2o`0002?ooooo0_l0000>ooooo`;o0000:?ooool2o`0009Oooooo
000Nooooo`03o`000?oooooooooo04oooooo0_l0000Sooooo`;o00003_ooool2o`0002Sooooo0_l0
002Gooooo`007_ooool00ol0003oooooooooo`1>ooooo`;o0000FOooool4o`0009[ooooo000Noooo
o`03o`000?oooooooooo04kooooo0_l0000mooooo`Co00006?ooool4o`0002[ooooo0_l0001Doooo
o`;o00006?ooool001kooooo00?o0000ooooooooool02_ooool2o`00087ooooo1?l00016ooooo`;o
00001oooool2o`0003?ooooo0_l0000?ooooo`;o00001Oooool2o`0001Sooooo000Dooooo`Co0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`05ooooo`;o00000oooool2o`000=Cooooo
0_l0000<ooooo`;o00009Oooool2o`0000oooooo0_l0000Oooooo`005_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo1?l0003Uooooo`;o00009Oooool2o`00033ooooo000F
ooooo`03o`000?oooooooooo00Gooooo0ol00007ooooo`;o0000;?ooool2o`0002oooooo0_l0000Q
ooooo`;o0000R_ooool2o`00033ooooo000Fooooo`03o`000?oooooooooo03gooooo0_l0000_oooo
o`;o00008Oooool2o`000;cooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo
00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000D
ooooo`03oeEEEOmVIVKo00000?ooooooD_ooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.54477 .05154 Mdot
.77556 .56562 Mdot
.10407 .55892 Mdot
.5505 .69965 Mdot
.64717 .71817 Mdot
.84026 .01742 Mdot
.63187 .88304 Mdot
.91221 .76279 Mdot
.51599 .20242 Mdot
.15123 .8888 Mdot
.28419 .3007 Mdot
.29811 .17786 Mdot
.78444 .29384 Mdot
.47753 .65737 Mdot
.63551 .69017 Mdot
.88181 .91284 Mdot
.94332 .01705 Mdot
.0866 .85031 Mdot
.35665 .08909 Mdot
.1294 .13287 Mdot
.7956 .93156 Mdot
.0234 .1988 Mdot
.46641 .58588 Mdot
.68011 .97604 Mdot
.72683 .33669 Mdot
.15763 .36388 Mdot
.13637 .69164 Mdot
.23052 .49591 Mdot
.14798 .62959 Mdot
.18872 .69047 Mdot
.83645 .58579 Mdot
.01442 .60293 Mdot
.08584 .60913 Mdot
.03609 .35886 Mdot
.57429 .97824 Mdot
.40074 .3379 Mdot
.80236 .68673 Mdot
.19831 .92912 Mdot
.71092 .94968 Mdot
.9229 .47803 Mdot
.51787 .36495 Mdot
.77903 .83267 Mdot
.63656 .82451 Mdot
.71966 .27428 Mdot
.50583 .16991 Mdot
.72883 .87068 Mdot
.97657 .1467 Mdot
.37286 .48753 Mdot
.12938 .50521 Mdot
.12978 .60352 Mdot
.37311 .51036 Mdot
.16187 .08071 Mdot
.90039 .10042 Mdot
.4279 .29319 Mdot
.21878 .32133 Mdot
.66325 .0636 Mdot
.66797 .19605 Mdot
.97954 .14812 Mdot
.73644 .0944 Mdot
.65149 .61556 Mdot
.65222 .63431 Mdot
.47692 .05676 Mdot
.23396 .16885 Mdot
.27002 .93134 Mdot
.37886 .02326 Mdot
.88695 .68336 Mdot
.11502 .65691 Mdot
.17865 .66428 Mdot
.4019 .50567 Mdot
.15429 .47127 Mdot
.62048 .36623 Mdot
.45767 .81088 Mdot
.01318 .7771 Mdot
.93567 .79899 Mdot
.73425 .65339 Mdot
.62095 .82286 Mdot
.40048 .58488 Mdot
.77895 .09433 Mdot
.3307 .97303 Mdot
.64523 .47493 Mdot
.9737 .42217 Mdot
.44628 .0487 Mdot
.308 .10096 Mdot
.94364 .19285 Mdot
.33965 .27895 Mdot
.96289 .43902 Mdot
.56035 .67075 Mdot
.29671 .57132 Mdot
.11468 .1308 Mdot
.56271 .43198 Mdot
.73927 .20244 Mdot
.87235 .91198 Mdot
.81085 .73568 Mdot
.47144 .90827 Mdot
.45778 .67954 Mdot
.48282 .76036 Mdot
.16318 .35562 Mdot
.47501 .36616 Mdot
.64771 .64001 Mdot
.13322 .74955 Mdot
.57778 .46426 Mdot
.61546 .27258 Mdot
.79355 .30647 Mdot
.69785 .3155 Mdot
.02799 .6163 Mdot
.27167 .45243 Mdot
.52513 .98182 Mdot
.83391 .64738 Mdot
.31683 .67106 Mdot
.31374 .32607 Mdot
.71411 .07612 Mdot
.22548 .62114 Mdot
.09138 .56682 Mdot
.56499 .30368 Mdot
.34255 .21523 Mdot
.82192 .94305 Mdot
.35974 .64381 Mdot
.59526 .5356 Mdot
.87978 .70738 Mdot
.80649 .8437 Mdot
.51793 .08085 Mdot
.44757 .47244 Mdot
.84871 .04965 Mdot
.26737 .89625 Mdot
.71239 .43781 Mdot
.65719 .63751 Mdot
.41488 .1777 Mdot
.88024 .64959 Mdot
.01033 .57875 Mdot
.2398 .15877 Mdot
.17549 .9167 Mdot
.4783 .27016 Mdot
.70264 .88092 Mdot
.98551 .75271 Mdot
.80878 .87608 Mdot
.7634 .90163 Mdot
.14139 .39313 Mdot
.06118 .21889 Mdot
.77135 .17025 Mdot
.22594 .61443 Mdot
.71615 .54667 Mdot
.94128 .41088 Mdot
.49578 .67512 Mdot
.50778 .1856 Mdot
.8382 .83949 Mdot
.47701 .38812 Mdot
.98432 .00845 Mdot
.75863 .53161 Mdot
.79811 .66051 Mdot
.65249 .26746 Mdot
.07193 .44485 Mdot
.4716 .69804 Mdot
.40066 .94324 Mdot
.48543 .24194 Mdot
.85983 .22301 Mdot
.02271 .10134 Mdot
.0666 .33882 Mdot
.50058 .75828 Mdot
.12718 .3755 Mdot
.78685 .18133 Mdot
.28401 .67013 Mdot
.08925 .95907 Mdot
.25722 .18035 Mdot
.6628 .21589 Mdot
.90195 .2819 Mdot
.13231 .01914 Mdot
.99704 .10399 Mdot
.15468 .87281 Mdot
.97555 .72016 Mdot
.69903 .15944 Mdot
.80339 .3894 Mdot
.95707 .02304 Mdot
.47445 .67438 Mdot
.82271 .01895 Mdot
.17219 .44899 Mdot
.11488 .848 Mdot
.31531 .21193 Mdot
.93745 .78411 Mdot
.27331 .06309 Mdot
.73794 .86637 Mdot
.34266 .38811 Mdot
.0839 .75163 Mdot
.58432 .95355 Mdot
.17176 .68352 Mdot
.06486 .32411 Mdot
.39411 .7096 Mdot
.84761 .83043 Mdot
.23418 .81658 Mdot
.57724 .66343 Mdot
.25153 .07762 Mdot
.25895 .55517 Mdot
.46858 .16615 Mdot
.87146 .2121 Mdot
.33949 .45956 Mdot
.33199 .21377 Mdot
.21267 .73072 Mdot
.31239 .93456 Mdot
.86366 .0662 Mdot
.41968 .05915 Mdot
.67461 .2046 Mdot
.88742 .44085 Mdot
.37807 .17219 Mdot
.58339 .93068 Mdot
.95445 .05101 Mdot
.75704 .6734 Mdot
.56986 .63643 Mdot
.37986 .50438 Mdot
.40231 .86054 Mdot
.11292 .52497 Mdot
.49352 .83937 Mdot
.64801 .42072 Mdot
.86395 .67974 Mdot
.80577 .02482 Mdot
.53076 .55229 Mdot
.17742 .13956 Mdot
.53126 .54631 Mdot
.46541 .42121 Mdot
.00627 .95505 Mdot
.04041 .96178 Mdot
.5593 .0493 Mdot
.97301 .39154 Mdot
.02077 .16513 Mdot
.27987 .92594 Mdot
.20198 .53065 Mdot
.51897 .94605 Mdot
.62605 .93346 Mdot
.38648 .76165 Mdot
.13976 .4321 Mdot
.96598 .38526 Mdot
.08834 .43215 Mdot
.88039 .46866 Mdot
.57383 .42769 Mdot
.95246 .12199 Mdot
.50809 .21741 Mdot
.62775 .24103 Mdot
.35125 .73181 Mdot
.06387 .34008 Mdot
.68022 .75367 Mdot
.72236 .53365 Mdot
.58552 .36634 Mdot
.71169 .10327 Mdot
.45252 .88925 Mdot
.78643 .67987 Mdot
.9236 .50656 Mdot
.87909 .51272 Mdot
.37031 .33408 Mdot
.20636 .31658 Mdot
.06431 .64711 Mdot
.18747 .02147 Mdot
.4291 .84882 Mdot
.50991 .53259 Mdot
.88856 .43736 Mdot
.75328 .38422 Mdot
.48093 .5931 Mdot
.01188 .7497 Mdot
.60255 .04151 Mdot
.1779 .2819 Mdot
.18707 .66242 Mdot
.92643 .92042 Mdot
.07776 .06062 Mdot
.78402 .94413 Mdot
.69396 .16656 Mdot
.31901 .3665 Mdot
.76056 .68454 Mdot
.52069 .02713 Mdot
.32444 .13623 Mdot
.55366 .23244 Mdot
.67694 .13947 Mdot
.42082 .99558 Mdot
.53461 .52196 Mdot
.53912 .03011 Mdot
.41173 .41653 Mdot
.70997 .13098 Mdot
.76287 .29464 Mdot
.43603 .8098 Mdot
.95758 .56552 Mdot
.8703 .82766 Mdot
.67778 .38425 Mdot
.36166 .54981 Mdot
.04612 .19957 Mdot
.89619 .59944 Mdot
.46623 .72288 Mdot
.40192 .52404 Mdot
.09943 .35114 Mdot
.64691 .34796 Mdot
.38155 .10136 Mdot
.25603 .58316 Mdot
.37893 .4907 Mdot
.34089 .80095 Mdot
.6561 .15141 Mdot
.93411 .29568 Mdot
.65511 .90693 Mdot
.99295 .65157 Mdot
.14367 .1391 Mdot
.63589 .17223 Mdot
.08924 .83279 Mdot
.94374 .77948 Mdot
.66301 .77671 Mdot
.64273 .15082 Mdot
.32887 .24063 Mdot
.34693 .30516 Mdot
.62787 .13393 Mdot
.36809 .05419 Mdot
.01793 .27206 Mdot
.33007 .4477 Mdot
.829 .08815 Mdot
.73917 .32013 Mdot
.78456 .21024 Mdot
.84048 .49607 Mdot
.07687 .479 Mdot
.15287 .39013 Mdot
.70275 .19329 Mdot
.85077 .03987 Mdot
.02977 .01458 Mdot
.43796 .03075 Mdot
.05696 .78707 Mdot
.15283 .53801 Mdot
.27311 .74381 Mdot
.36836 .26285 Mdot
.53331 .4884 Mdot
.57292 .72194 Mdot
.41193 .05435 Mdot
.46509 .37673 Mdot
.75409 .81616 Mdot
.65933 .29163 Mdot
.67917 .8468 Mdot
.17661 .30598 Mdot
.57704 .01434 Mdot
.0688 .7228 Mdot
.2589 .31558 Mdot
.65532 .50501 Mdot
.77051 .78238 Mdot
.12744 .73823 Mdot
.31373 .77274 Mdot
.61723 .31655 Mdot
.60469 .91193 Mdot
.00275 .98006 Mdot
.97049 .11023 Mdot
.78137 .7192 Mdot
.34856 .05078 Mdot
.7574 .95113 Mdot
.0444 .78021 Mdot
.05718 .49098 Mdot
.31922 .04319 Mdot
.97439 .7978 Mdot
.96064 .22526 Mdot
.31217 .43608 Mdot
.40083 .35877 Mdot
.35428 .41121 Mdot
.38538 .29355 Mdot
.528 .73737 Mdot
.08197 .19759 Mdot
.81567 .83138 Mdot
.99262 .37236 Mdot
.80357 .29493 Mdot
.71813 .37421 Mdot
.78411 .54251 Mdot
.71281 .19368 Mdot
.42697 .15123 Mdot
.35704 .7902 Mdot
.11754 .69502 Mdot
.92657 .54162 Mdot
.54459 .00288 Mdot
.88951 .29871 Mdot
.77388 .21656 Mdot
.85182 .88152 Mdot
.01507 .87671 Mdot
.17871 .46221 Mdot
.18613 .28926 Mdot
.51079 .31336 Mdot
.71419 .18276 Mdot
.19904 .56816 Mdot
.64153 .44269 Mdot
.22758 .07173 Mdot
.05228 .48483 Mdot
.38324 .72786 Mdot
.23316 .31316 Mdot
.48619 .89138 Mdot
.26287 .48144 Mdot
.35246 .38411 Mdot
.03173 .14718 Mdot
.79657 .02555 Mdot
.27263 .00935 Mdot
.64255 .50232 Mdot
.67585 .61154 Mdot
.36998 .47562 Mdot
.57885 .08153 Mdot
.94187 .79311 Mdot
.39083 .81366 Mdot
.5009 .85683 Mdot
.08288 .37703 Mdot
.10351 .51765 Mdot
.00604 .18483 Mdot
.35165 .44699 Mdot
.77848 .13044 Mdot
.66413 .89973 Mdot
.05776 .56401 Mdot
.33895 .46887 Mdot
.4336 .43734 Mdot
.35205 .72085 Mdot
.08807 .66873 Mdot
.89618 .81931 Mdot
.05041 .3366 Mdot
.7478 .25625 Mdot
.99935 .1967 Mdot
.3513 .85451 Mdot
.26577 .02136 Mdot
.73211 .90991 Mdot
.16328 .50222 Mdot
.43795 .4858 Mdot
.68438 .01975 Mdot
.04088 .80998 Mdot
.55133 .30599 Mdot
.18985 .036 Mdot
.54616 .92432 Mdot
.48697 .73455 Mdot
.5918 .77262 Mdot
.09067 .92506 Mdot
.37117 .70618 Mdot
.40389 .9702 Mdot
.16289 .24892 Mdot
.01083 .52927 Mdot
.52351 .27397 Mdot
.92462 .67451 Mdot
.927 .92305 Mdot
.6898 .68354 Mdot
.33624 .95378 Mdot
.24791 .99403 Mdot
.78921 .22611 Mdot
.20193 .11409 Mdot
.46301 .4751 Mdot
.84327 .09861 Mdot
.25515 .27129 Mdot
.87765 .61458 Mdot
.77662 .95211 Mdot
.90782 .89515 Mdot
.80447 .07405 Mdot
.17315 .16677 Mdot
.51344 .07523 Mdot
.97057 .21758 Mdot
.76912 .89414 Mdot
.81337 .14867 Mdot
.35093 .46386 Mdot
.92503 .00517 Mdot
.05075 .23753 Mdot
.09261 .43572 Mdot
.31907 .24048 Mdot
.22948 .49552 Mdot
.46967 .12116 Mdot
.01133 .28358 Mdot
.00114 .00106 Mdot
.08564 .02121 Mdot
.27708 .1519 Mdot
.22748 .9173 Mdot
.97117 .64309 Mdot
.25739 .86721 Mdot
.87545 .45031 Mdot
.1199 .47642 Mdot
.51123 .25478 Mdot
.93527 .02596 Mdot
.08645 .08874 Mdot
.96901 .78722 Mdot
.0402 .04283 Mdot
.92832 .72128 Mdot
.80814 .93583 Mdot
.65599 .75911 Mdot
.88216 .24766 Mdot
.35388 .84677 Mdot
.96167 .75266 Mdot
.18902 .41537 Mdot
.40548 .54253 Mdot
.20868 .3444 Mdot
.3639 .49902 Mdot
.28446 .60205 Mdot
.27865 .41148 Mdot
.40137 .83623 Mdot
.51524 .5206 Mdot
.70024 .03221 Mdot
.67831 .22764 Mdot
.39155 .14059 Mdot
.67139 .43015 Mdot
.15753 .77026 Mdot
.31112 .9326 Mdot
.90408 .47096 Mdot
.90214 .47838 Mdot
.66445 .91393 Mdot
.6683 .02186 Mdot
.30821 .03265 Mdot
.19796 .54626 Mdot
.56296 .95529 Mdot
.56457 .27349 Mdot
.1263 .85969 Mdot
.84807 .79859 Mdot
.0137 .04449 Mdot
.58216 .911 Mdot
.065 .61838 Mdot
.63503 .47735 Mdot
.35558 .74972 Mdot
.92195 .41044 Mdot
.09235 .67192 Mdot
.76884 .9092 Mdot
.5744 .67185 Mdot
.24926 .68042 Mdot
.40325 .85708 Mdot
.44639 .83728 Mdot
.43444 .85775 Mdot
.81914 .9713 Mdot
.41445 .19428 Mdot
.22904 .53879 Mdot
.01419 .48958 Mdot
.3523 .17348 Mdot
.87656 .86271 Mdot
.53845 .21918 Mdot
.34721 .1459 Mdot
.33399 .58355 Mdot
.89924 .24366 Mdot
.93285 .70171 Mdot
.41961 .4312 Mdot
.06866 .68514 Mdot
.0502 .19183 Mdot
.79451 .10106 Mdot
.08125 .65729 Mdot
.48738 .97271 Mdot
.15955 .83971 Mdot
.90378 .79858 Mdot
.85741 .73906 Mdot
.6148 .25964 Mdot
.91345 .53996 Mdot
.72685 .51322 Mdot
.44865 .06368 Mdot
.70337 .87329 Mdot
.44345 .9169 Mdot
.86373 .72712 Mdot
.40706 .21457 Mdot
.42158 .79933 Mdot
.20254 .32992 Mdot
.56275 .04571 Mdot
.39006 .54588 Mdot
.90288 .7412 Mdot
.43195 .05101 Mdot
.22094 .18287 Mdot
.93817 .94232 Mdot
.56269 .3547 Mdot
.53999 .07027 Mdot
.6539 .5828 Mdot
.08777 .90092 Mdot
.18746 .82857 Mdot
.9304 .6161 Mdot
.66981 .8281 Mdot
.49527 .02489 Mdot
.72178 .04167 Mdot
.1082 .929 Mdot
.4558 .81406 Mdot
.12502 .94171 Mdot
.93823 .50418 Mdot
.63017 .82639 Mdot
.23922 .87647 Mdot
.49737 .97036 Mdot
.00659 .09291 Mdot
.6119 .39926 Mdot
.3818 .31004 Mdot
.07184 .32929 Mdot
.615 .31311 Mdot
.00861 .35535 Mdot
.20433 .54418 Mdot
.83839 .36881 Mdot
.2212 .08515 Mdot
.16333 .49762 Mdot
.02716 .16358 Mdot
.62093 .57238 Mdot
.97543 .02593 Mdot
.05407 .21791 Mdot
.54852 .76106 Mdot
.93705 .93372 Mdot
.88868 .40268 Mdot
.97397 .5332 Mdot
.72923 .90352 Mdot
.09027 .11947 Mdot
.55308 .86352 Mdot
.88226 .57671 Mdot
.48092 .6548 Mdot
.30628 .95931 Mdot
.55044 .58388 Mdot
.20716 .78616 Mdot
.95671 .86802 Mdot
.31506 .8976 Mdot
.02358 .4202 Mdot
.38601 .31938 Mdot
.24908 .56166 Mdot
.2506 .24503 Mdot
.74114 .65361 Mdot
.32344 .62327 Mdot
.21519 .04377 Mdot
.06236 .61907 Mdot
.70945 .41478 Mdot
.81003 .87798 Mdot
.70765 .50188 Mdot
.54031 .02534 Mdot
.63935 .12656 Mdot
.19912 .66087 Mdot
.43509 .5197 Mdot
.9037 .37102 Mdot
.64914 .82165 Mdot
.625 .70288 Mdot
.3891 .82283 Mdot
.51783 .0385 Mdot
.72413 .45284 Mdot
.66266 .20555 Mdot
.97134 .90607 Mdot
.16727 .2253 Mdot
.28738 .82442 Mdot
.92336 .51924 Mdot
.89718 .25932 Mdot
.97477 .19306 Mdot
.203 .39319 Mdot
.39451 .44541 Mdot
.85907 .52543 Mdot
.83192 .3617 Mdot
.17962 .11755 Mdot
.21412 .20116 Mdot
.25311 .25648 Mdot
.00167 .02099 Mdot
.92109 .47705 Mdot
.12378 .45659 Mdot
.06881 .17252 Mdot
.10393 .30835 Mdot
.82097 .73474 Mdot
.75431 .90818 Mdot
.91704 .16397 Mdot
.8775 .50123 Mdot
.78215 .09158 Mdot
.70806 .34498 Mdot
.574 .79041 Mdot
.66128 .36921 Mdot
.60808 .3581 Mdot
.49283 .86784 Mdot
.49426 .23044 Mdot
.43379 .60416 Mdot
.71814 .45104 Mdot
.72461 .74145 Mdot
.75637 .24174 Mdot
.80215 .19481 Mdot
.01927 .10529 Mdot
.13895 .89499 Mdot
.49014 .36005 Mdot
.52249 .57064 Mdot
.83702 .95686 Mdot
.9849 .65804 Mdot
.298 .77134 Mdot
.59603 .09855 Mdot
.62453 .36514 Mdot
.8265 .31224 Mdot
.8232 .16811 Mdot
.06921 .07253 Mdot
.84887 .0179 Mdot
.88545 .22227 Mdot
.40375 .70299 Mdot
.31768 .60667 Mdot
.52154 .70117 Mdot
.37806 .99386 Mdot
.17871 .97484 Mdot
.8268 .94022 Mdot
.59904 .6546 Mdot
.95558 .58285 Mdot
.73084 .53127 Mdot
.93132 .5554 Mdot
.83706 .55838 Mdot
.00095 .28776 Mdot
.47841 .81048 Mdot
.72812 .72627 Mdot
.91188 .15424 Mdot
.30528 .77725 Mdot
.6881 .13448 Mdot
.52327 .79217 Mdot
.13414 .52502 Mdot
.52285 .25416 Mdot
.44819 .03873 Mdot
.63662 .74402 Mdot
.56593 .43536 Mdot
.59079 .41086 Mdot
.13274 .57991 Mdot
.90773 .73003 Mdot
.2659 .47066 Mdot
.55757 .99755 Mdot
.53279 .38109 Mdot
.07908 .16059 Mdot
.44396 .81117 Mdot
.51149 .86138 Mdot
.95063 .81735 Mdot
.91991 .16223 Mdot
.42969 .3369 Mdot
.28411 .79654 Mdot
.25207 .71166 Mdot
.4213 .11164 Mdot
.94132 .19586 Mdot
.81865 .15896 Mdot
.45346 .85997 Mdot
.69443 .04353 Mdot
.96446 .09397 Mdot
.13793 .13752 Mdot
.05874 .23142 Mdot
.26342 .93006 Mdot
.67397 .93989 Mdot
.93444 .08848 Mdot
.37677 .18298 Mdot
.55822 .02177 Mdot
.39073 .94193 Mdot
.78446 .90784 Mdot
.98215 .03715 Mdot
.04483 .81911 Mdot
.97259 .98827 Mdot
.86193 .72691 Mdot
.95907 .71169 Mdot
.64368 .84195 Mdot
.33037 .81689 Mdot
.7543 .7084 Mdot
.90848 .67896 Mdot
.15103 .73122 Mdot
.5628 .692 Mdot
.41174 .86876 Mdot
.53556 .69998 Mdot
.4118 .00455 Mdot
.5178 .75687 Mdot
.50471 .23274 Mdot
.51384 .00016 Mdot
.8161 .34604 Mdot
.13843 .22841 Mdot
.10684 .68282 Mdot
.18512 .50449 Mdot
.91053 .90662 Mdot
.66734 .85797 Mdot
.54411 .08275 Mdot
.17658 .11294 Mdot
.08728 .12341 Mdot
.70369 .40102 Mdot
.62779 .93551 Mdot
.14523 .44595 Mdot
.76662 .54438 Mdot
.96171 .17231 Mdot
.61493 .90645 Mdot
.73148 .62303 Mdot
.65914 .95473 Mdot
.10905 .81012 Mdot
.16006 .82689 Mdot
.88755 .65255 Mdot
.0276 .74858 Mdot
.22865 .29625 Mdot
.44499 .76823 Mdot
.03839 .89538 Mdot
.63329 .17867 Mdot
.122 .67779 Mdot
.06344 .22729 Mdot
.34562 .01001 Mdot
.35919 .31774 Mdot
.28123 .1549 Mdot
.15425 .44589 Mdot
.34867 .45745 Mdot
.17148 .65209 Mdot
.16499 .20629 Mdot
.7716 .92921 Mdot
.08164 .35587 Mdot
.09333 .70529 Mdot
.00467 .63318 Mdot
.07516 .43285 Mdot
.70409 .66818 Mdot
.67075 .16008 Mdot
.3777 .4681 Mdot
.47156 .75954 Mdot
.07391 .05589 Mdot
.3451 .0622 Mdot
.86386 .80454 Mdot
.61851 .17793 Mdot
.82741 .4935 Mdot
.56995 .42767 Mdot
.77779 .81556 Mdot
.45023 .0398 Mdot
.11856 .19231 Mdot
.82438 .83481 Mdot
.7859 .67923 Mdot
.30789 .0302 Mdot
.6668 .66841 Mdot
.00757 .92314 Mdot
.84789 .81913 Mdot
.43444 .79009 Mdot
.97561 .28021 Mdot
.9094 .31709 Mdot
.15278 .42012 Mdot
.41408 .32251 Mdot
.98911 .27257 Mdot
.54468 .53273 Mdot
.24806 .63854 Mdot
.28201 .45764 Mdot
.53641 .92546 Mdot
.22924 .48958 Mdot
.73345 .15136 Mdot
.83996 .74492 Mdot
.71303 .82627 Mdot
.97581 .38233 Mdot
.60526 .36092 Mdot
.51651 .10486 Mdot
.57132 .13303 Mdot
.01682 .61721 Mdot
.27809 .53933 Mdot
.68967 .11445 Mdot
.69673 .56902 Mdot
.5054 .67001 Mdot
.91851 .37247 Mdot
.71054 .97027 Mdot
.1604 .59133 Mdot
.68982 .54288 Mdot
.60014 .18539 Mdot
.12855 .48284 Mdot
.07365 .09749 Mdot
.15678 .91077 Mdot
.7506 .51296 Mdot
.42215 .75126 Mdot
.09865 .98905 Mdot
.96173 .12617 Mdot
.13557 .57122 Mdot
.29609 .20096 Mdot
.93008 .02492 Mdot
.5612 .61308 Mdot
.37521 .88442 Mdot
.38794 .08515 Mdot
.25643 .83211 Mdot
.186 .12956 Mdot
.55063 .27406 Mdot
.80889 .42328 Mdot
.40677 .24029 Mdot
.80231 .25192 Mdot
.31626 .62377 Mdot
.55123 .09608 Mdot
.34113 .55389 Mdot
.9451 .52815 Mdot
.01113 .71482 Mdot
.60205 .39794 Mdot
.70994 .92774 Mdot
.37097 .22355 Mdot
.2042 .69835 Mdot
.60706 .84533 Mdot
.7523 .41318 Mdot
.75964 .54807 Mdot
.48115 .83442 Mdot
.2535 .49672 Mdot
.09477 .23517 Mdot
.26364 .01365 Mdot
.12886 .47552 Mdot
.70637 .57059 Mdot
.46371 .59282 Mdot
.38038 .30217 Mdot
.30473 .84944 Mdot
.81837 .50194 Mdot
.59707 .39107 Mdot
.01352 .90902 Mdot
.16108 .6017 Mdot
.80516 .36709 Mdot
.02131 .41154 Mdot
.58661 .39858 Mdot
.84728 .89108 Mdot
.83514 .87313 Mdot
.4285 .34327 Mdot
.49964 .52593 Mdot
.07929 .53882 Mdot
.72638 .06891 Mdot
.52699 .10256 Mdot
.66767 .20487 Mdot
.41082 .45578 Mdot
.90736 .79296 Mdot
.34488 .08927 Mdot
.36569 .43924 Mdot
.4524 .15307 Mdot
.48546 .6112 Mdot
.06865 .76493 Mdot
.03066 .0404 Mdot
.94481 .27094 Mdot
.25947 .92634 Mdot
.46277 .12331 Mdot
.54665 .76639 Mdot
.09685 .62248 Mdot
.6843 .92846 Mdot
.70694 .5783 Mdot
.27339 .53404 Mdot
.20965 .47007 Mdot
.83285 .96792 Mdot
.18583 .65991 Mdot
.84705 .88272 Mdot
.19629 .43395 Mdot
.5429 .91149 Mdot
.68834 .35535 Mdot
.04118 .19007 Mdot
.63663 .68804 Mdot
.31183 .21684 Mdot
.88472 .06465 Mdot
.08334 .72762 Mdot
.72002 .63969 Mdot
.20549 .80464 Mdot
.48928 .9347 Mdot
.40342 .87701 Mdot
.33789 .45563 Mdot
.81535 .92056 Mdot
.69454 .14507 Mdot
.8194 .77563 Mdot
.01303 .50218 Mdot
.46229 .51351 Mdot
.17325 .39258 Mdot
.42415 .74108 Mdot
.4981 .79799 Mdot
.1736 .98139 Mdot
.96369 .90831 Mdot
.81527 .05921 Mdot
.5808 .49753 Mdot
.95496 .18364 Mdot
.93156 .30729 Mdot
.18062 .45343 Mdot
.87347 .85031 Mdot
.67306 .98481 Mdot
.74528 .41263 Mdot
.29393 .19889 Mdot
.29227 .56962 Mdot
.07535 .26248 Mdot
.3735 .70655 Mdot
.30511 .15828 Mdot
.74749 .25371 Mdot
.39542 .92949 Mdot
.86096 .90152 Mdot
.16979 .52101 Mdot
.03245 .00646 Mdot
.54162 .58129 Mdot
.33205 .63843 Mdot
.20274 .33752 Mdot
.99464 .02397 Mdot
.17216 .11996 Mdot
.66624 .2721 Mdot
.82213 .00652 Mdot
.87382 .06327 Mdot
.47201 .03205 Mdot
.05763 .20675 Mdot
.2571 .5559 Mdot
.98009 .15553 Mdot
.76042 .92972 Mdot
.69284 .5619 Mdot
.51267 .54732 Mdot
.65304 .49306 Mdot
.38537 .47241 Mdot
.94194 .26567 Mdot
.51821 .42081 Mdot
.02297 .15754 Mdot
.09147 .34363 Mdot
.01022 .99591 Mdot
.78927 .83289 Mdot
.98511 .88529 Mdot
.07362 .85789 Mdot
.33739 .36837 Mdot
.60605 .26552 Mdot
.63928 .83043 Mdot
.17555 .83812 Mdot
.65239 .60935 Mdot
.7021 .37224 Mdot
.58436 .40672 Mdot
.5659 .07351 Mdot
.52893 .45601 Mdot
.7316 .19576 Mdot
.49864 .61584 Mdot
.70269 .38299 Mdot
.20625 .20256 Mdot
.14173 .16252 Mdot
.61203 .41726 Mdot
.92149 .36922 Mdot
.00448 .76307 Mdot
.26417 .95208 Mdot
.3751 .40129 Mdot
.65326 .9235 Mdot
.80105 .90018 Mdot
.87657 .68264 Mdot
.34743 .3294 Mdot
.21863 .25439 Mdot
.09599 .1719 Mdot
.12161 .13704 Mdot
.43908 .7096 Mdot
.1554 .72247 Mdot
.47954 .90158 Mdot
.93625 .81565 Mdot
.14937 .54519 Mdot
.23833 .93726 Mdot
.30299 .59993 Mdot
.40661 .20979 Mdot
.00075 .31552 Mdot
.14299 .91049 Mdot
.85958 .18879 Mdot
.06606 .8185 Mdot
.37529 .43445 Mdot
.86579 .05086 Mdot
.85109 .48796 Mdot
.88455 .28019 Mdot
.74671 .89773 Mdot
.60113 .38813 Mdot
.48861 .25256 Mdot
.2395 .13351 Mdot
.53317 .9818 Mdot
.14141 .17802 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001goooooool00018o`0000Cooooo000Mooooo`;o00003oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool01?l0003o
ooooooooooooool2o`0000Sooooo0ol0000@ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003oooooooooo`06ooooo`;o
00001Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;o00002oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo0ol0000@ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool00oooool2o`0000Sooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;o
oooo000Nooooo`03o`000?oooooooooo00Kooooo0_l0001=ooooo`;o00005Oooool2o`0001Cooooo
0_l00023ooooo`;o00008?ooool2o`00017ooooo0_l00009ooooo`007_ooool00ol0003ooooooooo
o`1Booooo`;o000000?oooooo`000?l000005Oooool2o`000<kooooo0_l00009ooooo`007_ooool0
0ol0003oooooooooo`06ooooo`;o0000B_ooool2o`0006?ooooo0_l0002>ooooo`007_ooool00ol0
003oooooooooo`06ooooo`;o00007oooool2o`0008kooooo0_l0000Qooooo`;o0000:oooool2o`00
00Cooooo0_l000000ooooooo0000o`00000Mooooo`;o00005_ooool001gooooo0_l0000Jooooo`;o
00003Oooool2o`00013ooooo0_l0000Gooooo`;o0000GOooool2o`0002;ooooo0_l00003ooooo`;o
0000:oooool2o`0000Cooooo0_l000000ooooooo0000o`00000Mooooo`;o00005_ooool001gooooo
0_l0000Jooooo`;o00007oooool2o`0001Oooooo0_l0000Sooooo`;o00009?ooool2o`0000gooooo
0_l00003ooooo`;o00008_ooool2o`0002Sooooo0_l000000ooooooo0000o`00000Vooooo`Co0000
1Oooool2o`0000Cooooo0_l00004ooooo`;o00001_ooool001kooooo00?o0000ooooooooool0Mooo
ool2o`0002Cooooo0_l00006ooooo`;o00001Oooool2o`00057ooooo0_l000000ooooooo0000o`00
000Vooooo`Co00001Oooool2o`0000Cooooo0_l00004ooooo`;o00001_ooool001kooooo00?o0000
ooooooooool0H?ooool2o`0002Sooooo0_l00009ooooo`;o00003_ooool2o`0000Cooooo0_l0002J
ooooo`007_ooool00ol0003oooooooooo`1Pooooo`;o0000:?ooool2o`0000Wooooo0_l0000Doooo
o`;o0000<oooool2o`0006Gooooo000Nooooo`03o`000?oooooooooo03[ooooo0_l0000Tooooo`;o
0000O_ooool2o`0005Wooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`06ooooo`;o0000
<_ooool2o`0005;ooooo0_l0000Dooooo`;o0000J_ooool2o`0002Wooooo0_l0000:ooooo`007_oo
ool00ol0003oooooooooo`02o`0000Cooooo0_l000000ooooooo0000o`00000gooooo`;o00008?oo
ool2o`0002Sooooo0_l0000Dooooo`;o00006_ooool2o`0001cooooo0_l00007ooooo`;o00009ooo
ool2o`0003Gooooo000Nooooo`03o`000?oooooooooo00;o00001oooool2o`0003Oooooo0_l0000P
ooooo`;o0000COooool2o`0000_ooooo0_l0000Looooo`;o00001oooool2o`0005kooooo000Noooo
o`03o`000?oooooooooo08gooooo0_l0000Sooooo`?o0000Foooool2o`0003Gooooo000Nooooo`;o
0000K_ooool2o`0001Wooooo0_l00003ooooo`;o00007_ooool2o`0000?ooooo0_l0001Looooo`;o
00000oooool2o`0001_ooooo0_l0000Cooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o0000
Eoooool2o`0000Gooooo0_l0000<ooooo`;o00001?ooool2o`0000gooooo0_l0000Dooooo`;o0000
I_ooool2o`0001_ooooo0_l0000Cooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o0000G_oo
ool2o`0000cooooo1?l0000Aooooo`;o0000K?ooool2o`00043ooooo000Nooooo`03o`000?oooooo
oooo01Gooooo0_l0001Eooooo`;o00005_ooool2o`0007oooooo0_l00010ooooo`007_ooool00ol0
003oooooooooo`0Eooooo`;o0000?_ooool2o`0001Gooooo0_l0000Pooooo`;o0000A?ooool2o`00
04;ooooo0_l00002ooooo`;o0000:Oooool001kooooo00?o0000ooooooooool0EOooool2o`0003Oo
oooo0_l00014ooooo`;o00004_ooool2o`0002_ooooo0_l000000ooooooo0000o`000002ooooo`;o
0000:Oooool001kooooo00?o0000ooooooooool0A_ooool2o`0006?ooooo0_l0000kooooo`;o0000
:oooool2o`00033ooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0000booooo`;o0000Fooo
ool2o`0000Kooooo0_l00007ooooo`;o0000Boooool2o`0004Cooooo000Nooooo`03o`000?oooooo
oooo01;ooooo0_l0000jooooo`;o0000Doooool2o`0000oooooo0_l0000^ooooo`;o00006oooool2
o`0004Cooooo000Nooooo`03o`000?oooooooooo037ooooo0_l0000Kooooo`;o0000E?ooool2o`00
03kooooo0_l0001Qooooo`007_ooool00ol0003oooooooooo`0aooooo`;o0000LOooool2o`0000Oo
oooo0_l00009ooooo`;o0000SOooool001kooooo00?o0000ooooooooool0A?ooool2o`0003Cooooo
0_l0000aooooo`;o00002Oooool2o`0008gooooo000Nooooo`03o`000?oooooooooo01Sooooo0_l0
000Zooooo`;o00009_ooool2o`0000;ooooo0_l00008ooooo`;o0000SOooool2o`00027ooooo0_l0
000Iooooo`007_ooool3o`0001Sooooo0_l0001Booooo`;o00000_ooool2o`0008Sooooo0_l0000=
ooooo`;o00008Oooool2o`0001Wooooo000Nooooo`?o0000[oooool2o`0003[ooooo0_l0000<oooo
o`?o0000>Oooool2o`00013ooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0002Iooooo`;o
00003Oooool2o`0002_ooooo0_l0000<ooooo`;o00004oooool2o`0002Gooooo0_l0000@ooooo`00
7_ooool2o`0000Cooooo0_l0000?ooooo`;o0000B_ooool2o`0001Kooooo0_l0000]ooooo`;o0000
5Oooool2o`0003kooooo0_l0000>ooooo`;o00004Oooool2o`0002Cooooo000Nooooo`03o`000?oo
oooooooo00;ooooo0ol0001Kooooo`;o00005_ooool2o`0002[ooooo0_l000000ooooooo0000o`00
000jooooo`;o00006Oooool2o`00027ooooo0_l0000Mooooo`;o00001Oooool001kooooo00?o0000
ooooooooool00_ooool2o`000:3ooooo0_l0000mooooo`;o0000Foooool2o`0000Gooooo000Noooo
o`03o`000?oooooooooo08Gooooo0_l0002`ooooo`;o00003_ooool001kooooo00?o0000oooooooo
ool0=Oooool2o`0000Oooooo0_l00015ooooo`;o0000EOooool2o`0005Wooooo0_l0000>ooooo`00
7_ooool00ol0003oooooooooo`0eooooo`?o00001_ooool2o`0009cooooo0_l0001Yooooo`007_oo
ool00ol0003oooooooooo`0Iooooo`;o00006Oooool4o`0005gooooo0_l0002`ooooo`007_ooool0
0ol0003oooooooooo`0Hooooo`?o00006Oooool2o`0005cooooo0_l000000ooooooo0000o`00002K
ooooo`;o00004oooool001kooooo00?o0000ooooooooool06?ooool2o`0007Sooooo0_l0000hoooo
o`;o0000I?ooool2o`000003ooooool0003o0000013ooooo000Nooooo`03o`000?oooooooooo03So
oooo0_l0002Booooo`;o0000:oooool2o`0003[ooooo0_l0000@ooooo`007_ooool00ol0003ooooo
ooooo`0Qooooo`;o00000oooool2o`00013ooooo0_l0000@ooooo`;o0000J_ooool2o`0002_ooooo
0_l0000Dooooo`;o0000C?ooool001kooooo00?o0000ooooooooool08Oooool2o`0000?ooooo0_l0
000Rooooo`;o00006Oooool2o`0004oooooo0_l0000@ooooo`;o00004_ooool2o`0000Gooooo0_l0
001Rooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o00001?ooool4o`0000Wooooo0_l0000]
ooooo`;o0000HOooool2o`0000kooooo0_l00002ooooo`;o0000JOooool001kooooo00?o0000oooo
ooooool08oooool2o`0000Cooooo1?l00009ooooo`;o0000@oooool2o`0005_ooooo0_l0001]oooo
o`007_ooool00ol0003oooooooooo`1]ooooo`;o00003?ooool2o`00067ooooo0_l0001Wooooo`00
7_ooool00ol0003oooooooooo`06ooooo`;o0000IOooool2o`0006oooooo0_l0000Tooooo`;o0000
<oooool3o`0000_ooooo000Nooooo`;o00001oooool2o`0004kooooo0_l0000_ooooo`;o0000A?oo
ool2o`0000;ooooo0_l0000Gooooo`;o00006?ooool2o`0003?ooooo0ol0000;ooooo`007_ooool0
0ol0003oooooooooo`1Fooooo`?o0000;_ooool2o`0000Kooooo0_l0000looooo`;o00000_ooool2
o`0001Oooooo0_l0000hooooo`;o00008Oooool001kooooo00?o0000ooooooooool00oooool2o`00
05;ooooo0_l00006ooooo`;o0000;_ooool2o`0009?ooooo0_l0000Eooooo`;o00002_ooool001ko
oooo00?o0000ooooooooool00oooool2o`00017ooooo0_l0000booooo`;o00004oooool2o`0007Go
oooo0_l00007ooooo`;o00009Oooool2o`0003?ooooo0_l0000:ooooo`007_ooool00ol0003ooooo
ooooo`05ooooo`;o00003oooool2o`0001;ooooo0_l0000Nooooo`;o0000R_ooool2o`0000Oooooo
0_l0000Uooooo`;o00007_ooool3o`0001kooooo000Nooooo`03o`000?oooooooooo00?ooooo1?l0
000Sooooo`;o00002?ooool2o`0005kooooo0_l00018ooooo`;o0000A_ooool3o`0001kooooo000N
ooooo`03o`000?oooooooooo00?ooooo0_l0000_ooooo`;o00004_ooool2o`0004[ooooo0_l0000:
ooooo`;o0000??ooool2o`0001Oooooo0_l0000?ooooo`;o0000?Oooool001kooooo00?o0000oooo
ooooool04_ooool2o`0000Oooooo0_l0000[ooooo`;o00009?ooool2o`0000Oooooo0_l0000Woooo
o`;o0000:Oooool2o`0002[ooooo0_l0000?ooooo`;o0000:oooool2o`00013ooooo000Nooooo`03
o`000?oooooooooo01;ooooo0_l00007ooooo`;o0000DOooool2o`0000Oooooo0_l0001Booooo`;o
0000J?ooool2o`00013ooooo000Nooooo`03o`000?oooooooooo02[ooooo0_l0000aooooo`;o0000
9?ooool2o`00043ooooo0_l00003ooooo`;o0000Noooool001kooooo00?o0000ooooooooool0:_oo
ool2o`0001Sooooo0_l0000:ooooo`;o00002oooool2o`0002Cooooo0_l00010ooooo`;o00000ooo
ool2o`0001Sooooo0_l0000Fooooo`;o0000BOooool001kooooo0ol00014ooooo`;o00002_ooool2
o`0002Cooooo0_l0000Yooooo`;o00007?ooool2o`0002?ooooo0_l0000Fooooo`;o0000=?ooool2
o`0001?ooooo000Nooooo`?o0000M_ooool2o`0002Wooooo0_l0000Looooo`;o0000D_ooool2o`00
01gooooo0_l0000Cooooo`007_ooool00ol0003oooooooooo`09ooooo`;o000000?oooooo`000?l0
0000ooooool6ooooo`;o0000<_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool02Oooool2o`000003ooooool0003o000001Co
oooo0_l0001Oooooo`;o0000Foooool2o`0000;ooooo0_l0000Kooooo`;o0000;?ooool2o`0000So
oooo0_l0000<ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`0Gooooo`;o00002Oooool2o`00
05oooooo0_l0001@ooooo`;o00002Oooool2o`0000;ooooo0_l00004ooooo`;o00005Oooool2o`00
02_ooooo0ol00008ooooo`;o00001_ooool2o`0000Cooooo0003ooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`?o00000oooool2o`0000Kooooo0_l0000:oooo
o`;o0000:?ooool2o`0001Sooooo0ol0001gooooo`;o00004oooool2o`0004;ooooo0_l0000Aoooo
o`;o00001?ooool000?ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^
00Kooooo00?o0000ooooooooool00oooool2o`0000Kooooo0_l0000booooo`Co00006?ooool3o`00
04Kooooo0_l00016ooooo`;o0000FOooool000?ooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool03oooool2o`00027ooooo0_l0000;oooo
o`;o0000Hoooool2o`0002gooooo1_l0000Cooooo`;o0000FOooool000?ooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03oooool2o`00
027ooooo0_l0001<ooooo`;o0000DOooool6o`0002;ooooo0_l0001:ooooo`000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooo
oooo06;ooooo0_l0000Looooo`;o0000NOooool2o`0001[ooooo0_l0000^ooooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oo
oooooooo06;ooooo0_l00004ooooo`;o000000?oooooo`000?l000004oooool2o`00057ooooo0_l0
000Rooooo`;o00007_ooool2o`0002kooooo000Nooooo`03o`000?oooooooooo00gooooo0_l00000
0ooooooo0000o`00001?ooooo`;o00001Oooool2o`000003ooooool0003o000001?ooooo0_l0000O
ooooo`;o00002?ooool2o`0002Kooooo0_l0000Rooooo`;o0000?_ooool2o`0000kooooo000Noooo
o`03o`000?oooooooooo00gooooo0_l000000ooooooo0000o`00001?ooooo`;o0000?_ooool2o`00
00Sooooo0_l0001_ooooo`;o00006Oooool2o`0000kooooo000Nooooo`03o`000?oooooooooo03;o
oooo0_l00010ooooo`;o0000WOooool2o`0000Oooooo0_l0000Fooooo`;o00004Oooool001kooooo
00?o0000ooooooooool04Oooool2o`0001Kooooo0_l00007ooooo`;o0000@?ooool2o`0006;ooooo
0_l0000Rooooo`;o00005Oooool2o`0001oooooo0_l0000Aooooo`007_ooool00ol0003ooooooooo
o`0?ooooo`Co00005_ooool2o`0007;ooooo0_l0000iooooo`;o00008_ooool2o`0004Wooooo000N
ooooo`03o`000?oooooooooo00oooooo0_l0000:ooooo`;o0000P?ooool2o`000003ooooool0003o
000000kooooo0_l0002Eooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o00003Oooool2o`00
08?ooooo0_l0000>ooooo`;o0000UOooool001kooooo00?o0000ooooooooool03?ooool2o`0005Ko
oooo0_l000000ooooooo0000o`00000Gooooo`;o0000A_ooool2o`0007gooooo000Nooooo`03o`00
0?oooooooooo06Cooooo0_l000000ooooooo0000o`00000Gooooo`;o00006?ooool2o`0002cooooo
0_l0000Xooooo`;o0000;?ooool2o`0002Gooooo000Nooooo`03o`000?oooooooooo04gooooo0_l0
001;ooooo`;o0000E_ooool2o`0002cooooo0_l0000Uooooo`007_ooool00ol0003oooooooooo`0a
ooooo`;o00006_ooool2o`000<cooooo0_l0000Zooooo`007_ooool2o`0003;ooooo0_l0001Xoooo
o`;o0000I?ooool2o`0001Sooooo0_l0000Zooooo`007_ooool00ol0003oooooooooo`13ooooo`;o
00002Oooool2o`0004_ooooo0_l00005ooooo`;o00000_ooool2o`0004Oooooo0_l0000@ooooo`;o
0000A?ooool001kooooo00?o0000ooooooooool0@oooool2o`0000Wooooo0_l0001Booooo`;o0000
0_ooool2o`0001cooooo0_l0000Yooooo`;o0000;oooool2o`0002Gooooo000Nooooo`03o`000?oo
oooooooo01Cooooo0_l0001Nooooo`;o0000C_ooool2o`0005[ooooo0_l0000Uooooo`007_ooool0
0ol0003oooooooooo`0Dooooo`;o0000G_ooool2o`0004_ooooo0_l0001[ooooo`;o00005oooool0
01kooooo00?o0000ooooooooool0`Oooool2o`0000gooooo0_l0001Looooo`;o00005oooool001ko
oooo00?o0000ooooooooool00_ooool2o`0004_ooooo0_l00016ooooo`;o0000=oooool2o`0000;o
oooo0_l0001Iooooo`;o00005_ooool001kooooo00?o0000ooooooooool00_ooool2o`0004_ooooo
0_l00016ooooo`;o00003Oooool2o`0000Oooooo0_l00002ooooo`;o00003oooool2o`0000kooooo
0_l0000@ooooo`;o0000Aoooool2o`0000cooooo0_l00008ooooo`007_ooool00ol0003ooooooooo
o`2Vooooo`;o00001oooool2o`0000;ooooo0_l0000?ooooo`;o00008?ooool2o`0005Gooooo0_l0
0008ooooo`007_ooool00ol0003oooooooooo`1Zooooo`;o0000[oooool2o`0001cooooo0_l0000<
ooooo`007_ooool00ol0003oooooooooo`02o`0003Cooooo0_l0000booooo`;o0000[oooool2o`00
00Cooooo0_l0000Fooooo`;o00003?ooool001kooooo00?o0000ooooooooool00_l0000dooooo`;o
0000jOooool2o`0002Cooooo000Mooooo`;o0000>_ooool2o`000?oooooo3_ooool001gooooo0_l0
000jooooo`;o0000?oooool2o`0000cooooo0_l00019ooooo`;o0000Loooool001kooooo00?o0000
ooooooooool0A_ooool2o`00037ooooo0_l0000<ooooo`;o0000BOooool2o`00023ooooo0_l00005
ooooo`;o00001?ooool2o`0002Wooooo0_l0000Iooooo`007_ooool00ol0003oooooooooo`16oooo
o`;o0000[?ooool2o`0000Gooooo0_l00004ooooo`;o00006_ooool2o`0000gooooo0_l0000Ioooo
o`007_ooool2o`0005Wooooo0_l0000Nooooo`;o0000Xoooool2o`0002Sooooo000Nooooo`03o`00
0?oooooooooo05Sooooo0_l0000Cooooo`;o00002Oooool2o`0003[ooooo0_l0002Aooooo`007_oo
ool00ol0003oooooooooo`0Nooooo`;o00005Oooool2o`0003Kooooo0_l00010ooooo`;o00000ooo
ool2o`0004Sooooo0_l0000[ooooo`;o00006_ooool001kooooo00?o0000ooooooooool07_ooool2
o`0001Gooooo0_l00011ooooo`;o0000=Oooool2o`0004gooooo0_l0000[ooooo`;o00006_ooool0
01kooooo00?o0000ooooooooool0B?ooool2o`0002kooooo0_l0000Xooooo`;o00008?ooool2o`00
04?ooooo0_l0000looooo`007Oooool2o`00047ooooo0_l00007ooooo`;o00001_ooool2o`0001oo
oooo0_l0000_ooooo`;o00008?ooool3o`0001Sooooo0_l0000Xooooo`;o00006Oooool2o`00027o
oooo000Mooooo`;o0000@Oooool2o`0000oooooo0_l0000Oooooo`;o00001_ooool2o`0004[ooooo
0_l0000Hooooo`;o00002oooool2o`0003Kooooo0_l0000Qooooo`007_ooool00ol0003ooooooooo
o`0Aooooo`;o0000<?ooool2o`0003Cooooo0_l00008ooooo`;o0000Ioooool2o`0005Wooooo000N
ooooo`03o`000?oooooooooo017ooooo0_l0000`ooooo`;o00007Oooool2o`0001oooooo0_l00032
ooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o0000:Oooool2o`0002;ooooo0_l00009oooo
o`;o0000f?ooool001kooooo00?o0000ooooooooool04oooool2o`0002Wooooo0_l0000]ooooo`;o
0000f?ooool001kooooo00?o0000ooooooooool03?ooool2o`0006Kooooo0_l0001booooo`;o0000
GOooool001kooooo00?o0000ooooooooool03?ooool2o`0000Cooooo0_l0000Zooooo`;o0000=?oo
ool2o`0000Sooooo0_l00008ooooo`;o0000G_ooool2o`0005gooooo000Nooooo`03o`000?oooooo
oooo017ooooo0ol0000Zooooo`;o0000?_ooool2o`0000Sooooo0_l0002mooooo`007_ooool00ol0
003oooooooooo`0Aooooo`;o00001oooool2o`0002Cooooo0_l00015ooooo`;o0000FOooool2o`00
06?ooooo000Nooooo`03o`000?oooooooooo01[ooooo0_l0000Tooooo`;o0000AOooool2o`0004Go
oooo0_l0000Booooo`;o00008Oooool2o`00043ooooo000Nooooo`;o00007Oooool2o`000;3ooooo
0_l0000eooooo`;o0000@?ooool001kooooo00?o0000ooooooooool07?ooool2o`0009Gooooo0_l0
002Booooo`007_ooool01?l0003oooooo`000?l0000Eooooo`;o00006Oooool2o`00083ooooo0_l0
000=ooooo`;o00006?ooool2o`0006Wooooo000Nooooo`04o`000?oooooo0000o`0000Oooooo0_l0
000<ooooo`;o00006Oooool2o`0004_ooooo0_l0000Kooooo`;o00009?ooool3o`0001Sooooo0_l0
001Yooooo`007_ooool00ol0003oooooooooo`08ooooo`;o00009Oooool2o`0004gooooo0_l0000K
ooooo`;o00009?ooool2o`0004Oooooo0_l0000kooooo`007_ooool00ol0003oooooooooo`0_oooo
o`;o0000<oooool2o`00033ooooo0_l0000<ooooo`;o00005?ooool2o`0000[ooooo0ol0000ioooo
o`;o00001_ooool2o`0003_ooooo000Nooooo`03o`000?oooooooooo06Cooooo0_l00004ooooo`;o
0000:_ooool2o`0000cooooo0_l0000Dooooo`;o00002_ooool3o`0000[ooooo0_l0000]ooooo`;o
00002?ooool2o`0001Wooooo0_l0000Nooooo`007_ooool00ol0003oooooooooo`1Zooooo`;o0000
Ioooool2o`0000_ooooo0_l0000Zooooo`;o00005?ooool2o`0000?ooooo0_l0000Fooooo`;o0000
1_ooool001kooooo00?o0000ooooooooool09Oooool2o`000;Wooooo0_l00003ooooo`;o0000>ooo
ool2o`0000?ooooo0_l0000Fooooo`;o00001_ooool001kooooo00?o0000ooooooooool05oooool2
o`0000cooooo0_l0001/ooooo`;o0000D?ooool2o`00063ooooo000Nooooo`03o`000?oooooooooo
01Oooooo0_l0001jooooo`;o00005?ooool2o`0008kooooo0_l0000<ooooo`007_ooool00ol0003o
ooooooooo`1^ooooo`;o0000>Oooool2o`0002gooooo0_l00006ooooo`;o00003oooool2o`0004?o
oooo0_l000000ooooooo0000o`00000<ooooo`007_ooool00ol0003oooooooooo`1[ooooo`;o0000
00?oooooo`000?l000009oooool2o`0002Kooooo0_l0000Gooooo`;o00001_ooool2o`0000oooooo
0_l00013ooooo`;o00003oooool001kooooo00?o0000ooooooooool0;_ooool2o`0003_ooooo0_l0
000Zooooo`;o00009Oooool3o`00043ooooo0_l0000eooooo`;o00003Oooool000?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool0:_ooool2o`0000;ooooo0_l00004ooooo`;o00002?ooool2o`0007kooooo0_l0
0011ooooo`;o0000=Oooool2o`0000gooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Zooooo`;o00002?oo
ool2o`0000Sooooo0_l00020ooooo`;o0000QOooool000?ooooo00Go410@oooooooooooooooooa0@
400;ooooo`Go00001_ooool3o`0007Kooooo0_l00013ooooo`;o00000oooool2o`000003ooooool0
003o000001cooooo0_l0001Tooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00001oooool00ol0003oooooooooo`1fooooo`;o0000@oooool2o`0000Kooooo
0_l0000Looooo`;o0000>_ooool2o`0002Sooooo0003ooooo`05o`000?ooooooooooooooool00000
2oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo0;[ooooo0_l0001Qooooo`;o
0000:?ooool000?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oo
oooo00?o0000ooooooooool0^_ooool2o`0006cooooo0_l0000Mooooo`000oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`03ooooo`;o
0000DOooool2o`0001Oooooo0_l0001;ooooo`;o0000<?ooool4o`0003Kooooo0_l00004ooooo`;o
00005oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Ko
oooo00?o0000ooooooooool00oooool2o`0003Cooooo0_l0000Kooooo`;o00005oooool2o`00017o
oooo0_l0000hooooo`;o00009Oooool2o`0000Wooooo1?l0000looooo`;o00005oooool001kooooo
00?o0000ooooooooool0>Oooool2o`0004Oooooo0_l0000oooooo`;o00007_ooool2o`0006;ooooo
000Nooooo`03o`000?oooooooooo00Cooooo0_l0000Xooooo`;o0000Hoooool2o`0000oooooo0_l0
000Mooooo`;o00002_ooool2o`0006Oooooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`04
ooooo`;o0000:?ooool2o`0006?ooooo0_l0000?ooooo`;o0000:Oooool2o`0003;ooooo0_l0000c
ooooo`;o00003Oooool001kooooo00?o0000ooooooooool0]Oooool3o`0004_ooooo0_l00012oooo
o`007_ooool00ol0003oooooooooo`24ooooo`;o0000;Oooool5o`0001kooooo0_l0001_ooooo`00
7_ooool00ol0003oooooooooo`0Dooooo`;o00000oooool2o`0000kooooo0_l0000Aooooo`;o0000
>?ooool2o`0000cooooo0_l0000]ooooo`;o00008Oooool2o`0006oooooo000Nooooo`03o`000?oo
oooooooo01Cooooo0_l00003ooooo`?o00003Oooool2o`00017ooooo0_l0000Sooooo`;o00004ooo
ool2o`00017ooooo0_l0000Yooooo`;o0000;Oooool2o`0003Sooooo0_l0000Xooooo`007_ooool0
0ol0003oooooooooo`0Jooooo`;o0000AOooool2o`00013ooooo0_l0000Dooooo`;o0000:Oooool2
o`0002gooooo0_l0000gooooo`?o00005_ooool2o`00013ooooo000Nooooo`03o`000?oooooooooo
07?ooooo0_l0001Gooooo`;o0000C_ooool2o`0001Oooooo0_l0000@ooooo`007_ooool00ol0003o
ooooooooo`0Cooooo`;o00005_ooool2o`000003ooooool0003o000003kooooo0_l0000<ooooo`;o
0000C_ooool2o`0007Wooooo000Nooooo`03o`000?oooooooooo01?ooooo0_l0000Fooooo`;o0000
00?oooooo`000?l000001?ooool2o`00037ooooo0_l00005ooooo`;o00003?ooool2o`0009_ooooo
0_l0000/ooooo`007_ooool2o`0003Gooooo0_l000000ooooooo0000o`00000Kooooo`;o00004Ooo
ool2o`0007cooooo1?l0000`ooooo`;o0000;?ooool001kooooo00?o0000ooooooooool09?ooool2
o`00017ooooo0_l0000Kooooo`;o00005?ooool2o`0001Gooooo0_l0000Uooooo`;o0000>oooool4
o`0005kooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l0000booooo`;o00004?ooool2o`00
0003ooooool0003o000001;ooooo0_l0000Uooooo`;o0000WOooool001kooooo00?o0000oooooooo
ool0=_ooool2o`00023ooooo0_l0000@ooooo`;o000000?oooooo`000?l00000f?ooool001kooooo
00?o0000ooooooooool0=_ooool2o`0003Kooooo0_l00018ooooo`;o0000SOooool001kooooo00?o
0000ooooooooool0J_ooool2o`0000;ooooo0_l00007ooooo`;o0000?oooool2o`00063ooooo0_l0
000[ooooo`007_ooool00ol0003oooooooooo`0^ooooo`;o00004?ooool2o`00013ooooo0_l0000F
ooooo`;o00002oooool2o`000:7ooooo0_l00006ooooo`;o00008oooool001kooooo00?o0000oooo
ooooool0;_ooool2o`00013ooooo0_l0000@ooooo`;o00009Oooool2o`0001;ooooo0_l00003oooo
o`;o0000>_ooool2o`0005;ooooo0_l0000Sooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o
000000?oooooo`000?l00000C?ooool2o`0000?ooooo0_l0000Booooo`;o00000oooool2o`0003Ko
oooo0_l00002ooooo`;o0000Eoooool3o`0001gooooo000Nooooo`03o`000?oooooooooo01Gooooo
0_l0000<ooooo`;o000000?oooooo`000?l00000C?ooool2o`0005Cooooo0_l0001Eooooo`;o0000
1?ooool3o`0001gooooo000Nooooo`03o`000?oooooooooo01Gooooo0_l0000?ooooo`;o0000:Ooo
ool2o`000<kooooo0_l0000Tooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o00005oooool2
o`0002Wooooo0_l0000gooooo`;o0000^oooool001kooooo00?o0000ooooooooool00_l0000;oooo
o`;o0000=oooool2o`0002gooooo0_l0000Cooooo`;o00007Oooool2o`0006Kooooo0_l0000doooo
o`007_ooool00ol0003oooooooooo`02o`0000cooooo0_l0000fooooo`;o0000;Oooool4o`00033o
oooo0_l0000Uooooo`;o0000=oooool2o`0000Kooooo0_l0000dooooo`007_ooool00ol0003ooooo
ooooo`0>ooooo`;o0000=_ooool3o`0002kooooo0_l0001Gooooo`;o0000=oooool2o`0000;ooooo
0_l0000hooooo`007_ooool00ol0003oooooooooo`0aooooo`;o00004oooool3o`0000Gooooo0_l0
000Rooooo`;o0000AOooool2o`0005;ooooo0_l0000hooooo`007_ooool2o`000003ooooool0003o
000002oooooo0_l0000Kooooo`;o00008_ooool2o`0004Gooooo0_l0000Booooo`;o00004oooool2
o`0002;ooooo0_l0000Aooooo`;o0000;?ooool001kooooo00?o0000ooooooooool00_l0000Toooo
o`;o00002Oooool2o`0000Gooooo0_l0000mooooo`;o00001_ooool2o`0004cooooo0_l00002oooo
o`;o00003oooool2o`0002;ooooo0_l0000Aooooo`;o00004_ooool2o`0001Sooooo000Nooooo`03
o`000?oooooooooo02Kooooo0_l0000@ooooo`;o0000?Oooool2o`0000Kooooo0_l0001@ooooo`;o
0000EOooool2o`0000?ooooo0_l0000Hooooo`007_ooool00ol0003oooooooooo`1eooooo`;o0000
/Oooool2o`0001gooooo000Nooooo`03o`000?oooooooooo07Gooooo0_l0000Kooooo`;o0000E?oo
ool2o`0000Kooooo0_l0000Xooooo`;o0000:oooool001kooooo00?o0000ooooooooool07_ooool2
o`0007;ooooo0_l0001Dooooo`;o00001_ooool2o`0002Sooooo0_l0000[ooooo`007_ooool00ol0
003oooooooooo`0Nooooo`;o00004oooool2o`0005Cooooo0_l0000Hooooo`;o0000Poooool2o`00
01gooooo000Nooooo`03o`000?oooooooooo03?ooooo0_l0001:ooooo`;o00002?ooool2o`0001So
oooo0_l00005ooooo`;o0000O?ooool2o`0001gooooo000Nooooo`03o`000?oooooooooo027ooooo
0_l00004ooooo`;o0000E_ooool2o`0001gooooo0_l0000:ooooo`;o0000Ioooool2o`0003;ooooo
000Nooooo`04o`000?oooooo0000o`00023ooooo0_l00004ooooo`;o0000MOooool2o`0007?ooooo
0_l0000Jooooo`;o00005_ooool001kooooo00Co0000ooooool0003o0000?Oooool2o`0006;ooooo
0_l00009ooooo`;o0000>_ooool2o`0000Sooooo0_l0000jooooo`;o00002?ooool2o`0000cooooo
000Nooooo`03o`000?oooooooooo03kooooo0_l0000Eooooo`;o0000Boooool2o`0000Wooooo0_l0
000>ooooo`;o0000:?ooool4o`0000Sooooo0_l00014ooooo`;o00003?ooool001kooooo00?o0000
ooooooooool05_ooool2o`0001Kooooo0_l0000Fooooo`;o00003Oooool3o`0006Gooooo0_l0000X
ooooo`;o0000G_ooool001kooooo00?o0000ooooooooool05_ooool2o`0001Kooooo0_l0000Foooo
o`;o00003_ooool2o`0002Sooooo0_l0001iooooo`;o0000:?ooool2o`0000;ooooo0_l0000Loooo
o`007_ooool00ol0003oooooooooo`0/ooooo`;o00004?ooool2o`00043ooooo0_l0001Jooooo`;o
00005oooool2o`0000Cooooo0_l0000Xooooo`;o00000_ooool2o`0001cooooo000Nooooo`03o`00
0?oooooooooo02cooooo0_l0000>ooooo`Co0000>oooool2o`0002Kooooo0_l00004ooooo`;o0000
<Oooool2o`0000Oooooo0_l0000<ooooo`Co0000D?ooool001kooooo0_l0000mooooo`;o0000<ooo
ool2o`0000Sooooo0_l0000Vooooo`;o00001?ooool2o`0003[ooooo0_l0000<ooooo`;o0000D_oo
ool001kooooo00?o0000ooooooooool0Joooool2o`0000Cooooo0_l0000eooooo`;o0000WOooool0
01kooooo00?o0000ooooooooool0Coooool3o`0001Wooooo0_l0000kooooo`;o0000POooool2o`00
01[ooooo000Nooooo`03o`000?oooooooooo01kooooo0_l0000_ooooo`?o0000^_ooool2o`0001go
oooo0_l0000Jooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o00003Oooool2o`0002gooooo
0_l0002>ooooo`;o0000;Oooool2o`0003Wooooo000Nooooo`03o`000?oooooooooo00oooooo0_l0
0009ooooo`;o0000<Oooool2o`0008kooooo0_l0000Iooooo`;o0000>Oooool2o`0001;ooooo000N
ooooo`03o`000?oooooooooo01[ooooo0_l0000Qooooo`;o00007?ooool2o`00087ooooo0_l0000H
ooooo`;o0000>Oooool2o`0001;ooooo000Nooooo`03o`000?oooooooooo02Sooooo0_l0000Coooo
o`;o00007?ooool3o`0004Sooooo0_l0000Nooooo`;o00005_ooool2o`0000;ooooo0_l0001Soooo
o`007_ooool00ol0003oooooooooo`0Xooooo`;o0000<_ooool2o`0004Sooooo0_l0000Nooooo`;o
00006_ooool2o`0006?ooooo000Nooooo`04o`000?oooooo0000o`000>7ooooo0_l0000gooooo`;o
0000:_ooool001kooooo00Co0000ooooool0003o00009_ooool2o`0008?ooooo0_l0000dooooo`;o
0000=oooool2o`0002[ooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l0000Vooooo`;o0000
5oooool2o`0001Cooooo0_l0000/ooooo`;o000000?oooooo`000?l000007oooool2o`0003[ooooo
0_l0000Uooooo`;o00004_ooool001kooooo00?o0000ooooooooool0Coooool2o`0001Oooooo0_l0
000Dooooo`;o00005?ooool2o`0001Wooooo0_l0000Oooooo`;o0000>_ooool2o`0002Gooooo0_l0
000Booooo`007_ooool00ol0003oooooooooo`0`ooooo`;o0000H_ooool2o`000;7ooooo0003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<
c006ooooo`03o`000?oooooooooo033ooooo0_l0001Qooooo`;o00000oooool2o`000:gooooo0003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RH
ob4Q8@06ooooo`03o`000?oooooooooo09?ooooo0_l00003ooooo`;o0000[Oooool000?ooooo00Go
410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`0005ko
oooo0_l0002oooooo`;o00009_ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05
o`000?nHV9SooooooiRHV?lQ8B401_ooool01?l0003oooooooooooooool2o`0002?ooooo0_l00008
ooooo`;o00009_ooool2o`0000Cooooo0_l0000Yooooo`;o0000U?ooool2o`0002Kooooo0003oooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00Co
0000oooooooooooooooo0_l0000Sooooo`;o00002?ooool2o`0002Kooooo0_l00009ooooo`;o0000
9?ooool2o`000;cooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7
ooooo`08ooooo`03o`000?oooooooooo01Sooooo0_l00019ooooo`;o0000Joooool2o`0007Gooooo
0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`00
0?oooooooooo01Sooooo0_l00020ooooo`;o00005_ooool2o`0001cooooo0_l00006ooooo`;o0000
KOooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Ko
oooo00?o0000ooooooooool01Oooool2o`0003kooooo0_l0001Cooooo`;o00000_ooool2o`0001;o
oooo0_l0000Looooo`;o00001_ooool2o`0003oooooo0_l0000?ooooo`;o00006oooool001kooooo
00Co0000oooooooooooooooo0_l00002ooooo`;o00002Oooool3o`0003;ooooo0_l0001Gooooo`;o
0000<?ooool2o`0004Oooooo0_l0000?ooooo`;o00006oooool001kooooo00Co0000oooooooooooo
oooo0_l0000=ooooo`?o00002?ooool2o`0002Sooooo0_l0003oooooo`7ooooo000Nooooo`03o`00
0?oooooooooo01_ooooo0_l0000Xooooo`;o00007?ooool4o`0008?ooooo0_l0001Kooooo`007_oo
ool00ol0003oooooooooo`1Sooooo`Co0000Poooool2o`0005_ooooo000Nooooo`03o`000?oooooo
oooo02cooooo0_l0003ooooooa[ooooo000Nooooo`;o0000;Oooool2o`000:;ooooo0_l0001eoooo
o`007_ooool2o`000;Kooooo0_l0000Iooooo`Co0000Loooool001kooooo00?o0000ooooooooool0
COooool2o`0001Wooooo0_l0001;ooooo`;o00005oooool2o`0000;ooooo0_l0000Booooo`;o0000
Goooool001kooooo00?o0000ooooooooool0COooool2o`0001Wooooo0_l00007ooooo`;o0000Fooo
ool2o`0001Kooooo0_l0001@ooooo`;o00003Oooool001kooooo00?o0000ooooooooool04Oooool2
o`0005kooooo0_l00035ooooo`;o00003Oooool001kooooo00?o0000ooooooooool04Oooool2o`00
0?Sooooo0_l0000=ooooo`;o0000:oooool001kooooo0_l0000eooooo`;o0000]Oooool2o`0001ko
oooo0_l0000=ooooo`Co00008Oooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo03Cooooo
0_l0001Rooooo`;o00009Oooool2o`0002[ooooo1?l0000]ooooo`;o00008Oooool2o`0000Kooooo
000Nooooo`03o`000?oooooooooo01Kooooo0_l00009ooooo`;o0000M?ooool3o`0002Gooooo0_l0
000/ooooo`;o0000COooool2o`0000Wooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l00009
ooooo`;o00005Oooool3o`0000;ooooo0_l0001Hooooo`;o0000I_ooool2o`0003_ooooo0_l00009
ooooo`007_ooool00ol0003oooooooooo`0fooooo`Go00000_ooool2o`0007Wooooo0_l00015oooo
o`;o0000A_ooool001kooooo00?o0000ooooooooool06Oooool2o`0001_ooooo0_l00020ooooo`;o
00006oooool2o`0000[ooooo0_l0001Tooooo`007_ooool00ol0003oooooooooo`0Iooooo`?o0000
??ooool2o`0000Wooooo0_l0000kooooo`;o00004?ooool2o`0000?ooooo0_l0000Looooo`;o0000
2_ooool2o`0006Cooooo000Nooooo`03o`000?oooooooooo01[ooooo0_l0000looooo`;o00002Ooo
ool2o`00037ooooo0_l00008ooooo`;o00004?ooool2o`0000?ooooo0_l0000iooooo`;o0000=?oo
ool2o`0001gooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l0001`ooooo`;o00001Oooool2
o`0005?ooooo0_l0000dooooo`;o00007Oooool001kooooo00?o0000ooooooooool09?ooool2o`00
02Oooooo0_l00012ooooo`;o00002_ooool2o`0005cooooo0ol0000Gooooo`;o00003?ooool2o`00
02;ooooo000Nooooo`03o`000?oooooooooo01oooooo0_l0000Cooooo`;o00005oooool2o`0004;o
oooo0_l00019ooooo`;o00007Oooool3o`0001Oooooo0_l00002ooooo`;o000000?oooooo`000?l0
00001Oooool2o`0002;ooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0000;ooooo`;o0000
4oooool2o`000:Kooooo0_l0000Eooooo`;o00003?ooool2o`0001Kooooo0_l000000ooooooo0000
o`00000Yooooo`007_ooool00ol0003oooooooooo`0Booooo`;o0000]_ooool3o`0002Kooooo0_l0
000<ooooo`;o0000A?ooool001kooooo00?o0000ooooooooool0:?ooool2o`0000oooooo0_l0001h
ooooo`;o00005Oooool3o`0007[ooooo000Nooooo`03o`000?oooooooooo02;ooooo0_l00004oooo
o`;o00003oooool2o`0007Sooooo0_l0002Booooo`007_ooool00ol0003oooooooooo`0Rooooo`;o
00006_ooool2o`0005Gooooo0_l0002`ooooo`007_ooool2o`0003oooooo0_l0001Eooooo`;o0000
3_ooool2o`0000?ooooo0_l00003ooooo`;o0000N_ooool2o`0001[ooooo000Nooooo`03o`000?oo
oooooooo01[ooooo0_l0001Sooooo`;o00009?ooool2o`0000?ooooo0_l00003ooooo`;o00005_oo
ool2o`0006;ooooo0_l0000Jooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o0000FOooool2
o`0000Sooooo0_l00016ooooo`;o0000:?ooool2o`0002Oooooo0_l0000[ooooo`007_ooool00ol0
003oooooooooo`1>ooooo`;o00009Oooool2o`0000Gooooo0_l0000=ooooo`;o0000I?ooool2o`00
02Oooooo0_l0000Hooooo`;o00004Oooool001kooooo00Co0000ooooool0003o0000COooool2o`00
02cooooo0_l0000=ooooo`;o0000Yoooool2o`00017ooooo000Nooooo`04o`000?oooooo0000o`00
0?ooooooAoooool001kooooo00?o0000ooooooooool0K_ooool2o`0005kooooo0_l0000Zooooo`;o
0000?Oooool2o`0000cooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0000Jooooo`;o0000
?_ooool2o`0002?ooooo0_l0000Qooooo`;o00005_ooool2o`0002[ooooo0_l0000^ooooo`;o0000
3Oooool2o`0000cooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0000Jooooo`;o0000Hooo
ool2o`00027ooooo0_l0000aooooo`;o0000:Oooool3o`0001?ooooo0_l0000Kooooo`007_ooool0
0ol0003oooooooooo`0Gooooo`;o0000Goooool2o`0006oooooo0_l0000Yooooo`?o00003?ooool2
o`0002;ooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0000Dooooo`;o00004_ooool2o`00
02_ooooo0_l00008ooooo`;o0000ZOooool2o`0002;ooooo000Nooooo`03o`000?oooooooooo02go
oooo0_l0000Booooo`;o0000:oooool2o`0002[ooooo0_l0001Xooooo`;o000000?oooooo`000?l0
0000?_ooool001kooooo00?o0000ooooooooool09Oooool2o`0007?ooooo0_l0000<ooooo`;o0000
F_ooool2o`000003ooooool0003o000000[ooooo0_l0000booooo`007_ooool00ol0003ooooooooo
o`0Uooooo`;o0000Goooool2o`00023ooooo0_l0000mooooo`;o0000:_ooool2o`0000cooooo0_l0
000Tooooo`007_ooool00ol0003oooooooooo`1Eooooo`;o0000;oooool2o`0004?ooooo0_l0000J
ooooo`;o00009?ooool2o`0001;ooooo0_l0000Tooooo`007_ooool00ol0003oooooooooo`05oooo
o`;o0000C_ooool2o`0007Cooooo0_l00010ooooo`;o0000>?ooool001kooooo0_l000000ooooooo
0000o`000003ooooo`;o00004?ooool2o`0000kooooo0_l00016ooooo`;o00005?ooool2o`000<3o
oooo000Nooooo`03o`000?oooooooooo00;o00005Oooool2o`0000kooooo0_l00016ooooo`;o0000
5?ooool2o`0005;ooooo0_l0001Jooooo`;o00001Oooool2o`0000Wooooo000Nooooo`03o`000?oo
oooooooo0:Cooooo0_l0000cooooo`;o0000F_ooool2o`0000Gooooo0_l00009ooooo`007_ooool0
0ol0003oooooooooo`2Eooooo`;o00000_ooool2o`0000Cooooo0_l00003ooooo`;o00002?ooool2
o`00027ooooo0_l0001dooooo`007_ooool2o`0007_ooooo0_l0000Iooooo`;o00000_ooool2o`00
00Cooooo0_l0000=ooooo`;o00008Oooool2o`00057ooooo0_l0000Qooooo`007_ooool2o`0001?o
oooo0_l0001Vooooo`;o0000<_ooool2o`0007Cooooo0_l0000Qooooo`007_ooool00ol0003ooooo
ooooo`0Booooo`;o00006oooool2o`0005cooooo0_l0000Oooooo`;o0000Uoooool001kooooo00?o
0000ooooooooool0;oooool2o`0002cooooo0_l00003ooooo`;o0000:Oooool2o`0002gooooo0_l0
0029ooooo`007_ooool00ol0003oooooooooo`1Mooooo`;o00000oooool2o`0005Sooooo0_l00018
ooooo`;o0000?oooool001kooooo00?o0000ooooooooool00_l0001Mooooo`;o0000L_ooool2o`00
037ooooo0_l0000Wooooo`;o00005_ooool001kooooo00?o0000ooooooooool00_l00008ooooo`;o
0000Doooool2o`0007;ooooo0_l0000Qooooo`;o0000=oooool2o`0001Kooooo000Nooooo`03o`00
0?oooooooooo00[ooooo0_l0003Zooooo`;o0000=Oooool2o`0001Sooooo000Nooooo`03o`000?oo
oooooooo00kooooo0_l0000_ooooo`;o0000k?ooool2o`0000Sooooo0_l0000>ooooo`007_ooool0
0ol0003oooooooooo`0>ooooo`;o0000;oooool2o`0002oooooo0_l0000Gooooo`;o0000:oooool2
o`0007oooooo0_l0000>ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1`ooooo`;o00005ooo
ool2o`0001_ooooo0_l0000>ooooo`;o0000Joooool2o`0000Wooooo0_l0000Gooooo`000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40
1_ooool00ol0003oooooooooo`1Hooooo`;o0000A?ooool2o`0000Kooooo0_l0001kooooo`;o0000
2Oooool2o`0000Wooooo0_l0000<ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo
00Go0000ooooooooooooooooo`000006ooooo`?o0000F?ooool2o`00017ooooo0_l0000Hooooo`;o
00005oooool2o`00073ooooo0_l0000@ooooo`;o00002?ooool2o`0000_ooooo0_l0000<ooooo`00
0oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06oooo
o`03o`000?oooooooooo06_ooooo0_l0000Hooooo`;o0000ROooool2o`00013ooooo0_l00008oooo
o`;o00006Oooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`01_ooool00ol0003oooooooooo`0oooooo`;o0000e?ooool2o`00033ooooo0003oooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o
0000ooooooooool02Oooool2o`0001Cooooo0_l0000Nooooo`;o0000BOooool2o`0008Wooooo0_l0
000`ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zj
o`000006ooooo`03o`000?oooooooooo00Wooooo0_l0000Dooooo`;o0000JOooool4o`0000?ooooo
0_l00004ooooo`;o0000[_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`1kooooo`;o00003oooool2o`0000;o
oooo0ol00004ooooo`;o0000F?ooool2o`0000Kooooo0_l0000aooooo`;o00006Oooool001kooooo
00?o0000ooooooooool02_ooool2o`0000Gooooo0_l0000eooooo`;o00007Oooool2o`0001;ooooo
0_l0000Cooooo`;o0000Goooool2o`0000Kooooo0_l0000Eooooo`;o00003Oooool2o`0000_ooooo
0_l00003ooooo`;o00005?ooool001kooooo00?o0000ooooooooool02_ooool2o`0000Gooooo0_l0
000eooooo`;o00007Oooool2o`0006Kooooo0_l0000oooooo`;o00003Oooool2o`00013ooooo0_l0
000Dooooo`007_ooool00ol0003oooooooooo`1Iooooo`;o00007oooool2o`0004[ooooo0_l00003
ooooo`;o00000_ooool2o`0007Kooooo000Nooooo`03o`000?oooooooooo033ooooo0_l00007oooo
o`;o00007_ooool2o`0001oooooo0_l0001:ooooo`;o000000?oooooo`000?l000000_l00009oooo
o`;o00003?ooool2o`00037ooooo0_l0000^ooooo`007_ooool00ol0003oooooooooo`0`ooooo`;o
00001oooool2o`0008kooooo0_l000000ooooooo0000o`000008ooooo`;o00003?ooool2o`0001oo
oooo0_l00008ooooo`;o00001_ooool2o`0002kooooo000Nooooo`03o`000?oooooooooo01Wooooo
0_l0000dooooo`;o0000Aoooool2o`0003;ooooo0_l0000[ooooo`;o000000?oooooo`000?l00000
1oooool2o`000003ooooool0003o000000Gooooo0_l0000fooooo`007_ooool00ol0003ooooooooo
o`0Iooooo`;o0000=?ooool2o`0002gooooo0_l0000=ooooo`;o00002Oooool2o`0005oooooo0_l0
00000ooooooo0000o`00000:ooooo`;o0000?Oooool001kooooo00?o0000ooooooooool0<?ooool2
o`0000?ooooo0_l00017ooooo`;o00003Oooool2o`0000gooooo0_l0001^ooooo`;o0000>Oooool0
01kooooo00?o0000ooooooooool0<?ooool2o`0000?ooooo0_l0001Uooooo`;o0000;oooool2o`00
03?ooooo0_l00008ooooo`;o0000>Oooool001kooooo00?o0000ooooooooool0Koooool2o`00053o
oooo0_l0000:ooooo`;o00002_ooool2o`0002Oooooo0_l00013ooooo`007_ooool00ol0003ooooo
ooooo`0Hooooo`;o00001oooool2o`0003cooooo0_l0000>ooooo`;o00005_ooool2o`0003Sooooo
0_l0000Fooooo`;o0000?Oooool2o`0002gooooo000Nooooo`;o00006Oooool2o`0000Oooooo0_l0
000looooo`;o00009_ooool2o`0008oooooo0_l0000]ooooo`007_ooool00ol0003oooooooooo`1^
ooooo`;o0000eoooool001kooooo00?o0000ooooooooool05?ooool2o`0005Sooooo0_l0000?oooo
o`;o00002?ooool2o`0001Cooooo0_l0000dooooo`;o0000L?ooool001kooooo00?o0000oooooooo
ool05?ooool2o`0000oooooo0_l0001Hooooo`;o00002?ooool2o`0000Cooooo0_l0000>ooooo`;o
000000?oooooo`000?l00000<Oooool2o`00073ooooo000Nooooo`03o`000?oooooooooo02Gooooo
0_l0001Hooooo`;o00003_ooool2o`00017ooooo0_l0000<ooooo`;o0000Ioooool2o`0002cooooo
000Nooooo`03o`000?oooooooooo053ooooo0_l0000`ooooo`;o00006?ooool2o`0001;ooooo0_l0
000jooooo`;o0000:oooool2o`0001Sooooo0_l0000Booooo`007_ooool00ol0003oooooooooo`1@
ooooo`;o0000<?ooool2o`0001Sooooo0_l0001;ooooo`;o000000?oooooo`000?l00000AOooool2
o`0001;ooooo000Nooooo`03o`000?oooooooooo02kooooo0_l0002aooooo`;o00001_ooool2o`00
023ooooo0_l0000jooooo`007_ooool01?l0003oooooooooooooool2o`0002_ooooo0_l0000Joooo
o`;o0000<oooool2o`00063ooooo0_l0000Pooooo`;o00001_ooool2o`0003[ooooo000Nooooo`04
o`000?ooooooooooooooo`;o0000Aoooool2o`0003?ooooo0_l0001Oooooo`;o00008Oooool2o`00
04;ooooo000Nooooo`03o`000?oooooooooo0<Wooooo0_l0000Eooooo`;o0000;Oooool4o`0003Co
oooo000Nooooo`03o`000?oooooooooo07Kooooo0_l0001Aooooo`;o0000A?ooool4o`0002Wooooo
0_l00009ooooo`007_ooool00ol0003oooooooooo`0]ooooo`;o0000Aoooool2o`0001Oooooo0_l0
002[ooooo`;o00002Oooool001kooooo00?o0000ooooooooool0;Oooool2o`00063ooooo0_l00009
ooooo`;o0000Loooool2o`0003Kooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0000Ooooo
o`;o0000:?ooool2o`0004Gooooo0_l0001Jooooo`;o00005oooool2o`0001;ooooo0_l0000Roooo
o`007_ooool00ol0003oooooooooo`08ooooo`;o00007oooool2o`0002Sooooo0_l0000=ooooo`;o
0000Roooool2o`0000Gooooo0_l0000[ooooo`;o00008_ooool001kooooo0_l0000Iooooo`;o0000
B?ooool2o`0003Cooooo0_l0000jooooo`;o00006Oooool2o`0000?ooooo0_l0000:ooooo`;o0000
4_ooool2o`00037ooooo000Nooooo`03o`000?oooooooooo01Sooooo0_l0001nooooo`;o0000>_oo
ool2o`0001?ooooo0_l00009ooooo`;o00002_ooool2o`0001;ooooo0_l0000aooooo`007_ooool0
0ol0003oooooooooo`2Eooooo`;o0000;Oooool2o`0000_ooooo0_l0000Fooooo`;o00001_ooool2
o`0000Sooooo0_l0000Wooooo`;o00003oooool2o`000003ooooool0003o000000gooooo000Noooo
o`03o`000?oooooooooo00;o0000:?ooool2o`0000?ooooo0_l0001Tooooo`;o00005Oooool2o`00
00_ooooo0_l00009ooooo`;o00002oooool2o`0001Oooooo0_l00005ooooo`;o00000oooool2o`00
00?ooooo0_l0000Wooooo`;o00003oooool2o`000003ooooool0003o000000gooooo000Nooooo`03
o`000?oooooooooo00;o0000:?ooool2o`0000?ooooo0_l0001kooooo`;o00002oooool2o`0000Go
oooo0_l0000Booooo`;o00005?ooool2o`0000[ooooo0_l0000Oooooo`;o00000_ooool2o`0002[o
oooo000Nooooo`03o`000?oooooooooo03Gooooo0_l0000?ooooo`;o0000A?ooool2o`0003;ooooo
0_l0000Booooo`;o0000@Oooool2o`0000;ooooo0_l0000Zooooo`007_ooool00ol0003ooooooooo
o`0eooooo`;o00003oooool2o`0004Cooooo0_l0001gooooo`;o00008_ooool2o`0001cooooo000N
ooooo`?o0000d?ooool2o`0003?ooooo0_l0000Rooooo`;o00007?ooool001kooooo0ol0000Ioooo
o`;o0000=Oooool2o`0000Gooooo0_l0001Aooooo`;o000000?oooooo`000?l000008Oooool2o`00
05Oooooo0_l0000Looooo`007_ooool00ol0003oooooooooo`0Iooooo`;o00001?ooool2o`0001_o
oooo0_l0000Booooo`Co00000oooool2o`0002?ooooo0_l0000/ooooo`;o000000?oooooo`000?l0
0000:oooool2o`0000Oooooo0_l0000>ooooo`;o00000_ooool2o`0004kooooo000Nooooo`03o`00
0?oooooooooo01oooooo0_l0000Kooooo`;o00005?ooool4o`0000_ooooo0_l0000Iooooo`;o0000
??ooool2o`0001kooooo0_l00007ooooo`;o00003_ooool2o`0000;ooooo0_l00006ooooo`;o0000
A_ooool001kooooo00?o0000ooooooooool0E?ooool2o`0000_ooooo0_l0000hooooo`;o00007Ooo
ool2o`0000_ooooo0ol0000eooooo`;o00000_ooool2o`0002Sooooo0_l0000Hooooo`007_ooool0
0ol0003oooooooooo`19ooooo`;o00005_ooool2o`0003Sooooo0_l0000Zooooo`?o0000>Oooool2
o`0002Sooooo0_l0000Hooooo`007_ooool00ol0003oooooooooo`0Uooooo`;o00008_ooool2o`00
033ooooo0_l0001Jooooo`;o0000<?ooool2o`0002;ooooo0_l0000Hooooo`007_ooool00ol0003o
ooooooooo`0Uooooo`;o0000E?ooool2o`000003ooooool0003o000005Oooooo0_l0000Rooooo`;o
00002_ooool4o`0002;ooooo0_l0000Hooooo`007_ooool00ol0003oooooooooo`1nooooo`;o0000
9Oooool2o`0005Cooooo0_l0000:ooooo`;o0000?_ooool001kooooo0_l0002Vooooo`;o0000??oo
ool2o`0000gooooo0_l0001Cooooo`007_ooool00ol0003oooooooooo`1Booooo`;o00005Oooool2
o`0004oooooo0_l0000Fooooo`;o00003oooool2o`0000gooooo0_l00004ooooo`;o0000COooool0
01kooooo0ol0001Booooo`;o00005Oooool2o`0004Sooooo0_l00005ooooo`;o00005_ooool2o`00
02Cooooo0_l0000Booooo`;o0000>Oooool001kooooo0ol0000Iooooo`;o0000A?ooool2o`0005;o
oooo0_l0001Gooooo`;o0000>Oooool001kooooo00?o0000ooooooooool02Oooool2o`0000kooooo
0_l00014ooooo`;o0000i_ooool001kooooo00?o0000ooooooooool02Oooool2o`000?oooooo?Ooo
ool001kooooo00?o0000ooooooooool0Ooooool2o`0006;ooooo0_l0000Vooooo`;o0000>_ooool0
01kooooo00?o0000ooooooooool0Ioooool2o`0001Kooooo0_l0000Iooooo`;o00000_ooool2o`00
04?ooooo0_l0000Qooooo`;o00000oooool2o`0003[ooooo000Nooooo`03o`000?oooooooooo03Ko
oooo0_l0000_ooooo`;o0000<Oooool2o`0000;ooooo0_l0000iooooo`;o0000:oooool2o`0003oo
oooo000Nooooo`03o`000?oooooooooo03Kooooo0_l0001oooooo`;o00008?ooool2o`0006cooooo
000Nooooo`;o0000=Oooool2o`00077ooooo1?l0000<ooooo`;o0000S_ooool001kooooo0_l0000e
ooooo`;o0000LOooool4o`0002cooooo0_l0001^ooooo`007_ooool00ol0003oooooooooo`3Goooo
o`;o0000Goooool2o`0000gooooo000Nooooo`03o`000?oooooooooo01cooooo0_l0003ooooooa_o
oooo0_l0000=ooooo`005?ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0
7?ooool2o`0002kooooo0_l0000Yooooo`;o0000c_ooool001Kooooo00?o0000ooooooooool01Ooo
ool01?l0003oooooo`000?l0001;ooooo`;o0000:Oooool2o`0000cooooo0_l0000Zooooo`;o0000
U?ooool001Kooooo00?o0000ooooooooool01Oooool4o`0008Cooooo0_l0000Zooooo`;o0000U?oo
ool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooo
oe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0
oooooom@ooooo`005?ooool00omEEEGoIVIVo`00003ooooooe;ooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.55571 .08337 Mdot
.7339 .55347 Mdot
.07898 .55268 Mdot
.52074 .68135 Mdot
.63172 .75812 Mdot
.81769 .97475 Mdot
.6385 .83922 Mdot
.92189 .77794 Mdot
.47968 .22147 Mdot
.13736 .89026 Mdot
.29231 .31922 Mdot
.27544 .16162 Mdot
.82662 .32466 Mdot
.45149 .6986 Mdot
.65824 .68302 Mdot
.83974 .92756 Mdot
.93635 .0151 Mdot
.11223 .86232 Mdot
.38884 .08632 Mdot
.10025 .17573 Mdot
.81881 .95434 Mdot
.05353 .19443 Mdot
.43649 .54512 Mdot
.68779 .94327 Mdot
.69937 .30911 Mdot
.14632 .33545 Mdot
.13124 .71659 Mdot
.21541 .49744 Mdot
.10469 .61151 Mdot
.19228 .7245 Mdot
.80636 .61632 Mdot
.00247 .64009 Mdot
.07756 .57139 Mdot
.03906 .35463 Mdot
.55054 .93632 Mdot
.44066 .32173 Mdot
.76079 .71785 Mdot
.20483 .8966 Mdot
.71937 .9096 Mdot
.89983 .4886 Mdot
.52433 .38745 Mdot
.7969 .85449 Mdot
.62839 .8625 Mdot
.70458 .30268 Mdot
.46128 .19939 Mdot
.75659 .85904 Mdot
.00088 .17324 Mdot
.40502 .44641 Mdot
.15077 .54647 Mdot
.11097 .64007 Mdot
.34038 .54633 Mdot
.12099 .06248 Mdot
.90666 .06897 Mdot
.41455 .29848 Mdot
.18805 .29787 Mdot
.61995 .0847 Mdot
.63702 .1872 Mdot
.95384 .1364 Mdot
.72627 .1041 Mdot
.63803 .59993 Mdot
.66601 .64806 Mdot
.43788 .04881 Mdot
.2351 .1913 Mdot
.22666 .89752 Mdot
.41963 .03178 Mdot
.90155 .68984 Mdot
.14107 .64369 Mdot
.19136 .69325 Mdot
.41357 .54582 Mdot
.14831 .46737 Mdot
.59752 .35166 Mdot
.41986 .77803 Mdot
.02103 .79432 Mdot
.8916 .81887 Mdot
.69614 .69363 Mdot
.57604 .83203 Mdot
.36695 .57081 Mdot
.76438 .05171 Mdot
.31686 .01738 Mdot
.6626 .4478 Mdot
.99281 .3807 Mdot
.42555 .07071 Mdot
.30456 .11921 Mdot
.91584 .20273 Mdot
.37277 .235 Mdot
.93392 .47459 Mdot
.58643 .63221 Mdot
.26692 .55303 Mdot
.12879 .15101 Mdot
.59252 .41126 Mdot
.72312 .22249 Mdot
.83915 .87321 Mdot
.82137 .75342 Mdot
.50527 .89251 Mdot
.42672 .72359 Mdot
.49943 .77954 Mdot
.14397 .39859 Mdot
.47591 .39425 Mdot
.64707 .67689 Mdot
.11847 .75011 Mdot
.60745 .43583 Mdot
.61599 .24886 Mdot
.79439 .30217 Mdot
.68562 .28519 Mdot
.06407 .64081 Mdot
.2713 .48352 Mdot
.54716 .00748 Mdot
.86214 .61518 Mdot
.31284 .69855 Mdot
.29579 .31025 Mdot
.75571 .11205 Mdot
.26691 .64872 Mdot
.05848 .58584 Mdot
.56104 .31047 Mdot
.3531 .19317 Mdot
.7846 .93463 Mdot
.37967 .64197 Mdot
.60329 .54102 Mdot
.92302 .7259 Mdot
.83166 .83783 Mdot
.52022 .11551 Mdot
.44525 .43665 Mdot
.85421 .09322 Mdot
.26919 .87762 Mdot
.70588 .41728 Mdot
.61744 .65707 Mdot
.44318 .13446 Mdot
.92281 .63282 Mdot
.97418 .58215 Mdot
.22881 .18097 Mdot
.14064 .94746 Mdot
.48727 .25351 Mdot
.71108 .92209 Mdot
.95118 .72697 Mdot
.7661 .91824 Mdot
.77298 .93976 Mdot
.15012 .41045 Mdot
.06528 .19202 Mdot
.79645 .18511 Mdot
.23248 .64959 Mdot
.73282 .51359 Mdot
.91426 .37953 Mdot
.50245 .65677 Mdot
.51637 .21558 Mdot
.88173 .82569 Mdot
.47438 .39946 Mdot
.02514 .99764 Mdot
.79145 .5501 Mdot
.78583 .67796 Mdot
.63622 .26718 Mdot
.07991 .4013 Mdot
.49377 .70765 Mdot
.43678 .97778 Mdot
.48994 .23716 Mdot
.8439 .23068 Mdot
.06364 .11169 Mdot
.05208 .31613 Mdot
.49905 .80237 Mdot
.11643 .40923 Mdot
.79726 .16102 Mdot
.24036 .64164 Mdot
.07051 .98458 Mdot
.25103 .15087 Mdot
.66758 .18651 Mdot
.90574 .26224 Mdot
.08715 .04012 Mdot
.97153 .12187 Mdot
.11373 .83835 Mdot
.0098 .71568 Mdot
.70469 .12585 Mdot
.80347 .39557 Mdot
.99686 .05464 Mdot
.47335 .66431 Mdot
.83585 .97979 Mdot
.13218 .42334 Mdot
.07805 .88316 Mdot
.31667 .25039 Mdot
.9004 .75417 Mdot
.25532 .03909 Mdot
.69725 .82603 Mdot
.33511 .41393 Mdot
.08221 .78892 Mdot
.62176 .92773 Mdot
.17504 .64406 Mdot
.05844 .35324 Mdot
.4297 .75459 Mdot
.836 .8412 Mdot
.26109 .78106 Mdot
.60915 .68053 Mdot
.26999 .11772 Mdot
.26395 .55084 Mdot
.48295 .20141 Mdot
.83941 .22706 Mdot
.31 .50255 Mdot
.30728 .21016 Mdot
.22462 .76727 Mdot
.33986 .94658 Mdot
.88555 .10317 Mdot
.41349 .01565 Mdot
.71486 .23195 Mdot
.89408 .42556 Mdot
.35483 .20514 Mdot
.5398 .96465 Mdot
.96171 .09357 Mdot
.79064 .64717 Mdot
.56141 .681 Mdot
.39268 .5259 Mdot
.42736 .82304 Mdot
.14464 .4899 Mdot
.45123 .80986 Mdot
.64041 .38387 Mdot
.82651 .66789 Mdot
.83701 .048 Mdot
.56123 .55174 Mdot
.20726 .17488 Mdot
.5093 .54828 Mdot
.50686 .43795 Mdot
.03733 .95805 Mdot
.02338 .00195 Mdot
.52149 .04427 Mdot
.97082 .42103 Mdot
.98025 .14501 Mdot
.23993 .94748 Mdot
.24405 .56802 Mdot
.4925 .98893 Mdot
.59252 .92674 Mdot
.37503 .72473 Mdot
.17298 .46832 Mdot
.95783 .37603 Mdot
.04511 .42066 Mdot
.84358 .4648 Mdot
.61287 .46568 Mdot
.96311 .13334 Mdot
.54282 .23026 Mdot
.63378 .27584 Mdot
.38917 .75241 Mdot
.05171 .37712 Mdot
.7067 .73676 Mdot
.76666 .56314 Mdot
.62392 .35757 Mdot
.71988 .0967 Mdot
.49011 .84728 Mdot
.78678 .72288 Mdot
.96694 .47133 Mdot
.91404 .49867 Mdot
.33349 .33082 Mdot
.19017 .31255 Mdot
.03521 .668 Mdot
.22855 .02541 Mdot
.41878 .8426 Mdot
.5512 .55145 Mdot
.88469 .39451 Mdot
.74144 .36433 Mdot
.48436 .63735 Mdot
.04489 .73296 Mdot
.60819 .07582 Mdot
.22137 .32403 Mdot
.18415 .65479 Mdot
.9405 .92175 Mdot
.05888 .07805 Mdot
.80243 .98689 Mdot
.73139 .14456 Mdot
.34082 .3455 Mdot
.75722 .66128 Mdot
.50915 .07044 Mdot
.36237 .11321 Mdot
.55374 .24757 Mdot
.6643 .12654 Mdot
.42271 .01374 Mdot
.56916 .56119 Mdot
.5709 .00179 Mdot
.41982 .39401 Mdot
.67809 .10485 Mdot
.77866 .33817 Mdot
.4276 .85037 Mdot
.93246 .5886 Mdot
.82807 .86996 Mdot
.6588 .38515 Mdot
.36449 .53085 Mdot
.08542 .16807 Mdot
.85322 .60796 Mdot
.4256 .69775 Mdot
.37172 .51501 Mdot
.0956 .39309 Mdot
.60361 .31996 Mdot
.40685 .14427 Mdot
.26653 .55956 Mdot
.38418 .46524 Mdot
.34915 .78131 Mdot
.63524 .16987 Mdot
.89404 .33876 Mdot
.64023 .91212 Mdot
.95108 .64216 Mdot
.12374 .12474 Mdot
.66886 .21596 Mdot
.11825 .82101 Mdot
.97425 .80667 Mdot
.62261 .76783 Mdot
.61793 .15534 Mdot
.32771 .21119 Mdot
.35925 .28488 Mdot
.6029 .13045 Mdot
.37622 .03517 Mdot
.05329 .30839 Mdot
.33479 .48328 Mdot
.83861 .09441 Mdot
.75597 .35613 Mdot
.80956 .18292 Mdot
.87187 .46084 Mdot
.09816 .50686 Mdot
.16425 .39533 Mdot
.67953 .20526 Mdot
.89453 .01989 Mdot
.98617 .98569 Mdot
.42948 .07506 Mdot
.02327 .76569 Mdot
.18435 .50162 Mdot
.27534 .76079 Mdot
.33741 .23528 Mdot
.55484 .48709 Mdot
.55562 .68496 Mdot
.3686 .07024 Mdot
.48161 .37937 Mdot
.7788 .77554 Mdot
.67699 .2686 Mdot
.70204 .88039 Mdot
.15834 .28388 Mdot
.58792 .02336 Mdot
.06411 .69168 Mdot
.22256 .3527 Mdot
.63637 .54642 Mdot
.75752 .77645 Mdot
.17069 .77207 Mdot
.29963 .79497 Mdot
.59893 .30297 Mdot
.61101 .93087 Mdot
.01123 .94481 Mdot
.99896 .14093 Mdot
.76383 .75144 Mdot
.32152 .0273 Mdot
.78919 .96848 Mdot
.00786 .76457 Mdot
.06323 .51162 Mdot
.34171 .07963 Mdot
.98092 .82963 Mdot
.95263 .19385 Mdot
.29223 .43615 Mdot
.43133 .35448 Mdot
.37035 .40206 Mdot
.34251 .30355 Mdot
.51683 .74206 Mdot
.11138 .18578 Mdot
.81791 .86398 Mdot
.01381 .33101 Mdot
.84516 .2605 Mdot
.7612 .34161 Mdot
.77382 .52231 Mdot
.71975 .23684 Mdot
.39167 .17566 Mdot
.37884 .79346 Mdot
.1108 .68354 Mdot
.946 .57983 Mdot
.50414 .03237 Mdot
.92416 .3029 Mdot
.77599 .2587 Mdot
.82004 .88246 Mdot
.01996 .90844 Mdot
.1489 .45033 Mdot
.15683 .29619 Mdot
.51885 .30275 Mdot
.67537 .20961 Mdot
.23089 .59918 Mdot
.65408 .43576 Mdot
.19538 .11037 Mdot
.06128 .49355 Mdot
.36203 .71669 Mdot
.19426 .32433 Mdot
.45117 .92441 Mdot
.26338 .50597 Mdot
.39203 .384 Mdot
.01648 .11983 Mdot
.78296 .9903 Mdot
.25157 .99996 Mdot
.64191 .48075 Mdot
.68649 .65366 Mdot
.35648 .46084 Mdot
.53634 .06946 Mdot
.90489 .83541 Mdot
.43266 .83607 Mdot
.54471 .82125 Mdot
.07886 .41956 Mdot
.0631 .52702 Mdot
.97199 .20946 Mdot
.36899 .4462 Mdot
.8106 .11955 Mdot
.6374 .87554 Mdot
.03467 .55639 Mdot
.3699 .5038 Mdot
.40731 .3965 Mdot
.37503 .75895 Mdot
.06583 .65055 Mdot
.91999 .84864 Mdot
.07774 .32075 Mdot
.76772 .23013 Mdot
.01579 .20085 Mdot
.30941 .87485 Mdot
.29494 .99173 Mdot
.76198 .90985 Mdot
.17113 .52478 Mdot
.48111 .49521 Mdot
.673 .03788 Mdot
.01613 .82658 Mdot
.51717 .29723 Mdot
.18644 .06912 Mdot
.53025 .88628 Mdot
.50858 .74821 Mdot
.60428 .77535 Mdot
.10919 .96333 Mdot
.40013 .69344 Mdot
.43879 .96361 Mdot
.13882 .25839 Mdot
.04717 .55796 Mdot
.55604 .30986 Mdot
.93973 .64222 Mdot
.94802 .92284 Mdot
.66316 .66332 Mdot
.32958 .94684 Mdot
.24492 .0054 Mdot
.81421 .26128 Mdot
.22442 .13254 Mdot
.50413 .47859 Mdot
.87669 .07787 Mdot
.27543 .31054 Mdot
.92043 .61079 Mdot
.8094 .91004 Mdot
.88964 .87885 Mdot
.77058 .07702 Mdot
.13707 .12622 Mdot
.53194 .04025 Mdot
.98336 .21022 Mdot
.80731 .86902 Mdot
.84796 .16838 Mdot
.39242 .4797 Mdot
.88106 .00082 Mdot
.02701 .25891 Mdot
.05172 .4806 Mdot
.30743 .25915 Mdot
.25052 .51154 Mdot
.44707 .09109 Mdot
.0234 .29475 Mdot
.0046 .9614 Mdot
.12942 .99536 Mdot
.28774 .18237 Mdot
.19232 .91598 Mdot
.98544 .61274 Mdot
.2211 .82527 Mdot
.86846 .44283 Mdot
.08009 .43454 Mdot
.47057 .27354 Mdot
.91876 .01308 Mdot
.11305 .09299 Mdot
.98547 .80777 Mdot
.01791 .04213 Mdot
.94577 .72345 Mdot
.82034 .94934 Mdot
.66388 .71784 Mdot
.92577 .24635 Mdot
.3539 .80205 Mdot
.96703 .71463 Mdot
.18383 .45766 Mdot
.40655 .52975 Mdot
.17475 .35452 Mdot
.38288 .52764 Mdot
.27841 .63613 Mdot
.27475 .39674 Mdot
.42367 .82453 Mdot
.54349 .53701 Mdot
.66921 .01703 Mdot
.70861 .19953 Mdot
.4061 .12548 Mdot
.65063 .39554 Mdot
.13196 .75791 Mdot
.33496 .95577 Mdot
.868 .49389 Mdot
.86157 .51739 Mdot
.67909 .94759 Mdot
.67629 .03062 Mdot
.34607 .03304 Mdot
.22223 .58345 Mdot
.58679 .92548 Mdot
.60355 .29359 Mdot
.09022 .88986 Mdot
.86239 .80893 Mdot
.04796 .04217 Mdot
.61838 .94292 Mdot
.09138 .6376 Mdot
.66667 .51449 Mdot
.32269 .78091 Mdot
.90128 .39382 Mdot
.06658 .65744 Mdot
.76846 .90037 Mdot
.56978 .64283 Mdot
.25479 .69572 Mdot
.39012 .84262 Mdot
.48317 .79867 Mdot
.43161 .89106 Mdot
.77448 .94562 Mdot
.43018 .16304 Mdot
.19754 .52053 Mdot
.0188 .47225 Mdot
.38703 .21713 Mdot
.86098 .90494 Mdot
.52865 .2265 Mdot
.38157 .17229 Mdot
.36306 .61988 Mdot
.90256 .23906 Mdot
.97078 .73294 Mdot
.38047 .43899 Mdot
.1061 .69608 Mdot
.04044 .1856 Mdot
.81818 .08463 Mdot
.11264 .62339 Mdot
.52177 .95802 Mdot
.1608 .80893 Mdot
.90251 .82178 Mdot
.86961 .72778 Mdot
.62958 .29039 Mdot
.87805 .57707 Mdot
.74839 .46842 Mdot
.40703 .04773 Mdot
.73308 .86305 Mdot
.45664 .95224 Mdot
.82431 .68817 Mdot
.43348 .23858 Mdot
.39345 .81966 Mdot
.18256 .33979 Mdot
.5804 .08781 Mdot
.40272 .5222 Mdot
.86061 .70815 Mdot
.43602 .03556 Mdot
.20183 .14913 Mdot
.93825 .89781 Mdot
.55944 .37643 Mdot
.57295 .03509 Mdot
.64494 .5993 Mdot
.04873 .88718 Mdot
.16208 .86993 Mdot
.957 .63781 Mdot
.6722 .873 Mdot
.46391 .0244 Mdot
.72109 .07418 Mdot
.11745 .8992 Mdot
.4291 .83604 Mdot
.08881 .91153 Mdot
.96 .54898 Mdot
.60657 .78641 Mdot
.22458 .85993 Mdot
.46758 .98867 Mdot
.97187 .08006 Mdot
.60039 .44084 Mdot
.38994 .29788 Mdot
.04725 .32622 Mdot
.57887 .31288 Mdot
.01952 .33711 Mdot
.24013 .56708 Mdot
.83979 .33614 Mdot
.19054 .10892 Mdot
.14366 .4607 Mdot
.05653 .15846 Mdot
.58593 .56227 Mdot
.99409 .98933 Mdot
.07562 .21064 Mdot
.51404 .78199 Mdot
.93776 .97472 Mdot
.84573 .37815 Mdot
.01027 .54692 Mdot
.69532 .90115 Mdot
.07924 .121 Mdot
.59466 .88287 Mdot
.84688 .56982 Mdot
.44803 .63399 Mdot
.35089 .91743 Mdot
.54351 .55471 Mdot
.18473 .79585 Mdot
.93863 .86351 Mdot
.33684 .91173 Mdot
.00496 .39476 Mdot
.41632 .27477 Mdot
.21884 .58355 Mdot
.24644 .24425 Mdot
.71467 .61243 Mdot
.30989 .5841 Mdot
.17655 .06852 Mdot
.05008 .57724 Mdot
.72197 .42318 Mdot
.77463 .87169 Mdot
.69293 .47009 Mdot
.52903 .04962 Mdot
.59912 .16499 Mdot
.20203 .68445 Mdot
.46945 .49066 Mdot
.86626 .35086 Mdot
.66548 .79026 Mdot
.64539 .6771 Mdot
.39948 .8116 Mdot
.50613 .00877 Mdot
.76545 .47755 Mdot
.64106 .22728 Mdot
.98183 .91784 Mdot
.20169 .26797 Mdot
.29442 .84247 Mdot
.91029 .49274 Mdot
.91439 .26043 Mdot
.95441 .23113 Mdot
.15864 .38219 Mdot
.39806 .46496 Mdot
.85007 .48065 Mdot
.80265 .36544 Mdot
.17337 .09315 Mdot
.25123 .22828 Mdot
.28087 .26516 Mdot
.95891 .05077 Mdot
.8978 .51267 Mdot
.14034 .46752 Mdot
.07303 .16153 Mdot
.09571 .32556 Mdot
.82493 .691 Mdot
.78732 .9513 Mdot
.88536 .1189 Mdot
.89497 .49494 Mdot
.80097 .11638 Mdot
.73245 .35631 Mdot
.60988 .76239 Mdot
.68311 .39634 Mdot
.62272 .33872 Mdot
.45407 .83965 Mdot
.45957 .26685 Mdot
.44799 .60299 Mdot
.72417 .48712 Mdot
.75118 .74338 Mdot
.74972 .27715 Mdot
.76622 .15675 Mdot
.03881 .07135 Mdot
.12312 .89088 Mdot
.5186 .39942 Mdot
.52946 .58408 Mdot
.80559 .9703 Mdot
.9863 .65521 Mdot
.257 .79328 Mdot
.62802 .14108 Mdot
.62152 .39553 Mdot
.78703 .30824 Mdot
.78184 .20728 Mdot
.11009 .06202 Mdot
.83281 .04631 Mdot
.89766 .25998 Mdot
.40456 .73763 Mdot
.2771 .58595 Mdot
.50808 .67731 Mdot
.38208 .02177 Mdot
.16166 .97398 Mdot
.84309 .97024 Mdot
.6297 .66807 Mdot
.9671 .57153 Mdot
.75785 .54983 Mdot
.94655 .59997 Mdot
.83534 .59345 Mdot
.95915 .2484 Mdot
.52122 .76631 Mdot
.77151 .75334 Mdot
.92325 .17875 Mdot
.30048 .82087 Mdot
.67124 .11523 Mdot
.54637 .76106 Mdot
.13177 .53761 Mdot
.49001 .27894 Mdot
.46358 .07773 Mdot
.6338 .77003 Mdot
.5376 .3943 Mdot
.58503 .42981 Mdot
.10709 .53822 Mdot
.90371 .7684 Mdot
.27387 .44949 Mdot
.51388 .0366 Mdot
.51273 .42389 Mdot
.0567 .18634 Mdot
.47205 .79663 Mdot
.47756 .8173 Mdot
.91791 .80868 Mdot
.93389 .13698 Mdot
.47051 .32386 Mdot
.25891 .79754 Mdot
.27378 .69446 Mdot
.44485 .11968 Mdot
.91042 .15467 Mdot
.84061 .17252 Mdot
.48755 .8215 Mdot
.69355 .07675 Mdot
.92539 .11534 Mdot
.12569 .17072 Mdot
.09692 .21617 Mdot
.28328 .94297 Mdot
.71646 .98341 Mdot
.93476 .05527 Mdot
.35215 .19813 Mdot
.58027 .02527 Mdot
.35291 .9528 Mdot
.82925 .9427 Mdot
.95473 .04198 Mdot
.04508 .77535 Mdot
.93903 .01689 Mdot
.82957 .696 Mdot
.9328 .71028 Mdot
.63696 .84319 Mdot
.3075 .81694 Mdot
.79232 .69785 Mdot
.8648 .70921 Mdot
.12173 .76095 Mdot
.60224 .66619 Mdot
.38329 .90942 Mdot
.55718 .71468 Mdot
.42764 .04382 Mdot
.52749 .78827 Mdot
.50742 .25838 Mdot
.50508 .98795 Mdot
.78064 .32593 Mdot
.10757 .26141 Mdot
.07853 .71898 Mdot
.15339 .46264 Mdot
.86555 .86802 Mdot
.64127 .88809 Mdot
.57389 .04826 Mdot
.17318 .08355 Mdot
.05619 .09529 Mdot
.73523 .38494 Mdot
.63972 .92626 Mdot
.14166 .48737 Mdot
.76865 .50979 Mdot
.94369 .13517 Mdot
.60066 .88053 Mdot
.69991 .58325 Mdot
.64398 .9221 Mdot
.14845 .78532 Mdot
.15991 .78335 Mdot
.88559 .61332 Mdot
.01303 .77866 Mdot
.23936 .31734 Mdot
.46422 .76299 Mdot
.00745 .92031 Mdot
.60533 .1625 Mdot
.1549 .69399 Mdot
.09486 .19228 Mdot
.36552 .02173 Mdot
.36085 .36081 Mdot
.30573 .14634 Mdot
.11117 .48748 Mdot
.33011 .44342 Mdot
.18736 .61797 Mdot
.18056 .21636 Mdot
.81363 .94627 Mdot
.08318 .386 Mdot
.11843 .6929 Mdot
.01835 .60212 Mdot
.11445 .41033 Mdot
.743 .6706 Mdot
.66289 .13933 Mdot
.34679 .43368 Mdot
.46196 .74305 Mdot
.10614 .08113 Mdot
.3647 .03405 Mdot
.83551 .7748 Mdot
.64101 .17744 Mdot
.84301 .47791 Mdot
.61182 .39437 Mdot
.73509 .78701 Mdot
.40887 .07412 Mdot
.08134 .20585 Mdot
.83559 .84531 Mdot
.8248 .68261 Mdot
.28414 .01207 Mdot
.62779 .69166 Mdot
.00853 .88847 Mdot
.88212 .82804 Mdot
.4591 .80061 Mdot
.94967 .25839 Mdot
.937 .31489 Mdot
.1246 .38348 Mdot
.43795 .3315 Mdot
.95283 .26656 Mdot
.51214 .57649 Mdot
.2175 .67487 Mdot
.31884 .47494 Mdot
.50025 .89456 Mdot
.2195 .49678 Mdot
.70773 .15669 Mdot
.85106 .78781 Mdot
.66887 .80883 Mdot
.00496 .38085 Mdot
.63413 .33441 Mdot
.47633 .13945 Mdot
.59195 .15673 Mdot
.05414 .6533 Mdot
.2837 .57113 Mdot
.64475 .08806 Mdot
.69373 .58719 Mdot
.51504 .68181 Mdot
.89681 .33975 Mdot
.75443 .9846 Mdot
.13782 .62152 Mdot
.65962 .51344 Mdot
.59383 .19714 Mdot
.09432 .46344 Mdot
.09117 .13096 Mdot
.13009 .90053 Mdot
.71758 .46882 Mdot
.39587 .72246 Mdot
.11289 .97218 Mdot
.97056 .13045 Mdot
.12779 .54106 Mdot
.30596 .23596 Mdot
.89954 .00949 Mdot
.556 .6325 Mdot
.39699 .90204 Mdot
.3729 .07877 Mdot
.2151 .86174 Mdot
.15188 .08895 Mdot
.58687 .30261 Mdot
.84649 .45625 Mdot
.38304 .24133 Mdot
.78626 .23515 Mdot
.34542 .60912 Mdot
.57045 .08966 Mdot
.3556 .50976 Mdot
.92468 .54778 Mdot
.04954 .69887 Mdot
.64149 .37866 Mdot
.74542 .92715 Mdot
.39922 .20053 Mdot
.24785 .71337 Mdot
.64271 .83455 Mdot
.77452 .38249 Mdot
.76601 .50805 Mdot
.51954 .8634 Mdot
.28581 .50753 Mdot
.07302 .26237 Mdot
.27215 .05016 Mdot
.1143 .47411 Mdot
.71987 .5809 Mdot
.45832 .63705 Mdot
.41066 .29068 Mdot
.30112 .83339 Mdot
.8582 .54657 Mdot
.61522 .36008 Mdot
.00122 .94909 Mdot
.18614 .58678 Mdot
.80595 .35062 Mdot
.02328 .41455 Mdot
.62427 .39101 Mdot
.81828 .85077 Mdot
.81389 .90079 Mdot
.44998 .30364 Mdot
.49288 .51985 Mdot
.06068 .5602 Mdot
.72527 .063 Mdot
.53469 .1094 Mdot
.63325 .20396 Mdot
.43812 .43225 Mdot
.91661 .76399 Mdot
.32626 .10784 Mdot
.38231 .4622 Mdot
.41717 .16669 Mdot
.47808 .65187 Mdot
.05631 .77342 Mdot
.0744 .04245 Mdot
.90734 .30251 Mdot
.26002 .88886 Mdot
.46257 .10296 Mdot
.53627 .77469 Mdot
.11414 .5805 Mdot
.70982 .9209 Mdot
.6977 .56313 Mdot
.23658 .54804 Mdot
.19093 .48599 Mdot
.84825 .98641 Mdot
.2239 .62163 Mdot
.86315 .85495 Mdot
.22742 .40922 Mdot
.51445 .87643 Mdot
.67435 .39516 Mdot
.06771 .19164 Mdot
.65086 .72529 Mdot
.26804 .18151 Mdot
.86322 .07161 Mdot
.12105 .72273 Mdot
.76208 .6762 Mdot
.18274 .82606 Mdot
.44844 .9639 Mdot
.40969 .88157 Mdot
.31046 .4645 Mdot
.80452 .91534 Mdot
.72595 .15857 Mdot
.82753 .81442 Mdot
.98555 .52392 Mdot
.46849 .54162 Mdot
.2119 .36251 Mdot
.43823 .72947 Mdot
.53943 .77671 Mdot
.16497 .99319 Mdot
.00051 .90284 Mdot
.84592 .02079 Mdot
.60025 .52759 Mdot
.95153 .19547 Mdot
.96529 .27847 Mdot
.21411 .47285 Mdot
.88953 .84549 Mdot
.65488 .02068 Mdot
.76775 .39261 Mdot
.30677 .20192 Mdot
.31854 .52592 Mdot
.05175 .29866 Mdot
.40781 .71414 Mdot
.29587 .18791 Mdot
.71664 .27513 Mdot
.43544 .90178 Mdot
.84128 .90687 Mdot
.13105 .5188 Mdot
.04144 .97236 Mdot
.56583 .58834 Mdot
.36345 .66824 Mdot
.16917 .29679 Mdot
.95424 .05282 Mdot
.20675 .08793 Mdot
.63706 .2477 Mdot
.82122 .98918 Mdot
.83053 .06204 Mdot
.47704 .99768 Mdot
.07829 .24517 Mdot
.25551 .56828 Mdot
.94649 .18364 Mdot
.7796 .89051 Mdot
.67231 .60486 Mdot
.5201 .50404 Mdot
.62748 .46235 Mdot
.40285 .50635 Mdot
.90099 .30371 Mdot
.49162 .42675 Mdot
.97996 .15209 Mdot
.10554 .33873 Mdot
.99101 .99735 Mdot
.75965 .86108 Mdot
.95445 .90325 Mdot
.06919 .87952 Mdot
.37266 .38825 Mdot
.63949 .28533 Mdot
.65501 .83619 Mdot
.14601 .86883 Mdot
.66411 .621 Mdot
.74358 .3517 Mdot
.59409 .37838 Mdot
.54916 .10274 Mdot
.51218 .47181 Mdot
.69945 .15231 Mdot
.46699 .65921 Mdot
.71897 .36315 Mdot
.18417 .18119 Mdot
.16986 .16821 Mdot
.61949 .43535 Mdot
.93484 .38865 Mdot
.0448 .72512 Mdot
.28044 .94724 Mdot
.3608 .43642 Mdot
.64135 .93421 Mdot
.75814 .8743 Mdot
.85152 .69171 Mdot
.38124 .30526 Mdot
.22149 .23742 Mdot
.10623 .21424 Mdot
.14061 .15986 Mdot
.39734 .68881 Mdot
.11668 .67984 Mdot
.44223 .87375 Mdot
.92634 .82374 Mdot
.17114 .52698 Mdot
.19633 .97978 Mdot
.32181 .56239 Mdot
.43441 .19874 Mdot
.03135 .34716 Mdot
.12266 .87162 Mdot
.8344 .22343 Mdot
.07097 .80197 Mdot
.34661 .44572 Mdot
.8647 .03138 Mdot
.81551 .4822 Mdot
.84826 .29766 Mdot
.73451 .86522 Mdot
.56167 .40857 Mdot
.50213 .2116 Mdot
.21711 .12052 Mdot
.5617 .95364 Mdot
.1839 .1588 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00?o
oooo0_l00008ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool2o`0000Wo
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo0_l00005ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`02ooooo`007_ooool00ol0003oooooooooo`03ooooo`;o00002?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0;ooooo`?o00003oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
0_l00005ooooo`;o00002Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool00_ooool001kooooo00?o0000ooooooooool0C?ooool2o`0005;ooooo0_l0
000<ooooo`;o0000L?ooool2o`0002Gooooo000Nooooo`03o`000?oooooooooo05Sooooo0_l0000[
ooooo`;o00006Oooool2o`0007kooooo0_l00005ooooo`;o00007_ooool001kooooo00?o0000oooo
ooooool0F?ooool2o`0002Sooooo0_l000000ooooooo0000o`00002Pooooo`;o00000oooool2o`00
01Wooooo000Nooooo`03o`000?oooooooooo06?ooooo0_l0000Mooooo`;o0000DOooool2o`0004So
oooo0_l0000;ooooo`?o00006?ooool001kooooo00?o0000ooooooooool0Hoooool2o`0000kooooo
0_l00003ooooo`;o0000Eoooool2o`0000;ooooo0_l0000hooooo`;o00003_ooool2o`0000cooooo
0_l0000Hooooo`007_ooool00ol0003oooooooooo`16ooooo`;o0000:oooool2o`0000?ooooo0_l0
000Iooooo`;o00009?ooool4o`0001Cooooo0_l0000looooo`;o0000=_ooool001kooooo00?o0000
ooooooooool0A_ooool2o`0001cooooo0_l0000]ooooo`;o00009?ooool4o`0008[ooooo000Noooo
o`03o`000?oooooooooo06Cooooo0_l0000Nooooo`;o0000D_ooool2o`0003_ooooo0_l0000`oooo
o`007_ooool00ol0003oooooooooo`1/ooooo`;o00001?ooool2o`0000;ooooo0_l0000<ooooo`;o
00006_ooool2o`0001Cooooo0_l0000Pooooo`;o0000>oooool2o`00033ooooo000Nooooo`03o`00
0?oooooooooo06cooooo0_l00004ooooo`;o00000_ooool2o`0001;ooooo0_l0000Dooooo`;o0000
00?oooooo`000?l000004Oooool2o`0001oooooo0_l0001^ooooo`007_ooool00ol0003ooooooooo
o`0Hooooo`;o0000=Oooool2o`0003Wooooo0_l0000Gooooo`;o00001?ooool2o`0002cooooo0_l0
001^ooooo`007_ooool00ol0003oooooooooo`02ooooo`;o00001oooool2o`0000Oooooo0_l00002
ooooo`;o0000=Oooool2o`0003Kooooo0_l0000Looooo`;o00000_ooool2o`0008Oooooo0_l0000C
ooooo`007_ooool00ol0003oooooooooo`02ooooo`;o00001oooool2o`0000Oooooo0_l0001aoooo
o`;o00007?ooool2o`0006Cooooo0_l0000Uooooo`;o00004oooool001kooooo00?o0000oooooooo
ool0E?ooool2o`0002[ooooo0_l00008ooooo`;o00007?ooool2o`0000cooooo0_l0001Cooooo`?o
0000>Oooool001kooooo0_l0001Eooooo`;o0000:_ooool2o`0000Sooooo0_l0000Looooo`;o0000
3?ooool2o`0003cooooo0_l0000Fooooo`;o00009?ooool4o`00017ooooo000Nooooo`03o`000?oo
oooooooo0?Cooooo0_l0000fooooo`;o00001?ooool4o`0000[ooooo0_l00005ooooo`007_ooool0
0ol0003oooooooooo`3oooooobgooooo0_l0000Booooo`;o00001Oooool001kooooo00?o0000oooo
ooooool08?ooool2o`000003ooooool0003o00000>Gooooo0_l0000kooooo`007_ooool00ol0003o
ooooooooo`0Pooooo`;o000000?oooooo`000?l00000`oooool2o`00023ooooo0_l0000kooooo`00
7_ooool00ol0003oooooooooo`0eooooo`;o0000/Oooool2o`0003Wooooo0_l0000Rooooo`007_oo
ool00ol0003oooooooooo`08ooooo`;o0000:oooool2o`000003ooooool0003o000003[ooooo0_l0
000@ooooo`;o00006Oooool2o`0000Oooooo0_l0001Yooooo`;o00003?ooool2o`0002;ooooo000N
ooooo`03o`000?oooooooooo00Sooooo0_l0000^ooooo`;o0000>_ooool2o`0000_ooooo0_l00003
ooooo`Co00005oooool2o`0000Oooooo0_l0000jooooo`;o0000;Oooool2o`00033ooooo000Noooo
o`03o`000?oooooooooo00oooooo0_l0001`ooooo`;o00001Oooool2o`0000Wooooo0_l0000]oooo
o`;o00006Oooool2o`0000Oooooo0_l0000>ooooo`;o00008Oooool2o`0002cooooo000Nooooo`03
o`000?oooooooooo00oooooo0_l0000=ooooo`;o0000Boooool2o`0000Sooooo0_l0000Looooo`;o
0000;Oooool2o`0001Wooooo0_l0000Gooooo`;o00008Oooool2o`0001gooooo0_l0000=ooooo`00
7_ooool00ol0003oooooooooo`0Nooooo`;o00005?ooool2o`0003Gooooo0_l00008ooooo`;o0000
>_ooool2o`0008Gooooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`0dooooo`;o0000A?oo
ool2o`0003Gooooo0_l0000Booooo`;o0000?oooool2o`0003oooooo000Nooooo`03o`000?oooooo
oooo02gooooo0_l0000@ooooo`;o0000>Oooool2o`0003Wooooo0_l00002ooooo`;o00002_ooool2
o`0000Oooooo0_l0000fooooo`;o0000?oooool001kooooo00?o0000ooooooooool08Oooool2o`00
00[ooooo0_l00005ooooo`;o00002Oooool2o`0004cooooo0_l0000Vooooo`;o00000_ooool2o`00
01?ooooo0_l00012ooooo`;o00008Oooool2o`00013ooooo000Nooooo`03o`000?oooooooooo00ko
oooo0_l0000Aooooo`;o00004Oooool2o`0005Oooooo0_l0001Gooooo`;o00009Oooool2o`0000?o
oooo0_l0000Qooooo`;o00004?ooool001kooooo00?o0000ooooooooool03_ooool2o`000=Kooooo
0_l0000Uooooo`;o0000>?ooool001kooooo0_l0002_ooooo`;o0000Uoooool001kooooo00?o0000
ooooooooool0T_ooool2o`0001[ooooo0_l0000Xooooo`;o00003_ooool2o`0003;ooooo0_l0000Y
ooooo`007_ooool00ol0003oooooooooo`0jooooo`;o0000:_ooool2o`0002[ooooo0_l00014oooo
o`;o00003_ooool2o`0003;ooooo0_l0000Yooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o
00009oooool3o`0002Wooooo0_l00012ooooo`;o0000A_ooool2o`0005?ooooo000Nooooo`03o`00
0?oooooooooo017ooooo0_l0000Xooooo`;o0000=Oooool2o`0003Kooooo0_l0000Zooooo`;o0000
6_ooool2o`0005?ooooo000Nooooo`03o`000?oooooooooo05Cooooo0_l0000Looooo`;o0000<Ooo
ool2o`0002oooooo0_l0000Xooooo`;o00009oooool2o`0001cooooo000Nooooo`04o`000?oooooo
ooooooooo`;o00004oooool2o`0002[ooooo0_l0000@ooooo`;o00002Oooool2o`0002cooooo0_l0
000Fooooo`;o0000FOooool2o`000003ooooool0003o000001Oooooo0_l0000;ooooo`;o00007?oo
ool001kooooo00Co0000oooooooooooooooo0_l0000Cooooo`;o0000:_ooool2o`0001_ooooo0_l0
000/ooooo`;o0000M?ooool2o`0001Oooooo0_l0000Jooooo`;o00003Oooool001kooooo00?o0000
ooooooooool09?ooool2o`0000;ooooo0_l0001Fooooo`;o0000D_ooool2o`0000_ooooo0_l0001E
ooooo`;o00003Oooool001kooooo00?o0000ooooooooool09?ooool2o`0000;ooooo0_l0001Foooo
o`;o0000?_ooool2o`0001;ooooo0_l0000;ooooo`;o0000E?ooool2o`0000kooooo000Nooooo`03
o`000?oooooooooo01[ooooo0_l0000Yooooo`;o0000NOooool2o`0007?ooooo1?l0000>ooooo`00
7_ooool00ol0003oooooooooo`0Jooooo`;o0000:Oooool2o`0004Gooooo0_l0002Qooooo`;o0000
00Coooooo`000?l0003ooooo0_l0000@ooooo`007_ooool00ol0003oooooooooo`2<ooooo`;o0000
2Oooool2o`0003[ooooo0_l0001Gooooo`;o000000Coooooo`000?l0003ooooo0_l0000Cooooo`00
7_ooool00ol0003oooooooooo`2Gooooo`;o0000;oooool2o`0000Wooooo0_l0001Gooooo`;o0000
4oooool2o`0000Cooooo000Nooooo`03o`000?oooooooooo083ooooo0_l00016ooooo`;o00008?oo
ool2o`0004oooooo0_l00004ooooo`;o00001?ooool001kooooo00?o0000ooooooooool0Goooool2
o`0001oooooo0_l0001Xooooo`;o0000Coooool2o`0000[ooooo000Nooooo`;o00009oooool2o`00
01Gooooo0_l0000>ooooo`;o00004?ooool2o`000=Wooooo0_l0000;ooooo`007_ooool00ol0003o
ooooooooo`0Vooooo`;o00005Oooool2o`0000kooooo0_l0002@ooooo`;o0000@oooool2o`0001Co
oooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`2looooo`;o00001oooool2o`0001Sooooo
0_l000000ooooooo0000o`00000Aooooo`;o0000;Oooool2o`00027ooooo000Nooooo`03o`000?oo
oooooooo00kooooo0_l0000Jooooo`;o00003?ooool2o`0008;ooooo0_l00007ooooo`;o00006ooo
ool2o`0000Cooooo0_l0000;ooooo`;o00002?ooool2o`0004Kooooo000Nooooo`03o`000?oooooo
oooo00kooooo0_l00004ooooo`;o00005?ooool2o`0000cooooo0_l0000Kooooo`;o0000<Oooool2
o`0003Oooooo0_l0000Uooooo`;o00005Oooool2o`0004Kooooo000Nooooo`03o`000?oooooooooo
01Cooooo0_l0000oooooo`;o0000;Oooool2o`0000;ooooo0_l0000eooooo`Co0000Q?ooool001ko
oooo00?o0000ooooooooool06?ooool2o`0001Wooooo0_l0001?ooooo`;o0000>Oooool2o`0000Wo
oooo0_l00014ooooo`;o0000=Oooool001gooooo0_l0000Jooooo`;o00002oooool2o`0000cooooo
0_l00013ooooo`;o0000D?ooool2o`00047ooooo0_l000000ooooooo0000o`00000eooooo`007Ooo
ool2o`0001kooooo0_l00007ooooo`;o00006?ooool2o`0003Oooooo0_l000000ooooooo0000o`00
002@ooooo`;o0000>?ooool001kooooo00?o0000ooooooooool07?ooool2o`00027ooooo0_l0000j
ooooo`;o0000Coooool2o`0005[ooooo0_l0000Mooooo`007_ooool00ol0003oooooooooo`0hoooo
o`;o00003?ooool2o`0000_ooooo0_l00004ooooo`;o0000LOooool2o`0005[ooooo0_l0000Moooo
o`007_ooool00ol0003oooooooooo`09ooooo`;o00005Oooool2o`0001Kooooo0_l0000<ooooo`;o
00002oooool2o`0000Cooooo0_l0002Tooooo`;o00000_ooool2o`0002_ooooo0_l0000Eooooo`00
7_ooool00ol0003oooooooooo`09ooooo`;o00000oooool2o`00013ooooo0_l0000jooooo`;o0000
KOooool2o`0000Sooooo0_l0000Xooooo`;o00000_ooool2o`0002_ooooo0_l0000Eooooo`007_oo
ool00ol0003oooooooooo`0>ooooo`;o000000Coooooo`000?l0003o0000=?ooool2o`0001;ooooo
0_l0001]ooooo`;o00002?ooool2o`00073ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo00gooooo0_l00002ooooo`?o0000
1oooool2o`0002_ooooo0_l0000Uooooo`;o0000`Oooool2o`0001?ooooo0003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03
o`000?oooooooooo00gooooo0_l0000<ooooo`;o0000DOooool3o`0004cooooo0_l0001booooo`?o
00004oooool000?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo0ol000000ooooooo0000o`00001[ooooo`;o00003_ooool2o`0000Wooooo0_l00007ooooo`;o
0000:Oooool2o`0002?ooooo0_l0001=ooooo`;o00005?ooool000?ooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00Co0000oooooooooooooooo0_l0001Moooo
o`;o00007?ooool2o`0000Wooooo0_l00007ooooo`;o00001Oooool2o`0002oooooo0_l0000Foooo
o`;o0000@_ooool2o`0001oooooo0003ooooo`05o`000?ooooooooooooooool000003_ooool00omg
MgOoIVIVooooo`05ooooo`03o`000?oooooooooo01Kooooo0_l00018ooooo`;o00003Oooool2o`00
02Sooooo0_l0000_ooooo`;o00003Oooool2o`0001oooooo0_l0000Zooooo`;o00007oooool000?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool05_ooool2o`0004Sooooo0_l0000=ooooo`;o0000I_ooool4o`0001oooooo0_l0000loooo
o`;o00000_ooool2o`0000Wooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool05?ooool2o`0004[ooooo0_l00004
ooooo`;o0000=oooool2o`0003Kooooo0_l0001Oooooo`;o00000_ooool2o`0000Wooooo0003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o
0000ooooooooool05?ooool2o`0000Gooooo0_l000000ooooooo0000o`00000Gooooo`;o0000;Ooo
ool2o`0003Oooooo0_l00003ooooo`;o0000;oooool2o`00073ooooo000Nooooo`03o`000?oooooo
oooo01_ooooo0_l000000ooooooo0000o`00000Gooooo`;o0000@Oooool2o`0002Sooooo0_l0000_
ooooo`;o0000L?ooool001kooooo00?o0000ooooooooool0N_ooool2o`0001cooooo0_l0001=oooo
o`;o0000G_ooool001kooooo00?o0000ooooooooool0V?ooool2o`0004gooooo0_l0000Rooooo`;o
0000>_ooool001kooooo00?o0000ooooooooool0C_ooool2o`0005Sooooo0_l0000Rooooo`;o0000
?Oooool4o`0003Sooooo000Nooooo`03o`000?oooooooooo04kooooo0_l0001Hooooo`;o00000_oo
ool2o`0001kooooo0_l0000Fooooo`;o00003oooool2o`0001Kooooo0ol0000Rooooo`;o00004ooo
ool001kooooo00?o0000ooooooooool0MOooool2o`0003Gooooo0_l0000fooooo`;o00003oooool2
o`0000Gooooo0_l0000@ooooo`;o00008_ooool2o`0001?ooooo000Nooooo`03o`000?oooooooooo
04Cooooo0_l0000Iooooo`;o00002Oooool2o`0000Wooooo0_l0000Tooooo`;o0000BOooool2o`00
01Cooooo0_l00019ooooo`007_ooool00ol0003oooooooooo`14ooooo`;o00006Oooool2o`0000Wo
oooo0_l0000<ooooo`;o00003oooool2o`00013ooooo0_l00019ooooo`;o0000>Oooool2o`0002Co
oooo000Nooooo`03o`000?oooooooooo04cooooo0_l0000Zooooo`;o00003oooool2o`0009Kooooo
0_l0000Tooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o0000=Oooool2o`000=_ooooo0_l0
000Looooo`007_ooool00ol0003oooooooooo`0Eooooo`;o0000C?ooool2o`0004_ooooo0_l0000B
ooooo`;o00001Oooool2o`0005cooooo0_l00009ooooo`;o00004Oooool001kooooo0_l0001Toooo
o`;o0000=Oooool2o`0001Cooooo0_l0000Booooo`;o00001Oooool2o`0006Oooooo0_l0000Aoooo
o`007_ooool00ol0003oooooooooo`2Jooooo`;o0000Zoooool001kooooo00?o0000ooooooooool0
1Oooool2o`0002;ooooo0_l0000eooooo`;o0000?oooool2o`0005Gooooo0_l0000gooooo`;o0000
5?ooool001kooooo00?o0000ooooooooool01Oooool2o`0000gooooo0_l00009ooooo`;o00002?oo
ool2o`0003Gooooo0_l0000oooooo`;o0000EOooool2o`0000_ooooo0_l00008ooooo`;o00003ooo
ool4o`000003ooooool0003o000000[ooooo0_l0000Dooooo`007_ooool00ol0003oooooooooo`0D
ooooo`;o00002Oooool2o`0003Kooooo0_l0002/ooooo`;o00002?ooool2o`0000oooooo1?l00000
0ooooooo0000o`00000Pooooo`007_ooool00ol0003oooooooooo`0mooooo`;o00006?ooool2o`00
03Sooooo0_l0000hooooo`;o00002oooool2o`0005Sooooo0_l0000Cooooo`007_ooool00ol0003o
ooooooooo`0mooooo`;o0000D_ooool2o`0003Sooooo0_l0000;ooooo`;o0000F?ooool2o`0001?o
oooo000Nooooo`03o`000?oooooooooo08?ooooo0_l0000@ooooo`;o0000C_ooool2o`00063ooooo
000Nooooo`03o`000?oooooooooo08?ooooo0_l0000@ooooo`;o0000<oooool2o`0001Wooooo0_l0
0009ooooo`;o0000EOooool001kooooo00?o0000ooooooooool0Voooool2o`0002gooooo0_l0000T
ooooo`;o0000A?ooool2o`0000oooooo000Nooooo`03o`000?oooooooooo02oooooo0_l0001Zoooo
o`;o0000VOooool2o`0000oooooo000Nooooo`03o`000?oooooooooo02oooooo0_l00010ooooo`;o
0000FOooool2o`0000gooooo0_l0001Zooooo`007_ooool00ol0003oooooooooo`1aooooo`;o0000
E_ooool2o`000003ooooool0003o000000gooooo0_l0001Zooooo`007_ooool00ol0003ooooooooo
o`21ooooo`;o0000?Oooool2o`0000Oooooo0_l0001looooo`007_ooool00ol0003oooooooooo`03
ooooo`;o0000:_ooool2o`00053ooooo0_l0000mooooo`;o0000QOooool001kooooo00?o0000oooo
ooooool00oooool2o`0000Sooooo0_l0000Pooooo`;o00000_ooool2o`0000Cooooo0_l00010oooo
o`;o00001_ooool2o`0001oooooo0_l0001Zooooo`;o0000=Oooool001kooooo0_l0000>ooooo`;o
00009?ooool2o`0000Cooooo0_l00010ooooo`;o00001_ooool2o`0001oooooo0ol0000Dooooo`;o
00009?ooool2o`0001_ooooo0_l0000@ooooo`;o00004Oooool2o`0002;ooooo000Nooooo`03o`00
0?oooooooooo06_ooooo0_l0000;ooooo`;o00005?ooool2o`0001Gooooo0_l0000Dooooo`;o0000
0_ooool2o`00023ooooo0_l0000Kooooo`;o00008Oooool4o`0000?ooooo0_l0000Mooooo`007_oo
ool00ol0003oooooooooo`0=ooooo`;o0000G?ooool2o`0000_ooooo0_l0000Dooooo`;o0000;ooo
ool2o`0003_ooooo0_l0000Sooooo`;o00001Oooool2o`0001gooooo000Nooooo`03o`000?oooooo
oooo00gooooo0_l00016ooooo`;o00001Oooool2o`0005?ooooo0ol0000[ooooo`;o00006oooool2
o`0004Wooooo000Nooooo`03o`000?oooooooooo03[ooooo0_l0000Iooooo`;o00001Oooool2o`00
05?ooooo0ol00004ooooo`;o00009Oooool2o`0004cooooo0_l0000Hooooo`007_ooool00ol0003o
ooooooooo`0=ooooo`;o0000:oooool2o`0000kooooo0_l0001/ooooo`;o0000Loooool2o`0001So
oooo000Nooooo`03o`000?oooooooooo00gooooo0_l00006ooooo`;o0000<oooool2o`0000oooooo
0_l0001Sooooo`;o0000QOooool001kooooo00?o0000ooooooooool05Oooool2o`0002Cooooo0_l0
0007ooooo`;o00005Oooool2o`0002kooooo0_l00008ooooo`;o0000:Oooool2o`0008Gooooo000N
ooooo`03o`000?oooooooooo00_ooooo0_l0000>ooooo`;o00007_ooool2o`0000Oooooo0_l00015
ooooo`;o00002?ooool2o`0006?ooooo0_l0000=ooooo`;o0000??ooool001kooooo00?o0000oooo
ooooool02oooool2o`0000kooooo0_l0003Mooooo`;o00003Oooool2o`0003cooooo000Nooooo`03
o`000?oooooooooo00;o0000I_ooool2o`00023ooooo0_l0002kooooo`007_ooool00ol0003ooooo
ooooo`02o`0002Wooooo0_l0000kooooo`;o00008?ooool2o`0003kooooo0_l00011ooooo`;o0000
>?ooool001kooooo00?o0000ooooooooool00_ooool2o`0001[ooooo0_l0000;ooooo`;o0000VOoo
ool2o`0000;ooooo0_l0000]ooooo`;o00004_ooool2o`00013ooooo0_l0000Vooooo`007_ooool0
0ol0003oooooooooo`02ooooo`;o00006_ooool2o`0001Oooooo0_l0002=ooooo`;o0000:oooool2
o`0000Cooooo0_l0000Tooooo`;o00009_ooool001kooooo00?o0000ooooooooool0=oooool2o`00
03;ooooo0_l00026ooooo`;o0000D_ooool001kooooo00?o0000ooooooooool01_ooool2o`0006?o
oooo0_l0003Jooooo`007_ooool2o`0000Oooooo0_l0002fooooo`;o0000;_ooool2o`0001;ooooo
0_l0000Booooo`;o0000;oooool001kooooo00?o0000ooooooooool02Oooool2o`0000Cooooo0_l0
000Tooooo`;o00003Oooool2o`0004;ooooo0_l0000dooooo`;o0000;_ooool2o`0001;ooooo0_l0
000Booooo`;o0000;oooool001kooooo00?o0000ooooooooool02Oooool2o`0000Cooooo0_l0000T
ooooo`;o00003Oooool2o`0004;ooooo0_l0000mooooo`;o00008Oooool2o`0000Kooooo0_l0001C
ooooo`007_ooool00ol0003oooooooooo`1aooooo`;o0000DOooool2o`000003ooooool0003o0000
027ooooo0_l00006ooooo`;o0000Doooool001kooooo00?o0000ooooooooool0@Oooool2o`0002ko
oooo0_l0001Aooooo`;o00008?ooool2o`0000Gooooo0_l0001Hooooo`007_ooool00ol0003ooooo
ooooo`11ooooo`;o0000Xoooool2o`0000Gooooo0_l0000Booooo`;o0000A?ooool001kooooo00?o
0000ooooooooool0ooooool2ooooo`;o0000A?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`2booooo`;o0000Ooooool2o`0001;ooooo000Nooooo`03
o`000?oooooooooo00gooooo0_l00029ooooo`;o00006?ooool2o`0000Wooooo0_l0000=ooooo`;o
0000@Oooool2o`0001Cooooo0_l0000<ooooo`;o00004_ooool001kooooo0_l0000>ooooo`;o0000
8?ooool2o`0006Oooooo0_l0000Sooooo`;o00003Oooool2o`0002[ooooo0_l0000Eooooo`;o0000
5?ooool2o`0001Sooooo0_l00006ooooo`007_ooool2o`0002Gooooo0_l00009ooooo`;o0000B_oo
ool2o`0004oooooo0_l00004ooooo`;o00005oooool2o`0000_ooooo0_l00015ooooo`;o00001_oo
ool001kooooo00?o0000ooooooooool05oooool2o`0000_ooooo0_l0001?ooooo`;o00001?ooool2
o`0002Wooooo0_l0000Tooooo`;o00001?ooool2o`0001Oooooo0_l0000oooooo`;o00006Oooool0
01kooooo00?o0000ooooooooool05oooool2o`0005cooooo0_l0000_ooooo`;o00007oooool2o`00
06?ooooo0_l0000Iooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool2o`0001cooooo0_l0001Wooooo`;o00004Oooool2o`00
01;ooooo0_l0000Fooooo`;o00000_ooool2o`0002cooooo0_l0000Uooooo`;o00000oooool2o`00
02Cooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooo
ooooool01Oooool2o`0001cooooo0_l0000Dooooo`;o00008_ooool2o`0002Wooooo0_l00002oooo
o`;o00004Oooool2o`0001;ooooo0_l0000Fooooo`;o000000?oooooo`000?l000001oooool2o`00
00Kooooo0_l000000ooooooo0000o`00000Iooooo`;o00002_ooool2o`0001Wooooo0_l00003oooo
o`;o00009?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool3o`00
02_ooooo0_l00004ooooo`;o00008_ooool2o`0002Wooooo0_l0000Dooooo`;o00003?ooool2o`00
023ooooo0_l00007ooooo`;o00001_ooool2o`000003ooooool0003o000002Gooooo0_l00014oooo
o`000oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool0
0ol0003oooooooooo`0Fooooo`;o00004oooool2o`0004Oooooo0_l0000Pooooo`;o00003?ooool2
o`000:7ooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0
0007ooooo`03o`000?oooooooooo01Kooooo0_l0001Looooo`;o0000dOooool000?ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool08Ooo
ool3o`0000Wooooo0_l0000Gooooo`;o0000J_ooool2o`0009?ooooo0003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo027ooooo0ol0
0009ooooo`;o00005oooool2o`0006[ooooo0_l00009ooooo`;o0000R?ooool000?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool00ooo
ool2o`0006Cooooo0_l0001Booooo`;o0000R?ooool001kooooo00?o0000ooooooooool00oooool2
o`00017ooooo0_l0001Aooooo`;o0000M_ooool2o`0006Cooooo000Nooooo`03o`000?oooooooooo
00_ooooo0_l00009ooooo`;o0000bOooool2o`0005Gooooo0_l0000=ooooo`007_ooool00ol0003o
ooooooooo`0;ooooo`;o00006_ooool2o`0007[ooooo0_l00012ooooo`;o0000=_ooool2o`0001Oo
oooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`0Wooooo`;o0000Loooool2o`0000Gooooo
0_l00012ooooo`;o0000=_ooool2o`0002Kooooo000Nooooo`03o`000?oooooooooo09cooooo0_l0
000Looooo`;o0000Roooool001kooooo00?o0000ooooooooool05_ooool2o`0005Gooooo0_l0000K
ooooo`;o0000;_ooool2o`0008_ooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l00013oooo
o`;o00004?ooool2o`0000;ooooo0_l0000Gooooo`;o000000?oooooo`000?l000004_ooool2o`00
01kooooo0_l00002ooooo`;o00002_ooool2o`0007Cooooo000Nooooo`03o`000?oooooooooo05_o
oooo0_l0000Dooooo`;o00001Oooool2o`0001?ooooo0_l0000Booooo`;o00007?ooool4o`0000;o
oooo0_l0000:ooooo`;o0000M?ooool001kooooo00?o0000ooooooooool0Ioooool2o`0000oooooo
0_l00015ooooo`;o0000EOooool2o`0002oooooo000Nooooo`03o`000?oooooooooo06Oooooo0_l0
0004ooooo`;o00001Oooool2o`0000[ooooo0_l0002Dooooo`;o0000;oooool001kooooo00?o0000
ooooooooool0;?ooool2o`0002Oooooo0_l0000Fooooo`;o00001Oooool2o`0000[ooooo0_l0001A
ooooo`;o0000L_ooool001kooooo0_l0000]ooooo`;o00009oooool2o`0007cooooo0_l0001boooo
o`007_ooool00ol0003oooooooooo`3ooooooa3ooooo0_l0000fooooo`007_ooool00ol0003ooooo
ooooo`0hooooo`;o0000eOooool2o`0003Kooooo000Nooooo`03o`000?oooooooooo02_ooooo0_l0
00000ooooooo0000o`000008ooooo`;o0000=_ooool2o`0000Kooooo0_l0001>ooooo`;o0000COoo
ool2o`0002kooooo000Nooooo`03o`000?oooooooooo01_ooooo0_l0000>ooooo`;o000000?ooooo
o`000?l00000<Oooool2o`0000gooooo0_l00006ooooo`?o00000_ooool2o`0004Cooooo0_l00003
ooooo`;o0000A?ooool2o`0000Oooooo0_l0000^ooooo`007_ooool00ol0003oooooooooo`0Koooo
o`;o00003Oooool4o`0000Kooooo0_l0000[ooooo`;o00005_ooool2o`0000;ooooo0_l00014oooo
o`;o00008?ooool2o`0000Sooooo0_l0000Mooooo`;o0000=oooool001kooooo00?o0000oooooooo
ool0:_ooool4o`0000Kooooo0_l0001/ooooo`;o0000>Oooool2o`0000Kooooo0_l00008ooooo`;o
0000AOooool2o`0000oooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0000Mooooo`;o0000
7_ooool2o`00027ooooo0_l0000looooo`;o0000>Oooool2o`0004gooooo0_l00008ooooo`;o0000
3oooool001kooooo00?o0000ooooooooool00_ooool2o`0001gooooo0_l0000Nooooo`;o00008Ooo
ool2o`0008oooooo0_l0000Gooooo`;o00007?ooool2o`0001Wooooo000Nooooo`03o`000?oooooo
oooo00gooooo0_l0001/ooooo`;o00008oooool2o`0002_ooooo0_l0000Vooooo`;o00005oooool4
o`0003Gooooo000Nooooo`03o`000?oooooooooo00gooooo0_l00015ooooo`;o00004oooool2o`00
013ooooo0_l0000Sooooo`;o0000:oooool2o`0003Kooooo0_l00009ooooo`;o0000=Oooool001ko
oooo00?o0000ooooooooool0:_ooool2o`0000kooooo0_l0000Hooooo`;o00004oooool2o`0004Go
oooo0_l0000eooooo`;o00007?ooool2o`00043ooooo000Nooooo`03o`000?oooooooooo023ooooo
0_l00008ooooo`?o00003Oooool2o`0007Cooooo0_l0000eooooo`;o0000=oooool2o`0002Gooooo
000Nooooo`03o`000?oooooooooo013ooooo0_l0000>ooooo`;o00002Oooool2o`0006Sooooo0_l0
0029ooooo`;o00000_ooool2o`00027ooooo000Nooooo`03o`000?oooooooooo013ooooo0_l00023
ooooo`;o000000?oooooo`000?l00000O?ooool2o`0000Oooooo0_l00003ooooo`;o00008Oooool0
01kooooo00?o0000ooooooooool0@_ooool3o`0005?ooooo0_l0001looooo`;o00001oooool2o`00
00Cooooo0_l0000Pooooo`007_ooool2o`0003Wooooo0_l00008ooooo`?o00007?ooool2o`000<;o
oooo0_l0000Pooooo`007_ooool00ol0003oooooooooo`0hooooo`;o00009oooool2o`00017ooooo
0_l0000_ooooo`;o0000X?ooool001kooooo00?o0000ooooooooool07?ooool2o`0003Cooooo0_l0
0005ooooo`;o00006Oooool2o`0000Wooooo0_l0000Tooooo`;o0000C_ooool2o`00053ooooo000N
ooooo`03o`000?oooooooooo013ooooo0_l0000:ooooo`;o0000;oooool2o`0000?ooooo0_l00005
ooooo`;o00005?ooool2o`0000kooooo0_l0001dooooo`?o0000Coooool001kooooo00?o0000oooo
ooooool04?ooool2o`0003_ooooo0_l0000Pooooo`;o00001?ooool2o`0005_ooooo0_l000000ooo
oooo0000o`00000Cooooo`;o00002_ooool2o`0002Sooooo0_l0000Uooooo`007_ooool00ol0003o
ooooooooo`1eooooo`;o0000Foooool2o`000003ooooool0003o000001?ooooo0_l0000Xooooo`;o
00002_ooool2o`0002Gooooo000Nooooo`03o`000?oooooooooo02Kooooo0_l0000Dooooo`;o0000
G_ooool2o`0007Kooooo0_l0000aooooo`007_ooool00ol0003oooooooooo`0Vooooo`;o00005?oo
ool2o`00047ooooo0_l0000Kooooo`;o0000FOooool2o`0004?ooooo0_l00009ooooo`007_ooool0
0ol0003oooooooooo`0@ooooo`;o00008_ooool2o`0002gooooo0_l0000Gooooo`;o000000?ooooo
o`000?l00000M_ooool2o`0004?ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`0@oooo
o`;o00008_ooool2o`0002gooooo0_l0000Cooooo`;o00000_ooool2o`0000;ooooo0_l0000moooo
o`;o0000Q_ooool001kooooo00?o0000ooooooooool0L_ooool2o`0000Cooooo0_l00006ooooo`;o
0000?Oooool2o`0008Kooooo000Nooooo`03o`000?oooooooooo07;ooooo0_l0003Cooooo`007_oo
ool00ol0003oooooooooo`0Oooooo`;o00001_ooool2o`0008Cooooo0_l0002Hooooo`007_ooool0
0ol0003oooooooooo`0Oooooo`;o00001?ooool4o`0006_ooooo0_l0000Gooooo`;o00004Oooool2
o`0008Gooooo000Nooooo`03o`000?oooooooooo02Gooooo0_l0001Kooooo`;o00001_ooool2o`00
00Sooooo0_l0000Zooooo`;o0000QOooool001kooooo00Co0000ooooool0003o0000;?ooool2o`00
01[ooooo0_l0000Pooooo`;o00005Oooool2o`0000Kooooo0_l0000Eooooo`;o0000:?ooool2o`00
04Kooooo0_l0000Dooooo`;o00007?ooool001kooooo1?l0000/ooooo`;o00006_ooool2o`0000Oo
oooo0_l0000Gooooo`;o0000=?ooool2o`0000cooooo0_l000000ooooooo0000o`00000Gooooo`;o
00009Oooool2o`0000Wooooo0_l0000Dooooo`;o00005?ooool2o`0000Wooooo0_l0000Aooooo`00
7_ooool00ol0003oooooooooo`0Fooooo`;o0000>_ooool3o`0005Sooooo1?l000000ooooooo0000
o`00000fooooo`;o00001_ooool2o`0000Wooooo0_l0000eooooo`;o00004Oooool001kooooo00?o
0000ooooooooool01oooool2o`0000;ooooo0_l00009ooooo`;o0000>oooool2o`0005Sooooo0_l0
000kooooo`;o0000Foooool001kooooo00?o0000ooooooooool01oooool2o`0000;ooooo0_l00003
ooooo`;o0000@Oooool2o`00063ooooo0_l0002@ooooo`007_ooool00ol0003oooooooooo`0@oooo
o`;o0000@Oooool2o`00013ooooo0_l0001>ooooo`;o00000oooool2o`0002?ooooo0_l0000Doooo
o`;o0000D?ooool001kooooo00?o0000ooooooooool0B_ooool2o`0001Wooooo0_l0001Cooooo`;o
00008oooool2o`0001Cooooo0_l0001@ooooo`007_ooool00ol0003oooooooooo`1:ooooo`?o0000
0_ooool2o`000;kooooo0_l0000fooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o0000=?oo
ool2o`0000;ooooo0_l00007ooooo`;o00006Oooool2o`0009[ooooo0_l0000Uooooo`;o00003ooo
ool001kooooo00?o0000ooooooooool05Oooool2o`00047ooooo0_l0000Iooooo`;o0000;Oooool2
o`0009;ooooo0_l0000?ooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o0000U?ooool2o`00
07Gooooo0_l0000/ooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o00004oooool2o`000<?o
oooo0_l0000aooooo`;o00005?ooool2o`0000Sooooo0_l0000<ooooo`007_ooool00ol0003ooooo
ooooo`0Qooooo`;o00008?ooool3o`0001_ooooo0_l00015ooooo`;o0000=Oooool2o`0000Gooooo
0_l00017ooooo`;o00002?ooool2o`0000cooooo000Nooooo`03o`000?oooooooooo00oooooo0_l0
000Wooooo`;o00002Oooool3o`00013ooooo0_l00009ooooo`;o0000AOooool2o`0000[ooooo0_l0
000Wooooo`Co0000B_ooool2o`0001[ooooo000Nooooo`03o`000?oooooooooo00oooooo0_l0000W
ooooo`;o00007?ooool2o`0005cooooo0_l0000Wooooo`;o0000C?ooool2o`0001[ooooo0003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<
c006ooooo`03o`000?oooooooooo0?oooooo3?ooool2o`0003[ooooo0003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`00
0?oooooooooo0?oooooo3?ooool2o`0003[ooooo0003ooooo`05oa0@4?ooooooooooooooool@4100
2oooool01Ol0003ooooooooooooooooo000000Kooooo0ol00017ooooo`;o0000P_ooool2o`000003
ooooool0003o0000063ooooo0_l0000Eooooo`000oooool01Ol0003ooooooooooooooooo000000_o
oooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo00;ooooo0_l00013oooo
o`;o0000AOooool2o`0003_ooooo0_l000000ooooooo0000o`00001Pooooo`;o00005Oooool000?o
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool0
0ol0003oooooooooo`02ooooo`;o0000R_ooool2o`0004Kooooo0_l0001_ooooo`000oooool01Ol@
413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`1/
ooooo`;o0000J?ooool2o`0003Wooooo0_l0000dooooo`000oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0Nooooo`;o0000C?ooool2
o`0007Kooooo0_l0000[ooooo`;o00002Oooool2o`0000Wooooo0_l0000Cooooo`;o00002Oooool0
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o
0000ooooooooool07_ooool2o`000<Cooooo0_l0000Looooo`;o00004?ooool2o`0000Kooooo0_l0
0009ooooo`;o00004oooool2o`0000Wooooo000Nooooo`03o`000?oooooooooo03Wooooo0_l00037
ooooo`;o00004?ooool2o`00037ooooo000Nooooo`03o`000?oooooooooo02Wooooo0_l0000>oooo
o`;o00002_ooool2o`0002_ooooo0_l0001Pooooo`;o0000LOooool001kooooo00?o0000oooooooo
ool08Oooool2o`0000Kooooo0_l0000Jooooo`;o0000:oooool2o`00063ooooo0_l0001aooooo`00
7_ooool00ol0003oooooooooo`0Qooooo`;o0000oooooolUooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo08kooooo0_l0000Qooooo`;o00002?ooool2
o`0006_ooooo0_l0000Mooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o0000>_ooool2o`00
03Kooooo0_l000000ooooooo0000o`000006ooooo`;o00005_ooool2o`0000Sooooo0_l0001[oooo
o`;o00002Oooool2o`0001;ooooo000Nooooo`;o00004_ooool2o`0000Oooooo0_l00004ooooo`;o
0000=?ooool2o`0003Wooooo0_l00006ooooo`;o0000V?ooool2o`0001;ooooo000Nooooo`;o0000
4_ooool2o`0000gooooo0_l00008ooooo`;o00002Oooool2o`0001?ooooo0_l0000[ooooo`;o0000
??ooool2o`0007Kooooo0_l00002ooooo`;o00005?ooool001kooooo00?o0000ooooooooool0:_oo
ool2o`0000Wooooo0_l0000Cooooo`;o0000:oooool2o`0003cooooo0_l00016ooooo`;o0000;_oo
ool2o`0000;ooooo0_l0000Dooooo`007_ooool00ol0003oooooooooo`17ooooo`;o00002_ooool2
o`0007oooooo0_l0000Wooooo`;o0000B?ooool001kooooo0_l0000>ooooo`;o00000_ooool2o`00
03Cooooo0_l0000:ooooo`;o0000@_ooool2o`0003_ooooo0_l0001aooooo`007_ooool00ol0003o
ooooooooo`0=ooooo`;o00000_ooool2o`0002Gooooo0_l0001Mooooo`;o0000@_ooool2o`00063o
oooo0_l00008ooooo`007_ooool00ol0003oooooooooo`0Booooo`;o00009?ooool2o`0005[ooooo
0_l00009ooooo`;o00009?ooool2o`0001Cooooo0_l0001Pooooo`;o00002?ooool001kooooo00?o
0000ooooooooool04_ooool2o`00083ooooo0_l00009ooooo`;o00009?ooool2o`0002_ooooo0_l0
001Cooooo`007_ooool00ol0003oooooooooo`2Fooooo`;o0000>oooool2o`0001gooooo0_l0001C
ooooo`007_ooool00ol0003oooooooooo`07ooooo`;o0000JOooool2o`0002;ooooo0_l0000Xoooo
o`;o00001oooool2o`0000Sooooo0_l0000dooooo`;o0000??ooool001kooooo00?o0000oooooooo
ool01oooool2o`0006Wooooo0_l0001<ooooo`;o00001oooool2o`0002;ooooo0_l0000Jooooo`;o
0000??ooool001kooooo00?o0000ooooooooool0@oooool2o`000:Sooooo0_l0001Hooooo`007_oo
ool00ol0003oooooooooo`13ooooo`;o0000G?ooool2o`0002_ooooo0_l0000Tooooo`;o00001Ooo
ool2o`0004[ooooo000Nooooo`03o`000?oooooooooo02;ooooo0_l0001mooooo`;o00003oooool2
o`0000kooooo0_l0000:ooooo`;o00009?ooool2o`0000Gooooo0_l0001:ooooo`007_ooool00ol0
003oooooooooo`0Pooooo`Co0000Ooooool4o`0000_ooooo0_l0000>ooooo`;o00003_ooool2o`00
03Cooooo0_l0000mooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o00007?ooool2o`0006?o
oooo1?l0000:ooooo`;o00007oooool2o`0003Cooooo0_l0000mooooo`007_ooool00ol0003ooooo
ooooo`0nooooo`;o0000?Oooool2o`0003;ooooo0_l0001Eooooo`;o00005oooool2o`0002Cooooo
000Nooooo`03o`000?oooooooooo017ooooo0_l0000?ooooo`;o00005_ooool2o`00047ooooo0ol0
0018ooooo`;o0000?_ooool2o`0000Oooooo0_l0000>ooooo`;o00009?ooool001kooooo00?o0000
ooooooooool04Oooool2o`0000_ooooo0_l00002ooooo`;o00002_ooool2o`0000[ooooo0_l0000C
ooooo`;o00001?ooool2o`0002Oooooo0_l00018ooooo`;o00005?ooool2o`0002Sooooo1?l00005
ooooo`;o0000=?ooool001kooooo00?o0000ooooooooool03?ooool2o`00013ooooo0_l0000>oooo
o`;o00007oooool2o`0000Cooooo0_l0000;ooooo`;o00008_ooool2o`0000Oooooo0_l0001=oooo
o`;o00007Oooool2o`0000_ooooo0_l0000kooooo`007_ooool2o`0000gooooo0_l0001Dooooo`;o
00008_ooool2o`0000Oooooo0_l0001/ooooo`;o0000B?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`2Looooo`;o0000M_ooool2o`00037ooooo000N
ooooo`03o`000?oooooooooo09cooooo0_l0001fooooo`?o00005?ooool2o`0001[ooooo000Noooo
o`03o`000?oooooooooo04cooooo0_l0000booooo`;o0000;oooool2o`0006;ooooo0_l0000Doooo
o`;o00002Oooool2o`0000oooooo000Nooooo`04o`000?oooooo0000o`0002Kooooo0_l0000Soooo
o`;o00009?ooool2o`0000cooooo0_l0000_ooooo`;o00008Oooool2o`0001gooooo0_l00011oooo
o`;o00003oooool001kooooo00Co0000ooooool0003o00005?ooool2o`00013ooooo0_l00019oooo
o`;o0000H?ooool2o`0001gooooo0_l0001Booooo`007_ooool00ol0003oooooooooo`0Eooooo`;o
00003?ooool2o`0005Sooooo0_l00008ooooo`;o0000Loooool2o`00037ooooo0_l0000Fooooo`00
7_ooool00ol0003oooooooooo`0:ooooo`;o00005oooool2o`0001Gooooo0_l0000jooooo`;o0000
1Oooool2o`0000Sooooo0_l00016ooooo`;o0000:oooool2o`0002[ooooo0_l00005ooooo`Co0000
5?ooool001kooooo00?o0000ooooooooool02_ooool2o`0002kooooo0_l0000jooooo`;o00004_oo
ool2o`0004?ooooo0_l00016ooooo`;o00003oooool2o`0000Oooooo0_l0000Dooooo`007_ooool0
0ol0003oooooooooo`0:ooooo`;o0000O_ooool2o`0008_ooooo0_l0000Oooooo`;o00003Oooool0
01kooooo00?o0000ooooooooool02_ooool2o`000?oooooo;Oooool2o`0000gooooo000Nooooo`03
o`000?oooooooooo07oooooo0_l0001Qooooo`;o0000Hoooool001kooooo00?o0000ooooooooool0
Ooooool2o`0002?ooooo0_l0000looooo`;o0000Hoooool001kooooo00?o0000ooooooooool0T_oo
ool2o`00013ooooo0_l0001:ooooo`;o0000EOooool001kooooo00?o0000ooooooooool0T_ooool2
o`0000gooooo0_l0001=ooooo`;o0000EOooool001kooooo0_l0000Sooooo`;o0000OOooool2o`00
057ooooo0_l0001Aooooo`007_ooool00ol0003oooooooooo`0Rooooo`;o0000E_ooool2o`0000co
oooo0_l0001Zooooo`;o000000?oooooo`000?l000003_ooool2o`0001Sooooo0_l0000Tooooo`00
7_ooool00ol0003oooooooooo`0Wooooo`;o0000DOooool2o`0000cooooo0_l0001]ooooo`;o0000
3_ooool2o`0001Sooooo0_l0000Tooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o00000_oo
ool2o`0002cooooo0_l0000Oooooo`;o0000=_ooool2o`0001Wooooo0_l0001looooo`007_ooool0
0ol0003oooooooooo`0Sooooo`;o0000<?ooool2o`0001oooooo0_l0000Kooooo`;o00006Oooool2
o`0001;ooooo0_l00005ooooo`;o0000Foooool2o`0001oooooo000Nooooo`?o00000oooool2o`00
043ooooo0_l0001<ooooo`;o00004?ooool2o`0001_ooooo0_l0001Rooooo`;o00007oooool001ko
oooo0ol00003ooooo`;o0000@?ooool2o`0005kooooo0_l0000Oooooo`;o00000_ooool2o`0005Ko
oooo0_l0000Sooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o00008oooool2o`00097ooooo
0_l00002ooooo`;o0000E_ooool2o`0002?ooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l0
00000ooooooo0000o`00000Sooooo`;o0000MOooool2o`0001Cooooo0_l0000`ooooo`;o00001Ooo
ool2o`00017ooooo0_l0000iooooo`007_ooool00ol0003oooooooooo`02o`0000Wooooo0_l0001g
ooooo`;o00006?ooool2o`0000[ooooo0ol0000Cooooo`;o0000<?ooool2o`0000Gooooo0_l0000A
ooooo`;o00006_ooool2o`0001gooooo000Nooooo`03o`000?oooooooooo00;o0000Coooool2o`00
01;ooooo0_l00006ooooo`;o00005Oooool2o`0001Sooooo0_l00003ooooo`;o00001_ooool2o`00
07_ooooo0_l0000Mooooo`007_ooool00ol0003oooooooooo`0/ooooo`;o00000_ooool2o`0001oo
oooo0_l0000Booooo`;o00001_ooool2o`0003Cooooo0_l0002Rooooo`007_ooool00ol0003ooooo
ooooo`0/ooooo`;o00000_ooool2o`0007Gooooo0_l0000Hooooo`;o0000:?ooool2o`0002Cooooo
0_l0000dooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o0000S_ooool2o`0001Sooooo0_l0
000Aooooo`;o00005Oooool2o`0002Cooooo0_l0000dooooo`000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`03ooooo`;o00004_ooool2o`0003Kooooo0_l0000<ooooo`;o00006?ooool2o`0005_ooooo
0_l0001aooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q
8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`03ooooo`;o0000<oooool2o`0001Go
oooo0ol0000;ooooo`;o00006?ooool2o`0001cooooo0_l0002`ooooo`000oooool01Ol@413ooooo
oooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000>?ooool2o`00
01Kooooo0_l0000oooooo`;o00000_ooool2o`0000;ooooo0_l0002/ooooo`000oooool01Ol0003o
oooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooo
oooo01?ooooo0_l0001Jooooo`;o00008?ooool2o`0000Kooooo0_l00003ooooo`;o0000Yoooool0
00?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_oo
ool00ol0003oooooooooo`0Cooooo`;o0000F_ooool2o`0002gooooo0_l0002Iooooo`;o00003?oo
ool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@4100
1_ooool00ol0003oooooooooo`0`ooooo`;o0000GOooool2o`0004Cooooo0_l0000mooooo`;o0000
4?ooool2o`00017ooooo0_l000000ooooooo0000o`000009ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo033o
oooo0_l0001<ooooo`;o00003oooool2o`0004Cooooo0_l0000mooooo`;o00004?ooool2o`0001Co
oooo0_l00009ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@06ooooo`03o`000?oooooooooo07kooooo0_l00029ooooo`;o0000??ooool001ko
oooo00?o0000ooooooooool0H?ooool2o`0003Gooooo0_l0001`ooooo`;o00004oooool2o`0002Oo
oooo000Nooooo`03o`000?oooooooooo02;ooooo0_l0000jooooo`Co00006_ooool2o`0001Wooooo
0_l000000ooooooo0000o`00000Aooooo`;o0000Koooool2o`000003ooooool0003o000002Cooooo
000Nooooo`03o`000?oooooooooo02;ooooo0_l0000Pooooo`;o00006?ooool2o`0001cooooo0_l0
0008ooooo`?o00004Oooool2o`00017ooooo0_l0001/ooooo`;o00001?ooool2o`0000Kooooo0_l0
000Looooo`007_ooool01?l0003oooooooooooooool2o`0003Cooooo0_l0000;ooooo`;o0000@?oo
ool3o`0005Kooooo0_l0000jooooo`;o00003?ooool2o`0001cooooo000Nooooo`04o`000?oooooo
ooooooooo`;o0000=?ooool2o`000:Kooooo0_l0000jooooo`;o00007_ooool2o`0000[ooooo000N
ooooo`03o`000?oooooooooo05kooooo0_l0001Gooooo`;o00005?ooool2o`0006cooooo0_l0000:
ooooo`007_ooool00ol0003oooooooooo`1Nooooo`;o00009oooool4o`0002cooooo0_l0000Doooo
o`;o00000_ooool2o`0003Oooooo0_l0000Fooooo`;o00008oooool001kooooo00?o0000oooooooo
ool08Oooool2o`0006Cooooo1?l00005ooooo`;o0000>Oooool2o`0000Cooooo0_l0000gooooo`;o
00005_ooool2o`0002?ooooo000Nooooo`03o`000?oooooooooo027ooooo0_l0000iooooo`;o0000
7Oooool2o`0000Oooooo0_l0000:ooooo`;o0000>Oooool2o`0003oooooo0_l0000iooooo`007_oo
ool00ol0003oooooooooo`1Looooo`;o00007Oooool2o`0000Oooooo0_l00015ooooo`;o0000?ooo
ool2o`0000oooooo0_l0000Xooooo`007_ooool00ol0003oooooooooo`2Kooooo`;o0000Koooool2
o`0000oooooo0_l00008ooooo`;o00007_ooool001kooooo0_l00028ooooo`;o00004_ooool2o`00
06Wooooo0_l0000Oooooo`;o00007_ooool001kooooo00?o0000ooooooooool0Qoooool2o`0007Ko
oooo0_l00005ooooo`;o00003Oooool2o`00033ooooo000Nooooo`03o`000?oooooooooo0?;ooooo
0_l0000;ooooo`;o00005?ooool2o`00033ooooo000Nooooo`03o`000?oooooooooo023ooooo0_l0
000Pooooo`;o000000?oooooo`000?l00000POooool2o`0002Sooooo0ol0001Booooo`007_ooool0
0ol0003oooooooooo`0Pooooo`;o00008?ooool2o`000003ooooool0003o000005kooooo0_l0000Q
ooooo`;o00008?ooool3o`0000Kooooo0_l0000Aooooo`;o00009Oooool2o`0001Sooooo000Noooo
o`03o`000?oooooooooo0:Gooooo0_l00013ooooo`?o00006Oooool2o`0000gooooo0_l0000Foooo
o`;o00006?ooool001kooooo00?o0000ooooooooool09?ooool2o`0000Gooooo0_l00004ooooo`;o
0000aOooool2o`0000Sooooo0_l00005ooooo`;o00002_ooool2o`00033ooooo000Nooooo`03o`00
0?oooooooooo02Cooooo0_l00005ooooo`;o00001?ooool2o`0002gooooo0_l0000Zooooo`;o0000
B?ooool2o`0001[ooooo0_l00004ooooo`;o00002?ooool2o`0000Gooooo0_l00002ooooo`;o0000
>?ooool001kooooo00?o0000ooooooooool0Doooool2o`0000_ooooo0_l0000Zooooo`;o00005Ooo
ool2o`0002Kooooo0_l00009ooooo`;o00006_ooool2o`0001Wooooo0_l0000hooooo`007_ooool0
0ol0003oooooooooo`0Booooo`;o0000?oooool2o`0004kooooo0_l0000Jooooo`;o00002_ooool2
o`0001?ooooo0_l0000kooooo`;o0000:?ooool001kooooo00?o0000ooooooooool04_ooool2o`00
0003ooooool0003o000006[ooooo0_l0000jooooo`Co00007oooool2o`0002Cooooo0_l0000Eoooo
o`;o0000:?ooool001kooooo00?o0000ooooooooool03?ooool2o`0000Oooooo0_l0001Zooooo`;o
00009Oooool2o`0001?ooooo0_l00017ooooo`;o0000?oooool001kooooo00Co0000ooooool0003o
00002oooool2o`0000_ooooo0_l0000>ooooo`;o00009Oooool2o`0005Kooooo0_l0000Rooooo`;o
0000NOooool001kooooo00Co0000ooooool0003o00006?ooool2o`0000Wooooo0_l00003ooooo`;o
00009Oooool2o`0003Kooooo0_l0000Fooooo`;o0000:_ooool2o`0002_ooooo0_l0001<ooooo`00
7_ooool00ol0003oooooooooo`0Tooooo`;o0000H_ooool2o`0001Gooooo0ol0001Gooooo`;o0000
C?ooool001kooooo00?o0000ooooooooool08_ooool2o`0001[ooooo0_l00006ooooo`;o0000Eooo
ool2o`0008cooooo0_l0000Hooooo`007_ooool2o`0002?ooooo0_l00002ooooo`;o00005_ooool2
o`0000Kooooo0_l0000eooooo`;o00002_ooool2o`0005?ooooo0_l0000Fooooo`;o00003?ooool2
o`0002Oooooo0_l0000Hooooo`007Oooool2o`0002Sooooo0_l0001Eooooo`;o00002_ooool2o`00
05?ooooo0_l0000Fooooo`;o00003?ooool2o`0000kooooo0_l0000Looooo`;o00004oooool001go
oooo0_l00004ooooo`;o0000ooooool:ooooo`;o00001Oooool2o`0001cooooo0_l0000Cooooo`00
7_ooool00ol0003oooooooooo`02ooooo`;o00005Oooool2o`0004kooooo0_l0000=ooooo`;o0000
K?ooool2o`0000cooooo0_l0000=ooooo`;o00002?ooool2o`0003Sooooo000Nooooo`03o`000?oo
oooooooo01Wooooo0_l0001>ooooo`;o00003Oooool2o`0005;ooooo0_l0000Hooooo`;o00003?oo
ool2o`0000gooooo0_l00012ooooo`007_ooool00ol0003oooooooooo`0jooooo`;o0000<_ooool2
o`0005cooooo0_l0000cooooo`;o0000>?ooool2o`0000[ooooo000Nooooo`?o0000>_ooool2o`00
03;ooooo0_l0001cooooo`;o00004?ooool2o`0000[ooooo0_l0000hooooo`;o00002_ooool001ko
oooo0ol0003=ooooo`;o00005?ooool2o`00013ooooo0_l0000gooooo`Co00005Oooool001kooooo
00?o0000ooooooooool0Soooool2o`0002[ooooo1?l0000=ooooo`?o00005?ooool2o`0000Wooooo
0_l0000nooooo`Co00005Oooool001kooooo00?o0000ooooooooool0Soooool2o`0002[ooooo1?l0
0007ooooo`;o00001?ooool2o`00023ooooo0_l0000Mooooo`;o0000>?ooool001kooooo00?o0000
ooooooooool0`oooool2o`000003ooooool0003o000004Gooooo0_l0000hooooo`007_ooool00ol0
003oooooooooo`2_ooooo`;o00004_ooool2o`0000Oooooo0_l0000]ooooo`;o0000B_ooool001ko
oooo00?o0000ooooooooool0[oooool2o`0001_ooooo0_l0000]ooooo`;o0000B_ooool001kooooo
00?o0000ooooooooool0moooool2o`0004kooooo000Nooooo`03o`000?oooooooooo00;o0000E_oo
ool2o`0006_ooooo0_l0000Dooooo`;o00006_ooool3o`0000oooooo0_l0000looooo`007_ooool0
0ol0003oooooooooo`02o`0002Sooooo0_l0000Nooooo`;o00002oooool3o`0000gooooo0_l00000
0ooooooo0000o`00001Iooooo`;o00004_ooool4o`0001_ooooo0_l0000:ooooo`;o00000oooool2
o`0003cooooo000Mooooo`?o0000:oooool2o`0001kooooo0_l0000;ooooo`;o00003_ooool2o`00
0003ooooool0003o000006gooooo0_l0000Qooooo`;o00001_ooool2o`000003ooooool0003o0000
03kooooo000Mooooo`;o0000LOooool2o`0001oooooo0_l0000Qooooo`;o0000Aoooool2o`0000So
oooo0ol0000nooooo`007_ooool00ol0003oooooooooo`1Yooooo`;o00001?ooool2o`0001oooooo
0_l0000Qooooo`;o0000DOooool2o`0003oooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0
001Oooooo`;o0000>oooool2o`0009oooooo000Nooooo`;o00002Oooool2o`0001Gooooo0_l0001Z
ooooo`;o000000?oooooo`000?l000005_ooool2o`0009oooooo000Nooooo`;o00008?ooool2o`00
06[ooooo0_l000000ooooooo0000o`00000Kooooo`;o0000V_ooool001kooooo00?o0000oooooooo
ool0Zoooool2o`0004oooooo0_l00004ooooo`;o00002_ooool2o`0003Oooooo000Nooooo`03o`00
0?oooooooooo00Wooooo0_l0000Fooooo`;o0000fOooool2o`0000Cooooo0_l0000:ooooo`;o0000
=oooool001kooooo00?o0000ooooooooool02Oooool2o`0001Kooooo0_l0000=ooooo`;o0000e?oo
ool2o`0002Gooooo0_l0000Hooooo`007_ooool00ol0003oooooooooo`0`ooooo`;o0000F?ooool2
o`0007[ooooo0_l0000Uooooo`;o00006?ooool001kooooo00?o0000ooooooooool0??ooool2o`00
04cooooo0_l00020ooooo`;o0000>Oooool001kooooo00?o0000ooooooooool04oooool2o`0002Oo
oooo0_l0002Wooooo`;o00002_ooool2o`0001Wooooo0_l0000iooooo`007_ooool00ol0003ooooo
ooooo`0Cooooo`;o0000Ooooool2o`0000[ooooo0_l00013ooooo`;o00002_ooool2o`0000kooooo
0_l0000=ooooo`;o0000:oooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo05cooooo0_l0
000fooooo`;o00001_ooool2o`0000;ooooo0_l0001Hooooo`;o00001Oooool2o`0000Cooooo0_l0
0007ooooo`;o0000:oooool4o`0000Kooooo000Dooooo`Co000000?o410@ooooooooool00oooool0
0ol0003oooooooooo`0booooo`;o0000:?ooool2o`0003kooooo0_l0001Looooo`;o00002oooool2
o`0003Kooooo0_l00006ooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Cooooo0_l0000Pooooo`;o00002_ooool2o`0006?ooooo0_l0002Uooooo`;o00001oooool001Ko
oooo00?o0000ooooooooool01Oooool3o`0000Cooooo0_l0000Pooooo`;o00009_ooool2o`0004Oo
oooo0_l0002Uooooo`;o00001oooool001Kooooo00?o0000ooooooooool0E_ooool2o`000?Oooooo
000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@
ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Dooooo`03oeEEEOmVIVKo00000?oo
ooooD_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.56675 .11515 Mdot
.69217 .54133 Mdot
.05414 .54633 Mdot
.49099 .66337 Mdot
.61621 .79837 Mdot
.79511 .93182 Mdot
.64524 .79564 Mdot
.93133 .79342 Mdot
.44347 .24045 Mdot
.12316 .89171 Mdot
.30044 .33771 Mdot
.25279 .14553 Mdot
.86874 .35518 Mdot
.42563 .74016 Mdot
.68093 .67612 Mdot
.79746 .94231 Mdot
.92908 .01316 Mdot
.1375 .87429 Mdot
.42132 .08364 Mdot
.07084 .21865 Mdot
.84197 .977 Mdot
.08357 .18997 Mdot
.40642 .50423 Mdot
.69583 .9105 Mdot
.67172 .2813 Mdot
.13492 .30705 Mdot
.12594 .7413 Mdot
.20022 .49896 Mdot
.06147 .59321 Mdot
.1956 .75825 Mdot
.77631 .64716 Mdot
.99069 .67733 Mdot
.0695 .53353 Mdot
.04219 .35024 Mdot
.52698 .89441 Mdot
.48071 .30552 Mdot
.71928 .74944 Mdot
.21116 .86404 Mdot
.72819 .86962 Mdot
.87686 .49912 Mdot
.53087 .40977 Mdot
.81482 .87675 Mdot
.62041 .90067 Mdot
.68932 .33084 Mdot
.41678 .2288 Mdot
.78451 .84775 Mdot
.02521 .19965 Mdot
.43713 .40521 Mdot
.17222 .58756 Mdot
.09216 .67639 Mdot
.30751 .58207 Mdot
.07977 .04458 Mdot
.91283 .03741 Mdot
.40134 .30373 Mdot
.15717 .27441 Mdot
.57673 .10581 Mdot
.60615 .17832 Mdot
.92812 .12457 Mdot
.71611 .11372 Mdot
.62449 .58443 Mdot
.67973 .66202 Mdot
.39911 .04091 Mdot
.23611 .21384 Mdot
.18324 .86368 Mdot
.46075 .04038 Mdot
.91612 .69672 Mdot
.16704 .63019 Mdot
.2038 .72191 Mdot
.4251 .58579 Mdot
.14241 .46348 Mdot
.57457 .33691 Mdot
.38242 .74527 Mdot
.02854 .81165 Mdot
.84722 .8391 Mdot
.65804 .73416 Mdot
.53116 .84136 Mdot
.33331 .5565 Mdot
.74992 .00882 Mdot
.30337 .06192 Mdot
.67979 .42038 Mdot
.01219 .339 Mdot
.4051 .09275 Mdot
.30127 .13769 Mdot
.88816 .21236 Mdot
.40595 .19101 Mdot
.90514 .5101 Mdot
.61244 .59384 Mdot
.23699 .5345 Mdot
.14263 .17141 Mdot
.6223 .39019 Mdot
.70689 .24237 Mdot
.80575 .83471 Mdot
.83194 .77174 Mdot
.53934 .87674 Mdot
.39594 .76788 Mdot
.51607 .79887 Mdot
.12471 .4417 Mdot
.47692 .42224 Mdot
.64637 .71402 Mdot
.10352 .75048 Mdot
.63705 .40706 Mdot
.61659 .2251 Mdot
.79515 .29759 Mdot
.67326 .2547 Mdot
.10023 .66521 Mdot
.27084 .51462 Mdot
.56925 .03313 Mdot
.89048 .58322 Mdot
.30899 .72594 Mdot
.27786 .29438 Mdot
.79732 .14779 Mdot
.30824 .67599 Mdot
.02579 .60479 Mdot
.55719 .3172 Mdot
.36372 .17111 Mdot
.74734 .92619 Mdot
.39968 .64007 Mdot
.61122 .5463 Mdot
.96615 .74477 Mdot
.85674 .8324 Mdot
.52262 .15006 Mdot
.44289 .40078 Mdot
.85972 .13653 Mdot
.27117 .85896 Mdot
.69909 .39642 Mdot
.5776 .67684 Mdot
.47164 .09118 Mdot
.96551 .61627 Mdot
.93829 .58564 Mdot
.21768 .20328 Mdot
.10545 .97834 Mdot
.49638 .2368 Mdot
.71991 .96332 Mdot
.91675 .70148 Mdot
.72355 .96049 Mdot
.78267 .97785 Mdot
.15882 .4279 Mdot
.06924 .16509 Mdot
.82152 .19974 Mdot
.23886 .6844 Mdot
.74941 .48037 Mdot
.88732 .34794 Mdot
.50915 .63869 Mdot
.52506 .2455 Mdot
.92498 .81223 Mdot
.47185 .41071 Mdot
.06549 .98701 Mdot
.82429 .56866 Mdot
.77361 .69586 Mdot
.61995 .26683 Mdot
.08806 .35778 Mdot
.516 .71762 Mdot
.47325 .01238 Mdot
.49457 .23231 Mdot
.82798 .23809 Mdot
.10433 .12227 Mdot
.03761 .29326 Mdot
.49756 .84655 Mdot
.10576 .44306 Mdot
.80765 .14045 Mdot
.19653 .6128 Mdot
.05129 .0103 Mdot
.24478 .12158 Mdot
.67238 .15706 Mdot
.90958 .24227 Mdot
.04158 .06139 Mdot
.94597 .13972 Mdot
.07246 .80381 Mdot
.04401 .71127 Mdot
.71035 .09223 Mdot
.80338 .40145 Mdot
.03637 .08634 Mdot
.47232 .65449 Mdot
.84891 .9404 Mdot
.09223 .39778 Mdot
.0408 .91835 Mdot
.31808 .28884 Mdot
.86316 .72464 Mdot
.23742 .01535 Mdot
.65679 .7861 Mdot
.32759 .43986 Mdot
.08024 .82615 Mdot
.65945 .90196 Mdot
.17815 .60427 Mdot
.05215 .38227 Mdot
.4656 .79973 Mdot
.82428 .85238 Mdot
.28815 .74544 Mdot
.64095 .69786 Mdot
.28848 .15808 Mdot
.26881 .54627 Mdot
.4974 .23659 Mdot
.80737 .24178 Mdot
.28039 .54547 Mdot
.28263 .20661 Mdot
.23651 .80364 Mdot
.36771 .95867 Mdot
.90744 .13995 Mdot
.40768 .97225 Mdot
.75501 .25913 Mdot
.9008 .41009 Mdot
.33165 .23809 Mdot
.49636 .99863 Mdot
.96887 .13612 Mdot
.82428 .62133 Mdot
.5529 .72586 Mdot
.40533 .54721 Mdot
.45279 .78556 Mdot
.17652 .45479 Mdot
.40919 .78041 Mdot
.63267 .34672 Mdot
.78912 .65647 Mdot
.86825 .07089 Mdot
.59159 .55112 Mdot
.23688 .21034 Mdot
.48723 .55021 Mdot
.54828 .45452 Mdot
.06792 .96123 Mdot
.00588 .04231 Mdot
.48378 .03919 Mdot
.96892 .45035 Mdot
.93971 .12481 Mdot
.20003 .96913 Mdot
.28596 .60511 Mdot
.4662 .03184 Mdot
.55921 .92007 Mdot
.36392 .68792 Mdot
.2062 .50457 Mdot
.94988 .36656 Mdot
.00216 .40911 Mdot
.80679 .4608 Mdot
.6518 .50334 Mdot
.97374 .14461 Mdot
.57767 .24307 Mdot
.63981 .31057 Mdot
.4275 .77313 Mdot
.03972 .41408 Mdot
.73325 .72026 Mdot
.81094 .59271 Mdot
.66227 .34858 Mdot
.72812 .09007 Mdot
.52788 .80535 Mdot
.78721 .76644 Mdot
.01057 .43603 Mdot
.94914 .48461 Mdot
.29673 .32756 Mdot
.17382 .30855 Mdot
.00616 .68887 Mdot
.26961 .02962 Mdot
.40886 .83639 Mdot
.59238 .57026 Mdot
.88085 .35141 Mdot
.72939 .34415 Mdot
.48782 .68179 Mdot
.07777 .7162 Mdot
.61392 .11013 Mdot
.26469 .3662 Mdot
.18102 .64684 Mdot
.95407 .92318 Mdot
.0397 .09573 Mdot
.82093 .02928 Mdot
.7688 .12243 Mdot
.36269 .32453 Mdot
.7539 .63838 Mdot
.49772 .11366 Mdot
.40052 .0903 Mdot
.55395 .26267 Mdot
.6517 .1136 Mdot
.42495 .032 Mdot
.60362 .60038 Mdot
.60271 .97347 Mdot
.428 .37152 Mdot
.64626 .07873 Mdot
.79432 .38141 Mdot
.41955 .89095 Mdot
.90756 .61181 Mdot
.78571 .91256 Mdot
.63965 .38575 Mdot
.36716 .51169 Mdot
.12451 .13663 Mdot
.81036 .61672 Mdot
.38524 .67291 Mdot
.34134 .50578 Mdot
.09188 .43511 Mdot
.56034 .29188 Mdot
.43232 .18717 Mdot
.27687 .5357 Mdot
.38934 .43968 Mdot
.3578 .76169 Mdot
.61447 .18831 Mdot
.854 .38154 Mdot
.62568 .91738 Mdot
.90932 .63293 Mdot
.10353 .11068 Mdot
.70181 .25959 Mdot
.14697 .80913 Mdot
.0044 .83407 Mdot
.58212 .75924 Mdot
.59324 .15985 Mdot
.32662 .18177 Mdot
.37165 .26456 Mdot
.57804 .12697 Mdot
.38472 .01628 Mdot
.08868 .34452 Mdot
.3394 .5188 Mdot
.84824 .10039 Mdot
.77258 .39184 Mdot
.83452 .15537 Mdot
.90332 .42549 Mdot
.11982 .5346 Mdot
.17552 .4007 Mdot
.65628 .21712 Mdot
.93808 .9998 Mdot
.94213 .95694 Mdot
.42126 .11939 Mdot
.98933 .74437 Mdot
.21586 .4652 Mdot
.27774 .77765 Mdot
.30653 .2077 Mdot
.57622 .48553 Mdot
.53828 .64827 Mdot
.32559 .08626 Mdot
.49824 .38192 Mdot
.80364 .73553 Mdot
.69456 .24542 Mdot
.72532 .91417 Mdot
.13993 .26176 Mdot
.59883 .03237 Mdot
.05936 .66045 Mdot
.18607 .38992 Mdot
.61731 .58773 Mdot
.74467 .7711 Mdot
.21376 .80571 Mdot
.28589 .81717 Mdot
.58069 .28936 Mdot
.61755 .94986 Mdot
.01924 .90972 Mdot
.02738 .1716 Mdot
.7464 .78423 Mdot
.29482 .00401 Mdot
.82108 .9856 Mdot
.97107 .74905 Mdot
.06963 .53218 Mdot
.36446 .11624 Mdot
.98705 .86164 Mdot
.94472 .16222 Mdot
.27227 .43634 Mdot
.46194 .35018 Mdot
.38649 .39302 Mdot
.29971 .31349 Mdot
.50567 .74702 Mdot
.14054 .174 Mdot
.82008 .89694 Mdot
.03513 .28939 Mdot
.88674 .2258 Mdot
.8041 .30874 Mdot
.76351 .50204 Mdot
.72658 .27982 Mdot
.35648 .20007 Mdot
.4011 .79674 Mdot
.10395 .67183 Mdot
.96567 .61814 Mdot
.46381 .06183 Mdot
.95884 .30676 Mdot
.77801 .30059 Mdot
.78812 .88367 Mdot
.02439 .94033 Mdot
.11914 .4385 Mdot
.12742 .30309 Mdot
.52707 .2921 Mdot
.63653 .23637 Mdot
.26256 .62978 Mdot
.66646 .42852 Mdot
.1629 .14933 Mdot
.07064 .5022 Mdot
.34112 .70561 Mdot
.15518 .33556 Mdot
.41649 .95743 Mdot
.2638 .53044 Mdot
.43169 .38395 Mdot
.00109 .09254 Mdot
.76948 .9547 Mdot
.23064 .99081 Mdot
.64113 .45889 Mdot
.69707 .69599 Mdot
.34291 .44601 Mdot
.49393 .05734 Mdot
.86752 .87796 Mdot
.47484 .85849 Mdot
.58853 .78581 Mdot
.07505 .4621 Mdot
.02301 .53632 Mdot
.93804 .23386 Mdot
.38628 .44539 Mdot
.84274 .10836 Mdot
.61094 .85151 Mdot
.01187 .54874 Mdot
.40067 .53855 Mdot
.3811 .35571 Mdot
.3984 .79712 Mdot
.04364 .63226 Mdot
.94336 .87818 Mdot
.10509 .3048 Mdot
.78757 .20379 Mdot
.03228 .20481 Mdot
.26785 .89519 Mdot
.32446 .96226 Mdot
.792 .90992 Mdot
.179 .54723 Mdot
.52404 .50443 Mdot
.66177 .05594 Mdot
.99098 .84329 Mdot
.48316 .28843 Mdot
.18278 .10257 Mdot
.51457 .84827 Mdot
.53021 .76212 Mdot
.61663 .77833 Mdot
.12726 .00178 Mdot
.42941 .68092 Mdot
.47404 .95707 Mdot
.11459 .26783 Mdot
.08377 .58661 Mdot
.58866 .3457 Mdot
.95495 .61013 Mdot
.96854 .92275 Mdot
.63646 .64334 Mdot
.32329 .93998 Mdot
.24204 .01701 Mdot
.83917 .29618 Mdot
.24674 .15123 Mdot
.54507 .4819 Mdot
.91007 .05694 Mdot
.2957 .34975 Mdot
.96339 .60717 Mdot
.84208 .86811 Mdot
.87097 .86271 Mdot
.73675 .07973 Mdot
.1007 .08595 Mdot
.55054 .00524 Mdot
.99626 .20262 Mdot
.84546 .84424 Mdot
.88258 .18785 Mdot
.43376 .49538 Mdot
.83687 .99632 Mdot
.00329 .28007 Mdot
.01119 .52543 Mdot
.29584 .27779 Mdot
.27145 .52748 Mdot
.42469 .06099 Mdot
.03551 .30564 Mdot
.0076 .92191 Mdot
.17281 .96976 Mdot
.29845 .21296 Mdot
.15696 .91468 Mdot
.99992 .5825 Mdot
.18478 .78322 Mdot
.8615 .43519 Mdot
.04051 .39265 Mdot
.43005 .29224 Mdot
.90197 .00016 Mdot
.13933 .09762 Mdot
.00154 .8285 Mdot
.99529 .04158 Mdot
.96312 .72588 Mdot
.83247 .96276 Mdot
.67175 .67689 Mdot
.96945 .24475 Mdot
.35435 .75733 Mdot
.97233 .6768 Mdot
.17856 .50003 Mdot
.40745 .51676 Mdot
.14067 .36473 Mdot
.4017 .55606 Mdot
.27225 .66988 Mdot
.2708 .3822 Mdot
.44635 .81285 Mdot
.5716 .55332 Mdot
.63837 .00176 Mdot
.73885 .17128 Mdot
.42087 .11038 Mdot
.6297 .3606 Mdot
.10618 .74539 Mdot
.35919 .97903 Mdot
.83199 .51675 Mdot
.8211 .55639 Mdot
.69407 .98123 Mdot
.68445 .03929 Mdot
.38427 .03359 Mdot
.24633 .62029 Mdot
.61082 .89571 Mdot
.64259 .31367 Mdot
.05372 .92006 Mdot
.87656 .81972 Mdot
.08185 .04007 Mdot
.6548 .97486 Mdot
.1178 .65663 Mdot
.69818 .55144 Mdot
.29015 .81209 Mdot
.88068 .37696 Mdot
.04084 .64284 Mdot
.76819 .89171 Mdot
.56512 .61401 Mdot
.26024 .71079 Mdot
.37746 .82815 Mdot
.52005 .76014 Mdot
.42918 .92434 Mdot
.72994 .91986 Mdot
.44603 .13175 Mdot
.16596 .50218 Mdot
.02377 .45487 Mdot
.42182 .26073 Mdot
.84501 .94729 Mdot
.51896 .23377 Mdot
.41603 .19867 Mdot
.39209 .656 Mdot
.90596 .23417 Mdot
.00859 .76436 Mdot
.34131 .44677 Mdot
.14344 .7068 Mdot
.03061 .17927 Mdot
.84189 .06787 Mdot
.14404 .58926 Mdot
.55632 .94334 Mdot
.16187 .77803 Mdot
.90089 .84529 Mdot
.88175 .71697 Mdot
.64434 .32107 Mdot
.84279 .6143 Mdot
.76982 .42339 Mdot
.36578 .03188 Mdot
.76304 .85312 Mdot
.47013 .98761 Mdot
.78492 .64971 Mdot
.45998 .26253 Mdot
.36579 .84001 Mdot
.16241 .34974 Mdot
.59815 .1299 Mdot
.4152 .49829 Mdot
.81831 .67557 Mdot
.44037 .02018 Mdot
.18247 .1156 Mdot
.93778 .85344 Mdot
.55624 .39794 Mdot
.60597 .9999 Mdot
.63589 .61593 Mdot
.00926 .87352 Mdot
.13644 .91124 Mdot
.98374 .65968 Mdot
.67491 .9181 Mdot
.43278 .02394 Mdot
.72049 .1066 Mdot
.12631 .86941 Mdot
.40277 .85803 Mdot
.05216 .88141 Mdot
.98202 .59383 Mdot
.58284 .74669 Mdot
.2099 .84332 Mdot
.43802 .00704 Mdot
.93699 .06725 Mdot
.58881 .48208 Mdot
.39819 .28568 Mdot
.02274 .32296 Mdot
.5428 .31259 Mdot
.03058 .31864 Mdot
.27577 .5897 Mdot
.84113 .30318 Mdot
.1596 .13301 Mdot
.12409 .4238 Mdot
.08574 .15339 Mdot
.55084 .55212 Mdot
.0123 .95288 Mdot
.09703 .20328 Mdot
.47956 .80308 Mdot
.93806 .01576 Mdot
.80272 .35335 Mdot
.0469 .56067 Mdot
.66187 .89889 Mdot
.06797 .12277 Mdot
.63646 .90231 Mdot
.81159 .56307 Mdot
.41519 .61327 Mdot
.39588 .87557 Mdot
.53647 .52549 Mdot
.16215 .80537 Mdot
.92008 .85918 Mdot
.35898 .92588 Mdot
.98667 .36913 Mdot
.44675 .23012 Mdot
.18843 .60511 Mdot
.24219 .24349 Mdot
.68812 .57143 Mdot
.29617 .54457 Mdot
.13764 .09361 Mdot
.03804 .53535 Mdot
.73424 .43128 Mdot
.73934 .86571 Mdot
.67802 .43803 Mdot
.51784 .07385 Mdot
.55903 .20343 Mdot
.20466 .70771 Mdot
.5036 .46143 Mdot
.8288 .3304 Mdot
.68187 .75927 Mdot
.66571 .65156 Mdot
.41035 .80039 Mdot
.49454 .97905 Mdot
.8067 .50206 Mdot
.61949 .24894 Mdot
.99185 .92977 Mdot
.23593 .31067 Mdot
.30177 .86051 Mdot
.89737 .4662 Mdot
.93165 .26123 Mdot
.93414 .26892 Mdot
.11418 .37132 Mdot
.40149 .48439 Mdot
.84111 .43576 Mdot
.77324 .36889 Mdot
.16684 .06911 Mdot
.28826 .25543 Mdot
.30863 .27382 Mdot
.91592 .08058 Mdot
.87463 .5483 Mdot
.15702 .47845 Mdot
.07705 .1506 Mdot
.08751 .34272 Mdot
.82893 .64775 Mdot
.82041 .9943 Mdot
.85369 .07364 Mdot
.91254 .48862 Mdot
.8198 .14085 Mdot
.75662 .36735 Mdot
.64566 .73464 Mdot
.70467 .42313 Mdot
.63733 .31916 Mdot
.4156 .81148 Mdot
.42501 .3032 Mdot
.46218 .60181 Mdot
.73007 .52299 Mdot
.77785 .74582 Mdot
.74295 .31232 Mdot
.73026 .11848 Mdot
.05806 .03762 Mdot
.10693 .88676 Mdot
.54715 .4386 Mdot
.5364 .59759 Mdot
.77421 .98349 Mdot
.98782 .6525 Mdot
.21614 .81513 Mdot
.66009 .18361 Mdot
.61843 .42558 Mdot
.74746 .30396 Mdot
.74043 .24624 Mdot
.15061 .05184 Mdot
.81676 .07441 Mdot
.90993 .29739 Mdot
.40575 .77245 Mdot
.23634 .56485 Mdot
.49464 .65377 Mdot
.38651 .04981 Mdot
.14434 .97332 Mdot
.85925 9e-05 Mdot
.66028 .68177 Mdot
.97887 .56028 Mdot
.78482 .56842 Mdot
.96201 .64467 Mdot
.8337 .62873 Mdot
.91743 .20875 Mdot
.56402 .72235 Mdot
.81501 .78097 Mdot
.93471 .20306 Mdot
.29605 .86449 Mdot
.65442 .09598 Mdot
.56944 .73018 Mdot
.12955 .55005 Mdot
.45733 .30366 Mdot
.47916 .11668 Mdot
.63092 .79636 Mdot
.50932 .35303 Mdot
.57924 .44844 Mdot
.0817 .49638 Mdot
.89949 .80716 Mdot
.28177 .4284 Mdot
.47031 .07562 Mdot
.49268 .46651 Mdot
.03421 .21202 Mdot
.5003 .78216 Mdot
.44379 .77328 Mdot
.88488 .80031 Mdot
.94788 .1116 Mdot
.51148 .31076 Mdot
.23388 .79846 Mdot
.2955 .67705 Mdot
.46858 .12767 Mdot
.87959 .11329 Mdot
.86259 .18585 Mdot
.52177 .78309 Mdot
.69276 .10995 Mdot
.8863 .13659 Mdot
.1132 .20402 Mdot
.13491 .20088 Mdot
.30339 .95597 Mdot
.75925 .02676 Mdot
.93489 .02202 Mdot
.32758 .21329 Mdot
.60236 .02876 Mdot
.31548 .96376 Mdot
.87391 .97752 Mdot
.92706 .04683 Mdot
.04507 .73159 Mdot
.90517 .04551 Mdot
.79725 .66559 Mdot
.90646 .70918 Mdot
.63037 .84466 Mdot
.285 .81697 Mdot
.8304 .68783 Mdot
.82108 .73993 Mdot
.09223 .79051 Mdot
.64158 .6406 Mdot
.35527 .95008 Mdot
.57873 .72968 Mdot
.44379 .08315 Mdot
.53716 .81984 Mdot
.51026 .28397 Mdot
.49646 .97575 Mdot
.74506 .30554 Mdot
.0766 .29434 Mdot
.0501 .755 Mdot
.12173 .42083 Mdot
.82024 .82966 Mdot
.61552 .91833 Mdot
.60373 .01375 Mdot
.1695 .0545 Mdot
.02486 .06743 Mdot
.76652 .36854 Mdot
.65194 .91705 Mdot
.13825 .52875 Mdot
.77066 .47509 Mdot
.92567 .09792 Mdot
.58659 .85472 Mdot
.66822 .54355 Mdot
.62914 .88952 Mdot
.18764 .76036 Mdot
.15958 .73965 Mdot
.88377 .5743 Mdot
.99818 .80885 Mdot
.24996 .33843 Mdot
.48361 .75791 Mdot
.97605 .94542 Mdot
.57749 .14632 Mdot
.1876 .70991 Mdot
.12605 .15725 Mdot
.3858 .0336 Mdot
.36258 .40393 Mdot
.33034 .13797 Mdot
.06839 .529 Mdot
.31152 .42943 Mdot
.20307 .5835 Mdot
.19592 .22645 Mdot
.85562 .96325 Mdot
.08486 .41616 Mdot
.1434 .68027 Mdot
.03225 .5711 Mdot
.15383 .38791 Mdot
.78193 .67336 Mdot
.65507 .11856 Mdot
.31587 .3993 Mdot
.45253 .72677 Mdot
.13803 .10674 Mdot
.38467 .00605 Mdot
.80717 .74563 Mdot
.66357 .1769 Mdot
.85865 .4622 Mdot
.65364 .36074 Mdot
.69253 .75901 Mdot
.36782 .10849 Mdot
.04396 .21933 Mdot
.84669 .85621 Mdot
.86375 .68646 Mdot
.26065 .99415 Mdot
.5887 .71517 Mdot
.00904 .85396 Mdot
.91607 .8373 Mdot
.48397 .81119 Mdot
.92379 .23627 Mdot
.96466 .31236 Mdot
.09644 .34695 Mdot
.46196 .34047 Mdot
.91661 .26024 Mdot
.47956 .62031 Mdot
.18672 .71089 Mdot
.35558 .49221 Mdot
.46435 .86365 Mdot
.20968 .50397 Mdot
.682 .16194 Mdot
.86211 .83123 Mdot
.6248 .79179 Mdot
.03439 .37916 Mdot
.66294 .30773 Mdot
.43627 .17395 Mdot
.61271 .18043 Mdot
.09152 .68932 Mdot
.28914 .60262 Mdot
.5999 .06167 Mdot
.69061 .60544 Mdot
.5247 .69394 Mdot
.87513 .30673 Mdot
.79852 .99868 Mdot
.1152 .65144 Mdot
.62929 .48378 Mdot
.58766 .20889 Mdot
.06038 .44401 Mdot
.10842 .16467 Mdot
.10304 .89029 Mdot
.6844 .42444 Mdot
.36996 .69384 Mdot
.12669 .9555 Mdot
.97936 .13466 Mdot
.12018 .51076 Mdot
.31589 .27098 Mdot
.86875 .99399 Mdot
.55076 .65211 Mdot
.41921 .91963 Mdot
.35816 .07251 Mdot
.17368 .8913 Mdot
.11748 .0487 Mdot
.62318 .33112 Mdot
.88409 .48907 Mdot
.35938 .24232 Mdot
.77014 .21815 Mdot
.37448 .59418 Mdot
.58976 .08321 Mdot
.3699 .46545 Mdot
.90445 .56747 Mdot
.08791 .68284 Mdot
.6808 .35909 Mdot
.78112 .9266 Mdot
.42751 .17744 Mdot
.29145 .72817 Mdot
.67848 .82403 Mdot
.79655 .3515 Mdot
.77234 .4679 Mdot
.5581 .89243 Mdot
.31801 .51826 Mdot
.05121 .28943 Mdot
.28079 .08692 Mdot
.1 .47266 Mdot
.73327 .5913 Mdot
.45299 .68141 Mdot
.44107 .27916 Mdot
.29786 .81734 Mdot
.89814 .59126 Mdot
.63335 .32886 Mdot
.98847 .98934 Mdot
.21108 .57153 Mdot
.80662 .33386 Mdot
.02556 .41745 Mdot
.66184 .38312 Mdot
.78923 .81087 Mdot
.7925 .92863 Mdot
.47161 .26397 Mdot
.48591 .51365 Mdot
.04232 .5815 Mdot
.72426 .05696 Mdot
.54249 .11614 Mdot
.59891 .203 Mdot
.4654 .40864 Mdot
.92566 .73536 Mdot
.30782 .1266 Mdot
.39882 .48508 Mdot
.38205 .18027 Mdot
.47075 .69275 Mdot
.04372 .78188 Mdot
.11774 .04477 Mdot
.86988 .33375 Mdot
.26069 .85136 Mdot
.46254 .08253 Mdot
.52585 .78318 Mdot
.13155 .53831 Mdot
.73573 .9134 Mdot
.68833 .54796 Mdot
.19963 .56183 Mdot
.17216 .50193 Mdot
.86354 .00468 Mdot
.26178 .58297 Mdot
.87898 .82748 Mdot
.2584 .38469 Mdot
.48621 .84139 Mdot
.66011 .43463 Mdot
.0941 .19316 Mdot
.66505 .76285 Mdot
.22424 .1463 Mdot
.84168 .07835 Mdot
.15859 .71764 Mdot
.80417 .71311 Mdot
.15982 .84737 Mdot
.40792 .99314 Mdot
.41639 .88612 Mdot
.28298 .47339 Mdot
.79363 .91024 Mdot
.75734 .17196 Mdot
.83566 .85375 Mdot
.9584 .54568 Mdot
.47454 .56962 Mdot
.25036 .33258 Mdot
.45255 .7181 Mdot
.58071 .75563 Mdot
.15609 .00524 Mdot
.03685 .89755 Mdot
.87653 .98211 Mdot
.61959 .55745 Mdot
.94821 .20709 Mdot
.99908 .24934 Mdot
.24749 .49231 Mdot
.9052 .84094 Mdot
.63684 .05648 Mdot
.79002 .37227 Mdot
.31968 .20502 Mdot
.34468 .48205 Mdot
.02817 .33463 Mdot
.44245 .72196 Mdot
.2867 .21764 Mdot
.68564 .29633 Mdot
.47586 .87405 Mdot
.82132 .91234 Mdot
.09251 .51649 Mdot
.04996 .93843 Mdot
.58999 .59546 Mdot
.395 .69804 Mdot
.13547 .25603 Mdot
.91362 .08167 Mdot
.24111 .05624 Mdot
.60791 .22324 Mdot
.82032 .97152 Mdot
.78725 .06051 Mdot
.48227 .96335 Mdot
.09887 .28348 Mdot
.25376 .58038 Mdot
.91298 .21156 Mdot
.79883 .85153 Mdot
.65169 .64796 Mdot
.52731 .46057 Mdot
.60179 .43131 Mdot
.42012 .54007 Mdot
.86004 .34141 Mdot
.46503 .43256 Mdot
.93694 .14654 Mdot
.11962 .33383 Mdot
.97134 .99892 Mdot
.73019 .88961 Mdot
.92326 .92135 Mdot
.06434 .9012 Mdot
.408 .40823 Mdot
.67291 .30505 Mdot
.67089 .84224 Mdot
.11618 .89948 Mdot
.67575 .6328 Mdot
.78486 .33087 Mdot
.60382 .34977 Mdot
.53253 .13191 Mdot
.49529 .48743 Mdot
.66728 .1088 Mdot
.43543 .70279 Mdot
.735 .343 Mdot
.16186 .15993 Mdot
.19774 .17403 Mdot
.62685 .45311 Mdot
.94834 .40786 Mdot
.085 .68714 Mdot
.29696 .9425 Mdot
.34648 .47158 Mdot
.62972 .94495 Mdot
.71538 .84871 Mdot
.82647 .70124 Mdot
.41515 .28109 Mdot
.22421 .22049 Mdot
.11626 .25654 Mdot
.15935 .18284 Mdot
.35589 .6682 Mdot
.07785 .63698 Mdot
.40528 .84591 Mdot
.91607 .83209 Mdot
.19293 .50865 Mdot
.15419 .02254 Mdot
.34048 .52458 Mdot
.46227 .18763 Mdot
.0621 .37861 Mdot
.102 .83272 Mdot
.80922 .25782 Mdot
.07556 .78542 Mdot
.31788 .45701 Mdot
.86352 .01169 Mdot
.77994 .47631 Mdot
.81192 .31482 Mdot
.72256 .833 Mdot
.52223 .42873 Mdot
.51575 .17057 Mdot
.19451 .10781 Mdot
.59037 .92549 Mdot
.22614 .13976 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool3o`0000oo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00So
oooo0_l00003ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00Co0000ooooool0003o00003?ooool2o`00
00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool2o`0000Ko
oooo00Co0000ooooool0003o00003Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00_ooooo0ol0000?ooooo`03o`000?oooooooooo00Sooooo0_l00004ooooo`03o`000?oooooooooo
00Sooooo0_l00003ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool2o`00
00oooooo00?o0000ooooooooool02?ooool2o`0000?ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool01?l0
003oooooooooooooool2o`0000[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00;ooooo000Nooooo`03o`000?oooooooooo00gooooo0_l0000Poooo
o`;o0000B?ooool2o`0000oooooo0_l0000Sooooo`;o0000?oooool2o`0002?ooooo0_l0000`oooo
o`007_ooool00ol0003oooooooooo`0=ooooo`;o0000Qoooool2o`0005Sooooo0_l0000Sooooo`;o
00004oooool2o`0001_ooooo000Nooooo`03o`000?oooooooooo04Wooooo0_l0000^ooooo`;o0000
6oooool2o`0002Sooooo0_l0001Cooooo`;o00004oooool2o`000003ooooool0003o000001Sooooo
000Nooooo`03o`000?oooooooooo04Wooooo1?l0000/ooooo`;o0000AOooool2o`0006_ooooo0_l0
000Hooooo`007_ooool00ol0003oooooooooo`0^ooooo`;o00006oooool2o`0003kooooo0_l0002O
ooooo`;o00006Oooool001kooooo00?o0000ooooooooool0;_ooool2o`0005Wooooo1?l0002Ooooo
o`;o00006Oooool001kooooo00?o0000ooooooooool0ROooool2o`0003Gooooo0_l0000aooooo`;o
0000D_ooool001kooooo00?o0000ooooooooool0E?ooool2o`0001gooooo0_l0000Aooooo`;o0000
2oooool2o`0002_ooooo0_l0000aooooo`;o00004_ooool2o`0003kooooo000Nooooo`03o`000?oo
oooooooo05Cooooo0_l0000Mooooo`;o00001?ooool2o`0000_ooooo0_l0000;ooooo`;o00008?oo
ool2o`0000Sooooo0_l00016ooooo`;o0000?_ooool001kooooo00?o0000ooooooooool03oooool2
o`0006Sooooo0_l0000jooooo`;o00002?ooool2o`0006Cooooo0_l0000Pooooo`007_ooool00ol0
003oooooooooo`0?ooooo`;o00001Oooool2o`0006Kooooo0_l0000Booooo`;o00001Oooool2o`00
03oooooo0_l00019ooooo`;o00008?ooool001kooooo0ol0000Fooooo`;o0000I_ooool2o`0001;o
oooo0_l00005ooooo`;o0000?oooool2o`0006?ooooo0_l00006ooooo`007_ooool3o`0001Kooooo
0_l0000:ooooo`;o0000o_ooool2o`0000Gooooo0_l0000Dooooo`;o00001_ooool001kooooo00?o
0000ooooooooool05_ooool2o`0000[ooooo0_l0001Fooooo`;o0000Y_ooool2o`0000Gooooo0_l0
000Looooo`007_ooool2o`0002?ooooo0_l00009ooooo`;o0000Boooool2o`000<_ooooo000Noooo
o`03o`000?oooooooooo02gooooo0_l00004ooooo`;o00005Oooool2o`0007oooooo0_l00006oooo
o`;o0000L_ooool001kooooo00?o0000ooooooooool0<oooool2o`0001Gooooo0_l0001@ooooo`;o
0000;Oooool2o`0000Kooooo0_l0000Booooo`;o0000>oooool2o`00027ooooo000Nooooo`03o`00
0?oooooooooo00Wooooo0_l0001Dooooo`;o00009Oooool2o`0000_ooooo0_l00007ooooo`;o0000
8Oooool2o`0002Kooooo0_l0000Cooooo`;o00009_ooool2o`00027ooooo000Nooooo`03o`000?oo
oooooooo00Wooooo0_l0001Dooooo`;o00009Oooool2o`0000_ooooo0_l0000Zooooo`;o0000>ooo
ool2o`0004Wooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0003oooooo`Wooooo0_l0000M
ooooo`;o00006?ooool001kooooo00?o0000ooooooooool01?ooool2o`0002cooooo0_l0003Joooo
o`;o00001_ooool2o`0001Gooooo0_l0000Hooooo`007_ooool00ol0003oooooooooo`0booooo`;o
0000??ooool2o`0003;ooooo0_l0001Oooooo`;o00002_ooool2o`0000?ooooo0_l0000_ooooo`00
7_ooool00ol0003oooooooooo`1`ooooo`;o00008oooool2o`0000gooooo0_l0001Oooooo`;o0000
2_ooool2o`0003Cooooo000Nooooo`03o`000?oooooooooo09Gooooo0_l0000gooooo`;o00006ooo
ool2o`00027ooooo0_l0000Fooooo`;o00007oooool001kooooo00?o0000ooooooooool0QOooool2
o`0000Gooooo0_l00004ooooo`;o0000:?ooool2o`00013ooooo0_l0000Kooooo`;o00008Oooool2
o`0001Gooooo0ol0000Oooooo`007_ooool00ol0003oooooooooo`08ooooo`;o00004oooool2o`00
03Sooooo0_l0000=ooooo`;o00007Oooool2o`0000Gooooo0_l00004ooooo`;o0000:?ooool2o`00
06Oooooo0_l0000Pooooo`007_ooool00ol0003oooooooooo`08ooooo`;o00004oooool2o`0003So
oooo0_l0000=ooooo`;o00005_ooool2o`0006Wooooo0_l0001Looooo`007Oooool2o`0002_ooooo
0_l0001Cooooo`Co00004oooool2o`0004cooooo0_l00004ooooo`;o0000G?ooool001gooooo0_l0
000;ooooo`;o00007_ooool2o`0005Gooooo0_l0000Cooooo`;o0000>_ooool2o`00013ooooo0_l0
001Rooooo`007_ooool00ol0003oooooooooo`09ooooo`;o00007_ooool2o`000:Kooooo0_l0001F
ooooo`;o00007?ooool001kooooo0_l0000Zooooo`;o00003?ooool2o`000=Oooooo0_l0000Goooo
o`;o00007?ooool001kooooo00?o0000ooooooooool0=oooool2o`0007kooooo0_l0001Gooooo`;o
0000=Oooool001kooooo00?o0000ooooooooool0:Oooool2o`00013ooooo0_l0000fooooo`;o0000
@_ooool2o`0001cooooo0_l0000?ooooo`;o00009_ooool2o`0003Oooooo000Nooooo`03o`000?oo
oooooooo01kooooo0_l00009ooooo`;o00004?ooool2o`0003Kooooo0_l0000@ooooo`;o0000??oo
ool2o`00013ooooo0_l00006ooooo`;o00001oooool2o`0002Kooooo0_l0000Pooooo`;o00005Ooo
ool001kooooo00?o0000ooooooooool07_ooool2o`0006Gooooo0_l0000Gooooo`;o00005?ooool2
o`0000gooooo0_l0000;ooooo`;o00002oooool2o`0000Kooooo0_l0000cooooo`;o00005?ooool2
o`0001Gooooo000Nooooo`03o`000?oooooooooo03Oooooo0_l0000iooooo`;o00009?ooool2o`00
00Cooooo0_l0000<ooooo`;o00001_ooool2o`0001[ooooo0_l0000Cooooo`;o0000<oooool2o`00
02_ooooo000Nooooo`03o`000?oooooooooo03Oooooo0_l0000iooooo`;o00004Oooool2o`00017o
oooo0_l0000Booooo`;o00008oooool2o`0001Kooooo0_l0001Looooo`007_ooool00ol0003ooooo
ooooo`0Booooo`;o00002_ooool2o`0002_ooooo0_l0000hooooo`;o0000B_ooool2o`0001Kooooo
0_l0000;ooooo`;o0000Coooool001kooooo00?o0000ooooooooool04_ooool2o`0000[ooooo0_l0
000[ooooo`;o00004oooool2o`0005Kooooo0_l0000looooo`;o0000<_ooool2o`000003ooooool0
003o000001Sooooo000Nooooo`03o`000?oooooooooo063ooooo0_l0000booooo`;o00008_ooool2
o`0000Cooooo0_l0001Zooooo`;o000000?oooooo`000?l000006?ooool001kooooo00?o0000oooo
ooooool0<?ooool2o`0005_ooooo0_l00005ooooo`;o00004oooool2o`0001?ooooo0_l00027oooo
o`007_ooool00ol0003oooooooooo`0Tooooo`;o00002_ooool2o`0005_ooooo0_l0000Jooooo`;o
0000J?ooool2o`0000Oooooo0_l0000Iooooo`;o000000?oooooo`000?l000002oooool001kooooo
00?o0000ooooooooool09?ooool2o`0001oooooo0_l0000Gooooo`;o00001oooool2o`000:[ooooo
0_l00007ooooo`;o00004Oooool2o`0000Kooooo0_l000000ooooooo0000o`00000;ooooo`007_oo
ool00ol0003oooooooooo`15ooooo`;o00005oooool2o`0000Oooooo0_l0002Iooooo`;o00000_oo
ool2o`0001_ooooo0_l0000:ooooo`;o00005_ooool001kooooo00?o0000ooooooooool0C_ooool2
o`000;;ooooo0_l00002ooooo`;o00006oooool2o`0001?ooooo0_l0000=ooooo`007_ooool00ol0
003oooooooooo`15ooooo`;o00001oooool2o`0006Sooooo0_l00015ooooo`;o0000:oooool2o`00
00[ooooo0_l0000=ooooo`007_ooool2o`0001Kooooo0_l0000Jooooo`;o00004_ooool2o`0000Go
oooo0_l0001Hooooo`;o00004?ooool2o`0004Gooooo0_l0000[ooooo`;o00006Oooool001kooooo
00?o0000ooooooooool05Oooool2o`000003ooooool0003o000001Oooooo0_l0000Iooooo`;o0000
F?ooool2o`0009oooooo000Nooooo`03o`000?oooooooooo01Sooooo0_l0000;ooooo`;o0000<ooo
ool2o`0007[ooooo0_l0000cooooo`;o0000>_ooool001kooooo00?o0000ooooooooool09Oooool2
o`0000[ooooo0_l0000Wooooo`;o0000HOooool2o`0001Oooooo0_l0000cooooo`;o0000>_ooool0
01kooooo00?o0000ooooooooool0<Oooool2o`0008[ooooo0_l0000Kooooo`;o0000Doooool2o`00
01Kooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0000;ooooo`;o0000^Oooool2o`0005?o
oooo0_l0000Fooooo`007_ooool00ol0003oooooooooo`0Booooo`;o00002oooool2o`0008?ooooo
0_l0002Qooooo`007_ooool00ol0003oooooooooo`05ooooo`;o00008oooool2o`0004Kooooo0_l0
000`ooooo`;o0000A_ooool2o`0000Cooooo0_l0001Cooooo`007_ooool00ol0003oooooooooo`05
ooooo`;o00008oooool2o`00013ooooo0_l0000dooooo`;o00005_ooool2o`00063ooooo0_l00004
ooooo`;o0000Doooool001kooooo00?o0000ooooooooool01_ooool2o`0002;ooooo0_l0000@oooo
o`;o0000BOooool2o`000003ooooool0003o000003Gooooo0_l0000Aooooo`;o0000LOooool001ko
oooo00?o0000ooooooooool01_ooool2o`0002Sooooo0_l0000dooooo`;o00004?ooool2o`0000go
oooo0_l0000hooooo`Co00003oooool2o`00077ooooo000Nooooo`03o`000?oooooooooo033ooooo
0_l0000dooooo`;o00004?ooool2o`0004Wooooo0_l0000=ooooo`;o0000@?ooool2o`00037ooooo
000Nooooo`03o`000?oooooooooo08Sooooo0_l00008ooooo`;o0000<?ooool2o`0000cooooo0_l0
0010ooooo`;o00001Oooool2o`0002[ooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0001W
ooooo`;o00001_ooool2o`0000Sooooo0_l0000`ooooo`;o0000EOooool2o`0002[ooooo0003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooo
oooo01Oooooo0_l000000ooooooo0000o`00001Tooooo`;o0000aOooool000?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o
0000ooooooooool06_ooool2o`000?oooooo;?ooool000?ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol00004ooooo`;o00008_ooool2o`0004Kooooo0_l0
000Aooooo`;o0000P_ooool2o`0003kooooo0003ooooo`05o`000?ooooooooooooooool000003Ooo
ool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo00Cooooo0_l0000Eooooo`;o00001?oo
ool2o`0000Gooooo0_l0000Iooooo`;o0000:oooool2o`00017ooooo0_l0000]ooooo`;o00002ooo
ool2o`0003_ooooo0_l00009ooooo`;o00008oooool2o`0001;ooooo0_l00005ooooo`000oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`06ooooo`;o00004oooool2o`0000Cooooo0_l0000Pooooo`;o00004oooool2o`0000[ooooo0_l0
001<ooooo`;o00002oooool2o`0003_ooooo0_l0000^ooooo`;o00000_ooool2o`0000kooooo0_l0
0005ooooo`000oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`06ooooo`;o0000@Oooool2o`0000gooooo0_l00006ooooo`;o00000_oo
ool2o`0005Gooooo0_l0001Yooooo`;o00002?ooool2o`0001Gooooo0003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
1oooool2o`00043ooooo0_l0000Booooo`;o000000?oooooo`000?l000001?ooool2o`0005?ooooo
0_l0001Pooooo`;o00001_ooool3o`0001oooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool01oooool2o`00043o
oooo0_l0000Booooo`;o00001oooool2o`000;Gooooo0_l00006ooooo`;o00008?ooool001kooooo
00?o0000ooooooooool02_ooool2o`0000Oooooo0_l0000dooooo`;o00003_ooool2o`0007Kooooo
0_l0000Sooooo`;o0000Coooool001kooooo00?o0000ooooooooool02_ooool2o`0000Oooooo0_l0
000`ooooo`;o00004_ooool2o`0007Kooooo0_l0000Sooooo`;o0000Coooool001kooooo00?o0000
ooooooooool0AOooool2o`0007_ooooo1?l0001Fooooo`;o0000:Oooool001kooooo00?o0000oooo
ooooool0??ooool2o`0004Gooooo0_l0000mooooo`Co0000E_ooool2o`0002Wooooo000Nooooo`03
o`000?oooooooooo03cooooo0_l00015ooooo`;o00002?ooool2o`000;Sooooo000Nooooo`03o`00
0?oooooooooo08gooooo0_l0000>ooooo`;o00001_ooool2o`0007_ooooo0_l00009ooooo`;o0000
6?ooool001kooooo00?o0000ooooooooool0J?ooool2o`0003?ooooo0ol00005ooooo`;o00009?oo
ool2o`0003cooooo0_l0000Gooooo`;o00001?ooool2o`0000?ooooo0_l0000Hooooo`007_ooool0
0ol0003oooooooooo`1Xooooo`;o00008_ooool2o`0000oooooo0ol0000[ooooo`;o0000??ooool2
o`0001gooooo0_l0000Mooooo`007_ooool00ol0003oooooooooo`1;ooooo`;o00009?ooool2o`00
01Wooooo0_l0000Zooooo`;o0000:?ooool2o`0001kooooo0_l0000Pooooo`;o00008Oooool001ko
oooo00?o0000ooooooooool0Boooool2o`0002Cooooo0_l0000dooooo`;o00003oooool2o`0002Co
oooo0_l00002ooooo`;o00002Oooool2o`0001?ooooo0_l0000Pooooo`;o00004Oooool2o`0000ko
oooo000Nooooo`03o`000?oooooooooo0:Oooooo0_l0000Looooo`;o00005oooool2o`0000gooooo
0_l00018ooooo`;o00002?ooool2o`0000Cooooo000Nooooo`;o0000a_ooool2o`0007[ooooo0_l0
0004ooooo`007_ooool00ol0003oooooooooo`0Rooooo`;o00001?ooool2o`00033ooooo0_l0001k
ooooo`;o0000K_ooool001kooooo00?o0000ooooooooool08_ooool2o`0000Cooooo0_l0000`oooo
o`;o0000Noooool2o`0000Oooooo0_l0000?ooooo`;o00004?ooool2o`0004;ooooo000Nooooo`03
o`000?oooooooooo02Wooooo0_l0001Jooooo`;o00002_ooool2o`0001gooooo0_l0000^ooooo`;o
00003oooool2o`00013ooooo0_l0000Qooooo`;o00000oooool2o`0001[ooooo000Nooooo`03o`00
0?oooooooooo02Wooooo0_l0001:ooooo`;o00003_ooool2o`0000[ooooo0_l00002ooooo`;o0000
6Oooool2o`0007Cooooo0_l00003ooooo`;o00006_ooool001kooooo00?o0000ooooooooool08Ooo
ool2o`0005;ooooo0_l0000Nooooo`;o0000;_ooool2o`0006Gooooo0_l0000Iooooo`007_ooool0
0ol0003oooooooooo`0Qooooo`;o0000@?ooool2o`00063ooooo0_l0001Uooooo`;o00006Oooool0
01kooooo00?o0000ooooooooool0;oooool2o`0002oooooo0_l000000ooooooo0000o`00003Roooo
o`007_ooool00ol0003oooooooooo`0_ooooo`;o0000:oooool2o`0000;ooooo0_l0003Uooooo`00
7_ooool2o`0005gooooo0_l0000Uooooo`;o00001_ooool2o`0004Wooooo0_l0000@ooooo`;o0000
GOooool001kooooo0_l0000Mooooo`;o0000IOooool2o`0000Kooooo0_l0000Eooooo`;o0000<_oo
ool2o`00013ooooo0_l0001Mooooo`007_ooool00ol0003oooooooooo`0Looooo`;o0000Goooool2
o`0002?ooooo0_l0002Sooooo`007_ooool00ol0003oooooooooo`07ooooo`;o00001?ooool2o`00
05Cooooo0_l0000Hooooo`;o00006_ooool2o`0001kooooo0_l0002<ooooo`007_ooool00ol0003o
ooooooooo`07ooooo`?o00000oooool2o`0005Cooooo0_l0000Sooooo`;o00003oooool2o`0000co
oooo0_l00009ooooo`;o00001Oooool2o`0008cooooo000Nooooo`03o`000?oooooooooo00Sooooo
0_l0000;ooooo`;o0000?oooool2o`00033ooooo0_l0000Mooooo`;o00002Oooool2o`0002Oooooo
0_l0000`ooooo`;o0000>?ooool001kooooo00?o0000ooooooooool05Oooool2o`0003oooooo0_l0
0023ooooo`;o00008Oooool2o`0000gooooo0_l0000Eooooo`;o00008Oooool001kooooo0_l0003j
ooooo`;o00000oooool2o`0002Cooooo0_l0000Qooooo`007_ooool00ol0003oooooooooo`07oooo
o`;o00005Oooool2o`0000Gooooo0_l0001Gooooo`;o00001_ooool2o`0000Wooooo0_l00005oooo
o`;o0000?Oooool2o`0001Gooooo0ol00008ooooo`;o00004_ooool2o`0003Sooooo000Nooooo`03
o`000?oooooooooo00Oooooo0_l0000Eooooo`;o00001Oooool2o`000003ooooool0003o000000[o
oooo0_l00018ooooo`;o00001_ooool2o`0000Wooooo0_l00005ooooo`;o0000>Oooool2o`0000;o
oooo0_l0000Eooooo`?o00004?ooool2o`0000[ooooo0_l00009ooooo`;o00006_ooool2o`00017o
oooo000Nooooo`03o`000?oooooooooo02Sooooo0_l0000:ooooo`;o00004oooool2o`0005Oooooo
0_l0000Xooooo`;o00001Oooool2o`0002cooooo0_l0000Eooooo`;o00006_ooool2o`00017ooooo
000Nooooo`03o`000?oooooooooo04Wooooo0_l0000Booooo`;o0000@oooool2o`0000Sooooo0_l0
000Nooooo`?o00007_ooool2o`0001Gooooo0_l0000`ooooo`;o00003oooool001kooooo00?o0000
ooooooooool0GOooool2o`0004gooooo0_l00003ooooo`;o00006_ooool2o`0001kooooo0_l0000E
ooooo`;o0000<?ooool2o`0000oooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l0002Yoooo
o`;o00006?ooool4o`0007Sooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l000000ooooooo
0000o`000033ooooo`Co0000N?ooool001kooooo00?o0000ooooooooool00oooool2o`0006gooooo
0_l0003Cooooo`007_ooool00ol0003oooooooooo`1Looooo`;o00005?ooool2o`0005Kooooo0_l0
000mooooo`;o0000??ooool001kooooo00?o0000ooooooooool0COooool2o`0000gooooo0_l0001X
ooooo`;o00000_ooool2o`00013ooooo0_l0000Mooooo`;o00003?ooool2o`0003cooooo000Noooo
o`03o`000?oooooooooo00Gooooo0_l0000Looooo`;o00002Oooool2o`0001gooooo0_l0001goooo
o`;o00005?ooool2o`0001gooooo0_l00005ooooo`;o00004oooool2o`0002kooooo000Nooooo`03
o`000?oooooooooo00;o00000oooool2o`0001cooooo0_l00009ooooo`;o00007Oooool2o`0000oo
oooo0_l0001Gooooo`;o0000BOooool2o`0001?ooooo0_l0000^ooooo`007_ooool00ol0003ooooo
ooooo`02o`0001Kooooo0_l0000cooooo`;o00003oooool2o`0003;ooooo0_l0000Sooooo`;o0000
F_ooool2o`0003;ooooo000Nooooo`03o`000?oooooooooo01Sooooo0ol0001gooooo`;o00009ooo
ool2o`0002cooooo1?l0000Vooooo`;o0000<_ooool001kooooo00?o0000ooooooooool06Oooool4
o`0009kooooo0_l0000=ooooo`;o00001oooool2o`0001Cooooo1?l0000_ooooo`;o0000:Oooool0
01kooooo0_l0000;ooooo`;o00003oooool2o`0001Cooooo0_l0000Yooooo`;o0000=?ooool2o`00
02cooooo0_l00008ooooo`;o00001oooool2o`0002[ooooo0_l0000Iooooo`Co0000:Oooool001ko
oooo00?o0000ooooooooool02_ooool2o`0002Gooooo0_l0000Yooooo`;o0000=?ooool2o`0000go
oooo0_l0000Mooooo`;o0000?Oooool4o`0001Oooooo0_l0000[ooooo`007_ooool00ol0003ooooo
ooooo`0Iooooo`;o0000GOooool2o`0002Oooooo0_l0001Nooooo`;o00004oooool2o`0002oooooo
000Nooooo`03o`000?oooooooooo01Wooooo0_l0001Mooooo`;o0000Coooool2o`0000Gooooo0_l0
0007ooooo`;o0000>oooool2o`0002oooooo000Nooooo`03o`000?oooooooooo0<Wooooo0_l00005
ooooo`;o00001oooool2o`0006cooooo000Nooooo`03o`000?oooooooooo02[ooooo0_l0000Voooo
o`;o0000W_ooool2o`0003gooooo0_l0000Dooooo`007_ooool00ol0003oooooooooo`0Zooooo`;o
00009_ooool2o`0009kooooo0_l000000ooooooo0000o`000002o`0003Sooooo0_l0000:ooooo`;o
00002?ooool001kooooo00?o0000ooooooooool08Oooool2o`0006Cooooo0_l0001/ooooo`Co0000
1?ooool2o`0003kooooo0_l00008ooooo`007_ooool00ol0003oooooooooo`0Qooooo`;o0000I?oo
ool2o`0007Cooooo0_l00018ooooo`007_ooool00ol0003oooooooooo`07ooooo`;o00001oooool2
o`000?oooooo2Oooool2o`0002_ooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l00004oooo
o`;o000000?oooooo`000?l00000@_ooool2o`0004Sooooo0_l0001Nooooo`;o00004_ooool2o`00
00Kooooo0_l0000[ooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o0000@Oooool2o`0000;o
oooo0_l0000booooo`;o00005?ooool2o`0002cooooo0_l00005ooooo`;o0000:Oooool2o`0001;o
oooo0_l0000cooooo`007_ooool00ol0003oooooooooo`0^ooooo`;o00008?ooool2o`0003Kooooo
0_l00012ooooo`;o00001Oooool2o`0007;ooooo000Nooooo`03o`000?oooooooooo02kooooo0_l0
0008ooooo`;o0000S?ooool2o`0002oooooo0_l0001>ooooo`000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003ooooooooo
o`09ooooo`;o0000;Oooool2o`00043ooooo0_l0001:ooooo`;o0000;oooool2o`0004kooooo0003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`09ooooo`;o00003oooool2o`0005kooooo0_l0000eooooo`;o0000;?oo
ool2o`0006Kooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol0
000Jooooo`;o00006Oooool2o`0002cooooo0_l0000Wooooo`;o00008oooool2o`0002cooooo0_l0
001Vooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
1oooool00ol0003oooooooooo`0eooooo`;o0000;?ooool2o`0000gooooo0_l0000Hooooo`;o0000
Loooool2o`0004Cooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEE
ooooool00007ooooo`03o`000?oooooooooo07;ooooo0_l0000Fooooo`;o0000?oooool2o`0003Co
oooo0_l00014ooooo`000oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l0
00001oooool2o`0008;ooooo0_l00007ooooo`;o00001oooool2o`0001?ooooo0_l0000Qooooo`;o
0000E?ooool2o`0000gooooo0_l0000Eooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00co
oooo00?ok^k^odA4A?l000001oooool2o`0008;ooooo0_l0000@ooooo`Co00004Oooool2o`0007Oo
oooo0_l0000=ooooo`;o00005Oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03
ogMgMol0003ooooo00Kooooo00?o0000ooooooooool02Oooool2o`0000cooooo0_l0001looooo`;o
0000/?ooool001kooooo00?o0000ooooooooool01?ooool2o`0000?ooooo0_l0000<ooooo`;o0000
ooooool_ooooo`007_ooool00ol0003oooooooooo`04ooooo`;o00007Oooool2o`0007;ooooo0_l0
0010ooooo`;o0000K?ooool001kooooo00?o0000ooooooooool08oooool3o`00077ooooo0_l0000/
ooooo`;o00004_ooool3o`0000Gooooo0_l0000Cooooo`;o0000:_ooool2o`0002?ooooo000Noooo
o`03o`000?oooooooooo02Cooooo0_l0000:ooooo`;o00009Oooool2o`0004gooooo0_l0000Moooo
o`;o00003_ooool2o`0000?ooooo0_l00005ooooo`;o00004oooool2o`0002[ooooo0_l0000Soooo
o`007_ooool00ol0003oooooooooo`0`ooooo`;o00009Oooool2o`0000Sooooo0_l00013ooooo`;o
00006?ooool2o`0001?ooooo0_l0000Dooooo`;o0000F_ooool001kooooo00?o0000ooooooooool0
6_ooool2o`0004Gooooo0_l0000`ooooo`;o0000:oooool2o`00013ooooo0_l0000Gooooo`;o0000
F_ooool001kooooo00Co0000ooooool0003o00006Oooool2o`0003Sooooo0_l0000mooooo`;o0000
?Oooool2o`0000Cooooo0_l0000cooooo`;o00001Oooool2o`00037ooooo000Nooooo`04o`000?oo
oooo0000o`0002;ooooo0_l0000_ooooo`;o00004?ooool2o`0001;ooooo0_l0000booooo`;o0000
:?ooool2o`0003?ooooo0_l00005ooooo`;o0000<Oooool001kooooo00?o0000ooooooooool04?oo
ool2o`0000cooooo0_l00003ooooo`?o0000@?ooool2o`0001;ooooo0_l0000booooo`;o0000Uooo
ool001kooooo00?o0000ooooooooool04?ooool2o`0000cooooo0_l00004ooooo`;o0000AOooool2
o`0000cooooo0_l0003<ooooo`007_ooool00ol0003oooooooooo`1[ooooo`;o00003?ooool2o`00
03gooooo0_l0001mooooo`;o00003_ooool001kooooo0_l0002iooooo`;o00003_ooool2o`0006go
oooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`04ooooo`;o0000;oooool2o`0007Oooooo
0_l0000Hooooo`;o0000OOooool001kooooo00?o0000ooooooooool01?ooool2o`0002oooooo0_l0
000/ooooo`;o0000BOooool2o`0001cooooo0_l0001iooooo`007_ooool00ol0003oooooooooo`0D
ooooo`;o0000COooool2o`0003_ooooo0_l00005ooooo`;o00008oooool2o`0003Cooooo0_l0000?
ooooo`;o0000<_ooool001kooooo00?o0000ooooooooool05?ooool2o`0001Cooooo0_l0000Foooo
o`;o0000<?ooool2o`0002[ooooo0_l00005ooooo`;o0000FOooool2o`0000oooooo0_l0000boooo
o`007_ooool00ol0003oooooooooo`0Zooooo`;o00005_ooool2o`00033ooooo0_l0000Vooooo`;o
0000FOooool2o`0002Oooooo0_l0000Uooooo`007_ooool00ol0003oooooooooo`1]ooooo`;o0000
;Oooool2o`0005Wooooo0_l0000Wooooo`;o00009Oooool001kooooo00?o0000ooooooooool07?oo
ool2o`0003[ooooo0_l0000Cooooo`;o0000Qoooool2o`0004oooooo000Nooooo`03o`000?oooooo
oooo01cooooo0_l0000jooooo`;o0000W?ooool2o`000003ooooool0003o000004cooooo000Noooo
o`03o`000?oooooooooo02oooooo0_l0002oooooo`;o00001oooool2o`0004cooooo000Nooooo`03
o`000?oooooooooo02oooooo0_l0000kooooo`;o0000?oooool2o`0000cooooo0_l0000;ooooo`;o
00009_ooool2o`0005Gooooo000Nooooo`03o`000?oooooooooo06cooooo0_l0000@ooooo`;o0000
;Oooool2o`0000Sooooo0_l00002ooooo`;o00002oooool2o`0006Kooooo0_l0000Eooooo`007_oo
ool00ol0003oooooooooo`1nooooo`;o00007Oooool2o`0001Sooooo0_l0001Rooooo`;o00002?oo
ool2o`0000Wooooo0_l0000Eooooo`007_ooool00ol0003oooooooooo`1<ooooo`;o00008Oooool2
o`0002cooooo0_l0001looooo`;o00002?ooool2o`00023ooooo000Nooooo`03o`000?oooooooooo
01Kooooo0_l0000dooooo`;o00008Oooool2o`0001Sooooo0_l0002looooo`007_ooool00ol0003o
ooooooooo`0Fooooo`;o00009Oooool2o`0004Cooooo0_l00004ooooo`;o0000S_ooool2o`0002co
oooo000Nooooo`;o00005?ooool2o`0001gooooo1_l00005ooooo`;o0000A?ooool2o`0006oooooo
0_l0000<ooooo`;o00005Oooool2o`0002cooooo000Nooooo`03o`000?oooooooooo01?ooooo0_l0
000Mooooo`Ko00001oooool3o`0002Wooooo0_l0000Cooooo`;o00009?ooool2o`0002Sooooo0_l0
000Rooooo`;o00003?ooool2o`0004?ooooo000Nooooo`03o`000?oooooooooo03_ooooo0_l00002
ooooo`?o0000:Oooool2o`0001?ooooo0_l0000Tooooo`;o0000:?ooool2o`0007Gooooo000Noooo
o`03o`000?oooooooooo02?ooooo0_l0000Fooooo`;o0000=_ooool2o`000:gooooo0_l0000Soooo
o`007_ooool00ol0003oooooooooo`0Sooooo`;o0000;oooool2o`0001gooooo0_l0000Uooooo`;o
0000Q_ooool2o`0002?ooooo000Nooooo`03o`000?oooooooooo01[ooooo0_l0000hooooo`;o0000
:_ooool2o`0001Sooooo0_l0001^ooooo`;o0000>oooool001kooooo00?o0000ooooooooool06_oo
ool2o`0004Oooooo0_l00005ooooo`;o00005?ooool2o`0008Sooooo0_l0000kooooo`007_ooool0
0ol0003oooooooooo`1Sooooo`;o00001Oooool2o`0007gooooo0_l0001Looooo`007_ooool00ol0
003oooooooooo`02o`0006Wooooo0_l0000mooooo`;o0000?Oooool2o`0005cooooo000Nooooo`03
o`000?oooooooooo00;o00004?ooool2o`0001Gooooo0_l0000Wooooo`Co00005Oooool2o`0003go
oooo0_l0002Kooooo`007_ooool00ol0003oooooooooo`0Booooo`?o00005?ooool2o`0002Oooooo
1?l0003aooooo`007_ooool00ol0003oooooooooo`03ooooo`;o00000oooool2o`0000Sooooo0ol0
000>ooooo`;o00009?ooool2o`0000_ooooo0_l0003_ooooo`007_ooool00ol0003oooooooooo`03
ooooo`;o00000oooool2o`0001Wooooo0_l00002ooooo`;o00008?ooool2o`0000_ooooo0_l0000V
ooooo`;o0000aoooool001kooooo00?o0000ooooooooool09oooool2o`0005Gooooo0_l00004oooo
o`;o0000Eoooool2o`0006Sooooo000Nooooo`03o`000?oooooooooo05Oooooo0_l00003ooooo`;o
00009_ooool2o`0004oooooo0_l00006ooooo`;o0000E?ooool2o`0001;ooooo000Nooooo`03o`00
0?oooooooooo00;o00002oooool2o`0002Oooooo0_l0000Kooooo`;o00000_ooool2o`0000?ooooo
0_l0000Rooooo`;o0000@Oooool2o`00013ooooo0_l00005ooooo`;o0000>_ooool2o`0001Wooooo
0_l0000Booooo`007_ooool2o`000003ooooool0003o000000_ooooo0_l0000Gooooo`;o00003_oo
ool2o`0001_ooooo0_l0000[ooooo`;o00006?ooool2o`00023ooooo0_l00005ooooo`;o00005ooo
ool2o`000003ooooool0003o000003Oooooo0_l0000]ooooo`007_ooool00ol0003oooooooooo`0V
ooooo`;o0000L_ooool2o`0001?ooooo0_l00005ooooo`;o00001?ooool2o`00027ooooo0_l0001V
ooooo`007_ooool00ol0003oooooooooo`1Xooooo`;o00005?ooool2o`0002oooooo0_l00005oooo
o`;o00003Oooool2o`00043ooooo0_l0000nooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o
0000Foooool2o`0001Cooooo0_l00015ooooo`;o0000@?ooool2o`00037ooooo0_l0000;ooooo`00
7_ooool00ol0003oooooooooo`0;ooooo`;o0000<?ooool2o`000<Gooooo0_l0000dooooo`;o0000
2oooool001kooooo00?o0000ooooooooool0?Oooool2o`0000[ooooo0_l0002iooooo`;o0000@Ooo
ool001kooooo00?o0000ooooooooool0BOooool2o`0004_ooooo0_l0000Tooooo`;o0000?Oooool2
o`0000_ooooo0_l0000Hooooo`;o00008oooool001kooooo00?o0000ooooooooool01_ooool2o`00
03Wooooo0_l0001Cooooo`;o00009?ooool2o`0001kooooo0_l0000Mooooo`;o00002oooool2o`00
01Sooooo0_l0000Sooooo`007_ooool00ol0003oooooooooo`06ooooo`;o0000>Oooool2o`0009Wo
oooo0_l0000mooooo`;o0000:_ooool001kooooo00?o0000ooooooooool0oooooolLooooo`;o0000
:_ooool001kooooo00?o0000ooooooooool02_ooool2o`0004;ooooo0_l0000@ooooo`;o0000gooo
ool2o`0000Cooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0000booooo`;o00003_ooool2
o`000003ooooool0003o000000gooooo0_l0000Tooooo`;o0000?oooool2o`0005Cooooo0_l0000>
ooooo`;o00004_ooool2o`0000Cooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0000Koooo
o`;o00002?ooool2o`00017ooooo0_l0000cooooo`;o0000?Oooool4o`0005Cooooo0_l0000>oooo
o`;o00006?ooool001kooooo00?o0000ooooooooool05oooool2o`0001;ooooo0_l00007ooooo`;o
00008?ooool2o`0006gooooo0_l0000Sooooo`;o0000=?ooool2o`0002Gooooo0003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006oooo
o`03o`000?oooooooooo013ooooo0_l0000Iooooo`;o0000:Oooool2o`0001kooooo0_l0001;oooo
o`;o00009Oooool2o`0001Sooooo0_l0000Jooooo`;o00006Oooool2o`0000[ooooo0003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06
ooooo`03o`000?oooooooooo013ooooo0_l0001Tooooo`;o0000<_ooool2o`00013ooooo0_l00005
ooooo`;o0000?oooool2o`0003Gooooo0_l0000:ooooo`000oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000Z_ooool2o`00013ooooo0_l0
0002ooooo`;o0000QOooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0fooooo`;o00008_ooool2o`0003Kooooo
0_l0000/ooooo`;o0000QOooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`04ooooo`;o0000<?ooool2o`000003
ooooool0003o000001kooooo0ol0000fooooo`;o0000B?ooool2o`0005Oooooo0_l0000@ooooo`00
0oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003o
ooooooooo`04ooooo`;o0000<oooool2o`0001kooooo0_l00021ooooo`;o0000E?ooool2o`000003
ooooool0003o0000013ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo
410@oiRHV008ooooo`03o`000?oooooooooo03cooooo0_l00015ooooo`;o0000W_ooool2o`0000go
oooo0_l0000Cooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0
003o410@1_ooool00ol0003oooooooooo`0looooo`;o0000AOooool2o`0002oooooo0_l0000Eoooo
o`;o0000@Oooool2o`0001?ooooo0_l0000Aooooo`;o00003oooool001kooooo00?o0000oooooooo
ool0]?ooool2o`0001Gooooo0_l0000fooooo`;o00002Oooool2o`0002Kooooo0_l0000?ooooo`00
7_ooool00ol0003oooooooooo`1<ooooo`;o0000B_ooool2o`0006Wooooo0_l00003ooooo`;o0000
;?ooool2o`0000oooooo000Nooooo`03o`000?oooooooooo04cooooo0_l0001:ooooo`;o0000K_oo
ool2o`0003gooooo000Nooooo`03o`000?oooooooooo0?oooooo3?ooool2o`0003[ooooo000Noooo
o`03o`000?oooooooooo03;ooooo0_l0000Mooooo`;o0000^?ooool2o`0003[ooooo000Nooooo`03
o`000?oooooooooo00[ooooo0_l0000Vooooo`;o00007Oooool2o`0008Gooooo0_l0001:ooooo`;o
00008Oooool001kooooo00?o0000ooooooooool02_ooool2o`0000Wooooo0_l00031ooooo`;o0000
B_ooool2o`00027ooooo000Nooooo`03o`000?oooooooooo01Gooooo0_l0001Wooooo`;o00008Ooo
ool2o`0002Wooooo0_l0000Sooooo`;o0000E?ooool001kooooo00?o0000ooooooooool02Oooool2
o`0007?ooooo0_l0000Qooooo`;o0000:?ooool3o`0002?ooooo0_l0001Dooooo`007_ooool00ol0
003oooooooooo`09ooooo`;o0000;?ooool2o`0009;ooooo0_l0000[ooooo`;o0000>oooool2o`00
013ooooo000Nooooo`03o`000?oooooooooo03Oooooo0_l0001booooo`;o00008oooool2o`0002Ko
oooo0_l000000ooooooo0000o`00000<ooooo`;o0000:_ooool2o`00013ooooo000Nooooo`;o0000
8_ooool2o`0008Sooooo0_l00002ooooo`;o00007oooool2o`0000;ooooo0_l0000Uooooo`;o0000
3?ooool2o`0003;ooooo0_l00008ooooo`007_ooool00ol0003oooooooooo`0Qooooo`;o0000F?oo
ool2o`0001Sooooo0_l00006ooooo`;o00004?ooool2o`0002?ooooo0_l0000Vooooo`;o0000?ooo
ool2o`0000Sooooo000Nooooo`03o`000?oooooooooo02;ooooo0_l0001Gooooo`;o00006?ooool2
o`0000Kooooo0_l0001Mooooo`;o0000BOooool001kooooo00?o0000ooooooooool03oooool2o`00
017ooooo0_l0002eooooo`;o0000HOooool2o`0000Wooooo000Nooooo`03o`000?oooooooooo00oo
oooo0_l0000;ooooo`;o0000O_ooool2o`0003_ooooo0_l0000Tooooo`;o0000>oooool2o`0000Wo
oooo000Nooooo`03o`000?oooooooooo01cooooo0_l0001Booooo`;o0000:_ooool2o`00067ooooo
0_l00016ooooo`007_ooool00ol0003oooooooooo`0Nooooo`;o0000=?ooool2o`0001[ooooo0_l0
003Eooooo`007_ooool00ol0003oooooooooo`0Nooooo`;o0000=?ooool2o`0002?ooooo0_l0001o
ooooo`;o0000Boooool001kooooo00?o0000ooooooooool06_ooool2o`00043ooooo0_l00002oooo
o`;o00005oooool2o`0003gooooo0_l0000Looooo`;o000000?oooooo`000?l000007oooool2o`00
00[ooooo0_l0000`ooooo`;o00001?ooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo01[o
oooo0_l0000?ooooo`;o0000;oooool2o`0000;ooooo0_l0000Uooooo`;o0000;oooool2o`0001co
oooo0_l000000ooooooo0000o`00000[ooooo`;o0000<?ooool2o`0000Cooooo0_l00007ooooo`00
7_ooool00ol0003oooooooooo`0Hooooo`;o00004Oooool2o`0005[ooooo0_l00006ooooo`;o0000
2Oooool2o`0003Oooooo0_l0001booooo`007_ooool00ol0003oooooooooo`0Hooooo`;o0000<?oo
ool2o`0004?ooooo0_l00009ooooo`;o0000=oooool2o`00043ooooo0_l0000`ooooo`007_ooool3
o`0001Sooooo1?l0000^ooooo`;o00009_ooool2o`0009Kooooo0_l00009ooooo`;o0000<?ooool0
01kooooo0ol0000Jooooo`;o0000E_ooool2o`00027ooooo0_l0001cooooo`;o0000>oooool001ko
oooo00?o0000ooooooooool0M?ooool2o`0001oooooo0_l0000?ooooo`;o0000=oooool2o`0001Ko
oooo0_l0001>ooooo`007_ooool00ol0003oooooooooo`1dooooo`;o00001_ooool2o`0002Sooooo
0_l0000Tooooo`;o00004Oooool2o`0001Kooooo0_l0000]ooooo`;o00007oooool001kooooo0_l0
001mooooo`;o0000C_ooool2o`0003_ooooo0_l0000Kooooo`;o00007oooool001kooooo00?o0000
ooooooooool0Joooool2o`0001cooooo0_l0001nooooo`;o00006oooool2o`0001oooooo000Noooo
o`03o`000?oooooooooo02_ooooo0_l0000Aooooo`;o0000:oooool2o`0001cooooo0_l0002loooo
o`007_ooool00ol0003oooooooooo`0:ooooo`;o00007oooool2o`0000cooooo0_l00003ooooo`;o
00004?ooool2o`000=7ooooo0_l0000Rooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o0000
;Oooool2o`0001Gooooo0_l0001looooo`;o0000<Oooool2o`00023ooooo0_l0000Rooooo`007_oo
ool00ol0003oooooooooo`0Eooooo`;o00006?ooool2o`0007?ooooo0_l0000Eooooo`;o00004Ooo
ool2o`00037ooooo0_l0000Hooooo`;o0000:_ooool001kooooo00?o0000ooooooooool05Oooool2
o`0001Sooooo0_l0001Nooooo`;o00004oooool2o`0001Gooooo0_l0000]ooooo`;o0000;oooool2
o`0002[ooooo000Nooooo`03o`000?oooooooooo03kooooo0_l0001<ooooo`;o000000?oooooo`00
0?l000008_ooool2o`0003Gooooo0_l0001Kooooo`007_ooool00ol0003oooooooooo`0nooooo`;o
00008?ooool2o`0002[ooooo0_l000000ooooooo0000o`00000Oooooo`;o000000?oooooo`000?l0
0000H?ooool2o`0001kooooo0_l0000@ooooo`007_ooool00ol0003oooooooooo`1Kooooo`;o0000
0oooool2o`0002gooooo0_l0000Oooooo`;o00000oooool2o`000003ooooool0003o000005_ooooo
0_l0000Nooooo`;o00004?ooool001kooooo00?o0000ooooooooool02oooool2o`0004kooooo0_l0
001Hooooo`;o000000?oooooo`000?l00000SOooool001kooooo00?o0000ooooooooool02oooool2
o`000<7ooooo0_l00002ooooo`;o0000;Oooool2o`0002Kooooo0_l0000Looooo`007_ooool00ol0
003oooooooooo`3>ooooo`;o00000_ooool2o`0002gooooo0_l0000Vooooo`;o00007?ooool001ko
oooo00?o0000ooooooooool09Oooool2o`0000Wooooo0_l0001Dooooo`;o0000Ooooool2o`0003ko
oooo000Nooooo`03o`000?oooooooooo01kooooo0_l00005ooooo`;o00002Oooool2o`0002Sooooo
0_l0000Looooo`;o00003?ooool2o`0007[ooooo0_l00003ooooo`;o0000;Oooool2o`0000Kooooo
0_l00007ooooo`007_ooool00ol0003oooooooooo`0Nooooo`;o0000>_ooool2o`0001cooooo0_l0
000Vooooo`;o00005oooool2o`0003kooooo0_l00007ooooo`;o0000<_ooool2o`0000Kooooo0_l0
0007ooooo`007_ooool2o`0001oooooo0_l00020ooooo`;o00005oooool2o`0002_ooooo0_l0000A
ooooo`;o0000?Oooool2o`0000gooooo000Nooooo`03o`000?oooooooooo00cooooo0_l0000@oooo
o`;o0000a_ooool2o`00053ooooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o
0000HOooool2o`0002Sooooo0_l0000Nooooo`;o0000S?ooool001kooooo00?o0000ooooooooool0
>Oooool4o`0003;ooooo0_l0000Xooooo`;o00002_ooool2o`0001;ooooo0_l0000Oooooo`;o0000
00?oooooo`000?l00000J?ooool001kooooo00?o0000ooooooooool0>Oooool4o`0003?ooooo0_l0
000cooooo`;o000000?oooooo`000?l000003oooool2o`0001Wooooo0_l00004ooooo`;o000000?o
ooooo`000?l00000J?ooool001kooooo00Co0000ooooool0003o0000Koooool2o`0003Kooooo0_l0
000Zooooo`;o00009_ooool2o`0004Wooooo000Nooooo`04o`000?oooooo0000o`0007cooooo0_l0
001mooooo`;o0000BOooool001kooooo00?o0000ooooooooool0OOooool2o`000003ooooool0003o
000000Gooooo0_l00003ooooo`;o0000H?ooool2o`0001[ooooo0_l0000kooooo`007_ooool00ol0
003oooooooooo`20ooooo`;o00001Oooool2o`0000?ooooo0_l0001Pooooo`;o00006_ooool2o`00
03_ooooo000Nooooo`03o`000?oooooooooo037ooooo0_l0000Sooooo`;o0000K?ooool2o`00087o
oooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0000Uooooo`;o00008oooool2o`0002Wooooo
0_l0000Looooo`;o00008oooool2o`0003oooooo0_l00010ooooo`007_ooool00ol0003ooooooooo
o`0:ooooo`;o00002?ooool2o`0002;ooooo0_l00017ooooo`;o00003?ooool2o`0000kooooo0_l0
0005ooooo`?o0000A_ooool2o`0001Cooooo0_l00010ooooo`007_ooool00ol0003oooooooooo`0D
ooooo`;o00008_ooool2o`0005Gooooo0_l0000Eooooo`?o00004_ooool2o`0001Cooooo0_l0000L
ooooo`;o0000E_ooool001kooooo00?o0000ooooooooool06_ooool2o`0009oooooo0_l0000:oooo
o`;o00002?ooool2o`0007Cooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo01[ooooo0_l0002[
ooooo`;o0000H_ooool2o`0001[ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo07gooooo0ol0
0019ooooo`;o00000oooool2o`0005_ooooo0_l0000Jooooo`000oooool01Ol@413ooooooooooooo
oooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000B?ooool2o`0003?ooooo
0ol000000ooooooo0000o`00000@ooooo`;o00003oooool2o`0001kooooo0_l00003ooooo`;o0000
0oooool2o`0004cooooo0_l0000Yooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo
00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooooooo01?ooooo0_l0000cooooo`?o
0000=_ooool2o`00013ooooo0_l00003ooooo`;o00002_ooool2o`0001kooooo0_l0001Fooooo`;o
0000:Oooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`00
0?o<c<`01_ooool00ol0003oooooooooo`0Cooooo`;o00007?ooool2o`0000kooooo0_l00006oooo
o`;o0000COooool2o`0000kooooo0_l0001fooooo`;o00009Oooool000?ooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`0/
ooooo`;o00000oooool2o`0000kooooo0_l0001Uooooo`;o0000M_ooool2o`0001kooooo0_l00005
ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00
0006ooooo`03o`000?oooooooooo00Gooooo0_l0000Uooooo`;o0000;?ooool2o`0002Oooooo0_l0
0008ooooo`;o00002_ooool2o`00067ooooo0_l0000[ooooo`;o00005Oooool2o`0000Gooooo0003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo
00?o0000ooooooooool01Oooool2o`0003_ooooo0_l0000Fooooo`;o00009oooool2o`0000Sooooo
0_l0000:ooooo`;o0000HOooool2o`0002_ooooo0_l0000Looooo`007_ooool00ol0003ooooooooo
o`12ooooo`;o00005Oooool2o`0000;ooooo0_l0003Xooooo`007_ooool00ol0003oooooooooo`1I
ooooo`;o00000_ooool2o`0004cooooo0_l0001/ooooo`;o0000;?ooool001kooooo00?o0000oooo
ooooool0Zoooool2o`0002_ooooo0_l0000oooooo`;o0000;?ooool001gooooo0_l0000Hooooo`;o
0000Goooool2o`0005oooooo0_l00010ooooo`;o0000:oooool001gooooo0_l0000Hooooo`;o0000
Goooool2o`0008kooooo0_l0000;ooooo`;o00001?ooool2o`0002_ooooo000Nooooo`;o00007_oo
ool2o`000<Sooooo0_l0000Iooooo`;o00000oooool2o`0000Wooooo1?l0000@ooooo`;o00007ooo
ool001kooooo0_l0000Nooooo`;o0000H_ooool2o`0006Cooooo0_l0000Iooooo`;o00003_ooool2
o`0001;ooooo0_l0000Oooooo`007_ooool00ol0003oooooooooo`1cooooo`;o00003?ooool2o`00
08cooooo0_l0000Aooooo`;o00000_ooool2o`0001oooooo000Nooooo`03o`000?oooooooooo043o
oooo0_l0000aooooo`;o00009Oooool2o`0000gooooo0_l0000[ooooo`;o0000=oooool2o`00017o
oooo0_l0000Jooooo`;o00001oooool001kooooo00?o0000ooooooooool0@?ooool2o`0003kooooo
0_l0000Hooooo`;o00000_ooool2o`0000Wooooo0_l0000Nooooo`;o00002oooool2o`0003Oooooo
0_l0000@ooooo`;o00006oooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo033ooooo0_l0
001>ooooo`;o00007?ooool2o`0000?ooooo0_l0000Tooooo`;o00006Oooool2o`0001Gooooo0_l0
000Booooo`;o00004?ooool2o`0002Cooooo000Nooooo`;o0000<Oooool2o`0001oooooo0_l0001@
ooooo`;o00007_ooool2o`0001oooooo0_l0000>ooooo`;o00001Oooool2o`0000?ooooo0_l00006
ooooo`;o0000?Oooool001kooooo00Co0000ooooool0003o0000D?ooool2o`0006Sooooo0_l00006
ooooo`;o0000;oooool2o`0000[ooooo0_l00006ooooo`;o00000_ooool2o`000003ooooool0003o
000001cooooo0_l0000Hooooo`007_ooool01?l0003oooooo`000?l0001Cooooo`;o0000:Oooool2
o`0001Gooooo0_l0000Sooooo`;o0000Coooool2o`000003ooooool0003o000001Kooooo0_l00004
ooooo`;o00006?ooool001kooooo00?o0000ooooooooool0E?ooool2o`0000Sooooo0_l0000Ooooo
o`;o00005Oooool2o`0008oooooo0_l0000Dooooo`;o00002?ooool001kooooo00?o0000oooooooo
ool0=oooool2o`0000Sooooo0_l0000Iooooo`Co0000<oooool2o`0005Oooooo0_l0000Yooooo`;o
00009?ooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo03Oooooo0_l00008ooooo`;o0000
6Oooool2o`0003Gooooo0_l0001Gooooo`;o00008?ooool2o`0000Oooooo0_l0000^ooooo`007_oo
ool00ol0003oooooooooo`0Uooooo`;o0000`_ooool2o`0002?ooooo0_l0000gooooo`007_ooool0
1?l0003oooooo`000?l0000Tooooo`;o00000_ooool2o`0006cooooo0_l0001@ooooo`;o0000G?oo
ool001kooooo00Co0000ooooool0003o0000:?ooool2o`0005;ooooo0_l0000Hooooo`;o00004_oo
ool2o`0005Sooooo0_l0000?ooooo`;o0000;oooool001kooooo00?o0000ooooooooool0OOooool2
o`0002cooooo0_l0001Hooooo`;o00003oooool2o`0001Oooooo0_l0000Fooooo`007_ooool00ol0
003oooooooooo`0=ooooo`;o0000kOooool2o`00037ooooo0_l0000Fooooo`007_ooool00ol0003o
ooooooooo`0=ooooo`;o00004?ooool2o`0006;ooooo0_l0001gooooo`;o0000BOooool001kooooo
00?o0000ooooooooool07Oooool4o`0006;ooooo0_l00013ooooo`;o00007oooool2o`0005cooooo
000Nooooo`03o`000?oooooooooo01gooooo0_l00005ooooo`;o00003_ooool2o`0004kooooo0_l0
000[ooooo`;o00005Oooool2o`0001oooooo0_l0000;ooooo`;o0000Coooool001kooooo00?o0000
ooooooooool09?ooool2o`0000kooooo0_l0000Mooooo`;o0000;oooool2o`00027ooooo0_l00008
ooooo`;o00003oooool2o`0003;ooooo0_l0001?ooooo`007_ooool00ol0003oooooooooo`08oooo
o`;o00006?ooool2o`0002oooooo0_l0001Booooo`;o00006Oooool2o`0000oooooo0_l0000boooo
o`;o0000?_ooool001kooooo0_l00009ooooo`;o00001oooool2o`0000oooooo0_l0002Rooooo`;o
00000oooool2o`0000Gooooo0ol0000booooo`;o0000?_ooool001kooooo00?o0000ooooooooool0
4Oooool2o`000;?ooooo0_l00003ooooo`;o00001Oooool2o`0007?ooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool00_ooool2o`0002Cooooo0_l0002d
ooooo`;o00007Oooool3o`0004Oooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0000Toooo
o`;o00001Oooool2o`000:gooooo0_l00008ooooo`;o000000?oooooo`000?l000003_ooool5o`00
00Oooooo0_l0000nooooo`007_ooool00ol0003oooooooooo`0_ooooo`;o0000U_ooool2o`0000Oo
oooo0_l0000Fooooo`;o000000?oooooo`000?l000003_ooool2o`0000[ooooo0_l0000nooooo`00
7_ooool00ol0003oooooooooo`09ooooo`;o00000_ooool2o`0007Gooooo0_l0000/ooooo`;o0000
4?ooool2o`000003ooooool0003o000000Oooooo0_l00005ooooo`;o00004?ooool2o`0005cooooo
000Nooooo`?o00002Oooool2o`0000;ooooo0_l0001eooooo`;o0000;?ooool2o`00013ooooo0_l0
000Aooooo`;o00004?ooool2o`0003gooooo0_l00008ooooo`;o00000oooool2o`0000kooooo000N
ooooo`?o0000LOooool2o`0001Cooooo0_l0000cooooo`;o0000<Oooool2o`0000Wooooo0_l0000/
ooooo`;o00002?ooool2o`0000?ooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`1aoooo
o`;o00005?ooool2o`0003?ooooo0_l0000aooooo`;o00002Oooool2o`0000;ooooo0_l0000noooo
o`;o00001oooool001kooooo00?o0000ooooooooool0o_ooool2o`0003kooooo0_l00007ooooo`00
7_ooool00ol0003oooooooooo`3nooooo`;o0000Aoooool001kooooo00?o0000ooooooooool03?oo
ool2o`000?oooooo>_ooool001kooooo00?o0000ooooooooool01?ooool2o`0000Kooooo0_l0001>
ooooo`;o00001oooool2o`0009Sooooo0_l0000?ooooo`;o0000=Oooool001kooooo00?o0000oooo
ooooool01?ooool2o`0005Kooooo0_l00007ooooo`;o0000B_ooool2o`0001Kooooo0_l0000doooo
o`;o00003oooool2o`0002Oooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`2aooooo`;o
00005_ooool2o`0004Cooooo0_l0000Xooooo`;o00003?ooool001kooooo0_l0001`ooooo`;o0000
E?ooool2o`0004Sooooo0_l0000fooooo`007_ooool00ol0003oooooooooo`02o`0006gooooo0_l0
001Dooooo`;o0000;oooool2o`0004oooooo000Nooooo`03o`000?oooooooooo00;o00008oooool2
o`0003Sooooo0_l0000Rooooo`;o00004Oooool2o`0005kooooo0_l0000fooooo`;o00005oooool0
01kooooo00?o0000ooooooooool09Oooool2o`0003Sooooo0_l0000Booooo`;o00003_ooool2o`00
017ooooo0_l0001?ooooo`;o0000AOooool2o`0001Oooooo000Nooooo`03o`000?oooooooooo01;o
oooo0_l0001>ooooo`;o000000?oooooo`000?l000003?ooool2o`0002Cooooo0_l0001;ooooo`?o
00008_ooool2o`0000Gooooo0_l0000cooooo`007_ooool00ol0003oooooooooo`0Booooo`;o0000
C_ooool2o`000003ooooool0003o000003;ooooo0_l0001;ooooo`;o00008oooool2o`0000Gooooo
0_l0000cooooo`007_ooool00ol0003oooooooooo`0dooooo`;o00001oooool2o`000?oooooo2Ooo
ool001kooooo00?o0000ooooooooool0:oooool2o`0000Oooooo0_l00007ooooo`;o0000@Oooool2
o`0008Gooooo0_l0000nooooo`007_ooool00ol0003oooooooooo`0[ooooo`;o0000Doooool2o`00
01_ooooo0_l0000Qooooo`;o00003oooool2o`0003Cooooo0_l0000nooooo`007_ooool00ol0003o
ooooooooo`0Nooooo`;o0000DOooool2o`0002[ooooo0_l0000Qooooo`;o00003oooool2o`0002Oo
oooo0_l0000Booooo`;o00002?ooool2o`0002gooooo000Nooooo`03o`000?oooooooooo01kooooo
0_l0001Aooooo`;o0000:_ooool2o`0003oooooo0_l0000Jooooo`;o00004_ooool2o`0000Sooooo
0ol0000/ooooo`007_ooool00ol0003oooooooooo`3Nooooo`;o00006?ooool2o`0000gooooo0_l0
000@ooooo`;o0000;?ooool001kooooo00?o0000ooooooooool04Oooool2o`0008;ooooo0_l0001Q
ooooo`;o00003Oooool2o`0003kooooo000Nooooo`03o`000?oooooooooo017ooooo0_l0000doooo
o`;o0000C?ooool2o`000:Kooooo0_l00008ooooo`005?ooool4o`000003oa0@4?oooooooooo00?o
oooo00?o0000ooooooooool0Aoooool2o`0000Sooooo0_l0000^ooooo`;o0000Q?ooool2o`0000go
oooo0_l0000Uooooo`;o00002?ooool001Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`1Aooooo`;o0000;_ooool2o`0008Cooooo0_l00003ooooo`;o00002?ooool2o`0002oooooo
000Fooooo`03o`000?oooooooooo00Gooooo0ol0002Mooooo`;o00008_ooool2o`0003cooooo0_l0
000;ooooo`;o00007oooool2o`0000Wooooo0_l0000=ooooo`005_ooool00ol0003oooooooooo`2U
ooooo`;o00008_ooool2o`0003cooooo0_l0000/ooooo`;o00002Oooool2o`0000gooooo000Foooo
o`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`00
5_ooool00ol0003oooooooooo`3ooooooe3ooooo000Dooooo`03oeEEEOmVIVKo00000?ooooooD_oo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.57788 .14703 Mdot
.65032 .5291 Mdot
.02951 .5399 Mdot
.46134 .64568 Mdot
.60067 .83884 Mdot
.77262 .88893 Mdot
.65201 .75234 Mdot
.94045 .80925 Mdot
.40744 .25936 Mdot
.10846 .89316 Mdot
.30869 .35618 Mdot
.23011 .12966 Mdot
.91072 .38534 Mdot
.4001 .78183 Mdot
.70359 .66953 Mdot
.75528 .95703 Mdot
.92139 .01124 Mdot
.16237 .88623 Mdot
.45411 .08104 Mdot
.04127 .26157 Mdot
.86506 .99956 Mdot
.1134 .18557 Mdot
.3762 .46317 Mdot
.70431 .87776 Mdot
.64405 .25343 Mdot
.1233 .27861 Mdot
.12044 .76585 Mdot
.18493 .50056 Mdot
.01834 .57481 Mdot
.19875 .79176 Mdot
.74625 .67836 Mdot
.97895 .71463 Mdot
.06166 .49556 Mdot
.04537 .3457 Mdot
.50377 .85239 Mdot
.52101 .28919 Mdot
.67783 .78144 Mdot
.21732 .83135 Mdot
.73724 .82986 Mdot
.85396 .50959 Mdot
.5375 .43178 Mdot
.83265 .89931 Mdot
.61282 .9388 Mdot
.67401 .3588 Mdot
.37246 .25813 Mdot
.81249 .83685 Mdot
.04944 .22602 Mdot
.46933 .36391 Mdot
.19359 .62839 Mdot
.07326 .71255 Mdot
.27449 .61755 Mdot
.03812 .02693 Mdot
.91869 .00582 Mdot
.38834 .30888 Mdot
.12606 .25092 Mdot
.53359 .12703 Mdot
.57531 .16951 Mdot
.90229 .11259 Mdot
.70601 .12326 Mdot
.6109 .56902 Mdot
.69343 .67626 Mdot
.36073 .03317 Mdot
.23703 .23642 Mdot
.13953 .82972 Mdot
.50209 .04912 Mdot
.93058 .7039 Mdot
.19289 .61642 Mdot
.21605 .7503 Mdot
.43659 .62571 Mdot
.13655 .45959 Mdot
.55177 .32193 Mdot
.34537 .71254 Mdot
.03569 .82909 Mdot
.80266 .85973 Mdot
.61994 .775 Mdot
.48647 .85064 Mdot
.29954 .54202 Mdot
.73576 .96566 Mdot
.29018 .10675 Mdot
.69691 .39249 Mdot
.0317 .29707 Mdot
.38499 .11486 Mdot
.29817 .15643 Mdot
.86051 .22171 Mdot
.43929 .14696 Mdot
.87648 .54561 Mdot
.63843 .55561 Mdot
.20695 .51588 Mdot
.15622 .19193 Mdot
.65214 .36873 Mdot
.69059 .26226 Mdot
.77234 .79668 Mdot
.84244 .79057 Mdot
.57372 .86089 Mdot
.36562 .81218 Mdot
.53283 .81819 Mdot
.10547 .48478 Mdot
.47798 .45002 Mdot
.64564 .75146 Mdot
.08837 .75073 Mdot
.66666 .37786 Mdot
.61721 .20135 Mdot
.79571 .29288 Mdot
.66086 .22419 Mdot
.1363 .68942 Mdot
.27028 .54566 Mdot
.59145 .05886 Mdot
.91894 .55142 Mdot
.30535 .75319 Mdot
.26001 .27843 Mdot
.83907 .18333 Mdot
.34965 .70308 Mdot
.99321 .62373 Mdot
.55351 .32375 Mdot
.37451 .14911 Mdot
.71032 .91779 Mdot
.41979 .6382 Mdot
.61908 .55154 Mdot
.00911 .76384 Mdot
.88162 .82737 Mdot
.52515 .18466 Mdot
.44064 .36478 Mdot
.86527 .17962 Mdot
.2733 .84021 Mdot
.6922 .37507 Mdot
.53773 .69688 Mdot
.50029 .04797 Mdot
.00833 .59982 Mdot
.90255 .58925 Mdot
.2064 .22562 Mdot
.06976 .00943 Mdot
.5057 .22006 Mdot
.72909 .00445 Mdot
.88221 .67629 Mdot
.68135 .00264 Mdot
.7926 .01572 Mdot
.1674 .44545 Mdot
.07299 .13825 Mdot
.84668 .21428 Mdot
.24514 .71897 Mdot
.7659 .44686 Mdot
.86027 .31597 Mdot
.51593 .62087 Mdot
.53395 .27537 Mdot
.96787 .79913 Mdot
.4694 .42176 Mdot
.1053 .97654 Mdot
.85718 .58736 Mdot
.76135 .7142 Mdot
.60375 .26641 Mdot
.09612 .31421 Mdot
.5383 .7279 Mdot
.5099 .04715 Mdot
.4994 .22742 Mdot
.81205 .24536 Mdot
.14473 .13313 Mdot
.0231 .27022 Mdot
.49633 .89064 Mdot
.09516 .47682 Mdot
.81817 .11965 Mdot
.15257 .58363 Mdot
.03156 .03618 Mdot
.23846 .09258 Mdot
.67716 .12765 Mdot
.91338 .22198 Mdot
.99561 .08282 Mdot
.9203 .15744 Mdot
.03088 .76927 Mdot
.07813 .70681 Mdot
.7161 .05852 Mdot
.80306 .40684 Mdot
.07555 .1182 Mdot
.4714 .6449 Mdot
.86178 .90109 Mdot
.05225 .37217 Mdot
.00302 .95366 Mdot
.31966 .32722 Mdot
.82581 .69552 Mdot
.21951 .9919 Mdot
.61636 .74646 Mdot
.32006 .46582 Mdot
.07791 .86336 Mdot
.69755 .87619 Mdot
.18115 .56419 Mdot
.04594 .41117 Mdot
.50178 .84482 Mdot
.81246 .86394 Mdot
.31539 .70964 Mdot
.67272 .7155 Mdot
.30707 .19866 Mdot
.27355 .54154 Mdot
.51206 .27173 Mdot
.77531 .2564 Mdot
.25065 .58822 Mdot
.25803 .20315 Mdot
.24843 .83981 Mdot
.39596 .9709 Mdot
.92929 .17652 Mdot
.40227 .92903 Mdot
.7951 .28626 Mdot
.90749 .39431 Mdot
.3086 .27105 Mdot
.45304 .03276 Mdot
.97588 .17862 Mdot
.85796 .59579 Mdot
.54441 .77098 Mdot
.41788 .56839 Mdot
.47852 .74807 Mdot
.20831 .41977 Mdot
.36761 .75093 Mdot
.62499 .30929 Mdot
.75171 .64544 Mdot
.89942 .09358 Mdot
.6219 .55048 Mdot
.26642 .24584 Mdot
.46511 .55212 Mdot
.58968 .47082 Mdot
.09797 .96454 Mdot
.98794 .08274 Mdot
.44623 .03425 Mdot
.96726 .47955 Mdot
.89903 .10449 Mdot
.15989 .99096 Mdot
.32773 .64187 Mdot
.4401 .0749 Mdot
.52621 .91333 Mdot
.35302 .65116 Mdot
.23931 .54087 Mdot
.94199 .35678 Mdot
.95952 .39734 Mdot
.76989 .4565 Mdot
.69063 .54078 Mdot
.98423 .15583 Mdot
.61262 .25585 Mdot
.64589 .34516 Mdot
.4662 .79385 Mdot
.02794 .4509 Mdot
.75982 .70416 Mdot
.85527 .62253 Mdot
.70062 .3393 Mdot
.73646 .08329 Mdot
.56575 .76342 Mdot
.78766 .81053 Mdot
.05451 .40059 Mdot
.98447 .47051 Mdot
.2601 .32426 Mdot
.15724 .30451 Mdot
.97713 .70974 Mdot
.31084 .03412 Mdot
.39942 .83012 Mdot
.63352 .58911 Mdot
.87688 .30795 Mdot
.71722 .32369 Mdot
.4914 .72657 Mdot
.11052 .69933 Mdot
.61971 .14454 Mdot
.30799 .40845 Mdot
.17774 .6386 Mdot
.96713 .92478 Mdot
.02022 .11359 Mdot
.83954 .07137 Mdot
.80632 .1001 Mdot
.38473 .3035 Mdot
.75056 .61579 Mdot
.48643 .15693 Mdot
.43902 .06746 Mdot
.5543 .27769 Mdot
.63915 .10071 Mdot
.42752 .05043 Mdot
.63806 .63973 Mdot
.63472 .94514 Mdot
.43632 .34894 Mdot
.61453 .05263 Mdot
.80975 .42422 Mdot
.41193 .93149 Mdot
.88276 .63521 Mdot
.7434 .95529 Mdot
.62052 .38594 Mdot
.36969 .4924 Mdot
.16331 .10543 Mdot
.76753 .62579 Mdot
.34507 .64814 Mdot
.31083 .49645 Mdot
.08826 .47705 Mdot
.51725 .26367 Mdot
.45795 .23003 Mdot
.2871 .51171 Mdot
.39448 .41407 Mdot
.36682 .742 Mdot
.59371 .20681 Mdot
.8138 .42393 Mdot
.61149 .92261 Mdot
.86763 .62392 Mdot
.08302 .09691 Mdot
.73469 .30322 Mdot
.17545 .7971 Mdot
.03414 .86164 Mdot
.5416 .75086 Mdot
.5686 .16445 Mdot
.32566 .15246 Mdot
.38422 .24417 Mdot
.55325 .12358 Mdot
.39361 .99762 Mdot
.12396 .38059 Mdot
.34388 .55419 Mdot
.8579 .10608 Mdot
.78899 .42707 Mdot
.85957 .12761 Mdot
.93475 .38988 Mdot
.1416 .56219 Mdot
.1866 .40625 Mdot
.633 .22902 Mdot
.98117 .97976 Mdot
.89759 .92831 Mdot
.41332 .16375 Mdot
.95523 .72319 Mdot
.24725 .4289 Mdot
.28032 .79433 Mdot
.27575 .18023 Mdot
.59752 .48375 Mdot
.52097 .61183 Mdot
.28285 .10254 Mdot
.51503 .38421 Mdot
.82846 .69604 Mdot
.71206 .22225 Mdot
.74891 .94801 Mdot
.12129 .23962 Mdot
.60985 .04143 Mdot
.05461 .62913 Mdot
.14936 .42733 Mdot
.59821 .62915 Mdot
.73187 .76621 Mdot
.25675 .83914 Mdot
.27241 .83923 Mdot
.5626 .27562 Mdot
.62437 .96882 Mdot
.02675 .87475 Mdot
.05565 .20228 Mdot
.72903 .81749 Mdot
.26848 .98097 Mdot
.85305 .00251 Mdot
.93409 .73371 Mdot
.07627 .55263 Mdot
.38748 .15298 Mdot
.99274 .89384 Mdot
.93674 .13043 Mdot
.25226 .43662 Mdot
.49273 .34573 Mdot
.40272 .38399 Mdot
.25705 .32337 Mdot
.49463 .75217 Mdot
.16946 .16234 Mdot
.82213 .93013 Mdot
.05642 .24762 Mdot
.92832 .1908 Mdot
.84679 .27568 Mdot
.75313 .48156 Mdot
.73334 .32274 Mdot
.3214 .22449 Mdot
.42387 .79995 Mdot
.09701 .65994 Mdot
.98546 .65657 Mdot
.42369 .09141 Mdot
.99352 .31029 Mdot
.77986 .34237 Mdot
.75623 .88513 Mdot
.0283 .97232 Mdot
.08941 .42664 Mdot
.09778 .30994 Mdot
.53551 .28132 Mdot
.5977 .26312 Mdot
.29413 .66009 Mdot
.67879 .42086 Mdot
.13016 .18848 Mdot
.0803 .51075 Mdot
.32044 .69451 Mdot
.1159 .3468 Mdot
.38219 .99057 Mdot
.2641 .55481 Mdot
.47147 .38381 Mdot
.98541 .06533 Mdot
.75622 .91901 Mdot
.20969 .98191 Mdot
.6403 .4367 Mdot
.70766 .73867 Mdot
.32931 .43118 Mdot
.45166 .04532 Mdot
.82983 .92082 Mdot
.51735 .88082 Mdot
.63231 .75053 Mdot
.07144 .50454 Mdot
.98321 .5456 Mdot
.90407 .25799 Mdot
.40355 .44453 Mdot
.87494 .09689 Mdot
.58464 .82755 Mdot
.98933 .54112 Mdot
.43132 .57316 Mdot
.35503 .3149 Mdot
.42229 .8352 Mdot
.02149 .61392 Mdot
.96627 .90797 Mdot
.13222 .2888 Mdot
.80749 .17743 Mdot
.04867 .20873 Mdot
.2264 .91549 Mdot
.35435 .93294 Mdot
.82206 .91014 Mdot
.18681 .56955 Mdot
.56685 .51347 Mdot
.65071 .07397 Mdot
.96542 .8602 Mdot
.4494 .27952 Mdot
.17882 .13636 Mdot
.49913 .81017 Mdot
.55191 .77618 Mdot
.62894 .78155 Mdot
.1449 .04048 Mdot
.4589 .66862 Mdot
.50957 .95058 Mdot
.09014 .27725 Mdot
.12045 .61511 Mdot
.62141 .38128 Mdot
.97031 .57817 Mdot
.98855 .92281 Mdot
.60972 .62358 Mdot
.31736 .9332 Mdot
.23918 .02891 Mdot
.86395 .33084 Mdot
.26901 .17012 Mdot
.58594 .485 Mdot
.9432 .03594 Mdot
.31606 .38898 Mdot
.00649 .60367 Mdot
.87457 .8265 Mdot
.85198 .84691 Mdot
.70306 .08225 Mdot
.06399 .046 Mdot
.56926 .97031 Mdot
.0091 .19494 Mdot
.88343 .81985 Mdot
.91724 .20708 Mdot
.47494 .51089 Mdot
.79269 .99163 Mdot
.97961 .30101 Mdot
.97097 .57026 Mdot
.28438 .2964 Mdot
.29228 .54333 Mdot
.40261 .03101 Mdot
.04761 .31635 Mdot
.01009 .88253 Mdot
.21589 .94435 Mdot
.30926 .24365 Mdot
.12118 .9134 Mdot
.01461 .55231 Mdot
.14829 .74094 Mdot
.85447 .42727 Mdot
.00109 .35061 Mdot
.38977 .31085 Mdot
.88478 .98729 Mdot
.16531 .10258 Mdot
.01723 .84941 Mdot
.97222 .04109 Mdot
.98035 .72849 Mdot
.84456 .97612 Mdot
.6796 .63623 Mdot
.01312 .24294 Mdot
.35516 .71255 Mdot
.97765 .63908 Mdot
.17328 .54241 Mdot
.4082 .50362 Mdot
.10644 .37498 Mdot
.42041 .58435 Mdot
.26607 .70338 Mdot
.26685 .36777 Mdot
.46939 .80109 Mdot
.59967 .56961 Mdot
.60775 .98643 Mdot
.76911 .14301 Mdot
.43592 .09533 Mdot
.60883 .32534 Mdot
.08021 .73273 Mdot
.38381 .00249 Mdot
.79601 .53955 Mdot
.78066 .59548 Mdot
.70944 .01478 Mdot
.69285 .04789 Mdot
.42285 .03433 Mdot
.2703 .65683 Mdot
.63522 .8659 Mdot
.68167 .33358 Mdot
.01669 .95036 Mdot
.89047 .83094 Mdot
.1153 .03821 Mdot
.69153 .00675 Mdot
.14412 .67546 Mdot
.72958 .58835 Mdot
.25788 .84311 Mdot
.85996 .35973 Mdot
.01513 .62819 Mdot
.76803 .88324 Mdot
.56047 .58537 Mdot
.26572 .72565 Mdot
.36525 .81361 Mdot
.55702 .72175 Mdot
.42713 .95763 Mdot
.6857 .89414 Mdot
.4621 .10049 Mdot
.1344 .48383 Mdot
.02906 .43739 Mdot
.4568 .30425 Mdot
.82889 .98967 Mdot
.50945 .24101 Mdot
.45064 .22499 Mdot
.42128 .69219 Mdot
.90934 .22897 Mdot
.04618 .7959 Mdot
.30212 .45454 Mdot
.18059 .71731 Mdot
.02063 .17294 Mdot
.86562 .05085 Mdot
.17542 .55489 Mdot
.59115 .92863 Mdot
.16274 .74693 Mdot
.89886 .86914 Mdot
.89374 .70655 Mdot
.65916 .35156 Mdot
.80759 .65181 Mdot
.79108 .37793 Mdot
.32489 .01624 Mdot
.79311 .84352 Mdot
.48385 .02312 Mdot
.74552 .61161 Mdot
.4867 .2864 Mdot
.33856 .86027 Mdot
.14207 .35973 Mdot
.61595 .17209 Mdot
.42752 .47422 Mdot
.77599 .64341 Mdot
.44501 .00497 Mdot
.16282 .08235 Mdot
.93688 .80934 Mdot
.55315 .4191 Mdot
.63914 .96471 Mdot
.62679 .63274 Mdot
.96933 .86001 Mdot
.11035 .95257 Mdot
.01053 .68162 Mdot
.67802 .96319 Mdot
.40195 .02365 Mdot
.71995 .13892 Mdot
.13475 .83959 Mdot
.37691 .87998 Mdot
.01502 .85137 Mdot
.00422 .63877 Mdot
.55907 .7072 Mdot
.19506 .82655 Mdot
.40875 .02561 Mdot
.90185 .05438 Mdot
.57716 .52309 Mdot
.40666 .27339 Mdot
.99829 .31951 Mdot
.50693 .31214 Mdot
.04166 .29998 Mdot
.31127 .61202 Mdot
.84229 .26995 Mdot
.12839 .15734 Mdot
.10449 .3869 Mdot
.1147 .14847 Mdot
.51571 .54196 Mdot
.02998 .91653 Mdot
.11822 .19599 Mdot
.44531 .8241 Mdot
.93794 .05682 Mdot
.75949 .32822 Mdot
.08371 .57435 Mdot
.62883 .89664 Mdot
.05643 .12474 Mdot
.67865 .92173 Mdot
.77632 .55643 Mdot
.38237 .59254 Mdot
.44133 .83368 Mdot
.52936 .49618 Mdot
.13936 .81473 Mdot
.90109 .85515 Mdot
.38151 .94008 Mdot
.96857 .34324 Mdot
.47736 .18541 Mdot
.1579 .62635 Mdot
.23788 .24274 Mdot
.66148 .53049 Mdot
.28232 .50488 Mdot
.09843 .11903 Mdot
.02626 .49342 Mdot
.74639 .43895 Mdot
.70424 .85998 Mdot
.66303 .40556 Mdot
.50678 .09817 Mdot
.51902 .2419 Mdot
.20709 .73069 Mdot
.53771 .43197 Mdot
.79116 .30966 Mdot
.6983 .72863 Mdot
.686 .62628 Mdot
.42171 .78909 Mdot
.48314 .94942 Mdot
.84792 .52641 Mdot
.59797 .27057 Mdot
.00135 .94183 Mdot
.27007 .35332 Mdot
.30943 .87848 Mdot
.88448 .43953 Mdot
.94887 .26172 Mdot
.91382 .30641 Mdot
.06961 .36044 Mdot
.40478 .50369 Mdot
.83205 .39056 Mdot
.74364 .37195 Mdot
.16001 .04538 Mdot
.32539 .2826 Mdot
.33654 .28245 Mdot
.87274 .11027 Mdot
.85155 .58399 Mdot
.17372 .48938 Mdot
.08083 .13982 Mdot
.07919 .35982 Mdot
.83292 .60485 Mdot
.85361 .03704 Mdot
.82202 .02814 Mdot
.93023 .48226 Mdot
.83874 .16509 Mdot
.78063 .37802 Mdot
.68141 .70719 Mdot
.72612 .44945 Mdot
.652 .29943 Mdot
.37759 .78324 Mdot
.39067 .33944 Mdot
.47641 .6007 Mdot
.73588 .5587 Mdot
.80452 .74875 Mdot
.73606 .34735 Mdot
.69437 .08011 Mdot
.07686 .00407 Mdot
.09022 .88266 Mdot
.57572 .4775 Mdot
.54338 .61125 Mdot
.74309 .99645 Mdot
.9894 .64985 Mdot
.1752 .83677 Mdot
.69213 .2262 Mdot
.61535 .45526 Mdot
.70777 .29957 Mdot
.69896 .28518 Mdot
.19079 .04197 Mdot
.80083 .10219 Mdot
.92207 .3344 Mdot
.40739 .80727 Mdot
.19545 .54354 Mdot
.48129 .63051 Mdot
.3913 .07802 Mdot
.12662 .97286 Mdot
.87529 .02982 Mdot
.69084 .69577 Mdot
.99087 .5491 Mdot
.81179 .58713 Mdot
.97754 .6895 Mdot
.8321 .66432 Mdot
.87572 .16884 Mdot
.60681 .67865 Mdot
.85849 .80916 Mdot
.94618 .22714 Mdot
.29191 .90803 Mdot
.63767 .07675 Mdot
.59248 .69956 Mdot
.12739 .56233 Mdot
.42489 .32827 Mdot
.49492 .15569 Mdot
.62803 .82294 Mdot
.48123 .31154 Mdot
.57343 .46679 Mdot
.05659 .45441 Mdot
.89493 .84632 Mdot
.28966 .4074 Mdot
.42692 .11472 Mdot
.47257 .50891 Mdot
.01162 .23765 Mdot
.52869 .76773 Mdot
.41035 .72928 Mdot
.85157 .79239 Mdot
.96171 .08613 Mdot
.55268 .29752 Mdot
.20887 .79917 Mdot
.31727 .65943 Mdot
.49249 .1357 Mdot
.84872 .07168 Mdot
.88463 .19897 Mdot
.55609 .74474 Mdot
.69201 .14312 Mdot
.8472 .1576 Mdot
.10049 .23738 Mdot
.17267 .18563 Mdot
.32386 .96909 Mdot
.80229 .06985 Mdot
.93463 .98879 Mdot
.30313 .2285 Mdot
.62458 .03229 Mdot
.27842 .97486 Mdot
.91831 .01235 Mdot
.89908 .05164 Mdot
.04492 .68782 Mdot
.87104 .07408 Mdot
.7649 .63559 Mdot
.87997 .70842 Mdot
.62394 .84626 Mdot
.26275 .81686 Mdot
.86842 .67823 Mdot
.77731 .77115 Mdot
.06245 .82 Mdot
.68088 .61524 Mdot
.32763 .99085 Mdot
.60026 .74494 Mdot
.46019 .12257 Mdot
.54696 .85141 Mdot
.51334 .30945 Mdot
.48802 .96364 Mdot
.70936 .28503 Mdot
.04547 .32719 Mdot
.02147 .79102 Mdot
.09004 .37901 Mdot
.77487 .79177 Mdot
.59012 .94854 Mdot
.6337 .97926 Mdot
.16552 .02578 Mdot
.99315 .03969 Mdot
.79763 .35176 Mdot
.66454 .90784 Mdot
.13492 .57 Mdot
.77257 .44009 Mdot
.9075 .06054 Mdot
.57271 .82893 Mdot
.63643 .50378 Mdot
.61464 .85695 Mdot
.22666 .73517 Mdot
.15906 .69575 Mdot
.88207 .53542 Mdot
.98295 .83923 Mdot
.26051 .35954 Mdot
.50319 .75296 Mdot
.94413 .97064 Mdot
.54972 .13024 Mdot
.22009 .72557 Mdot
.15698 .1224 Mdot
.40647 .04567 Mdot
.36438 .44709 Mdot
.35517 .12977 Mdot
.02585 .57041 Mdot
.29296 .41549 Mdot
.21865 .54876 Mdot
.21106 .23654 Mdot
.89744 .98023 Mdot
.08659 .44625 Mdot
.16822 .66742 Mdot
.04634 .54005 Mdot
.19305 .36559 Mdot
.82084 .67653 Mdot
.64729 .09782 Mdot
.28502 .36502 Mdot
.44335 .7107 Mdot
.16962 .13267 Mdot
.40503 .97829 Mdot
.7788 .71698 Mdot
.6861 .17643 Mdot
.87426 .44628 Mdot
.69546 .32678 Mdot
.65003 .73137 Mdot
.32707 .143 Mdot
.00646 .23276 Mdot
.85759 .86747 Mdot
.90262 .69068 Mdot
.23733 .97649 Mdot
.54955 .73895 Mdot
.00912 .8196 Mdot
.94962 .84688 Mdot
.50908 .82171 Mdot
.89789 .21386 Mdot
.99234 .30953 Mdot
.06814 .31037 Mdot
.48616 .34929 Mdot
.88033 .25359 Mdot
.44705 .6643 Mdot
.15573 .74664 Mdot
.3922 .50939 Mdot
.42881 .83265 Mdot
.19976 .51122 Mdot
.65624 .16723 Mdot
.87292 .87505 Mdot
.58071 .77499 Mdot
.06397 .3773 Mdot
.69178 .28092 Mdot
.39639 .20844 Mdot
.63349 .2042 Mdot
.1288 .72518 Mdot
.29443 .63378 Mdot
.55515 .03537 Mdot
.68742 .62389 Mdot
.53441 .70642 Mdot
.85329 .27336 Mdot
.84287 .0124 Mdot
.0925 .68115 Mdot
.59888 .45387 Mdot
.58155 .22068 Mdot
.02663 .42447 Mdot
.12541 .19853 Mdot
.07544 .88008 Mdot
.65114 .37961 Mdot
.3443 .6653 Mdot
.14004 .93897 Mdot
.98798 .13885 Mdot
.11274 .48032 Mdot
.32596 .30596 Mdot
.83775 .97842 Mdot
.54554 .67198 Mdot
.44184 .93723 Mdot
.34374 .06645 Mdot
.1319 .9208 Mdot
.08268 .00875 Mdot
.65956 .35941 Mdot
.92176 .52181 Mdot
.33587 .24329 Mdot
.75404 .20112 Mdot
.40345 .57909 Mdot
.60917 .07687 Mdot
.38414 .42108 Mdot
.88435 .58728 Mdot
.12619 .66666 Mdot
.72008 .33919 Mdot
.81694 .9261 Mdot
.45597 .15433 Mdot
.3352 .74279 Mdot
.7144 .81379 Mdot
.81835 .32018 Mdot
.77858 .42744 Mdot
.597 .92138 Mdot
.35009 .52889 Mdot
.02932 .31636 Mdot
.28958 .12401 Mdot
.08588 .47109 Mdot
.74662 .60189 Mdot
.44783 .72604 Mdot
.47171 .26755 Mdot
.29492 .80115 Mdot
.93822 .63612 Mdot
.65154 .29743 Mdot
.97515 .02964 Mdot
.2359 .55606 Mdot
.80708 .31683 Mdot
.02808 .42018 Mdot
.69939 .37481 Mdot
.76023 .7715 Mdot
.77119 .95652 Mdot
.49347 .22423 Mdot
.47883 .50731 Mdot
.02411 .60275 Mdot
.72345 .05076 Mdot
.5504 .12297 Mdot
.56459 .2021 Mdot
.49278 .38484 Mdot
.93453 .70703 Mdot
.28959 .14563 Mdot
.41521 .50782 Mdot
.3471 .19384 Mdot
.46357 .73397 Mdot
.03085 .7904 Mdot
.16069 .04738 Mdot
.83226 .36463 Mdot
.26146 .81375 Mdot
.46272 .06218 Mdot
.51552 .79174 Mdot
.14904 .49597 Mdot
.76192 .90597 Mdot
.67885 .53274 Mdot
.16256 .57545 Mdot
.15339 .51788 Mdot
.87868 .02285 Mdot
.29952 .54404 Mdot
.89451 .8004 Mdot
.28932 .36029 Mdot
.45824 .80626 Mdot
.64583 .4737 Mdot
.12027 .19475 Mdot
.67927 .80072 Mdot
.18028 .11129 Mdot
.82018 .08482 Mdot
.19595 .71233 Mdot
.84622 .75051 Mdot
.1366 .86857 Mdot
.36778 .02261 Mdot
.42352 .89062 Mdot
.25542 .48229 Mdot
.78277 .90527 Mdot
.78877 .18529 Mdot
.84364 .89346 Mdot
.93147 .56751 Mdot
.48059 .59764 Mdot
.28876 .30265 Mdot
.4671 .70696 Mdot
.62197 .73476 Mdot
.14688 .01758 Mdot
.07269 .89236 Mdot
.90686 .94342 Mdot
.63887 .58731 Mdot
.94488 .2185 Mdot
.03288 .22005 Mdot
.28078 .51181 Mdot
.92047 .83674 Mdot
.61893 .09229 Mdot
.81206 .35154 Mdot
.3327 .20821 Mdot
.37072 .43812 Mdot
.00466 .37042 Mdot
.47735 .73 Mdot
.2776 .24745 Mdot
.65463 .31747 Mdot
.51662 .84622 Mdot
.80126 .91798 Mdot
.05421 .51401 Mdot
.05794 .90462 Mdot
.61414 .60272 Mdot
.42685 .72803 Mdot
.10154 .21527 Mdot
.87283 .11041 Mdot
.27544 .02486 Mdot
.57879 .19879 Mdot
.81947 .95372 Mdot
.74417 .05864 Mdot
.48774 .92909 Mdot
.11921 .32176 Mdot
.25188 .5922 Mdot
.87948 .23919 Mdot
.81808 .81294 Mdot
.63103 .6913 Mdot
.53448 .41685 Mdot
.57612 .39994 Mdot
.43729 .57367 Mdot
.81894 .37876 Mdot
.43848 .43817 Mdot
.89384 .14084 Mdot
.13351 .32891 Mdot
.95115 .00054 Mdot
.701 .91827 Mdot
.89157 .93965 Mdot
.05895 .92297 Mdot
.44341 .42817 Mdot
.70633 .32467 Mdot
.68698 .84848 Mdot
.08582 .93016 Mdot
.68733 .64483 Mdot
.82594 .30979 Mdot
.61366 .32088 Mdot
.51601 .16114 Mdot
.47829 .50283 Mdot
.63515 .0653 Mdot
.40411 .74665 Mdot
.75091 .32259 Mdot
.13929 .13883 Mdot
.22539 .17995 Mdot
.63417 .47055 Mdot
.96197 .42678 Mdot
.12511 .64901 Mdot
.3138 .93785 Mdot
.33209 .50668 Mdot
.6184 .95566 Mdot
.67286 .82337 Mdot
.80136 .71122 Mdot
.44927 .25682 Mdot
.22679 .20358 Mdot
.12606 .29884 Mdot
.17786 .2059 Mdot
.31458 .64756 Mdot
.03901 .59398 Mdot
.36881 .81801 Mdot
.90541 .84079 Mdot
.21464 .49034 Mdot
.11171 .06558 Mdot
.35903 .48664 Mdot
.4903 .1765 Mdot
.0929 .40995 Mdot
.08096 .79377 Mdot
.78397 .29209 Mdot
.07988 .76883 Mdot
.28913 .46829 Mdot
.8622 .99188 Mdot
.74428 .47013 Mdot
.77538 .33176 Mdot
.71078 .8011 Mdot
.48283 .4486 Mdot
.52953 .12957 Mdot
.17163 .09542 Mdot
.61936 .89731 Mdot
.26823 .12094 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo0_l00004ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`06ooooo`;o00001Oooool00ol0003o
ooooooooo`06ooooo`;o00001Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo0_l0000>ooooo`03o`000?oooooooooo00gooooo0_l0000?ooooo`03o`000?oooooooooo00;o
oooo000Nooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool2o`0000Kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo
0_l00004ooooo`03o`000?oooooooooo00_ooooo0ol0000?ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Kooooo
0_l00002ooooo`;o000000?oooooo`000?ooool01oooool2o`0000Gooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0=ooooo`;o00003_ooool00ol0003oooooooooo`03ooooo`;o0000
2?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo000Nooooo`03o`000?oo
oooooooo01?ooooo0_l00002ooooo`;o0000M?ooool2o`0004kooooo0_l00018ooooo`;o00007_oo
ool001kooooo00?o0000ooooooooool04oooool2o`0000;ooooo0_l0003eooooo`;o00005_ooool3
o`0001kooooo000Nooooo`03o`000?oooooooooo06Kooooo0_l0001kooooo`;o00006Oooool2o`00
00kooooo0_l0000Fooooo`?o00007_ooool001kooooo00?o0000ooooooooool0;?ooool2o`0003So
oooo0_l0001kooooo`;o00006Oooool2o`0004Oooooo000Nooooo`03o`000?oooooooooo02cooooo
0_l00015ooooo`;o0000YOooool2o`0002_ooooo000Nooooo`03o`000?oooooooooo03;ooooo0_l0
000Qooooo`;o00007?ooool2o`0000[ooooo1?l0000Fooooo`;o0000Ooooool2o`0002_ooooo000N
ooooo`03o`000?oooooooooo00Sooooo0_l0000Xooooo`;o00005_ooool2o`0000Wooooo0_l0000X
ooooo`Co00005_ooool2o`0006cooooo0_l0000nooooo`007_ooool00ol0003oooooooooo`08oooo
o`;o0000@?ooool2o`0003?ooooo0_l00026ooooo`;o00003oooool2o`0001oooooo0_l0000<oooo
o`007_ooool00ol0003oooooooooo`1Qooooo`;o00003_ooool2o`0000cooooo0_l00004ooooo`;o
00001_ooool4o`0003Kooooo0_l0001?ooooo`;o00007oooool2o`0000cooooo000Nooooo`03o`00
0?oooooooooo00Kooooo0_l0000Iooooo`;o0000?_ooool2o`0000kooooo0_l0000Booooo`;o0000
1_ooool4o`0001oooooo0_l0000Eooooo`;o0000B?ooool2o`0001cooooo0_l0000Fooooo`007_oo
ool00ol0003oooooooooo`06ooooo`;o00006Oooool2o`0000Sooooo0_l00023ooooo`;o0000Gooo
ool2o`0001cooooo0_l00007ooooo`;o00001Oooool2o`0000Kooooo000Nooooo`03o`000?oooooo
oooo02_ooooo0_l0000=ooooo`;o0000Q_ooool2o`0007Cooooo0_l00005ooooo`;o00001_ooool0
01kooooo00?o0000ooooooooool04Oooool2o`0001gooooo0_l00008ooooo`;o0000A?ooool2o`00
00gooooo0_l0000Aooooo`;o00007_ooool2o`0008?ooooo000Nooooo`03o`000?oooooooooo017o
oooo0_l0000Mooooo`;o0000C_ooool2o`0000Gooooo0_l00006ooooo`;o00003_ooool2o`000003
ooooool0003o000003Wooooo0_l0001Xooooo`007_ooool2o`0008Sooooo0_l0000Fooooo`;o0000
8oooool2o`0001Oooooo0_l00008ooooo`;o0000;?ooool2o`0000Wooooo0_l0000Uooooo`007_oo
ool00ol0003oooooooooo`34ooooo`;o00008Oooool2o`0002cooooo0_l00009ooooo`?o00009?oo
ool001kooooo00?o0000ooooooooool0_?ooool2o`0002Oooooo0_l00007ooooo`;o0000<Oooool2
o`0000[ooooo0_l0000Hooooo`007_ooool00ol0003oooooooooo`2Booooo`;o0000:?ooool2o`00
02Oooooo0_l00007ooooo`;o0000<oooool2o`0000Sooooo0_l0000Hooooo`007_ooool00ol0003o
ooooooooo`0Pooooo`;o0000L?ooool2o`0003Kooooo0_l0001Gooooo`;o00005oooool2o`0000Wo
oooo000Nooooo`03o`000?oooooooooo023ooooo0_l0001:ooooo`;o00007Oooool2o`0003gooooo
0_l0001`ooooo`;o00002Oooool001kooooo00?o0000ooooooooool0K?ooool2o`0001gooooo0_l0
001dooooo`;o00002_ooool2o`000003ooooool0003o000003Gooooo000Nooooo`03o`000?oooooo
oooo08_ooooo0_l00012ooooo`;o0000<?ooool2o`0000[ooooo0_l000000ooooooo0000o`000005
ooooo`;o0000;_ooool001kooooo00?o0000ooooooooool0Noooool2o`0000kooooo0_l0000eoooo
o`;o00001oooool2o`0000;ooooo0_l00016ooooo`;o0000;_ooool001kooooo00?o0000oooooooo
ool0Noooool2o`0001?ooooo0_l0000`ooooo`;o00001oooool2o`00017ooooo0_l0001Wooooo`00
7_ooool00ol0003oooooooooo`0aooooo`;o0000GOooool2o`0004cooooo1?l00009ooooo`;o0000
D?ooool2o`000003ooooool0003o000000Gooooo000Nooooo`03o`000?oooooooooo037ooooo0_l0
002]ooooo`;o00002Oooool2o`0001[ooooo0_l0000/ooooo`;o00001_ooool2o`000003ooooool0
003o000000Gooooo000Nooooo`03o`000?oooooooooo0?oooooo2?ooool2o`0002cooooo0_l0000@
ooooo`007_ooool00ol0003oooooooooo`19ooooo`;o0000>oooool2o`0003gooooo0_l0001Ioooo
o`;o00009Oooool001kooooo00?o0000ooooooooool0=?ooool2o`0001?ooooo0_l0000kooooo`;o
00000_ooool2o`0003Wooooo0_l0001Iooooo`;o00009Oooool001kooooo00?o0000ooooooooool0
5oooool2o`0001_ooooo0_l0001Dooooo`;o00005Oooool2o`0002_ooooo0_l00018ooooo`;o0000
;Oooool001kooooo0_l0000Hooooo`;o00006Oooool2o`0002Cooooo0_l0000hooooo`;o00003Ooo
ool2o`0002Wooooo1?l0000`ooooo`Co00005?ooool2o`0002gooooo000Nooooo`03o`000?oooooo
oooo037ooooo0ol0000Tooooo`;o0000>?ooool2o`0003Sooooo0_l0000booooo`Co00007?ooool2
o`0002Gooooo000Nooooo`03o`000?oooooooooo037ooooo0_l0000Wooooo`;o0000]oooool2o`00
00_ooooo0_l0000Uooooo`007_ooool00ol0003oooooooooo`0fooooo`;o00008_ooool2o`000;Oo
oooo0_l00003ooooo`;o0000;Oooool001kooooo00?o0000ooooooooool00_ooool2o`0003;ooooo
0_l00011ooooo`;o00003?ooool2o`0008oooooo0_l00007ooooo`;o00009?ooool001kooooo00?o
0000ooooooooool00_ooool2o`00013ooooo0_l0001Sooooo`;o00003?ooool2o`0009Sooooo0_l0
000Tooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o00001_ooool2o`0003Gooooo0_l0002a
ooooo`;o0000?oooool001kooooo00?o0000ooooooooool07?ooool2o`00017ooooo0_l0000Roooo
o`;o00001Oooool2o`0003Gooooo0_l0000Looooo`?o0000;oooool2o`0002?ooooo0_l0000ooooo
o`007_ooool00ol0003oooooooooo`0>ooooo`;o00007oooool2o`0002Wooooo0_l0000eooooo`;o
00005_ooool2o`0000Cooooo0ol0000_ooooo`;o0000I?ooool001kooooo00?o0000ooooooooool0
3_ooool2o`0003Oooooo0_l0000Vooooo`;o0000=oooool3o`0000Cooooo0_l0000Wooooo`;o0000
>Oooool2o`0001Oooooo0_l0000Iooooo`007_ooool00ol0003oooooooooo`0[ooooo`;o00001_oo
ool2o`0001;ooooo0_l0000Vooooo`;o0000=oooool2o`0000Gooooo0_l0000Wooooo`;o0000>Ooo
ool2o`0001Oooooo0_l0000Iooooo`007_ooool00ol0003oooooooooo`0[ooooo`;o00001_ooool2
o`000003ooooool0003o000006Cooooo0_l0002Yooooo`007_ooool00ol0003oooooooooo`0Doooo
o`Co00004Oooool2o`0000_ooooo0_l0001Tooooo`;o0000B?ooool2o`0005Gooooo0_l00008oooo
o`007_ooool00ol0003oooooooooo`0Dooooo`Co00004Oooool2o`000;_ooooo0_l0000fooooo`;o
00007Oooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo05[ooooo0_l0000:ooooo`;o0000
GOooool2o`0001Kooooo0_l0000Gooooo`;o00009_ooool2o`0002Oooooo000Nooooo`03o`000?oo
oooooooo027ooooo0_l0000gooooo`;o00002_ooool2o`0002?ooooo0_l0000[ooooo`;o00002ooo
ool2o`0001Kooooo0_l0000Gooooo`;o0000Coooool001kooooo0_l0000Rooooo`;o0000Doooool2
o`0001?ooooo0_l0000[ooooo`;o0000SOooool001kooooo00?o0000ooooooooool0I_ooool2o`00
00kooooo0_l00002ooooo`;o00005?ooool2o`000;Gooooo000Nooooo`03o`000?oooooooooo02Ko
oooo0_l0000eooooo`;o00001oooool2o`0001;ooooo0_l0000Dooooo`;o00002?ooool2o`000003
ooooool0003o0000073ooooo0_l0000Fooooo`;o00004oooool2o`0000Wooooo000Nooooo`03o`00
0?oooooooooo02Kooooo0_l0000eooooo`;o0000>oooool2o`000003ooooool0003o000000Gooooo
0_l0001Yooooo`;o00005_ooool2o`0001?ooooo0_l00009ooooo`007_ooool00ol0003ooooooooo
o`0cooooo`;o0000COooool2o`00023ooooo0_l0000?ooooo`;o0000T?ooool001kooooo00?o0000
ooooooooool0<oooool2o`0004gooooo0_l0000aooooo`;o00006_ooool2o`0003[ooooo0_l0000h
ooooo`007_ooool00ol0003oooooooooo`1Cooooo`;o0000H_ooool2o`0001Sooooo0_l0000joooo
o`;o00002_ooool2o`0002cooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0001>ooooo`;o
0000H_ooool2o`0000_ooooo0_l0001Cooooo`;o0000;?ooool001kooooo00?o0000ooooooooool0
0oooool2o`0009Kooooo0_l0000Wooooo`;o00005Oooool2o`0004gooooo0_l0000Kooooo`007_oo
ool00ol0003oooooooooo`2Kooooo`;o0000?_ooool2o`0002Gooooo0_l0000Aooooo`;o00004ooo
ool2o`0000gooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`15ooooo`;o00003oooool2
o`000:[ooooo0_l0000Aooooo`;o00008_ooool2o`0000cooooo000Nooooo`03o`000?oooooooooo
027ooooo0_l0000Aooooo`;o00003oooool2o`0000oooooo0_l0000oooooo`;o00003_ooool2o`00
05?ooooo0_l0000?ooooo`;o0000>?ooool001kooooo00?o0000ooooooooool08Oooool2o`0000?o
oooo0_l0000<ooooo`;o0000HOooool2o`0000kooooo0_l0001Cooooo`;o00003oooool2o`0003So
oooo000Nooooo`03o`000?oooooooooo02Kooooo0_l00007ooooo`;o0000nOooool2o`0001_ooooo
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`04o`00
0?oooooo0000o`0002;ooooo0_l0000:ooooo`;o0000??ooool2o`000;_ooooo0_l0000Kooooo`00
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@01_ooool01?l0003oooooo`000?l0000Qooooo`?o0000B?ooool2o`000=Sooooo0003oooo
o`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`?o00008_ooool2
o`000003ooooool0003o000003Wooooo0_l0001Fooooo`;o00002oooool2o`0002[ooooo0_l0000X
ooooo`;o0000:_ooool000?ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^00Kooooo00?o0000ooooooooool03_ooool2o`0001Gooooo0_l0000Oooooo`;o00002?ooool2
o`0000kooooo0_l0001Aooooo`;o00000oooool2o`0000_ooooo0_l00003ooooo`;o00009Oooool2
o`0002Sooooo0_l0000Zooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMg
ofIVI_ooool01Oooool00ol0003oooooooooo`0>ooooo`;o00009_ooool2o`0000kooooo0_l00008
ooooo`;o0000HOooool2o`0000Sooooo0_l0000;ooooo`;o0000F_ooool2o`0001oooooo0003oooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00cooooo0_l0000Xooooo`;o0000<?ooool2o`0001?ooooo0_l0000nooooo`;o0000Ioooool2
o`0001oooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonH
V9So410@00Kooooo00?o0000ooooooooool03?ooool2o`0005[ooooo0_l0000Cooooo`;o0000b?oo
ool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
1_ooool00ol0003oooooooooo`0Mooooo`;o0000l?ooool2o`0000oooooo0_l0000Uooooo`007_oo
ool00ol0003oooooooooo`0Mooooo`;o0000l?ooool2o`0000oooooo0_l0000=ooooo`;o00005_oo
ool001kooooo00?o0000ooooooooool01oooool2o`0009Oooooo0_l0000Gooooo`;o0000:?ooool2
o`0002oooooo0_l0000?ooooo`;o00002?ooool2o`0001Kooooo000Nooooo`03o`000?oooooooooo
00Oooooo0_l0000fooooo`;o00008oooool2o`0002Sooooo0_l0000<ooooo`;o00000_ooool2o`00
01Oooooo0_l0000Hooooo`;o00003_ooool2o`0002oooooo0_l0000?ooooo`;o00008?ooool001ko
oooo00?o0000ooooooooool03?ooool2o`00037ooooo0_l0000Mooooo`;o00001?ooool2o`0002So
oooo0_l0000<ooooo`Co0000:_ooool2o`0000Oooooo0_l00008ooooo`;o0000AOooool2o`0000[o
oooo0_l0000Eooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o0000D?ooool2o`00037ooooo
0_l0000;ooooo`;o0000:_ooool2o`00017ooooo0_l00015ooooo`;o00002_ooool2o`0001Gooooo
000Nooooo`?o0000TOooool2o`000;Cooooo000Nooooo`Go00006oooool2o`00027ooooo0_l00007
ooooo`;o0000o?ooool001kooooo00?o0000ooooooooool00_l0000Kooooo`;o00001?ooool2o`00
01_ooooo0_l00007ooooo`;o0000Eoooool2o`0007Kooooo0_l0000[ooooo`007_ooool00ol0003o
ooooooooo`02o`00027ooooo0_l0000Tooooo`;o00005Oooool2o`0000Oooooo0_l0000>ooooo`;o
00009oooool2o`000003ooooool0003o000007?ooooo0_l0000[ooooo`007_ooool00ol0003ooooo
ooooo`02o`0004Oooooo0_l00007ooooo`;o00000_ooool2o`0000Sooooo0_l00007ooooo`;o0000
3_ooool2o`0002[ooooo0_l0001Mooooo`;o0000@Oooool001kooooo00?o0000ooooooooool03_oo
ool2o`0004;ooooo0_l00002ooooo`;o0000[?ooool2o`00047ooooo000Nooooo`;o00003oooool2
o`0001Gooooo0_l0002Vooooo`;o0000Boooool2o`0002_ooooo000Nooooo`03o`000?oooooooooo
02Gooooo0_l0002Looooo`;o00002?ooool2o`0002Wooooo0_l0000Pooooo`;o0000:oooool001ko
oooo00?o0000ooooooooool0MOooool2o`0000Wooooo0_l0000<ooooo`;o0000<oooool2o`0003?o
oooo0_l0000Xooooo`;o00008oooool001kooooo00?o0000ooooooooool02Oooool2o`0006[ooooo
0_l00009ooooo`;o00003?ooool2o`0004cooooo0_l00014ooooo`;o00003?ooool2o`0001Gooooo
000Nooooo`03o`000?oooooooooo00Wooooo0_l0002Iooooo`;o00006?ooool2o`0001cooooo0_l0
001Booooo`;o00005Oooool001kooooo00?o0000ooooooooool0UOooool2o`0000gooooo0_l0000H
ooooo`Co0000QOooool001kooooo00?o0000ooooooooool00oooool2o`0005_ooooo0_l0000coooo
o`;o00002oooool2o`0001[ooooo1?l0001<ooooo`;o0000=oooool001kooooo00?o0000oooooooo
ool00oooool2o`0005_ooooo0_l0000Nooooo`;o00008?ooool2o`0001[ooooo0_l0001>ooooo`;o
000000?oooooo`000?l00000=?ooool001kooooo00?o0000ooooooooool06Oooool2o`0006Gooooo
0_l0000Wooooo`;o00001Oooool2o`000003ooooool0003o000005[ooooo1?l0000dooooo`007_oo
ool00ol0003oooooooooo`0Iooooo`;o00002Oooool2o`0002[ooooo0_l0000looooo`;o00006Ooo
ool3o`0000Cooooo0_l000000ooooooo0000o`00000Xooooo`;o0000<?ooool2o`0003Kooooo000N
ooooo`03o`000?oooooooooo02Cooooo0_l0000Zooooo`;o00005?ooool2o`000003ooooool0003o
000002?ooooo0_l0000Jooooo`;o0000<Oooool2o`0006Sooooo000Nooooo`03o`000?oooooooooo
06Kooooo0_l000000ooooooo0000o`00000_ooooo`;o0000@oooool2o`0000;ooooo0_l0000Ioooo
o`;o0000Aoooool001kooooo00?o0000ooooooooool09oooool2o`00077ooooo0_l00009ooooo`;o
0000>?ooool2o`0000;ooooo0_l0000Iooooo`;o0000Aoooool001kooooo00?o0000ooooooooool0
9oooool2o`0007cooooo0_l0001Dooooo`;o00000_ooool2o`0004Kooooo000Nooooo`03o`000?oo
oooooooo05Sooooo0_l0002Qooooo`;o00000_ooool2o`0004Kooooo000Nooooo`03o`000?oooooo
oooo00Kooooo0_l0000Mooooo`;o0000<Oooool2o`0005Kooooo0_l0000Nooooo`;o00004?ooool2
o`0006?ooooo000Nooooo`;o00001oooool2o`000003ooooool0003o000001[ooooo0_l0000coooo
o`;o0000E?ooool2o`0001kooooo0_l0000@ooooo`;o0000E_ooool2o`0000_ooooo000Nooooo`03
o`000?oooooooooo00Wooooo0_l0000Tooooo`;o0000:Oooool2o`0001gooooo0_l0000Eooooo`;o
0000FOooool2o`0004gooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`0_ooooo`;o0000
=Oooool2o`00017ooooo0ol0000Dooooo`;o0000FOooool2o`0002cooooo0_l0000:ooooo`;o0000
8?ooool001kooooo00?o0000ooooooooool04_ooool2o`0000Sooooo0_l00018ooooo`;o00004_oo
ool3o`0001_ooooo0_l00009ooooo`;o00008_ooool2o`0003Cooooo0_l00009ooooo`;o00003ooo
ool2o`0000[ooooo0_l0000Hooooo`;o00001_ooool001kooooo00?o0000ooooooooool04_ooool2
o`0000Oooooo0ol0001Aooooo`;o00002_ooool2o`0001_ooooo0_l00007ooooo`Co00008_ooool2
o`0003Cooooo0_l00009ooooo`;o0000=Oooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo
00Gooooo0_l00004ooooo`;o00003_ooool2o`0005;ooooo0_l0000`ooooo`;o0000;_ooool2o`00
02oooooo0_l0000@ooooo`;o0000<Oooool001kooooo00?o0000ooooooooool01Oooool2o`0000Co
oooo0_l0002fooooo`;o00003?ooool2o`0002oooooo0_l00002ooooo`;o00003?ooool2o`0002[o
oooo0_l00005ooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o0000:_ooool3o`0005gooooo
0ol0000Aooooo`;o00008?ooool2o`0000?ooooo0_l00004ooooo`;o00005?ooool2o`0003Sooooo
0_l00005ooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o00005_ooool2o`0002[ooooo0ol0
000Booooo`;o0000BOooool3o`00013ooooo0_l0000Jooooo`;o00000_ooool2o`000003ooooool0
003o000000?ooooo0_l00004ooooo`;o0000EOooool001kooooo00?o0000ooooooooool02oooool2
o`0001[ooooo0_l0000kooooo`;o00008?ooool2o`0003[ooooo0_l0000Jooooo`;o00000_ooool2
o`0000oooooo0_l0001Booooo`007_ooool00ol0003oooooooooo`0Wooooo`;o0000GOooool2o`00
05;ooooo0_l0000Gooooo`;o00000oooool2o`0001_ooooo0_l0000`ooooo`007_ooool00ol0003o
ooooooooo`3Jooooo`;o00007?ooool2o`0001_ooooo0_l0000Aooooo`;o00007Oooool001kooooo
00?o0000ooooooooool0Noooool2o`0006?ooooo0_l00004ooooo`;o0000@?ooool2o`0001gooooo
000Nooooo`03o`000?oooooooooo07_ooooo0_l0001Sooooo`;o00001?ooool2o`00017ooooo0_l0
001<ooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o0000Soooool2o`00033ooooo0_l0000Y
ooooo`;o0000??ooool2o`0000kooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l0000Eoooo
o`;o0000I_ooool2o`00013ooooo0_l0000`ooooo`;o00006oooool2o`0004[ooooo0_l0000>oooo
o`007Oooool3o`0002?ooooo0_l0001Vooooo`;o00003_ooool2o`0003Kooooo0_l0000Gooooo`;o
00004_ooool2o`0000?ooooo0_l00011ooooo`007Oooool2o`0005Kooooo0_l00014ooooo`;o0000
=_ooool2o`0002_ooooo0_l00003ooooo`;o0000@Oooool001kooooo00?o0000ooooooooool0E?oo
ool2o`0000[ooooo0_l0003<ooooo`;o00005oooool001kooooo00?o0000ooooooooool04oooool2
o`000003ooooool0003o000001;ooooo0_l0000Uooooo`;o00001oooool2o`0000Cooooo0_l0001`
ooooo`;o00000oooool2o`0003[ooooo0_l0000Iooooo`;o00005oooool001kooooo00?o0000oooo
ooooool04oooool2o`000003ooooool0003o000001;ooooo0_l0000Uooooo`;o00001oooool2o`00
03Sooooo0_l0000looooo`;o00000oooool2o`0003[ooooo0_l0000booooo`007_ooool00ol0003o
ooooooooo`0kooooo`;o00007?ooool2o`00033ooooo0_l00007ooooo`;o0000M?ooool2o`0003_o
oooo000Nooooo`;o0000??ooool2o`0001Kooooo0_l00004ooooo`;o0000<?ooool2o`0004?ooooo
0_l0000hooooo`;o0000>oooool001kooooo0_l0000>ooooo`;o0000A?ooool2o`0007_ooooo0_l0
000Looooo`;o0000Eoooool001kooooo00?o0000ooooooooool03Oooool2o`0000oooooo0_l0002m
ooooo`Co00003Oooool2o`0005Oooooo000Nooooo`03o`000?oooooooooo017ooooo0_l00006oooo
o`;o00000oooool2o`000;3ooooo0_l00003ooooo`;o00001_ooool4o`0001Wooooo0_l000000ooo
oooo0000o`000007ooooo`;o0000?oooool001kooooo00?o0000ooooooooool04Oooool2o`0000Ko
oooo0_l00009ooooo`;o0000X?ooool2o`0000Sooooo0_l00003ooooo`;o00008oooool2o`000003
ooooool0003o000000Oooooo0_l0000oooooo`007_ooool00ol0003oooooooooo`0Tooooo`;o0000
FOooool2o`0001Cooooo0_l00005ooooo`;o00001Oooool2o`00027ooooo0_l0001Looooo`;o0000
8Oooool001kooooo00?o0000ooooooooool07_ooool2o`0004?ooooo0_l0000Jooooo`;o00005?oo
ool2o`0000Gooooo0_l00005ooooo`;o00008Oooool2o`0005cooooo0_l0000Qooooo`007_ooool0
0ol0003oooooooooo`0Nooooo`;o0000@oooool2o`00067ooooo0_l00012ooooo`;o00008?ooool2
o`0001Wooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l00000
0ol@413oooooooooo`04ooooo`03o`000?oooooooooo0=kooooo0_l0000Zooooo`;o00005oooool2
o`0000Oooooo0_l0000Iooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0g_ooool2o`0004?ooooo0_l0000?
ooooo`;o00004Oooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool3
o`0000kooooo0_l0002Wooooo`;o0000Noooool2o`00017ooooo0003ooooo`05o`000?oooooooooo
ooooool000002oooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo00kooooo0_l0
002Wooooo`;o0000S_ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0000Oooooo00?o0000ooooooooool0>Oooool2o`0001oooooo0_l0001gooooo`;o0000
;?ooool2o`0004Cooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`000007ooooo`03o`000?oooooooooo01[ooooo0_l0000Mooooo`;o00007oooool2o`0000Cooooo
0_l0001aooooo`;o0000;?ooool2o`0004Cooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo00_ooooo0_l0000=ooooo`;o0000
A?ooool2o`000>Gooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000
ooooo`06ooooo`03o`000?oooooooooo00_ooooo0_l0001>ooooo`;o00007oooool2o`000<Wooooo
000Nooooo`03o`000?oooooooooo05_ooooo0_l0000Oooooo`;o0000;?ooool2o`0000Cooooo0_l0
002Eooooo`007_ooool00ol0003oooooooooo`05ooooo`;o0000>Oooool2o`0003Oooooo0_l0000I
ooooo`;o00005?ooool2o`0000Cooooo0_l0000Wooooo`;o0000K?ooool001kooooo00?o0000oooo
ooooool01Oooool2o`0003Wooooo0_l0000gooooo`;o00006Oooool2o`0004?ooooo0_l0000Xoooo
o`?o0000@Oooool001kooooo00?o0000ooooooooool01Oooool2o`0001;ooooo0_l0000Aooooo`;o
00007_ooool2o`0003kooooo0_l0001[ooooo`;o000000?oooooo`000?l000001Oooool3o`0000co
oooo0_l0000Qooooo`;o00004?ooool001kooooo00?o0000ooooooooool06Oooool2o`00017ooooo
0_l0000Nooooo`;o00006Oooool2o`0002?ooooo0_l0000Mooooo`;o0000C?ooool2o`000003oooo
ool0003o000001Cooooo0_l0000Qooooo`;o00004?ooool001kooooo00?o0000ooooooooool0Iooo
ool2o`0004;ooooo0_l0002Jooooo`007_ooool00ol0003oooooooooo`05ooooo`;o0000Aoooool2
o`0002Cooooo0_l0000Dooooo`;o0000@?ooool2o`0007Wooooo000Nooooo`03o`000?oooooooooo
00Gooooo0_l00017ooooo`;o00009?ooool2o`0001Cooooo0_l00010ooooo`;o00008Oooool2o`00
00Kooooo0_l0000Rooooo`;o0000:_ooool001kooooo00?o0000ooooooooool0koooool2o`0000Ko
oooo0_l0000Rooooo`;o0000:_ooool001kooooo00?o0000ooooooooool06?ooool2o`0001Sooooo
0_l0000nooooo`;o00002oooool2o`0007Cooooo0_l0000Qooooo`;o0000;Oooool001kooooo00?o
0000ooooooooool06?ooool2o`0001Sooooo0_l0000nooooo`;o00002oooool2o`0001Kooooo1?l0
001=ooooo`;o00002oooool2o`00027ooooo0_l0000]ooooo`007_ooool2o`0000Kooooo0_l0002@
ooooo`Co0000COooool2o`0005gooooo000Nooooo`03o`000?oooooooooo00Gooooo0_l00007oooo
o`;o0000C_ooool2o`0005oooooo0_l00003ooooo`;o0000<?ooool2o`0004oooooo000Nooooo`03
o`000?oooooooooo00kooooo0_l0000Hooooo`;o0000=?ooool2o`0005oooooo0_l00003ooooo`;o
0000<?ooool2o`0004oooooo000Nooooo`03o`000?oooooooooo02Sooooo0_l0003ooooooakooooo
000Nooooo`03o`000?oooooooooo06Cooooo0_l0000@ooooo`;o0000coooool001kooooo00?o0000
ooooooooool0F_ooool2o`0000Sooooo0_l0000@ooooo`;o0000?_ooool2o`0008oooooo000Noooo
o`03o`000?oooooooooo01Sooooo0_l00010ooooo`;o0000F_ooool2o`0000Cooooo0_l0000<oooo
o`;o00008_ooool2o`0004cooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o
0000KOooool2o`0003?ooooo0_l0000<ooooo`;o00000_ooool2o`0001kooooo0_l0001<ooooo`;o
00002Oooool001kooooo00?o0000ooooooooool06Oooool4o`0006[ooooo0_l0000^ooooo`;o0000
5Oooool2o`0007Oooooo000Nooooo`03o`000?oooooooooo01Wooooo1?l00004ooooo`;o0000U?oo
ool2o`0007gooooo0_l0000?ooooo`007_ooool00ol0003oooooooooo`0Qooooo`;o00001Oooool2
o`0002Gooooo0_l0001]ooooo`;o0000<Oooool2o`0003Oooooo0_l0000:ooooo`;o00003oooool0
01kooooo00?o0000ooooooooool07_ooool2o`0000Sooooo0_l0000Uooooo`;o00008?ooool2o`00
04Oooooo0_l00002ooooo`;o0000<Oooool2o`0003Oooooo0_l0000Kooooo`007_ooool00ol0003o
ooooooooo`0Nooooo`;o00005?ooool2o`0000cooooo0_l0000]ooooo`;o0000Aoooool2o`0008_o
oooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0000^ooooo`;o00003?ooool2o`00033ooooo
0_l0003Aooooo`007_ooool00ol0003oooooooooo`04ooooo`;o00002_ooool2o`0001[ooooo0_l0
000cooooo`;o00004Oooool2o`0003;ooooo0_l0002Mooooo`007_ooool00ol0003oooooooooo`0@
ooooo`;o00006_ooool2o`0003?ooooo0_l00015ooooo`;o0000WOooool001kooooo0_l0000ioooo
o`;o0000ooooool>ooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o00008oooool2o`0001ko
oooo0_l0000Uooooo`Co00005?ooool2o`0003;ooooo0_l0001jooooo`007_ooool00ol0003ooooo
ooooo`0Cooooo`;o0000@oooool2o`0000kooooo0_l0000Eooooo`Ko00004Oooool4o`00037ooooo
0_l0001jooooo`007_ooool00ol0003oooooooooo`0Fooooo`;o00009Oooool2o`0001Sooooo1?l0
000=ooooo`;o00004Oooool2o`0000Kooooo0_l0000Aooooo`Co0000N?ooool2o`0003?ooooo000N
ooooo`03o`000?oooooooooo00kooooo0_l00006ooooo`;o00009Oooool2o`0001Sooooo1?l0000P
ooooo`;o00006Oooool2o`0001cooooo0_l0001Looooo`;o0000<oooool001kooooo00?o0000oooo
ooooool03_ooool2o`0001kooooo0_l0000?ooooo`;o0000Loooool2o`00097ooooo000Nooooo`03
o`000?oooooooooo02kooooo0_l0000?ooooo`;o0000ooooool7ooooo`007_ooool00ol0003ooooo
ooooo`2hooooo`;o0000K_ooool2o`0001gooooo000Nooooo`03o`000?oooooooooo0;Sooooo0_l0
001Fooooo`;o00005_ooool2o`0001gooooo000Nooooo`03o`000?oooooooooo06kooooo0_l0001O
ooooo`;o0000?oooool2o`0003Gooooo000Nooooo`03o`000?oooooooooo06kooooo0_l0001Ooooo
o`;o00000_ooool2o`0000Cooooo0_l0001/ooooo`007_ooool00ol0003oooooooooo`3Cooooo`;o
00001?ooool2o`00043ooooo0_l0000Zooooo`007_ooool00ol0003oooooooooo`3oooooo`;o0000
6_ooool2o`0002[ooooo000Nooooo`03o`000?oooooooooo00Gooooo0_l00004ooooo`;o00009ooo
ool2o`0001Cooooo0_l00009ooooo`;o00001_ooool2o`0004Gooooo0_l0000fooooo`;o00008Ooo
ool2o`0003gooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`05ooooo`;o00001?ooool2
o`0002Oooooo0_l00005ooooo`;o00003Oooool2o`0000Sooooo0ol00004ooooo`Co0000AOooool2
o`0003Kooooo0_l0000kooooo`;o00008Oooool4o`0000Oooooo000Nooooo`03o`000?oooooooooo
03_ooooo0_l00006ooooo`;o00003oooool2o`0000Gooooo1?l0002jooooo`;o00008Oooool2o`00
00Wooooo000Nooooo`;o0000A?ooool2o`00083ooooo0ol0001Oooooo`;o00005Oooool2o`0000Oo
oooo000Nooooo`04o`000?ooooooooooooooo`;o00004_ooool2o`0001kooooo0_l0000Kooooo`;o
00006?ooool2o`0002Gooooo0_l0000`ooooo`?o0000Goooool2o`0001Gooooo0_l00007ooooo`00
7_ooool01?l0003oooooooooooooool2o`0001;ooooo0_l0000Nooooo`;o00004_ooool2o`0000Oo
oooo0_l0000Hooooo`;o00009Oooool2o`0003Kooooo0_l0000[ooooo`;o0000COooool001kooooo
00?o0000ooooooooool0BOooool2o`00083ooooo0_l0000Nooooo`;o00002oooool2o`0004gooooo
000Nooooo`03o`000?oooooooooo02Gooooo0_l00003ooooo`;o00002oooool2o`000;;ooooo0_l0
001Jooooo`007_ooool00ol0003oooooooooo`0Uooooo`;o00000oooool2o`0000_ooooo0_l0003o
ooooo`oooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0000Rooooo`;o00003oooool2o`00
04Wooooo0_l0000iooooo`;o000000?oooooo`000?l00000Ioooool2o`0000_ooooo0_l0000=oooo
o`007_ooool00ol0003oooooooooo`04ooooo`;o00008_ooool2o`0000oooooo0_l00019ooooo`;o
00000_ooool2o`0003Gooooo0_l000000ooooooo0000o`00001Wooooo`;o00002oooool2o`0000go
oooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0000Cooooo`;o00006?ooool2o`0005Gooooo
1?l0002kooooo`007_ooool00ol0003oooooooooo`02ooooo`;o00004oooool2o`0001Sooooo0_l0
001<ooooo`;o00002Oooool2o`000:_ooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`1o
ooooo`;o0000]_ooool2o`0000kooooo000Nooooo`03o`000?oooooooooo02gooooo0_l0001Foooo
o`;o0000:oooool2o`0005gooooo0_l0000dooooo`007_ooool00ol0003oooooooooo`0]ooooo`;o
00007_ooool2o`0003Kooooo0_l0000[ooooo`;o00006?ooool2o`0001_ooooo0_l0000Iooooo`;o
00002oooool4o`0000Kooooo0_l0000Zooooo`007_ooool00ol0003oooooooooo`1=ooooo`;o0000
Noooool4o`0001_ooooo0_l0000Iooooo`;o00003Oooool2o`0000Kooooo0_l00004ooooo`;o0000
9?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<00Kooooo00?o0000ooooooooool02Oooool2o`0004?ooooo0_l0000Xooooo`;o
0000D?ooool2o`0005Gooooo0_l0000Tooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`09oooo
o`;o0000@oooool2o`0002Sooooo0_l0000Nooooo`;o0000H?ooool2o`0001Oooooo0_l0000boooo
o`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006
ooooo`Co0000U_ooool3o`00063ooooo0_l0000Gooooo`;o0000<_ooool000?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool4o`0000?ooooo0_l0
002Aooooo`;o0000:oooool2o`0002Wooooo0_l0001Fooooo`000oooool01Ol0003ooooooooooooo
oooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`?o00001?ooool2o`000;kooooo
0_l0000Yooooo`;o00006_ooool2o`0003[ooooo0003ooooo`05oa0@4?ooooooooooooooool@4100
2oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo0?oooooo3?ooool2o`0003[ooooo
0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`00
0?oooooooooo067ooooo0_l00012ooooo`;o00001_ooool2o`0003oooooo0_l0001Gooooo`000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003o
ooooooooo`03ooooo`;o00007_ooool2o`0001Kooooo0_l0000Tooooo`;o0000@_ooool2o`0000Ko
oooo0_l0000Zooooo`;o00004oooool4o`0005Gooooo000Nooooo`03o`000?oooooooooo00?ooooo
0_l0000Nooooo`;o00005_ooool2o`0001Sooooo0_l00022ooooo`;o00005Oooool2o`0005Gooooo
000Nooooo`03o`000?oooooooooo05Gooooo0_l0001=ooooo`;o0000K?ooool2o`0003?ooooo000N
ooooo`03o`000?oooooooooo08[ooooo0_l0000Hooooo`;o00007?ooool2o`0001Oooooo0_l0000H
ooooo`;o00006oooool2o`0000;ooooo0_l0000Wooooo`;o00001_ooool001kooooo00Co0000oooo
oooooooooooo0_l0000/ooooo`;o00002_ooool2o`0004gooooo0_l0000fooooo`;o00005oooool2
o`0001Sooooo0_l0000Oooooo`;o00009oooool2o`0000Kooooo000Nooooo`04o`000?oooooooooo
ooooo`;o00002oooool2o`0001oooooo0_l0000:ooooo`;o0000Foooool2o`0002Cooooo0_l0000K
ooooo`;o0000J_ooool001kooooo00?o0000ooooooooool03_ooool2o`0004cooooo0_l0000joooo
o`;o00009?ooool2o`0000Sooooo0_l0001mooooo`007_ooool00ol0003oooooooooo`1Looooo`;o
0000J_ooool2o`0000oooooo0_l0000Jooooo`;o00009?ooool2o`00013ooooo0_l0000Hooooo`00
7_ooool2o`0003Oooooo0_l0001<ooooo`;o0000AOooool2o`0000cooooo0_l0000Jooooo`;o0000
9?ooool2o`00013ooooo0_l0000;ooooo`;o00002oooool001kooooo0_l0000gooooo`;o0000;_oo
ool2o`0001cooooo0_l00015ooooo`;o0000:oooool2o`00043ooooo0_l0000;ooooo`007_ooool0
0ol0003oooooooooo`1Vooooo`;o0000:_ooool2o`000003ooooool0003o000004Cooooo0_l0000C
ooooo`;o00001_ooool2o`0004gooooo000Nooooo`03o`000?oooooooooo02Gooooo0_l0000koooo
o`;o00002?ooool2o`0002Cooooo0_l000000ooooooo0000o`000014ooooo`;o00004oooool2o`00
04cooooo0_l00007ooooo`007_ooool2o`0002Kooooo0_l0000kooooo`;o00002?ooool2o`000003
ooooool0003o0000097ooooo0_l0000jooooo`;o00001oooool001kooooo00?o0000ooooooooool0
Koooool2o`00097ooooo0_l0000hooooo`;o00002Oooool001kooooo00?o0000ooooooooool0E?oo
ool2o`0000gooooo0_l0003Gooooo`;o00002Oooool001kooooo00?o0000ooooooooool06oooool2
o`0003Oooooo0_l00006ooooo`;o00001Oooool2o`000>;ooooo000Nooooo`03o`000?oooooooooo
01_ooooo0_l0000oooooo`;o00003_ooool2o`0001oooooo0_l0001kooooo`;o0000>oooool001ko
oooo00?o0000ooooooooool09Oooool2o`0000cooooo0_l0000gooooo`;o00007oooool2o`0000;o
oooo0_l0001gooooo`;o0000>oooool001kooooo00?o0000ooooooooool09Oooool2o`0000cooooo
0_l0001Looooo`;o0000C_ooool2o`0006Cooooo000Nooooo`03o`000?oooooooooo0:gooooo0_l0
000booooo`;o0000I?ooool001kooooo00?o0000ooooooooool0:oooool2o`00083ooooo0_l0000^
ooooo`;o0000:?ooool2o`0001;ooooo0_l0000Zooooo`007_ooool00ol0003oooooooooo`0Joooo
o`;o00003oooool2o`0009Cooooo0_l0000Jooooo`;o00004?ooool2o`0001Kooooo0_l0000=oooo
o`;o00000oooool2o`0002[ooooo000Nooooo`04o`000?oooooo0000o`0001Wooooo0_l0002Uoooo
o`;o0000;?ooool2o`0002Gooooo0_l0000_ooooo`007_ooool01?l0003oooooo`000?l0003ooooo
odOooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0000Looooo`;o0000oooooolAooooo`;o
00002oooool001kooooo00?o0000ooooooooool02_ooool2o`0001cooooo0_l0001Kooooo`;o0000
@_ooool2o`0005Kooooo0_l0000Gooooo`;o00002oooool001kooooo00?o0000ooooooooool0<?oo
ool2o`0003;ooooo0_l0000Oooooo`;o0000@_ooool2o`00017ooooo0_l0000Zooooo`?o00005_oo
ool2o`0002Cooooo000Nooooo`03o`000?oooooooooo023ooooo0_l0000>ooooo`;o0000<_ooool2
o`0004Gooooo0_l0000@ooooo`;o00007Oooool2o`0002[ooooo0ol0000looooo`007_ooool2o`00
027ooooo0_l00029ooooo`;o00004?ooool2o`0008Sooooo000Nooooo`03o`000?oooooooooo05;o
oooo0_l0000Jooooo`;o0000Poooool2o`0003Gooooo0_l0000Kooooo`007_ooool00ol0003ooooo
ooooo`0Eooooo`;o0000>oooool2o`0001[ooooo0_l0000Tooooo`;o00005?ooool2o`0000Kooooo
0_l0000Uooooo`;o00006?ooool2o`0002Gooooo0_l00002ooooo`;o00002_ooool4o`0001Wooooo
000Nooooo`03o`000?oooooooooo01Gooooo0_l0001;ooooo`;o0000:?ooool2o`0000Kooooo0_l0
000Dooooo`;o00001_ooool2o`0002Gooooo0_l0000Uooooo`;o00006?ooool2o`0000;ooooo0_l0
000<ooooo`;o00003?ooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0000V
ooooo`;o00009?ooool2o`0000Sooooo0_l000000ooooooo0000o`00000Kooooo`;o0000IOooool2
o`0000_ooooo0_l0000hooooo`;o00002oooool001kooooo00?o0000ooooooooool05?ooool2o`00
027ooooo0_l00003ooooo`;o0000;_ooool2o`000003ooooool0003o000006Kooooo0_l0000Joooo
o`;o00001?ooool2o`0003oooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`0gooooo`;o
00004oooool2o`0008Wooooo0_l0000Pooooo`;o0000C?ooool001kooooo00?o0000ooooooooool0
C?ooool2o`0006?ooooo0_l0001oooooo`;o00004oooool001kooooo00?o0000ooooooooool09_oo
ool2o`0001_ooooo0_l0000=ooooo`;o0000>Oooool2o`0000gooooo0_l0000Cooooo`;o0000Oooo
ool2o`0001?ooooo000Nooooo`03o`000?oooooooooo02Kooooo0_l0000Kooooo`;o00003Oooool2
o`0002gooooo0_l00004ooooo`;o00001?ooool2o`0000Sooooo0_l00003ooooo`;o00003Oooool2
o`0003;ooooo0_l0001Jooooo`;o00002_ooool001kooooo00?o0000ooooooooool05_ooool2o`00
02Oooooo0_l00010ooooo`;o00001?ooool2o`0000kooooo0_l0000Booooo`;o00008_ooool2o`00
00kooooo0_l0001Jooooo`;o00002_ooool001kooooo00?o0000ooooooooool05_ooool2o`0002Oo
oooo0_l00005ooooo`;o0000Boooool2o`00037ooooo0_l00007ooooo`;o0000Foooool2o`0001Wo
oooo000Nooooo`03o`000?oooooooooo04Kooooo0_l0001;ooooo`;o00006_ooool2o`0001Gooooo
0_l0000Jooooo`;o0000B?ooool2o`0001Wooooo000Nooooo`03o`000?oooooooooo02cooooo0_l0
0015ooooo`;o0000>_ooool2o`00037ooooo0_l0001Sooooo`007_ooool00ol0003oooooooooo`0/
ooooo`;o0000>oooool2o`0000Sooooo0_l0000looooo`;o00003?ooool2o`0008Kooooo000Noooo
o`03o`000?oooooooooo02oooooo1?l0000fooooo`;o00005?ooool2o`0001Kooooo0_l0000Hoooo
o`;o00003?ooool2o`0000?ooooo0_l0000kooooo`;o0000A?ooool001kooooo0_l0000Jooooo`;o
00005?ooool4o`0000oooooo0_l0000_ooooo`;o00002_ooool2o`0001Kooooo0_l0000Cooooo`;o
00005_ooool2o`0000?ooooo0_l00003ooooo`;o0000<Oooool2o`0000cooooo0_l0000fooooo`00
7_ooool00ol0003oooooooooo`0Iooooo`;o00009oooool2o`0001_ooooo0_l0000Booooo`;o0000
:?ooool4o`0000_ooooo0_l0000Kooooo`;o00000oooool4o`0003gooooo0_l0000fooooo`007_oo
ool00ol0003oooooooooo`1Oooooo`;o0000??ooool4o`0002oooooo0_l0001eooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`04o`000?oooooo0000o`000;?ooooo0_l0002A
ooooo`007_ooool01?l0003oooooo`000?l0000Rooooo`;o0000Soooool2o`0003Cooooo0_l0001K
ooooo`007_ooool00ol0003oooooooooo`06ooooo`;o00003_ooool2o`0000_ooooo0_l00023oooo
o`;o0000@?ooool2o`0005_ooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l0000>ooooo`;o
0000T?ooool2o`0000?ooooo0_l00014ooooo`;o00001?ooool2o`0004cooooo000Nooooo`03o`00
0?oooooooooo0:gooooo1?l00008ooooo`;o00002_ooool2o`0002cooooo0_l00004ooooo`;o0000
C?ooool001kooooo00?o0000ooooooooool0[oooool2o`0000Sooooo0_l0000:ooooo`;o0000P?oo
ool001kooooo00?o0000ooooooooool0O_ooool2o`0004Sooooo0_l0000>ooooo`;o0000KOooool0
01kooooo00?o0000ooooooooool0Moooool2o`0000Gooooo0_l00018ooooo`;o00003_ooool2o`00
06gooooo000Nooooo`03o`000?oooooooooo07Oooooo0_l0003>ooooo`007_ooool00ol0003ooooo
ooooo`03ooooo`;o000000?oooooo`000?l00000=?ooool2o`0004Oooooo0_l0000Looooo`;o0000
Doooool2o`0001Cooooo0_l0000gooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`03ooooo`;o
000000?oooooo`000?l000003_ooool2o`0002Cooooo0_l0000Iooooo`;o0000;?ooool2o`0000co
oooo0_l0000>ooooo`;o0000Doooool2o`0001Cooooo0_l000000ooooooo0000o`00000dooooo`00
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRH
V?lQ8B401_ooool00ol0003oooooooooo`0;ooooo`;o00002Oooool2o`0001gooooo0_l0000Poooo
o`;o0000>_ooool2o`0006;ooooo0_l0000Hooooo`;o0000=?ooool000?ooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`0000_ooooo0_l0000X
ooooo`;o00002Oooool2o`0004Cooooo0_l0000<ooooo`;o0000@oooool2o`0000Sooooo0_l0000B
ooooo`;o00009_ooool2o`0001Kooooo0_l0000>ooooo`000oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooooooo043ooooo0_l0
000Jooooo`;o0000:?ooool2o`0000cooooo0_l00013ooooo`;o00002?ooool2o`0003[ooooo0_l0
000Fooooo`;o00003_ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0
003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`1Looooo`;o00008_ooool2o`0000oooooo
0_l0002dooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo
^[Zjoa0@4006ooooo`03o`000?oooooooooo083ooooo0_l0000?ooooo`;o00002oooool2o`0007?o
oooo0_l0000Gooooo`Co00005oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`1cooooo`;o0000:Oooool2o`00
05cooooo0_l00008ooooo`;o00002oooool2o`0001Oooooo1?l0000Gooooo`000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooo
oooo02Wooooo0_l0000Vooooo`;o00008?ooool2o`0006oooooo0_l0000Fooooo`;o00002?ooool2
o`0003oooooo000Nooooo`03o`000?oooooooooo02Wooooo0_l0000Vooooo`;o00008?ooool3o`00
03?ooooo0_l0000iooooo`;o00000oooool2o`0005cooooo000Nooooo`04o`000?oooooo0000o`00
00oooooo0_l0000oooooo`;o00008Oooool2o`0002_ooooo0_l00006ooooo`;o0000?_ooool2o`00
033ooooo0_l0000Zooooo`007_ooool01?l0003oooooo`000?l0000?ooooo`;o0000Noooool2o`00
01;ooooo0_l0000Uooooo`;o00003Oooool2o`0004;ooooo0_l0000Zooooo`007_ooool00ol0003o
ooooooooo`0kooooo`;o0000D?ooool2o`0002_ooooo0_l0000<ooooo`;o00003Oooool2o`0003oo
oooo0_l000000ooooooo0000o`00000Zooooo`007_ooool00ol0003oooooooooo`07ooooo`;o0000
8?ooool2o`00013ooooo0_l00006ooooo`;o0000>Oooool2o`0003Kooooo0_l00002ooooo`;o0000
<?ooool2o`0002[ooooo0_l000000ooooooo0000o`000002o`0002Sooooo000Nooooo`03o`000?oo
oooooooo00Oooooo0_l0000Pooooo`;o00006?ooool2o`0003Wooooo0_l00007ooooo`;o00000_oo
ool2o`0002Wooooo0_l0000dooooo`;o0000;oooool2o`0002Sooooo000Nooooo`03o`000?oooooo
oooo03Gooooo0_l0001>ooooo`Co00000_ooool2o`0007Oooooo0_l0000Qooooo`;o00007_ooool0
01kooooo00?o0000ooooooooool0:?ooool2o`0000_ooooo0_l0000Fooooo`Co00000oooool3o`00
02kooooo0_l0000hooooo`;o0000@oooool2o`0001cooooo0_l00003ooooo`;o00004_ooool2o`00
00[ooooo000Nooooo`03o`000?oooooooooo02Sooooo0_l0000Sooooo`Go00000_ooool3o`0006So
oooo0_l0000mooooo`;o00008_ooool2o`0001Oooooo0_l0000:ooooo`007_ooool00ol0003ooooo
ooooo`1@ooooo`;o0000COooool2o`0000?ooooo0_l0000Qooooo`;o0000=Oooool2o`00017ooooo
0_l0000<ooooo`;o00004?ooool2o`0001Cooooo000Nooooo`04o`000?ooooooooooooooo`;o0000
W?ooool2o`0000?ooooo0_l0000Qooooo`;o00004_ooool2o`0003Cooooo0_l0000<ooooo`;o0000
4?ooool2o`0001Cooooo000Nooooo`;o00000_ooool2o`0009Oooooo0_l00004ooooo`;o00003?oo
ool2o`0002_ooooo0_l0001Zooooo`007_ooool01?l0003oooooooooooooool2o`0009Oooooo0_l0
0004ooooo`;o00003?ooool2o`00077ooooo0_l0000Tooooo`007_ooool00ol0003oooooooooo`34
ooooo`;o0000Foooool2o`0002Cooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0001Qoooo
o`;o0000B_ooool2o`0000cooooo0_l0000Kooooo`;o00007_ooool2o`0003?ooooo0ol0000>oooo
o`007_ooool00ol0003oooooooooo`07ooooo`;o00003?ooool2o`0005?ooooo0_l0001:ooooo`;o
0000:Oooool2o`0001kooooo0_l000000ooooooo0000o`00000`ooooo`?o00003_ooool001kooooo
00?o0000ooooooooool05Oooool2o`00017ooooo0_l0002Pooooo`;o0000>?ooool2o`0000gooooo
0_l0000booooo`007_ooool00ol0003oooooooooo`0Xooooo`;o0000X?ooool2o`0004Oooooo0_l0
000;ooooo`;o00009Oooool001kooooo00?o0000ooooooooool01Oooool2o`000?oooooo6_ooool2
o`0002Gooooo000Nooooo`03o`000?oooooooooo00Gooooo0_l0003Hooooo`Co0000=Oooool2o`00
02gooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0001:ooooo`;o00005?ooool2o`0002co
oooo0_l0000iooooo`Co0000=Oooool2o`0002gooooo000Nooooo`04o`000?oooooo0000o`0001?o
oooo0_l00003ooooo`;o0000AOooool2o`0001Cooooo0_l0000/ooooo`;o0000D?ooool2o`0004oo
oooo000Nooooo`04o`000?oooooo0000o`0001Sooooo0_l0000Fooooo`;o0000_oooool2o`0000;o
oooo0_l0001?ooooo`007_ooool00ol0003oooooooooo`0aooooo`;o0000_oooool2o`0000?ooooo
0_l0001>ooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o00002Oooool2o`0006Gooooo0_l0
000Eooooo`;o0000F?ooool2o`0004kooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l00009
ooooo`;o0000IOooool2o`0001Gooooo0_l0000looooo`;o0000<Oooool2o`0002oooooo0_l00006
ooooo`007_ooool00ol0003oooooooooo`35ooooo`;o000000?oooooo`000?l000004Oooool2o`00
02kooooo0_l000000ooooooo0000o`00000_ooooo`;o00001_ooool001kooooo0_l00036ooooo`;o
000000?oooooo`000?l00000@Oooool2o`0000Oooooo0_l0000aooooo`007_ooool00ol0003ooooo
ooooo`0?ooooo`;o0000jOooool2o`0001Sooooo0_l0000aooooo`007_ooool00ol0003ooooooooo
o`0?ooooo`;o0000B_ooool2o`0007Oooooo0_l0000Nooooo`;o00001?ooool2o`0003[ooooo0_l0
000?ooooo`007_ooool00ol0003oooooooooo`1Kooooo`;o0000Moooool2o`0001kooooo0_l0000A
ooooo`;o0000;Oooool2o`0000oooooo000Nooooo`03o`000?oooooooooo02?ooooo0_l00022oooo
o`;o0000G_ooool2o`0003kooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l0000Kooooo`;o
00008?ooool2o`00063ooooo0_l0000jooooo`;o00006oooool2o`0004Gooooo000Nooooo`03o`00
0?oooooooooo00Kooooo0_l0000Oooooo`;o00007?ooool2o`0009Wooooo0_l000000ooooooo0000
o`00000=ooooo`;o00003?ooool2o`0000Sooooo0_l0000kooooo`007_ooool00ol0003ooooooooo
o`0?ooooo`;o00005_ooool2o`0009Gooooo0_l00003ooooo`;o00005?ooool2o`0000Gooooo0_l0
000@ooooo`;o00005_ooool2o`00037ooooo0_l00008ooooo`007_ooool00ol0003oooooooooo`0?
ooooo`;o0000[Oooool2o`0000?ooooo0_l0000Dooooo`;o0000:_ooool2o`0002oooooo0_l00005
ooooo`;o00002?ooool001kooooo00?o0000ooooooooool06?ooool2o`0006Gooooo0_l0000Ioooo
o`;o00008?ooool2o`0004Oooooo1?l0000Gooooo`;o00005?ooool2o`0000oooooo000Nooooo`03
o`000?oooooooooo01Sooooo0_l00019ooooo`;o00002_ooool2o`0000kooooo0_l000000ooooooo
0000o`00000Fooooo`;o00008?ooool2o`0004Wooooo0_l0000Gooooo`;o00009Oooool001kooooo
00?o0000ooooooooool0Hoooool2o`0000[ooooo0_l0000Aooooo`;o0000`oooool001kooooo00?o
0000ooooooooool0:Oooool2o`0003Oooooo0_l0000Xooooo`;o0000=Oooool2o`0008;ooooo000M
ooooo`;o0000:oooool2o`0003Oooooo0_l0000Dooooo`;o00004_ooool2o`0003Gooooo0_l0001I
ooooo`;o00009oooool001gooooo0_l00014ooooo`;o0000=?ooool2o`00053ooooo0_l0001Boooo
o`;o00000oooool2o`0002;ooooo000Nooooo`03o`000?oooooooooo04;ooooo0_l0001hooooo`;o
00003?ooool2o`0002?ooooo0_l0000booooo`;o00008_ooool001kooooo0_l00002ooooo`;o0000
U_ooool2o`0000Oooooo0_l0000Hooooo`;o0000<Oooool2o`0005Kooooo000Nooooo`;o00000_oo
ool2o`0001gooooo0_l0001gooooo`;o00001oooool2o`0006;ooooo0_l0000oooooo`007_ooool2
o`00027ooooo0_l0001Uooooo`;o0000??ooool2o`0002Oooooo0_l000000ooooooo0000o`000004
ooooo`;o00003Oooool2o`0003oooooo000Nooooo`03o`000?oooooooooo08Oooooo0_l0000loooo
o`;o00009oooool2o`000003ooooool0003o000000Cooooo0_l0001>ooooo`007_ooool00ol0003o
ooooooooo`2Kooooo`;o0000>oooool2o`0006gooooo000Nooooo`03o`000?oooooooooo01cooooo
0_l0001mooooo`;o0000;oooool2o`0000[ooooo0_l0000Aooooo`;o0000F_ooool001kooooo00?o
0000ooooooooool07?ooool2o`0004Oooooo0_l0001>ooooo`;o00004?ooool2o`0000?ooooo0_l0
000Mooooo`;o0000F_ooool001kooooo00?o0000ooooooooool01Oooool2o`0001kooooo0_l0000n
ooooo`;o00005_ooool2o`0003Kooooo0_l0000@ooooo`;o0000I_ooool2o`0001Kooooo000Noooo
o`03o`000?oooooooooo00Gooooo0_l0000Nooooo`;o0000;oooool2o`0002Gooooo0_l0002?oooo
o`;o00007oooool2o`0001Kooooo000Nooooo`03o`000?oooooooooo01kooooo0_l0000Yooooo`;o
00002oooool2o`0002Sooooo0_l00018ooooo`;o0000@?ooool4o`0003Oooooo000Nooooo`03o`00
0?oooooooooo01kooooo0_l0000Pooooo`;o00001oooool2o`0000Sooooo0_l0000[ooooo`;o0000
B?ooool2o`00043ooooo0_l0000Booooo`;o00006Oooool2o`0000[ooooo000Nooooo`03o`000?oo
oooooooo043ooooo0_l0000Aooooo`;o0000boooool2o`0001Wooooo0_l0000:ooooo`007_ooool0
0ol0003oooooooooo`31ooooo`;o0000FOooool2o`0002Wooooo000Nooooo`03o`000?oooooooooo
033ooooo0_l0000dooooo`;o00004?ooool2o`0004Oooooo0_l0000kooooo`;o00002Oooool2o`00
017ooooo0_l0000>ooooo`;o00006Oooool001Cooooo1?l000000ol@413oooooooooo`03ooooo`03
o`000?oooooooooo033ooooo0_l0000Aooooo`;o00008Oooool2o`00013ooooo0_l00024ooooo`;o
00002Oooool2o`0000Wooooo0_l0000Fooooo`;o00006Oooool001Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`13ooooo`;o0000=oooool2o`0006oooooo0_l0000Uooooo`;o0000
<Oooool001Kooooo00?o0000ooooooooool01Oooool3o`0007cooooo0_l0001_ooooo`;o00009_oo
ool2o`00033ooooo000Fooooo`03o`000?oooooooooo0?oooooo7_ooool2o`00033ooooo000Foooo
o`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`00
5_ooool00ol0003oooooooooo`3ooooooe3ooooo000Dooooo`03oeEEEOmVIVKo00000?ooooooD_oo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.58905 .17911 Mdot
.60839 .5168 Mdot
.00508 .53341 Mdot
.43187 .62818 Mdot
.58532 .87929 Mdot
.7502 .84621 Mdot
.65878 .70927 Mdot
.94926 .8254 Mdot
.37173 .27823 Mdot
.09316 .89466 Mdot
.3171 .37463 Mdot
.20731 .11406 Mdot
.95259 .41505 Mdot
.37506 .82341 Mdot
.72616 .66325 Mdot
.71334 .97172 Mdot
.91334 .00939 Mdot
.1868 .89812 Mdot
.48718 .07865 Mdot
.01153 .30444 Mdot
.88804 .02215 Mdot
.14296 .18135 Mdot
.34592 .42201 Mdot
.71302 .84511 Mdot
.61641 .2256 Mdot
.11136 .25014 Mdot
.11469 .79031 Mdot
.16959 .50218 Mdot
.97532 .55639 Mdot
.20174 .825 Mdot
.71607 .7099 Mdot
.96708 .75204 Mdot
.05402 .45746 Mdot
.04849 .34098 Mdot
.48095 .81019 Mdot
.56159 .27263 Mdot
.6364 .81366 Mdot
.22334 .79844 Mdot
.74634 .79034 Mdot
.83109 .51997 Mdot
.54427 .45345 Mdot
.85038 .92211 Mdot
.6056 .97685 Mdot
.65878 .38639 Mdot
.3284 .28746 Mdot
.84039 .82632 Mdot
.07346 .25243 Mdot
.50174 .3223 Mdot
.21487 .66901 Mdot
.05419 .74865 Mdot
.24141 .65282 Mdot
.9959 .00936 Mdot
.92418 .97431 Mdot
.37562 .31395 Mdot
.09466 .22746 Mdot
.4906 .1485 Mdot
.5445 .16089 Mdot
.87629 .10042 Mdot
.69602 .13278 Mdot
.59736 .5537 Mdot
.70704 .69081 Mdot
.32268 .02568 Mdot
.23786 .25903 Mdot
.09548 .79567 Mdot
.54359 .05814 Mdot
.94494 .71133 Mdot
.21865 .60242 Mdot
.22823 .77845 Mdot
.4482 .66572 Mdot
.13062 .45563 Mdot
.5292 .30667 Mdot
.30853 .67975 Mdot
.0424 .84666 Mdot
.75808 .88067 Mdot
.58189 .81598 Mdot
.44219 .85977 Mdot
.26568 .5274 Mdot
.72188 .92244 Mdot
.27714 .15193 Mdot
.71406 .36401 Mdot
.05112 .255 Mdot
.36524 .13706 Mdot
.29519 .17546 Mdot
.83286 .23085 Mdot
.47294 .10304 Mdot
.8479 .58121 Mdot
.66439 .51742 Mdot
.17682 .49726 Mdot
.16958 .21256 Mdot
.68209 .34686 Mdot
.67427 .28224 Mdot
.73888 .75904 Mdot
.8528 .80984 Mdot
.60841 .84494 Mdot
.33573 .85629 Mdot
.54987 .83742 Mdot
.08628 .5277 Mdot
.47914 .47755 Mdot
.64493 .78912 Mdot
.07297 .75093 Mdot
.69634 .3482 Mdot
.61775 .1778 Mdot
.79599 .28808 Mdot
.64843 .19384 Mdot
.17224 .71349 Mdot
.26964 .57657 Mdot
.61382 .08472 Mdot
.94757 .51971 Mdot
.30191 .78021 Mdot
.24219 .26247 Mdot
.88091 .21875 Mdot
.39126 .73014 Mdot
.96067 .64272 Mdot
.55007 .33002 Mdot
.38561 .12721 Mdot
.6736 .90939 Mdot
.44004 .63641 Mdot
.62694 .55681 Mdot
.05178 .78303 Mdot
.90626 .82275 Mdot
.52787 .21943 Mdot
.43858 .32855 Mdot
.87084 .2225 Mdot
.27555 .82126 Mdot
.68536 .35322 Mdot
.49804 .71723 Mdot
.5291 .00503 Mdot
.05121 .58338 Mdot
.86694 .59309 Mdot
.19492 .24795 Mdot
.03349 .04065 Mdot
.5153 .20336 Mdot
.7386 .04545 Mdot
.8476 .65144 Mdot
.6395 .04469 Mdot
.80278 .05343 Mdot
.17588 .46303 Mdot
.07641 .11161 Mdot
.87187 .22866 Mdot
.25143 .75332 Mdot
.7822 .41289 Mdot
.83298 .28365 Mdot
.52288 .60328 Mdot
.54307 .30509 Mdot
.01043 .7863 Mdot
.46708 .4325 Mdot
.14455 .96623 Mdot
.89008 .60629 Mdot
.74897 .7329 Mdot
.58764 .26592 Mdot
.10386 .27055 Mdot
.5608 .7384 Mdot
.54672 .08218 Mdot
.50454 .22256 Mdot
.79605 .25256 Mdot
.18485 .14423 Mdot
.00849 .24709 Mdot
.49554 .9345 Mdot
.08462 .5104 Mdot
.82887 .09865 Mdot
.10852 .55428 Mdot
.01126 .06213 Mdot
.23207 .06392 Mdot
.68202 .09829 Mdot
.91713 .20137 Mdot
.94916 .10428 Mdot
.89449 .17496 Mdot
.98901 .73482 Mdot
.11209 .70227 Mdot
.7221 .02468 Mdot
.80244 .41162 Mdot
.11438 .15028 Mdot
.47067 .63551 Mdot
.87445 .86207 Mdot
.01224 .34638 Mdot
.96465 .98903 Mdot
.32143 .36555 Mdot
.78831 .66677 Mdot
.20144 .96874 Mdot
.57598 .70702 Mdot
.31251 .4917 Mdot
.07505 .90065 Mdot
.7359 .85049 Mdot
.18407 .52396 Mdot
.03981 .43987 Mdot
.53833 .88973 Mdot
.80059 .87581 Mdot
.34278 .67369 Mdot
.70444 .73343 Mdot
.32575 .23945 Mdot
.2782 .53669 Mdot
.52701 .30672 Mdot
.74315 .27102 Mdot
.22083 .63078 Mdot
.23339 .19984 Mdot
.26035 .87578 Mdot
.42459 .98333 Mdot
.95102 .21289 Mdot
.39729 .88589 Mdot
.83493 .31332 Mdot
.91406 .37807 Mdot
.28574 .30404 Mdot
.40998 .06713 Mdot
.9827 .22108 Mdot
.89166 .57052 Mdot
.53611 .81616 Mdot
.43041 .58955 Mdot
.50457 .71068 Mdot
.23994 .38489 Mdot
.32637 .72136 Mdot
.61746 .27169 Mdot
.7142 .63473 Mdot
.93039 .11609 Mdot
.65221 .54987 Mdot
.29597 .2814 Mdot
.44305 .55402 Mdot
.63112 .4869 Mdot
.12743 .96799 Mdot
.96952 .12318 Mdot
.40896 .02953 Mdot
.96588 .50866 Mdot
.85818 .08398 Mdot
.11935 .01303 Mdot
.36953 .6785 Mdot
.4143 .11815 Mdot
.49363 .90643 Mdot
.34221 .61433 Mdot
.27235 .57709 Mdot
.93408 .34662 Mdot
.91696 .38521 Mdot
.7328 .45179 Mdot
.72931 .57818 Mdot
.99444 .16704 Mdot
.64763 .26862 Mdot
.65209 .37945 Mdot
.50529 .81448 Mdot
.01637 .48757 Mdot
.78625 .68841 Mdot
.89958 .65266 Mdot
.73899 .32977 Mdot
.74503 .07636 Mdot
.60377 .7216 Mdot
.78806 .85504 Mdot
.09847 .36496 Mdot
.0201 .45631 Mdot
.2235 .32094 Mdot
.14039 .30038 Mdot
.94799 .73073 Mdot
.35238 .03891 Mdot
.39049 .82374 Mdot
.6747 .60814 Mdot
.8727 .26409 Mdot
.70502 .30308 Mdot
.49525 .77155 Mdot
.14312 .68234 Mdot
.62551 .17912 Mdot
.35136 .45068 Mdot
.17436 .63015 Mdot
.97971 .92655 Mdot
.00033 .13154 Mdot
.85823 .11329 Mdot
.84408 .07752 Mdot
.40705 .28238 Mdot
.74712 .59351 Mdot
.47539 .2004 Mdot
.47783 .04481 Mdot
.55487 .29257 Mdot
.62669 .08789 Mdot
.4304 .06906 Mdot
.67253 .67934 Mdot
.6671 .91674 Mdot
.44486 .32616 Mdot
.583 .0266 Mdot
.82493 .46651 Mdot
.40472 .9721 Mdot
.85798 .65891 Mdot
.70136 .99798 Mdot
.60156 .38572 Mdot
.37211 .47301 Mdot
.20183 .07454 Mdot
.72459 .63517 Mdot
.30497 .62329 Mdot
.28024 .48704 Mdot
.0847 .51882 Mdot
.47442 .23534 Mdot
.48389 .2729 Mdot
.29724 .48762 Mdot
.39966 .38833 Mdot
.37616 .72226 Mdot
.5729 .22546 Mdot
.77335 .4658 Mdot
.59769 .92774 Mdot
.82594 .61521 Mdot
.06213 .0834 Mdot
.76747 .34681 Mdot
.20373 .78486 Mdot
.06339 .88933 Mdot
.50128 .74262 Mdot
.54401 .16924 Mdot
.3249 .12339 Mdot
.39708 .22379 Mdot
.52857 .12044 Mdot
.40286 .97923 Mdot
.15903 .41662 Mdot
.34829 .58947 Mdot
.86757 .11157 Mdot
.80516 .46177 Mdot
.88463 .09965 Mdot
.96617 .35386 Mdot
.16332 .58961 Mdot
.19749 .41193 Mdot
.6097 .24104 Mdot
.02368 .95977 Mdot
.85273 .89996 Mdot
.40571 .20818 Mdot
.92099 .7022 Mdot
.27857 .39266 Mdot
.28306 .81074 Mdot
.24498 .15297 Mdot
.61882 .48177 Mdot
.50383 .57561 Mdot
.24024 .11918 Mdot
.53203 .38609 Mdot
.85314 .65692 Mdot
.72952 .19927 Mdot
.77275 .98182 Mdot
.10237 .21754 Mdot
.6211 .05055 Mdot
.04979 .59772 Mdot
.11252 .46473 Mdot
.57921 .67078 Mdot
.71902 .76164 Mdot
.29977 .87236 Mdot
.25903 .86108 Mdot
.54469 .26175 Mdot
.63155 .98773 Mdot
.03375 .83991 Mdot
.08369 .23308 Mdot
.7117 .85102 Mdot
.24227 .95815 Mdot
.88498 .01941 Mdot
.89695 .71864 Mdot
.08294 .57293 Mdot
.41084 .1898 Mdot
.99792 .9262 Mdot
.92853 .09852 Mdot
.23219 .43694 Mdot
.52377 .34094 Mdot
.41907 .37481 Mdot
.21442 .3332 Mdot
.48387 .75742 Mdot
.19813 .15085 Mdot
.82416 .96345 Mdot
.0775 .20584 Mdot
.96982 .15559 Mdot
.8893 .24239 Mdot
.74259 .46075 Mdot
.74 .3655 Mdot
.28647 .24904 Mdot
.44713 .80301 Mdot
.08993 .64791 Mdot
.00522 .69505 Mdot
.38391 .12111 Mdot
.02823 .3136 Mdot
.78146 .38382 Mdot
.72447 .88674 Mdot
.03159 .00438 Mdot
.05961 .41464 Mdot
.0678 .31672 Mdot
.5442 .27037 Mdot
.55896 .28981 Mdot
.32571 .69021 Mdot
.69113 .41266 Mdot
.09716 .22777 Mdot
.0901 .51913 Mdot
.29989 .68328 Mdot
.07635 .35797 Mdot
.34825 .02397 Mdot
.26432 .57905 Mdot
.51144 .38334 Mdot
.96923 .03814 Mdot
.74313 .88339 Mdot
.1885 .97326 Mdot
.6395 .41412 Mdot
.71819 .78165 Mdot
.31575 .41628 Mdot
.40965 .03353 Mdot
.79207 .96386 Mdot
.56028 .90295 Mdot
.67613 .71546 Mdot
.068 .54683 Mdot
.94363 .55492 Mdot
.87 .28173 Mdot
.4208 .44353 Mdot
.90705 .08523 Mdot
.55854 .80356 Mdot
.96704 .53351 Mdot
.46198 .60777 Mdot
.32921 .27401 Mdot
.44666 .87318 Mdot
.99935 .59555 Mdot
.9887 .93795 Mdot
.15905 .27275 Mdot
.82758 .15102 Mdot
.06484 .21275 Mdot
.18475 .93577 Mdot
.3846 .90371 Mdot
.85207 .91055 Mdot
.19455 .59172 Mdot
.60966 .52241 Mdot
.63981 .09203 Mdot
.93945 .87735 Mdot
.41595 .27049 Mdot
.17461 .17038 Mdot
.48403 .77196 Mdot
.57379 .79029 Mdot
.6413 .78491 Mdot
.16217 .07946 Mdot
.4886 .65653 Mdot
.5454 .94408 Mdot
.06538 .28666 Mdot
.15701 .6434 Mdot
.65432 .41645 Mdot
.9858 .54628 Mdot
.00804 .923 Mdot
.58306 .60404 Mdot
.31172 .92649 Mdot
.23628 .04113 Mdot
.88851 .36511 Mdot
.29127 .18923 Mdot
.62681 .4879 Mdot
.97593 .01495 Mdot
.33652 .42818 Mdot
.04964 .60017 Mdot
.90684 .78529 Mdot
.83283 .83147 Mdot
.66957 .08467 Mdot
.02679 .00621 Mdot
.58831 .93537 Mdot
.02174 .18732 Mdot
.92117 .79587 Mdot
.95185 .22603 Mdot
.51614 .52629 Mdot
.74875 .9868 Mdot
.95593 .3217 Mdot
.93092 .61517 Mdot
.27307 .31496 Mdot
.31301 .55903 Mdot
.3809 .00125 Mdot
.05958 .32692 Mdot
.01207 .8433 Mdot
.25874 .91904 Mdot
.32022 .27444 Mdot
.08483 .91218 Mdot
.02949 .52211 Mdot
.11163 .69852 Mdot
.8473 .4189 Mdot
.9618 .30832 Mdot
.34975 .32936 Mdot
.86736 .97452 Mdot
.191 .10787 Mdot
.03245 .87048 Mdot
.94865 .0406 Mdot
.99741 .73124 Mdot
.85662 .98951 Mdot
.6874 .59585 Mdot
.05668 .24109 Mdot
.35621 .66775 Mdot
.98298 .60145 Mdot
.16793 .5847 Mdot
.40883 .49037 Mdot
.07198 .38514 Mdot
.43915 .61264 Mdot
.25994 .73669 Mdot
.26292 .35336 Mdot
.49281 .78921 Mdot
.6278 .58599 Mdot
.57748 .97108 Mdot
.79953 .11467 Mdot
.4513 .08043 Mdot
.58813 .28985 Mdot
.05402 .72002 Mdot
.40879 .02623 Mdot
.7599 .56232 Mdot
.74011 .63484 Mdot
.72513 .04819 Mdot
.7015 .05638 Mdot
.46176 .0353 Mdot
.29426 .69317 Mdot
.65989 .83608 Mdot
.72081 .35328 Mdot
.97907 .98073 Mdot
.90413 .84255 Mdot
.14831 .03658 Mdot
.7286 .03851 Mdot
.17032 .69413 Mdot
.76088 .62549 Mdot
.22566 .87394 Mdot
.83903 .34205 Mdot
.98943 .61354 Mdot
.76796 .87496 Mdot
.55593 .55687 Mdot
.27125 .74029 Mdot
.35348 .79889 Mdot
.59414 .68361 Mdot
.42546 .99106 Mdot
.64177 .86843 Mdot
.47843 .06945 Mdot
.10285 .46537 Mdot
.03452 .41973 Mdot
.49208 .34756 Mdot
.81284 .03201 Mdot
.50022 .24821 Mdot
.48555 .25134 Mdot
.45072 .72854 Mdot
.91265 .22342 Mdot
.08341 .82755 Mdot
.26293 .46226 Mdot
.21763 .72763 Mdot
.01039 .1667 Mdot
.88928 .03374 Mdot
.20672 .5204 Mdot
.62636 .91382 Mdot
.16344 .71565 Mdot
.89652 .89336 Mdot
.90563 .69648 Mdot
.67406 .38173 Mdot
.77227 .68966 Mdot
.81205 .33195 Mdot
.28434 .00088 Mdot
.82315 .83425 Mdot
.49775 .05888 Mdot
.70603 .57383 Mdot
.51373 .31006 Mdot
.31167 .88043 Mdot
.12149 .36969 Mdot
.63372 .21446 Mdot
.43979 .45 Mdot
.73354 .61158 Mdot
.44991 .99002 Mdot
.14287 .04943 Mdot
.93568 .76557 Mdot
.55022 .4399 Mdot
.67267 .92946 Mdot
.61774 .64979 Mdot
.92898 .84674 Mdot
.08367 .99403 Mdot
.03726 .70357 Mdot
.68149 .00821 Mdot
.37148 .0236 Mdot
.71951 .17124 Mdot
.1428 .80971 Mdot
.35148 .90189 Mdot
.97741 .82148 Mdot
.02642 .68372 Mdot
.53544 .66799 Mdot
.18 .80956 Mdot
.37983 .0444 Mdot
.86645 .04147 Mdot
.56553 .56403 Mdot
.41543 .26103 Mdot
.97391 .31583 Mdot
.47134 .31139 Mdot
.05261 .28118 Mdot
.34671 .63415 Mdot
.84329 .23652 Mdot
.0969 .18188 Mdot
.08469 .34991 Mdot
.14337 .14378 Mdot
.48066 .5318 Mdot
.04708 .88028 Mdot
.13915 .18884 Mdot
.41151 .845 Mdot
.93746 .09786 Mdot
.71607 .30287 Mdot
.12049 .58787 Mdot
.59616 .8943 Mdot
.04453 .12687 Mdot
.72118 .94112 Mdot
.74093 .54986 Mdot
.34952 .57174 Mdot
.48723 .79167 Mdot
.52227 .4667 Mdot
.11627 .82398 Mdot
.88179 .8515 Mdot
.40443 .95439 Mdot
.95051 .31704 Mdot
.50826 .14084 Mdot
.12727 .64739 Mdot
.23348 .242 Mdot
.63473 .48947 Mdot
.26839 .46511 Mdot
.05889 .14472 Mdot
.01478 .45142 Mdot
.75838 .44612 Mdot
.66933 .85436 Mdot
.64812 .37254 Mdot
.49587 .12281 Mdot
.47927 .28034 Mdot
.20943 .75345 Mdot
.57196 .40218 Mdot
.75321 .28878 Mdot
.71468 .69828 Mdot
.70623 .60129 Mdot
.43353 .77768 Mdot
.47205 .91981 Mdot
.88916 .55073 Mdot
.57656 .29212 Mdot
.01027 .95396 Mdot
.30426 .39598 Mdot
.31735 .89634 Mdot
.87155 .41253 Mdot
.96601 .26194 Mdot
.89335 .34346 Mdot
.0249 .34942 Mdot
.40796 .52287 Mdot
.82273 .3448 Mdot
.71391 .37454 Mdot
.15283 .02195 Mdot
.36275 .30975 Mdot
.36469 .29106 Mdot
.8295 .13976 Mdot
.82849 .61991 Mdot
.19037 .50032 Mdot
.0843 .12926 Mdot
.07071 .37679 Mdot
.83688 .56224 Mdot
.88678 .0797 Mdot
.79049 .9825 Mdot
.9481 .4758 Mdot
.85777 .18918 Mdot
.80438 .38816 Mdot
.71711 .68005 Mdot
.74745 .47531 Mdot
.66677 .2796 Mdot
.34001 .75485 Mdot
.35655 .37559 Mdot
.49077 .59974 Mdot
.74157 .59449 Mdot
.83108 .7521 Mdot
.72907 .38206 Mdot
.65867 .04164 Mdot
.09509 .97065 Mdot
.07292 .87863 Mdot
.60432 .51618 Mdot
.55051 .62512 Mdot
.71228 .00926 Mdot
.99099 .64725 Mdot
.13398 .85826 Mdot
.72412 .26897 Mdot
.61232 .48466 Mdot
.66806 .29518 Mdot
.65748 .32416 Mdot
.23069 .03243 Mdot
.78516 .12972 Mdot
.9341 .371 Mdot
.40955 .84195 Mdot
.15449 .52217 Mdot
.46813 .60746 Mdot
.39648 .10636 Mdot
.1084 .97256 Mdot
.89118 .05953 Mdot
.72131 .71007 Mdot
.00309 .53794 Mdot
.83867 .60608 Mdot
.993 .73442 Mdot
.83039 .70025 Mdot
.83401 .1287 Mdot
.64966 .63523 Mdot
.9018 .83777 Mdot
.95756 .25102 Mdot
.28796 .95154 Mdot
.62108 .05758 Mdot
.6156 .66923 Mdot
.12519 .57442 Mdot
.39269 .35272 Mdot
.51092 .1949 Mdot
.62528 .84958 Mdot
.45343 .26979 Mdot
.56769 .48489 Mdot
.0316 .4123 Mdot
.89009 .88587 Mdot
.29759 .38641 Mdot
.38388 .15395 Mdot
.45247 .55118 Mdot
.9889 .26326 Mdot
.55731 .75336 Mdot
.37725 .68535 Mdot
.81811 .7849 Mdot
.97515 .06063 Mdot
.59412 .28405 Mdot
.18374 .79959 Mdot
.3391 .64166 Mdot
.51664 .14398 Mdot
.81788 .0299 Mdot
.90668 .21182 Mdot
.59057 .70655 Mdot
.69131 .17636 Mdot
.80816 .17845 Mdot
.08747 .27082 Mdot
.2102 .17048 Mdot
.34466 .9824 Mdot
.84558 .11273 Mdot
.93394 .95566 Mdot
.2788 .24386 Mdot
.64705 .03583 Mdot
.24156 .98617 Mdot
.96236 .04723 Mdot
.87086 .05642 Mdot
.04467 .644 Mdot
.83683 .10251 Mdot
.73244 .60591 Mdot
.85337 .70802 Mdot
.61774 .84786 Mdot
.24058 .81649 Mdot
.90635 .66896 Mdot
.73346 .80277 Mdot
.03227 .84957 Mdot
.72014 .59015 Mdot
.30035 .03188 Mdot
.62185 .76037 Mdot
.47687 .16217 Mdot
.55708 .88286 Mdot
.51671 .33465 Mdot
.47986 .95159 Mdot
.67363 .26456 Mdot
.01424 .35988 Mdot
.99248 .82719 Mdot
.05818 .33708 Mdot
.72944 .75428 Mdot
.56508 .97867 Mdot
.66403 .94471 Mdot
.16119 .99734 Mdot
.96087 .01197 Mdot
.82843 .33461 Mdot
.67749 .89858 Mdot
.13153 .61107 Mdot
.77428 .40461 Mdot
.88907 .02311 Mdot
.55905 .8031 Mdot
.60454 .46383 Mdot
.6004 .82434 Mdot
.26563 .70974 Mdot
.15842 .65167 Mdot
.88047 .49659 Mdot
.9673 .86984 Mdot
.27107 .38067 Mdot
.52305 .74811 Mdot
.91177 .99598 Mdot
.52207 .11438 Mdot
.25253 .74102 Mdot
.18762 .08782 Mdot
.4275 .05792 Mdot
.36618 .49016 Mdot
.38029 .12175 Mdot
.98341 .61177 Mdot
.27443 .40155 Mdot
.23415 .51392 Mdot
.22603 .24661 Mdot
.93895 .99737 Mdot
.08831 .47618 Mdot
.19293 .65438 Mdot
.06057 .50892 Mdot
.23207 .34333 Mdot
.85962 .68006 Mdot
.63962 .07714 Mdot
.25426 .33073 Mdot
.43445 .69483 Mdot
.20094 .15884 Mdot
.42576 .95075 Mdot
.7503 .68871 Mdot
.70861 .17614 Mdot
.88982 .43005 Mdot
.73731 .29265 Mdot
.60753 .70398 Mdot
.28653 .17774 Mdot
.96883 .24617 Mdot
.8683 .87906 Mdot
.94141 .69524 Mdot
.21393 .95903 Mdot
.51058 .76291 Mdot
.00878 .78543 Mdot
.9828 .85674 Mdot
.53451 .83209 Mdot
.87195 .19111 Mdot
.02004 .30646 Mdot
.03962 .27367 Mdot
.5106 .35779 Mdot
.84395 .2466 Mdot
.41474 .70846 Mdot
.12457 .78224 Mdot
.42871 .52646 Mdot
.39373 .80153 Mdot
.18977 .51849 Mdot
.63045 .17268 Mdot
.8835 .91922 Mdot
.53673 .75827 Mdot
.09348 .37528 Mdot
.72062 .25415 Mdot
.35682 .24297 Mdot
.6542 .22816 Mdot
.1659 .76091 Mdot
.2997 .66473 Mdot
.51061 .00923 Mdot
.68416 .64263 Mdot
.5443 .71921 Mdot
.83128 .23974 Mdot
.88723 .02606 Mdot
.06965 .71075 Mdot
.56854 .4237 Mdot
.57547 .23256 Mdot
.99305 .40474 Mdot
.14215 .23254 Mdot
.04728 .86995 Mdot
.61799 .33433 Mdot
.31874 .63669 Mdot
.15288 .92254 Mdot
.99627 .14304 Mdot
.10532 .44974 Mdot
.33628 .34089 Mdot
.80676 .96286 Mdot
.54048 .69213 Mdot
.46486 .95487 Mdot
.32964 .06062 Mdot
.08957 .95036 Mdot
.04733 .96894 Mdot
.69604 .38734 Mdot
.95962 .55458 Mdot
.31256 .24432 Mdot
.73798 .18424 Mdot
.43241 .56395 Mdot
.6287 .07065 Mdot
.39842 .3766 Mdot
.86434 .60732 Mdot
.16434 .65032 Mdot
.7593 .31903 Mdot
.85277 .92574 Mdot
.48473 .13136 Mdot
.37921 .75727 Mdot
.75037 .80379 Mdot
.83986 .28862 Mdot
.78459 .38644 Mdot
.6363 .95021 Mdot
.38208 .53941 Mdot
.00737 .34312 Mdot
.2985 .16142 Mdot
.07182 .46935 Mdot
.75988 .61277 Mdot
.44299 .77081 Mdot
.50265 .25582 Mdot
.29221 .78467 Mdot
.97832 .68118 Mdot
.66982 .26592 Mdot
.96132 .06997 Mdot
.26063 .54047 Mdot
.80722 .29959 Mdot
.03076 .42272 Mdot
.73696 .36601 Mdot
.73116 .73251 Mdot
.75009 .98438 Mdot
.51563 .1845 Mdot
.47176 .50084 Mdot
.00592 .62397 Mdot
.72291 .04442 Mdot
.55842 .13004 Mdot
.53033 .20135 Mdot
.52036 .36064 Mdot
.94329 .67895 Mdot
.27146 .16495 Mdot
.4315 .53045 Mdot
.31233 .20756 Mdot
.45671 .77532 Mdot
.01764 .79904 Mdot
.20329 .05029 Mdot
.79438 .39505 Mdot
.26232 .77588 Mdot
.46314 .04207 Mdot
.50547 .80025 Mdot
.16652 .45357 Mdot
.78825 .89866 Mdot
.66925 .51745 Mdot
.12542 .58889 Mdot
.1346 .53373 Mdot
.89366 .041 Mdot
.33718 .50497 Mdot
.90981 .77374 Mdot
.32034 .33588 Mdot
.43068 .771 Mdot
.63148 .51249 Mdot
.14618 .19649 Mdot
.69352 .8388 Mdot
.13606 .07659 Mdot
.79885 .09107 Mdot
.2332 .7068 Mdot
.88812 .78831 Mdot
.11292 .88974 Mdot
.32799 .05233 Mdot
.43111 .89507 Mdot
.22779 .49119 Mdot
.77198 .90046 Mdot
.82036 .19864 Mdot
.85147 .93344 Mdot
.90469 .58945 Mdot
.48677 .62581 Mdot
.32735 .27268 Mdot
.48193 .69608 Mdot
.66326 .71411 Mdot
.13725 .03017 Mdot
.10793 .88726 Mdot
.93684 .90498 Mdot
.65816 .61734 Mdot
.94147 .22972 Mdot
.06649 .19079 Mdot
.31398 .53122 Mdot
.93543 .83288 Mdot
.60112 .12824 Mdot
.8338 .33043 Mdot
.34587 .21154 Mdot
.39676 .39408 Mdot
.9813 .40594 Mdot
.51255 .73821 Mdot
.26856 .27733 Mdot
.62372 .33845 Mdot
.55773 .81823 Mdot
.78125 .92375 Mdot
.01609 .51143 Mdot
.06532 .87091 Mdot
.63838 .61017 Mdot
.45904 .75812 Mdot
.06734 .17465 Mdot
.83198 .13895 Mdot
.30995 .99379 Mdot
.54967 .17451 Mdot
.81867 .93597 Mdot
.70134 .05662 Mdot
.49359 .89475 Mdot
.13925 .35997 Mdot
.2499 .60383 Mdot
.84591 .26652 Mdot
.83722 .77478 Mdot
.61038 .73494 Mdot
.54183 .37275 Mdot
.55067 .36815 Mdot
.45448 .60727 Mdot
.77754 .4156 Mdot
.41197 .44358 Mdot
.85064 .1349 Mdot
.14714 .32392 Mdot
.93047 .00222 Mdot
.67214 .94694 Mdot
.85959 .95818 Mdot
.05296 .94483 Mdot
.47891 .44789 Mdot
.73975 .34412 Mdot
.70325 .85484 Mdot
.05485 .96094 Mdot
.69885 .65717 Mdot
.86674 .28849 Mdot
.62366 .29177 Mdot
.4997 .19057 Mdot
.4613 .5181 Mdot
.60321 .02186 Mdot
.37319 .79052 Mdot
.76666 .30201 Mdot
.11644 .11796 Mdot
.25289 .18599 Mdot
.64146 .48772 Mdot
.97575 .44544 Mdot
.1651 .61071 Mdot
.33094 .93328 Mdot
.3176 .54168 Mdot
.60745 .9663 Mdot
.63044 .79817 Mdot
.77609 .72158 Mdot
.48371 .23248 Mdot
.22923 .18673 Mdot
.13554 .34106 Mdot
.19614 .22901 Mdot
.27329 .62676 Mdot
.00019 .55091 Mdot
.33277 .78996 Mdot
.89445 .84986 Mdot
.23627 .47209 Mdot
.06884 .10888 Mdot
.37748 .4486 Mdot
.51861 .16554 Mdot
.12358 .44116 Mdot
.05959 .75485 Mdot
.75847 .3263 Mdot
.08392 .75224 Mdot
.26033 .47953 Mdot
.86077 .9721 Mdot
.70846 .46359 Mdot
.7386 .34845 Mdot
.69902 .76947 Mdot
.44352 .46821 Mdot
.54344 .08882 Mdot
.14846 .08336 Mdot
.64874 .86901 Mdot
.31036 .10244 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00Ko
oooo0_l00005ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool2o`0000Co
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`;o00001Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00Kooooo0_l00005ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool00_ooool001kooooo00?o0000ooooooooool01Oooool3o`0000Gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool01_ooool2o`0000Gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`06ooooo`;o00001Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo
000Nooooo`03o`000?oooooooooo00Gooooo0_l0002Kooooo`;o00001?ooool2o`0002oooooo0_l0
0008ooooo`;o0000@?ooool2o`0001Wooooo0_l00005ooooo`007_ooool00ol0003oooooooooo`0S
ooooo`;o0000OOooool2o`0003Gooooo0_l00008ooooo`;o0000@?ooool2o`0000gooooo0_l0000:
ooooo`;o00001Oooool001kooooo00?o0000ooooooooool08oooool2o`000?oooooo4?ooool2o`00
00?ooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`3ooooooagooooo0_l0000Kooooo`;o
00003?ooool001kooooo00?o0000ooooooooool0;_ooool2o`00093ooooo0_l0001Jooooo`?o0000
:?ooool001kooooo00?o0000ooooooooool0;_ooool2o`0003Gooooo0_l00006ooooo`;o00001_oo
ool2o`0004Wooooo0_l0000Uooooo`;o0000=?ooool2o`0002Sooooo000Nooooo`03o`000?oooooo
oooo06Gooooo0_l00006ooooo`;o00001_ooool2o`0000[ooooo0_l0000fooooo`;o0000;?ooool2
o`0003?ooooo0ol0000Xooooo`007_ooool00ol0003oooooooooo`0Yooooo`;o0000<oooool2o`00
027ooooo0_l0000fooooo`;o0000BOooool4o`0001Cooooo0_l0000Yooooo`007_ooool00ol0003o
ooooooooo`0Yooooo`;o00007?ooool2o`0001Gooooo0_l0000Qooooo`;o0000POooool4o`0001Go
oooo0_l0000Xooooo`007_ooool00ol0003oooooooooo`0/ooooo`;o00006Oooool2o`0003Sooooo
0_l0000?ooooo`;o0000>_ooool2o`0004gooooo0_l0000Hooooo`;o00003_ooool001kooooo00?o
0000ooooooooool01oooool2o`0002?ooooo0_l0000Kooooo`;o00008oooool2o`0002;ooooo0_l0
000jooooo`;o00006Oooool2o`0003?ooooo0_l0000@ooooo`;o00001Oooool2o`0000kooooo000N
ooooo`03o`000?oooooooooo00Oooooo0_l00010ooooo`;o00008oooool2o`0000Oooooo0_l0000I
ooooo`;o0000?_ooool2o`0001?ooooo1?l0000[ooooo`;o00001_ooool2o`00013ooooo0_l0000E
ooooo`007_ooool00ol0003oooooooooo`1gooooo`;o00006Oooool2o`0000?ooooo0_l0000coooo
o`;o00001?ooool2o`0001?ooooo0_l00003ooooo`;o0000:?ooool2o`0001gooooo0_l0000@oooo
o`007_ooool00ol0003oooooooooo`0Zooooo`;o00004_ooool2o`0005Oooooo0_l0000]ooooo`;o
00001?ooool2o`0001[ooooo0_l00002ooooo`;o0000Aoooool2o`00013ooooo000Nooooo`;o0000
:oooool2o`0001;ooooo0_l0000Wooooo`;o0000GOooool2o`00023ooooo0_l0000Gooooo`;o0000
A?ooool001kooooo00?o0000ooooooooool0Ioooool2o`0007Oooooo0_l0000Oooooo`;o00005?oo
ool2o`0002kooooo000Nooooo`03o`000?oooooooooo08Oooooo0_l0000Eooooo`;o00003Oooool2
o`0001Oooooo0_l0000Hooooo`;o0000=Oooool2o`0000Gooooo0_l0000Wooooo`007_ooool00ol0
003oooooooooo`02o`0006Gooooo0_l0000Nooooo`;o00005Oooool2o`0000gooooo0_l0000Goooo
o`;o0000E_ooool2o`0001Wooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`02o`0004Go
oooo0_l0000Nooooo`;o0000d?ooool2o`0000cooooo000Nooooo`03o`000?oooooooooo04Oooooo
0_l0000hooooo`;o00001Oooool2o`000;gooooo000Nooooo`03o`000?oooooooooo087ooooo0_l0
0005ooooo`;o00003Oooool2o`0002oooooo0_l0001Zooooo`;o00004Oooool001kooooo00?o0000
ooooooooool0?Oooool2o`0005Sooooo0_l0000_ooooo`;o0000J_ooool2o`00017ooooo000Noooo
o`03o`000?oooooooooo02Sooooo0_l0000Cooooo`;o0000SOooool2o`00023ooooo0_l0000Noooo
o`;o0000=oooool001kooooo00?o0000ooooooooool0:?ooool2o`0000Oooooo0_l0001Looooo`;o
00002Oooool2o`00033ooooo0_l0000Pooooo`;o00007_ooool2o`0000cooooo0_l0000Yooooo`00
7_ooool00ol0003oooooooooo`0@ooooo`;o00006_ooool2o`0000?ooooo0_l0001Looooo`;o0000
2Oooool2o`0001;ooooo0_l0001Sooooo`;o00001oooool2o`0002Wooooo000Nooooo`03o`000?oo
oooooooo013ooooo0_l0000Jooooo`;o0000P?ooool2o`0001?ooooo0_l0000Aooooo`;o0000>ooo
ool2o`0000kooooo0_l0000Rooooo`007_ooool00ol0003oooooooooo`0iooooo`;o0000L_ooool2
o`0001Cooooo0_l00003ooooo`;o00003?ooool2o`0004_ooooo0_l0000Rooooo`007_ooool00ol0
003oooooooooo`0iooooo`;o0000L_ooool2o`0001Wooooo0_l00002ooooo`;o0000<_ooool2o`00
04Gooooo000Nooooo`03o`000?oooooooooo0<cooooo0_l0000booooo`;o0000AOooool001kooooo
00?o0000ooooooooool0f_ooool2o`0002gooooo0_l0000@ooooo`;o00003Oooool2o`000003oooo
ool0003o000001Sooooo000Nooooo`;o0000H_ooool2o`0007Oooooo0_l0000]ooooo`;o000000?o
ooooo`000?l000002oooool4o`0000gooooo0_l000000ooooooo0000o`00000Hooooo`007_ooool0
0ol0003oooooooooo`1Qooooo`;o0000<oooool2o`0007Cooooo0_l0000;ooooo`;o00005Oooool2
o`0001Gooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0000Vooooo`;o0000@Oooool2o`00
01Oooooo0_l0002Hooooo`;o00005Oooool001kooooo00?o0000ooooooooool04_ooool2o`000003
ooooool0003o000002?ooooo0_l00011ooooo`;o0000Uoooool2o`0002oooooo000Nooooo`03o`00
0?oooooooooo01Gooooo0_l0000Xooooo`;o0000IOooool2o`0005Sooooo0_l0000=ooooo`;o0000
0_ooool2o`000003ooooool0003o000002oooooo000Nooooo`03o`000?oooooooooo02;ooooo0_l0
000Kooooo`;o0000@_ooool2o`00027ooooo0_l0001Hooooo`;o00003Oooool2o`0000;ooooo0_l0
000Eooooo`;o00006oooool001kooooo00?o0000ooooooooool08_ooool2o`0002Kooooo0_l0000]
ooooo`;o00002?ooool2o`0002?ooooo0_l00020ooooo`;o00006oooool001kooooo00?o0000oooo
ooooool0B_ooool2o`0001[ooooo0_l0000@ooooo`?o00008_ooool2o`0000Wooooo0_l0002=oooo
o`;o00003_ooool001kooooo00?o0000ooooooooool02_ooool2o`0005[ooooo0_l0000@ooooo`?o
00008_ooool2o`0009Sooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o0000
2oooool2o`00063ooooo0_l0000fooooo`;o00003?ooool2o`0003[ooooo0_l0000>ooooo`;o0000
>_ooool001gooooo0_l0000Iooooo`;o0000P?ooool2o`0001Kooooo0_l0000<ooooo`;o00007Ooo
ool2o`0001_ooooo0_l0000>ooooo`;o0000>_ooool001gooooo0_l0002Kooooo`;o0000@oooool2
o`00033ooooo0_l0000eooooo`007_ooool00ol0003oooooooooo`1cooooo`;o0000UOooool2o`00
00Cooooo0_l0000eooooo`007_ooool00ol0003oooooooooo`1cooooo`;o0000;?ooool2o`0006Oo
oooo0_l0000kooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o00006Oooool2o`0000cooooo
0_l0001Wooooo`;o000000?oooooo`000?l00000V_ooool2o`0000Gooooo000Nooooo`03o`000?oo
oooooooo00oooooo0_l0000Iooooo`;o00003?ooool2o`00067ooooo0_l00007ooooo`;o0000V_oo
ool2o`0000Gooooo000Nooooo`;o00008_ooool2o`0001Wooooo0_l0000Hooooo`;o0000@oooool2
o`0006cooooo0_l0000looooo`007_ooool00ol0003oooooooooo`0Qooooo`;o00006Oooool2o`00
00kooooo0_l00008ooooo`;o00008Oooool2o`0008kooooo0_l0000looooo`007_ooool00ol0003o
ooooooooo`1<ooooo`;o0000:oooool2o`000;cooooo0_l0000>ooooo`007_ooool00ol0003ooooo
ooooo`0mooooo`;o0000K_ooool2o`0008Sooooo0_l0000>ooooo`007_ooool00ol0003ooooooooo
o`0mooooo`;o00007_ooool2o`0003Sooooo0_l0000Dooooo`;o0000V?ooool001kooooo00Co0000
ooooool0003o0000Doooool2o`0000Oooooo0_l0000hooooo`;o00002oooool2o`0009Wooooo0_l0
0006ooooo`007_ooool01?l0003oooooo`000?l0000dooooo`;o00002Oooool2o`0001;ooooo0_l0
001>ooooo`;o00001oooool2o`00093ooooo0_l00006ooooo`007_ooool00ol0003oooooooooo`0e
ooooo`;o00002Oooool2o`0006_ooooo0_l0000Jooooo`;o00006oooool2o`0005oooooo000Noooo
o`03o`000?oooooooooo01;ooooo0_l00018ooooo`;o0000DOooool2o`0001Sooooo0_l0000Boooo
o`;o00000oooool2o`0000;ooooo0_l0000gooooo`;o00009_ooool001kooooo00?o0000oooooooo
ool04_ooool2o`0004Gooooo0_l000000ooooooo0000o`00001Aooooo`;o00002_ooool2o`0000So
oooo1?l0000Dooooo`;o00000oooool2o`0001oooooo0_l0000Jooooo`;o00009_ooool001kooooo
00?o0000ooooooooool06oooool2o`0000gooooo0_l0000]ooooo`;o0000H?ooool2o`0000Sooooo
1?l0000jooooo`;o0000@_ooool001kooooo00?o0000ooooooooool06oooool2o`0000gooooo0_l0
001hooooo`;o0000A_ooool2o`0005Wooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0000T
ooooo`;o00006oooool2o`0000Kooooo0_l0001Dooooo`;o0000A_ooool2o`0005Wooooo000Noooo
o`03o`000?oooooooooo00?ooooo0_l0000<ooooo`;o00005_ooool2o`0001_ooooo0_l00006oooo
o`;o00002oooool2o`0002Cooooo0_l0000Kooooo`;o0000Loooool2o`0000;ooooo0_l0000^oooo
o`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0
003oooooooooo`0Aooooo`;o0000B?ooool2o`0002Cooooo0_l0000Kooooo`;o00000_ooool2o`00
02_ooooo0_l00012ooooo`;o00000_ooool2o`0002kooooo0003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooo
oooo02_ooooo0_l0001eooooo`;o0000:oooool2o`0007Kooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`?o0000:oooool2o`0001_ooooo0_l0001<
ooooo`;o00004?ooool2o`0003oooooo0_l0000Looooo`;o0000?_ooool000?ooooo00Go0000oooo
ooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0B?ooool2
o`0004cooooo0_l0000;ooooo`;o00000oooool2o`0003oooooo0_l0000Looooo`;o00007Oooool2
o`0001oooooo0003ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05
ooooo`03o`000?oooooooooo01Gooooo0_l0002<ooooo`;o0000POooool2o`0001oooooo0003oooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01Gooooo0_l0001:ooooo`;o00007Oooool2o`000<Gooooo0003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool04Ooo
ool2o`00023ooooo0_l0000/ooooo`;o00002Oooool2o`0001;ooooo0_l0002Qooooo`;o00003?oo
ool2o`0001Cooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`00
0?lQ8B7oc<c<00Kooooo00?o0000ooooooooool04Oooool2o`00023ooooo0_l0000gooooo`;o0000
G?ooool2o`0005Oooooo0_l0000<ooooo`;o00005?ooool001kooooo00?o0000ooooooooool07Ooo
ool2o`0008Wooooo0_l0000Pooooo`;o0000C_ooool2o`0002_ooooo000Nooooo`03o`000?oooooo
oooo01gooooo0_l00021ooooo`;o00001_ooool2o`0006gooooo0_l000000ooooooo0000o`00000O
ooooo`;o00002_ooool001kooooo00?o0000ooooooooool0OOooool2o`00027ooooo0_l0000Doooo
o`;o00003?ooool2o`00057ooooo0_l0000<ooooo`;o00005?ooool2o`0000[ooooo000Nooooo`03
o`000?oooooooooo01_ooooo0_l0000Oooooo`;o0000?oooool2o`0003Oooooo0_l0000<ooooo`;o
00002oooool2o`0004Cooooo0_l0000<ooooo`;o00002_ooool2o`0001Cooooo000Nooooo`03o`00
0?oooooooooo01_ooooo0_l0000Oooooo`;o0000Toooool2o`0003Sooooo0_l0000:ooooo`;o0000
5Oooool2o`000003ooooool0003o000001Cooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0
000Aooooo`;o0000KOooool2o`0001cooooo0_l0001Booooo`;o00008Oooool2o`0001Oooooo000N
ooooo`03o`000?oooooooooo01Oooooo0_l0000Aooooo`;o0000J_ooool2o`000003ooooool0003o
000001cooooo0_l0001Eooooo`;o0000=oooool001kooooo00?o0000ooooooooool03_ooool2o`00
05Kooooo0_l0000^ooooo`;o0000:_ooool2o`0004Kooooo0_l00002ooooo`;o0000=oooool001ko
oooo00?o0000ooooooooool03_ooool2o`0003Sooooo0_l0000=ooooo`;o00002?ooool2o`0000?o
oooo0_l00008ooooo`;o0000D?ooool2o`0004Kooooo0_l0000Aooooo`;o0000:?ooool001kooooo
00Co0000ooooool0003o0000A?ooool2o`000003ooooool0003o000000gooooo0_l00008ooooo`;o
00003Oooool2o`0009cooooo0_l0000=ooooo`;o00006?ooool2o`0000kooooo000Nooooo`04o`00
0?oooooo0000o`0001oooooo0_l0000Iooooo`;o00002?ooool2o`0001;ooooo0_l00014ooooo`;o
0000KOooool2o`0002Oooooo0_l0000>ooooo`007_ooool2o`0001Gooooo0_l0000:ooooo`;o0000
6Oooool2o`0001cooooo0_l0000oooooo`;o00000oooool2o`0005kooooo0_l0000booooo`;o0000
4_ooool001kooooo00?o0000ooooooooool03Oooool2o`0000Gooooo0_l00024ooooo`;o00000ooo
ool2o`0004Gooooo0_l0000Gooooo`;o0000<_ooool2o`0001;ooooo000Nooooo`03o`000?oooooo
oooo00gooooo0_l0000jooooo`;o0000E?ooool2o`0004Gooooo0_l0001Oooooo`007_ooool00ol0
003oooooooooo`19ooooo`Co0000=_ooool2o`0002Sooooo0_l00027ooooo`;o00003oooool001ko
oooo00?o0000ooooooooool0Boooool2o`0003Kooooo0_l0000Xooooo`;o00003?ooool2o`0001Wo
oooo0ol0000oooooo`;o00007?ooool2o`0000Gooooo0_l00008ooooo`007_ooool00ol0003ooooo
ooooo`2kooooo`;o00004Oooool2o`0000Kooooo0ol0000>ooooo`;o00009_ooool2o`0000Oooooo
0_l0000Sooooo`;o00002?ooool001kooooo00?o0000ooooooooool06?ooool2o`0000Cooooo0_l0
001Sooooo`;o00002_ooool2o`0001cooooo0_l0000Fooooo`;o00001oooool2o`0001Oooooo0_l0
0004ooooo`;o00008?ooool2o`0003Kooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0000=
ooooo`;o00001?ooool2o`00013ooooo0_l0000booooo`Go00006_ooool2o`0000[ooooo0_l00008
ooooo`;o00004_ooool2o`0000?ooooo0_l0000Aooooo`;o00009_ooool2o`0005Sooooo000Noooo
o`03o`000?oooooooooo00Wooooo0_l0000Uooooo`;o00008Oooool2o`0000oooooo1Ol0000<oooo
o`;o00008_ooool2o`0001Oooooo0_l0002Cooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o
0000A?ooool2o`00023ooooo0_l0000Qooooo`;o0000>oooool2o`00073ooooo000Nooooo`03o`00
0?oooooooooo00gooooo0_l0001=ooooo`;o00008_ooool2o`0001Kooooo0_l0000Sooooo`;o0000
5_ooool4o`0003;ooooo0_l0000:ooooo`;o0000;_ooool001kooooo00?o0000ooooooooool04Ooo
ool2o`0004Wooooo0_l00009ooooo`;o00005oooool2o`0003_ooooo0_l0000Hooooo`;o0000<_oo
ool2o`0000[ooooo0_l0000^ooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o0000E?ooool2
o`0004Wooooo0_l00007ooooo`;o0000=?ooool2o`0000cooooo0_l0000<ooooo`;o00001oooool2
o`0002oooooo000Nooooo`03o`000?oooooooooo07;ooooo0_l0000looooo`Co00000oooool2o`00
00;ooooo0_l0000:ooooo`;o00008oooool2o`0000?ooooo0_l0000<ooooo`;o00003?ooool2o`00
00Oooooo0_l0000_ooooo`007_ooool00ol0003oooooooooo`1booooo`;o0000??ooool2o`0000Go
oooo0_l0000>ooooo`;o00003?ooool2o`0001Gooooo0_l0001Iooooo`007_ooool00ol0003ooooo
ooooo`3Eooooo`;o0000:oooool2o`0004?ooooo000Nooooo`;o0000:oooool2o`000<Wooooo0_l0
000;ooooo`;o0000@oooool001kooooo00?o0000ooooooooool00_l0000Xooooo`;o0000;Oooool2
o`00057ooooo0_l0000cooooo`;o00000_ooool2o`0000kooooo0_l0001@ooooo`007_ooool00ol0
003oooooooooo`04o`0005Gooooo0_l0001<ooooo`?o00000_ooool2o`0003?ooooo0_l00002oooo
o`;o0000C_ooool2o`00013ooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0001^ooooo`;o
00008Oooool2o`0000cooooo0_l00002ooooo`?o0000Roooool2o`00013ooooo000Nooooo`03o`00
0?oooooooooo00Gooooo0_l0001>ooooo`;o00006oooool2o`0000;ooooo0_l0000Mooooo`;o0000
3?ooool2o`0006Kooooo0_l0000jooooo`007_ooool00ol0003oooooooooo`05ooooo`;o00002ooo
ool2o`00047ooooo0_l0000Oooooo`;o0000Toooool2o`0002Cooooo0_l00006ooooo`;o00003?oo
ool001kooooo00?o0000ooooooooool04_ooool2o`00037ooooo0_l0002/ooooo`;o0000??ooool2
o`0000Kooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`0/ooooo`;o00005oooool2o`00
05Sooooo0_l0000aooooo`;o00007oooool2o`0003kooooo0_l0000Booooo`007_ooool00ol0003o
ooooooooo`0?ooooo`;o00006oooool2o`0005oooooo0_l0000@ooooo`;o0000<Oooool2o`0001ko
oooo0_l0000oooooo`;o00004_ooool001kooooo00?o0000ooooooooool03oooool2o`0005gooooo
0_l0000Jooooo`;o000000?oooooo`000?l000008?ooool2o`0003_ooooo0_l00004ooooo`;o0000
5oooool2o`0003[ooooo000Nooooo`03o`000?oooooooooo04;ooooo0_l0000;ooooo`;o00007Ooo
ool2o`0001[ooooo0_l0000Sooooo`;o0000>oooool2o`0001Kooooo0_l00005ooooo`;o0000>_oo
ool001kooooo00?o0000ooooooooool0@_ooool2o`0000_ooooo0_l0000Cooooo`;o0000?_ooool2
o`0001oooooo0_l0000mooooo`;o00000oooool2o`0003cooooo000Nooooo`03o`000?oooooooooo
00oooooo0_l0001Cooooo`;o0000?_ooool2o`0001oooooo1?l00010ooooo`;o0000??ooool001ko
oooo00?o0000ooooooooool03?ooool2o`000003ooooool0003o000001Oooooo0_l0000oooooo`;o
0000>oooool2o`0001oooooo0_l00014ooooo`;o0000>?ooool001kooooo0ol0000<ooooo`;o0000
6_ooool2o`0001gooooo0_l0000Pooooo`;o0000>oooool2o`0004Cooooo0_l0000Iooooo`;o0000
1?ooool2o`0000oooooo0_l0000Wooooo`007_ooool5o`0004Gooooo0_l0001Cooooo`;o0000??oo
ool2o`0000;ooooo0_l0000<ooooo`;o00001oooool2o`00013ooooo0_l0000Eooooo`;o00003?oo
ool2o`0001Wooooo000Nooooo`;o000000?oooooo`000?l000000_ooool2o`00017ooooo0_l00023
ooooo`;o0000??ooool2o`0000;ooooo0_l0000<ooooo`;o00001oooool2o`0003Gooooo0_l0000I
ooooo`007_ooool00ol0003oooooooooo`04ooooo`;o00004Oooool2o`0003Sooooo0_l0000Yoooo
o`;o0000GOooool2o`0000Wooooo0_l0001>ooooo`;o00003oooool001kooooo00?o0000oooooooo
ool05Oooool2o`0003[ooooo0_l0000Yooooo`;o00009?ooool2o`0003Oooooo0_l00009ooooo`;o
0000C_ooool2o`0000oooooo000Nooooo`04o`000?ooooooooooooooo`;o00004_ooool2o`0001;o
oooo0_l0001gooooo`;o000000?oooooo`000?l00000X?ooool001kooooo00Co0000oooooooooooo
oooo0_l0000Vooooo`;o0000N_ooool2o`0003gooooo0_l0001Qooooo`007_ooool00ol0003ooooo
ooooo`0Looooo`;o0000A_ooool2o`0007kooooo0_l00005ooooo`?o0000;oooool2o`0002Sooooo
000Nooooo`03o`000?oooooooooo01cooooo0_l00005ooooo`;o0000?oooool2o`0004Wooooo0_l0
000jooooo`?o0000;oooool2o`0002Sooooo000Nooooo`03o`000?oooooooooo02?ooooo0_l00027
ooooo`;o000000?oooooo`000?l000007_ooool2o`0005_ooooo0_l0000Iooooo`007_ooool00ol0
003oooooooooo`0Jooooo`;o0000Aoooool2o`0000_ooooo0_l0000;ooooo`;o00001Oooool2o`00
02Kooooo0_l0000Qooooo`;o00004oooool2o`0004Kooooo0_l0000Iooooo`007_ooool00ol0003o
ooooooooo`0Cooooo`;o00001Oooool2o`0004Oooooo0_l0000;ooooo`;o00002oooool2o`0000Go
oooo0_l0001:ooooo`;o00004_ooool2o`0003oooooo0_l0000Pooooo`007_ooool00ol0003ooooo
ooooo`0Cooooo`;o0000?oooool2o`0007[ooooo0_l00005ooooo`;o00004?ooool2o`0003[ooooo
0_l0000Pooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o0000=Oooool2o`0000Sooooo0_l0
001<ooooo`;o00006oooool2o`0001Kooooo0_l0000@ooooo`;o00003oooool2o`0002[ooooo0_l0
000Oooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o0000=Oooool2o`00017ooooo0_l0000O
ooooo`;o00008_ooool2o`0000Gooooo0_l0000Dooooo`;o00004Oooool2o`0000[ooooo0_l0000J
ooooo`?o00001?ooool2o`0002?ooooo0_l0000Oooooo`007_ooool00ol0003oooooooooo`1Moooo
o`;o00007oooool2o`0002Wooooo0_l0000Wooooo`;o00002_ooool2o`0001_ooooo0_l00004oooo
o`;o0000A?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`00
0003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0E_ooool2o`0002Gooooo0_l0001ooooo
o`;o0000Aoooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo05Kooooo0_l00007ooooo`;o00007?ooool2o`00
07oooooo0_l00017ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006oooo
o`?o0000Goooool2o`000>Kooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01?m4
A4CogMgMooooool00007ooooo`03o`000?oooooooooo05Gooooo0_l0001Oooooo`;o0000Soooool0
00?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o
0000ooooooooool0EOooool2o`0005oooooo0_l00010ooooo`;o0000@Oooool2o`0000;ooooo0_l0
0006ooooo`000oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001ooo
ool00ol0003oooooooooo`3hooooo`;o0000@Oooool2o`0000;ooooo0_l00006ooooo`000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0003ooooooooo
o`06ooooo`;o0000=?ooool2o`0009oooooo0_l0000Kooooo`;o00001Oooool2o`0001Cooooo0_l0
000^ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_oo
ool00ol0003oooooooooo`06ooooo`;o00001oooool2o`0001oooooo0_l0000:ooooo`;o00009Ooo
ool2o`0006Oooooo0_l00003ooooo`;o00002_ooool2o`0001[ooooo0ol00005ooooo`;o00005?oo
ool2o`0001Wooooo0_l0000Cooooo`007_ooool00ol0003oooooooooo`07ooooo`;o00001_ooool2
o`0001oooooo0_l0000aooooo`;o0000Ioooool2o`0000?ooooo0_l0000Vooooo`;o00005?ooool2
o`00027ooooo0_l0000Cooooo`007_ooool00ol0003oooooooooo`06ooooo`?o0000Hoooool2o`00
0:7ooooo0_l0000fooooo`007_ooool00ol0003oooooooooo`06ooooo`;o0000I?ooool2o`0004Oo
oooo0_l0002@ooooo`007_ooool00ol0003oooooooooo`1Yooooo`;o0000B_ooool2o`00093ooooo
000Nooooo`03o`000?oooooooooo06Wooooo0_l0002booooo`;o0000:?ooool001kooooo00?o0000
ooooooooool0U?ooool2o`0008Oooooo0_l0000Xooooo`007_ooool00ol0003oooooooooo`17oooo
o`;o0000Boooool2o`000;7ooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0000Iooooo`;o
00008Oooool2o`0006Kooooo0_l0002Fooooo`007_ooool00ol0003oooooooooo`09ooooo`;o0000
6Oooool2o`0005cooooo0_l000000ooooooo0000o`00000Xooooo`;o0000U_ooool001kooooo00?o
0000ooooooooool0P_ooool2o`000003ooooool0003o000006_ooooo0_l00015ooooo`;o00003?oo
ool001kooooo00?o0000ooooooooool07_ooool2o`0005Oooooo0_l0000Booooo`;o00002oooool2
o`0005Sooooo0_l00015ooooo`;o00003?ooool001kooooo0_l00002ooooo`;o00006oooool2o`00
01;ooooo0_l0000jooooo`;o00001oooool2o`0001;ooooo0_l0000;ooooo`;o00004oooool2o`00
03_ooooo0_l0001Kooooo`007_ooool01?l0003oooooooooooooool3o`0002;ooooo0_l0000:oooo
o`;o0000>_ooool2o`0003gooooo0_l0000kooooo`;o0000Foooool001kooooo00?o0000oooooooo
ool00_ooool2o`0000Wooooo0_l0000Gooooo`;o0000oooooolPooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`;o0000@_ooool2o`0009[ooooo0_l0000Cooooo`;o0000@oooool001kooooo00?o
0000ooooooooool07Oooool2o`000003ooooool0003o000001?ooooo0_l0000Jooooo`Co0000Jooo
ool2o`00023ooooo0_l00009ooooo`;o00002?ooool2o`0000Wooooo0_l00013ooooo`007_ooool0
0ol0003oooooooooo`0Mooooo`;o000000?oooooo`000?l000004oooool2o`0001cooooo0_l0000g
ooooo`;o00006?ooool2o`0001Sooooo0_l0000Pooooo`;o00004oooool2o`0000oooooo0_l0000m
ooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o0000Moooool2o`0001Sooooo0_l0001Poooo
o`;o0000?Oooool001kooooo00?o0000ooooooooool04oooool2o`0003Cooooo0_l0000Zooooo`;o
0000d?ooool001kooooo00?o0000ooooooooool06Oooool2o`0002kooooo0_l0000Zooooo`;o0000
8Oooool2o`0005Gooooo0_l0000oooooo`;o00005Oooool001kooooo00?o0000ooooooooool06Ooo
ool2o`0003Kooooo0_l00015ooooo`;o0000EOooool2o`0003oooooo0_l0000Eooooo`007_ooool0
0ol0003oooooooooo`1Aooooo`;o0000L_ooool2o`00083ooooo000Nooooo`03o`000?oooooooooo
05Oooooo0_l0001Kooooo`;o00003Oooool4o`0000;ooooo0_l0001looooo`007_ooool01?l0003o
ooooooooooooool2o`0005Cooooo0_l00004ooooo`;o00005?ooool2o`0000cooooo0_l0000aoooo
o`;o00003Oooool2o`0000?ooooo1_l0001iooooo`007_ooool01?l0003oooooooooooooool2o`00
04?ooooo0_l0000Eooooo`;o00000_ooool2o`00013ooooo0_l0000<ooooo`;o0000AOooool6o`00
07Wooooo000Nooooo`03o`000?oooooooooo04Kooooo0_l0000Iooooo`;o0000]oooool2o`0002_o
oooo000Nooooo`03o`000?oooooooooo03Gooooo0_l0003Sooooo`;o0000:oooool001kooooo0_l0
000dooooo`Co00000oooool2o`0005Wooooo0_l0002`ooooo`007_ooool00ol0003oooooooooo`0c
ooooo`;o00001Oooool2o`0002kooooo0_l0000Yooooo`;o0000/?ooool001kooooo00?o0000oooo
ooooool04?ooool2o`0005Sooooo0_l0003:ooooo`;o00003oooool001kooooo00Co0000oooooooo
oooooooo0_l0000=ooooo`;o00001Oooool2o`000?oooooo7_ooool2o`0000oooooo000Nooooo`04
o`000?ooooooooooooooo`;o00005?ooool2o`0002oooooo0_l0001oooooo`;o0000O?ooool001ko
oooo00?o0000ooooooooool0B?ooool2o`0004Sooooo0_l0000/ooooo`Co00001Oooool2o`0000Wo
oooo0ol0001`ooooo`007_ooool00ol0003oooooooooo`0Gooooo`Co00007oooool2o`0000?ooooo
0_l0001Aooooo`;o0000;?ooool4o`00013ooooo0ol0000cooooo`;o00009?ooool2o`0001Gooooo
000Nooooo`03o`000?oooooooooo00Gooooo0_l0000@ooooo`Co00004oooool2o`0000Sooooo1?l0
0003ooooo`;o0000@?ooool2o`0003oooooo0_l00016ooooo`;o00009?ooool2o`0001Gooooo000N
ooooo`03o`000?oooooooooo00Gooooo0_l0000Wooooo`;o00002?ooool2o`0004Oooooo0_l00004
ooooo`;o00006oooool2o`0001cooooo0_l00023ooooo`007_ooool00ol0003oooooooooo`0Hoooo
o`;o0000>?ooool2o`0003?ooooo0ol0000Jooooo`;o0000XOooool001kooooo0ol0000Hooooo`;o
0000>?ooool2o`0000kooooo0_l0000Tooooo`;o00003_ooool2o`0009cooooo0_l0000?ooooo`00
7_ooool3o`0002Sooooo0_l0000hooooo`;o0000=?ooool2o`0009cooooo0_l0000?ooooo`007_oo
ool2o`0002Wooooo0_l0000/ooooo`;o00008?ooool2o`000<gooooo000Nooooo`;o0000D_ooool2
o`0000?ooooo0_l0000;ooooo`;o00004oooool2o`000<gooooo000Nooooo`03o`000?oooooooooo
057ooooo0_l0000@ooooo`;o0000h_ooool001kooooo00?o0000ooooooooool04_ooool2o`000?oo
oooo:Oooool2o`0000Wooooo000Mooooo`?o00004oooool2o`0007_ooooo0_l0000oooooo`;o0000
6oooool2o`0002kooooo0_l0000Mooooo`;o00002Oooool001gooooo0_l0000Qooooo`;o0000Jooo
ool2o`000003ooooool0003o000002gooooo0_l0000@ooooo`;o00006oooool2o`0002kooooo0_l0
000@ooooo`;o00000oooool2o`00017ooooo000Nooooo`03o`000?oooooooooo01oooooo0_l0001[
ooooo`;o00008oooool2o`0000_ooooo0_l00008ooooo`;o0000IOooool2o`0000?ooooo0_l00003
ooooo`;o00003?ooool001kooooo00?o0000ooooooooool0H_ooool2o`0004gooooo0_l0000Eoooo
o`;o0000Koooool2o`0000cooooo000Nooooo`03o`000?oooooooooo06;ooooo0_l0000Tooooo`;o
0000:_ooool2o`0003gooooo0_l0000Gooooo`;o0000>Oooool001kooooo00?o0000ooooooooool0
R?ooool2o`0002[ooooo0_l0000mooooo`;o00005oooool2o`0003Wooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool05oooool2o`0005Gooooo0_l0002^
ooooo`;o00009oooool001kooooo00?o0000ooooooooool05oooool2o`0000cooooo0_l0000]oooo
o`;o00006?ooool2o`00033ooooo0_l0000oooooo`;o0000>oooool2o`0002Oooooo000Nooooo`03
o`000?oooooooooo02Gooooo0_l0000[ooooo`Co0000B_ooool2o`0003oooooo0_l00006ooooo`;o
0000G?ooool001kooooo00?o0000ooooooooool0D_ooool4o`0009?ooooo0_l0000Uooooo`;o0000
=Oooool001kooooo00?o0000ooooooooool03Oooool2o`0002?ooooo0_l0003Looooo`;o0000=Ooo
ool001kooooo00?o0000ooooooooool03Oooool2o`0001Cooooo1?l0000;ooooo`;o0000U?ooool2
o`0007gooooo000Nooooo`03o`000?oooooooooo02?ooooo1?l0000:ooooo`;o00002?ooool2o`00
033ooooo0_l0000Iooooo`;o0000?_ooool2o`0001cooooo0_l0000jooooo`;o00008oooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413o
c<c<00Kooooo00?o0000ooooooooool0<Oooool2o`0000Sooooo0_l0000`ooooo`;o00006Oooool2
o`0005cooooo0_l00005ooooo`Co00009Oooool2o`0000[ooooo0_l0000Sooooo`000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_oo
ool00ol0003oooooooooo`0<ooooo`;o0000cOooool2o`00013ooooo1?l0000Uooooo`;o0000:Ooo
ool2o`0000Cooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000000Kooooo0ol0000<ooooo`;o0000SOooool2o`0003kooooo0_l0001Tooooo`;o0000
1?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ
8B401_ooool00ol0003oooooooooo`0<ooooo`;o0000=Oooool2o`0000Sooooo0_l0001<ooooo`;o
00002Oooool2o`00017ooooo0_l0000Vooooo`;o0000F?ooool2o`0000[ooooo0003ooooo`05o`00
0?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000oooo
ooooool0@oooool2o`0000Sooooo0_l00011ooooo`;o00005?ooool2o`00017ooooo0_l0000Voooo
o`;o00001oooool2o`00027ooooo0_l00006ooooo`;o00001_ooool2o`0001cooooo0_l0000:oooo
o`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0
003oooooooooo`2@ooooo`Ko0000=Oooool2o`0000[ooooo0_l0000Aooooo`;o00008Oooool2o`00
00Kooooo0_l00006ooooo`;o0000:?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool09oooool2o`0000Wooooo0_l0001Goooo
o`;o00001Oooool4o`0003Gooooo0_l0000:ooooo`;o00004Oooool2o`0000Oooooo0_l00017oooo
o`;o00002Oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000
oa0@40Kooooo00?o0000ooooooooool09oooool2o`0000Wooooo0_l0000gooooo`;o00007_ooool2
o`0005gooooo0_l00007ooooo`;o00004oooool2o`00027ooooo0_l0000?ooooo`Co00001oooool0
01kooooo00?o0000ooooooooool0Joooool2o`0006Gooooo0_l0000dooooo`;o00008Oooool2o`00
017ooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`3Booooo`;o0000=Oooool2o`0003co
oooo000Nooooo`?o0000Goooool2o`0003Wooooo0_l0000Cooooo`;o0000@_ooool2o`0001Cooooo
0_l0000looooo`007_ooool3o`0005Gooooo0_l00008ooooo`;o00009oooool2o`00013ooooo0_l0
000Cooooo`;o0000@_ooool2o`0005;ooooo000Nooooo`03o`000?oooooooooo03Gooooo0_l0000=
ooooo`;o00003oooool2o`00037ooooo0_l0002mooooo`007_ooool00ol0003oooooooooo`0eoooo
o`;o00003Oooool2o`0002Oooooo0_l0001eooooo`;o00001oooool2o`0005Sooooo000Nooooo`03
o`000?oooooooooo06Cooooo0_l00007ooooo`;o00007?ooool2o`0000Sooooo0_l0000hooooo`;o
00004oooool2o`000003ooooool0003o000000Cooooo0_l0001Hooooo`007_ooool00ol0003ooooo
ooooo`1Tooooo`;o00009Oooool2o`0000Sooooo0_l0000hooooo`;o00005_ooool2o`0005kooooo
000Nooooo`03o`000?oooooooooo00[ooooo0_l0000Sooooo`;o0000>Oooool2o`0006kooooo0_l0
001Hooooo`;o00004Oooool001kooooo00?o0000ooooooooool02_ooool2o`0002?ooooo0_l0000i
ooooo`;o0000K_ooool2o`0005Sooooo0_l00008ooooo`;o00001oooool001kooooo00?o0000oooo
ooooool06Oooool2o`0000[ooooo0_l0000:ooooo`;o0000T_ooool2o`0007Oooooo0_l00007oooo
o`007_ooool2o`0001[ooooo0_l0000:ooooo`;o00002?ooool4o`0001Oooooo0_l0001iooooo`;o
0000B?ooool2o`0000oooooo0_l0000Uooooo`007_ooool00ol0003oooooooooo`0_ooooo`;o0000
2_ooool2o`0000gooooo0_l0001?ooooo`;o0000L_ooool2o`0000oooooo0_l0000Uooooo`007_oo
ool00ol0003oooooooooo`0kooooo`;o0000G_ooool2o`0004;ooooo0_l0000`ooooo`Co0000<_oo
ool001kooooo00?o0000ooooooooool0goooool2o`00033ooooo1?l0000booooo`007_ooool00ol0
003oooooooooo`1Mooooo`;o0000;oooool2o`0005Sooooo0_l0001Mooooo`007_ooool00ol0003o
ooooooooo`1Mooooo`;o00004Oooool2o`0001cooooo0_l0000Jooooo`;o0000??ooool2o`0001;o
oooo0_l00019ooooo`007_ooool00ol0003oooooooooo`12ooooo`;o0000;?ooool2o`0003Sooooo
0_l0000<ooooo`;o00002_ooool2o`0003Kooooo0_l0000Uooooo`;o00008_ooool001kooooo00?o
0000ooooooooool0@_ooool2o`0002Oooooo0_l0001;ooooo`;o00002_ooool2o`0005gooooo0_l0
000Rooooo`007_ooool00ol0003oooooooooo`1[ooooo`;o0000f_ooool001kooooo00?o0000oooo
ooooool0H?ooool2o`0001;ooooo0_l0001Qooooo`;o00003?ooool2o`0002cooooo0_l0000Joooo
o`;o00002Oooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0000Tooooo`;o
0000<Oooool2o`000003ooooool0003o000001;ooooo0_l00017ooooo`;o00006?ooool2o`0000co
oooo0_l0000/ooooo`;o00006_ooool2o`0000Wooooo0_l0000;ooooo`007_ooool00ol0003ooooo
ooooo`04ooooo`;o00009?ooool2o`00037ooooo0_l0000Hooooo`;o0000A?ooool2o`0008Sooooo
000Nooooo`03o`000?oooooooooo06Kooooo0_l0000?ooooo`;o0000Moooool2o`0000Gooooo0_l0
0003ooooo`;o0000BOooool001kooooo00?o0000ooooooooool0G?ooool2o`0000Sooooo0_l00014
ooooo`;o0000=?ooool2o`0000cooooo0_l00005ooooo`;o00000oooool2o`0004Wooooo000Noooo
o`?o0000<oooool2o`0002Oooooo0_l0000[ooooo`;o00003_ooool2o`00017ooooo0_l0000doooo
o`;o0000?_ooool2o`0000[ooooo0_l0000Gooooo`007_ooool3o`00023ooooo0_l0000Aooooo`;o
0000E?ooool2o`0000kooooo0_l00019ooooo`;o0000??ooool2o`0000[ooooo0_l0000Gooooo`00
7_ooool2o`00027ooooo0_l00032ooooo`;o00009?ooool2o`0001_ooooo0_l0000Nooooo`007_oo
ool00ol0003oooooooooo`08ooooo`;o00005_ooool2o`0009oooooo0_l00017ooooo`;o00006ooo
ool2o`0001kooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0000nooooo`;o0000>Oooool2
o`0003;ooooo0_l00003ooooo`;o00000oooool2o`0004kooooo0_l0000dooooo`007_ooool00ol0
003oooooooooo`0Cooooo`;o0000<oooool2o`0000Sooooo0_l0000_ooooo`;o00006oooool2o`00
01Gooooo0_l00003ooooo`;o00005?ooool2o`00017ooooo0ol0000Yooooo`;o00007?ooool2o`00
01Kooooo000Nooooo`03o`000?oooooooooo01?ooooo0_l0000Oooooo`;o00007?ooool2o`0004co
oooo0_l0000`ooooo`Co00003oooool3o`0004Oooooo0_l0000Fooooo`007_ooool00ol0003ooooo
ooooo`0aooooo`;o000000?oooooo`000?l00000J?ooool2o`0003Cooooo0_l00002ooooo`;o0000
KOooool001kooooo00?o0000ooooooooool03Oooool2o`0002;ooooo0_l0001[ooooo`;o00003Ooo
ool2o`0002Wooooo0_l00015ooooo`;o00009_ooool001kooooo00?o0000ooooooooool03Oooool2
o`0005Oooooo0_l0000>ooooo`;o0000=Oooool2o`00017ooooo0_l0000fooooo`;o00009Oooool2
o`0002Kooooo000Nooooo`03o`000?oooooooooo06Kooooo0_l0000>ooooo`;o0000B?ooool2o`00
03Kooooo0_l0001=ooooo`007_ooool00ol0003oooooooooo`13ooooo`;o0000=_ooool2o`00017o
oooo0_l0002gooooo`007_ooool00ol0003oooooooooo`13ooooo`;o0000=_ooool2o`00017ooooo
0_l0001Aooooo`;o00001oooool2o`0000?ooooo0_l0000oooooo`;o00003_ooool2o`0000Gooooo
000Nooooo`03o`000?oooooooooo0<;ooooo0_l0000Mooooo`;o00001oooool2o`0000?ooooo0_l0
000oooooo`;o00002oooool5o`0000Gooooo000Nooooo`03o`000?oooooooooo053ooooo0_l0001A
ooooo`;o00003Oooool2o`0000kooooo0_l0001iooooo`Co00001_ooool001kooooo00?o0000oooo
ooooool0C_ooool4o`0000;ooooo0_l00019ooooo`;o00000_ooool2o`0000gooooo0_l0002Coooo
o`007_ooool00ol0003oooooooooo`1>ooooo`;o00001?ooool2o`0004Wooooo0_l0002Vooooo`00
7_ooool00ol0003oooooooooo`0=ooooo`;o0000Uoooool2o`0009oooooo000Nooooo`;o00003_oo
ool2o`0000Gooooo0_l0002@ooooo`;o0000Woooool001kooooo00?o0000ooooooooool03oooool2
o`0000?ooooo0_l000000ooooooo0000o`00000Wooooo`;o00003?ooool2o`0001[ooooo0_l00015
ooooo`;o0000=_ooool2o`0001oooooo0_l0000Zooooo`;o00003oooool001kooooo00?o0000oooo
ooooool03oooool2o`0000Kooooo0_l0000Wooooo`;o00003?ooool2o`0001[ooooo0_l0000;oooo
o`;o00008?ooool2o`0001Kooooo0_l0000fooooo`;o00007oooool2o`0002[ooooo0_l0000?oooo
o`007_ooool00ol0003oooooooooo`0booooo`;o0000@oooool2o`0001Sooooo0_l00006ooooo`;o
00003oooool2o`0001[ooooo0_l0000Tooooo`;o0000FOooool001kooooo00?o0000ooooooooool0
<_ooool2o`0005gooooo0_l0000?ooooo`;o00001_ooool2o`0001[ooooo0_l0000Nooooo`;o0000
1?ooool2o`0005Wooooo000Nooooo`03o`000?oooooooooo0:;ooooo0_l00012ooooo`;o0000A?oo
ool2o`0001Wooooo000Nooooo`03o`000?oooooooooo0=oooooo0_l0001;ooooo`;o00006Oooool0
01kooooo00?o0000ooooooooool0R?ooool2o`0000;ooooo0_l0000;ooooo`;o00000_ooool2o`00
043ooooo0_l0001Vooooo`007_ooool00ol0003oooooooooo`1Aooooo`;o0000=Oooool2o`0000;o
oooo0_l00002ooooo`;o00001oooool2o`0000;ooooo0_l0001]ooooo`;o00005_ooool2o`00027o
oooo000Nooooo`03o`000?oooooooooo04Kooooo0_l00009ooooo`;o0000=_ooool2o`0000Gooooo
0_l0001jooooo`;o00005_ooool2o`00027ooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l0
000Pooooo`;o00005_ooool2o`0002Wooooo0_l0001Jooooo`;o0000H?ooool001kooooo00Co0000
ooooool0003o00003?ooool2o`0001Gooooo0_l0000Hooooo`;o00006oooool2o`000003ooooool0
003o000006cooooo0_l0000Gooooo`;o00007oooool2o`0001_ooooo0_l0000Rooooo`007_ooool0
1?l0003oooooo`000?l0000<ooooo`;o0000;oooool2o`0001_ooooo0_l0001_ooooo`;o0000>?oo
ool2o`0001Gooooo0_l00004ooooo`;o00008_ooool001kooooo00Co0000ooooool0003o00008?oo
ool2o`0004Gooooo0_l0000;ooooo`;o00008oooool4o`0001Sooooo0_l0000Fooooo`;o00007ooo
ool2o`0002cooooo0_l0000Xooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0Qooooo`;o0000
AOooool2o`0000_ooooo0_l0000Sooooo`Co00006?ooool2o`0001Kooooo0_l0000Oooooo`;o0000
E_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RH
oooooonHV9So8B4Q00Kooooo00?o0000ooooooooool06oooool2o`000?oooooo2oooool2o`0001ko
oooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo0000
00Kooooo0ol00002ooooo`;o00005oooool2o`0001_ooooo0_l0000:ooooo`;o0000:Oooool2o`00
02oooooo0_l0000Wooooo`;o0000G?ooool2o`0001kooooo0003ooooo`05o`000?oooooooooooooo
ool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000ooooooooool00_ooool2
o`0003Cooooo0_l0000:ooooo`;o0000:Oooool2o`0000_ooooo0_l0000?ooooo`;o00004Oooool2
o`0000oooooo0ol0000Eooooo`;o00007oooool2o`0000Cooooo0_l0001Eooooo`000oooool01Ol0
003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oo
oooooooo07cooooo0_l0000?ooooo`;o00008_ooool3o`0003Kooooo0_l00004ooooo`;o0000EOoo
ool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@4100
1_ooool00ol0003oooooooooo`0Zooooo`;o00002_ooool2o`00063ooooo0_l0001gooooo`;o0000
=?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l0
00001_ooool00ol0003oooooooooo`0Zooooo`;o00002_ooool2o`00023ooooo0_l0000nooooo`;o
0000Moooool2o`0003Cooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo
410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0B_ooool2o`0000cooooo0_l00016oooo
o`;o00002?ooool2o`0000gooooo0_l0000@ooooo`;o0000N_ooool001kooooo00?o0000oooooooo
ool0B_ooool2o`0005Cooooo0_l00008ooooo`;o00001Oooool2o`0000Kooooo0_l0000@ooooo`;o
0000N_ooool001kooooo00?o0000ooooooooool0EOooool2o`0005[ooooo0_l00027ooooo`;o0000
2oooool001kooooo00?o0000ooooooooool08_ooool2o`0001Wooooo0_l0000Fooooo`;o00007ooo
ool2o`0000?ooooo0_l00012ooooo`;o0000H_ooool2o`0000cooooo0_l00007ooooo`;o00002ooo
ool001kooooo00?o0000ooooooooool05oooool2o`0000Wooooo0_l0000Iooooo`;o0000=oooool2
o`0000?ooooo0_l00012ooooo`;o0000C?ooool2o`0001Cooooo0_l0000<ooooo`;o00003?ooool2
o`0000Kooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0003booooo`Co0000<?ooool2o`00
00Kooooo000Nooooo`03o`000?oooooooooo0:[ooooo0_l0001Looooo`;o000000?oooooo`000?l0
00007oooool2o`0001Wooooo000Nooooo`03o`000?oooooooooo0:[ooooo0_l00003ooooo`;o0000
8Oooool2o`0003Cooooo0_l0000Gooooo`;o00002Oooool2o`0001Wooooo000Nooooo`03o`000?oo
oooooooo00Oooooo0_l0002Vooooo`;o00008Oooool2o`0000Wooooo0_l00012ooooo`;o00009?oo
ool001kooooo00?o0000ooooooooool00_l00005ooooo`;o0000N?ooool2o`0005[ooooo0_l00013
ooooo`;o00008oooool001kooooo00?o0000ooooooooool00_l00008ooooo`;o0000MOooool3o`00
03kooooo0_l0000Pooooo`;o00002_ooool2o`00033ooooo0_l00006ooooo`;o00006oooool001ko
oooo00?o0000ooooooooool01_ooool2o`0000;ooooo0_l0001fooooo`;o0000?_ooool2o`000003
ooooool0003o000000;o00006oooool2o`0000[ooooo0_l0000]ooooo`;o00002Oooool2o`0001_o
oooo000Nooooo`;o00001oooool2o`000;gooooo1?l0000Jooooo`;o00001_ooool2o`0002kooooo
0_l00002ooooo`;o00009_ooool001kooooo00?o0000ooooooooool0JOooool2o`0006[ooooo0_l0
000:ooooo`Co00001_ooool2o`0000oooooo0_l0000Mooooo`;o0000:_ooool001kooooo00?o0000
ooooooooool09oooool2o`00043ooooo0_l0001Zooooo`;o00002_ooool2o`0001Wooooo0_l0000m
ooooo`;o00002_ooool001kooooo00?o0000ooooooooool09oooool2o`0002Oooooo0_l0000joooo
o`;o0000R_ooool2o`00027ooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`1@ooooo`;o
0000>_ooool2o`0008[ooooo0_l0000]ooooo`007_ooool00ol0003oooooooooo`3=ooooo`;o0000
N?ooool001kooooo00?o0000ooooooooool01_ooool2o`0000?ooooo0_l00004ooooo`;o0000^_oo
ool4o`0006Gooooo0_l0000?ooooo`007_ooool00ol0003oooooooooo`06ooooo`;o00000oooool2
o`0000Cooooo0_l0000booooo`;o00005_ooool2o`0002kooooo0_l00010ooooo`;o00009Oooool2
o`0003kooooo0_l0000?ooooo`007_ooool00ol0003oooooooooo`15ooooo`;o00002_ooool2o`00
00[ooooo0_l0000^ooooo`;o0000Ioooool2o`0000Sooooo0_l0000[ooooo`;o00006?ooool001ko
oooo00?o0000ooooooooool02oooool2o`0000Oooooo0_l0000kooooo`;o00003_ooool2o`0005Oo
oooo0_l0000fooooo`;o00003?ooool2o`0001Cooooo0_l0000Eooooo`;o00006?ooool001kooooo
00?o0000ooooooooool02oooool2o`0000Oooooo0_l0001;ooooo`;o0000C_ooool2o`0000Oooooo
0_l0000aooooo`;o00000oooool2o`0002;ooooo0_l0000_ooooo`007_ooool00ol0003ooooooooo
o`0Oooooo`;o0000G?ooool2o`0003;ooooo0_l0000dooooo`;o00001?ooool2o`0002kooooo0_l0
000Xooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o00003Oooool4o`0005[ooooo0_l0000/
ooooo`;o0000>_ooool2o`0003Cooooo0_l0000Xooooo`007_ooool00ol0003oooooooooo`0@oooo
o`;o00003oooool2o`0008Sooooo0_l0001booooo`;o00009_ooool001kooooo00?o0000oooooooo
ool06_ooool2o`0004Oooooo0_l0000Sooooo`;o00004_ooool2o`00023ooooo0_l0001Oooooo`;o
00009_ooool001kooooo00?o0000ooooooooool06_ooool2o`0001gooooo0_l0000Xooooo`;o0000
8oooool2o`0001;ooooo0_l0000Pooooo`;o00006?ooool2o`0002;ooooo0_l00019ooooo`007_oo
ool2o`0001Gooooo0_l0000Sooooo`;o0000<oooool2o`0006Sooooo0_l0000Mooooo`;o00000ooo
ool2o`0001?ooooo0_l0000dooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o0000F?ooool2
o`0000Wooooo0_l0000gooooo`;o0000@oooool2o`0001Sooooo0_l0000Iooooo`;o00006Oooool0
01kooooo00?o0000ooooooooool0NOooool2o`00027ooooo0_l0000Dooooo`;o0000N?ooool2o`00
01Wooooo000Nooooo`03o`000?oooooooooo09cooooo0_l0000iooooo`;o0000>?ooool2o`0003Co
oooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0002_ooooo`;o00003Oooool2o`0003Sooooo
0_l0000dooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o0000[oooool2o`0000_ooooo0_l0
001`ooooo`007_ooool00ol0003oooooooooo`1@ooooo`;o0000@oooool2o`0003kooooo0_l00014
ooooo`;o0000:_ooool001kooooo0ol0000^ooooo`;o00008?ooool2o`0004?ooooo0_l0001@oooo
o`;o00004Oooool2o`0001Cooooo0_l00009ooooo`;o0000:_ooool001kooooo0ol0000^ooooo`;o
0000<Oooool2o`0008Cooooo0_l0000Aooooo`;o00005?ooool3o`0002Oooooo0_l00004ooooo`;o
00001Oooool001kooooo00?o0000ooooooooool0HOooool2o`0005_ooooo0_l0000Gooooo`;o0000
>?ooool2o`0002Oooooo0_l00004ooooo`;o00001Oooool001kooooo00?o0000ooooooooool0Iooo
ool2o`0005Gooooo0_l0000Gooooo`;o0000K_ooool001kooooo00?o0000ooooooooool0>?ooool2
o`0002gooooo0_l0000dooooo`;o00007?ooool2o`0004Wooooo0_l00009ooooo`;o0000=?ooool0
01kooooo00?o0000ooooooooool0>?ooool2o`0006?ooooo0_l0000Looooo`;o0000BOooool2o`00
00Wooooo0_l0000Zooooo`;o00002?ooool001kooooo00?o0000ooooooooool0i_ooool2o`0005Go
oooo0_l00008ooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o0000W_ooool2o`0002Gooooo
0_l0000@ooooo`;o0000Goooool001kooooo00?o0000ooooooooool03Oooool2o`0009kooooo0_l0
000Uooooo`Co0000Koooool001kooooo0_l0000Jooooo`;o0000?oooool2o`0002[ooooo0_l0000@
ooooo`;o0000<Oooool2o`0000Wooooo0_l0001_ooooo`007_ooool01?l0003oooooo`000?l0000H
ooooo`;o0000?oooool2o`0002?ooooo0_l00005ooooo`;o00002oooool2o`0000?ooooo0_l0000a
ooooo`;o0000N_ooool001kooooo00Co0000ooooool0003o0000O_ooool2o`0001;ooooo0_l0002G
ooooo`;o00006Oooool001kooooo00?o0000ooooooooool01?ooool2o`0000Sooooo0_l0000aoooo
o`;o00002?ooool2o`000<Kooooo0_l0000Gooooo`;o00006Oooool001kooooo00?o0000oooooooo
ool01?ooool2o`0000Sooooo0_l0000aooooo`;o00002?ooool2o`000;3ooooo0_l00003ooooo`;o
00001?ooool2o`0000Wooooo0_l0000booooo`007_ooool00ol0003oooooooooo`0[ooooo`;o0000
U?ooool2o`0003[ooooo0_l00003ooooo`;o00001?ooool2o`0003gooooo000Nooooo`03o`000?oo
oooooooo00_ooooo0_l0000Hooooo`;o00001?ooool2o`00013ooooo0_l00022ooooo`;o0000Q?oo
ool001kooooo00?o0000ooooooooool02oooool2o`0000kooooo0_l00002ooooo`;o00001?ooool2
o`0001;ooooo0_l00002ooooo`;o0000@?ooool2o`0003Oooooo0_l0000Zooooo`;o0000;_ooool2
o`00037ooooo000Nooooo`03o`000?oooooooooo01_ooooo0_l00002ooooo`;o00006?ooool2o`00
04Cooooo0_l0000gooooo`;o0000:_ooool2o`0002kooooo1?l0000@ooooo`;o00007Oooool001ko
oooo00?o0000ooooooooool0Ooooool2o`0003?ooooo0_l0000;ooooo`;o0000Doooool2o`00013o
oooo0_l0000Mooooo`007_ooool00ol0003oooooooooo`1/ooooo`;o00004Oooool2o`0003?ooooo
0_l0000;ooooo`;o0000=?ooool2o`0000Cooooo0_l0000kooooo`;o00002oooool001kooooo00?o
0000ooooooooool0K?ooool2o`0001Sooooo0_l0001Xooooo`;o00001Oooool2o`0000Cooooo0_l0
000kooooo`;o00002oooool001kooooo00?o0000ooooooooool0B_ooool2o`0003[ooooo0_l00011
ooooo`;o00009?ooool3o`0005Gooooo000Nooooo`03o`000?oooooooooo04[ooooo0_l0000joooo
o`;o00001_ooool2o`0003Wooooo0_l0000Tooooo`;o00008Oooool2o`0002;ooooo0_l0000?oooo
o`005?ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool05oooool2o`0004So
oooo0_l0000Sooooo`;o00001_ooool2o`0008;ooooo0_l0000Rooooo`;o00003oooool001Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Gooooo`;o00005oooool2o`0002oooooo
0_l0001mooooo`;o0000@_ooool2o`0000Oooooo0_l0000Hooooo`005_ooool00ol0003ooooooooo
o`05ooooo`?o0000<?ooool2o`000:kooooo0_l00012ooooo`;o00001oooool2o`0001Sooooo000F
ooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@oooo
o`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?oooooo
D?ooool001Cooooo00?oEEEEofIVI_l00000oooooomBooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.60019 .21144 Mdot
.56655 .50439 Mdot
.98083 .52684 Mdot
.40258 .61077 Mdot
.57037 .91962 Mdot
.72776 .80367 Mdot
.66557 .6664 Mdot
.9578 .84184 Mdot
.33632 .2971 Mdot
.07724 .89625 Mdot
.32564 .39294 Mdot
.1843 .09879 Mdot
.9945 .44438 Mdot
.35045 .86486 Mdot
.74859 .65721 Mdot
.67164 .98636 Mdot
.90503 .00766 Mdot
.21084 .90999 Mdot
.52055 .07664 Mdot
.98165 .34714 Mdot
.91087 .04482 Mdot
.17226 .17732 Mdot
.31571 .38067 Mdot
.72173 .81254 Mdot
.58871 .19792 Mdot
.09912 .22169 Mdot
.1086 .81479 Mdot
.15414 .50377 Mdot
.93243 .53796 Mdot
.20454 .85806 Mdot
.68574 .74159 Mdot
.95497 .78966 Mdot
.0464 .41919 Mdot
.05143 .33608 Mdot
.45858 .76784 Mdot
.60234 .25595 Mdot
.59504 .84592 Mdot
.22929 .76529 Mdot
.75531 .75103 Mdot
.80811 .53023 Mdot
.55124 .47482 Mdot
.86803 .9452 Mdot
.59878 .01486 Mdot
.64367 .41352 Mdot
.28456 .31679 Mdot
.86819 .81613 Mdot
.0972 .27885 Mdot
.5345 .28028 Mdot
.23615 .70944 Mdot
.03483 .78482 Mdot
.20832 .68793 Mdot
.95303 .99184 Mdot
.92937 .94298 Mdot
.36318 .31894 Mdot
.06297 .2041 Mdot
.44795 .17029 Mdot
.51385 .15256 Mdot
.85018 .08812 Mdot
.68616 .14236 Mdot
.58398 .53839 Mdot
.72052 .70553 Mdot
.28487 .01842 Mdot
.23863 .28164 Mdot
.05103 .76171 Mdot
.58535 .06741 Mdot
.95914 .71897 Mdot
.24434 .58827 Mdot
.24037 .80638 Mdot
.46007 .70587 Mdot
.12456 .45158 Mdot
.50694 .29106 Mdot
.27177 .64684 Mdot
.04865 .86438 Mdot
.71353 .90179 Mdot
.54407 .85695 Mdot
.39838 .86878 Mdot
.23174 .51269 Mdot
.70817 .87927 Mdot
.26409 .19744 Mdot
.73119 .33514 Mdot
.07028 .2129 Mdot
.34581 .15948 Mdot
.29222 .19482 Mdot
.80517 .23987 Mdot
.50693 .05948 Mdot
.81922 .617 Mdot
.69025 .47915 Mdot
.14657 .47863 Mdot
.1827 .23328 Mdot
.71208 .32472 Mdot
.65796 .30223 Mdot
.70527 .72158 Mdot
.86304 .82946 Mdot
.64334 .82896 Mdot
.30613 .90028 Mdot
.56725 .85655 Mdot
.06706 .57045 Mdot
.48044 .50488 Mdot
.64424 .82685 Mdot
.05726 .75117 Mdot
.72606 .31827 Mdot
.61824 .15449 Mdot
.79607 .28318 Mdot
.63594 .16374 Mdot
.2081 .7374 Mdot
.26893 .60738 Mdot
.63634 .11072 Mdot
.9764 .48796 Mdot
.29865 .80698 Mdot
.22433 .2465 Mdot
.92268 .25392 Mdot
.43321 .75717 Mdot
.92807 .66184 Mdot
.54688 .33594 Mdot
.39711 .1055 Mdot
.63713 .90097 Mdot
.46047 .63472 Mdot
.6349 .56212 Mdot
.0941 .80234 Mdot
.93075 .81848 Mdot
.53085 .25432 Mdot
.43682 .29209 Mdot
.87635 .26515 Mdot
.2779 .80209 Mdot
.67856 .33108 Mdot
.4587 .73779 Mdot
.55823 .96228 Mdot
.09407 .56681 Mdot
.83127 .59719 Mdot
.18326 .27025 Mdot
.99662 .07194 Mdot
.5252 .18687 Mdot
.74836 .08638 Mdot
.81283 .62686 Mdot
.59791 .08676 Mdot
.81321 .0911 Mdot
.18422 .48059 Mdot
.07942 .0852 Mdot
.89699 .24281 Mdot
.25775 .78746 Mdot
.79825 .37829 Mdot
.80551 .25111 Mdot
.53003 .5859 Mdot
.55247 .33449 Mdot
.05264 .77365 Mdot
.46491 .4429 Mdot
.18332 .95604 Mdot
.92298 .62551 Mdot
.73641 .7518 Mdot
.57161 .26537 Mdot
.11126 .22686 Mdot
.58356 .74907 Mdot
.58377 .11751 Mdot
.51004 .21778 Mdot
.77999 .25971 Mdot
.22472 .15557 Mdot
.99368 .22393 Mdot
.49519 .9783 Mdot
.07406 .54383 Mdot
.8397 .07755 Mdot
.06439 .52474 Mdot
.99036 .08814 Mdot
.22556 .03559 Mdot
.68707 .06891 Mdot
.92076 .18054 Mdot
.9023 .12568 Mdot
.86858 .19226 Mdot
.94689 .70053 Mdot
.14587 .69764 Mdot
.72836 .99076 Mdot
.8015 .41576 Mdot
.1529 .18262 Mdot
.47016 .6263 Mdot
.88696 .82339 Mdot
.97216 .32036 Mdot
.92579 .0245 Mdot
.32335 .40376 Mdot
.75055 .63827 Mdot
.18306 .94577 Mdot
.53584 .66785 Mdot
.30489 .51745 Mdot
.07158 .93803 Mdot
.77424 .82494 Mdot
.18688 .48369 Mdot
.0337 .46837 Mdot
.57535 .93445 Mdot
.78869 .88797 Mdot
.3703 .63767 Mdot
.73604 .75149 Mdot
.34458 .2804 Mdot
.28278 .53174 Mdot
.54227 .34136 Mdot
.71093 .28565 Mdot
.19097 .67317 Mdot
.20859 .19669 Mdot
.27225 .91165 Mdot
.45358 .99594 Mdot
.97259 .24914 Mdot
.39273 .84274 Mdot
.87454 .34007 Mdot
.92053 .36133 Mdot
.26303 .33698 Mdot
.36734 .10169 Mdot
.98932 .26351 Mdot
.92541 .54542 Mdot
.52816 .86125 Mdot
.44306 .61075 Mdot
.53096 .67352 Mdot
.27155 .34994 Mdot
.28531 .69167 Mdot
.60997 .23403 Mdot
.67658 .6243 Mdot
.96105 .13851 Mdot
.68251 .5493 Mdot
.32566 .31699 Mdot
.42108 .55592 Mdot
.67258 .50278 Mdot
.15635 .97155 Mdot
.95068 .1636 Mdot
.37206 .02503 Mdot
.96475 .53768 Mdot
.81732 .06338 Mdot
.07828 .03524 Mdot
.41152 .71511 Mdot
.38895 .16158 Mdot
.46154 .89933 Mdot
.33143 .57745 Mdot
.30532 .61319 Mdot
.92606 .33605 Mdot
.87431 .37257 Mdot
.69555 .44668 Mdot
.76784 .61579 Mdot
.00432 .1783 Mdot
.68266 .28139 Mdot
.65844 .41331 Mdot
.54481 .83495 Mdot
.00502 .52409 Mdot
.81242 .67289 Mdot
.94385 .68308 Mdot
.77725 .32002 Mdot
.75384 .06937 Mdot
.64197 .68002 Mdot
.78842 .89981 Mdot
.14212 .32919 Mdot
.05588 .44192 Mdot
.18686 .3175 Mdot
.12327 .2961 Mdot
.91867 .75195 Mdot
.39421 .04393 Mdot
.38203 .81725 Mdot
.71589 .62745 Mdot
.86839 .21993 Mdot
.69279 .28246 Mdot
.49952 .81652 Mdot
.1756 .66521 Mdot
.63125 .21393 Mdot
.39475 .49274 Mdot
.1709 .62152 Mdot
.9918 .9285 Mdot
.97995 .14952 Mdot
.8769 .15509 Mdot
.8819 .05488 Mdot
.42975 .26123 Mdot
.74352 .57151 Mdot
.46474 .24407 Mdot
.51695 .02247 Mdot
.55567 .30719 Mdot
.61438 .0752 Mdot
.43368 .08793 Mdot
.70697 .71916 Mdot
.69974 .88831 Mdot
.4537 .30313 Mdot
.55179 .00067 Mdot
.83992 .50842 Mdot
.39789 .01287 Mdot
.83306 .68288 Mdot
.65959 .04056 Mdot
.58285 .38507 Mdot
.37453 .45346 Mdot
.24012 .04399 Mdot
.68153 .64484 Mdot
.26486 .59834 Mdot
.24958 .47753 Mdot
.08113 .56044 Mdot
.43198 .20704 Mdot
.51022 .31558 Mdot
.30732 .46342 Mdot
.40496 .36236 Mdot
.38578 .70247 Mdot
.55216 .24424 Mdot
.73267 .50728 Mdot
.58431 .93278 Mdot
.78405 .60678 Mdot
.04075 .07006 Mdot
.80007 .39003 Mdot
.23191 .77239 Mdot
.09207 .91714 Mdot
.46133 .73447 Mdot
.51959 .1743 Mdot
.3243 .09462 Mdot
.41034 .20351 Mdot
.50412 .11764 Mdot
.41247 .96102 Mdot
.19394 .4526 Mdot
.35272 .62469 Mdot
.87718 .11693 Mdot
.82107 .49604 Mdot
.90954 .07156 Mdot
.99753 .3175 Mdot
.18495 .61685 Mdot
.20827 .41762 Mdot
.58638 .25312 Mdot
.06558 .93988 Mdot
.80775 .87193 Mdot
.39852 .25275 Mdot
.88663 .68147 Mdot
.30995 .3563 Mdot
.28594 .82689 Mdot
.21412 .12599 Mdot
.64019 .47958 Mdot
.48687 .53953 Mdot
.19752 .13615 Mdot
.54927 .38748 Mdot
.87766 .61807 Mdot
.74699 .17648 Mdot
.79678 .01568 Mdot
.08316 .1956 Mdot
.63258 .05973 Mdot
.04493 .56618 Mdot
.07555 .50202 Mdot
.56044 .71268 Mdot
.70604 .75722 Mdot
.34298 .90545 Mdot
.24566 .88281 Mdot
.52701 .24778 Mdot
.63908 .00659 Mdot
.04029 .80522 Mdot
.11145 .26395 Mdot
.69438 .88462 Mdot
.21597 .93546 Mdot
.91677 .0364 Mdot
.85971 .70389 Mdot
.08955 .59305 Mdot
.43462 .22678 Mdot
.00256 .95871 Mdot
.91998 .06652 Mdot
.21205 .43723 Mdot
.5551 .33574 Mdot
.43559 .36538 Mdot
.17172 .34294 Mdot
.47352 .76269 Mdot
.22657 .13958 Mdot
.82625 .99693 Mdot
.09831 .16424 Mdot
.011 .12036 Mdot
.9317 .20878 Mdot
.73185 .43958 Mdot
.74656 .40783 Mdot
.2516 .27373 Mdot
.47088 .80593 Mdot
.0827 .63573 Mdot
.02479 .73362 Mdot
.34454 .151 Mdot
.06277 .31673 Mdot
.7828 .4247 Mdot
.6928 .88845 Mdot
.03423 .0365 Mdot
.02972 .40244 Mdot
.03755 .32334 Mdot
.55312 .25928 Mdot
.52044 .31627 Mdot
.35742 .72022 Mdot
.7035 .40396 Mdot
.06387 .26718 Mdot
.09986 .52736 Mdot
.27941 .67192 Mdot
.03656 .36898 Mdot
.31459 .05759 Mdot
.26447 .60317 Mdot
.55166 .38236 Mdot
.95254 .01098 Mdot
.73011 .84791 Mdot
.16697 .9648 Mdot
.63887 .39109 Mdot
.72859 .82476 Mdot
.30225 .40122 Mdot
.36803 .02195 Mdot
.75446 .007 Mdot
.60367 .92491 Mdot
.7199 .68057 Mdot
.06456 .58897 Mdot
.90418 .56427 Mdot
.83576 .30514 Mdot
.43812 .4423 Mdot
.93892 .07348 Mdot
.5327 .77953 Mdot
.94494 .52586 Mdot
.49281 .64252 Mdot
.30359 .23318 Mdot
.4715 .91104 Mdot
.97724 .57716 Mdot
.0106 .96808 Mdot
.18565 .25662 Mdot
.84778 .12454 Mdot
.08075 .21689 Mdot
.14274 .95614 Mdot
.41523 .87447 Mdot
.88197 .91126 Mdot
.2022 .61373 Mdot
.65257 .53126 Mdot
.62907 .11017 Mdot
.91316 .8948 Mdot
.38287 .26142 Mdot
.17015 .20459 Mdot
.46934 .7337 Mdot
.59588 .80443 Mdot
.65368 .78835 Mdot
.17912 .11874 Mdot
.51856 .64466 Mdot
.58165 .93753 Mdot
.04033 .29595 Mdot
.19348 .67152 Mdot
.68735 .45116 Mdot
.00146 .51433 Mdot
.02697 .92333 Mdot
.55662 .58467 Mdot
.30631 .91978 Mdot
.23326 .05366 Mdot
.91291 .39885 Mdot
.31353 .20867 Mdot
.66772 .49061 Mdot
.0081 .99401 Mdot
.35704 .46721 Mdot
.09275 .59655 Mdot
.93899 .74443 Mdot
.81357 .81637 Mdot
.63628 .0871 Mdot
.98893 .96646 Mdot
.60777 .90035 Mdot
.03411 .17981 Mdot
.95876 .77223 Mdot
.98631 .24484 Mdot
.55751 .54166 Mdot
.70504 .98196 Mdot
.93213 .34206 Mdot
.89086 .66027 Mdot
.26187 .33346 Mdot
.3337 .57464 Mdot
.35952 .9717 Mdot
.07131 .33732 Mdot
.01361 .80425 Mdot
.30156 .89373 Mdot
.33138 .30528 Mdot
.04786 .91105 Mdot
.04452 .49178 Mdot
.07478 .65599 Mdot
.83993 .41 Mdot
.92238 .26574 Mdot
.30996 .34779 Mdot
.84985 .96194 Mdot
.21644 .11349 Mdot
.04717 .89169 Mdot
.92466 .04016 Mdot
.01421 .73412 Mdot
.86865 .00304 Mdot
.69518 .55578 Mdot
.09998 .23926 Mdot
.35739 .6229 Mdot
.98833 .56385 Mdot
.1625 .62682 Mdot
.40947 .47698 Mdot
.03733 .39512 Mdot
.45803 .64102 Mdot
.25386 .76979 Mdot
.25904 .33886 Mdot
.51667 .77723 Mdot
.65607 .60252 Mdot
.5476 .95572 Mdot
.83023 .08627 Mdot
.46704 .06582 Mdot
.56757 .25416 Mdot
.02759 .70734 Mdot
.43414 .05017 Mdot
.72358 .5852 Mdot
.69941 .67448 Mdot
.74108 .08153 Mdot
.7104 .06479 Mdot
.501 .03653 Mdot
.3183 .72935 Mdot
.68463 .80629 Mdot
.7599 .37264 Mdot
.94089 .01121 Mdot
.91761 .85452 Mdot
.18092 .03519 Mdot
.76593 .07021 Mdot
.19647 .71262 Mdot
.79199 .6629 Mdot
.19326 .90468 Mdot
.81786 .32395 Mdot
.96371 .59891 Mdot
.7679 .86689 Mdot
.55156 .52841 Mdot
.27686 .75472 Mdot
.34207 .78398 Mdot
.63149 .64574 Mdot
.42413 .02469 Mdot
.59807 .8427 Mdot
.49508 .03875 Mdot
.07117 .44678 Mdot
.03999 .40185 Mdot
.52766 .39044 Mdot
.79697 .07435 Mdot
.49137 .25535 Mdot
.52085 .27761 Mdot
.48052 .76497 Mdot
.91584 .2176 Mdot
.12019 .85928 Mdot
.22369 .4699 Mdot
.25465 .73774 Mdot
.9998 .16054 Mdot
.91279 .01668 Mdot
.2379 .48588 Mdot
.66194 .89893 Mdot
.16404 .68423 Mdot
.89396 .91794 Mdot
.91741 .6867 Mdot
.68906 .41144 Mdot
.73671 .72773 Mdot
.83275 .28563 Mdot
.24393 .98573 Mdot
.8531 .82531 Mdot
.51196 .095 Mdot
.66642 .53625 Mdot
.54109 .33335 Mdot
.285 .90049 Mdot
.10066 .37954 Mdot
.65142 .25704 Mdot
.45217 .42554 Mdot
.69096 .58006 Mdot
.45516 .97526 Mdot
.12252 .01675 Mdot
.9343 .72208 Mdot
.54749 .46034 Mdot
.70646 .89417 Mdot
.60886 .66707 Mdot
.88839 .83378 Mdot
.05637 .03556 Mdot
.06377 .72556 Mdot
.68525 .05315 Mdot
.34134 .02376 Mdot
.71915 .2037 Mdot
.15054 .77978 Mdot
.32634 .92377 Mdot
.93947 .79184 Mdot
.04843 .72869 Mdot
.51208 .62904 Mdot
.16473 .79242 Mdot
.35127 .0634 Mdot
.831 .02858 Mdot
.55408 .60503 Mdot
.42458 .24867 Mdot
.94942 .31189 Mdot
.43611 .31034 Mdot
.0633 .26228 Mdot
.38223 .65623 Mdot
.84423 .20292 Mdot
.06511 .20664 Mdot
.06461 .31277 Mdot
.17175 .13935 Mdot
.44576 .52162 Mdot
.06365 .84417 Mdot
.15983 .18188 Mdot
.37818 .86581 Mdot
.93661 .13883 Mdot
.6726 .27749 Mdot
.15718 .60117 Mdot
.56391 .89184 Mdot
.03219 .12916 Mdot
.76389 .96052 Mdot
.70535 .54334 Mdot
.31668 .55086 Mdot
.53357 .74955 Mdot
.51536 .43697 Mdot
.09276 .83326 Mdot
.86235 .84821 Mdot
.42774 .96882 Mdot
.93232 .2905 Mdot
.53946 .09661 Mdot
.09651 .66825 Mdot
.22899 .24132 Mdot
.60798 .44827 Mdot
.25441 .42526 Mdot
.01897 .17059 Mdot
.00344 .40922 Mdot
.77017 .45284 Mdot
.63454 .84877 Mdot
.63335 .33912 Mdot
.48527 .14785 Mdot
.4399 .31858 Mdot
.21172 .776 Mdot
.60647 .3719 Mdot
.71516 .26786 Mdot
.73091 .6681 Mdot
.72639 .57664 Mdot
.44581 .76619 Mdot
.46142 .8901 Mdot
.93046 .57515 Mdot
.55532 .31344 Mdot
.01859 .9662 Mdot
.33856 .43847 Mdot
.32551 .91414 Mdot
.85847 .385 Mdot
.98299 .26199 Mdot
.87273 .38002 Mdot
.9801 .33819 Mdot
.41116 .54196 Mdot
.81316 .29862 Mdot
.68417 .37668 Mdot
.14523 .99874 Mdot
.40037 .33684 Mdot
.39313 .29965 Mdot
.78637 .16917 Mdot
.80523 .6561 Mdot
.20688 .51127 Mdot
.08739 .11893 Mdot
.06203 .39358 Mdot
.84072 .51974 Mdot
.91981 .12227 Mdot
.75914 .93692 Mdot
.96617 .46916 Mdot
.87681 .21313 Mdot
.82781 .39768 Mdot
.75267 .65311 Mdot
.76855 .50087 Mdot
.68156 .25978 Mdot
.30269 .72631 Mdot
.32257 .41156 Mdot
.5053 .59898 Mdot
.74711 .63057 Mdot
.85746 .75575 Mdot
.72201 .41626 Mdot
.62323 .00316 Mdot
.1127 .9373 Mdot
.05506 .87471 Mdot
.63302 .55476 Mdot
.55787 .63921 Mdot
.68174 .02199 Mdot
.99248 .64472 Mdot
.0923 .87976 Mdot
.75606 .3118 Mdot
.60937 .51384 Mdot
.62838 .29075 Mdot
.61608 .36296 Mdot
.27045 .02318 Mdot
.76971 .15722 Mdot
.94606 .40715 Mdot
.41219 .87654 Mdot
.11342 .50071 Mdot
.45513 .58456 Mdot
.40211 .13486 Mdot
.08958 .97234 Mdot
.90691 .08921 Mdot
.75163 .72455 Mdot
.01551 .5267 Mdot
.86541 .6253 Mdot
.0082 .77948 Mdot
.82845 .73643 Mdot
.7924 .08847 Mdot
.69259 .59204 Mdot
.94495 .86674 Mdot
.96879 .27471 Mdot
.28415 .99512 Mdot
.6047 .03849 Mdot
.63889 .63915 Mdot
.12289 .58633 Mdot
.3607 .37702 Mdot
.52723 .23435 Mdot
.62273 .87619 Mdot
.42602 .22793 Mdot
.56209 .5028 Mdot
.00661 .36994 Mdot
.88506 .92578 Mdot
.30564 .36528 Mdot
.34122 .19336 Mdot
.43248 .59347 Mdot
.96603 .28876 Mdot
.5862 .73911 Mdot
.34438 .64142 Mdot
.7845 .77775 Mdot
.98806 .03515 Mdot
.63567 .27043 Mdot
.15842 .79983 Mdot
.361 .62382 Mdot
.54105 .15259 Mdot
.7872 .98814 Mdot
.92863 .22439 Mdot
.62528 .66865 Mdot
.69063 .2098 Mdot
.76926 .19928 Mdot
.07413 .30422 Mdot
.24753 .15551 Mdot
.36575 .99586 Mdot
.88893 .15549 Mdot
.93291 .92273 Mdot
.25449 .25936 Mdot
.66979 .03937 Mdot
.2046 .99768 Mdot
.00592 .08215 Mdot
.84256 .06118 Mdot
.0443 .60013 Mdot
.80272 .13083 Mdot
.69986 .57654 Mdot
.82658 .70789 Mdot
.61175 .84944 Mdot
.21839 .81592 Mdot
.94423 .65998 Mdot
.68948 .83455 Mdot
.00162 .87929 Mdot
.75928 .56535 Mdot
.27324 .07315 Mdot
.64354 .77594 Mdot
.49391 .20205 Mdot
.56764 .91416 Mdot
.52037 .35943 Mdot
.4721 .93957 Mdot
.63791 .24415 Mdot
.98297 .39233 Mdot
.96311 .86357 Mdot
.0261 .29497 Mdot
.68387 .71695 Mdot
.54043 .00883 Mdot
.69466 .91011 Mdot
.15644 .9691 Mdot
.92812 .98433 Mdot
.85898 .31708 Mdot
.69067 .88931 Mdot
.12803 .65194 Mdot
.77575 .36848 Mdot
.8705 .98576 Mdot
.54565 .77723 Mdot
.5728 .42361 Mdot
.58636 .79173 Mdot
.30467 .68414 Mdot
.15769 .60742 Mdot
.87898 .45764 Mdot
.95128 .9007 Mdot
.28169 .40169 Mdot
.54325 .74336 Mdot
.87915 .02148 Mdot
.49466 .0989 Mdot
.285 .75625 Mdot
.21801 .05358 Mdot
.44892 .0704 Mdot
.36794 .53308 Mdot
.40578 .11392 Mdot
.94096 .65319 Mdot
.25596 .38749 Mdot
.24953 .47905 Mdot
.2409 .2567 Mdot
.98008 .01463 Mdot
.08998 .50596 Mdot
.2176 .64116 Mdot
.07488 .47764 Mdot
.27107 .32099 Mdot
.89824 .68386 Mdot
.63214 .05653 Mdot
.22353 .29635 Mdot
.42585 .67907 Mdot
.23204 .18521 Mdot
.44688 .9233 Mdot
.7216 .66065 Mdot
.73116 .17602 Mdot
.90533 .41338 Mdot
.77907 .2585 Mdot
.56522 .67688 Mdot
.24598 .21281 Mdot
.93105 .25945 Mdot
.87886 .89099 Mdot
.98006 .70001 Mdot
.19029 .94173 Mdot
.47198 .7869 Mdot
.00809 .75143 Mdot
.01557 .86684 Mdot
.56033 .84236 Mdot
.84599 .16817 Mdot
.04759 .30323 Mdot
.01088 .23689 Mdot
.53533 .36583 Mdot
.80749 .23943 Mdot
.38275 .75269 Mdot
.09311 .81781 Mdot
.46527 .54345 Mdot
.35916 .77028 Mdot
.17964 .52573 Mdot
.60464 .17836 Mdot
.8939 .9637 Mdot
.49306 .74163 Mdot
.12272 .37311 Mdot
.74943 .22748 Mdot
.31751 .27761 Mdot
.67487 .25229 Mdot
.20283 .79651 Mdot
.30501 .69555 Mdot
.46637 .98331 Mdot
.68088 .66164 Mdot
.55449 .73222 Mdot
.80923 .20598 Mdot
.93146 .03979 Mdot
.04658 .74034 Mdot
.53843 .39311 Mdot
.56945 .24452 Mdot
.95956 .38468 Mdot
.15864 .2666 Mdot
.0186 .85996 Mdot
.58499 .28877 Mdot
.29322 .60799 Mdot
.16524 .90617 Mdot
.00414 .14727 Mdot
.09774 .41902 Mdot
.34678 .37571 Mdot
.77588 .94744 Mdot
.53571 .71255 Mdot
.48827 .97257 Mdot
.31577 .05507 Mdot
.04663 .98 Mdot
.01136 .92921 Mdot
.73257 .41477 Mdot
.99761 .58735 Mdot
.28938 .24551 Mdot
.72199 .16749 Mdot
.46146 .54882 Mdot
.64842 .06453 Mdot
.41283 .33191 Mdot
.84425 .62764 Mdot
.20241 .6338 Mdot
.79837 .29868 Mdot
.8885 .92564 Mdot
.51382 .10873 Mdot
.42358 .77166 Mdot
.78622 .79399 Mdot
.86118 .25681 Mdot
.79033 .34485 Mdot
.67594 .97898 Mdot
.41408 .54984 Mdot
.98537 .36965 Mdot
.30747 .19919 Mdot
.05775 .46745 Mdot
.77295 .62395 Mdot
.43858 .81552 Mdot
.53396 .24398 Mdot
.28965 .76794 Mdot
.01828 .72635 Mdot
.6881 .23446 Mdot
.94702 .11029 Mdot
.28528 .52479 Mdot
.80712 .28219 Mdot
.03347 .42502 Mdot
.77445 .35678 Mdot
.70194 .69369 Mdot
.72921 .01224 Mdot
.53808 .14504 Mdot
.46482 .49426 Mdot
.98768 .64519 Mdot
.72261 .03801 Mdot
.56658 .1374 Mdot
.49629 .20083 Mdot
.54821 .33599 Mdot
.95193 .65106 Mdot
.2533 .18457 Mdot
.44785 .55301 Mdot
.27764 .22156 Mdot
.45028 .81661 Mdot
.00405 .80786 Mdot
.24565 .05352 Mdot
.75619 .42481 Mdot
.26323 .73778 Mdot
.46391 .02223 Mdot
.49583 .80862 Mdot
.18387 .41113 Mdot
.81461 .89158 Mdot
.65953 .50209 Mdot
.08818 .60212 Mdot
.11573 .54946 Mdot
.90846 .0592 Mdot
.37478 .46577 Mdot
.92499 .74742 Mdot
.35155 .31138 Mdot
.40356 .73569 Mdot
.61715 .55117 Mdot
.17184 .19839 Mdot
.70778 .87693 Mdot
.09147 .04217 Mdot
.7778 .09725 Mdot
.27047 .70109 Mdot
.92992 .82648 Mdot
.08866 .91096 Mdot
.28842 .0823 Mdot
.43915 .89945 Mdot
.20004 .50008 Mdot
.76125 .89585 Mdot
.85204 .21196 Mdot
.85923 .97367 Mdot
.87795 .61163 Mdot
.49316 .65418 Mdot
.36613 .24276 Mdot
.49707 .68543 Mdot
.70454 .69365 Mdot
.12719 .04297 Mdot
.14258 .88222 Mdot
.96648 .86682 Mdot
.67752 .64763 Mdot
.93791 .24075 Mdot
.09984 .16171 Mdot
.34712 .55053 Mdot
.95014 .82934 Mdot
.58333 .16441 Mdot
.8553 .30894 Mdot
.35926 .2151 Mdot
.4229 .34981 Mdot
.95801 .44112 Mdot
.5481 .74654 Mdot
.25958 .30722 Mdot
.59294 .35914 Mdot
.59914 .79019 Mdot
.76133 .9297 Mdot
.9782 .50873 Mdot
.07217 .83731 Mdot
.66273 .61786 Mdot
.49164 .7882 Mdot
.03283 .1342 Mdot
.79123 .16739 Mdot
.34468 .9629 Mdot
.52069 .15049 Mdot
.8179 .91843 Mdot
.65875 .05451 Mdot
.49994 .86018 Mdot
.15906 .39808 Mdot
.24787 .61532 Mdot
.8122 .29362 Mdot
.85623 .73695 Mdot
.58988 .77877 Mdot
.54943 .32819 Mdot
.52546 .33593 Mdot
.47183 .641 Mdot
.7359 .45184 Mdot
.38552 .44877 Mdot
.80747 .12885 Mdot
.16052 .3188 Mdot
.90946 .00403 Mdot
.64355 .97555 Mdot
.82753 .97692 Mdot
.04636 .96678 Mdot
.51456 .4673 Mdot
.77306 .36328 Mdot
.71955 .86126 Mdot
.02325 .99181 Mdot
.71028 .66974 Mdot
.90735 .26686 Mdot
.63375 .26253 Mdot
.48375 .22025 Mdot
.44441 .5333 Mdot
.57159 .97845 Mdot
.34269 .83423 Mdot
.78224 .28132 Mdot
.09325 .09739 Mdot
.2803 .19228 Mdot
.64874 .50468 Mdot
.98968 .46384 Mdot
.205 .57221 Mdot
.34833 .92873 Mdot
.30306 .57658 Mdot
.5969 .97689 Mdot
.58807 .77303 Mdot
.75061 .73218 Mdot
.51852 .20818 Mdot
.23153 .17007 Mdot
.14476 .38317 Mdot
.21423 .25213 Mdot
.23198 .60583 Mdot
.96152 .50778 Mdot
.29702 .76169 Mdot
.88333 .8593 Mdot
.2578 .4538 Mdot
.02553 .1524 Mdot
.39597 .41039 Mdot
.54719 .15486 Mdot
.15409 .47226 Mdot
.0379 .71599 Mdot
.73282 .36028 Mdot
.08764 .73567 Mdot
.23146 .4907 Mdot
.85928 .9525 Mdot
.67248 .45673 Mdot
.70172 .36482 Mdot
.68714 .73794 Mdot
.40431 .48762 Mdot
.55758 .0484 Mdot
.12496 .0716 Mdot
.67832 .84069 Mdot
.35263 .08429 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool2o`0000oooooo00?o0000ooooooooool01?ooool2o`0000Oo
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`;o00002Oooool00ol0003o
ooooooooo`02o`0000_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`00
7_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`04ooooo`;o00000oooool2o`0000;ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`?o00003_ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00;ooooo0_l00009ooooo`03o`000?oooooooooo00;o00002oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00;ooooo000Nooooo`03o`000?oooooooooo0:cooooo0_l0
000Nooooo`;o00008oooool2o`0002oooooo0_l0000Sooooo`007_ooool00ol0003oooooooooo`1m
ooooo`;o0000;Oooool2o`0003_ooooo0_l0000gooooo`;o00002_ooool2o`0000;ooooo0_l0000C
ooooo`007_ooool00ol0003oooooooooo`0Tooooo`;o0000Eoooool2o`00043ooooo0_l0000Xoooo
o`;o00005?ooool2o`0002Cooooo0_l00007ooooo`;o00000_ooool2o`0000Oooooo0_l0000:oooo
o`007_ooool00ol0003oooooooooo`0Tooooo`;o0000<_ooool2o`0006Gooooo0_l0000nooooo`;o
00009?ooool2o`0001Cooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`1Hooooo`;o0000
6_ooool2o`0001gooooo0_l0000?ooooo`;o0000=?ooool2o`0003kooooo0_l0000[ooooo`007_oo
ool00ol0003oooooooooo`1Dooooo`;o00005Oooool2o`0000Oooooo0ol0000?ooooo`;o00002ooo
ool2o`0000oooooo0_l0000dooooo`;o0000?_ooool2o`0000gooooo0_l0000Looooo`007_ooool0
0ol0003oooooooooo`1Dooooo`;o00005Oooool2o`0000Sooooo0_l0000?ooooo`;o0000P_ooool2
o`0001gooooo0_l0000Looooo`007_ooool00ol0003oooooooooo`3oooooo`_ooooo0_l0000koooo
o`007_ooool00ol0003oooooooooo`0Eooooo`;o00008?ooool2o`000?oooooo1Oooool2o`0000So
oooo000Nooooo`03o`000?oooooooooo00Oooooo0_l00005ooooo`;o00001Oooool2o`00023ooooo
0_l0000<ooooo`;o0000F?ooool2o`0004Kooooo0_l0000mooooo`;o00005Oooool2o`0000Sooooo
000Nooooo`03o`000?oooooooooo00Oooooo0_l00005ooooo`;o0000=Oooool2o`0005Kooooo1?l0
000Oooooo`;o00004?ooool2o`0000;ooooo0_l0000?ooooo`;o0000?Oooool2o`000003ooooool0
003o000000;o00006_ooool001kooooo00?o0000ooooooooool06_ooool2o`0000Wooooo0_l0000S
ooooo`;o0000<?ooool2o`0001oooooo0_l0000Qooooo`;o00004?ooool2o`0000;ooooo0_l0001A
ooooo`Co00006_ooool001kooooo00?o0000ooooooooool06_ooool2o`0000Wooooo0_l0000Soooo
o`;o0000<?ooool2o`000:Kooooo0_l0000Qooooo`007_ooool00ol0003oooooooooo`29ooooo`;o
00009_ooool2o`00077ooooo0_l0000Qooooo`007_ooool2o`0004Cooooo0_l00003ooooo`;o0000
0_ooool2o`0003_ooooo0_l0000Vooooo`;o0000:?ooool2o`0006[ooooo000Nooooo`03o`000?oo
oooooooo04?ooooo0_l00003ooooo`;o00000_ooool2o`0001Gooooo0_l0001Tooooo`;o00001ooo
ool2o`0000Oooooo0_l0000nooooo`;o0000:_ooool001kooooo00?o0000ooooooooool0H_ooool3
o`0003cooooo0_l0000Vooooo`?o00001_ooool2o`0004Oooooo0_l00006ooooo`;o00008_ooool0
01kooooo00?o0000ooooooooool0H_ooool2o`0003gooooo0_l0000Wooooo`;o0000@_ooool2o`00
01?ooooo0_l0000Rooooo`007_ooool00ol0003oooooooooo`1^ooooo`;o00009?ooool2o`0003Wo
oooo0_l0000Booooo`;o00008Oooool2o`0000Kooooo0_l0000gooooo`007_ooool00ol0003ooooo
ooooo`1^ooooo`;o00009?ooool2o`0002Cooooo0_l0000Cooooo`;o00002_ooool2o`0000Kooooo
0_l0000Qooooo`;o00007oooool2o`0001kooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0
000Jooooo`;o0000Ioooool2o`0002[ooooo0_l0000Oooooo`;o00005?ooool2o`0000;ooooo0_l0
000]ooooo`;o000000?oooooo`000?l000005oooool2o`0000Gooooo000Nooooo`03o`000?oooooo
oooo00Wooooo0_l0000Jooooo`;o0000;_ooool2o`0003Oooooo0_l0000dooooo`;o0000:oooool2
o`0000;ooooo0_l00008ooooo`;o00008oooool2o`0000Oooooo0_l0000Aooooo`;o00001Oooool0
01kooooo00?o0000ooooooooool0EOooool2o`0004kooooo0_l0000Mooooo`;o0000>Oooool2o`00
00cooooo0_l0000Nooooo`;o00006?ooool001kooooo00?o0000ooooooooool0YOooool2o`0006Ko
oooo0_l0000hooooo`007_ooool3o`0005[ooooo0_l0000Cooooo`;o0000O?ooool2o`0005Sooooo
000Nooooo`?o00005_ooool2o`0004;ooooo0_l0000Cooooo`;o0000COooool2o`0000_ooooo0_l0
000Pooooo`Co00006Oooool2o`0003_ooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l0001a
ooooo`;o0000<oooool2o`0000_ooooo0_l0000Rooooo`;o00003Oooool2o`0000[ooooo0_l00004
ooooo`;o00004Oooool2o`0001Wooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`29oooo
o`;o0000Loooool2o`0000Cooooo0_l0000:ooooo`;o00004Oooool2o`0001Wooooo0_l00007oooo
o`007_ooool00ol0003oooooooooo`1Uooooo`;o0000>oooool2o`0000Oooooo0_l0001Gooooo`;o
0000@Oooool001kooooo00?o0000ooooooooool06_ooool2o`0001cooooo0_l0000[ooooo`;o0000
=_ooool2o`0000?ooooo0_l00007ooooo`;o0000C?ooool2o`0004cooooo000Nooooo`;o00006ooo
ool2o`0001cooooo0_l0000iooooo`;o0000:?ooool2o`0005[ooooo0_l0001<ooooo`007_ooool0
0ol0003oooooooooo`1cooooo`;o00002?ooool2o`000<Sooooo000Nooooo`03o`000?oooooooooo
07gooooo0_l0000Tooooo`;o0000X_ooool001kooooo00?o0000ooooooooool0Xoooool2o`0002?o
oooo0_l000000ooooooo0000o`00001Sooooo`;o00005Oooool001kooooo00?o0000ooooooooool0
@_ooool2o`0003cooooo0_l00016ooooo`;o000000?oooooo`000?l00000Hoooool2o`0001Gooooo
000Nooooo`03o`000?oooooooooo04;ooooo0_l0000looooo`;o00007_ooool2o`0001Sooooo0_l0
001Mooooo`;o0000;?ooool001kooooo00Co0000ooooool0003o00005oooool2o`0001cooooo0_l0
001Xooooo`;o00006?ooool2o`0005gooooo0_l0000/ooooo`007_ooool01?l0003oooooo`000?l0
000Gooooo`;o00007?ooool2o`000>oooooo0_l0000Nooooo`007_ooool00ol0003oooooooooo`11
ooooo`;o0000cOooool2o`0000oooooo0_l00004ooooo`;o00007_ooool001kooooo00?o0000oooo
ooooool01_ooool2o`0003Wooooo0_l0002oooooo`;o00003?ooool2o`0000oooooo0_l0000Toooo
o`007_ooool00ol0003oooooooooo`06ooooo`;o0000nOooool3o`0004?ooooo000Nooooo`03o`00
0?oooooooooo00Oooooo0_l0000cooooo`;o0000@Oooool2o`00083ooooo0_l00014ooooo`007_oo
ool00ol0003oooooooooo`07ooooo`;o0000:oooool2o`0000Kooooo0_l00008ooooo`;o0000=ooo
ool2o`0003?ooooo0_l0001fooooo`;o00001_ooool2o`00017ooooo000Nooooo`03o`000?oooooo
oooo03Cooooo0_l0000@ooooo`;o0000K?ooool2o`0002Gooooo0_l0001?ooooo`;o00001_ooool2
o`00017ooooo000Nooooo`03o`000?oooooooooo0:_ooooo0_l0000^ooooo`;o0000J_ooool001ko
oooo0_l0002Kooooo`;o00003oooool2o`0009[ooooo000Nooooo`;o0000KOooool2o`0002cooooo
0_l00009ooooo`;o0000Toooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0
001Vooooo`;o0000=Oooool4o`0000Gooooo1?l0000Eooooo`;o0000D_ooool2o`0001oooooo0_l0
000;ooooo`007_ooool00ol0003oooooooooo`04ooooo`;o0000?oooool2o`0000Gooooo0_l0001E
ooooo`;o00001oooool4o`0001Gooooo0_l0000_ooooo`;o00008Oooool2o`0000;ooooo0_l0000X
ooooo`007_ooool00ol0003oooooooooo`15ooooo`;o00001Oooool2o`0001kooooo0_l00028oooo
o`;o00009Oooool2o`0002;ooooo0_l00004ooooo`007_ooool00ol0003oooooooooo`0Looooo`;o
0000C_ooool2o`0000cooooo0_l0000nooooo`;o00003oooool2o`0006Cooooo0_l0000>ooooo`;o
00001?ooool001kooooo00?o0000ooooooooool07?ooool2o`0005cooooo0_l0000nooooo`;o0000
3oooool2o`0001[ooooo0_l0000Dooooo`;o0000<_ooool2o`0001Cooooo000Nooooo`03o`000?oo
oooooooo00;ooooo0_l00013ooooo`;o0000AOooool2o`0005Oooooo0_l0000Cooooo`?o00004?oo
ool2o`0003Kooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l00013ooooo`;o0000AOooool2
o`0006cooooo0_l0000Aooooo`;o0000=_ooool001kooooo00?o0000ooooooooool0YOooool2o`00
04?ooooo0_l00003ooooo`;o0000E_ooool001kooooo0_l00008ooooo`;o0000:oooool2o`0006oo
oooo0_l0000Iooooo`;o0000:?ooool2o`0000?ooooo0_l0001Fooooo`007_ooool2o`0000Sooooo
0_l0000Uooooo`Co00000_ooool2o`0008[ooooo0_l0001Uooooo`;o00007_ooool001kooooo00?o
0000ooooooooool0;_ooool4o`0001Gooooo0_l00005ooooo`;o0000eoooool2o`0001kooooo000N
ooooo`03o`000?oooooooooo04Oooooo0_l00005ooooo`;o0000Eoooool2o`0009kooooo000Noooo
o`03o`000?oooooooooo0:Oooooo0_l0002Nooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`1Gooooo`;o00000_ooool2o`00
00kooooo0_l0002Yooooo`;o0000;oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool05oooool2
o`0002Oooooo0_l0000@ooooo`;o00000oooool2o`0000;ooooo0_l0000>ooooo`;o0000C_ooool2
o`0005Wooooo0_l0000_ooooo`000oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RH
ob4Q8Oo^k^h01oooool3o`0001Oooooo0_l0000Kooooo`;o00002_ooool2o`00013ooooo0_l0000<
ooooo`;o0000>oooool2o`0001cooooo0_l0000iooooo`;o0000Coooool000?ooooo00Go0000oooo
ooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool04?ooool2
o`0002;ooooo0_l0000Zooooo`;o00007oooool2o`0001Wooooo0ol00017ooooo`;o00003_ooool2
o`0001Kooooo0_l0000gooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMg
ofIVI_ooool01Oooool00ol0003oooooooooo`0@ooooo`?o00008?ooool2o`0004cooooo0_l00005
ooooo`;o00004_ooool2o`0004Sooooo0_l0000Kooooo`;o00002Oooool2o`0003Oooooo0003oooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo017ooooo0_l0000Pooooo`;o0000;Oooool2o`0002Cooooo0_l0000Jooooo`;o0000=_ooool2
o`0002Gooooo0_l0000Vooooo`;o00006_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`0Cooooo`;o0000=ooo
ool2o`0001Cooooo0_l00010ooooo`;o00006Oooool2o`0001_ooooo0_l0000cooooo`;o00001_oo
ool2o`00013ooooo0_l0000Jooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo01?ooooo0_l0000gooooo`;o0000
8oooool2o`0004cooooo0_l00008ooooo`;o0000A_ooool2o`0000Kooooo0_l0000/ooooo`007_oo
ool00ol0003oooooooooo`0Fooooo`;o0000FOooool2o`0002oooooo0_l0000Uooooo`;o0000Fooo
ool2o`0001oooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l00004ooooo`;o0000>?ooool2
o`00047ooooo0_l00007ooooo`;o0000L_ooool2o`0000kooooo0_l0000Oooooo`007_ooool00ol0
003oooooooooo`0Looooo`;o0000>?ooool2o`00047ooooo0_l0001kooooo`;o00004_ooool2o`00
01?ooooo0_l00006ooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o0000I?ooool2o`000003
ooooool0003o000006Gooooo0_l0000hooooo`;o00004oooool2o`0000Kooooo000Nooooo`03o`00
0?oooooooooo023ooooo0_l0001Tooooo`;o000000?oooooo`000?l00000IOooool2o`0005Gooooo
000Nooooo`03o`000?oooooooooo03Oooooo0_l0000Vooooo`;o0000A_ooool2o`0001Wooooo0_l0
000Hooooo`;o0000JOooool001kooooo00Co0000ooooool0003o0000=_ooool2o`0002Kooooo0_l0
0016ooooo`;o00006Oooool2o`0001Sooooo0_l0001Yooooo`007_ooool01?l0003oooooo`000?l0
000Kooooo`;o0000:?ooool2o`000;[ooooo0_l0000Yooooo`;o00006?ooool001kooooo00?o0000
ooooooooool07?ooool2o`0002Sooooo0_l0000[ooooo`;o00007_ooool2o`0001Cooooo0_l00004
ooooo`;o00006_ooool2o`0003Gooooo0_l0000Looooo`;o00002oooool2o`0001Sooooo000Noooo
o`03o`000?oooooooooo04Gooooo0_l0000Cooooo`;o00005oooool2o`0001kooooo0_l0000Doooo
o`;o00001?ooool2o`0000Cooooo0_l0000Dooooo`;o0000Doooool2o`0001_ooooo0_l00008oooo
o`007_ooool00ol0003oooooooooo`15ooooo`;o00004oooool2o`0002[ooooo0_l0000Oooooo`;o
00003?ooool2o`00087ooooo0_l00003ooooo`;o00002?ooool001kooooo0_l00013ooooo`;o0000
>Oooool2o`0000Oooooo0_l0000Oooooo`;o00004_ooool2o`0001[ooooo0_l0000Yooooo`;o0000
=?ooool2o`0000gooooo000Nooooo`03o`000?oooooooooo03Sooooo0_l00008ooooo`;o00001_oo
ool2o`00037ooooo0_l0000Mooooo`;o00002_ooool2o`0000[ooooo0_l00005ooooo`;o00000ooo
ool2o`0001Gooooo0_l0000Yooooo`;o00009?ooool2o`0001gooooo000Nooooo`03o`000?oooooo
oooo03Sooooo0_l0000@ooooo`;o00000oooool2o`0004_ooooo0_l0000:ooooo`;o00001_ooool2
o`0000;ooooo0_l0000:ooooo`;o00003_ooool2o`0000Oooooo0_l0000Nooooo`;o00006Oooool2
o`0001;ooooo0_l000000ooooooo0000o`00000Jooooo`007_ooool00ol0003oooooooooo`0@oooo
o`;o0000?Oooool2o`0002Oooooo0_l0000>ooooo`;o00009_ooool2o`0001Sooooo0_l00004oooo
o`;o00001oooool2o`0001kooooo0_l0000Iooooo`;o00005Oooool2o`0000kooooo0_l0000:oooo
o`007_ooool00ol0003oooooooooo`0@ooooo`;o00003_ooool2o`0005Kooooo0_l0000>ooooo`;o
0000;?ooool2o`0001;ooooo0_l0001=ooooo`;o00003Oooool2o`00017ooooo0_l000000ooooooo
0000o`000007ooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o00003Oooool2o`0000gooooo
0_l00025ooooo`;o0000;?ooool2o`0003?ooooo0_l00008ooooo`;o00000oooool2o`0001Cooooo
0_l00007ooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o00007?ooool2o`0000Kooooo0_l0
002Booooo`;o00005oooool2o`0003gooooo0_l0000Rooooo`007_ooool00ol0003oooooooooo`0g
ooooo`;o00005Oooool2o`0007_ooooo0_l0001Zooooo`;o00003_ooool001kooooo00?o0000oooo
ooooool0C_ooool2o`0001?ooooo0_l00010ooooo`;o0000<?ooool2o`0005kooooo0_l0000>oooo
o`007_ooool00ol0003oooooooooo`0Kooooo`;o0000A_ooool2o`0000Oooooo0_l0000gooooo`;o
00000oooool2o`0002_ooooo0_l0000Qooooo`;o0000Boooool001kooooo00?o0000ooooooooool0
6oooool2o`0002cooooo0_l0000Qooooo`;o0000??ooool2o`0002kooooo0_l000000ooooooo0000
o`00000Kooooo`;o00000oooool2o`000003ooooool0003o000004?ooooo000Nooooo`03o`000?oo
oooooooo04Wooooo0_l0002?ooooo`;o000000?oooooo`000?l000001?ooool2o`0001[ooooo0_l0
00000ooooooo0000o`000007ooooo`;o0000>_ooool001kooooo00?o0000ooooooooool0^_ooool2
o`0002Oooooo0_l0000Vooooo`;o00007_ooool2o`0000Wooooo0_l0000?ooooo`007_ooool00ol0
003oooooooooo`2:ooooo`;o00005Oooool2o`0001Oooooo0_l0000<ooooo`;o0000>_ooool2o`00
02Gooooo0_l00009ooooo`;o00003oooool001kooooo00?o0000ooooooooool01?ooool2o`0000?o
oooo0_l0000Iooooo`;o00007oooool2o`0004?ooooo0_l0000Eooooo`;o00009Oooool2o`0003[o
oooo0_l00011ooooo`007_ooool00ol0003oooooooooo`04ooooo`;o00000oooool2o`0001Wooooo
0_l0000Oooooo`;o00008_ooool2o`00017ooooo0_l00021ooooo`;o00000oooool2o`00047ooooo
000Nooooo`;o0000J_ooool2o`00017ooooo0_l0001Dooooo`;o0000:oooool2o`0000?ooooo0_l0
0011ooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o00001oooool2o`0005;ooooo0_l0000U
ooooo`;o0000@Oooool2o`0003Sooooo0_l0000iooooo`007_ooool00ol0003oooooooooo`0;oooo
o`;o00001oooool2o`0003[ooooo0_l0000Fooooo`;o00009Oooool2o`00023ooooo0_l0001Ioooo
o`;o00001?ooool2o`0003?ooooo000Nooooo`03o`000?oooooooooo053ooooo0_l0000Looooo`;o
00006_ooool2o`0002Gooooo0_l0000oooooo`;o00007_ooool2o`0001gooooo0_l0000Dooooo`00
7_ooool00ol0003oooooooooo`0Aooooo`;o0000Foooool2o`0001[ooooo0_l0000Tooooo`;o0000
@?ooool2o`0003gooooo0_l0000Dooooo`007_ooool00ol0003oooooooooo`0@ooooo`?o00009_oo
ool2o`0001gooooo0_l0000<ooooo`;o0000>_ooool2o`000003ooooool0003o000000Wooooo0_l0
001Qooooo`;o0000:oooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo013ooooo0_l0000N
ooooo`;o00001oooool2o`0001Wooooo0_l00002ooooo`;o00003?ooool2o`0000[ooooo0_l0000G
ooooo`;o00005Oooool2o`000003ooooool0003o0000047ooooo0_l0000?ooooo`;o00006?ooool2
o`0002?ooooo0_l00006ooooo`;o00001Oooool001kooooo00?o0000ooooooooool02?ooool2o`00
02Kooooo0_l0000Rooooo`;o00007?ooool2o`0001Oooooo0_l0001Kooooo`;o00003oooool2o`00
00_ooooo0_l0000`ooooo`;o00003Oooool001kooooo00?o0000ooooooooool02?ooool2o`000=Wo
oooo0_l0000Qooooo`;o0000?oooool001kooooo00?o0000ooooooooool0:_ooool2o`0008?ooooo
0_l0000booooo`;o0000H_ooool001kooooo00?o0000ooooooooool0:_ooool2o`0002Gooooo0_l0
000_ooooo`;o0000:?ooool2o`000003ooooool0003o000002Oooooo0_l0001]ooooo`007_ooool0
0ol0003oooooooooo`0=ooooo`;o0000@_ooool2o`0002oooooo0_l0000Sooooo`;o00000oooool6
o`0002Kooooo0_l0000@ooooo`;o0000?Oooool2o`0001cooooo000Nooooo`03o`000?oooooooooo
00gooooo0_l00004ooooo`;o0000>oooool3o`0002_ooooo0_l0000Wooooo`;o00001Oooool4o`00
01Sooooo0_l0000Nooooo`;o0000?Oooool2o`00013ooooo0_l0000:ooooo`007_ooool00ol0003o
ooooooooo`0Cooooo`;o0000>oooool3o`0002_ooooo0_l0000/ooooo`;o00007?ooool2o`0004co
oooo0_l0000Aooooo`;o00003_ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo03Cooooo
0_l0001fooooo`;o0000Coooool2o`0001Wooooo0_l0000Aooooo`;o00006_ooool001kooooo00?o
0000ooooooooool0=?ooool2o`0002_ooooo0_l0002Jooooo`;o0000??ooool2o`0000[ooooo000N
ooooo`;o0000EOooool2o`0000_ooooo0_l0000Rooooo`;o0000]?ooool2o`0000[ooooo000Noooo
o`03o`000?oooooooooo05Cooooo0_l0000_ooooo`;o0000`?ooool001kooooo00?o0000oooooooo
ool0HOooool2o`0009Gooooo0_l0001=ooooo`007_ooool00ol0003oooooooooo`1Qooooo`;o0000
@_ooool2o`0001Kooooo0_l0000[ooooo`;o00003?ooool2o`0004gooooo000Nooooo`03o`000?oo
oooooooo083ooooo0_l0000Sooooo`;o00005_ooool2o`0000Gooooo0_l0000Tooooo`;o00002ooo
ool2o`0002kooooo0_l0000Nooooo`007_ooool00ol0003oooooooooo`1Oooooo`;o00007oooool2
o`0000Oooooo0_l0000Oooooo`;o00006?ooool2o`0001[ooooo0_l0000Eooooo`;o0000;_ooool2
o`0001kooooo000Nooooo`?o00002?ooool2o`0005Gooooo0_l0000Xooooo`;o00007oooool2o`00
03Cooooo0_l0000Fooooo`;o0000@_ooool2o`0000Wooooo000Nooooo`?o00002?ooool2o`0001[o
oooo0_l0002Kooooo`;o0000<?ooool2o`0000?ooooo0_l0000Nooooo`;o00008_ooool2o`0000Wo
oooo000Nooooo`03o`000?oooooooooo02Cooooo0_l00017ooooo`;o0000D_ooool2o`0001Oooooo
0_l0000Gooooo`;o00008oooool2o`0002gooooo000Nooooo`03o`000?oooooooooo01gooooo0_l0
001>ooooo`;o00000_ooool2o`0006Oooooo0_l0000Sooooo`;o0000A_ooool001kooooo00?o0000
ooooooooool07Oooool2o`0004Cooooo0_l0000<ooooo`;o0000??ooool2o`0004kooooo0_l0000G
ooooo`;o0000;Oooool001kooooo00?o0000ooooooooool0:oooool2o`0003Kooooo0_l0001:oooo
o`;o00002?ooool2o`0005Sooooo0_l00003ooooo`;o00006_ooool2o`00017ooooo000Nooooo`03
o`000?oooooooooo02_ooooo0_l0000Rooooo`;o0000GOooool2o`0000Wooooo0_l0001Hooooo`;o
00007oooool2o`00017ooooo000Nooooo`03o`000?oooooooooo04oooooo0_l0001Fooooo`;o0000
1Oooool2o`0001cooooo0_l0000booooo`;o0000AOooool000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0
2?ooool2o`0000Kooooo0_l0001Dooooo`;o0000?oooool2o`0000;ooooo0_l0000Oooooo`;o0000
<_ooool2o`0003Wooooo0_l0000:ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool2o`0000Kooooo
0_l0000Nooooo`;o0000=?ooool2o`0004?ooooo0_l0001Looooo`;o0000<?ooool2o`0000[ooooo
0003ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol0000`ooooo`;o0000
;?ooool2o`000:Wooooo0_l0000Jooooo`;o00008?ooool000?ooooo00Go0000oooooooooooooooo
o`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool01_ooool2o`000003
ooooool0003o000004cooooo0_l00005ooooo`;o00001Oooool2o`0007[ooooo0_l00012ooooo`;o
00008?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`00
00Oooooo00?o0000ooooooooool01_ooool2o`000003ooooool0003o000004cooooo0_l0000<oooo
o`;o0000N_ooool2o`0004cooooo0_l0000Fooooo`000oooool01Ol@413ooooooooooooooooo410@
00cooooo00?oMgMgolc<c?l000001oooool2o`0007kooooo0_l0001`ooooo`;o00007?ooool2o`00
023ooooo0_l0000Fooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4
A?l000001oooool2o`0003Wooooo0_l0000[ooooo`;o00005_ooool2o`0004kooooo0_l00003oooo
o`;o00002?ooool2o`00017ooooo0_l0000Looooo`;o00004oooool2o`0002?ooooo0003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo
03Sooooo0_l0000[ooooo`;o0000I_ooool2o`0000?ooooo0_l00008ooooo`;o00002Oooool2o`00
0003ooooool0003o000001Cooooo0_l0000Pooooo`;o00008oooool001kooooo00?o0000oooooooo
ool02oooool2o`0000oooooo0_l0000Rooooo`;o0000YOooool2o`000003ooooool0003o000001Co
oooo0_l00015ooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o00003oooool2o`0002;ooooo
0_l0003oooooo`Kooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l00016ooooo`;o0000?_oo
ool2o`0002Gooooo0_l0000jooooo`;o00001_ooool2o`0004_ooooo000Nooooo`03o`000?oooooo
oooo00Oooooo0_l00016ooooo`;o0000?_ooool2o`0002Gooooo0_l0000jooooo`;o00001_ooool2
o`0004_ooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`11ooooo`;o0000H?ooool2o`000:;ooooo
000Nooooo`03o`000?oooooooooo047ooooo0_l0000Wooooo`;o0000=oooool2o`0004Gooooo0_l0
0017ooooo`;o00004_ooool001kooooo00?o0000ooooooooool03_ooool2o`0005[ooooo0_l0000N
ooooo`;o00001oooool2o`0005Gooooo0_l00017ooooo`;o00004_ooool001kooooo00?o0000oooo
ooooool03_ooool2o`0000?ooooo0_l0001eooooo`;o00001oooool2o`0004Wooooo0_l0001Ooooo
o`;o00001_ooool001kooooo00?o0000ooooooooool04oooool2o`0006Cooooo0_l00017ooooo`;o
00006_ooool2o`0005oooooo0_l00006ooooo`007_ooool2o`0002Gooooo0_l0000Eooooo`;o0000
>Oooool2o`000003ooooool0003o000004Oooooo0_l0000Gooooo`;o00003_ooool2o`0000Wooooo
0_l0001?ooooo`007_ooool00ol0003oooooooooo`0Tooooo`;o00005Oooool2o`0001?ooooo0_l0
000Tooooo`;o0000Hoooool2o`0000kooooo0_l00009ooooo`;o0000Coooool001kooooo00?o0000
ooooooooool0D?ooool2o`0008Gooooo0_l00011ooooo`;o0000:oooool001kooooo00?o0000oooo
ooooool0[_ooool2o`0002Oooooo0_l00011ooooo`;o0000:oooool001kooooo00?o0000oooooooo
ool0H?ooool2o`0001Cooooo0_l0000fooooo`;o0000S_ooool2o`0000Oooooo000Nooooo`03o`00
0?oooooooooo00Oooooo0_l00006ooooo`;o0000Coooool2o`0000kooooo0_l00004ooooo`;o0000
:oooool2o`0009Wooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`07ooooo`;o00001_oo
ool2o`0003Cooooo0_l0000Yooooo`;o0000<Oooool2o`00097ooooo0_l0000?ooooo`007_ooool0
0ol0003oooooooooo`0^ooooo`;o00005Oooool2o`0006Sooooo0_l00025ooooo`;o00003oooool0
01kooooo00?o0000ooooooooool05?ooool2o`0001Sooooo0_l0000Mooooo`;o0000<_ooool2o`00
02cooooo0_l0002Fooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o00005_ooool2o`0000[o
oooo0_l0000Cooooo`;o0000<_ooool2o`0004Wooooo0_l0000>ooooo`;o0000JOooool001kooooo
00?o0000ooooooooool0;?ooool2o`0000[ooooo0ol0000Booooo`;o0000OOooool2o`0000kooooo
0_l0001Yooooo`007_ooool00ol0003oooooooooo`0iooooo`;o00003_ooool2o`000?cooooo000N
ooooo`03o`000?oooooooooo04Wooooo0_l0000dooooo`;o0000^?ooool2o`0000cooooo000Noooo
o`03o`000?oooooooooo00[ooooo0_l0000kooooo`;o0000<oooool2o`000003ooooool0003o0000
05Cooooo0_l0001Rooooo`;o00003?ooool001kooooo00?o0000ooooooooool02_ooool2o`0003_o
oooo0_l0000cooooo`;o00005Oooool2o`00043ooooo0_l0000`ooooo`;o0000?_ooool001kooooo
00?o0000ooooooooool0Toooool2o`0007;ooooo0_l0000nooooo`007_ooool2o`0001Gooooo0_l0
000;ooooo`;o00006_ooool2o`0009?ooooo0_l00003ooooo`;o00007Oooool2o`0004oooooo000N
ooooo`03o`000?oooooooooo01Cooooo0_l0000;ooooo`;o00002oooool2o`0000gooooo0_l0001I
ooooo`;o00006Oooool3o`0001Wooooo0_l000000ooooooo0000o`000003ooooo`;o00007Oooool2
o`0004oooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l0000Cooooo`;o0000J?ooool2o`00
01Wooooo0ol0000Iooooo`;o00006Oooool2o`00027ooooo0_l0000Uooooo`;o00001?ooool2o`00
00_ooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l0000Tooooo`;o0000ZOooool2o`00027o
oooo0_l0000Uooooo`;o00001?ooool2o`0000_ooooo000Mooooo`;o0000@Oooool2o`0000Kooooo
0_l0001iooooo`;o0000Poooool001gooooo0_l00019ooooo`;o00005_ooool2o`00067ooooo0_l0
0023ooooo`007_ooool00ol0003oooooooooo`1Oooooo`;o0000[?ooool2o`0003Sooooo000Noooo
o`?o0000SOooool2o`0007kooooo0_l0000hooooo`007_ooool3o`000003ooooool0003o000000ko
oooo0_l00009ooooo`;o00006?ooool2o`00027ooooo0_l0000booooo`;o0000X?ooool2o`0000[o
oooo0_l0000:ooooo`007_ooool01?l0003oooooooooooooool2o`0000kooooo0_l00009ooooo`;o
00006?ooool2o`00027ooooo0_l0001Dooooo`;o0000D_ooool2o`0002[ooooo0_l0000:ooooo`;o
00002_ooool001kooooo00?o0000ooooooooool0F?ooool2o`0001[ooooo0_l0000Fooooo`;o0000
8Oooool2o`0001oooooo0_l0000aooooo`;o0000@_ooool001kooooo00?o0000ooooooooool0F?oo
ool2o`0001[ooooo0_l0000Fooooo`;o0000@_ooool2o`0000?ooooo0_l0001`ooooo`007_ooool0
0ol0003oooooooooo`2Jooooo`;o00007_ooool2o`0001Wooooo0_l0001Dooooo`;o00002Oooool2
o`0000oooooo000Nooooo`03o`000?oooooooooo08;ooooo0_l0000Fooooo`;o00005Oooool2o`00
00Oooooo0_l0001_ooooo`;o00002Oooool2o`0000oooooo000Nooooo`03o`000?oooooooooo01Co
oooo0_l0001/ooooo`;o00003oooool2o`0001cooooo0_l0000^ooooo`;o0000A_ooool2o`0001co
oooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0001looooo`?o0000C?ooool2o`0004Kooooo
0_l0000Looooo`007_ooool2o`0002?ooooo0_l0000oooooo`;o00002?ooool2o`0001Cooooo0_l0
000=ooooo`;o0000<Oooool2o`0001?ooooo0_l0001[ooooo`007_ooool00ol0003oooooooooo`0R
ooooo`;o0000?oooool2o`0000Sooooo0_l0000Dooooo`;o00002?ooool2o`0003Kooooo0_l00003
ooooo`;o00003_ooool2o`0006_ooooo000Nooooo`03o`000?oooooooooo08Gooooo0_l00006oooo
o`;o0000>oooool2o`0001;ooooo0_l0001Wooooo`007_ooool00ol0003oooooooooo`0Fooooo`;o
0000KOooool2o`0005Oooooo0_l0001Wooooo`007_ooool00ol0003oooooooooo`0Fooooo`;o0000
/_ooool2o`0005Kooooo0_l0000Iooooo`;o00002?ooool001kooooo00?o0000ooooooooool02_oo
ool2o`0000kooooo0_l0002^ooooo`;o00009oooool2o`0002gooooo0_l0000Iooooo`;o00002?oo
ool001kooooo00?o0000ooooooooool02_ooool2o`0000Kooooo0_l00006ooooo`;o0000eoooool2
o`0005;ooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0000[ooooo`;o0000[Oooool2o`00
05Oooooo000Nooooo`03o`000?oooooooooo03oooooo0_l0000Mooooo`;o00002?ooool2o`0007Go
oooo0_l0000=ooooo`;o0000>_ooool2o`0001_ooooo000Nooooo`03o`000?oooooooooo05kooooo
0_l00008ooooo`;o0000MOooool2o`0000Oooooo0_l00010ooooo`;o00003_ooool2o`0000_ooooo
000Nooooo`03o`000?oooooooooo06Sooooo0_l0001cooooo`;o00002Oooool2o`00053ooooo0_l0
000;ooooo`007_ooool00ol0003oooooooooo`2@ooooo`;o00007oooool2o`0002[ooooo0_l00008
ooooo`;o0000G_ooool001kooooo00?o0000ooooooooool09?ooool2o`0002Gooooo0_l00013oooo
o`;o00005_ooool2o`0000Oooooo0_l0000dooooo`;o0000Eoooool2o`0000Gooooo000Nooooo`03
o`000?oooooooooo017ooooo0_l0000Aooooo`;o00009Oooool2o`0005_ooooo0_l0002Fooooo`;o
00001Oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko
<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool04Oooool2o`0000Kooooo0_l0001]oooo
o`;o0000Doooool2o`0006Sooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo01Wooooo0ol0001/
ooooo`;o0000Doooool2o`0002_ooooo0_l0000kooooo`000oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o00002_ooool2o`0000kooooo0_l0
000Cooooo`;o00008Oooool2o`0004cooooo0_l0001Xooooo`;o0000:Oooool2o`00013ooooo0003
ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo
00?o0000ooooooooool02_ooool2o`0000gooooo0_l0000Dooooo`;o00008Oooool2o`0004cooooo
0_l0000_ooooo`;o0000H_ooool2o`00013ooooo0003ooooo`05o`000?ooooooooooooooool00000
2oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool06Oooool2o`0002co
oooo0_l00009ooooo`;o0000G?ooool2o`0001oooooo0_l0000Xooooo`;o0000B_ooool000?ooooo
00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000oooooooo
ool0;oooool2o`0001Kooooo0_l0000:ooooo`;o00001_ooool2o`0005?ooooo0_l00019ooooo`;o
0000B_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00So
oooo00?o0000ooooooooool0;oooool2o`0002;ooooo0_l00006ooooo`;o00000_ooool2o`0001ko
oooo0_l0000;ooooo`;o0000Roooool2o`0002cooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo03kooooo0_l0000<oooo
o`;o00004Oooool2o`0001kooooo0_l0000;ooooo`;o0000J?ooool2o`00027ooooo0_l0000/oooo
o`007_ooool00ol0003oooooooooo`0hooooo`;o00001?ooool2o`0000cooooo0_l00025ooooo`;o
00008Oooool2o`0000kooooo0_l0000Aooooo`;o0000;?ooool001kooooo00?o0000ooooooooool0
<oooool2o`0000?ooooo0_l0002Iooooo`;o0000<Oooool2o`00017ooooo0_l0000/ooooo`007_oo
ool00ol0003oooooooooo`0cooooo`;o0000>_ooool4o`0006Gooooo0_l0000Mooooo`;o00007?oo
ool2o`00017ooooo0_l0000Mooooo`007_ooool00ol0003oooooooooo`0aooooo`;o0000??ooool4
o`0002;ooooo0_l00011ooooo`;o00002oooool2o`00013ooooo0_l0000;ooooo`;o00002?ooool2
o`0000Gooooo0_l0000Aooooo`;o00007Oooool001kooooo00?o0000ooooooooool0<Oooool2o`00
06;ooooo0_l0000;ooooo`;o0000@Oooool2o`0000Sooooo0_l0000Cooooo`;o00002?ooool2o`00
03Oooooo000Nooooo`03o`000?oooooooooo03kooooo0_l0001Booooo`;o00003_ooool2o`0004_o
oooo0_l0001Fooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o00009Oooool2o`0003Cooooo
0_l0000Looooo`;o0000/oooool001kooooo00?o0000ooooooooool05oooool2o`0002[ooooo0_l0
000_ooooo`;o00006oooool2o`0000;ooooo0_l0000Jooooo`;o00006Oooool2o`0002;ooooo0_l0
001Eooooo`007_ooool00ol0003oooooooooo`13ooooo`;o00009oooool2o`0002?ooooo0_l00002
ooooo`;o00001Oooool2o`0001?ooooo0_l0000Iooooo`;o00008_ooool2o`0005Gooooo000Noooo
o`03o`000?oooooooooo05Cooooo0_l0000Fooooo`;o0000;_ooool2o`0000Kooooo0_l0000Soooo
o`;o00003_ooool2o`0006;ooooo1?l00006ooooo`007_ooool00ol0003oooooooooo`1Dooooo`;o
0000C_ooool2o`0002?ooooo0_l0000=ooooo`?o0000H_ooool4o`0000Kooooo000Nooooo`;o0000
9oooool2o`000;3ooooo0_l0000Gooooo`;o0000>oooool2o`000003ooooool0003o000001Cooooo
000Nooooo`03o`000?oooooooooo01Cooooo0_l0000@ooooo`;o0000D?ooool2o`0002;ooooo0_l0
001Cooooo`;o00003oooool2o`0002[ooooo0_l000000ooooooo0000o`00000Dooooo`007_ooool0
0ol0003oooooooooo`0Dooooo`;o0000H_ooool2o`0002;ooooo0_l0001Aooooo`;o00004Oooool2
o`0004?ooooo000Nooooo`03o`000?oooooooooo0=Wooooo0_l0000;ooooo`;o00001oooool2o`00
02gooooo0_l0000:ooooo`;o00000oooool2o`0001Kooooo000Nooooo`03o`000?oooooooooo03Go
oooo0_l0002Rooooo`;o00002oooool2o`0001Gooooo0_l0000Oooooo`;o00002_ooool2o`0000?o
oooo0_l0000Fooooo`007_ooool00ol0003oooooooooo`0Kooooo`;o00006?ooool2o`0007?ooooo
0_l0000Fooooo`;o00000oooool2o`0000_ooooo0_l0000Dooooo`;o00004Oooool2o`0004Sooooo
000Nooooo`03o`000?oooooooooo01_ooooo0_l0000Nooooo`;o00006_ooool2o`00057ooooo0_l0
000Fooooo`;o00000oooool2o`0000_ooooo0_l0000=ooooo`;o00001Oooool2o`0005_ooooo000N
ooooo`03o`000?oooooooooo03[ooooo0ol0000Jooooo`;o0000D?ooool2o`0003Cooooo0_l00002
ooooo`;o00007oooool2o`00047ooooo000Nooooo`03o`000?oooooooooo03[ooooo0_l0001]oooo
o`;o00002Oooool2o`0002Wooooo0_l0000Sooooo`;o0000@Oooool001kooooo00?o0000oooooooo
ool0Q_ooool2o`0002cooooo0_l0000Gooooo`;o00005oooool2o`0005oooooo000Nooooo`03o`00
0?oooooooooo037ooooo0_l0000/ooooo`;o00009Oooool2o`0004Gooooo0_l0000Gooooo`;o0000
8oooool2o`0000oooooo0_l00002ooooo`;o00003Oooool2o`0001Kooooo000Nooooo`03o`000?oo
oooooooo037ooooo0_l0000/ooooo`;o0000??ooool2o`0006cooooo0_l0000?ooooo`;o00000_oo
ool2o`0000Cooooo0_l00007ooooo`;o00005_ooool001kooooo00?o0000ooooooooool0@?ooool2
o`0005_ooooo0_l00027ooooo`;o00007oooool001kooooo00?o0000ooooooooool0@?ooool2o`00
01Oooooo0_l0003/ooooo`007_ooool00ol0003oooooooooo`1Iooooo`;o00001?ooool2o`0007oo
oooo0ol0001Tooooo`007_ooool00ol0003oooooooooo`0[ooooo`;o0000<_ooool2o`0007oooooo
0ol0001Tooooo`007_ooool2o`0002cooooo0_l0000Wooooo`;o00008oooool2o`000;Gooooo0_l0
0009ooooo`;o00002_ooool001kooooo00?o0000ooooooooool0E?ooool2o`0002?ooooo0_l0001[
ooooo`;o0000:oooool2o`0001_ooooo0_l00009ooooo`;o00002_ooool001kooooo00?o0000oooo
ooooool01Oooool2o`0008[ooooo0_l0001Cooooo`;o00008Oooool2o`0000Sooooo0_l0000boooo
o`007_ooool00ol0003oooooooooo`05ooooo`;o0000@_ooool2o`0004Kooooo0_l0001fooooo`;o
0000??ooool001kooooo00?o0000ooooooooool0??ooool2o`0000_ooooo0_l0001Oooooo`;o0000
1_ooool2o`0009?ooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0000booooo`;o0000A?oo
ool2o`0002Kooooo0_l00006ooooo`;o00009_ooool2o`0006_ooooo000Nooooo`03o`000?oooooo
oooo00Sooooo0_l0001Vooooo`;o00004?ooool2o`0005Kooooo0_l00006ooooo`;o0000D?ooool2
o`00017ooooo000Nooooo`03o`000?oooooooooo073ooooo0_l0001_ooooo`?o0000B?ooool2o`00
00Kooooo0_l0000Aooooo`007_ooool00ol0003oooooooooo`02ooooo`;o00003Oooool2o`0004_o
oooo0_l00021ooooo`;o00003Oooool2o`0003[ooooo0_l0000Iooooo`007_ooool00ol0003ooooo
ooooo`02ooooo`;o00002?ooool2o`0000?ooooo0_l0001;ooooo`;o00000oooool2o`0008Kooooo
0_l00003ooooo`;o0000EOooool001kooooo00?o0000ooooooooool03?ooool2o`0005Gooooo0_l0
001;ooooo`;o0000>Oooool2o`0000?ooooo0_l0001Eooooo`007_ooool01?l0003ooooooooooooo
ool2o`000003ooooool0003o000001;ooooo0_l0001Uooooo`;o00004Oooool4o`0001[ooooo0_l0
000nooooo`;o00005oooool2o`0003cooooo000Nooooo`04o`000?ooooooooooooooo`;o000000?o
ooooo`000?l000004_ooool2o`0002Kooooo0_l0000=ooooo`Co0000;?ooool2o`00013ooooo1Ol0
000Tooooo`;o00007oooool2o`0002cooooo0_l00007ooooo`;o0000<oooool001kooooo00?o0000
ooooooooool02oooool2o`0003?ooooo0_l0000=ooooo`Co0000?_ooool2o`0000Wooooo0_l0000L
ooooo`;o00007oooool2o`0003Gooooo0_l0000cooooo`007_ooool00ol0003oooooooooo`0;oooo
o`;o0000Soooool2o`0000oooooo0_l0000/ooooo`;o0000D?ooool2o`0001Sooooo000Nooooo`03
o`000?oooooooooo0:gooooo0ol0001iooooo`;o00000_ooool2o`0001Sooooo000Nooooo`Co0000
3Oooool2o`0009Wooooo0_l00003ooooo`;o00002_ooool2o`0002oooooo0_l00004ooooo`;o0000
=_ooool2o`0001cooooo000Nooooo`04o`000?oooooo0000o`0000gooooo0_l00016ooooo`;o0000
8?ooool2o`0002oooooo0_l0000?ooooo`;o0000;oooool2o`0000Cooooo0_l0000dooooo`;o0000
7_ooool001kooooo00?o0000ooooooooool0E_ooool2o`000003ooooool0003o000001gooooo0_l0
000?ooooo`;o0000E_ooool2o`00033ooooo0_l0000Booooo`;o00007_ooool001kooooo00?o0000
ooooooooool0FOooool2o`0002kooooo0_l0001Fooooo`;o0000<?ooool2o`0003;ooooo000Noooo
o`03o`000?oooooooooo00cooooo0_l0001>ooooo`;o0000>?ooool2o`000:oooooo000Nooooo`03
o`000?oooooooooo00cooooo0_l0000hooooo`;o00005?ooool2o`0002oooooo0_l00007ooooo`Co
0000[Oooool001kooooo00?o0000ooooooooool0A_ooool2o`0000Kooooo0_l0000:ooooo`;o0000
5Oooool2o`0001[ooooo0_l00002ooooo`;o00001Oooool2o`000:gooooo000Nooooo`03o`000?oo
oooooooo04Oooooo0_l00005ooooo`;o00002_ooool2o`0001Gooooo0_l0000Cooooo`;o00002Ooo
ool2o`0002Sooooo0_l0001gooooo`;o00004Oooool001kooooo00?o0000ooooooooool03Oooool2
o`0003;ooooo0_l00004ooooo`;o0000?Oooool2o`0003?ooooo0_l0000@ooooo`;o0000IOooool2
o`00017ooooo000Nooooo`04o`000?oooooo0000o`0000cooooo0_l0000booooo`;o0000HOooool2
o`0000?ooooo0_l00002ooooo`;o00003Oooool2o`0000oooooo0_l0000/ooooo`;o0000B_ooool0
01kooooo00Co0000ooooool0003o0000;?ooool2o`0007Gooooo0_l00003ooooo`;o00000_ooool2
o`0000gooooo0_l0000mooooo`;o0000B_ooool001kooooo00?o0000ooooooooool01oooool2o`00
02Cooooo0_l0000looooo`;o0000f_ooool001kooooo00?o0000ooooooooool01oooool2o`0004Oo
oooo0_l0000Iooooo`;o0000:?ooool2o`0000Gooooo0_l0000booooo`;o0000MOooool001kooooo
00?o0000ooooooooool0D?ooool2o`0004?ooooo0_l00005ooooo`;o00007Oooool2o`0000;ooooo
0_l0000?ooooo`;o0000Foooool2o`0000?ooooo0_l0000Cooooo`000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003o
ooooooooo`0aooooo`;o0000R?ooool2o`0000;ooooo0_l0000jooooo`;o0000<?ooool2o`0000?o
oooo0_l0000Cooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0aooooo`;o00002oooool2o`00
0;_ooooo0_l0001:ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooo
ooooooooooooo`000006ooooo`?o0000;oooool2o`0000gooooo0_l0003oooooo`Sooooo0003oooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o
0000ooooooooool06_ooool2o`0001?ooooo0_l0000Uooooo`;o0000T?ooool2o`0005gooooo0003
ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo
00?o0000ooooooooool00_l00007ooooo`;o00003oooool2o`0002kooooo0_l0000:ooooo`;o0000
1Oooool2o`0003Kooooo0_l0000Wooooo`;o00006_ooool2o`0000cooooo0_l0001Mooooo`000ooo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`;o
000000?oooooo`000?l000001oooool2o`0003oooooo0_l0000Aooooo`;o0000=_ooool2o`0000Ko
oooo0_l0000Oooooo`;o00006_ooool2o`0006_ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo0_l0002Nooooo`;o0000B?ooool2o`00
05kooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413o
ZJVY00Kooooo00?o0000ooooooooool07oooool2o`0002;ooooo0_l00015ooooo`;o00004_ooool2
o`0004Oooooo0_l0000Kooooo`;o00004?ooool2o`0002oooooo000Nooooo`03o`000?oooooooooo
01[ooooo0_l00003ooooo`;o00008_ooool2o`0003?ooooo0_l0000@ooooo`;o00000_ooool2o`00
00kooooo0_l0001Tooooo`;o00004?ooool2o`0001;ooooo0_l0000Kooooo`007_ooool00ol0003o
ooooooooo`0Jooooo`;o0000G?ooool2o`0001Cooooo0_l0002Jooooo`;o00006oooool001kooooo
00?o0000ooooooooool0jOooool2o`0000gooooo0_l0000Gooooo`;o00002Oooool2o`0002Wooooo
000Nooooo`03o`000?oooooooooo05Wooooo0_l0001booooo`;o00006_ooool2o`0000gooooo0_l0
000Gooooo`;o00002Oooool2o`0000cooooo0_l0000Kooooo`007_ooool00ol0003oooooooooo`1I
ooooo`;o0000L_ooool2o`0004Gooooo0_l0000Dooooo`;o00001Oooool2o`0001Cooooo000Noooo
o`03o`000?oooooooooo01[ooooo0_l0001?ooooo`;o0000@?ooool2o`0001kooooo0_l0000=oooo
o`;o0000=_ooool2o`0000Oooooo0_l0000Booooo`;o00005?ooool001kooooo00?o0000oooooooo
ool04oooool2o`0000Gooooo0_l0001?ooooo`;o0000@?ooool2o`0002gooooo0_l0000oooooo`;o
0000:?ooool001kooooo00?o0000ooooooooool04oooool2o`000<?ooooo0_l0001]ooooo`007_oo
ool00ol0003oooooooooo`0Aooooo`;o0000JOooool2o`0003Cooooo0_l0000:ooooo`;o00006?oo
ool2o`0005Wooooo0_l0000Booooo`007_ooool00ol0003oooooooooo`0Aooooo`;o0000JOooool2
o`0003Cooooo0_l00009ooooo`?o0000Loooool2o`0001;ooooo000Nooooo`03o`000?oooooooooo
0;gooooo0_l00004ooooo`;o00001Oooool2o`0001gooooo0_l0000Yooooo`;o0000<Oooool001ko
oooo0_l00034ooooo`;o00001Oooool2o`0001gooooo0_l0000Yooooo`;o0000<Oooool001kooooo
00?o0000ooooooooool0oooooolWooooo`;o00007oooool001kooooo00?o0000ooooooooool08ooo
ool2o`0001Wooooo0_l0001]ooooo`;o00001Oooool2o`0006Gooooo0_l00009ooooo`;o00007ooo
ool001kooooo00?o0000ooooooooool00_ooool2o`0001oooooo0_l0000Iooooo`;o0000G_ooool2
o`0000Sooooo0_l00003ooooo`;o00001Oooool2o`00033ooooo0_l0000cooooo`;o0000:_ooool0
01kooooo00?o0000ooooooooool00_ooool2o`0000Sooooo0_l0001Pooooo`;o0000;_ooool2o`00
00Sooooo0_l0000looooo`;o0000COooool2o`00013ooooo000Nooooo`04o`000?oooooooooooooo
o`;o00002Oooool2o`00063ooooo0_l00007ooooo`;o00001?ooool2o`0007Oooooo0_l0000goooo
o`;o00001?ooool3o`0000oooooo000Nooooo`04o`000?ooooooooooooooo`;o0000M?ooool2o`00
00Cooooo0_l0001gooooo`;o0000=oooool2o`0000Gooooo0_l0000?ooooo`007_ooool00ol0003o
ooooooooo`0>ooooo`;o0000Loooool2o`0007gooooo0_l00013ooooo`007_ooool00ol0003ooooo
ooooo`0>ooooo`;o0000L_ooool3o`00047ooooo0_l0000Jooooo`;o00007_ooool2o`0004?ooooo
000Mooooo`;o00007?ooool2o`0006Kooooo0_l00012ooooo`;o00006_ooool2o`0006?ooooo000M
ooooo`;o00007?ooool2o`0000kooooo0_l0000Pooooo`;o0000U?ooool2o`0006?ooooo000Noooo
o`03o`000?oooooooooo02[ooooo0_l0000Pooooo`;o0000T?ooool2o`0006Oooooo000Nooooo`03
o`000?oooooooooo09;ooooo0_l00018ooooo`Go00006oooool2o`0004Wooooo000Nooooo`03o`00
0?oooooooooo00_ooooo0_l00025ooooo`;o00007oooool2o`0002Oooooo1Ol0000Kooooo`;o0000
1oooool2o`0001?ooooo0_l0000[ooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o00002?oo
ool2o`0004Oooooo0_l0001Cooooo`;o0000;Oooool2o`0000oooooo0_l0000@ooooo`;o00004ooo
ool2o`0000Wooooo0_l0000Pooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o0000Aoooool2
o`0002_ooooo0_l00005ooooo`;o0000?oooool2o`0000gooooo0_l0000?ooooo`;o0000<?ooool2
o`00023ooooo000Nooooo`;o0000F_ooool2o`0000Cooooo0_l0000Zooooo`;o00001Oooool2o`00
02gooooo0_l00008ooooo`;o00001_ooool2o`0000oooooo0_l0000Fooooo`;o0000<oooool2o`00
01Cooooo000Nooooo`03o`000?oooooooooo03_ooooo0_l0000Looooo`;o00001?ooool2o`0000[o
oooo0_l0001Dooooo`;o00002?ooool2o`0001Oooooo0_l0000Fooooo`;o0000<oooool2o`0001Co
oooo000Nooooo`03o`000?oooooooooo03;ooooo0_l00007ooooo`;o0000;_ooool2o`000=[ooooo
000Nooooo`03o`000?oooooooooo00_ooooo0_l0000<ooooo`;o00005oooool2o`0000cooooo0_l0
000Booooo`;o0000?oooool2o`0004Oooooo0_l0000kooooo`;o0000:_ooool001kooooo00?o0000
ooooooooool02oooool2o`0000cooooo0_l0000Uooooo`;o00004_ooool2o`00013ooooo0_l0000]
ooooo`;o00007Oooool2o`0002Sooooo0_l0000kooooo`;o0000:_ooool001kooooo00?o0000oooo
ooooool06_ooool2o`0004[ooooo0_l0001<ooooo`;o0000JOooool2o`0002Kooooo000Nooooo`03
o`000?oooooooooo01[ooooo0_l00013ooooo`;o0000E?ooool2o`0004oooooo0_l0000Gooooo`;o
00009_ooool001kooooo00?o0000ooooooooool01Oooool2o`0005Sooooo0_l00005ooooo`;o0000
9Oooool2o`0002Kooooo0_l0001?ooooo`;o00008oooool2o`0001[ooooo000Nooooo`03o`000?oo
oooooooo00Gooooo0_l0001Oooooo`;o00009Oooool2o`00037ooooo0_l0001Jooooo`?o00003?oo
ool2o`0001[ooooo000Nooooo`03o`000?oooooooooo00;o0000Joooool2o`00057ooooo0_l0000a
ooooo`;o00009oooool3o`0001oooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`02o`00
06_ooooo0_l0001;ooooo`;o0000=oooool2o`0004Wooooo0_l00007ooooo`007_ooool00ol0003o
ooooooooo`12ooooo`;o0000Loooool2o`000003ooooool0003o000008_ooooo000Nooooo`03o`00
0?oooooooooo01?ooooo0_l0000<ooooo`;o00007oooool2o`0007?ooooo1?l0000hooooo`;o0000
D_ooool001kooooo00?o0000ooooooooool04Oooool4o`0000cooooo0_l0000Gooooo`;o0000FOoo
ool2o`0002;ooooo0_l0000hooooo`;o0000D_ooool001kooooo00?o0000ooooooooool04Oooool2
o`0002Oooooo0_l0001Iooooo`;o0000Ooooool2o`0001;ooooo0_l0000Kooooo`007_ooool00ol0
003oooooooooo`0gooooo`;o0000_oooool2o`0001cooooo0_l0000Booooo`;o00006oooool001ko
oooo0_l0000hooooo`;o0000_oooool2o`0004gooooo000Nooooo`03o`000?oooooooooo0?oooooo
5?ooool2o`0003;ooooo000Nooooo`03o`000?oooooooooo02[ooooo0_l0000;ooooo`;o0000MOoo
ool2o`0006?ooooo0_l0000booooo`007_ooool2o`0002_ooooo0_l0000;ooooo`;o0000BOooool2
o`0002[ooooo0_l00014ooooo`;o0000DOooool001kooooo0_l0001]ooooo`;o00005?ooool2o`00
02gooooo0_l00011ooooo`;o00006_ooool2o`0000gooooo0_l0000Vooooo`007_ooool00ol0003o
ooooooooo`02ooooo`;o00001oooool2o`0002Gooooo0_l0000hooooo`;o0000@oooool2o`0005go
oooo0_l0000=ooooo`;o00007?ooool2o`0000Sooooo000Nooooo`05o`000?oooooo0000o`000?oo
ool00_l00007ooooo`;o00008_ooool2o`000003ooooool0003o000005?ooooo0_l0002dooooo`;o
00002?ooool001kooooo00Co0000ooooool0003o00006?ooool2o`0001Cooooo0_l00010ooooo`;o
00005?ooool2o`0001;ooooo0_l0002Zooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o0000
5?ooool2o`00043ooooo0_l0000Mooooo`;o00002Oooool2o`00033ooooo0_l00014ooooo`;o0000
<_ooool001kooooo00?o0000ooooooooool0T?ooool2o`0000_ooooo0_l0000Gooooo`;o00001_oo
ool2o`0000gooooo0_l00009ooooo`;o0000;oooool2o`0000Sooooo0_l0000booooo`007_ooool0
0ol0003oooooooooo`0;ooooo`;o0000T?ooool2o`0001Oooooo0_l00006ooooo`;o00006?ooool2
o`0000Oooooo0_l0000Vooooo`;o0000??ooool001kooooo00?o0000ooooooooool02oooool2o`00
08Oooooo0_l0001;ooooo`;o0000Aoooool2o`0001_ooooo000Nooooo`03o`000?oooooooooo04_o
oooo0_l00017ooooo`;o0000@?ooool2o`0002Cooooo0_l0000Iooooo`;o00004Oooool2o`0001_o
oooo000Nooooo`03o`000?oooooooooo00?ooooo0_l00016ooooo`;o0000ROooool2o`00017ooooo
0_l0000Aooooo`;o00006Oooool2o`0001Wooooo0_l0000Cooooo`005?ooool4o`000003oa0@4?oo
oooooooo00?ooooo00Co0000ooooool0003o00000_ooool2o`000>Cooooo0_l00017ooooo`;o0000
4oooool001Kooooo00?o0000ooooooooool01Oooool01?l0003oooooo`000?l0000mooooo`;o0000
6?ooool2o`0001Wooooo0_l0000Jooooo`;o0000N?ooool2o`0003cooooo000Fooooo`03o`000?oo
oooooooo00Gooooo0ol0000[ooooo`;o00004Oooool2o`0001Sooooo0_l0000Iooooo`;o00006_oo
ool2o`0007Sooooo0_l0000looooo`005_ooool00ol0003oooooooooo`0cooooo`;o0000oooooolK
ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?oo
ooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005?ooool00omEEEGoIVIVo`00
003ooooooe;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.61135 .24394 Mdot
.52497 .49182 Mdot
.9567 .52004 Mdot
.37343 .59331 Mdot
.5559 .95996 Mdot
.70516 .76121 Mdot
.67248 .62368 Mdot
.96607 .85858 Mdot
.30112 .31593 Mdot
.06074 .89794 Mdot
.33424 .41096 Mdot
.16102 .08391 Mdot
.03644 .47335 Mdot
.32611 .90622 Mdot
.77081 .65132 Mdot
.63013 .00094 Mdot
.89656 .00611 Mdot
.23461 .92189 Mdot
.55437 .07492 Mdot
.95159 .38951 Mdot
.93349 .06758 Mdot
.20134 .17357 Mdot
.28557 .33906 Mdot
.73031 .78003 Mdot
.56109 .17047 Mdot
.08655 .1934 Mdot
.10206 .8394 Mdot
.13854 .50527 Mdot
.88959 .51942 Mdot
.20713 .89106 Mdot
.6554 .77336 Mdot
.94264 .82757 Mdot
.03864 .38064 Mdot
.05409 .33097 Mdot
.43666 .72546 Mdot
.64316 .23921 Mdot
.55403 .87825 Mdot
.23522 .73198 Mdot
.76408 .71182 Mdot
.78476 .54041 Mdot
.55845 .49594 Mdot
.8856 .96858 Mdot
.59226 .05296 Mdot
.62873 .44023 Mdot
.24082 .34603 Mdot
.89586 .80625 Mdot
.12058 .30521 Mdot
.56755 .23805 Mdot
.25747 .74968 Mdot
.0151 .82119 Mdot
.17527 .72284 Mdot
.90973 .97448 Mdot
.93429 .91195 Mdot
.35096 .3238 Mdot
.03094 .18091 Mdot
.40574 .19237 Mdot
.48364 .14451 Mdot
.82409 .07586 Mdot
.67642 .15206 Mdot
.57089 .52301 Mdot
.73391 .72033 Mdot
.2471 .01134 Mdot
.23941 .30421 Mdot
.00625 .7279 Mdot
.62736 .07687 Mdot
.97308 .72685 Mdot
.27 .57401 Mdot
.25248 .83415 Mdot
.47226 .74608 Mdot
.11831 .44738 Mdot
.48506 .27517 Mdot
.23502 .6138 Mdot
.05441 .88227 Mdot
.66901 .92295 Mdot
.50673 .8979 Mdot
.35498 .87775 Mdot
.19768 .4979 Mdot
.69447 .83613 Mdot
.25097 .2433 Mdot
.7483 .30602 Mdot
.08911 .17096 Mdot
.32659 .18228 Mdot
.28922 .21459 Mdot
.77751 .24881 Mdot
.54141 .01622 Mdot
.79017 .65301 Mdot
.71604 .44075 Mdot
.11617 .45989 Mdot
.19567 .25411 Mdot
.74209 .30242 Mdot
.64172 .32206 Mdot
.6716 .68418 Mdot
.87315 .84941 Mdot
.6784 .81305 Mdot
.27667 .94419 Mdot
.58507 .87569 Mdot
.04781 .61301 Mdot
.48191 .53212 Mdot
.64368 .86465 Mdot
.04123 .75154 Mdot
.75577 .28815 Mdot
.61881 .13137 Mdot
.7961 .27805 Mdot
.62352 .13383 Mdot
.24395 .76112 Mdot
.2682 .6381 Mdot
.659 .13689 Mdot
.00536 .4559 Mdot
.29551 .83357 Mdot
.2064 .23063 Mdot
.96424 .28884 Mdot
.47556 .78416 Mdot
.89529 .68116 Mdot
.54396 .34146 Mdot
.40908 .08408 Mdot
.60097 .89255 Mdot
.48113 .63311 Mdot
.64304 .56746 Mdot
.13598 .82182 Mdot
.95507 .81454 Mdot
.53413 .28915 Mdot
.43542 .25547 Mdot
.88172 .30751 Mdot
.28032 .78275 Mdot
.67183 .30873 Mdot
.41976 .75835 Mdot
.58781 .91959 Mdot
.13686 .55003 Mdot
.79526 .60151 Mdot
.17149 .2925 Mdot
.9591 .10333 Mdot
.53545 .17063 Mdot
.7583 .12739 Mdot
.77767 .60249 Mdot
.55649 .12902 Mdot
.8238 .12887 Mdot
.19242 .49807 Mdot
.08185 .05901 Mdot
.92195 .2567 Mdot
.2641 .82143 Mdot
.81407 .3431 Mdot
.77804 .21846 Mdot
.53742 .56862 Mdot
.56213 .36351 Mdot
.09449 .76117 Mdot
.46294 .453 Mdot
.22172 .94595 Mdot
.95575 .64491 Mdot
.72369 .77079 Mdot
.55575 .2647 Mdot
.11835 .1833 Mdot
.60664 .75992 Mdot
.62099 .15307 Mdot
.51593 .21314 Mdot
.76392 .26676 Mdot
.26446 .16727 Mdot
.97854 .20078 Mdot
.49538 .02224 Mdot
.06347 .57707 Mdot
.8506 .05653 Mdot
.02024 .49501 Mdot
.96885 .11422 Mdot
.21886 .00752 Mdot
.69228 .03956 Mdot
.92418 .15965 Mdot
.85524 .14701 Mdot
.84261 .20949 Mdot
.90452 .66647 Mdot
.17956 .69287 Mdot
.73478 .95683 Mdot
.80028 .41927 Mdot
.19117 .21522 Mdot
.46986 .61719 Mdot
.89937 .78507 Mdot
.93187 .29404 Mdot
.88663 .0601 Mdot
.32532 .44165 Mdot
.71258 .60995 Mdot
.16432 .92289 Mdot
.49601 .62886 Mdot
.29724 .54308 Mdot
.0675 .97551 Mdot
.81241 .79956 Mdot
.18955 .44335 Mdot
.0276 .49659 Mdot
.61283 .9792 Mdot
.77671 .90037 Mdot
.39796 .6016 Mdot
.76748 .76964 Mdot
.36362 .32138 Mdot
.2873 .52669 Mdot
.55781 .3756 Mdot
.67873 .30023 Mdot
.16112 .71538 Mdot
.18366 .19381 Mdot
.28416 .94748 Mdot
.48306 .00873 Mdot
.99388 .28528 Mdot
.38858 .79951 Mdot
.914 .36632 Mdot
.92688 .34408 Mdot
.24036 .36977 Mdot
.32506 .13658 Mdot
.99565 .30583 Mdot
.95919 .52027 Mdot
.52072 .90629 Mdot
.45588 .63199 Mdot
.55767 .63653 Mdot
.30323 .31483 Mdot
.2443 .66181 Mdot
.60252 .19643 Mdot
.63904 .61405 Mdot
.99131 .16094 Mdot
.71281 .5488 Mdot
.35552 .35249 Mdot
.39924 .55777 Mdot
.71401 .51858 Mdot
.18483 .9752 Mdot
.93152 .20401 Mdot
.33553 .02071 Mdot
.9637 .56654 Mdot
.77662 .0429 Mdot
.03659 .05757 Mdot
.45383 .75167 Mdot
.36397 .20533 Mdot
.42996 .89217 Mdot
.32067 .5405 Mdot
.33829 .64925 Mdot
.91788 .32502 Mdot
.83154 .35935 Mdot
.65827 .44135 Mdot
.80609 .65363 Mdot
.01376 .18965 Mdot
.71773 .29412 Mdot
.6649 .44678 Mdot
.58478 .85543 Mdot
.99379 .56036 Mdot
.83822 .65755 Mdot
.98791 .7137 Mdot
.81542 .30995 Mdot
.76285 .06244 Mdot
.68038 .63861 Mdot
.78871 .94484 Mdot
.18555 .29326 Mdot
.09153 .42727 Mdot
.15013 .31388 Mdot
.10586 .29168 Mdot
.88918 .77345 Mdot
.4365 .04916 Mdot
.37396 .81067 Mdot
.75701 .64697 Mdot
.86399 .17564 Mdot
.68061 .2618 Mdot
.50432 .86139 Mdot
.20806 .64789 Mdot
.63703 .2489 Mdot
.43822 .53468 Mdot
.16741 .6127 Mdot
.00337 .93065 Mdot
.95912 .16756 Mdot
.89548 .19684 Mdot
.91962 .03231 Mdot
.45282 .24007 Mdot
.73972 .54965 Mdot
.4545 .28778 Mdot
.55656 .00035 Mdot
.55671 .3215 Mdot
.60226 .06267 Mdot
.43745 .10709 Mdot
.74136 .75904 Mdot
.73242 .85989 Mdot
.4629 .27986 Mdot
.52099 .97488 Mdot
.85473 .55015 Mdot
.39152 .05379 Mdot
.80781 .70705 Mdot
.61802 .08317 Mdot
.56441 .38393 Mdot
.37701 .43371 Mdot
.27827 .01372 Mdot
.63853 .65466 Mdot
.22473 .5733 Mdot
.21883 .46789 Mdot
.07751 .60186 Mdot
.38995 .179 Mdot
.5369 .35789 Mdot
.3174 .43901 Mdot
.41043 .33615 Mdot
.39566 .68261 Mdot
.53164 .26301 Mdot
.69178 .54869 Mdot
.57137 .93783 Mdot
.74181 .59858 Mdot
.01875 .05686 Mdot
.83241 .4326 Mdot
.26006 .75976 Mdot
.12014 .94503 Mdot
.42176 .72634 Mdot
.49556 .17962 Mdot
.32389 .06624 Mdot
.424 .18353 Mdot
.48015 .11519 Mdot
.42254 .94289 Mdot
.22875 .48848 Mdot
.35723 .65985 Mdot
.88669 .12226 Mdot
.83671 .53007 Mdot
.93423 .04349 Mdot
.02866 .28091 Mdot
.20654 .64392 Mdot
.219 .42318 Mdot
.56317 .26517 Mdot
.10686 .92009 Mdot
.76265 .84418 Mdot
.39169 .29742 Mdot
.85205 .66098 Mdot
.34144 .31975 Mdot
.2889 .84289 Mdot
.18308 .09939 Mdot
.66168 .47718 Mdot
.47009 .50345 Mdot
.1546 .15348 Mdot
.56681 .38836 Mdot
.90198 .57946 Mdot
.76457 .15381 Mdot
.82103 .04969 Mdot
.06361 .17388 Mdot
.64427 .06902 Mdot
.04007 .53446 Mdot
.03852 .53913 Mdot
.54203 .75477 Mdot
.69296 .75284 Mdot
.38643 .9385 Mdot
.23219 .90448 Mdot
.50966 .23378 Mdot
.64687 .02545 Mdot
.04645 .77076 Mdot
.13888 .29482 Mdot
.67711 .91824 Mdot
.18943 .91283 Mdot
.94832 .05349 Mdot
.8222 .68934 Mdot
.09612 .61294 Mdot
.4588 .26393 Mdot
.00658 .99137 Mdot
.91116 .03456 Mdot
.19184 .4374 Mdot
.58669 .33015 Mdot
.45232 .35563 Mdot
.12889 .35252 Mdot
.4636 .76794 Mdot
.25488 .12867 Mdot
.82847 .03059 Mdot
.11873 .12288 Mdot
.0516 .08523 Mdot
.97388 .17509 Mdot
.72098 .41809 Mdot
.753 .44968 Mdot
.21674 .29843 Mdot
.49512 .80877 Mdot
.07537 .62341 Mdot
.04404 .77235 Mdot
.30537 .18126 Mdot
.097 .31968 Mdot
.7839 .46504 Mdot
.66118 .89017 Mdot
.03621 .06872 Mdot
.99969 .38992 Mdot
.00702 .32975 Mdot
.56228 .24809 Mdot
.48226 .34237 Mdot
.38936 .75012 Mdot
.71587 .3949 Mdot
.03024 .30654 Mdot
.10952 .53542 Mdot
.25897 .66041 Mdot
.99656 .37971 Mdot
.28108 .0915 Mdot
.2646 .62721 Mdot
.59216 .38089 Mdot
.93541 .98395 Mdot
.717 .81251 Mdot
.14502 .95645 Mdot
.63841 .36762 Mdot
.73888 .86795 Mdot
.28882 .38585 Mdot
.32676 .01055 Mdot
.71704 .05019 Mdot
.64748 .94688 Mdot
.76358 .64578 Mdot
.0611 .63092 Mdot
.86468 .57369 Mdot
.80138 .32819 Mdot
.45558 .44079 Mdot
.97042 .06177 Mdot
.50728 .75554 Mdot
.92292 .51804 Mdot
.52389 .67742 Mdot
.27801 .19261 Mdot
.49686 .94886 Mdot
.95514 .55871 Mdot
.03186 .99834 Mdot
.21212 .2405 Mdot
.86799 .09808 Mdot
.09632 .22117 Mdot
.10023 .97658 Mdot
.44629 .84519 Mdot
.91176 .91237 Mdot
.20982 .63557 Mdot
.69557 .54008 Mdot
.61846 .12849 Mdot
.8867 .91267 Mdot
.3501 .25242 Mdot
.1655 .23902 Mdot
.45503 .69548 Mdot
.61823 .81869 Mdot
.66612 .79189 Mdot
.1958 .15839 Mdot
.5488 .63296 Mdot
.61835 .931 Mdot
.01496 .30508 Mdot
.22997 .69944 Mdot
.72036 .48565 Mdot
.01726 .48211 Mdot
.04534 .92383 Mdot
.53046 .56538 Mdot
.30103 .91303 Mdot
.2301 .06648 Mdot
.93725 .43199 Mdot
.33584 .22846 Mdot
.70863 .49319 Mdot
.03958 .97319 Mdot
.3776 .50605 Mdot
.13581 .5927 Mdot
.97093 .70383 Mdot
.79412 .8015 Mdot
.60315 .08966 Mdot
.95049 .92688 Mdot
.62768 .86532 Mdot
.04606 .17243 Mdot
.9961 .74885 Mdot
.02045 .26357 Mdot
.59913 .557 Mdot
.66146 .97705 Mdot
.90817 .36198 Mdot
.85062 .70562 Mdot
.25071 .35181 Mdot
.35442 .59019 Mdot
.33844 .94223 Mdot
.08274 .34752 Mdot
.01479 .76544 Mdot
.3445 .86833 Mdot
.34271 .33606 Mdot
.01032 .91006 Mdot
.05957 .46121 Mdot
.03778 .61338 Mdot
.83238 .40045 Mdot
.88274 .22288 Mdot
.27027 .36605 Mdot
.83234 .94961 Mdot
.24171 .11952 Mdot
.06136 .91307 Mdot
.90038 .03981 Mdot
.0307 .73718 Mdot
.88066 .01676 Mdot
.70291 .51582 Mdot
.14293 .23752 Mdot
.35868 .57799 Mdot
.99372 .52612 Mdot
.15702 .66875 Mdot
.4102 .46343 Mdot
.00251 .4048 Mdot
.47715 .66947 Mdot
.24781 .80273 Mdot
.2552 .32421 Mdot
.54097 .76525 Mdot
.68448 .61924 Mdot
.51821 .94042 Mdot
.86102 .05793 Mdot
.48328 .0515 Mdot
.54718 .21842 Mdot
.00086 .69478 Mdot
.45999 .07436 Mdot
.68715 .60828 Mdot
.65871 .71423 Mdot
.7572 .11493 Mdot
.71947 .07321 Mdot
.54075 .03803 Mdot
.34248 .76537 Mdot
.70932 .77653 Mdot
.79887 .39154 Mdot
.90234 .04183 Mdot
.93093 .86687 Mdot
.21318 .03404 Mdot
.80345 .10199 Mdot
.22263 .73093 Mdot
.82273 .70049 Mdot
.16053 .93545 Mdot
.79655 .30544 Mdot
.93795 .58432 Mdot
.76775 .85899 Mdot
.54745 .49989 Mdot
.28253 .76898 Mdot
.33092 .76892 Mdot
.66907 .60805 Mdot
.42329 .05851 Mdot
.55472 .81704 Mdot
.51225 .00832 Mdot
.03934 .42797 Mdot
.0453 .38366 Mdot
.56354 .4328 Mdot
.78132 .11682 Mdot
.48294 .26242 Mdot
.55649 .30368 Mdot
.51077 .80138 Mdot
.91884 .21164 Mdot
.15648 .89111 Mdot
.18435 .47743 Mdot
.29172 .74768 Mdot
.98874 .15446 Mdot
.93607 .99977 Mdot
.26897 .45127 Mdot
.69772 .88404 Mdot
.1646 .65264 Mdot
.89127 .94293 Mdot
.92899 .67715 Mdot
.7041 .44082 Mdot
.701 .76589 Mdot
.85335 .23902 Mdot
.20339 .97071 Mdot
.88291 .81667 Mdot
.52662 .13146 Mdot
.62686 .49868 Mdot
.56874 .35625 Mdot
.25838 .92047 Mdot
.0795 .38921 Mdot
.66917 .29961 Mdot
.46472 .40073 Mdot
.64839 .54871 Mdot
.4609 .96063 Mdot
.10161 .98418 Mdot
.9327 .67886 Mdot
.54503 .48048 Mdot
.74028 .8589 Mdot
.60031 .68455 Mdot
.8477 .82118 Mdot
.02844 .0772 Mdot
.08999 .74761 Mdot
.68917 .09808 Mdot
.31145 .02411 Mdot
.71884 .23632 Mdot
.15803 .74984 Mdot
.30141 .94563 Mdot
.90134 .76249 Mdot
.07014 .77378 Mdot
.48897 .59025 Mdot
.14922 .77524 Mdot
.32299 .08268 Mdot
.79566 .01583 Mdot
.5429 .64617 Mdot
.43411 .23638 Mdot
.92471 .3076 Mdot
.40121 .30907 Mdot
.07365 .24335 Mdot
.41793 .67824 Mdot
.84517 .1693 Mdot
.03299 .23157 Mdot
.04421 .27546 Mdot
.19986 .13524 Mdot
.41101 .51137 Mdot
.07974 .80823 Mdot
.18026 .17518 Mdot
.34521 .88657 Mdot
.93545 .17977 Mdot
.62919 .25206 Mdot
.19382 .61428 Mdot
.53217 .88935 Mdot
.01932 .13159 Mdot
.80672 .98004 Mdot
.66968 .53691 Mdot
.28384 .5299 Mdot
.5803 .70752 Mdot
.50872 .40685 Mdot
.06876 .8427 Mdot
.84278 .84525 Mdot
.45152 .98336 Mdot
.9139 .26363 Mdot
.57102 .05267 Mdot
.0656 .689 Mdot
.22444 .24075 Mdot
.5815 .4067 Mdot
.24042 .38521 Mdot
.97861 .19657 Mdot
.99205 .36664 Mdot
.78171 .45919 Mdot
.59996 .84322 Mdot
.61871 .3054 Mdot
.47515 .17318 Mdot
.40085 .35657 Mdot
.21393 .79839 Mdot
.64121 .34119 Mdot
.67713 .24692 Mdot
.747 .63806 Mdot
.74642 .55216 Mdot
.45852 .75466 Mdot
.45129 .86034 Mdot
.97173 .59962 Mdot
.53433 .33444 Mdot
.02628 .97856 Mdot
.37291 .48071 Mdot
.33385 .93189 Mdot
.84525 .35684 Mdot
.99968 .26191 Mdot
.85198 .41597 Mdot
.93511 .32664 Mdot
.41447 .56097 Mdot
.80347 .25215 Mdot
.65449 .3785 Mdot
.13715 .97564 Mdot
.43823 .36374 Mdot
.42187 .30813 Mdot
.74339 .19867 Mdot
.78157 .69247 Mdot
.22324 .52215 Mdot
.08997 .10885 Mdot
.05312 .41012 Mdot
.84435 .47711 Mdot
.95256 .16481 Mdot
.72785 .89147 Mdot
.98432 .46218 Mdot
.89575 .23697 Mdot
.85104 .40652 Mdot
.788 .62634 Mdot
.78936 .52625 Mdot
.69638 .23998 Mdot
.26547 .6976 Mdot
.28863 .44724 Mdot
.52003 .59838 Mdot
.75245 .66684 Mdot
.88364 .75965 Mdot
.71489 .45008 Mdot
.58807 .96471 Mdot
.12973 .90402 Mdot
.03668 .87094 Mdot
.66192 .59334 Mdot
.56553 .65345 Mdot
.65137 .03468 Mdot
.99383 .64225 Mdot
.05006 .90138 Mdot
.78795 .3544 Mdot
.60667 .54287 Mdot
.58878 .28615 Mdot
.57487 .40135 Mdot
.3102 .01414 Mdot
.75442 .18482 Mdot
.95797 .4428 Mdot
.41525 .9111 Mdot
.07222 .47913 Mdot
.44229 .5617 Mdot
.4082 .16365 Mdot
.07011 .97219 Mdot
.92241 .11888 Mdot
.78174 .73912 Mdot
.02801 .51521 Mdot
.89189 .64476 Mdot
.02306 .82478 Mdot
.82624 .77281 Mdot
.751 .04834 Mdot
.73553 .54907 Mdot
.98784 .89605 Mdot
.97975 .29821 Mdot
.28038 .03882 Mdot
.58858 .01951 Mdot
.66239 .60923 Mdot
.12053 .59802 Mdot
.32882 .40105 Mdot
.54388 .27385 Mdot
.62052 .90283 Mdot
.39899 .18624 Mdot
.55674 .52056 Mdot
.98147 .32727 Mdot
.87991 .96606 Mdot
.31377 .34393 Mdot
.29872 .23315 Mdot
.41264 .63576 Mdot
.9429 .314 Mdot
.61541 .72505 Mdot
.3116 .59741 Mdot
.75066 .77075 Mdot
.00035 .00977 Mdot
.67728 .25673 Mdot
.13284 .80007 Mdot
.38301 .60593 Mdot
.56578 .16146 Mdot
.7567 .94653 Mdot
.95036 .23683 Mdot
.66025 .63093 Mdot
.69 .24341 Mdot
.73046 .22024 Mdot
.06044 .33746 Mdot
.28477 .14092 Mdot
.38716 .00946 Mdot
.93214 .19818 Mdot
.93161 .89014 Mdot
.23018 .27494 Mdot
.69271 .04291 Mdot
.16736 .00938 Mdot
.04884 .11717 Mdot
.81432 .06603 Mdot
.04391 .5561 Mdot
.76879 .15924 Mdot
.66724 .54736 Mdot
.79947 .70794 Mdot
.60608 .85108 Mdot
.19609 .81521 Mdot
.98192 .65118 Mdot
.64548 .86635 Mdot
.97051 .90925 Mdot
.79816 .54064 Mdot
.24613 .11477 Mdot
.66533 .79163 Mdot
.5114 .24217 Mdot
.57868 .94545 Mdot
.52435 .38376 Mdot
.46486 .9276 Mdot
.60223 .22378 Mdot
.95161 .42437 Mdot
.93342 .90026 Mdot
.99371 .2527 Mdot
.63833 .67971 Mdot
.51622 .03916 Mdot
.72536 .87551 Mdot
.15124 .94096 Mdot
.89507 .95689 Mdot
.88938 .29912 Mdot
.70391 .88006 Mdot
.12444 .69263 Mdot
.77708 .33185 Mdot
.85188 .94863 Mdot
.53263 .75143 Mdot
.54134 .38295 Mdot
.57261 .75925 Mdot
.34377 .6584 Mdot
.15692 .56297 Mdot
.87745 .41828 Mdot
.93495 .9319 Mdot
.29234 .42244 Mdot
.56382 .73873 Mdot
.84647 .04713 Mdot
.46775 .08378 Mdot
.31756 .77131 Mdot
.2482 .01965 Mdot
.47083 .08316 Mdot
.36976 .57591 Mdot
.43176 .10639 Mdot
.89835 .69478 Mdot
.2375 .37322 Mdot
.26484 .44405 Mdot
.25574 .26686 Mdot
.02063 .032 Mdot
.09156 .53559 Mdot
.24228 .62777 Mdot
.08909 .44617 Mdot
.31013 .29853 Mdot
.93668 .68791 Mdot
.62485 .03602 Mdot
.1928 .26185 Mdot
.41751 .66331 Mdot
.26303 .2119 Mdot
.46849 .89585 Mdot
.69281 .63273 Mdot
.7538 .17603 Mdot
.92081 .39614 Mdot
.82084 .22424 Mdot
.52326 .64998 Mdot
.20535 .24814 Mdot
.89305 .27248 Mdot
.8893 .90334 Mdot
.01842 .70499 Mdot
.16631 .92452 Mdot
.43387 .81082 Mdot
.00708 .71765 Mdot
.0479 .87714 Mdot
.58656 .85264 Mdot
.82003 .14524 Mdot
.07482 .29982 Mdot
.98179 .20011 Mdot
.56035 .3734 Mdot
.77105 .23219 Mdot
.35109 .79682 Mdot
.06117 .85355 Mdot
.502 .56043 Mdot
.32487 .7389 Mdot
.1694 .53288 Mdot
.57887 .18425 Mdot
.90418 .00847 Mdot
.44981 .72504 Mdot
.15169 .37077 Mdot
.77829 .20086 Mdot
.27834 .31231 Mdot
.69558 .27646 Mdot
.23964 .83196 Mdot
.31039 .72622 Mdot
.42265 .95755 Mdot
.67765 .68078 Mdot
.56504 .74539 Mdot
.78725 .17226 Mdot
.97536 .05363 Mdot
.02319 .77005 Mdot
.50862 .36201 Mdot
.5636 .25648 Mdot
.92596 .36416 Mdot
.17493 .30062 Mdot
.98948 .85018 Mdot
.55213 .243 Mdot
.26769 .57923 Mdot
.17719 .88984 Mdot
.01149 .1516 Mdot
.0899 .38811 Mdot
.35738 .41029 Mdot
.74508 .93218 Mdot
.53129 .73315 Mdot
.51222 .9904 Mdot
.30205 .04979 Mdot
.00303 .00973 Mdot
.97483 .88966 Mdot
.769 .44178 Mdot
.03562 .62003 Mdot
.26622 .2469 Mdot
.70609 .15089 Mdot
.49068 .53367 Mdot
.66832 .05848 Mdot
.4275 .28702 Mdot
.82386 .64819 Mdot
.24047 .61711 Mdot
.83735 .27805 Mdot
.92412 .92592 Mdot
.54337 .08644 Mdot
.46837 .78598 Mdot
.82185 .78438 Mdot
.88238 .22476 Mdot
.79593 .30281 Mdot
.71577 .00771 Mdot
.4462 .56021 Mdot
.96324 .39582 Mdot
.31643 .23736 Mdot
.0436 .46533 Mdot
.78572 .63534 Mdot
.43464 .86015 Mdot
.56557 .23213 Mdot
.28718 .75102 Mdot
.05792 .7717 Mdot
.70643 .2031 Mdot
.93232 .15061 Mdot
.30987 .50899 Mdot
.80696 .26456 Mdot
.03608 .42701 Mdot
.81179 .34711 Mdot
.6727 .65494 Mdot
.7085 .04008 Mdot
.56085 .10586 Mdot
.45803 .48757 Mdot
.96929 .66648 Mdot
.72249 .0316 Mdot
.57497 .14501 Mdot
.46271 .20055 Mdot
.57633 .31095 Mdot
.96041 .62333 Mdot
.23505 .20454 Mdot
.46435 .57556 Mdot
.24292 .23585 Mdot
.44435 .85783 Mdot
.99011 .81694 Mdot
.28791 .05705 Mdot
.71782 .45412 Mdot
.2642 .69949 Mdot
.46517 .00262 Mdot
.48672 .81691 Mdot
.20114 .36856 Mdot
.84087 .88481 Mdot
.64984 .48662 Mdot
.0509 .61513 Mdot
.09677 .565 Mdot
.92304 .07745 Mdot
.41244 .42638 Mdot
.93998 .72138 Mdot
.38297 .2868 Mdot
.3768 .7003 Mdot
.60306 .58983 Mdot
.19731 .20055 Mdot
.72204 .91509 Mdot
.04627 .00788 Mdot
.75696 .10352 Mdot
.30781 .6952 Mdot
.97154 .86497 Mdot
.06379 .93228 Mdot
.24891 .11266 Mdot
.44766 .90378 Mdot
.17213 .50891 Mdot
.75049 .89141 Mdot
.88368 .22521 Mdot
.86697 .01415 Mdot
.85101 .63405 Mdot
.49982 .6827 Mdot
.40517 .21301 Mdot
.51254 .67493 Mdot
.7458 .67327 Mdot
.11661 .05595 Mdot
.17678 .87723 Mdot
.9958 .82896 Mdot
.69695 .67808 Mdot
.93411 .25162 Mdot
.13278 .13288 Mdot
.3803 .56975 Mdot
.96462 .8261 Mdot
.56568 .20081 Mdot
.87665 .28706 Mdot
.37286 .21895 Mdot
.44927 .30527 Mdot
.93473 .47589 Mdot
.58402 .755 Mdot
.25066 .33701 Mdot
.5624 .37941 Mdot
.64081 .7623 Mdot
.74144 .93579 Mdot
.94046 .50576 Mdot
.07854 .80388 Mdot
.68721 .62573 Mdot
.52474 .81823 Mdot
.9978 .0939 Mdot
.75062 .19593 Mdot
.37966 .93207 Mdot
.49211 .12676 Mdot
.81709 .90118 Mdot
.61635 .05245 Mdot
.50684 .82553 Mdot
.17872 .43603 Mdot
.24582 .62669 Mdot
.7784 .32044 Mdot
.875 .69935 Mdot
.56967 .82276 Mdot
.55729 .28327 Mdot
.50057 .3033 Mdot
.48942 .67483 Mdot
.69411 .48778 Mdot
.35914 .45375 Mdot
.76446 .12288 Mdot
.17374 .31351 Mdot
.88825 .00602 Mdot
.61522 .00416 Mdot
.79555 .99588 Mdot
.03912 .98884 Mdot
.55045 .48646 Mdot
.80623 .38196 Mdot
.7358 .86774 Mdot
.99098 .02278 Mdot
.72167 .68243 Mdot
.94777 .24491 Mdot
.64389 .23324 Mdot
.46823 .25007 Mdot
.42767 .54845 Mdot
.54038 .93511 Mdot
.31245 .87782 Mdot
.79778 .26044 Mdot
.06951 .07707 Mdot
.30766 .19895 Mdot
.65609 .52153 Mdot
.00369 .4819 Mdot
.24483 .53359 Mdot
.36599 .92419 Mdot
.2885 .61142 Mdot
.58671 .98754 Mdot
.546 .74805 Mdot
.72492 .74287 Mdot
.5537 .18408 Mdot
.2337 .15375 Mdot
.15379 .4251 Mdot
.23225 .2753 Mdot
.19064 .58478 Mdot
.92299 .46439 Mdot
.26137 .73324 Mdot
.87209 .86912 Mdot
.27929 .43535 Mdot
.98174 .19605 Mdot
.41452 .37187 Mdot
.57605 .14445 Mdot
.18446 .50326 Mdot
.01592 .67725 Mdot
.70713 .39393 Mdot
.09107 .71914 Mdot
.20247 .50178 Mdot
.85775 .93318 Mdot
.63653 .44965 Mdot
.66486 .38092 Mdot
.67524 .70648 Mdot
.36518 .50689 Mdot
.57207 .00817 Mdot
.10096 .0601 Mdot
.70793 .81241 Mdot
.39519 .06646 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`04o`000?oooooooooooooo
o`;o00002_ooool00ol0003oooooooooo`0=ooooo`04o`000?oooooo0000o`0000gooooo00Co0000
oooooooooooooooo0_l00003ooooo`;o00001Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00;ooooo000Nooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool2
o`0000Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03Oooool01?l0003oooooooooooooool2o`0000[ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`04o`000?ooooooooooooooo`;o0000
2_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo1Ol0000?ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool00_ooool001gooooo0ol0000<ooooo`;o00009Ooo
ool2o`0000oooooo0_l0000Qooooo`;o00004_ooool2o`0001gooooo0_l00007ooooo`;o00004_oo
ool2o`0002gooooo0_l0000fooooo`Co000000?oooooo`000?l000008oooool001gooooo0ol0000<
ooooo`;o00009Oooool2o`0001Sooooo0_l00008ooooo`;o00003_ooool2o`0001;ooooo0_l0000M
ooooo`;o00001oooool2o`0001;ooooo0_l0000]ooooo`;o0000>oooool2o`0002?ooooo000Noooo
o`03o`000?oooooooooo04cooooo0_l00008ooooo`;o00002Oooool2o`0004Wooooo0_l0001Aoooo
o`;o00005Oooool2o`0000;ooooo0_l0000[ooooo`007_ooool00ol0003oooooooooo`1=ooooo`;o
00004_ooool2o`0004Wooooo0_l0000=ooooo`;o0000@_ooool2o`0001Gooooo0_l00002ooooo`;o
0000:oooool001kooooo00?o0000ooooooooool0COooool2o`0001[ooooo0_l0000booooo`;o0000
7?ooool2o`00087ooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`1Qooooo`;o00001_oo
ool2o`0003;ooooo0_l0000_ooooo`;o0000K_ooool2o`0000Oooooo000Nooooo`03o`000?oooooo
oooo067ooooo0_l0001[ooooo`;o0000Moooool001kooooo00?o0000ooooooooool00oooool2o`00
0>;ooooo0_l0000Pooooo`;o0000??ooool001kooooo00?o0000ooooooooool00oooool2o`0003co
oooo0_l0002=ooooo`;o00005Oooool2o`00023ooooo0_l0000Iooooo`;o000000?oooooo`000?l0
00007_ooool001kooooo00?o0000ooooooooool0@Oooool2o`0006Wooooo0_l0000Iooooo`;o0000
1oooool2o`0005;ooooo0_l000000ooooooo0000o`00000Nooooo`007_ooool00ol0003ooooooooo
o`1Gooooo`;o0000Boooool2o`0000Kooooo0_l0000Iooooo`;o00005?ooool2o`0000?ooooo0_l0
000mooooo`;o00009?ooool001kooooo00?o0000ooooooooool0Eoooool2o`0004_ooooo0_l0000g
ooooo`;o00000oooool2o`0001Cooooo0_l0000Wooooo`;o00002Oooool2o`0001Wooooo000Noooo
o`03o`000?oooooooooo0=gooooo0_l0000Iooooo`;o00005Oooool2o`00013ooooo0_l00009oooo
o`;o00006Oooool001kooooo00?o0000ooooooooool0G_ooool2o`0002[ooooo0_l0001Iooooo`;o
00002Oooool2o`0001Gooooo0_l00006ooooo`;o0000=_ooool001kooooo0_l0001Oooooo`;o0000
:_ooool2o`0000gooooo0_l0000Kooooo`;o00001?ooool2o`0000Kooooo0_l0000Oooooo`;o0000
2Oooool2o`0001Gooooo0_l0000Wooooo`;o00001oooool2o`0000cooooo000Nooooo`03o`000?oo
oooooooo02;ooooo0_l0001Gooooo`;o00007?ooool2o`0001_ooooo0_l00004ooooo`;o00001_oo
ool2o`0004[ooooo0_l0000Nooooo`;o00001oooool2o`0000cooooo000Nooooo`03o`000?oooooo
oooo00;ooooo0_l00004ooooo`;o00003?ooool2o`0000[ooooo0_l0000eooooo`;o00008?ooool2
o`0000Wooooo0_l0001=ooooo`;o0000>Oooool2o`0000;ooooo0_l0000aooooo`007_ooool00ol0
003oooooooooo`02ooooo`;o00001?ooool2o`0000cooooo0_l00005ooooo`;o0000>_ooool2o`00
02_ooooo0_l0000hooooo`;o00004oooool2o`0001gooooo0_l0000Nooooo`;o00001_ooool2o`00
01Wooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o0000XOooool2o`0003;o
oooo0_l0000Vooooo`;o00006Oooool2o`0000kooooo000Nooooo`03o`000?oooooooooo00Sooooo
0_l0000mooooo`;o00007?ooool2o`0001Gooooo0_l0001?ooooo`;o0000=_ooool2o`0002Cooooo
0_l0000Jooooo`007_ooool00ol0003oooooooooo`08ooooo`;o0000?Oooool2o`0001cooooo0_l0
000Eooooo`;o0000Coooool2o`0003Kooooo0_l0000Tooooo`;o00006_ooool001kooooo00?o0000
ooooooooool0TOooool2o`0001gooooo0_l0000dooooo`;o0000Goooool001kooooo00?o0000oooo
ooooool01Oooool2o`0000_ooooo0_l0001mooooo`;o00007Oooool2o`0001Kooooo0_l0000Loooo
o`;o00008?ooool2o`0001kooooo0_l0000Mooooo`007_ooool00ol0003oooooooooo`05ooooo`;o
00002oooool2o`000;Cooooo0_l0000nooooo`;o00007_ooool2o`0001gooooo000Nooooo`03o`00
0?oooooooooo033ooooo0_l0000cooooo`;o00006_ooool2o`00017ooooo0ol0000^ooooo`;o0000
P?ooool001kooooo00?o0000ooooooooool03Oooool2o`00027ooooo0_l0000cooooo`;o00006_oo
ool2o`00017ooooo0ol0000Fooooo`;o00005_ooool2o`00083ooooo000Nooooo`03o`000?oooooo
oooo00gooooo0_l0002Nooooo`;o00004Oooool2o`0008Gooooo000Nooooo`03o`000?oooooooooo
05Oooooo0_l0001Wooooo`;o0000QOooool001kooooo00?o0000ooooooooool0Eoooool2o`000>Oo
oooo0_l00005ooooo`007_ooool00ol0003oooooooooo`0gooooo`;o0000Xoooool2o`0003Sooooo
0_l0000Xooooo`;o00001Oooool001kooooo0_l0000hooooo`;o0000Xoooool2o`0002?ooooo0_l0
000Cooooo`;o0000;oooool001kooooo00?o0000ooooooooool0/_ooool2o`0003kooooo0_l0000=
ooooo`;o0000<Oooool2o`00017ooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l0001]oooo
o`Co00009_ooool2o`0003kooooo0_l00010ooooo`;o00004Oooool001kooooo00?o0000oooooooo
ool06Oooool2o`0006gooooo1?l0002kooooo`007_ooool00ol0003oooooooooo`1<ooooo`?o0000
BOooool2o`0005Sooooo0_l00013ooooo`;o00003_ooool001kooooo00?o0000ooooooooool03?oo
ool2o`0003kooooo0ol00019ooooo`;o0000F?ooool2o`0000Kooooo0_l0000kooooo`;o00003_oo
ool001kooooo00?o0000ooooooooool03?ooool2o`0003cooooo0_l0002^ooooo`;o0000;?ooool2
o`0001gooooo000Nooooo`03o`000?oooooooooo02;ooooo0_l0000Vooooo`;o0000Z?ooool2o`00
02Kooooo0_l0000:ooooo`;o00007Oooool001kooooo00?o0000ooooooooool08_ooool2o`0007So
oooo0_l0001Dooooo`Co00009_ooool2o`0002Wooooo000Nooooo`03o`000?oooooooooo04oooooo
0_l0001;ooooo`;o00004oooool2o`0001;ooooo0_l0000[ooooo`;o00005?ooool2o`0003gooooo
000Nooooo`03o`000?oooooooooo00;ooooo0_l0000Sooooo`;o00009_ooool2o`0005Kooooo0_l0
0008ooooo`;o00004_ooool2o`00047ooooo0_l0000mooooo`007_ooool00ol0003oooooooooo`02
ooooo`;o00008oooool2o`0001Cooooo0_l0000Wooooo`;o0000?oooool2o`0001cooooo1?l0001n
ooooo`007_ooool00ol0003oooooooooo`0mooooo`;o00009oooool2o`0005oooooo0_l00009oooo
o`;o0000Loooool001kooooo00?o0000ooooooooool0F?ooool2o`0007Sooooo0_l0001cooooo`00
7_ooool00ol0003oooooooooo`1Hooooo`;o0000?oooool2o`0001cooooo0_l0001=ooooo`;o0000
?oooool001kooooo00?o0000ooooooooool0VOooool2o`0001cooooo0_l0001=ooooo`;o00002_oo
ool2o`0003?ooooo000Nooooo`;o000000?oooooo`000?l00000e_ooool2o`0000Oooooo0_l0000_
ooooo`;o00005oooool2o`0001[ooooo000Nooooo`03o`000?oooooooooo00;o0000;?ooool2o`00
01Sooooo0_l0001looooo`;o00004?ooool2o`0000Oooooo0_l0000Aooooo`;o0000=Oooool2o`00
013ooooo0_l00008ooooo`007_ooool00ol0003oooooooooo`0^ooooo`;o00006?ooool2o`0007co
oooo0_l0000/ooooo`;o0000Aoooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo03cooooo
0_l0002hooooo`;o0000<?ooool2o`0001Cooooo0_l00007ooooo`007_ooool00ol0003ooooooooo
o`0looooo`;o0000@oooool2o`00037ooooo0_l00010ooooo`;o0000<?ooool2o`0001Cooooo0_l0
0007ooooo`007_ooool00ol0003oooooooooo`1Booooo`;o0000;Oooool2o`00037ooooo0_l0001l
ooooo`;o00004oooool001kooooo00?o0000ooooooooool0D_ooool2o`0005kooooo0_l0001Koooo
o`;o00008Oooool4o`00017ooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l0000<ooooo`;o
00008_ooool2o`0005Oooooo0_l0000Booooo`;o00001_ooool2o`0004Sooooo0_l0000Aooooo`;o
00008oooool2o`00017ooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l00004ooooo`;o0000
1_ooool2o`0001_ooooo0_l00005ooooo`;o0000Eoooool2o`0001;ooooo0_l00015ooooo`;o0000
2Oooool2o`0001Oooooo0_l0000Rooooo`;o00003?ooool001kooooo00?o0000ooooooooool04Ooo
ool2o`0002?ooooo0_l00013ooooo`;o00008?ooool2o`0005;ooooo0_l0000Rooooo`;o00005Ooo
ool2o`0000_ooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`06ooooo`;o0000Eoooool2
o`0000Gooooo0_l0000Cooooo`;o00008?ooool2o`0008gooooo0_l0000Iooooo`007_ooool00ol0
003oooooooooo`06ooooo`;o00006_ooool2o`0003_ooooo0_l00005ooooo`;o00007_ooool2o`00
02Sooooo0_l00006ooooo`;o0000=oooool2o`0005Cooooo000Nooooo`03o`000?oooooooooo02;o
oooo0_l0001Jooooo`;o00001_ooool2o`0002Sooooo0_l00006ooooo`;o0000=oooool2o`0005Co
oooo000Nooooo`03o`000?oooooooooo00;o0000O?ooool2o`000<Oooooo0003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo00;o0000
5_ooool2o`0001kooooo0_l0000Looooo`;o0000:?ooool2o`000<Gooooo0003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03
o`000?oooooooooo01Sooooo0_l0000Nooooo`;o00007?ooool2o`0002Sooooo0_l0000nooooo`;o
0000;_ooool2o`0002gooooo0_l0000:ooooo`;o00003Oooool3o`0000[ooooo0003ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`?o0000??ooool2o`0002;o
oooo0_l0000`ooooo`;o00008?ooool2o`0000[ooooo0_l0000/ooooo`Co00001oooool2o`0002Co
oooo0_l0000:ooooo`;o00003Oooool3o`0000[ooooo0003ooooo`05o`000?ooooooooooooooool0
00003Oooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo03cooooo0_l0000Rooooo`;o
0000<?ooool2o`00023ooooo0_l0000/ooooo`;o00002_ooool2o`0000Wooooo0_l0000`ooooo`;o
00003Oooool3o`0000[ooooo0003ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOo
IVIVooooo`05ooooo`03o`000?oooooooooo04Sooooo0_l0000Xooooo`;o0000K_ooool2o`0004Oo
oooo0_l0000Jooooo`000oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`18ooooo`;o0000:?ooool2o`0009[ooooo0_l0000gooooo`00
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006oooo
o`03o`000?oooooooooo057ooooo0_l0000]ooooo`;o00008_ooool2o`0006Sooooo0_l0000Goooo
o`;o00007_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0jooooo`;o00005Oooool2o`0000Oooooo0_l0000T
ooooo`;o00008_ooool2o`00087ooooo0_l0000Nooooo`007_ooool00ol0003oooooooooo`0joooo
o`;o00007_ooool2o`0001Wooooo0_l0000gooooo`;o0000BOooool2o`0004cooooo000Nooooo`03
o`000?oooooooooo01_ooooo0_l0001Hooooo`;o0000=oooool2o`0003Wooooo0_l0000>ooooo`;o
00008?ooool2o`0002[ooooo000Nooooo`03o`000?oooooooooo01_ooooo0_l0002Sooooo`;o0000
9oooool2o`0001cooooo0_l0000Booooo`;o0000:_ooool001kooooo00?o0000ooooooooool0JOoo
ool2o`0005Gooooo0_l00015ooooo`;o00004_ooool2o`0002[ooooo000Nooooo`03o`000?oooooo
oooo00Oooooo0_l0000fooooo`;o0000:?ooool2o`000=cooooo000Nooooo`03o`000?oooooooooo
00Oooooo0_l0000fooooo`;o00007?ooool2o`0004?ooooo0_l0000@ooooo`;o00005oooool2o`00
02Sooooo0_l0001>ooooo`007_ooool00ol0003oooooooooo`0Zooooo`;o00007oooool2o`00013o
oooo0_l00004ooooo`;o00009?ooool2o`0001Oooooo0_l0000@ooooo`;o00005oooool2o`0001Oo
oooo0_l0000?ooooo`;o00009_ooool2o`00013ooooo0_l0000Dooooo`007_ooool00ol0003ooooo
ooooo`0Zooooo`;o00001_ooool2o`0000gooooo0_l00002ooooo`;o00001?ooool2o`0001Kooooo
0_l0000Tooooo`;o00001?ooool2o`0002?ooooo0_l0000Gooooo`;o00003oooool2o`0000Kooooo
0_l0000Yooooo`;o00003?ooool2o`00013ooooo0_l0000Dooooo`007_ooool00ol0003ooooooooo
o`0Dooooo`;o00007?ooool2o`0000gooooo0_l00002ooooo`;o00001_ooool2o`00043ooooo0_l0
000Aooooo`;o00002oooool2o`0001;ooooo0_l00008ooooo`;o00003Oooool4o`00037ooooo0_l0
000dooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o0000=oooool2o`0000?ooooo0_l0001>
ooooo`;o00002oooool2o`0001;ooooo0_l0000Cooooo`;o00000_ooool2o`0005;ooooo0_l0000E
ooooo`007_ooool00ol0003oooooooooo`0oooooo`;o00004Oooool2o`00043ooooo0_l0000Moooo
o`;o00005_ooool2o`0000_ooooo0_l0000Oooooo`;o0000=Oooool2o`0001Gooooo000Nooooo`;o
0000@?ooool2o`0002gooooo0_l0000Tooooo`;o00007Oooool2o`0001?ooooo0_l000000ooooooo
0000o`00000/ooooo`;o00001_ooool2o`0002Wooooo0_l0000Aooooo`;o00001_ooool001kooooo
00?o0000ooooooooool0>oooool2o`00037ooooo0_l0000Iooooo`;o0000:?ooool2o`0001?ooooo
0_l0000gooooo`;o00009Oooool2o`0000;ooooo0_l0000Aooooo`;o00001_ooool001kooooo00?o
0000ooooooooool0>oooool2o`0004cooooo0_l0000Xooooo`;o00008oooool2o`0004kooooo0_l0
000Mooooo`007_ooool00ol0003oooooooooo`0kooooo`;o0000G?ooool2o`0003gooooo0ol0000T
ooooo`;o0000@?ooool2o`0000Cooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0000foooo
o`;o0000E?ooool2o`0000Kooooo0_l0000>ooooo`;o00001_ooool4o`0002Cooooo0_l0000Toooo
o`;o000000?oooooo`000?l000008Oooool2o`0001[ooooo0_l00004ooooo`007_ooool00ol0003o
ooooooooo`03ooooo`;o0000B_ooool2o`00043ooooo0_l0000Fooooo`;o00001_ooool4o`0003oo
oooo0_l0000<ooooo`;o00008Oooool2o`00023ooooo000Nooooo`03o`000?oooooooooo04oooooo
0_l0002Sooooo`;o0000DOooool001kooooo00?o0000ooooooooool0Aoooool2o`00057ooooo0_l0
000Aooooo`;o0000Koooool2o`0002Oooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0000k
ooooo`;o0000DOooool2o`00017ooooo0_l0000_ooooo`;o00007oooool2o`0000_ooooo0_l0000@
ooooo`;o00009oooool001kooooo00?o0000ooooooooool01Oooool2o`0000?ooooo0_l0000koooo
o`;o0000BOooool2o`0004[ooooo0_l0000Oooooo`;o00002oooool2o`0003Wooooo000Nooooo`03
o`000?oooooooooo00Gooooo0_l0002;ooooo`;o00007Oooool2o`0009Cooooo000Nooooo`03o`00
0?oooooooooo07Sooooo0_l0000=ooooo`;o0000:?ooool2o`0000Sooooo0_l0001Looooo`;o0000
9?ooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo07Sooooo0_l0000=ooooo`;o00001ooo
ool2o`0001Sooooo0_l0000?ooooo`;o0000=Oooool2o`0002Gooooo0_l0000Jooooo`;o00002?oo
ool2o`0000Kooooo000Nooooo`03o`000?oooooooooo01kooooo0_l0000Dooooo`;o00000_ooool2
o`0005Kooooo0_l0000Hooooo`;o0000A_ooool2o`00047ooooo0_l0000@ooooo`007_ooool00ol0
003oooooooooo`0Nooooo`;o00002Oooool2o`0000Wooooo0_l00002ooooo`;o0000Zoooool2o`00
04Cooooo0_l0000Jooooo`007_ooool00ol0003oooooooooo`0Yooooo`;o00005oooool2o`0001go
oooo0_l0000Hooooo`;o0000F?ooool2o`0000kooooo0_l0000fooooo`;o00003?ooool2o`0000go
oooo0_l0000;ooooo`007_ooool2o`0001Gooooo0_l0000Oooooo`;o00002oooool2o`0001gooooo
0_l0000Hooooo`;o0000F?ooool2o`0000;ooooo0_l0000Booooo`;o00004?ooool2o`0001cooooo
0_l0000Kooooo`;o00002oooool001kooooo00Co0000oooooooooooooooo0_l0000Aooooo`;o0000
3Oooool2o`00013ooooo0_l0000Cooooo`;o0000@_ooool2o`0000oooooo0_l0000@ooooo`;o0000
4_ooool2o`0001;ooooo0_l0000Booooo`;o00004?ooool2o`0003oooooo0_l00005ooooo`007_oo
ool01?l0003oooooooooooooool2o`0000?ooooo0_l0000Kooooo`;o00009Oooool2o`0003Wooooo
0_l00007ooooo`;o00003oooool2o`00013ooooo0_l0000Booooo`;o00003oooool2o`0001Oooooo
0_l0000>ooooo`;o00006_ooool2o`0000cooooo0_l0000Eooooo`;o00001Oooool001kooooo00?o
0000ooooooooool01_ooool2o`0007Kooooo0_l00005ooooo`;o0000<?ooool2o`0001gooooo0_l0
000Gooooo`;o00005?ooool2o`0001Cooooo0_l0000<ooooo`;o00007?ooool001kooooo00?o0000
ooooooooool0;Oooool2o`0000Gooooo0_l0000Pooooo`;o00001_ooool2o`0001kooooo0_l0000g
ooooo`;o0000C?ooool2o`0002Oooooo0_l0000Gooooo`007_ooool00ol0003oooooooooo`0]oooo
o`;o00001Oooool2o`00023ooooo0_l00006ooooo`;o0000c_ooool2o`0001Oooooo000Nooooo`03
o`000?oooooooooo01_ooooo0_l00011ooooo`;o00002oooool2o`0008cooooo0_l0001<ooooo`00
7_ooool00ol0003oooooooooo`0Kooooo`;o0000<_ooool2o`0001[ooooo0_l000000ooooooo0000
o`000002ooooo`;o0000?Oooool2o`0001[ooooo0_l0000Zooooo`;o0000C?ooool001kooooo00?o
0000ooooooooool0Coooool2o`0001gooooo0_l00002ooooo`;o0000?Oooool2o`0001[ooooo0_l0
001Gooooo`;o00001?ooool2o`0000gooooo0_l0000:ooooo`007_ooool3o`000;_ooooo0_l00013
ooooo`;o00009?ooool2o`0000Cooooo0_l0000=ooooo`;o00002_ooool001kooooo0ol0000=oooo
o`;o0000[?ooool2o`0003cooooo0_l00005ooooo`;o0000AOooool001kooooo00?o0000oooooooo
ool03Oooool2o`0005cooooo0_l0000Dooooo`;o00009oooool2o`0004gooooo0_l0001<ooooo`00
7_ooool00ol0003oooooooooo`0@ooooo`;o0000>oooool2o`0000[ooooo0_l0000@ooooo`;o0000
5?ooool2o`0002Oooooo0_l0002Kooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o0000>ooo
ool2o`0000[ooooo0_l0000nooooo`;o00004_ooool2o`0001gooooo0_l0001iooooo`007_ooool0
0ol0003oooooooooo`1Rooooo`;o0000=Oooool2o`0001;ooooo0_l0000Mooooo`;o0000=oooool2
o`0002;ooooo0_l0000Looooo`007_ooool00ol0003oooooooooo`0Gooooo`;o0000<Oooool2o`00
01Kooooo0_l0002Pooooo`?o00008_ooool2o`0001cooooo000Nooooo`;o00006?ooool2o`00037o
oooo0_l000000ooooooo0000o`00002eooooo`;o0000@Oooool001kooooo00?o0000ooooooooool0
9_ooool2o`0002Gooooo0_l0000Pooooo`;o0000Roooool2o`0004Wooooo000Nooooo`03o`000?oo
oooooooo02Kooooo0_l00017ooooo`;o00003Oooool2o`0000oooooo0_l0000Iooooo`;o00002Ooo
ool2o`0004Gooooo0_l0000Aooooo`;o0000=_ooool001kooooo00?o0000ooooooooool0O_ooool2
o`0000oooooo0_l0000Iooooo`;o00002Oooool2o`0005?ooooo0_l00003ooooo`;o0000=_ooool0
01kooooo00?o0000ooooooooool0R_ooool2o`0001Gooooo0_l0000@ooooo`;o0000EOooool2o`00
01Oooooo0_l00004ooooo`;o00007?ooool001kooooo00?o0000ooooooooool0E?ooool2o`0003Co
oooo0_l0000Eooooo`;o00004?ooool2o`0006kooooo1?l00002ooooo`;o00004oooool2o`0000Oo
oooo000Nooooo`03o`000?oooooooooo03gooooo0_l0000;ooooo`;o00002?ooool2o`0007Gooooo
0_l0001Hooooo`;o00005oooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo02gooooo0_l0
000>ooooo`;o00002_ooool3o`0003Oooooo0_l0000]ooooo`;o00005oooool2o`0007[ooooo000N
ooooo`03o`000?oooooooooo02gooooo0_l0000Jooooo`;o0000>?ooool2o`0002cooooo0ol0002C
ooooo`007_ooool00ol0003oooooooooo`2aooooo`Co00007?ooool2o`0006gooooo0_l00005oooo
o`007_ooool00ol0003oooooooooo`08ooooo`;o0000ZOooool2o`0000Oooooo0_l0000Cooooo`;o
000000?oooooo`000?l00000;?ooool2o`0003cooooo0_l00005ooooo`007_ooool00ol0003ooooo
ooooo`08ooooo`;o000000?oooooo`000?l00000?Oooool2o`0000kooooo0_l0001:ooooo`;o0000
1?ooool2o`0000Gooooo0_l00007ooooo`;o00005_ooool2o`0002cooooo0_l00013ooooo`007_oo
ool00ol0003oooooooooo`0;ooooo`;o00003?ooool2o`0002oooooo0_l0000>ooooo`;o0000B_oo
ool2o`0000Cooooo0_l00005ooooo`?o0000TOooool001kooooo00?o0000ooooooooool05_ooool2
o`000003ooooool0003o000009Wooooo0_l0001:ooooo`;o0000;oooool2o`0000kooooo0_l00004
ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool01?ooool00ol0003oooooooooo`0Fooooo`;o0000b_ooool2o`000003ooooool0003o
000001Wooooo0_l0000_ooooo`;o00003_ooool2o`0000Cooooo0003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3R
ooooo`;o000000?oooooo`000?l00000@?ooool2o`0000cooooo0_l0000@ooooo`000oooool01Ol@
413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`?o0000Ioooool2o`0002[ooooo0_l0001f
ooooo`;o00006_ooool2o`0000cooooo0_l0000@ooooo`000oooool01Ol0003ooooooooooooooooo
000000_ooooo00CoA4A4omgMgOoooooo00001oooool00ol0003oooooooooo`1Wooooo`;o0000:_oo
ool2o`0002;ooooo0_l0001Booooo`;o0000>_ooool000?ooooo00Go0000ooooooooooooooooo`00
000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo0_l0002Rooooo`;o00005?ooool4o`0005Kooooo
0_l0000dooooo`000oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000
1oooool2o`0000kooooo0_l0001Qooooo`;o0000;oooool2o`0001Kooooo0_l0001Fooooo`;o0000
=?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo
00?o0000ooooooooool03Oooool2o`0005[ooooo0_l00005ooooo`;o0000eOooool000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0
JOooool2o`000:Kooooo0_l0000dooooo`007_ooool00ol0003oooooooooo`3Vooooo`;o00006?oo
ool2o`0000oooooo0_l00006ooooo`;o0000;?ooool001kooooo00?o0000ooooooooool0Foooool2
o`0008Wooooo0_l0000Hooooo`;o00005oooool2o`0002cooooo000Nooooo`03o`000?oooooooooo
02kooooo0_l0000Cooooo`;o00005_ooool2o`000=Cooooo0_l0000Dooooo`007_ooool00ol0003o
ooooooooo`08ooooo`?o00003oooool2o`0001;ooooo0_l0000Cooooo`;o0000?Oooool2o`000:go
oooo0_l0000Dooooo`007_ooool00ol0003oooooooooo`08ooooo`?o00003oooool2o`0006Kooooo
0_l0002Yooooo`;o00006?ooool001kooooo00?o0000ooooooooool0M_ooool2o`0003_ooooo0_l0
001Fooooo`;o00008?ooool2o`0001Sooooo000Nooooo`03o`000?oooooooooo03Kooooo0_l00002
ooooo`;o00006oooool2o`0001gooooo0_l0000kooooo`;o0000E_ooool2o`0003[ooooo000Noooo
o`03o`000?oooooooooo03Kooooo0_l00002ooooo`;o00006oooool2o`0000[ooooo0_l0000[oooo
o`;o0000=_ooool2o`0001Oooooo0_l00002ooooo`;o0000H?ooool001kooooo00?o0000oooooooo
ool0>_ooool2o`0001Kooooo0_l0000?ooooo`;o000000?oooooo`000?l00000:?ooool2o`0003Ko
oooo0_l00008ooooo`;o00003Oooool2o`0000;ooooo0_l0000?ooooo`;o0000>oooool2o`0001;o
oooo000Nooooo`03o`000?oooooooooo01Wooooo0_l00007ooooo`;o00005_ooool2o`0001Kooooo
0_l00006ooooo`;o00002_ooool2o`0006[ooooo1?l0000Pooooo`;o0000>oooool2o`0001;ooooo
000Nooooo`03o`000?oooooooooo01Wooooo0_l00007ooooo`;o0000=_ooool2o`0006oooooo0_l0
0007ooooo`;o00003_ooool2o`0000_ooooo0_l0001Dooooo`007_ooool2o`0005Cooooo0_l0000m
ooooo`;o0000=oooool2o`0001Oooooo0_l0000;ooooo`;o0000E?ooool001kooooo0ol0001Coooo
o`;o00007?ooool2o`0001oooooo0_l0001Aooooo`;o0000H?ooool001kooooo0ol0001aooooo`;o
0000L_ooool2o`0001?ooooo0_l0001;ooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o0000
4Oooool2o`000=Kooooo0_l00010ooooo`;o00002Oooool001kooooo00?o0000ooooooooool02_oo
ool2o`0000?ooooo0_l0000Aooooo`;o0000GOooool2o`0007Sooooo0_l0000[ooooo`;o00004_oo
ool2o`0000Wooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0000gooooo`;o0000??ooool2
o`0007Sooooo0_l0000[ooooo`;o00007Oooool001kooooo00?o0000ooooooooool0@oooool2o`00
0?oooooo0oooool001kooooo00?o0000ooooooooool02?ooool2o`000?oooooo?_ooool001kooooo
00?o0000ooooooooool02?ooool2o`0002kooooo0_l0002Iooooo`;o0000>Oooool2o`0001cooooo
0_l0000Iooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o00008oooool2o`0003_ooooo0_l0
000fooooo`;o00009?ooool2o`0003Wooooo0_l0000Looooo`;o00006Oooool001kooooo0_l00002
ooooo`;o00004?ooool2o`00063ooooo0_l0000fooooo`;o0000V?ooool001kooooo0_l00002oooo
o`;o0000[?ooool2o`0001kooooo0_l0000Eooooo`;o0000Goooool001kooooo00?o0000oooooooo
ool0A_ooool2o`0004Wooooo0_l0000Looooo`;o00007_ooool2o`0000gooooo0_l00006ooooo`;o
0000Goooool001kooooo00?o0000ooooooooool0A_ooool2o`0004Wooooo0_l0000Dooooo`;o0000
=Oooool2o`0000;ooooo0_l0001Sooooo`007_ooool00ol0003oooooooooo`02ooooo`;o000000?o
ooooo`000?l00000X?ooool2o`0000Sooooo0_l0000_ooooo`;o0000Hoooool001kooooo00?o0000
ooooooooool00_ooool2o`000003ooooool0003o000003?ooooo1?l0001cooooo`;o00005Oooool2
o`0007gooooo000Nooooo`;o0000>oooool6o`0006kooooo0_l0000Hooooo`;o0000OOooool001ko
oooo00?o0000ooooooooool0:Oooool2o`0000gooooo0_l00004ooooo`;o0000EOooool2o`0001Oo
oooo0_l0001nooooo`;o00005oooool001kooooo00?o0000ooooooooool0:Oooool2o`0000Wooooo
0_l00002ooooo`;o0000>Oooool2o`0000;ooooo0_l0000Looooo`;o0000Uoooool2o`0001Oooooo
000Nooooo`03o`000?oooooooooo03Cooooo0_l0000[ooooo`;o00004?ooool2o`0000;ooooo0_l0
0009ooooo`;o0000`oooool001kooooo00?o0000ooooooooool0HOooool2o`0001oooooo0_l00033
ooooo`007_ooool00ol0003oooooooooo`05ooooo`;o0000fOooool2o`0004Kooooo0_l0000Moooo
o`007_ooool00ol0003oooooooooo`05ooooo`;o0000Z_ooool2o`0002gooooo0_l00002ooooo`;o
0000=oooool2o`0000Wooooo0_l00009ooooo`?o00004Oooool001kooooo00?o0000ooooooooool0
A?ooool2o`0006_ooooo0_l00002ooooo`;o00006_ooool2o`00017ooooo0_l0000gooooo`;o0000
5?ooool3o`00017ooooo000Nooooo`03o`000?oooooooooo04Cooooo0_l0000Cooooo`;o0000F_oo
ool2o`0001[ooooo0_l0000Zooooo`;o0000@?ooool2o`0000Kooooo000Nooooo`03o`000?oooooo
oooo05Sooooo0ol0002Rooooo`;o00003Oooool2o`00037ooooo0_l00006ooooo`007_ooool00ol0
003oooooooooo`0cooooo`;o00008oooool2o`0003oooooo0_l0001aooooo`;o0000>Oooool001ko
oooo00?o0000ooooooooool02Oooool2o`0000oooooo0_l00003ooooo`;o00004_ooool2o`0001Ko
oooo0_l0000mooooo`;o00003Oooool4o`000:[ooooo000Nooooo`03o`000?oooooooooo00Sooooo
0ol0000?ooooo`;o00000oooool2o`0002[ooooo0_l0000mooooo`;o00003oooool2o`0003Wooooo
0_l0001_ooooo`007_ooool00ol0003oooooooooo`08ooooo`;o0000F_ooool2o`00073ooooo0_l0
0006ooooo`;o00006oooool2o`0000;ooooo0_l00016ooooo`007_ooool00ol0003oooooooooo`1M
ooooo`;o00001Oooool2o`0005_ooooo0_l0000Kooooo`;o00006oooool2o`0000;ooooo0_l00016
ooooo`007_ooool00ol0003oooooooooo`1Mooooo`;o0000:?ooool2o`0003Sooooo0_l0000<oooo
o`;o00001?ooool2o`0000Kooooo0_l00005ooooo`;o0000HOooool001kooooo0_l0000Yooooo`;o
0000GOooool2o`0004Kooooo0_l00004ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`?o
00009?ooool2o`0003?ooooo000Nooooo`03o`000?oooooooooo02Sooooo0_l00031ooooo`?o0000
00?oooooo`000?l000008Oooool2o`0003?ooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0
001booooo`;o0000?oooool2o`0002kooooo0_l0001Fooooo`007_ooool00ol0003oooooooooo`0:
ooooo`;o0000L_ooool2o`0000?ooooo0_l00008ooooo`;o00004?ooool2o`0001kooooo0_l0001a
ooooo`;o00002oooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo02oooooo0_l0001Boooo
o`;o00001oooool3o`00013ooooo0_l0002Aooooo`;o00002oooool2o`0000Kooooo000Nooooo`03
o`000?oooooooooo01_ooooo0_l0000Booooo`;o0000Foooool2o`0001[ooooo0_l0002;ooooo`;o
00004?ooool001kooooo00?o0000ooooooooool06oooool2o`0005_ooooo0_l0000^ooooo`;o0000
00?oooooo`000?l000008?ooool2o`0006Kooooo0_l0000@ooooo`007_ooool00ol0003ooooooooo
o`15ooooo`;o0000<Oooool2o`00037ooooo0_l0000Pooooo`;o0000N?ooool001kooooo00?o0000
ooooooooool0AOooool2o`0000gooooo0_l0000Nooooo`;o00007Oooool2o`00083ooooo0_l0000`
ooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o0000@?ooool3o`0001[ooooo0_l00002oooo
o`;o00007Oooool2o`00083ooooo0_l0000:ooooo`;o00009?ooool001kooooo00?o0000oooooooo
ool04Oooool2o`00043ooooo0_l0000Kooooo`;o0000[oooool2o`0002Cooooo000Nooooo`03o`00
0?oooooooooo03[ooooo0_l0003aooooo`;o00006?ooool001kooooo00?o0000ooooooooool0>_oo
ool2o`000?7ooooo0_l0000Hooooo`007_ooool00ol0003oooooooooo`1_ooooo`;o0000:_ooool2
o`0002?ooooo0_l00025ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0Xooooo`;o0000AOoo
ool2o`0000Cooooo0_l0000Tooooo`;o00008oooool2o`00017ooooo0_l0001booooo`000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40
1_ooool00ol0003oooooooooo`0Sooooo`;o00000oooool2o`0003Oooooo0_l0000Booooo`;o0000
G?ooool2o`0007;ooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000000Kooooo0ol0000Sooooo`;o0000??ooool2o`0004;ooooo0_l00016ooooo`;o
0000BOooool2o`0000gooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003o
V9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool05Oooool2o`0006Kooooo0_l0000Voooo
o`;o0000A_ooool2o`0000[ooooo0_l00003ooooo`;o0000>?ooool2o`0000gooooo0003ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000
ooooooooool05Oooool2o`00067ooooo0_l00003ooooo`;o0000N_ooool2o`0000?ooooo0_l00017
ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool0
0ol0003oooooooooo`1hooooo`;o0000FOooool4o`0000Cooooo0_l00007ooooo`;o0000HOooool0
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000
ooooooooool02?ooool2o`000003ooooool0003o000000kooooo0_l0000Eooooo`;o00009_ooool2
o`0007Oooooo1?l00004ooooo`;o00001oooool2o`00067ooooo0003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo00Sooooo0_l0
00001?oooooo0000o`000?l0000=ooooo`;o00005Oooool2o`0000Oooooo0_l0000;ooooo`;o0000
4?ooool2o`00073ooooo0_l0001iooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o0000;Ooo
ool2o`0000_ooooo1?l00019ooooo`;o0000=Oooool2o`0000cooooo0_l0001[ooooo`007_ooool0
0ol0003oooooooooo`07ooooo`;o0000@Oooool2o`0004Wooooo0_l00013ooooo`;o0000Joooool0
01kooooo00?o0000ooooooooool01oooool2o`0000_ooooo0_l00031ooooo`;o00000_ooool2o`00
05Oooooo0_l0000Aooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o0000=Oooool3o`0000Co
oooo0_l00019ooooo`;o0000>?ooool2o`0000;ooooo0_l0000Oooooo`;o0000=_ooool2o`00017o
oooo000Nooooo`03o`000?oooooooooo013ooooo0_l0000iooooo`?o00001?ooool2o`0004Wooooo
0_l0000dooooo`;o00009oooool2o`0004Wooooo000Nooooo`03o`000?oooooooooo013ooooo0_l0
001nooooo`;o00001_ooool2o`0001Cooooo0_l0000Sooooo`;o00002?ooool2o`0003;ooooo0_l0
000dooooo`007_ooool00ol0003oooooooooo`10ooooo`;o00004Oooool2o`0002gooooo0_l0000<
ooooo`;o00001_ooool2o`0001Cooooo0_l000000ooooooo0000o`00000Zooooo`;o00004?ooool2
o`0000[ooooo0_l0000Dooooo`;o0000=?ooool001kooooo00?o0000ooooooooool0@?ooool2o`00
017ooooo0_l0000]ooooo`;o0000;Oooool2o`0002Kooooo0_l0000Dooooo`;o00002_ooool2o`00
04[ooooo000Nooooo`03o`000?oooooooooo03oooooo0_l0002Hooooo`;o0000I?ooool2o`0000Ko
oooo000Nooooo`03o`000?oooooooooo03oooooo0_l0001[ooooo`;o0000A?ooool4o`0002Sooooo
0_l0000Cooooo`;o00002_ooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo043ooooo0_l0
000Xooooo`;o0000>_ooool2o`0000Cooooo0_l00014ooooo`Co00004_ooool2o`0001Cooooo0_l0
000Cooooo`;o00004_ooool001kooooo0_l0000booooo`;o00003Oooool2o`0002Sooooo0_l0000j
ooooo`;o00003?ooool2o`00043ooooo0_l00005ooooo`;o00002Oooool2o`00037ooooo0_l0000:
ooooo`007_ooool00ol0003oooooooooo`0aooooo`;o0000POooool2o`0001Gooooo0_l0000:oooo
o`;o00007Oooool2o`0000Gooooo0_l00003ooooo`;o0000=oooool2o`0000[ooooo000Nooooo`03
o`000?oooooooooo06cooooo0_l0001Mooooo`;o00002_ooool2o`0002Wooooo0_l00008ooooo`;o
0000>Oooool001kooooo00?o0000ooooooooool0Boooool2o`0000?ooooo0_l0000Jooooo`;o0000
0_ooool2o`0009[ooooo0_l00003ooooo`;o0000=?ooool001kooooo00?o0000ooooooooool0Booo
ool2o`0000?ooooo0_l0000Nooooo`;o00004_ooool2o`0008_ooooo0_l0000dooooo`007_ooool0
0ol0003oooooooooo`0_ooooo`;o0000Doooool2o`0006_ooooo0_l0000_ooooo`;o00004oooool2
o`0000kooooo000Nooooo`03o`000?oooooooooo02oooooo0_l0001Vooooo`;o0000F?ooool2o`00
02oooooo0_l0000Cooooo`;o00003_ooool001kooooo00?o0000ooooooooool0Uoooool2o`0000;o
oooo0_l00006ooooo`;o0000BOooool2o`0005Oooooo000Nooooo`04o`000?ooooooooooooooo`;o
0000V?ooool2o`0000Kooooo0_l000000ooooooo0000o`00000fooooo`;o00003_ooool2o`0003[o
oooo0_l0000Kooooo`007_ooool01?l0003oooooooooooooool2o`00087ooooo0_l0000Pooooo`;o
00008oooool2o`0000_ooooo0_l00004ooooo`;o0000?oooool2o`0000Wooooo0ol0000Jooooo`00
7_ooool00ol0003oooooooooo`1mooooo`;o00001Oooool2o`0001Sooooo0_l0000[ooooo`;o0000
2Oooool4o`0000gooooo0_l0000fooooo`;o00002_ooool2o`0001[ooooo000Nooooo`03o`000?oo
oooooooo07gooooo0_l0000Oooooo`;o00007oooool2o`0001Gooooo0_l0000?ooooo`;o0000G_oo
ool001kooooo00?o0000ooooooooool04Oooool2o`000:cooooo0_l00016ooooo`;o00008oooool2
o`0001Wooooo000Nooooo`03o`000?oooooooooo017ooooo0_l0000Aooooo`;o00004?ooool2o`00
0<;ooooo0_l0000;ooooo`;o00008oooool2o`0001Wooooo000Mooooo`;o00009_ooool2o`00013o
oooo0_l0000Xooooo`;o0000;_ooool2o`0006Sooooo0_l0000Tooooo`;o00009Oooool001gooooo
0_l00019ooooo`;o00002Oooool2o`0000cooooo0_l0000^ooooo`;o0000Q_ooool2o`0000Kooooo
0_l0000Uooooo`007_ooool2o`0004Sooooo0_l00009ooooo`;o00008_ooool2o`0008oooooo0_l0
000?ooooo`;o0000;Oooool001kooooo00?o0000ooooooooool00_ooool2o`0007;ooooo0_l0002?
ooooo`;o00001oooool2o`0002Kooooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`02oooo
o`;o0000]Oooool2o`0001cooooo0_l0000Wooooo`;o000000?oooooo`000?l000002oooool2o`00
02Kooooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`2iooooo`;o00007?ooool2o`0001_o
oooo0_l0000:ooooo`;o000000?oooooo`000?l00000@_ooool001kooooo00?o0000ooooooooool0
d_ooool2o`00023ooooo0_l00017ooooo`;o00002?ooool001kooooo0ol0000`ooooo`;o0000X?oo
ool2o`0006Wooooo0_l00008ooooo`007_ooool3o`0001Wooooo0_l0000Eooooo`;o0000^?ooool2
o`0005_ooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l0000Jooooo`;o0000/oooool2o`00
047ooooo0_l0000Hooooo`007_ooool00ol0003oooooooooo`0eooooo`;o0000:_ooool2o`0002;o
oooo0_l00003ooooo`;o00000_ooool2o`0003Cooooo0_l0001Wooooo`;o00002Oooool2o`0000go
oooo000Nooooo`?o0000HOooool2o`0002;ooooo0_l00003ooooo`;o00000_ooool2o`0003Cooooo
0_l0001booooo`;o00003Oooool001kooooo0ol00014ooooo`;o00000_ooool2o`0000Oooooo0_l0
001Fooooo`;o0000W?ooool001kooooo00?o0000ooooooooool0A?ooool2o`0000;ooooo0_l00007
ooooo`;o0000E_ooool2o`0009cooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l0001Noooo
o`;o0000Boooool2o`0004Gooooo0_l0001;ooooo`007_ooool00ol0003oooooooooo`06ooooo`;o
0000G_ooool2o`0004_ooooo0_l00015ooooo`;o0000Boooool001kooooo00?o0000ooooooooool0
]?ooool2o`0003;ooooo0_l0001Mooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o0000@?oo
ool2o`0003Sooooo0_l0000Fooooo`;o00001Oooool2o`0003;ooooo0_l0001Fooooo`;o00001Ooo
ool001kooooo0_l0000:ooooo`;o00003_ooool2o`0001Cooooo0_l0000Oooooo`;o00001oooool4
o`0001gooooo0_l0000Cooooo`;o00001?ooool2o`0001;ooooo0_l00002ooooo`;o0000TOooool2
o`0000Gooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0000Tooooo`;o00007oooool2o`00
00Oooooo0_l0000Oooooo`;o00004oooool4o`0001Kooooo0_l000000ooooooo0000o`00000<oooo
o`;o00008Oooool2o`0006Sooooo000Nooooo`03o`000?oooooooooo097ooooo0_l0000>ooooo`;o
00002Oooool2o`0000cooooo0_l0000Qooooo`;o0000J?ooool001kooooo00?o0000ooooooooool0
Boooool2o`0000?ooooo0_l0000booooo`;o00006oooool2o`0001?ooooo0_l00009ooooo`;o0000
:_ooool2o`0002cooooo0_l0000Zooooo`007_ooool00ol0003oooooooooo`0Kooooo`;o0000;_oo
ool2o`0000?ooooo0_l0000booooo`;o0000<?ooool2o`0000Wooooo0_l00009ooooo`;o00004ooo
ool2o`0000[ooooo0_l0000/ooooo`;o00001?ooool2o`0002Cooooo000Nooooo`04o`000?oooooo
ooooooooo`;o00006?ooool2o`0004kooooo0_l0000oooooo`;o00007_ooool2o`0001;ooooo0ol0
000nooooo`;o00009?ooool001kooooo00Co0000oooooooooooooooo1?l0001Cooooo`;o00003Ooo
ool2o`0000;ooooo0_l0000Vooooo`;o00005oooool2o`0003;ooooo0_l0000Cooooo`;o0000D?oo
ool001kooooo00?o0000ooooooooool00oooool2o`0000Gooooo0ol00002ooooo`;o0000Aoooool2
o`0000Wooooo0_l00002ooooo`;o0000:_ooool2o`0003cooooo0_l0000Dooooo`;o00001oooool2
o`0000?ooooo0_l0000Booooo`;o00004_ooool2o`0002Sooooo000Nooooo`03o`000?oooooooooo
00[ooooo0ol00002ooooo`;o00000_ooool2o`0001Oooooo0_l0000eooooo`;o0000K?ooool2o`00
00oooooo0_l00003ooooo`;o00001oooool2o`0001Oooooo0_l0000Booooo`;o0000:?ooool001ko
oooo00?o0000ooooooooool04oooool2o`0001Oooooo0_l0002dooooo`;o0000Hoooool001kooooo
00?o0000ooooooooool0jOooool2o`0005cooooo000Nooooo`03o`000?oooooooooo05Oooooo0_l0
000mooooo`;o0000DOooool2o`0001cooooo0_l0000Gooooo`;o00009Oooool001kooooo00?o0000
ooooooooool0Eoooool2o`0003_ooooo1?l0001_ooooo`;o00005oooool2o`0002Gooooo000Noooo
o`03o`000?oooooooooo09Cooooo0_l0000nooooo`;o0000LOooool000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000
ooooooooool0e?ooool2o`00077ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo06kooooo0_l0
003Gooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooooooooooo
o`000006ooooo`?o00009oooool2o`0001Sooooo0_l0000[ooooo`;o00002_ooool2o`0008Sooooo
0_l00011ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oooooo
V9RHoc8b<P06ooooo`03o`000?oooooooooo01Gooooo0_l0000@ooooo`;o00006?ooool2o`0000Wo
oooo0_l0000/ooooo`;o00009_ooool2o`0005[ooooo0_l00004ooooo`;o0000@Oooool000?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0
003oooooooooo`0Eooooo`;o0000=Oooool2o`0005Cooooo0_l0001Jooooo`;o00007oooool2o`00
02Kooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o
410@00Kooooo00?o0000ooooooooool05_ooool2o`0008Gooooo0_l00020ooooo`;o00009_ooool0
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_oo
ool00ol0003oooooooooo`0Fooooo`;o0000GOooool2o`0001;ooooo0_l0000Booooo`;o0000>Ooo
ool2o`0000Sooooo0_l000000ooooooo0000o`00001Pooooo`000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo03cooooo
0_l0000gooooo`;o00004_ooool2o`0004gooooo0_l00008ooooo`;o000000?oooooo`000?l00000
Boooool2o`0001?ooooo000Nooooo`03o`000?oooooooooo03cooooo0_l0001Looooo`;o00002_oo
ool2o`0000Sooooo0_l0000Cooooo`;o0000E?ooool2o`0001Gooooo0_l0000:ooooo`;o00001ooo
ool001kooooo00Co0000oooooooooooooooo0_l0000Uooooo`;o0000:?ooool2o`0004Kooooo0_l0
000:ooooo`;o00002?ooool2o`0001?ooooo0_l00018ooooo`;o00002_ooool2o`00027ooooo0_l0
0007ooooo`007_ooool01?l0003oooooooooooooool4o`0002?ooooo0_l0000Xooooo`;o0000COoo
ool2o`0001;ooooo0_l0001Hooooo`;o0000=_ooool001kooooo00?o0000ooooooooool00oooool2
o`0009cooooo0_l0000Booooo`;o0000Moooool2o`0000Gooooo0_l0000@ooooo`007_ooool00ol0
003oooooooooo`3ooooooboooooo0_l00005ooooo`;o00002Oooool2o`0000Gooooo000Nooooo`03
o`000?oooooooooo04[ooooo0_l00002ooooo`;o00003?ooool2o`000>;ooooo0_l00005ooooo`00
7_ooool00ol0003oooooooooo`1:ooooo`;o00000_ooool2o`0000cooooo0_l00020ooooo`;o0000
Ioooool001kooooo00?o0000ooooooooool07Oooool2o`000;oooooo0_l0001Wooooo`007_ooool0
0ol0003oooooooooo`0Booooo`;o00002Oooool2o`0003_ooooo0_l0001Sooooo`;o0000<oooool2
o`00057ooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l00016ooooo`;o0000<Oooool2o`00
033ooooo0_l0000cooooo`;o00006?ooool2o`0003Oooooo000Nooooo`03o`000?oooooooooo08go
oooo0_l0001oooooo`;o00002?ooool2o`0002Cooooo0_l00007ooooo`007_ooool2o`000;cooooo
0_l00004ooooo`;o0000EOooool2o`0002Cooooo0_l00007ooooo`007_ooool00ol0003ooooooooo
o`0@ooooo`;o0000Z?ooool3o`0000Cooooo0_l00024ooooo`007_ooool00ol0003oooooooooo`0@
ooooo`;o0000N_ooool2o`0002cooooo0_l0000aooooo`;o00001_ooool2o`0003oooooo0_l0000?
ooooo`007_ooool00ol0003oooooooooo`29ooooo`;o000000Coooooo`000?l0003ooooo0_l0000?
ooooo`;o0000B?ooool2o`000003ooooool0003o000000Kooooo0_l0000oooooo`;o00003oooool0
01kooooo00?o0000ooooooooool0ROooool2o`0000Cooooo0_l0000?ooooo`;o00009_ooool2o`00
00?ooooo0_l0000Kooooo`;o0000C?ooool2o`0000gooooo000Nooooo`03o`000?oooooooooo06co
oooo0_l0001Jooooo`;o00000oooool3o`0001_ooooo0ol0000mooooo`;o00002oooool2o`0000go
oooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0001Rooooo`;o0000H?ooool2o`0001_ooooo
0ol0000Yooooo`;o00004_ooool2o`0001[ooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0
003oooooo`kooooo0_l0000^ooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o0000:?ooool2
o`0002[ooooo0_l0000<ooooo`;o0000BOooool2o`0002cooooo0_l0001Mooooo`007_ooool00ol0
003oooooooooo`0;ooooo`;o0000:?ooool2o`0002[ooooo0_l0000<ooooo`;o0000?oooool2o`00
00Sooooo0_l0000Uooooo`;o00001Oooool2o`0005gooooo000Nooooo`03o`000?oooooooooo00ko
oooo0_l0002Pooooo`;o0000;Oooool4o`0006Cooooo000Nooooo`03o`000?oooooooooo00kooooo
0_l0001Looooo`;o0000LOooool2o`0002cooooo0_l0000hooooo`007_ooool00ol0003ooooooooo
o`0eooooo`;o0000=Oooool2o`0003_ooooo0_l0000Xooooo`;o0000>?ooool2o`0001cooooo0_l0
000<ooooo`;o00003?ooool001kooooo00?o0000ooooooooool0;oooool2o`0000Cooooo0_l00008
ooooo`;o0000Aoooool2o`0001oooooo0_l0000Dooooo`;o00004_ooool2o`0001Cooooo0_l00005
ooooo`;o0000>Oooool2o`0000cooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`0_oooo
o`;o00003_ooool2o`0004Oooooo0_l0000:ooooo`;o0000:Oooool2o`0002Sooooo0_l00005oooo
o`;o0000Boooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo013ooooo0_l00022ooooo`;o
00002oooool2o`0009[ooooo0_l00008ooooo`007_ooool2o`0000gooooo0_l00002ooooo`;o0000
Soooool2o`0005Gooooo0_l0000<ooooo`;o00008oooool2o`0001[ooooo000Nooooo`03o`000?oo
oooooooo00cooooo0_l0000Hooooo`;o00007oooool2o`0004Cooooo0_l0000gooooo`;o0000<?oo
ool2o`0000cooooo0_l0000Eooooo`;o00003?ooool2o`0001[ooooo000Nooooo`03o`000?oooooo
oooo02Kooooo0_l0000Oooooo`;o00007Oooool2o`0002Gooooo0_l0000Fooooo`;o00007oooool2
o`0005Gooooo0_l0000Xooooo`007_ooool01?l0003oooooo`000?l0001Uooooo`;o00006oooool2
o`00023ooooo0_l0002@ooooo`;o00003_ooool001kooooo00Co0000ooooool0003o00003oooool2
o`0002Oooooo0_l0000Sooooo`;o00008oooool2o`0009Oooooo0_l00006ooooo`;o00001_ooool2
o`0000Wooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o00009oooool2o`00
02?ooooo0_l00027ooooo`;o0000<oooool2o`0000Kooooo0_l00006ooooo`;o00006Oooool001ko
oooo00?o0000ooooooooool07oooool2o`0002oooooo0_l0001Yooooo`;o00006oooool2o`0000go
oooo0_l0001Nooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o00004_ooool2o`00013ooooo
0_l0000Eooooo`;o00001_ooool2o`0006Wooooo0_l0000Hooooo`;o000000?oooooo`000?l00000
KOooool001kooooo00?o0000ooooooooool02oooool2o`0002Cooooo0ol0000Dooooo`;o0000:Ooo
ool2o`00063ooooo0_l0001Aooooo`;o00001oooool2o`0001Cooooo000Nooooo`03o`000?oooooo
oooo03;ooooo0_l0000oooooo`;o00007_ooool2o`0009?ooooo0_l00007ooooo`;o00005?ooool0
01kooooo0_l0000Booooo`;o0000EOooool2o`0000gooooo0_l0000Jooooo`;o0000<?ooool2o`00
02Oooooo0_l0000Sooooo`;o00005oooool2o`0001Wooooo000Nooooo`;o00004_ooool2o`0001go
oooo0_l0000fooooo`;o00003Oooool2o`0003?ooooo0_l0000Gooooo`;o00009_ooool3o`0002?o
oooo0_l0000Gooooo`;o00006Oooool001kooooo00?o0000ooooooooool0<?ooool2o`0004Sooooo
0_l0000`ooooo`;o00002?ooool2o`0003Gooooo0_l0001Hooooo`007_ooool00ol0003ooooooooo
o`0]ooooo`;o0000>oooool2o`0000kooooo0_l0000Xooooo`;o00004?ooool2o`0008oooooo000N
ooooo`03o`000?oooooooooo02?ooooo0_l00008ooooo`;o00009oooool2o`0000Kooooo0_l0000:
ooooo`;o00006Oooool2o`0001gooooo0_l0000Booooo`;o0000@_ooool2o`00023ooooo0_l0000W
ooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o00007oooool2o`00013ooooo1?l00004oooo
o`;o00009Oooool2o`00037ooooo0_l0000Dooooo`;o00008_ooool2o`0000Sooooo0_l0000Coooo
o`;o00002oooool2o`0002Oooooo000Nooooo`;o0000AOooool2o`0001;ooooo0_l00013ooooo`;o
0000;oooool2o`0002;ooooo0_l0000Fooooo`;o00001Oooool2o`0003Cooooo000Nooooo`03o`00
0?oooooooooo09gooooo0_l0001[ooooo`;o0000>oooool001kooooo00?o0000ooooooooool0:ooo
ool2o`0005Sooooo0_l0001Tooooo`;o0000<_ooool2o`0002Kooooo000Nooooo`03o`000?oooooo
oooo02_ooooo0_l0001Hooooo`;o00002oooool2o`0001gooooo0_l0000hooooo`;o0000<_ooool2
o`0002Kooooo000Nooooo`03o`000?oooooooooo09;ooooo0_l0000Mooooo`;o0000U?ooool001ko
oooo00?o0000ooooooooool0^oooool2o`0005gooooo0_l0000[ooooo`007_ooool00ol0003ooooo
ooooo`2kooooo`;o0000GOooool4o`0002Wooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0
0008ooooo`;o0000:Oooool2o`000=cooooo0_l0000Yooooo`007_ooool00ol0003oooooooooo`09
ooooo`;o00001oooool3o`0001?ooooo0_l0000>ooooo`;o00001?ooool2o`0006Gooooo0_l0001m
ooooo`;o00008Oooool001kooooo00?o0000ooooooooool01?ooool2o`0000cooooo0_l00008oooo
o`;o00002_ooool2o`0000kooooo0_l0001[ooooo`;o00007?ooool2o`0000kooooo0_l0001?oooo
o`;o00008Oooool001kooooo00?o0000ooooooooool01?ooool2o`0001Kooooo0_l0002Uooooo`;o
00003_ooool2o`0002gooooo0_l00013ooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o0000
L?ooool2o`00077ooooo0_l0000Xooooo`;o00006Oooool001kooooo00?o0000ooooooooool07Ooo
ool2o`00073ooooo0_l0000Zooooo`;o0000Koooool2o`0001Wooooo000Nooooo`?o00002Oooool2
o`0009Oooooo0_l0000Gooooo`;o0000R_ooool001Cooooo1?l000000ol@413oooooooooo`03oooo
o`?o00002Oooool2o`0009Oooooo0_l0002Sooooo`005_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?oooooo0_l00016ooooo`005_ooool00ol0003oooooooooo`05ooooo`?o0000
1_ooool2o`000?Oooooo0_l0000[ooooo`;o00006Oooool001Kooooo00?o0000ooooooooool03_oo
ool2o`000?oooooo9Oooool2o`0001Wooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool0
01Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3o
oooo000Dooooo`03oeEEEOmVIVKo00000?ooooooD_ooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.62265 .27637 Mdot
.48368 .47907 Mdot
.93253 .51297 Mdot
.34447 .57577 Mdot
.54188 .00042 Mdot
.68256 .71876 Mdot
.67952 .58103 Mdot
.97403 .87566 Mdot
.26591 .33465 Mdot
.0437 .89986 Mdot
.34289 .42863 Mdot
.13734 .06934 Mdot
.07827 .50199 Mdot
.30193 .94758 Mdot
.79275 .64556 Mdot
.58878 .01566 Mdot
.88802 .00475 Mdot
.25822 .93385 Mdot
.58865 .07341 Mdot
.9214 .43133 Mdot
.9558 .09049 Mdot
.23032 .17026 Mdot
.25542 .29727 Mdot
.73878 .74754 Mdot
.53381 .1432 Mdot
.07352 .1653 Mdot
.09501 .86421 Mdot
.12282 .50657 Mdot
.84667 .50067 Mdot
.20946 .92413 Mdot
.62521 .8052 Mdot
.93008 .86581 Mdot
.03061 .34173 Mdot
.05644 .32562 Mdot
.41512 .68303 Mdot
.68409 .22241 Mdot
.51348 .9107 Mdot
.24119 .69853 Mdot
.77266 .67267 Mdot
.76104 .5506 Mdot
.56598 .51687 Mdot
.90314 .99225 Mdot
.58604 .09123 Mdot
.61393 .46664 Mdot
.19707 .37505 Mdot
.92337 .79669 Mdot
.14373 .33144 Mdot
.60087 .19581 Mdot
.27885 .78982 Mdot
.99499 .85783 Mdot
.14213 .75764 Mdot
.86632 .95738 Mdot
.93901 .88131 Mdot
.33887 .32851 Mdot
.99834 .15787 Mdot
.3639 .21483 Mdot
.45399 .13675 Mdot
.79805 .06384 Mdot
.66678 .16191 Mdot
.55813 .50749 Mdot
.74724 .73516 Mdot
.20921 .00442 Mdot
.24017 .32665 Mdot
.9611 .69426 Mdot
.66958 .08651 Mdot
.98669 .73494 Mdot
.29567 .55961 Mdot
.26457 .8619 Mdot
.48489 .78631 Mdot
.11187 .44294 Mdot
.4636 .25916 Mdot
.1983 .58058 Mdot
.05966 .90039 Mdot
.62457 .94416 Mdot
.46997 .9389 Mdot
.31187 .88669 Mdot
.16353 .48294 Mdot
.68074 .79299 Mdot
.23782 .28936 Mdot
.76543 .27655 Mdot
.10744 .1292 Mdot
.30746 .20549 Mdot
.28619 .23471 Mdot
.74992 .25762 Mdot
.57641 .9731 Mdot
.76074 .68917 Mdot
.74176 .40219 Mdot
.08559 .44091 Mdot
.2086 .27504 Mdot
.77213 .27976 Mdot
.62555 .34158 Mdot
.6381 .64683 Mdot
.88314 .86967 Mdot
.71351 .79718 Mdot
.24718 .98816 Mdot
.60325 .89499 Mdot
.02843 .65547 Mdot
.48364 .5593 Mdot
.64328 .90254 Mdot
.02482 .75207 Mdot
.78552 .25773 Mdot
.6196 .10843 Mdot
.79619 .27264 Mdot
.61131 .10409 Mdot
.27983 .78475 Mdot
.26753 .66869 Mdot
.6818 .16322 Mdot
.03422 .42345 Mdot
.29249 .86009 Mdot
.18844 .21501 Mdot
.00546 .32345 Mdot
.5184 .81115 Mdot
.86223 .7007 Mdot
.54132 .34661 Mdot
.42154 .06299 Mdot
.56514 .88431 Mdot
.50209 .63155 Mdot
.65138 .57284 Mdot
.17748 .84144 Mdot
.97913 .81091 Mdot
.53774 .32375 Mdot
.43439 .2189 Mdot
.88696 .34938 Mdot
.28284 .76331 Mdot
.66514 .28608 Mdot
.38122 .77885 Mdot
.61775 .87705 Mdot
.17955 .53305 Mdot
.75877 .60606 Mdot
.15962 .31464 Mdot
.92115 .13487 Mdot
.54614 .15461 Mdot
.76834 .1686 Mdot
.74212 .57833 Mdot
.5155 .1715 Mdot
.83443 .16683 Mdot
.20054 .51539 Mdot
.08364 .03294 Mdot
.94666 .27035 Mdot
.27048 .85535 Mdot
.82986 .30739 Mdot
.75067 .18581 Mdot
.5451 .55135 Mdot
.57201 .3921 Mdot
.13592 .74881 Mdot
.46122 .46282 Mdot
.25991 .93594 Mdot
.98829 .66442 Mdot
.7109 .78979 Mdot
.54016 .26392 Mdot
.12506 .13999 Mdot
.63002 .77091 Mdot
.65842 .18879 Mdot
.52229 .20868 Mdot
.74791 .27359 Mdot
.30416 .17939 Mdot
.96288 .17771 Mdot
.49626 .06634 Mdot
.05278 .61014 Mdot
.8615 .03572 Mdot
.97604 .46494 Mdot
.94686 .14046 Mdot
.21194 .97958 Mdot
.69754 .01034 Mdot
.92732 .13883 Mdot
.80813 .16846 Mdot
.81663 .22674 Mdot
.86188 .63261 Mdot
.2132 .68793 Mdot
.74121 .923 Mdot
.79892 .42225 Mdot
.22936 .24815 Mdot
.46983 .60812 Mdot
.91161 .74705 Mdot
.89133 .26731 Mdot
.84738 .09587 Mdot
.32732 .47926 Mdot
.67456 .58173 Mdot
.14518 .90012 Mdot
.45649 .58995 Mdot
.28959 .56854 Mdot
.06277 .0131 Mdot
.85031 .77424 Mdot
.19214 .40275 Mdot
.02143 .5245 Mdot
.65053 .02409 Mdot
.76471 .91293 Mdot
.42585 .56546 Mdot
.79871 .78783 Mdot
.38284 .3622 Mdot
.29179 .52146 Mdot
.57359 .40938 Mdot
.64658 .31451 Mdot
.13113 .75747 Mdot
.15861 .19133 Mdot
.29608 .98337 Mdot
.51323 .02165 Mdot
.01473 .32117 Mdot
.38484 .75624 Mdot
.95335 .39197 Mdot
.93307 .32631 Mdot
.21768 .40229 Mdot
.28289 .17189 Mdot
.00158 .34783 Mdot
.99293 .49485 Mdot
.51384 .95141 Mdot
.46898 .65324 Mdot
.58473 .59964 Mdot
.3349 .27961 Mdot
.20334 .63178 Mdot
.59526 .15896 Mdot
.60174 .60389 Mdot
.021 .1835 Mdot
.74302 .5484 Mdot
.38549 .38775 Mdot
.37761 .55955 Mdot
.75533 .53445 Mdot
.21295 .97895 Mdot
.91207 .24444 Mdot
.29922 .01656 Mdot
.96255 .5953 Mdot
.73604 .02266 Mdot
.99425 .08004 Mdot
.49657 .78822 Mdot
.33922 .24946 Mdot
.39888 .88502 Mdot
.30996 .50342 Mdot
.37144 .6852 Mdot
.90952 .31349 Mdot
.78871 .34557 Mdot
.62104 .43579 Mdot
.84393 .69162 Mdot
.02261 .20113 Mdot
.75284 .30656 Mdot
.67141 .48007 Mdot
.62511 .87605 Mdot
.9825 .59647 Mdot
.86366 .64236 Mdot
.03161 .74451 Mdot
.85359 .29945 Mdot
.77196 .05575 Mdot
.7189 .59728 Mdot
.78907 .99008 Mdot
.22893 .2572 Mdot
.12694 .41235 Mdot
.11326 .31012 Mdot
.08817 .2872 Mdot
.85949 .79522 Mdot
.47934 .05461 Mdot
.36626 .80402 Mdot
.79791 .6666 Mdot
.85952 .13143 Mdot
.66849 .24099 Mdot
.50968 .90631 Mdot
.24053 .63037 Mdot
.64291 .28377 Mdot
.48191 .57655 Mdot
.16386 .60367 Mdot
.01442 .93305 Mdot
.93787 .1857 Mdot
.91392 .23861 Mdot
.95713 .00991 Mdot
.4763 .21903 Mdot
.73572 .52786 Mdot
.44464 .33134 Mdot
.59661 .97837 Mdot
.55798 .33548 Mdot
.5904 .05031 Mdot
.44175 .12659 Mdot
.77563 .79894 Mdot
.76502 .8315 Mdot
.4725 .25647 Mdot
.49079 .9492 Mdot
.86927 .59185 Mdot
.38559 .09497 Mdot
.78223 .7313 Mdot
.57668 .12597 Mdot
.5462 .38232 Mdot
.37961 .41367 Mdot
.31641 .98361 Mdot
.59578 .66457 Mdot
.18457 .54808 Mdot
.18803 .45803 Mdot
.07378 .64311 Mdot
.34825 .15134 Mdot
.56387 .3998 Mdot
.32749 .4143 Mdot
.41617 .3097 Mdot
.40585 .66263 Mdot
.51148 .28168 Mdot
.65088 .59017 Mdot
.55884 .94302 Mdot
.69935 .59053 Mdot
.99611 .04382 Mdot
.86463 .47466 Mdot
.28827 .74703 Mdot
.14764 .97303 Mdot
.38258 .71814 Mdot
.47207 .18523 Mdot
.32363 .03817 Mdot
.43808 .1639 Mdot
.45678 .11302 Mdot
.43312 .9248 Mdot
.26349 .52417 Mdot
.36196 .6949 Mdot
.89607 .1277 Mdot
.85205 .564 Mdot
.95862 .01559 Mdot
.05937 .24416 Mdot
.22814 .67077 Mdot
.2297 .42844 Mdot
.5402 .27709 Mdot
.14756 .90044 Mdot
.71743 .81649 Mdot
.38513 .34196 Mdot
.81714 .64067 Mdot
.37303 .28305 Mdot
.29194 .85884 Mdot
.15175 .07321 Mdot
.68325 .47469 Mdot
.45355 .46725 Mdot
.11138 .17114 Mdot
.58457 .38877 Mdot
.92611 .54089 Mdot
.78225 .13132 Mdot
.84539 .08394 Mdot
.04354 .15234 Mdot
.65613 .07848 Mdot
.03513 .50251 Mdot
.00143 .57602 Mdot
.52403 .79696 Mdot
.67993 .74848 Mdot
.43029 .97158 Mdot
.21855 .9262 Mdot
.49277 .21986 Mdot
.6548 .04446 Mdot
.05223 .73649 Mdot
.16614 .32558 Mdot
.65989 .95189 Mdot
.16256 .89029 Mdot
.9795 .07074 Mdot
.78435 .67492 Mdot
.10255 .63265 Mdot
.48338 .30106 Mdot
.00996 .02418 Mdot
.90217 .00276 Mdot
.17157 .43731 Mdot
.61842 .32421 Mdot
.46937 .34553 Mdot
.08586 .36188 Mdot
.45414 .77319 Mdot
.28312 .11821 Mdot
.83078 .06449 Mdot
.13864 .08175 Mdot
.09158 .05026 Mdot
.01556 .1415 Mdot
.71005 .39632 Mdot
.75928 .49127 Mdot
.18187 .32299 Mdot
.51989 .81163 Mdot
.06788 .61095 Mdot
.0629 .81128 Mdot
.26621 .21194 Mdot
.13094 .3225 Mdot
.78475 .50511 Mdot
.62968 .89195 Mdot
.03755 .10111 Mdot
.96944 .37696 Mdot
.97614 .33584 Mdot
.5717 .23687 Mdot
.44444 .36812 Mdot
.42165 .77993 Mdot
.72821 .38551 Mdot
.99624 .34566 Mdot
.11905 .54327 Mdot
.23859 .64874 Mdot
.95632 .39001 Mdot
.24756 .1258 Mdot
.26478 .65111 Mdot
.63282 .37895 Mdot
.91802 .95714 Mdot
.70382 .77713 Mdot
.12258 .9482 Mdot
.63803 .34377 Mdot
.74909 .91118 Mdot
.27537 .37016 Mdot
.28566 .99929 Mdot
.67968 .09356 Mdot
.69143 .96895 Mdot
.807 .61112 Mdot
.05746 .67278 Mdot
.8249 .58318 Mdot
.767 .35077 Mdot
.4733 .43898 Mdot
.00143 .05022 Mdot
.48231 .73161 Mdot
.90087 .50997 Mdot
.55533 .71241 Mdot
.2524 .15247 Mdot
.52287 .98677 Mdot
.93295 .54013 Mdot
.05246 .02872 Mdot
.23855 .22457 Mdot
.88811 .07179 Mdot
.11151 .2256 Mdot
.05704 .99711 Mdot
.47785 .81591 Mdot
.94144 .91391 Mdot
.21744 .6572 Mdot
.73854 .54899 Mdot
.60809 .14698 Mdot
.86019 .93095 Mdot
.31749 .24356 Mdot
.1607 .27362 Mdot
.44109 .65725 Mdot
.64084 .8331 Mdot
.67865 .79548 Mdot
.21234 .19849 Mdot
.57938 .62135 Mdot
.65528 .92461 Mdot
.9892 .31395 Mdot
.26651 .72719 Mdot
.75324 .52014 Mdot
.03299 .44955 Mdot
.06314 .92453 Mdot
.50459 .54608 Mdot
.29582 .90629 Mdot
.22679 .07965 Mdot
.96153 .46462 Mdot
.35824 .24853 Mdot
.74943 .49581 Mdot
.07043 .95251 Mdot
.39827 .54477 Mdot
.17879 .58863 Mdot
.00253 .66342 Mdot
.7744 .78666 Mdot
.5703 .09241 Mdot
.91175 .88763 Mdot
.64781 .83041 Mdot
.05748 .16522 Mdot
.0331 .72569 Mdot
.05414 .2822 Mdot
.64113 .57228 Mdot
.61798 .97224 Mdot
.88411 .3813 Mdot
.81007 .75113 Mdot
.23954 .36993 Mdot
.37529 .60566 Mdot
.31759 .91281 Mdot
.09388 .35751 Mdot
.01562 .72685 Mdot
.3877 .8429 Mdot
.35415 .36665 Mdot
.97228 .90934 Mdot
.07447 .43035 Mdot
.00065 .57067 Mdot
.82476 .39027 Mdot
.84299 .17993 Mdot
.23057 .38404 Mdot
.81487 .93755 Mdot
.26689 .12598 Mdot
.07498 .93465 Mdot
.87599 .03963 Mdot
.04682 .74041 Mdot
.89263 .03067 Mdot
.71057 .47595 Mdot
.18567 .23594 Mdot
.36011 .533 Mdot
.99908 .48812 Mdot
.15144 .71053 Mdot
.41111 .44968 Mdot
.9675 .41403 Mdot
.4966 .69796 Mdot
.24176 .83561 Mdot
.25135 .30939 Mdot
.56569 .75337 Mdot
.71298 .63603 Mdot
.4894 .92521 Mdot
.89178 .0298 Mdot
.50017 .03739 Mdot
.52715 .1828 Mdot
.97378 .68238 Mdot
.48643 .09881 Mdot
.65079 .63145 Mdot
.61819 .75404 Mdot
.77342 .14856 Mdot
.7286 .08183 Mdot
.58103 .03971 Mdot
.3669 .80131 Mdot
.73397 .74679 Mdot
.83777 .40984 Mdot
.86367 .07261 Mdot
.94406 .8796 Mdot
.24522 .03312 Mdot
.84107 .13403 Mdot
.2488 .7491 Mdot
.85314 .73819 Mdot
.12738 .96632 Mdot
.77527 .28651 Mdot
.91203 .56974 Mdot
.76749 .85119 Mdot
.54364 .47119 Mdot
.28831 .78314 Mdot
.31999 .75376 Mdot
.70679 .57044 Mdot
.42298 .09259 Mdot
.51178 .79149 Mdot
.53007 .97803 Mdot
.00732 .4088 Mdot
.05034 .36512 Mdot
.59968 .47476 Mdot
.76577 .15952 Mdot
.47494 .26945 Mdot
.59236 .32946 Mdot
.54152 .83783 Mdot
.92161 .20565 Mdot
.19237 .92304 Mdot
.14492 .48477 Mdot
.32891 .7575 Mdot
.9771 .14852 Mdot
.95908 .98303 Mdot
.30001 .41638 Mdot
.73348 .86913 Mdot
.16508 .62087 Mdot
.88854 .96827 Mdot
.94029 .66779 Mdot
.71907 .47007 Mdot
.66528 .80405 Mdot
.8739 .19226 Mdot
.16257 .95579 Mdot
.91256 .80833 Mdot
.54181 .16816 Mdot
.58752 .46099 Mdot
.5966 .37874 Mdot
.23169 .9405 Mdot
.05807 .39857 Mdot
.68698 .34188 Mdot
.47756 .37547 Mdot
.60598 .51737 Mdot
.46725 .94607 Mdot
.08003 .95169 Mdot
.93081 .63581 Mdot
.54286 .50038 Mdot
.77403 .82368 Mdot
.59211 .70216 Mdot
.80682 .80879 Mdot
.99987 .11901 Mdot
.11582 .76976 Mdot
.69319 .14324 Mdot
.28167 .02464 Mdot
.71859 .26888 Mdot
.16532 .71988 Mdot
.27654 .96754 Mdot
.863 .73343 Mdot
.09145 .81904 Mdot
.46611 .55152 Mdot
.13346 .75811 Mdot
.29487 .10231 Mdot
.76051 .00334 Mdot
.53207 .6874 Mdot
.44403 .22424 Mdot
.89978 .30285 Mdot
.3666 .30763 Mdot
.0836 .22446 Mdot
.45396 .70017 Mdot
.84609 .13579 Mdot
.00038 .25652 Mdot
.02341 .23803 Mdot
.22781 .1316 Mdot
.37643 .50104 Mdot
.09537 .77252 Mdot
.20053 .16888 Mdot
.31248 .9073 Mdot
.93397 .22078 Mdot
.58588 .22653 Mdot
.23043 .62716 Mdot
.50093 .88695 Mdot
.00585 .13418 Mdot
.8497 .99981 Mdot
.63407 .53051 Mdot
.25096 .50876 Mdot
.62738 .66562 Mdot
.50242 .37626 Mdot
.04427 .85235 Mdot
.82306 .84253 Mdot
.47589 .99798 Mdot
.89528 .23647 Mdot
.60297 .00892 Mdot
.03437 .70976 Mdot
.21986 .24038 Mdot
.55521 .36464 Mdot
.22641 .34485 Mdot
.93774 .22265 Mdot
.98039 .32365 Mdot
.79302 .46524 Mdot
.5657 .83785 Mdot
.60415 .27136 Mdot
.46555 .19882 Mdot
.36202 .39429 Mdot
.21608 .82075 Mdot
.67601 .31014 Mdot
.63917 .22589 Mdot
.76292 .60814 Mdot
.76622 .52775 Mdot
.47166 .74313 Mdot
.44169 .83058 Mdot
.01288 .62409 Mdot
.51363 .35508 Mdot
.03333 .99108 Mdot
.40735 .52279 Mdot
.3424 .94968 Mdot
.83197 .32811 Mdot
.01588 .26169 Mdot
.83115 .45133 Mdot
.88991 .31461 Mdot
.41799 .57993 Mdot
.79385 .2055 Mdot
.62486 .37997 Mdot
.12853 .95263 Mdot
.47636 .39031 Mdot
.45094 .31643 Mdot
.70049 .22826 Mdot
.75765 .72892 Mdot
.23955 .53286 Mdot
.09195 .09895 Mdot
.04397 .4263 Mdot
.8478 .43414 Mdot
.98492 .20744 Mdot
.69652 .84606 Mdot
.0024 .45479 Mdot
.91454 .26063 Mdot
.8742 .41474 Mdot
.82293 .59974 Mdot
.80978 .5516 Mdot
.71127 .22011 Mdot
.22832 .66874 Mdot
.25467 .48264 Mdot
.53505 .59786 Mdot
.75761 .70321 Mdot
.9096 .7638 Mdot
.70768 .48377 Mdot
.55323 .92642 Mdot
.14624 .87088 Mdot
.01783 .86742 Mdot
.69096 .63201 Mdot
.57355 .6678 Mdot
.62114 .04751 Mdot
.99497 .63982 Mdot
.00728 .92321 Mdot
.81982 .3965 Mdot
.60431 .57182 Mdot
.54932 .28131 Mdot
.53387 .43924 Mdot
.35005 .00526 Mdot
.73921 .21253 Mdot
.9698 .47799 Mdot
.41881 .94565 Mdot
.03089 .45727 Mdot
.42968 .53881 Mdot
.4147 .19281 Mdot
.05 .97214 Mdot
.93763 .14866 Mdot
.81161 .75375 Mdot
.04045 .50345 Mdot
.91811 .6644 Mdot
.03751 .87034 Mdot
.82374 .8093 Mdot
.7097 .00842 Mdot
.77828 .50618 Mdot
.03031 .92568 Mdot
.99034 .32138 Mdot
.2766 .08276 Mdot
.57276 .00069 Mdot
.68606 .5794 Mdot
.11808 .6095 Mdot
.29698 .42472 Mdot
.56082 .31319 Mdot
.61855 .92961 Mdot
.37233 .14494 Mdot
.5517 .53819 Mdot
.95601 .28422 Mdot
.87474 .00662 Mdot
.32193 .32239 Mdot
.25619 .2732 Mdot
.39307 .678 Mdot
.91952 .33882 Mdot
.64492 .71111 Mdot
.27891 .55332 Mdot
.71665 .76379 Mdot
.01198 .98453 Mdot
.71896 .24291 Mdot
.1069 .80045 Mdot
.40523 .58797 Mdot
.59085 .17052 Mdot
.72624 .90506 Mdot
.97173 .24916 Mdot
.69539 .59329 Mdot
.68943 .27693 Mdot
.69173 .24119 Mdot
.04645 .37046 Mdot
.32201 .12675 Mdot
.40902 .02317 Mdot
.97505 .24092 Mdot
.93012 .85796 Mdot
.20586 .29052 Mdot
.71568 .0466 Mdot
.12971 .02119 Mdot
.09116 .15236 Mdot
.78618 .07114 Mdot
.04343 .51189 Mdot
.73495 .18781 Mdot
.63472 .51822 Mdot
.77202 .70806 Mdot
.60071 .85288 Mdot
.17363 .81452 Mdot
.01938 .64245 Mdot
.60164 .89824 Mdot
.93905 .93953 Mdot
.83661 .51595 Mdot
.21893 .15683 Mdot
.68722 .80738 Mdot
.52933 .28232 Mdot
.5901 .97688 Mdot
.52866 .40761 Mdot
.45821 .91567 Mdot
.56672 .20343 Mdot
.92015 .4559 Mdot
.90354 .93736 Mdot
.96083 .21032 Mdot
.59303 .64255 Mdot
.49264 .06967 Mdot
.75601 .84094 Mdot
.14558 .91292 Mdot
.86198 .92976 Mdot
.91963 .28067 Mdot
.71712 .87079 Mdot
.12063 .73325 Mdot
.7784 .2948 Mdot
.83327 .9118 Mdot
.52003 .72571 Mdot
.51017 .34182 Mdot
.55922 .7269 Mdot
.38306 .63255 Mdot
.15607 .51832 Mdot
.87587 .37831 Mdot
.91839 .96343 Mdot
.30297 .44286 Mdot
.58476 .73422 Mdot
.81381 .073 Mdot
.44145 .06893 Mdot
.3503 .78627 Mdot
.27827 .9859 Mdot
.49336 .09619 Mdot
.37174 .61866 Mdot
.45826 .0992 Mdot
.85545 .73659 Mdot
.21904 .35866 Mdot
.2801 .40877 Mdot
.27056 .2771 Mdot
.06052 .04952 Mdot
.09301 .56501 Mdot
.26698 .61421 Mdot
.1031 .41443 Mdot
.34922 .27601 Mdot
.97482 .69215 Mdot
.61777 .01567 Mdot
.16202 .2274 Mdot
.40949 .64748 Mdot
.29398 .23897 Mdot
.49066 .86843 Mdot
.66408 .60487 Mdot
.77653 .17618 Mdot
.93621 .37827 Mdot
.86264 .18994 Mdot
.48163 .62317 Mdot
.16469 .28362 Mdot
.85489 .28516 Mdot
.8997 .91613 Mdot
.05642 .71009 Mdot
.14193 .90741 Mdot
.39623 .83472 Mdot
.0057 .68404 Mdot
.07972 .88769 Mdot
.61315 .86308 Mdot
.79412 .12248 Mdot
.10174 .29627 Mdot
.95217 .16342 Mdot
.5856 .38053 Mdot
.73469 .22488 Mdot
.31972 .84088 Mdot
.02875 .88952 Mdot
.53899 .57741 Mdot
.29077 .70742 Mdot
.15906 .53984 Mdot
.55338 .1903 Mdot
.91435 .05343 Mdot
.40695 .70843 Mdot
.18051 .36818 Mdot
.80726 .17432 Mdot
.23916 .34689 Mdot
.71634 .30041 Mdot
.27639 .8674 Mdot
.31592 .75676 Mdot
.37945 .93184 Mdot
.67457 .69998 Mdot
.57596 .75868 Mdot
.76539 .13869 Mdot
.01875 .06762 Mdot
.99943 .79998 Mdot
.47917 .33049 Mdot
.558 .26836 Mdot
.89224 .34308 Mdot
.19115 .3345 Mdot
.95998 .8407 Mdot
.51957 .19721 Mdot
.24218 .55033 Mdot
.18879 .8736 Mdot
.01823 .15608 Mdot
.08177 .35693 Mdot
.36807 .44452 Mdot
.71428 .91702 Mdot
.52728 .75384 Mdot
.53681 .00835 Mdot
.28839 .04478 Mdot
.95877 .0396 Mdot
.93794 .85044 Mdot
.80528 .46846 Mdot
.07349 .65264 Mdot
.24304 .24848 Mdot
.69027 .13443 Mdot
.52015 .51846 Mdot
.68834 .0526 Mdot
.44252 .24202 Mdot
.80307 .6689 Mdot
.27855 .60025 Mdot
.8763 .25709 Mdot
.95957 .92657 Mdot
.57341 .06437 Mdot
.51364 .80031 Mdot
.8572 .77486 Mdot
.90348 .19262 Mdot
.80155 .26036 Mdot
.75563 .03654 Mdot
.47856 .57054 Mdot
.94096 .42146 Mdot
.32544 .27577 Mdot
.02933 .46288 Mdot
.79811 .64689 Mdot
.43121 .90478 Mdot
.59746 .2203 Mdot
.28483 .734 Mdot
.09716 .81724 Mdot
.72483 .1718 Mdot
.91732 .19103 Mdot
.33444 .49301 Mdot
.80684 .24669 Mdot
.0385 .42864 Mdot
.84911 .33692 Mdot
.6436 .61626 Mdot
.68783 .06807 Mdot
.58406 .06689 Mdot
.45148 .48071 Mdot
.95064 .6879 Mdot
.72241 .02534 Mdot
.58369 .15281 Mdot
.42959 .20059 Mdot
.60462 .2856 Mdot
.96871 .59566 Mdot
.21676 .22493 Mdot
.4811 .5981 Mdot
.20817 .25038 Mdot
.43891 .89903 Mdot
.97582 .8263 Mdot
.33019 .06087 Mdot
.67937 .48331 Mdot
.26525 .66106 Mdot
.46708 .98312 Mdot
.47814 .82523 Mdot
.21839 .32571 Mdot
.86706 .87834 Mdot
.64027 .47105 Mdot
.01349 .62804 Mdot
.07769 .58034 Mdot
.93736 .09585 Mdot
.45028 .38669 Mdot
.95467 .69556 Mdot
.41464 .26215 Mdot
.35032 .66478 Mdot
.58934 .62852 Mdot
.22271 .20313 Mdot
.73627 .95329 Mdot
.0004 .9737 Mdot
.73621 .11003 Mdot
.34528 .68918 Mdot
.01283 .90379 Mdot
.03833 .95377 Mdot
.2093 .14345 Mdot
.4567 .90813 Mdot
.14412 .51757 Mdot
.73968 .88706 Mdot
.9152 .23837 Mdot
.87472 .05483 Mdot
.82372 .65665 Mdot
.50685 .71131 Mdot
.44457 .18356 Mdot
.52836 .66452 Mdot
.78693 .65296 Mdot
.10544 .06908 Mdot
.21065 .87233 Mdot
.02475 .79139 Mdot
.71646 .70856 Mdot
.93004 .26228 Mdot
.16529 .10433 Mdot
.41366 .5889 Mdot
.97881 .82318 Mdot
.54833 .23738 Mdot
.89789 .26475 Mdot
.38672 .22309 Mdot
.47599 .26052 Mdot
.91143 .51026 Mdot
.62028 .76359 Mdot
.24172 .3666 Mdot
.53208 .39921 Mdot
.68267 .73451 Mdot
.72156 .94198 Mdot
.9027 .50247 Mdot
.08447 .77067 Mdot
.71177 .63367 Mdot
.55831 .84832 Mdot
.96216 .05379 Mdot
.71011 .22457 Mdot
.41504 .90126 Mdot
.46415 .10331 Mdot
.81625 .88419 Mdot
.57418 .05056 Mdot
.51428 .79092 Mdot
.1983 .47371 Mdot
.24381 .6379 Mdot
.74461 .34684 Mdot
.89348 .66194 Mdot
.54984 .86687 Mdot
.56539 .23814 Mdot
.47609 .27041 Mdot
.50737 .70873 Mdot
.65226 .52376 Mdot
.33283 .45848 Mdot
.72154 .11712 Mdot
.18687 .30805 Mdot
.86701 .0082 Mdot
.58709 .03292 Mdot
.76377 .01509 Mdot
.03123 .01102 Mdot
.58664 .5054 Mdot
.83934 .40006 Mdot
.75199 .87426 Mdot
.9581 .05389 Mdot
.73303 .69516 Mdot
.98786 .22281 Mdot
.65414 .20393 Mdot
.45314 .27994 Mdot
.41114 .56354 Mdot
.50968 .89189 Mdot
.28234 .92139 Mdot
.81339 .23936 Mdot
.04514 .05691 Mdot
.33502 .20605 Mdot
.66356 .53837 Mdot
.01764 .4996 Mdot
.28461 .49479 Mdot
.38398 .91967 Mdot
.27402 .64614 Mdot
.57683 .99833 Mdot
.50433 .72317 Mdot
.69919 .75359 Mdot
.58926 .16017 Mdot
.23579 .13787 Mdot
.16267 .46677 Mdot
.25024 .29847 Mdot
.14926 .56351 Mdot
.88443 .42056 Mdot
.22579 .70466 Mdot
.86076 .87929 Mdot
.30075 .41659 Mdot
.93741 .23979 Mdot
.4333 .33303 Mdot
.60524 .13422 Mdot
.21473 .53409 Mdot
.99365 .63858 Mdot
.6814 .42728 Mdot
.09415 .70264 Mdot
.1734 .51269 Mdot
.8562 .91418 Mdot
.60071 .44231 Mdot
.62804 .39669 Mdot
.6635 .67506 Mdot
.32615 .52604 Mdot
.58694 .9681 Mdot
.07633 .04871 Mdot
.73749 .78413 Mdot
.43821 .04891 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00Co0000ooooool0003o00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool02_ooool2o`000003ooooool0003ooooo00Gooooo0_l00008oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00;o00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00gooooo0_l0000>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool01?l0003oooooo`000?l0000<ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03Oooool2o`0000oooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`02o`0000cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`04oooo
o`;o00000oooool2o`0000;ooooo0_l0000>ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool00_ooool001kooooo00?o0000ooooooooool0K_ooool2o`0003[ooooo0_l0000Dooooo`;o
00007Oooool2o`0000;ooooo0_l0000aooooo`Co00000oooool2o`0001Cooooo0_l0000Booooo`00
7_ooool00ol0003oooooooooo`06ooooo`;o00002?ooool2o`0009Sooooo0_l0000Dooooo`;o0000
7Oooool2o`0000;ooooo0_l0000aooooo`;o00006oooool2o`0001;ooooo000Nooooo`03o`000?oo
oooooooo00Kooooo0_l00008ooooo`;o0000Boooool2o`0005cooooo0_l00008ooooo`;o0000;Ooo
ool2o`0003kooooo0_l0000Aooooo`007_ooool00ol0003oooooooooo`1Mooooo`;o0000G?ooool2
o`0000Sooooo0_l0000]ooooo`;o0000?_ooool2o`00017ooooo000Nooooo`03o`000?oooooooooo
02Kooooo0_l0001kooooo`;o0000A_ooool2o`0005[ooooo000Nooooo`04o`000?oooooo0000o`00
02Gooooo0_l0000_ooooo`;o0000:?ooool2o`00023ooooo0_l0000Zooooo`;o00005_ooool2o`00
00;ooooo0_l0001Jooooo`007_ooool01?l0003oooooo`000?l0000<ooooo`;o0000B?ooool2o`00
02Sooooo0_l0001<ooooo`;o00005_ooool2o`0005kooooo000Nooooo`03o`000?oooooooooo00go
oooo0_l0003ooooooa3ooooo0_l0000Wooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o0000
<oooool2o`0006gooooo0_l0001Qooooo`;o00009oooool001kooooo00?o0000ooooooooool05ooo
ool2o`0003?ooooo0_l0000Gooooo`;o0000=oooool2o`0001_ooooo0_l0000eooooo`;o00008?oo
ool2o`00037ooooo000Nooooo`03o`000?oooooooooo06Gooooo0_l0000gooooo`;o00006Oooool2
o`0003Oooooo0_l0000Pooooo`;o00000oooool2o`0001Wooooo0_l0000Aooooo`007_ooool00ol0
003oooooooooo`2iooooo`;o00005_ooool2o`0004Kooooo0_l0000Iooooo`;o00002_ooool2o`00
00Gooooo000Nooooo`03o`000?oooooooooo05[ooooo0_l0001Zooooo`;o00002Oooool2o`0001;o
oooo0_l0001Iooooo`;o00001Oooool001gooooo0_l0000Booooo`;o00000oooool2o`0000?ooooo
0_l0000nooooo`;o0000;_ooool2o`0002_ooooo0_l00003ooooo`;o00002?ooool2o`0001gooooo
0_l0001Pooooo`007Oooool3o`00017ooooo0_l00003ooooo`;o00000oooool2o`0006kooooo0_l0
000[ooooo`;o00000oooool2o`0001kooooo0_l00017ooooo`;o00008?ooool001kooooo00?o0000
ooooooooool0V?ooool2o`0004;ooooo0_l0000Iooooo`;o00007oooool2o`0000_ooooo0_l0000<
ooooo`Co00004?ooool001kooooo00?o0000ooooooooool02oooool2o`0008_ooooo0_l0001Moooo
o`;o00007oooool2o`0001Wooooo1?l0000@ooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o
0000F_ooool2o`000=kooooo000Nooooo`03o`000?oooooooooo06Oooooo0_l0000Looooo`;o0000
;oooool2o`0004Oooooo0_l00009ooooo`;o0000>oooool001kooooo00?o0000ooooooooool00_oo
ool2o`0001[ooooo0_l0001Uooooo`;o00001?ooool2o`00013ooooo0_l0000Gooooo`;o00000_oo
ool2o`00023ooooo0_l0000Qooooo`;o00002Oooool2o`0003_ooooo000Nooooo`03o`000?oooooo
oooo00;ooooo0_l0000Jooooo`;o00002Oooool2o`00063ooooo0_l0000?ooooo`?o00006oooool2
o`00023ooooo0_l0000Mooooo`;o00008?ooool2o`0001_ooooo0_l0000;ooooo`007_ooool00ol0
003oooooooooo`0Yooooo`;o00000_ooool2o`0006gooooo0_l0000Mooooo`;o0000?_ooool2o`00
00Oooooo0_l0000?ooooo`;o00001_ooool2o`0001_ooooo0_l0000;ooooo`007_ooool00ol0003o
ooooooooo`0]ooooo`;o0000S?ooool2o`0004Oooooo0_l0000?ooooo`;o0000<?ooool001kooooo
00?o0000ooooooooool0A_ooool2o`0008Wooooo0_l0001/ooooo`;o00001_ooool001kooooo00?o
0000ooooooooool0:Oooool2o`0001_ooooo0_l0000>ooooo`;o0000NOooool2o`0001Kooooo0_l0
000Tooooo`;o0000;_ooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo02Wooooo0_l0000[
ooooo`;o0000O_ooool2o`00017ooooo0_l0000Tooooo`;o0000=_ooool001kooooo00?o0000oooo
ooooool0e_ooool2o`0005_ooooo0_l0000Booooo`007_ooool00ol0003oooooooooo`25ooooo`;o
0000;_ooool2o`0000?ooooo0_l0000Mooooo`;o0000F?ooool2o`0001;ooooo000Nooooo`03o`00
0?oooooooooo07Wooooo0_l0000:ooooo`;o00005Oooool2o`0001Oooooo0_l00003ooooo`;o0000
7Oooool2o`0003Cooooo0_l0000Looooo`;o00006?ooool001kooooo00?o0000ooooooooool06_oo
ool2o`0005gooooo0_l0000Fooooo`;o00001oooool4o`00077ooooo0_l0000Looooo`;o00006?oo
ool001kooooo0_l00009ooooo`;o00004?ooool2o`00043ooooo0_l0000cooooo`;o00001oooool2
o`000:_ooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0000Xooooo`;o0000:?ooool2o`00
03Gooooo0_l0000^ooooo`;o0000P_ooool001kooooo00?o0000ooooooooool0<_ooool2o`0005oo
oooo0_l0000^ooooo`Co0000P?ooool001kooooo00?o0000ooooooooool0aOooool2o`0002Cooooo
0_l0001Jooooo`007_ooool00ol0003oooooooooo`2@ooooo`;o0000FOooool2o`0005[ooooo000N
ooooo`03o`000?oooooooooo05Sooooo0_l0000fooooo`;o0000E?ooool2o`0005oooooo000Noooo
o`03o`000?oooooooooo05Sooooo0_l0002<ooooo`;o0000FOooool2o`0000Cooooo000Nooooo`03
o`000?oooooooooo0?kooooo0_l00011ooooo`;o00001?ooool001kooooo00?o0000ooooooooool0
C?ooool2o`0000Gooooo0_l0000@ooooo`;o00009Oooool2o`0002Wooooo0_l00015ooooo`;o0000
Aoooool001kooooo00?o0000ooooooooool07oooool2o`0002_ooooo0_l00005ooooo`;o00004?oo
ool2o`0002Gooooo0_l0000Yooooo`;o0000I_ooool2o`0002Kooooo000Nooooo`03o`000?oooooo
oooo01oooooo0_l0000Uooooo`;o0000/_ooool2o`0001Oooooo0_l0000:ooooo`;o00009_ooool0
01kooooo0ol00016ooooo`;o0000Aoooool2o`00033ooooo0_l0000Iooooo`;o00007?ooool2o`00
017ooooo1?l00002ooooo`;o00004_ooool2o`0001kooooo000Nooooo`?o0000BOooool2o`0004Co
oooo0_l0000`ooooo`;o00006Oooool2o`0001Oooooo0_l0000Fooooo`Co00005_ooool4o`0001co
oooo000Nooooo`04o`000?ooooooooooooooo`;o00008_ooool2o`0002;ooooo0_l0002Zooooo`;o
0000<_ooool2o`0000Gooooo0_l0000Eooooo`007_ooool01?l0003oooooooooooooool2o`0002;o
oooo0_l0000Iooooo`;o0000<oooool2o`0003;ooooo0_l0000booooo`;o0000DOooool2o`0001Go
oooo000Nooooo`03o`000?oooooooooo043ooooo0_l0000cooooo`;o0000<_ooool2o`0001Oooooo
0_l0000Iooooo`;o00006?ooool2o`0003Cooooo0_l0000;ooooo`;o00002oooool001kooooo0_l0
001^ooooo`;o0000Doooool2o`0003?ooooo0_l0000dooooo`;o00002oooool2o`0000_ooooo000N
ooooo`03o`000?oooooooooo00[ooooo0_l0000>ooooo`;o0000<_ooool2o`0001gooooo0_l0000n
ooooo`;o00002oooool2o`0008_ooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l00006oooo
o`;o00003_ooool2o`0002Oooooo0_l00009ooooo`;o0000GOooool2o`0000_ooooo0_l00024oooo
o`;o00001Oooool001kooooo00?o0000ooooooooool00_ooool2o`0003oooooo0_l0001fooooo`Co
0000=_ooool2o`0004Wooooo0_l00005ooooo`007_ooool00ol0003oooooooooo`2:ooooo`;o0000
;oooool4o`0001Kooooo0_l00003ooooo`;o00006Oooool2o`0003[ooooo0_l0000Dooooo`007_oo
ool00ol0003oooooooooo`0?ooooo`;o00000oooool2o`0007Cooooo0_l00019ooooo`;o00000ooo
ool2o`0002oooooo0_l0000Tooooo`;o00005?ooool001kooooo00?o0000ooooooooool03oooool2
o`0000?ooooo0_l0000Wooooo`;o00002?ooool2o`0006?ooooo0_l0000>ooooo`;o0000>?ooool2
o`0000_ooooo0_l00006ooooo`;o0000>_ooool001kooooo00?o0000ooooooooool08?ooool2o`00
01_ooooo0_l00008ooooo`;o00003oooool2o`0004Wooooo0_l00007ooooo`;o00003_ooool2o`00
02[ooooo0_l0000<ooooo`;o00002oooool2o`0004;ooooo000Nooooo`03o`000?oooooooooo023o
oooo0_l0000fooooo`;o0000BOooool2o`0004?ooooo0_l0000>ooooo`;o00002?ooool2o`0004?o
oooo000Nooooo`03o`000?oooooooooo05oooooo0_l0002Gooooo`;o00002?ooool2o`00037ooooo
0_l0000@ooooo`007_ooool00ol0003oooooooooo`1Oooooo`;o0000A_ooool2o`0006Gooooo0_l0
000Uooooo`;o00004?ooool001kooooo00?o0000ooooooooool00oooool2o`0008Oooooo0_l00007
ooooo`;o00004?ooool2o`0004Oooooo0_l0000Looooo`;o00007Oooool2o`0001Sooooo000Noooo
o`03o`000?oooooooooo00?ooooo0_l00027ooooo`;o00001oooool2o`0003_ooooo0_l0000Goooo
o`;o00000oooool2o`0003_ooooo0_l0000Hooooo`007_ooool00ol0003oooooooooo`0_ooooo`;o
0000Ooooool2o`00023ooooo0_l0000Gooooo`;o00009oooool2o`00013ooooo0_l0000Oooooo`00
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`0_ooooo`;o0000D_ooool2o`0002_ooooo0_l0001Rooooo`;o00000_ooool2o`0000So
oooo0_l00002ooooo`;o00007oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0Poooool2o`00
023ooooo0_l0000Hooooo`;o0000Eoooool2o`0000Sooooo0_l0000Sooooo`000oooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool3o`0000?ooooo0_l0000loooo
o`;o0000AOooool2o`0000Wooooo0_l0000@ooooo`;o00006?ooool2o`0008Kooooo0003ooooo`05
o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo
00?ooooo0_l0000looooo`;o000000?oooooo`000?l00000@_ooool2o`0000Wooooo0_l0000Ooooo
o`;o00006oooool2o`0007Cooooo0003ooooo`05o`000?ooooooooooooooool000003_ooool00omg
MgOoIVIVooooo`05ooooo`03o`000?oooooooooo04Cooooo0_l0000Jooooo`;o00001oooool2o`00
04Wooooo0_l0000Kooooo`;o0000:oooool2o`0002Sooooo0_l0000Booooo`;o00002Oooool000?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0H?ooool2o`0000Oooooo0_l0000kooooo`;o0000E_ooool2o`0002Sooooo0_l0000:oooo
o`;o00001_ooool2o`0000Wooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0D_ooool2o`0005;ooooo0_l00014
ooooo`;o0000A_ooool2o`00017ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0>Oooool2o`0001Oooooo0_l0
000Nooooo`;o0000N?ooool2o`0005Wooooo000Nooooo`03o`000?oooooooooo03Wooooo0_l0000g
ooooo`;o00005Oooool2o`0000cooooo0_l0002^ooooo`007_ooool00ol0003oooooooooo`29oooo
o`;o00003?ooool2o`0000?ooooo0_l0000Pooooo`;o00006_ooool2o`0000Oooooo0_l00017oooo
o`?o00003_ooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l00007ooooo`;o
00008?ooool2o`0000Gooooo0_l0000_ooooo`;o00004?ooool2o`0000kooooo0_l0000Pooooo`;o
00003?ooool2o`0000cooooo0_l00007ooooo`;o00001_ooool2o`0003oooooo0ol0000>ooooo`;o
00002?ooool001kooooo00?o0000ooooooooool05oooool2o`0000Oooooo0_l0000?ooooo`;o0000
3oooool2o`0000Gooooo0_l0000_ooooo`;o00004?ooool2o`0002cooooo0_l0000@ooooo`;o0000
4_ooool2o`000003ooooool0003o000000Kooooo0_l0000Hooooo`;o0000@?ooool001kooooo00?o
0000ooooooooool0<Oooool2o`0008Oooooo0_l0000Tooooo`;o00008oooool2o`00043ooooo000N
ooooo`03o`000?oooooooooo05Wooooo0_l0003/ooooo`007_ooool00ol0003oooooooooo`03oooo
o`;o0000<oooool2o`0001oooooo0_l0001Cooooo`;o00001?ooool4o`0006Oooooo0_l0000Voooo
o`007_ooool00ol0003oooooooooo`03ooooo`;o0000<oooool2o`0000Wooooo0_l0000Fooooo`;o
0000DOooool2o`0000Cooooo1?l0000Mooooo`;o00001_ooool2o`0002Gooooo0_l0000Iooooo`;o
00001?ooool2o`0000Kooooo0_l0000:ooooo`;o00003?ooool001kooooo00?o0000ooooooooool0
3oooool2o`0003;ooooo0_l0000Fooooo`;o00001_ooool2o`0002Oooooo0_l00017ooooo`;o0000
1_ooool2o`0000Oooooo0_l0000Looooo`;o00007oooool2o`0000Kooooo0_l0000:ooooo`;o0000
3?ooool001kooooo00?o0000ooooooooool03oooool2o`0005;ooooo0_l0000Wooooo`;o0000F?oo
ool2o`0001[ooooo0_l0000Pooooo`;o00008Oooool001kooooo00?o0000ooooooooool0@?ooool2
o`0000Cooooo0_l00003ooooo`;o00007Oooool2o`0000Cooooo0_l0002@ooooo`;o00008?ooool2
o`0001;ooooo0_l0000=ooooo`007_ooool2o`00047ooooo0_l00004ooooo`;o00000oooool2o`00
01gooooo0_l00004ooooo`;o0000a_ooool2o`0000gooooo000Mooooo`;o0000Uoooool2o`000;3o
oooo000Mooooo`;o0000B?ooool2o`0004_ooooo1?l0001Iooooo`;o00002Oooool2o`0001cooooo
0_l0000/ooooo`007_ooool01?l0003oooooooooooooool2o`0004?ooooo0_l0000kooooo`;o0000
3_ooool2o`0000;ooooo0_l0001Gooooo`;o00002Oooool2o`0000?ooooo0_l0000Gooooo`;o0000
2_ooool2o`0000?ooooo0_l0000Kooooo`007_ooool01?l0003oooooooooooooool2o`00083ooooo
0_l0000Booooo`;o00004_ooool2o`0005?ooooo0_l0000Nooooo`;o00000oooool2o`0000?ooooo
0_l0000Kooooo`007_ooool00ol0003oooooooooo`2[ooooo`;o00001?ooool2o`0003?ooooo0_l0
000fooooo`Co00009Oooool001kooooo00?o0000ooooooooool0U_ooool3o`0001Sooooo0_l0000=
ooooo`;o00009?ooool2o`0003Kooooo0_l0000@ooooo`;o00005Oooool001kooooo00?o0000oooo
ooooool0<?ooool2o`0000kooooo0_l0000=ooooo`;o0000AOooool3o`0002Oooooo0_l0000]oooo
o`;o00003_ooool2o`0002oooooo0_l0000Eooooo`007_ooool00ol0003oooooooooo`0`ooooo`;o
00003_ooool2o`0000gooooo0_l00003ooooo`;o00004?ooool2o`0000Gooooo0_l0000mooooo`;o
00006?ooool2o`0001Cooooo0_l0000Aooooo`;o00001?ooool2o`0000Sooooo0_l00016ooooo`00
7_ooool00ol0003oooooooooo`1Dooooo`;o00004?ooool2o`000003ooooool0003o000000;ooooo
0_l0000Pooooo`;o00006oooool4o`0001Kooooo0_l0000Dooooo`;o00005oooool4o`0002kooooo
0_l0000Nooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o00008_ooool2o`0003Kooooo0_l0
000:ooooo`;o00006?ooool2o`00017ooooo0_l00004ooooo`;o00001?ooool2o`0001gooooo0_l0
000Xooooo`;o0000;_ooool2o`0000[ooooo0_l0000Booooo`007_ooool00ol0003oooooooooo`0=
ooooo`;o00002_ooool2o`0001Kooooo0_l00012ooooo`;o0000:oooool2o`0000Cooooo0_l0000F
ooooo`;o00002oooool2o`0000Gooooo0_l0000Rooooo`;o00006?ooool2o`0001oooooo0_l0000B
ooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o00009?ooool2o`0000Sooooo0_l0001eoooo
o`;o00004_ooool2o`0002;ooooo0_l0000Hooooo`;o0000<oooool001kooooo00?o0000oooooooo
ool0?oooool2o`0000Sooooo0_l0003looooo`007_ooool00ol0003oooooooooo`0Mooooo`;o0000
f_ooool2o`0004cooooo000Nooooo`03o`000?oooooooooo01gooooo0_l0000^ooooo`Co0000Z?oo
ool2o`0001Kooooo0_l0000dooooo`007_ooool2o`0004kooooo1?l00018ooooo`;o0000B_ooool2
o`0002[ooooo0_l0000=ooooo`;o00009Oooool001kooooo00?o0000ooooooooool0VOooool2o`00
04[ooooo0_l0000iooooo`;o00009Oooool001kooooo00?o0000ooooooooool0>Oooool2o`0003So
oooo0_l0001looooo`;o00005oooool2o`0003_ooooo000Nooooo`03o`000?oooooooooo027ooooo
0_l0000Fooooo`;o00004oooool2o`0002?ooooo0_l0000>ooooo`;o0000Doooool2o`0001Oooooo
0_l0000Gooooo`;o0000>oooool001kooooo00?o0000ooooooooool08Oooool2o`0000gooooo0_l0
000Looooo`;o0000<oooool2o`0002gooooo0_l0000Jooooo`;o00002?ooool2o`0004?ooooo0_l0
0005ooooo`;o00005oooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo033ooooo0_l0001L
ooooo`;o00008_ooool2o`0001[ooooo0_l0001=ooooo`;o00001Oooool2o`0001Oooooo0_l00008
ooooo`007_ooool01?l0003oooooooooooooool2o`0008_ooooo0_l0002gooooo`007_ooool3o`00
0003ooooool0003o000002?ooooo0_l0000?ooooo`;o0000;?ooool2o`0004Cooooo0_l0000Hoooo
o`;o0000M?ooool2o`000003ooooool0003o000000Oooooo000Nooooo`?o00003_ooool2o`0001Ko
oooo0_l0000:ooooo`;o00000oooool2o`0000[ooooo0_l00005ooooo`;o00006Oooool2o`0004Co
oooo0_l0000Hooooo`;o0000I?ooool2o`0000kooooo0_l000000ooooooo0000o`000007ooooo`00
7_ooool00ol0003oooooooooo`0>ooooo`;o00008_ooool2o`0000oooooo0_l00005ooooo`;o0000
7_ooool2o`0002cooooo0_l0000Rooooo`;o0000C?ooool2o`0001oooooo0_l0000Jooooo`007_oo
ool00ol0003oooooooooo`0[ooooo`;o0000?Oooool2o`0001gooooo0_l000000ooooooo0000o`00
000:ooooo`;o00008_ooool2o`0004cooooo0_l0000kooooo`007_ooool00ol0003oooooooooo`0[
ooooo`;o00003Oooool2o`0001Kooooo0_l0000eooooo`;o000000?oooooo`000?l000008oooool2
o`0008Kooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`0jooooo`;o00005_ooool2o`00
05gooooo0_l0001Mooooo`;o00005Oooool2o`00013ooooo0_l0000<ooooo`007_ooool00ol0003o
ooooooooo`06ooooo`;o0000LOooool2o`0002Oooooo0_l0000Sooooo`;o00004_ooool2o`0003?o
oooo0_l0000Eooooo`;o00007_ooool001kooooo00?o0000ooooooooool01_ooool2o`0003gooooo
0_l0000booooo`;o00006Oooool2o`0000cooooo0_l0000Sooooo`;o00000_ooool2o`0000kooooo
0_l0000Oooooo`;o00008?ooool2o`00023ooooo0_l00005ooooo`007Oooool2o`0004Oooooo0_l0
0003ooooo`;o0000B?ooool2o`0001Kooooo0_l0000Mooooo`;o00008Oooool2o`0000cooooo0_l0
000Pooooo`;o00008?ooool2o`0000Gooooo000Mooooo`?o0000Boooool2o`00063ooooo0_l00010
ooooo`;o00001Oooool2o`0002Gooooo0_l0000Yooooo`007_ooool00ol0003oooooooooo`2Soooo
o`;o0000D?ooool2o`0002Gooooo0_l0000Yooooo`007_ooool00ol0003oooooooooo`0Fooooo`;o
00000_ooool2o`0008Oooooo0_l0002Rooooo`007_ooool00ol0003oooooooooo`0Fooooo`;o0000
0_ooool2o`0002Oooooo0_l0003oooooo`?ooooo000Nooooo`03o`000?oooooooooo01Sooooo0_l0
000Yooooo`;o0000<oooool2o`000<gooooo000Nooooo`03o`000?oooooooooo00cooooo0_l0000:
ooooo`;o0000<?ooool2o`0002?ooooo0_l00007ooooo`;o0000=_ooool2o`0009Gooooo000Noooo
o`03o`000?oooooooooo00_ooooo0ol0000Yooooo`;o00004Oooool2o`0000Wooooo0_l0000Hoooo
o`;o00006oooool2o`0002;ooooo0_l0002Eooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o
0000:_ooool2o`00017ooooo0_l00009ooooo`;o0000=Oooool2o`000;Wooooo000Nooooo`03o`00
0?oooooooooo03cooooo0_l0001Iooooo`;o00001_ooool2o`000:Kooooo000Nooooo`03o`000?oo
oooooooo03cooooo0_l0001Iooooo`;o00001_ooool2o`0001gooooo0_l0000:ooooo`;o0000COoo
ool2o`00017ooooo0_l00009ooooo`;o00003_ooool001kooooo00?o0000ooooooooool0[Oooool2
o`0000_ooooo0_l00002ooooo`;o00001oooool2o`000003ooooool0003o000004gooooo1?l0000?
ooooo`;o00002Oooool2o`0000kooooo000Nooooo`03o`000?oooooooooo04Oooooo0_l0001Toooo
o`;o00002oooool2o`0000_ooooo0_l0000Pooooo`;o0000<?ooool2o`0002[ooooo000Nooooo`03
o`000?oooooooooo04Oooooo0_l0000`ooooo`;o00004oooool2o`0002[ooooo0_l0000]ooooo`;o
0000G?ooool001kooooo00?o0000ooooooooool0NOooool2o`0001?ooooo0_l00007ooooo`;o0000
8Oooool2o`0004cooooo0_l0000Xooooo`?o00004_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0
L_ooool2o`0002?ooooo0_l0000Mooooo`;o0000D?ooool2o`0002Sooooo0ol0000Booooo`000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0L_ooool2o`0004;ooooo0_l0000@ooooo`;o00006Oooool2o`00027ooooo
0_l0000oooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`?o0000
3oooool2o`0009Sooooo0_l00008ooooo`;o00004oooool2o`0001Wooooo0_l0000Qooooo`;o0000
1Oooool2o`0003Sooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgM
ooooool00007ooooo`03o`000?oooooooooo00oooooo0_l0000Yooooo`;o00001oooool2o`0006Co
oooo0_l00008ooooo`;o0000>?ooool2o`0001kooooo0_l0000hooooo`000oooool01Ol0003ooooo
oooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`0joooo
o`;o00001oooool2o`000:Sooooo0_l0001Hooooo`000oooool01Ol@413ooooooooooooooooo410@
00cooooo00?oMgMgolc<c?l000001oooool3o`0005Oooooo0_l0001?ooooo`;o00003?ooool2o`00
05Cooooo0_l0000iooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4
A?l000001oooool3o`0002Gooooo0_l0000`ooooo`;o0000Coooool2o`0000cooooo0_l0001Doooo
o`;o0000>Oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo
00Kooooo00?o0000ooooooooool07Oooool2o`0000Kooooo0_l0000fooooo`?o00001_ooool2o`00
00oooooo0_l0002Oooooo`;o00007?ooool2o`0000oooooo000Nooooo`03o`000?oooooooooo01go
oooo0_l0000nooooo`?o00001_ooool2o`0000oooooo0_l0002Oooooo`;o00007?ooool2o`0000oo
oooo000Nooooo`03o`000?oooooooooo0?oooooo0Oooool2o`0001Wooooo0_l0000Aooooo`;o0000
5oooool001kooooo00?o0000ooooooooool01oooool2o`0005?ooooo0_l0002Rooooo`;o00006Ooo
ool2o`00017ooooo0_l0000Gooooo`007_ooool00ol0003oooooooooo`07ooooo`Go0000>oooool2
o`0001?ooooo0_l0000=ooooo`;o0000K?ooool2o`0006cooooo000Nooooo`03o`000?oooooooooo
00Sooooo1?l00008ooooo`;o0000<Oooool2o`0002;ooooo0_l0001/ooooo`;o0000C?ooool2o`00
01kooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0003jooooo`;o00005Oooool2o`0001ko
oooo000Nooooo`03o`000?oooooooooo03Cooooo0_l0002@ooooo`;o0000B?ooool2o`0003Gooooo
000Nooooo`03o`000?oooooooooo01Sooooo0_l0000Jooooo`;o0000H?ooool2o`00017ooooo0_l0
000Kooooo`;o0000Ooooool001kooooo00?o0000ooooooooool06?ooool2o`0000Kooooo0_l0000l
ooooo`;o0000=_ooool2o`00017ooooo0_l0000Dooooo`;o0000Q_ooool001kooooo00?o0000oooo
ooooool08?ooool2o`0003cooooo0_l0000Dooooo`;o0000BOooool2o`0008Kooooo000Nooooo`03
o`000?oooooooooo00Oooooo0_l0001[ooooo`;o00003?ooool2o`000<?ooooo000Nooooo`;o0000
2?ooool2o`0007Wooooo0_l00026ooooo`;o0000>oooool001kooooo0_l0003oooooo`cooooo0_l0
000Kooooo`;o00007_ooool001kooooo0_l00007ooooo`;o0000<Oooool2o`0002gooooo0_l0002m
ooooo`;o00007_ooool001kooooo00?o0000ooooooooool01_ooool2o`00037ooooo0_l0000]oooo
o`;o0000DOooool2o`0008[ooooo000Nooooo`03o`000?oooooooooo00Gooooo0_l0002;ooooo`;o
00009oooool2o`00047ooooo0_l0000dooooo`;o00000oooool2o`0000cooooo000Nooooo`03o`00
0?oooooooooo00Gooooo0_l0000Zooooo`;o0000G?ooool2o`000003ooooool0003o000002oooooo
0_l0000iooooo`;o00000_ooool2o`00033ooooo0_l00003ooooo`;o00003?ooool001kooooo00?o
0000ooooooooool0<Oooool2o`0005cooooo0_l0000Looooo`;o00005?ooool2o`0000Oooooo0_l0
000Hooooo`;o00006_ooool2o`0004?ooooo000Nooooo`03o`000?oooooooooo03cooooo0_l0001_
ooooo`;o00004?ooool2o`0000_ooooo0_l0000<ooooo`;o00002_ooool2o`0002gooooo0_l0000`
ooooo`007_ooool00ol0003oooooooooo`0looooo`;o0000POooool2o`0001Wooooo0_l00007oooo
o`;o0000<?ooool2o`00023ooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`1Vooooo`;o
00009oooool2o`0000Sooooo0_l0000kooooo`;o00002oooool2o`0005;ooooo0_l0000>ooooo`00
7_ooool00ol0003oooooooooo`0aooooo`;o00007?ooool2o`0001Gooooo0_l0000Wooooo`;o0000
2?ooool2o`0003_ooooo0_l000000ooooooo0000o`000007ooooo`;o0000Hoooool001kooooo00?o
0000ooooooooool0:oooool2o`0000Cooooo0_l0000Looooo`;o0000R?ooool2o`0000Oooooo0_l0
001Sooooo`007_ooool00ol0003oooooooooo`0[ooooo`;o0000oooooolEooooo`;o00001?ooool0
01kooooo00?o0000ooooooooool0JOooool2o`0008Sooooo0_l0001<ooooo`;o00001?ooool001ko
oooo00?o0000ooooooooool0F?ooool2o`0000oooooo0_l00025ooooo`;o000000?oooooo`000?l0
0000B_ooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0001Dooooo`;o0000
U_ooool2o`0004gooooo0_l00006ooooo`007_ooool2o`0000?ooooo0_l00003ooooo`;o00003?oo
ool2o`0005oooooo0_l0000dooooo`;o0000HOooool2o`00013ooooo0_l0000Tooooo`007_ooool0
0ol0003oooooooooo`07ooooo`Co00002_ooool2o`0004[ooooo0_l0000Cooooo`;o0000=?ooool2
o`0000gooooo0_l0000nooooo`;o00004_ooool2o`00013ooooo0_l0000Tooooo`007_ooool00ol0
003oooooooooo`09ooooo`;o00006Oooool2o`0002Oooooo0_l0000Booooo`;o0000C_ooool2o`00
00Sooooo0_l0000looooo`Co0000B_ooool001kooooo00?o0000ooooooooool02_ooool2o`0001So
oooo0_l0000Wooooo`;o0000H_ooool2o`0004Kooooo0_l0000Vooooo`;o000000?oooooo`000?l0
00008Oooool001kooooo00?o0000ooooooooool02_ooool2o`0002Sooooo0_l0003[ooooo`;o0000
00?oooooo`000?l000001Oooool2o`0001[ooooo000Nooooo`03o`000?oooooooooo02_ooooo0_l0
0007ooooo`;o00001oooool2o`0007Gooooo0_l0000;ooooo`;o0000BOooool2o`0001gooooo0_l0
000Jooooo`007_ooool00ol0003oooooooooo`0[ooooo`;o00000_ooool2o`0000cooooo0_l0001V
ooooo`;o00003Oooool2o`0000_ooooo0_l00007ooooo`;o00009Oooool2o`0001Wooooo0_l0000i
ooooo`007_ooool00ol0003oooooooooo`0_ooooo`;o00008Oooool2o`0000Oooooo0_l0000Soooo
o`;o00008oooool2o`0002?ooooo0_l00004ooooo`;o00007oooool2o`0005Cooooo000Nooooo`03
o`000?oooooooooo00?ooooo0_l0001=ooooo`;o00001oooool2o`0000Wooooo0_l0000Hooooo`;o
0000C_ooool2o`0007Gooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0001Qooooo`;o0000
Poooool2o`0000Sooooo0_l0001@ooooo`007_ooool00ol0003oooooooooo`0fooooo`;o00004_oo
ool2o`0002Gooooo0_l0001Gooooo`;o00007oooool2o`0000Sooooo0_l0001@ooooo`007_ooool0
0ol0003oooooooooo`0fooooo`;o00002_ooool2o`0000Kooooo0_l0000Uooooo`;o0000Eoooool2
o`0002Gooooo0_l0001Dooooo`007_ooool00ol0003oooooooooo`12ooooo`;o0000A?ooool2o`00
02Gooooo0_l0000Sooooo`;o00006oooool2o`0005Cooooo000Nooooo`03o`000?oooooooooo033o
oooo0_l0001Fooooo`;o00009Oooool2o`0002?ooooo0_l0001Cooooo`Co00006_ooool001kooooo
00?o0000ooooooooool08oooool2o`0000_ooooo0_l0001;ooooo`;o0000Z_ooool4o`0001[ooooo
000Nooooo`03o`000?oooooooooo02?ooooo0_l0000Cooooo`;o0000@oooool2o`00027ooooo0_l0
001;ooooo`;o0000F?ooool001kooooo0_l0000iooooo`;o00004Oooool2o`0004Kooooo0_l0000;
ooooo`;o00002oooool2o`0003gooooo0ol00004ooooo`;o00003_ooool2o`0004;ooooo000Noooo
o`03o`000?oooooooooo04_ooooo0_l0000:ooooo`;o0000>_ooool2o`0001Sooooo0_l0000moooo
o`;o00001Oooool2o`0000kooooo0_l00012ooooo`007_ooool00ol0003oooooooooo`1Gooooo`;o
0000k_ooool001kooooo00?o0000ooooooooool0G?ooool2o`0001Wooooo0_l0000Pooooo`;o0000
[?ooool001kooooo00?o0000ooooooooool0;?ooool2o`0002kooooo0_l0000Iooooo`;o00002Ooo
ool2o`0001Gooooo0_l0001fooooo`;o0000=?ooool001kooooo00?o0000ooooooooool06_ooool2
o`00013ooooo0_l0001Dooooo`;o00000_ooool2o`0008Wooooo0_l0000dooooo`007_ooool00ol0
003oooooooooo`0Jooooo`;o0000?_ooool2o`0002[ooooo0_l0001Jooooo`;o0000@?ooool2o`00
027ooooo000Mooooo`;o0000G?ooool2o`0003_ooooo0_l0000Wooooo`;o00002_ooool2o`0000;o
oooo0_l0000@ooooo`;o0000@?ooool2o`00027ooooo000Mooooo`;o0000K_ooool2o`0002Wooooo
1?l0000Uooooo`;o00002_ooool2o`0000;ooooo0_l0001eooooo`007Oooool2o`0006kooooo0_l0
000[ooooo`;o00004?ooool2o`0002kooooo0_l0000@ooooo`;o0000F?ooool001kooooo00?o0000
ooooooooool05Oooool2o`0002Gooooo0_l00016ooooo`;o00009Oooool2o`0002[ooooo1_l0000@
ooooo`;o0000F?ooool001kooooo00?o0000ooooooooool05Oooool2o`0002Gooooo0_l00016oooo
o`;o0000DOooool4o`0002gooooo0_l0000mooooo`007_ooool00ol0003oooooooooo`0fooooo`;o
0000B?ooool4o`0008Cooooo0_l0000mooooo`007_ooool00ol0003oooooooooo`0fooooo`;o0000
B?ooool4o`0000cooooo0_l0000mooooo`;o00003_ooool2o`0003Gooooo0_l0000_ooooo`000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<
c<`01_ooool00ol0003oooooooooo`2@ooooo`;o0000?Oooool2o`0000gooooo0ol0000eooooo`;o
0000;oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGo
MgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0V?ooool2o`00013ooooo0_l0000boooo
o`;o00001_ooool2o`0004gooooo1?l00002ooooo`;o00002_ooool000?ooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`0005Kooooo0_l00010
ooooo`;o00004?ooool2o`0000kooooo0_l0000Zooooo`;o00007oooool2o`0002cooooo1?l00002
ooooo`;o00002_ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9So
oooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0aooooo`;o00008oooool2o`0006;ooooo0_l0
0004ooooo`;o0000AOooool2o`0003kooooo0003ooooo`05o`000?ooooooooooooooool000002ooo
ool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0<Oooool2o`0004?ooooo
0_l00018ooooo`;o00004_ooool2o`0001gooooo0_l0001Booooo`000oooool01Ol@413ooooooooo
oooooooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`0=ooooo`;o0000
4oooool2o`0005;ooooo0_l0000Mooooo`;o0000?Oooool2o`0001gooooo0ol0001Aooooo`000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003ooooo
ooooo`0=ooooo`;o00000oooool2o`0000kooooo0_l0001aooooo`;o0000GOooool2o`0000cooooo
0_l00013ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o
410@1_ooool00ol0003oooooooooo`0Booooo`;o0000?oooool2o`0007Sooooo0_l0000cooooo`;o
0000@oooool001kooooo00?o0000ooooooooool0Doooool2o`00023ooooo0_l0001Fooooo`;o0000
N?ooool001kooooo00?o0000ooooooooool0<_ooool2o`00047ooooo0_l00011ooooo`;o0000SOoo
ool001kooooo00?o0000ooooooooool00_l0000`ooooo`;o0000I?ooool2o`0001kooooo0_l0002=
ooooo`007_ooool00ol0003oooooooooo`02o`0004Gooooo0_l0001?ooooo`;o00008Oooool2o`00
08[ooooo000Nooooo`03o`000?oooooooooo00;o0000??ooool2o`0000Oooooo0_l000000ooooooo
0000o`00001Cooooo`;o00006_ooool2o`0001;ooooo0_l0001fooooo`007_ooool00ol0003ooooo
ooooo`0Mooooo`;o00007oooool2o`0000[ooooo0_l0000/ooooo`;o00009Oooool2o`0002kooooo
0_l0000<ooooo`;o00001?ooool2o`0002oooooo0_l0000aooooo`007_ooool00ol0003ooooooooo
o`0Mooooo`;o0000;?ooool2o`0002_ooooo0_l0001Sooooo`;o00001?ooool3o`0002kooooo0_l0
000Eooooo`;o00006_ooool001kooooo00?o0000ooooooooool0Boooool2o`0009Oooooo0_l0000P
ooooo`;o00008oooool2o`0001;ooooo0_l00006ooooo`007_ooool00ol0003oooooooooo`02oooo
o`;o00004?ooool2o`000:Oooooo0_l00017ooooo`;o00003Oooool2o`0002Sooooo0_l00006oooo
o`007_ooool00ol0003oooooooooo`02ooooo`;o00004?ooool2o`0003oooooo0_l0001Vooooo`;o
00003?ooool2o`00037ooooo0ol0000Dooooo`;o0000<?ooool001kooooo00?o0000ooooooooool0
BOooool2o`0000[ooooo0_l0000Zooooo`;o0000B?ooool2o`00037ooooo0ol00016ooooo`007_oo
ool2o`0001Gooooo0_l0000cooooo`;o00001oooool2o`0002gooooo0_l0000Aooooo`;o0000I_oo
ool2o`0004Wooooo000Nooooo`03o`000?oooooooooo00Gooooo0_l0000=ooooo`;o0000??ooool2
o`00043ooooo0_l0001Vooooo`;o0000BOooool001kooooo00?o0000ooooooooool01Oooool2o`00
03cooooo0_l00016ooooo`;o0000Noooool2o`0003gooooo000Nooooo`03o`000?oooooooooo04?o
oooo0_l0000=ooooo`;o0000;?ooool2o`0000Wooooo0_l0001kooooo`;o00005?ooool2o`0002Oo
oooo000Nooooo`;o0000Doooool2o`0001[ooooo0_l0000@ooooo`;o00009_ooool2o`0001Cooooo
0_l00008ooooo`;o0000E?ooool2o`0000Kooooo0_l0000Eooooo`;o00002?ooool001kooooo0_l0
0017ooooo`;o00002oooool2o`0001Wooooo0_l0000hooooo`;o00003?ooool2o`0000Kooooo0_l0
0008ooooo`;o0000=Oooool2o`0002Gooooo0_l00006ooooo`;o00003Oooool2o`0000Sooooo000N
ooooo`03o`000?oooooooooo04Kooooo0_l0000;ooooo`;o0000HOooool2o`0004Oooooo1?l0000[
ooooo`;o00005oooool001kooooo00?o0000ooooooooool03oooool2o`0003Gooooo0_l0002_oooo
o`;o00000_ooool2o`0000Cooooo0_l00014ooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o
0000Joooool2o`0005Kooooo0_l0000Qooooo`;o00000_ooool2o`0004[ooooo000Nooooo`03o`00
0?oooooooooo07cooooo0_l0001Fooooo`;o0000LOooool001kooooo0ol00023ooooo`;o0000/ooo
ool2o`0000gooooo000Nooooo`?o0000MOooool2o`0000cooooo0_l0002cooooo`;o00003Oooool0
01kooooo00?o0000ooooooooool0@Oooool2o`0002Wooooo0_l00007ooooo`;o0000<_ooool2o`00
04Sooooo0_l0000looooo`;o00005?ooool001kooooo00?o0000ooooooooool0@Oooool2o`0002Wo
oooo0_l0000kooooo`;o0000B?ooool2o`0001Wooooo0_l0000Qooooo`;o00001_ooool2o`0000co
oooo000Nooooo`03o`000?oooooooooo07;ooooo0_l0001fooooo`;o00008_ooool2o`0002;ooooo
1?l00003ooooo`;o00003?ooool001kooooo00?o0000ooooooooool0B_ooool2o`0002Kooooo0_l0
000Yooooo`;o0000Boooool2o`0004Kooooo1?l0000Aooooo`007_ooool2o`0001_ooooo0_l0000^
ooooo`;o0000@oooool2o`0000cooooo0_l0000Mooooo`;o00006Oooool2o`0003_ooooo0_l0000a
ooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o0000:Oooool2o`0004Sooooo0_l0000[oooo
o`;o00006Oooool2o`0001Wooooo0_l0000Pooooo`;o0000<Oooool001kooooo00?o0000oooooooo
ool0AOooool2o`0001?ooooo0_l0000Tooooo`;o00007oooool2o`0004;ooooo0_l0000;ooooo`;o
00000oooool2o`0004kooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l00005ooooo`;o0000
7Oooool2o`0002_ooooo0_l0000Tooooo`;o00007oooool2o`0002_ooooo0_l0000Eooooo`;o0000
4?ooool2o`0004kooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l00005ooooo`;o00007Ooo
ool2o`0007;ooooo0_l0000=ooooo`;o00007?ooool2o`0007Oooooo000Nooooo`03o`000?oooooo
oooo0;3ooooo0_l0002Eooooo`007_ooool00ol0003oooooooooo`0booooo`;o0000A?ooool2o`00
063ooooo0_l0001[ooooo`007_ooool00ol0003oooooooooo`0booooo`;o0000A?ooool2o`0002Ko
oooo0_l0000hooooo`;o0000Joooool001kooooo00Co0000oooooooooooooooo0_l00004ooooo`;o
0000B_ooool2o`0004_ooooo0_l00003ooooo`;o00002oooool2o`0009?ooooo000Nooooo`04o`00
0?ooooooooooooooo`;o00001?ooool2o`0004[ooooo0_l0001@ooooo`;o00002oooool2o`0003ko
oooo0_l0001Cooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o0000M?ooool2o`0005Oooooo
0_l00006ooooo`;o00006?ooool2o`00037ooooo000Nooooo`03o`000?oooooooooo00gooooo0_l0
000Dooooo`;o0000<oooool2o`0003oooooo0_l0000Oooooo`;o00007_ooool2o`0001?ooooo0_l0
0009ooooo`;o00006?ooool2o`0002Oooooo0_l00008ooooo`007_ooool00ol0003oooooooooo`0=
ooooo`;o0000BOooool2o`00063ooooo0_l0000Nooooo`;o00004oooool2o`00023ooooo0ol0000Y
ooooo`;o00002?ooool001kooooo00?o0000ooooooooool02oooool2o`000?oooooo1Oooool3o`00
03?ooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l00003ooooo`;o0000R?ooool2o`000;3o
oooo000Nooooo`03o`000?oooooooooo00Kooooo0_l0000Pooooo`;o0000<?ooool2o`0003Wooooo
0_l00012ooooo`;o00004?ooool3o`0003Kooooo0_l0000Qooooo`007_ooool2o`0002Wooooo0_l0
000Sooooo`;o00002oooool2o`0007gooooo0_l0000@ooooo`?o00005Oooool2o`0001oooooo0_l0
000Qooooo`007_ooool00ol0003oooooooooo`04ooooo`;o0000Aoooool2o`0001Gooooo0_l00011
ooooo`;o00002oooool2o`0000oooooo0_l0000Hooooo`;o00008_ooool3o`00047ooooo000Noooo
o`03o`000?oooooooooo00Cooooo0_l0000Qooooo`;o000000?oooooo`000?l00000=oooool3o`00
0003ooooool0003o0000013ooooo0_l0000/ooooo`;o00002oooool2o`0000oooooo0_l0000Hoooo
o`;o00008oooool2o`00047ooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l000000ooooooo
0000o`00000gooooo`;o00000_ooool2o`00013ooooo0_l0000looooo`;o0000S_ooool001kooooo
00?o0000ooooooooool09oooool2o`0002oooooo0_l0001Mooooo`;o00003Oooool2o`0001gooooo
0_l0000mooooo`;o00008Oooool001kooooo00?o0000ooooooooool0F?ooool2o`0006cooooo0_l0
000Mooooo`;o0000?Oooool2o`00027ooooo000Nooooo`03o`000?oooooooooo02;ooooo0_l0003o
ooooobCooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l00002ooooo`;o00001Oooool2o`00
06cooooo0_l0000gooooo`;o0000O?ooool001kooooo00?o0000ooooooooool05oooool2o`0000;o
oooo0_l0001cooooo`;o0000=oooool2o`0004Gooooo0_l000000ooooooo0000o`00000booooo`00
7_ooool00ol0003oooooooooo`1hooooo`;o0000Ioooool2o`0002gooooo0_l000000ooooooo0000
o`00000booooo`007_ooool00ol0003oooooooooo`1hooooo`;o00002oooool2o`0005[ooooo0_l0
001Tooooo`007_ooool00ol0003oooooooooo`1Gooooo`;o000000?oooooo`000?l00000:Oooool2
o`0006Gooooo0_l0001Iooooo`007_ooool00ol0003oooooooooo`1Gooooo`;o000000?oooooo`00
0?l000004_ooool2o`0002[ooooo0_l000000ooooooo0000o`00001=ooooo`;o00002_ooool2o`00
00Kooooo0_l00015ooooo`007_ooool00ol0003oooooooooo`04ooooo`;o0000DOooool2o`0001Go
oooo0_l0000Zooooo`;o000000?oooooo`000?l000000oooool3o`0003kooooo0_l0000Cooooo`;o
00001_ooool2o`0004Gooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo00Cooooo0_l0001Aoooo
o`;o0000BOooool3o`0003Cooooo0_l00008ooooo`;o0000H_ooool000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000
ooooooooool0Y_ooool2o`00037ooooo0_l00009ooooo`;o0000;Oooool2o`0001?ooooo0_l0000M
ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00
0006ooooo`?o00007oooool2o`0008;ooooo0_l000000ooooooo0000o`00000aooooo`;o00002Ooo
ool2o`0001;ooooo0_l0000Iooooo`;o00004oooool2o`0001Oooooo0_l00004ooooo`000oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`00
0?oooooooooo01oooooo0_l0001Booooo`;o0000;_ooool2o`0002oooooo0_l0000Rooooo`;o0000
Aoooool2o`0000Cooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0Loooool2o`0005;ooooo0_l0000;ooooo`;o
0000LOooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj
^_l@41001_ooool00ol0003oooooooooo`37ooooo`;o00004_ooool2o`0002Gooooo0_l00004oooo
o`;o00006oooool2o`00023ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool04?ooool2o`0009;ooooo0ol0000d
ooooo`;o00009Oooool2o`0000Cooooo0_l0000Kooooo`;o00004oooool2o`0000_ooooo0003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o
0000ooooooooool04?ooool2o`0002;ooooo0_l0001Qooooo`;o00002oooool3o`0003kooooo0_l0
001Cooooo`;o00002oooool001kooooo00?o0000ooooooooool06_ooool3o`0001Oooooo0_l0001Q
ooooo`;o0000C?ooool2o`00063ooooo000Nooooo`03o`000?oooooooooo01[ooooo0ol0000Uoooo
o`;o0000ooooool4ooooo`007_ooool00ol0003oooooooooo`12ooooo`;o0000Doooool2o`0005oo
oooo0_l00010ooooo`;o00002oooool001kooooo00?o0000ooooooooool0Uoooool2o`0005oooooo
0_l0000oooooo`?o00002oooool001kooooo00?o0000ooooooooool0Roooool2o`00047ooooo0_l0
000Uooooo`;o0000@_ooool2o`0000cooooo000Nooooo`03o`000?oooooooooo07gooooo0_l0000<
ooooo`;o0000?oooool4o`0002Gooooo0_l0001@ooooo`007_ooool00ol0003oooooooooo`1:oooo
o`;o0000<Oooool2o`0002gooooo0_l00006ooooo`;o00005_ooool2o`0007Wooooo000Nooooo`03
o`000?oooooooooo04[ooooo0_l0000Hooooo`;o0000A_ooool2o`0000Kooooo0_l0000looooo`;o
0000@?ooool2o`00017ooooo000Nooooo`03o`000?oooooooooo03Kooooo0_l0000/ooooo`;o0000
5?ooool2o`0007Kooooo0_l0000Cooooo`;o0000:oooool2o`00017ooooo000Nooooo`03o`000?oo
oooooooo03Kooooo0_l00012ooooo`;o0000H_ooool2o`0002Oooooo0_l0000nooooo`007_ooool0
0ol0003oooooooooo`2aooooo`;o0000:oooool2o`0006Oooooo000Nooooo`;o00002oooool2o`00
0:Gooooo0_l0000<ooooo`;o0000=?ooool2o`0003Kooooo0_l0000Hooooo`007_ooool00ol0003o
ooooooooo`0:ooooo`;o0000B?ooool2o`0006Wooooo0_l0000dooooo`;o0000=_ooool2o`0001So
oooo000Nooooo`03o`000?oooooooooo05Cooooo0_l00005ooooo`;o0000cOooool2o`0001?ooooo
0_l00006ooooo`007_ooool00ol0003oooooooooo`1Booooo`;o00001oooool2o`000<gooooo0_l0
000Cooooo`;o00001_ooool001kooooo00?o0000ooooooooool06oooool2o`0003Gooooo0_l00007
ooooo`;o0000I_ooool2o`0008;ooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0000Goooo
o`;o0000>Oooool2o`0004?ooooo0_l0000Booooo`;o00004_ooool2o`0006Gooooo0_l0000Koooo
o`007_ooool00ol0003oooooooooo`02ooooo`;o00001?ooool2o`00027ooooo0_l0000Yooooo`;o
0000@oooool2o`0001;ooooo0_l0000dooooo`;o00000oooool2o`0002oooooo0_l0000=ooooo`;o
00006oooool001kooooo00?o0000ooooooooool02?ooool2o`00027ooooo0_l0000<ooooo`;o0000
1Oooool2o`000:?ooooo0_l00003ooooo`;o00001?ooool2o`0002Wooooo0_l0000Zooooo`007_oo
ool00ol0003oooooooooo`0iooooo`;o00001Oooool2o`0008?ooooo1?l0000Wooooo`;o0000Aooo
ool2o`0000cooooo000Nooooo`03o`000?oooooooooo0<Gooooo1?l0001;ooooo`Co00005oooool2
o`0000Sooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`3ooooooaGooooo1?l0000Eoooo
o`Co00005_ooool001kooooo00?o0000ooooooooool0HOooool2o`0001_ooooo0_l0000Oooooo`;o
00004oooool2o`0003Kooooo0_l0000Gooooo`;o00009_ooool2o`0001Sooooo000Nooooo`03o`00
0?oooooooooo00Gooooo0_l0000?ooooo`;o00006Oooool2o`0002kooooo0_l0000Kooooo`;o0000
7oooool2o`0001?ooooo0_l0000fooooo`;o00005oooool2o`0001gooooo0_l0000Qooooo`007_oo
ool00ol0003oooooooooo`05ooooo`;o00003oooool2o`0001Wooooo0_l0001_ooooo`;o00009Ooo
ool2o`0005Wooooo0_l0000Qooooo`007_ooool00ol0003oooooooooo`2Rooooo`;o00007?ooool2
o`0000Oooooo0_l0001looooo`007_ooool00ol0003oooooooooo`2;ooooo`;o0000<_ooool3o`00
08Gooooo000Nooooo`;o00002oooool2o`0000?ooooo0_l0000Jooooo`?o0000EOooool2o`0000Ko
oooo0_l0000booooo`;o00003?ooool2o`0007Sooooo000Nooooo`03o`000?oooooooooo00;o0000
2?ooool2o`0000?ooooo0_l0000Jooooo`?o0000EOooool2o`0000?ooooo0_l00013ooooo`;o0000
6Oooool2o`0005gooooo000Nooooo`03o`000?oooooooooo00;o0000:?ooool2o`00033ooooo0_l0
0003ooooo`;o00009Oooool2o`0000Kooooo0_l0000@ooooo`;o0000A?ooool2o`0005gooooo000N
ooooo`03o`000?oooooooooo02[ooooo0_l0000`ooooo`;o00000oooool2o`0002gooooo0_l0000@
ooooo`?o0000B_ooool2o`0001[ooooo0_l0000[ooooo`;o00003Oooool001kooooo00?o0000oooo
ooooool0:oooool2o`0003Kooooo0_l0000nooooo`;o0000B_ooool2o`0000Cooooo0_l0000Doooo
o`;o00001Oooool2o`0001[ooooo0_l00008ooooo`;o00003Oooool001kooooo00?o0000oooooooo
ool0:oooool2o`0003Kooooo0_l0000/ooooo`;o0000DOooool2o`0000oooooo0_l0000Kooooo`;o
00003?ooool2o`0000cooooo0_l0000Gooooo`007_ooool00ol0003oooooooooo`1iooooo`;o0000
5_ooool2o`00057ooooo0_l0000jooooo`;o00009Oooool001kooooo0ol0000jooooo`;o00001?oo
ool2o`0001Kooooo0_l0000Oooooo`;o0000L_ooool2o`0005Sooooo000Nooooo`?o00001_ooool2
o`0000Sooooo0_l0000Xooooo`;o00001?ooool2o`000003ooooool0003o000001?ooooo0_l0000_
ooooo`;o00004?ooool2o`0001?ooooo0_l0000Oooooo`;o00006_ooool2o`0004Gooooo0_l0000A
ooooo`007_ooool00ol0003oooooooooo`06ooooo`;o00002?ooool2o`00037ooooo0_l00014oooo
o`;o00004?ooool2o`0001?ooooo0_l0000Cooooo`;o00002_ooool2o`00047ooooo0_l0000Noooo
o`;o00004Oooool001kooooo00Co0000oooooooooooooooo0_l0001dooooo`;o0000C?ooool2o`00
04gooooo0_l0000aooooo`007_ooool01?l0003oooooooooooooool2o`00017ooooo0_l0000joooo
o`;o00009Oooool2o`0009_ooooo0_l0000aooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o
0000>_ooool2o`0004?ooooo0_l0001^ooooo`;o00006oooool2o`0000Wooooo0_l0000Hooooo`00
7_ooool00ol0003oooooooooo`17ooooo`;o0000C?ooool2o`0004oooooo0_l0000Mooooo`;o0000
6oooool2o`0000Wooooo0_l0000Hooooo`007_ooool00ol0003oooooooooo`17ooooo`;o0000>ooo
ool2o`0002cooooo0_l0000Cooooo`;o00007Oooool2o`0005oooooo000Nooooo`03o`000?oooooo
oooo02Cooooo0_l0000hooooo`;o00009?ooool2o`0000kooooo0_l0000Looooo`;o00004oooool2
o`0007kooooo000Nooooo`;o00005oooool2o`0000cooooo0_l0000hooooo`;o00002oooool2o`00
02Oooooo0_l00005ooooo`;o00001_ooool2o`000:;ooooo000Nooooo`03o`000?oooooooooo00So
oooo0_l00009ooooo`;o000000?oooooo`000?l000003_ooool2o`0004?ooooo0_l0000^ooooo`;o
00001_ooool2o`0002gooooo0_l0000Gooooo`;o0000F_ooool001kooooo00?o0000ooooooooool0
2?ooool2o`0000Wooooo0_l0000Aooooo`;o00002Oooool2o`0009oooooo0_l0000Gooooo`;o0000
:Oooool2o`0000kooooo0_l0000Oooooo`007_ooool00ol0003oooooooooo`0aooooo`;o0000hooo
ool2o`0000kooooo0_l0000Oooooo`007_ooool00ol0003oooooooooo`3oooooobOooooo0_l0000O
ooooo`007_ooool00ol0003oooooooooo`0Uooooo`;o0000ooooool2o`0001oooooo000Nooooo`03
o`000?oooooooooo02Gooooo0_l0000_ooooo`;o0000Hoooool2o`00023ooooo0_l0000nooooo`;o
0000:?ooool001kooooo00?o0000ooooooooool03?ooool2o`0001kooooo0_l0000Xooooo`;o0000
<?ooool2o`0002gooooo0_l00002ooooo`;o00002?ooool2o`0001Kooooo0_l0000nooooo`;o0000
:?ooool001gooooo0_l0000>ooooo`;o00007_ooool2o`0005[ooooo0_l0000]ooooo`;o00003?oo
ool2o`00083ooooo000Mooooo`;o0000@oooool2o`0006Gooooo0_l0000Booooo`Co0000Qoooool0
01kooooo00?o0000ooooooooool0@Oooool2o`0006Gooooo0_l0000Booooo`Co0000Qoooool001ko
oooo00?o0000ooooooooool00_l0000oooooo`;o00006Oooool2o`0000Gooooo0_l0000_ooooo`;o
0000W_ooool2o`00017ooooo000Nooooo`03o`000?oooooooooo00;o0000B_ooool2o`0000Sooooo
0_l00004ooooo`;o00001Oooool2o`0002oooooo0_l0000@ooooo`;o0000S?ooool2o`00017ooooo
000Nooooo`03o`000?oooooooooo00Oooooo0_l00013ooooo`;o00002?ooool2o`0004kooooo0_l0
001Dooooo`;o0000BOooool001Cooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooo
oooo00Oooooo0_l0003cooooo`;o00009?ooool2o`0002?ooooo000Fooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool03_ooool2o`0008Oooooo0_l00029ooooo`;o00008oooool001Ko
oooo00?o0000ooooooooool01Oooool3o`0000kooooo0_l00019ooooo`;o0000??ooool2o`0001ko
oooo0_l0001Gooooo`;o0000=Oooool001Kooooo00?o0000ooooooooool0HOooool2o`0005cooooo
0_l0001Gooooo`;o0000=Oooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool0
0ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Co
oooo00?oEEEEofIVI_l00000oooooomBooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.63406 .30852 Mdot
.44275 .46608 Mdot
.90821 .50555 Mdot
.31569 .55808 Mdot
.52845 .04107 Mdot
.66009 .67634 Mdot
.68661 .53843 Mdot
.98167 .89313 Mdot
.2306 .35323 Mdot
.02619 .90211 Mdot
.35159 .44602 Mdot
.11313 .05495 Mdot
.11991 .53028 Mdot
.27782 .98901 Mdot
.81431 .63988 Mdot
.54775 .03061 Mdot
.87946 .0037 Mdot
.28175 .94591 Mdot
.62327 .07209 Mdot
.89114 .47262 Mdot
.97769 .11362 Mdot
.25922 .16743 Mdot
.22518 .25545 Mdot
.74716 .71508 Mdot
.50711 .11613 Mdot
.05993 .13734 Mdot
.08745 .88926 Mdot
.10695 .50753 Mdot
.80357 .48169 Mdot
.21156 .95734 Mdot
.59528 .83719 Mdot
.9173 .90447 Mdot
.02224 .30256 Mdot
.05847 .32009 Mdot
.39396 .6405 Mdot
.72511 .20549 Mdot
.47351 .94327 Mdot
.24721 .66491 Mdot
.78097 .63359 Mdot
.73709 .56084 Mdot
.57384 .53765 Mdot
.92063 .01623 Mdot
.58019 .12969 Mdot
.59931 .49286 Mdot
.15324 .40375 Mdot
.95055 .78746 Mdot
.16674 .35755 Mdot
.63443 .15356 Mdot
.30036 .82998 Mdot
.97452 .89482 Mdot
.1087 .7925 Mdot
.82289 .94061 Mdot
.94351 .8511 Mdot
.32683 .33307 Mdot
.96508 .13494 Mdot
.32235 .23757 Mdot
.42498 .12929 Mdot
.77207 .05218 Mdot
.65726 .17183 Mdot
.54571 .49182 Mdot
.76043 .75003 Mdot
.17106 .99758 Mdot
.24086 .34895 Mdot
.91565 .66069 Mdot
.71188 .09642 Mdot
.99999 .74315 Mdot
.3214 .54496 Mdot
.27666 .88974 Mdot
.49803 .82664 Mdot
.10523 .43816 Mdot
.44261 .24311 Mdot
.16155 .54705 Mdot
.06441 .91881 Mdot
.58027 .96562 Mdot
.43386 .97999 Mdot
.26889 .8957 Mdot
.12928 .46763 Mdot
.66713 .74989 Mdot
.2246 .33544 Mdot
.78266 .24668 Mdot
.12519 .08761 Mdot
.28835 .22907 Mdot
.28311 .25511 Mdot
.7224 .26612 Mdot
.61176 .93022 Mdot
.73112 .72539 Mdot
.76743 .3633 Mdot
.05479 .4216 Mdot
.22147 .29607 Mdot
.80226 .2567 Mdot
.60942 .36074 Mdot
.60482 .60948 Mdot
.893 .89033 Mdot
.74862 .78131 Mdot
.21757 .0322 Mdot
.62163 .91458 Mdot
.00879 .69789 Mdot
.48574 .58641 Mdot
.64296 .94061 Mdot
.00808 .75276 Mdot
.81537 .22701 Mdot
.62063 .08566 Mdot
.79638 .26685 Mdot
.59936 .07452 Mdot
.31585 .80841 Mdot
.26697 .6991 Mdot
.70469 .18964 Mdot
.06284 .39062 Mdot
.28956 .88669 Mdot
.17038 .19981 Mdot
.04623 .35777 Mdot
.56174 .83829 Mdot
.82882 .72035 Mdot
.53895 .3514 Mdot
.4346 .04217 Mdot
.52966 .87629 Mdot
.52344 .63004 Mdot
.65989 .57821 Mdot
.21872 .86122 Mdot
.00287 .80758 Mdot
.54164 .35803 Mdot
.43386 .18252 Mdot
.89218 .3907 Mdot
.28551 .74386 Mdot
.6585 .26306 Mdot
.34311 .79932 Mdot
.64786 .83475 Mdot
.22218 .51574 Mdot
.722 .61069 Mdot
.14764 .3367 Mdot
.88291 .16659 Mdot
.55734 .13875 Mdot
.77842 .20991 Mdot
.70639 .55423 Mdot
.47511 .21417 Mdot
.84502 .20491 Mdot
.20861 .53236 Mdot
.08475 .00698 Mdot
.97103 .28376 Mdot
.27689 .88935 Mdot
.84571 .27118 Mdot
.72335 .15319 Mdot
.55316 .53399 Mdot
.58204 .42031 Mdot
.17705 .73652 Mdot
.45983 .47238 Mdot
.29803 .92604 Mdot
.02055 .68392 Mdot
.69813 .80881 Mdot
.52493 .26299 Mdot
.13127 .0969 Mdot
.65366 .782 Mdot
.69599 .22451 Mdot
.52916 .20433 Mdot
.73198 .28005 Mdot
.34389 .19191 Mdot
.9467 .15473 Mdot
.49793 .11069 Mdot
.04186 .64307 Mdot
.87239 .01522 Mdot
.93167 .43447 Mdot
.92445 .16685 Mdot
.20478 .95174 Mdot
.70267 .98138 Mdot
.93014 .11819 Mdot
.76106 .19002 Mdot
.79068 .24386 Mdot
.81889 .59877 Mdot
.24683 .68277 Mdot
.7476 .88928 Mdot
.79757 .42489 Mdot
.26749 .28132 Mdot
.47017 .59905 Mdot
.92352 .70926 Mdot
.85066 .24029 Mdot
.80806 .13196 Mdot
.32932 .51662 Mdot
.63662 .55355 Mdot
.12562 .87755 Mdot
.41731 .55101 Mdot
.28201 .59377 Mdot
.05739 .05083 Mdot
.88785 .74908 Mdot
.19465 .36176 Mdot
.01509 .5521 Mdot
.6883 .06922 Mdot
.75266 .92558 Mdot
.45403 .52925 Mdot
.82957 .80602 Mdot
.40225 .40277 Mdot
.29628 .51595 Mdot
.58952 .4428 Mdot
.61447 .32841 Mdot
.10082 .79967 Mdot
.13331 .18925 Mdot
.30802 .01933 Mdot
.54414 .03475 Mdot
.03517 .35681 Mdot
.38151 .71289 Mdot
.99255 .41712 Mdot
.93905 .30809 Mdot
.19492 .43443 Mdot
.24073 .2076 Mdot
.00712 .38951 Mdot
.0265 .46905 Mdot
.50761 .99668 Mdot
.48248 .6745 Mdot
.61215 .56269 Mdot
.36663 .24441 Mdot
.16236 .60148 Mdot
.5883 .12154 Mdot
.5648 .59367 Mdot
.05003 .20616 Mdot
.77307 .54805 Mdot
.41566 .42273 Mdot
.35618 .5612 Mdot
.79647 .55036 Mdot
.24084 .98279 Mdot
.89237 .28472 Mdot
.26294 .01251 Mdot
.96116 .62395 Mdot
.69542 .00271 Mdot
.95134 .10271 Mdot
.53983 .82489 Mdot
.31458 .29373 Mdot
.36828 .87787 Mdot
.29922 .46605 Mdot
.4049 .72102 Mdot
.90103 .30148 Mdot
.74597 .33133 Mdot
.5839 .42998 Mdot
.88141 .72971 Mdot
.03081 .21268 Mdot
.78802 .3185 Mdot
.67794 .51334 Mdot
.66559 .89689 Mdot
.97098 .63246 Mdot
.88876 .62722 Mdot
.07498 .77546 Mdot
.89176 .28845 Mdot
.7811 .0494 Mdot
.75731 .55601 Mdot
.7895 .03562 Mdot
.27225 .22133 Mdot
.16215 .39709 Mdot
.0762 .3063 Mdot
.07021 .28269 Mdot
.82944 .8172 Mdot
.52294 .06029 Mdot
.35895 .79738 Mdot
.83842 .68632 Mdot
.85496 .08745 Mdot
.65646 .21998 Mdot
.51564 .95136 Mdot
.27305 .61261 Mdot
.64887 .31831 Mdot
.52597 .61838 Mdot
.16022 .59438 Mdot
.02498 .93577 Mdot
.91621 .20393 Mdot
.93211 .28025 Mdot
.99429 .98775 Mdot
.50033 .19812 Mdot
.73158 .50615 Mdot
.43513 .37465 Mdot
.63692 .95665 Mdot
.55947 .34912 Mdot
.57886 .03815 Mdot
.44667 .14642 Mdot
.80963 .83885 Mdot
.79746 .80313 Mdot
.48257 .23305 Mdot
.4613 .92364 Mdot
.88348 .6335 Mdot
.38015 .13652 Mdot
.75635 .7556 Mdot
.53574 .16891 Mdot
.52824 .38032 Mdot
.38236 .39334 Mdot
.35467 .95356 Mdot
.55337 .67447 Mdot
.14436 .52254 Mdot
.15715 .4478 Mdot
.06978 .68427 Mdot
.30683 .12405 Mdot
.59102 .4413 Mdot
.33758 .3893 Mdot
.42225 .28307 Mdot
.4164 .64253 Mdot
.49175 .30016 Mdot
.61015 .63166 Mdot
.54672 .94843 Mdot
.65688 .58254 Mdot
.97289 .03098 Mdot
.89674 .51637 Mdot
.31665 .73426 Mdot
.17466 .00114 Mdot
.34376 .70982 Mdot
.44918 .19106 Mdot
.32354 .01026 Mdot
.45273 .14457 Mdot
.43409 .11118 Mdot
.44426 .90677 Mdot
.29821 .55956 Mdot
.367 .72982 Mdot
.90526 .13336 Mdot
.8671 .59785 Mdot
.98264 .98792 Mdot
.08962 .20744 Mdot
.24977 .6974 Mdot
.24033 .43335 Mdot
.51757 .2888 Mdot
.18785 .881 Mdot
.67218 .78881 Mdot
.37881 .38631 Mdot
.78183 .62043 Mdot
.40485 .24632 Mdot
.29508 .87486 Mdot
.11995 .04725 Mdot
.70479 .47219 Mdot
.43731 .43081 Mdot
.06768 .189 Mdot
.60243 .38881 Mdot
.95005 .50205 Mdot
.79996 .10907 Mdot
.86969 .11853 Mdot
.02285 .13092 Mdot
.6681 .08819 Mdot
.03001 .4702 Mdot
.96413 .61273 Mdot
.50651 .83929 Mdot
.66703 .74417 Mdot
.47475 .00474 Mdot
.2047 .94806 Mdot
.47644 .20604 Mdot
.6628 .06371 Mdot
.05764 .70233 Mdot
.19328 .35622 Mdot
.64268 .98573 Mdot
.13534 .86794 Mdot
.01017 .0882 Mdot
.74618 .66058 Mdot
.10872 .65223 Mdot
.50838 .33793 Mdot
.01274 .05718 Mdot
.89314 .97127 Mdot
.15119 .43685 Mdot
.65021 .31792 Mdot
.48681 .33512 Mdot
.04257 .37103 Mdot
.44517 .77848 Mdot
.31139 .10811 Mdot
.8331 .09873 Mdot
.15802 .04083 Mdot
.13086 .01541 Mdot
.05659 .10804 Mdot
.69902 .37426 Mdot
.76542 .53286 Mdot
.14692 .34742 Mdot
.54517 .81464 Mdot
.06016 .59835 Mdot
.08134 .85047 Mdot
.22702 .24302 Mdot
.16472 .32522 Mdot
.78539 .54516 Mdot
.59829 .89393 Mdot
.03826 .13364 Mdot
.93896 .36354 Mdot
.94492 .34156 Mdot
.58141 .22555 Mdot
.40696 .39355 Mdot
.45443 .80973 Mdot
.74051 .37578 Mdot
.96185 .38444 Mdot
.12842 .55082 Mdot
.21826 .63686 Mdot
.91592 .39982 Mdot
.21396 .16051 Mdot
.26506 .67482 Mdot
.67349 .37667 Mdot
.9005 .9307 Mdot
.69069 .74177 Mdot
.0996 .9401 Mdot
.63767 .31957 Mdot
.75925 .9545 Mdot
.26183 .35424 Mdot
.24455 .98809 Mdot
.64237 .13719 Mdot
.73529 .9912 Mdot
.84999 .57654 Mdot
.05351 .71462 Mdot
.78474 .59268 Mdot
.73267 .37291 Mdot
.49138 .43683 Mdot
.03184 .03887 Mdot
.45779 .70774 Mdot
.87868 .50152 Mdot
.58715 .74745 Mdot
.22673 .11276 Mdot
.54957 .02484 Mdot
.91057 .52128 Mdot
.0724 .05925 Mdot
.26494 .20901 Mdot
.90812 .04578 Mdot
.12634 .23019 Mdot
.01322 .01778 Mdot
.50996 .78672 Mdot
.97092 .91588 Mdot
.22507 .67859 Mdot
.78136 .55797 Mdot
.59797 .16555 Mdot
.83366 .94957 Mdot
.28489 .23491 Mdot
.15576 .3083 Mdot
.42753 .61897 Mdot
.66362 .84764 Mdot
.6913 .79912 Mdot
.22882 .23911 Mdot
.61033 .6097 Mdot
.69226 .91839 Mdot
.96301 .32251 Mdot
.30315 .75485 Mdot
.78595 .55466 Mdot
.0485 .41661 Mdot
.08042 .92549 Mdot
.47911 .5267 Mdot
.29067 .89964 Mdot
.22329 .09315 Mdot
.98565 .49681 Mdot
.38086 .26874 Mdot
.79011 .49846 Mdot
.10069 .93203 Mdot
.41917 .5834 Mdot
.2217 .58427 Mdot
.03387 .62299 Mdot
.75441 .77184 Mdot
.5379 .09536 Mdot
.8729 .84884 Mdot
.66811 .79562 Mdot
.06829 .15814 Mdot
.06976 .70262 Mdot
.08744 .30074 Mdot
.68331 .58755 Mdot
.57466 .96767 Mdot
.86006 .40004 Mdot
.76914 .79669 Mdot
.22829 .38778 Mdot
.39644 .62102 Mdot
.29688 .88345 Mdot
.10478 .36732 Mdot
.01612 .68835 Mdot
.43135 .81746 Mdot
.36568 .397 Mdot
.93393 .90903 Mdot
.08913 .39914 Mdot
.96332 .52779 Mdot
.81721 .37961 Mdot
.80318 .13706 Mdot
.19079 .40171 Mdot
.79741 .92571 Mdot
.29204 .13284 Mdot
.08804 .95645 Mdot
.85155 .03975 Mdot
.06258 .74375 Mdot
.90455 .04487 Mdot
.71815 .4361 Mdot
.2283 .23465 Mdot
.36168 .48785 Mdot
.00425 .44975 Mdot
.14564 .75223 Mdot
.41223 .4357 Mdot
.93232 .42278 Mdot
.51648 .72653 Mdot
.23568 .8686 Mdot
.24741 .2945 Mdot
.59078 .74159 Mdot
.74144 .65288 Mdot
.46125 .9101 Mdot
.92249 .00196 Mdot
.51789 .02347 Mdot
.50765 .14732 Mdot
.94641 .67 Mdot
.51362 .12356 Mdot
.61461 .65462 Mdot
.57796 .79393 Mdot
.78967 .18237 Mdot
.73773 .09077 Mdot
.62168 .0416 Mdot
.39173 .83724 Mdot
.75854 .71708 Mdot
.8767 .42766 Mdot
.82493 .1037 Mdot
.95696 .89277 Mdot
.27713 .03237 Mdot
.87862 .16631 Mdot
.27503 .76722 Mdot
.88321 .77603 Mdot
.09368 .99731 Mdot
.7541 .26715 Mdot
.88588 .55497 Mdot
.7671 .84341 Mdot
.54015 .44224 Mdot
.29425 .79731 Mdot
.30931 .73857 Mdot
.74446 .5329 Mdot
.42327 .12701 Mdot
.46935 .76607 Mdot
.54852 .94791 Mdot
.97505 .38921 Mdot
.05509 .3463 Mdot
.63605 .51651 Mdot
.75026 .20235 Mdot
.46741 .27638 Mdot
.62833 .35492 Mdot
.57272 .87445 Mdot
.92404 .1997 Mdot
.22797 .95514 Mdot
.10535 .49175 Mdot
.36636 .76729 Mdot
.96491 .14271 Mdot
.98176 .96658 Mdot
.33096 .38121 Mdot
.76917 .85424 Mdot
.16546 .58886 Mdot
.88578 .99395 Mdot
.9513 .65847 Mdot
.73396 .49929 Mdot
.62972 .84229 Mdot
.8943 .14557 Mdot
.12135 .941 Mdot
.9419 .80034 Mdot
.5575 .205 Mdot
.54839 .42305 Mdot
.62451 .40088 Mdot
.20482 .96064 Mdot
.03638 .40759 Mdot
.70476 .38376 Mdot
.49079 .34981 Mdot
.56386 .48591 Mdot
.47424 .93161 Mdot
.05785 .91938 Mdot
.92864 .59273 Mdot
.54104 .52011 Mdot
.80756 .78848 Mdot
.58424 .71978 Mdot
.76559 .79642 Mdot
.97066 .16097 Mdot
.14125 .79207 Mdot
.69726 .18854 Mdot
.25187 .02531 Mdot
.71839 .30109 Mdot
.17244 .68984 Mdot
.25164 .98953 Mdot
.82432 .70452 Mdot
.11228 .86455 Mdot
.4436 .51269 Mdot
.11737 .74108 Mdot
.26681 .12228 Mdot
.72536 .99116 Mdot
.52163 .72868 Mdot
.45445 .21225 Mdot
.87474 .29762 Mdot
.33216 .30608 Mdot
.09311 .20567 Mdot
.49038 .72207 Mdot
.84694 .1025 Mdot
.96716 .28135 Mdot
.00203 .20057 Mdot
.25562 .12839 Mdot
.34196 .49055 Mdot
.11057 .73699 Mdot
.22066 .16309 Mdot
.27988 .92811 Mdot
.93212 .26176 Mdot
.54284 .20092 Mdot
.26708 .6398 Mdot
.47031 .88465 Mdot
.99172 .13691 Mdot
.89272 .01991 Mdot
.59867 .52406 Mdot
.21805 .48731 Mdot
.67472 .62372 Mdot
.49655 .34523 Mdot
.01936 .8623 Mdot
.80313 .83993 Mdot
.50103 .01274 Mdot
.87648 .20918 Mdot
.63516 .96542 Mdot
.00281 .73057 Mdot
.21523 .2403 Mdot
.52915 .32222 Mdot
.21233 .30431 Mdot
.89648 .24868 Mdot
.96835 .28032 Mdot
.80422 .47113 Mdot
.53182 .83267 Mdot
.58971 .23709 Mdot
.45652 .22468 Mdot
.3233 .43172 Mdot
.21811 .84322 Mdot
.71085 .27865 Mdot
.60137 .20474 Mdot
.77854 .57829 Mdot
.78581 .50337 Mdot
.48526 .73164 Mdot
.4326 .80087 Mdot
.05379 .64847 Mdot
.49332 .37534 Mdot
.03978 .00378 Mdot
.442 .56476 Mdot
.35118 .96752 Mdot
.81875 .29889 Mdot
.03153 .26136 Mdot
.81025 .48637 Mdot
.84464 .30208 Mdot
.42181 .59881 Mdot
.7843 .15881 Mdot
.59524 .3811 Mdot
.11938 .92976 Mdot
.51488 .41646 Mdot
.48038 .32449 Mdot
.65765 .25769 Mdot
.73355 .76542 Mdot
.25583 .54326 Mdot
.09325 .08916 Mdot
.03459 .44211 Mdot
.85122 .39075 Mdot
.01664 .25011 Mdot
.66519 .80067 Mdot
.02026 .44701 Mdot
.9331 .28405 Mdot
.89737 .42241 Mdot
.85744 .57321 Mdot
.82986 .57694 Mdot
.72623 .20011 Mdot
.1912 .63966 Mdot
.22064 .51771 Mdot
.55045 .59733 Mdot
.7626 .73963 Mdot
.93522 .76822 Mdot
.7004 .51752 Mdot
.51881 .88833 Mdot
.16238 .83793 Mdot
.99857 .86425 Mdot
.72005 .67071 Mdot
.58192 .68214 Mdot
.5911 .06057 Mdot
.99587 .63734 Mdot
.96405 .94541 Mdot
.85175 .43813 Mdot
.60227 .60069 Mdot
.51015 .27625 Mdot
.49319 .4768 Mdot
.39018 .99647 Mdot
.72408 .24016 Mdot
.98146 .51277 Mdot
.4229 .98027 Mdot
.98934 .43505 Mdot
.41734 .51581 Mdot
.4217 .22228 Mdot
.0293 .97229 Mdot
.95248 .1786 Mdot
.8411 .76844 Mdot
.05272 .49133 Mdot
.94402 .68409 Mdot
.05154 .91622 Mdot
.82091 .84588 Mdot
.66829 .96876 Mdot
.82084 .46328 Mdot
.07229 .95562 Mdot
.0005 .34424 Mdot
.27282 .127 Mdot
.55734 .9821 Mdot
.70975 .54962 Mdot
.11544 .62078 Mdot
.26506 .44809 Mdot
.57799 .35222 Mdot
.61674 .95664 Mdot
.34606 .10399 Mdot
.54702 .5557 Mdot
.93019 .24088 Mdot
.86956 .04749 Mdot
.33006 .30073 Mdot
.21358 .31335 Mdot
.37386 .72009 Mdot
.896 .36313 Mdot
.67465 .69721 Mdot
.24626 .50896 Mdot
.68265 .75685 Mdot
.02305 .95951 Mdot
.76069 .22885 Mdot
.08052 .80106 Mdot
.42775 .56993 Mdot
.61623 .17963 Mdot
.6957 .86364 Mdot
.99262 .26136 Mdot
.73053 .5557 Mdot
.6889 .31008 Mdot
.65307 .26192 Mdot
.03217 .40315 Mdot
.35941 .11293 Mdot
.43143 .03706 Mdot
.01744 .28356 Mdot
.92841 .82618 Mdot
.18148 .30612 Mdot
.7386 .05057 Mdot
.09148 .03311 Mdot
.13291 .18769 Mdot
.75807 .0766 Mdot
.04277 .46733 Mdot
.70118 .2164 Mdot
.60238 .48903 Mdot
.74434 .70824 Mdot
.5956 .85493 Mdot
.15092 .81398 Mdot
.05658 .63367 Mdot
.55799 .93043 Mdot
.90737 .97019 Mdot
.87483 .4911 Mdot
.1916 .19937 Mdot
.70919 .82316 Mdot
.54763 .32225 Mdot
.6018 .00857 Mdot
.53328 .43105 Mdot
.45213 .90382 Mdot
.53157 .18311 Mdot
.88861 .48693 Mdot
.8736 .97488 Mdot
.92745 .16795 Mdot
.54809 .60536 Mdot
.46983 .10043 Mdot
.78653 .80639 Mdot
.13949 .88508 Mdot
.82886 .90298 Mdot
.94967 .26188 Mdot
.73027 .86154 Mdot
.11647 .77392 Mdot
.77983 .25726 Mdot
.81464 .8752 Mdot
.50786 .70008 Mdot
.47939 .30033 Mdot
.5462 .69461 Mdot
.42265 .60659 Mdot
.15511 .47333 Mdot
.8743 .33779 Mdot
.90171 .99532 Mdot
.31355 .46299 Mdot
.60605 .72978 Mdot
.78118 .09922 Mdot
.41581 .05436 Mdot
.38339 .80122 Mdot
.30831 .95221 Mdot
.51666 .10952 Mdot
.374 .66129 Mdot
.48545 .09234 Mdot
.8122 .77855 Mdot
.2005 .34386 Mdot
.29529 .37318 Mdot
.28529 .2874 Mdot
.09975 .06717 Mdot
.09426 .59416 Mdot
.29177 .60043 Mdot
.11687 .38239 Mdot
.38844 .25351 Mdot
.01266 .69644 Mdot
.61087 .99556 Mdot
.13106 .19324 Mdot
.40181 .63156 Mdot
.32487 .26627 Mdot
.51342 .84111 Mdot
.63548 .57704 Mdot
.79932 .17639 Mdot
.95149 .35988 Mdot
.90433 .15572 Mdot
.44037 .59637 Mdot
.12391 .31914 Mdot
.81673 .29743 Mdot
.91004 .92938 Mdot
.09407 .71525 Mdot
.11712 .8905 Mdot
.35906 .85861 Mdot
.00405 .65043 Mdot
.11102 .8985 Mdot
.63995 .87375 Mdot
.76824 .10001 Mdot
.12845 .2927 Mdot
.9221 .12684 Mdot
.61096 .3873 Mdot
.6984 .21743 Mdot
.28857 .88498 Mdot
.99589 .92583 Mdot
.57635 .59434 Mdot
.25684 .67583 Mdot
.14862 .54648 Mdot
.52832 .19644 Mdot
.92435 .09865 Mdot
.36448 .69169 Mdot
.20924 .36531 Mdot
.83626 .14788 Mdot
.1999 .38127 Mdot
.73714 .32386 Mdot
.31318 .90293 Mdot
.32169 .78728 Mdot
.33665 .90618 Mdot
.67165 .71921 Mdot
.58724 .77207 Mdot
.74355 .10533 Mdot
.06152 .08178 Mdot
.97535 .83018 Mdot
.45012 .29866 Mdot
.55269 .28005 Mdot
.85847 .32146 Mdot
.20729 .36821 Mdot
.93018 .83157 Mdot
.48755 .15157 Mdot
.21668 .52114 Mdot
.20014 .85753 Mdot
.02433 .16067 Mdot
.07338 .32554 Mdot
.37887 .47851 Mdot
.68341 .90193 Mdot
.52371 .77463 Mdot
.56202 .02649 Mdot
.27475 .03996 Mdot
.91413 .0697 Mdot
.90079 .81161 Mdot
.84142 .49496 Mdot
.11106 .68518 Mdot
.2198 .25028 Mdot
.6745 .11815 Mdot
.55 .5031 Mdot
.70833 .04699 Mdot
.458 .19709 Mdot
.7819 .6897 Mdot
.31674 .58316 Mdot
.91515 .23588 Mdot
.99474 .92761 Mdot
.60388 .0425 Mdot
.55943 .81477 Mdot
.8922 .76551 Mdot
.92432 .16056 Mdot
.80728 .2176 Mdot
.79549 .0657 Mdot
.51127 .58082 Mdot
.91857 .44657 Mdot
.33445 .31423 Mdot
.01485 .46005 Mdot
.81008 .65854 Mdot
.4283 .94944 Mdot
.62957 .2084 Mdot
.28263 .71691 Mdot
.13592 .86301 Mdot
.74328 .14058 Mdot
.902 .23154 Mdot
.35903 .47679 Mdot
.8068 .22859 Mdot
.04069 .42989 Mdot
.88645 .32622 Mdot
.6147 .57757 Mdot
.66715 .09633 Mdot
.60764 .02812 Mdot
.44522 .47365 Mdot
.93168 .70937 Mdot
.72228 .01937 Mdot
.59276 .1607 Mdot
.39698 .20089 Mdot
.63302 .25996 Mdot
.97677 .56788 Mdot
.19842 .2457 Mdot
.49821 .62065 Mdot
.17337 .26514 Mdot
.43402 .94029 Mdot
.96122 .83598 Mdot
.37267 .06492 Mdot
.64091 .51252 Mdot
.26641 .62244 Mdot
.46969 .96374 Mdot
.4701 .83363 Mdot
.23557 .28274 Mdot
.89315 .87219 Mdot
.6308 .45536 Mdot
.97584 .64087 Mdot
.0584 .59547 Mdot
.95135 .11447 Mdot
.48845 .34663 Mdot
.96906 .66981 Mdot
.44671 .23751 Mdot
.3241 .62914 Mdot
.57598 .66717 Mdot
.24806 .20621 Mdot
.75045 .99166 Mdot
.954 .93979 Mdot
.71547 .11684 Mdot
.38302 .68304 Mdot
.0537 .94299 Mdot
.01233 .9755 Mdot
.16954 .17472 Mdot
.46632 .91254 Mdot
.11599 .52589 Mdot
.7288 .88275 Mdot
.94647 .2514 Mdot
.8824 .09581 Mdot
.79604 .67932 Mdot
.51431 .74001 Mdot
.48452 .15439 Mdot
.54457 .65415 Mdot
.8277 .63273 Mdot
.09361 .08233 Mdot
.24434 .86757 Mdot
.05335 .75405 Mdot
.736 .7391 Mdot
.92567 .27272 Mdot
.1974 .07609 Mdot
.44733 .60797 Mdot
.99268 .82057 Mdot
.53135 .27389 Mdot
.91898 .24217 Mdot
.40095 .22746 Mdot
.50319 .21571 Mdot
.888 .54426 Mdot
.65683 .77228 Mdot
.23271 .39593 Mdot
.50206 .41859 Mdot
.72467 .70676 Mdot
.70161 .9483 Mdot
.86481 .49879 Mdot
.08996 .73765 Mdot
.7363 .64167 Mdot
.59229 .8786 Mdot
.92611 .0139 Mdot
.66966 .25305 Mdot
.45091 .87047 Mdot
.43688 .08019 Mdot
.81532 .86734 Mdot
.53242 .04888 Mdot
.52222 .75644 Mdot
.21781 .51104 Mdot
.24185 .64888 Mdot
.71085 .37281 Mdot
.91164 .62459 Mdot
.53043 .91117 Mdot
.57381 .19292 Mdot
.45207 .2374 Mdot
.52573 .7427 Mdot
.61053 .55974 Mdot
.30655 .46295 Mdot
.67864 .11163 Mdot
.19994 .30253 Mdot
.84577 .0107 Mdot
.5593 .06189 Mdot
.732 .03461 Mdot
.02272 .03337 Mdot
.62314 .52419 Mdot
.87251 .41765 Mdot
.7681 .88082 Mdot
.92484 .08524 Mdot
.74434 .70796 Mdot
.02733 .20069 Mdot
.66455 .17456 Mdot
.43847 .30968 Mdot
.39488 .57855 Mdot
.47955 .84879 Mdot
.25223 .96505 Mdot
.82906 .21808 Mdot
.02013 .0369 Mdot
.36253 .2135 Mdot
.67113 .55524 Mdot
.03142 .51692 Mdot
.32435 .45568 Mdot
.40238 .91518 Mdot
.25965 .68069 Mdot
.56733 .00936 Mdot
.4631 .69837 Mdot
.67354 .76434 Mdot
.62512 .13633 Mdot
.23777 .12243 Mdot
.17145 .50807 Mdot
.26815 .32161 Mdot
.10776 .54195 Mdot
.84587 .37618 Mdot
.19023 .6759 Mdot
.84933 .88978 Mdot
.32213 .39754 Mdot
.89274 .28342 Mdot
.45243 .29395 Mdot
.63471 .1241 Mdot
.24498 .56459 Mdot
.97112 .59987 Mdot
.6556 .46045 Mdot
.09684 .68618 Mdot
.14424 .52327 Mdot
.85463 .8955 Mdot
.56504 .4347 Mdot
.59121 .41212 Mdot
.65193 .64366 Mdot
.28716 .54496 Mdot
.6021 .92828 Mdot
.05102 .03745 Mdot
.76694 .75587 Mdot
.48187 .0316 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00Wo
oooo0_l00002ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`05ooooo`;o00001oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`?o00003oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01_ooool2o`0000Go
oooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`02ooooo`007_ooool00ol0003oooooooooo`09ooooo`;o00000_ooool00ol0003ooooo
ooooo`07ooooo`;o00001?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo
0_l00007ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00_ooooo0ol0000?ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`06ooooo`;o00001Oooool00ol0003ooooo
ooooo`04ooooo`;o00001oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo
000Nooooo`03o`000?oooooooooo01Oooooo0_l0001<ooooo`;o0000;oooool2o`0001cooooo0_l0
000:ooooo`;o0000QOooool001kooooo00?o0000ooooooooool0DOooool2o`0001;ooooo0_l0000h
ooooo`;o00004oooool2o`0000[ooooo0_l0001=ooooo`;o0000=_ooool001kooooo00?o0000oooo
ooooool09_ooool2o`0002Wooooo0_l0001<ooooo`;o0000K_ooool2o`0000Oooooo0_l0000=oooo
o`Co00007?ooool001kooooo00?o0000ooooooooool00_l0000Tooooo`;o0000>?ooool2o`0008Go
oooo0_l0000_ooooo`;o00003Oooool4o`0001cooooo000Nooooo`03o`000?oooooooooo00;o0000
G_ooool2o`0008Gooooo0_l0000eooooo`;o00009oooool001kooooo00?o0000ooooooooool0C_oo
ool2o`0005Cooooo0_l00009ooooo`;o0000KOooool2o`0002Oooooo000Nooooo`03o`000?oooooo
oooo04kooooo0_l0001Dooooo`;o00002Oooool2o`0000;ooooo0_l0000<ooooo`;o0000Q?ooool0
01kooooo00?o0000ooooooooool0VOooool2o`0001?ooooo0_l00003ooooo`;o00003?ooool2o`00
07Gooooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`03ooooo`;o00005Oooool2o`0002Oo
oooo0_l0000Aooooo`;o0000@Oooool2o`0001;ooooo0ol0000jooooo`;o0000C?ooool2o`0000go
oooo000Nooooo`03o`000?oooooooooo00;ooooo0ol00007ooooo`;o00003?ooool2o`0002Oooooo
0_l0000Aooooo`;o0000<?ooool2o`0002?ooooo0_l00009ooooo`;o0000<?ooool2o`00017ooooo
0_l00018ooooo`007_ooool00ol0003oooooooooo`02ooooo`;o00000_ooool2o`0000Cooooo0_l0
000Qooooo`;o00009?ooool2o`00037ooooo0_l0000Nooooo`;o00003_ooool2o`0004?ooooo0_l0
000Booooo`;o0000=?ooool001kooooo00?o0000ooooooooool01_ooool2o`0002Oooooo0_l0000T
ooooo`;o0000<_ooool2o`0001gooooo0_l0000Fooooo`;o00001?ooool2o`0004Wooooo0_l0000d
ooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o0000I?ooool2o`0003Gooooo0_l00004oooo
o`;o00006_ooool2o`0003?ooooo0_l00009ooooo`?o00008_ooool001kooooo00?o0000oooooooo
ool08oooool2o`0008Cooooo0_l0000gooooo`;o00002?ooool2o`0000cooooo0_l0000Kooooo`;o
00002Oooool3o`0002;ooooo000Nooooo`;o00004?ooool2o`0009Sooooo0_l00011ooooo`;o0000
2Oooool2o`000003ooooool0003o000004_ooooo000Nooooo`03o`000?oooooooooo00oooooo0_l0
000@ooooo`;o0000H?ooool2o`0007;ooooo0_l0001>ooooo`007_ooool00ol0003oooooooooo`02
o`00017ooooo0_l0000<ooooo`;o0000H?ooool2o`000<;ooooo000Nooooo`03o`000?oooooooooo
00;o00004Oooool2o`00097ooooo0_l0000:ooooo`;o00002?ooool2o`0008Wooooo000Nooooo`03
o`000?oooooooooo07Gooooo0_l0000_ooooo`;o00002_ooool2o`0000Sooooo0_l0000Eooooo`;o
0000:_ooool2o`0004Kooooo000Nooooo`03o`000?oooooooooo01cooooo0_l0001Gooooo`;o0000
G?ooool2o`0002[ooooo0_l00016ooooo`007_ooool00ol0003oooooooooo`0Looooo`;o0000ZOoo
ool2o`0001?ooooo0_l00017ooooo`;o00008?ooool001kooooo00?o0000ooooooooool0_oooool2
o`0000Kooooo0_l0000Cooooo`;o0000Aoooool2o`00023ooooo000Nooooo`03o`000?oooooooooo
03cooooo0_l00021ooooo`;o0000<Oooool2o`0005?ooooo000Nooooo`03o`000?oooooooooo03co
oooo0_l0001<ooooo`;o0000I_ooool2o`0005?ooooo000Nooooo`03o`000?oooooooooo013ooooo
0_l00008ooooo`;o0000K_ooool2o`000;_ooooo000Nooooo`03o`000?oooooooooo013ooooo0_l0
0008ooooo`;o0000Z_ooool2o`0004[ooooo0_l0000Eooooo`;o00007?ooool001kooooo00Co0000
ooooool0003o00006Oooool2o`0000Wooooo0_l0002Oooooo`;o00003Oooool2o`0003_ooooo0_l0
000Eooooo`;o00007?ooool001kooooo00Co0000ooooool0003o00006Oooool2o`0000Wooooo0_l0
000Mooooo`;o0000E?ooool2o`0003Wooooo0_l0000Eooooo`;o0000FOooool001kooooo00?o0000
ooooooooool0A?ooool2o`0005Cooooo0_l0000?ooooo`;o0000:?ooool2o`0000cooooo0_l00007
ooooo`;o0000;Oooool2o`0002[ooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l00022oooo
o`;o0000:?ooool2o`0000cooooo0_l0000Eooooo`;o00003oooool2o`0000kooooo0_l0000;oooo
o`;o00007Oooool001kooooo0_l0000Xooooo`;o0000K?ooool2o`0005oooooo0_l00002ooooo`;o
00003oooool2o`0000;ooooo0_l0000Gooooo`;o00001oooool2o`0001Cooooo000Nooooo`03o`00
0?oooooooooo06cooooo0_l0000Wooooo`;o0000Eoooool2o`0000Kooooo0_l0000@ooooo`;o0000
1Oooool2o`00023ooooo0_l0000Dooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o0000DOoo
ool2o`0000Wooooo0_l00020ooooo`;o00004?ooool2o`0000Kooooo0_l0000mooooo`007_ooool0
0ol0003oooooooooo`0>ooooo`;o0000DOooool2o`0002Kooooo0_l0000Cooooo`;o00001?ooool2
o`0003?ooooo0_l0000Uooooo`;o0000AOooool001kooooo00?o0000ooooooooool0A_ooool2o`00
02Wooooo0_l0000Fooooo`;o00004oooool2o`0000Cooooo0_l0000cooooo`;o0000E_ooool2o`00
00Oooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`16ooooo`;o0000:Oooool2o`0002ko
oooo0_l0000dooooo`;o00002oooool2o`0004Cooooo0_l00005ooooo`;o00001oooool2o`0000_o
oooo000Nooooo`03o`000?oooooooooo0:7ooooo0_l0000dooooo`;o00002oooool2o`00037ooooo
0_l0000Aooooo`;o00006oooool001kooooo00?o0000ooooooooool0BOooool2o`0000Sooooo0_l0
000;ooooo`;o0000@Oooool2o`0001Kooooo0_l0000=ooooo`;o0000Boooool2o`0002kooooo000N
ooooo`03o`000?oooooooooo04Wooooo0_l00008ooooo`Co00002Oooool2o`0002?ooooo0_l0000L
ooooo`;o00005_ooool2o`0000gooooo0_l0001Looooo`;o00007Oooool001kooooo00?o0000oooo
ooooool0Coooool2o`0000Cooooo0_l0000^ooooo`?o0000<Oooool2o`0006gooooo0_l0000Moooo
o`007_ooool00ol0003oooooooooo`03ooooo`;o00000oooool2o`0004Gooooo0_l0000:ooooo`;o
0000:Oooool2o`00037ooooo0_l00018ooooo`;o00007Oooool2o`0002?ooooo000Nooooo`03o`00
0?oooooooooo00?ooooo0_l00003ooooo`;o0000DOooool2o`0001[ooooo0_l0001>ooooo`;o0000
>_ooool2o`0001gooooo0_l0000Booooo`;o00003oooool001kooooo00?o0000ooooooooool03ooo
ool2o`0006Kooooo0_l0000hooooo`;o00005?ooool2o`0000Cooooo0_l0000booooo`;o0000<ooo
ool2o`0000Kooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o0000X?ooool2
o`0001[ooooo0_l0000Oooooo`;o00004Oooool2o`0003?ooooo0_l00006ooooo`;o00001oooool0
01kooooo00?o0000ooooooooool0Soooool2o`0005gooooo0_l0000_ooooo`;o00005Oooool2o`00
00oooooo000Nooooo`03o`000?oooooooooo08gooooo1?l0000@ooooo`;o0000JOooool2o`00017o
oooo0_l0000Vooooo`007_ooool2o`0008kooooo0_l0000;ooooo`;o00001Oooool2o`0006Wooooo
0_l0000iooooo`007_ooool00ol0003oooooooooo`2Iooooo`?o0000;_ooool2o`0001_ooooo0_l0
0017ooooo`;o00005Oooool001kooooo00?o0000ooooooooool04_ooool2o`0008Gooooo0_l0000_
ooooo`;o00006oooool2o`0003Wooooo0_l0000<ooooo`;o00005Oooool001kooooo00?o0000oooo
ooooool01?ooool2o`0000cooooo0_l0000]ooooo`;o0000N_ooool2o`0003cooooo0_l0000Uoooo
o`;o00001?ooool2o`0000gooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`04ooooo`;o
0000>oooool2o`000003ooooool0003o000007Oooooo0_l0000looooo`;o0000:oooool2o`0000go
oooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`14ooooo`;o00002_ooool2o`0006cooooo
0_l0001Jooooo`?o00002oooool2o`0001gooooo000Nooooo`03o`000?oooooooooo053ooooo0_l0
001Hooooo`;o00004_ooool2o`0005[ooooo0ol0000;ooooo`?o00007?ooool001kooooo00?o0000
ooooooooool0Z_ooool2o`0002Kooooo0_l0001Eooooo`;o00007?ooool001kooooo00?o0000oooo
ooooool0<oooool2o`0009gooooo1?l0000Zooooo`;o0000AOooool001kooooo00?o0000oooooooo
ool0<oooool2o`0008oooooo0_l0000>ooooo`;o0000:_ooool2o`00033ooooo0_l0000Cooooo`00
7_ooool00ol0003oooooooooo`29ooooo`;o0000>Oooool2o`0003Oooooo0_l0000cooooo`;o0000
4oooool001kooooo00?o0000ooooooooool0ROooool2o`0001kooooo0_l0001Booooo`;o0000B?oo
ool001kooooo00?o0000ooooooooool04_ooool2o`0001?ooooo0_l00020ooooo`;o0000=?ooool2
o`0006Kooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0000Cooooo`;o0000@oooool2o`00
023ooooo0_l0001?ooooo`Co00004?ooool2o`0005;ooooo0003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo02Kooooo0ol00013oooo
o`;o00008?ooool2o`0002Kooooo0_l0000Yooooo`;o00004?ooool2o`0005;ooooo0003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006
ooooo`03o`000?oooooooooo02Kooooo0_l0001Yooooo`;o00003?ooool2o`0000Oooooo0_l0000<
ooooo`;o0000Soooool000?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7o
k^k^00Oooooo0ol00005ooooo`;o0000;?ooool2o`0000Gooooo0_l00011ooooo`;o00004_ooool2
o`0000cooooo0_l00007ooooo`;o00000_ooool2o`0003[ooooo0_l0000nooooo`;o00007Oooool0
00?ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0_l00006
ooooo`;o0000;?ooool2o`0000Gooooo0_l00011ooooo`;o0000:Oooool2o`0000;ooooo0_l0000j
ooooo`;o00001_ooool2o`0003Cooooo1?l0000Mooooo`000oooool01Ol0003ooooooooooooooooo
000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`0<ooooo`;o00002oooool3
o`00037ooooo0_l00018ooooo`;o00003oooool2o`0000Oooooo0_l0000<ooooo`;o00009oooool2
o`0000Kooooo0_l0000Mooooo`;o00005Oooool2o`0001oooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo0_l0000;
ooooo`?o0000;_ooool2o`000003ooooool0003o000000?ooooo0_l00013ooooo`;o00006?ooool2
o`0000cooooo0_l00008ooooo`;o00007Oooool2o`0000oooooo0_l0000Dooooo`;o00002?ooool2
o`0002cooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonH
V9So410@00Kooooo00?o0000ooooooooool01_ooool2o`0004;ooooo0_l00006ooooo`;o00007_oo
ool2o`0001cooooo0_l0000gooooo`;o0000;_ooool2o`0001kooooo0_l0000/ooooo`000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`00
0?oooooooooo00Kooooo0_l0001Zooooo`;o00007?ooool2o`0000Cooooo0_l00007ooooo`;o0000
?oooool2o`0006Gooooo000Nooooo`03o`000?oooooooooo09Kooooo0_l00007ooooo`;o0000?_oo
ool3o`00023ooooo0_l00005ooooo`;o0000??ooool001kooooo00?o0000ooooooooool0E?ooool2
o`0002oooooo0_l0001:ooooo`;o00003?ooool2o`00027ooooo0_l00005ooooo`;o0000??ooool0
01kooooo00?o0000ooooooooool0E?ooool2o`0002oooooo0_l00009ooooo`;o00009oooool2o`00
01Kooooo0_l0000;ooooo`;o0000Ioooool001kooooo00?o0000ooooooooool0O_ooool2o`00013o
oooo0_l0000Wooooo`;o00008oooool2o`0001?ooooo0_l0000=ooooo`;o000000?oooooo`000?l0
0000@?ooool001kooooo00?o0000ooooooooool09Oooool2o`0003?ooooo0_l0000Rooooo`;o0000
Loooool2o`0000gooooo0_l000000ooooooo0000o`00000Jooooo`;o00009?ooool001kooooo00?o
0000ooooooooool09Oooool2o`0001oooooo0_l0000Aooooo`?o0000?Oooool2o`0008Kooooo0_l0
000Tooooo`007_ooool00ol0003oooooooooo`16ooooo`;o00004Oooool2o`0000[ooooo0_l0000V
ooooo`Co00002?ooool2o`00027ooooo0_l0001Wooooo`;o00008?ooool001kooooo00?o0000oooo
ooooool0@_ooool2o`0000;ooooo0_l0000Mooooo`;o00009_ooool4o`0002_ooooo0_l0000Yoooo
o`;o00009oooool2o`0001?ooooo0_l00003ooooo`;o00006oooool001kooooo00?o0000oooooooo
ool0@_ooool2o`0000;ooooo0_l0000[ooooo`;o00005oooool2o`0005Wooooo0_l0000Dooooo`;o
00004Oooool2o`0001Gooooo0_l000000ooooooo0000o`00000Kooooo`007_ooool00ol0003ooooo
ooooo`0looooo`;o00002?ooool2o`0002_ooooo0_l0000;ooooo`;o00002_ooool2o`0006cooooo
0_l000000ooooooo0000o`00000Xooooo`;o00007_ooool001kooooo00Co0000oooooooooooooooo
0_l0000iooooo`;o00001Oooool2o`0003_ooooo0_l0001hooooo`;o00008oooool2o`0002Kooooo
000Nooooo`;o00000_ooool2o`00043ooooo0_l0000eooooo`;o0000F_ooool2o`0004Oooooo0_l0
000?ooooo`;o00005Oooool001kooooo00?o0000ooooooooool0AOooool2o`00017ooooo0_l0000P
ooooo`;o0000F_ooool2o`0002Wooooo0_l0000]ooooo`;o00005Oooool001kooooo00?o0000oooo
ooooool0AOooool2o`00017ooooo0_l0001hooooo`;o00009Oooool2o`0000Kooooo0_l00014oooo
o`007_ooool00ol0003oooooooooo`06ooooo`;o0000`_ooool2o`0000Cooooo1?l0000Uooooo`;o
0000<?ooool2o`0000Cooooo0_l0000<ooooo`;o00001_ooool001kooooo00?o0000ooooooooool0
1_ooool2o`0002cooooo0_l0001aooooo`;o00008Oooool2o`0000Cooooo1?l0001Gooooo`;o0000
1?ooool2o`0000cooooo0_l00006ooooo`007_ooool00ol0003oooooooooo`0dooooo`;o0000<?oo
ool2o`00013ooooo0_l0000]ooooo`;o0000:Oooool2o`0001?ooooo0_l00008ooooo`;o00003?oo
ool2o`0004Kooooo000Nooooo`03o`000?oooooooooo06Kooooo0_l0000@ooooo`;o0000KOooool2
o`0000Sooooo0_l0000<ooooo`;o00003_ooool2o`0003Kooooo000Nooooo`03o`000?oooooooooo
0:Wooooo0_l0001Tooooo`;o00006?ooool2o`0001cooooo000Nooooo`03o`000?oooooooooo09Co
oooo0_l0000<ooooo`;o00001Oooool2o`0007kooooo0_l0000Looooo`007_ooool00ol0003ooooo
ooooo`1Cooooo`;o0000?oooool2o`0000cooooo0_l0000<ooooo`;o0000<Oooool2o`0000Gooooo
0_l0000oooooo`;o00002_ooool2o`0000kooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0
000?ooooo`;o0000<oooool2o`0000Wooooo0_l0000`ooooo`;o0000:Oooool2o`00037ooooo0_l0
0005ooooo`;o0000<_ooool2o`0000_ooooo0_l00009ooooo`Co00003Oooool001kooooo00?o0000
ooooooooool00_ooool2o`0000oooooo0_l0000cooooo`;o00003oooool2o`0002[ooooo0_l0002G
ooooo`;o00002oooool2o`0000Wooooo1?l0000=ooooo`007_ooool00ol0003oooooooooo`1Ioooo
o`;o0000BOooool2o`0007Sooooo0_l0000Wooooo`007_ooool00ol0003oooooooooo`0Vooooo`;o
0000O?ooool2o`0007Sooooo0_l0000Wooooo`007_ooool00ol0003oooooooooo`0Vooooo`;o0000
7?ooool2o`0000Kooooo0_l0000Dooooo`;o0000:oooool2o`000;Kooooo000Nooooo`03o`000?oo
oooooooo04Cooooo0_l00006ooooo`;o00005?ooool2o`0002[ooooo0ol0001dooooo`?o00004?oo
ool2o`0002gooooo000Nooooo`;o00001?ooool2o`0001?ooooo0_l0000Sooooo`;o0000:?ooool2
o`0002Gooooo0_l00008ooooo`;o00000_ooool2o`0004Oooooo0_l0000Nooooo`?o00001_ooool2
o`0000Sooooo0_l00007ooooo`;o00009?ooool001kooooo00?o0000ooooooooool00oooool2o`00
01?ooooo0_l0000Sooooo`;o00000_ooool2o`0002Cooooo0_l0000_ooooo`;o00000_ooool2o`00
04Oooooo0_l0000Wooooo`;o00004Oooool2o`0002Cooooo000Nooooo`03o`000?oooooooooo01Go
oooo0_l0000Hooooo`;o00001_ooool2o`0000Sooooo0_l0000Uooooo`;o0000H?ooool2o`00067o
oooo0_l0000Hooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o00006?ooool2o`0000Kooooo
0_l0000_ooooo`;o00008?ooool2o`0003kooooo0_l0000@ooooo`;o0000Coooool2o`0001Sooooo
000Nooooo`03o`000?oooooooooo047ooooo0_l0000Vooooo`;o00007oooool2o`00053ooooo0_l0
001Yooooo`007_ooool00ol0003oooooooooo`11ooooo`;o00009_ooool2o`0006Cooooo0_l0001f
ooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o00004oooool2o`000:Gooooo0_l00002oooo
o`;o0000:oooool2o`0004Wooooo000Nooooo`03o`000?oooooooooo00oooooo0_l0000Cooooo`;o
0000;Oooool2o`0005?ooooo0_l00004ooooo`;o00006oooool2o`0000;ooooo0_l0000Kooooo`;o
00003_ooool2o`0001Gooooo0_l0000Pooooo`;o00004?ooool001kooooo00?o0000ooooooooool0
5?ooool2o`0001_ooooo0_l0000Pooooo`;o0000@oooool2o`0000kooooo0_l00004ooooo`;o0000
??ooool2o`0002Gooooo0_l00007ooooo`;o00005oooool2o`00013ooooo000Nooooo`03o`000?oo
oooooooo01Cooooo0_l0000Kooooo`;o0000IOooool2o`0002[ooooo0_l0001Fooooo`;o0000:Ooo
ool001kooooo00?o0000ooooooooool0I_ooool2o`0005cooooo0_l0000Xooooo`;o0000Eoooool0
01kooooo00?o0000ooooooooool0AOooool2o`0001oooooo0_l0000booooo`;o0000D_ooool2o`00
05Oooooo000Nooooo`03o`000?oooooooooo02cooooo0_l0000Gooooo`;o0000Doooool2o`0000Go
oooo0_l0001eooooo`;o0000;Oooool001kooooo00?o0000ooooooooool0;?ooool2o`0007?ooooo
0_l0001eooooo`;o00005Oooool2o`0001Kooooo000Mooooo`;o0000?oooool2o`0005kooooo0_l0
002@ooooo`;o00005_ooool001gooooo0_l0000@ooooo`;o00007?ooool2o`0000oooooo0_l0000;
ooooo`;o0000Coooool4o`000:Sooooo000Nooooo`;o00003oooool2o`0001cooooo0_l0000Loooo
o`;o0000Coooool2o`0000kooooo0_l00005ooooo`;o0000Toooool001kooooo00?o0000oooooooo
ool0Aoooool2o`0000Sooooo0_l00018ooooo`;o00003_ooool2o`0000Gooooo0_l00004ooooo`;o
00003_ooool2o`0007gooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l00002ooooo`;o0000
9Oooool2o`0000Oooooo0_l0000:ooooo`;o00002?ooool2o`0005Wooooo0_l0000:ooooo`;o0000
3_ooool2o`0007gooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l00002ooooo`;o00009Ooo
ool2o`0000Oooooo0_l0001_ooooo`;o00005?ooool2o`0006gooooo0_l0000Dooooo`007_ooool0
0ol0003oooooooooo`0kooooo`;o0000QOooool2o`00037ooooo0_l0000Xooooo`;o00003?ooool2
o`0000;ooooo0_l0000Dooooo`007_ooool00ol0003oooooooooo`0Nooooo`;o00006oooool2o`00
00?ooooo0_l0002cooooo`;o0000:?ooool2o`0000cooooo0_l0000Hooooo`007_ooool00ol0003o
ooooooooo`0Nooooo`;o00007oooool3o`000?oooooo1_ooool001kooooo00?o0000ooooooooool0
2_ooool2o`0003?ooooo0_l0000Kooooo`;o0000QOooool2o`0000Gooooo0_l0001Kooooo`007_oo
ool00ol0003oooooooooo`0:ooooo`;o0000D?ooool2o`0002_ooooo0_l0000Aooooo`;o0000>Ooo
ool2o`0000Kooooo0_l00002ooooo`;o00001Oooool2o`000003ooooool0003o0000023ooooo0_l0
000fooooo`007_ooool00ol0003oooooooooo`29ooooo`;o00004Oooool2o`0003Wooooo0_l00006
ooooo`;o00003?ooool2o`0001Oooooo0_l00007ooooo`;o0000=_ooool001kooooo00?o0000oooo
ooooool08_ooool2o`0001Wooooo0_l0000Xooooo`;o0000?oooool2o`0001?ooooo0_l00017oooo
o`;o0000?oooool001kooooo00?o0000ooooooooool08_ooool2o`0001Wooooo0_l0000Xooooo`;o
0000?oooool2o`0001?ooooo0_l0000Rooooo`;o0000D_ooool2o`00013ooooo000Nooooo`03o`00
0?oooooooooo04Kooooo0_l0000_ooooo`;o0000Aoooool2o`000003ooooool0003o000001cooooo
0_l0001Booooo`;o00004?ooool001kooooo0ol0000@ooooo`;o0000=?ooool2o`0002;ooooo0_l0
000;ooooo`;o0000Aoooool2o`000003ooooool0003o000004cooooo0_l0000;ooooo`;o00006Ooo
ool2o`0000cooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l0
00000ol@413oooooooooo`04ooooo`?o00004?ooool2o`0005Sooooo0_l0000<ooooo`;o00001_oo
ool2o`0008oooooo0_l0000;ooooo`;o00006Oooool2o`0000cooooo0003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0aooooo`;o00005Oooool2o`0001_ooooo0_l0000<ooooo`;o00000oooool2o`0000Kooooo0_l0
0035ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`?o00006Ooo
ool2o`0001Kooooo0_l0000Eooooo`;o00006oooool2o`0000cooooo0_l0001Booooo`;o0000Booo
ool2o`00013ooooo0_l0000Oooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00001oooool00ol0003oooooooooo`06ooooo`;o00004Oooool2o`0001?ooooo
0_l0000:ooooo`;o0000@oooool2o`0004Kooooo0_l0001;ooooo`;o00004?ooool2o`0001oooooo
0003ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03
o`000?oooooooooo00Kooooo0_l0000Vooooo`;o00002_ooool2o`0004?ooooo0_l00036ooooo`00
0oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003o
ooooooooo`08ooooo`;o0000oooooolnooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00co
oooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`08ooooo`;o0000/_ooool2o`0008Wo
oooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03
o`000?oooooooooo00cooooo0_l0002Eooooo`;o00005oooool2o`0008Wooooo000Nooooo`03o`00
0?oooooooooo00cooooo0_l0002Aooooo`;o00000_ooool2o`0007?ooooo0_l0000Uooooo`;o0000
1_ooool001kooooo00?o0000ooooooooool03_ooool2o`0007?ooooo0_l0000Jooooo`;o00006?oo
ool2o`0005gooooo0_l00006ooooo`;o00002Oooool2o`0001;ooooo0_l00006ooooo`007_ooool0
0ol0003oooooooooo`0>ooooo`;o0000Loooool2o`0002Wooooo0_l00009ooooo`;o0000A?ooool2
o`0001oooooo0_l00009ooooo`;o00006_ooool001kooooo00?o0000ooooooooool0[_ooool2o`00
04oooooo0_l0000Hooooo`;o0000;?ooool001kooooo00?o0000ooooooooool02Oooool2o`0005[o
oooo0_l0000Sooooo`;o00007Oooool2o`0000oooooo0_l0001Mooooo`;o0000;?ooool001kooooo
00?o0000ooooooooool02Oooool2o`00033ooooo0_l0000=ooooo`;o00006Oooool2o`0002?ooooo
0_l0000Mooooo`;o00002Oooool2o`0000Cooooo0_l0001_ooooo`;o00004Oooool2o`0000Oooooo
000Nooooo`03o`000?oooooooooo01kooooo0_l0000=ooooo`;o00003?ooool2o`0000gooooo0_l0
000fooooo`;o00006?ooool2o`0001Kooooo0_l0000_ooooo`;o0000:_ooool2o`0001Sooooo0_l0
000Aooooo`;o00001oooool001kooooo00?o0000ooooooooool07_ooool2o`0000gooooo0_l0001C
ooooo`;o00006?ooool2o`0004Oooooo0_l0000Zooooo`;o0000=?ooool001kooooo00?o0000oooo
ooooool01oooool2o`000:;ooooo0_l0000?ooooo`;o0000ROooool001kooooo00?o0000oooooooo
ool00_ooool2o`0000?ooooo0_l0001Uooooo`;o0000>oooool2o`0000oooooo0_l0001Yooooo`;o
00007_ooool001kooooo0_l00003ooooo`;o0000:oooool2o`00027ooooo0_l0000Jooooo`;o0000
]oooool2o`0001kooooo000Nooooo`;o0000<?ooool2o`00027ooooo0_l0003cooooo`007_ooool0
0ol0003oooooooooo`1Uooooo`;o0000H_ooool2o`0007cooooo000Nooooo`03o`000?oooooooooo
06Gooooo0_l0001Rooooo`;o0000O?ooool001kooooo00Co0000oooooooooooooooo0_l0003>oooo
o`;o0000M?ooool001kooooo00Co0000oooooooooooooooo0_l0001Mooooo`Co0000KOooool2o`00
03Cooooo0_l0000nooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o00006_ooool2o`0003Go
oooo0_l000000ooooooo0000o`000002o`0002Sooooo0_l0001iooooo`;o0000?_ooool001kooooo
00?o0000ooooooooool01?ooool4o`0000;ooooo0_l0000Jooooo`;o0000=Oooool2o`0002gooooo
0_l0001cooooo`;o0000A?ooool001kooooo00?o0000ooooooooool01?ooool4o`0002Kooooo0_l0
001Mooooo`;o00000_ooool2o`0004kooooo0_l0000Nooooo`;o00006oooool2o`0002Oooooo000N
ooooo`03o`000?oooooooooo02kooooo0_l00011ooooo`;o00006_ooool2o`0000;ooooo0_l00009
ooooo`;o0000@oooool2o`0003_ooooo0_l0000Wooooo`007_ooool00ol0003oooooooooo`1aoooo
o`;o00001?ooool2o`0002?ooooo0_l0002Yooooo`007_ooool00ol0003oooooooooo`1gooooo`;o
0000R?ooool2o`0004Cooooo000Nooooo`03o`000?oooooooooo04?ooooo0_l0001^ooooo`;o0000
C?ooool4o`0001Sooooo0_l0000Xooooo`007_ooool00ol0003oooooooooo`13ooooo`;o0000;?oo
ool2o`00043ooooo0_l0000;ooooo`;o0000@Oooool2o`0001Sooooo0_l0000Xooooo`007_ooool0
0ol0003oooooooooo`0=ooooo`;o00003oooool2o`0004_ooooo0_l00004ooooo`;o0000>_ooool2
o`00013ooooo0ol0001Fooooo`;o0000;Oooool001kooooo00?o0000ooooooooool03Oooool2o`00
00oooooo0_l0001;ooooo`;o0000@?ooool2o`00013ooooo0_l0001<ooooo`;o00002Oooool2o`00
02gooooo000Nooooo`03o`000?oooooooooo0>_ooooo0_l0000@ooooo`;o00003_ooool2o`0000Ko
oooo0_l0000Uooooo`;o00002Oooool001kooooo0_l0003/ooooo`;o00004?ooool2o`0001Kooooo
0_l00003ooooo`;o00005Oooool2o`0000Wooooo0_l00009ooooo`007_ooool00ol0003ooooooooo
o`2_ooooo`;o0000B_ooool2o`0001gooooo0_l00007ooooo`;o00003?ooool2o`0001Cooooo000N
ooooo`03o`000?oooooooooo01oooooo0_l0000Cooooo`;o0000NOooool2o`0003Wooooo0_l0000?
ooooo`;o00009_ooool2o`0002;ooooo000Nooooo`03o`000?oooooooooo01oooooo0_l0000Coooo
o`;o00003Oooool2o`0000Oooooo0_l0002Looooo`;o0000Foooool001kooooo00?o0000oooooooo
ool0@oooool2o`0000Oooooo0_l0000nooooo`;o0000?_ooool2o`0000[ooooo0_l0001Qooooo`;o
00002_ooool001kooooo00?o0000ooooooooool01_ooool2o`0003cooooo0_l0000Fooooo`;o0000
2Oooool2o`0001_ooooo0_l00006ooooo`;o0000?Oooool3o`0000[ooooo0_l00006ooooo`;o0000
?Oooool2o`0001[ooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`06ooooo`;o0000>_oo
ool4o`0001Kooooo0_l00009ooooo`;o00006oooool2o`0002Kooooo0_l0000Mooooo`;o00004ooo
ool2o`0003gooooo0_l0000Vooooo`007_ooool00ol0003oooooooooo`0[ooooo`;o00005Oooool2
o`0006Sooooo0_l0000Aooooo`;o00001Oooool2o`0005cooooo0_l0000Qooooo`007_ooool00ol0
003oooooooooo`0Rooooo`;o00001oooool2o`0006_ooooo0_l0000Uooooo`;o00001Oooool2o`00
05cooooo0_l0000Qooooo`007_ooool00ol0003oooooooooo`0Rooooo`?o0000J_ooool2o`0000Oo
oooo0_l0002Kooooo`;o00004?ooool001kooooo00?o0000ooooooooool08oooool2o`0001_ooooo
0_l0001=ooooo`;o0000GOooool2o`0000Gooooo0_l0000nooooo`;o00004?ooool001kooooo00?o
0000ooooooooool0@?ooool2o`0006kooooo0_l0000looooo`;o00001Oooool2o`00053ooooo000N
ooooo`03o`000?oooooooooo0;3ooooo0_l00004ooooo`;o00008oooool2o`0006[ooooo000Noooo
o`03o`000?oooooooooo01oooooo0_l0002Eooooo`;o00008oooool2o`0006[ooooo000Nooooo`03
o`000?oooooooooo01oooooo0_l0000^ooooo`;o00002?ooool2o`0000Wooooo0_l0002Eooooo`;o
00008?ooool2o`0002Sooooo000Nooooo`03o`000?oooooooooo02cooooo0_l00002ooooo`;o0000
7Oooool2o`0000Sooooo0_l00009ooooo`;o0000TOooool2o`0000;ooooo0_l0000Pooooo`;o0000
:?ooool001kooooo0_l0000Wooooo`;o00001?ooool2o`0000;ooooo0_l0001Booooo`;o0000GOoo
ool2o`0001;ooooo0_l00006ooooo`;o0000A_ooool001kooooo00Co0000oooooooooooooooo0_l0
000Sooooo`;o0000G?ooool2o`0004Gooooo0_l0000Eooooo`?o00005_ooool2o`0000;ooooo0_l0
000Kooooo`;o0000:Oooool001kooooo00Co0000oooooooooooooooo0_l0001Pooooo`;o0000BOoo
ool2o`0001_ooooo0_l00009ooooo`;o00002_ooool2o`0000Gooooo0_l00007ooooo`;o00001_oo
ool3o`0001oooooo0_l0000Yooooo`007_ooool00ol0003oooooooooo`1Mooooo`;o00001?ooool2
o`0000_ooooo0_l0000looooo`;o00004_ooool2o`0001;ooooo0_l0000Aooooo`;o000000?ooooo
o`000?l000001?ooool2o`0000Kooooo0_l0001;ooooo`007_ooool00ol0003oooooooooo`1Moooo
o`;o00004Oooool2o`00053ooooo0ol0000Wooooo`;o0000FOooool001kooooo00?o0000oooooooo
ool0C?ooool2o`0003kooooo0_l0000eooooo`;o0000P_ooool001kooooo00?o0000ooooooooool0
C?ooool2o`0003Wooooo0_l00003ooooo`;o0000Zoooool2o`0000cooooo000Nooooo`03o`000?oo
oooooooo08Oooooo0_l0002:ooooo`;o00009?ooool2o`0000cooooo000Nooooo`03o`000?oooooo
oooo0?oooooo4Oooool2o`000003ooooool0003o000003;ooooo000Nooooo`03o`000?oooooooooo
07cooooo0_l00016ooooo`;o00001?ooool2o`0000Kooooo0_l0000Uooooo`;o00003oooool2o`00
00Cooooo0_l0000eooooo`007_ooool00ol0003oooooooooo`1looooo`;o00009?ooool2o`00023o
oooo0_l00004ooooo`;o00001Oooool3o`0002Gooooo0_l0000?ooooo`;o0000>oooool001kooooo
00?o0000ooooooooool0A?ooool2o`0001gooooo0_l0000Oooooo`;o00007?ooool2o`0002gooooo
0_l0001dooooo`007_ooool00ol0003oooooooooo`0booooo`;o00004?ooool2o`0001gooooo0_l0
000Oooooo`;o00005?ooool2o`0003kooooo0_l0001[ooooo`007_ooool00ol0003oooooooooo`0b
ooooo`;o0000I_ooool2o`0003kooooo0_l0001[ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003ooooooooo
o`0Kooooo`;o00004oooool2o`0002Kooooo0_l0001Jooooo`;o000000?oooooo`000?l00000@_oo
ool2o`0002gooooo0_l0000Kooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0?ooooo`;o0000
2_ooool2o`0001?ooooo0_l0000Vooooo`;o0000<Oooool2o`0002;ooooo0_l00003ooooo`;o0000
00?oooooo`000?l00000@_ooool2o`0001Wooooo0_l0000Booooo`;o00006oooool000?ooooo00Go
410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`0000oo
oooo0_l0001:ooooo`;o0000:?ooool2o`0000Cooooo0_l00008ooooo`;o00006?ooool2o`0000oo
oooo0_l00014ooooo`;o00003_ooool2o`00023ooooo0_l0000=ooooo`000oooool01Ol0003ooooo
oooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo
00oooooo0_l0000Pooooo`;o0000:?ooool2o`0002Sooooo0_l0000>ooooo`;o0000:Oooool2o`00
04Cooooo0_l0000`ooooo`;o00003Oooool000?ooooo00Go0000ooooooooooooooooo`00000;oooo
o`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0aooooo`;o0000D_ooool2
o`0002Oooooo0_l0002Gooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEE
ohN7Qoooool02?ooool00ol0003oooooooooo`25ooooo`;o00001_ooool2o`0001oooooo0_l0000A
ooooo`?o0000Poooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413o
V9RH00Sooooo00?o0000ooooooooool0EOooool2o`0003Kooooo0_l0000booooo`?o00008oooool2
o`0004cooooo0_l0000@ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<
odA4A?l0003o410@1_ooool00ol0003oooooooooo`1Eooooo`;o0000T?ooool2o`0004cooooo0_l0
000@ooooo`007_ooool00ol0003oooooooooo`27ooooo`;o00007_ooool2o`0009kooooo000Noooo
o`03o`000?oooooooooo027ooooo0_l0000_ooooo`;o0000:Oooool2o`0000Sooooo0_l0000Eoooo
o`;o00001oooool2o`00057ooooo0_l0001;ooooo`007_ooool00ol0003oooooooooo`07ooooo`;o
00006?ooool2o`0002oooooo0_l0000Yooooo`;o00007oooool2o`0003Oooooo0_l0000Qooooo`;o
0000:?ooool2o`0000kooooo0_l0000Aooooo`007_ooool00ol0003oooooooooo`07ooooo`;o0000
c_ooool2o`0004Cooooo0_l00005ooooo`;o00003_ooool2o`00017ooooo000Nooooo`03o`000?oo
oooooooo06Gooooo0_l0000Hooooo`;o00009Oooool2o`0001[ooooo0_l0001Iooooo`;o0000:?oo
ool001kooooo00?o0000ooooooooool03_ooool2o`0005Gooooo0_l0000Hooooo`;o00009Oooool2
o`0001[ooooo0_l0000fooooo`;o00003Oooool2o`00013ooooo0_l0000Kooooo`;o00003Oooool0
01kooooo00?o0000ooooooooool03_ooool2o`0003?ooooo0_l0002eooooo`;o00003Oooool2o`00
013ooooo0_l0000Kooooo`;o00001_ooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo03[o
oooo0_l00007ooooo`;o00003_ooool2o`0002Oooooo0_l00027ooooo`;o0000<_ooool2o`0000Go
oooo0_l00005ooooo`007_ooool00ol0003oooooooooo`09ooooo`;o0000;oooool2o`0001Oooooo
0_l0000Wooooo`;o00001Oooool2o`0004_ooooo0_l0000Iooooo`;o00006?ooool2o`0003;ooooo
0_l0000<ooooo`007_ooool00ol0003oooooooooo`09ooooo`;o0000N?ooool2o`0004_ooooo0_l0
000Iooooo`;o0000F_ooool001kooooo00?o0000ooooooooool03Oooool2o`0003cooooo0_l0003j
ooooo`007_ooool2o`0000kooooo0_l0000@ooooo`;o0000:_ooool2o`000:3ooooo0_l0001Hoooo
o`007_ooool2o`00023ooooo0_l0002<ooooo`;o00005Oooool2o`0002Oooooo0_l0001Hooooo`00
7_ooool00ol0003oooooooooo`2]ooooo`;o00005Oooool2o`0003gooooo0_l0000/ooooo`;o0000
5?ooool001kooooo00?o0000ooooooooool0MOooool2o`0007Oooooo0_l0000Cooooo`;o00008Ooo
ool2o`0000Wooooo0_l0000Dooooo`007_ooool00ol0003oooooooooo`1<ooooo`;o00009oooool2
o`0007Oooooo0_l0000fooooo`;o00007oooool001kooooo00?o0000ooooooooool0C?ooool2o`00
06Wooooo0_l0002>ooooo`007_ooool00ol0003oooooooooo`2gooooo`;o0000;Oooool2o`0004So
oooo0_l00005ooooo`;o00003_ooool001kooooo00?o0000ooooooooool0D_ooool2o`0004Gooooo
0_l0000Eooooo`;o0000=?ooool2o`0004Sooooo0_l00005ooooo`;o00003_ooool001kooooo00?o
0000ooooooooool0>_ooool2o`0001?ooooo0_l000000ooooooo0000o`000015ooooo`;o00005Ooo
ool2o`00023ooooo0_l0001cooooo`007_ooool00ol0003oooooooooo`0jooooo`;o00002Oooool2
o`0000Sooooo0ol00020ooooo`;o0000:oooool2o`0004Kooooo000Nooooo`03o`000?oooooooooo
00?ooooo0_l00010ooooo`;o00001Oooool2o`0000;ooooo0_l0000Vooooo`;o0000?oooool2o`00
04Cooooo0_l0000^ooooo`;o00005_ooool001kooooo00?o0000ooooooooool00oooool2o`0000ko
oooo0_l00006ooooo`;o00000oooool2o`0002[ooooo0_l0000Zooooo`;o0000?oooool2o`00057o
oooo0_l0000Qooooo`;o00005_ooool001kooooo00Co0000oooooooooooooooo0_l0000@ooooo`;o
00001_ooool2o`0000?ooooo0_l0000Booooo`;o0000a?ooool2o`00013ooooo0_l0000iooooo`00
7_ooool01?l0003oooooooooooooool2o`00037ooooo0_l0000looooo`;o0000Q_ooool2o`0004_o
oooo000Nooooo`03o`000?oooooooooo00;o0000L?ooool2o`0003Wooooo0_l0002Hooooo`007_oo
ool00ol0003oooooo`000002o`0004_ooooo0_l00004ooooo`;o0000?Oooool2o`0001Wooooo0_l0
000Xooooo`;o0000K_ooool001kooooo1?l0000>ooooo`;o00000_ooool2o`0003Sooooo0_l00004
ooooo`;o0000?Oooool2o`0000gooooo0_l0000dooooo`;o0000K_ooool001kooooo00?o0000oooo
ooooool03oooool2o`0000;ooooo0_l0002<ooooo`;o0000IOooool2o`0003gooooo000Nooooo`03
o`000?oooooooooo097ooooo0_l0001Dooooo`;o00001Oooool2o`0001Sooooo0_l0000mooooo`00
7_ooool00ol0003oooooooooo`1/ooooo`;o00008oooool2o`0005Cooooo0_l00005ooooo`;o0000
>?ooool2o`000003ooooool0003o000001[ooooo000Nooooo`03o`000?oooooooooo00gooooo0_l0
001Mooooo`;o00002_ooool2o`000:kooooo0_l000000ooooooo0000o`00000Jooooo`007_ooool0
0ol0003oooooooooo`0=ooooo`;o00002oooool2o`0003cooooo0_l0000Nooooo`;o0000MOooool2
o`000003ooooool0003o000005?ooooo000Nooooo`03o`000?oooooooooo01[ooooo0_l0000loooo
o`;o00006oooool2o`0000Wooooo0_l0000hooooo`;o00006_ooool2o`0001Oooooo0_l000000ooo
oooo0000o`00000Eooooo`;o0000??ooool001kooooo00?o0000ooooooooool0MOooool2o`0000Wo
oooo0_l0000Iooooo`;o00007Oooool2o`0001[ooooo0_l0000aooooo`;o0000??ooool001kooooo
00?o0000ooooooooool0Voooool2o`0000Oooooo0_l00014ooooo`;o0000Foooool001kooooo00?o
0000ooooooooool0Loooool2o`0002oooooo0ol0000Jooooo`;o00009oooool2o`0002kooooo0_l0
000[ooooo`007_ooool2o`0007Cooooo0_l0000Uooooo`;o00002Oooool2o`0001[ooooo0_l0001G
ooooo`;o0000:oooool001kooooo0_l0000fooooo`;o0000;?ooool2o`0003Gooooo0_l0002[oooo
o`007_ooool00ol0003oooooooooo`0Iooooo`;o00001Oooool2o`0001?ooooo0_l0000Yooooo`;o
000000?oooooo`000?l00000Q_ooool2o`0005[ooooo000Nooooo`03o`000?oooooooooo01Wooooo
0_l00005ooooo`Co0000??ooool2o`00047ooooo0_l00002ooooo`;o00004oooool2o`0001kooooo
0_l0000=ooooo`;o00001oooool2o`00057ooooo000Nooooo`03o`000?oooooooooo013ooooo0_l0
000@ooooo`;o0000=Oooool2o`0004Sooooo0_l00002ooooo`;o00004oooool2o`0001Oooooo0_l0
0005ooooo`;o00005_ooool2o`0004_ooooo0_l00004ooooo`007_ooool00ol0003oooooooooo`0@
ooooo`;o0000Aoooool2o`00063ooooo0_l0000Hooooo`;o0000J_ooool2o`0000Cooooo000Noooo
o`;o0000_?ooool2o`0001Sooooo0_l0000Looooo`;o0000:?ooool2o`0002Sooooo000Nooooo`04
o`000?oooooo0000o`0000cooooo0_l0000Looooo`;o0000<Oooool2o`0007Gooooo0_l0000Loooo
o`;o0000:?ooool2o`0002Sooooo000Nooooo`04o`000?oooooo0000o`0000cooooo0_l0000Loooo
o`;o0000<Oooool2o`0004Kooooo0_l0000booooo`;o00005_ooool2o`000003ooooool0003o0000
053ooooo000Nooooo`03o`000?oooooooooo0:Kooooo0_l0000booooo`;o00005_ooool2o`000003
ooooool0003o0000053ooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0EOooool2o`0001cooooo0_l0000Oooooo`;o0000@Oooool2o`00017ooooo0_l0
000booooo`;o00009oooool001kooooo00?o0000ooooooooool0EOooool2o`0001cooooo0_l0000O
ooooo`;o0000@Oooool2o`00017ooooo0_l0000Qooooo`;o00003oooool2o`0000cooooo0_l0000I
ooooo`007_ooool00ol0003oooooooooo`2kooooo`;o00005?ooool2o`0001kooooo0_l0000Joooo
o`;o00007Oooool2o`0001Wooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0000<ooooo`;o
0000P_ooool2o`0001?ooooo0_l0000Dooooo`;o00007_ooool2o`0002Sooooo0_l0000Zooooo`00
7_ooool00ol0003oooooooooo`0Dooooo`;o00003?ooool2o`0006Wooooo0_l0000Gooooo`;o0000
G?ooool2o`0001Gooooo0_l0000Zooooo`007_ooool00ol0003oooooooooo`2=ooooo`;o0000@Ooo
ool2o`0001gooooo0_l0000Cooooo`;o0000@Oooool001kooooo00?o0000ooooooooool0d?ooool2
o`0001gooooo0_l0001Fooooo`007_ooool00ol0003oooooooooo`1Tooooo`;o0000??ooool2o`00
03;ooooo0_l0000Zooooo`;o0000;Oooool2o`0001Cooooo000Nooooo`03o`000?oooooooooo06Co
oooo0_l0000looooo`;o0000<_ooool2o`0002[ooooo0_l0000]ooooo`;o00005?ooool000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<
00Kooooo00?o0000ooooooooool07oooool2o`0000Wooooo0_l0002<ooooo`;o0000SOooool000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q00Kooooo00?o0000ooooooooool07oooool2o`0000Wooooo0_l0000`ooooo`;o00004oooool2
o`0004Gooooo0_l0000Kooooo`;o00007_ooool3o`0004oooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0000Fooooo`;o00001Ooo
ool2o`0003gooooo0_l0000=ooooo`;o00001?ooool2o`0001Kooooo0_l00019ooooo`?o00001_oo
ool2o`0001Kooooo0ol0000fooooo`;o00005oooool000?ooooo00Go0000ooooooooooooooooo`00
000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool00ol0003oooooooooo`0Fooooo`;o0000
1Oooool2o`0004cooooo0_l0000<ooooo`;o00003_ooool2o`0004Wooooo0_l00007ooooo`;o0000
8?ooool2o`0002gooooo0_l0000Gooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo
00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo07Wooooo0_l00021ooooo`;o
000000?oooooo`000?l000002Oooool2o`0003_ooooo0003ooooo`05oa0@4?ooooooooooooooool@
41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo0_l0001Tooooo`;o0000:oooool2o`00
04gooooo0_l0000Kooooo`;o00003?ooool2o`0003_ooooo0003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo0_l0001Tooooo`;o0000:oooool2
o`0004gooooo0_l00010ooooo`;o00009?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`0]ooooo`;o0000O_oo
ool2o`0000?ooooo0_l0001]ooooo`;o00009?ooool001kooooo00?o0000ooooooooool0;Oooool2
o`0005Wooooo0_l0000Sooooo`;o00000oooool2o`0005Kooooo0_l0000kooooo`007_ooool00ol0
003oooooooooo`28ooooo`;o0000P?ooool2o`0003?ooooo0_l00006ooooo`007_ooool00ol0003o
ooooooooo`2[ooooo`;o0000=Oooool2o`0005_ooooo0_l00006ooooo`007_ooool00ol0003ooooo
ooooo`2Nooooo`;o00002oooool2o`0003Gooooo0_l00016ooooo`;o00006oooool001kooooo00?o
0000ooooooooool0G_ooool2o`0003kooooo0_l0002:ooooo`;o00003Oooool2o`0000cooooo000N
ooooo`03o`000?oooooooooo05kooooo0_l0000eooooo`;o00004_ooool2o`0002Cooooo0_l0001I
ooooo`;o00003Oooool2o`0000cooooo000Nooooo`03o`000?oooooooooo037ooooo0_l00018oooo
o`;o00006?ooool2o`0001;ooooo0_l0000Booooo`;o00004?ooool2o`0006?ooooo0_l0000Aoooo
o`007_ooool00ol0003oooooooooo`0aooooo`;o0000B?ooool2o`0002Cooooo1?l0000>ooooo`;o
00002?ooool2o`0004;ooooo1?l0000_ooooo`;o00004Oooool001kooooo00?o0000ooooooooool0
@oooool2o`0005cooooo1?l0000>ooooo`;o00005?ooool2o`0002[ooooo0_l0000:ooooo`Co0000
@_ooool001kooooo00?o0000ooooooooool0@oooool2o`0008Cooooo0_l0000Zooooo`;o00004?oo
ool2o`0003kooooo000Nooooo`03o`000?oooooooooo09Sooooo0_l0000jooooo`;o0000<Oooool2
o`0000oooooo0_l0000]ooooo`007_ooool2o`0001Oooooo0_l00020ooooo`;o0000>_ooool2o`00
04;ooooo0_l0000Eooooo`;o00005_ooool001kooooo00?o0000ooooooooool05_ooool2o`000:Ko
oooo0_l0000fooooo`;o0000=oooool2o`0001Kooooo000Nooooo`03o`000?oooooooooo03gooooo
0_l0000booooo`;o0000Boooool2o`0003Kooooo0_l0001?ooooo`007_ooool00ol0003ooooooooo
o`02ooooo`;o0000>Oooool2o`0000Cooooo0_l0000/ooooo`;o0000M_ooool2o`0005cooooo000N
ooooo`03o`000?oooooooooo00;ooooo0_l0000Looooo`;o00001_ooool2o`0001Wooooo0_l0002I
ooooo`;o00002Oooool2o`0005Kooooo0_l00004ooooo`007_ooool00ol0003oooooooooo`0Poooo
o`;o00001_ooool2o`0001oooooo1?l0002Aooooo`;o00009Oooool2o`0003[ooooo0_l00004oooo
o`007_ooool00ol0003oooooooooo`0Xooooo`;o00007oooool4o`00047ooooo0_l0001eooooo`;o
0000@?ooool001kooooo00?o0000ooooooooool0G?ooool2o`00033ooooo0_l0000Vooooo`;o0000
5?ooool2o`00053ooooo0_l0000Wooooo`007_ooool00ol0003oooooooooo`0Uooooo`;o0000=Ooo
ool2o`0001Kooooo0_l0000booooo`;o00003?ooool2o`0001Cooooo0_l0000gooooo`;o00005ooo
ool2o`0002Oooooo000Nooooo`03o`000?oooooooooo02Gooooo0_l0000Booooo`;o0000>Oooool2
o`0003;ooooo0_l0000Booooo`;o0000>?ooool2o`0000gooooo0_l00010ooooo`007_ooool00ol0
003oooooooooo`0iooooo`;o00008Oooool2o`0005kooooo0_l0000[ooooo`;o00002oooool2o`00
04oooooo000Nooooo`03o`000?oooooooooo02Wooooo0_l0000_ooooo`Co0000=oooool2o`0005;o
oooo0_l0001Looooo`007_ooool00ol0003oooooooooo`0Hooooo`;o00003oooool2o`0002_ooooo
0_l00002ooooo`;o0000>Oooool2o`0000kooooo0_l00018ooooo`;o00007oooool2o`0000cooooo
0_l0000Wooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o00002?ooool2o`0003;ooooo0_l0
001=ooooo`;o0000B?ooool2o`0001oooooo0_l0000<ooooo`;o00004oooool2o`0000Kooooo0_l0
000:ooooo`007_ooool00ol0003oooooooooo`0Rooooo`;o0000;oooool2o`0006Wooooo0_l0001B
ooooo`;o00007oooool2o`0000Cooooo1?l0000:ooooo`007_ooool00ol0003oooooooooo`0Poooo
o`;o0000<Oooool2o`0006Wooooo0_l0000Dooooo`;o0000??ooool2o`0002Gooooo0_l0000<oooo
o`007_ooool2o`0000Gooooo0_l0000Jooooo`;o0000>?ooool2o`0007Sooooo0_l00004ooooo`;o
0000Joooool001kooooo00?o0000ooooooooool01?ooool2o`0005Cooooo0_l00006ooooo`;o0000
:oooool2o`0004Wooooo0_l0000]ooooo`;o00006oooool2o`0001oooooo000Nooooo`03o`000?oo
oooooooo06;ooooo0_l00005ooooo`;o00008Oooool2o`000003ooooool0003o000007Sooooo0_l0
000Kooooo`;o00007oooool001kooooo00?o0000ooooooooool0JOooool2o`00027ooooo0_l00004
ooooo`;o00005?ooool2o`0008;ooooo0_l0000Iooooo`007_ooool00ol0003oooooooooo`2Boooo
o`?o00004oooool2o`0001cooooo0_l0001Tooooo`;o00006Oooool001kooooo00?o0000oooooooo
ool03Oooool2o`00073ooooo0_l0000Booooo`;o0000<Oooool2o`00073ooooo0_l0000=ooooo`00
7_ooool00ol0003oooooooooo`0=ooooo`Ko0000K?ooool2o`0005cooooo0_l0001Iooooo`;o0000
3Oooool001kooooo00?o0000ooooooooool03oooool4o`0007oooooo0_l00019ooooo`;o0000J?oo
ool001kooooo00?o0000ooooooooool05_ooool2o`0004Gooooo0_l0000cooooo`;o0000GOooool2
o`0000cooooo0_l0000oooooo`;o00001Oooool001kooooo00?o0000ooooooooool05_ooool2o`00
00_ooooo0_l0000booooo`;o00001?ooool2o`00067ooooo0_l000000ooooooo0000o`00000/oooo
o`;o00003?ooool2o`0002?ooooo0_l0000Iooooo`?o00001Oooool001kooooo00?o0000oooooooo
ool07Oooool2o`0000Cooooo0_l0000booooo`;o0000?Oooool2o`0001Wooooo0_l0000=ooooo`;o
000000?oooooo`000?l00000G?ooool2o`000003ooooool0003o000001Wooooo0_l00006ooooo`00
7_ooool00ol0003oooooooooo`04ooooo`;o00005oooool2o`0007Oooooo0_l0000Iooooo`;o0000
K_ooool2o`0002Cooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0003ooooood;ooooo000N
ooooo`03o`000?oooooooooo01cooooo0_l00005ooooo`;o0000I?ooool2o`0004;ooooo0_l0000h
ooooo`;o0000:Oooool2o`0001?ooooo000Nooooo`03o`000?oooooooooo00gooooo0_l0000=oooo
o`;o00001Oooool2o`0006Cooooo0_l0000;ooooo`;o0000=Oooool2o`0003Sooooo0_l0000Yoooo
o`;o000000?oooooo`000?l000004?ooool001kooooo00?o0000ooooooooool03Oooool2o`0002oo
oooo0_l0000Gooooo`;o0000?Oooool2o`0001Kooooo0_l0000`ooooo`;o0000Doooool2o`00013o
oooo000Nooooo`;o0000?oooool2o`0001Oooooo0_l0000^ooooo`;o00006oooool2o`0000Sooooo
0_l0000`ooooo`;o0000:Oooool2o`0003[ooooo000Nooooo`03o`000?oooooooooo03kooooo0_l0
000Pooooo`;o00003Oooool2o`0001Kooooo0_l0000Kooooo`;o0000COooool2o`0001Kooooo0_l0
000jooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o00001?ooool2o`0002Kooooo0_l00003
ooooo`;o00006?ooool2o`0000gooooo0_l0001Cooooo`;o00001Oooool2o`0002Kooooo0_l0001B
ooooo`007_ooool00ol0003oooooooooo`03ooooo`;o00003_ooool2o`0000Cooooo0_l0000Soooo
o`;o000000?oooooo`000?l000000oooool2o`0007cooooo0_l00005ooooo`;o0000N_ooool001ko
oooo00?o0000ooooooooool00oooool2o`0003Wooooo0_l0001Eooooo`;o0000/?ooool001kooooo
00?o0000ooooooooool0C_ooool2o`0004Gooooo0_l0000Rooooo`;o00003oooool2o`0006oooooo
0_l0000:ooooo`007_ooool00ol0003oooooooooo`1>ooooo`;o00007_ooool2o`0004Oooooo1?l0
000?ooooo`;o00002Oooool2o`0004cooooo0_l0000Fooooo`;o00002_ooool001kooooo00?o0000
ooooooooool01Oooool2o`0006Oooooo0_l00017ooooo`;o00007?ooool2o`0004Oooooo0_l00003
ooooo`;o00008_ooool001kooooo00?o0000ooooooooool00_l00003ooooo`;o0000oooooolBoooo
o`;o00001?ooool2o`0002Oooooo000Nooooo`03o`000?oooooooooo00;o0000oooooolGooooo`;o
0000;Oooool001kooooo00?o0000ooooooooool0QOooool2o`0000;ooooo0_l0000Vooooo`;o0000
;Oooool2o`0006Gooooo000Nooooo`03o`000?oooooooooo04[ooooo0_l0000iooooo`;o00000_oo
ool2o`0002Kooooo0_l0000]ooooo`;o0000IOooool001kooooo00?o0000ooooooooool0B_ooool3
o`00083ooooo0_l0001/ooooo`;o00000_ooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo
04_ooooo0_l000000ooooooo0000o`000006ooooo`;o0000MOooool2o`0001Wooooo0_l000000ooo
oooo0000o`000003ooooo`;o0000BOooool2o`0000;ooooo0_l00006ooooo`005?ooool4o`000003
oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0C_ooool2o`0000Kooooo0_l0002@ooooo`;o
000000?oooooo`000?l000000oooool2o`0002[ooooo0_l0000Yooooo`005_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo01[ooooo0_l0000Gooooo`;o0000A_ooool2o`0002Cooooo
0_l0000Oooooo`;o0000F?ooool2o`0000?ooooo0_l0000Tooooo`005_ooool00ol0003ooooooooo
o`05ooooo`?o00006_ooool2o`0001Oooooo0_l00016ooooo`;o00009?ooool2o`0001oooooo0_l0
001Mooooo`;o00009?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0
003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo
00?o0000ooooooooool0oooooom@ooooo`005?ooool00omEEEGoIVIVo`00003ooooooe;ooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.64555 .34027 Mdot
.40214 .45283 Mdot
.88362 .49772 Mdot
.28704 .54013 Mdot
.51565 .08202 Mdot
.63779 .63398 Mdot
.69372 .49584 Mdot
.98903 .91107 Mdot
.19513 .37162 Mdot
.00832 .90481 Mdot
.36038 .46315 Mdot
.0883 .04068 Mdot
.16139 .55816 Mdot
.25366 .03048 Mdot
.83555 .63419 Mdot
.50725 .04585 Mdot
.87084 .00313 Mdot
.30528 .95807 Mdot
.6581 .07101 Mdot
.86072 .51349 Mdot
.99897 .13692 Mdot
.28811 .16502 Mdot
.19483 .2139 Mdot
.75542 .68274 Mdot
.4811 .08934 Mdot
.04569 .1095 Mdot
.07941 .91467 Mdot
.09091 .50804 Mdot
.76046 .46262 Mdot
.2134 .99074 Mdot
.56567 .86943 Mdot
.90436 .94361 Mdot
.01341 .26328 Mdot
.06019 .31446 Mdot
.37315 .59777 Mdot
.76626 .1884 Mdot
.43418 .97608 Mdot
.25328 .63104 Mdot
.78905 .59451 Mdot
.71306 .57109 Mdot
.58199 .5583 Mdot
.93793 .04063 Mdot
.57468 .16824 Mdot
.58489 .51896 Mdot
.1092 .43207 Mdot
.97733 .77848 Mdot
.18958 .38346 Mdot
.6682 .11131 Mdot
.32208 .8703 Mdot
.95377 .93229 Mdot
.07484 .8276 Mdot
.77941 .92413 Mdot
.9477 .82129 Mdot
.31476 .3375 Mdot
.93123 .11216 Mdot
.28093 .26052 Mdot
.39668 .12217 Mdot
.7461 .04097 Mdot
.64793 .18171 Mdot
.53362 .47596 Mdot
.77344 .76499 Mdot
.13247 .99085 Mdot
.24139 .3711 Mdot
.86986 .62704 Mdot
.75425 .10667 Mdot
.013 .75147 Mdot
.34726 .53006 Mdot
.28878 .91777 Mdot
.51179 .86717 Mdot
.09839 .43302 Mdot
.42213 .22704 Mdot
.12469 .5131 Mdot
.0687 .9376 Mdot
.53628 .98738 Mdot
.39838 .0213 Mdot
.2259 .90492 Mdot
.09486 .45188 Mdot
.65369 .70689 Mdot
.21123 .38142 Mdot
.79999 .21647 Mdot
.14235 .04615 Mdot
.26926 .25296 Mdot
.27997 .2757 Mdot
.69503 .27419 Mdot
.64729 .88764 Mdot
.70144 .76173 Mdot
.79322 .32398 Mdot
.02376 .4019 Mdot
.23423 .31718 Mdot
.83251 .23325 Mdot
.59331 .37964 Mdot
.5718 .572 Mdot
.90269 .91141 Mdot
.78359 .76551 Mdot
.18767 .0764 Mdot
.64016 .93444 Mdot
.98887 .74029 Mdot
.48827 .6134 Mdot
.64272 .97895 Mdot
.99101 .75358 Mdot
.84522 .19606 Mdot
.62189 .06309 Mdot
.79671 .26062 Mdot
.5877 .04514 Mdot
.35214 .8322 Mdot
.26651 .72934 Mdot
.72773 .21595 Mdot
.09123 .35746 Mdot
.2867 .91345 Mdot
.15208 .18506 Mdot
.08672 .39185 Mdot
.60552 .86567 Mdot
.79505 .74009 Mdot
.53683 .35584 Mdot
.44837 .02164 Mdot
.4947 .86851 Mdot
.5452 .62845 Mdot
.66847 .58355 Mdot
.25983 .88125 Mdot
.02625 .80453 Mdot
.54577 .39195 Mdot
.43396 .14634 Mdot
.89747 .43149 Mdot
.28836 .72438 Mdot
.65201 .23967 Mdot
.30536 .8199 Mdot
.67816 .7926 Mdot
.26474 .49799 Mdot
.68516 .61534 Mdot
.13549 .35866 Mdot
.84436 .19843 Mdot
.56897 .123 Mdot
.78858 .25104 Mdot
.67062 .53017 Mdot
.43524 .25687 Mdot
.85546 .24291 Mdot
.21662 .54888 Mdot
.08526 .98116 Mdot
.99494 .29698 Mdot
.28332 .92355 Mdot
.86154 .23458 Mdot
.69614 .12066 Mdot
.56155 .51648 Mdot
.59218 .4483 Mdot
.21797 .72419 Mdot
.45878 .48169 Mdot
.33621 .91624 Mdot
.05253 .70338 Mdot
.68545 .82787 Mdot
.51005 .26183 Mdot
.13691 .05398 Mdot
.67752 .79319 Mdot
.73373 .25997 Mdot
.53646 .19994 Mdot
.71619 .286 Mdot
.38399 .20476 Mdot
.93 .13188 Mdot
.50035 .15535 Mdot
.03065 .67588 Mdot
.8832 .99519 Mdot
.88719 .4035 Mdot
.90159 .19336 Mdot
.19733 .92411 Mdot
.70767 .95275 Mdot
.93251 .09778 Mdot
.71406 .21151 Mdot
.76484 .26065 Mdot
.77561 .56482 Mdot
.28051 .67739 Mdot
.7539 .85561 Mdot
.79632 .42727 Mdot
.30551 .3146 Mdot
.47092 .58986 Mdot
.9351 .67152 Mdot
.80988 .21302 Mdot
.76874 .16833 Mdot
.3314 .55372 Mdot
.59882 .5253 Mdot
.10564 .85531 Mdot
.37844 .5119 Mdot
.27458 .6187 Mdot
.05138 .0887 Mdot
.92498 .72408 Mdot
.19698 .32053 Mdot
.00846 .57938 Mdot
.72611 .11469 Mdot
.74054 .93839 Mdot
.48257 .49285 Mdot
.86004 .82435 Mdot
.42195 .44306 Mdot
.30078 .51015 Mdot
.60559 .47604 Mdot
.58242 .34199 Mdot
.07005 .84211 Mdot
.10765 .18744 Mdot
.32006 .05534 Mdot
.5756 .04813 Mdot
.05529 .39219 Mdot
.37855 .66939 Mdot
.03152 .4418 Mdot
.94475 .28953 Mdot
.17199 .4661 Mdot
.19851 .24378 Mdot
.01239 .43078 Mdot
.05982 .44279 Mdot
.50214 .04224 Mdot
.49642 .69572 Mdot
.63979 .52564 Mdot
.39871 .20932 Mdot
.12128 .57084 Mdot
.58166 .08423 Mdot
.52819 .58332 Mdot
.07849 .22892 Mdot
.80299 .54769 Mdot
.44612 .45741 Mdot
.33497 .56264 Mdot
.83745 .56623 Mdot
.26853 .98672 Mdot
.87252 .32462 Mdot
.22656 .00853 Mdot
.95945 .65245 Mdot
.65467 .98315 Mdot
.90791 .12561 Mdot
.5836 .86178 Mdot
.28987 .33801 Mdot
.33802 .87083 Mdot
.28843 .42841 Mdot
.43878 .75671 Mdot
.89238 .28903 Mdot
.70335 .31658 Mdot
.54688 .42397 Mdot
.91851 .7679 Mdot
.03839 .22431 Mdot
.82338 .32989 Mdot
.68452 .5466 Mdot
.70611 .91788 Mdot
.95915 .66833 Mdot
.91349 .61191 Mdot
.11792 .80659 Mdot
.92977 .27706 Mdot
.79025 .04349 Mdot
.79562 .51473 Mdot
.78995 .08162 Mdot
.31557 .18583 Mdot
.19716 .38146 Mdot
.03888 .30246 Mdot
.05192 .2782 Mdot
.79904 .83932 Mdot
.5672 .06628 Mdot
.35205 .79083 Mdot
.87858 .70608 Mdot
.85024 .04387 Mdot
.64461 .19874 Mdot
.52223 .99668 Mdot
.30571 .59456 Mdot
.65491 .35244 Mdot
.57043 .66013 Mdot
.15646 .58474 Mdot
.03513 .93886 Mdot
.89412 .22215 Mdot
.94997 .32163 Mdot
.03101 .96591 Mdot
.52489 .17726 Mdot
.72743 .48444 Mdot
.42596 .41764 Mdot
.67731 .93523 Mdot
.56114 .36243 Mdot
.56769 .02627 Mdot
.45227 .16652 Mdot
.84336 .87884 Mdot
.82954 .77482 Mdot
.49314 .20957 Mdot
.4324 .89828 Mdot
.89733 .675 Mdot
.37531 .17841 Mdot
.73031 .77998 Mdot
.49527 .21192 Mdot
.51055 .37793 Mdot
.38532 .37274 Mdot
.39324 .92362 Mdot
.51135 .68432 Mdot
.10401 .49656 Mdot
.1261 .43714 Mdot
.06542 .72539 Mdot
.2656 .09708 Mdot
.6183 .48263 Mdot
.34769 .36404 Mdot
.42874 .25631 Mdot
.42733 .62227 Mdot
.47238 .31827 Mdot
.56967 .67305 Mdot
.53509 .95413 Mdot
.6145 .57452 Mdot
.94924 .01843 Mdot
.92857 .55771 Mdot
.34528 .72143 Mdot
.20125 .02936 Mdot
.30523 .70136 Mdot
.4269 .19706 Mdot
.32362 .98243 Mdot
.46805 .12551 Mdot
.41212 .1097 Mdot
.45592 .88892 Mdot
.33304 .59468 Mdot
.37239 .76465 Mdot
.91408 .13923 Mdot
.8818 .6315 Mdot
.00628 .96059 Mdot
.11942 .17086 Mdot
.27144 .72384 Mdot
.25082 .43786 Mdot
.49527 .30019 Mdot
.22789 .86187 Mdot
.6271 .76122 Mdot
.37269 .4304 Mdot
.74628 .60017 Mdot
.4372 .20963 Mdot
.29833 .89104 Mdot
.08755 .02141 Mdot
.72631 .46962 Mdot
.42138 .39407 Mdot
.02343 .207 Mdot
.62029 .38863 Mdot
.97372 .46277 Mdot
.81769 .08723 Mdot
.89376 .15341 Mdot
.00147 .10962 Mdot
.6802 .09818 Mdot
.02465 .43744 Mdot
.9265 .64927 Mdot
.48959 .88183 Mdot
.65431 .73994 Mdot
.51995 .03818 Mdot
.19058 .97013 Mdot
.46066 .1923 Mdot
.6709 .08326 Mdot
.06269 .66816 Mdot
.22026 .38666 Mdot
.62554 .0199 Mdot
.10773 .84591 Mdot
.04017 .10581 Mdot
.70788 .64631 Mdot
.11457 .67168 Mdot
.53372 .3744 Mdot
.01491 .09037 Mdot
.88403 .94025 Mdot
.13063 .43598 Mdot
.68209 .31121 Mdot
.5046 .32432 Mdot
.99902 .37989 Mdot
.43672 .78384 Mdot
.33987 .09833 Mdot
.83532 .1334 Mdot
.17693 6e-05 Mdot
.16961 .98066 Mdot
.09695 .0747 Mdot
.68795 .35182 Mdot
.77148 .57443 Mdot
.11179 .37171 Mdot
.57094 .81785 Mdot
.05217 .58555 Mdot
.09932 .88998 Mdot
.18773 .27442 Mdot
.19834 .32789 Mdot
.7859 .58517 Mdot
.56713 .89622 Mdot
.03829 .1663 Mdot
.90834 .34969 Mdot
.91348 .3469 Mdot
.59136 .21404 Mdot
.36977 .41869 Mdot
.48777 .83966 Mdot
.75284 .36567 Mdot
.9273 .42276 Mdot
.13763 .55799 Mdot
.19791 .62465 Mdot
.87556 .40909 Mdot
.18018 .19567 Mdot
.26544 .69832 Mdot
.71411 .37406 Mdot
.88287 .90474 Mdot
.67768 .70649 Mdot
.07607 .93226 Mdot
.63739 .29498 Mdot
.76935 .99808 Mdot
.24814 .33813 Mdot
.20326 .97696 Mdot
.60526 .18091 Mdot
.77905 .01383 Mdot
.89268 .54178 Mdot
.0492 .75649 Mdot
.74437 .60213 Mdot
.69837 .39466 Mdot
.50984 .43432 Mdot
.06167 .0277 Mdot
.43372 .68381 Mdot
.85627 .49275 Mdot
.61935 .78258 Mdot
.20087 .0734 Mdot
.57679 .0632 Mdot
.8879 .50205 Mdot
.09171 .08989 Mdot
.29134 .19386 Mdot
.92792 .02017 Mdot
.14088 .23499 Mdot
.96886 .03869 Mdot
.54264 .75769 Mdot
.00012 .91832 Mdot
.23268 .69974 Mdot
.82403 .56691 Mdot
.58809 .18406 Mdot
.80708 .96852 Mdot
.25229 .22653 Mdot
.15068 .34301 Mdot
.41434 .58054 Mdot
.68652 .86231 Mdot
.70407 .80282 Mdot
.2452 .28006 Mdot
.64151 .59794 Mdot
.72917 .91232 Mdot
.93648 .33077 Mdot
.34003 .78252 Mdot
.81852 .58915 Mdot
.06378 .38327 Mdot
.09719 .92677 Mdot
.45404 .50712 Mdot
.28556 .89315 Mdot
.21956 .10695 Mdot
.00949 .52853 Mdot
.40384 .28894 Mdot
.83073 .50109 Mdot
.13041 .91183 Mdot
.44041 .62186 Mdot
.26463 .57952 Mdot
.06491 .58242 Mdot
.73426 .75708 Mdot
.50608 .09859 Mdot
.83375 .81036 Mdot
.68859 .76093 Mdot
.07851 .15119 Mdot
.10604 .67953 Mdot
.12052 .31929 Mdot
.72552 .60282 Mdot
.53168 .96342 Mdot
.83613 .41831 Mdot
.72799 .84231 Mdot
.21686 .40529 Mdot
.41793 .6362 Mdot
.27626 .85425 Mdot
.11548 .37692 Mdot
.01635 .64982 Mdot
.47553 .79213 Mdot
.37736 .42708 Mdot
.89538 .9092 Mdot
.10358 .36762 Mdot
.9257 .48452 Mdot
.8098 .36853 Mdot
.76338 .09445 Mdot
.1508 .41895 Mdot
.7799 .91404 Mdot
.3173 .14003 Mdot
.10055 .97849 Mdot
.82704 .04032 Mdot
.07795 .7472 Mdot
.91626 .05949 Mdot
.72568 .39605 Mdot
.27084 .23372 Mdot
.36337 .44246 Mdot
.00916 .4109 Mdot
.13953 .794 Mdot
.41362 .42145 Mdot
.89706 .43104 Mdot
.53683 .75515 Mdot
.22951 .90182 Mdot
.24334 .27968 Mdot
.61626 .72988 Mdot
.76979 .6698 Mdot
.43366 .89519 Mdot
.95303 .97456 Mdot
.5363 .00986 Mdot
.48878 .11203 Mdot
.91873 .65756 Mdot
.54147 .14856 Mdot
.5787 .67773 Mdot
.53815 .83402 Mdot
.80597 .21616 Mdot
.7469 .1001 Mdot
.6625 .04376 Mdot
.417 .87325 Mdot
.78294 .68747 Mdot
.91565 .44504 Mdot
.78612 .13521 Mdot
.96961 .9064 Mdot
.30901 .03173 Mdot
.9159 .19869 Mdot
.30139 .7854 Mdot
.91283 .81408 Mdot
.05939 .02844 Mdot
.73306 .24735 Mdot
.85943 .53992 Mdot
.76655 .8357 Mdot
.53694 .41302 Mdot
.30043 .81163 Mdot
.29887 .72334 Mdot
.78206 .49537 Mdot
.42428 .16177 Mdot
.42745 .74073 Mdot
.56743 .91808 Mdot
.94258 .36918 Mdot
.05956 .32729 Mdot
.67256 .5582 Mdot
.73485 .24503 Mdot
.46029 .28309 Mdot
.66433 .38007 Mdot
.60427 .91135 Mdot
.92601 .19377 Mdot
.26336 .9874 Mdot
.06562 .49828 Mdot
.40421 .77708 Mdot
.95213 .13704 Mdot
.00407 .95049 Mdot
.36192 .34578 Mdot
.8047 .83942 Mdot
.16574 .55648 Mdot
.88296 .02013 Mdot
.96199 .64906 Mdot
.74883 .52853 Mdot
.59439 .88072 Mdot
.91437 .09907 Mdot
.07963 .92647 Mdot
.9708 .79265 Mdot
.57353 .24174 Mdot
.5095 .38482 Mdot
.6524 .4228 Mdot
.17766 .98097 Mdot
.01446 .41621 Mdot
.72247 .42528 Mdot
.50439 .32375 Mdot
.52202 .45428 Mdot
.48186 .91738 Mdot
.03522 .88744 Mdot
.92612 .54941 Mdot
.53958 .53967 Mdot
.84071 .75336 Mdot
.57674 .73742 Mdot
.72415 .78412 Mdot
.94085 .20304 Mdot
.16636 .81457 Mdot
.70149 .23375 Mdot
.22193 .02608 Mdot
.71835 .33271 Mdot
.17937 .6596 Mdot
.22659 .01158 Mdot
.78528 .6757 Mdot
.13266 .91037 Mdot
.4214 .47368 Mdot
.10089 .7241 Mdot
.23875 .14259 Mdot
.6901 .97936 Mdot
.51166 .77001 Mdot
.46543 .20035 Mdot
.84963 .29191 Mdot
.29773 .30446 Mdot
.10219 .18704 Mdot
.5273 .74401 Mdot
.84765 .0696 Mdot
.93349 .306 Mdot
.97994 .16317 Mdot
.28339 .12553 Mdot
.30757 .47981 Mdot
.12535 .70153 Mdot
.24065 .15776 Mdot
.24727 .94906 Mdot
.92991 .30254 Mdot
.50018 .17527 Mdot
.30385 .65217 Mdot
.44025 .88255 Mdot
.97692 .13976 Mdot
.93563 .04046 Mdot
.56349 .51749 Mdot
.18506 .4654 Mdot
.72213 .58184 Mdot
.49104 .3138 Mdot
.99408 .87265 Mdot
.78292 .83741 Mdot
.52695 .0278 Mdot
.85741 .18183 Mdot
.66743 .92222 Mdot
.97097 .75145 Mdot
.21047 .24057 Mdot
.50336 .27943 Mdot
.19813 .26381 Mdot
.85496 .2745 Mdot
.95586 .23682 Mdot
.81541 .47688 Mdot
.49847 .8277 Mdot
.57547 .2026 Mdot
.44802 .25058 Mdot
.28457 .46887 Mdot
.22002 .86593 Mdot
.74583 .24667 Mdot
.56376 .1834 Mdot
.79398 .54841 Mdot
.80535 .47898 Mdot
.49936 .72019 Mdot
.42406 .77125 Mdot
.09439 .67275 Mdot
.47337 .39517 Mdot
.04569 .01668 Mdot
.47701 .60657 Mdot
.36027 .98547 Mdot
.80564 .2691 Mdot
.04668 .26102 Mdot
.78931 .5213 Mdot
.7994 .28903 Mdot
.426 .61754 Mdot
.77479 .11224 Mdot
.56566 .38199 Mdot
.10976 .90717 Mdot
.55373 .44222 Mdot
.51019 .3322 Mdot
.61496 .28677 Mdot
.70938 .80199 Mdot
.27214 .5533 Mdot
.09387 .07946 Mdot
.02497 .45749 Mdot
.85476 .34691 Mdot
.04779 .29275 Mdot
.63406 .75537 Mdot
.03787 .43879 Mdot
.95135 .30719 Mdot
.92055 .42956 Mdot
.89165 .54647 Mdot
.84969 .60216 Mdot
.74131 .17996 Mdot
.154 .61026 Mdot
.18657 .55233 Mdot
.5662 .59668 Mdot
.7674 .77615 Mdot
.96044 .77283 Mdot
.69312 .55129 Mdot
.48496 .85048 Mdot
.17821 .80525 Mdot
.97899 .86148 Mdot
.74912 .70952 Mdot
.59065 .69644 Mdot
.56138 .07385 Mdot
.99647 .63477 Mdot
.92054 .96802 Mdot
.8837 .4794 Mdot
.60049 .62942 Mdot
.47136 .27091 Mdot
.45293 .51408 Mdot
.43085 .98783 Mdot
.70908 .26747 Mdot
.99284 .54712 Mdot
.42761 .01509 Mdot
.94755 .41235 Mdot
.40527 .49263 Mdot
.42927 .25185 Mdot
.00812 .97273 Mdot
.96677 .20861 Mdot
.87019 .78327 Mdot
.06476 .47874 Mdot
.96962 .70374 Mdot
.06513 .96248 Mdot
.81782 .88259 Mdot
.62686 .9294 Mdot
.86339 .42018 Mdot
.11375 .98581 Mdot
.01026 .36683 Mdot
.26907 .17159 Mdot
.54238 .96381 Mdot
.7334 .51986 Mdot
.11256 .63184 Mdot
.23305 .47111 Mdot
.59527 .39096 Mdot
.61508 .98397 Mdot
.32022 .06339 Mdot
.54269 .57308 Mdot
.90397 .19742 Mdot
.86426 .08879 Mdot
.33818 .27902 Mdot
.17084 .35351 Mdot
.35501 .76206 Mdot
.87249 .38694 Mdot
.70453 .68339 Mdot
.21357 .4642 Mdot
.64879 .74999 Mdot
.03367 .93483 Mdot
.80254 .21453 Mdot
.0537 .80193 Mdot
.45062 .55173 Mdot
.64181 .18864 Mdot
.66518 .82228 Mdot
.01292 .27349 Mdot
.7656 .51813 Mdot
.68849 .3427 Mdot
.61455 .2823 Mdot
.01766 .43545 Mdot
.3973 .09948 Mdot
.45454 .05122 Mdot
.05931 .32613 Mdot
.92631 .79476 Mdot
.15698 .32175 Mdot
.7615 .05494 Mdot
.05262 .04514 Mdot
.17428 .22331 Mdot
.72998 .08249 Mdot
.04188 .42232 Mdot
.66757 .24477 Mdot
.57023 .45973 Mdot
.71654 .70855 Mdot
.59078 .85725 Mdot
.12791 .81368 Mdot
.09349 .62475 Mdot
.51475 .96292 Mdot
.87559 .00134 Mdot
.91288 .46594 Mdot
.1641 .24243 Mdot
.73119 .83899 Mdot
.56615 .36184 Mdot
.61372 .04056 Mdot
.53818 .45417 Mdot
.4466 .89215 Mdot
.49688 .16282 Mdot
.85687 .51759 Mdot
.84361 .01285 Mdot
.89359 .12569 Mdot
.5035 .56807 Mdot
.44779 .13156 Mdot
.81675 .7719 Mdot
.13302 .85757 Mdot
.79565 .87638 Mdot
.97928 .24293 Mdot
.74336 .85235 Mdot
.11191 .81476 Mdot
.78139 .21933 Mdot
.79585 .83873 Mdot
.49615 .67445 Mdot
.44898 .2585 Mdot
.5336 .66231 Mdot
.46262 .58047 Mdot
.154 .42788 Mdot
.87273 .29677 Mdot
.88495 .0277 Mdot
.32411 .48284 Mdot
.62768 .72538 Mdot
.74858 .12589 Mdot
.39085 .04009 Mdot
.41695 .81623 Mdot
.33844 .9186 Mdot
.54062 .12314 Mdot
.3766 .70374 Mdot
.5134 .08584 Mdot
.76857 .8206 Mdot
.18181 .32891 Mdot
.31033 .33736 Mdot
.29988 .29777 Mdot
.13833 .08492 Mdot
.09527 .62309 Mdot
.31675 .58637 Mdot
.13044 .35008 Mdot
.4281 .23106 Mdot
.05023 .70071 Mdot
.60415 .97577 Mdot
.09974 .15936 Mdot
.3945 .61545 Mdot
.35583 .29367 Mdot
.53674 .814 Mdot
.60703 .54912 Mdot
.82214 .17663 Mdot
.96657 .34107 Mdot
.94564 .12164 Mdot
.39951 .56943 Mdot
.08297 .35464 Mdot
.77868 .30913 Mdot
.92025 .9431 Mdot
.13129 .72044 Mdot
.09186 .87394 Mdot
.32223 .88262 Mdot
.0021 .61674 Mdot
.14186 .90966 Mdot
.66689 .88461 Mdot
.7424 .07796 Mdot
.15499 .28921 Mdot
.89159 .09049 Mdot
.63631 .39384 Mdot
.66227 .20975 Mdot
.25749 .92924 Mdot
.96269 .96258 Mdot
.61402 .61113 Mdot
.22299 .64403 Mdot
.13805 .55271 Mdot
.5037 .20258 Mdot
.93393 .14416 Mdot
.32233 .67477 Mdot
.23779 .36218 Mdot
.86515 .12162 Mdot
.16045 .41531 Mdot
.75806 .34679 Mdot
.35009 .93859 Mdot
.32776 .81789 Mdot
.29405 .88065 Mdot
.66889 .73852 Mdot
.59893 .78561 Mdot
.72178 .07233 Mdot
.10362 .09607 Mdot
.95092 .86072 Mdot
.42145 .26657 Mdot
.54762 .29145 Mdot
.82471 .29934 Mdot
.22326 .40165 Mdot
.90001 .82281 Mdot
.45619 .10614 Mdot
.19111 .49149 Mdot
.21129 .84173 Mdot
.02975 .16537 Mdot
.06474 .29406 Mdot
.38984 .51227 Mdot
.6525 .88695 Mdot
.52067 .79557 Mdot
.58768 .04491 Mdot
.26108 .03527 Mdot
.86919 .10016 Mdot
.86319 .77311 Mdot
.87744 .52126 Mdot
.14827 .71764 Mdot
.19645 .25239 Mdot
.65888 .10207 Mdot
.58019 .48758 Mdot
.72828 .04175 Mdot
.47407 .1523 Mdot
.76044 .71059 Mdot
.35513 .56582 Mdot
.95364 .21454 Mdot
.02956 .92908 Mdot
.63458 .02089 Mdot
.60567 .82945 Mdot
.92676 .75637 Mdot
.94472 .12863 Mdot
.81303 .17464 Mdot
.83538 .09532 Mdot
.54441 .59099 Mdot
.89607 .47121 Mdot
.34349 .3526 Mdot
.00011 .45677 Mdot
.82173 .67019 Mdot
.42596 .99429 Mdot
.66186 .1963 Mdot
.28058 .69971 Mdot
.1743 .9091 Mdot
.76181 .10953 Mdot
.88637 .27192 Mdot
.38374 .46033 Mdot
.8068 .21023 Mdot
.04264 .43073 Mdot
.92373 .31505 Mdot
.58602 .53876 Mdot
.64662 .12486 Mdot
.63143 .98963 Mdot
.43927 .46635 Mdot
.9124 .73089 Mdot
.72206 .01379 Mdot
.60209 .16855 Mdot
.36501 .20143 Mdot
.66156 .23402 Mdot
.98452 .53983 Mdot
.17993 .2668 Mdot
.51579 .64313 Mdot
.1384 .28012 Mdot
.42968 .98173 Mdot
.94626 .84602 Mdot
.41569 .06927 Mdot
.60259 .54167 Mdot
.26768 .58354 Mdot
.47298 .9446 Mdot
.46264 .8422 Mdot
.25264 .23989 Mdot
.919 .86646 Mdot
.62141 .43954 Mdot
.93788 .6536 Mdot
.03885 .61038 Mdot
.96481 .13331 Mdot
.52699 .30617 Mdot
.98316 .644 Mdot
.4793 .21288 Mdot
.29813 .59327 Mdot
.56297 .70577 Mdot
.27338 .20975 Mdot
.76455 .03042 Mdot
.90735 .90631 Mdot
.69482 .12393 Mdot
.42112 .67672 Mdot
.09409 .98251 Mdot
.98587 .99754 Mdot
.12948 .20637 Mdot
.47651 .91717 Mdot
.08768 .53379 Mdot
.71785 .8785 Mdot
.9773 .26429 Mdot
.88982 .13716 Mdot
.76804 .70206 Mdot
.52227 .76878 Mdot
.52513 .12542 Mdot
.56118 .64372 Mdot
.86815 .61245 Mdot
.0811 .09567 Mdot
.27798 .86305 Mdot
.08157 .71684 Mdot
.75547 .76973 Mdot
.92099 .28289 Mdot
.22914 .04813 Mdot
.4814 .62692 Mdot
.00619 .81828 Mdot
.51469 .31013 Mdot
.93971 .21944 Mdot
.41576 .23195 Mdot
.53089 .17088 Mdot
.86426 .57795 Mdot
.69358 .78108 Mdot
.22351 .42489 Mdot
.47243 .43755 Mdot
.76663 .67913 Mdot
.68154 .95485 Mdot
.82674 .49483 Mdot
.09504 .70471 Mdot
.76072 .64972 Mdot
.62653 .90917 Mdot
.88985 .97443 Mdot
.62936 .2812 Mdot
.48732 .83985 Mdot
.41034 .05742 Mdot
.81421 .8506 Mdot
.49127 .0475 Mdot
.53066 .72208 Mdot
.23727 .54791 Mdot
.23994 .65959 Mdot
.67706 .3984 Mdot
.92944 .58705 Mdot
.51154 .95574 Mdot
.58253 .14761 Mdot
.42856 .20438 Mdot
.54458 .77676 Mdot
.56902 .5956 Mdot
.28023 .46713 Mdot
.63587 .10638 Mdot
.21289 .29707 Mdot
.8245 .01367 Mdot
.53198 .09112 Mdot
.70018 .05454 Mdot
.01364 .05592 Mdot
.65982 .54289 Mdot
.90573 .43478 Mdot
.7841 .88744 Mdot
.89118 .11689 Mdot
.75554 .72087 Mdot
.06615 .17866 Mdot
.67513 .14515 Mdot
.42417 .33917 Mdot
.37893 .59336 Mdot
.45001 .80588 Mdot
.222 .00882 Mdot
.84466 .19664 Mdot
.99455 .01708 Mdot
.39046 .22119 Mdot
.67875 .57209 Mdot
.04494 .53382 Mdot
.36409 .41631 Mdot
.42124 .91082 Mdot
.24536 .71502 Mdot
.55824 .02068 Mdot
.42231 .67352 Mdot
.64805 .77517 Mdot
.66121 .11255 Mdot
.23962 .10734 Mdot
.18012 .5489 Mdot
.2859 .3447 Mdot
.06608 .52001 Mdot
.80741 .33134 Mdot
.15454 .6469 Mdot
.83776 .90052 Mdot
.34347 .37821 Mdot
.84789 .32667 Mdot
.47193 .25463 Mdot
.66439 .11409 Mdot
.27525 .59473 Mdot
.94827 .56097 Mdot
.62985 .4935 Mdot
.09914 .66966 Mdot
.11495 .5334 Mdot
.85293 .8771 Mdot
.52955 .42685 Mdot
.55444 .42735 Mdot
.6405 .61226 Mdot
.24825 .56358 Mdot
.61746 .88877 Mdot
.02511 .02635 Mdot
.79618 .72768 Mdot
.5263 .01459 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Go
oooo0_l00007ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool4o`0000Ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;o
oooo000Nooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`03ooooo`;o00002?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool00_ooool001kooooo00?o0000ooooooooool0A?ooool4o`0006;ooooo0_l0
002Kooooo`007_ooool00ol0003oooooooooo`14ooooo`Co0000H_ooool2o`0005cooooo0_l00004
ooooo`;o0000=oooool001kooooo00?o0000ooooooooool02oooool2o`0003Wooooo0_l0000ooooo
o`;o00007_ooool2o`0003kooooo0_l0000@ooooo`;o00003Oooool2o`0000Cooooo0_l0000goooo
o`007_ooool00ol0003oooooooooo`0;ooooo`;o0000N_ooool2o`0001kooooo0_l0000nooooo`;o
00004?ooool2o`0003Gooooo0_l0000=ooooo`;o00001_ooool001kooooo00?o0000ooooooooool0
6?ooool2o`0006?ooooo0_l0000?ooooo`;o00008Oooool2o`0001Cooooo0_l000000ooooooo0000
o`00001?ooooo`;o00003Oooool2o`0000Cooooo0_l0000=ooooo`;o00001_ooool001kooooo00?o
0000ooooooooool06?ooool2o`0006?ooooo0_l0000?ooooo`;o00008Oooool2o`0001Cooooo0_l0
00000ooooooo0000o`00001?ooooo`;o00003Oooool2o`0001_ooooo000Nooooo`03o`000?oooooo
oooo00Cooooo0_l00009ooooo`?o0000<_ooool2o`00067ooooo0_l0000;ooooo`;o0000I_ooool2
o`0002Wooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l00009ooooo`?o0000:oooool2o`00
00Gooooo0_l00008ooooo`;o00004?ooool2o`0004Gooooo0_l0000;ooooo`;o0000?_ooool2o`00
02Kooooo0_l0000Yooooo`007_ooool00ol0003oooooooooo`0mooooo`;o00003oooool2o`000003
ooooool0003o000000gooooo0_l0002Booooo`;o0000DOooool001kooooo00?o0000ooooooooool0
DOooool2o`0005;ooooo0_l0002Pooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o0000H?oo
ool2o`0002Sooooo0_l0000Looooo`;o0000:Oooool2o`0001Wooooo0_l0000Qooooo`?o00002?oo
ool2o`0000kooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l0001Pooooo`;o00008_ooool2
o`0002;ooooo0_l0000>ooooo`;o00005?ooool2o`0000?ooooo0_l0000=ooooo`;o00002_ooool2
o`0000Gooooo0_l0000Jooooo`?o00002?ooool2o`0000kooooo000Nooooo`03o`000?oooooooooo
00gooooo0_l0000Kooooo`;o0000L?ooool2o`000003ooooool0003o000000;o00006?ooool2o`00
01Kooooo0_l0000Dooooo`;o00004_ooool2o`00017ooooo0_l0000eooooo`007_ooool00ol0003o
ooooooooo`0=ooooo`;o00006oooool2o`0001[ooooo0_l0001Dooooo`;o00000oooool2o`0001Co
oooo0_l00002ooooo`;o0000R_ooool001kooooo0_l00017ooooo`;o0000B?ooool2o`0002Gooooo
0_l0002>ooooo`007_ooool00ol0003oooooooooo`02o`0002Kooooo0_l0000jooooo`;o0000:_oo
ool2o`0004kooooo0_l0000Aooooo`;o0000D_ooool001kooooo00?o0000ooooooooool00_l0000V
ooooo`;o0000>_ooool2o`0001_ooooo0_l0001Mooooo`;o00004Oooool2o`00037ooooo0_l0000O
ooooo`007_ooool00ol0003oooooooooo`21ooooo`;o0000Xoooool2o`0001oooooo000Nooooo`03
o`000?oooooooooo06Cooooo0_l0001Aooooo`;o00003Oooool2o`0007oooooo000Nooooo`03o`00
0?oooooooooo06Cooooo0_l0001>ooooo`;o000000?oooooo`000?l000003Oooool2o`0007oooooo
000Nooooo`03o`000?oooooooooo08?ooooo0_l0000_ooooo`;o00007?ooool2o`0003_ooooo0_l0
000fooooo`007_ooool00ol0003oooooooooo`0Kooooo`;o00008?ooool2o`0004Cooooo0_l0000]
ooooo`;o00007_ooool2o`0001?ooooo0_l0000Vooooo`;o0000=_ooool001kooooo00?o0000oooo
ooooool06oooool2o`0001cooooo0_l00002ooooo`;o0000Loooool2o`0003?ooooo0_l00004oooo
o`;o0000F?ooool001kooooo00?o0000ooooooooool06_ooool2o`0001gooooo0_l0002booooo`;o
0000F?ooool001kooooo00?o0000ooooooooool06_ooool2o`0008Sooooo0_l0000Cooooo`;o0000
6oooool2o`00017ooooo0_l0000Booooo`;o0000B?ooool001kooooo00?o0000ooooooooool0:Ooo
ool2o`0007Sooooo0ol0000Cooooo`;o00006oooool2o`00017ooooo0_l0000Booooo`;o00001ooo
ool2o`0003oooooo000Nooooo`04o`000?ooooooooooooooo`;o00002_ooool2o`0000_ooooo0_l0
000=ooooo`;o0000KOooool2o`0000Wooooo0_l0001Qooooo`;o00003Oooool2o`0000Oooooo0_l0
000Wooooo`007_ooool01?l0003oooooooooooooool2o`0000[ooooo0_l0000;ooooo`;o0000O?oo
ool2o`0000oooooo0_l0001Zooooo`;o00001oooool2o`0002Oooooo000Nooooo`03o`000?oooooo
oooo01Kooooo0_l00006ooooo`;o0000ROooool2o`0004Wooooo0_l0000Eooooo`;o0000>_ooool0
01kooooo00?o0000ooooooooool05_ooool2o`0000Kooooo0_l0000booooo`;o00005_ooool2o`00
017ooooo0_l0000Qooooo`;o0000=oooool2o`0001Wooooo0_l0000Eooooo`;o00006?ooool2o`00
00Cooooo0_l0000Jooooo`007_ooool2o`0005?ooooo0_l0000Fooooo`;o00004Oooool2o`00027o
oooo0_l0000`ooooo`;o00001Oooool2o`0001Cooooo0_l0000Uooooo`;o00003Oooool2o`0000Co
oooo0_l0000Jooooo`007_ooool00ol0003oooooooooo`09ooooo`;o0000aoooool2o`0001_ooooo
0_l0000Uooooo`;o0000;oooool001kooooo00?o0000ooooooooool02Oooool2o`0003Sooooo0_l0
0005ooooo`;o0000A?ooool2o`0003Wooooo0_l0000Tooooo`;o0000E?ooool001gooooo0_l0000=
ooooo`;o0000=_ooool2o`0000Gooooo0_l0000fooooo`;o00003?ooool2o`0000Wooooo0_l0000^
ooooo`;o00002?ooool2o`0001[ooooo0_l000000ooooooo0000o`00000eooooo`;o00006_ooool0
01gooooo0_l0000=ooooo`;o0000MOooool2o`0001Oooooo0_l0000fooooo`Co00004Oooool2o`00
00[ooooo0_l00002ooooo`;o0000<Oooool2o`0001[ooooo000Nooooo`03o`000?oooooooooo0=?o
oooo0ol0000Booooo`;o00003_ooool2o`0002Cooooo0_l0000Wooooo`007_ooool00ol0003ooooo
ooooo`3Nooooo`;o0000?_ooool2o`0002Oooooo000Nooooo`03o`000?oooooooooo07gooooo0_l0
000]ooooo`;o00001oooool2o`0002Oooooo0_l0000eooooo`;o00006?ooool2o`0001Kooooo000N
ooooo`03o`000?oooooooooo05Sooooo0_l0000Sooooo`;o00005Oooool2o`00017ooooo0_l00003
ooooo`;o00001oooool2o`0001Oooooo0_l0000>ooooo`;o00003oooool2o`0002Cooooo0_l00007
ooooo`;o00000oooool2o`0000[ooooo0_l0000Fooooo`007_ooool00ol0003oooooooooo`1Hoooo
o`;o0000>_ooool2o`00017ooooo0_l0000Uooooo`;o00007oooool2o`0002gooooo0_l00003oooo
o`;o00002_ooool2o`0001Kooooo000Nooooo`03o`000?oooooooooo08gooooo0_l0001looooo`;o
00007Oooool2o`0000?ooooo0_l00005ooooo`;o00003oooool001kooooo00?o0000ooooooooool0
SOooool2o`0006cooooo0_l0000>ooooo`;o00007Oooool2o`0000[ooooo0_l0000?ooooo`007_oo
ool00ol0003oooooooooo`3kooooo`;o00008?ooool2o`0000Kooooo0_l0000:ooooo`;o00001_oo
ool2o`0000Kooooo0_l00004ooooo`007_ooool00ol0003oooooooooo`1:ooooo`;o00005oooool2
o`000;Sooooo0_l00006ooooo`;o00002_ooool2o`0000Kooooo0_l00006ooooo`;o00001?ooool0
01kooooo00?o0000ooooooooool0B_ooool2o`0001Oooooo0_l0001booooo`;o0000Doooool2o`00
01Wooooo000Nooooo`03o`000?oooooooooo08Wooooo0_l0000Qooooo`;o00002oooool2o`0001co
oooo0_l0001Cooooo`;o00006Oooool001kooooo0_l0000Fooooo`;o0000L_ooool2o`00027ooooo
0_l0000;ooooo`;o0000S?ooool001kooooo00?o0000ooooooooool05Oooool2o`0007oooooo0_l0
0026ooooo`;o00009oooool001kooooo00?o0000ooooooooool0B_ooool2o`0004[ooooo0_l00007
ooooo`;o0000OOooool2o`0002Oooooo000Nooooo`03o`000?oooooooooo01cooooo0_l0000/oooo
o`;o0000Doooool2o`000:Kooooo000Nooooo`03o`000?oooooooooo01cooooo0_l0001Xooooo`;o
00005Oooool2o`0009_ooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`06ooooo`Co0000
D?ooool2o`0002[ooooo0_l00007ooooo`;o00003?ooool2o`0009_ooooo0_l0000;ooooo`007_oo
ool00ol0003oooooooooo`06ooooo`Co0000D?ooool2o`0003?ooooo0_l0000Vooooo`;o00001ooo
ool2o`0003Cooooo0_l0001?ooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o0000;_ooool2
o`0005?ooooo0_l0000=ooooo`;o00001oooool2o`0003Cooooo0_l0001?ooooo`007_ooool00ol0
003oooooooooo`0Sooooo`;o0000;_ooool2o`0004Wooooo0_l00008ooooo`;o0000F_ooool2o`00
0003ooooool0003o000003kooooo000Nooooo`03o`000?oooooooooo017ooooo0_l0001Sooooo`;o
00009_ooool2o`0000Oooooo0_l0001Kooooo`;o000000?oooooo`000?l00000?_ooool001kooooo
00?o0000ooooooooool04Oooool2o`0006?ooooo0_l0000_ooooo`;o00006?ooool2o`0000cooooo
0_l0000Looooo`;o00009?ooool2o`0003;ooooo000Nooooo`03o`000?oooooooooo02gooooo0_l0
000cooooo`;o0000Coooool2o`0000Kooooo0_l00004ooooo`;o00003?ooool2o`0001cooooo0_l0
000Tooooo`;o0000<_ooool001kooooo00?o0000ooooooooool07Oooool4o`0000cooooo0_l0000c
ooooo`;o0000Coooool2o`0000Kooooo0_l0000@ooooo`;o00009_ooool2o`00053ooooo000Noooo
o`03o`000?oooooooooo01gooooo1?l0002/ooooo`;o00009_ooool2o`00053ooooo0003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo
05_ooooo0_l0000eooooo`;o0000SOooool2o`0000Kooooo0_l0000Looooo`000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool0
0ol0003oooooooooo`0fooooo`;o00008oooool2o`0002[ooooo0_l00009ooooo`;o0000?oooool2
o`0003Wooooo0ol0000@ooooo`?o00001Oooool2o`0001cooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`?o0000=_ooool2o`0004oooooo0_l0000:
ooooo`;o00005Oooool2o`00027ooooo0_l00004ooooo`;o0000>Oooool3o`00017ooooo0_l00002
ooooo`;o00007oooool000?ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^00Kooooo00?o0000ooooooooool0Loooool2o`0001;ooooo0_l0000:ooooo`;o00002oooool2
o`0000Sooooo0_l0000;ooooo`;o00005?ooool2o`0003oooooo0_l0000Fooooo`;o00001_ooool2
o`0001Oooooo0003ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05
ooooo`03o`000?oooooooooo00?ooooo0_l0000Qooooo`;o0000Boooool2o`0000Cooooo0_l0000<
ooooo`;o00005oooool2o`0001Gooooo0_l0001eooooo`;o00005oooool000?ooooo00Go410@oooo
oooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool2
o`00027ooooo0_l0000]ooooo`;o00008_ooool2o`0000?ooooo0_l0000:ooooo`;o00004?ooool2
o`0003Gooooo0_l0000]ooooo`;o0000<_ooool2o`0000oooooo0003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0EOoo
ool2o`0002Oooooo0_l0000:ooooo`;o00003?ooool2o`0000;ooooo0ol0000dooooo`;o00003ooo
ool2o`0001cooooo0ol0000aooooo`;o00003oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0kooooo`;o0000
Foooool2o`0000?ooooo0_l0000Mooooo`;o00009_ooool2o`0000;ooooo0_l0000Fooooo`Go0000
;Oooool2o`0001?ooooo000Nooooo`03o`000?oooooooooo03_ooooo0_l0001oooooo`;o0000:_oo
ool2o`00013ooooo0_l00004ooooo`Co0000:Oooool2o`0000?ooooo0_l0000Cooooo`007_ooool0
0ol0003oooooooooo`1kooooo`;o0000OOooool2o`0002?ooooo0_l0000<ooooo`;o00006?ooool0
01kooooo00?o0000ooooooooool02?ooool2o`0002_ooooo0_l00014ooooo`;o0000X_ooool2o`00
02Kooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0000;ooooo`;o00007_ooool2o`0001Oo
oooo0_l0000eooooo`;o0000`?ooool001kooooo00?o0000ooooooooool05Oooool2o`0003Oooooo
0_l0000cooooo`Ko0000__ooool001kooooo00?o0000ooooooooool0:_ooool2o`0002Sooooo0_l0
000]ooooo`;o00000_ooool2o`0004[ooooo0_l0000;ooooo`;o0000:Oooool2o`0000Oooooo0_l0
000aooooo`007_ooool00ol0003oooooooooo`0Zooooo`;o0000:?ooool2o`0007gooooo0_l0000;
ooooo`;o0000:Oooool2o`0000Oooooo0_l0000Mooooo`;o00004_ooool001kooooo00?o0000oooo
ooooool0@?ooool2o`0000cooooo0_l00020ooooo`;o0000HOooool2o`0001;ooooo000Nooooo`03
o`000?oooooooooo037ooooo0_l00009ooooo`;o00000_ooool2o`0000cooooo0_l0001Vooooo`;o
00006?ooool2o`00043ooooo0_l0000Vooooo`;o00002oooool001kooooo00?o0000ooooooooool0
<Oooool2o`0000Wooooo0_l0001hooooo`;o00007Oooool2o`0001?ooooo0ol000000ooooooo0000
o`00000Rooooo`;o00009_ooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo0=Gooooo0_l0
000Cooooo`?o000000?oooooo`000?l00000Eoooool001kooooo0_l0000mooooo`;o00005Oooool2
o`0003;ooooo0_l00005ooooo`;o0000K?ooool2o`0004Wooooo000Nooooo`03o`000?oooooooooo
03cooooo0_l0000Eooooo`;o0000<_ooool2o`0000Gooooo0_l00005ooooo`;o0000IOooool2o`00
04Wooooo000Nooooo`03o`000?oooooooooo08Oooooo1?l00003ooooo`;o00001Oooool2o`000;3o
oooo000Nooooo`03o`000?oooooooooo00_ooooo0_l0001:ooooo`;o0000<?ooool2o`0000?ooooo
0_l0000Booooo`;o0000A_ooool2o`0000Wooooo0_l00008ooooo`;o0000A_ooool001kooooo00?o
0000ooooooooool00_l00009ooooo`;o0000;oooool2o`0001Wooooo0_l00019ooooo`;o0000A_oo
ool2o`0000Wooooo0_l00008ooooo`;o0000>Oooool2o`0000_ooooo000Nooooo`03o`000?oooooo
oooo00;o0000=?ooool2o`0000Cooooo0_l00017ooooo`;o0000Foooool2o`0005Kooooo0_l0000;
ooooo`007_ooool00ol0003oooooooooo`0fooooo`;o0000COooool2o`0000kooooo0_l0001;oooo
o`;o00007_ooool2o`0001Sooooo0_l0000Yooooo`007_ooool00ol0003oooooooooo`02o`0003Oo
oooo0_l0001Jooooo`;o0000Aoooool2o`0002;ooooo0_l0000>ooooo`;o00002?ooool2o`0002Wo
oooo000Nooooo`03o`000?oooooooooo00;o00002oooool2o`0002[ooooo0_l0000Looooo`;o0000
QOooool2o`0003;ooooo0_l0000Fooooo`;o00006oooool001kooooo00?o0000ooooooooool03Ooo
ool2o`0001[ooooo0_l0000Pooooo`?o00002Oooool2o`00017ooooo0_l0000dooooo`;o00009_oo
ool2o`00063ooooo0_l0000Kooooo`007_ooool00ol0003oooooooooo`0Yooooo`;o00008?ooool3
o`0001cooooo0_l0000Vooooo`;o00003?ooool2o`0002;ooooo0_l00002ooooo`;o0000GOooool2
o`0001kooooo000Nooooo`03o`000?oooooooooo09;ooooo0_l0000`ooooo`;o00007oooool2o`00
043ooooo0_l0000Nooooo`007_ooool00ol0003oooooooooo`0^ooooo`;o0000Coooool2o`0004?o
oooo0_l0000Oooooo`;o00006Oooool2o`0001cooooo0_l0000?ooooo`;o00005_ooool001kooooo
00?o0000ooooooooool02oooool2o`00027ooooo0_l0001?ooooo`;o0000;Oooool2o`00053ooooo
0_l0000>ooooo`;o00003?ooool2o`0000oooooo0_l0000Fooooo`007_ooool00ol0003ooooooooo
o`0;ooooo`;o00001?ooool2o`0005gooooo0_l0000looooo`;o00006oooool2o`0004?ooooo0_l0
000eooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o0000;_ooool2o`0001[ooooo0_l0000A
ooooo`;o0000FOooool2o`0003_ooooo0_l0000>ooooo`;o00009Oooool2o`0000Kooooo000Noooo
o`;o00002_ooool2o`0003Kooooo0_l0000Jooooo`;o0000?_ooool2o`0006Wooooo0_l0000>oooo
o`;o00004?ooool2o`0001?ooooo0_l00006ooooo`007_ooool00ol0003oooooooooo`09ooooo`;o
0000D_ooool2o`0003kooooo0_l0002;ooooo`;o00006oooool001kooooo00?o0000ooooooooool0
GOooool2o`0004Sooooo0_l00022ooooo`;o00001?ooool2o`0001Cooooo000Nooooo`03o`000?oo
oooooooo0:?ooooo0_l00002ooooo`;o0000<Oooool2o`0001gooooo0_l0000`ooooo`;o00001?oo
ool2o`0001Cooooo000Nooooo`03o`000?oooooooooo00oooooo0_l0001>ooooo`;o0000>oooool2
o`0000Gooooo0_l0000eooooo`;o00007Oooool2o`0002gooooo0_l0000Mooooo`007_ooool00ol0
003oooooooooo`0?ooooo`;o0000=oooool2o`0001Gooooo0_l0000kooooo`;o0000@oooool2o`00
04Gooooo0_l0000Mooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o00005oooool2o`0000[o
oooo0_l0001;ooooo`;o0000B_ooool2o`0006Cooooo000Nooooo`03o`000?oooooooooo02?ooooo
0_l0000:ooooo`;o00002oooool2o`0005Oooooo0_l00009ooooo`;o0000G?ooool2o`00037ooooo
0_l0000Dooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o00007_ooool2o`0006oooooo0_l0
001Looooo`;o00004?ooool2o`0000Kooooo0_l0000Gooooo`;o00005?ooool001kooooo00?o0000
ooooooooool03oooool2o`0002Kooooo0_l00003ooooo`;o0000b_ooool2o`0000Kooooo0_l00006
ooooo`;o0000;Oooool001kooooo00?o0000ooooooooool0=oooool2o`0000?ooooo0_l0001Toooo
o`;o0000@Oooool2o`0001_ooooo0_l00004ooooo`;o00008_ooool2o`0001Wooooo000Nooooo`03
o`000?oooooooooo0:;ooooo0_l00011ooooo`;o00006oooool2o`0002Sooooo0_l0000Iooooo`00
7_ooool00ol0003oooooooooo`1=ooooo`;o00002oooool2o`0000Gooooo0ol0000Rooooo`;o0000
_oooool001kooooo00?o0000ooooooooool0COooool2o`0000_ooooo0_l00005ooooo`?o00008_oo
ool2o`00037ooooo0_l0000Cooooo`;o00003?ooool2o`0005Sooooo0_l0000?ooooo`007_ooool0
0ol0003oooooooooo`0]ooooo`;o0000:_ooool2o`0001Oooooo0_l00015ooooo`;o00004oooool2
o`0000cooooo0_l0001Hooooo`;o00003oooool001kooooo00?o0000ooooooooool0;Oooool2o`00
02[ooooo0_l0000Gooooo`;o0000O_ooool2o`0001kooooo0_l0000Aooooo`;o00008?ooool001ko
oooo0_l0000Wooooo`;o0000]?ooool2o`0001Cooooo0_l0000Nooooo`;o00003oooool4o`00023o
oooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0000=ooooo`;o00002oooool2o`0003Oooooo
0_l0001Sooooo`;o00002Oooool2o`0004Gooooo0_l0000Rooooo`007_ooool00ol0003ooooooooo
o`0Gooooo`;o000000?oooooo`000?l000005oooool2o`0003Oooooo0_l0000looooo`;o00009Ooo
ool2o`0007Cooooo000Nooooo`03o`000?oooooooooo01[ooooo0_l0000<ooooo`;o0000P?ooool2
o`0009_ooooo000Nooooo`03o`000?oooooooooo02Sooooo0_l0000Oooooo`;o00008_ooool2o`00
04?ooooo1?l0002Aooooo`007_ooool01?l0003oooooo`000?l00018ooooo`;o00008_ooool2o`00
04?ooooo1?l0000kooooo`;o0000E?ooool001kooooo00Co0000ooooool0003o00007Oooool2o`00
0=7ooooo0_l0000@ooooo`;o0000:Oooool2o`0001Oooooo000Nooooo`03o`000?oooooooooo01ko
oooo1?l0000Iooooo`;o00003Oooool2o`0002gooooo0_l00028ooooo`;o0000:Oooool2o`0001Oo
oooo000Nooooo`03o`000?oooooooooo023ooooo0_l0000Iooooo`;o00003Oooool2o`0002gooooo
0_l0000^ooooo`;o0000>Oooool2o`00067ooooo000Nooooo`03o`000?oooooooooo027ooooo0_l0
0019ooooo`;o0000=?ooool2o`0000Gooooo0_l0000Booooo`;o00009Oooool2o`00067ooooo000N
ooooo`03o`000?oooooooooo027ooooo0_l0000Iooooo`;o00000oooool2o`0002Wooooo0_l0000d
ooooo`;o00004?ooool2o`0000Oooooo0_l0000Eooooo`;o0000Joooool2o`0000Cooooo000Noooo
o`03o`000?oooooooooo017ooooo0_l0000Wooooo`Co00000oooool2o`0005oooooo0_l0000@oooo
o`;o00007_ooool2o`0006_ooooo0_l00004ooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o
00009oooool2o`0000Oooooo0_l0001Mooooo`;o00008_ooool2o`00053ooooo0_l0000]ooooo`00
7_ooool00ol0003oooooooooo`0Hooooo`;o0000:Oooool2o`0006Sooooo0_l0000>ooooo`;o0000
1oooool2o`00053ooooo0_l0000]ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0>ooooo`;o0000
2?ooool2o`0006_ooooo0_l0000Vooooo`;o00003_ooool2o`0000cooooo0_l0000Booooo`;o0000
I_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00kooooo0_l0001eooooo`;o00003oooool2o`0003?ooooo
0_l0000Booooo`;o00001oooool2o`0005gooooo0003ooooo`05oa0@4?ooooooooooooooool@4100
2oooool5o`0000Kooooo0ol0002Fooooo`;o0000@?ooool2o`0000kooooo0_l0001Mooooo`000ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`04ooooo`;o0000?_ooool2o`0009;ooooo0_l00012ooooo`;o0000:Oooool000?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000oooo
ooooool01?ooool2o`0003cooooo1?l0003Fooooo`;o0000:Oooool000?ooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0@_ooool2o`00
0=Gooooo0_l0000/ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4
A?l000001oooool01?l0003oooooo`000?l0002Yooooo`;o0000KOooool2o`0001Gooooo0_l0000E
ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool0
0ol0003oooooo`000003o`0002gooooo0_l00010ooooo`;o0000=_ooool2o`0008Cooooo0_l0000E
ooooo`007_ooool01?l0003oooooooooooooool2o`0002[ooooo0_l000000ooooooo0000o`000010
ooooo`Co00004?ooool2o`0008Cooooo0_l0000iooooo`007_ooool00ol0003oooooooooo`09oooo
o`;o00008_ooool2o`0004Gooooo0_l0000<ooooo`;o00000_ooool2o`0004Sooooo0_l0000joooo
o`;o00001oooool2o`0001;ooooo0_l0000Looooo`007_ooool00ol0003oooooooooo`09ooooo`;o
0000>_ooool2o`0003_ooooo0_l0000Zooooo`;o00008?ooool2o`0001Gooooo0_l0000/ooooo`;o
00004_ooool2o`0001cooooo000Nooooo`03o`000?oooooooooo02kooooo0_l0000Eooooo`;o0000
4oooool2o`0001_ooooo0_l0000_ooooo`;o00001?ooool4o`0003Gooooo0_l0000Fooooo`;o0000
A_ooool001kooooo00?o0000ooooooooool00_l00008ooooo`;o00008_ooool2o`0002[ooooo0_l0
000Iooooo`Co0000;oooool2o`0000Kooooo0_l0001=ooooo`;o00007oooool2o`0000Gooooo0_l0
000Nooooo`007_ooool00ol0003oooooooooo`02o`0000Sooooo0_l0000@ooooo`;o000000?ooooo
o`000?l00000E?ooool2o`0002_ooooo0_l0001looooo`Co00000oooool2o`0001kooooo000Noooo
o`03o`000?oooooooooo00;ooooo1?l0000Fooooo`;o000000?oooooo`000?l000001?ooool3o`00
02Gooooo0_l00016ooooo`;o00002oooool2o`0007kooooo0_l0000Sooooo`007_ooool00ol0003o
ooooooooo`02ooooo`Co00000_ooool2o`0001_ooooo0ol0000Uooooo`;o0000A_ooool2o`0002oo
oooo0_l0001oooooo`007_ooool00ol0003oooooooooo`06ooooo`Co00001Oooool2o`00067ooooo
0_l0000Aooooo`;o0000:Oooool2o`0001Cooooo0_l0001oooooo`007_ooool00ol0003ooooooooo
o`06ooooo`;o00001oooool2o`00067ooooo0_l0000Aooooo`;o0000:Oooool2o`0007Cooooo0_l0
000Oooooo`007_ooool00ol0003oooooooooo`2looooo`;o0000J?ooool2o`0001oooooo000Noooo
o`;o00007?ooool2o`0006;ooooo0_l0000kooooo`;o0000ROooool001kooooo00?o0000oooooooo
ool06oooool2o`0006;ooooo0_l0000Uooooo`;o00000oooool2o`0009[ooooo000Mooooo`;o0000
1_ooool2o`0008Oooooo0_l0000Gooooo`;o00000oooool2o`0000Sooooo0_l0002@ooooo`007Ooo
ool2o`0000Kooooo0_l0001cooooo`;o00004_ooool2o`0002Kooooo0_l0000looooo`;o0000@ooo
ool2o`0000gooooo000Nooooo`03o`000?oooooooooo03Sooooo0_l00007ooooo`;o0000;_ooool2
o`0000Kooooo0_l0001hooooo`;o0000@oooool2o`0000gooooo000Nooooo`03o`000?oooooooooo
03Cooooo0_l00002ooooo`;o00001oooool2o`0001Cooooo0ol0000Gooooo`;o00006?ooool2o`00
09Sooooo0_l0000Pooooo`007_ooool00ol0003oooooooooo`0dooooo`;o00004_ooool2o`0000go
oooo0ol0000aooooo`;o0000Foooool2o`0003Gooooo0_l00004ooooo`;o00008?ooool001kooooo
00?o0000ooooooooool0B?ooool2o`0003_ooooo0_l0001Qooooo`;o0000=Oooool2o`0002Kooooo
000Nooooo`03o`000?oooooooooo08Gooooo0_l0000Rooooo`;o00005_ooool2o`0004;ooooo0_l0
0010ooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o0000COooool2o`0004Oooooo0_l0000F
ooooo`;o0000?oooool2o`000003ooooool0003o000001Cooooo0_l0000Zooooo`007_ooool00ol0
003oooooooooo`0Aooooo`;o0000COooool2o`0000?ooooo0_l0000Zooooo`;o0000<_ooool2o`00
03_ooooo0_l0000Gooooo`;o0000:_ooool001kooooo00?o0000ooooooooool0IOooool2o`0002[o
oooo0_l0000booooo`;o00008Oooool2o`0003oooooo0_l0000Looooo`007_ooool00ol0003ooooo
ooooo`2iooooo`;o0000;Oooool2o`0003oooooo0_l0000Looooo`007_ooool00ol0003ooooooooo
o`0jooooo`;o0000A?ooool2o`0001Oooooo0_l0000Nooooo`;o00003_ooool2o`0004Oooooo0_l0
000cooooo`007_ooool00ol0003oooooooooo`0Nooooo`;o00006_ooool2o`0004Cooooo0_l0000G
ooooo`;o0000;_ooool2o`0001;ooooo0_l0000Kooooo`;o00003Oooool2o`0000Oooooo0_l0000c
ooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o00002oooool2o`0003;ooooo0_l00029oooo
o`;o00006oooool2o`0000gooooo0_l0000@ooooo`;o0000:_ooool001kooooo0_l0000Booooo`;o
0000?oooool2o`000;Kooooo0_l0000?ooooo`Co0000:?ooool001kooooo00?o0000ooooooooool0
ooooool;ooooo`;o00004Oooool2o`0002Sooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l0
001dooooo`;o0000]_ooool001kooooo00?o0000ooooooooool06Oooool2o`0004?ooooo0_l0000G
ooooo`;o00005_ooool2o`000;Kooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l0000hoooo
o`;o00005oooool2o`0000;ooooo0_l0000Booooo`;o0000K_ooool2o`0001?ooooo0_l0000aoooo
o`007_ooool00ol0003oooooooooo`0Tooooo`;o0000EOooool2o`0001;ooooo0_l0000Qooooo`?o
0000@?ooool2o`0000Sooooo0_l0000Aooooo`Co0000<Oooool001kooooo00?o0000ooooooooool0
4Oooool2o`0009oooooo0ol00005ooooo`;o0000;_ooool2o`0000Wooooo0_l0000Kooooo`;o0000
<oooool001kooooo00?o0000ooooooooool04Oooool2o`000:Oooooo0_l0000^ooooo`;o00004Ooo
ool2o`0001[ooooo0_l0000/ooooo`007_ooool00ol0003oooooooooo`2oooooo`;o00002oooool2
o`0002oooooo0_l0000Jooooo`;o0000;?ooool001kooooo00Co0000ooooool0003o0000K?ooool2
o`00053ooooo0_l0000;ooooo`;o00002?ooool2o`0001Oooooo0_l0001Fooooo`007_ooool01?l0
003oooooo`000?l0000Pooooo`;o0000B_ooool2o`0006Oooooo0_l0000Gooooo`;o0000E_ooool0
01kooooo00?o0000ooooooooool02_ooool2o`0000cooooo0_l00007ooooo`;o0000oooooolUoooo
o`007_ooool00ol0003oooooooooo`0:ooooo`;o00003?ooool2o`00097ooooo0_l0000=ooooo`;o
0000Roooool001kooooo00?o0000ooooooooool0FOooool2o`00053ooooo0_l0000=ooooo`;o0000
1?ooool2o`00057ooooo0_l00009ooooo`;o00007?ooool2o`0000Wooooo000Nooooo`03o`000?oo
oooooooo05Wooooo0_l0001Uooooo`;o00004?ooool2o`0003oooooo0_l00009ooooo`;o00007?oo
ool2o`0000Wooooo000Nooooo`03o`000?oooooooooo03Kooooo0_l0000:ooooo`;o00001Oooool2
o`0008Oooooo0_l00006ooooo`;o00008_ooool2o`000003ooooool0003o000001_ooooo0_l0000O
ooooo`;o00001_ooool001kooooo0_l0000gooooo`;o00002_ooool2o`0000Gooooo0_l00013oooo
o`;o0000<Oooool2o`0001Oooooo0_l000000ooooooo0000o`00000Oooooo`;o000000?oooooo`00
0?l000006oooool2o`0000Wooooo0_l0000Dooooo`;o00001_ooool001kooooo00?o0000oooooooo
ool0:Oooool2o`0000kooooo0_l0000Iooooo`;o00004_ooool2o`0002Cooooo0_l0000aooooo`;o
00006_ooool2o`0004[ooooo0_l0000Looooo`007_ooool00ol0003oooooooooo`0Yooooo`;o0000
1oooool2o`0000Gooooo0_l0000Iooooo`;o00004_ooool2o`000<3ooooo0_l0000Kooooo`007_oo
ool00ol0003oooooooooo`0Yooooo`;o00001Oooool4o`0008Gooooo0_l0000Looooo`;o0000DOoo
ool2o`0000Cooooo0_l0000Eooooo`007_ooool00ol0003oooooooooo`0`ooooo`;o00006oooool2
o`0001[ooooo0_l0001>ooooo`;o00007?ooool2o`0005Oooooo0_l0000Eooooo`007_ooool00ol0
003oooooooooo`1=ooooo`;o00006_ooool2o`0000Cooooo0_l00027ooooo`;o00003_ooool2o`00
00;ooooo0_l0000iooooo`007_ooool00ol0003oooooooooo`1_ooooo`;o00003Oooool2o`00023o
oooo0_l0001Fooooo`;o00003_ooool2o`0000;ooooo0_l0000iooooo`007_ooool00ol0003ooooo
ooooo`0Sooooo`;o0000FOooool2o`00023ooooo0_l0000:ooooo`;o00002?ooool2o`00027ooooo
0_l00009ooooo`;o0000HOooool001kooooo00?o0000ooooooooool08oooool2o`0008Oooooo0_l0
0008ooooo`;o00003?ooool2o`0001?ooooo0_l00009ooooo`;o00004Oooool2o`0004kooooo000N
ooooo`04o`000?oooooo0000o`00057ooooo0_l0001`ooooo`;o0000<Oooool2o`0001cooooo0_l0
000`ooooo`007_ooool01?l0003oooooo`000?l0000@ooooo`;o0000?oooool2o`0002oooooo0_l0
000=ooooo`;o0000Doooool2o`0002cooooo0_l0000`ooooo`007_ooool00ol0003oooooooooo`0=
ooooo`;o00000_ooool2o`0001cooooo0_l0000Rooooo`;o0000;_ooool2o`0000gooooo0_l0000D
ooooo`;o0000:oooool2o`00013ooooo0_l0000Booooo`;o0000B_ooool001kooooo00?o0000oooo
ooooool03Oooool2o`00023ooooo0_l0000Rooooo`;o00003_ooool2o`0004?ooooo0_l0000[oooo
o`;o00009?ooool2o`0002gooooo0_l0000Kooooo`007_ooool00ol0003oooooooooo`1Sooooo`;o
0000<?ooool2o`0001Kooooo0_l0001Gooooo`;o00008_ooool2o`0001_ooooo0003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006oooo
o`03o`000?oooooooooo05Gooooo0_l00006ooooo`Co00001oooool2o`0000gooooo0_l0000Loooo
o`;o00005_ooool2o`0004gooooo0_l00008ooooo`;o0000?oooool000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000
ooooooooool0EOooool2o`0000Kooooo1?l00007ooooo`;o00002oooool4o`0003_ooooo0ol0000E
ooooo`;o0000;_ooool2o`0004Wooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool0
1Ol0003ooooooooooooooooo000000Kooooo0ol0001eooooo`;o0000?Oooool3o`0001Gooooo0_l0
000Qooooo`;o0000E_ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`3Xooooo`;o00001?ooool3o`0001oooooo
0_l0000eooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o
410@olc<c006ooooo`03o`000?oooooooooo09Oooooo0_l0001?ooooo`;o00001?ooool2o`00023o
oooo0_l0000eooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qooo
ool02?ooool00ol0003oooooooooo`09ooooo`;o00008oooool2o`0006Oooooo0_l0002^ooooo`00
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003o
ooooooooo`09ooooo`;o00008oooool2o`0006_ooooo0_l0000Wooooo`;o00001_ooool2o`0004So
oooo0_l0000=ooooo`;o00008?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04
olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0O?ooool2o`0001gooooo0_l0000Woooo
o`;o00001_ooool2o`0000gooooo0_l0000iooooo`;o00003Oooool2o`00023ooooo000Nooooo`;o
0000E_ooool2o`0002Gooooo0_l00008ooooo`;o0000Doooool2o`0006[ooooo000Nooooo`;o0000
E_ooool2o`0002oooooo0ol00002ooooo`;o0000^_ooool001kooooo00?o0000ooooooooool06_oo
ool3o`0001oooooo0_l00019ooooo`;o00000_ooool2o`000;[ooooo000Nooooo`03o`000?oooooo
oooo01[ooooo0ol0000Oooooo`;o0000F_ooool2o`0001?ooooo0_l0001Xooooo`;o0000;_ooool0
01kooooo00?o0000ooooooooool08?ooool2o`0002cooooo0_l00018ooooo`;o00004oooool2o`00
013ooooo0_l0001Fooooo`;o00000_ooool2o`0002[ooooo000Nooooo`03o`000?oooooooooo023o
oooo0_l0000/ooooo`;o0000Koooool2o`0000[ooooo0_l0000oooooo`;o00003Oooool2o`0002?o
oooo0_l00005ooooo`007_ooool00ol0003oooooooooo`24ooooo`;o0000AOooool2o`0003oooooo
0_l0000booooo`;o00001Oooool001kooooo00?o0000ooooooooool0Q?ooool2o`000<7ooooo000N
ooooo`03o`000?oooooooooo04Cooooo0_l0001Nooooo`;o00003?ooool2o`0008Sooooo0_l00009
ooooo`007_ooool00ol0003oooooooooo`0^ooooo`;o00005?ooool2o`0005kooooo0_l0000<oooo
o`;o0000;_ooool2o`0005Sooooo0_l00009ooooo`007_ooool01?l0003oooooooooooooool2o`00
02_ooooo0_l0002booooo`;o00003oooool2o`0003Cooooo0_l0000:ooooo`;o00004?ooool001ko
oooo0_l00002ooooo`;o0000G?ooool2o`0009;ooooo0_l0000dooooo`;o00002Oooool3o`00013o
oooo000Nooooo`03o`000?oooooooooo05oooooo0_l0003<ooooo`;o00001Oooool2o`00017ooooo
000Nooooo`03o`000?oooooooooo03Kooooo0_l0000Booooo`;o0000foooool2o`0000Cooooo0_l0
000Hooooo`007_ooool00ol0003oooooooooo`0fooooo`;o00004_ooool2o`0005gooooo0_l0000:
ooooo`;o0000L?ooool2o`0001kooooo000Nooooo`03o`000?oooooooooo0:Wooooo0_l0000:oooo
o`;o0000T?ooool001kooooo00?o0000ooooooooool04?ooool2o`000?oooooo8oooool2o`00017o
oooo000Nooooo`03o`000?oooooooooo013ooooo0_l0000:ooooo`;o00000oooool2o`0005Cooooo
0_l0001mooooo`;o00003oooool2o`0002?ooooo0_l00006ooooo`;o00004Oooool001kooooo00?o
0000ooooooooool06oooool3o`0000?ooooo0_l00012ooooo`;o00004?ooool2o`0000cooooo0_l0
000Fooooo`;o00005_ooool2o`0003oooooo0_l0000?ooooo`;o00005oooool2o`0000[ooooo0_l0
000Iooooo`007_ooool00ol0003oooooooooo`06ooooo`;o00004oooool2o`0003[ooooo0_l0000<
ooooo`;o00007_ooool2o`0001Kooooo0_l0000Fooooo`;o000000?oooooo`000?l00000@Oooool2
o`0002?ooooo0_l0000Uooooo`007_ooool00ol0003oooooooooo`06ooooo`;o00005_ooool2o`00
03Oooooo0_l0000/ooooo`;o0000<Oooool2o`0003_ooooo0_l00004ooooo`;o0000B_ooool001ko
oooo00?o0000ooooooooool07_ooool2o`0006Wooooo0_l0001Fooooo`;o00003_ooool2o`0000;o
oooo0_l0001@ooooo`007_ooool00ol0003oooooooooo`29ooooo`;o00005oooool2o`0003gooooo
0_l0000>ooooo`;o0000E?ooool001kooooo00?o0000ooooooooool0X_ooool2o`0005Kooooo0_l0
001;ooooo`007_ooool00ol0003oooooooooo`3jooooo`;o0000Boooool001kooooo00?o0000oooo
ooooool0WOooool2o`0001gooooo0_l00029ooooo`007_ooool00ol0003oooooooooo`1Booooo`;o
0000BOooool2o`0001gooooo0_l00029ooooo`007_ooool2o`0000gooooo0_l0000Gooooo`;o0000
8Oooool2o`0000Sooooo0_l00003ooooo`;o00001_ooool2o`0009Gooooo0_l0001?ooooo`007_oo
ool00ol0003oooooooooo`0<ooooo`?o00003?ooool2o`0000Sooooo0_l0000Qooooo`;o00003Ooo
ool2o`0000Kooooo0_l0000Eooooo`;o0000>oooool2o`00047ooooo0_l0000oooooo`;o00003_oo
ool001kooooo00?o0000ooooooooool03Oooool2o`0000cooooo0_l0001Iooooo`;o0000>oooool2
o`0001_ooooo0_l00006ooooo`;o00002oooool2o`0003?ooooo0_l0000Kooooo`;o00003_ooool0
01kooooo00?o0000ooooooooool0d?ooool2o`0000Kooooo0_l0000;ooooo`;o00002?ooool2o`00
00;ooooo0_l0000Uooooo`;o0000:oooool001kooooo00?o0000ooooooooool0C?ooool2o`000:7o
oooo0_l00002ooooo`;o0000D_ooool001kooooo00?o0000ooooooooool05_ooool2o`0001Cooooo
0_l0000Nooooo`;o0000nOooool001kooooo00?o0000ooooooooool05_ooool2o`0000oooooo0_l0
0003ooooo`;o0000L?ooool2o`0005;ooooo0_l0001Cooooo`007_ooool00ol0003oooooooooo`0M
ooooo`;o00002?ooool2o`0001[ooooo0_l0000?ooooo`;o00001oooool2o`0000gooooo0_l0000`
ooooo`;o00002?ooool2o`0004Sooooo0_l0000eooooo`;o00007?ooool001kooooo00?o0000oooo
ooooool04Oooool2o`0000[ooooo0_l0000Tooooo`;o00003oooool2o`0000Cooooo0_l000000ooo
oooo0000o`00000=ooooo`;o0000>_ooool2o`0001kooooo0_l0001Oooooo`;o00007?ooool001ko
oooo00?o0000ooooooooool04Oooool2o`00043ooooo0_l00005ooooo`;o0000J?ooool2o`0000;o
oooo0_l0000eooooo`;o0000A_ooool001kooooo00?o0000ooooooooool0Doooool2o`0006oooooo
0_l0000iooooo`;o00009?ooool2o`00023ooooo000Nooooo`03o`000?oooooooooo0?oooooo9_oo
ool2o`00023ooooo000Nooooo`03o`000?oooooooooo0;Oooooo0_l0000Looooo`;o0000L?ooool0
01kooooo00?o0000ooooooooool0Qoooool2o`0002kooooo0_l0000Hooooo`;o00000_ooool2o`00
02Oooooo0_l0000mooooo`;o00002?ooool001kooooo00?o0000ooooooooool0Qoooool2o`0001ko
oooo0_l0000Xooooo`;o0000:oooool2o`0003gooooo0_l00008ooooo`007_ooool00ol0003ooooo
ooooo`0Eooooo`;o0000T?ooool2o`0009kooooo000Nooooo`;o000000?oooooo`000?l000004ooo
ool2o`000;Sooooo0_l0001Wooooo`;o00003Oooool001kooooo00?o0000ooooooooool00_l0003=
ooooo`;o0000??ooool2o`0002Wooooo0_l00004ooooo`;o00001oooool001kooooo00?o0000oooo
ooooool03?ooool2o`0007gooooo0_l0000Mooooo`Co00007?ooool2o`0001oooooo0_l0000Poooo
o`;o00006_ooool2o`0001?ooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o
0000OOooool2o`0001gooooo1?l0000Looooo`;o00004?ooool2o`0000gooooo0_l0000looooo`;o
00007?ooool001kooooo00?o0000ooooooooool0Koooool2o`0005Oooooo0_l0000Booooo`;o0000
0_ooool2o`0006Gooooo000Nooooo`03o`000?oooooooooo06oooooo0_l00004ooooo`;o0000DOoo
ool2o`0001Kooooo0_l0000Eooooo`;o00000_ooool2o`0004[ooooo000Nooooo`03o`000?oooooo
oooo07Gooooo0_l0000[ooooo`;o00000_ooool2o`0004Wooooo0_l00004ooooo`;o00000_ooool2
o`0002[ooooo0_l0000Nooooo`007_ooool00ol0003oooooooooo`26ooooo`;o00006_ooool2o`00
00;ooooo0_l00019ooooo`;o00004_ooool2o`0000kooooo0_l0000@ooooo`;o00002oooool2o`00
017ooooo000Nooooo`03o`000?oooooooooo08Kooooo0_l00017ooooo`;o00009?ooool2o`0000ko
oooo0_l00003ooooo`;o00002Oooool2o`0001gooooo0_l0000Aooooo`007_ooool00ol0003ooooo
ooooo`1oooooo`;o0000;?ooool2o`00023ooooo0_l0000Tooooo`;o00004oooool2o`0002kooooo
0_l0000;ooooo`007_ooool00ol0003oooooooooo`1Zooooo`;o00004oooool2o`0002cooooo0_l0
000Fooooo`;o00005_ooool2o`0000[ooooo0_l0001?ooooo`;o00002oooool001kooooo00?o0000
ooooooooool0G_ooool2o`0000[ooooo0_l0000Nooooo`;o0000<oooool2o`0000Cooooo0_l0000F
ooooo`;o00002?ooool4o`0002cooooo0_l0000^ooooo`007_ooool00ol0003oooooooooo`1Noooo
o`;o0000:_ooool2o`0003?ooooo0_l0000Vooooo`;o0000;_ooool2o`0002kooooo000Nooooo`03
o`000?oooooooooo06kooooo0_l0003Gooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0Yoooo
o`;o0000@oooool2o`0002Kooooo0_l00010ooooo`;o0000Coooool2o`0000gooooo0_l0000=oooo
o`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B401_ooool00ol0003oooooooooo`0Yooooo`;o0000Joooool2o`0000gooooo0_l0000a
ooooo`;o0000Coooool2o`0000gooooo0_l0000=ooooo`000oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000YOooool2o`000:3ooooo0003
ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo
00?o0000ooooooooool03Oooool2o`000=;ooooo1?l0001Rooooo`000oooool01Ol0003ooooooooo
oooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo00Co
oooo0_l00007ooooo`;o00004oooool2o`0001;ooooo0_l0001Fooooo`;o0000DOooool4o`0006;o
oooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@
00Kooooo00?o0000ooooooooool01?ooool2o`0001cooooo0_l0000Booooo`;o0000E_ooool2o`00
07_ooooo0_l0000jooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo05kooooo0_l0002[ooooo`;o0000>_ooool0
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_oo
ool00ol0003oooooooooo`0Pooooo`;o00000oooool2o`0000_ooooo0_l0000Zooooo`;o00008ooo
ool2o`0002Gooooo0_l0001iooooo`;o00008?ooool001kooooo0ol0000Pooooo`;o00000oooool2
o`0000_ooooo0_l0000booooo`;o00006oooool2o`0002Gooooo0_l0000:ooooo`;o0000KOooool2
o`00023ooooo000Nooooo`?o0000Goooool2o`0000Gooooo0_l0001>ooooo`;o00007?ooool2o`00
023ooooo0_l0000hooooo`;o00005Oooool001kooooo00?o0000ooooooooool0Goooool2o`0007?o
oooo0_l0000Pooooo`;o00006oooool2o`0000_ooooo0_l0000>ooooo`;o00005Oooool001kooooo
00?o0000ooooooooool05?ooool2o`0008Sooooo0_l0000kooooo`;o0000=_ooool2o`0000_ooooo
0_l0000Uooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o0000R?ooool2o`00027ooooo0_l0
000Hooooo`;o0000J_ooool001kooooo00?o0000ooooooooool0K_ooool2o`0003_ooooo0_l0000D
ooooo`;o0000Q?ooool001kooooo00?o0000ooooooooool0K_ooool2o`0003_ooooo0_l00018oooo
o`;o00000oooool2o`0004_ooooo000Nooooo`03o`000?oooooooooo09[ooooo0_l0001>ooooo`;o
00002Oooool2o`0000?ooooo0_l00003ooooo`Go0000@oooool001kooooo00?o0000ooooooooool0
4oooool2o`0002cooooo0_l0001?ooooo`;o00001_ooool2o`0004gooooo0ol0000Cooooo`Go0000
@oooool001kooooo00?o0000ooooooooool04oooool2o`0000[ooooo0_l0000Pooooo`;o0000Cooo
ool2o`0005Gooooo0_l00015ooooo`;o00005Oooool001kooooo00?o0000ooooooooool07oooool2
o`000?oooooo4?ooool2o`0001Gooooo000Nooooo`;o0000Voooool2o`0005;ooooo0_l0000Eoooo
o`;o0000@?ooool001kooooo00?o0000ooooooooool07_ooool2o`0003Kooooo0_l00012ooooo`;o
0000D_ooool2o`000003ooooool0003o000001;ooooo0_l00010ooooo`007_ooool00ol0003ooooo
ooooo`0Nooooo`;o00001oooool2o`0002gooooo0_l0001Tooooo`;o0000<oooool2o`0005Cooooo
000Nooooo`03o`000?oooooooooo02Oooooo0_l0000Mooooo`;o0000L_ooool4o`0001gooooo0_l0
001Dooooo`;o00001oooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo04Kooooo0_l0000>
ooooo`;o0000H_ooool2o`0000Gooooo0_l0000Hooooo`;o0000E?ooool2o`0000Oooooo0_l0000;
ooooo`007_ooool00ol0003oooooooooo`13ooooo`;o00004Oooool2o`0004Gooooo0_l00003oooo
o`;o00007Oooool2o`0006Cooooo0_l0000Nooooo`007_ooool00ol0003oooooooooo`13ooooo`;o
00008?ooool2o`0000?ooooo0_l0000aooooo`;o00000oooool2o`00013ooooo0_l0001aooooo`;o
00007_ooool001kooooo00?o0000ooooooooool06_ooool2o`0004Wooooo0_l00003ooooo`;o0000
5oooool2o`0002oooooo0_l00029ooooo`;o00001_ooool001kooooo00?o0000ooooooooool06_oo
ool2o`0006Oooooo0_l0001jooooo`;o00004?ooool2o`0002cooooo0_l00006ooooo`007_ooool0
0ol0003oooooooooo`1Kooooo`;o0000H?ooool2o`0002Kooooo0_l0000Hooooo`;o00003Oooool2
o`000003ooooool0003o000003Cooooo000Nooooo`03o`000?oooooooooo053ooooo0_l00009oooo
o`;o00002?ooool2o`0002Cooooo0_l0000>ooooo`;o00008?ooool2o`0002Kooooo0_l0000Ooooo
o`;o00001_ooool2o`0003Oooooo000Nooooo`03o`000?oooooooooo053ooooo0_l0000Cooooo`;o
00009?ooool2o`0000kooooo0_l0000cooooo`;o00000oooool2o`0002oooooo0_l0000oooooo`00
7_ooool00ol0003oooooooooo`07ooooo`;o00004oooool2o`0007;ooooo0_l0000cooooo`;o0000
1oooool4o`0000?ooooo0_l0000Tooooo`;o0000B_ooool001kooooo00?o0000ooooooooool01ooo
ool2o`0001?ooooo0_l0000kooooo`;o00000_ooool2o`0002kooooo0_l000000ooooooo0000o`00
000cooooo`;o00001oooool2o`0002_ooooo0_l0001:ooooo`007_ooool00ol0003oooooooooo`1I
ooooo`;o00000_ooool2o`0002[ooooo0_l00002ooooo`;o00009Oooool2o`00097ooooo000Noooo
o`03o`000?oooooooooo08Sooooo0ol0000Yooooo`;o0000TOooool001kooooo0_l00017ooooo`;o
0000@?ooool2o`0008;ooooo0_l0000iooooo`007_ooool01?l0003oooooo`000?l00014ooooo`?o
0000a?ooool2o`0000gooooo0_l0000Zooooo`007_ooool01?l0003oooooo`000?l0000Oooooo`;o
00008oooool2o`000=Cooooo0_l00006ooooo`;o00004_ooool2o`0000kooooo000Nooooo`03o`00
0?oooooooooo023ooooo0_l00004ooooo`?o000000?oooooo`000?l000002Oooool2o`0004kooooo
0_l0000iooooo`;o00001_ooool2o`0005Gooooo1_l0000Booooo`;o00001?ooool2o`0000Sooooo
000Nooooo`03o`000?oooooooooo01Kooooo0_l0000>ooooo`?o000000?oooooo`000?l000002Ooo
ool2o`0002;ooooo0_l0000Zooooo`;o0000>Oooool2o`0000Kooooo0_l0000Oooooo`;o00003_oo
ool2o`0002Cooooo1?l0000Jooooo`;o00002?ooool001kooooo00?o0000ooooooooool05_ooool2
o`00047ooooo0ol0000=ooooo`;o0000;?ooool4o`0004Kooooo0_l00006ooooo`;o00003_ooool2
o`0004cooooo000Mooooo`;o0000G?ooool2o`0000gooooo0ol0000[ooooo`Co00006Oooool2o`00
02_ooooo0_l0001Tooooo`007Oooool2o`0003kooooo0_l0000Jooooo`;o00004?ooool2o`00013o
oooo0_l0000fooooo`;o00007oooool2o`0002;ooooo0_l0001<ooooo`007_ooool00ol0003ooooo
ooooo`0Fooooo`;o00000oooool2o`0001oooooo0_l0000Jooooo`;o00008_ooool2o`0005Oooooo
0_l0000Rooooo`;o0000C?ooool001kooooo00?o0000ooooooooool01Oooool2o`0000oooooo0_l0
0003ooooo`;o0000<oooool2o`0007Kooooo0_l0001mooooo`007_ooool00ol0003oooooooooo`05
ooooo`;o00003_ooool2o`0003Wooooo0_l0001fooooo`;o0000J?ooool2o`0001?ooooo000Noooo
o`03o`000?oooooooooo00Oooooo0_l0000<ooooo`;o0000]Oooool2o`0000[ooooo0_l0001Hoooo
o`;o00004oooool001kooooo00?o0000ooooooooool01oooool2o`0000Wooooo0_l0001Jooooo`;o
0000G?ooool2o`0000[ooooo0_l0000Cooooo`;o0000F?ooool001kooooo00?o0000ooooooooool0
1oooool2o`0000Wooooo0_l0001Jooooo`;o0000OOooool2o`0002cooooo0_l0000Zooooo`007_oo
ool00ol0003oooooooooo`2Fooooo`;o0000Poooool2o`0000Gooooo0_l00003ooooo`;o00007_oo
ool001kooooo00?o0000ooooooooool0U_ooool2o`0008[ooooo0_l00003ooooo`;o00007_ooool0
01kooooo0_l0001=ooooo`;o0000nOooool001kooooo0_l0001=ooooo`;o0000G?ooool2o`0002go
oooo0_l00007ooooo`;o0000Hoooool001kooooo00?o0000ooooooooool0X_ooool2o`0000Kooooo
0_l0000]ooooo`;o00001oooool2o`0006?ooooo000Nooooo`?o0000Goooool2o`00047ooooo0_l0
002Sooooo`007_ooool3o`00017ooooo0_l0001<ooooo`;o0000@_ooool2o`0000Cooooo0_l00000
0ooooooo0000o`000027ooooo`;o00004?ooool001kooooo00?o0000ooooooooool01_ooool2o`00
00Wooooo0_l0002@ooooo`;o00001?ooool2o`000003ooooool0003o000008Oooooo0_l0000@oooo
o`007_ooool00ol0003oooooooooo`06ooooo`;o0000<_ooool2o`000<Kooooo0_l0000Sooooo`;o
00007_ooool001kooooo00Co0000ooooool0003o0000>Oooool2o`000<Kooooo0_l0000Sooooo`;o
00007_ooool001kooooo00Co0000ooooool0003o0000R?ooool2o`0003Gooooo0_l0001Kooooo`;o
00004oooool2o`0001?ooooo000Nooooo`03o`000?oooooooooo01gooooo0_l0000Oooooo`;o0000
BOooool2o`0003Gooooo0_l0000;ooooo`;o00003Oooool2o`0003oooooo0_l0000Cooooo`;o0000
4oooool001kooooo00?o0000ooooooooool06?ooool4o`000003ooooool0003o000001Cooooo0_l0
00000ooooooo0000o`000006ooooo`;o00009Oooool2o`00027ooooo0_l00013ooooo`;o00003Ooo
ool2o`0006Wooooo000Nooooo`03o`000?oooooooooo01Sooooo1?l0000Gooooo`;o000000?ooooo
o`000?l00000;Oooool2o`0000[ooooo0_l0000Eooooo`;o0000>_ooool2o`0000_ooooo0_l0001d
ooooo`007_ooool00ol0003oooooooooo`0Qooooo`;o0000;oooool3o`0001cooooo0_l0000Eoooo
o`;o00008?ooool2o`0001Sooooo0_l0000;ooooo`;o0000M?ooool001kooooo00?o0000oooooooo
ool08Oooool2o`0000Cooooo0_l0000Hooooo`;o00003oooool3o`0003?ooooo0_l0000Pooooo`;o
00007Oooool2o`0007cooooo000Dooooo`Co000000?o410@ooooooooool00oooool00ol0003ooooo
ooooo`0Wooooo`;o00006?ooool2o`0004?ooooo0_l00011ooooo`;o0000O?ooool001Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`26ooooo`;o00007_ooool2o`0007?ooooo0_l0
000Oooooo`;o00002Oooool001Kooooo00?o0000ooooooooool01Oooool3o`000:Kooooo0_l0001>
ooooo`;o00008oooool2o`0001oooooo0_l00009ooooo`005_ooool00ol0003oooooooooo`3noooo
o`;o0000Coooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003ooooo
ooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Cooooo00?oEEEE
ofIVI_l00000oooooomBooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.65714 .3717 Mdot
.36182 .43934 Mdot
.85882 .48956 Mdot
.25852 .52186 Mdot
.50348 .1233 Mdot
.61566 .59158 Mdot
.70089 .45317 Mdot
.99609 .92948 Mdot
.15935 .38976 Mdot
.99013 .90798 Mdot
.36936 .48002 Mdot
.06294 .02655 Mdot
.2027 .58555 Mdot
.22937 .07206 Mdot
.85651 .62834 Mdot
.46741 .06148 Mdot
.86209 .00313 Mdot
.3289 .97036 Mdot
.69307 .07018 Mdot
.83016 .5541 Mdot
.01952 .16035 Mdot
.31722 .16293 Mdot
.16425 .17277 Mdot
.76353 .65047 Mdot
.45582 .06291 Mdot
.03077 .08178 Mdot
.07093 .94052 Mdot
.07461 .50798 Mdot
.71741 .44337 Mdot
.21491 .0243 Mdot
.53648 .90197 Mdot
.89119 .98326 Mdot
.00407 .224 Mdot
.06162 .30884 Mdot
.35263 .5547 Mdot
.80754 .17118 Mdot
.39549 .00921 Mdot
.25942 .59684 Mdot
.79698 .5553 Mdot
.68904 .58132 Mdot
.59037 .5788 Mdot
.95486 .06546 Mdot
.56942 .20667 Mdot
.57066 .54492 Mdot
.06493 .46 Mdot
.0037 .76974 Mdot
.21208 .40905 Mdot
.70213 .06922 Mdot
.34403 .91085 Mdot
.93275 .97023 Mdot
.04051 .86303 Mdot
.7358 .90789 Mdot
.95148 .79181 Mdot
.30266 .34183 Mdot
.89687 .08965 Mdot
.23952 .28366 Mdot
.36919 .1154 Mdot
.7201 .03018 Mdot
.63877 .19137 Mdot
.52179 .45986 Mdot
.7862 .78008 Mdot
.09345 .98432 Mdot
.24169 .39301 Mdot
.82374 .59315 Mdot
.79666 .11726 Mdot
.02565 .75993 Mdot
.37332 .51486 Mdot
.30096 .94603 Mdot
.52612 .90799 Mdot
.09133 .42749 Mdot
.40223 .21095 Mdot
.08759 .47859 Mdot
.07257 .95676 Mdot
.4928 .00954 Mdot
.3636 .06291 Mdot
.18277 .91457 Mdot
.06021 .43568 Mdot
.64044 .66399 Mdot
.19755 .42708 Mdot
.81743 .18603 Mdot
.15902 .00483 Mdot
.25016 .27708 Mdot
.27679 .29642 Mdot
.66792 .28183 Mdot
.68295 .84528 Mdot
.67181 .79823 Mdot
.81917 .28409 Mdot
.99257 .3818 Mdot
.2468 .33834 Mdot
.8627 .20953 Mdot
.57726 .39835 Mdot
.53904 .53436 Mdot
.91215 .93297 Mdot
.81827 .74985 Mdot
.15736 .12074 Mdot
.6588 .95459 Mdot
.96861 .78279 Mdot
.49125 .64022 Mdot
.64256 .01765 Mdot
.97359 .75455 Mdot
.87491 .16501 Mdot
.62336 .04076 Mdot
.79717 .25395 Mdot
.57632 .01603 Mdot
.38882 .8562 Mdot
.26615 .75947 Mdot
.751 .24197 Mdot
.11938 .3242 Mdot
.28391 .94045 Mdot
.13341 .17061 Mdot
.12699 .42567 Mdot
.64959 .89332 Mdot
.76096 .75994 Mdot
.5349 .35994 Mdot
.46282 .00147 Mdot
.46034 .86104 Mdot
.56734 .62676 Mdot
.67713 .58885 Mdot
.30095 .90161 Mdot
.0492 .80179 Mdot
.55007 .42559 Mdot
.43478 .1104 Mdot
.90273 .47188 Mdot
.29138 .70478 Mdot
.64571 .21594 Mdot
.26788 .84069 Mdot
.7086 .75064 Mdot
.30731 .47984 Mdot
.64836 .62002 Mdot
.12309 .3805 Mdot
.80565 .23015 Mdot
.58096 .10734 Mdot
.79888 .29179 Mdot
.63493 .50603 Mdot
.39585 .29942 Mdot
.86575 .28063 Mdot
.22456 .56491 Mdot
.08533 .95559 Mdot
.01842 .31012 Mdot
.2898 .95797 Mdot
.87717 .19773 Mdot
.66907 .08827 Mdot
.57017 .49879 Mdot
.60243 .47613 Mdot
.2588 .71172 Mdot
.45804 .49071 Mdot
.37463 .90667 Mdot
.08415 .72278 Mdot
.67284 .8471 Mdot
.49547 .26036 Mdot
.14205 .01118 Mdot
.70153 .80457 Mdot
.77168 .29501 Mdot
.54405 .19537 Mdot
.70066 .29149 Mdot
.42474 .21775 Mdot
.91278 .10924 Mdot
.5033 .2001 Mdot
.01911 .70858 Mdot
.89385 .97573 Mdot
.84279 .37213 Mdot
.87825 .2198 Mdot
.18962 .8969 Mdot
.7126 .92441 Mdot
.93438 .07769 Mdot
.66731 .2327 Mdot
.73918 .277 Mdot
.73228 .53077 Mdot
.31432 .67175 Mdot
.76005 .82211 Mdot
.79521 .42936 Mdot
.34345 .34784 Mdot
.47208 .58044 Mdot
.94631 .63364 Mdot
.76916 .18555 Mdot
.72951 .2047 Mdot
.3337 .59052 Mdot
.5612 .49692 Mdot
.0852 .83345 Mdot
.33981 .47249 Mdot
.26729 .64331 Mdot
.04471 .1267 Mdot
.96173 .69912 Mdot
.19909 .27935 Mdot
.0015 .60632 Mdot
.76401 .16038 Mdot
.72833 .95147 Mdot
.51145 .45618 Mdot
.89011 .84294 Mdot
.44195 .48309 Mdot
.30541 .50406 Mdot
.62177 .50914 Mdot
.55047 .35528 Mdot
.03883 .88492 Mdot
.0815 .18584 Mdot
.33239 .09155 Mdot
.60741 .06181 Mdot
.07522 .42725 Mdot
.37594 .62566 Mdot
.07028 .46603 Mdot
.95011 .27073 Mdot
.14881 .49725 Mdot
.15608 .2803 Mdot
.01746 .4716 Mdot
.09291 .4161 Mdot
.49736 .0882 Mdot
.51092 .71692 Mdot
.66754 .48849 Mdot
.4315 .17432 Mdot
.07996 .53976 Mdot
.57536 .04711 Mdot
.49194 .5728 Mdot
.10649 .25183 Mdot
.83288 .54719 Mdot
.47688 .49182 Mdot
.31398 .56376 Mdot
.87825 .58188 Mdot
.29614 .99075 Mdot
.8526 .36405 Mdot
.1899 .00466 Mdot
.9574 .68077 Mdot
.61397 .96396 Mdot
.86403 .14877 Mdot
.62774 .89896 Mdot
.26504 .38219 Mdot
.30805 .86404 Mdot
.27757 .39045 Mdot
.47319 .79248 Mdot
.88353 .27619 Mdot
.66095 .30136 Mdot
.51004 .4177 Mdot
.95518 .80628 Mdot
.04542 .23602 Mdot
.85882 .34076 Mdot
.69115 .57983 Mdot
.74657 .93905 Mdot
.94698 .70407 Mdot
.93784 .59627 Mdot
.16042 .838 Mdot
.96745 .26541 Mdot
.79935 .03807 Mdot
.83398 .47335 Mdot
.79037 .12807 Mdot
.35925 .15064 Mdot
.23184 .36551 Mdot
.00122 .29863 Mdot
.03325 .27377 Mdot
.76832 .86161 Mdot
.61185 .07252 Mdot
.34556 .78443 Mdot
.91836 .72583 Mdot
.84536 .00079 Mdot
.63292 .17721 Mdot
.5294 .04242 Mdot
.33857 .5762 Mdot
.66104 .38623 Mdot
.61526 .70182 Mdot
.15255 .57467 Mdot
.0449 .94236 Mdot
.87164 .24021 Mdot
.96758 .36271 Mdot
.06734 .94442 Mdot
.54984 .15635 Mdot
.72333 .46262 Mdot
.41709 .46036 Mdot
.71771 .91405 Mdot
.56295 .37546 Mdot
.55688 .01472 Mdot
.4585 .18675 Mdot
.87683 .91913 Mdot
.86122 .74667 Mdot
.50411 .18596 Mdot
.404 .87321 Mdot
.91079 .71638 Mdot
.37111 .22052 Mdot
.7042 .80452 Mdot
.4552 .2548 Mdot
.49313 .37517 Mdot
.38856 .35192 Mdot
.43227 .89395 Mdot
.46984 .69415 Mdot
.06342 .46999 Mdot
.0948 .42605 Mdot
.06067 .76651 Mdot
.2244 .07033 Mdot
.64568 .52383 Mdot
.35792 .33858 Mdot
.43572 .22941 Mdot
.43865 .60175 Mdot
.45332 .33603 Mdot
.52957 .7144 Mdot
.52396 .9602 Mdot
.5723 .56637 Mdot
.92525 .00632 Mdot
.96007 .59867 Mdot
.37424 .70849 Mdot
.22745 .05772 Mdot
.26692 .69268 Mdot
.40527 .20313 Mdot
.32389 .9547 Mdot
.48407 .10671 Mdot
.39099 .1086 Mdot
.46812 .87136 Mdot
.36812 .62948 Mdot
.37822 .79953 Mdot
.92243 .1453 Mdot
.89615 .6649 Mdot
.02955 .93365 Mdot
.14875 .13447 Mdot
.29322 .75015 Mdot
.26116 .44198 Mdot
.47325 .31119 Mdot
.26785 .84311 Mdot
.58232 .73378 Mdot
.36677 .47423 Mdot
.71066 .57985 Mdot
.47014 .17294 Mdot
.30171 .90746 Mdot
.05466 .99575 Mdot
.74787 .4669 Mdot
.40577 .35707 Mdot
.97854 .22507 Mdot
.63818 .38825 Mdot
.99717 .42303 Mdot
.83532 .06587 Mdot
.91742 .18842 Mdot
.97938 .08847 Mdot
.69243 .1084 Mdot
.01908 .40422 Mdot
.8885 .68562 Mdot
.47327 .92468 Mdot
.64179 .73585 Mdot
.56576 .07199 Mdot
.1761 .99246 Mdot
.44544 .17856 Mdot
.67912 .10306 Mdot
.06741 .63382 Mdot
.24695 .41676 Mdot
.60853 .05441 Mdot
.07966 .82424 Mdot
.06947 .12355 Mdot
.66958 .63213 Mdot
.1201 .69092 Mdot
.55927 .41054 Mdot
.0164 .12372 Mdot
.87472 .90972 Mdot
.10982 .43468 Mdot
.71417 .30407 Mdot
.52267 .31313 Mdot
.95527 .3884 Mdot
.42884 .78936 Mdot
.36885 .08886 Mdot
.83739 .16832 Mdot
.19542 .95944 Mdot
.20796 .94614 Mdot
.13669 .04145 Mdot
.67697 .32898 Mdot
.77746 .6159 Mdot
.07643 .39583 Mdot
.59717 .82132 Mdot
.04389 .57238 Mdot
.11685 .92993 Mdot
.14822 .30607 Mdot
.23172 .33057 Mdot
.7863 .62506 Mdot
.53635 .89884 Mdot
.03768 .19906 Mdot
.87764 .33543 Mdot
.88194 .35184 Mdot
.60142 .20223 Mdot
.33278 .44359 Mdot
.52172 .86986 Mdot
.76528 .35513 Mdot
.8927 .46067 Mdot
.14663 .56469 Mdot
.17749 .61205 Mdot
.83526 .41796 Mdot
.14612 .23124 Mdot
.2659 .72157 Mdot
.75479 .37106 Mdot
.86502 .87921 Mdot
.66477 .67137 Mdot
.05212 .92481 Mdot
.63727 .27001 Mdot
.77939 .04215 Mdot
.23426 .32195 Mdot
.16163 .96606 Mdot
.56829 .22439 Mdot
.82276 .03695 Mdot
.93509 .50666 Mdot
.0445 .79848 Mdot
.70392 .61152 Mdot
.66405 .41606 Mdot
.52859 .43147 Mdot
.091 .01673 Mdot
.4101 .65974 Mdot
.83377 .48372 Mdot
.65189 .81791 Mdot
.17462 .03418 Mdot
.60435 .10182 Mdot
.86501 .48248 Mdot
.11038 .12063 Mdot
.31798 .17909 Mdot
.94742 .99506 Mdot
.1551 .24005 Mdot
.92407 .05994 Mdot
.57582 .72881 Mdot
.02901 .92121 Mdot
.24024 .72064 Mdot
.86656 .57565 Mdot
.57837 .20234 Mdot
.78039 .98789 Mdot
.21969 .21849 Mdot
.14534 .37766 Mdot
.40149 .54179 Mdot
.70946 .87714 Mdot
.71688 .80668 Mdot
.26147 .32119 Mdot
.67282 .5861 Mdot
.766 .90642 Mdot
.90975 .3387 Mdot
.37729 .81032 Mdot
.8509 .62344 Mdot
.07885 .34967 Mdot
.11351 .92844 Mdot
.42928 .48728 Mdot
.28055 .88693 Mdot
.21559 .12094 Mdot
.03302 .55978 Mdot
.42723 .30894 Mdot
.87134 .50355 Mdot
.15974 .89207 Mdot
.46205 .66008 Mdot
.30765 .57441 Mdot
.09567 .54148 Mdot
.71403 .74248 Mdot
.47494 .10215 Mdot
.7942 .77208 Mdot
.70916 .72641 Mdot
.08813 .14435 Mdot
.14197 .65628 Mdot
.15337 .33793 Mdot
.76768 .61807 Mdot
.48923 .95955 Mdot
.8123 .43623 Mdot
.68677 .88808 Mdot
.20512 .42239 Mdot
.43981 .65111 Mdot
.25575 .82531 Mdot
.12594 .38633 Mdot
.01626 .61112 Mdot
.52031 .76701 Mdot
.38926 .4569 Mdot
.8566 .90983 Mdot
.1178 .33595 Mdot
.88785 .44082 Mdot
.80254 .357 Mdot
.72359 .05224 Mdot
.11054 .43578 Mdot
.76224 .90258 Mdot
.34293 .14753 Mdot
.1126 .00076 Mdot
.80242 .04139 Mdot
.0929 .75073 Mdot
.92761 .07454 Mdot
.73323 .35564 Mdot
.31344 .23307 Mdot
.36524 .39682 Mdot
.01392 .37164 Mdot
.13306 .836 Mdot
.41533 .40696 Mdot
.86177 .43889 Mdot
.5577 .7839 Mdot
.22322 .93548 Mdot
.23915 .26504 Mdot
.64204 .71826 Mdot
.79796 .68675 Mdot
.40658 .88057 Mdot
.98329 .94763 Mdot
.55522 .99665 Mdot
.47059 .07705 Mdot
.89067 .64495 Mdot
.56972 .1736 Mdot
.54314 .70081 Mdot
.49887 .87439 Mdot
.82234 .24973 Mdot
.7561 .10977 Mdot
.70342 .04625 Mdot
.44278 .90952 Mdot
.8071 .65793 Mdot
.9545 .462 Mdot
.74733 .16694 Mdot
.98198 .9205 Mdot
.34105 .03121 Mdot
.95265 .23101 Mdot
.32804 .80371 Mdot
.94201 .85244 Mdot
.02459 .05977 Mdot
.71224 .22717 Mdot
.83278 .52459 Mdot
.76579 .82815 Mdot
.53394 .3835 Mdot
.30687 .82616 Mdot
.28865 .70798 Mdot
.81976 .45775 Mdot
.42601 .19672 Mdot
.38605 .71539 Mdot
.58672 .88859 Mdot
.91001 .34877 Mdot
.06374 .30824 Mdot
.70914 .59985 Mdot
.71966 .28734 Mdot
.45352 .28953 Mdot
.70036 .40491 Mdot
.63607 .94856 Mdot
.92743 .18781 Mdot
.29865 .01975 Mdot
.02562 .50424 Mdot
.44259 .78697 Mdot
.93877 .13153 Mdot
.02603 .93482 Mdot
.39305 .31018 Mdot
.83992 .82478 Mdot
.16585 .52362 Mdot
.87996 .04685 Mdot
.97234 .63947 Mdot
.76374 .5577 Mdot
.55936 .91947 Mdot
.93399 .05294 Mdot
.03748 .91234 Mdot
.99928 .78524 Mdot
.58972 .27819 Mdot
.47086 .34621 Mdot
.6803 .44451 Mdot
.15012 .00152 Mdot
.99237 .4244 Mdot
.74021 .46653 Mdot
.51826 .29729 Mdot
.48045 .42236 Mdot
.49008 .90348 Mdot
.01223 .85596 Mdot
.92327 .5057 Mdot
.53843 .55904 Mdot
.87347 .71837 Mdot
.56966 .75515 Mdot
.68266 .77198 Mdot
.91046 .24506 Mdot
.19118 .83737 Mdot
.70598 .27859 Mdot
.1917 .02699 Mdot
.71847 .36388 Mdot
.18613 .62906 Mdot
.20126 .03374 Mdot
.74602 .6469 Mdot
.15265 .95665 Mdot
.3995 .43439 Mdot
.08399 .70711 Mdot
.21062 .16319 Mdot
.6548 .96793 Mdot
.50227 .81151 Mdot
.47693 .18841 Mdot
.82448 .28572 Mdot
.26319 .30286 Mdot
.11077 .16859 Mdot
.56475 .76606 Mdot
.84818 .03717 Mdot
.89956 .33034 Mdot
.95718 .12587 Mdot
.31132 .12295 Mdot
.27327 .4688 Mdot
.1398 .66591 Mdot
.26058 .15275 Mdot
.21453 .97025 Mdot
.92743 .343 Mdot
.458 .14961 Mdot
.34083 .66428 Mdot
.41072 .88073 Mdot
.96146 .14275 Mdot
.97818 .06145 Mdot
.52856 .51076 Mdot
.1518 .44295 Mdot
.76952 .53993 Mdot
.48581 .28197 Mdot
.96848 .88342 Mdot
.76246 .83504 Mdot
.55344 .04324 Mdot
.83811 .15446 Mdot
.69976 .87925 Mdot
.93875 .77248 Mdot
.20555 .24119 Mdot
.47786 .23629 Mdot
.18372 .22359 Mdot
.81336 .29991 Mdot
.94285 .19322 Mdot
.82667 .48246 Mdot
.46573 .823 Mdot
.5614 .16785 Mdot
.43997 .27631 Mdot
.24584 .5057 Mdot
.22181 .88903 Mdot
.78101 .21431 Mdot
.5264 .16189 Mdot
.8094 .51842 Mdot
.82498 .45443 Mdot
.51403 .70879 Mdot
.41605 .74174 Mdot
.13462 .69685 Mdot
.45372 .41465 Mdot
.05113 .02983 Mdot
.51244 .64818 Mdot
.36975 .0036 Mdot
.79265 .23884 Mdot
.06138 .26075 Mdot
.76841 .55615 Mdot
.75431 .27539 Mdot
.43057 .63598 Mdot
.7653 .066 Mdot
.5362 .38263 Mdot
.09969 .88504 Mdot
.59277 .46775 Mdot
.54025 .33951 Mdot
.57239 .31551 Mdot
.68523 .83873 Mdot
.28853 .56298 Mdot
.09387 .06986 Mdot
.01512 .47238 Mdot
.85833 .3026 Mdot
.07857 .33545 Mdot
.60319 .71022 Mdot
.05527 .43011 Mdot
.9693 .33007 Mdot
.94368 .43631 Mdot
.92557 .51937 Mdot
.86924 .62711 Mdot
.75656 .1597 Mdot
.11663 .58049 Mdot
.15235 .58644 Mdot
.58224 .59588 Mdot
.77196 .81282 Mdot
.98526 .77766 Mdot
.68588 .58505 Mdot
.4517 .81292 Mdot
.19381 .77285 Mdot
.95907 .85913 Mdot
.77805 .74845 Mdot
.59973 .71075 Mdot
.53208 .08739 Mdot
.99675 .63199 Mdot
.87679 .99116 Mdot
.91551 .52032 Mdot
.59896 .65805 Mdot
.43292 .26531 Mdot
.41298 .55109 Mdot
.47217 .97952 Mdot
.69435 .29435 Mdot
.0039 .58105 Mdot
.433 .05024 Mdot
.90571 .38924 Mdot
.39348 .46917 Mdot
.43734 .2813 Mdot
.98656 .97354 Mdot
.98044 .23861 Mdot
.89884 .79829 Mdot
.07654 .46563 Mdot
.9949 .72338 Mdot
.07829 .00906 Mdot
.81449 .91952 Mdot
.58558 .89034 Mdot
.906 .3767 Mdot
.15477 .01623 Mdot
.01979 .38912 Mdot
.26544 .21653 Mdot
.52788 .9459 Mdot
.7571 .49005 Mdot
.10939 .64261 Mdot
.20089 .49367 Mdot
.61259 .42953 Mdot
.61359 .01167 Mdot
.29467 .023 Mdot
.53868 .59028 Mdot
.87725 .15388 Mdot
.85871 .13053 Mdot
.34647 .25731 Mdot
.12783 .39354 Mdot
.33655 .80408 Mdot
.84906 .41034 Mdot
.73443 .66973 Mdot
.18066 .41895 Mdot
.61515 .74329 Mdot
.04392 .91055 Mdot
.84447 .19999 Mdot
.02642 .80309 Mdot
.47384 .53326 Mdot
.66757 .19739 Mdot
.63481 .78112 Mdot
.03274 .2856 Mdot
.80072 .48048 Mdot
.6882 .37492 Mdot
.57615 .30234 Mdot
.00294 .46729 Mdot
.43604 .08644 Mdot
.47837 .06575 Mdot
.10091 .36866 Mdot
.92376 .7636 Mdot
.13224 .33745 Mdot
.78438 .05975 Mdot
.01322 .05737 Mdot
.21539 .25928 Mdot
.70193 .08871 Mdot
.04079 .3769 Mdot
.63417 .27277 Mdot
.53825 .43024 Mdot
.68872 .70901 Mdot
.58632 .85985 Mdot
.10449 .81367 Mdot
.13009 .61554 Mdot
.4721 .99579 Mdot
.84366 .03306 Mdot
.95076 .44036 Mdot
.13633 .28578 Mdot
.7531 .85497 Mdot
.5848 .40115 Mdot
.62583 .07284 Mdot
.54333 .47704 Mdot
.44159 .88076 Mdot
.46271 .14259 Mdot
.82499 .54799 Mdot
.81349 .05137 Mdot
.85935 .0837 Mdot
.45933 .53057 Mdot
.42646 .16295 Mdot
.84659 .73755 Mdot
.12617 .83046 Mdot
.7622 .84995 Mdot
.00833 .22393 Mdot
.75632 .84331 Mdot
.1069 .85589 Mdot
.78308 .18114 Mdot
.77674 .80241 Mdot
.48496 .64878 Mdot
.41899 .21649 Mdot
.52144 .62995 Mdot
.50297 .5541 Mdot
.15262 .38201 Mdot
.87105 .25529 Mdot
.86799 .06062 Mdot
.33479 .50241 Mdot
.64957 .72108 Mdot
.71605 .15277 Mdot
.36658 .02614 Mdot
.45105 .83146 Mdot
.36883 .88521 Mdot
.56506 .1369 Mdot
.37956 .74601 Mdot
.542 .07966 Mdot
.72471 .86281 Mdot
.16287 .31398 Mdot
.32532 .30144 Mdot
.31439 .30817 Mdot
.17638 .10277 Mdot
.09598 .65171 Mdot
.34195 .572 Mdot
.14376 .3177 Mdot
.46832 .20855 Mdot
.08745 .70491 Mdot
.59762 .95634 Mdot
.06786 .12562 Mdot
.38752 .59901 Mdot
.38698 .32097 Mdot
.56061 .78714 Mdot
.57875 .52108 Mdot
.8449 .17687 Mdot
.98143 .32198 Mdot
.9864 .08778 Mdot
.35895 .54216 Mdot
.04179 .39003 Mdot
.74081 .32025 Mdot
.93022 .95733 Mdot
.16818 .72555 Mdot
.06613 .85779 Mdot
.28562 .90687 Mdot
.99984 .5828 Mdot
.17233 .92129 Mdot
.69391 .89566 Mdot
.71658 .05629 Mdot
.18129 .28591 Mdot
.86074 .05455 Mdot
.66168 .40015 Mdot
.62634 .20176 Mdot
.22635 .97378 Mdot
.92919 .99978 Mdot
.65189 .62782 Mdot
.18911 .61188 Mdot
.12728 .55846 Mdot
.47947 .20859 Mdot
.94298 .18983 Mdot
.28044 .65761 Mdot
.26612 .35887 Mdot
.89376 .09567 Mdot
.12071 .44894 Mdot
.77913 .36925 Mdot
.38731 .97447 Mdot
.33417 .84872 Mdot
.25159 .85536 Mdot
.66627 .758 Mdot
.61102 .79936 Mdot
.70003 .03967 Mdot
.14508 .11043 Mdot
.92615 .89166 Mdot
.39325 .23432 Mdot
.54275 .30249 Mdot
.79102 .27664 Mdot
.23893 .43469 Mdot
.86942 .81436 Mdot
.42559 .06106 Mdot
.16533 .46126 Mdot
.2223 .82629 Mdot
.0345 .17017 Mdot
.05577 .26266 Mdot
.40107 .54575 Mdot
.62172 .87219 Mdot
.5182 .81674 Mdot
.61363 .06362 Mdot
.24733 .03069 Mdot
.82395 .13103 Mdot
.82516 .73479 Mdot
.91324 .54725 Mdot
.18519 .75 Mdot
.17288 .25481 Mdot
.64343 .08618 Mdot
.61055 .47189 Mdot
.74821 .03691 Mdot
.49075 .10765 Mdot
.73881 .7316 Mdot
.39376 .54817 Mdot
.99156 .19315 Mdot
.06402 .93098 Mdot
.66541 .99962 Mdot
.65227 .84438 Mdot
.96091 .74738 Mdot
.96456 .0969 Mdot
.81878 .13171 Mdot
.8751 .12538 Mdot
.5779 .60099 Mdot
.87341 .49547 Mdot
.35262 .39079 Mdot
.98514 .453 Mdot
.83309 .68182 Mdot
.42427 .03946 Mdot
.69436 .18392 Mdot
.27867 .68228 Mdot
.21239 .95565 Mdot
.78037 .07881 Mdot
.8705 .31195 Mdot
.40869 .44362 Mdot
.80687 .19169 Mdot
.04438 .43114 Mdot
.9608 .30353 Mdot
.55754 .49981 Mdot
.62627 .15346 Mdot
.65533 .95152 Mdot
.43363 .45877 Mdot
.89271 .75246 Mdot
.72178 .00865 Mdot
.61158 .17623 Mdot
.33362 .20217 Mdot
.6903 .20773 Mdot
.99195 .51134 Mdot
.16122 .28817 Mdot
.53382 .66552 Mdot
.10318 .29529 Mdot
.42598 .02349 Mdot
.93094 .85644 Mdot
.45949 .074 Mdot
.56444 .57069 Mdot
.26905 .54429 Mdot
.47689 .92582 Mdot
.45575 .85103 Mdot
.26968 .19734 Mdot
.94453 .86113 Mdot
.61207 .42355 Mdot
.89956 .66614 Mdot
.01898 .62501 Mdot
.97765 .15231 Mdot
.56575 .26533 Mdot
.99693 .61801 Mdot
.51234 .18813 Mdot
.27235 .5571 Mdot
.55039 .74439 Mdot
.29884 .21365 Mdot
.77862 .06964 Mdot
.86045 .87331 Mdot
.67431 .13112 Mdot
.45963 .67022 Mdot
.13402 .02227 Mdot
.95905 .01997 Mdot
.08904 .2383 Mdot
.4873 .92212 Mdot
.05912 .5412 Mdot
.70685 .87439 Mdot
.00764 .27709 Mdot
.89685 .17872 Mdot
.73983 .72491 Mdot
.53078 .79772 Mdot
.56625 .09663 Mdot
.57814 .63321 Mdot
.90829 .59189 Mdot
.06794 .1091 Mdot
.31171 .85879 Mdot
.10938 .6796 Mdot
.77475 .8005 Mdot
.91601 .29277 Mdot
.26066 .0203 Mdot
.51592 .6457 Mdot
.01931 .81633 Mdot
.49827 .34597 Mdot
.95991 .19662 Mdot
.43116 .23641 Mdot
.55896 .126 Mdot
.84025 .61135 Mdot
.73042 .79004 Mdot
.21406 .45342 Mdot
.4431 .45619 Mdot
.80842 .65156 Mdot
.66146 .9617 Mdot
.78868 .4907 Mdot
.09971 .67168 Mdot
.78501 .65779 Mdot
.66095 .94001 Mdot
.85341 .9355 Mdot
.58921 .30898 Mdot
.52434 .8095 Mdot
.38458 .03501 Mdot
.81278 .83407 Mdot
.45082 .0465 Mdot
.53962 .68776 Mdot
.2567 .58434 Mdot
.23804 .66999 Mdot
.64325 .42369 Mdot
.94688 .54915 Mdot
.49326 .0007 Mdot
.5915 .10224 Mdot
.40569 .17139 Mdot
.56395 .81101 Mdot
.52781 .6313 Mdot
.25389 .47099 Mdot
.59331 .10127 Mdot
.22566 .29178 Mdot
.80314 .01716 Mdot
.50522 .12063 Mdot
.66839 .0748 Mdot
.00399 .0787 Mdot
.69659 .56153 Mdot
.93889 .4515 Mdot
.79991 .89423 Mdot
.85715 .14887 Mdot
.76657 .73391 Mdot
.10439 .15676 Mdot
.68588 .11571 Mdot
.41021 .3684 Mdot
.36328 .60784 Mdot
.42105 .76319 Mdot
.19146 .05271 Mdot
.8601 .17509 Mdot
.96853 .9976 Mdot
.41902 .22895 Mdot
.68643 .58891 Mdot
.05817 .55024 Mdot
.40402 .37668 Mdot
.4406 .90674 Mdot
.23108 .74918 Mdot
.54956 .03237 Mdot
.38195 .64848 Mdot
.6228 .78618 Mdot
.69747 .08891 Mdot
.24136 .09246 Mdot
.18863 .58921 Mdot
.30353 .36767 Mdot
.02412 .49755 Mdot
.76909 .28595 Mdot
.11864 .61758 Mdot
.82597 .91156 Mdot
.3649 .35866 Mdot
.80306 .36943 Mdot
.49183 .21508 Mdot
.69423 .10422 Mdot
.30566 .62452 Mdot
.92509 .5217 Mdot
.6042 .52643 Mdot
.10107 .65296 Mdot
.08541 .54302 Mdot
.85096 .85901 Mdot
.4943 .41871 Mdot
.51784 .44233 Mdot
.62923 .5808 Mdot
.20936 .5818 Mdot
.63305 .84954 Mdot
.99871 .01551 Mdot
.8251 .69959 Mdot
.57128 .99798 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02o`0000_ooooo0_l0000?ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00?ooooo0_l00009ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool00_l00008ooooo`;o000000?oooooo`000?ooool03_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool02oooool3o`0000;ooooo0_l0000;ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`00
7_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool2o`000003ooooool0003o000000Sooooo0_l00002ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo
0_l00009ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_l0000;ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool00_l0000;ooooo`03o`000?oooooooooo00Gooooo
0_l00006ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool05Oooool2o`0001Wooooo0_l00008ooooo`;o0000@?ooool2o`0001kooooo0_l0
0019ooooo`;o0000@?ooool2o`0001cooooo000Nooooo`03o`000?oooooooooo01Gooooo0_l0000C
ooooo`;o0000D?ooool2o`0001kooooo0_l0000Uooooo`;o00008_ooool2o`0005kooooo000Noooo
o`03o`000?oooooooooo01Wooooo0_l0000?ooooo`;o00000_ooool2o`00087ooooo0_l00004oooo
o`;o00002_ooool2o`0007cooooo0_l00004ooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o
00004oooool2o`0002gooooo0_l0001Booooo`;o00001?ooool2o`0001Cooooo0_l0000booooo`;o
0000?_ooool2o`0000Cooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l0000Xooooo`;o0000
2_ooool2o`0006kooooo0_l0000booooo`;o0000<Oooool2o`00017ooooo000Nooooo`03o`000?oo
oooooooo02Oooooo0_l0000Iooooo`;o00003Oooool2o`0000Wooooo0_l0000Xooooo`;o0000[?oo
ool2o`00017ooooo000Nooooo`03o`000?oooooooooo013ooooo0_l0000Xooooo`;o00001_ooool2
o`0001Sooooo0_l0000Eooooo`;o00004Oooool2o`000;oooooo000Nooooo`03o`000?oooooooooo
00gooooo0_l000000ooooooo0000o`00000Xooooo`;o00004?ooool2o`0001gooooo0_l00006oooo
o`;o0000LOooool2o`0005oooooo000Nooooo`03o`000?oooooooooo00gooooo0_l0000Vooooo`;o
00001_ooool2o`0000gooooo0_l0000Mooooo`;o00003?ooool2o`0003Cooooo0_l0000eooooo`;o
00009_ooool2o`0003Oooooo000Nooooo`03o`000?oooooooooo03Gooooo0_l00006ooooo`;o0000
>_ooool2o`0003Cooooo0_l0000nooooo`;o00003oooool2o`0000Gooooo0_l00005ooooo`Co0000
=Oooool001kooooo00?o0000ooooooooool0Q_ooool2o`0003oooooo0_l0000Fooooo`;o00003_oo
ool2o`0000oooooo0ol00004ooooo`;o00001oooool2o`0003Gooooo000Nooooo`03o`000?oooooo
oooo02Sooooo0_l0001Looooo`;o00008?ooool2o`0000Kooooo0_l0000Eooooo`;o00005_ooool2
o`0001Sooooo0_l00006ooooo`;o0000A?ooool001kooooo00?o0000ooooooooool0:?ooool2o`00
06Cooooo0_l0000Hooooo`;o00001_ooool2o`0000Gooooo0_l0000Xooooo`;o00005_ooool2o`00
01oooooo0_l0000[ooooo`007_ooool00ol0003oooooooooo`29ooooo`;o00000oooool2o`0002Oo
oooo0_l0000Xooooo`;o0000=oooool2o`0002_ooooo000Nooooo`;o0000>oooool2o`0004gooooo
0_l0001Looooo`;o00006oooool2o`0002Kooooo0_l0000Iooooo`007_ooool00ol0003ooooooooo
o`0jooooo`;o0000Q_ooool2o`00027ooooo1?l0000Kooooo`;o00003_ooool2o`0001Kooooo0_l0
000Iooooo`007_ooool00ol0003oooooooooo`02o`0000;ooooo0_l00010ooooo`;o0000N_ooool2
o`00027ooooo0_l0000Dooooo`;o00005oooool2o`00037ooooo000Nooooo`03o`000?oooooooooo
00;o00000_ooool2o`00043ooooo0_l0000Zooooo`;o00004_ooool2o`0000Sooooo0_l00002oooo
o`;o0000:oooool2o`0003Sooooo0_l0000Iooooo`;o00004?ooool2o`00013ooooo0_l0000;oooo
o`007_ooool00ol0003oooooooooo`1booooo`;o00004_ooool2o`0000Sooooo0_l00002ooooo`;o
000000?oooooo`000?l00000:?ooool4o`00033ooooo0_l0000Dooooo`;o00002Oooool2o`00013o
oooo0_l00008ooooo`;o00001_ooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo09Oooooo
0_l0000Zooooo`;o0000<?ooool2o`0001Cooooo0_l0000Uooooo`;o00004oooool001kooooo00?o
0000ooooooooool06_ooool2o`0002Wooooo0ol0001/ooooo`;o00009oooool2o`000003ooooool0
003o000001Oooooo0_l0001<ooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o0000:Oooool3
o`0004Wooooo0_l0000Qooooo`;o00003Oooool2o`0000;ooooo0_l0000<ooooo`;o00001_ooool2
o`000003ooooool0003o000001Oooooo0_l0000^ooooo`;o00007?ooool001kooooo00?o0000oooo
ooooool0TOooool2o`0000;ooooo0_l0000/ooooo`;o00000_ooool2o`0000cooooo0_l0001Boooo
o`;o000000?oooooo`000?l000006Oooool001kooooo0_l0002Fooooo`;o00005Oooool2o`0004co
oooo0_l0000`ooooo`;o00006Oooool001kooooo0_l00007ooooo`;o0000Y?ooool2o`0004cooooo
0_l0000Gooooo`;o0000<_ooool001kooooo00?o0000ooooooooool01_ooool2o`0008;ooooo0_l0
000Mooooo`;o00008_ooool2o`0004Cooooo0_l0000booooo`007_ooool00ol0003oooooooooo`1d
ooooo`;o00005?ooool2o`0001;ooooo0_l00009ooooo`;o00008_ooool2o`0000Kooooo0_l00008
ooooo`?o0000?Oooool2o`0001Wooooo0_l000000ooooooo0000o`000008ooooo`007_ooool00ol0
003oooooooooo`1:ooooo`;o00007?ooool2o`0000[ooooo0_l0000Xooooo`;o0000=Oooool2o`00
00Sooooo0ol0000mooooo`;o00006Oooool2o`000003ooooool0003o000000Sooooo000Nooooo`03
o`000?oooooooooo04[ooooo0_l0000Looooo`;o0000B_ooool2o`0006Sooooo0_l0000Wooooo`00
7_ooool00ol0003oooooooooo`2dooooo`;o0000J?ooool2o`0001Gooooo0_l0000@ooooo`007_oo
ool2o`0003Kooooo0_l0001Oooooo`;o00009?ooool3o`000003ooooool0003o000007?ooooo0_l0
000@ooooo`007_ooool00ol0003oooooooooo`0eooooo`;o0000Goooool2o`0002Cooooo0ol00000
0ooooooo0000o`00000Gooooo`;o00000oooool2o`0006Oooooo000Nooooo`03o`000?oooooooooo
07_ooooo0_l0000Looooo`Co00007?ooool2o`0001kooooo0_l00002ooooo`?o0000Ioooool001ko
oooo00?o0000ooooooooool04_ooool2o`0001Oooooo0_l0001>ooooo`;o00003?ooool2o`0000ko
oooo1?l0000Looooo`;o00008_ooool2o`0001?ooooo0_l0000aooooo`;o00008?ooool001kooooo
00?o0000ooooooooool04_ooool2o`0001Oooooo0_l0001Looooo`;o0000Ioooool2o`00037ooooo
0_l0000Pooooo`007_ooool00ol0003oooooooooo`1dooooo`;o0000IOooool2o`0002;ooooo0_l0
0016ooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o00003Oooool2o`00017ooooo0_l0000`
ooooo`;o0000:_ooool2o`0003Wooooo0_l0000Rooooo`;o0000A_ooool001kooooo00Co0000oooo
oooooooooooo0_l0000?ooooo`;o00003?ooool2o`0000gooooo0_l0000Aooooo`;o00007Oooool2
o`0003gooooo0_l0002Uooooo`007_ooool01?l0003oooooooooooooool2o`0000Oooooo0_l00006
ooooo`;o0000COooool2o`0003gooooo0_l0000@ooooo`;o0000I?ooool2o`0001Wooooo0_l0000B
ooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o00001_ooool2o`0009kooooo0_l00019oooo
o`;o00005?ooool2o`0000?ooooo0_l0000Iooooo`;o00004_ooool001kooooo00?o0000oooooooo
ool0eoooool2o`0002Cooooo0_l00007ooooo`Co00002Oooool2o`0001Sooooo0_l0000Hooooo`00
7_ooool00ol0003oooooooooo`0/ooooo`;o0000ZOooool2o`0002gooooo1?l0000Sooooo`;o0000
6?ooool001kooooo00?o0000ooooooooool0;?ooool2o`0008Kooooo0_l0002Aooooo`007_ooool0
0ol0003oooooooooo`2Booooo`;o00008?ooool2o`0007kooooo0_l0000Aooooo`007_ooool00ol0
003oooooooooo`0Iooooo`;o0000Moooool2o`0009Cooooo0_l0000:ooooo`;o00004Oooool001ko
oooo00?o0000ooooooooool06Oooool2o`00053ooooo0_l0002Vooooo`Co00004Oooool2o`0001go
oooo000Nooooo`;o0000K?ooool2o`0000Cooooo0_l0000Nooooo`;o0000P?ooool4o`00033ooooo
000Nooooo`03o`000?oooooooooo057ooooo0_l0000Nooooo`;o00007_ooool2o`0003Cooooo0_l0
000Looooo`;o00009Oooool2o`0000_ooooo0_l0000Oooooo`;o00002oooool001kooooo00?o0000
ooooooooool07_ooool2o`00037ooooo0_l0001Looooo`;o00005_ooool2o`0001cooooo0_l0000U
ooooo`;o00002oooool2o`0001oooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`02oooo
o`;o00006_ooool2o`0008oooooo0_l00011ooooo`Co0000DOooool001kooooo00?o0000oooooooo
ool00_ooool2o`0003cooooo0_l0000Qooooo`;o00008_ooool2o`0001kooooo0_l00019ooooo`Co
0000DOooool001kooooo00?o0000ooooooooool0@?ooool2o`00027ooooo0_l0000Rooooo`;o0000
7_ooool2o`0004Kooooo0_l0000Wooooo`;o0000;Oooool001kooooo00?o0000ooooooooool01ooo
ool2o`0001Oooooo0_l0002@ooooo`;o0000>oooool2o`0001_ooooo0_l0000:ooooo`;o0000;Ooo
ool001kooooo00?o0000ooooooooool01oooool2o`0001Oooooo0_l00005ooooo`;o00002?ooool2
o`0004gooooo0_l0000Cooooo`;o00006oooool2o`000003ooooool0003o000004_ooooo0_l00008
ooooo`;o0000>Oooool001kooooo00?o0000ooooooooool09oooool2o`0000Sooooo0_l0001=oooo
o`;o00001_ooool2o`0000_ooooo0_l0000Nooooo`;o00003?ooool2o`0003gooooo0_l0000@oooo
o`;o0000<Oooool001kooooo00?o0000ooooooooool0Hoooool2o`0002?ooooo0_l00003ooooo`;o
0000=?ooool2o`0000Gooooo0_l00013ooooo`;o00000oooool2o`0000Wooooo0_l0000Vooooo`00
7_ooool00ol0003oooooooooo`1Sooooo`;o0000:?ooool2o`0003_ooooo0_l0000^ooooo`;o0000
4oooool2o`0000kooooo0_l0000Vooooo`007_ooool00ol0003oooooooooo`0Fooooo`;o0000R?oo
ool2o`0003cooooo0_l0000Fooooo`;o00000_ooool2o`0004_ooooo000Nooooo`03o`000?oooooo
oooo01Kooooo0_l0001iooooo`;o00001?ooool2o`0000Oooooo1?l0000jooooo`;o00005_ooool2
o`0000kooooo0_l0000Nooooo`;o000000?oooooo`000?l000007?ooool001kooooo00?o0000oooo
ooooool0TOooool2o`0000Cooooo0_l00009ooooo`;o0000:?ooool2o`0003Cooooo0_l00002oooo
o`;o00007_ooool2o`000003ooooool0003o000000?ooooo0_l0000Gooooo`000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`3<oooo
o`;o0000=?ooool2o`0002[ooooo0_l0000>ooooo`;o00001oooool000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000
ooooooooool0E?ooool2o`00033ooooo0_l0000Uooooo`;o00009_ooool2o`0004;ooooo0_l0000C
ooooo`;o00001?ooool2o`0000Sooooo0_l00007ooooo`000oooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool3o`0000Sooooo0_l0001:ooooo`;o0000<?ooool2
o`0001Sooooo0_l0000;ooooo`;o00009_ooool2o`0003Oooooo0_l00009ooooo`;o00006Oooool2
o`00017ooooo0003ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06
ooooo`03o`000?oooooooooo00Sooooo0_l0001Nooooo`;o00005_ooool2o`0001kooooo0_l0000F
ooooo`;o00001Oooool2o`0000Oooooo0_l00014ooooo`;o0000=oooool000?ooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0J?ooool2
o`0001Kooooo0_l0000cooooo`;o000000?oooooo`000?l000001Oooool2o`0000Oooooo0_l0000O
ooooo`;o0000G?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0U?ooool2o`0000;ooooo0_l0000Kooooo`;o00009Oooool2
o`0000_ooooo0_l0000Yooooo`;o0000<Oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`1Mooooo`;o00008?oo
ool2o`0001?ooooo0_l00002ooooo`;o0000@_ooool2o`0003Kooooo0_l0000aooooo`000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`00
0?oooooooooo05;ooooo0_l00009ooooo`;o00008?ooool2o`0000?ooooo0_l0000Fooooo`;o0000
<?ooool2o`0002[ooooo0_l0001;ooooo`007_ooool00ol0003oooooooooo`13ooooo`;o00003Ooo
ool2o`00033ooooo1?l0000Dooooo`;o0000<?ooool2o`0002[ooooo0_l0000Mooooo`;o0000;?oo
ool001kooooo00?o0000ooooooooool0@oooool2o`00033ooooo0_l0000?ooooo`;o0000TOooool2
o`0002cooooo000Nooooo`Co0000=oooool2o`0003_ooooo0_l0000nooooo`;o0000Poooool2o`00
00_ooooo000Nooooo`Co0000=oooool2o`0004[ooooo0_l0000_ooooo`;o0000;?ooool2o`0005Go
oooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`0[ooooo`;o0000Eoooool2o`0000Cooooo
0_l0001Gooooo`;o00007Oooool2o`0002kooooo0_l0000Cooooo`007_ooool00ol0003ooooooooo
o`0[ooooo`;o0000=Oooool2o`0001Sooooo0_l0000<ooooo`;o0000BOooool2o`0002_ooooo0_l0
000^ooooo`;o00004oooool001kooooo00?o0000ooooooooool02oooool2o`0005Gooooo0_l0000H
ooooo`;o00002_ooool2o`0000gooooo0_l0000looooo`;o0000L?ooool001kooooo00?o0000oooo
ooooool02oooool2o`0000cooooo0_l0000Cooooo`;o00003oooool2o`0004Oooooo0_l0000=oooo
o`;o0000IOooool2o`0001Oooooo0_l0000Rooooo`;o00002_ooool001kooooo00?o0000oooooooo
ool06Oooool2o`0001?ooooo0_l0000?ooooo`;o0000[oooool2o`0000cooooo0_l0000Gooooo`;o
00008_ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo0?3ooooo0_l0000booooo`;o0000
8Oooool001kooooo00?o0000ooooooooool0ooooool8ooooo`;o00006oooool2o`00027ooooo000N
ooooo`;o00008?ooool2o`000>Kooooo0_l0000nooooo`007_ooool00ol0003oooooooooo`0Ooooo
o`;o00004oooool2o`0005[ooooo0_l0001]ooooo`;o00005_ooool2o`0002kooooo000Nooooo`03
o`000?oooooooooo03Cooooo0_l0000<ooooo`;o0000:Oooool2o`00027ooooo0_l0001]ooooo`;o
00005_ooool2o`0002kooooo000Nooooo`03o`000?oooooooooo00kooooo1?l0000`ooooo`;o0000
:Oooool2o`0002kooooo0_l0002Xooooo`007_ooool00ol0003oooooooooo`0>ooooo`Co0000>?oo
ool2o`0003gooooo0_l0000Booooo`;o00005Oooool2o`00083ooooo0_l0000?ooooo`007_ooool0
0ol0003oooooooooo`1:ooooo`;o0000?Oooool2o`0002Wooooo0_l00020ooooo`;o00003oooool0
01kooooo00?o0000ooooooooool0boooool2o`0006Cooooo0_l0000Dooooo`007_ooool00ol0003o
ooooooooo`07ooooo`;o0000`Oooool3o`0006Cooooo0_l0000Dooooo`007_ooool3o`0000Oooooo
0_l00014ooooo`;o0000??ooool2o`0002oooooo0_l0000<ooooo`;o00008?ooool2o`0000?ooooo
0_l0000:ooooo`;o00007?ooool2o`0002[ooooo000Nooooo`?o0000;oooool2o`0000cooooo0_l0
000>ooooo`;o0000>oooool3o`0002oooooo0_l0000Sooooo`;o00002Oooool2o`0000?ooooo0_l0
000:ooooo`;o00005_ooool2o`0000Cooooo0_l0000Zooooo`007_ooool00ol0003oooooooooo`0_
ooooo`;o00003?ooool2o`0000_ooooo0_l0000nooooo`;o00003_ooool2o`0003Wooooo0_l0000:
ooooo`;o00008oooool2o`0000gooooo0_l0000`ooooo`007_ooool00ol0003oooooooooo`07oooo
o`;o00007oooool2o`0000gooooo0_l0000Aooooo`;o0000C_ooool2o`0003Wooooo0_l0000?oooo
o`;o00003_ooool2o`0000kooooo1?l0000mooooo`007_ooool00ol0003oooooooooo`07ooooo`;o
00007oooool2o`0000Kooooo0_l00005ooooo`;o0000E_ooool2o`0005Gooooo0_l0000>ooooo`;o
00004?ooool2o`0003gooooo000Nooooo`03o`000?oooooooooo033ooooo0_l0000Cooooo`;o0000
B?ooool2o`0004oooooo0_l0000Nooooo`;o00009?ooool2o`0001oooooo000Nooooo`03o`000?oo
oooooooo01gooooo0_l0000Vooooo`;o00003oooool2o`0008Kooooo1?l0000Eooooo`;o00001ooo
ool2o`0002Cooooo0_l0000Oooooo`007Oooool2o`0001oooooo0_l0000gooooo`;o00009Oooool2
o`0002Gooooo0_l0000hooooo`;o00005oooool2o`0004kooooo000Mooooo`?o0000D_ooool2o`00
01?ooooo0_l0000Eooooo`;o00009Oooool2o`0000Kooooo0_l00009ooooo`;o00006_ooool2o`00
02oooooo0_l0000=ooooo`;o0000<_ooool001kooooo00?o0000ooooooooool0DOooool2o`0001?o
oooo0_l00014ooooo`;o00002Oooool2o`0001[ooooo0_l0000?ooooo`;o00007_ooool2o`0000go
oooo0_l0000Oooooo`;o00004Oooool001kooooo00?o0000ooooooooool04?ooool3o`0001Wooooo
0_l0000dooooo`;o00008oooool2o`0003;ooooo0_l0000Wooooo`;o0000C_ooool2o`00017ooooo
000Nooooo`03o`000?oooooooooo00;ooooo0_l0000<ooooo`?o00006Oooool2o`0003Cooooo0_l0
000Hooooo`;o00002Oooool2o`0000gooooo0_l0000Sooooo`;o0000F_ooool2o`0002kooooo000N
ooooo`03o`000?oooooooooo00;ooooo0_l0000]ooooo`;o0000BOooool2o`0001Sooooo0_l0000>
ooooo`;o0000Koooool2o`0002kooooo000Nooooo`03o`000?oooooooooo02_ooooo0_l00004oooo
o`;o0000Loooool2o`0000kooooo0_l0002?ooooo`007_ooool00ol0003oooooooooo`0[ooooo`;o
00009?ooool2o`0002Oooooo0_l0000jooooo`;o0000=Oooool2o`0005Sooooo000Nooooo`03o`00
0?oooooooooo02?ooooo0_l0000Sooooo`;o00001oooool2o`0002Oooooo0_l0001aooooo`;o0000
C?ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo02?ooooo0_l0000Sooooo`;o0000lOoo
ool2o`0000[ooooo000Nooooo`03o`000?oooooooooo0=Sooooo0_l00016ooooo`;o00005Oooool2
o`0000kooooo000Nooooo`03o`000?oooooooooo04Oooooo0_l0002?ooooo`;o0000A_ooool2o`00
01Gooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o00002oooool2o`0002?o
oooo0_l00016ooooo`;o0000R?ooool2o`0002cooooo000Nooooo`03o`000?oooooooooo01Gooooo
0_l0000;ooooo`;o00000oooool2o`0000Gooooo0_l0000Looooo`;o00008_ooool2o`0001gooooo
0_l0000Kooooo`;o0000Joooool2o`0000Wooooo0_l0000Qooooo`007_ooool00ol0003ooooooooo
o`0Wooooo`;o00001Oooool2o`0001cooooo0_l0000@ooooo`;o00004?ooool2o`0003[ooooo0_l0
001Uooooo`;o00003oooool2o`00027ooooo000Nooooo`03o`000?oooooooooo05kooooo0_l0002c
ooooo`;o00005?ooool2o`0001cooooo000Nooooo`03o`000?oooooooooo06cooooo0_l0000Woooo
o`;o00001oooool2o`0008Cooooo0_l00003ooooo`;o00007?ooool001kooooo0_l0000Gooooo`;o
0000E?ooool2o`0000cooooo0_l0000Iooooo`;o00001oooool2o`0007_ooooo0_l00007ooooo`;o
00008Oooool001kooooo00?o0000ooooooooool05_ooool2o`0006;ooooo0_l0001iooooo`;o0000
9?ooool2o`0002[ooooo000Nooooo`03o`000?oooooooooo083ooooo0_l0000]ooooo`;o0000>Ooo
ool2o`0000Wooooo0_l0000:ooooo`;o0000A?ooool001kooooo00?o0000ooooooooool0D_ooool2
o`0001oooooo0_l0000;ooooo`;o0000:?ooool2o`0000?ooooo0_l0000iooooo`;o00005Oooool2
o`0004Cooooo000Nooooo`03o`000?oooooooooo05;ooooo0_l0000Oooooo`;o0000=Oooool2o`00
03Wooooo0_l0000Zooooo`;o00008oooool2o`0000oooooo000Nooooo`03o`000?oooooooooo04Oo
oooo0_l0002Looooo`;o0000:_ooool2o`0002?ooooo0_l0000?ooooo`007_ooool00ol0003ooooo
ooooo`0Mooooo`;o0000:?ooool2o`0001Kooooo0_l0000Pooooo`;o0000M_ooool2o`0000Kooooo
0_l00014ooooo`007_ooool00ol0003oooooooooo`02o`0001_ooooo0_l00010ooooo`;o00008?oo
ool2o`0004oooooo0_l0000Mooooo`;o00001_ooool2o`0000Kooooo0_l0000;ooooo`;o0000=ooo
ool001kooooo00?o0000ooooooooool00_l0001mooooo`;o00006oooool2o`0001Gooooo0_l0000M
ooooo`;o00002?ooool2o`0001?ooooo0_l0000Kooooo`;o0000=oooool001kooooo00?o0000oooo
ooooool02Oooool2o`00023ooooo0_l0001Booooo`;o00006oooool2o`0001Gooooo0_l0000Woooo
o`;o0000A?ooool2o`0002?ooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0000Iooooo`;o
00001Oooool4o`0002?ooooo0_l0001Fooooo`;o0000M_ooool2o`0001_ooooo0_l00006ooooo`00
7_ooool00ol0003oooooooooo`0Tooooo`;o00001oooool2o`0002?ooooo0_l0001Eooooo`?o0000
Toooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo02Gooooo0_l00022ooooo`;o00008?oo
ool2o`0000Kooooo0_l0001Mooooo`;o00004oooool001kooooo00?o0000ooooooooool00_ooool2
o`0000Gooooo0_l0000Jooooo`;o00002Oooool2o`0002Cooooo0_l0000Gooooo`;o0000F_ooool2
o`0000Kooooo0_l0001=ooooo`;o00003_ooool2o`0001?ooooo0003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo0_l00005ooooo`;o00006_ooool2o`0000Wooooo0_l0000Hooooo`;o00002_ooool2
o`0001Oooooo0_l0002aooooo`;o00008oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Gooooo0_l0000>
ooooo`;o00008oooool2o`0002Oooooo0_l0003Booooo`000oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol00006ooooo`?o00005Oooool2o`0005cooooo0_l00013ooooo`Co00005oooool2
o`0007;ooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool0
0007ooooo`03o`000?oooooooooo00;ooooo0_l0002dooooo`Co00005oooool2o`0007;ooooo0003
ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`00
0?oooooooooo00;ooooo0_l0001oooooo`;o0000Foooool2o`0006Gooooo0003ooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo047ooooo
0_l00010ooooo`;o0000Foooool2o`0002kooooo0_l0000eooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`11ooooo`;o0000
Koooool2o`0005cooooo0_l0000eooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo
00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`0Jooooo`;o0000Loooool2o`00027ooooo
0_l0000Pooooo`;o0000LOooool001kooooo00?o0000ooooooooool06_ooool2o`0001_ooooo0_l0
000Cooooo`;o0000@Oooool2o`0000cooooo0_l00003ooooo`;o0000<?ooool2o`0003Gooooo0_l0
000jooooo`007_ooool00ol0003oooooooooo`0gooooo`;o00001_ooool2o`0000_ooooo0_l0001:
ooooo`;o00000oooool2o`0000?ooooo0_l0001Wooooo`;o0000>_ooool001kooooo00?o0000oooo
ooooool09Oooool2o`0001Sooooo0_l0001Gooooo`;o00005Oooool2o`0001;ooooo0_l00008oooo
o`;o0000L?ooool3o`0000Gooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l00004ooooo`?o
00002?ooool2o`0001Gooooo0_l0001aooooo`;o00004_ooool2o`0000Sooooo0_l0001`ooooo`?o
00001Oooool001kooooo00?o0000ooooooooool02_ooool2o`0000;ooooo0_l00004ooooo`;o0000
1?ooool3o`0001oooooo0_l0001Zooooo`;o000000?oooooo`000?l000005_ooool2o`0003Wooooo
0_l00017ooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o00000_ooool2o`00013ooooo0_l0
000Xooooo`;o0000<_ooool2o`0002Sooooo0_l000000ooooooo0000o`00000Fooooo`;o0000>Ooo
ool2o`0004Oooooo000Nooooo`03o`000?oooooooooo00oooooo0_l0000?ooooo`;o0000:?ooool2
o`0003;ooooo0_l00024ooooo`;o0000:Oooool2o`0001Kooooo000Nooooo`03o`000?oooooooooo
00oooooo0_l0000?ooooo`;o0000D?ooool2o`00093ooooo0_l0000>ooooo`;o00001oooool2o`00
013ooooo1?l0000Dooooo`007_ooool00ol0003oooooooooo`0]ooooo`;o00008_ooool2o`0001Go
oooo0_l00008ooooo`;o00003Oooool2o`00027ooooo0_l0000oooooo`;o0000;Oooool2o`0000Oo
oooo0_l0000Booooo`;o00005?ooool001kooooo00?o0000ooooooooool0;Oooool2o`0002;ooooo
0_l0000Eooooo`;o00005oooool2o`00027ooooo0_l0000cooooo`;o00002_ooool2o`00063ooooo
000Nooooo`03o`000?oooooooooo02?ooooo0_l0002dooooo`;o0000K?ooool001kooooo0_l0000T
ooooo`;o00007?ooool2o`0009gooooo0_l0001;ooooo`;o00003Oooool2o`0000Wooooo000Noooo
o`03o`000?oooooooooo047ooooo0_l00019ooooo`;o00005?ooool2o`0003cooooo0_l0000Voooo
o`;o00008oooool2o`0000gooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`1jooooo`;o
00003Oooool2o`000003ooooool0003o000001Cooooo0_l0001Rooooo`Co0000?Oooool001kooooo
00?o0000ooooooooool04Oooool2o`0001oooooo0_l00016ooooo`;o00001oooool2o`0000Cooooo
0_l0000Kooooo`;o0000?oooool2o`0001gooooo0_l0000Fooooo`;o00004_ooool2o`0001?ooooo
000Nooooo`03o`000?oooooooooo017ooooo0_l00002ooooo`;o00006oooool2o`0004oooooo0_l0
000Qooooo`;o0000?oooool2o`0003Gooooo0_l0000Booooo`;o00004oooool001kooooo0_l0000D
ooooo`Co0000?_ooool2o`0006Kooooo0_l0000^ooooo`Co0000E_ooool001kooooo0_l00003oooo
o`;o00003?ooool2o`000003ooooool0003o000003Wooooo0_l00005ooooo`;o00009Oooool2o`00
03oooooo0_l00003ooooo`;o0000:Oooool4o`00033ooooo0_l0000Tooooo`007_ooool01?l0003o
ooooooooooooool3o`0000cooooo0_l0000looooo`;o00006_ooool2o`0000Oooooo0_l00007oooo
o`;o0000A?ooool2o`0004Oooooo0_l0000Dooooo`;o00009?ooool001kooooo00Co0000oooooooo
oooooooo0_l0001Wooooo`;o00001oooool2o`0003Sooooo0_l0000Aooooo`;o0000BOooool2o`00
03[ooooo000Nooooo`03o`000?oooooooooo01Sooooo0_l00016ooooo`;o00004_ooool2o`0003Oo
oooo0_l0000Aooooo`;o0000?_ooool2o`0004Gooooo000Nooooo`03o`000?oooooooooo01Sooooo
0_l00016ooooo`;o00004_ooool2o`0001Kooooo0_l0001booooo`;o00001oooool4o`0000Sooooo
0_l0000`ooooo`007_ooool00ol0003oooooooooo`27ooooo`;o00000oooool2o`0007_ooooo1?l0
0008ooooo`;o0000<?ooool001kooooo00?o0000ooooooooool0Qoooool2o`0004cooooo0_l0000K
ooooo`;o00007oooool2o`0003;ooooo000Nooooo`03o`000?oooooooooo097ooooo0_l00004oooo
o`;o0000??ooool2o`0001_ooooo0_l00008ooooo`;o00005Oooool2o`0003;ooooo000Nooooo`03
o`000?oooooooooo03gooooo0_l0001Booooo`;o00001?ooool2o`0006?ooooo0_l0000Jooooo`;o
0000;Oooool001kooooo00?o0000ooooooooool01?ooool2o`0002Kooooo0_l0000?ooooo`;o0000
Loooool2o`000003ooooool0003o0000067ooooo0_l0000]ooooo`007_ooool2o`0000Gooooo0_l0
000Vooooo`;o0000>oooool2o`0004Kooooo0ol000000ooooooo0000o`00002@ooooo`007_ooool0
0ol0003oooooooooo`04ooooo`;o0000A_ooool2o`00017ooooo0_l00008ooooo`;o0000A_ooool2
o`0006Cooooo0_l0000?ooooo`;o00007Oooool001kooooo00?o0000ooooooooool01?ooool2o`00
00kooooo0_l0000fooooo`;o00004Oooool2o`0006Wooooo0_l0001;ooooo`;o00003oooool2o`00
00;ooooo0_l0000Iooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o0000T_ooool2o`0001co
oooo0_l00002ooooo`;o0000H?ooool2o`00013ooooo0_l00007ooooo`007_ooool00ol0003ooooo
ooooo`1eooooo`;o0000<Oooool2o`0001cooooo0_l0001fooooo`;o00001oooool001kooooo00?o
0000ooooooooool0MOooool2o`000=3ooooo000Nooooo`03o`000?oooooooooo0;Sooooo0_l00019
ooooo`;o00008Oooool2o`000003ooooool0003o000001cooooo000Nooooo`03o`000?oooooooooo
03;ooooo0_l0000Looooo`;o0000I_ooool2o`0001Cooooo0_l0000cooooo`;o00008Oooool2o`00
0003ooooool0003o000001cooooo000Nooooo`03o`000?oooooooooo03;ooooo0_l0000Looooo`;o
0000K_ooool2o`0000cooooo0_l0000kooooo`;o00007?ooool2o`0001cooooo000Nooooo`03o`00
0?oooooooooo0<3ooooo0_l00019ooooo`;o0000>_ooool001kooooo00?o0000ooooooooool0TOoo
ool2o`0000?ooooo0_l0001Booooo`;o0000Foooool001kooooo00?o0000ooooooooool0TOooool2
o`0000?ooooo0_l0000Cooooo`;o0000?Oooool2o`0005_ooooo000Nooooo`03o`000?oooooooooo
0:_ooooo0_l0002Jooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o00001Oooool2o`0000?o
oooo0_l0001Dooooo`;o00002oooool2o`0007Kooooo0_l0001?ooooo`007_ooool00ol0003ooooo
ooooo`0?ooooo`;o00001Oooool4o`000003ooooool0003o000003Kooooo0_l0000Looooo`;o0000
2oooool2o`0003Gooooo0_l0000oooooo`;o0000Coooool001kooooo00?o0000ooooooooool06?oo
ool2o`0003Wooooo0_l0000Wooooo`Co0000=Oooool2o`00057ooooo0_l000000ooooooo0000o`00
000Hooooo`;o00008?ooool001kooooo0_l0000@ooooo`;o0000Joooool2o`0000Cooooo0_l00024
ooooo`;o000000?oooooo`000?l000006?ooool2o`0000Wooooo0_l0000Eooooo`007_ooool00ol0
003oooooooooo`0?ooooo`;o0000G_ooool2o`00017ooooo0_l0000Kooooo`;o0000JOooool2o`00
02Cooooo0_l0000Eooooo`007_ooool00ol0003oooooooooo`1Dooooo`;o00006Oooool2o`0002ko
oooo0_l0001Cooooo`Co00001oooool2o`0000Wooooo0_l0000kooooo`007_ooool00ol0003ooooo
ooooo`07ooooo`;o00007?ooool2o`0002gooooo0_l0001Eooooo`;o0000Aoooool4o`0000Oooooo
0_l00016ooooo`007_ooool00ol0003oooooooooo`07ooooo`;o00007?ooool2o`0003?ooooo0_l0
0006ooooo`;o0000Aoooool2o`00037ooooo0_l0001Wooooo`007_ooool00ol0003oooooooooo`0/
ooooo`;o00005oooool2o`0001?ooooo0_l00006ooooo`;o0000D_ooool2o`0002Kooooo0_l0001W
ooooo`007_ooool00ol0003oooooooooo`0/ooooo`;o00005oooool2o`0006oooooo0_l0002?oooo
o`007_ooool00ol0003oooooooooo`0:ooooo`;o0000Goooool2o`0002oooooo0_l0000Eooooo`;o
0000T_ooool001kooooo00?o0000ooooooooool02_ooool2o`00027ooooo0_l0000aooooo`;o0000
2?ooool3o`0002oooooo0_l0000Eooooo`;o0000HOooool2o`0002oooooo000Nooooo`03o`000?oo
oooooooo02gooooo0_l0000aooooo`;o00002?ooool2o`00053ooooo0_l0001Hooooo`;o0000;ooo
ool001kooooo0_l0000Sooooo`;o00007?ooool2o`0005?ooooo0_l0000Uooooo`;o00002_ooool2
o`0001;ooooo0ol00004ooooo`;o0000=?ooool2o`0002cooooo000Nooooo`;o00008oooool2o`00
01[ooooo1?l0000=ooooo`;o0000A?ooool2o`00037ooooo0_l0000Aooooo`Co00001?ooool2o`00
03Cooooo0_l0000Vooooo`;o00001?ooool001kooooo00?o0000ooooooooool0;Oooool2o`0000oo
oooo0_l0000?ooooo`;o0000Q_ooool3o`000003ooooool0003o000006Cooooo0_l00004ooooo`00
7_ooool00ol0003oooooooooo`0]ooooo`;o00002_ooool2o`0002gooooo0_l00011ooooo`;o0000
5oooool2o`00017ooooo0ol000000ooooooo0000o`000016ooooo`;o00008_ooool000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Ko
oooo00?o0000ooooooooool0>Oooool2o`0002gooooo0_l00011ooooo`;o00005oooool2o`0004;o
oooo0_l0000Iooooo`;o00008_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0D?ooool2o`00
06Oooooo0_l0001=ooooo`;o00008oooool2o`0001Sooooo0003ooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0001@ooooo`;o0000:?ooool2
o`0003cooooo0ol0000Wooooo`;o0000BOooool2o`0000Gooooo0_l0000Aooooo`000oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oo
oooooooo07[ooooo0_l0000>ooooo`;o0000;?ooool2o`0002Sooooo0_l0001@ooooo`;o00004Ooo
ool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
1Oooool2o`0008cooooo0_l0002kooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo
00?oEEEEohN7Qoooool01oooool2o`0007Cooooo0_l0003Cooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool01?l0003oooooooooooooool2o`0003?o
oooo0_l000000ooooooo0000o`00000gooooo`;o0000KOooool2o`0002[ooooo0_l0000hooooo`00
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_ooool01?l0
003oooooooooooooool2o`0002?ooooo0_l0000>ooooo`;o000000?oooooo`000?l00000Y_ooool2
o`0001Kooooo0_l0000Booooo`;o0000>?ooool001kooooo00?o0000ooooooooool08_ooool2o`00
00;ooooo0_l0003=ooooo`;o00000_ooool2o`0004Gooooo0_l00005ooooo`007_ooool00ol0003o
ooooooooo`0Rooooo`;o0000Zoooool2o`0002Cooooo0_l00019ooooo`;o00001Oooool001kooooo
00?o0000ooooooooool00_ooool2o`0005_ooooo0_l0000Eooooo`;o0000Eoooool2o`0002_ooooo
0_l0000Cooooo`;o0000=?ooool001kooooo00?o0000ooooooooool00_ooool2o`0005_ooooo0_l0
000Eooooo`;o0000??ooool2o`0001[ooooo0_l0000Zooooo`;o00004oooool3o`0000;ooooo0_l0
000_ooooo`007_ooool00ol0003oooooooooo`0hooooo`;o0000>_ooool2o`0002oooooo1?l0000;
ooooo`;o00006_ooool2o`00043ooooo0_l00002ooooo`;o0000;oooool001kooooo00?o0000oooo
ooooool04_ooool2o`0002Cooooo0_l0000jooooo`;o0000;oooool4o`0000oooooo0_l0000Loooo
o`;o0000F?ooool2o`0000kooooo0_l00005ooooo`007_ooool00ol0003oooooooooo`0Booooo`;o
0000M?ooool2o`0002kooooo0_l0000Looooo`;o0000F?ooool2o`0000kooooo0_l00005ooooo`00
7_ooool00ol0003oooooooooo`28ooooo`;o00004_ooool2o`0009[ooooo0_l0000=ooooo`007_oo
ool00ol0003oooooooooo`0Oooooo`;o0000<_ooool2o`0004Oooooo0_l0002Jooooo`;o00003Ooo
ool001kooooo00?o0000ooooooooool07oooool2o`0003;ooooo0_l0001?ooooo`;o0000B?ooool2
o`0002gooooo0_l0000Xooooo`007_ooool00ol0003oooooooooo`1hooooo`;o00008?ooool2o`00
00Kooooo1?l00018ooooo`;o0000;Oooool2o`0002Sooooo000Nooooo`;o00007?ooool4o`0005Wo
oooo0_l0000Aooooo`;o00003Oooool2o`0000Kooooo0_l0001@ooooo`;o00003Oooool2o`0004;o
oooo000Nooooo`03o`000?oooooooooo01_ooooo1?l0000;ooooo`;o0000Goooool2o`0006Oooooo
0_l0000=ooooo`;o0000@_ooool001kooooo00?o0000ooooooooool0:_ooool2o`0002_ooooo0_l0
001Vooooo`;o0000>_ooool2o`0000Gooooo0_l00013ooooo`007_ooool00ol0003oooooooooo`1G
ooooo`;o0000:?ooool2o`0000oooooo0_l0000[ooooo`;o0000>_ooool2o`0000Gooooo0_l00013
ooooo`007_ooool00ol0003oooooooooo`1[ooooo`;o00005?ooool2o`0000oooooo0_l0000Eoooo
o`;o00008Oooool2o`00057ooooo0_l0000Vooooo`007_ooool00ol0003oooooooooo`0Yooooo`;o
0000@?ooool2o`0003cooooo0_l0000Qooooo`;o0000DOooool3o`0002Gooooo000Nooooo`03o`00
0?oooooooooo01cooooo0_l0000;ooooo`;o00007_ooool2o`0001Oooooo0_l0000]ooooo`;o0000
@Oooool2o`0001Gooooo0_l0000cooooo`;o00009Oooool001kooooo00?o0000ooooooooool07?oo
ool2o`0002_ooooo0_l0000Gooooo`;o0000;Oooool2o`00047ooooo0_l0000Eooooo`;o0000F_oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`0Ooooo
o`;o0000oooooolCooooo`;o00004_ooool001kooooo00?o0000ooooooooool07oooool2o`0003Go
oooo0_l0002cooooo`;o00009_ooool2o`0001;ooooo000Nooooo`03o`000?oooooooooo05Kooooo
0_l0002Wooooo`;o00002_ooool2o`00013ooooo0_l0000Xooooo`007_ooool00ol0003ooooooooo
o`2[ooooo`;o0000D_ooool2o`0001cooooo0_l0000Xooooo`007_ooool00ol0003oooooooooo`0S
ooooo`;o0000;_ooool2o`0005Kooooo0_l0002Jooooo`007_ooool00ol0003oooooooooo`0Soooo
o`;o0000;_ooool2o`00043ooooo0_l0002`ooooo`007_ooool00ol0003oooooooooo`0Xooooo`;o
0000Joooool2o`00077ooooo0_l0000[ooooo`;o00004?ooool001kooooo0_l0000Yooooo`;o0000
P_ooool2o`0001Kooooo0_l00012ooooo`;o0000:oooool2o`00013ooooo000Nooooo`03o`000?oo
oooooooo01Sooooo0_l00011ooooo`;o0000Coooool2o`0001Kooooo0_l0001Zooooo`;o00005Ooo
ool001kooooo00?o0000ooooooooool00_ooool2o`0001?ooooo0ol00010ooooo`?o00006Oooool2
o`0002_ooooo0_l0002;ooooo`;o00005Oooool001kooooo00?o0000ooooooooool00_ooool2o`00
01?ooooo0_l0000gooooo`;o00002?ooool2o`0001[ooooo0_l0000[ooooo`;o00006_ooool3o`00
01[ooooo0_l0001Yooooo`007_ooool00ol0003oooooooooo`1@ooooo`;o0000E_ooool2o`0001Go
oooo0ol0000Jooooo`;o0000JOooool001kooooo00?o0000ooooooooool0NOooool2o`0002Oooooo
0_l00004ooooo`;o0000N_ooool2o`00027ooooo000Nooooo`03o`000?oooooooooo04[ooooo0_l0
000]ooooo`;o00009oooool2o`0002Wooooo1?l00017ooooo`;o00002_ooool2o`00027ooooo000N
ooooo`03o`000?oooooooooo01Oooooo0_l0000aooooo`;o00001_ooool2o`0007Wooooo1?l00017
ooooo`;o00009Oooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0000Joooo
o`;o00007Oooool2o`0008kooooo0_l00008ooooo`;o0000>?ooool2o`0001Oooooo0_l00006oooo
o`007_ooool00ol0003oooooooooo`0cooooo`;o0000P_ooool2o`0002Wooooo0_l00008ooooo`;o
0000>?ooool2o`0001oooooo000Nooooo`03o`000?oooooooooo0;Oooooo0_l0000cooooo`;o0000
FOooool001kooooo00?o0000ooooooooool0^Oooool2o`0001;ooooo0_l0000Mooooo`;o00001ooo
ool2o`00017ooooo0_l0000mooooo`007_ooool00ol0003oooooooooo`2iooooo`;o00004_ooool2
o`0002Kooooo0_l0000Aooooo`;o00001Oooool2o`0003Kooooo000Nooooo`03o`000?oooooooooo
08?ooooo0_l0001Oooooo`;o0000:Oooool2o`0003Kooooo000Nooooo`03o`000?oooooooooo08?o
oooo0_l0000Zooooo`;o00004oooool2o`0001kooooo0_l0001Qooooo`007_ooool00ol0003ooooo
ooooo`1gooooo`;o0000=_ooool2o`0001?ooooo0_l0000cooooo`;o00006Oooool2o`0001kooooo
0_l0000Aooooo`007_ooool2o`0001_ooooo0_l0000Looooo`;o00003Oooool2o`0001;ooooo0_l0
000Jooooo`;o0000JOooool2o`0001Gooooo0_l0000;ooooo`;o00003?ooool2o`0001kooooo0_l0
000Aooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o00007?ooool2o`0000gooooo0_l0000B
ooooo`;o0000QOooool2o`0002;ooooo0_l0000Fooooo`;o00006?ooool2o`0000gooooo000Noooo
o`03o`000?oooooooooo0;Gooooo0_l0000Mooooo`;o0000B?ooool2o`0001Sooooo0_l0000=oooo
o`007_ooool00ol0003oooooooooo`04ooooo`;o0000C?ooool2o`00067ooooo0_l0000Mooooo`;o
00007Oooool2o`0005;ooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0001<ooooo`;o0000
<Oooool2o`0006cooooo0_l0000cooooo`;o00007Oooool001kooooo00?o0000ooooooooool04?oo
ool2o`0007?ooooo0_l0000Nooooo`;o00003?ooool2o`0007?ooooo0_l0000Mooooo`007_ooool2
o`00017ooooo0_l0002Cooooo`;o00003?ooool2o`0009;ooooo000Nooooo`;o0000??ooool2o`00
09gooooo0_l0000Rooooo`;o0000;Oooool2o`0001Sooooo000Nooooo`03o`000?oooooooooo03_o
oooo0_l0002Mooooo`;o00008_ooool2o`0002gooooo0_l0000Hooooo`007_ooool00ol0003ooooo
ooooo`3oooooocgooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3:ooooo`;o0000;ooo
ool2o`0003oooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`1/ooooo`;o0000@oooool2
o`0001Oooooo0_l0000_ooooo`;o0000>_ooool2o`0000Sooooo0_l00004ooooo`007_ooool00ol0
003oooooooooo`1/ooooo`;o00007_ooool2o`0002?ooooo0ol0000Booooo`;o0000Koooool2o`00
00Sooooo0_l00004ooooo`007_ooool00ol0003oooooooooo`27ooooo`;o00000oooool2o`0002Co
oooo0_l0000Booooo`;o00008Oooool2o`0004Kooooo0_l0000Dooooo`000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0
003oooooooooo`27ooooo`;o00003Oooool2o`00057ooooo0_l00016ooooo`;o00005?ooool000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q00Kooooo00?o0000ooooooooool0U_ooool2o`00013ooooo0_l0002Mooooo`000oooool01Ol@
413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o00002_oo
ool2o`0006_ooooo0_l0000_ooooo`;o00006Oooool2o`00017ooooo0_l0000Pooooo`;o00009_oo
ool2o`0002Gooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooo
oonHV9So<S8b00Kooooo00?o0000ooooooooool01?ooool2o`0000Cooooo1?l0001Iooooo`Co0000
3?ooool2o`0004[ooooo0_l0000Aooooo`;o00008?ooool2o`0002Kooooo0_l0000Uooooo`000ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03
o`000?oooooooooo00Cooooo0_l00006ooooo`;o0000FOooool4o`0007Gooooo0ol00002ooooo`;o
00004Oooool2o`0003Sooooo0_l0000Cooooo`000oooool01Ol@413ooooooooooooooooo410@00_o
oooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo07Oooooo0_l0000]oooo
o`;o0000>?ooool3o`0000;ooooo0_l0001;ooooo`;o00004oooool000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`1g
ooooo`;o00005_ooool2o`0000kooooo0_l00005ooooo`;o00002oooool2o`0004;ooooo0_l0001>
ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVY
Z@06ooooo`03o`000?oooooooooo00;ooooo0_l0000Jooooo`;o0000Koooool2o`0000kooooo0_l0
000Booooo`;o0000@_ooool2o`0001kooooo0_l0000^ooooo`007_ooool00ol0003oooooooooo`02
ooooo`;o00006_ooool2o`0008Cooooo0_l0000Zooooo`;o0000AOooool2o`0002kooooo000Noooo
o`03o`000?oooooooooo0:Cooooo0_l0000Hooooo`;o00004?ooool2o`00027ooooo0_l0001Boooo
o`007_ooool00ol0003oooooooooo`0Fooooo`;o0000=oooool2o`0004;ooooo0_l0000Yooooo`;o
0000<oooool2o`0001Sooooo0_l0000hooooo`007_ooool00ol0003oooooooooo`0Fooooo`;o0000
;?ooool2o`0000Wooooo0_l0000?ooooo`;o0000<Oooool2o`00063ooooo0_l0000Fooooo`;o0000
>?ooool001kooooo00?o0000ooooooooool09Oooool2o`0001gooooo0_l0000Jooooo`;o0000;Ooo
ool2o`0006Cooooo0_l0001@ooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o00002oooool2
o`0006Sooooo0_l0001cooooo`;o0000@Oooool001kooooo00?o0000ooooooooool06?ooool2o`00
00gooooo0_l00007ooooo`;o00002?ooool2o`000;Sooooo0_l0000>ooooo`;o0000@Oooool001ko
oooo00?o0000ooooooooool09oooool2o`0000Oooooo0_l00008ooooo`;o00005oooool2o`0008Ko
oooo0_l0000Gooooo`;o0000DOooool001kooooo00?o0000ooooooooool0Doooool2o`0008Kooooo
0_l0000Eooooo`;o0000:Oooool2o`0002Sooooo000Nooooo`03o`000?oooooooooo05?ooooo0_l0
001kooooo`;o00001Oooool2o`000003ooooool0003o000001Kooooo0_l0000Yooooo`;o0000:?oo
ool001kooooo00?o0000ooooooooool0JOooool2o`0005oooooo0_l00004ooooo`;o00001Oooool2
o`000003ooooool0003o000001Sooooo0_l0001Aooooo`007_ooool2o`0006[ooooo0_l0000Uoooo
o`;o0000>?ooool2o`0002Sooooo0_l0000hooooo`;o00005oooool001kooooo00?o0000oooooooo
ool00_l0000Mooooo`;o0000;Oooool2o`0002[ooooo0_l0000Dooooo`;o0000Goooool2o`0003So
oooo0_l000000ooooooo0000o`00000Gooooo`007_ooool00ol0003oooooooooo`02o`0000oooooo
0_l0000<ooooo`;o0000;Oooool2o`00017ooooo0_l0000Gooooo`;o0000MOooool2o`0001kooooo
0_l0000Hooooo`;o00001oooool2o`00017ooooo000Nooooo`03o`000?oooooooooo017ooooo0_l0
001>ooooo`;o0000;oooool2o`0002Oooooo0_l0000iooooo`;o00006Oooool2o`0001cooooo0_l0
0003ooooo`;o00004Oooool001kooooo00?o0000ooooooooool02Oooool2o`0005Gooooo0_l0000`
ooooo`;o00009oooool2o`0002[ooooo0_l0000=ooooo`;o0000=oooool2o`0001Kooooo000Noooo
o`03o`000?oooooooooo00Wooooo0_l0001Eooooo`;o0000QOooool2o`0005kooooo000Nooooo`03
o`000?oooooooooo09Cooooo0_l0000@ooooo`;o0000Woooool001kooooo00?o0000ooooooooool0
Ooooool2o`0001?ooooo0_l00008ooooo`;o00001_ooool2o`0001kooooo0_l0000Jooooo`;o0000
<?ooool2o`00037ooooo000Nooooo`03o`000?oooooooooo07oooooo0_l0000Mooooo`;o00009_oo
ool2o`0001[ooooo0ol0000_ooooo`;o0000<Oooool001kooooo00?o0000ooooooooool0P?ooool3
o`0000Sooooo0_l0001Booooo`;o00000_ooool2o`00033ooooo0_l0000`ooooo`007_ooool00ol0
003oooooooooo`20ooooo`?o00002?ooool2o`0005;ooooo0_l0000dooooo`;o00008?ooool2o`00
00kooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0000Aooooo`;o0000>Oooool2o`0001_o
oooo0_l00031ooooo`;o00003_ooool001kooooo00?o0000ooooooooool02Oooool2o`00017ooooo
0_l0000Vooooo`;o00004Oooool2o`0001_ooooo0_l00014ooooo`?o00007_ooool2o`0006[ooooo
000Nooooo`03o`000?oooooooooo033ooooo0_l0000Booooo`;o0000M?ooool3o`0001;ooooo0_l0
000:ooooo`;o0000C?ooool2o`0001cooooo000Nooooo`03o`000?oooooooooo033ooooo0_l0001F
ooooo`;o0000AOooool2o`0000cooooo0_l0000Qooooo`;o00009oooool2o`0001cooooo000Noooo
o`03o`000?oooooooooo03[ooooo0_l0001<ooooo`;o00008?ooool2o`0001cooooo0_l0000Coooo
o`;o00008Oooool2o`0004Gooooo000Nooooo`;o0000>oooool2o`0002;ooooo0_l0001:ooooo`;o
00007?ooool2o`0002[ooooo0_l0001Aooooo`007_ooool00ol0003oooooooooo`1Nooooo`;o0000
>oooool2o`0000gooooo0_l00018ooooo`;o0000DOooool001kooooo00?o0000ooooooooool0FOoo
ool2o`0000?ooooo0_l0000Fooooo`;o00004oooool2o`0000kooooo0_l0000:ooooo`;o0000@_oo
ool2o`0000Sooooo0_l00017ooooo`;o00001oooool001kooooo00?o0000ooooooooool02_ooool2
o`0004gooooo0_l00003ooooo`;o00003?ooool2o`0000Sooooo0_l0000Cooooo`?o00006Oooool2
o`0004;ooooo0_l00008ooooo`;o00004Oooool2o`0000Sooooo0_l00004ooooo`;o00009?ooool2
o`0000Oooooo000Nooooo`03o`000?oooooooooo00Sooooo1?l0000[ooooo`;o0000<oooool2o`00
01kooooo0_l0001Gooooo`;o00008Oooool2o`0000Sooooo0_l00004ooooo`;o0000;Oooool001ko
oooo00?o0000ooooooooool02?ooool2o`0002gooooo0_l0002/ooooo`;o0000H?ooool001kooooo
00?o0000ooooooooool0/_ooool2o`00057ooooo0_l0000Booooo`;o00008?ooool2o`0000[ooooo
000Nooooo`03o`000?oooooooooo00Gooooo0_l0000]ooooo`;o0000I?ooool2o`0001Kooooo0_l0
001Aooooo`;o00004_ooool2o`00023ooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`05
ooooo`;o00001_ooool2o`0002Gooooo0_l0001Pooooo`?o000000?oooooo`000?l00000B?ooool2
o`00067ooooo000Nooooo`03o`000?oooooooooo00gooooo0_l0000Booooo`?o0000L_ooool3o`00
04_ooooo0_l0001Jooooo`;o00001Oooool001kooooo00?o0000ooooooooool04Oooool2o`0000ko
oooo0ol0003oooooo`7ooooo0_l0000Jooooo`;o00001Oooool001kooooo00?o0000ooooooooool0
1?ooool3o`0000[ooooo0_l0000aooooo`;o0000boooool2o`00017ooooo0_l0000Qooooo`007_oo
ool00ol0003oooooooooo`04ooooo`?o0000?Oooool2o`000:Wooooo0_l0000Pooooo`;o0000=?oo
ool001kooooo00?o0000ooooooooool02_ooool2o`0000Oooooo0_l00013ooooo`;o0000NOooool2
o`0001[ooooo0_l0001Fooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o00001_ooool3o`00
04?ooooo0_l0001iooooo`;o0000L_ooool001kooooo00?o0000ooooooooool04_ooool2o`0002_o
oooo0_l0000Mooooo`;o0000B?ooool2o`00027ooooo0_l0001_ooooo`;o00002Oooool001kooooo
0_l00010ooooo`;o00007Oooool2o`0004Sooooo0_l0000Qooooo`;o00001?ooool2o`0001Kooooo
0_l0001Aooooo`;o00002Oooool001kooooo00?o0000ooooooooool0IOooool2o`0006[ooooo0ol0
000Eooooo`;o0000G?ooool001kooooo00?o0000ooooooooool04oooool2o`0000?ooooo0_l0000D
ooooo`;o00004Oooool2o`0001Oooooo0_l00009ooooo`;o0000Eoooool2o`0001;ooooo0_l0001F
ooooo`;o00006oooool001kooooo00?o0000ooooooooool04oooool2o`0000?ooooo0_l0000Doooo
o`;o00002oooool2o`0000Cooooo0_l0000Gooooo`;o0000?oooool2o`0000Wooooo0_l0000Foooo
o`;o0000J_ooool2o`0001_ooooo000Nooooo`03o`000?oooooooooo03_ooooo0_l0001Nooooo`;o
00002Oooool2o`0001_ooooo0_l0000>ooooo`;o0000L_ooool001kooooo00?o0000ooooooooool0
<?ooool2o`00097ooooo0_l0000>ooooo`;o0000L_ooool001kooooo00?o0000ooooooooool0<?oo
ool2o`00013ooooo0_l0002=ooooo`;o0000F?ooool2o`0001[ooooo000Nooooo`03o`000?oooooo
oooo04;ooooo0_l0000Sooooo`;o0000J?ooool2o`0005Sooooo0_l0000Jooooo`007_ooool00ol0
003oooooooooo`15ooooo`;o00008?ooool2o`00017ooooo0_l0002Rooooo`;o00007Oooool2o`00
00Sooooo000Nooooo`03o`000?oooooooooo04Gooooo0_l0000cooooo`;o00006Oooool2o`0008Oo
oooo0_l0000Mooooo`;o00002?ooool001kooooo00?o0000ooooooooool0UOooool2o`000;3ooooo
000Nooooo`03o`000?oooooooooo01[ooooo0_l0003oooooo`?ooooo0_l0000Wooooo`007_ooool0
0ol0003oooooooooo`0Jooooo`;o0000g_ooool2o`0002;ooooo0_l0000Wooooo`007_ooool00ol0
003oooooooooo`1Looooo`;o0000W?ooool2o`0001gooooo0_l0000/ooooo`005?ooool4o`000003
oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0=Oooool2o`0002Gooooo0_l0002kooooo`;o
0000;?ooool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0>ooooo`;o0000
9Oooool2o`0005kooooo0_l0000Iooooo`;o00001?ooool2o`0007Sooooo0_l00005ooooo`;o0000
3_ooool001Kooooo00?o0000ooooooooool01Oooool3o`0000kooooo0_l00025ooooo`;o00006Ooo
ool2o`0000Cooooo0_l0000Looooo`;o0000E?ooool2o`0000Cooooo0_l00005ooooo`;o00003_oo
ool001Kooooo00?o0000ooooooooool0g?ooool2o`0005Cooooo0_l0000Kooooo`005_ooool00ol0
003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo
00?o0000ooooooooool0oooooom@ooooo`005?ooool00omEEEGoIVIVo`00003ooooooe;ooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.66886 .40279 Mdot
.32174 .42553 Mdot
.83403 .48106 Mdot
.22998 .50315 Mdot
.49189 .16476 Mdot
.59374 .54909 Mdot
.70815 .41026 Mdot
.00278 .94832 Mdot
.12315 .40763 Mdot
.97158 .91159 Mdot
.37861 .49652 Mdot
.03711 .01267 Mdot
.24383 .61243 Mdot
.20493 .11374 Mdot
.87723 .62226 Mdot
.42826 .07749 Mdot
.85308 .00369 Mdot
.35276 .98288 Mdot
.7281 .06955 Mdot
.79952 .59443 Mdot
.03939 .18393 Mdot
.34682 .16109 Mdot
.1333 .1319 Mdot
.77152 .6182 Mdot
.43125 .03687 Mdot
.01522 .05427 Mdot
.06205 .96679 Mdot
.05796 .50728 Mdot
.67447 .42385 Mdot
.21616 .05802 Mdot
.50778 .93488 Mdot
.87773 .02349 Mdot
.99414 .18478 Mdot
.06275 .30337 Mdot
.33237 .51121 Mdot
.8488 .15395 Mdot
.35742 .04271 Mdot
.26558 .56219 Mdot
.80489 .51586 Mdot
.66508 .5915 Mdot
.59899 .59916 Mdot
.97128 .09063 Mdot
.56431 .24473 Mdot
.55664 .57068 Mdot
.02037 .48743 Mdot
.02963 .76121 Mdot
.23418 .43427 Mdot
.7361 .02732 Mdot
.36633 .95173 Mdot
.91139 .00867 Mdot
.00575 .89888 Mdot
.69207 .89192 Mdot
.95482 .76259 Mdot
.29062 .34609 Mdot
.86207 .06752 Mdot
.19797 .30699 Mdot
.34243 .10893 Mdot
.69409 .01971 Mdot
.62977 .20069 Mdot
.51014 .44346 Mdot
.7986 .79542 Mdot
.05404 .97808 Mdot
.24172 .41464 Mdot
.77744 .559 Mdot
.83896 .12811 Mdot
.03784 .76854 Mdot
.39968 .49926 Mdot
.31328 .97454 Mdot
.54097 .94921 Mdot
.08393 .42156 Mdot
.38305 .1949 Mdot
.05013 .44349 Mdot
.07604 .97631 Mdot
.44994 .03218 Mdot
.32941 .10482 Mdot
.13939 .92477 Mdot
.02531 .41908 Mdot
.62736 .62116 Mdot
.18343 .47233 Mdot
.83483 .15551 Mdot
.17533 .96373 Mdot
.23099 .30138 Mdot
.27361 .31726 Mdot
.64107 .28907 Mdot
.71871 .80322 Mdot
.64232 .83508 Mdot
.84513 .24375 Mdot
.96134 .36145 Mdot
.25918 .35946 Mdot
.89266 .18564 Mdot
.56128 .41684 Mdot
.50651 .49648 Mdot
.92128 .95506 Mdot
.85259 .73434 Mdot
.12662 .16517 Mdot
.67759 .97509 Mdot
.94791 .82555 Mdot
.49471 .66688 Mdot
.64257 .05674 Mdot
.95575 .75567 Mdot
.90425 .134 Mdot
.62503 .01875 Mdot
.79772 .24691 Mdot
.56529 .98736 Mdot
.42602 .88053 Mdot
.26591 .78966 Mdot
.77444 .26763 Mdot
.1472 .29109 Mdot
.28119 .96775 Mdot
.11425 .15641 Mdot
.16689 .45909 Mdot
.69387 .92125 Mdot
.72665 .78002 Mdot
.53311 .36373 Mdot
.47791 .98175 Mdot
.42656 .85391 Mdot
.58983 .62497 Mdot
.68588 .59411 Mdot
.34227 .92233 Mdot
.07165 .79937 Mdot
.55449 .45898 Mdot
.43641 .07478 Mdot
.90792 .51188 Mdot
.29458 .68498 Mdot
.63958 .19183 Mdot
.23053 .86181 Mdot
.73901 .70897 Mdot
.35004 .46136 Mdot
.61171 .62468 Mdot
.11032 .40215 Mdot
.767 .2616 Mdot
.59327 .0918 Mdot
.80926 .33203 Mdot
.59932 .48176 Mdot
.35683 .34178 Mdot
.87589 .31796 Mdot
.23237 .58046 Mdot
.08498 .9304 Mdot
.04164 .32325 Mdot
.29635 .99263 Mdot
.89247 .16077 Mdot
.64211 .05603 Mdot
.57891 .48087 Mdot
.61272 .5038 Mdot
.2997 .69906 Mdot
.45757 .49937 Mdot
.41351 .89744 Mdot
.11535 .74207 Mdot
.66037 .86662 Mdot
.48112 .25859 Mdot
.14681 .96859 Mdot
.72554 .81633 Mdot
.80979 .32956 Mdot
.55188 .19051 Mdot
.68544 .29655 Mdot
.4661 .2307 Mdot
.89506 .08689 Mdot
.50657 .24462 Mdot
.00717 .7412 Mdot
.9042 .95685 Mdot
.79844 .34037 Mdot
.85462 .24606 Mdot
.18169 .87029 Mdot
.7175 .89633 Mdot
.93575 .05795 Mdot
.62078 .25351 Mdot
.71373 .29293 Mdot
.68902 .49659 Mdot
.34836 .66584 Mdot
.76594 .78891 Mdot
.79424 .43111 Mdot
.38157 .38093 Mdot
.47361 .57069 Mdot
.95722 .59545 Mdot
.72853 .15794 Mdot
.6905 .24077 Mdot
.33621 .62688 Mdot
.52369 .46829 Mdot
.06425 .81197 Mdot
.30139 .43275 Mdot
.26006 .66756 Mdot
.03739 .16486 Mdot
.99807 .67408 Mdot
.20087 .23842 Mdot
.99426 .63277 Mdot
.80196 .20605 Mdot
.71606 .96488 Mdot
.54051 .4192 Mdot
.91981 .86188 Mdot
.46223 .52275 Mdot
.31024 .49762 Mdot
.63802 .5421 Mdot
.51865 .36828 Mdot
.0072 .92818 Mdot
.05475 .18448 Mdot
.34522 .12799 Mdot
.63947 .07574 Mdot
.09487 .46193 Mdot
.37365 .58153 Mdot
.10873 .48974 Mdot
.95512 .25178 Mdot
.12528 .52779 Mdot
.1133 .31709 Mdot
.02234 .51193 Mdot
.12568 .38905 Mdot
.49324 .1345 Mdot
.52601 .73818 Mdot
.69539 .45119 Mdot
.46497 .13941 Mdot
.0383 .50807 Mdot
.56942 .01034 Mdot
.45606 .56198 Mdot
.13406 .27505 Mdot
.8627 .54641 Mdot
.50789 .52587 Mdot
.29317 .56448 Mdot
.91884 .59716 Mdot
.3238 .99492 Mdot
.83272 .40309 Mdot
.15289 .001 Mdot
.95497 .70895 Mdot
.57354 .94519 Mdot
.81984 .17204 Mdot
.67216 .93643 Mdot
.24006 .42616 Mdot
.27834 .85755 Mdot
.26662 .35227 Mdot
.50823 .82852 Mdot
.87446 .263 Mdot
.6188 .28574 Mdot
.47338 .41114 Mdot
.99141 .84497 Mdot
.05191 .2479 Mdot
.89425 .35121 Mdot
.69785 .61301 Mdot
.78691 .96054 Mdot
.93441 .73976 Mdot
.96194 .58019 Mdot
.20262 .86982 Mdot
.00474 .25367 Mdot
.80831 .03311 Mdot
.87241 .43167 Mdot
.79072 .17473 Mdot
.4036 .1157 Mdot
.26623 .34941 Mdot
.96326 .29476 Mdot
.01418 .26945 Mdot
.73734 .88419 Mdot
.65675 .07898 Mdot
.3395 .77823 Mdot
.95772 .7456 Mdot
.84025 .95827 Mdot
.62139 .15539 Mdot
.53711 .08855 Mdot
.37167 .55742 Mdot
.66726 .41971 Mdot
.66034 .74363 Mdot
.14837 .56405 Mdot
.05428 .94627 Mdot
.84892 .25802 Mdot
.98509 .40355 Mdot
.10327 .92334 Mdot
.57511 .13535 Mdot
.71933 .44057 Mdot
.40853 .50273 Mdot
.75807 .89313 Mdot
.56486 .38823 Mdot
.5465 .00362 Mdot
.46529 .20694 Mdot
.90998 .95989 Mdot
.89252 .71864 Mdot
.51546 .1622 Mdot
.37615 .84847 Mdot
.92385 .75774 Mdot
.36753 .26273 Mdot
.67808 .82945 Mdot
.41551 .29746 Mdot
.47588 .37209 Mdot
.39212 .33088 Mdot
.47185 .86463 Mdot
.4289 .70392 Mdot
.02252 .44289 Mdot
.06317 .41458 Mdot
.05544 .80777 Mdot
.18303 .04366 Mdot
.67315 .56491 Mdot
.36838 .31296 Mdot
.44322 .20241 Mdot
.45034 .58083 Mdot
.4345 .3535 Mdot
.49 .75582 Mdot
.51335 .96672 Mdot
.53034 .55804 Mdot
.90092 .99474 Mdot
.9913 .63917 Mdot
.40361 .69542 Mdot
.25348 .08619 Mdot
.22869 .68373 Mdot
.38439 .20926 Mdot
.32439 .92723 Mdot
.50077 .08821 Mdot
.3707 .10786 Mdot
.48089 .85416 Mdot
.40352 .6639 Mdot
.38457 .83469 Mdot
.93026 .15151 Mdot
.91015 .69814 Mdot
.05243 .90713 Mdot
.17763 .09823 Mdot
.31524 .77647 Mdot
.27138 .44576 Mdot
.45144 .32185 Mdot
.30793 .82468 Mdot
.53795 .70647 Mdot
.36112 .51771 Mdot
.67506 .55946 Mdot
.50362 .13624 Mdot
.30529 .92421 Mdot
.02137 .9704 Mdot
.76955 .46393 Mdot
.3905 .31983 Mdot
.93309 .24314 Mdot
.65615 .38759 Mdot
.02057 .38293 Mdot
.85271 .04492 Mdot
.94058 .22341 Mdot
.95665 .06759 Mdot
.70474 .1187 Mdot
.01344 .3707 Mdot
.85014 .72188 Mdot
.45751 .96793 Mdot
.62947 .73196 Mdot
.61196 .10608 Mdot
.16128 .01505 Mdot
.43084 .16485 Mdot
.68745 .12297 Mdot
.07179 .59907 Mdot
.27341 .44653 Mdot
.59178 .08921 Mdot
.05108 .80292 Mdot
.09814 .14143 Mdot
.63138 .61797 Mdot
.12527 .70988 Mdot
.58491 .44645 Mdot
.0172 .15725 Mdot
.86508 .87966 Mdot
.08864 .43296 Mdot
.74653 .29648 Mdot
.54088 .30157 Mdot
.91151 .3966 Mdot
.42154 .79513 Mdot
.39853 .07971 Mdot
.83929 .20325 Mdot
.21363 .9192 Mdot
.24609 .91204 Mdot
.17601 .00835 Mdot
.66622 .30575 Mdot
.78332 .65724 Mdot
.04081 .4197 Mdot
.62386 .82503 Mdot
.0353 .55867 Mdot
.13397 .97035 Mdot
.10837 .33795 Mdot
.26486 .33327 Mdot
.78654 .66483 Mdot
.50606 .90183 Mdot
.0364 .232 Mdot
.84686 .32078 Mdot
.85036 .35641 Mdot
.61158 .19 Mdot
.29596 .46818 Mdot
.5562 .90041 Mdot
.77786 .34414 Mdot
.85806 .4982 Mdot
.15534 .57083 Mdot
.15685 .59895 Mdot
.79506 .42648 Mdot
.11167 .26712 Mdot
.26645 .74469 Mdot
.79561 .36764 Mdot
.8468 .85407 Mdot
.65197 .63636 Mdot
.02776 .9178 Mdot
.63734 .24465 Mdot
.78932 .08663 Mdot
.22016 .30584 Mdot
.11967 .95551 Mdot
.53147 .26751 Mdot
.86627 .06055 Mdot
.97733 .47109 Mdot
.03928 .84079 Mdot
.66348 .62092 Mdot
.62979 .43717 Mdot
.5475 .42836 Mdot
.1199 .00599 Mdot
.38691 .6354 Mdot
.81133 .47438 Mdot
.68465 .85353 Mdot
.14802 .99512 Mdot
.63216 .14054 Mdot
.8421 .46255 Mdot
.12847 .15147 Mdot
.34512 .16456 Mdot
.96656 .97043 Mdot
.16894 .24542 Mdot
.87882 .08161 Mdot
.60941 .70004 Mdot
.0575 .92454 Mdot
.24781 .74138 Mdot
.9089 .58406 Mdot
.5688 .22024 Mdot
.75357 .00773 Mdot
.18695 .21076 Mdot
.13962 .41213 Mdot
.38896 .5026 Mdot
.73238 .89222 Mdot
.72963 .8109 Mdot
.27763 .36236 Mdot
.70423 .5742 Mdot
.80259 .90081 Mdot
.8829 .34629 Mdot
.41507 .83842 Mdot
.88304 .6575 Mdot
.09363 .31605 Mdot
.12943 .93058 Mdot
.40482 .46706 Mdot
.27566 .8811 Mdot
.21143 .13503 Mdot
.05626 .59048 Mdot
.45094 .32869 Mdot
.91189 .50565 Mdot
.18877 .87288 Mdot
.48419 .69813 Mdot
.35084 .56889 Mdot
.12605 .49991 Mdot
.69374 .72815 Mdot
.44451 .10603 Mdot
.75428 .73402 Mdot
.7297 .69214 Mdot
.09713 .13769 Mdot
.17761 .63263 Mdot
.18585 .35661 Mdot
.80973 .63322 Mdot
.44737 .95612 Mdot
.78858 .45382 Mdot
.64561 .93409 Mdot
.19296 .43908 Mdot
.46214 .66579 Mdot
.23533 .79669 Mdot
.13603 .39552 Mdot
.01587 .57194 Mdot
.56568 .74209 Mdot
.40146 .48639 Mdot
.81749 .9109 Mdot
.13168 .30437 Mdot
.84999 .39677 Mdot
.79538 .34502 Mdot
.68379 .01031 Mdot
.06991 .45219 Mdot
.74435 .89141 Mdot
.36915 .15526 Mdot
.12429 .02328 Mdot
.77764 .04292 Mdot
.10737 .75428 Mdot
.93848 .08997 Mdot
.74095 .31481 Mdot
.3564 .23262 Mdot
.36734 .35092 Mdot
.01855 .33216 Mdot
.12619 .87839 Mdot
.41734 .39219 Mdot
.82653 .44639 Mdot
.5791 .81287 Mdot
.21678 .96956 Mdot
.23486 .25061 Mdot
.66802 .70681 Mdot
.82592 .70374 Mdot
.38005 .86629 Mdot
.01317 .92112 Mdot
.57457 .98392 Mdot
.45311 .04243 Mdot
.8623 .63211 Mdot
.5982 .19842 Mdot
.50807 .72394 Mdot
.46015 .91512 Mdot
.83869 .28297 Mdot
.76527 .11966 Mdot
.74436 .049 Mdot
.46911 .94616 Mdot
.83106 .62832 Mdot
.99324 .47854 Mdot
.70865 .19858 Mdot
.99399 .93504 Mdot
.37347 .03092 Mdot
.98892 .26326 Mdot
.35507 .82229 Mdot
.97081 .89119 Mdot
.98921 .09135 Mdot
.69168 .20663 Mdot
.80613 .50897 Mdot
.76475 .8209 Mdot
.53107 .3537 Mdot
.31362 .84097 Mdot
.2786 .69242 Mdot
.85755 .41981 Mdot
.4284 .23169 Mdot
.34511 .68998 Mdot
.60643 .85942 Mdot
.87734 .32803 Mdot
.06762 .28934 Mdot
.74573 .64145 Mdot
.70473 .32922 Mdot
.44704 .29568 Mdot
.73647 .42937 Mdot
.66808 .98613 Mdot
.92833 .18184 Mdot
.33404 .05224 Mdot
.98535 .50962 Mdot
.48156 .79712 Mdot
.92485 .12622 Mdot
.0476 .91957 Mdot
.42455 .27437 Mdot
.87472 .81042 Mdot
.16566 .49018 Mdot
.87661 .07405 Mdot
.98237 .62956 Mdot
.77863 .5867 Mdot
.52478 .95859 Mdot
.95316 .00721 Mdot
.99494 .89866 Mdot
.02731 .77811 Mdot
.60605 .31426 Mdot
.43245 .30729 Mdot
.70829 .46596 Mdot
.12222 .0223 Mdot
.97022 .43223 Mdot
.75805 .50754 Mdot
.53228 .27046 Mdot
.4391 .39014 Mdot
.49885 .88998 Mdot
.98882 .82488 Mdot
.92027 .46155 Mdot
.53756 .57818 Mdot
.90587 .6834 Mdot
.56305 .77304 Mdot
.64125 .76015 Mdot
.87971 .28688 Mdot
.21581 .86059 Mdot
.71076 .32302 Mdot
.16114 .02806 Mdot
.71876 .39463 Mdot
.19269 .59806 Mdot
.17561 .05605 Mdot
.70666 .61811 Mdot
.17231 .00331 Mdot
.37792 .39479 Mdot
.06668 .68993 Mdot
.18228 .18403 Mdot
.61966 .95687 Mdot
.49351 .85332 Mdot
.48889 .17637 Mdot
.79933 .27907 Mdot
.22858 .30136 Mdot
.11879 .15039 Mdot
.60269 .78828 Mdot
.84845 .00523 Mdot
.86549 .35431 Mdot
.93381 .08877 Mdot
.33969 .12058 Mdot
.23897 .45742 Mdot
.15395 .62994 Mdot
.28065 .14796 Mdot
.18156 .99175 Mdot
.92484 .38315 Mdot
.41646 .12408 Mdot
.37809 .6761 Mdot
.38173 .87925 Mdot
.94539 .1459 Mdot
.02017 .08276 Mdot
.49382 .50373 Mdot
.11816 .42006 Mdot
.81695 .49783 Mdot
.4808 .24982 Mdot
.94252 .89463 Mdot
.74173 .83298 Mdot
.58037 .05905 Mdot
.81861 .12717 Mdot
.73211 .83653 Mdot
.9061 .79368 Mdot
.20037 .2421 Mdot
.45272 .19293 Mdot
.169 .18371 Mdot
.77179 .3248 Mdot
.92929 .14961 Mdot
.83801 .48773 Mdot
.4336 .81862 Mdot
.54758 .13292 Mdot
.43228 .30183 Mdot
.20704 .54207 Mdot
.22349 .91266 Mdot
.81631 .18171 Mdot
.48941 .14031 Mdot
.82487 .48817 Mdot
.8447 .42956 Mdot
.52929 .69743 Mdot
.40858 .71229 Mdot
.17454 .72068 Mdot
.43433 .43383 Mdot
.0561 .04324 Mdot
.54836 .68967 Mdot
.37969 .02204 Mdot
.77975 .20826 Mdot
.07565 .26068 Mdot
.7475 .59081 Mdot
.7094 .26133 Mdot
.43556 .65413 Mdot
.75572 .02012 Mdot
.50687 .383 Mdot
.08916 .86341 Mdot
.63187 .4931 Mdot
.57045 .3465 Mdot
.52996 .3439 Mdot
.66117 .87578 Mdot
.30504 .57225 Mdot
.09333 .06039 Mdot
.00507 .48679 Mdot
.86181 .25785 Mdot
.10906 .3782 Mdot
.57263 .66519 Mdot
.07244 .42105 Mdot
.98706 .35276 Mdot
.96676 .44268 Mdot
.95932 .49184 Mdot
.88853 .65181 Mdot
.77188 .1394 Mdot
.07894 .55014 Mdot
.11788 .62002 Mdot
.59858 .59494 Mdot
.77621 .84978 Mdot
.00963 .78274 Mdot
.6787 .61875 Mdot
.41904 .77567 Mdot
.20924 .74058 Mdot
.93877 .85718 Mdot
.80672 .78758 Mdot
.60913 .72515 Mdot
.50331 .10121 Mdot
.99673 .62884 Mdot
.83277 .01487 Mdot
.94715 .56081 Mdot
.59773 .68668 Mdot
.39491 .25952 Mdot
.37337 .58768 Mdot
.51409 .97166 Mdot
.67991 .3208 Mdot
.01468 .61445 Mdot
.43912 .08578 Mdot
.86389 .36578 Mdot
.38199 .44535 Mdot
.44575 .31052 Mdot
.96461 .97477 Mdot
.99361 .26859 Mdot
.92707 .81355 Mdot
.088 .452 Mdot
.01977 .74304 Mdot
.09105 .05591 Mdot
.81083 .95684 Mdot
.54474 .85161 Mdot
.94858 .33289 Mdot
.19541 .04684 Mdot
.02922 .41117 Mdot
.26197 .26175 Mdot
.5139 .92842 Mdot
.78093 .46003 Mdot
.10588 .65296 Mdot
.16842 .51571 Mdot
.62995 .4679 Mdot
.61233 .0398 Mdot
.26922 .98274 Mdot
.53502 .60727 Mdot
.85018 .11043 Mdot
.85284 .17248 Mdot
.35514 .23564 Mdot
.08445 .43331 Mdot
.3185 .84636 Mdot
.8257 .43338 Mdot
.76425 .65616 Mdot
.14732 .37329 Mdot
.58182 .73675 Mdot
.05377 .88674 Mdot
.88625 .18531 Mdot
.99865 .80459 Mdot
.49736 .51444 Mdot
.69353 .20579 Mdot
.60473 .74021 Mdot
.05221 .2978 Mdot
.83598 .44255 Mdot
.68805 .40675 Mdot
.5379 .32202 Mdot
.98807 .49866 Mdot
.47557 .07378 Mdot
.50288 .08067 Mdot
.14217 .4111 Mdot
.92078 .7326 Mdot
.10715 .35321 Mdot
.80714 .06495 Mdot
.97324 .06986 Mdot
.25628 .2955 Mdot
.67393 .09509 Mdot
.03953 .33129 Mdot
.60096 .30038 Mdot
.50641 .40048 Mdot
.66093 .7097 Mdot
.58231 .86275 Mdot
.08054 .81398 Mdot
.16641 .60584 Mdot
.43007 .02913 Mdot
.81148 .06528 Mdot
.98858 .4144 Mdot
.1082 .32943 Mdot
.7748 .87124 Mdot
.6035 .44027 Mdot
.63815 .10532 Mdot
.54862 .49964 Mdot
.43713 .86974 Mdot
.42919 .12252 Mdot
.79305 .57812 Mdot
.7832 .09032 Mdot
.82478 .0421 Mdot
.41545 .49272 Mdot
.40586 .19448 Mdot
.87607 .70331 Mdot
.11888 .80371 Mdot
.7285 .82382 Mdot
.0368 .205 Mdot
.76906 .83457 Mdot
.1014 .89745 Mdot
.78484 .14285 Mdot
.7573 .76639 Mdot
.47428 .62295 Mdot
.38964 .17447 Mdot
.50971 .59743 Mdot
.54365 .52744 Mdot
.15083 .33591 Mdot
.86915 .21351 Mdot
.8507 .09398 Mdot
.34571 .52161 Mdot
.67164 .71696 Mdot
.68365 .17956 Mdot
.34281 .01249 Mdot
.48575 .84701 Mdot
.39966 .85215 Mdot
.58982 .15065 Mdot
.38298 .78833 Mdot
.57108 .07377 Mdot
.68076 .9053 Mdot
.14359 .29921 Mdot
.34047 .26552 Mdot
.32902 .31857 Mdot
.21404 .12065 Mdot
.09632 .67995 Mdot
.36738 .5572 Mdot
.15674 .28548 Mdot
.50899 .1859 Mdot
.12427 .7089 Mdot
.59142 .93733 Mdot
.03535 .09203 Mdot
.38086 .5821 Mdot
.41846 .34808 Mdot
.58501 .76051 Mdot
.55061 .49284 Mdot
.86748 .17708 Mdot
.99607 .30274 Mdot
.02651 .05418 Mdot
.31866 .51446 Mdot
.00045 .42517 Mdot
.70314 .33091 Mdot
.93985 .97207 Mdot
.20482 .73051 Mdot
.03995 .84207 Mdot
.24915 .93149 Mdot
.9973 .54835 Mdot
.20251 .93343 Mdot
.72098 .90693 Mdot
.69077 .03488 Mdot
.20727 .28287 Mdot
.82959 .01907 Mdot
.68711 .40615 Mdot
.59055 .19336 Mdot
.19501 .01861 Mdot
.89535 .03751 Mdot
.68991 .64451 Mdot
.15504 .57925 Mdot
.11618 .56363 Mdot
.45564 .21443 Mdot
.95147 .2355 Mdot
.23865 .64013 Mdot
.29433 .35544 Mdot
.92193 .07008 Mdot
.0806 .4821 Mdot
.80031 .39128 Mdot
.42507 .01069 Mdot
.34094 .87984 Mdot
.20918 .83046 Mdot
.66379 .77774 Mdot
.62353 .81334 Mdot
.67832 .00728 Mdot
.18608 .12486 Mdot
.90105 .92307 Mdot
.36566 .20208 Mdot
.53802 .31316 Mdot
.75743 .2535 Mdot
.25437 .46736 Mdot
.83842 .80619 Mdot
.39575 .01637 Mdot
.13918 .43055 Mdot
.23326 .81121 Mdot
.03859 .17514 Mdot
.04638 .23144 Mdot
.41264 .57878 Mdot
.59127 .85771 Mdot
.51633 .83821 Mdot
.63981 .08256 Mdot
.23347 .02626 Mdot
.77855 .16211 Mdot
.78681 .69658 Mdot
.94885 .57281 Mdot
.2219 .78236 Mdot
.14898 .25752 Mdot
.62815 .07046 Mdot
.64097 .45603 Mdot
.76809 .03244 Mdot
.5081 .06328 Mdot
.71707 .75282 Mdot
.43272 .53007 Mdot
.0288 .17184 Mdot
.09807 .93331 Mdot
.69634 .97876 Mdot
.69908 .85961 Mdot
.99464 .73849 Mdot
.98379 .06544 Mdot
.82438 .08897 Mdot
.91445 .15568 Mdot
.61168 .61086 Mdot
.85071 .51936 Mdot
.36193 .42875 Mdot
.97006 .44881 Mdot
.84418 .69342 Mdot
.4233 .08502 Mdot
.72708 .17127 Mdot
.27688 .66457 Mdot
.25025 .00259 Mdot
.79881 .04845 Mdot
.85453 .35155 Mdot
.43396 .42657 Mdot
.80696 .17303 Mdot
.04593 .43117 Mdot
.99762 .29182 Mdot
.52919 .46061 Mdot
.60609 .1819 Mdot
.67939 .91375 Mdot
.42827 .45085 Mdot
.87261 .77414 Mdot
.72149 .00389 Mdot
.6212 .18362 Mdot
.30279 .20313 Mdot
.71929 .18108 Mdot
.99916 .48233 Mdot
.14217 .3098 Mdot
.55231 .68786 Mdot
.06762 .31078 Mdot
.42296 .06564 Mdot
.91525 .86725 Mdot
.50401 .0791 Mdot
.52656 .59952 Mdot
.27047 .5046 Mdot
.48136 .90743 Mdot
.44944 .86019 Mdot
.28695 .15509 Mdot
.96969 .8562 Mdot
.60277 .40737 Mdot
.86089 .67852 Mdot
.9988 .63922 Mdot
.98984 .17145 Mdot
.60468 .22413 Mdot
.0104 .59159 Mdot
.54571 .1632 Mdot
.24663 .52049 Mdot
.53831 .78315 Mdot
.32468 .21781 Mdot
.79258 .10923 Mdot
.8132 .84069 Mdot
.65395 .13829 Mdot
.49866 .66357 Mdot
.17357 .06222 Mdot
.9318 .04282 Mdot
.04809 .27051 Mdot
.49865 .92749 Mdot
.03023 .54801 Mdot
.69584 .87053 Mdot
.03761 .2899 Mdot
.90344 .22027 Mdot
.71151 .74796 Mdot
.53989 .82692 Mdot
.60778 .06803 Mdot
.59543 .62263 Mdot
.94817 .57094 Mdot
.05413 .12266 Mdot
.34574 .85484 Mdot
.13684 .64205 Mdot
.7937 .83157 Mdot
.91078 .30234 Mdot
.29211 .99262 Mdot
.55091 .66437 Mdot
.03197 .81474 Mdot
.48202 .38147 Mdot
.97951 .17381 Mdot
.44708 .24078 Mdot
.58741 .08119 Mdot
.81603 .6445 Mdot
.76714 .79934 Mdot
.20429 .48151 Mdot
.41405 .47449 Mdot
.85 .62391 Mdot
.64152 .9689 Mdot
.75075 .48634 Mdot
.104 .63831 Mdot
.80913 .66583 Mdot
.69552 .97118 Mdot
.81667 .89705 Mdot
.54921 .33641 Mdot
.56195 .77944 Mdot
.35944 .01295 Mdot
.81094 .81782 Mdot
.41107 .0459 Mdot
.54905 .65346 Mdot
.27613 .62031 Mdot
.23611 .68006 Mdot
.6095 .44873 Mdot
.9641 .51078 Mdot
.47559 .04614 Mdot
.60077 .057 Mdot
.38361 .13857 Mdot
.58384 .84551 Mdot
.48701 .66687 Mdot
.22747 .47445 Mdot
.55103 .09628 Mdot
.23822 .28668 Mdot
.78163 .02115 Mdot
.47904 .15035 Mdot
.63671 .09526 Mdot
.99369 .10173 Mdot
.73342 .5801 Mdot
.97199 .46783 Mdot
.81534 .90135 Mdot
.82284 .18096 Mdot
.7774 .74713 Mdot
.14205 .13506 Mdot
.69675 .08633 Mdot
.39657 .39736 Mdot
.34792 .62187 Mdot
.39266 .72065 Mdot
.16059 .09672 Mdot
.87527 .15353 Mdot
.94212 .97856 Mdot
.44817 .23666 Mdot
.69417 .60568 Mdot
.07108 .56608 Mdot
.44427 .3368 Mdot
.4605 .90303 Mdot
.21678 .78334 Mdot
.54133 .04445 Mdot
.34195 .62312 Mdot
.5979 .79743 Mdot
.73378 .06542 Mdot
.24305 .07766 Mdot
.19694 .629 Mdot
.32121 .39051 Mdot
.98189 .47452 Mdot
.73093 .2401 Mdot
.08243 .58777 Mdot
.81384 .92298 Mdot
.38658 .33891 Mdot
.75834 .41175 Mdot
.51207 .1753 Mdot
.72416 .09445 Mdot
.33625 .65394 Mdot
.90173 .48198 Mdot
.57866 .55921 Mdot
.10264 .63587 Mdot
.05552 .55202 Mdot
.8486 .84127 Mdot
.45924 .41025 Mdot
.48141 .45703 Mdot
.61813 .54925 Mdot
.17032 .59951 Mdot
.64894 .81059 Mdot
.97185 .00502 Mdot
.85375 .67155 Mdot
.61665 .98186 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`?o00001?ooool2o`0000So
oooo00?o0000ooooooooool03?ooool2o`0000oooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0<ooooo`;o00004?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool00oooool2o`0000Sooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0=ooooo`;o00003_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool00_ooool001kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00?ooooo0_l00008ooooo`03o`000?oooooooooo00Cooooo
0_l00008ooooo`03o`000?oooooooooo00cooooo0_l0000?ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool2o`00013ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`03ooooo`;o00002?ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00cooooo0ol0000>ooooo`03o`000?oooooooooo00gooooo
0ol00004ooooo`;o00002?ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooooooo
o`0Sooooo`;o00004?ooool2o`0007kooooo0_l0000Qooooo`Co00005Oooool2o`0001gooooo0_l0
000Booooo`;o00003?ooool2o`0000Cooooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`08
ooooo`;o0000:oooool2o`0003Cooooo0_l00004ooooo`;o00004oooool2o`0002gooooo0_l0000S
ooooo`;o00005Oooool2o`00037ooooo0_l0000Qooooo`007_ooool00ol0003oooooooooo`08oooo
o`;o00009_ooool2o`0003Wooooo0_l00004ooooo`;o00002_ooool2o`0000Oooooo0_l00023oooo
o`;o0000>_ooool001kooooo00?o0000ooooooooool0<?ooool2o`0000Wooooo0_l00010ooooo`;o
0000B?ooool2o`0001Gooooo0_l0000Zooooo`?o0000>_ooool001kooooo00?o0000ooooooooool0
9?ooool2o`0001Gooooo0_l0000jooooo`;o0000C_ooool2o`0001Gooooo0_l0000Booooo`;o0000
1_ooool2o`0000kooooo0_l0000kooooo`007_ooool00ol0003oooooooooo`0Tooooo`;o0000DOoo
ool2o`0007Wooooo0_l00006ooooo`;o00007Oooool2o`0002cooooo000Nooooo`03o`000?oooooo
oooo02Cooooo0_l0000:ooooo`;o00005_ooool2o`000:7ooooo0_l0000/ooooo`;o0000;?ooool0
01kooooo00?o0000ooooooooool0<?ooool2o`0001Kooooo0_l0000[ooooo`;o00004Oooool2o`00
00Cooooo0_l0001Kooooo`;o0000F_ooool001kooooo00?o0000ooooooooool0MOooool2o`00017o
oooo0_l00004ooooo`;o0000C?ooool2o`0001Sooooo0_l0000;ooooo`;o0000@_ooool001kooooo
00?o0000ooooooooool0R?ooool2o`0005;ooooo0_l0000Hooooo`;o00002oooool2o`0001[ooooo
0_l0000Vooooo`007_ooool00ol0003oooooooooo`28ooooo`;o0000>Oooool2o`0005[ooooo0_l0
000Vooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o00009oooool2o`0003Oooooo0_l0000M
ooooo`;o00006oooool2o`0001Gooooo0_l0000dooooo`;o00003Oooool2o`00027ooooo0_l0000J
ooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o00009oooool2o`0000;ooooo0_l0000coooo
o`;o00004?ooool2o`0000_ooooo0_l00006ooooo`;o00004oooool2o`0004_ooooo0_l0000=oooo
o`;o00001oooool2o`0001Sooooo0_l0000Jooooo`007_ooool00ol0003oooooooooo`0kooooo`;o
0000AOooool2o`0001?ooooo0_l0001Eooooo`;o00004?ooool2o`0000oooooo0_l0000dooooo`00
7_ooool2o`0006Wooooo0_l00024ooooo`;o00004?ooool2o`0004Gooooo000Nooooo`04o`000?oo
ooooooooooooo`;o000000?oooooo`000?l000004oooool2o`0001[ooooo0_l0000aooooo`;o0000
Hoooool2o`0007Sooooo000Nooooo`04o`000?ooooooooooooooo`;o000000?oooooo`000?l00000
4oooool2o`0001[ooooo0_l0000;ooooo`;o0000MOooool2o`0000Cooooo0_l0000<ooooo`;o0000
GOooool2o`0001Wooooo000Nooooo`03o`000?oooooooooo01[ooooo0_l0000Hooooo`;o00003?oo
ool2o`0007Gooooo0_l00004ooooo`;o0000EOooool2o`0001Cooooo0_l0000Iooooo`007_ooool0
0ol0003oooooooooo`0Jooooo`;o00006?ooool2o`0004oooooo0_l0000Jooooo`;o0000Aoooool2
o`0001Kooooo1?l0000@ooooo`;o00009?ooool2o`0000Wooooo000Nooooo`03o`000?oooooooooo
08Gooooo0_l0000Jooooo`;o00007_ooool2o`0002Oooooo0_l0000Fooooo`Co00003_ooool2o`00
01gooooo0_l00007ooooo`;o00002Oooool001kooooo00?o0000ooooooooool0`Oooool2o`0000Go
oooo0_l0000Oooooo`;o0000:Oooool2o`0001;ooooo0_l00009ooooo`;o00000oooool2o`0000go
oooo000Nooooo`03o`000?oooooooooo08[ooooo0_l0000:ooooo`;o00007_ooool2o`00013ooooo
0_l0000Oooooo`;o0000;_ooool2o`0000gooooo0_l0000>ooooo`;o00003Oooool001kooooo00?o
0000ooooooooool0Boooool2o`0003[ooooo0_l000000ooooooo0000o`00000:ooooo`;o00007_oo
ool2o`0001Cooooo0_l0001;ooooo`;o0000;?ooool001kooooo00?o0000ooooooooool0Boooool2
o`00033ooooo0_l00008ooooo`;o00005_ooool3o`0001Wooooo0_l0000?ooooo`;o00000oooool2
o`0007Cooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0001iooooo`;o00008?ooool3o`00
01Wooooo0_l0000?ooooo`;o00000oooool2o`0004Oooooo0_l0000[ooooo`007_ooool00ol0003o
ooooooooo`02ooooo`;o0000B_ooool2o`0003Kooooo0_l00003ooooo`;o0000?oooool2o`00013o
oooo0_l0000Mooooo`;o00006oooool2o`0000?ooooo0_l0000Vooooo`007_ooool00ol0003ooooo
ooooo`1>ooooo`;o0000=_ooool2o`0000?ooooo0_l0000Booooo`;o00002_ooool2o`0000oooooo
0_l0000Pooooo`;o00006oooool4o`0000Wooooo0_l0000Eooooo`;o00002_ooool4o`0000Wooooo
0_l0000=ooooo`007_ooool00ol0003oooooooooo`07ooooo`;o0000U_ooool2o`0000[ooooo0_l0
000?ooooo`?o0000??ooool2o`0000_ooooo0_l0000Qooooo`Co00002Oooool2o`0000?ooooo0_l0
0008ooooo`007_ooool00ol0003oooooooooo`07ooooo`;o00009oooool2o`0007gooooo0_l0000<
ooooo`;o00003?ooool2o`0000[ooooo0_l0000>ooooo`;o00009oooool2o`0002_ooooo0_l00008
ooooo`007_ooool00ol0003oooooooooo`0`ooooo`;o00001?ooool2o`0007Oooooo0_l0000Joooo
o`;o00002_ooool2o`0000kooooo0_l0000Wooooo`;o0000=Oooool001kooooo0_l0000gooooo`;o
0000J?ooool2o`0009gooooo0_l00006ooooo`007_ooool00ol0003oooooooooo`1Wooooo`;o0000
=oooool2o`0002Wooooo0_l0001booooo`;o00001_ooool001kooooo00?o0000ooooooooool0Iooo
ool2o`0000;ooooo0_l00007ooooo`;o00005_ooool2o`0003Gooooo0_l00006ooooo`;o0000N_oo
ool001kooooo00?o0000ooooooooool0Joooool2o`0000Oooooo0_l0000Fooooo`;o0000=Oooool2
o`0003Wooooo0_l0000@ooooo`;o0000=Oooool001kooooo00?o0000ooooooooool0?oooool2o`00
0;gooooo0_l0000@ooooo`;o0000=Oooool001kooooo00?o0000ooooooooool0?oooool2o`0003ko
oooo0_l00036ooooo`007_ooool00ol0003oooooooooo`11ooooo`;o00009oooool2o`0001?ooooo
0_l0001Pooooo`;o00004_ooool2o`00053ooooo000Nooooo`03o`000?oooooooooo00gooooo0_l0
000booooo`;o00009oooool2o`0001Oooooo0_l00002ooooo`;o0000D_ooool2o`0000Cooooo0_l0
000Booooo`;o0000D?ooool001kooooo00?o0000ooooooooool03Oooool2o`0002Wooooo0_l00019
ooooo`;o00000_ooool2o`0005;ooooo0_l0000Yooooo`;o00008Oooool2o`0001cooooo000Noooo
o`03o`000?oooooooooo03Sooooo0_l0000booooo`;o0000V?ooool2o`0000Gooooo0_l0000Joooo
o`;o00007?ooool001kooooo00?o0000ooooooooool09oooool2o`0004?ooooo0_l00010ooooo`;o
0000GOooool2o`0003Sooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l000000ooooooo0000
o`00000Eooooo`;o0000FOooool2o`0000;ooooo0_l0000<ooooo`;o00001oooool2o`0006Wooooo
0_l0000Sooooo`007_ooool00ol0003oooooooooo`0Kooooo`;o00003Oooool2o`0001Gooooo0_l0
000fooooo`;o00006?ooool2o`0000Oooooo0_l00002ooooo`;o00005Oooool2o`0001Oooooo0_l0
000Uooooo`;o0000:Oooool2o`0002?ooooo000Nooooo`03o`000?oooooooooo01_ooooo0ol0001K
ooooo`;o00006?ooool2o`0000Kooooo0_l0000/ooooo`;o00001Oooool2o`0002Gooooo0_l00002
ooooo`;o0000B_ooool001kooooo00?o0000ooooooooool07?ooool2o`0007gooooo0_l0000/oooo
o`;o0000<?ooool2o`0003;ooooo0_l0000Fooooo`007_ooool00ol0003oooooooooo`1Gooooo`;o
0000e_ooool2o`0001Kooooo000Nooooo`;o00009?ooool2o`000003ooooool0003o000002oooooo
0_l0000oooooo`;o00008_ooool2o`0006cooooo0_l0000Kooooo`007_ooool00ol0003ooooooooo
o`0Sooooo`;o000000?oooooo`000?l00000<Oooool2o`0003gooooo0_l0000Rooooo`;o0000D_oo
ool2o`0000Kooooo0_l0000@ooooo`;o00006oooool001kooooo00Co0000oooooooooooooooo0_l0
000Nooooo`;o0000=_ooool2o`0001Wooooo0_l0001@ooooo`;o00008Oooool2o`00023ooooo0_l0
0003ooooo`;o00001_ooool2o`0000_ooooo0_l0000Pooooo`007_ooool01?l0003ooooooooooooo
ool2o`0001kooooo0_l0001:ooooo`;o00001Oooool2o`00053ooooo0_l0000Qooooo`;o00008?oo
ool2o`00017ooooo0_l00005ooooo`;o00008?ooool001kooooo00?o0000ooooooooool0KOooool2
o`0003Cooooo0_l00008ooooo`;o0000B_ooool2o`0002?ooooo0_l0000Wooooo`007_ooool00ol0
003oooooooooo`08ooooo`;o00006oooool2o`0004Gooooo0_l0000Jooooo`;o00004_ooool2o`00
00Gooooo0_l00008ooooo`;o0000B_ooool2o`0004cooooo000Nooooo`03o`000?oooooooooo00So
oooo0_l0000Kooooo`;o0000AOooool2o`0001[ooooo0_l0000Booooo`;o0000ZOooool001kooooo
00?o0000ooooooooool01Oooool2o`000>7ooooo0_l0000Hooooo`;o00000_ooool2o`0000Wooooo
0_l0000[ooooo`;o00001oooool001kooooo00?o0000ooooooooool01Oooool2o`000003ooooool0
003o0000077ooooo0_l0000Nooooo`;o00001Oooool2o`0004Cooooo0_l0000Cooooo`;o00000ooo
ool2o`0000;ooooo0_l00009ooooo`;o00009oooool2o`0000;ooooo0_l00007ooooo`007_ooool0
0ol0003oooooooooo`08ooooo`;o0000LOooool2o`0001kooooo0_l00005ooooo`;o0000=_ooool2
o`00027ooooo0_l0000Gooooo`;o00008_ooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo
0<7ooooo0_l0000Gooooo`;o00002_ooool2o`0001gooooo1?l0000=ooooo`;o00004_ooool2o`00
01_ooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l00003ooooo`;o00008oooool2o`0000;o
oooo0_l0001Xooooo`;o00007_ooool2o`0000?ooooo0_l0000Nooooo`;o00007Oooool4o`0001?o
oooo1?l0000:ooooo`;o00004oooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo00Wooooo
0_l00003ooooo`;o00008oooool2o`0000;ooooo0_l0001Xooooo`;o00008oooool2o`0005Cooooo
1?l0000Oooooo`;o00001_ooool001kooooo00?o0000ooooooooool0[oooool2o`0001;ooooo0_l0
0007ooooo`;o0000NOooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool5o`0000Kooooo00?o0000ooooooooool0N?ooool2o`0000Kooooo0_l0000=ooooo`;o00007_oo
ool2o`0000_ooooo0_l00005ooooo`;o00001oooool2o`0007Wooooo0003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`00
0?oooooooooo07Sooooo0_l00006ooooo`;o00003Oooool2o`0002_ooooo0_l00029ooooo`000ooo
ool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool3o`000;kooooo
0_l00009ooooo`;o00005oooool2o`0006?ooooo0003ooooo`05o`000?ooooooooooooooool00000
3Oooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo05kooooo0_l0000Cooooo`;o0000
5oooool2o`00033ooooo0_l00009ooooo`;o00005oooool2o`0002Wooooo0_l0000hooooo`000ooo
ool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooo
ooooo`08ooooo`;o0000E?ooool2o`0001?ooooo0_l0000Gooooo`;o00001Oooool2o`0004Sooooo
0_l0000Rooooo`;o00002_ooool2o`0003Sooooo0003ooooo`05oa0@4?ooooooooooooooool@4100
3oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo0_l0001_ooooo`;o0000
6?ooool2o`0004Sooooo0_l0000Jooooo`;o00001_ooool2o`0004Cooooo0003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000oooooooo
ool0>Oooool2o`0003kooooo0_l0001nooooo`;o00006oooool2o`0002oooooo0003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000oooo
ooooool0>Oooool2o`0005Gooooo0_l00024ooooo`;o0000;oooool001kooooo00?o0000oooooooo
ool0IOooool2o`0002Wooooo0_l0002eooooo`007_ooool00ol0003oooooooooo`1Uooooo`;o0000
C_ooool2o`0006_ooooo0_l0000Sooooo`007_ooool00ol0003oooooooooo`2eooooo`;o00002Ooo
ool2o`00063ooooo0_l0000:ooooo`;o00005oooool001kooooo00?o0000ooooooooool0`?ooool2
o`0006cooooo0_l0000Gooooo`007_ooool00ol0003oooooooooo`08ooooo`;o000000?oooooo`00
0?l00000N_ooool2o`0000[ooooo0_l0002booooo`007_ooool00ol0003oooooooooo`08ooooo`;o
000000?oooooo`000?l00000Hoooool2o`0001Gooooo0_l0000:ooooo`;o0000/_ooool001kooooo
00?o0000ooooooooool0Koooool3o`0001cooooo0_l0002Qooooo`;o00005?ooool001kooooo00?o
0000ooooooooool0?Oooool2o`00033ooooo0_l0000Looooo`?o0000C?ooool2o`0000cooooo0_l0
0015ooooo`;o00005?ooool001kooooo00?o0000ooooooooool0?Oooool2o`0004kooooo0_l0001=
ooooo`;o00003?ooool2o`0002?ooooo0_l0000Jooooo`;o00006_ooool001kooooo00?o0000oooo
ooooool0<oooool2o`0000Sooooo0_l0001Rooooo`;o00004?ooool2o`0001Kooooo0_l0000boooo
o`;o00003_ooool2o`000003ooooool0003o000001Oooooo0_l0000Jooooo`007_ooool00ol0003o
ooooooooo`0=ooooo`;o00009?ooool2o`0006?ooooo0_l00007ooooo`;o00004?ooool2o`0001Ko
oooo0_l0000booooo`;o00004Oooool2o`0003?ooooo000Nooooo`;o00003_ooool2o`0003Wooooo
0_l0001>ooooo`;o0000;?ooool2o`0002[ooooo0_l0000nooooo`;o00004oooool001kooooo0_l0
0019ooooo`;o0000O?ooool2o`0002[ooooo0_l0000nooooo`;o00004oooool001kooooo0_l0000]
ooooo`;o0000C_ooool2o`0001[ooooo0_l0001fooooo`;o00000_ooool2o`00037ooooo000Noooo
o`03o`000?oooooooooo01Cooooo0_l0000Fooooo`;o00008oooool2o`00023ooooo0_l00007oooo
o`;o00006_ooool2o`0004Wooooo0_l0000@ooooo`;o00006Oooool2o`0000;ooooo0_l0000aoooo
o`007_ooool00ol0003oooooooooo`0Dooooo`;o0000>oooool2o`0001Sooooo0_l00006ooooo`;o
0000K_ooool2o`00013ooooo0_l0000Qooooo`;o00008oooool2o`0000Sooooo000Nooooo`03o`00
0?oooooooooo023ooooo0_l00019ooooo`;o0000??ooool2o`0004gooooo0_l0000Nooooo`;o0000
8oooool4o`0000Kooooo000Nooooo`03o`000?oooooooooo00;o00002_ooool2o`0001;ooooo0_l0
0027ooooo`;o0000COooool2o`0004Gooooo0_l00006ooooo`007_ooool00ol0003oooooooooo`02
o`0000[ooooo0_l0000Iooooo`;o0000GOooool2o`00027ooooo0_l0002Looooo`007_ooool00ol0
003oooooooooo`0Wooooo`;o0000GOooool2o`000;oooooo000Nooooo`03o`000?oooooooooo0?oo
oooo0Oooool2o`0004Gooooo000Nooooo`03o`000?oooooooooo03oooooo0_l0002oooooo`;o0000
2oooool2o`0003Sooooo000Nooooo`03o`000?oooooooooo02oooooo0_l0000>ooooo`;o00002?oo
ool2o`0007[ooooo0_l00016ooooo`;o00002oooool2o`0002_ooooo000Nooooo`03o`000?oooooo
oooo00Sooooo0_l00008ooooo`;o00006oooool2o`0001Sooooo0_l0001jooooo`;o00001Oooool2
o`0004cooooo0_l0000[ooooo`007_ooool00ol0003oooooooooo`08ooooo`;o00002?ooool2o`00
01Sooooo0_l0002Nooooo`;o00005_ooool2o`0005[ooooo0_l00005ooooo`007_ooool00ol0003o
ooooooooo`0/ooooo`;o00008Oooool2o`0003cooooo0_l0001<ooooo`;o00001oooool2o`0000Wo
oooo0_l00014ooooo`;o00002Oooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo00gooooo
0_l0000Looooo`;o00008_ooool2o`0003;ooooo0_l00008ooooo`;o0000C?ooool2o`0001;ooooo
0_l00014ooooo`;o00004?ooool001kooooo0_l0000>ooooo`;o00007?ooool2o`0001Wooooo0ol0
000jooooo`;o00000oooool2o`0002;ooooo0_l0000Aooooo`;o0000Hoooool2o`0001[ooooo0_l0
0005ooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o00005Oooool2o`0001[ooooo0_l00000
1?oooooo0000o`000?l0000oooooo`;o00008_ooool2o`00017ooooo0_l0000Cooooo`;o0000C_oo
ool2o`0001[ooooo0_l00005ooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o00005Oooool2
o`0001?ooooo0_l00005ooooo`;o0000@oooool2o`0004[ooooo0_l0001aooooo`007_ooool00ol0
003oooooooooo`0Booooo`;o00005_ooool2o`00013ooooo0_l0001:ooooo`;o00000oooool2o`00
0;Sooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0000Fooooo`;o0000B?ooool2o`0001Oo
oooo0_l0000Looooo`;o00005?ooool2o`0002[ooooo0_l0001Hooooo`007_ooool00ol0003ooooo
ooooo`0Jooooo`;o00001Oooool2o`0003;ooooo0_l0000Mooooo`;o0000=Oooool2o`0001Cooooo
0_l0000Zooooo`;o0000:_ooool2o`0002cooooo000Nooooo`03o`000?oooooooooo01[ooooo0_l0
0005ooooo`;o0000<_ooool2o`00013ooooo0_l0000Booooo`;o0000G?ooool2o`0003Cooooo0_l0
0008ooooo`;o0000;?ooool001kooooo00?o0000ooooooooool02Oooool2o`0005cooooo0_l0000B
ooooo`;o00004_ooool2o`0001[ooooo0_l0000/ooooo`;o00002?ooool2o`0002[ooooo0_l0000f
ooooo`007_ooool00ol0003oooooooooo`09ooooo`;o0000Q?ooool2o`0001[ooooo0_l0000foooo
o`;o00004_ooool2o`0004kooooo000Nooooo`03o`000?oooooooooo01oooooo0_l0001]ooooo`;o
0000DOooool2o`0001Cooooo0_l0000:ooooo`;o00005?ooool2o`0002cooooo000Nooooo`03o`00
0?oooooooooo00;ooooo0_l00005ooooo`;o00005?ooool2o`00037ooooo0_l0000Wooooo`;o0000
4Oooool2o`00053ooooo0ol0000Pooooo`;o00005?ooool2o`0001Gooooo0_l0000Eooooo`007_oo
ool00ol0003oooooooooo`02ooooo`;o00001Oooool2o`0002;ooooo0_l0000Sooooo`;o00009ooo
ool2o`00037ooooo0_l0000`ooooo`;o00008Oooool2o`0002_ooooo0_l0000Eooooo`007_ooool0
0ol0003oooooooooo`0Oooooo`;o00003?ooool2o`0004_ooooo0_l0000@ooooo`;o00008?ooool2
o`0009Oooooo000Nooooo`03o`000?oooooooooo01oooooo0_l0001?ooooo`;o00002?ooool2o`00
013ooooo0_l0001aooooo`;o0000A_ooool001kooooo00?o0000ooooooooool0L?ooool2o`0003Ko
oooo0_l0001?ooooo`;o00000oooool3o`0004Kooooo000Nooooo`03o`000?oooooooooo05[ooooo
0_l0000Xooooo`;o00008_ooool2o`0000_ooooo0_l00012ooooo`;o00000oooool2o`0001_ooooo
0_l0000Zooooo`007_ooool2o`0005?ooooo0_l00006ooooo`;o00005oooool2o`0000oooooo0_l0
000_ooooo`;o0000Foooool2o`0000Oooooo0_l00002ooooo`;o00009_ooool001kooooo00?o0000
ooooooooool07oooool2o`00037ooooo0ol0000Nooooo`;o00005?ooool2o`0001kooooo0_l0001W
ooooo`;o000000?oooooo`000?l000002?ooool2o`0001cooooo0_l00008ooooo`007_ooool00ol0
003oooooooooo`0Oooooo`;o00005oooool2o`0001Wooooo0_l00007ooooo`;o0000:oooool2o`00
01kooooo0_l0001Uooooo`;o00000oooool2o`0002Kooooo0_l00008ooooo`007_ooool00ol0003o
ooooooooo`0hooooo`;o00005_ooool2o`0000[ooooo0_l0002booooo`;o0000=Oooool001kooooo
00?o0000ooooooooool0D?ooool2o`0000Cooooo0_l0001Aooooo`;o0000ROooool2o`00017ooooo
000Nooooo`03o`000?oooooooooo05Kooooo0_l0001Aooooo`;o0000J_ooool2o`0001gooooo0_l0
000Aooooo`007_ooool00ol0003oooooooooo`2Uooooo`;o0000F?ooool2o`0001Cooooo0_l0000`
ooooo`007_ooool00ol0003oooooooooo`02o`0002[ooooo0_l0001Yooooo`;o00003?ooool2o`00
05Sooooo0_l00016ooooo`007_ooool00ol0003oooooooooo`02o`0002[ooooo0_l0001Yooooo`;o
0000[_ooool001kooooo00?o0000ooooooooool07oooool2o`000?oooooo9oooool001kooooo00?o
0000ooooooooool07oooool2o`0005Oooooo0_l0000Oooooo`;o0000[?ooool001kooooo00?o0000
ooooooooool00oooool2o`0007?ooooo0_l0000Oooooo`;o00001_ooool2o`0008Kooooo0_l0000L
ooooo`007_ooool00ol0003oooooooooo`03ooooo`;o0000W?ooool2o`00017ooooo0_l0000Koooo
o`;o0000E_ooool2o`0001cooooo000Nooooo`03o`000?oooooooooo02Gooooo0_l0000mooooo`;o
00009Oooool2o`0002Oooooo0_l0000Kooooo`;o0000;Oooool2o`0004Gooooo0003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03
o`000?oooooooooo02Gooooo0_l0000mooooo`;o00004Oooool2o`0000_ooooo0_l00005ooooo`;o
0000FOooool2o`0001Sooooo0_l00015ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0:?ooool2o`0004go
oooo0_l00004ooooo`;o00001Oooool2o`00063ooooo0_l0000Xooooo`;o00004_ooool2o`00027o
oooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol0000Xooooo`;o
0000Doooool2o`0002;ooooo0_l0001]ooooo`;o00004_ooool2o`00027ooooo0003ooooo`05o`00
0?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo
023ooooo0_l0001oooooo`;o0000<_ooool2o`0003Cooooo0_l0000_ooooo`;o00002Oooool000?o
oooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000
ooooooooool08?ooool2o`0009kooooo0_l0000Cooooo`;o00001?ooool3o`0002gooooo0_l0000_
ooooo`;o00002Oooool000?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co
000000Oooooo00?o0000ooooooooool09?ooool2o`0006_ooooo0_l0000]ooooo`;o00006Oooool3
o`0000Cooooo0_l0001Sooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000001oooool00ol0003oooooooooo`05ooooo`;o00007Oooool2o`0000?ooooo0ol0001U
ooooo`;o00000oooool2o`0004[ooooo0_l0000>ooooo`;o0000Doooool000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool01Oooool2
o`0000Wooooo0_l0000Gooooo`?o00007_ooool2o`0004[ooooo0_l0001Jooooo`;o0000BOooool2
o`0000Sooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l00003ooooo`;o00001Oooool2o`00
03Sooooo0_l0001Pooooo`;o00001?ooool2o`00027ooooo0_l0001Vooooo`;o00002?ooool001ko
oooo00?o0000ooooooooool01?ooool2o`0000?ooooo0_l00008ooooo`;o00000_ooool2o`0000Wo
oooo0_l00028ooooo`;o00001?ooool2o`00027ooooo0_l0000looooo`;o0000<_ooool001gooooo
0_l0000Eooooo`;o00000_ooool2o`0000Wooooo0_l00010ooooo`;o0000LOooool2o`0003[ooooo
0_l0000booooo`007Oooool2o`0004cooooo0_l0000Hooooo`;o00003?ooool2o`0001Gooooo0_l0
000Sooooo`;o00009oooool2o`0002Gooooo0_l00017ooooo`007_ooool00ol0003oooooooooo`0;
ooooo`;o00007?ooool2o`0001oooooo0_l0000Vooooo`;o00005Oooool2o`0002?ooooo0_l0000k
ooooo`;o00004Oooool2o`0000oooooo0_l00007ooooo`;o0000;Oooool001kooooo00?o0000oooo
ooooool02oooool2o`0000[ooooo1?l0000>ooooo`;o00007Oooool2o`0001Cooooo0_l0000Yoooo
o`;o0000H?ooool2o`00017ooooo0_l00008ooooo`;o00001Oooool2o`0000Oooooo0_l0000Moooo
o`;o00003_ooool001kooooo00?o0000ooooooooool05oooool4o`0002gooooo0_l0000Dooooo`;o
0000:Oooool2o`0003kooooo0_l0000mooooo`;o0000;Oooool2o`0000kooooo000Nooooo`03o`00
0?oooooooooo03_ooooo0_l00023ooooo`;o00001oooool2o`0001_ooooo0_l0001Oooooo`007_oo
ool00ol0003oooooooooo`03ooooo`;o00001oooool2o`0002gooooo0_l0001Uooooo`;o00007?oo
ool2o`0002Cooooo0_l0000Tooooo`;o0000:?ooool2o`0000oooooo000Nooooo`03o`000?oooooo
oooo00?ooooo0_l00007ooooo`;o0000A_ooool3o`00027ooooo0_l0000Xooooo`;o00005_ooool2
o`0004gooooo0_l000000ooooooo0000o`00000Xooooo`;o00003oooool001kooooo00?o0000oooo
ooooool0E?ooool3o`00027ooooo0_l00010ooooo`;o00001_ooool2o`0004Gooooo0_l0000/oooo
o`;o00003_ooool001kooooo0_l0000Dooooo`;o00000oooool2o`0006gooooo0_l0000iooooo`;o
00006_ooool2o`0005Oooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o0000
0oooool2o`0006gooooo0_l00013ooooo`;o00004?ooool2o`0001cooooo0_l00019ooooo`007_oo
ool00ol0003oooooooooo`0booooo`;o00005_ooool2o`0004cooooo0_l0000Fooooo`;o00006_oo
ool2o`0002kooooo0_l00019ooooo`007_ooool00ol0003oooooooooo`0Kooooo`;o00005Oooool2
o`0001Kooooo0_l0000Rooooo`;o0000:?ooool2o`0000kooooo0_l00006ooooo`;o0000B?ooool2
o`0001;ooooo0_l0000Gooooo`;o00007_ooool001kooooo00?o0000ooooooooool06oooool2o`00
057ooooo0_l0000hooooo`;o0000C?ooool2o`0000;ooooo0_l0000Booooo`;o00005oooool2o`00
01kooooo000Nooooo`03o`000?oooooooooo04oooooo0_l0000;ooooo`;o00008Oooool2o`0002Go
oooo0_l0000Qooooo`;o00005oooool2o`0001;ooooo0_l00010ooooo`;o00003Oooool001kooooo
00?o0000ooooooooool0Coooool2o`0000_ooooo0_l0000Qooooo`;o00009Oooool2o`00027ooooo
0_l0000Gooooo`;o0000E?ooool4o`0000_ooooo000Nooooo`03o`000?oooooooooo03Sooooo0_l0
000<ooooo`;o0000>_ooool2o`00083ooooo0_l0000dooooo`?o00002_ooool001kooooo00?o0000
ooooooooool0>?ooool2o`0000cooooo0_l0000jooooo`;o0000P?ooool2o`0003Gooooo0_l0000:
ooooo`007_ooool00ol0003oooooooooo`2hooooo`;o0000DOooool2o`0003;ooooo0_l00006oooo
o`007_ooool00ol0003oooooooooo`0Fooooo`;o00009_ooool2o`0007Sooooo0_l00005ooooo`;o
0000B_ooool2o`0001Cooooo0_l0000Looooo`Co00001?ooool001kooooo0ol0000Fooooo`;o0000
9_ooool2o`0003kooooo0_l0000oooooo`;o0000;oooool2o`0002oooooo0_l0000Nooooo`;o0000
1?ooool001kooooo0ol00003ooooo`;o00006_ooool2o`00017ooooo0_l0001:ooooo`;o0000L?oo
ool2o`0001Kooooo0_l00002ooooo`;o0000>Oooool001kooooo00?o0000ooooooooool00oooool2
o`0001[ooooo0_l0000Aooooo`;o0000Coooool2o`0002[ooooo0_l0000Hooooo`;o0000?Oooool2
o`0000;ooooo0_l0000Vooooo`;o00004Oooool001kooooo00?o0000ooooooooool0Moooool2o`00
00[ooooo0_l0000Looooo`;o00003?ooool2o`0001Sooooo0_l0000Aooooo`;o0000E_ooool2o`00
017ooooo000Nooooo`03o`000?oooooooooo067ooooo0_l0000Dooooo`;o00001Oooool2o`00017o
oooo0_l0000>ooooo`;o00002oooool2o`0002cooooo0_l0000Wooooo`;o00003?ooool2o`0002So
oooo0_l00008ooooo`007_ooool2o`0002Kooooo0_l0000jooooo`;o00005oooool2o`0000;ooooo
0_l000000ooooooo0000o`00000>ooooo`;o00006oooool2o`0005Gooooo0_l0000<ooooo`;o0000
:?ooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo02Gooooo0_l0000Pooooo`;o00002ooo
ool2o`0002Cooooo0_l00005ooooo`;o00006Oooool2o`0002Gooooo0_l0001Oooooo`;o00008Ooo
ool001kooooo00?o0000ooooooooool02?ooool2o`0000Gooooo0_l0000fooooo`;o00002oooool2
o`0004Kooooo0_l0000Uooooo`;o0000;Oooool2o`00033ooooo0_l0000Qooooo`007_ooool00ol0
003oooooooooo`03ooooo`;o00000oooool2o`0000Gooooo0_l0001Gooooo`;o0000R?ooool2o`00
00kooooo0_l0000Oooooo`;o00004?ooool2o`0000Gooooo0_l00009ooooo`007_ooool00ol0003o
ooooooooo`03ooooo`;o0000G_ooool2o`0000?ooooo0_l0000dooooo`;o0000H_ooool2o`0001oo
oooo0_l0000@ooooo`;o00001Oooool2o`0000Wooooo000Nooooo`03o`000?oooooooooo03?ooooo
0_l0000^ooooo`;o00003?ooool2o`0002_ooooo0_l0001Rooooo`;o0000@oooool001kooooo00?o
0000ooooooooool0<oooool2o`0001Oooooo0_l0000Sooooo`;o0000Soooool2o`0000cooooo0_l0
000eooooo`007_ooool00ol0003oooooooooo`1<ooooo`;o00007_ooool2o`0002Cooooo0_l0001l
ooooo`;o0000=Oooool001kooooo00?o0000ooooooooool0K?ooool2o`0002Cooooo0_l0000=oooo
o`;o0000Y?ooool001kooooo00?o0000ooooooooool09Oooool2o`0006;ooooo0_l0000Fooooo`;o
00002_ooool2o`0009Sooooo000Nooooo`03o`000?oooooooooo02Gooooo0_l0001Rooooo`;o0000
8_ooool2o`0009Sooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`0oooooo`;o0000R_ooool2o`00
07[ooooo000Nooooo`03o`000?oooooooooo03oooooo0_l0002:ooooo`;o0000N_ooool001kooooo
00?o0000ooooooooool01_ooool2o`000?oooooo3Oooool2o`0002[ooooo0_l00005ooooo`007_oo
ool2o`0000Oooooo0_l0000>ooooo`;o0000YOooool2o`0000Kooooo0_l0001=ooooo`;o0000:_oo
ool2o`0000Gooooo000Nooooo`03o`000?oooooooooo00kooooo0_l00006ooooo`;o0000YOooool2
o`0000Kooooo0_l00020ooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o0000Hoooool4o`00
037ooooo0_l0002Mooooo`007_ooool00ol0003oooooooooo`07ooooo`;o0000J_ooool4o`00037o
oooo0_l0000>ooooo`;o00007Oooool2o`00023ooooo0_l0000eooooo`;o00005Oooool001kooooo
00?o0000ooooooooool01oooool2o`0001Wooooo0_l00008ooooo`;o00009?ooool2o`0003cooooo
0_l0000Vooooo`;o00007Oooool2o`00023ooooo0_l0000eooooo`;o00005Oooool001kooooo00?o
0000ooooooooool04oooool2o`0000gooooo0_l00008ooooo`;o00009?ooool2o`0000Oooooo0_l0
000cooooo`;o0000AOooool2o`0006kooooo000Nooooo`03o`000?oooooooooo01?ooooo0_l00016
ooooo`;o00004Oooool2o`0006Oooooo0_l0001^ooooo`007_ooool01?l0003oooooooooooooool2
o`0002_ooooo0_l0000_ooooo`;o00003Oooool2o`0002Kooooo0_l0000Iooooo`;o0000OOooool2
o`0001Gooooo000Nooooo`04o`000?ooooooooooooooo`;o0000:oooool2o`0002oooooo0_l0000e
ooooo`;o00006Oooool2o`0002kooooo0_l0001=ooooo`;o00005Oooool001kooooo00?o0000oooo
ooooool0;_ooool2o`0005;ooooo0_l0000Wooooo`;o0000=?ooool2o`0001_ooooo0_l00017oooo
o`007_ooool00ol0003oooooooooo`0^ooooo`;o00005oooool2o`0002cooooo0_l000000ooooooo
0000o`000008ooooo`;o00002_ooool2o`0001_ooooo0_l0000mooooo`;o00004_ooool2o`0003Go
oooo0_l0000@ooooo`007_ooool00ol0003oooooooooo`17ooooo`;o0000;?ooool2o`000003oooo
ool0003o000001Cooooo0_l0001Jooooo`;o0000=oooool2o`00013ooooo0_l0000@ooooo`007_oo
ool00ol0003oooooooooo`0Gooooo`;o0000G?ooool2o`0008;ooooo0_l0000Xooooo`;o00008_oo
ool001kooooo00Co0000ooooool0003o00003Oooool2o`0000Oooooo0_l0001Looooo`;o0000GOoo
ool2o`0001Wooooo0_l00008ooooo`;o0000C?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00Co0000ooooool0003o
00003Oooool2o`000:kooooo0_l0000Dooooo`;o00001Oooool2o`0001;ooooo0_l0000?ooooo`;o
0000AOooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGo
MgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0>oooool2o`0006Gooooo0_l0000Joooo
o`;o00006oooool2o`0002?ooooo0_l0000Uooooo`;o00002_ooool2o`0001;ooooo0003ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0000C
ooooo`;o00006_ooool2o`0000;ooooo0_l00006ooooo`;o0000IOooool2o`0000?ooooo0_l0000F
ooooo`;o0000I_ooool2o`0000[ooooo0_l0000Booooo`000oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo01?ooooo0_l0
000Jooooo`;o00000_ooool2o`0007;ooooo0_l0000Fooooo`;o0000Q_ooool000?ooooo00Go0000
ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003ooooo
ooooo`0booooo`;o0000M_ooool2o`0003;ooooo0_l0001Wooooo`000oooool01Ol@413ooooooooo
oooooooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`0booooo`;o0000
M_ooool2o`0003;ooooo0_l0001Wooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`1;ooooo`;o0000M_ooool2o`0001[ooooo
0_l0001Vooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o
410@1_ooool01?l0003oooooooooooooool2o`0004Sooooo0_l0001fooooo`;o00006_ooool2o`00
06Kooooo000Nooooo`04o`000?ooooooooooooooo`;o0000a_ooool2o`0000kooooo0_l00007oooo
o`;o00004oooool2o`0004kooooo000Nooooo`03o`000?oooooooooo02;ooooo0_l0000booooo`;o
00005Oooool2o`0004kooooo0_l00009ooooo`?o00002Oooool2o`0000?ooooo0_l00007ooooo`;o
00004oooool2o`00023ooooo0_l0000/ooooo`007_ooool00ol0003oooooooooo`0Rooooo`;o0000
<_ooool2o`0001?ooooo1?l0000Wooooo`;o00009?ooool3o`0000Cooooo0_l00003ooooo`;o0000
2_ooool2o`0003[ooooo0_l00007ooooo`;o0000;?ooool001kooooo00?o0000ooooooooool0JOoo
ool4o`0002Wooooo0_l0000Tooooo`;o00001Oooool2o`0004Gooooo0_l00004ooooo`;o0000;_oo
ool2o`0000Gooooo000Nooooo`03o`000?oooooooooo02kooooo0_l0000<ooooo`;o0000:oooool2
o`0009oooooo0_l0000_ooooo`;o00000oooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo
02kooooo0_l00006ooooo`;o00001?ooool2o`000<Gooooo0_l0000?ooooo`;o00009Oooool2o`00
00;ooooo0_l00006ooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o00005oooool2o`0004;o
oooo0_l0001Dooooo`;o0000<Oooool2o`0000oooooo0_l0000Yooooo`;o00001_ooool001kooooo
00?o0000ooooooooool07Oooool3o`0002Wooooo0_l0000_ooooo`;o0000E?ooool2o`0006cooooo
0_l000000ooooooo0000o`000004ooooo`007_ooool00ol0003oooooooooo`0Nooooo`;o00002?oo
ool2o`0001oooooo0_l0002Sooooo`;o0000C_ooool2o`000003ooooool0003o000000Cooooo000N
ooooo`03o`000?oooooooooo02Sooooo0_l0002booooo`;o00004?ooool2o`0001Gooooo0_l00010
ooooo`007_ooool00ol0003oooooooooo`3Looooo`;o00009oooool2o`00043ooooo000Nooooo`;o
00007oooool2o`0008kooooo0_l0001]ooooo`;o0000:?ooool001kooooo00?o0000ooooooooool0
7_ooool2o`0004Wooooo0_l0000Nooooo`;o00008oooool2o`0004Cooooo0_l0000Wooooo`;o0000
:?ooool001kooooo00?o0000ooooooooool0JOooool2o`0001kooooo0_l0001Yooooo`;o00001Ooo
ool2o`0001kooooo0_l0000Zooooo`007_ooool00ol0003oooooooooo`3kooooo`;o00007_ooool2
o`0002[ooooo000Nooooo`03o`000?oooooooooo05Kooooo0_l0000Wooooo`;o00004Oooool2o`00
00[ooooo0_l0000?ooooo`;o00001Oooool2o`0004Cooooo0_l00019ooooo`007_ooool00ol0003o
ooooooooo`1@ooooo`;o00001?ooool2o`0001Gooooo0_l0000@ooooo`;o00004Oooool2o`0000Ko
oooo0_l000001?oooooo0000o`000?l0000?ooooo`;o00001Oooool2o`0004Cooooo0_l00005oooo
o`;o0000@_ooool001kooooo00?o0000ooooooooool0D?ooool2o`0001_ooooo0_l0000[ooooo`;o
000000?oooooo`000?l00000I?ooool2o`0000cooooo0_l0000dooooo`007_ooool00ol0003ooooo
ooooo`3ooooooa;ooooo0_l0000]ooooo`;o00001Oooool001kooooo00?o0000ooooooooool0Mooo
ool2o`000<Oooooo0_l00005ooooo`007_ooool00ol0003oooooooooo`0Kooooo`;o0000;?ooool2
o`0002cooooo0_l0002Kooooo`;o0000<Oooool001kooooo00?o0000ooooooooool06oooool2o`00
02Wooooo0_l000000ooooooo0000o`000039ooooo`;o00003?ooool2o`0002?ooooo000Nooooo`03
o`000?oooooooooo04Kooooo0_l0000Dooooo`;o0000H?ooool2o`0006;ooooo0_l0000Sooooo`00
7_ooool00ol0003oooooooooo`0Booooo`;o0000B?ooool2o`0000kooooo0_l00010ooooo`?o0000
3Oooool2o`0008Oooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l00012ooooo`;o00005?oo
ool2o`00043ooooo0ol0000hooooo`;o00008oooool2o`0003Oooooo000Nooooo`03o`000?oooooo
oooo05Kooooo0_l0000Wooooo`;o0000J?ooool2o`0002?ooooo0_l0000gooooo`007_ooool00ol0
003oooooooooo`1Mooooo`;o00008?ooool2o`0001Sooooo0_l0000=ooooo`;o0000D_ooool2o`00
02Kooooo0_l0000Qooooo`007_ooool2o`0005kooooo0_l0000jooooo`;o00003Oooool2o`0001So
oooo0_l0000hooooo`;o00009_ooool2o`00027ooooo000Nooooo`03o`000?oooooooooo08Oooooo
0_l0000iooooo`;o0000A?ooool2o`0000oooooo0_l0000/ooooo`007_ooool00ol0003ooooooooo
o`27ooooo`;o00008_ooool2o`0002Sooooo0_l0000aooooo`;o00003oooool2o`0002cooooo000N
ooooo`03o`000?oooooooooo02Cooooo0ol00024ooooo`;o00009_ooool4o`0001Gooooo0_l00014
ooooo`;o00004oooool001kooooo00?o0000ooooooooool09?ooool3o`0005[ooooo0_l0001@oooo
o`;o00005oooool2o`0004Cooooo0_l0000Cooooo`007_ooool00ol0003oooooooooo`21ooooo`;o
0000Doooool2o`0006oooooo000Nooooo`03o`000?oooooooooo03Gooooo0_l00015ooooo`;o0000
F?ooool2o`0004Kooooo0_l0000Wooooo`007_ooool00ol0003oooooooooo`0eooooo`;o0000AOoo
ool2o`0002?ooooo0_l0001]ooooo`;o00003?ooool2o`0002Oooooo000Nooooo`03o`000?oooooo
oooo0:7ooooo0_l0000Oooooo`;o0000C?ooool2o`0003Gooooo000Nooooo`03o`000?oooooooooo
0<;ooooo0_l0000Iooooo`;o0000J?ooool001kooooo00?o0000ooooooooool0?_ooool2o`0008Wo
oooo0_l0000Booooo`;o0000B?ooool2o`0001kooooo000Nooooo`03o`000?oooooooooo03kooooo
0_l00029ooooo`;o00009_ooool2o`0001kooooo0_l0000Dooooo`;o00007_ooool001kooooo00?o
0000ooooooooool0Yoooool2o`00013ooooo0_l0000fooooo`;o00007_ooool2o`0002cooooo0_l0
0006ooooo`007_ooool3o`00027ooooo0_l0000Mooooo`;o00002_ooool2o`0005Wooooo0_l0000;
ooooo`;o00000oooool2o`0000Gooooo0_l0001Zooooo`;o00004Oooool2o`0000Kooooo000Noooo
o`?o00000_ooool2o`0001gooooo0_l0000Mooooo`;o00002_ooool2o`0000Gooooo0_l0001Ooooo
o`;o00002_ooool2o`00017ooooo0_l0001Gooooo`;o00001Oooool2o`0001;ooooo000Nooooo`03
o`000?oooooooooo00;ooooo0_l0001?ooooo`;o0000O_ooool2o`0000kooooo0_l0000Dooooo`;o
0000>?ooool2o`0001;ooooo000Nooooo`;o0000i?ooool2o`0001Cooooo0_l0001<ooooo`007_oo
ool00ol0003oooooooooo`0Oooooo`;o0000a?ooool2o`00063ooooo000Nooooo`03o`000?oooooo
oooo01oooooo0_l0001jooooo`;o0000B?ooool2o`00047ooooo0_l00009ooooo`;o00004_ooool0
01kooooo00?o0000ooooooooool0Voooool2o`0001gooooo0_l0000@ooooo`;o0000F_ooool2o`00
00Wooooo0_l0000Booooo`007_ooool00ol0003oooooooooo`06ooooo`;o0000/_ooool2o`00013o
oooo0_l0001Tooooo`;o00004oooool001kooooo00?o0000ooooooooool01_ooool2o`000>[ooooo
0_l0000nooooo`;o00004oooool001kooooo00?o0000ooooooooool02?ooool2o`000>Sooooo0_l0
001Cooooo`007_ooool00ol0003oooooooooo`08ooooo`;o0000ZOooool2o`0009;ooooo000Noooo
o`03o`000?oooooooooo06;ooooo0_l0000Pooooo`;o0000;Oooool2o`0006?ooooo0_l0000]oooo
o`007_ooool00ol0003oooooooooo`05ooooo`;o0000Foooool2o`0000Kooooo0_l0000Hooooo`;o
0000;Oooool2o`0001oooooo0_l00012ooooo`;o0000;Oooool001kooooo00?o0000ooooooooool0
1Oooool2o`0003gooooo0_l0000Tooooo`;o0000Aoooool2o`0001oooooo0_l0000Booooo`;o0000
GOooool001kooooo00Co0000ooooool0003o0000@Oooool4o`0006Gooooo0_l0000kooooo`;o0000
GOooool001kooooo00Co0000ooooool0003o0000@Oooool2o`0003Cooooo0_l0000aooooo`;o0000
4oooool2o`00043ooooo0_l00013ooooo`007_ooool00ol0003oooooooooo`1Booooo`;o00009?oo
ool2o`0004Kooooo0_l0000cooooo`;o00002oooool2o`0004?ooooo0003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`00
0?oooooooooo05;ooooo0_l0002Qooooo`;o0000:oooool2o`0002?ooooo0003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03
o`000?oooooooooo04Sooooo0_l0000kooooo`;o00004Oooool2o`0002Cooooo0_l00010ooooo`;o
00008?ooool2o`0002?ooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003o
oooooooooooooooo000000Kooooo0ol0000Cooooo`;o0000<oooool2o`0003_ooooo0_l0000Aoooo
o`;o00009?ooool2o`0003Gooooo0_l00009ooooo`;o0000AOooool000?ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool00ol0003oooooooooo`0<
ooooo`;o00001Oooool2o`0000kooooo0_l00031ooooo`;o00003Oooool2o`00053ooooo0003oooo
o`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o
0000ooooooooool03?ooool2o`0001Gooooo0_l00031ooooo`;o00009?ooool2o`0003?ooooo0_l0
0004ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zj
oa0@4006ooooo`03o`000?oooooooooo00kooooo0_l0003looooo`;o0000<oooool2o`0000Cooooo
0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Ko
oooo00?o0000ooooooooool03_ooool2o`000003ooooool0003o000003Gooooo0_l0001^ooooo`;o
00003Oooool2o`0000Kooooo0_l0000Hooooo`;o0000;Oooool2o`0002gooooo0003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000oooo
ooooool01_ooool2o`0000Wooooo0_l00003ooooo`;o0000<?ooool2o`0006kooooo0_l0000=oooo
o`;o00001_ooool2o`0001Oooooo0ol0000]ooooo`;o00003oooool2o`0001cooooo000Nooooo`03
o`000?oooooooooo00Kooooo0_l0000>ooooo`;o0000LOooool2o`0005gooooo0_l0000Jooooo`;o
00008oooool2o`0001cooooo000Nooooo`03o`000?oooooooooo06oooooo0_l0000Hooooo`;o0000
J_ooool2o`0000gooooo0_l00011ooooo`007_ooool00ol0003oooooooooo`1Pooooo`;o00003Ooo
ool2o`0005Kooooo0_l0000Pooooo`;o00002_ooool2o`0003Wooooo0_l0000;ooooo`;o00002?oo
ool001kooooo00?o0000ooooooooool0H?ooool2o`0003oooooo0_l00008ooooo`;o00006_ooool2
o`00023ooooo0_l00015ooooo`;o00002oooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo
043ooooo0_l0001Oooooo`;o00002?ooool2o`0002_ooooo0_l0000Tooooo`;o0000Aoooool001ko
oooo00?o0000ooooooooool0@?ooool2o`0003Oooooo0_l0001Mooooo`;o00004oooool2o`0000Oo
oooo0_l00006ooooo`;o0000Aoooool001kooooo00?o0000ooooooooool0NOooool2o`0005;ooooo
0_l0000Kooooo`;o000000?oooooo`000?l000001oooool2o`0004oooooo000Nooooo`03o`000?oo
oooooooo00Wooooo0_l0001Gooooo`;o00007oooool2o`0001oooooo0_l0000Wooooo`;o00006ooo
ool2o`0001Sooooo0_l00011ooooo`007_ooool00ol0003oooooooooo`09ooooo`;o0000Eoooool2
o`0001oooooo0_l0000Oooooo`;o0000G_ooool2o`0000[ooooo0_l0000eooooo`007_ooool00ol0
003oooooooooo`09ooooo`;o0000F?ooool2o`0003Gooooo0_l0000Nooooo`;o0000E?ooool2o`00
02cooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`1Sooooo`;o00004Oooool2o`0002;o
oooo0_l0000Nooooo`;o0000??ooool2o`0004Cooooo0_l00007ooooo`007_ooool2o`0007Oooooo
0_l00006ooooo`;o00007?ooool2o`0000oooooo0_l00019ooooo`;o0000COooool001kooooo00?o
0000ooooooooool0K?ooool2o`00013ooooo0_l00007ooooo`;o00003oooool2o`0000;ooooo0_l0
000?ooooo`;o0000:oooool2o`0003?ooooo0_l0000Vooooo`;o00003_ooool001kooooo00?o0000
ooooooooool0E_ooool2o`0001Cooooo0_l0000Iooooo`;o00003oooool2o`0002;ooooo0_l00003
ooooo`;o00005oooool2o`0003?ooooo0_l0000Looooo`;o00002?ooool2o`0000kooooo000Noooo
o`03o`000?oooooooooo04;ooooo0_l00003ooooo`;o00003Oooool2o`0003Kooooo0_l0000/oooo
o`;o00000oooool2o`0001cooooo0_l00016ooooo`;o00001?ooool2o`0001Sooooo000Nooooo`03
o`000?oooooooooo01Wooooo0_l0000Wooooo`;o00000oooool2o`0004Gooooo0_l00005ooooo`;o
00008_ooool2o`0002Cooooo0_l00016ooooo`;o00007_ooool001kooooo00?o0000ooooooooool0
6Oooool2o`0005cooooo0_l0000Looooo`;o00008_ooool2o`0001Sooooo0_l0001@ooooo`;o0000
8?ooool001kooooo00?o0000ooooooooool0=oooool2o`0000Gooooo0_l0000gooooo`;o00004Ooo
ool2o`0004Oooooo0_l00009ooooo`;o00006?ooool2o`0002_ooooo0_l0000Pooooo`007_ooool0
0ol0003oooooooooo`0gooooo`Co00000oooool2o`0004[ooooo0_l0001Booooo`;o00006?ooool2
o`0004gooooo000Nooooo`03o`000?oooooooooo03Wooooo0_l0002Hooooo`;o0000L_ooool001ko
oooo00?o0000ooooooooool09Oooool2o`0002oooooo0_l0000Cooooo`;o00002oooool2o`0000co
oooo0_l0001;ooooo`;o0000@?ooool2o`00033ooooo000Nooooo`03o`000?oooooooooo02Gooooo
0_l0000_ooooo`;o00004oooool2o`0000_ooooo0_l0000<ooooo`;o0000SOooool2o`00033ooooo
000Nooooo`03o`000?oooooooooo00gooooo0_l0003Mooooo`;o0000FOooool001kooooo00?o0000
ooooooooool03Oooool2o`0008oooooo0_l0001<ooooo`;o0000FOooool001kooooo00?o0000oooo
ooooool0W_ooool2o`0003gooooo0_l0000;ooooo`;o00000_ooool2o`0000;ooooo0_l00014oooo
o`;o00003Oooool001kooooo00?o0000ooooooooool0gOooool2o`0000Kooooo0_l00003ooooo`;o
00000_ooool2o`0000;ooooo0_l0000jooooo`;o00002?ooool2o`0000gooooo000Nooooo`?o0000
7Oooool2o`0006?ooooo0_l0001Qooooo`;o00007_ooool2o`0002Oooooo0_l0000?ooooo`;o0000
1_ooool001kooooo0ol0000Mooooo`;o0000Hoooool2o`0001cooooo0_l0000?ooooo`;o0000C_oo
ool2o`0000;ooooo0_l0000hooooo`;o00001_ooool001kooooo00?o0000ooooooooool0T_ooool2
o`0000cooooo0_l0000?ooooo`;o00009_ooool2o`0002Kooooo0_l00002ooooo`;o0000@?ooool0
01kooooo00?o0000ooooooooool03Oooool2o`0008?ooooo0_l00004ooooo`;o0000?oooool2o`00
00_ooooo0_l0001Oooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o0000ROooool2o`0004co
oooo0_l0000Nooooo`;o0000<?ooool2o`0000gooooo000Nooooo`03o`000?oooooooooo04Gooooo
0_l00005ooooo`;o0000Roooool2o`0002_ooooo0_l0000`ooooo`;o00003Oooool001kooooo00?o
0000ooooooooool01Oooool2o`0003kooooo0_l00005ooooo`;o0000@oooool2o`0004Kooooo0_l0
001/ooooo`007_ooool00ol0003oooooooooo`05ooooo`;o00001?ooool2o`0003Cooooo0_l0001>
ooooo`;o0000]?ooool001kooooo00?o0000ooooooooool00_l00009ooooo`;o00004?ooool2o`00
02;ooooo0_l0000Xooooo`;o0000L?ooool2o`0002Gooooo0_l0000Kooooo`;o00009?ooool001ko
oooo00?o0000ooooooooool00_l0000=ooooo`;o00003?ooool2o`0000[ooooo0_l0000dooooo`;o
00001?ooool2o`0000Cooooo0_l0001`ooooo`;o00009Oooool2o`0001_ooooo0_l0000Tooooo`00
7_ooool3o`0000oooooo0_l0000Hooooo`;o0000=?ooool2o`0000Cooooo0_l0000gooooo`;o0000
0oooool2o`000:;ooooo000Nooooo`?o00006?ooool2o`0000;ooooo0_l00008ooooo`;o00009Ooo
ool2o`0004oooooo0_l00003ooooo`;o0000X_ooool001kooooo00?o0000ooooooooool06?ooool2
o`0000;ooooo0_l00008ooooo`;o00005_ooool2o`0000gooooo0_l0001Booooo`;o0000:oooool2
o`0000Kooooo0_l0001Wooooo`;o00001_ooool001kooooo00?o0000ooooooooool0?_ooool2o`00
067ooooo0_l0000Iooooo`;o00004?ooool2o`0000Kooooo0_l0001Wooooo`;o00001_ooool001ko
oooo00?o0000ooooooooool0_?ooool2o`0008Wooooo000Nooooo`03o`000?oooooooooo0;Kooooo
0_l0002?ooooo`007_ooool2o`0000oooooo0_l00024ooooo`;o00008?ooool2o`0008oooooo000N
ooooo`;o00003oooool2o`0006?ooooo0_l0000Oooooo`;o00005_ooool2o`0009Wooooo000Noooo
o`03o`000?oooooooooo07?ooooo0_l0000gooooo`;o0000VOooool001kooooo00?o0000oooooooo
ool08oooool2o`0006Sooooo0_l0000fooooo`;o0000??ooool2o`0001gooooo0_l00003ooooo`;o
00007_ooool001kooooo00?o0000ooooooooool08oooool2o`0006Sooooo0_l0000Gooooo`;o0000
7Oooool2o`0003Gooooo0_l00005ooooo`;o00002?ooool2o`0001?ooooo1?l000000ooooooo0000
o`00000Nooooo`007_ooool00ol0003oooooooooo`0eooooo`;o0000Koooool2o`0005Cooooo0_l0
000?ooooo`;o00005Oooool2o`00027ooooo000Nooooo`03o`000?oooooooooo013ooooo0_l0000S
ooooo`;o0000K?ooool2o`00043ooooo0_l0001Pooooo`007_ooool00ol0003oooooooooo`0@oooo
o`;o00006_ooool2o`0001Cooooo0_l0000Cooooo`;o0000>?ooool2o`00013ooooo0_l0000Woooo
o`;o00005oooool2o`00063ooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0000Rooooo`;o
00000oooool2o`0001Cooooo0_l0000Cooooo`;o0000>?ooool2o`00013ooooo0_l0000Wooooo`;o
00004?ooool2o`0004gooooo0_l00007ooooo`;o00003oooool001kooooo00?o0000ooooooooool0
0oooool2o`00013ooooo0_l0000@ooooo`;o0000>Oooool2o`0003oooooo0_l0000cooooo`;o0000
1?ooool2o`0004gooooo0_l00006ooooo`?o00003oooool001kooooo00?o0000ooooooooool03Ooo
ool2o`0000Kooooo0_l0001;ooooo`;o0000M?ooool2o`0000Cooooo0_l0001>ooooo`;o00001Ooo
ool2o`00013ooooo000Nooooo`03o`000?oooooooooo00gooooo0_l00028ooooo`;o0000:oooool2
o`0001Sooooo0_l0001>ooooo`;o00005oooool001kooooo00?o0000ooooooooool0Doooool2o`00
01[ooooo0_l0000Vooooo`;o00007_ooool2o`0000_ooooo0_l00021ooooo`007_ooool00ol0003o
ooooooooo`1Cooooo`;o00006_ooool2o`0004?ooooo0_l000000ooooooo0000o`00000Looooo`;o
0000L?ooool001kooooo00?o0000ooooooooool0=oooool2o`0007_ooooo0_l0000Oooooo`;o0000
L?ooool001Cooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo03Oooooo0_l0
000Rooooo`?o0000`oooool2o`0002Cooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0;?ooool2o`0002gooooo0ol00007ooooo`;o0000^_ooool2o`0002Cooooo000Foooo
o`03o`000?oooooooooo00Gooooo0ol0000/ooooo`;o0000=oooool2o`000>3ooooo000Fooooo`03
o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_oo
ool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool0
01Cooooo00?oEEEEofIVI_l00000oooooomBooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.68076 .43356 Mdot
.28186 .41146 Mdot
.80933 .47212 Mdot
.20128 .48397 Mdot
.48074 .20615 Mdot
.57196 .50647 Mdot
.71564 .36699 Mdot
.00902 .96752 Mdot
.08645 .42519 Mdot
.95264 .91564 Mdot
.38814 .51252 Mdot
.0108 .99909 Mdot
.28487 .63878 Mdot
.18029 .15548 Mdot
.89776 .61595 Mdot
.38987 .09385 Mdot
.84372 .00483 Mdot
.37705 .99584 Mdot
.76315 .06905 Mdot
.7687 .6345 Mdot
.05865 .20775 Mdot
.37703 .15939 Mdot
.10189 .0912 Mdot
.77936 .58582 Mdot
.40735 .01127 Mdot
.99906 .02702 Mdot
.05272 .99341 Mdot
.04094 .50596 Mdot
.63171 .40402 Mdot
.21726 .0919 Mdot
.47961 .96828 Mdot
.86385 .06424 Mdot
.98358 .14572 Mdot
.06355 .29809 Mdot
.31234 .46724 Mdot
.88982 .13668 Mdot
.3199 .07655 Mdot
.27173 .52702 Mdot
.81287 .476 Mdot
.64117 .60163 Mdot
.60787 .61944 Mdot
.98701 .11606 Mdot
.55936 .2824 Mdot
.54287 .59624 Mdot
.97562 .51433 Mdot
.05507 .75284 Mdot
.25606 .45917 Mdot
.77006 .98572 Mdot
.38914 .99309 Mdot
.88955 .04769 Mdot
.97059 .93514 Mdot
.64846 .87634 Mdot
.9577 .73355 Mdot
.2787 .35032 Mdot
.82689 .04573 Mdot
.15599 .33044 Mdot
.3163 .10265 Mdot
.66819 .0095 Mdot
.6209 .20956 Mdot
.49858 .42674 Mdot
.81062 .8111 Mdot
.01418 .97217 Mdot
.24156 .436 Mdot
.73109 .52458 Mdot
.88102 .13903 Mdot
.04953 .77734 Mdot
.42633 .48314 Mdot
.32586 .00341 Mdot
.5563 .99091 Mdot
.0761 .4153 Mdot
.36458 .17891 Mdot
.01238 .408 Mdot
.07907 .9962 Mdot
.40771 .05526 Mdot
.2958 .14691 Mdot
.0956 .93546 Mdot
.99026 .40222 Mdot
.61446 .5783 Mdot
.16893 .51715 Mdot
.85205 .12493 Mdot
.19135 .92304 Mdot
.21159 .32581 Mdot
.27044 .33816 Mdot
.61437 .2959 Mdot
.75441 .7616 Mdot
.61312 .87227 Mdot
.871 .20313 Mdot
.93005 .34093 Mdot
.27149 .38051 Mdot
.92223 .16161 Mdot
.54536 .43509 Mdot
.4741 .45819 Mdot
.93 .97769 Mdot
.88658 .71898 Mdot
.09538 .20988 Mdot
.69654 .99596 Mdot
.92678 .86866 Mdot
.49873 .69341 Mdot
.64277 .09604 Mdot
.93744 .75693 Mdot
.93309 .10309 Mdot
.627 .99715 Mdot
.79833 .23955 Mdot
.55472 .95922 Mdot
.46386 .90532 Mdot
.26581 .82002 Mdot
.79799 .29296 Mdot
.1746 .25822 Mdot
.2786 .99541 Mdot
.09457 .14247 Mdot
.20636 .49208 Mdot
.73827 .94955 Mdot
.69225 .80049 Mdot
.5314 .36724 Mdot
.49356 .96254 Mdot
.3934 .84719 Mdot
.6126 .62311 Mdot
.69462 .59932 Mdot
.38402 .9435 Mdot
.09355 .79731 Mdot
.55897 .49212 Mdot
.43876 .03951 Mdot
.91317 .5514 Mdot
.29797 .66489 Mdot
.63359 .16732 Mdot
.1931 .88336 Mdot
.76931 .66751 Mdot
.39303 .44249 Mdot
.5753 .62931 Mdot
.09705 .42351 Mdot
.72846 .29271 Mdot
.60581 .0764 Mdot
.81971 .37192 Mdot
.56372 .45733 Mdot
.3181 .38402 Mdot
.886 .35498 Mdot
.24004 .59545 Mdot
.08416 .90566 Mdot
.0646 .33646 Mdot
.30308 .0276 Mdot
.90734 .12377 Mdot
.61535 .02401 Mdot
.58767 .46276 Mdot
.62304 .53133 Mdot
.34082 .68617 Mdot
.45731 .50757 Mdot
.45304 .8887 Mdot
.14611 .76133 Mdot
.64812 .88653 Mdot
.46703 .25657 Mdot
.15122 .92639 Mdot
.74947 .82853 Mdot
.84796 .36377 Mdot
.55994 .18532 Mdot
.67045 .30123 Mdot
.50785 .24345 Mdot
.87682 .06482 Mdot
.51007 .28884 Mdot
.99474 .77389 Mdot
.91414 .93855 Mdot
.75417 .30826 Mdot
.83086 .27204 Mdot
.17346 .84418 Mdot
.72242 .86866 Mdot
.93655 .03858 Mdot
.57437 .27389 Mdot
.68852 .3085 Mdot
.64588 .46221 Mdot
.38272 .65962 Mdot
.77159 .75607 Mdot
.79336 .43247 Mdot
.42002 .41381 Mdot
.4755 .56053 Mdot
.96799 .55669 Mdot
.688 .13014 Mdot
.65168 .27647 Mdot
.33896 .66279 Mdot
.48628 .43934 Mdot
.04277 .79086 Mdot
.26316 .39273 Mdot
.25287 .69145 Mdot
.02943 .20325 Mdot
.03401 .64875 Mdot
.20233 .19772 Mdot
.98674 .6587 Mdot
.83994 .25141 Mdot
.70382 .97864 Mdot
.56964 .38196 Mdot
.94912 .88125 Mdot
.48275 .56196 Mdot
.31527 .49071 Mdot
.65436 .57494 Mdot
.4869 .38099 Mdot
.97515 .97183 Mdot
.02738 .18339 Mdot
.35868 .16462 Mdot
.67171 .08982 Mdot
.11401 .4961 Mdot
.37167 .53686 Mdot
.14664 .51284 Mdot
.95982 .23277 Mdot
.10129 .5577 Mdot
.07009 .35408 Mdot
.027 .55166 Mdot
.15796 .36179 Mdot
.48962 .18088 Mdot
.54166 .75958 Mdot
.72341 .4136 Mdot
.49904 .10459 Mdot
.99636 .47578 Mdot
.56391 .97405 Mdot
.42052 .55071 Mdot
.16118 .29856 Mdot
.89251 .54524 Mdot
.5391 .55955 Mdot
.27248 .56469 Mdot
.95932 .61203 Mdot
.35175 .99946 Mdot
.81289 .44177 Mdot
.11557 .99765 Mdot
.9521 .73709 Mdot
.53355 .92688 Mdot
.77556 .19517 Mdot
.71677 .97428 Mdot
.2149 .46984 Mdot
.2488 .85144 Mdot
.25564 .31403 Mdot
.54388 .86495 Mdot
.86524 .24953 Mdot
.57677 .26971 Mdot
.43687 .40428 Mdot
.0272 .88406 Mdot
.05795 .26001 Mdot
.92963 .36135 Mdot
.70449 .6462 Mdot
.82699 .98252 Mdot
.92141 .77553 Mdot
.98591 .56355 Mdot
.24459 .90212 Mdot
.04165 .24204 Mdot
.81706 .02857 Mdot
.9109 .38959 Mdot
.79108 .22119 Mdot
.44879 .08101 Mdot
.30058 .33326 Mdot
.92514 .29083 Mdot
.99479 .26525 Mdot
.70625 .90719 Mdot
.70179 .08555 Mdot
.33382 .77218 Mdot
.99663 .76548 Mdot
.8348 .91629 Mdot
.61001 .13336 Mdot
.54523 .13492 Mdot
.40505 .53809 Mdot
.67365 .45288 Mdot
.70556 .78568 Mdot
.14382 .5528 Mdot
.06319 .95058 Mdot
.82613 .27553 Mdot
.00261 .4442 Mdot
.13869 .90274 Mdot
.60062 .11429 Mdot
.71552 .4182 Mdot
.40026 .5446 Mdot
.79823 .87263 Mdot
.56683 .40074 Mdot
.5366 .99304 Mdot
.47254 .22695 Mdot
.94272 .00124 Mdot
.92344 .69065 Mdot
.52718 .13833 Mdot
.34885 .82411 Mdot
.93648 .79926 Mdot
.36439 .30491 Mdot
.65209 .85477 Mdot
.37619 .33996 Mdot
.45878 .36873 Mdot
.39605 .30967 Mdot
.51203 .83575 Mdot
.38851 .71362 Mdot
.98147 .41544 Mdot
.0312 .40282 Mdot
.04968 .84942 Mdot
.14137 .0172 Mdot
.70068 .6059 Mdot
.37917 .28725 Mdot
.45129 .1753 Mdot
.4624 .55946 Mdot
.41596 .37072 Mdot
.45108 .79743 Mdot
.50327 .97374 Mdot
.48865 .54943 Mdot
.87613 .98378 Mdot
.02224 .67918 Mdot
.43349 .6822 Mdot
.27963 .11478 Mdot
.19042 .67445 Mdot
.36418 .21541 Mdot
.32523 .9002 Mdot
.51802 .06998 Mdot
.35116 .10737 Mdot
.49426 .83738 Mdot
.43938 .69803 Mdot
.39149 .87021 Mdot
.93755 .15779 Mdot
.92375 .73136 Mdot
.07484 .88108 Mdot
.20621 .06205 Mdot
.33757 .80291 Mdot
.28163 .44922 Mdot
.42986 .33227 Mdot
.34831 .80653 Mdot
.49407 .67921 Mdot
.35574 .56068 Mdot
.63951 .53899 Mdot
.53756 .0996 Mdot
.30913 .94139 Mdot
.98762 .94539 Mdot
.79135 .46059 Mdot
.37561 .28243 Mdot
.88733 .26109 Mdot
.67428 .38662 Mdot
.04385 .3427 Mdot
.86976 .0244 Mdot
.96334 .25831 Mdot
.93331 .04702 Mdot
.71716 .12892 Mdot
.00769 .33709 Mdot
.81145 .75826 Mdot
.44234 .01169 Mdot
.6174 .72824 Mdot
.65834 .14021 Mdot
.14615 .03791 Mdot
.41691 .1512 Mdot
.6959 .14279 Mdot
.07582 .56358 Mdot
.29991 .47598 Mdot
.57527 .12416 Mdot
.02197 .78198 Mdot
.12625 .15955 Mdot
.59334 .60378 Mdot
.13008 .72858 Mdot
.61059 .48216 Mdot
.01735 .191 Mdot
.85506 .85007 Mdot
.06699 .43084 Mdot
.77906 .28853 Mdot
.55918 .28966 Mdot
.86775 .40449 Mdot
.41486 .80119 Mdot
.42904 .07093 Mdot
.84106 .23792 Mdot
.23165 .87949 Mdot
.28418 .87844 Mdot
.21505 .97556 Mdot
.65567 .28214 Mdot
.789 .69859 Mdot
.00497 .44327 Mdot
.65091 .82905 Mdot
.02646 .54428 Mdot
.15073 .01115 Mdot
.06807 .36991 Mdot
.29796 .33598 Mdot
.7866 .70463 Mdot
.4763 .90529 Mdot
.03463 .26515 Mdot
.81609 .3058 Mdot
.81879 .36064 Mdot
.62186 .17737 Mdot
.2593 .4924 Mdot
.59114 .93139 Mdot
.79056 .3328 Mdot
.82353 .53527 Mdot
.16369 .57635 Mdot
.13589 .5852 Mdot
.75496 .43462 Mdot
.07675 .30333 Mdot
.26713 .76776 Mdot
.83652 .36387 Mdot
.82819 .82934 Mdot
.63926 .60137 Mdot
.00296 .91122 Mdot
.63756 .21887 Mdot
.79916 .13132 Mdot
.20576 .28984 Mdot
.07729 .94537 Mdot
.4948 .3103 Mdot
.90939 .08452 Mdot
.01953 .43507 Mdot
.03358 .88351 Mdot
.62311 .63031 Mdot
.59562 .45805 Mdot
.56646 .42498 Mdot
.14844 .99553 Mdot
.36411 .61066 Mdot
.78899 .46462 Mdot
.71754 .88956 Mdot
.12109 .95638 Mdot
.66013 .17913 Mdot
.81929 .4422 Mdot
.14609 .18255 Mdot
.37287 .15018 Mdot
.98524 .94624 Mdot
.18239 .25105 Mdot
.83312 .10356 Mdot
.64328 .67137 Mdot
.08553 .9283 Mdot
.25542 .76205 Mdot
.95117 .59208 Mdot
.55939 .23775 Mdot
.72667 .02797 Mdot
.15389 .20331 Mdot
.13341 .44627 Mdot
.37674 .4629 Mdot
.75523 .90771 Mdot
.74229 .81555 Mdot
.29383 .40344 Mdot
.73562 .56223 Mdot
.83877 .89565 Mdot
.85602 .35355 Mdot
.45347 .86688 Mdot
.91492 .69144 Mdot
.108 .28263 Mdot
.14491 .9332 Mdot
.38066 .44641 Mdot
.27092 .87571 Mdot
.2071 .14924 Mdot
.07918 .62045 Mdot
.47489 .34819 Mdot
.95251 .50725 Mdot
.21753 .85419 Mdot
.50692 .73614 Mdot
.39428 .56284 Mdot
.15595 .45773 Mdot
.67347 .7141 Mdot
.41481 .11017 Mdot
.71421 .69622 Mdot
.75015 .65804 Mdot
.10558 .13126 Mdot
.21299 .60846 Mdot
.21788 .3752 Mdot
.85158 .64825 Mdot
.4061 .9532 Mdot
.76497 .47101 Mdot
.60472 .98051 Mdot
.18038 .45541 Mdot
.48499 .68029 Mdot
.2149 .7683 Mdot
.14564 .40445 Mdot
.01528 .53208 Mdot
.61152 .71731 Mdot
.41397 .51539 Mdot
.77798 .91244 Mdot
.14514 .27303 Mdot
.81218 .35237 Mdot
.78831 .33269 Mdot
.64412 .96868 Mdot
.02889 .46815 Mdot
.72633 .88065 Mdot
.39606 .16313 Mdot
.13559 .04604 Mdot
.75276 .04478 Mdot
.12137 .75788 Mdot
.94873 .10566 Mdot
.74885 .27362 Mdot
.39989 .23221 Mdot
.36974 .30487 Mdot
.02302 .29271 Mdot
.11884 .92129 Mdot
.41965 .37715 Mdot
.79137 .45349 Mdot
.60101 .84212 Mdot
.21016 .00405 Mdot
.23045 .23638 Mdot
.69407 .69555 Mdot
.85362 .72086 Mdot
.35409 .85242 Mdot
.04263 .89502 Mdot
.59435 .97171 Mdot
.43627 .00823 Mdot
.83374 .61909 Mdot
.62679 .22278 Mdot
.47361 .74716 Mdot
.42203 .95635 Mdot
.85503 .3159 Mdot
.77443 .12957 Mdot
.78528 .05198 Mdot
.49601 .98331 Mdot
.85482 .59855 Mdot
.03192 .49462 Mdot
.67013 .22987 Mdot
.00557 .94997 Mdot
.40647 .03104 Mdot
.02488 .29557 Mdot
.38257 .84116 Mdot
.99923 .93038 Mdot
.95312 .12318 Mdot
.67129 .18571 Mdot
.77956 .49292 Mdot
.76346 .81405 Mdot
.52827 .32361 Mdot
.32069 .85609 Mdot
.26871 .6766 Mdot
.8954 .38151 Mdot
.43133 .26655 Mdot
.30451 .66434 Mdot
.62654 .83058 Mdot
.84464 .30696 Mdot
.07114 .27067 Mdot
.7822 .68307 Mdot
.69006 .37072 Mdot
.44083 .30162 Mdot
.77276 .45349 Mdot
.70029 .02409 Mdot
.92875 .17583 Mdot
.3699 .08502 Mdot
.945 .51445 Mdot
.52119 .80761 Mdot
.91036 .12105 Mdot
.06871 .90475 Mdot
.45645 .23841 Mdot
.90911 .79636 Mdot
.16506 .45624 Mdot
.87283 .10157 Mdot
.99215 .61914 Mdot
.79341 .61548 Mdot
.49071 .99821 Mdot
.97182 .96194 Mdot
.95201 .8854 Mdot
.05484 .77125 Mdot
.62248 .34994 Mdot
.39434 .26816 Mdot
.73644 .48713 Mdot
.09394 .04333 Mdot
.94806 .43975 Mdot
.776 .54821 Mdot
.54644 .24329 Mdot
.39799 .35765 Mdot
.50817 .87696 Mdot
.96495 .79418 Mdot
.91731 .41698 Mdot
.537 .59707 Mdot
.93791 .64836 Mdot
.55695 .79115 Mdot
.60008 .74857 Mdot
.84886 .3284 Mdot
.24029 .88425 Mdot
.71579 .36709 Mdot
.13025 .02938 Mdot
.71926 .42501 Mdot
.19898 .56646 Mdot
.14967 .07854 Mdot
.66724 .58934 Mdot
.19167 .05029 Mdot
.35665 .35495 Mdot
.04893 .67243 Mdot
.15363 .20512 Mdot
.58484 .94626 Mdot
.48535 .89556 Mdot
.50129 .16421 Mdot
.77424 .27209 Mdot
.19373 .3 Mdot
.12631 .13242 Mdot
.64108 .81072 Mdot
.84838 .97385 Mdot
.83142 .37795 Mdot
.90983 .05194 Mdot
.36867 .11839 Mdot
.20451 .44567 Mdot
.16779 .59341 Mdot
.30104 .14332 Mdot
.1483 .0136 Mdot
.92222 .42303 Mdot
.37571 .09877 Mdot
.41577 .68768 Mdot
.35334 .87821 Mdot
.92875 .14916 Mdot
.0615 .1043 Mdot
.45924 .49628 Mdot
.08402 .39682 Mdot
.86448 .45529 Mdot
.47608 .21743 Mdot
.91619 .90633 Mdot
.72087 .83134 Mdot
.60762 .07516 Mdot
.79897 .09995 Mdot
.76436 .79422 Mdot
.87304 .81513 Mdot
.19487 .24323 Mdot
.42811 .14946 Mdot
.15392 .14409 Mdot
.73036 .34934 Mdot
.91518 .10608 Mdot
.84945 .49255 Mdot
.40209 .81459 Mdot
.5341 .09798 Mdot
.4249 .32715 Mdot
.16798 .57793 Mdot
.22504 .93682 Mdot
.85154 .14891 Mdot
.45293 .11879 Mdot
.84046 .45748 Mdot
.86448 .40431 Mdot
.54506 .68608 Mdot
.40164 .68276 Mdot
.21425 .74432 Mdot
.41518 .45267 Mdot
.06055 .05689 Mdot
.58474 .73116 Mdot
.39022 .04091 Mdot
.76691 .17736 Mdot
.08946 .26089 Mdot
.72649 .62534 Mdot
.6647 .2469 Mdot
.44103 .672 Mdot
.74607 .97459 Mdot
.47762 .38308 Mdot
.07809 .84225 Mdot
.67101 .51828 Mdot
.60072 .35317 Mdot
.48761 .37198 Mdot
.63731 .91321 Mdot
.3217 .58101 Mdot
.0923 .05111 Mdot
.99491 .50069 Mdot
.86518 .21282 Mdot
.13906 .42079 Mdot
.54244 .62013 Mdot
.08923 .41167 Mdot
.00476 .37537 Mdot
.98982 .4487 Mdot
.99306 .4638 Mdot
.90756 .67636 Mdot
.7872 .11905 Mdot
.04084 .5191 Mdot
.08302 .65296 Mdot
.61516 .59392 Mdot
.78016 .88715 Mdot
.03351 .7881 Mdot
.67153 .65247 Mdot
.38698 .73862 Mdot
.22457 .70824 Mdot
.91806 .85564 Mdot
.83502 .82703 Mdot
.61885 .73969 Mdot
.47507 .11526 Mdot
.99643 .62514 Mdot
.78845 .0391 Mdot
.97871 .60078 Mdot
.5968 .71537 Mdot
.35743 .25366 Mdot
.33406 .62371 Mdot
.55654 .96429 Mdot
.6657 .34688 Mdot
.02522 .64721 Mdot
.44597 .12164 Mdot
.82207 .342 Mdot
.37081 .42117 Mdot
.45443 .33951 Mdot
.9422 .97644 Mdot
.00648 .29865 Mdot
.95487 .82913 Mdot
.09899 .4379 Mdot
.04415 .76275 Mdot
.10332 .10295 Mdot
.80684 .99466 Mdot
.50441 .81325 Mdot
.99109 .28891 Mdot
.2358 .07765 Mdot
.0385 .43297 Mdot
.25854 .30713 Mdot
.50044 .91142 Mdot
.80487 .42963 Mdot
.10197 .6628 Mdot
.13558 .53721 Mdot
.64738 .50608 Mdot
.61136 .06828 Mdot
.24382 .94283 Mdot
.53176 .62404 Mdot
.8228 .06715 Mdot
.84675 .21431 Mdot
.36432 .21403 Mdot
.04062 .47268 Mdot
.30079 .88897 Mdot
.80243 .45604 Mdot
.79393 .64263 Mdot
.1135 .3275 Mdot
.54891 .73034 Mdot
.06314 .8634 Mdot
.92767 .17048 Mdot
.9704 .80648 Mdot
.52106 .49521 Mdot
.71967 .21382 Mdot
.57501 .69944 Mdot
.07137 .3102 Mdot
.87132 .40424 Mdot
.68813 .43824 Mdot
.49973 .34137 Mdot
.97312 .5295 Mdot
.51572 .06144 Mdot
.52794 .09587 Mdot
.18294 .45322 Mdot
.91739 .70166 Mdot
.08159 .36897 Mdot
.82974 .07047 Mdot
.93262 .08265 Mdot
.2971 .33186 Mdot
.64605 .1015 Mdot
.03802 .28573 Mdot
.56784 .32758 Mdot
.47464 .37045 Mdot
.63324 .71056 Mdot
.57875 .86599 Mdot
.05605 .81467 Mdot
.20242 .59551 Mdot
.3887 .06292 Mdot
.77913 .0978 Mdot
.02639 .38821 Mdot
.07963 .3732 Mdot
.79621 .88793 Mdot
.62224 .47919 Mdot
.65062 .13783 Mdot
.55397 .52197 Mdot
.4333 .85915 Mdot
.39641 .10265 Mdot
.76101 .60798 Mdot
.75284 .12946 Mdot
.78996 .00091 Mdot
.37186 .45437 Mdot
.38599 .22602 Mdot
.90519 .66911 Mdot
.11111 .77731 Mdot
.69472 .79811 Mdot
.06467 .18632 Mdot
.78153 .82623 Mdot
.09537 .93956 Mdot
.78658 .10452 Mdot
.73767 .7307 Mdot
.46406 .59681 Mdot
.36104 .13254 Mdot
.49842 .56462 Mdot
.58448 .5005 Mdot
.1486 .28986 Mdot
.86703 .17149 Mdot
.83308 .12757 Mdot
.35687 .54031 Mdot
.69378 .71306 Mdot
.65141 .20604 Mdot
.31945 .99921 Mdot
.52106 .86298 Mdot
.43113 .8195 Mdot
.61476 .16423 Mdot
.38694 .83088 Mdot
.6005 .06813 Mdot
.63698 .94818 Mdot
.12388 .28469 Mdot
.356 .22963 Mdot
.34389 .32895 Mdot
.25156 .13863 Mdot
.09624 .70778 Mdot
.39309 .54187 Mdot
.16929 .2535 Mdot
.55001 .16303 Mdot
.16072 .71264 Mdot
.58564 .91876 Mdot
.00218 .05866 Mdot
.37452 .56463 Mdot
.45027 .37496 Mdot
.60985 .73405 Mdot
.52254 .46433 Mdot
.88976 .17717 Mdot
.01056 .28354 Mdot
.06602 .02085 Mdot
.27858 .48629 Mdot
.95909 .46005 Mdot
.66572 .3412 Mdot
.94904 .98732 Mdot
.24134 .73535 Mdot
.01327 .82676 Mdot
.21266 .95657 Mdot
.99463 .51325 Mdot
.23244 .94607 Mdot
.74804 .91859 Mdot
.66507 .01367 Mdot
.23289 .28 Mdot
.79815 .98408 Mdot
.71277 .41181 Mdot
.55489 .18455 Mdot
.16341 .06371 Mdot
.86102 .07573 Mdot
.72791 .66127 Mdot
.12062 .54597 Mdot
.10465 .56811 Mdot
.43229 .2201 Mdot
.95958 .28112 Mdot
.1968 .62219 Mdot
.32268 .35196 Mdot
.94953 .04482 Mdot
.04003 .51469 Mdot
.82159 .41295 Mdot
.46345 .04741 Mdot
.34813 .91139 Mdot
.16661 .80592 Mdot
.66148 .7978 Mdot
.63641 .82761 Mdot
.65676 .97522 Mdot
.22678 .1394 Mdot
.87558 .95506 Mdot
.33872 .1699 Mdot
.53338 .3235 Mdot
.72396 .23001 Mdot
.26975 .49965 Mdot
.807 .79835 Mdot
.36655 .97218 Mdot
.11254 .39945 Mdot
.24418 .7964 Mdot
.04205 .18034 Mdot
.03647 .20047 Mdot
.42456 .61128 Mdot
.56126 .84356 Mdot
.51505 .86007 Mdot
.66617 .10163 Mdot
.21952 .02209 Mdot
.73316 .19304 Mdot
.74827 .65853 Mdot
.98435 .59785 Mdot
.25855 .81488 Mdot
.12465 .2605 Mdot
.61307 .05492 Mdot
.67147 .43996 Mdot
.78786 .02831 Mdot
.52597 .01925 Mdot
.69527 .77438 Mdot
.47196 .51148 Mdot
.06541 .15075 Mdot
.13163 .9361 Mdot
.72737 .95823 Mdot
.74597 .87525 Mdot
.02787 .72967 Mdot
.00237 .03428 Mdot
.82976 .04646 Mdot
.9533 .186 Mdot
.64569 .62067 Mdot
.82807 .54282 Mdot
.37152 .46639 Mdot
.95496 .44425 Mdot
.85499 .70508 Mdot
.4231 .13091 Mdot
.7599 .15838 Mdot
.27519 .64651 Mdot
.28807 .04984 Mdot
.8171 .01845 Mdot
.83858 .39083 Mdot
.45948 .4092 Mdot
.80701 .1542 Mdot
.04722 .43086 Mdot
.03425 .28019 Mdot
.50093 .42111 Mdot
.58605 .20998 Mdot
.70361 .87636 Mdot
.42318 .44254 Mdot
.85212 .79603 Mdot
.72122 .99947 Mdot
.63096 .19065 Mdot
.27242 .20428 Mdot
.7484 .15415 Mdot
.00628 .45283 Mdot
.1227 .33162 Mdot
.57125 .71021 Mdot
.03172 .32645 Mdot
.42067 .10817 Mdot
.89918 .87851 Mdot
.54907 .0845 Mdot
.48908 .62809 Mdot
.27194 .46446 Mdot
.48639 .88954 Mdot
.44375 .86978 Mdot
.3046 .11301 Mdot
.99443 .85168 Mdot
.59352 .39098 Mdot
.82194 .69087 Mdot
.97832 .65292 Mdot
.00139 .19075 Mdot
.64371 .18247 Mdot
.02367 .56445 Mdot
.57938 .13811 Mdot
.22083 .4834 Mdot
.52681 .82217 Mdot
.35101 .22211 Mdot
.80648 .14895 Mdot
.76553 .80845 Mdot
.63373 .14532 Mdot
.53824 .6568 Mdot
.2128 .10233 Mdot
.90402 .06608 Mdot
.00677 .30293 Mdot
.51054 .93334 Mdot
.00109 .55416 Mdot
.68492 .86708 Mdot
.06728 .30288 Mdot
.9097 .2616 Mdot
.68316 .77133 Mdot
.54956 .85648 Mdot
.64955 .03966 Mdot
.613 .61199 Mdot
.98796 .54946 Mdot
.0397 .13642 Mdot
.3802 .85126 Mdot
.16395 .60396 Mdot
.81227 .86303 Mdot
.90545 .31164 Mdot
.32371 .96527 Mdot
.58632 .68299 Mdot
.04412 .81354 Mdot
.46589 .4167 Mdot
.99851 .15113 Mdot
.46343 .24497 Mdot
.61612 .03657 Mdot
.7916 .67756 Mdot
.80359 .80903 Mdot
.19419 .50917 Mdot
.38528 .49235 Mdot
.8914 .59606 Mdot
.62184 .97653 Mdot
.71294 .48164 Mdot
.10788 .60437 Mdot
.83304 .67388 Mdot
.7302 .00267 Mdot
.77951 .85906 Mdot
.50927 .36352 Mdot
.60009 .74961 Mdot
.33479 .9913 Mdot
.8087 .80194 Mdot
.37204 .04574 Mdot
.55889 .61908 Mdot
.29561 .65579 Mdot
.23416 .68979 Mdot
.57579 .47358 Mdot
.98128 .47188 Mdot
.45852 .09198 Mdot
.61031 .01206 Mdot
.36229 .10594 Mdot
.60421 .88033 Mdot
.44677 .7023 Mdot
.20084 .4775 Mdot
.50913 .09148 Mdot
.25061 .28174 Mdot
.75997 .02556 Mdot
.45338 .18008 Mdot
.60519 .11579 Mdot
.98265 .125 Mdot
.77019 .59855 Mdot
.00506 .48372 Mdot
.83035 .90892 Mdot
.78844 .21286 Mdot
.788 .76062 Mdot
.17928 .11355 Mdot
.70772 .05696 Mdot
.38327 .42606 Mdot
.33282 .63543 Mdot
.36477 .67805 Mdot
.12937 .1408 Mdot
.89008 .13196 Mdot
.91525 .96003 Mdot
.47776 .24421 Mdot
.70188 .62245 Mdot
.08363 .58122 Mdot
.48478 .29668 Mdot
.481 .89981 Mdot
.20238 .81766 Mdot
.53356 .05692 Mdot
.3022 .5973 Mdot
.57347 .8089 Mdot
.77012 .04208 Mdot
.24477 .06299 Mdot
.20502 .66827 Mdot
.33909 .41317 Mdot
.93962 .45103 Mdot
.69292 .19391 Mdot
.04584 .55724 Mdot
.80134 .93489 Mdot
.40861 .31899 Mdot
.71377 .4537 Mdot
.53267 .13537 Mdot
.75413 .08473 Mdot
.36711 .683 Mdot
.87846 .4418 Mdot
.55331 .59183 Mdot
.1038 .6182 Mdot
.02531 .56034 Mdot
.84585 .82391 Mdot
.42437 .40151 Mdot
.44513 .47135 Mdot
.60713 .51759 Mdot
.13097 .61659 Mdot
.66508 .77198 Mdot
.94448 .99493 Mdot
.88215 .64347 Mdot
.66235 .96622 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00Co0000ooooool0003o00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00Gooooo0_l00006ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01_ooool2o`00
00Gooooo00?o0000ooooooooool02_ooool2o`0000;ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo0000ooooo`0?oooo
o`03o`000?oooooooooo00;ooooo000Nooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00Co0000ooooool0
003o00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo0_l00006oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool01_ooool2o`0000Gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0:ooooo`;o000000?oooooo`000?ooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001ko
oooo00?o0000ooooooooool0R_ooool2o`0004Wooooo0_l0000gooooo`;o0000=oooool001kooooo
00?o0000ooooooooool0;?ooool3o`00057ooooo0_l00008ooooo`Co0000=?ooool2o`00013ooooo
0ol0001`ooooo`007_ooool00ol0003oooooooooo`0/ooooo`?o0000DOooool2o`0000[ooooo0_l0
000dooooo`;o00004?ooool2o`00077ooooo000Nooooo`03o`000?oooooooooo02[ooooo0_l0001k
ooooo`;o0000GOooool2o`0003oooooo000Nooooo`03o`000?oooooooooo017ooooo0_l0000Goooo
o`;o00005oooool2o`0006;ooooo0_l0001Mooooo`;o0000?oooool001kooooo00?o0000oooooooo
ool04Oooool2o`00033ooooo0_l0001oooooo`;o00006_ooool2o`00017ooooo0_l0000Rooooo`;o
0000;_ooool001kooooo00?o0000ooooooooool0G_ooool2o`0006Cooooo0_l0000Jooooo`;o0000
1_ooool2o`0000Wooooo0_l00007ooooo`;o00002?ooool2o`0000oooooo0_l0000Xooooo`;o0000
1?ooool001kooooo00?o0000ooooooooool09_ooool2o`0003Kooooo0_l0000Pooooo`;o0000I_oo
ool2o`0001;ooooo0_l00008ooooo`;o0000>Oooool2o`0000Cooooo000Nooooo`;o00009oooool2
o`0005Sooooo0_l00035ooooo`007_ooool2o`0002cooooo0_l0002Gooooo`;o0000POooool001ko
oooo00?o0000ooooooooool0:oooool2o`0004kooooo0_l0000>ooooo`;o0000=oooool2o`0000Wo
oooo0_l0000[ooooo`;o0000;_ooool2o`0001Wooooo000Nooooo`03o`000?oooooooooo01[ooooo
0_l0001Oooooo`;o00003_ooool2o`0004;ooooo0_l0000Uooooo`;o00001?ooool2o`0002kooooo
0_l0000Iooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o00003?ooool2o`0004_ooooo0_l0
000Looooo`;o0000G?ooool2o`0000?ooooo0_l0000Aooooo`?o00007oooool2o`0000Cooooo0_l0
000Dooooo`007_ooool00ol0003oooooooooo`0Xooooo`;o00004?ooool2o`0001kooooo0_l0000I
ooooo`;o00007?ooool2o`0005cooooo0_l0000Fooooo`?o00004Oooool2o`0000cooooo0_l00004
ooooo`;o00005?ooool001kooooo0_l0000Kooooo`;o00007_ooool2o`0001kooooo0_l0002Ooooo
o`;o00008?ooool2o`0000Gooooo0_l0000Qooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o
0000I?ooool2o`00047ooooo0_l0000fooooo`;o00009oooool2o`00027ooooo000Nooooo`;o0000
4Oooool2o`0006kooooo0_l0000Wooooo`;o00006?ooool2o`0001gooooo0_l0001Sooooo`007_oo
ool2o`00017ooooo0_l0000]ooooo`;o0000>Oooool2o`0002Sooooo0_l00003ooooo`;o0000=ooo
ool2o`0006?ooooo000Nooooo`03o`000?oooooooooo037ooooo0_l0000<ooooo`;o00002_ooool2
o`0002gooooo0_l0000Xooooo`;o0000Koooool2o`0000;ooooo0_l0000/ooooo`007_ooool00ol0
003oooooooooo`0aooooo`;o00006?ooool2o`0007;ooooo0_l00002ooooo`;o0000;oooool2o`00
017ooooo0_l0000<ooooo`;o00000_ooool2o`0000Oooooo0_l0000Sooooo`007_ooool00ol0003o
ooooooooo`27ooooo`;o00006oooool2o`0001Wooooo0_l00002ooooo`;o0000;oooool2o`00017o
oooo0_l000000ooooooo0000o`00000Fooooo`;o00008oooool001kooooo00?o0000ooooooooool0
Qoooool2o`0001_ooooo0_l0000Kooooo`;o0000Aoooool2o`0003_ooooo000Nooooo`03o`000?oo
oooooooo04Wooooo0_l0000Iooooo`;o0000Foooool2o`00057ooooo0_l0000aooooo`007_ooool0
0ol0003oooooooooo`0]ooooo`;o00006_ooool2o`0001Wooooo0_l0000Xooooo`;o0000<Oooool2
o`00057ooooo0_l0000aooooo`007_ooool00ol0003oooooooooo`0]ooooo`;o0000Goooool2o`00
09_ooooo0_l0000Jooooo`007_ooool00ol0003oooooooooo`1dooooo`;o0000>?ooool2o`00033o
oooo0_l0000?ooooo`;o0000<Oooool2o`0000Gooooo0_l0000Jooooo`007_ooool00ol0003ooooo
ooooo`1dooooo`;o0000>?ooool2o`0002Kooooo0_l00008ooooo`;o00003oooool2o`00037ooooo
0_l0000Qooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o00009?ooool2o`0004cooooo0_l0
000>ooooo`;o0000<oooool2o`0006oooooo000Nooooo`03o`000?oooooooooo01gooooo0_l0000T
ooooo`;o0000=_ooool2o`0001Cooooo0_l0000>ooooo`;o00001Oooool2o`0002?ooooo0_l0001h
ooooo`007_ooool00ol0003oooooooooo`1fooooo`;o00000oooool2o`0002_ooooo1Ol0000Poooo
o`;o0000:_ooool2o`0004cooooo000Nooooo`;o0000@_ooool2o`00023ooooo0_l0000Aooooo`;o
00001Oooool2o`0002_ooooo0ol0000Qooooo`;o00001?ooool2o`0002?ooooo0_l00005ooooo`;o
00005_ooool2o`0002gooooo000Nooooo`03o`000?oooooooooo013ooooo0_l0000;ooooo`;o0000
8_ooool2o`00023ooooo0_l0000=ooooo`;o00002Oooool2o`0001oooooo0_l0000^ooooo`;o0000
1?ooool2o`0002Kooooo0_l00002ooooo`;o00002Oooool2o`0000_ooooo0_l0000Aooooo`;o0000
0oooool2o`0001Gooooo000Nooooo`03o`000?oooooooooo013ooooo0_l0000;ooooo`;o0000Cooo
ool2o`0000;ooooo0_l0000Aooooo`;o00005oooool2o`0005cooooo0_l0000=ooooo`;o00006?oo
ool2o`0000Cooooo0_l00003ooooo`;o00005Oooool001kooooo00?o0000ooooooooool0K_ooool2
o`0001?ooooo1?l0002Nooooo`;o00008?ooool001kooooo00?o0000ooooooooool0=_ooool2o`00
01oooooo0_l00006ooooo`;o00008_ooool2o`0003[ooooo0_l00026ooooo`007_ooool00ol0003o
ooooooooo`0fooooo`;o00007oooool2o`0000Kooooo0_l0000eooooo`;o00009oooool4o`0007[o
oooo0_l00008ooooo`007_ooool00ol0003oooooooooo`1dooooo`;o00006Oooool2o`0000Gooooo
0_l0000Yooooo`;o0000>Oooool2o`0002Kooooo0_l0000Gooooo`;o00002?ooool001kooooo00?o
0000ooooooooool0M?ooool2o`0001Oooooo1?l0000Vooooo`;o0000@oooool2o`0002Gooooo0ol0
000<ooooo`;o00004oooool001kooooo00?o0000ooooooooool0SOooool2o`0002Sooooo0_l0001H
ooooo`;o00004?ooool2o`0000gooooo0_l00007ooooo`;o00002_ooool001kooooo00?o0000oooo
ooooool0g?ooool2o`0000Oooooo0_l0000:ooooo`;o00001Oooool2o`00017ooooo0_l00004oooo
o`;o0000:?ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo01kooooo0_l00005ooooo`;o
0000B_ooool2o`0001;ooooo0_l0000kooooo`;o00006?ooool2o`0000Oooooo0_l0000:ooooo`;o
00001Oooool2o`0000Kooooo0_l00009ooooo`;o00004?ooool2o`0002Sooooo000Nooooo`03o`00
0?oooooooooo00Wooooo0_l0000Cooooo`;o00001Oooool2o`0004[ooooo0_l0000Booooo`;o0000
8_ooool2o`0000;ooooo0_l0000Cooooo`;o0000??ooool2o`0001_ooooo0_l0000Xooooo`007_oo
ool00ol0003oooooooooo`09ooooo`;o0000>oooool2o`0000Kooooo0_l0001Gooooo`Co00000_oo
ool2o`0000Wooooo0_l0000Eooooo`;o0000BOooool2o`000003ooooool0003o000002Sooooo000N
ooooo`03o`000?oooooooooo01_ooooo0_l00009ooooo`;o00007_ooool2o`0000Kooooo0_l0001G
ooooo`;o00003oooool2o`0001Gooooo0_l000000ooooooo0000o`00000:ooooo`;o0000>_ooool2
o`0002_ooooo000Nooooo`03o`000?oooooooooo01_ooooo0_l00009ooooo`;o00001_ooool2o`00
02kooooo0_l0001Zooooo`;o00001_ooool2o`0000[ooooo0_l0001Looooo`;o00002Oooool001ko
oooo00?o0000ooooooooool0;_ooool2o`0002cooooo1?l0001Zooooo`;o0000=_ooool2o`0000go
oooo0_l0000Yooooo`;o00002Oooool001kooooo0_l0000Booooo`;o0000;?ooool2o`0001_ooooo
0_l0000Gooooo`;o00003?ooool2o`0000;ooooo0_l0001iooooo`;o00003Oooool2o`0001Oooooo
0_l0000Eooooo`;o00001?ooool001kooooo00?o0000ooooooooool04Oooool2o`0002cooooo0_l0
000dooooo`;o00003?ooool2o`0000;ooooo0_l0001Vooooo`;o00004Oooool2o`0002Kooooo0_l0
000Eooooo`;o00001?ooool001kooooo00?o0000ooooooooool0=_ooool2o`000;Oooooo0_l0000A
ooooo`;o0000:Oooool2o`0001Sooooo000Nooooo`03o`000?oooooooooo02Gooooo0_l0000?oooo
o`;o0000?_ooool2o`0007_ooooo0_l0000hooooo`;o00006?ooool001kooooo00?o0000oooooooo
ool09Oooool2o`0004oooooo0_l00005ooooo`;o00008?ooool2o`0000kooooo0_l0000Cooooo`;o
0000;Oooool2o`0003?ooooo0_l0000Mooooo`007_ooool00ol0003oooooooooo`1`ooooo`;o0000
2oooool2o`00023ooooo0_l0000>ooooo`;o00004oooool2o`0000Cooooo0_l0001Looooo`;o0000
7Oooool001kooooo00?o0000ooooooooool0J_ooool2o`0000Cooooo0_l0001Hooooo`;o0000GOoo
ool2o`0001cooooo000Nooooo`03o`000?oooooooooo06[ooooo0_l0002Zooooo`;o00004Oooool2
o`0001cooooo000Nooooo`03o`000?oooooooooo08oooooo0_l00025ooooo`;o00004_ooool2o`00
01_ooooo000Nooooo`03o`000?oooooooooo07;ooooo0_l0000Kooooo`;o0000=Oooool2o`0000_o
oooo0_l0000Pooooo`;o00009_ooool2o`0000_ooooo0_l0000Kooooo`007_ooool00ol0003ooooo
ooooo`0:ooooo`;o00007oooool2o`0004Gooooo0_l0000Kooooo`;o00002_ooool2o`0002Wooooo
0_l00005ooooo`;o00001?ooool2o`00023ooooo0_l0000Vooooo`;o0000:?ooool001kooooo00?o
0000ooooooooool01Oooool2o`0000?ooooo0_l0000Oooooo`;o0000H_ooool2o`0000[ooooo0_l0
000Cooooo`Co00006Oooool2o`0000Oooooo0_l0001_ooooo`007_ooool00ol0003oooooooooo`05
ooooo`;o00002_ooool2o`0009gooooo1?l0000Rooooo`;o0000F_ooool2o`0001?ooooo000Moooo
o`;o00001?ooool2o`0000gooooo0_l0002fooooo`;o0000Ioooool2o`0001?ooooo0003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00005ooooo`;o00001?ooool2o`00
0<Gooooo0_l0000Booooo`;o00002oooool2o`0000cooooo0_l0001=ooooo`000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool0
0ol0003oooooooooo`0nooooo`;o0000WOooool2o`0000_ooooo0_l0000<ooooo`;o0000COooool0
00?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol00008
ooooo`;o0000=?ooool2o`000?oooooo2?ooool000?ooooo00Go0000ooooooooooooooooo`00000=
ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool01Oooool2o`000003ooooool0003o
000002Cooooo0_l0000Tooooo`;o0000`Oooool2o`0002kooooo0003ooooo`05o`000?oooooooooo
ooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l0000W
ooooo`;o00009?ooool2o`0004;ooooo0_l0000fooooo`;o0000AOooool2o`0002kooooo0003oooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00oooooo0_l0000:ooooo`;o00004Oooool2o`0006Sooooo0_l0000Pooooo`;o00002_ooool2
o`0000Sooooo0_l0001eooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000
okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo00oooooo0_l0000:ooooo`;o0000WOoo
ool2o`0000[ooooo0_l0000dooooo`;o00005oooool2o`00033ooooo0003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0
L_ooool2o`0007;ooooo0_l0000Dooooo`;o00004Oooool2o`0000Cooooo0_l0000`ooooo`007_oo
ool00ol0003oooooooooo`1booooo`;o00008oooool2o`0003;ooooo0_l0000Iooooo`;o00009ooo
ool2o`0003Kooooo000Nooooo`03o`000?oooooooooo06kooooo0_l0000Hooooo`;o00003Oooool2
o`0002oooooo0_l000000ooooooo0000o`00000`ooooo`;o0000B?ooool001kooooo00?o0000oooo
ooooool0K_ooool2o`0001Sooooo0_l0000nooooo`;o0000<oooool2o`0004Sooooo000Nooooo`03
o`000?oooooooooo07Wooooo0_l0000Kooooo`;o0000[oooool001kooooo00?o0000ooooooooool0
L?ooool2o`0000Oooooo0_l0000Kooooo`;o0000?_ooool2o`0000oooooo0_l0001Nooooo`007_oo
ool00ol0003oooooooooo`1`ooooo`;o00003?ooool2o`0005Kooooo0_l0000?ooooo`;o0000Booo
ool2o`00017ooooo000Nooooo`03o`000?oooooooooo04Oooooo0_l0000eooooo`;o0000<_ooool2
o`0005Wooooo0_l0000Uooooo`;o00004Oooool001kooooo00?o0000ooooooooool0Aoooool2o`00
04Oooooo0_l0000Pooooo`;o0000Boooool2o`0000cooooo0_l0000hooooo`007_ooool00ol0003o
ooooooooo`09ooooo`;o0000<?ooool2o`0005?ooooo0_l00005ooooo`;o00002?ooool2o`0000_o
oooo0_l0001?ooooo`;o0000A_ooool001kooooo00?o0000ooooooooool02Oooool2o`00033ooooo
0_l0001Fooooo`;o00000_ooool2o`0000Sooooo0_l0000;ooooo`;o00009?ooool2o`00077ooooo
000Nooooo`03o`000?oooooooooo09?ooooo0_l0000oooooo`;o0000?oooool2o`00033ooooo000N
ooooo`;o0000=?ooool2o`0000;ooooo0_l0003Dooooo`;o00001_ooool2o`00033ooooo000Noooo
o`03o`000?oooooooooo03?ooooo0_l00002ooooo`;o0000=oooool2o`0002;ooooo0_l0001goooo
o`;o0000>?ooool001kooooo00?o0000ooooooooool0=Oooool2o`0003Wooooo0_l0000Rooooo`;o
0000Woooool2o`00013ooooo000Nooooo`03o`000?oooooooooo00oooooo0_l00008ooooo`;o0000
2Oooool2o`0000oooooo0_l0003Uooooo`;o00001_ooool2o`0000oooooo0_l0000@ooooo`007_oo
ool00ol0003oooooooooo`07ooooo`;o00001_ooool2o`0000Sooooo0_l00009ooooo`;o0000m_oo
ool2o`0000Kooooo0_l0000Iooooo`;o00001_ooool001kooooo00?o0000ooooooooool01oooool2
o`0007?ooooo0_l0000:ooooo`;o0000]Oooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo
01?ooooo0_l0001Wooooo`;o00002_ooool2o`0002gooooo0_l0000oooooo`;o00004?ooool2o`00
03_ooooo000Nooooo`03o`000?oooooooooo01?ooooo0_l0000Fooooo`;o0000R_ooool2o`0003Ko
oooo0_l00007ooooo`;o00004?ooool2o`0003_ooooo000Nooooo`03o`000?oooooooooo02_ooooo
0_l0002:ooooo`;o00005oooool2o`0001gooooo0_l0000Gooooo`;o0000?Oooool001kooooo00?o
0000ooooooooool01oooool2o`0003oooooo0_l00026ooooo`;o0000=_ooool2o`0002[ooooo0_l0
000Aooooo`007_ooool01?l0003oooooo`000?l00006ooooo`;o00005_ooool2o`0002Oooooo0_l0
0003ooooo`;o00009oooool2o`0003[ooooo0_l0000Mooooo`;o0000HOooool2o`00017ooooo000N
ooooo`04o`000?oooooo0000o`0000Oooooo0_l0000Eooooo`;o00000oooool2o`0002Oooooo0_l0
000Wooooo`?o0000>Oooool2o`0001gooooo0_l0001dooooo`007_ooool00ol0003oooooooooo`08
ooooo`;o00006_ooool2o`0000Kooooo0_l0000Aooooo`;o0000=_ooool2o`0002Wooooo0_l0000>
ooooo`;o0000AOooool2o`0004?ooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`03oooo
o`;o00009oooool2o`00017ooooo0_l0001Qooooo`;o00003_ooool2o`0003Gooooo0_l0000>oooo
o`;o00001?ooool2o`0002Sooooo0_l0000Cooooo`;o00001oooool001kooooo00?o0000oooooooo
ool00oooool3o`0009?ooooo0_l0000Yooooo`;o00008oooool2o`0001Cooooo0_l0000Xooooo`;o
00007?ooool001kooooo0ol00004ooooo`;o00002oooool2o`0001gooooo0_l0001Wooooo`;o0000
:Oooool2o`00087ooooo000Nooooo`?o00004Oooool2o`0001gooooo0_l00009ooooo`;o0000C_oo
ool2o`0004Wooooo0_l0001_ooooo`007_ooool3o`0001;ooooo0_l000000ooooooo0000o`00000T
ooooo`;o0000=Oooool4o`0001Gooooo0_l00019ooooo`;o0000;Oooool2o`00043ooooo000Noooo
o`?o00004_ooool2o`000003ooooool0003o000003Wooooo0_l0000Pooooo`Co0000I_ooool2o`00
01?ooooo0_l0000Booooo`;o00001oooool2o`0003Oooooo000Nooooo`03o`000?oooooooooo01?o
oooo0_l0000kooooo`;o0000:oooool2o`0001kooooo0_l0000mooooo`;o00004oooool2o`0001_o
oooo0_l0000Booooo`;o00008oooool001kooooo00?o0000ooooooooool04oooool2o`0003[ooooo
0_l0000/ooooo`;o00007_ooool2o`0008?ooooo0_l0000Sooooo`007_ooool00ol0003ooooooooo
o`1?ooooo`;o0000`Oooool2o`0003?ooooo000Nooooo`03o`000?oooooooooo087ooooo0_l0002?
ooooo`;o0000<oooool001kooooo00?o0000ooooooooool0POooool2o`0002Gooooo0ol0002Loooo
o`007_ooool00ol0003oooooooooo`06ooooo`;o0000>Oooool2o`0004?ooooo0_l0000Pooooo`?o
0000W?ooool001kooooo00?o0000ooooooooool01_ooool2o`0001Wooooo0_l0000<ooooo`;o0000
4?ooool2o`0002Wooooo0_l0000Hooooo`;o0000;?ooool2o`0005[ooooo0_l0000eooooo`007_oo
ool00ol0003oooooooooo`0Qooooo`;o000000?oooooo`000?l000002Oooool2o`0002_ooooo1?l0
000<ooooo`;o00006_ooool2o`0002[ooooo0_l00016ooooo`?o00004Oooool2o`0003Gooooo000N
ooooo`03o`000?oooooooooo017ooooo0_l0000Aooooo`;o0000=_ooool4o`0002Sooooo0_l0001b
ooooo`?o0000B?ooool001kooooo0ol0000Aooooo`;o0000@Oooool2o`0000Oooooo0_l0000aoooo
o`;o0000]Oooool001kooooo0ol0000:ooooo`;o0000B?ooool2o`00023ooooo0_l0000Hooooo`;o
00003?ooool2o`0003Cooooo0_l0000aooooo`;o00008Oooool2o`0001_ooooo000Nooooo`03o`00
0?oooooooooo00[ooooo0_l0001Zooooo`;o00009_ooool2o`0003Cooooo0_l0000aooooo`;o0000
8Oooool2o`0001_ooooo000Nooooo`03o`000?oooooooooo09Kooooo0_l0000looooo`;o0000LOoo
ool001kooooo0_l0001Gooooo`;o00003Oooool2o`0002oooooo0_l0000^ooooo`;o00003?ooool2
o`0001?ooooo0_l0001Looooo`007_ooool00ol0003oooooooooo`0Cooooo`;o0000@Oooool2o`00
00gooooo0_l00009ooooo`;o0000COooool2o`0000Gooooo0_l0000Qooooo`;o00006Oooool2o`00
00cooooo0_l00008ooooo`;o0000:Oooool001kooooo00?o0000ooooooooool04oooool2o`0005_o
oooo0_l0000;ooooo`;o0000@?ooool2o`0004?ooooo0_l0000<ooooo`;o00002?ooool2o`0002Wo
oooo000Nooooo`03o`000?oooooooooo07gooooo0_l00027ooooo`;o0000?oooool001kooooo00?o
0000ooooooooool0;oooool2o`00073ooooo0_l0001Sooooo`;o00001?ooool2o`0000;ooooo0_l0
000Hooooo`;o00006oooool001kooooo00?o0000ooooooooool0;oooool2o`00073ooooo0_l00006
ooooo`;o0000>_ooool2o`0002Gooooo0_l00002ooooo`;o00006?ooool2o`0001_ooooo000Noooo
o`03o`000?oooooooooo01;ooooo0_l00002ooooo`;o0000NOooool2o`0000?ooooo0_l0000Aoooo
o`;o0000>_ooool2o`00063ooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l00002ooooo`;o
0000Joooool2o`0000cooooo0_l00003ooooo`;o00000_ooool2o`00043ooooo0_l0000Xooooo`;o
0000?oooool001kooooo0_l0000Gooooo`;o0000:oooool2o`0003kooooo0_l00009ooooo`;o0000
2_ooool2o`00043ooooo0_l0000Xooooo`;o0000?oooool001kooooo0_l00014ooooo`;o0000?ooo
ool2o`0000Sooooo0_l0001jooooo`;o0000>oooool001kooooo00?o0000ooooooooool0E?ooool2
o`0002kooooo0_l0000Dooooo`;o00006Oooool2o`0005?ooooo0_l0000Cooooo`;o00009_ooool0
01kooooo00?o0000ooooooooool0E?ooool2o`0000gooooo0_l0000booooo`;o000000?oooooo`00
0?l000006Oooool2o`0006Sooooo0_l0000Vooooo`007_ooool00ol0003oooooooooo`04ooooo`;o
0000GOooool2o`0003;ooooo0_l0000nooooo`;o0000K_ooool001kooooo00?o0000ooooooooool0
1?ooool2o`000;Oooooo0_l0000Hooooo`;o0000=?ooool2o`0001Gooooo0_l0000Qooooo`000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0
1?ooool00ol0003oooooooooo`1Aooooo`;o0000J_ooool2o`0004kooooo0_l0000Eooooo`;o0000
8Oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo01Oooooo0_l0000hooooo`;o0000m?ooool000?ooooo00Go
410@oooooooooooooooooa0@400;ooooo`Go00001_ooool3o`0001Oooooo0_l00007ooooo`;o0000
T_ooool2o`00097ooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgM
ooooool00007ooooo`03o`000?oooooooooo00Kooooo0_l0000Hooooo`;o0000>Oooool2o`0002Wo
oooo0_l00002ooooo`;o0000:?ooool2o`0001?ooooo0_l0001:ooooo`Co00009Oooool2o`0000Oo
oooo0003ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007oooo
o`03o`000?oooooooooo00Kooooo0_l0000Sooooo`;o0000;_ooool2o`0002Wooooo0_l00002oooo
o`;o0000?Oooool2o`0004[ooooo1?l0000Uooooo`;o00001oooool000?ooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool00_l0000Yoooo
o`;o0000I?ooool2o`0008?ooooo0_l0000_ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`02o`0001Oooooo0_l0000moooo
o`;o00004?ooool2o`0002Gooooo0_l0001Aooooo`;o00008Oooool2o`0003kooooo0003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo
01Gooooo0_l00002ooooo`;o0000?Oooool2o`00013ooooo0_l0000Hooooo`;o0000G_ooool2o`00
0003ooooool0003o000001kooooo0_l0000booooo`;o00002_ooool001kooooo00?o0000oooooooo
ool05Oooool2o`0006gooooo0_l0000=ooooo`;o0000D?ooool4o`0003gooooo0_l0000Cooooo`;o
00002_ooool001kooooo00?o0000ooooooooool0:Oooool2o`0004Wooooo0_l0000Mooooo`;o0000
2_ooool2o`0004Cooooo0_l0000oooooo`;o00007oooool001kooooo00?o0000ooooooooool06?oo
ool2o`000003ooooool0003o000000cooooo0_l00019ooooo`;o0000:Oooool2o`0001?ooooo0_l0
000`ooooo`;o0000@?ooool2o`0001gooooo000Nooooo`03o`000?oooooooooo01Sooooo0_l00000
0ooooooo0000o`00001Kooooo`;o00009?ooool2o`0001Cooooo0_l0000`ooooo`;o0000@?ooool2
o`0001gooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l00005ooooo`;o0000I?ooool2o`00
02Cooooo0_l0001Rooooo`;o0000@oooool001kooooo00?o0000ooooooooool00_ooool2o`0000Co
oooo0_l000000ooooooo0000o`000005ooooo`;o0000VOooool2o`0002[ooooo0_l0000Fooooo`;o
00002oooool2o`0000;ooooo0_l00013ooooo`007_ooool00ol0003oooooooooo`02ooooo`;o0000
1?ooool2o`0001;ooooo0_l0000/ooooo`;o0000HOooool2o`0002[ooooo0_l0000Fooooo`;o0000
2oooool2o`0004Oooooo000Nooooo`03o`000?oooooooooo01cooooo0_l0000/ooooo`;o0000C_oo
ool2o`0003[ooooo0_l00004ooooo`;o0000D_ooool2o`0001Gooooo000Nooooo`;o0000OOooool2
o`0000Oooooo0_l0000Cooooo`;o0000>_ooool2o`0000Cooooo0_l0000Vooooo`Co00004Oooool2
o`0001Gooooo1?l0000Cooooo`007_ooool2o`0002Sooooo0_l0000Eooooo`;o0000>?ooool2o`00
00;ooooo0_l00007ooooo`;o0000OOooool4o`00017ooooo0_l0000Gooooo`;o00004oooool001ko
oooo00?o0000ooooooooool09oooool2o`0001Gooooo0_l0000Gooooo`;o00007oooool2o`000<Co
oooo0_l00007ooooo`007_ooool3o`0003Oooooo0_l0000Nooooo`;o0000:_ooool2o`0005;ooooo
0_l0000Nooooo`;o00001?ooool2o`0002kooooo0_l0000?ooooo`;o00001oooool001kooooo0ol0
000booooo`;o00000oooool2o`0003cooooo0_l0000<ooooo`;o0000D_ooool2o`0000_ooooo0_l0
000Aooooo`;o00001?ooool2o`0000;ooooo0_l0000Booooo`;o00005_ooool2o`0001Sooooo000N
ooooo`03o`000?oooooooooo02oooooo0_l000000ooooooo0000o`000003ooooo`;o00005_ooool2
o`0002Cooooo0_l0000Oooooo`;o00006oooool2o`0000Wooooo0_l0000Tooooo`;o00006oooool2
o`0000[ooooo0_l00006ooooo`;o0000<?ooool001kooooo00?o0000ooooooooool0;oooool2o`00
01kooooo0_l00015ooooo`;o00006oooool2o`0000Kooooo0_l000000ooooooo0000o`00000>oooo
o`;o0000;Oooool2o`0000kooooo0_l0000Uooooo`;o00004Oooool001kooooo00?o0000oooooooo
ool0E?ooool2o`00023ooooo0_l0000^ooooo`;o00004oooool2o`00017ooooo0_l0000/ooooo`?o
0000=Oooool2o`0000Wooooo0_l00006ooooo`007_ooool00ol0003oooooooooo`05ooooo`;o0000
COooool2o`0000_ooooo0_l0000Booooo`?o0000;_ooool2o`0005Cooooo0_l00011ooooo`;o0000
1_ooool001kooooo00?o0000ooooooooool01Oooool2o`0003_ooooo0_l0000Mooooo`;o00004_oo
ool2o`0001Kooooo0_l0001Vooooo`;o0000A?ooool2o`0000[ooooo000Nooooo`03o`000?oooooo
oooo00Wooooo0_l0000gooooo`;o0000BOooool2o`0002Sooooo0_l0000looooo`;o00003?ooool2
o`0003Kooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`09ooooo`;o0000<_ooool2o`00
01kooooo0_l0001Hooooo`;o0000B_ooool3o`0003[ooooo0_l00005ooooo`007_ooool00ol0003o
ooooooooo`0mooooo`;o00007_ooool2o`0006Oooooo0_l0000looooo`;o0000>_ooool2o`0000Go
oooo000Nooooo`?o0000?Oooool2o`0000Gooooo0_l00010ooooo`;o0000>_ooool2o`0000;ooooo
0_l0000Looooo`;o0000HOooool001kooooo0ol0000mooooo`;o00001Oooool2o`00013ooooo0_l0
000^ooooo`;o0000>_ooool2o`00023ooooo0_l00005ooooo`;o0000F_ooool001kooooo00?o0000
ooooooooool0E_ooool2o`0009?ooooo0_l0001Jooooo`007_ooool00ol0003oooooooooo`0ooooo
o`;o00003oooool2o`00013ooooo0_l0000Eooooo`;o0000=oooool2o`0004Gooooo0_l0000Eoooo
o`;o0000=Oooool001kooooo00?o0000ooooooooool01_ooool2o`0001Wooooo0_l0000Looooo`;o
00003oooool2o`00013ooooo0_l0000Eooooo`;o00005_ooool2o`0001;ooooo0_l0000;ooooo`;o
0000AOooool2o`0001Gooooo0_l0000eooooo`007_ooool00ol0003oooooooooo`06ooooo`;o0000
6Oooool2o`00037ooooo0_l0000kooooo`;o00004_ooool2o`000:3ooooo000Nooooo`;o0000EOoo
ool2o`0006Cooooo0_l00023ooooo`;o00001_ooool001kooooo00?o0000ooooooooool0^_ooool2
o`0008?ooooo0_l00006ooooo`007_ooool00ol0003oooooooooo`09ooooo`;o0000Q_ooool2o`00
02?ooooo0_l0000Fooooo`;o0000H_ooool2o`0001?ooooo000Nooooo`03o`000?oooooooooo00Wo
oooo0_l0000`ooooo`;o0000E?ooool2o`0000;ooooo0_l0000Oooooo`;o00005_ooool2o`0006;o
oooo0_l0000Cooooo`007_ooool00ol0003oooooooooo`09ooooo`;o00008Oooool2o`0000gooooo
0_l0000mooooo`;o00006Oooool2o`0009Sooooo0_l00008ooooo`;o00001?ooool2o`0000Kooooo
000Nooooo`03o`000?oooooooooo00Wooooo0_l0000Qooooo`;o00001Oooool2o`0004Gooooo0_l0
0006ooooo`;o0000?Oooool2o`0006cooooo0_l00008ooooo`;o00001?ooool2o`0000Kooooo000N
ooooo`03o`000?oooooooooo00Wooooo0_l0000Xooooo`;o0000COooool2o`0003gooooo0_l0000C
ooooo`;o0000Koooool001kooooo00?o0000ooooooooool02Oooool2o`000:Gooooo0_l0000Toooo
o`;o0000Koooool001kooooo00?o0000ooooooooool0E?ooool2o`0005[ooooo0_l0000hooooo`;o
0000Foooool001kooooo00?o0000ooooooooool0E?ooool2o`0009Cooooo0_l0001<ooooo`;o0000
3Oooool001kooooo00Co0000oooooooooooooooo0_l00033ooooo`;o0000L?ooool2o`0000gooooo
000Nooooo`04o`000?ooooooooooooooo`;o0000`oooool2o`00043ooooo0_l0000mooooo`007_oo
ool00ol0003oooooooooo`0Xooooo`;o0000Boooool2o`0000Wooooo0_l0001:ooooo`;o0000>_oo
ool2o`0003gooooo000Nooooo`03o`000?oooooooooo02Sooooo0_l00016ooooo`;o00000oooool2
o`0000Gooooo0_l00002ooooo`;o0000B_ooool2o`0007Wooooo000Nooooo`03o`000?oooooooooo
00Cooooo0_l0001Zooooo`;o00002_ooool4o`0008Wooooo0_l0000Cooooo`;o00009oooool001ko
oooo00?o0000ooooooooool01?ooool2o`0001gooooo0_l0001Iooooo`;o0000N?ooool2o`0000oo
oooo0_l0000Cooooo`;o00009oooool001kooooo0_l00006ooooo`;o00007?ooool2o`00063ooooo
0_l0000Dooooo`;o0000Foooool2o`0002_ooooo0_l0000Fooooo`;o00002?ooool001gooooo0_l0
0007ooooo`;o00009?ooool2o`0005Sooooo0_l0000Dooooo`;o0000R?ooool2o`0001Kooooo0_l0
0008ooooo`007Oooool2o`0000gooooo0_l0000@ooooo`;o00003?ooool2o`000?oooooo2oooool2
o`0000kooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l00005ooooo`;o00004?ooool2o`00
057ooooo0_l0000Pooooo`;o00000_ooool2o`0001?ooooo0_l0002:ooooo`;o00003_ooool001ko
oooo00?o0000ooooooooool01?ooool2o`0000oooooo0_l0001Iooooo`;o00002_ooool2o`0001Co
oooo0_l00002ooooo`;o000000?oooooo`000?l000004?ooool2o`0003kooooo0_l0001?ooooo`;o
00002Oooool001kooooo00?o0000ooooooooool01?ooool2o`0000oooooo0_l0000Vooooo`;o0000
5Oooool2o`00023ooooo0_l00004ooooo`;o00006oooool2o`0000?ooooo0_l0001;ooooo`;o0000
Coooool2o`0000Wooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0000Hooooo`;o00007Ooo
ool2o`0001Gooooo0_l0000Pooooo`;o00009_ooool2o`000:Oooooo000Nooooo`03o`000?oooooo
oooo01kooooo0_l0003oooooobSooooo000Nooooo`03o`000?oooooooooo037ooooo0_l0002Noooo
o`;o0000M?ooool001kooooo00?o0000ooooooooool0<Oooool3o`00093ooooo0_l0000;ooooo`;o
0000M?ooool001kooooo00?o0000ooooooooool05oooool2o`0001Wooooo0_l0000`ooooo`;o0000
G_ooool2o`00087ooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0000?ooooo`;o0000>_oo
ool2o`0009?ooooo0_l0001<ooooo`007_ooool00ol0003oooooooooo`0Xooooo`;o0000coooool2
o`0004cooooo000Nooooo`03o`000?oooooooooo0;3ooooo0_l0000Sooooo`;o0000L?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413o
c<c<00Kooooo00?o0000ooooooooool0<_ooool2o`0007cooooo0_l0000Booooo`;o00003oooool2
o`0005[ooooo0_l0000Dooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0booooo`;o00002_oo
ool2o`0000[ooooo0_l0000Booooo`;o0000<oooool2o`0001Gooooo1?l0000Fooooo`;o0000F?oo
ool2o`00017ooooo0_l00009ooooo`;o00002Oooool000?ooooo00Go410@oooooooooooooooooa0@
400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`0003kooooo0_l0000:ooooo`;o0000
4_ooool2o`0003?ooooo0_l0000Eooooo`Co0000<?ooool2o`0001Kooooo0_l0000Jooooo`;o0000
2_ooool2o`0001[ooooo1?l00009ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo
00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo037ooooo0_l0002:ooooo`;o
00003Oooool2o`00013ooooo0_l0000Fooooo`;o00006_ooool2o`0002Kooooo0_l0000;ooooo`00
0oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c006oooo
o`03o`000?oooooooooo01oooooo0_l0000@ooooo`;o0000R_ooool2o`0000gooooo0_l0000Boooo
o`;o0000IOooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo
00Sooooo00?o0000ooooooooool07oooool2o`00023ooooo0_l0002Mooooo`;o00004Oooool2o`00
05;ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008oooo
o`03o`000?oooooooooo047ooooo0_l0000_ooooo`;o00004_ooool2o`0003_ooooo0_l0000^oooo
o`;o0000?oooool2o`00017ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<
c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo02Kooooo0_l0001:ooooo`;o00004_ooool2
o`0003_ooooo0_l0000iooooo`;o00008?ooool2o`0001;ooooo0_l0000Aooooo`007_ooool00ol0
003oooooooooo`0Nooooo`;o00001_ooool2o`0008[ooooo0_l0000>ooooo`;o0000>_ooool2o`00
00_ooooo0_l0000Cooooo`;o00007?ooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo01Ko
oooo0_l00006ooooo`;o00007?ooool2o`0006kooooo0_l00004ooooo`;o00003_ooool2o`0000[o
oooo0_l0000@ooooo`;o0000:Oooool2o`00037ooooo0_l00007ooooo`007_ooool00ol0003ooooo
ooooo`0Fooooo`;o00009?ooool2o`0002[ooooo0_l0000oooooo`;o000000?oooooo`000?l00000
5Oooool2o`0000Wooooo0_l0000@ooooo`;o00001_ooool2o`0005Kooooo0_l00005ooooo`007_oo
ool00ol0003oooooooooo`1Xooooo`;o0000<Oooool2o`0000cooooo0_l0000Hooooo`;o00008ooo
ool2o`0005Kooooo0_l00005ooooo`007_ooool00ol0003oooooooooo`2Kooooo`;o00006_ooool2
o`0000gooooo0_l0001oooooo`007_ooool00ol0003oooooooooo`2gooooo`;o00003Oooool2o`00
02kooooo0_l0001?ooooo`007_ooool00ol0003oooooooooo`1Xooooo`;o0000S?ooool2o`0004oo
oooo000Nooooo`03o`000?oooooooooo05Sooooo0_l0000>ooooo`;o0000gOooool001kooooo00?o
0000ooooooooool0F?ooool2o`000:Cooooo0_l0000Kooooo`;o0000:_ooool001kooooo00?o0000
ooooooooool01?ooool2o`0004oooooo0_l0002:ooooo`;o00006oooool2o`0001_ooooo0_l0000Z
ooooo`007_ooool00ol0003oooooooooo`04ooooo`;o000000?oooooo`000?l00000C?ooool2o`00
08[ooooo0_l0000^ooooo`;o00006_ooool2o`0001Sooooo000Nooooo`;o00002?ooool2o`0000ko
oooo0_l0002mooooo`;o0000>Oooool2o`0001[ooooo0_l0000;ooooo`;o00002oooool001kooooo
00?o0000ooooooooool05oooool2o`0004?ooooo0_l0001hooooo`;o0000H_ooool2o`0000_ooooo
000Nooooo`03o`000?oooooooooo05cooooo0_l0000Jooooo`;o0000<Oooool2o`0004;ooooo0ol0
001;ooooo`;o00002?ooool001kooooo00?o0000ooooooooool0N?ooool2o`00037ooooo0_l0000l
ooooo`;o00001?ooool3o`0004_ooooo0_l00008ooooo`007_ooool00ol0003oooooooooo`0Moooo
o`;o0000?_ooool4o`0000Wooooo0_l0001mooooo`;o0000G?ooool001kooooo00?o0000oooooooo
ool07Oooool2o`00023ooooo0_l0000Looooo`Co00002Oooool2o`0008[ooooo0_l0001?ooooo`00
7_ooool00ol0003oooooooooo`0oooooo`;o0000S?ooool2o`0002Oooooo0_l0000Zooooo`;o0000
8oooool001kooooo00?o0000ooooooooool03?ooool2o`0002cooooo0_l0001?ooooo`;o0000@?oo
ool2o`0003cooooo0_l0000Eooooo`;o00008oooool001kooooo00?o0000ooooooooool03?ooool2
o`0002cooooo0_l0000Gooooo`;o00007Oooool2o`0001Oooooo0_l0001`ooooo`;o00003?ooool2
o`0001Kooooo0_l0000Rooooo`007_ooool00ol0003oooooooooo`03ooooo`;o0000C_ooool2o`00
01gooooo0_l0000Vooooo`;o000000?oooooo`000?l00000G_ooool2o`0002Cooooo0_l0000Roooo
o`007_ooool00ol0003oooooooooo`03ooooo`;o0000K_ooool2o`0000Wooooo0_l00009ooooo`;o
00003oooool2o`000003ooooool0003o000001cooooo0_l0000mooooo`;o0000Boooool001kooooo
00?o0000ooooooooool0Joooool2o`0000Kooooo0_l00009ooooo`;o00002Oooool2o`0002;ooooo
0_l0000<ooooo`;o0000?Oooool2o`0004_ooooo000Nooooo`03o`000?oooooooooo04Sooooo0_l0
000Qooooo`;o00005_ooool2o`0002Sooooo0_l0002Hooooo`007_ooool00ol0003oooooooooo`18
ooooo`;o00001?ooool2o`0003?ooooo0_l0000Iooooo`;o0000Ioooool2o`0001cooooo0_l00000
0ooooooo0000o`00000Mooooo`007_ooool00ol0003oooooooooo`1>ooooo`;o0000C_ooool2o`00
03kooooo0_l00004ooooo`;o00008Oooool2o`0001cooooo0_l000000ooooooo0000o`00000Moooo
o`007_ooool00ol0003oooooooooo`2;ooooo`;o0000:_ooool2o`0002Gooooo0_l00004ooooo`;o
00005_ooool2o`0004Wooooo000Nooooo`;o0000S?ooool4o`0002Sooooo0_l00013ooooo`;o0000
:?ooool2o`0001oooooo000Nooooo`03o`000?oooooooooo08gooooo0_l0001]ooooo`;o00005?oo
ool2o`0001;ooooo0_l0000Oooooo`007_ooool00ol0003oooooooooo`0Kooooo`;o0000:?ooool2
o`000;Gooooo0_l0000Dooooo`;o0000<oooool001kooooo00?o0000ooooooooool06oooool2o`00
02Sooooo0_l0001_ooooo`;o00004_ooool2o`0007_ooooo000Nooooo`03o`000?oooooooooo033o
oooo0_l00018ooooo`;o0000>_ooool2o`0001;ooooo0_l0000;ooooo`;o00001?ooool2o`0006So
oooo000Nooooo`03o`000?oooooooooo033ooooo0_l00018ooooo`;o0000@_ooool2o`0000?ooooo
0_l0000Booooo`;o00001?ooool2o`0006Sooooo000Nooooo`03o`000?oooooooooo0;kooooo0_l0
0003ooooo`;o0000C?ooool2o`0000Wooooo0_l0000Yooooo`007_ooool00ol0003oooooooooo`3o
oooooa;ooooo0_l00009ooooo`;o0000:Oooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`05ooooo`;o00007oooool2o`0008Kooooo0_l0000Eooooo`;o
0000P?ooool001kooooo00?o0000ooooooooool01Oooool2o`0001oooooo0_l00026ooooo`;o0000
2_ooool2o`0000Wooooo0_l0000Uooooo`;o0000>_ooool2o`0001gooooo000Nooooo`03o`000?oo
oooooooo04[ooooo0_l0001Eooooo`;o00005oooool2o`0000Kooooo0_l0000Xooooo`;o0000>_oo
ool2o`0000Wooooo0_l0000Booooo`007_ooool00ol0003oooooooooo`1:ooooo`;o0000;_ooool2
o`0002Gooooo0_l0000Oooooo`;o0000KOooool4o`0001;ooooo000Nooooo`03o`000?oooooooooo
07[ooooo0_l00019ooooo`;o0000J_ooool2o`0001Cooooo000Nooooo`03o`000?oooooooooo04;o
oooo0_l00021ooooo`;o0000P?ooool001kooooo00?o0000ooooooooool0@_ooool2o`0005;ooooo
0_l0000Wooooo`;o0000Q_ooool001kooooo0_l0002Gooooo`;o00009oooool2o`0008Kooooo000N
ooooo`03o`000?oooooooooo00kooooo0_l0002_ooooo`;o0000Q_ooool001kooooo00?o0000oooo
ooooool03_ooool2o`0001?ooooo0_l0003Booooo`;o0000=?ooool2o`0001Sooooo000Nooooo`03
o`000?oooooooooo02?ooooo0_l00027ooooo`;o0000BOooool2o`0000?ooooo0_l00006ooooo`;o
00009oooool2o`0001Sooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0000Oooooo`;o0000
8_ooool2o`0005_ooooo0_l00013ooooo`;o00002Oooool2o`0000Kooooo0_l00011ooooo`007_oo
ool00ol0003oooooooooo`0:ooooo`;o00007oooool2o`0002;ooooo0_l0002Pooooo`;o0000COoo
ool2o`0000Gooooo000Nooooo`03o`000?oooooooooo04;ooooo0_l0000?ooooo`;o0000joooool2
o`0000Gooooo000Nooooo`03o`000?oooooooooo00kooooo0_l0000booooo`;o00003oooool2o`00
01?ooooo0_l0001Zooooo`;o00001?ooool2o`0006_ooooo000Nooooo`03o`000?oooooooooo00ko
oooo0_l0001Hooooo`;o0000J_ooool2o`0000Cooooo0_l00002ooooo`;o0000Aoooool2o`0001Ko
oooo0_l00006ooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o00004_ooool2o`000;cooooo
0_l00017ooooo`;o00005_ooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0
0007ooooo`;o00004_ooool2o`000?oooooo9_ooool001kooooo00?o0000ooooooooool00oooool2
o`000=cooooo0_l0001Tooooo`007_ooool00ol0003oooooooooo`07ooooo`;o0000f?ooool2o`00
06Cooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l000000ooooooo0000o`00002Uooooo`;o
0000U?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co
8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool02_ooool2o`000:Gooooo0_l00011oooo
o`;o0000@?ooool2o`0000oooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo01[ooooo0_l0000_
ooooo`;o0000@_ooool2o`0004;ooooo0_l0000Oooooo`;o00006oooool2o`00013ooooo0_l0000A
ooooo`;o00003oooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooo
ooooooooool000001_ooool3o`0001[ooooo0_l0000_ooooo`;o0000@_ooool2o`0004;ooooo0_l0
0008ooooo`?o00008_ooool2o`0000gooooo0_l0000@ooooo`;o00001oooool2o`0001Wooooo0003
ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo
00?o0000ooooooooool0J_ooool2o`0001Oooooo0_l0001Hooooo`?o00008_ooool3o`0002Oooooo
0_l0000Iooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o
0000olc<c006ooooo`03o`000?oooooooooo03;ooooo0_l0000fooooo`;o000000?oooooo`000?l0
00005?ooool2o`0007kooooo0_l0000booooo`;o00003_ooool000?ooooo00Go410@oooooooooooo
oooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`0boooo
o`;o0000>Oooool2o`0003Kooooo0_l0000?ooooo`;o0000?Oooool2o`0000[ooooo0_l0000doooo
o`;o00003_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooo
okZj^_l000001_ooool00ol0003oooooooooo`2Pooooo`;o00000oooool2o`0000oooooo0_l0000D
ooooo`;o00009oooool2o`0000[ooooo1?l00012ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo00[ooooo0_l0
0002ooooo`;o0000@?ooool2o`0002gooooo0_l0000Oooooo`;o0000:_ooool2o`0001oooooo0_l0
0005ooooo`;o00003Oooool2o`0001?ooooo0_l0000]ooooo`007_ooool00ol0003oooooooooo`0:
ooooo`;o00000_ooool2o`0002kooooo0_l0000@ooooo`;o0000;Oooool2o`0000Oooooo0_l0001S
ooooo`;o00001Oooool2o`0002;ooooo0_l0000]ooooo`007_ooool00ol0003oooooooooo`0noooo
o`;o00004_ooool2o`0003Cooooo0_l0000Mooooo`;o0000W_ooool001kooooo00?o0000oooooooo
ool0D_ooool2o`0001Wooooo0_l0000hooooo`;o0000I_ooool2o`0003Kooooo000Nooooo`03o`00
0?oooooooooo00;o0000Joooool2o`0005cooooo0_l0000Sooooo`;o00002?ooool2o`0000oooooo
0_l00002ooooo`;o0000=_ooool001kooooo00?o0000ooooooooool00_l0001hooooo`;o0000C?oo
ool2o`000003ooooool0003o000000?ooooo0_l0000Dooooo`;o00002?ooool2o`0000Sooooo0_l0
000=ooooo`Co00009Oooool2o`0001?ooooo000Nooooo`03o`000?oooooooooo07[ooooo0_l0001<
ooooo`;o00001_ooool2o`0001Cooooo0_l0000Qooooo`;o00009oooool2o`0001?ooooo000Noooo
o`03o`000?oooooooooo09gooooo0_l00003ooooo`;o0000Xoooool001kooooo00?o0000oooooooo
ool0WOooool2o`0000?ooooo0_l0002Sooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o0000
7Oooool2o`0004;ooooo0_l0000hooooo`;o00002oooool2o`0008Kooooo000Nooooo`03o`000?oo
oooooooo01Gooooo0_l0000Mooooo`;o0000@_ooool2o`0000;ooooo0_l0000dooooo`;o00002ooo
ool2o`0008Kooooo000Nooooo`03o`000?oooooooooo00cooooo0_l0001^ooooo`;o0000U?ooool2
o`0003?ooooo000Nooooo`;o00003Oooool2o`0003oooooo0_l0000Pooooo`;o00001_ooool2o`00
09Wooooo0_l0000[ooooo`;o00001_ooool001kooooo00?o0000ooooooooool0@oooool2o`0000So
oooo0_l0000Eooooo`;o00002Oooool2o`0000Kooooo0_l0000fooooo`;o00007oooool2o`0005Co
oooo0_l0000Gooooo`;o00001_ooool001kooooo00?o0000ooooooooool0@oooool2o`0001oooooo
0_l0000Sooooo`;o00009?ooool2o`0001oooooo0_l0000Wooooo`;o0000:oooool2o`0001oooooo
000Nooooo`03o`000?oooooooooo08Wooooo0_l0000Hooooo`;o0000E?ooool2o`0004cooooo000N
ooooo`03o`000?oooooooooo013ooooo0_l0002Aooooo`Co00001_ooool2o`0005Gooooo0_l00011
ooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o0000OOooool2o`0001Cooooo0_l00006oooo
o`;o00002Oooool2o`00027ooooo0_l0000:ooooo`;o00006oooool2o`0002?ooooo0_l0000Loooo
o`007_ooool00ol0003oooooooooo`1kooooo`;o00003oooool2o`000003ooooool0003o000002Oo
oooo0_l0000Qooooo`;o00002_ooool2o`00043ooooo0_l0000Looooo`007_ooool00ol0003ooooo
ooooo`1kooooo`;o00003oooool2o`0003Gooooo0_l0000jooooo`;o0000A_ooool001kooooo00?o
0000ooooooooool0E?ooool2o`0004_ooooo0_l0000Pooooo`;o00002_ooool2o`00013ooooo0_l0
000;ooooo`;o00003oooool2o`0004Kooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0000a
ooooo`;o00002oooool2o`0000;ooooo0_l0000Eooooo`;o0000<?ooool2o`0001gooooo0_l0000=
ooooo`;o00004?ooool2o`0000Gooooo0_l00004ooooo`;o0000<?ooool2o`0002Gooooo000Noooo
o`03o`000?oooooooooo00Gooooo1?l0000;ooooo`;o00009Oooool2o`0000[ooooo0_l0000?oooo
o`;o00005Oooool2o`0004oooooo0_l0000Vooooo`;o0000=_ooool2o`0000kooooo0_l0000Eoooo
o`007_ooool00ol0003oooooooooo`05ooooo`Co0000<_ooool2o`0000gooooo0_l00023ooooo`;o
0000:Oooool2o`0003Cooooo0ol0000Dooooo`007_ooool00ol0003oooooooooo`1:ooooo`;o0000
4_ooool2o`0002oooooo0_l00009ooooo`;o0000<oooool2o`0001Cooooo0_l0000Cooooo`;o0000
0oooool2o`00033ooooo0_l0000Dooooo`007_ooool00ol0003oooooooooo`1Nooooo`;o0000;ooo
ool2o`0000Wooooo0_l00019ooooo`;o00006?ooool2o`0004Kooooo000Nooooo`03o`000?oooooo
oooo00[ooooo0_l0002>ooooo`;o0000LOooool2o`0003Sooooo000Nooooo`03o`000?oooooooooo
00[ooooo0_l0002>ooooo`;o0000LOooool2o`0003Sooooo000Nooooo`;o0000C?ooool2o`0001Wo
oooo0_l0000`ooooo`;o0000[Oooool001kooooo00?o0000ooooooooool04_ooool2o`0000?ooooo
0_l0000@ooooo`;o00008?ooool2o`0001Wooooo0_l0000[ooooo`;o00000_ooool3o`000:gooooo
000Nooooo`03o`000?oooooooooo01;ooooo0_l00003ooooo`;o00004?ooool2o`0006Sooooo0_l0
0002ooooo`;o0000B?ooool2o`0000kooooo0_l0000cooooo`;o00007oooool001kooooo0_l0001^
ooooo`;o0000<?ooool2o`00043ooooo0_l0000>ooooo`;o00005oooool2o`0001[ooooo0_l0000O
ooooo`007_ooool2o`0006kooooo0_l0000`ooooo`;o0000:_ooool2o`0002cooooo0_l0000?oooo
o`;o0000>oooool001kooooo00?o0000ooooooooool0boooool2o`0002cooooo0_l0000@ooooo`;o
00009Oooool2o`0001?ooooo000Nooooo`03o`000?oooooooooo0;[ooooo0_l0000cooooo`;o0000
6_ooool2o`0002Gooooo0_l0000Cooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o00005Ooo
ool2o`0007kooooo0_l0000cooooo`;o0000E_ooool001kooooo00?o0000ooooooooool08oooool2
o`0000Sooooo0_l0000;ooooo`;o0000KOooool2o`0009cooooo000Nooooo`03o`000?oooooooooo
01Sooooo0_l0000Cooooo`;o0000N_ooool2o`0009cooooo000Nooooo`03o`000?oooooooooo01So
oooo0_l0000Aooooo`;o0000MOooool2o`0001Sooooo0_l00023ooooo`;o00001?ooool001kooooo
00?o0000ooooooooool06oooool2o`0000[ooooo0_l00002ooooo`;o0000MOooool2o`0001Sooooo
0_l00012ooooo`;o0000=Oooool2o`0000Sooooo0_l00004ooooo`007_ooool00ol0003ooooooooo
o`0Kooooo`;o00002_ooool2o`0001cooooo0_l0002iooooo`;o00008oooool2o`00013ooooo0_l0
000>ooooo`007_ooool00ol0003oooooooooo`0Kooooo`;o0000:?ooool2o`0001Wooooo0_l00033
ooooo`;o00008?ooool001kooooo00?o0000ooooooooool05Oooool2o`0000Cooooo0_l0000^oooo
o`;o00004oooool2o`0001Oooooo0_l00032ooooo`;o00002?ooool001kooooo00?o0000oooooooo
ool05Oooool2o`00033ooooo0_l00002ooooo`;o0000;?ooool2o`0003oooooo0_l0000?ooooo`;o
0000Koooool3o`0000Sooooo000Nooooo`?o00004?ooool2o`0003Gooooo0_l0001aooooo`;o0000
3oooool2o`0001oooooo0_l0001>ooooo`;o00002Oooool001kooooo0ol0000@ooooo`;o0000K_oo
ool2o`0006[ooooo0_l0001Iooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o00007?ooool2
o`0003gooooo0_l00003ooooo`;o0000T_ooool2o`0002cooooo000Nooooo`03o`000?oooooooooo
02?ooooo0_l0000Looooo`;o0000@_ooool2o`0002Wooooo0_l0000fooooo`;o0000;oooool2o`00
00[ooooo0_l0000Pooooo`007_ooool00ol0003oooooooooo`2Looooo`;o00004_ooool2o`0003Ko
oooo0_l0000kooooo`;o00004Oooool2o`0000gooooo000Nooooo`03o`000?oooooooooo06Gooooo
0_l0000eooooo`;o00004oooool2o`00023ooooo0_l0001Sooooo`;o00003Oooool001kooooo00Co
0000ooooool0003o0000I?ooool2o`00037ooooo0_l0000Gooooo`;o00006_ooool2o`0000Cooooo
0_l0001booooo`007_ooool00ol0003oooooo`000002o`00077ooooo0_l0000Sooooo`;o00008ooo
ool2o`0000kooooo0_l0001Zooooo`;o00003?ooool001kooooo00?o0000ooooooooool00_l00010
ooooo`;o0000;oooool2o`0002_ooooo0_l0000Aooooo`;o00002?ooool2o`0001;ooooo0_l0000B
ooooo`;o00001oooool2o`00023ooooo0_l0000Looooo`;o00002Oooool2o`0000cooooo000Noooo
o`03o`000?oooooooooo04;ooooo0_l0001Looooo`;o00004Oooool2o`00017ooooo0_l00009oooo
o`;o00003_ooool2o`0000;ooooo0_l00007ooooo`;o00008?ooool2o`0001Sooooo0_l00002oooo
o`;o00005oooool001kooooo00?o0000ooooooooool0`?ooool2o`0000Cooooo0_l0000Iooooo`;o
00009_ooool2o`0001oooooo0_l0000Kooooo`007_ooool00ol0003oooooooooo`2Mooooo`;o0000
8Oooool2o`0003gooooo0_l00008ooooo`;o00003_ooool2o`0002cooooo000Nooooo`03o`000?oo
oooooooo09gooooo0_l0001Gooooo`;o00001oooool2o`0001Sooooo0_l0000Eooooo`;o00005Ooo
ool001kooooo00?o0000ooooooooool0JOooool2o`0004Kooooo0_l00013ooooo`;o0000>?ooool2
o`0001Gooooo000Dooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`0=oooo
o`;o0000F_ooool2o`0000oooooo0_l0000^ooooo`;o00001Oooool2o`0004oooooo0_l00013oooo
o`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00gooooo0_l00007ooooo`;o
00002Oooool2o`0000Wooooo0_l0000Xooooo`;o00007_ooool2o`0000;ooooo0_l0000^ooooo`;o
00007?ooool2o`0001Cooooo0_l0000Rooooo`;o0000:oooool2o`0001Kooooo000Fooooo`03o`00
0?oooooooooo00Gooooo1?l0000Eooooo`;o00002Oooool2o`0000Wooooo0_l0000Xooooo`;o0000
3?ooool2o`0000Sooooo0_l00006ooooo`;o00008oooool2o`0002_ooooo0_l0000Dooooo`;o0000
1_ooool2o`0004Oooooo0_l0000Fooooo`005_ooool00ol0003oooooooooo`07ooooo`;o0000Hooo
ool2o`0000Sooooo0_l0000[ooooo`;o0000BOooool2o`0005oooooo000Fooooo`03o`000?oooooo
oooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003o
ooooooooo`3ooooooe3ooooo000Dooooo`03oeEEEOmVIVKo00000?ooooooD_ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.69284 .46405 Mdot
.24214 .39716 Mdot
.78473 .46266 Mdot
.17227 .4644 Mdot
.46995 .24738 Mdot
.55025 .46362 Mdot
.7234 .32339 Mdot
.0147 .98708 Mdot
.04922 .44239 Mdot
.93322 .92021 Mdot
.39791 .5279 Mdot
.9839 .98582 Mdot
.326 .66468 Mdot
.15537 .19745 Mdot
.91827 .6094 Mdot
.35214 .11048 Mdot
.83397 .00648 Mdot
.40193 .00942 Mdot
.79819 .06863 Mdot
.73774 .67461 Mdot
.07741 .23188 Mdot
.40785 .15775 Mdot
.07 .05077 Mdot
.78707 .55326 Mdot
.3841 .98628 Mdot
.98226 6e-05 Mdot
.04282 .02038 Mdot
.02369 .50402 Mdot
.58902 .38393 Mdot
.21835 .12602 Mdot
.45205 .00219 Mdot
.84954 .10521 Mdot
.97244 .10684 Mdot
.06396 .29299 Mdot
.29249 .42282 Mdot
.93038 .11935 Mdot
.28294 .11066 Mdot
.27788 .49131 Mdot
.82094 .43563 Mdot
.61736 .61171 Mdot
.61699 .63967 Mdot
.00207 .14169 Mdot
.55443 .31974 Mdot
.52946 .62157 Mdot
.93091 .54062 Mdot
.08 .74452 Mdot
.27789 .48371 Mdot
.80388 .94457 Mdot
.41257 .03509 Mdot
.86717 .08706 Mdot
.93493 .97186 Mdot
.60509 .86124 Mdot
.96014 .70456 Mdot
.26692 .35451 Mdot
.79144 .0242 Mdot
.11354 .35391 Mdot
.29077 .09656 Mdot
.64251 .99962 Mdot
.61216 .21797 Mdot
.48701 .4096 Mdot
.82228 .82724 Mdot
.97376 .96663 Mdot
.24128 .45708 Mdot
.68476 .48989 Mdot
.92269 .14988 Mdot
.0607 .78635 Mdot
.4532 .46645 Mdot
.33892 .03279 Mdot
.57211 .03307 Mdot
.06778 .40872 Mdot
.34668 .16293 Mdot
.97447 .37233 Mdot
.08154 .01643 Mdot
.36614 .07876 Mdot
.26267 .18912 Mdot
.05125 .9466 Mdot
.95513 .38519 Mdot
.60171 .53537 Mdot
.15403 .56143 Mdot
.86897 .09428 Mdot
.20709 .88281 Mdot
.19185 .35026 Mdot
.26736 .35905 Mdot
.58769 .3023 Mdot
.78998 .72036 Mdot
.58425 .90993 Mdot
.89668 .16221 Mdot
.89876 .32024 Mdot
.28389 .40142 Mdot
.95136 .13753 Mdot
.52943 .45302 Mdot
.44178 .41943 Mdot
.93816 .00086 Mdot
.92019 .70375 Mdot
.06361 .25492 Mdot
.71565 .01717 Mdot
.90518 .91227 Mdot
.50334 .71991 Mdot
.64316 .1353 Mdot
.91868 .75836 Mdot
.96126 .07229 Mdot
.6293 .97599 Mdot
.79895 .23189 Mdot
.54462 .93156 Mdot
.50235 .93067 Mdot
.26582 .85067 Mdot
.82164 .31807 Mdot
.20158 .22552 Mdot
.27626 .02352 Mdot
.07438 .12883 Mdot
.24554 .52465 Mdot
.78264 .97831 Mdot
.65802 .82138 Mdot
.52965 .37043 Mdot
.50981 .94382 Mdot
.36086 .84091 Mdot
.6356 .62123 Mdot
.70326 .60452 Mdot
.42639 .96527 Mdot
.11488 .79557 Mdot
.5635 .52497 Mdot
.44171 .00468 Mdot
.91854 .59045 Mdot
.30154 .64446 Mdot
.62775 .14248 Mdot
.15542 .90536 Mdot
.79945 .6262 Mdot
.4363 .42318 Mdot
.53921 .63385 Mdot
.08319 .4445 Mdot
.69012 .3235 Mdot
.61862 .0611 Mdot
.8303 .41146 Mdot
.52814 .43263 Mdot
.27967 .42609 Mdot
.89616 .39171 Mdot
.24755 .60981 Mdot
.08278 .88141 Mdot
.08715 .34968 Mdot
.31026 .06297 Mdot
.92167 .08679 Mdot
.58893 .99232 Mdot
.59645 .44445 Mdot
.63343 .55873 Mdot
.38226 .67303 Mdot
.45723 .51521 Mdot
.49323 .88051 Mdot
.17651 .78063 Mdot
.63609 .90692 Mdot
.45321 .2544 Mdot
.15524 .88464 Mdot
.7733 .84118 Mdot
.88623 .39765 Mdot
.56824 .17984 Mdot
.65563 .30552 Mdot
.54977 .256 Mdot
.85808 .043 Mdot
.5136 .33286 Mdot
.98181 .8068 Mdot
.92358 .92084 Mdot
.71009 .27585 Mdot
.80713 .2978 Mdot
.16492 .81843 Mdot
.72735 .84146 Mdot
.93673 .01957 Mdot
.52801 .29388 Mdot
.66353 .3237 Mdot
.60281 .4276 Mdot
.41746 .65308 Mdot
.77705 .72362 Mdot
.79262 .43338 Mdot
.45872 .44631 Mdot
.47771 .54992 Mdot
.97875 .51731 Mdot
.64759 .10213 Mdot
.61298 .31175 Mdot
.34198 .69837 Mdot
.44891 .40996 Mdot
.02075 .77005 Mdot
.22497 .35255 Mdot
.24574 .71503 Mdot
.02101 .24194 Mdot
.0696 .62288 Mdot
.20351 .15722 Mdot
.97892 .68422 Mdot
.87788 .29652 Mdot
.6917 .99279 Mdot
.59874 .34441 Mdot
.97797 .90112 Mdot
.5036 .60073 Mdot
.32045 .48329 Mdot
.67075 .6077 Mdot
.45517 .39337 Mdot
.94254 .01589 Mdot
.99952 .18259 Mdot
.37272 .20131 Mdot
.70411 .10386 Mdot
.13261 .5297 Mdot
.36992 .49159 Mdot
.18411 .53539 Mdot
.96426 .2138 Mdot
.07679 .58692 Mdot
.02643 .39101 Mdot
.03148 .59069 Mdot
.18977 .33444 Mdot
.48636 .22714 Mdot
.55787 .78124 Mdot
.75167 .37567 Mdot
.53352 .06989 Mdot
.9544 .443 Mdot
.55886 .93825 Mdot
.38527 .53887 Mdot
.18783 .32218 Mdot
.92248 .54362 Mdot
.57057 .59293 Mdot
.25177 .56433 Mdot
.99969 .62636 Mdot
.38024 .00457 Mdot
.79319 .47998 Mdot
.07775 .99466 Mdot
.94877 .76529 Mdot
.49408 .90909 Mdot
.73126 .21794 Mdot
.76144 .01253 Mdot
.18948 .51314 Mdot
.21929 .84569 Mdot
.24463 .27585 Mdot
.58006 .90188 Mdot
.85596 .23583 Mdot
.53479 .25328 Mdot
.40054 .39706 Mdot
.06249 .9236 Mdot
.06357 .27235 Mdot
.96502 .37126 Mdot
.71106 .6795 Mdot
.86674 .00502 Mdot
.90794 .81156 Mdot
.00982 .54621 Mdot
.28657 .93491 Mdot
.07816 .23067 Mdot
.82556 .02438 Mdot
.94943 .34718 Mdot
.79144 .26732 Mdot
.49455 .0466 Mdot
.33522 .31712 Mdot
.88697 .28682 Mdot
.97519 .26122 Mdot
.67524 .93066 Mdot
.74696 .09207 Mdot
.32851 .76626 Mdot
.03505 .78552 Mdot
.82897 .87486 Mdot
.59882 .11116 Mdot
.55366 .18121 Mdot
.43871 .51816 Mdot
.68017 .4858 Mdot
.75088 .82812 Mdot
.13883 .54092 Mdot
.07155 .95529 Mdot
.80337 .29282 Mdot
.02005 .48451 Mdot
.17368 .88264 Mdot
.62635 .09314 Mdot
.71196 .3955 Mdot
.39228 .58585 Mdot
.83806 .85263 Mdot
.56876 .41296 Mdot
.52721 .98291 Mdot
.48012 .2468 Mdot
.97487 .04308 Mdot
.954 .66262 Mdot
.53922 .11442 Mdot
.32199 .80008 Mdot
.94861 .84112 Mdot
.36164 .34707 Mdot
.62636 .88055 Mdot
.33723 .38232 Mdot
.44182 .36509 Mdot
.4004 .28836 Mdot
.55282 .80736 Mdot
.34857 .72323 Mdot
.94036 .38774 Mdot
.99897 .39086 Mdot
.0434 .89148 Mdot
.0993 .99108 Mdot
.7281 .64689 Mdot
.39039 .2615 Mdot
.45984 .14813 Mdot
.47479 .5376 Mdot
.39772 .38769 Mdot
.41276 .83942 Mdot
.49378 .98123 Mdot
.44724 .54037 Mdot
.85086 .97341 Mdot
.05278 .71884 Mdot
.46386 .66883 Mdot
.30619 .14353 Mdot
.15195 .66474 Mdot
.34449 .22153 Mdot
.32647 .87368 Mdot
.53569 .05197 Mdot
.33225 .10707 Mdot
.50827 .82111 Mdot
.47575 .73208 Mdot
.39905 .90622 Mdot
.94438 .16408 Mdot
.93693 .76467 Mdot
.09671 .85549 Mdot
.23467 .02615 Mdot
.36031 .82962 Mdot
.29197 .45232 Mdot
.40856 .34251 Mdot
.38913 .78867 Mdot
.45077 .65186 Mdot
.35057 .60307 Mdot
.60403 .51838 Mdot
.57184 .06304 Mdot
.31334 .95905 Mdot
.95335 .9208 Mdot
.81326 .45678 Mdot
.36115 .24499 Mdot
.84148 .27883 Mdot
.69263 .38533 Mdot
.06681 .30247 Mdot
.88634 .00432 Mdot
.98591 .29327 Mdot
.90936 .0268 Mdot
.72966 .13895 Mdot
.0018 .30351 Mdot
.77244 .79502 Mdot
.42779 .05599 Mdot
.60567 .72469 Mdot
.70486 .17413 Mdot
.13065 .0611 Mdot
.40359 .1376 Mdot
.70445 .16235 Mdot
.07945 .52739 Mdot
.32656 .50498 Mdot
.55901 .15904 Mdot
.99235 .76128 Mdot
.15391 .17796 Mdot
.55556 .5895 Mdot
.13452 .74713 Mdot
.6363 .51771 Mdot
.01702 .22503 Mdot
.84463 .82096 Mdot
.04492 .42837 Mdot
.81172 .28033 Mdot
.57749 .27742 Mdot
.82411 .41198 Mdot
.40876 .80759 Mdot
.46016 .06247 Mdot
.84277 .27232 Mdot
.2496 .8402 Mdot
.32249 .84526 Mdot
.25394 .94319 Mdot
.64525 .25812 Mdot
.79446 .74024 Mdot
.96904 .46652 Mdot
.67824 .83348 Mdot
.01743 .5292 Mdot
.1671 .0523 Mdot
.02733 .40175 Mdot
.33133 .33869 Mdot
.78645 .74474 Mdot
.44718 .90932 Mdot
.03252 .29851 Mdot
.78542 .29061 Mdot
.78736 .36454 Mdot
.6323 .16436 Mdot
.22259 .51615 Mdot
.62646 .96287 Mdot
.80341 .32118 Mdot
.78903 .57191 Mdot
.17167 .5812 Mdot
.11451 .57075 Mdot
.71503 .44237 Mdot
.04138 .33969 Mdot
.26793 .79091 Mdot
.87754 .35976 Mdot
.8092 .80507 Mdot
.62666 .56633 Mdot
.97768 .90508 Mdot
.6379 .19264 Mdot
.80897 .17585 Mdot
.19099 .27392 Mdot
.03435 .93564 Mdot
.45817 .35289 Mdot
.95188 .10866 Mdot
.06155 .39874 Mdot
.02737 .92668 Mdot
.58293 .6397 Mdot
.56146 .47875 Mdot
.58541 .42132 Mdot
.17659 .98544 Mdot
.34158 .58538 Mdot
.76675 .45437 Mdot
.75046 .92608 Mdot
.09367 .91805 Mdot
.68821 .21734 Mdot
.7966 .42138 Mdot
.16329 .21391 Mdot
.40123 .13589 Mdot
.0034 .92248 Mdot
.19545 .25684 Mdot
.7872 .12548 Mdot
.67732 .64277 Mdot
.113 .93252 Mdot
.2631 .78277 Mdot
.9934 .59953 Mdot
.55012 .2549 Mdot
.69982 .04845 Mdot
.12042 .19614 Mdot
.12669 .48003 Mdot
.36477 .4227 Mdot
.77795 .9237 Mdot
.75487 .82064 Mdot
.31027 .44432 Mdot
.76695 .55008 Mdot
.87457 .89104 Mdot
.82923 .36052 Mdot
.49251 .89586 Mdot
.94646 .72536 Mdot
.12182 .24941 Mdot
.15999 .93627 Mdot
.35679 .42532 Mdot
.26632 .87074 Mdot
.20261 .16365 Mdot
.10171 .64976 Mdot
.49892 .36744 Mdot
.99325 .50827 Mdot
.24615 .83587 Mdot
.53025 .77432 Mdot
.43802 .55619 Mdot
.18539 .41516 Mdot
.65329 .70026 Mdot
.38574 .11452 Mdot
.67409 .65866 Mdot
.77046 .62407 Mdot
.11353 .12512 Mdot
.24812 .58365 Mdot
.24964 .39369 Mdot
.89326 .66324 Mdot
.36551 .95091 Mdot
.74147 .48778 Mdot
.5642 .02739 Mdot
.16741 .47141 Mdot
.50841 .6947 Mdot
.19435 .73998 Mdot
.15473 .41313 Mdot
.01457 .49156 Mdot
.6577 .69265 Mdot
.42673 .54378 Mdot
.73825 .9145 Mdot
.15812 .24187 Mdot
.77451 .30765 Mdot
.78139 .32008 Mdot
.60473 .92749 Mdot
.98768 .48365 Mdot
.70831 .87037 Mdot
.42362 .17105 Mdot
.1465 .06911 Mdot
.72785 .04683 Mdot
.13492 .76152 Mdot
.95832 .1215 Mdot
.75689 .23212 Mdot
.44393 .23171 Mdot
.37254 .25879 Mdot
.02726 .25341 Mdot
.111 .96465 Mdot
.42223 .36184 Mdot
.75632 .46012 Mdot
.62333 .87178 Mdot
.20337 .03893 Mdot
.22592 .22228 Mdot
.72012 .68451 Mdot
.88099 .7382 Mdot
.32861 .83896 Mdot
.07157 .86939 Mdot
.61453 .95998 Mdot
.42006 .97458 Mdot
.80504 .60594 Mdot
.6555 .24668 Mdot
.43974 .77055 Mdot
.38457 .99818 Mdot
.87143 .34861 Mdot
.78359 .13931 Mdot
.8261 .05514 Mdot
.52351 .02092 Mdot
.87853 .56855 Mdot
.0704 .51011 Mdot
.63173 .26072 Mdot
.01661 .96529 Mdot
.44014 .03169 Mdot
.06061 .32802 Mdot
.41064 .86045 Mdot
.02714 .96998 Mdot
.91642 .15514 Mdot
.651 .1644 Mdot
.75306 .4764 Mdot
.762 .80765 Mdot
.52547 .29324 Mdot
.32812 .8716 Mdot
.25889 .66043 Mdot
.93331 .34285 Mdot
.43464 .3013 Mdot
.2641 .63835 Mdot
.64701 .80213 Mdot
.81201 .2857 Mdot
.07421 .25223 Mdot
.81849 .7249 Mdot
.67564 .41191 Mdot
.43489 .30744 Mdot
.80918 .47717 Mdot
.73263 .06227 Mdot
.92877 .16976 Mdot
.4064 .11808 Mdot
.90477 .51869 Mdot
.56143 .81855 Mdot
.89531 .11592 Mdot
.08928 .89042 Mdot
.48871 .20231 Mdot
.94301 .78263 Mdot
.16404 .42193 Mdot
.86859 .12912 Mdot
.00175 .60806 Mdot
.80801 .64418 Mdot
.45723 .03829 Mdot
.98995 .9171 Mdot
.90861 .87263 Mdot
.08184 .76455 Mdot
.63895 .38528 Mdot
.35671 .22897 Mdot
.76468 .50795 Mdot
.06512 .06466 Mdot
.92596 .44688 Mdot
.7939 .58858 Mdot
.56073 .2158 Mdot
.35725 .32495 Mdot
.5181 .86446 Mdot
.94058 .76382 Mdot
.91444 .37202 Mdot
.53682 .6157 Mdot
.96974 .61304 Mdot
.5514 .80962 Mdot
.55934 .73718 Mdot
.81808 .36968 Mdot
.26475 .90835 Mdot
.72108 .41082 Mdot
.09893 .03102 Mdot
.72 .45506 Mdot
.20496 .53424 Mdot
.12339 .10129 Mdot
.62783 .56051 Mdot
.21083 .09756 Mdot
.33571 .31496 Mdot
.03077 .65453 Mdot
.12456 .22648 Mdot
.55043 .93615 Mdot
.47783 .93836 Mdot
.51404 .15198 Mdot
.74926 .26483 Mdot
.15844 .29871 Mdot
.1334 .11472 Mdot
.6798 .83354 Mdot
.84792 .94302 Mdot
.79749 .40122 Mdot
.88526 .01545 Mdot
.39829 .11638 Mdot
.16972 .43364 Mdot
.18128 .55619 Mdot
.32195 .13882 Mdot
.11466 .0358 Mdot
.9197 .46252 Mdot
.33561 .0737 Mdot
.45392 .69909 Mdot
.32544 .87765 Mdot
.91161 .15243 Mdot
.10224 .12609 Mdot
.42481 .48827 Mdot
.04935 .37332 Mdot
.91219 .41225 Mdot
.4717 .18488 Mdot
.88939 .91859 Mdot
.70004 .83014 Mdot
.63514 .09136 Mdot
.7793 .07264 Mdot
.79643 .75235 Mdot
.83952 .83698 Mdot
.189 .24452 Mdot
.40408 .10604 Mdot
.1385 .10472 Mdot
.68917 .37355 Mdot
.90045 .06263 Mdot
.86106 .49683 Mdot
.37118 .81092 Mdot
.52097 .06314 Mdot
.41782 .3523 Mdot
.12855 .61312 Mdot
.22649 .96143 Mdot
.88653 .11595 Mdot
.41697 .09739 Mdot
.85618 .42629 Mdot
.88439 .37865 Mdot
.56132 .67472 Mdot
.39515 .65303 Mdot
.25385 .76789 Mdot
.39628 .47103 Mdot
.06442 .07082 Mdot
.62155 .7728 Mdot
.4014 .06027 Mdot
.75408 .14615 Mdot
.10275 .26135 Mdot
.70537 .6599 Mdot
.62013 .23204 Mdot
.44699 .68968 Mdot
.73636 .9295 Mdot
.4484 .38283 Mdot
.06646 .82149 Mdot
.7102 .54328 Mdot
.63097 .3595 Mdot
.44527 .39975 Mdot
.61371 .95114 Mdot
.3385 .5892 Mdot
.09074 .04213 Mdot
.98474 .51399 Mdot
.86838 .1675 Mdot
.16855 .46308 Mdot
.51264 .5749 Mdot
.10546 .40196 Mdot
.02233 .3979 Mdot
.01285 .45435 Mdot
.02676 .43533 Mdot
.92632 .70086 Mdot
.8025 .09856 Mdot
.0025 .48744 Mdot
.04774 .68537 Mdot
.63191 .59283 Mdot
.78387 .92503 Mdot
.05686 .79375 Mdot
.66441 .68627 Mdot
.35539 .7016 Mdot
.23984 .67564 Mdot
.89688 .85457 Mdot
.86292 .86694 Mdot
.62891 .75441 Mdot
.44731 .12944 Mdot
.99593 .62079 Mdot
.744 .06357 Mdot
.01018 .64005 Mdot
.59626 .74415 Mdot
.32039 .24779 Mdot
.29496 .65926 Mdot
.59946 .95741 Mdot
.65167 .37262 Mdot
.03543 .67943 Mdot
.45336 .15763 Mdot
.78038 .31792 Mdot
.35992 .39663 Mdot
.46328 .36829 Mdot
.91925 .97861 Mdot
.01922 .32884 Mdot
.98219 .84511 Mdot
.10938 .42339 Mdot
.06803 .78259 Mdot
.11513 .15025 Mdot
.80258 .03298 Mdot
.46472 .77537 Mdot
.03346 .24505 Mdot
.27629 .10871 Mdot
.0475 .45445 Mdot
.25511 .35259 Mdot
.4876 .89497 Mdot
.82895 .39876 Mdot
.09761 .67215 Mdot
.10228 .55809 Mdot
.66486 .54409 Mdot
.61066 .09688 Mdot
.21845 .90337 Mdot
.52892 .64062 Mdot
.79519 .024 Mdot
.84054 .25583 Mdot
.37402 .19238 Mdot
.99653 .51157 Mdot
.28338 .93204 Mdot
.77925 .4782 Mdot
.82342 .62913 Mdot
.07914 .28174 Mdot
.51651 .72407 Mdot
.07197 .84049 Mdot
.96867 .1556 Mdot
.94165 .80874 Mdot
.54483 .47556 Mdot
.74587 .22143 Mdot
.54572 .65871 Mdot
.09011 .32272 Mdot
.90677 .36551 Mdot
.6884 .46945 Mdot
.46155 .36045 Mdot
.95819 .55971 Mdot
.55632 .04935 Mdot
.55336 .11119 Mdot
.22332 .49501 Mdot
.91361 .67073 Mdot
.05553 .38458 Mdot
.85209 .07611 Mdot
.89135 .09564 Mdot
.33818 .36823 Mdot
.61835 .10784 Mdot
.03622 .24034 Mdot
.5347 .35443 Mdot
.44294 .34011 Mdot
.60581 .71156 Mdot
.57563 .8697 Mdot
.03102 .81573 Mdot
.23813 .58451 Mdot
.34798 .0971 Mdot
.74676 .13025 Mdot
.06397 .36189 Mdot
.05056 .41682 Mdot
.81731 .90514 Mdot
.64102 .51794 Mdot
.66325 .17013 Mdot
.55945 .54401 Mdot
.43012 .84905 Mdot
.36431 .08303 Mdot
.72881 .63777 Mdot
.72251 .16842 Mdot
.75492 .96018 Mdot
.32853 .41556 Mdot
.36666 .25749 Mdot
.93407 .63484 Mdot
.10282 .75108 Mdot
.6611 .77282 Mdot
.09202 .16795 Mdot
.79375 .81836 Mdot
.08878 .9821 Mdot
.78831 .06608 Mdot
.71795 .69532 Mdot
.45426 .57023 Mdot
.33305 .09075 Mdot
.48746 .53139 Mdot
.62536 .47338 Mdot
.14589 .24394 Mdot
.86464 .12927 Mdot
.81526 .16105 Mdot
.36824 .55842 Mdot
.71595 .70941 Mdot
.61928 .23207 Mdot
.29654 .98644 Mdot
.55695 .87946 Mdot
.46321 .78725 Mdot
.63987 .17749 Mdot
.39148 .87381 Mdot
.6302 .06262 Mdot
.59346 .99152 Mdot
.10366 .27034 Mdot
.37201 .19374 Mdot
.3591 .33929 Mdot
.28926 .15677 Mdot
.09571 .73534 Mdot
.41908 .52593 Mdot
.18143 .22169 Mdot
.5913 .13998 Mdot
.19691 .71612 Mdot
.58023 .90072 Mdot
.96833 .02553 Mdot
.36844 .54657 Mdot
.48223 .40156 Mdot
.63506 .70776 Mdot
.49449 .43542 Mdot
.91172 .17705 Mdot
.02485 .26451 Mdot
.10497 .98782 Mdot
.23854 .45765 Mdot
.91778 .49448 Mdot
.62847 .35114 Mdot
.95766 .00304 Mdot
.27788 .74009 Mdot
.98608 .81183 Mdot
.17601 .98208 Mdot
.99195 .47755 Mdot
.26233 .95917 Mdot
.77501 .93075 Mdot
.6396 .99278 Mdot
.25836 .27722 Mdot
.76646 .94958 Mdot
.73869 .41714 Mdot
.51948 .17546 Mdot
.13152 .1091 Mdot
.82629 .1141 Mdot
.76581 .67817 Mdot
.08572 .51206 Mdot
.09262 .5719 Mdot
.40941 .22565 Mdot
.96757 .32677 Mdot
.15467 .60363 Mdot
.35134 .34839 Mdot
.97651 .01988 Mdot
.99921 .54665 Mdot
.84301 .43419 Mdot
.50239 .08449 Mdot
.35582 .94348 Mdot
.12371 .78167 Mdot
.65944 .81825 Mdot
.64962 .84228 Mdot
.63544 .94358 Mdot
.26749 .15412 Mdot
.84964 .98763 Mdot
.31231 .13779 Mdot
.52872 .33355 Mdot
.6906 .20614 Mdot
.28512 .53143 Mdot
.77523 .79094 Mdot
.33792 .92857 Mdot
.08532 .36808 Mdot
.25512 .78182 Mdot
.04501 .18584 Mdot
.0261 .1698 Mdot
.43688 .64331 Mdot
.53175 .82985 Mdot
.51437 .88244 Mdot
.69268 .12061 Mdot
.2055 .01828 Mdot
.68781 .22359 Mdot
.7096 .62061 Mdot
.01976 .62215 Mdot
.29527 .84767 Mdot
.09982 .26371 Mdot
.59828 .03957 Mdot
.70212 .42362 Mdot
.80749 .0245 Mdot
.54434 .9756 Mdot
.67358 .7963 Mdot
.51138 .49236 Mdot
.10147 .12995 Mdot
.16472 .93934 Mdot
.75842 .93812 Mdot
.79277 .89138 Mdot
.06063 .72078 Mdot
.0203 .00339 Mdot
.83486 .00422 Mdot
.99175 .21635 Mdot
.6798 .63048 Mdot
.80545 .56587 Mdot
.38136 .50354 Mdot
.9399 .43929 Mdot
.86548 .71693 Mdot
.42349 .17693 Mdot
.79274 .14522 Mdot
.27356 .62801 Mdot
.32631 .0974 Mdot
.83511 .98885 Mdot
.82275 .42971 Mdot
.48511 .39145 Mdot
.807 .13515 Mdot
.04819 .43022 Mdot
.07057 .26873 Mdot
.47264 .38119 Mdot
.56616 .23762 Mdot
.72793 .83945 Mdot
.41831 .43379 Mdot
.8312 .81831 Mdot
.72102 .99542 Mdot
.64086 .19724 Mdot
.24228 .20553 Mdot
.77755 .12697 Mdot
.01331 .42296 Mdot
.10269 .35347 Mdot
.59063 .73263 Mdot
.99557 .34218 Mdot
.419 .15091 Mdot
.88265 .8903 Mdot
.59448 .09002 Mdot
.45209 .6564 Mdot
.27344 .42392 Mdot
.49206 .8722 Mdot
.43871 .87989 Mdot
.32281 .07109 Mdot
.01868 .84758 Mdot
.58424 .37432 Mdot
.78273 .70344 Mdot
.95757 .66622 Mdot
.01249 .21031 Mdot
.68287 .14042 Mdot
.03677 .53658 Mdot
.61328 .11287 Mdot
.19481 .44591 Mdot
.5159 .86166 Mdot
.37783 .2264 Mdot
.82032 .18845 Mdot
.71768 .77667 Mdot
.61367 .15211 Mdot
.57828 .64994 Mdot
.252 .14265 Mdot
.87563 .08962 Mdot
.96532 .33548 Mdot
.52302 .93972 Mdot
.97188 .5596 Mdot
.67416 .8641 Mdot
.09655 .31601 Mdot
.91583 .30278 Mdot
.65496 .79505 Mdot
.55974 .88651 Mdot
.69155 .01152 Mdot
.63077 .60131 Mdot
.0277 .5273 Mdot
.02468 .15044 Mdot
.41524 .84812 Mdot
.19071 .56519 Mdot
.83049 .89498 Mdot
.90012 .32078 Mdot
.35575 .93842 Mdot
.62212 .70163 Mdot
.05573 .8127 Mdot
.44985 .45153 Mdot
.01692 .12869 Mdot
.48009 .24903 Mdot
.64514 .99222 Mdot
.76697 .71083 Mdot
.83969 .81918 Mdot
.18377 .53637 Mdot
.35675 .50961 Mdot
.93282 .56792 Mdot
.6025 .98461 Mdot
.67524 .47664 Mdot
.11131 .56971 Mdot
.85672 .68204 Mdot
.7649 .03454 Mdot
.74211 .82155 Mdot
.46931 .39032 Mdot
.63865 .71997 Mdot
.31062 .97019 Mdot
.80608 .7865 Mdot
.33362 .04601 Mdot
.5691 .58456 Mdot
.31524 .69089 Mdot
.23218 .69918 Mdot
.54211 .4982 Mdot
.99847 .43251 Mdot
.44199 .13804 Mdot
.62021 .9675 Mdot
.34162 .07351 Mdot
.62491 .91563 Mdot
.40706 .73767 Mdot
.17389 .48017 Mdot
.46763 .08683 Mdot
.26296 .27689 Mdot
.73825 .03026 Mdot
.4282 .20974 Mdot
.57388 .13623 Mdot
.97097 .14846 Mdot
.80681 .61687 Mdot
.03807 .4991 Mdot
.84501 .91705 Mdot
.75402 .24441 Mdot
.79834 .77451 Mdot
.21629 .09226 Mdot
.71879 .02769 Mdot
.37027 .45439 Mdot
.31793 .64856 Mdot
.33725 .6352 Mdot
.09773 .18515 Mdot
.90443 .11034 Mdot
.88787 .94207 Mdot
.50761 .25159 Mdot
.70949 .63926 Mdot
.09575 .59563 Mdot
.52538 .2564 Mdot
.50213 .89716 Mdot
.18779 .85227 Mdot
.5262 .06962 Mdot
.26254 .57092 Mdot
.54956 .82075 Mdot
.80638 .01897 Mdot
.24663 .0486 Mdot
.21294 .70711 Mdot
.35726 .43554 Mdot
.89743 .4271 Mdot
.65499 .14729 Mdot
.00898 .526 Mdot
.78853 .94731 Mdot
.43102 .29895 Mdot
.66937 .49535 Mdot
.55359 .09539 Mdot
.78412 .07498 Mdot
.39834 .71184 Mdot
.85534 .40115 Mdot
.52829 .62425 Mdot
.10451 .59985 Mdot
.99491 .56795 Mdot
.84269 .80699 Mdot
.38974 .39242 Mdot
.40903 .48515 Mdot
.59621 .4858 Mdot
.09121 .63301 Mdot
.68145 .73371 Mdot
.91655 .98534 Mdot
.91038 .61529 Mdot
.70828 .95101 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00;o
oooo0_l00009ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool2o`0000ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01oooool2o`0000Cooooo00?o0000ooooooooool02?ooool2o`0000?o
oooo00?o0000ooooooooool02Oooool2o`0000;ooooo00Co0000ooooool0003o00001_ooool2o`00
00Gooooo00?o0000ooooooooool00_ooool001kooooo00?o0000ooooooooool00_ooool2o`0000Wo
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool01oooool2o`0000Gooooo00?o0000ooooooooool02Oooool2o`0000;o
oooo0_l0000>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo0_l00004ooooo`03o`000?oooooooooo00;o
oooo0_l00004ooooo`;o00000oooool00ol0003oooooooooo`0=ooooo`04o`000?oooooo0000o`00
00gooooo00?o0000ooooooooool00_ooool001kooooo00?o0000ooooooooool0N?ooool2o`0000Go
oooo0_l0000:ooooo`;o0000O_ooool2o`0000Wooooo0_l0000_ooooo`007_ooool00ol0003ooooo
ooooo`1oooooo`;o0000G?ooool2o`0001Cooooo0_l0001Booooo`007_ooool00ol0003ooooooooo
o`0Fooooo`;o0000aOooool2o`0001Cooooo0_l0000Wooooo`;o00004?ooool2o`0001Oooooo000N
ooooo`03o`000?oooooooooo01Kooooo0_l0000Wooooo`;o0000Y?ooool2o`0001_ooooo0_l0000H
ooooo`;o00003_ooool4o`0000Wooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`0:oooo
o`;o0000<oooool2o`0006Gooooo0_l0000mooooo`;o00006oooool2o`0002Sooooo0_l0000;oooo
o`;o00003?ooool001kooooo00?o0000ooooooooool02_ooool2o`0004[ooooo0_l0001>ooooo`;o
0000EOooool3o`0000;ooooo0_l00004ooooo`;o0000;Oooool2o`0000kooooo000Nooooo`03o`00
0?oooooooooo04Sooooo0_l0000<ooooo`;o0000Foooool2o`00037ooooo0_l0000Eooooo`?o0000
0_ooool2o`0000Cooooo0_l0000Jooooo`;o00004Oooool2o`0000kooooo000Nooooo`03o`000?oo
oooooooo01cooooo0_l0000Zooooo`;o0000@Oooool2o`0002Kooooo0_l0000aooooo`;o00001?oo
ool2o`0003Kooooo0_l0000Qooooo`007_ooool00ol0003oooooooooo`0Looooo`;o0000C?ooool2
o`0001Kooooo0_l00007ooooo`;o0000:Oooool2o`0003Cooooo0_l00007ooooo`;o00002_ooool2
o`0004Cooooo000Nooooo`03o`000?oooooooooo027ooooo0_l00017ooooo`;o00005_ooool2o`00
00gooooo0_l0000Sooooo`;o0000?Oooool2o`0000[ooooo0_l00014ooooo`007_ooool00ol0003o
ooooooooo`0Qooooo`;o00006oooool2o`00057ooooo0_l0000[ooooo`;o0000Qoooool001kooooo
00?o0000ooooooooool06Oooool2o`0002?ooooo0_l0001nooooo`;o0000Doooool2o`0002Cooooo
0_l0000<ooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o0000COooool2o`0003?ooooo0_l0
001:ooooo`;o0000:?ooool2o`0002Cooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`1<
ooooo`;o00006_ooool2o`0003?ooooo0_l0000Booooo`;o0000;?ooool2o`0000Sooooo0_l0001L
ooooo`007_ooool2o`0001Cooooo0_l0000Mooooo`;o00006?ooool2o`0005cooooo0_l00005oooo
o`;o0000;?ooool2o`0006Kooooo000Nooooo`03o`000?oooooooooo01?ooooo0_l0000Mooooo`;o
0000Doooool2o`00027ooooo0_l0001Looooo`;o0000?Oooool001kooooo00?o0000ooooooooool0
Qoooool2o`0007oooooo0_l0000mooooo`007_ooool00ol0003oooooooooo`0Vooooo`;o0000E_oo
ool2o`00017ooooo0_l0000booooo`;o00000_ooool2o`0001oooooo0_l0000eooooo`;o00009?oo
ool001kooooo00?o0000ooooooooool04Oooool2o`0001?ooooo0_l0000iooooo`;o00006oooool2
o`00017ooooo0_l0000Booooo`;o00003oooool2o`0000gooooo0_l00002ooooo`;o00007oooool2
o`0000;ooooo0_l0000aooooo`;o00009?ooool001kooooo00?o0000ooooooooool04Oooool2o`00
04kooooo0_l00012ooooo`;o00003oooool2o`0003Kooooo0_l0000<ooooo`;o000000?oooooo`00
0?l00000A_ooool001kooooo00?o0000ooooooooool04Oooool2o`0001Wooooo0_l0000gooooo`;o
0000@?ooool4o`00057ooooo0_l000000ooooooo0000o`000016ooooo`007_ooool00ol0003ooooo
ooooo`0Aooooo`;o00006Oooool2o`0003Oooooo0_l00002ooooo`Co0000>_ooool4o`0004kooooo
1?l0000gooooo`;o00004Oooool001kooooo00?o0000ooooooooool0JOooool4o`0008cooooo1?l0
000Dooooo`;o00008Oooool2o`00017ooooo000Nooooo`03o`000?oooooooooo07?ooooo0_l0002L
ooooo`;o0000=?ooool001kooooo00?o0000ooooooooool0L_ooool3o`000=;ooooo000Nooooo`03
o`000?oooooooooo07;ooooo0_l0000Pooooo`;o00002Oooool2o`0007Gooooo0_l0000@ooooo`;o
00007Oooool001kooooo00?o0000ooooooooool0U?ooool2o`0000Wooooo0_l0000Looooo`;o0000
Eoooool2o`000003ooooool0003o000000gooooo0_l0000Mooooo`007_ooool00ol0003ooooooooo
o`12ooooo`;o00009?ooool2o`0005?ooooo0_l00009ooooo`Co00008oooool2o`0002Sooooo0_l0
000/ooooo`007_ooool00ol0003oooooooooo`12ooooo`;o00005_ooool2o`0000cooooo0_l00016
ooooo`;o00005_ooool4o`0002?ooooo0_l0000Uooooo`;o00001_ooool2o`0002Oooooo000Noooo
o`03o`000?oooooooooo043ooooo0_l0000Hooooo`;o00002_ooool2o`0000Gooooo0_l0000Doooo
o`;o0000:oooool2o`00013ooooo0_l0000mooooo`;o00004oooool2o`0000Kooooo0_l0000Woooo
o`007_ooool2o`0002Gooooo0_l0000Jooooo`;o00009?ooool2o`0000Gooooo0_l0000Dooooo`;o
0000?Oooool2o`0000[ooooo0_l0000aooooo`;o0000A?ooool001kooooo00?o0000ooooooooool0
9?ooool2o`0000?ooooo0_l0002Sooooo`;o00004Oooool2o`0002gooooo0_l0000eooooo`007_oo
ool00ol0003oooooooooo`0Yooooo`;o0000:oooool2o`00013ooooo0_l0000Eooooo`;o0000A?oo
ool2o`0001[ooooo0_l0000]ooooo`;o00007oooool2o`0000Gooooo0_l0000=ooooo`007_ooool0
0ol0003oooooooooo`0Wooooo`;o0000;Oooool4o`0000kooooo0_l00004ooooo`;o00003oooool2
o`0002oooooo0_l0000=ooooo`;o00001?ooool2o`0005_ooooo0_l0000=ooooo`;o00001Oooool2
o`0000gooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l0000_ooooo`;o00005?ooool2o`00
00Wooooo0_l0000`ooooo`;o00000oooool2o`0000gooooo0_l00002ooooo`;o0000A?ooool2o`00
01Oooooo0_l0000Sooooo`007_ooool00ol0003oooooooooo`0Wooooo`;o0000D?ooool2o`0000;o
oooo0_l000000ooooooo0000o`00000Yooooo`;o00005_ooool2o`0004Cooooo0_l0000Aooooo`;o
000000?oooooo`000?l000009_ooool001kooooo00?o0000ooooooooool0OOooool2o`000003oooo
ool0003o000005_ooooo0_l0000mooooo`;o000000?oooooo`000?l000002Oooool2o`0001_ooooo
000Nooooo`03o`000?oooooooooo0=gooooo0_l0001;ooooo`;o00001oooool2o`0001;ooooo000N
ooooo`03o`000?oooooooooo01gooooo0_l00002ooooo`;o00008?ooool2o`000;Cooooo0_l00000
0ooooooo0000o`00000eooooo`;o00004_ooool001kooooo00Co0000oooooooooooooooo0_l0000A
ooooo`;o00001oooool2o`0000;ooooo0_l0000Pooooo`;o0000B?ooool2o`00063ooooo0_l00008
ooooo`;o000000?oooooo`000?l000005oooool3o`0002oooooo000Nooooo`04o`000?oooooooooo
ooooo`;o00004Oooool2o`0000Oooooo0_l0001^ooooo`;o0000H?ooool2o`0002Cooooo0ol0000_
ooooo`007_ooool00ol0003oooooooooo`1nooooo`;o0000=_ooool2o`0001Gooooo0_l0000coooo
o`;o0000@oooool001kooooo00?o0000ooooooooool0HOooool2o`0000;ooooo0_l0000Gooooo`?o
00002oooool2o`0002Sooooo0_l0000Eooooo`;o00006_ooool2o`00013ooooo0_l00005ooooo`;o
0000;Oooool2o`0001Cooooo000Nooooo`;o0000Coooool2o`00017ooooo0_l00002ooooo`;o0000
6?ooool2o`0000_ooooo0_l0000^ooooo`;o00002_ooool2o`00013ooooo0_l0000=ooooo`;o0000
4?ooool2o`0003Cooooo0_l0000Dooooo`007_ooool2o`0004oooooo0_l0000?ooooo`;o0000Fooo
ool2o`0000[ooooo0_l0000@ooooo`;o00008_ooool2o`0004Oooooo000Nooooo`03o`000?oooooo
oooo05oooooo0_l0000`ooooo`;o0000?_ooool2o`0001kooooo0_l0000;ooooo`;o0000>?ooool2
o`0000gooooo000Nooooo`;o00001Oooool2o`0001_ooooo0_l0001Qooooo`;o00002oooool2o`00
013ooooo0_l0000Nooooo`;o00003?ooool2o`0001kooooo0_l0000eooooo`;o00003_ooool2o`00
00gooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0000Kooooo`;o0000<?ooool2o`0002oo
oooo0_l0000Mooooo`;o00007_ooool2o`0005oooooo1_l0000Mooooo`007_ooool00ol0003ooooo
ooooo`0nooooo`;o00004oooool2o`0000Gooooo0_l0000Tooooo`;o00003Oooool2o`0009?ooooo
1?l0000?ooooo`;o00003_ooool001kooooo00?o0000ooooooooool0?_ooool2o`0001[ooooo0_l0
000Tooooo`;o00003Oooool2o`00027ooooo0_l0001Aooooo`;o0000<?ooool2o`0000kooooo000N
ooooo`03o`000?oooooooooo03kooooo0_l0000]ooooo`;o0000@oooool2o`0001Gooooo0_l00005
ooooo`;o00003oooool2o`0002;ooooo0_l0000Hooooo`;o00003_ooool2o`0001Kooooo000Noooo
o`03o`000?oooooooooo03kooooo0_l0000]ooooo`;o0000F_ooool2o`0000Gooooo0_l0000?oooo
o`;o0000<oooool2o`0000Oooooo0_l0000>ooooo`;o00005_ooool001kooooo00?o0000oooooooo
ool01?ooool2o`0001Cooooo0_l0002hooooo`;o00004Oooool2o`0002gooooo0_l0000Booooo`;o
00006oooool001kooooo00?o0000ooooooooool01?ooool2o`0001Cooooo0_l0001Zooooo`;o0000
C?ooool2o`00017ooooo0_l00011ooooo`;o00006oooool001kooooo00?o0000ooooooooool0Q_oo
ool2o`0001gooooo0_l0000jooooo`;o00008?ooool2o`0004;ooooo000Nooooo`03o`000?oooooo
oooo02kooooo0_l0001Fooooo`;o00007Oooool2o`0002Gooooo0_l0000Cooooo`;o00008?ooool2
o`0001oooooo0_l0000Qooooo`007_ooool00ol0003oooooooooo`0^ooooo`;o0000E_ooool2o`00
02Sooooo0_l00003ooooo`;o00005Oooool2o`0005Kooooo0_l0000Kooooo`;o00001?ooool001ko
oooo00?o0000ooooooooool02oooool2o`0000oooooo0_l0001gooooo`;o00006Oooool2o`0000?o
oooo0_l0002:ooooo`;o00001?ooool001kooooo00?o0000ooooooooool02oooool2o`0000oooooo
0_l0001gooooo`;o0000L?ooool2o`0003kooooo000Nooooo`03o`000?oooooooooo057ooooo0_l0
002dooooo`;o0000?_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool5o`0000Kooooo00?o0000ooooooooool0DOooool2o`0002;ooooo0_l0001Dooooo`;o0000N_oo
ool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^
k_ooooooA4A400Kooooo00?o0000ooooooooool08oooool2o`0000Wooooo0_l00015ooooo`;o0000
E?ooool3o`0007Wooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Q
onk^kP07ooooo`?o00008oooool2o`0000Wooooo0_l00015ooooo`;o0000EOooool2o`0007Wooooo
0003ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`03o`00
0?oooooooooo07Gooooo0_l0000Tooooo`;o0000Z_ooool000?ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0Boooool2o`0004kooooo
0_l0000oooooo`;o0000JOooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_l00019ooooo`;o0000>_ooool2o`0005?ooooo
0_l0001Yooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo
V9RHoa0@4006ooooo`03o`000?oooooooooo00;o0000QOooool2o`000;kooooo0003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000oooo
ooooool0<Oooool2o`0007oooooo0_l00021ooooo`;o00001oooool2o`0000Oooooo000Nooooo`03
o`000?oooooooooo037ooooo0_l0001oooooo`;o00003oooool2o`0001Oooooo0_l0000<ooooo`;o
0000BOooool2o`0000Oooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`0gooooo`;o0000
3?ooool2o`0002Gooooo0_l0001Eooooo`;o00005oooool2o`0000cooooo0_l00002ooooo`;o0000
Eoooool001kooooo00Co0000oooooooooooooooo0_l0000dooooo`;o00001?ooool2o`0000Kooooo
0_l0000Uooooo`;o00004oooool2o`0005Wooooo0_l0000@ooooo`;o0000Eoooool001kooooo00Co
0000oooooooooooooooo0_l0000Qooooo`;o00005oooool2o`00037ooooo0_l00005ooooo`;o0000
2?ooool2o`0001Oooooo0_l00010ooooo`;o0000JOooool001kooooo00?o0000ooooooooool05Ooo
ool2o`0000gooooo0_l0001:ooooo`;o00001Oooool2o`0001?ooooo0_l0000<ooooo`;o0000:Ooo
ool2o`0002_ooooo0_l0000<ooooo`;o0000AOooool001kooooo00?o0000ooooooooool05Oooool2
o`0007Gooooo0_l0000gooooo`;o0000:oooool2o`0000cooooo0_l00015ooooo`007_ooool00ol0
003oooooooooo`2dooooo`;o0000G?ooool2o`0003?ooooo000Nooooo`03o`000?oooooooooo00So
oooo0_l0002Zooooo`;o0000G?ooool2o`0003?ooooo000Nooooo`03o`000?oooooooooo00?ooooo
0_l00003ooooo`;o00008Oooool2o`0000;ooooo0_l00030ooooo`;o0000E?ooool001kooooo00?o
0000ooooooooool00oooool2o`0000;ooooo0_l0000Rooooo`;o00000_ooool2o`0000Sooooo0_l0
000fooooo`;o00008_ooool2o`000003ooooool0003o000003Oooooo0_l0000Nooooo`;o0000E?oo
ool001kooooo00?o0000ooooooooool01oooool2o`0001[ooooo0_l0000Dooooo`;o0000:Oooool2
o`0000_ooooo0_l0000Rooooo`;o000000?oooooo`000?l00000=oooool2o`0007Cooooo000Noooo
o`;o00001_ooool2o`0000gooooo0_l0000=ooooo`;o0000?oooool2o`0003;ooooo0_l00007oooo
o`;o00001oooool2o`0009_ooooo000Nooooo`03o`000?oooooooooo00Gooooo0_l0000:ooooo`;o
000000?oooooo`000?l00000NOooool2o`00013ooooo0_l00004ooooo`;o000000?oooooo`000?l0
00000oooool2o`0005cooooo0_l0000hooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o0000
:?ooool2o`0003Kooooo1?l0000Hooooo`;o00005_ooool2o`0000Kooooo0_l0000Mooooo`;o0000
?Oooool2o`0003Sooooo000Nooooo`03o`000?oooooooooo01gooooo0_l0000Looooo`;o0000=_oo
ool4o`0000Cooooo0_l0001<ooooo`;o00000oooool2o`0006Wooooo0_l0000<ooooo`007_ooool0
0ol0003oooooooooo`04ooooo`;o00005_ooool3o`0005cooooo0_l0001<ooooo`;o00009?ooool2
o`0004Sooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`04ooooo`;o00003Oooool2o`00
00Oooooo0_l0003Aooooo`;o00003?ooool2o`0004Sooooo000Nooooo`03o`000?oooooooooo01?o
oooo0_l00009ooooo`;o0000gOooool2o`0004Sooooo000Nooooo`03o`000?oooooooooo017ooooo
0_l0000;ooooo`;o00006_ooool2o`000=;ooooo0_l0000gooooo`007_ooool00ol0003ooooooooo
o`0Aooooo`;o00009oooool2o`0000oooooo0_l00003ooooo`?o0000IOooool2o`0002Wooooo0_l0
000Yooooo`;o0000=oooool001kooooo00?o0000ooooooooool0Boooool2o`0000?ooooo0ol0001U
ooooo`;o0000:Oooool2o`0001oooooo0_l00007ooooo`;o0000>?ooool001kooooo00?o0000oooo
ooooool05_ooool2o`000>cooooo0_l00007ooooo`;o0000>?ooool001kooooo00?o0000oooooooo
ool05_ooool2o`000>cooooo0_l0000Fooooo`;o0000:Oooool001kooooo00?o0000ooooooooool0
O_ooool2o`0008Cooooo0_l0000Fooooo`;o0000:Oooool001kooooo00?o0000ooooooooool04Ooo
ool2o`0006_ooooo0_l0000Wooooo`;o0000D_ooool2o`0000Cooooo0_l0000iooooo`;o00002Ooo
ool001kooooo00?o0000ooooooooool04Oooool2o`0009Cooooo0ol0001Aooooo`;o00001?ooool2
o`0001Kooooo0_l0000Qooooo`;o00002Oooool001kooooo00?o0000ooooooooool01_ooool2o`00
02Oooooo0_l0001Gooooo`;o00007_ooool2o`0005Sooooo0_l0000Eooooo`;o0000;?ooool001ko
oooo0_l00007ooooo`;o00002_ooool2o`0001_ooooo0_l0001Gooooo`?o0000<?ooool2o`0004Go
oooo0_l0000Rooooo`;o00007oooool001gooooo0_l0000Dooooo`;o0000MOooool2o`00033ooooo
0_l0000Dooooo`;o0000Doooool2o`0001oooooo000Mooooo`;o0000Roooool2o`0004Kooooo0_l0
000Uooooo`;o0000COooool001kooooo00?o0000ooooooooool0ROooool2o`0003Sooooo0_l0000c
ooooo`;o0000COooool001kooooo00?o0000ooooooooool0JOooool2o`0005Sooooo0_l00022oooo
o`007_ooool00ol0003oooooooooo`0Kooooo`;o0000C?ooool2o`0008oooooo0_l0000;ooooo`;o
0000?_ooool001kooooo00?o0000ooooooooool06oooool2o`0004cooooo0_l00015ooooo`;o0000
B?ooool2o`0000Gooooo0_l00004ooooo`;o00005oooool3o`0002Cooooo000Nooooo`03o`000?oo
oooooooo01Wooooo0_l0000Nooooo`;o0000MOooool2o`0002;ooooo0_l00006ooooo`;o00002Ooo
ool2o`00017ooooo0_l00005ooooo`;o00007Oooool3o`0002Cooooo000Nooooo`03o`000?oooooo
oooo01Wooooo0_l0000Nooooo`;o0000=Oooool2o`0006;ooooo0_l00006ooooo`;o00002Oooool2
o`0004gooooo0_l0000?ooooo`007_ooool00ol0003oooooooooo`02ooooo`;o00003?ooool2o`00
05kooooo0_l00034ooooo`;o00003oooool001kooooo00?o0000ooooooooool00_ooool2o`0000co
oooo0_l0002Aooooo`;o00000oooool2o`0009gooooo000Nooooo`03o`000?oooooooooo03[ooooo
0_l0001Wooooo`;o00000oooool2o`0008cooooo0_l0000?ooooo`007_ooool00ol0003ooooooooo
o`09ooooo`;o0000;oooool2o`0002cooooo0_l00007ooooo`;o0000`oooool2o`0000oooooo000N
ooooo`03o`000?oooooooooo00Wooooo0_l0001Mooooo`;o00001oooool2o`0000kooooo0_l00009
ooooo`;o0000WOooool2o`0001?ooooo0_l00005ooooo`007_ooool00ol0003oooooooooo`21oooo
o`;o00002Oooool2o`00037ooooo0_l0001Zooooo`;o00004oooool2o`0000Gooooo000Nooooo`03
o`000?oooooooooo06kooooo0_l000000ooooooo0000o`00001<ooooo`;o0000E_ooool2o`0001So
oooo0_l0000Dooooo`007_ooool2o`0001Wooooo0_l0000Pooooo`;o0000<_ooool2o`000003oooo
ool0003o000005Gooooo0_l0001=ooooo`;o00006?ooool2o`0001Cooooo000Nooooo`03o`000?oo
oooooooo01Sooooo0_l00003ooooo`;o00000_ooool2o`0001Oooooo0_l00009ooooo`;o00002?oo
ool2o`0000;ooooo0_l0000_ooooo`;o00002oooool2o`0001Oooooo0_l0000Looooo`;o0000OOoo
ool001kooooo00?o0000ooooooooool07Oooool2o`0000;ooooo0_l0000Rooooo`;o00002?ooool2
o`0000;ooooo0_l0000_ooooo`;o00002oooool2o`0001Oooooo0_l0002Kooooo`007_ooool00ol0
003oooooooooo`1Cooooo`;o0000?Oooool2o`0003Gooooo0_l0000nooooo`;o00003_ooool2o`00
02cooooo000Nooooo`03o`000?oooooooooo017ooooo0_l00010ooooo`;o0000<?ooool2o`0000_o
oooo0_l0000eooooo`;o0000?_ooool2o`0000kooooo0_l0000/ooooo`007_ooool00ol0003ooooo
ooooo`0Aooooo`;o0000L_ooool2o`0000Gooooo0_l0000@ooooo`;o0000G?ooool2o`0002Gooooo
0_l0000Rooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o0000D?ooool2o`00023ooooo0_l0
0005ooooo`;o00002Oooool2o`0000Sooooo0_l0001Booooo`;o00002?ooool2o`0001_ooooo0_l0
000Rooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o00002_ooool2o`00053ooooo0_l0000W
ooooo`;o00004oooool2o`0002Kooooo0_l0000:ooooo`;o0000:?ooool2o`0001gooooo0_l0000?
ooooo`;o000000?oooooo`000?l000003?ooool001kooooo00?o0000ooooooooool03?ooool2o`00
0:cooooo0_l0000Dooooo`;o00002_ooool2o`0001;ooooo0_l0000cooooo`;o00003oooool2o`00
0003ooooool0003o000000cooooo000Nooooo`03o`000?oooooooooo0;[ooooo0_l0000dooooo`;o
0000:Oooool2o`0002[ooooo000Nooooo`03o`000?oooooooooo06[ooooo0_l0000Rooooo`;o0000
1_ooool2o`0008?ooooo0_l0000Zooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o0000F_oo
ool2o`0002;ooooo0_l00006ooooo`;o00008oooool2o`0000oooooo0_l0000?ooooo`;o0000Dooo
ool2o`0001?ooooo000Nooooo`03o`000?oooooooooo00kooooo0_l0001]ooooo`;o0000??ooool2
o`0000oooooo0_l0000?ooooo`;o0000Coooool2o`0000;ooooo0_l0000Cooooo`007_ooool00ol0
003oooooooooo`04ooooo`;o0000Moooool2o`0001Gooooo0_l00004ooooo`;o0000Poooool2o`00
00gooooo0_l0000Aooooo`;o00001?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool01?ooool2o`00
04Oooooo0_l0000/ooooo`;o00004oooool2o`0000;ooooo0_l00004ooooo`;o0000Poooool2o`00
023ooooo0_l00004ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool2o`0004Kooooo1?l0000Roooo
o`;o00002?ooool2o`000003ooooool0003o0000013ooooo0_l0001Aooooo`;o0000=oooool2o`00
02Wooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol00003oooo
o`;o00002oooool2o`0003Wooooo0_l0000Tooooo`;o00002oooool2o`0000gooooo0_l0001Doooo
o`;o00006_ooool2o`0000Sooooo0_l00007ooooo`;o00002?ooool2o`0002Wooooo0003ooooo`05
o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooo
oooo00Gooooo0_l00009ooooo`;o00003?ooool2o`0003Sooooo0_l0000cooooo`;o00002_ooool2
o`0006Cooooo0_l00008ooooo`;o00001oooool2o`0003?ooooo0003ooooo`05o`000?oooooooooo
ooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo00Gooooo0_l0
000Gooooo`;o0000>?ooool2o`0003oooooo0_l0002/ooooo`000oooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0Booooo`;o0000N_oo
ool2o`0000[ooooo0_l0002[ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o
k^k^odA4A?l000001oooool00ol0003oooooooooo`0Booooo`;o00006_ooool2o`0005kooooo0_l0
000:ooooo`;o00006Oooool2o`00027ooooo0_l0000<ooooo`;o00008?ooool4o`0001Sooooo0_l0
000Qooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_oo
ool00ol0003oooooooooo`0^ooooo`;o00002?ooool2o`0002gooooo0_l0001<ooooo`;o00008Ooo
ool2o`0000cooooo0_l0000Pooooo`Co00006?ooool2o`00027ooooo000Nooooo`03o`000?oooooo
oooo00cooooo0_l0000Zooooo`;o0000;Oooool2o`0002?ooooo0_l0001Nooooo`;o0000FOooool0
01kooooo00?o0000ooooooooool03?ooool2o`0002?ooooo0_l0000Xooooo`;o00005Oooool2o`00
01Sooooo0_l0000/ooooo`;o0000<?ooool2o`00017ooooo0_l00016ooooo`007_ooool00ol0003o
ooooooooo`02o`0001gooooo0_l0000@ooooo`;o00008_ooool2o`0000Cooooo0_l0000Cooooo`Co
00005_ooool2o`0002kooooo0_l0000Tooooo`;o00007Oooool2o`0004Kooooo000Nooooo`03o`00
0?oooooooooo00;o00002?ooool2o`0001?ooooo0_l0000dooooo`Co00005oooool2o`0001Sooooo
0_l0000dooooo`;o00007_ooool2o`00033ooooo0_l0000<ooooo`;o00009Oooool001kooooo00?o
0000ooooooooool02_ooool4o`0004Wooooo0_l0001Wooooo`;o0000AOooool2o`0000Wooooo0_l0
000<ooooo`;o00009Oooool001kooooo00?o0000ooooooooool03?ooool2o`0002Gooooo0_l0001?
ooooo`;o00008_ooool2o`0005Cooooo0_l00007ooooo`;o00001Oooool2o`00037ooooo0_l00004
ooooo`007_ooool00ol0003oooooooooo`05ooooo`;o0000;?ooool2o`0003_ooooo0_l0000Boooo
o`;o00005oooool2o`0000Wooooo0_l0001Dooooo`;o00001oooool2o`0000Gooooo0_l0000aoooo
o`;o00001?ooool001kooooo00?o0000ooooooooool01Oooool2o`0006Wooooo0_l0000[ooooo`;o
0000J?ooool2o`0002Cooooo0_l0000Hooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o0000
Doooool2o`00087ooooo0_l00017ooooo`;o00000oooool2o`0001?ooooo000Nooooo`03o`000?oo
oooooooo00cooooo0_l00009ooooo`;o00008_ooool2o`0002Cooooo0_l0000^ooooo`;o0000:ooo
ool2o`0002Cooooo0_l00013ooooo`;o00001oooool2o`0001?ooooo000Nooooo`03o`000?oooooo
oooo01Oooooo0_l0000Rooooo`;o0000E?ooool2o`0002_ooooo0_l0001Yooooo`;o00007?ooool0
01kooooo0_l0001Looooo`;o0000<Oooool2o`0001Sooooo0_l0002Mooooo`007_ooool00ol0003o
ooooooooo`02o`0000Wooooo0_l0001>ooooo`;o00005oooool2o`0001Sooooo0_l0000Hooooo`;o
0000??ooool2o`0000gooooo0_l0001@ooooo`007_ooool00ol0003oooooooooo`02o`0000Wooooo
0_l0000looooo`?o0000:?ooool2o`00073ooooo0_l0000=ooooo`;o00003Oooool2o`00047ooooo
000Nooooo`03o`000?oooooooooo04Wooooo0ol0002Vooooo`;o00001oooool2o`0000Oooooo0_l0
000Qooooo`;o00007_ooool001kooooo00?o0000ooooooooool0<oooool3o`0007Wooooo0_l0000/
ooooo`;o00004oooool2o`0000Oooooo0_l0000Zooooo`;o00007_ooool001kooooo00?o0000oooo
ooooool0<oooool3o`0005Wooooo0_l0000Nooooo`;o0000;?ooool2o`0005Sooooo0_l0000>oooo
o`007_ooool00ol0003oooooooooo`0booooo`;o0000BOooool2o`00013ooooo0_l0001;ooooo`;o
0000FOooool2o`0000kooooo000Nooooo`03o`000?oooooooooo03;ooooo0_l00019ooooo`;o0000
B?ooool2o`0001?ooooo0_l0001Yooooo`007_ooool00ol0003oooooooooo`2]ooooo`;o00006?oo
ool2o`0000kooooo0_l0000Hooooo`;o00004?ooool2o`0003Wooooo0_l00007ooooo`007_ooool0
0ol0003oooooooooo`0Uooooo`;o00003Oooool2o`0007Oooooo0_l00003ooooo`;o00008oooool2
o`0001Sooooo0_l00006ooooo`;o00000oooool2o`0000?ooooo0_l0000iooooo`;o00001oooool0
01kooooo00?o0000ooooooooool09Oooool2o`0000gooooo0_l0000Pooooo`;o00003?ooool2o`00
04cooooo0_l00015ooooo`;o00000oooool2o`0003gooooo0_l00008ooooo`007_ooool00ol0003o
ooooooooo`02ooooo`;o0000D_ooool2o`0000cooooo0_l0000Kooooo`;o0000>oooool2o`0001Wo
oooo0_l0001Rooooo`;o00002?ooool001kooooo0_l00003ooooo`;o0000OOooool2o`0000?ooooo
0_l0000fooooo`;o00006Oooool4o`00013ooooo0_l0001Hooooo`007_ooool2o`0000;ooooo0_l0
001Cooooo`;o00007?ooool2o`00013ooooo0_l0000Jooooo`;o0000=oooool2o`00013ooooo0_l0
001Hooooo`007_ooool01?l0003oooooooooooooool2o`00047ooooo0_l0000@ooooo`;o00007?oo
ool2o`0002cooooo0_l0000booooo`;o0000C_ooool2o`0001oooooo000Nooooo`03o`000?oooooo
oooo00Sooooo0_l0000jooooo`;o0000I_ooool2o`0002Sooooo0_l0000looooo`;o00004?ooool2
o`0001oooooo000Nooooo`;o00002Oooool2o`000:;ooooo0_l0001Vooooo`;o0000<Oooool001ko
oooo00?o0000ooooooooool01?ooool2o`00063ooooo0_l0000@ooooo`;o0000cOooool001kooooo
00?o0000ooooooooool01?ooool2o`00063ooooo0_l0000@ooooo`;o0000N_ooool2o`0004Wooooo
0_l00006ooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o0000Foooool2o`0008;ooooo0_l0
0019ooooo`?o00001Oooool001kooooo00?o0000ooooooooool04oooool2o`0000?ooooo0_l0000O
ooooo`;o0000=Oooool2o`000<[ooooo0_l00002ooooo`;o00001Oooool001kooooo00?o0000oooo
ooooool06?ooool2o`0001oooooo0_l00009ooooo`;o0000AOooool2o`0000Cooooo0_l0000hoooo
o`?o0000K?ooool4o`0000Wooooo000Nooooo`03o`000?oooooooooo04Cooooo0_l00015ooooo`;o
00001?ooool2o`0002gooooo0_l00009ooooo`?o0000E?ooool2o`0001Kooooo0_l0000;ooooo`00
7_ooool00ol0003oooooooooo`30ooooo`;o0000H?ooool2o`0002?ooooo000Nooooo`04o`000?oo
oooo0000o`0000Cooooo0_l0000?ooooo`;o0000=?ooool2o`0003Kooooo0_l0000]ooooo`;o0000
T_ooool001kooooo00Go0000ooooool0003o0000ooooo`02o`000003ooooool0003o000000oooooo
0_l0000?ooooo`;o00008oooool2o`0002oooooo0_l00005ooooo`;o0000;Oooool2o`0009;ooooo
000Nooooo`03o`000?oooooooooo00;ooooo0_l0000Sooooo`;o0000<?ooool2o`0002;ooooo0_l0
000Kooooo`;o0000Zoooool001kooooo00?o0000ooooooooool02?ooool2o`0002kooooo0_l00005
ooooo`;o00006?ooool2o`0003oooooo0_l0000Tooooo`;o0000QOooool001kooooo00?o0000oooo
ooooool02?ooool2o`0002kooooo0_l00005ooooo`;o0000>?ooool2o`0001_ooooo0_l0000Xoooo
o`;o0000QOooool001kooooo00?o0000ooooooooool0:Oooool2o`0004kooooo0_l0000Booooo`;o
00001oooool2o`0009?ooooo0_l0000Jooooo`007_ooool00ol0003oooooooooo`0Yooooo`;o0000
G?ooool2o`0000Cooooo0_l0000Sooooo`;o00008?ooool2o`0000gooooo0_l00013ooooo`;o0000
00?oooooo`000?l000006_ooool001kooooo00Co0000ooooool0003o0000Loooool2o`00017ooooo
0_l0000Yooooo`;o00008?ooool2o`0000gooooo0_l00013ooooo`;o00005oooool2o`0000Cooooo
000Nooooo`Co0000Loooool2o`00027ooooo0_l0001Looooo`;o0000B_ooool2o`0000Cooooo000N
ooooo`03o`000?oooooooooo09Oooooo0_l0001Looooo`;o00001Oooool2o`0004Wooooo000Noooo
o`03o`000?oooooooooo01gooooo0_l0000Hooooo`;o0000DOooool2o`00073ooooo0_l00019oooo
o`007_ooool00ol0003oooooooooo`0Mooooo`;o00006?ooool2o`0003_ooooo0_l0000Dooooo`;o
0000??ooool4o`0006Oooooo0_l00003ooooo`;o00003Oooool001kooooo00?o0000ooooooooool0
;_ooool2o`0004Cooooo0_l0001Booooo`Co0000Ioooool2o`0000?ooooo0_l0000=ooooo`007_oo
ool00ol0003oooooooooo`0^ooooo`;o00002_ooool2o`0001;ooooo0_l0001hooooo`;o0000>?oo
ool2o`0004?ooooo000Nooooo`03o`000?oooooooooo023ooooo0_l0000Hooooo`;o00004_ooool2
o`00043ooooo0_l0000fooooo`;o0000>?ooool2o`0001Kooooo0_l0000?ooooo`;o00004_ooool2
o`0000Kooooo000Nooooo`03o`000?oooooooooo01[ooooo0_l00004ooooo`?o0000;_ooool2o`00
03gooooo0_l0001Zooooo`;o00007?ooool2o`0000oooooo0_l0000Booooo`;o00001_ooool001ko
oooo00?o0000ooooooooool06_ooool2o`0000Gooooo0_l0000^ooooo`;o0000D?ooool2o`0005Oo
oooo0_l00019ooooo`007_ooool00ol0003oooooooooo`2Sooooo`;o0000X_ooool001kooooo00?o
0000ooooooooool0=?ooool2o`000?oooooo4_ooool001kooooo00?o0000ooooooooool0=?ooool2
o`0001?ooooo0_l00002ooooo`;o00007?ooool2o`0004Sooooo0_l0002@ooooo`007_ooool00ol0
003oooooooooo`0Eooooo`;o0000<_ooool2o`0000;ooooo0_l0000Looooo`;o00003_ooool2o`00
03Sooooo0_l00017ooooo`;o0000Aoooool001kooooo00?o0000ooooooooool01_ooool2o`0000go
oooo0_l0001Cooooo`;o00003oooool2o`0003Cooooo0_l0001;ooooo`;o00009oooool2o`0001ko
oooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0
003o410@olc<c006ooooo`03o`000?oooooooooo00Kooooo0_l0001Rooooo`;o0000AOooool2o`00
00;ooooo0_l0000Booooo`;o0000G?ooool2o`0001kooooo0003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooo
oooo01_ooooo0_l0002Hooooo`;o00004_ooool2o`0007cooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0000Kooooo`;o000000?o
ooooo`000?l00000P?ooool2o`0009gooooo0_l00006ooooo`000oooool01Ol0003ooooooooooooo
oooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo01kooooo
0_l0000>ooooo`;o0000?_ooool2o`00033ooooo0_l0000Wooooo`;o0000M?ooool2o`0000Kooooo
0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Ko
oooo00?o0000ooooooooool0;_ooool2o`0003kooooo0_l0001Iooooo`;o00005_ooool2o`0001oo
oooo0_l00013ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qooo
ool01oooool2o`0004kooooo0_l00028ooooo`;o00002Oooool2o`0001oooooo0_l0000Rooooo`;o
00007oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Oo
oooo0_l0000Xooooo`;o00009?ooool2o`0007Oooooo0_l0000?ooooo`;o0000C_ooool2o`0000oo
oooo0_l0000>ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0
003o410@1_ooool00ol0003oooooooooo`0Vooooo`;o0000P_ooool2o`0001Wooooo0_l0001Moooo
o`;o00004Oooool2o`0000kooooo000Nooooo`03o`000?oooooooooo0:[ooooo0_l0001Fooooo`;o
00008?ooool2o`00027ooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0002Tooooo`;o0000
8Oooool2o`0001Kooooo0_l0000Mooooo`;o0000??ooool2o`0000Gooooo000Nooooo`03o`000?oo
oooooooo00;ooooo0_l0000?ooooo`;o0000Toooool2o`00027ooooo0_l0000Fooooo`;o00004Ooo
ool2o`0004Sooooo0_l00005ooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o0000@?ooool2
o`00057ooooo0_l0001<ooooo`;o00002?ooool2o`0003oooooo0_l00004ooooo`007_ooool00ol0
003oooooooooo`1Eooooo`;o0000P_ooool2o`0002Gooooo0_l00006ooooo`;o0000=oooool2o`00
00Cooooo000Nooooo`03o`000?oooooooooo01[ooooo0_l0002?ooooo`;o0000;?ooool2o`0002go
oooo0_l0000Rooooo`;o00006Oooool001kooooo00?o0000ooooooooool06_ooool2o`0004kooooo
0_l0000oooooo`;o0000??ooool2o`00047ooooo0_l0000Iooooo`007_ooool01?l0003oooooo`00
0?l0001Aooooo`;o00005_ooool2o`0003cooooo0_l0000?ooooo`;o00002Oooool2o`0001gooooo
0_l00004ooooo`;o0000G?ooool001kooooo00Co0000ooooool0003o0000DOooool2o`0003Kooooo
0_l0000Looooo`;o00003oooool2o`0000Wooooo0_l0000Booooo`;o00002Oooool2o`0001kooooo
0_l00012ooooo`007_ooool00ol0003oooooooooo`1Nooooo`;o0000:_ooool2o`0004cooooo0_l0
000?ooooo`;o00006?ooool2o`0004;ooooo000Nooooo`03o`000?oooooooooo01gooooo0_l0000o
ooooo`;o00000oooool2o`0005?ooooo0_l0000_ooooo`;o0000G?ooool001kooooo0_l0000Noooo
o`;o0000A?ooool2o`0001Oooooo0_l00006ooooo`;o00002?ooool2o`0002Sooooo0_l0002=oooo
o`007_ooool00ol0003oooooooooo`06ooooo`;o0000M?ooool2o`0000Kooooo0_l00008ooooo`?o
0000]_ooool001kooooo00?o0000ooooooooool01_ooool2o`0005Cooooo0_l0000aooooo`;o0000
7?ooool2o`0002Sooooo0_l0001^ooooo`007_ooool00ol0003oooooooooo`1@ooooo`;o00002_oo
ool2o`0004oooooo0_l0000Xooooo`;o00002?ooool2o`0004oooooo0_l0000Cooooo`007_ooool0
0ol0003oooooooooo`0]ooooo`;o00008Oooool2o`0001Cooooo0_l0001iooooo`;o0000>oooool2
o`0001;ooooo0_l0000Cooooo`007_ooool00ol0003oooooooooo`0]ooooo`;o0000=oooool2o`00
02_ooooo0_l00029ooooo`;o00004oooool2o`0001;ooooo000Nooooo`03o`000?oooooooooo09?o
oooo0_l0002@ooooo`;o00003?ooool2o`0001;ooooo000Nooooo`03o`000?oooooooooo01cooooo
0_l0001Jooooo`;o0000>?ooool2o`0003Sooooo0_l0000gooooo`;o00008?ooool001kooooo00?o
0000ooooooooool07?ooool2o`0002cooooo0_l0000/ooooo`;o0000>?ooool2o`0003Sooooo0_l0
001Iooooo`007_ooool00ol0003oooooooooo`07ooooo`;o0000@Oooool2o`0009Oooooo0_l0000@
ooooo`;o0000D?ooool001kooooo00?o0000ooooooooool01oooool2o`000=[ooooo0_l0000@oooo
o`;o00006oooool2o`0002Kooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o
0000aoooool2o`00013ooooo0_l0000Zooooo`;o00009_ooool2o`0000_ooooo000Nooooo`03o`00
0?oooooooooo00_ooooo0_l00020ooooo`;o0000AOooool2o`00013ooooo0_l0001Oooooo`007_oo
ool00ol0003oooooooooo`1Rooooo`;o0000:Oooool2o`0004?ooooo0_l0001cooooo`007_ooool0
0ol0003oooooooooo`1Rooooo`;o0000?Oooool2o`0002oooooo0_l0000Aooooo`;o0000H?ooool0
01kooooo00?o0000ooooooooool0Aoooool2o`0002;ooooo0_l0000Rooooo`;o00004?ooool2o`00
04;ooooo0_l0001Pooooo`007_ooool2o`0004Sooooo0_l0000Rooooo`;o00000_ooool2o`0001ko
oooo0_l0000eooooo`;o00002?ooool2o`0005Oooooo0_l0000Looooo`007_ooool00ol0003ooooo
ooooo`1_ooooo`;o0000EOooool2o`0000Sooooo0_l0000Xooooo`;o0000:oooool4o`0000Wooooo
0_l0000Aooooo`007_ooool00ol0003oooooooooo`11ooooo`;o0000Qoooool2o`0002kooooo0_l0
000[ooooo`;o00002oooool2o`00017ooooo000Nooooo`03o`000?oooooooooo047ooooo0_l0000j
ooooo`;o0000@_ooool2o`0000Oooooo0_l0000Iooooo`;o00003_ooool2o`00053ooooo000Noooo
o`03o`000?oooooooooo07gooooo0_l00012ooooo`;o00008_ooool2o`0000kooooo0_l0001@oooo
o`007_ooool00ol0003oooooooooo`0looooo`;o00003_ooool2o`000<Oooooo0_l0000`ooooo`00
7_ooool00ol0003oooooooooo`0=ooooo`;o000000?oooooo`000?l00000:_ooool2o`0000kooooo
0_l0001Booooo`;o0000:_ooool2o`0002oooooo0_l0000Fooooo`;o0000<?ooool001kooooo00?o
0000ooooooooool03Oooool2o`000003ooooool0003o000005_ooooo0_l0000aooooo`;o00000_oo
ool2o`0002Kooooo0_l0000[ooooo`;o00000_ooool2o`0004Sooooo000Nooooo`03o`000?oooooo
oooo06gooooo0_l0000eooooo`;o00006oooool2o`0003Kooooo0_l0000;ooooo`;o0000:?ooool2
o`0001Gooooo000Nooooo`03o`000?oooooooooo0<7ooooo0_l00013ooooo`;o0000:?ooool2o`00
01Gooooo000Nooooo`03o`000?oooooooooo09Oooooo0_l0000Sooooo`;o0000ROooool001kooooo
00?o0000ooooooooool06oooool2o`0007[ooooo0_l0000Sooooo`;o00006oooool2o`0006cooooo
000Nooooo`03o`000?oooooooooo01_ooooo0_l0001Sooooo`;o0000<?ooool2o`0002Gooooo0_l0
000oooooo`;o0000:oooool001kooooo00?o0000ooooooooool0>oooool2o`0001Wooooo0_l0000X
ooooo`;o0000<?ooool2o`0004[ooooo0_l0000Jooooo`;o0000:oooool001kooooo00?o0000oooo
ooooool05_ooool2o`0002?ooooo0_l0000Iooooo`;o0000I_ooool2o`0003cooooo1?l00017oooo
o`007_ooool00ol0003oooooooooo`0Fooooo`;o00004?ooool2o`0009Cooooo0_l0000looooo`;o
0000BOooool001kooooo0_l0000Nooooo`;o00002Oooool2o`000?oooooo7_ooool001kooooo00?o
0000ooooooooool07Oooool2o`000:Wooooo0_l0000eooooo`;o0000A_ooool001kooooo00?o0000
ooooooooool0b?ooool2o`0003Gooooo0_l00016ooooo`007_ooool00ol0003oooooooooo`3ooooo
obSooooo0_l0000Nooooo`007_ooool00ol0003oooooooooo`0Xooooo`;o0000oOooool2o`0000Go
oooo0_l0000?ooooo`;o00001_ooool001kooooo00?o0000ooooooooool05_ooool2o`00013ooooo
0_l0000mooooo`;o0000`oooool6o`0000gooooo0_l00006ooooo`007_ooool00ol0003ooooooooo
o`03ooooo`;o00004Oooool2o`0003Kooooo0_l0000Gooooo`;o0000`oooool2o`0000;ooooo0_l0
000Eooooo`007_ooool00ol0003oooooooooo`03ooooo`;o0000BOooool2o`0003_ooooo0_l0000i
ooooo`;o00002oooool2o`0007;ooooo000Nooooo`03o`000?oooooooooo08_ooooo0_l00006oooo
o`;o00004oooool2o`0001cooooo0_l0000;ooooo`;o0000:_ooool2o`0004Kooooo000Nooooo`03
o`000?oooooooooo09?ooooo0_l0000Cooooo`;o0000>oooool2o`0001Sooooo0_l00016ooooo`00
7_ooool00ol0003oooooooooo`0Booooo`;o00004?ooool2o`0000oooooo0_l0000Hooooo`;o0000
H?ooool2o`0003;ooooo0_l00017ooooo`;o00005oooool001kooooo00?o0000ooooooooool01ooo
ool2o`0000Wooooo0_l0000@ooooo`;o00003oooool2o`0001Sooooo1?l0001Nooooo`;o0000Nooo
ool2o`0001Oooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l00007ooooo`;o0000?oooool2
o`0002Oooooo0_l0000Fooooo`;o0000K_ooool2o`0004?ooooo000Nooooo`03o`000?oooooooooo
013ooooo0_l00011ooooo`;o00009Oooool2o`0001Kooooo0_l0001Tooooo`;o00002?ooool2o`00
04?ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q
8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo00kooooo0_l00013ooooo`;o0000Xoooool2
o`0004gooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4Q
oiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo00kooooo0_l0000Aooooo`;o0000[_oo
ool2o`0000Cooooo0_l0000Nooooo`;o0000C_ooool000?ooooo00Go410@oooooooooooooooooa0@
400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`00027ooooo0_l00012ooooo`;o0000
J_ooool2o`0000Cooooo0_l0000Nooooo`;o0000C_ooool000?ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool00ol0003oooooooooo`1Uooooo`;o
0000Ioooool2o`0007Oooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co
0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0c_ooool2o`0003?ooooo0_l00009oooo
o`;o0000:oooool2o`0000[ooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@
413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0POooool2o`0002cooooo0ol00012
ooooo`;o00003Oooool2o`0000Wooooo0_l0000Nooooo`;o00002oooool2o`0000[ooooo0003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o
0000ooooooooool03_ooool2o`0006Gooooo0_l0000:ooooo`;o0000;?ooool3o`0004;ooooo0_l0
000]ooooo`;o00002Oooool2o`0000cooooo0_l00009ooooo`000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo00Kooooo
0_l00006ooooo`;o0000IOooool2o`000:cooooo0_l0000Gooooo`;o00002Oooool001kooooo00?o
0000ooooooooool01_ooool2o`0002Wooooo0_l0001oooooo`;o00007_ooool2o`0002[ooooo0_l0
000:ooooo`;o000000?oooooo`000?l00000>?ooool001kooooo00?o0000ooooooooool04Oooool2
o`0001kooooo0_l0001^ooooo`;o00003?ooool2o`000003ooooool0003o000001kooooo0_l0000I
ooooo`;o00000_ooool2o`0000_ooooo0_l0000:ooooo`;o000000Coooooo`000?l0003o0000=ooo
ool001kooooo00?o0000ooooooooool04Oooool2o`0008kooooo0_l0000<ooooo`;o00008Oooool2
o`0001Wooooo0_l00002ooooo`;o00006oooool2o`0003Oooooo000Nooooo`03o`000?oooooooooo
0?3ooooo0_l0000Eooooo`;o0000?_ooool001kooooo00?o0000ooooooooool0LOooool2o`0003Ko
oooo0_l0000dooooo`;o00003oooool2o`0001Gooooo0_l0000nooooo`007_ooool00ol0003ooooo
ooooo`1aooooo`;o0000=_ooool2o`0002gooooo0ol00004ooooo`;o0000I_ooool001kooooo00?o
0000ooooooooool0C?ooool2o`0008[ooooo0ol0000booooo`;o0000>?ooool001kooooo00?o0000
ooooooooool04oooool2o`0003Oooooo0ol0000Hooooo`;o00002?ooool2o`0000oooooo0_l0001U
ooooo`;o00008_ooool2o`00027ooooo0_l0000Eooooo`007_ooool00ol0003oooooooooo`0Coooo
o`;o0000>?ooool2o`0001Sooooo0_l00008ooooo`;o00003oooool2o`0004_ooooo0_l0000Goooo
o`?o00003?ooool2o`0003Oooooo0_l0000Eooooo`007_ooool00ol0003oooooooooo`13ooooo`;o
00008?ooool2o`0006Sooooo0_l0000Gooooo`;o00003Oooool2o`0004;ooooo0_l0000:ooooo`00
7_ooool00ol0003oooooooooo`02ooooo`;o0000?oooool2o`0001Oooooo0_l00007ooooo`;o0000
7?ooool2o`0000?ooooo0_l0002aooooo`;o00002_ooool001kooooo0_l00003ooooo`;o0000=Ooo
ool2o`0001Oooooo0_l00008ooooo`;o00009Oooool2o`0000?ooooo0_l00022ooooo`;o0000>Ooo
ool001kooooo00?o0000ooooooooool06oooool2o`0001cooooo0_l0000Gooooo`;o0000^?ooool2
o`00017ooooo0_l0000Vooooo`007_ooool00ol0003oooooooooo`0Kooooo`;o0000ooooool3oooo
o`;o00009_ooool001kooooo00?o0000ooooooooool0POooool2o`00027ooooo0_l0000Kooooo`;o
0000Q?ooool001kooooo00?o0000ooooooooool0POooool2o`00027ooooo0_l0000Kooooo`;o0000
5?ooool2o`0006kooooo000Nooooo`03o`000?oooooooooo0:Cooooo0_l0000aooooo`;o0000>ooo
ool2o`00037ooooo000Nooooo`03o`000?oooooooooo01?ooooo0_l0000mooooo`;o00004oooool2
o`0004kooooo0_l0000>ooooo`;o00006Oooool2o`00033ooooo0_l0000aooooo`007_ooool00ol0
003oooooooooo`0Cooooo`;o0000?Oooool2o`0001;ooooo0ol0000Booooo`;o00007oooool2o`00
01Wooooo0_l0000>ooooo`;o00006Oooool2o`0002Gooooo0_l0000Hooooo`;o00008_ooool001ko
oooo00?o0000ooooooooool0I_ooool2o`0001?ooooo0_l0000Oooooo`;o0000Joooool2o`0001So
oooo0_l0000Rooooo`007_ooool00ol0003oooooooooo`1Vooooo`;o00008oooool2o`0000oooooo
0_l0000Cooooo`;o00005Oooool2o`0007gooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0
000Kooooo`;o00002Oooool2o`0004[ooooo0_l0000?ooooo`;o00001Oooool2o`0000cooooo0_l0
000Eooooo`;o0000OOooool001kooooo00?o0000ooooooooool05oooool2o`0001Gooooo0_l00004
ooooo`;o00002Oooool2o`0006;ooooo0_l0000=ooooo`;o0000Toooool001kooooo00?o0000oooo
ooooool0;_ooool2o`0008;ooooo0_l0001Wooooo`;o0000:_ooool001kooooo00?o0000oooooooo
ool02_ooool2o`0000gooooo0_l0003Sooooo`;o00006?ooool2o`000003ooooool0003o000002[o
oooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0000=ooooo`;o0000Ooooool4o`00063ooooo
0_l0000:ooooo`;o00003?ooool2o`0002gooooo000Nooooo`03o`000?oooooooooo09[ooooo1?l0
00000ooooooo0000o`00001Yooooo`;o0000>oooool001kooooo0_l0002Pooooo`;o00005oooool3
o`0007oooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`0^ooooo`;o00004oooool2o`00
07?ooooo0ol0001;ooooo`;o0000<_ooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo02ko
oooo0_l0000Cooooo`;o00003Oooool2o`0002[ooooo0_l0001;ooooo`;o0000>Oooool2o`0003;o
oooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`1Booooo`;o0000:_ooool2o`0000gooooo
0_l0000>ooooo`;o00006oooool2o`0000oooooo0_l0001jooooo`007_ooool00ol0003ooooooooo
o`2=ooooo`;o00003_ooool2o`0001_ooooo0_l0000`ooooo`;o0000=?ooool2o`0002?ooooo000N
ooooo`03o`000?oooooooooo0<Oooooo0_l0000Sooooo`;o00008Oooool2o`00017ooooo0_l0000J
ooooo`;o00001oooool001kooooo00?o0000ooooooooool06_ooool2o`000:_ooooo0_l00016oooo
o`;o00003?ooool2o`0000Wooooo0_l000000ooooooo0000o`000005ooooo`;o00002_ooool2o`00
00Oooooo000Nooooo`;o00004Oooool2o`0000Sooooo0_l0003Mooooo`;o00008_ooool2o`0000Wo
oooo0_l000000ooooooo0000o`000005ooooo`;o00004oooool001kooooo0_l00006ooooo`;o0000
2Oooool2o`000=kooooo0_l00007ooooo`Co0000B_ooool001kooooo00?o0000ooooooooool01Ooo
ool2o`0006?ooooo0_l0001Dooooo`;o0000:Oooool2o`0000?ooooo0_l00009ooooo`;o0000B_oo
ool001kooooo00?o0000ooooooooool08Oooool2o`0003Gooooo0_l0000@ooooo`;o0000<oooool2
o`0000cooooo0_l0000Aooooo`;o00005Oooool2o`0001;ooooo0_l0000;ooooo`;o0000COooool0
01kooooo00?o0000ooooooooool01oooool2o`0001Sooooo0_l0000=ooooo`;o00009_ooool3o`00
04Cooooo0_l0000<ooooo`Co00009_ooool2o`0001oooooo0_l0001=ooooo`007_ooool00ol0003o
ooooooooo`07ooooo`;o00009oooool3o`0002Kooooo0_l0000Eooooo`;o00009Oooool2o`0001Ko
oooo0_l000000ooooooo0000o`00000nooooo`;o0000Doooool001kooooo00?o0000ooooooooool0
<Oooool2o`0003gooooo0_l0000Uooooo`;o00003Oooool2o`0000[ooooo0_l0000nooooo`;o0000
:Oooool2o`0002Sooooo000Nooooo`03o`000?oooooooooo04kooooo0_l0000Pooooo`;o0000<?oo
ool2o`0000;ooooo0_l0000Rooooo`;o0000=Oooool2o`0000gooooo0_l0000;ooooo`;o0000:?oo
ool001kooooo00?o0000ooooooooool03Oooool2o`0003oooooo0_l0000Pooooo`;o0000<?ooool2
o`0002Kooooo0_l0000`ooooo`;o00000oooool2o`0000gooooo0_l0000eooooo`007_ooool2o`00
00kooooo0_l0001Tooooo`;o0000C_ooool2o`0001gooooo0_l0000Aooooo`;o00001Oooool2o`00
04Wooooo000Nooooo`03o`000?oooooooooo07?ooooo0_l0001>ooooo`;o00007Oooool2o`00017o
oooo0_l0001@ooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o0000Z_ooool2o`0008Kooooo
000Nooooo`03o`000?oooooooooo01?ooooo0_l0000looooo`;o00003oooool2o`0005_ooooo0_l0
0003ooooo`;o0000:oooool2o`0005Cooooo000Nooooo`03o`000?oooooooooo04Kooooo0_l00009
ooooo`;o00003oooool2o`00063ooooo0_l00002ooooo`;o00009oooool2o`0005Cooooo000Noooo
o`04o`000?ooooooooooooooo`;o00007Oooool2o`0002Cooooo0_l0000oooooo`;o0000?oooool2
o`0006kooooo0_l0000=ooooo`007_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l0000I
ooooo`;o0000?oooool2o`0002Cooooo0_l0000mooooo`;o0000L?ooool2o`0000gooooo000Noooo
o`03o`000?oooooooooo00Gooooo0_l0001Jooooo`;o0000Hoooool2o`0006Cooooo0_l0000Ioooo
o`007_ooool00ol0003oooooooooo`24ooooo`;o00009oooool2o`0001Wooooo0_l00017ooooo`;o
00006Oooool2o`0001Wooooo000Nooooo`03o`000?oooooooooo08Cooooo0_l0000Wooooo`;o0000
6Oooool2o`00033ooooo0_l0000Eooooo`;o00005?ooool2o`0001kooooo000Nooooo`03o`000?oo
oooooooo01Wooooo0_l0000Jooooo`;o0000IOooool2o`0005cooooo0_l0000[ooooo`;o00007_oo
ool001kooooo00?o0000ooooooooool06Oooool2o`0001[ooooo0_l0001Uooooo`;o00002Oooool2
o`0001Oooooo0_l0001Tooooo`;o00007oooool001kooooo00Co0000oooooooooooooooo0_l0000K
ooooo`;o00005Oooool2o`0002Gooooo0_l0000Kooooo`;o0000;?ooool2o`0001Oooooo0_l0001>
ooooo`;o00005?ooool2o`0001Cooooo0_l00009ooooo`007_ooool01?l0003oooooooooooooool2
o`0001Wooooo1?l0000looooo`;o00006oooool2o`0004;ooooo0_l0001<ooooo`;o00000oooool2
o`0002[ooooo0_l00009ooooo`005?ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooo
ooooool05Oooool2o`0000Gooooo0_l0002Mooooo`Co00003Oooool4o`0000gooooo0_l0000/oooo
o`;o0000>_ooool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Eooooo`;o
0000Y?ooool2o`0000oooooo1?l0000=ooooo`;o00001oooool2o`0005oooooo000Fooooo`03o`00
0?oooooooooo00Gooooo0ol0001iooooo`;o0000D_ooool2o`0001Oooooo0_l0001Oooooo`005_oo
ool00ol0003oooooooooo`21ooooo`;o0000D_ooool2o`0007Sooooo000Fooooo`03o`000?oooooo
oooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003o
ooooooooo`3ooooooe3ooooo000Dooooo`03oeEEEOmVIVKo00000?ooooooD_ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.70504 .49426 Mdot
.20239 .38272 Mdot
.76025 .45273 Mdot
.14286 .44444 Mdot
.4594 .28853 Mdot
.52854 .42038 Mdot
.73136 .27947 Mdot
.01967 .00702 Mdot
.01163 .45924 Mdot
.91318 .92537 Mdot
.40792 .54254 Mdot
.95629 .97295 Mdot
.36734 .69026 Mdot
.13009 .23966 Mdot
.93882 .60247 Mdot
.31489 .12738 Mdot
.82396 .0085 Mdot
.42744 .02365 Mdot
.83318 .06811 Mdot
.70668 .71494 Mdot
.09577 .25625 Mdot
.43912 .15621 Mdot
.03749 .0107 Mdot
.79473 .5204 Mdot
.36147 .96194 Mdot
.96475 .97347 Mdot
.03223 .0477 Mdot
.00628 .50149 Mdot
.54625 .36352 Mdot
.21946 .16046 Mdot
.42514 .03658 Mdot
.83492 .14594 Mdot
.96067 .06805 Mdot
.064 .28799 Mdot
.27291 .37814 Mdot
.97041 .10194 Mdot
.24643 .14505 Mdot
.28406 .45505 Mdot
.8292 .39477 Mdot
.59375 .62173 Mdot
.62637 .65992 Mdot
.01665 .16752 Mdot
.54948 .35679 Mdot
.51644 .64667 Mdot
.88637 .56634 Mdot
.10443 .73614 Mdot
.29978 .50772 Mdot
.83755 .90393 Mdot
.43657 .07761 Mdot
.84436 .12631 Mdot
.89861 .00908 Mdot
.56206 .84671 Mdot
.96223 .67546 Mdot
.25525 .35863 Mdot
.75594 .00289 Mdot
.07052 .37725 Mdot
.26573 .09079 Mdot
.61716 .99009 Mdot
.60354 .22594 Mdot
.47537 .39206 Mdot
.8336 .84395 Mdot
.93266 .96153 Mdot
.24092 .47778 Mdot
.6385 .45492 Mdot
.96395 .16059 Mdot
.07136 .79554 Mdot
.48019 .44919 Mdot
.35249 .06269 Mdot
.58835 .07543 Mdot
.05899 .40189 Mdot
.32923 .14702 Mdot
.93647 .33659 Mdot
.08333 .03707 Mdot
.32507 .10266 Mdot
.22968 .23138 Mdot
.00624 .95818 Mdot
.91997 .368 Mdot
.58909 .49223 Mdot
.1387 .60509 Mdot
.88545 .06345 Mdot
.22269 .84294 Mdot
.17173 .37464 Mdot
.26439 .37986 Mdot
.56097 .30834 Mdot
.82528 .67952 Mdot
.55573 .94817 Mdot
.92203 .12105 Mdot
.86749 .29952 Mdot
.29654 .42217 Mdot
.98002 .11344 Mdot
.51347 .47051 Mdot
.40959 .38025 Mdot
.94566 .02445 Mdot
.95347 .68858 Mdot
.03147 .30016 Mdot
.7349 .03866 Mdot
.88298 .95653 Mdot
.50853 .74655 Mdot
.64373 .17435 Mdot
.89948 .76009 Mdot
.98877 .04164 Mdot
.63192 .95522 Mdot
.79951 .22394 Mdot
.53506 .9044 Mdot
.54155 .9565 Mdot
.26596 .88164 Mdot
.84543 .34302 Mdot
.22823 .19293 Mdot
.27425 .05213 Mdot
.0537 .1155 Mdot
.28458 .55665 Mdot
.82695 .00748 Mdot
.62407 .84272 Mdot
.52781 .37331 Mdot
.52674 .92555 Mdot
.3288 .83502 Mdot
.65877 .61932 Mdot
.71186 .60972 Mdot
.46943 .98762 Mdot
.13571 .79403 Mdot
.56815 .55748 Mdot
.4453 .97036 Mdot
.92402 .62905 Mdot
.30524 .62363 Mdot
.62211 .1174 Mdot
.11738 .92776 Mdot
.8294 .58491 Mdot
.47973 .40343 Mdot
.50353 .63823 Mdot
.06881 .4651 Mdot
.65196 .35394 Mdot
.63173 .04587 Mdot
.8411 .45056 Mdot
.49248 .40752 Mdot
.24142 .46788 Mdot
.90647 .42811 Mdot
.25494 .62357 Mdot
.08081 .85756 Mdot
.10917 .36281 Mdot
.31797 .09874 Mdot
.93536 .04978 Mdot
.56293 .96099 Mdot
.60521 .42584 Mdot
.64394 .58598 Mdot
.42403 .65964 Mdot
.4573 .52219 Mdot
.53415 .87289 Mdot
.20661 .80003 Mdot
.62427 .92786 Mdot
.43967 .25216 Mdot
.1589 .84328 Mdot
.797 .85436 Mdot
.92468 .43117 Mdot
.57676 .17408 Mdot
.6409 .30945 Mdot
.59179 .2683 Mdot
.83896 .02132 Mdot
.51712 .37666 Mdot
.96839 .84006 Mdot
.9324 .90373 Mdot
.66615 .24309 Mdot
.78351 .32341 Mdot
.15605 .79292 Mdot
.73233 .81472 Mdot
.93626 .00089 Mdot
.48167 .31369 Mdot
.63865 .33854 Mdot
.5597 .39271 Mdot
.45258 .64623 Mdot
.78229 .69156 Mdot
.79206 .43383 Mdot
.49749 .4783 Mdot
.48015 .53875 Mdot
.98956 .4773 Mdot
.60739 .07402 Mdot
.57426 .34665 Mdot
.34528 .73378 Mdot
.41163 .38018 Mdot
.99828 .74935 Mdot
.18658 .31232 Mdot
.23859 .73843 Mdot
.01238 .28084 Mdot
.10478 .59639 Mdot
.20453 .11699 Mdot
.9708 .70945 Mdot
.91584 .34163 Mdot
.6798 .00729 Mdot
.62777 .30652 Mdot
.00617 .92154 Mdot
.52484 .63914 Mdot
.32582 .47529 Mdot
.68719 .64045 Mdot
.4235 .40541 Mdot
.90926 .06031 Mdot
.97138 .182 Mdot
.38721 .23791 Mdot
.73661 .11777 Mdot
.15072 .56271 Mdot
.36837 .44561 Mdot
.22122 .55736 Mdot
.96853 .1949 Mdot
.05187 .61545 Mdot
.98249 .42783 Mdot
.03575 .62897 Mdot
.22116 .30705 Mdot
.48333 .27332 Mdot
.57461 .80335 Mdot
.78017 .33741 Mdot
.56844 .03534 Mdot
.91249 .40983 Mdot
.5543 .90293 Mdot
.35026 .52632 Mdot
.21406 .34577 Mdot
.95265 .54144 Mdot
.6023 .62611 Mdot
.23095 .56337 Mdot
.03994 .64003 Mdot
.40931 .01033 Mdot
.77358 .51768 Mdot
.03922 .99209 Mdot
.945 .79374 Mdot
.45536 .89184 Mdot
.68695 .2403 Mdot
.80614 .05107 Mdot
.16371 .55592 Mdot
.18966 .84023 Mdot
.23354 .2377 Mdot
.6166 .9394 Mdot
.84658 .22191 Mdot
.49291 .23664 Mdot
.36454 .38954 Mdot
.09715 .96359 Mdot
.06883 .28484 Mdot
.00036 .38109 Mdot
.71762 .71302 Mdot
.90603 .02792 Mdot
.89392 .84811 Mdot
.03366 .52819 Mdot
.32886 .96818 Mdot
.11427 .21952 Mdot
.83383 .02043 Mdot
.98794 .30473 Mdot
.79185 .31323 Mdot
.54085 .01242 Mdot
.37021 .30096 Mdot
.84878 .28279 Mdot
.95548 .25732 Mdot
.6444 .9546 Mdot
.79218 .09844 Mdot
.32351 .76047 Mdot
.07299 .80575 Mdot
.82284 .83403 Mdot
.58793 .08883 Mdot
.56231 .22728 Mdot
.47257 .49754 Mdot
.68677 .51845 Mdot
.79615 .87106 Mdot
.13338 .52844 Mdot
.07925 .96044 Mdot
.78073 .30995 Mdot
.03734 .5243 Mdot
.20837 .86289 Mdot
.65234 .07194 Mdot
.70863 .3725 Mdot
.38459 .62646 Mdot
.87754 .83324 Mdot
.57061 .42485 Mdot
.51843 .97314 Mdot
.4879 .26657 Mdot
.00634 .08517 Mdot
.98436 .63431 Mdot
.55162 .09052 Mdot
.29545 .77632 Mdot
.96019 .88346 Mdot
.35925 .38912 Mdot
.60089 .90688 Mdot
.29863 .42451 Mdot
.42502 .36121 Mdot
.40519 .26704 Mdot
.59417 .77952 Mdot
.30895 .7328 Mdot
.89928 .35985 Mdot
.96658 .37885 Mdot
.0365 .934 Mdot
.05655 .9654 Mdot
.75545 .68801 Mdot
.40204 .23572 Mdot
.46876 .12103 Mdot
.48737 .51517 Mdot
.37981 .40438 Mdot
.37505 .88187 Mdot
.48497 .98909 Mdot
.40605 .53069 Mdot
.82522 .96353 Mdot
.08287 .75831 Mdot
.49469 .65528 Mdot
.33322 .17242 Mdot
.11311 .6546 Mdot
.32522 .22758 Mdot
.32812 .84758 Mdot
.55384 .03413 Mdot
.31385 .10705 Mdot
.52292 .80539 Mdot
.51268 .76628 Mdot
.40732 .94282 Mdot
.95086 .17033 Mdot
.94966 .79825 Mdot
.118 .83025 Mdot
.26319 .99072 Mdot
.3835 .85669 Mdot
.30251 .45503 Mdot
.38761 .35261 Mdot
.43042 .77108 Mdot
.40788 .62425 Mdot
.3456 .64489 Mdot
.56866 .49755 Mdot
.60651 .02659 Mdot
.318 .97726 Mdot
.91844 .89678 Mdot
.83531 .45245 Mdot
.3471 .20752 Mdot
.79565 .29645 Mdot
.71119 .38377 Mdot
.08938 .26233 Mdot
.90236 .98468 Mdot
.0084 .32839 Mdot
.88477 .00687 Mdot
.74218 .1487 Mdot
.99583 .27011 Mdot
.73328 .83229 Mdot
.41376 .10069 Mdot
.59439 .72136 Mdot
.75139 .20767 Mdot
.11472 .08469 Mdot
.39071 .12419 Mdot
.71303 .18158 Mdot
.08262 .4906 Mdot
.35335 .53332 Mdot
.54301 .19373 Mdot
.9623 .74068 Mdot
.18123 .19664 Mdot
.51806 .57498 Mdot
.13854 .76562 Mdot
.66209 .55303 Mdot
.01648 .25928 Mdot
.8338 .79241 Mdot
.0225 .42562 Mdot
.84445 .27197 Mdot
.59582 .26483 Mdot
.78069 .41901 Mdot
.40321 .81436 Mdot
.49178 .05432 Mdot
.84449 .30658 Mdot
.26759 .80121 Mdot
.36117 .81245 Mdot
.29296 .91128 Mdot
.6349 .23368 Mdot
.79964 .78233 Mdot
.93315 .48929 Mdot
.70579 .83835 Mdot
.00828 .51348 Mdot
.1832 .09388 Mdot
.98629 .43344 Mdot
.36505 .34134 Mdot
.78605 .78529 Mdot
.41879 .91391 Mdot
.03019 .33201 Mdot
.75487 .27522 Mdot
.75613 .3681 Mdot
.6429 .15103 Mdot
.18566 .53934 Mdot
.66208 .99479 Mdot
.81641 .30935 Mdot
.75444 .60833 Mdot
.17925 .58539 Mdot
.0926 .55566 Mdot
.67526 .44982 Mdot
.00571 .37606 Mdot
.26883 .81424 Mdot
.91868 .35543 Mdot
.78989 .78137 Mdot
.61419 .53115 Mdot
.95176 .89949 Mdot
.63835 .16598 Mdot
.81863 .22003 Mdot
.17581 .25806 Mdot
.99076 .92637 Mdot
.42165 .39527 Mdot
.99377 .13281 Mdot
.10313 .3622 Mdot
.02051 .97032 Mdot
.5431 .64903 Mdot
.52733 .49907 Mdot
.6043 .41735 Mdot
.20441 .9758 Mdot
.31922 .5595 Mdot
.74464 .4437 Mdot
.78337 .96309 Mdot
.06564 .88017 Mdot
.71633 .2551 Mdot
.77412 .40009 Mdot
.18012 .24546 Mdot
.43004 .12179 Mdot
.0209 .89919 Mdot
.20812 .2627 Mdot
.74122 .1471 Mdot
.71143 .61426 Mdot
.13991 .93717 Mdot
.27085 .80364 Mdot
.03559 .60621 Mdot
.54094 .27179 Mdot
.67314 .06906 Mdot
.08653 .18926 Mdot
.11944 .51331 Mdot
.35309 .38213 Mdot
.80059 .94023 Mdot
.76739 .82623 Mdot
.32696 .48482 Mdot
.79825 .53766 Mdot
.90989 .88708 Mdot
.80262 .36719 Mdot
.5323 .92541 Mdot
.97761 .75932 Mdot
.13518 .21636 Mdot
.1747 .93976 Mdot
.3332 .40385 Mdot
.26187 .86614 Mdot
.19794 .17831 Mdot
.12372 .67857 Mdot
.52286 .3864 Mdot
.034 .50868 Mdot
.2748 .81784 Mdot
.55417 .81293 Mdot
.48202 .54892 Mdot
.2145 .3724 Mdot
.63336 .68663 Mdot
.35713 .11914 Mdot
.63406 .62122 Mdot
.79065 .59011 Mdot
.12107 .11934 Mdot
.28312 .55822 Mdot
.28143 .41205 Mdot
.93477 .6782 Mdot
.32551 .94921 Mdot
.71803 .50416 Mdot
.52415 .0745 Mdot
.15403 .48697 Mdot
.53236 .70911 Mdot
.17358 .71155 Mdot
.16339 .42157 Mdot
.01375 .45048 Mdot
.7041 .66818 Mdot
.43973 .57151 Mdot
.69853 .91707 Mdot
.17068 .21084 Mdot
.73699 .26272 Mdot
.77464 .30723 Mdot
.56564 .88684 Mdot
.94647 .49862 Mdot
.69038 .86056 Mdot
.45159 .179 Mdot
.15707 .09259 Mdot
.70305 .049 Mdot
.14805 .76517 Mdot
.96735 .13736 Mdot
.76492 .19026 Mdot
.48831 .23114 Mdot
.37575 .21268 Mdot
.03127 .21431 Mdot
.10255 .00845 Mdot
.42508 .34631 Mdot
.7214 .46635 Mdot
.64593 .90199 Mdot
.19647 .07426 Mdot
.22123 .20826 Mdot
.74614 .6737 Mdot
.90797 .75584 Mdot
.30351 .82586 Mdot
.09993 .84415 Mdot
.63504 .9487 Mdot
.40451 .94154 Mdot
.77621 .59269 Mdot
.68428 .27016 Mdot
.4064 .79423 Mdot
.34771 .04067 Mdot
.88794 .38113 Mdot
.79269 .14873 Mdot
.86671 .05833 Mdot
.55156 .05879 Mdot
.90237 .53814 Mdot
.10847 .52503 Mdot
.59339 .29116 Mdot
.02697 .98103 Mdot
.47437 .03278 Mdot
.09596 .3605 Mdot
.43936 .88023 Mdot
.05435 .01 Mdot
.87935 .18693 Mdot
.63084 .14277 Mdot
.72664 .45946 Mdot
.76044 .80175 Mdot
.5227 .2627 Mdot
.33598 .88754 Mdot
.24905 .64388 Mdot
.97123 .30413 Mdot
.43824 .336 Mdot
.22366 .6119 Mdot
.66783 .77415 Mdot
.77946 .26428 Mdot
.07687 .23397 Mdot
.85445 .76713 Mdot
.66138 .45281 Mdot
.42923 .3132 Mdot
.8457 .50032 Mdot
.76506 .10049 Mdot
.92848 .16357 Mdot
.44334 .15139 Mdot
.86484 .52232 Mdot
.60219 .83005 Mdot
.87974 .11059 Mdot
.10926 .8765 Mdot
.52122 .16612 Mdot
.97643 .76924 Mdot
.1626 .38736 Mdot
.86399 .15644 Mdot
.01126 .59623 Mdot
.82241 .67296 Mdot
.42431 .07874 Mdot
.00743 .87277 Mdot
.86463 .86049 Mdot
.10833 .75789 Mdot
.65545 .42032 Mdot
.3195 .18972 Mdot
.79295 .52835 Mdot
.0357 .08633 Mdot
.90402 .45355 Mdot
.81169 .62879 Mdot
.57518 .18801 Mdot
.31688 .2922 Mdot
.52867 .85254 Mdot
.91577 .73371 Mdot
.91164 .32684 Mdot
.53699 .63411 Mdot
.00153 .57713 Mdot
.54641 .82864 Mdot
.51912 .72605 Mdot
.78751 .41061 Mdot
.28937 .93289 Mdot
.7266 .45424 Mdot
.06699 .03308 Mdot
.72087 .48479 Mdot
.21063 .50146 Mdot
.09675 .12443 Mdot
.58855 .53153 Mdot
.23001 .14526 Mdot
.31514 .27497 Mdot
.01231 .63612 Mdot
.09504 .24806 Mdot
.51653 .92653 Mdot
.47102 .98166 Mdot
.52709 .13973 Mdot
.72437 .25725 Mdot
.12267 .29745 Mdot
.14016 .0974 Mdot
.71873 .8568 Mdot
.84709 .91275 Mdot
.7638 .42404 Mdot
.86013 .97932 Mdot
.42835 .11464 Mdot
.13454 .42132 Mdot
.19438 .51835 Mdot
.34334 .13447 Mdot
.08046 .05842 Mdot
.91739 .50148 Mdot
.29603 .04902 Mdot
.49256 .71046 Mdot
.29796 .87753 Mdot
.89409 .15552 Mdot
.14253 .14823 Mdot
.39057 .47956 Mdot
.01429 .34971 Mdot
.96004 .36884 Mdot
.46763 .15228 Mdot
.86204 .93149 Mdot
.67937 .82935 Mdot
.66291 .10751 Mdot
.75961 .04524 Mdot
.82822 .71095 Mdot
.80563 .8594 Mdot
.18275 .24591 Mdot
.38048 .06293 Mdot
.12277 .06575 Mdot
.64817 .39747 Mdot
.88511 .01926 Mdot
.8729 .50048 Mdot
.34073 .80757 Mdot
.50831 .02847 Mdot
.41104 .37727 Mdot
.08865 .64768 Mdot
.22791 .9865 Mdot
.92103 .0828 Mdot
.38145 .07631 Mdot
.87212 .39464 Mdot
.90444 .35269 Mdot
.57802 .66337 Mdot
.389 .62296 Mdot
.29349 .79153 Mdot
.37762 .48873 Mdot
.06769 .08509 Mdot
.65877 .81485 Mdot
.4131 .08011 Mdot
.74121 .11464 Mdot
.11554 .26196 Mdot
.68424 .69462 Mdot
.57565 .21676 Mdot
.45342 .70727 Mdot
.72668 .88489 Mdot
.41931 .38228 Mdot
.05428 .80103 Mdot
.74939 .5681 Mdot
.66123 .36551 Mdot
.40303 .42718 Mdot
.59042 .98954 Mdot
.35546 .59679 Mdot
.08857 .03354 Mdot
.97462 .52666 Mdot
.87134 .12191 Mdot
.19763 .50498 Mdot
.48313 .52926 Mdot
.12108 .39196 Mdot
.03962 .42032 Mdot
.03573 .45963 Mdot
.06021 .40656 Mdot
.94475 .72537 Mdot
.81775 .07778 Mdot
.96411 .45523 Mdot
.01205 .71743 Mdot
.64881 .59164 Mdot
.78747 .96344 Mdot
.0797 .79962 Mdot
.65746 .72025 Mdot
.32411 .66444 Mdot
.25505 .64269 Mdot
.87515 .85411 Mdot
.89038 .90746 Mdot
.63935 .76948 Mdot
.41994 .14376 Mdot
.99533 .61576 Mdot
.6996 .08805 Mdot
.04144 .67873 Mdot
.59621 .77323 Mdot
.28373 .24189 Mdot
.25599 .69446 Mdot
.64273 .95097 Mdot
.63771 .39805 Mdot
.04528 .71127 Mdot
.46113 .19367 Mdot
.73884 .29362 Mdot
.34936 .37185 Mdot
.4722 .3968 Mdot
.89565 .98127 Mdot
.03176 .35912 Mdot
.00895 .86152 Mdot
.11918 .40853 Mdot
.09138 .80258 Mdot
.12652 .19789 Mdot
.79823 .07146 Mdot
.42561 .73784 Mdot
.07558 .2014 Mdot
.31718 .14006 Mdot
.05617 .47553 Mdot
.2517 .39799 Mdot
.4755 .87908 Mdot
.85326 .36747 Mdot
.09276 .68109 Mdot
.06843 .57835 Mdot
.68239 .58192 Mdot
.61025 .12541 Mdot
.19299 .86431 Mdot
.5265 .65704 Mdot
.76752 .98107 Mdot
.8343 .29717 Mdot
.38418 .17067 Mdot
.95244 .54983 Mdot
.26626 .97559 Mdot
.75617 .49989 Mdot
.85276 .6156 Mdot
.04434 .2361 Mdot
.48467 .71796 Mdot
.08024 .81791 Mdot
.00928 .14079 Mdot
.91238 .81144 Mdot
.56863 .45547 Mdot
.77206 .22867 Mdot
.51686 .61792 Mdot
.10833 .33523 Mdot
.94231 .32658 Mdot
.68876 .50038 Mdot
.42346 .37929 Mdot
.94333 .58931 Mdot
.59735 .03742 Mdot
.57912 .12649 Mdot
.2635 .53629 Mdot
.90963 .63972 Mdot
.02906 .40005 Mdot
.87408 .08168 Mdot
.84952 .10847 Mdot
.37961 .40445 Mdot
.59091 .11406 Mdot
.03414 .19516 Mdot
.5015 .381 Mdot
.41144 .30961 Mdot
.57882 .71275 Mdot
.57293 .87399 Mdot
.00546 .81709 Mdot
.27365 .57287 Mdot
.30776 .13162 Mdot
.71441 .16243 Mdot
.10111 .33547 Mdot
.02111 .46018 Mdot
.83818 .92296 Mdot
.65988 .55646 Mdot
.67597 .20208 Mdot
.5651 .56573 Mdot
.42757 .83945 Mdot
.33271 .06379 Mdot
.69655 .66766 Mdot
.69217 .20703 Mdot
.71989 .91989 Mdot
.28552 .37647 Mdot
.34775 .28893 Mdot
.96287 .60024 Mdot
.09402 .72481 Mdot
.62776 .7479 Mdot
.11893 .14991 Mdot
.80572 .81105 Mdot
.0815 .02507 Mdot
.79001 .02759 Mdot
.69821 .66022 Mdot
.44475 .54311 Mdot
.30557 .0493 Mdot
.47668 .4976 Mdot
.66628 .44599 Mdot
.14274 .19819 Mdot
.86192 .0868 Mdot
.7973 .1942 Mdot
.37983 .57587 Mdot
.73811 .70605 Mdot
.58724 .25766 Mdot
.27405 .97423 Mdot
.59332 .89651 Mdot
.49587 .75541 Mdot
.6651 .19039 Mdot
.39666 .91725 Mdot
.66019 .05719 Mdot
.55037 .03523 Mdot
.08293 .25613 Mdot
.38848 .15778 Mdot
.37468 .34953 Mdot
.32735 .17501 Mdot
.09467 .76278 Mdot
.44529 .50927 Mdot
.19321 .19004 Mdot
.63285 .11672 Mdot
.23289 .71938 Mdot
.57518 .88327 Mdot
.93379 .99272 Mdot
.36257 .52784 Mdot
.51413 .42777 Mdot
.6606 .68166 Mdot
.46639 .40604 Mdot
.93341 .17673 Mdot
.03893 .24567 Mdot
.14325 .95524 Mdot
.1984 .42863 Mdot
.87675 .52827 Mdot
.59123 .36075 Mdot
.9656 .01916 Mdot
.31454 .74479 Mdot
.95839 .79726 Mdot
.13904 .00805 Mdot
.98924 .44134 Mdot
.29241 .97275 Mdot
.8019 .94342 Mdot
.61444 .97226 Mdot
.28384 .27447 Mdot
.73473 .91555 Mdot
.76482 .42212 Mdot
.48434 .16627 Mdot
.09929 .15487 Mdot
.79136 .15219 Mdot
.80354 .69532 Mdot
.05033 .47757 Mdot
.08009 .57503 Mdot
.38698 .23114 Mdot
.97551 .37248 Mdot
.11212 .5844 Mdot
.38035 .34471 Mdot
.00279 .99528 Mdot
.95838 .57793 Mdot
.86463 .45495 Mdot
.54179 .12173 Mdot
.36407 .97614 Mdot
.08034 .75753 Mdot
.65769 .83915 Mdot
.6631 .85745 Mdot
.61439 .91241 Mdot
.30845 .169 Mdot
.82334 .02065 Mdot
.28639 .10583 Mdot
.52403 .34336 Mdot
.65725 .18181 Mdot
.30052 .56262 Mdot
.74328 .78404 Mdot
.30979 .88549 Mdot
.05756 .33655 Mdot
.26609 .76738 Mdot
.04762 .19162 Mdot
.01536 .13937 Mdot
.44959 .67501 Mdot
.50283 .81671 Mdot
.51436 .90538 Mdot
.7193 .13942 Mdot
.19134 .01494 Mdot
.64251 .2537 Mdot
.67089 .58273 Mdot
.05498 .64579 Mdot
.33228 .8808 Mdot
.07447 .26706 Mdot
.58386 .02439 Mdot
.73297 .40701 Mdot
.827 .0209 Mdot
.56327 .93234 Mdot
.65217 .81863 Mdot
.55085 .47267 Mdot
.13708 .1095 Mdot
.19747 .943 Mdot
.78945 .91851 Mdot
.83942 .90811 Mdot
.09293 .7117 Mdot
.03752 .97286 Mdot
.83968 .96236 Mdot
.03003 .24688 Mdot
.71396 .64034 Mdot
.78276 .58865 Mdot
.39139 .53993 Mdot
.92495 .43392 Mdot
.87563 .72903 Mdot
.42431 .22295 Mdot
.8255 .13174 Mdot
.27193 .60902 Mdot
.36507 .14528 Mdot
.85284 .95969 Mdot
.80712 .46812 Mdot
.51067 .37335 Mdot
.80688 .11579 Mdot
.0488 .42928 Mdot
.1065 .25742 Mdot
.44436 .34096 Mdot
.54639 .26494 Mdot
.75229 .803 Mdot
.41366 .42455 Mdot
.80993 .84115 Mdot
.72094 .99174 Mdot
.65085 .2034 Mdot
.21212 .20684 Mdot
.80666 .09949 Mdot
.02015 .39286 Mdot
.08209 .37518 Mdot
.61049 .75531 Mdot
.95931 .35798 Mdot
.41776 .19375 Mdot
.8656 .90276 Mdot
.64022 .0955 Mdot
.41553 .68446 Mdot
.27508 .38312 Mdot
.49844 .85542 Mdot
.43437 .89054 Mdot
.34155 .02957 Mdot
.04238 .84386 Mdot
.57488 .35733 Mdot
.74328 .71638 Mdot
.93659 .67923 Mdot
.02338 .23011 Mdot
.72214 .09812 Mdot
.04964 .50807 Mdot
.64746 .08749 Mdot
.16846 .4081 Mdot
.50564 .90171 Mdot
.40509 .23063 Mdot
.83399 .22762 Mdot
.66991 .74526 Mdot
.59382 .15863 Mdot
.61869 .64304 Mdot
.29139 .18319 Mdot
.84676 .11302 Mdot
.9238 .36806 Mdot
.53612 .94656 Mdot
.94271 .56439 Mdot
.66358 .8616 Mdot
.12528 .32914 Mdot
.92195 .34401 Mdot
.62708 .8192 Mdot
.57039 .91713 Mdot
.73376 .98366 Mdot
.64869 .59056 Mdot
.06728 .50451 Mdot
.00923 .1647 Mdot
.4509 .84545 Mdot
.2171 .52577 Mdot
.84841 .92757 Mdot
.8948 .32988 Mdot
.38835 .91214 Mdot
.65828 .72043 Mdot
.06682 .81215 Mdot
.43393 .48583 Mdot
.03481 .10647 Mdot
.49696 .25299 Mdot
.67446 .94823 Mdot
.74215 .74445 Mdot
.87541 .82989 Mdot
.17298 .56298 Mdot
.3284 .52616 Mdot
.97437 .53924 Mdot
.58354 .99308 Mdot
.63763 .47137 Mdot
.11422 .53441 Mdot
.88014 .69035 Mdot
.79962 .06657 Mdot
.7047 .78452 Mdot
.42936 .41678 Mdot
.67753 .69057 Mdot
.2869 .94963 Mdot
.80316 .7716 Mdot
.29573 .04676 Mdot
.57955 .54981 Mdot
.33509 .72578 Mdot
.23014 .70831 Mdot
.5085 .52236 Mdot
.01554 .39288 Mdot
.42586 .18421 Mdot
.63044 .92336 Mdot
.32145 .04149 Mdot
.64585 .95148 Mdot
.3678 .77311 Mdot
.14655 .48239 Mdot
.42659 .08241 Mdot
.27537 .27207 Mdot
.71661 .03516 Mdot
.40341 .23932 Mdot
.54286 .15653 Mdot
.95886 .172 Mdot
.84328 .63515 Mdot
.07085 .51391 Mdot
.85931 .92578 Mdot
.71963 .27563 Mdot
.80839 .78891 Mdot
.25336 .07139 Mdot
.73 .99863 Mdot
.35753 .48218 Mdot
.30322 .66131 Mdot
.30992 .59191 Mdot
.06565 .22983 Mdot
.91821 .08855 Mdot
.85993 .9247 Mdot
.5376 .25886 Mdot
.71707 .65618 Mdot
.10735 .60936 Mdot
.56609 .21594 Mdot
.52401 .89507 Mdot
.17295 .88717 Mdot
.5193 .08247 Mdot
.2228 .54393 Mdot
.5262 .83315 Mdot
.84252 .99611 Mdot
.24866 .03465 Mdot
.2207 .74569 Mdot
.37571 .4575 Mdot
.85547 .40273 Mdot
.6172 .10041 Mdot
.97205 .49412 Mdot
.77562 .96022 Mdot
.45375 .27886 Mdot
.62504 .53673 Mdot
.57488 .05544 Mdot
.81409 .06513 Mdot
.42997 .74061 Mdot
.83243 .3601 Mdot
.50365 .65645 Mdot
.10468 .58083 Mdot
.96448 .57484 Mdot
.83913 .79062 Mdot
.35544 .38306 Mdot
.37314 .49824 Mdot
.58534 .45375 Mdot
.05096 .64885 Mdot
.69797 .69573 Mdot
.88797 .97623 Mdot
.93866 .58678 Mdot
.75433 .93622 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`04o`000?oooooo0000o`00
00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00Sooooo0_l00003ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001ko
oooo00?o0000ooooooooool00_ooool2o`0000Wooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01_ooool2o`0000Go
oooo00?o0000ooooooooool03Oooool01?l0003oooooo`000?l0000=ooooo`03o`000?oooooooooo
00Gooooo0_l00006ooooo`03o`000?oooooooooo00Sooooo0_l00003ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003o
ooooooooo`02ooooo`;o00002_ooool2o`0000gooooo0_l0000:ooooo`;o0000E_ooool2o`0005Ko
oooo0_l0000]ooooo`?o00004Oooool2o`0000;ooooo0_l0000Uooooo`007_ooool00ol0003ooooo
ooooo`08ooooo`;o00001?ooool2o`0000gooooo0_l0000:ooooo`;o0000E_ooool2o`0002Wooooo
0_l0001Jooooo`;o00005_ooool2o`0002Gooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0
000`ooooo`;o0000L?ooool2o`0009Wooooo000Nooooo`03o`000?oooooooooo03[ooooo0_l0003P
ooooo`;o00006?ooool2o`0000oooooo000Nooooo`03o`000?oooooooooo0?oooooo2Oooool7o`00
00gooooo0_l0000Hooooo`;o00003oooool001kooooo00?o0000ooooooooool05_ooool2o`0006oo
oooo0_l0000aooooo`;o0000C?ooool7o`00023ooooo0_l0000Fooooo`007_ooool00ol0003ooooo
ooooo`0Fooooo`;o0000Koooool2o`0001Sooooo0_l0000Gooooo`;o00001Oooool2o`0003[ooooo
0_l0000Sooooo`;o00002oooool2o`0001Kooooo000Nooooo`03o`000?oooooooooo06_ooooo0_l0
000dooooo`;o00007_ooool2o`0003[ooooo0_l0000Sooooo`;o00008oooool001kooooo00?o0000
ooooooooool04_ooool2o`0000Gooooo0_l0000booooo`;o00007?ooool2o`0002Wooooo0_l0000G
ooooo`?o0000<oooool2o`00063ooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l00003oooo
o`Co0000<_ooool2o`0003Oooooo0_l0000>ooooo`;o00005oooool3o`0000?ooooo0_l00007oooo
o`;o00009Oooool2o`00063ooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0001Dooooo`;o
00005oooool2o`0002gooooo0_l00007ooooo`;o0000:oooool2o`0005[ooooo000Nooooo`03o`00
0?oooooooooo06Cooooo0_l00007ooooo`;o0000O?ooool2o`00053ooooo0_l00008ooooo`007_oo
ool00ol0003oooooooooo`1Looooo`;o00001_ooool2o`0006?ooooo0_l0000Xooooo`;o0000B?oo
ool2o`0000Sooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l0001Dooooo`;o000000?ooooo
o`000?l00000J?ooool2o`0001Gooooo0_l0000Aooooo`;o0000=oooool2o`0001Wooooo000Noooo
o`;o00001oooool2o`0004gooooo0_l00005ooooo`;o000000?oooooo`000?l00000Ooooool2o`00
023ooooo0_l0000Xooooo`;o00006Oooool001kooooo00?o0000ooooooooool0EOooool2o`0004Go
oooo0_l0000Iooooo`;o0000BOooool2o`0004?ooooo000Nooooo`03o`000?oooooooooo01Kooooo
0_l00024ooooo`;o00004Oooool2o`0000Kooooo0_l0000Jooooo`;o0000@Oooool2o`0002oooooo
000Nooooo`03o`000?oooooooooo01Kooooo0_l0001Fooooo`;o00002?ooool2o`0003Gooooo0_l0
000Rooooo`;o0000@Oooool2o`0000_ooooo0_l0000Rooooo`007_ooool00ol0003oooooooooo`0T
ooooo`;o0000@_ooool2o`0000Cooooo0_l00008ooooo`;o0000Roooool2o`0001Gooooo0_l00005
ooooo`;o00008_ooool001kooooo00?o0000ooooooooool09?ooool2o`0004;ooooo0_l0001]oooo
o`;o00009oooool2o`0000?ooooo0_l00004ooooo`;o00003oooool2o`0001Kooooo0_l0000Aoooo
o`007_ooool00ol0003oooooooooo`1>ooooo`;o0000P?ooool2o`0000Gooooo0_l0000Vooooo`?o
00002Oooool2o`0002Oooooo0_l0000Aooooo`007_ooool00ol0003oooooooooo`0looooo`;o0000
4?ooool2o`0005Kooooo0_l0000Iooooo`;o00003Oooool2o`0002gooooo0_l00016ooooo`007_oo
ool00ol0003oooooooooo`0looooo`;o0000>_ooool2o`00013ooooo0_l0000Jooooo`;o00004ooo
ool2o`0000Cooooo0_l00013ooooo`;o0000?oooool001kooooo00?o0000ooooooooool0N?ooool2
o`0000Sooooo0_l00002ooooo`;o00000_ooool2o`0002oooooo0_l00019ooooo`;o0000?oooool0
01kooooo00?o0000ooooooooool0P_ooool2o`0000;ooooo0ol0000Looooo`;o0000LOooool2o`00
00gooooo0_l0000Nooooo`007_ooool3o`0000Oooooo0_l00009ooooo`;o00003Oooool2o`0006Co
oooo0_l0000Looooo`;o00009oooool2o`0004Cooooo0_l00002ooooo`;o00003Oooool2o`0001ko
oooo000Nooooo`?o00001oooool2o`0000Wooooo0_l0000=ooooo`;o0000S?ooool2o`0000[ooooo
0_l0000Aooooo`;o00003oooool2o`0003?ooooo0_l0000@ooooo`;o00007oooool001kooooo00?o
0000ooooooooool0;oooool2o`00027ooooo0_l0001Kooooo`;o00002_ooool2o`0002;ooooo0_l0
0015ooooo`;o00007oooool001kooooo00?o0000ooooooooool0;oooool2o`0000Kooooo0_l0000I
ooooo`;o0000N?ooool2o`0007Wooooo000Nooooo`03o`000?oooooooooo02Wooooo0_l0000<oooo
o`;o0000:_ooool2o`0006Oooooo0_l0000Iooooo`;o00005?ooool2o`0000?ooooo0_l00013oooo
o`007_ooool2o`0002[ooooo0_l0000hooooo`;o000000?oooooo`000?l000006_ooool2o`00047o
oooo0_l0000Pooooo`;o00003?ooool2o`0000Kooooo0_l00003ooooo`;o0000<oooool2o`0000ko
oooo000Nooooo`03o`000?oooooooooo05Wooooo0_l0000;ooooo`;o00006_ooool2o`00047ooooo
0_l0000^ooooo`;o0000@?ooool2o`0000kooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0
001@ooooo`;o00001oooool2o`0006oooooo0_l0000kooooo`;o0000=Oooool001kooooo00?o0000
ooooooooool01oooool2o`0001oooooo0_l0000hooooo`;o0000Koooool2o`0003_ooooo0_l00008
ooooo`;o0000:oooool001kooooo00?o0000ooooooooool0:?ooool2o`0005gooooo0_l0000coooo
o`;o0000;oooool2o`00023ooooo0_l00009ooooo`;o00007oooool2o`0000[ooooo000Nooooo`03
o`000?oooooooooo00gooooo0_l0000_ooooo`;o0000Aoooool2o`0003?ooooo0_l00008ooooo`;o
00000_ooool2o`0001oooooo1?l0000Cooooo`;o00002oooool2o`0002[ooooo0_l0000:ooooo`00
7_ooool00ol0003oooooooooo`0=ooooo`;o00005?ooool2o`0001Wooooo0_l0000`ooooo`;o0000
8_ooool2o`00033ooooo0_l00002ooooo`;o00007oooool2o`0001Gooooo0_l0000Tooooo`;o0000
7Oooool001kooooo00?o0000ooooooooool06oooool2o`0000Kooooo0_l0001;ooooo`;o00002Ooo
ool2o`0000_ooooo0_l0000:ooooo`;o00005_ooool2o`0006Wooooo0_l0000?ooooo`;o00007Ooo
ool001kooooo00?o0000ooooooooool06oooool2o`0004Gooooo0_l0000Gooooo`;o00002oooool2
o`0002;ooooo0_l0000:ooooo`;o00002?ooool2o`0004[ooooo0_l00007ooooo`;o0000;_ooool0
01kooooo00?o0000ooooooooool0H_ooool2o`0005Cooooo0_l00008ooooo`;o0000B_ooool2o`00
03Oooooo000Nooooo`03o`000?oooooooooo063ooooo0_l0002Vooooo`;o0000=Oooool2o`0000Ko
oooo000Nooooo`03o`000?oooooooooo063ooooo0_l0000:ooooo`;o0000V_ooool2o`0003Gooooo
0_l00006ooooo`007_ooool01?l0003oooooooooooooool2o`0006Wooooo0_l0000iooooo`;o0000
?Oooool2o`0004kooooo0_l0000?ooooo`007_ooool00ol0003oooooo`000003o`00063ooooo0_l0
0012ooooo`;o00008?ooool2o`0001_ooooo0_l0001>ooooo`;o00003oooool001kooooo00Co0000
ooooool0003o0000A_ooool2o`0000?ooooo0_l0000Eooooo`;o00003_ooool2o`0000oooooo0_l0
0013ooooo`;o0000@?ooool2o`0003[ooooo000Nooooo`03o`000?oooooooooo02[ooooo0_l0000K
ooooo`;o00000oooool2o`0001Wooooo0_l0000:ooooo`;o00003oooool2o`0006Oooooo0_l0000?
ooooo`;o00002oooool2o`0003[ooooo000Nooooo`;o00009?ooool2o`0000Gooooo0_l0000koooo
o`;o00008oooool2o`0003oooooo0_l0000Nooooo`;o00003oooool2o`0004Oooooo000Nooooo`03
o`000?oooooooooo01cooooo0_l00005ooooo`;o0000Ioooool2o`0000Kooooo0_l0000gooooo`;o
0000;_ooool2o`0004Sooooo000Nooooo`03o`000?oooooooooo01cooooo0_l0001Looooo`;o0000
3oooool2o`0000Oooooo0_l0000Fooooo`;o0000Coooool2o`0001Kooooo0_l00008ooooo`;o0000
9_ooool001kooooo00?o0000ooooooooool0@oooool2o`0003Gooooo0_l0000?ooooo`;o00007ooo
ool2o`0000oooooo0_l0001Fooooo`;o00002?ooool2o`0001Cooooo0_l0000@ooooo`007_ooool0
0ol0003oooooooooo`13ooooo`;o0000N?ooool2o`0002Gooooo0_l00014ooooo`;o00002Oooool2
o`00013ooooo000Nooooo`03o`000?oooooo000000?o0000U_ooool2o`0000[ooooo0_l0000Toooo
o`;o00005oooool2o`0004Cooooo0_l0000Kooooo`007_ooool00ol0003oooooo`000003o`0005go
oooo0_l0000gooooo`;o00002_ooool2o`0002Cooooo0_l0001Tooooo`;o00005?ooool001kooooo
00?o0000ooooooooool0H?ooool2o`0000Kooooo0_l0000?ooooo`;o0000]_ooool2o`000003oooo
ool0003o0000017ooooo000Nooooo`03o`000?oooooooooo06Kooooo1?l0000?ooooo`;o0000??oo
ool2o`0001Cooooo0_l0001Looooo`;o00001oooool2o`00017ooooo000Nooooo`03o`000?oooooo
oooo03cooooo0_l0000Xooooo`;o00009oooool2o`0002Kooooo0_l0000Dooooo`;o0000G?ooool2
o`0001[ooooo000Nooooo`03o`000?oooooooooo03cooooo0_l0001Aooooo`;o0000@Oooool2o`00
013ooooo0_l0001Booooo`;o00003Oooool001kooooo00?o0000ooooooooool0Foooool2o`0002Wo
oooo0_l0001:ooooo`;o00004?ooool2o`0005;ooooo0_l0000=ooooo`007_ooool00ol0003ooooo
ooooo`1Kooooo`;o0000:Oooool2o`0002oooooo0_l0001Qooooo`;o0000:oooool001kooooo00?o
0000ooooooooool02oooool2o`0000_ooooo0_l0000Qooooo`;o00009oooool2o`00057ooooo0_l0
000Kooooo`;o00007oooool2o`0002?ooooo0_l0000[ooooo`000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`07ooooo`;o00000_oo
ool2o`0000_ooooo0_l0000Qooooo`;o00002Oooool2o`0001cooooo0_l0000Nooooo`;o00003?oo
ool2o`0001Sooooo0_l0000Vooooo`;o00007oooool2o`0000Sooooo0_l0000fooooo`;o00003_oo
ool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^
k_ooooooA4A400Kooooo00?o0000ooooooooool01oooool2o`0001cooooo0_l00003ooooo`;o0000
2oooool2o`0000gooooo0_l0000looooo`;o00003?ooool2o`0001Sooooo0_l0001Aooooo`;o0000
=_ooool2o`0000kooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Q
onk^kP07ooooo`?o00009Oooool2o`0000?ooooo0_l0000;ooooo`;o0000ooooool?ooooo`000ooo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003ooooo
ooooo`0Dooooo`;o0000^Oooool2o`0000Oooooo0_l0001]ooooo`000oooool01Ol0003ooooooooo
oooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`0Dooooo`;o0000
:oooool2o`0008cooooo0_l00007ooooo`;o00000oooool2o`0006Sooooo0003ooooo`05oa0@4?oo
ooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo047ooooo
0_l000000ooooooo0000o`00000Wooooo`;o0000K_ooool2o`00017ooooo0_l0001Eooooo`000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03
o`000?oooooooooo03?ooooo0_l0000?ooooo`;o00009oooool2o`0000Oooooo0_l0001hooooo`;o
0000EOooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01_ooool00ol0003oooooooooo`06ooooo`;o00008?ooool2o`0000Wooooo0_l00011oooo
o`;o0000??ooool2o`00097ooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l0000Iooooo`;o
00001Oooool2o`0008[ooooo0_l000000ooooooo0000o`00002>ooooo`007_ooool00ol0003ooooo
ooooo`0Qooooo`;o0000U?ooool2o`0004gooooo0_l00007ooooo`;o0000=_ooool001kooooo00?o
0000ooooooooool0Q_ooool2o`0003Sooooo0_l0000nooooo`;o00001?ooool2o`0000Oooooo0_l0
000fooooo`007_ooool00ol0003oooooooooo`1Vooooo`;o00007_ooool2o`0002_ooooo0_l0000;
ooooo`;o0000=Oooool2o`0000Oooooo0_l00009ooooo`;o0000>_ooool001kooooo00?o0000oooo
ooooool00oooool2o`0000cooooo0_l0000dooooo`;o00007Oooool2o`0001;ooooo0_l00004oooo
o`;o00006Oooool2o`0001Kooooo0_l00012ooooo`;o00004_ooool2o`0003[ooooo000Nooooo`03
o`000?oooooooooo00?ooooo0_l0000<ooooo`;o00000_ooool2o`00033ooooo0_l0000aooooo`;o
00001?ooool2o`0001Wooooo0_l0000]ooooo`;o0000Noooool001kooooo00?o0000ooooooooool0
2_ooool2o`0000Wooooo0_l0000aooooo`;o0000<?ooool2o`0000?ooooo0_l0000Kooooo`;o0000
;?ooool2o`0007_ooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0000Jooooo`;o00008?oo
ool2o`00033ooooo0_l00003ooooo`;o00006oooool2o`0003gooooo0_l0001Zooooo`007_ooool0
0ol0003oooooooooo`0Vooooo`;o0000<?ooool2o`0002Gooooo0_l0001Cooooo`;o00001Oooool2
o`0006[ooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l000000ooooooo0000o`00000[oooo
o`?o00007oooool2o`0007[ooooo0_l0001aooooo`007_ooool00ol0003oooooooooo`06ooooo`;o
000000?oooooo`000?l000004?ooool2o`0001Wooooo0ol0003oooooo`oooooo000Nooooo`;o0000
7?ooool2o`0006kooooo0_l0000@ooooo`;o0000Z?ooool001kooooo00?o0000ooooooooool05ooo
ool2o`0000;ooooo0_l0001^ooooo`;o00004?ooool2o`0002kooooo0_l0000Fooooo`;o0000H?oo
ool001kooooo00Co0000oooooooooooooooo0_l0000Dooooo`;o00000_ooool2o`0000;ooooo0_l0
000Dooooo`;o0000M?ooool2o`0000kooooo0_l0000@ooooo`;o00005_ooool4o`0004[ooooo0_l0
000Booooo`007_ooool01?l0003oooooooooooooool2o`0001Kooooo0_l00004ooooo`Co00004_oo
ool2o`0000Wooooo0_l0001Tooooo`;o00000oooool2o`0000kooooo0_l0000Zooooo`;o00000_oo
ool2o`0004Kooooo0_l0000Booooo`007_ooool00ol0003oooooooooo`0Iooooo`;o00001_ooool2
o`0001gooooo0_l0001Tooooo`;o00001_ooool2o`0000kooooo0_l0000[ooooo`;o00003?ooool2
o`0004cooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0001Zooooo`;o00006Oooool2o`00
017ooooo0_l0000<ooooo`Co0000>Oooool2o`0004cooooo000Nooooo`03o`000?oooooooooo01Co
oooo0_l0000oooooo`;o0000:Oooool2o`0001Wooooo0_l0000?ooooo`;o00003_ooool2o`0001co
oooo0_l0000booooo`;o0000<?ooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo05Gooooo
0_l000000ooooooo0000o`000008ooooo`;o0000=Oooool2o`00017ooooo0_l0000/ooooo`;o0000
<_ooool2o`00033ooooo0_l00005ooooo`007_ooool00ol0003oooooooooo`1Hooooo`;o00002?oo
ool2o`0003Gooooo0_l0001;ooooo`;o00002Oooool2o`0005Cooooo000Nooooo`03o`000?oooooo
oooo00;o0000SOooool2o`0005Gooooo0_l00002ooooo`;o00001Oooool2o`0005Cooooo000Noooo
o`03o`000?oooooooooo00;o0000SOooool2o`0005Wooooo0_l0000Tooooo`;o0000=Oooool001ko
oooo00?o0000ooooooooool04_ooool2o`000?cooooo0_l0000eooooo`007_ooool00ol0003ooooo
ooooo`0Aooooo`?o0000FOooool2o`0002;ooooo0_l0002dooooo`007_ooool00ol0003ooooooooo
o`0Aooooo`;o0000D?ooool2o`0000Sooooo0_l0000Rooooo`;o0000:_ooool2o`0002gooooo0_l0
001Iooooo`007_ooool00ol0003oooooooooo`1Sooooo`;o0000F?ooool2o`0002gooooo0_l0000A
ooooo`;o0000A_ooool001kooooo00?o0000ooooooooool09?ooool2o`000=Wooooo0_l0000:oooo
o`;o00002Oooool2o`0002oooooo000Nooooo`;o00001oooool2o`0001cooooo0_l0001>ooooo`;o
0000UOooool2o`0000Wooooo0_l0000_ooooo`007_ooool00ol0003oooooooooo`06ooooo`;o0000
K?ooool2o`000<;ooooo0_l00003ooooo`;o00002?ooool001kooooo00?o0000ooooooooool0A?oo
ool2o`0006cooooo0_l0000Dooooo`;o0000;_ooool2o`0001Cooooo0_l0000Xooooo`;o00000ooo
ool2o`0000Sooooo000Nooooo`03o`000?oooooooooo04Cooooo0_l0000looooo`;o0000;_ooool2
o`0001Cooooo0_l00002ooooo`;o0000:_ooool4o`0000Wooooo0_l00007ooooo`;o0000=oooool0
01kooooo00?o0000ooooooooool0>Oooool2o`0004Oooooo0_l00003ooooo`;o00003oooool2o`00
03;ooooo0_l0000/ooooo`;o000000?oooooo`000?l000001_ooool2o`00043ooooo000Nooooo`03
o`000?oooooooooo03Wooooo0_l0001<ooooo`;o00003oooool2o`0006?ooooo0_l00018ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?_ooooo0_l0
001:ooooo`007_ooool00ol0003oooooooooo`3kooooo`;o00009oooool2o`0000Sooooo0_l0000G
ooooo`007_ooool01?l0003oooooo`000?l0000Tooooo`;o0000n?ooool2o`0000?ooooo0_l00008
ooooo`;o00005oooool001kooooo00Co0000ooooool0003o00001Oooool2o`0001gooooo0_l0003h
ooooo`;o00009_ooool001kooooo00?o0000ooooooooool01_ooool2o`0000Oooooo0_l0000<oooo
o`Co0000JOooool2o`000:3ooooo0_l0000Iooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o
00003?ooool4o`0006Wooooo0_l00010ooooo`;o0000;?ooool2o`00033ooooo0_l0000Iooooo`00
7_ooool00ol0003oooooooooo`1cooooo`;o00005oooool2o`0003kooooo0_l0000/ooooo`;o0000
:_ooool2o`0001oooooo000Nooooo`03o`000?oooooooooo047ooooo0_l0000`ooooo`;o00000ooo
ool2o`0001;ooooo0_l0000Hooooo`;o0000Ioooool2o`0001Gooooo1?l0000Mooooo`007_ooool0
0ol0003oooooooooo`11ooooo`;o0000=Oooool2o`0000cooooo0_l0000Nooooo`;o00003oooool2
o`0005Kooooo0_l0000Gooooo`;o00007Oooool001kooooo0_l00002ooooo`;o0000Loooool2o`00
00kooooo0_l0000_ooooo`;o0000S_ooool001kooooo00Co0000oooooooooooooooo0_l0001coooo
o`;o00000_ooool2o`0005Cooooo0_l0001@ooooo`;o00008oooool001kooooo00?o0000oooooooo
ool0N_ooool2o`0003?ooooo0_l00006ooooo`;o00005oooool2o`00053ooooo0_l00003ooooo`;o
00002oooool2o`00017ooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l0000Cooooo`;o0000
<_ooool2o`0003Gooooo0_l0000Wooooo`;o00001_ooool2o`0000?ooooo0_l0001=ooooo`;o0000
4oooool2o`0000Gooooo0_l0000;ooooo`;o00004Oooool001kooooo00?o0000ooooooooool01_oo
ool2o`0001?ooooo1_l0000^ooooo`;o0000=Oooool2o`0002Gooooo0_l0000=ooooo`;o0000COoo
ool2o`0001?ooooo0_l0000Uooooo`007_ooool00ol0003oooooooooo`0Mooooo`Co0000S?ooool2
o`0002Cooooo0_l0000/ooooo`;o0000A?ooool001kooooo00?o0000ooooooooool0doooool2o`00
01gooooo0_l0000=ooooo`;o00003_ooool2o`0001Cooooo0ol0000:ooooo`;o00004Oooool001ko
oooo00?o0000ooooooooool0@_ooool2o`0002Wooooo0_l0000cooooo`;o00000oooool2o`0003Wo
oooo0_l0000>ooooo`;o00007Oooool2o`0001Cooooo0ol0000:ooooo`;o00000oooool2o`0000co
oooo000Nooooo`?o00005oooool2o`0001_ooooo0_l0000<ooooo`;o00005Oooool2o`0001;ooooo
0_l0000cooooo`Co000000?oooooo`000?l00000>Oooool2o`0005Gooooo0_l0000<ooooo`007_oo
ool3o`0001?ooooo0_l00002ooooo`;o00006oooool2o`0001oooooo0_l00002ooooo`;o00009ooo
ool2o`0000;ooooo0_l0000Looooo`;o0000T?ooool2o`0000oooooo000Mooooo`;o00005Oooool2
o`0002Wooooo0_l0000Booooo`;o000000?oooooo`000?l000006?ooool2o`00013ooooo1ol0000G
ooooo`;o0000O?ooool2o`0001Oooooo0_l0000?ooooo`007Oooool2o`00043ooooo0_l0000Boooo
o`;o000000?oooooo`000?l000006?ooool2o`00013ooooo1Ol0000Iooooo`;o0000@_ooool2o`00
03Sooooo0_l0000Xooooo`007_ooool00ol0003oooooooooo`0aooooo`;o00008_ooool2o`0001So
oooo0_l0000eooooo`;o0000>oooool2o`0006;ooooo000Nooooo`03o`000?oooooooooo02?ooooo
0_l0000<ooooo`;o0000?_ooool3o`0002;ooooo0_l0000>ooooo`;o0000Woooool000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo
00Co0000oooooooooooooooo0ol0000Oooooo`;o0000C?ooool3o`0002;ooooo0_l0000Jooooo`;o
0000EOooool2o`0000cooooo0_l0000^ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooooooo0ol0001:oooo
o`;o0000=Oooool2o`0000kooooo0_l0000Kooooo`;o00005oooool2o`0000;ooooo0_l0000hoooo
o`;o00003?ooool2o`0002kooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`00
00Kooooo0ol00005ooooo`;o0000Aoooool2o`0003Gooooo0_l0000>ooooo`;o0000=?ooool2o`00
00;ooooo0_l0000Wooooo`;o0000COooool000?ooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool01Oooool2o`0000Sooooo0_l0001G
ooooo`;o0000;_ooool2o`0005kooooo0_l0000Hooooo`;o0000<oooool000?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool03ooo
ool2o`0005Oooooo0_l0000=ooooo`;o00003Oooool2o`0000cooooo0_l00002ooooo`;o0000D?oo
ool2o`0002Kooooo0_l0000cooooo`000oooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l000001oooool00ol0003oooooooooo`0?ooooo`;o00004_ooool2o`0000kooooo0_l0
0012ooooo`;o00003Oooool2o`0000cooooo0_l00006ooooo`;o0000C?ooool2o`0003Wooooo0_l0
000Pooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001ooo
ool00ol0003oooooooooo`0Sooooo`;o00003_ooool2o`0002;ooooo0_l00013ooooo`;o0000G_oo
ool2o`0002Oooooo0_l0000Pooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?o
MgMgo`000?ooool01_ooool00ol0003oooooooooo`1Gooooo`;o0000Xoooool2o`0004Wooooo000N
ooooo`03o`000?oooooooooo08Oooooo0_l0000gooooo`;o0000>?ooool2o`0004_ooooo000Noooo
o`03o`000?oooooooooo00Wooooo0_l0000Mooooo`;o00001oooool2o`0002Wooooo0_l0000Yoooo
o`;o00007oooool2o`0001Kooooo0_l0000?ooooo`;o00008_ooool2o`0000?ooooo0_l0001;oooo
o`007_ooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`0001gooooo0_l00007ooooo`;o
0000:Oooool3o`0002?ooooo0_l0000Tooooo`;o00002oooool2o`0000[ooooo0_l0000>ooooo`;o
00008Oooool3o`00053ooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0000gooooo`;o0000
7oooool2o`00023ooooo0_l000000ooooooo0000o`00000Oooooo`;o00004?ooool2o`0000[ooooo
0_l0000aooooo`;o0000;Oooool2o`0001Kooooo0_l0000:ooooo`007_ooool00ol0003ooooooooo
o`0<ooooo`;o0000;_ooool2o`00047ooooo0_l0000Rooooo`;o0000O_ooool2o`0000Cooooo0_l0
000@ooooo`;o00002_ooool001kooooo00?o0000ooooooooool03?ooool2o`000>oooooo0_l0000Z
ooooo`;o00004_ooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo0?gooooo0_l0000Zoooo
o`;o00004_ooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0k_ooool2o`0004kooooo0_l00007ooooo`007_ooool00ol0003ooooooooo
o`0Zooooo`;o0000B?ooool2o`0005oooooo0_l0000Gooooo`;o0000C_ooool2o`0000Oooooo000N
ooooo`03o`000?oooooooooo00;o0000:?ooool2o`0004Sooooo0_l0000Rooooo`;o0000>oooool4
o`0006kooooo000Nooooo`;o000000?oooooo`000?l00000U_ooool2o`0003Wooooo0_l00002oooo
o`;o00006_ooool2o`0001Kooooo1?l0000Cooooo`;o00008oooool001kooooo00?o0000oooooooo
ool0F?ooool2o`0000Cooooo0_l0001Eooooo`;o00000oooool2o`0000oooooo0_l00006ooooo`;o
00004oooool2o`0000Wooooo0_l0000Fooooo`Co00001_ooool2o`0000_ooooo0_l0000Aooooo`;o
00004?ooool001kooooo00?o0000ooooooooool00_l00005ooooo`;o0000Coooool2o`0000Cooooo
0_l0000Fooooo`;o0000?Oooool2o`0000?ooooo0_l0000?ooooo`;o00006oooool2o`0002_ooooo
0_l0000Nooooo`;o00004?ooool001kooooo00?o0000ooooooooool00_l000000ooooooo0000o`00
0002ooooo`;o0000KOooool2o`00073ooooo0_l0001Mooooo`007_ooool00ol0003oooooooooo`03
ooooo`;o00003Oooool2o`000?oooooo=?ooool001kooooo00?o0000ooooooooool04_ooool2o`00
03Kooooo0_l0002Jooooo`;o00006_ooool2o`0004?ooooo000Nooooo`03o`000?oooooooooo04[o
oooo0_l0001Gooooo`;o00009_ooool2o`0001Wooooo0_l0000Jooooo`;o0000@oooool001kooooo
00?o0000ooooooooool0Xoooool2o`0000[ooooo0_l0000Jooooo`;o0000N_ooool001kooooo00?o
0000ooooooooool03?ooool4o`0003[ooooo0_l0000Jooooo`;o0000Aoooool2o`0008gooooo0_l0
0007ooooo`007_ooool00ol0003oooooooooo`0<ooooo`Co0000>_ooool2o`0001[ooooo0_l0000C
ooooo`;o00008Oooool2o`0009kooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`0/oooo
o`;o0000@_ooool2o`0000Wooooo0_l0000Qooooo`;o0000Yoooool001kooooo00?o0000oooooooo
ool0;?ooool4o`0003Kooooo0_l00008ooooo`;o00005oooool2o`0005_ooooo0_l0001Oooooo`00
7_ooool00ol0003oooooooooo`0^ooooo`;o0000=_ooool2o`0000oooooo0_l0000@ooooo`;o0000
Foooool2o`0004?ooooo0_l0000Jooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o0000G_oo
ool2o`0004;ooooo0_l0001^ooooo`;o00006_ooool001kooooo00?o0000ooooooooool05oooool2
o`000:;ooooo0_l0000Tooooo`;o0000EOooool2o`0000gooooo000Nooooo`03o`000?oooooooooo
07Gooooo0_l0000Oooooo`?o00003_ooool2o`0000cooooo0_l0000Zooooo`;o0000COooool2o`00
00Kooooo0_l0000=ooooo`007_ooool3o`00043ooooo0_l0000cooooo`;o00007oooool3o`0000ko
oooo0_l0000<ooooo`;o00009Oooool2o`0001Cooooo0_l0000Kooooo`;o00001oooool2o`0000co
oooo0_l00008ooooo`;o00005Oooool001kooooo0ol0000Booooo`;o0000:?ooool2o`0000;ooooo
0_l0002Jooooo`;o00001oooool2o`0000_ooooo0_l0000Kooooo`;o00001oooool2o`0000cooooo
0_l0000Oooooo`007_ooool00ol0003oooooooooo`07ooooo`;o00000oooool2o`0000Cooooo0_l0
000Xooooo`;o00007oooool2o`0008Kooooo0_l0001Pooooo`007_ooool00ol0003oooooooooo`07
ooooo`;o00000oooool2o`0004oooooo0_l0000^ooooo`;o0000^?ooool001kooooo00Co0000oooo
ool0003o00004_ooool2o`0000kooooo0_l0001Xooooo`;o0000^?ooool001kooooo00Co0000oooo
ool0003o00004_ooool2o`0000kooooo0_l0001eooooo`;o0000Foooool2o`0004kooooo000Noooo
o`03o`000?oooooooooo03_ooooo0_l0001Mooooo`;o0000?oooool2o`0001[ooooo0_l00005oooo
o`;o0000Aoooool001kooooo00?o0000ooooooooool02?ooool2o`00037ooooo0_l0001Dooooo`;o
00003_ooool2o`0003Sooooo0_l0000Qooooo`;o00005Oooool2o`00033ooooo000Nooooo`03o`00
0?oooooooooo00Sooooo0_l0000Eooooo`;o00008Oooool2o`0002?ooooo0_l00005ooooo`;o0000
8Oooool2o`0000kooooo0_l0001booooo`;o00008_ooool2o`0000cooooo000Nooooo`03o`000?oo
oooooooo00Oooooo0_l0000Fooooo`;o00001_ooool2o`0001Wooooo0_l0000Sooooo`;o00001Ooo
ool2o`0000;ooooo0_l0000Uooooo`;o0000Hoooool2o`0001Wooooo0_l0000Nooooo`;o00003?oo
ool001kooooo00?o0000ooooooooool01oooool2o`0001kooooo0_l00016ooooo`;o000000?ooooo
o`000?l000003?ooool2o`0001Oooooo0_l0000Pooooo`;o00001oooool2o`0003Sooooo0_l0000I
ooooo`;o0000;?ooool001kooooo00?o0000ooooooooool08Oooool2o`0002oooooo0_l0000Koooo
o`;o00003oooool2o`0003Wooooo0_l00007ooooo`;o0000POooool001kooooo00?o0000oooooooo
ool08Oooool2o`0001Gooooo0_l0000Hooooo`;o0000A?ooool2o`0002gooooo0_l0000fooooo`;o
00008?ooool2o`0001Kooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`0hooooo`;o0000
@Oooool2o`0000Cooooo0_l0000Eooooo`;o0000;Oooool2o`0003Kooooo0_l0000Pooooo`;o0000
3oooool2o`0000Gooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`14ooooo`;o0000=Ooo
ool2o`0000Cooooo0_l00009ooooo`;o0000Y?ooool2o`0001?ooooo000Nooooo`03o`000?oooooo
oooo04Cooooo0_l00016ooooo`;o00002oooool2o`000:cooooo000Nooooo`;o0000V_ooool2o`00
01gooooo0_l0001hooooo`;o00004oooool001kooooo00?o0000ooooooooool0^?ooool2o`0001Wo
oooo0_l0001Mooooo`;o00004oooool001kooooo00?o0000ooooooooool06_ooool2o`0001Gooooo
0_l0000Aooooo`;o00004_ooool2o`0005_ooooo0_l0000Kooooo`?o0000L_ooool001kooooo00?o
0000ooooooooool06_ooool2o`0001Gooooo0_l0000Aooooo`;o00004_ooool2o`0000[ooooo0_l0
001?ooooo`;o00006oooool2o`0007?ooooo000Nooooo`03o`000?oooooooooo02gooooo0_l00005
ooooo`;o00004Oooool2o`0000oooooo0_l00004ooooo`;o00001?ooool2o`000>7ooooo000Noooo
o`03o`000?oooooooooo02gooooo0_l00005ooooo`;o00004Oooool2o`0001Gooooo0_l0001Doooo
o`;o0000I_ooool2o`00013ooooo0_l0000Gooooo`007_ooool00ol0003oooooooooo`2dooooo`;o
0000>_ooool2o`0002[ooooo0_l0000@ooooo`;o00005oooool001kooooo00?o0000ooooooooool0
EOooool2o`0003Cooooo0_l0001Sooooo`;o0000EOooool001kooooo00?o0000ooooooooool05_oo
ool2o`0003gooooo0_l0000Pooooo`;o00004_ooool2o`0001Oooooo0_l0002?ooooo`;o00004?oo
ool001gooooo0_l0000Dooooo`;o00000_ooool2o`0005oooooo0_l0000[ooooo`;o0000SOooool4
o`00013ooooo000Mooooo`;o00005?ooool2o`0000[ooooo0_l0002fooooo`;o00000_ooool2o`00
05Oooooo0_l0000Booooo`007_ooool00ol0003oooooooooo`0Nooooo`Co00005?ooool2o`0009ko
oooo0_l00002ooooo`;o0000;_ooool2o`0003_ooooo000Nooooo`03o`000?oooooooooo023ooooo
0_l0000Dooooo`;o0000UOooool2o`0002_ooooo0_l0000>ooooo`;o00008Oooool2o`0001Sooooo
000Nooooo`03o`000?oooooooooo067ooooo0_l0001Zooooo`Co0000:Oooool2o`000003ooooool0
003o000002kooooo1?l0000Fooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`1Qooooo`;o0000
K?ooool2o`0002Oooooo0_l00003ooooo`;o0000<?ooool2o`0001Kooooo0003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03
o`000?oooooooooo00;o00007?ooool2o`0004oooooo0_l00027ooooo`;o0000COooool000?ooooo
00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool5o`00
01cooooo0_l0001?ooooo`;o0000a?ooool2o`00013ooooo0003ooooo`05o`000?oooooooooooooo
ool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0ooooool^
ooooo`;o00001_ooool2o`00013ooooo0003ooooo`05o`000?ooooooooooooooool000002oooool0
1Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool01oooool2o`00023ooooo0_l0
003oooooo`?ooooo0_l0000Hooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00?o
EEEEohN7Qoooool02?ooool00ol0003oooooooooo`07ooooo`;o00005_ooool2o`0000Sooooo0_l0
000Yooooo`;o0000SOooool2o`0000cooooo0_l0001Dooooo`000oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0Oooooo`;o00009?oo
ool2o`0000gooooo0_l0002=ooooo`;o00003?ooool2o`0005Cooooo0003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo00gooooo
0_l0000fooooo`;o0000W?ooool2o`0002cooooo0_l0000/ooooo`;o00001_ooool001kooooo00?o
0000ooooooooool03Oooool2o`0009Gooooo0_l0000/ooooo`;o00003oooool2o`0002cooooo0_l0
000/ooooo`;o00001_ooool001kooooo00?o0000ooooooooool0Y?ooool2o`0001Oooooo0_l0000;
ooooo`;o00001_ooool2o`0007?ooooo000Nooooo`03o`000?oooooooooo04oooooo0_l0000>oooo
o`;o00006Oooool2o`0000Cooooo0_l0000kooooo`;o00002oooool2o`0007_ooooo000Nooooo`03
o`000?oooooooooo04oooooo0_l0000>ooooo`;o00006?ooool3o`0000Cooooo0_l0000nooooo`;o
0000@_ooool2o`00047ooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0001_ooooo`;o0000
AOooool2o`0004;ooooo0_l0000Rooooo`;o00007Oooool001kooooo00?o0000ooooooooool02?oo
ool2o`000:3ooooo0_l0001looooo`;o00004_ooool2o`0000Wooooo000Nooooo`03o`000?oooooo
oooo00;o0000Z?ooool2o`0006;ooooo0_l0000/ooooo`;o00002Oooool001kooooo00?o0000oooo
ooooool00_l00007ooooo`;o0000UOooool2o`0000Gooooo0_l0000booooo`;o00001oooool2o`00
02Sooooo0_l0000Dooooo`;o00008Oooool001kooooo00?o0000ooooooooool02Oooool2o`0004;o
oooo1?l0001?ooooo`;o00001Oooool2o`0001cooooo0_l0000Dooooo`;o00001oooool2o`0003ko
oooo0_l0000Qooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o0000?Oooool4o`0001_ooooo
0_l0000Qooooo`;o00004oooool2o`0001oooooo0_l00020ooooo`007_ooool00ol0003ooooooooo
o`0<ooooo`Co00002Oooool2o`00057ooooo0_l0000Qooooo`;o00004oooool2o`0000Kooooo0_l0
002Iooooo`007_ooool2o`0000gooooo0_l0000;ooooo`;o0000TOooool2o`0009Wooooo000Noooo
o`03o`000?oooooooooo027ooooo0_l0001jooooo`;o000000?oooooo`000?l00000@oooool2o`00
063ooooo000Nooooo`03o`000?oooooooooo027ooooo0_l0001Sooooo`;o00005Oooool2o`000003
ooooool0003o000000Gooooo0_l0000looooo`;o0000H?ooool001kooooo00?o0000ooooooooool0
G_ooool2o`0002Kooooo0_l0000Oooooo`;o00007oooool2o`0001Gooooo0_l0001Vooooo`007_oo
ool00ol0003oooooooooo`1Nooooo`;o00001Oooool2o`00057ooooo0_l0000>ooooo`;o00005Ooo
ool2o`0006Kooooo000Nooooo`03o`000?oooooooooo06Gooooo0_l0001Aooooo`;o00009?ooool2
o`000003ooooool0003o000006Cooooo000Nooooo`03o`000?oooooooooo0=kooooo0_l000000ooo
oooo0000o`00001Tooooo`007_ooool00ol0003oooooooooo`2>ooooo`;o0000G_ooool2o`0001Oo
oooo0_l0000nooooo`007_ooool00ol0003oooooooooo`2>ooooo`;o0000G_ooool2o`0001Oooooo
0_l0000/ooooo`;o00004?ooool001kooooo00?o0000ooooooooool02Oooool2o`0000oooooo0_l0
0008ooooo`;o0000h_ooool2o`0002;ooooo0_l00007ooooo`;o00004?ooool001kooooo00?o0000
ooooooooool02Oooool2o`0000oooooo0_l00008ooooo`;o0000[Oooool2o`0003?ooooo0_l0000R
ooooo`;o00006Oooool001kooooo00?o0000ooooooooool0Poooool2o`0004Gooooo0_l00007oooo
o`;o0000L_ooool001kooooo00?o0000ooooooooool0Loooool2o`0000kooooo0_l00015ooooo`;o
00009Oooool2o`0002Oooooo0_l0000Fooooo`;o00004oooool001kooooo00?o0000ooooooooool0
Loooool2o`0006?ooooo0_l0000Gooooo`;o00001oooool2o`0001kooooo0_l0000Fooooo`;o0000
4oooool001kooooo00?o0000ooooooooool0Coooool2o`0008Oooooo1?l00003ooooo`;o00006Ooo
ool2o`0000Gooooo0_l00014ooooo`007_ooool00ol0003oooooooooo`1?ooooo`;o0000ROooool2
o`0000?ooooo0_l0000Pooooo`;o0000A?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0Aoooool2o`0004Kooooo
0_l0001Kooooo`;o0000FOooool001kooooo00?o0000ooooooooool02oooool2o`0000gooooo0_l0
000Hooooo`;o00004Oooool2o`0004Kooooo0_l0000;ooooo`;o00002oooool2o`00047ooooo0_l0
000Kooooo`;o0000;Oooool2o`0000gooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l0000=
ooooo`;o00006?ooool2o`0006Kooooo0_l0000;ooooo`;o00003Oooool2o`0002Sooooo0_l00000
0ooooooo0000o`00000Rooooo`;o0000;Oooool2o`0000gooooo000Nooooo`03o`000?oooooooooo
00;o0000Uoooool2o`0001gooooo0_l0000Xooooo`;o000000?oooooo`000?l000001oooool2o`00
05Oooooo000Nooooo`03o`000?oooooooooo00;o0000A_ooool2o`0004oooooo0_l0000gooooo`;o
00006_ooool2o`0005Oooooo000Nooooo`03o`000?oooooooooo04Sooooo0_l0001cooooo`;o0000
4oooool2o`0007?ooooo000Nooooo`03o`000?oooooooooo01[ooooo0_l0001=ooooo`;o0000>_oo
ool2o`0001Kooooo0_l0001`ooooo`;o00005_ooool001kooooo00?o0000ooooooooool06_ooool2
o`0004gooooo0_l0000jooooo`;o0000L_ooool2o`0001Cooooo0_l0000Fooooo`007_ooool00ol0
003oooooooooo`1Pooooo`;o0000]oooool2o`0002cooooo000Nooooo`03o`000?oooooooooo01ko
oooo0_l00010ooooo`;o00002_ooool2o`000;Sooooo0_l0000Oooooo`007_ooool00ol0003ooooo
ooooo`0Nooooo`;o0000:Oooool2o`00027ooooo0_l0000Hooooo`;o0000W_ooool2o`0001oooooo
000Nooooo`03o`000?oooooooooo04Wooooo0_l0000kooooo`Co0000Zoooool2o`00013ooooo000N
ooooo`03o`000?oooooooooo04Cooooo0_l0000Looooo`;o00009?ooool2o`0004cooooo0_l0000E
ooooo`;o0000A_ooool2o`00013ooooo000Nooooo`03o`000?oooooooooo04Cooooo0_l0000Loooo
o`;o0000?Oooool2o`0002Gooooo0_l0000<ooooo`;o00005Oooool2o`0005Sooooo000Nooooo`;o
0000X_ooool2o`0002Gooooo0_l0001fooooo`;o00001Oooool001kooooo00?o0000ooooooooool0
oooooom1ooooo`;o00001Oooool001kooooo00?o0000ooooooooool05_ooool2o`0000Oooooo0_l0
001looooo`;o00008oooool2o`0005oooooo0_l0000Rooooo`007_ooool00ol0003oooooooooo`0F
ooooo`?o00001_ooool2o`0004Cooooo0_l0000fooooo`;o00008oooool2o`0005cooooo0_l00000
0ooooooo0000o`00000Eooooo`;o00002oooool001kooooo00?o0000ooooooooool05oooool2o`00
00;ooooo0_l00018ooooo`;o0000^Oooool2o`0001Sooooo0_l0000;ooooo`007_ooool00ol0003o
ooooooooo`0Kooooo`;o00003?ooool2o`000003ooooool0003o000007Gooooo0_l0001]ooooo`;o
0000<oooool001kooooo00?o0000ooooooooool0:Oooool2o`000003ooooool0003o000002Cooooo
0_l0001?ooooo`;o00009oooool2o`0004Cooooo0_l0000Uooooo`;o00003?ooool001kooooo00?o
0000ooooooooool0D_ooool2o`0001oooooo0_l0000Cooooo`;o0000=?ooool2o`0000cooooo0_l0
000cooooo`;o0000=_ooool2o`0000cooooo000Nooooo`03o`000?oooooooooo05cooooo0_l0000E
ooooo`;o00004oooool2o`0003Cooooo0_l0000Eooooo`;o0000:_ooool2o`0004Cooooo000Noooo
o`03o`000?oooooooooo05cooooo0_l0001Oooooo`;o00005_ooool2o`00073ooooo000Nooooo`03
o`000?oooooooooo0;gooooo0_l0000nooooo`;o000000?oooooo`000?l00000AOooool001kooooo
00?o0000ooooooooool0hOooool2o`0000_ooooo0_l0000;ooooo`Co000000?oooooo`000?l00000
AOooool001kooooo00?o0000ooooooooool0hOooool2o`0000_ooooo0_l0000;ooooo`;o0000B_oo
ool001kooooo00?o0000ooooooooool0Foooool2o`000:Kooooo0_l00008ooooo`;o0000>?ooool0
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<00Kooooo00?o0000ooooooooool0:?ooool2o`0000Gooooo0_l0000Zooooo`;o00008ooo
ool2o`00087ooooo0_l00006ooooo`Co00008?ooool2o`0001Kooooo0003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`00
0?oooooooooo01?ooooo0_l0000Cooooo`;o00001Oooool2o`0004oooooo0_l00029ooooo`;o0000
8_ooool2o`0000;ooooo0_l0000Booooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo
00Go0000ooooooooooooooooo`000006ooooo`?o00003_ooool2o`0000?ooooo0_l000000ooooooo
0000o`00000Wooooo`;o0000l?ooool4o`0001;ooooo0003ooooo`05o`000?ooooooooooooooool0
00002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000ooooooooool03_ooool2o`00
00Kooooo0_l00002ooooo`;o00008oooool2o`0001;ooooo0ol0001Qooooo`;o0000=oooool2o`00
0003ooooool0003o000003cooooo0_l0000Dooooo`000oooool01Ol0003ooooooooooooooooo0000
00_ooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo01Cooooo0_l00004
ooooo`;o0000=oooool3o`00053ooooo0_l0000?ooooo`;o0000=oooool2o`000003ooooool0003o
000005;ooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj
^[[o410@00Kooooo00?o0000ooooooooool05?ooool2o`0005Gooooo0_l0000iooooo`;o0000Wooo
ool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`0Booooo`;o0000Eoooool2o`0000Cooooo0_l0000mooooo`;o0000
D?ooool2o`00027ooooo0_l0000Pooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo01;ooooo0_l0000oooooo`;o
00007?ooool2o`0000cooooo0_l0000_ooooo`;o00008?ooool2o`0001Kooooo0_l0000Fooooo`;o
00008Oooool2o`00023ooooo000Nooooo`?o00005_ooool2o`0003_ooooo1?l0000Xooooo`;o0000
7_ooool2o`0002Oooooo0_l00006ooooo`Co00005_ooool2o`0005_ooooo000Nooooo`?o00005_oo
ool2o`0003gooooo0_l00018ooooo`;o00009oooool2o`0000Kooooo0_l0001eooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo05oooooo0_l0001=oooo
o`;o0000AOooool2o`00053ooooo000Nooooo`03o`000?oooooooooo02;ooooo0_l0000kooooo`;o
0000COooool2o`00013ooooo0_l0000Gooooo`;o00006_ooool2o`00027ooooo0_l0000]ooooo`00
7_ooool00ol0003oooooooooo`0Rooooo`;o0000Poooool2o`0001Oooooo0_l0000Gooooo`;o0000
3oooool2o`0001_ooooo0_l0000?ooooo`?o0000;?ooool001kooooo00?o0000ooooooooool0Iooo
ool2o`0003kooooo0_l00011ooooo`;o00006oooool2o`00013ooooo0_l0000/ooooo`007_ooool0
0ol0003oooooooooo`0jooooo`;o0000:oooool2o`0001kooooo0_l00019ooooo`;o00003Oooool2
o`0005Cooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o00004?ooool2o`00
01;ooooo0_l00008ooooo`;o00002?ooool2o`00047ooooo0_l0000nooooo`;o00002Oooool2o`00
00gooooo0_l0000Pooooo`;o00001_ooool2o`0002[ooooo0_l0000>ooooo`007_ooool00ol0003o
ooooooooo`0:ooooo`;o00004?ooool2o`0001;ooooo0_l0000Booooo`;o0000B?ooool2o`0002?o
oooo0_l0000Booooo`;o0000>_ooool2o`0000Kooooo0_l0000jooooo`007_ooool00ol0003ooooo
ooooo`1Wooooo`;o00009Oooool2o`0002?ooooo0_l0001Zooooo`;o00009_ooool001kooooo0_l0
001Xooooo`;o0000?oooool2o`0007Gooooo0_l0000Vooooo`007_ooool00ol0003oooooooooo`2N
ooooo`;o00002?ooool2o`0005Gooooo0_l0000Gooooo`;o0000;Oooool001kooooo00?o0000oooo
ooooool05_ooool2o`00067ooooo0_l0000Sooooo`;o0000<oooool2o`00017ooooo0_l0000Goooo
o`;o000000?oooooo`000?l000005?ooool2o`0002gooooo000Nooooo`04o`000?oooooo0000o`00
01Gooooo0_l0001Qooooo`;o0000F?ooool3o`0000Kooooo0_l00008ooooo`;o00006_ooool2o`00
017ooooo0_l0000`ooooo`007_ooool01?l0003oooooo`000?l0000jooooo`;o00000oooool2o`00
09;ooooo0_l00006ooooo`;o0000=oooool2o`00033ooooo000Nooooo`03o`000?oooooooooo03_o
oooo0_l00003ooooo`;o00003oooool2o`000?Cooooo000Nooooo`03o`000?oooooooooo057ooooo
0_l0002/ooooo`;o0000A_ooool001kooooo0ol0002Zooooo`;o00002_ooool2o`0004Oooooo0_l0
0016ooooo`007_ooool3o`0001oooooo0_l0000looooo`;o0000Boooool2o`0000[ooooo0_l0002?
ooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o00003?ooool2o`0003cooooo0_l00009oooo
o`;o00008Oooool2o`0000Wooooo0_l0002_ooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o
0000?oooool2o`0001Cooooo0_l0000<ooooo`;o00004oooool2o`0000Wooooo0_l0000Oooooo`;o
0000Noooool2o`00017ooooo000Nooooo`03o`000?oooooooooo03Cooooo0_l0000Looooo`;o0000
3Oooool2o`0001?ooooo0_l0000looooo`;o000000?oooooo`000?l00000;oooool2o`0003[ooooo
0_l0000>ooooo`;o00004Oooool001kooooo00?o0000ooooooooool0=?ooool2o`0002_ooooo0_l0
0006ooooo`;o0000BOooool2o`0003;ooooo0_l0000jooooo`;o00008Oooool001kooooo00?o0000
ooooooooool0JOooool2o`0001kooooo0_l00005ooooo`;o0000]Oooool001kooooo00?o0000oooo
ooooool0ROooool2o`0000Gooooo0_l0000Dooooo`;o0000Woooool001kooooo00?o0000oooooooo
ool00oooool2o`000:7ooooo0_l0000Eooooo`;o0000Ioooool2o`0000Wooooo0_l0000Dooooo`00
7_ooool2o`0000Cooooo0_l0002Kooooo`;o00006oooool2o`0000oooooo0_l0001Fooooo`;o0000
2Oooool2o`0001Cooooo000Nooooo`03o`000?oooooooooo0:3ooooo0_l000000ooooooo0000o`00
0005ooooo`;o00001?ooool2o`0001cooooo0_l0000looooo`;o00001oooool2o`0001Cooooo0_l0
000Jooooo`007_ooool00ol0003oooooooooo`2Sooooo`;o00001Oooool2o`0000Cooooo0_l0000=
ooooo`;o0000Boooool3o`0000Kooooo0_l00006ooooo`;o00003?ooool2o`0001[ooooo000Noooo
o`03o`000?oooooooooo05_ooooo0_l0001Rooooo`;o0000C?ooool2o`0000kooooo0_l0000Xoooo
o`007_ooool00ol0003oooooooooo`1Kooooo`;o00007Oooool2o`0000Sooooo0_l0000nooooo`;o
0000BOooool2o`0003Kooooo000Nooooo`03o`000?oooooooooo07[ooooo0_l000000ooooooo0000
o`000005ooooo`;o0000;oooool2o`0000gooooo0_l0000Iooooo`;o00002_ooool2o`0002;ooooo
0_l0000fooooo`007_ooool00ol0003oooooooooo`1mooooo`;o0000=_ooool2o`0002Sooooo0_l0
0005ooooo`;o00000oooool2o`00013ooooo0_l00018ooooo`007_ooool3o`000<Wooooo0_l0000K
ooooo`;o00005Oooool2o`0000gooooo0_l0000iooooo`007_ooool3o`000:Cooooo0_l000000ooo
oooo0000o`000002o`0001kooooo0_l00011ooooo`;o00001Oooool2o`00013ooooo0_l0000Goooo
o`;o00001oooool001kooooo00?o0000ooooooooool08_ooool2o`00083ooooo0_l000000ooooooo
0000o`000002o`0001cooooo0_l00017ooooo`;o000000?oooooo`000?l000004?ooool2o`0001Oo
oooo0_l00007ooooo`007_ooool00ol0003oooooooooo`0Rooooo`;o0000=_ooool2o`0005Oooooo
0_l0000Booooo`;o0000Aoooool2o`0000;ooooo0_l0000aooooo`007_ooool00ol0003ooooooooo
o`08ooooo`;o0000D?ooool2o`0005Oooooo0_l0000looooo`;o00008Oooool2o`00037ooooo000N
ooooo`03o`000?oooooooooo00Sooooo0_l0000Oooooo`;o0000VOooool2o`0002_ooooo0_l0001D
ooooo`007_ooool00ol0003oooooooooo`0Yooooo`;o00002_ooool2o`0004Sooooo0_l00013oooo
o`;o0000>_ooool2o`0004Gooooo000Nooooo`03o`000?oooooooooo03Gooooo0_l00005ooooo`;o
0000@Oooool3o`0007kooooo0ol00014ooooo`007_ooool00ol0003oooooooooo`0looooo`;o0000
@_ooool2o`0002Sooooo0_l00005ooooo`;o00005oooool2o`0000_ooooo0_l0000Xooooo`;o0000
A?ooool001kooooo0_l0001Jooooo`;o00002oooool2o`0004;ooooo0_l00005ooooo`;o00005ooo
ool2o`000004ooooool0003o0000o`0000Oooooo0_l0001^ooooo`007_ooool00ol0003ooooooooo
o`1Iooooo`;o00002oooool2o`0006Gooooo0ol0001gooooo`007_ooool00ol0003oooooooooo`0Z
ooooo`;o0000P?ooool2o`0001_ooooo0_l00002ooooo`;o0000C?ooool2o`0002[ooooo000Noooo
o`?o00005_ooool2o`0001;ooooo0_l00020ooooo`;o00001Oooool2o`0001Cooooo0_l0000]oooo
o`;o00005oooool2o`0000Sooooo0_l0000Zooooo`007_ooool3o`0001Kooooo0_l00003ooooo`;o
0000E?ooool2o`00043ooooo0_l00013ooooo`;o000000Coooooo`000?l0003o00002_ooool2o`00
00?ooooo0_l00002ooooo`;o00006?ooool2o`0001[ooooo000Nooooo`03o`000?oooooooooo00ko
oooo0_l0000;ooooo`;o0000E?ooool2o`0008Sooooo0ol0000:ooooo`;o00000oooool2o`0001co
oooo0_l0000Jooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o0000Eoooool2o`000=kooooo
000Nooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`;o0000DOooool2o`0000[ooooo0_l0
000Tooooo`;o00005Oooool2o`0001kooooo0_l0001]ooooo`;o00004_ooool001kooooo00?o0000
ooooooooool00oooool2o`0000?ooooo0_l0000dooooo`;o00004_ooool2o`000003ooooool0003o
000000Cooooo0_l0000Eooooo`;o00006Oooool2o`0001Gooooo0_l0000Nooooo`;o0000Eoooool2
o`0001Cooooo0_l000000ooooooo0000o`00000?ooooo`007_ooool00ol0003oooooooooo`0noooo
o`;o00004_ooool2o`000003ooooool0003o000000cooooo0_l0000=ooooo`;o0000X?ooool2o`00
00Oooooo0_l0000Gooooo`;o00003oooool001kooooo00?o0000ooooooooool01Oooool2o`0005co
oooo0_l0000`ooooo`;o0000G_ooool2o`0001gooooo0_l00009ooooo`;o00009_ooool001kooooo
00?o0000ooooooooool01Oooool2o`0008kooooo0_l0001Cooooo`;o00002Oooool2o`0002Sooooo
1?l0000Tooooo`007_ooool00ol0003oooooooooo`16ooooo`;o0000COooool2o`0005?ooooo0_l0
000eooooo`;o00009?ooool001kooooo00?o0000ooooooooool0A_ooool2o`0000Wooooo0_l00012
ooooo`;o00000oooool2o`00023ooooo0_l00007ooooo`;o00007oooool2o`0005oooooo000Doooo
o`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`09ooooo`;o0000A_ooool2o`00
04Oooooo0_l0000Nooooo`Co00001oooool2o`0000cooooo0_l0000Aooooo`;o0000@oooool2o`00
01[ooooo000Fooooo`03o`000?oooooooooo00Gooooo0_l0000:ooooo`;o0000[oooool2o`0001Oo
oooo0_l0000iooooo`;o00006oooool2o`0001[ooooo000Fooooo`03o`000?oooooooooo00Gooooo
0ol0003Yooooo`;o00008oooool2o`0003Oooooo000Fooooo`03o`000?oooooooooo0?7ooooo0_l0
001Looooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo
0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005?ooool00omEEEGoIVIV
o`00003ooooooe;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.71729 .52425 Mdot
.16241 .36811 Mdot
.7359 .44245 Mdot
.11303 .4241 Mdot
.44901 .32966 Mdot
.50666 .37672 Mdot
.73939 .23519 Mdot
.02379 .02742 Mdot
.97392 .47566 Mdot
.89245 .93114 Mdot
.41813 .55637 Mdot
.9279 .96052 Mdot
.40898 .71567 Mdot
.10445 .282 Mdot
.95942 .59505 Mdot
.27803 .14457 Mdot
.81383 .01073 Mdot
.45348 .03835 Mdot
.86797 .06744 Mdot
.67568 .75556 Mdot
.11374 .28072 Mdot
.4707 .15484 Mdot
.00416 .9711 Mdot
.80246 .48718 Mdot
.33935 .93815 Mdot
.94643 .94733 Mdot
.02092 .07542 Mdot
.98881 .49835 Mdot
.50331 .34281 Mdot
.22051 .19519 Mdot
.39873 .07143 Mdot
.82011 .18632 Mdot
.94828 .02935 Mdot
.06373 .28305 Mdot
.25356 .3333 Mdot
.0099 .08454 Mdot
.21002 .17974 Mdot
.29044 .41838 Mdot
.83772 .35355 Mdot
.57047 .63169 Mdot
.63605 .68028 Mdot
.031 .19353 Mdot
.54438 .39355 Mdot
.50383 .67161 Mdot
.84199 .59162 Mdot
.12837 .72763 Mdot
.32183 .53112 Mdot
.87091 .86395 Mdot
.461 .12052 Mdot
.82132 .16519 Mdot
.86169 .04649 Mdot
.51958 .83277 Mdot
.96412 .64616 Mdot
.24367 .36261 Mdot
.72055 .98181 Mdot
.02709 .4004 Mdot
.24098 .08549 Mdot
.59217 .98082 Mdot
.59499 .23353 Mdot
.46365 .37419 Mdot
.84462 .86134 Mdot
.89084 .95689 Mdot
.2405 .49799 Mdot
.59219 .41962 Mdot
.00498 .17129 Mdot
.08155 .80482 Mdot
.50713 .43137 Mdot
.36647 .09309 Mdot
.60497 .11781 Mdot
.04981 .39482 Mdot
.31213 .13131 Mdot
.89855 .30082 Mdot
.08444 .05823 Mdot
.2844 .12697 Mdot
.19659 .27367 Mdot
.96034 .97025 Mdot
.88497 .35067 Mdot
.57645 .44867 Mdot
.12294 .64813 Mdot
.90147 .03249 Mdot
.23824 .8033 Mdot
.15127 .39884 Mdot
.2616 .40051 Mdot
.53419 .31413 Mdot
.86032 .63892 Mdot
.52777 .98682 Mdot
.94696 .07966 Mdot
.83628 .27875 Mdot
.30955 .44263 Mdot
.0082 .08942 Mdot
.49744 .48742 Mdot
.37767 .34078 Mdot
.95246 .04828 Mdot
.98652 .67329 Mdot
.99915 .34547 Mdot
.75426 .06021 Mdot
.86024 .00125 Mdot
.51432 .77347 Mdot
.6444 .21306 Mdot
.87985 .76227 Mdot
.01554 .01129 Mdot
.63484 .93482 Mdot
.79996 .21561 Mdot
.52616 .87778 Mdot
.58138 .98271 Mdot
.2663 .91295 Mdot
.86937 .36775 Mdot
.2548 .16047 Mdot
.27254 .08126 Mdot
.03252 .10252 Mdot
.32367 .58802 Mdot
.87113 .03686 Mdot
.59048 .86466 Mdot
.52581 .37589 Mdot
.54437 .90776 Mdot
.29706 .82948 Mdot
.68209 .61745 Mdot
.72046 .61499 Mdot
.51317 .01035 Mdot
.15614 .79254 Mdot
.57297 .58965 Mdot
.44956 .9365 Mdot
.92949 .66734 Mdot
.30903 .60228 Mdot
.61671 .09217 Mdot
.07877 .95052 Mdot
.85935 .54338 Mdot
.52305 .38332 Mdot
.46824 .64237 Mdot
.05403 .48525 Mdot
.61377 .38403 Mdot
.64516 .03072 Mdot
.85214 .48922 Mdot
.45666 .38203 Mdot
.20311 .50923 Mdot
.91706 .46414 Mdot
.26222 .63679 Mdot
.07825 .83394 Mdot
.13067 .37575 Mdot
.32608 .13492 Mdot
.94843 .01286 Mdot
.53747 .93002 Mdot
.61382 .40687 Mdot
.65458 .61314 Mdot
.46616 .64595 Mdot
.45751 .52842 Mdot
.57572 .86583 Mdot
.23651 .81959 Mdot
.61275 .94927 Mdot
.42637 .24994 Mdot
.16224 .80209 Mdot
.82055 .8682 Mdot
.96333 .46433 Mdot
.58547 .16809 Mdot
.62616 .313 Mdot
.6338 .28025 Mdot
.81962 .99977 Mdot
.52046 .42017 Mdot
.95436 .87379 Mdot
.94048 .88729 Mdot
.62223 .20992 Mdot
.76004 .34873 Mdot
.14683 .76748 Mdot
.73735 .78849 Mdot
.93506 .98254 Mdot
.43538 .33343 Mdot
.61372 .35303 Mdot
.51638 .35746 Mdot
.48806 .63907 Mdot
.78728 .65985 Mdot
.79171 .43385 Mdot
.53622 .50966 Mdot
.48272 .52695 Mdot
.00036 .43678 Mdot
.56753 .04589 Mdot
.53541 .38122 Mdot
.34886 .76922 Mdot
.37461 .35012 Mdot
.97546 .72866 Mdot
.14783 .27196 Mdot
.23134 .76179 Mdot
.00368 .31986 Mdot
.13947 .56928 Mdot
.20552 .07727 Mdot
.9624 .7346 Mdot
.95391 .38667 Mdot
.66814 .022 Mdot
.65676 .26825 Mdot
.03351 .94248 Mdot
.54647 .67737 Mdot
.33141 .46671 Mdot
.70369 .67333 Mdot
.39201 .41706 Mdot
.87543 .10465 Mdot
.94312 .18143 Mdot
.40203 .27456 Mdot
.76914 .13144 Mdot
.16842 .59513 Mdot
.36709 .3991 Mdot
.25811 .57872 Mdot
.97274 .176 Mdot
.02663 .64341 Mdot
.93853 .46435 Mdot
.03977 .66672 Mdot
.25235 .27955 Mdot
.48039 .31947 Mdot
.59189 .8261 Mdot
.80882 .29883 Mdot
.60383 .00093 Mdot
.87083 .37637 Mdot
.5503 .86817 Mdot
.31542 .51303 Mdot
.24007 .36922 Mdot
.98289 .53868 Mdot
.63435 .65927 Mdot
.20995 .56178 Mdot
.0799 .6532 Mdot
.43892 .01664 Mdot
.75403 .55505 Mdot
.99985 .99001 Mdot
.94075 .82263 Mdot
.41738 .87512 Mdot
.64266 .26226 Mdot
.85079 .08955 Mdot
.13756 .59808 Mdot
.15985 .83497 Mdot
.22236 .19957 Mdot
.65347 .97735 Mdot
.83712 .2077 Mdot
.45117 .21998 Mdot
.32888 .38175 Mdot
.13109 .00404 Mdot
.07375 .29738 Mdot
.03559 .39082 Mdot
.72418 .74685 Mdot
.94472 .05093 Mdot
.87932 .88536 Mdot
.05729 .50957 Mdot
.37159 .00199 Mdot
.15004 .20859 Mdot
.84192 .01662 Mdot
.02643 .26239 Mdot
.79239 .35885 Mdot
.58775 .97846 Mdot
.40557 .28483 Mdot
.81063 .27862 Mdot
.93575 .25346 Mdot
.61383 .97891 Mdot
.83735 .10448 Mdot
.31873 .7548 Mdot
.11044 .8261 Mdot
.81643 .79389 Mdot
.5774 .06647 Mdot
.57106 .27311 Mdot
.50648 .47616 Mdot
.69341 .55091 Mdot
.8413 .91465 Mdot
.12748 .51539 Mdot
.08621 .96605 Mdot
.7582 .3268 Mdot
.05442 .56349 Mdot
.24299 .8434 Mdot
.67858 .05072 Mdot
.7054 .3492 Mdot
.37712 .66654 Mdot
.91652 .81452 Mdot
.57228 .43635 Mdot
.51035 .96369 Mdot
.49578 .28631 Mdot
.03719 .12749 Mdot
.0146 .60551 Mdot
.56443 .06667 Mdot
.26906 .75273 Mdot
.97103 .92641 Mdot
.35721 .4309 Mdot
.57575 .93378 Mdot
.26038 .4664 Mdot
.40844 .35711 Mdot
.41031 .24576 Mdot
.636 .75226 Mdot
.2695 .74237 Mdot
.85839 .33181 Mdot
.9342 .3667 Mdot
.02879 .97698 Mdot
.01301 .94019 Mdot
.78266 .72943 Mdot
.41403 .20999 Mdot
.47807 .09414 Mdot
.50002 .49203 Mdot
.36222 .42071 Mdot
.3379 .92477 Mdot
.47689 .99728 Mdot
.36506 .52016 Mdot
.79942 .95406 Mdot
.11249 .79773 Mdot
.52596 .64157 Mdot
.36058 .2014 Mdot
.07378 .64404 Mdot
.30624 .23361 Mdot
.33012 .82184 Mdot
.5725 .01646 Mdot
.29585 .10741 Mdot
.53822 .79024 Mdot
.55022 .80087 Mdot
.41622 .97996 Mdot
.95714 .17651 Mdot
.9619 .83228 Mdot
.13883 .80513 Mdot
.29192 .95586 Mdot
.40721 .8842 Mdot
.31334 .45731 Mdot
.367 .36254 Mdot
.47219 .75378 Mdot
.36526 .59611 Mdot
.34082 .68628 Mdot
.53327 .47623 Mdot
.64157 .99027 Mdot
.32308 .99603 Mdot
.88283 .87346 Mdot
.8576 .44769 Mdot
.33335 .17004 Mdot
.74992 .31381 Mdot
.72985 .38189 Mdot
.11157 .22228 Mdot
.91774 .96538 Mdot
.03079 .36355 Mdot
.85967 .98716 Mdot
.75467 .15814 Mdot
.98982 .23684 Mdot
.69414 .87005 Mdot
.40006 .14583 Mdot
.58358 .71837 Mdot
.79783 .24081 Mdot
.09831 .10883 Mdot
.37815 .11114 Mdot
.72158 .20045 Mdot
.08536 .45329 Mdot
.38032 .56092 Mdot
.52718 .22827 Mdot
.93191 .72019 Mdot
.2083 .21552 Mdot
.48079 .56001 Mdot
.14216 .78409 Mdot
.68795 .58821 Mdot
.01585 .29366 Mdot
.82263 .76451 Mdot
.99987 .42257 Mdot
.87719 .26343 Mdot
.61415 .25189 Mdot
.73747 .42565 Mdot
.3981 .82154 Mdot
.52399 .04641 Mdot
.8463 .34072 Mdot
.28563 .76246 Mdot
.40019 .78 Mdot
.33234 .87978 Mdot
.62459 .20886 Mdot
.80458 .82507 Mdot
.89745 .5115 Mdot
.73346 .84366 Mdot
.99905 .49715 Mdot
.1992 .13604 Mdot
.94521 .46481 Mdot
.39912 .34387 Mdot
.78546 .82646 Mdot
.39108 .91903 Mdot
.02766 .3655 Mdot
.72437 .2595 Mdot
.72507 .37131 Mdot
.65364 .13744 Mdot
.1484 .56195 Mdot
.69799 .02695 Mdot
.82953 .29731 Mdot
.71979 .64474 Mdot
.18648 .58894 Mdot
.07022 .53998 Mdot
.6355 .45698 Mdot
.96991 .41233 Mdot
.26981 .83783 Mdot
.95996 .35099 Mdot
.77037 .75828 Mdot
.60179 .49569 Mdot
.92506 .89454 Mdot
.63892 .13902 Mdot
.82818 .26387 Mdot
.16028 .24222 Mdot
.9463 .91763 Mdot
.38533 .4373 Mdot
.03527 .15709 Mdot
.14416 .32547 Mdot
.01278 .01444 Mdot
.50367 .65828 Mdot
.4932 .51876 Mdot
.62301 .41301 Mdot
.23216 .96665 Mdot
.29698 .53297 Mdot
.72266 .4327 Mdot
.8163 .0005 Mdot
.03694 .84259 Mdot
.74447 .29248 Mdot
.75185 .37841 Mdot
.19663 .27707 Mdot
.45919 .108 Mdot
.03757 .8764 Mdot
.22052 .26855 Mdot
.69522 .16841 Mdot
.74554 .58583 Mdot
.16638 .94221 Mdot
.27867 .82475 Mdot
.07756 .61227 Mdot
.53177 .28851 Mdot
.64665 .08967 Mdot
.05234 .18267 Mdot
.11173 .54603 Mdot
.34178 .34133 Mdot
.82319 .95723 Mdot
.77982 .83241 Mdot
.34386 .52469 Mdot
.82958 .52492 Mdot
.94453 .88384 Mdot
.77622 .3735 Mdot
.57276 .95543 Mdot
.00839 .79344 Mdot
.14823 .18351 Mdot
.18918 .94364 Mdot
.31 .38212 Mdot
.25757 .86184 Mdot
.19308 .19324 Mdot
.14527 .70707 Mdot
.54662 .40504 Mdot
.07455 .50848 Mdot
.30355 .80007 Mdot
.57865 .85214 Mdot
.52619 .54104 Mdot
.24343 .32946 Mdot
.61374 .67321 Mdot
.32887 .12412 Mdot
.59426 .58379 Mdot
.81075 .55602 Mdot
.12821 .11405 Mdot
.31815 .53216 Mdot
.3135 .43017 Mdot
.97609 .69306 Mdot
.28594 .94802 Mdot
.69465 .5203 Mdot
.48459 .12176 Mdot
.14027 .50204 Mdot
.55685 .72369 Mdot
.15247 .68294 Mdot
.17168 .42972 Mdot
.01279 .40901 Mdot
.75052 .64392 Mdot
.45295 .59858 Mdot
.6589 .92006 Mdot
.18297 .17998 Mdot
.6995 .21742 Mdot
.768 .29409 Mdot
.52706 .84676 Mdot
.9054 .51299 Mdot
.67259 .85121 Mdot
.47984 .18703 Mdot
.1674 .11664 Mdot
.6784 .05122 Mdot
.1608 .7688 Mdot
.97603 .15321 Mdot
.77283 .148 Mdot
.53284 .23056 Mdot
.37927 .1666 Mdot
.03517 .17537 Mdot
.09339 .05281 Mdot
.42816 .33062 Mdot
.68656 .47229 Mdot
.66874 .93273 Mdot
.18951 .11018 Mdot
.21641 .19433 Mdot
.77206 .66314 Mdot
.93454 .77387 Mdot
.27865 .81307 Mdot
.12774 .81906 Mdot
.65584 .9378 Mdot
.38958 .90903 Mdot
.7473 .57934 Mdot
.71311 .29324 Mdot
.37348 .81828 Mdot
.31129 .0837 Mdot
.90469 .41342 Mdot
.80168 .15778 Mdot
.90695 .06143 Mdot
.58009 .09678 Mdot
.92644 .50721 Mdot
.14604 .53939 Mdot
.555 .32126 Mdot
.03647 .99724 Mdot
.50922 .03418 Mdot
.13078 .3928 Mdot
.46876 .90052 Mdot
.08078 .05051 Mdot
.84213 .21843 Mdot
.61086 .1209 Mdot
.70032 .44224 Mdot
.75881 .79642 Mdot
.51999 .23204 Mdot
.34429 .90389 Mdot
.23911 .62688 Mdot
.00914 .26552 Mdot
.44202 .37058 Mdot
.18301 .58485 Mdot
.6889 .74659 Mdot
.74691 .24254 Mdot
.07925 .21587 Mdot
.89005 .80989 Mdot
.6471 .49342 Mdot
.42381 .31892 Mdot
.88242 .52296 Mdot
.79748 .13843 Mdot
.92796 .15722 Mdot
.4806 .18489 Mdot
.82511 .52546 Mdot
.64339 .84219 Mdot
.86381 .10491 Mdot
.12869 .86281 Mdot
.554 .1299 Mdot
.00945 .75605 Mdot
.16079 .35259 Mdot
.85917 .18343 Mdot
.02067 .58373 Mdot
.83657 .70196 Mdot
.3918 .11961 Mdot
.02416 .82889 Mdot
.8202 .84904 Mdot
.13435 .75117 Mdot
.67191 .45504 Mdot
.28259 .15047 Mdot
.82126 .5484 Mdot
.00568 .10833 Mdot
.88237 .45977 Mdot
.82933 .669 Mdot
.5898 .15996 Mdot
.27686 .25943 Mdot
.5399 .84117 Mdot
.89061 .70385 Mdot
.90894 .28165 Mdot
.53755 .65236 Mdot
.03325 .54055 Mdot
.542 .84824 Mdot
.47945 .71513 Mdot
.75717 .45114 Mdot
.31434 .95788 Mdot
.73221 .49737 Mdot
.03432 .03563 Mdot
.72181 .51425 Mdot
.21607 .46812 Mdot
.06963 .14803 Mdot
.54934 .50221 Mdot
.24923 .19329 Mdot
.29489 .23495 Mdot
.99367 .61719 Mdot
.06515 .26977 Mdot
.48337 .91737 Mdot
.46492 .02534 Mdot
.54047 .12748 Mdot
.69949 .2493 Mdot
.08645 .29614 Mdot
.14659 .08063 Mdot
.75773 .88053 Mdot
.84592 .8831 Mdot
.73028 .44649 Mdot
.83463 .94354 Mdot
.45875 .11324 Mdot
.09891 .40869 Mdot
.20719 .47994 Mdot
.36508 .13039 Mdot
.04563 .08153 Mdot
.91532 .53984 Mdot
.25685 .02485 Mdot
.53174 .72192 Mdot
.27081 .87776 Mdot
.87631 .1583 Mdot
.18251 .17079 Mdot
.35654 .47007 Mdot
.9791 .32607 Mdot
.00792 .32532 Mdot
.46389 .11981 Mdot
.83427 .94496 Mdot
.65891 .82902 Mdot
.69086 .12353 Mdot
.73999 .01786 Mdot
.8597 .66993 Mdot
.77158 .88249 Mdot
.17619 .24735 Mdot
.35728 .02033 Mdot
.10656 .02733 Mdot
.6071 .42105 Mdot
.86925 .97603 Mdot
.88499 .50359 Mdot
.31056 .80456 Mdot
.4963 .99403 Mdot
.40452 .40196 Mdot
.04827 .6818 Mdot
.22936 .0121 Mdot
.955 .04949 Mdot
.34631 .05572 Mdot
.88832 .3627 Mdot
.92466 .32662 Mdot
.59514 .65208 Mdot
.38309 .59233 Mdot
.33326 .81541 Mdot
.35918 .50564 Mdot
.07038 .09978 Mdot
.69629 .8574 Mdot
.42517 .1004 Mdot
.72837 .08288 Mdot
.12792 .26264 Mdot
.66323 .72959 Mdot
.53128 .20118 Mdot
.46033 .72487 Mdot
.71704 .84078 Mdot
.39043 .38143 Mdot
.04165 .78071 Mdot
.78857 .5928 Mdot
.69148 .37117 Mdot
.36106 .45408 Mdot
.56757 .02819 Mdot
.37256 .60373 Mdot
.08571 .02549 Mdot
.96452 .53873 Mdot
.87399 .07596 Mdot
.22644 .54633 Mdot
.45374 .48296 Mdot
.13621 .38172 Mdot
.05663 .44245 Mdot
.05837 .46448 Mdot
.09328 .37754 Mdot
.96286 .74997 Mdot
.83288 .05678 Mdot
.92579 .42261 Mdot
.97605 .74933 Mdot
.66584 .5904 Mdot
.7911 .00224 Mdot
.10207 .80558 Mdot
.65076 .75455 Mdot
.29301 .62697 Mdot
.27017 .6093 Mdot
.85291 .85434 Mdot
.91722 .94869 Mdot
.65014 .78502 Mdot
.3929 .15833 Mdot
.99464 .61015 Mdot
.65533 .11245 Mdot
.07236 .71709 Mdot
.59664 .80288 Mdot
.24727 .23596 Mdot
.21697 .72947 Mdot
.68629 .94492 Mdot
.62365 .42315 Mdot
.05474 .74291 Mdot
.46914 .22974 Mdot
.6974 .26897 Mdot
.33918 .34687 Mdot
.48105 .42497 Mdot
.87144 .98429 Mdot
.04407 .38932 Mdot
.03502 .87835 Mdot
.12847 .39339 Mdot
.11425 .82264 Mdot
.1376 .2458 Mdot
.79385 .10976 Mdot
.38695 .70044 Mdot
.11746 .158 Mdot
.35843 .17164 Mdot
.06451 .49612 Mdot
.24841 .4432 Mdot
.46416 .86371 Mdot
.87778 .33593 Mdot
.08741 .68972 Mdot
.03422 .59799 Mdot
.69998 .61973 Mdot
.6101 .15376 Mdot
.16739 .82549 Mdot
.52452 .67337 Mdot
.73993 .93845 Mdot
.82813 .33837 Mdot
.39466 .14914 Mdot
.90842 .58753 Mdot
.24936 .01966 Mdot
.73316 .52123 Mdot
.88207 .6019 Mdot
.00936 .19061 Mdot
.45338 .71197 Mdot
.08799 .79546 Mdot
.04954 .12615 Mdot
.88255 .81476 Mdot
.59232 .43495 Mdot
.79817 .23553 Mdot
.48835 .57683 Mdot
.12605 .34761 Mdot
.9779 .28765 Mdot
.68917 .53108 Mdot
.38557 .39785 Mdot
.92852 .61838 Mdot
.63878 .0256 Mdot
.60518 .14168 Mdot
.30364 .57696 Mdot
.90561 .6085 Mdot
.00233 .41532 Mdot
.8957 .08701 Mdot
.80743 .12094 Mdot
.42137 .44032 Mdot
.56379 .12017 Mdot
.03193 .15016 Mdot
.46812 .40727 Mdot
.38026 .2791 Mdot
.55232 .7142 Mdot
.57072 .87888 Mdot
.97941 .81875 Mdot
.30916 .5606 Mdot
.26792 .16639 Mdot
.68204 .19429 Mdot
.13774 .30892 Mdot
.99148 .50312 Mdot
.85876 .94136 Mdot
.67881 .59485 Mdot
.68868 .23362 Mdot
.57094 .58713 Mdot
.4256 .83031 Mdot
.30151 .04503 Mdot
.66434 .69774 Mdot
.66181 .24522 Mdot
.68494 .88004 Mdot
.24282 .33723 Mdot
.32919 .32037 Mdot
.99168 .56507 Mdot
.08473 .69839 Mdot
.5948 .7234 Mdot
.14548 .13228 Mdot
.81745 .80442 Mdot
.07351 .06857 Mdot
.79174 .98919 Mdot
.67852 .6253 Mdot
.43542 .51526 Mdot
.27851 .00835 Mdot
.46593 .46305 Mdot
.70721 .4183 Mdot
.13931 .15267 Mdot
.85887 .04405 Mdot
.77916 .22695 Mdot
.39159 .5926 Mdot
.7602 .70304 Mdot
.55522 .28293 Mdot
.25182 .96256 Mdot
.63008 .91417 Mdot
.52915 .72389 Mdot
.69037 .2029 Mdot
.40247 .96122 Mdot
.69042 .05179 Mdot
.50779 .0791 Mdot
.06185 .24202 Mdot
.40526 .12205 Mdot
.3906 .35963 Mdot
.36575 .19333 Mdot
.09314 .79017 Mdot
.47163 .49181 Mdot
.20476 .1586 Mdot
.67462 .09331 Mdot
.26874 .72252 Mdot
.57061 .86641 Mdot
.89853 .96025 Mdot
.35688 .50835 Mdot
.54587 .45354 Mdot
.68633 .65578 Mdot
.43826 .37627 Mdot
.95494 .17626 Mdot
.05284 .22696 Mdot
.18111 .92309 Mdot
.15801 .39932 Mdot
.83594 .56157 Mdot
.55383 .36999 Mdot
.97277 .03559 Mdot
.35139 .74955 Mdot
.93024 .7831 Mdot
.10159 .03457 Mdot
.9865 .40479 Mdot
.32283 .98688 Mdot
.82876 .95656 Mdot
.58965 .95205 Mdot
.30955 .27169 Mdot
.70304 .88199 Mdot
.79113 .42673 Mdot
.44948 .15715 Mdot
.06665 .20104 Mdot
.75633 .18991 Mdot
.84096 .71285 Mdot
.01463 .44258 Mdot
.06713 .57756 Mdot
.36487 .23667 Mdot
.98342 .41808 Mdot
.06907 .56456 Mdot
.40971 .3409 Mdot
.02817 .97113 Mdot
.91757 .60863 Mdot
.88651 .47526 Mdot
.58153 .15898 Mdot
.37282 .00937 Mdot
.0365 .73335 Mdot
.6562 .86057 Mdot
.6768 .87313 Mdot
.59364 .88178 Mdot
.34973 .18396 Mdot
.79693 .05381 Mdot
.26084 .07427 Mdot
.51924 .35295 Mdot
.62395 .15713 Mdot
.31603 .59318 Mdot
.71131 .77764 Mdot
.28205 .8428 Mdot
.02948 .30496 Mdot
.27709 .75303 Mdot
.05004 .1976 Mdot
.00425 .10914 Mdot
.46273 .70656 Mdot
.47461 .8041 Mdot
.5151 .92885 Mdot
.74594 .15795 Mdot
.17703 .01215 Mdot
.59723 .28342 Mdot
.63226 .54481 Mdot
.08984 .66897 Mdot
.36972 .91433 Mdot
.0488 .2705 Mdot
.56989 .00937 Mdot
.76396 .39007 Mdot
.84637 .01744 Mdot
.58272 .88953 Mdot
.63106 .8415 Mdot
.59025 .4525 Mdot
.17235 .08959 Mdot
.23014 .94706 Mdot
.82043 .89943 Mdot
.88575 .92548 Mdot
.12474 .70243 Mdot
.0539 .94282 Mdot
.84425 .92092 Mdot
.06818 .27755 Mdot
.74812 .65034 Mdot
.76001 .61131 Mdot
.40162 .57551 Mdot
.9102 .4282 Mdot
.88546 .74147 Mdot
.42541 .26901 Mdot
.85809 .1179 Mdot
.27026 .58943 Mdot
.40416 .19342 Mdot
.87023 .93096 Mdot
.79167 .50609 Mdot
.53606 .35497 Mdot
.80666 .09606 Mdot
.04908 .42802 Mdot
.14203 .24621 Mdot
.41623 .30059 Mdot
.52665 .29207 Mdot
.77662 .76711 Mdot
.40923 .41482 Mdot
.78844 .86466 Mdot
.72105 .98832 Mdot
.66089 .20915 Mdot
.18177 .20826 Mdot
.83567 .07165 Mdot
.02677 .3626 Mdot
.06102 .3967 Mdot
.63079 .77845 Mdot
.92308 .37371 Mdot
.41681 .23667 Mdot
.84808 .91591 Mdot
.68621 .1009 Mdot
.37937 .71235 Mdot
.27698 .34215 Mdot
.50558 .83916 Mdot
.43073 .9017 Mdot
.36071 .9886 Mdot
.06548 .84043 Mdot
.56536 .34001 Mdot
.70373 .72968 Mdot
.91543 .69214 Mdot
.03417 .25005 Mdot
.76148 .05566 Mdot
.06223 .47898 Mdot
.68187 .06205 Mdot
.14177 .37006 Mdot
.49619 .94229 Mdot
.43267 .23492 Mdot
.84758 .26649 Mdot
.62237 .71422 Mdot
.57418 .16489 Mdot
.6594 .6362 Mdot
.33103 .22376 Mdot
.81765 .13606 Mdot
.88243 .4005 Mdot
.54987 .95381 Mdot
.91362 .56864 Mdot
.65322 .8596 Mdot
.15354 .34215 Mdot
.92817 .38517 Mdot
.59958 .84395 Mdot
.58154 .94826 Mdot
.77612 .9561 Mdot
.66675 .57973 Mdot
.10649 .48115 Mdot
.99355 .17912 Mdot
.4872 .84327 Mdot
.24328 .48578 Mdot
.86599 .96073 Mdot
.88962 .33893 Mdot
.42157 .88636 Mdot
.69469 .73955 Mdot
.07741 .81175 Mdot
.41814 .51934 Mdot
.05217 .08454 Mdot
.51392 .25693 Mdot
.70399 .90461 Mdot
.71727 .7785 Mdot
.91064 .84128 Mdot
.16183 .58897 Mdot
.30021 .54203 Mdot
.01594 .50995 Mdot
.56505 .00179 Mdot
.59998 .46577 Mdot
.11664 .49854 Mdot
.90333 .6988 Mdot
.83431 .09844 Mdot
.66744 .74789 Mdot
.38956 .4428 Mdot
.71655 .6614 Mdot
.26351 .92956 Mdot
.79997 .75731 Mdot
.25822 .04801 Mdot
.59014 .51474 Mdot
.35518 .76066 Mdot
.22795 .71728 Mdot
.47495 .5459 Mdot
.03243 .3531 Mdot
.41002 .2305 Mdot
.64095 .8797 Mdot
.30171 .00998 Mdot
.66707 .9877 Mdot
.32886 .80877 Mdot
.1188 .48413 Mdot
.38594 .0784 Mdot
.28794 .26721 Mdot
.69513 .04016 Mdot
.37895 .26895 Mdot
.5121 .17675 Mdot
.94657 .19549 Mdot
.87965 .65337 Mdot
.10326 .52814 Mdot
.87321 .93509 Mdot
.6853 .30648 Mdot
.81816 .80397 Mdot
.29064 .05103 Mdot
.74138 .96982 Mdot
.345 .50927 Mdot
.28864 .67373 Mdot
.28267 .54799 Mdot
.03332 .27469 Mdot
.93147 .06656 Mdot
.83158 .90792 Mdot
.56763 .26596 Mdot
.72464 .67327 Mdot
.11845 .6225 Mdot
.60691 .17522 Mdot
.54659 .89353 Mdot
.15789 .92234 Mdot
.51288 .09546 Mdot
.18287 .51634 Mdot
.50349 .84612 Mdot
.87842 .97352 Mdot
.25086 .02125 Mdot
.2283 .78424 Mdot
.39441 .47883 Mdot
.81379 .37801 Mdot
.57971 .05342 Mdot
.93517 .46166 Mdot
.76276 .97352 Mdot
.47666 .25877 Mdot
.58078 .57786 Mdot
.59659 .01558 Mdot
.84397 .05513 Mdot
.46207 .76952 Mdot
.80972 .31876 Mdot
.47946 .6885 Mdot
.10436 .56119 Mdot
.93407 .58114 Mdot
.83522 .77489 Mdot
.32149 .37346 Mdot
.33744 .5105 Mdot
.57436 .42129 Mdot
.01037 .66426 Mdot
.71457 .65801 Mdot
.85883 .96749 Mdot
.967 .55776 Mdot
.80043 .92188 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`;o00001?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo0_l00008ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;o
oooo0_l0000:ooooo`;o00003_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool02_ooool2o`0000;ooooo00Co0000oooooooooooooooo0_l0000:oooo
o`03o`000?oooooooooo00;o00002oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool00_ooool001kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo0_l00004ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool01?ooool2o`0000Sooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool2o`0000[o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool02_ooool2o`0000;ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`02ooooo`007_ooool00ol0003oooooooooo`1Fooooo`;o00001_ooool2o`0001Gooooo
0_l0000/ooooo`;o00004?ooool2o`00093ooooo000Nooooo`04o`000?ooooooooooooooo`;o0000
<_ooool2o`0000oooooo0_l0000>ooooo`;o00001_ooool2o`0001Gooooo0_l0000/ooooo`;o0000
4?ooool2o`0004gooooo0_l0000Zooooo`;o00005Oooool001kooooo00?o0000ooooooooool00ol0
000booooo`;o00003oooool2o`0004?ooooo0_l0000Yooooo`;o00001_ooool2o`0004Cooooo0_l0
0008ooooo`;o00008?ooool2o`0001Gooooo000Nooooo`03o`000?oooooooooo00;o0000Boooool2
o`0003cooooo0_l0000Yooooo`;o00001_ooool2o`0002cooooo0_l0000Pooooo`?o0000=_ooool0
01kooooo00?o0000ooooooooool0COooool2o`00027ooooo0_l0001Sooooo`;o00005Oooool2o`00
027ooooo0_l0000fooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o0000<oooool4o`0001oo
oooo0_l0000Qooooo`;o0000=oooool2o`0000Oooooo0_l0001`ooooo`007_ooool00ol0003ooooo
ooooo`04ooooo`;o00004_ooool2o`0000Gooooo0_l0000^ooooo`;o0000@_ooool2o`0001oooooo
0_l0000Fooooo`;o00004Oooool2o`0006Kooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0
000Iooooo`;o0000Toooool2o`0001Sooooo0_l0000?ooooo`;o0000Coooool2o`0001Gooooo000N
ooooo`03o`000?oooooooooo01gooooo0_l00022ooooo`;o0000:oooool2o`00057ooooo0_l0000=
ooooo`;o00005Oooool001kooooo00?o0000ooooooooool01oooool2o`0001Cooooo0_l00022oooo
o`;o0000M?ooool2o`0000Sooooo0_l0000Eooooo`;o00003Oooool001kooooo00?o0000oooooooo
ool01oooool2o`0008Kooooo0_l0001=ooooo`;o0000=oooool2o`0001oooooo0_l0000=ooooo`00
7_ooool00ol0003oooooooooo`2?ooooo`;o0000COooool2o`0003?ooooo0_l0000booooo`007_oo
ool00ol0003oooooooooo`1Nooooo`;o0000A_ooool2o`0000cooooo0_l0001Mooooo`?o0000<Ooo
ool001kooooo00?o0000ooooooooool05_ooool2o`0003Sooooo0_l0000<ooooo`;o0000A_ooool2
o`0000cooooo0_l0001Nooooo`;o00007?ooool2o`0001?ooooo000Nooooo`;o00005oooool2o`00
00;ooooo0_l0000dooooo`;o00002?ooool2o`0005cooooo0_l0000Nooooo`?o000000?oooooo`00
0?l00000DOooool2o`000003ooooool0003o000001?ooooo000Nooooo`03o`000?oooooooooo01[o
oooo0_l0000nooooo`;o00004?ooool2o`0004[ooooo0_l0000Nooooo`?o000000?oooooo`000?l0
00005Oooool2o`0000[ooooo0_l0000:ooooo`;o000000?oooooo`000?l000007oooool2o`0001Ko
oooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0001Cooooo`;o0000QOooool2o`0000[ooooo
0_l0000:ooooo`;o000000?oooooo`000?l00000=oooool001kooooo00?o0000ooooooooool05ooo
ool2o`000<7ooooo0_l0000Eooooo`;o0000<?ooool2o`0002;ooooo000Nooooo`03o`000?oooooo
oooo0=[ooooo0_l0000Eooooo`;o0000<?ooool2o`0002;ooooo000Nooooo`03o`000?oooooooooo
01Cooooo0_l0002Mooooo`;o00000oooool2o`0005cooooo0_l0000Cooooo`;o00006_ooool001ko
oooo00?o0000ooooooooool05?ooool2o`0006Sooooo0_l0000cooooo`;o00000oooool2o`0005;o
oooo0_l00008ooooo`;o00004oooool2o`0001[ooooo000Nooooo`03o`000?oooooooooo057ooooo
0_l0000[ooooo`;o0000S?ooool2o`0003Wooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0
000jooooo`;o00004?ooool2o`000<Gooooo0_l0000]ooooo`007_ooool00ol0003oooooooooo`03
ooooo`;o00009oooool2o`00017ooooo0_l0000Cooooo`;o00008oooool2o`0002Kooooo0_l0001e
ooooo`;o00005_ooool2o`0001Gooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l0000Ooooo
o`;o00009_ooool2o`0000_ooooo0_l0000Fooooo`;o00009_ooool2o`0004Kooooo0_l00015oooo
o`;o00005Oooool001kooooo00Co0000ooooool0003o00002_ooool4o`0003_ooooo0_l0000Eoooo
o`;o0000Q_ooool2o`0003Cooooo0_l0000Vooooo`007_ooool01?l0003oooooo`000?l0000<oooo
o`;o00009Oooool2o`0001Cooooo0_l00022ooooo`;o0000@?ooool2o`0000gooooo0_l0000Voooo
o`007_ooool01?l0003oooooo`000?l0000cooooo`;o0000?Oooool2o`0004oooooo0_l00008oooo
o`;o00001oooool2o`0003Oooooo0_l0000eooooo`007_ooool00ol0003oooooooooo`1cooooo`;o
00008_ooool2o`0000[ooooo0_l0000Cooooo`;o00002_ooool2o`00017ooooo0_l0000Yooooo`;o
0000@oooool001kooooo00?o0000ooooooooool04oooool2o`0008;ooooo0_l0000:ooooo`;o0000
4oooool2o`0004Sooooo0_l00007ooooo`;o0000>_ooool001kooooo0_l00007ooooo`;o00002ooo
ool2o`00077ooooo0_l0001Cooooo`;o0000;_ooool2o`0003[ooooo000Nooooo`03o`000?oooooo
oooo00Kooooo0_l0001nooooo`;o0000Doooool2o`0002oooooo0_l00007ooooo`;o00000_ooool2
o`0002cooooo000Nooooo`?o00007?ooool2o`0003kooooo0_l0000cooooo`;o0000NOooool2o`00
00Oooooo0_l00002ooooo`;o0000;?ooool001kooooo0ol0000Looooo`;o00006oooool2o`00027o
oooo0_l0000Iooooo`;o00006?ooool2o`0006_ooooo0_l00017ooooo`007_ooool2o`0002Oooooo
0_l0000Aooooo`;o0000??ooool2o`0001Sooooo0_l0000nooooo`;o0000:oooool2o`0004Oooooo
000Nooooo`03o`000?oooooooooo02Kooooo0_l0000:ooooo`;o0000GOooool2o`0002kooooo0_l0
000>ooooo`;o0000@?ooool2o`0003;ooooo000Nooooo`03o`000?oooooooooo03;ooooo0_l00017
ooooo`;o00005Oooool3o`0001kooooo0_l0000<ooooo`?o0000?_ooool2o`0000oooooo0_l0000b
ooooo`007_ooool00ol0003oooooooooo`1Wooooo`;o00004_ooool2o`0000?ooooo0_l0000@oooo
o`?o00001?ooool2o`0001Sooooo0_l0000=ooooo`;o00006?ooool2o`0002Cooooo0_l00013oooo
o`007_ooool00ol0003oooooooooo`08ooooo`;o00000_ooool2o`0004[ooooo0_l0000=ooooo`;o
00005oooool2o`0001Oooooo0_l0000Aooooo`;o0000;_ooool2o`0006Wooooo000Nooooo`03o`00
0?oooooooooo00Sooooo0_l00002ooooo`;o0000B_ooool2o`0001Wooooo0_l0000gooooo`;o0000
0_ooool2o`0009Gooooo000Nooooo`03o`000?oooooooooo02_ooooo0_l0000dooooo`;o00004?oo
ool2o`0003_ooooo0_l00014ooooo`;o0000Coooool001kooooo00?o0000ooooooooool0:oooool2
o`00013ooooo0_l0000Rooooo`;o00000oooool2o`0008kooooo0_l0000>ooooo`;o0000?oooool0
01kooooo00?o0000ooooooooool0?Oooool2o`0002Oooooo0_l0001Tooooo`;o00000_ooool2o`00
02gooooo0_l00005ooooo`;o0000?oooool001kooooo00?o0000ooooooooool0`Oooool2o`0000Wo
oooo0_l00002ooooo`;o0000;Oooool2o`0004Kooooo000Nooooo`03o`000?oooooooooo05Kooooo
0_l0000Vooooo`;o0000@Oooool2o`0008Cooooo000Nooooo`03o`000?oooooooooo01?ooooo0_l0
0011ooooo`;o00009_ooool2o`0007Oooooo0_l0001>ooooo`007_ooool2o`0000Oooooo0_l0000;
ooooo`;o0000@oooool2o`0002;ooooo0_l0001iooooo`;o0000C_ooool001kooooo00?o0000oooo
ooooool01_ooool2o`00027ooooo0_l0000]ooooo`;o00008_ooool2o`0001Oooooo0_l0000[oooo
o`;o0000MOooool2o`0000cooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0000Iooooo`;o
00001Oooool2o`0006?ooooo0_l00005ooooo`;o0000:oooool2o`0000?ooooo0_l0000Uooooo`;o
000000?oooooo`000?l000003_ooool2o`0001Kooooo0_l0000?ooooo`;o00003Oooool2o`0000co
oooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0000Iooooo`;o00006_ooool2o`0000oooooo
0_l0000[ooooo`;o00004?ooool2o`0002Wooooo0_l000000ooooooo0000o`000009ooooo`;o0000
9Oooool2o`000003ooooool0003o000000kooooo0_l0000Fooooo`;o00003oooool2o`0001_ooooo
000Nooooo`03o`000?oooooooooo03kooooo0_l0000?ooooo`;o0000:oooool2o`0003_ooooo0_l0
00000ooooooo0000o`000029ooooo`007_ooool00ol0003oooooooooo`1Cooooo`;o00008_ooool2
o`0003kooooo0_l0001>ooooo`;o0000?_ooool001kooooo00?o0000ooooooooool0Doooool2o`00
01?ooooo0_l0000=ooooo`;o0000?_ooool2o`000003ooooool0003o000002;ooooo0_l0000Woooo
o`;o0000?_ooool001kooooo0_l0000hooooo`;o0000;oooool2o`0000Kooooo0_l00018ooooo`;o
00008_ooool2o`0006Oooooo000Nooooo`;o00002?ooool2o`0002kooooo0_l0000gooooo`;o0000
<?ooool2o`0001gooooo0_l0001_ooooo`?o00000oooool2o`0000gooooo000Nooooo`03o`000?oo
oooooooo00Oooooo0_l0000gooooo`;o0000H?ooool2o`0001gooooo0_l0001_ooooo`?o00000ooo
ool2o`0000Gooooo0_l00006ooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o0000:?ooool2
o`0000Oooooo0_l0003]ooooo`;o00003_ooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo
00gooooo0_l0000Mooooo`;o00002Oooool2o`0003Gooooo0_l0000Xooooo`;o0000NOooool2o`00
01[ooooo0_l0000Fooooo`007_ooool00ol0003oooooooooo`0/ooooo`;o0000@?ooool2o`0002So
oooo0_l0001]ooooo`;o00002_ooool2o`0003;ooooo000Nooooo`04o`000?oooooo0000o`0009Oo
oooo0_l0001Hooooo`;o00004oooool2o`0003kooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`04o`000?oooooo0000o`0000Gooooo0_l0000coooo
o`;o00001Oooool4o`0000Oooooo0_l0000Tooooo`;o00002_ooool2o`0005Wooooo0_l0000Foooo
o`;o0000Doooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnH
V9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool01_ooool2o`0000Cooooo0_l0000]
ooooo`;o00001Oooool4o`0000Oooooo0_l0000Tooooo`;o00002_ooool2o`0005Wooooo0_l0001D
ooooo`;o00005Oooool000?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7o
k^k^00Oooooo0ol0000<ooooo`;o00001?ooool2o`00033ooooo0_l0001Sooooo`;o0000>oooool2
o`0004Sooooo0_l0000Eooooo`000oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h01_ooool00ol0003oooooooooo`0Booooo`;o0000<?ooool2o`0002_ooooo0_l0000f
ooooo`;o0000<Oooool2o`0000Sooooo0_l0001Oooooo`000oooool01Ol0003ooooooooooooooooo
000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`1aooooo`;o0000JOooool2
o`0006Wooooo0003ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo02gooooo0_l00008ooooo`;o0000BOooool2o`0004;ooooo0ol0000:
ooooo`;o0000=oooool2o`0003Wooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0;Oooool2o`0000Sooooo0_l0
0019ooooo`;o0000@_ooool3o`0000Cooooo0_l00004ooooo`;o0000=oooool2o`0003Wooooo0003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo
00?o0000ooooooooool05_ooool2o`0002Sooooo0_l0002;ooooo`;o0000<Oooool2o`0004Gooooo
000Nooooo`03o`000?oooooooooo01Kooooo0_l0000Xooooo`;o0000WOooool2o`0001oooooo0_l0
000<ooooo`;o0000=oooool001kooooo00?o0000ooooooooool08?ooool2o`0006gooooo0_l0001>
ooooo`;o0000;Oooool2o`0003Oooooo000Nooooo`03o`000?oooooooooo023ooooo0_l00016oooo
o`;o00009Oooool2o`000;Kooooo000Nooooo`03o`000?oooooooooo00gooooo0_l0001Iooooo`;o
0000?Oooool2o`00053ooooo0_l0001<ooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o0000
L_ooool2o`00017ooooo0_l0000?ooooo`Ko0000C_ooool2o`0004cooooo000Nooooo`03o`000?oo
oooooooo05cooooo0_l000000ooooooo0000o`00000Pooooo`;o00001_ooool2o`0000Wooooo0_l0
000?ooooo`;o00000_ooool2o`0001;ooooo0_l0000Mooooo`;o00003_ooool2o`0005Wooooo000N
ooooo`03o`000?oooooooooo04cooooo0_l0000>ooooo`;o000000?oooooo`000?l000004_ooool2
o`0000kooooo0_l00004ooooo`;o0000<_ooool2o`0001gooooo0_l0000>ooooo`;o00004Oooool2
o`0003gooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`1<ooooo`;o00009Oooool2o`00
00kooooo0_l0001jooooo`;o0000?Oooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo013o
oooo0_l0000Nooooo`;o0000_Oooool2o`0000kooooo0_l00016ooooo`007_ooool00ol0003ooooo
ooooo`0@ooooo`;o00005oooool3o`0000Cooooo0_l00003ooooo`;o0000B_ooool2o`00053ooooo
0_l0000Jooooo`;o0000E_ooool001kooooo00?o0000ooooooooool01oooool2o`00023ooooo0ol0
0009ooooo`;o0000B_ooool2o`0000Cooooo0_l0001:ooooo`;o00002_ooool2o`0006Kooooo000N
ooooo`;o00002?ooool2o`0007kooooo0_l0000kooooo`;o00006Oooool2o`0004_ooooo0_l0000I
ooooo`007_ooool00ol0003oooooooooo`34ooooo`;o0000I_ooool2o`0001Wooooo000Nooooo`03
o`000?oooooooooo05Kooooo0_l0000oooooo`;o00002_ooool2o`0004;ooooo0_l0001Nooooo`00
7_ooool00ol0003oooooooooo`04ooooo`;o00007oooool2o`0002oooooo0_l0000oooooo`;o0000
2_ooool2o`0002Sooooo0_l0000Hooooo`;o0000G_ooool001kooooo00Co0000ooooool0003o0000
0oooool2o`0001oooooo0_l0002Vooooo`;o0000>_ooool2o`0000kooooo0_l0000/ooooo`007_oo
ool01?l0003oooooo`000?l00013ooooo`;o00004oooool2o`0001cooooo0_l0000=ooooo`;o0000
;?ooool2o`0001_ooooo0_l0000<ooooo`;o0000:?ooool2o`0000Cooooo0_l00008ooooo`;o0000
;?ooool001kooooo00?o0000ooooooooool03?ooool2o`0000?ooooo0_l0000Iooooo`;o00005_oo
ool2o`0001?ooooo0_l00006ooooo`;o00005?ooool2o`0000gooooo0_l0000/ooooo`;o00006ooo
ool2o`0000cooooo0_l0000^ooooo`;o0000=_ooool001kooooo00?o0000ooooooooool01oooool2
o`0000?ooooo0_l00003ooooo`;o00006Oooool2o`0000kooooo0_l0000Sooooo`;o00007?ooool2
o`0003Gooooo0_l0002?ooooo`007_ooool00ol0003oooooooooo`07ooooo`;o00002Oooool2o`00
02Sooooo0_l00011ooooo`;o0000=Oooool2o`0008oooooo000Nooooo`03o`000?oooooooooo01;o
oooo0_l0000=ooooo`;o00006Oooool2o`00013ooooo0_l0000Xooooo`;o0000D?ooool2o`0003Oo
oooo0_l00007ooooo`;o0000>Oooool001kooooo00?o0000ooooooooool04Oooool2o`0000_ooooo
0_l000000ooooooo0000o`00000[ooooo`;o0000:?ooool2o`0003Kooooo0_l0000<ooooo`;o0000
2_ooool2o`0003Oooooo0_l00007ooooo`;o00005Oooool2o`0002;ooooo000Nooooo`03o`000?oo
oooooooo017ooooo0_l0000;ooooo`;o0000H?ooool2o`0001_ooooo0_l0000Aooooo`;o00003?oo
ool2o`0006?ooooo0_l0000Rooooo`007_ooool00ol0003oooooooooo`20ooooo`;o00006oooool2
o`0000[ooooo0_l0002?ooooo`;o00002oooool001kooooo00?o0000ooooooooool0Yoooool4o`00
03Wooooo0_l00008ooooo`;o0000B_ooool2o`0000_ooooo000Nooooo`04o`000?oooooooooooooo
o`;o00005Oooool2o`0008gooooo0_l0000kooooo`;o00002?ooool2o`0000Kooooo0_l0001?oooo
o`007_ooool01?l0003oooooooooooooool2o`00017ooooo0_l00002ooooo`;o0000g?ooool2o`00
00_ooooo0_l00005ooooo`;o0000>oooool001kooooo0_l0000Eooooo`;o0000KOooool2o`0007ko
oooo0_l00005ooooo`;o00005?ooool2o`0002Gooooo000Nooooo`03o`000?oooooooooo00Gooooo
0_l0001looooo`;o0000Voooool2o`0002Gooooo000Nooooo`03o`000?oooooooooo00Gooooo0_l0
000Rooooo`;o0000/?ooool2o`0006[ooooo000Nooooo`03o`000?oooooooooo02Wooooo0_l0002`
ooooo`;o0000J_ooool001kooooo00?o0000ooooooooool0Z_ooool2o`0001_ooooo0_l0000Woooo
o`;o0000EOooool001kooooo00?o0000ooooooooool0Z_ooool2o`0001_ooooo0_l0000Wooooo`;o
0000EOooool001kooooo0_l0001Xooooo`;o00007Oooool2o`00013ooooo0_l0000Fooooo`;o0000
DOooool2o`0004;ooooo000Nooooo`;o0000J?ooool2o`0001gooooo0_l0000@ooooo`;o00005_oo
ool2o`00057ooooo0_l00012ooooo`007_ooool3o`0002_ooooo0_l00035ooooo`;o0000=Oooool2
o`0000oooooo0_l0000;ooooo`007_ooool3o`0002_ooooo0_l0000Nooooo`;o0000@Oooool2o`00
06;ooooo0_l0000eooooo`;o00003oooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo04_o
oooo0_l000000ooooooo0000o`00000gooooo`Co00000oooool2o`0008?ooooo0_l0000booooo`00
7_ooool00ol0003oooooooooo`1>ooooo`;o0000=oooool4o`0008Sooooo0_l00004ooooo`;o0000
;?ooool001kooooo00?o0000ooooooooool0Boooool2o`000;cooooo0_l0000>ooooo`;o00000_oo
ool2o`0002Sooooo000Nooooo`03o`000?oooooooooo02kooooo0_l0000Kooooo`;o00002Oooool2
o`0001?ooooo0_l0000:ooooo`;o00002?ooool2o`0001gooooo0_l0000Booooo`;o0000Doooool2
o`0000Cooooo0_l0000<ooooo`;o0000:?ooool001kooooo00?o0000ooooooooool0;_ooool2o`00
02Kooooo0_l0000Cooooo`;o00002_ooool2o`0000Gooooo0_l000000ooooooo0000o`00000Moooo
o`;o00004_ooool2o`0005Wooooo0_l0000`ooooo`;o00001?ooool001kooooo00?o0000oooooooo
ool09Oooool2o`0004?ooooo0_l0000Booooo`;o0000Loooool2o`0004cooooo0_l00004ooooo`00
7_ooool2o`0002Kooooo0_l00013ooooo`;o00002_ooool2o`0006Wooooo0_l0000@ooooo`;o0000
9oooool2o`0001Kooooo0_l0000Aooooo`007_ooool00ol0003oooooooooo`06ooooo`;o0000:?oo
ool2o`0004Cooooo0_l0000]ooooo`;o00000oooool2o`0001Oooooo0_l0000Looooo`;o0000:Ooo
ool2o`0000kooooo0_l0000Fooooo`;o00004Oooool001kooooo00?o0000ooooooooool01_ooool2
o`0002Sooooo0_l0001?ooooo`;o00008Oooool3o`0000?ooooo0_l0000Gooooo`;o0000Aoooool2
o`0003Wooooo000Nooooo`03o`000?oooooooooo07_ooooo0_l00004ooooo`;o00008Oooool2o`00
05Sooooo0_l00017ooooo`007_ooool00ol0003oooooooooo`05ooooo`?o0000@oooool2o`0002Ko
oooo0_l00006ooooo`;o0000POooool2o`0001gooooo0_l0000Xooooo`007_ooool00ol0003ooooo
ooooo`05ooooo`?o0000@oooool2o`0002Kooooo0_l0002Xooooo`;o00003Oooool2o`0001Wooooo
000Nooooo`03o`000?oooooooooo00Gooooo0_l0000Sooooo`;o00001Oooool2o`0001Oooooo0_l0
001Tooooo`;o0000IOooool2o`0001?ooooo0_l0000Iooooo`007_ooool00ol0003oooooooooo`0Z
ooooo`;o00001Oooool2o`0001Oooooo0_l0000Hooooo`;o00009_ooool2o`0002;ooooo0_l0000[
ooooo`;o00002Oooool2o`0000kooooo0_l0000Mooooo`;o0000;_ooool001kooooo00?o0000oooo
ooooool09_ooool2o`0003cooooo0_l0000Tooooo`Co00001Oooool2o`0001;ooooo0_l0000doooo
o`;o00002Oooool2o`0000kooooo0_l0000Mooooo`;o00003oooool2o`0001gooooo000Nooooo`03
o`000?oooooooooo01[ooooo0_l0000:ooooo`;o0000H_ooool2o`0000Oooooo0_l0000<ooooo`;o
00001?ooool2o`0004Oooooo0_l0000Booooo`;o00004Oooool2o`0000oooooo0_l0000Mooooo`00
7_ooool00ol0003oooooooooo`0Jooooo`;o00003?ooool2o`0003Oooooo0_l00004ooooo`;o0000
4_ooool2o`0001?ooooo0_l0000?ooooo`;o00001oooool2o`0003gooooo0_l00005ooooo`;o0000
4_ooool2o`00047ooooo000Nooooo`03o`000?oooooooooo02Sooooo0_l0000gooooo`;o00001?oo
ool2o`0001;ooooo0_l0000Cooooo`;o00005?ooool2o`0000;ooooo0_l0000Gooooo`;o00009?oo
ool2o`0003oooooo0_l0000Kooooo`007_ooool00ol0003oooooooooo`2Vooooo`;o00006oooool2
o`0006Gooooo0_l00006ooooo`;o00004oooool001kooooo00?o0000ooooooooool01oooool2o`00
0003ooooool0003o00000>Sooooo0_l0000looooo`;o00004oooool000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000oooo
ooooool01oooool2o`000003ooooool0003o000000;o00006?ooool2o`0008Gooooo0_l00015oooo
o`;o0000DOooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo0_l00002ooooo`;o00005?ooool2o`00
057ooooo0_l0000booooo`;o0000V?ooool000?ooooo00Go410@oooooooooooooooooa0@400;oooo
o`Go00001_ooool3o`0000Gooooo0_l00009ooooo`;o00006oooool4o`00023ooooo0_l0000Poooo
o`;o00001?ooool2o`000:3ooooo0_l0000Zooooo`000oooool01Ol0003ooooooooooooooooo0000
00_ooooo00CoA4A4omgMgOoooooo00001oooool00ol0003oooooooooo`05ooooo`;o00009_ooool4
o`00023ooooo0_l0000Pooooo`;o00002_ooool2o`0009[ooooo0_l0000Zooooo`000oooool01Ol0
003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003ooooooooo
o`1oooooo`;o00004oooool2o`0001Sooooo0_l0000Cooooo`;o0000N?ooool2o`0000Sooooo0003
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oo
oooooooo00;o00006_ooool2o`0007Kooooo0_l0000Hooooo`;o00004oooool2o`0007Sooooo0_l0
0008ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001ooo
ool00ol0003oooooooooo`02o`0001[ooooo0_l0002Xooooo`;o0000F_ooool2o`0001?ooooo0_l0
000>ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_oo
ool2o`0008;ooooo0_l00013ooooo`;o0000F_ooool2o`0001?ooooo0_l0000>ooooo`007_ooool2
o`0005_ooooo0_l0000Oooooo`;o00001?ooool2o`0003Wooooo0_l0000Tooooo`;o0000F?ooool2
o`0000Wooooo000Nooooo`03o`000?oooooooooo05[ooooo0_l0000Fooooo`;o00001oooool2o`00
02Sooooo0_l0000@ooooo`;o00000oooool2o`0000?ooooo0_l0000Oooooo`;o0000AOooool2o`00
017ooooo0_l00003ooooo`;o00001?ooool001kooooo00?o0000ooooooooool08Oooool2o`0004oo
oooo0_l0000Tooooo`;o00002oooool2o`00013ooooo0_l00008ooooo`;o00001?ooool2o`0002?o
oooo0_l0000kooooo`;o00005_ooool2o`0000Cooooo000Nooooo`03o`000?oooooooooo00cooooo
0_l0000Cooooo`;o0000MOooool2o`0002gooooo0_l0000Sooooo`;o00003oooool2o`0002Gooooo
0_l0000Qooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o00009_ooool2o`0002cooooo0_l0
000<ooooo`;o0000;oooool2o`0005[ooooo0_l0000Uooooo`;o00008Oooool001kooooo00?o0000
ooooooooool0=?ooool2o`0002cooooo0_l0000<ooooo`;o0000;oooool2o`0001Wooooo0_l0000Y
ooooo`;o00005?ooool2o`0004Sooooo000Mooooo`;o0000Noooool2o`0003_ooooo0_l00004oooo
o`;o0000:Oooool2o`0001Cooooo0_l00018ooooo`007Oooool2o`0007_ooooo0_l0000:ooooo`;o
0000;oooool2o`0008oooooo000Nooooo`04o`000?ooooooooooooooo`;o00002oooool2o`0003go
oooo0_l0000Booooo`;o00006?ooool2o`0000Sooooo0_l0001Iooooo`;o00002Oooool2o`0005[o
oooo000Nooooo`04o`000?ooooooooooooooo`;o00002oooool2o`0003gooooo0_l0000Booooo`;o
00006?ooool2o`0006?ooooo0_l00007ooooo`Co0000F_ooool001kooooo00?o0000ooooooooool0
]oooool2o`00033ooooo0_l0000Xooooo`;o0000<_ooool001kooooo0_l0000Iooooo`;o0000Tooo
ool2o`0000Sooooo0_l00003ooooo`;o0000=?ooool2o`0001oooooo0_l0000booooo`007_ooool0
0ol0003oooooooooo`0Hooooo`;o0000Eoooool2o`0003[ooooo0_l0000=ooooo`;o00006?ooool2
o`0001[ooooo0_l0001Cooooo`007_ooool00ol0003oooooooooo`1Rooooo`;o00003Oooool2o`00
05Oooooo0_l0000:ooooo`;o0000Koooool001kooooo00?o0000ooooooooool0H_ooool2o`0006Ko
oooo0_l0001?ooooo`;o00003oooool2o`0001Wooooo000Nooooo`03o`000?oooooooooo00oooooo
0_l00022ooooo`;o0000:_ooool2o`0005[ooooo0_l00009ooooo`;o00001?ooool5o`0000Cooooo
0_l0000@ooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o0000<Oooool2o`0000gooooo0_l0
000Eooooo`;o0000:Oooool2o`0002[ooooo0_l0001Uooooo`;o00001Oooool4o`0000Cooooo0_l0
000@ooooo`007_ooool00ol0003oooooooooo`12ooooo`;o00003Oooool2o`0001Gooooo0_l00006
ooooo`;o0000eOooool001kooooo00?o0000ooooooooool0L?ooool2o`0006Wooooo0_l0001Zoooo
o`007_ooool00ol0003oooooooooo`2Qooooo`;o00001_ooool2o`00033ooooo0_l0000oooooo`;o
00006oooool2o`0000cooooo000Nooooo`03o`000?oooooooooo013ooooo0_l0000=ooooo`;o0000
7_ooool2o`0003_ooooo0_l0000Sooooo`;o00001_ooool2o`00077ooooo0_l0000Kooooo`;o0000
3?ooool001kooooo00?o0000ooooooooool04?ooool2o`0000gooooo0_l00002ooooo`;o00006_oo
ool2o`0003_ooooo0_l0000Aooooo`;o0000]_ooool001kooooo00?o0000ooooooooool03Oooool2
o`0001Cooooo0_l0000Vooooo`;o0000@_ooool2o`00073ooooo0_l00014ooooo`007_ooool00ol0
003oooooooooo`0=ooooo`;o0000??ooool2o`00057ooooo0_l0001Qooooo`;o00003_ooool2o`00
03Cooooo000Nooooo`03o`000?oooooooooo09Gooooo0_l00007ooooo`;o0000;_ooool2o`00047o
oooo0_l0000dooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o0000P_ooool2o`0000Oooooo
0_l0000Pooooo`;o00003?ooool2o`0007Oooooo000Nooooo`03o`000?oooooooooo017ooooo0_l0
000?ooooo`;o00009_ooool2o`0007Cooooo0_l0000Xooooo`;o0000DOooool2o`0000;ooooo0_l0
0004ooooo`007_ooool2o`0002?ooooo0_l00005ooooo`;o00007oooool2o`0006;ooooo0_l0000j
ooooo`;o0000DOooool2o`0000;ooooo0_l00004ooooo`007_ooool00ol0003oooooooooo`0Yoooo
o`;o0000A_ooool2o`0003_ooooo0_l0001/ooooo`;o00008?ooool2o`0000Oooooo000Nooooo`03
o`000?oooooooooo01Cooooo0_l0001Jooooo`?o0000R_ooool2o`0001gooooo0_l0000;ooooo`;o
00004oooool2o`0000Oooooo000Nooooo`04o`000?ooooooooooooooo`;o00003?ooool2o`0000?o
oooo0_l0000Xooooo`;o0000:_ooool4o`0000;ooooo0_l0000hooooo`;o0000DOooool2o`00027o
oooo0_l00007ooooo`;o00007?ooool001kooooo00Co0000oooooooooooooooo0_l0000<ooooo`;o
0000;Oooool2o`0002;ooooo0_l00006ooooo`Co0000??ooool2o`00013ooooo0_l0000Yooooo`;o
0000=oooool4o`0002?ooooo000Nooooo`03o`000?oooooooooo02Gooooo0_l0000@ooooo`;o0000
:Oooool2o`0002Gooooo0_l0000aooooo`;o0000:Oooool2o`0003Wooooo0_l0000Sooooo`007_oo
ool00ol0003oooooooooo`0Uooooo`;o00004?ooool2o`0003[ooooo0_l0000?ooooo`;o00000ooo
ool2o`00017ooooo0_l00010ooooo`;o00002_ooool2o`0005_ooooo000Nooooo`03o`000?oooooo
oooo07?ooooo0_l0000?ooooo`;o00005_ooool2o`00043ooooo0_l00005ooooo`;o00000oooool2
o`0002oooooo0_l0000Zooooo`007_ooool00ol0003oooooooooo`1/ooooo`;o0000:oooool2o`00
04[ooooo0_l0000Qooooo`Co00003oooool2o`0002[ooooo000Nooooo`03o`000?oooooooooo01go
oooo0_l0001=ooooo`;o00008oooool2o`0000Kooooo0_l0001]ooooo`Co0000>oooool001kooooo
00?o0000ooooooooool07Oooool2o`0003gooooo0_l00005ooooo`Co0000:_ooool2o`0004Wooooo
0_l0001Yooooo`007_ooool00ol0003oooooooooo`1Looooo`;o00001Oooool4o`0007Gooooo0_l0
001Yooooo`007_ooool00ol0003oooooooooo`0[ooooo`;o0000ooooool9ooooo`;o00001?ooool2
o`0000[ooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0000:ooooo`;o00005_ooool2o`00
033ooooo0_l00018ooooo`;o0000O?ooool2o`0000kooooo0_l00004ooooo`;o00002_ooool001ko
oooo00?o0000ooooooooool01oooool2o`0000[ooooo0_l00018ooooo`;o0000B?ooool2o`00023o
oooo0_l00018ooooo`;o00004?ooool2o`00023ooooo000Nooooo`03o`000?oooooooooo023ooooo
0_l0000Tooooo`;o00004?ooool2o`0003cooooo0_l0000aooooo`;o0000??ooool2o`0000[ooooo
0_l0000booooo`007_ooool2o`00027ooooo0_l0000Tooooo`;o00004?ooool2o`0003cooooo0_l0
0015ooooo`;o0000:?ooool2o`0003kooooo000Nooooo`03o`000?oooooooooo0=gooooo0_l0000B
ooooo`;o0000E?ooool001kooooo00?o0000ooooooooool0Q?ooool2o`0006_ooooo0_l0000@oooo
o`;o0000<Oooool2o`0000oooooo000Nooooo`03o`000?oooooooooo01kooooo0_l00010ooooo`;o
00005_ooool2o`0000[ooooo0_l0000Booooo`;o0000JOooool2o`00037ooooo0_l0000?ooooo`00
7_ooool00ol0003oooooooooo`0>ooooo`;o00003_ooool2o`0000cooooo0_l0000Booooo`;o0000
7_ooool2o`0001Kooooo0_l0000Nooooo`;o0000L_ooool2o`0003Wooooo000Nooooo`03o`000?oo
oooooooo00kooooo0_l00002ooooo`;o00006?ooool2o`0001;ooooo0_l0003:ooooo`;o0000<?oo
ool2o`0000Oooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0000Eooooo`;o0000n_ooool2
o`0001Oooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`0Yooooo`;o0000n_ooool2o`00
023ooooo000Nooooo`03o`000?oooooooooo07kooooo0_l00037ooooo`007_ooool00ol0003ooooo
ooooo`0Booooo`;o0000??ooool2o`0000gooooo0_l0000Mooooo`;o00006oooool2o`0001cooooo
0_l0000dooooo`;o0000E_ooool001kooooo00?o0000ooooooooool04_ooool2o`0003cooooo0_l0
000=ooooo`;o0000>_ooool2o`0001cooooo0_l0000Jooooo`;o00006?ooool2o`0003_ooooo0_l0
000Iooooo`007_ooool00ol0003oooooooooo`03ooooo`;o0000<_ooool2o`0008Cooooo0_l0000F
ooooo`;o00005oooool2o`0003cooooo0_l0000Iooooo`007_ooool00ol0003oooooooooo`03oooo
o`;o0000<_ooool2o`0002cooooo0_l0001?ooooo`;o00001Oooool2o`0001gooooo0_l0000@oooo
o`;o0000<oooool2o`0002;ooooo000Nooooo`03o`000?oooooooooo033ooooo0_l00007ooooo`;o
00006Oooool2o`0000oooooo0_l0001?ooooo`;o00007?ooool2o`0000Kooooo0_l0000`ooooo`;o
00004oooool2o`0002;ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo033ooooo0_l00007oooo
o`;o00006Oooool2o`0000gooooo0_l0000Cooooo`;o000000?oooooo`000?l00000>Oooool2o`00
01cooooo0_l00003ooooo`;o00008Oooool2o`00013ooooo0_l0000Tooooo`;o00004Oooool000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So
8B4Q00Kooooo00?o0000ooooooooool01oooool2o`00023ooooo0_l00008ooooo`;o0000;_ooool2
o`0000kooooo0_l00003ooooo`;o000000?oooooo`000?l00000G?ooool2o`00027ooooo0_l0000f
ooooo`;o00004Oooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooo
ooooooooool000001_ooool3o`0000Oooooo0_l0000Pooooo`;o00002?ooool2o`0003kooooo0_l0
000Jooooo`;o0000]_ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1Pooooo`;o00004oooool2o`0001Sooooo
0_l0002:ooooo`;o0000:_ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?mEEEGo0000oa0@4?o<c<`01_ooool01?l0003oooooooooooooool2o`0005gooooo0_l0000Coooo
o`;o0000Y?ooool2o`0002[ooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool00omE
EEGoQhN7ooooo`08ooooo`04o`000?ooooooooooooooo`;o0000DOooool2o`000<cooooo0_l00002
ooooo`;o00005oooool2o`0000Kooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
0ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo01Gooooo0_l0000mooooo`;o0000Noooool2
o`00023ooooo0_l0000]ooooo`;o00000_ooool2o`0001Oooooo0_l00006ooooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003ooooooooo
o`0Eooooo`;o0000^_ooool2o`0001?ooooo0_l0000;ooooo`;o0000D_ooool001kooooo00?o0000
ooooooooool0f_ooool2o`0000[ooooo0_l00012ooooo`;o00004oooool2o`0000Kooooo000Noooo
o`03o`000?oooooooooo02;ooooo0_l0002fooooo`;o00000oooool2o`0004Wooooo0_l0000Coooo
o`;o00001_ooool001kooooo00?o0000ooooooooool08_ooool2o`000;Cooooo0_l00005ooooo`;o
0000I_ooool001kooooo00?o0000ooooooooool0B_ooool2o`0000oooooo0_l0001kooooo`;o0000
KOooool001kooooo00?o0000ooooooooool0B_ooool2o`0000oooooo0_l0001Hooooo`;o0000T?oo
ool001kooooo00?o0000ooooooooool0]Oooool2o`00093ooooo000Nooooo`03o`000?oooooooooo
057ooooo0_l0001oooooo`;o0000Loooool001kooooo00?o0000ooooooooool0DOooool2o`0004So
oooo0_l0000eooooo`;o0000@?ooool2o`00037ooooo000Nooooo`03o`000?oooooooooo00Gooooo
0_l0000=ooooo`;o0000O_ooool2o`0000Gooooo0_l0000:ooooo`;o0000Aoooool2o`0002;ooooo
0_l0000aooooo`007_ooool00ol0003oooooooooo`05ooooo`;o00003Oooool2o`0007gooooo0ol0
000Aooooo`;o0000?Oooool2o`0000Sooooo0_l00013ooooo`;o00004?ooool001kooooo00?o0000
ooooooooool09?ooool2o`0006gooooo0_l0001Aooooo`;o00001oooool2o`0004Cooooo0_l0000@
ooooo`007_ooool2o`0001Oooooo0_l0000<ooooo`;o0000QOooool2o`00013ooooo0_l0000`oooo
o`;o0000:Oooool2o`0002_ooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l0002Cooooo`;o
00004?ooool2o`0001cooooo0_l0000mooooo`;o0000:oooool001kooooo00?o0000ooooooooool0
X?ooool2o`0002Sooooo0_l0000?ooooo`;o00001oooool2o`00067ooooo000Nooooo`03o`000?oo
oooooooo0:3ooooo0_l0000Xooooo`;o00006?ooool3o`0001Gooooo0_l00019ooooo`007_ooool0
1?l0003oooooo`000?l0003Tooooo`;o00004?ooool2o`0000?ooooo0_l00019ooooo`007_ooool0
1?l0003oooooo`000?l00008ooooo`;o0000Joooool2o`0007oooooo0_l0000aooooo`;o00006ooo
ool001kooooo00?o0000ooooooooool02Oooool2o`0000kooooo0_l0001Kooooo`;o0000:?ooool2
o`0006Sooooo0_l00007ooooo`;o00005Oooool2o`0001_ooooo000Nooooo`03o`000?oooooooooo
01Wooooo0_l0000oooooo`;o0000A?ooool2o`0000Cooooo0_l0000Kooooo`;o00007?ooool2o`00
00Cooooo0_l0000Qooooo`;o00001oooool2o`0002Sooooo0_l00008ooooo`007_ooool00ol0003o
ooooooooo`1Jooooo`;o0000B_ooool2o`0000Kooooo0_l0000Cooooo`;o00007?ooool2o`0000Co
oooo0_l0001Dooooo`;o00002?ooool001kooooo00?o0000ooooooooool0[_ooool2o`0001_ooooo
0_l0001jooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o00007oooool2o`0009cooooo0_l0
001jooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o00007oooool2o`0003cooooo0_l0003J
ooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o0000DOooool2o`0002_ooooo0_l0002]oooo
o`007_ooool00ol0003oooooooooo`0Hooooo`;o0000O_ooool2o`0008cooooo0_l0000Aooooo`;o
00003?ooool001kooooo00?o0000ooooooooool0oooooolWooooo`;o00004Oooool2o`0000cooooo
000Nooooo`03o`000?oooooooooo01Oooooo0_l0002kooooo`;o0000C?ooool2o`0002?ooooo000N
ooooo`;o00006?ooool2o`0000_ooooo0_l0001Dooooo`;o0000F?ooool2o`0003Kooooo0_l0000D
ooooo`;o00008oooool001kooooo00?o0000ooooooooool09?ooool2o`0005Cooooo0_l0001goooo
o`;o00005oooool2o`0000oooooo0_l0000Xooooo`007_ooool00ol0003oooooooooo`0[ooooo`;o
0000IOooool2o`0005oooooo0_l0000Xooooo`;o0000:?ooool001kooooo00?o0000ooooooooool0
:oooool2o`0006Gooooo0_l0002cooooo`007_ooool00ol0003oooooooooo`1gooooo`;o00005_oo
ool2o`0001kooooo0_l0000Eooooo`;o0000AOooool2o`0003Sooooo000Nooooo`03o`000?oooooo
oooo01?ooooo0_l0000aooooo`;o0000;oooool2o`0000Sooooo0_l0000<ooooo`;o00001oooool2
o`0001Gooooo0_l0000Eooooo`;o0000AOooool2o`0003Sooooo000Nooooo`03o`000?oooooooooo
01?ooooo0_l0000aooooo`;o0000>Oooool2o`0001Gooooo0_l0000Pooooo`;o0000Koooool2o`00
01[ooooo000Nooooo`03o`000?oooooooooo05?ooooo0_l0001Cooooo`?o00001_ooool2o`0000Oo
oooo0_l000000ooooooo0000o`00001/ooooo`;o00006_ooool001kooooo00?o0000ooooooooool0
Doooool2o`0003gooooo0_l0000Dooooo`?o00001_ooool2o`0000[ooooo0_l00028ooooo`007_oo
ool00ol0003oooooooooo`0Vooooo`;o00006_ooool2o`0004kooooo0_l00010ooooo`;o00002ooo
ool2o`0001Oooooo0_l0000mooooo`;o00003?ooool001kooooo00?o0000ooooooooool02?ooool2
o`0001cooooo0_l0000Jooooo`;o0000T?ooool2o`0000_ooooo0_l0000Gooooo`;o0000?Oooool2
o`0000cooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0003oooooobcooooo0_l0000@oooo
o`007_ooool00ol0003oooooooooo`3Nooooo`;o0000EOooool2o`00013ooooo000Nooooo`03o`00
0?oooooooooo05Cooooo0_l00028ooooo`;o0000??ooool2o`0002Wooooo000Nooooo`03o`000?oo
oooooooo00kooooo0_l00014ooooo`;o0000a_ooool2o`0002Wooooo000Nooooo`03o`000?oooooo
oooo00kooooo0_l00035ooooo`;o00001Oooool2o`0000Wooooo0_l0001Nooooo`007_ooool2o`00
02Wooooo0_l00014ooooo`;o0000IOooool2o`0000Gooooo0_l00009ooooo`;o0000C?ooool2o`00
00;ooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`0Xooooo`;o0000:Oooool2o`000003
ooooool0003o000000cooooo0_l00008ooooo`;o00009Oooool2o`0003Cooooo0_l00002ooooo`;o
0000I?ooool2o`0000;ooooo0_l0000<ooooo`007_ooool01?l0003oooooo`000?l0001Booooo`;o
000000?oooooo`000?l000003?ooool2o`0002oooooo0_l0000dooooo`;o00000_ooool2o`0000Oo
oooo0_l0000Vooooo`;o0000AOooool001kooooo00Co0000ooooool0003o0000K_ooool2o`0006Oo
oooo0_l0000Looooo`;o00002?ooool2o`0004Gooooo000Nooooo`03o`000?oooooooooo04Oooooo
0_l0000@ooooo`;o00005?ooool2o`0008Gooooo0_l0000Rooooo`;o0000:oooool001kooooo00?o
0000ooooooooool0Aoooool2o`00013ooooo0_l0002Mooooo`;o00003Oooool2o`00017ooooo0_l0
000[ooooo`007_ooool00ol0003oooooooooo`0/ooooo`;o00000_ooool2o`0003_ooooo0_l0000S
ooooo`;o0000I?ooool2o`0000gooooo0_l0000nooooo`007_ooool00ol0003oooooooooo`0/oooo
o`;o00000_ooool2o`0003_ooooo0_l0000Sooooo`;o0000/oooool001kooooo00?o0000oooooooo
ool0Xoooool2o`0006Kooooo0_l0000Oooooo`;o00006Oooool001kooooo00?o0000ooooooooool0
Xoooool2o`0002Cooooo0_l0000Hooooo`Co00009?ooool2o`0001oooooo0_l0000Iooooo`007_oo
ool00ol0003oooooooooo`09ooooo`;o0000Loooool2o`0004Wooooo0_l0000Hooooo`Co0000H?oo
ool001kooooo00?o0000ooooooooool02Oooool2o`0001oooooo0_l0000Jooooo`;o0000=_ooool2
o`0004oooooo0_l0001Iooooo`;o00006oooool001kooooo00?o0000ooooooooool0:_ooool2o`00
01[ooooo0_l00027ooooo`;o00006oooool2o`0003cooooo0_l0000Kooooo`007_ooool00ol0003o
ooooooooo`0Jooooo`;o0000Soooool2o`0003oooooo0_l0001Iooooo`000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool01?l0
003oooooo`000?l0000Iooooo`;o00004oooool2o`0007[ooooo0_l0001Hooooo`;o0000@?ooool0
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonH
V9So8B4Q00Kooooo00Co0000ooooool0003o00005oooool2o`0000Kooooo0_l0000=ooooo`;o0000
`_ooool2o`00013ooooo0_l00010ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo
00Go0000ooooooooooooooooo`000006ooooo`?o00006?ooool2o`0000Kooooo0_l0000mooooo`;o
0000C_ooool2o`0004;ooooo0_l0001Booooo`000oooool01Ol0003ooooooooooooooooo000000_o
oooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooooooo037ooooo0_l0000Foooo
o`;o00005?ooool2o`0003Gooooo0_l0000Gooooo`;o00003Oooool2o`0004Kooooo0_l0000ooooo
o`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006
ooooo`03o`000?oooooooooo01Kooooo0_l00005ooooo`;o00002_ooool2o`0000Kooooo0_l0000F
ooooo`;o00005_ooool2o`0003?ooooo0_l0000Vooooo`;o0000A_ooool2o`0003oooooo0003oooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o
0000ooooooooool05_ooool2o`0000Gooooo0_l0000:ooooo`;o0000=_ooool2o`0000Cooooo0_l0
002Mooooo`;o00005Oooool2o`0002Sooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool05Oooool2o`0003oooooo
0_l0000?ooooo`;o0000]?ooool2o`0002Sooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool05Oooool2o`0003oo
oooo0_l0000@ooooo`;o0000/Oooool2o`0000Wooooo0_l0000Oooooo`007_ooool00ol0003ooooo
ooooo`0Uooooo`;o00008_ooool2o`0001gooooo0_l0000;ooooo`;o0000Y?ooool2o`0000Wooooo
0_l0000Booooo`;o00002oooool001kooooo00?o0000ooooooooool08Oooool2o`0000;ooooo0_l0
000Rooooo`;o00007?ooool2o`0000cooooo0_l00006ooooo`;o0000[oooool2o`0000[ooooo0_l0
000;ooooo`007_ooool00ol0003oooooooooo`0Qooooo`;o00003oooool2o`0002;ooooo0_l0000?
ooooo`;o00005?ooool2o`0008;ooooo0_l0000[ooooo`;o00005oooool001kooooo00?o0000oooo
ooooool08?ooool2o`00013ooooo0_l0000Rooooo`;o0000I?ooool2o`0003gooooo0_l00004oooo
o`;o0000A?ooool001kooooo00?o0000ooooooooool01?ooool2o`0001[ooooo0_l0000jooooo`;o
0000:?ooool2o`0003Cooooo0_l0000Dooooo`;o00009oooool2o`0004[ooooo000Nooooo`03o`00
0?oooooooooo00Cooooo0_l0000?ooooo`;o00006Oooool2o`0002[ooooo0_l0000Xooooo`;o0000
7Oooool2o`0002_ooooo0_l0000Uooooo`;o0000>_ooool2o`00013ooooo000Nooooo`03o`000?oo
oooooooo01Gooooo0_l0000Iooooo`;o00008_ooool2o`0004oooooo0_l0001Booooo`;o0000>_oo
ool2o`00013ooooo000Nooooo`03o`000?oooooooooo017ooooo0_l00011ooooo`;o0000B_ooool2
o`0004?ooooo0_l0001Pooooo`007_ooool00ol0003oooooooooo`08ooooo`;o00001oooool2o`00
03Sooooo0_l0000;ooooo`;o0000@?ooool2o`0000Cooooo0_l00009ooooo`;o00004_ooool2o`00
00Sooooo0_l00002ooooo`;o00005_ooool2o`0000?ooooo0_l0000hooooo`;o00008Oooool001ko
oooo00?o0000ooooooooool02?ooool2o`00047ooooo0_l0000;ooooo`;o0000@?ooool2o`0000Co
oooo0_l00005ooooo`;o00000_ooool2o`0001;ooooo0_l00008ooooo`;o00000_ooool2o`0001_o
oooo0_l0000hooooo`;o00008Oooool001kooooo00?o0000ooooooooool0X?ooool2o`0000Gooooo
0_l00003ooooo`;o0000FOooool2o`0003kooooo000Nooooo`;o0000[Oooool2o`0000[ooooo0_l0
000Mooooo`;o0000;_ooool2o`0003kooooo000Nooooo`03o`000?oooooooooo0;Sooooo0_l0000M
ooooo`;o0000>?ooool2o`0003Cooooo000Nooooo`03o`000?oooooooooo0=kooooo0_l0000aoooo
o`;o0000=?ooool001kooooo00?o0000ooooooooool0D?ooool2o`0007kooooo0ol0000;ooooo`;o
0000;_ooool2o`0003Oooooo000Nooooo`03o`000?oooooooooo02Kooooo0_l0000Xooooo`;o0000
@Oooool2o`0002Oooooo0_l0000Booooo`?o0000:Oooool2o`00013ooooo0_l00007ooooo`;o0000
;_ooool001kooooo00?o0000ooooooooool09_ooool2o`0006_ooooo0_l0000Jooooo`;o00001?oo
ool4o`0000?ooooo0_l0000nooooo`;o00002Oooool2o`0000kooooo0_l0000^ooooo`007_ooool0
0ol0003oooooooooo`2_ooooo`;o00001?ooool4o`0002Gooooo0_l0000Wooooo`;o0000?_ooool0
01kooooo00?o0000ooooooooool0f?ooool2o`0000Cooooo0_l0000kooooo`;o00005Oooool2o`00
01?ooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0001:ooooo`;o0000;_ooool2o`00027o
oooo0_l0000_ooooo`;o0000@Oooool2o`0001Gooooo0_l0000Cooooo`007_ooool00ol0003ooooo
ooooo`07ooooo`?o0000B_ooool2o`0001;ooooo0_l0000Jooooo`;o00008Oooool2o`0000cooooo
0_l0000Eooooo`;o00003Oooool2o`0001Gooooo0_l0001Cooooo`007_ooool00ol0003ooooooooo
o`07ooooo`;o0000Goooool2o`0004_ooooo0_l00006ooooo`;o00003Oooool2o`0000gooooo0_l0
0003ooooo`;o00004?ooool2o`0000?ooooo0_l0000Fooooo`;o00007_ooool2o`0001Kooooo000N
ooooo`03o`000?oooooooooo083ooooo0_l00003ooooo`;o0000=_ooool2o`00027ooooo0_l0000E
ooooo`;o00005_ooool2o`0000Wooooo0_l0000Cooooo`;o00005_ooool001kooooo00?o0000oooo
ooooool0P?ooool2o`0000?ooooo0_l0000booooo`;o0000Goooool2o`0001;ooooo0_l0000Goooo
o`007_ooool00ol0003oooooooooo`2iooooo`;o0000Loooool2o`0001Oooooo000Nooooo`03o`00
0?oooooooooo0:kooooo0_l0001iooooo`;o00007?ooool001kooooo00?o0000ooooooooool0[_oo
ool2o`0005Oooooo0_l0000Pooooo`;o00007?ooool001kooooo0_l00029ooooo`;o00002_ooool2
o`00077ooooo0_l0000nooooo`007_ooool00ol0003oooooooooo`1/ooooo`;o00006_ooool2o`00
00[ooooo0_l0001;ooooo`;o0000I?ooool001kooooo00?o0000ooooooooool0K?ooool2o`0003oo
oooo0_l0000booooo`;o00009oooool2o`0003_ooooo000Nooooo`03o`000?oooooooooo07_ooooo
0_l0000`ooooo`;o0000Foooool2o`0003_ooooo000Nooooo`03o`000?oooooooooo05;ooooo0_l0
000Pooooo`;o00001Oooool2o`0004cooooo0_l00012ooooo`;o0000>?ooool001kooooo00?o0000
ooooooooool0D_ooool2o`00023ooooo0_l0000Sooooo`;o0000;_ooool2o`0004;ooooo0_l00000
0ooooooo0000o`00000Nooooo`;o00005Oooool001kooooo00?o0000ooooooooool0Noooool2o`00
01cooooo0_l0000gooooo`;o0000>_ooool4o`0001kooooo0_l0000Eooooo`007_ooool00ol0003o
ooooooooo`0_ooooo`;o00001_ooool2o`0004;ooooo0_l0001Eooooo`;o0000;?ooool2o`0000co
oooo0_l0000gooooo`007_ooool00ol0003oooooooooo`0_ooooo`;o00001_ooool2o`00037ooooo
0_l0002Dooooo`;o00006_ooool2o`0001[ooooo0_l0000=ooooo`007_ooool00ol0003ooooooooo
o`1Booooo`;o00005_ooool2o`0003Oooooo0_l00006ooooo`;o0000Koooool2o`0001[ooooo0_l0
000=ooooo`007_ooool00ol0003oooooooooo`1Booooo`;o0000Coooool2o`0000Kooooo0_l0000X
ooooo`;o0000@?ooool2o`0000Gooooo0_l0000Wooooo`007_ooool00ol0003oooooooooo`2goooo
o`;o00004Oooool2o`0000Wooooo0_l00010ooooo`?o00001?ooool2o`0002Oooooo000Nooooo`03
o`000?oooooooooo06[ooooo0_l0000Rooooo`;o00009oooool2o`00017ooooo0_l00005ooooo`;o
00006Oooool2o`0002[ooooo0_l0000]ooooo`007_ooool00ol0003oooooooooo`02o`0000Gooooo
0_l0000Yooooo`;o0000=_ooool2o`0002;ooooo0_l0000=ooooo`;o0000<_ooool2o`0001Wooooo
0_l0000Uooooo`;o0000<_ooool001kooooo00?o0000ooooooooool00_l00005ooooo`;o00001?oo
ool2o`0002?ooooo0_l00005ooooo`;o0000H_ooool2o`0003cooooo0_l0000^ooooo`;o00001_oo
ool2o`0003;ooooo000Nooooo`03o`000?oooooooooo00gooooo0_l0000Zooooo`;o00003?ooool2
o`00013ooooo0_l0001Nooooo`;o00008?ooool2o`0002kooooo0_l0000Iooooo`;o00002?ooool2
o`0001Gooooo000Nooooo`;o00005_ooool2o`00033ooooo0_l0000@ooooo`;o0000G_ooool2o`00
00Sooooo0_l0001Qooooo`;o00002?ooool2o`0001Gooooo000Nooooo`03o`000?oooooooooo01Go
oooo0_l0002Hooooo`;o00002oooool2o`0000Gooooo0_l0000kooooo`;o0000AOooool001kooooo
00?o0000ooooooooool0Foooool2o`0000Gooooo0_l0001;ooooo`;o00001Oooool2o`0000Cooooo
0_l0000jooooo`;o00001_ooool2o`0000Kooooo0ol0000Cooooo`;o00009oooool001kooooo00?o
0000ooooooooool0Foooool2o`0000Gooooo0_l0001Booooo`;o0000@?ooool2o`0000kooooo0ol0
000:ooooo`;o00001oooool4o`0000Sooooo0_l0000Kooooo`007_ooool00ol0003oooooooooo`1>
ooooo`;o0000;oooool2o`00027ooooo0_l0001aooooo`;o00002Oooool2o`0000Sooooo0_l0000K
ooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o0000;Oooool2o`0000Gooooo0_l0000_oooo
o`;o00008Oooool2o`0008;ooooo0_l0000Oooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o
0000;Oooool2o`000:Cooooo0_l0000Tooooo`;o00004Oooool2o`0000cooooo0_l0000Aooooo`00
7_ooool2o`0000Kooooo0_l0003Vooooo`;o00009?ooool2o`0001oooooo0_l0000Aooooo`007_oo
ool2o`0000Kooooo0_l0003]ooooo`;o00008?ooool2o`000003ooooool0003o000002cooooo000N
ooooo`03o`000?oooooooooo00Gooooo0_l0002dooooo`;o00001_ooool2o`0000_ooooo0_l0000R
ooooo`;o00008?ooool2o`000003ooooool0003o000002cooooo000Nooooo`03o`000?oooooooooo
00Gooooo0_l0001looooo`;o0000=_ooool3o`0000Gooooo0_l0000;ooooo`;o00005?ooool2o`00
04Cooooo0_l0000Iooooo`007_ooool00ol0003oooooooooo`23ooooo`;o0000=?ooool2o`000003
ooooool0003o000002Sooooo0_l0000_ooooo`;o00004oooool2o`0001Wooooo000Nooooo`03o`00
0?oooooooooo06Gooooo0_l0000:ooooo`;o0000=?ooool2o`00013ooooo0_l0000Jooooo`;o0000
3oooool2o`0002_ooooo0_l00002ooooo`;o0000;_ooool001kooooo00?o0000ooooooooool0IOoo
ool2o`0000[ooooo0_l0000dooooo`;o00008oooool2o`0000Oooooo0_l0000?ooooo`;o00005Ooo
ool2o`0001Cooooo0_l0000/ooooo`;o00001?ooool001Cooooo1?l000000ol@413oooooooooo`03
ooooo`03o`000?oooooooooo09gooooo0_l0000]ooooo`;o0000;oooool2o`0004;ooooo0_l00004
ooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo0_l0001Koooo
o`;o0000<?ooool2o`0000Cooooo0_l0002Xooooo`005_ooool00ol0003oooooooooo`05ooooo`?o
00002?ooool2o`0005_ooooo0_l0000`ooooo`;o0000KOooool2o`0003oooooo000Fooooo`03o`00
0?oooooooooo0?oooooo3oooool2o`0003oooooo000Fooooo`03o`000?oooooooooo0?ooooooD?oo
ool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooo
oe3ooooo000Dooooo`03oeEEEOmVIVKo00000?ooooooD_ooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.72959 .55413 Mdot
.12211 .35321 Mdot
.71161 .43186 Mdot
.08272 .4034 Mdot
.43871 .37065 Mdot
.48462 .33273 Mdot
.74737 .19055 Mdot
.0271 .04831 Mdot
.93623 .49161 Mdot
.87108 .93744 Mdot
.42845 .56949 Mdot
.89876 .94849 Mdot
.45104 .74105 Mdot
.0785 .32435 Mdot
.97994 .58716 Mdot
.2413 .16208 Mdot
.80367 .013 Mdot
.48009 .05343 Mdot
.9025 .06651 Mdot
.64487 .79663 Mdot
.1314 .30519 Mdot
.50254 .15367 Mdot
.96984 .93205 Mdot
.81039 .45363 Mdot
.31767 .91481 Mdot
.92728 .92167 Mdot
.00902 .10347 Mdot
.9713 .49464 Mdot
.46025 .32189 Mdot
.22147 .23011 Mdot
.37271 .10684 Mdot
.80515 .22634 Mdot
.93523 .99082 Mdot
.06326 .27813 Mdot
.23429 .28824 Mdot
.04884 .06741 Mdot
.17349 .2147 Mdot
.29715 .38141 Mdot
.84643 .31204 Mdot
.54754 .6416 Mdot
.64601 .70089 Mdot
.04526 .21962 Mdot
.5391 .42992 Mdot
.49166 .69654 Mdot
.79763 .61672 Mdot
.1519 .71904 Mdot
.34403 .55389 Mdot
.90378 .82467 Mdot
.48578 .16371 Mdot
.79815 .20373 Mdot
.8245 .08376 Mdot
.47779 .81934 Mdot
.96584 .61656 Mdot
.23212 .36634 Mdot
.68532 .96088 Mdot
.98348 .42332 Mdot
.21627 .08079 Mdot
.56768 .97176 Mdot
.58647 .24083 Mdot
.45194 .35598 Mdot
.85528 .87942 Mdot
.84842 .95262 Mdot
.24005 .51769 Mdot
.54568 .38391 Mdot
.04586 .18206 Mdot
.09132 .81411 Mdot
.53394 .41304 Mdot
.38078 .124 Mdot
.62182 .15999 Mdot
.04035 .38751 Mdot
.29526 .11595 Mdot
.8607 .26505 Mdot
.08493 .07994 Mdot
.24391 .15165 Mdot
.16327 .31581 Mdot
.91358 .98275 Mdot
.85017 .33321 Mdot
.56367 .40464 Mdot
.10675 .69082 Mdot
.91699 .00146 Mdot
.25369 .76381 Mdot
.13042 .42272 Mdot
.25898 .42088 Mdot
.50728 .31976 Mdot
.8953 .59828 Mdot
.50055 .02574 Mdot
.97145 .03821 Mdot
.80509 .25774 Mdot
.32287 .46271 Mdot
.03585 .06563 Mdot
.48137 .50363 Mdot
.34607 .30113 Mdot
.95866 .07222 Mdot
.01931 .65776 Mdot
.96685 .39072 Mdot
.7737 .08163 Mdot
.83718 .04606 Mdot
.52073 .8008 Mdot
.64512 .25146 Mdot
.85987 .76495 Mdot
.0414 .98146 Mdot
.63814 .91481 Mdot
.80026 .20693 Mdot
.51801 .85167 Mdot
.62174 .00915 Mdot
.26687 .94459 Mdot
.89356 .39228 Mdot
.28142 .12832 Mdot
.271 .11091 Mdot
.01087 .08983 Mdot
.36286 .61872 Mdot
.91497 .06615 Mdot
.55742 .8872 Mdot
.52364 .37814 Mdot
.56269 .89047 Mdot
.26547 .82421 Mdot
.70554 .61566 Mdot
.72911 .62034 Mdot
.55767 .03333 Mdot
.17626 .79108 Mdot
.57807 .62159 Mdot
.45454 .90309 Mdot
.93479 .70552 Mdot
.31289 .58027 Mdot
.61157 .06679 Mdot
.03942 .97372 Mdot
.88945 .50154 Mdot
.5662 .36284 Mdot
.43327 .64627 Mdot
.03896 .50486 Mdot
.57538 .41375 Mdot
.65888 .01558 Mdot
.86343 .52752 Mdot
.42089 .35616 Mdot
.16464 .55005 Mdot
.9279 .49982 Mdot
.26948 .64957 Mdot
.07518 .81041 Mdot
.15176 .38842 Mdot
.33445 .17145 Mdot
.96077 .97618 Mdot
.51273 .89949 Mdot
.62221 .38751 Mdot
.66545 .64033 Mdot
.50861 .63202 Mdot
.45777 .53395 Mdot
.61785 .85935 Mdot
.26635 .83931 Mdot
.60167 .97103 Mdot
.41327 .24781 Mdot
.16529 .76094 Mdot
.84388 .88273 Mdot
.00206 .49707 Mdot
.59436 .16189 Mdot
.61132 .31622 Mdot
.67576 .29187 Mdot
.80022 .97832 Mdot
.52366 .46321 Mdot
.93955 .9081 Mdot
.94775 .87149 Mdot
.57839 .17644 Mdot
.73663 .37366 Mdot
.13726 .74202 Mdot
.74237 .76283 Mdot
.9331 .96452 Mdot
.38924 .353 Mdot
.58863 .36716 Mdot
.47292 .32193 Mdot
.52387 .63168 Mdot
.79215 .62835 Mdot
.79156 .43351 Mdot
.57494 .5404 Mdot
.48534 .51447 Mdot
.01111 .3959 Mdot
.52814 .01783 Mdot
.49638 .41544 Mdot
.35265 .80483 Mdot
.3379 .31984 Mdot
.95231 .70799 Mdot
.10882 .23155 Mdot
.22394 .78519 Mdot
.99497 .35888 Mdot
.1738 .5416 Mdot
.20644 .03823 Mdot
.95367 .75985 Mdot
.99212 .43154 Mdot
.65673 .03675 Mdot
.68575 .22964 Mdot
.05995 .9639 Mdot
.56854 .71572 Mdot
.33724 .4576 Mdot
.72026 .70642 Mdot
.36078 .4282 Mdot
.84138 .14857 Mdot
.91477 .18071 Mdot
.41713 .31126 Mdot
.80164 .14478 Mdot
.18585 .62697 Mdot
.36614 .35219 Mdot
.29498 .59945 Mdot
.97684 .15705 Mdot
.00109 .67097 Mdot
.89473 .50049 Mdot
.04343 .70419 Mdot
.28358 .25193 Mdot
.47742 .3655 Mdot
.60969 .84949 Mdot
.8375 .25992 Mdot
.63966 .96663 Mdot
.82943 .34269 Mdot
.54695 .83396 Mdot
.28076 .49914 Mdot
.26611 .3924 Mdot
.01307 .53536 Mdot
.66669 .69259 Mdot
.18879 .55964 Mdot
.11942 .66606 Mdot
.46912 .02338 Mdot
.73453 .59232 Mdot
.95949 .98847 Mdot
.93594 .85205 Mdot
.38 .85883 Mdot
.59836 .28389 Mdot
.89528 .12768 Mdot
.11106 .63969 Mdot
.12975 .8298 Mdot
.2111 .16161 Mdot
.69065 .0155 Mdot
.82752 .19317 Mdot
.40958 .20344 Mdot
.29359 .3737 Mdot
.16453 .04514 Mdot
.07844 .30993 Mdot
.07062 .40033 Mdot
.73078 .78112 Mdot
.98285 .074 Mdot
.86415 .92332 Mdot
.08061 .49036 Mdot
.41477 .03636 Mdot
.18562 .19783 Mdot
.84982 .01281 Mdot
.06486 .2201 Mdot
.79306 .40409 Mdot
.63516 .94473 Mdot
.44121 .26871 Mdot
.77248 .27412 Mdot
.91604 .24954 Mdot
.5837 .00343 Mdot
.88239 .11012 Mdot
.31408 .74922 Mdot
.14745 .84647 Mdot
.80977 .75446 Mdot
.56725 .0441 Mdot
.57974 .31872 Mdot
.54032 .45413 Mdot
.70011 .58332 Mdot
.88613 .95882 Mdot
.12119 .50178 Mdot
.09243 .97215 Mdot
.73573 .34327 Mdot
.07117 .60211 Mdot
.27762 .8241 Mdot
.70501 .02945 Mdot
.70217 .32551 Mdot
.36991 .70632 Mdot
.95497 .79642 Mdot
.5738 .44738 Mdot
.50308 .9546 Mdot
.50359 .30602 Mdot
.06767 .17006 Mdot
.04462 .57618 Mdot
.57766 .04285 Mdot
.24265 .72918 Mdot
.98093 .9699 Mdot
.35545 .47222 Mdot
.55118 .96111 Mdot
.22223 .50784 Mdot
.39211 .35274 Mdot
.41567 .22459 Mdot
.67817 .72549 Mdot
.23004 .75195 Mdot
.81765 .30358 Mdot
.90199 .35444 Mdot
.02016 .02051 Mdot
.9685 .9155 Mdot
.80972 .77133 Mdot
.42622 .18447 Mdot
.4878 .0675 Mdot
.51261 .46819 Mdot
.34492 .4366 Mdot
.30118 .9681 Mdot
.46957 .00582 Mdot
.32421 .5089 Mdot
.77364 .94492 Mdot
.14172 .83711 Mdot
.55758 .62775 Mdot
.38813 .23057 Mdot
.03404 .63312 Mdot
.28747 .23968 Mdot
.33234 .7964 Mdot
.59168 .99892 Mdot
.2781 .10819 Mdot
.55412 .77561 Mdot
.58836 .83603 Mdot
.4257 .01759 Mdot
.96332 .18259 Mdot
.97354 .86678 Mdot
.15931 .78002 Mdot
.32096 .92147 Mdot
.43151 .91215 Mdot
.32444 .45915 Mdot
.3467 .37221 Mdot
.5145 .73674 Mdot
.32272 .56729 Mdot
.33625 .72748 Mdot
.4978 .45432 Mdot
.67697 .9541 Mdot
.32851 .01536 Mdot
.84664 .85086 Mdot
.88016 .4426 Mdot
.31981 .13281 Mdot
.70424 .33078 Mdot
.74852 .37965 Mdot
.13353 .18239 Mdot
.93242 .94643 Mdot
.05304 .39858 Mdot
.83422 .96762 Mdot
.76712 .16725 Mdot
.98383 .20357 Mdot
.65517 .9083 Mdot
.38666 .19138 Mdot
.57322 .71575 Mdot
.84416 .27358 Mdot
.08142 .13348 Mdot
.3659 .09858 Mdot
.73008 .21898 Mdot
.08764 .41553 Mdot
.40739 .5878 Mdot
.51141 .26275 Mdot
.90123 .69982 Mdot
.23524 .23451 Mdot
.44363 .54448 Mdot
.14544 .80255 Mdot
.71393 .62342 Mdot
.01519 .32808 Mdot
.81121 .73722 Mdot
.97721 .41921 Mdot
.90994 .25473 Mdot
.63248 .23864 Mdot
.6943 .43196 Mdot
.39338 .82909 Mdot
.55678 .03866 Mdot
.84827 .37462 Mdot
.3037 .72379 Mdot
.43956 .7478 Mdot
.37211 .84863 Mdot
.61435 .18372 Mdot
.80932 .86853 Mdot
.86202 .5333 Mdot
.76118 .84953 Mdot
.98975 .48022 Mdot
.21507 .17872 Mdot
.90428 .49578 Mdot
.4335 .34618 Mdot
.78475 .86832 Mdot
.36395 .9246 Mdot
.02499 .39886 Mdot
.69387 .2434 Mdot
.69402 .37415 Mdot
.66451 .12362 Mdot
.11082 .584 Mdot
.73406 .05911 Mdot
.84269 .28502 Mdot
.68518 .68131 Mdot
.19347 .59192 Mdot
.04747 .52372 Mdot
.59565 .46378 Mdot
.93419 .44836 Mdot
.27087 .86165 Mdot
.00133 .34646 Mdot
.75073 .73574 Mdot
.58934 .45975 Mdot
.89757 .89028 Mdot
.63964 .11183 Mdot
.83771 .30742 Mdot
.14454 .22643 Mdot
.90098 .90948 Mdot
.34924 .47875 Mdot
.07651 .18154 Mdot
.18487 .28856 Mdot
.00417 .05906 Mdot
.46465 .66745 Mdot
.45907 .53778 Mdot
.64153 .40828 Mdot
.26 .958 Mdot
.27489 .50585 Mdot
.70069 .4214 Mdot
.8492 .03798 Mdot
.00762 .80526 Mdot
.77265 .32946 Mdot
.72966 .35635 Mdot
.21291 .30851 Mdot
.48872 .09451 Mdot
.05348 .85393 Mdot
.2328 .27428 Mdot
.64925 .18944 Mdot
.77968 .55737 Mdot
.19261 .94763 Mdot
.28656 .84609 Mdot
.11912 .61781 Mdot
.52252 .30511 Mdot
.62038 .11013 Mdot
.01797 .17625 Mdot
.10358 .57819 Mdot
.33081 .30036 Mdot
.84566 .97457 Mdot
.79216 .83927 Mdot
.36091 .56387 Mdot
.86107 .5119 Mdot
.97837 .88123 Mdot
.74994 .37942 Mdot
.61379 .9858 Mdot
.03876 .82772 Mdot
.16107 .15093 Mdot
.20356 .94792 Mdot
.28719 .36016 Mdot
.25338 .85779 Mdot
.18806 .20838 Mdot
.16643 .73546 Mdot
.57018 .42325 Mdot
.11471 .50771 Mdot
.33238 .78254 Mdot
.60369 .89195 Mdot
.57043 .53263 Mdot
.27238 .2863 Mdot
.59447 .66002 Mdot
.30087 .12948 Mdot
.55473 .54616 Mdot
.83092 .52174 Mdot
.13498 .10929 Mdot
.35334 .50548 Mdot
.34591 .44793 Mdot
.01714 .70779 Mdot
.24667 .94727 Mdot
.67131 .53633 Mdot
.44539 .16921 Mdot
.12615 .51656 Mdot
.58183 .73859 Mdot
.13098 .65414 Mdot
.17967 .43748 Mdot
.01174 .36728 Mdot
.79693 .6198 Mdot
.46632 .62512 Mdot
.61957 .92347 Mdot
.19509 .14941 Mdot
.66201 .17177 Mdot
.7614 .28058 Mdot
.48918 .8072 Mdot
.86458 .52695 Mdot
.65504 .84239 Mdot
.50827 .19518 Mdot
.17749 .14127 Mdot
.65395 .05339 Mdot
.17324 .77242 Mdot
.9845 .16905 Mdot
.78067 .10541 Mdot
.57742 .2299 Mdot
.38304 .12084 Mdot
.03889 .13658 Mdot
.0836 .09776 Mdot
.43142 .31478 Mdot
.65169 .47801 Mdot
.69182 .96383 Mdot
.1824 .14672 Mdot
.21149 .1806 Mdot
.79789 .65281 Mdot
.9607 .7923 Mdot
.25383 .80049 Mdot
.15518 .79399 Mdot
.67694 .92725 Mdot
.37524 .87698 Mdot
.71844 .56595 Mdot
.74199 .31592 Mdot
.34088 .84267 Mdot
.27514 .12719 Mdot
.92177 .44549 Mdot
.81055 .16646 Mdot
.94677 .06432 Mdot
.60892 .13467 Mdot
.95069 .47582 Mdot
.18326 .5532 Mdot
.51646 .35113 Mdot
.04507 .01403 Mdot
.54474 .03581 Mdot
.16516 .4248 Mdot
.49896 .92128 Mdot
.10656 .09158 Mdot
.80481 .24963 Mdot
.59111 .09883 Mdot
.67395 .42476 Mdot
.75711 .79175 Mdot
.51731 .20135 Mdot
.35309 .92064 Mdot
.22907 .60941 Mdot
.04705 .22695 Mdot
.44592 .40483 Mdot
.14212 .55723 Mdot
.71012 .71945 Mdot
.71434 .22043 Mdot
.08144 .19793 Mdot
.92515 .85335 Mdot
.6328 .53371 Mdot
.41861 .32454 Mdot
.91937 .54522 Mdot
.82982 .176 Mdot
.92728 .15063 Mdot
.51803 .21851 Mdot
.78553 .52833 Mdot
.68493 .85491 Mdot
.84768 .09882 Mdot
.1477 .84923 Mdot
.58705 .09363 Mdot
.0421 .74289 Mdot
.15866 .31755 Mdot
.85423 .21009 Mdot
.02985 .57067 Mdot
.85052 .73126 Mdot
.35959 .16097 Mdot
.04033 .78525 Mdot
.77554 .8383 Mdot
.15998 .7444 Mdot
.68832 .48948 Mdot
.24582 .11152 Mdot
.84967 .56823 Mdot
.97523 .13051 Mdot
.86102 .46566 Mdot
.84682 .70939 Mdot
.60461 .13169 Mdot
.23698 .22662 Mdot
.55179 .83035 Mdot
.86523 .67416 Mdot
.90629 .23642 Mdot
.53849 .67058 Mdot
.06474 .5034 Mdot
.53826 .86839 Mdot
.44031 .70433 Mdot
.72694 .49137 Mdot
.33967 .98334 Mdot
.7379 .54031 Mdot
.00091 .03866 Mdot
.72281 .54358 Mdot
.22139 .43432 Mdot
.04217 .17194 Mdot
.5101 .47229 Mdot
.26846 .24148 Mdot
.27483 .19496 Mdot
.97483 .59778 Mdot
.03507 .29153 Mdot
.45103 .90868 Mdot
.45946 .06937 Mdot
.55415 .11524 Mdot
.67464 .24097 Mdot
.04993 .29482 Mdot
.15268 .06449 Mdot
.79675 .90485 Mdot
.84438 .85415 Mdot
.69681 .46866 Mdot
.80889 .90818 Mdot
.48952 .11214 Mdot
.06274 .39574 Mdot
.21984 .44105 Mdot
.3871 .12673 Mdot
.01024 .10504 Mdot
.91341 .57779 Mdot
.21781 .00127 Mdot
.57145 .73365 Mdot
.24385 .87828 Mdot
.85839 .16074 Mdot
.22233 .19367 Mdot
.32273 .45996 Mdot
.94395 .30241 Mdot
.05579 .28178 Mdot
.46049 .08762 Mdot
.80626 .95884 Mdot
.63874 .82927 Mdot
.7189 .13933 Mdot
.7205 .9905 Mdot
.89104 .62901 Mdot
.7375 .90618 Mdot
.16942 .24879 Mdot
.33447 .97828 Mdot
.08972 .98954 Mdot
.56582 .44423 Mdot
.85298 .93304 Mdot
.89735 .50629 Mdot
.2805 .80181 Mdot
.48512 .95988 Mdot
.39826 .42618 Mdot
.00751 .71571 Mdot
.23087 .03833 Mdot
.98837 .0163 Mdot
.3115 .03566 Mdot
.90478 .33061 Mdot
.94499 .30052 Mdot
.61264 .64091 Mdot
.37727 .56101 Mdot
.37324 .83957 Mdot
.34088 .52182 Mdot
.07256 .11492 Mdot
.73395 .90045 Mdot
.43761 .12114 Mdot
.71562 .05093 Mdot
.14004 .26334 Mdot
.64244 .76495 Mdot
.48702 .18555 Mdot
.46773 .74259 Mdot
.70749 .7972 Mdot
.36185 .38022 Mdot
.02861 .76046 Mdot
.82773 .61743 Mdot
.72166 .37647 Mdot
.31932 .48042 Mdot
.54523 .06696 Mdot
.38976 .61001 Mdot
.08214 .01805 Mdot
.95442 .55028 Mdot
.87637 .02972 Mdot
.25514 .58712 Mdot
.42438 .43592 Mdot
.15092 .3712 Mdot
.07333 .46418 Mdot
.08069 .46885 Mdot
.12587 .3483 Mdot
.98061 .77474 Mdot
.84788 .03559 Mdot
.88771 .38973 Mdot
.93969 .78134 Mdot
.68303 .58914 Mdot
.79482 .04111 Mdot
.12401 .81151 Mdot
.64434 .78932 Mdot
.26196 .58898 Mdot
.28528 .5753 Mdot
.83028 .85527 Mdot
.94334 .99036 Mdot
.66123 .80112 Mdot
.36612 .17327 Mdot
.99377 .60402 Mdot
.61123 .13666 Mdot
.10285 .75535 Mdot
.59757 .83319 Mdot
.21082 .23004 Mdot
.17773 .76443 Mdot
.73004 .93917 Mdot
.60941 .44785 Mdot
.06379 .7745 Mdot
.47726 .26589 Mdot
.65599 .24394 Mdot
.32933 .3217 Mdot
.48985 .45262 Mdot
.84681 .98749 Mdot
.05614 .41929 Mdot
.0603 .89552 Mdot
.13732 .37796 Mdot
.13671 .84272 Mdot
.14845 .29377 Mdot
.78944 .1477 Mdot
.34865 .66291 Mdot
.15903 .11496 Mdot
.39991 .2035 Mdot
.07251 .51615 Mdot
.24516 .48801 Mdot
.45352 .8488 Mdot
.90246 .30425 Mdot
.0816 .69819 Mdot
.99972 .61706 Mdot
.71766 .65766 Mdot
.61012 .18187 Mdot
.14153 .78675 Mdot
.52296 .68975 Mdot
.71243 .89619 Mdot
.8221 .37927 Mdot
.40541 .128 Mdot
.86447 .62486 Mdot
.23259 .06434 Mdot
.71024 .54243 Mdot
.91141 .58792 Mdot
.97431 .14517 Mdot
.42257 .70604 Mdot
.09534 .77299 Mdot
.08941 .1118 Mdot
.85225 .81877 Mdot
.61584 .414 Mdot
.82417 .24203 Mdot
.46 .53524 Mdot
.14337 .35979 Mdot
.01351 .24876 Mdot
.68962 .56168 Mdot
.34798 .41599 Mdot
.91367 .64714 Mdot
.68052 .01381 Mdot
.63144 .15664 Mdot
.3439 .61697 Mdot
.90162 .57698 Mdot
.97555 .43032 Mdot
.91699 .09196 Mdot
.76526 .13305 Mdot
.46326 .47557 Mdot
.53695 .1262 Mdot
.02945 .10536 Mdot
.43473 .43309 Mdot
.34938 .24861 Mdot
.5263 .71594 Mdot
.5691 .88434 Mdot
.95282 .82078 Mdot
.3448 .5477 Mdot
.22816 .20141 Mdot
.6497 .22584 Mdot
.17404 .28224 Mdot
.9618 .54546 Mdot
.87894 .96021 Mdot
.69789 .63326 Mdot
.70141 .26481 Mdot
.57705 .60828 Mdot
.42413 .82156 Mdot
.27061 .02679 Mdot
.63233 .72811 Mdot
.63146 .28307 Mdot
.65018 .84068 Mdot
.20014 .29775 Mdot
.31096 .3517 Mdot
.02036 .52934 Mdot
.07497 .67184 Mdot
.56228 .69931 Mdot
.17173 .11514 Mdot
.82892 .79854 Mdot
.06492 .11257 Mdot
.79354 .95094 Mdot
.65897 .59048 Mdot
.42615 .48664 Mdot
.25167 .96798 Mdot
.45519 .42785 Mdot
.74809 .39031 Mdot
.13561 .10755 Mdot
.85556 .00117 Mdot
.76092 .25934 Mdot
.40345 .60865 Mdot
.78219 .70038 Mdot
.52311 .30803 Mdot
.22975 .95137 Mdot
.66721 .9323 Mdot
.56295 .69264 Mdot
.71564 .21508 Mdot
.40884 .00569 Mdot
.72082 .04633 Mdot
.46572 .12313 Mdot
.04062 .228 Mdot
.42236 .08678 Mdot
.40682 .36945 Mdot
.40436 .21187 Mdot
.0912 .81752 Mdot
.49796 .47361 Mdot
.2162 .12755 Mdot
.71656 .06974 Mdot
.30456 .72561 Mdot
.56662 .85013 Mdot
.86262 .92813 Mdot
.35134 .48813 Mdot
.5775 .4788 Mdot
.71219 .63007 Mdot
.41025 .34616 Mdot
.97635 .17569 Mdot
.06663 .20835 Mdot
.21882 .89125 Mdot
.11726 .36968 Mdot
.7952 .59464 Mdot
.51625 .3789 Mdot
.97923 .05228 Mdot
.38849 .75439 Mdot
.90165 .7694 Mdot
.06349 .06171 Mdot
.98378 .368 Mdot
.35362 .00155 Mdot
.85544 .97003 Mdot
.56537 .9322 Mdot
.33553 .26887 Mdot
.67149 .84891 Mdot
.81763 .43096 Mdot
.41488 .14827 Mdot
.03387 .24736 Mdot
.7212 .22729 Mdot
.87815 .73073 Mdot
.97882 .40721 Mdot
.05381 .57951 Mdot
.343 .24231 Mdot
.99137 .46341 Mdot
.02566 .54415 Mdot
.43933 .33689 Mdot
.05263 .94751 Mdot
.87677 .63901 Mdot
.90868 .49522 Mdot
.62147 .19604 Mdot
.38201 .04315 Mdot
.99228 .70911 Mdot
.655 .88254 Mdot
.69073 .88931 Mdot
.57341 .85174 Mdot
.39122 .19914 Mdot
.77054 .08681 Mdot
.23542 .04326 Mdot
.5143 .36227 Mdot
.59081 .1322 Mdot
.33161 .62307 Mdot
.67943 .77174 Mdot
.25444 .80037 Mdot
.00131 .27339 Mdot
.2881 .73874 Mdot
.05235 .20371 Mdot
.99272 .07908 Mdot
.47635 .73816 Mdot
.44701 .79193 Mdot
.51665 .95275 Mdot
.77254 .17618 Mdot
.16253 .01001 Mdot
.55186 .31286 Mdot
.59373 .50666 Mdot
.12424 .69189 Mdot
.40769 .9483 Mdot
.02299 .27399 Mdot
.55647 .99449 Mdot
.79505 .37274 Mdot
.86552 .01398 Mdot
.60272 .84731 Mdot
.61034 .86496 Mdot
.62951 .43187 Mdot
.20739 .07033 Mdot
.26288 .95155 Mdot
.85122 .88102 Mdot
.93148 .94341 Mdot
.15611 .69305 Mdot
.06946 .91323 Mdot
.84849 .88004 Mdot
.10613 .30826 Mdot
.78225 .66052 Mdot
.73725 .634 Mdot
.41196 .61037 Mdot
.89575 .42221 Mdot
.89498 .7543 Mdot
.42671 .31511 Mdot
.89051 .10366 Mdot
.2686 .5692 Mdot
.44348 .24181 Mdot
.88712 .90275 Mdot
.77639 .54378 Mdot
.5613 .3363 Mdot
.80639 .07598 Mdot
.04908 .42641 Mdot
.17731 .23506 Mdot
.38835 .26019 Mdot
.50681 .3191 Mdot
.80081 .73181 Mdot
.40501 .40458 Mdot
.76687 .88883 Mdot
.7213 .98502 Mdot
.67095 .21458 Mdot
.15126 .20984 Mdot
.86456 .04355 Mdot
.03327 .3322 Mdot
.03961 .41796 Mdot
.65147 .80217 Mdot
.88707 .3893 Mdot
.41609 .27972 Mdot
.8302 .92965 Mdot
.73233 .10612 Mdot
.34355 .74016 Mdot
.2791 .301 Mdot
.51348 .82339 Mdot
.42779 .91333 Mdot
.38031 .94816 Mdot
.08803 .83714 Mdot
.55568 .32241 Mdot
.66427 .74334 Mdot
.89407 .70509 Mdot
.04488 .27005 Mdot
.80089 .01306 Mdot
.07449 .44937 Mdot
.71646 .03653 Mdot
.11471 .33175 Mdot
.48758 .98328 Mdot
.46044 .23932 Mdot
.86116 .30513 Mdot
.57518 .68356 Mdot
.55474 .17099 Mdot
.70032 .62946 Mdot
.37088 .26442 Mdot
.78843 .15873 Mdot
.8414 .43271 Mdot
.56428 .96142 Mdot
.88463 .57249 Mdot
.64317 .85816 Mdot
.18147 .35493 Mdot
.93462 .42618 Mdot
.57258 .86934 Mdot
.59323 .97977 Mdot
.81853 .92884 Mdot
.68495 .56887 Mdot
.14523 .45728 Mdot
.97776 .19356 Mdot
.52423 .84155 Mdot
.26946 .44529 Mdot
.88314 .99421 Mdot
.88461 .34788 Mdot
.45544 .86104 Mdot
.73121 .75905 Mdot
.08755 .81139 Mdot
.40244 .55206 Mdot
.06897 .06301 Mdot
.53086 .26083 Mdot
.73366 .86144 Mdot
.69247 .81306 Mdot
.94526 .85334 Mdot
.15039 .61441 Mdot
.27216 .55729 Mdot
.05735 .48006 Mdot
.54715 .01068 Mdot
.56223 .45972 Mdot
.11863 .46211 Mdot
.92632 .70736 Mdot
.86889 .12993 Mdot
.63039 .71168 Mdot
.34997 .46822 Mdot
.75561 .63244 Mdot
.24034 .90987 Mdot
.79657 .74362 Mdot
.22085 .04985 Mdot
.60074 .47922 Mdot
.37552 .79567 Mdot
.22557 .72616 Mdot
.44148 .56881 Mdot
.04917 .3132 Mdot
.39441 .27693 Mdot
.6518 .8366 Mdot
.28226 .97904 Mdot
.68856 .02406 Mdot
.2901 .84472 Mdot
.09062 .48534 Mdot
.34565 .07493 Mdot
.30072 .2623 Mdot
.67381 .04513 Mdot
.35477 .29863 Mdot
.48153 .19701 Mdot
.93423 .21886 Mdot
.91592 .67156 Mdot
.1352 .5418 Mdot
.88659 .9449 Mdot
.65098 .33693 Mdot
.82768 .81976 Mdot
.32817 .03118 Mdot
.75287 .94123 Mdot
.33263 .53568 Mdot
.27411 .68588 Mdot
.25551 .50347 Mdot
.0009 .31958 Mdot
.94425 .04449 Mdot
.80296 .89176 Mdot
.59762 .27287 Mdot
.73223 .6906 Mdot
.12914 .63518 Mdot
.64788 .13422 Mdot
.56986 .89253 Mdot
.14255 .95781 Mdot
.5069 .10858 Mdot
.1427 .48822 Mdot
.48155 .85957 Mdot
.91384 .95119 Mdot
.25318 .00846 Mdot
.23576 .82289 Mdot
.41327 .4994 Mdot
.77231 .35291 Mdot
.54263 .00645 Mdot
.89848 .42882 Mdot
.74998 .98702 Mdot
.49962 .23871 Mdot
.53677 .61874 Mdot
.61875 .97579 Mdot
.87366 .04495 Mdot
.49471 .79872 Mdot
.78709 .27708 Mdot
.45574 .72057 Mdot
.10358 .54099 Mdot
.90368 .58703 Mdot
.83102 .75979 Mdot
.28792 .36364 Mdot
.30191 .5221 Mdot
.56319 .3884 Mdot
.96949 .67935 Mdot
.73122 .62047 Mdot
.82933 .95904 Mdot
.9953 .52823 Mdot
.84649 .90805 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool00_ooool2o`0000Wooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`?o00003_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`08ooooo`;o00001?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo0ol0000=ooooo`03o`000?oooooooooo00;o
oooo0_l00009ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool3o`0000kooooo00Co0000ooooool0003o00003?ooool00ol0003o
ooooooooo`03ooooo`;o00002?ooool00ol0003oooooooooo`0:ooooo`;o000000?oooooo`000?oo
ool02Oooool2o`0000Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool2o`0000Wooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003oooooooooo`0aooooo`;o0000
6oooool2o`00037ooooo0_l0000Booooo`;o00005Oooool2o`0001Sooooo0_l0001oooooo`007_oo
ool00ol0003oooooooooo`0aooooo`;o00006oooool2o`0005kooooo0_l0000Fooooo`;o0000>?oo
ool3o`0000gooooo0_l0000eooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o0000F_ooool2
o`0004Gooooo0_l0000Rooooo`;o00001Oooool2o`000003ooooool0003o000002;ooooo0ol0000=
ooooo`;o00000oooool2o`0002Kooooo0_l00008ooooo`007_ooool00ol0003oooooooooo`0;oooo
o`;o00002_ooool2o`0004kooooo0_l0000Mooooo`;o00008?ooool2o`0002Sooooo0_l00005oooo
o`;o000000?oooooo`000?l00000=oooool2o`0002Kooooo0_l00008ooooo`007_ooool00ol0003o
ooooooooo`02ooooo`;o00004oooool2o`0006gooooo0_l0000Pooooo`;o0000WOooool001kooooo
00?o0000ooooooooool00_ooool2o`00093ooooo0_l00009ooooo`;o0000>oooool2o`0006Wooooo
000Nooooo`03o`000?oooooooooo05Cooooo0_l0000nooooo`;o00002Oooool2o`0003_ooooo0_l0
001Yooooo`007_ooool00ol0003oooooooooo`1Dooooo`;o00004Oooool2o`0007Sooooo0_l0000f
ooooo`;o0000;?ooool001kooooo00?o0000ooooooooool0Ioooool2o`0004Sooooo0_l0000^oooo
o`;o0000=_ooool2o`0002cooooo000Nooooo`03o`000?oooooooooo03oooooo0_l00006ooooo`;o
00006?ooool2o`00023ooooo0_l0000Xooooo`;o00000_ooool2o`0001kooooo0_l0000Booooo`;o
0000:Oooool2o`0002Kooooo0_l0000=ooooo`007Oooool2o`00047ooooo0_l00006ooooo`;o0000
6?ooool2o`00023ooooo0_l0000Xooooo`;o00000_ooool2o`0001kooooo0_l0000Booooo`;o0000
5oooool2o`00013ooooo0_l0000Vooooo`;o00003Oooool001gooooo0_l0001:ooooo`;o0000;_oo
ool2o`0003Oooooo0_l000000ooooooo0000o`000002ooooo`;o0000A?ooool2o`0001Gooooo0_l0
000Hooooo`;o00005_ooool001kooooo00?o0000ooooooooool0<Oooool2o`0001Gooooo0_l0000^
ooooo`;o0000>_ooool2o`0000;ooooo0_l0000Mooooo`;o00003Oooool2o`0002Cooooo0_l00007
ooooo`;o000000?oooooo`000?l000005Oooool2o`0001Kooooo000Nooooo`03o`000?oooooooooo
00Gooooo0_l0000Zooooo`;o00004Oooool2o`00097ooooo0_l0000=ooooo`;o00009?ooool2o`00
00[ooooo0_l0000]ooooo`007_ooool2o`0000Kooooo0_l0000mooooo`;o0000D_ooool2o`0003Ko
oooo0_l0000Cooooo`;o0000Doooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo09Sooooo
0_l0000fooooo`;o00004oooool2o`0005?ooooo0_l0000;ooooo`007_ooool2o`000>cooooo0_l0
001Jooooo`007_ooool2o`0001;ooooo0_l0003Hooooo`;o0000F_ooool001kooooo00?o0000oooo
ooooool02?ooool2o`0000Oooooo0ol0000Jooooo`;o00005oooool2o`000>Oooooo0_l0000Eoooo
o`007_ooool00ol0003oooooooooo`08ooooo`;o00000_ooool2o`0000Cooooo0_l0000Jooooo`;o
00005oooool2o`00057ooooo0_l0000Aooooo`;o00005?ooool2o`0005cooooo0_l00002ooooo`;o
00002Oooool2o`0001Gooooo000Nooooo`03o`000?oooooooooo00cooooo0_l0000aooooo`;o0000
D?ooool2o`0000Oooooo0_l0000Aooooo`;o00005?ooool2o`00023ooooo0_l0000jooooo`;o0000
0_ooool2o`00023ooooo000Nooooo`03o`000?oooooooooo03oooooo0_l0000[ooooo`;o00008ooo
ool2o`0005;ooooo0_l0001=ooooo`;o00001Oooool2o`0000[ooooo000Nooooo`03o`000?oooooo
oooo06cooooo0_l0002Dooooo`;o0000<?ooool2o`0000Gooooo0_l0000:ooooo`007_ooool00ol0
003oooooooooo`0Gooooo`;o0000:Oooool2o`000;kooooo0_l0000kooooo`;o00001_ooool001ko
oooo00?o0000ooooooooool05oooool2o`0002Wooooo0_l0002cooooo`;o00003oooool2o`0003Go
oooo0_l00006ooooo`007_ooool00ol0003oooooooooo`25ooooo`;o0000Koooool3o`0000oooooo
0_l0000mooooo`007_ooool01?l0003oooooo`000?l00024ooooo`;o00002oooool2o`0006;ooooo
0_l0001?ooooo`007_ooool01?l0003oooooo`000?l0000Nooooo`;o0000LOooool2o`0002Oooooo
0_l0001Yooooo`;o00007oooool001kooooo00?o0000ooooooooool07oooool2o`0007[ooooo0_l0
000Nooooo`;o0000JOooool2o`0001oooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0001J
ooooo`;o00009_ooool2o`0001oooooo0_l0001Aooooo`;o0000=_ooool001kooooo0_l0000Hoooo
o`;o0000F_ooool2o`0004Oooooo0_l0001Aooooo`;o0000=_ooool001kooooo00Co0000ooooool0
003o00001?ooool2o`000??ooooo0_l0000Qooooo`;o0000:?ooool001kooooo00Co0000ooooool0
003o00001?ooool2o`00027ooooo0_l0000/ooooo`;o00007Oooool2o`0002[ooooo0_l00017oooo
o`;o00003_ooool2o`00027ooooo0_l0000Xooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o
00003Oooool2o`0002;ooooo0_l00006ooooo`Co00007Oooool2o`0002Cooooo0_l00004ooooo`;o
00008oooool2o`0000Cooooo0_l0000Looooo`;o0000;oooool2o`0002[ooooo000Nooooo`03o`00
0?oooooooooo017ooooo1?l00004ooooo`;o00003Oooool2o`0000Kooooo0_l00002ooooo`;o0000
5_ooool2o`0000Kooooo0_l00015ooooo`;o00004oooool2o`0001Cooooo0_l00004ooooo`;o0000
COooool2o`0002[ooooo000Nooooo`03o`000?oooooooooo017ooooo1?l0000Kooooo`;o00000_oo
ool2o`0002Kooooo0_l0001Booooo`;o0000UOooool001kooooo00?o0000ooooooooool0G?ooool2
o`0001[ooooo0_l0000@ooooo`;o0000^oooool001kooooo00?o0000ooooooooool0N?ooool2o`00
013ooooo0_l00007ooooo`;o0000?oooool2o`00077ooooo000Nooooo`03o`000?oooooooooo05Go
oooo0_l0000Qooooo`Co00005oooool2o`0001Gooooo0_l0000Xooooo`;o0000LOooool001kooooo
00?o0000ooooooooool0@_ooool2o`00017ooooo1?l00005ooooo`;o00006_ooool2o`0000Cooooo
0_l0000Xooooo`;o0000J_ooool2o`0000Oooooo0_l0000Hooooo`;o00003?ooool001kooooo00?o
0000ooooooooool05_ooool2o`0002[ooooo0_l0000Cooooo`;o00001Oooool2o`0000Cooooo0_l0
000Jooooo`;o0000>_ooool2o`0000;ooooo0_l0000cooooo`;o00007oooool2o`0000Oooooo0_l0
000Hooooo`;o00003?ooool001kooooo00?o0000ooooooooool02Oooool2o`0000_ooooo0_l0001<
ooooo`;o0000E_ooool2o`0000;ooooo1Ol0000:ooooo`;o00009?ooool2o`00053ooooo000Noooo
o`03o`000?oooooooooo00Wooooo0_l0002gooooo`?o00002_ooool2o`0001Gooooo0_l0001Ooooo
o`007_ooool00ol0003oooooooooo`0fooooo`;o0000[_ooool2o`0005oooooo000Nooooo`03o`00
0?oooooooooo03Kooooo0_l00039ooooo`;o0000=_ooool2o`0000cooooo000Nooooo`03o`000?oo
oooooooo03Oooooo0_l0001:ooooo`;o0000N?ooool2o`0000;ooooo0_l0000:ooooo`;o0000:_oo
ool2o`0000cooooo000Nooooo`;o0000<Oooool2o`0000Gooooo0_l00002ooooo`;o00003_ooool2
o`0003Kooooo0_l0001hooooo`;o00003_ooool2o`0001[ooooo0_l0000Looooo`007_ooool00ol0
003oooooooooo`0`ooooo`;o00002Oooool2o`0000kooooo0_l0001Booooo`;o0000R?ooool2o`00
01cooooo000Nooooo`03o`000?oooooooooo09oooooo0_l0000Xooooo`;o0000K_ooool2o`0000co
oooo000Nooooo`03o`000?oooooooooo077ooooo0_l0001Cooooo`;o000000?oooooo`000?l00000
<Oooool2o`0001Gooooo0_l0000Tooooo`;o00003?ooool001kooooo00?o0000ooooooooool0@Ooo
ool2o`0000Oooooo0_l0000Uooooo`;o00009oooool2o`00027ooooo0_l00007ooooo`;o0000=?oo
ool2o`0001Gooooo0_l0000booooo`007_ooool00ol0003oooooooooo`11ooooo`;o00001oooool2
o`0004kooooo0_l0000Qooooo`;o0000=_ooool2o`0000cooooo0_l00012ooooo`007_ooool00ol0
003oooooooooo`0Booooo`;o0000NOooool2o`0006Kooooo0_l0000<ooooo`;o0000=oooool2o`00
00Wooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l00006ooooo`;o0000EOooool2o`0000So
oooo0_l0000Hooooo`;o00008Oooool2o`00027ooooo0_l0001Wooooo`;o00002Oooool001kooooo
00?o0000ooooooooool00_ooool2o`0000Kooooo0_l0001Mooooo`;o00002?ooool2o`0003_ooooo
0_l00006ooooo`;o00006Oooool2o`0002;ooooo0_l0000Aooooo`;o0000;Oooool2o`0000cooooo
000Nooooo`03o`000?oooooooooo00;ooooo0_l0000nooooo`;o0000M?ooool2o`0003gooooo0_l0
000Aooooo`;o0000;Oooool2o`0000cooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l00008
ooooo`;o00004?ooool2o`0001Sooooo0ol0001nooooo`;o0000HOooool2o`0000kooooo0_l0000@
ooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o00002?ooool2o`00013ooooo0_l0000Hoooo
o`;o0000@oooool2o`0001;ooooo0_l0000Vooooo`Co0000Goooool2o`0000kooooo0_l0000@oooo
o`007_ooool00ol0003oooooooooo`26ooooo`;o00004_ooool2o`0002Sooooo0_l00021ooooo`00
7_ooool00ol0003oooooooooo`1jooooo`;o0000Doooool2o`0001kooooo0_l0001Fooooo`000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003ooooo
ooooo`14ooooo`;o00003oooool2o`0002?ooooo0_l0000Uooooo`;o0000;?ooool2o`0001kooooo
0_l0000Hooooo`;o0000;oooool2o`0000_ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo01Ko
oooo0_l0000Pooooo`;o00002_ooool2o`0000oooooo0_l00011ooooo`;o00001oooool2o`0002?o
oooo0_l00011ooooo`;o0000;oooool2o`0000_ooooo0003ooooo`05oa0@4?ooooooooooooooool@
41003?ooool00onHV9So8B4Qonk^kP07ooooo`?o00005_ooool2o`00023ooooo0_l00011ooooo`;o
00006oooool2o`0000[ooooo0_l0000Pooooo`;o0000Ooooool000?ooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool03Oooool2o`0003Oo
oooo0_l0000cooooo`;o000000Coooooo`000?l0003ooooo0_l0000Qooooo`;o0000FOooool2o`00
03_ooooo0_l00009ooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool01Oooool00ol0003oooooooooo`0=ooooo`;o0000=oooool2o`0003Kooooo0_l000000ooo
oooo0000o`00001looooo`?o0000>_ooool2o`0000Wooooo0003ooooo`05oa0@4?oooooooooooooo
ool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo0_l0000Ioooo
o`;o00002_ooool2o`000<Gooooo0_l0000@ooooo`;o0000<oooool000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`0B
ooooo`;o00006Oooool2o`0000[ooooo0_l00014ooooo`;o0000TOooool2o`0003?ooooo0003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o
0000ooooooooool0=?ooool2o`0004Wooooo0_l0001Eooooo`;o00003Oooool2o`00063ooooo000N
ooooo`03o`000?oooooooooo00_ooooo0_l0000Wooooo`;o0000K_ooool2o`00033ooooo0_l0000=
ooooo`;o00000_ooool2o`00047ooooo0_l0000Iooooo`007_ooool00ol0003oooooooooo`0;oooo
o`;o00001?ooool2o`00097ooooo0_l0000nooooo`;o00000oooool2o`00047ooooo0_l0000Ioooo
o`007_ooool00ol0003oooooooooo`0Aooooo`;o0000L?ooool2o`0004[ooooo0_l0000Cooooo`;o
0000HOooool001kooooo00?o0000ooooooooool02Oooool4o`0001kooooo0_l0000Looooo`;o0000
>?ooool2o`0004[ooooo0_l0000Eooooo`;o00006_ooool2o`0004?ooooo000Nooooo`03o`000?oo
oooooooo00Wooooo1?l0000Booooo`;o00002_ooool2o`0001?ooooo0_l00002ooooo`;o00000ooo
ool2o`0002oooooo0_l0000looooo`;o00008Oooool2o`0000Wooooo0_l0000Jooooo`;o0000@ooo
ool001kooooo00?o0000ooooooooool07oooool2o`0001Gooooo0_l00008ooooo`;o00000_ooool2
o`0000;ooooo0_l0000`ooooo`;o0000??ooool2o`00027ooooo0_l0001Zooooo`007_ooool00ol0
003oooooooooo`0fooooo`;o00004?ooool2o`000=Wooooo0_l0000Rooooo`007_ooool00ol0003o
ooooooooo`1Iooooo`;o0000=oooool2o`0000[ooooo0_l0000Kooooo`;o00003Oooool2o`0000_o
oooo0_l0001:ooooo`;o00008_ooool001kooooo00?o0000ooooooooool0Doooool2o`0000Cooooo
0_l0000@ooooo`;o00007oooool2o`0000Cooooo0_l0000:ooooo`;o00006oooool2o`0000gooooo
0_l00005ooooo`;o00001?ooool2o`0000Cooooo0_l0000Yooooo`;o0000?Oooool001kooooo00?o
0000ooooooooool01oooool2o`0004[ooooo0_l0000Fooooo`;o00007oooool2o`0004?ooooo0_l0
000:ooooo`;o0000:Oooool2o`0003gooooo000Nooooo`03o`000?oooooooooo00;o00001Oooool2
o`0002[ooooo0_l0000hooooo`;o00004oooool2o`0007kooooo0_l0000Rooooo`;o00007oooool0
01kooooo0_l000000ooooooo0000o`00000aooooo`;o00008oooool2o`0001?ooooo0_l0000Coooo
o`;o0000B_ooool2o`0003;ooooo0_l0000Rooooo`;o00007oooool001kooooo00?o0000oooooooo
ool0F?ooool2o`0007Cooooo0_l0001Dooooo`;o00008Oooool001kooooo00?o0000ooooooooool0
loooool2o`0000gooooo0_l0000Pooooo`;o00008Oooool001kooooo00?o0000ooooooooool0G_oo
ool2o`0001[ooooo0_l0000Vooooo`;o00001?ooool2o`0004Wooooo0_l0000=ooooo`;o00002?oo
ool2o`0003Wooooo000Nooooo`03o`000?oooooooooo02Wooooo0_l0000cooooo`;o00005?ooool2
o`0000Cooooo0_l0000Kooooo`;o00002Oooool2o`0000Cooooo0_l0000fooooo`;o0000:_ooool2
o`0000Kooooo0_l0000aooooo`007_ooool00ol0003oooooooooo`0Yooooo`;o0000?_ooool2o`00
00Wooooo0_l0000Eooooo`;o00002_ooool2o`0004Oooooo0_l0000booooo`;o0000<Oooool001ko
oooo00?o0000ooooooooool02_ooool2o`0005gooooo0_l0000Pooooo`;o0000^_ooool001gooooo
0_l00005ooooo`;o00001Oooool2o`0003cooooo0_l0001dooooo`;o0000=oooool2o`0001Gooooo
0_l0000gooooo`007Oooool2o`0000Gooooo0_l0000;ooooo`;o0000=_ooool2o`0003;ooooo0_l0
0010ooooo`;o0000=oooool2o`0000?ooooo0_l0000@ooooo`;o0000=oooool001kooooo00?o0000
ooooooooool04?ooool2o`0006[ooooo0_l00005ooooo`;o0000K_ooool2o`0000Oooooo0_l00019
ooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o00009?ooool2o`0004gooooo0_l0000ioooo
o`;o00002Oooool2o`0002Sooooo0_l0001Booooo`007_ooool00ol0003oooooooooo`0>ooooo`;o
00009?ooool2o`0001kooooo0_l0001Xooooo`;o00002Oooool2o`0004?ooooo0_l0000gooooo`00
7_ooool00ol0003oooooooooo`0hooooo`;o00003_ooool2o`0000[ooooo0_l0002hooooo`;o0000
=oooool001kooooo00?o0000ooooooooool01oooool2o`0002oooooo0_l0000>ooooo`;o0000S_oo
ool2o`0006gooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l00003ooooo`;o00007_ooool2
o`000:[ooooo0_l0001]ooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o00007_ooool2o`00
00oooooo0_l0000`ooooo`;o0000e_ooool001kooooo0_l0000nooooo`;o00006?ooool2o`0000ko
oooo0_l00003ooooo`;o000000?oooooo`000?l00000__ooool2o`0001Kooooo000Nooooo`03o`00
0?oooooooooo02Oooooo0_l0000^ooooo`;o00003_ooool2o`0000?ooooo0_l0000hooooo`;o0000
G_ooool2o`0000cooooo0_l0000;ooooo`;o00003?ooool2o`0001Kooooo000Nooooo`03o`000?oo
oooooooo01kooooo0_l00007ooooo`;o00006?ooool2o`0005gooooo0_l00004ooooo`;o0000G_oo
ool2o`0000Cooooo0_l00006ooooo`;o00002oooool2o`0002Cooooo000Nooooo`03o`000?oooooo
oooo01Gooooo0_l00007ooooo`;o00008Oooool2o`00043ooooo0_l0000Kooooo`;o00001?ooool2
o`0006Cooooo0_l000000ooooooo0000o`00000fooooo`007_ooool00ol0003oooooooooo`0<oooo
o`;o00001oooool2o`0006cooooo0_l00002ooooo`?o00009Oooool2o`0005kooooo0_l0000foooo
o`007_ooool00ol0003oooooooooo`0<ooooo`;o00008Oooool4o`0005Cooooo0ol0000Uooooo`;o
00004_ooool2o`0002Sooooo0_l0001Hooooo`007Oooool2o`00037ooooo1?l0000gooooo`;o0000
=Oooool2o`0001Gooooo0_l00009ooooo`;o0000:?ooool2o`0005Sooooo000Mooooo`;o00005ooo
ool2o`00053ooooo0_l000000ooooooo0000o`00000Vooooo`;o00000_ooool2o`0000Wooooo0_l0
000>ooooo`;o00001Oooool2o`0008gooooo000Nooooo`03o`000?oooooooooo01Gooooo0_l0001@
ooooo`;o00006oooool2o`0000cooooo0_l00002ooooo`;o00006Oooool2o`0002gooooo0_l0001U
ooooo`007_ooool01?l0003oooooooooooooool2o`00087ooooo0_l0001Jooooo`;o00005Oooool2
o`0004kooooo000Nooooo`04o`000?ooooooooooooooo`;o00001?ooool2o`0001Sooooo0_l0001f
ooooo`;o0000A_ooool2o`0001Cooooo0_l0000Gooooo`;o00004?ooool2o`0002?ooooo000Noooo
o`03o`000?oooooooooo00Oooooo0_l0000Hooooo`;o0000M_ooool2o`0001Oooooo0_l0000]oooo
o`;o0000;Oooool2o`00013ooooo0_l0000Sooooo`007_ooool00ol0003oooooooooo`2;ooooo`;o
00009Oooool2o`0001cooooo0_l0001eooooo`007_ooool00ol0003oooooooooo`2;ooooo`;o0000
@oooool2o`0003Sooooo0_l0000kooooo`007_ooool00ol0003oooooooooo`3[ooooo`;o00007Ooo
ool2o`0003_ooooo000Mooooo`;o00009oooool2o`0005[ooooo0_l00006ooooo`;o0000H?ooool2
o`0002kooooo0_l0000Zooooo`007Oooool3o`0002Kooooo0_l0000jooooo`;o00007_ooool2o`00
00Kooooo0_l0000Iooooo`;o0000MOooool2o`0002[ooooo000Nooooo`03o`000?oooooooooo02Co
oooo0_l0000Aooooo`;o0000:?ooool2o`00013ooooo0_l00005ooooo`?o00009oooool2o`00057o
oooo0_l0000Xooooo`;o00009?ooool001kooooo00?o0000ooooooooool09?ooool2o`00017ooooo
0_l0000jooooo`;o00001Oooool3o`0000Sooooo0_l00008ooooo`;o0000F?ooool2o`0000cooooo
0_l0000Xooooo`;o00009?ooool001kooooo00?o0000ooooooooool0:_ooool2o`0002gooooo0_l0
000Zooooo`;o00002?ooool2o`0005Sooooo0_l0001Dooooo`;o00001_ooool001kooooo00?o0000
ooooooooool0:_ooool2o`0002gooooo0_l00018ooooo`;o00003oooool2o`0008Wooooo0_l00006
ooooo`007_ooool00ol0003oooooooooo`02o`0004Gooooo0_l0000@ooooo`;o0000??ooool2o`00
00[ooooo0_l0000?ooooo`;o00001Oooool2o`0008[ooooo000Nooooo`03o`000?oooooooooo00;o
00008?ooool2o`0002?ooooo0_l0000gooooo`;o00005Oooool2o`0002;ooooo0_l0001oooooo`;o
00002Oooool001kooooo00?o0000ooooooooool08_ooool2o`0000Wooooo0_l0000nooooo`;o0000
4Oooool2o`0000Wooooo0_l0001aooooo`;o0000??ooool2o`0000Wooooo000Nooooo`03o`000?oo
oooooooo02gooooo0_l0000/ooooo`;o00004?ooool2o`0001cooooo0_l0001Aooooo`;o00001ooo
ool2o`0000;ooooo0_l0000Aooooo`;o00004?ooool2o`0003Gooooo000Nooooo`03o`000?oooooo
oooo02Wooooo0_l0000`ooooo`;o0000Aoooool4o`0003Kooooo0_l00007ooooo`;o00000_ooool2
o`0000;ooooo0ol0000Eooooo`;o00001oooool2o`0003Gooooo000Nooooo`03o`000?oooooooooo
02Wooooo0_l0000aooooo`;o00005?ooool2o`00033ooooo1?l00017ooooo`?o00005Oooool2o`00
03kooooo000Nooooo`03o`000?oooooooooo05cooooo0_l0000Dooooo`;o0000>Oooool2o`0009So
oooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0000Rooooo`;o0000O_ooool2o`0000Cooooo
0_l0000Aooooo`;o0000Ooooool001kooooo00?o0000ooooooooool02Oooool2o`0002;ooooo0_l0
0024ooooo`;o00004Oooool2o`0002Oooooo0_l0000[ooooo`;o00006?ooool2o`0000oooooo0003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413ooooooooo
o`04ooooo`03o`000?oooooooooo05;ooooo0_l0002Kooooo`;o0000:oooool4o`0001Kooooo0_l0
000?ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oo
oooooooo00Gooooo00Co0000ooooool0003o00003oooool2o`00043ooooo0_l0003:ooooo`;o0000
9oooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool4o`0000?ooooo
0_l00007ooooo`;o000000Coooooo`000?l0003ooooo0_l0003ooooooc?ooooo0003ooooo`05o`00
0?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo
00Cooooo0_l00007ooooo`;o00001?ooool2o`0000;ooooo0_l0003Uooooo`;o0000Aoooool000?o
oooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000
ooooooooool05oooool2o`0006Oooooo0_l0000;ooooo`;o00009?ooool2o`0004Wooooo0_l0000j
ooooo`;o00002oooool000?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co
000000Oooooo00?o0000ooooooooool0P?ooool2o`0000_ooooo0_l0000Tooooo`;o00005oooool2
o`0006cooooo0_l0000;ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000001oooool00ol0003oooooooooo`2Yooooo`;o00008Oooool2o`0007Wooooo0003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooo
oooo01Sooooo0_l0001Cooooo`;o0000;_ooool2o`0000[ooooo0_l0000<ooooo`;o00002oooool2
o`00087ooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l00003ooooo`;o00002?ooool2o`00
05?ooooo0_l0000^ooooo`;o00006?ooool2o`0000_ooooo0_l0001dooooo`;o00002oooool001ko
oooo00?o0000ooooooooool02Oooool2o`0000?ooooo0_l0000Fooooo`;o0000:?ooool2o`0008ko
oooo0_l0000mooooo`;o00006Oooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo02Kooooo
0_l0000:ooooo`;o00007?ooool2o`0006?ooooo0_l0000Pooooo`;o00001oooool2o`0003gooooo
0_l0000Kooooo`;o00002Oooool001kooooo00?o0000ooooooooool03?ooool2o`0002Cooooo0_l0
000mooooo`;o00002_ooool2o`00017ooooo0_l0000Sooooo`;o00008?ooool2o`0004Oooooo0_l0
000:ooooo`;o00003_ooool2o`0000Wooooo000Nooooo`03o`000?oooooooooo00cooooo0_l0001S
ooooo`;o00002_ooool2o`00017ooooo0_l0000Iooooo`;o00007?ooool2o`0001?ooooo0_l00003
ooooo`;o00008Oooool2o`0001Sooooo0_l0000:ooooo`;o00002oooool2o`0000?ooooo0_l00007
ooooo`007_ooool00ol0003oooooooooo`14ooooo`;o0000@oooool2o`00023ooooo0_l0000Loooo
o`;o00004oooool2o`0000?ooooo0_l0000Hooooo`;o00001oooool2o`0000Gooooo0_l0000Zoooo
o`;o00000oooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo03Kooooo0_l0000<ooooo`;o
00009_ooool2o`0001Sooooo0_l000000ooooooo0000o`00001booooo`;o00003_ooool2o`0003So
oooo000Nooooo`03o`000?oooooooooo03Kooooo0_l0000;ooooo`;o00009oooool2o`0001Sooooo
0_l0002oooooo`007_ooool00ol0003oooooooooo`13ooooo`;o0000Koooool2o`0006Cooooo0_l0
000[ooooo`007_ooool00ol0003oooooooooo`1Cooooo`;o0000Goooool4o`0006;ooooo0_l0000<
ooooo`;o00007Oooool001kooooo00?o0000ooooooooool05?ooool2o`0003gooooo0_l0000Goooo
o`;o0000B?ooool2o`0000[ooooo0_l0001Tooooo`;o00000_ooool2o`0001Wooooo000Nooooo`;o
00005Oooool2o`0005Kooooo0_l0000]ooooo`;o00009Oooool2o`0006Sooooo0_l0000Iooooo`00
7_ooool00ol0003oooooooooo`2Kooooo`;o000000?oooooo`000?l000003?ooool2o`0005Gooooo
0_l00012ooooo`007_ooool00ol0003oooooooooo`0[ooooo`;o0000>?ooool2o`0000?ooooo0_l0
000booooo`;o00003?ooool2o`0000Gooooo0_l0001>ooooo`;o0000@_ooool001kooooo00?o0000
ooooooooool08_ooool2o`0000Oooooo0_l0000hooooo`;o00000oooool2o`0004Oooooo0_l00006
ooooo`;o0000R_ooool001kooooo00?o0000ooooooooool05?ooool2o`0000cooooo0_l00011oooo
o`;o0000?oooool2o`0001?ooooo0_l000000ooooooo0000o`00001Dooooo`;o0000:?ooool2o`00
00Oooooo000Nooooo`03o`000?oooooooooo01Cooooo1?l0001Fooooo`;o0000<oooool2o`000003
ooooool0003o000001Kooooo0_l0000Nooooo`;o0000=?ooool2o`0002Sooooo0_l00007ooooo`00
7_ooool00ol0003oooooooooo`0Fooooo`;o0000E_ooool2o`0003?ooooo0_l0000iooooo`;o0000
Ioooool001kooooo00?o0000ooooooooool0Koooool2o`0002gooooo0_l00002ooooo`;o0000Xooo
ool001kooooo00?o0000ooooooooool0Koooool2o`00027ooooo0_l0000:ooooo`;o00000_ooool2
o`0002cooooo0_l0001Oooooo`;o00005?ooool001kooooo00?o0000ooooooooool03oooool2o`00
05?ooooo0_l00007ooooo`;o00008oooool2o`0002Cooooo0_l00005ooooo`;o00003oooool2o`00
05oooooo0_l0000;ooooo`;o00001oooool001kooooo00?o0000ooooooooool03oooool2o`0005?o
oooo0_l00007ooooo`;o0000BOooool2o`0000Gooooo0_l0001mooooo`;o00001oooool001kooooo
00?o0000ooooooooool06Oooool2o`0006_ooooo0_l0002oooooo`007_ooool00ol0003ooooooooo
o`0Fooooo`;o000000?oooooo`000?l000003oooool2o`00023ooooo0_l0000Pooooo`;o00005_oo
ool2o`0005Cooooo0_l0001Yooooo`007_ooool00ol0003oooooooooo`0Fooooo`;o00004_ooool2
o`00023ooooo0_l0000Pooooo`;o0000K?ooool2o`0000[ooooo0_l00012ooooo`;o00006Oooool0
01kooooo00?o0000ooooooooool0j?ooool2o`0003Sooooo0ol00007ooooo`;o00002_ooool2o`00
00gooooo000Nooooo`;o0000F?ooool2o`0002Wooooo0_l0002Nooooo`?o00004oooool2o`0000go
oooo000Nooooo`;o00009?ooool2o`0003;ooooo0_l0000Yooooo`;o0000VOooool4o`0000Wooooo
0_l0000Kooooo`007_ooool00ol0003oooooooooo`09ooooo`;o00001_ooool2o`00013ooooo0_l0
000Zooooo`;o00001?ooool2o`0001Sooooo0_l0000Wooooo`;o0000Poooool4o`0000Wooooo0_l0
000Kooooo`007_ooool00ol0003oooooooooo`09ooooo`;o00001_ooool2o`0000kooooo0_l0000Q
ooooo`;o00002Oooool2o`0000Cooooo0_l0000>ooooo`;o00002?ooool2o`0002Oooooo0_l0000S
ooooo`;o0000HOooool2o`0002Gooooo000Nooooo`03o`000?oooooooooo027ooooo0_l0000Qoooo
o`;o00007oooool2o`0005Kooooo0_l0001Eooooo`;o00002_ooool2o`0002Gooooo000Nooooo`03
o`000?oooooooooo09[ooooo0_l0001hooooo`;o0000<Oooool001kooooo00?o0000ooooooooool0
4oooool2o`00013ooooo0_l0000Sooooo`;o0000C_ooool2o`000:_ooooo000Nooooo`03o`000?oo
oooooooo01?ooooo0_l0000@ooooo`;o00008oooool2o`000?_ooooo000Nooooo`03o`000?oooooo
oooo00_ooooo0_l0001Aooooo`;o00002oooool2o`0009gooooo0_l0000kooooo`007_ooool00ol0
003oooooooooo`0;ooooo`;o0000DOooool2o`0000_ooooo0_l0002Mooooo`;o00002Oooool2o`00
033ooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0003gooooo`;o00006?ooool2o`0002So
oooo0_l00006ooooo`007_ooool00ol0003oooooooooo`02ooooo`;o0000/Oooool2o`0004Cooooo
0_l0000Gooooo`?o0000:?ooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo00;o0000I_oo
ool2o`0002Oooooo0_l0000Rooooo`;o00004oooool2o`0000[ooooo0_l0000looooo`;o0000<Ooo
ool001kooooo00?o0000ooooooooool00_l0001Vooooo`;o00009oooool2o`0003Oooooo0_l0000:
ooooo`;o0000Koooool001kooooo00?o0000ooooooooool07_ooool2o`0000Sooooo0_l0000:oooo
o`;o0000Foooool2o`0002Cooooo0_l0000Zooooo`;o00001oooool2o`0005Wooooo000Nooooo`03
o`000?oooooooooo00Cooooo0_l0000Hooooo`;o00002?ooool2o`0000[ooooo0_l0001Fooooo`;o
0000:Oooool2o`0002[ooooo0_l00002ooooo`;o00000oooool2o`0000[ooooo0_l0000]ooooo`;o
00003?ooool2o`00013ooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0001Vooooo`;o0000
7_ooool2o`0002;ooooo0_l0000eooooo`;o00003oooool2o`0002gooooo0_l0000<ooooo`;o0000
4?ooool001kooooo0_l0000booooo`;o0000>Oooool2o`0004;ooooo0_l00020ooooo`;o00004ooo
ool001kooooo00?o0000ooooooooool0<Oooool2o`0000Cooooo0_l0000cooooo`;o00004Oooool2
o`0006Sooooo0_l00017ooooo`;o00004oooool001kooooo00?o0000ooooooooool0:_ooool2o`00
00_ooooo0_l0000Kooooo`;o00005_ooool2o`00017ooooo0_l0001Xooooo`;o00003_ooool2o`00
04cooooo000Nooooo`03o`000?oooooooooo02[ooooo0_l0000=ooooo`;o00006Oooool2o`00027o
oooo0_l00020ooooo`;o0000C?ooool001kooooo00?o0000ooooooooool0>Oooool2o`0003Kooooo
0_l00004ooooo`;o0000Hoooool2o`0006Wooooo000Nooooo`03o`000?oooooooooo06Gooooo0_l0
000:ooooo`;o0000JOooool2o`0000Oooooo0_l0001Pooooo`007_ooool00ol0003oooooooooo`1C
ooooo`;o00004?ooool2o`00023ooooo0_l00002ooooo`;o0000C_ooool2o`0000Sooooo0_l0000Y
ooooo`;o0000=Oooool001kooooo00?o0000ooooooooool01_ooool2o`0004_ooooo0_l0000boooo
o`;o00000_ooool2o`0004kooooo0_l0000cooooo`;o00002Oooool2o`0002[ooooo000Nooooo`03
o`000?oooooooooo00Kooooo0_l00002ooooo`;o0000COooool2o`000<3ooooo0_l0000Zooooo`00
7_ooool00ol0003oooooooooo`0:ooooo`;o000000?oooooo`000?l000003oooool2o`0003Wooooo
0_l00036ooooo`;o00000_ooool2o`00023ooooo000Nooooo`03o`000?oooooooooo00gooooo0_l0
000?ooooo`;o0000@_ooool2o`000;gooooo0_l00002ooooo`;o00008?ooool001kooooo00?o0000
ooooooooool08?ooool2o`00043ooooo0_l0001looooo`;o0000IOooool001kooooo00?o0000oooo
ooooool08?ooool2o`0002gooooo0_l0000_ooooo`;o0000G_ooool2o`00043ooooo1?l0000Doooo
o`;o00002oooool001kooooo00?o0000ooooooooool0>oooool2o`0001;ooooo1?l0000]ooooo`;o
0000D?ooool2o`0000Kooooo0_l00016ooooo`Co00005?ooool2o`0000_ooooo0003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006oooo
o`03o`000?oooooooooo03_ooooo0_l0000Dooooo`;o0000Ooooool2o`0000Kooooo0_l0000?oooo
o`;o00004Oooool2o`0004Oooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0>_ooooo0_l0000A
ooooo`;o0000>Oooool2o`0000cooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool0
1Ol0003ooooooooooooooooo000000Kooooo0ol0001Looooo`;o0000`Oooool2o`0001Sooooo0_l0
000<ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RH
ob4Q8@06ooooo`03o`000?oooooooooo01?ooooo0_l00017ooooo`;o0000`Oooool2o`0001kooooo
0_l00006ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o
410@olc<c006ooooo`03o`000?oooooooooo01?ooooo0_l0003oooooob_ooooo0_l00006ooooo`00
0oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003o
ooooooooo`16ooooo`;o0000<oooool2o`0000;ooooo0_l000000ooooooo0000o`00000cooooo`;o
0000S_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00So
oooo00?o0000ooooooooool0A_ooool2o`0003?ooooo0_l00002ooooo`;o000000?oooooo`000?l0
0000<oooool2o`0008kooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<co
A4A4o`000?l@4106ooooo`03o`000?oooooooooo02gooooo0_l0002booooo`;o0000Doooool2o`00
00oooooo000Nooooo`03o`000?oooooooooo02?ooooo0_l00008ooooo`;o0000?Oooool2o`0000Co
oooo0_l0000fooooo`;o0000=Oooool2o`0001cooooo0_l00008ooooo`;o0000:oooool2o`0000Wo
oooo0_l00004ooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o0000Aoooool2o`0000Cooooo
0_l0000fooooo`;o00003?ooool2o`0002oooooo0ol0000Cooooo`;o00002?ooool2o`0003Kooooo
0_l00004ooooo`007_ooool00ol0003oooooooooo`1Xooooo`;o0000:Oooool2o`0002?ooooo0_l0
000Zooooo`;o00000oooool3o`0001?ooooo0_l0000Dooooo`;o0000<?ooool001kooooo00?o0000
ooooooooool0>?ooool2o`0002kooooo0_l0000Yooooo`;o00007?ooool2o`00037ooooo0_l0000G
ooooo`;o00005_ooool2o`00033ooooo000Nooooo`03o`000?oooooooooo03Sooooo0_l0001/oooo
o`;o00002Oooool2o`0002gooooo0_l000000ooooooo0000o`00000Hooooo`;o00007oooool2o`00
02Oooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0002Hooooo`;o00000oooool2o`0003Oo
oooo0ol000000ooooooo0000o`000007ooooo`;o00001?ooool2o`0002[ooooo0_l0000Wooooo`00
7_ooool00ol0003oooooooooo`07ooooo`;o00007Oooool2o`0007Wooooo0_l0000looooo`;o0000
2oooool2o`0000Cooooo0_l0001Cooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o00001?oo
ool2o`0009_ooooo0_l0000?ooooo`;o0000@oooool2o`0002cooooo000Nooooo`03o`000?oooooo
oooo023ooooo0_l0002<ooooo`;o00004oooool2o`0000oooooo0_l00013ooooo`;o0000;?ooool0
01kooooo00?o0000ooooooooool0ROooool2o`0002?ooooo0_l0001eooooo`;o00008?ooool001ko
oooo00?o0000ooooooooool0Doooool2o`0003Cooooo0_l0002Jooooo`;o00008?ooool001kooooo
0_l0001Dooooo`;o0000Z_ooool2o`0004Kooooo000Nooooo`03o`000?oooooooooo02Kooooo0_l0
003Gooooo`;o0000A_ooool001kooooo00?o0000ooooooooool00_ooool2o`0002;ooooo0_l0002m
ooooo`;o0000H?ooool001kooooo00?o0000ooooooooool00_ooool2o`000;Wooooo0_l0000Voooo
o`;o00004oooool2o`0004_ooooo000Nooooo`03o`000?oooooooooo06gooooo0_l0001>ooooo`;o
0000>oooool2o`0004_ooooo000Nooooo`03o`000?oooooooooo02?ooooo0_l00018ooooo`;o0000
9?ooool2o`000;;ooooo000Mooooo`;o00005_ooool2o`0000gooooo0_l0001^ooooo`;o00005_oo
ool2o`0007Wooooo0_l0000Oooooo`007Oooool2o`0001Kooooo0_l0002Eooooo`;o0000J?ooool2
o`0000oooooo0_l0000Oooooo`007_ooool00ol0003oooooooooo`3ooooooaKooooo0_l0000`oooo
o`007_ooool00ol0003oooooooooo`3oooooocSooooo0_l0000>ooooo`007_ooool00ol0003ooooo
ooooo`2gooooo`;o00008_ooool2o`0005[ooooo0_l0000>ooooo`007_ooool00ol0003ooooooooo
o`1Eooooo`;o0000H?ooool2o`0002;ooooo0_l0001Zooooo`007_ooool00ol0003oooooooooo`1E
ooooo`;o0000Coooool2o`0009oooooo000Nooooo`03o`000?oooooooooo01oooooo0_l00003oooo
o`;o00002Oooool2o`0007Gooooo0_l0000;ooooo`;o00008?ooool2o`0001?ooooo0_l0001Koooo
o`007_ooool00ol0003oooooooooo`0Oooooo`;o00000oooool2o`0000Wooooo0_l0001[ooooo`;o
00005Oooool2o`00023ooooo0_l0000Cooooo`;o0000Foooool001kooooo00?o0000ooooooooool0
5_ooool2o`0008Cooooo0_l0000Eooooo`;o0000T_ooool001kooooo0_l0000Gooooo`;o0000Vooo
ool2o`0001Wooooo0_l0000Zooooo`;o00009Oooool2o`0002Cooooo000Nooooo`03o`000?oooooo
oooo00[ooooo0_l0001oooooo`;o0000@Oooool2o`0002[ooooo0_l0000Sooooo`Co00002Oooool2
o`0001Wooooo000Nooooo`04o`000?ooooooooooooooo`;o00001oooool2o`0006Sooooo0_l0000?
ooooo`;o00001?ooool2o`0005Wooooo0_l0000gooooo`;o00002?ooool2o`000003ooooool0003o
000000?ooooo0_l0000Dooooo`007_ooool01?l0003oooooooooooooool2o`00077ooooo0_l0000?
ooooo`;o0000@_ooool2o`0001_ooooo0_l0000Wooooo`;o00006?ooool2o`0000Kooooo0_l0000;
ooooo`;o00001oooool001kooooo00?o0000ooooooooool0bOooool2o`0004Cooooo0_l0000]oooo
o`;o00001oooool001kooooo0ol0002Wooooo`;o00003?ooool3o`0008oooooo000Nooooo`?o0000
;Oooool2o`00067ooooo0_l0000Eooooo`;o00003?ooool3o`0002_ooooo0_l0001Rooooo`007_oo
ool00ol0003oooooooooo`0]ooooo`;o0000<?ooool2o`0002oooooo0_l0001Aooooo`;o0000H_oo
ool001kooooo00?o0000ooooooooool0AOooool2o`0001Sooooo0_l0001gooooo`;o0000KOooool0
01kooooo00?o0000ooooooooool0AOooool2o`0000Cooooo0_l0000Booooo`;o00002?ooool2o`00
05kooooo0_l0000=ooooo`;o0000KOooool001kooooo00?o0000ooooooooool0Boooool2o`0001co
oooo0_l0001Nooooo`;o0000=Oooool2o`0000kooooo0_l00007ooooo`;o0000;?ooool001kooooo
00?o0000ooooooooool0<_ooool2o`0008;ooooo0_l0000hooooo`;o00003_ooool2o`0000kooooo
0_l00007ooooo`;o0000;?ooool001kooooo00?o0000ooooooooool0<_ooool2o`0002Kooooo0_l0
000kooooo`;o00002_ooool2o`00017ooooo0_l000000ooooooo0000o`00000eooooo`;o00004_oo
ool2o`00047ooooo000Nooooo`03o`000?oooooooooo02Wooooo0_l0000_ooooo`;o00004?ooool2
o`00027ooooo0_l00003ooooo`;o000000?oooooo`000?l000002_ooool2o`0001Cooooo0_l00019
ooooo`;o0000@Oooool001kooooo00?o0000ooooooooool02_ooool2o`0001gooooo0_l00005oooo
o`;o0000>_ooool2o`00027ooooo0_l00003ooooo`;o0000?_ooool2o`0002Wooooo0_l00016oooo
o`007_ooool00ol0003oooooooooo`0:ooooo`;o00009?ooool2o`0005Wooooo0_l00017ooooo`;o
0000:Oooool2o`0004Kooooo000Nooooo`;o0000Hoooool2o`0002Oooooo0_l0002jooooo`007_oo
ool00ol0003oooooooooo`17ooooo`;o00006Oooool2o`0001Kooooo0_l00027ooooo`;o00006_oo
ool2o`0002Kooooo000Nooooo`03o`000?oooooooooo01gooooo0_l0000Xooooo`;o0000<Oooool2
o`0008Oooooo0_l0000Jooooo`;o00009_ooool001kooooo00?o0000ooooooooool01Oooool2o`00
01Kooooo0_l0000Cooooo`;o0000]_ooool2o`0001kooooo0_l0000Vooooo`;o00004oooool001ko
oooo00?o0000ooooooooool01Oooool2o`0002_ooooo0_l0000Jooooo`;o0000V_ooool2o`000003
ooooool0003o000001_ooooo0_l0000Vooooo`;o00004oooool001kooooo00?o0000ooooooooool0
=_ooool2o`0001Kooooo0_l0001mooooo`;o00007_ooool2o`0002Cooooo0_l0000booooo`007_oo
ool00ol0003oooooooooo`0fooooo`;o0000UOooool2o`0004Cooooo0_l0000<ooooo`;o00009?oo
ool001kooooo00?o0000ooooooooool06oooool2o`0001Oooooo0_l0002Sooooo`;o0000:?ooool2
o`0001cooooo0_l0000Tooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o00002?ooool2o`00
01Oooooo0_l0001jooooo`;o00009oooool2o`0002Sooooo0_l0000fooooo`;o00002_ooool001ko
oooo00?o0000ooooooooool04Oooool2o`0009gooooo0_l00029ooooo`;o00002_ooool001kooooo
00?o0000ooooooooool0<?ooool2o`0003Kooooo0_l0001oooooo`;o0000@_ooool2o`0001Sooooo
000Nooooo`03o`000?oooooooooo00Wooooo0_l0000Uooooo`;o00004oooool2o`00027ooooo0_l0
001oooooo`;o0000@_ooool2o`0001Sooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0000O
ooooo`;o00006Oooool2o`000?oooooo0Oooool001kooooo00?o0000ooooooooool0:_ooool2o`00
00Wooooo0_l0002Fooooo`;o00008oooool2o`0005?ooooo0003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooo
oooo02kooooo0_l00005ooooo`;o0000E_ooool2o`0003kooooo0_l0000Sooooo`;o0000@?ooool2
o`00017ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4Q
oiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo02kooooo0_l0000hooooo`;o00003?oo
ool2o`0001Gooooo0_l0000oooooo`;o00004_ooool2o`0004kooooo1?l0000Aooooo`000oooool0
1Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000
C_ooool3o`0001Oooooo0_l0000<ooooo`;o00009Oooool2o`0000Kooooo0_l0000Wooooo`;o0000
0oooool2o`0000gooooo0_l0000Uooooo`;o00009oooool2o`0001?ooooo0003ooooo`05o`000?oo
ooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000oooooooo
ool0:oooool2o`00027ooooo0ol00006ooooo`;o0000A?ooool2o`0000Kooooo0_l0000Yooooo`;o
000000?oooooo`000?l00000=?ooool2o`0003cooooo0003ooooo`05o`000?ooooooooooooooool0
00002oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo0ol0000[ooooo`;o0000:_ooool2o`00
01Kooooo0_l0000Zooooo`;o0000<oooool2o`0007Gooooo0003ooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo0ol0001_ooooo`;o0000:_ooool2
o`000:[ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj
^[[o000000Kooooo00?o0000ooooooooool05?ooool2o`0000;ooooo0_l0000:ooooo`;o0000]ooo
ool2o`0006Sooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`00
0?l@413oZJVY00Kooooo00?o0000ooooooooool05?ooool2o`0000;ooooo1?l00008ooooo`;o0000
]oooool2o`0006Sooooo000Nooooo`03o`000?oooooooooo01[ooooo0_l0001kooooo`;o0000N?oo
ool2o`0003Cooooo000Nooooo`03o`000?oooooooooo01[ooooo0_l0001Zooooo`;o00003oooool2
o`00073ooooo0_l00006ooooo`;o00007oooool2o`0001?ooooo000Nooooo`03o`000?oooooooooo
04Wooooo0_l00007ooooo`;o00000_ooool2o`0002kooooo0_l0000Kooooo`;o0000I?ooool2o`00
01Oooooo0_l0000>ooooo`;o00004oooool001kooooo00?o0000ooooooooool02?ooool2o`0003oo
oooo0_l00007ooooo`;o00000_ooool2o`0004_ooooo0_l0001mooooo`;o00008oooool001kooooo
00?o0000ooooooooool02?ooool2o`0001cooooo0_l0001Dooooo`;o0000<Oooool2o`0001_ooooo
0_l0001iooooo`007_ooool00ol0003oooooooooo`0Vooooo`;o0000E?ooool2o`00033ooooo0ol0
000=ooooo`;o00003?ooool2o`0007Wooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l0000?
ooooo`;o0000P_ooool2o`0000_ooooo0_l000000ooooooo0000o`00000@ooooo`;o0000MOooool0
01kooooo00?o0000ooooooooool06Oooool2o`0000oooooo0_l0000Vooooo`;o00008Oooool2o`00
04Cooooo0_l0000Booooo`?o00009_ooool2o`0000?ooooo0_l00018ooooo`007_ooool00ol0003o
ooooooooo`0Xooooo`;o0000:?ooool2o`0001Oooooo0_l00008ooooo`;o0000;oooool2o`0002Oo
oooo1?l0000Uooooo`;o00000oooool2o`0004Sooooo000Nooooo`03o`000?oooooooooo02Sooooo
0_l00002ooooo`;o0000:oooool3o`0000oooooo0_l0000iooooo`;o0000:Oooool2o`0007Cooooo
000Nooooo`03o`000?oooooooooo02cooooo0_l0000[ooooo`?o00006Oooool2o`0001Sooooo0_l0
000Sooooo`;o00002_ooool4o`0001;ooooo0_l0000Kooooo`;o0000D_ooool001kooooo0_l0000]
ooooo`;o0000Aoooool2o`0001Sooooo0_l0000Cooooo`;o00003_ooool4o`0000Sooooo1?l0000B
ooooo`;o00006oooool2o`0001[ooooo0_l0000Hooooo`;o000000Coooooo`000?l0003ooooo0_l0
000Fooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o0000UOooool2o`00013ooooo0_l0000S
ooooo`;o0000;Oooool2o`0000;ooooo0ol0000Hooooo`;o000000Coooooo`000?l0003ooooo0_l0
000Fooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o0000?oooool2o`0002Oooooo0_l0000O
ooooo`;o0000:oooool2o`0000Kooooo0_l0000<ooooo`;o0000;Oooool2o`0000;ooooo0_l0000g
ooooo`007_ooool00ol0003oooooooooo`1>ooooo`;o00001?ooool2o`00027ooooo0_l0000Goooo
o`;o00001_ooool2o`0002_ooooo0_l00006ooooo`;o00006oooool2o`0005_ooooo000Nooooo`03
o`000?oooooooooo05Cooooo0_l0000jooooo`;o0000<?ooool2o`0002Kooooo0_l0001Kooooo`00
7_ooool00ol0003oooooooooo`2[ooooo`;o00005Oooool2o`0003Oooooo0_l00006ooooo`;o0000
<oooool2o`0000gooooo000Nooooo`03o`000?oooooooooo0:_ooooo0_l00009ooooo`;o0000@ooo
ool2o`0000Kooooo0_l0000[ooooo`;o00001_ooool2o`0000gooooo000Nooooo`03o`000?oooooo
oooo0;Kooooo0_l0001hooooo`;o00005Oooool001kooooo00?o0000ooooooooool0M_ooool2o`00
0<oooooo000Nooooo`03o`000?oooooooooo04_ooooo0_l0000Yooooo`;o0000V?ooool4o`0003?o
oooo000Nooooo`03o`000?oooooooooo04_ooooo0_l00024ooooo`;o0000>oooool6o`0002Kooooo
0_l0000;ooooo`007_ooool00ol0003oooooooooo`2aooooo`;o00000_ooool2o`0001[ooooo0_l0
000kooooo`;o0000:_ooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo0;7ooooo0_l00002
ooooo`;o00009Oooool2o`0001Oooooo0_l0000Yooooo`;o00009Oooool001kooooo00?o0000oooo
ooooool0@oooool2o`0006kooooo1?l00009ooooo`;o00006_ooool2o`0001Oooooo0_l0000:oooo
o`;o00007Oooool2o`0002Gooooo000Nooooo`03o`000?oooooooooo00oooooo0_l0000booooo`;o
0000K_ooool4o`0000Wooooo0_l0000Rooooo`;o00006oooool2o`0004Cooooo000Nooooo`03o`00
0?oooooooooo00oooooo0_l0002Booooo`;o0000?oooool2o`00067ooooo000Nooooo`;o0000Y?oo
ool2o`0004Kooooo0_l0001Jooooo`007_ooool00ol0003oooooooooo`2@ooooo`;o0000FOooool2
o`0001;ooooo0_l0000Kooooo`;o0000:Oooool001kooooo00?o0000ooooooooool0Soooool3o`00
03oooooo0_l0000Iooooo`;o00004Oooool2o`0000;ooooo0_l0000:ooooo`;o00002oooool2o`00
00oooooo0_l0000Hooooo`007_ooool00ol0003oooooooooo`1:ooooo`;o0000@oooool2o`00043o
oooo0_l0000Iooooo`;o00005Oooool2o`0000[ooooo0_l0000@ooooo`;o00002_ooool2o`0001So
oooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0000fooooo`;o00005oooool2o`0002;ooooo
0ol00011ooooo`;o0000E?ooool2o`0002Cooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0
001?ooooo`;o00008_ooool3o`00047ooooo0_l0001Zooooo`;o00003_ooool001kooooo00?o0000
ooooooooool0Koooool2o`000<Kooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`1Toooo
o`;o00002Oooool2o`0002gooooo0_l0000Uooooo`;o0000C_ooool2o`0001;ooooo0_l0000Loooo
o`007_ooool00ol0003oooooooooo`1Tooooo`;o00003?ooool2o`0002[ooooo0_l0000Uooooo`;o
0000C_ooool2o`0001;ooooo0_l0000Looooo`007_ooool00ol0003oooooooooo`1booooo`;o0000
I?ooool2o`0002cooooo0_l00002ooooo`;o00002?ooool2o`00037ooooo000Nooooo`03o`000?oo
oooooooo0;Cooooo0_l0000Oooooo`;o000000?oooooo`000?l00000;?ooool2o`0000;ooooo0_l0
0005ooooo`;o000000?oooooo`000?l000008Oooool2o`0000kooooo000Nooooo`03o`000?oooooo
oooo0;Cooooo0_l0000Oooooo`;o0000>_ooool2o`0002Cooooo0_l0000>ooooo`007_ooool00ol0
003oooooooooo`3Yooooo`;o0000;?ooool2o`0002kooooo000Nooooo`03o`000?oooooooooo0>Wo
oooo0_l00006ooooo`;o00009?ooool2o`0002kooooo000Nooooo`03o`000?oooooooooo05?ooooo
0_l0001eooooo`;o00009Oooool2o`0000Cooooo0_l0000Sooooo`;o00003Oooool2o`0001[ooooo
000Nooooo`03o`000?oooooooooo00gooooo0_l0000/ooooo`;o000000?oooooo`000?l000003?oo
ool2o`0000Gooooo0_l0000Sooooo`;o00001_ooool2o`0004Sooooo0_l0000[ooooo`;o00008ooo
ool2o`0000;ooooo0_l00009ooooo`;o00006_ooool001kooooo0_l0000>ooooo`;o0000;?ooool2
o`000003ooooool0003o000000Oooooo0_l00003ooooo`;o00000oooool2o`0002Gooooo0_l00006
ooooo`;o0000O?ooool2o`00023ooooo0_l00003ooooo`;o00001?ooool2o`0001[ooooo000Noooo
o`03o`000?oooooooooo04Oooooo0_l00008ooooo`;o0000C?ooool2o`0000?ooooo0_l0000boooo
o`;o00009?ooool2o`00013ooooo0_l0000Cooooo`;o00008?ooool001kooooo00?o0000oooooooo
ool0:_ooool2o`0002Cooooo0_l0001=ooooo`;o00000oooool2o`0003;ooooo0_l0000fooooo`;o
0000=Oooool001kooooo00?o0000ooooooooool0:_ooool2o`0002Cooooo0_l00018ooooo`;o0000
?oooool2o`0002Gooooo0_l00006ooooo`;o00003_ooool4o`0002Wooooo000Nooooo`03o`000?oo
oooooooo00oooooo0_l00029ooooo`;o00004oooool2o`0000;ooooo0_l0000Vooooo`Co00008ooo
ool2o`0000Kooooo0_l0000>ooooo`Co0000:Oooool001kooooo00?o0000ooooooooool03oooool2
o`0009kooooo0_l00002ooooo`;o00005oooool2o`0000oooooo0_l0001<ooooo`;o00006_ooool0
01kooooo00?o0000ooooooooool0C_ooool2o`0000kooooo0_l0001/ooooo`;o0000?Oooool2o`00
00Gooooo0_l0000Gooooo`;o00003_ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo01[o
oooo0_l0000booooo`;o00003_ooool2o`0005Cooooo0_l00009ooooo`;o0000B_ooool2o`0000Go
oooo0_l0000Wooooo`;o00002_ooool001kooooo00?o0000ooooooooool02Oooool2o`0000oooooo
0_l0002Hooooo`;o00002Oooool2o`0000Cooooo0_l00018ooooo`;o00008oooool2o`00017ooooo
000Nooooo`03o`000?oooooooooo00Wooooo0_l0001=ooooo`;o00003oooool2o`0005[ooooo0_l0
000iooooo`;o00003Oooool2o`0002?ooooo0_l0000Aooooo`007_ooool00ol0003oooooooooo`09
ooooo`;o0000COooool2o`0000oooooo0_l0001Booooo`;o0000@Oooool2o`0004Gooooo000Noooo
o`03o`000?oooooooooo00Wooooo0_l0001Oooooo`;o0000;_ooool2o`00027ooooo0_l0000Woooo
o`;o0000?Oooool2o`00023ooooo000Nooooo`03o`000?oooooooooo06[ooooo0_l0000^ooooo`;o
00009oooool2o`00027ooooo0_l00008ooooo`;o00007Oooool2o`0001Cooooo0_l0000=ooooo`;o
00004Oooool001kooooo00?o0000ooooooooool06Oooool2o`000:Sooooo0_l0000Qooooo`;o0000
2?ooool2o`0001gooooo0_l0000Kooooo`;o000000?oooooo`000?l000000oooool2o`00017ooooo
000Dooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`0Iooooo`;o0000U_oo
ool2o`0003?ooooo0_l0000cooooo`;o00003oooool2o`000003ooooool0003o000001Kooooo000F
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/Oooool2o`0006Sooooo0_l0000Z
ooooo`005_ooool00ol0003oooooooooo`05ooooo`?o0000_?ooool2o`0008Wooooo000Fooooo`03
o`000?oooooooooo0<Cooooo0_l00029ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo
000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@
ooooo`005?ooool00omEEEGoIVIVo`00003ooooooe;ooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.74204 .58405 Mdot
.08157 .33806 Mdot
.68725 .42098 Mdot
.05209 .38239 Mdot
.42851 .41122 Mdot
.46249 .28851 Mdot
.75534 .14564 Mdot
.02976 .06965 Mdot
.89871 .50722 Mdot
.8492 .94414 Mdot
.4388 .582 Mdot
.86893 .93681 Mdot
.49358 .76662 Mdot
.05242 .36656 Mdot
.00025 .57884 Mdot
.20446 .17998 Mdot
.79359 .01509 Mdot
.50728 .06881 Mdot
.93677 .06529 Mdot
.61438 .83833 Mdot
.14894 .32946 Mdot
.53463 .15269 Mdot
.93456 .89351 Mdot
.81858 .41982 Mdot
.29623 .89176 Mdot
.90727 .89656 Mdot
.99678 .13171 Mdot
.9538 .49048 Mdot
.41717 .3008 Mdot
.22233 .26509 Mdot
.34691 .14281 Mdot
.79014 .26604 Mdot
.92145 .95252 Mdot
.06275 .27316 Mdot
.21501 .24297 Mdot
.08724 .05073 Mdot
.13682 .24978 Mdot
.30414 .34415 Mdot
.8552 .27024 Mdot
.52496 .65156 Mdot
.65626 .72191 Mdot
.0595 .2457 Mdot
.53367 .46573 Mdot
.47998 .72168 Mdot
.75324 .64198 Mdot
.1751 .71044 Mdot
.36631 .57599 Mdot
.93606 .78608 Mdot
.51077 .20714 Mdot
.77491 .24196 Mdot
.78732 .12071 Mdot
.43669 .80629 Mdot
.96732 .58662 Mdot
.22056 .36967 Mdot
.65038 .94006 Mdot
.93994 .44598 Mdot
.19138 .07676 Mdot
.54383 .9629 Mdot
.57788 .24794 Mdot
.44028 .33743 Mdot
.86549 .89817 Mdot
.80569 .9486 Mdot
.23958 .53683 Mdot
.49899 .34775 Mdot
.08665 .19289 Mdot
.10073 .82342 Mdot
.56061 .39416 Mdot
.39532 .15546 Mdot
.63876 .20197 Mdot
.03078 .37997 Mdot
.27839 .10108 Mdot
.82287 .22902 Mdot
.08495 .10221 Mdot
.2033 .17675 Mdot
.12982 .35765 Mdot
.86618 .99542 Mdot
.8155 .31546 Mdot
.55067 .36013 Mdot
.09017 .73343 Mdot
.93191 .97049 Mdot
.26902 .7244 Mdot
.10926 .44618 Mdot
.25645 .44083 Mdot
.4802 .32522 Mdot
.93019 .55739 Mdot
.47406 .06491 Mdot
.99528 .99701 Mdot
.77388 .23636 Mdot
.33638 .48226 Mdot
.06296 .04226 Mdot
.46523 .51908 Mdot
.31469 .26138 Mdot
.96445 .09618 Mdot
.05177 .64198 Mdot
.93467 .4358 Mdot
.79323 .10277 Mdot
.81404 .09064 Mdot
.5278 .82859 Mdot
.64579 .28958 Mdot
.83956 .76818 Mdot
.06641 .9522 Mdot
.64188 .89516 Mdot
.80048 .19794 Mdot
.51061 .826 Mdot
.66253 .03556 Mdot
.26753 .97661 Mdot
.91804 .41667 Mdot
.308 .09664 Mdot
.26939 .1411 Mdot
.98881 .07738 Mdot
.40213 .64887 Mdot
.95851 .09522 Mdot
.52506 .91018 Mdot
.52132 .37994 Mdot
.5817 .87362 Mdot
.23384 .81911 Mdot
.72922 .61405 Mdot
.73793 .62587 Mdot
.6027 .05639 Mdot
.19614 .78967 Mdot
.58354 .65357 Mdot
.46027 .87004 Mdot
.93977 .74378 Mdot
.31686 .55759 Mdot
.60672 .0413 Mdot
.9992 .99748 Mdot
.91985 .45945 Mdot
.60913 .34199 Mdot
.39851 .64988 Mdot
.02365 .52393 Mdot
.53676 .44298 Mdot
.67291 .00036 Mdot
.87494 .56564 Mdot
.38527 .32996 Mdot
.12593 .59035 Mdot
.93893 .53517 Mdot
.2767 .662 Mdot
.07174 .78693 Mdot
.17259 .40072 Mdot
.3429 .20839 Mdot
.97224 .93991 Mdot
.48886 .86935 Mdot
.63035 .36773 Mdot
.67659 .66774 Mdot
.55131 .61798 Mdot
.45804 .53881 Mdot
.66047 .8534 Mdot
.29619 .85922 Mdot
.59112 .99292 Mdot
.40035 .24584 Mdot
.16807 .71982 Mdot
.86685 .8979 Mdot
.04067 .52929 Mdot
.60336 .15553 Mdot
.59625 .31915 Mdot
.71768 .30315 Mdot
.78089 .95686 Mdot
.52676 .50558 Mdot
.92382 .94302 Mdot
.9542 .85627 Mdot
.53464 .14285 Mdot
.71322 .39819 Mdot
.12737 .71655 Mdot
.7474 .73772 Mdot
.93038 .94683 Mdot
.34334 .37225 Mdot
.56327 .38092 Mdot
.42939 .28624 Mdot
.55995 .62423 Mdot
.79701 .59704 Mdot
.79159 .43283 Mdot
.61375 .57074 Mdot
.48792 .50127 Mdot
.02186 .35481 Mdot
.48942 .98995 Mdot
.45728 .44906 Mdot
.35664 .84067 Mdot
.30144 .28941 Mdot
.92883 .68738 Mdot
.0697 .19122 Mdot
.21637 .80869 Mdot
.98634 .39775 Mdot
.20792 .51341 Mdot
.2072 .99987 Mdot
.94453 .78537 Mdot
.03036 .47612 Mdot
.6456 .05138 Mdot
.71476 .19074 Mdot
.08561 .98585 Mdot
.59106 .75451 Mdot
.34326 .44794 Mdot
.73692 .73986 Mdot
.32975 .43881 Mdot
.80729 .19215 Mdot
.88636 .1797 Mdot
.43239 .34782 Mdot
.83414 .1578 Mdot
.20305 .65846 Mdot
.36543 .305 Mdot
.33193 .61952 Mdot
.98081 .13802 Mdot
.97522 .69834 Mdot
.85124 .53637 Mdot
.04671 .7416 Mdot
.3149 .22438 Mdot
.47441 .41115 Mdot
.62798 .87343 Mdot
.86619 .2207 Mdot
.67592 .93245 Mdot
.78814 .30867 Mdot
.54425 .80023 Mdot
.24621 .48467 Mdot
.29228 .41521 Mdot
.04306 .53153 Mdot
.69926 .72627 Mdot
.16745 .55699 Mdot
.15858 .67871 Mdot
.49998 .03047 Mdot
.71521 .62972 Mdot
.91829 .98728 Mdot
.93042 .88207 Mdot
.34303 .84282 Mdot
.55386 .30527 Mdot
.93968 .16542 Mdot
.08419 .68097 Mdot
.09934 .82468 Mdot
.19966 .12403 Mdot
.72806 .05352 Mdot
.81787 .17834 Mdot
.36818 .18728 Mdot
.25856 .36538 Mdot
.19766 .08693 Mdot
.08303 .32236 Mdot
.10539 .40955 Mdot
.7374 .81597 Mdot
.0205 .09724 Mdot
.84848 .96177 Mdot
.10359 .47059 Mdot
.45842 .07122 Mdot
.22103 .18727 Mdot
.85752 .00887 Mdot
.10323 .17785 Mdot
.79388 .44889 Mdot
.68301 .91123 Mdot
.47693 .25265 Mdot
.73433 .26924 Mdot
.89635 .24543 Mdot
.55411 .02799 Mdot
.92736 .11535 Mdot
.3095 .7437 Mdot
.18418 .86693 Mdot
.80292 .7156 Mdot
.55758 .02177 Mdot
.58819 .36407 Mdot
.57403 .43149 Mdot
.70703 .61585 Mdot
.9304 .00325 Mdot
.11455 .4876 Mdot
.09801 .97881 Mdot
.71325 .35933 Mdot
.08757 .64023 Mdot
.31224 .805 Mdot
.73163 .00802 Mdot
.6989 .30144 Mdot
.36296 .74601 Mdot
.99295 .77875 Mdot
.57515 .45789 Mdot
.49668 .94582 Mdot
.51122 .32565 Mdot
.09798 .21282 Mdot
.07433 .54634 Mdot
.59133 .01904 Mdot
.21609 .70564 Mdot
.98988 .01388 Mdot
.35382 .51292 Mdot
.52732 .98869 Mdot
.18401 .54875 Mdot
.37602 .34805 Mdot
.42121 .2037 Mdot
.72054 .69913 Mdot
.1904 .76158 Mdot
.77695 .27497 Mdot
.86999 .34205 Mdot
.01072 .06457 Mdot
.923 .89136 Mdot
.83657 .81387 Mdot
.43862 .15932 Mdot
.49809 .04114 Mdot
.52512 .44366 Mdot
.32784 .45197 Mdot
.26462 .01186 Mdot
.46297 .01469 Mdot
.28348 .49702 Mdot
.74795 .93601 Mdot
.17066 .87657 Mdot
.58954 .61394 Mdot
.41587 .25999 Mdot
.99397 .62185 Mdot
.26878 .24587 Mdot
.33467 .77117 Mdot
.6114 .98141 Mdot
.2603 .1095 Mdot
.57057 .76148 Mdot
.62705 .87176 Mdot
.43572 .05568 Mdot
.96945 .1885 Mdot
.98435 .90178 Mdot
.17953 .75495 Mdot
.35025 .88739 Mdot
.45648 .94045 Mdot
.33575 .46045 Mdot
.32668 .38154 Mdot
.55738 .72005 Mdot
.28028 .53781 Mdot
.33182 .76867 Mdot
.46225 .43172 Mdot
.71268 .91807 Mdot
.33415 .0352 Mdot
.81007 .82894 Mdot
.90302 .43731 Mdot
.30633 .09604 Mdot
.65852 .34738 Mdot
.7672 .37699 Mdot
.15533 .14276 Mdot
.94628 .92791 Mdot
.07511 .43334 Mdot
.8086 .94819 Mdot
.77955 .17608 Mdot
.97785 .17016 Mdot
.61661 .94694 Mdot
.37344 .23734 Mdot
.56332 .71358 Mdot
.89052 .30606 Mdot
.06422 .15851 Mdot
.35387 .08661 Mdot
.73858 .23721 Mdot
.08959 .37743 Mdot
.43449 .61406 Mdot
.49554 .29725 Mdot
.87025 .67958 Mdot
.26211 .25356 Mdot
.40648 .5283 Mdot
.14846 .82103 Mdot
.7401 .65882 Mdot
.01458 .36238 Mdot
.79963 .7104 Mdot
.95463 .41563 Mdot
.94272 .24585 Mdot
.65076 .22514 Mdot
.65104 .43796 Mdot
.38908 .83691 Mdot
.59009 .03099 Mdot
.85042 .40823 Mdot
.32181 .68511 Mdot
.4794 .71577 Mdot
.41225 .81775 Mdot
.60417 .15837 Mdot
.81393 .91263 Mdot
.82677 .55493 Mdot
.7889 .85601 Mdot
.98041 .46285 Mdot
.23078 .22171 Mdot
.86364 .52649 Mdot
.46798 .3482 Mdot
.784 .91078 Mdot
.33723 .93052 Mdot
.02226 .43198 Mdot
.66339 .22699 Mdot
.66285 .37661 Mdot
.67549 .10958 Mdot
.07287 .60552 Mdot
.77026 .09106 Mdot
.85589 .27243 Mdot
.65077 .71818 Mdot
.20029 .59442 Mdot
.02445 .50692 Mdot
.55565 .47007 Mdot
.89867 .48415 Mdot
.27198 .88567 Mdot
.04276 .3418 Mdot
.73109 .71366 Mdot
.57673 .42329 Mdot
.86928 .88672 Mdot
.64051 .08444 Mdot
.84729 .35066 Mdot
.12867 .2107 Mdot
.85484 .90197 Mdot
.31328 .5196 Mdot
.11763 .20616 Mdot
.22546 .25138 Mdot
.99494 .10403 Mdot
.42595 .67656 Mdot
.42495 .55615 Mdot
.65983 .40314 Mdot
.28789 .94979 Mdot
.2529 .47815 Mdot
.67862 .40978 Mdot
.88196 .07526 Mdot
.97785 .76816 Mdot
.80087 .36603 Mdot
.70745 .33389 Mdot
.22913 .3396 Mdot
.5187 .08128 Mdot
.06878 .83168 Mdot
.24506 .27986 Mdot
.60333 .21024 Mdot
.81396 .52894 Mdot
.21872 .95348 Mdot
.29451 .86764 Mdot
.16034 .62293 Mdot
.51307 .3216 Mdot
.59427 .13042 Mdot
.98351 .16983 Mdot
.09505 .60982 Mdot
.32007 .2593 Mdot
.86788 .992 Mdot
.80439 .84681 Mdot
.37802 .6024 Mdot
.89283 .49867 Mdot
.01128 .87913 Mdot
.72369 .38492 Mdot
.65531 .01622 Mdot
.06861 .8622 Mdot
.17368 .11876 Mdot
.21787 .95263 Mdot
.2646 .33795 Mdot
.24919 .85393 Mdot
.18288 .22367 Mdot
.18728 .76386 Mdot
.59355 .44096 Mdot
.15452 .50636 Mdot
.36134 .76518 Mdot
.6293 .93222 Mdot
.61473 .52377 Mdot
.30144 .24303 Mdot
.57561 .6471 Mdot
.27288 .1353 Mdot
.51529 .50812 Mdot
.85133 .48733 Mdot
.14141 .10513 Mdot
.3886 .47813 Mdot
.37851 .46516 Mdot
.05782 .72246 Mdot
.20742 .94693 Mdot
.64806 .55227 Mdot
.40641 .21701 Mdot
.1117 .53052 Mdot
.60727 .75402 Mdot
.10915 .62509 Mdot
.18746 .44476 Mdot
.0107 .32538 Mdot
.84332 .59585 Mdot
.47987 .65138 Mdot
.58074 .92721 Mdot
.207 .1193 Mdot
.62459 .1259 Mdot
.7548 .26668 Mdot
.45198 .76804 Mdot
.82397 .54071 Mdot
.63782 .8341 Mdot
.53679 .2035 Mdot
.18735 .16637 Mdot
.62975 .05543 Mdot
.18542 .77608 Mdot
.99288 .18481 Mdot
.78858 .0625 Mdot
.62196 .2291 Mdot
.38706 .07563 Mdot
.04236 .09798 Mdot
.07339 .14322 Mdot
.43478 .29879 Mdot
.61675 .4834 Mdot
.71516 .99502 Mdot
.17506 .18372 Mdot
.20639 .16718 Mdot
.82367 .64271 Mdot
.98641 .8111 Mdot
.22891 .78807 Mdot
.18236 .76895 Mdot
.69836 .917 Mdot
.36133 .8452 Mdot
.68974 .55263 Mdot
.77087 .3382 Mdot
.30851 .8673 Mdot
.23895 .17117 Mdot
.9391 .47735 Mdot
.81938 .17484 Mdot
.98618 .0672 Mdot
.6379 .17239 Mdot
.97506 .44408 Mdot
.2203 .5665 Mdot
.47776 .38069 Mdot
.05289 .03142 Mdot
.58083 .03755 Mdot
.19931 .45635 Mdot
.53006 .94241 Mdot
.13191 .13326 Mdot
.76747 .28048 Mdot
.57158 .07666 Mdot
.64745 .40692 Mdot
.75535 .78775 Mdot
.51471 .17079 Mdot
.36226 .93772 Mdot
.21892 .59143 Mdot
.08492 .18836 Mdot
.44989 .43852 Mdot
.10093 .52908 Mdot
.73144 .69267 Mdot
.68177 .19804 Mdot
.08355 .18011 Mdot
.95955 .89743 Mdot
.61859 .57375 Mdot
.41355 .32995 Mdot
.95638 .56718 Mdot
.86211 .21326 Mdot
.92649 .14379 Mdot
.55549 .25223 Mdot
.74616 .53113 Mdot
.72672 .86813 Mdot
.83153 .09235 Mdot
.16643 .83574 Mdot
.62036 .05728 Mdot
.07437 .72975 Mdot
.1564 .28224 Mdot
.84925 .23647 Mdot
.03875 .55709 Mdot
.86422 .76095 Mdot
.32754 .20277 Mdot
.05612 .74171 Mdot
.73082 .8282 Mdot
.18531 .73763 Mdot
.70469 .52374 Mdot
.20893 .07315 Mdot
.87815 .58795 Mdot
.94458 .15264 Mdot
.83996 .47133 Mdot
.8641 .75006 Mdot
.61957 .10325 Mdot
.19703 .19391 Mdot
.56432 .82003 Mdot
.83967 .64458 Mdot
.90364 .19098 Mdot
.53983 .68899 Mdot
.09593 .46568 Mdot
.53525 .88898 Mdot
.40159 .69359 Mdot
.69677 .53146 Mdot
.36529 .00928 Mdot
.74372 .58324 Mdot
.96674 .0421 Mdot
.72394 .57291 Mdot
.22664 .40004 Mdot
.0146 .19594 Mdot
.47076 .44165 Mdot
.2877 .28976 Mdot
.25474 .15526 Mdot
.95577 .57795 Mdot
.005 .31321 Mdot
.41943 .90033 Mdot
.45448 .11378 Mdot
.56811 .103 Mdot
.64978 .23235 Mdot
.01341 .29343 Mdot
.15842 .04902 Mdot
.83577 .92968 Mdot
.84248 .82588 Mdot
.66328 .49064 Mdot
.78309 .87333 Mdot
.52068 .11129 Mdot
.02636 .38253 Mdot
.23241 .40168 Mdot
.40937 .12362 Mdot
.97451 .12873 Mdot
.91146 .61545 Mdot
.17869 .97835 Mdot
.61164 .74587 Mdot
.21692 .87899 Mdot
.84042 .16284 Mdot
.26201 .2168 Mdot
.28912 .44933 Mdot
.90889 .27865 Mdot
.10363 .23818 Mdot
.45753 .05579 Mdot
.77827 .97286 Mdot
.61895 .83009 Mdot
.74701 .15486 Mdot
.70121 .96308 Mdot
.92225 .58796 Mdot
.70359 .9303 Mdot
.16251 .25018 Mdot
.31194 .93669 Mdot
.07221 .9524 Mdot
.52439 .46687 Mdot
.83632 .89044 Mdot
.91 .50874 Mdot
.2504 .79923 Mdot
.47475 .92607 Mdot
.39217 .44981 Mdot
.96638 .74958 Mdot
.23229 .0652 Mdot
.0209 .98354 Mdot
.27682 .01611 Mdot
.92137 .29839 Mdot
.96541 .27431 Mdot
.63053 .62993 Mdot
.37149 .52904 Mdot
.41356 .864 Mdot
.32268 .53735 Mdot
.07439 .13046 Mdot
.77179 .94396 Mdot
.45037 .14232 Mdot
.703 .01879 Mdot
.15203 .26397 Mdot
.62197 .80086 Mdot
.4429 .17016 Mdot
.47567 .76054 Mdot
.69803 .75423 Mdot
.33353 .37862 Mdot
.01518 .74027 Mdot
.86683 .64212 Mdot
.75179 .38138 Mdot
.27775 .50619 Mdot
.52334 .10581 Mdot
.40703 .61571 Mdot
.07792 .01125 Mdot
.94427 .56144 Mdot
.87845 .98331 Mdot
.28383 .62732 Mdot
.39511 .38827 Mdot
.16541 .36033 Mdot
.08972 .48544 Mdot
.10268 .47274 Mdot
.15825 .31879 Mdot
.99794 .79974 Mdot
.86274 .0142 Mdot
.8499 .3567 Mdot
.90287 .81377 Mdot
.70049 .58797 Mdot
.79862 .07976 Mdot
.14566 .81745 Mdot
.63823 .8247 Mdot
.23092 .55038 Mdot
.30047 .54067 Mdot
.80737 .85688 Mdot
.9687 .03231 Mdot
.67258 .81785 Mdot
.3395 .18864 Mdot
.99262 .59744 Mdot
.56726 .1607 Mdot
.13298 .79357 Mdot
.59903 .86409 Mdot
.17423 .22417 Mdot
.13823 .79942 Mdot
.77398 .93364 Mdot
.595 .47209 Mdot
.07248 .80613 Mdot
.48536 .30209 Mdot
.61455 .21864 Mdot
.31972 .29638 Mdot
.49859 .47959 Mdot
.82196 .99069 Mdot
.06799 .44894 Mdot
.08483 .91298 Mdot
.1459 .36218 Mdot
.15885 .86287 Mdot
.15919 .34153 Mdot
.78503 .18533 Mdot
.3105 .62508 Mdot
.20031 .07251 Mdot
.44159 .23575 Mdot
.08019 .5356 Mdot
.24193 .5323 Mdot
.44353 .83423 Mdot
.92722 .27245 Mdot
.0754 .70661 Mdot
.96494 .63572 Mdot
.73549 .69583 Mdot
.61021 .20977 Mdot
.11538 .74802 Mdot
.52187 .70638 Mdot
.68515 .85437 Mdot
.81624 .41981 Mdot
.41645 .1074 Mdot
.82043 .66214 Mdot
.21569 .10966 Mdot
.68742 .56364 Mdot
.9407 .57365 Mdot
.93911 .09966 Mdot
.39215 .7001 Mdot
.10235 .7505 Mdot
.12889 .09795 Mdot
.82158 .82351 Mdot
.63912 .39261 Mdot
.85015 .2482 Mdot
.43164 .493 Mdot
.16048 .37166 Mdot
.04916 .20979 Mdot
.69024 .59232 Mdot
.31063 .43365 Mdot
.89862 .67579 Mdot
.72252 .00192 Mdot
.6578 .17139 Mdot
.38423 .65643 Mdot
.89763 .54519 Mdot
.94886 .44505 Mdot
.9381 .09661 Mdot
.72313 .14485 Mdot
.50513 .51011 Mdot
.51039 .1323 Mdot
.02661 .06082 Mdot
.40141 .45828 Mdot
.31867 .21826 Mdot
.5008 .71803 Mdot
.56814 .89024 Mdot
.92565 .8233 Mdot
.38051 .53414 Mdot
.18827 .23665 Mdot
.61735 .25713 Mdot
.21023 .25534 Mdot
.93206 .58739 Mdot
.89862 .97929 Mdot
.7172 .67187 Mdot
.71416 .29566 Mdot
.58351 .62939 Mdot
.42317 .81313 Mdot
.23972 .00911 Mdot
.60065 .75898 Mdot
.60098 .32064 Mdot
.61576 .80187 Mdot
.15735 .25791 Mdot
.293 .3828 Mdot
.04884 .49308 Mdot
.06483 .64512 Mdot
.5302 .67563 Mdot
.19772 .09859 Mdot
.8401 .79341 Mdot
.05598 .15696 Mdot
.7954 .91287 Mdot
.63972 .5557 Mdot
.41688 .4573 Mdot
.22486 .92809 Mdot
.44448 .39204 Mdot
.78897 .3619 Mdot
.13157 .06303 Mdot
.85199 .95819 Mdot
.74268 .29137 Mdot
.41538 .62413 Mdot
.80412 .69806 Mdot
.49081 .33299 Mdot
.20767 .9406 Mdot
.7047 .95071 Mdot
.59719 .66176 Mdot
.74092 .22698 Mdot
.41574 .05064 Mdot
.75137 .04068 Mdot
.42398 .1675 Mdot
.01936 .21395 Mdot
.43983 .05203 Mdot
.42326 .37886 Mdot
.44316 .23076 Mdot
.08889 .8449 Mdot
.52422 .45468 Mdot
.22744 .09705 Mdot
.75861 .04594 Mdot
.34043 .72869 Mdot
.56326 .83435 Mdot
.82625 .89647 Mdot
.3459 .46727 Mdot
.60901 .50348 Mdot
.73824 .60457 Mdot
.38243 .31575 Mdot
.9977 .175 Mdot
.08036 .18979 Mdot
.25652 .8596 Mdot
.07623 .33976 Mdot
.75449 .62782 Mdot
.47853 .38737 Mdot
.9851 .06921 Mdot
.4259 .75932 Mdot
.87261 .75621 Mdot
.02485 .08938 Mdot
.98115 .33107 Mdot
.38473 .01672 Mdot
.8818 .98364 Mdot
.54177 .91266 Mdot
.36169 .26609 Mdot
.64021 .81634 Mdot
.84437 .43488 Mdot
.38055 .13986 Mdot
.00109 .29363 Mdot
.68608 .26436 Mdot
.91503 .74894 Mdot
.94311 .37164 Mdot
.04017 .58096 Mdot
.32128 .24812 Mdot
.99929 .50834 Mdot
.98202 .52322 Mdot
.46903 .33263 Mdot
.07628 .92438 Mdot
.83583 .66934 Mdot
.93114 .5149 Mdot
.66145 .23289 Mdot
.39156 .07747 Mdot
.94769 .68484 Mdot
.65419 .90496 Mdot
.70493 .90593 Mdot
.55379 .8222 Mdot
.4329 .21474 Mdot
.74423 .11952 Mdot
.20991 .01288 Mdot
.50921 .37122 Mdot
.55784 .10714 Mdot
.34729 .65243 Mdot
.64774 .76637 Mdot
.22673 .75808 Mdot
.97321 .24173 Mdot
.29909 .72447 Mdot
.05462 .20984 Mdot
.98072 .04922 Mdot
.49051 .77 Mdot
.41993 .78006 Mdot
.51902 .97696 Mdot
.79912 .19411 Mdot
.14771 .00857 Mdot
.50627 .34209 Mdot
.55516 .46799 Mdot
.15827 .71475 Mdot
.44623 .98267 Mdot
.99722 .2774 Mdot
.5437 .97976 Mdot
.82626 .35497 Mdot
.88438 .01039 Mdot
.62324 .80563 Mdot
.59014 .88893 Mdot
.66859 .41082 Mdot
.24225 .05176 Mdot
.29569 .95645 Mdot
.88159 .86325 Mdot
.9764 .96179 Mdot
.18715 .68361 Mdot
.08429 .88395 Mdot
.85233 .83981 Mdot
.14394 .33883 Mdot
.81636 .67094 Mdot
.71461 .65689 Mdot
.42237 .64471 Mdot
.88161 .41607 Mdot
.9041 .76757 Mdot
.42813 .36107 Mdot
.92284 .08899 Mdot
.26696 .54837 Mdot
.48291 .29037 Mdot
.90329 .87521 Mdot
.76126 .58146 Mdot
.58632 .31735 Mdot
.80618 .0556 Mdot
.0489 .42446 Mdot
.21245 .22391 Mdot
.36067 .2199 Mdot
.48679 .34597 Mdot
.82486 .69699 Mdot
.40101 .39377 Mdot
.74536 .91353 Mdot
.72176 .98169 Mdot
.68104 .21975 Mdot
.1206 .21156 Mdot
.89325 .01524 Mdot
.03975 .30167 Mdot
.01806 .43892 Mdot
.67243 .8265 Mdot
.85132 .40473 Mdot
.41552 .32278 Mdot
.81211 .94378 Mdot
.77852 .11105 Mdot
.30789 .76801 Mdot
.28138 .2597 Mdot
.52209 .80806 Mdot
.42551 .92531 Mdot
.40037 .90813 Mdot
.11015 .83393 Mdot
.54579 .30458 Mdot
.62504 .75749 Mdot
.87241 .71821 Mdot
.05558 .28999 Mdot
.84039 .97029 Mdot
.08645 .41933 Mdot
.7512 .01083 Mdot
.08745 .29324 Mdot
.47977 .02458 Mdot
.48827 .24387 Mdot
.87481 .34352 Mdot
.52841 .65324 Mdot
.53542 .17708 Mdot
.74146 .62293 Mdot
.41093 .30515 Mdot
.7592 .1811 Mdot
.80063 .46466 Mdot
.57934 .96926 Mdot
.85567 .57613 Mdot
.6335 .85723 Mdot
.20923 .36732 Mdot
.94127 .46699 Mdot
.54621 .8952 Mdot
.60547 .01138 Mdot
.86081 .90197 Mdot
.70335 .55805 Mdot
.18368 .43291 Mdot
.96197 .20786 Mdot
.56199 .84027 Mdot
.29576 .40433 Mdot
.89985 .02769 Mdot
.87977 .35666 Mdot
.48999 .83606 Mdot
.76777 .77906 Mdot
.09734 .81105 Mdot
.38675 .58411 Mdot
.08525 .04201 Mdot
.54771 .26469 Mdot
.76343 .8188 Mdot
.66782 .84819 Mdot
.97915 .86596 Mdot
.13866 .63941 Mdot
.24417 .57195 Mdot
.09851 .44967 Mdot
.52989 .01971 Mdot
.52433 .4531 Mdot
.12027 .42518 Mdot
.94898 .71602 Mdot
.90341 .16105 Mdot
.59367 .67595 Mdot
.31053 .49304 Mdot
.79475 .60368 Mdot
.2172 .89044 Mdot
.79303 .73047 Mdot
.18335 .05234 Mdot
.61122 .44318 Mdot
.39613 .8309 Mdot
.223 .73506 Mdot
.40805 .59115 Mdot
.06589 .27319 Mdot
.37902 .32339 Mdot
.66299 .79404 Mdot
.26291 .94858 Mdot
.71028 .06028 Mdot
.2514 .88088 Mdot
.06207 .48602 Mdot
.30555 .07201 Mdot
.31365 .25745 Mdot
.65271 .04996 Mdot
.33082 .32823 Mdot
.45106 .21752 Mdot
.92189 .24201 Mdot
.95194 .68973 Mdot
.16683 .55492 Mdot
.89937 .95507 Mdot
.61651 .36702 Mdot
.83691 .83629 Mdot
.36588 .01186 Mdot
.7645 .91286 Mdot
.32036 .56144 Mdot
.25954 .69789 Mdot
.22839 .45839 Mdot
.96856 .36438 Mdot
.95653 .02247 Mdot
.7743 .87619 Mdot
.62744 .27953 Mdot
.73989 .70823 Mdot
.13949 .64752 Mdot
.68896 .09301 Mdot
.59381 .89196 Mdot
.12682 .99374 Mdot
.5013 .12188 Mdot
.10225 .45956 Mdot
.46038 .87339 Mdot
.94852 .92923 Mdot
.25549 .99626 Mdot
.24311 .86168 Mdot
.43211 .51923 Mdot
.73088 .3274 Mdot
.50621 .95963 Mdot
.8621 .39583 Mdot
.73736 .00048 Mdot
.52255 .21876 Mdot
.49302 .65951 Mdot
.64137 .93611 Mdot
.90313 .03454 Mdot
.52804 .82834 Mdot
.76448 .23501 Mdot
.43248 .75279 Mdot
.10242 .52023 Mdot
.87325 .59264 Mdot
.82657 .74524 Mdot
.25457 .35355 Mdot
.26653 .53308 Mdot
.55181 .35506 Mdot
.9283 .69435 Mdot
.74802 .58313 Mdot
.79967 .95077 Mdot
.02346 .4982 Mdot
.89217 .89479 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool01?ooool2o`0000?o
oooo0_l00002ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00Kooooo0_l00005ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool00_ooool001kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Kooooo
0_l00005ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0;?ooool2o`0001cooooo0_l0000Wooooo`;o0000MOooool2o`0002Oooooo0_l0
0006ooooo`;o0000:_ooool001kooooo00?o0000ooooooooool05Oooool2o`0001Gooooo0_l0000B
ooooo`;o00002?ooool2o`0000Kooooo0_l0000Oooooo`;o0000C?ooool2o`0002Oooooo0_l00004
ooooo`;o00008Oooool2o`0000Kooooo0_l0000Zooooo`007_ooool00ol0003oooooooooo`0Eoooo
o`;o0000:Oooool2o`00013ooooo0_l00002ooooo`;o00006oooool2o`0000Cooooo0_l0000Goooo
o`;o0000;Oooool2o`0000kooooo0_l0000Mooooo`;o00003?ooool2o`0001Cooooo0_l00008oooo
o`;o00007_ooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo05Kooooo0_l0000Qooooo`;o
00005oooool2o`0001Cooooo0_l0000Booooo`;o00004oooool2o`0000gooooo0_l0000Looooo`;o
00005?ooool2o`0000Sooooo0_l0000Nooooo`;o00001oooool001kooooo00?o0000ooooooooool0
Z?ooool2o`0000Oooooo0_l00009ooooo`;o00008_ooool2o`00057ooooo0_l0000Booooo`007_oo
ool00ol0003oooooooooo`2Hooooo`;o00005oooool2o`00083ooooo0_l0000Booooo`007_ooool0
0ol0003oooooooooo`2Hooooo`;o00005_ooool2o`0006kooooo0_l0000Uooooo`007_ooool00ol0
003oooooooooo`0=ooooo`;o0000Soooool2o`00013ooooo0_l0000:ooooo`;o0000H_ooool2o`00
02Gooooo000Nooooo`03o`000?oooooooooo00gooooo0_l0001Jooooo`;o0000<oooool2o`0001co
oooo0_l0001Tooooo`;o00004oooool2o`0000kooooo000Nooooo`03o`000?oooooooooo06Wooooo
0_l0001>ooooo`;o00006?ooool2o`0004gooooo0_l0000Cooooo`;o00003_ooool001kooooo00?o
0000ooooooooool0W_ooool2o`0001Wooooo0_l00006ooooo`;o00004?ooool2o`0001_ooooo0_l0
001Eooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o00001_ooool2o`0008Cooooo0_l0000Q
ooooo`;o0000;Oooool2o`0004Cooooo0_l0000?ooooo`007_ooool00ol0003oooooooooo`0@oooo
o`;o00001_ooool2o`000=Wooooo0_l00011ooooo`;o00003oooool001kooooo00?o0000oooooooo
ool0;oooool2o`0005;ooooo0_l0001;ooooo`;o00008Oooool2o`0004Kooooo0_l0000:ooooo`00
7_ooool2o`0001Wooooo0_l0000Eooooo`;o00001_ooool2o`0001;ooooo0_l0000fooooo`;o0000
1_ooool2o`00047ooooo1?l0000Gooooo`;o0000D?ooool2o`0000[ooooo000Nooooo`03o`000?oo
oooooooo01Sooooo0_l0000Mooooo`;o00004_ooool2o`0003gooooo0ol00004ooooo`;o0000;Ooo
ool2o`0000Oooooo0_l00003ooooo`;o00006Oooool2o`0001Oooooo0_l00013ooooo`007_ooool0
0ol0003oooooooooo`2:ooooo`;o00001Oooool2o`0002gooooo0_l00004ooooo`;o000000?ooooo
o`000?l00000=oooool2o`0004?ooooo000Nooooo`03o`000?oooooooooo00Gooooo0_l0002ooooo
o`;o00006oooool2o`0001Oooooo0_l00019ooooo`007_ooool01?l0003oooooo`000?l00004oooo
o`;o00008?ooool2o`0001kooooo0_l0001=ooooo`;o0000Boooool2o`0001Oooooo0_l0000^oooo
o`;o00006Oooool001kooooo00Co0000ooooool0003o00009_ooool2o`0001kooooo0_l0001=oooo
o`;o00002Oooool2o`0008Wooooo0_l0000?ooooo`;o00002?ooool001kooooo00?o0000oooooooo
ool01_ooool2o`0005Oooooo0_l0000`ooooo`;o00003_ooool2o`0009Wooooo0ol00008ooooo`00
7_ooool00ol0003oooooooooo`06ooooo`;o0000=Oooool2o`000003ooooool0003o000001gooooo
0_l0000`ooooo`;o0000ZOooool2o`0000Wooooo000Nooooo`03o`000?oooooooooo03[ooooo0_l0
00001?oooooo0000o`000?ooool2o`0003Sooooo0ol0000iooooo`;o0000Hoooool2o`00023ooooo
0_l00008ooooo`007_ooool00ol0003oooooooooo`0jooooo`;o0000?_ooool3o`0002Sooooo0_l0
000?ooooo`;o0000B?ooool2o`0001Wooooo0_l0000Pooooo`;o00002?ooool001kooooo00?o0000
ooooooooool0YOooool2o`0002Gooooo0_l0000booooo`;o0000AOooool001kooooo00?o0000oooo
ooooool0??ooool2o`00037ooooo0_l0001Kooooo`;o0000NOooool001kooooo00?o0000oooooooo
ool01?ooool2o`0003Kooooo0_l0000aooooo`;o0000]oooool2o`0001gooooo000Nooooo`03o`00
0?oooooooooo00Cooooo0_l0003Fooooo`;o00006?ooool2o`0000gooooo0_l00003ooooo`;o0000
7?ooool2o`0001gooooo000Nooooo`03o`000?oooooooooo05oooooo0ol0001jooooo`;o00006?oo
ool2o`0000gooooo0_l00003ooooo`;o00008Oooool2o`0000Gooooo0ol0000@ooooo`007_ooool0
0ol0003oooooooooo`03ooooo`;o00001Oooool2o`0001[ooooo0_l0000Dooooo`;o00002?ooool2
o`0001Oooooo0ol0003;ooooo`;o00001Oooool3o`00013ooooo000Nooooo`;o00001?ooool2o`00
00Gooooo0_l0000;ooooo`;o00003Oooool2o`0001Cooooo0_l00008ooooo`;o00003_ooool2o`00
0:Kooooo0_l0000]ooooo`;o00006?ooool001kooooo00?o0000ooooooooool05oooool2o`00017o
oooo0_l0000Zooooo`;o0000C_ooool2o`0000gooooo0_l0000>ooooo`;o0000=oooool2o`0003oo
oooo0_l00006ooooo`007_ooool00ol0003oooooooooo`0Zooooo`;o0000Eoooool2o`00027ooooo
0_l00009ooooo`;o00000_ooool2o`0000kooooo0_l0001hooooo`;o00001_ooool001kooooo00?o
0000ooooooooool0@_ooool2o`0000gooooo0_l0000`ooooo`;o00008?ooool2o`0000[ooooo0_l0
000Tooooo`;o00008?ooool2o`0004cooooo000Nooooo`03o`000?oooooooooo04;ooooo0_l0000=
ooooo`;o0000?Oooool2o`0001?ooooo0_l0000`ooooo`;o00008?ooool2o`0004cooooo000Noooo
o`03o`000?oooooooooo093ooooo0_l0002Gooooo`;o00007?ooool001kooooo00?o0000oooooooo
ool0=?ooool2o`0000Wooooo0_l0002]ooooo`;o00003?ooool2o`0002_ooooo0_l0000Looooo`00
7_ooool00ol0003oooooooooo`0dooooo`;o00001oooool4o`00043ooooo0_l0000Looooo`;o0000
COooool2o`0000cooooo0_l00019ooooo`007_ooool00ol0003oooooooooo`0mooooo`;o0000@_oo
ool2o`0001cooooo0_l0000Vooooo`;o0000O_ooool001kooooo00?o0000ooooooooool05?ooool2
o`000:Oooooo0_l00008ooooo`;o0000L?ooool2o`0000cooooo000Nooooo`03o`000?oooooooooo
01Cooooo0_l0000Aooooo`;o0000NOooool2o`0001Wooooo0_l0001jooooo`;o00001Oooool2o`00
00Gooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l0000/ooooo`;o0000Boooool2o`0009co
oooo0_l00005ooooo`007_ooool00ol0003oooooooooo`1Eooooo`;o0000i?ooool2o`0000[ooooo
000Nooooo`03o`000?oooooooooo02kooooo0_l0000Sooooo`;o00006?ooool2o`0000Wooooo0_l0
000Dooooo`;o00006_ooool2o`0008oooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0D
ooooo`;o00006?ooool2o`0002?ooooo0_l0000Hooooo`;o00002Oooool2o`0001Cooooo0_l0000J
ooooo`;o0000>oooool2o`0000Sooooo0_l0000fooooo`;o00007?ooool001kooooo00?o0000oooo
ooooool05?ooool2o`000=7ooooo0_l00008ooooo`;o0000=_ooool2o`0001cooooo000Nooooo`;o
0000oooooom9ooooo`007_ooool00ol0003oooooooooo`2Zooooo`;o0000@oooool2o`0003kooooo
0_l0000Fooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o0000?oooool2o`0002_ooooo0_l0
000/ooooo`;o00005?ooool2o`0002gooooo0_l0000Jooooo`;o00008_ooool2o`0001Kooooo000N
ooooo`03o`000?oooooooooo00kooooo0_l000000ooooooo0000o`00000looooo`;o0000:oooool2
o`0000cooooo0_l0000Xooooo`;o00002_ooool2o`0004Wooooo0_l0000Eooooo`;o00008oooool0
01kooooo00?o0000ooooooooool04Oooool2o`0007Oooooo0_l0000Xooooo`;o00002_ooool2o`00
04_ooooo0_l0000Cooooo`;o00008oooool001kooooo00?o0000ooooooooool0>Oooool2o`0000Co
oooo0_l00015ooooo`;o0000QOooool2o`0001kooooo0_l0000Hooooo`007_ooool00ol0003ooooo
ooooo`0iooooo`;o00001?ooool2o`0004Gooooo0_l00004ooooo`;o0000Woooool2o`0000_ooooo
1?l00009ooooo`007_ooool00ol0003oooooooooo`1:ooooo`;o0000@?ooool2o`0001Gooooo0_l0
000Vooooo`;o00001Oooool2o`0006Kooooo1?l00009ooooo`007_ooool00ol0003oooooooooo`0n
ooooo`;o00002_ooool2o`0005Oooooo0_l0000Vooooo`;o00001Oooool2o`0002Gooooo0_l0000;
ooooo`;o0000>?ooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo01gooooo0_l0000Ooooo
o`;o0000J_ooool2o`0004gooooo0_l0000;ooooo`;o00005?ooool2o`0002;ooooo0_l00005oooo
o`007_ooool00ol0003oooooooooo`0Gooooo`;o00001?ooool2o`0001oooooo0_l0001Zooooo`;o
0000Aoooool2o`00017ooooo0_l0000Dooooo`;o0000:Oooool001kooooo00?o0000ooooooooool0
5oooool2o`0001cooooo0_l00007ooooo`;o0000/oooool2o`0000Kooooo0_l00012ooooo`;o0000
1_ooool001kooooo00?o0000ooooooooool05oooool2o`0001cooooo0_l0000=ooooo`;o00009?oo
ool2o`0000Sooooo0_l00025ooooo`;o0000>_ooool2o`0000Kooooo0_l00006ooooo`007_ooool0
0ol0003oooooooooo`0Cooooo`;o000000Coooooo`000?l0003o0000:oooool2o`0002Cooooo0_l0
0008ooooo`;o0000K_ooool2o`0003cooooo0_l0000Cooooo`;o00003_ooool000?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool04ooo
ool2o`000003ooooool0003o000000;o00008_ooool2o`000:Kooooo0_l0000Jooooo`Co00007_oo
ool2o`0002?ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A006ooooo`04o`000?ooooooooooooooo`;o00005Oooool2o`0002;o
oooo0_l0002Looooo`;o00009?ooool4o`0004?ooooo0003ooooo`05oa0@4?ooooooooooooooool@
41003?ooool00onHV9So8B4Qonk^kP07ooooo`?o000000?oooooo`000?l00000eoooool2o`0002Co
oooo0_l00015ooooo`000oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^
k^h01_ooool00ol0003oooooooooo`1Vooooo`;o00007Oooool2o`0002?ooooo0_l0000Pooooo`;o
0000NOooool000?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool08_ooool2o`0004;ooooo0_l0000Mooooo`;o00006oooool2o`0000Ko
oooo0_l0000Pooooo`;o0000NOooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool4o`0001;ooooo0_l00017ooooo`;o
0000=Oooool2o`0001cooooo1?l0001aooooo`;o00004?ooool000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`0<oooo
o`Co00003?ooool2o`0000Gooooo0_l000000ooooooo0000o`000013ooooo`;o0000Doooool4o`00
053ooooo0_l0000Oooooo`;o00004?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`02ooooo`;o00006?ooool2
o`0000Gooooo0_l000000ooooooo0000o`00001Qooooo`;o0000ROooool2o`00037ooooo000Noooo
o`03o`000?oooooooooo00;ooooo0_l0001=ooooo`;o00004?ooool2o`0001_ooooo0_l00007oooo
o`;o00001?ooool2o`0001Gooooo0_l0000Looooo`;o00004oooool2o`0006cooooo000Nooooo`03
o`000?oooooooooo04Oooooo0_l00008ooooo`;o00004?ooool2o`0000cooooo0_l0000=ooooo`;o
00003Oooool2o`0001Gooooo0_l0000Looooo`;o00004oooool2o`0003[ooooo0_l0000`ooooo`00
7_ooool00ol0003oooooooooo`0eooooo`Co00002?ooool2o`0000Cooooo0_l0000Iooooo`;o0000
3Oooool2o`0005cooooo0_l00014ooooo`;o0000<?ooool001kooooo00?o0000ooooooooool0=Ooo
ool4o`0000Sooooo0_l0000Oooooo`;o0000Joooool2o`0000?ooooo0_l0000Gooooo`;o00006?oo
ool2o`0003kooooo000Nooooo`03o`000?oooooooooo08cooooo0_l0000hooooo`;o00003?ooool2
o`0001Oooooo0_l0000Hooooo`;o0000?_ooool001kooooo00?o0000ooooooooool0S?ooool2o`00
03Sooooo0_l00007ooooo`;o00000_ooool2o`0001oooooo0_l0001Aooooo`007_ooool00ol0003o
ooooooooo`0Nooooo`;o00006Oooool2o`0003[ooooo0_l0000Dooooo`;o0000@_ooool2o`0000;o
oooo0_l0000Gooooo`;o00001_ooool2o`000003ooooool0003o000001Oooooo0_l0000eooooo`00
7_ooool00ol0003oooooooooo`0Nooooo`;o00006Oooool2o`0003[ooooo0_l0000Dooooo`;o0000
Goooool2o`0000Wooooo0_l0000Gooooo`;o0000=Oooool001kooooo00?o0000ooooooooool0@_oo
ool2o`0001[ooooo0_l0000kooooo`;o0000Foooool2o`0002kooooo0_l0000>ooooo`;o00003Ooo
ool001kooooo00?o0000ooooooooool03oooool2o`00037ooooo0_l0000?ooooo`;o00002Oooool2
o`0001kooooo0_l0000Kooooo`;o0000Foooool2o`0002Gooooo0_l00007ooooo`;o00001?ooool2
o`0000Sooooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o00005oooool2o`00
00Oooooo0_l0000Pooooo`;o00003oooool2o`0001Sooooo0_l0000hooooo`;o0000E_ooool2o`00
00gooooo0_l0000=ooooo`;o00005oooool001kooooo0_l0000Yooooo`;o00001oooool2o`0001;o
oooo0_l0000:ooooo`;o00004Oooool2o`00037ooooo0_l0000Gooooo`;o00001_ooool2o`0005Ko
oooo0_l0000eooooo`007_ooool00ol0003oooooooooo`10ooooo`;o00000oooool2o`0000[ooooo
0_l00014ooooo`;o00005oooool2o`0009Gooooo000Nooooo`03o`000?oooooooooo02oooooo0_l0
000?ooooo`;o00005Oooool2o`0000Wooooo1?l0001Oooooo`;o0000P?ooool001kooooo00?o0000
ooooooooool0;oooool2o`0002Kooooo0_l00009ooooo`Co00007Oooool2o`00043ooooo0_l00020
ooooo`007_ooool00ol0003oooooooooo`0]ooooo`;o00005Oooool2o`0001cooooo0_l0000Ooooo
o`;o0000:Oooool2o`0002_ooooo0_l0001Zooooo`007_ooool00ol0003oooooooooo`0]ooooo`;o
00005Oooool2o`0002_ooooo0_l0000kooooo`;o0000:oooool2o`0001Cooooo0_l0000:ooooo`;o
0000B?ooool001kooooo00?o0000ooooooooool0LOooool2o`0007Sooooo0_l00004ooooo`;o0000
2_ooool2o`0001?ooooo0_l0000cooooo`007_ooool00ol0003oooooooooo`0@ooooo`?o0000f?oo
ool2o`0000_ooooo0_l0000Hooooo`;o00005Oooool2o`0000_ooooo0_l0000?ooooo`007_ooool0
0ol0003oooooooooo`0@ooooo`?o0000iOooool2o`0001Sooooo0_l0000Eooooo`;o00002oooool2
o`0000Sooooo0_l00005ooooo`007_ooool00ol0003oooooooooo`1<ooooo`;o0000N_ooool2o`00
02_ooooo0_l0000/ooooo`;o00006oooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo02oo
oooo0_l0000Kooooo`;o0000N_ooool2o`0002_ooooo0_l0000/ooooo`;o00008_ooool001kooooo
00?o0000ooooooooool0;oooool2o`0005Kooooo0_l0002nooooo`007_ooool00ol0003ooooooooo
o`0>ooooo`;o0000BOooool2o`0000?ooooo0_l0000Wooooo`;o00002Oooool2o`0000Gooooo0_l0
000cooooo`;o0000Moooool001gooooo0_l00002ooooo`;o00003?ooool2o`0000Sooooo0_l0000o
ooooo`;o00000oooool2o`0003;ooooo0_l00005ooooo`;o0000<oooool2o`0001gooooo0_l0001H
ooooo`007Oooool2o`0000;ooooo0_l0000Fooooo`;o0000B_ooool2o`0007kooooo0_l00007oooo
o`;o0000F?ooool001kooooo00?o0000ooooooooool0I?ooool2o`0002?ooooo0_l0000Booooo`;o
0000AOooool2o`00047ooooo0_l0000Nooooo`007_ooool2o`0000[ooooo0_l0001iooooo`;o0000
0oooool2o`0000oooooo0_l000000ooooooo0000o`000010ooooo`;o0000A_ooool2o`0001kooooo
000Nooooo`03o`000?oooooooooo00Wooooo0_l0001Xooooo`;o00003?ooool2o`000003ooooool0
003o000001Cooooo0_l0000Aooooo`;o000000?oooooo`000?l00000;Oooool2o`0000Cooooo0_l0
001Pooooo`007_ooool00ol0003oooooooooo`1cooooo`;o00003?ooool2o`0002[ooooo0_l00000
0ooooooo0000o`00000cooooo`;o00005Oooool2o`0001oooooo0_l0000Xooooo`007_ooool00ol0
003oooooooooo`3looooo`;o00007oooool2o`0002Sooooo000Nooooo`?o0000oooooom8ooooo`00
7_ooool3o`0007Sooooo0_l00011ooooo`;o0000B?ooool2o`00043ooooo000Nooooo`03o`000?oo
oooooooo02oooooo0_l00017ooooo`;o0000@Oooool2o`000004ooooool0003o0000o`0004Cooooo
0_l00010ooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o00005_ooool2o`0004Kooooo0_l0
000:ooooo`;o00007_ooool2o`0001Wooooo0ol00026ooooo`007_ooool01?l0003oooooo`000?l0
000Fooooo`;o0000G_ooool2o`0000[ooooo0_l0000Cooooo`;o00002?ooool3o`0004Gooooo0_l0
001Kooooo`007_ooool01?l0003oooooo`000?l0000[ooooo`;o0000>Oooool2o`00013ooooo0_l0
0007ooooo`;o00005?ooool2o`0000Sooooo0_l00016ooooo`;o0000Foooool001kooooo00?o0000
ooooooooool0;?ooool2o`0003Wooooo0_l0000@ooooo`;o00001oooool2o`00013ooooo0_l00005
ooooo`;o0000W_ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo09Cooooo0_l00005oooo
o`;o0000AOooool2o`0005Oooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0Eooooo`?o
00004oooool2o`0001Wooooo0_l0000:ooooo`;o0000=oooool2o`0005Gooooo0_l0000Cooooo`;o
0000C_ooool001kooooo00?o0000ooooooooool02_ooool2o`0000Wooooo0ol0000Cooooo`;o0000
0oooool2o`0001Cooooo0_l0000:ooooo`;o0000=oooool2o`0001?ooooo0_l0000Pooooo`;o0000
<oooool2o`0001kooooo0_l0000^ooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o00009?oo
ool2o`0002gooooo0_l0000oooooo`;o00008?ooool2o`0005?ooooo0ol0000]ooooo`007_ooool0
0ol0003oooooooooo`1Oooooo`;o00005Oooool2o`00013ooooo0_l0000:ooooo`;o00001?ooool2
o`0000;ooooo0_l0000booooo`;o0000A?ooool2o`0002gooooo000Nooooo`;o0000Moooool2o`00
013ooooo0_l0000:ooooo`;o00001?ooool2o`0000;ooooo0_l0000booooo`;o0000>oooool2o`00
03Kooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0001:ooooo`;o0000G_ooool2o`0005So
oooo0_l00004ooooo`;o0000=_ooool001kooooo00?o0000ooooooooool00oooool2o`00027ooooo
0_l0000Wooooo`;o0000G_ooool2o`0005Sooooo0_l00005ooooo`;o00002?ooool2o`0002_ooooo
000Nooooo`03o`000?oooooooooo02Kooooo0_l0000:ooooo`;o0000Doooool2o`0002Kooooo0_l0
000cooooo`;o0000:_ooool2o`0000Sooooo0_l0000[ooooo`007_ooool01?l0003ooooooooooooo
ool2o`0002Sooooo0_l00005ooooo`;o0000Doooool2o`0002Kooooo0_l0000:ooooo`;o00009ooo
ool2o`0001Kooooo0_l0000iooooo`;o00003_ooool001kooooo00Co0000oooooooooooooooo0_l0
000:ooooo`;o00007?ooool2o`0001?ooooo0_l0000>ooooo`;o0000JOooool2o`0000Oooooo0_l0
000fooooo`;o00000_ooool2o`0003Gooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`0=
ooooo`;o0000<Oooool2o`0000;ooooo0_l0000:ooooo`;o0000L_ooool2o`0000?ooooo0_l0000e
ooooo`;o0000AOooool001kooooo00?o0000ooooooooool0<?ooool2o`0001;ooooo0_l0000Voooo
o`;o0000<oooool2o`0002Kooooo0_l0001Tooooo`;o00005_ooool001kooooo00?o0000oooooooo
ool0<?ooool2o`0003[ooooo0_l0000cooooo`;o0000<?ooool2o`0005[ooooo0_l0000Fooooo`00
7_ooool00ol0003oooooooooo`0Iooooo`;o0000COooool2o`0001_ooooo0_l0001<ooooo`;o0000
8?ooool2o`00053ooooo000Nooooo`03o`000?oooooooooo00Cooooo1?l00005ooooo`;o00002_oo
ool2o`00043ooooo0_l00009ooooo`Co00006oooool2o`00013ooooo0_l0000<ooooo`;o00003?oo
ool2o`0003_ooooo0_l00003ooooo`;o0000D?ooool001kooooo00?o0000ooooooooool01?ooool4
o`0000Gooooo0_l0001<ooooo`;o00002Oooool2o`0002oooooo0_l0000<ooooo`;o00003?ooool2
o`0003;ooooo0_l00007ooooo`;o0000EOooool001kooooo00?o0000ooooooooool0O?ooool2o`00
01Wooooo0_l0001>ooooo`;o0000G_ooool001kooooo00?o0000ooooooooool0O?ooool2o`0000ko
oooo0_l00009ooooo`;o0000[_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0O_ooool2o`0000co
oooo0_l0000Tooooo`;o00006?ooool2o`0007Wooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1nooooo`;o
0000<_ooool2o`0001Sooooo0_l0000Fooooo`;o0000;_ooool2o`0002Oooooo0_l00008ooooo`00
0oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`?o0000=?ooool2o`00013o
oooo0_l0002Looooo`;o0000;_ooool2o`0002Oooooo0_l00008ooooo`000oooool01Ol0003ooooo
oooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool00ol0003oooooooooo`0doooo
o`;o00004?ooool3o`0001?ooooo0_l0001dooooo`;o0000Loooool000?ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0Aoooool2
o`0001?ooooo0_l0001`ooooo`;o00000_ooool2o`0003gooooo0_l0000dooooo`000oooool01Ol@
413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0N
ooooo`;o0000[_ooool2o`0000Wooooo0_l0000eooooo`?o0000=?ooool000?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool07_ooool2
o`0006Oooooo0_l0000=ooooo`;o0000?Oooool2o`0000;ooooo0_l0000eooooo`;o0000=Oooool0
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000
ooooooooool0Foooool2o`0002[ooooo0_l0000=ooooo`;o0000?Oooool2o`0004Cooooo0_l0000E
ooooo`;o00004oooool001kooooo00?o0000ooooooooool06?ooool2o`00047ooooo0_l0002noooo
o`;o00002Oooool2o`0000[ooooo0_l0000Cooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o
0000`Oooool2o`0002Sooooo0ol0000Nooooo`;o00007oooool001kooooo00?o0000ooooooooool0
3?ooool2o`0001Gooooo0_l0002Booooo`;o00008_ooool2o`0002Sooooo0ol0000oooooo`007_oo
ool00ol0003oooooooooo`0<ooooo`;o00005Oooool2o`0009;ooooo0_l0002>ooooo`007_ooool0
0ol0003oooooooooo`03ooooo`;o0000SOooool2o`0002?ooooo0_l0002>ooooo`007_ooool00ol0
003oooooooooo`03ooooo`;o00003oooool2o`0002;ooooo0_l0000Wooooo`;o0000;oooool2o`00
02?ooooo0_l00014ooooo`;o00003oooool2o`0003Oooooo000Nooooo`03o`000?oooooooooo01Co
oooo0_l0000Rooooo`;o00009oooool2o`0006gooooo0_l0000[ooooo`;o00003oooool2o`00017o
oooo0_l00009ooooo`;o00006Oooool001kooooo00?o0000ooooooooool00_ooool2o`0004_ooooo
0_l0000Fooooo`;o00009Oooool2o`0002gooooo0_l0000Aooooo`;o0000Coooool2o`0000Wooooo
0_l0000Iooooo`007_ooool00ol0003oooooooooo`02ooooo`;o0000Boooool2o`0001Kooooo0_l0
000Uooooo`;o00001Oooool2o`00013ooooo0_l000000ooooooo0000o`00000Aooooo`;o00001?oo
ool2o`0007Cooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o00006?ooool2
o`0005[ooooo0_l0000@ooooo`;o000000?oooooo`000?l000005oooool2o`0006Sooooo0_l00000
0ooooooo0000o`000007ooooo`;o00003?ooool001kooooo00?o0000ooooooooool04_ooool2o`00
00Sooooo0_l000000ooooooo0000o`00000Hooooo`;o00007oooool2o`0000oooooo0_l0000>oooo
o`;o00005?ooool2o`0006_ooooo0_l0000]ooooo`;o000000?oooooo`000?l000005Oooool001ko
oooo0_l0000Cooooo`;o00002?ooool2o`0003cooooo0_l0000:ooooo`;o00000oooool2o`0000ko
oooo0_l0000Dooooo`;o00004oooool2o`0005Kooooo0_l00017ooooo`007_ooool00ol0003ooooo
ooooo`0mooooo`;o00009oooool2o`0003kooooo0_l0002Oooooo`007_ooool00ol0003ooooooooo
o`0Mooooo`;o00007_ooool2o`0000Oooooo0_l0000fooooo`;o00000oooool2o`00027ooooo0_l0
000?ooooo`;o0000K_ooool2o`0001kooooo000Nooooo`03o`000?oooooooooo01gooooo0_l0000W
ooooo`;o00008Oooool2o`0001?ooooo0_l00003ooooo`;o0000<_ooool2o`0006kooooo0_l0000N
ooooo`007_ooool00ol0003oooooooooo`0Kooooo`;o0000C?ooool2o`0000cooooo0_l0000`oooo
o`;o0000EOooool2o`0003Wooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0Kooooo`;o
0000Coooool2o`0000Wooooo0_l0000]ooooo`;o000000?oooooo`000?l000001Oooool2o`0004ko
oooo0_l0000/ooooo`;o00002oooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo01kooooo
0_l0001<ooooo`;o0000>?ooool2o`0000Sooooo0ol0001Jooooo`;o00007oooool2o`0001Oooooo
000Nooooo`03o`000?oooooooooo01gooooo0ol0002Aooooo`;o00002_ooool2o`0004kooooo0_l0
000hooooo`007_ooool00ol0003oooooooooo`06ooooo`;o00005Oooool2o`0002oooooo0_l0000Z
ooooo`;o0000@Oooool2o`0006kooooo0_l0000Hooooo`007_ooool00ol0003oooooooooo`06oooo
o`;o0000A_ooool2o`0002[ooooo0_l0000Rooooo`;o0000SOooool2o`0001Sooooo000Nooooo`03
o`000?oooooooooo06Wooooo0_l0000cooooo`;o00009?ooool2o`0005[ooooo0_l0000Uooooo`00
7_ooool00ol0003oooooooooo`0@ooooo`;o00001oooool2o`00037ooooo0_l0000Kooooo`;o0000
FOooool2o`0004_ooooo0_l0000=ooooo`;o00009Oooool001kooooo00?o0000ooooooooool04?oo
ool2o`0000Oooooo0_l00006ooooo`;o0000:Oooool2o`000<?ooooo0_l0000Oooooo`;o00004ooo
ool001kooooo00?o0000ooooooooool03?ooool2o`0001?ooooo0_l0000nooooo`;o00009Oooool2
o`0004[ooooo0_l0001Looooo`;o00004oooool001kooooo00?o0000ooooooooool03?ooool2o`00
05?ooooo0_l0000Uooooo`;o0000B_ooool2o`00077ooooo000Nooooo`03o`000?oooooooooo00Co
oooo0_l0001Booooo`;o0000a?ooool2o`0002Oooooo000Nooooo`;o00001Oooool2o`0005;ooooo
0_l00011ooooo`;o0000POooool2o`0002Oooooo000Nooooo`03o`000?oooooooooo09_ooooo0_l0
000:ooooo`;o00006Oooool2o`0008?ooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0000X
ooooo`;o00009_ooool2o`0004_ooooo0_l00002ooooo`;o00006Oooool2o`0005cooooo0_l00002
ooooo`;o00006oooool2o`0000Cooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0000Xoooo
o`;o00009_ooool2o`0004Sooooo0_l000000ooooooo0000o`00001kooooo`;o00000_ooool2o`00
01_ooooo0_l00004ooooo`007_ooool00ol0003oooooooooo`0oooooo`;o0000;_ooool2o`0002oo
oooo0_l00029ooooo`;o00006_ooool001kooooo00?o0000ooooooooool0?oooool2o`0002kooooo
0_l0002jooooo`;o00006_ooool001kooooo00?o0000ooooooooool07Oooool2o`0004?ooooo0_l0
000Tooooo`;o00002Oooool2o`000;;ooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0000G
ooooo`;o0000@oooool2o`0002Cooooo0_l00009ooooo`;o0000;oooool2o`0001_ooooo0_l0001H
ooooo`;o00002_ooool001kooooo00?o0000ooooooooool01?ooool2o`000;kooooo0_l0000Koooo
o`;o0000<_ooool2o`0002Cooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`09ooooo`;o
00004_ooool2o`0005Kooooo0_l00009ooooo`;o0000Poooool2o`0000kooooo0_l0000`ooooo`00
7_ooool00ol0003oooooooooo`09ooooo`?o00004Oooool2o`000003ooooool0003o000002Wooooo
0_l00006ooooo`;o00008?ooool2o`0000Wooooo0_l0001Looooo`;o00003_ooool2o`0001Gooooo
0_l00010ooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o00002_ooool2o`0000Sooooo0_l0
000Yooooo`;o00001_ooool2o`0002?ooooo0_l0001Tooooo`;o00003_ooool2o`00027ooooo0_l0
000Jooooo`;o00006?ooool001kooooo00?o0000ooooooooool05_ooool2o`0003;ooooo0_l0000;
ooooo`;o00003?ooool2o`00017ooooo0_l0000Gooooo`;o0000O_ooool2o`0001[ooooo0_l0000H
ooooo`007_ooool00ol0003oooooooooo`1:ooooo`;o00002oooool2o`0000Gooooo0_l00005oooo
o`;o0000:_ooool2o`0007Gooooo0_l0000mooooo`007_ooool00ol0003oooooooooo`1Nooooo`;o
0000Z?ooool2o`0001Kooooo0_l0000Uooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o0000
8_ooool2o`0001Wooooo0_l0003;ooooo`;o00009Oooool001kooooo0_l0000Eooooo`;o00008_oo
ool2o`0000gooooo0_l0000:ooooo`;o0000l_ooool001kooooo00?o0000ooooooooool0<_ooool2
o`0001?ooooo0_l00026ooooo`;o00002oooool2o`0002_ooooo0_l0000looooo`007_ooool00ol0
003oooooooooo`08ooooo`;o0000:?ooool2o`0002oooooo0_l0000Qooooo`;o0000A?ooool2o`00
0003ooooool0003o000000_ooooo0_l00003ooooo`;o00009_ooool2o`0001oooooo0_l0000Koooo
o`007_ooool00ol0003oooooooooo`08ooooo`;o0000:?ooool2o`0002oooooo0_l0000Qooooo`;o
0000A?ooool2o`0001?ooooo0_l00017ooooo`;o00006oooool001kooooo00?o0000ooooooooool0
I?ooool2o`0007Gooooo0_l0001Booooo`;o00005_ooool001kooooo00?o0000ooooooooool0A?oo
ool2o`0001kooooo0_l0001eooooo`;o0000>oooool2o`0001Gooooo0_l00002ooooo`;o00004_oo
ool001kooooo00?o0000ooooooooool0A?ooool2o`000=;ooooo0_l0000Iooooo`;o00004_ooool0
01kooooo00?o0000ooooooooool0Boooool2o`0007Kooooo0_l0000Rooooo`;o0000G_ooool001ko
oooo00?o0000ooooooooool0Boooool2o`0002Kooooo0_l0001>ooooo`Co00008?ooool2o`0002Wo
oooo0_l0000Jooooo`;o00005oooool001gooooo0_l0001eooooo`;o0000D?ooool2o`0004_ooooo
0_l0000Jooooo`;o00000oooool2o`0001;ooooo000Mooooo`;o00002oooool2o`00083ooooo0_l0
001Vooooo`;o0000?_ooool2o`0001;ooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0001_
ooooo`;o00003oooool2o`00063ooooo1?l00002ooooo`;o0000D_ooool001kooooo00?o0000oooo
ooooool0N_ooool2o`0006Cooooo0_l0000;ooooo`Co0000:?ooool2o`0000gooooo0_l000000ooo
oooo0000o`000009ooooo`;o00003oooool001kooooo00?o0000ooooooooool09Oooool2o`0001co
oooo0_l0000looooo`;o0000GOooool2o`0003Oooooo0_l0000=ooooo`;o000000?oooooo`000?l0
00002Oooool2o`0000oooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo02Gooooo0_l0000Foooo
o`;o00001?ooool2o`0003cooooo0_l0001Iooooo`;o0000>_ooool2o`0002gooooo0003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06
ooooo`03o`000?oooooooooo03gooooo0_l0002Mooooo`;o00008Oooool2o`0000gooooo0_l00008
ooooo`;o00009Oooool2o`0000Kooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool0
1Ol0003ooooooooooooooooo000000Kooooo0ol0003oooooo`;o00003Oooool2o`0002oooooo0_l0
0006ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RH
ob4Q8@06ooooo`03o`000?oooooooooo07Oooooo0_l00025ooooo`;o0000Aoooool000?ooooo00Go
0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003o
ooooooooo`0Dooooo`;o0000HOooool2o`0007?ooooo0_l0000@ooooo`;o0000Aoooool000?ooooo
00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000oooooooo
ool05?ooool2o`0000Gooooo0_l0003?ooooo`;o0000FOooool000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool06oooool2o`000?oo
oooo:oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@
40Kooooo00?o0000ooooooooool0P?ooool2o`0000Oooooo0_l0000aooooo`;o00009?ooool2o`00
00Gooooo0_l0000iooooo`;o00008Oooool001kooooo00?o0000ooooooooool0J?ooool2o`0001Ko
oooo0_l00007ooooo`;o00009?ooool2o`0000_ooooo0_l0000Tooooo`;o00001Oooool2o`0003Wo
oooo0_l0000Qooooo`007_ooool00ol0003oooooooooo`1Xooooo`;o0000AOooool2o`0008kooooo
0_l00006ooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o00003oooool2o`0002oooooo0_l0
000Pooooo`;o0000;Oooool2o`0003Wooooo0_l0001@ooooo`;o00001_ooool001kooooo00?o0000
ooooooooool07oooool2o`0000oooooo0_l0000Vooooo`;o00001oooool2o`00023ooooo0_l0000]
ooooo`;o0000>?ooool3o`0000;ooooo0_l0001Dooooo`007_ooool00ol0003oooooooooo`1Hoooo
o`;o0000H?ooool2o`0000gooooo0_l0000Iooooo`;o00001_ooool2o`0000?ooooo0_l0001Doooo
o`007_ooool00ol0003oooooooooo`2jooooo`;o00003Oooool2o`0001Wooooo0_l0001Qooooo`00
7_ooool00ol0003oooooooooo`3oooooocOooooo0_l0000?ooooo`007_ooool00ol0003ooooooooo
o`0Hooooo`;o00003oooool2o`000?oooooo3?ooool2o`0000oooooo000Nooooo`03o`000?oooooo
oooo00gooooo0_l00009ooooo`;o00003oooool2o`000<Kooooo0_l0000Eooooo`;o00003?ooool2
o`0002oooooo000Nooooo`03o`000?oooooooooo00gooooo0_l00002ooooo`;o0000L_ooool2o`00
033ooooo0_l0000hooooo`;o00005Oooool2o`0000?ooooo0_l00007ooooo`;o0000;oooool001ko
oooo00?o0000ooooooooool04Oooool2o`0001Kooooo0_l0001Booooo`Co00001?ooool2o`00033o
oooo0_l0001Dooooo`;o0000>?ooool001kooooo0_l0000Zooooo`;o0000@_ooool2o`0000kooooo
1?l0000Gooooo`;o00003Oooool3o`0009gooooo000Nooooo`03o`000?oooooooooo06gooooo0_l0
000:ooooo`;o00007Oooool2o`0000gooooo0ol0000@ooooo`;o0000Roooool001kooooo00?o0000
ooooooooool0?_ooool2o`0003Wooooo0_l0000Qooooo`;o00007?ooool2o`0002Sooooo0_l00007
ooooo`;o0000F?ooool001kooooo00?o0000ooooooooool0?_ooool2o`0001Kooooo0_l00014oooo
o`;o00008?ooool2o`0002Cooooo0_l00007ooooo`;o00006?ooool2o`0003kooooo000Nooooo`03
o`000?oooooooooo05Kooooo0_l0001Vooooo`;o0000Aoooool2o`0003kooooo000Nooooo`03o`00
0?oooooooooo0=Sooooo0_l0001]ooooo`007_ooool00ol0003oooooooooo`3Hooooo`;o00002ooo
ool2o`0001kooooo0_l00005ooooo`;o0000>Oooool001kooooo00?o0000ooooooooool0iOooool2
o`0001kooooo0_l00005ooooo`;o0000>Oooool001kooooo00?o0000ooooooooool0Q_ooool2o`00
023ooooo0_l0000Cooooo`;o0000HOooool2o`0002Gooooo000Nooooo`03o`000?oooooooooo01Oo
oooo0_l0000Fooooo`;o0000EOooool2o`00023ooooo0_l0000Cooooo`;o0000F?ooool2o`0000Oo
oooo0_l0000Uooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o00005_ooool2o`0000Sooooo
0_l0003Looooo`;o0000;_ooool001kooooo00?o0000ooooooooool0>Oooool2o`0002[ooooo0_l0
0039ooooo`;o00005Oooool001kooooo00?o0000ooooooooool0IOooool2o`0004Cooooo0_l0001m
ooooo`;o00001?ooool3o`0001Cooooo000Nooooo`03o`000?oooooooooo0:_ooooo0_l0000moooo
o`;o0000?_ooool2o`0000Gooooo0_l0000Dooooo`007_ooool00ol0003oooooooooo`1nooooo`;o
0000J_ooool3o`0003gooooo0_l0000Kooooo`007_ooool00ol0003oooooooooo`1@ooooo`;o0000
;?ooool2o`0006Kooooo0_l00003ooooo`;o00005?ooool2o`0000Gooooo0_l0000Pooooo`;o0000
3Oooool2o`0000cooooo000Nooooo`;o0000DOooool2o`0002Wooooo0_l0001Yooooo`;o00006Ooo
ool2o`0000Gooooo0_l0000_ooooo`;o00003?ooool001kooooo00?o0000ooooooooool0@_ooool2
o`0003Oooooo0_l0003:ooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o0000;?ooool2o`00
06;ooooo0_l00014ooooo`;o0000FOooool001kooooo00?o0000ooooooooool05?ooool2o`0001oo
oooo0_l0001_ooooo`;o0000A?ooool2o`0001;ooooo0_l00015ooooo`007_ooool00ol0003ooooo
ooooo`0_ooooo`;o00001?ooool2o`0007cooooo0_l0000eooooo`;o00005?ooool2o`0004Gooooo
000Nooooo`03o`000?oooooooooo02Gooooo0_l00008ooooo`;o0000Ioooool2o`0000Gooooo0_l0
000Booooo`;o0000=Oooool2o`0001Gooooo0_l0000]ooooo`;o00005Oooool001kooooo00?o0000
ooooooooool09Oooool2o`0000cooooo0_l0001Sooooo`;o00001Oooool2o`00013ooooo0_l0000L
ooooo`;o0000<?ooool2o`0001Gooooo0_l0000Fooooo`;o00005Oooool001kooooo00?o0000oooo
ooooool03oooool2o`0002;ooooo0_l0001Sooooo`;o00005oooool2o`0001cooooo1?l00015oooo
o`;o0000;Oooool001kooooo00?o0000ooooooooool03oooool2o`0004;ooooo0_l00008ooooo`;o
0000>Oooool2o`0003Oooooo0_l0000<ooooo`;o0000I_ooool001kooooo00?o0000ooooooooool0
5?ooool2o`0003gooooo0_l00008ooooo`;o00003?ooool2o`0007;ooooo0_l0001Vooooo`007_oo
ool00ol0003oooooooooo`0Dooooo`;o00000oooool2o`00053ooooo0_l0002Aooooo`;o0000Aooo
ool001kooooo00?o0000ooooooooool06Oooool2o`0002Wooooo0_l0002hooooo`;o0000Aoooool0
01kooooo00?o0000ooooooooool0>?ooool2o`0000[ooooo0_l0002Yooooo`;o0000E_ooool001ko
oooo00Co0000oooooooooooooooo0_l00008ooooo`;o000000?oooooo`000?l00000:?ooool2o`00
0;7ooooo0_l00002ooooo`;o0000E_ooool001kooooo00Co0000oooooooooooooooo0_l00008oooo
o`;o000000?oooooo`000?l00000DOooool2o`0008Sooooo0_l0000Looooo`;o00008_ooool2o`00
01Sooooo000Nooooo`03o`000?oooooooooo027ooooo0_l0000nooooo`;o00003oooool2o`0004oo
oooo0_l00014ooooo`;o00008_ooool2o`0001Sooooo000Nooooo`;o00007_ooool2o`0000;ooooo
0_l0001?ooooo`;o0000Coooool2o`00053ooooo0_l0000>ooooo`;o00003oooool2o`0000oooooo
000Nooooo`03o`000?oooooooooo01gooooo0_l0000Gooooo`;o0000D?ooool2o`0003;ooooo0_l0
0003ooooo`;o00007?ooool2o`0003Cooooo0_l0000>ooooo`;o00003oooool2o`0000oooooo000N
ooooo`03o`000?oooooooooo03Kooooo0_l0000>ooooo`;o0000@?ooool2o`0003;ooooo0_l00003
ooooo`;o00001?ooool2o`0001Kooooo0_l0000gooooo`;o0000;Oooool001kooooo00?o0000oooo
ooooool0A_ooool2o`0003kooooo0_l0000?ooooo`;o00009_ooool2o`0000Kooooo0_l0001<oooo
o`;o000000?oooooo`000?l00000;Oooool001kooooo00?o0000ooooooooool0>Oooool3o`0004[o
oooo0_l0000?ooooo`;o00007?ooool2o`0000Sooooo0_l0001Dooooo`;o0000<?ooool001kooooo
00?o0000ooooooooool0>Oooool3o`0003Gooooo0_l0000Yooooo`;o00005oooool2o`0001Oooooo
0_l0001gooooo`007_ooool00ol0003oooooooooo`0gooooo`;o00009oooool2o`0000Kooooo0_l0
0007ooooo`;o00007?ooool2o`0000[ooooo0ol0000`ooooo`;o0000?Oooool2o`0001?ooooo0_l0
000Fooooo`;o00002oooool001kooooo00?o0000ooooooooool0=oooool2o`0002Oooooo0_l00006
ooooo`?o00009?ooool2o`0000[ooooo0_l0001`ooooo`;o00004oooool2o`0001Kooooo0_l0000;
ooooo`007_ooool00ol0003oooooooooo`0hooooo`;o0000;oooool2o`000=cooooo000Nooooo`03
o`000?oooooooooo03Sooooo0_l0002kooooo`;o0000B?ooool2o`0000Kooooo000Nooooo`03o`00
0?oooooooooo08Cooooo0_l0001_ooooo`;o0000B?ooool2o`0000Kooooo000Nooooo`03o`000?oo
oooooooo08Cooooo0_l0002Yooooo`;o00005_ooool001kooooo00?o0000ooooooooool04oooool2
o`00037ooooo0_l0002Yooooo`;o0000>Oooool2o`000003ooooool0003o000001Kooooo000Noooo
o`03o`000?oooooooooo01?ooooo0_l0000Wooooo`;o00002?ooool2o`000:Wooooo0_l0000ioooo
o`;o00006Oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<
c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool09oooool2o`0001?ooooo0_l0002E
ooooo`;o0000>?ooool2o`0003Sooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo02Oooooo0_l0
002Zooooo`;o0000>?ooool2o`0003Sooooo0003ooooo`05oa0@4?ooooooooooooooool@41002ooo
ool01Ol0003ooooooooooooooooo000000Kooooo0ol0000Yooooo`;o00008_ooool2o`0005kooooo
0_l0000Gooooo`;o0000N?ooool2o`0000Gooooo0003ooooo`05o`000?ooooooooooooooool00000
2oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000ooooooooool0:Oooool2o`0002;o
oooo0_l0001Nooooo`;o00005Oooool4o`0007Sooooo0_l00005ooooo`000oooool01Ol0003ooooo
oooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo
01?ooooo0_l0001<ooooo`;o00009oooool2o`0003Sooooo0_l000000ooooooo0000o`00001noooo
o`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006
ooooo`03o`000?oooooooooo01?ooooo0_l0000]ooooo`;o00007Oooool2o`0002Oooooo0_l0000J
ooooo`;o00007oooool2o`0007kooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool07?ooool2o`0002Cooooo0_l0
0011ooooo`;o00007oooool2o`0009Gooooo0_l00008ooooo`000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo01cooooo
0_l0001Wooooo`;o0000AOooool2o`0001kooooo0_l0000Nooooo`;o00004oooool2o`0001[ooooo
0_l00008ooooo`007_ooool00ol0003oooooooooo`0[ooooo`;o00006oooool2o`0003Sooooo0_l0
0018ooooo`;o00002Oooool2o`0001?ooooo0_l00006ooooo`;o00005_ooool2o`0001?ooooo0_l0
000Tooooo`007_ooool00ol0003oooooooooo`0[ooooo`?o00006_ooool2o`0003Sooooo0_l0000/
ooooo`;o000000?oooooo`000?l000008_ooool2o`0001_ooooo0_l0001Aooooo`007_ooool00ol0
003oooooooooo`0Looooo`?o00003Oooool2o`0008;ooooo0_l000000ooooooo0000o`00000Foooo
o`;o0000>_ooool2o`00023ooooo0_l0000Looooo`007_ooool00ol0003oooooooooo`0Looooo`?o
0000Poooool2o`0000?ooooo0ol0000Qooooo`;o00002_ooool2o`00013ooooo0_l0000Looooo`;o
00001Oooool2o`0001Wooooo0_l0000Looooo`007_ooool00ol0003oooooooooo`0Booooo`;o0000
JOooool2o`0002?ooooo0_l00003ooooo`?o00006oooool2o`00013ooooo0_l0000@ooooo`;o0000
6?ooool2o`0000Wooooo0_l0000gooooo`007_ooool00ol0003oooooooooo`0Booooo`;o00003?oo
ool2o`0005_ooooo0_l0000=ooooo`;o00009Oooool2o`00013ooooo0_l00004ooooo`;o0000=_oo
ool2o`0004;ooooo000Nooooo`03o`000?oooooooooo023ooooo0_l0000@ooooo`;o0000A_ooool2
o`00013ooooo0_l0000=ooooo`;o00005_ooool2o`0001Kooooo0_l0000oooooo`;o0000>Oooool0
01kooooo00?o0000ooooooooool0<_ooool2o`0003cooooo0_l00008ooooo`;o00007oooool2o`00
01Kooooo0_l0000?ooooo`;o0000A_ooool2o`0000?ooooo0_l0000dooooo`007_ooool00ol0003o
ooooooooo`1[ooooo`;o00000oooool2o`00047ooooo0_l0000?ooooo`;o0000Boooool2o`0003Co
oooo000Nooooo`03o`000?oooooooooo01Wooooo0_l0001@ooooo`;o00001?ooool2o`0008kooooo
0_l00014ooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o0000E_ooool2o`0006;ooooo0_l0
000Zooooo`;o0000A?ooool001kooooo0_l0003Dooooo`Co0000L?ooool001kooooo00?o0000oooo
ooooool0COooool2o`0008Cooooo0_l00006ooooo`;o00007oooool2o`0003Cooooo0_l0000Coooo
o`007_ooool00ol0003oooooooooo`1=ooooo`;o00003Oooool2o`0006cooooo0_l0000?ooooo`;o
00007oooool2o`0000Cooooo0_l0000^ooooo`;o00004oooool001kooooo00?o0000ooooooooool0
4_ooool2o`0003Oooooo0_l00002ooooo`;o00002oooool2o`0006cooooo0_l0000fooooo`;o0000
@oooool001kooooo00?o0000ooooooooool04_ooool2o`0001cooooo0_l0000Iooooo`;o00000_oo
ool2o`00037ooooo0_l0000kooooo`;o0000F_ooool2o`0002[ooooo000Nooooo`03o`000?oooooo
oooo033ooooo0_l00006ooooo`;o00008_ooool2o`0000;ooooo0_l0000Pooooo`;o0000>oooool2
o`0002Oooooo0_l0000aooooo`;o00007Oooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo
03Sooooo0_l0000Rooooo`;o00000_ooool2o`00033ooooo0_l00007ooooo`;o0000:oooool2o`00
01kooooo0_l0001@ooooo`;o00002oooool001kooooo00?o0000ooooooooool0T_ooool2o`0000Oo
oooo0_l0000Looooo`;o00003Oooool2o`00033ooooo0_l0001;ooooo`007_ooool00ol0003ooooo
ooooo`0cooooo`;o0000GOooool2o`0002Gooooo0_l0000=ooooo`;o0000;_ooool4o`0002Kooooo
0_l0000Sooooo`007_ooool00ol0003oooooooooo`02o`00037ooooo0_l0000=ooooo`;o00002_oo
ool2o`000:Sooooo0_l0000Xooooo`;o00008oooool001kooooo00?o0000ooooooooool00_l0000E
ooooo`;o0000:Oooool2o`0000[ooooo0_l0003Jooooo`;o00006oooool001kooooo00?o0000oooo
ooooool05oooool2o`0003_ooooo0_l00031ooooo`;o00004Oooool2o`0001_ooooo000Nooooo`03
o`000?oooooooooo05Cooooo0_l0000Hooooo`;o0000>_ooool2o`0000Wooooo0_l00005ooooo`;o
0000FOooool2o`0002kooooo000Nooooo`03o`000?oooooooooo04;ooooo0_l0000Hooooo`;o0000
4?ooool2o`0003[ooooo0_l00009ooooo`;o00001Oooool3o`0004gooooo0_l0000Jooooo`;o0000
7Oooool001kooooo00?o0000ooooooooool0@_ooool2o`0001Sooooo0_l0001?ooooo`;o00003_oo
ool2o`0000kooooo0_l0000jooooo`;o000000?oooooo`000?l000004?ooool2o`0000Sooooo0_l0
0002ooooo`;o00006Oooool001kooooo00?o0000ooooooooool0[Oooool2o`0001kooooo0_l0000j
ooooo`;o00002_ooool3o`0000Kooooo0_l00003ooooo`;o00001oooool2o`0000Kooooo0_l0000A
ooooo`007_ooool2o`0008Gooooo0_l0002<ooooo`Ko00002oooool2o`0000oooooo0_l00006oooo
o`;o00002Oooool001kooooo00?o0000ooooooooool0Q?ooool2o`0004_ooooo0_l0000oooooo`Co
00009_ooool2o`0000Wooooo000Nooooo`03o`000?oooooooooo07kooooo0_l0001Aooooo`;o0000
3_ooool2o`0006Cooooo000Nooooo`03o`000?oooooooooo07kooooo0_l0000Wooooo`;o0000<Ooo
ool2o`0000Gooooo0_l0000Hooooo`;o0000B_ooool001kooooo00?o0000ooooooooool05oooool2
o`0008kooooo0_l00003ooooo`;o0000;?ooool2o`0001;ooooo0_l00004ooooo`;o00001Oooool2
o`000003ooooool0003o000000Gooooo0_l00010ooooo`007_ooool00ol0003oooooooooo`0Goooo
o`;o0000Toooool2o`00037ooooo0_l0000=ooooo`;o00001?ooool2o`0000Sooooo0_l00005oooo
o`;o0000@?ooool001kooooo00?o0000ooooooooool0goooool2o`0000?ooooo0_l0001Qooooo`00
7_ooool00ol0003oooooooooo`3Tooooo`;o0000HOooool001kooooo00?o0000ooooooooool05Ooo
ool2o`0006oooooo0_l0000>ooooo`;o00008Oooool2o`0008cooooo000Nooooo`03o`000?oooooo
oooo01Gooooo0_l0000^ooooo`;o0000?oooool2o`0000kooooo0_l0000Qooooo`;o00009_ooool2
o`0002Wooooo0_l0000Rooooo`;o00005Oooool001kooooo00?o0000ooooooooool0AOooool2o`00
02?ooooo0_l0001Looooo`;o00003_ooool2o`0000Oooooo0_l0000Yooooo`;o00008_ooool2o`00
01Gooooo000Nooooo`03o`000?oooooooooo06[ooooo0_l0001Looooo`;o00000_ooool2o`0000[o
oooo0_l0000Eooooo`;o00001oooool2o`0004gooooo000Nooooo`03o`000?oooooooooo067ooooo
0_l0000?ooooo`;o0000F?ooool2o`00027ooooo0_l00007ooooo`;o00007?ooool2o`0002oooooo
000Nooooo`03o`000?oooooooooo03oooooo0_l0000Pooooo`;o00003oooool2o`0001cooooo0_l0
000Fooooo`;o00009Oooool2o`0004Gooooo0_l0000Pooooo`;o00003Oooool001kooooo00?o0000
ooooooooool0?oooool2o`0004oooooo0_l0000Fooooo`;o00009Oooool2o`0002Kooooo0_l0000;
ooooo`;o00002_ooool2o`0001Kooooo0_l0000>ooooo`;o00003Oooool001kooooo00?o0000oooo
ooooool0?oooool2o`00013ooooo0_l0001:ooooo`;o00009Oooool2o`00037ooooo0_l00009oooo
o`Co00002_ooool2o`0001Kooooo1?l0000Kooooo`007_ooool2o`00043ooooo0_l0000@ooooo`;o
00001_ooool2o`0004;ooooo0_l0000Uooooo`;o00006oooool2o`0001gooooo1Ol0000Uooooo`;o
00006oooool001kooooo00?o0000ooooooooool04Oooool4o`0002kooooo0_l0000Dooooo`;o0000
Q_ooool2o`0001gooooo0_l0000Uooooo`;o00007_ooool001kooooo00?o0000ooooooooool04Ooo
ool4o`0002kooooo0_l0000Gooooo`;o0000W?ooool2o`0002Cooooo0_l00005ooooo`;o00007_oo
ool001kooooo00?o0000ooooooooool0G?ooool2o`0004;ooooo0_l0001Hooooo`;o00005Oooool2
o`0000gooooo0_l0000Uooooo`007_ooool00ol0003oooooooooo`2Pooooo`;o00002oooool2o`00
037ooooo0_l0000^ooooo`?o00009_ooool2o`0000cooooo000Nooooo`03o`000?oooooooooo0:go
oooo0_l0000aooooo`;o0000;_ooool2o`0002Oooooo0_l0000<ooooo`007_ooool00ol0003ooooo
ooooo`2hooooo`;o0000Doooool2o`0003Sooooo000Nooooo`03o`000?oooooooooo0;Sooooo0_l0
000oooooo`;o00004_ooool2o`0001cooooo0_l0000Jooooo`007_ooool00ol0003oooooooooo`3i
ooooo`;o0000<?ooool2o`0001[ooooo000Nooooo`03o`000?oooooooooo01cooooo0_l0000Hoooo
o`;o00006oooool2o`00053ooooo0_l0001iooooo`;o00009Oooool001kooooo00?o0000oooooooo
ool07?ooool2o`0001Sooooo0_l0000Kooooo`;o0000D?ooool2o`0000Kooooo0_l0000Dooooo`;o
00008_ooool2o`0003Oooooo0_l0000Uooooo`007_ooool00ol0003oooooooooo`03ooooo`;o0000
R?ooool2o`0001kooooo0_l0000Dooooo`;o00008_ooool2o`00033ooooo1?l0000Zooooo`007_oo
ool00ol0003oooooooooo`03ooooo`;o00004oooool2o`0007?ooooo0_l0000Hooooo`;o0000L?oo
ool4o`0000Wooooo0_l0000Oooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o0000POooool2
o`0000[ooooo0_l0001Nooooo`;o00007Oooool2o`0001oooooo000Dooooo`Co000000?o410@oooo
ooooool00oooool00ol0003oooooooooo`0Uooooo`;o0000M?ooool2o`0001oooooo0_l00019oooo
o`;o00003Oooool2o`0002oooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool09Oooool2o`0002Sooooo0_l0001[ooooo`;o00009_ooool2o`0002oooooo0ol0000Wooooo`Co
00001?ooool001Kooooo00?o0000ooooooooool01Oooool3o`0003oooooo0_l0000>ooooo`;o0000
Toooool2o`0002oooooo0_l0000Xooooo`Co00001?ooool001Kooooo00?o0000ooooooooool0Aooo
ool2o`000?oooooo1oooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0
003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Cooooo
00?oEEEEofIVI_l00000oooooomBooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.75467 .61422 Mdot
.04102 .32263 Mdot
.66276 .4097 Mdot
.02149 .36112 Mdot
.41835 .4512 Mdot
.44029 .24435 Mdot
.76342 .10043 Mdot
.03202 .09137 Mdot
.86146 .5227 Mdot
.82699 .95104 Mdot
.44914 .59404 Mdot
.83863 .92542 Mdot
.53671 .79253 Mdot
.02639 .40851 Mdot
.02033 .57007 Mdot
.16739 .19807 Mdot
.7836 .01689 Mdot
.53498 .08436 Mdot
.97079 .06401 Mdot
.58436 .8805 Mdot
.16645 .35341 Mdot
.56689 .15182 Mdot
.89842 .85556 Mdot
.82695 .38571 Mdot
.2748 .86893 Mdot
.88644 .87204 Mdot
.98441 .15997 Mdot
.93644 .48607 Mdot
.37418 .2797 Mdot
.22315 .29992 Mdot
.32108 .17934 Mdot
.77514 .30533 Mdot
.90698 .91451 Mdot
.06229 .26798 Mdot
.19563 .19762 Mdot
.12523 .03463 Mdot
.10009 .28475 Mdot
.31132 .30666 Mdot
.86402 .22809 Mdot
.50265 .66162 Mdot
.66682 .74343 Mdot
.07379 .27164 Mdot
.52807 .50087 Mdot
.46873 .74709 Mdot
.70898 .66756 Mdot
.19807 .70189 Mdot
.38861 .59753 Mdot
.96784 .74798 Mdot
.5358 .25078 Mdot
.75169 .27983 Mdot
.75025 .15734 Mdot
.39611 .79347 Mdot
.9686 .55635 Mdot
.20902 .37261 Mdot
.6159 .91936 Mdot
.89658 .46846 Mdot
.1662 .07339 Mdot
.52068 .9542 Mdot
.56918 .25497 Mdot
.42863 .31867 Mdot
.87515 .91746 Mdot
.76295 .94468 Mdot
.23907 .5554 Mdot
.45211 .31131 Mdot
.12743 .20382 Mdot
.10991 .83284 Mdot
.587 .37477 Mdot
.40999 .18747 Mdot
.65576 .24381 Mdot
.0213 .37219 Mdot
.26127 .08684 Mdot
.78507 .19264 Mdot
.08467 .125 Mdot
.16246 .20206 Mdot
.09633 .39917 Mdot
.81848 .00795 Mdot
.78084 .29729 Mdot
.53742 .31524 Mdot
.07338 .77608 Mdot
.94616 .93977 Mdot
.28426 .685 Mdot
.08793 .46923 Mdot
.25398 .46027 Mdot
.45299 .33054 Mdot
.96506 .51627 Mdot
.44805 .10437 Mdot
.01831 .95633 Mdot
.74271 .21463 Mdot
.34996 .50115 Mdot
.08958 .01942 Mdot
.44901 .53382 Mdot
.28337 .22174 Mdot
.97007 .12014 Mdot
.08395 .62592 Mdot
.90268 .48071 Mdot
.81286 .12358 Mdot
.791 .1349 Mdot
.53556 .85678 Mdot
.64628 .32743 Mdot
.81896 .77197 Mdot
.09081 .92342 Mdot
.64615 .87581 Mdot
.80074 .18862 Mdot
.50395 .8007 Mdot
.70361 .06177 Mdot
.26805 .00908 Mdot
.94271 .44093 Mdot
.33438 .06558 Mdot
.26756 .17179 Mdot
.96639 .06513 Mdot
.44153 .67875 Mdot
.00189 .12427 Mdot
.49351 .93342 Mdot
.5188 .38127 Mdot
.60136 .85709 Mdot
.20204 .81416 Mdot
.75313 .61275 Mdot
.74693 .63173 Mdot
.64803 .07935 Mdot
.21577 .78835 Mdot
.5894 .68583 Mdot
.46668 .83724 Mdot
.94429 .78234 Mdot
.32089 .53428 Mdot
.60223 .01571 Mdot
.95816 .02179 Mdot
.95047 .4172 Mdot
.65175 .3208 Mdot
.36389 .65322 Mdot
.00824 .54255 Mdot
.49795 .47159 Mdot
.6873 .98494 Mdot
.88646 .6037 Mdot
.3498 .30358 Mdot
.08698 .63018 Mdot
.95001 .57027 Mdot
.28389 .67419 Mdot
.06804 .76358 Mdot
.19335 .41261 Mdot
.35129 .24572 Mdot
.98287 .90412 Mdot
.46577 .83951 Mdot
.63821 .34755 Mdot
.68806 .69549 Mdot
.59429 .60392 Mdot
.45824 .54306 Mdot
.70345 .8479 Mdot
.326 .87934 Mdot
.58111 .01479 Mdot
.38751 .24415 Mdot
.17062 .67875 Mdot
.88925 .91361 Mdot
.07913 .56105 Mdot
.61245 .14905 Mdot
.58087 .32181 Mdot
.75953 .31404 Mdot
.76166 .93542 Mdot
.52972 .54726 Mdot
.90736 .97829 Mdot
.95993 .84159 Mdot
.4911 .10937 Mdot
.68968 .42225 Mdot
.11728 .69112 Mdot
.75248 .71308 Mdot
.92692 .9295 Mdot
.2976 .39114 Mdot
.53763 .39422 Mdot
.38591 .25061 Mdot
.59635 .61682 Mdot
.80191 .56603 Mdot
.7918 .43186 Mdot
.65282 .60102 Mdot
.49036 .48726 Mdot
.03273 .31347 Mdot
.45146 .96233 Mdot
.4181 .482 Mdot
.36087 .87667 Mdot
.26513 .25893 Mdot
.90494 .66684 Mdot
.03058 .15092 Mdot
.20859 .83231 Mdot
.97788 .43641 Mdot
.24194 .48466 Mdot
.20771 .96216 Mdot
.93489 .81136 Mdot
.06855 .5203 Mdot
.63475 .06583 Mdot
.74386 .15163 Mdot
.11073 .00835 Mdot
.61403 .7939 Mdot
.34938 .43772 Mdot
.75367 .77377 Mdot
.29886 .44889 Mdot
.77325 .23542 Mdot
.85798 .17837 Mdot
.44768 .38411 Mdot
.86669 .1705 Mdot
.22004 .68982 Mdot
.36489 .25775 Mdot
.36893 .6391 Mdot
.9847 .11893 Mdot
.94897 .72573 Mdot
.80793 .57224 Mdot
.0497 .7791 Mdot
.34616 .19712 Mdot
.47131 .45618 Mdot
.64678 .89773 Mdot
.89492 .18115 Mdot
.71258 .89843 Mdot
.74684 .27419 Mdot
.54216 .767 Mdot
.21166 .4696 Mdot
.31862 .43757 Mdot
.07288 .52723 Mdot
.73206 .76037 Mdot
.14592 .55386 Mdot
.19752 .69132 Mdot
.5315 .03777 Mdot
.69614 .66744 Mdot
.87653 .98619 Mdot
.92409 .91266 Mdot
.30624 .82698 Mdot
.50909 .32651 Mdot
.98409 .20291 Mdot
.05709 .72216 Mdot
.06868 .81966 Mdot
.18793 .08697 Mdot
.76565 .09126 Mdot
.80827 .1632 Mdot
.32677 .17161 Mdot
.22362 .3567 Mdot
.23049 .12937 Mdot
.08762 .33452 Mdot
.14005 .41846 Mdot
.74404 .85144 Mdot
.05788 .12073 Mdot
.83254 .00029 Mdot
.12637 .45035 Mdot
.50251 .10642 Mdot
.25622 .17691 Mdot
.86502 .00473 Mdot
.14152 .13579 Mdot
.79492 .49347 Mdot
.73127 .878 Mdot
.51261 .23674 Mdot
.69617 .264 Mdot
.87672 .241 Mdot
.52506 .05262 Mdot
.97229 .12036 Mdot
.30492 .73821 Mdot
.22072 .88758 Mdot
.79595 .67715 Mdot
.54845 .9995 Mdot
.59631 .40903 Mdot
.60749 .40831 Mdot
.71425 .6487 Mdot
.97412 .04776 Mdot
.10771 .47289 Mdot
.1031 .98599 Mdot
.69068 .37496 Mdot
.10373 .67806 Mdot
.34687 .78608 Mdot
.75846 .98633 Mdot
.69554 .27699 Mdot
.3562 .78574 Mdot
.0305 .76136 Mdot
.57628 .46784 Mdot
.49109 .93731 Mdot
.51864 .34512 Mdot
.12828 .25562 Mdot
.10382 .516 Mdot
.60546 .99518 Mdot
.18933 .68215 Mdot
.99812 .05831 Mdot
.35221 .55295 Mdot
.50417 .01643 Mdot
.14563 .58917 Mdot
.36009 .3431 Mdot
.42679 .18324 Mdot
.76311 .67312 Mdot
.15052 .7713 Mdot
.73624 .24596 Mdot
.83809 .32938 Mdot
.00084 .10897 Mdot
.87667 .86781 Mdot
.86313 .85708 Mdot
.45118 .1346 Mdot
.50899 .01499 Mdot
.53745 .41848 Mdot
.31086 .46678 Mdot
.22787 .05615 Mdot
.45699 .02388 Mdot
.24282 .48448 Mdot
.72245 .92725 Mdot
.19938 .91622 Mdot
.62189 .60019 Mdot
.44369 .2896 Mdot
.9536 .61024 Mdot
.25005 .25214 Mdot
.33711 .74604 Mdot
.63163 .96388 Mdot
.24224 .11142 Mdot
.58751 .74789 Mdot
.66624 .90785 Mdot
.44619 .09416 Mdot
.97564 .19419 Mdot
.99422 .93733 Mdot
.19951 .72995 Mdot
.37978 .8535 Mdot
.48213 .96901 Mdot
.34714 .46116 Mdot
.30683 .3905 Mdot
.6007 .70385 Mdot
.23789 .50771 Mdot
.32748 .80996 Mdot
.42664 .40847 Mdot
.7487 .8823 Mdot
.33982 .05554 Mdot
.77334 .80765 Mdot
.92611 .4319 Mdot
.29265 .0599 Mdot
.6126 .36358 Mdot
.78591 .37389 Mdot
.17689 .10351 Mdot
.95932 .90985 Mdot
.09709 .46775 Mdot
.78294 .92888 Mdot
.79206 .1846 Mdot
.97188 .13659 Mdot
.57858 .98566 Mdot
.36027 .2836 Mdot
.55384 .71193 Mdot
.93698 .33824 Mdot
.04692 .1837 Mdot
.34189 .07522 Mdot
.74712 .25515 Mdot
.09149 .33906 Mdot
.46166 .63997 Mdot
.47948 .33176 Mdot
.83897 .65951 Mdot
.28895 .27263 Mdot
.36929 .51148 Mdot
.15124 .83964 Mdot
.76644 .69455 Mdot
.01409 .39643 Mdot
.78793 .68398 Mdot
.93222 .41185 Mdot
.97559 .23667 Mdot
.66904 .21145 Mdot
.60758 .44358 Mdot
.38515 .84489 Mdot
.62383 .02328 Mdot
.85275 .4416 Mdot
.33996 .64627 Mdot
.51964 .68401 Mdot
.45284 .78705 Mdot
.59408 .13291 Mdot
.81842 .9571 Mdot
.79166 .57664 Mdot
.81658 .86305 Mdot
.97116 .4452 Mdot
.24634 .26476 Mdot
.82321 .55714 Mdot
.50238 .34994 Mdot
.78331 .9536 Mdot
.31068 .93669 Mdot
.01958 .46481 Mdot
.63291 .21039 Mdot
.63147 .37862 Mdot
.68661 .09528 Mdot
.03465 .62659 Mdot
.80659 .12269 Mdot
.86913 .25947 Mdot
.6167 .75555 Mdot
.20693 .59652 Mdot
.00136 .48968 Mdot
.51546 .47576 Mdot
.86343 .51981 Mdot
.27306 .90991 Mdot
.08427 .33688 Mdot
.71159 .69197 Mdot
.56384 .38631 Mdot
.84043 .88373 Mdot
.64157 .05687 Mdot
.85698 .39357 Mdot
.11273 .19501 Mdot
.80825 .89497 Mdot
.27739 .55977 Mdot
.1587 .23085 Mdot
.26598 .21412 Mdot
.98549 .14912 Mdot
.38749 .6856 Mdot
.39079 .57395 Mdot
.67791 .39753 Mdot
.31571 .94191 Mdot
.23092 .44986 Mdot
.65636 .39771 Mdot
.91466 .11225 Mdot
.94764 .73134 Mdot
.82918 .40217 Mdot
.68515 .31102 Mdot
.24539 .37034 Mdot
.5491 .06819 Mdot
.08372 .80964 Mdot
.25736 .28529 Mdot
.5574 .23091 Mdot
.84847 .50056 Mdot
.24465 .95977 Mdot
.30245 .88939 Mdot
.20134 .62774 Mdot
.5034 .33794 Mdot
.56829 .15061 Mdot
.94907 .16326 Mdot
.08626 .64101 Mdot
.30938 .21836 Mdot
.88979 .00931 Mdot
.8165 .85493 Mdot
.39515 .64042 Mdot
.92489 .48532 Mdot
.04339 .8775 Mdot
.69734 .38997 Mdot
.69718 .04647 Mdot
.09799 .89695 Mdot
.18601 .08713 Mdot
.23201 .95778 Mdot
.24213 .31546 Mdot
.2449 .85025 Mdot
.17755 .23893 Mdot
.20789 .79234 Mdot
.61664 .45817 Mdot
.19416 .50445 Mdot
.3905 .7479 Mdot
.65543 .97262 Mdot
.65901 .51462 Mdot
.33049 .19995 Mdot
.55712 .63441 Mdot
.24466 .14165 Mdot
.47572 .46934 Mdot
.87205 .45282 Mdot
.14753 .10155 Mdot
.42386 .45012 Mdot
.41115 .48175 Mdot
.09823 .73717 Mdot
.16799 .94701 Mdot
.62497 .56816 Mdot
.36747 .26522 Mdot
.097 .54393 Mdot
.63312 .77004 Mdot
.08706 .59568 Mdot
.19516 .45154 Mdot
.00981 .28322 Mdot
.88965 .57201 Mdot
.49363 .67761 Mdot
.54257 .93113 Mdot
.21863 .08972 Mdot
.58729 .07987 Mdot
.7482 .25241 Mdot
.41528 .72911 Mdot
.78356 .55453 Mdot
.62099 .82633 Mdot
.56534 .21195 Mdot
.19698 .19173 Mdot
.60583 .05732 Mdot
.19735 .77983 Mdot
.00133 .20038 Mdot
.7966 .01928 Mdot
.66646 .22813 Mdot
.39134 .03099 Mdot
.04554 .05974 Mdot
.06302 .18896 Mdot
.43816 .28281 Mdot
.58163 .48837 Mdot
.73876 .02598 Mdot
.16752 .22088 Mdot
.20106 .15401 Mdot
.84935 .63285 Mdot
.0116 .83031 Mdot
.20379 .77577 Mdot
.20929 .744 Mdot
.72014 .90699 Mdot
.34767 .8136 Mdot
.6612 .53942 Mdot
.79976 .36004 Mdot
.27618 .89213 Mdot
.20253 .21547 Mdot
.95661 .509 Mdot
.82827 .18288 Mdot
.02518 .0703 Mdot
.66696 .20996 Mdot
.99956 .4121 Mdot
.25724 .57931 Mdot
.43897 .40977 Mdot
.06018 .04934 Mdot
.61734 .03927 Mdot
.23336 .48737 Mdot
.56191 .96375 Mdot
.15702 .17537 Mdot
.73012 .31091 Mdot
.55237 .05446 Mdot
.6207 .38862 Mdot
.75356 .78437 Mdot
.51225 .14043 Mdot
.37171 .95507 Mdot
.20865 .57303 Mdot
.12277 .14987 Mdot
.45382 .47155 Mdot
.05949 .50039 Mdot
.75293 .66624 Mdot
.6493 .17547 Mdot
.08562 .16242 Mdot
.99305 .94207 Mdot
.60465 .61375 Mdot
.4086 .33521 Mdot
.99328 .58883 Mdot
.89443 .2502 Mdot
.9257 .13671 Mdot
.59283 .28591 Mdot
.70695 .53402 Mdot
.76868 .88182 Mdot
.81546 .08556 Mdot
.18493 .82239 Mdot
.65397 .02079 Mdot
.1064 .71665 Mdot
.15411 .24666 Mdot
.8443 .2625 Mdot
.04745 .54306 Mdot
.87754 .79116 Mdot
.29538 .24499 Mdot
.07163 .69825 Mdot
.68618 .81868 Mdot
.2104 .73094 Mdot
.72115 .55807 Mdot
.17175 .03543 Mdot
.90655 .60761 Mdot
.91392 .17458 Mdot
.81918 .47688 Mdot
.881 .79119 Mdot
.63468 .07466 Mdot
.15686 .1613 Mdot
.57742 .81019 Mdot
.81397 .6152 Mdot
.90101 .1452 Mdot
.54155 .70777 Mdot
.12693 .4275 Mdot
.53302 .90985 Mdot
.36312 .68277 Mdot
.66671 .57163 Mdot
.39117 .03565 Mdot
.74973 .62643 Mdot
.9321 .04575 Mdot
.72527 .60246 Mdot
.23191 .36532 Mdot
.98711 .21977 Mdot
.43134 .41034 Mdot
.3071 .33796 Mdot
.23443 .11598 Mdot
.93655 .55782 Mdot
.97509 .33461 Mdot
.38838 .89217 Mdot
.44981 .15855 Mdot
.58229 .09075 Mdot
.6249 .22354 Mdot
.97702 .29175 Mdot
.16383 .03418 Mdot
.87453 .95479 Mdot
.84024 .79825 Mdot
.62968 .5124 Mdot
.75728 .83898 Mdot
.55215 .11056 Mdot
.99007 .36907 Mdot
.24501 .36186 Mdot
.43187 .12105 Mdot
.93868 .15238 Mdot
.90929 .65297 Mdot
.13928 .95599 Mdot
.65222 .75868 Mdot
.18985 .87991 Mdot
.8225 .16462 Mdot
.30155 .24013 Mdot
.25562 .43815 Mdot
.87392 .25458 Mdot
.15145 .19453 Mdot
.45506 .02429 Mdot
.75039 .98679 Mdot
.59959 .83143 Mdot
.7752 .17011 Mdot
.68224 .93563 Mdot
.9533 .5467 Mdot
.67 .9546 Mdot
.15553 .25144 Mdot
.28943 .89538 Mdot
.05412 .91571 Mdot
.48279 .48882 Mdot
.81935 .84836 Mdot
.92288 .51103 Mdot
.22014 .79681 Mdot
.46514 .89253 Mdot
.38613 .47282 Mdot
.92482 .78369 Mdot
.23345 .0927 Mdot
.05265 .95134 Mdot
.24197 .99707 Mdot
.93808 .26589 Mdot
.98596 .24781 Mdot
.64881 .61919 Mdot
.3657 .49642 Mdot
.45439 .8886 Mdot
.30453 .55223 Mdot
.07602 .14635 Mdot
.80973 .98759 Mdot
.46334 .16388 Mdot
.69066 .98639 Mdot
.16398 .26443 Mdot
.60186 .8374 Mdot
.39891 .15517 Mdot
.48413 .77879 Mdot
.68875 .71175 Mdot
.30538 .37665 Mdot
.00139 .72019 Mdot
.90573 .66692 Mdot
.78191 .38584 Mdot
.23622 .5313 Mdot
.50178 .14477 Mdot
.42434 .621 Mdot
.07317 .00505 Mdot
.93404 .57233 Mdot
.88014 .93687 Mdot
.31253 .66708 Mdot
.36598 .34013 Mdot
.17985 .34909 Mdot
.1059 .5062 Mdot
.12446 .47614 Mdot
.19061 .28895 Mdot
.01483 .82508 Mdot
.87738 .99262 Mdot
.8122 .32335 Mdot
.86546 .84687 Mdot
.71823 .58708 Mdot
.80253 .1181 Mdot
.16708 .8235 Mdot
.63249 .86062 Mdot
.1998 .51125 Mdot
.31575 .50538 Mdot
.78434 .85905 Mdot
.99352 .07449 Mdot
.68416 .83513 Mdot
.3128 .20447 Mdot
.99121 .59045 Mdot
.52341 .18473 Mdot
.16291 .83188 Mdot
.60106 .89536 Mdot
.13751 .21826 Mdot
.09852 .8345 Mdot
.81802 .9283 Mdot
.58036 .49584 Mdot
.08089 .83792 Mdot
.4933 .33829 Mdot
.57309 .19319 Mdot
.3103 .271 Mdot
.50718 .50578 Mdot
.79705 .99371 Mdot
.07976 .47821 Mdot
.10887 .93075 Mdot
.15444 .34607 Mdot
.18076 .88319 Mdot
.16989 .38894 Mdot
.78069 .22265 Mdot
.2724 .58677 Mdot
.2413 .03072 Mdot
.4833 .26827 Mdot
.08764 .55455 Mdot
.23866 .576 Mdot
.43412 .81991 Mdot
.95209 .24035 Mdot
.06897 .71504 Mdot
.92986 .65419 Mdot
.75347 .73435 Mdot
.6103 .23755 Mdot
.08904 .70934 Mdot
.52119 .72341 Mdot
.65816 .81301 Mdot
.81055 .46004 Mdot
.42777 .08733 Mdot
.77626 .69971 Mdot
.19852 .15558 Mdot
.66482 .585 Mdot
.96986 .55913 Mdot
.90383 .054 Mdot
.36198 .69409 Mdot
.10917 .72805 Mdot
.16807 .08471 Mdot
.79067 .82889 Mdot
.66213 .37076 Mdot
.87617 .25402 Mdot
.4032 .45004 Mdot
.17754 .38316 Mdot
.08488 .17072 Mdot
.69117 .62321 Mdot
.27344 .45081 Mdot
.88318 .70454 Mdot
.76477 .98976 Mdot
.68424 .18597 Mdot
.42471 .69562 Mdot
.89373 .51327 Mdot
.92232 .45957 Mdot
.9591 .10111 Mdot
.68111 .15638 Mdot
.54687 .5439 Mdot
.48411 .13858 Mdot
.02332 .01667 Mdot
.36811 .48283 Mdot
.28788 .18824 Mdot
.47574 .72046 Mdot
.56789 .89643 Mdot
.89788 .82641 Mdot
.41621 .51994 Mdot
.14827 .27181 Mdot
.58487 .28823 Mdot
.24634 .22829 Mdot
.90216 .62909 Mdot
.91776 .99841 Mdot
.73674 .71083 Mdot
.72684 .32613 Mdot
.59036 .65065 Mdot
.42269 .80488 Mdot
.20862 .99201 Mdot
.5694 .79046 Mdot
.57019 .35793 Mdot
.58173 .76367 Mdot
.1145 .21791 Mdot
.27521 .41355 Mdot
.0772 .45637 Mdot
.05443 .61813 Mdot
.49847 .65222 Mdot
.2234 .0827 Mdot
.85098 .78894 Mdot
.04693 .2015 Mdot
.79727 .87516 Mdot
.62065 .52087 Mdot
.40761 .42731 Mdot
.19792 .88853 Mdot
.43378 .3557 Mdot
.82991 .33305 Mdot
.12718 .01912 Mdot
.84813 .91533 Mdot
.7244 .323 Mdot
.42738 .63926 Mdot
.82593 .69608 Mdot
.45835 .35777 Mdot
.18542 .93024 Mdot
.74251 .96916 Mdot
.63185 .63125 Mdot
.76625 .2386 Mdot
.42305 .09605 Mdot
.78207 .03475 Mdot
.38237 .21233 Mdot
.99821 .19971 Mdot
.45776 .01767 Mdot
.43976 .38783 Mdot
.482 .24993 Mdot
.08625 .87245 Mdot
.5503 .43508 Mdot
.23841 .0672 Mdot
.80082 .02185 Mdot
.3764 .73176 Mdot
.56051 .81901 Mdot
.78964 .86529 Mdot
.34053 .4458 Mdot
.64039 .52774 Mdot
.7645 .57938 Mdot
.35476 .28524 Mdot
.01907 .17417 Mdot
.09407 .17131 Mdot
.29412 .82815 Mdot
.03521 .30957 Mdot
.71391 .66132 Mdot
.44071 .39531 Mdot
.99058 .08635 Mdot
.46373 .76439 Mdot
.84317 .7435 Mdot
.98588 .11735 Mdot
.97867 .29387 Mdot
.41621 .03234 Mdot
.90775 .99723 Mdot
.51893 .89336 Mdot
.38795 .26345 Mdot
.60928 .78434 Mdot
.87132 .43859 Mdot
.34632 .13202 Mdot
.96847 .33962 Mdot
.65092 .30115 Mdot
.95143 .76754 Mdot
.90756 .33587 Mdot
.02629 .58194 Mdot
.29959 .25411 Mdot
.00719 .55289 Mdot
.93835 .50193 Mdot
.49864 .32819 Mdot
.09938 .90161 Mdot
.79471 .69992 Mdot
.95373 .53436 Mdot
.70142 .26953 Mdot
.40139 .11235 Mdot
.90272 .66059 Mdot
.65387 .92766 Mdot
.71947 .92287 Mdot
.53478 .79313 Mdot
.47462 .23069 Mdot
.71804 .15193 Mdot
.18414 .98314 Mdot
.50394 .37975 Mdot
.52511 .08209 Mdot
.36305 .68149 Mdot
.61635 .76157 Mdot
.19882 .71588 Mdot
.94523 .20979 Mdot
.31005 .7102 Mdot
.05694 .2159 Mdot
.96824 .01962 Mdot
.50526 .80219 Mdot
.39329 .76835 Mdot
.52214 .00138 Mdot
.82576 .21172 Mdot
.13251 .00776 Mdot
.46049 .37108 Mdot
.5164 .42872 Mdot
.19208 .73766 Mdot
.4854 .01735 Mdot
.9716 .28054 Mdot
.53161 .96517 Mdot
.85756 .33683 Mdot
.90291 .00665 Mdot
.64414 .76456 Mdot
.57058 .91318 Mdot
.70746 .38932 Mdot
.27686 .0338 Mdot
.32844 .96169 Mdot
.91136 .84611 Mdot
.0205 .98062 Mdot
.21796 .67416 Mdot
.09867 .85491 Mdot
.85577 .8002 Mdot
.18172 .36908 Mdot
.85036 .68167 Mdot
.69222 .68011 Mdot
.43292 .6788 Mdot
.86767 .40978 Mdot
.9127 .78134 Mdot
.42961 .40668 Mdot
.95508 .07413 Mdot
.26534 .52694 Mdot
.52221 .33896 Mdot
.91869 .84828 Mdot
.74629 .61939 Mdot
.61104 .29815 Mdot
.80605 .03492 Mdot
.04871 .42221 Mdot
.24743 .21276 Mdot
.33299 .17997 Mdot
.46663 .37258 Mdot
.84874 .66247 Mdot
.39715 .38244 Mdot
.72404 .93853 Mdot
.72247 .97821 Mdot
.69117 .22471 Mdot
.0899 .21332 Mdot
.92158 .98677 Mdot
.04632 .27087 Mdot
.99656 .45958 Mdot
.69365 .85138 Mdot
.81575 .41992 Mdot
.41505 .36571 Mdot
.79395 .95806 Mdot
.82482 .11566 Mdot
.27222 .79597 Mdot
.28369 .21845 Mdot
.53138 .79315 Mdot
.4238 .93752 Mdot
.42091 .86827 Mdot
.13201 .83083 Mdot
.53564 .28662 Mdot
.58618 .77221 Mdot
.85038 .73163 Mdot
.06633 .30968 Mdot
.87968 .92752 Mdot
.09832 .38896 Mdot
.78614 .98486 Mdot
.06019 .25449 Mdot
.4726 .06615 Mdot
.51606 .24859 Mdot
.88858 .38164 Mdot
.48192 .62306 Mdot
.51621 .18329 Mdot
.78279 .61671 Mdot
.45108 .34586 Mdot
.73005 .20319 Mdot
.76012 .49645 Mdot
.59502 .97716 Mdot
.82672 .5798 Mdot
.6243 .85672 Mdot
.23699 .37929 Mdot
.9481 .50759 Mdot
.52061 .92134 Mdot
.61816 .04292 Mdot
.90259 .87561 Mdot
.72193 .54739 Mdot
.22206 .40808 Mdot
.94627 .22188 Mdot
.60037 .83941 Mdot
.32224 .36296 Mdot
.91624 .061 Mdot
.87508 .3652 Mdot
.52527 .81142 Mdot
.80427 .79968 Mdot
.10691 .81081 Mdot
.37107 .61562 Mdot
.10108 .02158 Mdot
.5644 .26852 Mdot
.79316 .77678 Mdot
.64349 .8838 Mdot
.01226 .87909 Mdot
.12671 .66415 Mdot
.21612 .58608 Mdot
.1395 .41886 Mdot
.51325 .02887 Mdot
.48627 .44581 Mdot
.12179 .38788 Mdot
.97122 .72483 Mdot
.93795 .19184 Mdot
.55738 .64065 Mdot
.27118 .51719 Mdot
.83393 .57523 Mdot
.19395 .87121 Mdot
.7894 .71777 Mdot
.14554 .05548 Mdot
.62143 .40668 Mdot
.41716 .86629 Mdot
.22024 .74402 Mdot
.37461 .61298 Mdot
.08265 .23298 Mdot
.36378 .36971 Mdot
.6744 .7521 Mdot
.24345 .91848 Mdot
.73219 .09622 Mdot
.21262 .91724 Mdot
.03339 .48622 Mdot
.26527 .06966 Mdot
.32663 .25274 Mdot
.63188 .05459 Mdot
.30705 .35765 Mdot
.42063 .23835 Mdot
.90963 .26486 Mdot
.98758 .70794 Mdot
.19829 .56756 Mdot
.91153 .96545 Mdot
.58173 .39671 Mdot
.84584 .85344 Mdot
.40385 .99298 Mdot
.77624 .88483 Mdot
.30815 .58657 Mdot
.24486 .70987 Mdot
.20124 .41277 Mdot
.93639 .40895 Mdot
.96827 .00064 Mdot
.74567 .86109 Mdot
.65708 .28596 Mdot
.74767 .72624 Mdot
.14962 .65964 Mdot
.73019 .05152 Mdot
.6184 .89165 Mdot
.11066 .03027 Mdot
.49604 .13537 Mdot
.06162 .43045 Mdot
.43989 .88747 Mdot
.98238 .90772 Mdot
.25763 .98459 Mdot
.25035 .90066 Mdot
.45088 .53839 Mdot
.6894 .30146 Mdot
.4706 .91306 Mdot
.82588 .3626 Mdot
.72496 .01367 Mdot
.54549 .19894 Mdot
.44953 .70035 Mdot
.6645 .89655 Mdot
.93229 .02397 Mdot
.56205 .85835 Mdot
.74188 .1926 Mdot
.40964 .78515 Mdot
.101 .49892 Mdot
.84273 .59822 Mdot
.82191 .73118 Mdot
.22132 .34313 Mdot
.23117 .54345 Mdot
.54016 .32137 Mdot
.88669 .70944 Mdot
.76499 .54603 Mdot
.77004 .94257 Mdot
.05156 .46774 Mdot
.93711 .88212 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo0_l00004ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`;o00002Oooool00ol0003o
ooooooooo`02ooooo`007_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo
0_l00007ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`04o`000?ooooooooooooooo`;o00002_ooool2o`0000kooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o0000
2_ooool2o`0000Gooooo0_l0000Zooooo`;o0000/Oooool2o`0000gooooo0_l00006ooooo`;o0000
0_ooool2o`0002Cooooo000Nooooo`03o`000?oooooooooo023ooooo0_l00005ooooo`;o0000:_oo
ool2o`0009?ooooo0_l0000Looooo`;o00005Oooool2o`0002Sooooo000Nooooo`03o`000?oooooo
oooo00?ooooo0_l0002Kooooo`?o00005_ooool2o`0000Gooooo0_l0000Vooooo`;o0000GOooool0
01kooooo00?o0000ooooooooool00oooool2o`0001Cooooo0_l0000:ooooo`;o0000J_ooool2o`00
00Oooooo0_l00004ooooo`?o00005_ooool2o`0000Gooooo0_l0000iooooo`;o00000_ooool2o`00
03Kooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o00000_ooool2o`0000Ko
oooo0_l0001Zooooo`;o00001oooool2o`0003Cooooo0_l0000Yooooo`;o00000_ooool3o`00037o
oooo0_l00002ooooo`;o00003_ooool001kooooo00?o0000ooooooooool07Oooool2o`00077ooooo
0_l0000eooooo`;o00001oooool2o`0001[ooooo0_l0000Booooo`;o0000:Oooool2o`0000Kooooo
0_l0000Booooo`007_ooool00ol0003oooooooooo`2@ooooo`;o00004Oooool2o`0002;ooooo0_l0
000Sooooo`;o0000?Oooool2o`0001[ooooo000Nooooo`03o`000?oooooooooo023ooooo0_l0000X
ooooo`;o0000;oooool2o`0002Kooooo0_l0002Rooooo`007_ooool00ol0003oooooooooo`0Poooo
o`;o00000oooool2o`0000[ooooo0_l0000Gooooo`;o00002_ooool2o`0002?ooooo0_l00006oooo
o`;o0000MOooool2o`0000Kooooo0_l00013ooooo`007_ooool00ol0003oooooooooo`0Uooooo`;o
00002_ooool2o`000003ooooool0003o0000023ooooo0_l0000Sooooo`;o00001_ooool2o`0002Co
oooo0_l0001?ooooo`;o00001_ooool2o`0004?ooooo000Nooooo`03o`000?oooooooooo03Cooooo
0_l00015ooooo`;o0000;?ooool2o`0001[ooooo0_l00020ooooo`007_ooool00ol0003ooooooooo
o`35ooooo`;o0000P?ooool001kooooo00?o0000ooooooooool0aOooool2o`0001Sooooo0_l0001:
ooooo`;o00006_ooool001kooooo00?o0000ooooooooool03oooool2o`000<kooooo0_l0001:oooo
o`;o00003?ooool2o`0000cooooo000Nooooo`;o00004?ooool2o`0009Kooooo0_l00010ooooo`;o
0000C_ooool2o`0000cooooo000Nooooo`03o`000?oooooooooo02_ooooo0_l0000Iooooo`;o0000
8_ooool2o`0003_ooooo0_l00006ooooo`;o00006?ooool2o`0001kooooo0_l0000gooooo`;o0000
8oooool001kooooo00?o0000ooooooooool02oooool2o`0001kooooo0_l0000Iooooo`;o00008_oo
ool2o`0004?ooooo0_l0000@ooooo`;o00001_ooool2o`000003ooooool0003o000005Cooooo0_l0
000Looooo`;o00001Oooool001kooooo00?o0000ooooooooool02oooool2o`0004kooooo0_l0001T
ooooo`;o00002Oooool2o`0001?ooooo0_l00013ooooo`;o00006?ooool2o`0000Gooooo000Noooo
o`03o`000?oooooooooo05_ooooo0_l0000<ooooo`;o0000Goooool2o`0001Gooooo0_l00013oooo
o`;o00003_ooool4o`0000gooooo000Nooooo`03o`000?oooooooooo04Wooooo0_l0000Nooooo`;o
0000:oooool2o`0001Kooooo0_l0000Jooooo`;o0000J_ooool4o`0000gooooo000Nooooo`03o`00
0?oooooooooo00Cooooo0_l00013ooooo`;o00001oooool2o`0004;ooooo0_l0000Fooooo`;o0000
Uoooool001kooooo00?o0000ooooooooool01?ooool2o`0002cooooo0_l0000Nooooo`;o00005ooo
ool2o`0005gooooo0_l0001Vooooo`;o00002oooool2o`0000Kooooo000Nooooo`03o`000?oooooo
oooo03;ooooo0_l0000gooooo`;o0000GOooool2o`0006Kooooo0_l0000;ooooo`;o00001_ooool0
01kooooo00?o0000ooooooooool0^oooool2o`0001;ooooo0_l0001fooooo`007_ooool00ol0003o
ooooooooo`15ooooo`;o0000H?ooool2o`000003ooooool0003o000000oooooo0_l0000Booooo`;o
0000M_ooool001kooooo00?o0000ooooooooool0<oooool2o`0000?ooooo0ol0000:ooooo`;o0000
2_ooool2o`0003Cooooo0_l0000Nooooo`;o000000?oooooo`000?l00000FOooool2o`0003Oooooo
0_l00007ooooo`007_ooool00ol0003oooooooooo`0cooooo`;o00000oooool3o`0000Sooooo0_l0
000<ooooo`;o0000=?ooool2o`0007cooooo0_l0000gooooo`;o00001oooool001kooooo00?o0000
ooooooooool01_ooool2o`0003_ooooo0_l00003ooooo`;o0000Koooool2o`0003[ooooo0_l0001@
ooooo`007_ooool00ol0003oooooooooo`06ooooo`;o0000@?ooool2o`0003_ooooo0_l00006oooo
o`;o0000:_ooool2o`00023ooooo0_l0000=ooooo`;o00002Oooool2o`00053ooooo000Nooooo`03
o`000?oooooooooo08Gooooo0_l00006ooooo`;o0000C?ooool2o`0000gooooo0_l0001Kooooo`00
7_ooool2o`0002gooooo0_l00036ooooo`;o0000?_ooool2o`00017ooooo000Nooooo`03o`000?oo
oooooooo02cooooo0_l00007ooooo`;o0000Eoooool2o`0006Cooooo0_l0000nooooo`;o00004Ooo
ool001gooooo0_l0000gooooo`;o0000Eoooool2o`0000oooooo0_l0002Vooooo`007Oooool2o`00
04gooooo0_l0001?ooooo`;o000000?oooooo`000?l000003_ooool2o`0009Kooooo000Nooooo`03
o`000?oooooooooo04_ooooo0_l0000aooooo`;o00007?ooool2o`00017ooooo0_l0001dooooo`;o
00008?ooool001kooooo00?o0000ooooooooool0B?ooool2o`0003Cooooo0_l00021ooooo`;o0000
1Oooool2o`0001_ooooo0_l0000Eooooo`;o00002Oooool001kooooo00?o0000ooooooooool03ooo
ool2o`0003Oooooo0_l0000nooooo`;o0000Moooool2o`0000Gooooo0_l0000]ooooo`?o00000_oo
ool2o`0000Wooooo000Mooooo`;o00004Oooool2o`0007Oooooo0_l0001hooooo`Co0000<Oooool3
o`0000;ooooo0_l00009ooooo`007Oooool2o`0001Wooooo0_l0003Yooooo`Co0000@Oooool001ko
oooo00?o0000ooooooooool05oooool2o`0002kooooo0_l0003nooooo`007_ooool00ol0003ooooo
ooooo`17ooooo`;o00008oooool2o`0004oooooo0_l00028ooooo`007_ooool00ol0003ooooooooo
o`0Zooooo`;o0000@?ooool2o`00027ooooo0_l0000<ooooo`;o00007_ooool2o`0003kooooo0_l0
000Zooooo`;o00003Oooool2o`0000gooooo000Nooooo`03o`000?oooooooooo02[ooooo0_l0001S
ooooo`;o00002?ooool2o`0000;ooooo0_l0001Nooooo`;o0000:_ooool2o`0000gooooo0_l0000=
ooooo`007_ooool00ol0003oooooooooo`1;ooooo`;o0000C?ooool2o`0000Oooooo0_l0002Soooo
o`007_ooool00ol0003oooooooooo`1;ooooo`;o0000D_ooool2o`000003ooooool0003o000007go
oooo0_l0000Tooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o0000R?ooool2o`0002;ooooo
0_l0001Looooo`;o00009?ooool001kooooo0_l00007ooooo`;o00003Oooool2o`0000gooooo0_l0
002>ooooo`?o00003?ooool2o`00023ooooo0_l00007ooooo`;o0000C?ooool2o`0000Wooooo000N
ooooo`03o`000?oooooooooo00Kooooo0_l0000Looooo`;o00005oooool2o`0003oooooo0_l0000d
ooooo`?o0000;_ooool2o`0000Oooooo0_l0000mooooo`;o00003Oooool2o`0000Wooooo000Noooo
o`03o`000?oooooooooo03cooooo0ol0000oooooo`;o0000FOooool2o`0001Gooooo0_l0000koooo
o`;o00006?ooool001kooooo00?o0000ooooooooool0;oooool2o`0000_ooooo0_l0001@ooooo`;o
0000BOooool2o`0001Gooooo0_l0001:ooooo`;o00002Oooool001kooooo00?o0000ooooooooool0
6?ooool2o`0001Gooooo0_l0001Mooooo`;o00000oooool2o`0006kooooo0_l0000[ooooo`;o0000
2_ooool2o`0000Wooooo000Nooooo`03o`000?oooooooooo01Sooooo0_l0001iooooo`;o0000K_oo
ool2o`0000;ooooo0_l0000Wooooo`;o00005Oooool001kooooo00?o0000ooooooooool0n?ooool2
o`0000gooooo0_l0000=ooooo`;o0000;oooool001kooooo00?o0000ooooooooool05oooool2o`00
0003ooooool0003o000003Oooooo0_l0000Aooooo`;o0000T?ooool2o`0001cooooo0_l0000_oooo
o`007_ooool00ol0003oooooooooo`02ooooo`;o00004oooool2o`000003ooooool0003o000001?o
oooo0_l0000Rooooo`;o00004Oooool2o`0006Oooooo0_l0001Dooooo`;o00008?ooool001kooooo
00?o0000ooooooooool00_ooool2o`0002_ooooo0_l0000Nooooo`;o00004oooool2o`0006Wooooo
0_l00012ooooo`;o00004?ooool2o`00023ooooo000Nooooo`03o`000?oooooooooo04oooooo0_l0
000Cooooo`;o00000_ooool2o`0009oooooo0_l00008ooooo`;o00002_ooool2o`0002Kooooo000N
ooooo`03o`000?oooooooooo00_ooooo0_l0001Kooooo`;o00007Oooool2o`0001_ooooo1?l0000b
ooooo`;o00008Oooool2o`0000[ooooo0_l0000Dooooo`;o00009_ooool001kooooo00?o0000oooo
ooooool02oooool2o`0000?ooooo0_l00017ooooo`;o00009_ooool2o`0000Cooooo0_l0000Koooo
o`Co0000<_ooool2o`00027ooooo0_l000000ooooooo0000o`000015ooooo`007_ooool00ol0003o
ooooooooo`0@ooooo`;o0000:_ooool2o`0001_ooooo0_l0000Vooooo`;o0000OOooool2o`0002_o
oooo0_l0000Hooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go
00001_ooool00ol0003oooooooooo`0Qooooo`;o00002_ooool2o`0000gooooo0_l0001hooooo`;o
0000=Oooool2o`0000cooooo0_l0000`ooooo`;o00002_ooool2o`0000cooooo0003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006oooo
o`03o`000?oooooooooo027ooooo0_l0000:ooooo`;o00000oooool2o`0000Oooooo0_l0000_oooo
o`;o0000B?ooool2o`0003Gooooo0_l0000<ooooo`;o0000??ooool2o`0000cooooo0003ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP06ooooo`Co0000<_ooool2o`00
00Oooooo0_l0000Zooooo`;o00000oooool2o`0003oooooo0_l0002Aooooo`;o00001Oooool000?o
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Gooooo0_l0000=oooo
o`;o00006?ooool2o`0000[ooooo0_l0000dooooo`;o0000A?ooool2o`0003[ooooo0_l0001Aoooo
o`;o00000_ooool2o`0000Gooooo0003ooooo`05o`000?ooooooooooooooool000003_ooool00omg
MgOoIVIVooooo`05ooooo`03o`000?oooooooooo00_ooooo0_l0000Hooooo`;o00002_ooool2o`00
02oooooo0_l00025ooooo`;o0000DOooool2o`0000Wooooo0003ooooo`05oa0@4?oooooooooooooo
ool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06;ooooo0_l0001Voooo
o`;o00002Oooool2o`0005Sooooo0_l0000Fooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo01Wooooo0_l0000a
ooooo`;o0000:_ooool2o`0003[ooooo0_l0000Dooooo`;o00002Oooool2o`00037ooooo0_l0000U
ooooo`;o00005_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0>ooooo`;o00002Oooool2o`0002?ooooo0_l0
000<ooooo`;o00001?ooool2o`0002Cooooo0_l0000jooooo`;o00007oooool2o`0001Kooooo0_l0
000Iooooo`;o0000?Oooool001kooooo00?o0000ooooooooool03_ooool2o`00017ooooo0_l00006
ooooo`;o00004oooool2o`0001;ooooo0_l00004ooooo`;o00001_ooool2o`0008_ooooo0_l0001>
ooooo`;o00002?ooool001kooooo00?o0000ooooooooool08Oooool2o`0000Kooooo0_l00007oooo
o`;o00009?ooool2o`0000Kooooo0_l0002Hooooo`;o0000=?ooool2o`0000_ooooo0_l00008oooo
o`007_ooool00ol0003oooooooooo`0booooo`;o00009?ooool2o`0006gooooo0_l0000Dooooo`;o
00006oooool2o`0003Cooooo0_l0000Eooooo`007_ooool00ol0003oooooooooo`1<ooooo`;o0000
NOooool2o`0000cooooo0_l00006ooooo`;o0000=_ooool2o`00033ooooo000Nooooo`03o`000?oo
oooooooo02oooooo0_l0000Kooooo`;o0000B?ooool2o`0001Wooooo0_l0000Rooooo`;o0000?_oo
ool2o`00033ooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0000Fooooo`;o0000IOooool2
o`0001Wooooo0_l0002Dooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o0000R_ooool2o`00
01gooooo0_l0000cooooo`;o0000@?ooool2o`0000cooooo000Nooooo`03o`000?oooooooooo03Ko
oooo0_l0000Vooooo`;o00009Oooool2o`0001cooooo0_l0000Mooooo`;o0000<Oooool4o`00023o
oooo0_l0000Fooooo`;o00001_ooool2o`0000cooooo000Nooooo`03o`000?oooooooooo03Kooooo
0_l0000Vooooo`;o00006_ooool2o`0000Wooooo0_l00004ooooo`;o0000A?ooool2o`0002;ooooo
0_l0000Rooooo`;o00005_ooool2o`0001Cooooo000Nooooo`03o`000?oooooooooo02kooooo0_l0
000/ooooo`;o00004?ooool2o`0000[ooooo0_l0000?ooooo`;o0000A?ooool2o`0001Sooooo0_l0
001Jooooo`007_ooool00ol0003oooooooooo`0^ooooo`;o0000;?ooool2o`00013ooooo0_l0000Y
ooooo`;o00002Oooool2o`0004Gooooo0_l0000booooo`;o00006oooool2o`0000Wooooo000Noooo
o`;o0000;oooool2o`0001gooooo0_l0000Gooooo`;o00004Oooool2o`0001kooooo0_l00009oooo
o`;o00001?ooool2o`0004?ooooo0_l0000^ooooo`;o00006oooool2o`0000Wooooo000Nooooo`03
o`000?oooooooooo00oooooo0_l0000Eooooo`;o00001_ooool2o`0001gooooo0_l0000>ooooo`;o
00001oooool2o`00017ooooo0_l0000_ooooo`;o00002Oooool2o`0003Sooooo0_l0000Wooooo`?o
0000;?ooool001kooooo00?o0000ooooooooool03oooool2o`0001Gooooo0_l0000Zooooo`;o0000
2Oooool2o`0001Cooooo0_l00010ooooo`;o0000>?ooool2o`0002Gooooo1Ol0000/ooooo`007_oo
ool00ol0003oooooooooo`1Booooo`;o00007oooool2o`0009Wooooo0_l00006ooooo`;o0000;ooo
ool001kooooo00?o0000ooooooooool0<Oooool2o`0001Wooooo0_l0000Uooooo`;o00001Oooool2
o`0006;ooooo0_l0000^ooooo`;o00005?ooool2o`0000Oooooo0_l0000Hooooo`007_ooool00ol0
003oooooooooo`0@ooooo`;o00007oooool2o`0001Wooooo0_l0000Uooooo`;o00001Oooool2o`00
01gooooo0_l0000Hooooo`;o0000:Oooool2o`0004Cooooo0_l00007ooooo`;o00006?ooool001ko
oooo00?o0000ooooooooool02oooool2o`0000?ooooo0_l00002ooooo`;o00005_ooool2o`0003?o
oooo0_l0000fooooo`;o00006?ooool2o`0002_ooooo0_l0001Uooooo`007_ooool00ol0003ooooo
ooooo`0;ooooo`;o00001oooool2o`0001Kooooo0_l0000/ooooo`;o00001Oooool2o`0007gooooo
0_l0000=ooooo`;o0000E_ooool001kooooo00?o0000ooooooooool0F_ooool2o`0008;ooooo0_l0
000?ooooo`;o0000E_ooool001kooooo00?o0000ooooooooool0M_ooool2o`0006Kooooo0_l0000@
ooooo`;o0000A_ooool2o`0000gooooo000Nooooo`04o`000?oooooo0000o`00073ooooo0_l00003
ooooo`;o00004_ooool2o`0006Cooooo0_l00016ooooo`;o00003Oooool001kooooo00Co0000oooo
ool0003o00006oooool2o`0003;ooooo0_l0000Mooooo`Co00005oooool2o`0001kooooo0_l0000A
ooooo`;o00004oooool2o`0007?ooooo000Nooooo`03o`000?oooooooooo01cooooo0_l0000Loooo
o`;o00005?ooool2o`0001gooooo0_l0000Kooooo`;o00007?ooool2o`0000kooooo0_l000000ooo
oooo0000o`00000Cooooo`;o0000Loooool001kooooo00?o0000ooooooooool0>_ooool2o`00053o
oooo0_l0000/ooooo`;o0000O_ooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo0?oooooo
>oooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo0<?ooooo0_l0000eooooo`;o0000?_oo
ool2o`0000_ooooo000Nooooo`;o0000AOooool2o`0007gooooo0_l0000;ooooo`;o00002_ooool2
o`0001cooooo0_l0001;ooooo`007_ooool00ol0003oooooooooo`14ooooo`;o0000:?ooool2o`00
063ooooo0_l0000:ooooo`;o00006_ooool2o`0004gooooo000Nooooo`03o`000?oooooooooo067o
oooo0_l0000;ooooo`;o0000R?ooool2o`0004gooooo000Nooooo`03o`000?oooooooooo00Oooooo
0_l00008ooooo`;o0000C_ooool2o`0002cooooo0_l0001:ooooo`;o00003?ooool2o`0005cooooo
000Nooooo`03o`000?oooooooooo00Oooooo0_l00008ooooo`;o0000O?ooool2o`0004[ooooo0_l0
000<ooooo`;o00002?ooool2o`0005;ooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l00012
ooooo`;o0000G_ooool2o`0004Kooooo0_l0001Booooo`007_ooool00ol0003oooooooooo`1;oooo
o`;o0000>_ooool2o`0002;ooooo0_l0000Sooooo`;o0000MOooool001kooooo00?o0000oooooooo
ool02Oooool2o`0007cooooo0_l0000Rooooo`;o00003?ooool2o`0001Gooooo0_l0000Eooooo`;o
00006oooool2o`00047ooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0002Fooooo`;o0000
2?ooool2o`0000cooooo0_l0000Cooooo`;o00005oooool3o`0001[ooooo0_l00011ooooo`007_oo
ool00ol0003oooooooooo`2?ooooo`;o00003Oooool2o`000003ooooool0003o000002_ooooo0_l0
000Hooooo`;o00008_ooool2o`0003Wooooo000Nooooo`03o`000?oooooooooo08oooooo0_l00007
ooooo`;o00001?ooool2o`0006[ooooo1?l0000iooooo`007_ooool00ol0003oooooooooo`0Hoooo
o`;o0000Ioooool2o`0001Gooooo0_l0001`ooooo`;o00005oooool2o`0001Cooooo0_l0000<oooo
o`007_ooool00ol0003oooooooooo`0Gooooo`Go0000A?ooool2o`0001oooooo0_l0000Iooooo`;o
00000_ooool2o`0000Cooooo0_l0001[ooooo`;o00003_ooool2o`0000Sooooo0_l00008ooooo`Co
00003?ooool001kooooo00?o0000ooooooooool05oooool2o`000003ooooool0003o000004Cooooo
0_l0000Aooooo`;o00009oooool2o`0000;ooooo0_l00004ooooo`;o0000Joooool2o`0001Sooooo
0_l00008ooooo`;o00003_ooool001kooooo00?o0000ooooooooool0A?ooool2o`0002_ooooo1?l0
000Jooooo`;o00005?ooool2o`000:3ooooo000Nooooo`03o`000?oooooooooo02kooooo0_l0000D
ooooo`;o0000:oooool2o`0001cooooo0_l0000Dooooo`;o00009?ooool2o`0007[ooooo000Noooo
o`;o0000;oooool2o`0000Kooooo0_l0001Wooooo`;o0000:_ooool2o`0007[ooooo000Nooooo`03
o`000?oooooooooo03;ooooo0_l00002ooooo`;o0000Ioooool2o`000:Kooooo000Nooooo`03o`00
0?oooooooooo03;ooooo0_l0000Aooooo`;o00006Oooool2o`0002Oooooo0_l00006ooooo`;o0000
8_ooool2o`00093ooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l00010ooooo`;o00006Ooo
ool2o`0002Oooooo0_l00006ooooo`;o00008_ooool2o`0004Wooooo0_l00015ooooo`007_ooool0
0ol0003oooooooooo`03ooooo`;o0000Aoooool2o`0001Oooooo0_l0001Looooo`;o0000>oooool2
o`0000Kooooo0_l0000mooooo`007_ooool00ol0003oooooooooo`17ooooo`;o00000oooool2o`00
01Oooooo0_l0000Looooo`;o0000?_ooool2o`0004?ooooo0_l0000>ooooo`;o0000;Oooool001ko
oooo00?o0000ooooooooool0=oooool2o`0000kooooo0_l00003ooooo`;o00009?ooool2o`0000oo
oooo0_l0002Cooooo`;o00009?ooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo00?ooooo
0_l0000booooo`;o00001oooool2o`0000[ooooo0_l0000Tooooo`;o00007_ooool4o`0003gooooo
0_l0001Yooooo`;o00001oooool001kooooo00?o0000ooooooooool00oooool2o`0003_ooooo0_l0
000Mooooo`;o0000<Oooool4o`0002Gooooo0_l0000Fooooo`;o00001oooool2o`0001gooooo0_l0
001:ooooo`007_ooool00ol0003oooooooooo`19ooooo`;o00005?ooool2o`0003oooooo0_l0000I
ooooo`;o00003?ooool2o`00017ooooo0_l0000Mooooo`;o0000B_ooool001kooooo00?o0000oooo
ooooool0BOooool2o`0003;ooooo0_l0000Qooooo`;o00000oooool2o`0002;ooooo0_l0001Boooo
o`;o0000:?ooool001kooooo00?o0000ooooooooool0=_ooool2o`0004Gooooo0_l0000>ooooo`;o
00005_ooool2o`0005?ooooo0_l0000=ooooo`;o00004_ooool2o`0002Sooooo000Nooooo`03o`00
0?oooooooooo01cooooo0_l00005ooooo`;o00003_ooool2o`000003ooooool0003o000005?ooooo
1?l0000Tooooo`;o00004Oooool2o`0003;ooooo0_l0000=ooooo`;o0000??ooool001kooooo00?o
0000ooooooooool07?ooool2o`0000Gooooo0_l0000>ooooo`;o0000:?ooool2o`000003ooooool0
003o000002Wooooo0_l0000Vooooo`;o00004Oooool2o`0001Oooooo0_l000000ooooooo0000o`00
001Sooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o
410@ooooooooool01?ooool00ol0003oooooooooo`1Mooooo`;o000000?oooooo`000?l00000BOoo
ool2o`0003;ooooo0_l000000ooooooo0000o`00000_ooooo`;o0000<_ooool000?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00;o0000ROooool2o`0001kooooo0_l0000<ooooo`;o00005_ooool2o`0000Gooooo0_l0
000iooooo`;o0000<_ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001_oo
ool5o`0001Wooooo0_l0001^ooooo`;o0000;?ooool2o`0001Kooooo0_l00005ooooo`;o0000KOoo
ool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo
00?o0000ooooooooool06oooool2o`000>cooooo0_l0000looooo`000oooool01Ol0003ooooooooo
oooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`28ooooo`;o
0000??ooool2o`00047ooooo0_l0000looooo`000oooool01Ol@413ooooooooooooooooo410@00co
oooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`04ooooo`;o0000?_ooool2o`00047o
oooo0ol000000ooooooo0000o`00000aooooo`;o000000?oooooo`000?l000000oooool2o`0000_o
oooo0_l00011ooooo`;o00005?ooool2o`0001Wooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo00Cooooo0_l0000eooooo`Co
00001Oooool2o`0000oooooo0_l0000`ooooo`?o000000?oooooo`000?l00000<Oooool2o`000003
ooooool0003o0000013ooooo0_l00011ooooo`;o00004oooool3o`0001?ooooo0_l00004ooooo`00
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003o
ooooooooo`0kooooo`Co00005_ooool2o`000=Cooooo0_l0000Dooooo`;o00001?ooool001kooooo
00?o0000ooooooooool0:Oooool2o`00083ooooo0_l00024ooooo`;o00005?ooool001kooooo00?o
0000ooooooooool03?ooool2o`0001_ooooo0_l00020ooooo`;o0000;oooool2o`0002Oooooo0_l0
000Zooooo`;o00005?ooool001kooooo00?o0000ooooooooool03?ooool2o`000<kooooo0_l0000W
ooooo`;o0000@?ooool001kooooo00?o0000ooooooooool09Oooool2o`0005Wooooo0_l0000Roooo
o`;o0000XOooool001kooooo00?o0000ooooooooool04?ooool2o`0001?ooooo0_l0001Iooooo`;o
00008_ooool2o`0005Oooooo0_l0000Zooooo`;o00007?ooool001kooooo00?o0000ooooooooool0
4?ooool2o`0009gooooo0_l0001<ooooo`;o0000:_ooool2o`0001cooooo000Nooooo`03o`000?oo
oooooooo04oooooo0_l0000Booooo`;o00002?ooool2o`00043ooooo0_l00029ooooo`;o00002ooo
ool001kooooo00?o0000ooooooooool0Coooool2o`0001;ooooo0_l00008ooooo`;o0000Z?ooool2
o`0001Gooooo0_l0000:ooooo`;o00002oooool001kooooo00?o0000ooooooooool0`Oooool2o`00
04kooooo0_l00004ooooo`;o00005Oooool2o`0001Oooooo000Nooooo`03o`000?oooooooooo06_o
oooo0_l0000]ooooo`;o00009Oooool2o`0004kooooo0_l0000Uooooo`;o00003Oooool001kooooo
00?o0000ooooooooool09Oooool2o`00023ooooo0_l0000Dooooo`;o00003?ooool2o`0001;ooooo
0_l00005ooooo`;o00004_ooool2o`0009cooooo0_l0000=ooooo`007_ooool2o`0002Kooooo0_l0
000Dooooo`;o00002_ooool2o`0000cooooo0_l00006ooooo`;o00008?ooool2o`0000?ooooo1?l0
002?ooooo`;o0000;_ooool001kooooo00?o0000ooooooooool05Oooool2o`0002Cooooo0_l0000H
ooooo`;o0000;Oooool2o`0000oooooo0_l00020ooooo`;o0000;_ooool001kooooo00?o0000oooo
ooooool05Oooool2o`0007kooooo0_l0000]ooooo`;o0000H_ooool2o`0001Kooooo0_l00005oooo
o`007_ooool00ol0003oooooooooo`1>ooooo`;o00007Oooool2o`0005Gooooo0_l0000mooooo`;o
00008oooool2o`0001Kooooo0_l00005ooooo`007_ooool00ol0003oooooooooo`02ooooo`;o0000
B_ooool2o`0001gooooo0_l0002Dooooo`;o0000@_ooool001kooooo00?o0000ooooooooool00_oo
ool2o`0000Wooooo0_l0000<ooooo`;o0000A?ooool2o`0005Cooooo0_l0001Vooooo`;o00009_oo
ool001kooooo00?o0000ooooooooool03Oooool2o`0000Wooooo0_l000000ooooooo0000o`00000T
ooooo`;o00007_ooool2o`0002cooooo0_l00006ooooo`;o00001Oooool2o`0001Oooooo0_l0001V
ooooo`;o00009_ooool001kooooo00?o0000ooooooooool06?ooool2o`0000Gooooo0_l0000Poooo
o`;o0000=_ooool2o`0001Cooooo0_l00006ooooo`;o00001Oooool2o`000:Oooooo000Nooooo`03
o`000?oooooooooo01oooooo0_l00003ooooo`;o0000Doooool2o`0002Sooooo0_l0001Qooooo`;o
0000?oooool001kooooo00?o0000ooooooooool05_ooool2o`0000cooooo0_l0001mooooo`;o0000
HOooool2o`0001Wooooo0_l0000Tooooo`007_ooool00ol0003oooooooooo`0Fooooo`;o0000G?oo
ool2o`0000cooooo1?l0002Kooooo`;o00009?ooool001kooooo00?o0000ooooooooool01oooool2
o`0003oooooo0_l000000ooooooo0000o`00000Wooooo`;o00003?ooool4o`0001Gooooo0_l0002<
ooooo`;o000000?oooooo`000?l000006Oooool001gooooo0_l00009ooooo`;o0000?oooool2o`00
0003ooooool0003o000004cooooo1?l0000Looooo`;o0000K_ooool2o`000003ooooool0003o0000
01Wooooo000Mooooo`;o0000Voooool2o`0001kooooo0_l00013ooooo`;o0000Aoooool001kooooo
00?o0000ooooooooool0Loooool2o`0004Cooooo0_l0000hooooo`;o00002Oooool2o`0004Oooooo
000Nooooo`03o`000?oooooooooo01gooooo0_l0001Dooooo`;o0000A?ooool2o`0003Sooooo0_l0
001Booooo`007_ooool2o`00013ooooo0_l0000<ooooo`;o0000Coooool2o`0003Sooooo0_l0001V
ooooo`;o00006oooool2o`0001Sooooo000Nooooo`03o`000?oooooooooo00oooooo0_l0000Zoooo
o`;o00009_ooool2o`0000Wooooo0_l0000aooooo`;o00001Oooool2o`0006Kooooo0_l0000Koooo
o`;o00006?ooool001kooooo00?o0000ooooooooool07_ooool2o`0001_ooooo0_l0000<ooooo`;o
00006?ooool2o`0003cooooo0_l0002=ooooo`;o00005Oooool001kooooo00?o0000ooooooooool0
7_ooool2o`0001gooooo0_l0000:ooooo`;o0000:Oooool2o`000;;ooooo0_l00006ooooo`;o0000
00?oooooo`000?l000004_ooool001kooooo00?o0000ooooooooool0?Oooool2o`0003Gooooo0_l0
001Cooooo`;o00001oooool2o`0004[ooooo0_l00008ooooo`;o00002Oooool2o`0001;ooooo000N
ooooo`03o`000?oooooooooo01kooooo0_l0000dooooo`;o0000Loooool2o`0000Oooooo0_l0001:
ooooo`;o00005_ooool2o`0000oooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0000:oooo
o`;o0000=?ooool2o`0002gooooo0_l00011ooooo`;o0000COooool2o`0001oooooo0_l0000?oooo
o`007_ooool00ol0003oooooooooo`0Booooo`;o0000Koooool2o`00047ooooo0_l0001<ooooo`?o
0000<?ooool001kooooo00?o0000ooooooooool05?ooool2o`0003cooooo0_l00030ooooo`;o0000
<Oooool001kooooo00?o0000ooooooooool05?ooool2o`0003cooooo0_l0001hooooo`;o0000NOoo
ool001kooooo00?o0000ooooooooool0BOooool2o`00087ooooo0_l0001iooooo`007_ooool00ol0
003oooooooooo`19ooooo`;o00006Oooool2o`0002Sooooo0_l0001Booooo`;o0000C_ooool2o`00
01?ooooo000Nooooo`03o`000?oooooooooo06Cooooo0_l0000Xooooo`;o0000@oooool2o`0000go
oooo0_l0001>ooooo`;o00004oooool001kooooo00Co0000ooooool0003o0000SOooool2o`0004?o
oooo0_l0001booooo`007_ooool01?l0003oooooo`000?l0000:ooooo`;o00003_ooool2o`0002[o
oooo0_l00018ooooo`;o00006oooool2o`0009Oooooo000Nooooo`03o`000?oooooooooo00_ooooo
0_l0000>ooooo`;o0000:_ooool2o`0004Sooooo0_l0000Eooooo`;o00001?ooool2o`0003Oooooo
0_l0000<ooooo`;o0000>oooool2o`0001?ooooo000Nooooo`;o0000ZOooool2o`0003gooooo0_l0
000<ooooo`;o0000>oooool2o`0001?ooooo000Nooooo`?o00006?ooool2o`00017ooooo0_l0000b
ooooo`;o00003Oooool2o`0008_ooooo0_l0001:ooooo`007_ooool3o`0001Sooooo0_l0000Aoooo
o`;o00007Oooool2o`0001?ooooo0_l0000=ooooo`;o0000M_ooool2o`0001?ooooo0_l0000;oooo
o`;o00008_ooool2o`0000Wooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`0Fooooo`;o
0000<_ooool2o`0000[ooooo0_l0002>ooooo`;o00008?ooool2o`0002;ooooo0_l00009ooooo`;o
00003_ooool001kooooo00?o0000ooooooooool05_ooool2o`0003kooooo0_l0003Oooooo`;o0000
3_ooool001kooooo00?o0000ooooooooool0ooooool2ooooo`;o0000A?ooool001kooooo00?o0000
ooooooooool00_ooool2o`0003Sooooo0_l00029ooooo`;o0000>?ooool2o`0002kooooo0_l0000D
ooooo`007_ooool00ol0003oooooooooo`02ooooo`;o0000>?ooool2o`0000;ooooo0_l00025oooo
o`;o00003?ooool2o`0002cooooo0_l0000Hooooo`;o00003Oooool2o`0000?ooooo0_l0000Doooo
o`007_ooool00ol0003oooooooooo`10ooooo`;o00001oooool2o`00033ooooo0_l0001Hooooo`;o
0000;?ooool2o`0000Kooooo0_l0000@ooooo`;o00003Oooool2o`0001Wooooo000Nooooo`03o`00
0?oooooooooo04Wooooo0_l00005ooooo`;o0000:Oooool2o`0007Oooooo0_l00007ooooo`;o0000
3?ooool2o`0003[ooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0001:ooooo`;o0000X_oo
ool2o`0000Oooooo0_l0000:ooooo`;o0000??ooool001kooooo00?o0000ooooooooool01?ooool2
o`000<kooooo0_l0000cooooo`;o0000??ooool001kooooo00?o0000ooooooooool0@_ooool2o`00
013ooooo0_l0000:ooooo`;o0000L_ooool2o`0000oooooo0_l0001Hooooo`;o00001_ooool001ko
oooo00?o0000ooooooooool0:oooool2o`0001Gooooo0_l0000@ooooo`;o00002_ooool2o`0008?o
oooo0_l0001Gooooo`?o00001_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0:oooool2o`00
067ooooo0_l0002^ooooo`;o00001oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool06?ooool2
o`0002Gooooo0_l0000iooooo`;o00004_ooool2o`000;Oooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0000Hooooo`;o00009Ooo
ool2o`0003Wooooo0_l0001:ooooo`;o00002?ooool2o`0003cooooo0_l0000gooooo`000oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`03o`00
0?oooooooooo0;gooooo0_l00007ooooo`;o00002?ooool2o`0001Kooooo0_l0000Tooooo`;o0000
3?ooool2o`0002Wooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<00Kooooo00?o0000ooooooooool0_Oooool2o`0002Wooooo0_l0000booooo`;o
0000:Oooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00So
oooo00?o0000ooooooooool0oooooolTooooo`;o00003Oooool2o`0001?ooooo0003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo07Ko
oooo0_l0001iooooo`;o0000<?ooool2o`0000gooooo0_l0000Cooooo`000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`1eoooo
o`?o0000B?ooool2o`0002oooooo0_l0000Booooo`;o0000@?ooool001kooooo00?o0000oooooooo
ool03_ooool2o`0006Gooooo0_l00017ooooo`Co00003Oooool2o`0001kooooo1?l00007ooooo`;o
00002Oooool2o`00043ooooo000Nooooo`03o`000?oooooooooo00kooooo0_l0001fooooo`;o0000
=_ooool2o`0000oooooo0_l0000Nooooo`;o00002Oooool2o`0004_ooooo000Nooooo`03o`000?oo
oooooooo08Kooooo0_l0000Aooooo`;o0000@_ooool2o`0006Sooooo000Nooooo`03o`000?oooooo
oooo00Oooooo0_l0000>ooooo`;o00009?ooool2o`0005[ooooo0_l00012ooooo`;o00004Oooool2
o`0005Gooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0000>ooooo`?o00008oooool2o`00
08[ooooo0_l0000Tooooo`?o0000;oooool2o`0002Cooooo000Nooooo`03o`000?oooooooooo01So
oooo0_l0002Gooooo`;o00005_ooool2o`0002Cooooo0_l0000Oooooo`;o00003oooool2o`0002Co
oooo000Nooooo`03o`000?oooooooooo0;7ooooo0_l0001Mooooo`;o0000=Oooool001kooooo00?o
0000ooooooooool06?ooool2o`0005[ooooo0_l00006ooooo`;o00002Oooool2o`0000Wooooo0_l0
000Mooooo`;o0000U?ooool001kooooo00?o0000ooooooooool06?ooool2o`0005[ooooo0_l00006
ooooo`;o00002Oooool2o`0000Wooooo0_l0000Mooooo`;o0000U?ooool001kooooo00?o0000oooo
ooooool0J_ooool2o`000=_ooooo000Nooooo`03o`000?oooooooooo06[ooooo0_l0001hooooo`;o
0000HOooool001kooooo0_l0001cooooo`;o0000:_ooool2o`0001cooooo0_l0000Vooooo`;o0000
?_ooool2o`00027ooooo000Nooooo`03o`000?oooooooooo07;ooooo0_l0000Zooooo`;o00007?oo
ool2o`0006Kooooo0_l00004ooooo`;o00006oooool001kooooo00?o0000ooooooooool0;Oooool2
o`000=kooooo0_l0000Kooooo`;o00006oooool001kooooo00?o0000ooooooooool0;Oooool2o`00
073ooooo0_l00013ooooo`;o00009oooool2o`000003ooooool0003o000000oooooo0_l0000Toooo
o`007_ooool00ol0003oooooooooo`0Uooooo`;o0000N?ooool2o`0004?ooooo0_l0000Zooooo`;o
00003oooool2o`0002Cooooo000Nooooo`03o`000?oooooooooo02Gooooo0_l0000jooooo`;o0000
Noooool2o`0000;ooooo0_l0000=ooooo`;o0000;oooool2o`0002?ooooo000Nooooo`03o`000?oo
oooooooo067ooooo0_l0001kooooo`;o00000_ooool2o`0000gooooo0_l0000_ooooo`;o00008ooo
ool001kooooo00?o0000ooooooooool0@oooool2o`0001?ooooo0_l0002Jooooo`;o0000DOooool0
01kooooo00?o0000ooooooooool07_ooool2o`0002?ooooo0_l0000Cooooo`;o0000@_ooool2o`00
05Kooooo0_l00009ooooo`;o0000A_ooool001kooooo00?o0000ooooooooool07_ooool2o`0001?o
oooo0_l0001Dooooo`Co00003oooool2o`0003oooooo0_l0000Pooooo`;o0000A_ooool001kooooo
00?o0000ooooooooool0<oooool2o`0000Cooooo0_l0000gooooo`;o00005Oooool4o`0001Sooooo
0_l0000fooooo`;o00007Oooool2o`0001;ooooo0_l0000eooooo`007_ooool00ol0003ooooooooo
o`0iooooo`;o00007Oooool2o`0001Sooooo0_l00006ooooo`;o0000:Oooool2o`0001Gooooo0_l0
000nooooo`;o00004_ooool2o`0003Gooooo000Nooooo`03o`000?oooooooooo04?ooooo0_l0000C
ooooo`;o00008?ooool2o`00043ooooo0_l00029ooooo`007_ooool00ol0003oooooooooo`0Roooo
o`;o00006?ooool2o`0000Gooooo0_l0002Nooooo`;o0000H_ooool001kooooo00?o0000oooooooo
ool08_ooool2o`0001Sooooo0_l0000dooooo`;o00004_ooool2o`0005Cooooo0_l00005ooooo`;o
00004?ooool2o`00017ooooo0_l0000mooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o0000
GOooool2o`0001;ooooo0_l0001Dooooo`;o00005oooool2o`00017ooooo0_l0000mooooo`007_oo
ool2o`0001Cooooo0_l0000Wooooo`;o0000D?ooool2o`0006Sooooo0_l00004ooooo`;o0000Aooo
ool001kooooo00?o0000ooooooooool0??ooool2o`00053ooooo0_l0000_ooooo`;o0000=oooool2
o`0000Cooooo0_l0000Kooooo`;o0000:_ooool001kooooo00?o0000ooooooooool0[?ooool2o`00
017ooooo0_l0001Jooooo`;o00008?ooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo01Wo
oooo0_l0000`ooooo`;o00005?ooool2o`0004Wooooo0_l00002ooooo`;o0000:_ooool2o`0000go
oooo0_l0000_ooooo`;o00007oooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo01Wooooo
0_l0000`ooooo`;o00005?ooool2o`0004gooooo0_l0000Zooooo`;o00003Oooool2o`0000Cooooo
0_l0000Yooooo`;o0000:Oooool001kooooo00?o0000ooooooooool04_ooool2o`0000[ooooo0_l0
000Mooooo`;o0000/_ooool2o`0000[ooooo0_l00018ooooo`007Oooool2o`0001Cooooo0_l0000:
ooooo`;o00007Oooool2o`0005Sooooo0_l0001Tooooo`;o0000B?ooool001gooooo0_l0000@oooo
o`;o0000Qoooool2o`0000cooooo0_l0002Pooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o
0000UOooool2o`0004Sooooo0_l0000oooooo`;o00001_ooool2o`0000gooooo000Nooooo`03o`00
0?oooooooooo01oooooo0_l0000Looooo`;o0000A?ooool2o`0006[ooooo0_l0000oooooo`;o0000
1_ooool2o`0000gooooo000Nooooo`03o`000?oooooooooo01oooooo0_l0000Looooo`;o000000?o
ooooo`000?l00000=?ooool2o`0000_ooooo0_l00022ooooo`;o00001oooool2o`0001kooooo0_l0
000Eooooo`007_ooool00ol0003oooooooooo`10ooooo`;o0000=?ooool2o`0007Wooooo0_l0000D
ooooo`;o00001oooool2o`0001kooooo0_l0000Eooooo`007_ooool00ol0003oooooooooo`0Loooo
o`;o00007?ooool2o`0002?ooooo0_l0002@ooooo`;o0000E?ooool001kooooo00?o0000oooooooo
ool07?ooool2o`0001cooooo0_l0000Sooooo`;o0000i_ooool001kooooo00?o0000ooooooooool0
@?ooool2o`000003ooooool0003o0000093ooooo0_l0000gooooo`;o0000=oooool001kooooo00?o
0000ooooooooool0@?ooool2o`000003ooooool0003o000002Cooooo0_l0000@ooooo`;o00005ooo
ool2o`0002Gooooo0_l0000Hooooo`;o0000=oooool2o`0002Oooooo0_l0000>ooooo`007_ooool2
o`0006[ooooo0_l0000@ooooo`;o00005oooool2o`0002Gooooo0_l0001jooooo`;o00003_ooool0
01kooooo00?o0000ooooooooool0eoooool2o`0006kooooo000Nooooo`03o`000?oooooooooo0<Co
oooo0_l0000Aooooo`;o0000K_ooool001kooooo00?o0000ooooooooool0a?ooool2o`0000[ooooo
0_l0000Hooooo`;o0000Foooool001kooooo00?o0000ooooooooool01_ooool2o`0000[ooooo0_l0
002Uooooo`;o00002Oooool2o`0000[ooooo0_l0000Hooooo`;o0000Foooool001kooooo00?o0000
ooooooooool01_ooool2o`0000[ooooo0_l0001oooooo`;o00005oooool2o`0000_ooooo0_l00009
ooooo`;o00001oooool2o`0007Sooooo000Nooooo`03o`000?oooooooooo07cooooo0_l0000Eoooo
o`;o00005oooool2o`0001cooooo0_l000000ooooooo0000o`00001Rooooo`;o00005?ooool001ko
oooo00?o0000ooooooooool0;Oooool2o`0004gooooo0_l0000looooo`;o00003_ooool2o`0003[o
oooo0_l0000Yooooo`;o00005?ooool001kooooo00?o0000ooooooooool05?ooool2o`0001Oooooo
0_l0000?ooooo`;o0000N_ooool2o`0003Gooooo0_l0000Cooooo`;o0000?oooool001kooooo00?o
0000ooooooooool03?ooool2o`0000Kooooo0_l0000Xooooo`;o0000FOooool2o`0005Kooooo0_l0
000;ooooo`;o0000Aoooool001kooooo00?o0000ooooooooool03?ooool2o`0002kooooo0_l0001K
ooooo`;o0000Hoooool2o`0002Gooooo0_l00008ooooo`;o00005_ooool001kooooo00?o0000oooo
ooooool0??ooool2o`0003;ooooo0_l0000?ooooo`;o0000?oooool2o`0002gooooo0_l0000boooo
o`;o00000_ooool2o`0000Cooooo0_l0000Fooooo`007_ooool00ol0003oooooooooo`12ooooo`;o
0000:Oooool2o`000003ooooool0003o000000oooooo0_l0000<ooooo`;o0000<Oooool2o`0002go
oooo0_l0000fooooo`;o00007?ooool001kooooo00?o0000ooooooooool0@_ooool2o`0002Wooooo
0_l0000Pooooo`;o00009?ooool2o`0005[ooooo0_l00006ooooo`?o0000:oooool000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Ko
oooo00?o0000ooooooooool0?oooool2o`0003cooooo0_l0000Zooooo`?o00002Oooool2o`0000go
oooo0_l0001;ooooo`;o00001_ooool3o`0002_ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo
03oooooo0_l00002ooooo`;o00003oooool2o`0002Oooooo0_l0000Zooooo`?o00006?ooool2o`00
087ooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo
000000Kooooo0ol00013ooooo`;o00003oooool2o`0004[ooooo0_l0001Oooooo`;o00002_ooool2
o`0000?ooooo0_l0000cooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8b
oiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooooooo0:3ooooo0_l0001Oooooo`;o00002_oo
ool2o`0000?ooooo0_l0000cooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go
c<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo08Gooooo0_l0000Iooooo`;o0000
YOooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
41001_ooool00ol0003oooooooooo`0Gooooo`;o0000COooool2o`0001gooooo0_l0000aooooo`;o
0000?Oooool2o`0004kooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o
^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool05oooool2o`0000Kooooo0_l00015oooo
o`;o0000?oooool2o`0000oooooo0_l0000Hooooo`;o00008oooool2o`0003?ooooo0_l0000Ioooo
o`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06
ooooo`03o`000?oooooooooo01oooooo0_l0000Mooooo`;o0000;Oooool2o`0003Sooooo0_l0000Y
ooooo`;o0000F?ooool2o`0001Wooooo000Nooooo`03o`000?oooooooooo03kooooo0_l0000]oooo
o`;o0000@oooool2o`0002Oooooo0_l0001Zooooo`007_ooool00ol0003oooooooooo`0Booooo`;o
00009?ooool2o`0004oooooo0_l0000Wooooo`;o00009oooool2o`0006[ooooo000Nooooo`04o`00
0?ooooooooooooooo`;o00003oooool2o`0001kooooo0_l00004ooooo`;o0000Coooool2o`000;co
oooo000Nooooo`04o`000?ooooooooooooooo`;o0000;oooool2o`0002Sooooo0_l000000ooooooo
0000o`00001Uooooo`;o0000F?ooool2o`0002Gooooo000Nooooo`03o`000?oooooooooo00;o0000
9Oooool2o`0000Sooooo0_l0000Yooooo`;o000000?oooooo`000?l00000G_ooool2o`0000Gooooo
0_l0000eooooo`;o00008Oooool2o`0002Gooooo000Nooooo`03o`000?oooooooooo00;o00006_oo
ool2o`0000;ooooo0_l00005ooooo`;o00002?ooool2o`0000gooooo0_l0001mooooo`;o0000??oo
ool2o`0004Sooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l00004ooooo`;o00000_ooool2
o`0001kooooo0_l0001Booooo`;o0000:_ooool2o`0001Sooooo0_l0001[ooooo`007_ooool00ol0
003oooooooooo`0Fooooo`;o00005Oooool2o`0006Cooooo0ol0000Yooooo`?o00006?ooool2o`00
01Kooooo0_l0001Cooooo`007_ooool00ol0003oooooooooo`0]ooooo`;o0000I?ooool2o`0002[o
oooo0_l0000aooooo`;o0000@?ooool2o`00017ooooo000Nooooo`03o`000?oooooooooo07Wooooo
0_l0002Jooooo`;o00003Oooool2o`0000kooooo0_l0000Aooooo`007_ooool00ol0003ooooooooo
o`1<ooooo`;o0000:oooool2o`0006Kooooo0_l0000Sooooo`;o00003Oooool2o`0000gooooo0_l0
00000ooooooo0000o`00000Nooooo`007_ooool2o`0004gooooo0_l0002?ooooo`;o00000_ooool2
o`0000_ooooo0_l0000Fooooo`;o00007oooool2o`0001kooooo000Nooooo`03o`000?oooooooooo
01cooooo0_l0001Iooooo`;o0000I?ooool2o`0000oooooo0_l0000Eooooo`;o00002?ooool2o`00
00oooooo0_l0000Uooooo`007_ooool00ol0003oooooooooo`0Looooo`;o0000FOooool2o`00037o
oooo0_l00007ooooo`;o00002_ooool2o`0000Kooooo0_l0000booooo`;o00002?ooool2o`0000So
oooo0_l00004ooooo`;o00002Oooool2o`0002Gooooo000Nooooo`03o`000?oooooooooo0:[ooooo
0_l00007ooooo`;o00002_ooool2o`0000Kooooo0_l000000ooooooo0000o`00000Rooooo`;o0000
2oooool2o`0001Sooooo0_l0000`ooooo`007_ooool00ol0003oooooooooo`3:ooooo`;o00008_oo
ool2o`0000gooooo0_l00006ooooo`;o0000@?ooool001kooooo00?o0000ooooooooool0Q?ooool3
o`0007Kooooo0_l00006ooooo`;o00004_ooool2o`0002cooooo000Nooooo`03o`000?oooooooooo
03_ooooo0_l0000Hooooo`;o0000;Oooool3o`0009;ooooo0_l0000/ooooo`007_ooool00ol0003o
ooooooooo`0Hooooo`;o00008Oooool2o`0001Sooooo0_l00035ooooo`;o0000:Oooool001kooooo
00?o0000ooooooooool02_ooool2o`0000cooooo0_l0001Gooooo`;o0000Foooool2o`0001[ooooo
0_l0000Cooooo`;o00006oooool2o`0000?ooooo0_l0000Tooooo`007_ooool00ol0003ooooooooo
o`02o`0000Sooooo0_l0000^ooooo`;o0000:_ooool2o`0000Wooooo0_l00017ooooo`;o00004_oo
ool2o`0001[ooooo0_l0000Cooooo`;o00008?ooool2o`0002Cooooo000Nooooo`03o`000?oooooo
oooo00;o0000=Oooool2o`000003ooooool0003o000002[ooooo0_l0001Booooo`;o00004Oooool2
o`00023ooooo0_l00005ooooo`;o00005Oooool2o`0001kooooo0_l0000Hooooo`007_ooool00ol0
003oooooooooo`0gooooo`;o0000U?ooool2o`00023ooooo0_l00005ooooo`Co00004oooool2o`00
01kooooo0_l0000Hooooo`007_ooool00ol0003oooooooooo`0looooo`;o00001_ooool2o`0001So
oooo0_l0000[ooooo`;o00000oooool2o`0006Kooooo0_l0001=ooooo`007_ooool00ol0003ooooo
ooooo`0looooo`;o00001_ooool2o`00013ooooo0_l00006ooooo`;o00006_ooool2o`0000oooooo
0_l00003ooooo`;o000000?oooooo`000?l000004?ooool2o`0001kooooo0_l00020ooooo`007_oo
ool00ol0003oooooooooo`1Fooooo`;o00000_ooool2o`0001kooooo0_l0000Gooooo`;o00004?oo
ool2o`0000kooooo0_l00008ooooo`;o00001?ooool2o`0003cooooo0_l00012ooooo`007_ooool0
0ol0003oooooooooo`0Looooo`;o0000??ooool2o`0005Wooooo0_l00008ooooo`;o00003Oooool2
o`0000Cooooo0_l0000>ooooo`;o00007Oooool2o`0004;ooooo000Nooooo`;o00007Oooool2o`00
02oooooo0_l0001oooooo`;o00001?ooool2o`0000kooooo0_l0001Qooooo`007_ooool00ol0003o
ooooooooo`0Looooo`;o0000;oooool2o`000>cooooo0_l0000:ooooo`007_ooool00ol0003ooooo
ooooo`3Dooooo`;o00004?ooool2o`0005?ooooo0_l0000:ooooo`007_ooool00ol0003ooooooooo
o`1Eooooo`;o0000D_ooool2o`0002Wooooo0_l0000@ooooo`;o0000C?ooool2o`0000Gooooo0_l0
000:ooooo`007_ooool00ol0003oooooooooo`1Eooooo`;o0000?_ooool2o`0001;ooooo0_l0000:
ooooo`;o0000I_ooool2o`0000Cooooo0_l00003ooooo`;o00002_ooool2o`00017ooooo000Noooo
o`03o`000?oooooooooo00gooooo0_l0000^ooooo`;o00000_ooool2o`0005;ooooo0_l0000Noooo
o`;o0000FOooool2o`0000Kooooo0_l00003ooooo`;o00001?ooool2o`0000?ooooo0_l0000Moooo
o`007_ooool00ol0003oooooooooo`0=ooooo`;o0000;_ooool2o`0000;ooooo0_l00008ooooo`;o
0000Moooool2o`0004[ooooo0_l00006ooooo`;o0000;Oooool001kooooo00?o0000ooooooooool0
6Oooool2o`00033ooooo0_l0001Hooooo`;o00007Oooool2o`00023ooooo0_l0001Oooooo`007_oo
ool00ol0003oooooooooo`0Iooooo`;o0000R_ooool2o`0003oooooo0_l0000Uooooo`;o0000>?oo
ool001kooooo00?o0000ooooooooool0>?ooool2o`0009Kooooo0_l0000Eooooo`;o00004Oooool2
o`0000[ooooo0_l00005ooooo`;o00002oooool2o`0000gooooo0_l0000Looooo`007_ooool00ol0
003oooooooooo`0Oooooo`;o00005oooool2o`0007;ooooo0_l0000Rooooo`;o00005Oooool2o`00
017ooooo0_l0000:ooooo`;o00004_ooool2o`0000gooooo0_l0000Looooo`007_ooool00ol0003o
ooooooooo`0Oooooo`;o0000Noooool2o`0000kooooo0_l0000/ooooo`;o00006?ooool2o`00057o
oooo000Nooooo`03o`000?oooooooooo067ooooo0_l0000Sooooo`;o00005?ooool2o`0003cooooo
0_l0000;ooooo`;o00002oooool2o`0002Cooooo0_l0000Sooooo`;o00001_ooool001kooooo00?o
0000ooooooooool0HOooool4o`00027ooooo0_l0000Dooooo`;o0000BOooool2o`0000gooooo0_l0
000Rooooo`;o00004oooool2o`0000kooooo0_l00006ooooo`007_ooool00ol0003oooooooooo`1S
ooooo`;o0000Soooool4o`0003Oooooo0_l0000>ooooo`;o00001_ooool001kooooo00?o0000oooo
ooooool0<_ooool2o`000<3ooooo0_l0001Aooooo`007_ooool2o`0000kooooo0_l0000Sooooo`;o
0000eOooool2o`0003cooooo000Nooooo`03o`000?oooooooooo00gooooo0_l0002Fooooo`;o0000
;oooool2o`0002?ooooo0_l0000<ooooo`;o00003Oooool2o`0002gooooo000Nooooo`03o`000?oo
oooooooo00;ooooo0_l0000Uooooo`;o00007?ooool2o`0002cooooo0_l0000^ooooo`;o0000;ooo
ool2o`0002?ooooo0_l00009ooooo`;o00004?ooool2o`0002gooooo000Nooooo`03o`000?oooooo
oooo00;ooooo0_l0000Uooooo`;o00007?ooool2o`0000;ooooo0_l0000Xooooo`;o0000Qoooool2
o`0000Kooooo0_l0000oooooo`007_ooool00ol0003oooooooooo`0oooooo`;o00002_ooool2o`00
01[ooooo0_l0000Vooooo`;o00008_ooool2o`0001Cooooo0_l0000cooooo`;o0000Aoooool001ko
oooo00?o0000ooooooooool0?oooool2o`0002Kooooo0_l0000Vooooo`;o00006?ooool2o`0000So
oooo0_l0000Dooooo`;o0000FOooool2o`00027ooooo000Nooooo`03o`000?oooooooooo09Wooooo
0_l0000>ooooo`;o0000@_ooool2o`0003Gooooo0_l0000Qooooo`007_ooool00ol0003ooooooooo
o`2Iooooo`;o0000=_ooool2o`0001[ooooo0_l0001Hooooo`007_ooool00ol0003oooooooooo`3A
ooooo`;o0000M?ooool001kooooo00?o0000ooooooooool0_Oooool2o`0002Sooooo0_l0000joooo
o`;o00008_ooool001kooooo00?o0000ooooooooool00oooool2o`000;Sooooo0_l0000Xooooo`;o
0000>_ooool2o`0002;ooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0000cooooo`;o0000
5_ooool2o`0006Kooooo0_l0000Qooooo`;o00007_ooool2o`0004[ooooo000Nooooo`03o`000?oo
oooooooo01gooooo0_l0000Iooooo`;o00005_ooool2o`0006Kooooo0_l0000Qooooo`?o00004_oo
ool4o`0000Oooooo0_l00006ooooo`;o00005?ooool2o`0000gooooo0_l0000Mooooo`007_ooool0
0ol0003oooooooooo`0Mooooo`;o0000_Oooool2o`0001;ooooo1?l000000ooooooo0000o`00000<
ooooo`;o00005?ooool2o`0000gooooo0_l0000Mooooo`005?ooool4o`000003oa0@4?oooooooooo
00?ooooo00?o0000ooooooooool0@?ooool2o`0003gooooo0_l0001dooooo`;o00002?ooool2o`00
01Sooooo0_l0000/ooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo043o
oooo0_l00009ooooo`;o0000<_ooool2o`00043ooooo0_l0000looooo`;o00006?ooool2o`0000So
oooo0_l0000Rooooo`005_ooool00ol0003oooooooooo`05ooooo`?o0000Boooool2o`00067ooooo
0_l0000Aooooo`;o0000H?ooool2o`000003ooooool0003o000001oooooo000Fooooo`03o`000?oo
oooooooo0;Kooooo0_l0001fooooo`;o00007oooool001Kooooo00?o0000ooooooooool0oooooom@
ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?oo
ooooD?ooool001Cooooo00?oEEEEofIVI_l00000oooooomBooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.76748 .64484 Mdot
.00061 .30682 Mdot
.638 .39791 Mdot
.99106 .33955 Mdot
.40813 .49057 Mdot
.41801 .20042 Mdot
.77166 .05487 Mdot
.03404 .11345 Mdot
.82442 .53822 Mdot
.80463 .95796 Mdot
.45951 .60578 Mdot
.80805 .91422 Mdot
.5804 .81886 Mdot
.00049 .45022 Mdot
.04025 .56091 Mdot
.13017 .21624 Mdot
.77376 .01833 Mdot
.56297 .09995 Mdot
.00456 .06294 Mdot
.55498 .92289 Mdot
.18404 .37703 Mdot
.59926 .15094 Mdot
.86159 .81808 Mdot
.83546 .35133 Mdot
.25318 .84626 Mdot
.86497 .84797 Mdot
.9721 .18815 Mdot
.91927 .48149 Mdot
.33115 .25873 Mdot
.22405 .33451 Mdot
.29499 .21638 Mdot
.76005 .34415 Mdot
.89181 .87685 Mdot
.06191 .26249 Mdot
.17607 .15237 Mdot
.16285 .01898 Mdot
.06341 .3194 Mdot
.31854 .26903 Mdot
.87299 .18558 Mdot
.48056 .67186 Mdot
.67774 .76545 Mdot
.08814 .29727 Mdot
.52224 .53534 Mdot
.45789 .77275 Mdot
.66505 .69359 Mdot
.22083 .69343 Mdot
.41087 .61868 Mdot
.99913 .71015 Mdot
.56075 .29449 Mdot
.72842 .3173 Mdot
.71333 .19371 Mdot
.35592 .78069 Mdot
.96978 .5258 Mdot
.19754 .37519 Mdot
.582 .89873 Mdot
.85347 .49086 Mdot
.14066 .07053 Mdot
.49825 .94565 Mdot
.56038 .26198 Mdot
.41693 .2999 Mdot
.88428 .93704 Mdot
.72035 .94076 Mdot
.23847 .57347 Mdot
.40515 .27488 Mdot
.1681 .21476 Mdot
.11893 .84251 Mdot
.61305 .35496 Mdot
.42455 .21992 Mdot
.67276 .28549 Mdot
.01197 .36412 Mdot
.24382 .07326 Mdot
.7474 .15595 Mdot
.08416 .14812 Mdot
.12148 .22744 Mdot
.06295 .44043 Mdot
.77078 .02017 Mdot
.7461 .27864 Mdot
.52398 .27027 Mdot
.05642 .81895 Mdot
.95977 .90938 Mdot
.29942 .64549 Mdot
.06659 .49187 Mdot
.25149 .47913 Mdot
.42568 .33577 Mdot
.99997 .47491 Mdot
.42231 .14417 Mdot
.04078 .91613 Mdot
.71164 .19268 Mdot
.36347 .51934 Mdot
.11583 .99702 Mdot
.43269 .54797 Mdot
.25186 .18239 Mdot
.97567 .14415 Mdot
.11598 .60959 Mdot
.87094 .52554 Mdot
.83264 .14403 Mdot
.7681 .1788 Mdot
.544 .88525 Mdot
.64657 .36494 Mdot
.79816 .77628 Mdot
.1149 .895 Mdot
.65089 .85673 Mdot
.80113 .17897 Mdot
.49793 .77573 Mdot
.74496 .08767 Mdot
.26827 .04195 Mdot
.96757 .46502 Mdot
.36069 .03509 Mdot
.26544 .20293 Mdot
.94375 .05305 Mdot
.48114 .70871 Mdot
.0452 .15347 Mdot
.46272 .95686 Mdot
.51603 .38217 Mdot
.62158 .84088 Mdot
.16998 .80939 Mdot
.77722 .61191 Mdot
.75612 .63803 Mdot
.69358 .10208 Mdot
.23516 .7872 Mdot
.59569 .71859 Mdot
.4737 .80464 Mdot
.94824 .82133 Mdot
.32487 .51034 Mdot
.59814 .98995 Mdot
.9167 .04631 Mdot
.98128 .37479 Mdot
.69418 .29928 Mdot
.32932 .65636 Mdot
.99272 .5608 Mdot
.45892 .49949 Mdot
.7021 .96927 Mdot
.89778 .64179 Mdot
.31434 .27716 Mdot
.04788 .66975 Mdot
.96095 .60516 Mdot
.29099 .68623 Mdot
.06416 .74043 Mdot
.21416 .42409 Mdot
.35957 .2833 Mdot
.99281 .8688 Mdot
.4433 .80986 Mdot
.64582 .32698 Mdot
.69991 .72369 Mdot
.63764 .59 Mdot
.45838 .54677 Mdot
.74669 .84278 Mdot
.35579 .89959 Mdot
.57155 .03656 Mdot
.37456 .24274 Mdot
.17302 .63766 Mdot
.91102 .92966 Mdot
.11745 .59238 Mdot
.62163 .14246 Mdot
.56525 .32429 Mdot
.80129 .32448 Mdot
.74255 .91405 Mdot
.53265 .58853 Mdot
.89035 .01359 Mdot
.96503 .82738 Mdot
.44783 .07605 Mdot
.66599 .44587 Mdot
.10713 .6657 Mdot
.75764 .68888 Mdot
.9228 .91248 Mdot
.25193 .4096 Mdot
.5117 .40701 Mdot
.34233 .21523 Mdot
.63314 .60962 Mdot
.80697 .53534 Mdot
.79221 .43071 Mdot
.69225 .63162 Mdot
.4926 .47251 Mdot
.04375 .27172 Mdot
.41409 .93493 Mdot
.37883 .51425 Mdot
.36528 .91278 Mdot
.22876 .22849 Mdot
.8806 .64646 Mdot
.99141 .1107 Mdot
.20054 .85611 Mdot
.96955 .47486 Mdot
.2759 .45529 Mdot
.20785 .9248 Mdot
.92464 .83785 Mdot
.10666 .56405 Mdot
.62413 .08006 Mdot
.77312 .11225 Mdot
.13547 .03127 Mdot
.63739 .83385 Mdot
.35551 .42693 Mdot
.77046 .80819 Mdot
.26798 .45838 Mdot
.73927 .27834 Mdot
.82975 .17672 Mdot
.4629 .41999 Mdot
.8994 .18288 Mdot
.23685 .72119 Mdot
.36426 .21071 Mdot
.40596 .65844 Mdot
.98853 .09996 Mdot
.92223 .75335 Mdot
.76474 .60842 Mdot
.05242 .81685 Mdot
.37718 .17033 Mdot
.46804 .50055 Mdot
.66611 .92221 Mdot
.92383 .14129 Mdot
.74956 .86466 Mdot
.70551 .23932 Mdot
.54055 .73421 Mdot
.17706 .45398 Mdot
.34497 .45938 Mdot
.10259 .5225 Mdot
.76501 .79496 Mdot
.12426 .55028 Mdot
.23627 .70396 Mdot
.56351 .04514 Mdot
.67744 .7056 Mdot
.83437 .985 Mdot
.91706 .94363 Mdot
.26936 .81129 Mdot
.46415 .34765 Mdot
.02866 .24011 Mdot
.02981 .76344 Mdot
.03778 .81496 Mdot
.17585 .05046 Mdot
.80341 .12864 Mdot
.7988 .1477 Mdot
.28512 .15648 Mdot
.18876 .3477 Mdot
.26303 .17233 Mdot
.09231 .34634 Mdot
.17478 .42702 Mdot
.75081 .88731 Mdot
.09507 .14453 Mdot
.81651 .03854 Mdot
.14915 .42969 Mdot
.5469 .14175 Mdot
.29114 .16694 Mdot
.87225 .00039 Mdot
.17955 .09409 Mdot
.79633 .53816 Mdot
.77973 .84509 Mdot
.54823 .22097 Mdot
.65799 .25847 Mdot
.85724 .23622 Mdot
.49646 .07733 Mdot
.01719 .12543 Mdot
.30028 .73274 Mdot
.25699 .90842 Mdot
.7889 .63912 Mdot
.53991 .97725 Mdot
.60403 .45346 Mdot
.64055 .38462 Mdot
.72177 .68199 Mdot
.01751 .09252 Mdot
.10082 .45773 Mdot
.10783 .99358 Mdot
.66791 .39006 Mdot
.11983 .71585 Mdot
.38163 .76724 Mdot
.7855 .96437 Mdot
.69214 .25221 Mdot
.34963 .82555 Mdot
.06773 .74419 Mdot
.57713 .47729 Mdot
.48624 .929 Mdot
.52585 .36436 Mdot
.15858 .29824 Mdot
.13319 .48517 Mdot
.62007 .97116 Mdot
.16239 .65866 Mdot
.00605 .1031 Mdot
.35054 .59242 Mdot
.48166 .04436 Mdot
.10711 .6292 Mdot
.34418 .33794 Mdot
.43231 .16318 Mdot
.80576 .64755 Mdot
.11047 .78118 Mdot
.69556 .21664 Mdot
.80626 .31633 Mdot
.99083 .1536 Mdot
.82977 .84471 Mdot
.8892 .90075 Mdot
.46389 .11021 Mdot
.52053 .98901 Mdot
.54949 .39273 Mdot
.29388 .48096 Mdot
.19076 .10098 Mdot
.45155 .03333 Mdot
.20211 .47131 Mdot
.69723 .91858 Mdot
.22779 .95612 Mdot
.65463 .58668 Mdot
.47142 .31933 Mdot
.91297 .59843 Mdot
.23125 .25843 Mdot
.33961 .72094 Mdot
.65235 .94626 Mdot
.22386 .11395 Mdot
.6049 .73486 Mdot
.70591 .94409 Mdot
.45696 .13299 Mdot
.98199 .19961 Mdot
.00345 .97336 Mdot
.21927 .70506 Mdot
.4096 .81967 Mdot
.50847 .99779 Mdot
.35852 .46126 Mdot
.28704 .39903 Mdot
.64448 .68824 Mdot
.19542 .47698 Mdot
.32318 .85136 Mdot
.391 .38472 Mdot
.78485 .84686 Mdot
.34546 .0764 Mdot
.7366 .78691 Mdot
.94941 .42637 Mdot
.27867 .02434 Mdot
.56636 .37938 Mdot
.80466 .37041 Mdot
.19812 .06481 Mdot
.97167 .89224 Mdot
.11905 .50175 Mdot
.75732 .90968 Mdot
.8047 .1928 Mdot
.96593 .103 Mdot
.5411 .02433 Mdot
.34707 .32993 Mdot
.54476 .71076 Mdot
.98363 .37011 Mdot
.02963 .20884 Mdot
.32987 .06441 Mdot
.75566 .27274 Mdot
.09349 .30036 Mdot
.48896 .66582 Mdot
.46329 .36616 Mdot
.80748 .63976 Mdot
.31576 .2917 Mdot
.33202 .49398 Mdot
.15381 .85847 Mdot
.79281 .7307 Mdot
.01376 .43026 Mdot
.77619 .65798 Mdot
.91002 .40795 Mdot
.00865 .22715 Mdot
.68743 .19767 Mdot
.5638 .44873 Mdot
.38156 .85292 Mdot
.65794 .01535 Mdot
.85533 .47487 Mdot
.35812 .60719 Mdot
.56018 .65258 Mdot
.49394 .75653 Mdot
.58408 .10733 Mdot
.82281 .00155 Mdot
.75669 .59871 Mdot
.84406 .8705 Mdot
.96206 .42733 Mdot
.26186 .30777 Mdot
.78293 .58802 Mdot
.53659 .35144 Mdot
.78268 .99638 Mdot
.28398 .9431 Mdot
.01696 .49733 Mdot
.60251 .19372 Mdot
.59978 .38016 Mdot
.69792 .08072 Mdot
.9962 .64736 Mdot
.84306 .15394 Mdot
.88249 .24614 Mdot
.58304 .79347 Mdot
.21344 .59828 Mdot
.9783 .47213 Mdot
.47504 .48076 Mdot
.82842 .5555 Mdot
.2739 .93434 Mdot
.12588 .33161 Mdot
.69241 .67071 Mdot
.55062 .34885 Mdot
.81124 .88114 Mdot
.64289 .02907 Mdot
.86686 .43628 Mdot
.09669 .17938 Mdot
.76151 .88831 Mdot
.24143 .59939 Mdot
.1997 .25548 Mdot
.3063 .17712 Mdot
.97606 .19419 Mdot
.34919 .69461 Mdot
.3566 .59128 Mdot
.69574 .39137 Mdot
.34342 .93427 Mdot
.20894 .42105 Mdot
.63381 .38509 Mdot
.94745 .14906 Mdot
.91693 .69478 Mdot
.85765 .43807 Mdot
.6627 .28775 Mdot
.26171 .40073 Mdot
.57984 .05508 Mdot
.09849 .78787 Mdot
.26967 .2906 Mdot
.51144 .25163 Mdot
.88332 .47222 Mdot
.27027 .96637 Mdot
.31021 .91131 Mdot
.24218 .63233 Mdot
.49356 .35412 Mdot
.54242 .17079 Mdot
.91473 .1565 Mdot
.07733 .67198 Mdot
.29847 .17779 Mdot
.91133 .02647 Mdot
.82843 .86349 Mdot
.41235 .67823 Mdot
.95716 .47185 Mdot
.07504 .87628 Mdot
.67081 .39447 Mdot
.73935 .0764 Mdot
.12712 .93203 Mdot
.19798 .05605 Mdot
.24582 .96325 Mdot
.21974 .29273 Mdot
.24039 .84675 Mdot
.17216 .25413 Mdot
.22826 .82099 Mdot
.63948 .47495 Mdot
.23368 .50194 Mdot
.41993 .73066 Mdot
.68201 .01288 Mdot
.70332 .50539 Mdot
.35929 .15733 Mdot
.53895 .62189 Mdot
.21615 .14849 Mdot
.43597 .42987 Mdot
.89302 .41823 Mdot
.15333 .0985 Mdot
.45906 .42149 Mdot
.44369 .49765 Mdot
.13859 .752 Mdot
.12822 .94743 Mdot
.6021 .58412 Mdot
.32846 .3136 Mdot
.08218 .5569 Mdot
.65935 .78661 Mdot
.06481 .56588 Mdot
.20284 .45782 Mdot
.00909 .24063 Mdot
.93592 .54816 Mdot
.50763 .70407 Mdot
.50511 .93517 Mdot
.2299 .06075 Mdot
.55019 .03369 Mdot
.74162 .2378 Mdot
.37888 .69026 Mdot
.74335 .56865 Mdot
.6046 .819 Mdot
.59391 .22045 Mdot
.20642 .21723 Mdot
.58216 .05902 Mdot
.20903 .78373 Mdot
.00993 .21568 Mdot
.80474 .97571 Mdot
.71101 .22703 Mdot
.39595 .98674 Mdot
.0484 .02191 Mdot
.05263 .23467 Mdot
.44147 .26696 Mdot
.54628 .49286 Mdot
.76262 .0566 Mdot
.1599 .25804 Mdot
.19546 .14118 Mdot
.87486 .62325 Mdot
.03629 .84993 Mdot
.17843 .76361 Mdot
.236 .71916 Mdot
.7422 .8972 Mdot
.33417 .7821 Mdot
.6328 .52628 Mdot
.82869 .3815 Mdot
.24363 .91714 Mdot
.16598 .25982 Mdot
.9742 .54042 Mdot
.8373 .1906 Mdot
.06391 .07378 Mdot
.69613 .24743 Mdot
.0242 .37989 Mdot
.29409 .59165 Mdot
.40012 .43832 Mdot
.06712 .06768 Mdot
.65417 .04078 Mdot
.26736 .51778 Mdot
.59438 .98514 Mdot
.18196 .21766 Mdot
.69265 .34091 Mdot
.53353 .03225 Mdot
.59358 .36982 Mdot
.75181 .78153 Mdot
.50997 .11018 Mdot
.38142 .97264 Mdot
.19825 .5542 Mdot
.16041 .11166 Mdot
.45761 .5039 Mdot
.018 .47127 Mdot
.77455 .64025 Mdot
.61695 .1528 Mdot
.08754 .14489 Mdot
.02591 .98719 Mdot
.59111 .65397 Mdot
.40364 .34035 Mdot
.02995 .6101 Mdot
.92692 .28677 Mdot
.925 .12943 Mdot
.63001 .31951 Mdot
.66794 .53711 Mdot
.8107 .89586 Mdot
.79951 .0784 Mdot
.20318 .80923 Mdot
.68794 .98404 Mdot
.13839 .70364 Mdot
.15179 .21098 Mdot
.83943 .28813 Mdot
.05604 .52862 Mdot
.89034 .82192 Mdot
.26309 .28739 Mdot
.08703 .65481 Mdot
.64179 .80962 Mdot
.23529 .72434 Mdot
.73784 .59269 Mdot
.13418 .99819 Mdot
.93469 .62724 Mdot
.88342 .19623 Mdot
.79872 .48245 Mdot
.89737 .83289 Mdot
.65 .04585 Mdot
.11647 .12893 Mdot
.59103 .80082 Mdot
.78825 .58619 Mdot
.89853 .09916 Mdot
.54364 .72701 Mdot
.15798 .38895 Mdot
.53154 .9309 Mdot
.32475 .67187 Mdot
.6369 .61203 Mdot
.41737 .06243 Mdot
.75591 .67006 Mdot
.89719 .0494 Mdot
.72688 .63249 Mdot
.23724 .33026 Mdot
.95979 .24328 Mdot
.39188 .37852 Mdot
.32653 .3859 Mdot
.21379 .07728 Mdot
.91726 .53751 Mdot
.94537 .35566 Mdot
.35766 .88408 Mdot
.44521 .20366 Mdot
.59665 .07836 Mdot
.60005 .21466 Mdot
.94082 .28965 Mdot
.16885 .01982 Mdot
.91284 .97999 Mdot
.83769 .7712 Mdot
.59601 .53395 Mdot
.73153 .80507 Mdot
.58381 .10981 Mdot
.95396 .35534 Mdot
.25768 .32171 Mdot
.45456 .11887 Mdot
.90295 .17585 Mdot
.90671 .6906 Mdot
.09953 .93399 Mdot
.69316 .77201 Mdot
.16251 .88104 Mdot
.80471 .16605 Mdot
.34093 .26367 Mdot
.22214 .42646 Mdot
.83908 .23014 Mdot
.19913 .15097 Mdot
.4531 .99307 Mdot
.72273 .00046 Mdot
.58074 .83319 Mdot
.80354 .18505 Mdot
.66369 .9082 Mdot
.98431 .50522 Mdot
.63685 .97882 Mdot
.14853 .25258 Mdot
.26671 .85424 Mdot
.03558 .87944 Mdot
.44099 .51002 Mdot
.80217 .80675 Mdot
.93591 .5132 Mdot
.18966 .79454 Mdot
.45619 .85914 Mdot
.38005 .49517 Mdot
.88265 .8183 Mdot
.23427 .12082 Mdot
.08394 .91958 Mdot
.20676 .97843 Mdot
.95497 .233 Mdot
.00668 .22095 Mdot
.66747 .6088 Mdot
.35985 .46309 Mdot
.49583 .91335 Mdot
.28634 .56652 Mdot
.07749 .16244 Mdot
.84769 .03096 Mdot
.47638 .18574 Mdot
.67871 .95373 Mdot
.17594 .26471 Mdot
.58226 .87434 Mdot
.35494 .14068 Mdot
.49313 .79733 Mdot
.67983 .66972 Mdot
.27729 .37428 Mdot
.98724 .7002 Mdot
.94417 .69187 Mdot
.81209 .38993 Mdot
.19461 .55585 Mdot
.48039 .18389 Mdot
.44171 .62606 Mdot
.06799 .99928 Mdot
.92368 .58306 Mdot
.8813 .89061 Mdot
.34119 .70664 Mdot
.33688 .29181 Mdot
.19438 .33752 Mdot
.12198 .52646 Mdot
.14619 .47907 Mdot
.22304 .25888 Mdot
.03122 .85083 Mdot
.89165 .97091 Mdot
.7745 .28957 Mdot
.82757 .88046 Mdot
.73624 .5866 Mdot
.80658 .15605 Mdot
.18828 .82976 Mdot
.62723 .89684 Mdot
.16857 .47153 Mdot
.33098 .4694 Mdot
.76128 .86163 Mdot
.01811 .11698 Mdot
.69603 .85284 Mdot
.28583 .22075 Mdot
.98957 .58308 Mdot
.47961 .20891 Mdot
.19262 .87039 Mdot
.60375 .92677 Mdot
.10071 .21234 Mdot
.05865 .86984 Mdot
.86191 .92312 Mdot
.5655 .5191 Mdot
.08908 .87001 Mdot
.50108 .37433 Mdot
.53168 .16777 Mdot
.30081 .24567 Mdot
.51556 .53126 Mdot
.77223 .99642 Mdot
.0915 .50706 Mdot
.1326 .94888 Mdot
.16306 .32963 Mdot
.20239 .90375 Mdot
.18068 .43601 Mdot
.77642 .25965 Mdot
.23422 .54798 Mdot
.28194 .98942 Mdot
.52491 .30091 Mdot
.09496 .57306 Mdot
.23529 .61925 Mdot
.42522 .80571 Mdot
.97714 .20789 Mdot
.0624 .72354 Mdot
.89439 .67269 Mdot
.77152 .77333 Mdot
.61037 .26525 Mdot
.06264 .67072 Mdot
.5209 .74085 Mdot
.63148 .77214 Mdot
.80516 .50023 Mdot
.43939 .06766 Mdot
.73208 .7377 Mdot
.18109 .20182 Mdot
.64252 .60666 Mdot
.99892 .54432 Mdot
.86837 .00818 Mdot
.33191 .68806 Mdot
.11594 .7057 Mdot
.20689 .07201 Mdot
.7597 .83477 Mdot
.68489 .34842 Mdot
.90232 .25948 Mdot
.37474 .40647 Mdot
.19467 .39431 Mdot
.12047 .13177 Mdot
.69246 .65455 Mdot
.23624 .46741 Mdot
.86723 .73361 Mdot
.8072 .97732 Mdot
.71086 .20044 Mdot
.4654 .73491 Mdot
.89004 .48131 Mdot
.896 .47398 Mdot
.98007 .10569 Mdot
.63926 .16776 Mdot
.58859 .57733 Mdot
.458 .14507 Mdot
.01956 .97299 Mdot
.33476 .50671 Mdot
.2568 .15868 Mdot
.45102 .72319 Mdot
.56835 .90277 Mdot
.86944 .83005 Mdot
.45182 .50509 Mdot
.10829 .30674 Mdot
.55222 .31926 Mdot
.28231 .20138 Mdot
.87192 .67083 Mdot
.9364 .01752 Mdot
.75645 .75021 Mdot
.73941 .35615 Mdot
.59761 .67225 Mdot
.42269 .79674 Mdot
.1771 .97533 Mdot
.53863 .82244 Mdot
.5391 .39489 Mdot
.54816 .72601 Mdot
.07159 .17787 Mdot
.25746 .44382 Mdot
.10558 .41928 Mdot
.04383 .59082 Mdot
.46694 .62891 Mdot
.24873 .06739 Mdot
.86147 .78503 Mdot
.03794 .24589 Mdot
.79906 .83782 Mdot
.60153 .48584 Mdot
.39833 .39678 Mdot
.1707 .84918 Mdot
.42302 .31912 Mdot
.8709 .30382 Mdot
.1224 .97566 Mdot
.84389 .87273 Mdot
.70601 .35417 Mdot
.43947 .65425 Mdot
.8475 .69449 Mdot
.42578 .38228 Mdot
.16284 .92017 Mdot
.78055 .98745 Mdot
.6669 .60108 Mdot
.79162 .24987 Mdot
.43064 .14189 Mdot
.81293 .02845 Mdot
.34059 .25757 Mdot
.97722 .1852 Mdot
.47625 .98357 Mdot
.45621 .39637 Mdot
.52075 .26926 Mdot
.08335 .90033 Mdot
.5761 .41492 Mdot
.24902 .03791 Mdot
.84312 .9974 Mdot
.41257 .73486 Mdot
.55831 .80407 Mdot
.75299 .83451 Mdot
.33517 .42375 Mdot
.67181 .55192 Mdot
.79094 .55456 Mdot
.32707 .25479 Mdot
.04049 .17326 Mdot
.10765 .15297 Mdot
.3316 .79685 Mdot
.99433 .27897 Mdot
.67363 .69526 Mdot
.40284 .40279 Mdot
.99588 .10375 Mdot
.50202 .76969 Mdot
.8134 .73125 Mdot
.94686 .14545 Mdot
.97639 .25623 Mdot
.4481 .04832 Mdot
.93319 .01076 Mdot
.49687 .87427 Mdot
.41414 .26102 Mdot
.57876 .75291 Mdot
.89852 .44221 Mdot
.31197 .12476 Mdot
.93603 .38527 Mdot
.6156 .33766 Mdot
.98728 .78651 Mdot
.8722 .29982 Mdot
.01221 .58252 Mdot
.27779 .26023 Mdot
.01496 .59705 Mdot
.89484 .48047 Mdot
.52808 .32364 Mdot
.12221 .87918 Mdot
.75348 .73092 Mdot
.97632 .55361 Mdot
.74137 .30584 Mdot
.41142 .14775 Mdot
.85731 .63649 Mdot
.65403 .95042 Mdot
.73431 .93993 Mdot
.51632 .76446 Mdot
.51627 .24686 Mdot
.69202 .18413 Mdot
.15797 .95381 Mdot
.49845 .38785 Mdot
.49272 .0571 Mdot
.37889 .71046 Mdot
.58537 .75733 Mdot
.17071 .67378 Mdot
.91744 .17754 Mdot
.32097 .69588 Mdot
.0593 .22179 Mdot
.95532 .99029 Mdot
.52066 .83472 Mdot
.36697 .75669 Mdot
.52591 .02591 Mdot
.85251 .22899 Mdot
.11692 .00739 Mdot
.4146 .39972 Mdot
.47738 .38886 Mdot
.22568 .76068 Mdot
.52518 .05225 Mdot
.94616 .28326 Mdot
.52021 .9507 Mdot
.88897 .31835 Mdot
.921 .0028 Mdot
.66539 .72403 Mdot
.55171 .93755 Mdot
.74617 .36729 Mdot
.31118 .01632 Mdot
.36114 .9672 Mdot
.94043 .82945 Mdot
.06406 .99993 Mdot
.2486 .66466 Mdot
.11287 .82617 Mdot
.8588 .76118 Mdot
.21958 .39899 Mdot
.88404 .69272 Mdot
.6702 .70377 Mdot
.44366 .71295 Mdot
.85395 .40334 Mdot
.92067 .79561 Mdot
.43105 .45179 Mdot
.98715 .05936 Mdot
.26365 .50491 Mdot
.5613 .38736 Mdot
.93342 .82184 Mdot
.73152 .65777 Mdot
.63558 .2788 Mdot
.80601 .01389 Mdot
.04862 .41968 Mdot
.28223 .20183 Mdot
.30508 .14056 Mdot
.44635 .39883 Mdot
.87235 .62825 Mdot
.39332 .37076 Mdot
.70301 .96356 Mdot
.7235 .97452 Mdot
.7014 .22951 Mdot
.05916 .21502 Mdot
.94938 .95837 Mdot
.05301 .23972 Mdot
.97514 .47996 Mdot
.71517 .87663 Mdot
.78039 .43491 Mdot
.41457 .40836 Mdot
.77584 .97226 Mdot
.87127 .11993 Mdot
.23642 .82407 Mdot
.28578 .1775 Mdot
.54123 .77864 Mdot
.42259 .9499 Mdot
.44192 .82851 Mdot
.1537 .82798 Mdot
.52534 .26869 Mdot
.54777 .78748 Mdot
.82798 .74548 Mdot
.07721 .32897 Mdot
.91843 .88498 Mdot
.11031 .35832 Mdot
.82117 .95863 Mdot
.03301 .21546 Mdot
.46585 .10796 Mdot
.54378 .25342 Mdot
.90256 .4196 Mdot
.43556 .59277 Mdot
.49706 .18965 Mdot
.82418 .61093 Mdot
.49115 .38639 Mdot
.70105 .2251 Mdot
.71988 .52833 Mdot
.61121 .98499 Mdot
.79781 .58373 Mdot
.61559 .85653 Mdot
.2648 .3909 Mdot
.95504 .54799 Mdot
.49576 .94765 Mdot
.63117 .07425 Mdot
.94364 .84971 Mdot
.74074 .537 Mdot
.26048 .38282 Mdot
.93074 .23557 Mdot
.63927 .83895 Mdot
.34877 .32126 Mdot
.93247 .0942 Mdot
.87056 .3735 Mdot
.56117 .78714 Mdot
.84066 .82088 Mdot
.11637 .8108 Mdot
.35537 .64679 Mdot
.11654 .00159 Mdot
.58099 .27233 Mdot
.82282 .7353 Mdot
.61967 .91963 Mdot
.04478 .89267 Mdot
.11465 .68879 Mdot
.18796 .59982 Mdot
.18054 .3877 Mdot
.49719 .03818 Mdot
.448 .43787 Mdot
.12342 .35028 Mdot
.99302 .73381 Mdot
.97266 .22234 Mdot
.52139 .60556 Mdot
.23177 .54071 Mdot
.87315 .547 Mdot
.17043 .8522 Mdot
.78568 .70552 Mdot
.10737 .05911 Mdot
.63129 .36966 Mdot
.43865 .90176 Mdot
.21727 .75309 Mdot
.34117 .63447 Mdot
.09941 .19262 Mdot
.34859 .41571 Mdot
.68614 .71065 Mdot
.22373 .88861 Mdot
.75428 .13184 Mdot
.17355 .95384 Mdot
.0047 .48606 Mdot
.22467 .06792 Mdot
.33951 .24819 Mdot
.61132 .059 Mdot
.28334 .38675 Mdot
.3901 .25947 Mdot
.89754 .28735 Mdot
.02284 .72621 Mdot
.22961 .57977 Mdot
.9231 .97594 Mdot
.54657 .42588 Mdot
.8544 .87105 Mdot
.44229 .9744 Mdot
.788 .85713 Mdot
.29589 .61118 Mdot
.23003 .72188 Mdot
.17413 .36674 Mdot
.90442 .45338 Mdot
.97946 .97912 Mdot
.71716 .84638 Mdot
.6866 .29213 Mdot
.75556 .7447 Mdot
.15962 .67165 Mdot
.77166 .00969 Mdot
.64359 .89152 Mdot
.09414 .06725 Mdot
.49097 .14903 Mdot
.02107 .40104 Mdot
.41996 .90167 Mdot
.01556 .8867 Mdot
.25945 .97327 Mdot
.25736 .93983 Mdot
.46957 .55697 Mdot
.64779 .27514 Mdot
.43568 .86667 Mdot
.78977 .32905 Mdot
.71286 .02651 Mdot
.56845 .17924 Mdot
.40628 .74139 Mdot
.68809 .85721 Mdot
.96107 .01344 Mdot
.5967 .88865 Mdot
.71945 .15 Mdot
.38721 .81758 Mdot
.09949 .47712 Mdot
.81213 .60402 Mdot
.81701 .71757 Mdot
.18814 .3324 Mdot
.19571 .55329 Mdot
.52831 .28756 Mdot
.84456 .72487 Mdot
.7822 .5092 Mdot
.74052 .93439 Mdot
.07968 .43692 Mdot
.98134 .8699 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`;o00002Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool2o`0000Oo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`;o00002?ooool00ol0003o
ooooooooo`03ooooo`;o00002?ooool00ol0003oooooooooo`03ooooo`;o00002?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo000Nooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`;o00002Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00?ooooo0_l00008ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool00oooool2o`0000Sooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`02ooooo`007_ooool00ol0003oooooooooo`0Rooooo`;o0000doooool2o`0001gooooo0_l0
000_ooooo`007_ooool00ol0003oooooooooo`3Jooooo`;o00006oooool2o`0001gooooo0_l00005
ooooo`;o00003?ooool2o`0000Oooooo0_l0000Aooooo`007_ooool00ol0003oooooooooo`1Qoooo
o`;o0000Koooool2o`0000Kooooo0_l0000Vooooo`;o00006Oooool2o`0000cooooo0_l00007oooo
o`;o00004Oooool001kooooo00?o0000ooooooooool0<Oooool4o`0002cooooo0_l0001_ooooo`;o
00008oooool2o`0000Wooooo0_l0000Xooooo`;o00006Oooool001kooooo00?o0000ooooooooool0
3?ooool2o`0002?ooooo1?l00031ooooo`?o0000<oooool2o`0001Wooooo000Nooooo`03o`000?oo
oooooooo00cooooo0_l00018ooooo`;o0000Coooool2o`0000?ooooo0_l00018ooooo`;o0000Cooo
ool001kooooo00?o0000ooooooooool0E_ooool2o`0004oooooo0_l00003ooooo`;o00007oooool2
o`0001Gooooo0_l0000Nooooo`;o00007_ooool2o`00027ooooo000Nooooo`03o`000?oooooooooo
02Sooooo0_l0002Sooooo`;o00005Oooool2o`0001kooooo0_l00009ooooo`;o00004oooool2o`00
027ooooo000Nooooo`03o`000?oooooooooo02Sooooo0_l00017ooooo`;o00007?ooool2o`0001So
oooo0_l00004ooooo`;o0000G_ooool2o`0003Kooooo000Nooooo`03o`000?oooooooooo04gooooo
0_l0000Rooooo`;o00007?ooool2o`0000gooooo0_l00009ooooo`;o00001?ooool2o`0000Gooooo
0_l0002?ooooo`007_ooool00ol0003oooooooooo`1=ooooo`;o0000Coooool2o`0001Kooooo0_l0
000Iooooo`;o0000<_ooool2o`00043ooooo000Nooooo`03o`000?oooooooooo05?ooooo0_l00013
ooooo`;o0000=oooool2o`0003;ooooo0_l00010ooooo`007_ooool00ol0003oooooooooo`1Coooo
o`;o0000@oooool2o`0001Wooooo0_l0000Jooooo`;o0000EOooool2o`0001oooooo000Nooooo`03
o`000?oooooooooo03Gooooo0_l0001Gooooo`;o00008oooool2o`0001[ooooo0_l0001?ooooo`;o
00001?ooool2o`0001oooooo000Nooooo`;o0000=_ooool2o`0005Oooooo0_l0000Gooooo`;o0000
Moooool2o`0000gooooo0_l0000Fooooo`007_ooool00ol0003oooooooooo`0looooo`;o0000JOoo
ool2o`0000oooooo0_l0000jooooo`;o000000?oooooo`000?l00000=_ooool2o`0001Kooooo000N
ooooo`03o`000?oooooooooo01oooooo0_l0000Kooooo`;o0000G_ooool2o`0001[ooooo0ol00008
ooooo`;o0000;oooool2o`000003ooooool0003o000004Cooooo0_l00008ooooo`007_ooool2o`00
023ooooo0_l0000Vooooo`;o0000>oooool2o`0001Kooooo0_l0000Kooooo`;o00002?ooool2o`00
07Sooooo0_l00008ooooo`007_ooool2o`0003gooooo0_l00009ooooo`;o00007_ooool2o`0001_o
oooo0_l00031ooooo`007_ooool00ol0003oooooooooo`0Booooo`;o00001_ooool2o`00023ooooo
0_l00007ooooo`;o00001_ooool2o`0001Sooooo0_l0000Rooooo`;o0000^_ooool001kooooo00?o
0000ooooooooool04_ooool2o`0000Kooooo0_l0000>ooooo`;o00004oooool2o`0000Cooooo0_l0
0006ooooo`;o0000??ooool2o`000;[ooooo000Nooooo`03o`000?oooooooooo017ooooo0_l0000G
ooooo`;o00004oooool2o`0000[ooooo0_l0001looooo`;o0000O?ooool001kooooo00?o0000oooo
ooooool04Oooool2o`0002kooooo0_l00008ooooo`;o00007oooool2o`0001oooooo0_l0000>oooo
o`;o0000:_ooool2o`00027ooooo0_l0001Iooooo`007_ooool00ol0003oooooooooo`11ooooo`;o
0000:Oooool2o`0001oooooo0_l0000>ooooo`;o00007oooool2o`0000Oooooo0_l0000Fooooo`;o
00002oooool2o`0001;ooooo0_l00015ooooo`007_ooool00ol0003oooooooooo`2nooooo`;o0000
1oooool2o`0001Kooooo0_l0000Oooooo`;o0000AOooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3^ooooo`;o0000Eoooool001kooooo00?o0000oooo
ooooool00_ooool2o`000>[ooooo0_l0001Gooooo`007_ooool00ol0003oooooooooo`02ooooo`;o
0000<_ooool2o`000??ooooo0_l0000Jooooo`007_ooool00ol0003oooooooooo`0^ooooo`;o0000
1_ooool2o`000>Sooooo0_l00009ooooo`;o00006_ooool001kooooo0_l0000_ooooo`;o00002_oo
ool2o`0007Oooooo0_l0000Xooooo`;o0000@Oooool2o`0001_ooooo0_l00008ooooo`007_ooool3
o`0003[ooooo0_l0001gooooo`;o0000:?ooool2o`0005Oooooo0_l00003ooooo`Co000000?ooooo
o`000?l000001Oooool001kooooo0ol0002Cooooo`;o00009Oooool2o`0007[ooooo0_l00003oooo
o`;o00000oooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo033ooooo0_l0001Qooooo`;o
00003Oooool2o`0001Kooooo0_l00022ooooo`;o00001oooool001kooooo00?o0000ooooooooool0
1oooool2o`0002Oooooo0_l0000Cooooo`;o0000C?ooool2o`0000gooooo0_l0000Fooooo`;o0000
>oooool2o`0004Gooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`02ooooo`;o00000ooo
ool2o`0003cooooo0_l0002`ooooo`;o0000C_ooool001kooooo00?o0000ooooooooool00_ooool2
o`0004Cooooo0_l00016ooooo`;o0000QOooool2o`0002kooooo000Nooooo`03o`000?oooooooooo
04Sooooo0_l00016ooooo`;o0000QOooool2o`0002kooooo000Nooooo`04o`000?oooooooooooooo
o`;o0000G_ooool2o`000>Cooooo000Nooooo`04o`000?ooooooooooooooo`;o00007oooool2o`00
03gooooo0_l0002Nooooo`;o00009_ooool2o`0001cooooo000Nooooo`03o`000?oooooooooo02;o
oooo0ol0001[ooooo`;o0000Goooool2o`0000kooooo0_l0000Vooooo`;o00007?ooool001kooooo
00?o0000ooooooooool08oooool2o`0006_ooooo0_l0001Oooooo`;o0000E?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`0kooooo`;o00008_ooool2
o`0000kooooo0_l0000Gooooo`;o00009?ooool2o`0001Kooooo0_l0001Pooooo`;o00007Oooool0
01kooooo00?o0000ooooooooool06?ooool2o`000003ooooool0003o000001kooooo0_l0000Roooo
o`;o00003_ooool2o`0001Cooooo0_l000000ooooooo0000o`000007ooooo`;o00006oooool2o`00
01Kooooo0_l00013ooooo`;o00006oooool2o`0000Kooooo0_l00007ooooo`;o00003?ooool001ko
oooo00?o0000ooooooooool05oooool3o`000003ooooool0003o000002Gooooo0_l0000nooooo`;o
000000?oooooo`000?l000002_ooool2o`0000Wooooo0_l0001Rooooo`;o00002Oooool2o`0002?o
oooo0_l00007ooooo`;o00003?ooool001kooooo0_l0000Hooooo`;o00009?ooool2o`0000?ooooo
0_l0000nooooo`;o00006?ooool2o`00027ooooo0_l0000Uooooo`;o00006?ooool2o`0002kooooo
0_l0000Eooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o00004_ooool2o`0001Cooooo0_l0
0006ooooo`;o0000P?ooool2o`0000?ooooo0_l0000Pooooo`;o00009_ooool2o`0002kooooo0_l0
0007ooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o00004_ooool2o`0001Cooooo0_l0000R
ooooo`;o00005_ooool2o`00057ooooo0_l0000Yooooo`;o00004Oooool2o`0000[ooooo0_l0000E
ooooo`;o00005oooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo04oooooo0_l00008oooo
o`;o00005_ooool2o`0007cooooo0_l0000Aooooo`;o00008Oooool2o`00023ooooo000Nooooo`03
o`000?oooooooooo01Gooooo0_l0000hooooo`;o0000=oooool2o`000;gooooo000Nooooo`03o`00
0?oooooooooo01Gooooo0_l00014ooooo`;o0000:oooool2o`0007Sooooo0_l00013ooooo`007_oo
ool00ol0003oooooooooo`1Kooooo`;o00006_ooool2o`00033ooooo0_l0000Qooooo`;o0000=?oo
ool2o`0004?ooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l00016ooooo`;o00009?ooool2
o`00033ooooo0_l000000ooooooo0000o`00000Nooooo`;o0000NOooool001kooooo00?o0000oooo
ooooool02Oooool2o`0004Kooooo0_l0001Iooooo`;o0000G?ooool2o`0001Gooooo0_l0000Toooo
o`007_ooool00ol0003oooooooooo`0Cooooo`;o00001_ooool2o`0003cooooo0_l00002ooooo`Co
0000E?ooool2o`0003oooooo0_l00008ooooo`;o00002?ooool2o`0001Gooooo0_l00003ooooo`;o
00007oooool001kooooo00?o0000ooooooooool04oooool2o`0000Kooooo0_l0000aooooo`;o0000
2Oooool2o`0000;ooooo1?l0001Dooooo`;o0000?oooool2o`0000Sooooo0_l0000Nooooo`;o0000
1?ooool2o`0001oooooo000Nooooo`03o`000?oooooooooo04kooooo0_l00017ooooo`?o0000@ooo
ool2o`0002;ooooo0_l0000Eooooo`;o00001_ooool2o`0001Sooooo0_l0000;ooooo`007_ooool0
0ol0003oooooooooo`2Gooooo`?o0000@oooool2o`0002;ooooo0_l0000Eooooo`;o00007_ooool4
o`0000_ooooo000Nooooo`03o`000?oooooooooo09gooooo0_l0001]ooooo`;o0000:_ooool2o`00
00gooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006oooo
o`03o`000?oooooooooo01cooooo0_l0001oooooo`;o00008Oooool2o`00027ooooo0ol0000Loooo
o`;o00002?ooool2o`0002_ooooo0_l0000<ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`0L
ooooo`;o0000X_ooool2o`0001Wooooo0_l00006ooooo`?o00007?ooool2o`0001Oooooo0_l0000L
ooooo`;o00003?ooool000?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7o
k^k^00Oooooo0ol00024ooooo`;o0000EOooool2o`0000Kooooo0_l0000fooooo`;o00007_ooool2
o`0000[ooooo0003ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06
ooooo`03o`000?oooooooooo03Oooooo0_l0000Iooooo`;o00001?ooool2o`0002[ooooo0_l00007
ooooo`;o0000E?ooool2o`0005Kooooo0_l0000:ooooo`000oooool01Ol0003ooooooooooooooooo
000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`0gooooo`;o00006Oooool2
o`0000Cooooo0_l0000cooooo`;o0000^?ooool000?ooooo00Go410@oooooooooooooooooa0@400?
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool2o`00093ooooo0_l0002P
ooooo`;o00002oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`06ooooo`;o00005Oooool2o`0000kooooo0_l0
0013ooooo`;o00009?ooool2o`000:3ooooo0_l0000;ooooo`000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`04o`000?oooooo0000o`0000Ko
oooo0_l00006ooooo`;o00003?ooool2o`0000Oooooo0_l00005ooooo`;o00001?ooool2o`0002Oo
oooo0_l0000=ooooo`;o00001Oooool2o`0004_ooooo0_l0000Mooooo`;o0000Ioooool001kooooo
00Co0000ooooool0003o00001_ooool2o`0000Kooooo0_l0000Eooooo`;o00002oooool2o`0000;o
oooo0_l00006ooooo`;o00006oooool2o`0000gooooo0_l0001Booooo`;o00007Oooool2o`0006Oo
oooo000Nooooo`?o00003oooool2o`0002Kooooo0_l00006ooooo`;o00006?ooool2o`0002_ooooo
0_l0000Vooooo`;o00003Oooool2o`0007Wooooo0_l0000=ooooo`007_ooool3o`0000oooooo0_l0
0018ooooo`;o0000:oooool2o`0002Kooooo0_l0000=ooooo`;o00008Oooool2o`0005Kooooo0_l0
000=ooooo`007_ooool01?l0003oooooo`000?l0000Rooooo`;o00008Oooool2o`0009Sooooo0_l0
00000ooooooo0000o`00000/ooooo`;o0000=?ooool001kooooo00Co0000ooooool0003o00008_oo
ool2o`00027ooooo0_l0002Hooooo`;o000000?oooooo`000?l00000:?ooool2o`0000;ooooo0_l0
000dooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o0000dOooool2o`0002_ooooo0_l0000S
ooooo`;o00004oooool001kooooo00?o0000ooooooooool03Oooool2o`000=kooooo0_l0000Toooo
o`;o00005Oooool2o`0000Kooooo0_l0000Cooooo`007_ooool01?l0003oooooo`000?l00004oooo
o`;o00001_ooool2o`000=;ooooo0_l0000:ooooo`;o00009?ooool2o`0001Gooooo0_l0000Koooo
o`007_ooool01?l0003oooooo`000?l00004ooooo`;o00001_ooool2o`0006Oooooo0_l0001Yoooo
o`;o0000DOooool2o`00017ooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0001Dooooo`;o
00005_ooool2o`0002cooooo0_l0000hooooo`;o0000>oooool2o`0001Oooooo0_l0000Aooooo`00
7_ooool00ol0003oooooooooo`08ooooo`;o0000E?ooool2o`0000[ooooo0_l0000hooooo`;o0000
>?ooool2o`0001gooooo0_l0000Looooo`;o0000:_ooool001kooooo0_l0000]ooooo`;o0000??oo
ool2o`0003Kooooo0_l00009ooooo`;o0000;_ooool2o`0001kooooo0_l00018ooooo`007_ooool0
0ol0003oooooooooo`0/ooooo`;o00001_ooool2o`0000Oooooo0_l0000Wooooo`;o0000>_ooool2
o`0000Wooooo0_l0000^ooooo`;o0000F_ooool2o`0000cooooo000Nooooo`03o`000?oooooooooo
033ooooo0_l00002ooooo`;o00001oooool2o`0000Gooooo0_l000000ooooooo0000o`00000Moooo
o`Co000000?oooooo`000?l000003_ooool2o`0005Gooooo0_l0000Tooooo`;o00009oooool2o`00
01Kooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o00007_ooool4o`00013o
oooo0_l000000ooooooo0000o`00000=ooooo`;o00004?ooool2o`000003ooooool0003o000000ko
oooo0_l00006ooooo`;o0000;Oooool2o`0001kooooo0_l0000Tooooo`;o00009oooool2o`0002Co
oooo000Nooooo`03o`000?oooooooooo013ooooo0_l0000Pooooo`;o000000?oooooo`000?l00000
7oooool2o`0001?ooooo0_l0000Fooooo`;o0000;Oooool2o`0000kooooo0_l00023ooooo`007_oo
ool00ol0003oooooooooo`0eooooo`;o0000;?ooool2o`0000Kooooo0_l0000Nooooo`;o00006_oo
ool2o`0001Wooooo0_l00023ooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o0000Eoooool2
o`0002Kooooo0_l0000Hooooo`Co0000W_ooool001kooooo00?o0000ooooooooool02_ooool2o`00
07Cooooo0_l0000Sooooo`?o00004Oooool2o`0001?ooooo0_l0000Rooooo`;o0000Doooool001ko
oooo00?o0000ooooooooool0H_ooool2o`0001cooooo0_l0000gooooo`;o00004oooool2o`0002;o
oooo0_l0001Cooooo`007_ooool00ol0003oooooooooo`1Rooooo`;o0000Ioooool2o`0001oooooo
1?l0001?ooooo`;o00001_ooool001kooooo00?o0000ooooooooool0LOooool2o`0005Sooooo0_l0
000Oooooo`Co0000?oooool2o`0000kooooo0_l00006ooooo`007_ooool00ol0003oooooooooo`1A
ooooo`;o00007_ooool2o`0006Cooooo0_l00017ooooo`;o00001oooool2o`0000Cooooo0_l0000F
ooooo`007_ooool00ol0003oooooooooo`1Aooooo`;o0000EOooool2o`0002Wooooo0_l00002oooo
o`;o00007oooool2o`0001?ooooo0_l0000Aooooo`;o00001oooool2o`0000?ooooo0_l0000Goooo
o`007_ooool00ol0003oooooooooo`13ooooo`;o00003oooool2o`0000gooooo0_l00004ooooo`;o
0000?Oooool2o`0002Wooooo0_l00006ooooo`;o00006oooool2o`0001?ooooo0_l0000Oooooo`;o
00005oooool001kooooo00?o0000ooooooooool0@oooool2o`0000oooooo0_l0000=ooooo`;o0000
1?ooool2o`0004Oooooo0_l0000Wooooo`;o0000J_ooool001kooooo00?o0000ooooooooool06Ooo
ool2o`0001Cooooo0_l00021ooooo`;o0000:_ooool2o`0006Oooooo000Nooooo`;o00006_ooool3
o`0001?ooooo0_l0001Booooo`;o00008_ooool2o`0003Gooooo0_l0000gooooo`;o0000;_ooool0
01kooooo00?o0000ooooooooool06_ooool2o`0006Oooooo0_l0000Rooooo`;o0000A?ooool2o`00
02Sooooo0_l0000^ooooo`007Oooool2o`00027ooooo0_l0000`ooooo`;o0000V_ooool2o`0002So
oooo0_l0000^ooooo`007Oooool2o`00027ooooo0_l0000`ooooo`;o0000m?ooool001kooooo00?o
0000ooooooooool0Ioooool2o`000=kooooo000Nooooo`03o`000?oooooooooo06Oooooo0_l00020
ooooo`;o00005oooool2o`0004?ooooo000Nooooo`03o`000?oooooooooo013ooooo0_l0001Koooo
o`;o00005_ooool2o`0000kooooo0_l0000Hooooo`;o00006?ooool2o`0001kooooo0_l0000Goooo
o`;o00006Oooool2o`0002Sooooo000Nooooo`03o`000?oooooooooo013ooooo0_l0000nooooo`;o
00006oooool2o`0001Kooooo0_l0000>ooooo`;o00004Oooool2o`0000Gooooo0_l00003ooooo`;o
00004oooool2o`0005;ooooo0_l0000Xooooo`007_ooool00ol0003oooooooooo`1@ooooo`;o0000
E_ooool2o`0000[ooooo0_l0000Hooooo`;o0000<?ooool2o`0004Gooooo000Nooooo`03o`000?oo
oooooooo01Gooooo0_l0000Jooooo`;o00005_ooool2o`0002;ooooo0_l0001Oooooo`;o0000;Ooo
ool2o`000003ooooool0003o000004Gooooo000Nooooo`03o`000?oooooooooo01Gooooo0_l0000>
ooooo`;o00002_ooool2o`0000Kooooo0_l0000>ooooo`;o00008_ooool2o`0008kooooo0_l00018
ooooo`007_ooool00ol0003oooooooooo`0Uooooo`;o00004_ooool2o`0000[ooooo0_l0000ooooo
o`;o0000_oooool001kooooo00?o0000ooooooooool0>oooool2o`0000Sooooo0_l0000Uooooo`;o
00006?ooool2o`0003cooooo0_l0001hooooo`;o00001oooool001kooooo00?o0000ooooooooool0
>oooool2o`0002oooooo0_l0000Aooooo`;o0000@oooool2o`0001Oooooo0_l0001Oooooo`;o0000
1oooool001kooooo00?o0000ooooooooool0Ooooool2o`0005cooooo0_l0000Dooooo`;o0000D_oo
ool001kooooo00?o0000ooooooooool06_ooool2o`0001gooooo0_l0001Hooooo`;o00006_ooool2
o`0002[ooooo0_l0000Fooooo`;o0000D_ooool001kooooo0_l0000Kooooo`;o00002?ooool2o`00
01?ooooo0_l0001Hooooo`;o00005Oooool2o`0000?ooooo0_l0000Zooooo`;o0000;oooool2o`00
03Wooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l0001fooooo`;o00003?ooool2o`0001Oo
oooo0_l0000Looooo`;o0000:Oooool2o`0003Wooooo000Nooooo`03o`000?oooooooooo09cooooo
0_l0000Uooooo`;o00007?ooool2o`0000Wooooo0_l00011ooooo`;o000000?oooooo`000?l00000
4oooool001kooooo00?o0000ooooooooool08?ooool2o`000<[ooooo0_l00011ooooo`;o000000?o
ooooo`000?l000004oooool001kooooo00?o0000ooooooooool00_l0000Nooooo`;o0000QOooool2
o`0009kooooo000Nooooo`03o`000?oooooooooo00;o0000<_ooool2o`0005gooooo0_l0000Boooo
o`;o00009Oooool2o`0001kooooo0_l0001Gooooo`007_ooool00ol0003oooooooooo`0dooooo`;o
0000GOooool2o`0002Sooooo0_l0000:ooooo`;o00000oooool2o`0001kooooo0_l0000Aooooo`;o
0000>Oooool2o`0000Wooooo000Nooooo`03o`000?oooooooooo07cooooo0_l0000oooooo`;o0000
2_ooool2o`0003Kooooo0_l0000Dooooo`;o00008oooool2o`0000Wooooo000Nooooo`03o`000?oo
oooooooo03cooooo0_l0000Hooooo`;o00009?ooool2o`00027ooooo0_l0001fooooo`;o00008_oo
ool2o`0000[ooooo000Nooooo`03o`000?oooooooooo03Sooooo0_l00002ooooo`;o00006?ooool2
o`0002?ooooo0_l0000Rooooo`;o00004oooool2o`0008Gooooo0_l0000:ooooo`007_ooool00ol0
003oooooooooo`04ooooo`;o0000<_ooool2o`0001Oooooo0_l0000Xooooo`;o00002Oooool2o`00
01cooooo0_l0000>ooooo`;o00002Oooool2o`0004Sooooo0_l0000looooo`007_ooool00ol0003o
ooooooooo`04ooooo`;o0000Boooool2o`0001?ooooo0_l0000Cooooo`;o00002Oooool2o`0001co
oooo0_l0000Iooooo`;o00002Oooool4o`0003_ooooo0_l0000Qooooo`;o00006Oooool001kooooo
00?o0000ooooooooool0;oooool2o`0000Kooooo0_l0000Oooooo`;o00003?ooool2o`0001?ooooo
0_l0000Jooooo`;o00000oooool4o`0001;ooooo0_l0000Fooooo`Co0000G_ooool2o`0001Wooooo
000Nooooo`03o`000?oooooooooo02oooooo0_l00006ooooo`;o00006Oooool2o`0000Cooooo0_l0
000mooooo`;o00000oooool4o`0001;ooooo0_l0000Qooooo`;o00001oooool2o`0002Cooooo0_l0
0011ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o
410@ooooooooool01?ooool00ol0003oooooooooo`0kooooo`;o00005Oooool2o`0005Oooooo0_l0
0002ooooo`;o00009?ooool3o`0000Kooooo0_l0000Tooooo`;o0000@Oooool000?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo03_ooooo0_l00010ooooo`;o00004Oooool2o`0001Wooooo0_l00002ooooo`;o00006_oo
ool2o`0000Wooooo0_l0001_ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
0006ooooo`?o00000oooool2o`0003kooooo0_l0000<ooooo`;o00001_ooool2o`0002;ooooo0_l0
0004ooooo`;o00002?ooool2o`000003ooooool0003o000003Wooooo0_l0001jooooo`000oooool0
1Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool00ol0003ooooo
ooooo`03ooooo`;o0000?_ooool2o`0000cooooo0_l00006ooooo`;o00009?ooool2o`0000;ooooo
0_l00008ooooo`;o0000Poooool2o`0003?ooooo0003ooooo`05o`000?ooooooooooooooool00000
2oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo07Kooooo0_l00007ooooo`;o
00008Oooool2o`0006kooooo0_l0000cooooo`000oooool01Ol@413ooooooooooooooooo410@00co
oooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`1>ooooo`;o00009_ooool2o`0000_o
oooo0_l0000Mooooo`;o0000P?ooool2o`00027ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo04kooooo0_l0000cooooo`;o
0000Woooool2o`00027ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo
0000ooooo`06ooooo`03o`000?oooooooooo06gooooo0_l00018ooooo`;o0000S_ooool001kooooo
00?o0000ooooooooool03?ooool2o`00013ooooo0_l0001=ooooo`;o0000B?ooool2o`0006Gooooo
0_l000000ooooooo0000o`00000Tooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o00004?oo
ool2o`00023ooooo0_l0001?ooooo`?o0000R_ooool2o`000003ooooool0003o000002Cooooo000N
ooooo`03o`000?oooooooooo043ooooo1?l0000Uooooo`;o00009_ooool3o`0001[ooooo0_l0002G
ooooo`007_ooool00ol0003oooooooooo`0eooooo`;o00002oooool4o`0002?ooooo0_l00004oooo
o`;o0000?Oooool2o`00087ooooo0_l00002ooooo`;o00004?ooool001kooooo00?o0000oooooooo
ool00_l0000Zooooo`;o00001oooool2o`0000gooooo0_l0000Yooooo`;o00006Oooool2o`00077o
oooo0_l0000booooo`;o00000_ooool2o`00013ooooo000Nooooo`03o`000?oooooooooo00;o0000
:_ooool2o`0005cooooo0_l0001^ooooo`;o000000?oooooo`000?l00000B?ooool001kooooo00?o
0000ooooooooool05_ooool2o`0001oooooo0_l0001Eooooo`;o0000J_ooool2o`0001Oooooo0_l0
00000ooooooo0000o`00000_ooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o00001?ooool2
o`0001oooooo0_l00015ooooo`;o00003_ooool2o`0008?ooooo0_l000000ooooooo0000o`00000_
ooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o0000?_ooool2o`0002cooooo0_l0002Poooo
o`;o00009Oooool001kooooo00?o0000ooooooooool0D?ooool2o`0008;ooooo0_l0001:ooooo`;o
00009Oooool001gooooo0_l0002eooooo`;o00007oooool2o`00077ooooo000Mooooo`?o0000ROoo
ool2o`0002Wooooo0_l0000;ooooo`;o0000H?ooool2o`0002?ooooo000Nooooo`03o`000?oooooo
oooo03Gooooo0_l0000Oooooo`;o0000<?ooool2o`0003Kooooo0_l0001Pooooo`;o00008oooool0
01kooooo00?o0000ooooooooool07Oooool2o`0001Kooooo0_l00007ooooo`;o00004oooool2o`00
0003ooooool0003o000001Cooooo0_l0003Iooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o
00007oooool2o`0001?ooooo0_l0000Gooooo`;o00000_ooool2o`000=Gooooo000Nooooo`03o`00
0?oooooooooo073ooooo0ol00033ooooo`;o00003oooool001kooooo00?o0000ooooooooool0BOoo
ool2o`0002Kooooo0_l00033ooooo`;o00003oooool001kooooo00?o0000ooooooooool00_ooool2
o`0002oooooo0_l00009ooooo`;o00002Oooool2o`0001cooooo0_l0003:ooooo`;o00004_ooool0
01kooooo00?o0000ooooooooool00_ooool2o`0002oooooo0_l00009ooooo`;o00009oooool2o`00
03?ooooo0_l0000^ooooo`;o0000A?ooool2o`0000Oooooo0_l00002ooooo`;o00004_ooool2o`00
00;ooooo0_l000000ooooooo0000o`000005ooooo`;o00001?ooool001kooooo00?o0000oooooooo
ool07?ooool2o`0001gooooo0_l0001Oooooo`;o00006_ooool2o`0001;ooooo0_l00014ooooo`;o
00001oooool2o`0000;ooooo0_l0000Fooooo`;o000000?oooooo`000?l000001Oooool2o`0000Co
oooo000Nooooo`03o`000?oooooooooo01cooooo0_l0000=ooooo`;o00003_ooool2o`00017ooooo
0_l0000;ooooo`;o0000>Oooool2o`00023ooooo0_l0001Uooooo`;o00006?ooool2o`0000cooooo
000Nooooo`03o`000?oooooooooo02_ooooo0_l0000Qooooo`;o00002oooool2o`0003Wooooo0_l0
001Xooooo`;o00006oooool4o`0000Kooooo0_l0000@ooooo`;o00003?ooool001kooooo0_l0000X
ooooo`;o0000U_ooool2o`0003oooooo0_l0000Kooooo`;o00002?ooool2o`0001kooooo000Noooo
o`;o0000:?ooool2o`0009Kooooo0_l00026ooooo`007_ooool00ol0003oooooooooo`0Booooo`;o
0000KOooool2o`0002[ooooo0_l0001Rooooo`;o0000=?ooool001kooooo00?o0000ooooooooool0
4_ooool2o`0005Cooooo0_l0000=ooooo`;o00002?ooool2o`0002[ooooo0_l0001Rooooo`;o0000
=?ooool001kooooo00Co0000oooooooooooooooo0_l0001Uooooo`;o00003Oooool2o`0001?ooooo
0_l00003ooooo`;o0000]?ooool001kooooo0_l00002ooooo`;o00008?ooool2o`0002?ooooo0_l0
0012ooooo`;o00000oooool2o`000003ooooool0003o000006cooooo0_l00013ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`;o00008oooool2o`0000Sooooo0_l0000kooooo`Co000000?ooooo
o`000?l00000Boooool2o`0001oooooo0_l0000hooooo`;o00002Oooool001kooooo00?o0000oooo
ooooool06_ooool2o`0003Kooooo0_l0000Eooooo`;o00009?ooool4o`0004kooooo0_l0001Ioooo
o`;o00002Oooool001kooooo00?o0000ooooooooool06_ooool2o`0004[ooooo0_l000000ooooooo
0000o`00000Pooooo`;o0000KOooool2o`0004_ooooo000Nooooo`03o`000?oooooooooo06Kooooo
0_l0000?ooooo`;o00004_ooool2o`0006gooooo0_l0000`ooooo`;o00006Oooool001kooooo00?o
0000ooooooooool0Doooool2o`0002;ooooo0_l0002cooooo`;o00006Oooool001kooooo00?o0000
ooooooooool0Doooool2o`0001gooooo0_l00010ooooo`;o0000TOooool001kooooo00?o0000oooo
ooooool07Oooool2o`0005?ooooo0_l00010ooooo`;o0000TOooool001kooooo00?o0000oooooooo
ool07Oooool2o`0000Gooooo0_l0002Tooooo`;o0000Boooool2o`0001kooooo0_l0000>ooooo`00
7_ooool00ol0003oooooooooo`0>ooooo`;o00005?ooool2o`000:Cooooo0_l0000Jooooo`;o0000
;oooool2o`0001kooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o0000Tooo
ool2o`00047ooooo0_l0001Oooooo`007_ooool00ol0003oooooooooo`2Sooooo`;o000000?ooooo
o`000?l000005_ooool2o`0004;ooooo0_l00013ooooo`007_ooool00ol0003oooooooooo`2Voooo
o`;o00005_ooool2o`0001Gooooo0_l0000Fooooo`;o00004?ooool2o`000003ooooool0003o0000
00Cooooo0_l0000Looooo`;o00007oooool001kooooo00?o0000ooooooooool0Aoooool2o`0008co
oooo0_l0000Fooooo`;o00004?ooool2o`0000Oooooo0_l0000Looooo`;o00004Oooool2o`0000co
oooo000Nooooo`03o`000?oooooooooo04Oooooo0_l0003`ooooo`;o00001_ooool2o`0000Cooooo
000Nooooo`03o`000?oooooooooo04Sooooo0_l0000oooooo`;o00001_ooool2o`0008Gooooo0_l0
000Booooo`;o00001?ooool2o`0000gooooo0_l00004ooooo`007_ooool2o`0002Gooooo0_l0000R
ooooo`;o0000?oooool2o`0000Kooooo0_l00013ooooo`;o0000@?ooool2o`0001;ooooo0_l00004
ooooo`;o00004oooool001kooooo00?o0000ooooooooool09?ooool2o`0001Kooooo0_l0002Hoooo
o`;o00009Oooool2o`0003[ooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o
00008_ooool3o`0005Oooooo0_l0001Vooooo`;o00002_ooool2o`0002kooooo0_l0000<ooooo`00
7_ooool00ol0003oooooooooo`09ooooo`;o00003?ooool2o`0002;ooooo0_l0001Hooooo`;o0000
L_ooool2o`0003Cooooo0_l00006ooooo`007_ooool00ol0003oooooooooo`09ooooo`;o00005?oo
ool2o`000?oooooo7oooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo017ooooo0_l0000<
ooooo`;o0000>?ooool2o`000>cooooo000Nooooo`03o`000?oooooooooo017ooooo0_l00016oooo
o`;o0000Toooool2o`0005Oooooo000Nooooo`03o`000?oooooooooo01_ooooo0_l0000/ooooo`;o
0000Xoooool2o`0005Oooooo000Nooooo`03o`000?oooooooooo01_ooooo0_l0000/ooooo`;o0000
o?ooool001kooooo00?o0000ooooooooool0^oooool2o`0008[ooooo000Nooooo`03o`000?oooooo
oooo00;o0000AOooool2o`0007;ooooo0_l0002:ooooo`007_ooool00ol0003oooooooooo`02o`00
04Gooooo0_l0001gooooo`;o0000?Oooool2o`0002Oooooo0_l0000Dooooo`;o00001oooool001ko
oooo00?o0000ooooooooool0ZOooool2o`0001Gooooo0_l0000?ooooo`;o00006?ooool2o`0000go
oooo1?l000000ooooooo0000o`00000Wooooo`;o00005?ooool2o`0000Oooooo000Nooooo`03o`00
0?oooooooooo00[ooooo0_l0001?ooooo`;o00004oooool2o`0003Oooooo0_l0000Pooooo`;o0000
1?ooool2o`0001Sooooo0_l0000=ooooo`Co0000BOooool000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000oooooooo
ool02_ooool2o`0001Kooooo0_l0000gooooo`;o00004Oooool4o`0001Oooooo0_l00010ooooo`;o
00007oooool2o`0005Wooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`04o`000?ooooooooooooooo`;o00007oooool2
o`0004[ooooo0_l0000Iooooo`;o0000HOooool2o`0005Wooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol000000ooooooo0000o`00
000fooooo`;o00001_ooool2o`0000Oooooo0_l00029ooooo`;o00006oooool2o`00037ooooo0_l0
000Pooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RH
ob4Q8@06ooooo`03o`000?oooooooooo03Wooooo0_l00006ooooo`;o00001oooool2o`0008Wooooo
0_l0000Kooooo`;o00004?ooool2o`0001oooooo0_l0000Pooooo`000oooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo073o
oooo0_l0000Oooooo`;o00004_ooool2o`0002Kooooo0_l0000eooooo`;o0000;_ooool2o`00017o
oooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03
o`000?oooooooooo00Kooooo0_l0000Jooooo`;o0000C?ooool2o`0001oooooo0_l0000Booooo`;o
00008oooool2o`000003ooooool0003o000000Kooooo0_l0000Nooooo`;o0000?Oooool2o`00017o
oooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03
o`000?oooooooooo00Kooooo0_l0000Jooooo`;o0000>?ooool2o`0006cooooo0ol00008ooooo`;o
00007_ooool2o`0000;ooooo0_l0000=ooooo`;o0000?Oooool000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0G?ooool2o`00
06gooooo0_l0000/ooooo`;o00003Oooool2o`0003gooooo000Nooooo`03o`000?oooooooooo04So
oooo0_l0000gooooo`;o0000a?ooool001kooooo00?o0000ooooooooool0B?ooool2o`0003Oooooo
0_l0000Xooooo`;o0000V_ooool001kooooo00?o0000ooooooooool0Zoooool2o`0006_ooooo0_l0
000]ooooo`007_ooool00ol0003oooooooooo`2;ooooo`;o0000R_ooool3o`0001;ooooo0_l0000I
ooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o0000J_ooool2o`0000Oooooo0_l00017oooo
o`;o0000>?ooool2o`0001?ooooo0_l0000Iooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o
0000:_ooool2o`0001kooooo0_l0000Wooooo`;o0000Aoooool2o`0000Wooooo0_l0001Mooooo`00
7_ooool00ol0003oooooooooo`0dooooo`;o00005Oooool2o`0001kooooo0_l0001kooooo`;o0000
2?ooool2o`0001oooooo0_l0000booooo`007_ooool00ol0003oooooooooo`0dooooo`;o0000_?oo
ool2o`0000Cooooo0_l00002ooooo`;o00001?ooool2o`0000oooooo0_l0000booooo`007_ooool0
0ol0003oooooooooo`3hooooo`;o00000_ooool2o`0000Cooooo0_l0000Looooo`;o00009Oooool0
01kooooo00?o0000ooooooooool0GOooool2o`00013ooooo0_l00024ooooo`;o00008oooool2o`00
00Cooooo0_l0000Uooooo`007_ooool00ol0003oooooooooo`1Mooooo`;o00004?ooool2o`0008Co
oooo0_l0000;ooooo`;o00005_ooool2o`0002Cooooo0_l00005ooooo`007_ooool2o`000;?ooooo
0_l0001>ooooo`;o0000??ooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo01Sooooo0_l0
001=ooooo`;o00008_ooool2o`0002Gooooo0_l00008ooooo`;o00007oooool2o`0006Sooooo000N
ooooo`03o`000?oooooooooo01Sooooo0_l0000Gooooo`;o0000=?ooool2o`0001Oooooo0_l00009
ooooo`;o0000;oooool2o`0001oooooo0_l0000;ooooo`;o00003?ooool2o`0004gooooo000Noooo
o`03o`000?oooooooooo037ooooo0_l0001=ooooo`;o0000J?ooool2o`0000cooooo0_l0001=oooo
o`007_ooool00ol0003oooooooooo`0Oooooo`;o0000;?ooool2o`000?Sooooo000Nooooo`03o`00
0?oooooooooo01oooooo0_l0000/ooooo`;o0000C?ooool2o`000:[ooooo000Nooooo`03o`000?oo
oooooooo00_ooooo0_l00003ooooo`;o00007_ooool2o`0003?ooooo0_l0000aooooo`;o000000?o
ooooo`000?l00000??ooool2o`0000;ooooo0_l0000Cooooo`;o00008oooool2o`0002kooooo000N
ooooo`03o`000?oooooooooo00_ooooo0_l00003ooooo`;o00000oooool2o`0001Wooooo0_l00000
0ooooooo0000o`00000`ooooo`;o0000<Oooool2o`0002Cooooo0_l0000Iooooo`;o00000_ooool2
o`0001?ooooo0_l0000Sooooo`;o00001_ooool2o`0002Kooooo000Nooooo`03o`000?oooooooooo
01Gooooo0_l0000Looooo`;o0000ROooool2o`0005oooooo0_l0000Vooooo`007_ooool00ol0003o
ooooooooo`22ooooo`;o0000`oooool001kooooo00?o0000ooooooooool0P_ooool2o`0006?ooooo
0_l0001Nooooo`007_ooool00ol0003oooooooooo`1Jooooo`;o0000Roooool2o`0005kooooo000N
ooooo`03o`000?oooooooooo027ooooo0_l0000gooooo`;o00003?ooool2o`0000gooooo0_l0001D
ooooo`;o00008oooool2o`0005?ooooo000Nooooo`03o`000?oooooooooo027ooooo0_l0000Qoooo
o`;o00008_ooool2o`0000gooooo0_l0001Dooooo`;o00008oooool2o`0002Oooooo0_l00006oooo
o`;o00002_ooool2o`0001Kooooo000Nooooo`03o`000?oooooooooo04Cooooo0_l0000Nooooo`;o
00001oooool2o`0006Gooooo0_l000000ooooooo0000o`00000fooooo`;o00002_ooool2o`0000Ko
oooo0_l000000ooooooo0000o`000007ooooo`;o00005_ooool001kooooo00?o0000ooooooooool0
I?ooool2o`0000Oooooo0_l0001Uooooo`;o000000?oooooo`000?l00000=_ooool2o`0001Gooooo
0_l0000Oooooo`007_ooool2o`000?oooooo?oooool2o`0000Sooooo000Nooooo`03o`000?oooooo
oooo02;ooooo0_l00005ooooo`;o00006?ooool2o`0000Cooooo0_l0001Fooooo`;o0000<oooool4
o`00027ooooo0_l00010ooooo`;o00002?ooool001kooooo00?o0000ooooooooool08_ooool2o`00
00Gooooo0_l0000Hooooo`;o00001?ooool2o`00023ooooo0_l0000[ooooo`;o00001oooool2o`00
03?ooooo1?l0000Qooooo`;o0000B_ooool001kooooo00?o0000ooooooooool0Joooool2o`0000[o
oooo0_l0000Oooooo`;o00004oooool2o`0002cooooo0_l0001Tooooo`;o00001?ooool001kooooo
00?o0000ooooooooool0Moooool2o`0001?ooooo0_l0000Oooooo`;o0000;?ooool2o`0006Cooooo
0_l00004ooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o0000Ioooool2o`0007Sooooo0_l0
000oooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o00009?ooool2o`0001oooooo0_l0001B
ooooo`;o0000A_ooool2o`0003oooooo000Nooooo`03o`000?oooooooooo013ooooo0_l0000eoooo
o`Co00007oooool2o`0002?ooooo0_l0000]ooooo`;o00005?ooool2o`0000Wooooo0_l0001Voooo
o`007_ooool00ol0003oooooooooo`03ooooo`;o00002oooool2o`0003Gooooo1?l00014ooooo`;o
00007?ooool3o`0002Cooooo0_l00009ooooo`;o0000;Oooool2o`0003Oooooo000Nooooo`03o`00
0?oooooooooo00?ooooo0_l00013ooooo`;o0000Hoooool3o`0005kooooo0_l0000gooooo`007_oo
ool00ol0003oooooooooo`1Nooooo`;o00009?ooool2o`0006_ooooo0_l0000;ooooo`;o00001?oo
ool2o`00047ooooo000Nooooo`03o`000?oooooooooo05kooooo0_l0000Rooooo`Co00003Oooool2
o`0001Oooooo0_l0000Cooooo`;o0000;_ooool2o`0000_ooooo0_l00004ooooo`;o000000?ooooo
o`000?l000003Oooool2o`0002Oooooo0_l00006ooooo`007_ooool00ol0003oooooooooo`22oooo
o`;o00003oooool2o`0001Oooooo0_l0000Cooooo`;o00009oooool2o`0001_ooooo0_l0000=oooo
o`;o00009oooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo017ooooo0_l0001]ooooo`;o
00008oooool2o`0004?ooooo0_l0001Kooooo`007_ooool00ol0003oooooooooo`0Aooooo`?o0000
K?ooool2o`0002?ooooo0_l0001;ooooo`;o00005Oooool2o`0003cooooo000Nooooo`03o`000?oo
oooooooo01;ooooo0_l0003Nooooo`;o00005Oooool2o`0003cooooo000Nooooo`;o0000loooool2
o`0005?ooooo000Nooooo`03o`000?oooooooooo02Wooooo0_l0000Hooooo`;o0000Loooool2o`00
03Sooooo0_l0000dooooo`;o00007Oooool001kooooo00?o0000ooooooooool0:Oooool2o`0001So
oooo0_l0000^ooooo`;o00009oooool2o`0001[ooooo1?l0001/ooooo`;o00007Oooool001kooooo
00?o0000ooooooooool0AOooool2o`0002cooooo0_l0000Wooooo`;o00007?ooool2o`0008_ooooo
000Nooooo`03o`000?oooooooooo00Kooooo0_l0000^ooooo`;o00003Oooool2o`000<cooooo0_l0
000booooo`007_ooool00ol0003oooooooooo`06ooooo`;o0000;_ooool2o`00043ooooo0_l0000Z
ooooo`;o0000<_ooool2o`0003Wooooo0_l0000booooo`007_ooool00ol0003oooooooooo`1hoooo
o`;o00009Oooool2o`0000?ooooo0_l0000booooo`;o0000KOooool001kooooo00?o0000oooooooo
ool0TOooool2o`0000cooooo0_l0000Xooooo`;o00004_ooool2o`0001Sooooo0_l0000Cooooo`;o
0000>Oooool001kooooo00?o0000ooooooooool0TOooool2o`0000_ooooo0_l0000Yooooo`;o0000
4_ooool2o`0001Sooooo0_l00006ooooo`;o00002oooool2o`0003Wooooo000Nooooo`03o`000?oo
oooooooo09kooooo0_l0000<ooooo`;o0000DOooool2o`0004Kooooo000Nooooo`03o`000?oooooo
oooo023ooooo0_l00017ooooo`;o00001Oooool2o`0003[ooooo0_l00012ooooo`;o0000EOooool0
01kooooo00?o0000ooooooooool08?ooool2o`0001kooooo0_l0000Wooooo`;o00001Oooool2o`00
07kooooo0_l0000Rooooo`;o0000<Oooool001kooooo00?o0000ooooooooool07?ooool2o`0002;o
oooo0_l00006ooooo`;o0000I?ooool2o`0000;ooooo0_l0000Nooooo`;o00005oooool2o`0002Oo
oooo0_l0000Wooooo`;o00002?ooool001kooooo00?o0000ooooooooool07?ooool2o`0002[ooooo
0_l0001Tooooo`;o00000_ooool2o`0001kooooo0_l0000Gooooo`;o0000D?ooool2o`0000Sooooo
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o
8B4Qolc<c006ooooo`03o`000?oooooooooo03[ooooo0_l0001mooooo`;o0000>_ooool2o`00053o
oooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?oo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo03[ooooo0_l0000/ooooo`;o00006oooool2o`00
01Gooooo0_l0000Kooooo`;o0000>_ooool2o`00033ooooo0_l0000Nooooo`000oooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000J?ooool2
o`0001_ooooo0_l0000Eooooo`;o00007_ooool2o`0006Wooooo0_l0000Nooooo`000oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oo
oooooooo0;7ooooo0_l00009ooooo`;o0000ROooool000?ooooo00Go0000ooooooooooooooooo`00
000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`26ooooo`;o0000
3_ooool2o`0001Wooooo0_l0000gooooo`;o00005Oooool2o`0004Cooooo0003ooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000oooooooo
ool0<oooool2o`0000Wooooo0_l00016ooooo`;o00001?ooool2o`0000Sooooo0_l0000eooooo`;o
00006oooool2o`0000[ooooo0_l00009ooooo`;o0000A?ooool000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`0Roooo
o`;o00003oooool2o`0000Wooooo0_l0000Cooooo`;o0000=oooool2o`0003oooooo0_l0000Woooo
o`;o0000Coooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000
oa0@4?nYZJT01_ooool00ol0003oooooooooo`08ooooo`;o00006?ooool2o`0002oooooo0_l0003b
ooooo`007_ooool00ol0003oooooooooo`08ooooo`;o00000oooool3o`0006[ooooo0_l0000moooo
o`;o00001Oooool2o`0005;ooooo0_l00005ooooo`;o0000:_ooool001kooooo00?o0000oooooooo
ool03Oooool3o`0003Kooooo0_l0000booooo`;o00001Oooool2o`0002Sooooo0_l0000<ooooo`;o
00001Oooool2o`0004_ooooo0_l00005ooooo`;o00001Oooool4o`0000cooooo0_l00003ooooo`;o
00005Oooool001kooooo00?o0000ooooooooool0A_ooool2o`000003ooooool0003o000002?ooooo
0_l0000Aooooo`;o0000:?ooool2o`00063ooooo0_l0000>ooooo`;o00003?ooool2o`0000?ooooo
0_l0000Eooooo`007_ooool00ol0003oooooooooo`0Qooooo`;o00002oooool2o`0001Wooooo0_l0
000Sooooo`;o00007?ooool2o`000:Sooooo0_l0000?ooooo`007_ooool00ol0003oooooooooo`0Q
ooooo`;o00002oooool2o`0000Wooooo0_l0001Aooooo`;o0000ROooool2o`0001Gooooo0_l00006
ooooo`;o00003oooool001kooooo00?o0000ooooooooool0>Oooool2o`0006[ooooo0_l0000Boooo
o`;o00004?ooool2o`0002Cooooo1?l0000Rooooo`;o00001oooool2o`0000cooooo0_l0000Goooo
o`007_ooool00ol0003oooooooooo`2Uooooo`;o00004_ooool2o`00013ooooo0_l0000Tooooo`Co
00002oooool2o`0001kooooo0_l00006ooooo`;o00007Oooool001kooooo00?o0000ooooooooool0
a_ooool2o`0000Cooooo0_l0000booooo`;o00009_ooool2o`0001gooooo000Nooooo`03o`000?oo
oooooooo02?ooooo0_l0002Qooooo`;o00001?ooool2o`00027ooooo0_l0001Fooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`;o00009Oooool2o`0000;ooooo0_l0002Eooooo`;o00002?ooool2
o`0000Sooooo1?l0000=ooooo`;o0000>oooool001kooooo00?o0000ooooooooool02?ooool2o`00
02Wooooo0_l0000Eooooo`;o00000_ooool2o`0009Gooooo0_l0000Booooo`Co00003Oooool2o`00
00Wooooo0_l0000Hooooo`;o00005_ooool001kooooo0_l00007ooooo`Co0000:Oooool2o`00033o
oooo0_l0000Aooooo`;o0000I?ooool2o`0003Gooooo0_l0000Hooooo`;o00005_ooool001kooooo
00?o0000ooooooooool01_ooool2o`0002_ooooo0_l00008ooooo`;o00005?ooool2o`00013ooooo
0_l0000Aooooo`;o0000I?ooool2o`0006Oooooo000Nooooo`03o`000?oooooooooo02kooooo0_l0
000=ooooo`;o00005?ooool2o`0003_ooooo0_l0000booooo`;o00002Oooool2o`0000_ooooo0_l0
000Nooooo`;o0000BOooool001kooooo00?o0000ooooooooool0;_ooool2o`00063ooooo0_l0000b
ooooo`;o00002Oooool2o`0000_ooooo0_l0000Eooooo`;o00001oooool2o`0004Wooooo000Noooo
o`03o`000?oooooooooo0?3ooooo0_l000000ooooooo0000o`00000Dooooo`;o0000??ooool001ko
oooo00?o0000ooooooooool0R_ooool2o`0006Cooooo0_l0000Gooooo`;o0000=?ooool2o`0000Ko
oooo000Nooooo`03o`000?oooooooooo00oooooo0_l00008ooooo`;o00008?ooool2o`0004gooooo
0_l00022ooooo`;o00000_ooool2o`0002Oooooo0_l00002ooooo`;o00001_ooool001kooooo00?o
0000ooooooooool03oooool2o`0000Sooooo0_l0000Pooooo`;o0000H?ooool2o`0001[ooooo0_l0
001Cooooo`;o00000_ooool2o`0002Oooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0D
ooooo`;o0000Qoooool2o`0001[ooooo0_l0000Yooooo`;o0000:?ooool2o`0000kooooo0_l0000W
ooooo`007_ooool00ol0003oooooooooo`07ooooo`;o00002oooool2o`0000kooooo0_l0000;oooo
o`;o0000/Oooool2o`0002?ooooo0_l0000Cooooo`;o00009oooool001kooooo00?o0000oooooooo
ool01oooool2o`0001_ooooo0_l0000;ooooo`;o0000?Oooool2o`0009;ooooo0_l00003ooooo`;o
0000??ooool001kooooo00Co0000oooooooooooooooo0_l0001]ooooo`;o0000>oooool2o`0005Go
oooo0_l0000Pooooo`;o00007oooool001kooooo00Co0000oooooooooooooooo0_l00012ooooo`;o
0000I_ooool2o`0000oooooo0_l0000`ooooo`;o000000?oooooo`000?l00000<Oooool2o`0001oo
oooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0000iooooo`;o0000Moooool2o`0000gooooo
0_l0000Qooooo`;o000000?oooooo`000?l000009Oooool2o`0001cooooo0_l0000=ooooo`007_oo
ool00ol0003oooooooooo`0:ooooo`;o00005Oooool2o`000:[ooooo0_l0000dooooo`;o00005Ooo
ool2o`0001cooooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`0Qooooo`;o0000U_ooool2
o`0000gooooo0_l0000Sooooo`;o00005?ooool2o`0004;ooooo000Nooooo`;o00006?ooool2o`00
05Oooooo0_l0000Booooo`;o00001?ooool2o`0002gooooo0_l0000=ooooo`;o00008oooool2o`00
02kooooo0_l0000Xooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o00009Oooool2o`00033o
oooo0_l0000Booooo`;o00001?ooool2o`0002Wooooo0_l0001Vooooo`;o0000:?ooool001kooooo
00?o0000ooooooooool0?_ooool2o`0000oooooo0_l0001Tooooo`;o00007Oooool2o`00077ooooo
000Nooooo`03o`000?oooooooooo04oooooo0_l0000@ooooo`;o0000LOooool2o`0001cooooo0_l0
0010ooooo`;o00004Oooool001kooooo00?o0000ooooooooool0HOooool2o`00013ooooo0_l0000X
ooooo`;o0000C_ooool2o`0000?ooooo0_l0000?ooooo`;o00008oooool2o`0000[ooooo0_l0000A
ooooo`007_ooool00ol0003oooooooooo`09ooooo`;o0000@?ooool2o`0002Kooooo0_l0000Xoooo
o`;o0000C_ooool2o`0001Cooooo0_l0000Sooooo`;o00007Oooool001kooooo00?o0000oooooooo
ool02Oooool2o`0000cooooo0_l0000Hooooo`;o00006?ooool2o`0007Sooooo0_l0000Hooooo`;o
0000I_ooool001kooooo00?o0000ooooooooool05oooool2o`0001Sooooo0_l0001mooooo`;o0000
4oooool2o`0000gooooo0_l00009ooooo`;o0000<oooool2o`00037ooooo000Nooooo`03o`000?oo
oooooooo03oooooo0_l0001_ooooo`;o00003_ooool2o`0001;ooooo0_l0000nooooo`;o0000<Ooo
ool001kooooo00?o0000ooooooooool0?oooool2o`0005Wooooo0_l0000Tooooo`;o0000H_ooool2
o`00027ooooo000Nooooo`03o`000?oooooooooo02Gooooo0_l0001cooooo`;o00003Oooool2o`00
07Wooooo0_l0000Qooooo`007_ooool00ol0003oooooooooo`0Looooo`;o00001oooool2o`0002ko
oooo0_l0000Eooooo`;o00005Oooool2o`0001_ooooo0_l00007ooooo`;o0000@_ooool2o`0005So
oooo000Nooooo`03o`000?oooooooooo01cooooo0_l0000gooooo`;o00005Oooool2o`0001Gooooo
0_l0000Kooooo`;o00003Oooool2o`0003cooooo0_l0000/ooooo`;o0000:_ooool001kooooo00?o
0000ooooooooool0D?ooool2o`0005gooooo0_l0000eooooo`;o00000oooool2o`0002kooooo0_l0
000Zooooo`007_ooool00ol0003oooooooooo`1@ooooo`;o00001_ooool2o`0004Cooooo0_l00011
ooooo`;o00000oooool2o`0000?ooooo0_l0000iooooo`;o00007oooool001kooooo00?o0000oooo
ooooool09_ooool2o`00033ooooo0_l00013ooooo`?o0000<?ooool2o`0000oooooo0_l00013oooo
o`;o00007oooool001kooooo0_l0000Wooooo`?o0000G?ooool2o`0001Kooooo0_l00006ooooo`;o
0000:Oooool3o`0007Cooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l00006ooooo`;o0000
0oooool2o`0004oooooo0_l0000Nooooo`;o0000:_ooool2o`0000Kooooo0_l0001/ooooo`007_oo
ool00ol0003oooooooooo`0_ooooo`;o00000oooool2o`00013ooooo0_l0001:ooooo`;o0000AOoo
ool2o`0002Kooooo0_l00014ooooo`007_ooool00ol0003oooooooooo`16ooooo`;o0000B_ooool2
o`0006gooooo0_l00004ooooo`;o0000:?ooool2o`0001Cooooo000Nooooo`03o`000?oooooooooo
04cooooo0_l0002Booooo`;o00009Oooool2o`0002Sooooo0_l0000Dooooo`007_ooool00ol0003o
ooooooooo`1<ooooo`;o00001_ooool2o`0001_ooooo0_l0001]ooooo`;o00006Oooool2o`0004[o
oooo000Nooooo`03o`000?oooooooooo05Cooooo0_l0000Kooooo`;o0000KOooool2o`0001Wooooo
0_l0001:ooooo`007_ooool2o`0000?ooooo0_l0001<ooooo`;o00009_ooool2o`0004_ooooo0_l0
000Iooooo`;o00005_ooool2o`0002Cooooo0_l0000Wooooo`007_ooool2o`0000?ooooo0_l0000P
ooooo`;o00003oooool2o`0001Wooooo0_l0000Vooooo`;o00004_ooool2o`0003Oooooo0_l0000P
ooooo`;o00003oooool2o`0000Sooooo0_l0000Jooooo`;o00002?ooool2o`0001gooooo000Noooo
o`03o`000?oooooooooo02Cooooo0_l0000?ooooo`;o00002?ooool2o`0004_ooooo0_l0000Moooo
o`;o00007_ooool2o`0001[ooooo0_l0000Iooooo`;o00009?ooool2o`00013ooooo0_l0000;oooo
o`007_ooool00ol0003oooooooooo`0oooooo`;o0000J_ooool2o`0001kooooo0_l0000eooooo`;o
00008Oooool2o`0001?ooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`2Gooooo`;o0000
9?ooool2o`0000Cooooo0_l0000Gooooo`;o0000;Oooool2o`0001Sooooo0_l0000Pooooo`007_oo
ool00ol0003oooooooooo`04ooooo`;o0000Moooool2o`0001Sooooo0_l0000Tooooo`;o00001?oo
ool2o`0001Oooooo0_l0000Looooo`;o00003oooool2o`0003[ooooo000Nooooo`03o`000?oooooo
oooo00Cooooo0_l0001Booooo`;o00008oooool2o`0002Kooooo0_l0000Gooooo`;o0000>_ooool2
o`0003Kooooo0_l0000Cooooo`005?ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooo
ooooool07oooool2o`0003Oooooo0_l0000eooooo`;o00005?ooool2o`0001Oooooo0_l0001boooo
o`;o00004oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Oooooo`;o
000000?oooooo`000?l00000Joooool2o`00013ooooo0_l0001Dooooo`;o000000?oooooo`000?l0
00004_ooool2o`0003Oooooo000Fooooo`03o`000?oooooooooo00Gooooo0ol0000Aooooo`?o0000
3_ooool2o`0000Cooooo0_l0001gooooo`;o0000E?ooool2o`000003ooooool0003o000001;ooooo
0_l0000gooooo`005_ooool00ol0003oooooooooo`0Iooooo`?o00005?ooool2o`000?oooooo7_oo
ool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooo
oe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Cooooo00?oEEEEofIVI_l00000
oooooomBooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.78034 .67598 Mdot
.96043 .29046 Mdot
.6129 .38558 Mdot
.96082 .31756 Mdot
.39774 .52924 Mdot
.3955 .15686 Mdot
.78008 .00891 Mdot
.03599 .13579 Mdot
.78758 .55403 Mdot
.78221 .96471 Mdot
.46992 .61741 Mdot
.77732 .9031 Mdot
.62458 .84553 Mdot
.97467 .4917 Mdot
.06008 .55145 Mdot
.09282 .23438 Mdot
.76406 .01937 Mdot
.59116 .11541 Mdot
.03819 .06223 Mdot
.52623 .96534 Mdot
.20181 .40031 Mdot
.63176 .14995 Mdot
.82428 .78106 Mdot
.84413 .31659 Mdot
.23129 .82377 Mdot
.84303 .82427 Mdot
.95997 .21611 Mdot
.90231 .47681 Mdot
.28788 .23793 Mdot
.225 .3689 Mdot
.26862 .25377 Mdot
.74495 .38252 Mdot
.87605 .83952 Mdot
.06164 .25665 Mdot
.15625 .10737 Mdot
.20008 .00367 Mdot
.02694 .3536 Mdot
.32554 .2315 Mdot
.88223 .14278 Mdot
.45866 .68231 Mdot
.68903 .78792 Mdot
.10267 .32246 Mdot
.51629 .56946 Mdot
.44746 .79859 Mdot
.62151 .72014 Mdot
.24354 .68497 Mdot
.43312 .63965 Mdot
.03012 .67244 Mdot
.58562 .33816 Mdot
.70507 .35427 Mdot
.6766 .22998 Mdot
.31589 .76791 Mdot
.97098 .49504 Mdot
.18621 .37744 Mdot
.54875 .87818 Mdot
.81069 .51335 Mdot
.11479 .06802 Mdot
.47646 .93721 Mdot
.55156 .26898 Mdot
.40503 .2813 Mdot
.89293 .95674 Mdot
.67807 .93673 Mdot
.23776 .5911 Mdot
.35797 .23871 Mdot
.20865 .22577 Mdot
.12776 .85256 Mdot
.63883 .33478 Mdot
.43891 .25268 Mdot
.68971 .32683 Mdot
.00283 .35571 Mdot
.22594 .06013 Mdot
.70992 .11902 Mdot
.08349 .17137 Mdot
.08042 .25271 Mdot
.02972 .48138 Mdot
.72323 .03198 Mdot
.71135 .25957 Mdot
.51045 .22535 Mdot
.03921 .86222 Mdot
.97289 .87934 Mdot
.3145 .60576 Mdot
.04525 .51418 Mdot
.24896 .4974 Mdot
.39821 .34097 Mdot
.03493 .43331 Mdot
.39656 .18432 Mdot
.06291 .87633 Mdot
.68077 .17062 Mdot
.37685 .5369 Mdot
.14181 .97493 Mdot
.41626 .56166 Mdot
.22006 .14339 Mdot
.98136 .16817 Mdot
.14792 .59298 Mdot
.83938 .57045 Mdot
.85263 .16417 Mdot
.74538 .22244 Mdot
.55308 .91385 Mdot
.64661 .40199 Mdot
.77718 .78107 Mdot
.13875 .86699 Mdot
.65611 .83788 Mdot
.80169 .16899 Mdot
.49239 .75103 Mdot
.78651 .11322 Mdot
.26806 .07527 Mdot
.99256 .48893 Mdot
.387 .00494 Mdot
.26307 .2344 Mdot
.92097 .04106 Mdot
.521 .73899 Mdot
.08844 .18274 Mdot
.43246 .98041 Mdot
.51293 .3827 Mdot
.64229 .82495 Mdot
.13769 .80492 Mdot
.80137 .61159 Mdot
.76544 .64486 Mdot
.73931 .12455 Mdot
.25436 .78619 Mdot
.60244 .75187 Mdot
.48124 .77221 Mdot
.95163 .86077 Mdot
.32873 .48578 Mdot
.59452 .96404 Mdot
.87508 .0708 Mdot
.01227 .3321 Mdot
.73653 .27729 Mdot
.29471 .65934 Mdot
.97712 .57876 Mdot
.41964 .5267 Mdot
.71729 .95334 Mdot
.9087 .68004 Mdot
.27869 .25079 Mdot
.00863 .70927 Mdot
.97167 .63986 Mdot
.29807 .69814 Mdot
.0601 .71747 Mdot
.23506 .43509 Mdot
.36764 .32102 Mdot
.0023 .8339 Mdot
.4213 .78032 Mdot
.65329 .30605 Mdot
.71213 .75237 Mdot
.68133 .57646 Mdot
.45838 .55005 Mdot
.79007 .83797 Mdot
.38566 .91993 Mdot
.56237 .05822 Mdot
.36137 .24163 Mdot
.17532 .59639 Mdot
.93225 .94591 Mdot
.15567 .6234 Mdot
.63094 .13573 Mdot
.54946 .32661 Mdot
.84309 .33446 Mdot
.72365 .89272 Mdot
.53571 .62982 Mdot
.87304 .04877 Mdot
.96962 .8136 Mdot
.40484 .04296 Mdot
.64217 .46918 Mdot
.09691 .64022 Mdot
.76286 .66517 Mdot
.91813 .89575 Mdot
.2063 .4276 Mdot
.4854 .41935 Mdot
.29847 .18024 Mdot
.67031 .60285 Mdot
.81228 .505 Mdot
.79286 .42946 Mdot
.73208 .66281 Mdot
.49452 .45718 Mdot
.05492 .22956 Mdot
.37713 .90761 Mdot
.33941 .54584 Mdot
.36983 .94898 Mdot
.19224 .19819 Mdot
.8559 .62631 Mdot
.95224 .07072 Mdot
.19213 .88018 Mdot
.96134 .51312 Mdot
.30983 .42536 Mdot
.20754 .88772 Mdot
.91378 .86478 Mdot
.14469 .60747 Mdot
.61371 .09406 Mdot
.80259 .07251 Mdot
.1599 .05454 Mdot
.66122 .8741 Mdot
.36155 .41566 Mdot
.78725 .84304 Mdot
.23706 .46732 Mdot
.70527 .32084 Mdot
.80173 .17475 Mdot
.47787 .45541 Mdot
.93243 .195 Mdot
.25359 .7526 Mdot
.36335 .16406 Mdot
.44305 .67774 Mdot
.99236 .08128 Mdot
.89491 .78137 Mdot
.72168 .64513 Mdot
.05486 .855 Mdot
.40801 .144 Mdot
.46451 .54425 Mdot
.68591 .94669 Mdot
.95293 .10129 Mdot
.78666 .83112 Mdot
.66425 .20422 Mdot
.53935 .70182 Mdot
.14254 .43785 Mdot
.37122 .48061 Mdot
.13227 .51741 Mdot
.79797 .83 Mdot
.10254 .54632 Mdot
.27496 .71662 Mdot
.59588 .05242 Mdot
.65914 .74426 Mdot
.79207 .98358 Mdot
.90952 .97477 Mdot
.2323 .79571 Mdot
.41899 .36866 Mdot
.07336 .27699 Mdot
.00224 .80501 Mdot
.00656 .81066 Mdot
.16336 .01432 Mdot
.84137 .16564 Mdot
.78951 .13183 Mdot
.24312 .14184 Mdot
.15403 .33844 Mdot
.29525 .21569 Mdot
.09724 .35776 Mdot
.20965 .43512 Mdot
.75772 .92334 Mdot
.13206 .16848 Mdot
.80052 .07642 Mdot
.17209 .40861 Mdot
.59143 .17706 Mdot
.32571 .15747 Mdot
.87918 .99587 Mdot
.21721 .05277 Mdot
.79798 .58323 Mdot
.82815 .8125 Mdot
.58387 .20524 Mdot
.61984 .25273 Mdot
.83797 .23107 Mdot
.46822 .1021 Mdot
.06207 .13069 Mdot
.2956 .72721 Mdot
.29291 .92949 Mdot
.78181 .60159 Mdot
.53194 .95501 Mdot
.61145 .49751 Mdot
.67331 .36043 Mdot
.72954 .71581 Mdot
.06082 .13763 Mdot
.09404 .44222 Mdot
.1123 .00149 Mdot
.64489 .40463 Mdot
.13586 .75375 Mdot
.41664 .74842 Mdot
.81257 .94219 Mdot
.68878 .22717 Mdot
.34317 .86538 Mdot
.1048 .72723 Mdot
.57772 .48634 Mdot
.48202 .9208 Mdot
.53278 .38332 Mdot
.189 .34064 Mdot
.16258 .4539 Mdot
.63515 .94699 Mdot
.13536 .63507 Mdot
.01393 .14822 Mdot
.34876 .63155 Mdot
.45959 .07239 Mdot
.0685 .66904 Mdot
.32814 .33265 Mdot
.43778 .14345 Mdot
.84827 .62244 Mdot
.07033 .79136 Mdot
.65503 .18721 Mdot
.77446 .30281 Mdot
.9809 .19824 Mdot
.78257 .82196 Mdot
.91471 .9447 Mdot
.4768 .086 Mdot
.53265 .96306 Mdot
.56115 .36655 Mdot
.27681 .49454 Mdot
.15325 .14619 Mdot
.44649 .04295 Mdot
.16141 .45757 Mdot
.67243 .90993 Mdot
.25577 .99633 Mdot
.6877 .57358 Mdot
.49898 .34907 Mdot
.87207 .58658 Mdot
.21236 .26478 Mdot
.34216 .69582 Mdot
.67355 .92855 Mdot
.20508 .11691 Mdot
.62273 .72232 Mdot
.74596 .98022 Mdot
.46783 .17205 Mdot
.98852 .20476 Mdot
.01233 .00978 Mdot
.23896 .68021 Mdot
.43984 .78587 Mdot
.53541 .02663 Mdot
.36978 .46077 Mdot
.26723 .4071 Mdot
.68867 .67314 Mdot
.15296 .44566 Mdot
.31882 .89285 Mdot
.35527 .36068 Mdot
.82094 .81173 Mdot
.35095 .09775 Mdot
.70002 .7666 Mdot
.97291 .42066 Mdot
.26429 .98919 Mdot
.51976 .39479 Mdot
.82356 .36661 Mdot
.2189 .0265 Mdot
.98354 .875 Mdot
.14098 .53534 Mdot
.73181 .89055 Mdot
.81751 .20069 Mdot
.96003 .06957 Mdot
.50408 .06296 Mdot
.33372 .37616 Mdot
.53605 .71004 Mdot
.03046 .40167 Mdot
.0124 .23375 Mdot
.31763 .05409 Mdot
.76421 .28991 Mdot
.09567 .26119 Mdot
.51645 .6919 Mdot
.44687 .40034 Mdot
.77588 .62048 Mdot
.34238 .31075 Mdot
.29463 .47582 Mdot
.15609 .87763 Mdot
.81901 .76734 Mdot
.01355 .46384 Mdot
.76443 .63249 Mdot
.88809 .4039 Mdot
.04184 .2173 Mdot
.706 .18383 Mdot
.5197 .45342 Mdot
.37824 .86099 Mdot
.69243 .00711 Mdot
.85822 .50817 Mdot
.37618 .56783 Mdot
.60104 .62148 Mdot
.53546 .72631 Mdot
.57422 .0816 Mdot
.82713 .04565 Mdot
.7219 .62133 Mdot
.8712 .87825 Mdot
.95312 .40928 Mdot
.27731 .35067 Mdot
.74274 .61938 Mdot
.57054 .35271 Mdot
.78214 .03876 Mdot
.25695 .94977 Mdot
.01434 .52958 Mdot
.57224 .17703 Mdot
.56772 .38126 Mdot
.70947 .06585 Mdot
.95753 .66801 Mdot
.87974 .1849 Mdot
.89611 .23243 Mdot
.54985 .8318 Mdot
.21983 .59967 Mdot
.95533 .45436 Mdot
.43434 .48515 Mdot
.79351 .59148 Mdot
.2744 .95903 Mdot
.16769 .32598 Mdot
.67361 .64998 Mdot
.53716 .31115 Mdot
.78186 .87876 Mdot
.64456 .001 Mdot
.87701 .47889 Mdot
.08047 .16378 Mdot
.71486 .88182 Mdot
.20536 .63867 Mdot
.24067 .28014 Mdot
.34627 .14062 Mdot
.96682 .23901 Mdot
.31093 .7036 Mdot
.32229 .60828 Mdot
.71337 .38464 Mdot
.37111 .92679 Mdot
.18706 .39177 Mdot
.61095 .37198 Mdot
.9804 .18578 Mdot
.88571 .65851 Mdot
.88641 .47388 Mdot
.6402 .26417 Mdot
.27808 .43066 Mdot
.61087 .04183 Mdot
.11315 .76643 Mdot
.28187 .29586 Mdot
.46541 .27244 Mdot
.91845 .44383 Mdot
.29552 .97328 Mdot
.31775 .93341 Mdot
.28293 .63668 Mdot
.48346 .37011 Mdot
.51664 .191 Mdot
.88064 .14955 Mdot
.0683 .70291 Mdot
.28722 .13771 Mdot
.9326 .04358 Mdot
.84007 .87235 Mdot
.42965 .71609 Mdot
.98957 .4582 Mdot
.10644 .87547 Mdot
.64402 .39842 Mdot
.78174 .10598 Mdot
.15596 .96748 Mdot
.20951 .02535 Mdot
.25922 .96902 Mdot
.19735 .26993 Mdot
.23559 .84345 Mdot
.16676 .26927 Mdot
.24836 .84983 Mdot
.66218 .49152 Mdot
.27315 .49879 Mdot
.44962 .71354 Mdot
.70897 .05278 Mdot
.74783 .49635 Mdot
.38787 .1152 Mdot
.521 .60955 Mdot
.18733 .15565 Mdot
.39604 .38992 Mdot
.91427 .38352 Mdot
.1588 .09581 Mdot
.494 .39241 Mdot
.47601 .51286 Mdot
.17883 .76704 Mdot
.08816 .9482 Mdot
.57948 .60029 Mdot
.2893 .36191 Mdot
.06729 .56955 Mdot
.68598 .80361 Mdot
.04248 .53575 Mdot
.21056 .46354 Mdot
.00854 .19767 Mdot
.98216 .52419 Mdot
.52191 .73094 Mdot
.4683 .93932 Mdot
.24073 .03219 Mdot
.51351 .98746 Mdot
.73512 .22291 Mdot
.34256 .65144 Mdot
.70339 .58323 Mdot
.58869 .81203 Mdot
.62256 .22891 Mdot
.21573 .24286 Mdot
.55878 .06057 Mdot
.22048 .78784 Mdot
.01867 .23068 Mdot
.81283 .93187 Mdot
.75568 .22573 Mdot
.40088 .94267 Mdot
.05102 .98443 Mdot
.0423 .2801 Mdot
.4446 .25132 Mdot
.51066 .49687 Mdot
.78667 .08683 Mdot
.15226 .2951 Mdot
.18956 .12864 Mdot
.90008 .61384 Mdot
.06064 .86996 Mdot
.15289 .75165 Mdot
.26264 .69436 Mdot
.76446 .88753 Mdot
.32072 .75059 Mdot
.60443 .51312 Mdot
.85783 .40268 Mdot
.2107 .94241 Mdot
.12942 .30409 Mdot
.99177 .57162 Mdot
.84655 .19801 Mdot
.10244 .07758 Mdot
.72536 .28466 Mdot
.04903 .34738 Mdot
.33081 .60362 Mdot
.36115 .46637 Mdot
.07386 .08635 Mdot
.69131 .04202 Mdot
.30126 .5476 Mdot
.62733 .00639 Mdot
.20677 .26003 Mdot
.65505 .37039 Mdot
.51515 .01003 Mdot
.56615 .35063 Mdot
.75015 .77913 Mdot
.50794 .07996 Mdot
.39134 .99038 Mdot
.18778 .53487 Mdot
.19772 .07378 Mdot
.46116 .53559 Mdot
.97656 .44189 Mdot
.7962 .61477 Mdot
.58474 .13002 Mdot
.08929 .12751 Mdot
.05847 .03267 Mdot
.57795 .69461 Mdot
.39852 .34548 Mdot
.06648 .63109 Mdot
.95965 .3229 Mdot
.92448 .12206 Mdot
.66706 .35281 Mdot
.62911 .5404 Mdot
.85254 .91005 Mdot
.78373 .07083 Mdot
.22115 .79633 Mdot
.72232 .94697 Mdot
.17032 .69069 Mdot
.14933 .17533 Mdot
.83464 .3133 Mdot
.06458 .51386 Mdot
.90251 .85314 Mdot
.23069 .32975 Mdot
.10234 .61127 Mdot
.59784 .80096 Mdot
.26009 .71779 Mdot
.75479 .62788 Mdot
.09629 .96127 Mdot
.96252 .64685 Mdot
.85323 .21759 Mdot
.77863 .48823 Mdot
.91308 .87502 Mdot
.66561 .01677 Mdot
.07585 .0968 Mdot
.6051 .79186 Mdot
.76261 .55765 Mdot
.89623 .05296 Mdot
.54613 .74667 Mdot
.18925 .35003 Mdot
.5307 .95202 Mdot
.28635 .66084 Mdot
.60748 .65287 Mdot
.44381 .0895 Mdot
.76217 .71421 Mdot
.86217 .05293 Mdot
.72876 .66308 Mdot
.24259 .295 Mdot
.93269 .26641 Mdot
.35232 .34645 Mdot
.3459 .43347 Mdot
.19272 .03899 Mdot
.89802 .51713 Mdot
.91587 .37639 Mdot
.32704 .87606 Mdot
.44044 .24905 Mdot
.61121 .06579 Mdot
.5753 .20574 Mdot
.90485 .28707 Mdot
.17346 .00581 Mdot
.95071 .00522 Mdot
.83477 .74461 Mdot
.56232 .55538 Mdot
.70598 .77158 Mdot
.61562 .10891 Mdot
.91807 .34128 Mdot
.2703 .28138 Mdot
.4774 .11693 Mdot
.86751 .19907 Mdot
.90361 .72852 Mdot
.05957 .91238 Mdot
.73446 .78577 Mdot
.13484 .88249 Mdot
.78711 .16715 Mdot
.38008 .28739 Mdot
.18873 .41428 Mdot
.80443 .20535 Mdot
.24653 .10768 Mdot
.45164 .96199 Mdot
.69539 .0137 Mdot
.56242 .83523 Mdot
.83206 .19968 Mdot
.64563 .88084 Mdot
.01536 .46352 Mdot
.60416 .00285 Mdot
.14151 .2536 Mdot
.24375 .81327 Mdot
.01669 .84358 Mdot
.39899 .53058 Mdot
.78482 .76558 Mdot
.94906 .51523 Mdot
.15892 .79254 Mdot
.44776 .82585 Mdot
.3738 .51682 Mdot
.83989 .85336 Mdot
.23471 .14938 Mdot
.11498 .88821 Mdot
.17108 .96013 Mdot
.97209 .19976 Mdot
.02756 .19378 Mdot
.68653 .59894 Mdot
.35388 .42916 Mdot
.53793 .93821 Mdot
.26803 .58037 Mdot
.07883 .17861 Mdot
.88557 .07408 Mdot
.48938 .20779 Mdot
.6672 .92091 Mdot
.1879 .26493 Mdot
.56326 .91144 Mdot
.31077 .12668 Mdot
.50267 .81608 Mdot
.67131 .62821 Mdot
.24918 .37156 Mdot
.97276 .68031 Mdot
.98218 .71702 Mdot
.84246 .39375 Mdot
.15293 .57991 Mdot
.45898 .22318 Mdot
.45912 .63106 Mdot
.06256 .99385 Mdot
.91315 .59371 Mdot
.88194 .84465 Mdot
.36991 .74619 Mdot
.30759 .24353 Mdot
.20902 .32574 Mdot
.13801 .54633 Mdot
.16795 .48153 Mdot
.25539 .22886 Mdot
.04728 .87698 Mdot
.90548 .94919 Mdot
.73678 .25532 Mdot
.78941 .91427 Mdot
.75452 .58667 Mdot
.81083 .19365 Mdot
.20918 .83629 Mdot
.62254 .93317 Mdot
.13739 .4313 Mdot
.34611 .43282 Mdot
.73829 .86446 Mdot
.04265 .15972 Mdot
.7083 .8708 Mdot
.2586 .23733 Mdot
.9878 .57542 Mdot
.43572 .23327 Mdot
.22195 .90919 Mdot
.60701 .95819 Mdot
.06378 .20633 Mdot
.0185 .90559 Mdot
.90541 .91807 Mdot
.5505 .54206 Mdot
.09705 .9025 Mdot
.50855 .41006 Mdot
.49037 .1424 Mdot
.29108 .22054 Mdot
.52379 .55634 Mdot
.74753 .99873 Mdot
.10321 .53558 Mdot
.15603 .96736 Mdot
.17183 .31293 Mdot
.22358 .92457 Mdot
.19157 .48261 Mdot
.7722 .29624 Mdot
.19596 .50868 Mdot
.3222 .94844 Mdot
.5664 .33359 Mdot
.10219 .59126 Mdot
.23181 .66221 Mdot
.41677 .79157 Mdot
.00238 .17515 Mdot
.05567 .73219 Mdot
.85846 .69145 Mdot
.78955 .81278 Mdot
.61044 .29285 Mdot
.03611 .63206 Mdot
.521 .75866 Mdot
.60522 .73173 Mdot
.80016 .54073 Mdot
.45129 .04823 Mdot
.68808 .77616 Mdot
.1635 .24817 Mdot
.6206 .62876 Mdot
.02791 .52923 Mdot
.83266 .96216 Mdot
.30186 .68196 Mdot
.12265 .68344 Mdot
.24527 .0597 Mdot
.7288 .84097 Mdot
.70749 .32559 Mdot
.92874 .26455 Mdot
.3462 .3625 Mdot
.21198 .40507 Mdot
.15582 .09304 Mdot
.69414 .68645 Mdot
.19904 .48342 Mdot
.85081 .76311 Mdot
.8496 .96461 Mdot
.73765 .21483 Mdot
.50641 .77445 Mdot
.88662 .44929 Mdot
.86996 .48831 Mdot
.00106 .11048 Mdot
.59756 .17904 Mdot
.63051 .61089 Mdot
.43196 .15179 Mdot
.01549 .92968 Mdot
.30128 .52994 Mdot
.2254 .12954 Mdot
.42657 .72613 Mdot
.56945 .90919 Mdot
.84048 .83411 Mdot
.4872 .48957 Mdot
.06848 .34127 Mdot
.51942 .35017 Mdot
.31798 .17487 Mdot
.84128 .71289 Mdot
.95474 .03671 Mdot
.77621 .79007 Mdot
.75194 .3857 Mdot
.60528 .69433 Mdot
.42313 .78866 Mdot
.14516 .95899 Mdot
.50842 .85467 Mdot
.50764 .4314 Mdot
.51499 .68878 Mdot
.02857 .13783 Mdot
.23972 .47355 Mdot
.1342 .38184 Mdot
.03311 .56319 Mdot
.43549 .60562 Mdot
.27364 .05256 Mdot
.87149 .7816 Mdot
.02905 .28995 Mdot
.8007 .80083 Mdot
.58217 .45049 Mdot
.38898 .3659 Mdot
.14318 .81014 Mdot
.41209 .28261 Mdot
.91205 .27414 Mdot
.11735 .93253 Mdot
.8393 .83042 Mdot
.68748 .38483 Mdot
.45167 .66927 Mdot
.86869 .69332 Mdot
.39306 .40651 Mdot
.13989 .91042 Mdot
.81868 .0054 Mdot
.70236 .57144 Mdot
.81706 .26075 Mdot
.43825 .18806 Mdot
.84382 .02178 Mdot
.29858 .30301 Mdot
.95639 .17049 Mdot
.49529 .94958 Mdot
.47243 .40454 Mdot
.55942 .28865 Mdot
.08019 .92862 Mdot
.6015 .39428 Mdot
.25921 .00905 Mdot
.88525 .97269 Mdot
.44899 .73806 Mdot
.55662 .78948 Mdot
.71643 .80407 Mdot
.32973 .40122 Mdot
.70346 .57639 Mdot
.81757 .53016 Mdot
.29915 .22452 Mdot
.06188 .17231 Mdot
.12102 .13477 Mdot
.36913 .76555 Mdot
.95367 .24787 Mdot
.63375 .72972 Mdot
.36488 .4099 Mdot
.00117 .12146 Mdot
.54077 .77528 Mdot
.78336 .71948 Mdot
.908 .17347 Mdot
.97432 .21818 Mdot
.48034 .06448 Mdot
.9583 .02435 Mdot
.47545 .85532 Mdot
.44012 .25885 Mdot
.54869 .72192 Mdot
.926 .44572 Mdot
.27727 .11809 Mdot
.90383 .43071 Mdot
.58008 .37386 Mdot
.02269 .80588 Mdot
.83699 .26331 Mdot
.99801 .58278 Mdot
.25581 .26644 Mdot
.02259 .64089 Mdot
.85161 .45895 Mdot
.55734 .319 Mdot
.14481 .85714 Mdot
.7123 .7624 Mdot
.99885 .57262 Mdot
.78126 .34166 Mdot
.42141 .18354 Mdot
.81164 .61267 Mdot
.65467 .97307 Mdot
.74939 .95689 Mdot
.49832 .73612 Mdot
.55785 .26311 Mdot
.66619 .21624 Mdot
.13143 .92482 Mdot
.49264 .39558 Mdot
.46075 .03218 Mdot
.39486 .73949 Mdot
.55484 .75355 Mdot
.14251 .63163 Mdot
.88991 .14506 Mdot
.33191 .68149 Mdot
.06166 .22748 Mdot
.94201 .96114 Mdot
.53664 .86746 Mdot
.34083 .74503 Mdot
.53017 .05046 Mdot
.87948 .24591 Mdot
.10105 .00733 Mdot
.3686 .428 Mdot
.43809 .34863 Mdot
.25912 .78383 Mdot
.56537 .08714 Mdot
.92095 .28552 Mdot
.50943 .9363 Mdot
.92059 .29948 Mdot
.93869 .99896 Mdot
.68705 .68399 Mdot
.53344 .96196 Mdot
.78486 .3448 Mdot
.3452 .99922 Mdot
.39394 .9729 Mdot
.96894 .81324 Mdot
.10737 .01958 Mdot
.27917 .65503 Mdot
.12691 .79781 Mdot
.86138 .72261 Mdot
.25756 .42848 Mdot
.91723 .70412 Mdot
.64859 .72795 Mdot
.45463 .74732 Mdot
.84048 .39672 Mdot
.92802 .81037 Mdot
.4323 .49634 Mdot
.01909 .0449 Mdot
.26188 .48225 Mdot
.60003 .43533 Mdot
.94755 .79586 Mdot
.71697 .69669 Mdot
.66009 .25925 Mdot
.80599 .99247 Mdot
.04872 .41686 Mdot
.31673 .19128 Mdot
.2768 .1017 Mdot
.42586 .42469 Mdot
.89568 .59424 Mdot
.38939 .35886 Mdot
.68237 .98836 Mdot
.72484 .97054 Mdot
.71174 .23412 Mdot
.02841 .21654 Mdot
.97674 .9302 Mdot
.05976 .20828 Mdot
.95382 .50014 Mdot
.73701 .90206 Mdot
.74523 .44979 Mdot
.41397 .45062 Mdot
.75781 .98621 Mdot
.91793 .12395 Mdot
.20036 .85235 Mdot
.28754 .13701 Mdot
.55156 .76447 Mdot
.4218 .96239 Mdot
.46341 .78884 Mdot
.17515 .82545 Mdot
.51497 .25081 Mdot
.50985 .80309 Mdot
.80526 .75979 Mdot
.0883 .34784 Mdot
.95659 .84279 Mdot
.12255 .32729 Mdot
.85608 .93228 Mdot
.00589 .1762 Mdot
.45931 .14995 Mdot
.57145 .25827 Mdot
.91682 .45742 Mdot
.38916 .56227 Mdot
.47791 .19615 Mdot
.86548 .60554 Mdot
.53091 .42655 Mdot
.67217 .24686 Mdot
.67989 .56051 Mdot
.62786 .99264 Mdot
.76898 .58811 Mdot
.60741 .85658 Mdot
.29264 .40208 Mdot
.96195 .58822 Mdot
.47155 .97406 Mdot
.64439 .10535 Mdot
.98414 .82421 Mdot
.7598 .52696 Mdot
.29892 .35718 Mdot
.91548 .24891 Mdot
.67865 .83877 Mdot
.37514 .27951 Mdot
.94878 .12742 Mdot
.86627 .38155 Mdot
.59756 .76322 Mdot
.87668 .8425 Mdot
.12568 .81116 Mdot
.33966 .6778 Mdot
.13173 .98191 Mdot
.59754 .27609 Mdot
.85218 .69429 Mdot
.5964 .9555 Mdot
.07697 .90666 Mdot
.10254 .71346 Mdot
.15968 .6132 Mdot
.22178 .35615 Mdot
.48161 .04755 Mdot
.40952 .42943 Mdot
.12527 .31231 Mdot
.01446 .743 Mdot
.00758 .25252 Mdot
.48557 .57054 Mdot
.19227 .5637 Mdot
.91244 .51886 Mdot
.1466 .83349 Mdot
.78183 .69376 Mdot
.06896 .06306 Mdot
.64087 .33219 Mdot
.46063 .93729 Mdot
.21415 .76228 Mdot
.30767 .65575 Mdot
.11598 .15224 Mdot
.33332 .46126 Mdot
.69825 .6697 Mdot
.20362 .85899 Mdot
.77657 .16717 Mdot
.13407 .99078 Mdot
.97605 .48566 Mdot
.18363 .0666 Mdot
.35214 .24389 Mdot
.59102 .0632 Mdot
.2596 .41544 Mdot
.35934 .28086 Mdot
.88568 .30941 Mdot
.05783 .74464 Mdot
.26082 .59157 Mdot
.93424 .98652 Mdot
.51104 .45458 Mdot
.86255 .88896 Mdot
.4812 .95594 Mdot
.79968 .82971 Mdot
.28351 .63548 Mdot
.21511 .73394 Mdot
.1472 .32039 Mdot
.87272 .49771 Mdot
.9903 .95791 Mdot
.68895 .83194 Mdot
.71606 .2979 Mdot
.76349 .76363 Mdot
.16954 .68362 Mdot
.81328 .96746 Mdot
.66931 .89151 Mdot
.07739 .10454 Mdot
.48602 .16281 Mdot
.98068 .37138 Mdot
.40046 .91591 Mdot
.04834 .86608 Mdot
.26088 .96227 Mdot
.26398 .97927 Mdot
.48816 .57521 Mdot
.60615 .24858 Mdot
.40122 .82034 Mdot
.75368 .29504 Mdot
.70107 .03896 Mdot
.59152 .15952 Mdot
.3633 .78251 Mdot
.7121 .81809 Mdot
.98954 .00311 Mdot
.63197 .91907 Mdot
.6972 .10719 Mdot
.36512 .85001 Mdot
.09803 .45496 Mdot
.78149 .61026 Mdot
.81183 .70443 Mdot
.15508 .32146 Mdot
.16017 .56264 Mdot
.51637 .25378 Mdot
.80205 .74073 Mdot
.79974 .47268 Mdot
.71122 .92614 Mdot
.10797 .40577 Mdot
.0251 .85808 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02o`0000_ooooo00?o0000oooooooo
ool03Oooool2o`0000oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool2o`0000_ooooo0_l000000ooooooo
0000ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0:ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo0_l000000ooooooo0000o`00000;ooooo`03o`00
0?oooooooooo00Cooooo0_l00007ooooo`;o00003oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool02Oooool2o`0000?ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3_ooool2o`0000Kooooo0_l00006ooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo0000
ooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool2o`0000Wooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`;o00002oooool2o`0000;ooooo
00?o0000ooooooooool00_ooool001kooooo00?o0000ooooooooool00_l0000Kooooo`;o00005Ooo
ool2o`0001[ooooo0_l0000Xooooo`;o00009oooool2o`0002?ooooo0_l0000Cooooo`;o00006_oo
ool2o`0000_ooooo0_l0000Yooooo`;o00005?ooool001kooooo00?o0000ooooooooool00_l0001>
ooooo`;o0000DOooool2o`0003Wooooo0_l0000Iooooo`;o0000C?ooool001kooooo00?o0000oooo
ooooool0<Oooool2o`000:7ooooo0_l00008ooooo`;o0000Ioooool001kooooo00?o0000oooooooo
ool07oooool2o`00013ooooo0_l0002Qooooo`;o00007_ooool2o`00057ooooo000Nooooo`03o`00
0?oooooooooo01oooooo0_l0003Cooooo`;o00006?ooool2o`0003Oooooo000Nooooo`03o`000?oo
oooooooo043ooooo0_l0003<ooooo`;o00008oooool2o`0001;ooooo000Nooooo`03o`000?oooooo
oooo043ooooo0_l000000ooooooo0000o`00001Uooooo`;o0000Qoooool2o`0001;ooooo000Noooo
o`03o`000?oooooooooo04?ooooo0_l00005ooooo`;o0000A_ooool2o`0001Kooooo0_l0000koooo
o`;o0000G_ooool001kooooo00?o0000ooooooooool03oooool2o`0003Wooooo0_l00016ooooo`;o
0000Doooool2o`0005kooooo000Nooooo`03o`000?oooooooooo00oooooo0_l0003oooooob;ooooo
0_l0000Cooooo`007_ooool00ol0003oooooooooo`0kooooo`;o0000Xoooool2o`0001Sooooo0_l0
000[ooooo`;o00002Oooool2o`0001?ooooo000Nooooo`03o`000?oooooooooo03_ooooo0_l00013
ooooo`;o00002oooool2o`0003?ooooo0_l0000Iooooo`;o000000?oooooo`000?l000006?ooool2
o`0002_ooooo0_l00002ooooo`;o00006_ooool001kooooo00?o0000ooooooooool00_ooool2o`00
07cooooo0_l0000;ooooo`;o00002Oooool2o`0002Sooooo0_l0000Iooooo`;o0000:_ooool2o`00
023ooooo0_l0000Jooooo`007_ooool00ol0003oooooooooo`02ooooo`;o0000Roooool2o`0000Oo
oooo0_l0000>ooooo`;o0000Goooool2o`0000gooooo0_l0000]ooooo`007_ooool2o`0004?ooooo
0_l0000Aooooo`;o0000>?ooool2o`0001Oooooo0_l0000Dooooo`;o00008_ooool2o`00033ooooo
0_l00002ooooo`;o00001Oooool2o`0002Kooooo000Nooooo`03o`000?oooooooooo033ooooo0_l0
000@ooooo`;o00004Oooool2o`0000cooooo0_l0001Iooooo`;o00008_ooool2o`00033ooooo0_l0
0009ooooo`;o00009_ooool001kooooo00?o0000ooooooooool0<?ooool2o`0001[ooooo0_l0000E
ooooo`;o0000C_ooool2o`0009;ooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0000koooo
o`;o00001Oooool2o`0006Cooooo0ol0002Booooo`007_ooool00ol0003oooooooooo`08ooooo`;o
00002?ooool2o`00037ooooo0_l0001Aooooo`;o00001_ooool2o`00013ooooo0_l00008ooooo`;o
00001Oooool2o`0001kooooo0_l0001Rooooo`007_ooool00ol0003oooooooooo`0Booooo`;o0000
3Oooool2o`0001Gooooo0_l0001Nooooo`;o00001_ooool2o`0001[ooooo0_l00005ooooo`;o0000
7_ooool2o`0006;ooooo000Nooooo`03o`000?oooooooooo027ooooo0_l0000Eooooo`;o0000`Ooo
ool2o`0001_ooooo0_l0000Gooooo`;o000000?oooooo`000?l000004Oooool001kooooo00?o0000
ooooooooool0??ooool2o`0005?ooooo0_l0001Xooooo`;o00001?ooool2o`0001Gooooo0_l00002
ooooo`;o00004oooool2o`000003ooooool0003o0000017ooooo000Nooooo`03o`000?oooooooooo
01gooooo0_l0000Mooooo`;o00005Oooool2o`0003cooooo0_l0001]ooooo`?o00006Oooool2o`00
02Wooooo000Nooooo`03o`000?oooooooooo01gooooo0_l0000dooooo`;o0000C?ooool2o`0005go
oooo0_l0000mooooo`;o00001_ooool001kooooo00?o0000ooooooooool0XOooool2o`0001Cooooo
0_l00026ooooo`;o00001_ooool001kooooo00?o0000ooooooooool05?ooool2o`00087ooooo0_l0
000Kooooo`;o000000?oooooo`000?l00000@oooool2o`0004Wooooo000Nooooo`03o`000?oooooo
oooo01Cooooo0_l0001fooooo`;o00002Oooool2o`0001_ooooo0_l00016ooooo`;o0000BOooool0
01kooooo00?o0000ooooooooool0;oooool2o`0005_ooooo0_l0002iooooo`007_ooool00ol0003o
ooooooooo`0_ooooo`?o0000TOooool2o`0008;ooooo000Nooooo`03o`000?oooooooooo01Gooooo
0_l0000Iooooo`;o0000??ooool2o`0005?ooooo0_l00022ooooo`007_ooool2o`0001Kooooo0_l0
000oooooo`;o00005_ooool2o`0002Cooooo0_l0002Looooo`;o00004oooool001kooooo00?o0000
ooooooooool05Oooool2o`0003oooooo0_l0000looooo`;o0000=oooool2o`0002_ooooo0_l0000f
ooooo`;o00004oooool001kooooo00?o0000ooooooooool05Oooool2o`0001Sooooo0_l0000Koooo
o`;o0000M_ooool2o`0000Oooooo0_l0000@ooooo`;o00006Oooool2o`0004_ooooo000Mooooo`;o
0000<Oooool2o`0001_ooooo0_l0001fooooo`;o00006Oooool2o`0006Kooooo000Mooooo`;o0000
O?ooool2o`00083ooooo0_l00019ooooo`007_ooool00ol0003oooooooooo`0oooooo`;o00005Ooo
ool2o`0002;ooooo0_l0000Kooooo`;o00008oooool2o`0003kooooo0_l00019ooooo`007_ooool0
0ol0003oooooooooo`0oooooo`;o00005Oooool2o`0003oooooo0_l0000Sooooo`;o00009Oooool2
o`0006;ooooo000Mooooo`;o0000iOooool2o`00047ooooo1?l0000Mooooo`007Oooool2o`0001_o
oooo0_l00016ooooo`;o0000ROooool2o`0003Sooooo1?l00006ooooo`;o00005Oooool001kooooo
00?o0000ooooooooool06Oooool2o`0001oooooo0_l00009ooooo`;o00006_ooool2o`0005Oooooo
0_l0000`ooooo`;o0000@_ooool2o`0001Gooooo000Nooooo`03o`000?oooooooooo013ooooo0_l0
000Xooooo`;o00002Oooool2o`0007?ooooo0_l00011ooooo`;o0000B?ooool001kooooo00?o0000
ooooooooool02?ooool2o`0000Kooooo0_l0000Aooooo`;o0000Y?ooool2o`0003;ooooo0_l00018
ooooo`007_ooool00ol0003oooooooooo`05ooooo`;o000000?oooooo`000?l000001_ooool2o`00
017ooooo0_l0000dooooo`;o0000K_ooool2o`0007cooooo000Nooooo`03o`000?oooooooooo00Go
oooo0_l00009ooooo`;o0000>Oooool2o`0000cooooo0_l0000Aooooo`;o0000;Oooool2o`0007ko
oooo0_l0000Zooooo`007_ooool00ol0003oooooooooo`13ooooo`;o00001_ooool2o`0001oooooo
0_l0000Cooooo`;o00001oooool2o`0000oooooo0_l0001nooooo`Co0000:?ooool001kooooo00?o
0000ooooooooool00_l0000/ooooo`;o00004oooool2o`0003cooooo0_l00007ooooo`;o0000TOoo
ool2o`0002Sooooo000Nooooo`;o000000?oooooo`000?l00000;?ooool2o`0001Sooooo0_l0000n
ooooo`;o00001oooool2o`0003Kooooo0_l0001?ooooo`;o0000:oooool001kooooo00?o0000oooo
ooooool08_ooool2o`0002Cooooo0_l0000nooooo`;o00001oooool2o`0003Kooooo0_l0001?oooo
o`;o0000:oooool001kooooo00?o0000ooooooooool08_ooool2o`0001Gooooo0_l0000[ooooo`;o
00005?ooool2o`000<Wooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0000]ooooo`;o0000
:oooool2o`0001Cooooo0_l0000nooooo`;o0000ROooool001kooooo00?o0000ooooooooool02_oo
ool2o`0000[ooooo0_l0001Jooooo`;o00009_ooool2o`00023ooooo0_l0001Cooooo`;o0000=?oo
ool001kooooo00?o0000ooooooooool05_ooool2o`0005[ooooo0_l0000Vooooo`;o0000G?ooool2
o`0000;ooooo0_l0000?ooooo`;o00000_ooool2o`0003Cooooo000Nooooo`03o`000?oooooooooo
02Oooooo0_l0003?ooooo`;o00000_ooool2o`0000?ooooo0_l0000:ooooo`;o00009?ooool2o`00
00Kooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o00001Oooool2o`0000ko
oooo0_l0001[ooooo`;o0000@oooool2o`0002Kooooo0_l0000Pooooo`;o00003_ooool2o`0000Ko
oooo0_l0000:ooooo`007_ooool3o`00013ooooo0_l00005ooooo`;o00004oooool2o`0003Gooooo
0_l0000_ooooo`;o0000@oooool2o`0002Kooooo0_l0000Pooooo`;o00008_ooool001kooooo0ol0
000Fooooo`;o00005?ooool2o`0003Gooooo0_l0001Aooooo`;o00001?ooool4o`00047ooooo0_l0
0014ooooo`007_ooool00ol0003oooooooooo`0Fooooo`;o000000?oooooo`000?l00000@_ooool2
o`0005Oooooo0_l00004ooooo`Co0000Qoooool001kooooo00?o0000ooooooooool06Oooool2o`00
04;ooooo0_l0000Nooooo`;o00001_ooool2o`0005[ooooo0_l0000gooooo`;o00007oooool2o`00
00[ooooo000Nooooo`03o`000?oooooooooo07gooooo0_l00006ooooo`;o00000oooool2o`0004Go
oooo0_l0000>ooooo`;o0000=oooool2o`0001oooooo0_l0000:ooooo`007_ooool00ol0003ooooo
ooooo`1Sooooo`;o00009Oooool2o`0001Sooooo0_l0000[ooooo`;o0000M?ooool000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0
1Oooool2o`0005cooooo0_l0000oooooo`;o0000GOooool2o`0002Kooooo0_l0000Jooooo`000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01_ooool01?l0003oooooo`000?l00004ooooo`;o0000<oooool2o`0005_ooooo0_l0001Zoooo
o`;o00002_ooool2o`0001[ooooo0_l0000>ooooo`;o00002_ooool000?ooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo1?l0000iooooo`;o0000Foooool2o`00
06gooooo0_l00002ooooo`;o00000oooool2o`0000Gooooo0_l0000Pooooo`;o000000?oooooo`00
0?l000002_ooool000?ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^
00Kooooo00?o0000ooooooooool0e?ooool2o`00033ooooo0_l00002ooooo`;o00002_ooool2o`00
023ooooo0_l0000=ooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool01Oooool00ol0003oooooooooo`0Aooooo`;o0000Y?ooool2o`000003ooooool0003o0000
01Sooooo0_l0000[ooooo`;o0000>_ooool2o`0000Sooooo0003ooooo`05oa0@4?oooooooooooooo
ool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00oooooo1?l00028oooo
o`;o00006_ooool2o`000003ooooool0003o000004Gooooo0_l0000jooooo`;o00002?ooool000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool0
0ol0003oooooooooo`0?ooooo`;o0000R_ooool2o`000:[ooooo0003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool01Ooo
ool2o`0005Gooooo0_l0001fooooo`;o00005_ooool2o`0004Kooooo0_l0000Aooooo`007_ooool0
0ol0003oooooooooo`05ooooo`;o00000_ooool2o`00057ooooo0_l0001fooooo`;o00005_ooool2
o`0002?ooooo0_l0000Qooooo`;o00000oooool2o`0000cooooo000Nooooo`03o`000?oooooooooo
00Wooooo0_l0001@ooooo`;o0000TOooool2o`00027ooooo0_l0000Vooooo`;o00003?ooool001ko
oooo00?o0000ooooooooool0@?ooool2o`0001Wooooo1?l0000booooo`;o00003oooool2o`0004Oo
oooo0_l000000ooooooo0000o`000002ooooo`;o0000Doooool001kooooo00?o0000ooooooooool0
4?ooool2o`0002kooooo0_l0000=ooooo`;o00003?ooool2o`0003;ooooo0_l0000?ooooo`;o0000
8_ooool2o`0001Cooooo0_l0000=ooooo`;o00001Oooool2o`0005?ooooo000Nooooo`03o`000?oo
oooooooo00;ooooo0_l0000:ooooo`Co0000?Oooool2o`0001Gooooo0_l0001Nooooo`;o00004?oo
ool2o`0000;ooooo0_l0000^ooooo`;o0000>Oooool001kooooo00?o0000ooooooooool01?l0000:
ooooo`;o00002_ooool2o`0003Gooooo0_l0000Cooooo`;o00008_ooool2o`0004cooooo0_l00009
ooooo`;o00009oooool2o`00017ooooo0_l0000Vooooo`007_ooool00ol0003oooooooooo`02o`00
01Sooooo0_l0000dooooo`?o00001_ooool2o`0002oooooo0_l0001Gooooo`;o0000>_ooool2o`00
02Kooooo000Nooooo`03o`000?oooooooooo053ooooo0_l00007ooooo`;o00005Oooool2o`000<Co
oooo0_l0000?ooooo`007_ooool00ol0003oooooooooo`12ooooo`;o00007?ooool2o`0000cooooo
1Ol00033ooooo`;o00003oooool001kooooo00?o0000ooooooooool0@_ooool2o`0001cooooo0_l0
000<ooooo`;o000000?oooooo`000?l00000Hoooool2o`0004;ooooo0_l0000[ooooo`007_ooool0
0ol0003oooooooooo`0aooooo`;o0000F?ooool2o`0003Cooooo0_l0000Cooooo`;o0000@_ooool2
o`0000[ooooo0_l0000:ooooo`;o00004oooool001kooooo0ol0000Fooooo`;o00004_ooool2o`00
00Gooooo0_l0000Sooooo`;o0000<oooool3o`0001Gooooo0_l0000Looooo`;o00000_ooool2o`00
05oooooo0_l0000:ooooo`;o00004oooool001kooooo0ol0000@ooooo`;o00001?ooool2o`0001;o
oooo0_l0000Wooooo`;o000000?oooooo`000?l00000<oooool3o`0001Gooooo0ol0000Oooooo`;o
00009?ooool2o`0005[ooooo000Nooooo`03o`000?oooooooooo013ooooo0_l00011ooooo`;o0000
=_ooool2o`0001Oooooo0_l0000@ooooo`;o00006_ooool2o`0000oooooo0_l00006ooooo`;o0000
F_ooool001kooooo00?o0000ooooooooool06oooool2o`0002;ooooo0_l0001:ooooo`;o0000:Ooo
ool2o`0001[ooooo0_l0000?ooooo`;o00008Oooool2o`0003oooooo000Nooooo`03o`000?oooooo
oooo01_ooooo0_l0000Looooo`;o00001?ooool4o`0006kooooo0_l0000Iooooo`;o0000>?ooool2
o`0000Cooooo0_l0000Looooo`;o00006oooool001kooooo00?o0000ooooooooool0>Oooool2o`00
00Kooooo0_l0000<ooooo`;o0000G_ooool4o`0001Wooooo0_l0000nooooo`;o00007?ooool3o`00
01[ooooo000Nooooo`03o`000?oooooooooo03;ooooo0_l00008ooooo`;o00004Oooool2o`0005ko
oooo0_l0001jooooo`;o00006_ooool001kooooo00?o0000ooooooooool0<_ooool2o`0000Sooooo
0_l0001Eooooo`;o0000Soooool2o`00027ooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0
001mooooo`;o0000:Oooool2o`0002_ooooo0_l0000gooooo`;o00008Oooool001kooooo00?o0000
ooooooooool02_ooool2o`0000Sooooo0_l0000dooooo`;o00009Oooool2o`0000?ooooo0_l00008
ooooo`;o0000??ooool2o`0002_ooooo0_l0001Jooooo`007_ooool00ol0003oooooooooo`0:oooo
o`;o0000?_ooool2o`0000Sooooo0_l0000Kooooo`;o00000oooool2o`0000Sooooo1?l00033oooo
o`007_ooool00ol0003oooooooooo`1Dooooo`;o00008Oooool2o`0000Wooooo0_l0001Tooooo`;o
0000>?ooool2o`0000?ooooo0_l0000Nooooo`007_ooool00ol0003oooooooooo`05ooooo`;o0000
L?ooool2o`0003Wooooo0_l0000dooooo`;o00002_ooool2o`0002cooooo0_l00003ooooo`;o0000
2oooool2o`00017ooooo000Nooooo`03o`000?oooooooooo00Gooooo0_l0002[ooooo`;o00003_oo
ool2o`00033ooooo0_l0000nooooo`;o00004Oooool001kooooo00?o0000ooooooooool0;Oooool2
o`0001cooooo0_l0000;ooooo`;o0000J?ooool2o`0002gooooo0_l00004ooooo`;o0000C_ooool0
01kooooo00?o0000ooooooooool0;Oooool2o`0001cooooo0_l0000;ooooo`;o0000Roooool2o`00
00[ooooo0_l00004ooooo`;o0000;_ooool2o`0001kooooo000Nooooo`;o0000i_ooool2o`00017o
oooo0_l0000]ooooo`;o00007_ooool001kooooo00?o0000ooooooooool09_ooool2o`0003Gooooo
0_l0002Iooooo`;o0000COooool001kooooo00?o0000ooooooooool09_ooool2o`0003Gooooo0_l0
001aooooo`;o0000MOooool001kooooo00?o0000ooooooooool0Joooool2o`0003kooooo0_l0000S
ooooo`;o0000B_ooool2o`0002Wooooo000Nooooo`03o`000?oooooooooo02Gooooo0_l0000=oooo
o`;o0000=Oooool2o`0003kooooo0_l0001Nooooo`;o00003oooool2o`0002Wooooo000Nooooo`03
o`000?oooooooooo02Gooooo0_l0000=ooooo`;o0000eOooool2o`000003ooooool0003o000002Co
oooo0_l0000Aooooo`007_ooool00ol0003oooooooooo`0/ooooo`;o0000AOooool2o`0003cooooo
0_l0000^ooooo`;o0000:oooool2o`0002Cooooo0_l0000Aooooo`007_ooool00ol0003ooooooooo
o`0Mooooo`;o00003Oooool4o`0004?ooooo0_l0000looooo`;o0000;_ooool2o`00057ooooo0_l0
000Aooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o00001Oooool2o`0000Sooooo0_l00002
ooooo`;o00003?ooool2o`0006gooooo0_l0000[ooooo`;o00001?ooool2o`00053ooooo0_l0000A
ooooo`007_ooool00ol0003oooooooooo`0Tooooo`;o00003?ooool2o`0000cooooo0_l00005oooo
o`;o0000I_ooool2o`0002_ooooo0_l00004ooooo`;o0000Hoooool001kooooo00?o0000oooooooo
ool00_l00015ooooo`;o00007_ooool2o`0004_ooooo0_l0000Fooooo`;o0000NOooool001kooooo
00?o0000ooooooooool00_l0001Uooooo`;o0000Boooool2o`0001Kooooo0_l00010ooooo`;o0000
=oooool001kooooo00?o0000ooooooooool0;_ooool2o`0008[ooooo0_l0000@ooooo`;o0000@?oo
ool2o`0003Oooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0000Jooooo`;o00002Oooool2
o`0004;ooooo0_l0000kooooo`;o0000?_ooool2o`0002[ooooo0_l0000Oooooo`007_ooool00ol0
003oooooooooo`0Booooo`;o00009Oooool2o`0004;ooooo0_l0001kooooo`?o0000:Oooool2o`00
01oooooo000Nooooo`03o`000?oooooooooo00cooooo0_l0000;ooooo`;o0000Doooool2o`0000go
oooo0_l0000;ooooo`;o0000Koooool2o`0004[ooooo000Nooooo`;o00003Oooool2o`0000_ooooo
0_l0000Nooooo`;o00006oooool2o`0001Kooooo0_l0000Jooooo`;o00004_ooool2o`0000Gooooo
0_l0000=ooooo`;o0000TOooool001kooooo00?o0000ooooooooool01Oooool2o`0003;ooooo0_l0
000Kooooo`;o0000A_ooool2o`0000Gooooo0_l0000=ooooo`?o00007_ooool2o`0000[ooooo0_l0
001Tooooo`007_ooool2o`0000Kooooo0_l0000Dooooo`;o00009oooool2o`0001Oooooo0_l0001F
ooooo`;o00007_ooool2o`0000[ooooo0_l0001Tooooo`007_ooool2o`0001cooooo0_l0000Woooo
o`;o00005oooool2o`00013ooooo0_l00009ooooo`;o0000Foooool2o`0006kooooo000Nooooo`03
o`000?oooooooooo05[ooooo0_l0000@ooooo`;o000000?oooooo`000?l000002Oooool2o`0005_o
oooo0_l0001^ooooo`007_ooool00ol0003oooooooooo`1Jooooo`;o00004?ooool2o`0000cooooo
0_l0000fooooo`;o0000E?ooool2o`0003gooooo000Nooooo`03o`000?oooooooooo04Gooooo0_l0
000cooooo`;o00002?ooool2o`0001?ooooo0_l0000Gooooo`;o00007Oooool2o`0003Gooooo0_l0
000mooooo`007_ooool00ol0003oooooooooo`15ooooo`;o00001_ooool2o`0003Gooooo0_l0000C
ooooo`;o0000:?ooool2o`0000cooooo0_l0001Xooooo`;o00002_ooool001kooooo00?o0000oooo
ooooool0COooool2o`0001Wooooo0_l0001>ooooo`;o00002Oooool2o`00067ooooo0_l0000Coooo
o`;o00002_ooool001kooooo00?o0000ooooooooool0>?ooool2o`0002kooooo0_l0001>ooooo`;o
0000K?ooool2o`0001oooooo000Nooooo`03o`000?oooooooooo02Sooooo0_l0000>ooooo`;o0000
JOooool2o`0000oooooo0_l0000hooooo`;o00009_ooool2o`0002oooooo000Nooooo`03o`000?oo
oooooooo02Sooooo0_l0001iooooo`;o00001?ooool2o`0000Wooooo0_l0000=ooooo`;o00005_oo
ool2o`0000Oooooo0_l00008ooooo`Co00009?ooool2o`0000gooooo0_l0000Pooooo`007_ooool0
0ol0003oooooooooo`2Yooooo`;o00006?ooool2o`0001Kooooo0_l00007ooooo`;o00002_ooool2
o`0003?ooooo0_l0000Pooooo`007_ooool00ol0003oooooooooo`0iooooo`;o0000@_ooool2o`00
0<Sooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@
413oooooooooo`04ooooo`03o`000?oooooooooo03Wooooo0_l00012ooooo`;o00007Oooool2o`00
00Oooooo0_l0000Hooooo`;o0000COooool2o`0003Oooooo0003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Loooo
o`;o00001oooool2o`0001Sooooo0_l0001<ooooo`?o0000=oooool000?ooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go00001_ooool3o`0003gooooo0_l0000Xooooo`;o00009?ooool2o`00
00gooooo0_l0000_ooooo`;o0000?_ooool2o`0003Sooooo0003ooooo`05o`000?oooooooooooooo
ool000002oooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo00Kooooo0_l0000e
ooooo`;o00007?ooool2o`0000[ooooo0_l0000Tooooo`;o0000?_ooool3o`0004?ooooo0_l00008
ooooo`;o0000:?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0000Oooooo00?o0000ooooooooool01_ooool2o`0001Oooooo0_l0000Pooooo`;o00004?oo
ool2o`0000Kooooo0_l0000Oooooo`;o00005oooool2o`0003Oooooo0_l00013ooooo`;o00002?oo
ool2o`0002Sooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00
0007ooooo`03o`000?oooooooooo01oooooo0_l0000Cooooo`;o00002oooool2o`00013ooooo0_l0
000Nooooo`;o00001oooool2o`0001Oooooo0_l0000:ooooo`;o0000:oooool2o`0006;ooooo0_l0
000Cooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001ooo
ool00ol0003oooooooooo`0dooooo`;o0000?Oooool2o`0002cooooo0_l0002?ooooo`;o00004ooo
ool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o
0000ooooooooool0>Oooool2o`0001Gooooo0_l0000Oooooo`;o0000e?ooool001kooooo00?o0000
ooooooooool03?ooool2o`0002_ooooo0_l0000Eooooo`;o00007oooool2o`0002Oooooo0_l0002[
ooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o0000S?ooool2o`0009cooooo0_l0000=oooo
o`007_ooool00ol0003oooooooooo`1Qooooo`;o00008oooool2o`000;3ooooo0_l0000=ooooo`00
7_ooool00ol0003oooooooooo`0oooooo`;o00003oooool2o`0000oooooo0_l0000Aooooo`;o0000
4?ooool2o`00023ooooo0_l0002Mooooo`007_ooool00ol0003oooooooooo`0Yooooo`;o00005?oo
ool2o`0000oooooo0_l00004ooooo`;o00005oooool2o`0000?ooooo0_l0000;ooooo`;o00007_oo
ool2o`0000Gooooo0_l0001Dooooo`;o00008_ooool2o`0002?ooooo000Nooooo`03o`000?oooooo
oooo00Oooooo0_l0000Pooooo`;o00005Oooool2o`0000Kooooo0_l0000<ooooo`;o00005?ooool2
o`000003ooooool0003o0000013ooooo0_l0000Nooooo`;o0000Foooool2o`0002;ooooo0_l0000S
ooooo`007_ooool00ol0003oooooooooo`07ooooo`;o00008Oooool2o`0001Cooooo0_l00006oooo
o`;o00008_ooool2o`00057ooooo0_l00026ooooo`007_ooool00ol0003oooooooooo`0Zooooo`;o
0000Toooool2o`0008Kooooo000Nooooo`03o`000?oooooooooo01[ooooo0_l0003oooooo`_ooooo
0_l0000Aooooo`;o00003?ooool001kooooo00?o0000ooooooooool06_ooool2o`0001;ooooo0_l0
003fooooo`;o000000?oooooo`000?l000003_ooool2o`0000cooooo000Nooooo`03o`000?oooooo
oooo02kooooo0_l00029ooooo`;o0000<oooool2o`0002cooooo0_l0000;ooooo`;o00007?ooool0
01kooooo0_l00023ooooo`;o00008Oooool2o`0001;ooooo0_l0000cooooo`;o0000;?ooool2o`00
02Wooooo000Nooooo`03o`000?oooooooooo01cooooo0_l0000Cooooo`;o0000Coooool2o`0001?o
oooo0_l00009ooooo`;o000000?oooooo`000?l00000Roooool2o`0001?ooooo000Nooooo`03o`00
0?oooooooooo01cooooo0_l0000Booooo`?o0000I?ooool2o`0000Cooooo0_l00003ooooo`;o0000
KOooool2o`0001?ooooo0_l0000:ooooo`;o00002_ooool2o`0000Oooooo000Nooooo`03o`000?oo
oooooooo033ooooo0_l0000fooooo`;o00002_ooool2o`0002Oooooo0_l0001booooo`;o00004ooo
ool2o`0001Kooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`03o`0003gooooo0_l0000V
ooooo`;o00002_ooool2o`000=7ooooo000Nooooo`03o`000?oooooooooo00?o0000?Oooool2o`00
00Oooooo0_l0000Vooooo`;o0000e?ooool001kooooo00?o0000ooooooooool0BOooool2o`0002Ko
oooo0_l0001Jooooo`;o0000N?ooool001kooooo00?o0000ooooooooool0B_ooool2o`00087ooooo
0_l0000aooooo`;o00006_ooool2o`0002Wooooo000Nooooo`03o`000?oooooooooo04[ooooo0_l0
000@ooooo`;o0000X_ooool2o`0001[ooooo0_l00003ooooo`;o00009?ooool001kooooo00?o0000
ooooooooool0G?ooool2o`0001Oooooo0_l0002Rooooo`;o00001_ooool2o`0002Cooooo000Noooo
o`03o`000?oooooooooo00Kooooo0_l0000Zooooo`;o00001_ooool2o`000003ooooool0003o0000
01;ooooo0_l0000Rooooo`;o0000X_ooool2o`0002cooooo000Nooooo`03o`000?oooooooooo00Ko
oooo0_l0000Zooooo`;o00001_ooool2o`000003ooooool0003o000001;ooooo0_l0000Dooooo`;o
00008?ooool2o`0002gooooo0_l0001oooooo`;o00003?ooool001kooooo00?o0000ooooooooool0
Ioooool2o`00023ooooo0_l0000?ooooo`;o00007?ooool2o`0003oooooo0_l0000Looooo`;o0000
8?ooool2o`0000Cooooo0_l00006ooooo`007_ooool00ol0003oooooooooo`2Jooooo`;o0000=ooo
ool2o`0002Cooooo0_l0000Looooo`;o00008?ooool2o`0000Cooooo0_l00006ooooo`007_ooool0
0ol0003oooooooooo`1Fooooo`;o0000<?ooool2o`0004Wooooo0_l0000Jooooo`;o0000Aoooool3
o`0000cooooo000Nooooo`03o`000?oooooooooo04gooooo0_l00006ooooo`?o0000<?ooool2o`00
01Sooooo0_l0000Oooooo`;o0000:_ooool2o`0002Oooooo0_l0000Nooooo`;o00003Oooool001ko
oooo0_l0001>ooooo`;o00001_ooool2o`0004_ooooo0_l0000Oooooo`;o0000Doooool2o`0001So
oooo0_l0000Cooooo`007_ooool00ol0003oooooooooo`3oooooo`Gooooo0_l0000/ooooo`;o0000
4oooool001kooooo00?o0000ooooooooool0??ooool2o`000<Kooooo0_l0000=ooooo`;o0000<_oo
ool001kooooo00?o0000ooooooooool0??ooool2o`000=Gooooo0_l0000booooo`007_ooool00ol0
003oooooooooo`0;ooooo`;o00001?ooool2o`0008Cooooo0_l0000Wooooo`;o0000@Oooool2o`00
02oooooo0_l0000Aooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o00001?ooool2o`0001Co
oooo0_l0001<ooooo`;o00008?ooool2o`0002Oooooo0_l00011ooooo`;o00006oooool2o`0000ko
oooo0_l00002ooooo`;o00004Oooool001kooooo00?o0000ooooooooool09oooool2o`0004cooooo
0_l0002Yooooo`;o00000oooool2o`0000Wooooo0_l0000Eooooo`007_ooool00ol0003ooooooooo
o`3oooooobKooooo0_l0000Dooooo`;o00002_ooool001kooooo00?o0000ooooooooool0Q?ooool2
o`0006gooooo0_l00016ooooo`;o00002_ooool001kooooo00Co0000oooooooooooooooo0_l00002
ooooo`;o0000Eoooool2o`0001gooooo0_l00005ooooo`;o0000KOooool2o`00017ooooo0_l0000o
ooooo`007_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l0001Gooooo`;o00007Oooool3
o`0008Kooooo0_l0000oooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o00004Oooool2o`00
00_ooooo0_l0000=ooooo`;o0000@oooool2o`0001;ooooo0_l0002cooooo`007_ooool00ol0003o
ooooooooo`0:ooooo`;o00004Oooool2o`0000_ooooo0_l0000=ooooo`;o0000>oooool2o`0001[o
oooo0_l0002cooooo`007_ooool00ol0003oooooooooo`1fooooo`;o0000=oooool2o`0001Oooooo
0_l0000fooooo`;o0000AOooool001kooooo00?o0000ooooooooool0J_ooool2o`0002Oooooo0_l0
000Jooooo`;o00005oooool2o`0003Kooooo0_l00015ooooo`007_ooool00ol0003oooooooooo`0M
ooooo`;o00002_ooool2o`0003?ooooo0_l0000:ooooo`;o00009oooool2o`000;;ooooo000Noooo
o`;o00004?ooool2o`0000cooooo0_l0000:ooooo`;o0000<oooool2o`00037ooooo0_l0002doooo
o`007_ooool00ol0003oooooooooo`0?ooooo`;o0000P?ooool2o`0006Wooooo0_l00019ooooo`00
7_ooool00ol0003oooooooooo`2Vooooo`;o00002oooool2o`0003oooooo0_l00006ooooo`;o0000
BOooool001kooooo00?o0000ooooooooool0Y_ooool2o`0000_ooooo0_l0000Tooooo`;o00006Ooo
ool2o`00057ooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0000Wooooo`;o00002?ooool2
o`0003kooooo0_l00007ooooo`;o0000E?ooool2o`0006cooooo000Nooooo`03o`000?oooooooooo
00Oooooo0_l0000Wooooo`;o00002?ooool2o`0003kooooo0_l00007ooooo`;o0000`_ooool001ko
oooo00?o0000ooooooooool04_ooool2o`0006;ooooo0_l0000/ooooo`;o0000Ioooool2o`0003So
oooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0001Rooooo`;o00008_ooool2o`0000Sooooo
0_l0000jooooo`;o0000:oooool2o`0002oooooo0_l000000ooooooo0000o`000004ooooo`007_oo
ool00ol0003oooooooooo`2Jooooo`?o0000??ooool4o`0000?ooooo0ol0001Jooooo`?o000000?o
ooooo`000?l000001?ooool001kooooo00?o0000ooooooooool0Voooool2o`0003cooooo1?l00004
ooooo`;o0000Eoooool2o`000003ooooool0003o000000Sooooo000Nooooo`03o`000?oooooooooo
02kooooo0_l0000Sooooo`;o0000iOooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo02ko
oooo0_l0000Sooooo`;o0000S?ooool2o`0001cooooo0_l0000oooooo`;o00001Oooool001kooooo
00?o0000ooooooooool0hOooool2o`0000kooooo0_l00003ooooo`;o00001oooool2o`0001Kooooo
0_l0000Looooo`;o00002Oooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo01gooooo0_l0
000Zooooo`;o00001_ooool2o`0009kooooo0_l00003ooooo`;o00001_ooool2o`0001Oooooo0_l0
000Looooo`;o00004?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool07Oooool2o`0000gooooo
0_l0000Kooooo`;o00001_ooool2o`000:_ooooo0_l0000Oooooo`;o00001?ooool2o`00023ooooo
0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMooooooo
V9RHob4Q8@06ooooo`03o`000?oooooooooo02cooooo0_l00007ooooo`;o0000j?ooool2o`0000Co
oooo0_l0000Pooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooo
ooooooooo`000006ooooo`?o0000=Oooool2o`0000cooooo0_l0001cooooo`;o00008Oooool2o`00
06[ooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So
8B4Q00Kooooo00?o0000ooooooooool0@oooool2o`0002;ooooo0_l0001?ooooo`;o00007?ooool2
o`0000?ooooo0_l0000Mooooo`;o0000Boooool000?ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`1Rooooo`;o00000ooo
ool2o`00023ooooo0_l0001;ooooo`;o00008_ooool2o`0001Wooooo0_l0000`ooooo`000oooool0
1Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003ooooooooo
o`0[ooooo`;o0000=Oooool2o`000003ooooool0003o000002;ooooo0_l0000Jooooo`;o0000Dooo
ool2o`0001Wooooo0_l0000`ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o
gMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0Mooooo`;o00003?ooool2o`0000?ooooo0_l0
000cooooo`;o0000?_ooool2o`0002;ooooo0_l0000_ooooo`;o00001?ooool2o`0000;ooooo0_l0
0011ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@
1_ooool00ol0003oooooooooo`0Mooooo`;o00004Oooool2o`0009Oooooo0_l0000dooooo`?o0000
0_ooool2o`0001_ooooo0_l0000Tooooo`007_ooool00ol0003oooooooooo`2Eooooo`;o0000E_oo
ool2o`00013ooooo0_l0000Pooooo`;o00009?ooool001kooooo00?o0000ooooooooool0UOooool2
o`0002Sooooo0_l0000Vooooo`;o00001?ooool2o`0000Wooooo0_l0000Fooooo`;o0000=Oooool0
01kooooo00?o0000ooooooooool0;_ooool2o`0008oooooo0_l0000Vooooo`;o00003oooool2o`00
01Kooooo0_l0000eooooo`007_ooool00ol0003oooooooooo`0^ooooo`;o0000U_ooool2o`0000ko
oooo0_l0000Iooooo`;o00007oooool2o`0003?ooooo000Nooooo`03o`000?oooooooooo017ooooo
0_l0000Gooooo`;o0000@Oooool2o`0002;ooooo0_l0000Gooooo`;o00006_ooool2o`0000kooooo
0_l0000Iooooo`;o00007oooool2o`0003?ooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0
0007ooooo`;o00005oooool2o`00047ooooo0_l0000Rooooo`;o00005oooool2o`0004Sooooo0_l0
001Aooooo`007_ooool00ol0003oooooooooo`08ooooo`;o00007_ooool2o`0002kooooo0_l0002J
ooooo`;o0000DOooool001kooooo00?o0000ooooooooool00oooool2o`0001Kooooo0_l0000;oooo
o`;o00005Oooool2o`0001Oooooo0_l0000_ooooo`;o0000[Oooool2o`0000gooooo000Nooooo`03
o`000?oooooooooo00?ooooo0_l0000Fooooo`;o00008_ooool2o`0004Sooooo0_l0002]ooooo`;o
00003Oooool001kooooo00?o0000ooooooooool0ioooool2o`0000cooooo0_l0000nooooo`;o0000
4?ooool001kooooo00?o0000ooooooooool0eoooool2o`0000kooooo0_l0000<ooooo`;o0000?_oo
ool2o`00013ooooo000Nooooo`;o0000K?ooool2o`0005Cooooo0_l0000Dooooo`;o0000K_ooool0
01kooooo00?o0000ooooooooool0Eoooool2o`0000Oooooo0_l00009ooooo`;o0000E?ooool2o`00
08Cooooo000Nooooo`03o`000?oooooooooo05Oooooo0_l00003ooooo`;o00000_ooool2o`000;[o
oooo0_l0000Yooooo`007_ooool00ol0003oooooooooo`17ooooo`;o00004?ooool2o`000003oooo
ool0003o00000;kooooo0_l0000Yooooo`007_ooool00ol0003oooooooooo`17ooooo`;o00004?oo
ool2o`0008kooooo0ol00008ooooo`;o0000DOooool001kooooo00?o0000ooooooooool0jOooool3
o`0000Sooooo0_l0000mooooo`;o00004_ooool001kooooo00?o0000ooooooooool04_ooool2o`00
07_ooooo0_l0001>ooooo`;o0000D_ooool2o`0001;ooooo000Nooooo`03o`000?oooooooooo00Ko
oooo0_l0000:ooooo`;o0000Noooool2o`0004_ooooo0_l000000ooooooo0000o`00001Vooooo`00
7_ooool00ol0003oooooooooo`06ooooo`;o0000H_ooool2o`00023ooooo0_l0001>ooooo`;o0000
7?ooool2o`0004_ooooo000Nooooo`03o`000?oooooooooo04[ooooo0_l0000Nooooo`;o00008?oo
ool2o`0006cooooo0_l0000Wooooo`;o00004oooool2o`0000gooooo000Nooooo`03o`000?oooooo
oooo02Cooooo0_l0000=ooooo`;o00005Oooool2o`0001;ooooo0_l00008ooooo`;o00009oooool2
o`0004Sooooo0_l00016ooooo`;o00004oooool2o`0000gooooo000Nooooo`03o`000?oooooooooo
02Cooooo0_l0000=ooooo`;o00005_ooool2o`00017ooooo0_l00008ooooo`;o00009oooool2o`00
04Sooooo0_l000000ooooooo0000o`00001Wooooo`007_ooool00ol0003oooooooooo`1;ooooo`;o
0000E_ooool2o`0003Wooooo0_l0001Wooooo`007_ooool00ol0003oooooooooo`0cooooo`;o0000
K_ooool3o`0006gooooo0_l000000ooooooo0000o`00000_ooooo`007_ooool00ol0003ooooooooo
o`0cooooo`;o00007?ooool2o`0001Sooooo0_l0000gooooo`;o00004_ooool2o`0000Oooooo0_l0
000gooooo`;o00005Oooool4o`000003ooooool0003o000002oooooo000Nooooo`03o`000?oooooo
oooo057ooooo0_l0000:ooooo`;o00003?ooool2o`0004_ooooo0_l00007ooooo`;o00008_ooool2
o`0001?ooooo0_l0000Eooooo`;o0000=?ooool001kooooo0_l0001Nooooo`;o0000C?ooool2o`00
03Sooooo0_l0001Pooooo`007_ooool00ol0003oooooooooo`0Booooo`;o0000COooool2o`0004So
oooo0_l0001Gooooo`;o00008?ooool2o`0001oooooo000Nooooo`03o`000?oooooooooo01;ooooo
0_l0001=ooooo`;o0000XOooool2o`00023ooooo0_l0000Oooooo`007_ooool01?l0003oooooo`00
0?l0002Yooooo`;o0000Voooool001kooooo00Co0000ooooool0003o00007?ooool2o`0006oooooo
0_l0000Jooooo`;o0000B?ooool2o`0001Oooooo0_l0000hooooo`007_ooool00ol0003ooooooooo
o`0?ooooo`;o00003?ooool2o`00037ooooo0_l00003ooooo`;o0000<Oooool2o`0000Cooooo0_l0
001Iooooo`;o00002Oooool2o`0001Oooooo0_l0000/ooooo`;o00002_ooool001kooooo00?o0000
ooooooooool03oooool2o`0003oooooo0_l00003ooooo`;o0000<Oooool2o`0003cooooo0_l0000Q
ooooo`;o00004?ooool2o`0003kooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`2^oooo
o`;o00005_ooool2o`0003?ooooo0_l0000Gooooo`;o0000<Oooool001kooooo00?o0000oooooooo
ool07_ooool2o`0003cooooo0_l0000Yooooo`;o00008Oooool2o`0000;ooooo0_l0000Fooooo`;o
0000C?ooool2o`00037ooooo000Nooooo`03o`000?oooooooooo01kooooo0_l0000looooo`;o0000
:Oooool2o`00027ooooo0_l0000Nooooo`;o00000oooool2o`00057ooooo0_l0000Sooooo`007_oo
ool00ol0003oooooooooo`0>ooooo`;o0000U_ooool2o`0001Wooooo0_l00007ooooo`;o00000ooo
ool2o`00057ooooo0_l0000Sooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o0000<_ooool2
o`0005[ooooo0_l00006ooooo`;o00006Oooool2o`0008Cooooo000Nooooo`03o`000?oooooooooo
04;ooooo0_l0000hooooo`;o00004?ooool2o`0000kooooo0_l00005ooooo`;o0000X?ooool001ko
oooo00?o0000ooooooooool0O?ooool2o`00013ooooo0_l0000Eooooo`;o0000F_ooool2o`0004Co
oooo000Nooooo`04o`000?ooooooooooooooo`;o00003?ooool2o`0005[ooooo0_l0001Uooooo`;o
0000;Oooool2o`0000Sooooo0_l0000jooooo`007_ooool01?l0003oooooooooooooool2o`0000co
oooo0_l0001Jooooo`;o00001oooool2o`0000gooooo0_l0000;ooooo`;o00006oooool2o`0002?o
oooo0_l0000gooooo`;o0000>_ooool001kooooo0_l0000_ooooo`;o0000=?ooool2o`0000kooooo
0_l0000=ooooo`;o00002oooool2o`0000[ooooo0_l0000?ooooo`;o00004Oooool2o`0008Gooooo
000Nooooo`03o`000?oooooooooo02Sooooo0_l00004ooooo`;o00007_ooool2o`0001Cooooo0_l0
000fooooo`;o00004_ooool2o`0000kooooo0_l0000Qooooo`;o0000H_ooool001kooooo00?o0000
ooooooooool0:?ooool2o`0002Cooooo0_l0001Pooooo`;o0000<Oooool2o`0006;ooooo000Noooo
o`03o`000?oooooooooo0:Gooooo0_l0001Kooooo`;o0000@oooool001kooooo00?o0000oooooooo
ool0@_ooool2o`00067ooooo0_l0000Gooooo`;o00008oooool2o`0000oooooo0_l0000<ooooo`;o
00003?ooool2o`0003Gooooo000Nooooo`03o`000?oooooooooo027ooooo0_l0000Cooooo`;o0000
2_ooool2o`00033ooooo0_l0000iooooo`;o00003Oooool2o`0001oooooo0_l00002ooooo`;o0000
3oooool2o`0000Gooooo0_l0000Cooooo`;o0000=Oooool001kooooo00?o0000ooooooooool08Ooo
ool2o`0001?ooooo0_l0000[ooooo`;o00003oooool2o`0003Wooooo0_l0000^ooooo`;o00006_oo
ool2o`0000Wooooo0_l0000oooooo`007_ooool00ol0003oooooooooo`1Sooooo`;o0000<oooool2
o`0004Oooooo0_l0000Sooooo`;o0000?oooool001kooooo00?o0000ooooooooool0V?ooool2o`00
00Oooooo0_l00009ooooo`;o0000;_ooool2o`0000?ooooo0_l0001Tooooo`007_ooool00ol0003o
ooooooooo`2Qooooo`;o00002Oooool2o`0002kooooo0_l0000Booooo`;o0000EOooool001kooooo
00?o0000ooooooooool0L_ooool2o`00017ooooo0_l0001Yooooo`;o00001oooool2o`0000gooooo
0_l0000=ooooo`;o00001_ooool2o`0002Kooooo000Nooooo`03o`000?oooooooooo053ooooo0_l0
000Pooooo`;o00004Oooool2o`0007;ooooo0_l0000=ooooo`;o00003Oooool2o`0000Kooooo0_l0
000Vooooo`007_ooool00ol0003oooooooooo`14ooooo`;o00002Oooool3o`0003?ooooo0_l00004
ooooo`;o0000Coooool2o`0000gooooo0_l0001Jooooo`007_ooool00ol0003oooooooooo`0Coooo
o`;o0000;oooool2o`0000Wooooo0_l0000booooo`Co00001?ooool2o`0000Kooooo0_l0000Loooo
o`;o00003_ooool2o`0001Wooooo0_l0000=ooooo`;o00002oooool2o`0004gooooo0003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006
ooooo`03o`000?oooooooooo01?ooooo0_l0000Kooooo`;o0000DOooool2o`0000kooooo0_l0000L
ooooo`;o00003_ooool2o`0003Gooooo0_l0001=ooooo`000oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003ooooooooo
o`0Uooooo`;o00002Oooool2o`0001;ooooo0_l000000ooooooo0000o`00003Wooooo`;o00005Ooo
ool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000
1_ooool3o`0002Gooooo0_l0000Mooooo`;o000000?oooooo`000?l00000A?ooool2o`0002oooooo
0_l00010ooooo`;o0000;_ooool2o`0001Gooooo0003ooooo`05o`000?ooooooooooooooool00000
2oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000ooooooooool0SOooool2o`0001?o
oooo0_l0000Jooooo`;o00006oooool2o`0000Sooooo0_l0000Iooooo`;o0000AOooool000?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool2o`00
00Cooooo0_l0000Tooooo`;o0000Moooool2o`0003Oooooo0_l00008ooooo`;o0000H?ooool000?o
oooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool2
o`0000Cooooo0_l0000Tooooo`?o0000oooooolLooooo`000oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`?o00009Oooool2o`0000?ooooo0_l0
000Oooooo`;o0000K_ooool2o`00043ooooo0_l00008ooooo`Co00007oooool2o`0000_ooooo0_l0
000>ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@06ooooo`?o00009Oooool2o`0002Cooooo0_l0001Booooo`;o00006_ooool2o`00043ooooo
0_l00008ooooo`Co00007oooool2o`0000_ooooo0_l0000>ooooo`007_ooool00ol0003ooooooooo
o`2Oooooo`;o0000@_ooool2o`0005;ooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`1n
ooooo`;o0000Hoooool2o`0001Gooooo0_l0001;ooooo`007_ooool00ol0003oooooooooo`0eoooo
o`;o00004?ooool2o`0003Gooooo0_l0001=ooooo`;o0000:oooool2o`0001;ooooo0_l0000/oooo
o`;o00002Oooool001kooooo00?o0000ooooooooool0=Oooool2o`00013ooooo0_l00014ooooo`;o
0000?_ooool2o`0003oooooo0_l0000/ooooo`;o00002Oooool001kooooo00?o0000ooooooooool0
SOooool2o`00023ooooo0_l0001;ooooo`;o000000Coooooo`000?l0003o00002oooool2o`0003So
oooo000Nooooo`;o0000;Oooool2o`00087ooooo0_l0000[ooooo`;o00007_ooool2o`000004oooo
ool0003o0000o`0000_ooooo0_l0000hooooo`007_ooool2o`0002gooooo0_l0000Booooo`;o0000
LOooool2o`0001cooooo0_l00009ooooo`;o00007oooool2o`0000kooooo0_l0000hooooo`007_oo
ool00ol0003oooooooooo`10ooooo`;o0000LOooool2o`0001cooooo0_l00006ooooo`;o00003_oo
ool2o`0001;ooooo0_l0000Jooooo`;o0000;?ooool001kooooo00Co0000oooooooooooooooo0_l0
0015ooooo`;o0000Soooool2o`0000kooooo0_l0000Aooooo`;o00006oooool2o`0001Sooooo0_l0
000Booooo`007_ooool01?l0003oooooooooooooool2o`0004Gooooo0_l0001mooooo`;o0000<ooo
ool2o`0001_ooooo1?l0000Fooooo`;o00004_ooool001kooooo00?o0000ooooooooool0COooool2
o`0002Cooooo0_l0001Booooo`;o0000D_ooool2o`0002[ooooo000Nooooo`;o00009_ooool2o`00
01Kooooo0_l0000>ooooo`;o00009?ooool2o`0009Sooooo0_l0000Booooo`;o00009?ooool001ko
oooo00?o0000ooooooooool03_ooool2o`0001Gooooo0_l0000Fooooo`;o0000Eoooool2o`0000Wo
oooo0_l0001Zooooo`;o00004_ooool2o`0002Cooooo000Nooooo`03o`000?oooooooooo00Cooooo
0_l00008ooooo`;o00006oooool2o`00017ooooo0_l0001Fooooo`;o00002Oooool2o`0001kooooo
0_l00024ooooo`007_ooool00ol0003oooooooooo`04ooooo`;o00000oooool2o`00023ooooo0_l0
000Aooooo`;o0000=oooool2o`0004Sooooo0_l0001^ooooo`;o00005?ooool001kooooo00?o0000
ooooooooool02Oooool2o`00063ooooo0_l0000:ooooo`;o0000Loooool2o`0003Oooooo0_l0000:
ooooo`;o00005?ooool001kooooo00?o0000ooooooooool03?ooool2o`0001_ooooo0_l00010oooo
o`;o0000?Oooool2o`00043ooooo0_l0000gooooo`;o00008?ooool001kooooo00?o0000oooooooo
ool03?ooool2o`0000;ooooo0_l0000Gooooo`;o0000Ooooool2o`0003Kooooo0_l0001Sooooo`00
7_ooool00ol0003oooooooooo`0@ooooo`;o0000`Oooool2o`0000gooooo0_l0000Yooooo`;o0000
>?ooool001kooooo00?o0000ooooooooool02oooool2o`0000?ooooo0_l0000<ooooo`;o00003ooo
ool2o`0003Gooooo0_l0001[ooooo`;o0000>?ooool2o`0001Kooooo0_l0000Eooooo`;o00002Ooo
ool001kooooo00?o0000ooooooooool02oooool2o`0000?ooooo0_l0000<ooooo`;o00003oooool2
o`0000Wooooo0_l0000Zooooo`;o0000A_ooool2o`0001kooooo0_l0000Zooooo`;o00006oooool2
o`0000cooooo0_l0000Aooooo`;o00000_ooool2o`0000Wooooo000Nooooo`03o`000?oooooooooo
02Sooooo0_l0000@ooooo`;o0000L_ooool2o`0001kooooo0_l0000Dooooo`;o00005?ooool2o`00
01_ooooo0_l0000Oooooo`;o00003Oooool001kooooo00?o0000ooooooooool0:?ooool2o`000;[o
oooo0_l0001Qooooo`007_ooool00ol0003oooooooooo`0Qooooo`;o00007?ooool2o`000;?ooooo
0_l0000Nooooo`;o0000<Oooool001kooooo00?o0000ooooooooool08Oooool2o`0001cooooo0_l0
000Sooooo`;o0000Koooool2o`00013ooooo0_l000000ooooooo0000o`000008ooooo`;o00007_oo
ool2o`00037ooooo000Nooooo`03o`000?oooooooooo06Cooooo0_l0001_ooooo`;o00004?ooool2
o`000003ooooool0003o000003[ooooo0_l0000Oooooo`007_ooool00ol0003oooooooooo`3ooooo
obOooooo0_l0000Oooooo`007_ooool2o`0001cooooo0_l0003>ooooo`;o0000F_ooool001kooooo
00?o0000ooooooooool00_ooool2o`0001Oooooo0_l0003>ooooo`;o00003?ooool2o`0004cooooo
000Nooooo`03o`000?oooooooooo00;ooooo0_l0000Aooooo`;o0000Goooool2o`00087ooooo0_l0
001<ooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o00004_ooool2o`0001Wooooo0_l0000`
ooooo`;o0000>oooool4o`00023ooooo0_l0000hooooo`;o0000=?ooool001kooooo00?o0000oooo
ooooool03oooool2o`0001Sooooo0_l0000Iooooo`;o0000J_ooool2o`000003ooooool0003o0000
00;o00008?ooool2o`0002Cooooo0_l0000Booooo`;o0000=?ooool001kooooo00?o0000oooooooo
ool03oooool2o`0006gooooo0_l0000`ooooo`;o0000Boooool2o`0004Sooooo000Nooooo`03o`00
0?oooooooooo07Wooooo0_l00003ooooo`;o00006Oooool2o`0002kooooo0_l0000:ooooo`;o0000
Boooool2o`0002?ooooo000Nooooo`03o`000?oooooooooo07Wooooo0_l0000Nooooo`;o0000;_oo
ool2o`0000[ooooo0_l0000Kooooo`;o0000;_ooool2o`0002?ooooo000Nooooo`03o`000?oooooo
oooo02Oooooo0_l0000Looooo`;o0000;_ooool2o`0006cooooo0_l0000=ooooo`;o0000Doooool0
01kooooo00Co0000oooooooooooooooo0_l0000Cooooo`;o00003oooool2o`0001cooooo0_l0000D
ooooo`;o00006?ooool2o`00063ooooo0_l0000:ooooo`;o0000E?ooool2o`0000cooooo000Noooo
o`04o`000?ooooooooooooooo`;o00004oooool2o`0000[ooooo0_l0000gooooo`;o0000JOooool2
o`0000oooooo0_l0000[ooooo`;o00003?ooool2o`0002Gooooo0_l0000<ooooo`007_ooool00ol0
003oooooooooo`0Rooooo`;o0000?oooool2o`0003gooooo0_l0000Rooooo`;o0000??ooool2o`00
00cooooo0_l0000cooooo`007_ooool00ol0003oooooooooo`1Sooooo`;o0000;Oooool4o`000003
ooooool0003o000000Wooooo0_l00007ooooo`;o0000:oooool2o`0006gooooo000Nooooo`03o`00
0?oooooooooo043ooooo0_l0001@ooooo`Co000000?oooooo`000?l000004_ooool2o`0002_ooooo
0_l0000Zooooo`;o0000@Oooool001kooooo00?o0000ooooooooool0@?ooool2o`0003cooooo0_l0
0024ooooo`;o00007oooool2o`00023ooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l0001:
ooooo`;o00005oooool2o`0004[ooooo0_l0000?ooooo`;o00002_ooool2o`0003cooooo0_l00004
ooooo`;o00006_ooool001kooooo0_l0000Jooooo`;o0000=?ooool2o`0001Cooooo0_l0000=oooo
o`;o00009oooool2o`0002_ooooo0_l0000?ooooo`;o00002_ooool2o`0003Wooooo0_l00007oooo
o`;o00006_ooool001kooooo00?o0000ooooooooool0Coooool2o`0002?ooooo0_l0000Wooooo`;o
00002Oooool2o`0003_ooooo0_l0000kooooo`;o00008oooool001kooooo00?o0000ooooooooool0
V?ooool2o`0000kooooo0ol0000Cooooo`;o00009Oooool2o`0000Wooooo0_l0000/ooooo`;o0000
7_ooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo02_ooooo0_l00007ooooo`;o00007ooo
ool2o`00047ooooo0_l0000?ooooo`;o00004oooool2o`000003ooooool0003o000002gooooo0_l0
000/ooooo`;o00007_ooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo01_ooooo0_l0000>
ooooo`;o00001oooool2o`0001_ooooo0_l00002ooooo`;o0000;_ooool2o`0000Sooooo0_l0000H
ooooo`;o00004_ooool2o`0000;ooooo0_l00018ooooo`;o00008Oooool2o`0001Oooooo000Noooo
o`03o`000?oooooooooo01_ooooo0_l0000dooooo`;o0000<_ooool2o`0000Sooooo0_l0000Foooo
o`Co00004_ooool2o`0003_ooooo0_l0000?ooooo`;o00000oooool2o`0001cooooo0_l0000Goooo
o`007_ooool00ol0003oooooooooo`0_ooooo`;o00007oooool2o`0005Gooooo0_l0001Aooooo`;o
00002?ooool2o`0000[ooooo0_l0000eooooo`007_ooool00ol0003oooooooooo`0_ooooo`;o0000
7oooool2o`0000[ooooo0_l0000Nooooo`;o0000Doooool2o`0001Gooooo0_l0000Jooooo`;o0000
5_ooool2o`0002Wooooo000Nooooo`03o`000?oooooooooo02[ooooo0_l0000`ooooo`;o00007_oo
ool2o`0001Oooooo0_l0000jooooo`;o00005Oooool2o`0003;ooooo0_l00006ooooo`;o00008Ooo
ool001kooooo00?o0000ooooooooool0:_ooool2o`0002Kooooo0_l00011ooooo`;o0000SOooool2
o`00027ooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l0000Yooooo`;o0000=?ooool2o`00
06Cooooo0_l0001Gooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o00006Oooool2o`0005oo
oooo0_l0001Tooooo`;o00003Oooool2o`0004Sooooo000Nooooo`03o`000?oooooooooo00cooooo
0_l0002Eooooo`;o0000=Oooool2o`0001Kooooo0_l00009ooooo`;o0000;Oooool2o`0001Wooooo
000Nooooo`03o`000?oooooooooo02Oooooo0_l0000Yooooo`;o00009oooool2o`0002Kooooo0_l0
000eooooo`;o00005_ooool2o`0003Sooooo0_l0000Iooooo`005?ooool4o`000003oa0@4?oooooo
oooo00?ooooo00?o0000ooooooooool04?ooool2o`0001Gooooo0_l0000Yooooo`;o00009oooool2
o`0004_ooooo0_l0000hooooo`;o0000@oooool001Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0@ooooo`;o0000?Oooool2o`0007Oooooo0_l0000hooooo`;o00005_ooool2o`00
02_ooooo000Fooooo`03o`000?oooooooooo00Gooooo0ol0001?ooooo`;o00006oooool2o`00087o
oooo0_l0000Yooooo`;o00004Oooool2o`0001Sooooo000Fooooo`03o`000?oooooooooo07Cooooo
0_l00021ooooo`;o0000??ooool2o`0001Sooooo000Fooooo`03o`000?oooooooooo0?ooooooD?oo
ool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooo
oe3ooooo000Dooooo`03oeEEEOmVIVKo00000?ooooooD_ooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.79307 .70768 Mdot
.92053 .27357 Mdot
.58749 .37281 Mdot
.93086 .29505 Mdot
.38711 .56745 Mdot
.37281 .11358 Mdot
.78855 .96257 Mdot
.03795 .15828 Mdot
.75089 .57032 Mdot
.75979 .97116 Mdot
.48032 .62913 Mdot
.74656 .89184 Mdot
.6693 .87235 Mdot
.94894 .53302 Mdot
.07992 .54174 Mdot
.0554 .25232 Mdot
.75446 .02001 Mdot
.61946 .13071 Mdot
.0718 .06178 Mdot
.49793 .00778 Mdot
.21977 .42314 Mdot
.66437 .14878 Mdot
.78661 .74445 Mdot
.85301 .2814 Mdot
.20911 .80149 Mdot
.8207 .80089 Mdot
.94809 .2438 Mdot
.88563 .47203 Mdot
.24433 .21735 Mdot
.226 .40301 Mdot
.242 .29132 Mdot
.72988 .42053 Mdot
.85983 .80251 Mdot
.06145 .25047 Mdot
.13614 .06254 Mdot
.23687 .98866 Mdot
.99073 .38737 Mdot
.33223 .19422 Mdot
.89175 .09984 Mdot
.43691 .69298 Mdot
.70076 .81076 Mdot
.11748 .34723 Mdot
.51027 .6036 Mdot
.43744 .8245 Mdot
.57837 .74719 Mdot
.26625 .67647 Mdot
.45535 .66064 Mdot
.06097 .63479 Mdot
.61032 .38155 Mdot
.68162 .39081 Mdot
.63997 .26605 Mdot
.27581 .75506 Mdot
.97226 .46413 Mdot
.17507 .37934 Mdot
.51604 .85772 Mdot
.76822 .53621 Mdot
.08877 .06572 Mdot
.4551 .92883 Mdot
.54269 .27591 Mdot
.39277 .26287 Mdot
.9013 .97644 Mdot
.63617 .93253 Mdot
.23698 .60843 Mdot
.31047 .20276 Mdot
.249 .23692 Mdot
.13635 .86299 Mdot
.66449 .31425 Mdot
.45303 .28558 Mdot
.70657 .36776 Mdot
.99392 .34688 Mdot
.20764 .04727 Mdot
.67261 .08176 Mdot
.08264 .19463 Mdot
.0394 .27771 Mdot
.99655 .52209 Mdot
.67587 .04337 Mdot
.67665 .24017 Mdot
.49688 .18043 Mdot
.02177 .90586 Mdot
.98572 .84958 Mdot
.32942 .56584 Mdot
.02393 .53627 Mdot
.24639 .5151 Mdot
.37039 .34614 Mdot
.07007 .39143 Mdot
.37058 .22476 Mdot
.08483 .8369 Mdot
.65005 .14838 Mdot
.39001 .55403 Mdot
.16753 .95312 Mdot
.39962 .57505 Mdot
.18792 .1046 Mdot
.98723 .19214 Mdot
.17984 .57609 Mdot
.8078 .61565 Mdot
.87293 .18408 Mdot
.72285 .26581 Mdot
.56271 .94248 Mdot
.64638 .43859 Mdot
.75609 .78626 Mdot
.1623 .83934 Mdot
.66181 .81921 Mdot
.80253 .1587 Mdot
.48722 .72656 Mdot
.82828 .13848 Mdot
.26744 .1089 Mdot
.0176 .51266 Mdot
.41341 .97497 Mdot
.26044 .26608 Mdot
.89815 .02907 Mdot
.56124 .76959 Mdot
.13148 .21199 Mdot
.40248 .00406 Mdot
.50951 .383 Mdot
.66349 .80924 Mdot
.10519 .80087 Mdot
.8254 .6118 Mdot
.77476 .65227 Mdot
.78523 .1467 Mdot
.27337 .78526 Mdot
.60964 .78556 Mdot
.48917 .73994 Mdot
.95465 .90054 Mdot
.33241 .46069 Mdot
.59137 .93805 Mdot
.83355 .09516 Mdot
.04351 .2889 Mdot
.77892 .25491 Mdot
.26003 .66217 Mdot
.96145 .59655 Mdot
.38011 .55348 Mdot
.73274 .93712 Mdot
.91916 .71858 Mdot
.24276 .2246 Mdot
.96916 .74901 Mdot
.98222 .67456 Mdot
.30512 .70994 Mdot
.05592 .69474 Mdot
.256 .44562 Mdot
.37536 .35875 Mdot
.01153 .79939 Mdot
.39963 .75085 Mdot
.6607 .2848 Mdot
.72464 .78149 Mdot
.72539 .56348 Mdot
.45819 .55308 Mdot
.83328 .83333 Mdot
.41571 .94039 Mdot
.55345 .07975 Mdot
.34786 .24074 Mdot
.17761 .5548 Mdot
.9532 .96227 Mdot
.19389 .65423 Mdot
.64039 .1288 Mdot
.53351 .32878 Mdot
.88513 .34404 Mdot
.705 .87134 Mdot
.53895 .67142 Mdot
.85573 .0838 Mdot
.97382 .80026 Mdot
.36194 .01004 Mdot
.61824 .49237 Mdot
.08666 .61467 Mdot
.76806 .64204 Mdot
.91308 .87923 Mdot
.16082 .44511 Mdot
.45875 .43139 Mdot
.25428 .1456 Mdot
.7079 .59671 Mdot
.81794 .47502 Mdot
.79379 .42818 Mdot
.77209 .69459 Mdot
.49608 .44148 Mdot
.0661 .18715 Mdot
.3403 .88042 Mdot
.29981 .57704 Mdot
.37443 .98535 Mdot
.15547 .16806 Mdot
.83094 .60646 Mdot
.91313 .03088 Mdot
.18327 .90456 Mdot
.9532 .55124 Mdot
.34357 .39502 Mdot
.20677 .85095 Mdot
.90246 .892 Mdot
.18271 .65065 Mdot
.60343 .10784 Mdot
.8322 .03247 Mdot
.18402 .07802 Mdot
.68553 .91441 Mdot
.36737 .40404 Mdot
.8039 .87804 Mdot
.20615 .47573 Mdot
.6712 .36291 Mdot
.77401 .17248 Mdot
.49248 .49047 Mdot
.96577 .20692 Mdot
.27022 .78404 Mdot
.3622 .11772 Mdot
.48025 .69719 Mdot
.99626 .0629 Mdot
.86701 .80986 Mdot
.67889 .68248 Mdot
.0571 .89355 Mdot
.43871 .1179 Mdot
.46077 .58769 Mdot
.70608 .97094 Mdot
.98218 .06146 Mdot
.82362 .79778 Mdot
.62313 .169 Mdot
.53847 .66989 Mdot
.10823 .42129 Mdot
.39724 .50133 Mdot
.16198 .51197 Mdot
.8307 .86526 Mdot
.08084 .54211 Mdot
.31362 .72922 Mdot
.6285 .05952 Mdot
.64122 .78338 Mdot
.74974 .98182 Mdot
.90173 .00591 Mdot
.19501 .78028 Mdot
.37353 .38953 Mdot
.11821 .31347 Mdot
.97439 .84705 Mdot
.97506 .80681 Mdot
.15056 .97843 Mdot
.87964 .2024 Mdot
.78047 .11568 Mdot
.20076 .12746 Mdot
.11948 .3289 Mdot
.32717 .25934 Mdot
.1025 .36874 Mdot
.24464 .44273 Mdot
.76471 .95919 Mdot
.1688 .19251 Mdot
.78469 .11399 Mdot
.19528 .38708 Mdot
.63604 .21227 Mdot
.35998 .14834 Mdot
.88592 .99119 Mdot
.25444 .0117 Mdot
.79962 .62882 Mdot
.87621 .78024 Mdot
.61956 .18944 Mdot
.58172 .24681 Mdot
.819 .22557 Mdot
.44011 .12691 Mdot
.10688 .13611 Mdot
.29086 .72157 Mdot
.3285 .95081 Mdot
.77472 .56463 Mdot
.52445 .93277 Mdot
.61871 .5414 Mdot
.70592 .33581 Mdot
.73746 .75015 Mdot
.10406 .18287 Mdot
.08751 .42633 Mdot
.11666 .00962 Mdot
.6216 .41875 Mdot
.15178 .79193 Mdot
.45189 .7297 Mdot
.83952 .91982 Mdot
.68552 .20193 Mdot
.33672 .9053 Mdot
.1418 .7105 Mdot
.57803 .4951 Mdot
.47825 .91266 Mdot
.53937 .402 Mdot
.21951 .38285 Mdot
.19212 .42217 Mdot
.65069 .92271 Mdot
.10832 .61136 Mdot
.0219 .19343 Mdot
.34688 .67054 Mdot
.43768 .10049 Mdot
.02982 .70892 Mdot
.3118 .32729 Mdot
.44319 .12386 Mdot
.89055 .59767 Mdot
.03 .80201 Mdot
.61463 .15764 Mdot
.74274 .28878 Mdot
.97117 .24268 Mdot
.73524 .79946 Mdot
.93992 .98874 Mdot
.4899 .06182 Mdot
.54523 .93711 Mdot
.57254 .34007 Mdot
.25965 .50757 Mdot
.11548 .19154 Mdot
.44164 .05267 Mdot
.12087 .44336 Mdot
.64808 .90119 Mdot
.28334 .03685 Mdot
.72114 .56105 Mdot
.52626 .3787 Mdot
.83102 .57489 Mdot
.19334 .27122 Mdot
.34473 .67066 Mdot
.69516 .91069 Mdot
.18593 .12004 Mdot
.64096 .7103 Mdot
.78615 .01597 Mdot
.47867 .21118 Mdot
.99522 .20969 Mdot
.02112 .04642 Mdot
.25867 .65531 Mdot
.47044 .75216 Mdot
.5627 .05542 Mdot
.38082 .45982 Mdot
.24737 .41475 Mdot
.73321 .65865 Mdot
.11068 .41389 Mdot
.31429 .9345 Mdot
.31925 .33649 Mdot
.8567 .77692 Mdot
.35622 .11942 Mdot
.66384 .74672 Mdot
.99661 .41474 Mdot
.24952 .95435 Mdot
.47281 .4099 Mdot
.8427 .3625 Mdot
.23927 .98846 Mdot
.99513 .85806 Mdot
.16293 .56856 Mdot
.70653 .87138 Mdot
.83064 .20828 Mdot
.95417 .03631 Mdot
.46735 .10157 Mdot
.32012 .42215 Mdot
.52768 .70974 Mdot
.07754 .43294 Mdot
.99532 .25834 Mdot
.30505 .0441 Mdot
.77284 .30661 Mdot
.0979 .22175 Mdot
.54422 .71837 Mdot
.43013 .43425 Mdot
.74426 .60176 Mdot
.36867 .32984 Mdot
.2571 .45715 Mdot
.15804 .89713 Mdot
.84487 .80441 Mdot
.01342 .4972 Mdot
.75271 .60758 Mdot
.86646 .39967 Mdot
.07505 .20725 Mdot
.72477 .16981 Mdot
.47524 .45777 Mdot
.3751 .86913 Mdot
.72719 .99842 Mdot
.86138 .54162 Mdot
.39405 .52815 Mdot
.64224 .59088 Mdot
.57734 .69646 Mdot
.56457 .05572 Mdot
.8315 .08949 Mdot
.68741 .6446 Mdot
.89795 .88616 Mdot
.94444 .39102 Mdot
.2926 .39338 Mdot
.70273 .65136 Mdot
.60427 .35369 Mdot
.7817 .08079 Mdot
.22952 .95672 Mdot
.01172 .56161 Mdot
.54204 .16025 Mdot
.53533 .38201 Mdot
.72121 .05059 Mdot
.91857 .6888 Mdot
.9168 .21564 Mdot
.9101 .21843 Mdot
.51718 .87027 Mdot
.22617 .60075 Mdot
.93255 .43643 Mdot
.39334 .48906 Mdot
.75858 .628 Mdot
.27453 .984 Mdot
.20962 .32015 Mdot
.65518 .62986 Mdot
.52355 .27337 Mdot
.75241 .87635 Mdot
.64658 .97263 Mdot
.88746 .52151 Mdot
.06409 .14822 Mdot
.66852 .87532 Mdot
.16928 .67777 Mdot
.28148 .30488 Mdot
.38598 .10445 Mdot
.95783 .28347 Mdot
.27266 .71249 Mdot
.28783 .6251 Mdot
.73092 .37748 Mdot
.39889 .91946 Mdot
.1654 .36207 Mdot
.58781 .35846 Mdot
.01353 .22236 Mdot
.8541 .62251 Mdot
.91546 .50966 Mdot
.61773 .24036 Mdot
.29434 .46016 Mdot
.64218 .02838 Mdot
.1277 .74535 Mdot
.29381 .30117 Mdot
.41917 .29333 Mdot
.95384 .4153 Mdot
.32041 .98047 Mdot
.32508 .95574 Mdot
.32359 .64086 Mdot
.47305 .38594 Mdot
.49087 .21118 Mdot
.84684 .14244 Mdot
.05917 .73401 Mdot
.27559 .09799 Mdot
.95383 .06073 Mdot
.85141 .88131 Mdot
.44712 .75411 Mdot
.02209 .44435 Mdot
.13763 .87504 Mdot
.61694 .40191 Mdot
.82434 .13526 Mdot
.18448 .00321 Mdot
.2206 .99492 Mdot
.27222 .97509 Mdot
.17489 .2472 Mdot
.23047 .84035 Mdot
.16133 .28437 Mdot
.26815 .87887 Mdot
.68492 .50814 Mdot
.31253 .49509 Mdot
.47951 .69663 Mdot
.73614 .09226 Mdot
.79263 .48763 Mdot
.41634 .07333 Mdot
.50313 .59744 Mdot
.15821 .16298 Mdot
.35581 .34974 Mdot
.93582 .34856 Mdot
.16397 .0933 Mdot
.5286 .36309 Mdot
.50802 .52767 Mdot
.21892 .78233 Mdot
.04794 .94926 Mdot
.55714 .61685 Mdot
.24993 .40999 Mdot
.05239 .58197 Mdot
.71306 .82094 Mdot
.02015 .5054 Mdot
.21837 .46873 Mdot
.00808 .15454 Mdot
.02843 .50004 Mdot
.53656 .75814 Mdot
.43189 .94353 Mdot
.25115 .00394 Mdot
.47726 .94122 Mdot
.7288 .20776 Mdot
.30617 .6125 Mdot
.66383 .59846 Mdot
.5733 .80527 Mdot
.65128 .23724 Mdot
.22487 .26862 Mdot
.53565 .062 Mdot
.23172 .79215 Mdot
.02752 .24538 Mdot
.82079 .88786 Mdot
.80055 .22414 Mdot
.40605 .89871 Mdot
.05352 .94717 Mdot
.03216 .32508 Mdot
.4475 .2358 Mdot
.47467 .50047 Mdot
.8109 .11675 Mdot
.14473 .33199 Mdot
.18332 .11626 Mdot
.925 .6045 Mdot
.08479 .89036 Mdot
.12725 .73996 Mdot
.28928 .6695 Mdot
.78674 .8778 Mdot
.30725 .71901 Mdot
.57594 .49988 Mdot
.88726 .42368 Mdot
.17731 .96797 Mdot
.09305 .34807 Mdot
.00931 .60261 Mdot
.85616 .20516 Mdot
.14085 .08161 Mdot
.7546 .32147 Mdot
.07413 .31443 Mdot
.36737 .6154 Mdot
.32196 .49395 Mdot
.08053 .10527 Mdot
.72869 .04284 Mdot
.33502 .57705 Mdot
.66063 .0274 Mdot
.23146 .30249 Mdot
.61725 .39945 Mdot
.49716 .98779 Mdot
.53848 .33117 Mdot
.74855 .77714 Mdot
.50616 .04969 Mdot
.4014 .00829 Mdot
.17733 .51508 Mdot
.23463 .03609 Mdot
.46447 .56696 Mdot
.93528 .41232 Mdot
.81774 .58983 Mdot
.55264 .1071 Mdot
.09089 .11027 Mdot
.09095 .07839 Mdot
.56514 .73576 Mdot
.39307 .35055 Mdot
.10296 .65198 Mdot
.99265 .35853 Mdot
.92417 .11469 Mdot
.70396 .3857 Mdot
.59037 .54387 Mdot
.8941 .92425 Mdot
.76811 .06292 Mdot
.23887 .78364 Mdot
.75694 .90965 Mdot
.20227 .67782 Mdot
.14661 .13977 Mdot
.83006 .33799 Mdot
.07315 .49886 Mdot
.91417 .88469 Mdot
.19824 .37201 Mdot
.11764 .56757 Mdot
.55439 .79254 Mdot
.28486 .71122 Mdot
.77185 .66366 Mdot
.05827 .92463 Mdot
.99013 .66651 Mdot
.82338 .23864 Mdot
.75888 .49432 Mdot
.92835 .91742 Mdot
.68152 .98732 Mdot
.03515 .06491 Mdot
.61967 .78319 Mdot
.73717 .52963 Mdot
.89392 .00668 Mdot
.54902 .76667 Mdot
.22064 .31087 Mdot
.53033 .97314 Mdot
.2479 .64968 Mdot
.57842 .69424 Mdot
.47035 .11669 Mdot
.76838 .75889 Mdot
.82717 .05629 Mdot
.73083 .69427 Mdot
.24779 .25979 Mdot
.9059 .28912 Mdot
.31245 .31428 Mdot
.36506 .48063 Mdot
.17124 .00095 Mdot
.87894 .49671 Mdot
.88667 .39686 Mdot
.29632 .86818 Mdot
.43544 .29459 Mdot
.62598 .053 Mdot
.55059 .19675 Mdot
.86919 .28405 Mdot
.17773 .99207 Mdot
.98843 .03051 Mdot
.83147 .71849 Mdot
.52863 .57688 Mdot
.68079 .73851 Mdot
.64755 .10779 Mdot
.88247 .32684 Mdot
.28269 .24114 Mdot
.50036 .11501 Mdot
.83246 .22203 Mdot
.89996 .76686 Mdot
.0194 .89107 Mdot
.77594 .79993 Mdot
.10687 .8843 Mdot
.76978 .16796 Mdot
.41888 .31126 Mdot
.15553 .40165 Mdot
.77008 .18023 Mdot
.29351 .06467 Mdot
.45052 .93098 Mdot
.66831 .0265 Mdot
.54463 .83743 Mdot
.86091 .21403 Mdot
.62808 .85352 Mdot
.0465 .42159 Mdot
.57184 .02671 Mdot
.13445 .25452 Mdot
.22053 .77244 Mdot
.99756 .80811 Mdot
.35676 .55067 Mdot
.7673 .72485 Mdot
.96231 .51715 Mdot
.12799 .79089 Mdot
.43973 .79264 Mdot
.36734 .53796 Mdot
.7968 .88861 Mdot
.2348 .17819 Mdot
.14578 .85722 Mdot
.13502 .94213 Mdot
.98943 .16632 Mdot
.04845 .16648 Mdot
.70603 .58976 Mdot
.34769 .39485 Mdot
.58053 .96308 Mdot
.24961 .59392 Mdot
.07999 .19475 Mdot
.92354 .11709 Mdot
.50232 .22986 Mdot
.65612 .88799 Mdot
.19979 .26519 Mdot
.54482 .94856 Mdot
.26624 .11306 Mdot
.51269 .83495 Mdot
.66317 .58733 Mdot
.22102 .36854 Mdot
.95802 .6606 Mdot
.01991 .74246 Mdot
.87311 .39736 Mdot
.11123 .60366 Mdot
.43741 .26259 Mdot
.47654 .63613 Mdot
.05703 .98864 Mdot
.9024 .60434 Mdot
.8821 .799 Mdot
.39873 .78575 Mdot
.27799 .19548 Mdot
.22368 .31387 Mdot
.15406 .56586 Mdot
.1898 .48351 Mdot
.2875 .19904 Mdot
.06311 .90348 Mdot
.91899 .92753 Mdot
.69916 .22071 Mdot
.75116 .94793 Mdot
.77297 .58732 Mdot
.81538 .23096 Mdot
.22972 .84311 Mdot
.61835 .96943 Mdot
.10644 .39064 Mdot
.36102 .39584 Mdot
.71547 .86736 Mdot
.06717 .20249 Mdot
.72092 .8888 Mdot
.23113 .2541 Mdot
.98599 .56755 Mdot
.39161 .25779 Mdot
.25081 .94828 Mdot
.61075 .98952 Mdot
.02675 .20019 Mdot
.97814 .94162 Mdot
.94854 .91316 Mdot
.53539 .56496 Mdot
.10481 .93535 Mdot
.51565 .44551 Mdot
.44914 .11703 Mdot
.28105 .19568 Mdot
.53192 .58137 Mdot
.72297 .00062 Mdot
.11493 .56382 Mdot
.17915 .98612 Mdot
.18069 .29608 Mdot
.24432 .94569 Mdot
.20256 .52866 Mdot
.76806 .33234 Mdot
.15774 .46883 Mdot
.36225 .90769 Mdot
.60772 .36605 Mdot
.10942 .60925 Mdot
.22834 .70508 Mdot
.40866 .77749 Mdot
.02774 .14235 Mdot
.0488 .74111 Mdot
.82211 .71066 Mdot
.80739 .85253 Mdot
.6105 .32022 Mdot
.0095 .5933 Mdot
.52152 .77672 Mdot
.57938 .69179 Mdot
.79536 .58168 Mdot
.46338 .02889 Mdot
.64449 .81501 Mdot
.14582 .2945 Mdot
.59905 .65139 Mdot
.05691 .51391 Mdot
.79681 .91596 Mdot
.27176 .67572 Mdot
.12934 .66123 Mdot
.28324 .04768 Mdot
.69814 .84736 Mdot
.73002 .30232 Mdot
.95548 .26921 Mdot
.31739 .31836 Mdot
.22944 .41538 Mdot
.19089 .05451 Mdot
.69615 .71893 Mdot
.16192 .49888 Mdot
.83395 .79304 Mdot
.89181 .95175 Mdot
.76464 .22898 Mdot
.54785 .81418 Mdot
.88349 .41718 Mdot
.84421 .50268 Mdot
.02215 .11558 Mdot
.55594 .19021 Mdot
.67281 .64499 Mdot
.40583 .15868 Mdot
.01123 .88663 Mdot
.26765 .55273 Mdot
.19363 .10062 Mdot
.4023 .72921 Mdot
.57112 .91565 Mdot
.81117 .83845 Mdot
.52221 .47363 Mdot
.02897 .37536 Mdot
.48636 .38093 Mdot
.35334 .1487 Mdot
.81026 .75542 Mdot
.97302 .056 Mdot
.79585 .83031 Mdot
.76452 .4149 Mdot
.61333 .71697 Mdot
.42391 .78065 Mdot
.11293 .94294 Mdot
.47871 .887 Mdot
.47581 .4676 Mdot
.48209 .65194 Mdot
.98558 .09792 Mdot
.22196 .50276 Mdot
.16312 .34398 Mdot
.02238 .53532 Mdot
.40395 .58224 Mdot
.29813 .03805 Mdot
.88099 .77862 Mdot
.0204 .33347 Mdot
.80207 .7642 Mdot
.56251 .41479 Mdot
.37932 .33489 Mdot
.11544 .77149 Mdot
.40082 .24626 Mdot
.95351 .24404 Mdot
.11206 .88973 Mdot
.83435 .78839 Mdot
.66879 .41503 Mdot
.46396 .68446 Mdot
.88944 .69256 Mdot
.36007 .43046 Mdot
.11661 .90101 Mdot
.85676 .02302 Mdot
.73819 .5424 Mdot
.84273 .27119 Mdot
.4457 .2344 Mdot
.87467 .01487 Mdot
.25625 .34848 Mdot
.93579 .15569 Mdot
.51479 .91563 Mdot
.48829 .41243 Mdot
.59803 .30794 Mdot
.07685 .95722 Mdot
.62653 .37317 Mdot
.26899 .98049 Mdot
.92714 .94791 Mdot
.48567 .74144 Mdot
.5554 .7751 Mdot
.6802 .77396 Mdot
.32409 .37833 Mdot
.73551 .60147 Mdot
.84442 .50612 Mdot
.27092 .19453 Mdot
.08317 .17136 Mdot
.13417 .11669 Mdot
.4068 .73426 Mdot
.91329 .21639 Mdot
.59426 .76467 Mdot
.32668 .41667 Mdot
.00657 .13941 Mdot
.57997 .78111 Mdot
.75314 .70822 Mdot
.86947 .20133 Mdot
.97247 .17985 Mdot
.51282 .08067 Mdot
.98332 .03804 Mdot
.45447 .83645 Mdot
.46585 .25682 Mdot
.51898 .69134 Mdot
.95372 .44908 Mdot
.24217 .11176 Mdot
.87193 .47599 Mdot
.54427 .4097 Mdot
.05785 .82572 Mdot
.80203 .22637 Mdot
.98378 .5828 Mdot
.23361 .27277 Mdot
.03013 .68465 Mdot
.80869 .43745 Mdot
.58647 .31421 Mdot
.16712 .83546 Mdot
.67143 .79432 Mdot
.02136 .5914 Mdot
.82127 .37708 Mdot
.43121 .21955 Mdot
.76582 .58933 Mdot
.65567 .99547 Mdot
.76461 .97356 Mdot
.48067 .70806 Mdot
.5994 .27928 Mdot
.64048 .2482 Mdot
.1046 .89615 Mdot
.48646 .40307 Mdot
.42903 .00734 Mdot
.41099 .76858 Mdot
.52474 .7501 Mdot
.11431 .58935 Mdot
.86267 .11243 Mdot
.34283 .66703 Mdot
.06401 .23296 Mdot
.92847 .9321 Mdot
.55314 .90029 Mdot
.31472 .73334 Mdot
.53473 .07494 Mdot
.90678 .26247 Mdot
.0851 .00749 Mdot
.32235 .45591 Mdot
.39849 .30833 Mdot
.29238 .80703 Mdot
.60574 .12189 Mdot
.89605 .28732 Mdot
.49914 .92193 Mdot
.9525 .2801 Mdot
.9562 .99514 Mdot
.70903 .64453 Mdot
.51564 .98636 Mdot
.82368 .32193 Mdot
.37909 .98236 Mdot
.4269 .97875 Mdot
.99706 .79747 Mdot
.15055 .03945 Mdot
.30968 .64525 Mdot
.14078 .76987 Mdot
.86351 .68449 Mdot
.29552 .45751 Mdot
.94994 .71588 Mdot
.62734 .75261 Mdot
.46589 .78185 Mdot
.82729 .38989 Mdot
.93485 .82559 Mdot
.43325 .54038 Mdot
.051 .0307 Mdot
.26005 .45905 Mdot
.63842 .48292 Mdot
.96121 .77034 Mdot
.70262 .73618 Mdot
.68463 .23945 Mdot
.80594 .9707 Mdot
.04906 .41373 Mdot
.35093 .18108 Mdot
.24809 .0632 Mdot
.40508 .45022 Mdot
.91877 .56028 Mdot
.38514 .34686 Mdot
.66204 .01278 Mdot
.72639 .96621 Mdot
.72219 .23849 Mdot
.99772 .21783 Mdot
.00388 .90224 Mdot
.06643 .1767 Mdot
.93262 .52019 Mdot
.75904 .92739 Mdot
.71024 .46467 Mdot
.41309 .49247 Mdot
.73987 .99977 Mdot
.9648 .12794 Mdot
.16389 .88094 Mdot
.28893 .09687 Mdot
.56232 .7506 Mdot
.42127 .97498 Mdot
.4853 .74927 Mdot
.1963 .82326 Mdot
.50451 .23293 Mdot
.47241 .81882 Mdot
.78225 .77454 Mdot
.09969 .36627 Mdot
.99437 .80097 Mdot
.13502 .29592 Mdot
.89073 .90588 Mdot
.97888 .13687 Mdot
.45276 .19203 Mdot
.59912 .26303 Mdot
.93133 .49512 Mdot
.34257 .53142 Mdot
.45868 .20271 Mdot
.90654 .60035 Mdot
.57031 .46639 Mdot
.64334 .26838 Mdot
.64022 .59317 Mdot
.64489 7e-05 Mdot
.74024 .59307 Mdot
.59979 .85675 Mdot
.32032 .41287 Mdot
.96876 .62831 Mdot
.44771 .00053 Mdot
.65776 .13618 Mdot
.02432 .79913 Mdot
.77914 .51735 Mdot
.33713 .33133 Mdot
.90056 .2619 Mdot
.71847 .83878 Mdot
.40116 .23791 Mdot
.96527 .16069 Mdot
.86227 .38936 Mdot
.6344 .73968 Mdot
.91224 .86443 Mdot
.1348 .81194 Mdot
.32392 .70874 Mdot
.14671 .9625 Mdot
.6141 .27967 Mdot
.88114 .65372 Mdot
.57363 .99129 Mdot
.10895 .92098 Mdot
.09037 .7383 Mdot
.13139 .62635 Mdot
.26305 .32438 Mdot
.46631 .05695 Mdot
.37076 .42064 Mdot
.12732 .27403 Mdot
.03567 .75252 Mdot
.04269 .28228 Mdot
.44961 .53544 Mdot
.15278 .58628 Mdot
.95186 .49065 Mdot
.12252 .81516 Mdot
.7778 .68256 Mdot
.03047 .06725 Mdot
.65034 .29437 Mdot
.48299 .97288 Mdot
.21087 .77166 Mdot
.27409 .67689 Mdot
.13233 .11196 Mdot
.31787 .50634 Mdot
.71071 .62936 Mdot
.1831 .82966 Mdot
.79911 .2022 Mdot
.09437 .02797 Mdot
.94749 .48508 Mdot
.14222 .06549 Mdot
.36445 .23981 Mdot
.57095 .06724 Mdot
.23583 .44369 Mdot
.32824 .30239 Mdot
.8741 .33102 Mdot
.09266 .76338 Mdot
.29193 .60309 Mdot
.94517 .99713 Mdot
.47515 .48292 Mdot
.87037 .90698 Mdot
.52052 .93754 Mdot
.81113 .8025 Mdot
.27104 .65962 Mdot
.20014 .74612 Mdot
.12043 .27378 Mdot
.84132 .5421 Mdot
.00096 .9369 Mdot
.66118 .81773 Mdot
.74549 .30323 Mdot
.77139 .78299 Mdot
.17949 .69562 Mdot
.8548 .92496 Mdot
.69549 .89149 Mdot
.06056 .14207 Mdot
.4811 .1766 Mdot
.94054 .34139 Mdot
.38121 .93024 Mdot
.0809 .84582 Mdot
.26192 .95156 Mdot
.27022 .01902 Mdot
.50665 .59341 Mdot
.56456 .22187 Mdot
.3671 .77406 Mdot
.71764 .26057 Mdot
.68951 .05098 Mdot
.61467 .13969 Mdot
.32045 .82362 Mdot
.73645 .77926 Mdot
.01789 .99296 Mdot
.66774 .94944 Mdot
.67513 .06403 Mdot
.34315 .88251 Mdot
.09676 .43244 Mdot
.75082 .61706 Mdot
.80633 .69181 Mdot
.12217 .31029 Mdot
.12464 .57164 Mdot
.50434 .22 Mdot
.75924 .75707 Mdot
.81764 .43641 Mdot
.68222 .91772 Mdot
.13661 .37418 Mdot
.06863 .84663 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Co
oooo0_l00002ooooo`;o00001?ooool00ol0003oooooooooo`0=ooooo`;o00003_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00kooooo0_l0000<ooooo`?o00003oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02oooool3o`0000oo
oooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo000Nooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool02?ooool2o`0000?ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`08ooooo`;o00001?ooool00ol0003oooooooooo`0=ooooo`;o00003_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo0_l00006ooooo`;o00001_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool4o`0000kooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooooooo
o`0Hooooo`;o00002?ooool2o`0004kooooo0_l0000:ooooo`;o00001oooool2o`0001Gooooo0_l0
001oooooo`Co00009?ooool001kooooo00?o0000ooooooooool08_ooool2o`0002_ooooo0_l0000Q
ooooo`;o00002_ooool2o`0001kooooo0_l0000cooooo`;o0000L_ooool001kooooo00?o0000oooo
ooooool0Coooool2o`0008;ooooo0_l0000Vooooo`;o00006oooool2o`0002gooooo000Nooooo`03
o`000?oooooooooo05Cooooo0_l0002Uooooo`;o00006oooool2o`0002gooooo000Nooooo`03o`00
0?oooooooooo05Cooooo0_l0002Kooooo`;o0000E?ooool001kooooo00?o0000ooooooooool0lOoo
ool2o`0001oooooo0_l0000cooooo`007_ooool00ol0003oooooooooo`0Kooooo`;o0000M_ooool2
o`00027ooooo0_l0000Eooooo`;o00001?ooool4o`0003_ooooo0_l0000<ooooo`;o00009Oooool0
01kooooo00?o0000ooooooooool03?ooool2o`0000gooooo0_l0001fooooo`;o00008Oooool2o`00
01Gooooo0_l00004ooooo`Co0000BOooool2o`0000?ooooo0_l0000Fooooo`;o00002?ooool001ko
oooo00?o0000ooooooooool03?ooool2o`000?cooooo0_l0000Iooooo`;o00005_ooool2o`0000So
oooo000Nooooo`03o`000?oooooooooo04Sooooo0_l0000>ooooo`;o00000oooool2o`000:_ooooo
0_l0000Vooooo`;o00002?ooool2o`0000Wooooo000Nooooo`03o`000?oooooooooo02gooooo0_l0
000Iooooo`;o00003_ooool2o`0000?ooooo0_l0003Cooooo`;o00002?ooool2o`0000Wooooo000N
ooooo`03o`000?oooooooooo02gooooo0_l0000`ooooo`;o0000Moooool2o`0000oooooo0_l0001L
ooooo`007_ooool00ol0003oooooooooo`03ooooo`;o0000>_ooool2o`0001kooooo0_l0001goooo
o`;o00003oooool2o`0005cooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0000jooooo`;o
00005oooool2o`0004Kooooo0_l00014ooooo`;o0000Goooool001kooooo0_l0001Iooooo`;o0000
<Oooool2o`0001?ooooo0_l0000Uooooo`;o00004oooool2o`0000Sooooo0_l0001Oooooo`007_oo
ool00ol0003oooooooooo`0jooooo`;o0000Coooool2o`0002Kooooo0_l0000Booooo`;o00004ooo
ool2o`0002_ooooo0_l0000]ooooo`;o00003Oooool001kooooo00?o0000ooooooooool0>_ooool2
o`0005Oooooo0_l0000Nooooo`;o00004oooool2o`0003oooooo0_l0000]ooooo`;o00003Oooool0
01kooooo00?o0000ooooooooool04oooool2o`0001?ooooo0_l0001Yooooo`;o00001_ooool2o`00
00gooooo0_l0000Looooo`;o0000;?ooool2o`0003[ooooo0_l00007ooooo`;o00000oooool2o`00
00Gooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0000:ooooo`;o00001?ooool2o`0000go
oooo1?l0000Qooooo`;o00003?ooool2o`0003kooooo0_l0000=ooooo`;o0000:oooool2o`0001go
oooo0_l0000jooooo`;o00001oooool2o`0000?ooooo0_l00005ooooo`007_ooool00ol0003ooooo
ooooo`06ooooo`?o00004?ooool2o`0000oooooo0_l0000Qooooo`;o00003?ooool2o`0005Wooooo
0_l0000Oooooo`;o0000K_ooool001kooooo00?o0000ooooooooool01_ooool2o`000:kooooo0_l0
002?ooooo`007_ooool00ol0003oooooooooo`23ooooo`;o00009Oooool2o`0009_ooooo000Noooo
o`03o`000?oooooooooo03Sooooo0_l00019ooooo`;o00009Oooool2o`0009_ooooo000Nooooo`03
o`000?oooooooooo01Wooooo0_l0000Mooooo`;o0000JOooool2o`0000_ooooo0_l00018ooooo`;o
0000Boooool001kooooo00?o0000ooooooooool06Oooool2o`0000oooooo0_l0001gooooo`;o0000
2oooool2o`0002Gooooo0_l0000Qooooo`;o00005_ooool2o`0003?ooooo000Nooooo`03o`000?oo
oooooooo02[ooooo0_l0002[ooooo`;o0000>Oooool2o`0003?ooooo000Nooooo`03o`000?oooooo
oooo0?oooooo2oooool2o`0003_ooooo000Nooooo`03o`000?oooooooooo037ooooo0_l0002hoooo
o`;o00007Oooool2o`0003_ooooo000Nooooo`03o`000?oooooooooo037ooooo0_l0002hooooo`;o
00007_ooool2o`0003[ooooo000Nooooo`03o`000?oooooooooo05Gooooo0_l00003ooooo`;o0000
[oooool2o`00017ooooo0_l0000Looooo`;o00002Oooool001kooooo0_l0000looooo`;o00006?oo
ool2o`0000?ooooo0_l0000^ooooo`;o00002?ooool2o`0008Sooooo0_l0000Looooo`;o00002Ooo
ool001kooooo00?o0000ooooooooool05_ooool2o`00027ooooo1?l0000looooo`;o00003oooool2
o`0000Sooooo0_l0002aooooo`007_ooool00ol0003oooooooooo`0Fooooo`;o00008Oooool2o`00
01Sooooo0_l0000Tooooo`;o0000=Oooool2o`0000kooooo0_l0000<ooooo`;o0000Moooool001ko
oooo00?o0000ooooooooool06Oooool2o`0000cooooo0_l0000Rooooo`;o00001_ooool2o`0005_o
oooo0_l0000>ooooo`;o00003?ooool2o`0007Oooooo000Nooooo`03o`000?oooooooooo01Wooooo
0_l0000<ooooo`;o00008_ooool2o`0000Gooooo0_l0000Qooooo`;o0000:?ooool2o`0005[ooooo
0_l0000Gooooo`;o00004_ooool2o`0001gooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0
000Sooooo`;o00003Oooool2o`0001Wooooo0_l0000Nooooo`;o000000?oooooo`000?l000005?oo
ool2o`000003ooooool0003o000000Gooooo0_l00008ooooo`;o0000FOooool3o`0000Oooooo0_l0
000>ooooo`;o00004_ooool2o`0001gooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0000S
ooooo`;o00003Oooool3o`0003Kooooo1?l0000Gooooo`;o000000?oooooo`000?l000001Oooool2
o`0006?ooooo0_l00008ooooo`;o00008_ooool2o`0001gooooo000Nooooo`03o`000?oooooooooo
03Sooooo0_l0000fooooo`;o00006_ooool2o`0003?ooooo0_l00024ooooo`007_ooool00ol0003o
ooooooooo`0mooooo`;o0000C?ooool3o`0003?ooooo0_l00024ooooo`007_ooool00ol0003ooooo
ooooo`0mooooo`;o0000C?ooool2o`0003oooooo0_l0001Xooooo`;o00003oooool001kooooo00?o
0000ooooooooool0aOooool2o`0000Gooooo0_l0001Xooooo`;o00003oooool001kooooo00?o0000
ooooooooool07oooool2o`000:Cooooo0_l0000;ooooo`;o0000=?ooool2o`0003gooooo000Noooo
o`?o00007oooool2o`0000_ooooo0_l0002Fooooo`;o00003?ooool2o`0003Cooooo0ol0000_oooo
o`;o00002oooool001kooooo0ol00005ooooo`;o00002Oooool2o`0001[ooooo0_l0002Fooooo`;o
0000@oooool2o`0000Cooooo0_l0000Yooooo`;o00002oooool001kooooo00?o0000ooooooooool0
1Oooool2o`0000Wooooo0_l0000mooooo`;o0000__ooool2o`0003Kooooo000Nooooo`03o`000?oo
oooooooo017ooooo0_l0000looooo`;o00007_ooool4o`0005cooooo0_l00003ooooo`;o00009Ooo
ool2o`0004[ooooo000Nooooo`;o00004_ooool2o`0005cooooo1?l0001Looooo`;o00000oooool2
o`0002Gooooo0_l0001:ooooo`007_ooool01?l0003oooooo`000?l0003oooooodOooooo000Noooo
o`04o`000?oooooo0000o`0000Oooooo0_l0002jooooo`;o0000I_ooool2o`0001Wooooo000Noooo
o`03o`000?oooooooooo00Sooooo0_l0001fooooo`;o0000:_ooool2o`0001Kooooo0_l0000koooo
o`;o0000:Oooool2o`0000Sooooo0_l0000?ooooo`007_ooool00ol0003oooooooooo`0_ooooo`;o
0000Coooool2o`0002[ooooo0_l0001Cooooo`;o0000<oooool2o`0000oooooo000Nooooo`03o`00
0?oooooooooo00cooooo0_l0000Qooooo`;o0000ooooool>ooooo`;o00001oooool001kooooo00?o
0000ooooooooool03?ooool2o`00023ooooo0_l0002Fooooo`;o00008?ooool2o`0000cooooo0_l0
0016ooooo`;o00001oooool001kooooo00?o0000ooooooooool05oooool2o`0001Gooooo0_l0002F
ooooo`;o00008?ooool2o`0000cooooo1?l0001=ooooo`007_ooool00ol0003oooooooooo`0Aoooo
o`;o00001?ooool2o`0007oooooo0_l0001Nooooo`;o0000COooool001kooooo00?o0000oooooooo
ool04Oooool2o`0003Gooooo0_l0001>ooooo`;o0000[Oooool001kooooo00?o0000ooooooooool0
7_ooool2o`0002Sooooo0_l0000Tooooo`;o0000;Oooool2o`0005Oooooo0_l00010ooooo`;o0000
3Oooool001kooooo00?o0000ooooooooool07_ooool2o`0004kooooo0_l0000]ooooo`;o0000Eooo
ool2o`00023ooooo0_l0000Nooooo`;o00003Oooool001kooooo00?o0000ooooooooool04Oooool2
o`000?oooooo1_ooool2o`0002gooooo000Nooooo`03o`000?oooooooooo017ooooo0_l0000>oooo
o`;o0000K?ooool2o`00023ooooo0_l0000Booooo`;o0000P?ooool000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool00oooool2o`00
017ooooo0ol00008ooooo`;o00004?ooool2o`0001oooooo0_l0000Booooo`;o00009Oooool2o`00
023ooooo0_l0000Booooo`;o0000M_ooool2o`0000Sooooo0003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooo
oooo00?ooooo0_l0000Aooooo`?o00006_ooool2o`0001oooooo1Ol0000?ooooo`;o0000AOooool2
o`0008cooooo0_l00008ooooo`000oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RH
ob4Q8Oo^k^h01oooool3o`0000Gooooo0_l0001?ooooo`Go0000E?ooool2o`0006Kooooo0_l0000^
ooooo`000oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01_ooool0
0ol0003oooooooooo`05ooooo`;o00002oooool2o`0004Gooooo0_l00006ooooo`;o0000;_ooool2
o`0004Sooooo0_l0000Sooooo`;o00005Oooool2o`000003ooooool0003o000002_ooooo0003oooo
o`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooo
oooo01;ooooo1?l0001;ooooo`;o0000;_ooool2o`0004Sooooo0_l0000Sooooo`;o00004?ooool2
o`0000Kooooo0_l0000Jooooo`;o00003oooool000?ooooo00Go410@oooooooooooooooooa0@400?
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05?ooool2o`000=?ooooo0_l0000O
ooooo`;o00001_ooool2o`0002;ooooo0_l00007ooooo`;o00001_ooool000?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003ooooooooo
o`0Wooooo`;o0000Koooool2o`000003ooooool0003o000002kooooo0_l0000Looooo`;o00007ooo
ool2o`0003?ooooo0_l00006ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo02Oooooo0_l0001_ooooo`;o0000
00?oooooo`000?l00000;_ooool2o`0004Oooooo0_l0000?ooooo`?o00007oooool001kooooo00?o
0000ooooooooool0Boooool2o`0003_ooooo0_l0002:ooooo`;o00003_ooool4o`0001Sooooo0_l0
0005ooooo`007_ooool00ol0003oooooooooo`02o`0001[ooooo0_l0000]ooooo`;o0000>oooool2
o`0001Kooooo0_l0000Aooooo`;o0000:_ooool2o`0002[ooooo0_l0000Gooooo`;o00006_ooool2
o`0000Gooooo000Nooooo`03o`000?oooooooooo00;o00006_ooool2o`0002gooooo0_l0000Woooo
o`;o0000:_ooool2o`00017ooooo0_l0000Zooooo`;o00007oooool2o`0000Cooooo0_l00003oooo
o`;o0000>_ooool001kooooo00?o0000ooooooooool0Boooool2o`0002Oooooo0_l0001nooooo`;o
00002_ooool3o`0000?ooooo0_l0000oooooo`007_ooool00ol0003oooooooooo`2Oooooo`;o0000
Doooool2o`0000_ooooo0_l00002ooooo`;o0000@?ooool001kooooo00?o0000ooooooooool04Ooo
ool2o`0007[ooooo0_l0000@ooooo`?o0000Hoooool2o`00043ooooo000Nooooo`03o`000?oooooo
oooo017ooooo0_l0000jooooo`;o0000;oooool2o`0000gooooo0_l0000Aooooo`;o0000;_ooool2
o`0007Gooooo000Nooooo`03o`000?oooooooooo04gooooo0_l00009ooooo`;o00004oooool2o`00
00?ooooo0_l0000:ooooo`;o00003Oooool2o`0003Kooooo0_l00009ooooo`;o00001_ooool4o`00
00_ooooo0_l0000Oooooo`;o0000?Oooool001kooooo00?o0000ooooooooool0F?ooool2o`0001?o
oooo0_l00003ooooo`;o0000DOooool2o`00017ooooo1?l0000;ooooo`;o00007oooool2o`0002Ko
oooo1?l00004ooooo`;o00003Oooool001kooooo00?o0000ooooooooool01Oooool2o`0002kooooo
0_l00017ooooo`;o0000>Oooool2o`0007Gooooo1?l00004ooooo`;o00003Oooool001kooooo00?o
0000ooooooooool01Oooool2o`0000Wooooo0_l0000Sooooo`;o0000Aoooool2o`0003Wooooo0_l0
000Aooooo`;o0000NOooool001kooooo0_l0000?ooooo`Co0000^_ooool2o`0007Wooooo000Noooo
o`03o`000?oooooooooo00kooooo0_l0000Hooooo`;o00007Oooool2o`000;3ooooo0_l0001<oooo
o`007_ooool00ol0003oooooooooo`0Xooooo`;o00007Oooool2o`0000?ooooo0_l0000Hooooo`;o
00004oooool2o`0001Kooooo0_l0001Tooooo`;o0000A?ooool2o`0000Kooooo000Nooooo`03o`00
0?oooooooooo04cooooo0_l0000Hooooo`;o00004oooool3o`0000cooooo0_l00007ooooo`;o0000
D?ooool2o`0003[ooooo1?l0000Jooooo`;o00001_ooool001kooooo00?o0000ooooooooool0?Ooo
ool2o`0003gooooo0_l0000<ooooo`;o0000<oooool2o`0002Cooooo1?l0000hooooo`Co00008_oo
ool001kooooo00?o0000ooooooooool0?Oooool2o`0000Kooooo0_l0000:ooooo`;o0000K?ooool2
o`0000_ooooo0ol0000Hooooo`;o0000G_ooool001kooooo00?o0000ooooooooool0>oooool2o`00
00Sooooo0_l0000:ooooo`;o0000NOooool3o`0003oooooo0_l0000Sooooo`;o00004_ooool001ko
oooo00?o0000ooooooooool08oooool4o`0001Cooooo0_l0000;ooooo`;o0000G?ooool2o`0006Ko
oooo0_l0000Gooooo`;o00002_ooool2o`0001;ooooo000Nooooo`03o`000?oooooooooo00Wooooo
0_l0000Hooooo`Co00008Oooool2o`0005cooooo0_l00004ooooo`;o0000NOooool2o`0001kooooo
000Nooooo`03o`000?oooooooooo00Wooooo0_l0002Qooooo`;o00004Oooool2o`0000?ooooo0_l0
001/ooooo`;o00004oooool001kooooo00?o0000ooooooooool02_ooool2o`0002Cooooo0_l0002=
ooooo`;o00000oooool2o`0004_ooooo0_l00003ooooo`;o00006_ooool3o`0001;ooooo000Noooo
o`03o`000?oooooooooo00[ooooo0_l0000Tooooo`;o0000GOooool2o`0004;ooooo0_l0000loooo
o`;o00000oooool2o`0000Oooooo0_l0000Booooo`;o00004_ooool001kooooo00?o0000oooooooo
ool02_ooool2o`0008?ooooo0_l00012ooooo`;o00006?ooool2o`00033ooooo0_l000000ooooooo
0000o`00000Sooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o0000?oooool2o`0003Oooooo
0_l0001Wooooo`;o0000<oooool2o`0002?ooooo000Nooooo`03o`000?oooooooooo02Sooooo0_l0
00000ooooooo0000o`00000:ooooo`;o00004_ooool2o`0003Oooooo0_l00003ooooo`;o0000A?oo
ool2o`0005[ooooo0_l0000Jooooo`007_ooool00ol0003oooooooooo`0Xooooo`;o000000?ooooo
o`000?l000002_ooool2o`00053ooooo0_l00014ooooo`;o0000F_ooool2o`0001[ooooo000Noooo
o`;o0000B?ooool2o`0001;ooooo0_l0000:ooooo`;o0000P?ooool2o`0005cooooo000Nooooo`03
o`000?oooooooooo04Oooooo0_l0000>ooooo`;o00000_ooool2o`0000[ooooo0_l00020ooooo`;o
00000oooool2o`0005Oooooo000Nooooo`03o`000?oooooooooo05Oooooo0_l0000Tooooo`;o0000
?oooool2o`0002kooooo0_l00007ooooo`;o0000C_ooool001kooooo00?o0000ooooooooool09?oo
ool2o`0001kooooo0_l0000gooooo`;o00001Oooool2o`0003Sooooo0_l0000gooooo`;o0000C_oo
ool001kooooo00?o0000ooooooooool05?ooool2o`0000cooooo1?l0000Nooooo`?o00006_ooool2
o`00027ooooo0_l0000eooooo`;o00005oooool2o`00077ooooo000Nooooo`03o`000?oooooooooo
01Cooooo0_l0000<ooooo`;o00008Oooool2o`0001[ooooo0_l0001Hooooo`;o00005oooool2o`00
077ooooo000Nooooo`03o`000?oooooooooo043ooooo0_l0000Qooooo`;o0000GOooool2o`0008?o
oooo000Nooooo`03o`000?oooooooooo043ooooo0_l0000?ooooo`;o00004?ooool2o`0005gooooo
0_l0000]ooooo`;o00005Oooool2o`0003gooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l0
0019ooooo`;o00003_ooool2o`0008kooooo0_l0000Eooooo`;o00004Oooool2o`0002[ooooo000N
ooooo`03o`000?oooooooooo00Kooooo0_l0000Kooooo`;o0000??ooool2o`00017ooooo0_l0000c
ooooo`;o0000L?ooool2o`0002[ooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0000Noooo
o`;o00001_ooool2o`0003cooooo0_l00009ooooo`;o0000<oooool4o`0004Wooooo0_l0000Poooo
o`;o0000;Oooool001kooooo00?o0000ooooooooool00oooool2o`0002Kooooo0_l0000gooooo`;o
00000oooool2o`0000cooooo0_l0000booooo`;o0000=?ooool2o`0001?ooooo0_l0000Pooooo`;o
0000;Oooool001kooooo00?o0000ooooooooool0I?ooool2o`00017ooooo0_l0001Xooooo`;o0000
9oooool2o`0003_ooooo000Nooooo`03o`000?oooooooooo0;Kooooo0_l0001Booooo`;o00008_oo
ool2o`0001Oooooo000Nooooo`03o`000?oooooooooo037ooooo0_l00023ooooo`;o0000I?ooool2
o`00013ooooo0_l0000Gooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o00001_ooool2o`00
00gooooo0_l0000Looooo`;o00008oooool2o`0000?ooooo0_l0002Qooooo`;o00003_ooool2o`00
017ooooo0_l00006ooooo`007_ooool2o`0001_ooooo0_l00006ooooo`;o0000:oooool2o`0001oo
oooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o00000:kooooo0_l0000Aooooo`;o
00001_ooool001kooooo00?o0000ooooooooool0L?ooool2o`0000[ooooo0_l00012ooooo`;o0000
QOooool001kooooo00?o0000ooooooooool0`?ooool2o`0008Gooooo000Nooooo`03o`000?oooooo
oooo07Kooooo0_l00013ooooo`;o0000P_ooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo
03;ooooo0_l00012ooooo`;o0000<?ooool2o`00017ooooo0_l0000Iooooo`;o0000=_ooool2o`00
02oooooo0_l00006ooooo`007_ooool00ol0003oooooooooo`0Looooo`;o00005?ooool2o`0007Co
oooo0_l0000Gooooo`;o00004oooool2o`0003Kooooo0_l0000gooooo`007_ooool00ol0003ooooo
ooooo`0Looooo`?o00009Oooool2o`0007_ooooo0_l0000Oooooo`;o0000Hoooool001kooooo00?o
0000ooooooooool07Oooool2o`0001gooooo0_l00006ooooo`;o0000MOooool2o`0000_ooooo0_l0
000Hooooo`;o0000Hoooool001kooooo00?o0000ooooooooool01Oooool2o`00027ooooo0_l0000B
ooooo`;o0000OOooool2o`0000_ooooo0_l0001mooooo`007_ooool00ol0003oooooooooo`05oooo
o`;o00008Oooool2o`0000_ooooo0_l0000^ooooo`;o0000@?ooool2o`00047ooooo0_l0000Koooo
o`;o0000?_ooool001kooooo00?o0000ooooooooool0=Oooool2o`0002kooooo0_l0000cooooo`;o
00002oooool2o`000003ooooool0003o000001Kooooo0_l0000Vooooo`;o00006oooool2o`0003ko
oooo000Nooooo`03o`000?oooooooooo04?ooooo0_l0001Eooooo`;o00001_ooool2o`0000Kooooo
0_l0000Fooooo`;o00007Oooool2o`0006Cooooo000Nooooo`03o`000?oooooooooo03_ooooo0_l0
0006ooooo`;o0000DOooool2o`0000[ooooo0_l0000mooooo`;o0000Foooool2o`0000Oooooo000N
ooooo`03o`000?oooooooooo01?ooooo0_l00009ooooo`;o00006oooool2o`0003Sooooo0_l0000O
ooooo`;o0000@Oooool2o`0002kooooo0_l00009ooooo`;o00006Oooool2o`0000gooooo0_l00007
ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool01?ooool00ol0003oooooooooo`0Cooooo`;o00002Oooool2o`0003_ooooo0_l0000?
ooooo`?o00001_ooool2o`0006;ooooo0_l0000^ooooo`;o00002Oooool2o`0001Wooooo0_l0000F
ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0Foooool2o`0000oooooo0ol00002ooooo`;o0000YOooool2
o`0000;ooooo0_l0000Yooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006
ooooo`?o0000LOooool2o`0005;ooooo0_l0001?ooooo`Co00000_ooool2o`0002Wooooo0003oooo
o`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00007ooooo`03o`000?oo
oooooooo02kooooo0_l0000Eooooo`;o0000;?ooool2o`0002Gooooo0_l0000?ooooo`;o00005ooo
ool3o`0004oooooo0_l0000_ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Co
gMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`0^ooooo`;o00005Oooool2o`0002cooooo
0_l0000Uooooo`;o00003oooool2o`0001Oooooo0_l00021ooooo`000oooool01Ol@413ooooooooo
oooooooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`1=ooooo`;o0000
Aoooool2o`0001Gooooo0_l0002Hooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo
00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`1=ooooo`;o00005Oooool2o`00033ooooo
0_l00003ooooo`;o00004?ooool2o`0007gooooo0_l0000Iooooo`000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`0<ooooo`;o0000
4_ooool2o`0002Cooooo0_l00004ooooo`;o00005_ooool2o`0003Gooooo0_l0000Fooooo`;o0000
8?ooool2o`0001gooooo0_l0000fooooo`;o00001?ooool2o`0000cooooo0_l00005ooooo`007_oo
ool00ol0003oooooooooo`0<ooooo`;o00004_ooool2o`0002Cooooo0_l00004ooooo`;o00006?oo
ool2o`0004_ooooo0_l0000Aooooo`;o00003Oooool2o`0001gooooo0_l0000Uooooo`;o00005Ooo
ool2o`0000cooooo0_l00005ooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o00004_ooool2
o`0001Wooooo0_l0000Xooooo`Co00003?ooool2o`00053ooooo0_l0000Qooooo`;o0000<?ooool2
o`0002[ooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l0000Booooo`;o00006Oooool2o`00
00Oooooo0_l0000Oooooo`;o00003_ooool2o`0007?ooooo0_l0000aooooo`;o0000:Oooool001ko
oooo00?o0000ooooooooool06?ooool2o`0002Wooooo0_l0002iooooo`;o00007?ooool2o`0002Wo
oooo000Nooooo`03o`000?oooooooooo01Sooooo0_l0001Gooooo`;o00007_ooool2o`0006_ooooo
0_l00017ooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o00001?ooool2o`0005Cooooo0_l0
000Eooooo`;o00001oooool2o`000;Cooooo000Nooooo`03o`000?oooooooooo01Gooooo0_l00004
ooooo`;o0000Joooool2o`0007Wooooo0_l000000ooooooo0000o`00000Sooooo`;o00006_ooool0
01kooooo00?o0000ooooooooool0c_ooool2o`0003?ooooo0_l000000ooooooo0000o`00000Soooo
o`;o00006_ooool001kooooo00?o0000ooooooooool00oooool2o`0001kooooo0_l0000Tooooo`Co
0000D?ooool2o`0002oooooo0_l0001gooooo`007_ooool00ol0003oooooooooo`03ooooo`;o0000
7_ooool2o`0000_ooooo0_l0000Gooooo`Co00000_ooool2o`0004cooooo0_l00005ooooo`;o0000
XOooool001kooooo00?o0000ooooooooool0<?ooool2o`0001gooooo0_l0000_ooooo`;o00008_oo
ool2o`0008cooooo0_l0000Cooooo`007_ooool2o`00087ooooo0_l0002`ooooo`;o00004oooool0
01kooooo00?o0000ooooooooool0IOooool2o`000>3ooooo000Nooooo`03o`000?oooooooooo04oo
oooo0ol0000:ooooo`;o00001oooool2o`0002oooooo0_l0002_ooooo`007_ooool00ol0003ooooo
ooooo`1?ooooo`?o00002_ooool2o`0000[ooooo0_l0000>ooooo`;o00007?ooool2o`000:oooooo
000Nooooo`03o`000?oooooooooo05cooooo0_l0000:ooooo`;o00003_ooool2o`0006Wooooo0_l0
001Cooooo`;o00003Oooool001kooooo00?o0000ooooooooool0;oooool2o`0001;ooooo0_l0001B
ooooo`;o00007?ooool2o`0002cooooo0_l0001Cooooo`;o00003Oooool001kooooo00?o0000oooo
ooooool0;oooool2o`0001;ooooo0_l0001Booooo`;o00007?ooool2o`0006Gooooo0_l0000Yoooo
o`007_ooool00ol0003oooooooooo`2Vooooo`;o0000G_ooool2o`0001Cooooo0_l0000Yooooo`00
7_ooool00ol0003oooooooooo`0oooooo`;o0000IOooool2o`0005kooooo0_l0000?ooooo`;o0000
;_ooool001kooooo00?o0000ooooooooool0?oooool2o`0003;ooooo0_l0002Rooooo`;o0000;_oo
ool001kooooo00?o0000ooooooooool0>_ooool2o`0003Oooooo0_l0000Qooooo`;o0000<oooool2
o`0007[ooooo000Nooooo`03o`000?oooooooooo03[ooooo0_l0001Jooooo`;o0000<oooool2o`00
06?ooooo0_l0000Eooooo`007_ooool00ol0003oooooooooo`1looooo`;o00007_ooool2o`00063o
oooo0_l0000`ooooo`;o00005Oooool001kooooo00?o0000ooooooooool0O?ooool2o`0000Cooooo
0_l0000Hooooo`;o00009oooool2o`0003Oooooo0_l0000aooooo`;o00005?ooool001kooooo00?o
0000ooooooooool0HOooool2o`0000;ooooo0_l0000Kooooo`;o0000=?ooool2o`0000_ooooo0_l0
000/ooooo`;o0000=_ooool2o`0000Cooooo0_l0000Dooooo`007_ooool00ol0003oooooooooo`02
o`0001;ooooo0_l0000Kooooo`;o0000;_ooool2o`0000;ooooo0_l0001Aooooo`;o0000>Oooool2
o`0002Gooooo0_l0000?ooooo`;o00006_ooool001kooooo0_l000000ooooooo0000o`000003oooo
o`;o00003Oooool2o`0001_ooooo0_l0000Aooooo`;o0000=oooool2o`0001Oooooo0_l0000Ooooo
o`;o0000EOooool2o`0000[ooooo0_l0000[ooooo`007_ooool00ol0003oooooooooo`02ooooo`;o
000000?oooooo`000?l00000?Oooool2o`0003Oooooo0_l0000Gooooo`;o00007oooool2o`0005Go
oooo0_l0000gooooo`007_ooool00ol0003oooooooooo`02ooooo`;o0000C?ooool2o`00017ooooo
0_l0001fooooo`;o0000<Oooool2o`0003Oooooo000Nooooo`03o`000?oooooooooo037ooooo0_l0
000Mooooo`;o00004Oooool2o`0007Kooooo0_l0000aooooo`;o00005_ooool2o`0001oooooo000N
ooooo`03o`000?oooooooooo00;ooooo0_l0000:ooooo`;o00008Oooool2o`0000?ooooo0_l0003^
ooooo`;o00007oooool001kooooo00?o0000ooooooooool00_ooool2o`0000[ooooo0_l0000Voooo
o`;o00005?ooool2o`000:_ooooo0_l0000jooooo`;o00004?ooool001kooooo00?o0000oooooooo
ool0C?ooool2o`000:_ooooo0_l0000`ooooo`;o00002?ooool2o`00013ooooo000Nooooo`03o`00
0?oooooooooo0?oooooo7Oooool2o`0000gooooo0_l0000Cooooo`;o00001Oooool001kooooo00?o
0000ooooooooool0oooooolMooooo`;o00008_ooool2o`0000Gooooo000Nooooo`03o`000?oooooo
oooo03kooooo0_l0000looooo`;o00008oooool2o`0004Wooooo0_l0001Iooooo`007_ooool00ol0
003oooooooooo`0nooooo`;o0000:oooool2o`0000oooooo0_l0000Sooooo`;o0000BOooool2o`00
04;ooooo0_l0000Eooooo`007_ooool00ol0003oooooooooo`03ooooo`?o0000IOooool2o`00027o
oooo0_l0001Vooooo`;o0000>?ooool2o`0001Gooooo000Nooooo`03o`000?oooooooooo00?ooooo
0ol0001]ooooo`;o00006Oooool2o`0006Kooooo0_l0001?ooooo`007_ooool00ol0003ooooooooo
o`0Fooooo`;o0000Foooool2o`0001Cooooo0_l0000jooooo`;o00009Oooool2o`0001oooooo0_l0
0005ooooo`;o0000<Oooool001kooooo00?o0000ooooooooool05_ooool2o`00077ooooo0_l0000a
ooooo`;o00001oooool2o`0002Gooooo0_l0000Oooooo`;o00001Oooool2o`00037ooooo000Noooo
o`03o`000?oooooooooo0;cooooo0_l00029ooooo`007_ooool2o`00077ooooo0_l00030ooooo`;o
00004oooool001kooooo00?o0000ooooooooool0=_ooool2o`0001_ooooo0_l0000Kooooo`;o0000
1Oooool2o`0000;ooooo0_l0000Dooooo`;o0000Woooool2o`0001?ooooo000Nooooo`03o`000?oo
oooooooo03Kooooo0_l0000Kooooo`;o00008_ooool2o`0000;ooooo0_l0000Dooooo`;o0000]?oo
ool001kooooo00?o0000ooooooooool0i_ooool2o`0003oooooo0_l0000Nooooo`007_ooool00ol0
003oooooooooo`02o`0001oooooo0_l00033ooooo`Co0000?Oooool2o`0001kooooo000Nooooo`03
o`000?oooooooooo00;o00007oooool2o`0000_ooooo0_l0000gooooo`;o0000:_ooool2o`0001Go
oooo0_l0000looooo`;o00003_ooool2o`0004gooooo000Nooooo`03o`000?oooooooooo02;ooooo
0_l0000:ooooo`;o000000?oooooo`000?l00000=?ooool2o`00017ooooo0_l0000Gooooo`;o0000
5Oooool2o`0004Cooooo0_l00006ooooo`;o0000@_ooool2o`0000Wooooo000Nooooo`03o`000?oo
oooooooo02;ooooo1?l0000;ooooo`;o0000Aoooool2o`0007Cooooo0_l0001:ooooo`;o00002Ooo
ool001kooooo00?o0000ooooooooool09?ooool2o`00013ooooo0_l00016ooooo`;o0000R_ooool2
o`0003_ooooo000Nooooo`03o`000?oooooooooo03Kooooo0_l0000Uooooo`;o00002_ooool2o`00
01?ooooo0_l0000Xooooo`;o0000H?ooool2o`0003_ooooo000Nooooo`03o`000?oooooooooo00go
oooo0_l0001>ooooo`;o00002_ooool2o`0001Cooooo0_l0000Wooooo`?o0000Doooool2o`0004Oo
oooo000Nooooo`03o`000?oooooooooo00gooooo0_l0001`ooooo`;o0000:?ooool2o`0005?ooooo
0_l0000looooo`;o00002Oooool001kooooo00?o0000ooooooooool0;_ooool2o`0006;ooooo0_l0
000oooooo`;o00008_ooool2o`0004?ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`03
ooooo`;o00007?ooool2o`0000_ooooo0_l0001Rooooo`;o0000>Oooool2o`0000Cooooo0_l0000<
ooooo`;o00004_ooool4o`0000gooooo0_l0000oooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool01?l0003oooooo`00
0?l00002ooooo`;o00007?ooool2o`0002[ooooo0_l0001Booooo`;o0000:Oooool3o`0001;ooooo
0_l0000:ooooo`;o00001_ooool2o`0000oooooo0_l0000oooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool01?l0003o
ooooo`000?l0001<ooooo`;o0000D?ooool4o`0002Wooooo0_l0000Dooooo`;o00002Oooool2o`00
02kooooo0_l0000Eooooo`;o00004Oooool000?ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000001_ooool3o`0004Gooooo0_l0001Hooooo`;o0000<oooool2
o`0000cooooo0_l0000iooooo`;o00001?ooool2o`0000oooooo0_l0000Aooooo`000oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`04o`000?oo
oooo0000o`0001oooooo0_l0000Sooooo`;o00005?ooool2o`0004Gooooo0_l0000`ooooo`;o0000
5Oooool2o`000003ooooool0003o000003?ooooo0_l0000Rooooo`000oooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`04o`000?oooooo0000o`00
01oooooo0_l0000iooooo`;o0000AOooool2o`0004Oooooo0_l000000ooooooo0000o`00000Joooo
o`;o00005Oooool2o`0000Kooooo0_l0000Looooo`000oooool01Ol@413ooooooooooooooooo410@
00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`0Oooooo`;o0000:?ooool2o`00
0:Kooooo0_l0000Gooooo`;o00005Oooool2o`0000Kooooo0_l0000Looooo`000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0Ooooo
o`;o0000:?ooool2o`0001Cooooo0_l0002@ooooo`;o00005Oooool2o`0003gooooo0003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooo
oooo01Sooooo0_l00005ooooo`;o0000?_ooool2o`0001;ooooo0_l0002>ooooo`;o00000oooool2
o`0003gooooo000Nooooo`03o`000?oooooooooo01Sooooo0_l0001Iooooo`;o0000??ooool2o`00
03gooooo0_l0000Aooooo`;o0000@_ooool001kooooo00?o0000ooooooooool0/Oooool2o`0003go
oooo0_l0000Pooooo`;o0000<oooool001kooooo00?o0000ooooooooool0FOooool2o`000;Oooooo
0_l0000cooooo`007_ooool00ol0003oooooooooo`0Wooooo`;o0000<?ooool2o`0009Sooooo0_l0
000;ooooo`;o0000=Oooool2o`0000kooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l0001_
ooooo`;o0000=oooool2o`00013ooooo0_l0000>ooooo`;o00002oooool2o`0003Gooooo0_l0000>
ooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o0000Q_ooool2o`0003Oooooo0_l0000@oooo
o`;o0000H_ooool001kooooo00?o0000ooooooooool04?ooool2o`0008Gooooo0_l0002^ooooo`00
7_ooool00ol0003oooooooooo`1Uooooo`;o0000<?ooool2o`000:kooooo000Nooooo`03o`000?oo
oooooooo06Gooooo0_l0002?ooooo`;o0000Coooool001kooooo00?o0000ooooooooool0HOooool2
o`0007Cooooo0_l00002ooooo`;o00001Oooool2o`0001;ooooo0_l0001?ooooo`007_ooool00ol0
003oooooooooo`1<ooooo`;o00004oooool2o`0007Cooooo0_l00002ooooo`;o00001Oooool2o`00
06?ooooo000Nooooo`;o00007_ooool2o`0001Sooooo0_l0000Cooooo`;o0000Boooool2o`0002Co
oooo0_l0000Oooooo`;o00005_ooool2o`0004gooooo000Nooooo`03o`000?oooooooooo01gooooo
0_l0000Hooooo`;o00000_ooool2o`0001?ooooo0_l00017ooooo`;o00009?ooool2o`0001oooooo
0_l0000Fooooo`;o00008?ooool2o`0002_ooooo000Nooooo`03o`000?oooooooooo03_ooooo0_l0
000Cooooo`;o00000_ooool2o`0009Cooooo0_l0000^ooooo`;o0000:oooool001kooooo00?o0000
ooooooooool09_ooool2o`0002Sooooo0_l00002ooooo`;o0000>_ooool2o`0005Sooooo0_l00017
ooooo`;o00004_ooool001kooooo00?o0000ooooooooool09_ooool2o`0002Sooooo0_l0000noooo
o`;o0000IOooool2o`0003[ooooo0_l0000Booooo`007_ooool00ol0003oooooooooo`1[ooooo`;o
0000R_ooool2o`0004Gooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`1Jooooo`;o0000
3oooool4o`0003cooooo0_l0002Aooooo`;o00001oooool001kooooo00?o0000ooooooooool0F_oo
ool2o`00013ooooo0ol0000looooo`;o0000S_ooool2o`0000[ooooo000Nooooo`03o`000?oooooo
oooo03?ooooo0_l00009ooooo`;o00004_ooool5o`000>Cooooo0_l0000:ooooo`007_ooool00ol0
003oooooooooo`0cooooo`;o00002Oooool2o`0001;ooooo1Ol0003`ooooo`007_ooool00ol0003o
ooooooooo`3Iooooo`;o00007_ooool2o`0004cooooo000Nooooo`03o`000?oooooooooo00Kooooo
0_l0002;ooooo`;o0000A?ooool2o`0001kooooo0_l0000Jooooo`;o0000<?ooool001kooooo00?o
0000ooooooooool01_ooool2o`0008_ooooo0_l00020ooooo`;o00004?ooool2o`0001kooooo000N
ooooo`03o`000?oooooooooo08[ooooo0_l0000Iooooo`;o00004Oooool2o`0004Sooooo0_l0000I
ooooo`;o00002?ooool2o`0001kooooo000Nooooo`03o`000?oooooooooo00kooooo0_l0000Voooo
o`;o0000D_ooool2o`0001Wooooo0_l0000Aooooo`;o0000;oooool2o`0000cooooo0_l00009oooo
o`;o00006Oooool2o`0002Sooooo000Nooooo`03o`000?oooooooooo00kooooo0_l0000Vooooo`;o
0000H?ooool2o`0001kooooo0_l0000_ooooo`;o00003?ooool2o`0004kooooo000Nooooo`;o0000
VOooool2o`000:gooooo000Nooooo`03o`000?oooooooooo04Kooooo0_l0003oooooo`007_ooool0
0ol0003oooooooooo`16ooooo`;o00007Oooool2o`00037ooooo0_l0001Gooooo`;o00002oooool2
o`0004Oooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l0000Rooooo`;o0000;?ooool2o`00
00Gooooo0_l00004ooooo`;o0000<Oooool2o`0000gooooo0_l0000Sooooo`;o00008oooool2o`00
00_ooooo0_l00007ooooo`;o0000?_ooool001kooooo00?o0000ooooooooool01_ooool2o`0002;o
oooo0_l0000Yooooo`;o000000?oooooo`000?l000001Oooool2o`0004Kooooo0_l0000Sooooo`;o
0000>Oooool2o`0003kooooo000Nooooo`03o`000?oooooooooo05Gooooo0_l0001/ooooo`;o0000
K?ooool2o`0001Cooooo000Nooooo`03o`000?oooooooooo063ooooo0_l0001;ooooo`;o00005?oo
ool2o`0001Wooooo0_l0000Zooooo`;o00006oooool2o`0000Sooooo0_l0000Dooooo`007_ooool0
0ol0003oooooooooo`1Jooooo`;o00001?ooool2o`0004_ooooo0_l0000_ooooo`;o0000:_ooool2
o`0001_ooooo0_l0000Nooooo`007_ooool00ol0003oooooooooo`1Jooooo`;o0000?_ooool2o`00
05Wooooo0_l0001@ooooo`007_ooool00ol0003oooooooooo`1Rooooo`;o00006oooool2o`0000ko
oooo0_l00009ooooo`;o0000FOooool2o`00053ooooo000Nooooo`03o`000?oooooooooo06;ooooo
0_l0000Kooooo`;o00003_ooool2o`000;Kooooo000Nooooo`03o`000?oooooooooo00oooooo0_l0
001Aooooo`;o00007?ooool2o`0003;ooooo0_l0000Zooooo`;o0000IOooool001kooooo00?o0000
ooooooooool03oooool2o`0000Sooooo0_l0001Uooooo`;o0000<_ooool2o`0002?ooooo0_l00005
ooooo`;o0000IOooool001kooooo00?o0000ooooooooool00_ooool2o`0000Sooooo0_l0000;oooo
o`;o00002_ooool2o`0007?ooooo0ol0000]ooooo`;o00003Oooool2o`0006cooooo000Nooooo`03
o`000?oooooooooo00;ooooo0_l00008ooooo`;o00005oooool2o`0007?ooooo0ol0000]ooooo`;o
0000<?ooool2o`0004Wooooo000Nooooo`03o`000?oooooooooo02Gooooo0_l0000Fooooo`;o0000
NOooool2o`0001[ooooo0_l0000Vooooo`;o0000BOooool001kooooo0_l0000nooooo`;o0000?ooo
ool2o`0001[ooooo0_l0000:ooooo`;o00002oooool2o`0000?ooooo0_l0000Jooooo`;o00005_oo
ool2o`0004Wooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`07ooooo`;o0000MOooool2
o`0000gooooo0_l00006ooooo`;o00000oooool2o`0000[ooooo0_l0000;ooooo`;o00004oooool2
o`0002;ooooo0_l00019ooooo`;o00003_ooool001kooooo00?o0000ooooooooool01oooool2o`00
04gooooo0_l0000eooooo`;o00001_ooool2o`00037ooooo0_l0000Yooooo`;o00003_ooool2o`00
04;ooooo000Nooooo`03o`000?oooooooooo05Kooooo0_l0001Booooo`;o0000Aoooool2o`000003
ooooool0003o000000_ooooo0_l00012ooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o0000
S_ooool2o`0004[ooooo0_l00009ooooo`;o0000A?ooool001kooooo00?o0000ooooooooool06_oo
ool2o`0009;ooooo0_l0000=ooooo`;o0000@_ooool2o`0001gooooo0_l0000Uooooo`007_ooool0
0ol0003oooooooooo`0Zooooo`;o0000E_ooool2o`0002[ooooo0_l00002ooooo`;o00002Oooool2
o`00067ooooo0_l0000Booooo`;o00004Oooool001kooooo00?o0000ooooooooool08Oooool2o`00
00Oooooo0_l0000Dooooo`;o00000_ooool2o`0003cooooo0_l0000^ooooo`;o0000P?ooool2o`00
017ooooo000Nooooo`03o`000?oooooooooo027ooooo0_l0000Mooooo`;o00000_ooool2o`0002go
oooo0_l0000kooooo`;o00009oooool2o`0001oooooo0_l0001;ooooo`007_ooool00ol0003ooooo
ooooo`1cooooo`;o00003?ooool2o`0002;ooooo0_l00009ooooo`;o00009oooool2o`00013ooooo
0_l00002ooooo`;o00002Oooool2o`0001Kooooo0_l00006ooooo`;o0000:oooool001kooooo00?o
0000ooooooooool0>oooool2o`0000Kooooo0_l0000looooo`;o00000oooool2o`0000_ooooo0_l0
000@ooooo`;o00004Oooool2o`0002gooooo0_l00002ooooo`;o00000_ooool2o`00027ooooo0_l0
0005ooooo`?o0000:oooool001kooooo00?o0000ooooooooool0>oooool2o`0000Kooooo0_l00005
ooooo`;o00002?ooool3o`0002Oooooo0_l00006ooooo`;o00002oooool2o`0002?ooooo0_l00008
ooooo`;o000000?oooooo`000?l000001Oooool2o`0001Wooooo0_l0000>ooooo`;o00008?ooool2
o`0002cooooo000Nooooo`03o`000?oooooooooo04[ooooo0_l00008ooooo`?o00009oooool2o`00
04;ooooo0_l000000ooooooo0000o`000005ooooo`;o00009?ooool2o`0000?ooooo0_l0000Boooo
o`;o0000>_ooool001kooooo00?o0000ooooooooool09Oooool2o`000<_ooooo0_l0000Gooooo`;o
0000>_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co
8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool09Oooool2o`0000Kooooo0_l0000Hoooo
o`;o0000@_ooool2o`0002?ooooo0_l0000Tooooo`;o0000<oooool2o`0003[ooooo0003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06
ooooo`03o`000?oooooooooo02gooooo0_l0000Hooooo`;o0000@_ooool2o`0002?ooooo0_l0000T
ooooo`;o0000<?ooool2o`000003ooooool0003o000003?ooooo0_l00005ooooo`000oooool01Ol@
413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`Go00000_oo
ool2o`0001Sooooo0_l0003;ooooo`;o00002oooool2o`0000gooooo0ol0000Aooooo`;o00006ooo
ool2o`0000Gooooo0ol00005ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go
<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooooooo00;o00000_ooool4o`0001Kooooo
0_l0000Pooooo`;o0000ZOooool2o`0000_ooooo0_l0000:ooooo`;o000000?oooooo`000?l00000
2_ooool2o`0000Kooooo0_l0000Kooooo`;o00001Oooool2o`0000Kooooo0003ooooo`05o`000?oo
ooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000oooooooo
ool01_ooool2o`0003Sooooo0_l0000Iooooo`;o0000FOooool2o`0004cooooo0_l00009ooooo`;o
00000_ooool2o`0002Cooooo0_l0000<ooooo`000oooool01Ol@413ooooooooooooooooo410@00_o
oooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo05_ooooo0_l0001Ioooo
o`;o00007?ooool2o`0003Wooooo0_l00005ooooo`;o00008Oooool2o`0000Gooooo0_l00005oooo
o`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006
ooooo`03o`000?oooooooooo02Sooooo0_l0002Zooooo`;o00002_ooool2o`0003Cooooo0_l0000X
ooooo`;o00001Oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o
0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`0Tooooo`;o00000_ooool2o`0008Cooooo0_l0
000Mooooo`;o00004Oooool2o`0006Gooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l0001_
ooooo`;o00005oooool2o`0001gooooo0_l00004ooooo`;o0000L_ooool001kooooo00?o0000oooo
ooooool0UOooool2o`0003cooooo0_l0000?ooooo`;o0000HOooool001kooooo00?o0000oooooooo
ool03oooool2o`0002_ooooo0_l0000Vooooo`;o00009?ooool2o`0005Sooooo0_l00016ooooo`;o
00006Oooool001kooooo00?o0000ooooooooool03oooool2o`0002_ooooo0_l0000Vooooo`;o0000
9?ooool2o`000:3ooooo0_l0000Iooooo`007_ooool00ol0003oooooooooo`0gooooo`;o0000a_oo
ool2o`0004Kooooo000Nooooo`03o`000?oooooooooo03Oooooo0_l0001Zooooo`;o0000F_ooool2
o`0000[ooooo0_l0000jooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o00006Oooool2o`00
05cooooo0_l0000Aooooo`;o00002?ooool2o`0005cooooo0_l0000jooooo`007_ooool00ol0003o
ooooooooo`0Gooooo`;o00006?ooool3o`0001?ooooo0_l00017ooooo`;o00006oooool2o`0003Ko
oooo0_l0000Mooooo`;o0000@Oooool001kooooo00?o0000ooooooooool0<Oooool2o`0001Cooooo
0_l0002Looooo`;o00007Oooool2o`00047ooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0
0002ooooo`;o0000;oooool2o`000?3ooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`0B
ooooo`;o00000_ooool2o`000<Oooooo0_l0001Hooooo`;o000000?oooooo`000?l000002Oooool0
01kooooo0_l00010ooooo`;o0000W_ooool2o`00027ooooo0_l0000hooooo`;o00002Oooool001ko
oooo00?o0000ooooooooool0?oooool2o`0008Oooooo0_l0000hooooo`;o0000@oooool001kooooo
00?o0000ooooooooool0:oooool2o`0007Oooooo0_l0000Iooooo`;o00001oooool2o`0007Gooooo
0_l00006ooooo`007_ooool00ol0003oooooooooo`0[ooooo`;o0000Moooool2o`0001Wooooo0_l0
001nooooo`;o00001_ooool001kooooo00?o0000ooooooooool0:?ooool2o`000>3ooooo0_l0000H
ooooo`;o00008Oooool001kooooo00?o0000ooooooooool0:?ooool2o`0003;ooooo0_l00026oooo
o`;o00009?ooool2o`0001Sooooo0_l0000Qooooo`007_ooool00ol0003oooooooooo`1Looooo`;o
00006?ooool2o`0002cooooo0_l0000kooooo`Go0000HOooool001kooooo00?o0000ooooooooool0
M_ooool2o`0002cooooo0_l0000_ooooo`;o00002_ooool3o`0006?ooooo000Nooooo`03o`000?oo
oooooooo02Wooooo0_l0002Zooooo`;o00006_ooool2o`0000Wooooo0_l00019ooooo`007_ooool0
0ol0003oooooooooo`0Yooooo`;o00001_ooool2o`00023ooooo0_l0000Fooooo`;o0000J?ooool2
o`0001[ooooo0_l00009ooooo`;o00000oooool2o`0002;ooooo0_l0000Pooooo`007_ooool00ol0
003oooooooooo`0aooooo`;o00008?ooool2o`0001Kooooo0_l0002Dooooo`;o00003_ooool2o`00
01;ooooo0_l0000Pooooo`007_ooool00ol0003oooooooooo`02o`0001gooooo0_l0001:ooooo`;o
0000:oooool2o`0007Oooooo0_l0000=ooooo`;o00000oooool2o`00023ooooo000Nooooo`03o`00
0?oooooooooo00;o00007Oooool3o`0007Kooooo0_l0000gooooo`;o00004oooool2o`0001Oooooo
0_l00006ooooo`;o00005oooool2o`0000?ooooo0_l0000Pooooo`007_ooool00ol0003ooooooooo
o`02ooooo`;o00004oooool2o`0000Oooooo0_l0002_ooooo`;o00002oooool2o`0000Kooooo0_l0
0007ooooo`;o00003_ooool2o`0000Kooooo0_l0000Hooooo`;o00009?ooool001kooooo00?o0000
ooooooooool00_ooool2o`0000[ooooo0_l00007ooooo`;o00001Oooool2o`000;kooooo0_l0000?
ooooo`;o0000<?ooool2o`0002Cooooo000Nooooo`03o`000?oooooooooo00kooooo0_l0000>oooo
o`;o00003oooool2o`0004oooooo0_l00035ooooo`007_ooool2o`0002?ooooo0_l0000;ooooo`;o
0000Coooool2o`0002kooooo0_l0000Mooooo`;o0000HOooool2o`0001?ooooo000Nooooo`;o0000
4Oooool2o`00013ooooo0_l0000Cooooo`;o0000<?ooool2o`0004Gooooo0_l0000Mooooo`;o0000
HOooool2o`0001?ooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0000;ooooo`;o00009Ooo
ool2o`00033ooooo0_l00007ooooo`;o0000Xoooool2o`0000Cooooo0_l0000Xooooo`007_ooool0
0ol0003oooooooooo`03ooooo`;o0000KOooool2o`0006[ooooo0_l0000Booooo`;o00008oooool2
o`0000Cooooo0_l0000Xooooo`007_ooool00ol0003oooooooooo`2Gooooo`;o0000@_ooool2o`00
0003ooooool0003o000001;ooooo0_l0000looooo`;o00005Oooool001kooooo00?o0000oooooooo
ool0Uoooool2o`0000[ooooo0_l0000Aooooo`;o00008_ooool3o`0002;ooooo0_l0000Yooooo`;o
00001?ooool2o`0001Gooooo000Nooooo`03o`000?oooooooooo01oooooo0_l0001Mooooo`;o0000
8oooool2o`00017ooooo0_l0000Rooooo`;o00008oooool2o`0000cooooo0_l0000Kooooo`;o0000
6oooool001kooooo00?o0000ooooooooool07oooool2o`0005gooooo0_l0000Nooooo`;o0000;ooo
ool2o`0003cooooo0_l0000hooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o0000SOooool2
o`0002oooooo0_l00011ooooo`;o00002oooool2o`0002Kooooo000Nooooo`03o`000?oooooooooo
00oooooo0_l0001Wooooo`;o00005_ooool2o`00067ooooo0_l0000Mooooo`;o00002oooool2o`00
00Kooooo0_l0000Nooooo`007_ooool00ol0003oooooooooo`1hooooo`;o00005?ooool4o`0001Co
oooo0_l0000Sooooo`;o00009_ooool2o`0003;ooooo0_l000000ooooooo0000o`00000Kooooo`00
7_ooool00ol0003oooooooooo`0Nooooo`;o0000@_ooool2o`0002[ooooo0_l0000Fooooo`;o0000
8oooool2o`0005gooooo0_l0000Kooooo`007Oooool2o`00023ooooo0_l00012ooooo`;o0000@Ooo
ool2o`0000Kooooo0_l0000=ooooo`;o0000;?ooool2o`0005_ooooo000Mooooo`;o0000:_ooool2
o`0005Wooooo0_l0000Booooo`;o00003?ooool2o`0000Kooooo0_l00004ooooo`;o00001oooool2
o`0002cooooo0_l0001>ooooo`;o00002oooool001kooooo00?o0000ooooooooool08Oooool2o`00
00Gooooo0_l0000Qooooo`;o0000=_ooool2o`0000?ooooo0_l0000=ooooo`;o00006_ooool2o`00
08Gooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o00004_ooool2o`0002So
oooo1?l0000iooooo`;o00008oooool2o`00047ooooo0_l0000gooooo`;o00007?ooool001kooooo
0_l0000<ooooo`Co0000?_ooool2o`0000;ooooo0_l0000Dooooo`;o0000A?ooool2o`0002Kooooo
0_l0000Iooooo`;o0000;?ooool2o`0000Wooooo0_l0000Looooo`007_ooool00ol0003ooooooooo
o`0;ooooo`;o00009Oooool2o`0001Wooooo0_l00002ooooo`;o00005?ooool2o`0006cooooo0_l0
0017ooooo`;o00009oooool001kooooo00?o0000ooooooooool05Oooool2o`0001_ooooo0_l0000C
ooooo`;o00001?ooool2o`0001Oooooo0_l0003Oooooo`007_ooool00ol0003oooooooooo`0Eoooo
o`;o0000<?ooool2o`0001gooooo0_l0002=ooooo`;o0000D?ooool001kooooo00?o0000oooooooo
ool0;?ooool2o`0008_ooooo0_l0000jooooo`;o00001Oooool2o`0003Cooooo0_l0000Cooooo`00
7_ooool00ol0003oooooooooo`0/ooooo`;o0000Roooool2o`0002gooooo0_l0000Booooo`;o0000
=?ooool2o`0001?ooooo000Nooooo`03o`000?oooooooooo03Kooooo0_l0002=ooooo`;o00008Ooo
ool2o`0005gooooo000Nooooo`03o`000?oooooooooo03Kooooo0_l0001Qooooo`;o00003Oooool2
o`0001_ooooo0_l00007ooooo`;o00004Oooool2o`00013ooooo0_l0000=ooooo`;o0000@oooool0
01kooooo00?o0000ooooooooool0E?ooool2o`0002cooooo0_l000000ooooooo0000o`00000Boooo
o`;o00003Oooool2o`0002Cooooo0_l0000Aooooo`;o00004?ooool3o`0000cooooo0_l0000Moooo
o`;o00009?ooool001kooooo00?o0000ooooooooool0;Oooool2o`0002Gooooo0_l0000/ooooo`;o
000000?oooooo`000?l000000_l0001[ooooo`;o0000:oooool2o`0002Cooooo000Nooooo`03o`00
0?oooooooooo02gooooo0_l0000Tooooo`;o00003oooool2o`00017ooooo0_l0000>ooooo`;o0000
Ioooool2o`0005Gooooo000Nooooo`03o`000?oooooooooo05?ooooo1?l0000=ooooo`;o00004?oo
ool3o`0007Oooooo0_l0001Eooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o00009_ooool2
o`00017ooooo0ol00009ooooo`;o00007oooool2o`0002Kooooo0_l00004ooooo`;o0000<oooool2
o`0005;ooooo0_l0000Hooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o00009_ooool2o`00
017ooooo0ol0001Booooo`;o00001?ooool2o`00013ooooo0_l0000:ooooo`;o00005Oooool2o`00
047ooooo0_l0000?ooooo`;o00006?ooool001Cooooo1?l000000ol@413oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo0_l0000booooo`;o0000O_ooool2o`0000[ooooo0_l0001Hooooo`;o
0000:Oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o0000
<_ooool2o`0000cooooo0_l0002;ooooo`;o0000G?ooool2o`0000;ooooo0_l0000Booooo`005_oo
ool00ol0003oooooooooo`05ooooo`?o0000A?ooool2o`0008_ooooo0_l0000Eooooo`;o00000_oo
ool2o`00047ooooo0_l00002ooooo`;o00004_ooool001Kooooo00?o0000ooooooooool0l?ooool2
o`0000;ooooo0_l0001Iooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03
o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005?oo
ool00omEEEGoIVIVo`00003ooooooe;ooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.80555 .73991 Mdot
.88099 .2563 Mdot
.56186 .35974 Mdot
.90126 .2721 Mdot
.37625 .60545 Mdot
.34994 .07036 Mdot
.79701 .91588 Mdot
.03998 .18079 Mdot
.7144 .58715 Mdot
.73743 .97723 Mdot
.49068 .64108 Mdot
.71593 .88042 Mdot
.71441 .89916 Mdot
.92332 .57426 Mdot
.09984 .5318 Mdot
.01811 .26998 Mdot
.74496 .02024 Mdot
.64784 .14573 Mdot
.10537 .06152 Mdot
.46983 .05016 Mdot
.23773 .44558 Mdot
.69714 .1473 Mdot
.74873 .70829 Mdot
.86226 .24579 Mdot
.18659 .77938 Mdot
.79807 .77786 Mdot
.93656 .2712 Mdot
.86924 .4672 Mdot
.20042 .19695 Mdot
.22696 .43674 Mdot
.21513 .32895 Mdot
.71494 .45842 Mdot
.84325 .76595 Mdot
.06138 .24403 Mdot
.11585 .01787 Mdot
.27335 .97389 Mdot
.95486 .42082 Mdot
.33862 .15715 Mdot
.90154 .05682 Mdot
.41527 .70379 Mdot
.71281 .8339 Mdot
.13251 .37165 Mdot
.50417 .63808 Mdot
.42774 .85049 Mdot
.53556 .77462 Mdot
.28892 .66791 Mdot
.47761 .68179 Mdot
.09186 .59714 Mdot
.63481 .4246 Mdot
.65812 .42705 Mdot
.60338 .30187 Mdot
.23555 .74217 Mdot
.97379 .43305 Mdot
.16402 .38089 Mdot
.48377 .83728 Mdot
.72598 .55954 Mdot
.06268 .06361 Mdot
.43397 .92052 Mdot
.53368 .2827 Mdot
.38011 .24454 Mdot
.90964 .996 Mdot
.59467 .92815 Mdot
.23614 .6256 Mdot
.26265 .16706 Mdot
.28902 .24823 Mdot
.14464 .87374 Mdot
.69015 .2934 Mdot
.4668 .31846 Mdot
.72345 .40838 Mdot
.98535 .33762 Mdot
.18899 .03456 Mdot
.63545 .04409 Mdot
.08163 .21784 Mdot
.99861 .30231 Mdot
.9635 .56266 Mdot
.62869 .05433 Mdot
.64209 .2205 Mdot
.48323 .13534 Mdot
.00419 .94968 Mdot
.9984 .82018 Mdot
.34417 .52571 Mdot
.00271 .55817 Mdot
.24379 .53241 Mdot
.34212 .35127 Mdot
.10555 .34913 Mdot
.34426 .26535 Mdot
.10657 .79788 Mdot
.61946 .12585 Mdot
.40292 .57094 Mdot
.19294 .93154 Mdot
.38275 .58825 Mdot
.15539 .06587 Mdot
.99337 .21595 Mdot
.21179 .55895 Mdot
.77608 .66137 Mdot
.89361 .20382 Mdot
.70049 .30883 Mdot
.57272 .97103 Mdot
.64606 .47504 Mdot
.73499 .79181 Mdot
.18553 .81198 Mdot
.6679 .80076 Mdot
.80369 .14817 Mdot
.48233 .70231 Mdot
.87035 .16355 Mdot
.26642 .14262 Mdot
.04275 .53621 Mdot
.43989 .9451 Mdot
.2575 .29789 Mdot
.87542 .0169 Mdot
.6019 .80044 Mdot
.17426 .24122 Mdot
.37249 .02779 Mdot
.50574 .38317 Mdot
.6851 .79379 Mdot
.07254 .79732 Mdot
.84928 .61243 Mdot
.78402 .66026 Mdot
.83144 .16861 Mdot
.29214 .78431 Mdot
.61727 .81952 Mdot
.49742 .70786 Mdot
.95754 .94045 Mdot
.33581 .4353 Mdot
.58864 .91194 Mdot
.79224 .11938 Mdot
.07501 .24527 Mdot
.82164 .23213 Mdot
.2253 .66494 Mdot
.94576 .61426 Mdot
.34033 .58003 Mdot
.74836 .92061 Mdot
.92927 .75755 Mdot
.20648 .19857 Mdot
.92949 .78921 Mdot
.99266 .70949 Mdot
.31207 .72162 Mdot
.05174 .67224 Mdot
.27684 .45578 Mdot
.38263 .39641 Mdot
.02062 .76542 Mdot
.37811 .72143 Mdot
.66816 .26324 Mdot
.73732 .81101 Mdot
.76972 .55106 Mdot
.45772 .55609 Mdot
.87624 .8289 Mdot
.44589 .96098 Mdot
.54464 .10109 Mdot
.334 .24003 Mdot
.17993 .5129 Mdot
.97409 .97865 Mdot
.23215 .68505 Mdot
.64994 .12156 Mdot
.51734 .33079 Mdot
.92752 .35327 Mdot
.68667 .84994 Mdot
.54236 .71346 Mdot
.83863 .11869 Mdot
.97781 .78747 Mdot
.31891 .97726 Mdot
.5942 .51554 Mdot
.07645 .58903 Mdot
.77325 .61949 Mdot
.9078 .86293 Mdot
.11547 .4622 Mdot
.43168 .44327 Mdot
.2097 .11109 Mdot
.74587 .59125 Mdot
.82394 .44523 Mdot
.79505 .42687 Mdot
.81196 .72693 Mdot
.49724 .42566 Mdot
.07722 .1447 Mdot
.30342 .85342 Mdot
.26007 .60805 Mdot
.37897 .02185 Mdot
.11837 .13801 Mdot
.80584 .58702 Mdot
.87411 .99091 Mdot
.17394 .92921 Mdot
.94512 .58928 Mdot
.37693 .36448 Mdot
.20557 .8144 Mdot
.89095 .91937 Mdot
.22077 .69383 Mdot
.59322 .12135 Mdot
.86189 .99217 Mdot
.20781 .1016 Mdot
.71017 .95453 Mdot
.37276 .39221 Mdot
.82042 .9129 Mdot
.1753 .48369 Mdot
.63708 .40466 Mdot
.74659 .16993 Mdot
.50665 .52539 Mdot
.99944 .21864 Mdot
.28661 .81548 Mdot
.36083 .07145 Mdot
.51764 .71691 Mdot
.00029 .04469 Mdot
.83876 .83877 Mdot
.63633 .72043 Mdot
.05913 .93232 Mdot
.46936 .09177 Mdot
.45685 .63123 Mdot
.72643 .99478 Mdot
.01157 .02176 Mdot
.86028 .76482 Mdot
.58208 .13354 Mdot
.53776 .6384 Mdot
.07419 .4043 Mdot
.42288 .52174 Mdot
.19177 .50612 Mdot
.86325 .90054 Mdot
.05921 .53767 Mdot
.35217 .74172 Mdot
.66129 .06631 Mdot
.6237 .82282 Mdot
.7075 .97966 Mdot
.89398 .03684 Mdot
.15747 .76507 Mdot
.32763 .41024 Mdot
.16324 .34966 Mdot
.94635 .88945 Mdot
.94335 .80349 Mdot
.13755 .94275 Mdot
.91831 .23898 Mdot
.77165 .09928 Mdot
.15798 .11314 Mdot
.08513 .31904 Mdot
.35872 .30316 Mdot
.10805 .37931 Mdot
.27956 .44996 Mdot
.77175 .99469 Mdot
.20517 .21661 Mdot
.7691 .15135 Mdot
.21851 .3652 Mdot
.68074 .24726 Mdot
.394 .13933 Mdot
.89267 .98631 Mdot
.29135 .97084 Mdot
.80111 .67495 Mdot
.92389 .74848 Mdot
.65531 .17342 Mdot
.54356 .24072 Mdot
.80041 .21974 Mdot
.41194 .15169 Mdot
.15152 .14165 Mdot
.28601 .71584 Mdot
.36392 .97236 Mdot
.76776 .52817 Mdot
.51729 .9105 Mdot
.62602 .58555 Mdot
.73856 .31084 Mdot
.74544 .78495 Mdot
.14707 .22811 Mdot
.08125 .41003 Mdot
.12091 .01791 Mdot
.5981 .43259 Mdot
.16749 .83045 Mdot
.48735 .71112 Mdot
.86636 .89727 Mdot
.68249 .17644 Mdot
.33017 .94548 Mdot
.17885 .69397 Mdot
.57811 .50379 Mdot
.47478 .90457 Mdot
.54563 .42046 Mdot
.24999 .42475 Mdot
.22174 .39002 Mdot
.6666 .89824 Mdot
.08131 .58753 Mdot
.03002 .2385 Mdot
.34493 .70946 Mdot
.41575 .12855 Mdot
.99109 .74911 Mdot
.29508 .32195 Mdot
.44856 .10424 Mdot
.93266 .57299 Mdot
.98953 .81318 Mdot
.5743 .12782 Mdot
.7112 .27434 Mdot
.96176 .2868 Mdot
.68803 .7773 Mdot
.96512 .0327 Mdot
.5031 .03753 Mdot
.55818 .9111 Mdot
.58375 .31335 Mdot
.24242 .5202 Mdot
.07743 .23689 Mdot
.43681 .06237 Mdot
.08052 .42873 Mdot
.62415 .89234 Mdot
.31056 .07753 Mdot
.75487 .54907 Mdot
.55324 .40816 Mdot
.78995 .56355 Mdot
.17414 .2777 Mdot
.34723 .64543 Mdot
.71709 .89265 Mdot
.16639 .12324 Mdot
.65942 .69885 Mdot
.82639 .05136 Mdot
.48935 .25021 Mdot
.0022 .2144 Mdot
.02997 .08322 Mdot
.27832 .63034 Mdot
.50135 .71859 Mdot
.59014 .08401 Mdot
.39147 .4586 Mdot
.22741 .42206 Mdot
.77788 .64475 Mdot
.06869 .38167 Mdot
.30956 .97641 Mdot
.28285 .31229 Mdot
.8921 .74258 Mdot
.36125 .14116 Mdot
.62795 .72729 Mdot
.02062 .40856 Mdot
.2344 .91976 Mdot
.42546 .42488 Mdot
.86219 .35808 Mdot
.25932 .95066 Mdot
.0066 .84145 Mdot
.18491 .60153 Mdot
.68155 .85219 Mdot
.84417 .2156 Mdot
.94839 .00305 Mdot
.43064 .14007 Mdot
.30622 .46787 Mdot
.51956 .70982 Mdot
.1249 .46383 Mdot
.97853 .28252 Mdot
.29213 .03427 Mdot
.78173 .32286 Mdot
.1 .1822 Mdot
.57227 .74524 Mdot
.41296 .46798 Mdot
.71284 .58368 Mdot
.39449 .34893 Mdot
.21948 .4381 Mdot
.15957 .91689 Mdot
.87041 .84187 Mdot
.01344 .53038 Mdot
.74113 .58328 Mdot
.84519 .39519 Mdot
.10817 .19708 Mdot
.74379 .15548 Mdot
.43035 .46196 Mdot
.37207 .87742 Mdot
.76207 .98926 Mdot
.86466 .57525 Mdot
.4116 .4882 Mdot
.68373 .56084 Mdot
.61944 .66717 Mdot
.55507 .02964 Mdot
.83608 .13318 Mdot
.65323 .66851 Mdot
.92448 .89425 Mdot
.9361 .37246 Mdot
.3076 .43584 Mdot
.66304 .68398 Mdot
.63784 .35437 Mdot
.78143 .12256 Mdot
.20174 .96393 Mdot
.00919 .59349 Mdot
.51184 .14328 Mdot
.50264 .38255 Mdot
.73309 .03488 Mdot
.87928 .70995 Mdot
.95424 .24619 Mdot
.92448 .20424 Mdot
.48492 .90877 Mdot
.23247 .60165 Mdot
.91007 .41829 Mdot
.35195 .49267 Mdot
.72372 .66511 Mdot
.27434 .00921 Mdot
.25144 .31428 Mdot
.63705 .61036 Mdot
.50979 .23546 Mdot
.72304 .87385 Mdot
.64888 .94397 Mdot
.89809 .56416 Mdot
.04769 .13272 Mdot
.62258 .8688 Mdot
.13328 .71696 Mdot
.32196 .32971 Mdot
.42556 .06831 Mdot
.94918 .32749 Mdot
.23432 .72134 Mdot
.25327 .64179 Mdot
.74856 .37005 Mdot
.42681 .91231 Mdot
.14383 .33208 Mdot
.56449 .34466 Mdot
.04688 .25869 Mdot
.8223 .58684 Mdot
.94471 .54538 Mdot
.59528 .21635 Mdot
.31041 .4893 Mdot
.6737 .01459 Mdot
.14221 .72457 Mdot
.30538 .3066 Mdot
.37248 .31425 Mdot
.98956 .38651 Mdot
.34506 .98788 Mdot
.33221 .97829 Mdot
.36413 .64493 Mdot
.46225 .40164 Mdot
.46497 .23123 Mdot
.81334 .13517 Mdot
.04999 .76545 Mdot
.26355 .05834 Mdot
.97521 .07792 Mdot
.86258 .8903 Mdot
.46486 .79224 Mdot
.05486 .43024 Mdot
.16849 .87491 Mdot
.58963 .40504 Mdot
.86722 .16436 Mdot
.21276 .03917 Mdot
.2314 .96475 Mdot
.28491 .9814 Mdot
.15221 .22449 Mdot
.22499 .83744 Mdot
.15585 .29938 Mdot
.28762 .90813 Mdot
.70785 .52513 Mdot
.35172 .49101 Mdot
.5096 .67999 Mdot
.76348 .13137 Mdot
.83777 .47924 Mdot
.44477 .03147 Mdot
.48515 .58564 Mdot
.12875 .17038 Mdot
.31516 .30951 Mdot
.95772 .31322 Mdot
.16884 .0909 Mdot
.56291 .3336 Mdot
.53968 .5425 Mdot
.25876 .79777 Mdot
.00761 .95047 Mdot
.53491 .63388 Mdot
.21045 .45773 Mdot
.03755 .59421 Mdot
.7404 .83851 Mdot
.99795 .47485 Mdot
.2262 .47349 Mdot
.00784 .11141 Mdot
.07482 .47569 Mdot
.55158 .78558 Mdot
.39564 .94784 Mdot
.26127 .97591 Mdot
.44126 .89502 Mdot
.72276 .19233 Mdot
.26964 .57344 Mdot
.62462 .61432 Mdot
.55841 .79866 Mdot
.68008 .24531 Mdot
.23376 .29447 Mdot
.51267 .06327 Mdot
.24266 .79657 Mdot
.03658 .25978 Mdot
.82861 .84372 Mdot
.84579 .22219 Mdot
.41142 .85494 Mdot
.05589 .91007 Mdot
.02233 .36959 Mdot
.45016 .22028 Mdot
.43825 .50392 Mdot
.83538 .14649 Mdot
.13731 .36862 Mdot
.1767 .10395 Mdot
.94977 .59519 Mdot
.10869 .91101 Mdot
.10157 .72855 Mdot
.31583 .64454 Mdot
.80896 .86795 Mdot
.29366 .68733 Mdot
.54721 .48656 Mdot
.91702 .44449 Mdot
.14361 .99377 Mdot
.05696 .39166 Mdot
.02689 .63346 Mdot
.86617 .21209 Mdot
.17904 .08578 Mdot
.78405 .35789 Mdot
.0995 .28107 Mdot
.40379 .62707 Mdot
.28255 .52116 Mdot
.08715 .1244 Mdot
.7662 .04322 Mdot
.3686 .60632 Mdot
.69412 .04802 Mdot
.25595 .345 Mdot
.57921 .42816 Mdot
.47938 .96549 Mdot
.51061 .31155 Mdot
.74698 .77553 Mdot
.50453 .0193 Mdot
.41146 .02627 Mdot
.16696 .49488 Mdot
.27119 .99858 Mdot
.46754 .59838 Mdot
.89433 .38249 Mdot
.83922 .56534 Mdot
.5206 .08395 Mdot
.0924 .09323 Mdot
.12336 .12432 Mdot
.55265 .77731 Mdot
.38713 .35557 Mdot
.13948 .6729 Mdot
.02598 .39377 Mdot
.92413 .1073 Mdot
.74087 .4183 Mdot
.55162 .54754 Mdot
.93553 .93847 Mdot
.75263 .0547 Mdot
.25633 .77103 Mdot
.79166 .87208 Mdot
.2343 .66501 Mdot
.1436 .1043 Mdot
.82583 .36231 Mdot
.08184 .48357 Mdot
.92563 .91642 Mdot
.16581 .41397 Mdot
.13298 .52364 Mdot
.51142 .78428 Mdot
.30954 .70458 Mdot
.78883 .70002 Mdot
.02008 .88817 Mdot
.01767 .68635 Mdot
.79392 .25935 Mdot
.73943 .50077 Mdot
.94349 .95991 Mdot
.69763 .95746 Mdot
.99451 .03321 Mdot
.63467 .77481 Mdot
.712 .50207 Mdot
.89166 .96019 Mdot
.55231 .78691 Mdot
.25187 .27172 Mdot
.53024 .99418 Mdot
.20942 .63844 Mdot
.54956 .73617 Mdot
.4969 .14377 Mdot
.77448 .80398 Mdot
.79231 .05943 Mdot
.73297 .72604 Mdot
.25268 .2247 Mdot
.87949 .31143 Mdot
.2722 .28219 Mdot
.38388 .52747 Mdot
.14955 .96312 Mdot
.86015 .47633 Mdot
.85782 .41705 Mdot
.26535 .86046 Mdot
.43003 .34013 Mdot
.64092 .03992 Mdot
.52585 .18759 Mdot
.83391 .28063 Mdot
.18176 .97855 Mdot
.0262 .0559 Mdot
.82784 .69285 Mdot
.49484 .59865 Mdot
.65587 .70592 Mdot
.6796 .10632 Mdot
.84724 .31201 Mdot
.29473 .20109 Mdot
.52337 .11293 Mdot
.7978 .24471 Mdot
.89589 .8057 Mdot
.97908 .86998 Mdot
.8173 .8144 Mdot
.07863 .88639 Mdot
.75275 .16848 Mdot
.4572 .33513 Mdot
.1225 .38858 Mdot
.73605 .15483 Mdot
.34012 .02178 Mdot
.44961 .90005 Mdot
.64141 .03888 Mdot
.5273 .83968 Mdot
.89017 .22814 Mdot
.61099 .82625 Mdot
.07794 .37933 Mdot
.53976 .05039 Mdot
.1273 .25533 Mdot
.19709 .73174 Mdot
.97827 .77315 Mdot
.3143 .57053 Mdot
.74966 .68462 Mdot
.97569 .51896 Mdot
.09687 .78967 Mdot
.43203 .75949 Mdot
.36062 .55884 Mdot
.75362 .92365 Mdot
.2345 .20714 Mdot
.17625 .82653 Mdot
.0987 .92434 Mdot
.00704 .13282 Mdot
.06939 .13917 Mdot
.7259 .58123 Mdot
.34111 .36034 Mdot
.62349 .98783 Mdot
.23112 .60729 Mdot
.08102 .21084 Mdot
.96179 .16008 Mdot
.51512 .25179 Mdot
.64546 .85498 Mdot
.21145 .26551 Mdot
.52672 .98562 Mdot
.2213 .09952 Mdot
.52315 .85386 Mdot
.65536 .54704 Mdot
.1928 .36529 Mdot
.94312 .64109 Mdot
.05755 .7683 Mdot
.90412 .40071 Mdot
.06955 .62728 Mdot
.4155 .30201 Mdot
.49395 .64143 Mdot
.05143 .98355 Mdot
.89145 .61505 Mdot
.88187 .75386 Mdot
.42778 .82537 Mdot
.24803 .14764 Mdot
.23818 .30199 Mdot
.17015 .58514 Mdot
.21174 .48503 Mdot
.31925 .16946 Mdot
.07874 .93019 Mdot
.93239 .90592 Mdot
.66176 .18582 Mdot
.71301 .98125 Mdot
.7915 .58852 Mdot
.82032 .26792 Mdot
.24989 .85011 Mdot
.61451 .00548 Mdot
.0758 .34953 Mdot
.37552 .35867 Mdot
.69292 .87025 Mdot
.09163 .24517 Mdot
.73379 .90669 Mdot
.20336 .27098 Mdot
.98424 .55956 Mdot
.3471 .28242 Mdot
.27934 .98763 Mdot
.61481 .02064 Mdot
.98984 .19389 Mdot
.93771 .97775 Mdot
.99154 .90836 Mdot
.52017 .58809 Mdot
.11236 .9684 Mdot
.52237 .48082 Mdot
.40788 .0916 Mdot
.27067 .17105 Mdot
.53997 .60671 Mdot
.69852 .00202 Mdot
.12671 .59183 Mdot
.20201 .00512 Mdot
.18948 .2792 Mdot
.26471 .96706 Mdot
.2136 .57432 Mdot
.76416 .36806 Mdot
.11965 .42856 Mdot
.40233 .86717 Mdot
.64886 .39819 Mdot
.11668 .62712 Mdot
.22489 .74803 Mdot
.40078 .76347 Mdot
.05323 .10962 Mdot
.04185 .7504 Mdot
.78544 .73037 Mdot
.82504 .8923 Mdot
.61051 .34734 Mdot
.98295 .55438 Mdot
.52246 .79494 Mdot
.55375 .65243 Mdot
.79057 .62315 Mdot
.47558 .00951 Mdot
.60134 .85408 Mdot
.12818 .34068 Mdot
.57772 .67462 Mdot
.08601 .49835 Mdot
.7609 .86946 Mdot
.24161 .66942 Mdot
.13608 .63908 Mdot
.32084 .03582 Mdot
.66781 .85386 Mdot
.75268 .27865 Mdot
.98255 .27347 Mdot
.28818 .27427 Mdot
.24686 .42532 Mdot
.22562 .01611 Mdot
.6984 .75195 Mdot
.12489 .51391 Mdot
.81677 .82338 Mdot
.93395 .93882 Mdot
.79195 .24279 Mdot
.58977 .854 Mdot
.8807 .38485 Mdot
.81876 .51727 Mdot
.04341 .12084 Mdot
.51429 .2012 Mdot
.71541 .67971 Mdot
.37954 .16566 Mdot
.00684 .8438 Mdot
.23393 .57525 Mdot
.16146 .07174 Mdot
.37816 .73235 Mdot
.57323 .92203 Mdot
.78164 .8429 Mdot
.55684 .45756 Mdot
.98979 .40907 Mdot
.45293 .41157 Mdot
.38845 .12266 Mdot
.77894 .79837 Mdot
.99144 .07538 Mdot
.81531 .87067 Mdot
.77733 .44398 Mdot
.62162 .74018 Mdot
.42496 .7727 Mdot
.0805 .92708 Mdot
.44933 .91938 Mdot
.44355 .50364 Mdot
.44924 .61535 Mdot
.94283 .0582 Mdot
.20424 .53152 Mdot
.19211 .30587 Mdot
.01176 .50728 Mdot
.37219 .55872 Mdot
.32226 .0237 Mdot
.8901 .77613 Mdot
.01207 .37654 Mdot
.80316 .72796 Mdot
.54253 .37884 Mdot
.36918 .30386 Mdot
.0876 .73325 Mdot
.38917 .21001 Mdot
.99532 .21363 Mdot
.10648 .84718 Mdot
.82908 .74677 Mdot
.65003 .445 Mdot
.47638 .69985 Mdot
.9098 .69221 Mdot
.32671 .45415 Mdot
.09303 .89183 Mdot
.89491 .0404 Mdot
.77428 .51386 Mdot
.86877 .28124 Mdot
.4529 .28074 Mdot
.90558 .00772 Mdot
.21371 .39383 Mdot
.91551 .14082 Mdot
.53465 .88168 Mdot
.50378 .4202 Mdot
.6366 .32702 Mdot
.07339 .98599 Mdot
.65141 .35174 Mdot
.27845 .95217 Mdot
.96894 .92314 Mdot
.52267 .745 Mdot
.55461 .76095 Mdot
.6443 .74426 Mdot
.31808 .35528 Mdot
.76779 .6272 Mdot
.87156 .48229 Mdot
.24233 .16475 Mdot
.10434 .17042 Mdot
.14709 .09876 Mdot
.44462 .70303 Mdot
.8733 .18473 Mdot
.55516 .79995 Mdot
.28815 .42319 Mdot
.01219 .15742 Mdot
.61961 .78718 Mdot
.72288 .69751 Mdot
.83135 .229 Mdot
.97091 .14141 Mdot
.54541 .09671 Mdot
.00842 .05183 Mdot
.43384 .81765 Mdot
.49132 .25473 Mdot
.48949 .66114 Mdot
.98171 .45224 Mdot
.20666 .1055 Mdot
.84032 .52128 Mdot
.50813 .44531 Mdot
.09284 .84601 Mdot
.76745 .18907 Mdot
.96959 .5827 Mdot
.21115 .2792 Mdot
.03765 .72864 Mdot
.76611 .41597 Mdot
.61551 .3092 Mdot
.1891 .81408 Mdot
.63094 .82656 Mdot
.04392 .61003 Mdot
.86164 .41223 Mdot
.44077 .2556 Mdot
.72011 .56656 Mdot
.65691 .0175 Mdot
.77987 .98986 Mdot
.46325 .68024 Mdot
.64094 .29525 Mdot
.61482 .27991 Mdot
.0775 .86772 Mdot
.47991 .41043 Mdot
.39736 .98253 Mdot
.42734 .79773 Mdot
.49499 .74688 Mdot
.08613 .54688 Mdot
.8357 .07969 Mdot
.35367 .65248 Mdot
.06641 .23822 Mdot
.91483 .90311 Mdot
.5701 .93308 Mdot
.2885 .72156 Mdot
.5394 .09924 Mdot
.93447 .27872 Mdot
.0691 .00778 Mdot
.27584 .48349 Mdot
.35838 .26807 Mdot
.32538 .83019 Mdot
.64617 .15638 Mdot
.87153 .28873 Mdot
.48917 .90757 Mdot
.98475 .26029 Mdot
.9737 .99129 Mdot
.73129 .6057 Mdot
.49808 .01069 Mdot
.86286 .29864 Mdot
.41294 .96564 Mdot
.45995 .98466 Mdot
.02503 .78223 Mdot
.19353 .05948 Mdot
.34007 .63535 Mdot
.15451 .74227 Mdot
.8653 .64681 Mdot
.33326 .4862 Mdot
.9824 .72803 Mdot
.60644 .7777 Mdot
.47752 .81646 Mdot
.81446 .38284 Mdot
.9414 .84125 Mdot
.43389 .58428 Mdot
.0829 .01664 Mdot
.25812 .43548 Mdot
.67678 .53055 Mdot
.97464 .74532 Mdot
.68852 .77616 Mdot
.70931 .21937 Mdot
.80585 .9486 Mdot
.04972 .41024 Mdot
.38485 .17106 Mdot
.21901 .02481 Mdot
.38386 .47552 Mdot
.94187 .5263 Mdot
.38042 .33481 Mdot
.64191 .03681 Mdot
.72809 .9615 Mdot
.73286 .24254 Mdot
.96731 .21886 Mdot
.03091 .87445 Mdot
.07304 .1451 Mdot
.91158 .54018 Mdot
.78115 .95244 Mdot
.67541 .47973 Mdot
.41181 .53404 Mdot
.72203 .01287 Mdot
.01194 .13198 Mdot
.12702 .9098 Mdot
.28991 .05682 Mdot
.57344 .73705 Mdot
.42084 .98766 Mdot
.50753 .70987 Mdot
.21707 .82129 Mdot
.49392 .2149 Mdot
.43536 .83461 Mdot
.75907 .78967 Mdot
.11139 .38429 Mdot
.032 .75969 Mdot
.14758 .26434 Mdot
.92522 .87954 Mdot
.95214 .09758 Mdot
.44605 .23409 Mdot
.62678 .26758 Mdot
.94606 .53273 Mdot
.29576 .50029 Mdot
.43929 .20923 Mdot
.94743 .59522 Mdot
.60943 .50607 Mdot
.61456 .28964 Mdot
.60084 .62641 Mdot
.66216 .00717 Mdot
.71172 .59864 Mdot
.59268 .85696 Mdot
.34769 .42341 Mdot
.9755 .66843 Mdot
.42397 .02702 Mdot
.67125 .16669 Mdot
.06435 .7746 Mdot
.79874 .50816 Mdot
.37491 .30549 Mdot
.88602 .27458 Mdot
.75853 .83894 Mdot
.42682 .19643 Mdot
.98205 .19391 Mdot
.85862 .3969 Mdot
.67154 .71661 Mdot
.94755 .88664 Mdot
.1437 .81313 Mdot
.30811 .7396 Mdot
.16144 .94329 Mdot
.63066 .28303 Mdot
.9098 .61347 Mdot
.55116 .02694 Mdot
.14067 .93551 Mdot
.07818 .76348 Mdot
.10312 .63943 Mdot
.30406 .2926 Mdot
.45108 .06629 Mdot
.33159 .41162 Mdot
.12939 .23557 Mdot
.0568 .76245 Mdot
.07804 .31163 Mdot
.41333 .50024 Mdot
.1133 .60865 Mdot
.99149 .46233 Mdot
.09823 .79726 Mdot
.77363 .67192 Mdot
.99205 .07163 Mdot
.65982 .25625 Mdot
.50556 .00847 Mdot
.20739 .78119 Mdot
.24044 .69795 Mdot
.14846 .07182 Mdot
.30221 .55105 Mdot
.72348 .58966 Mdot
.16222 .8006 Mdot
.82204 .23693 Mdot
.05461 .06531 Mdot
.91916 .48439 Mdot
.1006 .06454 Mdot
.37641 .23587 Mdot
.55102 .07106 Mdot
.21201 .47156 Mdot
.29671 .32403 Mdot
.86288 .35225 Mdot
.12743 .78254 Mdot
.32291 .61448 Mdot
.95609 .00767 Mdot
.43883 .51111 Mdot
.87804 .92498 Mdot
.56017 .9191 Mdot
.82229 .77561 Mdot
.2585 .68366 Mdot
.18507 .75848 Mdot
.09369 .22697 Mdot
.81004 .58676 Mdot
.01154 .91604 Mdot
.63381 .80373 Mdot
.77509 .30814 Mdot
.77919 .80272 Mdot
.18953 .70777 Mdot
.89621 .88234 Mdot
.72201 .89136 Mdot
.04372 .17968 Mdot
.4761 .19029 Mdot
.90075 .31099 Mdot
.36202 .94476 Mdot
.11328 .82596 Mdot
.26263 .9411 Mdot
.27612 .05896 Mdot
.52502 .61192 Mdot
.52292 .19499 Mdot
.33305 .72779 Mdot
.68177 .22574 Mdot
.67811 .06253 Mdot
.63789 .1196 Mdot
.27745 .86476 Mdot
.76091 .74081 Mdot
.04621 .98291 Mdot
.70381 .97953 Mdot
.6532 .02045 Mdot
.32113 .91522 Mdot
.09576 .40951 Mdot
.72028 .62447 Mdot
.80056 .67974 Mdot
.08942 .29885 Mdot
.08915 .58041 Mdot
.49219 .18606 Mdot
.71639 .77384 Mdot
.83589 .40012 Mdot
.65356 .90909 Mdot
.16545 .34221 Mdot
.11198 .83556 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03?ooool2o`0000oooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool2o`00013o
oooo00?o0000ooooooooool00_ooool001kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool2o`0000kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03_ooool01?l0003oooooooooooooool2o`0000[ooooo00?o0000oooooooo
ool00_l0000:ooooo`;o00003oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`;o00004?ooool00ol0003o
ooooooooo`02ooooo`007_ooool00ol0003oooooooooo`0Booooo`;o0000:_ooool2o`0001Gooooo
0_l00010ooooo`;o00001oooool2o`0002;ooooo0_l0000=ooooo`;o0000COooool2o`0000oooooo
0_l0000Booooo`007_ooool00ol0003oooooooooo`0Booooo`;o0000@Oooool2o`00043ooooo0_l0
0005ooooo`Co0000AOooool2o`0003Wooooo0_l0000?ooooo`;o00004_ooool001kooooo00?o0000
ooooooooool05oooool2o`0002cooooo0_l0001Gooooo`;o0000=oooool2o`0000kooooo0_l0001N
ooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o00002Oooool3o`00023ooooo0_l0001Ioooo
o`;o0000;oooool2o`0000Cooooo0_l0000oooooo`;o0000;Oooool001kooooo00?o0000oooooooo
ool00_l0000Pooooo`?o0000AOooool2o`0000_ooooo0_l0000Wooooo`;o00008_ooool2o`0000[o
oooo0ol0000Kooooo`;o0000:?ooool2o`0002gooooo000Nooooo`03o`000?oooooooooo00;o0000
@Oooool2o`00023ooooo0_l00003ooooo`;o00002oooool2o`0004_ooooo0_l0000:ooooo`;o0000
7?ooool2o`0005Oooooo000Nooooo`03o`000?oooooooooo04?ooooo0_l0000Pooooo`;o00003_oo
ool2o`0000_ooooo0_l00002ooooo`;o00009oooool2o`0009Kooooo000Nooooo`03o`000?oooooo
oooo07Gooooo0_l0000;ooooo`;o00000_ooool2o`0000Cooooo0_l0000Qooooo`?o0000UOooool0
01kooooo00?o0000ooooooooool0>Oooool2o`00023ooooo0_l0000_ooooo`;o00008_ooool2o`00
03Sooooo0_l0001:ooooo`;o00001oooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo03Wo
oooo0_l0000Pooooo`;o00001oooool2o`0003Wooooo0_l0000/ooooo`;o00006oooool2o`0003?o
oooo0_l0000Eooooo`;o00001oooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo047ooooo
0_l0000Qooooo`;o0000>Oooool2o`0002_ooooo0ol0001@ooooo`;o00009_ooool001kooooo00?o
0000ooooooooool0@Oooool2o`0008Oooooo1?l0000Wooooo`;o0000:?ooool2o`0002Kooooo000M
ooooo`;o0000c?ooool2o`0002Wooooo0_l0001@ooooo`007Oooool2o`0009Oooooo0_l0000Doooo
o`;o0000<Oooool2o`0006Oooooo000Nooooo`Co0000U?ooool2o`0001Cooooo0_l0000aooooo`;o
0000:Oooool2o`0003cooooo000Nooooo`04o`000?oooooo0000o`0000?ooooo0_l00032ooooo`;o
00009oooool2o`0001Kooooo0_l0000looooo`007_ooool00ol0003oooooooooo`04ooooo`;o0000
=Oooool2o`0001Gooooo0_l00002ooooo`;o00000_ooool2o`0006cooooo0_l0000Wooooo`;o0000
2_ooool2o`0002;ooooo0_l0000;ooooo`;o00005oooool001kooooo00?o0000ooooooooool07_oo
ool2o`0001_ooooo0_l0000Eooooo`;o00000_ooool2o`0000;ooooo0_l0000^ooooo`;o0000C?oo
ool2o`0002?ooooo0_l0000Rooooo`;o00002oooool2o`0001Oooooo000Nooooo`03o`000?oooooo
oooo00kooooo1?l0000;ooooo`?o00003_ooool2o`0005[ooooo0_l0000Gooooo`;o0000<oooool2
o`0006gooooo000Nooooo`03o`000?oooooooooo00kooooo1?l0000;ooooo`;o00003oooool2o`00
05Kooooo0_l00007ooooo`;o00004_ooool2o`0002kooooo0_l0001booooo`007_ooool00ol0003o
ooooooooo`0/ooooo`;o00000_ooool2o`0003cooooo0_l000000ooooooo0000o`00000Cooooo`;o
00001oooool2o`0001kooooo0_l0000Rooooo`;o0000JOooool2o`0000Oooooo000Nooooo`03o`00
0?oooooooooo02cooooo0_l00002ooooo`;o0000??ooool2o`000003ooooool0003o000003cooooo
0_l0002=ooooo`;o00001oooool001kooooo00?o0000ooooooooool0HOooool2o`000=Kooooo0_l0
0003ooooo`;o00001oooool001kooooo00?o0000ooooooooool0HOooool2o`000:Wooooo0_l0000[
ooooo`;o00000oooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l0002Moooo
o`;o00005Oooool2o`0004kooooo0_l0000iooooo`007_ooool00ol0003oooooooooo`06ooooo`;o
0000;_ooool2o`0006gooooo0_l0000Eooooo`;o0000ROooool001kooooo00?o0000ooooooooool0
=_ooool2o`000?oooooo4?ooool001kooooo00?o0000ooooooooool06_ooool2o`0001Oooooo0_l0
001;ooooo`;o00004_ooool2o`000;7ooooo000Nooooo`03o`000?oooooooooo01[ooooo0_l0000G
ooooo`;o0000Boooool2o`0001;ooooo0_l0000Gooooo`;o0000V?ooool001kooooo00?o0000oooo
ooooool0;?ooool2o`0001Kooooo0_l0001Uooooo`Co0000B?ooool2o`0003Sooooo0_l0000Doooo
o`007_ooool2o`0002gooooo0_l0000Aooooo`;o00000oooool2o`0006Gooooo1?l00018ooooo`;o
0000>?ooool2o`0001Cooooo000Nooooo`03o`000?oooooooooo02_ooooo0_l00008ooooo`;o0000
2?ooool2o`0004gooooo0_l0000Mooooo`;o0000V?ooool001kooooo00?o0000ooooooooool0:ooo
ool2o`0000Sooooo0_l00008ooooo`;o0000COooool2o`0004Wooooo0_l0001=ooooo`;o00007Ooo
ool001kooooo0ol0000=ooooo`;o0000<Oooool2o`0009Oooooo0_l0001=ooooo`;o00007Oooool0
01kooooo0ol0000=ooooo`;o00008?ooool2o`0000oooooo0_l0001Tooooo`;o0000Woooool001ko
oooo00?o0000ooooooooool0;oooool2o`0007Gooooo0_l0002Oooooo`007_ooool00ol0003ooooo
ooooo`0:ooooo`;o0000/Oooool2o`0000cooooo0_l0000`ooooo`;o00003_ooool2o`0003Sooooo
000Nooooo`03o`000?oooooooooo00[ooooo0_l0000<ooooo`;o00002_ooool2o`0000cooooo0_l0
0016ooooo`;o0000@Oooool2o`0000cooooo0_l00002ooooo`;o0000:Oooool2o`000003ooooool0
003o000000kooooo0_l0000hooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o00002_ooool2
o`0000cooooo0_l00016ooooo`;o0000BOooool2o`0000Sooooo0_l0000Yooooo`;o0000Boooool0
01kooooo00?o0000ooooooooool0Poooool2o`0003;ooooo0_l0000<ooooo`;o0000P?ooool001ko
oooo1Ol00009ooooo`;o0000M_ooool2o`0003;ooooo1?l0000iooooo`;o00005_ooool2o`0003Wo
oooo000Nooooo`Go00002Oooool2o`0008cooooo0_l0000Nooooo`;o0000>Oooool2o`0000kooooo
0_l00006ooooo`;o0000>Oooool001kooooo00?o0000ooooooooool04_ooool2o`0000kooooo0_l0
001Hooooo`;o00006oooool2o`0006Wooooo0_l00011ooooo`007_ooool00ol0003oooooooooo`0B
ooooo`;o00003_ooool2o`0000Wooooo0_l0000Sooooo`;o00007Oooool2o`0000Wooooo0_l0000:
ooooo`;o0000W?ooool2o`00013ooooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`0Doooo
o`?o00005_ooool2o`0002?ooooo0_l0000Mooooo`;o00005Oooool2o`0001?ooooo0_l00003oooo
o`;o0000:oooool2o`0005Gooooo0_l0000@ooooo`;o00003Oooool001kooooo00?o0000oooooooo
ool05?ooool3o`0003Kooooo0_l0001>ooooo`;o00000oooool2o`0002_ooooo0_l0000>ooooo`;o
00008?ooool2o`0000Sooooo0_l0000jooooo`007_ooool2o`0004kooooo0_l0000cooooo`;o0000
Foooool2o`0001Gooooo0_l00009ooooo`;o00002?ooool2o`0003[ooooo000Nooooo`03o`000?oo
oooooooo08;ooooo0_l0001Wooooo`;o00002Oooool2o`0004oooooo000Nooooo`03o`000?oooooo
oooo00;o0000J?ooool2o`0006;ooooo0_l0000Kooooo`;o000000?oooooo`000?l00000Eoooool0
01kooooo00?o0000ooooooooool00_l0001Xooooo`;o0000H_ooool2o`0001kooooo0_l00015oooo
o`;o00004?ooool001kooooo00?o0000ooooooooool0oooooolGooooo`?o00007?ooool2o`00013o
oooo000Nooooo`03o`000?oooooooooo04_ooooo0_l00004ooooo`;o00009?ooool2o`0005gooooo
0_l0000nooooo`?o0000;_ooool001kooooo00?o0000ooooooooool07_ooool2o`0000Kooooo0_l0
000Sooooo`;o00001?ooool2o`00017ooooo0_l0000Aooooo`;o0000GOooool2o`0001Oooooo1?l0
000Gooooo`;o0000>oooool001kooooo00?o0000ooooooooool07_ooool2o`0000Kooooo0_l0000/
ooooo`;o00003_ooool2o`0001?ooooo0_l0001Fooooo`;o00007?ooool4o`0001Oooooo0_l0000k
ooooo`007_ooool00ol0003oooooooooo`1Dooooo`;o00008oooool2o`0005Kooooo0_l00007oooo
o`;o0000Joooool001kooooo00?o0000ooooooooool02_ooool2o`000<kooooo0_l0001[ooooo`00
7_ooool00ol0003oooooooooo`09ooooo`?o00004?ooool2o`000?oooooo:_ooool001kooooo00?o
0000ooooooooool02Oooool2o`00017ooooo0_l0002eooooo`;o0000@oooool2o`0002gooooo000N
ooooo`03o`000?oooooooooo09cooooo0_l00009ooooo`;o0000:_ooool2o`0004?ooooo0_l0000]
ooooo`007_ooool00ol0003oooooooooo`2Gooooo`;o00000oooool2o`0000Wooooo0_l0001<oooo
o`;o0000D?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`00
00Kooooo00?o0000ooooooooool0Uoooool2o`0000gooooo0_l0000oooooo`;o00003?ooool2o`00
04Cooooo0_l000000ooooooo0000o`000007ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`0O
ooooo`;o00007?ooool2o`0004Sooooo0_l0000Mooooo`;o0000?oooool2o`0005;ooooo0_l00000
0ooooooo0000o`000007ooooo`000oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RH
ob4Q8Oo^k^h01oooool3o`0001oooooo0_l0000Looooo`Co00006oooool2o`0002Wooooo0_l0000J
ooooo`;o0000X_ooool000?ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^00Kooooo00?o0000ooooooooool0?oooool2o`0001_ooooo0_l00015ooooo`;o0000NOooool2
o`0000Sooooo0_l0000Mooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMg
ofIVI_ooool01Oooool00ol0003oooooooooo`18ooooo`;o0000e?ooool2o`0000Sooooo0_l0000M
ooooo`000oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`18ooooo`;o0000<?ooool2o`0000oooooo0_l0002jooooo`000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oo
oooooooo01Kooooo0_l0001Rooooo`;o00003oooool2o`0008Sooooo0_l0000Xooooo`;o00001_oo
ool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
1_ooool2o`0001Oooooo0_l0000Wooooo`;o0000Foooool2o`0001oooooo0_l0001?ooooo`;o0000
1Oooool2o`0002Sooooo0_l00006ooooo`007_ooool2o`0001Oooooo0_l0000Wooooo`;o0000Fooo
ool2o`0001oooooo0_l0000Sooooo`;o00007?ooool2o`0000cooooo0_l0000Vooooo`;o00001ooo
ool4o`0000Cooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l0001fooooo`;o0000?Oooool2
o`0001?ooooo0_l0000Looooo`;o00003Oooool2o`0002Gooooo0_l00009ooooo`;o00001?ooool0
01kooooo00?o0000ooooooooool0;Oooool2o`0001oooooo0_l0000nooooo`;o0000?Oooool2o`00
00_ooooo0_l0000cooooo`;o0000=_ooool001kooooo00?o0000ooooooooool06_ooool2o`00013o
oooo0ol0000Oooooo`;o0000R_ooool2o`0002kooooo0_l0000Aooooo`;o0000:?ooool001kooooo
00?o0000ooooooooool06_ooool2o`00013ooooo0_l0001Uooooo`;o0000MOooool2o`00017ooooo
0_l0000Xooooo`007_ooool00ol0003oooooooooo`2=ooooo`;o00001?ooool2o`0007;ooooo0_l0
000nooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o00000_ooool2o`0000oooooo0_l0001>
ooooo`;o00005Oooool2o`0001?ooooo0_l0001Sooooo`;o0000?_ooool001kooooo00?o0000oooo
ooooool01_ooool2o`0000Wooooo0_l00002ooooo`;o00003oooool2o`0000gooooo0_l0000aoooo
o`;o00003?ooool2o`0002[ooooo0_l00009ooooo`;o0000F?ooool2o`0001gooooo0_l0000Ooooo
o`007_ooool00ol0003oooooooooo`06ooooo`;o00002?ooool2o`0002?ooooo0_l0000aooooo`;o
0000@oooool2o`0003_ooooo0_l0000Aooooo`;o00009oooool2o`0001oooooo000Nooooo`03o`00
0?oooooooooo013ooooo0_l00002ooooo`;o00001?ooool2o`0005_ooooo0_l0001Pooooo`;o0000
3oooool2o`00017ooooo1?l0000Cooooo`;o00007?ooool2o`0001?ooooo000Nooooo`03o`000?oo
oooooooo01Cooooo0_l00004ooooo`;o0000?_ooool2o`0001_ooooo0_l0000Rooooo`;o0000??oo
ool2o`0002Cooooo0_l0000Cooooo`;o00007?ooool2o`0001?ooooo000Nooooo`;o0000Foooool2
o`0003oooooo0_l00006ooooo`;o0000X_ooool001kooooo00?o0000ooooooooool09Oooool2o`00
06Cooooo0_l0000?ooooo`;o00001Oooool2o`0002gooooo0_l00016ooooo`;o0000:oooool001ko
oooo00?o0000ooooooooool02?ooool2o`000003ooooool0003o000001Sooooo0_l0001Tooooo`;o
00003oooool2o`0003Cooooo0_l0000Zooooo`;o00006_ooool2o`0002_ooooo000Nooooo`03o`00
0?oooooooooo00Sooooo0_l000000ooooooo0000o`00003aooooo`;o0000??ooool2o`0000Wooooo
000Nooooo`03o`000?oooooooooo02cooooo0_l0000Cooooo`;o0000:Oooool2o`0006Oooooo0_l0
001Uooooo`;o00002Oooool001kooooo00?o0000ooooooooool0;?ooool2o`0001?ooooo0_l0000Y
ooooo`;o00000_ooool2o`0005Kooooo0_l0000;ooooo`;o0000<?ooool2o`0003kooooo000Noooo
o`03o`000?oooooooooo00;ooooo0_l0000jooooo`;o00003_ooool2o`00023ooooo0_l0001Foooo
o`;o0000?Oooool2o`0001Sooooo0_l00009ooooo`;o00006Oooool001kooooo00?o0000oooooooo
ool00_ooool2o`0003[ooooo0_l0000>ooooo`;o00002_ooool2o`0008Oooooo0_l0000gooooo`;o
00000oooool2o`0000Wooooo0_l0000=ooooo`;o00002_ooool001kooooo00?o0000ooooooooool0
=?ooool2o`0002Cooooo0_l00027ooooo`;o0000=oooool2o`0001gooooo0_l0000:ooooo`007_oo
ool00ol0003oooooooooo`0Looooo`;o00005_ooool2o`0000?ooooo0_l00006ooooo`;o0000C?oo
ool2o`0003?ooooo0_l0000[ooooo`;o00006?ooool2o`0000Wooooo0_l0000Dooooo`;o00006Ooo
ool001kooooo00?o0000ooooooooool07?ooool2o`0001_ooooo0_l00006ooooo`;o00004Oooool2
o`0001Oooooo0_l0000Pooooo`;o00006?ooool2o`0001Wooooo0_l00003ooooo`;o00009_ooool2
o`0001Sooooo0_l00009ooooo`;o00005?ooool2o`0000cooooo0_l0000;ooooo`007_ooool00ol0
003oooooooooo`1Dooooo`;o00005oooool2o`0003[ooooo0_l0000Nooooo`;o0000J_ooool2o`00
00?ooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`34ooooo`;o0000DOooool2o`0001co
oooo0_l0000@ooooo`007_ooool00ol0003oooooooooo`1Oooooo`;o0000Hoooool2o`0001Kooooo
0_l0000iooooo`;o0000;_ooool001kooooo00?o0000ooooooooool0B?ooool2o`0001Gooooo0_l0
001[ooooo`;o00003_ooool2o`0006Wooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l0000D
ooooo`;o00005oooool2o`0000Kooooo0_l0001jooooo`;o0000A_ooool2o`00037ooooo000Noooo
o`;o00006_ooool2o`0001Cooooo0_l0000Hooooo`;o00001Oooool2o`00037ooooo0_l0000koooo
o`;o0000D_ooool2o`0002_ooooo0_l00004ooooo`007_ooool00ol0003oooooooooo`0jooooo`;o
00003Oooool2o`0002Kooooo0_l000000ooooooo0000o`000002o`0000_ooooo0_l0000kooooo`;o
0000Ooooool2o`0000Cooooo000Nooooo`03o`000?oooooooooo03[ooooo0_l0000Sooooo`;o0000
4?ooool2o`000003ooooool0003o000000;o0000J?ooool2o`0001Kooooo0_l0001=ooooo`007_oo
ool00ol0003oooooooooo`0Eooooo`;o0000B?ooool2o`000003ooooool0003o000003kooooo0_l0
000Pooooo`;o00006_ooool2o`0000[ooooo0_l0000:ooooo`;o00005Oooool2o`0000Wooooo0_l0
0005ooooo`;o00009?ooool001kooooo00?o0000ooooooooool05Oooool2o`0003Oooooo0_l00008
ooooo`;o00002?ooool2o`00017ooooo0_l0000[ooooo`;o00005_ooool2o`0000Sooooo0_l0000V
ooooo`;o00008Oooool2o`0000Wooooo0_l00005ooooo`;o00004?ooool2o`0001;ooooo000Noooo
o`03o`000?oooooooooo04kooooo0_l00008ooooo`;o00006oooool2o`0004?ooooo0_l0001goooo
o`;o00004_ooool001kooooo00?o0000ooooooooool06?ooool2o`0007[ooooo0_l0002aooooo`00
7_ooool00ol0003oooooooooo`0Hooooo`;o0000@_ooool2o`0003Kooooo0_l0001Tooooo`;o0000
Boooool001kooooo00?o0000ooooooooool0G?ooool2o`0006gooooo0_l0000]ooooo`;o0000Booo
ool001kooooo00?o0000ooooooooool0@_ooool2o`00027ooooo0_l0001Tooooo`;o0000Hoooool2
o`0001Gooooo000Nooooo`03o`000?oooooooooo02_ooooo0_l0000Eooooo`;o00008Oooool2o`00
03gooooo0_l0000=ooooo`;o0000Noooool2o`0001Gooooo000Nooooo`03o`000?oooooooooo02_o
oooo0_l0001;ooooo`;o00005oooool2o`00017ooooo0_l0000=ooooo`;o0000T_ooool001kooooo
00?o0000ooooooooool0N?ooool2o`0001Oooooo0_l0002Yooooo`;o00002Oooool001kooooo00?o
0000ooooooooool09_ooool2o`0000[ooooo0_l0001Dooooo`;o0000/_ooool2o`0000Wooooo000N
ooooo`03o`000?oooooooooo02Kooooo0_l0000:ooooo`;o00006oooool2o`0003Oooooo0_l0000Y
ooooo`;o0000T_ooool001kooooo00?o0000ooooooooool0Coooool2o`0002_ooooo0_l0000eoooo
o`;o00003Oooool2o`0008?ooooo000Nooooo`;o00005_ooool2o`0000Oooooo0_l0000Aooooo`;o
0000>?ooool2o`0000oooooo0_l00014ooooo`;o00003?ooool2o`0007Gooooo000Nooooo`03o`00
0?oooooooooo01Gooooo0_l00007ooooo`;o00004Oooool2o`0003Sooooo0_l0001Nooooo`;o0000
0oooool2o`0004;ooooo0_l0000Cooooo`;o00007?ooool001kooooo00?o0000ooooooooool0Hooo
ool2o`0001Gooooo0_l0001?ooooo`;o0000;_ooool2o`0001Oooooo0_l0000Cooooo`;o00007?oo
ool001kooooo00?o0000ooooooooool0Hoooool2o`0000Kooooo0_l00009ooooo`;o00000_ooool2
o`0003Oooooo0_l00016ooooo`;o00005oooool2o`00037ooooo000Nooooo`03o`000?oooooooooo
06_ooooo0_l00009ooooo`;o0000>oooool2o`0005?ooooo0_l0000mooooo`007_ooool00ol0003o
ooooooooo`0kooooo`;o00001_ooool2o`00037ooooo0_l0002@ooooo`;o0000?Oooool001kooooo
00?o0000ooooooooool00oooool2o`0002Cooooo0_l0000@ooooo`;o00001_ooool2o`00037ooooo
0_l0001gooooo`;o00000oooool2o`00057ooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0
000Rooooo`Co0000a?ooool2o`0000?ooooo0_l0000fooooo`;o00006Oooool001kooooo00?o0000
ooooooooool00_l0000Uooooo`;o0000ooooool4ooooo`;o00006Oooool001kooooo00?o0000oooo
ooooool00_l0000Cooooo`;o00002?ooool2o`0008_ooooo0_l0002Iooooo`007_ooool00ol0003o
ooooooooo`0Booooo`;o000000?oooooo`000?l000002?ooool2o`00013ooooo0_l0001/ooooo`;o
00002oooool2o`00077ooooo0_l0000Vooooo`007_ooool00ol0003oooooooooo`0Booooo`;o0000
3?ooool2o`0000oooooo0_l0001/ooooo`?o0000Hoooool2o`0001?ooooo0_l00003ooooo`;o0000
9_ooool001kooooo00?o0000ooooooooool08?ooool2o`0000;ooooo0_l0001jooooo`;o0000Hooo
ool2o`0001?ooooo0_l0000Rooooo`;o00001oooool001kooooo00?o0000ooooooooool03_ooool2
o`0001Cooooo0_l0000Nooooo`;o0000n?ooool2o`0000Oooooo0003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo0_l00008ooooo`;o0000<Oooool2o`000003ooooool0003o000002oooooo0_l0003@
ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool2o`0003_ooooo0_l0000booooo`;o000000?ooooo
o`000?l00000EOooool2o`0003kooooo0_l00002ooooo`;o0000<_ooool000?ooooo00Go410@oooo
oooooooooooooa0@400;ooooo`Go00001_ooool3o`0007Sooooo0_l0001Eooooo`;o0000>oooool2
o`000003ooooool0003o000000;ooooo0_l0000=ooooo`;o00008oooool000?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool05?oo
ool2o`0007cooooo0_l0001hooooo`;o00005?ooool2o`0002?ooooo0003ooooo`05o`000?oooooo
ooooooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo01Cooooo
0_l0001looooo`;o0000:?ooool2o`0000gooooo0_l0001jooooo`000oooool01Ol@413ooooooooo
oooooooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`03ooooo`;o0000
1oooool2o`0000Sooooo0_l00003ooooo`;o0000BOooool2o`00033ooooo0_l0000Fooooo`;o0000
2_ooool2o`0000gooooo0_l0000Jooooo`;o0000EOooool2o`0000Oooooo0003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo00?ooooo
0_l00007ooooo`;o00002?ooool2o`0000?ooooo0_l00019ooooo`Co00009Oooool2o`0000Oooooo
0_l0000Fooooo`;o0000=Oooool2o`0002_ooooo0_l0000Xooooo`;o00001oooool000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0
<_ooool2o`0003Cooooo0_l0000Uooooo`;o0000I?ooool2o`0001gooooo0_l0000aooooo`007_oo
ool00ol0003oooooooooo`0booooo`;o0000^Oooool2o`0000Kooooo0_l0000Looooo`;o00003ooo
ool2o`00027ooooo000Nooooo`03o`000?oooooooooo04Kooooo0_l0001Hooooo`;o00002oooool2
o`0003kooooo0_l0000Tooooo`;o00003oooool2o`0000cooooo0_l0000Cooooo`007_ooool00ol0
003oooooooooo`16ooooo`;o00001?ooool3o`0000_ooooo0_l0000Aooooo`;o00005oooool2o`00
01Kooooo1?l0000;ooooo`;o00006oooool2o`0006Kooooo0_l0000Cooooo`007_ooool00ol0003o
ooooooooo`0Fooooo`;o00002oooool2o`0002Oooooo0ol0000;ooooo`;o00004Oooool2o`0001Oo
oooo0_l0000Fooooo`;o00006?ooool2o`00013ooooo0_l00006ooooo`;o0000:_ooool2o`0004Oo
oooo000Nooooo`03o`000?oooooooooo00kooooo0_l00006ooooo`;o00002oooool2o`0009?ooooo
0_l0000Hooooo`;o0000:_ooool2o`0004Oooooo000Nooooo`03o`000?oooooooooo00kooooo0_l0
002^ooooo`;o0000N?ooool2o`0000gooooo000Nooooo`03o`000?oooooooooo04?ooooo0_l00000
0ooooooo0000o`000008ooooo`;o00003_ooool2o`0000Oooooo0_l0001Cooooo`;o0000N?ooool2
o`0000gooooo000Nooooo`03o`000?oooooooooo04?ooooo0_l000000ooooooo0000o`000008oooo
o`;o00003_ooool2o`0000Oooooo0_l0003Looooo`007_ooool00ol0003oooooooooo`28ooooo`;o
0000Koooool2o`0004cooooo000Nooooo`03o`000?oooooooooo04Wooooo0_l0000mooooo`;o0000
5oooool2o`0002cooooo0_l0000Xooooo`;o00003Oooool2o`0001cooooo0_l0000Oooooo`007_oo
ool00ol0003oooooooooo`19ooooo`;o00003?ooool2o`0004Sooooo0_l0000/ooooo`;o0000=ooo
ool2o`0001cooooo0_l0000Oooooo`007_ooool2o`0005Sooooo0_l0003Rooooo`;o00002_ooool0
01kooooo00?o0000ooooooooool0E_ooool2o`0000kooooo0_l0003Cooooo`;o00002_ooool001ko
oooo00?o0000ooooooooool0@?ooool2o`0001Cooooo0_l0000>ooooo`;o00004oooool2o`0003Co
oooo0_l0000aooooo`;o0000HOooool001kooooo00?o0000ooooooooool08Oooool2o`0001gooooo
0_l0000iooooo`;o00002oooool2o`0002Oooooo0_l0000aooooo`;o0000F?ooool2o`0000Oooooo
000Nooooo`03o`000?oooooooooo027ooooo0_l000000ooooooo0000o`00001Rooooo`;o0000]?oo
ool2o`0000Oooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l0000iooooo`;o00008Oooool2
o`0009;ooooo0_l0000_ooooo`007_ooool00ol0003oooooooooo`11ooooo`;o00007?ooool2o`00
027ooooo0_l0002Booooo`;o0000;oooool001kooooo00?o0000ooooooooool0@Oooool2o`0000;o
oooo0_l00027ooooo`;o0000L?ooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo01Cooooo
0_l0000_ooooo`;o0000<_ooool2o`0005?ooooo0_l00014ooooo`;o0000:_ooool2o`0000Gooooo
000Nooooo`03o`000?oooooooooo01Cooooo0_l0001Sooooo`;o0000:oooool2o`0002oooooo0_l0
000cooooo`;o00001_ooool2o`00037ooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l0000M
ooooo`;o00007oooool2o`0004kooooo0_l0000_ooooo`;o0000<oooool2o`0000Wooooo0_l0000^
ooooo`007_ooool00ol0003oooooooooo`0Fooooo`;o00007Oooool2o`0000[ooooo0_l0000Coooo
o`;o00004?ooool2o`0004Cooooo0_l0001Wooooo`;o00003_ooool2o`0001kooooo000Nooooo`03
o`000?oooooooooo047ooooo0_l0000Nooooo`;o00001Oooool2o`0001Sooooo0_l0000Zooooo`;o
0000Moooool2o`0001kooooo000Nooooo`03o`000?oooooooooo067ooooo0_l0000;ooooo`;o0000
4_ooool2o`000<?ooooo000Nooooo`03o`000?oooooooooo03;ooooo0_l0000jooooo`;o0000eooo
ool001kooooo00?o0000ooooooooool06?ooool2o`0001Sooooo0_l0003ooooooaCooooo000Noooo
o`;o00006Oooool2o`0004;ooooo0_l0000Tooooo`;o0000Goooool2o`0000Oooooo0_l0001Ioooo
o`007_ooool00ol0003oooooooooo`1Looooo`;o00009?ooool2o`0000Kooooo1?l0000Zooooo`;o
0000:Oooool2o`0000Oooooo0_l0001Iooooo`007_ooool00ol0003oooooooooo`02o`0003Sooooo
0_l0001>ooooo`Co0000:_ooool2o`0000Sooooo0_l0000looooo`;o0000AOooool001kooooo00?o
0000ooooooooool00_l0000hooooo`;o0000Coooool2o`0003Gooooo0_l0000looooo`;o0000AOoo
ool001kooooo00?o0000ooooooooool09?ooool2o`00013ooooo0_l0001Cooooo`;o0000Joooool2
o`0004gooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l0000@ooooo`;o0000QOooool2o`00
03Wooooo0_l0000<ooooo`;o0000?oooool001kooooo00?o0000ooooooooool0Boooool2o`0000_o
oooo0_l0001Sooooo`;o0000Aoooool2o`00037ooooo0_l0000<ooooo`007_ooool00ol0003ooooo
ooooo`0Wooooo`;o00008_ooool2o`0000_ooooo0_l0000[ooooo`;o0000Q_ooool2o`0002[ooooo
0_l0000<ooooo`007_ooool00ol0003oooooooooo`0Wooooo`;o0000@oooool2o`0001Oooooo0_l0
000Jooooo`;o0000?oooool2o`0002Wooooo0_l0000Oooooo`;o00005oooool001kooooo00?o0000
ooooooooool00_l0001Zooooo`;o00002oooool2o`0002Kooooo0_l0000oooooo`;o00004Oooool2
o`0003Oooooo0_l0000Gooooo`007_ooool00ol0003oooooooooo`02o`0001[ooooo0_l0000Poooo
o`;o00002oooool2o`0002cooooo0_l0001Mooooo`;o00006oooool2o`0003Sooooo0_l0000Foooo
o`007_ooool00ol0003oooooooooo`0:ooooo`;o00004?ooool2o`00023ooooo0_l0000;ooooo`;o
0000=Oooool2o`0005Cooooo0_l0001Eooooo`;o00005_ooool001kooooo00?o0000ooooooooool0
2_ooool2o`0000?ooooo0_l0001aooooo`;o0000`oooool001kooooo00?o0000ooooooooool03ooo
ool2o`0009[ooooo0_l0001gooooo`;o00008Oooool001kooooo00?o0000ooooooooool0Zoooool2
o`0007Oooooo0_l00009ooooo`;o00005_ooool001kooooo00?o0000ooooooooool06?ooool2o`00
09Gooooo0_l0000Pooooo`;o0000G?ooool2o`0001Kooooo000Nooooo`;o00006Oooool2o`0004Co
oooo0_l0001?ooooo`;o00008?ooool2o`0001kooooo0_l00003ooooo`;o0000Coooool001kooooo
00?o0000ooooooooool0G_ooool2o`00097ooooo0_l00003ooooo`;o0000@oooool2o`0000[ooooo
000Nooooo`03o`000?oooooooooo097ooooo0_l0002Xooooo`;o00002_ooool001kooooo0_l00012
ooooo`;o0000;_ooool2o`0000;ooooo0_l0000Jooooo`;o0000Aoooool2o`0000cooooo0_l0001B
ooooo`;o00002Oooool001kooooo0_l00012ooooo`;o0000;_ooool2o`0000;ooooo0_l0001Soooo
o`;o00003?ooool2o`0001?ooooo0_l0000Qooooo`;o00004oooool2o`0000Gooooo0_l00009oooo
o`007_ooool00ol0003oooooooooo`3Vooooo`;o00005Oooool2o`0000kooooo0_l0000Aooooo`;o
00004oooool2o`00013ooooo000Nooooo`03o`000?oooooooooo0>Kooooo0_l0000Uooooo`;o0000
>?ooool001kooooo00?o0000ooooooooool0E?ooool2o`0000cooooo0_l0000Kooooo`;o0000Z_oo
ool2o`0001[ooooo000Nooooo`03o`000?oooooooooo047ooooo0_l00005ooooo`;o00002_ooool2
o`0000cooooo0_l0000Kooooo`;o0000U?ooool2o`00017ooooo0_l000000ooooooo0000o`00000J
ooooo`007_ooool00ol0003oooooooooo`11ooooo`;o00001Oooool2o`000<_ooooo0_l0000Aoooo
o`;o00007Oooool001kooooo00?o0000ooooooooool06Oooool2o`00053ooooo0_l0001kooooo`;o
0000COooool2o`0000kooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l0000Hooooo`;o0000
=_ooool2o`0001cooooo0_l0000?ooooo`;o0000:oooool2o`0001_ooooo0_l00002ooooo`;o0000
0oooool2o`0004Sooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`0Fooooo`;o00006ooo
ool2o`0004?ooooo0_l0000?ooooo`;o00003oooool2o`0000Wooooo0_l0000Pooooo`;o00006ooo
ool2o`0000Oooooo0_l0000>ooooo`;o00000oooool3o`0000;ooooo0_l0000nooooo`007_ooool0
0ol0003oooooooooo`0Eooooo`?o00003Oooool2o`00057ooooo0_l0000[ooooo`;o0000?Oooool2
o`000003ooooool0003o000000Gooooo0_l0000=ooooo`;o00000oooool3o`0000;ooooo0_l0000V
ooooo`;o00005_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool0
1Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00Co0000ooooool0003o00001oooool2o`0000_ooooo
0_l0000>ooooo`;o0000`?ooool2o`0000Gooooo0_l0000oooooo`;o00005_ooool000?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Ko
oooo00Co0000ooooool0003o00001oooool2o`00013ooooo0_l0003ooooooaGooooo0ol0000Doooo
o`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006
ooooo`?o00006_ooool2o`0007Sooooo0_l00007ooooo`;o0000A?ooool2o`0004_ooooo0ol0000D
ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q
8@06ooooo`03o`000?oooooooooo03Sooooo0_l0000=ooooo`;o0000Boooool2o`0000Oooooo0_l0
0014ooooo`;o0000H_ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mE
EEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0hooooo`;o00003Oooool2o`0002_ooooo
1?l0000cooooo`;o0000?Oooool2o`0005_ooooo0003ooooo`05oa0@4?ooooooooooooooool@4100
2oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo00[ooooo0_l0000Eooooo`;o0000
9?ooool2o`0000Oooooo0_l0000Rooooo`Co0000<oooool2o`0001kooooo0_l0000Mooooo`;o0000
Foooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo
00?o0000ooooooooool02_ooool2o`0001Gooooo0_l0000]ooooo`;o0000EOooool2o`0002;ooooo
0_l00013ooooo`;o00004_ooool2o`00027ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo06Gooooo0_l0000Wooooo`;o
00005oooool2o`0001kooooo0_l00017ooooo`;o00003?ooool2o`0000Cooooo0_l00009ooooo`;o
00005_ooool001kooooo00?o0000ooooooooool0IOooool2o`0002Oooooo0_l0000gooooo`;o0000
;_ooool2o`0002Gooooo0_l0000?ooooo`;o00005_ooool001kooooo00?o0000ooooooooool0mooo
ool2o`0004kooooo000Nooooo`03o`000?oooooooooo04Wooooo0_l0002Kooooo`;o00005Oooool2
o`0004Sooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0000>ooooo`;o00009Oooool2o`00
03Cooooo0_l0000nooooo`;o00009Oooool2o`0000kooooo0_l00005ooooo`;o0000B?ooool001ko
oooo00?o0000ooooooooool04_ooool2o`0000kooooo0_l0000booooo`;o00009oooool2o`0000oo
oooo0_l0000]ooooo`;o0000=Oooool2o`0004oooooo000Nooooo`03o`000?oooooooooo00Gooooo
0_l0001?ooooo`;o0000>?ooool2o`0001Sooooo0_l0002Kooooo`007_ooool00ol0003ooooooooo
o`05ooooo`;o0000Hoooool2o`0003Cooooo0_l00008ooooo`;o0000Voooool001kooooo00?o0000
ooooooooool07Oooool2o`0000Wooooo0_l0000Fooooo`;o0000:?ooool2o`0002oooooo0_l00003
ooooo`;o00002Oooool2o`0008;ooooo0_l0000Fooooo`007_ooool00ol0003oooooooooo`0Moooo
o`;o00002Oooool2o`0001Kooooo0_l0000<ooooo`;o0000Boooool3o`0000gooooo0_l00022oooo
o`;o00005_ooool001kooooo00?o0000ooooooooool0C_ooool2o`0001?ooooo0_l00008ooooo`;o
00000oooool2o`0002Sooooo0_l0001Kooooo`;o00006_ooool2o`00033ooooo000Nooooo`03o`00
0?oooooooooo06?ooooo0_l00008ooooo`;o00000oooool2o`0008Gooooo0_l0000Jooooo`;o0000
<?ooool001kooooo0_l0001`ooooo`;o0000?oooool2o`0009Gooooo000Nooooo`03o`000?oooooo
oooo06oooooo0_l0000oooooo`;o0000UOooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`2Kooooo`;o0000Foooool2o`000003ooooool0003o000004[o
oooo000Nooooo`03o`000?oooooooooo04Gooooo0_l000000ooooooo0000o`00001Aooooo`;o0000
B_ooool2o`0000oooooo0_l000000ooooooo0000o`00001:ooooo`007_ooool00ol0003ooooooooo
o`15ooooo`;o000000?oooooo`000?l000004?ooool2o`0006Wooooo0_l00009ooooo`;o00005Ooo
ool2o`00053ooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`1:ooooo`;o00003_ooool2
o`0006Wooooo0_l00009ooooo`;o00009Oooool2o`00043ooooo0_l0000<ooooo`007_ooool00ol0
003oooooooooo`0=ooooo`;o00006_ooool2o`0001oooooo0_l0001/ooooo`;o0000?Oooool2o`00
00Oooooo0_l00015ooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o00006_ooool2o`0008go
oooo0_l00016ooooo`;o0000AOooool001kooooo00?o0000ooooooooool0T_ooool2o`0000kooooo
0_l00010ooooo`;o00006_ooool2o`0004Gooooo000Nooooo`03o`000?oooooooooo053ooooo0_l0
0010ooooo`;o00000oooool2o`0000Wooooo0_l0000_ooooo`;o00003oooool2o`0001[ooooo0_l0
0015ooooo`007_ooool00ol0003oooooooooo`02ooooo`;o0000@oooool2o`0000Oooooo0_l00009
ooooo`;o0000>_ooool2o`0003[ooooo0_l0000Kooooo`;o0000EOooool001kooooo00?o0000oooo
ooooool00_ooool2o`0004?ooooo0_l0000Booooo`;o0000Toooool2o`0005Gooooo000Nooooo`03
o`000?oooooooooo0?oooooo2_ooool2o`0001Wooooo0_l0000Qooooo`007_ooool00ol0003ooooo
ooooo`0fooooo`;o00003?ooool2o`000<?ooooo0_l0000Iooooo`;o00008Oooool001kooooo00?o
0000ooooooooool0=_ooool2o`0000cooooo0_l00004ooooo`;o0000Q_ooool2o`0001?ooooo0_l0
001Nooooo`007_ooool2o`0004_ooooo0_l0001;ooooo`Co0000=oooool2o`0001?ooooo0_l0000C
ooooo`;o0000BOooool001kooooo00?o0000ooooooooool0HOooool2o`00023ooooo0_l00007oooo
o`;o00002Oooool4o`00067ooooo0_l00019ooooo`007_ooool00ol0003oooooooooo`0jooooo`;o
00009Oooool2o`00023ooooo0_l00007ooooo`;o00004?ooool2o`00037ooooo0_l0000Looooo`;o
0000E_ooool001kooooo00?o0000ooooooooool0>_ooool2o`00033ooooo0_l0000/ooooo`;o0000
0_ooool2o`000003ooooool0003o000000;ooooo0_l0000Zooooo`;o00007?ooool2o`0002Wooooo
0_l0000Sooooo`;o00001_ooool001kooooo00?o0000ooooooooool0K?ooool2o`0002cooooo0_l0
0005ooooo`;o00000_ooool2o`0000Gooooo0_l0001/ooooo`;o00008oooool2o`0000Kooooo000N
ooooo`03o`000?oooooooooo02Oooooo0_l0000`ooooo`;o0000BOooool2o`0000Kooooo0_l0000X
ooooo`;o0000Koooool001kooooo00?o0000ooooooooool09oooool2o`00033ooooo0_l00014oooo
o`;o00000oooool2o`0002Gooooo0_l00009ooooo`;o0000Koooool001kooooo00?o0000oooooooo
ool0B?ooool2o`00013ooooo0_l00005ooooo`;o00005?ooool2o`0002Kooooo0_l0000Zooooo`;o
0000N_ooool001kooooo00?o0000ooooooooool0:_ooool2o`0001cooooo0_l0000@ooooo`;o0000
1Oooool2o`0001Cooooo0_l0001?ooooo`;o00008?ooool2o`0001Sooooo0_l00011ooooo`007_oo
ool00ol0003oooooooooo`08ooooo`;o00004oooool2o`0000_ooooo0_l0000looooo`;o0000G_oo
ool2o`00023ooooo0_l0000?ooooo`;o00001?ooool2o`000003ooooool0003o000003Gooooo0_l0
000:ooooo`007_ooool00ol0003oooooooooo`08ooooo`;o00003_ooool2o`0000?ooooo0_l0000M
ooooo`;o0000:_ooool2o`0000gooooo0_l00022ooooo`;o00001?ooool2o`0003Sooooo0_l0000:
ooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o00008_ooool2o`0003Wooooo0_l0000foooo
o`;o0000U_ooool001kooooo00?o0000ooooooooool0H?ooool2o`0004gooooo0_l00005ooooo`;o
0000Soooool001kooooo00?o0000ooooooooool0;_ooool2o`0001Sooooo0_l0000Fooooo`;o0000
3?ooool2o`0004Kooooo0_l0000>ooooo`;o0000:oooool2o`0000gooooo0_l0000Jooooo`;o0000
9oooool001kooooo00?o0000ooooooooool0;_ooool2o`0001Sooooo0_l0000Tooooo`;o0000=_oo
ool2o`0000kooooo0_l0000>ooooo`;o00001Oooool2o`0002Cooooo0_l0000=ooooo`;o00006_oo
ool2o`0001Wooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`15ooooo`;o0000E_ooool2
o`0000Oooooo0_l0000>ooooo`;o00005Oooool2o`0003[ooooo0_l0000Mooooo`;o00003oooool2
o`0000cooooo000Nooooo`;o00002_ooool2o`0003[ooooo0_l0001Fooooo`;o0000J_ooool2o`00
01gooooo0_l0000Dooooo`;o00001oooool001kooooo00?o0000ooooooooool02Oooool2o`000=Co
oooo0_l0000jooooo`;o00008Oooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo0=oooooo
0_l0000jooooo`;o00003Oooool2o`0001_ooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l0
000`ooooo`;o0000C_ooool2o`0002Kooooo0_l0001hooooo`;o00006oooool001kooooo00?o0000
ooooooooool01_ooool2o`0000Kooooo0_l00005ooooo`;o00008Oooool2o`0004Cooooo0_l00008
ooooo`;o00009_ooool2o`0009Gooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l00007oooo
o`Co00001Oooool2o`0001Sooooo0_l0001=ooooo`;o0000S_ooool2o`0000Cooooo0_l0000aoooo
o`007_ooool00ol0003oooooooooo`03ooooo`;o00001oooool2o`000003ooooool0003o000001ko
oooo0_l0003Mooooo`;o00001?ooool2o`00037ooooo000Nooooo`03o`000?oooooooooo00oooooo
0_l0000nooooo`;o0000=Oooool2o`000;;ooooo0_l0000;ooooo`007_ooool00ol0003ooooooooo
o`0Aooooo`;o0000??ooool2o`0003Gooooo0_l0000Rooooo`;o00007_ooool2o`00013ooooo0_l0
0007ooooo`;o00002?ooool2o`0001Kooooo0_l0000Dooooo`;o00006oooool2o`0000_ooooo000N
ooooo`03o`000?oooooooooo017ooooo0_l0000Vooooo`;o0000Koooool2o`0000Cooooo0_l0000?
ooooo`;o00001oooool2o`00013ooooo0_l00007ooooo`;o00002?ooool2o`0000kooooo0_l00006
ooooo`;o00005?ooool2o`0002Sooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0000Ooooo
o`;o00004_ooool2o`0000Cooooo0_l0001_ooooo`;o00003oooool2o`0001Wooooo0_l0000Qoooo
o`;o0000A_ooool001kooooo00?o0000ooooooooool01?ooool2o`0001oooooo0_l0000Hooooo`;o
00006_ooool2o`0004Gooooo0_l0000;ooooo`;o0000?Oooool2o`0005Oooooo000Nooooo`03o`00
0?oooooooooo05_ooooo0_l00015ooooo`;o00002oooool2o`0001Cooooo0_l0000Wooooo`;o0000
B_ooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo01_ooooo0_l0002Booooo`;o00005?oo
ool2o`0002Cooooo0_l00006ooooo`;o0000=Oooool2o`0000kooooo0_l0000;ooooo`000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0
1_ooool00ol0003oooooooooo`0Kooooo`;o0000M_ooool2o`00017ooooo0_l0000cooooo`;o0000
3_ooool2o`0000Kooooo0_l0000eooooo`;o00006oooool000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000oooooooo
ool04oooool2o`0000Oooooo0_l000000ooooooo0000o`00000Zooooo`;o00000oooool2o`0003Go
oooo0_l0000:ooooo`;o00004Oooool2o`0003?ooooo0_l0001Zooooo`000oooool01Ol@413ooooo
oooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o00004oooool2o`00
00Oooooo0_l000000ooooooo0000o`00000@ooooo`;o00006?ooool2o`0000?ooooo0_l0000eoooo
o`;o00009oooool3o`0000gooooo0_l0000Cooooo`;o00008_ooool2o`0004cooooo0003ooooo`05
o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000
ooooooooool0<Oooool2o`0007gooooo0ol0000=ooooo`;o00002?ooool2o`0000Wooooo0_l0000Q
ooooo`?o0000=?ooool2o`0001Kooooo0003ooooo`05o`000?ooooooooooooooool000002oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0b_ooool2o`0002cooooo0ol0
000Tooooo`;o00003_ooool2o`0001Kooooo0003ooooo`05oa0@4?ooooooooooooooool@41002ooo
ool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0oooooolPooooo`;o0000
9_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l0
00001_ooool00ol0003oooooooooo`0[ooooo`;o00002oooool2o`000;;ooooo0_l0001@ooooo`;o
00001oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@
4?nYZJT01_ooool00ol0003oooooooooo`0[ooooo`;o00002oooool3o`0000Cooooo0_l0000Hoooo
o`;o0000??ooool2o`0005?ooooo0_l0000Hooooo`;o0000=_ooool2o`0000Oooooo000Nooooo`03
o`000?oooooooooo03Wooooo0_l00004ooooo`;o00006?ooool2o`0002kooooo0_l0000<ooooo`;o
0000;?ooool2o`0003oooooo0_l0000oooooo`007_ooool00ol0003oooooooooo`12ooooo`;o0000
AOooool2o`0003[ooooo0_l0001iooooo`;o00001Oooool001kooooo00?o0000ooooooooool0@_oo
ool2o`0004?ooooo0_l0000nooooo`;o0000??ooool2o`0003Wooooo0_l00005ooooo`007_ooool0
0ol0003oooooooooo`0Qooooo`;o00004_ooool2o`00053ooooo0_l0000jooooo`;o00000_ooool4
o`0003[ooooo0_l00010ooooo`007_ooool00ol0003oooooooooo`0Qooooo`;o00003oooool2o`00
0003ooooool0003o000002oooooo0_l0001Kooooo`;o00001?ooool2o`0004kooooo0_l0000/oooo
o`007_ooool00ol0003oooooooooo`0booooo`;o0000<_ooool2o`00027ooooo0_l0001Iooooo`;o
0000<oooool2o`0002cooooo000Nooooo`03o`000?oooooooooo023ooooo0_l0000Sooooo`;o0000
@_ooool2o`0000kooooo0_l00019ooooo`;o0000HOooool001kooooo00?o0000ooooooooool08?oo
ool2o`0002?ooooo0_l0001Booooo`;o00003?ooool2o`0004Cooooo0_l00003ooooo`;o00006Ooo
ool2o`0003Sooooo000Nooooo`?o0000Yoooool2o`0004Cooooo0_l00003ooooo`;o00001_ooool2
o`0000gooooo0_l00002ooooo`;o00002?ooool2o`0001Gooooo0_l0000Gooooo`007_ooool3o`00
01[ooooo0_l00002ooooo`;o0000f_ooool2o`0000gooooo0_l0000<ooooo`;o00005Oooool2o`00
01Oooooo000Nooooo`03o`000?oooooooooo01[ooooo0_l00002ooooo`;o0000;Oooool2o`0008co
oooo0_l0001Zooooo`007_ooool2o`0004kooooo0_l0000@ooooo`;o00009_ooool2o`00053ooooo
1?l0001Zooooo`007_ooool00ol0003oooooooooo`1Oooooo`;o00008Oooool2o`0000?ooooo0_l0
000Mooooo`;o00005?ooool2o`000003ooooool0003o000000gooooo0_l00005ooooo`;o00000_oo
ool2o`0006cooooo000Nooooo`03o`000?oooooooooo08;ooooo0_l0000Rooooo`;o00005?ooool5
o`0000gooooo0_l00005ooooo`;o0000L?ooool001kooooo00?o0000ooooooooool0D_ooool2o`00
06Wooooo0_l00028ooooo`007_ooool00ol0003oooooooooo`1Booooo`;o00000_ooool2o`000<_o
oooo0_l0000Rooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o0000?oooool2o`0002Oooooo
0_l00015ooooo`;o0000>oooool2o`0001kooooo0_l0000Rooooo`007_ooool00ol0003ooooooooo
o`0Eooooo`;o0000J?ooool2o`0004Gooooo0_l0000Eooooo`;o00005?ooool2o`0000kooooo1?l0
000cooooo`;o00002oooool001kooooo00?o0000ooooooooool01_ooool2o`0002?ooooo0_l00006
ooooo`;o0000Z?ooool2o`0000Sooooo0_l0000:ooooo`;o00002?ooool2o`0000Kooooo0_l0000c
ooooo`;o00002oooool001kooooo00?o0000ooooooooool01_ooool2o`0002?ooooo0_l00006oooo
o`;o0000@?ooool2o`00073ooooo0_l0000Dooooo`;o0000B?ooool001kooooo00?o0000oooooooo
ool0MOooool2o`0006kooooo0_l00012ooooo`;o00007?ooool001kooooo00?o0000ooooooooool0
Z_ooool2o`0003Wooooo0_l0000hooooo`;o00002?ooool2o`0001cooooo000Nooooo`03o`000?oo
oooooooo01Gooooo0_l0002Cooooo`;o0000Loooool2o`0000oooooo0_l0000Eooooo`007_ooool0
0ol0003oooooooooo`02ooooo`;o00004Oooool2o`000?gooooo0_l0000Jooooo`;o00005Oooool0
01kooooo00?o0000ooooooooool00_ooool2o`0001Kooooo0_l0002[ooooo`;o00007?ooool4o`00
01oooooo0_l0000:ooooo`;o00006_ooool2o`0001Gooooo000Nooooo`03o`000?oooooooooo01[o
oooo0_l0001_ooooo`;o0000>_ooool2o`0001cooooo1?l0000Oooooo`;o00007_ooool2o`0001go
oooo000Nooooo`03o`000?oooooooooo08_ooooo0_l00018ooooo`;o00003Oooool2o`00033ooooo
0_l0000@ooooo`;o00007Oooool001kooooo0_l0002?ooooo`;o0000AOooool2o`0000gooooo0_l0
000_ooooo`?o0000;oooool001kooooo00?o0000ooooooooool0S_ooool2o`0000Kooooo0_l0001m
ooooo`;o00003_ooool2o`00023ooooo000Nooooo`03o`000?oooooooooo05Wooooo0_l0000koooo
o`;o00000_ooool3o`0004gooooo0_l0000iooooo`;o00001?ooool2o`00017ooooo0_l00007oooo
o`007_ooool00ol0003oooooooooo`0>ooooo`;o00003oooool2o`0000Cooooo0_l0000booooo`;o
0000?oooool3o`0000Oooooo0_l0000;ooooo`;o00007Oooool2o`0001Sooooo0_l0000oooooo`;o
00004Oooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo00kooooo0_l0000?ooooo`;o0000
1?ooool2o`00063ooooo0_l0000Kooooo`;o00002oooool2o`0000Sooooo0_l0000Cooooo`;o0000
=Oooool2o`0003kooooo000Nooooo`03o`000?oooooooooo00;o0000;_ooool2o`0003;ooooo0_l0
000Qooooo`;o0000<_ooool2o`0004;ooooo0_l00006ooooo`;o00008?ooool2o`0001cooooo000N
ooooo`03o`000?oooooooooo00;o0000;_ooool2o`0001Kooooo0_l0000Jooooo`;o00008oooool2
o`0000?ooooo0_l0000Rooooo`;o0000>oooool2o`0000kooooo0_l0000Mooooo`;o00002Oooool2
o`0001cooooo000Nooooo`03o`000?oooooooooo04Sooooo0_l0000oooooo`;o00000oooool2o`00
02;ooooo0_l00002ooooo`;o0000=oooool4o`0002_ooooo0_l0000Gooooo`;o00003_ooool001ko
oooo00?o0000ooooooooool05_ooool2o`0000Cooooo0_l0002Hooooo`;o0000>Oooool2o`0002Ko
oooo0_l0000Looooo`;o00003_ooool001kooooo00?o0000ooooooooool05Oooool3o`0000Cooooo
0_l0000Fooooo`;o0000Qoooool2o`0005[ooooo0_l0000/ooooo`007_ooool00ol0003ooooooooo
o`0?ooooo`;o00001?ooool2o`0001gooooo0_l00005ooooo`;o0000N?ooool2o`0000Kooooo0_l0
0028ooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o00006Oooool2o`0000oooooo0_l0001h
ooooo`;o0000T?ooool001kooooo00?o0000ooooooooool0:_ooool2o`000?oooooo0Oooool2o`00
01Wooooo000Nooooo`03o`000?oooooooooo057ooooo0_l0003Iooooo`;o00001Oooool2o`0001;o
oooo000Nooooo`03o`000?oooooooooo02Wooooo0_l00005ooooo`;o00007oooool2o`0001Cooooo
0_l00009ooooo`;o00005oooool2o`0004;ooooo0_l0001Rooooo`;o00004_ooool001kooooo00?o
0000ooooooooool0:Oooool2o`0000Gooooo0_l0000eooooo`;o00002Oooool2o`0000Wooooo0_l0
000<ooooo`;o0000@_ooool2o`00037ooooo0_l00013ooooo`007_ooool3o`00053ooooo0_l0000[
ooooo`;o0000Poooool2o`0004?ooooo000Nooooo`?o0000D?ooool2o`0000Cooooo0_l0002;oooo
o`;o00005Oooool2o`0004_ooooo000Nooooo`03o`000?oooooooooo05Kooooo0_l00027ooooo`;o
00000_ooool2o`0001Gooooo0_l0001;ooooo`007_ooool00ol0003oooooooooo`2=ooooo`;o0000
D?ooool2o`0003gooooo0_l0000?ooooo`;o00005_ooool001kooooo00?o0000ooooooooool0;Ooo
ool2o`0000kooooo0_l0001>ooooo`;o0000F_ooool2o`0003?ooooo0_l0000?ooooo`;o00005_oo
ool001kooooo00?o0000ooooooooool0;Oooool2o`0000kooooo0_l00008ooooo`;o00002Oooool2
o`0002kooooo0_l0000Dooooo`;o0000Coooool2o`0005cooooo000Nooooo`03o`000?oooooooooo
023ooooo0_l0000Uooooo`;o00002Oooool2o`0002kooooo0_l0000Dooooo`;o0000[Oooool001ko
oooo00?o0000ooooooooool08?ooool2o`0003Wooooo0_l0000Eooooo`;o0000@_ooool2o`0008oo
oooo000Nooooo`03o`000?oooooooooo057ooooo0_l00002ooooo`;o00001?ooool2o`0000Cooooo
0_l0000?ooooo`;o0000@_ooool2o`0008oooooo000Nooooo`03o`000?oooooooooo03Oooooo0_l0
000Hooooo`;o00000_ooool2o`0000[ooooo0_l000000ooooooo0000o`000002ooooo`;o0000Mooo
ool2o`0000Wooooo0_l0000oooooo`;o00002_ooool2o`0000cooooo000Nooooo`03o`000?oooooo
oooo03Oooooo0_l0000Pooooo`;o00002Oooool2o`0000;ooooo0_l0000Cooooo`;o0000H_ooool5
o`0000Kooooo0_l0000oooooo`;o00002_ooool2o`0000cooooo000Nooooo`03o`000?oooooooooo
00_ooooo1?l0001:ooooo`;o00008_ooool2o`0001;ooooo0_l0000Dooooo`;o0000>Oooool4o`00
067ooooo000Nooooo`03o`000?oooooooooo00_ooooo1?l00005ooooo`;o0000@Oooool2o`0001?o
oooo0_l0000Gooooo`;o00002_ooool2o`0001Cooooo0_l0000Nooooo`;o0000EOooool2o`0002Oo
oooo000Nooooo`03o`000?oooooooooo01Cooooo0_l00011ooooo`;o00004oooool2o`0001Oooooo
0_l00010ooooo`;o0000:oooool2o`0000?ooooo0_l0000Mooooo`;o00001?ooool2o`0001Sooooo
0_l0000=ooooo`005?ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0:ooo
ool2o`0007_ooooo0_l0000nooooo`;o00002_ooool2o`000003ooooool0003o000000;o00006Ooo
ool2o`0000;ooooo0_l0000Nooooo`;o00003Oooool001Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0[ooooo`;o0000Noooool2o`0003kooooo0_l0000=ooooo`;o00006oooool2
o`0000kooooo0_l0000Qooooo`005_ooool00ol0003oooooooooo`05ooooo`?o0000E?ooool2o`00
0<kooooo0_l0000Qooooo`005_ooool00ol0003oooooooooo`1Looooo`;o0000lOooool001Kooooo
00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000F
ooooo`03o`000?oooooooooo0?ooooooD?ooool001Cooooo00?oEEEEofIVI_l00000oooooomBoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.81781 .77253 Mdot
.84191 .23884 Mdot
.53597 .3465 Mdot
.8721 .24893 Mdot
.36522 .6434 Mdot
.32683 .02701 Mdot
.80551 .86893 Mdot
.04218 .20319 Mdot
.67821 .60458 Mdot
.71514 .98293 Mdot
.50097 .65344 Mdot
.68543 .86893 Mdot
.75967 .92582 Mdot
.89775 .61558 Mdot
.11994 .5216 Mdot
.98109 .28736 Mdot
.73552 .02006 Mdot
.67634 .16032 Mdot
.13885 .06141 Mdot
.44169 .09237 Mdot
.25555 .46777 Mdot
.73013 .14538 Mdot
.71083 .67265 Mdot
.87196 .20999 Mdot
.1638 .7574 Mdot
.77523 .75513 Mdot
.92544 .29834 Mdot
.85316 .46231 Mdot
.15599 .17657 Mdot
.22779 .47023 Mdot
.18806 .36651 Mdot
.70025 .49652 Mdot
.82645 .72978 Mdot
.06141 .2374 Mdot
.09543 .97336 Mdot
.30959 .95928 Mdot
.9194 .45395 Mdot
.34469 .12009 Mdot
.91166 .01358 Mdot
.39376 .71463 Mdot
.72495 .8572 Mdot
.14761 .39576 Mdot
.49798 .67304 Mdot
.41827 .87659 Mdot
.49313 .80221 Mdot
.31143 .65927 Mdot
.49996 .70322 Mdot
.12284 .55942 Mdot
.65926 .46761 Mdot
.63466 .46328 Mdot
.56674 .33747 Mdot
.1951 .72934 Mdot
.97569 .40166 Mdot
.15293 .38216 Mdot
.45189 .81684 Mdot
.68399 .58339 Mdot
.03665 .0616 Mdot
.41296 .91232 Mdot
.52444 .28926 Mdot
.36703 .22624 Mdot
.9182 .01527 Mdot
.55348 .92351 Mdot
.23526 .64274 Mdot
.21436 .13143 Mdot
.32861 .25972 Mdot
.15262 .88465 Mdot
.71604 .27215 Mdot
.48011 .35123 Mdot
.74061 .44893 Mdot
.97715 .328 Mdot
.17007 .02199 Mdot
.59841 .006 Mdot
.08061 .24091 Mdot
.95815 .32653 Mdot
.93058 .60322 Mdot
.5816 .06486 Mdot
.60767 .20048 Mdot
.46949 .09 Mdot
.98659 .99362 Mdot
.0111 .79122 Mdot
.35861 .48547 Mdot
.98167 .58 Mdot
.24113 .54953 Mdot
.31335 .35638 Mdot
.14117 .30654 Mdot
.31749 .30605 Mdot
.12823 .75924 Mdot
.58891 .10287 Mdot
.41553 .58782 Mdot
.21802 .91013 Mdot
.36567 .6014 Mdot
.1226 .02723 Mdot
.99987 .23957 Mdot
.24374 .54166 Mdot
.74432 .7076 Mdot
.91473 .22353 Mdot
.67837 .35144 Mdot
.58295 .99933 Mdot
.6458 .51168 Mdot
.71386 .79768 Mdot
.2084 .78476 Mdot
.67416 .78259 Mdot
.80512 .13746 Mdot
.4776 .67832 Mdot
.91281 .18852 Mdot
.26494 .17633 Mdot
.06811 .55958 Mdot
.46644 .91527 Mdot
.25422 .32978 Mdot
.85291 .00441 Mdot
.64287 .83151 Mdot
.21676 .27042 Mdot
.34233 .05148 Mdot
.50155 .38322 Mdot
.70681 .77867 Mdot
.03987 .79421 Mdot
.87311 .61342 Mdot
.7932 .66875 Mdot
.878 .19036 Mdot
.3106 .78333 Mdot
.6252 .85363 Mdot
.50586 .67608 Mdot
.96044 .9804 Mdot
.3388 .40978 Mdot
.58626 .8856 Mdot
.75113 .1434 Mdot
.10656 .20146 Mdot
.86479 .20912 Mdot
.19055 .66774 Mdot
.93007 .6321 Mdot
.30035 .6065 Mdot
.76406 .90386 Mdot
.93923 .79699 Mdot
.16969 .17258 Mdot
.88969 .82993 Mdot
.00314 .74476 Mdot
.31883 .73323 Mdot
.04767 .64997 Mdot
.29745 .46573 Mdot
.38937 .43401 Mdot
.02976 .73188 Mdot
.35665 .692 Mdot
.6758 .24133 Mdot
.74999 .84077 Mdot
.81424 .5391 Mdot
.4569 .55931 Mdot
.91906 .82482 Mdot
.47612 .98158 Mdot
.53582 .12206 Mdot
.31972 .23944 Mdot
.18234 .47075 Mdot
.99507 .99502 Mdot
.27037 .71594 Mdot
.65957 .11387 Mdot
.50083 .33264 Mdot
.97035 .36214 Mdot
.6685 .82863 Mdot
.5459 .75594 Mdot
.82182 .15343 Mdot
.98181 .77518 Mdot
.27567 .94458 Mdot
.57009 .53896 Mdot
.06635 .56332 Mdot
.7785 .59747 Mdot
.90245 .84689 Mdot
.07031 .47893 Mdot
.40409 .45514 Mdot
.16461 .07655 Mdot
.78403 .58635 Mdot
.83032 .41542 Mdot
.79673 .42554 Mdot
.85161 .75969 Mdot
.49792 .40983 Mdot
.08835 .10225 Mdot
.26628 .82659 Mdot
.22024 .63898 Mdot
.38334 .05833 Mdot
.08109 .10799 Mdot
.78078 .56804 Mdot
.83526 .95061 Mdot
.16432 .95401 Mdot
.9371 .6274 Mdot
.40974 .3339 Mdot
.20398 .77793 Mdot
.87947 .94673 Mdot
.25882 .7371 Mdot
.58301 .13442 Mdot
.89174 .95153 Mdot
.23108 .12514 Mdot
.73493 .99434 Mdot
.37764 .38032 Mdot
.83696 .94756 Mdot
.14454 .49135 Mdot
.6029 .44629 Mdot
.71948 .16707 Mdot
.5204 .5606 Mdot
.03345 .23015 Mdot
.30267 .84695 Mdot
.35925 .02505 Mdot
.55522 .73696 Mdot
.00455 .02652 Mdot
.81038 .86787 Mdot
.59388 .75899 Mdot
.06103 .97123 Mdot
.49998 .0654 Mdot
.45281 .67503 Mdot
.74686 .01819 Mdot
.04108 .9821 Mdot
.89671 .73229 Mdot
.54102 .09768 Mdot
.537 .60744 Mdot
.0404 .3869 Mdot
.44807 .54219 Mdot
.22164 .50002 Mdot
.89579 .9358 Mdot
.03778 .53303 Mdot
.39068 .75421 Mdot
.69417 .07264 Mdot
.60646 .8624 Mdot
.66536 .97709 Mdot
.88652 .06749 Mdot
.11979 .75008 Mdot
.28131 .43081 Mdot
.20823 .38564 Mdot
.91827 .93204 Mdot
.91156 .80069 Mdot
.1243 .90722 Mdot
.95741 .27542 Mdot
.76298 .08263 Mdot
.11486 .09886 Mdot
.05095 .30891 Mdot
.38971 .34703 Mdot
.11376 .38951 Mdot
.31423 .45699 Mdot
.77883 .02979 Mdot
.24108 .24076 Mdot
.75376 .18843 Mdot
.24153 .34315 Mdot
.72569 .28188 Mdot
.42788 .13021 Mdot
.89962 .98113 Mdot
.32803 .93013 Mdot
.80244 .72156 Mdot
.97141 .71717 Mdot
.69123 .15702 Mdot
.50524 .23434 Mdot
.78224 .21368 Mdot
.38363 .17635 Mdot
.19583 .14721 Mdot
.28095 .71006 Mdot
.3992 .994 Mdot
.76102 .49214 Mdot
.51043 .88815 Mdot
.63344 .63027 Mdot
.77155 .2855 Mdot
.75338 .82007 Mdot
.18984 .27329 Mdot
.07523 .39334 Mdot
.12504 .02636 Mdot
.57443 .44637 Mdot
.18288 .86915 Mdot
.52301 .69279 Mdot
.8932 .87473 Mdot
.67972 .15055 Mdot
.32347 .98584 Mdot
.21595 .67763 Mdot
.57803 .51267 Mdot
.47155 .8965 Mdot
.55155 .43885 Mdot
.28024 .46643 Mdot
.25115 .35764 Mdot
.68276 .87361 Mdot
.05442 .56363 Mdot
.03836 .28336 Mdot
.34292 .74833 Mdot
.39372 .15645 Mdot
.9524 .78971 Mdot
.27793 .31669 Mdot
.45387 .08439 Mdot
.97484 .54838 Mdot
.94908 .82482 Mdot
.53394 .09762 Mdot
.67996 .2595 Mdot
.95272 .3306 Mdot
.64094 .75552 Mdot
.99054 .07659 Mdot
.51633 .01306 Mdot
.57145 .88492 Mdot
.59484 .28644 Mdot
.22514 .53263 Mdot
.03943 .28207 Mdot
.43193 .07192 Mdot
.04042 .41373 Mdot
.60054 .8833 Mdot
.33743 .11806 Mdot
.78881 .53758 Mdot
.57989 .43751 Mdot
.749 .55268 Mdot
.15478 .28412 Mdot
.34962 .62013 Mdot
.73917 .87449 Mdot
.14647 .12647 Mdot
.67798 .68807 Mdot
.86678 .08649 Mdot
.49972 .28902 Mdot
.00952 .2189 Mdot
.03905 .12009 Mdot
.29785 .60529 Mdot
.53248 .68528 Mdot
.61763 .11217 Mdot
.40159 .45734 Mdot
.20727 .42912 Mdot
.82254 .63138 Mdot
.02694 .34909 Mdot
.30459 .01843 Mdot
.24604 .28817 Mdot
.92726 .70868 Mdot
.36603 .16283 Mdot
.59217 .70845 Mdot
.04501 .40201 Mdot
.21898 .88538 Mdot
.37757 .43983 Mdot
.88215 .35335 Mdot
.27911 .91306 Mdot
.01805 .82521 Mdot
.20692 .63445 Mdot
.65674 .83306 Mdot
.85813 .22276 Mdot
.94279 .96964 Mdot
.39381 .17841 Mdot
.29203 .51341 Mdot
.51161 .71027 Mdot
.17241 .49437 Mdot
.96211 .30638 Mdot
.27891 .02441 Mdot
.79109 .33878 Mdot
.10195 .14259 Mdot
.60052 .77253 Mdot
.39525 .50169 Mdot
.68171 .56617 Mdot
.41973 .36801 Mdot
.18174 .4188 Mdot
.16079 .9368 Mdot
.89583 .87961 Mdot
.01368 .56342 Mdot
.72976 .55954 Mdot
.8244 .39045 Mdot
.14111 .18683 Mdot
.76307 .14083 Mdot
.38494 .46617 Mdot
.36907 .88594 Mdot
.79698 .9797 Mdot
.86796 .60911 Mdot
.42862 .44825 Mdot
.72549 .53135 Mdot
.66159 .63858 Mdot
.54567 .00329 Mdot
.84096 .17671 Mdot
.61919 .69308 Mdot
.95098 .90248 Mdot
.92819 .35355 Mdot
.32225 .47814 Mdot
.62346 .71725 Mdot
.67141 .35484 Mdot
.78136 .16409 Mdot
.1737 .97134 Mdot
.00678 .62535 Mdot
.48153 .126 Mdot
.46952 .38299 Mdot
.74506 .01875 Mdot
.83973 .73151 Mdot
.99207 .27654 Mdot
.93929 .18999 Mdot
.45291 .94726 Mdot
.23872 .60248 Mdot
.88799 .39984 Mdot
.31018 .49617 Mdot
.68899 .7028 Mdot
.2739 .03449 Mdot
.29294 .30843 Mdot
.61908 .59149 Mdot
.49577 .19728 Mdot
.69379 .87132 Mdot
.6514 .91503 Mdot
.90877 .60692 Mdot
.03144 .11724 Mdot
.57694 .8622 Mdot
.09734 .75643 Mdot
.36196 .35459 Mdot
.46506 .03202 Mdot
.94092 .37117 Mdot
.19586 .73025 Mdot
.21862 .65845 Mdot
.76656 .3624 Mdot
.45487 .90529 Mdot
.12228 .30188 Mdot
.54094 .33068 Mdot
.08042 .29479 Mdot
.79052 .55159 Mdot
.97412 .58109 Mdot
.57282 .19201 Mdot
.32621 .51828 Mdot
.70533 .00036 Mdot
.15674 .70406 Mdot
.31647 .31216 Mdot
.32522 .33521 Mdot
.02569 .35735 Mdot
.36952 .99534 Mdot
.33915 .00094 Mdot
.40458 .64894 Mdot
.45096 .41728 Mdot
.43876 .25109 Mdot
.78011 .12772 Mdot
.04085 .79731 Mdot
.25115 .01866 Mdot
.99694 .09508 Mdot
.87372 .8993 Mdot
.48299 .83039 Mdot
.08791 .41576 Mdot
.19901 .87492 Mdot
.56208 .40802 Mdot
.91049 .19335 Mdot
.24072 .07524 Mdot
.24195 .93476 Mdot
.29736 .98783 Mdot
.12927 .20172 Mdot
.21913 .83463 Mdot
.15034 .31428 Mdot
.30687 .93769 Mdot
.73106 .54261 Mdot
.39051 .48683 Mdot
.53975 .66375 Mdot
.79104 .17021 Mdot
.8832 .47093 Mdot
.47315 .98951 Mdot
.4669 .57427 Mdot
.09905 .17777 Mdot
.27402 .26937 Mdot
.98001 .27753 Mdot
.17335 .08855 Mdot
.597 .30393 Mdot
.57111 .55768 Mdot
.29823 .81322 Mdot
.96725 .9518 Mdot
.51261 .65144 Mdot
.17092 .5052 Mdot
.02283 .60643 Mdot
.76776 .85619 Mdot
.97607 .44408 Mdot
.23398 .478 Mdot
.00798 .0683 Mdot
.12145 .451 Mdot
.56698 .81319 Mdot
.35937 .95227 Mdot
.27114 .94803 Mdot
.40546 .84893 Mdot
.71708 .17655 Mdot
.23301 .53425 Mdot
.58553 .63082 Mdot
.54392 .79217 Mdot
.70913 .25301 Mdot
.24237 .32037 Mdot
.48969 .06429 Mdot
.25324 .80102 Mdot
.04586 .27392 Mdot
.83632 .7997 Mdot
.89147 .22008 Mdot
.41698 .81131 Mdot
.05809 .87313 Mdot
.01284 .41374 Mdot
.45253 .20461 Mdot
.40132 .50742 Mdot
.86017 .17609 Mdot
.12995 .40496 Mdot
.16966 .09165 Mdot
.97459 .58595 Mdot
.13233 .93178 Mdot
.07598 .7175 Mdot
.34223 .61949 Mdot
.83112 .85803 Mdot
.27989 .65556 Mdot
.51818 .47339 Mdot
.94714 .46505 Mdot
.10977 .01976 Mdot
.02116 .43485 Mdot
.04458 .66441 Mdot
.87662 .21891 Mdot
.21684 .08999 Mdot
.81396 .39406 Mdot
.12495 .24753 Mdot
.4401 .63872 Mdot
.24298 .54819 Mdot
.09374 .14359 Mdot
.8038 .04325 Mdot
.40202 .63552 Mdot
.7277 .06816 Mdot
.28014 .38746 Mdot
.54094 .45679 Mdot
.46169 .94315 Mdot
.48239 .29175 Mdot
.74536 .77427 Mdot
.50293 .98876 Mdot
.4214 .0442 Mdot
.1567 .47438 Mdot
.30752 .96117 Mdot
.47038 .63016 Mdot
.85384 .35231 Mdot
.86076 .54115 Mdot
.48856 .06052 Mdot
.09388 .07632 Mdot
.15558 .1703 Mdot
.5405 .81906 Mdot
.38062 .36057 Mdot
.17611 .694 Mdot
.05968 .42863 Mdot
.92451 .09981 Mdot
.77809 .45087 Mdot
.51267 .55158 Mdot
.97701 .95268 Mdot
.73724 .04611 Mdot
.27351 .75845 Mdot
.82635 .83441 Mdot
.26629 .65222 Mdot
.14032 .0689 Mdot
.82209 .38636 Mdot
.09076 .46794 Mdot
.93709 .94822 Mdot
.13337 .45562 Mdot
.14848 .47945 Mdot
.46889 .77607 Mdot
.33404 .69785 Mdot
.80563 .73685 Mdot
.98178 .85192 Mdot
.0453 .70646 Mdot
.7649 .27974 Mdot
.72022 .50763 Mdot
.95871 .00235 Mdot
.71387 .92727 Mdot
.95406 .00152 Mdot
.64986 .7668 Mdot
.68709 .47495 Mdot
.88952 .91351 Mdot
.55598 .80731 Mdot
.28274 .23266 Mdot
.53027 .01506 Mdot
.17094 .62722 Mdot
.52091 .77848 Mdot
.52332 .17058 Mdot
.78046 .84933 Mdot
.75755 .06229 Mdot
.73514 .75831 Mdot
.25715 .18974 Mdot
.85354 .33343 Mdot
.23155 .25021 Mdot
.40231 .57427 Mdot
.12765 .92547 Mdot
.84165 .45596 Mdot
.8294 .43703 Mdot
.23407 .85292 Mdot
.42408 .38562 Mdot
.65598 .02641 Mdot
.50094 .1781 Mdot
.7991 .27689 Mdot
.18557 .96525 Mdot
.06415 .08135 Mdot
.824 .66765 Mdot
.4608 .62094 Mdot
.63105 .67398 Mdot
.71174 .10436 Mdot
.81249 .29686 Mdot
.30634 .16128 Mdot
.54634 .11053 Mdot
.76358 .26709 Mdot
.89163 .84507 Mdot
.93872 .84917 Mdot
.85848 .8291 Mdot
.05019 .88865 Mdot
.73601 .16871 Mdot
.49504 .35891 Mdot
.08959 .37515 Mdot
.70229 .12908 Mdot
.38651 .97888 Mdot
.44891 .86921 Mdot
.61464 .05084 Mdot
.51038 .84192 Mdot
.91987 .24215 Mdot
.59421 .7991 Mdot
.10961 .33669 Mdot
.50772 .0738 Mdot
.12007 .25602 Mdot
.17355 .69119 Mdot
.95899 .73866 Mdot
.27165 .59027 Mdot
.73203 .64493 Mdot
.98932 .52066 Mdot
.06572 .78884 Mdot
.42457 .7264 Mdot
.35363 .57965 Mdot
.71052 .95845 Mdot
.23373 .2362 Mdot
.20639 .79599 Mdot
.06215 .90667 Mdot
.025 .09929 Mdot
.09036 .11188 Mdot
.74604 .57327 Mdot
.33404 .3258 Mdot
.66667 .01223 Mdot
.2126 .6206 Mdot
.08201 .2268 Mdot
.00044 .203 Mdot
.52766 .27346 Mdot
.63505 .822 Mdot
.22281 .26585 Mdot
.50875 .02251 Mdot
.17586 .08592 Mdot
.53401 .87273 Mdot
.64771 .50722 Mdot
.16445 .36184 Mdot
.92818 .62177 Mdot
.09521 .79454 Mdot
.93557 .40369 Mdot
.02799 .65095 Mdot
.39302 .34141 Mdot
.51127 .64716 Mdot
.04579 .97857 Mdot
.88043 .62598 Mdot
.88141 .70918 Mdot
.4571 .86507 Mdot
.2176 .09981 Mdot
.2524 .29015 Mdot
.18628 .60432 Mdot
.23368 .48629 Mdot
.35064 .13996 Mdot
.09419 .95703 Mdot
.94576 .88442 Mdot
.62458 .15056 Mdot
.67494 .01418 Mdot
.81009 .59024 Mdot
.82573 .30458 Mdot
.26973 .85725 Mdot
.61087 .04118 Mdot
.04537 .3081 Mdot
.38947 .32147 Mdot
.67053 .87314 Mdot
.11608 .28767 Mdot
.74679 .92439 Mdot
.17532 .28786 Mdot
.98265 .55152 Mdot
.30208 .30714 Mdot
.30763 .02709 Mdot
.61903 .05139 Mdot
.9533 .18745 Mdot
.8974 .01375 Mdot
.03446 .90374 Mdot
.50473 .61175 Mdot
.11974 .00161 Mdot
.52868 .51625 Mdot
.36655 .066 Mdot
.25984 .14651 Mdot
.54791 .63263 Mdot
.67415 .00295 Mdot
.13857 .61976 Mdot
.22466 .02433 Mdot
.19806 .26228 Mdot
.28486 .9886 Mdot
.22463 .61986 Mdot
.76067 .40355 Mdot
.0817 .38792 Mdot
.44255 .82682 Mdot
.69 .43019 Mdot
.12403 .64502 Mdot
.22124 .79105 Mdot
.39309 .7495 Mdot
.07888 .07694 Mdot
.03497 .76009 Mdot
.74861 .7505 Mdot
.8427 .93195 Mdot
.61041 .37425 Mdot
.95658 .51541 Mdot
.52386 .81319 Mdot
.52811 .61363 Mdot
.78576 .66514 Mdot
.48776 .99003 Mdot
.55853 .89311 Mdot
.11061 .38661 Mdot
.5564 .69849 Mdot
.11536 .48246 Mdot
.72502 .82291 Mdot
.2114 .66313 Mdot
.14291 .61699 Mdot
.35817 .0239 Mdot
.63769 .8604 Mdot
.77573 .2546 Mdot
.00998 .27743 Mdot
.25854 .23034 Mdot
.26407 .43502 Mdot
.26011 .97786 Mdot
.70076 .78543 Mdot
.08804 .52865 Mdot
.79943 .8539 Mdot
.97614 .92588 Mdot
.81969 .25631 Mdot
.63205 .8938 Mdot
.87837 .3522 Mdot
.79351 .53213 Mdot
.06485 .12613 Mdot
.47244 .21188 Mdot
.75815 .71503 Mdot
.35303 .1726 Mdot
.00243 .80134 Mdot
.20018 .59764 Mdot
.129 .04295 Mdot
.35409 .73547 Mdot
.57566 .92821 Mdot
.75204 .8474 Mdot
.59119 .44154 Mdot
.95102 .44242 Mdot
.419 .44216 Mdot
.42341 .09647 Mdot
.74747 .84159 Mdot
.01019 .09478 Mdot
.83472 .91099 Mdot
.79049 .47314 Mdot
.63005 .76391 Mdot
.42627 .76482 Mdot
.04787 .91136 Mdot
.42011 .95184 Mdot
.41078 .53976 Mdot
.41623 .579 Mdot
.90039 .01836 Mdot
.18656 .56007 Mdot
.22097 .26771 Mdot
.0014 .47905 Mdot
.34013 .53512 Mdot
.34614 .00934 Mdot
.89899 .77414 Mdot
.00411 .41924 Mdot
.80404 .69214 Mdot
.52223 .34276 Mdot
.35847 .27288 Mdot
.05984 .69536 Mdot
.37725 .17378 Mdot
.03747 .18302 Mdot
.10073 .80488 Mdot
.82358 .70554 Mdot
.63131 .47505 Mdot
.48894 .71549 Mdot
.92994 .69221 Mdot
.29299 .4777 Mdot
.0692 .88281 Mdot
.93336 .05752 Mdot
.8106 .48569 Mdot
.89527 .29101 Mdot
.45967 .32697 Mdot
.93673 .00027 Mdot
.17099 .43895 Mdot
.89565 .12587 Mdot
.55485 .84765 Mdot
.5188 .42793 Mdot
.67519 .34584 Mdot
.06984 .01488 Mdot
.67634 .33009 Mdot
.28768 .92405 Mdot
.01072 .89847 Mdot
.55995 .74879 Mdot
.55411 .74708 Mdot
.60853 .71505 Mdot
.31162 .33221 Mdot
.80013 .65346 Mdot
.89897 .45846 Mdot
.21326 .13502 Mdot
.12535 .16946 Mdot
.15972 .08088 Mdot
.48257 .67193 Mdot
.83372 .15299 Mdot
.51648 .83534 Mdot
.2493 .42952 Mdot
.01812 .17536 Mdot
.6595 .79356 Mdot
.69269 .68737 Mdot
.79366 .25647 Mdot
.96976 .1029 Mdot
.57799 .11239 Mdot
.03375 .06566 Mdot
.41352 .79891 Mdot
.51647 .25242 Mdot
.45999 .63131 Mdot
.01006 .45514 Mdot
.17063 .09921 Mdot
.8089 .56678 Mdot
.47154 .48096 Mdot
.12768 .86657 Mdot
.73322 .15151 Mdot
.9555 .58262 Mdot
.18843 .28564 Mdot
.04524 .773 Mdot
.72391 .39442 Mdot
.64453 .30395 Mdot
.2107 .79282 Mdot
.59071 .85893 Mdot
.06658 .62867 Mdot
.90244 .44714 Mdot
.44993 .29156 Mdot
.67467 .54434 Mdot
.65828 .03912 Mdot
.79517 .00578 Mdot
.44589 .65266 Mdot
.68255 .31091 Mdot
.58917 .31136 Mdot
.05023 .83952 Mdot
.47287 .41773 Mdot
.36558 .95777 Mdot
.44399 .82693 Mdot
.46557 .74381 Mdot
.05812 .50421 Mdot
.80895 .04675 Mdot
.36442 .63787 Mdot
.06888 .24331 Mdot
.90116 .87421 Mdot
.58734 .96566 Mdot
.26207 .70973 Mdot
.54406 .12319 Mdot
.96257 .2947 Mdot
.05305 .00819 Mdot
.22914 .51087 Mdot
.31779 .22789 Mdot
.35821 .85345 Mdot
.68673 .19045 Mdot
.84747 .28985 Mdot
.47946 .8932 Mdot
.01736 .24021 Mdot
.9913 .98739 Mdot
.75379 .56747 Mdot
.48055 .03488 Mdot
.90252 .27502 Mdot
.44675 .94897 Mdot
.493 .99053 Mdot
.05304 .76745 Mdot
.23615 .0796 Mdot
.37034 .62538 Mdot
.16819 .71491 Mdot
.86695 .60946 Mdot
.37067 .51476 Mdot
.01486 .74057 Mdot
.58578 .80313 Mdot
.48958 .85107 Mdot
.80212 .37555 Mdot
.94787 .85729 Mdot
.43427 .62833 Mdot
.11473 .00273 Mdot
.25597 .41169 Mdot
.71534 .57864 Mdot
.98805 .72072 Mdot
.67453 .81653 Mdot
.73435 .19891 Mdot
.8058 .9262 Mdot
.05068 .40636 Mdot
.41855 .161 Mdot
.18967 .98656 Mdot
.36215 .50077 Mdot
.96517 .49228 Mdot
.37512 .32276 Mdot
.62191 .06041 Mdot
.72989 .95645 Mdot
.74389 .24623 Mdot
.93727 .21973 Mdot
.05783 .84691 Mdot
.07968 .11351 Mdot
.89067 .56019 Mdot
.8033 .97717 Mdot
.64075 .49506 Mdot
.41011 .57563 Mdot
.70426 .02553 Mdot
.05941 .13599 Mdot
.08988 .93879 Mdot
.29054 .0167 Mdot
.58473 .72396 Mdot
.42032 .00034 Mdot
.52993 .67079 Mdot
.23746 .81942 Mdot
.48307 .19659 Mdot
.3986 .85047 Mdot
.73579 .8051 Mdot
.12323 .40194 Mdot
.06967 .71882 Mdot
.16001 .23268 Mdot
.95966 .85341 Mdot
.9258 .05824 Mdot
.43903 .27602 Mdot
.65448 .27184 Mdot
.96099 .5703 Mdot
.24873 .46896 Mdot
.41964 .21562 Mdot
.98836 .59017 Mdot
.64852 .54599 Mdot
.58578 .31064 Mdot
.5615 .6603 Mdot
.67956 .01384 Mdot
.68352 .60482 Mdot
.58592 .85712 Mdot
.3746 .43383 Mdot
.98224 .70879 Mdot
.40013 .05343 Mdot
.68496 .19678 Mdot
.1044 .75047 Mdot
.81857 .49931 Mdot
.41212 .27969 Mdot
.87195 .28702 Mdot
.79857 .83919 Mdot
.45228 .15485 Mdot
.99921 .227 Mdot
.85544 .40415 Mdot
.7088 .69413 Mdot
.98281 .90906 Mdot
.15237 .81456 Mdot
.29208 .7704 Mdot
.17591 .92426 Mdot
.64727 .2861 Mdot
.93841 .57339 Mdot
.52879 .06232 Mdot
.17215 .9502 Mdot
.06601 .78905 Mdot
.07498 .6526 Mdot
.3446 .26098 Mdot
.4358 .07546 Mdot
.29199 .40248 Mdot
.13131 .19701 Mdot
.07796 .77278 Mdot
.11357 .3407 Mdot
.37652 .46504 Mdot
.07392 .63099 Mdot
.03147 .43376 Mdot
.07388 .77976 Mdot
.7694 .6618 Mdot
.95396 .07601 Mdot
.66947 .21779 Mdot
.52818 .04391 Mdot
.20358 .79081 Mdot
.20674 .71907 Mdot
.16434 .03178 Mdot
.28637 .59562 Mdot
.73651 .55055 Mdot
.14106 .77174 Mdot
.8454 .27142 Mdot
.01495 .10274 Mdot
.8911 .48358 Mdot
.05889 .06373 Mdot
.38798 .23198 Mdot
.53112 .07455 Mdot
.18818 .49915 Mdot
.26474 .34574 Mdot
.85214 .37317 Mdot
.16208 .80201 Mdot
.35374 .62579 Mdot
.96719 .01809 Mdot
.40202 .53937 Mdot
.88575 .94291 Mdot
.60013 .90049 Mdot
.83324 .74906 Mdot
.24587 .70771 Mdot
.16981 .77099 Mdot
.06691 .18002 Mdot
.77879 .63188 Mdot
.02204 .89534 Mdot
.60669 .78996 Mdot
.80514 .31268 Mdot
.78684 .82269 Mdot
.19959 .7201 Mdot
.93758 .8399 Mdot
.74867 .89112 Mdot
.02702 .21719 Mdot
.47089 .20373 Mdot
.86141 .2803 Mdot
.34274 .95944 Mdot
.1455 .80639 Mdot
.26308 .93086 Mdot
.28166 .09884 Mdot
.54325 .63098 Mdot
.4811 .16779 Mdot
.29888 .68147 Mdot
.64618 .19054 Mdot
.66681 .07361 Mdot
.66118 .09905 Mdot
.23417 .90608 Mdot
.78528 .70278 Mdot
.07448 .97297 Mdot
.73998 .00923 Mdot
.63141 .97645 Mdot
.29896 .9482 Mdot
.09496 .38618 Mdot
.68998 .63248 Mdot
.79461 .66815 Mdot
.05682 .28717 Mdot
.05378 .58908 Mdot
.47983 .15184 Mdot
.67358 .79099 Mdot
.85462 .3636 Mdot
.62516 .90026 Mdot
.19425 .31005 Mdot
.15516 .82478 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool01?l0003oooooooooooooool4o`0000Sooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool02Oooool2o`0000;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03oooo
o`;o00002?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo0ol0000@oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo0ol0000=oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool2o`0000kooooo00?o0000oooo
ooooool02?ooool2o`0000?ooooo1Ol0000<ooooo`03o`000?oooooooooo00;ooooo000Nooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool01?l0003oooooooooooooool4o`00
00Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`?o00003_ooool3o`00
00oooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0;ooooo`;o000000?oooooo`000?ooool03_ooool2o`0000kooooo00?o0000oooo
ooooool03Oooool5o`0000cooooo00?o0000ooooooooool00_ooool001kooooo00?o0000oooooooo
ool03Oooool2o`0005gooooo0_l0001@ooooo`;o0000;?ooool2o`00013ooooo0_l00017ooooo`00
7_ooool00ol0003oooooooooo`0=ooooo`;o0000GOooool2o`0003Kooooo0_l0000_ooooo`;o0000
5Oooool2o`0003Kooooo0_l0000Qooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o0000AOoo
ool2o`0004Sooooo0_l00002ooooo`;o0000:oooool6o`0004Gooooo0_l00002ooooo`Co00007ooo
ool001kooooo00?o0000ooooooooool04oooool2o`0000_ooooo0_l0000/ooooo`;o00002_ooool2
o`0000?ooooo0_l00017ooooo`;o0000;Oooool4o`0001?ooooo0ol0000_ooooo`?o00000oooool2
o`0000kooooo0_l0000?ooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o00004Oooool2o`00
01Wooooo0_l0000?ooooo`;o0000@?ooool2o`0004Sooooo0_l000001?oooooo0000o`000?l0000`
ooooo`;o00004oooool2o`0000oooooo000Nooooo`03o`000?oooooooooo03?ooooo0_l0000@oooo
o`;o00004?ooool2o`0001Oooooo0ol0000^ooooo`;o0000?_ooool2o`0000Sooooo0_l0001Joooo
o`007_ooool2o`0002Gooooo0ol0000Nooooo`;o00004?ooool2o`0000Oooooo0_l00004ooooo`;o
00002?ooool3o`0005kooooo0_l0000>ooooo`;o0000I?ooool001kooooo0_l0000Uooooo`?o0000
2_ooool2o`0002gooooo0_l00004ooooo`;o0000:oooool2o`0003cooooo0_l0000Vooooo`;o0000
C?ooool001kooooo00?o0000ooooooooool0<Oooool2o`0002;ooooo0_l0000looooo`;o00000ooo
ool2o`0005oooooo0_l0001<ooooo`007_ooool00ol0003oooooooooo`1Eooooo`;o0000@Oooool2
o`000:gooooo000Nooooo`03o`000?oooooooooo0<;ooooo0_l0000>ooooo`;o0000Loooool001ko
oooo00?o0000ooooooooool09_ooool2o`0005gooooo0_l0000Qooooo`;o00006?ooool2o`0000ko
oooo0_l0000]ooooo`;o0000A?ooool001kooooo00?o0000ooooooooool09_ooool2o`0005gooooo
0_l0000Qooooo`;o0000@_ooool2o`0001?ooooo1?l00012ooooo`007_ooool00ol0003ooooooooo
o`3/ooooo`;o00005Oooool2o`0004;ooooo000Nooooo`;o0000K?ooool2o`00017ooooo0_l00014
ooooo`?o0000P?ooool001kooooo00?o0000ooooooooool0Joooool2o`00017ooooo0_l00014oooo
o`?o0000P?ooool001kooooo00?o0000ooooooooool0NOooool2o`000:kooooo1?l0000Jooooo`00
7_ooool00ol0003oooooooooo`08ooooo`;o00007oooool2o`0004kooooo0_l0000Pooooo`;o0000
2oooool2o`0001cooooo0_l0000Zooooo`;o0000=Oooool4o`0001[ooooo000Nooooo`03o`000?oo
oooooooo00Oooooo0ol00005ooooo`;o00006?ooool2o`0004Sooooo0_l0000Vooooo`;o000000?o
ooooo`000?l000002?ooool2o`0000oooooo0_l0000;ooooo`;o0000:_ooool2o`0005?ooooo000N
ooooo`?o00001oooool2o`0000Kooooo0_l0000Iooooo`;o0000Aoooool2o`0002Kooooo0_l00000
0ooooooo0000o`00000Iooooo`;o0000;Oooool2o`0003;ooooo0_l0000Yooooo`007_ooool3o`00
02[ooooo0_l0001Looooo`;o0000G_ooool2o`0003;ooooo0_l0000Yooooo`007_ooool00ol0003o
ooooooooo`1:ooooo`;o0000??ooool2o`0001Oooooo0_l00006ooooo`;o0000:_ooool2o`0000Oo
oooo0_l0001Wooooo`007_ooool00ol0003oooooooooo`0Fooooo`;o00000_ooool2o`0001Gooooo
0_l0000Gooooo`;o0000?_ooool2o`0001Gooooo0_l00006ooooo`;o0000:_ooool2o`0000Oooooo
0_l0001Booooo`;o00002_ooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo017ooooo0_l0
0003ooooo`;o00000_ooool2o`0001Cooooo0ol0000Fooooo`;o0000?oooool2o`000:Kooooo0_l0
000:ooooo`;o00001oooool001kooooo00?o0000ooooooooool04Oooool2o`0001gooooo0_l0000G
ooooo`;o0000A?ooool2o`0006?ooooo0_l0001Aooooo`007_ooool00ol0003oooooooooo`0eoooo
o`;o0000F?ooool2o`0006?ooooo0_l0000Pooooo`;o0000;oooool001kooooo00?o0000oooooooo
ool0=?ooool3o`0000_ooooo0_l0001Aooooo`;o0000Ooooool2o`0002oooooo000Nooooo`03o`00
0?oooooooooo03?ooooo0ol0000<ooooo`;o0000Aoooool2o`0000Sooooo0_l0002`ooooo`007_oo
ool01?l0003oooooo`000?l0000booooo`;o0000DOooool2o`0000?ooooo0_l0002cooooo`;o0000
1Oooool001kooooo00Co0000ooooool0003o00000oooool2o`0001_ooooo0_l0000@ooooo`;o0000
3_ooool2o`0001;ooooo0_l0000]ooooo`;o00008Oooool2o`000003ooooool0003o000002Gooooo
0_l0001Cooooo`;o00005_ooool2o`0000Gooooo000Nooooo`;o00000_ooool2o`000003ooooool0
003o000001?ooooo0_l00006ooooo`;o00004?ooool2o`0000kooooo0_l0000Booooo`;o0000D?oo
ool2o`000003ooooool0003o000000gooooo0_l0000Fooooo`;o0000Doooool2o`0000gooooo0_l0
000>ooooo`007_ooool01?l0003oooooooooooooool2o`0001Kooooo0_l0002Pooooo`;o00009_oo
ool2o`0005;ooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`0Fooooo`;o0000boooool2
o`0006;ooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l000000ooooooo0000o`00002Coooo
o`;o0000Uoooool001kooooo00?o0000ooooooooool05_ooool2o`000003ooooool0003o000009?o
oooo0_l00008ooooo`;o00002oooool2o`0000_ooooo0_l0001cooooo`007_ooool00ol0003ooooo
ooooo`06ooooo`;o00003_ooool2o`0005;ooooo0_l0001<ooooo`;o00002oooool2o`0000_ooooo
0_l0001cooooo`007_ooool00ol0003oooooooooo`06ooooo`;o000000?oooooo`000?l00000Gooo
ool4o`000=Wooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0001Qooooo`;o0000??ooool2
o`000003ooooool0003o000009Sooooo000Nooooo`03o`000?oooooooooo017ooooo0_l0000Ioooo
o`;o00006Oooool2o`0004oooooo0_l0000@ooooo`;o000000?oooooo`000?l00000L?ooool2o`00
02Kooooo000Nooooo`03o`000?oooooooooo017ooooo0_l0000Iooooo`;o00006Oooool2o`0003ko
oooo0_l0000?ooooo`;o0000A_ooool2o`0001Sooooo0_l0000Sooooo`;o00009_ooool001kooooo
00?o0000ooooooooool0@_ooool2o`0004?ooooo0_l0001Gooooo`;o00006?ooool2o`0004_ooooo
000Nooooo`03o`000?oooooooooo00oooooo0_l0000`ooooo`?o0000MOooool2o`0008cooooo000N
ooooo`03o`000?oooooooooo00oooooo0_l0000`ooooo`;o0000M_ooool2o`0004Oooooo0_l00013
ooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o0000Coooool2o`0008Cooooo0_l0000<oooo
o`;o0000@oooool001kooooo00?o0000ooooooooool06_ooool2o`000003ooooool0003o000004oo
oooo0_l0001iooooo`;o00001Oooool2o`0000;ooooo0_l0001Aooooo`007_ooool00ol0003ooooo
ooooo`0Jooooo`;o00008?ooool2o`0001;ooooo0_l0002Gooooo`;o00001Oooool2o`0005Gooooo
000Nooooo`;o0000?Oooool2o`0001;ooooo0_l00016ooooo`;o0000;Oooool2o`00013ooooo0_l0
000?ooooo`;o0000Foooool001kooooo00?o0000ooooooooool0Soooool2o`0000Oooooo0_l0000]
ooooo`;o00004?ooool2o`0000oooooo0_l0000Kooooo`;o00000_ooool2o`0003[ooooo000Noooo
o`03o`000?oooooooooo07cooooo0_l0000Aooooo`;o0000C?ooool2o`0002Sooooo0_l00002oooo
o`;o0000>_ooool001kooooo00?o0000ooooooooool0Goooool2o`0001_ooooo0_l00006ooooo`;o
0000D_ooool2o`0000?ooooo0_l0001Xooooo`007_ooool00ol0003oooooooooo`1Oooooo`;o0000
4_ooool2o`0000oooooo0_l0001Booooo`;o00008?ooool2o`0004_ooooo000Nooooo`03o`000?oo
oooooooo07?ooooo0_l0001aooooo`;o00004_ooool2o`0004_ooooo000Nooooo`03o`000?oooooo
oooo02Gooooo0_l00007ooooo`;o0000J?ooool2o`0000cooooo0_l0000nooooo`;o00000oooool2
o`00013ooooo0_l00018ooooo`007_ooool00ol0003oooooooooo`0Uooooo`;o00001oooool2o`00
00?ooooo0_l0000jooooo`;o00009oooool2o`0000cooooo0_l00013ooooo`;o00004?ooool2o`00
04Sooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0000[ooooo`;o00000_ooool2o`0001go
oooo0_l0000Kooooo`;o00001_ooool4o`0006[ooooo0_l0000Vooooo`;o00001Oooool2o`00037o
oooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0000Hooooo`;o00004Oooool2o`00027ooooo
0_l0000Sooooo`Co000000?oooooo`000?l000008Oooool2o`0004Cooooo0_l0000Vooooo`;o0000
1Oooool2o`00037ooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l00008ooooo`;o0000G_oo
ool2o`00027ooooo0_l0002Vooooo`007_ooool00ol0003oooooooooo`08ooooo`;o00002?ooool2
o`000?oooooo=?ooool001kooooo00?o0000ooooooooool02?ooool2o`00023ooooo0_l00035oooo
o`;o0000<_ooool2o`0000_ooooo0_l0000Cooooo`007_ooool00ol0003oooooooooo`0Zooooo`;o
00008oooool2o`0006Gooooo0_l0000Fooooo`;o00002oooool2o`0001Cooooo0_l0000Vooooo`;o
00002_ooool2o`0000Kooooo0_l00003ooooo`;o00004oooool000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0Coooool2o`0006Go
oooo0_l0000Fooooo`;o00002oooool2o`0003cooooo0_l00009ooooo`;o00001oooool2o`0001So
oooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A006ooooo`03o`000?oooooooooo02Oooooo0_l0001`ooooo`;o00000_ooool2o`00
03cooooo0_l00017ooooo`;o00008Oooool000?ooooo00Go410@oooooooooooooooooa0@400<oooo
o`03oiRHV?lQ8B7ok^k^00Oooooo0ol0000Wooooo`;o0000L?ooool2o`0000;ooooo0_l0000Roooo
o`;o00006?ooool2o`0000kooooo0_l0001Jooooo`000oooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h01Oooool2o`0000cooooo0_l0000Cooooo`;o00001Oooool2o`00
06gooooo0_l0000Zooooo`;o0000:?ooool2o`0005[ooooo0003ooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`04ooooo`;o00003?ooool2o`0001?ooooo0_l00005oooo
o`;o0000Ioooool2o`0000Cooooo0_l0002`ooooo`000oooool01Ol@413ooooooooooooooooo410@
00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2?ooooo`;o0000Q?ooool4o`00
02kooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@00Kooooo00?o0000ooooooooool0UOooool2o`0007kooooo1?l0000^ooooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oo
oooooooo08Cooooo0_l0000?ooooo`;o0000Hoooool2o`0004_ooooo000Nooooo`04o`000?oooooo
0000o`0000Cooooo0_l0001mooooo`;o0000D?ooool2o`0002;ooooo0_l0000Mooooo`;o00004_oo
ool2o`0001Sooooo000Nooooo`04o`000?oooooo0000o`0000Cooooo0_l0003?ooooo`;o0000>ooo
ool2o`0000Cooooo0_l00003ooooo`;o00003Oooool2o`0001Sooooo000Nooooo`03o`000?oooooo
oooo0?oooooo5?ooool2o`0000Wooooo0_l00005ooooo`;o00008?ooool001kooooo00?o0000oooo
ooooool05oooool2o`0004[ooooo0_l0000>ooooo`;o0000/?ooool2o`0001[ooooo0_l00004oooo
o`007_ooool00ol0003oooooooooo`07ooooo`;o00003_ooool2o`0003Oooooo0_l0000Aooooo`;o
00003_ooool2o`0000Gooooo0_l00035ooooo`;o00001?ooool001kooooo00?o0000ooooooooool0
1oooool2o`0002Oooooo0_l0000Nooooo`;o00001_ooool2o`00023ooooo0_l0000Tooooo`;o0000
YOooool001kooooo00?o0000ooooooooool04?ooool2o`0001kooooo0_l0000Fooooo`;o00003_oo
ool2o`0004Kooooo0_l0002Uooooo`007_ooool00ol0003oooooooooo`02ooooo`;o00003?ooool2
o`0000Cooooo0_l0000`ooooo`Co00006?ooool2o`0007;ooooo0_l0000dooooo`;o0000<Oooool2
o`0000Cooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0000>ooooo`;o00000_ooool2o`00
03;ooooo0_l0000Hooooo`;o0000L_ooool2o`0003Cooooo0_l0000Gooooo`;o00006?ooool2o`00
00Cooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0003Jooooo`;o0000=oooool2o`0001ko
oooo000Nooooo`03o`000?oooooooooo02Gooooo0_l0000Pooooo`;o0000YOooool2o`0002Oooooo
0_l0000^ooooo`007_ooool2o`0002Kooooo0_l0000Pooooo`;o0000@_ooool2o`0001Oooooo0_l0
000looooo`;o0000<oooool2o`0002kooooo000Nooooo`03o`000?oooooooooo02?ooooo0_l0001V
ooooo`;o00005oooool2o`0003cooooo0_l0000Dooooo`;o00001?ooool2o`0000Kooooo0_l0000o
ooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o0000@_ooool2o`00073ooooo0_l0000Moooo
o`;o00001?ooool2o`0000Kooooo0_l0000oooooo`007_ooool00ol0003oooooooooo`0looooo`;o
0000:Oooool2o`0000?ooooo0_l0001[ooooo`;o0000K?ooool001kooooo00?o0000ooooooooool0
??ooool2o`0000Kooooo0_l0000Vooooo`;o0000fOooool001kooooo00?o0000ooooooooool0A?oo
ool2o`000:kooooo0_l0001Aooooo`007_ooool00ol0003oooooooooo`12ooooo`Co00003oooool2
o`0007[ooooo0_l0000Qooooo`;o00006Oooool2o`0003Kooooo000Nooooo`03o`000?oooooooooo
00_ooooo0_l0000]ooooo`;o00001_ooool2o`00017ooooo0_l0000Iooooo`;o0000=Oooool2o`00
02Sooooo0_l0000Booooo`;o0000:?ooool2o`00013ooooo0_l0000Tooooo`007_ooool01?l0003o
ooooo`000?l0000:ooooo`;o0000;Oooool2o`0003Cooooo0_l0000Iooooo`;o00006_ooool2o`00
03cooooo0_l0000Iooooo`;o00007oooool2o`00013ooooo0_l00006ooooo`;o000000?oooooo`00
0?l000001oooool001kooooo00Co0000ooooool0003o0000POooool2o`0000Oooooo0_l0001Xoooo
o`;o00002Oooool2o`0001;ooooo0_l0000Mooooo`;o00001_ooool2o`000003ooooool0003o0000
00Oooooo000Nooooo`03o`000?oooooooooo00Sooooo0ol0000Sooooo`;o0000D_ooool2o`0006Co
oooo0_l0000;ooooo`;o00007Oooool2o`00037ooooo000Nooooo`03o`000?oooooooooo00Sooooo
0ol00003ooooo`;o00007_ooool2o`0000Wooooo0_l00022ooooo`;o00003oooool2o`0001Sooooo
0_l0000=ooooo`;o00007_ooool2o`0002;ooooo0_l0000:ooooo`007_ooool00ol0003ooooooooo
o`0>ooooo`;o00004_ooool2o`00017ooooo0_l00002ooooo`;o00004Oooool4o`0004kooooo0_l0
0006ooooo`;o00005Oooool2o`0000oooooo0_l0000Wooooo`;o00005_ooool2o`0000Kooooo0_l0
000Rooooo`;o00002_ooool001kooooo00?o0000ooooooooool08_ooool2o`00017ooooo0_l0000E
ooooo`Co0000?_ooool2o`0000Wooooo0_l00003ooooo`;o00001_ooool2o`0006Oooooo0_l0000>
ooooo`;o00009_ooool001kooooo00?o0000ooooooooool05_ooool2o`0007Kooooo0_l00009oooo
o`;o0000Q?ooool2o`0001Cooooo0_l0000@ooooo`007_ooool00ol0003oooooooooo`0Fooooo`;o
0000k?ooool2o`0002?ooooo0_l0000:ooooo`;o00004?ooool001kooooo0_l0000Uooooo`;o0000
g_ooool2o`0002?ooooo0_l0000Looooo`007_ooool00ol0003oooooooooo`0Tooooo`;o0000V?oo
ool2o`0000gooooo0_l0000iooooo`;o0000?Oooool001kooooo00?o0000ooooooooool02oooool3
o`0001cooooo0_l0000_ooooo`;o000000?oooooo`000?l000000oooool2o`0005Wooooo0_l0000=
ooooo`;o0000>Oooool2o`0002_ooooo0_l0000@ooooo`007_ooool00ol0003oooooooooo`0;oooo
o`?o00007?ooool2o`0000oooooo0_l0000Nooooo`;o000000?oooooo`000?l000000oooool2o`00
05Gooooo0ol0000Mooooo`;o0000FOooool2o`00013ooooo000Nooooo`03o`000?oooooooooo02go
oooo0_l0000<ooooo`;o00009_ooool2o`0005Gooooo0ol0000Mooooo`;o00009_ooool2o`0004?o
oooo000Nooooo`03o`000?oooooooooo02gooooo0_l0000Wooooo`;o00002oooool2o`0009gooooo
0_l00013ooooo`007_ooool00ol0003oooooooooo`1;ooooo`;o00002Oooool2o`000>oooooo000N
ooooo`03o`000?oooooooooo04_ooooo0_l0000Yooooo`;o00000oooool2o`000<[ooooo000Noooo
o`03o`000?oooooooooo06Sooooo0_l0000<ooooo`;o00000oooool2o`0001Cooooo0_l0002Poooo
o`;o00004_ooool001kooooo00?o0000ooooooooool0Coooool2o`0001Oooooo0_l0000Wooooo`;o
0000AOooool2o`0005Wooooo0_l00005ooooo`;o00002oooool001kooooo00?o0000ooooooooool0
Coooool2o`00013ooooo0_l0000looooo`;o00002oooool2o`0002[ooooo0_l0000gooooo`;o0000
7oooool2o`0000Kooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o0000?ooo
ool2o`0000?ooooo0_l0000Iooooo`;o00007?ooool2o`0000_ooooo0_l0001Sooooo`;o00007ooo
ool2o`0001?ooooo000Nooooo`03o`000?oooooooooo023ooooo0_l00014ooooo`;o00006Oooool2
o`00037ooooo0_l00017ooooo`;o0000B?ooool001kooooo00?o0000ooooooooool08Oooool2o`00
05Wooooo0_l0000Xooooo`;o00003?ooool2o`0004Oooooo0_l00018ooooo`007_ooool00ol0003o
ooooooooo`0Qooooo`;o00009oooool2o`0000Kooooo0_l0000Xooooo`;o0000:?ooool2o`0002oo
oooo0_l0001^ooooo`007_ooool00ol0003oooooooooo`1:ooooo`;o00001_ooool2o`0002Oooooo
0_l0000]ooooo`;o0000:oooool2o`0006kooooo000Nooooo`;o00001_ooool2o`0007Cooooo0_l0
000Kooooo`;o00004?ooool2o`0002cooooo0_l0001]ooooo`007_ooool00ol0003oooooooooo`05
ooooo`;o0000Joooool2o`0002Cooooo0_l0000looooo`Co0000=oooool2o`0000Kooooo1?l0000=
ooooo`;o00006oooool001kooooo00?o0000ooooooooool01?ooool2o`0004Sooooo0_l0000Boooo
o`;o00003_ooool2o`0006;ooooo0_l0000iooooo`;o00001_ooool4o`0000gooooo0_l0000Koooo
o`007_ooool00ol0003oooooooooo`04ooooo`;o0000B?ooool2o`0001;ooooo0_l0000Dooooo`;o
00008oooool2o`000:Sooooo000Nooooo`03o`000?oooooooooo037ooooo0_l00015ooooo`;o0000
8oooool2o`0005Kooooo0_l0000Kooooo`;o00008oooool2o`0000kooooo000Nooooo`03o`000?oo
oooooooo037ooooo0_l00006ooooo`;o0000^_ooool2o`0001_ooooo0_l0000Sooooo`;o00003_oo
ool001kooooo00?o0000ooooooooool0>Oooool2o`0004Wooooo0_l00031ooooo`007_ooool00ol0
003oooooooooo`24ooooo`;o0000Roooool2o`0001_ooooo0_l0000Gooooo`007_ooool00ol0003o
ooooooooo`0Iooooo`;o0000Yoooool2o`0003gooooo0_l0000>ooooo`;o00006oooool2o`0001Oo
oooo000Nooooo`03o`000?oooooooooo01Wooooo0_l0002Wooooo`;o0000?Oooool2o`0004Cooooo
000Nooooo`03o`000?oooooooooo02kooooo0_l00017ooooo`;o0000c_ooool001kooooo00?o0000
ooooooooool0;_ooool2o`00013ooooo0_l0000eooooo`;o00003Oooool2o`0000gooooo0_l00008
ooooo`;o0000Y_ooool001kooooo00?o0000ooooooooool02Oooool2o`0000_ooooo0_l00003oooo
o`;o00000oooool2o`0001kooooo0_l0000Eooooo`;o0000;Oooool2o`0000gooooo0_l00008oooo
o`;o0000I_ooool2o`0003kooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0000;ooooo`;o
00000oooool2o`0000?ooooo0ol0000dooooo`;o0000[_ooool3o`0003gooooo0003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03
o`000?oooooooooo01Cooooo0_l0000;ooooo`;o0000a?ooool2o`0001cooooo0_l000000ooooooo
0000o`00000mooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool05?ooool2o`0001Kooooo0_l0002iooooo`;o
00007?ooool2o`00043ooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Ko
oooo0ol0000/ooooo`;o0000koooool2o`0002Sooooo0003ooooo`05o`000?ooooooooooooooool0
00002oooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo00_ooooo0_l0000Goooo
o`;o0000=Oooool2o`0009Kooooo0_l0000Mooooo`;o00002Oooool2o`0000gooooo0_l0000;oooo
o`;o00003?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0000Oooooo00?o0000ooooooooool02oooool3o`0001Kooooo1?l0000cooooo`;o0000U_ooool2
o`0001gooooo0_l0000Hooooo`;o00002oooool2o`0000cooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo00cooooo0_l0000H
ooooo`;o0000@_ooool2o`0003;ooooo0_l0000Cooooo`;o0000T_ooool000?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0Coooool2
o`0001Wooooo0_l0000booooo`;o00004oooool2o`0009;ooooo0003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo00;o00001oooool2
o`0000gooooo0_l0000eooooo`;o0000^Oooool2o`0003_ooooo000Nooooo`;o000000?oooooo`00
0?l000001oooool2o`0000gooooo0_l0000Mooooo`;o0000EOooool2o`0000Kooooo0_l0001boooo
o`;o0000>oooool001kooooo0_l0000hooooo`;o0000EOooool2o`0000Kooooo0_l0002_ooooo`00
7_ooool00ol0003oooooooooo`3oooooo`;o0000A_ooool001kooooo00?o0000ooooooooool03ooo
ool2o`0009Cooooo0_l0001Hooooo`;o0000A_ooool001kooooo00?o0000ooooooooool03oooool2
o`0002kooooo0_l0000<ooooo`;o00002?ooool2o`0004cooooo0_l0000eooooo`;o0000JOooool0
01kooooo00?o0000ooooooooool00oooool2o`000003ooooool0003o000003Oooooo0_l0000<oooo
o`;o00000oooool2o`0000?ooooo0_l0000Mooooo`;o00000_ooool2o`00063ooooo0_l0001Yoooo
o`007_ooool00ol0003oooooooooo`03ooooo`;o000000?oooooo`000?l00000B_ooool2o`0002;o
oooo0_l00002ooooo`;o0000??ooool2o`00053ooooo0_l0000kooooo`007_ooool00ol0003ooooo
ooooo`0cooooo`;o0000@_ooool2o`0003Kooooo0_l00007ooooo`;o0000D?ooool2o`0003_ooooo
000Nooooo`03o`000?oooooooooo03?ooooo0_l00012ooooo`;o00002oooool2o`0002Wooooo0_l0
000;ooooo`;o0000Loooool2o`0000Kooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`24
ooooo`;o0000<Oooool2o`0000?ooooo0_l00002ooooo`;o0000Goooool2o`0000kooooo0_l00006
ooooo`;o00003?ooool001kooooo00?o0000ooooooooool0Qoooool2o`0002kooooo0_l00007oooo
o`;o0000:oooool2o`0003;ooooo0_l0000Tooooo`007_ooool2o`0002Cooooo0_l0001Rooooo`;o
0000I?ooool2o`0000[ooooo0_l0001<ooooo`007_ooool01?l0003oooooo`000?l0000Rooooo`;o
00000_ooool2o`0005Kooooo0_l0001hooooo`;o00004oooool2o`0001Oooooo0_l0000Nooooo`00
7_ooool01?l0003oooooo`000?l0000Vooooo`;o0000>Oooool2o`0001[ooooo0ol0000[ooooo`;o
0000H?ooool2o`00013ooooo0_l00005ooooo`;o00007_ooool001kooooo00?o0000ooooooooool0
H_ooool2o`0001[ooooo0_l0000/ooooo`;o0000Hoooool2o`0000gooooo0_l0000Uooooo`007_oo
ool00ol0003oooooooooo`1Mooooo`;o00005oooool2o`0005;ooooo0_l00015ooooo`;o00007Ooo
ool2o`0001Gooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l0000dooooo`;o00001_ooool2
o`0000Cooooo0_l0000Gooooo`;o000000?oooooo`000?l00000Coooool2o`0000Kooooo0_l0001L
ooooo`;o00005Oooool001kooooo00?o0000ooooooooool06Oooool2o`0001cooooo0_l0000=oooo
o`;o00001Oooool4o`0000Kooooo0_l0000Pooooo`;o0000Eoooool2o`0004Oooooo0_l0000Zoooo
o`007_ooool00ol0003oooooooooo`0_ooooo`;o00001_ooool2o`0000gooooo0_l00005ooooo`;o
0000EOooool2o`0002?ooooo0_l0000@ooooo`;o00008?ooool2o`0001cooooo0_l0000Zooooo`00
7_ooool00ol0003oooooooooo`0_ooooo`;o00005oooool2o`00017ooooo0_l00008ooooo`;o0000
?Oooool2o`0002?ooooo0_l0000@ooooo`;o00008?ooool2o`0004Sooooo000Mooooo`;o00005Ooo
ool2o`0001Oooooo0_l0000Jooooo`;o00004Oooool2o`0000Sooooo0_l0000^ooooo`;o0000/?oo
ool001gooooo0_l0000Eooooo`;o00003?ooool2o`0000Wooooo0_l0001Wooooo`;o0000Qoooool2
o`0002Oooooo000Nooooo`03o`000?oooooooooo027ooooo0_l0000Uooooo`;o00009_ooool2o`00
00Wooooo0_l00026ooooo`;o00006Oooool2o`0002Oooooo000Nooooo`03o`000?oooooooooo04So
oooo0_l0000Vooooo`;o00002Oooool2o`0008Kooooo0_l00012ooooo`007_ooool00ol0003ooooo
ooooo`0[ooooo`;o0000a_ooool2o`00047ooooo0_l0000?ooooo`007_ooool00ol0003ooooooooo
o`0[ooooo`;o00001oooool2o`0002_ooooo0_l0001Yooooo`;o00004_ooool2o`00017ooooo0_l0
0011ooooo`;o00003oooool001kooooo00?o0000ooooooooool0=?ooool2o`0000?ooooo0_l0000V
ooooo`;o0000JOooool2o`0001;ooooo0_l0000Tooooo`;o0000?oooool001kooooo0_l0000joooo
o`;o00002Oooool2o`0002cooooo0_l00008ooooo`;o0000R?ooool2o`0003oooooo000Nooooo`03
o`000?oooooooooo00oooooo0_l0000Rooooo`;o00003oooool2o`0002cooooo0_l00008ooooo`;o
0000bOooool001kooooo00?o0000ooooooooool03oooool2o`0002;ooooo0_l00019ooooo`;o0000
C_ooool2o`0001Kooooo0_l0001Oooooo`007_ooool00ol0003oooooooooo`16ooooo`;o0000=_oo
ool2o`0004kooooo0_l0000Fooooo`;o0000Goooool001kooooo00?o0000ooooooooool0A_ooool2
o`0001?ooooo0_l0000Gooooo`;o0000@_ooool2o`0001Cooooo0_l0001gooooo`007_ooool00ol0
003oooooooooo`1Kooooo`;o00005oooool2o`0003;ooooo0_l0000>ooooo`;o0000NOooool2o`00
01;ooooo000Nooooo`03o`000?oooooooooo06Kooooo0_l00010ooooo`;o0000ROooool2o`0000Wo
oooo0_l00007ooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o0000@Oooool2o`000=Kooooo
0_l00007ooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o0000oooooolSooooo`007_ooool0
0ol0003oooooooooo`0Iooooo`;o0000ooooool]ooooo`007_ooool00ol0003oooooooooo`08oooo
o`;o00003oooool2o`0002[ooooo0_l0002Qooooo`;o00005?ooool2o`0004Oooooo000Nooooo`03
o`000?oooooooooo00Sooooo0_l0000kooooo`;o000000?oooooo`000?l000008?ooool2o`0007co
oooo0_l0000Dooooo`;o0000Aoooool001kooooo00?o0000ooooooooool0B?ooool2o`00023ooooo
0_l0000Cooooo`;o0000=?ooool2o`0004Gooooo0_l00007ooooo`;o0000@?ooool001kooooo00?o
0000ooooooooool0Boooool2o`0003;ooooo1?l0000;ooooo`;o00009Oooool2o`0003?ooooo0_l0
000@ooooo`;o00001oooool2o`0000gooooo0_l0000aooooo`007_ooool00ol0003oooooooooo`1;
ooooo`;o0000=?ooool2o`0000_ooooo0_l00017ooooo`;o00004Oooool2o`0002Sooooo0_l0000a
ooooo`007_ooool00ol0003oooooooooo`1;ooooo`;o0000P_ooool2o`0000Kooooo0_l0001Poooo
o`;o00003?ooool001kooooo0_l0001;ooooo`?o0000E_ooool2o`0002[ooooo0_l0000Jooooo`;o
00004?ooool2o`0003[ooooo1?l0000:ooooo`007_ooool00ol0003oooooooooo`1:ooooo`;o0000
Eoooool2o`0004Kooooo0_l00002ooooo`;o00003?ooool2o`0003cooooo0_l0000:ooooo`007_oo
ool00ol0003oooooooooo`2fooooo`;o0000=oooool2o`0005Kooooo000Nooooo`03o`000?oooooo
oooo01;ooooo0_l0000@ooooo`;o00004oooool2o`0005Gooooo0_l0000Cooooo`;o00003oooool2
o`00037ooooo0_l0000booooo`;o0000:?ooool001kooooo00?o0000ooooooooool00_l0000<oooo
o`;o000000Coooooo`000?l0003o00004?ooool2o`0001?ooooo0_l0001Eooooo`;o00004oooool2
o`0004;ooooo0_l0000booooo`;o0000:?ooool001kooooo00?o0000ooooooooool00_l0000<oooo
o`;o000000?oooooo`000?l00000aoooool2o`0002Oooooo0_l00012ooooo`007_ooool00ol0003o
ooooooooo`3Jooooo`;o00005Oooool2o`0000Oooooo0_l00007ooooo`;o0000;oooool2o`00017o
oooo000Nooooo`03o`000?oooooooooo0>kooooo0_l000000ooooooo0000o`000007ooooo`;o0000
<Oooool2o`0000Gooooo0_l0000Aooooo`007_ooool00ol0003oooooooooo`1oooooo`Co00004Ooo
ool2o`0005Sooooo0_l0000mooooo`;o00006?ooool001kooooo00?o0000ooooooooool0Koooool2
o`0000kooooo1_l0000?ooooo`;o0000C_ooool2o`00067ooooo000Nooooo`03o`000?oooooooooo
06oooooo0_l0000Booooo`;o0000Goooool2o`0004gooooo0_l00004ooooo`Co00002_ooool001ko
oooo00?o0000ooooooooool0f_ooool2o`0005Oooooo0_l00004ooooo`Co00002_ooool001kooooo
00?o0000ooooooooool0Poooool2o`0005Gooooo0_l0000Oooooo`;o0000??ooool2o`0000cooooo
000Nooooo`03o`000?oooooooooo00gooooo0_l00015ooooo`;o0000;Oooool2o`00043ooooo0_l0
000dooooo`;o00001_ooool2o`0003Cooooo0_l00002ooooo`;o00002?ooool000?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo
00?o0000ooooooooool03Oooool2o`0004Gooooo0_l0001_ooooo`;o0000??ooool2o`0003Sooooo
0_l00008ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEE
EOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0mooooo`;o00006_ooool2o`0009ko
oooo0_l0001<ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooo
ooooooooo`000006ooooo`?o0000?Oooool2o`0001[ooooo0_l0002Nooooo`;o0000C?ooool000?o
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool0
0ol0003oooooooooo`19ooooo`;o0000:?ooool2o`000;Gooooo0_l0000Kooooo`000oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oo
oooooooo00?ooooo0_l0000cooooo`;o00003oooool2o`0001;ooooo0ol0000Cooooo`;o0000Hooo
ool4o`0004Oooooo0_l00005ooooo`;o00006oooool000?ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool00oooool2o`0003?ooooo0_l0
000Sooooo`?o0000B_ooool2o`0002cooooo1?l0000jooooo`;o00002oooool2o`0002;ooooo0003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oo
oooooooo0:3ooooo0_l00008ooooo`;o0000J_ooool4o`0002gooooo0003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo0:3ooooo
0_l00006ooooo`;o0000K_ooool2o`0000Kooooo0_l0000Uooooo`007_ooool00ol0003ooooooooo
o`0Zooooo`;o0000?oooool2o`0003_ooooo0_l0001fooooo`;o00009Oooool001kooooo00?o0000
ooooooooool0:Oooool3o`0001Gooooo0_l00002ooooo`;o00009?ooool2o`000003ooooool0003o
000002;ooooo0_l0002Fooooo`;o00006oooool001kooooo0ol0000Yooooo`;o00005_ooool2o`00
00;ooooo0_l0000Wooooo`?o00000oooool2o`0001cooooo0_l0002Fooooo`;o00006oooool001ko
oooo0ol0000Booooo`;o00007oooool2o`0003[ooooo0_l00003ooooo`;o00004oooool2o`0008oo
oooo0_l0000Aooooo`;o00006?ooool001kooooo00?o0000ooooooooool04_ooool4o`0001gooooo
0_l0001Dooooo`;o00001_ooool2o`0000;ooooo0_l0000Fooooo`;o00002oooool2o`0000kooooo
0_l0000]ooooo`;o00003?ooool2o`00017ooooo0_l0000Aooooo`;o00006?ooool001kooooo00?o
0000ooooooooool05?ooool2o`0002Wooooo0_l0001@ooooo`;o00000_ooool2o`0001Kooooo0ol0
000:ooooo`;o00003_ooool2o`00013ooooo0_l0000Kooooo`;o00003?ooool2o`00027ooooo0_l0
000Kooooo`007_ooool00ol0003oooooooooo`0oooooo`;o0000<Oooool2o`0000_ooooo0_l0000]
ooooo`;o0000;?ooool2o`0004cooooo0_l0000Kooooo`007_ooool00ol0003oooooooooo`13oooo
o`;o0000;Oooool2o`0000_ooooo0_l0000:ooooo`;o0000A_ooool2o`0007;ooooo000Nooooo`03
o`000?oooooooooo04?ooooo0_l00003ooooo`;o0000:Oooool2o`0001Kooooo0_l00016ooooo`;o
0000L_ooool001kooooo00?o0000ooooooooool09?ooool2o`0002;ooooo0_l0000Yooooo`;o0000
;Oooool2o`0004Kooooo0_l0001Kooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o00005ooo
ool2o`0005Wooooo0_l0000Qooooo`;o0000A_ooool2o`0005_ooooo000Nooooo`;o00001_ooool2
o`0000Cooooo0_l00007ooooo`;o0000??ooool2o`0002_ooooo0_l0000<ooooo`;o00004?ooool2
o`0000;ooooo0_l0001Kooooo`;o0000AOooool001kooooo00?o0000ooooooooool01Oooool2o`00
00gooooo0_l0000looooo`;o00000oooool2o`0003Cooooo0_l0000@ooooo`;o00000_ooool2o`00
05_ooooo0_l00015ooooo`007_ooool00ol0003oooooooooo`13ooooo`;o00004_ooool2o`0000So
oooo0_l0003Tooooo`007_ooool00ol0003oooooooooo`13ooooo`;o00007?ooool2o`0004oooooo
0_l00012ooooo`;o0000Coooool001kooooo00?o0000ooooooooool02_ooool2o`0003Gooooo0_l0
001Xooooo`;o00001Oooool2o`0004;ooooo0_l00003ooooo`;o0000B_ooool001kooooo00?o0000
ooooooooool02_ooool2o`0002kooooo0_l00005ooooo`;o0000J?ooool2o`0004kooooo0_l00000
0ooooooo0000o`000008ooooo`;o0000?Oooool001kooooo00?o0000ooooooooool0>_ooool2o`00
05gooooo0_l0000=ooooo`;o0000E?ooool2o`0000Sooooo0_l0000mooooo`007_ooool00ol0003o
ooooooooo`2?ooooo`;o00002?ooool2o`0000?ooooo0_l00008ooooo`;o00007oooool2o`0001So
oooo0_l0001Rooooo`007_ooool00ol0003oooooooooo`12ooooo`;o0000Boooool2o`0000gooooo
1?l0000Wooooo`;o00006?ooool2o`0006;ooooo000Nooooo`03o`000?oooooooooo04;ooooo0_l0
001Cooooo`;o00001oooool2o`000:Gooooo000Nooooo`03o`000?oooooooooo05gooooo0_l0000h
ooooo`;o0000[_ooool001kooooo00?o0000ooooooooool0GOooool2o`0004[ooooo0_l0002Loooo
o`007_ooool00ol0003oooooooooo`2Yooooo`;o0000;Oooool2o`0000?ooooo0_l0001Xooooo`00
7_ooool00ol0003oooooooooo`0dooooo`;o0000>_ooool2o`0003Cooooo0_l0000Mooooo`;o0000
4Oooool2o`0000?ooooo0_l0000Rooooo`;o00009oooool2o`0001_ooooo000Nooooo`03o`000?oo
oooooooo00oooooo0_l0000Sooooo`?o0000>Oooool2o`0003Cooooo0_l0000Mooooo`;o00006ooo
ool2o`0001gooooo0_l0000Wooooo`;o00006oooool001kooooo00?o0000ooooooooool03oooool2
o`0002Cooooo0_l0000aooooo`;o0000Aoooool2o`0002oooooo0_l0001Sooooo`007_ooool2o`00
06Wooooo0_l00017ooooo`;o0000U?ooool001kooooo00?o0000ooooooooool0;oooool2o`0006go
oooo0_l0000looooo`;o00007Oooool2o`0000_ooooo0_l0000mooooo`007_ooool00ol0003ooooo
ooooo`0;ooooo`;o00008_ooool2o`0001_ooooo0_l0001@ooooo`;o00007?ooool2o`0001kooooo
0_l0000@ooooo`;o00002oooool2o`0000_ooooo0_l0000Oooooo`;o00004?ooool2o`0000[ooooo
000Nooooo`03o`000?oooooooooo00_ooooo0_l0000oooooo`;o00000oooool2o`0000Cooooo0_l0
0019ooooo`;o00006?ooool2o`00033ooooo0_l0000Zooooo`;o00003Oooool2o`00013ooooo0_l0
000:ooooo`007_ooool00ol0003oooooooooo`0cooooo`;o00007?ooool2o`0000Cooooo0_l0000S
ooooo`;o00009?ooool2o`0007Kooooo0_l0000[ooooo`007_ooool00ol0003oooooooooo`0Eoooo
o`;o00007?ooool2o`0001oooooo0_l0000Vooooo`;o00007Oooool2o`0002Gooooo0_l00003oooo
o`;o0000:Oooool2o`0004Cooooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`0Cooooo`Co
00009_ooool4o`0001?ooooo0_l00015ooooo`;o00009Oooool2o`0000?ooooo0_l0000Yooooo`;o
0000A?ooool2o`0000?ooooo0_l00008ooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o0000
:?ooool4o`0007Wooooo0_l00015ooooo`;o0000>_ooool2o`0000Sooooo000Nooooo`03o`000?oo
oooooooo08Kooooo0_l0000booooo`;o0000AOooool2o`0004Cooooo000Nooooo`03o`000?oooooo
oooo03_ooooo0ol00018ooooo`;o0000POooool2o`0003cooooo000Nooooo`03o`000?oooooooooo
00Kooooo0_l0000cooooo`?o00009_ooool2o`000:?ooooo0_l00002ooooo`;o00004?ooool2o`00
02Kooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l0001Looooo`;o00002Oooool2o`0009co
oooo0_l0000@ooooo`;o00009_ooool001kooooo00?o0000ooooooooool0D?ooool2o`0001gooooo
0_l0000oooooo`;o0000D?ooool2o`00033ooooo0_l0000Aooooo`007_ooool01?l0003ooooooooo
ooooool2o`0004gooooo0_l0001Nooooo`;o0000D?ooool2o`00033ooooo0_l0000Aooooo`007_oo
ool2o`0000;ooooo0_l0002@ooooo`;o0000/_ooool001kooooo0_l0001/ooooo`;o00009_ooool2
o`0001_ooooo1?l0002Cooooo`007_ooool2o`0001oooooo0_l00003ooooo`;o0000A_ooool2o`00
00oooooo0_l0000booooo`Co0000>oooool2o`0001[ooooo0_l0000jooooo`007_ooool00ol0003o
ooooooooo`0Nooooo`;o00000oooool2o`0005Kooooo0ol0001aooooo`;o00006_ooool2o`0003[o
oooo000Nooooo`03o`000?oooooooooo01cooooo0_l0000Cooooo`;o0000B?ooool2o`00033ooooo
0_l0000Mooooo`;o0000:_ooool2o`0004gooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0
000Cooooo`;o00002?ooool2o`0000Wooooo0_l0000Rooooo`;o0000E_ooool2o`0000kooooo0_l0
000=ooooo`;o00007Oooool2o`0000_ooooo0_l0000Gooooo`;o0000=?ooool001kooooo00?o0000
ooooooooool01oooool2o`0001gooooo0_l0000]ooooo`;o0000I_ooool2o`0000[ooooo0_l0000P
ooooo`;o00009?ooool2o`0003Cooooo000Nooooo`03o`000?oooooooooo08Kooooo0_l00011oooo
o`;o00001?ooool2o`0007Kooooo000Nooooo`03o`000?oooooooooo00gooooo0_l0001gooooo`;o
0000Aoooool2o`0007Kooooo000Nooooo`03o`000?oooooooooo00_ooooo1?l00006ooooo`;o0000
4oooool2o`0000Oooooo0_l0000Vooooo`;o0000H_ooool2o`0004Gooooo0_l0000oooooo`007_oo
ool00ol0003oooooooooo`0;ooooo`;o00002?ooool2o`0001?ooooo0_l00007ooooo`;o00009_oo
ool2o`0003Oooooo0_l0000Yooooo`;o0000;Oooool2o`0001Kooooo0_l0000Hooooo`;o00006Ooo
ool2o`0000[ooooo000Nooooo`03o`000?oooooooooo03kooooo0_l0001Dooooo`;o00003oooool2
o`0003_ooooo0_l0000:ooooo`;o0000<?ooool2o`0001Wooooo0_l0000:ooooo`007_ooool00ol0
003oooooooooo`0Dooooo`;o0000:?ooool2o`0006Gooooo0_l0000`ooooo`;o00002Oooool2o`00
06?ooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0000Zooooo`;o00007oooool2o`0007Co
oooo0_l00007ooooo`;o0000IOooool001kooooo00?o0000ooooooooool0@?ooool2o`0001oooooo
0_l0001mooooo`;o0000IOooool001kooooo00Co0000ooooool0003o00004?ooool2o`0002_ooooo
0_l00004ooooo`;o0000Noooool2o`0001Cooooo0_l0001Iooooo`;o00004oooool000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Ko
oooo00Co0000ooooool0003o00002?ooool2o`0000Kooooo0_l00008ooooo`;o00008Oooool4o`00
00;ooooo0_l0001Wooooo`;o00004_ooool2o`0000oooooo0_l00003ooooo`;o0000FOooool2o`00
01?ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRH
V?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo00Wooooo0_l0000@ooooo`;o00008_ooool3
o`0006_ooooo0_l0000Sooooo`;o00004?ooool2o`0004Oooooo0_l0000Hooooo`000oooool01Ol@
413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o00002Ooo
ool2o`0003Cooooo0_l0000=ooooo`;o0000<_ooool2o`0003Wooooo0_l0000Uooooo`;o00009_oo
ool2o`0001Kooooo0_l00007ooooo`;o00006?ooool000?ooooo00Go0000ooooooooooooooooo`00
000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool2o`0003;ooooo0_l0000Kooooo`;o0000
<_ooool2o`0001Sooooo0_l0000Looooo`;o000000?oooooo`000?l00000COooool2o`0001Kooooo
0_l0000Qooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o
0000olc<c006ooooo`;o00007_ooool2o`0000cooooo0_l00004ooooo`;o0000JOooool2o`0001co
oooo0_l0000_ooooo`;o0000F_ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05
oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`0Mooooo`;o00003?ooool2o`00
08Cooooo0_l0000hooooo`;o0000F_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`1Mooooo`;o00009?ooool2
o`00027ooooo0_l00009ooooo`;o000000?oooooo`000?l00000TOooool000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003ooooooooo
o`0]ooooo`;o0000;_ooool2o`0002Cooooo0_l0000Qooooo`;o00003?ooool2o`00097ooooo000N
ooooo`03o`000?oooooooooo02gooooo0_l0000Jooooo`;o0000A?ooool2o`0001_ooooo0_l0000Y
ooooo`;o0000K_ooool001kooooo00?o0000ooooooooool0BOooool2o`0004Cooooo0_l0000Koooo
o`;o00007?ooool2o`0000_ooooo0_l0000Hooooo`;o0000E?ooool001kooooo00?o0000oooooooo
ool00_ooool2o`0002[ooooo0_l0002Jooooo`;o00007?ooool2o`0000Oooooo0_l00009ooooo`;o
0000:Oooool2o`0000Oooooo0_l0000Eooooo`007_ooool00ol0003oooooooooo`02ooooo`;o0000
:_ooool2o`0002;ooooo0_l0000hooooo`;o0000Aoooool2o`00017ooooo0_l0000Booooo`;o0000
:Oooool2o`0000Oooooo0_l0000Eooooo`007_ooool00ol0003oooooooooo`1Booooo`;o0000>?oo
ool2o`0000_ooooo0_l0000booooo`;o00001_ooool2o`0003cooooo0_l00008ooooo`;o0000:?oo
ool001kooooo00?o0000ooooooooool0@oooool2o`0005Cooooo0_l0000booooo`;o00000_ooool2
o`0003Kooooo0_l00008ooooo`;o00002?ooool2o`0002Sooooo000Nooooo`03o`000?oooooooooo
04?ooooo0_l0001Oooooo`;o0000:oooool2o`0003Kooooo0_l0000looooo`007_ooool00ol0003o
ooooooooo`0<ooooo`;o0000U_ooool2o`0004[ooooo0_l0000>ooooo`;o0000:oooool2o`0001So
oooo000Nooooo`03o`000?oooooooooo00cooooo0_l0002Dooooo`;o0000Boooool3o`0000kooooo
0_l0000[ooooo`;o00006?ooool001kooooo00?o0000ooooooooool03oooool2o`0004gooooo0_l0
0012ooooo`;o0000Boooool2o`0002gooooo0_l000000ooooooo0000o`00000Tooooo`007_ooool0
0ol0003oooooooooo`0?ooooo`;o0000COooool2o`00023ooooo0_l0000^ooooo`;o0000?_ooool2
o`0000Sooooo0_l0000Rooooo`;o000000?oooooo`000?l000002_ooool2o`0001Sooooo000Noooo
o`;o0000BOooool2o`0003?ooooo0_l000000ooooooo0000o`00000Iooooo`;o00004oooool2o`00
03kooooo0_l00008ooooo`;o0000<Oooool2o`0000Gooooo0_l00005ooooo`;o00002_ooool001ko
oooo00?o0000ooooooooool0B?ooool2o`0002Kooooo0_l0000;ooooo`;o00007?ooool2o`0002[o
oooo0_l0000/ooooo`;o00002Oooool2o`0003;ooooo0_l00005ooooo`;o00002_ooool001kooooo
00?o0000ooooooooool0E?ooool2o`0001[ooooo0_l00018ooooo`Co00002Oooool2o`0001oooooo
0_l0000;ooooo`;o00002Oooool2o`0000Sooooo0_l0000Tooooo`;o00005Oooool001kooooo00?o
0000ooooooooool0E?ooool2o`00067ooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l0
0008ooooo`;o00006oooool2o`00023ooooo0_l0000Tooooo`;o00005Oooool001kooooo00?o0000
ooooooooool0T?ooool2o`0002Gooooo0_l00008ooooo`;o00002?ooool2o`0007[ooooo000Noooo
o`03o`000?oooooooooo02Gooooo0_l0001Yooooo`;o0000LOooool2o`0004;ooooo000Nooooo`03
o`000?oooooooooo02Gooooo0_l0000@ooooo`;o0000EOooool2o`0004_ooooo1?l0000Sooooo`?o
0000@_ooool001kooooo00?o0000ooooooooool03oooool2o`0002Kooooo0_l00004ooooo`;o0000
Coooool2o`0001Wooooo0_l0000[ooooo`;o00000_ooool5o`0000gooooo0_l0000Dooooo`;o0000
6_ooool2o`000003ooooool0003o000002Cooooo000Nooooo`03o`000?oooooooooo00oooooo0_l0
000/ooooo`;o0000AOooool2o`0002?ooooo0_l0000[ooooo`;o00000_ooool2o`00013ooooo0_l0
000`ooooo`;o000000?oooooo`000?l000009?ooool001kooooo00?o0000ooooooooool0Q?ooool2
o`0009Wooooo0_l0000Vooooo`007_ooool00ol0003oooooooooo`0Booooo`;o0000Zoooool2o`00
05kooooo0_l0000Vooooo`007_ooool00ol0003oooooooooo`0Booooo`;o00006Oooool2o`0001Co
oooo0_l0000_ooooo`;o0000@?ooool2o`0000;ooooo0_l00003ooooo`;o0000K_ooool2o`0001Ko
oooo000Nooooo`03o`000?oooooooooo00cooooo0_l0000Oooooo`;o00005?ooool2o`0002oooooo
0_l0000/ooooo`;o00004_ooool2o`0000;ooooo0_l0001cooooo`;o00005_ooool001kooooo00?o
0000ooooooooool03?ooool2o`0008[ooooo0_l00008ooooo`;o00003Oooool2o`0003cooooo0_l0
001Fooooo`007_ooool00ol0003oooooooooo`03ooooo`;o0000Toooool2o`0001Oooooo0_l0000F
ooooo`;o00009?ooool2o`0005Kooooo000Nooooo`04o`000?oooooo0000o`0000;ooooo0_l0002@
ooooo`;o0000<_ooool2o`0004gooooo0_l0000]ooooo`007_ooool4o`0009Cooooo0_l0000Xoooo
o`;o00001_ooool2o`0004oooooo0_l0000Gooooo`;o00005?ooool001kooooo00?o0000oooooooo
ool01oooool2o`0008Oooooo0_l0000]ooooo`;o00001_ooool2o`0002_ooooo0_l0000kooooo`;o
00005?ooool001kooooo00?o0000ooooooooool01oooool2o`0000Oooooo0_l0000Booooo`;o0000
8_ooool2o`0004Kooooo0_l0001Rooooo`;o0000DOooool001kooooo00?o0000ooooooooool02ooo
ool2o`0000?ooooo0_l0000Booooo`;o00007Oooool2o`0000?ooooo0_l00031ooooo`;o0000;_oo
ool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l0000fooooo`;o00004_ooool2
o`0002Wooooo0_l00027ooooo`;o00004?ooool2o`0001cooooo0_l0000:ooooo`007_ooool00ol0
003oooooooooo`1Gooooo`;o0000:Oooool2o`00013ooooo0_l0000jooooo`;o0000Boooool2o`00
02Sooooo000Nooooo`03o`000?oooooooooo09Cooooo0_l0000jooooo`;o0000MOooool001kooooo
00?o0000ooooooooool0FOooool2o`0005Gooooo0_l0002Eooooo`007_ooool00ol0003ooooooooo
o`0Uooooo`;o00003_ooool2o`0002;ooooo0_l0001Eooooo`;o0000?Oooool2o`0000;ooooo0_l0
000=ooooo`;o0000=Oooool2o`0000cooooo000Nooooo`03o`000?oooooooooo02Gooooo0_l0000>
ooooo`;o0000<?ooool2o`0004kooooo0_l0000[ooooo`;o00002Oooool2o`0000;ooooo0_l0000=
ooooo`;o0000=Oooool2o`0000cooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l0000Xoooo
o`;o00005?ooool2o`0004kooooo0_l0000[ooooo`;o0000:?ooool2o`0001Kooooo0_l0000Ooooo
o`007_ooool00ol0003oooooooooo`0Wooooo`;o00008_ooool2o`0000Cooooo0_l0002kooooo`;o
00003oooool2o`0000Gooooo0_l0000Oooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o0000
5Oooool2o`0001Wooooo0_l0000Cooooo`;o0000_Oooool2o`0002Kooooo000Nooooo`03o`000?oo
oooooooo01Wooooo0_l0000Eooooo`;o0000;_ooool2o`000>Gooooo000Nooooo`03o`000?oooooo
oooo05Kooooo0_l0000jooooo`;o0000R?ooool2o`0002Wooooo000Nooooo`03o`000?oooooooooo
05Cooooo1?l00005ooooo`;o0000<?ooool2o`000003ooooool0003o000007Sooooo0_l0000<oooo
o`Co00003oooool2o`0001Sooooo000Nooooo`;o0000=Oooool2o`0001kooooo0_l00007ooooo`;o
00009Oooool2o`0000Oooooo1?l0001jooooo`?o00003?ooool2o`0000;ooooo0_l0000=ooooo`;o
00001oooool2o`0000oooooo000Nooooo`03o`000?oooooooooo037ooooo0_l000000ooooooo0000
o`00000kooooo`;o00004Oooool2o`0000Oooooo0_l0001looooo`;o00004Oooool2o`0001Kooooo
0_l00002ooooo`;o00002oooool001kooooo00?o0000ooooooooool06oooool2o`0001Cooooo0_l0
000nooooo`Co0000M?ooool2o`0004oooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`0K
ooooo`;o0000A?ooool2o`0000Sooooo0_l00006ooooo`;o0000K_ooool2o`0000Cooooo0_l0001L
ooooo`007_ooool00ol0003oooooooooo`1Pooooo`?o00002?ooool2o`0007Kooooo0_l0001Roooo
o`007_ooool00ol0003oooooooooo`0hooooo`;o00009_ooool2o`0005Wooooo0_l0002:ooooo`00
7_ooool00ol0003oooooooooo`0hooooo`;o0000POooool2o`00077ooooo0_l0000Gooooo`007_oo
ool00ol0003oooooooooo`0@ooooo`;o00000_ooool2o`0000Gooooo0_l0000Gooooo`;o0000n?oo
ool2o`0001Oooooo000Nooooo`03o`000?oooooooooo013ooooo0_l00002ooooo`;o00001Oooool2
o`0001Oooooo0_l0002Cooooo`;o0000O?ooool001kooooo00?o0000ooooooooool02oooool2o`00
04?ooooo0_l0000Xooooo`;o0000COooool2o`0000Wooooo0_l0000[ooooo`;o0000A?ooool001ko
oooo00?o0000ooooooooool02Oooool4o`0004?ooooo0_l0000Xooooo`;o00006oooool2o`0003_o
oooo0_l0000Yooooo`Co00007Oooool2o`0001;ooooo0_l0000Aooooo`007_ooool00ol0003ooooo
ooooo`09ooooo`;o0000S?ooool2o`0004_ooooo0_l0000Iooooo`;o00007oooool2o`0001;ooooo
0_l0000Aooooo`007_ooool00ol0003oooooooooo`0jooooo`;o00007?ooool2o`0000?ooooo0_l0
0006ooooo`;o0000>?ooool2o`0004?ooooo0_l0001Hooooo`;o00001oooool001kooooo00?o0000
ooooooooool0>_ooool2o`0001cooooo0_l00003ooooo`;o00001_ooool2o`0002oooooo0_l00002
ooooo`Co000000?oooooo`000?l00000WOooool2o`0000Oooooo000Dooooo`Co000000?o410@oooo
ooooool00oooool00ol0003oooooooooo`1nooooo`;o00005_ooool2o`0000;ooooo1?l0001=oooo
o`;o0000D?ooool2o`0000Sooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0M?ooool2o`0000Sooooo0_l0001[ooooo`;o0000D?ooool4o`0000Kooooo000Fooooo`03o`00
0?oooooooooo00Gooooo0ol0001dooooo`;o0000@oooool2o`0008Cooooo0_l00006ooooo`005_oo
ool00ol0003oooooooooo`31ooooo`;o0000S?ooool001Kooooo00?o0000ooooooooool0oooooom@
ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?oo
ooooD?ooool001Cooooo00?oEEEEofIVI_l00000oooooomBooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.82999 .80547 Mdot
.80331 .22123 Mdot
.50969 .33312 Mdot
.84344 .22561 Mdot
.35406 .68136 Mdot
.30354 .98351 Mdot
.81405 .82199 Mdot
.04454 .22545 Mdot
.64217 .6226 Mdot
.69293 .98832 Mdot
.51111 .66633 Mdot
.65492 .85741 Mdot
.80502 .95229 Mdot
.87227 .65715 Mdot
.14025 .51117 Mdot
.94445 .30451 Mdot
.72617 .01951 Mdot
.70505 .17441 Mdot
.17211 .06134 Mdot
.41348 .1342 Mdot
.27315 .48993 Mdot
.76335 .14306 Mdot
.67299 .63759 Mdot
.88211 .17415 Mdot
.1409 .73559 Mdot
.7523 .73274 Mdot
.91479 .32522 Mdot
.83746 .45739 Mdot
.11122 .15609 Mdot
.22849 .50366 Mdot
.16075 .40395 Mdot
.68587 .53509 Mdot
.80958 .69399 Mdot
.06154 .23059 Mdot
.07487 .92908 Mdot
.34567 .94473 Mdot
.88431 .48689 Mdot
.35051 .08274 Mdot
.92212 .97003 Mdot
.37233 .72546 Mdot
.73706 .88053 Mdot
.16262 .41964 Mdot
.49175 .70844 Mdot
.40893 .9028 Mdot
.45107 .82984 Mdot
.33374 .65061 Mdot
.52239 .72502 Mdot
.15401 .52162 Mdot
.68388 .51093 Mdot
.61128 .4998 Mdot
.52984 .37291 Mdot
.15453 .71665 Mdot
.97805 .36989 Mdot
.14174 .38323 Mdot
.42029 .79645 Mdot
.6422 .60781 Mdot
.01085 .05959 Mdot
.39201 .90423 Mdot
.51484 .29554 Mdot
.35356 .20787 Mdot
.92709 .03426 Mdot
.51242 .91866 Mdot
.23434 .65994 Mdot
.16556 .0957 Mdot
.36771 .27124 Mdot
.16042 .89563 Mdot
.74241 .25045 Mdot
.49287 .38389 Mdot
.75817 .48964 Mdot
.96936 .31808 Mdot
.15092 .00951 Mdot
.56139 .96747 Mdot
.07958 .2638 Mdot
.91812 .35048 Mdot
.89777 .64397 Mdot
.53448 .07488 Mdot
.57333 .1799 Mdot
.45564 .04424 Mdot
.96918 .03752 Mdot
.02393 .76261 Mdot
.37256 .44534 Mdot
.96078 .60191 Mdot
.23843 .56665 Mdot
.2841 .36152 Mdot
.17667 .26382 Mdot
.29018 .34681 Mdot
.14989 .72084 Mdot
.55829 .0793 Mdot
.42785 .60487 Mdot
.24288 .88878 Mdot
.3484 .61458 Mdot
.08966 .98875 Mdot
.00671 .26304 Mdot
.27564 .52436 Mdot
.71253 .75434 Mdot
.9363 .24319 Mdot
.65658 .39386 Mdot
.5932 .02724 Mdot
.64565 .5488 Mdot
.69261 .80382 Mdot
.23097 .75757 Mdot
.68036 .76476 Mdot
.80677 .12656 Mdot
.47285 .65467 Mdot
.95572 .21348 Mdot
.26302 .21 Mdot
.09368 .58289 Mdot
.49313 .88545 Mdot
.25055 .36167 Mdot
.83063 .99155 Mdot
.68388 .86268 Mdot
.25889 .29961 Mdot
.31197 .07497 Mdot
.49678 .3832 Mdot
.72843 .76389 Mdot
.00728 .79141 Mdot
.89704 .6147 Mdot
.80238 .67767 Mdot
.925 .21209 Mdot
.32878 .78239 Mdot
.6332 .88772 Mdot
.51425 .64475 Mdot
.96354 .02026 Mdot
.34132 .38429 Mdot
.584 .85906 Mdot
.71023 .16709 Mdot
.13797 .15746 Mdot
.90838 .18607 Mdot
.15581 .67072 Mdot
.91446 .65019 Mdot
.26023 .63293 Mdot
.77986 .88697 Mdot
.94928 .83687 Mdot
.1325 .14651 Mdot
.84995 .871 Mdot
.01378 .78038 Mdot
.32537 .74485 Mdot
.04377 .62793 Mdot
.31773 .47568 Mdot
.39552 .47174 Mdot
.03906 .6987 Mdot
.33511 .66254 Mdot
.68379 .21892 Mdot
.76261 .87062 Mdot
.85896 .52742 Mdot
.45565 .56291 Mdot
.96194 .82112 Mdot
.5063 .00206 Mdot
.52687 .1425 Mdot
.30499 .2389 Mdot
.18476 .42846 Mdot
.01622 .01138 Mdot
.30836 .74685 Mdot
.66925 .10565 Mdot
.4838 .33431 Mdot
.01361 .37069 Mdot
.6503 .80745 Mdot
.54959 .79874 Mdot
.8053 .18802 Mdot
.98592 .76326 Mdot
.23223 .91201 Mdot
.54579 .56292 Mdot
.05645 .53755 Mdot
.7839 .57591 Mdot
.89717 .83116 Mdot
.02541 .49535 Mdot
.37587 .46718 Mdot
.11919 .042 Mdot
.82236 .58188 Mdot
.83723 .38545 Mdot
.79893 .42416 Mdot
.89122 .79282 Mdot
.498 .394 Mdot
.09949 .05977 Mdot
.22884 .79984 Mdot
.18041 .67 Mdot
.3876 .09458 Mdot
.04388 .07793 Mdot
.75591 .54947 Mdot
.79657 .9101 Mdot
.1545 .97892 Mdot
.92916 .66575 Mdot
.44195 .30333 Mdot
.20211 .74151 Mdot
.86817 .97395 Mdot
.29663 .78043 Mdot
.57274 .14693 Mdot
.92178 .91073 Mdot
.25386 .14857 Mdot
.75978 .0338 Mdot
.38195 .36851 Mdot
.85365 .98202 Mdot
.11392 .49879 Mdot
.56862 .48813 Mdot
.69268 .16378 Mdot
.53378 .59638 Mdot
.06766 .24152 Mdot
.31847 .87859 Mdot
.35752 .97852 Mdot
.59286 .75744 Mdot
.00907 .00832 Mdot
.78206 .89698 Mdot
.55146 .79799 Mdot
.06287 .0103 Mdot
.53048 .03865 Mdot
.44877 .71907 Mdot
.76737 .04123 Mdot
.07061 .94255 Mdot
.93313 .70016 Mdot
.49986 .0613 Mdot
.53598 .57717 Mdot
.00691 .36916 Mdot
.47278 .56297 Mdot
.25149 .49386 Mdot
.92851 .97098 Mdot
.01661 .52827 Mdot
.4293 .76673 Mdot
.72709 .07853 Mdot
.58931 .90188 Mdot
.62326 .97419 Mdot
.87945 .0979 Mdot
.08217 .73536 Mdot
.23466 .45134 Mdot
.25294 .42153 Mdot
.89032 .9746 Mdot
.87983 .79836 Mdot
.11089 .87181 Mdot
.99692 .31166 Mdot
.75438 .06564 Mdot
.07162 .08455 Mdot
.01694 .29856 Mdot
.4201 .39095 Mdot
.11949 .39942 Mdot
.34853 .46404 Mdot
.78602 .06454 Mdot
.27656 .2649 Mdot
.7388 .22522 Mdot
.2642 .32107 Mdot
.77114 .31606 Mdot
.46162 .12074 Mdot
.90683 .97567 Mdot
.36456 .88958 Mdot
.80368 .76854 Mdot
.01905 .68622 Mdot
.7274 .14011 Mdot
.46654 .22756 Mdot
.76449 .20741 Mdot
.35505 .20081 Mdot
.23963 .1527 Mdot
.27565 .70429 Mdot
.43435 .01559 Mdot
.75456 .4564 Mdot
.50381 .86573 Mdot
.64083 .67566 Mdot
.8051 .25984 Mdot
.76123 .85536 Mdot
.2323 .31841 Mdot
.06937 .37631 Mdot
.129 .03496 Mdot
.55052 .46035 Mdot
.19804 .90787 Mdot
.55866 .67494 Mdot
.92012 .85237 Mdot
.67714 .12416 Mdot
.31661 .02618 Mdot
.253 .66142 Mdot
.57781 .522 Mdot
.46852 .88845 Mdot
.55711 .4574 Mdot
.31023 .50809 Mdot
.2802 .32523 Mdot
.69891 .84892 Mdot
.02773 .53968 Mdot
.0469 .32802 Mdot
.3408 .78721 Mdot
.37149 .18409 Mdot
.91379 .83074 Mdot
.26032 .31146 Mdot
.45909 .06417 Mdot
.01724 .52378 Mdot
.90871 .83681 Mdot
.49349 .06689 Mdot
.6491 .24418 Mdot
.94412 .37412 Mdot
.59382 .7342 Mdot
.01644 .12039 Mdot
.52948 .98833 Mdot
.58486 .85857 Mdot
.60585 .2592 Mdot
.20785 .54503 Mdot
.00162 .32706 Mdot
.42696 .08117 Mdot
.00062 .39837 Mdot
.57703 .87404 Mdot
.36403 .15831 Mdot
.82297 .52641 Mdot
.60631 .46703 Mdot
.70828 .54223 Mdot
.13523 .29044 Mdot
.35184 .59484 Mdot
.76125 .85629 Mdot
.12627 .12962 Mdot
.69654 .67793 Mdot
.90752 .12139 Mdot
.50963 .32756 Mdot
.01715 .22329 Mdot
.04842 .15686 Mdot
.31725 .58021 Mdot
.56358 .65251 Mdot
.6451 .13976 Mdot
.4111 .45624 Mdot
.18695 .43607 Mdot
.86726 .6184 Mdot
.9855 .3162 Mdot
.29943 .06034 Mdot
.20883 .26407 Mdot
.96245 .67516 Mdot
.37055 .1843 Mdot
.55628 .69031 Mdot
.06968 .39508 Mdot
.20332 .85104 Mdot
.32912 .4549 Mdot
.90264 .34832 Mdot
.2987 .87565 Mdot
.02956 .80926 Mdot
.22896 .66746 Mdot
.63193 .81404 Mdot
.87254 .22983 Mdot
.93738 .93611 Mdot
.35673 .21653 Mdot
.27759 .55896 Mdot
.50374 .71111 Mdot
.22002 .52476 Mdot
.94609 .32999 Mdot
.26546 .01446 Mdot
.80106 .35446 Mdot
.10382 .10287 Mdot
.62882 .8002 Mdot
.37694 .53559 Mdot
.65079 .54922 Mdot
.44437 .38712 Mdot
.14385 .39934 Mdot
.16182 .9568 Mdot
.92133 .9175 Mdot
.01412 .59646 Mdot
.71863 .53627 Mdot
.8042 .38549 Mdot
.17376 .17646 Mdot
.78257 .12588 Mdot
.33896 .47051 Mdot
.36605 .89465 Mdot
.83203 .9698 Mdot
.87137 .64327 Mdot
.44503 .40846 Mdot
.76751 .5023 Mdot
.70378 .61062 Mdot
.53623 .97664 Mdot
.84621 .22015 Mdot
.58503 .71839 Mdot
.9775 .91083 Mdot
.92076 .33431 Mdot
.33653 .52048 Mdot
.58381 .75118 Mdot
.70527 .35513 Mdot
.78157 .20541 Mdot
.14547 .97886 Mdot
.0045 .6574 Mdot
.45105 .10827 Mdot
.4358 .38341 Mdot
.75712 .00226 Mdot
.80013 .75344 Mdot
.03026 .30668 Mdot
.95452 .1757 Mdot
.42093 .98572 Mdot
.24499 .60334 Mdot
.86644 .38105 Mdot
.26808 .4997 Mdot
.65426 .74112 Mdot
.27321 .05966 Mdot
.33395 .30264 Mdot
.60106 .57329 Mdot
.4814 .15861 Mdot
.66451 .86875 Mdot
.65398 .88585 Mdot
.91955 .64989 Mdot
.01554 .10166 Mdot
.53146 .85552 Mdot
.06151 .7962 Mdot
.4014 .37951 Mdot
.50446 .99549 Mdot
.93315 .4145 Mdot
.15727 .73931 Mdot
.18394 .67522 Mdot
.78514 .35455 Mdot
.48307 .89832 Mdot
.10066 .27154 Mdot
.51704 .31652 Mdot
.11401 .33071 Mdot
.75893 .51669 Mdot
.00367 .6169 Mdot
.5503 .16713 Mdot
.34167 .5473 Mdot
.73703 .98579 Mdot
.17133 .68381 Mdot
.32704 .31777 Mdot
.27745 .3562 Mdot
.06214 .32787 Mdot
.39383 .00276 Mdot
.34594 .02352 Mdot
.44495 .65301 Mdot
.43907 .433 Mdot
.41212 .27074 Mdot
.74705 .12002 Mdot
.03179 .82948 Mdot
.23853 .97894 Mdot
.01922 .11213 Mdot
.88497 .90834 Mdot
.50145 .86856 Mdot
.12111 .40094 Mdot
.22927 .87493 Mdot
.53418 .41103 Mdot
.95421 .22235 Mdot
.26828 .11118 Mdot
.2523 .90485 Mdot
.30965 .99424 Mdot
.10609 .17879 Mdot
.21298 .83185 Mdot
.14469 .32906 Mdot
.32594 .9674 Mdot
.75451 .56054 Mdot
.42871 .48281 Mdot
.5698 .6481 Mdot
.8189 .20886 Mdot
.92897 .46256 Mdot
.50145 .94741 Mdot
.44825 .56334 Mdot
.06926 .18499 Mdot
.23244 .22928 Mdot
.00268 .24164 Mdot
.17746 .08615 Mdot
.63101 .27399 Mdot
.60234 .57345 Mdot
.33739 .82876 Mdot
.92701 .95313 Mdot
.49017 .66956 Mdot
.13151 .55254 Mdot
.00823 .61878 Mdot
.79512 .87391 Mdot
.95459 .41303 Mdot
.24163 .48246 Mdot
.00852 .02513 Mdot
.1682 .42602 Mdot
.58259 .84091 Mdot
.323 .95678 Mdot
.28082 .92025 Mdot
.3698 .80295 Mdot
.71174 .16033 Mdot
.19635 .49505 Mdot
.54629 .64803 Mdot
.52969 .78583 Mdot
.73866 .26024 Mdot
.25061 .34625 Mdot
.4666 .06496 Mdot
.26349 .80551 Mdot
.0553 .28787 Mdot
.84398 .75601 Mdot
.9376 .21792 Mdot
.42276 .76775 Mdot
.06023 .83636 Mdot
.00375 .45753 Mdot
.45456 .1886 Mdot
.36379 .51112 Mdot
.88538 .2056 Mdot
.12256 .44102 Mdot
.16225 .07931 Mdot
.99954 .57683 Mdot
.15581 .95269 Mdot
.05058 .70681 Mdot
.36846 .59444 Mdot
.85333 .84822 Mdot
.26595 .6238 Mdot
.48866 .4605 Mdot
.97763 .48544 Mdot
.07578 .04593 Mdot
.98572 .47773 Mdot
.06245 .69564 Mdot
.88752 .22567 Mdot
.25414 .0941 Mdot
.84447 .43003 Mdot
.15024 .21383 Mdot
.47627 .65061 Mdot
.20337 .57521 Mdot
.10029 .16268 Mdot
.84152 .04295 Mdot
.43532 .66477 Mdot
.76135 .08791 Mdot
.30393 .42988 Mdot
.50228 .48566 Mdot
.44406 .92076 Mdot
.45369 .27173 Mdot
.74364 .77333 Mdot
.50128 .95805 Mdot
.43125 .06192 Mdot
.14652 .45368 Mdot
.34368 .92384 Mdot
.47301 .66236 Mdot
.81391 .32185 Mdot
.88252 .51714 Mdot
.45642 .03673 Mdot
.09532 .05944 Mdot
.18747 .21618 Mdot
.52863 .86087 Mdot
.37353 .36562 Mdot
.21275 .71533 Mdot
.09363 .46314 Mdot
.9254 .09215 Mdot
.81573 .48353 Mdot
.4733 .55618 Mdot
.01859 .96692 Mdot
.72193 .03715 Mdot
.2904 .7459 Mdot
.86104 .79692 Mdot
.29815 .63946 Mdot
.13682 .03353 Mdot
.81895 .41019 Mdot
.09991 .45197 Mdot
.94871 .97997 Mdot
.10101 .49701 Mdot
.16408 .43504 Mdot
.42664 .76795 Mdot
.35839 .69109 Mdot
.82234 .77404 Mdot
.94352 .81594 Mdot
.07313 .72695 Mdot
.73643 .2998 Mdot
.70131 .51493 Mdot
.97418 .04464 Mdot
.73014 .89688 Mdot
.91386 .96967 Mdot
.66503 .7592 Mdot
.66245 .44819 Mdot
.88751 .86685 Mdot
.55989 .82783 Mdot
.31317 .19365 Mdot
.53023 .03563 Mdot
.13255 .61612 Mdot
.49254 .82095 Mdot
.54953 .19687 Mdot
.78642 .89473 Mdot
.72287 .0648 Mdot
.73723 .79095 Mdot
.26116 .15478 Mdot
.82816 .35515 Mdot
.19048 .21823 Mdot
.4204 .62117 Mdot
.10559 .88795 Mdot
.82355 .43556 Mdot
.80145 .45693 Mdot
.20252 .84543 Mdot
.41753 .43117 Mdot
.67109 .01249 Mdot
.47574 .16812 Mdot
.76487 .27291 Mdot
.18919 .95202 Mdot
.10223 .1068 Mdot
.82015 .64285 Mdot
.42652 .64363 Mdot
.60616 .64275 Mdot
.74395 .10197 Mdot
.77836 .28143 Mdot
.31757 .12137 Mdot
.56921 .10759 Mdot
.72988 .28915 Mdot
.88744 .88473 Mdot
.89841 .82864 Mdot
.89968 .84407 Mdot
.02167 .89107 Mdot
.71959 .16856 Mdot
.53233 .38258 Mdot
.05677 .36142 Mdot
.66868 .10286 Mdot
.43278 .93597 Mdot
.44841 .83845 Mdot
.58786 .0623 Mdot
.49378 .84415 Mdot
.95003 .25604 Mdot
.57758 .77218 Mdot
.14128 .29383 Mdot
.47558 .09679 Mdot
.11272 .25656 Mdot
.15004 .65086 Mdot
.93981 .70455 Mdot
.22893 .61001 Mdot
.7145 .60577 Mdot
.00324 .52228 Mdot
.03464 .78831 Mdot
.41725 .69339 Mdot
.34641 .6005 Mdot
.66747 .99298 Mdot
.23252 .26525 Mdot
.2362 .76546 Mdot
.0255 .88916 Mdot
.04338 .06568 Mdot
.11134 .08454 Mdot
.76639 .56578 Mdot
.32643 .29129 Mdot
.7099 .03625 Mdot
.19411 .63399 Mdot
.08298 .24257 Mdot
.03944 .24582 Mdot
.53987 .29481 Mdot
.62469 .78915 Mdot
.23378 .26617 Mdot
.49069 .05914 Mdot
.13003 .07229 Mdot
.54509 .89153 Mdot
.64019 .46787 Mdot
.13594 .35823 Mdot
.91333 .60269 Mdot
.1329 .82104 Mdot
.96749 .40631 Mdot
.98659 .67486 Mdot
.36993 .38084 Mdot
.52844 .65345 Mdot
.04016 .97371 Mdot
.86948 .6372 Mdot
.88091 .66489 Mdot
.48663 .90482 Mdot
.18665 .05186 Mdot
.2662 .27833 Mdot
.20253 .62357 Mdot
.25552 .4875 Mdot
.38176 .11022 Mdot
.1095 .98407 Mdot
.95916 .86308 Mdot
.58744 .11473 Mdot
.63694 .04672 Mdot
.82883 .59234 Mdot
.83174 .34097 Mdot
.28931 .86452 Mdot
.60722 .0764 Mdot
.01513 .26644 Mdot
.40283 .28428 Mdot
.64815 .87596 Mdot
.14047 .33003 Mdot
.75985 .94189 Mdot
.14704 .30467 Mdot
.98128 .54349 Mdot
.25655 .33193 Mdot
.33572 .06641 Mdot
.62326 .08164 Mdot
.91717 .18095 Mdot
.85742 .04941 Mdot
.07731 .89926 Mdot
.48897 .63605 Mdot
.12697 .03504 Mdot
.5346 .55215 Mdot
.32507 .04015 Mdot
.24856 .12185 Mdot
.55566 .6592 Mdot
.64985 .00352 Mdot
.15057 .6478 Mdot
.24706 .04355 Mdot
.20629 .24533 Mdot
.30484 .01014 Mdot
.23569 .66546 Mdot
.75771 .43897 Mdot
.04389 .34695 Mdot
.48302 .78654 Mdot
.73147 .46234 Mdot
.13153 .66312 Mdot
.21727 .8341 Mdot
.38551 .73556 Mdot
.10457 .04429 Mdot
.02821 .77012 Mdot
.7117 .77102 Mdot
.8605 .97146 Mdot
.61022 .4011 Mdot
.93049 .47639 Mdot
.52559 .8315 Mdot
.5022 .57549 Mdot
.78096 .70757 Mdot
.49988 .97041 Mdot
.51588 .93196 Mdot
.09306 .43223 Mdot
.53504 .72296 Mdot
.1449 .46625 Mdot
.68905 .77653 Mdot
.18116 .65697 Mdot
.14987 .59501 Mdot
.39535 .01186 Mdot
.60761 .8669 Mdot
.79928 .23027 Mdot
.0377 .2812 Mdot
.22847 .18643 Mdot
.28099 .44469 Mdot
.29442 .93964 Mdot
.70303 .81923 Mdot
.05144 .54317 Mdot
.78211 .88447 Mdot
.01837 .91301 Mdot
.84795 .26964 Mdot
.6744 .93336 Mdot
.87658 .31925 Mdot
.76848 .54731 Mdot
.08642 .13134 Mdot
.43023 .22217 Mdot
.80084 .75081 Mdot
.32621 .17939 Mdot
.99815 .75923 Mdot
.16653 .62011 Mdot
.09636 .01426 Mdot
.32994 .73861 Mdot
.57817 .9341 Mdot
.72241 .85197 Mdot
.62538 .42571 Mdot
.91266 .47552 Mdot
.38446 .47291 Mdot
.45832 .06993 Mdot
.71595 .8849 Mdot
.02943 .11408 Mdot
.85426 .95123 Mdot
.80401 .50244 Mdot
.63847 .78807 Mdot
.42777 .757 Mdot
.01516 .89577 Mdot
.39087 .98431 Mdot
.37754 .57606 Mdot
.38289 .54283 Mdot
.85829 .97818 Mdot
.16898 .58862 Mdot
.24944 .22954 Mdot
.99141 .45061 Mdot
.30775 .51159 Mdot
.36986 .99489 Mdot
.90792 .77261 Mdot
.99658 .46158 Mdot
.80484 .65671 Mdot
.50149 .30651 Mdot
.34725 .24188 Mdot
.03229 .65785 Mdot
.36506 .13735 Mdot
.07982 .15229 Mdot
.09497 .76282 Mdot
.818 .6647 Mdot
.61264 .50543 Mdot
.50164 .73141 Mdot
.95012 .69257 Mdot
.25897 .50125 Mdot
.04529 .87394 Mdot
.97223 .07444 Mdot
.84722 .45769 Mdot
.92229 .30053 Mdot
.46589 .37309 Mdot
.96815 .99259 Mdot
.1282 .48389 Mdot
.87626 .11077 Mdot
.57526 .8136 Mdot
.53332 .43575 Mdot
.71409 .36443 Mdot
.06628 .04392 Mdot
.7016 .30813 Mdot
.2967 .8961 Mdot
.05244 .87396 Mdot
.59732 .75298 Mdot
.55369 .73359 Mdot
.57267 .68652 Mdot
.30466 .30918 Mdot
.83248 .68015 Mdot
.92676 .43447 Mdot
.18367 .1052 Mdot
.14616 .16836 Mdot
.17204 .06299 Mdot
.52048 .64121 Mdot
.79447 .12111 Mdot
.4781 .87074 Mdot
.21017 .43578 Mdot
.02437 .19319 Mdot
.69936 .80022 Mdot
.66253 .67786 Mdot
.7565 .28371 Mdot
.96915 .06427 Mdot
.6105 .12749 Mdot
.05933 .07947 Mdot
.39341 .78023 Mdot
.54127 .24974 Mdot
.4303 .60186 Mdot
.03878 .45777 Mdot
.1342 .09286 Mdot
.77766 .61263 Mdot
.43436 .51689 Mdot
.16239 .88726 Mdot
.69924 .11357 Mdot
.94155 .58266 Mdot
.16543 .29202 Mdot
.05294 .81768 Mdot
.68219 .37282 Mdot
.67372 .29835 Mdot
.23199 .77157 Mdot
.5506 .89123 Mdot
.08941 .64748 Mdot
.94364 .48185 Mdot
.45858 .32736 Mdot
.62942 .52264 Mdot
.65968 .0603 Mdot
.8106 .02131 Mdot
.42844 .62532 Mdot
.72454 .32617 Mdot
.56339 .34257 Mdot
.02296 .81155 Mdot
.46523 .4251 Mdot
.3337 .93307 Mdot
.4609 .8562 Mdot
.43634 .7409 Mdot
.03041 .46129 Mdot
.78233 .01349 Mdot
.37503 .62327 Mdot
.07141 .24822 Mdot
.88758 .84551 Mdot
.60463 .99789 Mdot
.23542 .69794 Mdot
.54861 .14661 Mdot
.99107 .31045 Mdot
.03703 .00872 Mdot
.1824 .53822 Mdot
.27677 .18774 Mdot
.391 .87686 Mdot
.72764 .22401 Mdot
.82397 .29071 Mdot
.46996 .87883 Mdot
.05024 .21997 Mdot
.00906 .98348 Mdot
.7765 .52968 Mdot
.46292 .05882 Mdot
.94267 .25121 Mdot
.48058 .93229 Mdot
.526 .99625 Mdot
.08116 .75299 Mdot
.27835 .09959 Mdot
.40045 .61543 Mdot
.18187 .68777 Mdot
.8687 .57242 Mdot
.4076 .54345 Mdot
.04748 .75347 Mdot
.56528 .82876 Mdot
.50193 .88568 Mdot
.7904 .36808 Mdot
.9544 .87357 Mdot
.43448 .6726 Mdot
.14641 .98904 Mdot
.2535 .38783 Mdot
.75415 .62725 Mdot
.00162 .69648 Mdot
.6605 .85709 Mdot
.75981 .17808 Mdot
.80587 .90362 Mdot
.05191 .40213 Mdot
.45205 .15064 Mdot
.16013 .94841 Mdot
.33994 .52614 Mdot
.9888 .45813 Mdot
.36925 .31072 Mdot
.60189 .08351 Mdot
.73175 .95114 Mdot
.7554 .24955 Mdot
.90766 .22053 Mdot
.08473 .81959 Mdot
.08638 .08185 Mdot
.86994 .58036 Mdot
.82558 .00157 Mdot
.6062 .51083 Mdot
.40808 .61736 Mdot
.68656 .03781 Mdot
.10704 .13991 Mdot
.0526 .96796 Mdot
.29098 .97647 Mdot
.59598 .71147 Mdot
.41967 .01294 Mdot
.55225 .63226 Mdot
.25754 .81759 Mdot
.47188 .17783 Mdot
.36196 .86646 Mdot
.7124 .82076 Mdot
.13507 .4193 Mdot
.10752 .67832 Mdot
.17215 .2009 Mdot
.99415 .82755 Mdot
.89988 .01868 Mdot
.43151 .31779 Mdot
.68243 .27567 Mdot
.97608 .60795 Mdot
.20152 .43759 Mdot
.39965 .22178 Mdot
.02942 .58523 Mdot
.68772 .58644 Mdot
.55684 .33141 Mdot
.52204 .69485 Mdot
.69702 .02014 Mdot
.65548 .61158 Mdot
.57931 .85722 Mdot
.40097 .44437 Mdot
.98914 .74952 Mdot
.37621 .07964 Mdot
.69903 .22637 Mdot
.14455 .72665 Mdot
.83866 .49065 Mdot
.4488 .25379 Mdot
.8584 .29922 Mdot
.83859 .83953 Mdot
.47751 .11289 Mdot
.01671 .25996 Mdot
.8528 .41115 Mdot
.74609 .67224 Mdot
.01806 .93158 Mdot
.16086 .8161 Mdot
.27573 .80123 Mdot
.19018 .90528 Mdot
.66409 .28877 Mdot
.96716 .53343 Mdot
.50634 .09729 Mdot
.20343 .96498 Mdot
.05391 .81491 Mdot
.04701 .66601 Mdot
.38466 .22935 Mdot
.42043 .0843 Mdot
.25201 .3933 Mdot
.13298 .1583 Mdot
.0992 .78341 Mdot
.14908 .36957 Mdot
.33916 .42997 Mdot
.03471 .65351 Mdot
.07177 .40486 Mdot
.0496 .76256 Mdot
.76521 .65214 Mdot
.91634 .08025 Mdot
.67944 .17883 Mdot
.55072 .07898 Mdot
.19946 .80044 Mdot
.17292 .74034 Mdot
.17998 .99182 Mdot
.27042 .64017 Mdot
.74979 .51189 Mdot
.11984 .74306 Mdot
.8693 .3057 Mdot
.97575 .14008 Mdot
.86336 .48273 Mdot
.01731 .06294 Mdot
.39916 .22797 Mdot
.51113 .07758 Mdot
.16441 .52665 Mdot
.23237 .36744 Mdot
.84196 .39382 Mdot
.19653 .82157 Mdot
.38442 .63711 Mdot
.97857 .02838 Mdot
.36474 .56779 Mdot
.89365 .96072 Mdot
.64018 .88157 Mdot
.84413 .72288 Mdot
.23305 .73184 Mdot
.1544 .78362 Mdot
.04018 .13293 Mdot
.74763 .67745 Mdot
.03246 .8748 Mdot
.57965 .7765 Mdot
.83581 .31695 Mdot
.79442 .84281 Mdot
.20954 .73258 Mdot
.97902 .79776 Mdot
.77538 .89078 Mdot
.01056 .25457 Mdot
.46532 .21676 Mdot
.82261 .24937 Mdot
.32333 .97418 Mdot
.17757 .78695 Mdot
.26334 .92073 Mdot
.28681 .13843 Mdot
.56129 .65069 Mdot
.43902 .14014 Mdot
.26446 .63511 Mdot
.61079 .15481 Mdot
.65553 .08422 Mdot
.68447 .07798 Mdot
.19067 .9475 Mdot
.80958 .66519 Mdot
.10268 .96321 Mdot
.77624 .03857 Mdot
.60967 .93208 Mdot
.27661 .98129 Mdot
.09425 .36252 Mdot
.65981 .64108 Mdot
.78865 .65698 Mdot
.02435 .2753 Mdot
.01857 .59779 Mdot
.46724 .11716 Mdot
.63072 .80844 Mdot
.8739 .32681 Mdot
.59683 .89116 Mdot
.22278 .27784 Mdot
.19816 .81408 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool02oooool2o`000003ooooool0003ooooo00kooooo00?o0000oooooooo
ool03Oooool3o`0000gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0<ooooo`;o
00003oooool00ol0003oooooooooo`0=ooooo`04o`000?oooooo0000o`0000gooooo00?o0000oooo
ooooool01?ooool2o`0000Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0;ooooo`;o000000?oooooo`000?ooool03_ooool00ol0003o
ooooooooo`0=ooooo`?o00003Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00co
oooo0_l0000?ooooo`03o`000?oooooooooo00gooooo00Co0000ooooool0003o00003Oooool00ol0
003oooooooooo`04ooooo`;o00001oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool01?l0003o
ooooo`000?l00007ooooo`;o00001_ooool2o`0001_ooooo0_l0000`ooooo`;o0000i_ooool001ko
oooo00?o0000ooooool000000ol00005ooooo`;o00001_ooool2o`0001_ooooo0_l0000`ooooo`;o
00006oooool2o`0000Kooooo0_l0001@ooooo`;o00008_ooool2o`0004_ooooo000Nooooo`04o`00
0?ooooooooooooooo`;o00006?ooool2o`0003Gooooo0_l0000Xooooo`;o00001_ooool2o`0000?o
oooo0_l0001;ooooo`;o00008_ooool2o`0004_ooooo000Nooooo`03o`000?oooooooooo01_ooooo
0_l0000eooooo`;o0000=Oooool2o`0005gooooo0_l0000fooooo`;o00009Oooool001kooooo00?o
0000ooooooooool0g_ooool2o`0000Sooooo0_l0000Iooooo`;o00006oooool2o`0001?ooooo0_l0
000@ooooo`007_ooool01?l0003oooooo`000?l0001[ooooo`;o0000L?ooool2o`0002?ooooo0_l0
000`ooooo`;o00004?ooool001kooooo00Co0000ooooool0003o0000H_ooool2o`0000Oooooo0_l0
001?ooooo`;o0000Noooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo06?ooooo0_l0001H
ooooo`;o0000Noooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo02Gooooo1Ol00039oooo
o`;o0000=?ooool2o`0001cooooo000Nooooo`03o`000?oooooooooo02Gooooo1Ol0001Vooooo`;o
00005_ooool2o`00037ooooo0_l00006ooooo`;o00000_ooool2o`0000[ooooo0_l0000dooooo`;o
00003?ooool2o`0000kooooo000Nooooo`03o`000?oooooooooo06Kooooo0_l0000Xooooo`;o0000
5_ooool2o`00037ooooo0_l00006ooooo`;o00000_ooool2o`0000cooooo0_l000000ooooooo0000
o`00000mooooo`;o00003_ooool001kooooo00?o0000ooooooooool04Oooool2o`0000_ooooo0_l0
0003ooooo`;o00009oooool2o`0001Sooooo0_l0000Xooooo`;o00005_ooool2o`0004_ooooo0_l0
00000ooooooo0000o`00000Cooooo`;o0000>?ooool001kooooo00?o0000ooooooooool04Oooool2
o`0000;ooooo0_l00007ooooo`;o00000oooool2o`0002Oooooo0_l00012ooooo`;o0000>Oooool2
o`00043ooooo0_l0000Zooooo`;o00003?ooool001kooooo00?o0000ooooooooool05Oooool2o`00
0;Cooooo0_l00016ooooo`;o00009?ooool2o`0000cooooo000Nooooo`;o0000>_ooool2o`000=So
oooo0_l0000booooo`007_ooool00ol0003oooooooooo`0iooooo`;o0000ooooool=ooooo`007_oo
ool01?l0003oooooo`000?l0000Jooooo`?o0000=oooool2o`0003_ooooo0_l00007ooooo`;o0000
Z_ooool001kooooo00Go0000ooooool0003o0000ooooo`02o`0001Oooooo0ol0000Fooooo`;o0000
7oooool2o`0000Kooooo0_l0000Yooooo`;o00002?ooool2o`0000Oooooo0_l000000ooooooo0000
o`00000Kooooo`;o00005Oooool2o`0007?ooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0
0006ooooo`;o0000:?ooool2o`0002Oooooo0_l0000Yooooo`;o00001oooool2o`000003ooooool0
003o000000Sooooo0_l0000Kooooo`;o00005Oooool2o`0001?ooooo0_l00008ooooo`;o00002?oo
ool2o`0003[ooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o0000:?ooool2
o`0003?ooooo0_l0000Vooooo`;o000000?oooooo`000?l000001_ooool2o`0004Wooooo0_l00008
ooooo`;o00002?ooool2o`0003[ooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`1Yoooo
o`;o00009_ooool2o`0000Wooooo0_l0002Yooooo`007_ooool00ol0003oooooooooo`0Vooooo`;o
0000>Oooool2o`0002kooooo0_l0000Gooooo`;o0000S?ooool2o`0000gooooo000Nooooo`03o`00
0?oooooooooo00[ooooo0_l0000Jooooo`;o0000>Oooool2o`0003oooooo0_l00006ooooo`;o0000
5Oooool2o`0001Oooooo0_l0001Looooo`;o00003Oooool001kooooo00?o0000ooooooooool02_oo
ool2o`0000?ooooo0_l0000Pooooo`;o0000@oooool2o`0000oooooo0_l0000Iooooo`;o00002ooo
ool4o`0000kooooo0_l0000Gooooo`;o00003?ooool2o`0003cooooo0_l0000Oooooo`007_ooool0
0ol0003oooooooooo`0?ooooo`;o00001oooool2o`0001Oooooo0_l0000kooooo`;o00001_ooool2
o`0000gooooo1?l0000Vooooo`Co00003Oooool2o`0000Gooooo0_l00008ooooo`;o00005Oooool2
o`0003cooooo0_l0000Oooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o00000oooool2o`00
00Kooooo0_l0000Dooooo`;o0000=_ooool2o`0001Gooooo0_l0000iooooo`;o00001Oooool2o`00
00Sooooo0_l0001dooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o00002oooool2o`0001Co
oooo0_l0002kooooo`;o0000D_ooool001kooooo00?o0000ooooooooool0:?ooool2o`000<Wooooo
0_l0000dooooo`;o00007?ooool001kooooo00?o0000ooooooooool0:?ooool2o`0000Sooooo0_l0
000Kooooo`;o0000:Oooool2o`000:gooooo0_l0000Looooo`007_ooool00ol0003oooooooooo`0b
ooooo`;o00006oooool2o`0000Gooooo0_l0000Rooooo`;o00006oooool2o`0000Sooooo0_l0001g
ooooo`;o0000:oooool001kooooo0_l00002ooooo`;o00006oooool2o`0003Kooooo0_l0000ooooo
o`;o00002?ooool2o`0003;ooooo0_l0000Gooooo`;o0000:_ooool2o`0002_ooooo000Nooooo`04
o`000?ooooooooooooooo`;o00006oooool2o`0001Sooooo0_l0002Kooooo`;o00005oooool2o`00
05Oooooo000Nooooo`03o`000?oooooooooo01gooooo0_l0000Iooooo`;o0000EOooool2o`0002Co
oooo0_l0000Nooooo`;o0000L?ooool001kooooo00?o0000ooooooooool00_ooool2o`0001Wooooo
0_l0000dooooo`;o00008oooool2o`0001Gooooo0_l0000Tooooo`;o0000H_ooool2o`0002cooooo
000Nooooo`03o`000?oooooooooo00;ooooo0_l000000ooooooo0000o`00001<ooooo`;o00008ooo
ool2o`0001gooooo0_l0000Rooooo`;o00008_ooool2o`0003Sooooo0_l0000/ooooo`007_ooool0
0ol0003oooooooooo`05ooooo`;o0000SOooool2o`000003ooooool0003o000002;ooooo0_l0000R
ooooo`;o0000I_ooool001kooooo00Co0000oooooooooooooooo0_l0001Pooooo`;o0000;Oooool4
o`0005Wooooo0_l0000=ooooo`;o00008oooool2o`0002;ooooo000Nooooo`04o`000?oooooooooo
ooooo`;o0000B_ooool2o`0001Cooooo0_l0000]ooooo`;o0000A?ooool2o`0001Gooooo0_l0000=
ooooo`;o00008oooool2o`0002;ooooo000Nooooo`03o`000?oooooooooo04gooooo0_l0001coooo
o`;o00005?ooool2o`00023ooooo0_l00006ooooo`;o0000@oooool001kooooo00?o0000oooooooo
ool09Oooool2o`0009_ooooo0_l0000fooooo`;o00001_ooool2o`0004?ooooo000Nooooo`03o`00
0?oooooooooo00Wooooo0_l0000=ooooo`;o00002oooool2o`000?oooooo8Oooool001kooooo00?o
0000ooooooooool02Oooool2o`0000gooooo0_l0001Xooooo`;o0000`oooool001kooooo00?o0000
ooooooooool0FOooool2o`0001Sooooo0_l0000=ooooo`;o0000B_ooool2o`0007Oooooo000Noooo
o`03o`000?oooooooooo01oooooo0_l0000hooooo`;o00006?ooool2o`0001Kooooo0_l0000Joooo
o`;o00009Oooool2o`0001Sooooo0_l0001?ooooo`;o00003?ooool001kooooo00?o0000oooooooo
ool07oooool2o`0006[ooooo0_l0000Jooooo`;o0000?oooool2o`0000[ooooo0_l00013ooooo`;o
00003?ooool001kooooo00?o0000ooooooooool09oooool2o`0002Gooooo0_l0001Nooooo`;o0000
1_ooool2o`0003cooooo0_l0001Aooooo`007_ooool2o`0002Sooooo0_l0000Uooooo`;o0000?ooo
ool2o`0001gooooo0_l00006ooooo`;o0000Soooool001kooooo00?o0000ooooooooool05_ooool2
o`0003;ooooo0_l00005ooooo`;o0000??ooool2o`00037ooooo0_l00023ooooo`007_ooool00ol0
003oooooooooo`0<ooooo`;o00002?ooool2o`0000Sooooo0_l00005ooooo`Co00007oooool2o`00
00Gooooo0_l0001_ooooo`;o0000Poooool001kooooo00?o0000ooooooooool03?ooool2o`0001;o
oooo0_l00005ooooo`Co0000Aoooool2o`0002Cooooo0_l00019ooooo`;o0000H_ooool001kooooo
00?o0000ooooooooool07?ooool2o`0005Cooooo0_l0000Tooooo`;o0000@oooool2o`0000Cooooo
0_l0001Rooooo`007_ooool00ol0003oooooooooo`0Looooo`;o0000TOooool2o`0002cooooo0_l0
0004ooooo`;o0000H_ooool001kooooo00?o0000ooooooooool0:oooool2o`0006[ooooo0_l0000F
ooooo`;o0000<_ooool2o`000003ooooool0003o000005oooooo000Nooooo`03o`000?oooooooooo
02_ooooo0_l0001Zooooo`;o0000COooool2o`0005oooooo000Nooooo`03o`000?oooooooooo03Co
oooo0_l0002[ooooo`;o0000>?ooool2o`0001Gooooo0_l0000Cooooo`007_ooool00ol0003ooooo
ooooo`0Nooooo`;o00005?ooool2o`00033ooooo0_l0000]ooooo`;o0000@_ooool2o`0000Kooooo
0_l0000@ooooo`;o00009_ooool2o`0001Gooooo0_l0000Cooooo`007_ooool00ol0003ooooooooo
o`0Nooooo`;o0000A_ooool2o`0002gooooo0_l0000Oooooo`;o00008Oooool2o`0001Sooooo0_l0
000aooooo`;o00007oooool001kooooo00?o0000ooooooooool04_ooool2o`00063ooooo0ol0000o
ooooo`;o0000K_ooool2o`0001oooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0000boooo
o`;o00003_ooool2o`0001cooooo0ol0000Iooooo`;o0000L?ooool2o`0001oooooo0_l0000Roooo
o`007_ooool00ol0003oooooooooo`16ooooo`;o00003_ooool2o`0003Sooooo0_l0001`ooooo`;o
00007oooool2o`0002;ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo1Ol00006ooooo`03o`000?oooooooooo00Cooooo0_l0001Looooo`;o0000hoooool000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A4
00Kooooo00?o0000ooooooooool01?ooool2o`0005cooooo0_l0001;ooooo`;o0000U_ooool000?o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0000doooo
o`;o0000>Oooool2o`0003kooooo0_l0002Fooooo`000oooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`0dooooo`;o0000>Oooool2o`00
0=Kooooo0003ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05oooo
o`03o`000?oooooooooo0?Cooooo0_l00004ooooo`;o00008?ooool2o`0002Wooooo0003ooooo`05
oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
057ooooo0_l0000Looooo`;o0000Poooool2o`0000Cooooo0_l0000:ooooo`;o00005?ooool2o`00
02Wooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@00Kooooo00?o0000ooooooooool0DOooool2o`0001cooooo0_l0002Eooooo`;o00008Oooool2
o`0000Sooooo0_l0000Booooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo02gooooo0_l0000:ooooo`;o0000=Ooo
ool2o`000;Oooooo0_l00008ooooo`;o00004_ooool001kooooo00?o0000ooooooooool0;Oooool2
o`0000[ooooo0ol0000dooooo`;o00008Oooool2o`0004Gooooo0_l0001Aooooo`;o00006?ooool0
01kooooo00?o0000ooooooooool03?ooool2o`0002cooooo0_l00012ooooo`;o00002?ooool2o`00
00Wooooo0_l00015ooooo`;o00009Oooool2o`0000cooooo0_l0000Booooo`;o00002?ooool2o`00
00?ooooo0_l0000Cooooo`007_ooool01?l0003oooooooooooooool2o`0000Oooooo1?l0001`oooo
o`;o00002?ooool2o`0005kooooo0_l00002ooooo`;o00004oooool2o`0000_ooooo0ol0000;oooo
o`;o00001Oooool2o`0000gooooo0_l0000Cooooo`007_ooool01?l0003oooooooooooooool2o`00
00Oooooo0_l0001booooo`;o00005?ooool2o`0004Wooooo0_l00007ooooo`;o00000_ooool2o`00
023ooooo0_l0000<ooooo`;o0000:Oooool001kooooo00?o0000ooooooooool04?ooool2o`0003Go
oooo0_l00004ooooo`;o0000:_ooool2o`0000?ooooo0_l0000Dooooo`;o0000BOooool2o`0001oo
oooo0_l0000Fooooo`;o0000;Oooool001kooooo00?o0000ooooooooool04?ooool2o`0003Gooooo
0_l00004ooooo`;o0000:_ooool2o`0008Gooooo0_l0000Fooooo`;o0000;Oooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`1Oooooo`;o0000i_ooool0
01kooooo0_l0000Cooooo`;o00000oooool2o`0004Kooooo0_l0000<ooooo`;o0000H?ooool2o`00
05_ooooo0_l0000Iooooo`007_ooool2o`0000[ooooo0_l00007ooooo`;o00000oooool2o`0002Ko
oooo0_l0000/ooooo`;o0000H?ooool2o`0005_ooooo0_l0000Iooooo`007_ooool00ol0003ooooo
ooooo`09ooooo`;o00002?ooool2o`0002[ooooo0_l0001[ooooo`;o0000?oooool2o`0000;ooooo
0_l0000Dooooo`;o0000?_ooool001kooooo0_l0000Dooooo`;o0000Uoooool2o`0003oooooo0_l0
0002ooooo`;o00005?ooool2o`0002Gooooo0_l0000Gooooo`007_ooool01?l0003oooooo`000?l0
000Pooooo`;o0000Joooool2o`0009kooooo0_l000000ooooooo0000o`00000Dooooo`007_ooool0
1?l0003oooooo`000?l0000Pooooo`;o0000Joooool2o`00037ooooo0_l0001^ooooo`;o00005?oo
ool001kooooo00Co0000oooooooooooooooo0_l0002nooooo`;o0000:Oooool2o`0001Cooooo0_l0
0013ooooo`007_ooool3o`000003ooooool0003o000001?ooooo0_l0000Mooooo`;o00002Oooool2
o`0000Gooooo0_l0000=ooooo`;o0000U?ooool2o`0001Cooooo0_l00013ooooo`007_ooool3o`00
0003ooooool0003o000001?ooooo0_l0000Mooooo`;o00002Oooool2o`0000Gooooo0ol0000<oooo
o`;o0000koooool001kooooo00Co0000oooooooooooooooo0_l0000Jooooo`;o0000:Oooool2o`00
02Wooooo0_l0000=ooooo`;o00002oooool2o`0007oooooo0_l0000eooooo`007_ooool00ol0003o
ooooooooo`0Mooooo`;o0000E?ooool2o`0000gooooo0_l0000;ooooo`;o0000>?ooool2o`0002[o
oooo0_l0000Iooooo`;o0000=Oooool001kooooo00?o0000ooooooooool01?ooool2o`0003kooooo
0_l00023ooooo`;o00003oooool2o`0001Wooooo0_l0001@ooooo`007_ooool00ol0003ooooooooo
o`04ooooo`;o00000_ooool2o`0003[ooooo0_l0000<ooooo`;o0000Q_ooool2o`0006_ooooo000N
ooooo`03o`000?oooooooooo00Sooooo0_l00018ooooo`;o0000:oooool2o`00077ooooo0_l00005
ooooo`;o0000C?ooool001kooooo00?o0000ooooooooool0Ooooool2o`00077ooooo0_l00005oooo
o`;o0000C?ooool001kooooo00?o0000ooooooooool03_ooool2o`0001Sooooo0_l0002Zooooo`;o
00004oooool2o`0005cooooo000Nooooo`03o`000?oooooooooo00kooooo0_l0000Hooooo`;o0000
2?ooool2o`0003;ooooo0_l0001/ooooo`;o00004oooool2o`0001gooooo0_l0000mooooo`007_oo
ool00ol0003oooooooooo`0Zooooo`;o00001_ooool2o`0003;ooooo0_l0000kooooo`;o00001_oo
ool2o`0005_ooooo0_l0000mooooo`007_ooool01?l0003oooooooooooooool2o`0002Oooooo0_l0
000Tooooo`;o0000DOooool2o`0000Kooooo0_l0000Zooooo`;o0000>_ooool2o`0003;ooooo000N
ooooo`;o00000_ooool2o`0004gooooo0_l0000Fooooo`;o0000KOooool2o`0001;ooooo0_l0000V
ooooo`;o00004oooool2o`0001gooooo000Nooooo`03o`000?oooooooooo02cooooo0_l0000joooo
o`;o00008_ooool2o`0005gooooo0_l0000Zooooo`;o00003oooool2o`0000Gooooo0_l0000Foooo
o`007_ooool00ol0003oooooooooo`06ooooo`;o00009?ooool2o`0005kooooo0_l0000Aooooo`;o
0000?oooool2o`0003Gooooo0_l0000Fooooo`;o00005_ooool001kooooo00?o0000ooooooooool0
1_ooool2o`0004Wooooo0_l0000<ooooo`;o00004oooool2o`0002Wooooo0_l0000oooooo`;o0000
G?ooool4o`0000Gooooo000Nooooo`03o`000?oooooooooo057ooooo0_l0000<ooooo`;o00004ooo
ool2o`000<Sooooo1?l00005ooooo`007_ooool00ol0003oooooooooo`1Vooooo`;o00008?ooool2
o`0001[ooooo0_l0001Aooooo`;o00004oooool2o`0002Wooooo0_l00003ooooo`;o00002Oooool0
01kooooo00?o0000ooooooooool0Aoooool2o`0000Wooooo0_l0000Booooo`;o00008?ooool2o`00
01[ooooo0_l0001Aooooo`;o00004oooool2o`0000_ooooo0_l0000Looooo`;o00000oooool2o`00
00Wooooo000Nooooo`03o`000?oooooooooo04Oooooo0_l00009ooooo`;o0000/?ooool2o`0001?o
oooo0_l0000/ooooo`007Oooool2o`0005Wooooo0_l0000hooooo`;o0000E?ooool2o`0001_ooooo
0_l0000Booooo`;o00002oooool2o`00023ooooo000Mooooo`;o00003Oooool2o`0000?ooooo0_l0
000Hooooo`?o0000:_ooool2o`0003Sooooo0_l0000?ooooo`;o0000@oooool2o`0002oooooo0_l0
000;ooooo`;o00002?ooool2o`0001Kooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l00003
ooooo`;o00003oooool2o`0000Oooooo0ol0000Rooooo`;o0000DOooool2o`0000gooooo0_l0001l
ooooo`;o00005_ooool001kooooo00?o0000ooooooooool08Oooool2o`0002cooooo0_l00018oooo
o`;o00001oooool2o`0000gooooo0_l0001dooooo`;o00007_ooool001kooooo00?o0000oooooooo
ool0VOooool2o`0008cooooo0_l0000Nooooo`007_ooool00ol0003oooooooooo`2cooooo`;o0000
EOooool2o`0003_ooooo000Nooooo`03o`000?oooooooooo0;?ooooo0_l0001Eooooo`;o0000>ooo
ool001kooooo00?o0000ooooooooool02_ooool2o`00047ooooo0_l0000;ooooo`;o0000aOooool2
o`0002Cooooo000Nooooo`;o00002oooool2o`00047ooooo0_l0000;ooooo`;o0000aOooool2o`00
00?ooooo0_l0000Oooooo`007_ooool00ol0003oooooooooo`3Qooooo`;o00006?ooool2o`0000?o
oooo0_l00007ooooo`;o00006oooool2o`0001oooooo000Nooooo`03o`000?oooooooooo05Kooooo
0_l00029ooooo`;o00006?ooool2o`0000?ooooo0_l00007ooooo`;o0000??ooool001kooooo00?o
0000ooooooooool0:?ooool2o`0002cooooo0_l0003_ooooo`007_ooool00ol0003oooooooooo`0>
ooooo`;o00002oooool2o`0000_ooooo0_l0000Sooooo`;o00002Oooool2o`000>gooooo000Noooo
o`03o`000?oooooooooo00kooooo0_l0000;ooooo`;o0000:_ooool2o`0000Cooooo0_l00009oooo
o`;o00006oooool2o`0006gooooo0_l0001Qooooo`007_ooool3o`0002cooooo0_l0000Iooooo`;o
0000;?ooool2o`000003ooooool0003o000006[ooooo0_l0000Gooooo`;o0000>oooool2o`0000_o
oooo000Nooooo`Go0000:_ooool2o`0004[ooooo0_l0000Iooooo`;o00004oooool2o`00033ooooo
0_l0000Qooooo`;o0000>oooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo00;o00004?oo
ool2o`0007oooooo0_l0000Cooooo`;o0000<?ooool2o`0005?ooooo0_l0000Fooooo`007_ooool0
0ol0003oooooooooo`0Booooo`;o0000J_ooool2o`000:oooooo0_l0000Fooooo`007_ooool00ol0
003oooooooooo`1dooooo`;o00002?ooool2o`0002Wooooo0_l0001[ooooo`;o0000;oooool001ko
oooo00?o0000ooooooooool0:_ooool2o`0003oooooo0_l00007ooooo`;o00005?ooool2o`00013o
oooo0ol0000:ooooo`;o0000E_ooool2o`0000Wooooo0_l00008ooooo`;o0000;oooool001kooooo
00?o0000ooooooooool0:_ooool2o`0002;ooooo0_l0000Kooooo`;o00007Oooool4o`0000kooooo
0ol0001Rooooo`;o00002Oooool2o`0003Wooooo000Nooooo`03o`000?oooooooooo04kooooo0_l0
000dooooo`;o00001_ooool2o`000;Wooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo0_l0
000iooooo`;o0000=?ooool2o`0001Sooooo0_l0000aooooo`;o0000>oooool2o`0003Oooooo0003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Cooooo`;o0000>Oooool2o`0004kooooo0_l0000aooooo`;o0000>ooo
ool2o`0003Oooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo1?l0
000Sooooo`;o00001_ooool2o`0009Gooooo0_l00023ooooo`000oooool01Ol0003ooooooooooooo
oooo000000_ooooo00CoA4A4omgMgOoooooo00001_ooool2o`0000oooooo0_l0000Dooooo`;o0000
1_ooool2o`0000?ooooo0_l0002@ooooo`;o0000Poooool000?ooooo00Go0000oooooooooooooooo
o`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool03Oooool2o`0000Co
oooo0_l0000Kooooo`;o0000ooooool5ooooo`;o00003oooool000?ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool04oooool2o`0007So
oooo0_l0001gooooo`;o0000;_ooool2o`0000oooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo08gooooo0_l0000Kooooo`;o
0000F_ooool2o`0000Wooooo0_l0000Oooooo`;o00004oooool000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0Z_ooool2o`0006Go
oooo0_l0000Hooooo`;o00001Oooool2o`0001?ooooo000Nooooo`03o`000?oooooooooo02Sooooo
0_l00007ooooo`;o0000n?ooool2o`0001[ooooo000Nooooo`03o`000?oooooooooo02Sooooo0_l0
0007ooooo`;o00006oooool2o`000?Oooooo000Nooooo`03o`000?oooooooooo04kooooo0_l00013
ooooo`;o0000<_ooool2o`0003Oooooo0_l00015ooooo`007_ooool00ol0003oooooooooo`0coooo
o`;o00000oooool2o`0005Wooooo0_l0000booooo`;o0000=oooool2o`0004Gooooo000Nooooo`03
o`000?oooooooooo03?ooooo0_l00003ooooo`;o00009Oooool2o`0000Wooooo0_l0000Hooooo`;o
0000R?ooool2o`0003Oooooo000Nooooo`03o`000?oooooooooo01[ooooo0_l0000Eooooo`;o0000
;?ooool2o`0000Wooooo0_l0000Hooooo`;o00001Oooool2o`00087ooooo0_l0000Iooooo`;o0000
7?ooool001kooooo00?o0000ooooooooool06_ooool2o`0001Gooooo0_l00006ooooo`;o00000_oo
ool2o`000003ooooool0003o000004Wooooo0_l0000Looooo`;o0000GOooool2o`0001oooooo0_l0
000Looooo`007_ooool00ol0003oooooooooo`0Tooooo`;o00004oooool2o`0000;ooooo0_l00000
0ooooooo0000o`00001Wooooo`;o0000Aoooool2o`0001Cooooo0_l0000mooooo`007_ooool00ol0
003oooooooooo`0Tooooo`;o0000c?ooool2o`0005?ooooo000Nooooo`03o`000?oooooooooo05Oo
oooo0_l0000Looooo`;o00001oooool2o`000<Oooooo000Nooooo`03o`000?oooooooooo05Oooooo
0_l0000Looooo`;o00001oooool2o`0005?ooooo0_l0001booooo`007_ooool2o`0001gooooo0_l0
000Zooooo`;o0000ROooool2o`0006Wooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`0L
ooooo`;o00003_ooool2o`0001[ooooo0_l0000Mooooo`;o00006Oooool2o`0006gooooo0_l0001;
ooooo`;o00001oooool001kooooo0_l00009ooooo`;o00008_ooool2o`0003Wooooo0_l0000Ioooo
o`;o0000;Oooool2o`0003kooooo0_l0000=ooooo`;o00002_ooool2o`000003ooooool0003o0000
02cooooo0_l00008ooooo`007_ooool2o`0000Oooooo1?l0002Aooooo`;o00004_ooool4o`0003Oo
oooo0_l0000Dooooo`;o00002_ooool2o`000003ooooool0003o000001Wooooo0_l0000Aooooo`;o
000000?oooooo`000?l000001Oooool001kooooo00?o0000ooooooooool01_ooool2o`0001;ooooo
0_l0001Aooooo`;o0000;?ooool2o`0001;ooooo0_l0000iooooo`;o0000?_ooool2o`0001Cooooo
0_l00005ooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o00003oooool2o`00043ooooo0_l0
0007ooooo`;o0000BOooool2o`0000Wooooo0_l0001iooooo`007_ooool00ol0003oooooooooo`0[
ooooo`;o0000?Oooool2o`0000[ooooo0_l00004ooooo`;o0000@oooool2o`0000Wooooo0_l0001i
ooooo`007_ooool00ol0003oooooooooo`1Zooooo`;o00003Oooool2o`000003ooooool0003o0000
0<Wooooo000Nooooo`03o`000?oooooooooo06?ooooo0_l0000Dooooo`;o0000Z_ooool2o`0000?o
oooo0_l0000@ooooo`;o00002Oooool001kooooo00?o0000ooooooooool0Hoooool2o`000<3ooooo
0_l00003ooooo`;o00004?ooool2o`0000Wooooo000Nooooo`03o`000?oooooooooo02Kooooo0_l0
000Rooooo`;o0000>oooool2o`0007cooooo0_l0000>ooooo`;o00006?ooool2o`0001Kooooo000N
ooooo`03o`000?oooooooooo02Kooooo0_l0000Rooooo`;o0000>oooool2o`0001Kooooo0_l0001T
ooooo`;o00003_ooool2o`0000Cooooo0_l0000Booooo`;o00002Oooool2o`0000_ooooo000Noooo
o`03o`000?oooooooooo04oooooo0_l00004ooooo`;o0000B?ooool2o`0001Cooooo0_l0000koooo
o`;o00009oooool2o`0001gooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`1?ooooo`;o
00001?ooool2o`0005kooooo0_l0000kooooo`;o00006Oooool2o`0003Sooooo000Nooooo`03o`00
0?oooooooooo00Cooooo0_l0000fooooo`;o00004?ooool2o`000;gooooo0_l0000hooooo`007_oo
ool00ol0003oooooooooo`04ooooo`;o00005oooool2o`0000;ooooo0_l0000Iooooo`;o00004?oo
ool2o`0000?ooooo0_l0003booooo`007_ooool2o`0001kooooo0_l00002ooooo`;o0000;Oooool2
o`000003ooooool0003o000006kooooo0_l0000`ooooo`;o00002_ooool2o`0004Cooooo000Noooo
o`03o`000?oooooooooo04Kooooo0_l00008ooooo`;o0000LOooool2o`00033ooooo0_l0000:oooo
o`;o0000A?ooool001kooooo00?o0000ooooooooool0A_ooool2o`0001Wooooo0_l0001Pooooo`;o
0000P_ooool001kooooo00?o0000ooooooooool0:Oooool2o`0003Gooooo0ol0000?ooooo`;o0000
COooool2o`0001Oooooo0_l0000Dooooo`;o0000EOooool001kooooo00?o0000ooooooooool0:Ooo
ool2o`0003Gooooo0_l0000@ooooo`;o0000COooool2o`0001Oooooo0_l00004ooooo`;o00003_oo
ool2o`0005Gooooo000Nooooo`03o`000?oooooooooo08Wooooo0_l0001Eooooo`;o00004Oooool2
o`0002Kooooo0_l0000Zooooo`007_ooool00ol0003oooooooooo`1Yooooo`;o00007_ooool2o`00
06Sooooo0_l0000Vooooo`;o0000:_ooool001kooooo0_l00002ooooo`;o0000:oooool2o`0003Wo
oooo0_l0001=ooooo`;o00003oooool2o`0007cooooo000Nooooo`;o00000_ooool2o`0002_ooooo
0_l000000ooooooo0000o`00000@ooooo`;o00004?ooool2o`0001?ooooo0_l0001<ooooo`;o0000
3oooool2o`0003cooooo0_l0000nooooo`007_ooool01?l0003oooooooooooooool2o`0002kooooo
0_l0000@ooooo`;o00004?ooool2o`0001?ooooo0_l0002<ooooo`;o00003Oooool2o`0000[ooooo
0_l0000booooo`007_ooool01?l0003oooooooooooooool2o`000?Gooooo0_l0000Iooooo`;o0000
8Oooool2o`0000oooooo000Nooooo`03o`000?oooooooooo07Kooooo0_l0001Sooooo`;o00002Ooo
ool2o`0004kooooo0_l0000?ooooo`007_ooool00ol0003oooooooooo`05ooooo`;o00001oooool2
o`0002Oooooo0_l0000mooooo`;o0000Hoooool2o`0000Wooooo0_l0001Oooooo`007_ooool00ol0
003oooooooooo`05ooooo`;o00001oooool2o`0002Oooooo0_l0002Yooooo`;o0000Hoooool001ko
oooo00?o0000ooooooooool03Oooool2o`00033ooooo0_l0000gooooo`;o00001_ooool2o`00063o
oooo0_l0001Gooooo`;o00002_ooool001kooooo00?o0000ooooooooool03Oooool2o`00033ooooo
0_l0000Zooooo`;o00002oooool2o`0000Kooooo0_l0001<ooooo`;o00009_ooool2o`0004?ooooo
0_l0000:ooooo`007_ooool2o`0006cooooo0_l0001Qooooo`?o00008Oooool2o`0000;ooooo0_l0
001?ooooo`007_ooool00ol0003oooooooooo`0Wooooo`;o0000POooool2o`0002?ooooo0_l0000Q
ooooo`;o0000Doooool001kooooo00?o0000ooooooooool09oooool2o`0006gooooo0_l0000Boooo
o`;o0000Voooool001kooooo00?o0000ooooooooool0E_ooool2o`0003kooooo0_l0001Iooooo`;o
0000E?ooool001kooooo00?o0000ooooooooool0E_ooool2o`0003Kooooo1?l00004ooooo`;o0000
5Oooool2o`0004;ooooo0_l0001Dooooo`007_ooool00ol0003oooooooooo`19ooooo`;o0000@ooo
ool4o`0000Cooooo0_l0000Eooooo`;o0000A_ooool2o`00053ooooo000Nooooo`03o`000?oooooo
oooo04Wooooo0_l0000Wooooo`;o0000POooool2o`00053ooooo000Nooooo`03o`000?oooooooooo
07;ooooo0_l0001;ooooo`?o0000E?ooool2o`0002oooooo000Nooooo`03o`000?oooooooooo03ko
oooo0_l0000gooooo`;o00009_ooool2o`0001kooooo0ol0000iooooo`;o00006Oooool2o`0002oo
oooo000Nooooo`03o`000?oooooooooo03kooooo0_l0000gooooo`;o00009_ooool2o`0000Wooooo
0_l0001?ooooo`;o0000A?ooool2o`0000Cooooo000Nooooo`03o`000?oooooooooo06?ooooo0_l0
0015ooooo`;o0000Foooool2o`0000kooooo0_l0000Eooooo`;o00004Oooool2o`0000Cooooo000N
ooooo`03o`000?oooooooooo00Gooooo0_l0000Cooooo`;o0000Aoooool2o`000:;ooooo0_l0000>
ooooo`;o00005Oooool2o`0001Oooooo000Nooooo`03o`000?oooooooooo00Gooooo0_l0000Coooo
o`;o00005oooool2o`000:Kooooo0_l0001Zooooo`007_ooool00ol0003oooooooooo`0cooooo`;o
0000Y_ooool2o`0006[ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo02gooooo0_l0000ooooo
o`;o00001?ooool2o`0009?ooooo0_l0000looooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`04
o`0002Wooooo0_l0000oooooo`;o00001?ooool2o`0003?ooooo0_l0001Nooooo`;o0000??ooool0
00?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_oo
ool7o`0006Wooooo0_l0000jooooo`;o0000W?ooool000?ooooo00Go0000ooooooooooooooooo`00
000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1<ooooo`;o0000
7oooool2o`0001Wooooo0_l0002Kooooo`;o00003Oooool2o`00017ooooo0003ooooo`05o`000?oo
ooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000oooooooo
ool0C?ooool2o`0003Wooooo0ol0001Jooooo`;o0000?oooool2o`0000gooooo0_l0000Aooooo`00
0oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003o
ooooooooo`16ooooo`;o0000?oooool2o`0004Cooooo0_l0000Eooooo`;o0000Doooool2o`0000co
oooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03
o`000?oooooooooo04Kooooo0_l00025ooooo`;o00000_ooool2o`0000kooooo0_l0000Fooooo`;o
0000?_ooool2o`0000cooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<co
A4A4o`000?l@4106ooooo`03o`000?oooooooooo02Oooooo0_l00014ooooo`;o00003oooool2o`00
057ooooo0_l0000>ooooo`;o00005_ooool2o`0002Gooooo0_l0000Uooooo`007_ooool4o`0002Ko
oooo0_l00014ooooo`;o00003oooool2o`000003ooooool0003o000009?ooooo0_l00008ooooo`;o
00009Oooool001kooooo1?l0000aooooo`;o0000COooool2o`0000;ooooo0_l00016ooooo`;o0000
Aoooool2o`0002oooooo000Nooooo`03o`000?oooooooooo03;ooooo0_l0000:ooooo`;o00004_oo
ool2o`0002;ooooo0_l0000=ooooo`Co0000A?ooool2o`0007Sooooo000Nooooo`03o`000?oooooo
oooo00[ooooo0_l0000booooo`;o00004_ooool2o`0002;ooooo0_l0000?ooooo`;o0000J?ooool2
o`0005Cooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0003Uooooo`;o0000E?ooool001ko
oooo00?o0000ooooooooool0>oooool2o`0001?ooooo0_l0001Mooooo`;o0000U_ooool001kooooo
00?o0000ooooooooool0>oooool2o`0001?ooooo1?l0000Uooooo`;o00008?ooool2o`0001;ooooo
0_l0000Vooooo`;o0000?_ooool2o`0002kooooo000Nooooo`03o`000?oooooooooo05;ooooo1?l0
0007ooooo`;o00006_ooool2o`00023ooooo0_l0000eooooo`;o00000oooool2o`0003kooooo0_l0
000^ooooo`007_ooool00ol0003oooooooooo`1Dooooo`;o00001oooool2o`0002Sooooo0_l0000L
ooooo`;o00006_ooool2o`0000oooooo0_l0000cooooo`;o00003_ooool2o`0000Oooooo0_l0000U
ooooo`007_ooool00ol0003oooooooooo`27ooooo`;o00006_ooool4o`0001[ooooo0_l00014oooo
o`;o00003_ooool2o`0000Oooooo0_l0000Uooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o
00004_ooool2o`0007Cooooo0_l00008ooooo`;o00001_ooool2o`0006kooooo1?l0000Nooooo`00
7_ooool2o`0001[ooooo0_l0000Booooo`;o0000>Oooool2o`0002?ooooo0_l00008ooooo`;o0000
3oooool2o`0000?ooooo0_l00003ooooo`Go0000?_ooool2o`0002kooooo1?l0000Nooooo`007_oo
ool00ol0003oooooooooo`07ooooo`;o00009?ooool2o`0003Wooooo0_l0000Sooooo`;o00001ooo
ool3o`0000oooooo0_l00008ooooo`?o0000@?ooool2o`00053ooooo000Nooooo`;o00001oooool3
o`0002kooooo0_l0001Mooooo`;o00006Oooool2o`0004Wooooo0_l00004ooooo`;o00004oooool2
o`0002kooooo000Nooooo`;o00001oooool2o`0002oooooo0_l0000?ooooo`;o00001?ooool2o`00
01Wooooo0_l0000[ooooo`;o00006Oooool2o`0004Wooooo0_l00004ooooo`;o00004oooool2o`00
02kooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l0000Oooooo`?o00000oooool2o`0001Wo
oooo0_l0000Nooooo`;o00002oooool2o`0006_ooooo0_l000000ooooooo0000o`00000Booooo`;o
00003_ooool2o`0001_ooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l0000Jooooo`;o0000
7Oooool2o`000003ooooool0003o000003kooooo0_l0000Gooooo`;o0000Goooool2o`000003oooo
ool0003o000001;ooooo0_l0000>ooooo`;o00006oooool001kooooo00?o0000ooooooooool02ooo
ool2o`0002;ooooo0_l00006ooooo`;o00003Oooool2o`0005?ooooo0_l00005ooooo`;o0000Xooo
ool001kooooo00?o0000ooooooooool0;oooool2o`0000Kooooo0_l0001@ooooo`;o00004?ooool2
o`0001Gooooo0_l0000jooooo`;o0000COooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo
03Sooooo0_l0001?ooooo`;o00009oooool2o`0001Sooooo0_l00005ooooo`;o00002Oooool2o`00
00kooooo0ol0000@ooooo`;o0000<_ooool2o`0000Kooooo0_l00008ooooo`007_ooool00ol0003o
ooooooooo`0Oooooo`;o00005oooool2o`0009;ooooo0_l00005ooooo`;o00002Oooool2o`0000oo
oooo0_l0000@ooooo`;o00002?ooool2o`0002Sooooo0_l0000@ooooo`007_ooool00ol0003ooooo
ooooo`0Oooooo`;o00004oooool2o`0003Wooooo0_l0002Jooooo`;o0000>_ooool001kooooo00?o
0000ooooooooool00_ooool2o`00033ooooo0_l0000iooooo`;o0000AOooool2o`0008oooooo000N
ooooo`03o`000?oooooooooo00;ooooo0_l0000cooooo`;o0000N?ooool2o`0000?ooooo0_l0002?
ooooo`007_ooool00ol0003oooooooooo`0gooooo`;o0000=oooool2o`0001;ooooo0_l0000[oooo
o`;o0000O_ooool2o`0001Cooooo000Mooooo`;o00004_ooool2o`0005kooooo0_l0000Booooo`;o
00008?ooool2o`0005_ooooo0_l0000/ooooo`;o00005?ooool001gooooo0_l0000;ooooo`;o0000
1Oooool2o`0003Kooooo0_l0001Looooo`;o0000Foooool2o`0004;ooooo000Nooooo`;o00002_oo
ool2o`0003gooooo0_l0003Qooooo`;o00006_ooool001kooooo00?o0000ooooooooool0EOooool2
o`000=Cooooo1?l0000Hooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o0000Aoooool2o`00
04Gooooo0_l0001Looooo`;o0000<Oooool2o`0001Sooooo000Nooooo`03o`000?oooooooooo00co
oooo0_l0002>ooooo`;o00000_ooool2o`0001cooooo0_l0000jooooo`;o0000Boooool001kooooo
00?o0000ooooooooool0X?ooool2o`0001cooooo0_l00027ooooo`007_ooool00ol0003ooooooooo
o`0^ooooo`;o00004Oooool2o`000?oooooo1Oooool001kooooo00?o0000ooooooooool0;Oooool3
o`00017ooooo0_l0001;ooooo`;o0000:_ooool2o`0008_ooooo000Nooooo`03o`000?oooooooooo
02gooooo0_l0001Oooooo`;o00006_ooool2o`0000kooooo0_l0001Booooo`;o0000=oooool001ko
oooo00?o0000ooooooooool05?ooool2o`0001Gooooo0_l00018ooooo`;o0000;oooool2o`0000;o
oooo0_l0001Rooooo`;o0000=oooool001kooooo00?o0000ooooooooool05?ooool2o`0001Gooooo
0_l00018ooooo`;o0000;oooool2o`0009oooooo000Nooooo`03o`000?oooooooooo043ooooo0_l0
0006ooooo`;o0000EOooool2o`0004oooooo0_l0001Eooooo`007_ooool00ol0003oooooooooo`0G
ooooo`;o00004Oooool2o`0001Cooooo0_l00006ooooo`;o0000;oooool2o`0002Cooooo0_l0000?
ooooo`;o00002oooool2o`00037ooooo0_l0001Eooooo`007_ooool00ol0003oooooooooo`0Goooo
o`;o00004Oooool2o`0000?ooooo0_l0000fooooo`;o00004?ooool2o`0003Gooooo0_l0000;oooo
o`;o0000R?ooool001kooooo00?o0000ooooooooool0;oooool2o`0000?ooooo0_l00008ooooo`;o
00009oooool2o`00027ooooo0_l00015ooooo`;o0000M?ooool001kooooo00?o0000ooooooooool0
8oooool2o`0000oooooo0_l00008ooooo`;o00009_ooool2o`0002;ooooo0_l00015ooooo`;o0000
M?ooool001kooooo00?o0000ooooooooool08oooool2o`0003Gooooo0_l00004ooooo`;o00001?oo
ool2o`000=oooooo000Nooooo`;o0000Foooool2o`0000Cooooo0_l0001Hooooo`;o0000A?ooool2
o`0003_ooooo0_l00008ooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o00002Oooool2o`00
0:;ooooo0_l00002ooooo`;o00009?ooool2o`0001[ooooo0_l0000kooooo`;o00002?ooool001ko
oooo00?o0000ooooooooool02oooool2o`0000Wooooo0_l0000_ooooo`;o0000?_ooool2o`0003Co
oooo0ol0000Tooooo`;o00006_ooool2o`0000cooooo0_l0000gooooo`007_ooool00ol0003ooooo
ooooo`17ooooo`;o0000?_ooool2o`0003Cooooo0_l0000Eooooo`;o0000>?ooool2o`00033ooooo
0_l00005ooooo`007_ooool00ol0003oooooooooo`04ooooo`;o00001_ooool2o`0000gooooo0_l0
002gooooo`;o00004oooool2o`00057ooooo0_l00002ooooo`;o00001Oooool001kooooo00?o0000
ooooooooool01?ooool2o`0000Kooooo0_l0000=ooooo`;o0000;?ooool2o`0003cooooo0_l0001@
ooooo`;o00003_ooool2o`00057ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`05oooo
o`;o0000@_ooool2o`0003[ooooo1?l0001@ooooo`;o00009_ooool2o`0004Cooooo000Nooooo`03
o`000?oooooooooo00Gooooo0_l00010ooooo`;o0000??ooool4o`0002oooooo0_l0000Yooooo`;o
00002Oooool2o`00017ooooo0_l0000Pooooo`;o00008_ooool001kooooo00?o0000ooooooooool0
Aoooool2o`0006oooooo0_l0000Rooooo`;o00001Oooool2o`0000Wooooo0_l0000Gooooo`;o0000
6_ooool2o`0002;ooooo000Nooooo`03o`000?oooooooooo0;Sooooo0_l0000Rooooo`;o0000:Ooo
ool2o`0003kooooo000Nooooo`03o`000?oooooooooo00;o0000F_ooool2o`0000Wooooo0_l0000C
ooooo`;o0000bOooool001kooooo00?o0000ooooooooool00_l0000Jooooo`;o00004?ooool2o`00
02cooooo0_l00009ooooo`;o00004oooool2o`000<Wooooo000Nooooo`03o`000?oooooooooo00Oo
oooo0_l0000Cooooo`;o00004?ooool2o`0000Kooooo0_l0000cooooo`;o0000;?ooool2o`0000go
oooo0_l0000Qooooo`;o0000N_ooool001kooooo0ol00007ooooo`;o0000;Oooool2o`0003?ooooo
0_l0000/ooooo`;o00003Oooool2o`0001gooooo0_l00002ooooo`;o00007oooool2o`0005Wooooo
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o
8B4Qolc<c006ooooo`?o0000aoooool2o`0002?ooooo0_l0000`ooooo`;o00009oooool000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q
00Kooooo00?o0000ooooooooool04?ooool2o`0007?ooooo0_l0000Xooooo`;o0000Hoooool2o`00
00Sooooo0_l0000Jooooo`;o00002oooool000?ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000001_ooool3o`00013ooooo0_l0000[ooooo`;o00001oooool2
o`0003gooooo0_l0000Xooooo`;o00005oooool2o`0001Gooooo0_l0000cooooo`;o00001?ooool2
o`0001kooooo0_l0000;ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8b
oiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooooooo03gooooo0_l00007ooooo`;o00003_oo
ool2o`0001cooooo0_l0000iooooo`;o00005oooool2o`0001?ooooo1?l0000iooooo`;o0000:ooo
ool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0
1_ooool00ol0003oooooooooo`1Booooo`;o00000_ooool2o`0001cooooo0_l0001Wooooo`;o0000
:oooool2o`0003_ooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zj
oooooonj^[[o410@00Kooooo00?o0000ooooooooool01Oooool2o`0004_ooooo0_l0001eooooo`;o
00001?ooool2o`0003Wooooo0_l0000kooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo00?ooooo1?l00032oooo
o`;o00001?ooool2o`0007Kooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnY
ZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool00oooool2o`0000Sooooo0_l0000Q
ooooo`;o00002_ooool2o`0007Wooooo0_l0000@ooooo`;o0000I?ooool2o`0001Kooooo000Noooo
o`03o`000?oooooooooo00gooooo0_l00008ooooo`;o00005oooool2o`0000[ooooo0_l0000Boooo
o`;o0000IOooool2o`00013ooooo0_l0000Eooooo`;o0000COooool2o`0001Kooooo000Nooooo`03
o`000?oooooooooo00gooooo0_l00008ooooo`;o00003_ooool2o`0001?ooooo0_l0000Booooo`;o
0000B_ooool2o`0004;ooooo0_l000000ooooooo0000o`00000Pooooo`;o0000;_ooool2o`00013o
oooo000Nooooo`03o`000?oooooooooo02Oooooo0_l0000Cooooo`;o0000G_ooool2o`0004Gooooo
0_l0000Pooooo`;o0000;_ooool2o`00013ooooo000Nooooo`03o`000?oooooooooo06[ooooo0_l0
0016ooooo`Co0000J_ooool2o`0001gooooo0_l00006ooooo`007_ooool00ol0003oooooooooo`06
ooooo`;o0000>Oooool2o`0002Oooooo0_l0000Sooooo`;o00005_ooool2o`0000Wooooo1?l0001Z
ooooo`;o00000oooool2o`0001Sooooo0_l00006ooooo`007_ooool00ol0003oooooooooo`06oooo
o`;o0000>Oooool4o`0004[ooooo0_l0000Fooooo`;o0000Moooool2o`0000?ooooo0_l0000Poooo
o`007_ooool00ol0003oooooooooo`0?ooooo`;o0000<_ooool2o`000=kooooo0_l0000<ooooo`;o
00005?ooool001kooooo00?o0000ooooooooool03oooool2o`0007gooooo0_l0000Yooooo`;o0000
D_ooool2o`0001Cooooo0_l0000<ooooo`;o00005?ooool001kooooo00?o0000ooooooooool0S_oo
ool2o`0000cooooo0_l0000Kooooo`;o0000@oooool2o`0000gooooo0_l0000Aooooo`;o00009Ooo
ool001kooooo00?o0000ooooooooool0?_ooool2o`0005cooooo0_l0001Pooooo`;o00007?ooool2
o`0000;ooooo0_l0000Uooooo`007_ooool00ol0003oooooooooo`0nooooo`;o0000Woooool2o`00
033ooooo0_l00009ooooo`;o0000:Oooool001kooooo0_l0000oooooo`;o0000Woooool2o`0000Ko
oooo0_l0000Xooooo`;o00005?ooool2o`0001kooooo000Nooooo`03o`000?oooooooooo03kooooo
0_l0001Booooo`;o00005Oooool2o`0003cooooo0_l0000:ooooo`;o0000<_ooool2o`0001kooooo
000Nooooo`03o`000?oooooooooo09;ooooo0_l0000Eooooo`;o00003Oooool4o`0001Gooooo1?l0
000Nooooo`;o0000D_ooool001kooooo00?o0000ooooooooool0Z?ooool2o`0000kooooo1?l0000E
ooooo`Co0000L_ooool001kooooo00?o0000ooooooooool0F_ooool2o`0004Cooooo0_l00006oooo
o`;o0000<?ooool2o`0005Sooooo0_l0000Aooooo`007_ooool00ol0003oooooooooo`1Jooooo`;o
00005_ooool2o`0002_ooooo0ol0000Oooooo`;o00004Oooool2o`0000Cooooo0_l00010ooooo`;o
00005_ooool2o`00017ooooo000Nooooo`03o`000?oooooooooo023ooooo0_l0001@ooooo`;o0000
8oooool2o`0000Kooooo0_l0000Pooooo`;o00004Oooool2o`0001kooooo0_l0000Jooooo`;o0000
2_ooool2o`0002Wooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l00003ooooo`Co00004Ooo
ool2o`0002Cooooo0_l0001?ooooo`;o00007_ooool2o`0003_ooooo0_l00008ooooo`;o00004?oo
ool2o`00023ooooo0_l0000Cooooo`007_ooool00ol0003oooooooooo`06ooooo`;o00000oooool4
o`0003Oooooo0_l0000Eooooo`;o00007?ooool2o`0003[ooooo0_l0000Fooooo`;o0000;Oooool2
o`0003;ooooo0_l0000Cooooo`007_ooool00ol0003oooooooooo`1Mooooo`;o00001?ooool2o`00
01Kooooo0_l0000Hooooo`;o0000>?ooool2o`0001_ooooo0_l0001Iooooo`007_ooool00ol0003o
ooooooooo`1Sooooo`;o0000<?ooool2o`0003Gooooo0_l0000Nooooo`;o0000FOooool001kooooo
00?o0000ooooooooool0<Oooool2o`0006Wooooo0_l000000ooooooo0000o`00000[ooooo`;o0000
0oooool2o`0001;ooooo0_l0000Booooo`?o00008?ooool2o`0002Wooooo000Nooooo`03o`000?oo
oooooooo00Cooooo0_l0000Hooooo`;o00004Oooool2o`0001Sooooo0_l0000Uooooo`;o00008?oo
ool2o`0000Kooooo0_l000000ooooooo0000o`00000Yooooo`;o00001Oooool2o`0001;ooooo0_l0
000Booooo`?o00008?ooool2o`0002Wooooo000Nooooo`03o`000?oooooooooo00?ooooo0ol0000H
ooooo`;o0000:oooool2o`0002Gooooo0_l0000Pooooo`;o00005oooool4o`0000gooooo0_l0000:
ooooo`;o0000;?ooool2o`0004gooooo000Nooooo`04o`000?ooooooooooooooo`Co0000:oooool2
o`0002[ooooo0_l0000Eooooo`;o0000>?ooool4o`0000gooooo0_l0000hooooo`;o00000_ooool2
o`0004Wooooo000Nooooo`04o`000?ooooooooooooooo`;o00004_ooool2o`0001Wooooo0_l0000Z
ooooo`;o00005Oooool2o`0002Cooooo0_l0001>ooooo`;o00003oooool4o`0004Wooooo000Noooo
o`;o00005_ooool2o`0008;ooooo0_l0000Pooooo`;o0000;?ooool2o`0000oooooo0_l0001;oooo
o`007_ooool00ol0003oooooooooo`0jooooo`;o00004_ooool2o`0002_ooooo0_l00004ooooo`;o
00005oooool2o`0001oooooo0_l00015ooooo`;o0000@oooool001kooooo00?o0000ooooooooool0
>_ooool4o`00013ooooo0_l0000[ooooo`;o00001?ooool2o`0001Oooooo0_l0001Vooooo`;o0000
6?ooool2o`0002Wooooo000Nooooo`03o`000?oooooooooo03cooooo0_l00031ooooo`;o00006ooo
ool2o`0000[ooooo0_l0000@ooooo`;o00002oooool001kooooo00?o0000ooooooooool00_ooool2
o`0004?ooooo0_l0002fooooo`;o00009oooool2o`00013ooooo0_l0000;ooooo`007_ooool00ol0
003oooooooooo`02ooooo`;o0000@oooool2o`000=kooooo0_l0000Nooooo`007_ooool00ol0003o
ooooooooo`1Aooooo`;o00001?ooool2o`0003?ooooo0_l0000Dooooo`;o0000Poooool2o`0001ko
oooo000Nooooo`03o`000?oooooooooo057ooooo0_l00004ooooo`;o00004oooool2o`0001kooooo
0_l0000Dooooo`;o0000Xoooool001kooooo00?o0000ooooooooool0K?ooool2o`000=Wooooo000N
ooooo`03o`000?oooooooooo01Cooooo0_l0003ooooooc;ooooo000Nooooo`03o`000?oooooooooo
00;ooooo0_l0000@ooooo`;o0000D_ooool2o`0002kooooo0_l0000:ooooo`;o00007?ooool2o`00
01?ooooo0_l0001^ooooo`007_ooool00ol0003oooooooooo`02ooooo`;o0000I?ooool2o`0001oo
oooo0_l0000=ooooo`;o00002_ooool2o`0001;ooooo0_l00008ooooo`;o00004oooool2o`0005Co
oooo0_l0000Hooooo`007_ooool00ol0003oooooooooo`29ooooo`;o0000;Oooool2o`0007?ooooo
0_l0000Hooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o0000Aoooool2o`0009Gooooo0_l0
001Booooo`007_ooool00ol0003oooooooooo`0Cooooo`;o0000Aoooool2o`0000kooooo0_l00025
ooooo`;o0000D_ooool001kooooo00?o0000ooooooooool0<?ooool2o`0000Sooooo0_l0000`oooo
o`;o0000<Oooool2o`000:Kooooo000Nooooo`;o0000<Oooool2o`0000Sooooo0_l0001Sooooo`;o
0000BOooool2o`0002Kooooo0_l0000cooooo`007_ooool00ol0003oooooooooo`0_ooooo`;o0000
2?ooool2o`000:oooooo0_l0000Fooooo`;o00003_ooool2o`0001Gooooo0_l0000Looooo`007_oo
ool00ol0003oooooooooo`0_ooooo`?o00001oooool2o`0002[ooooo0_l0002Kooooo`;o00009Ooo
ool2o`0001cooooo000Nooooo`03o`000?oooooooooo033ooooo0_l0000cooooo`;o0000>?ooool2
o`0007gooooo0_l0000Wooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o0000P?ooool2o`00
07gooooo0_l0000Wooooo`007_ooool00ol0003oooooooooo`02ooooo`;o00006Oooool2o`0001oo
oooo0_l0003oooooo`Sooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l00009ooooo`;o0000
;oooool2o`0002Kooooo0_l0001:ooooo`;o0000E_ooool2o`0001Wooooo0_l000000ooooooo0000
o`00000Mooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o0000Eoooool2o`0003Kooooo0_l0
000Booooo`;o0000E_ooool2o`0000Sooooo0_l0000?ooooo`;o000000?oooooo`000?l000000_l0
000Kooooo`007_ooool00ol0003oooooooooo`09ooooo`;o0000F_ooool2o`0003Oooooo0_l0000W
ooooo`;o0000Boooool4o`0000Gooooo0_l00004ooooo`;o00001Oooool2o`0001_ooooo000Noooo
o`03o`000?oooooooooo00Wooooo0_l0000Pooooo`;o000000?oooooo`000?l000006Oooool2o`00
00oooooo0_l00009ooooo`;o00002Oooool2o`0003Sooooo0_l0000Kooooo`;o0000B_ooool2o`00
0003ooooool0003o000000Gooooo0_l00004ooooo`;o00008_ooool001kooooo00?o0000oooooooo
ool0:oooool2o`000003ooooool0003o000001Wooooo0_l0000;ooooo`;o00000_ooool2o`0001Co
oooo0_l0000hooooo`;o0000IOooool4o`0001_ooooo0_l0000Eooooo`007_ooool01?l0003ooooo
o`000?l0000Nooooo`;o0000=Oooool2o`0000Oooooo0_l0000Jooooo`;o0000U?ooool2o`0001go
oooo0_l0000Eooooo`007_ooool01?l0003oooooo`000?l0000Hooooo`;o00001?ooool2o`0003ko
oooo0_l0000Jooooo`;o00002?ooool2o`00027ooooo0_l0000cooooo`;o00003Oooool2o`0005Wo
oooo000Nooooo`03o`000?oooooooooo01Wooooo0_l0000@ooooo`;o00002Oooool2o`0004gooooo
0_l0000Qooooo`;o0000<oooool2o`0000gooooo0_l0000Looooo`;o0000>oooool001Cooooo1?l0
00000ol@413oooooooooo`03ooooo`03o`000?oooooooooo02_ooooo0_l00009ooooo`;o0000:Ooo
ool2o`00017ooooo0_l0001Oooooo`;o0000<oooool2o`0002_ooooo0_l0000>ooooo`005_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo067ooooo0_l0000Aooooo`;o0000:_ooool2
o`0000Gooooo0_l0000Gooooo`;o00004oooool2o`00063ooooo0_l0000>ooooo`005_ooool00ol0
003oooooooooo`05ooooo`?o0000X?ooool2o`0000Gooooo0_l0000Gooooo`;o0000QOooool001Ko
oooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo
000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@
ooooo`005?ooool00omEEEGoIVIVo`00003ooooooe;ooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.84226 .83873 Mdot
.76518 .20347 Mdot
.48284 .31967 Mdot
.81528 .20219 Mdot
.34279 .7194 Mdot
.28009 .93991 Mdot
.82267 .77531 Mdot
.04706 .24759 Mdot
.60598 .64126 Mdot
.67077 .99342 Mdot
.52106 .67978 Mdot
.62426 .84588 Mdot
.85056 .97855 Mdot
.84707 .69904 Mdot
.16065 .50066 Mdot
.90832 .32151 Mdot
.71693 .01863 Mdot
.73415 .18796 Mdot
.20502 .06118 Mdot
.38503 .17559 Mdot
.29046 .51223 Mdot
.7968 .14041 Mdot
.63507 .60311 Mdot
.89271 .13823 Mdot
.118 .71397 Mdot
.72934 .7108 Mdot
.90473 .35191 Mdot
.82228 .45246 Mdot
.06632 .13537 Mdot
.22906 .53717 Mdot
.13324 .44131 Mdot
.67167 .57417 Mdot
.79287 .65858 Mdot
.06173 .22363 Mdot
.0543 .88496 Mdot
.38169 .93016 Mdot
.84967 .51983 Mdot
.35619 .04509 Mdot
.93287 .92629 Mdot
.35087 .73636 Mdot
.74915 .90383 Mdot
.17746 .44345 Mdot
.48549 .74423 Mdot
.39974 .92905 Mdot
.40919 .85757 Mdot
.35588 .64204 Mdot
.54477 .74724 Mdot
.18523 .48381 Mdot
.70874 .55477 Mdot
.58786 .53695 Mdot
.49243 .4084 Mdot
.11393 .70418 Mdot
.9809 .33785 Mdot
.13038 .38417 Mdot
.38883 .77617 Mdot
.60028 .63286 Mdot
.98552 .05745 Mdot
.37119 .8962 Mdot
.50472 .30164 Mdot
.33964 .18921 Mdot
.9364 .05298 Mdot
.47138 .91363 Mdot
.23328 .67729 Mdot
.11639 .05983 Mdot
.40627 .28259 Mdot
.16813 .90664 Mdot
.76936 .22836 Mdot
.50497 .41662 Mdot
.77612 .53061 Mdot
.96202 .308 Mdot
.13153 .9971 Mdot
.52422 .92855 Mdot
.07851 .28652 Mdot
.87866 .3742 Mdot
.86528 .68501 Mdot
.48716 .08426 Mdot
.5389 .15858 Mdot
.44165 .99807 Mdot
.95221 .08125 Mdot
.03695 .73423 Mdot
.38595 .40545 Mdot
.94018 .62402 Mdot
.23565 .5839 Mdot
.25437 .3667 Mdot
.21183 .22103 Mdot
.26236 .38759 Mdot
.17153 .68266 Mdot
.52751 .05507 Mdot
.43989 .62233 Mdot
.26758 .86742 Mdot
.33095 .62791 Mdot
.05663 .95049 Mdot
.01389 .28643 Mdot
.30729 .5072 Mdot
.68057 .80155 Mdot
.95836 .26278 Mdot
.63501 .43636 Mdot
.60327 .05461 Mdot
.6455 .58651 Mdot
.67114 .8103 Mdot
.25332 .73046 Mdot
.68636 .74738 Mdot
.80862 .11541 Mdot
.46792 .6315 Mdot
.99907 .23844 Mdot
.26068 .24355 Mdot
.11941 .60631 Mdot
.51995 .85559 Mdot
.24643 .39359 Mdot
.80861 .97834 Mdot
.72476 .89386 Mdot
.30054 .32875 Mdot
.28142 .09819 Mdot
.49135 .38324 Mdot
.74993 .74955 Mdot
.97486 .78881 Mdot
.92129 .61622 Mdot
.81172 .68696 Mdot
.97247 .23382 Mdot
.34679 .78157 Mdot
.64103 .92157 Mdot
.52237 .61407 Mdot
.96703 .05995 Mdot
.3433 .35891 Mdot
.58162 .83244 Mdot
.66969 .19027 Mdot
.16915 .11325 Mdot
.95244 .16299 Mdot
.12109 .67392 Mdot
.89917 .66858 Mdot
.21998 .65948 Mdot
.79574 .87008 Mdot
.95951 .87694 Mdot
.0951 .12023 Mdot
.81035 .91217 Mdot
.0246 .81622 Mdot
.33172 .75655 Mdot
.0401 .60613 Mdot
.33758 .48582 Mdot
.40105 .5098 Mdot
.04864 .66585 Mdot
.31341 .63318 Mdot
.69224 .19594 Mdot
.77526 .90052 Mdot
.90405 .51585 Mdot
.45397 .56702 Mdot
.00501 .81763 Mdot
.5363 .02213 Mdot
.51766 .16222 Mdot
.2898 .23823 Mdot
.18695 .38616 Mdot
.03766 .02772 Mdot
.34609 .77786 Mdot
.67894 .09689 Mdot
.46616 .33593 Mdot
.05725 .37897 Mdot
.63195 .78654 Mdot
.55335 .84179 Mdot
.78918 .22245 Mdot
.99028 .75161 Mdot
.18863 .8794 Mdot
.52115 .58755 Mdot
.04678 .51174 Mdot
.78956 .55464 Mdot
.89214 .81571 Mdot
.98083 .51164 Mdot
.34709 .4795 Mdot
.07361 .00749 Mdot
.86098 .57764 Mdot
.84481 .35532 Mdot
.80177 .42273 Mdot
.93109 .82633 Mdot
.49741 .37825 Mdot
.11054 .01728 Mdot
.19116 .77311 Mdot
.14053 .70123 Mdot
.39176 .13047 Mdot
.00696 .04773 Mdot
.73131 .53123 Mdot
.75803 .86952 Mdot
.14448 .0039 Mdot
.92155 .70442 Mdot
.47355 .27265 Mdot
.20005 .70519 Mdot
.85716 .0009 Mdot
.33414 .82386 Mdot
.56236 .15869 Mdot
.95198 .86994 Mdot
.27625 .17181 Mdot
.78476 .07291 Mdot
.38568 .35678 Mdot
.87062 .01618 Mdot
.08342 .50604 Mdot
.53411 .53052 Mdot
.66619 .15994 Mdot
.54679 .63292 Mdot
.10191 .25271 Mdot
.33413 .91032 Mdot
.35572 .93189 Mdot
.63031 .77836 Mdot
.01392 .99009 Mdot
.75385 .92606 Mdot
.5091 .83724 Mdot
.06478 .04947 Mdot
.5608 .01137 Mdot
.44476 .76332 Mdot
.78802 .06392 Mdot
.10014 .90317 Mdot
.96988 .66842 Mdot
.4585 .02431 Mdot
.53458 .54761 Mdot
.97381 .35114 Mdot
.49705 .58432 Mdot
.28111 .48781 Mdot
.96153 .00598 Mdot
.99574 .52348 Mdot
.46803 .77939 Mdot
.76009 .08403 Mdot
.57197 .94104 Mdot
.58103 .9709 Mdot
.87278 .12803 Mdot
.04469 .7209 Mdot
.18773 .47195 Mdot
.29727 .45748 Mdot
.86268 .0169 Mdot
.84834 .7964 Mdot
.09744 .83654 Mdot
.0368 .34776 Mdot
.74588 .04829 Mdot
.0285 .07011 Mdot
.98318 .28809 Mdot
.4499 .43501 Mdot
.12516 .40914 Mdot
.38231 .47133 Mdot
.79333 .09895 Mdot
.31158 .28897 Mdot
.72437 .2616 Mdot
.28639 .29898 Mdot
.81728 .34998 Mdot
.49511 .11067 Mdot
.91437 .96997 Mdot
.40114 .8491 Mdot
.80498 .81588 Mdot
.06699 .6556 Mdot
.7638 .12278 Mdot
.42731 .2203 Mdot
.74722 .20084 Mdot
.32603 .22497 Mdot
.28301 .15803 Mdot
.27008 .69862 Mdot
.4694 .03692 Mdot
.74859 .42082 Mdot
.49734 .84333 Mdot
.64798 .72172 Mdot
.83923 .23398 Mdot
.76908 .89077 Mdot
.27433 .36353 Mdot
.06363 .35904 Mdot
.13277 .0436 Mdot
.52625 .47475 Mdot
.21306 .94653 Mdot
.59404 .65773 Mdot
.94724 .83019 Mdot
.67466 .09722 Mdot
.30959 .06633 Mdot
.28989 .64533 Mdot
.57738 .53198 Mdot
.46563 .88038 Mdot
.56234 .47637 Mdot
.33983 .54994 Mdot
.30875 .29281 Mdot
.71491 .82433 Mdot
.0013 .51573 Mdot
.05559 .37251 Mdot
.33854 .8262 Mdot
.34886 .21139 Mdot
.87543 .87202 Mdot
.24223 .30622 Mdot
.46416 .04347 Mdot
.05994 .49913 Mdot
.86856 .84905 Mdot
.45283 .03557 Mdot
.61854 .22831 Mdot
.93605 .41738 Mdot
.54645 .71343 Mdot
.04285 .16403 Mdot
.54248 .96321 Mdot
.59816 .83214 Mdot
.61692 .23148 Mdot
.19054 .55756 Mdot
.96418 .37187 Mdot
.42187 .08999 Mdot
.96129 .38268 Mdot
.5534 .86463 Mdot
.39031 .19823 Mdot
.85749 .5154 Mdot
.63263 .49706 Mdot
.66779 .53225 Mdot
.11543 .29666 Mdot
.35386 .56973 Mdot
.78334 .8382 Mdot
.10587 .13257 Mdot
.715 .66839 Mdot
.94875 .15609 Mdot
.51897 .36602 Mdot
.02508 .22761 Mdot
.05803 .19348 Mdot
.33643 .55525 Mdot
.59438 .62041 Mdot
.67264 .16672 Mdot
.41999 .45545 Mdot
.16641 .44302 Mdot
.91228 .60567 Mdot
.94446 .28316 Mdot
.29407 .102 Mdot
.17121 .23991 Mdot
.99796 .64196 Mdot
.37467 .20543 Mdot
.52015 .67278 Mdot
.09451 .3879 Mdot
.18748 .81666 Mdot
.2802 .47015 Mdot
.92375 .34308 Mdot
.31809 .83834 Mdot
.04118 .79347 Mdot
.25086 .70063 Mdot
.60699 .79523 Mdot
.88747 .23683 Mdot
.93218 .90252 Mdot
.31918 .25437 Mdot
.26297 .60462 Mdot
.49583 .71236 Mdot
.26754 .55525 Mdot
.93059 .3534 Mdot
.25177 .00436 Mdot
.81172 .36997 Mdot
.10559 .06298 Mdot
.65698 .82816 Mdot
.35818 .56979 Mdot
.61988 .53284 Mdot
.46839 .40635 Mdot
.10581 .37975 Mdot
.16267 .97684 Mdot
.94701 .95538 Mdot
.01479 .62966 Mdot
.70776 .51342 Mdot
.7847 .38041 Mdot
.20605 .16592 Mdot
.80224 .11064 Mdot
.29248 .47509 Mdot
.36308 .90343 Mdot
.8673 .95964 Mdot
.87507 .67773 Mdot
.46082 .36883 Mdot
.8099 .47353 Mdot
.74604 .58314 Mdot
.52666 .94962 Mdot
.85197 .26349 Mdot
.55059 .74429 Mdot
.00413 .91921 Mdot
.91391 .31487 Mdot
.35039 .56306 Mdot
.54399 .78556 Mdot
.73975 .35522 Mdot
.78224 .2465 Mdot
.11705 .98647 Mdot
.00252 .68971 Mdot
.42039 .08998 Mdot
.40147 .38393 Mdot
.76934 .98542 Mdot
.76059 .77574 Mdot
.06863 .33669 Mdot
.97023 .16137 Mdot
.38891 .02403 Mdot
.25121 .60434 Mdot
.84551 .36206 Mdot
.22572 .50336 Mdot
.61932 .77996 Mdot
.27225 .08463 Mdot
.37439 .29678 Mdot
.58283 .5558 Mdot
.46665 .11929 Mdot
.63509 .86612 Mdot
.65641 .85648 Mdot
.93065 .69315 Mdot
.00019 .0859 Mdot
.48604 .84886 Mdot
.02574 .83612 Mdot
.44026 .40455 Mdot
.54371 .95858 Mdot
.92589 .45759 Mdot
.11862 .74853 Mdot
.14919 .69219 Mdot
.80439 .34654 Mdot
.51139 .89129 Mdot
.07887 .24103 Mdot
.49263 .30225 Mdot
.14743 .36648 Mdot
.72769 .4821 Mdot
.03347 .65291 Mdot
.52759 .14151 Mdot
.35679 .57653 Mdot
.76886 .97093 Mdot
.18586 .6638 Mdot
.33706 .32334 Mdot
.22919 .37722 Mdot
.09864 .29823 Mdot
.41809 .01003 Mdot
.35261 .04591 Mdot
.48518 .65742 Mdot
.42656 .44897 Mdot
.3849 .29019 Mdot
.71414 .11193 Mdot
.02282 .86179 Mdot
.22567 .93914 Mdot
.04201 .12902 Mdot
.89639 .91737 Mdot
.52005 .90674 Mdot
.15425 .38593 Mdot
.25936 .87493 Mdot
.50578 .41425 Mdot
.99838 .25132 Mdot
.2955 .14688 Mdot
.26248 .87496 Mdot
.32178 .00051 Mdot
.08281 .1556 Mdot
.20663 .82905 Mdot
.1388 .34375 Mdot
.34489 .99704 Mdot
.77821 .57881 Mdot
.4663 .47918 Mdot
.59955 .63314 Mdot
.84722 .24739 Mdot
.9752 .45407 Mdot
.52973 .90509 Mdot
.42917 .55289 Mdot
.03953 .19201 Mdot
.19042 .1891 Mdot
.02571 .20571 Mdot
.18116 .08362 Mdot
.66522 .2436 Mdot
.63336 .58992 Mdot
.37643 .8444 Mdot
.88702 .95433 Mdot
.46757 .68817 Mdot
.09219 .59991 Mdot
.99388 .63133 Mdot
.82258 .8917 Mdot
.93363 .38173 Mdot
.24906 .48701 Mdot
.00943 .98189 Mdot
.21478 .40097 Mdot
.59811 .86866 Mdot
.28651 .96125 Mdot
.29034 .8925 Mdot
.33414 .75708 Mdot
.70672 .14362 Mdot
.15964 .45589 Mdot
.50676 .6659 Mdot
.51556 .77978 Mdot
.76878 .26708 Mdot
.2584 .37215 Mdot
.44335 .06511 Mdot
.27348 .81007 Mdot
.0648 .3017 Mdot
.8518 .71269 Mdot
.98421 .21575 Mdot
.42865 .72432 Mdot
.06242 .79973 Mdot
.99507 .50112 Mdot
.45614 .17201 Mdot
.32575 .51512 Mdot
.91106 .23511 Mdot
.11518 .47691 Mdot
.15449 .06686 Mdot
.02476 .56781 Mdot
.17912 .97365 Mdot
.02543 .69644 Mdot
.39447 .56961 Mdot
.87569 .83859 Mdot
.25189 .59214 Mdot
.45856 .44795 Mdot
.00851 .50572 Mdot
.04183 .07213 Mdot
.95068 .52047 Mdot
.08055 .72719 Mdot
.89894 .23238 Mdot
.29109 .09799 Mdot
.87557 .46592 Mdot
.17526 .17994 Mdot
.51223 .663 Mdot
.16376 .6024 Mdot
.10675 .18152 Mdot
.87951 .04232 Mdot
.46854 .69431 Mdot
.79507 .10731 Mdot
.32727 .47244 Mdot
.46309 .51498 Mdot
.42652 .89833 Mdot
.42441 .25145 Mdot
.74182 .7728 Mdot
.49958 .92706 Mdot
.44098 .07925 Mdot
.1363 .43287 Mdot
.3798 .88652 Mdot
.47548 .69501 Mdot
.77465 .2912 Mdot
.90466 .49319 Mdot
.42414 .01255 Mdot
.09669 .04256 Mdot
.21896 .26194 Mdot
.51681 .90268 Mdot
.36588 .37075 Mdot
.24919 .7368 Mdot
.12769 .49743 Mdot
.92681 .08425 Mdot
.85382 .51628 Mdot
.43348 .56134 Mdot
.06034 .98119 Mdot
.70671 .02784 Mdot
.30701 .73344 Mdot
.89591 .75979 Mdot
.3298 .62676 Mdot
.1331 .99819 Mdot
.81647 .43393 Mdot
.10915 .43576 Mdot
.96062 .01157 Mdot
.0688 .53817 Mdot
.17955 .39056 Mdot
.3845 .75996 Mdot
.38264 .6844 Mdot
.83915 .81159 Mdot
.90547 .7802 Mdot
.10113 .74772 Mdot
.70865 .31947 Mdot
.68268 .5227 Mdot
.99012 .08676 Mdot
.74642 .86637 Mdot
.87396 .93761 Mdot
.68 .75205 Mdot
.63803 .42176 Mdot
.88569 .82032 Mdot
.56381 .84846 Mdot
.3432 .15445 Mdot
.53001 .05568 Mdot
.09427 .60522 Mdot
.46437 .86358 Mdot
.57552 .22242 Mdot
.7925 .94011 Mdot
.68827 .06694 Mdot
.73918 .82397 Mdot
.2648 .11963 Mdot
.80345 .3767 Mdot
.14902 .18614 Mdot
.43829 .66841 Mdot
.08348 .8506 Mdot
.80604 .41512 Mdot
.77403 .47687 Mdot
.17079 .83791 Mdot
.41037 .47696 Mdot
.6862 .9982 Mdot
.45013 .15751 Mdot
.73126 .26862 Mdot
.19259 .93875 Mdot
.14023 .13205 Mdot
.81651 .61837 Mdot
.3921 .66661 Mdot
.58097 .61224 Mdot
.77623 .09919 Mdot
.74485 .26572 Mdot
.32856 .08117 Mdot
.59193 .10393 Mdot
.69685 .31081 Mdot
.88342 .92447 Mdot
.85836 .80839 Mdot
.94112 .85928 Mdot
.99319 .89359 Mdot
.70352 .16794 Mdot
.5691 .40633 Mdot
.02409 .34747 Mdot
.63508 .0761 Mdot
.47911 .89299 Mdot
.44807 .80777 Mdot
.56093 .07313 Mdot
.47736 .84648 Mdot
.98066 .26986 Mdot
.56085 .74562 Mdot
.17267 .25089 Mdot
.44324 .11915 Mdot
.10518 .25691 Mdot
.12658 .61077 Mdot
.92095 .67081 Mdot
.18617 .62991 Mdot
.69706 .56706 Mdot
.01749 .52386 Mdot
.00369 .78795 Mdot
.40995 .66051 Mdot
.33899 .62151 Mdot
.62442 .02718 Mdot
.23088 .29425 Mdot
.26577 .73501 Mdot
.9889 .87174 Mdot
.06203 .03198 Mdot
.13219 .05708 Mdot
.78699 .5586 Mdot
.31828 .2567 Mdot
.75321 .05993 Mdot
.1756 .64757 Mdot
.08391 .25815 Mdot
.07862 .28852 Mdot
.55171 .31594 Mdot
.61418 .75664 Mdot
.24432 .26644 Mdot
.47244 .09521 Mdot
.08399 .05857 Mdot
.55614 .91016 Mdot
.63275 .42896 Mdot
.10725 .3545 Mdot
.89881 .58381 Mdot
.17052 .8476 Mdot
.99992 .40864 Mdot
.94551 .69908 Mdot
.34629 .42038 Mdot
.54535 .66037 Mdot
.03464 .96894 Mdot
.85881 .64872 Mdot
.8807 .62094 Mdot
.51628 .94449 Mdot
.1553 .0038 Mdot
.27954 .26646 Mdot
.21875 .64302 Mdot
.27711 .48882 Mdot
.41274 .08012 Mdot
.12468 .01133 Mdot
.97271 .84188 Mdot
.5502 .07818 Mdot
.59886 .07876 Mdot
.84784 .5947 Mdot
.83841 .37716 Mdot
.30867 .87188 Mdot
.60346 .11097 Mdot
.98519 .2247 Mdot
.41559 .24694 Mdot
.62562 .87864 Mdot
.16462 .3723 Mdot
.77303 .95921 Mdot
.11848 .32141 Mdot
.98024 .5355 Mdot
.21055 .35671 Mdot
.36364 .10546 Mdot
.62739 .11128 Mdot
.88151 .17443 Mdot
.81776 .08475 Mdot
.12014 .89494 Mdot
.47293 .66095 Mdot
.13401 .06852 Mdot
.54015 .5887 Mdot
.28344 .01409 Mdot
.23689 .09699 Mdot
.56313 .68642 Mdot
.62549 .0037 Mdot
.16262 .67608 Mdot
.26915 .06261 Mdot
.21409 .2283 Mdot
.32466 .0315 Mdot
.24659 .71122 Mdot
.75529 .47448 Mdot
.00626 .30577 Mdot
.52368 .74649 Mdot
.77339 .49473 Mdot
.13913 .68146 Mdot
.21311 .87714 Mdot
.37796 .72168 Mdot
.13014 .01169 Mdot
.02164 .78036 Mdot
.67461 .79197 Mdot
.87857 .01071 Mdot
.60985 .42821 Mdot
.90483 .43729 Mdot
.52743 .84992 Mdot
.47586 .53806 Mdot
.77624 .75043 Mdot
.51191 .95048 Mdot
.47322 .9706 Mdot
.07561 .47763 Mdot
.51358 .74789 Mdot
.17444 .44994 Mdot
.65287 .73057 Mdot
.15089 .65102 Mdot
.15693 .57322 Mdot
.43246 .99965 Mdot
.57735 .87325 Mdot
.82334 .20577 Mdot
.06559 .28484 Mdot
.19796 .1424 Mdot
.29751 .45447 Mdot
.32856 .90141 Mdot
.70509 .8533 Mdot
.01506 .55767 Mdot
.76488 .91505 Mdot
.06067 .90023 Mdot
.8768 .2828 Mdot
.71668 .97266 Mdot
.87543 .28611 Mdot
.74373 .56279 Mdot
.10802 .13634 Mdot
.38751 .23204 Mdot
.8436 .78696 Mdot
.29903 .18594 Mdot
.99411 .71738 Mdot
.13293 .64278 Mdot
.06362 .98576 Mdot
.30562 .74182 Mdot
.58052 .93964 Mdot
.69269 .85664 Mdot
.65953 .41018 Mdot
.87475 .50855 Mdot
.34932 .50397 Mdot
.49306 .04289 Mdot
.68439 .92813 Mdot
.04909 .13322 Mdot
.87402 .99128 Mdot
.81792 .53189 Mdot
.64674 .81257 Mdot
.42937 .74932 Mdot
.9825 .88028 Mdot
.36159 .01668 Mdot
.344 .61263 Mdot
.34912 .50697 Mdot
.81648 .93772 Mdot
.15147 .61735 Mdot
.27748 .19126 Mdot
.98185 .42197 Mdot
.275 .48823 Mdot
.39351 .98031 Mdot
.91713 .77146 Mdot
.98946 .50374 Mdot
.80583 .62163 Mdot
.48015 .27015 Mdot
.33554 .21068 Mdot
.00499 .6206 Mdot
.35262 .10059 Mdot
.12223 .12136 Mdot
.08929 .72094 Mdot
.81263 .62421 Mdot
.59394 .53644 Mdot
.51436 .7477 Mdot
.97063 .69328 Mdot
.22472 .52492 Mdot
.02142 .86521 Mdot
.01164 .09117 Mdot
.88435 .42966 Mdot
.94989 .30989 Mdot
.47147 .41927 Mdot
.9999 .98477 Mdot
.08548 .52868 Mdot
.85726 .09544 Mdot
.59565 .77973 Mdot
.54735 .44387 Mdot
.75362 .38287 Mdot
.0628 .07297 Mdot
.72755 .28574 Mdot
.30555 .86824 Mdot
.09418 .84958 Mdot
.63447 .75764 Mdot
.55315 .72057 Mdot
.53652 .65865 Mdot
.29716 .28612 Mdot
.86505 .70721 Mdot
.95505 .4103 Mdot
.15362 .07523 Mdot
.1667 .16707 Mdot
.18401 .045 Mdot
.5581 .61114 Mdot
.75537 .08895 Mdot
.43988 .90616 Mdot
.17079 .44209 Mdot
.03093 .21096 Mdot
.73899 .80725 Mdot
.63219 .66899 Mdot
.71998 .31061 Mdot
.96905 .02544 Mdot
.64296 .14188 Mdot
.08511 .09317 Mdot
.37339 .76164 Mdot
.56576 .24659 Mdot
.40032 .57282 Mdot
.06779 .46019 Mdot
.09754 .08636 Mdot
.74659 .65882 Mdot
.39663 .55325 Mdot
.19699 .90798 Mdot
.66537 .07515 Mdot
.92792 .58286 Mdot
.14211 .29834 Mdot
.06071 .8625 Mdot
.64093 .35116 Mdot
.70342 .29232 Mdot
.25305 .75039 Mdot
.51045 .92335 Mdot
.11242 .66654 Mdot
.98526 .51649 Mdot
.46661 .3631 Mdot
.58417 .50156 Mdot
.66105 .081 Mdot
.82623 .03647 Mdot
.41078 .59834 Mdot
.7672 .34113 Mdot
.5373 .37373 Mdot
.99581 .78375 Mdot
.45697 .43268 Mdot
.30174 .90837 Mdot
.47796 .88552 Mdot
.40718 .73816 Mdot
.00302 .41816 Mdot
.7559 .97987 Mdot
.38547 .60886 Mdot
.07396 .25296 Mdot
.87421 .81703 Mdot
.62174 .02964 Mdot
.20857 .68631 Mdot
.55295 .1693 Mdot
.01996 .32604 Mdot
.0212 .00929 Mdot
.13569 .56564 Mdot
.23536 .14744 Mdot
.42391 .90033 Mdot
.76908 .25713 Mdot
.80112 .29136 Mdot
.46062 .86446 Mdot
.08326 .19959 Mdot
.02708 .97956 Mdot
.79954 .49215 Mdot
.44513 .08228 Mdot
.98331 .22732 Mdot
.51444 .91546 Mdot
.55883 .00155 Mdot
.1094 .73874 Mdot
.32025 .11931 Mdot
.43037 .60574 Mdot
.19545 .66085 Mdot
.87079 .53555 Mdot
.44405 .5725 Mdot
.08028 .76659 Mdot
.54478 .85449 Mdot
.51441 .92025 Mdot
.77937 .36046 Mdot
.96106 .88997 Mdot
.43462 .71713 Mdot
.17789 .97545 Mdot
.25059 .36403 Mdot
.79307 .67626 Mdot
.01554 .67258 Mdot
.64633 .89765 Mdot
.78564 .15693 Mdot
.80609 .88101 Mdot
.05337 .39761 Mdot
.48522 .13972 Mdot
.13042 .91031 Mdot
.31733 .55174 Mdot
.01285 .4238 Mdot
.36278 .29862 Mdot
.58175 .10594 Mdot
.73368 .94561 Mdot
.76748 .25253 Mdot
.87855 .22132 Mdot
.11165 .79239 Mdot
.09309 .05009 Mdot
.84954 .60072 Mdot
.84813 .0256 Mdot
.57157 .52723 Mdot
.40584 .65938 Mdot
.6689 .04972 Mdot
.15456 .14361 Mdot
.01539 .99724 Mdot
.29124 .93615 Mdot
.60689 .69962 Mdot
.41894 .02531 Mdot
.57427 .59442 Mdot
.27737 .81581 Mdot
.46026 .15845 Mdot
.32533 .88253 Mdot
.68884 .83669 Mdot
.14684 .43651 Mdot
.14553 .6381 Mdot
.18394 .16897 Mdot
.02878 .80184 Mdot
.87436 .97879 Mdot
.42337 .35949 Mdot
.71091 .27901 Mdot
.99144 .6458 Mdot
.15407 .40624 Mdot
.37914 .22759 Mdot
.0707 .58042 Mdot
.72697 .62739 Mdot
.52759 .35208 Mdot
.48243 .7299 Mdot
.71455 .02611 Mdot
.62735 .61894 Mdot
.57259 .85725 Mdot
.42673 .45518 Mdot
.99631 .79053 Mdot
.35217 .10553 Mdot
.71365 .2554 Mdot
.18469 .70304 Mdot
.85918 .48206 Mdot
.48491 .22757 Mdot
.84552 .31121 Mdot
.87874 .84009 Mdot
.50251 .07028 Mdot
.0345 .29283 Mdot
.85079 .418 Mdot
.78341 .65084 Mdot
.05341 .95417 Mdot
.16922 .81765 Mdot
.25911 .83215 Mdot
.20431 .88625 Mdot
.68133 .29101 Mdot
.99627 .49349 Mdot
.48366 .13154 Mdot
.23446 .97967 Mdot
.04188 .84091 Mdot
.0193 .6797 Mdot
.42421 .19743 Mdot
.40496 .09274 Mdot
.2116 .38418 Mdot
.13444 .11937 Mdot
.12048 .79417 Mdot
.18439 .39833 Mdot
.30128 .39507 Mdot
.99575 .67629 Mdot
.11223 .3757 Mdot
.02548 .74557 Mdot
.76112 .64291 Mdot
.8792 .08422 Mdot
.68974 .13926 Mdot
.57308 .11339 Mdot
.19513 .81005 Mdot
.13898 .76174 Mdot
.19535 .95185 Mdot
.25432 .68482 Mdot
.76341 .47356 Mdot
.09866 .71459 Mdot
.89385 .33978 Mdot
.9371 .1773 Mdot
.83607 .48189 Mdot
.97617 .06204 Mdot
.40981 .22363 Mdot
.49093 .07997 Mdot
.14068 .55416 Mdot
.19958 .38916 Mdot
.83244 .41431 Mdot
.23078 .8411 Mdot
.41496 .6486 Mdot
.99037 .03854 Mdot
.32715 .59645 Mdot
.90183 .97832 Mdot
.68007 .86247 Mdot
.85521 .69708 Mdot
.22002 .75608 Mdot
.13888 .79632 Mdot
.01377 .08568 Mdot
.7165 .72351 Mdot
.04294 .85438 Mdot
.55253 .76339 Mdot
.86715 .32101 Mdot
.80206 .86313 Mdot
.21929 .74518 Mdot
.02066 .75586 Mdot
.80218 .89041 Mdot
.99442 .29187 Mdot
.45925 .22928 Mdot
.78435 .21828 Mdot
.30379 .98883 Mdot
.20948 .76754 Mdot
.26342 .91061 Mdot
.29163 .17779 Mdot
.57903 .67107 Mdot
.39666 .11197 Mdot
.22991 .58887 Mdot
.57543 .11835 Mdot
.64421 .09428 Mdot
.70778 .05646 Mdot
.14695 .98887 Mdot
.83407 .62795 Mdot
.13078 .95368 Mdot
.81265 .06755 Mdot
.58773 .88733 Mdot
.25407 .01429 Mdot
.0935 .33866 Mdot
.62951 .65028 Mdot
.78284 .64618 Mdot
.99212 .26332 Mdot
.98359 .60668 Mdot
.45442 .08188 Mdot
.58772 .82613 Mdot
.89384 .28981 Mdot
.56828 .88177 Mdot
.25089 .24559 Mdot
.24096 .80336 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`Go00003_ooool00ol0003o
ooooooooo`0=ooooo`;o00003_ooool00ol0003oooooooooo`03ooooo`;o00002?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00;o00003?ooool00ol0003oooooooooo`04ooooo`;o
00001oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0=ooooo`04o`000?oooooo0000o`0000cooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo000Nooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000oooooooo
ool02oooool5o`0000kooooo00?o0000ooooooooool03Oooool2o`0000kooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;o00003?ooool00ol0003o
ooooooooo`04ooooo`;o00001oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02o`0000cooooo00?o0000oooooooo
ool00_ooool001kooooo00?o0000ooooooooool00oooool2o`0000oooooo0_l0001^ooooo`;o0000
[_ooool2o`00017ooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0000Oooooo`Co0000G?oo
ool4o`0002[ooooo0_l0001Vooooo`;o00006?ooool2o`00017ooooo000Nooooo`03o`000?oooooo
oooo02Cooooo1?l0000Vooooo`;o00002?ooool2o`0001Oooooo0_l0000Cooooo`;o0000:_ooool2
o`0006?ooooo0_l000000ooooooo0000o`00000Hooooo`;o00004Oooool001kooooo00?o0000oooo
ooooool08?ooool2o`0002cooooo0_l00008ooooo`;o00005oooool2o`0007;ooooo0_l0000]oooo
o`;o000000?oooooo`000?l00000;_ooool001kooooo00?o0000ooooooooool08?ooool2o`0008So
oooo0_l0000iooooo`;o0000;Oooool2o`00037ooooo000Nooooo`03o`000?oooooooooo07[ooooo
0_l00008ooooo`;o00002oooool2o`0001Oooooo0_l0001Tooooo`;o00009Oooool2o`0000kooooo
000Nooooo`03o`000?oooooooooo00Sooooo0_l0001`ooooo`;o00002?ooool2o`0000_ooooo0_l0
000dooooo`;o00006Oooool4o`0002[ooooo0_l0000Uooooo`;o00003_ooool001kooooo00?o0000
ooooooooool02?ooool2o`0000Kooooo0_l0001Cooooo`;o0000Goooool3o`0001Wooooo1?l0001Q
ooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o0000Doooool2o`0005oooooo0_l0001ooooo
o`007_ooool00ol0003oooooooooo`2?ooooo`;o00000oooool2o`0007?ooooo0_l0000looooo`00
7_ooool00ol0003oooooooooo`2?ooooo`;o00000oooool2o`0007?ooooo0_l0000cooooo`;o0000
1oooool001kooooo00?o0000ooooooooool06oooool2o`0000[ooooo0_l0001Zooooo`;o00001ooo
ool2o`0007cooooo0_l0000Rooooo`;o00001oooool001kooooo00?o0000ooooooooool06oooool2
o`0000[ooooo0_l0000?ooooo`;o0000=Oooool3o`00027ooooo0_l00007ooooo`;o0000O?ooool2
o`0002_ooooo000Nooooo`?o00004Oooool2o`0000Oooooo0_l0000Looooo`;o0000=Oooool3o`00
06?ooooo0_l0000Gooooo`;o0000Eoooool001kooooo0ol0000Aooooo`;o00001oooool2o`000;Wo
oooo0_l0000Gooooo`;o0000??ooool2o`0001Wooooo000Nooooo`03o`000?oooooooooo0:Oooooo
0ol0000Fooooo`;o00008?ooool2o`0004Sooooo0_l0000Iooooo`007_ooool00ol0003ooooooooo
o`0Gooooo`;o00002Oooool2o`0000?ooooo0_l0001nooooo`?o00005_ooool2o`00023ooooo0_l0
001Hooooo`;o00002Oooool001kooooo00?o0000ooooooooool05oooool2o`0000Wooooo0_l00003
ooooo`;o00005_ooool2o`0001;ooooo0_l0002Looooo`;o0000@oooool2o`000004ooooool0003o
0000ooooo`;o00002Oooool001kooooo00?o0000ooooooooool07_ooool2o`0001oooooo0_l0000B
ooooo`;o0000=oooool2o`0006?ooooo0_l00009ooooo`;o0000>?ooool2o`000003ooooool0003o
000000cooooo000Nooooo`03o`000?oooooooooo01kooooo0_l00007ooooo`;o00001Oooool2o`00
037ooooo0_l0000Yooooo`;o0000C_ooool2o`0001kooooo0_l00006ooooo`;o0000@Oooool001ko
oooo00?o0000ooooooooool01Oooool2o`0000;ooooo0_l0000Looooo`;o00001Oooool2o`00037o
oooo0_l0000looooo`;o0000>oooool2o`0002Kooooo0_l00011ooooo`007_ooool00ol0003ooooo
ooooo`05ooooo`;o00000_ooool2o`0000Gooooo0_l0000Looooo`;o0000Koooool2o`00017ooooo
0_l0000Pooooo`;o00009Oooool2o`0004[ooooo000Nooooo`03o`000?oooooooooo013ooooo0_l0
000Looooo`;o0000Ooooool2o`000003ooooool0003o000001Kooooo0_l00008ooooo`;o00009Ooo
ool2o`0004[ooooo000Nooooo`03o`000?oooooooooo06Oooooo0_l0000Iooooo`;o00001oooool2
o`0000kooooo0_l0000Booooo`;o00003_ooool2o`0000Wooooo0_l00007ooooo`;o0000G?ooool2
o`0001Cooooo000Nooooo`03o`000?oooooooooo03Oooooo0_l0000^ooooo`;o00006Oooool2o`00
00Oooooo1?l000000ooooooo0000o`000008ooooo`?o00008_ooool2o`0001;ooooo0_l0000Noooo
o`;o00009Oooool2o`0000gooooo0_l00006ooooo`;o00005?ooool001gooooo0_l00002ooooo`;o
00006_ooool2o`0001Wooooo0_l0000Kooooo`;o0000=oooool2o`000003ooooool0003o000000So
oooo0_l0001Gooooo`;o00004Oooool2o`0001;ooooo0_l0000=ooooo`;o00004oooool2o`0000Oo
oooo000Mooooo`;o00000_ooool2o`0001[ooooo0_l0000fooooo`;o0000;oooool2o`0006[ooooo
0_l0000Cooooo`;o0000=_ooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo00;o00005_oo
ool2o`0006Kooooo0_l00003ooooo`;o0000J_ooool2o`0005Cooooo000Nooooo`03o`000?oooooo
oooo00;o00005_ooool2o`0006Kooooo0_l0000Cooooo`;o0000=_ooool2o`0004Cooooo0_l0000b
ooooo`007_ooool00ol0003oooooooooo`19ooooo`;o00003?ooool2o`0000;ooooo0_l0000hoooo
o`;o0000=_ooool2o`0000Sooooo1?l0000Mooooo`;o00001?ooool2o`0001?ooooo0_l0000boooo
o`007_ooool2o`0004[ooooo0_l0000<ooooo`;o00000_ooool2o`0001;ooooo0_l0001Vooooo`Co
00007Oooool2o`0000Cooooo0_l00017ooooo`007_ooool00ol0003oooooooooo`1Kooooo`;o0000
4Oooool3o`000003ooooool0003o000004Gooooo0_l000000ooooooo0000o`000029ooooo`007_oo
ool00ol0003oooooooooo`1^ooooo`;o00000_ooool2o`0004Gooooo0_l000000ooooooo0000o`00
0010ooooo`;o0000Aoooool001kooooo00?o0000ooooooooool0OOooool2o`0001kooooo0_l0000Q
ooooo`;o00001_ooool2o`0001[ooooo0_l0000Hooooo`;o000000?oooooo`000?l00000A?ooool0
01kooooo00?o0000ooooooooool0<oooool2o`0004Sooooo0_l0000Nooooo`;o00005oooool2o`00
00Sooooo0_l00006ooooo`;o00006_ooool2o`0001_ooooo0_l00014ooooo`007_ooool00ol0003o
ooooooooo`0cooooo`;o0000POooool2o`0004_ooooo0_l00012ooooo`007_ooool00ol0003ooooo
ooooo`0Kooooo`;o00001oooool2o`0000;ooooo0_l0000Xooooo`;o00004?ooool2o`0002Kooooo
0_l00006ooooo`;o00008Oooool2o`0004[ooooo0_l00012ooooo`007_ooool00ol0003ooooooooo
o`0Kooooo`;o00001oooool2o`0000;ooooo0_l0000Xooooo`;o00004?ooool2o`0002Kooooo0_l0
0006ooooo`;o00008Oooool2o`0003_ooooo0_l0001Aooooo`007_ooool00ol0003oooooooooo`3d
ooooo`;o0000DOooool001kooooo00?o0000ooooooooool02_ooool2o`0006oooooo0_l0002Koooo
o`;o0000;Oooool001kooooo00?o0000ooooooooool02_ooool4o`00013ooooo0_l00009ooooo`;o
0000D?ooool2o`0001cooooo0_l0001mooooo`;o0000;Oooool001kooooo00?o0000ooooooooool0
3?ooool2o`0000?ooooo0_l0000;ooooo`?o00002?ooool2o`0006kooooo0_l0002/ooooo`007_oo
ool00ol0003oooooooooo`0Aooooo`;o00003?ooool2o`0007Wooooo0_l00010ooooo`;o0000@?oo
ool2o`0002Oooooo000Nooooo`03o`000?oooooooooo03cooooo0_l0001Looooo`;o00002oooool2
o`0002Cooooo0_l0000=ooooo`;o00008Oooool2o`0001gooooo0_l0000Wooooo`007_ooool00ol0
003oooooooooo`0^ooooo`;o00003?ooool2o`0006Wooooo0_l0000Tooooo`;o00004oooool2o`00
01_ooooo0_l00016ooooo`007_ooool00ol0003oooooooooo`0^ooooo`;o00006?ooool2o`0001;o
oooo0_l00024ooooo`;o0000Hoooool001kooooo0_l00019ooooo`;o00004_ooool2o`000>Wooooo
000Nooooo`03o`000?oooooooooo06_ooooo0_l0003Jooooo`007_ooool00ol0003oooooooooo`0G
ooooo`;o0000?oooool2o`00017ooooo0_l0000Qooooo`;o0000Joooool2o`0003?ooooo0_l0000E
ooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o0000?oooool2o`0003Cooooo0_l00002oooo
o`;o00005oooool2o`0000Kooooo0_l0000Oooooo`;o00009Oooool2o`0003?ooooo0_l00005oooo
o`;o00003_ooool001kooooo00?o0000ooooooooool02_ooool2o`0008Kooooo0_l0000@ooooo`;o
00001Oooool2o`0000Kooooo0_l0000Oooooo`;o0000G?ooool2o`0000?ooooo0_l0000>ooooo`00
7_ooool00ol0003oooooooooo`0:ooooo`;o00009_ooool2o`0000_ooooo0_l0001Sooooo`;o0000
<Oooool2o`0005Wooooo0_l0000Cooooo`007_ooool00ol0003oooooooooo`0booooo`;o00001?oo
ool2o`0000Gooooo0_l0001_ooooo`;o00009Oooool2o`0000Sooooo0_l0001Tooooo`007_ooool0
0ol0003oooooooooo`0hooooo`;o00007?ooool2o`0003Sooooo0_l0000Nooooo`;o0000;oooool2
o`0006Cooooo000Nooooo`03o`000?oooooooooo05Kooooo0_l0000Qooooo`;o00005Oooool2o`00
08Sooooo0_l0000[ooooo`007_ooool00ol0003oooooooooo`1Kooooo`;o00007?ooool2o`0009oo
oooo0_l0000Aooooo`;o00006?ooool001kooooo00?o0000ooooooooool07oooool2o`0001Cooooo
0_l0000Tooooo`;o0000d?ooool2o`0001Sooooo000Nooooo`03o`000?oooooooooo01oooooo0_l0
000Dooooo`;o00009_ooool2o`000>Sooooo000Nooooo`03o`000?oooooooooo02cooooo0_l0000_
ooooo`;o0000S?ooool2o`0005[ooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0000Qoooo
o`;o00003?ooool2o`0001[ooooo0_l0000Booooo`;o0000J_ooool2o`0001?ooooo0_l0001Joooo
o`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0
003oooooooooo`09ooooo`;o00001?ooool2o`0002Wooooo0_l0000Jooooo`;o00004_ooool2o`00
06[ooooo0_l0001_ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`0?ooooo`;o0000J_ooool2
o`0000Wooooo0_l0001Eooooo`;o0000J?ooool000?ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0000Gooooo`;o0000H_ooool2o`0000Wooooo0_l0001E
ooooo`;o00004?ooool2o`0005Kooooo0003ooooo`05o`000?ooooooooooooooool000003Oooool0
0onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo01Oooooo0_l0003Fooooo`;o00001?ooool2
o`0000kooooo0_l00010ooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMg
ofIVI_ooool01Oooool00ol0003oooooooooo`04ooooo`;o0000L?ooool2o`0007gooooo0_l0000>
ooooo`;o000000?oooooo`000?l00000?Oooool000?ooooo00Go410@oooooooooooooooooa0@400?
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool2o`00073ooooo0_l0002@
ooooo`;o0000?Oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`06ooooo`;o0000HOooool2o`0000;ooooo0_l0
003Hooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c006ooooo`03o`000?oooooooooo00Kooooo0_l0001Qooooo`;o00000_ooool2o`000<gooooo
0_l00009ooooo`007_ooool00ol0003oooooooooo`3kooooo`;o0000?oooool2o`0000Wooooo000N
ooooo`03o`000?oooooooooo047ooooo0_l00014ooooo`;o0000;_ooool2o`0004;ooooo0ol0000L
ooooo`;o0000:oooool001kooooo00?o0000ooooooooool04?ooool2o`0002oooooo0_l0000Soooo
o`;o00006Oooool2o`0000Cooooo0_l0000^ooooo`;o0000@oooool2o`0001cooooo0_l0000Poooo
o`;o00002Oooool001kooooo00?o0000ooooooooool01?ooool2o`0000[ooooo0_l0000_ooooo`;o
00008oooool2o`0000oooooo0_l00008ooooo`;o00005oooool2o`0002Wooooo0_l0000_ooooo`;o
0000A?ooool2o`0000Wooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0000kooooo`;o0000
=?ooool2o`000003ooooool0003o000001Gooooo0_l00007ooooo`;o0000:?ooool3o`0002oooooo
0_l00014ooooo`;o00002Oooool001kooooo00?o0000ooooooooool0N_ooool2o`0001Gooooo0_l0
000aooooo`;o0000Aoooool2o`00017ooooo0_l00002ooooo`;o00004_ooool2o`0000gooooo000N
ooooo`03o`000?oooooooooo05[ooooo0_l0002aooooo`;o00003Oooool2o`0000;ooooo0_l00002
ooooo`;o00004_ooool2o`0000gooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l0000Loooo
o`;o00009?ooool2o`000<3ooooo0_l0000Sooooo`;o00001?ooool001kooooo00?o0000oooooooo
ool05_ooool2o`0001cooooo0_l0000Kooooo`;o0000POooool2o`0006_ooooo0_l00004ooooo`00
7_ooool00ol0003oooooooooo`1=ooooo`;o00000_ooool2o`00033ooooo0_l0000_ooooo`;o0000
7_ooool2o`0002Cooooo0_l0000Cooooo`;o0000=_ooool001kooooo00?o0000ooooooooool02ooo
ool2o`00043ooooo0_l0000dooooo`;o0000;oooool2o`0004Cooooo0_l0000Cooooo`;o0000=_oo
ool001kooooo0_l0000<ooooo`;o00001oooool2o`0000Oooooo0_l0000Eooooo`;o0000D?ooool2
o`0006gooooo0_l00019ooooo`;o00001Oooool001kooooo00?o0000ooooooooool05?ooool2o`00
00Oooooo0_l0000Eooooo`;o0000;Oooool3o`00023ooooo0_l0001Looooo`;o00003oooool2o`00
04Wooooo0_l00005ooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o00001Oooool2o`0004?o
oooo0ol0001nooooo`;o00004?ooool2o`0004oooooo000Nooooo`03o`000?oooooooooo01Oooooo
0_l00005ooooo`;o00008oooool2o`000:;ooooo0_l0000=ooooo`;o0000>oooool2o`0001;ooooo
000Nooooo`03o`000?oooooooooo04?ooooo0_l0002Rooooo`;o00001Oooool2o`00027ooooo0_l0
000Pooooo`;o00002Oooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo04_ooooo0_l0000:
ooooo`;o0000TOooool2o`0000;ooooo0_l00006ooooo`;o00006Oooool2o`0002_ooooo0_l00007
ooooo`007_ooool00ol0003oooooooooo`1;ooooo`;o00002_ooool2o`0003oooooo0_l0001@oooo
o`;o00002_ooool2o`0004?ooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`2Fooooo`Co
0000XOooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo09Kooooo0_l0002_ooooo`007_oo
ool00ol0003oooooooooo`3Sooooo`;o0000H_ooool001kooooo00?o0000ooooooooool0P?ooool2
o`00067ooooo0_l0000dooooo`;o00005?ooool2o`0001Kooooo000Nooooo`03o`000?oooooooooo
00;o00003oooool2o`0000;ooooo0_l00015ooooo`;o00008_ooool2o`0006Kooooo0_l0000_oooo
o`;o00005?ooool2o`0001Kooooo000Nooooo`03o`000?oooooooooo00;o00003oooool2o`0000;o
oooo0_l00015ooooo`;o00000oooool2o`0001Kooooo0_l0001]ooooo`;o0000;oooool2o`0000?o
oooo0_l0000Looooo`;o00002Oooool001kooooo00?o0000ooooooooool01oooool2o`0000cooooo
0_l00019ooooo`?o00005_ooool2o`0005kooooo0_l00006ooooo`;o00005Oooool2o`0000Kooooo
0_l0000Looooo`;o00007?ooool2o`000003ooooool0003o000000Kooooo000Nooooo`03o`000?oo
oooooooo00Oooooo0_l0000Hooooo`;o00009?ooool2o`0001Oooooo0_l0001gooooo`;o00001_oo
ool2o`0001Gooooo0_l00006ooooo`;o0000?Oooool2o`0000Kooooo000Nooooo`03o`000?oooooo
oooo01cooooo0_l00003ooooo`;o00001oooool2o`0001_ooooo0_l0000@ooooo`;o00005oooool2
o`0000;ooooo0_l0003?ooooo`007_ooool2o`0001;ooooo0_l00009ooooo`;o00003?ooool2o`00
02gooooo0_l0000Gooooo`;o00000_ooool2o`0002Cooooo0_l00002ooooo`;o0000YOooool001ko
oooo0ol0000Aooooo`;o0000ROooool2o`0000;ooooo0_l0002Uooooo`007_ooool3o`0004_ooooo
0_l0003Xooooo`;o00004?ooool001kooooo00?o0000ooooooooool0Boooool2o`00097ooooo0_l0
0006ooooo`;o00009oooool2o`00023ooooo0_l00002ooooo`;o00004?ooool001kooooo00?o0000
ooooooooool0g_ooool2o`0000Kooooo0_l0000Wooooo`;o00005?ooool2o`0000[ooooo0_l0000D
ooooo`007_ooool00ol0003oooooooooo`2_ooooo`;o0000M?ooool2o`00023ooooo000Nooooo`03
o`000?oooooooooo09Wooooo0_l0000Dooooo`;o0000<Oooool2o`0003;ooooo0_l0000_ooooo`00
7_ooool00ol0003oooooooooo`0Rooooo`;o0000AOooool2o`0002kooooo0_l00017ooooo`;o0000
<_ooool2o`0000_ooooo0_l0000Rooooo`007_ooool00ol0003oooooooooo`02ooooo`;o00007_oo
ool2o`0004Gooooo0_l0002hooooo`;o00008_ooool001kooooo00?o0000ooooooooool00_ooool2
o`0005[ooooo0_l0003Wooooo`007_ooool00ol0003oooooooooo`1Nooooo`;o0000ioooool001ko
oooo00?o0000ooooooooool04_ooool2o`0007oooooo0_l0002booooo`007_ooool00ol0003ooooo
ooooo`0Booooo`;o00001_ooool2o`0007Oooooo0_l0002Vooooo`;o00002_ooool001kooooo00?o
0000ooooooooool06_ooool2o`000=Wooooo0_l0000Wooooo`;o00006oooool2o`0000[ooooo000N
ooooo`03o`000?oooooooooo02Wooooo0_l0003:ooooo`;o00009oooool2o`0000Sooooo0_l0000M
ooooo`007_ooool00ol0003oooooooooo`04ooooo`;o00000_ooool2o`0001oooooo0_l0003Foooo
o`;o00009Oooool2o`0001gooooo000Nooooo`;o00001Oooool2o`0000;ooooo0_l00032ooooo`;o
0000<oooool2o`0000?ooooo0_l0000Jooooo`;o00005?ooool2o`0000gooooo000Nooooo`03o`00
0?oooooooooo01oooooo0_l00026ooooo`;o00008oooool2o`0003Sooooo0_l0000Jooooo`;o0000
1_ooool2o`0000cooooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o00007ooo
ool2o`0003Oooooo0_l0000/ooooo`;o0000@oooool2o`00027ooooo0_l0000Iooooo`;o00006ooo
ool001kooooo00?o0000ooooooooool04Oooool2o`0002gooooo0_l0000Yooooo`;o00003?ooool2
o`0000_ooooo0_l0001Tooooo`;o00002oooool2o`0001Cooooo0_l0000fooooo`007_ooool00ol0
003oooooooooo`0Aooooo`;o0000>_ooool2o`0000Kooooo0_l0000Dooooo`;o00006Oooool2o`00
00cooooo0_l0001Sooooo`;o00005?ooool2o`0003Kooooo000Nooooo`03o`000?oooooooooo02co
oooo0_l0000Oooooo`Co00001?ooool2o`0003gooooo0_l0000?ooooo`;o0000J?ooool2o`0003Ko
oooo000Nooooo`03o`000?oooooooooo02cooooo0_l0000Qooooo`;o0000@Oooool2o`00017ooooo
0_l0001Mooooo`;o0000@Oooool001kooooo00?o0000ooooooooool03_ooool2o`00027ooooo0_l0
000Mooooo`;o00008Oooool2o`0001gooooo0_l0001`ooooo`;o0000;oooool2o`00013ooooo000N
ooooo`03o`000?oooooooooo00kooooo0_l0000@ooooo`;o00003oooool2o`0001gooooo0_l0000Q
ooooo`;o0000=_ooool2o`0006gooooo0_l0000Iooooo`;o00004?ooool001kooooo00?o0000oooo
ooooool03_ooool2o`0000kooooo1?l0000Tooooo`;o0000E_ooool2o`0000_ooooo0_l0001Doooo
o`;o00002Oooool2o`0000cooooo0_l0000[ooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o
00003_ooool2o`0002Kooooo0_l0001Fooooo`;o0000Foooool2o`0000Cooooo0_l00009ooooo`;o
00007Oooool2o`0000Oooooo0_l0000Aooooo`007_ooool00ol0003oooooooooo`0Vooooo`;o0000
6Oooool2o`0003_ooooo0_l0000Looooo`;o0000Doooool2o`0000Sooooo0_l0000^ooooo`;o0000
1oooool2o`00017ooooo000Nooooo`03o`000?oooooooooo01_ooooo0_l00009ooooo`;o00001_oo
ool2o`0000Wooooo0_l00006ooooo`;o00003_ooool2o`0002_ooooo0_l0000Looooo`;o0000Dooo
ool2o`0005Cooooo000Nooooo`03o`000?oooooooooo01_ooooo0_l0000Aooooo`;o00001_ooool2
o`000003ooooool0003o000000;ooooo0_l0000Booooo`;o0000m?ooool000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000
ooooooooool0=_ooool2o`0000Gooooo0_l0000=ooooo`;o00004?ooool2o`000>Oooooo0003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0=ooooo`;o0000?Oooool2o`00013ooooo0_l0003Wooooo`000oooool01Ol@
413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`?o00003Oooool2o`0002Wooooo0_l00008
ooooo`;o0000ooooool4ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo00001oooool00ol0003oooooooooo`0hooooo`;o00002?ooool2o`000?oooooo1?oo
ool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo
00?o0000ooooooooool0;_ooool2o`0004Wooooo0_l0000@ooooo`;o00001oooool2o`0001oooooo
0_l0002@ooooo`000oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000
1oooool00ol0003oooooooooo`0Uooooo`;o00001oooool2o`0004Wooooo0_l0000@ooooo`;o0000
1oooool2o`0000Kooooo0_l0000Gooooo`;o00006oooool2o`0005kooooo0_l0000=ooooo`;o0000
1?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo
00?o0000ooooooooool09Oooool2o`0007Gooooo0_l0000dooooo`;o0000G_ooool2o`0000gooooo
0_l00004ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool0
1_ooool00ol0003oooooooooo`2Pooooo`;o0000H?ooool2o`0000Oooooo0_l0000jooooo`007_oo
ool2o`0009Kooooo0_l00009ooooo`;o0000H?ooool2o`0000Oooooo0_l00003ooooo`;o00006_oo
ool2o`0001Wooooo000Nooooo`;o0000KOooool2o`0002Oooooo0_l0000dooooo`;o00008_ooool2
o`00013ooooo0_l0000=ooooo`;o00006_ooool2o`0000gooooo0_l0000:ooooo`007_ooool00ol0
003oooooooooo`02o`0006[ooooo0_l0001Mooooo`;o00008_ooool2o`00013ooooo0_l0000hoooo
o`;o00002_ooool001kooooo00?o0000ooooooooool00_l00030ooooo`;o00001_ooool2o`0007_o
oooo000Nooooo`03o`000?oooooooooo0<;ooooo0_l00006ooooo`;o0000Coooool2o`0002[ooooo
000Nooooo`03o`000?oooooooooo02Sooooo0_l0001Tooooo`Co0000Loooool2o`0001Cooooo0_l0
000Zooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o00001oooool2o`0000;ooooo0_l0001P
ooooo`Co0000>?ooool2o`0003Wooooo0_l0000Kooooo`;o00008oooool001kooooo00?o0000oooo
ooooool07oooool2o`0000_ooooo0_l0002Looooo`;o0000E_ooool2o`0002?ooooo000Nooooo`03
o`000?oooooooooo02Oooooo0_l00009ooooo`?o000000?oooooo`000?l00000M_ooool2o`0009Oo
oooo000Nooooo`03o`000?oooooooooo02Oooooo0_l00009ooooo`?o000000?oooooo`000?l00000
M_ooool2o`0009Oooooo000Nooooo`03o`000?oooooooooo03Gooooo0_l0001@ooooo`;o00002?oo
ool2o`000;Cooooo000Nooooo`;o0000=_ooool2o`00053ooooo0_l00008ooooo`;o0000M?ooool2
o`0003kooooo000Nooooo`03o`000?oooooooooo033ooooo0_l0000[ooooo`;o00009Oooool2o`00
0003ooooool0003o000007kooooo0_l0000`ooooo`;o00003?ooool001kooooo00?o0000oooooooo
ool0<?ooool2o`0002_ooooo0_l0000Uooooo`;o000000?oooooo`000?l00000X?ooool2o`0000ko
oooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`0Booooo`;o0000BOooool2o`000<[ooooo
0_l0000Looooo`007_ooool00ol0003oooooooooo`0Booooo`;o0000ooooooldooooo`007_ooool0
0ol0003oooooooooo`3ooooooa[ooooo0_l0000/ooooo`007_ooool00ol0003oooooooooo`0ioooo
o`;o00007?ooool2o`0001oooooo0_l0002Oooooo`;o0000;?ooool001kooooo00?o0000oooooooo
ool0>Oooool2o`0001cooooo0_l00002ooooo`;o00002Oooool2o`00013ooooo0_l0000]ooooo`;o
0000B?ooool2o`000003ooooool0003o000000gooooo0_l00012ooooo`007_ooool00ol0003ooooo
ooooo`0Dooooo`;o00002oooool2o`0003Sooooo0_l00009ooooo`;o00006Oooool2o`0002Cooooo
0_l0000:ooooo`;o0000??ooool2o`000003ooooool0003o000000;ooooo0_l00009ooooo`;o0000
@_ooool001kooooo00?o0000ooooooooool05?ooool2o`0000_ooooo0_l0001:ooooo`;o00004_oo
ool2o`00013ooooo0_l0000Nooooo`;o0000@oooool2o`0004gooooo000Nooooo`03o`000?oooooo
oooo03Sooooo0_l0000cooooo`;o00009?ooool2o`0005?ooooo0_l0000Rooooo`;o00001Oooool2
o`0003;ooooo000Nooooo`03o`000?oooooooooo03Sooooo0_l0000Cooooo`;o00006oooool2o`00
07cooooo0_l0000Rooooo`;o00001Oooool2o`0003;ooooo000Nooooo`03o`000?oooooooooo04go
oooo0_l00006ooooo`Co00004Oooool2o`000=_ooooo000Nooooo`03o`000?oooooooooo05Gooooo
1?l0002Wooooo`;o00008?ooool2o`0001cooooo0_l00005ooooo`007_ooool00ol0003ooooooooo
o`3gooooo`;o00001oooool2o`00023ooooo0_l0000Looooo`;o00001Oooool001kooooo00?o0000
ooooooooool03oooool2o`0001Cooooo0_l0002Sooooo`;o0000:oooool2o`0004kooooo000Noooo
o`;o00004?ooool2o`0001Cooooo0_l00009ooooo`;o0000R?ooool2o`0000kooooo0_l0001coooo
o`;o00001_ooool001kooooo00Co0000ooooool0003o0000;oooool2o`0001?ooooo0_l0000Voooo
o`;o0000Boooool2o`0008;ooooo0ol00006ooooo`007_ooool01?l0003oooooo`000?l0000Foooo
o`;o0000;?ooool2o`0001Wooooo0_l0000;ooooo`;o0000ZOooool2o`0002Cooooo0_l00007oooo
o`007_ooool00ol0003oooooooooo`0;ooooo`;o00002_ooool2o`0004Oooooo0_l0000;ooooo`;o
00003oooool2o`0009Sooooo0_l0000Qooooo`;o00002_ooool001kooooo00?o0000ooooooooool0
2oooool2o`0004gooooo0_l0000Rooooo`;o00004_ooool2o`0004kooooo0_l0001Gooooo`;o0000
2_ooool001gooooo0_l0001Looooo`;o00002_ooool2o`0002[ooooo0_l0001>ooooo`;o0000;Ooo
ool4o`0000gooooo0_l0000Hooooo`;o00002Oooool001gooooo0_l0001Xooooo`;o0000Z?ooool5
o`0000gooooo0_l0000=ooooo`;o00002Oooool2o`0000Wooooo000Nooooo`03o`000?oooooooooo
00;ooooo0_l0003Fooooo`;o0000=?ooool2o`0001oooooo0_l0000=ooooo`;o00001Oooool001ko
oooo00?o0000ooooooooool00_ooool2o`00047ooooo0_l0001_ooooo`;o00008_ooool2o`0006Co
oooo0_l00005ooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o0000:oooool2o`0006oooooo
0_l0002?ooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o0000T?ooool2o`0000cooooo0_l0
000;ooooo`;o00003_ooool2o`0001?ooooo0_l0000<ooooo`;o00003?ooool2o`0003oooooo000N
ooooo`03o`000?oooooooooo0:[ooooo0_l0000<ooooo`;o00000oooool2o`0000Kooooo0_l0000>
ooooo`;o00004oooool2o`0000cooooo0_l0000<ooooo`;o00003oooool2o`0002;ooooo0_l0000:
ooooo`007_ooool00ol0003oooooooooo`0Booooo`;o0000<_ooool2o`0004oooooo0_l0000Roooo
o`Co0000F?ooool2o`0002;ooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0Booooo`;o
0000<_ooool2o`0004oooooo0_l0000Rooooo`;o0000R_ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`2Zooooo`;o0000Voooool001kooooo0_l0001T
ooooo`;o00001Oooool2o`0003kooooo0_l0002Kooooo`007_ooool00ol0003oooooooooo`0Zoooo
o`;o0000=oooool2o`0000Gooooo0_l0000Aooooo`;o00002?ooool2o`0005Wooooo0_l0000Ioooo
o`;o0000B?ooool001kooooo00Co0000oooooooooooooooo0_l0000Wooooo`;o00003_ooool2o`00
01Oooooo0_l0000Dooooo`;o00004_ooool2o`0000Sooooo0_l0000`ooooo`;o00009oooool2o`00
01Wooooo0_l00018ooooo`007_ooool01?l0003oooooooooooooool2o`0003Oooooo0_l0000Goooo
o`;o00005?ooool2o`0004kooooo0_l00011ooooo`;o0000BOooool001kooooo00?o0000oooooooo
ool0K_ooool2o`0001Wooooo0_l0001Sooooo`;o00003?ooool2o`0004Wooooo000Nooooo`03o`00
0?oooooooooo02Sooooo0_l00014ooooo`;o00006Oooool2o`0000Cooooo0_l0001>ooooo`;o0000
3Oooool2o`0005Oooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0000Rooooo`;o0000AOoo
ool3o`0000[ooooo0_l0000Aooooo`;o0000C_ooool2o`0006Kooooo000Nooooo`03o`000?oooooo
oooo00Cooooo0_l0000Yooooo`;o0000?_ooool3o`0000[ooooo1?l0000<ooooo`;o0000^Oooool0
01kooooo00?o0000ooooooooool0;oooool2o`0003oooooo0_l0000<ooooo`;o00003?ooool2o`00
04Sooooo0_l0001_ooooo`007_ooool00ol0003oooooooooo`1`ooooo`;o0000I?ooool2o`00027o
oooo0_l0000Iooooo`;o0000<Oooool001kooooo00?o0000ooooooooool04oooool2o`000>Cooooo
0_l0000Iooooo`;o0000<Oooool001kooooo00?o0000ooooooooool04oooool2o`0003?ooooo0_l0
001Cooooo`;o0000Coooool2o`00033ooooo0_l00008ooooo`;o00006oooool001kooooo00?o0000
ooooooooool0Aoooool3o`0005?ooooo0_l00006ooooo`;o00001?ooool2o`00027ooooo0_l0000N
ooooo`;o0000<?ooool2o`0000Sooooo0_l0000Kooooo`007_ooool00ol0003oooooooooo`17oooo
o`;o0000G?ooool2o`0000Cooooo0_l0000Mooooo`;o00000_ooool2o`0007Oooooo0003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006
ooooo`03o`000?oooooooooo04kooooo0_l0001Wooooo`;o00004Oooool2o`0004Cooooo0_l0000e
ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOo
oooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1>ooooo`;o00005_ooool2o`0004oooooo0_l0
001Gooooo`;o0000=Oooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oo
ooooooooooooool000001_ooool3o`0001[ooooo0_l0001:ooooo`;o00006Oooool2o`0008gooooo
0_l0000eooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@06ooooo`03o`000?oooooooooo01[ooooo0_l0000Eooooo`;o0000C_ooool2o`0004Oo
oooo0_l00014ooooo`;o0000=Oooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05
o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`09ooooo`;o00004?ooool2o`00
00Kooooo0_l0000<ooooo`;o00006oooool2o`000003ooooool0003o000003Gooooo0_l00010oooo
o`;o0000F?ooool2o`0001Kooooo0_l00009ooooo`000oooool01Ol@413ooooooooooooooooo410@
00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`09ooooo`;o00004?ooool2o`00
00Kooooo0_l0000Yooooo`;o000000?oooooo`000?l000009_ooool2o`0000gooooo0_l0002Joooo
o`;o00005_ooool2o`0000Wooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooM
gMgo410@oiRHV008ooooo`03o`000?oooooooooo02Gooooo0_l00015ooooo`;o00002oooool2o`00
03Kooooo0_l00006ooooo`;o0000S?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool09Oooool2o`0004Gooooo0_l0000h
ooooo`;o00002Oooool2o`0000Kooooo0_l0001/ooooo`;o00007_ooool001kooooo00?o0000oooo
ooooool0;Oooool2o`0007Oooooo0_l0000Pooooo`;o0000>oooool2o`00023ooooo0_l0000Noooo
o`007_ooool3o`0002gooooo0_l0000kooooo`;o00007oooool2o`00033ooooo0_l00009ooooo`;o
0000>?ooool2o`000003ooooool0003o000001?ooooo0_l0000[ooooo`007_ooool3o`0006[ooooo
0_l0000Oooooo`;o0000<?ooool2o`0004?ooooo1?l0000Dooooo`;o00004_ooool2o`0001Oooooo
000Nooooo`03o`000?oooooooooo06Oooooo0_l0001oooooo`;o00006_ooool2o`0000Gooooo0_l0
000Qooooo`;o00005oooool001kooooo00Co0000oooooooooooooooo0_l0000eooooo`;o0000;Ooo
ool2o`0002_ooooo0_l0001Booooo`;o00008Oooool2o`0003;ooooo0_l00006ooooo`007_ooool0
1?l0003oooooooooooooool2o`0003Gooooo0_l0000Xooooo`;o0000<?ooool2o`0001Sooooo0_l0
000?ooooo`;o0000O_ooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo02_ooooo0_l0000e
ooooo`;o0000B_ooool2o`0000oooooo0_l00026ooooo`007_ooool00ol0003oooooooooo`0[oooo
o`;o0000oooooolKooooo`007_ooool00ol0003oooooooooo`0Wooooo`;o00006_ooool2o`0002_o
oooo0_l0001?ooooo`;o0000<?ooool2o`0004_ooooo0_l00005ooooo`007_ooool00ol0003ooooo
ooooo`0Wooooo`;o00006_ooool2o`0001Gooooo0_l0000Dooooo`;o0000Coooool2o`00033ooooo
0_l00005ooooo`;o0000@_ooool4o`0000Gooooo000Nooooo`03o`000?oooooooooo03Gooooo0_l0
000Sooooo`;o00009oooool2o`0004Cooooo0_l0000_ooooo`;o00005oooool2o`0002Wooooo0_l0
0007ooooo`007_ooool2o`0000Sooooo0_l0000Tooooo`;o00001_ooool2o`0004cooooo0_l00014
ooooo`;o0000<?ooool2o`0001Kooooo0_l0000booooo`007_ooool00ol0003oooooooooo`07oooo
o`;o00002Oooool2o`0001Wooooo0_l0003<ooooo`;o0000B_ooool001kooooo00?o0000oooooooo
ool04_ooool2o`0002oooooo0_l0000kooooo`;o00006?ooool2o`0000kooooo0_l0000Aooooo`;o
0000<?ooool2o`0000gooooo0_l00017ooooo`007_ooool00ol0003oooooooooo`0kooooo`;o0000
1_ooool2o`0003_ooooo0ol0000Cooooo`;o00000_ooool2o`0000kooooo0_l000000ooooooo0000
o`00000>ooooo`;o0000<?ooool2o`0000gooooo0_l00017ooooo`007_ooool00ol0003ooooooooo
o`0hooooo`;o000000?oooooo`000?l00000A?ooool2o`0001?ooooo0_l0000:ooooo`;o00002Ooo
ool2o`0009Sooooo000Nooooo`03o`000?oooooooooo00cooooo0_l0000Booooo`;o00005_ooool2
o`00047ooooo0_l0000=ooooo`;o00005Oooool3o`00043ooooo0_l0000jooooo`;o00005Oooool2
o`0000kooooo000Nooooo`03o`000?oooooooooo00cooooo0_l0000Booooo`;o0000FOooool2o`00
00gooooo0_l0000Eooooo`;o00005Oooool2o`0000oooooo0_l0000Iooooo`;o0000>_ooool2o`00
00Gooooo0_l0000>ooooo`;o00003_ooool001kooooo00Co0000oooooooooooooooo0_l0000Poooo
o`;o0000P?ooool2o`00017ooooo0_l0000?ooooo`;o0000G?ooool2o`0001kooooo000Nooooo`04
o`000?ooooooooooooooo`;o00008?ooool2o`0000cooooo0_l0000Eooooo`;o0000Foooool2o`00
05Oooooo0_l0000Hooooo`;o00009_ooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo00;o
oooo0_l0000]ooooo`;o00005Oooool2o`0005_ooooo0_l0001Gooooo`;o00006?ooool2o`0002Ko
oooo0_l00005ooooo`007_ooool00ol0003oooooooooo`02ooooo`;o00009Oooool2o`0000Wooooo
0_l0001_ooooo`;o0000X?ooool001kooooo00?o0000ooooooooool0:Oooool2o`0000Wooooo0_l0
000:ooooo`;o00003Oooool2o`0002Oooooo0_l0000iooooo`;o0000Coooool2o`0000oooooo0_l0
000`ooooo`007_ooool2o`00047ooooo0_l0000=ooooo`;o00009oooool2o`0001[ooooo0_l0000M
ooooo`;o0000Coooool2o`0000oooooo0_l0000`ooooo`007_ooool2o`0002gooooo0_l0001Voooo
o`;o0000U?ooool2o`0000_ooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`04ooooo`;o
00009_ooool2o`0006Kooooo1?l0002Booooo`;o00002oooool2o`0000kooooo000Nooooo`03o`00
0?oooooooooo00Cooooo0_l0001>ooooo`;o0000?_ooool4o`0002Wooooo0_l0001<ooooo`;o0000
00?oooooo`000?l000006oooool2o`0001Kooooo000Nooooo`;o0000:oooool2o`00027ooooo0_l0
0005ooooo`;o0000Joooool2o`0004cooooo0_l000000ooooooo0000o`00000Kooooo`;o00005_oo
ool001kooooo00?o0000ooooooooool08Oooool2o`0000Oooooo0_l0000<ooooo`;o00000oooool2
o`0000kooooo0_l0003Hooooo`;o00007_ooool001kooooo00?o0000ooooooooool08Oooool2o`00
01Gooooo0_l00003ooooo`;o0000e_ooool2o`00013ooooo0_l0000Nooooo`007_ooool00ol0003o
ooooooooo`1<ooooo`;o0000Voooool2o`0002[ooooo0_l0000`ooooo`007_ooool00ol0003ooooo
ooooo`0Looooo`;o00001?ooool2o`0002Sooooo0_l0001?ooooo`;o00003oooool2o`0003Wooooo
0_l0000Vooooo`;o0000=?ooool001kooooo00?o0000ooooooooool07?ooool2o`0000Cooooo0_l0
001Uooooo`;o00004_ooool2o`0000oooooo0_l0001Qooooo`;o0000;?ooool2o`0000Kooooo000N
ooooo`03o`000?oooooooooo00[ooooo0_l0000=ooooo`;o0000D?ooool2o`0001cooooo0_l0000U
ooooo`;o0000SOooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0000=oooo
o`;o0000D?ooool2o`0000[ooooo0_l0000gooooo`;o00007Oooool2o`0001Cooooo0_l0001Poooo
o`007_ooool00ol0003oooooooooo`0Fooooo`;o0000Goooool2o`0000kooooo0_l00016ooooo`;o
00005?ooool2o`00063ooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l0001_ooooo`;o0000
4?ooool2o`000:cooooo000Nooooo`03o`000?oooooooooo04kooooo0_l0000@ooooo`;o0000=ooo
ool2o`0003Gooooo0_l0001eooooo`007_ooool00ol0003oooooooooo`08ooooo`;o0000A?ooool2
o`0000;ooooo0_l0000<ooooo`;o00003?ooool2o`00063ooooo0_l0001eooooo`007_ooool00ol0
003oooooooooo`08ooooo`;o00005Oooool2o`0002cooooo0_l00003ooooo`;o00006_ooool2o`00
013ooooo0_l00035ooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o0000;?ooool2o`00013o
oooo0_l0000Oooooo`;o0000aOooool001kooooo00?o0000ooooooooool01?ooool2o`0003gooooo
0_l0000Jooooo`;o0000>Oooool2o`0001?ooooo0_l000000ooooooo0000o`00002Cooooo`007_oo
ool00ol0003oooooooooo`04ooooo`;o00005oooool2o`0000?ooooo0_l0000Oooooo`;o0000EOoo
ool2o`0000Oooooo0_l000000ooooooo0000o`000005ooooo`Co000000?oooooo`000?l000009ooo
ool2o`0006[ooooo000Nooooo`;o00007_ooool2o`0000?ooooo0_l0000Zooooo`;o0000=oooool2
o`0001[ooooo0_l000000ooooooo0000o`000005ooooo`;o0000;?ooool2o`0001?ooooo0_l00006
ooooo`;o0000A?ooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo04kooooo0_l0000goooo
o`;o0000D?ooool2o`0001Gooooo0_l00006ooooo`;o0000A?ooool2o`0000Oooooo000Nooooo`03
o`000?oooooooooo00?ooooo0_l0000nooooo`;o00008oooool3o`0005Wooooo0_l00004ooooo`;o
00003Oooool2o`0006cooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0000nooooo`;o0000
8oooool3o`0000kooooo0_l00019ooooo`;o00001?ooool2o`0005?ooooo0_l0000Vooooo`007_oo
ool00ol0003oooooooooo`0Yooooo`;o0000B_ooool2o`0000;ooooo0_l0000Aooooo`;o00008_oo
ool2o`0006gooooo0_l0000Vooooo`007_ooool00ol0003oooooooooo`0Fooooo`;o00004Oooool2
o`0004[ooooo0_l0000Eooooo`;o00008_ooool2o`0009Gooooo000Nooooo`03o`000?oooooooooo
01Kooooo0_l0000Xooooo`;o0000ooooool6ooooo`007_ooool00ol0003oooooooooo`0jooooo`;o
00001?ooool2o`000:_ooooo0_l0000gooooo`;o00007oooool001kooooo00?o0000ooooooooool0
>_ooool2o`0003kooooo0_l0001aooooo`;o00001?ooool2o`0001;ooooo0_l0000Mooooo`;o0000
7oooool001kooooo00?o0000ooooooooool0K?ooool2o`0000cooooo0_l0000Hooooo`;o0000<ooo
ool2o`0002Sooooo0_l0000Booooo`;o0000?_ooool001kooooo00?o0000ooooooooool00oooool2
o`0006Oooooo0ol0000Uooooo`;o00003Oooool2o`0001Wooooo0_l00005ooooo`;o00000_ooool2
o`0005Oooooo0_l0000Sooooo`007_ooool00ol0003oooooooooo`03ooooo`;o0000J?ooool2o`00
03Cooooo0_l00008ooooo`;o00003oooool2o`0000Gooooo0_l0001Kooooo`;o00007?ooool2o`00
00Gooooo000Nooooo`;o0000[_ooool2o`0001[ooooo0_l00013ooooo`;o0000:Oooool2o`0000Go
oooo0_l00005ooooo`007_ooool2o`000<[ooooo0_l00013ooooo`;o0000:Oooool2o`0000Gooooo
0_l00005ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<
c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`09ooooo`;o00005Oooool2o`000003
ooooool0003o00000;;ooooo0_l0001Wooooo`;o00001Oooool000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000oooo
ooooool02Oooool2o`0001Gooooo0_l000000ooooooo0000o`000004ooooo`;o0000U_ooool2o`00
01Cooooo0_l0000gooooo`;o0000=Oooool000?ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000001_ooool3o`00013ooooo0_l0000Gooooo`;o0000U_ooool2
o`0004gooooo0_l0000eooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8b
oiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooooooo00Gooooo0_l00009ooooo`;o0000>?oo
ool2o`0008gooooo0_l0001/ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go
c<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo00Gooooo0_l00013ooooo`;o0000
SOooool2o`00017ooooo0_l0001Iooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo
00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo03_ooooo0_l0000Hooooo`;o
0000=oooool2o`0004Kooooo0_l0000Dooooo`;o00009Oooool2o`0003;ooooo0003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000oooo
ooooool0>oooool2o`0001Sooooo0_l0000gooooo`;o0000?_ooool2o`0000Kooooo0_l0000eoooo
o`;o00001?ooool2o`0003;ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnY
ZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool01?ooool2o`00053ooooo0_l0001f
ooooo`;o0000<_ooool2o`0000Wooooo0_l0000?ooooo`;o00009oooool001kooooo0ol00004oooo
o`;o0000;Oooool2o`0000Cooooo0_l0000Kooooo`;o0000Z_ooool2o`0001Cooooo0_l00004oooo
o`;o00009oooool001kooooo0ol0000cooooo`;o00001?ooool2o`000=gooooo0_l00002ooooo`;o
0000:Oooool001kooooo00?o0000ooooooooool0JOooool2o`0007Wooooo0_l00006ooooo`;o0000
;_ooool2o`0002Wooooo000Nooooo`03o`000?oooooooooo06Wooooo0ol0001?ooooo`;o00005?oo
ool2o`00017ooooo0_l00006ooooo`;o0000?Oooool2o`0001[ooooo000Nooooo`03o`000?oooooo
oooo03oooooo0_l0000Yooooo`;o0000Coooool2o`0001Cooooo0_l0001Hooooo`;o00000oooool2
o`0001Gooooo000Nooooo`03o`000?oooooooooo03oooooo0_l0000?ooooo`;o0000Ioooool2o`00
00?ooooo0_l0001`ooooo`;o00005Oooool001kooooo00?o0000ooooooooool01?ooool2o`0001Ko
oooo0_l0000Eooooo`;o00006oooool2o`0004oooooo0_l0000Fooooo`;o00000oooool2o`0001co
oooo0_l0001Yooooo`007_ooool00ol0003oooooooooo`04ooooo`;o00000oooool2o`00017ooooo
0_l0000Eooooo`;o00004_ooool2o`0001[ooooo0_l0000looooo`;o0000>Oooool2o`0001gooooo
0_l0000Aooooo`;o00002Oooool3o`0002_ooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0
000looooo`;o00006_ooool2o`0003Wooooo0_l0000@ooooo`;o0000BOooool2o`00017ooooo0_l0
0009ooooo`?o00007?ooool2o`0000gooooo000Nooooo`03o`000?oooooooooo07Kooooo0_l0000O
ooooo`;o00001Oooool2o`00013ooooo0_l0000Eooooo`;o0000Koooool2o`0000gooooo000Noooo
o`03o`000?oooooooooo01[ooooo0_l0000Gooooo`;o0000@Oooool2o`0000Kooooo0_l0000Goooo
o`;o000000?oooooo`000?l000002oooool2o`0000[ooooo0_l0000Booooo`;o0000COooool2o`00
02oooooo000Nooooo`;o00006?ooool2o`000003ooooool0003o000001Oooooo0_l00019ooooo`;o
00006_ooool2o`0000_ooooo0_l0000:ooooo`;o0000;?ooool2o`0003?ooooo0_l0000_ooooo`00
7_ooool00ol0003oooooooooo`0:ooooo`;o00002oooool2o`0008cooooo0_l00006ooooo`;o0000
8_ooool2o`0000kooooo0_l0001Tooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o0000MOoo
ool2o`0002;ooooo0_l00006ooooo`;o00001oooool2o`0001Wooooo0_l0000:ooooo`;o0000Cooo
ool2o`0001Oooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0000;ooooo`;o0000Koooool2
o`0003?ooooo0_l0000Qooooo`;o00000_ooool2o`0004oooooo0_l0000Gooooo`007_ooool00ol0
003oooooooooo`03ooooo`;o00002oooool2o`00083ooooo0ol0000Kooooo`;o00009oooool2o`00
02Kooooo0_l00014ooooo`007_ooool00ol0003oooooooooo`03ooooo`;o0000C_ooool2o`0000[o
oooo0_l0000aooooo`?o00006oooool2o`0000cooooo0_l0000:ooooo`;o00008oooool2o`00013o
oooo0_l00014ooooo`007_ooool00ol0003oooooooooo`1Cooooo`;o00002_ooool3o`0005cooooo
0_l0000:ooooo`;o00008oooool2o`000003ooooool0003o000000_ooooo0_l0000`ooooo`;o0000
2_ooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo053ooooo0ol0000=ooooo`;o0000E_oo
ool2o`0003Sooooo0_l0000;ooooo`;o00006?ooool2o`0001Kooooo0_l0000:ooooo`;o00002?oo
ool001kooooo00?o0000ooooooooool0@Oooool2o`0000gooooo0ol0001Uooooo`;o0000Goooool2
o`0001Wooooo0_l0000Aooooo`007_ooool00ol0003oooooooooo`0iooooo`;o00001_ooool2o`00
053ooooo0_l0000booooo`;o0000>Oooool2o`00033ooooo0_l00005ooooo`;o00002_ooool001ko
oooo00?o0000ooooooooool0>Oooool2o`0002_ooooo0_l0000[ooooo`;o00008?ooool2o`00013o
oooo0_l0000iooooo`;o0000=oooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00kooooo
0_l0000^ooooo`;o00009_ooool2o`0000oooooo0_l0000Nooooo`;o00007?ooool2o`00093ooooo
000Nooooo`03o`000?oooooooooo00kooooo0_l0000^ooooo`;o0000=oooool2o`0001kooooo0_l0
000Rooooo`;o0000Moooool2o`00017ooooo000Nooooo`03o`000?oooooooooo05[ooooo0_l0000l
ooooo`;o00002?ooool2o`0001Oooooo0_l0000iooooo`;o00002Oooool2o`0000Cooooo0_l0000[
ooooo`;o00004Oooool001kooooo00?o0000ooooooooool08oooool2o`0003Gooooo0_l0000Ioooo
o`;o00008Oooool2o`0000Sooooo0_l00014ooooo`;o00003?ooool2o`0000Wooooo0_l00004oooo
o`;o0000=_ooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo02?ooooo0_l0001@ooooo`;o
00004?ooool2o`0004Gooooo0_l0000Hooooo`;o0000EOooool2o`0000Kooooo000Nooooo`;o0000
4Oooool2o`0005Gooooo0_l0000Mooooo`?o0000AOooool2o`0002Sooooo0_l0000aooooo`;o0000
6_ooool001kooooo00?o0000ooooooooool04?ooool2o`0000[ooooo0_l00019ooooo`;o00002Ooo
ool2o`0001;ooooo0_l0000Looooo`;o00000_ooool2o`0004Gooooo0_l00007ooooo`;o0000<Ooo
ool2o`0001[ooooo000Nooooo`03o`000?oooooooooo01cooooo0_l0000Eooooo`;o00001oooool2
o`00023ooooo0_l0000Booooo`;o00005oooool2o`0001Oooooo0ol000000ooooooo0000o`000015
ooooo`;o0000E_ooool001kooooo00?o0000ooooooooool09_ooool2o`0000_ooooo0_l00007oooo
o`;o00005?ooool2o`0000[ooooo0_l00009ooooo`;o00008?ooool2o`0001Sooooo0_l0000:oooo
o`;o0000U?ooool001kooooo00?o0000ooooooooool09_ooool2o`0002[ooooo0_l0000Eooooo`;o
0000:_ooool2o`0001[ooooo0_l0001@ooooo`;o0000@_ooool001kooooo00?o0000ooooooooool0
UOooool2o`0000cooooo0_l0001@ooooo`;o00003?ooool2o`0001[ooooo0_l0000Vooooo`007_oo
ool2o`000:Cooooo0_l0001@ooooo`;o0000:?ooool2o`0002Kooooo000Nooooo`;o0000Xoooool3
o`0002Oooooo0_l0001iooooo`007_ooool00ol0003oooooooooo`2Nooooo`;o00000_ooool2o`00
02Sooooo0_l0000Sooooo`;o0000:?ooool2o`0000kooooo0_l0000Jooooo`007_ooool00ol0003o
ooooooooo`1hooooo`;o00001?ooool2o`0001kooooo0_l00006ooooo`;o0000<_ooool2o`0001Go
oooo0_l0000Xooooo`;o00003_ooool2o`0001[ooooo000Nooooo`03o`000?oooooooooo073ooooo
0_l00006ooooo`;o00001?ooool2o`0002Kooooo0_l0000booooo`;o0000Joooool001kooooo00?o
0000ooooooooool0Foooool2o`0001?ooooo0_l0003Eooooo`007_ooool00ol0003oooooooooo`0j
ooooo`;o00002Oooool2o`0001Cooooo0_l0002Xooooo`;o00004Oooool2o`0002gooooo000Noooo
o`03o`000?oooooooooo03[ooooo0_l00009ooooo`;o00004?ooool2o`0005gooooo0_l000000ooo
oooo0000o`000013ooooo`;o00001Oooool2o`00017ooooo0_l0000]ooooo`007_ooool00ol0003o
ooooooooo`1Gooooo`;o0000Boooool2o`00013ooooo0_l000000ooooooo0000o`00000_ooooo`;o
00004_ooool2o`0004Oooooo000Nooooo`03o`000?oooooooooo047ooooo0_l0001Qooooo`;o0000
A?ooool2o`0005_ooooo000Nooooo`;o00003oooool2o`0002_ooooo0_l00004ooooo`;o0000Gooo
ool2o`0000?ooooo0_l0002Nooooo`007_ooool00ol0003oooooooooo`0=ooooo`?o00005_ooool2
o`0001?ooooo0_l0001Uooooo`;o00000oooool2o`0007?ooooo0_l0000Yooooo`007_ooool00ol0
003oooooooooo`0=ooooo`;o00005oooool2o`000?Cooooo0_l0000Booooo`;o00005Oooool001ko
oooo00?o0000ooooooooool0[Oooool2o`0004Sooooo0_l0000Mooooo`;o00006?ooool2o`0001Go
oooo000Nooooo`03o`000?oooooooooo05Wooooo0_l0001Aooooo`?o0000B?ooool2o`0001gooooo
0_l0000_ooooo`007_ooool00ol0003oooooooooo`1Iooooo`;o0000DOooool2o`0009Wooooo000N
ooooo`03o`000?oooooooooo00Oooooo0_l0003ooooooagooooo0_l0000Pooooo`007_ooool00ol0
003oooooooooo`07ooooo`;o0000SOooool2o`00027ooooo0_l0000Zooooo`;o00003oooool2o`00
02gooooo0_l0000Pooooo`007_ooool00ol0003oooooooooo`0fooooo`;o0000G_ooool2o`00027o
oooo0_l0000Zooooo`;o00003oooool2o`0004oooooo000Nooooo`03o`000?oooooooooo037ooooo
0_l00003ooooo`;o0000boooool2o`0000_ooooo0_l00006ooooo`;o00001oooool2o`0002Cooooo
000Nooooo`04o`000?oooooo0000o`0000Cooooo0_l00008ooooo`;o00008?ooool2o`0001Gooooo
0_l0000booooo`;o0000M?ooool2o`0000oooooo0_l0000;ooooo`;o00001_ooool2o`0000Oooooo
0_l0000Tooooo`007_ooool01?l0003oooooo`000?l00004ooooo`;o00002?ooool2o`0003Oooooo
0_l0000booooo`;o0000M?ooool2o`0000;ooooo0_l00019ooooo`;o00001?ooool001kooooo00?o
0000ooooooooool04Oooool2o`0000oooooo0_l0003Booooo`;o0000BOooool2o`0000Cooooo000N
ooooo`03o`000?oooooooooo00;o00003oooool2o`0000oooooo0_l00008ooooo`;o0000<Oooool2
o`000;Oooooo0_l0000]ooooo`005?ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooo
ooooool00_l0000Zooooo`;o0000<Oooool2o`0007Gooooo0_l00010ooooo`;o0000;Oooool001Ko
oooo00?o0000ooooooooool01Oooool01?l0003oooooooooooooool2o`0002Cooooo0_l00013oooo
o`;o0000J?ooool2o`0006oooooo000Fooooo`03o`000?oooooooooo00Gooooo0ol000000ooooooo
0000o`00000Tooooo`;o0000@oooool2o`0001[ooooo0_l000000ooooooo0000o`00001>ooooo`;o
0000J_ooool001Kooooo00?o0000ooooooooool0;oooool2o`0005oooooo0_l000000ooooooo0000
o`00001>ooooo`;o0000J_ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool0
0ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Co
oooo00?oEEEEofIVI_l00000oooooomBooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.85478 .87221 Mdot
.72753 .1853 Mdot
.45531 .30617 Mdot
.78758 .1785 Mdot
.33138 .75757 Mdot
.25652 .89619 Mdot
.83154 .72899 Mdot
.04972 .26962 Mdot
.56929 .66062 Mdot
.64854 .99819 Mdot
.53066 .69382 Mdot
.59323 .83439 Mdot
.89645 .00461 Mdot
.82233 .74126 Mdot
.181 .49019 Mdot
.87286 .33843 Mdot
.70778 .01744 Mdot
.76369 .201 Mdot
.23755 .06079 Mdot
.3561 .21644 Mdot
.30747 .53483 Mdot
.83052 .13742 Mdot
.59683 .56932 Mdot
.90377 .1021 Mdot
.09515 .69252 Mdot
.7063 .68938 Mdot
.89531 .3785 Mdot
.8078 .44755 Mdot
.02156 .11442 Mdot
.2295 .57089 Mdot
.10568 .47862 Mdot
.65739 .61383 Mdot
.77649 .62348 Mdot
.06201 .21653 Mdot
.03384 .84093 Mdot
.4178 .9155 Mdot
.81559 .55288 Mdot
.36174 .00716 Mdot
.94391 .88252 Mdot
.32931 .74739 Mdot
.76127 .92708 Mdot
.19209 .46729 Mdot
.47912 .7804 Mdot
.39068 .95521 Mdot
.36742 .88534 Mdot
.37782 .63373 Mdot
.56687 .7699 Mdot
.21634 .44605 Mdot
.73376 .59907 Mdot
.56408 .5749 Mdot
.45436 .4442 Mdot
.07341 .69191 Mdot
.98421 .30568 Mdot
.11891 .38503 Mdot
.35739 .75603 Mdot
.55786 .65863 Mdot
.96072 .05511 Mdot
.35048 .88813 Mdot
.49396 .30762 Mdot
.32529 .17013 Mdot
.94618 .07145 Mdot
.43032 .90843 Mdot
.23201 .69484 Mdot
.06709 .0238 Mdot
.44412 .29366 Mdot
.17578 .91768 Mdot
.79686 .20591 Mdot
.51643 .44968 Mdot
.79455 .57181 Mdot
.95519 .29782 Mdot
.11195 .98473 Mdot
.48684 .88933 Mdot
.07732 .30917 Mdot
.83988 .39781 Mdot
.83329 .72636 Mdot
.43953 .09289 Mdot
.50414 .13639 Mdot
.42755 .95152 Mdot
.93576 .12472 Mdot
.05028 .70604 Mdot
.39875 .36586 Mdot
.92006 .64637 Mdot
.23275 .60143 Mdot
.2241 .37197 Mdot
.24662 .17804 Mdot
.23398 .42851 Mdot
.19307 .64468 Mdot
.49643 .03014 Mdot
.45164 .64034 Mdot
.29219 .84604 Mdot
.3133 .64148 Mdot
.02373 .91229 Mdot
.02139 .30972 Mdot
.33859 .49038 Mdot
.6483 .84914 Mdot
.98095 .28231 Mdot
.61344 .47928 Mdot
.61311 .08132 Mdot
.64513 .62489 Mdot
.64935 .81709 Mdot
.27545 .70346 Mdot
.69206 .7305 Mdot
.81068 .10393 Mdot
.46268 .60893 Mdot
.04288 .26332 Mdot
.25792 .27691 Mdot
.14523 .63008 Mdot
.54666 .82577 Mdot
.24178 .42565 Mdot
.78685 .96494 Mdot
.76557 .92497 Mdot
.34162 .35785 Mdot
.25069 .12117 Mdot
.48525 .38349 Mdot
.7714 .73564 Mdot
.94282 .78633 Mdot
.94605 .61797 Mdot
.82144 .69657 Mdot
.02043 .2555 Mdot
.36472 .78086 Mdot
.64855 .95515 Mdot
.53009 .58417 Mdot
.97104 .09941 Mdot
.34466 .3336 Mdot
.57891 .80592 Mdot
.62947 .21275 Mdot
.20006 .06876 Mdot
.99703 .1398 Mdot
.08644 .67737 Mdot
.88444 .68725 Mdot
.17955 .68626 Mdot
.81175 .85333 Mdot
.97001 .91707 Mdot
.05767 .09367 Mdot
.77094 .95334 Mdot
.03565 .85209 Mdot
.33793 .76837 Mdot
.03673 .5846 Mdot
.35695 .49637 Mdot
.40596 .54842 Mdot
.05854 .63327 Mdot
.29151 .60402 Mdot
.70114 .17232 Mdot
.78799 .93041 Mdot
.94969 .50434 Mdot
.45184 .57177 Mdot
.04837 .8142 Mdot
.56603 .04158 Mdot
.50802 .1811 Mdot
.2742 .23732 Mdot
.18876 .34394 Mdot
.05938 .04398 Mdot
.38374 .80899 Mdot
.6887 .08756 Mdot
.44783 .33756 Mdot
.10109 .38708 Mdot
.61324 .76599 Mdot
.55689 .88491 Mdot
.77358 .25658 Mdot
.99506 .74015 Mdot
.14497 .84677 Mdot
.49607 .613 Mdot
.03732 .48598 Mdot
.79568 .53358 Mdot
.88751 .80045 Mdot
.93666 .52798 Mdot
.31779 .49223 Mdot
.02808 .97301 Mdot
.90008 .57359 Mdot
.85313 .32509 Mdot
.8054 .42131 Mdot
.97134 .85998 Mdot
.49615 .36269 Mdot
.12147 .97482 Mdot
.15332 .74636 Mdot
.10064 .73265 Mdot
.3956 .16587 Mdot
.97052 .01738 Mdot
.70703 .51337 Mdot
.71949 .82904 Mdot
.13422 .02887 Mdot
.91449 .7434 Mdot
.50448 .24164 Mdot
.19776 .66903 Mdot
.84654 .02758 Mdot
.3716 .86737 Mdot
.55174 .16959 Mdot
.98246 .82922 Mdot
.29833 .19476 Mdot
.80992 .11168 Mdot
.38879 .34511 Mdot
.888 .05005 Mdot
.05301 .51329 Mdot
.49913 .57363 Mdot
.63991 .15542 Mdot
.55937 .67018 Mdot
.13595 .26378 Mdot
.34981 .94197 Mdot
.35395 .88515 Mdot
.6674 .79967 Mdot
.01912 .97181 Mdot
.7257 .95503 Mdot
.46671 .87662 Mdot
.06682 .08853 Mdot
.59084 .9835 Mdot
.44073 .80783 Mdot
.80886 .08629 Mdot
.12966 .86395 Mdot
.00713 .63696 Mdot
.41695 .98683 Mdot
.53274 .51879 Mdot
.94121 .33299 Mdot
.52088 .60647 Mdot
.3104 .48204 Mdot
.99501 .04081 Mdot
.97526 .51877 Mdot
.50677 .79233 Mdot
.79324 .08914 Mdot
.55428 .97981 Mdot
.53846 .96713 Mdot
.86651 .15789 Mdot
.00751 .70665 Mdot
.14065 .49262 Mdot
.34112 .49372 Mdot
.83543 .05892 Mdot
.81714 .79475 Mdot
.08398 .80128 Mdot
.07692 .38371 Mdot
.73753 .0306 Mdot
.98576 .05548 Mdot
.94988 .27752 Mdot
.47909 .47945 Mdot
.13079 .41877 Mdot
.4155 .47907 Mdot
.8008 .13301 Mdot
.34606 .31286 Mdot
.7106 .29754 Mdot
.30807 .27677 Mdot
.86419 .3838 Mdot
.52824 .0998 Mdot
.9223 .96411 Mdot
.43783 .80866 Mdot
.80643 .86356 Mdot
.11519 .62525 Mdot
.80041 .10503 Mdot
.38746 .21246 Mdot
.73042 .1938 Mdot
.29656 .24878 Mdot
.32611 .16308 Mdot
.26427 .6931 Mdot
.50422 .05767 Mdot
.74332 .38528 Mdot
.49085 .82104 Mdot
.65473 .76833 Mdot
.87393 .20796 Mdot
.777 .9262 Mdot
.31579 .40872 Mdot
.05801 .34163 Mdot
.13636 .05214 Mdot
.50146 .48971 Mdot
.22787 .98509 Mdot
.6289 .6412 Mdot
.97471 .80812 Mdot
.67223 .06971 Mdot
.30243 .10624 Mdot
.32658 .62943 Mdot
.57659 .54275 Mdot
.46276 .87227 Mdot
.56717 .49599 Mdot
.36909 .59215 Mdot
.33677 .26022 Mdot
.73071 .80002 Mdot
.97525 .49184 Mdot
.06446 .41684 Mdot
.33624 .86526 Mdot
.32573 .23825 Mdot
.83733 .91339 Mdot
.22365 .30096 Mdot
.469 .0222 Mdot
.1028 .47448 Mdot
.8287 .86143 Mdot
.41198 .00375 Mdot
.5881 .21171 Mdot
.92853 .46051 Mdot
.4987 .69317 Mdot
.06951 .2075 Mdot
.55521 .93765 Mdot
.61106 .80581 Mdot
.62811 .20304 Mdot
.17316 .57032 Mdot
.92726 .41652 Mdot
.41657 .0983 Mdot
.92248 .36682 Mdot
.52951 .85517 Mdot
.41601 .23755 Mdot
.89258 .50449 Mdot
.6589 .52778 Mdot
.62735 .52284 Mdot
.09532 .30285 Mdot
.35556 .545 Mdot
.8055 .82036 Mdot
.08538 .13525 Mdot
.73337 .65938 Mdot
.99051 .19065 Mdot
.52773 .40463 Mdot
.03332 .23185 Mdot
.06777 .22996 Mdot
.35529 .53065 Mdot
.6247 .58906 Mdot
.70044 .19301 Mdot
.42827 .45511 Mdot
.14571 .45 Mdot
.95779 .59317 Mdot
.90399 .25004 Mdot
.28855 .14343 Mdot
.13326 .21563 Mdot
.03393 .60904 Mdot
.37824 .22603 Mdot
.48367 .65585 Mdot
.1194 .38055 Mdot
.17151 .78222 Mdot
.23088 .48567 Mdot
.94546 .33773 Mdot
.3374 .80107 Mdot
.05299 .7777 Mdot
.27252 .73395 Mdot
.58169 .77673 Mdot
.90301 .24379 Mdot
.92721 .86896 Mdot
.28115 .29196 Mdot
.24823 .65053 Mdot
.48772 .71409 Mdot
.31488 .58599 Mdot
.91567 .37669 Mdot
.23781 .99409 Mdot
.82319 .38541 Mdot
.10728 .02293 Mdot
.68484 .85632 Mdot
.33909 .60438 Mdot
.58876 .51722 Mdot
.49177 .42587 Mdot
.06776 .36003 Mdot
.16328 .99686 Mdot
.97304 .99318 Mdot
.01586 .66314 Mdot
.69721 .49102 Mdot
.76602 .37526 Mdot
.238 .15512 Mdot
.8221 .09506 Mdot
.2456 .47995 Mdot
.36021 .91214 Mdot
.90292 .94934 Mdot
.87928 .71249 Mdot
.47597 .32936 Mdot
.85297 .44483 Mdot
.7885 .55603 Mdot
.51686 .92221 Mdot
.85837 .30672 Mdot
.51586 .77064 Mdot
.03101 .92761 Mdot
.90771 .29536 Mdot
.36392 .60601 Mdot
.50399 .82028 Mdot
.77497 .35515 Mdot
.78352 .2873 Mdot
.0885 .99417 Mdot
.00102 .72233 Mdot
.38951 .07118 Mdot
.36655 .38466 Mdot
.78175 .96835 Mdot
.72105 .79846 Mdot
.10705 .36658 Mdot
.98647 .14692 Mdot
.35681 .06205 Mdot
.2573 .60561 Mdot
.82533 .34297 Mdot
.18321 .50717 Mdot
.584 .81917 Mdot
.27108 .10935 Mdot
.41416 .29071 Mdot
.56421 .5391 Mdot
.45155 .07925 Mdot
.60531 .86343 Mdot
.65854 .82715 Mdot
.94231 .73673 Mdot
.98543 .06991 Mdot
.44062 .84227 Mdot
.99019 .87607 Mdot
.47852 .42989 Mdot
.58268 .92125 Mdot
.91918 .50063 Mdot
.07999 .75782 Mdot
.11441 .70937 Mdot
.82445 .33842 Mdot
.5396 .88412 Mdot
.05702 .21038 Mdot
.46753 .28786 Mdot
.18063 .40224 Mdot
.69691 .4478 Mdot
.06364 .6892 Mdot
.50451 .11505 Mdot
.3716 .60614 Mdot
.80085 .95588 Mdot
.20027 .64402 Mdot
.34647 .32884 Mdot
.18043 .39835 Mdot
.13488 .26853 Mdot
.44227 .01697 Mdot
.35914 .06801 Mdot
.52512 .66243 Mdot
.41344 .46537 Mdot
.35699 .30938 Mdot
.6814 .10336 Mdot
.01405 .89416 Mdot
.21264 .89925 Mdot
.06509 .14568 Mdot
.90809 .92638 Mdot
.53848 .9447 Mdot
.18717 .37091 Mdot
.28937 .87488 Mdot
.47673 .41779 Mdot
.04299 .28021 Mdot
.32248 .1823 Mdot
.27259 .84502 Mdot
.33379 .00658 Mdot
.05953 .13217 Mdot
.20015 .82619 Mdot
.13266 .35842 Mdot
.36374 .02647 Mdot
.80228 .59735 Mdot
.50328 .47607 Mdot
.6288 .61892 Mdot
.87616 .28579 Mdot
.02189 .44552 Mdot
.5578 .86253 Mdot
.40961 .54303 Mdot
.01006 .19891 Mdot
.14808 .14867 Mdot
.04907 .16969 Mdot
.18455 .08083 Mdot
.69984 .21264 Mdot
.6641 .60709 Mdot
.41554 .86009 Mdot
.84738 .9554 Mdot
.44478 .70721 Mdot
.05303 .64761 Mdot
.97998 .64415 Mdot
.85022 .90954 Mdot
.91322 .35027 Mdot
.25623 .49176 Mdot
.0107 .9386 Mdot
.26088 .37605 Mdot
.61318 .89628 Mdot
.24988 .96556 Mdot
.29979 .86467 Mdot
.29835 .71133 Mdot
.702 .12638 Mdot
.1228 .41673 Mdot
.46692 .68439 Mdot
.50136 .77408 Mdot
.79958 .27361 Mdot
.26563 .39815 Mdot
.41989 .06473 Mdot
.28331 .81467 Mdot
.07426 .31545 Mdot
.86007 .6697 Mdot
.0313 .21354 Mdot
.43449 .68112 Mdot
.06471 .76308 Mdot
.98676 .54474 Mdot
.4572 .1547 Mdot
.28732 .51951 Mdot
.93734 .2646 Mdot
.10781 .51276 Mdot
.14649 .05419 Mdot
.05031 .55899 Mdot
.20216 .99455 Mdot
.00068 .68636 Mdot
.42007 .54527 Mdot
.89838 .82915 Mdot
.23771 .56076 Mdot
.42783 .43583 Mdot
.03973 .52604 Mdot
.00819 .09812 Mdot
.91611 .56328 Mdot
.09883 .7589 Mdot
.91096 .23908 Mdot
.32787 .10163 Mdot
.90727 .50179 Mdot
.2 .1458 Mdot
.54786 .67603 Mdot
.12415 .62994 Mdot
.11308 .20012 Mdot
.9179 .04139 Mdot
.50156 .72425 Mdot
.82898 .12636 Mdot
.35011 .51535 Mdot
.42333 .5449 Mdot
.4091 .87582 Mdot
.39447 .23075 Mdot
.73991 .77269 Mdot
.49776 .8958 Mdot
.45047 .09602 Mdot
.12601 .41201 Mdot
.41604 .84918 Mdot
.47775 .7281 Mdot
.73614 .26029 Mdot
.92737 .46927 Mdot
.39175 .98803 Mdot
.098 .02561 Mdot
.25002 .30763 Mdot
.50485 .94428 Mdot
.35761 .37601 Mdot
.28543 .75838 Mdot
.16175 .53171 Mdot
.92869 .07604 Mdot
.89248 .54913 Mdot
.3932 .56708 Mdot
.10221 .99551 Mdot
.69158 .01819 Mdot
.3234 .72111 Mdot
.93128 .72293 Mdot
.36126 .6143 Mdot
.12918 .96288 Mdot
.81474 .45766 Mdot
.11842 .41945 Mdot
.97301 .04298 Mdot
.03675 .57945 Mdot
.19467 .34613 Mdot
.34235 .75211 Mdot
.4068 .6779 Mdot
.85622 .84943 Mdot
.86792 .74471 Mdot
.12919 .76856 Mdot
.68162 .33881 Mdot
.66421 .53102 Mdot
.00663 .12864 Mdot
.76267 .83596 Mdot
.83436 .90547 Mdot
.69465 .7454 Mdot
.61365 .39566 Mdot
.88425 .774 Mdot
.56745 .86911 Mdot
.37291 .11485 Mdot
.5295 .07503 Mdot
.05614 .59466 Mdot
.43624 .90622 Mdot
.60138 .24719 Mdot
.79876 .98539 Mdot
.65373 .06861 Mdot
.74102 .85727 Mdot
.26818 .08422 Mdot
.77956 .39817 Mdot
.10732 .15381 Mdot
.456 .71603 Mdot
.06141 .8133 Mdot
.78933 .39465 Mdot
.74722 .49697 Mdot
.13896 .83034 Mdot
.40258 .52326 Mdot
.70131 .9836 Mdot
.42407 .1462 Mdot
.69833 .26392 Mdot
.19581 .92542 Mdot
.17803 .15703 Mdot
.8133 .59412 Mdot
.35755 .68984 Mdot
.55533 .5825 Mdot
.80867 .09602 Mdot
.71202 .24963 Mdot
.33939 .04069 Mdot
.61443 .09946 Mdot
.66455 .33207 Mdot
.87968 .96417 Mdot
.81862 .78841 Mdot
.98285 .87456 Mdot
.96494 .89615 Mdot
.68783 .16675 Mdot
.60545 .43046 Mdot
.99172 .33337 Mdot
.60137 .0487 Mdot
.52543 .8499 Mdot
.44778 .77729 Mdot
.53373 .08323 Mdot
.46096 .84888 Mdot
.01175 .28359 Mdot
.54378 .71951 Mdot
.20371 .20785 Mdot
.41057 .14087 Mdot
.09741 .25715 Mdot
.10319 .571 Mdot
.90264 .63736 Mdot
.14332 .65011 Mdot
.67968 .52885 Mdot
.03206 .52552 Mdot
.97306 .78768 Mdot
.40249 .62793 Mdot
.33137 .64279 Mdot
.58117 .06084 Mdot
.22876 .32324 Mdot
.29513 .70466 Mdot
.95254 .85438 Mdot
.08082 .99821 Mdot
.15287 .02947 Mdot
.80804 .55164 Mdot
.30963 .22186 Mdot
.79667 .08324 Mdot
.15701 .66144 Mdot
.08473 .27362 Mdot
.11768 .33115 Mdot
.56321 .33694 Mdot
.60324 .72456 Mdot
.25441 .2666 Mdot
.45389 .13057 Mdot
.03798 .04472 Mdot
.56687 .9285 Mdot
.62529 .39044 Mdot
.07845 .35067 Mdot
.88479 .56512 Mdot
.20806 .87412 Mdot
.03281 .4108 Mdot
.90497 .72362 Mdot
.32206 .46021 Mdot
.56184 .66795 Mdot
.02934 .96419 Mdot
.84862 .6605 Mdot
.88099 .57721 Mdot
.54572 .98379 Mdot
.12369 .95572 Mdot
.29241 .25441 Mdot
.23483 .66273 Mdot
.29838 .49041 Mdot
.44354 .04956 Mdot
.13969 .0386 Mdot
.98656 .82075 Mdot
.51267 .04088 Mdot
.56055 .11006 Mdot
.86731 .59726 Mdot
.84584 .41327 Mdot
.32796 .87921 Mdot
.59952 .14474 Mdot
.95572 .1829 Mdot
.42768 .20914 Mdot
.60269 .88118 Mdot
.18848 .41458 Mdot
.78636 .97636 Mdot
.08967 .33811 Mdot
.97961 .52761 Mdot
.16408 .3816 Mdot
.39137 .14412 Mdot
.63144 .14018 Mdot
.84636 .16778 Mdot
.77832 .11975 Mdot
.16296 .89074 Mdot
.45663 .68639 Mdot
.14088 .1018 Mdot
.54526 .62606 Mdot
.2416 .98783 Mdot
.22493 .07187 Mdot
.57014 .71425 Mdot
.60093 .0034 Mdot
.17461 .70457 Mdot
.29101 .08144 Mdot
.22152 .2111 Mdot
.34434 .05264 Mdot
.25726 .7571 Mdot
.75344 .51019 Mdot
.96899 .26446 Mdot
.56413 .70686 Mdot
.81588 .52733 Mdot
.14673 .70004 Mdot
.20887 .92012 Mdot
.37036 .70794 Mdot
.15552 .9791 Mdot
.01534 .79069 Mdot
.6372 .81331 Mdot
.89706 .04968 Mdot
.60928 .45578 Mdot
.87975 .3981 Mdot
.52914 .8684 Mdot
.44899 .50128 Mdot
.77162 .7937 Mdot
.52375 .93016 Mdot
.43042 .00886 Mdot
.05827 .52297 Mdot
.49195 .77325 Mdot
.20379 .43366 Mdot
.61631 .68514 Mdot
.12061 .64533 Mdot
.16398 .5517 Mdot
.46948 .98709 Mdot
.54673 .87947 Mdot
.84788 .18104 Mdot
.09345 .28839 Mdot
.1671 .09809 Mdot
.31355 .46453 Mdot
.36271 .86311 Mdot
.70696 .88749 Mdot
.97904 .57234 Mdot
.74772 .94557 Mdot
.10305 .88755 Mdot
.90635 .2959 Mdot
.75901 .01174 Mdot
.87498 .25289 Mdot
.71926 .57862 Mdot
.1295 .14107 Mdot
.34417 .24144 Mdot
.88666 .82343 Mdot
.27152 .19218 Mdot
.99055 .6758 Mdot
.09937 .66573 Mdot
.03097 .95731 Mdot
.28109 .74517 Mdot
.5825 .94479 Mdot
.66274 .86141 Mdot
.69392 .39486 Mdot
.83742 .54166 Mdot
.3137 .53548 Mdot
.52753 .01519 Mdot
.65269 .97117 Mdot
.06901 .15212 Mdot
.89419 .03108 Mdot
.83238 .5615 Mdot
.65467 .83735 Mdot
.43095 .74186 Mdot
.95008 .86483 Mdot
.33222 .0488 Mdot
.31025 .64948 Mdot
.31486 .47156 Mdot
.77488 .89718 Mdot
.13396 .6464 Mdot
.30519 .15269 Mdot
.97276 .39319 Mdot
.24194 .46514 Mdot
.41716 .96553 Mdot
.92683 .77052 Mdot
.98272 .54594 Mdot
.80723 .5868 Mdot
.45814 .23345 Mdot
.32336 .17909 Mdot
.97812 .58362 Mdot
.34001 .06346 Mdot
.16449 .09013 Mdot
.08376 .67923 Mdot
.80767 .58397 Mdot
.5749 .56826 Mdot
.52691 .76442 Mdot
.99166 .69431 Mdot
.19034 .54878 Mdot
.99774 .85653 Mdot
.05158 .10765 Mdot
.9221 .40154 Mdot
.97804 .31915 Mdot
.47642 .46578 Mdot
.03206 .97688 Mdot
.04287 .57355 Mdot
.83858 .07977 Mdot
.61567 .74622 Mdot
.56092 .45249 Mdot
.7939 .40124 Mdot
.0595 .10182 Mdot
.75423 .26297 Mdot
.31432 .84036 Mdot
.13593 .82524 Mdot
.67123 .76275 Mdot
.55223 .70805 Mdot
.49996 .63143 Mdot
.28916 .26288 Mdot
.8981 .73458 Mdot
.98386 .38597 Mdot
.12334 .04503 Mdot
.18698 .16552 Mdot
.19563 .02683 Mdot
.59529 .58186 Mdot
.71642 .0564 Mdot
.40173 .94147 Mdot
.13121 .44843 Mdot
.03776 .22863 Mdot
.77848 .81465 Mdot
.60142 .66074 Mdot
.68423 .33717 Mdot
.96944 .98644 Mdot
.67549 .15555 Mdot
.11093 .10658 Mdot
.35333 .74318 Mdot
.59005 .24285 Mdot
.36994 .54428 Mdot
.09697 .46253 Mdot
.06084 .07961 Mdot
.71562 .70545 Mdot
.35843 .59012 Mdot
.23152 .92866 Mdot
.63149 .03618 Mdot
.91477 .58324 Mdot
.11843 .30467 Mdot
.06858 .90738 Mdot
.59987 .32943 Mdot
.73387 .28585 Mdot
.2739 .72928 Mdot
.47014 .95519 Mdot
.13553 .68586 Mdot
.02728 .55118 Mdot
.47398 .39897 Mdot
.5386 .48126 Mdot
.66242 .10113 Mdot
.84216 .05135 Mdot
.39279 .57186 Mdot
.81064 .35592 Mdot
.51071 .40508 Mdot
.96901 .75605 Mdot
.44808 .44065 Mdot
.26973 .88358 Mdot
.49501 .91477 Mdot
.37802 .73557 Mdot
.97606 .37489 Mdot
.72961 .94602 Mdot
.39564 .59485 Mdot
.07646 .25758 Mdot
.86119 .78878 Mdot
.63867 .06086 Mdot
.18151 .67486 Mdot
.55703 .19111 Mdot
.04914 .3415 Mdot
.00571 .0098 Mdot
.089 .5933 Mdot
.19364 .10686 Mdot
.45695 .92374 Mdot
.81116 .28992 Mdot
.77902 .29184 Mdot
.45131 .85011 Mdot
.11626 .17903 Mdot
.04537 .97564 Mdot
.82322 .45474 Mdot
.4271 .10516 Mdot
.02443 .20339 Mdot
.54815 .89838 Mdot
.59138 .0063 Mdot
.13769 .7246 Mdot
.36194 .13873 Mdot
.45996 .5966 Mdot
.20889 .63417 Mdot
.87342 .4988 Mdot
.48008 .60217 Mdot
.11318 .77977 Mdot
.52406 .88024 Mdot
.52673 .95455 Mdot
.76914 .35274 Mdot
.96796 .90641 Mdot
.43469 .76192 Mdot
.2091 .96179 Mdot
.24715 .34032 Mdot
.83232 .7256 Mdot
.02988 .64897 Mdot
.63181 .93798 Mdot
.8118 .13541 Mdot
.80648 .8585 Mdot
.05511 .39291 Mdot
.51796 .12801 Mdot
.10068 .8723 Mdot
.29443 .57766 Mdot
.03731 .38934 Mdot
.35566 .28632 Mdot
.56138 .12755 Mdot
.73566 .93991 Mdot
.78019 .25519 Mdot
.85002 .22203 Mdot
.13853 .76514 Mdot
.09977 .01823 Mdot
.82959 .62129 Mdot
.87102 .04934 Mdot
.53656 .54442 Mdot
.40347 .70169 Mdot
.65122 .06115 Mdot
.20185 .14704 Mdot
.97855 .02647 Mdot
.2914 .89571 Mdot
.61723 .68837 Mdot
.4181 .03733 Mdot
.59585 .5574 Mdot
.29705 .81407 Mdot
.44817 .13835 Mdot
.28869 .89856 Mdot
.66501 .85281 Mdot
.1585 .4537 Mdot
.18355 .59818 Mdot
.19543 .13678 Mdot
.06363 .77616 Mdot
.84922 .93869 Mdot
.41459 .40127 Mdot
.74011 .2819 Mdot
.00727 .68392 Mdot
.10643 .37488 Mdot
.35804 .23293 Mdot
.11218 .57586 Mdot
.76626 .6688 Mdot
.49781 .37283 Mdot
.44268 .76535 Mdot
.73218 .03176 Mdot
.59885 .627 Mdot
.56554 .85725 Mdot
.45187 .46644 Mdot
.00381 .83163 Mdot
.32795 .13106 Mdot
.72892 .28395 Mdot
.22466 .67959 Mdot
.8803 .47351 Mdot
.52041 .20072 Mdot
.83338 .32311 Mdot
.91922 .84082 Mdot
.52718 .02692 Mdot
.05246 .32559 Mdot
.84947 .42478 Mdot
.82102 .62976 Mdot
.08889 .97682 Mdot
.17748 .81915 Mdot
.24237 .86307 Mdot
.21839 .86717 Mdot
.69918 .2928 Mdot
.02576 .45358 Mdot
.46056 .16501 Mdot
.26522 .99423 Mdot
.03 .86695 Mdot
.992 .69369 Mdot
.46317 .16482 Mdot
.3893 .10071 Mdot
.17071 .37517 Mdot
.13573 .08017 Mdot
.14171 .80488 Mdot
.21933 .42716 Mdot
.26276 .36037 Mdot
.95727 .69937 Mdot
.15263 .34642 Mdot
.00168 .72875 Mdot
.75721 .63404 Mdot
.84243 .08787 Mdot
.70028 .09911 Mdot
.59521 .14699 Mdot
.19065 .81959 Mdot
.105 .78317 Mdot
.2105 .91179 Mdot
.23799 .72965 Mdot
.77761 .43541 Mdot
.0776 .68629 Mdot
.91908 .37378 Mdot
.89897 .21445 Mdot
.80941 .48112 Mdot
.93555 .06091 Mdot
.41983 .21874 Mdot
.47041 .08161 Mdot
.11697 .58188 Mdot
.16636 .41099 Mdot
.82366 .43474 Mdot
.26492 .86059 Mdot
.4453 .66045 Mdot
.00268 .04852 Mdot
.28935 .62538 Mdot
.91043 .99572 Mdot
.71971 .84341 Mdot
.86676 .6716 Mdot
.2068 .78036 Mdot
.12329 .80896 Mdot
.98786 .03819 Mdot
.68521 .7701 Mdot
.05356 .834 Mdot
.52514 .75067 Mdot
.89921 .32499 Mdot
.80985 .8836 Mdot
.22884 .75784 Mdot
.06262 .71411 Mdot
.82913 .89011 Mdot
.97869 .32905 Mdot
.45255 .24121 Mdot
.74661 .18686 Mdot
.28411 .0033 Mdot
.24121 .74814 Mdot
.26342 .9004 Mdot
.29615 .21686 Mdot
.59628 .69211 Mdot
.35405 .08333 Mdot
.19524 .54292 Mdot
.53984 .08106 Mdot
.63284 .10369 Mdot
.73121 .03453 Mdot
.10302 .03025 Mdot
.859 .59095 Mdot
.15876 .94421 Mdot
.84928 .09622 Mdot
.56535 .84235 Mdot
.23125 .0471 Mdot
.09265 .3147 Mdot
.5988 .66015 Mdot
.77732 .6357 Mdot
.96033 .25125 Mdot
.94905 .61581 Mdot
.44133 .04598 Mdot
.54439 .84397 Mdot
.91447 .25278 Mdot
.53939 .8722 Mdot
.27859 .21316 Mdot
.28359 .79263 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`;o00001?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_l0000;ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`;o
00003oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo000Nooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`;o0000
1?ooool00ol0003oooooooooo`07ooooo`;o00001?ooool00ol0003oooooooooo`02o`0000cooooo
00?o0000ooooooooool00_l0000;ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0:ooooo`;o000000?oooooo`000?l000003oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00_ooooo0ol0000?ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool00_ooool001kooooo0ol0001Xooooo`;o00001oooool2o`0001Gooooo0_l0
000booooo`;o0000HOooool2o`0002Kooooo000Nooooo`?o0000R?ooool2o`0006Wooooo0_l0001B
ooooo`007_ooool00ol0003oooooooooo`2Wooooo`;o0000B_ooool2o`0005;ooooo000Nooooo`03
o`000?oooooooooo01cooooo0_l0001^ooooo`;o00006Oooool2o`0003Cooooo0_l00003ooooo`;o
0000Doooool2o`0000kooooo000Nooooo`03o`000?oooooooooo01cooooo0_l000000ooooooo0000
o`00001[ooooo`;o00001_ooool2o`0004Oooooo0_l00003ooooo`;o0000Doooool2o`0000kooooo
000Nooooo`03o`000?oooooooooo01;ooooo0_l00008ooooo`;o000000?oooooo`000?l00000Looo
ool2o`000;7ooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l00008ooooo`;o00002_ooool2
o`00017ooooo0_l0000eooooo`;o0000<oooool2o`0006Kooooo0_l0000Yooooo`;o00002oooool0
01kooooo00?o0000ooooooooool07Oooool2o`0000Wooooo0_l00004ooooo`;o00002oooool2o`00
03Gooooo0_l0000Yooooo`;o00002?ooool2o`00047ooooo1?l0000Qooooo`;o00003_ooool2o`00
01Wooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o00003oooool2o`0006go
oooo0_l0001;ooooo`Co0000<Oooool2o`0002Kooooo000Nooooo`03o`000?oooooooooo08Cooooo
0_l00013ooooo`;o00007oooool2o`00057ooooo0_l00008ooooo`007_ooool00ol0003ooooooooo
o`0Yooooo`;o0000?oooool2o`0001Sooooo0_l0000Mooooo`;o00009?ooool2o`0005_ooooo0_l0
000Eooooo`Co00001_ooool001kooooo00?o0000ooooooooool03oooool2o`0001Sooooo0_l0000o
ooooo`;o0000=oooool2o`0000oooooo0_l0001`ooooo`;o00004?ooool2o`0000Gooooo0_l00006
ooooo`007_ooool00ol0003oooooooooo`08ooooo`;o00001Oooool2o`0001?ooooo0_l0000Qoooo
o`;o0000@_ooool2o`0002Oooooo0_l00022ooooo`;o00003Oooool001kooooo0_l00009ooooo`;o
00006_ooool2o`00027ooooo0_l0000Oooooo`;o00008Oooool3o`00037ooooo0_l0001Fooooo`;o
00001?ooool2o`000003ooooool0003o000002Gooooo000Nooooo`;o0000:Oooool2o`0003kooooo
0_l00002ooooo`;o00007_ooool2o`00037ooooo0_l0001=ooooo`;o00001oooool2o`0000Cooooo
0_l000000ooooooo0000o`00000Uooooo`007_ooool00ol0003oooooooooo`0Xooooo`;o00000_oo
ool2o`0003kooooo0_l0001gooooo`;o00009oooool2o`0002Cooooo0_l00006ooooo`;o00002Ooo
ool001kooooo00?o0000ooooooooool0;?ooool2o`0007;ooooo0_l00013ooooo`;o00009?ooool2
o`0002Oooooo0_l00006ooooo`;o00002Oooool001kooooo00?o0000ooooooooool0BOooool2o`00
02Gooooo0_l0000^ooooo`;o00005oooool2o`00017ooooo0_l00002ooooo`;o0000>Oooool2o`00
01oooooo0_l0000Iooooo`007_ooool00ol0003oooooooooo`19ooooo`;o00007oooool2o`0000Co
oooo0_l0000Booooo`;o0000<oooool2o`00017ooooo0_l00002ooooo`;o0000F_ooool2o`0001Wo
oooo000Nooooo`03o`000?oooooooooo03gooooo0_l0000[ooooo`;o00001Oooool2o`00017ooooo
0_l0001:ooooo`;o0000MOooool001kooooo00?o0000ooooooooool0?Oooool2o`0000Kooooo0_l0
000Zooooo`;o00002?ooool2o`0005?ooooo0_l00004ooooo`;o0000F?ooool2o`0000[ooooo0_l0
0009ooooo`007_ooool00ol0003oooooooooo`15ooooo`;o0000=?ooool2o`0002_ooooo0_l0000/
ooooo`;o0000F?ooool2o`0000[ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`2Xoooo
o`;o0000P?ooool2o`0001_ooooo000Nooooo`03o`000?oooooooooo013ooooo0_l0000Fooooo`;o
00003_ooool2o`0005Gooooo0_l0000Jooooo`;o00005_ooool2o`0004Sooooo0_l0000Kooooo`;o
00006oooool001kooooo00?o0000ooooooooool04?ooool2o`0001Kooooo0_l0000>ooooo`;o0000
6Oooool2o`0000Gooooo0_l0000Cooooo`;o00007_ooool2o`0000Cooooo0_l0000Booooo`Co0000
5_ooool2o`0003[ooooo0_l0000<ooooo`;o0000>?ooool001kooooo00?o0000ooooooooool0Dooo
ool2o`0000Gooooo0_l0000Cooooo`;o00009?ooool2o`0001;ooooo0_l0000aooooo`;o00008Ooo
ool2o`0000;ooooo0_l00012ooooo`007_ooool00ol0003oooooooooo`0Booooo`;o00007Oooool2
o`000:Wooooo0_l0000Pooooo`;o00000oooool2o`0000Wooooo0_l0000gooooo`007_ooool00ol0
003oooooooooo`0?ooooo`;o000000?oooooo`000?l000007Oooool2o`0005Sooooo0_l0001aoooo
o`;o00003_ooool2o`0003Oooooo000Nooooo`03o`000?oooooooooo00oooooo0_l0001jooooo`;o
000000?oooooo`000?l00000Loooool2o`0000;ooooo0_l00007ooooo`;o0000=Oooool001kooooo
00Co0000ooooool0003o0000<Oooool2o`0004oooooo0_l00009ooooo`;o00006?ooool2o`0001[o
oooo0_l0000Jooooo`;o00008Oooool2o`0000;ooooo0_l00007ooooo`;o00009_ooool2o`0000go
oooo000Nooooo`Co00003_ooool2o`0001Wooooo0_l00006ooooo`;o0000<_ooool2o`0001;ooooo
0_l00007ooooo`;o00008oooool2o`0001[ooooo0_l0000=ooooo`;o00002oooool2o`00043ooooo
0_l0000Dooooo`;o00003Oooool001kooooo00?o0000ooooooooool03oooool2o`0001Wooooo0_l0
000jooooo`;o00004_ooool2o`0000_ooooo0_l00011ooooo`;o00001oooool2o`0000Cooooo0_l0
000Uooooo`;o000000?oooooo`000?l000007Oooool2o`0002?ooooo000Nooooo`03o`000?oooooo
oooo00gooooo0_l0000Aooooo`;o00006Oooool2o`00027ooooo0_l0000Wooooo`;o0000@Oooool2
o`0000gooooo0_l0000Uooooo`;o000000?oooooo`000?l00000@_ooool001kooooo00?o0000oooo
ooooool03Oooool2o`00017ooooo0_l0000Iooooo`;o00005oooool2o`0000Sooooo0_l0001Boooo
o`;o0000Coooool2o`0004;ooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0001?ooooo`;o
00007oooool2o`0002Wooooo0_l0000@ooooo`;o0000Coooool2o`0004;ooooo000Nooooo`03o`00
0?oooooooooo00?ooooo0_l0001`ooooo`;o0000:Oooool2o`000:Gooooo000Nooooo`03o`000?oo
oooooooo04gooooo0_l0002Zooooo`;o0000C?ooool001kooooo00?o0000ooooooooool0COooool2
o`000:[ooooo0_l0001<ooooo`007_ooool00ol0003oooooooooo`3Pooooo`;o00009oooool2o`00
027ooooo0_l0000Iooooo`007_ooool3o`0008oooooo0_l0000Cooooo`;o00003?ooool2o`0002co
oooo0_l0000Wooooo`;o00008Oooool2o`0001Wooooo000Nooooo`?o00003oooool2o`0005Kooooo
0_l0000Vooooo`;o00004oooool2o`0000cooooo0_l0001<ooooo`;o0000AOooool001kooooo00?o
0000ooooooooool03oooool2o`0000Oooooo0_l0001=ooooo`;o0000=oooool2o`0005kooooo0_l0
0002ooooo`;o0000@Oooool001kooooo00?o0000ooooooooool06?ooool2o`00027ooooo0_l0000e
ooooo`;o00006_ooool2o`00013ooooo0_l0001Rooooo`;o00001?ooool2o`0003Cooooo0_l00005
ooooo`007_ooool00ol0003oooooooooo`0Vooooo`;o00004oooool2o`0003Gooooo0_l0000=oooo
o`;o00002oooool2o`0003Wooooo0_l0000oooooo`;o0000=?ooool2o`0000Gooooo000Nooooo`03
o`000?oooooooooo017ooooo0_l0000Cooooo`;o00005Oooool2o`0001_ooooo0_l0000Oooooo`;o
00001?ooool2o`0003cooooo0_l00008ooooo`;o0000O?ooool001kooooo00?o0000ooooooooool0
4Oooool2o`0001Wooooo0_l0000?ooooo`?o00006_ooool2o`0001oooooo0_l00009ooooo`;o0000
=Oooool4o`0007cooooo0_l00008ooooo`007_ooool2o`0001?ooooo0_l0000Hooooo`;o00004?oo
ool2o`0004Kooooo0_l0000eooooo`;o0000O_ooool2o`0000Sooooo000Nooooo`03o`000?oooooo
oooo01;ooooo0_l0000;ooooo`;o0000:?ooool2o`0001Cooooo0_l0000`ooooo`;o0000]?ooool0
01kooooo00?o0000ooooooooool07oooool2o`0001Gooooo0_l0000Aooooo`;o00005?ooool2o`00
033ooooo0_l0000iooooo`;o00002Oooool2o`0003gooooo0_l0000_ooooo`007_ooool00ol0003o
ooooooooo`0fooooo`;o0000U?ooool2o`0000Wooooo0_l0000mooooo`;o0000;oooool001kooooo
00?o0000ooooooooool0I_ooool2o`000=oooooo000Nooooo`03o`000?oooooooooo03Wooooo0_l0
000[ooooo`;o00005?ooool2o`0001Cooooo0_l00018ooooo`;o0000JOooool001kooooo00?o0000
ooooooooool03?ooool2o`0002_ooooo0_l0000[ooooo`;o00005?ooool2o`0001Cooooo0_l0000K
ooooo`;o0000:oooool2o`00037ooooo0_l0000fooooo`007_ooool00ol0003oooooooooo`0<oooo
o`;o0000F?ooool2o`0004Oooooo0_l0000_ooooo`;o0000;Oooool2o`0003Kooooo000Nooooo`03
o`000?oooooooooo0>3ooooo0_l0001Uooooo`007_ooool00ol0003oooooooooo`0Rooooo`;o0000
:?ooool2o`0001Oooooo0_l0002Eooooo`;o0000BOooool001kooooo00?o0000ooooooooool08_oo
ool2o`0002Sooooo0_l0000Gooooo`;o0000>_ooool2o`0005Wooooo0_l0000Booooo`;o00008Ooo
ool2o`0001;ooooo000Nooooo`03o`000?oooooooooo06Gooooo0_l0000jooooo`;o0000AOooool2
o`0002Kooooo0_l0000Qooooo`;o00004_ooool001kooooo00?o0000ooooooooool0j?ooool2o`00
00Gooooo0_l0001Fooooo`007_ooool00ol0003oooooooooo`2aooooo`;o0000??ooool2o`0004go
oooo0_l00007ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go
00001_ooool00ol0003oooooooooo`1Dooooo`;o00001oooool2o`0005;ooooo0_l0000]ooooo`;o
00001oooool2o`0005?ooooo0_l00007ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1Doooo
o`;o00001oooool2o`00087ooooo0_l00007ooooo`;o0000G?ooool000?ooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo1?l0000Pooooo`;o0000P_ooool2o`00
04gooooo0_l0001Aooooo`000oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q
8Oo^k^h01_ooool01?l0003oooooo`000?l00003ooooo`;o00006oooool2o`0008;ooooo0_l0000Q
ooooo`;o0000:_ooool2o`00057ooooo0003ooooo`05o`000?ooooooooooooooool000003_ooool0
0omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l0000<ooooo`;o0000]?ooool2
o`0003Gooooo0_l00016ooooo`000oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0>ooooo`;o00000_ooool2o`0002[ooooo0_l00017
ooooo`;o0000M_ooool2o`0001Oooooo0_l0000]ooooo`000oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo00Kooooo0_l0
0006ooooo`;o0000;_ooool2o`0000Cooooo0_l0000@ooooo`;o00008_ooool2o`0000_ooooo0_l0
000booooo`;o00003?ooool2o`0001Cooooo0_l0000gooooo`;o0000;Oooool000?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`06ooooo`;o00002?ooool2o`0001Gooooo0_l0000Kooooo`;o00004?ooool2o`0001Sooooo
0_l00008ooooo`;o0000?oooool2o`0000cooooo0_l0000Dooooo`;o0000?oooool2o`0002Gooooo
000Nooooo`03o`000?oooooooooo013ooooo0_l0000Eooooo`;o0000<oooool2o`0001;ooooo0_l0
000Booooo`;o0000V_ooool2o`0002Gooooo000Nooooo`03o`000?oooooooooo05cooooo0_l00003
ooooo`;o00008Oooool2o`0008[ooooo0_l0000eooooo`007_ooool00ol0003oooooooooo`1Qoooo
o`;o0000[Oooool2o`0003Gooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0001]ooooo`;o
0000c_ooool001kooooo00?o0000ooooooooool01oooool3o`0000Sooooo0_l0001Sooooo`;o0000
0oooool2o`000<Wooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l00009ooooo`;o0000G?oo
ool2o`0000[ooooo0_l0000Cooooo`;o0000]?ooool001kooooo00?o0000ooooooooool0EOooool2
o`0000oooooo0_l00008ooooo`;o00004Oooool2o`0000cooooo0_l0002dooooo`007_ooool00ol0
003oooooooooo`1Eooooo`;o00003oooool2o`0001_ooooo0_l0000:ooooo`;o0000Toooool2o`00
027ooooo000Nooooo`03o`000?oooooooooo06cooooo0_l0000Qooooo`;o00003oooool2o`0001[o
oooo0_l0001Sooooo`;o000000?oooooo`000?l000008Oooool001kooooo00?o0000ooooooooool0
K?ooool2o`0003;ooooo0_l0000Jooooo`;o000000?oooooo`000?l00000H?ooool2o`0002Cooooo
000Nooooo`03o`000?oooooooooo05cooooo0_l0001Qooooo`;o00008_ooool2o`0003gooooo0_l0
000Sooooo`007_ooool2o`0005gooooo0_l00025ooooo`;o0000<oooool2o`0000Sooooo0_l00000
0ooooooo0000o`00000=ooooo`;o00004Oooool001kooooo00?o0000ooooooooool00oooool2o`00
05Kooooo0_l0002Jooooo`;o000000?oooooo`000?l000007?ooool2o`0000_ooooo0_l0000=oooo
o`;o00004Oooool001kooooo00?o0000ooooooooool00oooool2o`00013ooooo0_l00005ooooo`;o
0000?Oooool2o`0009[ooooo0_l000000ooooooo0000o`00001;ooooo`007_ooool00ol0003ooooo
ooooo`0Eooooo`;o00001Oooool2o`0004_ooooo0_l00020ooooo`;o0000F_ooool001kooooo00?o
0000ooooooooool02_ooool2o`0001cooooo0_l0000`ooooo`;o00003Oooool2o`0007Cooooo0_l0
000:ooooo`;o00001?ooool2o`0003[ooooo0_l00008ooooo`;o00003_ooool001kooooo00?o0000
ooooooooool02_ooool2o`0001cooooo0_l0000Uooooo`;o00002Oooool2o`0008?ooooo0_l0000@
ooooo`;o0000>_ooool2o`0000Sooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`0<oooo
o`;o00006_ooool2o`0002Gooooo0_l0003fooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o
00002Oooool2o`000>Oooooo0_l00015ooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o0000
=oooool2o`0000kooooo0_l0002Nooooo`;o0000;oooool2o`0001Cooooo000Nooooo`03o`000?oo
oooooooo00[ooooo0_l00014ooooo`;o00003_ooool2o`000<oooooo0_l0000Dooooo`007_ooool0
0ol0003oooooooooo`02o`0000Sooooo0_l0003Mooooo`;o00000_ooool2o`0004cooooo0_l0000:
ooooo`007_ooool00ol0003oooooooooo`02o`0006kooooo0_l0001gooooo`?o000000?oooooo`00
0?l000003?ooool2o`0001cooooo0_l0000Pooooo`;o00002_ooool001kooooo00?o0000oooooooo
ool06_ooool2o`0005Cooooo0_l0000Rooooo`;o0000E?ooool2o`0000oooooo0_l00007ooooo`;o
00004oooool2o`0002cooooo000Nooooo`03o`000?oooooooooo01[ooooo0_l0000kooooo`;o0000
:_ooool2o`0000oooooo0_l00019ooooo`;o00006?ooool2o`0000Wooooo0_l00011ooooo`007_oo
ool00ol0003oooooooooo`1Gooooo`;o0000:_ooool2o`0000Oooooo0_l0001Aooooo`;o00006?oo
ool2o`0002Sooooo0_l0000Rooooo`007_ooool00ol0003oooooooooo`2<ooooo`;o0000EOooool2
o`0003kooooo0_l0000=ooooo`;o00004oooool001kooooo0_l0000Looooo`;o0000:?ooool2o`00
09cooooo0_l0001=ooooo`;o00004oooool001kooooo00?o0000ooooooooool06oooool2o`0000Go
oooo0_l0000Qooooo`;o0000mOooool2o`0000Wooooo000Nooooo`03o`000?oooooooooo02;ooooo
0_l0000Yooooo`;o0000@Oooool2o`0000[ooooo0_l0001eooooo`;o00009oooool2o`0000Wooooo
000Nooooo`03o`000?oooooooooo00?ooooo0_l0000@ooooo`;o0000=_ooool2o`00027ooooo0_l0
000Nooooo`;o00002_ooool2o`0007Gooooo0_l0000booooo`007_ooool00ol0003oooooooooo`03
ooooo`;o00004?ooool2o`0000?ooooo0_l0001@ooooo`;o00000_ooool2o`000=Gooooo000Noooo
o`03o`000?oooooooooo01Cooooo0_l00004ooooo`;o0000D?ooool2o`000=Wooooo000Nooooo`03
o`000?oooooooooo01Cooooo0_l0003oooooobGooooo0_l0000;ooooo`007_ooool00ol0003ooooo
ooooo`16ooooo`;o0000`oooool2o`0002gooooo0_l0000;ooooo`007_ooool00ol0003ooooooooo
o`0=ooooo`;o0000=oooool2o`000<?ooooo0_l00004ooooo`;o00003Oooool2o`0002Gooooo000N
ooooo`03o`000?oooooooooo00gooooo0_l0001Nooooo`;o0000:?ooool2o`0002Kooooo0_l0001@
ooooo`;o00003Oooool2o`0001Sooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`0Roooo
o`;o0000B?ooool3o`0002Sooooo0_l0000Vooooo`;o00004oooool2o`0005Sooooo0_l0000:oooo
o`;o00000_ooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo02;ooooo0_l00018ooooo`;o
0000I_ooool2o`0005Sooooo0_l0000>ooooo`;o00001oooool001kooooo00?o0000ooooooooool0
6Oooool2o`0007;ooooo0_l0000Tooooo`;o00009?ooool3o`0002cooooo0_l0000>ooooo`;o0000
5Oooool2o`0001Kooooo000Nooooo`03o`000?oooooooooo00cooooo0_l000000ooooooo0000o`00
0008ooooo`;o0000<Oooool2o`0003oooooo0_l0000Tooooo`;o00009?ooool3o`0002cooooo0_l0
000>ooooo`;o00005Oooool2o`0001Kooooo000Nooooo`03o`000?oooooooooo00cooooo0_l00000
0ooooooo0000o`00000Xooooo`;o00004Oooool2o`0002cooooo0_l0002<ooooo`;o0000?Oooool0
01kooooo00?o0000ooooooooool0;_ooool2o`0000Wooooo1?l0000mooooo`;o0000S?ooool2o`00
03gooooo000Nooooo`;o00005_ooool2o`0001Oooooo0_l0000;ooooo`;o0000j?ooool2o`00023o
oooo000Nooooo`03o`000?oooooooooo01Gooooo0_l0003Oooooo`Co0000:oooool2o`00023ooooo
000Nooooo`03o`000?oooooooooo06_ooooo0_l00029ooooo`Co00002Oooool2o`0004;ooooo000N
ooooo`03o`000?oooooooooo01;ooooo0_l0000Cooooo`;o0000:?ooool2o`0001Sooooo0_l0002F
ooooo`;o0000@_ooool001kooooo00?o0000ooooooooool04_ooool2o`0001?ooooo0_l0000Xoooo
o`;o0000B_ooool2o`000:Sooooo000Nooooo`03o`000?oooooooooo01oooooo0_l0001Mooooo`;o
00007Oooool2o`0008Wooooo0_l0000Mooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o0000
GOooool2o`000:Sooooo0_l0000Mooooo`007_ooool00ol0003oooooooooo`0iooooo`;o00002_oo
ool2o`0005Oooooo0_l0002Wooooo`007_ooool00ol0003oooooooooo`0Nooooo`;o00004oooool2
o`0000Cooooo0_l0000:ooooo`;o00002_ooool2o`0001gooooo0_l0000/ooooo`;o0000EOooool2
o`00033ooooo0_l0000@ooooo`;o00003?ooool001kooooo00?o0000ooooooooool07_ooool2o`00
01?ooooo0_l0000Looooo`;o00007Oooool2o`0008?ooooo0_l0000Xooooo`;o00001Oooool3o`00
013ooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o00003?ooool2o`000>co
oooo0_l00005ooooo`;o00007oooool001kooooo00?o0000ooooooooool05Oooool2o`0000cooooo
0_l0000<ooooo`;o0000@?ooool2o`0002Gooooo0_l0001Booooo`;o00006?ooool2o`0000_ooooo
0_l0000`ooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o00001_ooool2o`0000Cooooo0_l0
001>ooooo`;o00009Oooool2o`0005;ooooo0_l0000Hooooo`;o00002oooool2o`0002Gooooo0_l0
0009ooooo`007_ooool00ol0003oooooooooo`08ooooo`;o00004oooool2o`000:Sooooo0_l0001c
ooooo`;o00002Oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2
o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool02?ooool2o`0000Cooooo0_l0002g
ooooo`;o00005?ooool2o`0001kooooo0_l0000iooooo`;o00003Oooool000?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00kooooo0_l00012ooooo`;o0000Koooool2o`0001Sooooo0_l0000Jooooo`;o00000_ooool2
o`0000kooooo0_l0000;ooooo`;o00007?ooool2o`0000gooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41002oooool5o`0000Kooooo0ol0000gooooo`;o00006Oooool2o`0002oooooo0_l0000A
ooooo`;o0000:oooool2o`0003Cooooo0_l00003ooooo`;o00003Oooool2o`0000_ooooo0_l0000[
ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001ooo
ool00ol0003oooooooooo`0gooooo`;o0000B_ooool2o`00017ooooo0_l0001Vooooo`;o0000:?oo
ool2o`0001gooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEoooo
ool00007ooooo`03o`000?oooooooooo03Oooooo0_l0001Yooooo`;o00000oooool2o`0007oooooo
0_l0000Mooooo`000oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000
1oooool00ol0003oooooooooo`1Sooooo`;o0000?Oooool2o`0000?ooooo0_l0002Nooooo`000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0003ooooo
ooooo`07ooooo`;o00007?ooool2o`0000_ooooo0_l0000_ooooo`;o0000Z_ooool2o`0003Kooooo
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`00
0?oooooooooo00Oooooo0_l0000Looooo`;o00002oooool2o`0000Gooooo0_l0003Dooooo`;o0000
6?ooool2o`0001cooooo000Nooooo`03o`000?oooooooooo017ooooo0_l0000?ooooo`Ko00004Ooo
ool2o`0005cooooo0_l0002@ooooo`;o00007?ooool001kooooo00?o0000ooooooooool04Oooool2
o`0000oooooo1_l0001_ooooo`;o0000JOooool2o`0004?ooooo000Nooooo`03o`000?oooooooooo
04[ooooo0_l0001@ooooo`;o0000I?ooool2o`0000cooooo0_l0000eooooo`007_ooool00ol0003o
ooooooooo`13ooooo`;o00000oooool4o`00053ooooo0_l0001booooo`;o0000=Oooool001kooooo
00?o0000ooooooooool0@oooool2o`0000?ooooo0_l0001=ooooo`;o0000:?ooool2o`0008Cooooo
000Nooooo`03o`000?oooooooooo03kooooo0_l0001Gooooo`;o0000:?ooool2o`0004Gooooo0_l0
000mooooo`007_ooool00ol0003oooooooooo`0nooooo`;o0000Aoooool2o`00073ooooo0_l0000=
ooooo`;o0000?Oooool001kooooo00?o0000ooooooooool0Qoooool2o`0000Gooooo0_l0001Yoooo
o`;o0000C?ooool001kooooo00?o0000ooooooooool0S_ooool4o`000;Gooooo000Nooooo`03o`00
0?oooooooooo00?ooooo0_l0000mooooo`;o0000C?ooool2o`0007oooooo0_l0000dooooo`007_oo
ool00ol0003oooooooooo`03ooooo`;o00008_ooool2o`0000;ooooo0_l0000Eooooo`;o0000H?oo
ool2o`0003Sooooo0_l0000Sooooo`;o00003?ooool2o`0003Cooooo000Nooooo`;o0000:?ooool2
o`0000;ooooo0_l0001gooooo`;o00003?ooool2o`0002[ooooo0_l0000Sooooo`;o0000@_ooool0
01kooooo00?o0000ooooooooool01?ooool2o`0002Wooooo0_l0001Fooooo`;o0000:Oooool2o`00
00kooooo0_l00014ooooo`;o0000?Oooool001kooooo00?o0000ooooooooool01?ooool2o`0002Wo
oooo0_l0001Fooooo`;o0000>Oooool2o`00047ooooo0_l000000ooooooo0000o`00000mooooo`00
7_ooool00ol0003oooooooooo`0Kooooo`;o0000B?ooool2o`0009kooooo0_l0000Sooooo`;o0000
6oooool001kooooo00?o0000ooooooooool06oooool2o`0002kooooo0_l0000Eooooo`;o000000?o
ooooo`000?l000006oooool2o`0001?ooooo0_l0002Aooooo`;o00006oooool001kooooo00?o0000
ooooooooool0>_ooool2o`0000oooooo0_l0000Eooooo`;o00007_ooool2o`0000_ooooo0_l00006
ooooo`;o0000[_ooool001kooooo00?o0000ooooooooool0>_ooool2o`0002Kooooo0_l0000[oooo
o`;o0000V?ooool2o`0001cooooo000Nooooo`03o`000?oooooooooo01gooooo0_l00013ooooo`;o
0000]_ooool2o`0000gooooo0_l0000Looooo`007_ooool00ol0003oooooooooo`0Mooooo`;o0000
POooool2o`0007Sooooo0_l0000[ooooo`007_ooool00ol0003oooooooooo`0Nooooo`;o0000;?oo
ool2o`0003Gooooo0_l0000Cooooo`;o00001_ooool2o`0000Wooooo0_l0000Fooooo`;o0000?_oo
ool2o`0004;ooooo000Nooooo`03o`000?oooooooooo01kooooo0_l0000/ooooo`;o00004oooool2
o`00023ooooo0_l0000Cooooo`;o00004Oooool2o`0001Kooooo0_l0000nooooo`;o0000@_ooool0
01kooooo00?o0000ooooooooool02?ooool2o`0003gooooo0_l0000Hooooo`;o0000i?ooool001ko
oooo00?o0000ooooooooool02?ooool2o`0002gooooo0_l0000>ooooo`;o00005?ooool2o`0000_o
oooo0_l0000cooooo`;o0000Y_ooool001kooooo00?o0000ooooooooool0:_ooool2o`0000_ooooo
0_l0000Fooooo`;o00003?ooool2o`0000Cooooo0_l00005ooooo`;o0000<oooool2o`0003kooooo
0_l0001Hooooo`;o00003?ooool001kooooo00?o0000ooooooooool0:_ooool2o`0002?ooooo0_l0
000Booooo`;o00001_ooool2o`0000?ooooo0_l00012ooooo`;o0000:Oooool2o`0005Sooooo0_l0
000<ooooo`007_ooool00ol0003oooooooooo`1[ooooo`;o00000oooool2o`0004;ooooo0_l0000i
ooooo`;o00009oooool2o`0002gooooo000Nooooo`;o0000Soooool2o`0005oooooo0_l0000Woooo
o`;o00002Oooool2o`0000;ooooo0_l0000Nooooo`007_ooool00ol0003oooooooooo`2>ooooo`;o
0000S_ooool2o`0000?ooooo0_l00002ooooo`;o00002?ooool2o`0001Cooooo000Nooooo`03o`00
0?oooooooooo03Oooooo0_l0003Uooooo`;o00004Oooool2o`0001Cooooo000Nooooo`03o`000?oo
oooooooo03Oooooo0_l0002hooooo`;o0000E?ooool001kooooo00?o0000ooooooooool03Oooool2
o`00013ooooo0_l00031ooooo`;o00003Oooool2o`0005Cooooo000Nooooo`03o`000?oooooooooo
00gooooo0_l0000@ooooo`;o0000COooool2o`0004_ooooo0_l0000Uooooo`;o0000Hoooool001ko
oooo00?o0000ooooooooool0FOooool2o`0001?ooooo0_l0000iooooo`;o00004?ooool2o`0007co
oooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o0000B?ooool2o`0002Cooooo
0_l0000Xooooo`;o00007Oooool2o`0006oooooo0_l0000<ooooo`007_ooool00ol0003ooooooooo
o`06ooooo`;o000000?oooooo`000?l000001?ooool2o`0006kooooo0_l00017ooooo`;o0000>ooo
ool2o`00043ooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l000000ooooooo0000o`000037
ooooo`;o00001Oooool2o`0002[ooooo0_l0000Uooooo`;o00003?ooool2o`0000_ooooo000Noooo
o`03o`000?oooooooooo033ooooo0_l0000mooooo`;o0000HOooool4o`0000?ooooo0_l0001Aoooo
o`;o00003?ooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo033ooooo0_l0000^ooooo`Co
00002oooool2o`0006?ooooo0_l0000Yooooo`;o0000A_ooool001kooooo00?o0000ooooooooool0
H?ooool4o`0004oooooo0_l0001:ooooo`;o0000A_ooool001kooooo00?o0000ooooooooool0/ooo
ool2o`0000;ooooo0_l0001Cooooo`;o0000>Oooool001kooooo00?o0000ooooooooool0>oooool2
o`0003;ooooo0_l00003ooooo`;o00002oooool2o`000003ooooool0003o000000;o00008_ooool2
o`0000_ooooo0_l0001Cooooo`;o0000;oooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo
03[ooooo0ol0000booooo`;o00000oooool2o`0000[ooooo0ol000000ooooooo0000o`000002o`00
02;ooooo0_l0002?ooooo`Co00002?ooool001kooooo0_l00006ooooo`;o0000:_ooool2o`0000Oo
oooo0_l00014ooooo`;o0000POooool2o`0001Wooooo0_l0000Kooooo`;o00002_ooool001kooooo
00?o0000ooooooooool01Oooool2o`0002[ooooo0_l0003@ooooo`Co00005oooool2o`0002Oooooo
000Nooooo`03o`000?oooooooooo0;kooooo0_l0000looooo`;o00001oooool2o`00043ooooo000N
ooooo`03o`000?oooooooooo00cooooo0_l0000kooooo`;o0000Loooool2o`0003cooooo0_l00019
ooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o0000>oooool2o`000<3ooooo0_l0000Ioooo
o`;o00007oooool001kooooo00?o0000ooooooooool0O?ooool2o`0008gooooo0_l0000?ooooo`;o
00002?ooool2o`0001oooooo000Nooooo`03o`000?oooooooooo03Cooooo0_l00016ooooo`;o0000
>Oooool2o`0000Gooooo0_l0001Looooo`;o0000:Oooool001kooooo00?o0000ooooooooool07Ooo
ool2o`0001Gooooo0_l0000@ooooo`;o0000=?ooool2o`00017ooooo0_l0000Vooooo`;o00001Ooo
ool2o`0003kooooo0_l0000jooooo`;o00002oooool001kooooo00?o0000ooooooooool02_ooool2
o`00017ooooo0_l000000ooooooo0000o`00000Tooooo`;o0000=?ooool2o`00017ooooo0_l0000=
ooooo`;o00004oooool2o`0004Wooooo0_l0000Qooooo`;o00005oooool2o`0000_ooooo000Noooo
o`03o`000?oooooooooo00Sooooo1?l0000Dooooo`;o0000>_ooool2o`00043ooooo0_l0000Coooo
o`;o0000<Oooool2o`0003;ooooo0_l00005ooooo`;o00009?ooool001kooooo00?o0000oooooooo
ool02?ooool2o`0001Sooooo0_l0000hooooo`;o0000D_ooool2o`0000_ooooo0_l0000Wooooo`;o
0000<_ooool2o`0002_ooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0000Hooooo`;o0000
Q?ooool2o`0000Kooooo0_l0000;ooooo`;o0000@oooool2o`00027ooooo0_l0000Cooooo`;o0000
2oooool001kooooo00?o0000ooooooooool02?ooool2o`0005Sooooo0_l00014ooooo`;o0000F?oo
ool2o`00027ooooo0_l0000Cooooo`;o00002oooool001kooooo00?o0000ooooooooool0H_ooool2
o`0000cooooo0_l0001Eooooo`;o0000>Oooool2o`0000oooooo0_l0000booooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_oo
ool00ol0003oooooooooo`0>ooooo`;o00002Oooool2o`0005Gooooo0_l00002ooooo`;o00001ooo
ool2o`0004Sooooo0_l0000kooooo`;o00003Oooool2o`0001kooooo0_l0000Booooo`000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40
1_ooool00ol0003oooooooooo`0>ooooo`;o00002Oooool2o`0005Wooooo0_l00007ooooo`;o0000
4_ooool2o`0006kooooo0_l000000ooooooo0000o`00000@ooooo`;o00006oooool2o`0001;ooooo
0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Ko
oooo0ol0000hooooo`;o0000Eoooool2o`0005Oooooo0_l0000Eooooo`;o00004oooool2o`0002oo
oooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q
00Kooooo00?o0000ooooooooool0>?ooool2o`0000kooooo0_l0000Aooooo`;o0000>oooool2o`00
053ooooo0_l0001Kooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEE
EOl0003o410@olc<c006ooooo`03o`000?oooooooooo04Sooooo0_l00006ooooo`;o00002Oooool2
o`0000gooooo0_l00006ooooo`;o000000?oooooo`000?l000008Oooool2o`0000_ooooo0_l0000]
ooooo`;o0000LOooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOo
oooo00Sooooo00?o0000ooooooooool01oooool2o`0004Oooooo0_l0000Hooooo`;o00001_ooool2
o`000003ooooool0003o000001_ooooo0_l0000Aooooo`;o0000;Oooool2o`00077ooooo0003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooo
oooo00Oooooo0_l00029ooooo`;o00002Oooool2o`000:Sooooo0003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo077ooooo0_l0
000Zooooo`;o0000<oooool2o`0005cooooo0_l0000Eooooo`007_ooool00ol0003oooooooooo`1a
ooooo`;o0000EOooool2o`0000Sooooo0_l0001Kooooo`?o00005Oooool001kooooo00?o0000oooo
ooooool0b?ooool2o`00043ooooo0_l0000Sooooo`;o00005_ooool001kooooo00?o0000oooooooo
ool08Oooool2o`0003Oooooo0_l0001booooo`;o0000:?ooool2o`00013ooooo0_l0000kooooo`00
7_ooool00ol0003oooooooooo`0Qooooo`;o0000=oooool2o`0002?ooooo0_l0000/ooooo`;o0000
4?ooool2o`0000gooooo0_l0000Xooooo`;o0000COooool001kooooo00?o0000ooooooooool09?oo
ool2o`0000Gooooo0_l0000iooooo`;o00005oooool2o`0001gooooo0_l0000=ooooo`;o00004?oo
ool2o`0004Kooooo0_l0000nooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o00004oooool2
o`0000Gooooo0_l0000Cooooo`;o00009?ooool2o`0000oooooo0_l0000Uooooo`;o0000D_ooool2
o`0001?ooooo0_l0000nooooo`007_ooool3o`0000oooooo0_l0000_ooooo`;o0000=Oooool2o`00
07Wooooo0_l00005ooooo`;o00009_ooool2o`0002Cooooo000Nooooo`?o0000Soooool2o`0003Oo
oooo0_l0000_ooooo`;o00009_ooool2o`0002Cooooo000Nooooo`03o`000?oooooooooo03gooooo
0_l0000Sooooo`;o00001?ooool2o`0002Gooooo0_l0000gooooo`;o0000L?ooool2o`0000_ooooo
000Nooooo`03o`000?oooooooooo02?ooooo0_l00002ooooo`;o00004_ooool4o`0002?ooooo0_l0
0004ooooo`;o0000_Oooool2o`00017ooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`06
ooooo`;o00001Oooool2o`0001Cooooo0_l00002ooooo`;o000000?oooooo`000?l000003oooool2
o`0002Cooooo0_l00034ooooo`;o00007_ooool001kooooo0_l00007ooooo`;o00001Oooool2o`00
01_ooooo0_l0000Qooooo`;o00004_ooool2o`000>Cooooo000Nooooo`03o`000?oooooooooo04go
oooo0_l0001:ooooo`;o0000[?ooool001kooooo00?o0000ooooooooool0VOooool2o`0001Kooooo
0_l0000gooooo`;o0000Foooool001kooooo00?o0000ooooooooool0;oooool2o`0001Oooooo0_l0
0013ooooo`;o00006?ooool2o`0000Sooooo0_l00002ooooo`;o00002?ooool2o`0002Wooooo0_l0
000Tooooo`;o0000=Oooool001kooooo00Co0000oooooooooooooooo0_l0000Iooooo`;o00004Ooo
ool2o`0001Oooooo0_l00013ooooo`;o00006?ooool2o`0000cooooo0_l00008ooooo`;o0000Cooo
ool2o`0003Gooooo000Nooooo`04o`000?ooooooooooooooo`;o00006Oooool2o`0009Gooooo0_l0
0010ooooo`;o0000D?ooool001kooooo00?o0000ooooooooool0??ooool2o`0007Cooooo0ol00010
ooooo`;o00007Oooool4o`0002oooooo000Nooooo`03o`000?oooooooooo03Oooooo0_l00003oooo
o`;o0000M?ooool2o`00063ooooo1?l0000_ooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o
00007Oooool2o`0004Oooooo0_l0000/ooooo`;o0000S_ooool2o`0000Oooooo000Nooooo`03o`00
0?oooooooooo01Oooooo0ol0000[ooooo`;o0000>Oooool2o`0000Oooooo0_l0000Sooooo`;o0000
S_ooool2o`0000Oooooo000Nooooo`?o00005oooool2o`0002cooooo0_l00012ooooo`;o0000_?oo
ool001gooooo1?l0000Eooooo`;o00004Oooool2o`0000cooooo0_l0001Hooooo`;o00000_ooool2
o`0002kooooo0_l0001Eooooo`;o0000:_ooool001gooooo0_l0000Cooooo`;o00000_ooool2o`00
017ooooo0_l0000<ooooo`;o0000>?ooool2o`0001kooooo0_l00002ooooo`;o0000;_ooool3o`00
01_ooooo0_l0000gooooo`;o0000:_ooool001kooooo00?o0000ooooooooool04Oooool2o`000003
ooooool0003o000000Gooooo0_l0000eooooo`;o00007?ooool2o`0002cooooo0_l0000Nooooo`;o
00001Oooool2o`0001_ooooo0_l0001Sooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o0000
1Oooool2o`0002[ooooo0_l00009ooooo`;o0000B_ooool2o`0000Sooooo0_l0000Dooooo`;o0000
O_ooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo04Oooooo0_l0001Oooooo`;o0000GOoo
ool2o`0002[ooooo0_l00009ooooo`;o00001oooool001kooooo0_l0000]ooooo`;o0000DOooool2
o`0008Kooooo0_l0000Zooooo`;o00004_ooool001kooooo00?o0000ooooooooool0;?ooool2o`00
00Oooooo0_l0000Nooooo`;o00001Oooool2o`00027ooooo0_l0001Tooooo`;o0000H?ooool001ko
oooo0ol0000<ooooo`;o00009oooool2o`0001kooooo0_l00005ooooo`;o00005_ooool2o`0001Ko
oooo0_l0000Qooooo`;o00000_ooool2o`00033ooooo0_l0001Pooooo`007_ooool3o`0000cooooo
0_l0000Cooooo`;o0000>_ooool2o`0001Gooooo0_l0000Fooooo`;o00008Oooool2o`0000;ooooo
0_l0002Booooo`007_ooool00ol0003oooooooooo`0@ooooo`;o00003oooool2o`0003[ooooo0_l0
000kooooo`;o00006Oooool2o`0006?ooooo0_l0000[ooooo`007_ooool00ol0003oooooooooo`0@
ooooo`;o0000O_ooool2o`0000Sooooo0_l0000Iooooo`;o0000Hoooool2o`0002_ooooo000Noooo
o`03o`000?oooooooooo06Gooooo0_l0000Yooooo`;o00006oooool2o`0009Sooooo000Mooooo`;o
0000Ioooool2o`0004Kooooo0_l0001cooooo`;o00001oooool2o`0001[ooooo000Mooooo`;o0000
:oooool2o`0007Cooooo0_l0000Oooooo`;o0000B?ooool3o`0001Gooooo0_l00007ooooo`;o0000
6_ooool001gooooo0_l0000[ooooo`;o00007_ooool2o`0000[ooooo0_l00010ooooo`;o00001_oo
ool2o`0001oooooo0_l00018ooooo`?o0000>_ooool001gooooo0_l0000Oooooo`;o0000:_ooool2
o`0000[ooooo0_l00010ooooo`;o0000A?ooool2o`0002_ooooo0_l0000kooooo`007_ooool00ol0
003oooooooooo`0Mooooo`;o0000=Oooool2o`00027ooooo0_l0001Tooooo`;o00006?ooool2o`00
02Oooooo0_l0000Uooooo`007_ooool00ol0003oooooooooo`1Dooooo`;o00008Oooool2o`0007ko
oooo0_l0000Wooooo`;o00003?ooool2o`0001Oooooo000Nooooo`03o`000?oooooooooo08Sooooo
0_l0001mooooo`;o00009Oooool2o`0000oooooo0_l00006ooooo`007_ooool00ol0003ooooooooo
o`1Gooooo`;o00005_ooool2o`0001Oooooo0_l0001Dooooo`;o00009oooool2o`0000gooooo0_l0
000=ooooo`;o00006?ooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo02kooooo0_l0000J
ooooo`;o00002oooool2o`0000kooooo0_l00006ooooo`;o0000Doooool2o`0001Sooooo0_l0000f
ooooo`;o00003Oooool2o`00023ooooo000Nooooo`;o0000;oooool2o`0001[ooooo0_l0000Koooo
o`;o0000?_ooool2o`0001_ooooo0_l00021ooooo`007_ooool00ol0003oooooooooo`1[ooooo`;o
0000>_ooool2o`0009kooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l0000^ooooo`;o0000
2?ooool2o`0001Kooooo0_l000000ooooooo0000o`000003ooooo`;o0000aOooool2o`0000kooooo
000Nooooo`03o`000?oooooooooo01Kooooo0_l00004ooooo`;o0000:?ooool2o`0000Sooooo0_l0
0007ooooo`;o00003Oooool2o`0000Kooooo0_l00035ooooo`;o00003_ooool001kooooo00?o0000
ooooooooool04Oooool2o`0000Wooooo0_l0000kooooo`;o0000;_ooool2o`0004_ooooo0_l0001_
ooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o00005_ooool2o`0005kooooo0_l000000ooo
oooo0000o`00000Iooooo`;o00006_ooool2o`00017ooooo0_l0001_ooooo`007_ooool00ol0003o
ooooooooo`0Vooooo`;o000000?oooooo`000?l00000?oooool2o`00023ooooo0_l0000Iooooo`;o
00002oooool2o`0000gooooo0_l0000<ooooo`;o00002?ooool2o`0006[ooooo000Nooooo`03o`00
0?oooooooooo02Kooooo0_l00012ooooo`;o0000<?ooool2o`0000Kooooo0_l0000>ooooo`;o0000
6oooool2o`0000Sooooo0_l0000?ooooo`;o0000>oooool2o`0001cooooo000Nooooo`03o`000?oo
oooooooo017ooooo0_l00029ooooo`;o000000?oooooo`000?l000000oooool2o`0004Kooooo0_l0
000]ooooo`;o00003?ooool2o`0001cooooo000Nooooo`03o`000?oooooooooo00gooooo0_l00002
ooooo`;o0000N_ooool2o`00013ooooo0_l0000Hooooo`;o0000H?ooool2o`0002[ooooo000Noooo
o`03o`000?oooooooooo00gooooo0_l0000Booooo`;o00004Oooool2o`0000Wooooo0_l0000aoooo
o`;o00006Oooool2o`0000Wooooo0_l0000Oooooo`;o0000S?ooool001kooooo00?o0000oooooooo
ool07_ooool2o`000003ooooool0003o0000017ooooo0_l00009ooooo`;o0000<Oooool2o`0002Co
oooo0_l0002]ooooo`007_ooool00ol0003oooooooooo`0Nooooo`;o0000i_ooool2o`0000cooooo
0_l0000Hooooo`;o00002?ooool2o`0000gooooo000Nooooo`04o`000?ooooooooooooooo`;o0000
ooooool4ooooo`;o00003?ooool2o`0001Sooooo0_l00008ooooo`;o00003Oooool000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Ko
oooo00Co0000oooooooooooooooo0_l0001Eooooo`;o0000Aoooool2o`0005Cooooo0_l0000=oooo
o`;o0000?oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ
8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0F?ooool2o`0004Oooooo0_l0001D
ooooo`;o00003Oooool2o`0003oooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool0
1Ol0003ooooooooooooooooo000000Kooooo0ol0001Zooooo`;o0000JOooool2o`0000oooooo0_l0
00000ooooooo0000o`00000aooooo`;o0000:Oooool000?ooooo00Go0000ooooooooooooooooo`00
000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool00ol0003oooooooooo`0Gooooo`;o0000
DOooool2o`0006Wooooo0_l0000?ooooo`;o000000?oooooo`000?l00000<Oooool2o`0002Wooooo
0003ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Ko
oooo00?o0000ooooooooool05oooool2o`00017ooooo0_l0002<ooooo`;o00002Oooool2o`0008;o
oooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@
00Kooooo00?o0000ooooooooool09?ooool2o`0000Cooooo0_l0001=ooooo`;o00003oooool3o`00
02_ooooo0_l00009ooooo`;o0000M?ooool2o`0000cooooo0003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool04?ooool2
o`0001;ooooo0_l0001Cooooo`;o00003oooool3o`0003kooooo0_l0001/ooooo`;o00003?ooool0
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_oo
ool00ol0003oooooooooo`0<ooooo`;o00000_ooool2o`0004Kooooo0_l00002ooooo`;o0000KOoo
ool2o`0002cooooo0_l0001<ooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o0000:?ooool2
o`0000;ooooo0_l0000Looooo`;o00000_ooool2o`0005cooooo0_l0000Cooooo`;o0000:?ooool2
o`0004cooooo000Nooooo`03o`000?oooooooooo03Kooooo0_l00002ooooo`;o0000Goooool2o`00
00?ooooo0_l0000Hooooo`;o00004oooool2o`00037ooooo0_l0000iooooo`;o00002?ooool001ko
oooo00?o0000ooooooooool0:?ooool2o`00077ooooo0_l00003ooooo`;o0000H?ooool2o`0001So
oooo0_l0000Oooooo`;o00002?ooool001kooooo00?o0000ooooooooool0:?ooool2o`0001?ooooo
0_l0001_ooooo`;o00008_ooool2o`0004Sooooo0_l0000Yooooo`007_ooool2o`0002[ooooo0_l0
000Booooo`;o0000Koooool2o`0002;ooooo0_l0000Booooo`;o0000>?ooool2o`0001Wooooo0_l0
000:ooooo`007_ooool2o`0000kooooo0_l0000Jooooo`;o0000T_ooool2o`0002Oooooo0_l0000h
ooooo`;o00006Oooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00gooooo0_l0002^oooo
o`;o00004_ooool2o`00027ooooo0_l0001Aooooo`007_ooool00ol0003oooooooooo`07ooooo`;o
0000FOooool2o`0006gooooo0_l0000Qooooo`;o0000<Oooool2o`0001kooooo000Nooooo`03o`00
0?oooooooooo00Oooooo0_l0001Iooooo`;o00009oooool2o`00023ooooo0_l00005ooooo`;o0000
<?ooool2o`0003oooooo0_l0000Nooooo`007_ooool00ol0003oooooooooo`0[ooooo`;o0000:?oo
ool2o`0000Cooooo0_l0000^ooooo`;o00008?ooool2o`0000Gooooo0_l0000`ooooo`;o0000Gooo
ool001kooooo00?o0000ooooooooool0:oooool2o`0002Sooooo0_l00004ooooo`;o00009_ooool2
o`0000[ooooo0_l000000ooooooo0000o`00000Cooooo`;o00009_ooool2o`00047ooooo0_l0000c
ooooo`007_ooool2o`0000Sooooo0_l0001jooooo`;o00002_ooool2o`000003ooooool0003o0000
01?ooooo0_l0000Vooooo`;o00000oooool2o`0002kooooo0_l0000<ooooo`;o0000<oooool001ko
oooo00?o0000ooooooooool01oooool2o`0009oooooo0_l0000Zooooo`;o00001Oooool2o`0002Oo
oooo0_l0000/ooooo`;o00004oooool001kooooo00?o0000ooooooooool0Z?ooool2o`0000[ooooo
0_l0000Uooooo`;o00004?ooool2o`0001?ooooo0_l0000^ooooo`;o00003?ooool2o`0000Gooooo
000Nooooo`03o`000?oooooooooo05;ooooo0_l0000_ooooo`;o0000;?ooool2o`000003ooooool0
003o000001gooooo0_l0000Hooooo`;o00004oooool2o`0000Gooooo0_l0000]ooooo`;o00001_oo
ool2o`0000Gooooo000Nooooo`03o`000?oooooooooo02Kooooo0_l0000Sooooo`;o00001Oooool2
o`0000Wooooo0_l0000:ooooo`;o00001oooool2o`0000oooooo0_l0000/ooooo`;o00003_ooool2
o`00013ooooo0_l0000]ooooo`;o00001Oooool2o`0002Kooooo0_l00005ooooo`;o00003Oooool0
01kooooo00?o0000ooooooooool01_ooool2o`0001kooooo0_l0000Kooooo`;o00001_ooool2o`00
013ooooo0_l0000:ooooo`;o00001oooool2o`000003ooooool0003o0000037ooooo0_l0000Goooo
o`;o0000?oooool2o`0002gooooo0_l0000Dooooo`007_ooool00ol0003oooooooooo`06ooooo`;o
0000>oooool2o`00033ooooo0_l0000aooooo`;o00002_ooool2o`0007?ooooo0_l0000Looooo`00
7_ooool00ol0003oooooooooo`0Mooooo`;o00008Oooool2o`0001Sooooo0_l0000fooooo`;o0000
5oooool2o`0000Oooooo0_l0001Looooo`;o00005Oooool2o`00013ooooo0_l0000:ooooo`007_oo
ool00ol0003oooooooooo`0Mooooo`;o00008Oooool2o`0001Sooooo0_l0000Uooooo`;o00003ooo
ool4o`0001Gooooo0_l0001Uooooo`;o00009oooool2o`000003ooooool0003o000000Oooooo000N
ooooo`03o`000?oooooooooo06Oooooo0_l0000Hooooo`;o00004Oooool2o`00013ooooo0_l00006
ooooo`;o0000S_ooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo05Cooooo0_l0000Aoooo
o`;o0000?Oooool2o`0000?ooooo0_l000000ooooooo0000o`00000@ooooo`;o0000@Oooool2o`00
02[ooooo0_l0000Fooooo`007_ooool00ol0003oooooooooo`1Dooooo`;o00006Oooool2o`0000;o
oooo0_l0000fooooo`;o00001?ooool2o`0000gooooo0_l00011ooooo`;o0000:_ooool2o`0001Ko
oooo000Nooooo`03o`000?oooooooooo01gooooo0_l0001?ooooo`?o00000_ooool2o`0002Gooooo
0_l0000Eooooo`;o0000;oooool2o`0002Gooooo0_l0000looooo`007_ooool00ol0003ooooooooo
o`0Mooooo`;o00004_ooool2o`0003_ooooo0_l0000Zooooo`;o0000A_ooool2o`0002Gooooo0_l0
000looooo`007_ooool00ol0003oooooooooo`02o`0002oooooo0_l0000Looooo`;o00002_ooool2
o`00047ooooo0_l0000Sooooo`;o0000LOooool2o`0000oooooo000Nooooo`03o`000?oooooooooo
00;o0000?oooool2o`0000cooooo0_l00009ooooo`?o0000@Oooool2o`0000kooooo0_l0000Coooo
o`;o0000<oooool2o`0003cooooo0_l0000?ooooo`007_ooool2o`0004;ooooo0_l0000?ooooo`;o
00001_ooool2o`0005;ooooo0_l00018ooooo`;o0000COooool001kooooo00?o0000ooooooooool0
D_ooool2o`000;Oooooo0_l0000jooooo`007_ooool00ol0003oooooooooo`0Booooo`;o0000M?oo
ool4o`0007oooooo0_l0000Zooooo`;o00003_ooool001kooooo00?o0000ooooooooool04_ooool2
o`0002cooooo0_l00016ooooo`Co0000Q?ooool2o`0002Gooooo0_l0000>ooooo`007_ooool00ol0
003oooooooooo`04ooooo`;o0000>_ooool2o`0002oooooo0_l0000Zooooo`;o0000KOooool2o`00
00;ooooo0_l0000eooooo`007_ooool00ol0003oooooooooo`04ooooo`;o0000;oooool2o`0003[o
oooo0_l0000Aooooo`;o00005oooool2o`0006gooooo0_l0000Yooooo`;o00003_ooool001kooooo
00?o0000ooooooooool0=Oooool2o`0000Wooooo0_l00012ooooo`;o0000/Oooool2o`0000kooooo
000Nooooo`03o`000?oooooooooo043ooooo0_l0001>ooooo`;o00004_ooool2o`0001?ooooo0_l0
002<ooooo`007_ooool00ol0003oooooooooo`0looooo`;o0000D_ooool2o`0001;ooooo0_l0000C
ooooo`;o0000>?ooool4o`000003ooooool0003o000002Wooooo0_l0000Rooooo`007_ooool00ol0
003oooooooooo`06ooooo`;o0000=?ooool2o`0000Wooooo0_l0001Mooooo`;o00003?ooool2o`00
03gooooo1?l000000ooooooo0000o`00000Yooooo`;o00008_ooool001kooooo00?o0000oooooooo
ool01_ooool2o`0003oooooo0_l0001Mooooo`;o00003?ooool2o`0004Kooooo0_l00019ooooo`00
7_ooool00ol0003oooooooooo`3looooo`;o0000BOooool001kooooo00Co0000ooooool0003o0000
[oooool2o`0001Oooooo0_l00015ooooo`;o0000=Oooool001kooooo00Co0000ooooool0003o0000
KOooool2o`0000kooooo0_l0000`ooooo`;o00005oooool2o`00023ooooo0_l0000Sooooo`;o0000
=Oooool001kooooo00?o0000ooooooooool0;oooool2o`0003gooooo0_l0000>ooooo`;o00008?oo
ool2o`0000Wooooo0_l0000<ooooo`;o0000<?ooool2o`0000;ooooo0_l0001Fooooo`007_ooool0
0ol0003oooooooooo`0_ooooo`;o0000Koooool2o`0000Wooooo0_l0000<ooooo`;o0000;_ooool2
o`0000Cooooo0_l0001Fooooo`007_ooool2o`0008Sooooo0_l0001Pooooo`;o0000=_ooool2o`00
02Cooooo000Nooooo`03o`000?oooooooooo08Oooooo0_l0000Nooooo`;o0000C_ooool2o`0002So
oooo0_l0000Tooooo`007_ooool00ol0003oooooooooo`06ooooo`;o00007?ooool2o`0005Gooooo
0_l0000Hooooo`;o00004?ooool2o`0002Kooooo0_l0000Gooooo`;o00003Oooool2o`0000Oooooo
0_l0000=ooooo`;o0000=_ooool001kooooo00?o0000ooooooooool01_ooool2o`0001cooooo0_l0
001Eooooo`;o00006?ooool2o`0003Sooooo0_l0000Gooooo`;o00005_ooool2o`0000gooooo0_l0
000fooooo`007_ooool00ol0003oooooooooo`0Vooooo`;o00006?ooool2o`000>Kooooo0_l0000M
ooooo`007_ooool00ol0003oooooooooo`05ooooo`;o00007oooool2o`0001Sooooo0_l0000;oooo
o`;o0000=Oooool2o`0002Gooooo0_l0001?ooooo`;o00007?ooool2o`0000cooooo0_l0000Moooo
o`007_ooool00ol0003oooooooooo`05ooooo`;o0000A_ooool2o`0003Gooooo0_l0000Uooooo`;o
0000COooool4o`0001cooooo0_l0000[ooooo`007_ooool00ol0003oooooooooo`02ooooo`;o0000
00?oooooo`000?l00000bOooool2o`0002Sooooo0_l0001;ooooo`007_ooool00ol0003ooooooooo
o`02ooooo`;o000000?oooooo`000?l000001?ooool2o`0001Kooooo0_l0002[ooooo`;o0000:_oo
ool2o`0004Wooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l00003ooooo`;o00003?ooool2
o`0000Sooooo0_l00009ooooo`;o0000c?ooool2o`0004Wooooo000Nooooo`03o`000?oooooooooo
00Kooooo0_l0000Aooooo`;o00004oooool2o`00083ooooo0_l0002Eooooo`007_ooool00ol0003o
ooooooooo`0Pooooo`;o00009?ooool2o`0006Gooooo0_l000000ooooooo0000o`00000:ooooo`;o
00008_ooool2o`0001kooooo0_l00015ooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o0000
9?ooool2o`0000;ooooo0_l0000_ooooo`;o00001_ooool2o`00013ooooo0_l0000Fooooo`;o0000
3Oooool2o`0002;ooooo0_l0000Nooooo`;o0000=Oooool2o`0000kooooo000Nooooo`03o`000?oo
oooooooo04[ooooo0_l0000_ooooo`;o00001_ooool2o`00013ooooo0_l0002Pooooo`;o00003_oo
ool001Cooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo01Wooooo0_l0000S
ooooo`;o00002Oooool2o`0000Oooooo0_l0003Tooooo`;o00003Oooool001Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Iooooo`;o00000_ooool2o`0001;ooooo0_l0000;oooo
o`;o00002Oooool2o`0000Oooooo0_l0003@ooooo`;o00004_ooool2o`0000gooooo000Fooooo`03
o`000?oooooooooo00Gooooo0ol0000Fooooo`;o00001Oooool2o`0001;ooooo0_l0002Looooo`;o
0000Doooool2o`00027ooooo000Fooooo`03o`000?oooooooooo01kooooo0_l0002gooooo`;o0000
M_ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3o
oooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Cooooo00?oEEEEofIVI_l0
0000oooooomBooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.86761 .90576 Mdot
.69031 .16655 Mdot
.42704 .29246 Mdot
.76035 .15437 Mdot
.31988 .79589 Mdot
.23297 .85229 Mdot
.8409 .68294 Mdot
.0525 .29161 Mdot
.53201 .68069 Mdot
.62609 .00252 Mdot
.53979 .70849 Mdot
.56161 .823 Mdot
.94281 .03053 Mdot
.79801 .78378 Mdot
.20119 .47986 Mdot
.83812 .35531 Mdot
.69866 .01593 Mdot
.79371 .21355 Mdot
.26985 .06012 Mdot
.32663 .25674 Mdot
.32417 .55795 Mdot
.86467 .13408 Mdot
.55804 .53638 Mdot
.91525 .06566 Mdot
.07242 .67127 Mdot
.68302 .66854 Mdot
.88651 .405 Mdot
.79416 .4427 Mdot
.97714 .09318 Mdot
.22977 .60498 Mdot
.07822 .51595 Mdot
.64282 .65415 Mdot
.76054 .58871 Mdot
.06237 .20933 Mdot
.01365 .79686 Mdot
.45392 .90063 Mdot
.78218 .58613 Mdot
.36722 .96889 Mdot
.95533 .83875 Mdot
.30764 .75858 Mdot
.77346 .95026 Mdot
.20642 .4913 Mdot
.47257 .81688 Mdot
.38165 .98113 Mdot
.32571 .91297 Mdot
.3995 .62587 Mdot
.58846 .79294 Mdot
.247 .4085 Mdot
.75899 .6438 Mdot
.53975 .61369 Mdot
.41568 .48056 Mdot
.03312 .67985 Mdot
.98799 .27341 Mdot
.10738 .38586 Mdot
.32585 .73605 Mdot
.51486 .68512 Mdot
.93638 .05256 Mdot
.32982 .87989 Mdot
.4825 .31346 Mdot
.31062 .1506 Mdot
.95641 .08967 Mdot
.38924 .90302 Mdot
.23057 .71259 Mdot
.01794 .98767 Mdot
.48123 .30442 Mdot
.18341 .92865 Mdot
.82489 .18305 Mdot
.5273 .48336 Mdot
.81362 .61325 Mdot
.94891 .28757 Mdot
.09234 .97235 Mdot
.44928 .84989 Mdot
.07607 .33185 Mdot
.8019 .42134 Mdot
.80179 .76799 Mdot
.39155 .10085 Mdot
.46887 .11331 Mdot
.41339 .90467 Mdot
.91975 .16792 Mdot
.06396 .67803 Mdot
.4109 .3264 Mdot
.90059 .66896 Mdot
.22971 .61936 Mdot
.1932 .3774 Mdot
.28117 .13469 Mdot
.20504 .46967 Mdot
.21448 .607 Mdot
.46498 .00448 Mdot
.46302 .65894 Mdot
.31678 .82453 Mdot
.29546 .65544 Mdot
.99108 .8741 Mdot
.02918 .33292 Mdot
.36943 .47415 Mdot
.61558 .8968 Mdot
.00401 .30175 Mdot
.59156 .52291 Mdot
.62274 .10726 Mdot
.64436 .66395 Mdot
.62711 .82413 Mdot
.2974 .67668 Mdot
.69741 .71416 Mdot
.81311 .09206 Mdot
.45698 .58708 Mdot
.08684 .28815 Mdot
.25469 .31008 Mdot
.17103 .65419 Mdot
.57297 .79608 Mdot
.23656 .45795 Mdot
.7653 .95142 Mdot
.80647 .95604 Mdot
.38205 .38699 Mdot
.21974 .14383 Mdot
.47851 .38408 Mdot
.79304 .72211 Mdot
.9113 .78394 Mdot
.97137 .62002 Mdot
.83168 .70645 Mdot
.06871 .27708 Mdot
.38259 .78028 Mdot
.65576 .98841 Mdot
.53725 .5551 Mdot
.97548 .13857 Mdot
.34537 .30818 Mdot
.57568 .77964 Mdot
.58937 .23443 Mdot
.23067 .02395 Mdot
.04206 .11638 Mdot
.05194 .68106 Mdot
.87042 .70614 Mdot
.13901 .71325 Mdot
.828 .83676 Mdot
.98086 .95717 Mdot
.0204 .0668 Mdot
.73166 .99441 Mdot
.04696 .88793 Mdot
.34407 .78032 Mdot
.03369 .56346 Mdot
.37583 .50755 Mdot
.4104 .5877 Mdot
.06871 .60106 Mdot
.26945 .5753 Mdot
.71042 .1481 Mdot
.80091 .96026 Mdot
.99584 .49299 Mdot
.44922 .57724 Mdot
.09198 .81068 Mdot
.59542 .06032 Mdot
.49783 .19906 Mdot
.25823 .23608 Mdot
.19005 .30184 Mdot
.08127 .06007 Mdot
.42138 .84022 Mdot
.69859 .0777 Mdot
.42882 .33918 Mdot
.14501 .39511 Mdot
.59392 .74585 Mdot
.55998 .92784 Mdot
.75866 .29038 Mdot
.00041 .72882 Mdot
.10134 .81406 Mdot
.4705 .63925 Mdot
.02817 .46031 Mdot
.80251 .51272 Mdot
.88337 .78534 Mdot
.89302 .54449 Mdot
.28806 .50551 Mdot
.98286 .93849 Mdot
.93978 .56972 Mdot
.86223 .29481 Mdot
.80993 .41988 Mdot
.01198 .89363 Mdot
.49422 .34735 Mdot
.13234 .93233 Mdot
.11545 .71966 Mdot
.06082 .76413 Mdot
.3989 .20061 Mdot
.93457 .98689 Mdot
.68304 .49593 Mdot
.68076 .78882 Mdot
.12384 .0537 Mdot
.90809 .78254 Mdot
.53479 .21002 Mdot
.19533 .63309 Mdot
.83629 .05406 Mdot
.40909 .91079 Mdot
.5408 .17957 Mdot
.01336 .7885 Mdot
.32013 .21731 Mdot
.83545 .15006 Mdot
.3912 .33343 Mdot
.90581 .08371 Mdot
.02286 .5207 Mdot
.46359 .61756 Mdot
.61369 .15011 Mdot
.57137 .70813 Mdot
.16971 .27485 Mdot
.36549 .97337 Mdot
.35222 .83826 Mdot
.70408 .82132 Mdot
.02467 .95348 Mdot
.69753 .98385 Mdot
.42419 .91588 Mdot
.069 .12728 Mdot
.62046 .95511 Mdot
.43663 .8525 Mdot
.83004 .1083 Mdot
.15923 .82467 Mdot
.04487 .60586 Mdot
.37534 .94898 Mdot
.53033 .49078 Mdot
.90918 .31476 Mdot
.54418 .62944 Mdot
.33924 .47677 Mdot
.02896 .07547 Mdot
.95523 .51426 Mdot
.54526 .80557 Mdot
.82672 .09388 Mdot
.53621 .01803 Mdot
.49554 .96285 Mdot
.86073 .18749 Mdot
.97092 .6926 Mdot
.09355 .51337 Mdot
.38451 .53056 Mdot
.80854 .10067 Mdot
.78623 .79346 Mdot
.07063 .76586 Mdot
.11721 .41955 Mdot
.72932 .01259 Mdot
.94348 .04063 Mdot
.91714 .26688 Mdot
.50764 .52459 Mdot
.13635 .42838 Mdot
.44811 .48748 Mdot
.80866 .16667 Mdot
.37989 .33651 Mdot
.6976 .33308 Mdot
.32924 .25422 Mdot
.91183 .41753 Mdot
.56095 .08805 Mdot
.93068 .95816 Mdot
.47445 .76839 Mdot
.80809 .91139 Mdot
.16343 .59527 Mdot
.83739 .0869 Mdot
.34694 .20397 Mdot
.71406 .1862 Mdot
.26668 .27224 Mdot
.36889 .1677 Mdot
.25829 .68782 Mdot
.53863 .07764 Mdot
.73884 .34968 Mdot
.48418 .7989 Mdot
.66101 .81536 Mdot
.90922 .18176 Mdot
.78505 .96158 Mdot
.35656 .45421 Mdot
.05254 .32416 Mdot
.13982 .06045 Mdot
.47603 .50541 Mdot
.24244 .02345 Mdot
.66326 .62537 Mdot
.00264 .78606 Mdot
.66983 .04165 Mdot
.29509 .14593 Mdot
.36306 .61395 Mdot
.57526 .55435 Mdot
.45977 .86406 Mdot
.57149 .51641 Mdot
.39803 .63491 Mdot
.36423 .22723 Mdot
.74634 .77609 Mdot
.94966 .4681 Mdot
.07361 .46107 Mdot
.33396 .90418 Mdot
.30213 .26468 Mdot
.79951 .95476 Mdot
.20451 .29573 Mdot
.47356 .00032 Mdot
.14578 .44983 Mdot
.78912 .87396 Mdot
.37106 .97153 Mdot
.55758 .19423 Mdot
.92155 .50366 Mdot
.45059 .67353 Mdot
.09622 .25086 Mdot
.56752 .91169 Mdot
.62339 .77973 Mdot
.6394 .17375 Mdot
.1557 .58339 Mdot
.89089 .46108 Mdot
.41095 .10598 Mdot
.88425 .35088 Mdot
.50529 .84567 Mdot
.441 .27628 Mdot
.92827 .49368 Mdot
.68508 .55912 Mdot
.58661 .51419 Mdot
.07501 .30913 Mdot
.35687 .52086 Mdot
.82789 .80283 Mdot
.06492 .13766 Mdot
.75179 .65084 Mdot
.03271 .22506 Mdot
.53594 .44371 Mdot
.0418 .236 Mdot
.07755 .26636 Mdot
.37374 .50665 Mdot
.6546 .55849 Mdot
.72866 .21867 Mdot
.43596 .45535 Mdot
.1249 .45703 Mdot
.00382 .581 Mdot
.86415 .21688 Mdot
.28281 .18455 Mdot
.09513 .19121 Mdot
.07026 .57652 Mdot
.38116 .24605 Mdot
.44679 .63958 Mdot
.14422 .37317 Mdot
.15551 .74773 Mdot
.18127 .50146 Mdot
.96774 .3323 Mdot
.35668 .76386 Mdot
.06506 .76189 Mdot
.29404 .76742 Mdot
.55583 .75859 Mdot
.91918 .2507 Mdot
.92265 .83542 Mdot
.2426 .3293 Mdot
.23332 .69676 Mdot
.47929 .71634 Mdot
.362 .61721 Mdot
.90134 .39989 Mdot
.22359 .98361 Mdot
.83552 .40077 Mdot
.10893 .98279 Mdot
.71238 .88458 Mdot
.31976 .63946 Mdot
.55715 .50244 Mdot
.51452 .44593 Mdot
.02986 .34023 Mdot
.16367 .01676 Mdot
.99956 .03086 Mdot
.01742 .69691 Mdot
.68696 .46903 Mdot
.74819 .37004 Mdot
.26971 .14397 Mdot
.84232 .07911 Mdot
.19837 .48513 Mdot
.35738 .92066 Mdot
.93895 .93896 Mdot
.88417 .74747 Mdot
.49042 .28985 Mdot
.89675 .41614 Mdot
.83159 .52915 Mdot
.50675 .89444 Mdot
.86556 .34991 Mdot
.48081 .79735 Mdot
.05815 .936 Mdot
.9022 .27585 Mdot
.37717 .64947 Mdot
.46377 .85516 Mdot
.81107 .35497 Mdot
.78561 .3279 Mdot
.06 .00187 Mdot
.0001 .75512 Mdot
.35843 .0519 Mdot
.33099 .38562 Mdot
.79435 .95117 Mdot
.68129 .82155 Mdot
.14542 .39644 Mdot
.00315 .13226 Mdot
.32455 .09969 Mdot
.26324 .6073 Mdot
.80599 .32381 Mdot
.14057 .51114 Mdot
.54814 .85856 Mdot
.26971 .13381 Mdot
.45316 .2843 Mdot
.54505 .52324 Mdot
.4361 .03853 Mdot
.57493 .86068 Mdot
.66024 .79802 Mdot
.9546 .78046 Mdot
.97113 .05368 Mdot
.39513 .83571 Mdot
.95498 .91603 Mdot
.51614 .45576 Mdot
.62112 .88358 Mdot
.91302 .54378 Mdot
.04151 .76709 Mdot
.07967 .7267 Mdot
.84536 .33024 Mdot
.56742 .87676 Mdot
.0353 .17963 Mdot
.44171 .27316 Mdot
.21335 .43813 Mdot
.66661 .41373 Mdot
.09407 .72572 Mdot
.48094 .0877 Mdot
.38611 .63627 Mdot
.83308 .94075 Mdot
.21453 .62453 Mdot
.35522 .3342 Mdot
.13119 .41962 Mdot
.17084 .23886 Mdot
.46626 .0234 Mdot
.3655 .08973 Mdot
.56457 .66814 Mdot
.39975 .48238 Mdot
.32841 .32831 Mdot
.64881 .09418 Mdot
.00555 .92652 Mdot
.19964 .85926 Mdot
.08829 .16211 Mdot
.92019 .93536 Mdot
.55655 .98223 Mdot
.21957 .35603 Mdot
.31937 .87465 Mdot
.44706 .42183 Mdot
.08775 .30906 Mdot
.34911 .21727 Mdot
.28267 .81498 Mdot
.34571 .01234 Mdot
.03641 .10847 Mdot
.19363 .82328 Mdot
.12631 .37312 Mdot
.38249 .05554 Mdot
.82697 .61612 Mdot
.53961 .47365 Mdot
.65758 .60543 Mdot
.90582 .32415 Mdot
.06898 .43695 Mdot
.58542 .81991 Mdot
.38957 .53383 Mdot
.98098 .20568 Mdot
.10561 .10794 Mdot
.07261 .1335 Mdot
.18771 .07771 Mdot
.73493 .18106 Mdot
.6946 .62492 Mdot
.45466 .87575 Mdot
.80808 .9564 Mdot
.42174 .72666 Mdot
.01418 .69564 Mdot
.96665 .65727 Mdot
.87814 .92738 Mdot
.89344 .31875 Mdot
.26309 .49687 Mdot
.01231 .89528 Mdot
.30633 .35127 Mdot
.62767 .92368 Mdot
.2131 .96967 Mdot
.30922 .83667 Mdot
.26239 .6658 Mdot
.69756 .10857 Mdot
.08594 .37755 Mdot
.42676 .70343 Mdot
.48691 .76873 Mdot
.83116 .27996 Mdot
.27218 .42438 Mdot
.39618 .0638 Mdot
.2931 .81923 Mdot
.0837 .32922 Mdot
.86898 .62694 Mdot
.07865 .21121 Mdot
.44005 .63836 Mdot
.06722 .72642 Mdot
.97891 .58864 Mdot
.45774 .13659 Mdot
.24859 .52437 Mdot
.96421 .29402 Mdot
.10054 .5487 Mdot
.13835 .04129 Mdot
.07614 .55047 Mdot
.22487 .01528 Mdot
.97654 .67653 Mdot
.44518 .5216 Mdot
.92154 .81978 Mdot
.22334 .52975 Mdot
.39651 .42424 Mdot
.07126 .54657 Mdot
.97495 .12381 Mdot
.8821 .60629 Mdot
.11717 .79058 Mdot
.92361 .24572 Mdot
.36445 .10496 Mdot
.93955 .53778 Mdot
.22451 .11129 Mdot
.58295 .68972 Mdot
.08458 .65783 Mdot
.11929 .21857 Mdot
.95676 .04026 Mdot
.53427 .75472 Mdot
.86329 .14505 Mdot
.37253 .55889 Mdot
.38306 .57551 Mdot
.39172 .85325 Mdot
.36382 .20944 Mdot
.73791 .773 Mdot
.49572 .86428 Mdot
.4596 .11207 Mdot
.11566 .39112 Mdot
.45229 .81185 Mdot
.47975 .76164 Mdot
.6983 .22898 Mdot
.95062 .44538 Mdot
.35936 .96319 Mdot
.0993 .00857 Mdot
.28053 .35325 Mdot
.4926 .98544 Mdot
.34868 .38143 Mdot
.32156 .78005 Mdot
.19575 .56621 Mdot
.93101 .06757 Mdot
.93174 .58213 Mdot
.35251 .57343 Mdot
.14406 .00984 Mdot
.67643 .00819 Mdot
.33965 .709 Mdot
.96733 .68625 Mdot
.39245 .60233 Mdot
.12521 .92754 Mdot
.81381 .48146 Mdot
.1277 .4031 Mdot
.98586 .07421 Mdot
.00504 .6211 Mdot
.20924 .30184 Mdot
.3001 .74441 Mdot
.43073 .67177 Mdot
.87362 .8874 Mdot
.83092 .70943 Mdot
.15727 .78935 Mdot
.65517 .35791 Mdot
.6457 .53993 Mdot
.02355 .17027 Mdot
.77894 .8058 Mdot
.79503 .87334 Mdot
.70897 .73924 Mdot
.58914 .36989 Mdot
.88335 .72785 Mdot
.5706 .88967 Mdot
.40232 .07474 Mdot
.5286 .09355 Mdot
.01828 .58451 Mdot
.40808 .94866 Mdot
.62725 .27129 Mdot
.80529 .03054 Mdot
.61914 .06967 Mdot
.74279 .89073 Mdot
.27138 .04856 Mdot
.75657 .4196 Mdot
.06556 .12124 Mdot
.47345 .76409 Mdot
.03954 .77588 Mdot
.77353 .37413 Mdot
.72094 .51738 Mdot
.10716 .82267 Mdot
.39428 .57026 Mdot
.71636 .96877 Mdot
.39751 .13418 Mdot
.66603 .25872 Mdot
.19898 .91199 Mdot
.21565 .18168 Mdot
.81071 .57011 Mdot
.32281 .71337 Mdot
.52912 .55361 Mdot
.84145 .09248 Mdot
.6798 .23305 Mdot
.3501 .99989 Mdot
.63675 .09419 Mdot
.6327 .35311 Mdot
.87635 .00378 Mdot
.77917 .76877 Mdot
.02494 .88984 Mdot
.93702 .8987 Mdot
.67245 .16492 Mdot
.64152 .45512 Mdot
.95983 .31915 Mdot
.56735 .02059 Mdot
.57144 .80681 Mdot
.44736 .74706 Mdot
.50613 .09249 Mdot
.44444 .85129 Mdot
.0432 .29723 Mdot
.52622 .69395 Mdot
.23451 .1645 Mdot
.37744 .16192 Mdot
.08949 .2574 Mdot
.0799 .53157 Mdot
.88498 .60413 Mdot
.10046 .67061 Mdot
.66237 .49118 Mdot
.04696 .5274 Mdot
.94294 .78746 Mdot
.39472 .59584 Mdot
.32355 .66445 Mdot
.53761 .09374 Mdot
.22607 .35228 Mdot
.32431 .67456 Mdot
.91659 .83703 Mdot
.09969 .96443 Mdot
.17336 .00168 Mdot
.82977 .54489 Mdot
.30061 .1866 Mdot
.84047 .1062 Mdot
.13838 .67556 Mdot
.08544 .28911 Mdot
.15654 .37383 Mdot
.57441 .35792 Mdot
.59161 .69302 Mdot
.26406 .26655 Mdot
.43486 .16515 Mdot
.99225 .03069 Mdot
.57714 .94648 Mdot
.61783 .35216 Mdot
.04972 .34679 Mdot
.87138 .54661 Mdot
.24561 .90058 Mdot
.06609 .41284 Mdot
.86516 .74834 Mdot
.29729 .5005 Mdot
.57774 .67621 Mdot
.02434 .95939 Mdot
.83904 .67252 Mdot
.88188 .53369 Mdot
.5748 .02253 Mdot
.09204 .90761 Mdot
.30487 .24202 Mdot
.25074 .68272 Mdot
.31925 .49251 Mdot
.47407 .0184 Mdot
.15457 .0657 Mdot
.00085 .79962 Mdot
.47476 .00283 Mdot
.52191 .14048 Mdot
.88738 .60004 Mdot
.85403 .44932 Mdot
.34728 .88636 Mdot
.59543 .17761 Mdot
.92675 .14096 Mdot
.43909 .1706 Mdot
.57915 .88356 Mdot
.21185 .45702 Mdot
.79991 .99338 Mdot
.06083 .3548 Mdot
.97945 .51995 Mdot
.11724 .40656 Mdot
.41865 .18217 Mdot
.63548 .16829 Mdot
.8117 .16082 Mdot
.73924 .15433 Mdot
.20582 .8865 Mdot
.44003 .71233 Mdot
.14763 .13472 Mdot
.54983 .66421 Mdot
.19954 .96136 Mdot
.21272 .04645 Mdot
.57655 .74263 Mdot
.57599 .00252 Mdot
.18649 .73323 Mdot
.31271 .10005 Mdot
.22869 .19358 Mdot
.36387 .07343 Mdot
.26783 .80308 Mdot
.75212 .5462 Mdot
.93222 .22306 Mdot
.604 .66782 Mdot
.85907 .5601 Mdot
.15429 .71879 Mdot
.20459 .963 Mdot
.3626 .69446 Mdot
.18075 .94642 Mdot
.00945 .801 Mdot
.5993 .83489 Mdot
.916 .08843 Mdot
.60841 .48397 Mdot
.85532 .35882 Mdot
.53051 .88677 Mdot
.42152 .46525 Mdot
.76708 .83736 Mdot
.53526 .90945 Mdot
.38748 .04665 Mdot
.04119 .5685 Mdot
.4701 .79895 Mdot
.23266 .41758 Mdot
.5791 .64035 Mdot
.09037 .63997 Mdot
.17097 .53044 Mdot
.50627 .97401 Mdot
.51568 .88552 Mdot
.87293 .15601 Mdot
.12112 .29201 Mdot
.13607 .05342 Mdot
.32908 .47504 Mdot
.3969 .82473 Mdot
.70864 .92168 Mdot
.9435 .58733 Mdot
.73062 .97597 Mdot
.14549 .87487 Mdot
.93658 .30899 Mdot
.8015 .05058 Mdot
.8752 .21958 Mdot
.69496 .59492 Mdot
.15088 .14551 Mdot
.30028 .25039 Mdot
.93017 .86002 Mdot
.24376 .19803 Mdot
.98759 .63449 Mdot
.06591 .68896 Mdot
.99862 .92883 Mdot
.25644 .74864 Mdot
.584 .94953 Mdot
.63241 .86621 Mdot
.72895 .37953 Mdot
.80074 .57494 Mdot
.27776 .56752 Mdot
.56164 .9868 Mdot
.62074 .01385 Mdot
.08901 .17081 Mdot
.91482 .07071 Mdot
.8475 .5913 Mdot
.66217 .86227 Mdot
.43237 .7347 Mdot
.91805 .84939 Mdot
.30272 .08061 Mdot
.2763 .6867 Mdot
.28012 .43662 Mdot
.73339 .85666 Mdot
.11647 .67576 Mdot
.33265 .11378 Mdot
.96421 .36426 Mdot
.20847 .44233 Mdot
.44078 .95044 Mdot
.9371 .76971 Mdot
.97646 .58842 Mdot
.80927 .55219 Mdot
.43546 .1961 Mdot
.31085 .14704 Mdot
.95174 .54698 Mdot
.32724 .02601 Mdot
.20658 .05856 Mdot
.07839 .63776 Mdot
.80335 .54395 Mdot
.55531 .60092 Mdot
.53911 .78153 Mdot
.01331 .69557 Mdot
.15582 .5729 Mdot
.97443 .84784 Mdot
.09171 .12383 Mdot
.96041 .3733 Mdot
.00668 .32831 Mdot
.48075 .51295 Mdot
.06453 .96894 Mdot
.00055 .61877 Mdot
.82026 .06378 Mdot
.63506 .71317 Mdot
.57402 .46173 Mdot
.83511 .41956 Mdot
.05636 .13034 Mdot
.7816 .23984 Mdot
.32308 .8124 Mdot
.17771 .8008 Mdot
.70757 .76829 Mdot
.55077 .69612 Mdot
.46294 .60498 Mdot
.28072 .23932 Mdot
.93185 .76214 Mdot
.01319 .36149 Mdot
.09297 .01465 Mdot
.20706 .16363 Mdot
.20693 .00843 Mdot
.63191 .55343 Mdot
.67762 .02345 Mdot
.36362 .97657 Mdot
.0916 .45479 Mdot
.04482 .24621 Mdot
.81806 .82239 Mdot
.56997 .65321 Mdot
.64908 .36348 Mdot
.97029 .94734 Mdot
.70824 .16854 Mdot
.1367 .11966 Mdot
.33316 .72491 Mdot
.61428 .23841 Mdot
.33914 .51634 Mdot
.12629 .46486 Mdot
.0243 .07259 Mdot
.68443 .75262 Mdot
.31994 .62752 Mdot
.26599 .94918 Mdot
.5974 .99663 Mdot
.90219 .58386 Mdot
.09447 .31109 Mdot
.07658 .95227 Mdot
.55875 .30758 Mdot
.76508 .27902 Mdot
.29461 .70835 Mdot
.42964 .98661 Mdot
.15864 .70539 Mdot
.06966 .58618 Mdot
.48072 .43527 Mdot
.49248 .4617 Mdot
.66383 .1206 Mdot
.85846 .06597 Mdot
.3744 .54597 Mdot
.85496 .37064 Mdot
.48351 .4369 Mdot
.94278 .72846 Mdot
.43859 .44916 Mdot
.23772 .85861 Mdot
.51184 .94368 Mdot
.34875 .73321 Mdot
.94964 .33148 Mdot
.70331 .91205 Mdot
.40545 .58139 Mdot
.07892 .26219 Mdot
.8486 .76075 Mdot
.65545 .09144 Mdot
.15434 .66364 Mdot
.56082 .21199 Mdot
.07852 .35689 Mdot
.99067 .01019 Mdot
.04245 .62137 Mdot
.15168 .06591 Mdot
.48988 .94685 Mdot
.85407 .3226 Mdot
.75775 .29213 Mdot
.44191 .83575 Mdot
.14915 .15827 Mdot
.0639 .97167 Mdot
.8477 .41739 Mdot
.40871 .12737 Mdot
.06586 .17933 Mdot
.58143 .88103 Mdot
.62356 .01045 Mdot
.16597 .71055 Mdot
.40328 .15765 Mdot
.48908 .58819 Mdot
.22217 .60781 Mdot
.87669 .46217 Mdot
.51561 .63261 Mdot
.14612 .79284 Mdot
.50303 .9058 Mdot
.5387 .98838 Mdot
.75976 .3449 Mdot
.97521 .92284 Mdot
.43462 .80698 Mdot
.24012 .94798 Mdot
.24311 .31665 Mdot
.87206 .77521 Mdot
.04463 .62568 Mdot
.61689 .97801 Mdot
.83837 .11351 Mdot
.80708 .83616 Mdot
.05713 .38807 Mdot
.55024 .11541 Mdot
.071 .83424 Mdot
.27133 .60404 Mdot
.06212 .35473 Mdot
.34789 .27367 Mdot
.5407 .14828 Mdot
.73763 .9341 Mdot
.79359 .25754 Mdot
.82208 .22254 Mdot
.16542 .73786 Mdot
.10643 .9863 Mdot
.81024 .64211 Mdot
.89433 .07285 Mdot
.50099 .56242 Mdot
.40091 .7443 Mdot
.63346 .072 Mdot
.2489 .1501 Mdot
.94217 .05554 Mdot
.29156 .85502 Mdot
.62692 .67775 Mdot
.4171 .04886 Mdot
.6169 .52122 Mdot
.3167 .81229 Mdot
.4356 .11749 Mdot
.25206 .91434 Mdot
.6408 .86901 Mdot
.16998 .47098 Mdot
.22147 .55864 Mdot
.20669 .10422 Mdot
.0987 .75042 Mdot
.8244 .89854 Mdot
.40522 .44345 Mdot
.77006 .28446 Mdot
.02366 .72229 Mdot
.05878 .34346 Mdot
.33637 .23777 Mdot
.15373 .57164 Mdot
.80581 .71058 Mdot
.46737 .39387 Mdot
.4028 .80108 Mdot
.74993 .03709 Mdot
.56971 .63584 Mdot
.55801 .85722 Mdot
.4764 .47833 Mdot
.01171 .87272 Mdot
.30347 .15622 Mdot
.74493 .31212 Mdot
.26447 .65637 Mdot
.90206 .46501 Mdot
.55541 .17295 Mdot
.82206 .33494 Mdot
.96014 .8416 Mdot
.5515 .98285 Mdot
.07056 .35832 Mdot
.84889 .43153 Mdot
.85922 .60892 Mdot
.12443 .99947 Mdot
.18573 .82058 Mdot
.22561 .89388 Mdot
.23246 .84802 Mdot
.71776 .29415 Mdot
.05562 .41366 Mdot
.43691 .19766 Mdot
.2958 .00854 Mdot
.01838 .89296 Mdot
.96533 .7079 Mdot
.50156 .1314 Mdot
.37336 .10815 Mdot
.1294 .36626 Mdot
.13691 .04065 Mdot
.16295 .81545 Mdot
.25375 .4562 Mdot
.2236 .32575 Mdot
.91949 .72266 Mdot
.1927 .31723 Mdot
.97846 .71208 Mdot
.75358 .62557 Mdot
.80605 .09119 Mdot
.71104 .05843 Mdot
.61718 .17967 Mdot
.18615 .82907 Mdot
.07107 .80447 Mdot
.22563 .87164 Mdot
.22152 .77461 Mdot
.79263 .39732 Mdot
.05675 .65822 Mdot
.94489 .40768 Mdot
.86145 .25151 Mdot
.78354 .48047 Mdot
.89538 .05955 Mdot
.42915 .21317 Mdot
.44951 .08249 Mdot
.09331 .60995 Mdot
.13279 .43291 Mdot
.8157 .45518 Mdot
.29905 .87995 Mdot
.47532 .67284 Mdot
.01544 .05831 Mdot
.25139 .65472 Mdot
.91952 .01299 Mdot
.75918 .82454 Mdot
.87897 .64636 Mdot
.1935 .80465 Mdot
.10773 .82144 Mdot
.96242 .99053 Mdot
.65354 .81711 Mdot
.06439 .81356 Mdot
.49738 .73839 Mdot
.93195 .32895 Mdot
.81786 .90417 Mdot
.23829 .77057 Mdot
.10486 .6725 Mdot
.85633 .88986 Mdot
.96346 .36613 Mdot
.44516 .25256 Mdot
.70931 .15491 Mdot
.26429 .0175 Mdot
.27282 .72883 Mdot
.26345 .88999 Mdot
.30034 .25553 Mdot
.61281 .71377 Mdot
.31125 .0543 Mdot
.16043 .49723 Mdot
.50387 .04294 Mdot
.62138 .11235 Mdot
.75476 .01228 Mdot
.05906 .07151 Mdot
.88453 .55418 Mdot
.18668 .93469 Mdot
.8863 .12455 Mdot
.5425 .79742 Mdot
.20818 .07965 Mdot
.09167 .29079 Mdot
.56741 .67072 Mdot
.77222 .62555 Mdot
.92906 .2391 Mdot
.91506 .62525 Mdot
.428 .0095 Mdot
.50066 .86183 Mdot
.93572 .21569 Mdot
.51011 .86251 Mdot
.30598 .18036 Mdot
.32617 .78192 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00Co0000ooooool0003o00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00Cooooo0_l00008ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool01?l0
003oooooooooooooool2o`000003ooooool0003o000000Oooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`05ooooo`;o00001oooool00ol0003oooooooooo`04ooooo`;o00001oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0
003oooooooooo`0=ooooo`04o`000?oooooo0000o`0000cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`04ooooo`;o00002?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00gooooo00Co0000oooooooooooooooo0_l000000ooooooo0000o`000007ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool01Oooool2o`0000Oooooo00?o0000ooooooooool01?oo
ool2o`0000Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`;o00001_oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_oo
ool001kooooo00?o0000ooooooooool07?ooool2o`0000gooooo0_l0000Booooo`;o00006oooool2
o`0002Wooooo0_l0000nooooo`;o00003oooool2o`0006Cooooo0_l00007ooooo`007_ooool00ol0
003oooooooooo`0Looooo`;o00003Oooool2o`0001;ooooo0_l0000Kooooo`;o00003_ooool2o`00
01Wooooo0_l0000nooooo`;o00003oooool2o`0000oooooo0_l00006ooooo`;o0000=?ooool2o`00
01Gooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o00005Oooool2o`0001;o
oooo0_l0000Uooooo`;o0000F?ooool2o`0001Oooooo0_l00008ooooo`;o00001_ooool2o`0003Co
oooo0_l0000Nooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o00005Oooool2o`0001;ooooo
0_l0000;ooooo`;o0000@_ooool2o`0001;ooooo0_l0000Jooooo`;o00005oooool2o`0006Kooooo
000Nooooo`03o`000?oooooooooo05;ooooo0_l00012ooooo`;o00004_ooool2o`0000Sooooo0_l0
00000ooooooo0000o`00002>ooooo`007_ooool00ol0003oooooooooo`17ooooo`;o00000_ooool2
o`0001Wooooo0_l0000[ooooo`;o00007oooool2o`000003ooooool0003o000001oooooo0_l0001]
ooooo`007_ooool00ol0003oooooooooo`17ooooo`;o00000_ooool2o`0001Wooooo0_l0000[oooo
o`;o0000@oooool2o`0006gooooo000Nooooo`03o`000?oooooooooo0?oooooo0oooool2o`0002[o
oooo0_l0000>ooooo`;o000000?oooooo`000?l000001?ooool001kooooo00?o0000ooooooooool0
ooooool3ooooo`;o0000:_ooool2o`0000kooooo0_l000000ooooooo0000o`000004ooooo`007_oo
ool00ol0003oooooooooo`3`ooooo`;o0000EOooool001kooooo00?o0000ooooooooool0:?ooool3
o`0005oooooo0_l0001Tooooo`;o0000?Oooool2o`0000;ooooo0_l0000Booooo`007_ooool00ol0
003oooooooooo`0Xooooo`?o0000Goooool2o`0001Cooooo0_l0000dooooo`;o0000Eoooool2o`00
00;ooooo0_l0000Booooo`007_ooool00ol0003oooooooooo`11ooooo`;o0000=oooool2o`0002Co
oooo0_l0000dooooo`;o0000Koooool001kooooo00?o0000ooooooooool0@Oooool2o`00017ooooo
0_l0000Tooooo`;o00001oooool2o`0007_ooooo0_l00015ooooo`007_ooool2o`0002Gooooo0_l0
0002ooooo`;o0000:_ooool2o`0001[ooooo0_l0000Aooooo`;o0000Noooool2o`0002[ooooo0_l0
000:ooooo`;o00003Oooool001kooooo00?o0000ooooooooool09?ooool2o`0000;ooooo0_l0000g
ooooo`;o00003Oooool2o`0000Kooooo0_l0002Booooo`;o00007_ooool4o`0000Sooooo0_l0000=
ooooo`007_ooool01?l0003oooooooooooooool2o`0003cooooo0_l0000Pooooo`;o00005Oooool2
o`0006Wooooo0_l0000Wooooo`;o00004Oooool2o`0000gooooo0_l0000Gooooo`007_ooool01?l0
003oooooooooooooool2o`0001?ooooo0_l0000Aooooo`;o00005?ooool2o`0001?ooooo0_l0001W
ooooo`;o00009?ooool2o`0003[ooooo0_l0000Vooooo`007_ooool00ol0003oooooooooo`0Foooo
o`;o00004Oooool2o`0000;ooooo0ol0000Tooooo`;o00009oooool2o`0003kooooo0_l00018oooo
o`;o00002_ooool2o`00013ooooo0_l0000Pooooo`007_ooool00ol0003oooooooooo`03ooooo`;o
0000:?ooool3o`0004gooooo0_l00028ooooo`;o00002_ooool2o`00013ooooo0_l00004ooooo`;o
00006_ooool001kooooo00?o0000ooooooooool00oooool2o`0000[ooooo0_l0002dooooo`;o0000
0oooool2o`0005Wooooo0_l00004ooooo`;o00006_ooool001kooooo00?o0000ooooooooool01?oo
ool2o`0000Wooooo0_l0001Qooooo`;o00002oooool2o`0004Cooooo0_l00003ooooo`;o0000Dooo
ool2o`0000Cooooo0_l0000Eooooo`;o00002Oooool001kooooo00?o0000ooooooooool01?ooool3
o`0003;ooooo0_l0000gooooo`;o00002oooool2o`0002[ooooo0_l0000booooo`;o0000?_ooool2
o`0001_ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`05ooooo`;o0000<_ooool2o`00
00Gooooo0_l0000Looooo`;o0000Boooool2o`0003;ooooo0_l0000]ooooo`;o0000=oooool001ko
oooo00?o0000ooooooooool0@?ooool2o`0001cooooo0_l0000^ooooo`;o0000O_ooool2o`0001;o
oooo0_l0000Sooooo`007_ooool00ol0003oooooooooo`2>ooooo`;o0000O?ooool2o`0001Cooooo
0_l0000Sooooo`007_ooool00ol0003oooooooooo`1cooooo`;o00008oooool2o`0001Sooooo0_l0
001Hooooo`;o00006?ooool2o`0000_ooooo0_l0000Booooo`007_ooool00ol0003oooooooooo`1c
ooooo`;o00008oooool2o`0000Kooooo0_l00006ooooo`;o00002?ooool2o`0001gooooo0_l0000_
ooooo`Co00001oooool2o`0001Oooooo0_l0000;ooooo`;o00001Oooool2o`0000_ooooo000Noooo
o`03o`000?oooooooooo0:3ooooo0_l00006ooooo`;o000000?oooooo`000?l000007_ooool2o`00
00;ooooo1?l0000_ooooo`Co00000oooool2o`0000;ooooo0_l0000[ooooo`;o00002oooool001ko
oooo00?o0000ooooooooool0IOooool2o`0004Cooooo0_l0000Nooooo`;o00000_ooool2o`0003So
oooo0_l0000looooo`007_ooool2o`0006?ooooo0_l000000ooooooo0000o`00000Dooooo`;o0000
Q_ooool2o`0004;ooooo000Nooooo`03o`000?oooooooooo03oooooo0_l0000Qooooo`;o00003_oo
ool2o`0000Oooooo0_l00004ooooo`;o0000P?ooool2o`0004;ooooo000Nooooo`03o`000?oooooo
oooo00Sooooo0_l0000Dooooo`;o00007oooool2o`00037ooooo0_l000000ooooooo0000o`00000:
ooooo`;o0000@oooool2o`0001Oooooo0_l0000Yooooo`;o000000?oooooo`000?l00000>?ooool0
01kooooo00?o0000ooooooooool02?ooool2o`0001Cooooo0_l0000Uooooo`;o0000;_ooool2o`00
01[ooooo0_l0000cooooo`;o00005oooool2o`0002Wooooo0_l000000ooooooo0000o`00000hoooo
o`007_ooool00ol0003oooooooooo`15ooooo`;o00008Oooool2o`0002Oooooo0_l000000ooooooo
0000o`00000`ooooo`;o0000A?ooool2o`0003Wooooo000Nooooo`03o`000?oooooooooo00[ooooo
0_l0001Looooo`;o00008?ooool2o`0000Sooooo0_l0000Iooooo`;o00005Oooool2o`0004Cooooo
0_l0000iooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o00001Oooool2o`0001Gooooo0_l0
001Pooooo`;o00008oooool2o`0002?ooooo0_l0001aooooo`007_ooool00ol0003oooooooooo`0A
ooooo`;o00001oooool2o`0000cooooo0_l0002Zooooo`;o0000Hoooool2o`0000cooooo000Noooo
o`03o`000?oooooooooo01;ooooo0_l00006ooooo`;o0000IOooool2o`0009Wooooo0_l0000Koooo
o`;o00003?ooool001kooooo00?o0000ooooooooool03_ooool2o`0000;ooooo0_l0001]ooooo`;o
0000VOooool2o`0002Wooooo000Nooooo`;o00003oooool2o`0000?ooooo0_l0002:ooooo`;o0000
Y_ooool001kooooo0_l0000Dooooo`;o00005oooool2o`0002Kooooo0_l000000ooooooo0000o`00
000Tooooo`;o00004_ooool2o`0000cooooo0_l0001dooooo`;o0000<?ooool001kooooo00?o0000
ooooooooool04Oooool2o`0001Wooooo0_l0000Vooooo`;o000000?oooooo`000?l000009?ooool2
o`0001;ooooo0_l00022ooooo`;o00008_ooool2o`0000cooooo000Nooooo`03o`000?oooooooooo
017ooooo0_l0002Cooooo`;o0000POooool2o`0000kooooo0_l0000<ooooo`007_ooool00ol0003o
ooooooooo`0]ooooo`;o00005?ooool2o`0000oooooo0_l00006ooooo`;o0000B?ooool2o`0006go
oooo0_l0000Booooo`;o00007?ooool001kooooo00?o0000ooooooooool0;Oooool2o`0001Cooooo
0_l0000?ooooo`;o00001_ooool2o`0000?ooooo0_l00019ooooo`;o0000=Oooool2o`00033ooooo
0_l0000`ooooo`007_ooool2o`0004kooooo0_l0000Booooo`;o0000BOooool2o`0001Gooooo0_l0
000Nooooo`;o00009oooool2o`0003Wooooo000Nooooo`03o`000?oooooooooo04gooooo0_l0000B
ooooo`;o0000H?ooool2o`0001gooooo0_l00008ooooo`;o00001Oooool2o`0001Oooooo0_l0000i
ooooo`007_ooool00ol0003oooooooooo`0/ooooo`;o0000<Oooool2o`0001kooooo0_l0001Qoooo
o`;o00002?ooool2o`0000Gooooo0_l0000Sooooo`;o0000;Oooool001kooooo00?o0000oooooooo
ool0;?ooool2o`00037ooooo0_l0000Nooooo`;o0000Poooool2o`0001;ooooo0_l0000]ooooo`00
7_ooool00ol0003oooooooooo`0Iooooo`;o00009?ooool2o`0003Kooooo0_l0002;ooooo`;o0000
@Oooool001kooooo00?o0000ooooooooool06Oooool2o`0002Cooooo0_l00007ooooo`;o0000;Ooo
ool2o`00013ooooo0_l0001<ooooo`;o00000oooool2o`0002Gooooo0_l00012ooooo`007_ooool0
0ol0003oooooooooo`04ooooo`;o0000@_ooool2o`0002[ooooo0_l0000Cooooo`Co0000?Oooool2
o`0000_ooooo0_l00003ooooo`;o00001?ooool2o`0001oooooo0_l0000Rooooo`;o00007_ooool0
01kooooo00?o0000ooooooooool01?ooool2o`0001?ooooo0_l0001Iooooo`;o00005Oooool2o`00
02?ooooo0_l0000Hooooo`;o00005_ooool2o`0004?ooooo0_l0000Nooooo`007_ooool00ol0003o
ooooooooo`0Iooooo`;o0000UOooool2o`0001[ooooo0_l0001iooooo`007_ooool00ol0003ooooo
ooooo`07ooooo`;o00002?ooool2o`0009Wooooo0_l0000?ooooo`;o00001_ooool2o`0000Gooooo
0_l0001iooooo`007_ooool00ol0003oooooooooo`07ooooo`;o00002?ooool2o`0002oooooo0_l0
000Kooooo`;o00008oooool2o`0002Kooooo0_l0000?ooooo`;o00001_ooool2o`0002Cooooo0_l0
000fooooo`;o00008_ooool001kooooo00?o0000ooooooooool0@_ooool2o`0001Cooooo0_l00005
ooooo`;o00008oooool2o`0006Gooooo0_l0000Kooooo`;o00006Oooool2o`0002;ooooo000Noooo
o`03o`000?oooooooooo05Sooooo0_l00004ooooo`;o0000Q?ooool2o`0002;ooooo0_l0000:oooo
o`;o0000<Oooool001kooooo00?o0000ooooooooool06oooool2o`00047ooooo0_l00024ooooo`;o
0000;_ooool2o`00037ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo1Ol00006ooooo`03o`000?oooooooooo01_ooooo0_l0000Yooooo`;o0000JOooool2o`0009Co
oooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A006ooooo`03o`000?oooooooooo04Kooooo0_l00003ooooo`;o0000??ooool3o`00
02Gooooo0_l0002Dooooo`000oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q
8Oo^k^h01oooool3o`0004_ooooo0_l0000aooooo`;o00002Oooool3o`0001;ooooo0_l0002Woooo
o`000oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0
003oooooooooo`1]ooooo`;o00003oooool2o`0001kooooo0_l0002Wooooo`000oooool01Ol0003o
oooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`1]oooo
o`;o0000c?ooool2o`0000[ooooo0003ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo013ooooo0_l0001Pooooo`;o0000=_ooool2o`00
08oooooo0_l0000:ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo013ooooo0_l00003ooooo`;o0000Foooool2
o`0001?ooooo0_l0000Qooooo`;o00001_ooool2o`0004[ooooo0_l00017ooooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oo
oooooooo01Gooooo0_l0001`ooooo`;o0000:Oooool2o`0004[ooooo0_l0000/ooooo`;o00006Ooo
ool001kooooo00?o0000ooooooooool08oooool2o`0003oooooo0_l00007ooooo`;o0000N_ooool2
o`0002[ooooo0_l000000ooooooo0000o`00000Booooo`;o00006Oooool001kooooo00?o0000oooo
ooooool08oooool2o`0003oooooo0_l00007ooooo`;o0000N_ooool2o`0001cooooo0_l0000<oooo
o`;o000000?oooooo`000?l00000;Oooool001kooooo00?o0000ooooooooool01oooool2o`000?ko
oooo0_l0000Rooooo`;o00006_ooool001kooooo00?o0000ooooooooool01oooool2o`0006Wooooo
0_l0001[ooooo`;o0000B_ooool2o`0001[ooooo000Nooooo`03o`000?oooooooooo07;ooooo0_l0
001[ooooo`;o0000I_ooool001kooooo00?o0000ooooooooool0^oooool2o`0001cooooo0_l0001/
ooooo`007_ooool00ol0003oooooooooo`09ooooo`;o0000AOooool2o`0001Oooooo0_l0001@oooo
o`;o00007?ooool2o`0006cooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0000Xooooo`;o
00006oooool2o`0000Gooooo0_l0000@ooooo`;o0000FOooool2o`0003Cooooo0_l0000^ooooo`;o
00006oooool001kooooo00?o0000ooooooooool0<oooool2o`0002;ooooo0_l00006ooooo`;o0000
Hoooool2o`0003Cooooo0_l0000^ooooo`;o00006oooool001kooooo00?o0000ooooooooool02_oo
ool2o`0005?ooooo0_l0000Gooooo`;o0000[_ooool2o`0001gooooo000Nooooo`03o`000?oooooo
oooo00[ooooo0_l0001Booooo`;o00006?ooool2o`000:kooooo0_l0000Mooooo`007_ooool2o`00
01cooooo0_l00011ooooo`;o0000;Oooool2o`0008Gooooo0_l0000Aooooo`;o00007_ooool001ko
oooo00?o0000ooooooooool06oooool2o`00047ooooo0_l00007ooooo`;o00009?ooool2o`0008Go
oooo0_l0000Aooooo`;o00007_ooool001kooooo00?o0000ooooooooool06Oooool2o`0004?ooooo
0_l00006ooooo`?o0000Joooool2o`0002Sooooo0_l00017ooooo`007_ooool00ol0003ooooooooo
o`0Fooooo`;o000000?oooooo`000?l00000Boooool2o`0006cooooo0_l0000Xooooo`;o0000Aooo
ool001kooooo00?o0000ooooooooool05_ooool2o`0004Kooooo0_l0003Wooooo`007_ooool00ol0
003oooooooooo`0Eooooo`;o0000>oooool2o`0000[ooooo0_l00036ooooo`;o00007oooool001ko
oooo00?o0000ooooooooool05Oooool2o`0003_ooooo0_l0001dooooo`;o0000G?ooool2o`0001oo
oooo000Nooooo`03o`000?oooooooooo03?ooooo0_l0000Nooooo`;o00006?ooool2o`0001cooooo
0_l0000kooooo`;o0000Loooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0
000Oooooo`;o00007_ooool2o`0001Sooooo0_l0000Looooo`;o0000U?ooool2o`0001[ooooo0_l0
0008ooooo`007_ooool00ol0003oooooooooo`0Booooo`;o0000Moooool2o`0006Sooooo0_l0000C
ooooo`;o00005Oooool2o`0002Cooooo000Nooooo`03o`000?oooooooooo08oooooo0_l0001Toooo
o`;o00004oooool2o`0003_ooooo000Nooooo`03o`000?oooooooooo08oooooo0_l0001Uooooo`;o
0000Coooool001kooooo00?o0000ooooooooool06?ooool2o`00087ooooo0_l0001Fooooo`;o0000
00?oooooo`000?l00000>?ooool2o`0001Gooooo000Nooooo`03o`000?oooooooooo00gooooo0_l0
0009ooooo`Co00001oooool2o`0006;ooooo0_l0000Booooo`;o0000EOooool3o`0003_ooooo0_l0
000Eooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o00002oooool2o`0000Oooooo0_l0000I
ooooo`;o0000Aoooool2o`0005cooooo0_l0000;ooooo`;o00008?ooool2o`0001oooooo0_l0000@
ooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o0000<_ooool2o`000:Gooooo0_l0000]oooo
o`;o00007oooool2o`00013ooooo000Nooooo`;o00002oooool2o`0002kooooo0_l00004ooooo`;o
0000ooooool6ooooo`007_ooool2o`0003_ooooo0_l00004ooooo`;o0000E_ooool2o`000:gooooo
000Nooooo`03o`000?oooooooooo06cooooo0_l0000Zooooo`;o00006?ooool2o`0007Sooooo0_l0
000Iooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o00000_ooool2o`000003ooooool0003o
000003;ooooo0_l0000Kooooo`;o0000A?ooool2o`0007Sooooo0_l0000Iooooo`007_ooool00ol0
003oooooooooo`0Dooooo`;o00000_ooool2o`000003ooooool0003o000003;ooooo0_l00018oooo
o`;o0000Doooool2o`0003?ooooo0_l0000Rooooo`007_ooool00ol0003oooooooooo`0kooooo`;o
00003_ooool2o`0004cooooo0_l0001Cooooo`;o0000<oooool2o`0002;ooooo000Nooooo`03o`00
0?oooooooooo03_ooooo0_l0000>ooooo`;o0000dOooool2o`0001Cooooo0_l0000Aooooo`007_oo
ool00ol0003oooooooooo`0=ooooo`;o0000loooool2o`0000kooooo0_l0000:ooooo`;o00000_oo
ool2o`00013ooooo0_l0000Aooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o0000=_ooool2
o`0003[ooooo0_l0001oooooo`;o00003_ooool2o`0000kooooo0_l0000Sooooo`007_ooool3o`00
01Oooooo0_l0000/ooooo`;o00001?ooool2o`0001[ooooo0_l0000Hooooo`;o0000N?ooool2o`00
01;ooooo0_l0000Jooooo`;o00006_ooool001kooooo0ol00005ooooo`;o00003_ooool4o`0003;o
oooo0_l0000Jooooo`;o00004_ooool2o`0006;ooooo0_l0000Jooooo`;o00004_ooool2o`0001[o
oooo0_l00004ooooo`;o00001?ooool2o`0000kooooo000Nooooo`03o`000?oooooooooo00Gooooo
0_l0000>ooooo`;o0000F?ooool2o`0000Kooooo0_l00002ooooo`;o0000H_ooool2o`0002Kooooo
0_l0000Xooooo`;o00001?ooool2o`0000kooooo000Nooooo`03o`000?oooooooooo06oooooo0_l0
0006ooooo`;o00003_ooool2o`0007kooooo0_l0000nooooo`007_ooool00ol0003oooooooooo`06
ooooo`;o0000Ooooool2o`000;kooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l00007oooo
o`;o0000h_ooool2o`0005;ooooo000Nooooo`03o`000?oooooooooo00cooooo0_l000000ooooooo
0000o`00002<ooooo`;o0000E?ooool2o`0005;ooooo000Nooooo`;o00003Oooool2o`00057ooooo
0_l0000looooo`;o0000COooool2o`0002Oooooo0_l00004ooooo`;o0000:_ooool001kooooo00?o
0000ooooooooool04?ooool2o`0003?ooooo0_l0000@ooooo`;o00001_ooool2o`0006Cooooo0_l0
0003ooooo`;o00008?ooool2o`0001Kooooo0_l0000?ooooo`;o00001?ooool2o`0002[ooooo000N
ooooo`03o`000?oooooooooo013ooooo0_l00003ooooo`;o0000;?ooool4o`00013ooooo0_l0001N
ooooo`;o00003?ooool2o`0000?ooooo0_l00005ooooo`;o0000<Oooool2o`0000Kooooo0_l0000i
ooooo`007_ooool00ol0003oooooooooo`0Cooooo`Co0000;?ooool2o`0007;ooooo0_l0000Hoooo
o`;o0000>Oooool2o`0000Cooooo0_l0000cooooo`007_ooool00ol0003oooooooooo`02o`00017o
oooo0_l0002jooooo`;o0000@Oooool2o`00027ooooo0_l0000@ooooo`007_ooool00ol0003ooooo
ooooo`02o`0002Cooooo0_l0002Wooooo`;o0000I?ooool2o`00013ooooo000Nooooo`03o`000?oo
oooooooo02Kooooo0_l0002Cooooo`;o0000<_ooool2o`0004Cooooo0_l0000@ooooo`007_ooool0
0ol0003oooooooooo`0Uooooo`;o00001?ooool2o`0008kooooo0_l0000booooo`;o00008Oooool2
o`00023ooooo0_l0000Aooooo`007_ooool00ol0003oooooooooo`0Uooooo`;o00001?ooool2o`00
00;ooooo0_l00036ooooo`;o00006Oooool2o`00023ooooo0_l0000Aooooo`007_ooool00ol0003o
ooooooooo`0Hooooo`;o00005Oooool2o`0000[ooooo0_l0002/ooooo`;o00003?ooool2o`0004ko
oooo000Nooooo`03o`000?oooooooooo01Sooooo0_l0000Qooooo`;o0000<?ooool2o`0007[ooooo
0_l0001Looooo`007_ooool00ol0003oooooooooo`0Oooooo`;o0000A_ooool2o`0000Cooooo0_l0
000Xooooo`;o0000[_ooool001kooooo00?o0000ooooooooool03_ooool2o`0000oooooo0_l00016
ooooo`;o00003oooool2o`0001gooooo0_l0002^ooooo`007_ooool00ol0003oooooooooo`0>oooo
o`;o00004Oooool2o`0005Gooooo0_l0003=ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0Qoooo
o`;o00002?ooool2o`0006Oooooo0_l0002aooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0:oooool2o`00
06Oooooo0_l0001Xooooo`;o0000Aoooool000?ooooo00Go410@oooooooooooooooooa0@400;oooo
o`Go00001_ooool3o`0002_ooooo0_l0003Aooooo`;o00003?ooool2o`0001?ooooo0_l0000Toooo
o`000oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool0
0ol0003oooooooooo`0Uooooo`;o0000iOooool2o`0001?ooooo0_l0000Tooooo`000oooool01Ol0
003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003ooooooooo
o`0Rooooo`;o000000?oooooo`000?l00000mOooool2o`0002Wooooo0003ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo02;ooooo0_l0
000Xooooo`;o0000c_ooool2o`00017ooooo0_l0000Fooooo`000oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0Aooooo`;o0000>Ooo
ool2o`000>7ooooo0_l0000Fooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?o
MgMgo`000?ooool01_ooool00ol0003oooooooooo`0>ooooo`;o000000?oooooo`000?l00000`_oo
ool2o`0004Sooooo0_l0000Vooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o00004_ooool2
o`0000?ooooo0_l0000Oooooo`;o0000Roooool2o`0001_ooooo0_l0000Gooooo`;o00000_ooool2
o`0000kooooo0_l00003ooooo`;o00008Oooool001kooooo00?o0000ooooooooool08_ooool2o`00
00?ooooo0_l0000Oooooo`;o0000@oooool2o`0006?ooooo0_l0000=ooooo`Co00001_ooool2o`00
00;ooooo0_l0000Cooooo`;o00008Oooool001kooooo00?o0000ooooooooool0E?ooool2o`0002Oo
oooo0_l0000>ooooo`;o0000L_ooool4o`0004;ooooo000Nooooo`03o`000?oooooooooo02Sooooo
0_l0000Zooooo`;o00009oooool2o`000<Sooooo000Nooooo`03o`000?oooooooooo02Sooooo0_l0
003Vooooo`;o0000=Oooool001kooooo00?o0000ooooooooool09oooool2o`000>Oooooo0_l0000e
ooooo`007_ooool00ol0003oooooooooo`0Booooo`;o00004oooool2o`0001Sooooo0_l0000Doooo
o`;o0000?oooool3o`000:cooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0000]ooooo`;o
00005?ooool2o`0003oooooo0ol0002/ooooo`007_ooool00ol0003oooooooooo`10ooooo`;o0000
?_ooool2o`0002Sooooo0_l0001Booooo`;o0000Aoooool001kooooo00?o0000ooooooooool0@?oo
ool2o`0003kooooo0_l0000Qooooo`;o00001Oooool2o`0005;ooooo0_l0000aooooo`;o00005?oo
ool001kooooo00?o0000ooooooooool0:oooool2o`0005gooooo0_l0000Gooooo`;o0000KOooool2
o`0001gooooo0_l0000Dooooo`007_ooool2o`0002cooooo0_l0001Mooooo`;o0000Q_ooool2o`00
03?ooooo000Nooooo`03o`000?oooooooooo01[ooooo0_l0000booooo`;o00008?ooool2o`0001So
oooo0_l0000Hooooo`;o00009_ooool2o`0003Oooooo0_l00010ooooo`007_ooool00ol0003ooooo
ooooo`0Jooooo`;o00002?ooool2o`0001_ooooo0_l00006ooooo`;o00000oooool2o`00023ooooo
0_l0000Hooooo`;o00006?ooool2o`0002Kooooo0_l0000gooooo`;o0000@?ooool001kooooo00?o
0000ooooooooool01Oooool2o`0000gooooo0_l0000>ooooo`;o00006oooool2o`0000Kooooo0_l0
001Aooooo`;o00006Oooool2o`00063ooooo0_l00003ooooo`;o00009oooool001kooooo00?o0000
ooooooooool01Oooool2o`0000gooooo0_l0000?ooooo`;o0000G_ooool2o`0001Gooooo0_l0000I
ooooo`;o0000H?ooool2o`0000?ooooo0_l000000ooooooo0000o`00000Tooooo`007_ooool00ol0
003oooooooooo`0Uooooo`;o0000G_ooool2o`0009[ooooo0_l0000>ooooo`;o00005?ooool001ko
oooo00?o0000ooooooooool0<oooool2o`0000[ooooo0_l0002Jooooo`;o0000E?ooool2o`0001Co
oooo000Nooooo`03o`000?oooooooooo03?ooooo0_l0000:ooooo`;o00009_ooool2o`0000_ooooo
0_l0000eooooo`;o0000;_ooool2o`0006[ooooo000Nooooo`03o`000?oooooooooo06Oooooo0_l0
00000ooooooo0000o`000008ooooo`;o0000=Oooool2o`0009[ooooo000Nooooo`03o`000?oooooo
oooo03gooooo0_l0000[ooooo`;o00005oooool2o`0001;ooooo0_l0001Rooooo`;o0000B_ooool0
01kooooo00?o0000ooooooooool0?Oooool2o`0003oooooo0_l00003ooooo`;o00004_ooool2o`00
00kooooo0_l0000Iooooo`;o0000=oooool2o`0000Oooooo0_l00011ooooo`007_ooool00ol0003o
ooooooooo`0looooo`;o0000@?ooool2o`0002Oooooo0_l0000Iooooo`;o0000@?ooool2o`00047o
oooo000Nooooo`03o`000?oooooooooo03cooooo0_l0001@ooooo`;o0000]oooool001kooooo00?o
0000ooooooooool0?oooool2o`0002?ooooo0_l0000Xooooo`;o00006?ooool2o`0002Wooooo0_l0
001[ooooo`;o00001Oooool001kooooo00?o0000ooooooooool0?oooool2o`0002?ooooo0_l00012
ooooo`;o0000:Oooool2o`0000Gooooo0_l0001>ooooo`;o00005?ooool2o`0000Gooooo000Noooo
o`03o`000?oooooooooo033ooooo0_l0000Oooooo`;o0000Qoooool2o`0004kooooo0_l0000Koooo
o`007_ooool2o`00037ooooo0_l00005ooooo`;o00006?ooool2o`0000[ooooo0_l0001Booooo`;o
0000U?ooool001kooooo00?o0000ooooooooool0=oooool2o`00027ooooo0_l000000ooooooo0000
o`00000hooooo`;o00006?ooool2o`0007Cooooo0_l0000Nooooo`007_ooool00ol0003ooooooooo
o`1Jooooo`;o00006Oooool3o`0001oooooo0_l0002>ooooo`;o00007_ooool001kooooo00?o0000
ooooooooool0:_ooool2o`0004Wooooo0ol0003?ooooo`007_ooool00ol0003oooooooooo`0Joooo
o`;o00003_ooool2o`0006cooooo0_l0000Qooooo`;o0000A?ooool2o`0002oooooo0_l0000Coooo
o`007_ooool00ol0003oooooooooo`0Eooooo`;o00000oooool2o`0004kooooo0_l0000/ooooo`;o
00007?ooool2o`0000?ooooo0_l0000Yooooo`;o00006Oooool2o`0002oooooo0_l0000Cooooo`00
7_ooool00ol0003oooooooooo`03ooooo`;o00004?ooool2o`0005?ooooo0_l00004ooooo`;o0000
A?ooool2o`0000cooooo0_l0000Pooooo`;o0000D_ooool2o`0000_ooooo000Nooooo`03o`000?oo
oooooooo00?ooooo0_l0001[ooooo`;o00006oooool2o`0001kooooo0_l0000=ooooo`;o00001_oo
ool2o`0007Cooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`1=ooooo`;o0000?_ooool2
o`0001;ooooo0_l0000:ooooo`;o00003Oooool2o`0008Wooooo000Nooooo`03o`000?oooooooooo
00_ooooo0_l0000Vooooo`;o00003oooool2o`0000Oooooo0_l0001Booooo`;o0000Ioooool2o`00
03_ooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l00009ooooo`;o00006oooool2o`0000oo
oooo0_l0000cooooo`;o0000Soooool2o`0003_ooooo000Nooooo`03o`000?oooooooooo01Kooooo
0_l0001Qooooo`Co0000=?ooool2o`0006Sooooo0_l0000Zooooo`007_ooool00ol0003ooooooooo
o`1kooooo`;o0000=?ooool2o`0006Sooooo0_l0000@ooooo`;o00006?ooool001kooooo00?o0000
ooooooooool0c_ooool2o`0005gooooo0_l0000Hooooo`007_ooool00ol0003oooooooooo`3>oooo
o`;o0000<Oooool2o`0000Oooooo0_l0000Booooo`;o00001Oooool2o`00023ooooo000Nooooo`03
o`000?oooooooooo01?ooooo0_l00008ooooo`;o0000Eoooool2o`0007Sooooo0_l0000?ooooo`;o
00001oooool2o`0000_ooooo0_l00005ooooo`;o00001Oooool2o`0000[ooooo0_l0000Dooooo`00
7_ooool2o`0001Cooooo1?l00006ooooo`;o0000Eoooool2o`0007Sooooo0_l0000Uooooo`;o0000
6?ooool2o`0001Cooooo000Nooooo`03o`000?oooooooooo01Gooooo0_l0002Aooooo`;o00003Ooo
ool2o`00013ooooo0_l0000hooooo`;o00005_ooool2o`0002[ooooo000Nooooo`03o`000?oooooo
oooo06Gooooo0_l00011ooooo`;o000000?oooooo`000?l000002_ooool2o`00013ooooo0_l0000h
ooooo`;o00005_ooool2o`0002[ooooo000Nooooo`03o`000?oooooooooo04Cooooo0_l0000Ooooo
o`;o00003_ooool2o`0003Cooooo0_l0000Tooooo`;o00002?ooool2o`0003Kooooo0_l0000boooo
o`007_ooool00ol0003oooooooooo`07ooooo`;o0000>oooool2o`0002oooooo0_l0000Xooooo`;o
0000<?ooool2o`0000Sooooo0_l0000fooooo`;o0000<_ooool001kooooo00?o0000ooooooooool0
1oooool2o`0003?ooooo0_l0001Qooooo`;o0000Y_ooool001kooooo00?o0000ooooooooool02Ooo
ool2o`00037ooooo0_l0000Hooooo`;o00009?ooool2o`0008Gooooo0_l0000Xooooo`;o00006?oo
ool001kooooo00?o0000ooooooooool02Oooool2o`0002?ooooo0ol0000Uooooo`;o00005_ooool2
o`0000cooooo0_l00025ooooo`;o0000:?ooool2o`0001Sooooo000Nooooo`03o`000?oooooooooo
01?ooooo0_l0000Iooooo`?o00008_ooool2o`0001Wooooo0_l00008ooooo`;o0000Q_ooool2o`00
04Gooooo000Nooooo`03o`000?oooooooooo01?ooooo0_l0000nooooo`;o00008oooool2o`0001Co
oooo0_l0001`ooooo`;o0000AOooool001kooooo0_l00021ooooo`;o00003?ooool2o`0009_ooooo
0_l0000Jooooo`007_ooool2o`0000?ooooo0_l0000[ooooo`;o0000Coooool2o`0009oooooo0_l0
0008ooooo`;o00006_ooool001kooooo00?o0000ooooooooool00_ooool2o`0000oooooo0_l0000J
ooooo`;o0000D?ooool2o`0000gooooo0_l00009ooooo`;o0000E_ooool2o`0000Gooooo0_l0000U
ooooo`;o00003?ooool2o`0000Sooooo0ol0000;ooooo`007_ooool00ol0003oooooooooo`0Coooo
o`;o0000K?ooool2o`0000gooooo0_l00009ooooo`;o0000E_ooool2o`0000Gooooo0_l0000Coooo
o`;o00007_ooool2o`0000Sooooo0ol0000;ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`3N
ooooo`;o0000;oooool2o`0003Kooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo037ooooo0_l0
0019ooooo`;o0000H?ooool2o`0006Oooooo0003ooooo`05oa0@4?ooooooooooooooool@41002ooo
ool01Ol0003ooooooooooooooooo000000Kooooo0ol0000Booooo`;o00007Oooool2o`0004Wooooo
0_l0000booooo`;o0000J_ooool2o`0002Wooooo0003ooooo`05o`000?ooooooooooooooool00000
2oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool04_ooool2o`00043o
oooo0_l0000Uooooo`;o0000<oooool2o`0006[ooooo0_l0000Yooooo`000oooool01Ol0003ooooo
oooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo
00[ooooo0_l0000fooooo`;o00000oooool2o`0000Sooooo0_l000000ooooooo0000o`00000Uoooo
o`;o00005Oooool2o`0003kooooo0_l00017ooooo`?o0000:Oooool000?ooooo00Go410@oooooooo
oooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool02_ooool2o`00
00kooooo0_l0000Vooooo`Co000000?oooooo`000?l000002?ooool2o`0003oooooo0_l0000noooo
o`;o0000?oooool2o`0000Kooooo0_l0000Zooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0Jooooo`;o0000:?ooool2o`00
0;kooooo0_l0000=ooooo`;o0000<_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0L_ooool2o`0003Oooooo0_l0001G
ooooo`;o00000oooool2o`0003cooooo000Mooooo`;o0000BOooool2o`0002Wooooo0_l0000Ooooo
o`;o00005_ooool2o`0005cooooo0_l0000looooo`007Oooool4o`0000[ooooo0_l0000kooooo`;o
0000:Oooool2o`0001oooooo0_l0002Sooooo`;o00003Oooool001kooooo0ol0000:ooooo`;o0000
=_ooool2o`00093ooooo0_l00008ooooo`;o00004Oooool2o`0000Cooooo0_l0000/ooooo`;o0000
4Oooool2o`0000gooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0000fooooo`;o00008?oo
ool2o`0001Sooooo0_l0001Dooooo`;o00002?ooool2o`00017ooooo0_l00004ooooo`;o00007Ooo
ool2o`0000gooooo0_l0000Pooooo`007_ooool00ol0003oooooooooo`1Tooooo`;o00006?ooool2
o`0002gooooo0_l0001Wooooo`;o0000;oooool001kooooo00?o0000ooooooooool0>oooool2o`00
043ooooo0_l0000Uooooo`;o00001oooool2o`0008kooooo0_l00008ooooo`007_ooool00ol0003o
ooooooooo`0Eooooo`;o00009?ooool2o`0003cooooo0_l00002ooooo`;o00009Oooool2o`0000oo
oooo0_l00026ooooo`;o00002?ooool001kooooo00?o0000ooooooooool05Oooool2o`0000;ooooo
0_l00019ooooo`;o00004oooool2o`00013ooooo1?l00006ooooo`;o00007_ooool2o`000003oooo
ool0003o000008gooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l00019ooooo`;o00009Ooo
ool4o`0000Kooooo0_l0000Qooooo`;o0000>Oooool2o`0000kooooo0_l00012ooooo`007_ooool0
0ol0003oooooooooo`3cooooo`;o00003_ooool2o`0001Gooooo0_l0000[ooooo`007_ooool00ol0
003oooooooooo`1gooooo`;o0000XOooool2o`0002_ooooo000Nooooo`;o0000N?ooool2o`0003co
oooo0_l0000iooooo`;o0000EOooool001kooooo00?o0000ooooooooool0<oooool2o`0001Wooooo
0_l00002ooooo`;o00002?ooool2o`0005Oooooo0_l0000Fooooo`;o00008Oooool2o`0005Gooooo
000Nooooo`03o`000?oooooooooo00kooooo0_l00007ooooo`;o00006_ooool2o`0001Wooooo0_l0
0002ooooo`;o00002?ooool2o`0003Cooooo0_l0000iooooo`;o0000Ioooool2o`0000oooooo000N
ooooo`03o`000?oooooooooo00kooooo0_l00007ooooo`;o0000NOooool2o`000:;ooooo0_l0000?
ooooo`007_ooool00ol0003oooooooooo`0^ooooo`;o00008Oooool2o`0001;ooooo0_l00018oooo
o`;o00007?ooool2o`0007Sooooo000Nooooo`03o`000?oooooooooo02kooooo0_l0000Qooooo`;o
00004_ooool2o`0004Sooooo0_l00002ooooo`;o00002oooool2o`0000_ooooo0_l0000;ooooo`;o
0000Joooool001kooooo00?o0000ooooooooool04oooool2o`0000Sooooo0_l0001Yooooo`;o0000
:Oooool3o`0000[ooooo0_l0000Hooooo`;o0000AOooool2o`0002Cooooo000Nooooo`03o`000?oo
oooooooo01?ooooo0_l00008ooooo`?o0000AOooool2o`00027ooooo0_l00004ooooo`;o00001_oo
ool2o`0001cooooo0_l0001Gooooo`;o00004_ooool2o`0002Cooooo000Nooooo`03o`000?oooooo
oooo017ooooo0_l0000;ooooo`;o00000_ooool2o`0000Gooooo0_l0000booooo`;o00001_ooool2
o`0002Oooooo0_l00006ooooo`;o00008?ooool2o`0000kooooo0_l00013ooooo`;o0000:_ooool2
o`0000cooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l00004ooooo`;o00000_ooool2o`00
00oooooo0_l00005ooooo`;o0000<_ooool2o`0004[ooooo0_l0000=ooooo`;o00003_ooool2o`00
06oooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`07ooooo`;o00001?ooool2o`0003ko
oooo0_l0001Jooooo`;o0000H_ooool2o`0003Sooooo000Nooooo`03o`000?oooooooooo04gooooo
0_l00007ooooo`;o0000Boooool2o`0006Sooooo0_l0000Wooooo`;o00003oooool001kooooo00?o
0000ooooooooool04Oooool2o`0003gooooo0_l00004ooooo`;o0000Boooool2o`0001Cooooo0_l0
001kooooo`;o00003oooool001kooooo00?o0000ooooooooool04Oooool2o`0003gooooo0_l0001W
ooooo`;o000000?oooooo`000?l00000N_ooool2o`0000gooooo000Nooooo`03o`000?oooooooooo
00;o0000L?ooool2o`0003?ooooo0_l00006ooooo`;o00002oooool2o`0007[ooooo0_l0000=oooo
o`007_ooool00ol0003oooooooooo`04o`0004Cooooo0_l0000Xooooo`;o0000<oooool2o`0000Ko
oooo0_l0002Fooooo`007_ooool2o`0000?ooooo0_l00014ooooo`;o0000oOooool001kooooo00?o
0000ooooooooool0;oooool2o`0005Kooooo0_l0002nooooo`007_ooool00ol0003oooooooooo`0_
ooooo`;o0000:oooool2o`0002Wooooo0_l0000Rooooo`;o00002Oooool2o`0005;ooooo0_l0000;
ooooo`;o00007Oooool2o`0000oooooo000Nooooo`03o`000?oooooooooo03;ooooo0_l0000Xoooo
o`;o00003?ooool2o`0003oooooo0_l00009ooooo`;o0000B_ooool2o`0000Kooooo0_l0000;oooo
o`;o00007Oooool2o`0000oooooo000Nooooo`03o`000?oooooooooo02Wooooo0_l00007ooooo`;o
00004oooool2o`0001cooooo0_l00003ooooo`;o00007oooool2o`0003Kooooo0_l00005ooooo`;o
00004oooool2o`00027ooooo0_l00006ooooo`;o0000;_ooool2o`0000_ooooo000Nooooo`03o`00
0?oooooooooo02Wooooo0_l0000Looooo`;o00007?ooool2o`0002Cooooo0_l0000;ooooo`;o0000
:Oooool2o`0000Gooooo0_l0000Cooooo`;o0000FOooool2o`0000_ooooo000Nooooo`03o`000?oo
oooooooo027ooooo0_l0000;ooooo`;o0000J?ooool2o`000:gooooo000Nooooo`03o`000?oooooo
oooo00Cooooo0_l0000Kooooo`;o00002oooool2o`000<kooooo0_l0000Wooooo`;o00007_ooool0
01kooooo00?o0000ooooooooool01?ooool2o`0000cooooo0_l00002ooooo`;o00000_ooool2o`00
04cooooo0_l0000Kooooo`;o0000Moooool2o`0002Oooooo0_l0000Nooooo`007Oooool2o`0001Co
oooo0_l00002ooooo`;o00000_ooool2o`0003Wooooo0_l0000Aooooo`;o00006oooool2o`0009Co
oooo0_l0000Aooooo`;o00005oooool001gooooo0_l0000kooooo`;o00006_ooool2o`0001Kooooo
0_l0002/ooooo`;o00004Oooool2o`0001Oooooo000Nooooo`03o`000?oooooooooo03Wooooo0_l0
000[ooooo`;o00001Oooool2o`0001Wooooo0_l0002mooooo`007_ooool00ol0003oooooooooo`0b
ooooo`;o0000<_ooool2o`00023ooooo0_l0000Dooooo`;o0000@_ooool2o`0006?ooooo000Noooo
o`03o`000?oooooooooo03;ooooo0_l0001Zooooo`;o00005oooool2o`0002Wooooo0_l0001Soooo
o`007_ooool00ol0003oooooooooo`1Mooooo`;o00007oooool2o`0003Oooooo0_l0002>ooooo`00
7_ooool00ol0003oooooooooo`0^ooooo`;o00007oooool2o`0000cooooo0_l0000Oooooo`;o0000
3Oooool2o`0002kooooo0_l0001Fooooo`;o00001?ooool2o`0002[ooooo000Nooooo`;o00007Ooo
ool2o`00013ooooo0_l0000Oooooo`;o0000??ooool2o`0002kooooo0_l0001Fooooo`;o00001?oo
ool2o`0002[ooooo000Nooooo`03o`000?oooooooooo01cooooo0_l0002<ooooo`;o0000;_ooool2
o`0006_ooooo000Mooooo`;o0000[?ooool2o`0002kooooo0_l0001[ooooo`007Oooool2o`0006;o
oooo0_l0001?ooooo`;o0000GOooool2o`0003Gooooo000Nooooo`03o`000?oooooooooo013ooooo
0ol0001=ooooo`;o00003_ooool2o`0002Cooooo1?l0000Gooooo`;o0000GOooool2o`0001Wooooo
0_l0000Jooooo`007_ooool00ol0003oooooooooo`09ooooo`;o00001Oooool5o`0005_ooooo0_l0
000Tooooo`Co0000TOooool2o`0001[ooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l00008
ooooo`;o0000A_ooool2o`0003Wooooo0_l00002ooooo`;o0000A_ooool2o`0001Gooooo0_l00006
ooooo`;o0000:_ooool2o`0001Sooooo000Nooooo`03o`000?oooooooooo04Wooooo0_l0000@oooo
o`;o0000>Oooool2o`0000;ooooo0_l00016ooooo`;o00002?ooool2o`0000_ooooo0_l00006oooo
o`;o0000:_ooool2o`0001Sooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0000iooooo`;o
00000oooool2o`000:7ooooo0_l000000ooooooo0000o`00000Vooooo`;o0000;_ooool001kooooo
00?o0000ooooooooool02Oooool2o`0003Wooooo0_l0002Yooooo`;o00009_ooool2o`0002kooooo
000Nooooo`03o`000?oooooooooo06Cooooo1?l00004ooooo`;o00002_ooool2o`00037ooooo0_l0
000:ooooo`;o00003_ooool2o`0005[ooooo0_l0000=ooooo`;o00004oooool001kooooo00?o0000
ooooooooool0I?ooool4o`0000Cooooo0_l0000:ooooo`;o0000<Oooool2o`0000[ooooo0_l0000>
ooooo`;o0000=_ooool2o`0001[ooooo0_l00006ooooo`?o00003?ooool2o`0001?ooooo000Noooo
o`;o000000?oooooo`000?l00000eoooool2o`0002Cooooo0_l0000Jooooo`;o00001oooool2o`00
00Sooooo0_l0000Gooooo`007_ooool2o`000003ooooool0003o0000023ooooo0_l0000;ooooo`;o
0000Z?ooool2o`0005?ooooo0_l0000Gooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0Roooo
o`;o00001oooool2o`0000;ooooo0_l0002:ooooo`;o0000?_ooool2o`0004[ooooo0003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06
ooooo`03o`000?oooooooooo00;o0000:Oooool2o`0003Oooooo0_l0000booooo`;o00004_ooool2
o`0000Sooooo0_l00003ooooo`;o00005_ooool2o`0002Kooooo0_l0001:ooooo`000oooool01Ol@
413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000005ooooo`Ko0000=?oo
ool2o`0002cooooo0_l0000Iooooo`;o00005?ooool2o`000004ooooool0003o0000o`00017ooooo
0_l00008ooooo`;o00006oooool2o`0007;ooooo0003ooooo`05o`000?ooooooooooooooool00000
2oooool01Olb<S;oV9RHoooooonHV9So<S8b00Gooooo0_l000000ooooooo0000o`00000eooooo`;o
00006oooool2o`0002[ooooo0_l0000Dooooo`;o00000_ooool2o`0006kooooo0_l0000looooo`00
0oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006oooo
o`03o`000?oooooooooo01?ooooo0_l0000Vooooo`;o00005_ooool2o`0003Cooooo0_l0000Roooo
o`;o00001oooool2o`00047ooooo0_l0000>ooooo`;o0000??ooool000?ooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`0C
ooooo`;o00009_ooool2o`0004cooooo0_l0000Rooooo`;o00001oooool2o`00047ooooo0_l0001<
ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00
0006ooooo`03o`000?oooooooooo01[ooooo0_l00017ooooo`Co0000:?ooool2o`000;Kooooo0003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo
00?o0000ooooooooool04Oooool2o`0000Oooooo0_l000000ooooooo0000o`00000Booooo`;o0000
9Oooool2o`0000Wooooo1?l0000Xooooo`;o0000@_ooool2o`0007;ooooo000Nooooo`03o`000?oo
oooooooo017ooooo0_l0000:ooooo`;o00004_ooool2o`0002Gooooo0_l000000ooooooo0000o`00
000iooooo`;o0000>?ooool2o`000003ooooool0003o000007;ooooo000Nooooo`03o`000?oooooo
oooo01oooooo0_l0000Gooooo`;o00008Oooool2o`0003Wooooo0_l0000Rooooo`;o00005?ooool2
o`0000Oooooo0_l00006ooooo`;o00008oooool2o`0001oooooo0_l0000Nooooo`007_ooool00ol0
003oooooooooo`0Oooooo`;o00003oooool2o`0000Kooooo0_l000000ooooooo0000o`00000Voooo
o`;o00006?ooool2o`0003?ooooo0_l00006ooooo`;o00003?ooool2o`0000oooooo0_l00006oooo
o`;o00004?ooool2o`00017ooooo0_l0000Oooooo`;o00007_ooool001kooooo00?o0000oooooooo
ool0<?ooool2o`0000Wooooo0_l0000Vooooo`;o00006?ooool2o`0003?ooooo0_l0000Dooooo`;o
0000:Oooool2o`0005;ooooo000Nooooo`03o`000?oooooooooo03Sooooo0_l0003oooooo`kooooo
000Nooooo`03o`000?oooooooooo01?ooooo0_l0000Sooooo`;o0000QOooool2o`0008Kooooo000N
ooooo`03o`000?oooooooooo01?ooooo0_l0001;ooooo`;o00006_ooool2o`0000kooooo0_l0000a
ooooo`;o0000=?ooool2o`0000_ooooo0_l00005ooooo`;o00006oooool4o`0001gooooo000Noooo
o`03o`000?oooooooooo063ooooo0_l0000<ooooo`;o00003?ooool2o`0000Oooooo0_l00005oooo
o`;o0000Ioooool2o`0000_ooooo0_l00005ooooo`;o00006oooool4o`0000Sooooo0_l0000Coooo
o`007_ooool00ol0003oooooooooo`1^ooooo`;o00005Oooool2o`000:_ooooo1?l0000Aooooo`00
7_ooool00ol0003oooooooooo`2Pooooo`;o0000T_ooool2o`00017ooooo000Nooooo`03o`000?oo
oooooooo04Oooooo0_l00015ooooo`;o00004?ooool2o`0008Cooooo0_l0000Aooooo`;o00003?oo
ool001kooooo0_l00018ooooo`?o0000<Oooool2o`0000gooooo1_l0002Fooooo`;o00004Oooool2
o`0000cooooo000Nooooo`03o`000?oooooooooo04Sooooo0_l0000Aooooo`;o00007_ooool2o`00
00gooooo1?l00005ooooo`;o0000/_ooool001kooooo00?o0000ooooooooool0?Oooool2o`0000[o
oooo0_l0000@ooooo`;o0000=_ooool2o`0001Wooooo0_l000000ooooooo0000o`00000gooooo`;o
0000Foooool001kooooo00?o0000ooooooooool0?Oooool2o`0000[ooooo0_l0001Dooooo`;o0000
00?oooooo`000?l000002_ooool2o`000003ooooool0003o000000Cooooo0_l0000Jooooo`;o0000
5Oooool2o`0003kooooo0_l0000Kooooo`007_ooool00ol0003oooooooooo`2Aooooo`;o00002_oo
ool4o`000003ooooool0003o000001?ooooo0_l0000Jooooo`;o0000EOooool2o`0001_ooooo000N
ooooo`03o`000?oooooooooo097ooooo0_l0000:ooooo`;o0000:_ooool2o`0007cooooo000Noooo
o`03o`000?oooooooooo04Gooooo0_l00022ooooo`;o000000?oooooo`000?l00000NOooool001ko
oooo00?o0000ooooooooool00_l0000Yooooo`;o00006?ooool2o`0001gooooo0_l0001Vooooo`;o
0000;_ooool4o`0003kooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`02o`0002Wooooo
0_l0000gooooo`;o0000:_ooool2o`0002;ooooo0_l00016ooooo`Co0000?_ooool2o`0000Oooooo
000Nooooo`03o`000?oooooooooo05gooooo0_l00008ooooo`;o00009oooool2o`0002;ooooo0_l0
0003ooooo`;o0000S?ooool001kooooo00?o0000ooooooooool0GOooool2o`0000Sooooo0_l0001?
ooooo`?o00002oooool2o`0007oooooo000Nooooo`03o`000?oooooooooo03oooooo0_l0000/oooo
o`;o0000=Oooool2o`0000;ooooo0_l0000>ooooo`;o00003?ooool2o`0001_ooooo0_l0001Roooo
o`007_ooool00ol0003oooooooooo`04ooooo`;o00001Oooool2o`0003;ooooo0_l0000Aooooo`;o
00006Oooool2o`0003Gooooo0_l00002ooooo`;o00002oooool2o`0002cooooo0_l0000]ooooo`;o
00001?ooool2o`0002gooooo000Nooooo`03o`000?oooooooooo00;ooooo1?l00005ooooo`;o0000
AOooool2o`00067ooooo0_l0000fooooo`;o00008oooool2o`0000Cooooo0_l0000]ooooo`007_oo
ool00ol0003oooooooooo`04o`00047ooooo0_l0001Jooooo`;o0000B_ooool2o`0005Sooooo000N
ooooo`03o`000?oooooooooo00;o0000@oooool2o`0005[ooooo0_l0000Qooooo`;o0000@_ooool2
o`0002?ooooo0_l0000Hooooo`007_ooool2o`0004gooooo0_l00011ooooo`;o0000<oooool2o`00
04;ooooo0_l0000Sooooo`;o00006?ooool001kooooo00?o0000ooooooooool0C?ooool2o`0001[o
oooo0_l0000@ooooo`;o00001_ooool2o`0000_ooooo0_l0001eooooo`;o0000?oooool001kooooo
00?o0000ooooooooool06_ooool2o`0004cooooo0_l0000@ooooo`;o00001_ooool2o`0001_ooooo
0_l0001Uooooo`;o00003_ooool2o`0002oooooo000Nooooo`03o`000?oooooooooo01[ooooo0_l0
001Uooooo`;o00007?ooool2o`0000Wooooo0_l00008ooooo`;o0000COooool2o`00017ooooo0_l0
000_ooooo`007_ooool00ol0003oooooooooo`0mooooo`;o00003oooool2o`0001Kooooo0_l0000I
ooooo`;o00009oooool2o`0000Sooooo0_l0000[ooooo`;o00008?ooool2o`0004;ooooo000Noooo
o`03o`000?oooooooooo03gooooo0_l0000?ooooo`;o00005_ooool2o`0001kooooo0_l0001Ioooo
o`;o0000Coooool2o`0001?ooooo000Nooooo`03o`000?oooooooooo073ooooo0_l0000Dooooo`;o
0000Z_ooool2o`0001?ooooo000Nooooo`03o`000?oooooooooo073ooooo0_l0001Fooooo`;o0000
6?ooool2o`0005Gooooo0_l0000<ooooo`007_ooool3o`000<Sooooo0_l0000Hooooo`;o0000EOoo
ool2o`0000cooooo000Nooooo`?o00009Oooool2o`00017ooooo0_l0001hooooo`;o0000IOooool2
o`0002Kooooo0_l00004ooooo`007_ooool00ol0003oooooooooo`0Uooooo`Co00003oooool2o`00
07Sooooo0_l0001Uooooo`;o00009_ooool2o`0000Cooooo000Nooooo`03o`000?oooooooooo00oo
oooo0_l0000Fooooo`;o00004?ooool2o`000;7ooooo0_l0000iooooo`;o00007_ooool001kooooo
00?o0000ooooooooool03oooool2o`0002Sooooo0_l0002aooooo`;o0000>Oooool2o`0000Cooooo
0_l0000<ooooo`;o00002_ooool001kooooo00?o0000ooooooooool0ooooool<ooooo`;o00008?oo
ool2o`0000cooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`2Rooooo`;o0000Ioooool2
o`0003[ooooo000Nooooo`03o`000?oooooooooo03Oooooo0_l0000Aooooo`;o0000=Oooool2o`00
01Sooooo0_l00005ooooo`;o00005?ooool2o`0007gooooo0_l0000>ooooo`007_ooool2o`0003So
oooo0_l0000Aooooo`;o00001_ooool2o`0002;ooooo0_l00009ooooo`;o00002?ooool2o`0000ko
oooo0_l0000Kooooo`Co0000>Oooool4o`0000Gooooo0_l0000gooooo`;o00003_ooool001kooooo
00?o0000ooooooooool01?ooool2o`0000oooooo0_l0000kooooo`;o00008_ooool2o`0001?ooooo
0_l0000]ooooo`;o0000>Oooool4o`0000Gooooo1?l00015ooooo`007_ooool00ol0003ooooooooo
o`04ooooo`;o00003oooool2o`000:oooooo0_l0000hooooo`Go0000=_ooool2o`0000[ooooo000N
ooooo`03o`000?oooooooooo00Cooooo0_l00030ooooo`;o0000>?ooool5o`0002Gooooo0_l0000?
ooooo`;o00002_ooool001kooooo00?o0000ooooooooool01?ooool2o`0003Oooooo0ol0000aoooo
o`;o0000:_ooool2o`0005cooooo0_l00003ooooo`;o0000:?ooool2o`0001_ooooo000Nooooo`03
o`000?oooooooooo01cooooo0_l0000Oooooo`?o0000<Oooool2o`0002[ooooo0_l0001Looooo`;o
0000B_ooool001kooooo00?o0000ooooooooool04Oooool2o`0000Wooooo0_l0000Sooooo`;o0000
<?ooool2o`00073ooooo0_l0001Pooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o00001ooo
ool2o`0002Gooooo0_l0000`ooooo`Co0000K_ooool2o`00063ooooo000Nooooo`03o`000?oooooo
oooo017ooooo0_l00007ooooo`;o0000Eoooool4o`0002Wooooo0_l00017ooooo`;o0000G?ooool0
01kooooo00?o0000ooooooooool0L_ooool2o`0002cooooo0_l0000Rooooo`;o00008oooool2o`00
05cooooo000Nooooo`03o`000?oooooooooo07;ooooo0_l00004ooooo`;o0000=oooool2o`00017o
oooo0_l00021ooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o00009?ooool2o`00037ooooo
0_l0000Rooooo`;o00004Oooool4o`0002cooooo0_l0001Vooooo`007_ooool00ol0003ooooooooo
o`02ooooo`;o00006_ooool3o`0002Cooooo0_l00011ooooo`;o00004_ooool2o`0000gooooo0_l0
0002ooooo`;o000000?oooooo`000?l000007Oooool2o`0000cooooo0_l0001;ooooo`;o00006Ooo
ool001kooooo00?o0000ooooooooool00_ooool2o`0001[ooooo0_l0001Xooooo`;o00008Oooool2
o`0000Gooooo0_l0000Mooooo`;o0000FOooool2o`0000Oooooo0_l0000@ooooo`005?ooool4o`00
0003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0j_ooool2o`0001Cooooo0_l0000coooo
o`;o00004?ooool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2nooooo`;o
0000:_ooool2o`0001Cooooo0_l00015ooooo`005_ooool00ol0003oooooooooo`05ooooo`?o0000
9?ooool2o`0004Sooooo0_l0001>ooooo`;o0000Qoooool001Kooooo00?o0000ooooooooool0;?oo
ool2o`0004Sooooo0_l0003Gooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Foooo
o`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`00
5?ooool00omEEEGoIVIVo`00003ooooooe;ooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.88083 .93928 Mdot
.65335 .14711 Mdot
.39798 .27834 Mdot
.73359 .12971 Mdot
.30835 .8342 Mdot
.2095 .80825 Mdot
.85093 .63714 Mdot
.05546 .31367 Mdot
.4941 .7015 Mdot
.60329 .00632 Mdot
.5483 .72384 Mdot
.52935 .81175 Mdot
.9896 .05632 Mdot
.77403 .8266 Mdot
.22102 .46982 Mdot
.80426 .37211 Mdot
.68947 .01407 Mdot
.82439 .22569 Mdot
.30207 .05913 Mdot
.29661 .29656 Mdot
.34058 .58173 Mdot
.89935 .13042 Mdot
.51859 .50427 Mdot
.92717 .02904 Mdot
.04988 .65028 Mdot
.65948 .64832 Mdot
.8784 .43145 Mdot
.78143 .43793 Mdot
.93302 .07162 Mdot
.22988 .63949 Mdot
.05103 .55348 Mdot
.6278 .69518 Mdot
.7451 .55435 Mdot
.06285 .20211 Mdot
.99393 .7527 Mdot
.48985 .88547 Mdot
.74944 .61974 Mdot
.37264 .93028 Mdot
.96724 .79493 Mdot
.28592 .76993 Mdot
.78576 .97336 Mdot
.22044 .51562 Mdot
.46567 .8535 Mdot
.37254 .00666 Mdot
.28402 .94026 Mdot
.42079 .61858 Mdot
.60931 .81628 Mdot
.27699 .3712 Mdot
.78459 .68896 Mdot
.51471 .65328 Mdot
.37645 .51772 Mdot
.99325 .66802 Mdot
.99227 .24107 Mdot
.09587 .38665 Mdot
.2942 .71636 Mdot
.47129 .71234 Mdot
.91245 .04983 Mdot
.30917 .87137 Mdot
.47031 .31909 Mdot
.29574 .13065 Mdot
.96699 .10759 Mdot
.34817 .89734 Mdot
.22907 .73062 Mdot
.96915 .95139 Mdot
.5176 .31491 Mdot
.19111 .93943 Mdot
.85351 .15979 Mdot
.53748 .51784 Mdot
.83343 .65501 Mdot
.94325 .27727 Mdot
.07285 .95985 Mdot
.41148 .81041 Mdot
.07491 .35458 Mdot
.76488 .44488 Mdot
.77068 .80991 Mdot
.34315 .1082 Mdot
.43304 .08936 Mdot
.39919 .85754 Mdot
.90423 .21087 Mdot
.07789 .65025 Mdot
.42227 .28677 Mdot
.88194 .69171 Mdot
.22653 .6377 Mdot
.16168 .38301 Mdot
.3156 .09096 Mdot
.17571 .51112 Mdot
.23573 .56968 Mdot
.43325 .9782 Mdot
.47387 .6782 Mdot
.34137 .80291 Mdot
.2775 .66992 Mdot
.95884 .83579 Mdot
.03734 .3561 Mdot
.39976 .4586 Mdot
.58223 .94432 Mdot
.02756 .32116 Mdot
.56908 .56736 Mdot
.63221 .13233 Mdot
.64313 .7037 Mdot
.60422 .83135 Mdot
.31924 .65039 Mdot
.70245 .69836 Mdot
.81605 .07981 Mdot
.45066 .56596 Mdot
.13078 .31312 Mdot
.25085 .3431 Mdot
.19677 .67859 Mdot
.5986 .76667 Mdot
.23085 .49059 Mdot
.74383 .93782 Mdot
.84762 .98703 Mdot
.42177 .41643 Mdot
.18869 .16611 Mdot
.47106 .38508 Mdot
.81511 .70892 Mdot
.88043 .78159 Mdot
.99726 .62246 Mdot
.84254 .71657 Mdot
.11706 .29874 Mdot
.40033 .77988 Mdot
.66268 .02127 Mdot
.5437 .52687 Mdot
.98026 .17746 Mdot
.34537 .28242 Mdot
.57176 .75373 Mdot
.54911 .25535 Mdot
.26119 .97881 Mdot
.08723 .09266 Mdot
.01777 .68499 Mdot
.85714 .7252 Mdot
.0985 .74039 Mdot
.8446 .82034 Mdot
.99211 .99716 Mdot
.98339 .03964 Mdot
.69237 .03523 Mdot
.05853 .92362 Mdot
.35012 .79238 Mdot
.031 .54273 Mdot
.39426 .51953 Mdot
.41439 .62765 Mdot
.07906 .56929 Mdot
.24719 .54712 Mdot
.72001 .12323 Mdot
.81405 .99003 Mdot
.04248 .48195 Mdot
.446 .58345 Mdot
.13576 .80693 Mdot
.62445 .07824 Mdot
.48697 .21611 Mdot
.24193 .23451 Mdot
.1908 .25985 Mdot
.10326 .07593 Mdot
.45887 .87145 Mdot
.7086 .06727 Mdot
.40904 .34077 Mdot
.18866 .40318 Mdot
.57384 .72623 Mdot
.56253 .97041 Mdot
.74458 .32391 Mdot
.00636 .71759 Mdot
.05785 .78112 Mdot
.44434 .66619 Mdot
.01946 .43476 Mdot
.81017 .49211 Mdot
.87983 .77033 Mdot
.85009 .56127 Mdot
.25797 .51937 Mdot
.93804 .90385 Mdot
.9801 .5662 Mdot
.87215 .26443 Mdot
.81541 .41845 Mdot
.05295 .92715 Mdot
.49158 .33212 Mdot
.14331 .88969 Mdot
.07764 .69307 Mdot
.02129 .79556 Mdot
.40142 .23455 Mdot
.89906 .95634 Mdot
.65915 .47902 Mdot
.64161 .74896 Mdot
.11348 .07827 Mdot
.90234 .82173 Mdot
.56462 .17754 Mdot
.19277 .59747 Mdot
.82647 .08029 Mdot
.44655 .95392 Mdot
.52941 .18862 Mdot
.04474 .74771 Mdot
.34154 .23932 Mdot
.86154 .18808 Mdot
.39285 .32162 Mdot
.92408 .11714 Mdot
.99313 .52845 Mdot
.42745 .6622 Mdot
.58734 .1439 Mdot
.58267 .74678 Mdot
.20312 .28595 Mdot
.38111 .00442 Mdot
.35046 .79127 Mdot
.74045 .84325 Mdot
.03055 .935 Mdot
.66921 .01242 Mdot
.38157 .95482 Mdot
.07125 .16579 Mdot
.64961 .92634 Mdot
.43233 .89711 Mdot
.85175 .12994 Mdot
.18891 .78528 Mdot
.0829 .57521 Mdot
.33369 .9108 Mdot
.52723 .4636 Mdot
.87788 .29648 Mdot
.56679 .65321 Mdot
.3676 .47213 Mdot
.06311 .10982 Mdot
.93578 .51008 Mdot
.58315 .81905 Mdot
.86072 .09824 Mdot
.51773 .05551 Mdot
.45226 .958 Mdot
.85552 .21676 Mdot
.93501 .67872 Mdot
.04669 .53428 Mdot
.42747 .56817 Mdot
.78219 .142 Mdot
.75554 .79248 Mdot
.05753 .73037 Mdot
.1575 .45539 Mdot
.72113 .99429 Mdot
.90162 .02563 Mdot
.88504 .25613 Mdot
.53545 .57058 Mdot
.14178 .43806 Mdot
.4801 .49672 Mdot
.81713 .1999 Mdot
.41296 .36005 Mdot
.68527 .36836 Mdot
.34987 .23117 Mdot
.9601 .45125 Mdot
.59327 .07538 Mdot
.9395 .95216 Mdot
.51068 .72849 Mdot
.81 .95923 Mdot
.21159 .56565 Mdot
.87485 .06843 Mdot
.30593 .19485 Mdot
.6981 .17794 Mdot
.23631 .29541 Mdot
.41115 .17167 Mdot
.2522 .68293 Mdot
.5726 .09671 Mdot
.73517 .31393 Mdot
.47712 .77701 Mdot
.66679 .86265 Mdot
.94501 .15531 Mdot
.79326 .99687 Mdot
.39678 .50026 Mdot
.04728 .30673 Mdot
.14328 .06846 Mdot
.44992 .52198 Mdot
.25691 .0615 Mdot
.69737 .61021 Mdot
.03109 .76397 Mdot
.66732 .01305 Mdot
.28762 .18523 Mdot
.39924 .59906 Mdot
.57329 .56678 Mdot
.45653 .85572 Mdot
.57518 .53766 Mdot
.4266 .67821 Mdot
.39107 .19362 Mdot
.76197 .75252 Mdot
.92466 .44453 Mdot
.08303 .50535 Mdot
.33169 .94278 Mdot
.27804 .29067 Mdot
.76191 .99606 Mdot
.18482 .29055 Mdot
.47783 .9778 Mdot
.18864 .4253 Mdot
.74972 .88658 Mdot
.33008 .93897 Mdot
.52669 .17582 Mdot
.9152 .54708 Mdot
.40202 .6545 Mdot
.12288 .29431 Mdot
.57925 .88544 Mdot
.63504 .75403 Mdot
.65072 .14362 Mdot
.13817 .59681 Mdot
.8552 .50577 Mdot
.40486 .11299 Mdot
.84677 .33488 Mdot
.48063 .83617 Mdot
.4652 .31453 Mdot
.96458 .48313 Mdot
.71131 .59105 Mdot
.54527 .50635 Mdot
.05475 .31552 Mdot
.35777 .49745 Mdot
.85067 .78553 Mdot
.04454 .13985 Mdot
.77049 .64275 Mdot
.07518 .25942 Mdot
.54355 .48345 Mdot
.0505 .24011 Mdot
.08736 .30284 Mdot
.39175 .48344 Mdot
.6843 .5286 Mdot
.75739 .24376 Mdot
.44302 .45631 Mdot
.1041 .46414 Mdot
.0503 .5693 Mdot
.82494 .18343 Mdot
.27689 .22523 Mdot
.05701 .16676 Mdot
.10679 .5444 Mdot
.38335 .26549 Mdot
.40939 .62396 Mdot
.16877 .36586 Mdot
.13956 .71331 Mdot
.13148 .5175 Mdot
.99061 .32681 Mdot
.37582 .72683 Mdot
.07741 .74602 Mdot
.31554 .80099 Mdot
.52933 .74092 Mdot
.93597 .25746 Mdot
.91862 .80186 Mdot
.20342 .36661 Mdot
.21833 .74332 Mdot
.47042 .71918 Mdot
.40882 .64903 Mdot
.88764 .42302 Mdot
.2093 .97284 Mdot
.84872 .41609 Mdot
.11067 .94254 Mdot
.73971 .9129 Mdot
.30025 .6751 Mdot
.52489 .4885 Mdot
.53659 .4667 Mdot
.99233 .3204 Mdot
.16402 .03641 Mdot
.02644 .06833 Mdot
.01952 .73086 Mdot
.67696 .44743 Mdot
.73119 .36473 Mdot
.30131 .13244 Mdot
.86302 .06287 Mdot
.15081 .49059 Mdot
.35455 .92885 Mdot
.97542 .92852 Mdot
.88975 .78256 Mdot
.50414 .24998 Mdot
.94119 .38743 Mdot
.87547 .50253 Mdot
.49624 .86637 Mdot
.87355 .39303 Mdot
.44537 .82432 Mdot
.08552 .94425 Mdot
.89739 .25625 Mdot
.3901 .69345 Mdot
.42327 .88997 Mdot
.84813 .35472 Mdot
.78864 .36837 Mdot
.03173 .00944 Mdot
.99976 .78794 Mdot
.32715 .03219 Mdot
.29473 .38676 Mdot
.80715 .93391 Mdot
.64112 .8449 Mdot
.18354 .42636 Mdot
.0201 .1173 Mdot
.29213 .13696 Mdot
.26903 .6095 Mdot
.78762 .30455 Mdot
.09796 .51531 Mdot
.51171 .8979 Mdot
.26824 .15789 Mdot
.49139 .27745 Mdot
.52521 .50822 Mdot
.42035 .99719 Mdot
.54389 .85791 Mdot
.66143 .76922 Mdot
.96748 .82421 Mdot
.95718 .03722 Mdot
.34957 .82915 Mdot
.92018 .95589 Mdot
.55308 .48237 Mdot
.65895 .84584 Mdot
.90754 .58721 Mdot
.0034 .77633 Mdot
.04512 .74409 Mdot
.86713 .32197 Mdot
.59463 .86929 Mdot
.01379 .14874 Mdot
.41511 .25797 Mdot
.24553 .47429 Mdot
.63663 .37989 Mdot
.12462 .7623 Mdot
.45686 .05948 Mdot
.40028 .66693 Mdot
.86562 .92558 Mdot
.22865 .60539 Mdot
.36325 .33941 Mdot
.08185 .44092 Mdot
.20658 .20911 Mdot
.48991 .02916 Mdot
.37157 .11096 Mdot
.60334 .67462 Mdot
.38554 .50019 Mdot
.29915 .34703 Mdot
.61616 .08423 Mdot
.99742 .95875 Mdot
.18676 .81917 Mdot
.11151 .1784 Mdot
.93274 .94428 Mdot
.57418 .01916 Mdot
.25131 .34127 Mdot
.3494 .87414 Mdot
.41672 .42646 Mdot
.13248 .33805 Mdot
.3752 .25164 Mdot
.29279 .78484 Mdot
.35751 .01775 Mdot
.01344 .08446 Mdot
.18722 .82032 Mdot
.11981 .38785 Mdot
.40099 .08413 Mdot
.8524 .6352 Mdot
.57532 .472 Mdot
.68614 .59263 Mdot
.93619 .36246 Mdot
.11635 .42838 Mdot
.61232 .77746 Mdot
.36909 .52541 Mdot
.95231 .2123 Mdot
.06312 .0669 Mdot
.09623 .09707 Mdot
.19079 .07416 Mdot
.77046 .14888 Mdot
.72506 .64333 Mdot
.49355 .89124 Mdot
.76903 .95732 Mdot
.39838 .74652 Mdot
.97587 .74386 Mdot
.95396 .67067 Mdot
.90649 .94518 Mdot
.87441 .28717 Mdot
.26959 .50247 Mdot
.01426 .85183 Mdot
.35111 .3264 Mdot
.64163 .95086 Mdot
.17627 .9735 Mdot
.31868 .8085 Mdot
.22631 .62071 Mdot
.69332 .0901 Mdot
.04921 .33832 Mdot
.38622 .72295 Mdot
.47202 .76378 Mdot
.86359 .28615 Mdot
.2781 .45089 Mdot
.37217 .06232 Mdot
.30292 .82367 Mdot
.09317 .34306 Mdot
.87865 .58445 Mdot
.12607 .20889 Mdot
.44513 .59624 Mdot
.06998 .68983 Mdot
.97158 .633 Mdot
.45767 .11763 Mdot
.20957 .52969 Mdot
.99166 .3234 Mdot
.09342 .58491 Mdot
.1302 .02814 Mdot
.10219 .54225 Mdot
.24748 .03568 Mdot
.95306 .66693 Mdot
.46969 .49877 Mdot
.94527 .81041 Mdot
.2087 .49912 Mdot
.36457 .41318 Mdot
.10304 .5674 Mdot
.94202 .14921 Mdot
.84886 .64958 Mdot
.13564 .82208 Mdot
.93684 .25221 Mdot
.40071 .10778 Mdot
.97244 .57408 Mdot
.24894 .07636 Mdot
.6173 .70417 Mdot
.04513 .68601 Mdot
.12544 .23702 Mdot
.99602 .03895 Mdot
.56639 .78567 Mdot
.89814 .16341 Mdot
.39456 .60312 Mdot
.34241 .60679 Mdot
.37429 .83059 Mdot
.33257 .18748 Mdot
.73585 .77367 Mdot
.49329 .83263 Mdot
.46818 .12728 Mdot
.10528 .37021 Mdot
.48824 .77467 Mdot
.48133 .79558 Mdot
.66092 .19704 Mdot
.97447 .42158 Mdot
.32691 .93801 Mdot
.10071 .99142 Mdot
.31038 .39883 Mdot
.48001 .02594 Mdot
.33906 .38704 Mdot
.35764 .8018 Mdot
.22955 .60102 Mdot
.93375 .0589 Mdot
.97165 .61548 Mdot
.3115 .58044 Mdot
.18592 .02396 Mdot
.6611 .99779 Mdot
.35571 .69729 Mdot
.00407 .64975 Mdot
.42326 .59096 Mdot
.12135 .89205 Mdot
.81373 .50544 Mdot
.13686 .38675 Mdot
.99902 .10514 Mdot
.97379 .66318 Mdot
.22322 .2576 Mdot
.2578 .73694 Mdot
.45424 .66619 Mdot
.89145 .92535 Mdot
.79453 .6744 Mdot
.18545 .81008 Mdot
.62902 .37697 Mdot
.62694 .54953 Mdot
.04071 .21172 Mdot
.79538 .77594 Mdot
.75591 .84131 Mdot
.72304 .73356 Mdot
.56438 .34431 Mdot
.88319 .68184 Mdot
.57313 .91004 Mdot
.43136 .03406 Mdot
.52721 .11113 Mdot
.9808 .57483 Mdot
.37984 .99074 Mdot
.65323 .29484 Mdot
.81215 .07546 Mdot
.5843 .06996 Mdot
.74451 .92423 Mdot
.27449 .01257 Mdot
.73439 .4411 Mdot
.02387 .08841 Mdot
.49051 .81252 Mdot
.01804 .7384 Mdot
.75866 .35355 Mdot
.69499 .53823 Mdot
.07551 .81479 Mdot
.38556 .61795 Mdot
.7313 .95374 Mdot
.3704 .12148 Mdot
.63407 .25294 Mdot
.20223 .89838 Mdot
.25315 .20599 Mdot
.8089 .54639 Mdot
.28793 .73727 Mdot
.5022 .52555 Mdot
.87474 .08861 Mdot
.64794 .21582 Mdot
.36071 .95873 Mdot
.65896 .0881 Mdot
.60097 .37411 Mdot
.87343 .04335 Mdot
.73997 .74947 Mdot
.06735 .90499 Mdot
.90953 .90117 Mdot
.65725 .16233 Mdot
.67752 .48028 Mdot
.92854 .30487 Mdot
.53292 .99177 Mdot
.61676 .76395 Mdot
.44658 .71724 Mdot
.478 .10081 Mdot
.4277 .85365 Mdot
.07488 .31092 Mdot
.50807 .66912 Mdot
.26519 .12078 Mdot
.34377 .18231 Mdot
.08153 .25773 Mdot
.05684 .49237 Mdot
.86809 .57117 Mdot
.05765 .69137 Mdot
.64502 .45408 Mdot
.06221 .52958 Mdot
.91341 .78724 Mdot
.38655 .56437 Mdot
.31555 .68663 Mdot
.49358 .1257 Mdot
.22272 .38141 Mdot
.35332 .64494 Mdot
.88119 .81967 Mdot
.11867 .93053 Mdot
.19379 .97364 Mdot
.85229 .5384 Mdot
.29137 .15086 Mdot
.88478 .12879 Mdot
.11974 .68995 Mdot
.08612 .30473 Mdot
.19504 .41661 Mdot
.58531 .37901 Mdot
.57923 .66222 Mdot
.27325 .26621 Mdot
.41518 .19893 Mdot
.94689 .01644 Mdot
.58688 .96405 Mdot
.61036 .31387 Mdot
.02125 .3429 Mdot
.8587 .52836 Mdot
.28324 .92678 Mdot
.09965 .4148 Mdot
.82597 .77322 Mdot
.27215 .5414 Mdot
.59294 .68524 Mdot
.01967 .95445 Mdot
.83014 .6848 Mdot
.88348 .49042 Mdot
.60348 .06055 Mdot
.06055 .85936 Mdot
.31691 .22916 Mdot
.26655 .70309 Mdot
.33969 .49524 Mdot
.50426 .98655 Mdot
.16941 .09245 Mdot
.01564 .77841 Mdot
.43654 .96412 Mdot
.48274 .16996 Mdot
.90822 .6031 Mdot
.863 .48546 Mdot
.3666 .89324 Mdot
.59116 .20953 Mdot
.89821 .09876 Mdot
.44984 .13125 Mdot
.55495 .88581 Mdot
.23477 .49974 Mdot
.81369 .01026 Mdot
.0322 .37148 Mdot
.9798 .51266 Mdot
.07037 .4315 Mdot
.44523 .21942 Mdot
.63952 .19555 Mdot
.77762 .15346 Mdot
.70056 .18832 Mdot
.24879 .88211 Mdot
.42305 .73877 Mdot
.15434 .16734 Mdot
.55373 .70312 Mdot
.15746 .93463 Mdot
.20042 .02065 Mdot
.58225 .77156 Mdot
.55064 .00099 Mdot
.19838 .76205 Mdot
.33429 .11832 Mdot
.23572 .17572 Mdot
.38316 .09376 Mdot
.27844 .849 Mdot
.7513 .58261 Mdot
.89598 .18147 Mdot
.64315 .62955 Mdot
.90302 .59315 Mdot
.16187 .7377 Mdot
.20027 .00563 Mdot
.35458 .68143 Mdot
.20601 .91353 Mdot
.00403 .81122 Mdot
.56064 .85659 Mdot
.93538 .12695 Mdot
.60709 .51288 Mdot
.83172 .31946 Mdot
.53139 .90492 Mdot
.39347 .42995 Mdot
.76262 .88122 Mdot
.54628 .88843 Mdot
.34431 .08396 Mdot
.02442 .61443 Mdot
.44789 .82489 Mdot
.2609 .40175 Mdot
.5412 .59636 Mdot
.06023 .63493 Mdot
.17785 .50946 Mdot
.54269 .9603 Mdot
.4842 .89135 Mdot
.89852 .13069 Mdot
.14859 .29578 Mdot
.10503 .00847 Mdot
.34413 .48615 Mdot
.43098 .78639 Mdot
.71013 .95581 Mdot
.90858 .60269 Mdot
.71347 .00618 Mdot
.18805 .86204 Mdot
.96748 .32205 Mdot
.84438 .08913 Mdot
.87603 .18601 Mdot
.67073 .6118 Mdot
.17222 .14967 Mdot
.25597 .25888 Mdot
.97417 .89656 Mdot
.21583 .20352 Mdot
.98518 .59355 Mdot
.03269 .7124 Mdot
.96664 .90021 Mdot
.23177 .75228 Mdot
.58495 .95385 Mdot
.60149 .87104 Mdot
.76475 .36415 Mdot
.76486 .60853 Mdot
.2416 .60012 Mdot
.59531 .95782 Mdot
.58843 .05595 Mdot
.10905 .18939 Mdot
.93589 .11014 Mdot
.86338 .6214 Mdot
.66922 .88728 Mdot
.43346 .72794 Mdot
.88655 .83393 Mdot
.27313 .11212 Mdot
.24226 .72435 Mdot
.2448 .40203 Mdot
.69179 .8163 Mdot
.09901 .70537 Mdot
.35989 .07444 Mdot
.95626 .33525 Mdot
.17448 .41979 Mdot
.46422 .93493 Mdot
.948 .76894 Mdot
.97071 .63134 Mdot
.8121 .51786 Mdot
.41204 .15793 Mdot
.29813 .11458 Mdot
.92594 .51069 Mdot
.31435 .98821 Mdot
.24858 .02658 Mdot
.07318 .59663 Mdot
.79984 .50421 Mdot
.53501 .6344 Mdot
.55072 .799 Mdot
.03553 .69701 Mdot
.12124 .59735 Mdot
.95159 .83907 Mdot
.13186 .13976 Mdot
.99933 .34497 Mdot
.03583 .33742 Mdot
.48438 .56098 Mdot
.09722 .96088 Mdot
.95873 .66444 Mdot
.80239 .04749 Mdot
.65383 .68077 Mdot
.58659 .47167 Mdot
.87718 .43789 Mdot
.05334 .15861 Mdot
.80969 .21635 Mdot
.33182 .78437 Mdot
.21958 .7763 Mdot
.74364 .77426 Mdot
.54865 .68492 Mdot
.42528 .57925 Mdot
.27191 .21537 Mdot
.96625 .78975 Mdot
.04302 .33692 Mdot
.06272 .98413 Mdot
.22703 .16138 Mdot
.21812 .98972 Mdot
.66816 .52573 Mdot
.63869 .99004 Mdot
.32545 .01131 Mdot
.05219 .46117 Mdot
.05208 .26378 Mdot
.858 .83033 Mdot
.53783 .64645 Mdot
.61418 .3898 Mdot
.97155 .90814 Mdot
.74133 .18088 Mdot
.16245 .13242 Mdot
.31285 .70696 Mdot
.63849 .23325 Mdot
.30795 .48911 Mdot
.15563 .46728 Mdot
.98799 .06528 Mdot
.65287 .80026 Mdot
.28126 .66549 Mdot
.30044 .9694 Mdot
.56287 .95647 Mdot
.89035 .58474 Mdot
.07044 .31766 Mdot
.08476 .99704 Mdot
.51729 .28541 Mdot
.79709 .27189 Mdot
.31523 .6878 Mdot
.38897 .01755 Mdot
.18174 .72514 Mdot
.11223 .62159 Mdot
.48677 .47224 Mdot
.44564 .4429 Mdot
.66531 .13931 Mdot
.87522 .08036 Mdot
.35561 .52081 Mdot
.90011 .3853 Mdot
.45561 .46941 Mdot
.91726 .70098 Mdot
.42847 .45836 Mdot
.20578 .83348 Mdot
.52827 .9721 Mdot
.31931 .73115 Mdot
.92385 .28801 Mdot
.67677 .87804 Mdot
.41482 .5686 Mdot
.08141 .26687 Mdot
.83657 .73291 Mdot
.6722 .12127 Mdot
.12713 .6527 Mdot
.56428 .23201 Mdot
.10803 .37228 Mdot
.97605 .01042 Mdot
.99621 .64985 Mdot
.10969 .02462 Mdot
.52247 .96947 Mdot
.89783 .35521 Mdot
.73731 .29214 Mdot
.43228 .82142 Mdot
.18199 .13727 Mdot
.08265 .96758 Mdot
.87299 .38003 Mdot
.38979 .14888 Mdot
.10739 .15517 Mdot
.61405 .86356 Mdot
.65539 .01402 Mdot
.19425 .69671 Mdot
.44398 .17583 Mdot
.51748 .58056 Mdot
.2353 .58184 Mdot
.88068 .42565 Mdot
.55046 .66383 Mdot
.17917 .8058 Mdot
.4816 .93102 Mdot
.55027 .02156 Mdot
.75126 .33692 Mdot
.98284 .93915 Mdot
.43432 .8522 Mdot
.27113 .93391 Mdot
.23845 .2929 Mdot
.91238 .82495 Mdot
.05969 .60279 Mdot
.60152 .01757 Mdot
.86546 .09124 Mdot
.80798 .81401 Mdot
.05945 .38314 Mdot
.5821 .10185 Mdot
.04155 .79602 Mdot
.24809 .63097 Mdot
.08714 .3201 Mdot
.33946 .26054 Mdot
.51957 .16807 Mdot
.73955 .92821 Mdot
.8078 .25962 Mdot
.79484 .22271 Mdot
.19234 .7107 Mdot
.11319 .95427 Mdot
.79157 .66323 Mdot
.91811 .09617 Mdot
.46466 .58124 Mdot
.39811 .78721 Mdot
.61552 .08209 Mdot
.29584 .15277 Mdot
.9062 .08443 Mdot
.29176 .81411 Mdot
.63601 .66786 Mdot
.41579 .05981 Mdot
.63748 .4858 Mdot
.33634 .81045 Mdot
.42249 .09586 Mdot
.21548 .92984 Mdot
.61605 .88524 Mdot
.18124 .48847 Mdot
.25918 .51949 Mdot
.21789 .07119 Mdot
.13387 .72465 Mdot
.79986 .8584 Mdot
.39526 .48626 Mdot
.80084 .28674 Mdot
.04054 .76077 Mdot
.01135 .31204 Mdot
.31416 .24207 Mdot
.19522 .56775 Mdot
.84588 .75266 Mdot
.43623 .41539 Mdot
.36276 .83696 Mdot
.76785 .04207 Mdot
.53988 .64548 Mdot
.54988 .85716 Mdot
.50025 .49104 Mdot
.01998 .91368 Mdot
.2788 .18096 Mdot
.76177 .34004 Mdot
.30416 .6336 Mdot
.92447 .45665 Mdot
.59004 .14425 Mdot
.81167 .34668 Mdot
.00155 .84232 Mdot
.57538 .93819 Mdot
.08883 .39104 Mdot
.84913 .43831 Mdot
.89817 .58838 Mdot
.16002 .02197 Mdot
.19408 .82194 Mdot
.20896 .92449 Mdot
.24661 .82874 Mdot
.73708 .29511 Mdot
.08581 .37368 Mdot
.41252 .22948 Mdot
.32629 .02257 Mdot
.00709 .91885 Mdot
.93937 .72225 Mdot
.53935 .09702 Mdot
.35705 .11503 Mdot
.08792 .35741 Mdot
.13809 .00089 Mdot
.1843 .82593 Mdot
.28766 .4856 Mdot
.18382 .29116 Mdot
.88247 .74606 Mdot
.2322 .28814 Mdot
.9559 .69554 Mdot
.75033 .61754 Mdot
.77018 .0941 Mdot
.72191 .01727 Mdot
.63908 .21146 Mdot
.18175 .83848 Mdot
.03739 .82558 Mdot
.24086 .83132 Mdot
.20509 .81963 Mdot
.80864 .35918 Mdot
.03617 .63044 Mdot
.97131 .44151 Mdot
.82464 .28837 Mdot
.75845 .48004 Mdot
.85567 .05805 Mdot
.43771 .20682 Mdot
.42814 .08262 Mdot
.06974 .63843 Mdot
.09913 .45489 Mdot
.80862 .47572 Mdot
.33321 .89901 Mdot
.50482 .6859 Mdot
.02848 .06783 Mdot
.21331 .68447 Mdot
.92906 .03022 Mdot
.79869 .80592 Mdot
.89195 .62134 Mdot
.1803 .82892 Mdot
.09231 .83372 Mdot
.93742 .94277 Mdot
.62135 .86438 Mdot
.0755 .79294 Mdot
.46915 .72665 Mdot
.96535 .33285 Mdot
.82613 .92473 Mdot
.24775 .78338 Mdot
.14714 .63115 Mdot
.88391 .8896 Mdot
.94885 .40312 Mdot
.437 .26331 Mdot
.67233 .12231 Mdot
.24436 .0314 Mdot
.30438 .7098 Mdot
.26354 .87931 Mdot
.30408 .29375 Mdot
.62862 .7361 Mdot
.26834 .02495 Mdot
.12554 .45176 Mdot
.46745 .00399 Mdot
.60977 .12012 Mdot
.77842 .98977 Mdot
.01524 .11251 Mdot
.91079 .51767 Mdot
.21464 .92496 Mdot
.92381 .1526 Mdot
.51905 .75276 Mdot
.18503 .11176 Mdot
.09062 .26704 Mdot
.53533 .68206 Mdot
.76762 .6158 Mdot
.89835 .22678 Mdot
.88182 .63495 Mdot
.41447 .97249 Mdot
.45652 .87959 Mdot
.95748 .17841 Mdot
.4804 .85272 Mdot
.33313 .14708 Mdot
.3687 .77127 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`09ooooo`;o00000_ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo0_l00005ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool00_ooool2o`0000Wooooo00?o0000ooooooooool03Oooool2o`0000oo
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;o
oooo000Nooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo0_l0000?ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`04ooooo`;o000000?oooooo`000?l00000
1Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo0_l00009ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03_ooool2o`0000kooooo00?o0000ooooooooool0
3Oooool01?l0003oooooooooooooool2o`0000[ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo000Nooooo`03o`000?oooooooooo00Kooooo
0_l0000Fooooo`;o00007Oooool2o`0003Kooooo0_l00019ooooo`;o00008_ooool2o`0001kooooo
0_l0000cooooo`;o00003?ooool001kooooo00?o0000ooooooooool01_ooool2o`0001Kooooo0_l0
000eooooo`;o00003oooool2o`0006gooooo0_l0000]ooooo`;o0000<oooool2o`0000cooooo000N
ooooo`03o`000?oooooooooo05Gooooo0_l0000?ooooo`;o0000JOooool2o`0000;ooooo0_l00005
ooooo`;o0000D_ooool2o`0001Gooooo000Nooooo`03o`000?oooooooooo073ooooo0_l00008oooo
o`;o0000>oooool2o`0000Kooooo0_l0000@ooooo`;o00002Oooool2o`0000Wooooo0_l00017oooo
o`;o00005Oooool001kooooo00?o0000ooooooooool0<?ooool2o`0000_ooooo0_l0000Wooooo`;o
00002?ooool2o`0000Sooooo0_l0000cooooo`;o00001_ooool2o`0000Kooooo0_l0000Booooo`;o
00004_ooool2o`0005kooooo000Nooooo`03o`000?oooooooooo023ooooo0_l0000>ooooo`;o0000
1_ooool2o`0000?ooooo0_l0000Dooooo`;o00004Oooool2o`00033ooooo0_l0000Eooooo`;o0000
8_ooool2o`0004cooooo0_l0000Tooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o00001?oo
ool2o`00013ooooo0_l0000Cooooo`;o00001?ooool2o`0004?ooooo0_l00027ooooo`;o00001_oo
ool2o`0001cooooo000Nooooo`03o`000?oooooooooo02Kooooo0_l0000Sooooo`Co00005oooool2
o`0003?ooooo0_l0002<ooooo`?o00006oooool001kooooo00?o0000ooooooooool0Boooool2o`00
01Wooooo0_l0000Pooooo`;o00004Oooool2o`00043ooooo0_l0001;ooooo`;o00006oooool001ko
oooo00?o0000ooooooooool0<Oooool2o`0001Wooooo0_l0000jooooo`;o0000Doooool2o`0005Co
oooo0_l0000Booooo`007_ooool00ol0003oooooooooo`0aooooo`;o00006Oooool2o`000>Gooooo
0_l00007ooooo`;o00000_ooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo0?Kooooo0_l0
000Pooooo`;o00008_ooool2o`0000;ooooo0_l00005ooooo`007_ooool00ol0003oooooooooo`3f
ooooo`;o00002Oooool2o`0001Gooooo0_l0000]ooooo`007_ooool00ol0003oooooooooo`3ooooo
o`;ooooo0_l0000Rooooo`;o00008?ooool001kooooo0_l0003oooooobOooooo0_l0000Pooooo`00
7_ooool00ol0003oooooooooo`2Tooooo`;o00005Oooool2o`00087ooooo0_l00007ooooo`007_oo
ool00ol0003oooooooooo`1Nooooo`;o00008oooool2o`0000_ooooo0_l0000Booooo`;o00005Ooo
ool2o`0005Gooooo0_l0000Gooooo`;o00004Oooool2o`0000Oooooo000Nooooo`03o`000?oooooo
oooo04oooooo0_l0000=ooooo`;o00005Oooool2o`0000cooooo0_l0000;ooooo`;o0000;_ooool2
o`00053ooooo1?l0000Eooooo`;o00006_ooool001kooooo00?o0000ooooooooool0Coooool2o`00
02Cooooo0_l00019ooooo`;o0000D_ooool2o`0002Oooooo0_l00008ooooo`007_ooool00ol0003o
ooooooooo`04ooooo`?o00002Oooool2o`0001Sooooo0_l0002fooooo`;o0000=?ooool2o`0002?o
oooo0_l00008ooooo`007_ooool00ol0003oooooooooo`04ooooo`?o00002Oooool2o`0001Sooooo
0_l0000Gooooo`;o0000MOooool2o`0002Kooooo0_l0000dooooo`;o00004Oooool2o`0001[ooooo
000Nooooo`03o`000?oooooooooo03[ooooo0_l00007ooooo`;o0000;?ooool2o`0004Oooooo0_l0
001_ooooo`;o00006_ooool001kooooo00?o0000ooooooooool07Oooool2o`0000;ooooo0_l0000G
ooooo`;o00004Oooool2o`0002;ooooo0_l0001:ooooo`;o00002?ooool2o`0003_ooooo0_l00011
ooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o00000_ooool2o`0002[ooooo0_l0001^oooo
o`;o00002?ooool2o`0003_ooooo0ol00002ooooo`;o00003Oooool2o`0002gooooo000Nooooo`03
o`000?oooooooooo00;o0000J_ooool2o`00013ooooo0_l00007ooooo`;o0000>oooool2o`0003oo
oooo0_l00002ooooo`;o00003Oooool2o`0000Wooooo0_l0000Rooooo`007_ooool00ol0003ooooo
ooooo`02o`0006[ooooo0_l0000@ooooo`;o00001oooool2o`0003_ooooo0_l0001Mooooo`;o0000
8_ooool001kooooo00?o0000ooooooooool01?ooool2o`0008?ooooo0_l00017ooooo`;o00002Ooo
ool2o`0002oooooo0_l00008ooooo`;o0000;Oooool001kooooo00?o0000ooooooooool01?ooool2
o`0001;ooooo0_l0000Iooooo`;o0000;Oooool2o`0002Gooooo0_l00017ooooo`;o00002Oooool2
o`0002oooooo0_l00005ooooo`;o000000?oooooo`000?l00000;Oooool001kooooo00?o0000oooo
ooooool06?ooool2o`0001Wooooo0_l0000]ooooo`;o00005?ooool2o`0000_ooooo0_l0000_oooo
o`;o0000?_ooool2o`0001gooooo0_l0000?ooooo`;o00007oooool001kooooo00?o0000oooooooo
ool06oooool2o`0005_ooooo0_l0000;ooooo`;o00009?ooool2o`0000Wooooo0_l0000nooooo`;o
00007?ooool2o`0000[ooooo0_l00004ooooo`;o00007oooool001kooooo0_l0000Looooo`;o0000
N_ooool2o`0001;ooooo0_l0000<ooooo`;o0000FOooool2o`0000[ooooo0_l0000Uooooo`007_oo
ool00ol0003oooooooooo`2Gooooo`;o00008?ooool2o`0008Kooooo0_l00004ooooo`007_ooool0
0ol0003oooooooooo`1[ooooo`;o00004Oooool2o`000;Kooooo0_l00009ooooo`;o00001?ooool0
01kooooo00?o0000ooooooooool04?ooool2o`0002Kooooo0_l0000Kooooo`;o00005?ooool2o`00
00Sooooo0_l00007ooooo`;o00009oooool2o`0008?ooooo0_l00008ooooo`;o00003oooool001ko
oooo00Co0000oooooooooooooooo0_l0000=ooooo`;o00009_ooool2o`0001_ooooo0_l00006oooo
o`;o00004Oooool2o`0000?ooooo0_l00009ooooo`;o00009Oooool2o`0008?ooooo0_l0000Ioooo
o`007_ooool01?l0003oooooooooooooool3o`0005Wooooo0_l0000Aooooo`;o00003_ooool2o`00
00oooooo0_l0002Eooooo`;o00007Oooool001kooooo00?o0000ooooooooool00_ooool2o`0004ko
oooo0_l0000Eooooo`;o00009_ooool2o`0002oooooo0_l0000Booooo`;o0000D?ooool2o`0001go
oooo000Nooooo`03o`000?oooooooooo05;ooooo0_l0000Eooooo`;o00002Oooool2o`0004cooooo
0_l0000Booooo`;o00003_ooool2o`0005oooooo000Nooooo`03o`000?oooooooooo07Cooooo0_l0
000Nooooo`;o00001_ooool2o`0003Sooooo0_l0000>ooooo`;o0000A?ooool2o`0001Wooooo000N
ooooo`03o`000?oooooooooo09Cooooo0_l00006ooooo`;o0000C?ooool2o`0002Gooooo0_l00009
ooooo`;o00000_ooool2o`0000[ooooo0_l0000Iooooo`007_ooool00ol0003oooooooooo`0aoooo
o`;o0000:Oooool4o`0002kooooo0_l0000iooooo`;o00007oooool2o`0002Gooooo0_l00009oooo
o`;o00000_ooool2o`0002Gooooo000Nooooo`03o`000?oooooooooo037ooooo0_l0000Yooooo`Co
0000;_ooool2o`0003Wooooo0_l0001Eooooo`;o00009Oooool001kooooo00?o0000ooooooooool0
9oooool2o`0000kooooo0_l0000Rooooo`;o0000Moooool2o`00077ooooo000Nooooo`03o`000?oo
oooooooo00[ooooo0_l0000Kooooo`;o00003_ooool2o`0002;ooooo0_l0001gooooo`;o00009?oo
ool2o`0004_ooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0002_ooooo`?o00004Oooool2
o`0002Wooooo0_l0001;ooooo`007_ooool00ol0003oooooooooo`02o`0006Kooooo0_l0000Aoooo
o`;o0000?_ooool3o`00017ooooo0ol0000Tooooo`;o0000Coooool001kooooo0_l000000ooooooo
0000o`00000booooo`;o00009Oooool2o`0000_ooooo0_l0000Aooooo`;o0000Doooool2o`0002Co
oooo0_l0000fooooo`;o00005oooool001kooooo00?o0000ooooooooool07oooool2o`0001?ooooo
0_l0000Uooooo`?o0000Voooool2o`0002gooooo0_l00004ooooo`;o00005oooool001kooooo00?o
0000ooooooooool07oooool2o`0003;ooooo0_l00007ooooo`;o00009?ooool2o`0007Gooooo0_l0
000]ooooo`;o00001Oooool2o`0001Kooooo000Nooooo`03o`000?oooooooooo00gooooo0_l00014
ooooo`;o0000;Oooool2o`0008gooooo0_l0000Looooo`;o00005_ooool001kooooo00?o0000oooo
ooooool03Oooool2o`0003Oooooo0_l0002:ooooo`;o0000?Oooool2o`0000gooooo0_l0000Uoooo
o`007_ooool00ol0003oooooooooo`0>ooooo`;o00000oooool2o`0001Wooooo0_l00009ooooo`;o
00002oooool2o`0008[ooooo0_l0001<ooooo`;o00009Oooool001kooooo00?o0000ooooooooool0
3_ooool2o`0000?ooooo0_l0000Iooooo`;o00002Oooool2o`0005kooooo0_l0000:ooooo`;o0000
X?ooool001kooooo00?o0000ooooooooool0P_ooool2o`0001Gooooo0_l0000:ooooo`;o0000X?oo
ool001kooooo00?o0000ooooooooool0BOooool2o`0003Oooooo0_l00008ooooo`;o00006Oooool2
o`0009kooooo000Nooooo`03o`000?oooooooooo023ooooo0_l0000Wooooo`;o0000@Oooool2o`00
01Wooooo0_l0000:ooooo`;o0000:_ooool2o`0005;ooooo0_l00006ooooo`;o00002_ooool001ko
oooo00?o0000ooooooooool08?ooool2o`0003Gooooo0_l0000Cooooo`;o0000AOooool2o`0002[o
oooo0_l0000<ooooo`;o0000<?ooool2o`0001;ooooo0_l00006ooooo`;o00002_ooool001kooooo
00?o0000ooooooooool0Eoooool4o`00017ooooo0_l0001oooooo`;o00006Oooool2o`0001Gooooo
0_l0000Vooooo`007_ooool00ol0003oooooooooo`1Iooooo`;o00003Oooool2o`0003kooooo0_l0
000fooooo`;o00009_ooool2o`0000[ooooo0_l00003ooooo`;o0000;?ooool001kooooo00?o0000
ooooooooool07oooool2o`0004Oooooo0_l0000nooooo`;o0000=_ooool2o`0003;ooooo0_l00003
ooooo`;o0000;?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0000Kooooo00?o0000ooooooooool07oooool2o`0003kooooo0_l0000Jooooo`;o0000b_ooool0
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Kooooo00?o0000ooooooooool0Goooool2o`0001[ooooo0_l0001?ooooo`;o00001Ooo
ool2o`0007;ooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^
kP07ooooo`?o0000Poooool2o`0004Oooooo0_l00005ooooo`;o0000<Oooool2o`0003oooooo0003
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oo
oooooooo013ooooo0_l0000`ooooo`;o0000?oooool2o`00087ooooo0_l0000oooooo`000oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`0@ooooo`;o0000<?ooool2o`0000[ooooo0_l0000jooooo`;o0000^oooool000?ooooo00Go410@
oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09Ooo
ool2o`0001Sooooo0_l0000=ooooo`;o0000>_ooool2o`00033ooooo0_l00029ooooo`000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`00
0?oooooooooo00Wooooo0_l0000Jooooo`;o00006?ooool2o`0007_ooooo0_l0000>ooooo`;o0000
E?ooool2o`0000gooooo0_l0000Dooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo00Wooooo0_l00019ooooo`;o
0000A?ooool2o`00033ooooo0_l000000ooooooo0000o`00000booooo`;o00007Oooool2o`0000go
oooo0_l0000Dooooo`007_ooool00ol0003oooooooooo`1Dooooo`;o0000=oooool2o`0000_ooooo
0_l0000cooooo`;o0000<_ooool2o`0000gooooo0_l0000cooooo`007_ooool00ol0003ooooooooo
o`2=ooooo`;o0000Koooool2o`0001;ooooo0_l0000cooooo`007_ooool00ol0003oooooooooo`1F
ooooo`;o0000Y_ooool2o`0000Sooooo0_l0000mooooo`007_ooool00ol0003oooooooooo`1Foooo
o`;o0000/?ooool2o`0001Kooooo0_l0000Uooooo`007_ooool00ol0003oooooooooo`1Sooooo`;o
00002Oooool2o`0001;ooooo0_l0000_ooooo`;o0000Joooool2o`0002Gooooo000Nooooo`03o`00
0?oooooooooo04_ooooo0_l0000Fooooo`;o00002Oooool2o`0000kooooo0_l00002ooooo`;o0000
;oooool2o`0001Kooooo0_l0001jooooo`007_ooool00ol0003oooooooooo`0Uooooo`;o00009?oo
ool2o`00037ooooo0_l0001;ooooo`;o0000N_ooool001kooooo00?o0000ooooooooool03?ooool2
o`0001Oooooo0_l00014ooooo`;o0000dOooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo
00cooooo0_l0001Dooooo`;o00001oooool2o`0008Gooooo0_l0001:ooooo`;o00001oooool001ko
oooo00?o0000ooooooooool0H_ooool2o`0008kooooo0_l0001Cooooo`007_ooool00ol0003ooooo
ooooo`2Pooooo`;o0000YOooool001kooooo0_l0001gooooo`;o0000:?ooool2o`0002Sooooo0_l0
001Pooooo`;o00006Oooool001kooooo00?o0000ooooooooool0M_ooool2o`0003Kooooo0_l0000J
ooooo`;o0000D?ooool2o`0000;ooooo0_l0000:ooooo`;o00006Oooool001kooooo00?o0000oooo
ooooool05?ooool4o`0002cooooo0_l00009ooooo`;o0000<_ooool2o`0002Wooooo0_l0001Coooo
o`;o00005oooool2o`0000;ooooo0_l0000:ooooo`;o00006Oooool001kooooo00?o0000oooooooo
ool05?ooool4o`0002;ooooo0_l00008ooooo`;o00002Oooool2o`0001Wooooo0_l0000Gooooo`;o
0000O_ooool2o`0002Oooooo0_l0000Iooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o0000
:oooool2o`0002kooooo0_l0000=ooooo`;o00003oooool2o`0008_ooooo0_l0000^ooooo`007_oo
ool00ol0003oooooooooo`0=ooooo`;o00001oooool2o`000003ooooool0003o000003[ooooo0_l0
000Rooooo`;o00003oooool2o`0008_ooooo0_l0000^ooooo`007_ooool00ol0003oooooooooo`0F
ooooo`;o000000?oooooo`000?l00000>_ooool2o`000:Sooooo0_l00016ooooo`007_ooool00ol0
003oooooooooo`3oooooo`;o0000A_ooool001kooooo00?o0000ooooooooool0W?ooool2o`00097o
oooo0_l0000Fooooo`007_ooool00ol0003oooooooooo`1mooooo`;o00007Oooool2o`00097ooooo
0_l0000Fooooo`007_ooool00ol0003oooooooooo`1/ooooo`;o00003oooool2o`000<Sooooo000N
ooooo`03o`000?oooooooooo03kooooo0_l0000/ooooo`;o00005oooool2o`0001gooooo0_l0001J
ooooo`;o00004oooool2o`000003ooooool0003o000002gooooo000Nooooo`03o`000?oooooooooo
03Sooooo0_l00004ooooo`;o00001oooool2o`0003cooooo0_l0000Mooooo`;o0000F_ooool2o`00
00Kooooo0_l0000;ooooo`;o000000?oooooo`000?l000003_ooool2o`0001gooooo000Nooooo`03
o`000?oooooooooo03Sooooo0_l0000=ooooo`Co00002oooool2o`0009Cooooo0_l0000Jooooo`;o
00007_ooool2o`0001gooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l00006ooooo`;o0000
2_ooool2o`0000oooooo0_l0000;ooooo`;o00001?ooool2o`000003ooooool0003o000006oooooo
0_l0000Jooooo`;o0000:oooool2o`0002cooooo000Nooooo`03o`000?oooooooooo02;ooooo1?l0
0006ooooo`;o00006oooool2o`00017ooooo0_l000000ooooooo0000o`00001_ooooo`;o00006_oo
ool2o`0002_ooooo0_l0000/ooooo`007_ooool2o`0001Wooooo0_l00008ooooo`;o0000oooooolT
ooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o0000h_ooool2o`0002cooooo0_l0000Koooo
o`007_ooool00ol0003oooooooooo`0;ooooo`;o00002oooool2o`000>;ooooo0_l0000/ooooo`;o
00006oooool001kooooo00?o0000ooooooooool00_l00009ooooo`;o00001oooool2o`000?oooooo
<_ooool001kooooo00?o0000ooooooooool00_l0000<ooooo`;o00001?ooool2o`00013ooooo0_l0
001[ooooo`;o00003oooool2o`0001cooooo0_l0000Wooooo`;o0000F_ooool001kooooo00?o0000
ooooooooool03_ooool2o`0000?ooooo0_l0000Aooooo`;o0000Joooool2o`0000oooooo0_l0000L
ooooo`;o00009oooool2o`0005[ooooo000Nooooo`03o`000?oooooooooo00Gooooo0_l00007oooo
o`;o00000oooool2o`0000?ooooo0_l0001kooooo`;o0000Loooool2o`0003?ooooo0_l00006oooo
o`007_ooool00ol0003oooooooooo`05ooooo`;o00004Oooool2o`0006;ooooo0_l0000Gooooo`;o
0000Eoooool2o`0001[ooooo0_l0000:ooooo`;o00007_ooool2o`0000Kooooo0ol00006ooooo`00
7_ooool00ol0003oooooooooo`1^ooooo`;o00003?ooool2o`00073ooooo0_l0000Vooooo`;o0000
7_ooool2o`0000Kooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`1^ooooo`;o0000c_oo
ool2o`0000Oooooo000Nooooo`03o`000?oooooooooo09cooooo0_l0002Hooooo`;o00003oooool0
01kooooo00?o0000ooooooooool0W?ooool2o`00077ooooo0_l0000Rooooo`;o000000?oooooo`00
0?l000003oooool001kooooo00?o0000ooooooooool02?ooool6o`0001Wooooo0_l00019ooooo`;o
0000O?ooool2o`0001gooooo0_l0000Rooooo`;o00004_ooool001kooooo00?o0000ooooooooool0
2?ooool6o`0001Wooooo0_l0000Uooooo`;o00008_ooool2o`0000gooooo0_l0001]ooooo`;o0000
0_ooool2o`00057ooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0000Eooooo`;o0000<Ooo
ool3o`00037ooooo0_l0000`ooooo`;o0000?oooool2o`0004_ooooo0_l00004ooooo`007_ooool0
0ol0003oooooooooo`03ooooo`;o00005Oooool2o`00037ooooo0_l0000>ooooo`;o0000E?ooool2
o`0004oooooo0_l0000kooooo`;o00001?ooool001kooooo0_l0001Nooooo`;o0000YOooool2o`00
047ooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0003Mooooo`;o00006oooool2o`0003Go
oooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0000:ooooo`;o00000_ooool2o`000=Wooooo
0_l0000Kooooo`;o00003_ooool2o`0002Gooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0
000>ooooo`;o0000J?ooool2o`0007oooooo0_l0000Kooooo`;o00009Oooool001kooooo00?o0000
ooooooooool0P_ooool2o`00077ooooo0_l0000<ooooo`;o00009oooool2o`0001Wooooo000Noooo
o`03o`000?oooooooooo03?ooooo0_l00009ooooo`;o0000Z_ooool2o`0000Wooooo0_l0000eoooo
o`;o00006Oooool001kooooo00?o0000ooooooooool07_ooool2o`0001?ooooo0_l00009ooooo`;o
0000Voooool2o`0000gooooo0_l0000@ooooo`;o0000BOooool001kooooo00?o0000ooooooooool0
1_ooool2o`0001Kooooo0ol0000eooooo`;o0000Poooool2o`0001oooooo0_l00003ooooo`;o0000
A?ooool001kooooo00?o0000ooooooooool01_ooool2o`00013ooooo0_l00005ooooo`;o0000=Ooo
ool2o`0006Oooooo0_l00010ooooo`;o0000A?ooool001kooooo00?o0000ooooooooool06?ooool2
o`000:3ooooo0_l00003ooooo`;o00001oooool2o`0007gooooo000Nooooo`03o`000?oooooooooo
04Cooooo0_l0001dooooo`;o00003?ooool2o`000003ooooool0003o000004_ooooo0_l0000]oooo
o`007_ooool00ol0003oooooooooo`0?ooooo`;o00007oooool2o`0001;ooooo0_l0001?ooooo`;o
0000=?ooool2o`0004_ooooo0_l00007ooooo`;o00009?ooool001kooooo00?o0000ooooooooool0
3oooool2o`0000[ooooo0_l00006ooooo`;o00000oooool2o`0000Kooooo0_l0000Zooooo`;o0000
3?ooool2o`0002Wooooo0_l0002:ooooo`;o00002oooool2o`0001Oooooo000Nooooo`03o`000?oo
oooooooo01Wooooo1?l00006ooooo`;o00000oooool2o`0003;ooooo0_l0000<ooooo`;o0000F?oo
ool2o`0006Sooooo0_l0000Gooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0Iooooo`;o0000ZOoo
ool2o`0005;ooooo0_l0000]ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolIooooo`;o0000;Ooo
ool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool3o`00067ooooo0_l0
003Tooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
1oooool00ol0003oooooooooo`0iooooo`;o00004?ooool2o`0000Cooooo0_l0000>ooooo`;o0000
cOooool2o`0001Gooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEE
ooooool00007ooooo`03o`000?oooooooooo03Wooooo0_l0000@ooooo`;o00001?ooool2o`000=go
oooo0_l0000Eooooo`000oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l0
00001oooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo07;ooooo0_l0003Cooooo`00
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003o
ooooooooo`0Looooo`;o00007Oooool2o`0003Gooooo0_l0000Aooooo`;o00000oooool2o`0008Co
oooo0_l0000eooooo`007_ooool00ol0003oooooooooo`0Looooo`;o00007Oooool2o`0004Sooooo
0_l00003ooooo`;o0000NOooool2o`0000Wooooo0_l0000eooooo`007_ooool00ol0003ooooooooo
o`0eooooo`;o0000c_ooool2o`0003;ooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`0e
ooooo`;o00000_ooool2o`000=oooooo1?l0000Kooooo`;o00003?ooool001kooooo00?o0000oooo
ooooool08_ooool2o`0001Cooooo0ol00018ooooo`;o0000UOooool4o`0002Wooooo000Nooooo`03
o`000?oooooooooo01?ooooo0_l0000=ooooo`;o00005?ooool2o`0004;ooooo0_l00005ooooo`;o
0000U?ooool2o`0002cooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0000?ooooo`;o0000
Ioooool2o`0009_ooooo0_l0000/ooooo`007_ooool00ol0003oooooooooo`02ooooo`;o00009_oo
ool2o`000<kooooo0_l0000Mooooo`;o0000;?ooool001kooooo00?o0000ooooooooool05_ooool2
o`0001;ooooo0_l0002oooooo`;o00003Oooool2o`0001Cooooo0_l00007ooooo`;o0000;?ooool0
01kooooo00?o0000ooooooooool05_ooool2o`0007Gooooo0_l0001Looooo`;o00008oooool2o`00
02Kooooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`2=ooooo`;o0000I_ooool2o`0003;o
oooo0_l0000=ooooo`;o00003Oooool001kooooo00?o0000ooooooooool0f?ooool2o`0001_ooooo
0_l0000booooo`;o00007?ooool001kooooo0_l0000Vooooo`;o0000;oooool2o`00083ooooo0_l0
001Jooooo`;o00004Oooool001kooooo00?o0000ooooooooool07?ooool2o`0000Oooooo0_l00008
ooooo`;o00009Oooool2o`0003Cooooo0_l00010ooooo`;o0000F?ooool2o`0000[ooooo0_l0000A
ooooo`007_ooool00ol0003oooooooooo`0Looooo`;o00004Oooool2o`0004gooooo0_l00007oooo
o`;o00000oooool2o`00043ooooo0_l0001Hooooo`;o00007Oooool001kooooo00?o0000oooooooo
ool03Oooool2o`0006oooooo0_l00007ooooo`;o0000__ooool001kooooo00?o0000ooooooooool0
3Oooool2o`0000oooooo0_l00027ooooo`;o0000W_ooool001kooooo00?o0000ooooooooool07_oo
ool2o`0000kooooo0_l0001gooooo`;o000000?oooooo`000?l00000Voooool001kooooo00?o0000
ooooooooool0;_ooool2o`0001Cooooo0_l0001:ooooo`;o00006?ooool2o`0000_ooooo0_l00002
ooooo`;o0000R_ooool001kooooo00?o0000ooooooooool0A?ooool2o`0000Kooooo0_l0000Uoooo
o`;o00006oooool2o`0000Sooooo0_l0000Kooooo`;o00000_ooool2o`0008[ooooo000Nooooo`03
o`000?oooooooooo04cooooo0_l0000Uooooo`;o00009Oooool2o`0006Oooooo0_l00012ooooo`00
7_ooool00ol0003oooooooooo`3Booooo`;o00001?ooool2o`0001Sooooo0_l0000?ooooo`;o0000
@_ooool001kooooo00?o0000ooooooooool02_ooool2o`0006oooooo0_l0000`ooooo`;o000000?o
ooooo`000?l000008?ooool2o`0000Cooooo0_l0000Hooooo`;o0000@Oooool2o`00013ooooo000N
ooooo`03o`000?oooooooooo00[ooooo0_l0001=ooooo`;o00004Oooool2o`0000gooooo0ol0000_
ooooo`;o000000?oooooo`000?l000006Oooool2o`0004Oooooo0_l0000Oooooo`;o00004?ooool0
01kooooo00?o0000ooooooooool0=oooool2o`00023ooooo0_l00005ooooo`;o00002_ooool2o`00
00kooooo0_l0000Yooooo`;o00008_ooool2o`0004Oooooo0_l00005ooooo`;o0000:_ooool001ko
oooo00?o0000ooooooooool03_ooool2o`0001gooooo0_l00008ooooo`;o00003_ooool2o`0001Oo
oooo0_l0000mooooo`;o00001_ooool2o`0005[ooooo0_l0000Fooooo`;o0000:_ooool001kooooo
00?o0000ooooooooool03_ooool2o`0001gooooo0_l0000Hooooo`;o00008Oooool2o`0003?ooooo
0_l0001Rooooo`;o0000@_ooool001kooooo00?o0000ooooooooool0@?ooool2o`0002Sooooo0_l0
0004ooooo`;o00008oooool2o`000003ooooool0003o00000:gooooo000Nooooo`;o0000@Oooool2
o`0000Kooooo0_l0000:ooooo`;o00006_ooool2o`0000Oooooo0_l00002ooooo`;o00005_ooool2
o`000003ooooool0003o000007oooooo0_l0000/ooooo`007_ooool00ol0003oooooooooo`0Goooo
o`;o0000;oooool2o`0000[ooooo0_l0000Sooooo`;o00000_ooool2o`0002Gooooo0_l0001Joooo
o`;o00000_ooool2o`0000cooooo0_l00005ooooo`;o0000;?ooool001kooooo00?o0000oooooooo
ool05oooool2o`0008_ooooo0_l000000ooooooo0000o`000004ooooo`;o0000DOooool2o`0000;o
oooo0_l0000<ooooo`;o0000<oooool001kooooo00?o0000ooooooooool0=Oooool3o`0006oooooo
0_l00004ooooo`;o0000N_ooool2o`000003ooooool0003o000001Wooooo000Nooooo`03o`000?oo
oooooooo03Gooooo0ol00029ooooo`;o0000I_ooool2o`000003ooooool0003o000000cooooo0_l0
000;ooooo`007_ooool00ol0003oooooooooo`0Looooo`;o00002Oooool2o`0001_ooooo0_l0000`
ooooo`;o0000<oooool2o`0001Cooooo0_l00011ooooo`;o00007_ooool2o`0001Cooooo0_l0000;
ooooo`007_ooool00ol0003oooooooooo`0Looooo`;o00002Oooool2o`0001_ooooo0_l0000:oooo
o`;o00007Oooool2o`0000Gooooo0_l00004ooooo`;o0000;Oooool2o`0005Oooooo0_l0000Noooo
o`;o00008Oooool001kooooo00?o0000ooooooooool0D?ooool2o`0001gooooo0_l0000;ooooo`;o
00004?ooool2o`000;Oooooo000Nooooo`03o`000?oooooooooo07Cooooo0_l0000Hooooo`;o0000
3oooool2o`0000cooooo0_l0000Vooooo`;o0000L?ooool001kooooo00?o0000ooooooooool04?oo
ool2o`0002kooooo0_l0000booooo`;o0000:Oooool2o`0000cooooo0_l0000Vooooo`;o00000ooo
ool2o`0003Oooooo0_l0000Zooooo`;o00001_ooool001kooooo00?o0000ooooooooool04?ooool2
o`0002kooooo0_l0002Hooooo`;o0000=oooool2o`0002[ooooo0_l00006ooooo`007_ooool00ol0
003oooooooooo`0;ooooo`;o0000oooooolkooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o
0000Z_ooool2o`0002Gooooo0_l0000aooooo`;o0000=?ooool001kooooo00?o0000ooooooooool0
1_ooool2o`0001Gooooo0_l0000eooooo`;o0000HOooool2o`0002Gooooo0_l0000aooooo`;o0000
=?ooool001kooooo00?o0000ooooooooool01_ooool2o`0001Gooooo1?l0000cooooo`;o0000lOoo
ool001kooooo00?o0000ooooooooool07oooool2o`0002_ooooo0_l0002eooooo`;o00008?ooool2
o`00023ooooo000Nooooo`;o0000COooool2o`0007[ooooo0_l0000iooooo`;o00008?ooool2o`00
023ooooo000Nooooo`03o`000?oooooooooo00cooooo0_l0002jooooo`;o00009?ooool2o`0005Oo
oooo000Nooooo`03o`000?oooooooooo00cooooo0_l0003Pooooo`;o0000Eoooool001kooooo00?o
0000ooooooooool0VOooool2o`000:cooooo000Nooooo`03o`000?oooooooooo09Wooooo0_l0001e
ooooo`;o0000=Oooool001kooooo00?o0000ooooooooool0@Oooool2o`0003Oooooo0_l0000Boooo
o`;o00009Oooool3o`0005Sooooo0_l0000Yooooo`;o00002_ooool001kooooo00?o0000oooooooo
ool03?ooool2o`0000Sooooo0_l00005ooooo`;o00007?ooool2o`0000Cooooo0_l00006ooooo`;o
0000;oooool2o`0000Oooooo0_l00002ooooo`;o00001Oooool2o`0002Gooooo0ol00023ooooo`;o
00002_ooool001kooooo00?o0000ooooooooool03?ooool2o`0000Sooooo0_l00005ooooo`;o0000
7?ooool2o`0000cooooo0_l0000hooooo`;o00000_ooool2o`00027ooooo0_l0001Zooooo`;o0000
;oooool001kooooo00?o0000ooooooooool05oooool2o`00097ooooo0_l0001Zooooo`;o00008?oo
ool2o`000003ooooool0003o000000[ooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0001]
ooooo`;o0000/?ooool2o`000003ooooool0003o000000[ooooo000Nooooo`03o`000?oooooooooo
04Sooooo0_l0000Gooooo`;o00002?ooool2o`0001Wooooo0_l0000;ooooo`;o00003oooool2o`00
04[ooooo0_l0001Eooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o0000;?ooool2o`0001Oo
oooo0_l00008ooooo`;o00008?ooool2o`0000Cooooo0_l0000?ooooo`;o0000B_ooool2o`0002So
oooo0_l000000ooooooo0000o`00000Xooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o0000
LOooool2o`0008_ooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000002;o
oooo000Nooooo`03o`000?oooooooooo08Gooooo0_l0001Looooo`;o0000>oooool2o`000003oooo
ool0003o000002;ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo08Gooooo0_l0001Dooooo`;o
00001_ooool2o`0003cooooo0_l0000Iooooo`;o00002Oooool000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000oooo
ooooool05?ooool2o`0000gooooo0_l00004ooooo`;o00004?ooool2o`00053ooooo0_l0000Moooo
o`;o0000;Oooool2o`0004Cooooo0_l0000Iooooo`;o00002Oooool000?ooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`0001Cooooo0_l0000=
ooooo`;o00001?ooool2o`00013ooooo0_l0000:ooooo`;o000000?oooooo`000?l00000<_ooool2
o`0000gooooo0_l0000Mooooo`;o0000VOooool000?ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0?ooooo`;o0000=_oo
ool2o`000003ooooool0003o0000033ooooo1?l0002Sooooo`;o00008_ooool000?ooooo00Go0000
ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003ooooo
ooooo`0?ooooo`;o0000=Oooool2o`0002?ooooo0_l0000?ooooo`;o0000YOooool2o`0002;ooooo
0003ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`00
0?oooooooooo04Kooooo0_l0000;ooooo`;o00005_ooool2o`0007;ooooo0_l0000Dooooo`;o0000
D?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo
00?o0000ooooooooool0Doooool2o`00087ooooo0_l00007ooooo`;o00005?ooool2o`00053ooooo
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03
o`000?oooooooooo00Cooooo0_l0003@ooooo`;o00007Oooool2o`00047ooooo0_l0000=ooooo`00
7_ooool00ol0003oooooooooo`04ooooo`;o0000Loooool2o`0000[ooooo0_l0001Yooooo`;o0000
0oooool2o`00047ooooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o00008ooo
ool2o`0003;ooooo0_l0000:ooooo`;o0000JOooool2o`0002?ooooo0_l00007ooooo`;o00008?oo
ool2o`0000Gooooo000Nooooo`03o`000?oooooooooo023ooooo0_l0000Sooooo`;o0000>_ooool2
o`0006gooooo0_l0000Sooooo`;o00001oooool2o`00023ooooo0_l00005ooooo`007_ooool00ol0
003oooooooooo`21ooooo`Co0000`_ooool001kooooo00?o0000ooooooooool02?ooool2o`0002;o
oooo0_l0000Oooooo`;o0000=?ooool2o`0004Sooooo0_l0001Xooooo`;o00003_ooool001kooooo
00?o0000ooooooooool02?ooool2o`0000Gooooo0_l0000Kooooo`;o00007oooool2o`00013ooooo
0_l00019ooooo`;o00008Oooool2o`0004cooooo0_l0000Jooooo`?o00003Oooool001kooooo00?o
0000ooooooooool03oooool2o`0003Gooooo0_l0000Gooooo`;o0000BOooool2o`0006Gooooo0_l0
0008ooooo`;o00006oooool2o`0000gooooo000Nooooo`03o`000?oooooooooo01?ooooo0_l0000a
ooooo`?o0000b?ooool2o`0003Cooooo000Nooooo`03o`000?oooooooooo01?ooooo0_l0000boooo
o`;o0000Woooool2o`0000cooooo0_l0001?ooooo`007_ooool00ol0003oooooooooo`1_ooooo`;o
0000>_ooool2o`0003_ooooo0_l0000<ooooo`;o0000Coooool001kooooo0_l0000=ooooo`;o0000
1oooool2o`0004gooooo0_l00009ooooo`;o00004?ooool2o`0002Sooooo0_l0000Uooooo`;o0000
??ooool2o`0002kooooo0_l00005ooooo`007_ooool2o`0000gooooo0_l00007ooooo`;o00003_oo
ool2o`0003gooooo0_l0000Kooooo`;o00008?ooool2o`0000oooooo0_l0000Looooo`;o0000??oo
ool2o`0002kooooo0_l00005ooooo`007_ooool00ol0003oooooooooo`0Uooooo`;o0000F?ooool2
o`0002;ooooo0_l0000?ooooo`;o0000EOooool2o`0003[ooooo000Nooooo`03o`000?oooooooooo
07oooooo0_l0002:ooooo`;o0000>_ooool001kooooo00?o0000ooooooooool0Qoooool2o`0002oo
oooo0_l0002=ooooo`007_ooool00ol0003oooooooooo`1Gooooo`;o0000;_ooool2o`0002Kooooo
0_l00007ooooo`;o0000@oooool2o`0003Gooooo0_l00002ooooo`;o00003Oooool001kooooo00?o
0000ooooooooool0Eoooool2o`0002Gooooo0_l0000<ooooo`;o00000_ooool2o`0001gooooo0_l0
000Jooooo`;o0000<?ooool2o`0003?ooooo1?l00002ooooo`;o00001Oooool2o`0000Kooooo000N
ooooo`03o`000?oooooooooo05Kooooo0_l0000Vooooo`;o00003?ooool2o`0000;ooooo0_l0000?
ooooo`;o0000:?ooool2o`0006Gooooo0_l0000;ooooo`;o00001_ooool001kooooo00?o0000oooo
ooooool0E_ooool2o`0004Wooooo0_l0000Mooooo`;o0000??ooool2o`0003;ooooo0_l0000Coooo
o`007_ooool00ol0003oooooooooo`1Mooooo`;o0000HOooool2o`0003cooooo0_l00017ooooo`00
7_ooool00ol0003oooooooooo`0looooo`;o00007oooool2o`0002Sooooo0_l0000=ooooo`;o0000
>?ooool2o`0005[ooooo0_l0000Iooooo`007_ooool00ol0003oooooooooo`0looooo`;o00004?oo
ool2o`0001oooooo0_l0000Fooooo`;o00003Oooool2o`0001;ooooo0_l0000Tooooo`;o0000BOoo
ool2o`0000oooooo0_l0000Iooooo`007_ooool00ol0003oooooooooo`02ooooo`;o00001oooool2
o`0003Cooooo0_l0000;ooooo`;o00004_ooool2o`0000_ooooo0_l0000_ooooo`;o00002?ooool2
o`0000;ooooo0_l0000=ooooo`;o0000Boooool2o`0000oooooo0_l0000Zooooo`007_ooool00ol0
003oooooooooo`02ooooo`;o00001oooool2o`0000Kooooo0_l0000>ooooo`;o00007?ooool2o`00
01oooooo0_l0000looooo`;o00003?ooool2o`0000gooooo0_l0000looooo`;o00003Oooool2o`00
03_ooooo000Nooooo`03o`000?oooooooooo00oooooo0_l00002ooooo`Co00003?ooool2o`0003go
oooo0_l0000Gooooo`;o0000O_ooool2o`0001kooooo0_l0000Zooooo`007_ooool00ol0003ooooo
ooooo`0?ooooo`;o00001?ooool2o`0006Cooooo0_l0001;ooooo`;o0000DOooool2o`0001Kooooo
0_l0000Booooo`007_ooool00ol0003oooooooooo`07ooooo`;o0000<_ooool2o`0003?ooooo0_l0
001Fooooo`;o00005_ooool2o`00057ooooo0_l0000Booooo`007_ooool2o`0000Sooooo0_l0000b
ooooo`;o0000<oooool2o`0002_ooooo0_l00011ooooo`;o0000A?ooool2o`0001oooooo000Noooo
o`03o`000?oooooooooo01cooooo0_l0000eooooo`;o0000B?ooool2o`00017ooooo0_l0000Coooo
o`;o00001_ooool2o`0005Oooooo0_l0000Oooooo`007_ooool00ol0003oooooooooo`0Looooo`;o
0000=Oooool2o`0000gooooo0_l0001<ooooo`;o00004oooool2o`0000Kooooo0_l0001hooooo`00
7_ooool00ol0003oooooooooo`0jooooo`;o00008oooool2o`000003ooooool0003o00000:7ooooo
0_l00010ooooo`007_ooool00ol0003oooooooooo`07ooooo`;o00008?ooool2o`0000oooooo0_l0
000Sooooo`;o0000=?ooool2o`0006kooooo0_l00010ooooo`007_ooool3o`0000Oooooo0_l0000P
ooooo`;o0000<Oooool2o`0002oooooo0_l00006ooooo`;o0000Moooool2o`0003Oooooo000Noooo
o`?o0000G?ooool2o`0002oooooo0_l00006ooooo`;o0000Moooool2o`0003Oooooo000Nooooo`03
o`000?oooooooooo07Wooooo0_l0000Jooooo`;o00005oooool2o`0007gooooo0_l0000Hooooo`00
7_ooool00ol0003oooooooooo`0Wooooo`;o00003_ooool2o`0001;ooooo0_l0000Yooooo`;o0000
00?oooooo`000?l000006Oooool2o`0001Sooooo0_l00006ooooo`;o0000Foooool2o`0001Sooooo
0_l0000Hooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o00005_ooool2o`0000kooooo0_l0
000Booooo`;o0000:Oooool2o`00017ooooo0_l00009ooooo`;o00003?ooool2o`0001;ooooo0_l0
001Kooooo`;o0000<_ooool001kooooo00?o0000ooooooooool00_ooool2o`0000_ooooo0_l0000e
ooooo`;o00007?ooool2o`0002?ooooo0_l0000Gooooo`;o0000J?ooool2o`0003Wooooo000Noooo
o`03o`000?oooooooooo00;ooooo0_l00012ooooo`;o00007?ooool2o`0006;ooooo0_l0000Moooo
o`;o00008oooool2o`0003Wooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0000]ooooo`;o
00007Oooool2o`0000Oooooo0_l0000Zooooo`;o0000@Oooool2o`0001gooooo0_l0001Nooooo`00
7_ooool00ol0003oooooooooo`02ooooo`;o00006?ooool2o`0001?ooooo0_l0000Mooooo`;o0000
1oooool2o`0002[ooooo0_l0000Qooooo`;o0000WOooool001kooooo00?o0000ooooooooool02ooo
ool2o`0000oooooo0_l0000Uooooo`;o0000Hoooool2o`0008oooooo0_l0000<ooooo`007_ooool0
0ol0003oooooooooo`0:ooooo`?o00002?ooool2o`0002cooooo0_l0000hooooo`;o0000>_ooool2
o`00063ooooo0_l0000Looooo`;o00003?ooool001kooooo0_l0000;ooooo`;o00002Oooool2o`00
06Kooooo0_l0000jooooo`;o00004Oooool2o`0001kooooo0_l0000]ooooo`;o0000:_ooool001ko
oooo00?o0000ooooooooool0Aoooool2o`0005cooooo0_l0000?ooooo`;o00004_ooool4o`0001ko
oooo0_l00006ooooo`;o00006Oooool2o`0002kooooo0_l00006ooooo`007_ooool00ol0003ooooo
ooooo`17ooooo`;o0000G?ooool2o`0000oooooo0_l0000Booooo`;o0000:?ooool2o`0001Wooooo
0_l0000^ooooo`;o00001_ooool001kooooo00?o0000ooooooooool02Oooool2o`000?oooooo?Ooo
ool001kooooo00?o0000ooooooooool01_ooool2o`000003ooooool0003o000001Wooooo0_l0000F
ooooo`;o0000Eoooool2o`0002gooooo0_l00021ooooo`007_ooool00ol0003oooooooooo`06oooo
o`;o00007?ooool2o`0001Kooooo0_l0001Gooooo`;o00009oooool2o`0000Cooooo0_l00021oooo
o`007_ooool00ol0003oooooooooo`1Iooooo`;o0000Hoooool2o`0001?ooooo0_l00015ooooo`;o
00005?ooool2o`0001Gooooo000Nooooo`03o`000?oooooooooo05Wooooo0_l0000Iooooo`;o0000
@oooool2o`0001Sooooo0_l0000cooooo`;o00004?ooool2o`0001Cooooo0_l0000Eooooo`007_oo
ool2o`0004Cooooo0_l0000_ooooo`;o00009Oooool2o`0001cooooo0_l0000`ooooo`;o000000?o
ooooo`000?l000003_ooool2o`0000Sooooo0_l0000mooooo`007_ooool2o`0000;ooooo0_l00010
ooooo`;o0000D_ooool2o`0000;ooooo0_l0000Vooooo`;o00009_ooool2o`000003ooooool0003o
000000kooooo0_l00017ooooo`007_ooool01?l0003oooooooooooooool2o`0000cooooo0_l0001]
ooooo`;o00005oooool2o`0002[ooooo0_l0001Eooooo`;o000000?oooooo`000?l00000:?ooool0
01kooooo00?o0000ooooooooool03oooool2o`0002Sooooo0_l0000Aooooo`;o00003Oooool2o`00
00_ooooo0_l0000Dooooo`;o0000=?ooool2o`0005[ooooo0_l00008ooooo`;o000000?oooooo`00
0?l00000:?ooool001kooooo00?o0000ooooooooool0>Oooool2o`00017ooooo0_l0000=ooooo`;o
00002oooool2o`0001?ooooo0_l00009ooooo`;o0000:_ooool2o`0005[ooooo0_l0000Cooooo`;o
00006_ooool2o`0000Cooooo000Nooooo`03o`000?oooooooooo06kooooo0_l0000=ooooo`;o0000
2Oooool2o`0009_ooooo0_l0000?ooooo`;o00002Oooool2o`0000Cooooo0003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03
o`000?oooooooooo01Cooooo0_l0001Hooooo`;o0000P_ooool2o`0004;ooooo0_l0000?ooooo`00
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRH
V?lQ8B401_ooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`0000Wooooo0_l0001Hoooo
o`;o0000:?ooool2o`0005Sooooo0_l00012ooooo`;o00003oooool000?ooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`0000?ooooo0_l00004
ooooo`;o0000Eoooool2o`0003Cooooo0_l0000Eooooo`;o00007oooool2o`0007Gooooo0003oooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o
0000ooooooooool0H_ooool2o`0000Oooooo0_l00003ooooo`;o0000?Oooool2o`0001oooooo0_l0
001Eooooo`;o00007_ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0
003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`0Xooooo`;o00003?ooool2o`0003?ooooo
0_l00003ooooo`;o0000S_ooool2o`0002Gooooo0_l0000Nooooo`000oooool01Ol@413ooooooooo
oooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo02So
oooo0_l0000<ooooo`Co00001_ooool2o`00027ooooo0_l0002Aooooo`;o00002?ooool2o`0004Go
oooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o0000
00Kooooo0_l0000iooooo`;o00001_ooool2o`00027ooooo0_l00004ooooo`;o00005oooool2o`00
01Oooooo0_l0000;ooooo`;o0000C?ooool2o`0003Oooooo0_l0000Fooooo`000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`;o00005Oooool2
o`0004Gooooo0_l0000<ooooo`;o00005oooool2o`0001Oooooo0_l0000;ooooo`;o00006?ooool2
o`0001Wooooo0_l0000Tooooo`;o0000:_ooool2o`0001Kooooo000Nooooo`03o`000?oooooooooo
01Cooooo0_l0000Sooooo`;o00008?ooool2o`0005cooooo0_l00007ooooo`;o00006Oooool2o`00
02Cooooo0_l00012ooooo`007_ooool00ol0003oooooooooo`0Xooooo`;o00003oooool4o`0000;o
oooo0_l00017ooooo`;o0000;oooool2o`0005?ooooo0_l0000:ooooo`;o00001Oooool2o`0002Co
oooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0000Nooooo`;o00003oooool4o`0000;ooooo
0_l0000Mooooo`;o0000:?ooool2o`0000?ooooo0_l0001oooooo`;o00002_ooool2o`0000Gooooo
0_l00002ooooo`;o00003oooool2o`0000oooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0
000^ooooo`;o00004_ooool2o`00013ooooo0_l0000]ooooo`;o0000JOooool2o`0002_ooooo0_l0
000?ooooo`;o00003oooool001kooooo00?o0000ooooooooool0=_ooool4o`00013ooooo1?l0000P
ooooo`;o00001_ooool2o`0004Sooooo0_l0000fooooo`;o00006Oooool2o`0003;ooooo000Noooo
o`03o`000?oooooooooo01[ooooo0_l0000Jooooo`;o00001oooool2o`0000Wooooo0_l0000Doooo
o`;o00003?ooool2o`0000Kooooo0_l0000Tooooo`;o00008_ooool2o`00057ooooo0_l00007oooo
o`;o0000:Oooool001kooooo00?o0000ooooooooool06_ooool2o`0002?ooooo0_l0000Oooooo`;o
00004?ooool2o`0002Cooooo0_l00002ooooo`;o0000O_ooool2o`0001Kooooo0_l0000Aooooo`00
7_ooool00ol0003oooooooooo`0gooooo`;o0000>Oooool2o`0002Cooooo0_l0002Gooooo`;o0000
00?oooooo`000?l000004Oooool001gooooo0_l0000iooooo`;o0000]?ooool2o`0000?ooooo0_l0
000mooooo`;o00005?ooool001gooooo0_l0003>ooooo`;o00001?ooool2o`0001Wooooo0_l00003
ooooo`;o0000Doooool001kooooo00?o0000ooooooooool0E_ooool2o`0007Cooooo0_l00004oooo
o`;o0000Loooool001kooooo0_l00002ooooo`;o0000Doooool2o`00037ooooo0_l0000=ooooo`;o
0000[Oooool001kooooo00Co0000oooooooooooooooo0_l00024ooooo`Co00001Oooool2o`000003
ooooool0003o000000?ooooo0_l0002]ooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o0000
K?ooool2o`0000Oooooo0_l00007ooooo`;o000000?oooooo`000?l000006?ooool4o`000003oooo
ool0003o000004cooooo0_l00015ooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o00009ooo
ool2o`0004?ooooo0_l0000]ooooo`Co000000?oooooo`000?l000008Oooool2o`0002Wooooo0_l0
0015ooooo`007_ooool00ol0003oooooooooo`0iooooo`;o0000ROooool4o`0000gooooo0_l0001`
ooooo`007_ooool00ol0003oooooooooo`2Mooooo`;o00009Oooool4o`0007oooooo000Nooooo`03
o`000?oooooooooo063ooooo0_l0000_ooooo`;o00002_ooool2o`0001kooooo1?l00026ooooo`00
7_ooool00ol0003oooooooooo`1Pooooo`;o00002oooool2o`0002;ooooo0_l0000Zooooo`Co0000
Q_ooool001kooooo00?o0000ooooooooool0KOooool2o`000=Sooooo000Nooooo`03o`000?oooooo
oooo05;ooooo0_l0000looooo`;o0000A_ooool2o`0006gooooo000Nooooo`03o`000?oooooooooo
04gooooo0_l00003ooooo`;o0000??ooool2o`0004Kooooo0_l0000Jooooo`;o0000DOooool001ko
oooo00?o0000ooooooooool0COooool2o`0004cooooo0_l0000Cooooo`;o00001_ooool2o`0000[o
oooo0_l0000Zooooo`;o00000_ooool2o`00057ooooo000Nooooo`03o`000?oooooooooo02[ooooo
0_l0001Iooooo`;o00005?ooool2o`00013ooooo0_l000000ooooooo0000o`000006ooooo`;o0000
2_ooool2o`0000oooooo0_l0000Iooooo`;o0000:Oooool2o`0002[ooooo000Nooooo`03o`000?oo
oooooooo02?ooooo0_l00005ooooo`;o0000Aoooool2o`00013ooooo0_l0000Booooo`;o000000?o
ooooo`000?l000003oooool2o`0002Kooooo0_l00014ooooo`;o0000:_ooool001kooooo00?o0000
ooooooooool08oooool2o`0004kooooo0_l0000Tooooo`;o000000?oooooo`000?l00000ZOooool0
01kooooo00?o0000ooooooooool0?_ooool2o`0002Sooooo0_l00003ooooo`;o00006Oooool2o`00
01Sooooo0_l0002Eooooo`;o00003?ooool001kooooo0_l0000oooooo`;o0000:?ooool2o`0000?o
oooo0_l0000Iooooo`;o00006?ooool2o`00083ooooo0_l0000@ooooo`;o000000?oooooo`000?l0
00003?ooool001kooooo00?o0000ooooooooool04_ooool2o`0009Gooooo0_l0001iooooo`;o0000
1oooool2o`0000Oooooo0_l0000?ooooo`007_ooool00ol0003oooooooooo`0Booooo`;o0000UOoo
ool2o`0008;ooooo0_l00009ooooo`;o00003Oooool001kooooo00?o0000ooooooooool0J?ooool2
o`0004cooooo0_l00020ooooo`;o00003Oooool001kooooo00?o0000ooooooooool00_ooool2o`00
03_ooooo0_l0000Wooooo`;o0000C?ooool2o`0003Cooooo0_l0001Iooooo`007_ooool00ol0003o
ooooooooo`02ooooo`;o0000>oooool2o`000:_ooooo0_l0001Iooooo`007_ooool3o`000?oooooo
B?ooool001kooooo0ol0000?ooooo`;o0000oooooolgooooo`007_ooool00ol0003oooooooooo`0=
ooooo`Co0000;oooool4o`0001Cooooo0_l0001eooooo`;o00007Oooool2o`0001Sooooo0_l0000;
ooooo`;o00001oooool2o`0002Oooooo000Nooooo`03o`000?oooooooooo00gooooo0_l0000aoooo
o`Co00005?ooool2o`0001Gooooo0_l00004ooooo`;o0000F?ooool2o`0001_ooooo1?l0000Hoooo
o`;o00002oooool2o`0000Oooooo0_l0000Iooooo`;o00003?ooool001kooooo00?o0000oooooooo
ool08_ooool2o`0001kooooo0_l0000[ooooo`;o00001?ooool2o`00027ooooo0_l0001Booooo`;o
0000Boooool2o`0000cooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l0000Jooooo`;o0000
2oooool2o`0002?ooooo0_l0000mooooo`;o00000oooool2o`0006Sooooo0_l00013ooooo`007_oo
ool00ol0003oooooooooo`06ooooo`;o00009oooool2o`0000Wooooo0_l0000Hooooo`;o00004?oo
ool3o`0002[ooooo0_l0000Rooooo`;o0000=Oooool2o`0001;ooooo0_l0000Fooooo`;o00007ooo
ool2o`0000[ooooo000Nooooo`03o`000?oooooooooo023ooooo0_l0000Hooooo`;o00007?ooool2
o`0000cooooo0ol0001>ooooo`;o0000=Oooool2o`0002[ooooo0_l0000Oooooo`;o00002_ooool0
01kooooo00?o0000ooooooooool06?ooool2o`0000Kooooo0_l0000fooooo`;o00003_ooool2o`00
04oooooo0_l0001Xooooo`;o00001_ooool4o`0001Sooooo000Nooooo`03o`000?oooooooooo01So
oooo0_l0001>ooooo`;o0000Coooool2o`0006Sooooo0_l00006ooooo`Co00006?ooool001kooooo
0_l0003=ooooo`;o0000JOooool2o`0000kooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0
000Mooooo`;o0000EOooool2o`0001?ooooo0_l0000[ooooo`;o00004?ooool2o`0001cooooo0_l0
0011ooooo`;o00002?ooool2o`0000kooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0000M
ooooo`;o0000EOooool2o`0001?ooooo1?l0000Rooooo`;o00001Oooool2o`000003ooooool0003o
000002Cooooo0_l00005ooooo`;o00002_ooool2o`0002Sooooo0_l00005ooooo`;o00001?ooool2
o`0001Sooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l00005ooooo`;o0000E?ooool2o`00
01cooooo0_l0000Kooooo`;o00001Oooool2o`0000Sooooo0_l0000Tooooo`;o00004Oooool2o`00
00_ooooo0_l0000Kooooo`;o00001Oooool2o`0001Oooooo0_l00005ooooo`007_ooool00ol0003o
ooooooooo`0Dooooo`;o00001Oooool2o`0005Cooooo0_l0000Gooooo`;o00008?ooool2o`0000go
oooo0_l00016ooooo`;o0000>oooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo08[ooooo
0_l0000_ooooo`;o0000R_ooool001kooooo00?o0000ooooooooool05oooool2o`0004Gooooo0_l0
0016ooooo`;o0000Woooool001kooooo00?o0000ooooooooool05oooool2o`0002Oooooo0_l0000L
ooooo`;o00008oooool2o`00027ooooo1?l00009ooooo`;o0000A_ooool2o`0004[ooooo000Noooo
o`03o`000?oooooooooo03Gooooo0_l00004ooooo`;o00000oooool2o`00047ooooo0_l0000Soooo
o`;o00002Oooool2o`0004Kooooo0_l0001:ooooo`007_ooool00ol0003oooooooooo`0eooooo`;o
00001?ooool2o`0001Cooooo0_l0000fooooo`;o00003?ooool2o`000:kooooo000Nooooo`03o`00
0?oooooooooo057ooooo0_l0000fooooo`;o00003?ooool2o`000:kooooo000Nooooo`03o`000?oo
oooooooo013ooooo0_l0003oooooocKooooo000Nooooo`03o`000?oooooooooo013ooooo0_l0001@
ooooo`;o0000??ooool2o`0006gooooo0_l0000fooooo`007_ooool00ol0003oooooooooo`0Moooo
o`;o00009?ooool2o`0001gooooo0_l0000Cooooo`;o00009oooool2o`0000Oooooo0_l0000Qoooo
o`;o0000:oooool2o`0000[ooooo0_l00008ooooo`;o0000=_ooool001Cooooo1?l000000ol@413o
ooooooooo`03ooooo`03o`000?oooooooooo01gooooo0_l0000Tooooo`;o0000<_ooool2o`00033o
oooo0_l0000Qooooo`;o00006?ooool2o`00017ooooo0_l0000:ooooo`;o0000@?ooool001Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Gooooo`;o0000K?ooool2o`0004cooooo
0_l0000Aooooo`;o00003?ooool2o`0000Sooooo0_l0000nooooo`;o00001oooool001Kooooo00?o
0000ooooooooool01Oooool3o`0001Oooooo0_l0001/ooooo`;o0000C?ooool2o`0001oooooo0_l0
0008ooooo`;o0000?_ooool2o`0000Oooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool0
01Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3o
oooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Cooooo00?oEEEEofIVI_l00000oooo
oomBooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.89455 .97278 Mdot
.61636 .12681 Mdot
.36806 .26375 Mdot
.70715 .10443 Mdot
.29679 .87238 Mdot
.18629 .76416 Mdot
.86177 .59167 Mdot
.05866 .33585 Mdot
.45552 .72298 Mdot
.58009 .00955 Mdot
.55606 .73981 Mdot
.49641 .80068 Mdot
.03658 .08189 Mdot
.75027 .86953 Mdot
.24043 .46013 Mdot
.77139 .38883 Mdot
.68008 .01183 Mdot
.85586 .23748 Mdot
.33425 .05774 Mdot
.26597 .336 Mdot
.35669 .60621 Mdot
.93458 .12647 Mdot
.47831 .47308 Mdot
.93952 .99238 Mdot
.02764 .62958 Mdot
.63559 .62876 Mdot
.87111 .45802 Mdot
.76956 .43328 Mdot
.88929 .04987 Mdot
.22991 .67446 Mdot
.02418 .59134 Mdot
.61211 .73691 Mdot
.73012 .52048 Mdot
.0635 .1949 Mdot
.97469 .70853 Mdot
.52531 .87003 Mdot
.71708 .65385 Mdot
.37793 .8913 Mdot
.97967 .75099 Mdot
.26419 .78142 Mdot
.7983 .99636 Mdot
.23417 .54036 Mdot
.45833 .89 Mdot
.36318 .03177 Mdot
.24236 .9672 Mdot
.44155 .61198 Mdot
.62936 .83983 Mdot
.30631 .33398 Mdot
.81068 .73451 Mdot
.48888 .69364 Mdot
.33676 .5557 Mdot
.95391 .65651 Mdot
.99697 .20863 Mdot
.08446 .38745 Mdot
.26251 .69711 Mdot
.42712 .74015 Mdot
.88899 .04702 Mdot
.28852 .8626 Mdot
.45733 .32453 Mdot
.28076 .11022 Mdot
.9778 .12523 Mdot
.30704 .8913 Mdot
.22767 .74896 Mdot
.92075 .91498 Mdot
.55331 .32515 Mdot
.19902 .94985 Mdot
.88278 .13616 Mdot
.54689 .5532 Mdot
.85399 .6971 Mdot
.93823 .26682 Mdot
.05363 .94716 Mdot
.37334 .77096 Mdot
.07393 .37739 Mdot
.72862 .46862 Mdot
.7398 .85197 Mdot
.29447 .115 Mdot
.39666 .06467 Mdot
.38476 .81022 Mdot
.88927 .25342 Mdot
.092 .62272 Mdot
.4328 .2467 Mdot
.86414 .71468 Mdot
.22326 .6565 Mdot
.12979 .38875 Mdot
.34992 .04677 Mdot
.14621 .55288 Mdot
.25677 .53284 Mdot
.4012 .9514 Mdot
.48408 .69814 Mdot
.36581 .7813 Mdot
.25949 .68495 Mdot
.9271 .79733 Mdot
.04592 .3793 Mdot
.42946 .4438 Mdot
.54828 .99149 Mdot
.05155 .34063 Mdot
.54588 .61265 Mdot
.64153 .15651 Mdot
.6413 .7441 Mdot
.58054 .83873 Mdot
.34091 .62472 Mdot
.70727 .68306 Mdot
.8196 .06723 Mdot
.44366 .54567 Mdot
.1745 .33825 Mdot
.24638 .37612 Mdot
.22255 .70339 Mdot
.62338 .73771 Mdot
.2248 .52364 Mdot
.72231 .92415 Mdot
.88916 .01801 Mdot
.46076 .44646 Mdot
.15769 .18813 Mdot
.46285 .38652 Mdot
.83781 .69603 Mdot
.85026 .77928 Mdot
.02364 .62536 Mdot
.8541 .72694 Mdot
.16527 .32062 Mdot
.41772 .77963 Mdot
.66935 .05366 Mdot
.54939 .49949 Mdot
.9853 .21612 Mdot
.34466 .25621 Mdot
.56704 .72831 Mdot
.50839 .27563 Mdot
.29175 .93331 Mdot
.13243 .06864 Mdot
.98402 .68915 Mdot
.84459 .74446 Mdot
.05816 .76753 Mdot
.86177 .80395 Mdot
.00369 .03702 Mdot
.94662 .0123 Mdot
.65293 .0756 Mdot
.07039 .95911 Mdot
.35599 .8045 Mdot
.02873 .52236 Mdot
.41221 .53237 Mdot
.41789 .66826 Mdot
.08962 .53782 Mdot
.22468 .51944 Mdot
.72983 .0977 Mdot
.82753 .01972 Mdot
.08957 .47113 Mdot
.44212 .59045 Mdot
.17983 .80305 Mdot
.65324 .09535 Mdot
.47538 .23239 Mdot
.22534 .23266 Mdot
.19123 .21781 Mdot
.1253 .0915 Mdot
.49598 .90246 Mdot
.71862 .05627 Mdot
.38844 .34233 Mdot
.23176 .41148 Mdot
.55296 .70724 Mdot
.56459 .01247 Mdot
.7313 .35721 Mdot
.01277 .70649 Mdot
.01468 .74806 Mdot
.41763 .69378 Mdot
.0113 .40928 Mdot
.8187 .47177 Mdot
.87702 .75539 Mdot
.808 .5784 Mdot
.22757 .53375 Mdot
.89371 .86904 Mdot
.02099 .56314 Mdot
.88284 .23378 Mdot
.82183 .41706 Mdot
.09421 .96046 Mdot
.48818 .31683 Mdot
.15455 .8468 Mdot
.04001 .66663 Mdot
.98213 .8268 Mdot
.40312 .26783 Mdot
.86408 .92581 Mdot
.63522 .46266 Mdot
.60185 .70957 Mdot
.10317 .10254 Mdot
.89729 .86088 Mdot
.59406 .1441 Mdot
.19006 .56223 Mdot
.81725 .10622 Mdot
.48367 .99657 Mdot
.51747 .19675 Mdot
.07646 .70692 Mdot
.36235 .26077 Mdot
.88827 .22569 Mdot
.39366 .30962 Mdot
.94279 .15031 Mdot
.96395 .53661 Mdot
.39081 .70746 Mdot
.56068 .13671 Mdot
.59315 .78596 Mdot
.23604 .29703 Mdot
.39645 .03503 Mdot
.34852 .74434 Mdot
.77677 .86531 Mdot
.03673 .91631 Mdot
.64063 .04056 Mdot
.33876 .99336 Mdot
.07361 .20422 Mdot
.67823 .89744 Mdot
.42778 .94139 Mdot
.87411 .15122 Mdot
.21886 .7459 Mdot
.12112 .54486 Mdot
.292 .87226 Mdot
.52341 .43718 Mdot
.8474 .27799 Mdot
.58863 .67778 Mdot
.39541 .46819 Mdot
.0973 .14389 Mdot
.91702 .50627 Mdot
.62026 .8327 Mdot
.89532 .10231 Mdot
.49878 .09215 Mdot
.40862 .95264 Mdot
.851 .24565 Mdot
.89985 .66508 Mdot
.00021 .55551 Mdot
.46984 .60657 Mdot
.75648 .18286 Mdot
.72498 .79168 Mdot
.04472 .69492 Mdot
.19761 .49143 Mdot
.71284 .97576 Mdot
.86024 .01063 Mdot
.85366 .24507 Mdot
.56247 .61744 Mdot
.1471 .44788 Mdot
.51131 .5069 Mdot
.82634 .23276 Mdot
.44523 .38375 Mdot
.6734 .40364 Mdot
.36988 .20753 Mdot
.00906 .48514 Mdot
.62525 .06185 Mdot
.94877 .94609 Mdot
.54621 .68914 Mdot
.81224 .00701 Mdot
.25953 .53644 Mdot
.91286 .04979 Mdot
.2646 .18514 Mdot
.68239 .16894 Mdot
.20537 .31844 Mdot
.45268 .17485 Mdot
.24611 .67853 Mdot
.6062 .11484 Mdot
.73228 .2779 Mdot
.46947 .7554 Mdot
.67204 .91004 Mdot
.98118 .12856 Mdot
.80175 .03204 Mdot
.43651 .54722 Mdot
.04232 .28942 Mdot
.14682 .07614 Mdot
.42313 .53944 Mdot
.27142 .09914 Mdot
.7315 .59567 Mdot
.05991 .7418 Mdot
.66456 .98403 Mdot
.27992 .22401 Mdot
.43497 .58488 Mdot
.57061 .58006 Mdot
.45288 .84726 Mdot
.57817 .55974 Mdot
.45469 .7221 Mdot
.41716 .15923 Mdot
.77781 .72923 Mdot
.90041 .42111 Mdot
.09275 .54982 Mdot
.32936 .98101 Mdot
.25337 .31634 Mdot
.72443 .03719 Mdot
.16469 .2854 Mdot
.4817 .95465 Mdot
.23101 .40102 Mdot
.71028 .89926 Mdot
.28904 .90604 Mdot
.49525 .1565 Mdot
.90962 .59087 Mdot
.35303 .63608 Mdot
.14938 .33795 Mdot
.59026 .85908 Mdot
.64604 .72878 Mdot
.662 .11263 Mdot
.12064 .61056 Mdot
.82031 .55078 Mdot
.39816 .11929 Mdot
.8102 .31873 Mdot
.45545 .82665 Mdot
.48861 .35254 Mdot
.00154 .47286 Mdot
.73771 .62357 Mdot
.50317 .49937 Mdot
.03475 .32203 Mdot
.35822 .47482 Mdot
.87408 .7683 Mdot
.02426 .14184 Mdot
.78968 .63511 Mdot
.11777 .29391 Mdot
.55044 .524 Mdot
.05941 .24427 Mdot
.09721 .33954 Mdot
.40921 .46105 Mdot
.71405 .49931 Mdot
.78684 .26842 Mdot
.44938 .45802 Mdot
.08348 .47134 Mdot
.09709 .55798 Mdot
.78644 .1496 Mdot
.27063 .26547 Mdot
.019 .1422 Mdot
.14347 .51249 Mdot
.38475 .2844 Mdot
.37152 .60901 Mdot
.19291 .35869 Mdot
.12373 .67906 Mdot
.08175 .53378 Mdot
.01413 .3213 Mdot
.39469 .6902 Mdot
.09 .73014 Mdot
.33695 .83455 Mdot
.5021 .72375 Mdot
.95336 .26401 Mdot
.91527 .76825 Mdot
.16362 .40409 Mdot
.20348 .79012 Mdot
.46096 .72256 Mdot
.4552 .68146 Mdot
.87477 .44623 Mdot
.19515 .96169 Mdot
.86282 .43144 Mdot
.11265 .90207 Mdot
.76693 .94124 Mdot
.28067 .71132 Mdot
.49185 .47542 Mdot
.55796 .48822 Mdot
.95543 .30057 Mdot
.1645 .05571 Mdot
.05344 .10552 Mdot
.02203 .76487 Mdot
.66717 .42622 Mdot
.71491 .35935 Mdot
.33278 .12041 Mdot
.88426 .04644 Mdot
.1032 .49629 Mdot
.35161 .93668 Mdot
.01228 .91788 Mdot
.89607 .81769 Mdot
.51716 .20948 Mdot
.98638 .35869 Mdot
.92012 .47625 Mdot
.48521 .83814 Mdot
.8824 .43614 Mdot
.40951 .85131 Mdot
.11314 .95231 Mdot
.89327 .23634 Mdot
.40269 .73796 Mdot
.38253 .92448 Mdot
.88609 .35436 Mdot
.79262 .40876 Mdot
.0037 .01683 Mdot
.99983 .82061 Mdot
.29575 .01208 Mdot
.25778 .38806 Mdot
.82029 .91662 Mdot
.60033 .86838 Mdot
.22121 .4565 Mdot
.03712 .10206 Mdot
.25959 .17376 Mdot
.27469 .61229 Mdot
.77021 .28504 Mdot
.05558 .51965 Mdot
.47477 .93694 Mdot
.26665 .18152 Mdot
.52886 .27012 Mdot
.50457 .49409 Mdot
.40426 .95534 Mdot
.5122 .85509 Mdot
.6621 .74079 Mdot
.98085 .86779 Mdot
.94357 .02063 Mdot
.30386 .8225 Mdot
.88586 .99572 Mdot
.58933 .50976 Mdot
.69622 .80824 Mdot
.90289 .63101 Mdot
.96571 .78545 Mdot
.0109 .7615 Mdot
.88977 .31353 Mdot
.62106 .86179 Mdot
.99241 .11763 Mdot
.3877 .24222 Mdot
.27728 .51087 Mdot
.60669 .34622 Mdot
.15538 .79886 Mdot
.43229 .03051 Mdot
.41405 .69818 Mdot
.89864 .91037 Mdot
.24262 .58673 Mdot
.37051 .34455 Mdot
.03276 .46228 Mdot
.24223 .17916 Mdot
.5131 .03412 Mdot
.37719 .13155 Mdot
.64133 .68189 Mdot
.37085 .51887 Mdot
.26921 .36565 Mdot
.58325 .07342 Mdot
.98961 .99079 Mdot
.17416 .77898 Mdot
.13482 .1947 Mdot
.94575 .95312 Mdot
.5914 .05542 Mdot
.28242 .3265 Mdot
.37934 .87338 Mdot
.38565 .43172 Mdot
.17702 .36717 Mdot
.40054 .28544 Mdot
.30289 .75477 Mdot
.3691 .02272 Mdot
.99055 .06014 Mdot
.1811 .81726 Mdot
.11325 .40264 Mdot
.41895 .11207 Mdot
.87864 .65461 Mdot
.61042 .47104 Mdot
.71469 .58048 Mdot
.96732 .40071 Mdot
.16374 .41987 Mdot
.63845 .73539 Mdot
.34818 .51777 Mdot
.92405 .21865 Mdot
.02072 .0256 Mdot
.11985 .06035 Mdot
.194 .07021 Mdot
.80657 .11621 Mdot
.75566 .66227 Mdot
.53197 .90643 Mdot
.7301 .95817 Mdot
.37468 .76668 Mdot
.93811 .79211 Mdot
.94196 .68434 Mdot
.93536 .96296 Mdot
.85619 .25536 Mdot
.27574 .50862 Mdot
.01655 .80815 Mdot
.39513 .30134 Mdot
.65512 .9778 Mdot
.13961 .977 Mdot
.32804 .7803 Mdot
.19013 .57608 Mdot
.68906 .07095 Mdot
.0128 .29915 Mdot
.34537 .74289 Mdot
.45657 .75916 Mdot
.89685 .2921 Mdot
.2835 .47781 Mdot
.3478 .0603 Mdot
.31271 .82802 Mdot
.1027 .35703 Mdot
.88917 .54232 Mdot
.17354 .2066 Mdot
.44954 .55488 Mdot
.07297 .6534 Mdot
.96484 .67774 Mdot
.45701 .09786 Mdot
.17028 .53541 Mdot
.01974 .35277 Mdot
.08643 .6214 Mdot
.12219 .0147 Mdot
.12841 .53424 Mdot
.27013 .0557 Mdot
.93025 .6576 Mdot
.49346 .47689 Mdot
.96956 .80094 Mdot
.19376 .46887 Mdot
.33191 .4026 Mdot
.13494 .58849 Mdot
.90948 .17432 Mdot
.81641 .6932 Mdot
.1544 .85343 Mdot
.95066 .25848 Mdot
.43637 .10991 Mdot
.00592 .61084 Mdot
.27342 .04101 Mdot
.65091 .71933 Mdot
.00601 .71439 Mdot
.13156 .25556 Mdot
.03549 .03744 Mdot
.59774 .81694 Mdot
.93355 .18141 Mdot
.41616 .64805 Mdot
.30149 .63876 Mdot
.35666 .80785 Mdot
.30089 .16487 Mdot
.73377 .77462 Mdot
.49029 .80101 Mdot
.47614 .14165 Mdot
.09491 .34936 Mdot
.52359 .7378 Mdot
.48234 .82972 Mdot
.62366 .16426 Mdot
.99901 .39781 Mdot
.29441 .91247 Mdot
.10232 .97407 Mdot
.33952 .44467 Mdot
.46697 .06569 Mdot
.3287 .3929 Mdot
.39353 .82356 Mdot
.2632 .63631 Mdot
.93688 .05008 Mdot
.01215 .64928 Mdot
.27026 .58814 Mdot
.2279 .0377 Mdot
.64548 .98702 Mdot
.37154 .68611 Mdot
.04129 .61363 Mdot
.4535 .58035 Mdot
.11775 .85635 Mdot
.8145 .52972 Mdot
.14584 .37049 Mdot
.01224 .13575 Mdot
.94314 .70558 Mdot
.23684 .2132 Mdot
.21554 .72977 Mdot
.47715 .66127 Mdot
.90981 .96326 Mdot
.75876 .63975 Mdot
.21392 .83072 Mdot
.60287 .39619 Mdot
.60775 .55988 Mdot
.05808 .25316 Mdot
.81229 .74624 Mdot
.71686 .80939 Mdot
.73703 .72826 Mdot
.53922 .31871 Mdot
.88387 .63606 Mdot
.57499 .93018 Mdot
.45998 .99276 Mdot
.52533 .12778 Mdot
.94388 .56563 Mdot
.35136 .0324 Mdot
.67947 .31795 Mdot
.8196 .12006 Mdot
.54911 .0694 Mdot
.74616 .95771 Mdot
.27761 .97623 Mdot
.71281 .46283 Mdot
.98225 .05526 Mdot
.50698 .86107 Mdot
.99696 .70096 Mdot
.74461 .33284 Mdot
.66918 .55967 Mdot
.04416 .80672 Mdot
.37645 .66631 Mdot
.74613 .93862 Mdot
.34282 .10814 Mdot
.60217 .24651 Mdot
.20575 .88442 Mdot
.29047 .22992 Mdot
.80793 .52302 Mdot
.25303 .76151 Mdot
.47441 .4984 Mdot
.9086 .08449 Mdot
.61616 .19779 Mdot
.37118 .9172 Mdot
.68104 .08124 Mdot
.56903 .3953 Mdot
.87101 .08284 Mdot
.7008 .73048 Mdot
.11004 .91993 Mdot
.88261 .90353 Mdot
.64207 .15891 Mdot
.71362 .50595 Mdot
.898 .29047 Mdot
.49805 .96229 Mdot
.66133 .72153 Mdot
.4453 .68792 Mdot
.44929 .10825 Mdot
.41065 .85586 Mdot
.10668 .32478 Mdot
.48916 .64503 Mdot
.29585 .07661 Mdot
.30962 .20204 Mdot
.07367 .25821 Mdot
.03418 .45339 Mdot
.85203 .53858 Mdot
.01511 .71229 Mdot
.62758 .41747 Mdot
.07778 .53204 Mdot
.88458 .78702 Mdot
.37795 .53367 Mdot
.30743 .70938 Mdot
.44895 .15677 Mdot
.21874 .41073 Mdot
.38206 .61596 Mdot
.84645 .8023 Mdot
.1379 .8964 Mdot
.21439 .94523 Mdot
.87562 .53227 Mdot
.28199 .11463 Mdot
.92968 .15108 Mdot
.10119 .7045 Mdot
.08684 .32056 Mdot
.23298 .45963 Mdot
.59591 .40035 Mdot
.56607 .63224 Mdot
.28195 .26552 Mdot
.39471 .23189 Mdot
.90191 .00215 Mdot
.59608 .98118 Mdot
.60279 .27527 Mdot
.99329 .33903 Mdot
.84684 .51045 Mdot
.32092 .95262 Mdot
.13334 .41676 Mdot
.78736 .79823 Mdot
.24674 .58287 Mdot
.60732 .69506 Mdot
.01531 .94932 Mdot
.82196 .6974 Mdot
.88587 .44746 Mdot
.63182 .09779 Mdot
.02936 .8109 Mdot
.32849 .21575 Mdot
.28237 .72395 Mdot
.3597 .49869 Mdot
.53402 .954 Mdot
.18435 .11882 Mdot
.03083 .75709 Mdot
.398 .92492 Mdot
.4429 .19858 Mdot
.92991 .60653 Mdot
.87278 .52188 Mdot
.38583 .89979 Mdot
.58664 .24051 Mdot
.87025 .05632 Mdot
.45995 .09108 Mdot
.5301 .88789 Mdot
.25735 .54292 Mdot
.82784 .02703 Mdot
.00404 .38815 Mdot
.98076 .50574 Mdot
.02381 .45649 Mdot
.47103 .25593 Mdot
.64355 .2219 Mdot
.74418 .14562 Mdot
.66219 .22158 Mdot
.29191 .87741 Mdot
.40565 .76558 Mdot
.1611 .1998 Mdot
.55686 .74275 Mdot
.1156 .90762 Mdot
.18824 .99445 Mdot
.58713 .8009 Mdot
.52486 .9988 Mdot
.21048 .79101 Mdot
.35561 .13605 Mdot
.24268 .1575 Mdot
.40196 .11345 Mdot
.2891 .89473 Mdot
.75095 .61952 Mdot
.86031 .13948 Mdot
.6819 .59203 Mdot
.94783 .62656 Mdot
.16962 .75677 Mdot
.19608 .04785 Mdot
.34632 .66896 Mdot
.23149 .88028 Mdot
.999 .82122 Mdot
.52128 .87827 Mdot
.95515 .16518 Mdot
.60519 .54254 Mdot
.80904 .27992 Mdot
.53171 .92278 Mdot
.36472 .39526 Mdot
.75823 .92514 Mdot
.55668 .86721 Mdot
.30088 .12075 Mdot
.00803 .66081 Mdot
.42525 .85084 Mdot
.28847 .38616 Mdot
.50251 .55322 Mdot
.03033 .63021 Mdot
.18455 .48879 Mdot
.57861 .94609 Mdot
.45229 .89688 Mdot
.92467 .10506 Mdot
.17577 .29968 Mdot
.07417 .96329 Mdot
.3587 .49795 Mdot
.46464 .74822 Mdot
.71139 .98982 Mdot
.87452 .61841 Mdot
.6962 .03611 Mdot
.23089 .84898 Mdot
.99906 .33505 Mdot
.88788 .12737 Mdot
.87746 .15204 Mdot
.64633 .62937 Mdot
.19361 .15358 Mdot
.21123 .26707 Mdot
.01859 .93288 Mdot
.18783 .20875 Mdot
.9833 .55312 Mdot
.99984 .73596 Mdot
.93508 .87138 Mdot
.20722 .75613 Mdot
.58534 .95778 Mdot
.56978 .87585 Mdot
.8014 .34869 Mdot
.72949 .64259 Mdot
.20528 .63324 Mdot
.62842 .92845 Mdot
.55576 .09725 Mdot
.12917 .20802 Mdot
.95734 .14929 Mdot
.8801 .65184 Mdot
.67574 .91232 Mdot
.43409 .72163 Mdot
.8557 .81844 Mdot
.24352 .14319 Mdot
.20828 .76235 Mdot
.20881 .36768 Mdot
.6498 .77616 Mdot
.08165 .73506 Mdot
.38682 .03457 Mdot
.94903 .30617 Mdot
.14009 .39745 Mdot
.48729 .91896 Mdot
.95952 .76816 Mdot
.96557 .67466 Mdot
.81578 .48385 Mdot
.38793 .11897 Mdot
.28535 .08165 Mdot
.90086 .47476 Mdot
.3014 .95007 Mdot
.29063 .99423 Mdot
.06816 .55586 Mdot
.79719 .46477 Mdot
.51393 .66869 Mdot
.56158 .81671 Mdot
.05811 .69862 Mdot
.0867 .62211 Mdot
.92927 .83017 Mdot
.17207 .1555 Mdot
.03889 .31662 Mdot
.06538 .34658 Mdot
.48718 .60987 Mdot
.13013 .95262 Mdot
.91756 .71041 Mdot
.78502 .03096 Mdot
.67214 .649 Mdot
.5986 .48229 Mdot
.92008 .45635 Mdot
.05043 .18675 Mdot
.83859 .19251 Mdot
.34043 .75643 Mdot
.26165 .75188 Mdot
.77976 .78048 Mdot
.54577 .67448 Mdot
.38706 .55429 Mdot
.26283 .19097 Mdot
.00117 .81725 Mdot
.07321 .31242 Mdot
.03271 .95343 Mdot
.24699 .15879 Mdot
.22941 .97063 Mdot
.70434 .49867 Mdot
.59938 .95623 Mdot
.28716 .04567 Mdot
.01318 .46768 Mdot
.05957 .28143 Mdot
.89851 .83827 Mdot
.50491 .64049 Mdot
.57915 .41641 Mdot
.97323 .86872 Mdot
.77491 .19262 Mdot
.18825 .14489 Mdot
.29244 .68954 Mdot
.66275 .22735 Mdot
.27634 .46248 Mdot
.18484 .46991 Mdot
.95185 .05772 Mdot
.62072 .84817 Mdot
.24252 .70404 Mdot
.33487 .98929 Mdot
.52781 .91587 Mdot
.87937 .58598 Mdot
.04657 .32437 Mdot
.09316 .04161 Mdot
.47517 .26279 Mdot
.83003 .26449 Mdot
.33573 .66783 Mdot
.34797 .04801 Mdot
.20498 .74514 Mdot
.15486 .65727 Mdot
.49202 .51007 Mdot
.39808 .42481 Mdot
.66679 .1572 Mdot
.89254 .09453 Mdot
.33639 .49641 Mdot
.94607 .39994 Mdot
.427 .50273 Mdot
.89256 .67366 Mdot
.41767 .46832 Mdot
.17411 .80822 Mdot
.54424 .99993 Mdot
.28977 .72947 Mdot
.89877 .24437 Mdot
.64975 .84412 Mdot
.42366 .5566 Mdot
.08399 .27172 Mdot
.82519 .70529 Mdot
.68894 .15031 Mdot
.09999 .64201 Mdot
.56734 .25124 Mdot
.13753 .38774 Mdot
.96176 .01054 Mdot
.95047 .67871 Mdot
.06785 .98308 Mdot
.5546 .99149 Mdot
.9424 .38773 Mdot
.71764 .29179 Mdot
.42226 .8071 Mdot
.21491 .11597 Mdot
.10164 .9633 Mdot
.89914 .34263 Mdot
.37023 .16967 Mdot
.14899 .13092 Mdot
.64593 .84612 Mdot
.68696 .01713 Mdot
.22261 .68326 Mdot
.48397 .19319 Mdot
.54501 .57378 Mdot
.24824 .55635 Mdot
.88549 .38923 Mdot
.58454 .69583 Mdot
.21251 .81869 Mdot
.45977 .95578 Mdot
.56142 .05403 Mdot
.74357 .32877 Mdot
.99084 .95528 Mdot
.43368 .89728 Mdot
.30221 .91948 Mdot
.23324 .26901 Mdot
.95337 .87464 Mdot
.07498 .58028 Mdot
.58576 .05651 Mdot
.89315 .06871 Mdot
.80935 .79194 Mdot
.06209 .37821 Mdot
.61362 .08735 Mdot
.01245 .7576 Mdot
.22474 .65842 Mdot
.11222 .28565 Mdot
.33038 .24692 Mdot
.49786 .18695 Mdot
.74138 .9223 Mdot
.82292 .26141 Mdot
.76841 .22252 Mdot
.21938 .68388 Mdot
.12017 .92201 Mdot
.77351 .68475 Mdot
.94235 .11925 Mdot
.42759 .60088 Mdot
.39499 .83024 Mdot
.59731 .09134 Mdot
.34262 .15494 Mdot
.87075 .11312 Mdot
.29195 .77314 Mdot
.64455 .65868 Mdot
.41401 .07013 Mdot
.65781 .45101 Mdot
.35584 .80857 Mdot
.40882 .0735 Mdot
.17908 .94498 Mdot
.59056 .90142 Mdot
.19227 .50626 Mdot
.29657 .48087 Mdot
.22918 .03775 Mdot
.16919 .699 Mdot
.77571 .8183 Mdot
.38476 .52992 Mdot
.8326 .28878 Mdot
.05776 .79919 Mdot
.96445 .28067 Mdot
.29146 .24585 Mdot
.23652 .56423 Mdot
.88662 .7949 Mdot
.40434 .43751 Mdot
.32257 .87272 Mdot
.78606 .04674 Mdot
.50928 .65592 Mdot
.54108 .85706 Mdot
.52326 .50467 Mdot
.02856 .95441 Mdot
.25395 .20521 Mdot
.77946 .3678 Mdot
.34372 .61148 Mdot
.94762 .44849 Mdot
.62437 .11458 Mdot
.80226 .35828 Mdot
.04334 .84281 Mdot
.59867 .89318 Mdot
.10724 .42376 Mdot
.85023 .44522 Mdot
.938 .56819 Mdot
.19574 .04414 Mdot
.20271 .82321 Mdot
.19251 .95473 Mdot
.26091 .80934 Mdot
.75718 .29572 Mdot
.11615 .33374 Mdot
.38732 .26061 Mdot
.35666 .0362 Mdot
.99613 .9445 Mdot
.91411 .73672 Mdot
.57668 .06172 Mdot
.34037 .12132 Mdot
.04655 .34864 Mdot
.13944 .96084 Mdot
.20594 .83628 Mdot
.32117 .51554 Mdot
.1436 .2566 Mdot
.84622 .76957 Mdot
.27118 .25892 Mdot
.93403 .6792 Mdot
.74747 .61001 Mdot
.73479 .09653 Mdot
.73274 .97579 Mdot
.66099 .2424 Mdot
.17763 .84773 Mdot
.00405 .84647 Mdot
.25625 .79087 Mdot
.18894 .86457 Mdot
.82563 .32093 Mdot
.01592 .60303 Mdot
.99842 .47546 Mdot
.78875 .32499 Mdot
.734 .47994 Mdot
.8165 .05636 Mdot
.44551 .19968 Mdot
.40624 .08204 Mdot
.04638 .66719 Mdot
.06567 .47694 Mdot
.80242 .49649 Mdot
.36735 .91772 Mdot
.53359 .69967 Mdot
.04162 .07708 Mdot
.17526 .71464 Mdot
.93902 .0474 Mdot
.83866 .78739 Mdot
.9058 .59665 Mdot
.16738 .85306 Mdot
.07718 .8458 Mdot
.91288 .89493 Mdot
.58844 .91168 Mdot
.08691 .77214 Mdot
.44034 .71542 Mdot
.99944 .33671 Mdot
.83479 .94526 Mdot
.25734 .79625 Mdot
.18943 .59011 Mdot
.91205 .88927 Mdot
.93498 .44008 Mdot
.42804 .27352 Mdot
.63534 .08891 Mdot
.2245 .04492 Mdot
.33586 .69126 Mdot
.26374 .86835 Mdot
.30719 .33157 Mdot
.64374 .75898 Mdot
.22545 .99524 Mdot
.09066 .40641 Mdot
.43064 .96437 Mdot
.59791 .12695 Mdot
.80227 .96714 Mdot
.97147 .1532 Mdot
.93781 .48151 Mdot
.24279 .91486 Mdot
.96178 .18033 Mdot
.49491 .70856 Mdot
.16198 .14349 Mdot
.08961 .24347 Mdot
.50249 .69415 Mdot
.76355 .60651 Mdot
.86827 .21409 Mdot
.84944 .64495 Mdot
.40064 .93503 Mdot
.41202 .8971 Mdot
.97959 .14086 Mdot
.4502 .84283 Mdot
.35996 .11321 Mdot
.41098 .76081 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`;o00003_ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo000Nooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool00_l0000;ooooo`03o`000?oooooooooo00gooooo0_l0000>ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o0000ooooooooool0^?oo
ool2o`0004[ooooo0_l0000>ooooo`;o00007oooool2o`00013ooooo000Nooooo`03o`000?oooooo
oooo05cooooo0_l0001Eooooo`;o00000oooool2o`0001oooooo0_l0000iooooo`;o00006_ooool2
o`0000?ooooo0_l0000@ooooo`007_ooool00ol0003oooooooooo`0Tooooo`;o0000=_ooool2o`00
05Gooooo0_l0000Tooooo`;o0000EOooool2o`0001Gooooo000Nooooo`;o00009Oooool2o`000;Go
oooo0_l0000/ooooo`;o00004_ooool2o`0002Sooooo000Nooooo`;o0000MOooool2o`0006Gooooo
0_l0000/ooooo`;o00004_ooool2o`00013ooooo0_l0000Fooooo`007_ooool00ol0003ooooooooo
o`03ooooo`;o0000Koooool2o`000;Wooooo0_l0000Fooooo`007_ooool00ol0003oooooooooo`03
ooooo`;o0000ooooool5ooooo`;o0000??ooool001kooooo00?o0000ooooooooool0L_ooool2o`00
01Cooooo0_l0001aooooo`;o00001?ooool2o`0000Kooooo0_l0000looooo`007_ooool00ol0003o
ooooooooo`1^ooooo`;o00000_ooool2o`0000Kooooo0_l000000ooooooo0000o`000009ooooo`;o
00006Oooool2o`0005Kooooo0_l00004ooooo`;o0000A?ooool001kooooo0_l00008ooooo`;o0000
?Oooool2o`0002Kooooo1?l00008ooooo`;o000000?oooooo`000?l000009?ooool2o`0003Wooooo
0_l00007ooooo`;o0000G_ooool001kooooo0_l00008ooooo`;o0000?Oooool2o`0000gooooo0_l0
000Iooooo`;o0000F_ooool2o`00013ooooo0_l00007ooooo`;o0000G_ooool001kooooo00?o0000
ooooooooool06_ooool2o`00023ooooo0_l0000Gooooo`;o0000MOooool2o`0007Wooooo000Noooo
o`03o`000?oooooooooo01[ooooo0_l0000Pooooo`;o00001oooool2o`0001;ooooo0_l0000Coooo
o`;o0000Roooool2o`0001kooooo1?l0000>ooooo`;o00006?ooool001kooooo00?o0000oooooooo
ool0??ooool2o`0000Oooooo0_l0000Booooo`;o00004_ooool3o`0008_ooooo0_l0000Nooooo`Co
00001_ooool2o`0000Gooooo0ol0000Hooooo`007_ooool2o`0003gooooo0_l0000_ooooo`;o0000
I_ooool2o`0004Kooooo0_l00006ooooo`;o00001Oooool2o`0001Wooooo000Nooooo`03o`000?oo
oooooooo037ooooo0_l0000Qooooo`;o0000G?ooool2o`0000Kooooo1?l0000Gooooo`;o00003ooo
ool2o`0001gooooo0_l0000@ooooo`;o00008_ooool2o`0000[ooooo000Nooooo`03o`000?oooooo
oooo037ooooo0_l0000Qooooo`;o00004oooool2o`0004Oooooo0_l00006ooooo`Co0000:?ooool2
o`0001gooooo0_l0000@ooooo`;o00006?ooool2o`0000Sooooo0_l0000:ooooo`007_ooool00ol0
003oooooooooo`0Sooooo`;o0000A?ooool2o`0000;ooooo0_l00018ooooo`;o00003_ooool2o`00
06Sooooo0_l0000;ooooo`;o00001oooool001kooooo00?o0000ooooooooool08oooool2o`0004So
oooo0_l0000>ooooo`;o00005Oooool2o`00027ooooo0_l0000>ooooo`;o0000MOooool2o`0000Oo
oooo000Nooooo`03o`000?oooooooooo02Oooooo0_l0001Dooooo`;o00005Oooool2o`00073ooooo
0_l0000Fooooo`;o00009oooool001kooooo00?o0000ooooooooool09oooool2o`0001;ooooo0_l0
0015ooooo`;o0000:_ooool2o`0002cooooo0_l0000Xooooo`;o00005_ooool2o`0002Oooooo000N
ooooo`03o`000?oooooooooo03_ooooo0_l00014ooooo`?o0000:_ooool2o`0000[ooooo0_l0000P
ooooo`;o0000JOooool001kooooo00?o0000ooooooooool02Oooool2o`00027ooooo0_l0000^oooo
o`;o00008oooool2o`0003Oooooo0_l0000Dooooo`;o0000MOooool001kooooo00?o0000oooooooo
ool02Oooool2o`00027ooooo0_l0000^ooooo`;o0000L_ooool2o`0000Oooooo0_l0001/ooooo`00
7_ooool00ol0003oooooooooo`08ooooo`;o0000Coooool2o`0002Gooooo0_l0001Gooooo`;o0000
??ooool2o`0002kooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0001?ooooo`;o00009Ooo
ool2o`00047ooooo0_l0001Booooo`;o00002_ooool2o`0002;ooooo000Nooooo`03o`000?oooooo
oooo0<?ooooo0_l00005ooooo`;o0000Eoooool2o`0002;ooooo000Nooooo`03o`000?oooooooooo
02Gooooo0_l0001Zooooo`;o00002oooool2o`0001kooooo0_l0000:ooooo`;o0000Noooool001ko
oooo00?o0000ooooooooool09Oooool2o`0006[ooooo0_l0000;ooooo`;o00007_ooool2o`00013o
oooo0_l0000Iooooo`;o0000<Oooool2o`0002Oooooo000Nooooo`03o`000?oooooooooo05Cooooo
0_l0000jooooo`;o00007oooool2o`0001Kooooo0_l00005ooooo`;o00005oooool4o`00037ooooo
0_l0000Wooooo`007_ooool2o`0000Wooooo0_l0000Cooooo`;o0000=Oooool2o`0003[ooooo0_l0
000Oooooo`;o00005_ooool2o`0001kooooo0_l0000dooooo`;o00009_ooool001kooooo00?o0000
ooooooooool02?ooool2o`0000?ooooo0_l0000>ooooo`;o0000`oooool2o`0003_ooooo0_l00008
ooooo`;o00007?ooool001kooooo00?o0000ooooooooool03Oooool2o`0005cooooo0_l0000Qoooo
o`;o0000D_ooool2o`0002;ooooo0_l0000Qooooo`;o00007?ooool001kooooo00?o0000oooooooo
ool0Eoooool2o`0001;ooooo0_l0000Gooooo`;o00001?ooool2o`0000;ooooo0_l0001fooooo`;o
0000?oooool001kooooo00?o0000ooooooooool0Eoooool3o`0000;ooooo0_l0000Cooooo`;o0000
3?ooool2o`0000?ooooo0_l00004ooooo`;o0000=Oooool2o`0000Cooooo0_l0000:ooooo`;o0000
@_ooool2o`0002kooooo000Nooooo`03o`000?oooooooooo04;ooooo0_l0000Dooooo`;o00000_oo
ool2o`0001?ooooo0_l0000<ooooo`;o0000@?ooool2o`0000Cooooo0_l0000:ooooo`;o0000;Ooo
ool2o`0001?ooooo0_l0000Vooooo`;o00001_ooool001kooooo00?o0000ooooooooool0>?ooool2
o`0000Sooooo0_l0000Jooooo`;o00002?ooool2o`000003ooooool0003o000000gooooo0_l00000
0ooooooo0000o`000023ooooo`;o00000_ooool2o`0002Kooooo0_l0000?ooooo`;o00001_ooool0
01kooooo00?o0000ooooooooool0>?ooool2o`0002Cooooo0_l00008ooooo`;o000000?oooooo`00
0?l000003Oooool2o`000003ooooool0003o000008Oooooo0_l0000Vooooo`;o00005oooool001ko
oooo00?o0000ooooooooool0__ooool2o`0000Cooooo0_l0001Gooooo`;o00003Oooool2o`0000co
oooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`2Wooooo`;o00005Oooool2o`0000Cooooo
0_l0001Gooooo`;o00003Oooool2o`0000cooooo0ol0000:ooooo`007_ooool00ol0003ooooooooo
o`0/ooooo`;o0000BOooool2o`0002kooooo0_l0002Booooo`;o00002_ooool001kooooo00?o0000
ooooooooool00_l0000Zooooo`;o0000@Oooool2o`0000Kooooo0_l0000iooooo`;o0000Ioooool2
o`0002[ooooo000Nooooo`03o`000?oooooooooo00;o0000KOooool2o`00047ooooo0_l0001Poooo
o`;o00001Oooool2o`0002[ooooo000Nooooo`03o`000?oooooooooo00;ooooo1?l0002Aooooo`;o
0000Noooool2o`0002Cooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`02ooooo`Co0000
5_ooool2o`0001?ooooo0_l00006ooooo`;o00004?ooool2o`0004[ooooo0_l0000Tooooo`;o0000
;oooool2o`0004[ooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`0Looooo`;o00004ooo
ool2o`0000Kooooo0_l0000@ooooo`;o0000L?ooool2o`0002oooooo0_l0001Gooooo`007_ooool2
o`000=gooooo0_l0000Nooooo`;o00006_ooool3o`0000oooooo0_l00002ooooo`;o00000oooool2
o`0001;ooooo000Nooooo`03o`000?oooooooooo03_ooooo0_l0000^ooooo`;o0000Koooool2o`00
01kooooo0_l0000Jooooo`?o00003oooool2o`0000;ooooo0_l00003ooooo`;o00000oooool2o`00
00gooooo000Nooooo`03o`000?oooooooooo03Cooooo0_l00005ooooo`;o00003_ooool2o`0001ko
oooo0_l0000Qooooo`;o00003Oooool2o`0002gooooo0_l00007ooooo`;o0000HOooool2o`0000go
oooo000Nooooo`03o`000?oooooooooo03Cooooo0_l0000Eooooo`?o0000=_ooool2o`0000Sooooo
0_l0000=ooooo`;o0000;Oooool3o`0000Kooooo0_l0001`ooooo`007_ooool00ol0003ooooooooo
o`1<ooooo`;o0000=_ooool2o`00047ooooo0_l00004ooooo`;o0000N?ooool001kooooo00?o0000
ooooooooool0G_ooool2o`0006Oooooo0_l0001Yooooo`;o00004oooool001kooooo00?o0000oooo
ooooool0G_ooool2o`0001Cooooo0_l0001Tooooo`;o0000E_ooool2o`0001?ooooo000Nooooo`03
o`000?oooooooooo07Cooooo0_l0001Tooooo`;o0000Joooool001kooooo00?o0000ooooooooool0
D?ooool2o`0003gooooo0_l0002Cooooo`;o00008Oooool001kooooo00?o0000ooooooooool0Booo
ool2o`0000?ooooo0_l0000mooooo`;o0000Toooool2o`00027ooooo000Nooooo`03o`000?oooooo
oooo04_ooooo0_l00006ooooo`;o0000WOooool2o`0003Oooooo0_l00008ooooo`;o00004?ooool0
01kooooo00?o0000ooooooooool0D_ooool3o`0009gooooo0_l0000gooooo`;o00002?ooool2o`00
013ooooo000Nooooo`03o`000?oooooooooo00cooooo0_l0000Qooooo`;o00008Oooool2o`0004[o
oooo0_l0002Wooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o00008Oooool2o`00023ooooo
0_l0001;ooooo`;o0000Yoooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool04Oooool2o`0001Gooooo0_l0000Wooooo`;o0000
A_ooool2o`0005gooooo0_l0000Cooooo`;o0000>?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000oooooooo
ool04Oooool2o`0001Gooooo0_l0001_ooooo`;o00002Oooool2o`0001kooooo0_l0000booooo`;o
00004oooool2o`0003Sooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000<?ooool2o`0005[ooooo0ol0000Eooooo`;o00007_ooool2o`00087o
oooo0003ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`03
o`000?oooooooooo01Cooooo0_l0000Jooooo`;o0000;oooool2o`0002Wooooo0ol0002hooooo`00
0oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003o
ooooooooo`0Dooooo`;o00007_ooool2o`0001Sooooo0_l0000Aooooo`;o0000i?ooool000?ooooo
00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool09_ooool2o`0000cooooo0_l00003ooooo`;o00004oooool2o`0002Cooooo0_l0000^ooooo`;o
0000V_ooool2o`0000Gooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o
^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool09_ooool2o`00017ooooo0_l0000>oooo
o`;o0000:Oooool2o`0002kooooo0_l0002Jooooo`;o00001Oooool000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`19
ooooo`;o00007?ooool2o`000:gooooo0_l0000Tooooo`;o00002Oooool001kooooo00?o0000oooo
ooooool0>_ooool2o`0002_ooooo0_l0002]ooooo`;o00004?ooool2o`0001;ooooo0_l00009oooo
o`007_ooool00ol0003oooooooooo`0jooooo`;o0000TOooool2o`0000Cooooo0_l0000Qooooo`;o
0000<?ooool2o`0001gooooo000Nooooo`03o`000?oooooooooo05Oooooo0_l0001dooooo`;o0000
1?ooool2o`00027ooooo0_l0000Uooooo`;o0000:?ooool001kooooo00?o0000ooooooooool0Eooo
ool2o`0007[ooooo0_l00018ooooo`;o0000:?ooool001kooooo00?o0000ooooooooool0F_ooool2
o`00023ooooo0_l0001Eooooo`;o0000L_ooool001kooooo00?o0000ooooooooool0AOooool2o`00
01?ooooo0_l0000Pooooo`;o00006?ooool2o`00077ooooo0_l0000@ooooo`;o0000:_ooool001ko
oooo00?o0000ooooooooool0AOooool2o`0004oooooo0_l0001aooooo`;o00001oooool2o`0000Oo
oooo0_l000000ooooooo0000o`00000Wooooo`007_ooool00ol0003oooooooooo`2kooooo`;o0000
EOooool2o`0000[ooooo0_l0000Wooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o00002?oo
ool2o`0005oooooo0_l0000oooooo`;o00005_ooool2o`0004_ooooo0_l0000Uooooo`007_ooool0
0ol0003oooooooooo`0?ooooo`;o00002?ooool2o`00043ooooo0_l0000:ooooo`;o00004Oooool2
o`0000gooooo0_l0000eooooo`;o00004Oooool2o`0003cooooo0_l0000=ooooo`;o00009Oooool0
01kooooo00?o0000ooooooooool0Foooool2o`0000[ooooo0_l0000Pooooo`;o0000=Oooool2o`00
04oooooo0_l0000dooooo`007_ooool2o`00013ooooo0_l0002Sooooo`;o0000Ioooool2o`0002So
oooo000Nooooo`03o`000?oooooooooo00oooooo0_l0000Fooooo`;o00000_ooool2o`0003oooooo
0_l0000Wooooo`;o00007Oooool2o`0005cooooo0_l00009ooooo`;o0000:?ooool001kooooo00?o
0000ooooooooool05?ooool2o`00017ooooo0_l00002ooooo`;o00009oooool2o`0001Kooooo0_l0
000Wooooo`;o0000Noooool2o`0001gooooo0_l0000Dooooo`007_ooool00ol0003oooooooooo`0D
ooooo`;o0000?_ooool2o`0001cooooo0_l00006ooooo`;o00006_ooool2o`0006oooooo0_l0000X
ooooo`;o00005?ooool001kooooo00?o0000ooooooooool0E?ooool2o`0000;ooooo0_l0000Hoooo
o`Co00001?ooool2o`0001[ooooo0_l0001_ooooo`;o000000?oooooo`000?l000009_ooool2o`00
01?ooooo000Nooooo`03o`000?oooooooooo047ooooo0_l00005ooooo`;o00002_ooool2o`0000;o
oooo0_l0000Jooooo`;o00002Oooool2o`0007_ooooo0_l0000<ooooo`;o00008Oooool2o`0000?o
oooo0_l0000Cooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o0000:?ooool2o`0000Gooooo
0_l0000eooooo`;o00009oooool2o`0005;ooooo0_l0000_ooooo`;o00006?ooool001kooooo00?o
0000ooooooooool05oooool2o`0006kooooo0_l0000Oooooo`;o0000WOooool001kooooo00?o0000
ooooooooool0Qoooool2o`0001Sooooo0_l0000Mooooo`;o0000:?ooool2o`0002?ooooo0_l0000f
ooooo`007_ooool00ol0003oooooooooo`2Qooooo`;o00007Oooool2o`0002Sooooo0_l0000Goooo
o`;o00002_ooool2o`0002Cooooo0_l0000@ooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o
0000J?ooool2o`0008Sooooo0_l0000`ooooo`;o00004?ooool001kooooo00?o0000ooooooooool0
3oooool2o`0000oooooo0_l0000?ooooo`;o0000A_ooool2o`0000?ooooo0_l0001fooooo`;o0000
Coooool001kooooo00?o0000ooooooooool02_ooool2o`0001Cooooo0_l0000?ooooo`;o0000Booo
ool2o`0007Kooooo0_l0000Cooooo`;o00004oooool2o`0002Gooooo000Nooooo`03o`000?oooooo
oooo00[ooooo0_l0003Iooooo`;o00009?ooool2o`0001;ooooo0ol0000Uooooo`007_ooool00ol0
003oooooooooo`0Rooooo`;o0000`Oooool2o`0000_ooooo0_l0000[ooooo`;o00009_ooool001ko
oooo00?o0000ooooooooool00_l0000Pooooo`;o00004Oooool2o`0001;ooooo0_l0002Wooooo`;o
0000Doooool001kooooo0_l000000ooooooo0000o`00000cooooo`;o00004_ooool2o`00037ooooo
0_l0002eooooo`;o00004_ooool001kooooo00?o0000ooooooooool0O?ooool2o`000;Gooooo0_l0
000Booooo`007_ooool00ol0003oooooooooo`3ooooooc7ooooo0_l0000Eooooo`007_ooool00ol0
003oooooooooo`1looooo`;o0000/_ooool2o`0001Gooooo000Nooooo`03o`000?oooooooooo01Co
oooo0_l0001Vooooo`;o0000Woooool2o`0002Sooooo000Nooooo`03o`000?oooooooooo00Wooooo
0_l00009ooooo`;o0000>?ooool2o`0004_ooooo0_l0000looooo`;o0000@_ooool2o`0002Sooooo
000Nooooo`03o`000?oooooooooo00;o00001oooool2o`0000gooooo0_l0000Hooooo`;o00002ooo
ool2o`0000gooooo0_l0001;ooooo`;o00003_ooool2o`0002cooooo0_l0000Xooooo`;o00000ooo
ool2o`0003gooooo000Nooooo`03o`000?oooooooooo00;o00001Oooool2o`0000;ooooo0_l0000;
ooooo`;o00006?ooool2o`0000_ooooo0_l0001Zooooo`;o0000E_ooool2o`0000?ooooo0_l0000m
ooooo`007_ooool00ol0003oooooooooo`07ooooo`;o00000_ooool2o`0001;ooooo0_l0000goooo
o`;o0000=oooool2o`0001gooooo0_l0001:ooooo`;o0000BOooool001kooooo00?o0000oooooooo
ool07oooool2o`0003Oooooo0_l0000gooooo`;o00007Oooool2o`0003cooooo0_l0000<ooooo`;o
0000BOooool001kooooo00?o0000ooooooooool0H?ooool2o`0008cooooo0_l0001Gooooo`007_oo
ool00ol0003oooooooooo`0?ooooo`;o00004Oooool2o`0002kooooo0_l0000;ooooo`?o0000S?oo
ool2o`00057ooooo0_l00004ooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o00002_ooool2
o`0000Gooooo0_l00008ooooo`;o00001oooool2o`0001_ooooo0_l0000;ooooo`;o0000g_ooool4
o`0000Cooooo000Nooooo`03o`000?oooooooooo00gooooo0_l0000<ooooo`;o00003oooool2o`00
00Oooooo0_l00013ooooo`;o0000Y?ooool2o`0001gooooo1?l00004ooooo`007_ooool00ol0003o
ooooooooo`0=ooooo`;o0000IOooool2o`0000Cooooo0_l0002Tooooo`;o00009Oooool001kooooo
00?o0000ooooooooool02oooool2o`0000Cooooo0_l0001Qooooo`;o0000Boooool2o`0003gooooo
0_l00015ooooo`007_ooool2o`0000cooooo0_l00004ooooo`;o00002?ooool2o`000:Cooooo0_l0
000mooooo`;o0000AOooool001kooooo00?o0000ooooooooool00_ooool2o`0001Oooooo0_l0001n
ooooo`;o0000Ooooool2o`0002Wooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0000Ioooo
o`;o0000O?ooool2o`0004gooooo0_l0000`ooooo`;o0000:Oooool001kooooo00?o0000oooooooo
ool07Oooool2o`0001cooooo0_l0002Wooooo`;o00001?ooool2o`0001Gooooo0_l0000jooooo`;o
00002?ooool001kooooo00?o0000ooooooooool0>oooool2o`000:Oooooo0_l0000Kooooo`;o0000
>_ooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo03Gooooo0_l0000Looooo`;o0000l_oo
ool001kooooo00?o0000ooooooooool0:oooool2o`0000Sooooo0_l00009ooooo`;o00004Oooool2
o`000:Cooooo0_l0001<ooooo`007_ooool00ol0003oooooooooo`0[ooooo`;o00004oooool2o`00
0;Oooooo0_l0001<ooooo`007_ooool00ol0003oooooooooo`1<ooooo`;o0000nOooool001kooooo
00?o0000ooooooooool02oooool2o`0000?ooooo0_l00002ooooo`;o0000=_ooool2o`000?Wooooo
000Nooooo`03o`000?oooooooooo00_ooooo0_l00003ooooo`;o00000_ooool2o`000?oooooo<_oo
ool001kooooo00?o0000ooooooooool0SOooool2o`000;Sooooo000Nooooo`;o00006?ooool2o`00
00gooooo0_l000000ooooooo0000o`00000Uooooo`;o00002?ooool2o`00037ooooo0_l00003oooo
o`;o0000Hoooool2o`0003Gooooo0_l0000Gooooo`007_ooool2o`0001Sooooo0_l0000=ooooo`;o
000000?oooooo`000?l000009Oooool2o`0000Sooooo0_l0000fooooo`;o0000Hoooool2o`0002?o
oooo0_l0000@ooooo`;o00005oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0Ioooool2o`000;?o
oooo0_l0000Yooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0:Oooool2o`0003cooooo0_l00009ooooo`;o
0000@Oooool2o`0000Wooooo0_l0001oooooo`;o00001?ooool000?ooooo00Go410@oooooooooooo
oooooa0@400;ooooo`Go00001_ooool3o`0002Wooooo0_l0000Looooo`;o0000:Oooool2o`00047o
oooo0_l00007ooooo`Co0000KOooool2o`0000Gooooo0_l00009ooooo`;o00001?ooool000?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000oooo
ooooool08Oooool2o`0000kooooo0_l0000Dooooo`;o00007oooool2o`0005Cooooo0_l0000Goooo
o`;o0000E_ooool2o`0000Gooooo0_l0000?ooooo`000oooool01Ol0003ooooooooooooooooo0000
00_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`0Iooooo`;o00001_ooool2
o`0000kooooo0_l0000eooooo`;o0000KOooool2o`0006kooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo00;o00005oooool2
o`000>?ooooo0_l00017ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000001oooool00ol0003oooooooooo`02o`00047ooooo0_l00002ooooo`;o0000]Oooool2
o`0004Oooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06
ooooo`03o`000?oooooooooo04?ooooo0_l00002ooooo`;o0000Koooool2o`0008gooooo000Noooo
o`03o`000?oooooooooo02Oooooo0_l0002?ooooo`;o00003_ooool2o`0003gooooo0_l0000noooo
o`007_ooool00ol0003oooooooooo`0Wooooo`;o00002?ooool2o`0009Gooooo0_l0000mooooo`;o
00006?ooool2o`0002Cooooo000Nooooo`03o`000?oooooooooo01oooooo0_l0000@ooooo`;o0000
B_ooool2o`000:;ooooo0_l0000Tooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o0000G?oo
ool2o`0005Kooooo0_l0001`ooooo`007_ooool00ol0003oooooooooo`1iooooo`;o0000F_ooool2
o`0003gooooo0_l0000aooooo`007_ooool00ol0003oooooooooo`1iooooo`;o0000Noooool2o`00
01cooooo0_l0000aooooo`007_ooool00ol0003oooooooooo`1oooooo`;o00009Oooool2o`0004ko
oooo0_l0000Sooooo`;o0000:_ooool001kooooo00?o0000ooooooooool0Ooooool2o`0002Gooooo
0_l0001cooooo`;o00003oooool2o`0001Wooooo000Nooooo`03o`000?oooooooooo08Sooooo0_l0
002Rooooo`;o00006Oooool001kooooo00?o0000ooooooooool0J_ooool2o`0001cooooo0_l00008
ooooo`;o0000O?ooool2o`0000Kooooo0_l0000]ooooo`007_ooool00ol0003oooooooooo`0/oooo
o`;o0000??ooool2o`0002Kooooo0_l0001looooo`;o00001_ooool2o`0000;ooooo0_l0000Boooo
o`;o00005Oooool001kooooo0_l00008ooooo`;o00008oooool2o`000:Cooooo0_l00018ooooo`;o
00004_ooool2o`0001Gooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l000000ooooooo0000
o`00000kooooo`;o0000S?ooool2o`0005?ooooo0_l0000Nooooo`007_ooool00ol0003ooooooooo
o`04ooooo`;o0000?_ooool2o`0000;ooooo0_l00014ooooo`;o0000Qoooool2o`0000kooooo0_l0
000Nooooo`007_ooool00ol0003oooooooooo`07ooooo`;o0000?oooool4o`0000[ooooo0_l0000Y
ooooo`;o00002oooool2o`0003[ooooo0_l0001;ooooo`;o0000;_ooool001kooooo00?o0000oooo
ooooool01oooool2o`00047ooooo0_l0000:ooooo`;o0000:Oooool2o`0004Oooooo0_l0000Hoooo
o`;o00006Oooool2o`0004Kooooo000Nooooo`03o`000?oooooooooo00;o0000>Oooool2o`0003oo
oooo0_l00006ooooo`;o0000G_ooool2o`0000?ooooo0_l0000Dooooo`;o0000A_ooool001kooooo
00?o0000ooooooooool00_l0000Eooooo`Co00007Oooool2o`000003ooooool0003o000003oooooo
0_l00006ooooo`;o0000??ooool2o`0002Gooooo0_l0000Kooooo`;o0000?oooool001gooooo0_l0
000Iooooo`Co00007Oooool2o`0003Kooooo0_l0000Uooooo`;o0000:Oooool2o`0004;ooooo0_l0
000Iooooo`;o00009?ooool001gooooo0_l0000Cooooo`;o0000AOooool2o`0001Kooooo0_l0000U
ooooo`;o00000oooool2o`0008?ooooo0_l00004ooooo`;o00005oooool2o`0000Gooooo000Noooo
o`03o`000?oooooooooo017ooooo0_l00015ooooo`;o00000_ooool2o`0003kooooo0_l0001=oooo
o`;o0000>_ooool2o`0001Oooooo0_l00005ooooo`007_ooool00ol0003oooooooooo`1Looooo`;o
0000H?ooool2o`0002_ooooo0_l0000Hooooo`;o00009_ooool2o`0001Sooooo000Nooooo`04o`00
0?oooooo0000o`000;gooooo0_l00015ooooo`;o00009_ooool2o`0001Sooooo000Nooooo`04o`00
0?oooooo0000o`0003Oooooo0_l0001gooooo`;o0000U?ooool001kooooo00?o0000ooooooooool0
>?ooool2o`0000;ooooo0_l0001cooooo`;o0000U?ooool001kooooo00?o0000ooooooooool07Ooo
ool2o`0001gooooo0_l0000[ooooo`;o0000=Oooool2o`0005oooooo0_l00014ooooo`007_ooool0
0ol0003oooooooooo`0Mooooo`;o0000B_ooool2o`0000Kooooo0_l0000Sooooo`;o00001oooool3
o`0000cooooo0_l0000aooooo`;o000000?oooooo`000?l000006oooool2o`0004Cooooo000Noooo
o`;o0000L_ooool2o`0001Cooooo0_l0000=ooooo`;o00001oooool2o`0000gooooo0_l0000aoooo
o`;o000000?oooooo`000?l00000HOooool001kooooo00?o0000ooooooooool0Qoooool2o`0001go
oooo0_l0002Cooooo`;o00002_ooool001kooooo00?o0000ooooooooool0>_ooool2o`0001[ooooo
0_l0001:ooooo`;o00000_ooool2o`0003cooooo0_l00010ooooo`;o00004oooool2o`0000[ooooo
000Nooooo`03o`000?oooooooooo03[ooooo0_l0000Jooooo`;o0000A?ooool2o`0000Cooooo0_l0
000Gooooo`;o00009oooool2o`0002Wooooo0_l0000Eooooo`;o00007oooool001kooooo00?o0000
ooooooooool0:oooool2o`0002Wooooo0_l00014ooooo`;o00007Oooool2o`0005;ooooo0_l0000f
ooooo`007_ooool00ol0003oooooooooo`0[ooooo`;o0000=oooool2o`0000Oooooo0_l0003Hoooo
o`007_ooool00ol0003oooooooooo`0>ooooo`;o0000=Oooool2o`0001gooooo0_l00007ooooo`;o
00001Oooool2o`0007?ooooo0_l0001Looooo`007_ooool00ol0003oooooooooo`05ooooo`;o0000
1oooool2o`0003Gooooo0_l0000]ooooo`;o0000>Oooool2o`0003Sooooo0_l0000Hooooo`;o0000
4oooool2o`0002gooooo000Nooooo`03o`000?oooooooooo00Gooooo0_l0000nooooo`;o0000J?oo
ool2o`0005;ooooo0_l0000Cooooo`;o0000;Oooool001kooooo00?o0000ooooooooool0NOooool2
o`0008[ooooo0_l00010ooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o0000>?ooool2o`00
02Sooooo0_l00007ooooo`;o0000POooool2o`0001;ooooo0_l0000/ooooo`007_ooool00ol0003o
ooooooooo`0Eooooo`?o00003_ooool2o`0000_ooooo0_l0000Aooooo`;o00001oooool3o`0002Go
oooo0_l00009ooooo`;o0000UOooool2o`0001[ooooo0_l0000@ooooo`007_ooool00ol0003ooooo
ooooo`0Fooooo`;o000000?oooooo`000?l000002oooool2o`0000_ooooo0_l0000Aooooo`;o0000
2?ooool2o`0002Gooooo0_l0000<ooooo`;o0000R_ooool2o`0002;ooooo0_l0000@ooooo`007_oo
ool00ol0003oooooooooo`0Iooooo`;o0000;Oooool2o`0003_ooooo0_l0000jooooo`;o0000C_oo
ool2o`0000[ooooo0_l0000Xooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o00008oooool2
o`0000Kooooo0_l0000jooooo`;o0000<oooool2o`0005[ooooo0_l0000Xooooo`007_ooool00ol0
003oooooooooo`0Sooooo`;o0000:oooool2o`0003Sooooo1?l0002iooooo`007_ooool2o`0001_o
oooo0_l0001^ooooo`;o0000Noooool2o`0003kooooo000Nooooo`03o`000?oooooooooo01[ooooo
0_l0000?ooooo`;o0000COooool2o`0001;ooooo0_l0000?ooooo`;o00003Oooool2o`0005Oooooo
0_l0000cooooo`;o00002Oooool001gooooo0_l0000Dooooo`;o00001oooool2o`0000kooooo0_l0
000Pooooo`;o00006_ooool2o`0000oooooo0_l0000:ooooo`;o00001_ooool2o`0000oooooo0_l0
000=ooooo`;o0000S?ooool2o`0000Wooooo000Mooooo`;o00005?ooool2o`0000Oooooo0_l0000`
ooooo`;o00006_ooool2o`0001_ooooo0_l0000`ooooo`;o00001oooool2o`0001;ooooo0_l0001`
ooooo`007_ooool00ol0003oooooooooo`03ooooo`;o0000=Oooool2o`0000gooooo0_l0001]oooo
o`;o00001oooool2o`0001;ooooo0_l0001`ooooo`007_ooool00ol0003oooooooooo`03ooooo`;o
0000=Oooool2o`0000gooooo0_l0003Tooooo`;o00005_ooool001kooooo00?o0000ooooooooool0
ooooool^ooooo`Co00005_ooool001kooooo00?o0000ooooooooool0ooooool^ooooo`;o00006?oo
ool001kooooo00?o0000ooooooooool0>_ooool2o`00077ooooo0_l0002Hooooo`007_ooool00ol0
003oooooooooo`0jooooo`;o0000LOooool2o`0005Cooooo0_l00012ooooo`007_ooool00ol0003o
ooooooooo`0Dooooo`;o0000NOooool2o`0002Cooooo0_l0000]ooooo`;o00007Oooool2o`0004;o
oooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0000fooooo`;o0000>oooool2o`0000Cooooo
0_l0000Tooooo`;o0000;Oooool2o`00067ooooo000Nooooo`03o`000?oooooooooo02Sooooo0_l0
000Qooooo`?o00001_ooool2o`0003?ooooo0_l0002?ooooo`;o0000:oooool001kooooo00?o0000
ooooooooool01?ooool2o`0002;ooooo0_l0000?ooooo`;o00004?ooool2o`0000Oooooo0_l0000f
ooooo`;o0000Q_ooool2o`0000Cooooo0_l00008ooooo`;o00008Oooool000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o
0000ooooooooool01?ooool2o`0003?ooooo0_l0001Aooooo`;o0000C?ooool2o`0003Sooooo0_l0
000>ooooo`;o00008Oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0f_ooool2o`0000kooooo
0_l0000fooooo`;o00008oooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`00
0?ooooooooooooooool000001_ooool3o`0008Oooooo0_l0001Qooooo`;o0000=_ooool2o`0002?o
oooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q
00Kooooo00Co0000oooooooooooooooo0_l00024ooooo`;o0000__ooool000?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool01?l0003ooooooooo
ooooool2o`0006gooooo0_l0000Sooooo`;o0000GOooool2o`0003Cooooo0_l0000Kooooo`000ooo
ool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003ooooo
ooooo`1`ooooo`;o00000oooool2o`0001kooooo0_l00003ooooo`;o0000Doooool2o`0000?ooooo
0_l0000dooooo`;o00006oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgM
gOl@413oV9RH00Sooooo0ol0000Sooooo`;o0000<?ooool2o`0001Gooooo0_l00007ooooo`;o0000
5?ooool2o`0000gooooo0_l0000Aooooo`;o0000@?ooool2o`0005Kooooo0003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`?o00002Oooool2o`0001So
oooo0_l0000`ooooo`;o00005Oooool2o`0000[ooooo0_l0000Aooooo`;o00008?ooool2o`0009So
oooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0001]ooooo`;o0000>Oooool2o`0003_ooooo
0_l0000Vooooo`;o0000;Oooool001kooooo00?o0000ooooooooool06?ooool4o`0009Oooooo0_l0
000kooooo`;o00009_ooool2o`0002gooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0000B
ooooo`Co0000Coooool2o`0007oooooo0_l0001Iooooo`007_ooool00ol0003oooooooooo`04oooo
o`;o0000IOooool2o`0005kooooo0_l0000Oooooo`;o0000@_ooool2o`0001Gooooo000Nooooo`03
o`000?oooooooooo00Gooooo0ol00033ooooo`;o000000?oooooo`000?l00000DOooool2o`0000go
oooo0_l0000Eooooo`007_ooool00ol0003oooooooooo`05ooooo`?o0000=oooool2o`0007?ooooo
0_l0000Hooooo`;o0000DOooool2o`0002Cooooo000Nooooo`03o`000?oooooooooo03oooooo0_l0
000@ooooo`;o00007?ooool2o`0004?ooooo0_l00017ooooo`;o00007?ooool2o`0002[ooooo000N
ooooo`03o`000?oooooooooo057ooooo0_l0000;ooooo`;o00003oooool2o`0002oooooo0_l0001A
ooooo`;o00002?ooool2o`0001cooooo0_l0000Zooooo`007_ooool00ol0003oooooooooo`0Loooo
o`;o0000@?ooool2o`00043ooooo0_l00017ooooo`;o00002?ooool2o`0005;ooooo000Nooooo`03
o`000?oooooooooo01cooooo0_l0001mooooo`;o0000C?ooool2o`0002Gooooo0_l0000eooooo`00
7_ooool00ol0003oooooooooo`02o`00087ooooo0_l0000Fooooo`;o0000>Oooool2o`0003Sooooo
0_l0000eooooo`007_ooool2o`000003ooooool0003o000001;ooooo0_l0001]ooooo`;o0000DOoo
ool2o`0004;ooooo0_l0000[ooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o0000;_ooool2
o`0005_ooooo0_l00012ooooo`;o0000<oooool2o`0001Kooooo0_l0000Cooooo`007_ooool00ol0
003oooooooooo`0^ooooo`;o00005?ooool3o`0005[ooooo0_l0000Zooooo`;o00005_ooool2o`00
03?ooooo0_l0000>ooooo`;o00001_ooool2o`0001?ooooo000Nooooo`?o0000;_ooool2o`0001Go
oooo0_l0001@ooooo`;o0000=?ooool2o`0002?ooooo0_l0000fooooo`;o00006oooool001kooooo
0ol0002Gooooo`;o0000FOooool2o`0002cooooo0_l0000Uooooo`007_ooool00ol0003ooooooooo
o`09ooooo`Co0000G?ooool2o`0000_ooooo0_l0000<ooooo`;o00007Oooool2o`0007_ooooo0_l0
000Uooooo`007_ooool00ol0003oooooooooo`09ooooo`Co0000G?ooool2o`000003ooooool0003o
000000Sooooo0_l0000<ooooo`;o00007Oooool2o`000:;ooooo000Nooooo`03o`000?oooooooooo
04Oooooo0_l0000Sooooo`;o0000?oooool2o`0006oooooo0_l0000Fooooo`;o00003oooool001ko
oooo00?o0000ooooooooool0Aoooool2o`0006Cooooo0_l0000<ooooo`;o0000HOooool2o`0001Ko
oooo0_l0000?ooooo`007_ooool00ol0003oooooooooo`0Tooooo`;o00009_ooool2o`0006gooooo
0_l0001_ooooo`;o00000oooool2o`0000?ooooo0_l0000?ooooo`007_ooool00ol0003ooooooooo
o`0Tooooo`;o00007Oooool3o`0000Kooooo0_l00012ooooo`;o0000>_ooool2o`0001Cooooo0_l0
0018ooooo`;o00000oooool2o`0001Cooooo000Nooooo`03o`000?oooooooooo04?ooooo0ol0000:
ooooo`;o00008oooool2o`0001Wooooo0_l0000jooooo`;o00005?ooool2o`0001?ooooo0_l0000e
ooooo`;o00005oooool001kooooo00?o0000ooooooooool0D?ooool2o`0000Wooooo0_l0000Hoooo
o`;o00001Oooool2o`0000oooooo0_l0000Nooooo`;o0000B?ooool2o`0003Gooooo0_l0000<oooo
o`;o00002Oooool001kooooo00?o0000ooooooooool0Foooool2o`0000cooooo0_l0000Aooooo`;o
00003oooool2o`0001kooooo0_l0001Fooooo`;o0000=Oooool2o`0000Wooooo000Nooooo`03o`00
0?oooooooooo00[ooooo0_l0001Mooooo`;o00006Oooool2o`0001Gooooo0_l00002ooooo`;o0000
6Oooool2o`0000Gooooo0_l00012ooooo`;o00001Oooool2o`0003Wooooo000Nooooo`03o`000?oo
oooooooo00[ooooo0_l00003ooooo`;o00008_ooool2o`0001cooooo0_l0000_ooooo`Co00004ooo
ool4o`0000;ooooo0_l0000Iooooo`;o00001Oooool2o`0004Cooooo0_l00003ooooo`;o00001?oo
ool2o`0003?ooooo000Nooooo`;o00004?ooool2o`0002;ooooo0_l0000Looooo`;o0000;oooool2
o`0001Gooooo0_l0000>ooooo`;o0000G?ooool2o`0000Wooooo0_l0000/ooooo`;o00001Oooool0
01kooooo00?o0000ooooooooool07Oooool2o`0002Gooooo0_l00005ooooo`;o0000G?ooool2o`00
05gooooo0_l0000Uooooo`;o00003oooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo00;o
00004oooool2o`0000Kooooo0_l0000Uooooo`;o00001Oooool2o`0002kooooo0_l0000Pooooo`;o
00004Oooool2o`0005Kooooo0_l0000Uooooo`;o00002?ooool2o`0000cooooo000Nooooo`03o`00
0?oooooooooo00;o00004oooool2o`00043ooooo0_l00007ooooo`;o00006Oooool2o`00023ooooo
0_l0000Aooooo`;o00003_ooool2o`0006Cooooo0_l0000Aooooo`;o00003?ooool001kooooo0ol0
00000ooooooo0000o`00000booooo`;o00008?ooool2o`0000Oooooo0_l0001Nooooo`;o0000Dooo
ool2o`0000oooooo0_l0000Oooooo`007_ooool3o`000003ooooool0003o000003;ooooo0_l0001D
ooooo`;o0000R?ooool2o`00033ooooo000Nooooo`03o`000?oooooooooo08_ooooo0_l00013oooo
o`;o0000MOooool001kooooo00?o0000ooooooooool0F?ooool2o`0002oooooo0_l00005ooooo`Co
00002oooool2o`0002oooooo0_l000000ooooooo0000o`00001booooo`007_ooool00ol0003ooooo
ooooo`1Hooooo`;o0000;oooool2o`0000Gooooo1?l0000;ooooo`;o0000<_ooool2o`0003gooooo
0_l0000cooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o00009oooool2o`0001Kooooo0_l0
001Hooooo`;o00006?ooool2o`0001cooooo0_l0000;ooooo`;o00005oooool2o`0003?ooooo000N
ooooo`03o`000?oooooooooo01Wooooo0_l0000Wooooo`;o00005_ooool2o`0005Sooooo0_l0000H
ooooo`;o00004?ooool2o`0000[ooooo0_l0000;ooooo`;o0000C?ooool001kooooo00?o0000oooo
ooooool05_ooool2o`000;?ooooo0_l0000Cooooo`;o00008Oooool2o`0003cooooo0_l00004oooo
o`007_ooool00ol0003oooooooooo`0Fooooo`;o0000Ioooool2o`0002Gooooo0_l0000Kooooo`;o
00000_ooool2o`0000;ooooo0_l0000fooooo`;o00008?ooool2o`0001[ooooo0_l00004ooooo`00
7_ooool00ol0003oooooooooo`0?ooooo`;o0000K_ooool2o`0000Kooooo0_l0000Mooooo`;o0000
2Oooool2o`00013ooooo0_l00002ooooo`;o00002_ooool2o`00053ooooo0_l0000Pooooo`007_oo
ool00ol0003oooooooooo`0?ooooo`;o0000;_ooool2o`0002_ooooo0ol0000Hooooo`;o0000:?oo
ool2o`0001Wooooo0_l00005ooooo`;o0000>Oooool2o`0003Oooooo000Nooooo`04o`000?oooooo
ooooooooo`;o0000??ooool2o`0000;ooooo0_l0000Wooooo`?o00009?ooool2o`0001cooooo0_l0
000Iooooo`;o0000=_ooool2o`0000Sooooo0_l0000gooooo`007_ooool2o`0000;ooooo0_l00010
ooooo`;o000000?oooooo`000?l000002Oooool2o`00043ooooo0_l0001_ooooo`;o0000=?ooool2
o`0000_ooooo000Nooooo`03o`000?oooooooooo04Kooooo0_l00009ooooo`;o00002oooool2o`00
0=[ooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`02o`0000Cooooo0_l0000[ooooo`;o
00002_ooool2o`0001gooooo0_l0000;ooooo`;o0000:?ooool2o`0008;ooooo0_l0000/ooooo`00
7_ooool00ol0003oooooooooo`02o`0000Cooooo0_l0000[ooooo`;o00002_ooool2o`0002[ooooo
0_l0000Dooooo`;o00003Oooool2o`0000?ooooo0_l0000fooooo`;o0000B_ooool2o`0002cooooo
000Nooooo`04o`000?oooooo0000o`0003Oooooo0_l00006ooooo`;o00003?ooool2o`00037ooooo
0_l0000=ooooo`;o0000>oooool2o`0007Sooooo000Nooooo`04o`000?oooooo0000o`0000;ooooo
0_l0000cooooo`;o00001_ooool2o`0000cooooo0_l0000Vooooo`;o00002?ooool2o`000<Gooooo
000Nooooo`03o`000?oooooooooo00?ooooo0_l0000:ooooo`;o0000IOooool2o`0000Sooooo0_l0
002=ooooo`;o00001oooool2o`0000_ooooo0_l0000=ooooo`;o00004Oooool001kooooo00?o0000
ooooooooool03oooool2o`0000Oooooo0_l00011ooooo`;o00006?ooool2o`0009Sooooo0_l00007
ooooo`;o00002oooool2o`0000gooooo0_l0000Aooooo`007_ooool00ol0003oooooooooo`0Hoooo
o`;o0000@Oooool2o`0001Sooooo0_l0001Hooooo`;o00006Oooool2o`0005_ooooo000Nooooo`03
o`000?oooooooooo03Gooooo0_l0002Hooooo`;o00006Oooool2o`0002Cooooo0_l0000eooooo`00
7_ooool00ol0003oooooooooo`0eooooo`;o00006oooool2o`0001?ooooo0_l0000:ooooo`;o0000
3oooool2o`0007?ooooo0_l0000Eooooo`;o0000=Oooool001kooooo00?o0000ooooooooool0D_oo
ool2o`0001?ooooo0_l0000:ooooo`;o00003oooool2o`0007?ooooo0_l0000kooooo`;o00003ooo
ool001kooooo00?o0000ooooooooool0_Oooool2o`0004kooooo0_l0000<ooooo`;o00006Oooool2
o`0000oooooo000Nooooo`03o`000?oooooooooo03kooooo1?l0000=ooooo`;o0000K?ooool2o`00
02Wooooo0_l0000Sooooo`;o00003?ooool2o`0002[ooooo0003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooo
oooo03kooooo1?l0000=ooooo`;o0000Uoooool2o`0001Wooooo0_l0000Gooooo`;o00003oooool2
o`0001Sooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4Q
oiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo053ooooo0_l0002aooooo`;o00005ooo
ool2o`0000_ooooo0_l00002ooooo`;o00006?ooool000?ooooo00Go410@oooooooooooooooooa0@
400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`0000oooooo0_l0000Mooooo`;o0000
8?ooool2o`0004Wooooo1?l0000Looooo`;o0000?oooool2o`0002_ooooo0_l0000<ooooo`;o0000
3_ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb
<S801_ooool00ol0003oooooooooo`0?ooooo`;o00007Oooool2o`0000Kooooo0_l0001Sooooo`Co
00007?ooool2o`0003oooooo0_l0000Aooooo`;o00000oooool2o`00027ooooo0_l0000>ooooo`00
0oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006oooo
o`03o`000?oooooooooo00[ooooo0_l0000Zooooo`;o0000>?ooool2o`0001?ooooo0_l00028oooo
o`;o00000oooool2o`00037ooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@
413o^[Zjoooooonj^[[o410@00Kooooo00Co0000oooooooooooooooo0_l00007ooooo`;o0000:?oo
ool2o`0001_ooooo0_l0000Mooooo`;o00001oooool2o`0000[ooooo0_l0001Gooooo`;o00001Ooo
ool2o`00063ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooo
oonj^[[o000000Kooooo00Co0000oooooooooooooooo0_l00002ooooo`;o0000;Oooool2o`0001_o
oooo0_l0000Mooooo`;o00001oooool2o`0006?ooooo0_l00005ooooo`;o0000H?ooool000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0
003oooooooooo`05ooooo`;o0000oooooom1ooooo`007Oooool2o`0003Wooooo0_l00008ooooo`;o
0000Koooool2o`0000[ooooo0_l0000hooooo`;o00006?ooool2o`0000_ooooo0_l0000Vooooo`00
7Oooool2o`0003Wooooo0_l00008ooooo`;o00007?ooool2o`00057ooooo0_l0000:ooooo`;o0000
>?ooool2o`0001Sooooo0_l0000;ooooo`;o00008?ooool2o`0000Cooooo000Nooooo`03o`000?oo
oooooooo03kooooo0_l0000Oooooo`;o00006oooool2o`000<?ooooo0_l00004ooooo`007_ooool0
0ol0003oooooooooo`0nooooo`;o00008_ooool2o`0001Sooooo0_l0000Booooo`;o0000ZOooool2
o`0000[ooooo000Nooooo`03o`000?oooooooooo047ooooo0_l0000Oooooo`;o00006?ooool2o`00
01;ooooo0_l00007ooooo`;o0000Soooool2o`0000oooooo0_l0000:ooooo`007_ooool00ol0003o
ooooooooo`11ooooo`;o00009_ooool2o`00017ooooo0_l0000Kooooo`;o0000:oooool2o`0006;o
oooo0_l0000Kooooo`007_ooool00ol0003oooooooooo`0oooooo`;o0000:?ooool2o`0005_ooooo
0_l0001oooooo`007_ooool00ol0003oooooooooo`0oooooo`;o0000FOooool2o`0001gooooo0_l0
000=ooooo`;o0000E_ooool2o`0002Gooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l00022
ooooo`;o00002_ooool2o`0001gooooo0_l0000=ooooo`;o00001Oooool2o`0004oooooo0_l0000U
ooooo`007_ooool2o`0000_ooooo0_l00009ooooo`;o00005oooool2o`0005kooooo0ol0000moooo
o`?o0000M_ooool001kooooo0_l0000Fooooo`;o00005oooool2o`0000Kooooo0_l0000?ooooo`;o
0000A_ooool2o`0003Gooooo0_l00006ooooo`;o0000Moooool001kooooo0_l0000_ooooo`;o0000
0_ooool2o`0000;ooooo0_l0000?ooooo`;o0000>?ooool2o`0000?ooooo0_l0000nooooo`;o0000
9?ooool2o`0005Wooooo000Nooooo`03o`000?oooooooooo02;ooooo0_l0000:ooooo`;o00000_oo
ool2o`0004gooooo0_l00003ooooo`;o00006_ooool2o`0004Sooooo0_l0001Iooooo`007_ooool0
0ol0003oooooooooo`0Rooooo`;o0000GOooool2o`0001oooooo0_l00008ooooo`;o00003_ooool2
o`0008Wooooo000Nooooo`03o`000?oooooooooo05[ooooo0_l00015ooooo`;o00002Oooool2o`00
00kooooo0_l00008ooooo`;o0000F?ooool2o`0002Gooooo000Nooooo`03o`000?oooooooooo03Wo
oooo0_l0000Oooooo`;o0000AOooool2o`0002?ooooo0_l0000`ooooo`;o00009_ooool2o`0002Go
oooo000Nooooo`03o`000?oooooooooo03Wooooo0_l0000Gooooo`;o0000GOooool2o`0000cooooo
0_l0000gooooo`;o0000?_ooool2o`000003ooooool0003o000000[ooooo000Nooooo`03o`000?oo
oooooooo05;ooooo0_l0001Cooooo`;o00002?ooool2o`0000cooooo0_l0000_ooooo`;o0000;?oo
ool2o`0000cooooo0_l0000:ooooo`;o000000?oooooo`000?l000002_ooool001kooooo00?o0000
ooooooooool0Foooool3o`0000Oooooo0_l0000@ooooo`;o0000;_ooool2o`0004Oooooo0_l0000/
ooooo`;o00003?ooool2o`0000Cooooo0_l0000Cooooo`007_ooool00ol0003oooooooooo`1Koooo
o`?o00001oooool2o`00013ooooo0_l0000looooo`;o0000Noooool2o`0001?ooooo000Nooooo`03
o`000?oooooooooo04Oooooo0_l0000Booooo`;o0000B?ooool2o`0000kooooo0_l0002@ooooo`00
7_ooool00ol0003oooooooooo`17ooooo`;o0000G?ooool2o`000:3ooooo000Nooooo`03o`000?oo
oooooooo03oooooo0_l0003oooooo`Oooooo000Nooooo`03o`000?oooooooooo03oooooo0_l0001@
ooooo`;o00005Oooool2o`0007[ooooo0_l0000Qooooo`007_ooool00ol0003oooooooooo`1Poooo
o`;o00005Oooool2o`0001Sooooo0_l0000Eooooo`;o00005Oooool2o`0006?ooooo0_l0000Qoooo
o`007_ooool00ol0003oooooooooo`0Yooooo`;o0000;oooool2o`0000Cooooo0_l0000Eooooo`;o
0000A_ooool2o`0006Cooooo0_l0000Pooooo`007_ooool00ol0003oooooooooo`0Yooooo`;o0000
;oooool2o`0002Kooooo0_l00005ooooo`;o00001?ooool2o`0004Oooooo0_l00009ooooo`;o0000
@?ooool2o`00023ooooo000Nooooo`;o00008_ooool2o`0005Kooooo0_l00007ooooo`;o00001Ooo
ool2o`0000Cooooo0_l0000<ooooo`;o00007Oooool2o`0001[ooooo0_l00009ooooo`;o0000H_oo
ool001kooooo00?o0000ooooooooool08Oooool2o`0005Kooooo0_l0000Rooooo`;o00007Oooool2
o`0005gooooo0_l0000Zooooo`007_ooool00ol0003oooooooooo`0Qooooo`;o0000=oooool2o`00
04gooooo0_l0001`ooooo`;o0000:_ooool001kooooo00?o0000ooooooooool08Oooool2o`0003Oo
oooo0_l0001=ooooo`;o00004?ooool2o`0001Wooooo0_l00018ooooo`;o00009Oooool001kooooo
00?o0000ooooooooool0Boooool2o`0000oooooo0_l0001Mooooo`;o00006Oooool4o`0004Kooooo
0_l0000Uooooo`007_ooool00ol0003oooooooooo`02o`0000Kooooo0_l00011ooooo`;o00003ooo
ool2o`0001Gooooo1?l0000`ooooo`;o0000;oooool2o`0002gooooo0_l0000Nooooo`;o00007_oo
ool001kooooo00?o0000ooooooooool00_l00006ooooo`;o00005_ooool2o`0003cooooo0_l0000C
ooooo`Co00008oooool2o`0000_ooooo0_l0001Nooooo`;o00007_ooool2o`0001kooooo000Noooo
o`03o`000?oooooooooo023ooooo0_l000000ooooooo0000o`00000iooooo`;o0000>_ooool2o`00
00gooooo0_l0000looooo`;o00001?ooool2o`0005Sooooo000Nooooo`03o`000?oooooooooo02?o
oooo0_l0001Cooooo`;o00000oooool2o`0002[ooooo0_l0000looooo`;o00001?ooool2o`0000?o
oooo0_l0000Qooooo`;o0000<?ooool001kooooo00?o0000ooooooooool0N?ooool2o`0000?ooooo
0_l0000hooooo`;o00003oooool2o`0002Sooooo0_l0000Qooooo`;o0000<?ooool001kooooo00?o
0000ooooooooool00_ooool2o`0005Oooooo0_l0001Jooooo`;o00003oooool2o`0007gooooo000N
ooooo`03o`000?oooooooooo00;ooooo0_l0001Gooooo`;o00008Oooool2o`000<Oooooo000Noooo
o`03o`000?oooooooooo06kooooo0_l0000>ooooo`;o00005_ooool2o`0005Kooooo0_l0001Goooo
o`007_ooool00ol0003oooooooooo`1^ooooo`;o00005oooool2o`0000gooooo0_l0001Fooooo`;o
00001Oooool2o`00053ooooo000Nooooo`03o`000?oooooooooo03Kooooo0_l0000:ooooo`;o0000
@oooool2o`0006cooooo0_l0000Dooooo`;o0000<oooool2o`0000Gooooo000Nooooo`03o`000?oo
oooooooo00gooooo0_l0000Wooooo`;o00002_ooool2o`0007Cooooo0_l0001Aooooo`;o00008ooo
ool2o`0000kooooo0_l00005ooooo`007_ooool2o`0000;ooooo0_l0000:ooooo`;o0000;_ooool2
o`0001oooooo0_l0000Nooooo`;o0000>?ooool2o`0007Kooooo0_l0000Eooooo`007_ooool01?l0
003oooooooooooooool2o`0000;ooooo1?l0000Hooooo`;o00000oooool2o`0001;ooooo0_l00000
0ooooooo0000o`00000Oooooo`;o00001?ooool2o`0001Sooooo0_l000000ooooooo0000o`00000E
ooooo`;o00004?ooool2o`0008?ooooo0_l0000Fooooo`007_ooool00ol0003oooooooooo`05oooo
o`Co00006?ooool2o`0000?ooooo0_l0000Booooo`;o0000:?ooool2o`0001Wooooo1?l0000>oooo
o`;o00001Oooool2o`00013ooooo0_l0000>ooooo`;o00000oooool2o`0002gooooo0_l0000ooooo
o`;o00003Oooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo01?ooooo0_l00006ooooo`;o
00003?ooool2o`0005Cooooo0_l0000@ooooo`;o00009oooool2o`0000?ooooo0_l0000Xooooo`;o
00000oooool2o`0004kooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`0Cooooo`?o0000
1Oooool4o`0000[ooooo0_l0000@ooooo`;o0000HOooool2o`0004Wooooo0_l0000iooooo`;o0000
1_ooool2o`0001Wooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l00007ooooo`;o00007?oo
ool2o`0000kooooo0_l0000kooooo`;o00005?ooool2o`00067ooooo0_l0000Qooooo`;o00001_oo
ool2o`0001Wooooo000Nooooo`03o`000?oooooooooo04_ooooo0_l0000kooooo`;o0000Moooool2
o`0004Cooooo000Nooooo`03o`000?oooooooooo04Kooooo0_l0003Gooooo`;o00009_ooool001ko
oooo00?o0000ooooooooool07Oooool2o`0002Oooooo0_l0000>ooooo`;o0000S?ooool2o`0000Co
oooo0_l0000cooooo`;o00009_ooool001kooooo00?o0000ooooooooool07Oooool2o`0000[ooooo
0_l0000[ooooo`;o0000NOooool2o`00017ooooo0_l00004ooooo`;o0000Foooool001kooooo00?o
0000ooooooooool0:Oooool2o`0003cooooo0_l0001Eooooo`;o00004Oooool2o`0007Cooooo000N
ooooo`03o`000?oooooooooo01;ooooo0_l0001Cooooo`;o0000EOooool2o`0001Cooooo0_l0001a
ooooo`007_ooool00ol0003oooooooooo`0Booooo`;o0000^_ooool2o`0000Cooooo0_l0001aoooo
o`007_ooool00ol0003oooooooooo`1Yooooo`;o0000@oooool4o`0001cooooo0_l0000Cooooo`;o
0000FOooool2o`0000Oooooo000Dooooo`Co000000?o410@ooooooooool00oooool00ol0003ooooo
ooooo`0iooooo`;o00007oooool2o`0000gooooo0ol0000Uooooo`;o00006oooool4o`00037ooooo
0_l00018ooooo`;o00003oooool2o`0000Oooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0>Oooool2o`0000[ooooo0_l0000Cooooo`;o00003_ooool2o`0002Gooooo0_l0
0006ooooo`;o0000I?ooool2o`0001_ooooo0_l0000?ooooo`;o00006?ooool001Kooooo00?o0000
ooooooooool01Oooool3o`0004Gooooo0_l0001Booooo`;o00003?ooool2o`0000Cooooo0_l0001@
ooooo`;o00006oooool2o`0002Wooooo000Fooooo`03o`000?oooooooooo0:oooooo0_l00004oooo
o`;o0000V?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003ooooo
ooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Cooooo00?oEEEE
ofIVI_l00000oooooomBooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.90879 .00625 Mdot
.57913 .1056 Mdot
.33739 .24867 Mdot
.68068 .07843 Mdot
.28533 .91032 Mdot
.16344 .72018 Mdot
.87344 .54674 Mdot
.06216 .35816 Mdot
.41631 .74496 Mdot
.55644 .01222 Mdot
.563 .75625 Mdot
.46267 .78969 Mdot
.08363 .10721 Mdot
.7265 .91247 Mdot
.25942 .4508 Mdot
.73931 .40557 Mdot
.67045 .00924 Mdot
.88815 .24892 Mdot
.36624 .0558 Mdot
.23471 .37539 Mdot
.37246 .63147 Mdot
.97022 .12223 Mdot
.43722 .44271 Mdot
.95224 .95565 Mdot
.00575 .60926 Mdot
.61124 .60999 Mdot
.86473 .4848 Mdot
.7584 .42883 Mdot
.84608 .02798 Mdot
.23004 .70997 Mdot
.99774 .62966 Mdot
.59568 .77916 Mdot
.71551 .48715 Mdot
.06435 .18776 Mdot
.9559 .66459 Mdot
.56004 .85445 Mdot
.68479 .68852 Mdot
.38294 .85196 Mdot
.9925 .70703 Mdot
.24257 .79305 Mdot
.81122 .01928 Mdot
.24769 .56555 Mdot
.45043 .9262 Mdot
.35351 .0563 Mdot
.20094 .9937 Mdot
.46167 .60623 Mdot
.64878 .86349 Mdot
.33495 .29664 Mdot
.83741 .78028 Mdot
.46229 .73461 Mdot
.2967 .5944 Mdot
.91518 .64539 Mdot
.00193 .17612 Mdot
.07323 .38829 Mdot
.23089 .67845 Mdot
.38243 .76836 Mdot
.86605 .04406 Mdot
.26798 .85361 Mdot
.44351 .32981 Mdot
.26578 .08933 Mdot
.98878 .14261 Mdot
.26601 .88494 Mdot
.2265 .76756 Mdot
.87288 .87842 Mdot
.5885 .33521 Mdot
.20731 .95983 Mdot
.91266 .11219 Mdot
.55552 .58945 Mdot
.87533 .73955 Mdot
.93389 .25618 Mdot
.03469 .93421 Mdot
.33484 .73176 Mdot
.0732 .40026 Mdot
.69279 .49275 Mdot
.70886 .89406 Mdot
.24573 .1213 Mdot
.35973 .03931 Mdot
.36992 .76296 Mdot
.87509 .29563 Mdot
.10627 .59543 Mdot
.44251 .20603 Mdot
.84711 .73792 Mdot
.22006 .67582 Mdot
.09781 .39459 Mdot
.38398 .00201 Mdot
.11675 .59492 Mdot
.27754 .49651 Mdot
.36872 .92411 Mdot
.49354 .71868 Mdot
.38991 .75988 Mdot
.24152 .70057 Mdot
.89599 .75869 Mdot
.05492 .40255 Mdot
.4584 .42965 Mdot
.51384 .03808 Mdot
.07589 .3602 Mdot
.52189 .65883 Mdot
.65072 .17976 Mdot
.63892 .78493 Mdot
.55609 .84617 Mdot
.36232 .59978 Mdot
.71202 .66826 Mdot
.82368 .05434 Mdot
.43597 .52627 Mdot
.21787 .36346 Mdot
.2413 .40929 Mdot
.24852 .7287 Mdot
.6475 .70924 Mdot
.21852 .5571 Mdot
.70054 .91044 Mdot
.93119 .04895 Mdot
.49895 .47719 Mdot
.12682 .2101 Mdot
.45384 .38835 Mdot
.86126 .6835 Mdot
.82077 .77696 Mdot
.05039 .62868 Mdot
.86641 .73753 Mdot
.21317 .34257 Mdot
.43459 .77958 Mdot
.67583 .08548 Mdot
.55432 .47295 Mdot
.99069 .25467 Mdot
.34327 .22951 Mdot
.56149 .70342 Mdot
.4669 .2954 Mdot
.32245 .8874 Mdot
.17782 .04435 Mdot
.95071 .6936 Mdot
.83275 .76386 Mdot
.01812 .79457 Mdot
.8796 .78743 Mdot
.01538 .0767 Mdot
.91019 .98487 Mdot
.61328 .11527 Mdot
.08252 .99433 Mdot
.36156 .81669 Mdot
.02694 .50226 Mdot
.42955 .54607 Mdot
.4209 .70957 Mdot
.10041 .50654 Mdot
.20194 .49216 Mdot
.73975 .07152 Mdot
.84146 .0493 Mdot
.13689 .46039 Mdot
.43759 .59834 Mdot
.22434 .79908 Mdot
.68184 .11167 Mdot
.46302 .24798 Mdot
.20854 .23056 Mdot
.19164 .17563 Mdot
.14751 .10683 Mdot
.53242 .93315 Mdot
.72862 .0448 Mdot
.36699 .34388 Mdot
.2743 .42003 Mdot
.53124 .68887 Mdot
.5662 .05393 Mdot
.71865 .39044 Mdot
.01949 .69559 Mdot
.97181 .71497 Mdot
.39045 .72201 Mdot
.00381 .38385 Mdot
.82808 .4517 Mdot
.87497 .74051 Mdot
.76666 .59604 Mdot
.19697 .54856 Mdot
.85002 .83411 Mdot
.06234 .56047 Mdot
.8943 .20276 Mdot
.82917 .41574 Mdot
.13575 .99348 Mdot
.48394 .3013 Mdot
.16621 .80369 Mdot
.00267 .64045 Mdot
.94335 .85776 Mdot
.40398 .3006 Mdot
.82959 .8952 Mdot
.61107 .44683 Mdot
.56126 .67084 Mdot
.09299 .1266 Mdot
.89289 .89989 Mdot
.62318 .10968 Mdot
.18725 .52736 Mdot
.80863 .13174 Mdot
.52026 .03852 Mdot
.50488 .204 Mdot
.10837 .66624 Mdot
.38243 .28173 Mdot
.91575 .26293 Mdot
.39361 .29734 Mdot
.9619 .1832 Mdot
.93544 .54516 Mdot
.35381 .75332 Mdot
.53361 .12861 Mdot
.60286 .82544 Mdot
.26845 .30796 Mdot
.4113 .06501 Mdot
.34634 .69781 Mdot
.8133 .88734 Mdot
.04326 .89734 Mdot
.61178 .06814 Mdot
.2958 .03139 Mdot
.07618 .24275 Mdot
.70631 .86853 Mdot
.42276 .98518 Mdot
.8971 .17214 Mdot
.24907 .70679 Mdot
.15946 .51473 Mdot
.25042 .83347 Mdot
.51887 .41143 Mdot
.81782 .25921 Mdot
.60967 .70309 Mdot
.42254 .46496 Mdot
.13164 .17791 Mdot
.89908 .50282 Mdot
.65668 .84649 Mdot
.93048 .10609 Mdot
.47928 .12796 Mdot
.36456 .94678 Mdot
.84732 .2742 Mdot
.86557 .65183 Mdot
.95426 .57714 Mdot
.51146 .64586 Mdot
.73132 .22315 Mdot
.69436 .79104 Mdot
.03216 .65967 Mdot
.2375 .52775 Mdot
.70436 .95706 Mdot
.81932 .99558 Mdot
.82312 .23368 Mdot
.58872 .66517 Mdot
.15231 .45786 Mdot
.54165 .518 Mdot
.83642 .26526 Mdot
.47667 .40781 Mdot
.66174 .43917 Mdot
.3892 .18317 Mdot
.05861 .51923 Mdot
.65694 .04764 Mdot
.95846 .93987 Mdot
.58092 .65047 Mdot
.8149 .05469 Mdot
.30721 .50775 Mdot
.95133 .031 Mdot
.22307 .17497 Mdot
.66674 .15911 Mdot
.17393 .34146 Mdot
.4935 .17722 Mdot
.24008 .6747 Mdot
.63953 .13206 Mdot
.73004 .24147 Mdot
.46112 .73411 Mdot
.67677 .95738 Mdot
.01751 .10158 Mdot
.8107 .06702 Mdot
.47556 .59506 Mdot
.0377 .27224 Mdot
.15059 .08355 Mdot
.3957 .55778 Mdot
.286 .13635 Mdot
.76591 .58176 Mdot
.08899 .71965 Mdot
.66147 .95473 Mdot
.27182 .26232 Mdot
.47007 .57158 Mdot
.56721 .59424 Mdot
.44863 .83867 Mdot
.58047 .58267 Mdot
.48215 .7665 Mdot
.44254 .12405 Mdot
.7941 .70622 Mdot
.87712 .39778 Mdot
.10268 .5945 Mdot
.32694 .01875 Mdot
.22813 .34188 Mdot
.68694 .07794 Mdot
.14431 .28029 Mdot
.485 .93097 Mdot
.27277 .37698 Mdot
.67045 .91195 Mdot
.24817 .87272 Mdot
.46317 .13633 Mdot
.90487 .63518 Mdot
.30375 .61838 Mdot
.17566 .38171 Mdot
.60051 .83273 Mdot
.65651 .70403 Mdot
.67314 .08082 Mdot
.10321 .6246 Mdot
.78621 .59626 Mdot
.39081 .12485 Mdot
.7746 .30238 Mdot
.42964 .81711 Mdot
.51122 .39066 Mdot
.03914 .46279 Mdot
.76437 .65669 Mdot
.46018 .49333 Mdot
.01518 .32864 Mdot
.35807 .45284 Mdot
.89822 .75108 Mdot
.00408 .14367 Mdot
.8095 .62796 Mdot
.1603 .3286 Mdot
.55657 .56541 Mdot
.06856 .24855 Mdot
.10712 .37639 Mdot
.42596 .43936 Mdot
.74411 .47057 Mdot
.81717 .29276 Mdot
.45497 .46047 Mdot
.06313 .47864 Mdot
.14407 .54686 Mdot
.74858 .11529 Mdot
.2639 .30537 Mdot
.98111 .11748 Mdot
.18019 .48079 Mdot
.38533 .3029 Mdot
.33327 .59485 Mdot
.21657 .35163 Mdot
.10804 .64504 Mdot
.03229 .55025 Mdot
.03819 .31588 Mdot
.41318 .65423 Mdot
.10281 .7143 Mdot
.35821 .86804 Mdot
.47406 .70707 Mdot
.97136 .27042 Mdot
.91262 .73461 Mdot
.12352 .44172 Mdot
.18904 .8369 Mdot
.45084 .72644 Mdot
.50094 .71457 Mdot
.86282 .46962 Mdot
.18137 .9501 Mdot
.87785 .44693 Mdot
.11503 .86132 Mdot
.79427 .96949 Mdot
.26111 .74809 Mdot
.45796 .46319 Mdot
.57862 .51052 Mdot
.91924 .28066 Mdot
.16523 .0747 Mdot
.08051 .1425 Mdot
.02483 .79879 Mdot
.65749 .40536 Mdot
.69917 .35394 Mdot
.36396 .1078 Mdot
.906 .02987 Mdot
.0558 .50211 Mdot
.34852 .94407 Mdot
.04947 .90697 Mdot
.9031 .85266 Mdot
.52951 .16813 Mdot
.03229 .32997 Mdot
.96562 .45024 Mdot
.47347 .80984 Mdot
.89218 .47939 Mdot
.37318 .87813 Mdot
.14107 .96005 Mdot
.8899 .21607 Mdot
.41485 .7829 Mdot
.34149 .95854 Mdot
.92499 .35388 Mdot
.79748 .44919 Mdot
.97582 .02406 Mdot
.00019 .85296 Mdot
.26438 .99149 Mdot
.22019 .38957 Mdot
.83381 .89926 Mdot
.55877 .89185 Mdot
.25849 .48695 Mdot
.05419 .08658 Mdot
.22691 .21012 Mdot
.28022 .61572 Mdot
.75364 .26522 Mdot
.01358 .5242 Mdot
.43726 .9755 Mdot
.26487 .20468 Mdot
.56569 .26224 Mdot
.48305 .48088 Mdot
.38775 .91299 Mdot
.47977 .85216 Mdot
.66233 .71278 Mdot
.99462 .91109 Mdot
.9303 .00395 Mdot
.25813 .81583 Mdot
.85202 .03555 Mdot
.62494 .53791 Mdot
.73318 .77081 Mdot
.89911 .67528 Mdot
.92848 .79439 Mdot
.97698 .77881 Mdot
.91329 .30487 Mdot
.6468 .85432 Mdot
.97112 .08628 Mdot
.35949 .22587 Mdot
.30869 .54798 Mdot
.57655 .3125 Mdot
.18656 .83533 Mdot
.40719 .00087 Mdot
.42738 .73006 Mdot
.93225 .89505 Mdot
.25645 .56862 Mdot
.37696 .34966 Mdot
.98417 .48378 Mdot
.2778 .14884 Mdot
.53578 .03834 Mdot
.38225 .15144 Mdot
.67879 .68982 Mdot
.35563 .53832 Mdot
.23864 .38438 Mdot
.54998 .06182 Mdot
.98201 .02269 Mdot
.16194 .7388 Mdot
.15828 .21102 Mdot
.95918 .96183 Mdot
.60825 .09097 Mdot
.31291 .31159 Mdot
.40897 .87236 Mdot
.35383 .43752 Mdot
.22117 .39642 Mdot
.42503 .31882 Mdot
.31293 .72502 Mdot
.38035 .02712 Mdot
.96777 .03561 Mdot
.17541 .81405 Mdot
.1067 .41748 Mdot
.43628 .13925 Mdot
.90571 .67445 Mdot
.64509 .47069 Mdot
.74342 .56898 Mdot
.99928 .43899 Mdot
.21088 .41153 Mdot
.66399 .6938 Mdot
.32679 .51086 Mdot
.89641 .2247 Mdot
.97846 .9841 Mdot
.14366 .02334 Mdot
.19751 .06595 Mdot
.84331 .08311 Mdot
.7866 .68171 Mdot
.56971 .92133 Mdot
.69106 .95889 Mdot
.35062 .78711 Mdot
.90094 .84019 Mdot
.93061 .69833 Mdot
.96465 .98065 Mdot
.83881 .22323 Mdot
.28155 .51528 Mdot
.01916 .76418 Mdot
.4383 .27594 Mdot
.66823 .00445 Mdot
.10325 .98014 Mdot
.33724 .7523 Mdot
.15386 .53184 Mdot
.68466 .05117 Mdot
.9769 .26008 Mdot
.3043 .76322 Mdot
.44047 .75484 Mdot
.93096 .29776 Mdot
.28844 .50521 Mdot
.32316 .05771 Mdot
.32244 .83232 Mdot
.11227 .37111 Mdot
.90055 .50063 Mdot
.22107 .20423 Mdot
.45324 .51442 Mdot
.07616 .61721 Mdot
.95865 .72283 Mdot
.45576 .07729 Mdot
.13094 .54143 Mdot
.04839 .38221 Mdot
.07962 .65816 Mdot
.11441 .00092 Mdot
.15474 .52645 Mdot
.29288 .07528 Mdot
.90817 .64868 Mdot
.51637 .45585 Mdot
.99428 .79119 Mdot
.17854 .43888 Mdot
.29848 .39236 Mdot
.16691 .60988 Mdot
.87754 .19907 Mdot
.78466 .73719 Mdot
.17358 .88454 Mdot
.96508 .26459 Mdot
.47141 .11126 Mdot
.03985 .64809 Mdot
.298 .00521 Mdot
.68402 .73501 Mdot
.9672 .74293 Mdot
.13768 .27422 Mdot
.07509 .03571 Mdot
.62832 .84839 Mdot
.96945 .19911 Mdot
.43726 .69373 Mdot
.26044 .67141 Mdot
.33872 .78516 Mdot
.26893 .14169 Mdot
.73172 .77575 Mdot
.48652 .76947 Mdot
.48346 .15519 Mdot
.08463 .32865 Mdot
.55812 .70137 Mdot
.48262 .86382 Mdot
.58618 .13051 Mdot
.02431 .37407 Mdot
.26207 .88654 Mdot
.10419 .9564 Mdot
.36801 .49102 Mdot
.45337 .10467 Mdot
.31758 .39904 Mdot
.42897 .84531 Mdot
.29679 .6722 Mdot
.94037 .0411 Mdot
.05303 .68345 Mdot
.22885 .59645 Mdot
.27011 .05104 Mdot
.62949 .97591 Mdot
.38707 .67559 Mdot
.07883 .57791 Mdot
.48303 .57063 Mdot
.11456 .82043 Mdot
.81607 .55443 Mdot
.15462 .35434 Mdot
.02556 .16617 Mdot
.91312 .74823 Mdot
.25027 .16847 Mdot
.17353 .72296 Mdot
.49932 .65708 Mdot
.92868 .00111 Mdot
.72338 .60564 Mdot
.24278 .85119 Mdot
.57646 .41574 Mdot
.58799 .57106 Mdot
.07569 .29471 Mdot
.82983 .71671 Mdot
.67766 .7776 Mdot
.75113 .72331 Mdot
.51347 .29289 Mdot
.88539 .59073 Mdot
.5762 .95004 Mdot
.4881 .9508 Mdot
.52292 .14356 Mdot
.90768 .5569 Mdot
.32263 .0735 Mdot
.7061 .34081 Mdot
.82769 .16425 Mdot
.51347 .06805 Mdot
.74782 .99109 Mdot
.28085 .93944 Mdot
.69158 .48498 Mdot
.94079 .02192 Mdot
.52272 .90948 Mdot
.97623 .66378 Mdot
.7313 .31197 Mdot
.64325 .58183 Mdot
.01314 .79841 Mdot
.367 .71536 Mdot
.76093 .92342 Mdot
.31494 .09421 Mdot
.56999 .23932 Mdot
.20969 .87005 Mdot
.32733 .25335 Mdot
.80776 .50006 Mdot
.21827 .78597 Mdot
.4458 .47218 Mdot
.94297 .08013 Mdot
.58414 .17872 Mdot
.3814 .87524 Mdot
.70297 .0737 Mdot
.53665 .41689 Mdot
.86913 .12204 Mdot
.66144 .71188 Mdot
.15309 .93459 Mdot
.85624 .90578 Mdot
.62676 .15456 Mdot
.75001 .53218 Mdot
.8683 .27578 Mdot
.4626 .93222 Mdot
.70546 .67961 Mdot
.44342 .65926 Mdot
.41998 .11491 Mdot
.39313 .85791 Mdot
.13849 .33883 Mdot
.46945 .62171 Mdot
.32652 .03197 Mdot
.27501 .22114 Mdot
.066 .25886 Mdot
.01202 .41453 Mdot
.83681 .50643 Mdot
.97287 .73338 Mdot
.61 .38125 Mdot
.09364 .53469 Mdot
.8565 .78671 Mdot
.36883 .50377 Mdot
.29926 .7327 Mdot
.40364 .18702 Mdot
.21421 .4403 Mdot
.41038 .58776 Mdot
.81234 .78482 Mdot
.15755 .86196 Mdot
.23533 .91637 Mdot
.89981 .52656 Mdot
.27259 .07793 Mdot
.97505 .17306 Mdot
.08279 .71916 Mdot
.08768 .33658 Mdot
.27052 .50299 Mdot
.60619 .42208 Mdot
.55215 .60309 Mdot
.29014 .26446 Mdot
.37345 .2642 Mdot
.85742 .98786 Mdot
.60478 .9979 Mdot
.59498 .23611 Mdot
.966 .3352 Mdot
.83582 .49294 Mdot
.35858 .97802 Mdot
.16693 .41883 Mdot
.74919 .82322 Mdot
.22116 .62489 Mdot
.62092 .70558 Mdot
.01122 .94394 Mdot
.81448 .71036 Mdot
.88918 .40469 Mdot
.65994 .13418 Mdot
.99849 .76217 Mdot
.33951 .20172 Mdot
.2982 .74528 Mdot
.37917 .50288 Mdot
.56319 .92099 Mdot
.19953 .14495 Mdot
.04631 .73572 Mdot
.35908 .88528 Mdot
.4023 .22637 Mdot
.95235 .61048 Mdot
.88341 .55872 Mdot
.40476 .90595 Mdot
.58176 .2707 Mdot
.8428 .01369 Mdot
.46949 .05013 Mdot
.50454 .88976 Mdot
.27969 .58662 Mdot
.84245 .04365 Mdot
.97658 .40484 Mdot
.98236 .49912 Mdot
.97779 .4816 Mdot
.49604 .29185 Mdot
.64755 .24742 Mdot
.71108 .13716 Mdot
.62391 .25403 Mdot
.33515 .87244 Mdot
.38776 .79268 Mdot
.16797 .23221 Mdot
.55917 .78284 Mdot
.07413 .88032 Mdot
.17638 .96784 Mdot
.59125 .83046 Mdot
.49857 .99595 Mdot
.22296 .81996 Mdot
.37647 .15312 Mdot
.24963 .13892 Mdot
.42012 .13241 Mdot
.29994 .94011 Mdot
.75097 .657 Mdot
.82527 .09712 Mdot
.72058 .55522 Mdot
.99332 .66045 Mdot
.17771 .77595 Mdot
.19219 .08973 Mdot
.33783 .65716 Mdot
.25732 .84667 Mdot
.99427 .83091 Mdot
.4812 .89977 Mdot
.97528 .20316 Mdot
.6027 .57299 Mdot
.78733 .2401 Mdot
.53138 .94028 Mdot
.33516 .36093 Mdot
.75386 .969 Mdot
.56634 .8459 Mdot
.25734 .15702 Mdot
.99201 .70754 Mdot
.4021 .87664 Mdot
.31533 .37078 Mdot
.46293 .51102 Mdot
.00079 .62587 Mdot
.19108 .46838 Mdot
.61393 .93155 Mdot
.41983 .90207 Mdot
.95124 .07915 Mdot
.2026 .3036 Mdot
.04358 .91784 Mdot
.37274 .51047 Mdot
.49762 .71041 Mdot
.71249 .02362 Mdot
.84128 .63463 Mdot
.67877 .06561 Mdot
.27405 .83569 Mdot
.03129 .34811 Mdot
.93197 .16528 Mdot
.87954 .1177 Mdot
.62154 .6477 Mdot
.21517 .15728 Mdot
.16616 .27514 Mdot
.06331 .96893 Mdot
.15986 .21385 Mdot
.98202 .5131 Mdot
.96731 .75957 Mdot
.90407 .84235 Mdot
.183 .76017 Mdot
.58516 .96135 Mdot
.53733 .88057 Mdot
.83902 .3331 Mdot
.69431 .67722 Mdot
.16899 .66684 Mdot
.66094 .89891 Mdot
.52269 .1377 Mdot
.14943 .22672 Mdot
.97912 .1882 Mdot
.89765 .68271 Mdot
.68175 .93732 Mdot
.43416 .71582 Mdot
.82548 .80284 Mdot
.21394 .1739 Mdot
.17463 .8005 Mdot
.17229 .33347 Mdot
.60728 .73633 Mdot
.06454 .76478 Mdot
.41329 .99408 Mdot
.94253 .277 Mdot
.10553 .37522 Mdot
.50975 .90259 Mdot
.97154 .76729 Mdot
.96097 .71832 Mdot
.82029 .45015 Mdot
.36321 .07931 Mdot
.27261 .04826 Mdot
.87668 .43912 Mdot
.28853 .9115 Mdot
.33275 .9614 Mdot
.06343 .51536 Mdot
.79537 .42557 Mdot
.49201 .70369 Mdot
.57168 .83454 Mdot
.08091 .70041 Mdot
.05233 .64713 Mdot
.90754 .82107 Mdot
.21243 .17107 Mdot
.07884 .2884 Mdot
.09519 .35585 Mdot
.48917 .65966 Mdot
.16337 .94402 Mdot
.87715 .75662 Mdot
.768 .01419 Mdot
.6902 .61789 Mdot
.61005 .49356 Mdot
.96386 .47501 Mdot
.04771 .2149 Mdot
.86826 .16827 Mdot
.34883 .72882 Mdot
.30383 .72775 Mdot
.81628 .78676 Mdot
.54208 .66476 Mdot
.34832 .53016 Mdot
.25353 .16611 Mdot
.03639 .84444 Mdot
.10358 .2881 Mdot
.00298 .92249 Mdot
.26691 .15582 Mdot
.24098 .95109 Mdot
.74077 .47218 Mdot
.55951 .9221 Mdot
.24892 .07957 Mdot
.97476 .47436 Mdot
.06731 .29925 Mdot
.93972 .84607 Mdot
.47114 .63533 Mdot
.54368 .44349 Mdot
.97532 .82904 Mdot
.80917 .20386 Mdot
.21425 .15715 Mdot
.27202 .67273 Mdot
.68711 .22068 Mdot
.24424 .43628 Mdot
.21382 .47279 Mdot
.91601 .04997 Mdot
.5879 .89615 Mdot
.20391 .74311 Mdot
.36918 .00867 Mdot
.49209 .87494 Mdot
.86923 .58774 Mdot
.02306 .33121 Mdot
.10173 .0859 Mdot
.43225 .23961 Mdot
.86387 .25677 Mdot
.35604 .64852 Mdot
.30673 .07791 Mdot
.22854 .76538 Mdot
.19762 .69329 Mdot
.4964 .54883 Mdot
.34973 .40726 Mdot
.66823 .17424 Mdot
.91041 .10843 Mdot
.31668 .47267 Mdot
.99291 .41459 Mdot
.3977 .53693 Mdot
.86871 .64672 Mdot
.40615 .47901 Mdot
.14288 .78284 Mdot
.55972 .02714 Mdot
.26022 .72823 Mdot
.87444 .20037 Mdot
.62215 .81029 Mdot
.43188 .54547 Mdot
.08671 .27676 Mdot
.81452 .67801 Mdot
.70571 .17854 Mdot
.07298 .63151 Mdot
.56996 .26978 Mdot
.16688 .4033 Mdot
.94774 .01057 Mdot
.90534 .7079 Mdot
.02624 .94127 Mdot
.58622 .01296 Mdot
.98784 .42024 Mdot
.6986 .29107 Mdot
.41169 .79284 Mdot
.24803 .09437 Mdot
.12091 .95871 Mdot
.92621 .30508 Mdot
.35005 .18975 Mdot
.19077 .10651 Mdot
.67723 .82877 Mdot
.71831 .01988 Mdot
.25111 .67034 Mdot
.52324 .2097 Mdot
.57177 .56792 Mdot
.26098 .53138 Mdot
.89128 .35279 Mdot
.61778 .72853 Mdot
.24624 .83144 Mdot
.43741 .98 Mdot
.57214 .08576 Mdot
.7366 .32043 Mdot
.99912 .97121 Mdot
.43256 .94201 Mdot
.3334 .90465 Mdot
.22763 .24491 Mdot
.99484 .92409 Mdot
.09052 .55808 Mdot
.56963 .09473 Mdot
.92137 .04597 Mdot
.81131 .76983 Mdot
.06504 .37333 Mdot
.64487 .07202 Mdot
.98365 .71912 Mdot
.20145 .68639 Mdot
.13729 .2514 Mdot
.3207 .23278 Mdot
.47545 .20498 Mdot
.7431 .91634 Mdot
.83893 .26288 Mdot
.74269 .22186 Mdot
.24656 .65758 Mdot
.12753 .88945 Mdot
.7559 .7067 Mdot
.96694 .14206 Mdot
.38992 .62139 Mdot
.39143 .87322 Mdot
.57881 .09972 Mdot
.38895 .15646 Mdot
.83588 .14147 Mdot
.29214 .73238 Mdot
.65263 .65019 Mdot
.41165 .07975 Mdot
.67813 .41667 Mdot
.37506 .80675 Mdot
.39456 .05044 Mdot
.14306 .9597 Mdot
.56433 .91744 Mdot
.20314 .52434 Mdot
.33349 .44276 Mdot
.2407 .00391 Mdot
.20472 .67374 Mdot
.75186 .77819 Mdot
.37372 .57438 Mdot
.86529 .29054 Mdot
.07533 .83741 Mdot
.91818 .24921 Mdot
.26826 .24917 Mdot
.27765 .56121 Mdot
.92808 .83702 Mdot
.37169 .46023 Mdot
.28235 .90824 Mdot
.80467 .05112 Mdot
.47784 .6671 Mdot
.53153 .85689 Mdot
.54543 .5192 Mdot
.03742 .99489 Mdot
.22887 .22905 Mdot
.798 .39549 Mdot
.38298 .59012 Mdot
.97158 .44049 Mdot
.65847 .08402 Mdot
.79381 .36979 Mdot
.08547 .84304 Mdot
.6212 .84806 Mdot
.12574 .45653 Mdot
.85224 .45229 Mdot
.97856 .54847 Mdot
.23177 .06596 Mdot
.21178 .8243 Mdot
.17644 .98453 Mdot
.27536 .78993 Mdot
.77808 .29602 Mdot
.14644 .29395 Mdot
.36131 .29122 Mdot
.38674 .04926 Mdot
.98545 .96992 Mdot
.88961 .75132 Mdot
.61364 .02567 Mdot
.32335 .12699 Mdot
.00556 .33996 Mdot
.14111 .92044 Mdot
.228 .84642 Mdot
.35425 .54613 Mdot
.10334 .22212 Mdot
.81064 .7931 Mdot
.30969 .22935 Mdot
.91284 .66321 Mdot
.74498 .60308 Mdot
.69954 .09833 Mdot
.7435 .93416 Mdot
.68303 .27265 Mdot
.17395 .85673 Mdot
.97104 .86706 Mdot
.27179 .75049 Mdot
.17323 .90918 Mdot
.84357 .28249 Mdot
.9961 .57612 Mdot
.02617 .50961 Mdot
.7538 .36141 Mdot
.71001 .48027 Mdot
.77783 .05441 Mdot
.45255 .19171 Mdot
.38374 .08074 Mdot
.02328 .69622 Mdot
.03256 .49912 Mdot
.79705 .51761 Mdot
.40126 .936 Mdot
.56154 .71408 Mdot
.05485 .08609 Mdot
.13747 .74515 Mdot
.94933 .06441 Mdot
.87926 .76882 Mdot
.92051 .57249 Mdot
.15489 .87693 Mdot
.06243 .85768 Mdot
.88892 .84693 Mdot
.55481 .95879 Mdot
.09864 .75128 Mdot
.41096 .70473 Mdot
.03418 .34062 Mdot
.84387 .96573 Mdot
.26708 .80917 Mdot
.23166 .54948 Mdot
.94078 .88878 Mdot
.92197 .47719 Mdot
.41824 .28324 Mdot
.59813 .05472 Mdot
.20487 .05805 Mdot
.36719 .67336 Mdot
.26415 .85711 Mdot
.30963 .36926 Mdot
.65832 .78223 Mdot
.18281 .96508 Mdot
.05595 .36108 Mdot
.39335 .9242 Mdot
.58576 .13283 Mdot
.8265 .94443 Mdot
.92797 .19367 Mdot
.96562 .44563 Mdot
.27125 .90433 Mdot
.00012 .20783 Mdot
.46997 .66491 Mdot
.13911 .17506 Mdot
.08875 .22008 Mdot
.46883 .70685 Mdot
.75995 .5978 Mdot
.83894 .20101 Mdot
.81784 .65541 Mdot
.38641 .8971 Mdot
.3671 .91424 Mdot
.0019 .10308 Mdot
.4194 .83285 Mdot
.38637 .0787 Mdot
.45277 .75064 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool01?l0003oooooooooooooool2o`0000[ooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`09ooooo`;o00000_ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool02?ooool2o`0000Cooooo0ol0000=oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool2o`0000Wooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`06ooooo`;o00001Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00;ooooo000Nooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool02Oooool2o`0000;ooooo00?o0000ooooooooool03?ooool2o`0000oooooo00?o0000oooooooo
ool02?ooool2o`0000Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00;ooooo0_l00009ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00Co0000ooooool0
003o00001Oooool2o`0000Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02oooo
o`007_ooool00ol0003oooooooooo`1Mooooo`;o00005Oooool2o`00063ooooo0_l0001;ooooo`;o
00002oooool2o`0001Gooooo000Nooooo`03o`000?oooooooooo07Cooooo0_l0000kooooo`;o0000
1oooool2o`0001[ooooo0_l0000fooooo`;o00008?ooool2o`0001Gooooo000Nooooo`03o`000?oo
oooooooo0;7ooooo0_l00007ooooo`;o0000>_ooool2o`0001Kooooo0_l0000gooooo`007_ooool0
0ol0003oooooooooo`1Vooooo`;o0000OOooool2o`0000oooooo0_l0000<ooooo`;o0000@Oooool0
01kooooo00?o0000ooooooooool0I_ooool2o`0007gooooo0_l0000Mooooo`;o0000:?ooool2o`00
00_ooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0[ooooo`;o0000U_ooool2o`0001oo
oooo0_l00018ooooo`;o00002Oooool4o`0000[ooooo000Nooooo`03o`000?oooooooooo02_ooooo
0_l0001;ooooo`;o0000>?ooool2o`0000oooooo0_l0000Oooooo`;o0000:Oooool2o`0002Sooooo
0_l0000<ooooo`007_ooool00ol0003oooooooooo`1Looooo`;o00002?ooool2o`00013ooooo0_l0
000hooooo`;o0000Foooool2o`00017ooooo0_l0000=ooooo`;o00005?ooool001kooooo00?o0000
ooooooooool0G?ooool2o`0000Sooooo0_l0002jooooo`;o00003Oooool2o`0001Cooooo000Noooo
o`03o`000?oooooooooo01Cooooo0_l0002=ooooo`;o00001Oooool2o`0006Gooooo0_l0000Toooo
o`;o00003_ooool001kooooo00?o0000ooooooooool05?ooool2o`0005_ooooo0_l0000`ooooo`Co
00000oooool2o`0006Gooooo0_l0000Kooooo`;o00001oooool2o`0000kooooo000Nooooo`03o`00
0?oooooooooo03Kooooo0_l0000iooooo`;o0000<_ooool2o`0006Oooooo0_l00005ooooo`;o0000
5oooool2o`0001Oooooo000Nooooo`03o`000?oooooooooo03Kooooo0_l0002aooooo`;o00008ooo
ool2o`0000Gooooo0_l0000@ooooo`;o00007_ooool001kooooo00?o0000ooooooooool0EOooool2
o`0002?ooooo1?l0000Gooooo`;o0000>_ooool2o`0001Kooooo0_l0000Rooooo`;o00005oooool3
o`0000;ooooo0_l0000Jooooo`007_ooool2o`0005Gooooo0ol0000Sooooo`Co00005oooool2o`00
03[ooooo0_l00007ooooo`;o00009Oooool2o`0000[ooooo0_l0000Gooooo`;o00000oooool2o`00
01[ooooo000Nooooo`03o`000?oooooooooo05Cooooo0_l0000Iooooo`;o00000_ooool2o`0003oo
oooo0_l00008ooooo`;o00006_ooool2o`0001gooooo0_l00006ooooo`;o00000_ooool2o`000003
ooooool0003o000003gooooo000Nooooo`03o`000?oooooooooo03kooooo0_l0000Uooooo`;o0000
2?ooool2o`0000;ooooo0_l0000oooooo`;o00002?ooool2o`0003Wooooo0_l0000:ooooo`;o0000
00?oooooo`000?l00000?Oooool001kooooo00?o0000ooooooooool0?_ooool2o`0002Gooooo0_l0
0018ooooo`;o0000U_ooool001kooooo00?o0000ooooooooool0??ooool2o`0000Wooooo0_l0000i
ooooo`;o0000:oooool2o`0002Sooooo0_l0001Fooooo`;o00005?ooool001kooooo00?o0000oooo
ooooool0??ooool2o`0000Wooooo0_l0000iooooo`;o00007oooool2o`0001kooooo0_l0000Doooo
o`;o0000:?ooool2o`0002cooooo0_l0000Dooooo`007_ooool00ol0003oooooooooo`2Sooooo`;o
00007_ooool2o`0000Wooooo0_l0000Looooo`;o00005Oooool2o`0004;ooooo000Nooooo`03o`00
0?oooooooooo03;ooooo0_l0000aooooo`;o0000Ioooool2o`00013ooooo0_l0000:ooooo`;o0000
FOooool001kooooo00Co0000oooooooooooooooo0_l0000_ooooo`;o00008Oooool2o`0000Cooooo
0_l00003ooooo`;o00000oooool2o`0002Wooooo0_l00019ooooo`;o00000oooool2o`0006Gooooo
000Nooooo`04o`000?ooooooooooooooo`;o0000B_ooool2o`0000Kooooo0_l00004ooooo`;o0000
0oooool2o`00013ooooo0_l00005ooooo`;o00001oooool2o`0000cooooo0_l00015ooooo`Ko0000
DOooool2o`000003ooooool0003o000001Cooooo000Nooooo`03o`000?oooooooooo02gooooo0_l0
000Nooooo`;o00008oooool2o`0000Gooooo0_l00007ooooo`;o0000C_ooool2o`0000?ooooo1?l0
000cooooo`;o00007_ooool2o`000003ooooool0003o000001Cooooo000Nooooo`03o`000?oooooo
oooo00gooooo0ol0000=ooooo`;o00003_ooool2o`0008Oooooo0_l0000Jooooo`;o00001?ooool2
o`0003Cooooo0_l0000Xooooo`;o00003Oooool001kooooo00?o0000ooooooooool03Oooool3o`00
00gooooo0_l0000Kooooo`;o00005_ooool2o`0006;ooooo0_l0000Pooooo`;o0000G_ooool2o`00
00gooooo000Nooooo`03o`000?oooooooooo03[ooooo0_l0000Fooooo`;o0000K_ooool2o`0008?o
oooo000Nooooo`03o`000?oooooooooo04gooooo0_l0000Cooooo`;o0000DOooool2o`0000_ooooo
0_l00023ooooo`007_ooool00ol0003oooooooooo`1=ooooo`;o00004oooool2o`00057ooooo0_l0
00000ooooooo0000o`00000Uooooo`;o00009oooool2o`0003gooooo000Nooooo`;o00000oooool2
o`000;Cooooo0_l0000Uooooo`;o00009oooool2o`0003gooooo000Mooooo`;o00001?ooool2o`00
08_ooooo0_l0000Wooooo`;o0000SOooool001gooooo0_l0000Iooooo`;o00004oooool2o`0000co
oooo0_l0000fooooo`;o00006oooool2o`0002Oooooo0_l0001Zooooo`;o00001?ooool2o`0001_o
oooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0000Cooooo`;o00003?ooool2o`0003Kooooo
0_l0000Qooooo`;o0000;oooool2o`0001;ooooo0_l00018ooooo`;o00001?ooool2o`0001_ooooo
000Nooooo`03o`000?oooooooooo08Cooooo0_l0000?ooooo`;o0000;oooool2o`0001;ooooo0_l0
0019ooooo`;o00008?ooool001kooooo00?o0000ooooooooool0Q?ooool2o`0003gooooo0_l0000Z
ooooo`;o0000:Oooool2o`0000Wooooo0_l0000Dooooo`;o00002_ooool001kooooo00?o0000oooo
ooooool0C?ooool2o`0007Gooooo0_l0000Zooooo`;o0000:Oooool2o`0001oooooo0_l0000:oooo
o`007_ooool00ol0003oooooooooo`1<ooooo`;o0000?_ooool2o`0008Sooooo0_l0000Oooooo`;o
00003_ooool001kooooo00?o0000ooooooooool06_ooool2o`0004Wooooo0_l0000Dooooo`;o0000
3oooool2o`0008Sooooo0_l0000Oooooo`;o00003_ooool001kooooo00?o0000ooooooooool06_oo
ool2o`0004Wooooo0_l0000Dooooo`;o00006oooool2o`0000oooooo0_l0000?ooooo`;o0000Rooo
ool001kooooo00?o0000ooooooooool0Q?ooool2o`0001;ooooo0_l0000?ooooo`;o00003oooool2
o`00013ooooo0_l0000eooooo`;o0000@_ooool001kooooo00?o0000ooooooooool0FOooool2o`00
02Wooooo0_l0000<ooooo`;o00009_ooool2o`00013ooooo0_l00004ooooo`;o0000;oooool2o`00
04;ooooo000Nooooo`03o`000?oooooooooo04gooooo0_l0000:ooooo`;o0000;oooool2o`0000Ko
oooo0_l0000Booooo`;o0000:_ooool2o`0000oooooo0_l0001Rooooo`007_ooool00ol0003ooooo
ooooo`0Fooooo`;o0000=Oooool2o`0000Cooooo0_l0000eooooo`;o00006_ooool2o`0003_ooooo
0_l0000Wooooo`;o0000:?ooool2o`0000Gooooo0_l00008ooooo`007_ooool2o`0001Oooooo0_l0
000Uooooo`;o00005?ooool2o`00057ooooo0_l0001Tooooo`;o0000:?ooool2o`0000Gooooo0_l0
0008ooooo`007_ooool2o`0003kooooo0_l0000Gooooo`;o0000C_ooool2o`0009oooooo000Noooo
o`;o0000Eoooool2o`00023ooooo0_l0003=ooooo`007_ooool00ol0003oooooooooo`1fooooo`Co
00007oooool2o`0002gooooo0_l0001mooooo`007_ooool00ol0003oooooooooo`12ooooo`;o0000
3?ooool2o`000003ooooool0003o0000027ooooo0_l00002ooooo`;o00007Oooool2o`0002gooooo
0_l0001mooooo`007_ooool00ol0003oooooooooo`12ooooo`;o00003?ooool2o`000003ooooool0
003o000002Gooooo0_l0001Iooooo`;o0000L?ooool001kooooo00?o0000ooooooooool0eOooool2
o`0003;ooooo0_l0000looooo`007_ooool00ol0003oooooooooo`04ooooo`;o0000B?ooool2o`00
0;Wooooo0_l0000Pooooo`;o00006_ooool001kooooo00?o0000ooooooooool01?ooool2o`0004Oo
oooo0ol0001Hooooo`;o0000K?ooool2o`0001?ooooo0_l0000Jooooo`007_ooool00ol0003ooooo
ooooo`11ooooo`;o00002_ooool2o`0005Wooooo0_l0001/ooooo`;o00002?ooool2o`0001Oooooo
0_l0000<ooooo`007_ooool2o`0002[ooooo0_l0000?ooooo`;o00001Oooool2o`000003ooooool0
003o000008oooooo0_l00019ooooo`;o00005oooool2o`0000cooooo000Nooooo`;o0000:?ooool4
o`0000oooooo0_l00005ooooo`;o000000?oooooo`000?l00000E_ooool2o`0001cooooo0_l0000C
ooooo`;o00001?ooool2o`0000[ooooo0_l0001Tooooo`007_ooool00ol0003oooooooooo`0Woooo
o`;o0000Loooool2o`0001cooooo0_l0000Cooooo`;o00004?ooool2o`0006Cooooo000Nooooo`03
o`000?oooooooooo07[ooooo0_l0002iooooo`;o00004?ooool001kooooo00?o0000ooooooooool0
4Oooool2o`0006Oooooo0_l00003ooooo`;o0000]?ooool2o`0000?ooooo0_l0000;ooooo`007_oo
ool00ol0003oooooooooo`0Aooooo`;o0000Foooool2o`0000oooooo0_l0000>ooooo`;o0000ZOoo
ool2o`0000_ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0
0006ooooo`03o`000?oooooooooo06kooooo0_l0000Oooooo`;o0000VOooool2o`0001_ooooo0003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A006ooooo`03o`000?oooooooooo0?oooooo:oooool2o`0001_ooooo0003ooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`?o0000ooooool>ooooo`;o0000
2Oooool3o`0001cooooo0_l0000>ooooo`000oooool01Ol0003ooooooooooooooooo000000gooooo
00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`14ooooo`;o00009?ooool2o`0003Cooooo
0_l0001Qooooo`;o00002?ooool2o`0000Wooooo0ol00004ooooo`;o00005_ooool4o`0000cooooo
0003ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`00
0?oooooooooo04Cooooo0_l0000<ooooo`;o00005_ooool2o`00023ooooo0_l00008ooooo`;o0000
2?ooool2o`00067ooooo0_l0000Jooooo`;o00006?ooool2o`0000cooooo0003ooooo`05oa0@4?oo
ooooooooooooool@41003oooool00ol0003oooooooooo`03ooooo`;o00009oooool2o`0001oooooo
0_l0000:ooooo`;o0000>?ooool2o`0000Sooooo0_l0000>ooooo`;o0000Woooool000?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001Oooool2o`0002Oo
oooo0_l00008ooooo`;o00005Oooool2o`0005kooooo0_l0002Oooooo`000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo
00_ooooo0_l0000Rooooo`?o0000joooool2o`0002Sooooo000Nooooo`03o`000?oooooooooo00_o
oooo0_l0000Sooooo`;o0000joooool2o`0002Sooooo000Nooooo`03o`000?oooooooooo01Wooooo
0_l00002ooooo`;o0000=_ooool2o`0008Cooooo0_l0000@ooooo`;o0000F?ooool001kooooo00?o
0000ooooooooool06Oooool2o`0000;ooooo0_l0000fooooo`;o00006_ooool2o`0006Sooooo0_l0
000=ooooo`;o000000?oooooo`000?l000007_ooool2o`00013ooooo0_l0000Vooooo`007_ooool0
0ol0003oooooooooo`0/ooooo`;o0000@oooool2o`0000cooooo0_l0001Yooooo`;o00008Oooool2
o`00013ooooo0_l0000Vooooo`007_ooool00ol0003oooooooooo`0/ooooo`;o00004_ooool2o`00
00Cooooo0_l0000Iooooo`;o00002?ooool2o`0001;ooooo0_l00036ooooo`007_ooool00ol0003o
ooooooooo`0booooo`;o00003?ooool2o`0000Cooooo0_l0000Iooooo`;o000000?oooooo`000?l0
00001Oooool2o`0009[ooooo0_l0000nooooo`007_ooool00ol0003oooooooooo`0booooo`;o0000
<?ooool2o`0005Oooooo0_l00018ooooo`;o0000?_ooool001kooooo00?o0000ooooooooool0R?oo
ool2o`0002_ooooo0_l00006ooooo`;o0000?Oooool2o`0004Wooooo000Nooooo`03o`000?oooooo
oooo01Gooooo0_l0001aooooo`;o0000:oooool2o`0003;ooooo0_l0000Aooooo`;o0000BOooool0
01kooooo00?o0000ooooooooool05Oooool2o`0002oooooo0_l00026ooooo`;o00006Oooool2o`00
05cooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0000booooo`;o00002oooool2o`0001Go
oooo0_l0000Vooooo`;o0000>_ooool2o`0004gooooo0_l00007ooooo`;o00007oooool001kooooo
0_l0000Cooooo`;o00005Oooool2o`0002Sooooo0_l0000Aooooo`;o00000_ooool2o`0002Kooooo
0_l00029ooooo`;o00001oooool2o`0001oooooo000Nooooo`03o`000?oooooooooo02Wooooo0_l0
000kooooo`;o0000Goooool2o`0006?ooooo0_l0000@ooooo`;o00001oooool001kooooo00?o0000
ooooooooool04Oooool2o`000;Cooooo0_l0000mooooo`;o00003Oooool2o`0001Gooooo0_l0000@
ooooo`;o00001oooool001kooooo00?o0000ooooooooool04Oooool2o`00047ooooo0_l0001Noooo
o`;o0000D?ooool2o`0000gooooo0_l0000Rooooo`;o00003?ooool001kooooo00?o0000oooooooo
ool0E?ooool2o`0000Cooooo0_l0000Iooooo`;o0000?Oooool2o`0003_ooooo0_l0000Iooooo`?o
00005oooool2o`0000kooooo0_l000000ooooooo0000o`00000<ooooo`007_ooool00ol0003ooooo
ooooo`1Jooooo`;o00006Oooool2o`0007[ooooo0_l0000Iooooo`?o00005oooool2o`0000kooooo
0_l0000?ooooo`007_ooool00ol0003oooooooooo`2eooooo`;o00000_ooool2o`0007gooooo0_l0
000=ooooo`007_ooool00ol0003oooooooooo`08ooooo`;o00007oooool2o`0000Oooooo0_l00021
ooooo`;o00000_ooool2o`0001oooooo0_l0000cooooo`;o00009oooool2o`0000gooooo000Noooo
o`03o`000?oooooooooo00Sooooo0_l0000>ooooo`;o00003oooool2o`0000Oooooo0_l0001Foooo
o`;o0000C_ooool2o`0003?ooooo0_l00005ooooo`;o00005_ooool2o`0001Oooooo000Nooooo`03
o`000?oooooooooo01Sooooo0_l0000Aooooo`;o0000GOooool2o`0008[ooooo0_l0000?ooooo`;o
00001Oooool2o`0001Oooooo000Nooooo`03o`000?oooooooooo02_ooooo0_l0001;ooooo`;o0000
2_ooool2o`0008Sooooo0_l0000Gooooo`;o00007_ooool001kooooo00?o0000ooooooooool0N?oo
ool2o`0000[ooooo0_l00028ooooo`;o0000=oooool001kooooo00?o0000ooooooooool05_ooool2
o`0000Kooooo0_l0003eooooo`;o0000<?ooool001kooooo00?o0000ooooooooool05_ooool2o`00
00Kooooo0_l0001Aooooo`;o0000:_ooool2o`0000Cooooo0_l0000jooooo`;o00009Oooool2o`00
00gooooo0_l0000`ooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o00005Oooool2o`0003co
oooo0_l00006ooooo`;o00008Oooool2o`0000Oooooo0_l00004ooooo`;o0000>_ooool2o`0001So
oooo0_l0000;ooooo`;o00004?ooool2o`0002gooooo000Nooooo`03o`000?oooooooooo01;ooooo
1?l0000Eooooo`;o0000??ooool2o`00017ooooo0_l0000Fooooo`;o0000Hoooool2o`0001gooooo
0_l0000Aooooo`;o00006_ooool001kooooo0_l0000Cooooo`;o0000J?ooool2o`000003ooooool0
003o000001Sooooo0_l0001Mooooo`;o0000<Oooool2o`0001[ooooo000Nooooo`03o`000?oooooo
oooo03kooooo0_l0000Booooo`;o00009Oooool2o`0000Cooooo0_l0000Hooooo`;o0000GOooool2
o`0002_ooooo0_l00002ooooo`;o00007?ooool001kooooo00?o0000ooooooooool0?_ooool2o`00
01;ooooo0ol0000Tooooo`;o0000Z_ooool2o`0000;ooooo0_l0000Looooo`007_ooool00ol0003o
ooooooooo`1Cooooo`;o00003Oooool2o`0008Kooooo0_l0001Kooooo`007_ooool00ol0003ooooo
ooooo`1Rooooo`;o0000Doooool2o`00037ooooo0_l0001Kooooo`007_ooool00ol0003ooooooooo
o`08ooooo`;o0000[Oooool2o`0008kooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0001l
ooooo`;o0000Hoooool2o`0005[ooooo000Nooooo`03o`000?oooooooooo08Kooooo0_l0001Soooo
o`;o0000F_ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool01?l0003ooooo
ooooooooool2o`0000?ooooo0_l0000?ooooo`;o00005oooool2o`0005[ooooo0_l0002iooooo`00
7_ooool01?l0003oooooooooooooool4o`000003ooooool0003o000000oooooo0_l0000Gooooo`;o
00000_ooool2o`0005Kooooo0_l0001oooooo`;o0000>?ooool001kooooo00?o0000ooooooooool0
0oooool2o`0001?ooooo0_l0000Jooooo`;o0000QOooool2o`00053ooooo0_l0000Wooooo`;o0000
3oooool001kooooo00?o0000ooooooooool06?ooool2o`0000oooooo0_l0002@ooooo`;o0000NOoo
ool2o`0000oooooo000Nooooo`?o00001oooool2o`00023ooooo0_l00009ooooo`;o00002oooool2
o`0000?ooooo0_l0002Iooooo`;o0000I?ooool001kooooo0ol00007ooooo`;o0000:oooool2o`00
00_ooooo0_l00003ooooo`;o0000:oooool2o`0006cooooo0_l0001Tooooo`007_ooool00ol0003o
ooooooooo`06ooooo`;o0000Joooool2o`000=;ooooo000Nooooo`;o00001oooool2o`0003[ooooo
0_l0000booooo`;o0000coooool001kooooo00?o0000ooooooooool0;_ooool2o`0001;ooooo0_l0
000booooo`;o0000Ioooool2o`0003gooooo0_l00009ooooo`;o00007?ooool001kooooo00?o0000
ooooooooool04?ooool2o`0000Wooooo0_l0000Aooooo`;o0000[oooool2o`0003gooooo0_l00009
ooooo`;o00007?ooool001kooooo00?o0000ooooooooool03_ooool4o`0000?ooooo0_l00004oooo
o`;o0000C?ooool2o`000=cooooo000Nooooo`03o`000?oooooooooo00kooooo0_l00005ooooo`;o
0000;?ooool2o`0002Cooooo0_l00026ooooo`;o0000E?ooool001kooooo00?o0000ooooooooool0
@oooool2o`000:cooooo0_l0001Dooooo`007_ooool00ol0003oooooooooo`1Qooooo`;o0000Vooo
ool2o`0004Oooooo000Nooooo`03o`000?oooooooooo017ooooo0_l0000=ooooo`;o0000?oooool3
o`0009[ooooo0_l00017ooooo`007_ooool00ol0003oooooooooo`04ooooo`;o00002oooool2o`00
00_ooooo1?l0000Vooooo`;o00006?ooool2o`000>?ooooo000Nooooo`03o`000?oooooooooo00Co
oooo0_l0000Hooooo`?o00009oooool2o`0000_ooooo0_l0003`ooooo`007_ooool00ol0003ooooo
ooooo`0<ooooo`;o00009oooool2o`0001kooooo0_l0001[ooooo`;o0000Poooool001kooooo0_l0
000=ooooo`;o00009oooool2o`0001;ooooo0_l0001gooooo`;o0000Poooool001kooooo0_l0000E
ooooo`;o0000<oooool2o`0004Cooooo0_l0002fooooo`007_ooool00ol0003oooooooooo`0Doooo
o`;o0000;Oooool2o`0004[ooooo0_l0000Aooooo`;o0000@_ooool2o`0005oooooo0003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04oooo
o`03o`000?oooooooooo01cooooo0_l0000Uooooo`;o00006?ooool2o`0004?ooooo0_l00012oooo
o`;o0000Goooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo01cooooo0_l0000Vooooo`;o00005oooool2o`00
0:3ooooo0_l0000Hooooo`;o0000;?ooool000?ooooo00Go410@oooooooooooooooooa0@400;oooo
o`Go00001_ooool3o`0001Cooooo0_l0000^ooooo`;o00007Oooool2o`0009[ooooo0_l0000Hoooo
o`;o0000;?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgooooo
o`0000Oooooo00?o0000ooooooooool03_ooool2o`0000Cooooo0_l0000Looooo`;o0000;oooool2
o`000>;ooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0
0007ooooo`03o`000?oooooooooo00kooooo0_l0000Rooooo`;o0000>_ooool2o`0006;ooooo0_l0
000Hooooo`;o0000;oooool2o`0001[ooooo0_l0000<ooooo`000oooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`1:ooooo`;o00008_oo
ool2o`0002Oooooo0_l0000iooooo`;o00006?ooool2o`0002oooooo0_l0000Jooooo`;o00003?oo
ool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o
0000ooooooooool0@?ooool2o`0000Sooooo0_l0001;ooooo`;o00003?ooool2o`000:3ooooo0003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oo
oooooooo00;o0000?_ooool2o`0006?ooooo0_l0000@ooooo`;o0000D?ooool2o`0003Cooooo0_l0
0006ooooo`007_ooool00ol0003oooooooooo`02o`0001gooooo0_l0000Aooooo`;o0000M_ooool2
o`0000_ooooo0_l0000Oooooo`;o0000;oooool2o`0003Cooooo0_l00006ooooo`007_ooool00ol0
003oooooooooo`0Oooooo`;o00004Oooool2o`00027ooooo0_l0001Cooooo`;o00005Oooool2o`00
01Gooooo0_l0001Sooooo`;o00002?ooool001kooooo00?o0000ooooooooool0EOooool2o`0006[o
oooo0_l0000kooooo`;o0000?Oooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo0?;ooooo
0_l0000:ooooo`;o0000Aoooool001kooooo00?o0000ooooooooool0TOooool2o`0005oooooo0_l0
001Cooooo`007_ooool00ol0003oooooooooo`2Aooooo`;o0000]?ooool001kooooo00?o0000oooo
ooooool0Boooool2o`0002;ooooo0_l0003Fooooo`007_ooool00ol0003oooooooooo`0fooooo`;o
00002_ooool2o`0000Oooooo0_l0000Rooooo`;o00005Oooool2o`0004_ooooo0_l00014ooooo`;o
00007Oooool2o`0000Oooooo0_l00004ooooo`007_ooool00ol0003oooooooooo`0Tooooo`;o0000
4?ooool2o`0000[ooooo0_l0000Tooooo`;o00007?ooool2o`0000;ooooo0_l0000Qooooo`;o0000
9?ooool2o`0004Cooooo0_l0000Mooooo`;o00001oooool2o`0000Cooooo000Nooooo`03o`000?oo
oooooooo02Cooooo0_l00012ooooo`;o00008?ooool2o`00027ooooo0_l0000Dooooo`;o0000E?oo
ool2o`0001_ooooo0_l0000?ooooo`007_ooool00ol0003oooooooooo`33ooooo`;o0000>_ooool2
o`0000Kooooo0_l0000@ooooo`;o00006oooool2o`0000oooooo000Nooooo`;o0000DOooool2o`00
01kooooo0_l0002=ooooo`;o00001_ooool4o`0000Kooooo0_l0000Sooooo`;o00003oooool001ko
oooo00?o0000ooooooooool09Oooool2o`0002Wooooo0_l0000Nooooo`;o0000<_ooool2o`0006?o
oooo0_l00006ooooo`;o0000=?ooool001kooooo00?o0000ooooooooool09Oooool2o`0000Kooooo
0_l0001eooooo`;o0000XOooool001kooooo00?o0000ooooooooool02Oooool2o`0001gooooo0_l0
0003ooooo`;o0000A_ooool2o`0001Wooooo0_l0002eooooo`007_ooool00ol0003oooooooooo`09
ooooo`;o00007Oooool2o`0004_ooooo0_l0000>ooooo`;o00002Oooool3o`000;Cooooo000Noooo
o`03o`000?oooooooooo03[ooooo0_l00019ooooo`;o00002_ooool2o`000;Cooooo000Nooooo`03
o`000?oooooooooo03[ooooo0_l0002Booooo`;o00007_ooool2o`0002Cooooo0_l0000aooooo`00
7_ooool00ol0003oooooooooo`11ooooo`;o00008?ooool2o`0002Sooooo0_l0000Qooooo`;o0000
7?ooool2o`0001gooooo0ol0000Tooooo`;o00007oooool2o`0000;ooooo0_l0000<ooooo`007_oo
ool00ol0003oooooooooo`11ooooo`;o00008?ooool2o`0002Sooooo0_l0000?ooooo`;o00004?oo
ool2o`0003_ooooo0_l0000iooooo`;o00002oooool2o`0000;ooooo0_l0000<ooooo`007_ooool0
0ol0003oooooooooo`0@ooooo`;o00009?ooool2o`0004Sooooo0_l0000Gooooo`;o00000oooool2
o`0004?ooooo0_l0000iooooo`;o00002?ooool2o`0001gooooo000Nooooo`03o`000?oooooooooo
013ooooo0_l0000Tooooo`;o0000B?ooool2o`0001Oooooo0_l00018ooooo`;o0000>Oooool2o`00
01[ooooo1?l00009ooooo`007_ooool00ol0003oooooooooo`1@ooooo`;o0000Roooool2o`0000Ko
oooo0_l0000^ooooo`;o00008oooool4o`0000Wooooo000Nooooo`03o`000?oooooooooo053ooooo
0_l0002;ooooo`;o00001_ooool2o`0002kooooo0_l0000`ooooo`007_ooool00ol0003ooooooooo
o`0nooooo`;o0000=?ooool2o`0001_ooooo0_l0000_ooooo`;o00006Oooool2o`0002gooooo0_l0
000iooooo`007_ooool00ol0003oooooooooo`0nooooo`;o00005_ooool2o`0001cooooo0_l0000K
ooooo`;o0000;oooool2o`0001Wooooo0_l0000]ooooo`;o0000>Oooool001kooooo00?o0000oooo
ooooool01_ooool2o`0004kooooo0_l0003Sooooo`;o00002_ooool001kooooo0_l00006ooooo`?o
00001_ooool2o`000?;ooooo0_l0000Mooooo`;o00006?ooool2o`0000[ooooo000Nooooo`03o`00
0?oooooooooo00Gooooo0_l00007ooooo`;o0000A?ooool2o`0000Cooooo0_l0000Hooooo`;o0000
00?oooooo`000?l00000ROooool2o`0001cooooo0ol0000Tooooo`007_ooool00ol0003ooooooooo
o`0Mooooo`;o0000=Oooool2o`0000Cooooo0_l00004ooooo`;o00004_ooool2o`000003ooooool0
003o000009?ooooo0_l0000Booooo`;o00009Oooool001kooooo00?o0000ooooooooool01?ooool2
o`0001Oooooo0_l00011ooooo`;o00001?ooool2o`0000gooooo0_l0000Kooooo`;o00009?ooool2
o`0005;ooooo0_l0000iooooo`007_ooool00ol0003oooooooooo`04ooooo`;o0000:_ooool2o`00
03Cooooo0_l0000=ooooo`;o00006?ooool2o`000003ooooool0003o000002Cooooo0_l00021oooo
o`;o00002_ooool001kooooo00?o0000ooooooooool04Oooool2o`0001gooooo0_l0000Uooooo`;o
0000=_ooool2o`0001_ooooo0_l0001Aooooo`;o0000>_ooool2o`0000[ooooo000Nooooo`03o`00
0?oooooooooo00oooooo1?l00014ooooo`;o0000Doooool3o`00053ooooo0_l00016ooooo`007_oo
ool00ol0003oooooooooo`02o`0000gooooo0_l0002Looooo`;o0000V?ooool001kooooo00?o0000
ooooooooool00_l0000/ooooo`;o00002Oooool2o`0000?ooooo0_l0001:ooooo`;o0000U?ooool2
o`0002Gooooo000Nooooo`03o`000?oooooooooo02kooooo0_l00009ooooo`;o00000oooool2o`00
00Wooooo0_l0000Rooooo`;o00006oooool2o`0009Cooooo0_l0000Uooooo`007_ooool00ol0003o
ooooooooo`0^ooooo`;o00006Oooool2o`0000Kooooo0_l0000Jooooo`;o0000POooool2o`0005Go
oooo000Nooooo`03o`000?oooooooooo01[ooooo0_l0000Booooo`;o00008Oooool2o`0009gooooo
0_l0001Eooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o0000E?ooool2o`0000_ooooo0_l0
0018ooooo`;o0000O_ooool001kooooo00?o0000ooooooooool09_ooool2o`0004Sooooo0_l0000;
ooooo`;o0000B?ooool2o`0007kooooo000Nooooo`03o`000?oooooooooo02Kooooo0_l0001Poooo
o`;o0000X_ooool2o`0001Wooooo000Nooooo`03o`000?oooooooooo02_ooooo0_l0000?ooooo`;o
00008_ooool2o`0000gooooo0_l0000Gooooo`;o00004oooool2o`0007Wooooo0_l0000Booooo`;o
00003?ooool2o`0000_ooooo000Nooooo`;o00001oooool2o`0002?ooooo0_l0000?ooooo`;o0000
2Oooool2o`0001Oooooo0_l0000=ooooo`;o00005oooool2o`0001?ooooo0_l0001iooooo`;o0000
8?ooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l0000oooooo`;o0000_?oo
ool2o`00043ooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l0000Xooooo`;o0000>?ooool2
o`0006Oooooo0_l0000Mooooo`;o00007?ooool2o`0002;ooooo000Nooooo`03o`000?oooooooooo
013ooooo0_l00007ooooo`;o0000:?ooool2o`00017ooooo0_l0000Uooooo`;o0000Ioooool2o`00
03?ooooo0_l00006ooooo`;o00008_ooool001kooooo00?o0000ooooooooool04?ooool2o`0004Co
oooo0_l00033ooooo`;o0000:_ooool001kooooo00?o0000ooooooooool0C?ooool2o`0006?ooooo
0_l0002Dooooo`007_ooool00ol0003oooooooooo`1<ooooo`;o000000?oooooo`000?l00000H?oo
ool2o`0000?ooooo0_l0000fooooo`;o0000Eoooool001kooooo00?o0000ooooooooool0Coooool2
o`0004Cooooo0_l00002ooooo`;o00006oooool2o`0000?ooooo0_l00003ooooo`;o0000;?ooool2
o`0003Oooooo0_l0000Nooooo`007_ooool00ol0003oooooooooo`1eooooo`;o00007_ooool2o`00
00;ooooo0_l0000Pooooo`;o00000oooool2o`0006Gooooo0_l0000Gooooo`;o00001Oooool001ko
oooo00?o0000ooooooooool05_ooool2o`0005gooooo0_l0002kooooo`;o00003?ooool2o`0000Go
oooo000Nooooo`03o`000?oooooooooo01Kooooo0_l0002Qooooo`;o00004_ooool2o`0002Kooooo
0_l0000kooooo`;o00004oooool001kooooo00?o0000ooooooooool0^Oooool2o`0001;ooooo0_l0
000Vooooo`;o0000D?ooool001kooooo00?o0000ooooooooool0Eoooool2o`0002Sooooo0_l0002C
ooooo`;o0000;oooool001kooooo00?o0000ooooooooool0Eoooool2o`0001oooooo0_l00007oooo
o`;o0000;Oooool2o`0006Cooooo0_l00004ooooo`;o0000:Oooool000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000
ooooooooool07Oooool2o`0000?ooooo0_l0000hooooo`;o00002_ooool2o`0000kooooo0_l0000L
ooooo`;o00006?ooool2o`0000;ooooo0_l0001Vooooo`;o0000:Oooool000?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o
0000ooooooooool07Oooool3o`0000;ooooo0_l0000Rooooo`;o00005?ooool2o`0000[ooooo0_l0
000/ooooo`;o00007?ooool2o`0003gooooo1?l00004ooooo`;o0000B_ooool000?ooooo00Go410@
oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`0001kooooo
0_l0000Vooooo`;o0000:_ooool2o`0001Kooooo0_l0001Wooooo`Co00001?ooool2o`0004[ooooo
0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Ko
oooo00?o0000ooooooooool0L_ooool2o`0001Kooooo0_l0000Sooooo`;o0000?Oooool2o`0005Oo
oooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<
00Kooooo00?o0000ooooooooool0T_ooool2o`0001_ooooo0_l0000fooooo`;o00001Oooool2o`00
05Oooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08oooo
o`?o0000<_ooool2o`0005kooooo0_l0000_ooooo`;o00008_ooool2o`0005kooooo0003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`?o0000<_ooool2o`00
08oooooo0_l0001]ooooo`;o00004oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0Eoooool2o`000=Wooooo0_l0000C
ooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o0000@?ooool2o`0000Kooooo0_l0001koooo
o`;o0000JOooool001kooooo00?o0000ooooooooool05Oooool2o`0004Sooooo0_l0000Jooooo`;o
00006?ooool2o`0004Gooooo0_l0001Yooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o0000
9Oooool2o`0003Gooooo0_l0000Hooooo`;o0000/?ooool001gooooo0_l0000>ooooo`;o00003ooo
ool2o`0002Gooooo0_l0002mooooo`;o0000@_ooool001gooooo0_l0000>ooooo`;o00001_ooool2
o`0005oooooo0_l0002<ooooo`;o0000>oooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo
01Cooooo0_l0001Oooooo`;o0000U_ooool2o`00037ooooo0_l00005ooooo`007_ooool00ol0003o
ooooooooo`2Eooooo`;o0000M_ooool2o`0001?ooooo0_l0000Sooooo`007_ooool2o`0009Kooooo
0_l0002;ooooo`;o00008oooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooo
oooo00gooooo0_l0000@ooooo`;o0000POooool2o`0007;ooooo0_l0000=ooooo`;o00008?ooool0
01kooooo00?o0000ooooooooool02Oooool2o`0000;ooooo0_l0000@ooooo`;o0000Coooool2o`00
033ooooo0_l0000Rooooo`;o00002?ooool2o`0004Cooooo0_l0000;ooooo`Co00008?ooool001ko
oooo0_l0000:ooooo`;o0000IOooool2o`0004Oooooo0_l0000;ooooo`;o00002?ooool2o`0004?o
oooo0_l0000<ooooo`;o00008_ooool001kooooo00?o0000ooooooooool0P_ooool2o`0003Gooooo
0_l0001;ooooo`;o00003Oooool2o`00033ooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l0
000dooooo`;o00007?ooool2o`0001Kooooo0_l00008ooooo`;o00004?ooool2o`0000Kooooo0_l0
0018ooooo`;o00000_ooool2o`00013ooooo0_l0000oooooo`007_ooool00ol0003oooooooooo`06
ooooo`;o00003_ooool2o`0003Cooooo0_l0000Looooo`;o00008?ooool2o`0000gooooo0_l00000
0ooooooo0000o`000006ooooo`;o0000B?ooool2o`0000;ooooo0_l00019ooooo`;o00001_ooool0
01kooooo00?o0000ooooooooool01_ooool2o`0008gooooo0_l00004ooooo`;o00003oooool2o`00
00gooooo0_l0001Xooooo`;o00003?ooool2o`0000Cooooo0_l00004ooooo`;o00001_ooool001ko
oooo00?o0000ooooooooool07oooool2o`0001;ooooo0_l0001Pooooo`Co00004oooool2o`0000go
oooo0_l0000Vooooo`;o0000@?ooool2o`0000cooooo0_l00004ooooo`;o00003?ooool001kooooo
00?o0000ooooooooool07oooool2o`0001;ooooo0_l0000Iooooo`;o000000?oooooo`000?l00000
A?ooool2o`0001Wooooo0_l0000_ooooo`;o0000H_ooool001kooooo00?o0000ooooooooool0?_oo
ool2o`0000[ooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l00006ooooo`;o0000
5Oooool2o`0003gooooo0_l0001^ooooo`;o00008oooool001kooooo00?o0000ooooooooool0?_oo
ool2o`0000?ooooo0_l00005ooooo`;o00002?ooool2o`0000Kooooo0_l0000Eooooo`;o00001Ooo
ool2o`0006;ooooo0_l0000Uooooo`;o00006Oooool4o`0002?ooooo000Nooooo`03o`000?oooooo
oooo04?ooooo0_l00002ooooo`;o0000<Oooool2o`0006;ooooo0_l000000ooooooo0000o`00000R
ooooo`;o00006Oooool2o`0002Gooooo000Nooooo`03o`000?oooooooooo00gooooo0_l0000hoooo
o`;o0000V?ooool2o`0001Wooooo0_l0000Fooooo`;o00002_ooool2o`0002Gooooo000Nooooo`03
o`000?oooooooooo00gooooo0_l0000^ooooo`;o0000_Oooool2o`0001Kooooo0_l0000:ooooo`;o
00009Oooool001kooooo00?o0000ooooooooool0?Oooool2o`0006[ooooo0_l0000^ooooo`Co0000
J_ooool001kooooo00?o0000ooooooooool0??ooool2o`0006_ooooo0_l0000^ooooo`Co0000J_oo
ool001kooooo00?o0000ooooooooool00_ooool3o`0003Oooooo0_l0001<ooooo`;o0000B?ooool2
o`0005_ooooo0_l0000Dooooo`007_ooool00ol0003oooooooooo`02ooooo`?o0000Ioooool2o`00
01cooooo0_l00018ooooo`;o0000E?ooool2o`0000Gooooo0_l0000Dooooo`007_ooool2o`0001Oo
oooo0_l0000booooo`;o00008?ooool2o`0004?ooooo0_l0001gooooo`;o00006oooool001kooooo
00?o0000ooooooooool05_ooool2o`0003;ooooo0_l0000eooooo`;o00006Oooool2o`0001?ooooo
0ol0000>ooooo`;o00000_ooool2o`0000Wooooo0_l0001dooooo`007_ooool00ol0003ooooooooo
o`1=ooooo`;o0000<_ooool2o`00017ooooo1?l00004ooooo`;o00005?ooool2o`0000kooooo0_l0
0002ooooo`;o00002Oooool2o`0001oooooo0_l0000:ooooo`;o00008_ooool2o`0001[ooooo0ol0
0006ooooo`007_ooool00ol0003oooooooooo`17ooooo`;o00001?ooool2o`0003Kooooo0_l0000=
ooooo`Co00001_ooool2o`0002kooooo0_l00003ooooo`;o00007Oooool2o`0000[ooooo0_l00005
ooooo`;o00006oooool2o`0001[ooooo0ol00006ooooo`007_ooool00ol0003oooooooooo`0Moooo
o`;o0000:?ooool2o`0003cooooo0_l0000Gooooo`?o00004Oooool2o`0001[ooooo0_l00003oooo
o`;o0000<?ooool2o`00037ooooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o
0000E?ooool2o`0001Cooooo0_l0000Dooooo`;o00004Oooool2o`0001oooooo0_l0000eooooo`;o
0000;?ooool2o`0000gooooo000Nooooo`03o`000?oooooooooo01Oooooo1?l0000Fooooo`;o0000
@?ooool2o`0001Cooooo0_l0000Aooooo`;o0000K?ooool2o`0002Sooooo0_l00006ooooo`;o0000
2Oooool001kooooo00?o0000ooooooooool05oooool4o`0001Kooooo0_l000000ooooooo0000o`00
0015ooooo`;o00007oooool2o`0005;ooooo0_l00012ooooo`;o00001_ooool2o`0000Wooooo000N
ooooo`03o`000?oooooooooo03Cooooo0_l0000/ooooo`;o00005oooool2o`00017ooooo0_l0001P
ooooo`;o0000@_ooool2o`00017ooooo000Nooooo`03o`000?oooooooooo04gooooo0_l000000ooo
oooo0000o`00000=ooooo`;o000000?oooooo`000?l000002Oooool2o`0001Sooooo0_l00005oooo
o`;o0000=Oooool2o`00083ooooo000Nooooo`03o`000?oooooooooo04gooooo0_l000000ooooooo
0000o`000009ooooo`Ko00002?ooool2o`0000;ooooo0_l0000Hooooo`;o0000??ooool2o`00077o
oooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o0000C_ooool4o`0000[ooooo
0_l0000Wooooo`;o0000;Oooool2o`0001Oooooo0_l00019ooooo`;o00004Oooool2o`0000gooooo
000Nooooo`03o`000?oooooooooo00_ooooo0_l0000Tooooo`;o0000Goooool2o`0002gooooo0_l0
000Gooooo`;o00007oooool2o`0001;ooooo0_l00005ooooo`Co00002oooool2o`00023ooooo000N
ooooo`03o`000?oooooooooo037ooooo0_l00038ooooo`;o00004_ooool2o`0000Gooooo1?l0000]
ooooo`007_ooool00ol0003oooooooooo`0Yooooo`;o00004oooool2o`0001gooooo0_l0000Toooo
o`;o0000Toooool2o`0001cooooo0_l0000?ooooo`007_ooool00ol0003oooooooooo`0Yooooo`;o
00004oooool2o`00017ooooo0_l0000:ooooo`;o00009?ooool2o`000:3ooooo0_l0000?ooooo`;o
00003oooool001kooooo0_l0000Mooooo`;o0000<oooool2o`000003ooooool0003o000003Wooooo
0_l0002<ooooo`;o000000?oooooo`000?l000000oooool2o`00023ooooo000Nooooo`03o`000?oo
oooooooo01cooooo0_l0000fooooo`;o00005?ooool2o`0000?ooooo0_l0000Jooooo`;o00000_oo
ool2o`0008cooooo0_l000000ooooooo0000o`00000Uooooo`007_ooool00ol0003oooooooooo`1Z
ooooo`;o00000oooool2o`0001[ooooo0_l0000Vooooo`;o0000I?ooool2o`0002cooooo000Noooo
o`03o`000?oooooooooo03Oooooo0_l00012ooooo`;o0000=_ooool2o`0006Cooooo0_l00004oooo
o`;o00005Oooool2o`0000oooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0000cooooo`;o
00009_ooool2o`0001?ooooo0_l00005ooooo`;o0000S_ooool2o`0001;ooooo0_l0000Eooooo`;o
00002Oooool2o`0000Cooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0000=ooooo`;o0000
<oooool2o`0001Oooooo0_l0000Cooooo`;o00008oooool2o`00073ooooo0_l0000[ooooo`;o0000
1oooool2o`0000Cooooo000Nooooo`03o`000?oooooooooo017ooooo0_l0000cooooo`;o0000<?oo
ool2o`0001oooooo0ol0001Xooooo`;o00005?ooool2o`0001cooooo0_l0000=ooooo`007_ooool0
0ol0003oooooooooo`16ooooo`;o0000<?ooool2o`00023ooooo0_l0001>ooooo`;o00006?ooool2
o`0001Cooooo0_l0000[ooooo`007_ooool00ol0003oooooooooo`0fooooo`;o0000/_ooool2o`00
05_ooooo000Nooooo`03o`000?oooooooooo03Kooooo0_l0001Aooooo`;o0000<oooool2o`0001So
oooo0_l0000@ooooo`;o00001?ooool2o`0001Gooooo0_l0000aooooo`;o00002oooool001kooooo
00?o0000ooooooooool0ROooool2o`0003?ooooo0_l0000Booooo`;o00001?ooool2o`0001Kooooo
0_l0000Eooooo`;o00000oooool2o`0002cooooo0_l0000;ooooo`007_ooool00ol0003ooooooooo
o`0Zooooo`;o0000?_ooool2o`0001Oooooo0_l0000]ooooo`;o00006?ooool2o`0000Cooooo0_l0
000`ooooo`;o00001_ooool2o`0003Wooooo000Nooooo`03o`000?oooooooooo02[ooooo0_l0000G
ooooo`;o00009Oooool2o`0000;ooooo0_l0000Cooooo`;o0000;Oooool2o`0001Sooooo0_l0000f
ooooo`?o00002oooool2o`0000Kooooo0_l0000[ooooo`007_ooool00ol0003oooooooooo`13oooo
o`;o00004?ooool2o`0001Oooooo0_l0000Rooooo`;o0000B_ooool2o`0002Gooooo0_l0000;oooo
o`;o00001_ooool2o`0002?ooooo0_l00006ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`02
ooooo`;o0000Aoooool2o`0000Sooooo0_l0000Sooooo`;o00001_ooool2o`0000kooooo0_l0001:
ooooo`;o00008oooool2o`0002Gooooo0_l0000Cooooo`;o00001_ooool000?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o
0000ooooooooool00_ooool2o`0004Oooooo0_l0000]ooooo`;o00001_ooool2o`0007oooooo0_l0
000Uooooo`;o00006oooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oo
ooooooooooooool000001_ooool5o`0000;ooooo0_l0000_ooooo`;o00003_ooool2o`000?oooooo
0Oooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb
<S801_ooool00ol0003oooooooooo`02o`0000;ooooo0_l0000/ooooo`;o000000?oooooo`000?l0
00003_ooool2o`000<7ooooo0_l0000mooooo`000oooool01Ol0003ooooooooooooooooo000000_o
oooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo03;ooooo0_l00012oooo
o`;o0000T?ooool2o`0003gooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@
413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0Doooool2o`00027ooooo0_l0000N
ooooo`;o0000;_ooool2o`0007oooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0Doooool2o`00047ooooo0_l0
000^ooooo`;o0000Ooooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@
413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`0eooooo`;o00006Oooool2o`000?Gooooo
000Nooooo`03o`000?oooooooooo03Gooooo0_l0000Iooooo`;o00007oooool2o`0001Gooooo0_l0
002mooooo`007_ooool00ol0003oooooooooo`0Qooooo`;o00008Oooool2o`0002_ooooo0_l0000E
ooooo`;o0000VOooool2o`0002;ooooo000Nooooo`03o`000?oooooooooo027ooooo0_l0000Noooo
o`;o000000?oooooo`000?l00000N_ooool2o`0002gooooo0_l0000booooo`;o00008_ooool001ko
oooo00?o0000ooooooooool0@Oooool2o`0007gooooo0_l0000Fooooo`;o00005Oooool2o`0005Ko
oooo000Nooooo`03o`000?oooooooooo04cooooo0_l0001^ooooo`;o00006_ooool2o`0005oooooo
0_l00004ooooo`;o00001_ooool001kooooo00?o0000ooooooooool0C?ooool3o`0001Kooooo0_l0
000Mooooo`;o0000<?ooool2o`0000Cooooo0_l000000ooooooo0000o`00001?ooooo`;o00009ooo
ool2o`0000Cooooo0_l00006ooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o00008oooool2
o`0001;ooooo0_l00006ooooo`;o00003_ooool2o`0001gooooo0_l0000`ooooo`;o00001oooool2
o`0004oooooo0_l0000Hooooo`;o00006oooool001kooooo00?o0000ooooooooool05?ooool2o`00
02?ooooo0_l0000Jooooo`;o0000=oooool2o`00097ooooo0_l00007ooooo`;o00006oooool001ko
oooo00?o0000ooooooooool06?ooool2o`0007Cooooo0_l0002Aooooo`?o00008oooool001kooooo
00?o0000ooooooooool02?ooool2o`0000kooooo0_l0000/ooooo`;o00002?ooool2o`0003Gooooo
0_l0000Xooooo`;o000000?oooooo`000?l000006oooool2o`0004[ooooo0_l00003ooooo`;o0000
2Oooool2o`0001Sooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0000looooo`;o00002?oo
ool2o`0003Gooooo0_l0000Xooooo`;o000000?oooooo`000?l000004?ooool4o`0000Oooooo0_l0
001:ooooo`;o00003_ooool2o`0001Sooooo000Mooooo`?o0000C?ooool2o`0002_ooooo0_l0000N
ooooo`;o0000;?ooool4o`0005Oooooo0_l0000Tooooo`007Oooool2o`0004gooooo0_l00006oooo
o`;o00008oooool2o`0001kooooo0_l0000Hooooo`;o00006_ooool2o`00057ooooo0_l0000Toooo
o`007_ooool00ol0003oooooooooo`0@ooooo`;o00008_ooool2o`0001cooooo0ol0000Wooooo`;o
0000:oooool2o`0000Oooooo0_l0000Jooooo`;o0000Goooool2o`0001Kooooo000Nooooo`03o`00
0?oooooooooo013ooooo0_l0000?ooooo`;o00003?ooool2o`0000?ooooo0_l0000Looooo`;o0000
:?ooool2o`0002_ooooo0_l00024ooooo`;o00005_ooool001kooooo00?o0000ooooooooool08Ooo
ool2o`0000cooooo0_l0001Xooooo`;o0000=?ooool2o`0007Kooooo000Nooooo`03o`000?oooooo
oooo073ooooo0_l0000Wooooo`;o0000=?ooool2o`00017ooooo0_l0001Dooooo`;o00003Oooool0
01kooooo00?o0000ooooooooool0@?ooool2o`0002kooooo0_l0001`ooooo`;o0000E?ooool2o`00
00gooooo000Nooooo`03o`000?oooooooooo043ooooo0_l0000;ooooo`;o00006_ooool2o`00013o
oooo0_l00004ooooo`;o00006Oooool2o`000:Wooooo000Nooooo`03o`000?oooooooooo02kooooo
0_l0000Mooooo`;o00006_ooool2o`0000gooooo0_l000000ooooooo0000o`000002ooooo`Co0000
6Oooool2o`000:Wooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0000Hooooo`;o0000AOoo
ool2o`000003ooooool0003o000000Gooooo0_l0000Zooooo`;o0000Joooool2o`0002gooooo000N
ooooo`03o`000?oooooooooo01Cooooo0_l0001Oooooo`;o0000=?ooool2o`0006_ooooo0_l0000]
ooooo`007_ooool00ol0003oooooooooo`0dooooo`;o00006oooool3o`0001gooooo0_l0003Doooo
o`007_ooool00ol0003oooooooooo`0Uooooo`;o00003Oooool2o`0001_ooooo0ol0000Aooooo`;o
00002_ooool2o`0002gooooo0_l0001Rooooo`;o0000:?ooool2o`0001Oooooo000Nooooo`03o`00
0?oooooooooo02Gooooo0_l0000nooooo`;o0000>Oooool2o`00013ooooo0_l0001@ooooo`;o0000
:?ooool2o`0001Oooooo000Nooooo`03o`000?oooooooooo0;;ooooo0_l00007ooooo`;o00009Ooo
ool2o`0002Kooooo0_l0000Oooooo`;o00006_ooool001kooooo00?o0000ooooooooool02_ooool2
o`0006kooooo0_l0000oooooo`;o00005_ooool2o`0000gooooo0_l0000Vooooo`?o00007_ooool2
o`0001[ooooo000Nooooo`;o00002oooool2o`0006kooooo0_l00008ooooo`;o00004_ooool2o`00
00Sooooo0_l0000_ooooo`;o0000=_ooool2o`00017ooooo0_l0000Wooooo`007_ooool00ol0003o
ooooooooo`1Dooooo`;o00004_ooool2o`0001[ooooo0_l0000Booooo`;o00002?ooool2o`0007[o
oooo0_l0000Wooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o0000A_ooool2o`0000;ooooo
0_l0000>ooooo`;o00005Oooool2o`00097ooooo0_l0000cooooo`007_ooool00ol0003ooooooooo
o`0<ooooo`;o00009_ooool2o`0002;ooooo1?l0000Sooooo`;o00009Oooool2o`0003Sooooo0_l0
000`ooooo`;o0000:oooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo03Cooooo0_l0000S
ooooo`?o00005oooool2o`0000Gooooo0_l0000Zooooo`;o0000;_ooool2o`0000Sooooo0_l00006
ooooo`;o0000EOooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0000loooo
o`;o0000:Oooool2o`0000Gooooo0_l0000gooooo`;o00008Oooool2o`00013ooooo0_l00003oooo
o`;o0000F?ooool001kooooo00?o0000ooooooooool02_ooool2o`0001kooooo0_l0000Looooo`;o
0000JOooool2o`0003Sooooo0_l0001Hooooo`007_ooool2o`0002_ooooo0_l00018ooooo`;o0000
??ooool5o`0003cooooo0_l0001:ooooo`;o00001_ooool001kooooo0_l0001eooooo`;o00001_oo
ool2o`00013ooooo0_l0000Rooooo`;o000000?oooooo`000?l00000??ooool2o`0004[ooooo0_l0
0006ooooo`007_ooool00ol0003oooooooooo`1looooo`;o00004?ooool2o`000;Oooooo000Noooo
o`03o`000?oooooooooo09;ooooo0_l00006ooooo`;o00003Oooool2o`0001Sooooo0_l00022oooo
o`007_ooool00ol0003oooooooooo`07ooooo`;o00009Oooool2o`0004kooooo0_l0000Booooo`;o
00001_ooool2o`0000gooooo0_l0000Hooooo`;o0000:Oooool2o`0005Oooooo000Nooooo`03o`00
0?oooooooooo00Oooooo0_l0000Uooooo`;o00009oooool2o`0002Gooooo0_l0001Jooooo`;o0000
4_ooool2o`0005Oooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0001Aooooo`;o00001?oo
ool2o`0002[ooooo0_l0000Nooooo`;o0000;oooool2o`0005Oooooo0_l0000Booooo`007_ooool0
0ol0003oooooooooo`02o`0000;ooooo0_l0000[ooooo`;o0000:_ooool2o`0000kooooo0_l0000J
ooooo`;o00007_ooool2o`0005kooooo0_l0000Xooooo`;o00004_ooool001kooooo00?o0000oooo
ooooool00_l0000_ooooo`;o0000>_ooool2o`0000?ooooo0_l0002Eooooo`;o0000??ooool001ko
oooo0_l0000hooooo`;o00004Oooool2o`0002Kooooo0_l0000Wooooo`;o00006_ooool2o`0008ko
oooo000Nooooo`03o`000?oooooooooo03Oooooo0_l0000Aooooo`;o0000Coooool2o`0001[ooooo
0_l0000Jooooo`;o0000L_ooool001kooooo00?o0000ooooooooool07_ooool2o`000;?ooooo0_l0
0003ooooo`;o00001oooool2o`0004kooooo0_l0000Dooooo`007_ooool00ol0003oooooooooo`0N
ooooo`;o00000oooool2o`0000Gooooo0_l0000Cooooo`;o0000:_ooool2o`0004?ooooo0_l0000V
ooooo`;o00000oooool2o`0000;ooooo0_l0001>ooooo`;o00005?ooool001kooooo00?o0000oooo
ooooool08oooool2o`0000Gooooo0_l0000Cooooo`;o00009oooool2o`000003ooooool0003o0000
04?ooooo0_l00008ooooo`;o00008Oooool2o`0005Gooooo0_l0000Aooooo`007_ooool00ol0003o
ooooooooo`0gooooo`;o0000;oooool2o`00053ooooo0_l0001Booooo`;o00009?ooool2o`00017o
oooo000Nooooo`03o`000?oooooooooo013ooooo0_l0000Sooooo`Co0000^?ooool2o`0000_ooooo
0_l0000>ooooo`;o0000;?ooool2o`0000Wooooo000Nooooo`03o`000?oooooooooo013ooooo0_l0
000Sooooo`;o0000^_ooool2o`0000_ooooo0_l0000looooo`;o00000oooool2o`0000Cooooo000N
ooooo`03o`000?oooooooooo08[ooooo0_l0000mooooo`;o0000M_ooool2o`0000Cooooo000Noooo
o`03o`000?oooooooooo073ooooo0_l0000Hooooo`;o0000?Oooool2o`0007cooooo000Nooooo`03
o`000?oooooooooo01gooooo0_l0001Aooooo`;o00006?ooool2o`000:[ooooo0_l0000?ooooo`00
7_ooool00ol0003oooooooooo`0Mooooo`;o00005_ooool2o`0004kooooo0_l00003ooooo`;o0000
V?ooool2o`00013ooooo0_l00002ooooo`;o00002oooool001kooooo00?o0000ooooooooool0=Ooo
ool2o`0004kooooo0_l0002<ooooo`;o00003oooool2o`0001Cooooo0_l0000;ooooo`007_ooool0
0ol0003oooooooooo`1Booooo`;o0000Voooool2o`0002;ooooo0_l0000booooo`005?ooool4o`00
0003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool02?ooool2o`0000gooooo0_l0000?oooo
o`;o00004oooool2o`0001?ooooo0_l0000^ooooo`;o0000Joooool2o`0005Kooooo000Fooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool2o`0000gooooo0_l0000?ooooo`;o
00004oooool2o`0004?ooooo0_l0000Jooooo`;o00008Oooool2o`0004?ooooo0_l0000oooooo`00
5_ooool00ol0003oooooooooo`05ooooo`?o0000W_ooool2o`00027ooooo0_l00013ooooo`;o0000
?oooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3o
oooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000oooooooo
ool0oooooom@ooooo`005?ooool00omEEEGoIVIVo`00003ooooooe;ooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.92347 .03957 Mdot
.54155 .08354 Mdot
.30607 .23315 Mdot
.65402 .05177 Mdot
.27409 .94779 Mdot
.14096 .67651 Mdot
.88592 .50233 Mdot
.06608 .38053 Mdot
.37649 .76738 Mdot
.5323 .01435 Mdot
.56917 .77303 Mdot
.42812 .77887 Mdot
.13095 .13242 Mdot
.70255 .95535 Mdot
.27794 .44178 Mdot
.70776 .42246 Mdot
.66061 .00633 Mdot
.92127 .26005 Mdot
.39785 .0532 Mdot
.20293 .41493 Mdot
.3878 .65748 Mdot
.00618 .11781 Mdot
.39523 .41292 Mdot
.96535 .91872 Mdot
.98431 .58932 Mdot
.58632 .59212 Mdot
.85926 .51197 Mdot
.74786 .4246 Mdot
.80328 .00588 Mdot
.23043 .74599 Mdot
.97171 .66834 Mdot
.57854 .82167 Mdot
.70123 .45433 Mdot
.06549 .18069 Mdot
.9376 .62103 Mdot
.594 .83882 Mdot
.65233 .72373 Mdot
.38748 .8125 Mdot
.00557 .66329 Mdot
.22127 .80475 Mdot
.82448 .04198 Mdot
.2611 .59121 Mdot
.44187 .96197 Mdot
.34352 .0802 Mdot
.15991 .01977 Mdot
.48105 .60141 Mdot
.66769 .88716 Mdot
.36288 .25903 Mdot
.86473 .82598 Mdot
.43493 .77603 Mdot
.25648 .63375 Mdot
.87712 .63476 Mdot
.00718 .14351 Mdot
.06239 .38918 Mdot
.19946 .66034 Mdot
.33724 .79691 Mdot
.84355 .04089 Mdot
.24768 .84441 Mdot
.42879 .33496 Mdot
.25087 .06804 Mdot
4e-05 .15986 Mdot
.22525 .8782 Mdot
.2257 .78636 Mdot
.82554 .84164 Mdot
.62333 .34512 Mdot
.21603 .96934 Mdot
.94307 .08798 Mdot
.56343 .62665 Mdot
.8973 .78214 Mdot
.93027 .24532 Mdot
.01611 .921 Mdot
.29615 .69303 Mdot
.07287 .42315 Mdot
.65715 .51744 Mdot
.6776 .93615 Mdot
.19706 .12727 Mdot
.32248 .01331 Mdot
.35466 .71604 Mdot
.86183 .33751 Mdot
.12074 .5684 Mdot
.45145 .1646 Mdot
.83071 .76134 Mdot
.21708 .69568 Mdot
.06606 .40043 Mdot
.41763 .95658 Mdot
.08747 .63722 Mdot
.29795 .46061 Mdot
.33595 .89635 Mdot
.50215 .73969 Mdot
.41349 .73885 Mdot
.22376 .71675 Mdot
.86551 .72004 Mdot
.06444 .42585 Mdot
.48647 .41603 Mdot
.4788 .084 Mdot
.10056 .37985 Mdot
.49709 .70576 Mdot
.65982 .20212 Mdot
.63605 .82598 Mdot
.53085 .85359 Mdot
.3833 .57563 Mdot
.71681 .65405 Mdot
.82814 .04116 Mdot
.42745 .50772 Mdot
.26078 .3888 Mdot
.23568 .44271 Mdot
.2747 .75444 Mdot
.67119 .68129 Mdot
.21221 .59092 Mdot
.67842 .89671 Mdot
.97363 .07969 Mdot
.53622 .50869 Mdot
.09612 .23218 Mdot
.44395 .39049 Mdot
.88538 .67142 Mdot
.79187 .7746 Mdot
.07745 .63227 Mdot
.87935 .74828 Mdot
.26064 .36458 Mdot
.45073 .77979 Mdot
.6821 .11661 Mdot
.55857 .44712 Mdot
.99662 .29317 Mdot
.34124 .2023 Mdot
.55518 .6791 Mdot
.42452 .31479 Mdot
.35314 .84113 Mdot
.22357 .01975 Mdot
.91785 .6984 Mdot
.8215 .7833 Mdot
.97835 .82145 Mdot
.89802 .77075 Mdot
.02725 .11618 Mdot
.87422 .95729 Mdot
.57336 .15407 Mdot
.09493 .02921 Mdot
.36675 .82894 Mdot
.02563 .48231 Mdot
.44613 .56063 Mdot
.42333 .7515 Mdot
.11143 .47533 Mdot
.17911 .46504 Mdot
.74971 .04483 Mdot
.8558 .07861 Mdot
.18428 .44974 Mdot
.43237 .60713 Mdot
.26926 .79513 Mdot
.71029 .12721 Mdot
.44983 .26297 Mdot
.19158 .2283 Mdot
.19216 .13329 Mdot
.17003 .12201 Mdot
.56814 .96348 Mdot
.73859 .03291 Mdot
.34469 .3454 Mdot
.3162 .42891 Mdot
.50872 .67111 Mdot
.56737 .09472 Mdot
.70645 .42379 Mdot
.02644 .68492 Mdot
.92928 .68209 Mdot
.3628 .75082 Mdot
.99712 .3585 Mdot
.83832 .4319 Mdot
.87355 .72578 Mdot
.72577 .61437 Mdot
.16638 .56365 Mdot
.80686 .79898 Mdot
.10401 .55801 Mdot
.90652 .17146 Mdot
.83739 .41456 Mdot
.17762 .02613 Mdot
.47882 .28542 Mdot
.17841 .76053 Mdot
.9657 .61461 Mdot
.90504 .88846 Mdot
.40392 .33302 Mdot
.79546 .86443 Mdot
.58657 .43152 Mdot
.51991 .6328 Mdot
.08307 .15062 Mdot
.88906 .93867 Mdot
.65204 .07442 Mdot
.18446 .4927 Mdot
.80052 .15681 Mdot
.55628 .0798 Mdot
.49154 .21041 Mdot
.14053 .62576 Mdot
.40167 .30228 Mdot
.94402 .29989 Mdot
.39267 .2847 Mdot
.98147 .21593 Mdot
.90768 .55414 Mdot
.31649 .79956 Mdot
.50601 .11967 Mdot
.61189 .86503 Mdot
.30029 .31878 Mdot
.42558 .09425 Mdot
.34393 .65193 Mdot
.85016 .90924 Mdot
.05022 .87813 Mdot
.58262 .09502 Mdot
.25287 .06889 Mdot
.07902 .28144 Mdot
.73413 .83964 Mdot
.4172 .02833 Mdot
.9208 .19279 Mdot
.27947 .66822 Mdot
.19786 .48474 Mdot
.20916 .79455 Mdot
.51358 .38613 Mdot
.78912 .24009 Mdot
.63004 .72898 Mdot
.44881 .4624 Mdot
.16619 .21196 Mdot
.88208 .49981 Mdot
.69266 .86032 Mdot
.96609 .10964 Mdot
.45915 .16299 Mdot
.32022 .9404 Mdot
.84453 .30243 Mdot
.83198 .63909 Mdot
.90895 .59923 Mdot
.55224 .68595 Mdot
.7066 .26282 Mdot
.66356 .79053 Mdot
.0199 .62468 Mdot
.27724 .56442 Mdot
.69565 .93822 Mdot
.77875 .98036 Mdot
.79341 .22192 Mdot
.61426 .71363 Mdot
.15754 .46793 Mdot
.57122 .52997 Mdot
.84737 .29744 Mdot
.50727 .4323 Mdot
.65011 .47509 Mdot
.40782 .15811 Mdot
.10852 .55345 Mdot
.6884 .03288 Mdot
.96856 .93343 Mdot
.61491 .61258 Mdot
.81793 .10207 Mdot
.35445 .4796 Mdot
.99014 .01204 Mdot
.18152 .16453 Mdot
.65104 .14842 Mdot
.14225 .36455 Mdot
.5336 .17876 Mdot
.2342 .67142 Mdot
.67265 .14842 Mdot
.72829 .20449 Mdot
.45203 .71327 Mdot
.68117 .00455 Mdot
.05404 .07443 Mdot
.82002 .10164 Mdot
.51382 .64386 Mdot
.0335 .25514 Mdot
.15468 .09076 Mdot
.36761 .57694 Mdot
.30041 .1731 Mdot
.80079 .56852 Mdot
.11838 .6976 Mdot
.65802 .92524 Mdot
.26325 .30038 Mdot
.50436 .55921 Mdot
.56311 .60938 Mdot
.44363 .83004 Mdot
.5821 .60655 Mdot
.50875 .81115 Mdot
.46729 .08811 Mdot
.81098 .68359 Mdot
.85482 .3745 Mdot
.11281 .63941 Mdot
.32441 .05591 Mdot
.2024 .36748 Mdot
.64927 .11805 Mdot
.1239 .27527 Mdot
.48755 .90687 Mdot
.31387 .35314 Mdot
.63018 .92458 Mdot
.20765 .83908 Mdot
.43043 .11539 Mdot
.90084 .68003 Mdot
.25432 .60134 Mdot
.2017 .42558 Mdot
.61007 .80645 Mdot
.66662 .67981 Mdot
.68407 .04835 Mdot
.08599 .63886 Mdot
.75269 .64239 Mdot
.38285 .12969 Mdot
.73981 .28575 Mdot
.40311 .80764 Mdot
.53306 .42911 Mdot
.07725 .45281 Mdot
.79145 .69035 Mdot
.41629 .48812 Mdot
.99623 .33531 Mdot
.35715 .43138 Mdot
.923 .73392 Mdot
.98415 .14537 Mdot
.82998 .62139 Mdot
.20266 .36337 Mdot
.56198 .60775 Mdot
.078 .25296 Mdot
.1172 .41329 Mdot
.44182 .41823 Mdot
.77468 .44223 Mdot
.84843 .31681 Mdot
.45967 .46359 Mdot
.04316 .48602 Mdot
.19117 .53595 Mdot
.71089 .08038 Mdot
.25661 .34516 Mdot
.94349 .09259 Mdot
.21687 .44922 Mdot
.38503 .32108 Mdot
.29471 .58141 Mdot
.23979 .34466 Mdot
.09259 .61123 Mdot
.98327 .56697 Mdot
.06274 .31054 Mdot
.4311 .61901 Mdot
.11593 .69856 Mdot
.37919 .90129 Mdot
.44526 .69094 Mdot
.99001 .27673 Mdot
.91058 .70112 Mdot
.08353 .4794 Mdot
.17515 .88352 Mdot
.44002 .73081 Mdot
.54581 .74815 Mdot
.85178 .49334 Mdot
.16803 .93808 Mdot
.89383 .46264 Mdot
.11791 .82037 Mdot
.82187 .99759 Mdot
.24173 .78519 Mdot
.42318 .45164 Mdot
.59866 .53364 Mdot
.88389 .26047 Mdot
.1663 .09346 Mdot
.10784 .17946 Mdot
.02793 .83252 Mdot
.64787 .38475 Mdot
.68383 .34847 Mdot
.39471 .09454 Mdot
.92823 .01314 Mdot
.00879 .50802 Mdot
.34526 .95094 Mdot
.08709 .8958 Mdot
.91072 .88737 Mdot
.54127 .12591 Mdot
.07875 .30133 Mdot
.01194 .42441 Mdot
.46088 .78161 Mdot
.90292 .523 Mdot
.33649 .90468 Mdot
.16939 .96742 Mdot
.88731 .1955 Mdot
.42633 .8281 Mdot
.3003 .99208 Mdot
.96481 .35331 Mdot
.80314 .48989 Mdot
.94821 .03109 Mdot
.00086 .88507 Mdot
.2332 .97039 Mdot
.18212 .39127 Mdot
.8477 .88174 Mdot
.51644 .91515 Mdot
.29544 .51775 Mdot
.07148 .07093 Mdot
.19407 .24622 Mdot
.28567 .61977 Mdot
.73772 .24498 Mdot
.97209 .52896 Mdot
.39917 .01346 Mdot
.26276 .22745 Mdot
.60203 .25375 Mdot
.46062 .46846 Mdot
.37082 .87019 Mdot
.4465 .84911 Mdot
.66224 .68525 Mdot
.00877 .95415 Mdot
.91742 .9871 Mdot
.21264 .80913 Mdot
.8186 .07516 Mdot
.66015 .56686 Mdot
.77024 .73354 Mdot
.89603 .72 Mdot
.89173 .8031 Mdot
.94337 .79599 Mdot
.9377 .29592 Mdot
.67204 .84689 Mdot
.9501 .05473 Mdot
.3306 .20896 Mdot
.33977 .58569 Mdot
.54598 .27848 Mdot
.21829 .87164 Mdot
.38158 .97053 Mdot
.44007 .76244 Mdot
.96639 .87948 Mdot
.27016 .55099 Mdot
.38253 .3548 Mdot
.93627 .50546 Mdot
.31319 .11807 Mdot
.55792 .04191 Mdot
.38668 .17065 Mdot
.71606 .6983 Mdot
.33987 .5585 Mdot
.20751 .40329 Mdot
.51625 .04952 Mdot
.97467 .05439 Mdot
.15014 .69886 Mdot
.18182 .22732 Mdot
.97298 .97034 Mdot
.62482 .12571 Mdot
.34271 .29653 Mdot
.43803 .87111 Mdot
.32122 .44379 Mdot
.26484 .42587 Mdot
.4486 .35197 Mdot
.32289 .69577 Mdot
.39118 .03083 Mdot
.94528 .01089 Mdot
.17027 .81077 Mdot
.10035 .43232 Mdot
.45294 .16567 Mdot
.93347 .69474 Mdot
.67962 .4709 Mdot
.7725 .55816 Mdot
.032 .47739 Mdot
.25761 .4034 Mdot
.68923 .65277 Mdot
.30488 .50455 Mdot
.86956 .23045 Mdot
.93649 .94239 Mdot
.16779 .98601 Mdot
.20139 .06142 Mdot
.88049 .04968 Mdot
.8181 .7016 Mdot
.60676 .936 Mdot
.65174 .95947 Mdot
.32624 .80776 Mdot
.86435 .888 Mdot
.9198 .71268 Mdot
.99428 .99813 Mdot
.82226 .19074 Mdot
.28702 .52242 Mdot
.02201 .72017 Mdot
.48059 .25008 Mdot
.68112 .03079 Mdot
.06721 .98293 Mdot
.34621 .72467 Mdot
.11769 .48778 Mdot
.68006 .03088 Mdot
.9416 .22092 Mdot
.2632 .78385 Mdot
.42366 .7509 Mdot
.96589 .30319 Mdot
.29301 .53309 Mdot
.29838 .05455 Mdot
.33207 .83657 Mdot
.12198 .38526 Mdot
.91287 .45937 Mdot
.26849 .2016 Mdot
.45608 .47482 Mdot
.07962 .58128 Mdot
.95285 .76809 Mdot
.45393 .05599 Mdot
.09175 .54761 Mdot
.07756 .4117 Mdot
.07307 .69513 Mdot
.10692 .98678 Mdot
.18115 .51883 Mdot
.3156 .09436 Mdot
.88678 .64025 Mdot
.53846 .43547 Mdot
.01924 .78126 Mdot
.16316 .40903 Mdot
.26426 .3824 Mdot
.19902 .63165 Mdot
.84635 .22351 Mdot
.7534 .78142 Mdot
.1933 .91528 Mdot
.98016 .27058 Mdot
.50585 .11184 Mdot
.07409 .68562 Mdot
.32265 .96887 Mdot
.71693 .75107 Mdot
.92874 .77154 Mdot
.14381 .29297 Mdot
.11495 .03372 Mdot
.65833 .87988 Mdot
.0058 .21668 Mdot
.45774 .74006 Mdot
.21947 .70464 Mdot
.32055 .76269 Mdot
.23685 .1181 Mdot
.72976 .77701 Mdot
.48188 .73817 Mdot
.49011 .16793 Mdot
.07461 .30806 Mdot
.59187 .6655 Mdot
.48208 .89776 Mdot
.54835 .09587 Mdot
.05028 .3504 Mdot
.23002 .86022 Mdot
.10644 .93841 Mdot
.39579 .53805 Mdot
.43918 .1429 Mdot
.30563 .40552 Mdot
.46373 .86698 Mdot
.33033 .70872 Mdot
.94424 .03193 Mdot
.09416 .71782 Mdot
.18745 .60525 Mdot
.31242 .06392 Mdot
.61311 .96452 Mdot
.40216 .66579 Mdot
.11665 .54241 Mdot
.51173 .56186 Mdot
.11188 .78439 Mdot
.81839 .57969 Mdot
.16327 .33828 Mdot
.03914 .19654 Mdot
.88369 .79095 Mdot
.26358 .12338 Mdot
.1319 .71648 Mdot
.52064 .65364 Mdot
.94794 .03881 Mdot
.68817 .57228 Mdot
.27199 .87144 Mdot
.54957 .4357 Mdot
.56758 .58316 Mdot
.09357 .33642 Mdot
.84801 .68749 Mdot
.63819 .74601 Mdot
.7655 .7187 Mdot
.48691 .26665 Mdot
.88767 .54602 Mdot
.57681 .96959 Mdot
.51548 .90836 Mdot
.51994 .15851 Mdot
.87229 .54868 Mdot
.29372 .11403 Mdot
.73318 .36354 Mdot
.83643 .20805 Mdot
.47728 .06598 Mdot
.74952 .02427 Mdot
.28429 .90217 Mdot
.67054 .50766 Mdot
.89969 .98841 Mdot
.53766 .9576 Mdot
.9559 .62694 Mdot
.71857 .29083 Mdot
.617 .60483 Mdot
.98238 .7899 Mdot
.35721 .765 Mdot
.77576 .90812 Mdot
.28689 .07973 Mdot
.53733 .23138 Mdot
.21415 .85534 Mdot
.36356 .27638 Mdot
.80841 .47756 Mdot
.18395 .81053 Mdot
.41631 .44667 Mdot
.97771 .07557 Mdot
.55171 .15867 Mdot
.3912 .83302 Mdot
.72476 .06556 Mdot
.50361 .43893 Mdot
.86782 .16094 Mdot
.62175 .69377 Mdot
.19661 .94887 Mdot
.83032 .90784 Mdot
.61122 .14931 Mdot
.78686 .559 Mdot
.83948 .26076 Mdot
.42646 .90172 Mdot
.74958 .63824 Mdot
.44088 .63134 Mdot
.39004 .12081 Mdot
.37509 .85979 Mdot
.17026 .35297 Mdot
.44898 .59927 Mdot
.35706 .98675 Mdot
.23999 .23986 Mdot
.05864 .25963 Mdot
.99061 .37577 Mdot
.82244 .47473 Mdot
.93097 .75458 Mdot
.59216 .34519 Mdot
.10973 .53747 Mdot
.829 .78626 Mdot
.35902 .47459 Mdot
.29108 .75647 Mdot
.35757 .21656 Mdot
.20937 .47007 Mdot
.43807 .56042 Mdot
.7788 .76728 Mdot
.17772 .82725 Mdot
.25667 .88705 Mdot
.92489 .52133 Mdot
.26325 .04081 Mdot
.0208 .19491 Mdot
.06469 .73391 Mdot
.08876 .3527 Mdot
.30773 .54676 Mdot
.61614 .44421 Mdot
.53749 .57491 Mdot
.29779 .26311 Mdot
.35139 .29606 Mdot
.81333 .97342 Mdot
.6131 .01424 Mdot
.58683 .19615 Mdot
.93952 .33132 Mdot
.82565 .47584 Mdot
.39599 .00283 Mdot
.20039 .42102 Mdot
.71116 .84818 Mdot
.19569 .66741 Mdot
.63394 .71665 Mdot
.00744 .93833 Mdot
.80764 .72367 Mdot
.8935 .36199 Mdot
.68792 .16975 Mdot
.96784 .7134 Mdot
.34993 .18709 Mdot
.31404 .76699 Mdot
.3979 .50782 Mdot
.59165 .88773 Mdot
.2149 .17089 Mdot
.06207 .7144 Mdot
.31991 .84531 Mdot
.36089 .25354 Mdot
.97539 .61492 Mdot
.89485 .5961 Mdot
.42317 .9117 Mdot
.57647 .30031 Mdot
.81573 .97088 Mdot
.47843 .00846 Mdot
.47811 .89139 Mdot
.30189 .63091 Mdot
.85747 .06002 Mdot
.95002 .42163 Mdot
.98462 .49271 Mdot
.93249 .50691 Mdot
.52016 .32737 Mdot
.65155 .27226 Mdot
.67803 .12797 Mdot
.58547 .28582 Mdot
.37829 .8672 Mdot
.36932 .82 Mdot
.17483 .26459 Mdot
.5607 .82314 Mdot
.03311 .85278 Mdot
.16493 .94081 Mdot
.59465 .86009 Mdot
.47161 .99246 Mdot
.23588 .84884 Mdot
.39673 .16951 Mdot
.25656 .11998 Mdot
.43763 .15062 Mdot
.3109 .985 Mdot
.7513 .69506 Mdot
.79064 .05436 Mdot
.75951 .51909 Mdot
.03914 .69464 Mdot
.18629 .79522 Mdot
.18866 .1314 Mdot
.3291 .64605 Mdot
.28343 .81287 Mdot
.98984 .84037 Mdot
.44033 .92094 Mdot
.99585 .24102 Mdot
.59962 .60435 Mdot
.7664 .19988 Mdot
.53033 .95742 Mdot
.30479 .3267 Mdot
.74955 .0127 Mdot
.57523 .8246 Mdot
.21369 .1929 Mdot
.97624 .75449 Mdot
.3784 .90219 Mdot
.34141 .35557 Mdot
.42246 .46969 Mdot
.97165 .62188 Mdot
.19748 .44811 Mdot
.64868 .91682 Mdot
.38681 .90688 Mdot
.97816 .05304 Mdot
.22902 .30751 Mdot
.01339 .87213 Mdot
.38609 .52374 Mdot
.52974 .67309 Mdot
.71349 .05708 Mdot
.80873 .65142 Mdot
.66114 .09451 Mdot
.3174 .82228 Mdot
.0641 .36124 Mdot
.97661 .20298 Mdot
.88217 .08307 Mdot
.59622 .66678 Mdot
.23682 .16073 Mdot
.12095 .28323 Mdot
.10834 .0047 Mdot
.13195 .21893 Mdot
.98138 .47333 Mdot
.93513 .78316 Mdot
.87363 .81305 Mdot
.15924 .76439 Mdot
.58444 .96459 Mdot
.50406 .88512 Mdot
.87755 .31734 Mdot
.65904 .71242 Mdot
.13295 .70084 Mdot
.69296 .86932 Mdot
.48905 .17731 Mdot
.16976 .24546 Mdot
.00129 .22698 Mdot
.91591 .71403 Mdot
.68741 .9622 Mdot
.43361 .71058 Mdot
.79582 .78707 Mdot
.1844 .20436 Mdot
.14153 .83863 Mdot
.13553 .29933 Mdot
.56411 .69694 Mdot
.04777 .79447 Mdot
.43925 .95292 Mdot
.93677 .24764 Mdot
.07115 .35303 Mdot
.53136 .88593 Mdot
.98388 .76635 Mdot
.95676 .76219 Mdot
.82566 .41672 Mdot
.33811 .03899 Mdot
.25996 .01441 Mdot
.85345 .40368 Mdot
.27587 .87247 Mdot
.37477 .92804 Mdot
.05906 .47498 Mdot
.79435 .38655 Mdot
.46927 .73923 Mdot
.58102 .85241 Mdot
.10396 .70235 Mdot
.01826 .67241 Mdot
.88637 .81169 Mdot
.25285 .1864 Mdot
.11905 .26033 Mdot
.12523 .3652 Mdot
.49034 .71018 Mdot
.19706 .93502 Mdot
.83737 .80287 Mdot
.75116 .99718 Mdot
.7082 .58755 Mdot
.62106 .50557 Mdot
.0084 .49388 Mdot
.0453 .24311 Mdot
.89861 .14371 Mdot
.35696 .70171 Mdot
.34597 .7041 Mdot
.85337 .79297 Mdot
.53759 .65575 Mdot
.30904 .50672 Mdot
.2441 .14089 Mdot
.07198 .87142 Mdot
.1341 .26397 Mdot
.9736 .89131 Mdot
.28667 .15243 Mdot
.25287 .93108 Mdot
.77768 .4461 Mdot
.51893 .88771 Mdot
.21083 .11309 Mdot
.93708 .48123 Mdot
.07536 .3172 Mdot
.9814 .85362 Mdot
.4366 .63099 Mdot
.50754 .47114 Mdot
.97777 .78912 Mdot
.84424 .21469 Mdot
.24033 .16917 Mdot
.25163 .65651 Mdot
.71167 .21325 Mdot
.21169 .41035 Mdot
.24259 .47586 Mdot
.88063 .04204 Mdot
.55435 .94401 Mdot
.16572 .78251 Mdot
.40316 .02739 Mdot
.4555 .8338 Mdot
.85984 .59011 Mdot
.00014 .33811 Mdot
.11058 .13004 Mdot
.3885 .21583 Mdot
.89857 .24874 Mdot
.37601 .62993 Mdot
.26538 .10728 Mdot
.25245 .78585 Mdot
.24071 .72984 Mdot
.49988 .58853 Mdot
.30053 .39008 Mdot
.66966 .1904 Mdot
.92881 .12209 Mdot
.29638 .44944 Mdot
.04059 .42935 Mdot
.36767 .57195 Mdot
.84557 .6203 Mdot
.39379 .49044 Mdot
.11213 .75748 Mdot
.57472 .05377 Mdot
.23083 .72744 Mdot
.85089 .15607 Mdot
.59398 .7766 Mdot
.43933 .5352 Mdot
.08966 .28197 Mdot
.8045 .65118 Mdot
.72267 .20599 Mdot
.04624 .62127 Mdot
.57212 .28775 Mdot
.19606 .41898 Mdot
.93407 .01041 Mdot
.86087 .73744 Mdot
.98497 .89921 Mdot
.61744 .03394 Mdot
.03412 .45288 Mdot
.67998 .28997 Mdot
.40044 .7788 Mdot
.2813 .07243 Mdot
.14057 .95378 Mdot
.95413 .26729 Mdot
.32928 .20919 Mdot
.23289 .0819 Mdot
.7082 .8115 Mdot
.74959 .0223 Mdot
.27972 .65799 Mdot
.56183 .22537 Mdot
.59785 .56297 Mdot
.2735 .50684 Mdot
.89804 .31622 Mdot
.65042 .76169 Mdot
.2803 .84409 Mdot
.41447 .00361 Mdot
.58247 .11671 Mdot
.73024 .31186 Mdot
.00766 .98691 Mdot
.43084 .98624 Mdot
.36453 .88939 Mdot
.22175 .22062 Mdot
.03667 .9733 Mdot
.1063 .53605 Mdot
.55311 .13213 Mdot
.95002 .02306 Mdot
.81384 .74774 Mdot
.06841 .36851 Mdot
.67587 .05602 Mdot
.95513 .68081 Mdot
.17849 .7149 Mdot
.16241 .21724 Mdot
.31043 .21818 Mdot
.45227 .22221 Mdot
.74475 .9103 Mdot
.85583 .26403 Mdot
.71749 .22062 Mdot
.27383 .63184 Mdot
.13539 .85659 Mdot
.73861 .72906 Mdot
.9919 .16469 Mdot
.35174 .6427 Mdot
.38738 .91595 Mdot
.55995 .10726 Mdot
.43463 .15728 Mdot
.8016 .16945 Mdot
.29234 .69206 Mdot
.66037 .64242 Mdot
.40871 .08862 Mdot
.69863 .3826 Mdot
.3938 .80506 Mdot
.37978 .02667 Mdot
.10744 .97404 Mdot
.53739 .93324 Mdot
.21397 .54264 Mdot
.36968 .4051 Mdot
.25247 .9696 Mdot
.24052 .64899 Mdot
.72824 .73817 Mdot
.36215 .61963 Mdot
.89888 .29198 Mdot
.09334 .87546 Mdot
.87268 .2175 Mdot
.24463 .25221 Mdot
.31858 .55872 Mdot
.97005 .87887 Mdot
.33826 .48353 Mdot
.24236 .9433 Mdot
.82363 .05519 Mdot
.44562 .679 Mdot
.52115 .85663 Mdot
.56684 .53459 Mdot
.04651 .03511 Mdot
.20357 .25267 Mdot
.81733 .42326 Mdot
.42171 .56956 Mdot
.99636 .43265 Mdot
.69235 .05275 Mdot
.78616 .38127 Mdot
.12808 .84309 Mdot
.64313 .80299 Mdot
.14436 .48936 Mdot
.85515 .45963 Mdot
.01974 .52908 Mdot
.26804 .08743 Mdot
.22135 .8253 Mdot
.16075 .01392 Mdot
.28993 .77064 Mdot
.79981 .29603 Mdot
.17664 .25426 Mdot
.33452 .32149 Mdot
.41635 .06162 Mdot
.97507 .99512 Mdot
.86574 .76598 Mdot
.65025 .98912 Mdot
.30602 .13211 Mdot
.96528 .33134 Mdot
.14326 .87968 Mdot
.25049 .85635 Mdot
.3868 .57744 Mdot
.0633 .18784 Mdot
.77564 .81654 Mdot
.34765 .19932 Mdot
.89233 .64768 Mdot
.74279 .59688 Mdot
.66412 .09941 Mdot
.75422 .89242 Mdot
.70535 .30241 Mdot
.1708 .86548 Mdot
.93843 .8874 Mdot
.28746 .71044 Mdot
.15803 .95337 Mdot
.86242 .24372 Mdot
.97681 .54955 Mdot
.05441 .54392 Mdot
.71948 .3978 Mdot
.68633 .48108 Mdot
.73939 .05208 Mdot
.45883 .18296 Mdot
.36075 .07875 Mdot
.00042 .72546 Mdot
.99991 .52142 Mdot
.79244 .53923 Mdot
.43467 .95379 Mdot
.58871 .729 Mdot
.06831 .09493 Mdot
.10008 .7758 Mdot
.96 .08124 Mdot
.92048 .7502 Mdot
.93596 .54885 Mdot
.14292 .9005 Mdot
.0481 .86935 Mdot
.86554 .79868 Mdot
.52057 .00553 Mdot
.11075 .73043 Mdot
.38105 .69469 Mdot
.06947 .3446 Mdot
.85334 .98604 Mdot
.27701 .8221 Mdot
.27381 .50923 Mdot
.97002 .88805 Mdot
.90985 .5146 Mdot
.40756 .29254 Mdot
.56057 .01988 Mdot
.18559 .07087 Mdot
.39815 .65616 Mdot
.26483 .84564 Mdot
.3113 .40711 Mdot
.67252 .80569 Mdot
.14059 .9345 Mdot
.02169 .31582 Mdot
.3556 .88357 Mdot
.57325 .13781 Mdot
.85108 .92156 Mdot
.88509 .23393 Mdot
.99425 .40992 Mdot
.29998 .89334 Mdot
.03879 .23528 Mdot
.44428 .62197 Mdot
.11644 .20664 Mdot
.08816 .19688 Mdot
.43442 .72011 Mdot
.75676 .58981 Mdot
.8104 .18756 Mdot
.7869 .66638 Mdot
.37177 .85879 Mdot
.3219 .93094 Mdot
.02438 .06512 Mdot
.38794 .82285 Mdot
.41227 .04348 Mdot
.49381 .74085 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03?ooool3o`0000?ooooo0_l0000:ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00Co0000ooooool0003o00003?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00cooooo0ol00003ooooo`;o00002_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo0_l00008ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02o`0000Cooooo0_l00005ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool2o`0000kooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool00_ooool001kooooo00?o0000ooooooooool07oooool2o`0007Kooooo0_l0000<ooooo`;o0000
;?ooool2o`0000Cooooo0_l0000Vooooo`;o0000:Oooool2o`0001Wooooo000Nooooo`03o`000?oo
oooooooo06Gooooo0_l0000Gooooo`;o00005oooool2o`0005Oooooo0_l0000hooooo`Co000000?o
ooooo`000?l000003Oooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo033ooooo0_l0000N
ooooo`;o00004oooool2o`0001Oooooo0_l0000Yooooo`;o00006?ooool2o`0002_ooooo0_l0000h
ooooo`;o00000oooool2o`0000gooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`0`oooo
o`;o00004oooool2o`0000Wooooo0_l0001Gooooo`;o00001oooool2o`0000oooooo0_l00022oooo
o`007_ooool00ol0003oooooooooo`0`ooooo`;o00004oooool2o`0006_ooooo0_l0000looooo`;o
0000EOooool001kooooo00?o0000ooooooooool0l?ooool2o`0003oooooo0_l0000Dooooo`007_oo
ool00ol0003oooooooooo`0fooooo`;o0000?oooool2o`0000Kooooo0_l00003ooooo`;o0000J_oo
ool2o`0003oooooo0_l0000Dooooo`007_ooool00ol0003oooooooooo`0Kooooo`;o00006Oooool2
o`0003oooooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo0_l0001Cooooo`;o0000E?ooool3
o`0001Gooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l0000>ooooo`;o00001?ooool2o`00
05Sooooo0_l00018ooooo`;o00004_ooool2o`000003ooooool0003o000000kooooo0_l00011oooo
o`?o00005Oooool001kooooo00?o0000ooooooooool02oooool2o`0001Cooooo0_l0002Rooooo`;o
00005Oooool2o`0000kooooo0_l0001Iooooo`007_ooool00ol0003oooooooooo`1Aooooo`;o0000
5oooool2o`0009gooooo0_l00003ooooo`;o00006?ooool2o`0000Kooooo0_l0000Eooooo`007_oo
ool00ol0003oooooooooo`1Aooooo`;o00005oooool2o`0001Kooooo0_l0000]ooooo`;o0000EOoo
ool3o`0000?ooooo0_l0000:ooooo`;o00003?ooool2o`0000Kooooo0_l0000Eooooo`007_ooool0
0ol0003oooooooooo`22ooooo`;o0000;Oooool2o`0003gooooo0_l0000Fooooo`;o00004?ooool2
o`0002_ooooo000Nooooo`03o`000?oooooooooo0:Cooooo0_l0000dooooo`;o00005?ooool2o`00
02Sooooo0_l0000[ooooo`007_ooool2o`0007kooooo0_l0000Uooooo`;o0000:oooool2o`0000Oo
oooo0_l000000ooooooo0000o`00000=ooooo`;o0000;?ooool2o`0001kooooo0_l0000;ooooo`00
7_ooool00ol0003oooooooooo`1Mooooo`;o00001_ooool2o`0001Kooooo0_l0000@ooooo`;o0000
9_ooool2o`0001Sooooo0_l00005ooooo`;o00000oooool2o`0000gooooo0_l0000?ooooo`;o0000
2Oooool2o`0002Oooooo0_l00006ooooo`?o00002oooool001kooooo00?o0000ooooooooool0GOoo
ool2o`0000Kooooo0_l0000Xooooo`;o00009_ooool2o`0001oooooo0_l0000:ooooo`;o00005ooo
ool2o`0000Wooooo0_l0000Wooooo`;o00001_ooool2o`0000cooooo000Nooooo`03o`000?oooooo
oooo03gooooo0_l00014ooooo`;o0000Goooool2o`0002gooooo0_l0000booooo`007_ooool00ol0
003oooooooooo`04ooooo`;o0000=oooool2o`0002;ooooo0_l0000Pooooo`;o00004_ooool2o`00
04oooooo0_l0000Yooooo`;o0000<_ooool001kooooo00?o0000ooooooooool01?ooool2o`0004Oo
oooo0ol0000Aooooo`;o0000=?ooool2o`0004oooooo0_l0001Mooooo`007_ooool00ol0003ooooo
ooooo`0Cooooo`;o00008oooool2o`0001?ooooo0ol0003gooooo`007_ooool00ol0003ooooooooo
o`0=ooooo`;o00001?ooool2o`0002?ooooo0_l0000Mooooo`;o0000Moooool2o`0003Cooooo0_l0
000oooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o0000B?ooool2o`0007Oooooo0_l0000d
ooooo`;o0000<_ooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo05Wooooo0_l0000Aoooo
o`;o00000oooool2o`0003kooooo0_l0000`ooooo`;o0000;Oooool2o`00023ooooo0_l00002oooo
o`Co00002oooool001kooooo00?o0000ooooooooool0B?ooool2o`0000oooooo0_l0000Aooooo`;o
00000oooool2o`0002Gooooo0_l0000Booooo`;o00000oooool2o`00033ooooo0_l0000]ooooo`;o
00001oooool2o`0001Oooooo0_l00002ooooo`;o00003Oooool001kooooo00?o0000ooooooooool0
B?ooool2o`0000Wooooo0_l00013ooooo`;o00004_ooool2o`0006gooooo0_l0000Zooooo`007_oo
ool00ol0003oooooooooo`1Cooooo`;o0000;?ooool2o`00017ooooo0_l0002Hooooo`;o00005ooo
ool001kooooo00?o0000ooooooooool0;_ooool2o`0000;ooooo0_l0001=ooooo`;o00004Oooool2
o`0009Sooooo0ol0000Fooooo`007_ooool00ol0003oooooooooo`0Booooo`;o00006_ooool2o`00
00;ooooo0_l0000^ooooo`;o00006?ooool2o`0000Sooooo0_l0000Vooooo`;o00001?ooool2o`00
00?ooooo0_l0000Hooooo`;o0000F_ooool2o`0001Kooooo000Nooooo`03o`000?oooooooooo01;o
oooo0_l0001>ooooo`;o00006?ooool2o`0000Sooooo0_l0000Vooooo`;o00001?ooool2o`0000?o
oooo0_l0000Hooooo`?o0000LOooool001kooooo0_l0003Eooooo`;o0000<?ooool2o`0003oooooo
000Nooooo`03o`000?oooooooooo0?oooooo1oooool2o`0003oooooo000Nooooo`03o`000?oooooo
oooo05;ooooo0_l0001Nooooo`;o0000Toooool001kooooo00?o0000ooooooooool0D_ooool2o`00
04cooooo0_l0000@ooooo`;o0000P_ooool2o`0000oooooo000Nooooo`03o`000?oooooooooo043o
oooo0_l0000Iooooo`;o0000@oooool2o`0009Cooooo0_l0000?ooooo`007_ooool3o`0000Gooooo
0_l0000iooooo`;o00001oooool2o`00013ooooo0_l00005ooooo`;o00009?ooool2o`0002oooooo
0_l0000Dooooo`;o00002Oooool2o`0006_ooooo000Nooooo`?o00001Oooool2o`0004;ooooo0_l0
0004ooooo`;o00004Oooool2o`0001Oooooo0_l0000;ooooo`;o00005_ooool2o`0001Oooooo0_l0
000Dooooo`;o00002Oooool2o`0006_ooooo000Nooooo`03o`000?oooooooooo03?ooooo0_l0000J
ooooo`;o000000?oooooo`000?l000009oooool2o`0002?ooooo0_l00028ooooo`;o00006oooool0
01kooooo00?o0000ooooooooool0<oooool2o`0000Oooooo0_l0000Dooooo`;o0000F?ooool2o`00
01Wooooo0_l0000Jooooo`;o0000AOooool2o`0001_ooooo000Nooooo`03o`000?oooooooooo023o
oooo0_l0000Jooooo`;o0000>_ooool2o`0003;ooooo0_l0000Iooooo`;o00003oooool2o`0000Wo
oooo0_l0001Rooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o00001?ooool2o`00017ooooo
0ol0000Sooooo`;o00005oooool2o`0003Kooooo0_l0000Vooooo`;o0000KOooool001kooooo00?o
0000ooooooooool09_ooool2o`00017ooooo0ol0000Sooooo`;o0000Coooool2o`0009Gooooo000N
ooooo`03o`000?oooooooooo0;Kooooo0_l0002?ooooo`007_ooool00ol0003oooooooooo`1;oooo
o`;o0000?_ooool2o`0002Wooooo0_l0002?ooooo`007_ooool3o`0004_ooooo0_l0000nooooo`;o
0000Toooool2o`0001[ooooo0_l00009ooooo`007_ooool3o`000=3ooooo0_l00005ooooo`;o0000
Aoooool2o`0001[ooooo0_l00009ooooo`007_ooool2o`0001Sooooo0_l0001aooooo`;o0000=ooo
ool2o`0000_ooooo0_l00005ooooo`;o0000K_ooool001kooooo00?o0000ooooooooool05oooool2
o`00043ooooo0_l0000_ooooo`;o0000:_ooool2o`0000_ooooo0_l00022ooooo`007_ooool00ol0
003oooooooooo`1Iooooo`;o00009Oooool2o`0000Oooooo0_l0000[ooooo`;o0000B?ooool2o`00
00oooooo0_l0000dooooo`007Oooool2o`0004_ooooo0_l0000eooooo`;o00001oooool2o`0001[o
oooo0_l00008ooooo`;o0000Coooool2o`0000oooooo0_l00003ooooo`;o0000;oooool001gooooo
0_l0001;ooooo`;o0000A_ooool2o`0001;ooooo0_l00008ooooo`;o0000IOooool2o`0002oooooo
000Nooooo`03o`000?oooooooooo03Oooooo0_l0001Fooooo`Co0000Zoooool2o`0000Oooooo000N
ooooo`03o`000?oooooooooo03Oooooo0_l0000Aooooo`;o0000<Oooool2o`00013ooooo0_l0000:
ooooo`;o0000?oooool2o`0002;ooooo0_l0000looooo`;o00001oooool001kooooo00?o0000oooo
ooooool0@_ooool2o`0000Kooooo0_l0000Booooo`;o00006_ooool2o`000003ooooool0003o0000
01cooooo0_l0000oooooo`;o00008_ooool2o`00027ooooo0_l0000Rooooo`007_ooool00ol0003o
ooooooooo`12ooooo`;o00006_ooool2o`0001[ooooo0_l0002Wooooo`;o00008_ooool001kooooo
00?o0000ooooooooool07oooool2o`0007[ooooo0_l0000<ooooo`;o0000W?ooool001kooooo00?o
0000ooooooooool04Oooool2o`0000cooooo0_l0001jooooo`;o00003?ooool2o`0009cooooo000N
ooooo`03o`000?oooooooooo017ooooo0_l0001nooooo`;o0000]?ooool001kooooo00?o0000oooo
ooooool04?ooool2o`0003cooooo0_l0000Nooooo`;o00008Oooool2o`00073ooooo0_l00012oooo
o`007_ooool00ol0003oooooooooo`0@ooooo`;o0000??ooool2o`0001kooooo0_l0001Vooooo`;o
0000:oooool2o`0000;ooooo0_l0000nooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`03ooooo`;o0000??ooool2o`0009?o
oooo0_l0000_ooooo`;o00007_ooool2o`0001kooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo
00?ooooo0_l00004ooooo`;o00003_ooool2o`0002Kooooo0_l0001hooooo`;o0000Goooool2o`00
00Wooooo0_l0000Nooooo`000oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q
8Oo^k^h01oooool3o`0000Wooooo0_l0000>ooooo`;o0000D_ooool2o`0004cooooo0_l0000hoooo
o`;o00009Oooool2o`0002Wooooo0003ooooo`05o`000?ooooooooooooooool000003Oooool00onH
V9So8B4Qonk^kP06ooooo`03o`000?oooooooooo03Sooooo0_l0000Iooooo`;o00005_ooool4o`00
06?ooooo0_l0000Qooooo`;o0000@_ooool2o`0000cooooo0003ooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo02;ooooo0_l0000Doooo
o`;o00006Oooool2o`0001Kooooo0_l0001Uooooo`;o00004oooool4o`0004kooooo0_l0000<oooo
o`000oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Rooooo`;o0000@oooool2o`0003?ooooo0_l00019ooooo`Co00008Oooool2o`00
03Wooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@00Kooooo00?o0000ooooooooool0<_ooool2o`0003?ooooo0_l0000cooooo`;o0000AOooool2
o`0002Oooooo0_l0000iooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c006ooooo`?o0000<_ooool2o`0003cooooo0_l00008ooooo`;o0000Iooo
ool2o`0002Wooooo0_l0000[ooooo`;o00002_ooool001kooooo0ol0000Wooooo`;o00002?ooool2
o`0002kooooo0_l0000=ooooo`;o00002?ooool2o`0009;ooooo0_l00008ooooo`;o00008Oooool2
o`0000[ooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l00008ooooo`;o00004Oooool2o`00
01_ooooo0_l0000/ooooo`;o0000E?ooool2o`0001Oooooo0_l0000Hooooo`;o00005?ooool2o`00
01Oooooo000Nooooo`03o`000?oooooooooo04Cooooo0_l00019ooooo`;o00008_ooool2o`00033o
oooo0_l0000Gooooo`;o00003oooool2o`0001gooooo0_l0000Gooooo`007Oooool2o`0003Wooooo
0_l000000ooooooo0000o`00000Eooooo`;o0000H?ooool2o`0005[ooooo0_l0000fooooo`007Ooo
ool2o`0003Wooooo0_l000000ooooooo0000o`00000Eooooo`;o0000F?ooool2o`0006[ooooo0_l0
000^ooooo`007_ooool00ol0003oooooooooo`0Kooooo`;o0000@_ooool2o`0004[ooooo0_l0001Z
ooooo`;o00000oooool2o`0002Wooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0000Aoooo
o`;o0000@_ooool2o`000;_ooooo0_l0000Yooooo`007_ooool00ol0003oooooooooo`08ooooo`;o
0000@?ooool2o`000;3ooooo0_l00012ooooo`;o00001Oooool001kooooo00?o0000ooooooooool0
2oooool2o`0003gooooo0_l0002`ooooo`;o00005_ooool2o`0002[ooooo0_l00005ooooo`007_oo
ool00ol0003oooooooooo`0;ooooo`;o00009_ooool2o`0000Kooooo0_l0002_ooooo`;o00009_oo
ool2o`0001Cooooo0_l0000Kooooo`007_ooool00ol0003oooooooooo`0cooooo`;o00001_ooool2
o`0005_ooooo0_l0001Booooo`;o0000<_ooool2o`0000Sooooo1?l0000Iooooo`007_ooool2o`00
01Kooooo0_l0000Wooooo`;o00002oooool2o`0002Cooooo0_l0000Uooooo`;o0000Q_ooool2o`00
00[ooooo0_l0000Iooooo`007_ooool00ol0003oooooooooo`07ooooo`;o00003?ooool2o`0001ko
oooo0_l00007ooooo`;o00002oooool2o`0002Cooooo0_l0001=ooooo`;o0000QOooool001kooooo
00?o0000ooooooooool01oooool2o`0000Kooooo0_l0000Tooooo`;o0000>oooool2o`0004cooooo
0_l00025ooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o00004_ooool2o`0004gooooo0_l0
001^ooooo`;o0000:Oooool2o`0000cooooo0_l0000:ooooo`;o00007_ooool001kooooo00?o0000
ooooooooool08oooool2o`0000;ooooo0_l0000<ooooo`;o00009_ooool2o`0002oooooo0_l0001B
ooooo`;o0000:Oooool2o`0000?ooooo0_l00007ooooo`;o00002_ooool2o`0001kooooo000Noooo
o`03o`000?oooooooooo02Oooooo0_l0000<ooooo`;o00009_ooool2o`0002oooooo0_l0000:oooo
o`;o0000M_ooool2o`0001kooooo0_l0000Cooooo`007_ooool00ol0003oooooooooo`2Jooooo`;o
0000U_ooool2o`0000Oooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`3@ooooo`;o0000
JOooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l0001<ooooo`;o0000G?oo
ool2o`0006cooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`0Tooooo`;o0000C?ooool2
o`0003Wooooo0_l0002?ooooo`;o00001oooool001kooooo00?o0000ooooooooool05_ooool2o`00
0003ooooool0003o000000Sooooo0_l00028ooooo`;o0000V?ooool001kooooo00?o0000oooooooo
ool05_ooool2o`000003ooooool0003o000000Sooooo0_l0001Gooooo`;o00006_ooool2o`00023o
oooo0_l0000`ooooo`;o0000FOooool001kooooo00?o0000ooooooooool0O?ooool2o`0001[ooooo
0_l0000Looooo`;o00000_ooool2o`0001gooooo0_l0000Aooooo`;o0000FOooool001kooooo00?o
0000ooooooooool0:oooool2o`0005?ooooo0_l0000dooooo`;o00008Oooool2o`0000_ooooo0_l0
000hooooo`;o00007_ooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo02_ooooo0_l0000n
ooooo`;o000000?oooooo`000?l000004?ooool2o`0006Cooooo0_l0000Hooooo`;o00007_ooool2
o`0000_ooooo0_l0000Aooooo`;o00001Oooool001kooooo00?o0000ooooooooool0:?ooool2o`00
047ooooo0_l000000ooooooo0000o`00002@ooooo`;o00003Oooool2o`0001cooooo0_l0000Hoooo
o`007_ooool2o`0001Kooooo0_l0000Aooooo`;o00009oooool2o`0002_ooooo0_l0000gooooo`;o
0000:?ooool2o`0002_ooooo0ol0000Nooooo`;o00005_ooool001kooooo00?o0000ooooooooool0
5Oooool2o`0003[ooooo0_l0000[ooooo`;o0000=oooool2o`0002Sooooo0_l0000[ooooo`;o0000
7oooool2o`0000Gooooo0_l0000?ooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o0000<?oo
ool2o`000>kooooo0_l0000?ooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o00000_ooool2
o`00033ooooo0_l0002Qooooo`;o0000G?ooool001kooooo00?o0000ooooooooool04?ooool2o`00
07Cooooo0_l0001Qooooo`;o0000G?ooool001kooooo00?o0000ooooooooool00oooool2o`0000oo
oooo0_l0001`ooooo`;o0000R?ooool2o`0000Oooooo0_l00005ooooo`;o00009Oooool001kooooo
00?o0000ooooooooool00oooool2o`0000oooooo0_l00018ooooo`;o00006Oooool2o`0009Gooooo
0_l00007ooooo`;o00001Oooool2o`0002Gooooo000Nooooo`03o`000?oooooooooo05kooooo0_l0
0009ooooo`;o00003_ooool2o`000<cooooo000Nooooo`03o`000?oooooooooo05oooooo0_l00008
ooooo`;o0000>_ooool2o`000:3ooooo000Nooooo`03o`000?oooooooooo05oooooo0_l00014oooo
o`;o0000X?ooool001kooooo00?o0000ooooooooool0Ooooool2o`000:cooooo0_l00007ooooo`;o
00003oooool001kooooo00?o0000ooooooooool06_ooool2o`0006?ooooo0_l00006ooooo`;o0000
Y?ooool2o`0000Oooooo0_l00008ooooo`;o00001Oooool001gooooo0_l0000Looooo`;o00005Ooo
ool2o`0005Cooooo0_l0002;ooooo`;o0000:_ooool2o`0000Gooooo000Mooooo`;o0000<oooool2
o`000>7ooooo0_l0000aooooo`007_ooool00ol0003oooooooooo`0Booooo`;o0000=_ooool2o`00
00?ooooo0_l0000Kooooo`;o0000C_ooool2o`0000Wooooo0_l0001nooooo`007_ooool00ol0003o
ooooooooo`0Booooo`;o0000=_ooool2o`0000?ooooo0_l0000Kooooo`;o0000C_ooool2o`0000Wo
oooo0_l0000Aooooo`;o0000Joooool001kooooo0_l0000=ooooo`;o0000P?ooool2o`0004[ooooo
0_l0001[ooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o00001Oooool2o`0000Cooooo0_l0
000Hooooo`;o0000;Oooool2o`0001Cooooo0_l0000Dooooo`;o0000Y_ooool2o`0000oooooo000N
ooooo`03o`000?oooooooooo01?ooooo0_l00004ooooo`;o00006?ooool2o`0002gooooo0_l00007
ooooo`;o00002oooool2o`000;cooooo0_l0000?ooooo`007_ooool00ol0003oooooooooo`0Aoooo
o`;o0000F?ooool2o`000=?ooooo0_l00005ooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o
0000:oooool2o`000:[ooooo0_l0000booooo`;o00008?ooool2o`0000Gooooo000Nooooo`03o`00
0?oooooooooo02Gooooo0_l00003ooooo`;o00004_ooool2o`00017ooooo0_l0002Gooooo`;o0000
<_ooool2o`0002Oooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0000Aooooo`;o00000ooo
ool2o`0001;ooooo0_l0000Aooooo`;o0000m?ooool001kooooo00?o0000ooooooooool04_ooool2
o`0002[ooooo0_l0003oooooo`Sooooo000Nooooo`03o`000?oooooooooo0?oooooo4oooool2o`00
02[ooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`3ooooooa?ooooo0_l0000Zooooo`;o
00001oooool001kooooo00?o0000ooooooooool04Oooool2o`0000[ooooo0_l0000cooooo`;o0000
Roooool2o`0001[ooooo0_l0001:ooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o00002_oo
ool2o`0000Gooooo0_l0000/ooooo`;o0000Noooool2o`0000kooooo0_l0000Jooooo`;o0000B_oo
ool001kooooo00?o0000ooooooooool09?ooool2o`0002_ooooo0_l0001@ooooo`;o0000:_ooool2
o`0002gooooo0_l00017ooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o00009Oooool2o`00
01Sooooo0_l0000;ooooo`;o0000;?ooool2o`0001Gooooo0_l0001Iooooo`;o0000Aoooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo
00Cooooo00?o0000ooooooooool04?ooool2o`0002Gooooo0_l0000Uooooo`;o0000;?ooool2o`00
0;Wooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`3Vooooo`;o0000Goooool000?ooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go00001_ooool3o`00017ooooo0_l0003Cooooo`;o0000Goooool000?o
oooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000
ooooooooool04Oooool2o`0002cooooo0_l0000?ooooo`;o0000_oooool2o`0003Cooooo0003oooo
o`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oo
oooooooo03oooooo0_l0000?ooooo`;o00003Oooool4o`00017ooooo0_l0002Kooooo`;o0000=?oo
ool000?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o
0000ooooooooool0<Oooool2o`0000kooooo0_l0000Looooo`Co00004Oooool2o`000<Wooooo0_l0
0006ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001ooo
ool00ol0003oooooooooo`0Eooooo`;o00002oooool2o`0000gooooo0_l0000>ooooo`;o0000>Ooo
ool2o`000<7ooooo0_l00006ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?o
MgMgo`000?ooool01_ooool00ol0003oooooooooo`0Eooooo`;o00002oooool2o`0001[ooooo0_l0
000looooo`;o00007?ooool2o`00073ooooo0_l0000iooooo`007_ooool00ol0003oooooooooo`0l
ooooo`Co0000C?ooool2o`0000cooooo0_l0001/ooooo`;o00000_ooool2o`0003Wooooo000Noooo
o`03o`000?oooooooooo03cooooo0ol0001=ooooo`;o0000E?ooool2o`0002Cooooo0_l0000Woooo
o`;o00005?ooool001kooooo00?o0000ooooooooool00_l0000?ooooo`;o000000?oooooo`000?l0
00009oooool2o`0001?ooooo0_l0002>ooooo`;o00002oooool2o`0001Gooooo0_l0000Yooooo`;o
00005?ooool001kooooo00?o0000ooooooooool00_l0000?ooooo`;o000000?oooooo`000?l00000
9oooool2o`0001?ooooo0_l0000?ooooo`;o0000OOooool2o`0000_ooooo0_l0000Eooooo`;o0000
?oooool001kooooo00?o0000ooooooooool02Oooool2o`0005Sooooo0_l0000;ooooo`;o0000=ooo
ool2o`00013ooooo0_l0001?ooooo`;o0000>Oooool001kooooo00?o0000ooooooooool02Oooool2
o`0001;ooooo0_l0001Aooooo`;o0000;oooool2o`0000Kooooo0_l0000@ooooo`;o0000Coooool2
o`0003;ooooo0_l00005ooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o0000P_ooool2o`00
00Sooooo0_l00002ooooo`;o0000Soooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo0:3o
oooo0_l00009ooooo`;o00000_ooool2o`0009Kooooo000Nooooo`03o`000?oooooooooo04Wooooo
0_l0000;ooooo`;o00003?ooool2o`0003[ooooo0_l0000Rooooo`;o0000<_ooool2o`0004gooooo
000Nooooo`03o`000?oooooooooo04Wooooo0_l0000;ooooo`;o00003?ooool2o`0001gooooo0_l0
000/ooooo`;o00004Oooool2o`0003;ooooo0ol0001<ooooo`007_ooool00ol0003oooooooooo`0h
ooooo`;o00000_ooool2o`0000Cooooo0_l0000Hooooo`;o00009Oooool2o`0002cooooo0_l00016
ooooo`;o0000C?ooool001kooooo0_l00008ooooo`;o00003?ooool2o`00027ooooo0_l00002oooo
o`;o00001?ooool2o`0001Sooooo0_l0000Wooooo`;o0000`?ooool001kooooo00?o0000oooooooo
ool01oooool2o`0000cooooo0_l0001^ooooo`;o0000FOooool2o`0006Gooooo000Nooooo`03o`00
0?oooooooooo0>3ooooo0_l0000`ooooo`;o00004Oooool2o`00023ooooo000Nooooo`03o`000?oo
oooooooo05gooooo0_l0000_ooooo`;o0000P_ooool2o`0000[ooooo0_l00005ooooo`;o00008?oo
ool001kooooo00?o0000ooooooooool0=_ooool2o`0002Gooooo0_l0000_ooooo`;o000000?ooooo
o`000?l00000Roooool2o`0002Oooooo000Nooooo`03o`000?oooooooooo02oooooo0_l00005oooo
o`;o0000FOooool3o`000;?ooooo000Nooooo`03o`000?oooooooooo02oooooo0_l0000?ooooo`;o
0000@oooool2o`0000_ooooo0_l0000=ooooo`;o0000=_ooool2o`0006cooooo000Nooooo`03o`00
0?oooooooooo00oooooo0_l0000_ooooo`;o0000;oooool2o`0001;ooooo0_l00009ooooo`;o0000
3oooool2o`0002cooooo0_l00008ooooo`;o0000;?ooool2o`0003;ooooo0_l0000:ooooo`007_oo
ool00ol0003oooooooooo`06ooooo`;o00001oooool2o`0000oooooo0_l0000Yooooo`;o00009?oo
ool2o`0001gooooo0_l0000mooooo`;o0000<_ooool2o`0000;ooooo0ol0000aooooo`;o00002_oo
ool001kooooo00?o0000ooooooooool01_ooool2o`0000oooooo0_l00007ooooo`;o0000:Oooool2
o`0002;ooooo0_l0001Zooooo`;o00009_ooool2o`0000?ooooo0_l0000Sooooo`;o00006?ooool0
01kooooo00?o0000ooooooooool01?ooool2o`00017ooooo0_l0001Aooooo`;o00000oooool2o`00
06[ooooo0_l0001@ooooo`;o00006?ooool001kooooo00?o0000ooooooooool01?ooool2o`0000Co
oooo0_l0000`ooooo`;o0000;?ooool2o`000=_ooooo000Nooooo`03o`000?oooooooooo00[ooooo
0_l0000Fooooo`;o00001oooool2o`0000oooooo0_l0000nooooo`;o00001Oooool2o`0007cooooo
0_l00014ooooo`007_ooool00ol0003oooooooooo`0Rooooo`;o00001oooool2o`0000_ooooo0_l0
0012ooooo`;o00001Oooool2o`0007cooooo0_l0000>ooooo`;o0000:Oooool2o`0000Wooooo000N
ooooo`04o`000?oooooo0000o`0003Oooooo0_l0003Gooooo`;o0000:Oooool2o`0000Wooooo000N
ooooo`04o`000?oooooo0000o`000?ooooooAoooool001kooooo0_l0003ooooooagooooo0ol0000Y
ooooo`007_ooool00ol0003oooooooooo`1Oooooo`;o0000IOooool2o`0005?ooooo0ol0000>oooo
o`;o00006Oooool001kooooo00Co0000ooooool0003o0000E?ooool2o`0000Sooooo0ol0000Koooo
o`;o00002?ooool2o`00027ooooo0_l0000Jooooo`;o00003_ooool2o`0005?ooooo0ol0000Ioooo
o`007_ooool01?l0003oooooo`000?l0001Dooooo`;o00002Oooool2o`0001_ooooo0_l00008oooo
o`;o00008Oooool2o`0002[ooooo0_l0000kooooo`;o00005_ooool2o`0001[ooooo000Nooooo`03
o`000?oooooooooo05Gooooo0_l0002looooo`;o00003oooool2o`00027ooooo000Nooooo`03o`00
0?oooooooooo05cooooo0_l0001dooooo`;o0000D?ooool2o`00027ooooo000Nooooo`03o`000?oo
oooooooo03Oooooo0_l0000Sooooo`;o0000M?ooool2o`0001oooooo0_l0001Booooo`007_ooool0
0ol0003oooooooooo`0gooooo`;o00008?ooool2o`0001kooooo0_l0001hooooo`;o0000;?ooool2
o`0000Kooooo0_l0000Fooooo`;o00001?ooool001kooooo00?o0000ooooooooool0FOooool2o`00
01kooooo0_l0002Vooooo`;o00001_ooool2o`0001Kooooo0_l00004ooooo`007_ooool00ol0003o
ooooooooo`02ooooo`;o0000/_ooool2o`00083ooooo0_l0000=ooooo`007_ooool00ol0003ooooo
ooooo`02ooooo`;o0000Eoooool2o`0005Wooooo0_l00020ooooo`;o00003Oooool001kooooo00?o
0000ooooooooool07_ooool2o`0001[ooooo0_l0000Oooooo`;o0000;_ooool2o`0002Oooooo0_l0
0009ooooo`;o0000Q_ooool001kooooo00?o0000ooooooooool07_ooool4o`0001Sooooo0_l00011
ooooo`;o00003?ooool2o`0002Oooooo0_l00009ooooo`;o0000?Oooool2o`0004Oooooo000Noooo
o`03o`000?oooooooooo023ooooo1?l0000Mooooo`;o0000>_ooool2o`0007oooooo0_l00017oooo
o`007_ooool00ol0003oooooooooo`0>ooooo`;o00004_ooool2o`0001gooooo0_l0003oooooo`Go
oooo000Nooooo`03o`000?oooooooooo00kooooo0_l0000:ooooo`;o0000A?ooool2o`000;Gooooo
0_l00003ooooo`;o00003_ooool2o`0001Wooooo000Nooooo`;o00006oooool2o`0003Sooooo0_l0
000:ooooo`;o0000]Oooool2o`0000?ooooo0_l0000>ooooo`;o00002oooool2o`0000cooooo000N
ooooo`03o`000?oooooooooo01oooooo0_l0000cooooo`;o0000cOooool2o`0001Cooooo0_l0000<
ooooo`007_ooool00ol0003oooooooooo`0Nooooo`?o0000ooooool3ooooo`;o00008_ooool001ko
oooo00?o0000ooooooooool07_ooool2o`0004?ooooo0_l00005ooooo`;o00007_ooool2o`000003
ooooool0003o0000017ooooo0_l0001Eooooo`;o00000oooool2o`0004Wooooo000Nooooo`03o`00
0?oooooooooo03;ooooo0_l0000_ooooo`;o00001Oooool2o`0001kooooo0_l000000ooooooo0000
o`00000Aooooo`Co00006_ooool2o`0003Oooooo0_l00003ooooo`;o0000BOooool001kooooo00?o
0000ooooooooool0<_ooool2o`0002;ooooo0_l0001:ooooo`;o00006_ooool2o`0001?ooooo0_l0
001Wooooo`;o00002Oooool001kooooo00?o0000ooooooooool08oooool2o`00037ooooo0_l0000]
ooooo`;o0000C?ooool2o`0002_ooooo0_l0000jooooo`;o00002Oooool001kooooo00?o0000oooo
ooooool08oooool2o`0004kooooo0_l0000@ooooo`;o0000EOooool2o`0002;ooooo0_l00015oooo
o`007_ooool00ol0003oooooooooo`1cooooo`;o00000oooool2o`00037ooooo0_l0000_ooooo`;o
0000JOooool001kooooo00?o0000ooooooooool0Loooool2o`0000?ooooo1?l0000_ooooo`;o0000
V_ooool001kooooo00?o0000ooooooooool05_ooool2o`0004Cooooo0_l0000Eooooo`;o00001Ooo
ool2o`0008[ooooo0_l0000oooooo`007_ooool00ol0003oooooooooo`0Fooooo`;o0000A?ooool2
o`0000cooooo0_l00018ooooo`;o0000D?ooool2o`0003oooooo000Nooooo`03o`000?oooooooooo
06[ooooo0_l0000booooo`;o00005?ooool2o`0002cooooo0_l0001Sooooo`007_ooool00ol0003o
ooooooooo`11ooooo`;o00003_ooool2o`0004_ooooo0_l00012ooooo`;o00003_ooool2o`0001oo
oooo0_l0000Wooooo`;o00002Oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0@Oooool2o`00
00kooooo0_l0001Xooooo`;o0000=Oooool2o`0001oooooo0_l0000Wooooo`;o00002Oooool000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So
8B4Q00Kooooo00?o0000ooooooooool0^oooool2o`00033ooooo0_l0000`ooooo`;o00009_ooool0
00?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_oo
ool3o`0008kooooo0_l0001Mooooo`;o0000<?ooool2o`0000;ooooo0_l0000Rooooo`000oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`03o`00
0?oooooooooo04oooooo0_l0000mooooo`;o00002?ooool2o`0008Wooooo0_l0000Rooooo`000ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03
o`000?oooooooooo03Wooooo0_l0000Dooooo`;o0000=oooool2o`0000kooooo0_l0000Oooooo`;o
00001?ooool2o`0000?ooooo0_l00021ooooo`000oooool01Ol@413ooooooooooooooooo410@00_o
oooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`0iooooo`;o0000COooool2o`0002Wo
oooo0_l00004ooooo`;o00001?ooool2o`0000?ooooo0_l00021ooooo`000oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0Jooooo`;o
0000Uoooool2o`0000oooooo0_l00021ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`0Jooooo`;o0000Z?ooool2o`00
02;ooooo0_l0001<ooooo`;o000000?oooooo`000?l000003?ooool001kooooo00?o0000oooooooo
ool0L_ooool2o`0001Cooooo0_l0001Nooooo`;o0000C?ooool2o`000003ooooool0003o000000co
oooo000Nooooo`03o`000?oooooooooo00_ooooo0_l0001<ooooo`;o00005oooool2o`0001Cooooo
0_l00002ooooo`;o0000O?ooool2o`0000?ooooo0_l0000Looooo`;o00002Oooool2o`0000gooooo
000Nooooo`03o`000?oooooooooo00;ooooo0_l00007ooooo`;o00007Oooool2o`0002gooooo0_l0
000aooooo`;o0000O?ooool2o`0000?ooooo0_l0000Looooo`;o00002Oooool2o`0000gooooo000N
ooooo`03o`000?oooooooooo00;ooooo0_l0000Vooooo`;o0000Qoooool2o`0007kooooo0_l0000B
ooooo`007_ooool00ol0003oooooooooo`0mooooo`;o00005_ooool2o`0000Oooooo0_l0000Foooo
o`;o00004_ooool3o`0002Kooooo0_l0001nooooo`;o00004_ooool001kooooo00?o0000oooooooo
ool05Oooool2o`0002Kooooo0_l0000@ooooo`;o00001?ooool2o`0000Oooooo0_l0000Fooooo`;o
00004_ooool3o`0001Sooooo0_l0001booooo`;o0000;?ooool001kooooo00?o0000ooooooooool0
5Oooool2o`000003ooooool0003o000003Gooooo0_l0001Dooooo`;o0000L_ooool2o`0002cooooo
000Nooooo`03o`000?oooooooooo01Sooooo0_l00007ooooo`;o0000cOooool2o`0001Sooooo0_l0
000@ooooo`;o0000:Oooool001kooooo00?o0000ooooooooool06?ooool2o`0000Oooooo0_l0001;
ooooo`;o0000<oooool2o`0002kooooo0_l0000Kooooo`?o00005oooool2o`00013ooooo0_l0000Y
ooooo`007_ooool00ol0003oooooooooo`1Wooooo`;o00001Oooool2o`0003?ooooo0_l0000^oooo
o`;o00007?ooool2o`0005Cooooo000Nooooo`03o`000?oooooooooo04[ooooo0_l0000Kooooo`;o
0000]Oooool2o`0002Oooooo000Nooooo`;o0000Boooool2o`00023ooooo0_l0001^ooooo`;o0000
8oooool4o`0001Wooooo0_l0000Wooooo`007_ooool00ol0003oooooooooo`1>ooooo`;o00007?oo
ool2o`0000oooooo0_l0000Vooooo`;o00001?ooool2o`0002oooooo0_l00007ooooo`;o00006_oo
ool4o`0004;ooooo000Nooooo`03o`000?oooooooooo04kooooo0_l00007ooooo`;o00008Oooool2
o`000003ooooool0003o000002Kooooo0_l00004ooooo`;o0000>?ooool2o`00063ooooo000Noooo
o`03o`000?oooooooooo03gooooo0_l0000Hooooo`;o00008Oooool2o`000<_ooooo000Nooooo`?o
0000?Oooool2o`00043ooooo0_l0000kooooo`;o0000ROooool001kooooo0ol0000looooo`;o0000
6Oooool2o`0002Kooooo0_l0000kooooo`Co0000??ooool2o`0003[ooooo0_l0000=ooooo`007_oo
ool00ol0003oooooooooo`0looooo`;o00002_ooool2o`0000gooooo0_l00018ooooo`;o00006ooo
ool2o`0003cooooo0_l0000Nooooo`;o00006_ooool2o`0000gooooo000Nooooo`03o`000?oooooo
oooo00;ooooo0_l00014ooooo`;o0000Eoooool2o`0000Gooooo0_l0001booooo`;o0000:Oooool0
01kooooo00?o0000ooooooooool00_ooool2o`0002Kooooo0_l0001looooo`;o0000WOooool001ko
oooo00?o0000ooooooooool0:_ooool2o`00067ooooo0_l0000Qooooo`;o00008oooool2o`0004[o
oooo0_l0000?ooooo`;o00004oooool001kooooo00?o0000ooooooooool0SOooool2o`00027ooooo
0_l0000Sooooo`?o0000;?ooool2o`0001_ooooo0_l00007ooooo`;o00001_ooool2o`0001?ooooo
000Nooooo`03o`000?oooooooooo00Cooooo0_l0000>ooooo`;o0000VOooool2o`0002;ooooo0_l0
00000ooooooo0000o`00000/ooooo`;o00009?ooool2o`0001_ooooo000Nooooo`03o`000?oooooo
oooo00Cooooo0_l0000>ooooo`;o0000VOooool2o`0002;ooooo0_l0000Xooooo`;o00004Oooool2
o`0003Gooooo000Nooooo`03o`000?oooooooooo05_ooooo0ol0000_ooooo`;o0000K_ooool2o`00
017ooooo0_l0000eooooo`007_ooool00ol0003oooooooooo`09ooooo`;o00002Oooool2o`0002co
oooo0_l0000Gooooo`?o00001oooool2o`00017ooooo0_l0000Cooooo`;o0000=oooool2o`0002So
oooo0_l0000iooooo`;o00006_ooool001kooooo00?o0000ooooooooool02Oooool2o`0000Wooooo
0_l0000<ooooo`;o00002Oooool2o`0001?ooooo0_l0000Qooooo`;o00004Oooool2o`0003Wooooo
0_l0000Aooooo`;o00007Oooool2o`0000Wooooo0_l0000dooooo`;o00000oooool2o`0001[ooooo
000Nooooo`;o00007oooool2o`0000;ooooo0_l00003ooooo`;o00001?ooool2o`00047ooooo0_l0
0011ooooo`;o0000<?ooool2o`0001oooooo0_l0000Looooo`Co00007oooool001kooooo00?o0000
ooooooooool07_ooool2o`0000Oooooo0_l0000Jooooo`;o00009oooool2o`0000;ooooo0_l0000[
ooooo`;o0000Ioooool2o`0001cooooo0_l0000Qooooo`007_ooool00ol0003oooooooooo`13oooo
o`;o00008_ooool2o`0000?ooooo0_l0000_ooooo`;o0000Z?ooool001kooooo00?o0000oooooooo
ool0FOooool2o`0000cooooo0_l0000Pooooo`;o00004?ooool2o`000:[ooooo000Nooooo`03o`00
0?oooooooooo013ooooo0_l0000Tooooo`;o00008Oooool2o`0002kooooo0_l00004ooooo`;o0000
2_ooool2o`0002Oooooo0_l0000<ooooo`;o0000D_ooool3o`0000kooooo0_l0000>ooooo`007_oo
ool00ol0003oooooooooo`0@ooooo`;o00002?ooool2o`0000_ooooo0_l0000=ooooo`;o00003Ooo
ool2o`0002Sooooo0_l0000Nooooo`;o0000<oooool2o`0000Cooooo0_l00006ooooo`;o0000D_oo
ool3o`0000kooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`03ooooo`;o00005Oooool2
o`0000_ooooo0_l0000Looooo`;o0000:?ooool2o`0001Sooooo0_l0000oooooo`;o0000:Oooool2
o`0001kooooo0_l00008ooooo`;o00009_ooool001kooooo00?o0000ooooooooool00oooool2o`00
08Cooooo0_l00015ooooo`;o00008oooool2o`0000_ooooo0_l0000Aooooo`;o00002?ooool2o`00
02Kooooo000Mooooo`;o0000K_ooool2o`0006;ooooo0_l0000`ooooo`;o00005?ooool2o`0002go
oooo000Mooooo`;o0000BOooool2o`000003ooooool0003o0000023ooooo0_l0001=ooooo`;o0000
3?ooool2o`00027ooooo0_l0000Zooooo`;o0000;Oooool001kooooo00?o0000ooooooooool08?oo
ool2o`0002Gooooo0_l000000ooooooo0000o`00000oooooo`;o0000;_ooool2o`0000cooooo0_l0
000Qooooo`;o0000FOooool001kooooo00?o0000ooooooooool04Oooool2o`0000gooooo0_l0001Y
ooooo`;o0000JOooool2o`00033ooooo0_l0000Mooooo`007_ooool00ol0003oooooooooo`0Aoooo
o`;o0000Koooool2o`00013ooooo0_l00003ooooo`;o0000C_ooool2o`0000_ooooo0_l0000Loooo
o`;o00004_ooool2o`0001gooooo000Nooooo`03o`000?oooooooooo08;ooooo0_l0000=ooooo`;o
000000?oooooo`000?l000000oooool2o`000004ooooool0003o0000ooooo`;o0000B?ooool2o`00
02Wooooo0_l0000aooooo`007_ooool00ol0003oooooooooo`2Aooooo`;o00002Oooool2o`000003
ooooool0003o00000:Kooooo000Nooooo`03o`000?oooooooooo04Oooooo0_l0001Tooooo`;o0000
7?ooool2o`0003Oooooo0_l0000Dooooo`;o0000:oooool001kooooo0_l00018ooooo`;o0000:Ooo
ool2o`0001;ooooo0_l0000Uooooo`;o00007?ooool2o`0001Sooooo0_l0000Mooooo`;o00005?oo
ool2o`0000_ooooo0_l0000Nooooo`007_ooool00ol0003oooooooooo`1Eooooo`;o00006oooool2
o`0001;ooooo0_l0001Mooooo`;o0000@?ooool2o`0000;ooooo0_l0000<ooooo`;o00003?ooool0
01kooooo00?o0000ooooooooool08?ooool2o`0003?ooooo0_l00004ooooo`;o0000c_ooool2o`00
00cooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o00005?ooool2o`0002?o
oooo0_l0003Zooooo`007_ooool00ol0003oooooooooo`0fooooo`;o0000;?ooool2o`0002Gooooo
0_l00012ooooo`;o0000>Oooool2o`0002Oooooo0_l0000Booooo`007_ooool00ol0003ooooooooo
o`0`ooooo`;o0000<?ooool4o`0000[ooooo0_l0000Iooooo`;o0000@_ooool2o`0002Sooooo0_l0
000?ooooo`;o00002Oooool2o`0001cooooo0_l00007ooooo`;o00002Oooool001kooooo00?o0000
ooooooooool0<?ooool2o`00033ooooo0_l0000<ooooo`;o00001?ooool2o`00087ooooo0_l0000J
ooooo`;o00006oooool2o`0000Sooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`1Joooo
o`;o00006_ooool2o`0003gooooo0_l0001Yooooo`;o00002?ooool2o`0000Kooooo0_l0000Coooo
o`007_ooool00ol0003oooooooooo`0Looooo`;o0000??ooool2o`0002gooooo0_l0000Zooooo`;o
0000A_ooool2o`00027ooooo0_l00008ooooo`;o00006oooool001kooooo00?o0000ooooooooool0
7?ooool2o`00063ooooo0_l00007ooooo`Co0000<_ooool2o`0002[ooooo0_l0000Booooo`;o0000
B?ooool001kooooo00?o0000ooooooooool00_ooool2o`0002kooooo0_l0001:ooooo`;o00001ooo
ool2o`0000Gooooo0_l00002ooooo`;o0000:Oooool2o`0002[ooooo0_l00006ooooo`;o0000;Ooo
ool2o`0002Gooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0000Looooo`;o00004?ooool2
o`0001Kooooo0_l00005ooooo`;o0000>oooool2o`0000;ooooo0_l0001Mooooo`;o00005?ooool2
o`0001Oooooo0_l0000:ooooo`;o00006Oooool001kooooo00?o0000ooooooooool08?ooool2o`00
02?ooooo0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o00000:cooooo0_l00006oooo
o`Co00008Oooool2o`0001Wooooo000Nooooo`03o`000?oooooooooo04Gooooo0_l00007ooooo`;o
0000Q?ooool2o`0002Wooooo0_l00008ooooo`;o00004?ooool2o`0001gooooo0ol0000:ooooo`00
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q
8Oo<c<`01_ooool00ol0003oooooooooo`0;ooooo`;o0000<oooool2o`0009;ooooo0_l0000koooo
o`;o00002?ooool2o`0001gooooo0ol0000:ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0;
ooooo`;o0000:oooool2o`0000Kooooo0_l0000Aooooo`;o00005Oooool2o`000:Gooooo0_l0000L
ooooo`;o00005_ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooo
ooooooooool000001_ooool3o`0003Sooooo0_l0000Iooooo`;o00003_ooool2o`0000Gooooo0_l0
002Fooooo`;o00004Oooool2o`0001Sooooo0_l0000Fooooo`000oooool01Ol0003ooooooooooooo
oooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooooooo06?ooooo
0_l0001Xooooo`;o0000<oooool2o`0000Sooooo0_l00007ooooo`;o00001oooool2o`0002Oooooo
0003ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Ko
oooo00?o0000ooooooooool0A?ooool2o`0003Kooooo0_l00014ooooo`;o00002Oooool2o`0000So
oooo0_l0000cooooo`;o00004?ooool2o`0002Oooooo0003ooooo`05oa0@4?ooooooooooooooool@
41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0@Oooool2o`00
0003ooooool0003o0000023ooooo0_l0000Dooooo`;o000000?oooooo`000?l00000@Oooool2o`00
01?ooooo0_l0001^ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo03?ooooo0_l00003ooooo`;o00001oooool2
o`0001Gooooo0_l0000<ooooo`;o00004_ooool2o`0000?ooooo0_l0000Pooooo`;o0000?oooool2
o`0003Cooooo0_l00002ooooo`;o0000:Oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`0cooooo`;o00000ooo
ool2o`0001kooooo0_l0000Pooooo`;o00009Oooool2o`0003oooooo0_l0000dooooo`;o00000_oo
ool2o`0002Wooooo000Nooooo`03o`000?oooooooooo0?Sooooo0_l0001=ooooo`007_ooool00ol0
003oooooooooo`0Rooooo`;o0000<_ooool2o`0000_ooooo0_l0000?ooooo`;o0000@_ooool2o`00
03kooooo0_l00010ooooo`;o00002oooool001kooooo00?o0000ooooooooool08_ooool2o`00023o
oooo0_l0000@ooooo`;o00002oooool2o`0000oooooo0_l00004ooooo`;o0000=_ooool2o`0000?o
oooo0ol00020ooooo`;o00002oooool001kooooo00?o0000ooooooooool0=_ooool2o`0000cooooo
0_l0000dooooo`;o00002_ooool2o`0002[ooooo0_l00003ooooo`;o00004_ooool2o`0004Sooooo
0_l0000`ooooo`007_ooool00ol0003oooooooooo`0fooooo`;o0000>oooool2o`00017ooooo0_l0
0004ooooo`;o0000?Oooool2o`0004Sooooo0_l0000`ooooo`007_ooool00ol0003oooooooooo`05
ooooo`;o0000K?ooool2o`0000Kooooo0_l0000?ooooo`;o00000_ooool2o`000;Gooooo000Noooo
o`03o`000?oooooooooo00Gooooo0_l0001Qooooo`;o00004Oooool2o`0001?ooooo0_l0002eoooo
o`007_ooool00ol0003oooooooooo`0Zooooo`;o00004oooool2o`0002Oooooo0_l0001Cooooo`;o
0000;?ooool2o`00057ooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`0Vooooo`;o0000
0_ooool2o`0001?ooooo0_l0000Fooooo`;o00005_ooool2o`0004cooooo0_l0000/ooooo`;o0000
6oooool2o`0003Cooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`0Vooooo`;o00009?oo
ool2o`0000Cooooo0_l00003ooooo`;o00002oooool2o`0000Wooooo0_l0001Uooooo`;o0000<?oo
ool2o`0003gooooo000Nooooo`03o`000?oooooooooo04Wooooo0_l000000ooooooo0000o`000004
ooooo`;o00004?ooool2o`0002Oooooo0_l00017ooooo`;o00002oooool2o`0006;ooooo000Noooo
o`;o00002?ooool2o`00043ooooo0_l00012ooooo`;o0000:_ooool2o`0002Sooooo0_l0001Roooo
o`007_ooool00ol0003oooooooooo`07ooooo`;o0000>Oooool2o`0000Wooooo0_l0001Iooooo`;o
00003oooool2o`00083ooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0Xooooo`;o0000
6?ooool2o`0000Wooooo0_l0000Vooooo`;o0000;_ooool2o`000003ooooool0003o0000097ooooo
0_l0000:ooooo`007_ooool00ol0003oooooooooo`0Xooooo`;o00007Oooool2o`0002cooooo0ol0
000]ooooo`;o00005_ooool2o`0001kooooo0_l0001Xooooo`007_ooool00ol0003oooooooooo`0c
ooooo`;o00004_ooool2o`0002gooooo0_l00015ooooo`;o00001?ooool2o`0001Sooooo0_l0000P
ooooo`;o0000A_ooool001kooooo00?o0000ooooooooool0<oooool2o`0004;ooooo0_l0000Joooo
o`;o0000;_ooool2o`0003[ooooo0_l00016ooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o
00001Oooool2o`0002kooooo0_l0000?ooooo`;o00007_ooool2o`000003ooooool0003o0000017o
oooo0_l00007ooooo`;o0000B?ooool2o`0006Sooooo000Nooooo`03o`000?oooooooooo00;o0000
2_ooool2o`0000Gooooo0_l0000^ooooo`;o00003oooool4o`0001cooooo0_l0000Dooooo`;o0000
DOooool2o`0006Sooooo000Nooooo`03o`000?oooooooooo00;o00006?ooool2o`0003[ooooo0_l0
003_ooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o00003?ooool2o`0000kooooo0_l0000I
ooooo`;o0000Roooool2o`0006;ooooo0ol0000>ooooo`007_ooool00ol0003oooooooooo`0<oooo
o`;o00007?ooool2o`0000Wooooo0_l0000>ooooo`;o0000:?ooool2o`00067ooooo0_l0000koooo
o`;o00009Oooool3o`0000kooooo000Mooooo`;o0000=oooool2o`0001Sooooo0_l0000Nooooo`;o
0000;oooool2o`0000Oooooo0_l0000Zooooo`;o0000>?ooool2o`0003Kooooo000Mooooo`;o0000
DOooool2o`00027ooooo0_l0000/ooooo`;o00000oooool2o`0000;ooooo0_l0000Aooooo`;o0000
5oooool2o`0003kooooo0_l0000;ooooo`Co00001oooool2o`0000Sooooo0_l0000>ooooo`007_oo
ool00ol0003oooooooooo`1Mooooo`;o00004oooool2o`0002?ooooo0_l0000<ooooo`;o00005Ooo
ool2o`0003?ooooo0_l0000Rooooo`;o00002oooool4o`0000Oooooo0_l00008ooooo`?o00003Ooo
ool001kooooo00?o0000ooooooooool06?ooool2o`0004?ooooo0_l0000:ooooo`;o0000;?ooool2
o`0005Sooooo0_l00015ooooo`;o00003Oooool001kooooo00?o0000ooooooooool06?ooool2o`00
04oooooo0_l0000^ooooo`;o0000?Oooool2o`0006;ooooo0_l00009ooooo`007_ooool2o`0002_o
oooo0_l0000/ooooo`;o00007Oooool2o`0000kooooo0_l0000@ooooo`;o0000?Oooool2o`0006;o
oooo0_l00009ooooo`007_ooool00ol0003oooooooooo`0Zooooo`;o0000;?ooool2o`0000oooooo
0_l0000<ooooo`;o00003_ooool2o`000;kooooo000Nooooo`03o`000?oooooooooo06Wooooo0_l0
000?ooooo`;o00007_ooool2o`0000Oooooo0_l0001Cooooo`;o00004?ooool2o`0003_ooooo000N
ooooo`03o`000?oooooooooo07[ooooo0_l00009ooooo`;o00004oooool2o`0000Oooooo0_l00019
ooooo`;o00002?ooool2o`00013ooooo0_l00004ooooo`;o0000=Oooool001kooooo00?o0000oooo
ooooool0QOooool2o`0006Oooooo0_l0000Pooooo`;o0000=Oooool001kooooo00?o0000oooooooo
ool0>oooool2o`0003gooooo0_l0000Xooooo`;o0000:Oooool2o`0007Kooooo000Nooooo`04o`00
0?ooooooooooooooo`;o0000>?ooool2o`0003gooooo0_l0000?ooooo`;o00005oooool2o`0002Wo
oooo0_l0001Uooooo`;o00003oooool001kooooo00Co0000oooooooooooooooo0_l00028ooooo`;o
0000Q?ooool2o`0002?ooooo0_l0000?ooooo`007_ooool00ol0003oooooooooo`39ooooo`;o0000
1oooool2o`0003gooooo0_l0000dooooo`007_ooool00ol0003oooooooooo`1fooooo`;o0000DOoo
ool2o`0000Oooooo0_l0001cooooo`007_ooool00ol0003oooooooooo`1>ooooo`;o00005Oooool2
o`0000oooooo0_l0000cooooo`;o0000V_ooool001kooooo00?o0000ooooooooool0:_ooool2o`00
013ooooo0_l0000@ooooo`;o00005Oooool2o`0004Cooooo0_l0000Dooooo`;o00005Oooool2o`00
05gooooo0_l0000>ooooo`007_ooool3o`0001kooooo0_l0000:ooooo`;o00001oooool2o`0000Oo
oooo0_l00023ooooo`;o00005Oooool2o`0000Cooooo0_l0000mooooo`;o00006?ooool2o`0000ko
oooo000Nooooo`?o00007_ooool2o`0001;ooooo0ol0000_ooooo`;o0000N?ooool2o`0003gooooo
0_l0000=ooooo`;o00006Oooool001kooooo00?o0000ooooooooool0<_ooool2o`0001Oooooo0_l0
000Gooooo`;o0000B_ooool2o`0007[ooooo0_l0000Iooooo`007_ooool00ol0003oooooooooo`1;
ooooo`;o00002?ooool2o`0005Wooooo0_l0002Eooooo`007_ooool2o`0003gooooo0_l0000Goooo
o`;o00005Oooool2o`000=Wooooo000Nooooo`04o`000?oooooo0000o`0002Wooooo0_l00003oooo
o`;o00002oooool2o`0002kooooo0_l0000Kooooo`Co0000^_ooool001kooooo00Co0000ooooool0
003o0000:Oooool2o`0000?ooooo0_l0001Cooooo`;o00000oooool4o`0001_ooooo0_l000000ooo
oooo0000o`00000cooooo`;o0000=_ooool2o`0002gooooo000Nooooo`03o`000?oooooooooo08Co
oooo0_l0000Rooooo`;o000000?oooooo`000?l000008oooool2o`0000kooooo0_l0000fooooo`;o
0000;Oooool001kooooo00?o0000ooooooooool0S?ooool2o`0002Oooooo0_l0000Iooooo`;o0000
2Oooool2o`0006[ooooo000Nooooo`03o`000?oooooooooo08cooooo0_l0000Wooooo`;o00000ooo
ool2o`0000Oooooo0_l0000Fooooo`;o0000J_ooool001kooooo00?o0000ooooooooool0<oooool2
o`0000gooooo0_l0000:ooooo`;o00005Oooool2o`00053ooooo0_l000000ooooooo0000o`000007
ooooo`;o0000P_ooool001kooooo00?o0000ooooooooool02?ooool2o`0002Wooooo0_l0000=oooo
o`;o00001?ooool2o`0000Cooooo0_l0000Eooooo`;o00004Oooool2o`0003gooooo0_l0001<oooo
o`;o0000<Oooool2o`0000gooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0000Eooooo`;o
00009oooool2o`0002kooooo0_l0002:ooooo`?o0000<Oooool2o`0000gooooo000Nooooo`03o`00
0?oooooooooo01oooooo0_l0003Sooooo`;o0000@Oooool001kooooo00?o0000ooooooooool0nOoo
ool2o`0004cooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0001=ooooo`;o0000U_ooool2
o`0004cooooo000Nooooo`?o00004_ooool2o`0000_ooooo0_l0000Aooooo`;o0000;Oooool2o`00
00gooooo0_l0000Fooooo`;o0000Qoooool2o`0000gooooo0_l00004ooooo`;o00007oooool001ko
oooo0ol0000Oooooo`;o00004Oooool2o`0003cooooo0_l0000Fooooo`;o0000AOooool2o`00043o
oooo0_l0000=ooooo`;o00001?ooool2o`0001oooooo000Dooooo`Co000000?o410@ooooooooool0
0oooool00ol0003oooooooooo`1Nooooo`;o0000=Oooool2o`0003Sooooo0_l0001fooooo`005_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05kooooo0_l0000eooooo`;o0000FOoo
ool2o`0001Gooooo0_l0000`ooooo`;o00003?ooool001Kooooo00?o0000ooooooooool01Oooool3
o`000?3ooooo0_l0000Eooooo`;o0000<?ooool2o`0000Cooooo0_l00006ooooo`005_ooool00ol0
003oooooooooo`3oooooodSooooo0_l00006ooooo`005_ooool00ol0003oooooooooo`3ooooooe3o
oooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooo
oom@ooooo`005?ooool00omEEEGoIVIVo`00003ooooooe;ooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.93858 .07265 Mdot
.5034 .06077 Mdot
.27418 .21728 Mdot
.6271 .02456 Mdot
.26305 .98474 Mdot
.11886 .63321 Mdot
.89925 .45842 Mdot
.07058 .40287 Mdot
.3361 .79015 Mdot
.50754 .01597 Mdot
.57462 .79003 Mdot
.39273 .76832 Mdot
.17861 .15765 Mdot
.67839 .99804 Mdot
.29593 .43305 Mdot
.67657 .4396 Mdot
.65053 .00304 Mdot
.95528 .27098 Mdot
.42893 .04992 Mdot
.17095 .45458 Mdot
.40257 .68424 Mdot
.04253 .11332 Mdot
.35219 .3835 Mdot
.9789 .88152 Mdot
.96332 .56971 Mdot
.56075 .57517 Mdot
.85459 .53966 Mdot
.73784 .42063 Mdot
.76064 .98349 Mdot
.23118 .7824 Mdot
.94604 .70735 Mdot
.56072 .86426 Mdot
.68724 .42189 Mdot
.06703 .17379 Mdot
.91977 .57794 Mdot
.62734 .82322 Mdot
.6196 .75938 Mdot
.39135 .77315 Mdot
.01897 .61984 Mdot
.20051 .81652 Mdot
.838 .06435 Mdot
.27454 .61736 Mdot
.43265 .99723 Mdot
.33325 .10353 Mdot
.11928 .0455 Mdot
.49965 .59749 Mdot
.68624 .91078 Mdot
.39002 .22106 Mdot
.89246 .87142 Mdot
.40674 .81772 Mdot
.21636 .67365 Mdot
.8396 .62471 Mdot
.01286 .11088 Mdot
.05218 .39001 Mdot
.16836 .64275 Mdot
.29176 .82562 Mdot
.82137 .03741 Mdot
.22775 .83503 Mdot
.41306 .34001 Mdot
.23613 .0464 Mdot
.01176 .1771 Mdot
.185 .87108 Mdot
.22538 .80532 Mdot
.77858 .80463 Mdot
.65799 .35491 Mdot
.22517 .9784 Mdot
.97392 .06358 Mdot
.57064 .66467 Mdot
.91965 .82457 Mdot
.92747 .23431 Mdot
.99794 .90756 Mdot
.25746 .65497 Mdot
.07308 .44598 Mdot
.6214 .54289 Mdot
.64605 .97808 Mdot
.14868 .1331 Mdot
.28516 .98675 Mdot
.33904 .66973 Mdot
.84952 .37925 Mdot
.13552 .54155 Mdot
.45965 .12242 Mdot
.81479 .7848 Mdot
.2144 .71614 Mdot
.03495 .4062 Mdot
.45068 .9106 Mdot
.05856 .67978 Mdot
.31779 .42507 Mdot
.30303 .8681 Mdot
.50983 .76106 Mdot
.43634 .7183 Mdot
.20632 .73347 Mdot
.83549 .68171 Mdot
.07454 .44909 Mdot
.51354 .40283 Mdot
.44312 .12923 Mdot
.12563 .39946 Mdot
.47142 .75317 Mdot
.66889 .22364 Mdot
.63277 .8671 Mdot
.50475 .86096 Mdot
.40365 .55222 Mdot
.72171 .64051 Mdot
.83288 .02766 Mdot
.41799 .48994 Mdot
.30312 .41433 Mdot
.22976 .4763 Mdot
.30102 .78052 Mdot
.69473 .65393 Mdot
.20609 .62512 Mdot
.65596 .88292 Mdot
.01645 .11027 Mdot
.57268 .54106 Mdot
.06572 .25447 Mdot
.43303 .3929 Mdot
.90998 .65982 Mdot
.76344 .77226 Mdot
.10488 .63614 Mdot
.89271 .75913 Mdot
.30755 .38673 Mdot
.46598 .78025 Mdot
.68822 .14699 Mdot
.56216 .42185 Mdot
.0033 .3316 Mdot
.33859 .17454 Mdot
.54814 .65536 Mdot
.38115 .33397 Mdot
.38348 .79475 Mdot
.26965 .99474 Mdot
.88539 .70358 Mdot
.81073 .80265 Mdot
.93887 .84818 Mdot
.91683 .75399 Mdot
.03951 .15563 Mdot
.83864 .92941 Mdot
.53295 .19201 Mdot
.10771 .06387 Mdot
.37146 .84117 Mdot
.02491 .4624 Mdot
.46188 .57602 Mdot
.42499 .79384 Mdot
.12277 .44405 Mdot
.15632 .43793 Mdot
.75969 .01773 Mdot
.87053 .1076 Mdot
.23166 .43912 Mdot
.42644 .61675 Mdot
.31441 .79132 Mdot
.73873 .14206 Mdot
.43574 .27747 Mdot
.17455 .22596 Mdot
.19295 .09081 Mdot
.19288 .13712 Mdot
.60328 .99348 Mdot
.74855 .02062 Mdot
.32153 .34698 Mdot
.35734 .43813 Mdot
.48537 .65398 Mdot
.56805 .13477 Mdot
.6946 .45737 Mdot
.03371 .67451 Mdot
.88715 .64962 Mdot
.3347 .78005 Mdot
.99133 .3331 Mdot
.84939 .41236 Mdot
.87258 .7113 Mdot
.68504 .63346 Mdot
.13602 .57894 Mdot
.76417 .76368 Mdot
.14602 .55569 Mdot
.91942 .13999 Mdot
.84642 .41356 Mdot
.21989 .05844 Mdot
.47277 .26911 Mdot
.19118 .71761 Mdot
.92917 .58916 Mdot
.86724 .91882 Mdot
.40284 .36536 Mdot
.76161 .83342 Mdot
.56158 .41667 Mdot
.47778 .59556 Mdot
.07355 .17475 Mdot
.88569 .97713 Mdot
.68062 .03851 Mdot
.18174 .45803 Mdot
.79288 .18144 Mdot
.59179 .12039 Mdot
.47738 .21599 Mdot
.17302 .58562 Mdot
.41991 .32257 Mdot
.97323 .33666 Mdot
.39079 .27173 Mdot
.00167 .24867 Mdot
.8806 .56365 Mdot
.27906 .84593 Mdot
.47775 .10999 Mdot
.62035 .90457 Mdot
.33146 .32958 Mdot
.43928 .12278 Mdot
.34121 .60674 Mdot
.88738 .93081 Mdot
.05765 .85869 Mdot
.553 .12114 Mdot
.2101 .10605 Mdot
.08218 .32024 Mdot
.76199 .81072 Mdot
.41108 .07082 Mdot
.94519 .21332 Mdot
.30991 .63028 Mdot
.23627 .45477 Mdot
.1685 .75575 Mdot
.50741 .36106 Mdot
.76109 .22056 Mdot
.65 .75527 Mdot
.47407 .46046 Mdot
.20082 .24601 Mdot
.86592 .49729 Mdot
.72843 .87417 Mdot
.00213 .11305 Mdot
.43829 .19726 Mdot
.27584 .93347 Mdot
.84269 .33038 Mdot
.79897 .62695 Mdot
.86419 .62191 Mdot
.5923 .72659 Mdot
.68221 .30197 Mdot
.63253 .79019 Mdot
.008 .58998 Mdot
.31687 .60157 Mdot
.6867 .91923 Mdot
.73828 .96488 Mdot
.76435 .20973 Mdot
.63928 .76253 Mdot
.16289 .47799 Mdot
.60013 .54283 Mdot
.85927 .32932 Mdot
.53693 .4573 Mdot
.63838 .51162 Mdot
.42573 .13236 Mdot
.15875 .5878 Mdot
.71968 .01768 Mdot
.97906 .92673 Mdot
.64838 .57554 Mdot
.82127 .14903 Mdot
.40092 .45199 Mdot
.02926 .99282 Mdot
.14016 .154 Mdot
.63515 .13693 Mdot
.11066 .38769 Mdot
.57305 .17943 Mdot
.22854 .66873 Mdot
.70568 .164 Mdot
.72687 .16685 Mdot
.44215 .69296 Mdot
.68539 .05138 Mdot
.09093 .04717 Mdot
.82965 .13585 Mdot
.55128 .69341 Mdot
.02982 .23809 Mdot
.15916 .09786 Mdot
.33898 .59682 Mdot
.31441 .20939 Mdot
.83635 .55595 Mdot
.14817 .67584 Mdot
.65419 .89561 Mdot
.25415 .33839 Mdot
.53778 .54774 Mdot
.55832 .6254 Mdot
.43777 .82141 Mdot
.58308 .63132 Mdot
.53438 .8559 Mdot
.4914 .05148 Mdot
.82844 .66148 Mdot
.8334 .35124 Mdot
.12331 .68461 Mdot
.32172 .09254 Mdot
.1764 .39317 Mdot
.61134 .15738 Mdot
.10358 .27038 Mdot
.48922 .88247 Mdot
.3542 .3294 Mdot
.58944 .93703 Mdot
.16774 .8053 Mdot
.39707 .09373 Mdot
.89725 .72534 Mdot
.20498 .58481 Mdot
.22756 .46954 Mdot
.6191 .7803 Mdot
.67654 .65618 Mdot
.69482 .01535 Mdot
.06914 .65339 Mdot
.7195 .68919 Mdot
.37433 .13387 Mdot
.70554 .26872 Mdot
.37579 .79832 Mdot
.55411 .46804 Mdot
.11583 .44279 Mdot
.81907 .72453 Mdot
.37143 .4836 Mdot
.97814 .34192 Mdot
.35534 .41033 Mdot
.94814 .71693 Mdot
.96468 .14702 Mdot
.85104 .61547 Mdot
.24475 .39822 Mdot
.5667 .65097 Mdot
.08778 .25753 Mdot
.12761 .45014 Mdot
.45665 .39752 Mdot
.80589 .41422 Mdot
.88063 .34063 Mdot
.46337 .46733 Mdot
.02371 .49342 Mdot
.23841 .52516 Mdot
.67308 .04485 Mdot
.2488 .38504 Mdot
.90631 .0675 Mdot
.25335 .41776 Mdot
.38378 .33913 Mdot
.25602 .56853 Mdot
.26255 .33777 Mdot
.07748 .5777 Mdot
.93475 .58397 Mdot
.08771 .30524 Mdot
.44832 .58461 Mdot
.12945 .68312 Mdot
.39972 .93408 Mdot
.41572 .67544 Mdot
.0094 .28297 Mdot
.90894 .66803 Mdot
.04396 .51703 Mdot
.16187 .92976 Mdot
.42842 .73567 Mdot
.5899 .78206 Mdot
.84157 .51754 Mdot
.15523 .92565 Mdot
.91071 .4787 Mdot
.12144 .77926 Mdot
.84969 .02542 Mdot
.22272 .82246 Mdot
.38739 .44065 Mdot
.61815 .55767 Mdot
.84944 .24004 Mdot
.16777 .11211 Mdot
.13551 .21661 Mdot
.03141 .86612 Mdot
.63823 .36426 Mdot
.66873 .34286 Mdot
.42491 .08056 Mdot
.95085 .99615 Mdot
.96235 .51406 Mdot
.34179 .95727 Mdot
.12525 .88436 Mdot
.91883 .92174 Mdot
.55246 .08291 Mdot
.12551 .27277 Mdot
.05908 .39857 Mdot
.44738 .75361 Mdot
.91443 .56711 Mdot
.29965 .93071 Mdot
.19819 .97438 Mdot
.88546 .17474 Mdot
.437 .87332 Mdot
.2592 .02506 Mdot
.00556 .35269 Mdot
.8096 .53109 Mdot
.92098 .03788 Mdot
.00192 .917 Mdot
.20238 .94881 Mdot
.14394 .39305 Mdot
.86196 .86391 Mdot
.47327 .93817 Mdot
.33204 .54898 Mdot
.08916 .05517 Mdot
.16109 .28226 Mdot
.2911 .62441 Mdot
.72224 .22423 Mdot
.93122 .53399 Mdot
.36057 .05076 Mdot
.26029 .24994 Mdot
.63804 .24458 Mdot
.43719 .45668 Mdot
.35344 .82711 Mdot
.41241 .84597 Mdot
.66193 .6583 Mdot
.02328 .99696 Mdot
.90495 .96998 Mdot
.16775 .80247 Mdot
.78546 .11439 Mdot
.69518 .59664 Mdot
.8077 .69656 Mdot
.89336 .76501 Mdot
.85535 .81154 Mdot
.91005 .81301 Mdot
.96305 .28677 Mdot
.69701 .83948 Mdot
.92949 .02297 Mdot
.3011 .19157 Mdot
.37049 .62408 Mdot
.51478 .24394 Mdot
.25055 .9076 Mdot
.35555 .9396 Mdot
.45194 .79516 Mdot
.00095 .86367 Mdot
.28374 .53379 Mdot
.38711 .36 Mdot
.88911 .52751 Mdot
.34832 .08684 Mdot
.57955 .0449 Mdot
.39044 .1892 Mdot
.75344 .70733 Mdot
.32366 .57929 Mdot
.17613 .42234 Mdot
.48187 .03661 Mdot
.96768 .0859 Mdot
.13872 .65932 Mdot
.20533 .24359 Mdot
.98715 .97858 Mdot
.64106 .15964 Mdot
.37173 .28129 Mdot
.46631 .86964 Mdot
.28788 .45045 Mdot
.30799 .45557 Mdot
.47118 .38515 Mdot
.3327 .6672 Mdot
.40153 .03389 Mdot
.92317 .98591 Mdot
.1658 .80745 Mdot
.09441 .4471 Mdot
.46887 .19133 Mdot
.9616 .7154 Mdot
.71426 .47162 Mdot
.80212 .548 Mdot
.06531 .51583 Mdot
.3038 .39548 Mdot
.71442 .61241 Mdot
.28254 .49868 Mdot
.84352 .23595 Mdot
.89495 .90039 Mdot
.19235 .94827 Mdot
.20566 .05663 Mdot
.91809 .01597 Mdot
.85015 .72196 Mdot
.64329 .95044 Mdot
.61209 .95979 Mdot
.30167 .82848 Mdot
.82817 .93548 Mdot
.90937 .72734 Mdot
.0242 .01536 Mdot
.80633 .15787 Mdot
.2922 .52997 Mdot
.02517 .67635 Mdot
.522 .22362 Mdot
.6938 .05668 Mdot
.03154 .98542 Mdot
.35488 .69759 Mdot
.08181 .44367 Mdot
.67527 .01014 Mdot
.90704 .18168 Mdot
.22235 .80466 Mdot
.40607 .74736 Mdot
.0017 .30848 Mdot
.29729 .56142 Mdot
.27357 .05091 Mdot
.34151 .84071 Mdot
.13196 .39939 Mdot
.92607 .4184 Mdot
.31556 .19861 Mdot
.45792 .4359 Mdot
.08344 .54557 Mdot
.94736 .81335 Mdot
.45148 .03403 Mdot
.05291 .5539 Mdot
.10729 .44113 Mdot
.0669 .73233 Mdot
.09983 .97231 Mdot
.20768 .51125 Mdot
.33813 .11297 Mdot
.86591 .63238 Mdot
.55979 .41561 Mdot
.04449 .77132 Mdot
.14781 .37922 Mdot
.22944 .37263 Mdot
.23143 .65387 Mdot
.81592 .24764 Mdot
.72242 .8257 Mdot
.2136 .94555 Mdot
.99599 .27649 Mdot
.53963 .11169 Mdot
.1087 .72339 Mdot
.34725 .93197 Mdot
.74994 .76742 Mdot
.89062 .80011 Mdot
.14989 .31182 Mdot
.1552 .0315 Mdot
.68795 .91133 Mdot
.04272 .2343 Mdot
.47737 .78681 Mdot
.17881 .73846 Mdot
.30223 .74054 Mdot
.20491 .09425 Mdot
.72796 .77842 Mdot
.47635 .70726 Mdot
.496 .17985 Mdot
.06493 .28754 Mdot
.62499 .63028 Mdot
.48066 .93142 Mdot
.50998 .06048 Mdot
.07683 .32672 Mdot
.19844 .83363 Mdot
.10918 .92011 Mdot
.42274 .58584 Mdot
.42431 .1804 Mdot
.29286 .4123 Mdot
.49764 .88848 Mdot
.36368 .74586 Mdot
.9485 .02252 Mdot
.13574 .75236 Mdot
.14632 .61444 Mdot
.35462 .07631 Mdot
.59631 .95283 Mdot
.41661 .65672 Mdot
.15476 .50701 Mdot
.53958 .55399 Mdot
.10982 .74829 Mdot
.82135 .60563 Mdot
.17183 .32229 Mdot
.05319 .22705 Mdot
.85464 .83347 Mdot
.27686 .07796 Mdot
.09072 .71028 Mdot
.54117 .65089 Mdot
.9676 .07627 Mdot
.65294 .53971 Mdot
.30144 .89133 Mdot
.52198 .45617 Mdot
.5465 .59617 Mdot
.11176 .37818 Mdot
.86671 .65874 Mdot
.59835 .71477 Mdot
.78025 .71448 Mdot
.45946 .23989 Mdot
.89067 .50187 Mdot
.5769 .9888 Mdot
.542 .86565 Mdot
.51628 .17262 Mdot
.83762 .54104 Mdot
.26467 .15416 Mdot
.76074 .38623 Mdot
.84587 .2515 Mdot
.44043 .06326 Mdot
.75124 .05709 Mdot
.28792 .86435 Mdot
.64949 .53103 Mdot
.85902 .95461 Mdot
.5519 .00536 Mdot
.93601 .5905 Mdot
.70626 .26929 Mdot
.59023 .62873 Mdot
.95186 .78134 Mdot
.347 .81498 Mdot
.79067 .8926 Mdot
.25881 .06484 Mdot
.50401 .22268 Mdot
.21917 .8404 Mdot
.39897 .29912 Mdot
.80986 .4555 Mdot
.15031 .83509 Mdot
.38579 .42169 Mdot
.01282 .07084 Mdot
.51872 .13778 Mdot
.40034 .79078 Mdot
.74648 .0569 Mdot
.4696 .46151 Mdot
.86711 .19956 Mdot
.58159 .6762 Mdot
.24064 .96268 Mdot
.80469 .9096 Mdot
.59533 .1432 Mdot
.82433 .58648 Mdot
.8115 .24544 Mdot
.38964 .87082 Mdot
.79401 .59755 Mdot
.43762 .60421 Mdot
.35954 .12603 Mdot
.35656 .86147 Mdot
.20193 .36717 Mdot
.42777 .57771 Mdot
.38734 .94093 Mdot
.20468 .2584 Mdot
.05169 .26051 Mdot
.97013 .33697 Mdot
.80887 .44346 Mdot
.8894 .77583 Mdot
.57394 .30901 Mdot
.12614 .54031 Mdot
.80196 .7857 Mdot
.34841 .44594 Mdot
.28296 .78058 Mdot
.31081 .24557 Mdot
.20443 .49991 Mdot
.46495 .53391 Mdot
.74568 .74983 Mdot
.19856 .79245 Mdot
.27833 .85727 Mdot
.9507 .51653 Mdot
.25406 .00325 Mdot
.06705 .21686 Mdot
.047 .74879 Mdot
.09023 .36885 Mdot
.34464 .59106 Mdot
.62578 .46685 Mdot
.52207 .54765 Mdot
.30486 .26153 Mdot
.32853 .32773 Mdot
.76945 .9587 Mdot
.62108 .03014 Mdot
.57823 .15525 Mdot
.91399 .32732 Mdot
.8163 .45918 Mdot
.43291 .02699 Mdot
.23367 .42331 Mdot
.67304 .87316 Mdot
.17054 .71045 Mdot
.64656 .72817 Mdot
.00405 .93247 Mdot
.80135 .73731 Mdot
.89881 .31923 Mdot
.71594 .20454 Mdot
.9375 .66489 Mdot
.35975 .17189 Mdot
.32978 .789 Mdot
.41572 .51349 Mdot
.61945 .85434 Mdot
.23032 .19663 Mdot
.07821 .69328 Mdot
.28064 .80516 Mdot
.31871 .28033 Mdot
.99885 .61972 Mdot
.90687 .6341 Mdot
.44091 .91702 Mdot
.57074 .3295 Mdot
.78889 .92779 Mdot
.48669 .96624 Mdot
.45081 .89275 Mdot
.32402 .67582 Mdot
.87287 .07609 Mdot
.92439 .43851 Mdot
.98755 .48645 Mdot
.88794 .53261 Mdot
.54347 .36269 Mdot
.65554 .29656 Mdot
.64484 .11802 Mdot
.54663 .31711 Mdot
.42091 .8617 Mdot
.35035 .84735 Mdot
.18158 .29699 Mdot
.56147 .8635 Mdot
.99251 .82508 Mdot
.15399 .91337 Mdot
.59742 .88969 Mdot
.44396 .98844 Mdot
.24924 .87751 Mdot
.41627 .18522 Mdot
.26352 .10074 Mdot
.45443 .16809 Mdot
.32189 .02934 Mdot
.75195 .73364 Mdot
.75618 .01122 Mdot
.79897 .48356 Mdot
.0853 .7291 Mdot
.19554 .81458 Mdot
.18542 .17295 Mdot
.32015 .6356 Mdot
.30968 .7791 Mdot
.98571 .84968 Mdot
.39875 .94171 Mdot
.01708 .27888 Mdot
.59592 .63662 Mdot
.74595 .1591 Mdot
.52856 .97418 Mdot
.27373 .29249 Mdot
.74525 .05608 Mdot
.58342 .80335 Mdot
.16999 .22859 Mdot
.96074 .80152 Mdot
.35425 .92726 Mdot
.36662 .34046 Mdot
.381 .42898 Mdot
.94293 .61826 Mdot
.2038 .42791 Mdot
.68301 .90195 Mdot
.35328 .91121 Mdot
.00544 .02673 Mdot
.25502 .31143 Mdot
.98359 .82624 Mdot
.39863 .53772 Mdot
.56108 .6364 Mdot
.71439 .09003 Mdot
.77678 .66879 Mdot
.64325 .12268 Mdot
.36065 .80885 Mdot
.09745 .37436 Mdot
.02185 .2407 Mdot
.88528 .04815 Mdot
.57027 .6865 Mdot
.25843 .16392 Mdot
.07585 .29144 Mdot
.15375 .04015 Mdot
.10423 .22414 Mdot
.98147 .43369 Mdot
.90326 .80665 Mdot
.8436 .78349 Mdot
.13606 .76877 Mdot
.5832 .96752 Mdot
.46987 .88948 Mdot
.91708 .30135 Mdot
.62354 .74811 Mdot
.09732 .7352 Mdot
.72475 .83973 Mdot
.45464 .21609 Mdot
.19006 .26421 Mdot
.02407 .2658 Mdot
.93455 .74565 Mdot
.69283 .98687 Mdot
.43233 .70593 Mdot
.76664 .77122 Mdot
.15489 .23473 Mdot
.10907 .87659 Mdot
.09876 .26529 Mdot
.52022 .65806 Mdot
.03143 .82408 Mdot
.46454 .91126 Mdot
.93183 .21814 Mdot
.03726 .33084 Mdot
.55213 .8691 Mdot
.99648 .76545 Mdot
.95284 .80609 Mdot
.83181 .38349 Mdot
.3128 .9981 Mdot
.24752 .98009 Mdot
.83108 .36838 Mdot
.26342 .83308 Mdot
.41639 .89417 Mdot
.05519 .4346 Mdot
.79404 .34764 Mdot
.44566 .77517 Mdot
.58968 .87026 Mdot
.12743 .70453 Mdot
.98451 .69796 Mdot
.86559 .80204 Mdot
.29305 .20142 Mdot
.15941 .23241 Mdot
.15547 .37457 Mdot
.49064 .76119 Mdot
.23129 .92555 Mdot
.79802 .8489 Mdot
.73432 .97989 Mdot
.72628 .55801 Mdot
.63172 .51842 Mdot
.05355 .51285 Mdot
.04337 .27143 Mdot
.92959 .11893 Mdot
.36474 .67529 Mdot
.38781 .68111 Mdot
.89089 .79899 Mdot
.53235 .64743 Mdot
.26931 .48372 Mdot
.23467 .11539 Mdot
.10809 .89817 Mdot
.1647 .23995 Mdot
.94465 .85988 Mdot
.30618 .14863 Mdot
.26507 .91056 Mdot
.81525 .42037 Mdot
.47746 .85312 Mdot
.17302 .14645 Mdot
.90019 .4884 Mdot
.08377 .33521 Mdot
.02343 .86099 Mdot
.40136 .62744 Mdot
.47046 .49949 Mdot
.98047 .74913 Mdot
.88004 .22521 Mdot
.26633 .18092 Mdot
.23138 .64088 Mdot
.7365 .20514 Mdot
.17887 .38455 Mdot
.27112 .47912 Mdot
.84566 .03383 Mdot
.52014 .99155 Mdot
.12817 .82199 Mdot
.4366 .04544 Mdot
.41803 .79265 Mdot
.85106 .59313 Mdot
.97807 .34496 Mdot
.1198 .17424 Mdot
.34396 .19147 Mdot
.93418 .24048 Mdot
.39547 .61208 Mdot
.22406 .13632 Mdot
.27668 .80649 Mdot
.28409 .76687 Mdot
.50253 .62915 Mdot
.25052 .37317 Mdot
.67109 .20575 Mdot
.94774 .13556 Mdot
.27547 .42656 Mdot
.08896 .44409 Mdot
.33709 .60768 Mdot
.823 .59451 Mdot
.38049 .50253 Mdot
.08195 .73217 Mdot
.58926 .07978 Mdot
.20176 .72712 Mdot
.82789 .11144 Mdot
.5652 .74313 Mdot
.44589 .52574 Mdot
.09286 .28733 Mdot
.79508 .62496 Mdot
.73993 .23275 Mdot
.01987 .6113 Mdot
.57379 .30523 Mdot
.22508 .43476 Mdot
.92078 .01 Mdot
.81686 .76716 Mdot
.94413 .85691 Mdot
.64831 .0544 Mdot
.08104 .48552 Mdot
.66156 .28843 Mdot
.38842 .76505 Mdot
.31459 .05007 Mdot
.1607 .94847 Mdot
.98288 .22937 Mdot
.30791 .22815 Mdot
.27524 .05703 Mdot
.73916 .7943 Mdot
.78088 .02438 Mdot
.30836 .64625 Mdot
.59988 .24025 Mdot
.62335 .55893 Mdot
.28573 .48262 Mdot
.90584 .27941 Mdot
.68277 .79513 Mdot
.31453 .85655 Mdot
.39099 .02658 Mdot
.59235 .14685 Mdot
.72437 .30299 Mdot
.01651 .00235 Mdot
.42853 .02988 Mdot
.3953 .87372 Mdot
.21569 .19616 Mdot
.07886 .02224 Mdot
.12241 .51408 Mdot
.53605 .16873 Mdot
.97906 .99989 Mdot
.8169 .7258 Mdot
.07233 .36367 Mdot
.70666 .03946 Mdot
.92698 .64286 Mdot
.15594 .74385 Mdot
.18761 .18309 Mdot
.2996 .20316 Mdot
.42825 .23876 Mdot
.74633 .9041 Mdot
.87359 .26489 Mdot
.6926 .21873 Mdot
.30114 .60668 Mdot
.14387 .8235 Mdot
.72156 .7518 Mdot
.01736 .18731 Mdot
.3132 .66471 Mdot
.38283 .9582 Mdot
.54058 .11403 Mdot
.47959 .15736 Mdot
.76782 .19698 Mdot
.29256 .65239 Mdot
.66788 .63537 Mdot
.4052 .09679 Mdot
.71947 .34858 Mdot
.41179 .80353 Mdot
.36459 .00225 Mdot
.07225 .98806 Mdot
.50971 .94873 Mdot
.22488 .56115 Mdot
.40487 .36779 Mdot
.26452 .93479 Mdot
.27649 .62479 Mdot
.7048 .69848 Mdot
.35016 .66561 Mdot
.93351 .29314 Mdot
.11193 .91325 Mdot
.82796 .18554 Mdot
.22065 .2551 Mdot
.35918 .55681 Mdot
.01243 .9205 Mdot
.30414 .50733 Mdot
.20271 .97786 Mdot
.84286 .05892 Mdot
.41266 .69156 Mdot
.50988 .8563 Mdot
.58758 .55088 Mdot
.05595 .07512 Mdot
.17806 .27622 Mdot
.83745 .45127 Mdot
.45967 .54982 Mdot
.02201 .42482 Mdot
.72606 .02095 Mdot
.77921 .39283 Mdot
.17131 .84296 Mdot
.66471 .75803 Mdot
.16317 .52215 Mdot
.8589 .46733 Mdot
.06142 .50984 Mdot
.30437 .10854 Mdot
.23145 .82623 Mdot
.14546 .04296 Mdot
.30458 .75162 Mdot
.82239 .29574 Mdot
.20676 .21457 Mdot
.30694 .35172 Mdot
.44538 .0733 Mdot
.96502 .02006 Mdot
.8423 .78062 Mdot
.68658 .95225 Mdot
.28842 .13677 Mdot
.9259 .32261 Mdot
.14601 .83861 Mdot
.27333 .86603 Mdot
.41871 .60951 Mdot
.02367 .15373 Mdot
.74095 .83985 Mdot
.38497 .16873 Mdot
.87231 .63268 Mdot
.74087 .59146 Mdot
.62846 .09974 Mdot
.76494 .85053 Mdot
.72803 .33179 Mdot
.16829 .87395 Mdot
.90629 .90745 Mdot
.30317 .67099 Mdot
.14333 .99716 Mdot
.8821 .20468 Mdot
.95807 .52327 Mdot
.08307 .57836 Mdot
.68559 .43431 Mdot
.66281 .48244 Mdot
.70094 .0493 Mdot
.46433 .17342 Mdot
.33738 .07614 Mdot
.97781 .7549 Mdot
.96784 .54388 Mdot
.78853 .56146 Mdot
.46743 .97107 Mdot
.61524 .74432 Mdot
.08215 .10373 Mdot
.06329 .80639 Mdot
.97107 .09787 Mdot
.96206 .73165 Mdot
.95205 .52564 Mdot
.13155 .9237 Mdot
.03424 .88081 Mdot
.84256 .7502 Mdot
.48567 .05175 Mdot
.12336 .70973 Mdot
.35063 .68535 Mdot
.10524 .34859 Mdot
.86312 .00607 Mdot
.28712 .83499 Mdot
.31567 .46931 Mdot
.99968 .88708 Mdot
.89852 .55249 Mdot
.3959 .30152 Mdot
.5225 .98453 Mdot
.16671 .0835 Mdot
.42849 .63971 Mdot
.26577 .83398 Mdot
.31214 .44527 Mdot
.68654 .82926 Mdot
.09889 .90355 Mdot
.9881 .27053 Mdot
.31754 .84255 Mdot
.56025 .14196 Mdot
.87602 .89838 Mdot
.84305 .27396 Mdot
.02383 .3742 Mdot
.32882 .88184 Mdot
.07796 .26282 Mdot
.41786 .57986 Mdot
.09404 .23841 Mdot
.08793 .17392 Mdot
.39927 .73392 Mdot
.75395 .58256 Mdot
.78244 .17369 Mdot
.75649 .67792 Mdot
.35665 .82027 Mdot
.27664 .94709 Mdot
.04721 .02702 Mdot
.35581 .81289 Mdot
.43761 .00759 Mdot
.53394 .73143 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`04o`000?oooooooooooooo
o`;o00002_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`;o00003_ooool00ol0003oooooooooo`0=oooo
o`04o`000?ooooooooooooooo`;o00002oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00cooooo0_l0000?ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo000Nooooo`04o`000?oooooooooo
ooooo`;o00002_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`;o00003_ooool00ol0003oooooooooo`0=
ooooo`04o`000?ooooooooooooooo`;o00002oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03Oooool2o`0000oooooo00?o0000ooooooooool03?oo
ool2o`0000oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool00_l0000;ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003oooooooooo`2:
ooooo`;o00008oooool2o`0002Kooooo0_l0000kooooo`;o00004Oooool2o`0001kooooo000Noooo
o`03o`000?oooooooooo08[ooooo0_l0001;ooooo`;o00006Oooool2o`0003?ooooo0_l0000Noooo
o`007_ooool00ol0003oooooooooo`04ooooo`;o0000Voooool2o`0003_ooooo0_l0000Booooo`;o
0000<_ooool2o`0001oooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0002Kooooo`;o0000
>oooool2o`0000Kooooo0_l0000;ooooo`;o0000<Oooool2o`0001oooooo000Nooooo`03o`000?oo
oooooooo01Kooooo0_l0003>ooooo`Co00001Oooool2o`0000;ooooo0_l0000kooooo`;o00001?oo
ool2o`0000oooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l0000hooooo`;o0000M_ooool2
o`0001kooooo0_l00005ooooo`;o00002Oooool2o`0001Cooooo0_l0000Hooooo`;o00001?ooool2
o`0000Cooooo0_l0000?ooooo`007_ooool3o`0000_ooooo0_l00013ooooo`;o0000:Oooool2o`00
00cooooo0_l0000mooooo`;o0000<?ooool2o`0000oooooo0_l00003ooooo`;o00006?ooool2o`00
01_ooooo000Nooooo`?o00002oooool2o`00027ooooo0_l0000eooooo`;o00005?ooool2o`0000[o
oooo1?l0000kooooo`;o0000@oooool2o`0003[ooooo000Nooooo`03o`000?oooooooooo02kooooo
0_l0000eooooo`;o00005oooool2o`0000Oooooo0_l00006ooooo`;o0000=Oooool2o`0004Oooooo
0_l0000fooooo`007_ooool00ol0003oooooooooo`1nooooo`;o00003oooool2o`0000Sooooo0_l0
001/ooooo`;o00001_ooool2o`0001Kooooo0_l0000Nooooo`007_ooool00ol0003oooooooooo`0^
ooooo`;o0000JOooool2o`0003kooooo0_l00007ooooo`;o00008oooool2o`0001kooooo0_l0000N
ooooo`007_ooool00ol0003oooooooooo`0[ooooo`;o000000?oooooo`000?l00000ZOooool2o`00
00Oooooo0_l0001Sooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o00002?ooool2o`0000Ko
oooo0_l0000Looooo`;o0000?oooool2o`0002cooooo0_l0000Mooooo`;o0000K_ooool001kooooo
00?o0000ooooooooool06Oooool2o`0000Sooooo0_l0000Tooooo`;o00005oooool2o`0002?ooooo
0_l000000ooooooo0000o`00000/ooooo`;o00007Oooool2o`0000Oooooo0_l0000jooooo`;o0000
:Oooool001kooooo0_l0001Fooooo`;o00002oooool2o`0000gooooo0_l0000Dooooo`;o00004Ooo
ool4o`0003gooooo0_l00003ooooo`;o0000>_ooool2o`0002Wooooo000Nooooo`03o`000?oooooo
oooo01Wooooo0_l0000Tooooo`;o00005?ooool2o`0001[ooooo0_l0000Wooooo`Co0000<Oooool2
o`0000[ooooo1?l0000?ooooo`;o0000Eoooool001kooooo00?o0000ooooooooool06Oooool2o`00
02Cooooo0_l00002ooooo`;o00004?ooool2o`0007Sooooo0_l0000<ooooo`;o00003oooool4o`00
01cooooo0_l0000gooooo`007_ooool00ol0003oooooooooo`13ooooo`;o00004?ooool2o`0004Wo
oooo1?l0001;ooooo`?o00007?ooool2o`0003Oooooo000Nooooo`03o`000?oooooooooo01oooooo
0_l0000_ooooo`;o0000>Oooool2o`0001?ooooo1?l0001Xooooo`;o0000:oooool2o`0000cooooo
000Nooooo`03o`000?oooooooooo01oooooo0_l0000_ooooo`;o0000>Oooool2o`0007oooooo0_l0
000Eooooo`;o00005?ooool2o`0000cooooo000Nooooo`03o`000?oooooooooo00;o0000P?ooool2
o`0009oooooo0_l0000Rooooo`007_ooool00ol0003oooooooooo`02o`0000cooooo0_l0001boooo
o`;o00002Oooool2o`0009kooooo0_l0000Hooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o
0000A_ooool2o`0001;ooooo0_l00003ooooo`;o00007?ooool2o`0008Wooooo0_l0000Cooooo`;o
00001oooool2o`0000oooooo000Nooooo`03o`000?oooooooooo05Kooooo0_l0000Booooo`;o0000
0oooool2o`0001Gooooo0_l0000cooooo`;o0000Foooool2o`0001cooooo0_l0000?ooooo`007_oo
ool00ol0003oooooooooo`0booooo`;o0000D_ooool2o`0002Oooooo0_l0000:ooooo`;o0000R_oo
ool001kooooo00?o0000ooooooooool0<_ooool2o`0003Wooooo0_l00010ooooo`;o0000QOooool2
o`0000oooooo000Nooooo`03o`000?oooooooooo06gooooo0_l0001eooooo`;o0000D?ooool2o`00
00oooooo000Nooooo`03o`000?oooooooooo03_ooooo0_l0000Wooooo`;o0000O_ooool2o`00067o
oooo000Nooooo`03o`000?oooooooooo03_ooooo0_l00002ooooo`;o00008oooool2o`0001Oooooo
0_l00038ooooo`007_ooool00ol0003oooooooooo`0`ooooo`;o00003Oooool2o`0003cooooo0_l0
00000ooooooo0000o`000016ooooo`;o0000K_ooool2o`0000gooooo000Nooooo`;o0000<Oooool2
o`00023ooooo0_l0000/ooooo`;o0000A_ooool2o`0006kooooo0_l0000=ooooo`007_ooool00ol0
003oooooooooo`0Gooooo`;o0000>Oooool2o`0001Cooooo0_l0003Mooooo`007_ooool00ol0003o
ooooooooo`0Gooooo`;o00009oooool2o`0001gooooo0_l00007ooooo`;o0000[Oooool2o`0002ko
oooo000Nooooo`03o`000?oooooooooo00?o0000;oooool2o`0000cooooo0_l0000Mooooo`;o0000
=_ooool2o`0001;ooooo0_l0001Looooo`;o00003?ooool2o`0002kooooo000Nooooo`;o000000Co
ooooo`000?l0003o00001oooool2o`0002Kooooo0_l0000fooooo`;o0000:oooool2o`0001;ooooo
0ol0001=ooooo`;o00003?ooool2o`0003cooooo000Nooooo`;o00002oooool2o`0003cooooo0_l0
000Pooooo`;o0000@?ooool2o`00023ooooo0_l0000[ooooo`;o0000B_ooool001kooooo00?o0000
ooooooooool0B?ooool2o`0006Kooooo0_l0000:ooooo`;o00004?ooool2o`0005[ooooo0_l0000K
ooooo`007_ooool00ol0003oooooooooo`2;ooooo`;o00001?ooool2o`0001gooooo0_l0000:oooo
o`;o00003oooool2o`0005_ooooo0_l0000Kooooo`007_ooool00ol0003oooooooooo`1aooooo`;o
00006?ooool2o`0000Cooooo0_l0000jooooo`;o0000N?ooool001kooooo00?o0000ooooooooool0
LOooool2o`0001Wooooo0_l0002iooooo`007_ooool00ol0003oooooooooo`0/ooooo`;o0000F?oo
ool2o`0000Cooooo0_l0002iooooo`007_ooool00ol0003oooooooooo`0/ooooo`;o00005oooool2
o`0001?ooooo0_l0000Jooooo`;o00003_ooool2o`0002gooooo0_l0001Cooooo`;o00009?ooool2
o`0001Gooooo000Nooooo`03o`000?oooooooooo03_ooooo0_l00008ooooo`;o00004oooool2o`00
01[ooooo0_l0000]ooooo`;o00003_ooool2o`0001?ooooo0_l0000nooooo`;o00009?ooool2o`00
01Gooooo000Nooooo`03o`000?oooooooooo03_ooooo0_l0001Xooooo`;o00002oooool2o`0001Ko
oooo0_l0000Pooooo`;o0000>Oooool2o`0001kooooo000Nooooo`03o`000?oooooooooo0;;ooooo
0_l00009ooooo`;o0000;Oooool2o`0003Wooooo0_l0000Nooooo`007_ooool00ol0003ooooooooo
o`0dooooo`;o0000:Oooool2o`0005_ooooo0ol0000Mooooo`;o0000:Oooool2o`0002gooooo0_l0
000?ooooo`007_ooool2o`0003Gooooo0_l0000Yooooo`;o0000Foooool2o`0001kooooo0_l0000Y
ooooo`;o0000;Oooool2o`0000oooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0000Soooo
o`;o00009oooool2o`000??ooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l00003ooooo`;o
00007_ooool2o`0000_ooooo0_l0000Jooooo`;o0000A?ooool2o`0001kooooo0_l00009ooooo`;o
0000?Oooool2o`0004?ooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0000[ooooo`;o0000
H?ooool2o`0001kooooo0_l00009ooooo`;o00001oooool2o`00023ooooo0_l0000Booooo`;o0000
@oooool001kooooo00?o0000ooooooooool0D?ooool2o`0007[ooooo0_l0000Cooooo`;o00002ooo
ool2o`0005Oooooo000Nooooo`03o`000?oooooooooo053ooooo0_l0002?ooooo`;o00001Oooool2
o`0005gooooo000Nooooo`03o`000?oooooooooo07Wooooo0_l0000Eooooo`;o00006?ooool2o`00
03cooooo0_l0001Mooooo`007_ooool00ol0003oooooooooo`0hooooo`;o0000=oooool2o`0000Ko
oooo0_l0000Eooooo`;o000000?oooooo`000?l000003oooool2o`0000Cooooo0_l0002Kooooo`00
7_ooool00ol0003oooooooooo`0Booooo`Co00000_ooool2o`0000Wooooo0_l0000Cooooo`;o0000
<?ooool2o`0000Gooooo0_l0000Pooooo`;o00003oooool2o`0005Cooooo0_l0000Pooooo`;o0000
:Oooool001kooooo00?o0000ooooooooool00_l0000@ooooo`Co00000_ooool2o`0000Wooooo0_l0
0015ooooo`;o0000B_ooool2o`0004;ooooo0_l0000Pooooo`;o0000:Oooool001kooooo00?o0000
ooooooooool00_l0001@ooooo`;o0000<_ooool2o`0001Gooooo0_l0000Gooooo`;o0000A_ooool2
o`0002?ooooo0_l0000Rooooo`007_ooool00ol0003oooooooooo`0iooooo`;o00005oooool2o`00
02oooooo0_l000000ooooooo0000o`00000Eooooo`;o0000Goooool2o`0000Wooooo0_l0000Hoooo
o`;o00008_ooool001kooooo00?o0000ooooooooool00_ooool2o`0003Gooooo0_l00018ooooo`;o
0000Q?ooool2o`0003cooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0001Jooooo`;o0000
3?ooool2o`0000gooooo0_l0000Gooooo`;o00004oooool2o`0009cooooo0003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo05kooooo
0_l0000<ooooo`;o00003Oooool2o`0001Oooooo0_l0000Cooooo`;o0000W?ooool000?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Ko
oooo00?o0000ooooooooool0@_ooool2o`0000?ooooo0_l00011ooooo`;o0000J_ooool2o`0004oo
oooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`?o
0000@_ooool2o`0000?ooooo0_l0000Iooooo`;o00009_ooool2o`0006[ooooo0_l0000Nooooo`;o
0000;oooool000?ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Ko
oooo00?o0000ooooooooool0Foooool4o`0000?ooooo0_l0002booooo`;o0000;oooool000?ooooo
00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000oooooooo
ool0Foooool4o`0007Oooooo0_l0000=ooooo`;o00001?ooool2o`0002kooooo0_l0000Zooooo`00
0oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`1Rooooo`;o0000L_ooool2o`0000gooooo0_l00004ooooo`;o00001oooool2o`0002Go
oooo0_l0000Zooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oo
ooooV9RHoa0@4006ooooo`03o`000?oooooooooo06;ooooo0_l0002@ooooo`;o0000>Oooool2o`00
01Kooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0:?ooool2o`0001Gooooo0_l0001?ooooo`;o00001Oooool2
o`0009Kooooo0_l0000Fooooo`007_ooool00ol0003oooooooooo`0Booooo`;o00005?ooool2o`00
01Gooooo0_l0000Dooooo`;o0000>Oooool2o`0000Gooooo0_l00014ooooo`;o0000C?ooool2o`00
01[ooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l00011ooooo`;o00009?ooool2o`0002?o
oooo0_l0000kooooo`;o00005?ooool2o`0003Kooooo0_l0000Jooooo`007_ooool00ol0003ooooo
ooooo`0Nooooo`;o00005Oooool2o`0004Cooooo0_l0000Sooooo`;o00001?ooool2o`0002gooooo
0_l0000@ooooo`;o00002_ooool2o`0002Gooooo0_l0000[ooooo`007_ooool00ol0003ooooooooo
o`0=ooooo`;o00003oooool2o`0001?ooooo1?l0000Yooooo`;o0000A?ooool2o`0002gooooo0_l0
000@ooooo`;o0000<Oooool2o`0002_ooooo000Nooooo`03o`000?oooooooooo00gooooo0_l0000T
ooooo`;o0000:oooool2o`000=Wooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0:oooo
o`;o00008_ooool4o`000;[ooooo0_l0000kooooo`;o00004?ooool2o`0000[ooooo000Nooooo`03
o`000?oooooooooo00Kooooo0_l00002ooooo`;o00008_ooool4o`000;[ooooo0_l0000Pooooo`;o
00006Oooool2o`0001cooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l000000ooooooo0000
o`00000Booooo`;o00005Oooool2o`0005Cooooo0_l00008ooooo`;o0000;?ooool2o`0004gooooo
1?l0000Jooooo`;o00006Oooool001kooooo00?o0000ooooooooool00oooool2o`0001Gooooo0_l0
000Eooooo`;o00003?ooool2o`0004Kooooo0_l00008ooooo`;o00004?ooool2o`0001[ooooo0_l0
001?ooooo`;o00006_ooool2o`0001Wooooo000Nooooo`03o`000?oooooooooo03gooooo1?l0000P
ooooo`;o0000@?ooool2o`0002Kooooo0_l0000gooooo`;o0000@Oooool001gooooo0_l0000ooooo
o`;o00004_ooool2o`0000kooooo0_l0001Xooooo`;o0000=oooool3o`00043ooooo000Mooooo`?o
0000D_ooool2o`000;;ooooo0_l00008ooooo`;o0000=_ooool001kooooo00?o0000ooooooooool0
4Oooool2o`00037ooooo0_l00039ooooo`;o0000=_ooool001kooooo00?o0000ooooooooool04Ooo
ool2o`0000Gooooo0_l0000Tooooo`;o00001?ooool2o`000?oooooo0_ooool001kooooo00?o0000
ooooooooool03Oooool2o`0000Kooooo0_l000000ooooooo0000o`00000Tooooo`;o00007oooool2
o`000>Kooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`;o00001_ooool2o`00
00Gooooo0_l0000Looooo`;o00008oooool2o`000;Oooooo0_l0000]ooooo`007_ooool00ol0003o
ooooooooo`04ooooo`;o00005_ooool2o`0001cooooo0_l0002Uooooo`;o0000=Oooool2o`0002go
oooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0000Booooo`;o0000Foooool2o`0001Wooooo
0_l00019ooooo`;o0000Coooool2o`0000Wooooo0_l00008ooooo`007_ooool00ol0003ooooooooo
o`0:ooooo`;o00004_ooool2o`0000Gooooo0_l0001Dooooo`;o00006Oooool2o`0004Wooooo0_l0
000[ooooo`;o00008_ooool2o`0000Wooooo0_l00008ooooo`007_ooool00ol0003oooooooooo`0U
ooooo`;o00003oooool2o`0005;ooooo0_l00022ooooo`;o0000<?ooool2o`0000Gooooo000Noooo
o`04o`000?ooooooooooooooo`;o0000<oooool2o`0002_ooooo0_l0000@ooooo`;o00004oooool2
o`0009Kooooo0_l0000Looooo`;o00001Oooool001kooooo00?o0000ooooool000000ol0000]oooo
o`;o0000<Oooool2o`00013ooooo0_l0002[ooooo`;o00008oooool001kooooo00Co0000ooooool0
003o00006Oooool2o`0001Cooooo0_l0003oooooo`Cooooo0_l0000@ooooo`007_ooool00ol0003o
ooooooooo`0Aooooo`;o00001oooool2o`000;Oooooo0_l0001Pooooo`;o00004?ooool001kooooo
00?o0000ooooooooool04Oooool2o`0000;ooooo0_l0000nooooo`;o0000O?ooool2o`0005Kooooo
0_l0000Jooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o0000?_ooool2o`0007[ooooo0_l0
000dooooo`;o00008_ooool2o`0001[ooooo000Nooooo`03o`000?oooooooooo03Oooooo0_l00015
ooooo`;o0000DOooool2o`0003Cooooo0_l0000nooooo`007_ooool2o`0003Sooooo0_l00014oooo
o`?o0000F_ooool2o`0004[ooooo0_l0000Oooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o
0000Hoooool2o`0003Oooooo0_l0000Rooooo`;o00002oooool2o`0003gooooo0_l0000Oooooo`00
7Oooool2o`0001[ooooo0_l0002Looooo`;o0000;oooool2o`0005kooooo000Mooooo`;o0000;ooo
ool2o`00023ooooo0_l0001Uooooo`;o0000Soooool001kooooo00?o0000ooooooooool0;Oooool2
o`00023ooooo0_l0003fooooo`007_ooool00ol0003oooooooooo`2^ooooo`;o0000Uoooool001ko
oooo00?o0000ooooooooool05oooool2o`0009Gooooo0_l0001`ooooo`;o00009Oooool001kooooo
00?o0000ooooooooool05oooool2o`0001_ooooo0_l0001>ooooo`;o0000V_ooool2o`0000Oooooo
0_l0000Looooo`007_ooool00ol0003oooooooooo`0Eooooo`;o00007Oooool2o`0004kooooo0_l0
002Oooooo`;o00000_ooool2o`0001cooooo000Nooooo`03o`000?oooooooooo01Gooooo0_l0001@
ooooo`?o00001Oooool2o`0004Cooooo0_l0001Gooooo`;o00000oooool2o`00013ooooo0_l0000P
ooooo`007_ooool2o`0000Wooooo0_l0001Mooooo`?o00001Oooool2o`0004Cooooo0_l0000boooo
o`;o00008oooool2o`0000?ooooo0_l0000Yooooo`;o00001oooool001kooooo0_l00009ooooo`;o
00003Oooool2o`0005oooooo0_l0001_ooooo`;o0000COooool2o`0000Cooooo0_l00007ooooo`00
7_ooool00ol0003oooooooooo`0Gooooo`;o0000=_ooool4o`0002Gooooo0ol0002looooo`?o0000
3Oooool001kooooo00?o0000ooooooooool0Coooool4o`00023ooooo0_l00004ooooo`;o00001ooo
ool2o`0009Kooooo0_l0000Kooooo`;o000000?oooooo`000?l000002oooool001kooooo00?o0000
ooooooooool0Loooool2o`0000gooooo0_l0001Aooooo`;o0000@oooool2o`0001kooooo0_l0000;
ooooo`007_ooool00ol0003oooooooooo`0Nooooo`;o0000A?ooool2o`0006oooooo0_l0000?oooo
o`;o00005_ooool2o`0003[ooooo0_l0000;ooooo`007_ooool2o`0001oooooo0_l00010ooooo`;o
00000_ooool2o`00083ooooo0_l0000Fooooo`;o00002oooool2o`0003[ooooo000Nooooo`?o0000
H?ooool2o`00073ooooo0_l0000gooooo`;o0000>_ooool001kooooo0ol0003Booooo`;o0000Looo
ool001kooooo00?o0000ooooooooool0N_ooool2o`0002Gooooo0_l0002Tooooo`007_ooool00ol0
003oooooooooo`0Cooooo`;o0000IOooool2o`0002Gooooo0_l0000:ooooo`;o00007?ooool2o`00
07[ooooo000Nooooo`03o`000?oooooooooo01?ooooo0_l0000Yooooo`;o0000?oooool2o`0002co
oooo0_l0000Looooo`;o0000N_ooool001kooooo00?o0000ooooooooool06Oooool2o`0002?ooooo
0_l0000oooooo`?o0000R?ooool2o`0003_ooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l0
000[ooooo`;o00001Oooool2o`00037ooooo0_l00028ooooo`;o0000>oooool001kooooo00?o0000
ooooooooool01?ooool2o`0001Kooooo0_l0000@ooooo`;o00005_ooool2o`0000Gooooo0_l0003h
ooooo`007_ooool00ol0003oooooooooo`04ooooo`;o00005_ooool2o`0000;ooooo0_l0000:oooo
o`Co0000h?ooool2o`0003Gooooo000Nooooo`03o`000?oooooooooo023ooooo0_l0000:ooooo`;o
0000h_ooool2o`0003Gooooo000Nooooo`03o`000?oooooooooo03Kooooo0_l0000Eooooo`;o0000
7oooool2o`0002Gooooo0_l0001cooooo`;o0000>oooool001kooooo00?o0000ooooooooool08?oo
ool2o`0001Cooooo0_l0000Eooooo`;o00004Oooool2o`0000cooooo0_l0000Uooooo`;o0000G?oo
ool2o`0001Gooooo0_l0000kooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o00004Oooool2
o`0003kooooo0_l0002Aooooo`;o0000D_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool03Oooool2
o`0001cooooo0_l00008ooooo`;o0000D_ooool2o`0006kooooo0_l0001<ooooo`000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0:oooool2o`0000Sooooo0_l0000Xooooo`;o0000:?ooool2o`0000Gooooo0_l0001W
ooooo`;o0000C?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool3
o`0000oooooo0_l0000Dooooo`Co00008_ooool2o`0001;ooooo0_l0000_ooooo`;o0000]Oooool0
00?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o
0000ooooooooool03oooool2o`0000;ooooo0_l0000@ooooo`Co00008_ooool2o`0005Kooooo0_l0
002Rooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo0000
1oooool00ol0003oooooooooo`07ooooo`;o00002_ooool2o`0008kooooo0_l0002Rooooo`000ooo
ool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003ooooo
ooooo`07ooooo`;o0000I_ooool2o`000=Kooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo05_ooooo0_l0000Booooo`;o0000
W_ooool3o`0003Gooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000
ooooo`06ooooo`03o`000?oooooooooo05_ooooo0_l000000ooooooo0000o`00001Booooo`;o0000
C_ooool2o`0000_ooooo0ol0000eooooo`007_ooool00ol0003oooooooooo`1>ooooo`;o00003_oo
ool2o`0005;ooooo0_l0001>ooooo`;o00009Oooool2o`0001cooooo000Nooooo`03o`000?oooooo
oooo03Gooooo0_l0000Gooooo`;o0000:Oooool2o`0003Oooooo0ol0000Vooooo`;o00003oooool2
o`0001Oooooo0_l0000Rooooo`;o00007?ooool001kooooo00?o0000ooooooooool00oooool2o`00
033ooooo0_l0000Aooooo`;o00006Oooool2o`0001Cooooo0_l0000hooooo`;o00009_ooool2o`00
00oooooo0_l0000Gooooo`;o0000@?ooool001kooooo00?o0000ooooooooool00oooool2o`0003Wo
oooo0_l00008ooooo`;o00002oooool2o`0000cooooo0_l0003Rooooo`007_ooool00ol0003ooooo
ooooo`0nooooo`;o00005Oooool2o`00027ooooo0_l0003=ooooo`007_ooool00ol0003ooooooooo
o`0>ooooo`;o0000=Oooool2o`0001Gooooo0_l0000Jooooo`;o0000HOooool2o`0005kooooo0_l0
000:ooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o00007oooool2o`0001Cooooo0_l0000E
ooooo`;o00004_ooool2o`0001oooooo0_l00018ooooo`;o0000G_ooool2o`0000[ooooo000Noooo
o`03o`000?oooooooooo01oooooo0_l0000>ooooo`;o00005_ooool2o`0002Oooooo0_l00008oooo
o`;o00005Oooool2o`0004Gooooo0_l0001>ooooo`;o00007Oooool001kooooo00?o0000oooooooo
ool05_ooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000002o`00027o
oooo0_l0000aooooo`;o0000G?ooool2o`0002Wooooo0_l0000Sooooo`;o00007Oooool001kooooo
00?o0000ooooooooool05?ooool4o`000003ooooool0003o000000;o00001Oooool4o`0003_ooooo
0_l0000:ooooo`;o0000U?ooool2o`0004;ooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0
0005ooooo`;o00002?ooool2o`0003;ooooo0_l00006ooooo`;o00002_ooool2o`000=Sooooo000N
ooooo`;o00005Oooool2o`0000oooooo0_l0000booooo`;o00008oooool2o`0008cooooo0_l0000i
ooooo`007_ooool00ol0003oooooooooo`0cooooo`;o00005?ooool2o`0001Gooooo0_l0000Loooo
o`;o00009_ooool2o`0005_ooooo0_l00007ooooo`;o0000>Oooool001kooooo00?o0000oooooooo
ool0<oooool2o`0000;ooooo0_l0000@ooooo`;o00005Oooool2o`0002Sooooo0_l0000Jooooo`;o
00000_ooool2o`0003;ooooo0_l0000Sooooo`Co00006Oooool2o`0002Gooooo000Nooooo`03o`00
0?oooooooooo00Cooooo0_l0000aooooo`;o0000DOooool2o`0000Wooooo0ol0000Booooo`;o0000
<_ooool2o`0002Gooooo0_l0000Iooooo`;o00009Oooool001kooooo00?o0000ooooooooool01?oo
ool2o`0008oooooo0ol0002_ooooo`007_ooool00ol0003oooooooooo`2Cooooo`;o00006oooool2
o`0001Gooooo0_l0001:ooooo`;o0000<_ooool001kooooo00?o0000ooooooooool0A_ooool2o`00
01_ooooo0_l0000^ooooo`;o00006oooool2o`0001Gooooo0_l0000Kooooo`;o0000;Oooool2o`00
03;ooooo000Nooooo`03o`000?oooooooooo04Kooooo0_l0000Kooooo`;o0000Ooooool2o`00067o
oooo000Nooooo`03o`000?oooooooooo037ooooo0_l0000Dooooo`;o0000o_ooool001kooooo00?o
0000ooooooooool0<Oooool2o`0001Cooooo0_l0000;ooooo`;o0000c_ooool2o`00027ooooo000N
ooooo`03o`000?oooooooooo05?ooooo0ol00003ooooo`;o00006_ooool2o`0005cooooo0_l0000[
ooooo`;o00008_ooool2o`00027ooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l0000koooo
o`;o00001?ooool2o`0001[ooooo0_l0001Looooo`;o0000:oooool2o`0003_ooooo0_l00008oooo
o`007_ooool00ol0003oooooooooo`0Fooooo`;o0000K?ooool2o`0009_ooooo0_l0000Jooooo`;o
00002?ooool001kooooo00?o0000ooooooooool01?ooool2o`0007kooooo0_l0002Kooooo`;o0000
9?ooool001kooooo00?o0000ooooooooool01?ooool2o`000?oooooo@_ooool001kooooo00?o0000
ooooooooool0F?ooool2o`0003_ooooo0_l0001nooooo`;o0000<?ooool001kooooo0_l0000ooooo
o`;o00006?ooool2o`0001kooooo0_l0000Kooooo`;o0000O_ooool2o`0000Kooooo0_l0000Xoooo
o`007_ooool00ol0003oooooooooo`0nooooo`;o0000>?ooool2o`000:?ooooo0_l0000Xooooo`00
7_ooool00ol0003oooooooooo`0^ooooo`;o0000;oooool2o`000>Kooooo000Nooooo`03o`000?oo
oooooooo013ooooo0_l0000Looooo`;o00003oooool2o`0001kooooo0_l0001Zooooo`;o0000N_oo
ool001kooooo00?o0000ooooooooool03Oooool2o`000003ooooool0003o000001;ooooo0_l0000I
ooooo`;o0000@_ooool2o`0004Kooooo0_l0001Xooooo`;o00004?ooool001kooooo00?o0000oooo
ooooool02_ooool2o`000003ooooool0003o000000;ooooo0_l0000Aooooo`;o0000GOooool2o`00
08Sooooo0_l0000Rooooo`;o00000_ooool2o`00013ooooo000Nooooo`03o`000?oooooooooo00[o
oooo0_l00005ooooo`;o0000]_ooool2o`0004;ooooo0_l0000Rooooo`;o00005?ooool001kooooo
00?o0000ooooooooool0<Oooool2o`0009Kooooo0_l0001Xooooo`;o00004_ooool001kooooo00?o
0000ooooooooool0<Oooool2o`0001Kooooo0_l00012ooooo`;o0000X_ooool4o`0001;ooooo000N
ooooo`03o`000?oooooooooo04Wooooo0_l0000@ooooo`;o0000<?ooool2o`0008kooooo0_l0000B
ooooo`;o00005?ooool001kooooo00?o0000ooooooooool0Foooool2o`0007;ooooo0_l0000boooo
o`;o00006?ooool2o`0002Sooooo000Nooooo`03o`000?oooooooooo05Sooooo0_l0000iooooo`;o
0000>_ooool2o`0003;ooooo0_l0000Hooooo`;o00003?ooool2o`0001[ooooo000Nooooo`03o`00
0?oooooooooo05Sooooo0_l0000Sooooo`;o00005?ooool2o`0007gooooo0_l0000Gooooo`;o0000
6_ooool001kooooo00?o0000ooooooooool09Oooool2o`000003ooooool0003o000005?ooooo0_l0
000gooooo`;o00006?ooool2o`0003[ooooo0_l00004ooooo`;o0000<oooool001kooooo00?o0000
ooooooooool05oooool2o`0000cooooo0_l000000ooooooo0000o`00002<ooooo`;o00001oooool2
o`0000Gooooo0_l00008ooooo`;o0000>_ooool2o`0002Wooooo0_l0000>ooooo`007_ooool00ol0
003oooooooooo`0Gooooo`;o0000SOooool2o`0000?ooooo0_l0000Booooo`;o00001Oooool2o`00
03Wooooo0_l0000dooooo`;o00003_ooool001kooooo0_l0001Yooooo`;o00009oooool2o`0001?o
oooo0_l00003ooooo`;o00003_ooool2o`0004Cooooo0_l00014ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`;o0000FOooool2o`0001Gooooo0_l0000@ooooo`;o00006?ooool2o`0000kooooo
0_l0001Sooooo`;o00009Oooool001kooooo00?o0000ooooooooool03Oooool2o`0001cooooo0_l0
0014ooooo`;o00003?ooool2o`0002[ooooo0_l0000Hooooo`;o00008Oooool2o`0002;ooooo0_l0
000Booooo`;o00009Oooool001kooooo00?o0000ooooooooool0:oooool2o`0001Sooooo0_l0000Z
ooooo`;o0000D_ooool4o`0001oooooo0_l0000Rooooo`;o0000>Oooool001kooooo00?o0000oooo
ooooool0AOooool2o`0001Kooooo0_l0001Xooooo`;o0000<oooool2o`0001cooooo0_l0000[oooo
o`007_ooool00ol0003oooooooooo`1Mooooo`;o0000WOooool2o`0001cooooo0_l00009ooooo`;o
00008?ooool001kooooo00?o0000ooooooooool0Coooool2o`000=Cooooo0_l0000>ooooo`;o0000
4?ooool001kooooo00?o0000ooooooooool0Coooool2o`000>Cooooo0_l0000@ooooo`007_ooool0
0ol0003oooooooooo`2Booooo`;o00007_ooool2o`0001_ooooo0_l0001fooooo`007_ooool00ol0
003oooooooooo`0Eooooo`Co00003oooool2o`0003_ooooo0_l0000Pooooo`;o00002Oooool2o`00
01kooooo0_l0000Kooooo`;o0000E_ooool2o`0001kooooo000Nooooo`03o`000?oooooooooo01Go
oooo1?l0000?ooooo`;o0000>oooool2o`0001gooooo0_l000000ooooooo0000o`00001Xooooo`;o
0000=?ooool2o`0001kooooo000Nooooo`03o`000?oooooooooo03Cooooo0_l00009ooooo`;o0000
@oooool2o`0000Sooooo0_l0001Qooooo`;o0000>Oooool2o`0001Wooooo000Nooooo`03o`000?oo
oooooooo02oooooo0_l00003ooooo`;o00002Oooool2o`0004Cooooo0_l00007ooooo`;o0000N?oo
ool2o`0002;ooooo0_l0000Iooooo`007_ooool3o`0002oooooo0_l0000kooooo`;o00005oooool2
o`0006Kooooo0_l0000Iooooo`;o00008?ooool4o`0001Wooooo0003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`?o0000K?oo
ool2o`0007oooooo0_l0000Hooooo`;o00002?ooool2o`0001Oooooo1?l0000Iooooo`000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40
1_ooool00ol0003oooooooooo`1Zooooo`;o0000:oooool2o`0000Gooooo0_l0000>ooooo`;o0000
;_ooool2o`0001kooooo0_l00007ooooo`;o00002?ooool2o`0003Cooooo0003ooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0001Zooooo`;o
0000:oooool2o`0000Gooooo0_l0000>ooooo`;o0000;_ooool2o`0001kooooo0_l00017ooooo`00
0oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06oooo
o`03o`000?oooooooooo06?ooooo0_l0000Uooooo`;o0000^oooool000?ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`1N
ooooo`;o00000oooool2o`0000Kooooo0_l0000Mooooo`;o0000Noooool2o`0003kooooo0003oooo
o`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooo
oooo05kooooo0_l00009ooooo`Co00005oooool2o`00087ooooo0_l0000nooooo`000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`02
ooooo`;o0000IOooool2o`00017ooooo0_l00006ooooo`;o0000G_ooool2o`00067ooooo0003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oo
oooooooo00;ooooo0_l0000Wooooo`;o0000Coooool2o`0006Kooooo0_l0000[ooooo`;o0000=?oo
ool001kooooo00?o0000ooooooooool0:oooool2o`0002Sooooo0_l0000`ooooo`;o0000R?ooool2
o`0001_ooooo0_l0000Gooooo`007_ooool00ol0003oooooooooo`02ooooo`;o0000DOooool2o`00
033ooooo0_l0002<ooooo`;o00005oooool2o`00017ooooo0_l00004ooooo`007_ooool00ol0003o
ooooooooo`02ooooo`;o0000>oooool2o`0001Gooooo0_l00003ooooo`;o00005oooool2o`0003_o
oooo0_l0001;ooooo`;o00003Oooool2o`0000Kooooo0_l0000Zooooo`;o00001?ooool001kooooo
00?o0000ooooooooool0?oooool2o`0001Gooooo0_l00003ooooo`;o00005oooool2o`0000Sooooo
0_l0000aooooo`;o00002Oooool2o`00043ooooo1?l0000;ooooo`;o0000>?ooool001kooooo00?o
0000ooooooooool0HOooool2o`0001_ooooo0_l0000Oooooo`;o00006?ooool2o`000003ooooool0
003o000000Wooooo0_l0000gooooo`;o0000AOooool001kooooo00?o0000ooooooooool08oooool2
o`0003cooooo0_l0000looooo`;o00006?ooool2o`0000cooooo0_l0000Booooo`;o0000>?ooool4
o`0000[ooooo0_l0000Rooooo`007_ooool00ol0003oooooooooo`0Nooooo`;o00000oooool2o`00
03oooooo0_l0001<ooooo`;o00002_ooool2o`0001Gooooo0_l00004ooooo`;o0000>?ooool4o`00
00[ooooo0_l0000Rooooo`007_ooool00ol0003oooooooooo`0Nooooo`;o00009oooool2o`0001_o
oooo0_l0000Qooooo`;o0000:Oooool2o`0000[ooooo0_l0000Eooooo`;o00004?ooool2o`0005ko
oooo000Nooooo`03o`000?oooooooooo03?ooooo0_l0000Booooo`;o0000?_ooool2o`0005kooooo
0_l00010ooooo`;o00007?ooool001kooooo00?o0000ooooooooool0<oooool2o`0002_ooooo0_l0
0037ooooo`;o00007?ooool001kooooo00?o0000ooooooooool0H?ooool2o`0004Oooooo0_l0001a
ooooo`;o0000:Oooool001kooooo0_l0000Cooooo`;o0000Aoooool2o`0004cooooo0_l000000ooo
oooo0000o`000006ooooo`;o0000I_ooool2o`0002Wooooo000Nooooo`03o`000?oooooooooo01;o
oooo0_l0000cooooo`;o00001oooool2o`0000Wooooo0_l0000mooooo`;o00004?ooool4o`0000Co
oooo0_l0000Rooooo`;o00001?ooool2o`0006Oooooo000Nooooo`03o`000?oooooooooo02Wooooo
0_l0000Looooo`;o00001oooool2o`00037ooooo0_l0000Eooooo`;o00002Oooool2o`0000Oooooo
0_l0000Sooooo`;o00000oooool2o`0000Cooooo0_l0000fooooo`;o0000;oooool001kooooo00?o
0000ooooooooool0:Oooool2o`0005Sooooo0_l0000Pooooo`;o0000;?ooool2o`0003Cooooo0_l0
000;ooooo`;o00003?ooool2o`00027ooooo000Nooooo`03o`000?oooooooooo06;ooooo0_l0000:
ooooo`;o0000AOooool2o`0005;ooooo0_l0000Iooooo`;o00001oooool2o`0001Sooooo000Noooo
o`03o`000?oooooooooo04Kooooo0_l0000Jooooo`;o00001?ooool2o`0000Cooooo0_l00015oooo
o`;o0000@Oooool2o`0002Wooooo0_l00008ooooo`;o00006?ooool001kooooo00?o0000oooooooo
ool0A_ooool2o`0001Kooooo0_l00008ooooo`Co0000S?ooool2o`0002Wooooo0_l0000Rooooo`00
7_ooool00ol0003oooooooooo`07ooooo`;o0000>Oooool2o`0001[ooooo0_l0000:ooooo`;o0000
foooool001kooooo00?o0000ooooooooool01?ooool2o`000003ooooool0003o000002?ooooo0_l0
000Dooooo`;o00008Oooool2o`0000_ooooo0_l0000?ooooo`;o0000=?ooool2o`0003Oooooo0_l0
001Cooooo`007_ooool00ol0003oooooooooo`04ooooo`;o00002Oooool2o`0001_ooooo0_l0000g
ooooo`;o00002oooool2o`0000Kooooo0_l00007ooooo`;o0000=?ooool2o`0003Oooooo0_l0001C
ooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o00005Oooool2o`0005;ooooo0_l00003oooo
o`;o0000Roooool2o`0003Wooooo000Nooooo`03o`000?oooooooooo02Cooooo1?l00016ooooo`;o
00003oooool2o`0003Cooooo0_l0001Eooooo`;o0000>Oooool001kooooo00?o0000ooooooooool0
9?ooool2o`0004Sooooo0_l00015ooooo`;o0000;oooool2o`0005oooooo000Nooooo`03o`000?oo
oooooooo01Gooooo0_l0001[ooooo`;o00002?ooool2o`00027ooooo0_l0000eooooo`;o0000Gooo
ool001kooooo00?o0000ooooooooool05Oooool2o`0006_ooooo0_l00008ooooo`;o00008Oooool2
o`00057ooooo0_l00013ooooo`007_ooool00ol0003oooooooooo`1_ooooo`;o0000L?ooool2o`00
01oooooo0_l0000hooooo`;o00002Oooool001kooooo0_l0001`ooooo`;o0000L?ooool2o`0005Wo
oooo0_l00009ooooo`007_ooool00ol0003oooooooooo`0Uooooo`;o0000mOooool2o`0002Wooooo
000Nooooo`03o`000?oooooooooo02Gooooo0_l0001Qooooo`;o00003Oooool2o`0005Sooooo0_l0
000Yooooo`;o00004Oooool2o`0001Kooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l00009
ooooo`;o00003Oooool2o`0005?ooooo0_l0000=ooooo`;o0000F?ooool2o`0002Gooooo0_l0000E
ooooo`;o00005_ooool001kooooo00?o0000ooooooooool06Oooool2o`0000Wooooo0_l0000=oooo
o`;o0000ROooool2o`0003[ooooo0_l0000Looooo`;o0000;Oooool001kooooo00?o0000oooooooo
ool0>_ooool2o`0000Kooooo0_l0001jooooo`;o0000>_ooool2o`0003Cooooo0_l00003ooooo`;o
00004?ooool001kooooo00?o0000ooooooooool0>_ooool2o`0000Kooooo0_l00016ooooo`;o0000
Y?ooool2o`0000?ooooo0_l0000@ooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o0000JOoo
ool2o`0008Cooooo0_l0000eooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o00007?ooool2
o`0007gooooo0_l00017ooooo`?o00002?ooool2o`0000kooooo0_l0000Uooooo`007_ooool00ol0
003oooooooooo`0Hooooo`;o00008oooool2o`0007gooooo0_l0000@ooooo`;o0000=Oooool3o`00
01Sooooo0_l00002ooooo`;o00008Oooool001kooooo00?o0000ooooooooool04_ooool2o`0000?o
oooo0ol0000Uooooo`;o0000J?ooool2o`0002?ooooo0_l0001Dooooo`;o00003oooool2o`00013o
oooo000Nooooo`03o`000?oooooooooo01;ooooo0_l00003ooooo`;o00000oooool2o`00027ooooo
0_l0000mooooo`;o00001oooool2o`00023ooooo0_l00015ooooo`;o0000@oooool2o`00013ooooo
000Nooooo`03o`000?oooooooooo01cooooo0_l0000Hooooo`;o0000A_ooool2o`0000Oooooo0_l0
001Wooooo`;o00003_ooool2o`0004Gooooo000Nooooo`03o`000?oooooooooo03Kooooo0_l0000V
ooooo`;o0000X?ooool2o`0004Gooooo000Nooooo`03o`000?oooooooooo02oooooo0_l0000]oooo
o`;o0000E?ooool2o`0000kooooo0_l0001Vooooo`;o00006Oooool001kooooo00?o0000oooooooo
ool02oooool2o`0001?ooooo0_l0000=ooooo`;o0000@Oooool2o`0000cooooo0_l0000booooo`;o
00003_ooool2o`000003ooooool0003o000006?ooooo0_l0000Iooooo`007_ooool2o`0000cooooo
0_l0000Cooooo`;o0000?Oooool2o`00017ooooo0_l0000<ooooo`;o0000AOooool2o`0001gooooo
0_l00006ooooo`;o00007_ooool2o`0002_ooooo0_l0000:ooooo`007_ooool00ol0003ooooooooo
o`0Xooooo`;o0000=Oooool2o`0002cooooo0_l00006ooooo`;o0000Coooool2o`0000Kooooo0_l0
000Nooooo`;o00005_ooool2o`0001;ooooo0ol0000:ooooo`007_ooool00ol0003oooooooooo`0X
ooooo`;o00002Oooool2o`0005Sooooo0_l00006ooooo`;o0000>?ooool2o`0000?ooooo0_l0001@
ooooo`;o00004_ooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo03?ooooo0_l0001]oooo
o`;o00008Oooool2o`0000Sooooo0_l00003ooooo`;o0000B?ooool2o`0002Oooooo000Nooooo`03
o`000?oooooooooo09_ooooo0_l00005ooooo`;o00008Oooool2o`0000Gooooo0_l0000Vooooo`;o
0000:?ooool2o`0002Oooooo000Nooooo`03o`000?oooooooooo05Sooooo0_l0000Pooooo`;o0000
7oooool2o`0002oooooo0_l0000Vooooo`;o00003oooool2o`0001Oooooo0_l0000Pooooo`;o0000
1Oooool001kooooo00?o0000ooooooooool0:?ooool2o`0002kooooo0_l0000Pooooo`Co0000L_oo
ool2o`0001?ooooo0_l0000Gooooo`;o00008?ooool2o`0000Gooooo000Nooooo`03o`000?oooooo
oooo00[ooooo0_l0000Looooo`;o0000DOooool3o`0007;ooooo0_l00002ooooo`?o0000D?ooool0
01kooooo00?o0000ooooooooool02_ooool2o`0006oooooo0_l0000@ooooo`;o0000IOooool3o`00
02Kooooo0_l0000Xooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o0000??ooool2o`0002[o
oooo0_l0001Jooooo`;o0000<_ooool2o`0002Sooooo000Nooooo`03o`000?oooooooooo02?ooooo
0_l0000Rooooo`;o00003oooool2o`0000Cooooo0_l000000ooooooo0000o`000006ooooo`;o0000
:?ooool2o`0002Oooooo0_l00007ooooo`;o00008_ooool2o`0002?ooooo0_l0000Qooooo`;o0000
5?ooool001kooooo00?o0000ooooooooool0Aoooool2o`0000oooooo0_l00004ooooo`;o00002Ooo
ool2o`0002Sooooo0_l0000Wooooo`;o00001oooool2o`0003[ooooo0_l00002ooooo`;o00001ooo
ool2o`00027ooooo0_l0000Dooooo`007_ooool00ol0003oooooooooo`2Gooooo`;o0000J?ooool2
o`0000;ooooo0_l00007ooooo`;o0000=oooool001kooooo00?o0000ooooooooool0H_ooool2o`00
00?ooooo1?l0000Cooooo`;o00005oooool2o`0001kooooo0_l0000Aooooo`;o0000Noooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0??ooool2o`0002Cooooo0_l00003ooooo`Co00003_ooool2
o`0000?ooooo0_l00004ooooo`Co0000;oooool2o`00017ooooo0_l0000Pooooo`;o0000FOooool0
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonH
V9So8B4Q00Kooooo00?o0000ooooooooool0??ooool2o`0003_ooooo0_l00009ooooo`Co00001ooo
ool2o`0004Wooooo0_l0000@ooooo`;o0000FOooool000?ooooo00Go410@oooooooooooooooooa0@
400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`0007Kooooo0_l0000Gooooo`;o0000
BOooool2o`00047ooooo0ol0000Wooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo
00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooooooo03;ooooo0_l00012ooooo`;o
00002_ooool2o`0003Kooooo0_l00017ooooo`;o00004?ooool2o`0000Kooooo0ol0000Dooooo`;o
00004Oooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`00
0?o<c<`01_ooool00ol0003oooooooooo`0@ooooo`;o00008?ooool2o`00013ooooo0ol0000?oooo
o`?o0000:Oooool2o`0003Kooooo0_l0000mooooo`;o00002?ooool2o`00013ooooo0_l0000;oooo
o`;o00003_ooool4o`00017ooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@
413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool04?ooool2o`00023ooooo0_l0000@
ooooo`?o00003oooool3o`0001Sooooo0_l00026ooooo`;o00009oooool2o`0000kooooo0_l0000C
ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00
0006ooooo`03o`000?oooooooooo03;ooooo0_l0000looooo`?o0000POooool2o`0001cooooo0_l0
000@ooooo`;o00002_ooool2o`0001Gooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0>oooool4o`0002kooooo
0_l000000ooooooo0000o`000022ooooo`;o00007?ooool2o`00013ooooo0_l0000:ooooo`;o0000
5Oooool001kooooo00?o0000ooooooooool0>oooool4o`0002kooooo0_l0000Aooooo`;o0000aOoo
ool001kooooo00?o0000ooooooooool09_ooool2o`0001cooooo0_l0000Zooooo`;o00003_ooool2
o`0000Sooooo0_l0002kooooo`007_ooool00ol0003oooooooooo`06ooooo`;o00007_ooool2o`00
00?ooooo0_l0000Gooooo`;o00005Oooool2o`0001?ooooo0_l0000Hooooo`;o0000??ooool2o`00
01gooooo0_l0000nooooo`;o00005_ooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo00Ko
oooo0_l0000Sooooo`;o00006_ooool2o`0001;ooooo0_l000000ooooooo0000o`00000?ooooo`;o
0000Eoooool2o`0001gooooo0_l0000nooooo`;o00004oooool2o`000003ooooool0003o000000Ko
oooo000Nooooo`03o`000?oooooooooo04Oooooo0_l0000Eooooo`;o00003oooool2o`0006[ooooo
0_l0001Oooooo`;o00002Oooool001kooooo00?o0000ooooooooool0??ooool2o`0001Cooooo0_l0
0027ooooo`;o00005_ooool2o`0001gooooo0_l0000cooooo`007_ooool00ol0003oooooooooo`0]
ooooo`;o00003Oooool2o`0000Sooooo0_l0000:ooooo`;o00001Oooool2o`0009Sooooo0_l0000M
ooooo`;o0000<oooool001kooooo00?o0000ooooooooool0:oooool4o`0001Cooooo0_l000000ooo
oooo0000o`00000Aooooo`;o00004?ooool2o`00077ooooo0_l00008ooooo`;o00000oooool2o`00
05Sooooo000Nooooo`03o`000?oooooooooo02_ooooo0_l00007ooooo`;o00003Oooool2o`0001ko
oooo0_l00006ooooo`;o00002?ooool2o`0006Oooooo0_l00008ooooo`;o00000oooool2o`0005So
oooo000Nooooo`03o`000?oooooooooo03Cooooo0_l0000Qooooo`;o00002_ooool2o`00013ooooo
0_l0000;ooooo`;o0000`oooool001kooooo00?o0000ooooooooool0Eoooool2o`0001Gooooo0_l0
000Booooo`;o0000Noooool2o`0002cooooo0_l0000=ooooo`;o00002Oooool001kooooo0_l0001_
ooooo`;o00009oooool2o`0005cooooo0_l00008ooooo`;o0000;?ooool2o`0000gooooo0_l00009
ooooo`007_ooool00ol0003oooooooooo`2Gooooo`;o00002Oooool2o`0000Kooooo0_l0000Ioooo
o`;o0000;_ooool2o`00053ooooo000Nooooo`03o`000?oooooooooo00oooooo0_l00015ooooo`;o
00002_ooool2o`0003kooooo0_l00006ooooo`;o00006Oooool2o`0006Sooooo0_l0000Fooooo`00
7_ooool00ol0003oooooooooo`03ooooo`;o00002_ooool2o`0004Gooooo0_l0000:ooooo`;o0000
3?ooool2o`0001?ooooo0_l0000Iooooo`;o0000SOooool2o`0001Kooooo000Mooooo`;o00001Ooo
ool2o`0005Cooooo0_l0000Eooooo`;o00004oooool2o`0001Wooooo0_l0000:ooooo`;o00001?oo
ool2o`00063ooooo0_l0000Iooooo`;o00005_ooool001gooooo0_l00008ooooo`;o0000COooool2
o`0000;ooooo0_l00003ooooo`;o0000C?ooool2o`0000Cooooo0_l0000Fooooo`;o0000B?ooool2
o`00037ooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l0000`ooooo`;o00006oooool2o`00
00Oooooo0_l0000Kooooo`;o00005_ooool2o`0001[ooooo0_l0000;ooooo`;o00003?ooool2o`00
05;ooooo0_l0000Wooooo`007_ooool00ol0003oooooooooo`0cooooo`;o00000oooool2o`00047o
oooo0ol0000<ooooo`;o00001oooool2o`0001[ooooo0_l0000;ooooo`;o00006Oooool2o`00013o
oooo0_l0000cooooo`;o00009oooool001kooooo00?o0000ooooooooool07oooool2o`0001;ooooo
0_l0000Hooooo`;o0000;Oooool2o`0000cooooo0_l0001;ooooo`;o00004?ooool2o`0005cooooo
000Nooooo`03o`000?oooooooooo00Oooooo0_l0000Fooooo`;o0000;?ooool2o`000?Sooooo000N
ooooo`03o`000?oooooooooo00Oooooo0_l0001Nooooo`;o0000<_ooool2o`0003Cooooo0_l0001W
ooooo`;o00002oooool001kooooo00?o0000ooooooooool09Oooool2o`00043ooooo0_l0000boooo
o`;o0000=?ooool2o`0006Oooooo0_l00005ooooo`;o00001?ooool001kooooo00?o0000oooooooo
ool09Oooool2o`0006kooooo0_l00007ooooo`;o00007_ooool2o`00087ooooo0_l00004ooooo`00
7_ooool00ol0003oooooooooo`1Nooooo`;o0000;_ooool2o`0000Gooooo0_l00007ooooo`;o0000
7_ooool2o`0003gooooo0_l00018ooooo`007_ooool00ol0003oooooooooo`1Nooooo`;o00008ooo
ool2o`0000Wooooo0_l00011ooooo`;o0000:_ooool2o`0004Sooooo000Nooooo`03o`000?oooooo
oooo01oooooo0_l0001Rooooo`;o0000C?ooool2o`0004Kooooo0_l0000/ooooo`007_ooool2o`00
023ooooo0_l0002iooooo`;o0000?Oooool2o`0000Cooooo0_l0000Vooooo`007_ooool00ol0003o
ooooooooo`0Looooo`;o0000Z?ooool2o`0001;ooooo0_l0000Cooooo`;o0000;_ooool2o`0002Ko
oooo000Nooooo`03o`000?oooooooooo01cooooo0_l0000_ooooo`;o0000Moooool2o`0002Oooooo
0_l0000booooo`;o00006oooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo04gooooo0_l0
0003ooooo`;o00006oooool2o`0001gooooo0_l00003ooooo`;o0000A_ooool3o`0002Cooooo0_l0
000Oooooo`;o00006oooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo023ooooo0_l0000<
ooooo`;o00008_ooool2o`0001_ooooo0_l0000Mooooo`;o00000oooool2o`0004Kooooo0ol0000T
ooooo`;o0000@oooool001kooooo0_l0000Qooooo`;o00003?ooool2o`0005_ooooo0_l0002joooo
o`007_ooool2o`000003ooooool0003o000001gooooo0_l0001Zooooo`;o0000C_ooool2o`0003Wo
oooo0_l0000_ooooo`007_ooool00ol0003oooooooooo`02o`0001gooooo0_l00006ooooo`;o0000
/_ooool2o`0003Wooooo0_l0000?ooooo`;o00007_ooool001kooooo00?o0000ooooooooool09ooo
ool2o`0000Gooooo0_l0000Gooooo`;o0000g_ooool2o`00017ooooo0_l0000;ooooo`007_ooool0
0ol0003oooooooooo`0^ooooo`;o000000?oooooo`000?l000005?ooool2o`0002Kooooo0_l0002;
ooooo`;o00003oooool2o`0002_ooooo0_l0000;ooooo`007_ooool2o`0003;ooooo0_l0000Zoooo
o`;o00003_ooool4o`0002Oooooo0_l0001Rooooo`;o00003oooool2o`0000gooooo0_l0000Yoooo
o`007_ooool2o`0005?ooooo0_l00002ooooo`;o00001Oooool2o`0000kooooo0_l0000?ooooo`;o
00006?ooool2o`0006oooooo0_l0000Aooooo`;o0000:Oooool001kooooo00?o0000ooooooooool0
D_ooool2o`0000;ooooo0_l0000Vooooo`;o00005_ooool2o`0002Cooooo0_l0001;ooooo`;o0000
??ooool001kooooo00?o0000ooooooooool0Koooool2o`0000Wooooo0_l00002ooooo`;o00005_oo
ool2o`0002Cooooo0_l00029ooooo`007_ooool00ol0003oooooooooo`11ooooo`;o0000;?ooool2
o`0000Wooooo0_l00002ooooo`;o0000aoooool001kooooo00?o0000ooooooooool0<?ooool2o`00
00Sooooo0_l00005ooooo`;o00004oooool2o`0004[ooooo0_l0002Sooooo`007_ooool2o`00037o
oooo0_l00008ooooo`;o00000_ooool2o`0001Kooooo0_l0001:ooooo`;o0000:Oooool2o`0007So
oooo000Nooooo`03o`000?oooooooooo03kooooo0_l0001nooooo`;o00003Oooool2o`0000cooooo
0_l0000fooooo`;o0000<_ooool001kooooo00?o0000ooooooooool0Joooool2o`00057ooooo0_l0
000Kooooo`;o0000=_ooool2o`0003;ooooo000Nooooo`03o`000?oooooooooo06_ooooo0_l0000;
ooooo`;o0000BOooool2o`00037ooooo0_l0001?ooooo`007_ooool00ol0003oooooooooo`1:oooo
o`;o0000;?ooool2o`0004Wooooo0_l0000aooooo`;o0000Coooool001kooooo00?o0000oooooooo
ool0B_ooool2o`0004kooooo0_l0001@ooooo`;o0000FOooool001kooooo00?o0000ooooooooool0
V_ooool2o`0001gooooo0_l0000aooooo`;o0000=?ooool2o`0002?ooooo000Nooooo`03o`000?oo
oooooooo01cooooo0_l0001fooooo`;o00008oooool2o`0006Oooooo0_l0000Sooooo`007_ooool0
0ol0003oooooooooo`0Looooo`;o00007_ooool2o`0005Kooooo0_l0000Booooo`;o0000WOooool0
01kooooo00?o0000ooooooooool0??ooool4o`0000Gooooo0_l0001Qooooo`;o00009?ooool2o`00
04cooooo0_l0000Oooooo`;o00002?ooool001kooooo00?o0000ooooooooool0?_ooool2o`0000Go
oooo0_l00005ooooo`;o0000P?ooool2o`0001_ooooo0_l0000_ooooo`;o00007oooool2o`0000So
oooo000Nooooo`03o`000?oooooooooo00Kooooo0_l00014ooooo`;o00000oooool2o`0005?ooooo
0_l00013ooooo`;o00001_ooool2o`0005;ooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l0
000;ooooo`;o0000??ooool2o`0000Kooooo0_l0000aooooo`;o00006?ooool2o`0003Gooooo0_l0
000Dooooo`;o0000<oooool2o`0001gooooo000Nooooo`03o`000?oooooooooo01?ooooo0_l00014
ooooo`;o0000<Oooool2o`0001Oooooo0_l0000@ooooo`;o00009?ooool2o`0004Wooooo0_l0000M
ooooo`005?ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool01Oooool2o`00
04gooooo0_l0001?ooooo`;o00004?ooool2o`0000Oooooo0_l00025ooooo`005_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00?ooooo1?l0000Sooooo`;o0000:?ooool2o`0003?o
oooo0_l0000eooooo`;o0000Koooool2o`0001Cooooo000Fooooo`03o`000?oooooooooo00Gooooo
0ol00003ooooo`;o00009Oooool2o`0003Kooooo0_l0000Uooooo`;o0000COooool2o`0005Oooooo
0_l00007ooooo`;o00002oooool001Kooooo00?o0000ooooooooool0J_ooool2o`0007Cooooo0_l0
001Pooooo`;o00002oooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0
003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Cooooo
00?oEEEEofIVI_l00000oooooomBooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.95421 .10548 Mdot
.46455 .03743 Mdot
.24191 .20117 Mdot
.59981 .99685 Mdot
.25219 .02118 Mdot
.09723 .59016 Mdot
.91334 .41491 Mdot
.07581 .425 Mdot
.29544 .81313 Mdot
.48213 .01711 Mdot
.57947 .80724 Mdot
.35656 .75807 Mdot
.22648 .18284 Mdot
.65399 .0403 Mdot
.31335 .4246 Mdot
.64548 .45712 Mdot
.64014 .99931 Mdot
.99025 .28186 Mdot
.45946 .04607 Mdot
.13912 .49415 Mdot
.41665 .71167 Mdot
.07941 .10883 Mdot
.30821 .35429 Mdot
.99283 .84414 Mdot
.94273 .5504 Mdot
.5345 .55904 Mdot
.85053 .56795 Mdot
.72828 .41692 Mdot
.71795 .9607 Mdot
.23245 .81904 Mdot
.92063 .74665 Mdot
.54223 .90681 Mdot
.67347 .38972 Mdot
.06911 .16708 Mdot
.90233 .53528 Mdot
.66033 .80771 Mdot
.58651 .79533 Mdot
.39445 .73405 Mdot
.03268 .57663 Mdot
.18052 .82833 Mdot
.85181 .08633 Mdot
.28812 .64396 Mdot
.4229 .03198 Mdot
.32269 .12643 Mdot
.07911 .07111 Mdot
.51735 .59435 Mdot
.70454 .93425 Mdot
.41636 .18261 Mdot
.92051 .91652 Mdot
.37765 .85942 Mdot
.17658 .71409 Mdot
.80252 .61522 Mdot
.01909 .07819 Mdot
.04276 .39065 Mdot
.13769 .62551 Mdot
.24641 .85431 Mdot
.79936 .03353 Mdot
.20838 .82558 Mdot
.39624 .34506 Mdot
.22161 .02443 Mdot
.02418 .19446 Mdot
.14542 .86367 Mdot
.22567 .82441 Mdot
.73189 .76754 Mdot
.69266 .3646 Mdot
.23467 .98702 Mdot
.00526 .03897 Mdot
.57723 .7033 Mdot
.94225 .86684 Mdot
.92554 .22324 Mdot
.98019 .89393 Mdot
.21899 .61741 Mdot
.07394 .46861 Mdot
.58526 .56916 Mdot
.61418 .01965 Mdot
.10065 .13895 Mdot
.24791 .95963 Mdot
.32319 .62404 Mdot
.83804 .42109 Mdot
.1507 .51466 Mdot
.46716 .07958 Mdot
.79921 .80823 Mdot
.21212 .73715 Mdot
.00473 .41176 Mdot
.48299 .86426 Mdot
.03008 .72263 Mdot
.33692 .38983 Mdot
.27013 .83948 Mdot
.51656 .78276 Mdot
.45839 .69827 Mdot
.18937 .75064 Mdot
.80586 .6438 Mdot
.08527 .47213 Mdot
.53958 .38996 Mdot
.40676 .17381 Mdot
.15109 .41893 Mdot
.4448 .80095 Mdot
.67794 .2445 Mdot
.62911 .90818 Mdot
.47773 .86831 Mdot
.42313 .52952 Mdot
.72681 .62766 Mdot
.83781 .01376 Mdot
.40752 .47278 Mdot
.34479 .44015 Mdot
.22372 .50996 Mdot
.32741 .8069 Mdot
.71832 .62725 Mdot
.20038 .65968 Mdot
.63318 .86906 Mdot
.05982 .1408 Mdot
.60851 .57425 Mdot
.03584 .27694 Mdot
.42094 .39555 Mdot
.93484 .64859 Mdot
.73526 .77005 Mdot
.13279 .64023 Mdot
.90628 .77003 Mdot
.35375 .40912 Mdot
.48025 .78097 Mdot
.69425 .17667 Mdot
.56505 .39699 Mdot
.01098 .36991 Mdot
.33543 .14634 Mdot
.54039 .63226 Mdot
.33676 .35315 Mdot
.41307 .74852 Mdot
.31586 .96922 Mdot
.85316 .70909 Mdot
.80028 .82187 Mdot
.89969 .87473 Mdot
.93585 .73732 Mdot
.05237 .19518 Mdot
.80327 .90112 Mdot
.49183 .22909 Mdot
.12098 .09847 Mdot
.37561 .85324 Mdot
.02494 .44238 Mdot
.47676 .59217 Mdot
.42571 .83636 Mdot
.13452 .41259 Mdot
.13374 .41072 Mdot
.76963 .99017 Mdot
.88573 .13625 Mdot
.27882 .42859 Mdot
.41974 .62712 Mdot
.35949 .78774 Mdot
.76724 .15632 Mdot
.42067 .2916 Mdot
.15756 .22364 Mdot
.19408 .04822 Mdot
.21596 .15213 Mdot
.63803 .02307 Mdot
.75843 .00787 Mdot
.29762 .34868 Mdot
.39758 .44771 Mdot
.46114 .63749 Mdot
.56815 .17404 Mdot
.68296 .49141 Mdot
.04136 .6644 Mdot
.84531 .61757 Mdot
.30636 .80954 Mdot
.98655 .30758 Mdot
.86125 .39304 Mdot
.87187 .69712 Mdot
.64432 .65329 Mdot
.10609 .59436 Mdot
.72175 .72854 Mdot
.18842 .55341 Mdot
.93295 .10834 Mdot
.85625 .4128 Mdot
.26245 .09049 Mdot
.46577 .2523 Mdot
.20441 .67518 Mdot
.89297 .56413 Mdot
.82974 .94876 Mdot
.40061 .39781 Mdot
.72792 .80232 Mdot
.53589 .40222 Mdot
.43477 .55908 Mdot
.06455 .1991 Mdot
.88268 .01519 Mdot
.70896 .00205 Mdot
.17911 .4233 Mdot
.78559 .20565 Mdot
.62676 .16021 Mdot
.46237 .22083 Mdot
.20592 .54566 Mdot
.43709 .34276 Mdot
.00346 .37332 Mdot
.38799 .2585 Mdot
.02272 .28146 Mdot
.85401 .57371 Mdot
.24184 .89213 Mdot
.44878 .09964 Mdot
.62837 .94397 Mdot
.36185 .34044 Mdot
.45232 .15068 Mdot
.3382 .56213 Mdot
.92496 .95199 Mdot
.06562 .83912 Mdot
.52277 .14652 Mdot
.16759 .14306 Mdot
.08576 .35911 Mdot
.79006 .78176 Mdot
.40442 .11274 Mdot
.97038 .23386 Mdot
.34031 .59286 Mdot
.27448 .42489 Mdot
.12847 .71723 Mdot
.50022 .33601 Mdot
.73341 .20057 Mdot
.66976 .78189 Mdot
.4983 .45908 Mdot
.23529 .28003 Mdot
.85047 .49536 Mdot
.76416 .8879 Mdot
.03875 .1164 Mdot
.41663 .23082 Mdot
.23162 .92598 Mdot
.84172 .35824 Mdot
.76651 .61546 Mdot
.81983 .64511 Mdot
.63185 .76764 Mdot
.65798 .34069 Mdot
.60122 .79004 Mdot
.99641 .5555 Mdot
.35639 .63921 Mdot
.67751 .90008 Mdot
.69769 .94903 Mdot
.73563 .19707 Mdot
.66405 .81174 Mdot
.16847 .48793 Mdot
.62852 .55654 Mdot
.8721 .36112 Mdot
.56575 .4829 Mdot
.6264 .54895 Mdot
.44299 .10598 Mdot
.20941 .62234 Mdot
.7508 .002 Mdot
.98998 .91978 Mdot
.68163 .53932 Mdot
.82498 .19562 Mdot
.44629 .42482 Mdot
.06879 .97336 Mdot
.09913 .14354 Mdot
.61891 .12468 Mdot
.07952 .4107 Mdot
.61195 .17926 Mdot
.22318 .66656 Mdot
.73874 .17891 Mdot
.72555 .12859 Mdot
.43151 .67326 Mdot
.68937 .09763 Mdot
.1283 .01981 Mdot
.83966 .16971 Mdot
.58805 .74346 Mdot
.02685 .22118 Mdot
.16405 .10493 Mdot
.31006 .61727 Mdot
.32789 .24532 Mdot
.87251 .54399 Mdot
.17843 .65447 Mdot
.65003 .86586 Mdot
.24457 .37649 Mdot
.57041 .53707 Mdot
.55284 .64216 Mdot
.43099 .81282 Mdot
.58347 .65681 Mdot
.55921 .90064 Mdot
.51483 .01429 Mdot
.84634 .63986 Mdot
.81281 .32797 Mdot
.1343 .73015 Mdot
.31882 .12875 Mdot
.1504 .41887 Mdot
.573 .19592 Mdot
.08354 .26569 Mdot
.49002 .85794 Mdot
.39364 .30568 Mdot
.54819 .94924 Mdot
.12861 .77157 Mdot
.3632 .0715 Mdot
.89388 .77086 Mdot
.156 .56851 Mdot
.25332 .51357 Mdot
.62777 .75437 Mdot
.68641 .63322 Mdot
.70535 .98187 Mdot
.05273 .66817 Mdot
.68645 .73657 Mdot
.36529 .13753 Mdot
.6715 .25119 Mdot
.34779 .78913 Mdot
.57443 .50762 Mdot
.15487 .43256 Mdot
.84707 .75899 Mdot
.32569 .47958 Mdot
.96107 .34841 Mdot
.35257 .38957 Mdot
.97354 .70019 Mdot
.94586 .1486 Mdot
.87254 .61011 Mdot
.28644 .43323 Mdot
.57077 .69485 Mdot
.09795 .2623 Mdot
.13841 .48681 Mdot
.47032 .37708 Mdot
.83784 .38648 Mdot
.9138 .36441 Mdot
.46604 .47166 Mdot
.0049 .50078 Mdot
.28565 .51452 Mdot
.63499 .00876 Mdot
.24057 .42506 Mdot
.86965 .04208 Mdot
.28946 .38646 Mdot
.38148 .3572 Mdot
.21742 .55595 Mdot
.28479 .33097 Mdot
.06282 .54427 Mdot
.88658 .60138 Mdot
.11302 .30007 Mdot
.46469 .55097 Mdot
.14346 .66803 Mdot
.41967 .96632 Mdot
.38545 .66062 Mdot
.02967 .28921 Mdot
.90755 .63531 Mdot
.00493 .55462 Mdot
.14918 .97564 Mdot
.41601 .74097 Mdot
.63347 .81618 Mdot
.83205 .54235 Mdot
.143 .91285 Mdot
.92831 .49518 Mdot
.12568 .73823 Mdot
.87778 .05286 Mdot
.20432 .85974 Mdot
.35054 .43005 Mdot
.63723 .58253 Mdot
.81571 .21937 Mdot
.16959 .13072 Mdot
.16342 .25393 Mdot
.03534 .89959 Mdot
.62845 .34374 Mdot
.65371 .33707 Mdot
.45455 .06601 Mdot
.97387 .97886 Mdot
.9165 .52034 Mdot
.33811 .96302 Mdot
.16407 .87265 Mdot
.92735 .95575 Mdot
.56303 .03924 Mdot
.17242 .24437 Mdot
.10701 .37252 Mdot
.43298 .72597 Mdot
.92637 .61169 Mdot
.26285 .95613 Mdot
.22748 .98096 Mdot
.88425 .15379 Mdot
.44688 .91828 Mdot
.21825 .05762 Mdot
.04732 .3519 Mdot
.81676 .57294 Mdot
.89421 .04435 Mdot
.0034 .94873 Mdot
.17209 .92682 Mdot
.10599 .39476 Mdot
.87649 .84577 Mdot
.42937 .96085 Mdot
.36822 .58069 Mdot
.10732 .03933 Mdot
.12804 .31839 Mdot
.29661 .62953 Mdot
.70699 .20291 Mdot
.89088 .53942 Mdot
.32165 .08753 Mdot
.25741 .27233 Mdot
.67389 .23478 Mdot
.41269 .44542 Mdot
.33564 .78399 Mdot
.37749 .84266 Mdot
.66149 .63202 Mdot
.03818 .03954 Mdot
.8929 .95249 Mdot
.12363 .79588 Mdot
.75248 .15316 Mdot
.7303 .62722 Mdot
.84559 .66002 Mdot
.8909 .81003 Mdot
.81923 .81981 Mdot
.87695 .82988 Mdot
.98939 .27754 Mdot
.72192 .83214 Mdot
.90932 .99089 Mdot
.27115 .1738 Mdot
.4007 .66313 Mdot
.48275 .20871 Mdot
.28315 .94303 Mdot
.32921 .9081 Mdot
.46282 .82808 Mdot
.03586 .84777 Mdot
.29713 .51689 Mdot
.3906 .3653 Mdot
.84255 .55012 Mdot
.38315 .05513 Mdot
.60068 .04733 Mdot
.39348 .20717 Mdot
.79109 .71682 Mdot
.3072 .60059 Mdot
.14481 .44135 Mdot
.44683 .02317 Mdot
.96122 .11721 Mdot
.12778 .62013 Mdot
.22867 .2598 Mdot
.0017 .98658 Mdot
.65702 .19281 Mdot
.39987 .26586 Mdot
.49374 .86802 Mdot
.25405 .45736 Mdot
.35056 .48558 Mdot
.49262 .41852 Mdot
.34233 .63924 Mdot
.4114 .03639 Mdot
.90146 .96059 Mdot
.1621 .80418 Mdot
.08903 .46164 Mdot
.48399 .21622 Mdot
.99 .73633 Mdot
.74922 .47287 Mdot
.83243 .53851 Mdot
.09915 .55416 Mdot
.34929 .38784 Mdot
.73978 .57283 Mdot
.25987 .49306 Mdot
.81816 .2412 Mdot
.85379 .85798 Mdot
.21746 .91014 Mdot
.21029 .05161 Mdot
.95613 .98192 Mdot
.88251 .74259 Mdot
.67947 .9646 Mdot
.57203 .95981 Mdot
.27716 .84918 Mdot
.79217 .98255 Mdot
.89915 .7422 Mdot
.05455 .03236 Mdot
.79074 .1246 Mdot
.29713 .53785 Mdot
.0287 .63282 Mdot
.56265 .19638 Mdot
.70627 .08197 Mdot
.99629 .98768 Mdot
.36321 .67117 Mdot
.04653 .39934 Mdot
.67022 .98893 Mdot
.87317 .1423 Mdot
.18212 .8256 Mdot
.38768 .74423 Mdot
.03848 .31368 Mdot
.30143 .59014 Mdot
.2488 .04687 Mdot
.35064 .8447 Mdot
.14228 .4134 Mdot
.94017 .37754 Mdot
.36212 .19521 Mdot
.45867 .39742 Mdot
.08775 .50982 Mdot
.9421 .85854 Mdot
.44843 .01153 Mdot
.01453 .56024 Mdot
.13752 .47034 Mdot
.06123 .76974 Mdot
.09325 .95758 Mdot
.23433 .50368 Mdot
.36034 .13113 Mdot
.84541 .625 Mdot
.5804 .39612 Mdot
.0702 .76148 Mdot
.13264 .34937 Mdot
.19429 .36296 Mdot
.26413 .67658 Mdot
.78612 .27149 Mdot
.69149 .87003 Mdot
.23438 .97537 Mdot
.01275 .28238 Mdot
.57277 .11082 Mdot
.1439 .7614 Mdot
.37159 .89448 Mdot
.78316 .78395 Mdot
.8527 .82853 Mdot
.15595 .33076 Mdot
.19588 .02905 Mdot
.71733 .94264 Mdot
.08028 .25208 Mdot
.496 .83381 Mdot
.13871 .77265 Mdot
.28397 .71887 Mdot
.17327 .07027 Mdot
.72629 .78003 Mdot
.46997 .67685 Mdot
.50107 .19096 Mdot
.05575 .26713 Mdot
.65773 .59579 Mdot
.47849 .96477 Mdot
.47092 .02451 Mdot
.10387 .30306 Mdot
.16761 .80698 Mdot
.11251 .90152 Mdot
.44888 .63437 Mdot
.4087 .21724 Mdot
.27948 .41935 Mdot
.53068 .90986 Mdot
.39655 .78343 Mdot
.9532 .01283 Mdot
.17795 .78711 Mdot
.10564 .62388 Mdot
.39649 .0882 Mdot
.57904 .94085 Mdot
.43032 .64835 Mdot
.19319 .47147 Mdot
.56666 .54692 Mdot
.1084 .71236 Mdot
.82485 .63222 Mdot
.18026 .30635 Mdot
.06783 .25776 Mdot
.82585 .87576 Mdot
.29014 .03219 Mdot
.05008 .70434 Mdot
.56095 .64879 Mdot
.98776 .11353 Mdot
.61755 .50792 Mdot
.33093 .91067 Mdot
.49347 .47723 Mdot
.52468 .60998 Mdot
.13037 .41985 Mdot
.88575 .63044 Mdot
.55804 .68396 Mdot
.79536 .71065 Mdot
.43112 .21253 Mdot
.89436 .45829 Mdot
.57652 .0076 Mdot
.56777 .82291 Mdot
.51186 .18592 Mdot
.80358 .53402 Mdot
.23546 .19401 Mdot
.78887 .40902 Mdot
.85606 .29473 Mdot
.403 .05995 Mdot
.75293 .0894 Mdot
.29168 .82621 Mdot
.62827 .5552 Mdot
.81863 .92042 Mdot
.56562 .05267 Mdot
.91644 .55447 Mdot
.6942 .24725 Mdot
.56291 .65336 Mdot
.92157 .7728 Mdot
.33641 .865 Mdot
.8057 .8767 Mdot
.23084 .04962 Mdot
.46984 .21321 Mdot
.22479 .82534 Mdot
.43334 .32168 Mdot
.81206 .43388 Mdot
.11739 .85954 Mdot
.35419 .39703 Mdot
.04843 .06598 Mdot
.48502 .11613 Mdot
.40858 .7487 Mdot
.76815 .04772 Mdot
.43455 .48465 Mdot
.86703 .23798 Mdot
.54086 .65919 Mdot
.28498 .97602 Mdot
.77919 .91094 Mdot
.57894 .13629 Mdot
.86236 .61461 Mdot
.78414 .22982 Mdot
.35216 .83957 Mdot
.83901 .55758 Mdot
.43355 .57784 Mdot
.32859 .13076 Mdot
.33762 .86285 Mdot
.23337 .38143 Mdot
.40572 .55689 Mdot
.41713 .89456 Mdot
.16914 .27691 Mdot
.04535 .26152 Mdot
.95068 .29806 Mdot
.79605 .41258 Mdot
.84804 .79706 Mdot
.55522 .27245 Mdot
.14298 .5431 Mdot
.77528 .78511 Mdot
.33697 .41764 Mdot
.27502 .80497 Mdot
.26347 .27438 Mdot
.19959 .5297 Mdot
.49089 .50813 Mdot
.71277 .73265 Mdot
.22016 .75782 Mdot
.30019 .82723 Mdot
.9771 .51205 Mdot
.24506 .96522 Mdot
.11384 .23904 Mdot
.02976 .76383 Mdot
.09222 .3849 Mdot
.38119 .63593 Mdot
.63511 .49011 Mdot
.50581 .52118 Mdot
.31135 .25982 Mdot
.30489 .35945 Mdot
.72556 .9436 Mdot
.62867 .04552 Mdot
.5691 .11355 Mdot
.88953 .32323 Mdot
.8077 .44296 Mdot
.46929 .0506 Mdot
.26668 .42571 Mdot
.63469 .8981 Mdot
.14586 .75396 Mdot
.65896 .74012 Mdot
.00106 .92642 Mdot
.79547 .75117 Mdot
.90521 .27638 Mdot
.74413 .23872 Mdot
.90743 .61672 Mdot
.36899 .1562 Mdot
.34531 .81124 Mdot
.43257 .51983 Mdot
.64685 .82095 Mdot
.24561 .22218 Mdot
.09483 .67246 Mdot
.24159 .76517 Mdot
.27585 .30703 Mdot
.02258 .62479 Mdot
.91916 .67252 Mdot
.45796 .92193 Mdot
.56446 .35847 Mdot
.7621 .88431 Mdot
.49424 .92363 Mdot
.42274 .8938 Mdot
.34604 .72136 Mdot
.88869 .0918 Mdot
.89959 .45559 Mdot
.99118 .48027 Mdot
.84396 .55886 Mdot
.566 .39803 Mdot
.65953 .32041 Mdot
.61132 .10733 Mdot
.5071 .34808 Mdot
.46275 .85596 Mdot
.33102 .87451 Mdot
.18809 .32946 Mdot
.56158 .90383 Mdot
.95219 .79737 Mdot
.14367 .88556 Mdot
.59967 .91917 Mdot
.41575 .98392 Mdot
.26297 .9058 Mdot
.43508 .2003 Mdot
.2705 .08122 Mdot
.47048 .18486 Mdot
.33275 .07315 Mdot
.75284 .77257 Mdot
.72166 .96763 Mdot
.83919 .44859 Mdot
.13202 .76376 Mdot
.20557 .83398 Mdot
.18232 .21445 Mdot
.31109 .62572 Mdot
.33592 .74561 Mdot
.9819 .85891 Mdot
.35661 .96192 Mdot
.03911 .31676 Mdot
.59168 .66959 Mdot
.72566 .11776 Mdot
.52616 .99058 Mdot
.24212 .25827 Mdot
.74088 .09894 Mdot
.59106 .78226 Mdot
.12635 .26431 Mdot
.94546 .84852 Mdot
.3298 .95176 Mdot
.39088 .3254 Mdot
.33848 .38862 Mdot
.9145 .61502 Mdot
.21002 .40773 Mdot
.71708 .88696 Mdot
.31943 .91497 Mdot
.03315 .00022 Mdot
.28052 .3154 Mdot
.95407 .78031 Mdot
.41028 .55238 Mdot
.59175 .6004 Mdot
.71514 .12232 Mdot
.74522 .68672 Mdot
.62502 .15011 Mdot
.40339 .79551 Mdot
.1313 .38737 Mdot
.06784 .27852 Mdot
.88881 .01288 Mdot
.54372 .70675 Mdot
.27988 .16686 Mdot
.03116 .29979 Mdot
.19959 .0754 Mdot
.07689 .22962 Mdot
.98249 .39399 Mdot
.8716 .82997 Mdot
.81385 .75388 Mdot
.11356 .77329 Mdot
.58148 .9701 Mdot
.43485 .89361 Mdot
.95771 .28522 Mdot
.5877 .78413 Mdot
.0623 .76973 Mdot
.75657 .81014 Mdot
.41939 .25419 Mdot
.21018 .28297 Mdot
.0476 .30468 Mdot
.95342 .77741 Mdot
.69804 .01113 Mdot
.43029 .70186 Mdot
.73772 .7555 Mdot
.12548 .2652 Mdot
.07726 .91432 Mdot
.06231 .23147 Mdot
.47553 .6198 Mdot
.01551 .85366 Mdot
.48907 .86928 Mdot
.9277 .1886 Mdot
.00412 .30859 Mdot
.5722 .85223 Mdot
.00935 .76469 Mdot
.94915 .84994 Mdot
.83876 .35039 Mdot
.28744 .95664 Mdot
.23533 .94529 Mdot
.80952 .33315 Mdot
.25128 .79362 Mdot
.45732 .85984 Mdot
.05204 .39402 Mdot
.79443 .3087 Mdot
.42112 .81139 Mdot
.5978 .88805 Mdot
.15142 .70707 Mdot
.95107 .72383 Mdot
.84506 .79224 Mdot
.33282 .2161 Mdot
.19987 .20457 Mdot
.18581 .38392 Mdot
.48996 .81253 Mdot
.26594 .91558 Mdot
.7589 .89467 Mdot
.71736 .9622 Mdot
.74464 .5292 Mdot
.64207 .53207 Mdot
.09925 .53174 Mdot
.04208 .29984 Mdot
.96117 .09395 Mdot
.37208 .64952 Mdot
.42906 .65879 Mdot
.92861 .80488 Mdot
.52634 .63977 Mdot
.22928 .46093 Mdot
.22536 .08969 Mdot
.14483 .92464 Mdot
.19533 .21599 Mdot
.91602 .82825 Mdot
.32537 .14446 Mdot
.27752 .88947 Mdot
.85358 .39492 Mdot
.43509 .81851 Mdot
.13548 .17977 Mdot
.86402 .49608 Mdot
.09265 .35324 Mdot
.06588 .86825 Mdot
.36537 .62464 Mdot
.4324 .52858 Mdot
.98343 .70931 Mdot
.9166 .23555 Mdot
.29208 .19239 Mdot
.21143 .62568 Mdot
.76158 .19646 Mdot
.14602 .35876 Mdot
.29934 .48258 Mdot
.81096 .02523 Mdot
.4853 .03867 Mdot
.09135 .8614 Mdot
.46948 .06294 Mdot
.37963 .75168 Mdot
.84276 .59674 Mdot
.95702 .35168 Mdot
.12942 .21862 Mdot
.29885 .16665 Mdot
.97066 .23217 Mdot
.41423 .59497 Mdot
.18283 .1652 Mdot
.30114 .82727 Mdot
.32763 .80423 Mdot
.50429 .67046 Mdot
.20008 .35638 Mdot
.67249 .2204 Mdot
.9673 .14891 Mdot
.25409 .40389 Mdot
.13791 .45862 Mdot
.30625 .64398 Mdot
.80098 .56939 Mdot
.36631 .5152 Mdot
.05231 .70705 Mdot
.60327 .10513 Mdot
.17318 .72729 Mdot
.80522 .06644 Mdot
.53578 .71001 Mdot
.45152 .51699 Mdot
.09638 .29286 Mdot
.7862 .59938 Mdot
.75751 .25902 Mdot
.99381 .60158 Mdot
.57497 .32231 Mdot
.25391 .45061 Mdot
.90793 .00925 Mdot
.77319 .79694 Mdot
.9036 .81442 Mdot
.67884 .07427 Mdot
.12852 .51794 Mdot
.64317 .2864 Mdot
.37567 .75162 Mdot
.34774 .02723 Mdot
.18138 .94281 Mdot
.01245 .19151 Mdot
.286 .24684 Mdot
.31763 .03175 Mdot
.7703 .77719 Mdot
.81219 .02601 Mdot
.33698 .63507 Mdot
.63754 .25443 Mdot
.64846 .55572 Mdot
.29758 .45866 Mdot
.91468 .24247 Mdot
.71509 .82876 Mdot
.3487 .86874 Mdot
.36708 .049 Mdot
.60172 .1762 Mdot
.71889 .29375 Mdot
.02576 .01756 Mdot
.42568 .07299 Mdot
.42537 .85767 Mdot
.20957 .17155 Mdot
.12151 .07099 Mdot
.13894 .49194 Mdot
.51831 .20452 Mdot
.00848 .97646 Mdot
.82035 .70415 Mdot
.07685 .35873 Mdot
.73726 .02236 Mdot
.8991 .60529 Mdot
.13399 .7731 Mdot
.21293 .14889 Mdot
.2883 .18779 Mdot
.40335 .25481 Mdot
.74786 .89765 Mdot
.89226 .26558 Mdot
.66781 .2162 Mdot
.32847 .58199 Mdot
.15309 .79035 Mdot
.70463 .77486 Mdot
.0435 .2101 Mdot
.27462 .68731 Mdot
.37784 .99989 Mdot
.52056 .12009 Mdot
.52379 .1567 Mdot
.73436 .22402 Mdot
.29287 .61327 Mdot
.67528 .62904 Mdot
.40115 .10437 Mdot
.74069 .31441 Mdot
.42885 .8021 Mdot
.34909 .97728 Mdot
.03751 .00182 Mdot
.48129 .96392 Mdot
.23599 .57987 Mdot
.43891 .33059 Mdot
.2768 .89943 Mdot
.31259 .60106 Mdot
.68143 .65937 Mdot
.33784 .71223 Mdot
.96919 .29418 Mdot
.13112 .95076 Mdot
.78371 .15326 Mdot
.1964 .25794 Mdot
.39921 .55548 Mdot
.05524 .96193 Mdot
.26961 .53146 Mdot
.16354 .01202 Mdot
.86238 .06226 Mdot
.37899 .70477 Mdot
.4977 .85598 Mdot
.60773 .56801 Mdot
.06589 .11506 Mdot
.15241 .29983 Mdot
.85832 .47968 Mdot
.49672 .53082 Mdot
.04854 .41682 Mdot
.75963 .98867 Mdot
.77291 .40455 Mdot
.21527 .84269 Mdot
.68617 .71341 Mdot
.18229 .55488 Mdot
.86341 .47547 Mdot
.10364 .49047 Mdot
.34052 .12929 Mdot
.2421 .82715 Mdot
.13061 .07183 Mdot
.31927 .73302 Mdot
.8458 .29522 Mdot
.2368 .17479 Mdot
.27867 .38209 Mdot
.47381 .08438 Mdot
.9554 .04473 Mdot
.81915 .79524 Mdot
.72268 .9151 Mdot
.27062 .1411 Mdot
.88758 .31379 Mdot
.14947 .79742 Mdot
.29639 .87539 Mdot
.44984 .64234 Mdot
.98467 .1197 Mdot
.70634 .8631 Mdot
.42166 .13758 Mdot
.85265 .61816 Mdot
.73927 .5868 Mdot
.59237 .09934 Mdot
.77578 .80847 Mdot
.75112 .36096 Mdot
.16645 .88214 Mdot
.87454 .92711 Mdot
.31893 .63214 Mdot
.12908 .04065 Mdot
.90247 .16548 Mdot
.9399 .49727 Mdot
.11217 .61289 Mdot
.65188 .47116 Mdot
.63923 .48444 Mdot
.66229 .04594 Mdot
.46907 .16314 Mdot
.31376 .07307 Mdot
.95546 .78448 Mdot
.93625 .56661 Mdot
.78522 .58438 Mdot
.49954 .98792 Mdot
.64139 .75998 Mdot
.0965 .11258 Mdot
.02706 .83696 Mdot
.98269 .11434 Mdot
.0039 .71332 Mdot
.96871 .50275 Mdot
.12076 .94656 Mdot
.02086 .89211 Mdot
.81988 .70184 Mdot
.45009 .09742 Mdot
.13649 .68937 Mdot
.31989 .67666 Mdot
.14136 .35258 Mdot
.87319 .02571 Mdot
.2974 .8478 Mdot
.35695 .42972 Mdot
.02974 .88596 Mdot
.88768 .5909 Mdot
.38321 .31035 Mdot
.4838 .94878 Mdot
.14822 .09602 Mdot
.45805 .62397 Mdot
.26701 .82225 Mdot
.31235 .48374 Mdot
.70048 .85292 Mdot
.05781 .87233 Mdot
.95544 .22523 Mdot
.27939 .80138 Mdot
.54665 .14533 Mdot
.90127 .87479 Mdot
.80183 .31377 Mdot
.05433 .3383 Mdot
.35748 .86988 Mdot
.11757 .29054 Mdot
.39062 .53848 Mdot
.07204 .27043 Mdot
.08819 .15119 Mdot
.36336 .7482 Mdot
.75152 .57606 Mdot
.7548 .15937 Mdot
.72637 .69003 Mdot
.34108 .78175 Mdot
.23154 .96268 Mdot
.07049 .98873 Mdot
.32322 .80299 Mdot
.46242 .97118 Mdot
.57328 .7224 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00Oo
oooo0ol00003ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00Co0000ooooool0003o00003?ooool2o`00
00oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003o
ooooooooo`08ooooo`;o00000oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`04o`000?oooooo0000o`00
00cooooo0_l0000?ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001ko
oooo00?o0000ooooooooool0]oooool2o`00017ooooo0_l0000Vooooo`;o0000;oooool2o`0002;o
oooo000Nooooo`03o`000?oooooooooo037ooooo0_l0001Kooooo`;o00009oooool2o`00017ooooo
0_l0000Cooooo`;o00004Oooool2o`0002Wooooo0_l00004ooooo`;o00003Oooool2o`0001?ooooo
000Nooooo`03o`000?oooooooooo037ooooo0_l0001Kooooo`;o00004oooool2o`0003[ooooo0_l0
000[ooooo`;o00003Oooool4o`0001?ooooo0_l0000Cooooo`007_ooool00ol0003oooooooooo`04
ooooo`;o00008?ooool2o`00077ooooo0_l00008ooooo`;o00007oooool2o`0004Kooooo0_l0000=
ooooo`;o0000:_ooool001kooooo00?o0000ooooooooool01?ooool2o`00023ooooo0_l0000Voooo
o`;o0000BOooool2o`0002Wooooo0_l0000Vooooo`;o0000FOooool001kooooo00?o0000oooooooo
ool0A?ooool2o`0000Sooooo0_l0000mooooo`;o00001_ooool2o`0003Cooooo0_l0000Oooooo`;o
00005_ooool2o`0001;ooooo0_l0000]ooooo`007_ooool00ol0003oooooooooo`0looooo`;o0000
1_ooool2o`0002Oooooo0_l0000Nooooo`;o00001_ooool2o`0003Cooooo0_l0000gooooo`;o0000
4_ooool2o`0002gooooo000Nooooo`03o`000?oooooooooo03cooooo0_l0000Looooo`;o00001ooo
ool2o`0000Sooooo0_l0000Fooooo`;o0000`?ooool001kooooo00?o0000ooooooooool03_ooool2
o`0004[ooooo0_l00007ooooo`;o00008?ooool2o`0007Wooooo0_l00015ooooo`007_ooool00ol0
003oooooooooo`0>ooooo`;o0000L_ooool2o`0000oooooo0_l0001[ooooo`;o0000AOooool001ko
oooo0ol00008ooooo`;o00005Oooool2o`0000Gooooo0_l0001Jooooo`;o00003oooool2o`0000Go
oooo0_l0000Gooooo`;o00007?ooool2o`0007Cooooo000Nooooo`?o00002?ooool2o`0001Gooooo
0_l00005ooooo`;o0000L_ooool2o`0001Oooooo0_l0000Looooo`;o0000A?ooool2o`0000Kooooo
0_l0000Vooooo`007_ooool00ol0003oooooooooo`1=ooooo`;o0000@_ooool2o`0002cooooo0_l0
0007ooooo`;o00002Oooool2o`0004;ooooo0_l00006ooooo`;o00004Oooool2o`0001?ooooo000N
ooooo`03o`000?oooooooooo03_ooooo0_l0000:ooooo`;o00001?ooool2o`0002Cooooo0_l0000L
ooooo`;o000000?oooooo`000?l00000:Oooool2o`0000Oooooo0_l00009ooooo`;o00008Oooool2
o`0003[ooooo0_l0000Cooooo`007_ooool2o`0003cooooo0_l00003ooooo`;o00001Oooool2o`00
02[ooooo0_l0000Oooooo`;o00007_ooool2o`00043ooooo0_l0000Qooooo`;o0000;?ooool001ko
oooo00?o0000ooooooooool0@?ooool2o`0003Kooooo0_l0000jooooo`;o0000Hoooool2o`0002co
oooo000Nooooo`03o`000?oooooooooo04?ooooo0_l0000cooooo`;o0000cOooool001kooooo00?o
0000ooooooooool0@oooool2o`0003[ooooo0_l0000Dooooo`;o0000OOooool2o`00037ooooo000N
ooooo`03o`000?oooooooooo00cooooo0_l0001aooooo`;o00003oooool2o`0000?ooooo0_l0001m
ooooo`;o0000<Oooool001kooooo00?o0000ooooooooool03?ooool2o`0008;ooooo0_l0001`oooo
o`;o0000@oooool001kooooo00?o0000ooooooooool05_ooool2o`0000_ooooo0_l000000ooooooo
0000o`00000<ooooo`;o0000??ooool2o`0008kooooo0_l00013ooooo`007_ooool00ol0003ooooo
ooooo`0Fooooo`;o00002oooool2o`000003ooooool0003o000000cooooo0_l0000/ooooo`;o0000
1?ooool2o`0000Sooooo0_l0000Booooo`;o0000DOooool2o`0006cooooo000Nooooo`03o`000?oo
oooooooo00;ooooo0_l0000iooooo`;o00008oooool2o`0000Cooooo0_l0000Looooo`;o0000DOoo
ool2o`0006cooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0000iooooo`;o00005Oooool2
o`0003kooooo0_l0002aooooo`007_ooool00ol0003oooooooooo`1Dooooo`;o0000?_ooool4o`00
04[ooooo0_l0001Sooooo`007_ooool00ol0003oooooooooo`1Tooooo`;o0000<?ooool2o`0004[o
oooo0_l0000]ooooo`;o0000=?ooool001kooooo00?o0000ooooooooool0AOooool2o`0000[ooooo
0_l0000Aooooo`;o00005oooool2o`0007;ooooo0_l0000Nooooo`;o0000=?ooool001kooooo00?o
0000ooooooooool0AOooool2o`0000[ooooo0_l0000Zooooo`;o0000L_ooool2o`0002[ooooo0_l0
000Xooooo`007_ooool00ol0003oooooooooo`0/ooooo`;o0000koooool2o`0001Gooooo0_l0000A
ooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o00001oooool2o`00063ooooo0_l0000/oooo
o`;o00007_ooool2o`0000oooooo0_l00015ooooo`;o00004Oooool001kooooo0_l0000Tooooo`;o
0000JOooool2o`0002cooooo0_l0000Nooooo`;o00003oooool2o`0005Sooooo000Nooooo`03o`00
0?oooooooooo037ooooo0_l0001;ooooo`;o00003?ooool2o`0003;ooooo0_l0001`ooooo`;o0000
4oooool001kooooo00?o0000ooooooooool05_ooool2o`0001Wooooo0_l0001;ooooo`;o00003?oo
ool2o`0003;ooooo0_l000000ooooooo0000o`00001Vooooo`;o00001Oooool2o`0001?ooooo000N
ooooo`03o`000?oooooooooo01Kooooo0_l0002Nooooo`;o00002oooool2o`0006Kooooo0_l0000J
ooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o00002?ooool2o`0006;ooooo0_l0000doooo
o`?o0000Poooool4o`0000Sooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l00007ooooo`;o
00002?ooool2o`0006;ooooo0_l0000Iooooo`;o00006Oooool2o`00037ooooo0_l0001:ooooo`;o
00001Oooool4o`0000Sooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0002@ooooo`;o0000
2Oooool2o`00047ooooo0_l0001:ooooo`;o00001_ooool2o`0000Wooooo000Nooooo`03o`000?oo
oooooooo0:Gooooo0_l0000mooooo`;o0000E_ooool2o`0000Wooooo000Nooooo`03o`000?oooooo
oooo06Gooooo0_l0001Nooooo`;o00007Oooool2o`0001Oooooo0_l00018ooooo`007_ooool00ol0
003oooooooooo`1Tooooo`?o00001?ooool2o`0005Sooooo0_l0000Qooooo`;o00004oooool2o`00
04Sooooo000Nooooo`03o`000?oooooooooo03?ooooo0_l0000_ooooo`;o000000?oooooo`000?l0
00000_ooool2o`0000Cooooo0_l0001eooooo`;o0000GOooool001kooooo00?o0000ooooooooool0
<oooool2o`0003;ooooo0_l00008ooooo`;o0000AOooool2o`0006;ooooo0_l0000Yooooo`007_oo
ool00ol0003oooooooooo`0Mooooo`;o0000E?ooool2o`00013ooooo0_l0000aooooo`;o0000H_oo
ool2o`0002Wooooo000Nooooo`03o`000?oooooooooo00oooooo0_l0000<ooooo`;o0000=Oooool2
o`0001gooooo0_l0000@ooooo`;o0000TOooool2o`0002gooooo000Nooooo`03o`000?oooooooooo
00oooooo0_l0000;ooooo`;o00005?ooool2o`00023ooooo0_l0000@ooooo`;o0000A_ooool2o`00
06Sooooo0_l0000]ooooo`007_ooool00ol0003oooooooooo`0Looooo`;o00005?ooool2o`0000go
oooo0_l0000Sooooo`;o000000?oooooo`000?l00000>oooool2o`0000Kooooo0_l0001oooooo`;o
00001Oooool2o`0000oooooo000Nooooo`;o00006_ooool2o`0002Kooooo0ol0000Uooooo`;o0000
9?ooool2o`0001Gooooo0_l0000Oooooo`;o0000I_ooool2o`0000Gooooo0_l0000?ooooo`007_oo
ool00ol0003oooooooooo`0Iooooo`;o00009oooool2o`0004_ooooo0_l0000fooooo`;o0000:?oo
ool2o`0000Sooooo0_l0000Nooooo`;o0000:_ooool001kooooo00?o0000ooooooooool0M?ooool2
o`00033ooooo0_l00019ooooo`;o00000_ooool2o`0000Cooooo0_l0000Nooooo`;o0000:_ooool0
01kooooo00?o0000ooooooooool0M?ooool2o`00033ooooo0_l0000Pooooo`;o00009oooool2o`00
00;ooooo0_l0001@ooooo`007_ooool00ol0003oooooooooo`2Dooooo`;o0000<_ooool2o`0002Oo
oooo0_l0001Dooooo`007_ooool00ol0003oooooooooo`0Booooo`;o00008oooool2o`0001kooooo
0_l00004ooooo`;o0000=Oooool2o`0008_ooooo0_l0000Tooooo`007_ooool00ol0003ooooooooo
o`0Booooo`;o00008oooool2o`0001kooooo0_l00004ooooo`;o0000[_ooool2o`0001;ooooo0_l0
000Tooooo`007_ooool00ol0003oooooooooo`10ooooo`;o0000boooool2o`0003Sooooo000Noooo
o`03o`000?oooooooooo043ooooo0_l00007ooooo`;o00002Oooool2o`0002[ooooo0_l0000coooo
o`;o00002Oooool2o`0001cooooo0_l0001Wooooo`007_ooool00ol0003oooooooooo`0Xooooo`;o
00007oooool2o`0000Wooooo0_l0000Zooooo`;o0000<oooool2o`0000Wooooo0_l000000ooooooo
0000o`00000Iooooo`;o00003?ooool2o`0005Wooooo000Nooooo`03o`000?oooooooooo02Sooooo
0_l0000Looooo`;o0000>oooool2o`0003kooooo0_l0000Wooooo`;o0000FOooool001kooooo00?o
0000ooooooooool0A_ooool2o`0003_ooooo0_l0000@ooooo`;o00002oooool2o`000:?ooooo000N
ooooo`03o`000?oooooooooo05[ooooo0_l0000iooooo`;o00002oooool2o`0008Gooooo0_l0000L
ooooo`007_ooool00ol0003oooooooooo`02o`0005Sooooo0_l00013ooooo`;o0000R?ooool2o`00
01cooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006oooo
o`03o`000?oooooooooo00;o00000_ooool2o`0000Oooooo0_l0000iooooo`;o00004Oooool2o`00
01Gooooo0_l0000[ooooo`;o0000<?ooool2o`0007Cooooo0003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooo
oooo00Cooooo0_l00007ooooo`;o0000>Oooool2o`00017ooooo0_l0000Eooooo`;o0000?oooool2
o`000003ooooool0003o000001Wooooo0_l0000Hooooo`;o00001_ooool2o`0001?ooooo0_l0000m
ooooo`000oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool3
o`00017ooooo0_l0000hooooo`;o0000??ooool2o`0002Sooooo0_l000000ooooooo0000o`00000b
ooooo`?o00001_ooool2o`0001?ooooo0_l0000mooooo`000oooool01Ol0003ooooooooooooooooo
000000gooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`0Aooooo`;o0000>?ooool2
o`0003cooooo0_l0001Gooooo`;o00001_ooool2o`0005_ooooo0003ooooo`05o`000?oooooooooo
ooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo03gooooo0_l0000m
ooooo`;o00009_ooool2o`0003cooooo0_l0000Gooooo`;o0000B_ooool000?ooooo00Go410@oooo
oooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool2
o`00037ooooo0_l0000mooooo`;o00006oooool2o`0000Wooooo0_l0001Eooooo`;o0000B_ooool0
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_oo
ool00ol0003oooooooooo`0:ooooo`;o0000O?ooool2o`0000_ooooo0_l00002ooooo`;o0000[?oo
ool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
1_ooool00ol0003oooooooooo`0gooooo`;o00000_ooool2o`0002_ooooo0_l0000Nooooo`;o0000
2oooool2o`0000;ooooo0_l0000jooooo`;o0000L?ooool001kooooo00?o0000ooooooooool09_oo
ool2o`0000oooooo0_l00002ooooo`;o0000:oooool2o`0001Oooooo0_l0000Fooooo`;o0000>_oo
ool2o`0002kooooo0_l00010ooooo`007_ooool00ol0003oooooooooo`05ooooo`;o00007oooool2
o`0002Cooooo0_l0000cooooo`;o00003oooool2o`0004?ooooo0_l0000/ooooo`;o0000@?ooool0
01kooooo00?o0000ooooooooool01Oooool2o`0002Sooooo0_l0000Kooooo`;o0000A?ooool2o`00
04?ooooo0_l0000Booooo`;o0000??ooool2o`0000Sooooo0_l0000Booooo`007_ooool00ol0003o
ooooooooo`0_ooooo`;o0000^_ooool2o`0003cooooo0_l00008ooooo`;o00004_ooool001kooooo
00?o0000ooooooooool04?ooool2o`0000?ooooo0_l0001/ooooo`;o00005oooool2o`0005gooooo
0_l0001:ooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o00000oooool2o`0006cooooo0_l0
000Gooooo`;o0000>Oooool2o`0002;ooooo0_l0000jooooo`;o00003_ooool001kooooo00?o0000
ooooooooool0eoooool2o`0003gooooo0_l0000>ooooo`;o00003oooool2o`0000kooooo000Noooo
o`03o`000?oooooooooo027ooooo0_l0003;ooooo`;o00005_ooool2o`0000kooooo0_l0000>oooo
o`;o00007oooool001kooooo00?o0000ooooooooool08Oooool2o`00017ooooo0_l0002hooooo`;o
00005_ooool2o`0001gooooo0_l0000Pooooo`007_ooool00ol0003oooooooooo`0dooooo`;o0000
8oooool2o`0000_ooooo0_l0001`ooooo`;o00001?ooool2o`0004Gooooo0_l0000Pooooo`007_oo
ool00ol0003oooooooooo`1Iooooo`;o00002oooool2o`00073ooooo0_l00004ooooo`;o0000Iooo
ool001kooooo0_l0000Gooooo`;o0000Noooool2o`00047ooooo0_l0001_ooooo`007_ooool00ol0
003oooooooooo`0Fooooo`;o00006Oooool2o`0004cooooo0_l00003ooooo`;o00003Oooool2o`00
03Kooooo0_l00009ooooo`;o0000Koooool001kooooo00?o0000ooooooooool04_ooool2o`0001go
oooo0_l00009ooooo`;o00002?ooool2o`0000?ooooo0_l0000]ooooo`;o00000oooool2o`0000?o
oooo0_l00015ooooo`;o00009Oooool2o`0005?ooooo000Nooooo`03o`000?oooooooooo00_ooooo
0_l00005ooooo`;o00002?ooool2o`0001kooooo0_l00008ooooo`;o00000oooool2o`0001Cooooo
0_l0000Gooooo`;o0000M_ooool2o`0005?ooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l0
000:ooooo`;o00000oooool2o`0000Oooooo0_l0000jooooo`;o00006oooool2o`0009kooooo0_l0
000Wooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o00001oooool2o`0000cooooo0_l0001G
ooooo`;o0000W_ooool2o`0002Oooooo000Nooooo`03o`000?oooooooooo00kooooo0_l00003oooo
o`;o0000i_ooool2o`0004[ooooo000Nooooo`03o`000?oooooooooo01?ooooo0_l0000kooooo`Co
0000G?ooool2o`0004Wooooo0_l0001:ooooo`007_ooool00ol0003oooooooooo`08ooooo`;o0000
:Oooool2o`0001_ooooo1?l0001Looooo`;o0000L?ooool2o`0001[ooooo0_l00007ooooo`007_oo
ool00ol0003oooooooooo`08ooooo`;o00002?ooool2o`0001oooooo0_l0000Cooooo`;o0000f?oo
ool2o`0001[ooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`02o`000003ooooool0003o
000000gooooo0_l0000/ooooo`;o00001_ooool2o`000?Cooooo0_l00007ooooo`007_ooool00ol0
003oooooooooo`02o`000003ooooool0003o000003_ooooo0_l0002;ooooo`;o0000I?ooool2o`00
00Wooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`06ooooo`;o00006_ooool2o`000:Wo
oooo0_l0001Tooooo`;o00004_ooool001kooooo00?o0000ooooooooool01_ooool2o`0001?ooooo
0_l00005ooooo`;o0000HOooool2o`000<3ooooo000Nooooo`03o`000?oooooooooo01_ooooo0_l0
001Xooooo`;o0000Goooool2o`0002Oooooo0_l000000ooooooo0000o`00000Sooooo`;o00003_oo
ool001kooooo00?o0000ooooooooool0i_ooool2o`0002Oooooo0_l000000ooooooo0000o`00000M
ooooo`;o00001?ooool2o`0000kooooo000Nooooo`;o00001oooool2o`0000;ooooo0_l0000Eoooo
o`;o00002_ooool2o`000?oooooo0oooool2o`0001Cooooo000Nooooo`03o`000?oooooooooo00Ko
oooo0_l00002ooooo`?o00004Oooool2o`000003ooooool0003o000000[ooooo0_l0001=ooooo`;o
0000bOooool001kooooo0_l0000<ooooo`;o00004Oooool2o`0001Kooooo0_l0000Nooooo`;o0000
9?ooool2o`00083ooooo0_l0000mooooo`;o00002?ooool001kooooo0_l0000gooooo`;o00007_oo
ool2o`00023ooooo0_l00024ooooo`;o0000?Oooool2o`0000Sooooo000Nooooo`03o`000?oooooo
oooo00Sooooo0_l0001^ooooo`;o0000Loooool2o`0001;ooooo0_l0000Iooooo`;o0000:Oooool0
01kooooo00?o0000ooooooooool02?ooool3o`0004cooooo0_l0002Dooooo`;o00004_ooool2o`00
01Wooooo0_l0000Yooooo`007_ooool00ol0003oooooooooo`09ooooo`;o00006oooool2o`0002oo
oooo0_l0001iooooo`;o0000Loooool001kooooo00?o0000ooooooooool09_ooool2o`00067ooooo
0_l0000/ooooo`;o00006Oooool2o`0004Wooooo0_l0000Xooooo`007_ooool00ol0003ooooooooo
o`1kooooo`;o00003?ooool2o`0002cooooo0_l0001Tooooo`;o0000:?ooool001kooooo00?o0000
ooooooooool0>Oooool2o`00043ooooo0_l00027ooooo`;o0000@Oooool001kooooo00?o0000oooo
ooooool0;oooool2o`0000Sooooo0_l0000Mooooo`;o0000<Oooool2o`0007Kooooo0ol00011oooo
o`007_ooool00ol0003oooooooooo`0_ooooo`;o00009oooool2o`00037ooooo0_l0000Booooo`;o
0000H_ooool2o`0004;ooooo000Nooooo`03o`000?oooooooooo00kooooo0_l0002?ooooo`;o0000
;oooool2o`0007Gooooo000Nooooo`03o`000?oooooooooo00kooooo0_l0001Rooooo`;o00005_oo
ool2o`0004Cooooo1?l0001cooooo`007_ooool00ol0003oooooooooo`1booooo`;o00002Oooool2
o`0000_ooooo0_l0000looooo`;o00002?ooool2o`0007?ooooo000Nooooo`03o`000?oooooooooo
05gooooo0_l0000Nooooo`;o00008_ooool2o`0002Gooooo0_l0001Zooooo`;o00004Oooool001ko
oooo0_l0000<ooooo`;o00006_ooool2o`0003Cooooo0_l00012ooooo`;o0000J_ooool2o`0002Co
oooo0ol0000Aooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o00003Oooool2o`0000_ooooo
0_l000000ooooooo0000o`00000dooooo`;o00001oooool2o`000:;ooooo0_l0000Tooooo`;o0000
4_ooool001kooooo00?o0000ooooooooool06_ooool2o`0000kooooo0_l0000Aooooo`;o00008Ooo
ool2o`0000Oooooo0_l0000=ooooo`;o0000cOooool001kooooo00?o0000ooooooooool05Oooool2
o`000003ooooool0003o0000017ooooo0_l0000@ooooo`;o00008?ooool2o`0001Oooooo0_l0000i
ooooo`;o0000>oooool2o`0001cooooo0_l00007ooooo`;o0000;_ooool001kooooo00?o0000oooo
ooooool05Oooool2o`000003ooooool0003o0000017ooooo0_l0000>ooooo`;o00008_ooool2o`00
05;ooooo0_l0000kooooo`;o00007?ooool2o`0000Oooooo0_l0000^ooooo`007_ooool00ol0003o
ooooooooo`0kooooo`;o0000?_ooool2o`00063ooooo0_l00016ooooo`;o00008?ooool001kooooo
00Co0000ooooool0003o0000N_ooool2o`00063ooooo0_l00016ooooo`;o00008?ooool001kooooo
1?l0000Nooooo`;o0000oooooolWooooo`007_ooool2o`00023ooooo0_l0000Zooooo`;o0000n_oo
ool001kooooo00?o0000ooooooooool0Boooool2o`0004Sooooo0_l0002Gooooo`;o00005oooool0
01kooooo00?o0000ooooooooool0B?ooool2o`0000cooooo0_l0000mooooo`;o0000Uoooool2o`00
01Oooooo000Nooooo`03o`000?oooooooooo01[ooooo0_l0000Looooo`;o00003_ooool2o`0000co
oooo0_l0003_ooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o00002oooool2o`0000oooooo
0_l0000Pooooo`;o00003_ooool2o`000003ooooool0003o000009gooooo0_l0000iooooo`007_oo
ool00ol0003oooooooooo`0:ooooo`;o00006oooool2o`00037ooooo0_l0000=ooooo`?o000000?o
ooooo`000?l000000_l0000jooooo`;o0000:_ooool2o`0003?ooooo0_l0000iooooo`000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?oo
ool00ol0003oooooooooo`0:ooooo`;o000000?oooooo`000?l000003oooool2o`0004Wooooo0_l0
0004ooooo`;o0000>_ooool2o`0002[ooooo0_l0000hooooo`;o000000?oooooo`000?l000009Ooo
ool2o`0000[ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0=ooooo`;o00003oooool2o`0004oooooo0_l0
000=ooooo`;o00001Oooool2o`0000[ooooo0_l0000Qooooo`;o00000oooool2o`0005Kooooo0_l0
00000ooooooo0000o`00000Uooooo`;o00002_ooool000?ooooo00Go410@oooooooooooooooooa0@
400;ooooo`Go00001_ooool3o`0000_ooooo0_l0001Rooooo`;o00003Oooool2o`0000Gooooo0_l0
000:ooooo`;o00008Oooool2o`0000?ooooo0_l0002<ooooo`000oooool01Ol0003ooooooooooooo
oooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool00ol0003oooooooooo`0;ooooo`;o0000
@Oooool2o`0005[ooooo0_l0002Kooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo
00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`1>ooooo`;o0000F_ooool2o`0004_o
oooo0_l0001>ooooo`000oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l0
00001oooool00ol0003oooooooooo`10ooooo`;o0000;Oooool2o`0008Kooooo0_l00003ooooo`;o
0000BOooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oo
oooo0_l0000Gooooo`;o00003oooool5o`0001Cooooo0_l0000]ooooo`;o0000Roooool2o`000003
ooooool0003o0000017ooooo0_l0000cooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00go
oooo00?oMgMgo`000?ooool01_ooool2o`0001Oooooo0_l0000?ooooo`Go0000doooool2o`00017o
oooo0_l0000Aooooo`;o00008?ooool001kooooo00?o0000ooooooooool03?ooool2o`0001oooooo
0_l0000Xooooo`;o00004?ooool2o`00037ooooo0_l0001;ooooo`;o0000>_ooool2o`00023ooooo
000Nooooo`03o`000?oooooooooo00cooooo0_l0000Hooooo`;o00001Oooool2o`0002Sooooo0_l0
000@ooooo`;o0000<Oooool2o`0004_ooooo0_l0000Qooooo`;o0000>Oooool001kooooo00?o0000
ooooooooool05Oooool2o`0000oooooo0_l0000>ooooo`;o00004_ooool2o`0000Oooooo1?l0000;
ooooo`;o0000:Oooool2o`0007gooooo0_l0000iooooo`007_ooool00ol0003oooooooooo`0Eoooo
o`;o00007oooool2o`0001;ooooo0_l00007ooooo`Ko00002Oooool2o`0002Wooooo0_l0002hoooo
o`007_ooool00ol0003oooooooooo`1Gooooo`;o00005Oooool4o`000=Gooooo000Nooooo`03o`00
0?oooooooooo02kooooo0_l0000Yooooo`;o00004oooool4o`0009;ooooo0_l00011ooooo`007_oo
ool00ol0003oooooooooo`0^ooooo`;o0000:Oooool2o`000:Wooooo0_l00011ooooo`007_ooool0
0ol0003oooooooooo`1/ooooo`;o0000fOooool001kooooo00?o0000ooooooooool01?ooool2o`00
02Gooooo0_l0000oooooo`;o0000U?ooool2o`0004?ooooo000Nooooo`03o`000?oooooooooo00Co
oooo0_l0000Uooooo`;o0000EOooool2o`0007kooooo0_l00013ooooo`007_ooool00ol0003ooooo
ooooo`1mooooo`;o00000oooool2o`0008Wooooo0_l0000hooooo`007_ooool2o`0004oooooo0_l0
000]ooooo`;o0000S_ooool2o`0003Sooooo000Nooooo`03o`000?oooooooooo04kooooo0_l0003@
ooooo`;o00009Oooool001kooooo00?o0000ooooooooool0:Oooool2o`0002?ooooo0_l0000=oooo
o`;o0000?oooool2o`0002kooooo0_l0001?ooooo`?o00009Oooool001kooooo00?o0000oooooooo
ool06Oooool2o`0000kooooo0_l0000Kooooo`;o00001_ooool2o`0000gooooo0_l0000oooooo`;o
0000;_ooool2o`0004oooooo0_l0000Vooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o0000
:oooool2o`000?oooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0003ooooooc;ooooo000N
ooooo`03o`000?oooooooooo01Cooooo0_l0000Cooooo`;o00004?ooool2o`0005Kooooo0_l0000k
ooooo`;o0000MOooool001kooooo00?o0000ooooooooool06?ooool2o`0000oooooo0_l0000@oooo
o`;o0000@oooool2o`00017ooooo0_l0000kooooo`;o00007Oooool2o`0005Kooooo000Nooooo`03
o`000?oooooooooo01Sooooo0_l0001Vooooo`;o00006_ooool2o`00057ooooo0_l0000Tooooo`;o
0000<?ooool001kooooo00?o0000ooooooooool0I_ooool2o`0003Cooooo0_l0001eooooo`Co0000
9oooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo05gooooo0_l00002ooooo`;o00000ooo
ool2o`0004cooooo0_l0001Mooooo`;o0000:Oooool2o`0000Oooooo000Nooooo`03o`000?oooooo
oooo02Wooooo0_l0000booooo`;o00000_ooool2o`0000_ooooo0_l0000Iooooo`;o0000:Oooool2
o`0001Kooooo0_l0001iooooo`007_ooool00ol0003oooooooooo`0Nooooo`;o00002Oooool2o`00
00Sooooo0_l0000iooooo`;o00006Oooool2o`0003oooooo1?l0001iooooo`007_ooool00ol0003o
ooooooooo`0Nooooo`;o00002Oooool2o`0000Sooooo0_l0000Kooooo`;o0000N?ooool2o`0000ko
oooo0_l0001[ooooo`007_ooool00ol0003oooooooooo`0Yooooo`;o00009Oooool2o`0008Sooooo
0_l0000dooooo`;o00000oooool2o`0001?ooooo0_l0000Kooooo`007_ooool00ol0003ooooooooo
o`0Yooooo`;o0000iOooool2o`0000?ooooo0_l0000Cooooo`;o000000?oooooo`000?l000006?oo
ool001kooooo0_l0003ooooooboooooo0_l00008ooooo`;o00003_ooool001kooooo0_l00019oooo
o`;o0000kOooool2o`0000kooooo000Nooooo`03o`000?oooooooooo04Sooooo0_l0001Aooooo`;o
00006_ooool2o`0000cooooo0_l00020ooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o0000
:oooool2o`0005Cooooo0_l0000Jooooo`;o00003?ooool2o`00083ooooo000Nooooo`03o`000?oo
oooooooo01Sooooo0_l0000Cooooo`;o00005_ooool2o`0000Oooooo0_l00009ooooo`;o0000gooo
ool2o`0000_ooooo000Nooooo`03o`000?oooooooooo02Kooooo0_l00005ooooo`;o00007oooool2
o`0000Wooooo0_l000000ooooooo0000o`00000Eooooo`;o00006_ooool2o`000:Wooooo0_l0000;
ooooo`007_ooool00ol0003oooooooooo`0Vooooo`;o0000=?ooool2o`0001Gooooo0_l0000Doooo
o`;o00001?ooool2o`0000oooooo0_l00024ooooo`;o00007oooool001kooooo00?o0000oooooooo
ool0ROooool2o`0001Gooooo0_l00024ooooo`;o00007oooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`0mooooo`;o0000A_ooool2o`000003ooooool0
003o000006Cooooo0_l0001Gooooo`007_ooool00ol0003oooooooooo`0Looooo`;o00007oooool2
o`0001Gooooo0_l0000_ooooo`;o000000?oooooo`000?l000004oooool2o`0002kooooo0_l0000O
ooooo`;o0000Eoooool001kooooo00?o0000ooooooooool07?ooool2o`0003Kooooo0_l00017oooo
o`;o0000;_ooool2o`0003;ooooo0_l0000Nooooo`;o00009?ooool001kooooo00?o0000oooooooo
ool0G?ooool2o`0001gooooo0_l0000hooooo`;o00008_ooool2o`0002Kooooo0_l00008ooooo`;o
00004Oooool2o`000003ooooool0003o000002Cooooo000Nooooo`03o`000?oooooooooo05cooooo
0_l0000Mooooo`;o0000>?ooool2o`0002;ooooo0_l0000_ooooo`?o00004Oooool2o`0002Oooooo
000Nooooo`03o`000?oooooooooo013ooooo0_l0000Hooooo`;o00004oooool2o`000<Wooooo0_l0
000<ooooo`;o0000;Oooool001kooooo00?o0000ooooooooool04?ooool2o`0001Sooooo0_l0000C
ooooo`;o0000Loooool2o`0006;ooooo0_l0000]ooooo`007_ooool2o`0009Cooooo0_l0000Ooooo
o`;o00004_ooool2o`0004Cooooo0_l0000Nooooo`;o00005oooool001kooooo0_l0000Mooooo`;o
00006Oooool4o`0004Kooooo0_l0000@ooooo`;o0000<oooool2o`0004Cooooo0_l0000Fooooo`;o
00001_ooool2o`0001Oooooo000Nooooo`;o00007Oooool2o`0001Wooooo1?l00008ooooo`;o0000
>Oooool5o`0004Gooooo0_l00005ooooo`;o0000??ooool2o`0001Oooooo0_l0000Hooooo`;o0000
1Oooool001kooooo00Co0000oooooooooooooooo0_l00010ooooo`;o0000>Oooool4o`0000Oooooo
0_l0000Oooooo`;o00007?ooool2o`0000Gooooo0_l0000looooo`?o0000<?ooool2o`0000Gooooo
000Nooooo`04o`000?ooooooooooooooo`;o0000Ioooool2o`0001gooooo0_l0000Oooooo`;o0000
H_ooool2o`0000kooooo0_l0000Wooooo`007_ooool00ol0003oooooooooo`1Zooooo`;o0000/_oo
ool2o`0000cooooo0_l0000Iooooo`007_ooool00ol0003oooooooooo`0_ooooo`;o0000ROooool2
o`0000Gooooo0_l0000mooooo`;o00003_ooool2o`0001[ooooo0_l0000Iooooo`007_ooool00ol0
003oooooooooo`0_ooooo`;o0000ROooool2o`0000Gooooo0_l0000Yooooo`;o00004_ooool2o`00
00?ooooo0_l00009ooooo`;o0000=Oooool001kooooo00?o0000ooooooooool0`_ooool2o`0002So
oooo0_l00002ooooo`;o00004oooool2o`0000_ooooo0_l0000cooooo`007_ooool00ol0003ooooo
ooooo`07ooooo`;o0000P?ooool2o`0003Oooooo0_l0000/ooooo`;o00008?ooool2o`0003?ooooo
000Nooooo`03o`000?oooooooooo00Oooooo0_l00010ooooo`;o00007?ooool2o`0000_ooooo0_l0
000Cooooo`;o0000@?ooool2o`0007[ooooo000Nooooo`03o`000?oooooooooo04Wooooo0_l0000L
ooooo`;o00002oooool2o`0005Gooooo0_l0000^ooooo`;o0000B_ooool001kooooo00?o0000oooo
ooooool0k?ooool2o`0000gooooo0_l0001:ooooo`007_ooool00ol0003oooooooooo`0Kooooo`;o
0000@Oooool2o`0008cooooo0_l0000^ooooo`;o0000:Oooool000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000oooo
ooooool06oooool2o`000003ooooool0003o000003kooooo0_l0000;ooooo`;o00005_ooool2o`00
01;ooooo0_l0000;ooooo`;o0000M_ooool2o`0002Wooooo0003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooo
oooo01kooooo0_l0001;ooooo`;o00005_ooool2o`0001;ooooo0_l0000;ooooo`;o0000;?ooool2
o`0003[ooooo0_l0000gooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`000006ooooo`?o0000H?ooool4o`0005Sooooo0_l0000Dooooo`;o00009ooo
ool2o`00017ooooo0_l0000gooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go
0000oiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo063ooooo1?l0001Hooooo`;o0000
?Oooool2o`0001oooooo0_l0000Qooooo`;o00001_ooool000?ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`3ooooooago
oooo0_l00002ooooo`;o00007Oooool2o`0000Kooooo0003ooooo`05oa0@4?ooooooooooooooool@
41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo0:Kooooo0_l0001`ooooo`;o
00001_ooool2o`0002Gooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo
410@oiRHV008ooooo`03o`000?oooooooooo023ooooo0_l0000iooooo`;o0000BOooool2o`00073o
oooo0_l0000?ooooo`;o00007?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04
olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool08?ooool2o`0003Wooooo0_l0002Hoooo
o`;o00002_ooool2o`00017ooooo0_l0000?ooooo`;o00000_ooool2o`0001cooooo000Nooooo`03
o`000?oooooooooo04?ooooo0_l0000Looooo`;o0000T_ooool2o`0000[ooooo0_l0000<ooooo`Co
000000?oooooo`000?l000003Oooool4o`00023ooooo000Nooooo`03o`000?oooooooooo02Gooooo
0_l0000Iooooo`;o000000?oooooo`000?l000007?ooool2o`0003?ooooo0_l0001gooooo`Co0000
4?ooool2o`0002;ooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0000Iooooo`;o00001Ooo
ool2o`0000;ooooo0_l0000Eooooo`?o00007_ooool2o`0000;ooooo0_l0000<ooooo`;o00007?oo
ool2o`0000?ooooo0_l0001gooooo`;o0000=_ooool001kooooo00?o0000ooooooooool00oooool2
o`0001Wooooo0_l00009ooooo`;o00005_ooool2o`0001kooooo0_l00002ooooo`;o00003?ooool2
o`0000oooooo0_l0000;ooooo`;o0000D_ooool2o`000004ooooool0003o0000o`0002Cooooo0_l0
000fooooo`007_ooool00ol0003oooooooooo`1Looooo`;o00009_ooool2o`00057ooooo0_l0000<
ooooo`;o000000Coooooo`000?l0003o0000<Oooool2o`0002Wooooo000Nooooo`03o`000?oooooo
oooo00Gooooo0_l0001Eooooo`;o00001_ooool2o`0002Sooooo0_l0000Looooo`;o00009Oooool2
o`0000;ooooo0_l00002ooooo`;o0000:oooool2o`0001;ooooo0_l0000Yooooo`007_ooool00ol0
003oooooooooo`05ooooo`;o0000GOooool2o`0000?ooooo0_l0000=ooooo`;o00005?ooool2o`00
00;ooooo0_l0000Hooooo`;o00009Oooool2o`0000Kooooo0_l0000[ooooo`;o00006Oooool2o`00
02;ooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l00010ooooo`Co00000oooool2o`0000Ko
oooo0_l0000Hooooo`;o00004oooool2o`0006Kooooo0_l0000Booooo`;o00008_ooool001kooooo
00?o0000ooooooooool09oooool2o`00037ooooo0_l00003ooooo`;o00002_ooool2o`0000?ooooo
0_l0000Looooo`;o00005oooool2o`0000Oooooo0_l0001@ooooo`;o00002oooool2o`0003Kooooo
000Nooooo`03o`000?oooooooooo05[ooooo0_l00003ooooo`;o0000;Oooool2o`00023ooooo0_l0
001@ooooo`;o00000_ooool2o`0003oooooo000Nooooo`03o`000?oooooooooo07Gooooo0_l0000A
ooooo`;o0000:?ooool2o`0005;ooooo0_l0000Tooooo`;o00006Oooool001kooooo0_l0001foooo
o`;o00004Oooool2o`0002Sooooo0ol0000Hooooo`;o0000GOooool2o`0001Wooooo000Nooooo`03
o`000?oooooooooo03Kooooo0_l0001kooooo`;o00006?ooool2o`0007Sooooo000Nooooo`03o`00
0?oooooooooo03Kooooo0_l0001?ooooo`;o00008oooool2o`0000cooooo0_l0000Mooooo`;o0000
K?ooool001kooooo00?o0000ooooooooool0?Oooool2o`0003[ooooo0_l0000<ooooo`;o00008ooo
ool2o`0000cooooo0_l0000Mooooo`;o0000=?ooool2o`0003Kooooo000Nooooo`03o`000?oooooo
oooo00Wooooo0_l0000booooo`;o0000>_ooool2o`0000?ooooo0_l0002?ooooo`;o0000=_ooool0
01kooooo00?o0000ooooooooool02Oooool2o`0000;ooooo0_l0000Looooo`;o00005oooool2o`00
03Sooooo0_l00037ooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o00007?ooool2o`0001Oo
oooo0_l0000/ooooo`;o0000;?ooool2o`0001[ooooo0_l00029ooooo`007_ooool00ol0003ooooo
ooooo`0Kooooo`;o0000EOooool2o`0001Cooooo0_l0000Fooooo`;o00006_ooool2o`0006Wooooo
0_l0000Nooooo`007_ooool00ol0003oooooooooo`0Kooooo`;o00008Oooool2o`0001;ooooo0_l0
000@ooooo`;o00008_ooool2o`0000_ooooo0_l0002@ooooo`;o00007_ooool001kooooo00?o0000
ooooooooool0?_ooool2o`0001;ooooo0_l0000@ooooo`;o0000;oooool2o`000;3ooooo000Noooo
o`03o`000?oooooooooo0;7ooooo0_l0002Dooooo`007_ooool00ol0003oooooooooo`1Eooooo`;o
0000F_ooool2o`0003_ooooo0_l0001Gooooo`007_ooool00ol0003oooooooooo`0Xooooo`;o0000
:oooool2o`00097ooooo0_l00004ooooo`;o0000Eoooool001kooooo00?o0000ooooooooool0:?oo
ool2o`000;kooooo0_l0001Mooooo`007_ooool00ol0003oooooooooo`2eooooo`;o0000T?ooool0
01kooooo00?o0000ooooooooool0TOooool2o`0002;ooooo0_l0001Pooooo`;o0000;_ooool001ko
oooo0_l00029ooooo`;o00001oooool2o`0007?ooooo0_l0000?ooooo`;o00007oooool2o`0000go
oooo000Nooooo`03o`000?oooooooooo00cooooo0_l0001Yooooo`;o00003oooool2o`0002kooooo
0_l0001<ooooo`?o0000;oooool2o`0000gooooo000Nooooo`03o`000?oooooooooo00cooooo0ol0
000Nooooo`;o0000B?ooool2o`0003Cooooo0_l00009ooooo`;o0000COooool2o`0003kooooo000N
ooooo`03o`000?oooooooooo00gooooo0_l0000Nooooo`;o0000E?ooool2o`0002Gooooo0_l00000
0ooooooo0000o`00001?ooooo`;o00004Oooool2o`0002Wooooo0_l00009ooooo`007_ooool2o`00
023ooooo0_l0000Dooooo`;o0000<oooool2o`0001Oooooo0_l0000Uooooo`;o0000;oooool2o`00
027ooooo0_l0000Aooooo`;o0000:Oooool2o`0000Wooooo000Nooooo`;o00008?ooool2o`0000Go
oooo0_l0000=ooooo`;o0000<oooool2o`0006oooooo0_l0000Pooooo`;o0000B?ooool001kooooo
00?o0000ooooooooool09_ooool2o`00033ooooo0_l0002Sooooo`;o0000B?ooool001kooooo00?o
0000ooooooooool01_ooool2o`00053ooooo0_l0000Booooo`;o0000B?ooool2o`0007Wooooo0_l0
000Dooooo`007_ooool00ol0003oooooooooo`06ooooo`;o0000;?ooool2o`0003Kooooo0_l0000K
ooooo`;o0000:oooool2o`0007Wooooo0_l0000Dooooo`007_ooool00ol0003oooooooooo`0Xoooo
o`;o00002_ooool2o`0005?ooooo0_l0001Looooo`;o0000G_ooool001kooooo00?o0000oooooooo
ool0:?ooool2o`0003[ooooo0_l0001nooooo`;o000000?oooooo`000?l00000G_ooool001kooooo
00?o0000ooooooooool0I?ooool2o`0001Kooooo0_l0001Vooooo`;o0000F?ooool2o`0000Oooooo
000Nooooo`03o`000?oooooooooo02Gooooo0_l0000Jooooo`;o0000>Oooool2o`0005gooooo0_l0
001?ooooo`;o00004?ooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo02Gooooo0_l0000J
ooooo`;o0000@?ooool2o`0004gooooo0_l00007ooooo`;o0000?_ooool2o`0000?ooooo0_l0000:
ooooo`;o00006Oooool001kooooo00?o0000ooooooooool0JOooool2o`0000oooooo0_l00007oooo
o`;o0000=_ooool2o`0001Gooooo0_l00017ooooo`;o00000oooool2o`0002Gooooo000Nooooo`03
o`000?oooooooooo06Wooooo0_l00007ooooo`;o00001_ooool2o`0000Gooooo0ol0000gooooo`;o
0000J_ooool2o`0001kooooo000Nooooo`;o0000>_ooool2o`0003Oooooo0_l00002ooooo`?o0000
2?ooool3o`0007_ooooo0_l0000Vooooo`;o00007_ooool001kooooo00?o0000ooooooooool0:ooo
ool2o`0000cooooo0_l0000kooooo`?o0000Coooool2o`0003Gooooo0_l00003ooooo`;o0000@Ooo
ool001kooooo00?o0000ooooooooool0:oooool2o`0001Kooooo0_l0000[ooooo`;o0000E_ooool2
o`0002;ooooo0_l0000Fooooo`;o0000@Oooool001kooooo00?o0000ooooooooool0@oooool2o`00
02_ooooo0_l0001Jooooo`;o00007_ooool2o`00027ooooo0_l0000fooooo`007_ooool00ol0003o
ooooooooo`06ooooo`;o00002oooool2o`0001;ooooo0_l00002ooooo`;o0000Woooool2o`00047o
oooo0_l0000fooooo`007_ooool01?l0003oooooo`000?l00005ooooo`;o00002oooool2o`0001;o
oooo0_l00002ooooo`;o00007Oooool2o`000?_ooooo000Nooooo`04o`000?oooooo0000o`0000oo
oooo0_l0000hooooo`;o0000OOooool2o`0001oooooo0ol0000fooooo`;o00008_ooool001kooooo
00?o0000ooooooooool04?ooool2o`0000oooooo0_l00003ooooo`Go0000W_ooool2o`0001oooooo
0ol00004ooooo`;o0000:oooool2o`0000?ooooo0_l00003ooooo`;o00007Oooool001kooooo00?o
0000ooooooooool08Oooool2o`0000?ooooo1Ol0002fooooo`;o00003_ooool2o`0002_ooooo0_l0
0008ooooo`;o00007Oooool001kooooo00?o0000ooooooooool0hOooool2o`0001?ooooo0_l0000j
ooooo`;o00004oooool001kooooo00?o0000ooooooooool0Joooool2o`0002_ooooo0_l0000Roooo
o`;o00006?ooool2o`00013ooooo0_l0000<ooooo`;o00001Oooool2o`0003?ooooo0_l0000Coooo
o`007_ooool00ol0003oooooooooo`1Yooooo`Co00004?ooool2o`0001Wooooo0_l0000:ooooo`;o
00005Oooool3o`0001Sooooo0_l0000@ooooo`;o00003_ooool2o`000003ooooool0003o000000;o
0000<oooool3o`0001;ooooo000Nooooo`03o`000?oooooooooo03Kooooo0_l0000aooooo`;o0000
1_ooool2o`0000[ooooo0_l0000Uooooo`;o00005Oooool2o`0003_ooooo0_l000000ooooooo0000
o`00000fooooo`;o00004_ooool001kooooo00?o0000ooooooooool0;_ooool2o`0000Kooooo0_l0
000eooooo`;o00000_ooool2o`0004cooooo0_l00026ooooo`000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`0^ooooo`;o00007_ooool2o`0001gooooo0_l0001@ooooo`;o0000C_ooool2o`0003Kooooo
0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?oooooo
V9RHob4Q8@06ooooo`03o`000?oooooooooo02Cooooo0_l00006ooooo`;o00008?ooool2o`0002oo
oooo0_l0000jooooo`;o0000>_ooool2o`0000gooooo0_l00007ooooo`?o00007oooool2o`0001Co
oooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo0000
00Kooooo0ol0000Tooooo`;o00001_ooool2o`00057ooooo0_l0000;ooooo`;o0000;Oooool2o`00
03[ooooo0_l0000=ooooo`;o00002?ooool2o`0001oooooo0_l0000Dooooo`000oooool01Ol0003o
oooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooo
oooo037ooooo0_l0000Tooooo`;o00003?ooool2o`00023ooooo0_l00003ooooo`;o0000Foooool2
o`0005cooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0
003oc<c<00Kooooo00?o0000ooooooooool0<Oooool3o`00027ooooo1?l0000<ooooo`?o00007ooo
ool2o`0002oooooo0_l0000_ooooo`;o0000?oooool2o`0001_ooooo0003ooooo`05oa0@4?oooooo
ooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0
<_ooool2o`00027ooooo0_l00008ooooo`;o00001Oooool2o`00053ooooo0_l0000Iooooo`;o0000
7Oooool2o`0000Cooooo0_l00006ooooo`;o00007?ooool2o`0000[ooooo0_l0000Kooooo`000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03
o`000?oooooooooo05cooooo0_l000000ooooooo0000o`00000;ooooo`;o00005oooool2o`000003
ooooool0003o0000017ooooo0_l0000fooooo`?o00007?ooool2o`0000Cooooo0_l00006ooooo`;o
00007?ooool2o`0002Oooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo
410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0G?ooool2o`0000kooooo0_l0000Goooo
o`;o000000?oooooo`000?l000004Oooool2o`0002gooooo0_l00008ooooo`;o0000C?ooool2o`00
02?ooooo000Nooooo`03o`000?oooooooooo04Oooooo0_l00010ooooo`;o0000?oooool2o`0005Ko
oooo0_l0000Sooooo`007_ooool00ol0003oooooooooo`17ooooo`;o00002_ooool2o`0003Cooooo
0_l00013ooooo`;o0000<?ooool2o`0000Cooooo0_l0000oooooo`007_ooool00ol0003ooooooooo
o`0gooooo`;o00001oooool2o`0000?ooooo0_l0000<ooooo`;o0000Goooool2o`0001Sooooo0_l0
000`ooooo`;o00001?ooool2o`0003oooooo000Nooooo`03o`000?oooooooooo03Oooooo0_l00007
ooooo`;o00000oooool2o`0000Cooooo0_l0000>ooooo`Go0000<_ooool2o`00023ooooo0_l0000^
ooooo`;o0000:oooool2o`0001?ooooo0_l0000Oooooo`007_ooool00ol0003oooooooooo`0goooo
o`;o00004_ooool2o`0000kooooo1Ol0000booooo`;o0000D?ooool2o`0002_ooooo0_l00004oooo
o`Co00002oooool2o`0001oooooo000Nooooo`03o`000?oooooooooo03oooooo0_l0001Looooo`;o
0000B?ooool2o`0002kooooo1?l0000/ooooo`007_ooool00ol0003oooooooooo`05ooooo`;o0000
>?ooool2o`0004Gooooo0_l0000Eooooo`;o0000B?ooool2o`0005kooooo000Nooooo`03o`000?oo
oooooooo00Gooooo0_l0000:ooooo`;o0000@Oooool2o`0001Sooooo0_l0000Fooooo`;o0000_ooo
ool001kooooo00?o0000ooooooooool04Oooool2o`0002oooooo0_l0000@ooooo`;o00006?ooool2
o`0000Oooooo0_l00036ooooo`;o00001_ooool001kooooo00?o0000ooooooooool0@_ooool2o`00
02[ooooo0_l00007ooooo`;o0000X?ooool2o`0002Cooooo0_l00006ooooo`007_ooool00ol0003o
ooooooooo`08ooooo`;o0000C?ooool2o`0000Gooooo0_l0000?ooooo`;o0000ZOooool2o`0001Co
oooo0ol0000Eooooo`007_ooool2o`0000Wooooo0_l0001<ooooo`;o00001Oooool2o`0001Oooooo
0_l0000nooooo`;o0000:?ooool2o`0004gooooo0ol0000Eooooo`007_ooool01?l0003ooooooooo
ooooool2o`0004Wooooo0_l0000Xooooo`;o00006_ooool2o`0000[ooooo0_l0000Fooooo`;o0000
:?ooool2o`0006Gooooo000Nooooo`04o`000?ooooooooooooooo`;o00007oooool2o`0002Sooooo
0_l0000Yooooo`;o00003Oooool2o`0000[ooooo0_l00007ooooo`;o000000?oooooo`000?l00000
LOooool2o`0001_ooooo0_l0000;ooooo`;o00002_ooool001kooooo00?o0000ooooooooool06_oo
ool2o`0000Kooooo0_l0000Jooooo`;o0000=oooool2o`0000gooooo0_l00009ooooo`;o00002?oo
ool2o`0007Cooooo0_l0000Kooooo`;o00002oooool2o`0000[ooooo000Nooooo`03o`000?oooooo
oooo01[ooooo0_l0000?ooooo`;o00004Oooool2o`0002Wooooo0ol0000Uooooo`;o00001_ooool2
o`0004Oooooo0_l0001Sooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o00006?ooool2o`00
03cooooo0ol000000ooooooo0000o`00000Xooooo`Co000000?oooooo`000?l00000<Oooool2o`00
017ooooo0_l0001:ooooo`;o00005oooool001kooooo00?o0000ooooooooool04Oooool2o`0005[o
oooo0_l000000ooooooo0000o`00000Uooooo`;o00000_ooool3o`0002cooooo0_l00003ooooo`;o
00003?ooool2o`0004oooooo0_l0000Gooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o0000
8?ooool2o`0003Gooooo0_l00006ooooo`;o0000:Oooool2o`0002gooooo0_l0000Aooooo`;o0000
@Oooool3o`0002Cooooo000Nooooo`03o`000?oooooooooo00oooooo0_l0000Pooooo`;o0000:Ooo
ool2o`0000[ooooo0_l0002Hooooo`;o00001?ooool2o`0001Kooooo0ol0000Tooooo`007_ooool0
0ol0003oooooooooo`1Looooo`;o0000Y?ooool2o`0000Cooooo0_l0000mooooo`007_ooool00ol0
003oooooooooo`0booooo`;o0000oooooolDooooo`007_ooool00ol0003oooooooooo`06ooooo`;o
00008oooool2o`0000Gooooo0_l0002aooooo`;o00003Oooool2o`00057ooooo000Nooooo`03o`00
0?oooooooooo00Kooooo0_l0000Sooooo`;o0000:Oooool2o`0006Kooooo0_l0000Uooooo`;o0000
3Oooool2o`00057ooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l00016ooooo`;o00002Ooo
ool2o`0006Kooooo0_l0000dooooo`;o0000DOooool001kooooo00?o0000ooooooooool00oooool2
o`0004Kooooo0_l0000Xooooo`;o00003?ooool4o`0000;ooooo0_l0001Xooooo`;o0000A_ooool2
o`0000[ooooo000Nooooo`03o`000?oooooooooo05Kooooo0_l0000Mooooo`;o00003?ooool4o`00
00;ooooo0_l0000oooooo`;o00008oooool2o`0000;ooooo0_l00016ooooo`;o00002_ooool001ko
oooo0_l00008ooooo`;o00005oooool2o`0003Cooooo0_l0001Jooooo`;o00005_ooool2o`0000co
oooo0_l0000Eooooo`;o00004?ooool2o`0004Cooooo000Nooooo`03o`000?oooooooooo00Oooooo
0_l0000Gooooo`;o0000T?ooool2o`0002Cooooo0_l0000Wooooo`;o0000A?ooool001kooooo00?o
0000ooooooooool0DOooool2o`0001Cooooo0_l00013ooooo`;o00001?ooool2o`0001Cooooo0_l0
001mooooo`007_ooool00ol0003oooooooooo`13ooooo`;o00003?ooool2o`0001Cooooo0_l0000o
ooooo`;o00000_ooool2o`0001[ooooo0_l0000_ooooo`;o0000C?ooool001kooooo00?o0000oooo
ooooool05Oooool2o`0001?ooooo0_l0000Gooooo`;o00008_ooool2o`0003oooooo0_l0001?oooo
o`;o0000C?ooool001kooooo00?o0000ooooooooool05Oooool2o`0001?ooooo0_l0000Vooooo`;o
00004?ooool2o`00087ooooo0_l0000nooooo`;o00007_ooool001kooooo00?o0000ooooooooool0
D_ooool2o`00013ooooo0_l0000Wooooo`;o0000<?ooool2o`0002Kooooo0_l0000Mooooo`;o0000
7oooool2o`0001Gooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`2=ooooo`;o00000_oo
ool2o`0000[ooooo0_l0000Pooooo`;o0000AOooool2o`0003Kooooo0_l00007ooooo`007Oooool2
o`0002gooooo0_l00007ooooo`;o00004Oooool2o`0004Sooooo0_l0000:ooooo`;o0000NOooool2
o`0002gooooo000Mooooo`;o0000;Oooool2o`0000Oooooo0_l0000Aooooo`;o0000coooool2o`00
02gooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
hOooool2o`0006Cooooo000Nooooo`03o`000?oooooooooo0>7ooooo0_l0001Tooooo`007_ooool0
0ol0003oooooooooo`2hooooo`;o0000SOooool001kooooo00?o0000ooooooooool0=oooool2o`00
00oooooo0_l0000>ooooo`;o0000G_ooool2o`0000kooooo0_l0000Kooooo`;o000000?oooooo`00
0?l00000GOooool001kooooo0_l0000Tooooo`;o00004_ooool2o`0000oooooo0_l0000>ooooo`;o
0000?oooool2o`0002gooooo0_l0000Kooooo`;o000000?oooooo`000?l000008?ooool2o`0003_o
oooo000Nooooo`;o00009?ooool2o`0000;ooooo0_l0000nooooo`;o0000<?ooool2o`0001?ooooo
0_l0000_ooooo`;o0000:Oooool2o`0003_ooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l0
000nooooo`;o0000AOooool2o`0002oooooo0_l0000mooooo`;o00002Oooool2o`0001cooooo000N
ooooo`03o`000?oooooooooo01[ooooo0_l0000eooooo`;o00001_ooool2o`000<?ooooo0_l00009
ooooo`;o00007?ooool001kooooo00?o0000ooooooooool06_ooool2o`00033ooooo0_l00003oooo
o`;o00001_ooool2o`0002cooooo0_l0000]ooooo`;o0000;Oooool2o`0003[ooooo0_l00006oooo
o`;o00007?ooool001kooooo00?o0000ooooooooool03_ooool2o`0003Oooooo0_l00003ooooo`;o
00007?ooool2o`0000Cooooo0_l0000Eooooo`;o00003oooool2o`0001cooooo0_l0000]ooooo`;o
0000>_ooool2o`0002Cooooo000Nooooo`03o`000?oooooooooo00kooooo0_l0000gooooo`;o0000
0oooool2o`0001cooooo0_l00004ooooo`;o00004_ooool2o`00017ooooo0ol0000oooooo`;o0000
2_ooool2o`00063ooooo000Nooooo`03o`000?oooooooooo04cooooo0_l0000Eooooo`;o00007ooo
ool2o`00017ooooo0_l0000Pooooo`;o00007_ooool2o`0000cooooo0_l0001Nooooo`007_ooool0
0ol0003oooooooooo`0Booooo`;o0000Coooool2o`0002gooooo0_l0000Uooooo`;o0000;?ooool2
o`0005kooooo000Nooooo`04o`000?oooooo0000o`00017ooooo0_l0000Hooooo`;o00006_ooool2
o`0000oooooo0_l0000gooooo`;o0000/oooool001kooooo00Co0000ooooool0003o0000:oooool2
o`0001[ooooo0_l0000?ooooo`;o00004_ooool2o`000<[ooooo0_l0000<ooooo`007_ooool00ol0
003oooooooooo`16ooooo`;o00009Oooool2o`0007;ooooo0_l0000Jooooo`;o0000=?ooool2o`00
00Cooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`16ooooo`;o0000>oooool2o`0005co
oooo0_l0000Jooooo`;o0000=?ooool2o`0001;ooooo000Mooooo`;o00005Oooool2o`0003?ooooo
0_l0000iooooo`;o00006Oooool2o`0005?ooooo0_l0001;ooooo`;o00001Oooool001gooooo0_l0
000Eooooo`;o0000<oooool2o`0005Cooooo0_l00007ooooo`;o0000;Oooool2o`0001_ooooo0_l0
00000ooooooo0000o`00000/ooooo`;o00006_ooool2o`0000Gooooo000Dooooo`Co000000?o410@
ooooooooool00oooool00ol0003oooooooooo`2Wooooo`;o0000;Oooool2o`0001kooooo0_l0000/
ooooo`;o00008Oooool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2ooooo
o`;o0000Q_ooool001Kooooo00?o0000ooooooooool01Oooool3o`0007Oooooo0_l00016ooooo`;o
00002oooool2o`0007Wooooo000Fooooo`03o`000?oooooooooo07oooooo0_l0001Cooooo`;o0000
NOooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3o
oooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Cooooo00?oEEEEofIVI_l0
0000oooooomBooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.97048 .13814 Mdot
.4251 .01362 Mdot
.20944 .18502 Mdot
.57209 .96871 Mdot
.24148 .0572 Mdot
.07615 .5471 Mdot
.92829 .37153 Mdot
.08177 .44678 Mdot
.25485 .83628 Mdot
.4561 .01778 Mdot
.58387 .82464 Mdot
.32001 .74814 Mdot
.27426 .20801 Mdot
.62923 .082 Mdot
.33013 .41638 Mdot
.61417 .47518 Mdot
.62941 .9951 Mdot
.02635 .29276 Mdot
.48939 .04176 Mdot
.10777 .53342 Mdot
.43003 .73958 Mdot
.11687 .10448 Mdot
.26356 .32528 Mdot
.00712 .80676 Mdot
.92249 .53137 Mdot
.50747 .54358 Mdot
.84689 .59676 Mdot
.71912 .41347 Mdot
.67509 .93744 Mdot
.23422 .85579 Mdot
.89533 .78607 Mdot
.52313 .94919 Mdot
.65974 .35767 Mdot
.07184 .16066 Mdot
.88528 .49309 Mdot
.69324 .79241 Mdot
.55302 .8315 Mdot
.39688 .69534 Mdot
.04677 .53348 Mdot
.16125 .84018 Mdot
.86593 .10793 Mdot
.30183 .67096 Mdot
.41266 .06629 Mdot
.3119 .14901 Mdot
.0395 .09675 Mdot
.53423 .59186 Mdot
.72268 .95735 Mdot
.44203 .14362 Mdot
.94884 .96128 Mdot
.34801 .90087 Mdot
.13733 .75496 Mdot
.76594 .60632 Mdot
.02595 .04545 Mdot
.03425 .39097 Mdot
.10757 .60842 Mdot
.20145 .88286 Mdot
.77738 .02914 Mdot
.18967 .81618 Mdot
.37829 .35014 Mdot
.20737 .00212 Mdot
.03742 .21213 Mdot
.10655 .85612 Mdot
.2265 .84357 Mdot
.6853 .73076 Mdot
.72754 .37422 Mdot
.24445 .99519 Mdot
.03716 .0142 Mdot
.5833 .74239 Mdot
.9651 .90893 Mdot
.92448 .21218 Mdot
.96284 .88012 Mdot
.18091 .58008 Mdot
.0755 .49092 Mdot
.54855 .59615 Mdot
.58188 .06072 Mdot
.05316 .14505 Mdot
.21091 .93204 Mdot
.30722 .57879 Mdot
.82732 .46321 Mdot
.16632 .48755 Mdot
.47402 .03623 Mdot
.78372 .83162 Mdot
.21034 .75857 Mdot
.97555 .41698 Mdot
.5145 .81788 Mdot
.00205 .76574 Mdot
.35521 .35479 Mdot
.23747 .81082 Mdot
.52246 .80474 Mdot
.47965 .67873 Mdot
.17304 .76816 Mdot
.77662 .60641 Mdot
.09668 .49482 Mdot
.56469 .37734 Mdot
.36977 .2179 Mdot
.17686 .4382 Mdot
.4173 .84886 Mdot
.68699 .26478 Mdot
.62511 .94904 Mdot
.44993 .87559 Mdot
.4417 .50738 Mdot
.73214 .6155 Mdot
.84289 .9994 Mdot
.39601 .45604 Mdot
.38567 .46622 Mdot
.21777 .54354 Mdot
.3536 .83345 Mdot
.74212 .60128 Mdot
.19514 .6946 Mdot
.61012 .85514 Mdot
.10384 .17151 Mdot
.64388 .60819 Mdot
.00682 .29952 Mdot
.40761 .39842 Mdot
.95986 .63762 Mdot
.70719 .76812 Mdot
.16124 .64452 Mdot
.91991 .78098 Mdot
.39902 .43174 Mdot
.49361 .78196 Mdot
.70019 .20572 Mdot
.56715 .37245 Mdot
.01973 .40796 Mdot
.33192 .11779 Mdot
.53192 .60975 Mdot
.29156 .37248 Mdot
.44189 .7026 Mdot
.36197 .94313 Mdot
.8211 .71484 Mdot
.78991 .841 Mdot
.86068 .90098 Mdot
.95503 .7208 Mdot
.06594 .23507 Mdot
.76786 .87236 Mdot
.44979 .26553 Mdot
.13471 .13318 Mdot
.3792 .8651 Mdot
.02582 .42208 Mdot
.49078 .60897 Mdot
.42562 .87879 Mdot
.14669 .38086 Mdot
.11158 .38325 Mdot
.77948 .96209 Mdot
.90147 .16465 Mdot
.32556 .41822 Mdot
.41228 .63811 Mdot
.40411 .78434 Mdot
.79586 .17013 Mdot
.40458 .30553 Mdot
.14069 .22153 Mdot
.19553 .00541 Mdot
.23905 .16711 Mdot
.6724 .05214 Mdot
.76821 .99457 Mdot
.27309 .35057 Mdot
.43673 .45762 Mdot
.4361 .62157 Mdot
.56764 .21255 Mdot
.67135 .52616 Mdot
.04942 .65452 Mdot
.80379 .58598 Mdot
.278 .83922 Mdot
.98295 .28201 Mdot
.87395 .37388 Mdot
.87132 .68318 Mdot
.6034 .67376 Mdot
.07673 .60979 Mdot
.67943 .69387 Mdot
.2312 .55109 Mdot
.94709 .07647 Mdot
.86687 .41228 Mdot
.30505 .12229 Mdot
.45782 .235 Mdot
.2181 .63319 Mdot
.85706 .53952 Mdot
.79229 .97824 Mdot
.39713 .43047 Mdot
.69432 .7714 Mdot
.50922 .3881 Mdot
.3909 .52321 Mdot
.05623 .22382 Mdot
.87998 .05286 Mdot
.73709 .96501 Mdot
.17663 .38844 Mdot
.77856 .22951 Mdot
.66134 .19931 Mdot
.4465 .22507 Mdot
.23911 .50568 Mdot
.45313 .36293 Mdot
.03481 .40971 Mdot
.38433 .24502 Mdot
.04474 .31433 Mdot
.82781 .58427 Mdot
.205 .93791 Mdot
.41918 .08879 Mdot
.63602 .98304 Mdot
.3913 .35138 Mdot
.46464 .178 Mdot
.3348 .51791 Mdot
.96287 .97283 Mdot
.07422 .81952 Mdot
.49177 .17121 Mdot
.12531 .18015 Mdot
.08995 .39781 Mdot
.81826 .7529 Mdot
.39724 .15422 Mdot
.99654 .25451 Mdot
.37042 .55589 Mdot
.31228 .39516 Mdot
.08904 .67904 Mdot
.49191 .31082 Mdot
.70583 .18007 Mdot
.68948 .80881 Mdot
.52146 .45823 Mdot
.26931 .31414 Mdot
.83566 .49402 Mdot
.79982 .90129 Mdot
.07602 .11982 Mdot
.39417 .26395 Mdot
.18781 .91804 Mdot
.84158 .38617 Mdot
.73443 .60461 Mdot
.7758 .66877 Mdot
.67119 .80901 Mdot
.63371 .37922 Mdot
.56959 .79013 Mdot
.98521 .52109 Mdot
.39555 .67739 Mdot
.66811 .88069 Mdot
.65692 .93277 Mdot
.707 .18389 Mdot
.68874 .86113 Mdot
.17437 .49764 Mdot
.65658 .571 Mdot
.88584 .39301 Mdot
.59386 .50916 Mdot
.61408 .58703 Mdot
.45963 .0791 Mdot
.26051 .65708 Mdot
.7818 .98576 Mdot
.00133 .91266 Mdot
.71491 .50387 Mdot
.82907 .24196 Mdot
.4905 .398 Mdot
.10887 .95373 Mdot
.05865 .13335 Mdot
.6022 .11174 Mdot
.04913 .43334 Mdot
.65041 .17833 Mdot
.21821 .6648 Mdot
.77185 .19331 Mdot
.72414 .08978 Mdot
.42013 .65411 Mdot
.69307 .14325 Mdot
.16617 .9923 Mdot
.85007 .20329 Mdot
.62439 .79388 Mdot
.02473 .20453 Mdot
.16925 .11201 Mdot
.28111 .6381 Mdot
.34077 .28113 Mdot
.9091 .53255 Mdot
.20918 .63341 Mdot
.64563 .83606 Mdot
.23464 .4147 Mdot
.6024 .52713 Mdot
.54669 .6595 Mdot
.42335 .80429 Mdot
.58333 .68288 Mdot
.58348 .94523 Mdot
.53764 .97663 Mdot
.8645 .61866 Mdot
.79297 .30465 Mdot
.14591 .77601 Mdot
.31569 .16464 Mdot
.12472 .44435 Mdot
.53407 .23365 Mdot
.06402 .26124 Mdot
.49 .83342 Mdot
.43205 .28188 Mdot
.50637 .96115 Mdot
.09019 .73803 Mdot
.32901 .04886 Mdot
.89055 .81641 Mdot
.10751 .55217 Mdot
.27899 .55763 Mdot
.6362 .7288 Mdot
.69634 .61099 Mdot
.71567 .94786 Mdot
.03677 .6832 Mdot
.65341 .78443 Mdot
.35583 .14079 Mdot
.63745 .23309 Mdot
.31942 .78016 Mdot
.59408 .54795 Mdot
.19423 .42213 Mdot
.87517 .79357 Mdot
.27936 .47579 Mdot
.9451 .35481 Mdot
.34887 .36901 Mdot
.99924 .68373 Mdot
.92776 .15013 Mdot
.89425 .60514 Mdot
.32768 .46841 Mdot
.57428 .73921 Mdot
.10855 .26734 Mdot
.14967 .52319 Mdot
.48282 .3568 Mdot
.87059 .35889 Mdot
.94796 .38825 Mdot
.46768 .47651 Mdot
.98674 .50804 Mdot
.33263 .50401 Mdot
.59654 .97217 Mdot
.23211 .46513 Mdot
.8333 .01627 Mdot
.325 .35537 Mdot
.37813 .37537 Mdot
.17909 .54339 Mdot
.30645 .32434 Mdot
.04871 .51073 Mdot
.83856 .61915 Mdot
.13856 .29506 Mdot
.48016 .51794 Mdot
.158 .65324 Mdot
.43909 .99815 Mdot
.35462 .64636 Mdot
.05086 .29551 Mdot
.90626 .60286 Mdot
.9663 .59226 Mdot
.13701 .02125 Mdot
.40283 .74662 Mdot
.67685 .85047 Mdot
.82307 .56777 Mdot
.13143 .89975 Mdot
.94652 .51201 Mdot
.13056 .69747 Mdot
.90622 .07992 Mdot
.18659 .89687 Mdot
.31283 .4197 Mdot
.65606 .60813 Mdot
.78241 .19846 Mdot
.17166 .14938 Mdot
.19133 .29141 Mdot
.0398 .93288 Mdot
.61842 .3231 Mdot
.63862 .33107 Mdot
.48357 .05097 Mdot
.99732 .96131 Mdot
.87114 .52704 Mdot
.33422 .96824 Mdot
.20358 .86073 Mdot
.93619 .98943 Mdot
.57305 .99506 Mdot
.21929 .21612 Mdot
.15546 .34626 Mdot
.41781 .69874 Mdot
.93843 .65655 Mdot
.22622 .98104 Mdot
.25709 .9871 Mdot
.88362 .13261 Mdot
.4561 .9629 Mdot
.17753 .08994 Mdot
.08992 .35096 Mdot
.82444 .61539 Mdot
.86786 .05046 Mdot
.00533 .98028 Mdot
.14241 .90448 Mdot
.06863 .39614 Mdot
.89111 .82744 Mdot
.38491 .98313 Mdot
.40386 .61292 Mdot
.126 .02345 Mdot
.09517 .3546 Mdot
.3022 .63503 Mdot
.69177 .18101 Mdot
.85095 .54533 Mdot
.28257 .12393 Mdot
.25406 .29478 Mdot
.70969 .22438 Mdot
.38708 .4345 Mdot
.31759 .74112 Mdot
.34198 .8392 Mdot
.66096 .60643 Mdot
.05364 .082 Mdot
.88111 .9346 Mdot
.0803 .78941 Mdot
.71956 .19145 Mdot
.76566 .65849 Mdot
.88373 .62386 Mdot
.88848 .855 Mdot
.78318 .82799 Mdot
.84393 .8466 Mdot
.01685 .26834 Mdot
.74686 .82485 Mdot
.8895 .95844 Mdot
.241 .15588 Mdot
.43024 .70277 Mdot
.44985 .17279 Mdot
.31581 .9779 Mdot
.30268 .87606 Mdot
.47284 .86105 Mdot
.07128 .83184 Mdot
.3102 .50016 Mdot
.39297 .37071 Mdot
.79649 .57329 Mdot
.41759 .02299 Mdot
.62131 .04921 Mdot
.39584 .22469 Mdot
.82893 .72664 Mdot
.29073 .62221 Mdot
.11388 .46011 Mdot
.41125 .00928 Mdot
.95544 .14841 Mdot
.11738 .58105 Mdot
.25166 .27609 Mdot
.01672 .99436 Mdot
.67276 .22529 Mdot
.42709 .25018 Mdot
.52036 .86639 Mdot
.22 .46433 Mdot
.39241 .5159 Mdot
.51291 .45228 Mdot
.35171 .61178 Mdot
.4208 .03846 Mdot
.88006 .93489 Mdot
.15916 .80104 Mdot
.08433 .47582 Mdot
.49823 .24044 Mdot
.01872 .75748 Mdot
.78461 .47469 Mdot
.86329 .52963 Mdot
.13359 .59232 Mdot
.39386 .3804 Mdot
.76548 .53397 Mdot
.23701 .48746 Mdot
.79333 .24624 Mdot
.81271 .81532 Mdot
.24309 .87157 Mdot
.21518 .04635 Mdot
.99457 .94758 Mdot
.91496 .76333 Mdot
.71541 .97832 Mdot
.53147 .95951 Mdot
.25282 .86974 Mdot
.75613 .02909 Mdot
.88901 .75716 Mdot
.08543 .04927 Mdot
.7753 .0909 Mdot
.30184 .54593 Mdot
.03256 .58948 Mdot
.60267 .16835 Mdot
.71852 .10666 Mdot
.96149 .98971 Mdot
.37117 .6453 Mdot
.01216 .35464 Mdot
.66489 .96722 Mdot
.83981 .10266 Mdot
.14262 .84658 Mdot
.36867 .74143 Mdot
.07613 .31888 Mdot
.30556 .61916 Mdot
.22418 .04249 Mdot
.3594 .84856 Mdot
.15296 .42718 Mdot
.95529 .33665 Mdot
.40813 .19142 Mdot
.45821 .35921 Mdot
.0927 .47376 Mdot
.93709 .90357 Mdot
.44486 .9886 Mdot
.97655 .56662 Mdot
.16821 .49927 Mdot
.05614 .80731 Mdot
.08726 .94266 Mdot
.26097 .49605 Mdot
.38216 .14892 Mdot
.82521 .61806 Mdot
.60031 .37694 Mdot
.09652 .75181 Mdot
.11772 .31946 Mdot
.15898 .3533 Mdot
.29708 .69976 Mdot
.75684 .29509 Mdot
.66046 .91425 Mdot
.25546 .00475 Mdot
.03055 .28833 Mdot
.60528 .10929 Mdot
.17977 .79966 Mdot
.39545 .85653 Mdot
.81651 .8006 Mdot
.81484 .85682 Mdot
.16201 .34973 Mdot
.23692 .02633 Mdot
.74655 .97353 Mdot
.1184 .27013 Mdot
.51375 .88092 Mdot
.09931 .80704 Mdot
.2659 .69769 Mdot
.14197 .04618 Mdot
.72472 .78189 Mdot
.46275 .64695 Mdot
.50528 .2013 Mdot
.04728 .2469 Mdot
.69038 .56206 Mdot
.47568 .99777 Mdot
.43126 .98809 Mdot
.13122 .27956 Mdot
.13752 .78045 Mdot
.11652 .88266 Mdot
.47423 .68351 Mdot
.39233 .25362 Mdot
.26565 .42657 Mdot
.56307 .93107 Mdot
.42863 .82114 Mdot
.95833 .00285 Mdot
.22088 .82208 Mdot
.06553 .63342 Mdot
.43789 .09967 Mdot
.56129 .9286 Mdot
.44327 .64056 Mdot
.23176 .43578 Mdot
.59308 .54057 Mdot
.10759 .67672 Mdot
.8287 .65929 Mdot
.18843 .29051 Mdot
.0831 .28868 Mdot
.7971 .91771 Mdot
.30342 .98594 Mdot
.00992 .69871 Mdot
.58011 .64727 Mdot
.00864 .15076 Mdot
.58172 .47691 Mdot
.36021 .92947 Mdot
.46395 .49885 Mdot
.50207 .62444 Mdot
.14943 .46123 Mdot
.90494 .60246 Mdot
.51709 .65365 Mdot
.81067 .70718 Mdot
.402 .18463 Mdot
.89873 .4151 Mdot
.57564 .02596 Mdot
.59302 .78031 Mdot
.50663 .19847 Mdot
.77017 .52767 Mdot
.2061 .23383 Mdot
.8177 .43206 Mdot
.86716 .33787 Mdot
.3651 .05623 Mdot
.75456 .12118 Mdot
.29553 .78812 Mdot
.60672 .58011 Mdot
.77824 .88575 Mdot
.57876 .09943 Mdot
.8972 .5188 Mdot
.68223 .22465 Mdot
.53496 .67856 Mdot
.89137 .76432 Mdot
.32556 .91475 Mdot
.82071 .86045 Mdot
.20306 .0341 Mdot
.43482 .2031 Mdot
.23097 .81035 Mdot
.46662 .34413 Mdot
.815 .41262 Mdot
.0852 .88387 Mdot
.32162 .3726 Mdot
.08462 .06109 Mdot
.45056 .0939 Mdot
.41606 .70693 Mdot
.78978 .03801 Mdot
.3985 .50829 Mdot
.86769 .27627 Mdot
.49942 .64273 Mdot
.32937 .98879 Mdot
.75361 .91183 Mdot
.56197 .12868 Mdot
.90064 .64315 Mdot
.75711 .21389 Mdot
.31429 .8082 Mdot
.88449 .51818 Mdot
.42866 .55209 Mdot
.29737 .13516 Mdot
.31842 .86396 Mdot
.26452 .39575 Mdot
.38283 .53665 Mdot
.44623 .84779 Mdot
.13347 .29557 Mdot
.03978 .26271 Mdot
.93238 .25913 Mdot
.78396 .38196 Mdot
.80675 .81829 Mdot
.53581 .23537 Mdot
.16031 .54575 Mdot
.74871 .78464 Mdot
.32473 .38959 Mdot
.26731 .82958 Mdot
.21564 .30326 Mdot
.19502 .55939 Mdot
.51587 .48301 Mdot
.67995 .71595 Mdot
.24228 .72355 Mdot
.32208 .79724 Mdot
.00408 .50764 Mdot
.23632 .92672 Mdot
.161 .26152 Mdot
.01297 .77905 Mdot
.09486 .40066 Mdot
.41719 .68138 Mdot
.64412 .5141 Mdot
.48863 .49537 Mdot
.31726 .25809 Mdot
.28061 .39137 Mdot
.68152 .92808 Mdot
.63585 .06034 Mdot
.55934 .07119 Mdot
.86609 .31916 Mdot
.79983 .42716 Mdot
.50504 .07373 Mdot
.29933 .42822 Mdot
.59601 .92285 Mdot
.12185 .79774 Mdot
.67125 .7525 Mdot
.99854 .9202 Mdot
.78975 .76523 Mdot
.91264 .2335 Mdot
.77257 .27247 Mdot
.87746 .56885 Mdot
.37775 .1401 Mdot
.36048 .83358 Mdot
.44849 .52673 Mdot
.67409 .78771 Mdot
.26062 .24773 Mdot
.11203 .65188 Mdot
.20295 .72552 Mdot
.23241 .33389 Mdot
.04662 .63004 Mdot
.9316 .71117 Mdot
.47433 .92654 Mdot
.55745 .38745 Mdot
.73526 .84051 Mdot
.50108 .88081 Mdot
.39399 .89448 Mdot
.36781 .76737 Mdot
.90498 .10716 Mdot
.8755 .47304 Mdot
.99554 .47401 Mdot
.80046 .58566 Mdot
.58774 .43369 Mdot
.66352 .34392 Mdot
.57728 .09597 Mdot
.46647 .379 Mdot
.50378 .85016 Mdot
.31147 .90131 Mdot
.19437 .36199 Mdot
.56114 .944 Mdot
.91205 .76971 Mdot
.13404 .85751 Mdot
.60149 .94844 Mdot
.38705 .97899 Mdot
.27693 .93358 Mdot
.45313 .21478 Mdot
.27752 .06141 Mdot
.48573 .20095 Mdot
.34341 .11657 Mdot
.75385 .81172 Mdot
.68697 .92356 Mdot
.88014 .41403 Mdot
.17943 .79864 Mdot
.21627 .85339 Mdot
.17922 .25608 Mdot
.30201 .61624 Mdot
.36196 .71252 Mdot
.97844 .86807 Mdot
.31417 .98163 Mdot
.06202 .35463 Mdot
.58696 .70311 Mdot
.70525 .07586 Mdot
.52317 .00656 Mdot
.21013 .22411 Mdot
.73644 .14125 Mdot
.59831 .76143 Mdot
.08292 .30025 Mdot
.93042 .89541 Mdot
.30517 .97572 Mdot
.41408 .31032 Mdot
.29512 .34847 Mdot
.88618 .61206 Mdot
.21615 .38753 Mdot
.75106 .87175 Mdot
.28545 .91816 Mdot
.06134 .97352 Mdot
.30543 .31953 Mdot
.92474 .73447 Mdot
.42107 .56762 Mdot
.62191 .56511 Mdot
.71575 .15403 Mdot
.71382 .70519 Mdot
.60638 .17683 Mdot
.44527 .78224 Mdot
.16553 .40017 Mdot
.11445 .31651 Mdot
.89268 .97722 Mdot
.51648 .72745 Mdot
.30112 .16959 Mdot
.98739 .30818 Mdot
.24569 .11051 Mdot
.05015 .2354 Mdot
.98459 .35403 Mdot
.84 .85316 Mdot
.78425 .72444 Mdot
.09179 .77797 Mdot
.57928 .97234 Mdot
.39915 .89741 Mdot
.99946 .2691 Mdot
.55145 .82041 Mdot
.02786 .80441 Mdot
.78847 .78061 Mdot
.38324 .29194 Mdot
.22991 .30183 Mdot
.07192 .34361 Mdot
.97248 .80926 Mdot
.70301 .03482 Mdot
.42754 .69829 Mdot
.70892 .74011 Mdot
.09629 .29588 Mdot
.04607 .95183 Mdot
.02653 .19794 Mdot
.42998 .58214 Mdot
3e-05 .88321 Mdot
.5128 .82726 Mdot
.92433 .15905 Mdot
.97213 .28631 Mdot
.59177 .83538 Mdot
.02259 .76412 Mdot
.94572 .89367 Mdot
.84653 .31733 Mdot
.26211 .91462 Mdot
.22348 .91003 Mdot
.78869 .29788 Mdot
.23952 .75443 Mdot
.49745 .82542 Mdot
.04976 .3531 Mdot
.7955 .26962 Mdot
.39572 .84764 Mdot
.6055 .90572 Mdot
.17594 .71002 Mdot
.91785 .74989 Mdot
.8246 .78246 Mdot
.37205 .23052 Mdot
.24025 .17681 Mdot
.21614 .39322 Mdot
.48836 .86405 Mdot
.30079 .90511 Mdot
.7197 .94008 Mdot
.70024 .94405 Mdot
.76338 .50111 Mdot
.65218 .54649 Mdot
.14558 .55037 Mdot
.04163 .3283 Mdot
.99337 .0688 Mdot
.37896 .6243 Mdot
.46957 .63705 Mdot
.96644 .81076 Mdot
.51954 .63268 Mdot
.18918 .4381 Mdot
.2162 .06383 Mdot
.18221 .95081 Mdot
.22588 .19213 Mdot
.8875 .79652 Mdot
.34426 .13997 Mdot
.29011 .86793 Mdot
.89273 .36964 Mdot
.39186 .78392 Mdot
.09828 .21334 Mdot
.82846 .50435 Mdot
.10207 .37114 Mdot
.10894 .87539 Mdot
.32895 .62237 Mdot
.39343 .55823 Mdot
.98671 .66976 Mdot
.95406 .24589 Mdot
.3175 .20366 Mdot
.19192 .61073 Mdot
.78681 .18737 Mdot
.11336 .3329 Mdot
.32712 .48621 Mdot
.77631 .01614 Mdot
.44982 .08531 Mdot
.05523 .9007 Mdot
.50172 .07994 Mdot
.34066 .71101 Mdot
.83481 .60086 Mdot
.93706 .35832 Mdot
.13934 .26328 Mdot
.25347 .14157 Mdot
.00811 .22397 Mdot
.43221 .57851 Mdot
.14173 .19415 Mdot
.32563 .84809 Mdot
.37097 .84178 Mdot
.50517 .71228 Mdot
.14942 .33962 Mdot
.6738 .23441 Mdot
.9876 .16227 Mdot
.23235 .38134 Mdot
.18731 .47286 Mdot
.27544 .68072 Mdot
.77955 .54492 Mdot
.3514 .52826 Mdot
.02317 .68223 Mdot
.61675 .12979 Mdot
.14516 .72785 Mdot
.78265 .02096 Mdot
.50562 .67733 Mdot
.4562 .50883 Mdot
.10027 .29857 Mdot
.77782 .57446 Mdot
.77545 .28494 Mdot
.96792 .59204 Mdot
.57555 .33912 Mdot
.28251 .46652 Mdot
.89544 .00814 Mdot
.72963 .82681 Mdot
.86313 .77186 Mdot
.70908 .09354 Mdot
.17654 .55011 Mdot
.62465 .28388 Mdot
.36238 .73851 Mdot
.38067 .00392 Mdot
.20264 .93681 Mdot
.04289 .15393 Mdot
.26361 .2655 Mdot
.3599 .00599 Mdot
.80155 .76024 Mdot
.84356 .02716 Mdot
.3654 .62436 Mdot
.67499 .26802 Mdot
.67339 .55327 Mdot
.30894 .43488 Mdot
.92444 .20551 Mdot
.74743 .86246 Mdot
.38253 .88063 Mdot
.34284 .07098 Mdot
.61061 .20477 Mdot
.71373 .28406 Mdot
.03552 .03259 Mdot
.42229 .11564 Mdot
.45469 .84144 Mdot
.20345 .14695 Mdot
.16465 .11976 Mdot
.15595 .4695 Mdot
.49975 .23953 Mdot
.03837 .95283 Mdot
.82399 .68282 Mdot
.08204 .35362 Mdot
.76772 .0047 Mdot
.87131 .56804 Mdot
.11275 .80254 Mdot
.23828 .11466 Mdot
.27669 .17222 Mdot
.37756 .27055 Mdot
.74929 .89084 Mdot
.91188 .26621 Mdot
.6429 .21303 Mdot
.35555 .55768 Mdot
.16305 .75738 Mdot
.68779 .79826 Mdot
.07041 .2332 Mdot
.23626 .71044 Mdot
.37251 .04113 Mdot
.49979 .1255 Mdot
.56723 .15533 Mdot
.70108 .25058 Mdot
.29325 .57448 Mdot
.68268 .62343 Mdot
.3966 .11152 Mdot
.76236 .27996 Mdot
.44503 .80076 Mdot
.33336 .9518 Mdot
.00326 .0154 Mdot
.45223 .97876 Mdot
.24735 .59871 Mdot
.47183 .29331 Mdot
.28921 .86355 Mdot
.34862 .57769 Mdot
.65808 .62092 Mdot
.32536 .75936 Mdot
.00602 .29521 Mdot
.1509 .98801 Mdot
.73963 .12057 Mdot
.1719 .26087 Mdot
.4384 .55472 Mdot
.09859 .00316 Mdot
.23498 .5557 Mdot
.12482 .04594 Mdot
.88222 .06521 Mdot
.34485 .71851 Mdot
.48469 .85568 Mdot
.62743 .58587 Mdot
.07643 .15512 Mdot
.12669 .32356 Mdot
.87986 .50861 Mdot
.53283 .51248 Mdot
.07593 .40847 Mdot
.7931 .95586 Mdot
.76722 .41647 Mdot
.25983 .84237 Mdot
.70763 .66933 Mdot
.20181 .58756 Mdot
.86859 .48412 Mdot
.14652 .47073 Mdot
.37635 .14969 Mdot
.25317 .82811 Mdot
.11622 .1007 Mdot
.33392 .71487 Mdot
.87006 .29461 Mdot
.26673 .13494 Mdot
.24988 .41264 Mdot
.50156 .09495 Mdot
.94628 .06915 Mdot
.79609 .80987 Mdot
.75864 .8776 Mdot
.25271 .14524 Mdot
.8503 .30496 Mdot
.1537 .75638 Mdot
.31948 .88439 Mdot
.48017 .67576 Mdot
.94638 .08564 Mdot
.67168 .88628 Mdot
.45773 .10594 Mdot
.83326 .60408 Mdot
.73801 .58287 Mdot
.55571 .09828 Mdot
.78671 .76644 Mdot
.77472 .3901 Mdot
.1653 .89008 Mdot
.84297 .94635 Mdot
.33461 .59372 Mdot
.11532 .08406 Mdot
.92351 .12613 Mdot
.92234 .47156 Mdot
.14182 .64751 Mdot
.61798 .50863 Mdot
.61536 .48714 Mdot
.62331 .042 Mdot
.47304 .15223 Mdot
.29003 .0696 Mdot
.9333 .81416 Mdot
.90494 .58961 Mdot
.78242 .60797 Mdot
.531 .00437 Mdot
.66736 .776 Mdot
.1114 .1216 Mdot
.99131 .86753 Mdot
.99501 .13075 Mdot
.0461 .69526 Mdot
.98597 .47997 Mdot
.11057 .9692 Mdot
.00797 .90327 Mdot
.79741 .65382 Mdot
.41389 .14259 Mdot
.15017 .66937 Mdot
.28913 .66849 Mdot
.17768 .35651 Mdot
.88355 .04495 Mdot
.3077 .86048 Mdot
.39733 .3904 Mdot
.06032 .8847 Mdot
.87702 .62969 Mdot
.36952 .31914 Mdot
.44443 .91273 Mdot
.13012 .10858 Mdot
.4868 .60884 Mdot
.26852 .8106 Mdot
.31206 .52242 Mdot
.71438 .87657 Mdot
.01732 .84098 Mdot
.92371 .18002 Mdot
.24143 .76046 Mdot
.53237 .148 Mdot
.9267 .85091 Mdot
.76131 .35347 Mdot
.08561 .30231 Mdot
.38575 .8576 Mdot
.15741 .31844 Mdot
.36256 .49762 Mdot
.05064 .30265 Mdot
.08903 .12873 Mdot
.32702 .76283 Mdot
.74949 .57027 Mdot
.72723 .14458 Mdot
.69638 .7027 Mdot
.32521 .74348 Mdot
.18677 .97782 Mdot
.09429 .95027 Mdot
.29047 .79329 Mdot
.48662 .93438 Mdot
.61208 .71378 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03?ooool2o`0000oooooo00?o0000ooooooooool03_ooool3o`0000go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oo
oooo0_l00005ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`07ooooo`;o00001?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00Co0000ooooool0003o00003Oooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00cooooo0_l0000?ooooo`03o`000?oooooooooo00_o
oooo0_l000001?oooooo0000o`000?l0000=ooooo`?o00003Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00;o00001Oooool2o`0000Gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo0_l000000ooooooo0000o`000004oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool2o`0000[ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00Co0000oooo
ool0003o00003Oooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003oooooooooo`0koooo
o`;o00004_ooool2o`00023ooooo0_l0000?ooooo`;o00008_ooool2o`0004gooooo0_l0000Xoooo
o`;o00009_ooool001kooooo00?o0000ooooooooool0P_ooool2o`0000;ooooo0_l0002Gooooo`;o
00009_ooool001kooooo0_l00009ooooo`;o0000O?ooool2o`00073ooooo0_l0000Aooooo`;o0000
>_ooool001kooooo0_l00009ooooo`;o0000Q_ooool2o`0006Kooooo0_l0000Aooooo`;o0000>_oo
ool001kooooo00?o0000ooooooooool0:?ooool2o`0006Kooooo0_l0001Xooooo`;o0000Boooool0
01kooooo00?o0000ooooooooool09Oooool2o`000003ooooool0003o000005[ooooo0_l0000aoooo
o`;o0000@Oooool2o`0004_ooooo000Nooooo`03o`000?oooooooooo02Gooooo0_l0000Rooooo`;o
0000>Oooool2o`00037ooooo0_l0000iooooo`;o00006_ooool2o`0003Oooooo000Nooooo`03o`00
0?oooooooooo04Wooooo0_l0002Wooooo`;o00001Oooool2o`0001?ooooo0_l0000gooooo`007_oo
ool00ol0003oooooooooo`07ooooo`;o0000=Oooool2o`000:3ooooo0_l0000Gooooo`;o0000C?oo
ool001kooooo00?o0000ooooooooool01oooool2o`0003Gooooo0_l0001Fooooo`;o0000B?ooool2
o`0001_ooooo0_l00018ooooo`007_ooool00ol0003oooooooooo`1eooooo`;o00003_ooool2o`00
00oooooo0_l0001Uooooo`;o0000B?ooool001kooooo00?o0000ooooooooool0AOooool2o`0002ko
oooo0_l0000>ooooo`;o00005?ooool2o`0002[ooooo0_l0001nooooo`007_ooool00ol0003ooooo
ooooo`04ooooo`;o00007_ooool2o`0000Cooooo0_l0000Fooooo`;o000000?oooooo`000?l00000
E?ooool2o`0002[ooooo0_l0001Booooo`;o0000:_ooool001kooooo00?o0000ooooooooool01?oo
ool2o`0001;ooooo0_l0000:ooooo`;o00001?ooool2o`0001Kooooo0_l0000Sooooo`;o0000GOoo
ool2o`0004kooooo0_l00003ooooo`;o0000:_ooool001kooooo0_l0000Iooooo`;o0000COooool2
o`00033ooooo0_l0000[ooooo`;o00003_ooool2o`0003kooooo0_l00002ooooo`;o0000:oooool0
01kooooo00?o0000ooooooooool0Loooool2o`0002Cooooo0_l0000kooooo`;o0000@_ooool2o`00
02_ooooo000Nooooo`03o`000?oooooooooo04[ooooo0_l0000Wooooo`;o0000d_ooool001kooooo
00?o0000ooooooooool05oooool2o`00037ooooo0_l0000:ooooo`;o0000HOooool2o`00013ooooo
0_l0001jooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o0000:Oooool2o`0001;ooooo0_l0
001Qooooo`;o00004?ooool2o`0004kooooo0_l0000Zooooo`007_ooool00ol0003oooooooooo`12
ooooo`;o0000?_ooool2o`0009Oooooo0_l0000Rooooo`;o00001_ooool001kooooo00?o0000oooo
ooooool0F_ooool2o`0000oooooo0_l0000Eooooo`;o0000;_ooool2o`0007cooooo0_l0000=oooo
o`;o00001_ooool001kooooo00?o0000ooooooooool0F_ooool2o`0000oooooo0_l0000cooooo`;o
00004?ooool2o`0007cooooo0_l0000Eooooo`007_ooool00ol0003oooooooooo`2Pooooo`;o0000
?oooool2o`0004gooooo0_l0000Eooooo`007_ooool00ol0003oooooooooo`2Aooooo`;o00003?oo
ool2o`00043ooooo0_l00010ooooo`;o00002oooool2o`0001Gooooo000Nooooo`03o`000?oooooo
oooo00gooooo0_l0000Booooo`;o0000K_ooool2o`0000cooooo0_l0000Wooooo`;o0000FOooool2
o`0002;ooooo000Nooooo`03o`000?oooooooooo00gooooo0_l0000Booooo`;o0000Joooool2o`00
03Sooooo0_l0001Vooooo`;o00005Oooool001kooooo00?o0000ooooooooool0=_ooool2o`0004co
oooo0_l00008ooooo`;o0000Eoooool2o`0004Oooooo0_l0000Eooooo`007_ooool00ol0003ooooo
ooooo`0fooooo`;o0000C?ooool2o`0005cooooo0_l00003ooooo`;o00003oooool2o`0004gooooo
000Nooooo`03o`000?oooooooooo00Wooooo0_l00023ooooo`;o00003oooool2o`0001Oooooo0_l0
000Xooooo`;o00005?ooool2o`0004gooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0001o
ooooo`;o00000_ooool2o`0000oooooo0_l0000@ooooo`;o00001Oooool2o`0008gooooo000Noooo
o`;o00008oooool2o`0006Kooooo0_l0000Uooooo`;o00001Oooool2o`0005?ooooo0_l0000hoooo
o`007_ooool00ol0003oooooooooo`0Rooooo`;o0000KOooool2o`0007[ooooo0_l0000hooooo`00
7_ooool00ol0003oooooooooo`0Rooooo`;o00000_ooool2o`0006Wooooo0_l0001Booooo`;o0000
;_ooool2o`0000_ooooo0_l0000Sooooo`007_ooool00ol0003oooooooooo`0Vooooo`;o00002ooo
ool2o`0001Oooooo0_l0000_ooooo`;o0000@Oooool3o`0002;ooooo0_l0000^ooooo`;o00002ooo
ool2o`0002?ooooo000Nooooo`03o`000?oooooooooo03?ooooo0_l0000Dooooo`;o000000?ooooo
o`000?l00000;oooool2o`00047ooooo0ol00024ooooo`007_ooool00ol0003oooooooooo`19oooo
o`;o00007Oooool2o`0000;ooooo0_l0000Gooooo`;o0000`?ooool001kooooo00?o0000oooooooo
ool05Oooool2o`0001[ooooo0_l0000eooooo`;o00000_ooool2o`0001Oooooo0_l0001Uooooo`;o
00000oooool2o`0005Cooooo000Nooooo`03o`000?oooooooooo01Gooooo0_l00009ooooo`;o0000
3oooool2o`0002Gooooo0_l00005ooooo`;o0000Roooool2o`0000?ooooo0_l0001Dooooo`007_oo
ool00ol0003oooooooooo`0Pooooo`;o0000=_ooool2o`0000Gooooo0_l0000mooooo`;o0000R?oo
ool2o`0001gooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l00023ooooo`;o00004oooool2
o`0000oooooo0_l0001Rooooo`;o00007Oooool001kooooo00?o0000ooooooooool03oooool2o`00
00Sooooo0_l0000=ooooo`;o0000ROooool2o`0000oooooo0_l0001Eooooo`;o00008_ooool2o`00
00Kooooo000Nooooo`03o`000?oooooooooo00oooooo0_l0000Gooooo`;o0000:Oooool2o`0000So
oooo0_l0002looooo`;o00008_ooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo05?ooooo
0_l00008ooooo`;o0000f?ooool2o`0000kooooo000Nooooo`03o`000?oooooooooo04kooooo0_l0
000Looooo`;o00000_ooool2o`0000Gooooo0_l00009ooooo`;o0000Ioooool2o`0004[ooooo0_l0
000>ooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o0000?oooool2o`0001cooooo0_l00002
ooooo`;o00001Oooool2o`0000Wooooo0_l00008ooooo`;o0000Coooool2o`0000Wooooo0_l00000
0ooooooo0000o`00001Jooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o0000;oooool2o`00
00kooooo0_l0000Aooooo`;o00005Oooool2o`0001;ooooo0_l0000Kooooo`;o0000<_ooool2o`00
00Wooooo0_l00019ooooo`;o00004_ooool001kooooo1?l0000cooooo`;o00002?ooool2o`00027o
oooo0_l0000Cooooo`Co0000;oooool2o`0007oooooo0_l00007ooooo`;o00004_ooool001kooooo
00Co0000ooooool0003o00002Oooool2o`0000Wooooo0_l0000Mooooo`;o0000@?ooool2o`0000Go
oooo0_l0000Gooooo`;o0000COooool2o`0004?ooooo0_l0000Kooooo`007_ooool00ol0003ooooo
ooooo`0:ooooo`;o00002Oooool2o`0003?ooooo0_l0000aooooo`;o00005oooool2o`0001cooooo
0_l0000_ooooo`;o0000H?ooool001kooooo00?o0000ooooooooool04oooool2o`0003Gooooo0_l0
001Xooooo`;o0000L_ooool2o`0001gooooo000Nooooo`03o`000?oooooooooo01?ooooo0_l0003o
oooooaCooooo0_l0000Cooooo`;o00002?ooool001kooooo00?o0000ooooooooool0B_ooool2o`00
01Oooooo0_l0002looooo`;o00006_ooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo04[o
oooo0_l0000Booooo`;o00000oooool2o`0005_ooooo0_l0000mooooo`;o00008?ooool2o`0002Co
oooo000Nooooo`03o`000?oooooooooo01kooooo0_l0000fooooo`;o00001_ooool2o`0002kooooo
0_l0000<ooooo`;o00008_ooool2o`0003gooooo0_l00016ooooo`007_ooool00ol0003ooooooooo
o`0Nooooo`;o0000=_ooool2o`0003Kooooo0_l0000<ooooo`;o0000ZOooool001kooooo00?o0000
ooooooooool0B_ooool2o`0004Oooooo0_l0000/ooooo`;o00003?ooool2o`0007Kooooo000Noooo
o`03o`000?oooooooooo02Gooooo0_l0000Sooooo`;o0000Aoooool2o`0002cooooo0_l0000<oooo
o`;o00003?ooool2o`0000;ooooo0_l00015ooooo`;o00007Oooool001kooooo00?o0000oooooooo
ool09Oooool2o`0001Wooooo0_l0000mooooo`;o0000G?ooool2o`0000;ooooo0ol00014ooooo`;o
00007Oooool001kooooo00?o0000ooooooooool0@?ooool2o`0003gooooo0_l0001Qooooo`;o0000
6?ooool2o`0004Wooooo000Nooooo`03o`000?oooooooooo04Gooooo0_l0000jooooo`;o0000Hooo
ool2o`0001Cooooo0_l00019ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`Go00001_ooool00ol0003oooooooooo`0Zooooo`;o00006Oooool2o`0003[ooooo0_l0
001Sooooo`;o00003oooool2o`0004kooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo00Gooooo
0_l0000Sooooo`;o0000boooool2o`0004kooooo0003ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00onHV9So8B4Qonk^kP07ooooo`?o00001Oooool2o`0009?ooooo0_l00004ooooo`?o0000
<?ooool2o`0002Gooooo0_l0001;ooooo`000oooool01Ol0003ooooooooooooooooo000000gooooo
00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`1Sooooo`;o00009?ooool2o`0000oooooo
0_l00004ooooo`?o0000<?ooool2o`0002Gooooo0_l0000Dooooo`;o0000=Oooool000?ooooo00Go
0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0
1?ooool2o`0005gooooo0_l0000Tooooo`;o0000=oooool2o`0001cooooo0_l0000^ooooo`;o0000
5_ooool2o`0001gooooo0003ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo0_l0001?ooooo`;o0000Joooool2o`0001cooooo
0_l00016ooooo`;o00007Oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`08ooooo`;o00004_ooool2o`0003Oo
oooo0_l0001Mooooo`;o00005oooool2o`0005Wooooo0_l0000Mooooo`000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo
00Sooooo0_l0000Booooo`;o00009Oooool2o`0004[ooooo0_l0000Sooooo`;o00005oooool2o`00
02?ooooo0_l0000dooooo`;o00007Oooool001kooooo00?o0000ooooooooool0@oooool2o`0002oo
oooo0_l0000Iooooo`;o0000HOooool2o`0005?ooooo000Nooooo`03o`000?oooooooooo02[ooooo
0_l00018ooooo`;o0000dOooool001kooooo00Co0000ooooool0003o00003Oooool2o`0001[ooooo
0_l0000Dooooo`;o0000>oooool2o`0000kooooo0_l00018ooooo`;o000000?oooooo`000?l00000
1oooool2o`0006;ooooo000Nooooo`04o`000?oooooo0000o`0000gooooo0_l0000`ooooo`;o0000
>oooool2o`0000kooooo0_l00018ooooo`;o000000?oooooo`000?l000001oooool2o`0006;ooooo
000Nooooo`03o`000?oooooooooo07Gooooo0_l00022ooooo`;o0000C?ooool001kooooo00?o0000
ooooooooool04Oooool4o`0002[ooooo0_l0000dooooo`;o00006_ooool2o`0001Oooooo0_l0000O
ooooo`;o00002_ooool2o`00023ooooo0_l0000Zooooo`;o00008?ooool001kooooo00?o0000oooo
ooooool03?ooool2o`0000?ooooo1?l0000Zooooo`;o0000D?ooool2o`0001Oooooo0_l0000Ooooo
o`;o00002_ooool2o`0004cooooo0_l0000Pooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o
0000T?ooool2o`0000[ooooo0_l0002Kooooo`007_ooool00ol0003oooooooooo`2Nooooo`;o0000
JOooool2o`0003cooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l0001/ooooo`;o0000Pooo
ool2o`0000Wooooo0_l0000Wooooo`;o00004oooool001kooooo00?o0000ooooooooool02oooool2
o`0004Cooooo0_l0000Vooooo`;o00003?ooool2o`0007Gooooo0_l0000booooo`;o00004oooool0
01kooooo0_l0001Booooo`;o0000:?ooool2o`0000[ooooo0_l0001Gooooo`;o0000IOooool001ko
oooo00?o0000ooooooooool0=_ooool2o`0004?ooooo0_l0001Sooooo`;o0000G_ooool2o`0000Go
oooo000Nooooo`03o`000?oooooooooo03Kooooo0_l0000[ooooo`;o0000a_ooool2o`0001?ooooo
0_l00005ooooo`007_ooool00ol0003oooooooooo`09ooooo`;o00001_ooool2o`0001gooooo0_l0
0002ooooo`;o0000;Oooool2o`000<Kooooo0_l0000Jooooo`007_ooool00ol0003oooooooooo`09
ooooo`;o00001_ooool2o`0001Kooooo0_l00005ooooo`;o00000_ooool2o`0001cooooo0_l0000X
ooooo`;o00004?ooool2o`0004_ooooo0_l0001Zooooo`007_ooool01?l0003oooooooooooooool2
o`0001cooooo0_l00008ooooo`;o00009oooool2o`0002Sooooo0_l0000@ooooo`;o0000Aoooool2
o`0000;ooooo0_l00017ooooo`;o00008Oooool001kooooo00Co0000oooooooooooooooo0_l0000L
ooooo`;o000000?oooooo`000?l00000Doooool2o`0005kooooo0_l0000Vooooo`;o00008oooool2
o`0001_ooooo0_l00004ooooo`007_ooool00ol0003oooooooooo`0Rooooo`;o0000Doooool2o`00
07kooooo0_l00006ooooo`;o0000@?ooool2o`0000Cooooo000Nooooo`03o`000?oooooooooo04ko
oooo0_l0002Wooooo`;o00007Oooool2o`0002oooooo000Nooooo`03o`000?oooooooooo02Oooooo
0_l0000Uooooo`;o00006oooool2o`0008Oooooo0_l0000Pooooo`;o0000;oooool001kooooo00?o
0000ooooooooool09oooool2o`0004;ooooo0_l0000Kooooo`;o0000?Oooool2o`0001_ooooo0_l0
000>ooooo`;o0000AOooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo08Sooooo0_l0000m
ooooo`;o00006oooool2o`0001;ooooo0_l0000nooooo`;o000000?oooooo`000?l000002_ooool0
01kooooo00?o0000ooooooooool01_ooool2o`0000oooooo0_l0000Pooooo`;o0000_Oooool2o`00
03kooooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`04ooooo`Co00003oooool2o`00023o
oooo0ol0000looooo`;o00006oooool2o`000;3ooooo000Nooooo`?o00001?ooool2o`0000Kooooo
0_l0000=ooooo`;o00002_ooool4o`0000oooooo0_l0000Booooo`;o0000:?ooool2o`0001_ooooo
0_l0001Kooooo`;o00008oooool2o`0002kooooo000Nooooo`?o00003?ooool2o`0000gooooo0ol0
0009ooooo`Co00008oooool2o`000:;ooooo0_l00008ooooo`;o00006Oooool2o`0002kooooo000N
ooooo`?o00003?ooool2o`0000Wooooo0ol00002ooooo`;o0000:Oooool2o`000;?ooooo0_l00019
ooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o00002Oooool3o`0002Sooooo0_l00003oooo
o`;o0000=_ooool2o`0007gooooo0_l0000@ooooo`;o0000=Oooool001kooooo00?o0000oooooooo
ool0@_ooool2o`0003_ooooo0_l0001mooooo`;o00004?ooool2o`0002_ooooo0_l00008ooooo`00
7_ooool00ol0003oooooooooo`23ooooo`;o00005oooool2o`0009oooooo0_l00008ooooo`007_oo
ool00ol0003oooooooooo`0:ooooo`;o0000Aoooool2o`0002kooooo0_l0000Gooooo`;o0000ZOoo
ool001kooooo00?o0000ooooooooool02_ooool2o`0001Gooooo0_l0000`ooooo`;o0000^_ooool2
o`0003Kooooo000Nooooo`03o`000?oooooooooo01Gooooo0_l0000:ooooo`?o00002oooool2o`00
02kooooo0_l0000Cooooo`;o0000VOooool2o`0000Cooooo0_l0000`ooooo`007_ooool00ol0003o
ooooooooo`0Eooooo`;o00002oooool2o`000003ooooool0003o000000Sooooo0_l0000^ooooo`?o
00004_ooool2o`0004oooooo0_l0001>ooooo`;o0000<?ooool001kooooo00?o0000ooooooooool0
9Oooool2o`0002_ooooo0_l0000<ooooo`;o0000Hoooool2o`00083ooooo000Nooooo`03o`000?oo
oooooooo00Wooooo0_l00017ooooo`;o0000loooool001kooooo00?o0000ooooooooool02Oooool2
o`0001Kooooo0_l0002Yooooo`;o0000NOooool001kooooo00?o0000ooooooooool08Oooool2o`00
02Cooooo0_l00023ooooo`;o0000I?ooool2o`0001?ooooo000Nooooo`03o`000?oooooooooo02co
oooo0_l0000Iooooo`;o0000K_ooool2o`0005gooooo0_l0000Jooooo`;o00004oooool001kooooo
00?o0000ooooooooool0;?ooool2o`0008Wooooo0_l0001Mooooo`;o0000;oooool001kooooo00?o
0000ooooooooool04oooool2o`0007oooooo0_l0000nooooo`;o0000LOooool001kooooo00?o0000
ooooooooool04oooool2o`0001Wooooo0_l0000/ooooo`;o0000=_ooool2o`0003kooooo0_l0001a
ooooo`007_ooool2o`0001[ooooo0_l0000Cooooo`;o000000?oooooo`000?l000008_ooool2o`00
00Gooooo0_l0000Iooooo`;o00000_ooool2o`000<[ooooo000Nooooo`03o`000?oooooooooo00;o
00002_ooool2o`0000;ooooo0_l00005ooooo`Ko00004oooool3o`0002;ooooo0_l0000Hooooo`;o
00001_ooool2o`0000;ooooo0_l0001fooooo`;o0000>_ooool2o`0000_ooooo0_l00009ooooo`00
7_ooool00ol0003oooooooooo`02o`0000[ooooo0_l00002ooooo`;o00001Oooool2o`0000;ooooo
0_l0000Cooooo`;o00001?ooool2o`0002kooooo0_l00007ooooo`;o0000:?ooool2o`0003Oooooo
0_l0000Oooooo`;o0000>_ooool2o`0000_ooooo0_l00009ooooo`007_ooool00ol0003ooooooooo
o`0fooooo`;o0000;_ooool2o`0002Wooooo0_l00006ooooo`;o0000=oooool2o`0004?ooooo0_l0
000Dooooo`;o00006?ooool001kooooo00?o0000ooooooooool0>oooool2o`0005;ooooo1?l00024
ooooo`;o00005?ooool2o`0001Sooooo000Nooooo`03o`000?oooooooooo03_ooooo0_l0001Boooo
o`;o0000]_ooool001kooooo00?o0000ooooooooool0KOooool2o`000:oooooo0_l0000Wooooo`00
7_ooool00ol0003oooooooooo`0Mooooo`;o0000??ooool2o`0000Oooooo0_l00007ooooo`;o0000
3Oooool2o`0003Kooooo0_l0001Xooooo`;o00002_ooool2o`0001_ooooo000Nooooo`03o`000?oo
oooooooo01gooooo0_l0000looooo`;o00001oooool2o`00017ooooo0_l00003ooooo`;o0000=_oo
ool2o`0003;ooooo0_l0000^ooooo`;o00004?ooool2o`0001_ooooo000Nooooo`03o`000?oooooo
oooo07Oooooo0_l0000Kooooo`;o00007Oooool2o`0000[ooooo0_l00009ooooo`;o00007?ooool2
o`0002kooooo0_l0000]ooooo`007_ooool00ol0003oooooooooo`0/ooooo`;o00006Oooool2o`00
03?ooooo0_l0000Fooooo`;o00007Oooool2o`0000[ooooo0_l00009ooooo`;o0000;oooool2o`00
04[ooooo000Nooooo`03o`000?oooooooooo023ooooo0_l0000:ooooo`;o00006Oooool2o`0003?o
oooo0_l0001mooooo`;o0000B_ooool001kooooo00?o0000ooooooooool08?ooool2o`0001?ooooo
0_l0000;ooooo`;o0000GOooool2o`0000kooooo0_l0001Jooooo`;o00008Oooool2o`0001Gooooo
000Nooooo`03o`000?oooooooooo00Oooooo0_l0000/ooooo`;o00002oooool2o`0001?ooooo0_l0
000<ooooo`;o00005_ooool2o`0002;ooooo0_l0000>ooooo`;o0000AOooool2o`0001?ooooo0_l0
000Qooooo`;o00005Oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool01oooool2o`0003Wooooo0_l0
000Cooooo`;o00003?ooool2o`0001Kooooo0_l0001iooooo`;o00008_ooool2o`0002Wooooo0003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Booooo`;o00001Oooool2o`0002Oooooo0_l0000>ooooo`;o00003Ooo
ool2o`0003Sooooo0_l0001oooooo`;o0000:Oooool000?ooooo00Go410@oooooooooooooooooa0@
400;ooooo`Go00001_ooool3o`0001;ooooo0_l00005ooooo`Co00005Oooool2o`0001kooooo0_l0
000=ooooo`;o00007Oooool2o`0001Wooooo0_l0002Zooooo`000oooool01Ol0003ooooooooooooo
oooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool00ol0003oooooooooo`0Kooooo`;o0000
5Oooool2o`0004cooooo0_l00035ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo
00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo00;o
oooo0_l00003ooooo`;o00003?ooool2o`000?oooooo<Oooool000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool00_ooool2o`0000?o
oooo0_l0000<ooooo`;o0000=_ooool2o`0009Oooooo0_l0000Mooooo`;o00003oooool2o`0002oo
oooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03
o`000?oooooooooo04Sooooo0_l00003ooooo`;o00006?ooool2o`0007gooooo0_l0000=ooooo`;o
00003_ooool2o`0000oooooo0_l00002ooooo`;o00001?ooool2o`0002Gooooo000Nooooo`03o`00
0?oooooooooo04Sooooo0_l0000Hooooo`;o00000_ooool3o`0008cooooo0_l0000Sooooo`;o0000
1?ooool2o`0001Oooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`04ooooo`;o0000=Ooo
ool2o`0002Gooooo0_l00002ooooo`;o0000dOooool2o`0000cooooo000Nooooo`03o`000?oooooo
oooo00Cooooo0_l0000eooooo`;o0000ooooool;ooooo`007_ooool00ol0003oooooooooo`0^oooo
o`;o00008_ooool2o`0000Wooooo0_l0002Qooooo`;o0000AOooool001kooooo00?o0000oooooooo
ool0;_ooool2o`0002;ooooo0_l00009ooooo`;o00007_ooool3o`00083ooooo0_l00015ooooo`00
7_ooool00ol0003oooooooooo`0<ooooo`;o0000D_ooool2o`0001Sooooo0_l000001?oooooo0000
o`000?l0000kooooo`;o0000BOooool2o`0003oooooo000Nooooo`03o`000?oooooooooo00cooooo
0_l0000[ooooo`;o00003?ooool2o`0001Oooooo0_l0000Hooooo`;o0000?oooool2o`0004Wooooo
0_l0000oooooo`007_ooool00ol0003oooooooooo`0eooooo`;o00000_ooool2o`0000cooooo0_l0
003nooooo`007_ooool00ol0003oooooooooo`0Tooooo`;o00003oooool2o`000?oooooo4Oooool0
01kooooo00?o0000ooooooooool05_ooool2o`0000cooooo0_l0003oooooob;ooooo000Nooooo`03
o`000?oooooooooo01Kooooo0_l0003ooooooc3ooooo000Nooooo`;o0000Y?ooool2o`000:;ooooo
000Nooooo`03o`000?oooooooooo07gooooo0_l0000Tooooo`;o0000X_ooool001kooooo00?o0000
ooooooooool0OOooool2o`0000_ooooo0_l0000Iooooo`;o0000X?ooool001kooooo00?o0000oooo
ooooool08Oooool2o`0000Wooooo0_l0001Looooo`;o00006Oooool2o`000:3ooooo000Nooooo`03
o`000?oooooooooo027ooooo0_l00009ooooo`;o00005Oooool2o`0000;ooooo0_l00030ooooo`;o
0000??ooool001kooooo00?o0000ooooooooool0@oooool2o`0000;ooooo0_l0000?ooooo`;o0000
3?ooool2o`00017ooooo0_l0002>ooooo`;o0000??ooool001kooooo00?o0000ooooooooool0;?oo
ool2o`000003ooooool0003o000002Oooooo0_l0000<ooooo`;o00004Oooool2o`000:gooooo0_l0
000Mooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o00004?ooool2o`000003ooooool0003o
000000Sooooo0_l00030ooooo`;o00007?ooool2o`0000gooooo0_l0000Fooooo`;o00001Oooool0
01kooooo00?o0000ooooooooool05oooool2o`000003ooooool0003o000001gooooo0_l0000Loooo
o`;o0000>oooool2o`0002?ooooo0_l00009ooooo`;o0000=Oooool2o`0001cooooo0_l0000Uoooo
o`;o00001Oooool001kooooo00?o0000ooooooooool05oooool2o`0003kooooo0_l0000kooooo`;o
00008oooool2o`0000Wooooo0_l0001fooooo`;o00002Oooool001kooooo00?o0000ooooooooool0
Y?ooool2o`00073ooooo0_l0000Tooooo`;o00002Oooool001kooooo00?o0000ooooooooool0I_oo
ool2o`0003cooooo0_l0000Nooooo`;o0000D?ooool2o`0002oooooo000Nooooo`03o`000?oooooo
oooo03;ooooo0_l0000Eooooo`;o00006oooool2o`0005cooooo0_l00021ooooo`007_ooool00ol0
003oooooooooo`0Dooooo`;o00007?ooool2o`0001Gooooo0_l0003Aooooo`;o0000:Oooool001ko
oooo00?o0000ooooooooool05?ooool2o`0000Gooooo0_l0000dooooo`;o0000B?ooool2o`0006oo
oooo0_l0000>ooooo`;o0000:Oooool001kooooo00?o0000ooooooooool06oooool2o`0001Kooooo
1?l0000Jooooo`;o00007oooool2o`0001oooooo0_l00006ooooo`;o0000Koooool2o`0003Wooooo
000Nooooo`;o0000=?ooool4o`0002[ooooo0_l0000?ooooo`;o00007oooool2o`0005oooooo0_l0
001Aooooo`007_ooool00ol0003oooooooooo`1:ooooo`;o00005Oooool2o`0000Gooooo0_l0001j
ooooo`;o00003_ooool2o`0001?ooooo0_l0000looooo`007_ooool2o`0004_ooooo0_l0000Loooo
o`;o00004oooool2o`0000cooooo0_l00003ooooo`;o0000<oooool2o`0001gooooo0_l0000Soooo
o`;o00003oooool2o`00027ooooo0_l00008ooooo`007_ooool2o`0000gooooo0_l0001_ooooo`;o
00003?ooool2o`0000?ooooo0_l0000[ooooo`;o00001_ooool2o`0005?ooooo0_l0000Dooooo`;o
00002oooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo00cooooo0_l0002Kooooo`;o0000
4_ooool2o`0000kooooo0_l0001Qooooo`;o00005Oooool001kooooo00?o0000ooooooooool0JOoo
ool2o`00013ooooo0_l0000Kooooo`;o00003oooool2o`0002;ooooo0_l0001hooooo`007_ooool0
0ol0003oooooooooo`1Yooooo`;o00004?ooool2o`0001_ooooo0_l00021ooooo`;o00000oooool2
o`0001[ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`0]ooooo`;o0000<_ooool2o`00
01Sooooo0_l0002Nooooo`;o00000oooool2o`0001[ooooo0_l00009ooooo`007_ooool00ol0003o
ooooooooo`0]ooooo`;o0000<_ooool2o`0001Sooooo0_l0000Aooooo`;o0000<?ooool2o`0001Co
oooo0_l0000oooooo`;o0000;_ooool001kooooo00?o0000ooooooooool0K_ooool2o`0001kooooo
0_l0000`ooooo`;o00005?ooool2o`0001kooooo0_l0000Mooooo`Co0000;_ooool001kooooo00?o
0000ooooooooool02oooool2o`0001;ooooo0_l0001=ooooo`;o0000Q_ooool2o`0001gooooo0_l0
000<ooooo`;o00000oooool2o`0001gooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l0000B
ooooo`;o0000e?ooool2o`0002cooooo0_l00003ooooo`;o00007Oooool001kooooo00?o0000oooo
ooooool0N?ooool2o`0007_ooooo0_l0000Looooo`;o0000<_ooool001kooooo00?o0000oooooooo
ool0N?ooool2o`0004?ooooo0_l0001Dooooo`;o0000<_ooool001kooooo00?o0000ooooooooool0
<?ooool2o`0000Cooooo0_l0000;ooooo`;o0000G?ooool2o`0001[ooooo0_l0000jooooo`;o0000
5_ooool2o`0003Cooooo000Nooooo`03o`000?oooooooooo01Gooooo0_l0000Iooooo`;o00001?oo
ool2o`0000_ooooo0_l0000Iooooo`;o0000@Oooool2o`0001[ooooo0_l0000Aooooo`;o00009ooo
ool2o`0001Kooooo0_l0000dooooo`007_ooool2o`0001Kooooo0_l0000Dooooo`;o00002?ooool2
o`00013ooooo0_l0000Eooooo`;o0000GOooool2o`00017ooooo0_l0001eooooo`007_ooool00ol0
003oooooooooo`0Oooooo`;o00002_ooool2o`0000Sooooo0_l0000@ooooo`;o0000?_ooool2o`00
0003ooooool0003o000004_ooooo0_l0001^ooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o
00009oooool2o`0000gooooo0_l0000Fooooo`;o00000oooool2o`00017ooooo0_l000000ooooooo
0000o`00001;ooooo`;o0000K_ooool001kooooo00?o0000ooooooooool0>oooool2o`0000_ooooo
0_l0000=ooooo`;o00005_ooool2o`0000?ooooo0_l00006ooooo`;o0000bOooool001kooooo00?o
0000ooooooooool0>oooool2o`0003oooooo0_l0001Nooooo`;o0000JOooool001kooooo00?o0000
ooooooooool0a_ooool2o`0001Cooooo0_l0001Kooooo`;o00003?ooool001kooooo00?o0000oooo
ooooool0QOooool2o`0003oooooo0_l0000Xooooo`;o00005Oooool2o`0000kooooo1?l0000Noooo
o`;o00003?ooool001kooooo00?o0000ooooooooool0QOooool2o`0004[ooooo0_l0000Mooooo`;o
00003Oooool2o`0000Kooooo0_l0000>ooooo`Co0000;?ooool001kooooo00?o0000ooooooooool0
Foooool2o`0007Cooooo0_l0000Vooooo`;o00001?ooool2o`0004Kooooo000Nooooo`03o`000?oo
oooooooo05_ooooo0_l00003ooooo`;o00002oooool2o`0001Wooooo0_l0001_ooooo`;o0000C?oo
ool001kooooo00?o0000ooooooooool08_ooool2o`0001?ooooo0_l0000Wooooo`;o00002oooool2
o`0001Wooooo0_l0000gooooo`;o0000Q?ooool001kooooo00?o0000ooooooooool08_ooool2o`00
01?ooooo0_l0001?ooooo`;o0000=oooool2o`0002Wooooo0_l0000Booooo`;o00001oooool2o`00
03cooooo000Nooooo`03o`000?oooooooooo03gooooo0_l00025ooooo`;o00000_ooool2o`0002;o
oooo0_l0000Booooo`?o00001_ooool2o`0003cooooo000Nooooo`03o`000?oooooooooo00Kooooo
0_l0000eooooo`;o0000Joooool2o`0001Sooooo0_l00002ooooo`;o0000=oooool2o`0001oooooo
0_l0000Sooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^
k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`06ooooo`;o00007oooool2o`00043o
oooo0_l0000oooooo`;o0000M_ooool2o`0001;ooooo0ol0000>ooooo`000oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0
003oooooooooo`0Wooooo`;o0000@?ooool2o`0004?ooooo0_l0001Oooooo`;o00009Oooool3o`00
00kooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo
000000Kooooo0ol0001<ooooo`;o0000H?ooool2o`0005_ooooo0_l00002ooooo`;o0000=_ooool0
00?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_oo
ool00ol0003oooooooooo`1<ooooo`;o0000Woooool2o`0001cooooo0_l0000Eooooo`?o00008_oo
ool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
1_ooool00ol0003oooooooooo`3Cooooo`;o00005_ooool4o`0000Kooooo0_l000000ooooooo0000
o`00000Aooooo`;o00004_ooool2o`000004ooooool0003o0000o`0002;ooooo0003ooooo`05oa0@
4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo01Go
oooo0_l00008ooooo`;o0000NOooool3o`0000cooooo0_l0000Rooooo`;o00000_ooool4o`0001Ko
oooo0_l00008ooooo`;o000000?oooooo`000?l000000_l0000Sooooo`;o00009_ooool000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000oooooooo
ool05Oooool2o`0000Sooooo0_l0000Iooooo`;o0000<_ooool2o`0000oooooo0_l0000Iooooo`?o
00003?ooool2o`0002;ooooo0_l00002ooooo`;o00002oooool2o`0001[ooooo0_l0000Pooooo`;o
0000:Oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@
40Kooooo00?o0000ooooooooool0>_ooool2o`0002;ooooo0_l0000>ooooo`;o00003oooool2o`00
05gooooo0_l0000:ooooo`;o00007?ooool2o`0001;ooooo0_l0000Yooooo`007_ooool00ol0003o
ooooooooo`1Nooooo`?o0000ROooool2o`0001cooooo0_l00003ooooo`;o00001_ooool2o`00033o
oooo000Nooooo`03o`000?oooooooooo05[ooooo0_l00003ooooo`;o00001_ooool2o`00027ooooo
0_l00016ooooo`;o0000=?ooool2o`0000?ooooo0_l00006ooooo`;o0000<?ooool001kooooo00?o
0000ooooooooool0F_ooool2o`0000_ooooo0_l0000:ooooo`;o00000_ooool2o`00017ooooo0_l0
000Cooooo`;o0000<Oooool2o`0000Kooooo0_l0000oooooo`;o0000:_ooool001kooooo00?o0000
ooooooooool0Loooool2o`0000;ooooo0_l0000Vooooo`;o0000>Oooool2o`0003oooooo0_l0000Z
ooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o0000ooooool=ooooo`;o0000;?ooool001ko
oooo00?o0000ooooooooool02oooool2o`0000Cooooo0_l0000]ooooo`;o000000?oooooo`000?l0
00006Oooool2o`0004Gooooo0_l0001booooo`;o0000;?ooool001kooooo00?o0000ooooooooool0
4Oooool2o`0002gooooo0_l000000ooooooo0000o`00000Booooo`;o00001Oooool2o`0002;ooooo
0_l0000Aooooo`;o00003_ooool2o`0008gooooo0_l0000Aooooo`007_ooool00ol0003ooooooooo
o`1Gooooo`;o0000:Oooool2o`0000Sooooo0_l00007ooooo`;o0000WOooool2o`00017ooooo000N
ooooo`03o`000?oooooooooo08cooooo0_l0000@ooooo`;o0000POooool2o`0002Cooooo000Noooo
o`03o`000?oooooooooo033ooooo0_l0000mooooo`;o00001?ooool2o`0001_ooooo0_l0000:oooo
o`;o00006?ooool2o`0006Oooooo0_l0000Tooooo`007_ooool00ol0003oooooooooo`0Zooooo`;o
00001?ooool2o`0003gooooo0_l00004ooooo`;o00006oooool2o`0002Cooooo0_l0002=ooooo`00
7_ooool2o`00027ooooo0_l00008ooooo`;o00000oooool2o`000?oooooo5oooool001kooooo00?o
0000ooooooooool03?ooool2o`0001;ooooo0_l0000=ooooo`;o0000Doooool2o`0001kooooo0_l0
001Iooooo`;o0000;?ooool2o`0001Sooooo000Nooooo`03o`000?oooooooooo00cooooo0_l00013
ooooo`;o0000<Oooool2o`0001kooooo0_l00008ooooo`;o0000AOooool2o`0000Sooooo0_l00008
ooooo`;o00008_ooool2o`0001Sooooo000Nooooo`03o`000?oooooooooo057ooooo0_l0001Koooo
o`;o0000AOooool2o`0001;ooooo0_l0000looooo`007_ooool00ol0003oooooooooo`13ooooo`;o
0000ooooool3ooooo`007_ooool00ol0003oooooooooo`13ooooo`;o00005Oooool2o`0009cooooo
0_l0001=ooooo`007_ooool00ol0003oooooooooo`0]ooooo`;o0000:oooool2o`0000;ooooo0_l0
0022ooooo`;o00005?ooool2o`0004?ooooo0_l00008ooooo`007_ooool00ol0003oooooooooo`0]
ooooo`;o0000;oooool2o`00063ooooo0_l0000Pooooo`;o0000FOooool2o`0000Sooooo000Noooo
o`03o`000?oooooooooo01oooooo0_l0001Kooooo`;o00006_ooool2o`0000Kooooo0_l0000Noooo
o`;o0000QOooool001kooooo00?o0000ooooooooool06Oooool2o`0000Cooooo0_l0000dooooo`;o
00009Oooool2o`0001[ooooo0_l00006ooooo`;o00002?ooool2o`0009_ooooo000Nooooo`03o`00
0?oooooooooo00?ooooo0_l00003ooooo`;o00003oooool2o`0003[ooooo0_l0000]ooooo`;o0000
4?ooool4o`00013ooooo0_l0000>ooooo`;o0000C?ooool2o`0000gooooo0_l0000Xooooo`;o0000
1?ooool001kooooo00?o0000ooooooooool00oooool2o`0000?ooooo0_l0001jooooo`;o00004?oo
ool2o`0002;ooooo0_l0001<ooooo`;o00003Oooool2o`0002Sooooo0_l00004ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool02oooool2o`0002kooooo0_l00010ooooo`;o0000F_ooool2o`0006co
oooo000Nooooo`04o`000?oooooo0000o`0000[ooooo0_l0000Iooooo`;o00004oooool2o`0001Go
oooo0_l0000Yooooo`;o00001Oooool2o`000003ooooool0003o0000053ooooo0_l0001/ooooo`00
7_ooool4o`0002Gooooo0_l0000Zooooo`;o00002?ooool2o`0002Kooooo0_l000000ooooooo0000
o`000003ooooo`;o0000D?ooool2o`0006Oooooo000Nooooo`03o`000?oooooooooo05cooooo0_l0
000Zooooo`;o00000_ooool2o`0002gooooo0_l0000Qooooo`;o00001?ooool2o`00067ooooo000N
ooooo`03o`000?oooooooooo08?ooooo0_l00003ooooo`;o0000<Oooool2o`0002Oooooo0_l0000M
ooooo`;o0000@_ooool001kooooo00?o0000ooooooooool0=Oooool2o`0001;ooooo0_l0000Poooo
o`;o00005_ooool2o`0007kooooo0_l0000Vooooo`;o00006_ooool001kooooo00?o0000oooooooo
ool0=Oooool2o`0001;ooooo0_l0000Mooooo`;o000000?oooooo`000?l000001Oooool2o`0002co
oooo0_l0000Qooooo`;o0000@_ooool2o`0002;ooooo0_l0000Jooooo`007_ooool00ol0003ooooo
ooooo`1Xooooo`;o00002?ooool2o`0002cooooo0_l0000Qooooo`;o00005?ooool2o`0002cooooo
0_l0000nooooo`007_ooool00ol0003oooooooooo`1/ooooo`;o0000Joooool2o`0005Oooooo0_l0
000Cooooo`007_ooool00ol0003oooooooooo`1;ooooo`;o00007oooool2o`000<Cooooo0_l0000C
ooooo`007_ooool00ol0003oooooooooo`0nooooo`;o00002oooool2o`000:kooooo0_l0000<oooo
o`;o0000??ooool001kooooo00?o0000ooooooooool0:oooool2o`00017ooooo0_l0001Tooooo`;o
00009Oooool2o`0002kooooo0_l0000<ooooo`;o0000??ooool001kooooo00?o0000ooooooooool0
:oooool2o`0007Oooooo0_l0000Uooooo`;o00003_ooool2o`0006[ooooo000Nooooo`03o`000?oo
oooooooo0=_ooooo0_l0001<ooooo`;o00007?ooool001kooooo00?o0000ooooooooool06Oooool2
o`0005Oooooo0_l0000Dooooo`;o0000;Oooool2o`00073ooooo0_l0000Looooo`007_ooool00ol0
003oooooooooo`0Iooooo`;o0000B?ooool2o`0000gooooo1?l0000Booooo`;o0000;Oooool2o`00
0003ooooool0003o000002Kooooo0_l0001Sooooo`007_ooool00ol0003oooooooooo`1Sooooo`;o
000000?oooooo`000?l000003?ooool2o`0004Cooooo0_l0000Vooooo`;o0000Hoooool001kooooo
00?o0000ooooooooool0I?ooool4o`0001Oooooo0_l00036ooooo`007_ooool2o`0001cooooo0_l0
0017ooooo`;o00006Oooool2o`000:Gooooo0_l0000Oooooo`007_ooool00ol0003oooooooooo`0K
ooooo`;o00003?ooool2o`0001oooooo0_l0002:ooooo`;o0000;_ooool2o`0001kooooo0_l0000O
ooooo`007_ooool00ol0003oooooooooo`02ooooo`;o00009Oooool2o`0000?ooooo0_l000000ooo
oooo0000o`00000Gooooo`;o0000R_ooool2o`0002kooooo0_l0000Eooooo`;o0000:?ooool001ko
oooo00?o0000ooooooooool00_ooool2o`0002[ooooo0_l000000ooooooo0000o`00000=ooooo`;o
00002?ooool2o`0001[ooooo0_l0002Hooooo`;o00006oooool2o`0002Sooooo000Nooooo`03o`00
0?oooooooooo00?ooooo0_l0000kooooo`;o00002?ooool2o`0001[ooooo0_l0001Fooooo`;o0000
@?ooool2o`0002?ooooo0_l0000Pooooo`007_ooool2o`0000Cooooo0_l0001Qooooo`;o0000E_oo
ool2o`0003cooooo0ol0000Oooooo`;o00001Oooool2o`00023ooooo000Nooooo`;o0000=Oooool2
o`0003gooooo0_l0001]ooooo`;o00006?ooool3o`0001oooooo0_l00004ooooo`;o00008Oooool0
01kooooo00?o0000ooooooooool0=?ooool2o`0003gooooo0_l0001Yooooo`;o00000_ooool2o`00
037ooooo0_l0000=ooooo`;o00008Oooool001kooooo00?o0000ooooooooool0:oooool2o`000:So
oooo0_l00007ooooo`;o0000=Oooool2o`00033ooooo000Nooooo`03o`000?oooooooooo00;o0000
6?ooool2o`0000oooooo0_l0002Xooooo`;o0000L?ooool001kooooo00?o0000ooooooooool00_l0
000Hooooo`;o00003Oooool2o`0003Wooooo0_l0000Wooooo`;o00003Oooool2o`0001oooooo0_l0
000Yooooo`;o00004_ooool2o`0000[ooooo0_l0000Mooooo`;o00007_ooool001kooooo00?o0000
ooooooooool0:Oooool2o`0003Wooooo0_l0000Eooooo`;o00000_ooool2o`0000cooooo0_l0000=
ooooo`;o00007oooool2o`00017ooooo0_l0000Fooooo`;o00001Oooool2o`0000_ooooo0_l0000:
ooooo`;o00007Oooool2o`0001kooooo000Nooooo`03o`000?oooooooooo05cooooo0_l0000Moooo
o`;o00000_ooool2o`0004oooooo0_l00005ooooo`;o00005_ooool2o`0002kooooo0_l0000Voooo
o`007_ooool00ol0003oooooooooo`0Fooooo`;o0000A?ooool2o`0005Oooooo0_l0000Pooooo`;o
0000A_ooool2o`0002Kooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo01Kooooo0_l00012oooo
o`;o0000FOooool2o`00013ooooo0_l0000Dooooo`;o0000>Oooool2o`0002gooooo0003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06
ooooo`03o`000?oooooooooo02?ooooo0_l0000eooooo`;o00002Oooool2o`00063ooooo0_l0000D
ooooo`;o0000>Oooool2o`0000;ooooo0_l0000Yooooo`000oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o00008oooool2o`0000_ooooo0_l0
0004ooooo`;o0000;Oooool2o`0002Kooooo0_l0001<ooooo`;o0000:?ooool2o`0001Gooooo0_l0
000Yooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RH
oc8b<P06ooooo`03o`000?oooooooooo027ooooo0_l0000=ooooo`;o00001?ooool2o`0005Gooooo
0_l0001<ooooo`;o0000:?ooool2o`00043ooooo0003ooooo`05o`000?ooooooooooooooool00000
2oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo0ol00005ooooo`;o00005Oooool2o`0000?o
oooo0_l0001Sooooo`;o00007_ooool2o`0009oooooo0003ooooo`05oa0@4?ooooooooooooooool@
41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo0ol00005ooooo`;o00001oooool2o`00
00cooooo0_l0000Yooooo`;o00006Oooool2o`0002;ooooo0_l0000Nooooo`;o0000;_ooool2o`00
00Cooooo0_l0000Qooooo`;o0000=oooool2o`0000gooooo0003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool03_ooool2
o`0003Oooooo1?l00008ooooo`;o00003Oooool2o`0007;ooooo0_l00004ooooo`;o00004oooool2
o`0000cooooo0_l0000eooooo`Co00003Oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`0jooooo`;o00003Ooo
ool2o`0000Sooooo0_l0002Looooo`;o00004Oooool2o`0001Oooooo0_l0000<ooooo`;o00002Ooo
ool2o`0000oooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0000Tooooo`;o0000Ioooool2
o`0005gooooo1?l0000Gooooo`;o00003?ooool2o`0001[ooooo000Nooooo`03o`000?oooooooooo
01Cooooo0_l0000^ooooo`;o0000@Oooool2o`0001[ooooo0_l0000:ooooo`;o0000DOooool2o`00
04?ooooo000Nooooo`03o`000?oooooooooo04Cooooo0_l00011ooooo`;o00005Oooool2o`0000oo
oooo0_l00009ooooo`;o0000<oooool2o`0005Kooooo000Nooooo`03o`000?oooooooooo04kooooo
0_l0001>ooooo`;o00000oooool2o`0001Gooooo0_l0000]ooooo`;o00001?ooool2o`0000[ooooo
0_l0000Qooooo`;o00009oooool001kooooo00?o0000ooooooooool04oooool2o`0003Wooooo0_l0
0003ooooo`;o0000C_ooool2o`0000_ooooo0_l0000gooooo`;o00004?ooool2o`00027ooooo0_l0
000Wooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o0000?_ooool2o`0001[ooooo1?l0000X
ooooo`;o00004oooool2o`0004Wooooo0_l0001:ooooo`007_ooool00ol0003oooooooooo`1?oooo
o`;o00007_ooool4o`0002Sooooo0_l0000Oooooo`;o00004?ooool2o`0007Oooooo000Nooooo`03
o`000?oooooooooo00;ooooo0_l0000/ooooo`;o00007Oooool2o`0000Gooooo0_l0000Cooooo`;o
0000Coooool2o`00013ooooo0_l0000Kooooo`;o00004?ooool2o`0004Sooooo000Nooooo`03o`00
0?oooooooooo00;ooooo0_l0000/ooooo`;o00005?ooool2o`0000Sooooo0_l00004ooooo`;o0000
4oooool2o`0000Oooooo0_l0000Jooooo`;o0000FOooool2o`00013ooooo0_l00018ooooo`007_oo
ool00ol0003oooooooooo`0Zooooo`;o00006_ooool2o`0000Sooooo0_l0000Rooooo`;o00006_oo
ool2o`0007cooooo0_l0000gooooo`007_ooool00ol0003oooooooooo`0Zooooo`;o0000>_ooool2
o`0000Wooooo0_l0000:ooooo`;o00001Oooool2o`0000Oooooo0_l0000Aooooo`;o0000K?ooool2
o`0003Oooooo000Nooooo`;o0000@oooool2o`0002;ooooo0_l00009ooooo`;o00002_ooool2o`00
00Gooooo0_l00007ooooo`;o00004Oooool2o`0003Kooooo0_l0000cooooo`;o00006_ooool2o`00
01cooooo000Nooooo`03o`000?oooooooooo01oooooo0_l0000Qooooo`;o00001?ooool2o`0004oo
oooo0_l0000Wooooo`;o00005?ooool2o`0003?ooooo0_l0000>ooooo`;o00002_ooool2o`0001co
oooo000Nooooo`03o`000?oooooooooo01oooooo0_l00006ooooo`;o00007oooool2o`0002oooooo
0_l000000ooooooo0000o`00000Kooooo`;o00009oooool2o`00047ooooo0_l0000Fooooo`;o0000
:?ooool001kooooo00?o0000ooooooooool09oooool2o`0001Gooooo0_l0000Pooooo`;o00005ooo
ool2o`000003ooooool0003o000001Sooooo0_l00014ooooo`;o00004Oooool2o`0001Cooooo1?l0
000nooooo`007_ooool00ol0003oooooooooo`0nooooo`;o00006_ooool2o`0000Cooooo0_l00000
0ooooooo0000o`00000Booooo`;o00007Oooool2o`0000?ooooo0_l0000oooooo`;o00004Oooool2
o`0001Kooooo0_l0000nooooo`007_ooool00ol0003oooooooooo`1Jooooo`;o00001oooool2o`00
01;ooooo0_l0000Rooooo`;o00002?ooool2o`0009?ooooo0_l00002ooooo`;o00001oooool001ko
oooo00?o0000ooooooooool0Boooool2o`000003ooooool0003o000000[ooooo0_l00019ooooo`;o
0000BOooool2o`0004Sooooo0_l00002ooooo`;o00001oooool001kooooo00?o0000ooooooooool0
Boooool2o`000003ooooool0003o00000:3ooooo0_l00004ooooo`;o0000Coooool001kooooo00?o
0000ooooooooool07oooool2o`0003gooooo0_l0000^ooooo`;o0000E?ooool2o`0000gooooo0_l0
00000ooooooo0000o`00001?ooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o0000?Oooool2
o`0001Sooooo0_l0000<ooooo`;o00001_ooool2o`0000oooooo0_l00002ooooo`;o0000<?ooool2
o`0000gooooo0_l0000=ooooo`;o0000@?ooool2o`00013ooooo000Mooooo`;o00006_ooool2o`00
00Sooooo0_l0000Iooooo`;o0000>Oooool2o`0000cooooo0_l0000Gooooo`;o00000_ooool2o`00
033ooooo0_l0001Nooooo`;o00004?ooool001gooooo0_l0000Aooooo`;o00001oooool2o`0000So
oooo0_l0000Iooooo`;o00009Oooool2o`00073ooooo0_l0000Qooooo`;o0000C?ooool001kooooo
00?o0000ooooooooool03oooool2o`00027ooooo0_l0000`ooooo`;o0000L?ooool2o`00027ooooo
0_l0001<ooooo`007_ooool00ol0003oooooooooo`0booooo`;o0000^oooool2o`0005Kooooo000N
ooooo`03o`000?oooooooooo07cooooo0_l0001aooooo`;o0000>Oooool2o`0000?ooooo0_l0000F
ooooo`007_ooool00ol0003oooooooooo`0iooooo`;o0000@Oooool4o`000:[ooooo0_l00003oooo
o`;o00005_ooool001kooooo0_l0000?ooooo`;o00005oooool2o`00013ooooo0_l0000Vooooo`;o
00002_ooool2o`0000oooooo0_l00020ooooo`;o00004_ooool2o`00037ooooo000Nooooo`?o0000
3_ooool2o`0001Oooooo0_l000000ooooooo0000o`00000booooo`;o000000?oooooo`000?l00000
2_ooool2o`00097ooooo0_l0000Booooo`;o00005oooool2o`0001Sooooo000Nooooo`?o0000:_oo
ool2o`0003;ooooo0_l0001Qooooo`;o0000J_ooool2o`0001Sooooo000Nooooo`03o`000?oooooo
oooo04Gooooo0_l0001jooooo`;o0000;_ooool2o`0004?ooooo0_l0000?ooooo`007Oooool2o`00
04Oooooo0_l0000:ooooo`;o00004oooool2o`0002Cooooo0_l00015ooooo`;o00007?ooool2o`00
04?ooooo0_l0000?ooooo`007Oooool2o`0005?ooooo0_l0000Cooooo`;o00009?ooool2o`0004Go
oooo0_l0000Zooooo`;o0000A_ooool001kooooo00?o0000ooooooooool0>Oooool2o`0001kooooo
0_l0002Tooooo`;o0000@?ooool2o`0000Cooooo000Nooooo`03o`000?oooooooooo03Wooooo0_l0
000Nooooo`;o0000Hoooool2o`0001_ooooo0_l0001Tooooo`;o00001?ooool001kooooo00?o0000
ooooooooool0BOooool2o`0004_ooooo0_l0000Vooooo`;o00006oooool2o`0006[ooooo000Noooo
o`03o`000?oooooooooo04Wooooo0_l0000Vooooo`;o00008oooool2o`0001[ooooo0_l0000Uoooo
o`;o0000K?ooool001kooooo00?o0000ooooooooool02Oooool2o`0003Gooooo0_l0000_ooooo`;o
0000?oooool3o`0001cooooo0_l00006ooooo`;o0000K?ooool001kooooo00?o0000ooooooooool0
2Oooool2o`0003Gooooo0_l0000Dooooo`;o0000@_ooool2o`0001Oooooo0_l0000Looooo`;o0000
Aoooool2o`0002_ooooo000Nooooo`03o`000?oooooooooo03kooooo0ol0000Eooooo`;o0000@_oo
ool2o`0003_ooooo0_l00011ooooo`;o0000:oooool001kooooo00?o0000ooooooooool0?_ooool3
o`0009Kooooo0_l0000=ooooo`;o0000Goooool001kooooo00?o0000ooooooooool06?ooool2o`00
05Sooooo0_l0000nooooo`;o00001_ooool2o`0002Cooooo0_l00004ooooo`;o0000Goooool001ko
oooo00?o0000ooooooooool06?ooool2o`0005Sooooo0_l0000nooooo`;o00001_ooool2o`0000?o
oooo0_l0000Oooooo`;o00000oooool2o`0002Oooooo0_l0000_ooooo`;o00001_ooool001kooooo
0_l0000<ooooo`;o00003_ooool2o`0001[ooooo0_l0000_ooooo`;o0000??ooool2o`0001Oooooo
0_l00006ooooo`;o00007?ooool2o`0002Oooooo0_l0000_ooooo`;o00001_ooool001kooooo00?o
0000ooooooooool02?ooool2o`000003ooooool0003o000000kooooo0_l00002ooooo`;o00005_oo
ool2o`0002oooooo0_l0000looooo`;o00007oooool2o`0007kooooo000Nooooo`03o`000?oooooo
oooo00Sooooo0_l0000Eooooo`;o0000a_ooool2o`0001Gooooo0_l00017ooooo`007_ooool00ol0
003oooooooooo`2Yooooo`;o0000??ooool2o`0001Gooooo0_l0000Mooooo`;o0000:?ooool001ko
oooo00?o0000ooooooooool0T?ooool2o`0000oooooo0_l00006ooooo`;o0000C_ooool2o`0002;o
oooo0_l0000Aooooo`;o00003_ooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo093ooooo
0_l0000?ooooo`;o0000<Oooool2o`0001Kooooo0_l0000;ooooo`;o0000=Oooool2o`0000kooooo
0_l00005ooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o0000Aoooool2o`0004_ooooo0_l0
000Looooo`;o00005_ooool2o`0005Wooooo000Nooooo`03o`000?oooooooooo023ooooo0_l00017
ooooo`;o0000Boooool4o`0000Cooooo0_l0001eooooo`;o00004?ooool001kooooo00?o0000oooo
ooooool04?ooool2o`0004gooooo0_l0001Gooooo`;o00001?ooool2o`0002oooooo0_l00014oooo
o`;o00004?ooool001kooooo00?o0000ooooooooool04?ooool2o`0002Oooooo0_l0000Tooooo`;o
00000_ooool2o`0001Gooooo0_l0000Cooooo`;o00006_ooool2o`0003Oooooo0_l00009ooooo`;o
00003?ooool2o`0001oooooo0_l0000Wooooo`007_ooool3o`0003Wooooo0_l0000:ooooo`;o0000
6oooool3o`0001Gooooo0_l0000Cooooo`;o00006_ooool2o`0003Oooooo0_l0000Gooooo`;o0000
7oooool2o`0002Oooooo000Nooooo`?o0000AOooool2o`0001_ooooo0_l0000Eooooo`;o0000D?oo
ool2o`0007[ooooo000Nooooo`03o`000?oooooooooo02gooooo0_l0000Pooooo`;o00003_ooool2
o`0001Sooooo0_l0000=ooooo`;o00000oooool2o`0003cooooo0_l0000]ooooo`;o0000Boooool0
01kooooo00?o0000ooooooooool0;Oooool2o`00023ooooo0_l0000>ooooo`;o00001_ooool2o`00
01oooooo0_l00003ooooo`;o0000Joooool2o`00033ooooo0_l00006ooooo`;o00004Oooool001Co
oooo1?l000000ol@413oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o0000;oooool2o`00
03?ooooo0_l0002=ooooo`;o0000=?ooool2o`0000Kooooo0_l0000Aooooo`005_ooool00ol0003o
ooooooooo`05ooooo`04o`000?ooooooooooooooo`;o0000;oooool2o`0001Oooooo0_l0001:oooo
o`;o00007Oooool2o`00017ooooo0_l0000[ooooo`;o0000Coooool001Kooooo00?o0000oooooooo
ool01Oooool3o`0004_ooooo0_l0000nooooo`;o00002_ooool2o`0001gooooo0_l0000Aooooo`;o
0000@oooool2o`0003Oooooo000Fooooo`03o`000?oooooooooo09?ooooo0_l00021ooooo`;o0000
=oooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3o
oooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Cooooo00?oEEEEofIVI_l0
0000oooooomBooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.98754 .17086 Mdot
.38519 .98941 Mdot
.17693 .16903 Mdot
.54383 .94023 Mdot
.23092 .09291 Mdot
.05574 .50379 Mdot
.94427 .32819 Mdot
.0885 .46807 Mdot
.21451 .85947 Mdot
.42952 .01806 Mdot
.58791 .84218 Mdot
.28339 .73849 Mdot
.32179 .23321 Mdot
.60398 .12313 Mdot
.34617 .40832 Mdot
.58237 .4939 Mdot
.61823 .9904 Mdot
.06357 .30373 Mdot
.51866 .037 Mdot
.07711 .57234 Mdot
.44275 .76774 Mdot
.15484 .10026 Mdot
.21838 .29645 Mdot
.02186 .76959 Mdot
.90259 .51256 Mdot
.47953 .52875 Mdot
.84337 .6259 Mdot
.71023 .41029 Mdot
.63201 .91377 Mdot
.23637 .89249 Mdot
.86999 .82554 Mdot
.50341 .99133 Mdot
.6459 .32556 Mdot
.07518 .15459 Mdot
.86873 .45134 Mdot
.72619 .77737 Mdot
.51903 .86777 Mdot
.39878 .65697 Mdot
.06148 .4901 Mdot
.14263 .85207 Mdot
.88046 .1292 Mdot
.31564 .69831 Mdot
.40195 .10021 Mdot
.30091 .17138 Mdot
.00059 .12247 Mdot
.55041 .58997 Mdot
.74064 .97993 Mdot
.46704 .10417 Mdot
.97757 .00577 Mdot
.31805 .94201 Mdot
.09876 .79612 Mdot
.72961 .59796 Mdot
.03346 .01262 Mdot
.02675 .39088 Mdot
.07811 .59127 Mdot
.15708 .91125 Mdot
.75533 .02414 Mdot
.17156 .80696 Mdot
.35934 .35531 Mdot
.19349 .97943 Mdot
.05149 .23018 Mdot
.0684 .84856 Mdot
.22776 .86274 Mdot
.63868 .69439 Mdot
.76275 .38388 Mdot
.25446 .00292 Mdot
.06967 .98928 Mdot
.58892 .78182 Mdot
.98837 .95083 Mdot
.92431 .20116 Mdot
.94585 .86619 Mdot
.14334 .54264 Mdot
.07779 .51279 Mdot
.51122 .62373 Mdot
.54898 .10125 Mdot
.00636 .15142 Mdot
.17439 .90415 Mdot
.29115 .53374 Mdot
.81724 .50586 Mdot
.18234 .4601 Mdot
.48026 .99246 Mdot
.76812 .85498 Mdot
.2091 .78031 Mdot
.94736 .42199 Mdot
.54535 .77162 Mdot
.97442 .80911 Mdot
.3726 .31989 Mdot
.20516 .78234 Mdot
.52772 .82689 Mdot
.50011 .6596 Mdot
.15733 .78596 Mdot
.74764 .56953 Mdot
.10884 .51703 Mdot
.58899 .36488 Mdot
.33217 .26177 Mdot
.20286 .45721 Mdot
.38915 .89671 Mdot
.69605 .28452 Mdot
.62074 .98957 Mdot
.42146 .88278 Mdot
.45933 .48572 Mdot
.73768 .60395 Mdot
.84805 .98451 Mdot
.38347 .43958 Mdot
.42563 .49257 Mdot
.21209 .57701 Mdot
.37944 .85998 Mdot
.76618 .57593 Mdot
.19049 .72987 Mdot
.58677 .84123 Mdot
.14834 .20266 Mdot
.67912 .64275 Mdot
.97911 .3221 Mdot
.39309 .40151 Mdot
.98503 .62679 Mdot
.67915 .76651 Mdot
.19029 .64893 Mdot
.93359 .79202 Mdot
.44319 .45463 Mdot
.50622 .78314 Mdot
.70604 .23423 Mdot
.56847 .34803 Mdot
.0295 .4456 Mdot
.3282 .08895 Mdot
.52276 .58782 Mdot
.24577 .39198 Mdot
.47004 .65703 Mdot
.40776 .9167 Mdot
.78904 .72081 Mdot
.77941 .86002 Mdot
.82169 .92685 Mdot
.97444 .70449 Mdot
.0802 .27533 Mdot
.73232 .84333 Mdot
.40678 .30166 Mdot
.14884 .16807 Mdot
.38229 .87683 Mdot
.02765 .40139 Mdot
.50399 .62632 Mdot
.4249 .9211 Mdot
.15918 .3489 Mdot
.09004 .35539 Mdot
.78921 .93343 Mdot
.91794 .19293 Mdot
.37158 .40802 Mdot
.4042 .64951 Mdot
.44809 .78107 Mdot
.82459 .18364 Mdot
.38745 .31937 Mdot
.12404 .2198 Mdot
.19739 .96226 Mdot
.26208 .18211 Mdot
.70641 .08068 Mdot
.77788 .98063 Mdot
.24803 .35262 Mdot
.47481 .4679 Mdot
.41036 .60612 Mdot
.56652 .2504 Mdot
.6597 .5617 Mdot
.05797 .6448 Mdot
.76259 .55489 Mdot
.24974 .8689 Mdot
.98062 .2565 Mdot
.88753 .35489 Mdot
.87078 .66942 Mdot
.56206 .6947 Mdot
.04794 .6252 Mdot
.63703 .65971 Mdot
.2742 .54871 Mdot
.96183 .04445 Mdot
.87829 .41201 Mdot
.34754 .15383 Mdot
.44898 .21729 Mdot
.23224 .59133 Mdot
.82148 .51537 Mdot
.75475 .0071 Mdot
.39256 .46338 Mdot
.66074 .7408 Mdot
.48142 .37418 Mdot
.34623 .4877 Mdot
.04864 .24891 Mdot
.87763 .09018 Mdot
.76505 .92743 Mdot
.17424 .35342 Mdot
.77174 .25313 Mdot
.69569 .2378 Mdot
.42978 .2289 Mdot
.27236 .46556 Mdot
.46802 .38316 Mdot
.06712 .44566 Mdot
.37992 .23137 Mdot
.06773 .3472 Mdot
.80184 .59527 Mdot
.16867 .9834 Mdot
.38909 .07753 Mdot
.64327 .02167 Mdot
.41968 .3624 Mdot
.4762 .2048 Mdot
.33093 .47387 Mdot
.00123 .9934 Mdot
.08348 .80006 Mdot
.45994 .1953 Mdot
.08341 .21765 Mdot
.09492 .436 Mdot
.84642 .72421 Mdot
.38952 .19535 Mdot
.0239 .27531 Mdot
.39995 .51924 Mdot
.34939 .3656 Mdot
.05024 .64108 Mdot
.48246 .28537 Mdot
.67811 .15905 Mdot
.70921 .83593 Mdot
.54364 .45788 Mdot
.30277 .34845 Mdot
.82141 .49332 Mdot
.8353 .91424 Mdot
.11391 .12344 Mdot
.37083 .29692 Mdot
.14458 .90984 Mdot
.84225 .4143 Mdot
.7026 .5944 Mdot
.73188 .69283 Mdot
.71049 .85058 Mdot
.60911 .41787 Mdot
.53754 .79045 Mdot
.97453 .48662 Mdot
.43417 .71592 Mdot
.65855 .8611 Mdot
.61588 .91615 Mdot
.67825 .17022 Mdot
.71336 .9104 Mdot
.18066 .50703 Mdot
.68456 .58617 Mdot
.90046 .42508 Mdot
.62138 .53615 Mdot
.60142 .62574 Mdot
.47566 .05176 Mdot
.31189 .69211 Mdot
.8127 .9689 Mdot
.01322 .90541 Mdot
.74839 .46925 Mdot
.83367 .28819 Mdot
.53351 .37143 Mdot
.14958 .93394 Mdot
.01883 .12339 Mdot
.58493 .09816 Mdot
.01959 .45555 Mdot
.68855 .17679 Mdot
.21372 .66329 Mdot
.80503 .20741 Mdot
.72251 .05048 Mdot
.40811 .63536 Mdot
.69652 .18838 Mdot
.20453 .96451 Mdot
.86098 .23676 Mdot
.66053 .84455 Mdot
.02349 .18827 Mdot
.17473 .11911 Mdot
.25233 .65919 Mdot
.35292 .31697 Mdot
.94598 .52139 Mdot
.24043 .61247 Mdot
.64107 .80632 Mdot
.22452 .45286 Mdot
.63386 .51789 Mdot
.5399 .67733 Mdot
.41505 .79583 Mdot
.58269 .7094 Mdot
.60728 .98956 Mdot
.55986 .93864 Mdot
.8827 .5977 Mdot
.77369 .28122 Mdot
.15819 .82212 Mdot
.31231 .20035 Mdot
.09964 .46938 Mdot
.49434 .27082 Mdot
.04524 .25704 Mdot
.48926 .80896 Mdot
.46945 .25786 Mdot
.4639 .97278 Mdot
.05245 .70477 Mdot
.29468 .02581 Mdot
.88718 .86195 Mdot
.05971 .53555 Mdot
.30465 .60178 Mdot
.64439 .70363 Mdot
.70646 .58945 Mdot
.72583 .91336 Mdot
.02128 .69848 Mdot
.62026 .83256 Mdot
.346 .14376 Mdot
.60311 .2144 Mdot
.29094 .77141 Mdot
.61322 .58894 Mdot
.23365 .41152 Mdot
.90321 .82821 Mdot
.23277 .47202 Mdot
.93023 .36118 Mdot
.34429 .3486 Mdot
.02528 .66751 Mdot
.91039 .1516 Mdot
.91589 .60034 Mdot
.36834 .50375 Mdot
.5773 .78391 Mdot
.11956 .27268 Mdot
.16147 .55926 Mdot
.49414 .33653 Mdot
.90424 .33142 Mdot
.98316 .41201 Mdot
.46828 .48182 Mdot
.96915 .5152 Mdot
.37911 .49366 Mdot
.5576 .93522 Mdot
.22363 .50508 Mdot
.79704 .98992 Mdot
.35979 .32444 Mdot
.37373 .39369 Mdot
.1412 .53064 Mdot
.32745 .31789 Mdot
.03526 .47687 Mdot
.79067 .63724 Mdot
.16423 .29028 Mdot
.49467 .4855 Mdot
.17316 .63862 Mdot
.45801 .0296 Mdot
.3235 .63246 Mdot
.07296 .30192 Mdot
.9049 .57055 Mdot
.92783 .62998 Mdot
.12536 .0667 Mdot
.38906 .75248 Mdot
.72013 .88471 Mdot
.81442 .59368 Mdot
.12053 .88645 Mdot
.9652 .52897 Mdot
.13609 .65703 Mdot
.93518 .10672 Mdot
.16947 .93378 Mdot
.27449 .40951 Mdot
.67484 .63439 Mdot
.74921 .17729 Mdot
.17393 .16819 Mdot
.2189 .32913 Mdot
.04486 .96601 Mdot
.608 .3022 Mdot
.62329 .32485 Mdot
.51195 .03548 Mdot
.02131 .94356 Mdot
.82614 .53419 Mdot
.33017 .97303 Mdot
.24366 .84876 Mdot
.94542 .0228 Mdot
.58251 .95047 Mdot
.26601 .18807 Mdot
.20403 .31997 Mdot
.40204 .67186 Mdot
.9506 .70156 Mdot
.18992 .00556 Mdot
.28689 .99281 Mdot
.88353 .11121 Mdot
.46473 .00723 Mdot
.13709 .12217 Mdot
.13319 .34983 Mdot
.8323 .65821 Mdot
.84179 .05619 Mdot
.00784 .01161 Mdot
.11338 .88194 Mdot
.03214 .39704 Mdot
.90572 .80905 Mdot
.34009 .00502 Mdot
.43887 .64557 Mdot
.14523 .00745 Mdot
.06295 .39059 Mdot
.30784 .64082 Mdot
.67637 .15857 Mdot
.81134 .55171 Mdot
.24343 .16012 Mdot
.25018 .31746 Mdot
.74549 .21347 Mdot
.36045 .42384 Mdot
.29951 .69856 Mdot
.30619 .83572 Mdot
.6604 .5815 Mdot
.06976 .12452 Mdot
.86945 .91634 Mdot
.03764 .78315 Mdot
.68657 .22927 Mdot
.80114 .6902 Mdot
.92184 .58788 Mdot
.88608 .8998 Mdot
.74704 .83615 Mdot
.81084 .86319 Mdot
.04544 .25929 Mdot
.77175 .81759 Mdot
.86986 .92563 Mdot
.2108 .13793 Mdot
.45913 .74275 Mdot
.41623 .13639 Mdot
.34841 .0123 Mdot
.2761 .84379 Mdot
.48218 .89399 Mdot
.10736 .81601 Mdot
.3229 .48353 Mdot
.39422 .37625 Mdot
.75079 .59703 Mdot
.45157 .99047 Mdot
.64144 .05056 Mdot
.39748 .24194 Mdot
.86677 .73666 Mdot
.27435 .64409 Mdot
.08361 .47839 Mdot
.37525 .99501 Mdot
.95045 .17966 Mdot
.10763 .54181 Mdot
.27418 .29257 Mdot
.03231 .00192 Mdot
.68836 .25719 Mdot
.45343 .2342 Mdot
.54635 .86473 Mdot
.18599 .47114 Mdot
.43344 .54656 Mdot
.53216 .4865 Mdot
.36078 .58465 Mdot
.42972 .04014 Mdot
.85878 .90881 Mdot
.15687 .79813 Mdot
.08039 .48953 Mdot
.51147 .26412 Mdot
.04791 .7789 Mdot
.82055 .47718 Mdot
.89451 .52122 Mdot
.16866 .63039 Mdot
.4373 .37311 Mdot
.79156 .49585 Mdot
.21417 .48174 Mdot
.76882 .2511 Mdot
.77153 .77268 Mdot
.26906 .83287 Mdot
.22032 .04082 Mdot
.03355 .91306 Mdot
.94745 .78417 Mdot
.75116 .99147 Mdot
.4903 .95892 Mdot
.22875 .89016 Mdot
.71997 .07505 Mdot
.87883 .7722 Mdot
.11693 .06618 Mdot
.75983 .0567 Mdot
.30638 .55415 Mdot
.03682 .54611 Mdot
.64221 .13963 Mdot
.73053 .13089 Mdot
.92715 .99146 Mdot
.37873 .61979 Mdot
.97895 .30972 Mdot
.65926 .94504 Mdot
.80673 .06262 Mdot
.10379 .86759 Mdot
.34927 .73889 Mdot
.11449 .32409 Mdot
.3097 .64844 Mdot
.19979 .0378 Mdot
.36778 .85234 Mdot
.16402 .44063 Mdot
.97157 .29571 Mdot
.45349 .18727 Mdot
.45659 .32104 Mdot
.09841 .43721 Mdot
.93238 .94834 Mdot
.44076 .9653 Mdot
.93887 .57304 Mdot
.19932 .52786 Mdot
.05167 .84507 Mdot
.08192 .9276 Mdot
.28752 .48837 Mdot
.40349 .16637 Mdot
.80518 .61149 Mdot
.61964 .35792 Mdot
.12354 .7424 Mdot
.10316 .28963 Mdot
.1238 .34358 Mdot
.3302 .72334 Mdot
.72794 .3184 Mdot
.62921 .95816 Mdot
.27671 .03368 Mdot
.04943 .29436 Mdot
.63724 .10712 Mdot
.21626 .83816 Mdot
.41872 .81848 Mdot
.84976 .81735 Mdot
.77687 .88492 Mdot
.16816 .36868 Mdot
.27818 .02325 Mdot
.77563 .00384 Mdot
.15684 .28846 Mdot
.53085 .92797 Mdot
.06067 .84161 Mdot
.24813 .67691 Mdot
.11114 .022 Mdot
.72318 .78402 Mdot
.45478 .61751 Mdot
.5086 .21098 Mdot
.03966 .22695 Mdot
.72316 .52909 Mdot
.47228 .03039 Mdot
.39111 .9513 Mdot
.15878 .25632 Mdot
.10813 .75418 Mdot
.12121 .86368 Mdot
.49879 .73304 Mdot
.37514 .28982 Mdot
.25149 .43382 Mdot
.59495 .95206 Mdot
.46006 .85888 Mdot
.96392 .99259 Mdot
.26428 .85718 Mdot
.02595 .64303 Mdot
.47873 .1107 Mdot
.54303 .91614 Mdot
.45553 .63322 Mdot
.27023 .40001 Mdot
.61896 .5349 Mdot
.10745 .64132 Mdot
.83265 .68664 Mdot
.19629 .27493 Mdot
.09899 .31981 Mdot
.76818 .95917 Mdot
.31668 .93918 Mdot
.97016 .69336 Mdot
.59877 .64625 Mdot
.03037 .18819 Mdot
.54522 .44652 Mdot
.38916 .94794 Mdot
.43344 .52101 Mdot
.47864 .63944 Mdot
.16895 .50225 Mdot
.92404 .57463 Mdot
.47538 .62383 Mdot
.82601 .70394 Mdot
.37226 .15639 Mdot
.90393 .37213 Mdot
.57418 .04384 Mdot
.61794 .73798 Mdot
.50053 .21035 Mdot
.73717 .52205 Mdot
.17654 .27389 Mdot
.84723 .4555 Mdot
.87916 .3811 Mdot
.32691 .05212 Mdot
.75612 .15252 Mdot
.29941 .75027 Mdot
.58477 .60566 Mdot
.7377 .85074 Mdot
.59128 .14558 Mdot
.8783 .4835 Mdot
.67015 .20148 Mdot
.50631 .7042 Mdot
.86115 .75593 Mdot
.31455 .96415 Mdot
.83562 .84398 Mdot
.1756 .01829 Mdot
.39905 .19255 Mdot
.23755 .79554 Mdot
.49875 .36655 Mdot
.81868 .39168 Mdot
.05367 .90809 Mdot
.28833 .34833 Mdot
.12142 .05623 Mdot
.41551 .0712 Mdot
.42294 .66548 Mdot
.81139 .02771 Mdot
.36156 .53229 Mdot
.86921 .31455 Mdot
.45714 .62676 Mdot
.37363 .0011 Mdot
.72789 .91229 Mdot
.54435 .12044 Mdot
.93887 .67184 Mdot
.73018 .19762 Mdot
.27631 .77698 Mdot
.93035 .4792 Mdot
.42296 .52681 Mdot
.26603 .13934 Mdot
.29908 .86492 Mdot
.29525 .41015 Mdot
.35924 .51676 Mdot
.47468 .80101 Mdot
.09798 .31444 Mdot
.03515 .2641 Mdot
.91514 .22025 Mdot
.77249 .35152 Mdot
.76535 .83953 Mdot
.5156 .19772 Mdot
.17815 .54818 Mdot
.72213 .78439 Mdot
.31173 .3617 Mdot
.25977 .85426 Mdot
.16734 .33238 Mdot
.19088 .58896 Mdot
.53988 .45847 Mdot
.64705 .69971 Mdot
.26478 .68964 Mdot
.34381 .76743 Mdot
.03168 .50304 Mdot
.22793 .8879 Mdot
.20816 .28428 Mdot
.99664 .79451 Mdot
.09826 .41587 Mdot
.45258 .72719 Mdot
.65289 .53886 Mdot
.47042 .47014 Mdot
.32261 .2564 Mdot
.25581 .42341 Mdot
.63728 .91215 Mdot
.64255 .07462 Mdot
.54895 .02827 Mdot
.84356 .31513 Mdot
.79266 .41177 Mdot
.54007 .09636 Mdot
.33145 .43088 Mdot
.55693 .9474 Mdot
.09855 .84173 Mdot
.68346 .76524 Mdot
.99655 .91384 Mdot
.78398 .77948 Mdot
.92102 .19063 Mdot
.80137 .30598 Mdot
.84763 .52129 Mdot
.38608 .12367 Mdot
.37527 .8559 Mdot
.46351 .53413 Mdot
.7013 .75474 Mdot
.27526 .27341 Mdot
.12989 .63142 Mdot
.16488 .68622 Mdot
.18856 .36089 Mdot
.07112 .63537 Mdot
.94418 .74999 Mdot
.49005 .93094 Mdot
.54958 .41665 Mdot
.70836 .79667 Mdot
.50723 .83793 Mdot
.36467 .89494 Mdot
.38918 .81357 Mdot
.92186 .1223 Mdot
.85198 .49092 Mdot
.00066 .46752 Mdot
.75729 .61297 Mdot
.60881 .46981 Mdot
.66742 .36726 Mdot
.54261 .084 Mdot
.42467 .41006 Mdot
.54412 .84439 Mdot
.29182 .92777 Mdot
.2005 .39451 Mdot
.56017 .98392 Mdot
.87192 .74214 Mdot
.12508 .82943 Mdot
.60287 .97742 Mdot
.35796 .97369 Mdot
.291 .96097 Mdot
.47035 .22879 Mdot
.28457 .04125 Mdot
.50011 .21644 Mdot
.35381 .15967 Mdot
.75482 .85098 Mdot
.65211 .87908 Mdot
.92189 .37972 Mdot
.22746 .83376 Mdot
.22746 .87277 Mdot
.176 .29799 Mdot
.29295 .60702 Mdot
.3877 .67976 Mdot
.9754 .87718 Mdot
.27166 .00087 Mdot
.08579 .39227 Mdot
.58175 .73705 Mdot
.68455 .03347 Mdot
.51955 .02214 Mdot
.17796 .19019 Mdot
.73188 .18311 Mdot
.60522 .74091 Mdot
.04012 .33634 Mdot
.91563 .94206 Mdot
.2805 .9992 Mdot
.43622 .29515 Mdot
.25115 .30851 Mdot
.85782 .6093 Mdot
.22211 .36731 Mdot
.78492 .85629 Mdot
.25153 .92099 Mdot
.09014 .94665 Mdot
.32968 .32385 Mdot
.8955 .68878 Mdot
.4311 .58331 Mdot
.65174 .53049 Mdot
.71621 .18526 Mdot
.68244 .72413 Mdot
.58728 .20286 Mdot
.48647 .76913 Mdot
.2 .4127 Mdot
.16145 .35459 Mdot
.89676 .9412 Mdot
.48848 .74848 Mdot
.32215 .17219 Mdot
.94495 .31653 Mdot
.29184 .14545 Mdot
.02421 .24151 Mdot
.98789 .3139 Mdot
.80834 .87618 Mdot
.75465 .69526 Mdot
.07073 .78288 Mdot
.57656 .97422 Mdot
.36284 .901 Mdot
.04246 .25307 Mdot
.5147 .85682 Mdot
.99394 .83931 Mdot
.82031 .75125 Mdot
.34616 .32963 Mdot
.24914 .32093 Mdot
.09702 .38239 Mdot
.99185 .84127 Mdot
.70772 .05795 Mdot
.42414 .69508 Mdot
.68013 .72511 Mdot
.06761 .32676 Mdot
.01548 .98918 Mdot
.9916 .16481 Mdot
.38371 .54496 Mdot
.98508 .91271 Mdot
.53586 .78533 Mdot
.92172 .12945 Mdot
.9414 .26405 Mdot
.611 .81863 Mdot
.03631 .7638 Mdot
.94259 .93721 Mdot
.85513 .28429 Mdot
.23698 .87226 Mdot
.21208 .87449 Mdot
.76839 .26245 Mdot
.22815 .71554 Mdot
.53686 .79108 Mdot
.04841 .31197 Mdot
.79699 .23038 Mdot
.36973 .88382 Mdot
.61284 .92323 Mdot
.20108 .71332 Mdot
.88468 .77607 Mdot
.80406 .77281 Mdot
.41063 .24476 Mdot
.28054 .1491 Mdot
.24631 .40247 Mdot
.48607 .91555 Mdot
.3356 .89426 Mdot
.68034 .98501 Mdot
.68294 .92541 Mdot
.78254 .47385 Mdot
.66214 .56164 Mdot
.19248 .56878 Mdot
.04216 .35669 Mdot
.02626 .04358 Mdot
.38537 .59947 Mdot
.50931 .61578 Mdot
.00454 .81679 Mdot
.51199 .62611 Mdot
.14922 .41507 Mdot
.20726 .03773 Mdot
.22011 .9767 Mdot
.25634 .16842 Mdot
.85893 .76485 Mdot
.36283 .1352 Mdot
.30274 .84623 Mdot
.93281 .3445 Mdot
.34805 .74946 Mdot
.06156 .24742 Mdot
.79344 .51329 Mdot
.11215 .38871 Mdot
.1527 .88245 Mdot
.29238 .6204 Mdot
.35375 .58827 Mdot
.99027 .63042 Mdot
.9926 .25631 Mdot
.34256 .21481 Mdot
.17294 .59578 Mdot
.81214 .178 Mdot
.08114 .30701 Mdot
.35438 .48998 Mdot
.74159 .00642 Mdot
.41374 .13149 Mdot
.01972 .93985 Mdot
.53323 .09643 Mdot
.30154 .6707 Mdot
.82702 .60534 Mdot
.91818 .36496 Mdot
.14944 .30825 Mdot
.20804 .11641 Mdot
.0466 .21605 Mdot
.44945 .56253 Mdot
.10088 .22351 Mdot
.34994 .86884 Mdot
.41386 .87928 Mdot
.50522 .75446 Mdot
.09891 .32286 Mdot
.67499 .24787 Mdot
.0088 .17582 Mdot
.21034 .35881 Mdot
.23696 .48683 Mdot
.24488 .71781 Mdot
.75851 .52112 Mdot
.33595 .54157 Mdot
.99445 .65765 Mdot
.62973 .15382 Mdot
.1178 .72872 Mdot
.76002 .97487 Mdot
.47463 .64508 Mdot
.45994 .50119 Mdot
.10463 .30448 Mdot
.76977 .55014 Mdot
.79381 .31063 Mdot
.94219 .58259 Mdot
.57543 .35583 Mdot
.31079 .48247 Mdot
.88324 .00668 Mdot
.68604 .85672 Mdot
.8226 .72939 Mdot
.73902 .11234 Mdot
.22502 .58209 Mdot
.6058 .28089 Mdot
.34875 .72566 Mdot
.41327 .9802 Mdot
.22441 .9305 Mdot
.07405 .11663 Mdot
.24079 .28433 Mdot
.40194 .97979 Mdot
.83276 .74347 Mdot
.87508 .02781 Mdot
.39343 .61402 Mdot
.71239 .28108 Mdot
.69833 .55157 Mdot
.31975 .41123 Mdot
.93508 .16859 Mdot
.77968 .89598 Mdot
.41585 .89234 Mdot
.3184 .09259 Mdot
.6191 .23265 Mdot
.70877 .27389 Mdot
.04591 .04751 Mdot
.41835 .15787 Mdot
.48333 .82522 Mdot
.19738 .1224 Mdot
.20807 .16859 Mdot
.17338 .44671 Mdot
.4802 .27401 Mdot
.06885 .92903 Mdot
.82768 .66175 Mdot
.08797 .34831 Mdot
.79808 .9864 Mdot
.84369 .53112 Mdot
.09226 .83218 Mdot
.26369 .08029 Mdot
.26492 .15658 Mdot
.35095 .28619 Mdot
.75059 .88368 Mdot
.93254 .26687 Mdot
.61771 .20924 Mdot
.38215 .53366 Mdot
.17365 .72469 Mdot
.67097 .82192 Mdot
.09799 .25668 Mdot
.19833 .73393 Mdot
.36688 .08197 Mdot
.47824 .13034 Mdot
.61006 .15331 Mdot
.66784 .27661 Mdot
.29361 .53586 Mdot
.69016 .61847 Mdot
.39159 .1183 Mdot
.78438 .24523 Mdot
.46053 .79954 Mdot
.31744 .92591 Mdot
.96963 .02877 Mdot
.42261 .99326 Mdot
.25899 .61765 Mdot
.50366 .25573 Mdot
.30166 .82753 Mdot
.3843 .55461 Mdot
.63466 .58311 Mdot
.31276 .80674 Mdot
.04416 .29625 Mdot
.17121 .02503 Mdot
.69541 .08742 Mdot
.14732 .26409 Mdot
.47677 .55445 Mdot
.14255 .0443 Mdot
.20056 .57992 Mdot
.08662 .07981 Mdot
.90244 .06782 Mdot
.31052 .73258 Mdot
.47098 .85539 Mdot
.64688 .60439 Mdot
.08758 .19553 Mdot
.10126 .34736 Mdot
.90183 .53801 Mdot
.56809 .49479 Mdot
.10415 .39961 Mdot
.82646 .92248 Mdot
.76207 .42873 Mdot
.30461 .84206 Mdot
.72917 .62582 Mdot
.22179 .62019 Mdot
.87431 .49324 Mdot
.18988 .45061 Mdot
.41173 .16977 Mdot
.2645 .82916 Mdot
.10234 .12969 Mdot
.34846 .69707 Mdot
.89526 .294 Mdot
.29661 .09495 Mdot
.22082 .4432 Mdot
.52857 .10497 Mdot
.93774 .09341 Mdot
.77294 .82457 Mdot
.79448 .83981 Mdot
.23476 .14929 Mdot
.81386 .29612 Mdot
.15857 .71562 Mdot
.34243 .89313 Mdot
.50972 .70959 Mdot
.90871 .05144 Mdot
.63685 .90921 Mdot
.49316 .07381 Mdot
.81404 .59036 Mdot
.73701 .57961 Mdot
.51839 .09661 Mdot
.7976 .7246 Mdot
.7989 .41945 Mdot
.16478 .89784 Mdot
.81143 .96514 Mdot
.35007 .55558 Mdot
.10209 .12754 Mdot
.94523 .08665 Mdot
.90539 .44606 Mdot
.1721 .68225 Mdot
.58365 .54684 Mdot
.59103 .49054 Mdot
.58383 .03753 Mdot
.47625 .14078 Mdot
.26628 .06577 Mdot
.91127 .84389 Mdot
.87361 .6128 Mdot
.77988 .63206 Mdot
.56184 .02041 Mdot
.69327 .79232 Mdot
.1268 .13084 Mdot
.95602 .89809 Mdot
.00816 .14728 Mdot
.08881 .6775 Mdot
.00394 .45703 Mdot
.10101 .99168 Mdot
.99563 .9143 Mdot
.77509 .60617 Mdot
.37711 .18736 Mdot
.16446 .64959 Mdot
.25852 .66065 Mdot
.21397 .36043 Mdot
.89424 .06384 Mdot
.31794 .87302 Mdot
.43654 .35125 Mdot
.09152 .88335 Mdot
.86636 .66869 Mdot
.35491 .32797 Mdot
.40443 .87647 Mdot
.11247 .12125 Mdot
.51475 .59426 Mdot
.27019 .79912 Mdot
.31146 .56122 Mdot
.7282 .89997 Mdot
.97734 .80973 Mdot
.89278 .1348 Mdot
.20384 .71984 Mdot
.51737 .15004 Mdot
.95229 .82694 Mdot
.72127 .39317 Mdot
.1175 .26646 Mdot
.41347 .84522 Mdot
.19725 .34646 Mdot
.33381 .45701 Mdot
.03015 .33493 Mdot
.09044 .10653 Mdot
.29055 .77772 Mdot
.74775 .56514 Mdot
.69953 .12932 Mdot
.66638 .71588 Mdot
.30924 .70551 Mdot
.14247 .99266 Mdot
.11874 .91167 Mdot
.25777 .78381 Mdot
.51017 .89737 Mdot
.65052 .70558 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00Ko
oooo0_l00005ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo0ol00003ooooo`;o00002?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo0_l00008ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool01Oooool2o`0000Oooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`02ooooo`007_ooool00ol0003oooooooooo`06ooooo`;o00001Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00_ooooo0ol0000<ooooo`;o00000_ooool00ol0003ooooo
ooooo`0=ooooo`?o00003Oooool00ol0003oooooooooo`09ooooo`;o00000_ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00Co0000oooooooooooooooo0_l0000:ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool2o`000004ooooool0003o0000o`00
00Gooooo0_l00007ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool2o`00
00Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`06ooooo`;o00001_ooool00ol0
003oooooooooo`02ooooo`007_ooool00ol0003oooooooooo`0[ooooo`;o00003Oooool2o`0002ko
oooo0_l0000Wooooo`;o0000F?ooool2o`0000;ooooo0_l0000Xooooo`;o00007Oooool2o`0000_o
oooo000Nooooo`?o00001oooool2o`0006Cooooo0_l0003Hooooo`007_ooool3o`0000Oooooo0_l0
001Tooooo`;o0000f?ooool001kooooo00?o0000ooooooooool0=Oooool2o`00057ooooo0_l0002m
ooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o00004oooool2o`00057ooooo0_l0000Koooo
o`;o00003?ooool2o`0001Sooooo0_l0001Pooooo`;o00005_ooool001kooooo00?o0000oooooooo
ool08?ooool2o`0001;ooooo0_l0000Pooooo`;o00001?ooool2o`0004Oooooo0_l0000<ooooo`;o
00006?ooool2o`0002;ooooo0_l0000looooo`;o00005_ooool001kooooo00?o0000ooooooooool0
=?ooool2o`00023ooooo0_l00004ooooo`;o0000D?ooool2o`00047ooooo0_l0000Aooooo`;o0000
4_ooool2o`0001gooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`2Aooooo`;o00000_oo
ool2o`0001Oooooo0_l0001Dooooo`;o00004_ooool2o`0001gooooo0_l0000>ooooo`007_ooool0
0ol0003oooooooooo`1Fooooo`;o0000>Oooool2o`0000;ooooo0_l00013ooooo`;o0000Joooool0
01kooooo00?o0000ooooooooool0?Oooool4o`0001Gooooo0_l0001:ooooo`;o000000?oooooo`00
0?l000004oooool2o`0001kooooo0_l0001[ooooo`007_ooool00ol0003oooooooooo`0mooooo`Co
00000oooool2o`0001;ooooo0_l0000^ooooo`;o00006?ooool2o`000003ooooool0003o000001?o
oooo0_l0002;ooooo`007_ooool00ol0003oooooooooo`04ooooo`;o00009?ooool2o`0001Sooooo
0_l0000Booooo`;o0000;_ooool2o`0002gooooo0_l0001looooo`;o00004?ooool001kooooo00?o
0000ooooooooool01?ooool2o`0000Gooooo0_l0000Mooooo`;o0000Roooool2o`0007cooooo0_l0
000@ooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o0000_oooool2o`0001Wooooo0_l0001N
ooooo`007_ooool2o`0006Oooooo0_l0000_ooooo`;o0000<oooool2o`0001Wooooo0_l0000joooo
o`;o00008_ooool001kooooo00?o0000ooooooooool08oooool2o`00047ooooo0_l0000_ooooo`;o
0000F_ooool2o`0001Wooooo0_l0000Cooooo`;o00008_ooool001kooooo00?o0000ooooooooool0
8oooool2o`000;gooooo0_l0000?ooooo`;o00006Oooool2o`0003Oooooo000Nooooo`03o`000?oo
oooooooo0>;ooooo0_l0000Nooooo`;o0000@oooool001kooooo00?o0000ooooooooool0D_ooool2
o`000:kooooo0_l0000Kooooo`;o00009_ooool001kooooo00?o0000ooooooooool08_ooool2o`00
0003ooooool0003o000002_ooooo0_l0003;ooooo`Co00009?ooool001kooooo00?o0000oooooooo
ool08_ooool2o`000003ooooool0003o000005cooooo0_l0002Looooo`;o00009?ooool001kooooo
00?o0000ooooooooool0Poooool2o`0001Oooooo0_l0000_ooooo`;o00005oooool2o`0005oooooo
000Nooooo`03o`000?oooooooooo07[ooooo0_l0000Pooooo`;o0000;oooool2o`0001Oooooo0_l0
001Oooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o0000>?ooool2o`0002Kooooo0_l0001V
ooooo`;o0000Hoooool001kooooo00?o0000ooooooooool06?ooool2o`0003Sooooo0_l0000Ooooo
o`;o0000=oooool2o`0003Cooooo0_l0001Sooooo`007_ooool00ol0003oooooooooo`1cooooo`;o
0000=oooool2o`00033ooooo0_l0001?ooooo`;o00005_ooool001kooooo00?o0000ooooooooool0
Ioooool2o`0007Gooooo0_l0000iooooo`;o00005?ooool2o`0001Kooooo000Nooooo`03o`000?oo
oooooooo04Oooooo0_l0000Jooooo`;o00000_ooool2o`000;3ooooo0_l0000Booooo`;o00006?oo
ool001kooooo00?o0000ooooooooool0Aoooool2o`0001?ooooo0_l00005ooooo`;o0000?oooool2
o`0000?ooooo1?l00020ooooo`;o00006?ooool001kooooo00?o0000ooooooooool0G?ooool2o`00
04Kooooo0_l00003ooooo`Co00003Oooool2o`0008_ooooo000Nooooo`;o0000;oooool2o`0004oo
oooo0_l0000]ooooo`;o00002_ooool2o`0008_ooooo000Nooooo`03o`000?oooooooooo02kooooo
0_l0001?ooooo`;o00004oooool2o`0001;ooooo0_l00004ooooo`;o0000Uoooool001kooooo00?o
0000ooooooooool06Oooool2o`0007Wooooo0_l0000Booooo`;o00008Oooool2o`0005oooooo0_l0
000Iooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o0000OOooool2o`00037ooooo0_l0001>
ooooo`;o00003oooool2o`0001Wooooo000Nooooo`03o`000?oooooooooo09Sooooo0_l0001Boooo
o`;o0000;Oooool2o`0002[ooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0000Zooooo`;o
0000>Oooool2o`0006oooooo0_l0001Iooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o0000
2_ooool2o`0001?ooooo0_l00009ooooo`;o0000>Oooool2o`00033ooooo0_l0002Hooooo`007Ooo
ool2o`0000Cooooo0_l0000Looooo`?o00001Oooool2o`0000_ooooo0_l00005ooooo`;o0000>ooo
ool2o`0003;ooooo0_l0000Aooooo`;o0000I_ooool2o`0001gooooo000Mooooo`;o00001?ooool2
o`0000oooooo0_l00008ooooo`;o00000_ooool2o`0000Gooooo0_l0000Booooo`;o0000>oooool2
o`0004Gooooo0_l0001Vooooo`;o00007Oooool001kooooo00?o0000ooooooooool04oooool2o`00
00Sooooo0_l0001hooooo`;o0000A_ooool2o`0003Wooooo0_l0000<ooooo`;o00007Oooool001ko
oooo00?o0000ooooooooool07Oooool2o`0000Kooooo0_l0001Kooooo`;o00004oooool2o`0004Ko
oooo0_l00008ooooo`;o0000;oooool2o`0000cooooo0_l0000Mooooo`007_ooool00ol0003ooooo
ooooo`0Uooooo`;o0000Boooool2o`0000kooooo0ol0001Tooooo`;o0000<oooool2o`0002Oooooo
000Nooooo`03o`000?oooooooooo043ooooo0_l0000@ooooo`;o00007_ooool2o`0000oooooo0_l0
0018ooooo`;o0000Coooool2o`0002Oooooo000Nooooo`03o`000?oooooooooo043ooooo0_l0000@
ooooo`;o0000@oooool2o`0003Cooooo0_l0001hooooo`007_ooool00ol0003oooooooooo`1Koooo
o`;o00003oooool2o`0002Wooooo0_l0000Sooooo`;o0000ROooool001kooooo00Co0000ooooool0
003o0000F_ooool2o`0000oooooo0_l0001>ooooo`;o0000ROooool001kooooo1?l00017ooooo`;o
00003Oooool2o`0004_ooooo0_l0001nooooo`;o00008Oooool001kooooo0ol0000Dooooo`;o0000
<_ooool2o`0000gooooo0_l0000Dooooo`;o0000=Oooool2o`0001cooooo0_l00005ooooo`;o0000
9oooool2o`00033ooooo0_l0000Qooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o0000??oo
ool2o`0001Wooooo0_l00006ooooo`;o00003Oooool2o`0003cooooo0_l00005ooooo`;o00009ooo
ool2o`0005?ooooo000Nooooo`03o`000?oooooooooo04_ooooo0_l00005ooooo`;o00006oooool2
o`0000Cooooo0_l0000=ooooo`;o0000D_ooool2o`0006gooooo000Nooooo`03o`000?oooooooooo
04_ooooo0_l0000Rooooo`;o0000Ioooool2o`0006gooooo000Nooooo`03o`000?oooooooooo07oo
oooo0_l0002mooooo`;o00001oooool001kooooo00?o0000ooooooooool0;?ooool2o`0000Kooooo
0ol00009ooooo`;o00003Oooool2o`0002kooooo0_l000000ooooooo0000o`00001Dooooo`;o0000
D_ooool2o`00013ooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`0/ooooo`;o00001_oo
ool3o`0000Wooooo0_l0000=ooooo`;o00003Oooool2o`0000Gooooo0_l0000Kooooo`;o0000E?oo
ool2o`0005;ooooo0_l0000?ooooo`;o00002?ooool001kooooo00Co0000ooooool0003o0000GOoo
ool2o`0000Gooooo0_l0003Fooooo`;o00002?ooool001kooooo00Co0000ooooool0003o0000fooo
ool2o`00017ooooo0_l0000Cooooo`;o0000:oooool2o`0001Cooooo000Nooooo`03o`000?oooooo
oooo057ooooo0_l00029ooooo`;o00004Oooool2o`0001?ooooo0_l0000[ooooo`;o00005?ooool0
01kooooo00?o0000ooooooooool0DOooool2o`0009;ooooo0_l00003ooooo`;o00007?ooool2o`00
03gooooo000Nooooo`03o`000?oooooooooo00Cooooo1?l0001:ooooo`;o00008_ooool2o`0001Oo
oooo0_l0001=ooooo`;o00001Oooool2o`0000?ooooo0_l0000Looooo`;o0000?Oooool001kooooo
00?o0000ooooooooool01?ooool4o`0002kooooo0_l0000Jooooo`;o00008_ooool2o`0001Oooooo
0_l0001=ooooo`;o0000Aoooool2o`0001kooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo03Kooooo0_l00016ooooo`;o0000
Y_ooool3o`0001kooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo
00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo01Sooooo0_l0001Qooooo`;o
000000?oooooo`000?l000004Oooool2o`00017ooooo0_l00013ooooo`;o0000>oooool2o`0001oo
oooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`?o
00006?ooool2o`0004Oooooo0_l0000Hooooo`;o00005?ooool2o`00017ooooo0_l00013ooooo`;o
0000?Oooool2o`0001gooooo0003ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So
8B4Qonk^kP06ooooo`03o`000?oooooooooo02cooooo0_l0000cooooo`;o0000F?ooool2o`0001Wo
oooo0_l0001@ooooo`;o00007Oooool000?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0;?ooool2o`0006Wooooo0_l0000Rooooo`;o
00006Oooool2o`0002[ooooo0_l00013ooooo`000oooool01Ol@413ooooooooooooooooo410@00oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Gooooo`;o00001_ooool2o`0002Co
oooo0_l0000kooooo`;o0000@oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`2Oooooo`Co00008_ooool2o`00
02Oooooo0_l0001Gooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo00_ooooo0_l0001Nooooo`;o0000<Oooool2
o`000003ooooool0003o000001gooooo0_l0000/ooooo`;o0000Eoooool001kooooo00?o0000oooo
ooooool02oooool2o`0000[ooooo0_l0000;ooooo`;o0000AOooool2o`00027ooooo0_l0000>oooo
o`;o00008?ooool2o`0008Gooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0000;ooooo`;o
0000J?ooool2o`0009Gooooo0_l0000Pooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o0000
ooooool7ooooo`;o00008?ooool001kooooo00?o0000ooooooooool02Oooool2o`0001;ooooo0_l0
001Yooooo`;o00002oooool2o`000;3ooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l00002
ooooo`;o0000J?ooool2o`0000oooooo0_l0000;ooooo`;o0000A?ooool2o`0002;ooooo0_l00016
ooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o0000E_ooool2o`00013ooooo0_l0000Foooo
o`;o0000=?ooool2o`0001Cooooo0_l00004ooooo`;o00007?ooool2o`0004Kooooo000Nooooo`03
o`000?oooooooooo06Gooooo0_l0000Xooooo`;o0000=?ooool2o`0001Oooooo0_l000000ooooooo
0000o`00000aooooo`;o0000<Oooool001kooooo00?o0000ooooooooool0g_ooool2o`0003Cooooo
0_l0000aooooo`007_ooool00ol0003oooooooooo`04ooooo`;o0000Moooool2o`000<Sooooo000N
ooooo`03o`000?oooooooooo00Cooooo0_l0000:ooooo`;o0000Joooool2o`0000;ooooo0_l0001h
ooooo`;o0000B_ooool001kooooo00?o0000ooooooooool03?ooool2o`0000;ooooo0_l0001_oooo
o`;o0000<Oooool2o`00027ooooo0_l0000Rooooo`;o0000B_ooool001kooooo0_l0000;ooooo`Co
0000Y_ooool2o`00027ooooo0_l0000Mooooo`?o0000C_ooool001kooooo00?o0000ooooooooool0
2_ooool2o`00013ooooo0_l0000Booooo`;o0000<oooool2o`0003Wooooo0_l0001Dooooo`?o0000
@_ooool2o`0000;ooooo0_l00006ooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o00003ooo
ool2o`0001;ooooo0_l0000cooooo`;o0000;_ooool2o`0000Wooooo0_l0000jooooo`;o0000GOoo
ool2o`0000;ooooo0_l00006ooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o0000Foooool2
o`0002_ooooo0_l00015ooooo`;o00006?ooool2o`0004oooooo000Nooooo`03o`000?oooooooooo
00Oooooo0_l0000Sooooo`;o0000>_ooool2o`0003Sooooo0_l0001Booooo`;o0000=_ooool2o`00
01Oooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0000Iooooo`;o00002?ooool2o`0007Co
oooo0_l00027ooooo`;o000000?oooooo`000?l000005oooool001kooooo00?o0000ooooooooool0
8_ooool2o`0007Wooooo0_l0002<ooooo`;o00006_ooool001kooooo00?o0000ooooooooool08ooo
ool2o`00013ooooo0_l00005ooooo`;o00005oooool2o`00047ooooo0_l00003ooooo`;o0000@ooo
ool2o`0006?ooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0000@ooooo`;o00002oooool2
o`00013ooooo0_l00005ooooo`;o00005oooool2o`00047ooooo0_l0000kooooo`;o00002oooool2
o`0006?ooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0000@ooooo`;o0000ZOooool2o`00
01;ooooo0_l0000<ooooo`;o00004_ooool2o`0004kooooo000Nooooo`03o`000?oooooooooo043o
oooo0_l00008ooooo`;o0000MOooool2o`00023ooooo0_l0000Booooo`;o00006Oooool2o`0003?o
oooo000Nooooo`03o`000?oooooooooo043ooooo0_l00008ooooo`;o00008_ooool2o`0002Wooooo
0_l00013ooooo`;o0000<_ooool2o`0003?ooooo000Nooooo`03o`000?oooooooooo01gooooo0_l0
000@ooooo`Co0000>oooool2o`0000Kooooo0_l0000Qooooo`;o0000@oooool2o`0002_ooooo0_l0
000jooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o00004?ooool4o`0002;ooooo0_l0000O
ooooo`;o0000Toooool2o`0003[ooooo000Nooooo`03o`000?oooooooooo00[ooooo1?l0000eoooo
o`;o00004?ooool2o`0003?ooooo0_l0001hooooo`;o00006Oooool2o`0001Oooooo0_l0000=oooo
o`007_ooool00ol0003oooooooooo`0:ooooo`Co00009oooool2o`0000cooooo0_l0000_ooooo`;o
00005?ooool2o`0007Sooooo0_l0000Iooooo`;o00005oooool2o`0000gooooo000Nooooo`;o0000
5Oooool2o`0001oooooo0_l0000mooooo`;o00002_ooool2o`00043ooooo0_l00023ooooo`007_oo
ool00ol0003oooooooooo`0Aooooo`;o000000?oooooo`000?l000002?ooool2o`00063ooooo0_l0
0010ooooo`;o0000Poooool001kooooo00?o0000ooooooooool04Oooool2o`0000?ooooo0_l00006
ooooo`;o00003?ooool2o`00023ooooo0_l0002`ooooo`;o0000AOooool001kooooo00?o0000oooo
ooooool03?ooool2o`0000Sooooo0_l0000Dooooo`;o00008?ooool2o`000:kooooo1?l0000hoooo
o`;o00002oooool001kooooo00?o0000ooooooooool03?ooool2o`0000kooooo0_l0003Pooooo`;o
00003_ooool2o`0000Kooooo0_l0000Rooooo`;o000000?oooooo`000?l000002?ooool001kooooo
00?o0000ooooooooool07?ooool2o`0002oooooo0_l0000Gooooo`;o00001oooool2o`0009gooooo
0_l00006ooooo`;o00005oooool2o`0000cooooo0_l00008ooooo`007_ooool00ol0003ooooooooo
o`0Looooo`;o00008?ooool2o`0000gooooo0_l0000Gooooo`;o00001oooool2o`0000Cooooo0_l0
0003ooooo`;o00005?ooool2o`0005Oooooo0_l00014ooooo`;o00005_ooool001kooooo00?o0000
ooooooooool07?ooool2o`0000?ooooo0_l0000Kooooo`;o00003Oooool2o`0001Sooooo0_l0000<
ooooo`;o00000oooool2o`0001Cooooo0_l0001Gooooo`;o0000Coooool2o`0000_ooooo000Noooo
o`03o`000?oooooooooo01;ooooo0_l00008ooooo`;o00000oooool2o`0004Cooooo0_l00008oooo
o`;o0000E?ooool2o`0000Gooooo0_l0001Zooooo`;o00002oooool001kooooo00?o0000oooooooo
ool04_ooool2o`0002oooooo0_l0000Wooooo`;o000000?oooooo`000?l000000_l0001Dooooo`;o
00001Oooool2o`0005oooooo0_l0000Fooooo`007_ooool00ol0003oooooooooo`0booooo`;o0000
3oooool2o`0002Oooooo0_l000000ooooooo0000o`00002aooooo`;o00002oooool2o`0001Kooooo
000Nooooo`03o`000?oooooooooo00Kooooo0_l000000ooooooo0000o`00000Wooooo`;o0000JOoo
ool2o`0008?ooooo0_l0000Sooooo`007_ooool00ol0003oooooooooo`06ooooo`;o000000?ooooo
o`000?l00000T_ooool2o`000:Sooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool09?ooool2o`000?oooooo1_ooool2o`0001[ooooo000Nooooo`03o`00
0?oooooooooo01;ooooo0_l00004ooooo`;o00000oooool2o`0000Gooooo0_l0000:ooooo`;o0000
2_ooool2o`0001cooooo0_l00002ooooo`;o00003?ooool2o`0004Oooooo0_l0001dooooo`;o0000
6_ooool001kooooo0_l0000Cooooo`;o00001?ooool2o`0000?ooooo0_l00008ooooo`;o00001ooo
ool2o`0000[ooooo0_l0000Looooo`;o00000_ooool2o`0000cooooo0_l0000Looooo`;o0000:Ooo
ool2o`00043ooooo0_l0001>ooooo`007_ooool00ol0003oooooooooo`0Wooooo`;o00001oooool2
o`0000?ooooo0_l0000Fooooo`;o0000>oooool2o`0006_ooooo0_l0000Sooooo`;o0000:Oooool0
01kooooo00?o0000ooooooooool02_ooool2o`0000gooooo0_l0000Eooooo`;o00000oooool2o`00
01Kooooo0_l0000Rooooo`;o0000A?ooool2o`0000cooooo0_l0001Eooooo`;o0000:Oooool001ko
oooo00?o0000ooooooooool02_ooool2o`0000gooooo0_l0000Nooooo`;o00001Oooool3o`0002ko
oooo0_l00014ooooo`;o00003?ooool2o`0006?ooooo0_l0000Kooooo`007_ooool00ol0003ooooo
ooooo`0iooooo`;o00001Oooool3o`0001kooooo0_l0000Qooooo`;o0000Y?ooool2o`0001_ooooo
000Nooooo`03o`000?oooooooooo04Cooooo0_l0000Kooooo`;o00002_ooool2o`0001Gooooo0_l0
000Hooooo`;o00006oooool2o`0001Sooooo0_l0001?ooooo`;o00007oooool001kooooo00?o0000
ooooooooool0<oooool2o`0000oooooo0_l0000Wooooo`;o0000;oooool2o`0001_ooooo0_l0000H
ooooo`;o0000Coooool2o`0001oooooo000Nooooo`03o`000?oooooooooo03?ooooo0_l0001Eoooo
o`;o00007Oooool2o`0007Oooooo0_l0000Sooooo`007_ooool00ol0003oooooooooo`1looooo`;o
00003?ooool2o`0000cooooo0_l0000?ooooo`;o0000Moooool2o`0002?ooooo000Nooooo`03o`00
0?oooooooooo07cooooo0_l0000Jooooo`;o0000S_ooool2o`0001gooooo000Nooooo`03o`000?oo
oooooooo01_ooooo0_l0003mooooo`;o00003?ooool2o`0001gooooo000Nooooo`03o`000?oooooo
oooo01_ooooo0_l0001gooooo`;o0000G_ooool2o`0002Cooooo0_l0000[ooooo`007_ooool00ol0
003oooooooooo`0Pooooo`;o0000L_ooool2o`0005kooooo0_l0001Aooooo`007_ooool00ol0003o
ooooooooo`05ooooo`;o00002Oooool2o`0000kooooo0_l0000Zooooo`;o0000^?ooool2o`0003oo
oooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413o
ooooooooo`04ooooo`03o`000?oooooooooo00Gooooo0_l00009ooooo`;o00001_ooool2o`0002?o
oooo0_l0000=ooooo`;o00009oooool2o`0006oooooo0_l0000Nooooo`;o0000?oooool000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo0_l0000@ooooo`;o00008oooool2o`0003Kooooo0_l0001_ooooo`;o
0000Goooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool3o`0000Ko
oooo0_l0000Fooooo`;o0000=?ooool2o`000?7ooooo0003ooooo`05o`000?ooooooooooooooool0
00002oooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo00Gooooo0_l0000Goooo
o`;o0000;?ooool2o`0000Kooooo0_l0000Vooooo`;o0000bOooool000?ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool01Oooool2
o`0004Gooooo0_l0000^ooooo`;o0000bOooool000?ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0EOooool2o`0000Gooooo0_l0000>
ooooo`;o00001oooool2o`0000oooooo0_l0001Kooooo`;o0000H_ooool000?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0?Oooool2
o`0000Wooooo0_l0000;ooooo`;o00001Oooool2o`0000Kooooo0_l00006ooooo`;o00001oooool2
o`0000oooooo0_l0001Kooooo`;o00006Oooool2o`0001Wooooo0_l0000Qooooo`;o00002Oooool0
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000
ooooooooool07?ooool2o`0000kooooo0_l0000?ooooo`;o00002Oooool2o`0001[ooooo0_l00019
ooooo`;o0000COooool2o`0000kooooo0_l00009ooooo`;o00008Oooool2o`0000Wooooo000Noooo
o`03o`000?oooooooooo01cooooo0_l0000>ooooo`;o0000POooool2o`00017ooooo0_l0000loooo
o`;o00003?ooool2o`0003Oooooo000Nooooo`03o`000?oooooooooo0<;ooooo0_l0000looooo`;o
0000;_ooool2o`0001Gooooo000Nooooo`03o`000?oooooooooo04oooooo0_l0000Pooooo`;o0000
[_ooool2o`0000gooooo0_l0000Eooooo`007_ooool00ol0003oooooooooo`1?ooooo`;o00008?oo
ool2o`00087ooooo0_l0000[ooooo`;o00009?ooool001kooooo00?o0000ooooooooool0J?ooool2
o`0008[ooooo0_l0001Aooooo`007_ooool00ol0003oooooooooo`1>ooooo`;o00006?ooool2o`00
0=gooooo000Nooooo`03o`000?oooooooooo01_ooooo0ol0000`ooooo`;o0000moooool001kooooo
00?o0000ooooooooool06oooool3o`0001?ooooo0_l00016ooooo`;o0000c?ooool001kooooo00?o
0000ooooooooool0<Oooool2o`00017ooooo0_l0000cooooo`;o0000c?ooool001kooooo00?o0000
ooooooooool01Oooool2o`0000_ooooo0_l0000Pooooo`;o00003_ooool2o`0006Oooooo0_l0001c
ooooo`;o00008oooool001kooooo00?o0000ooooooooool01Oooool2o`0000_ooooo0_l0000Poooo
o`;o0000Moooool2o`0007?ooooo0_l0000Sooooo`007_ooool2o`0003_ooooo0_l00009ooooo`;o
0000coooool2o`0002oooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0000fooooo`;o0000
2Oooool2o`0004Gooooo0_l00021ooooo`;o00001Oooool2o`0002oooooo000Nooooo`;o00000ooo
ool2o`0003[ooooo0_l0000Xooooo`;o00008_ooool2o`0001gooooo1?l0001Pooooo`;o0000=_oo
ool001kooooo0_l0000hooooo`;o00001Oooool2o`0002Sooooo0_l00011ooooo`Co0000V?ooool0
01kooooo00?o0000ooooooooool0=oooool2o`0001_ooooo0_l0000Vooooo`;o0000bOooool001go
oooo0_l0000Kooooo`;o0000>Oooool2o`0002Kooooo0_l0000Hooooo`;o0000[oooool001gooooo
0_l0000Kooooo`;o000000?oooooo`000?l000006_ooool2o`0000kooooo0_l0001;ooooo`?o0000
:_ooool2o`0002_ooooo0_l0001Fooooo`007_ooool00ol0003oooooooooo`0Looooo`;o00006_oo
ool2o`0000kooooo0_l0000Mooooo`;o0000;?ooool2o`0002_ooooo0_l0000[ooooo`;o00002Ooo
ool2o`0004_ooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0001Nooooo`;o0000TOooool2
o`0000_ooooo0_l0000nooooo`007_ooool00ol0003oooooooooo`07ooooo`;o00003_ooool2o`00
0>kooooo0_l0000Qooooo`;o00006oooool001kooooo00?o0000ooooooooool05oooool2o`0002Wo
oooo0_l0000Mooooo`;o00000_ooool2o`0002gooooo0_l00023ooooo`;o00003oooool2o`0001_o
oooo000Nooooo`03o`000?oooooooooo04;ooooo0_l00005ooooo`;o00005_ooool2o`0000;ooooo
0_l0000Zooooo`;o000000?oooooo`000?l000001oooool2o`0000[ooooo0_l0001^ooooo`;o0000
7_ooool2o`0000cooooo000Nooooo`03o`000?oooooooooo013ooooo0_l00004ooooo`;o0000<Ooo
ool2o`0000kooooo0_l0000Aooooo`;o000000?oooooo`000?l000008?ooool2o`0000[ooooo0_l0
000:ooooo`;o0000S_ooool2o`0000cooooo000Nooooo`03o`000?oooooooooo013ooooo0_l00004
ooooo`;o0000@Oooool2o`00017ooooo0_l000000ooooooo0000o`00000Eooooo`;o0000=?ooool2
o`0004Wooooo0_l00008ooooo`;o00001Oooool2o`0002gooooo000Nooooo`03o`000?oooooooooo
07Oooooo0_l0000=ooooo`;o0000;Oooool2o`0000;ooooo0_l000000ooooooo0000o`00000ooooo
o`;o00002?ooool2o`0000Sooooo0_l00005ooooo`;o0000;Oooool001kooooo00?o0000oooooooo
ool0Moooool2o`0003cooooo0_l00002ooooo`;o0000@_ooool2o`0004Sooooo000Nooooo`;o0000
=?ooool2o`0005cooooo0_l0002dooooo`007_ooool00ol0003oooooooooo`06ooooo`;o00001_oo
ool2o`0002?ooooo0_l0000@ooooo`;o0000;Oooool2o`0001_ooooo0_l0001cooooo`;o0000?ooo
ool001kooooo00?o0000ooooooooool01_ooool2o`0000Kooooo0_l0000Wooooo`;o00003?ooool2
o`0002gooooo0_l0002@ooooo`;o0000?oooool001kooooo00?o0000ooooooooool0=oooool2o`00
0?oooooo3oooool001kooooo00?o0000ooooooooool05Oooool2o`000>Oooooo0_l0000Qooooo`;o
00009?ooool001kooooo00?o0000ooooooooool05Oooool2o`0000Sooooo0_l0001@ooooo`;o0000
Eoooool2o`0003;ooooo0_l00007ooooo`;o00006?ooool2o`0001Cooooo0_l0000>ooooo`007_oo
ool00ol0003oooooooooo`0Oooooo`;o0000D?ooool2o`0000_ooooo0_l00009ooooo`;o0000?ooo
ool2o`0002Kooooo0_l0000Cooooo`;o00005_ooool2o`0001Kooooo0_l0000>ooooo`007_ooool0
0ol0003oooooooooo`1nooooo`;o00002Oooool2o`00067ooooo0_l00004ooooo`;o00006oooool2
o`0000kooooo0_l0000>ooooo`;o00005_ooool001kooooo00?o0000ooooooooool0QOooool2o`00
06Gooooo0_l0000Qooooo`;o00007_ooool2o`0001Kooooo000Nooooo`03o`000?oooooooooo03go
oooo0_l00016ooooo`;o00004Oooool2o`0004gooooo0_l0001=ooooo`;o00003oooool001kooooo
00?o0000ooooooooool0:_ooool2o`00017ooooo0_l0000booooo`;o00009Oooool2o`0003Kooooo
0_l0000Eooooo`;o00009Oooool2o`0002Kooooo0_l0000?ooooo`007_ooool00ol0003ooooooooo
o`0?ooooo`;o00006Oooool2o`0002oooooo0_l0000Dooooo`;o00001Oooool2o`0001Wooooo0_l0
000`ooooo`?o00002?ooool2o`0003Kooooo0_l00004ooooo`;o0000=oooool001kooooo00?o0000
ooooooooool03oooool2o`0004[ooooo0_l0000Kooooo`;o00006Oooool2o`00033ooooo0ol00008
ooooo`;o0000=_ooool2o`0001Oooooo0_l0000Tooooo`007_ooool00ol0003oooooooooo`0Ooooo
o`;o00002Oooool2o`0003gooooo0_l0001Uooooo`;o0000Coooool2o`0002Cooooo000Nooooo`03
o`000?oooooooooo01oooooo0_l00009ooooo`;o0000?Oooool2o`0000kooooo0_l0003<ooooo`00
7_ooool00ol0003oooooooooo`08ooooo`;o0000;?ooool2o`0001gooooo0_l0000Rooooo`;o0000
3_ooool2o`0002oooooo0_l0002;ooooo`007_ooool2o`0000Wooooo0_l0000/ooooo`;o00007Ooo
ool2o`0003;ooooo0_l0000_ooooo`;o00008oooool2o`0001Gooooo0_l0000<ooooo`;o0000@Ooo
ool001kooooo00?o0000ooooooooool0Goooool2o`0001Sooooo0_l0000Looooo`;o0000A_ooool2
o`0001?ooooo1?l0000<ooooo`;o0000@Oooool001kooooo00?o0000ooooooooool0Goooool2o`00
00gooooo0_l00009ooooo`;o00007?ooool2o`0005_ooooo0_l0001Aooooo`007_ooool00ol0003o
ooooooooo`0`ooooo`;o0000;oooool2o`0000_ooooo0_l0003Gooooo`007_ooool00ol0003ooooo
ooooo`0`ooooo`;o0000;oooool2o`0002_ooooo0_l00012ooooo`?o0000L_ooool001kooooo00?o
0000ooooooooool0S_ooool2o`0004;ooooo0ol0000Jooooo`;o0000E_ooool001kooooo00?o0000
ooooooooool0>_ooool2o`000;?ooooo0_l0001Fooooo`007_ooool00ol0003oooooooooo`0Eoooo
o`;o00008oooool2o`000;?ooooo0_l0000aooooo`;o00002Oooool2o`0001Sooooo000Nooooo`03
o`000?oooooooooo01Gooooo0_l0003Nooooo`;o0000:oooool2o`0000Cooooo0_l00003ooooo`;o
00006?ooool001kooooo00?o0000ooooooooool0@Oooool2o`000:Sooooo0_l00008ooooo`;o0000
<Oooool2o`0001gooooo000Nooooo`03o`000?oooooooooo03gooooo0_l00002ooooo`;o00000_oo
ool2o`0008cooooo0_l0000Fooooo`;o0000@Oooool2o`0001Oooooo000Nooooo`03o`000?oooooo
oooo03gooooo0_l00006ooooo`;o0000:_ooool2o`0001Gooooo0_l00010ooooo`;o00001oooool2
o`0005Wooooo0_l0000Gooooo`007_ooool00ol0003oooooooooo`1_ooooo`Co00005Oooool2o`00
01cooooo0_l0000Rooooo`;o00003_ooool2o`0004cooooo0_l0000Mooooo`007_ooool00ol0003o
ooooooooo`0Eooooo`;o00008oooool2o`0000_ooooo0_l0000Vooooo`;o0000=Oooool2o`0000Oo
oooo0_l0000Booooo`;o00005Oooool2o`0000Kooooo0_l0000Qooooo`;o00008Oooool2o`0001go
oooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0
003o410@olc<c006ooooo`03o`000?oooooooooo01Gooooo0_l0000Sooooo`;o00002oooool2o`00
05[ooooo0_l0000:ooooo`;o00004_ooool2o`0001_ooooo1?l0000Qooooo`;o0000@?ooool000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So
8B4Q00Kooooo00?o0000ooooooooool0=?ooool2o`0006gooooo0_l0000kooooo`;o00001oooool2
o`0000Gooooo0_l0000?ooooo`;o00000_ooool2o`0001Cooooo0_l0000Zooooo`000oooool01Ol@
413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000=?oo
ool2o`0004?ooooo0_l0001^ooooo`;o00001Oooool2o`0000oooooo0_l0000Hooooo`;o00002Ooo
ool2o`0001oooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooo
oonHV9So8B4Q00Kooooo00?o0000ooooooooool0Goooool2o`0001Sooooo0_l0001aooooo`;o0000
>?ooool2o`0001oooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<00Kooooo00?o0000ooooooooool0Foooool2o`0000;ooooo0_l0000Pooooo`;o
0000=oooool2o`0001;ooooo0_l0000Looooo`;o00002_ooool2o`0000oooooo0_l0000looooo`00
0oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003o
ooooooooo`1Kooooo`;o00009?ooool2o`0003Oooooo0_l0000Booooo`;o0000:?ooool2o`0000oo
oooo0_l00008ooooo`;o0000<_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03
omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0B_ooool2o`000:Kooooo0_l0000>ooooo`;o
00003oooool2o`0000?ooooo0_l0000]ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`1:ooooo`;o0000<?ooool2o`00
02?ooooo0_l0001?ooooo`;o00003_ooool2o`0001Cooooo0_l0000]ooooo`007_ooool00ol0003o
ooooooooo`1@ooooo`;o0000:_ooool2o`0001;ooooo0_l0000?ooooo`;o0000>Oooool2o`0006Wo
oooo000Nooooo`03o`000?oooooooooo04Cooooo0_l0000:ooooo`;o00002Oooool2o`0001[ooooo
0_l0000Gooooo`;o0000B_ooool2o`0006Wooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l0
000gooooo`;o00005Oooool2o`0001[ooooo0_l0000Mooooo`;o00002_ooool2o`0001_ooooo0_l0
000Xooooo`;o0000G?ooool001kooooo00?o0000ooooooooool02oooool2o`0008Cooooo0_l00003
ooooo`;o00002?ooool4o`0001_ooooo0_l0000Xooooo`;o00008oooool2o`0002cooooo0_l00009
ooooo`007_ooool00ol0003oooooooooo`0Vooooo`;o00002oooool2o`0005cooooo0_l0000=oooo
o`Co0000J_ooool2o`0001[ooooo0_l0000@ooooo`Co00001oooool001kooooo00?o0000oooooooo
ool09_ooool2o`0000_ooooo0_l0000`ooooo`;o0000:Oooool2o`0004Gooooo0_l0000Pooooo`;o
0000;oooool2o`0001;ooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o0000
D?ooool2o`0001[ooooo0_l0000=ooooo`;o0000AOooool2o`00023ooooo0_l00002ooooo`;o0000
B?ooool001kooooo00?o0000ooooooooool03?ooool2o`0000Gooooo0_l0000Oooooo`;o0000:_oo
ool2o`0001oooooo0_l0000Dooooo`;o0000I?ooool2o`0004Sooooo000Nooooo`03o`000?oooooo
oooo00Cooooo0_l00006ooooo`;o00004Oooool2o`0001?ooooo0_l0000Oooooo`;o00002Oooool2
o`0003Gooooo0_l00010ooooo`;o0000K?ooool001kooooo00?o0000ooooooooool01?ooool2o`00
00Wooooo0_l0000>ooooo`;o0000=?ooool2o`0003Cooooo0_l00009ooooo`;o00009oooool2o`00
01Sooooo0_l0001/ooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o00008?ooool2o`0000Oo
oooo0_l0000Uooooo`;o00007?ooool2o`0000[ooooo0_l00009ooooo`;o00009oooool2o`0008Ko
oooo000Nooooo`;o0000<_ooool2o`0000Oooooo0_l0000Uooooo`;o00007?ooool2o`000<Kooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0:?ooool2
o`0002Cooooo0_l0000^ooooo`;o00005Oooool2o`0000Oooooo0_l0001Zooooo`;o0000<oooool2
o`0000Kooooo000Nooooo`03o`000?oooooooooo02Sooooo0_l0000Tooooo`Co0000;?ooool2o`00
01Gooooo0_l00007ooooo`;o0000:oooool2o`0003cooooo0ol0000cooooo`;o00001_ooool001ko
oooo00?o0000ooooooooool0@Oooool2o`0000gooooo0_l0000cooooo`;o0000A?ooool2o`0003co
oooo0_l0000looooo`007_ooool00ol0003oooooooooo`04ooooo`;o0000>oooool2o`0004;ooooo
0_l0002?ooooo`;o0000;oooool001kooooo00?o0000ooooooooool01?ooool2o`0005Sooooo0_l0
000Oooooo`;o0000UOooool3o`0001Cooooo0_l0000Hooooo`007_ooool00ol0003oooooooooo`1N
ooooo`;o00007oooool2o`0009Kooooo0_l0000Dooooo`;o00006?ooool001kooooo00?o0000oooo
ooooool06Oooool2o`0003;ooooo0_l0001Looooo`;o0000V_ooool001kooooo00?o0000oooooooo
ool06Oooool2o`0003;ooooo0_l0000[ooooo`;o0000;oooool2o`0009[ooooo000Nooooo`03o`00
0?oooooooooo03Cooooo0_l00014ooooo`;o0000boooool001kooooo00?o0000ooooooooool0<Ooo
ool2o`000003ooooool0003o00000=Gooooo0_l0000jooooo`007_ooool00ol0003oooooooooo`0a
ooooo`;o00007oooool2o`000:cooooo0_l00009ooooo`;o00004_ooool2o`0002Kooooo000Noooo
o`03o`000?oooooooooo05;ooooo0_l0000=ooooo`;o0000Qoooool2o`0001Cooooo0_l0000Moooo
o`;o00005_ooool2o`0000kooooo000Nooooo`03o`000?oooooooooo067ooooo0_l0000Sooooo`;o
0000:oooool2o`0001Oooooo0_l0000Looooo`;o00001Oooool2o`0004Cooooo0_l0000>ooooo`00
7_ooool00ol0003oooooooooo`03ooooo`;o0000F?ooool2o`0000Cooooo0_l00008ooooo`;o0000
5oooool2o`0002_ooooo0_l0000Gooooo`;o00008oooool2o`0005Cooooo000Nooooo`;o00001?oo
ool2o`0005Sooooo0_l00004ooooo`;o00002?ooool2o`0005oooooo0_l0001Qooooo`;o00005?oo
ool001kooooo00?o0000ooooooooool03Oooool2o`00057ooooo0_l0000nooooo`;o0000:oooool4
o`0003Oooooo0_l0000Wooooo`;o00001_ooool2o`0000cooooo000Nooooo`03o`000?oooooooooo
00gooooo0_l0001Aooooo`;o0000?_ooool2o`0002_ooooo1?l0000gooooo`;o0000;oooool2o`00
00cooooo000Nooooo`03o`000?oooooooooo0:;ooooo0_l0000Eooooo`;o0000S?ooool001kooooo
00?o0000ooooooooool0?Oooool2o`0006?ooooo0_l0000Eooooo`;o0000S?ooool001kooooo00?o
0000ooooooooool0;oooool2o`0000cooooo0_l00007ooooo`;o00000oooool2o`0003cooooo0_l0
001:ooooo`;o0000L?ooool001kooooo00?o0000ooooooooool0;oooool2o`0000gooooo0_l00006
ooooo`;o00000oooool2o`0003cooooo0_l0001:ooooo`;o00009Oooool2o`0004Wooooo000Noooo
o`03o`000?oooooooooo03kooooo0_l0000Wooooo`;o0000LOooool2o`00023ooooo0_l0000Aoooo
o`;o0000=_ooool001kooooo00?o0000ooooooooool0=?ooool2o`00037ooooo0_l00004ooooo`;o
00008?ooool2o`0004Sooooo0ol0000Sooooo`;o00003_ooool2o`0003Kooooo000Nooooo`03o`00
0?oooooooooo02;ooooo0_l0000@ooooo`;o00001?ooool2o`00037ooooo0_l0000Pooooo`;o0000
B?ooool2o`0002Cooooo0_l00006ooooo`;o0000?_ooool001kooooo00?o0000ooooooooool08_oo
ool2o`0001Kooooo0_l0000Uooooo`;o0000>oooool2o`0006Oooooo0_l0000nooooo`007_ooool0
0ol0003oooooooooo`0looooo`;o00008oooool2o`0003_ooooo0_l0002Wooooo`007_ooool00ol0
003oooooooooo`0looooo`;o00006_ooool2o`0001?ooooo0_l0001:ooooo`;o00002_ooool2o`00
04oooooo0_l0000_ooooo`007_ooool00ol0003oooooooooo`0Tooooo`;o0000<_ooool2o`0001?o
oooo0_l0001:ooooo`;o00001_ooool2o`0000;ooooo0_l0000<ooooo`;o0000@Oooool3o`0002ko
oooo000Nooooo`03o`000?oooooooooo02Cooooo0_l0001[ooooo`;o0000;_ooool2o`00013ooooo
0_l0000fooooo`;o00002_ooool2o`0002kooooo000Nooooo`03o`000?oooooooooo097ooooo0_l0
0008ooooo`;o0000K_ooool2o`0003[ooooo000Nooooo`;o0000G_ooool2o`0000kooooo0_l0000/
ooooo`;o0000J_ooool2o`0002Kooooo0_l0000Fooooo`007_ooool00ol0003oooooooooo`0Ooooo
o`;o0000??ooool2o`0000kooooo0_l0000;ooooo`;o00009?ooool2o`0003kooooo0_l0000Uoooo
o`;o00009_ooool2o`0001Kooooo000Nooooo`03o`000?oooooooooo01oooooo0_l0001Iooooo`;o
00009?ooool2o`0003kooooo0_l0000booooo`;o0000<Oooool001kooooo00?o0000ooooooooool0
oooooolEooooo`;o0000<Oooool001kooooo00?o0000ooooooooool02?ooool2o`000?oooooo?_oo
ool001kooooo00?o0000ooooooooool02?ooool2o`000<oooooo0ol0000gooooo`;o0000<_ooool0
01kooooo00?o0000ooooooooool00oooool2o`0006Oooooo0_l0000Nooooo`;o00003?ooool2o`00
03gooooo0ol0000gooooo`;o0000<_ooool001kooooo00?o0000ooooooooool00oooool2o`0005Go
oooo0_l0000@ooooo`;o00007_ooool2o`0000cooooo0_l0000Aooooo`;o0000B?ooool2o`0000So
oooo0_l0000Gooooo`;o0000:oooool001kooooo00?o0000ooooooooool0F_ooool2o`00057ooooo
0_l00018ooooo`;o00002?ooool2o`0001Oooooo1?l0000Yooooo`007_ooool00ol0003ooooooooo
o`0;ooooo`;o0000BOooool2o`0000;ooooo0_l0002<ooooo`;o00004Oooool2o`0001oooooo0_l0
000Yooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o0000<_ooool3o`0001Cooooo0_l00002
ooooo`;o0000<_ooool2o`0002_ooooo0_l0000[ooooo`;o00004Oooool2o`0004[ooooo000Noooo
o`03o`000?oooooooooo00Sooooo0_l00009ooooo`;o0000:_ooool3o`0000kooooo0_l0000loooo
o`;o00004?ooool2o`0000Sooooo0_l0000<ooooo`;o000000?oooooo`000?l00000:_ooool2o`00
04Oooooo0_l0000Eooooo`007_ooool00ol0003oooooooooo`08ooooo`;o00002Oooool2o`0001[o
oooo0_l0000Oooooo`;o0000C_ooool2o`0000Sooooo0_l0000<ooooo`;o0000;Oooool2o`0004Oo
oooo0_l0000Eooooo`007_ooool00ol0003oooooooooo`0_ooooo`;o0000NOooool3o`0009[ooooo
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o
8B4Qolc<c006ooooo`03o`000?oooooooooo0:[ooooo0ol0000`ooooo`;o0000C?ooool2o`0001?o
oooo0_l00005ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0Looooo`;o0000:oooool2o`00
03Sooooo0_l0001Hooooo`;o00000oooool2o`0004Oooooo0_l0000Cooooo`;o00001Oooool000?o
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3
o`0001Oooooo0_l00003ooooo`;o00004Oooool2o`0001Sooooo0_l00009ooooo`;o0000;Oooool2
o`0000gooooo0_l00002ooooo`;o0000B_ooool2o`0006?ooooo0003ooooo`05o`000?oooooooooo
ooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000ooooooooool05ooo
ool2o`0001Kooooo0_l0000Sooooo`;o0000??ooool2o`0000;ooooo0_l0002_ooooo`000oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`00
0?oooooooooo03Cooooo0_l0000/ooooo`;o0000J?ooool2o`0007Wooooo0003ooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000oooooooo
ool0=?ooool2o`0002cooooo0_l0000gooooo`;o0000;oooool2o`0005Cooooo0_l0000Eooooo`?o
00002oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj
^_l000001_ooool00ol0003oooooooooo`2Kooooo`;o0000QOooool2o`0001Gooooo0ol0000;oooo
o`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06
ooooo`03o`000?oooooooooo01oooooo0_l0001Iooooo`;o0000boooool001kooooo0_l0000Poooo
o`;o0000FOooool2o`0000Sooooo0_l0000mooooo`;o0000<_ooool2o`0001Oooooo0_l0000eoooo
o`007_ooool2o`00033ooooo0_l0001Cooooo`;o0000?Oooool2o`00017ooooo0_l0000Oooooo`;o
00005oooool2o`0003Gooooo000Nooooo`03o`000?oooooooooo02oooooo0_l0001Xooooo`;o0000
>oooool2o`0001oooooo0_l0000Nooooo`;o0000;_ooool001kooooo00?o0000ooooooooool0G_oo
ool2o`0003Wooooo0_l0000<ooooo`;o0000C_ooool2o`0001kooooo0_l00009ooooo`;o00003Ooo
ool2o`0001Cooooo000Nooooo`03o`000?oooooooooo02Gooooo0_l0000[ooooo`;o00002_ooool2
o`0004Oooooo0_l0001iooooo`;o00003Oooool2o`0001Cooooo000Nooooo`03o`000?oooooooooo
01[ooooo0_l00009ooooo`;o00007oooool2o`0000[ooooo0ol0001aooooo`;o0000Ooooool001ko
oooo00?o0000ooooooooool06_ooool2o`0002[ooooo0_l0000;ooooo`;o00002_ooool2o`00043o
oooo0_l0000Sooooo`;o00006_ooool2o`0000_ooooo0_l0001Fooooo`007_ooool00ol0003ooooo
ooooo`12ooooo`;o00006oooool2o`00043ooooo0_l0000oooooo`;o00002oooool2o`0000Cooooo
0_l00007ooooo`;o0000?oooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo013ooooo0_l0
000:ooooo`;o00009?ooool2o`0001;ooooo0_l00007ooooo`;o0000F_ooool2o`0002gooooo0_l0
0009ooooo`;o00001oooool2o`0000cooooo0_l0000Fooooo`;o00006?ooool3o`0000Kooooo000N
ooooo`03o`000?oooooooooo00gooooo0_l000000ooooooo0000o`00000:ooooo`;o0000>?ooool2
o`0000Kooooo0ol0000Qooooo`;o0000:Oooool2o`0000cooooo0_l0000Fooooo`;o00005Oooool2
o`00023ooooo0_l0000Fooooo`;o00006?ooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo
00gooooo0_l00003ooooo`;o0000=oooool2o`00017ooooo0_l0000Rooooo`;o0000:Oooool2o`00
02Cooooo0_l0001booooo`007_ooool2o`0001?ooooo0_l0000Fooooo`;o00007oooool2o`0002Ko
oooo0_l0001^ooooo`;o00001oooool2o`0000?ooooo0_l0001Dooooo`007_ooool00ol0003ooooo
ooooo`0Zooooo`;o00009?ooool2o`00027ooooo0_l000000ooooooo0000o`00000Mooooo`;o0000
C?ooool2o`0000Oooooo0_l00003ooooo`;o00000oooool2o`0000?ooooo0_l0001:ooooo`007_oo
ool00ol0003oooooooooo`12ooooo`;o00003?ooool4o`0002;ooooo0_l0000Iooooo`;o00000_oo
ool2o`0000cooooo0_l0000fooooo`;o00006Oooool2o`0000?ooooo0_l0001:ooooo`007_ooool0
0ol0003oooooooooo`12ooooo`;o00003_ooool2o`0002?ooooo0_l0000Hooooo`;o00004?ooool2
o`0002gooooo0_l00007ooooo`;o00007?ooool2o`00027ooooo0_l0000Yooooo`007_ooool00ol0
003oooooooooo`0Sooooo`;o00008Oooool2o`0001Gooooo0_l0000Hooooo`;o0000=Oooool2o`00
02;ooooo0_l0000Uooooo`;o00002Oooool2o`0001Kooooo0_l0000Yooooo`007_ooool00ol0003o
ooooooooo`0Nooooo`;o00000oooool2o`00027ooooo0_l0000Eooooo`;o0000A_ooool2o`0000Oo
oooo0_l0001Dooooo`;o0000:Oooool2o`0001Kooooo000Nooooo`03o`000?oooooooooo01kooooo
0_l0000]ooooo`;o00007oooool2o`0003Gooooo0_l00028ooooo`;o00005_ooool001kooooo00?o
0000ooooooooool0@Oooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o00005?oo
ool2o`0000Wooooo0_l0003Gooooo`007_ooool00ol0003oooooooooo`11ooooo`;o00000oooool2
o`000003ooooool0003o000001Sooooo0_l0000Cooooo`;o00001Oooool2o`0008;ooooo0_l0000d
ooooo`;o00003?ooool001kooooo00?o0000ooooooooool0N?ooool2o`0000Gooooo0_l000000ooo
oooo0000o`00001<ooooo`;o0000<Oooool2o`0003Cooooo0_l0000<ooooo`007_ooool00ol0003o
ooooooooo`0Jooooo`;o00001Oooool2o`0000_ooooo0_l00014ooooo`;o00003?ooool2o`000003
ooooool0003o000004Wooooo0_l0000Nooooo`;o0000EOooool001kooooo00?o0000ooooooooool0
6_ooool2o`0000Gooooo1?l00009ooooo`;o0000A?ooool2o`0000oooooo0_l0001Oooooo`;o0000
2?ooool2o`0000Kooooo0_l0001=ooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o00008Ooo
ool2o`0009kooooo0_l0000@ooooo`;o0000COooool001kooooo00?o0000ooooooooool0A_ooool2
o`000003ooooool0003o0000023ooooo0_l0000Fooooo`;o0000`_ooool001kooooo00?o0000oooo
ooooool0BOooool2o`0001kooooo1?l00005ooooo`;o00003oooool2o`0001Cooooo0_l0001Noooo
o`;o0000C?ooool001kooooo00?o0000ooooooooool0<Oooool2o`0003Kooooo0_l00007ooooo`;o
00001_ooool2o`0001gooooo0_l00007ooooo`;o0000EOooool2o`0003Sooooo0_l0000Booooo`00
7_ooool2o`0003;ooooo0_l0000oooooo`;o00001_ooool2o`0002Kooooo0_l00015ooooo`;o0000
<Oooool2o`0001Gooooo0_l0000Booooo`007_ooool00ol0003oooooooooo`02o`0003?ooooo0_l0
000kooooo`;o0000MOooool2o`00037ooooo0_l0000Yooooo`007_ooool00ol0003oooooooooo`02
o`0000_ooooo0_l0000Vooooo`;o0000oooooolAooooo`007_ooool00ol0003oooooooooo`0=oooo
o`;o00004oooool2o`0000Oooooo0_l00002ooooo`;o0000V_ooool2o`0001Oooooo0_l0000]oooo
o`;o0000<_ooool001kooooo00?o0000ooooooooool01oooool2o`0001Wooooo0_l00007ooooo`;o
00000_ooool2o`0009Sooooo1?l0000Gooooo`;o00000_ooool3o`00023ooooo0_l00006ooooo`;o
00009oooool2o`0000;ooooo0_l00005ooooo`007_ooool00ol0003oooooooooo`07ooooo`;o0000
Moooool2o`0001Sooooo0_l0000@ooooo`;o00005_ooool2o`0000?ooooo1?l0000Kooooo`?o0000
8?ooool2o`0000[ooooo0_l0000Sooooo`;o00000_ooool2o`0000Gooooo000Nooooo`03o`000?oo
oooooooo04kooooo0_l0000`ooooo`;o00006?ooool2o`00013ooooo0_l0000Fooooo`;o0000DOoo
ool2o`0002kooooo000Nooooo`03o`000?oooooooooo04kooooo0_l0000fooooo`;o0000>oooool2
o`0004Cooooo0_l0000looooo`007_ooool00ol0003oooooooooo`1Sooooo`;o00008Oooool2o`00
03_ooooo0_l0000Eooooo`;o0000:oooool4o`0000cooooo0_l0000^ooooo`007_ooool00ol0003o
ooooooooo`0Booooo`;o00000oooool2o`0004;ooooo0_l00006ooooo`;o0000@oooool2o`00033o
oooo0_l0000Iooooo`;o00004?ooool2o`0000kooooo0_l0000^ooooo`007_ooool00ol0003ooooo
ooooo`0Booooo`;o00000oooool2o`0002cooooo0_l0000Dooooo`;o0000?_ooool2o`0000_ooooo
0_l0001;ooooo`;o0000D?ooool001kooooo00?o0000ooooooooool0;Oooool2o`0000Cooooo0_l0
000@ooooo`;o0000E?ooool2o`0001Cooooo0_l00019ooooo`;o0000BOooool001kooooo00?o0000
ooooooooool0;Oooool2o`0000Cooooo0_l0000^ooooo`;o0000C?ooool3o`0004Sooooo0_l0000`
ooooo`;o00005oooool001kooooo00?o0000ooooooooool00_ooool2o`0005oooooo0_l00018oooo
o`;o00000oooool2o`0006_ooooo0_l00005ooooo`;o00001_ooool2o`0001Oooooo000Nooooo`03
o`000?oooooooooo00;ooooo0ol0001Nooooo`;o0000B?ooool2o`0002?ooooo0_l0001;ooooo`;o
00001Oooool2o`0001oooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0000Dooooo`;o0000
Goooool2o`0003Gooooo0_l0000Oooooo`;o0000Eoooool2o`0001[ooooo000Nooooo`;o00006_oo
ool2o`0005oooooo0ol0000dooooo`;o00001_ooool2o`00073ooooo0_l0000@ooooo`;o00002?oo
ool001kooooo00?o0000ooooooooool0Noooool2o`0003cooooo0_l00002ooooo`;o0000O_ooool2
o`0000Sooooo000Nooooo`03o`000?oooooooooo0;gooooo0_l00028ooooo`007_ooool00ol0003o
ooooooooo`1Jooooo`;o0000?oooool2o`0002_ooooo0_l0000/ooooo`;o0000Coooool001kooooo
00?o0000ooooooooool0??ooool2o`0001cooooo0_l00006ooooo`;o0000=oooool2o`0002_ooooo
0_l0000/ooooo`;o0000Coooool001kooooo00?o0000ooooooooool02_ooool2o`00033ooooo1?l0
000Rooooo`;o00009oooool2o`0007Oooooo0_l00011ooooo`007_ooool00ol0003oooooooooo`0:
ooooo`;o0000<_ooool2o`0004_ooooo0_l0001gooooo`;o0000@Oooool001kooooo00?o0000oooo
ooooool0Ioooool2o`0002[ooooo0_l0001_ooooo`;o0000@Oooool001kooooo00?o0000oooooooo
ool0Ioooool2o`0000Oooooo0_l0000Qooooo`;o00008_ooool2o`0003[ooooo0_l0001Booooo`00
7_ooool00ol0003oooooooooo`0kooooo`;o00001_ooool2o`0002_ooooo0_l00015ooooo`;o0000
1oooool2o`00037ooooo0_l0001Booooo`007_ooool00ol0003oooooooooo`0kooooo`;o00001_oo
ool2o`0003[ooooo0_l000000ooooooo0000o`00000looooo`;o0000:oooool2o`0000[ooooo0_l0
001<ooooo`007_ooool00ol0003oooooooooo`0cooooo`;o0000B_ooool2o`000003ooooool0003o
000002kooooo0_l0000Uooooo`;o00004_ooool2o`0000[ooooo0_l0000Eooooo`;o0000=Oooool0
01kooooo00?o0000ooooooooool0<oooool2o`0007gooooo0_l0000Uooooo`;o00009?ooool2o`00
00oooooo0_l0000eooooo`007_ooool01?l0003oooooooooooooool2o`00013ooooo0_l00008oooo
o`;o0000F_ooool2o`0001Cooooo0_l0000?ooooo`;o00007oooool2o`0000;ooooo0ol0000Xoooo
o`;o00003Oooool2o`0002Sooooo0_l0000Looooo`005?ooool4o`000003oa0@4?oooooooooo00;o
oooo0_l00003ooooo`;o00004?ooool2o`0000Sooooo0_l0000;ooooo`;o0000;Oooool2o`0001ko
oooo0_l0000:ooooo`;o00002?ooool2o`0000Oooooo0_l00006ooooo`;o00007oooool2o`0000;o
oooo0ol0000Xooooo`;o00003Oooool2o`0002Sooooo0_l0000:ooooo`;o00004?ooool001Kooooo
00?o0000ooooooooool01?ooool2o`0002cooooo0_l0000]ooooo`;o00006oooool2o`0000gooooo
0_l0000Aooooo`;o0000Voooool2o`00013ooooo000Fooooo`03o`000?oooooooooo00Gooooo0ol0
001Gooooo`;o00007Oooool2o`000<oooooo000Fooooo`03o`000?oooooooooo05oooooo0_l0003^
ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?oo
ooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005?ooool00omEEEGoIVIVo`00
003ooooooe;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.00551 .20382 Mdot
.34495 .96483 Mdot
.14454 .15337 Mdot
.51504 .91151 Mdot
.22048 .12847 Mdot
.03605 .46001 Mdot
.9614 .28485 Mdot
.09604 .48879 Mdot
.17461 .88266 Mdot
.4025 .01794 Mdot
.59156 .8598 Mdot
.24685 .72902 Mdot
.3689 .25849 Mdot
.57815 .16365 Mdot
.36136 .40039 Mdot
.54992 .51325 Mdot
.60655 .98522 Mdot
.10169 .3148 Mdot
.54731 .03181 Mdot
.04717 .61093 Mdot
.45499 .79612 Mdot
.19316 .09609 Mdot
.1728 .26799 Mdot
.03711 .73269 Mdot
.88299 .49391 Mdot
.45068 .5144 Mdot
.83977 .65524 Mdot
.70152 .40741 Mdot
.5886 .88987 Mdot
.23885 .92908 Mdot
.84457 .86507 Mdot
.4831 .0331 Mdot
.63177 .29322 Mdot
.07912 .14893 Mdot
.85277 .40987 Mdot
.75899 .76255 Mdot
.4845 .90401 Mdot
.40015 .61874 Mdot
.07694 .44623 Mdot
.12463 .86405 Mdot
.89555 .15028 Mdot
.32935 .72586 Mdot
.39083 .13382 Mdot
.28976 .19373 Mdot
.96247 .14833 Mdot
.56601 .58861 Mdot
.75842 .00192 Mdot
.49145 .06431 Mdot
.00682 .05005 Mdot
.28804 .98289 Mdot
.06089 .8376 Mdot
.69337 .59014 Mdot
.04158 .97965 Mdot
.02033 .39041 Mdot
.04936 .57385 Mdot
.11327 .93954 Mdot
.73313 .01852 Mdot
.15404 .79796 Mdot
.33949 .36057 Mdot
.18007 .95648 Mdot
.06635 .24863 Mdot
.03089 .84113 Mdot
.22939 .8819 Mdot
.59178 .65841 Mdot
.7984 .39375 Mdot
.26467 .01029 Mdot
.10277 .96421 Mdot
.59414 .82151 Mdot
.01216 .99261 Mdot
.92503 .19024 Mdot
.92911 .85228 Mdot
.10639 .50484 Mdot
.08082 .53416 Mdot
.47318 .65177 Mdot
.51544 .14122 Mdot
.96042 .15804 Mdot
.13842 .87615 Mdot
.27495 .48871 Mdot
.80756 .5491 Mdot
.19863 .43232 Mdot
.48596 .94832 Mdot
.75233 .87825 Mdot
.20839 .80222 Mdot
.92008 .42691 Mdot
.57573 .72561 Mdot
.94716 .85269 Mdot
.38908 .28502 Mdot
.1734 .75405 Mdot
.53249 .84915 Mdot
.5199 .64088 Mdot
.14225 .80402 Mdot
.71879 .53323 Mdot
.12174 .53869 Mdot
.61262 .35246 Mdot
.294 .30574 Mdot
.22899 .47595 Mdot
.3606 .94452 Mdot
.70511 .30381 Mdot
.61587 .02962 Mdot
.39252 .88995 Mdot
.47598 .46447 Mdot
.74329 .5929 Mdot
.85328 .96913 Mdot
.37001 .42332 Mdot
.46467 .51928 Mdot
.20685 .61036 Mdot
.40493 .88656 Mdot
.79034 .55109 Mdot
.1865 .76531 Mdot
.56302 .82741 Mdot
.19303 .23433 Mdot
.71433 .67781 Mdot
.95268 .34462 Mdot
.37747 .40475 Mdot
.01048 .61595 Mdot
.65095 .76516 Mdot
.21999 .65335 Mdot
.9474 .80324 Mdot
.48632 .47783 Mdot
.51832 .78454 Mdot
.71182 .26232 Mdot
.56901 .32354 Mdot
.04018 .48283 Mdot
.32432 .05981 Mdot
.51288 .5664 Mdot
.19964 .41142 Mdot
.49754 .61178 Mdot
.45308 .89016 Mdot
.75684 .72693 Mdot
.76871 .87894 Mdot
.78259 .95236 Mdot
.99409 .68837 Mdot
.09518 .31586 Mdot
.6966 .81428 Mdot
.36277 .3377 Mdot
.16322 .20335 Mdot
.38502 .88856 Mdot
.03054 .38028 Mdot
.51647 .64412 Mdot
.42369 .96326 Mdot
.17183 .31693 Mdot
.06928 .32732 Mdot
.79878 .90434 Mdot
.93527 .22126 Mdot
.41663 .39797 Mdot
.39557 .66106 Mdot
.49159 .77801 Mdot
.85362 .19702 Mdot
.36935 .33322 Mdot
.10772 .2186 Mdot
.19971 .91887 Mdot
.285 .19726 Mdot
.74006 .10876 Mdot
.78742 .96607 Mdot
.22256 .35478 Mdot
.51185 .47858 Mdot
.38405 .59085 Mdot
.56472 .28782 Mdot
.64796 .59791 Mdot
.06713 .63507 Mdot
.72155 .52439 Mdot
.22175 .89854 Mdot
.97946 .23111 Mdot
.90203 .336 Mdot
.87016 .65578 Mdot
.52024 .71603 Mdot
.01971 .64052 Mdot
.59439 .62601 Mdot
.3172 .54633 Mdot
.97713 .01228 Mdot
.8905 .41193 Mdot
.38971 .18523 Mdot
.43933 .19928 Mdot
.24674 .54943 Mdot
.78625 .49176 Mdot
.71705 .03531 Mdot
.38707 .49652 Mdot
.62695 .7105 Mdot
.45246 .36034 Mdot
.30099 .45231 Mdot
.04193 .27432 Mdot
.87572 .12722 Mdot
.79284 .88943 Mdot
.1719 .3184 Mdot
.76515 .27657 Mdot
.72993 .27585 Mdot
.41229 .23252 Mdot
.30537 .42539 Mdot
.48175 .40352 Mdot
.10028 .48111 Mdot
.37487 .21764 Mdot
.09162 .3799 Mdot
.77586 .60661 Mdot
.13282 .02866 Mdot
.35864 .06595 Mdot
.65006 .05975 Mdot
.44696 .37349 Mdot
.4869 .23119 Mdot
.32653 .42992 Mdot
.04017 .0138 Mdot
.09341 .78092 Mdot
.42734 .21904 Mdot
.04206 .25568 Mdot
.10071 .47361 Mdot
.87447 .69565 Mdot
.38126 .23635 Mdot
.05238 .29624 Mdot
.4287 .48286 Mdot
.38564 .33615 Mdot
.01202 .60311 Mdot
.47195 .25963 Mdot
.65006 .13758 Mdot
.7288 .86306 Mdot
.56494 .45797 Mdot
.33558 .38291 Mdot
.80759 .49318 Mdot
.87068 .92689 Mdot
.15228 .12735 Mdot
.34663 .3299 Mdot
.10194 .90155 Mdot
.84362 .44272 Mdot
.67091 .5848 Mdot
.68788 .71716 Mdot
.74963 .89208 Mdot
.58395 .45686 Mdot
.50502 .79099 Mdot
.96452 .45196 Mdot
.47227 .75466 Mdot
.64875 .84144 Mdot
.57447 .89932 Mdot
.64919 .15608 Mdot
.73781 .95931 Mdot
.18733 .51605 Mdot
.7126 .60198 Mdot
.91583 .45729 Mdot
.64856 .56381 Mdot
.58842 .66498 Mdot
.49111 .02401 Mdot
.36319 .72733 Mdot
.84354 .95148 Mdot
.02569 .89815 Mdot
.78219 .43527 Mdot
.83893 .3344 Mdot
.57553 .34493 Mdot
.19086 .91402 Mdot
.97977 .11362 Mdot
.56703 .08398 Mdot
.99093 .47738 Mdot
.72644 .1748 Mdot
.20978 .66185 Mdot
.83842 .22142 Mdot
.72061 .01066 Mdot
.39553 .61676 Mdot
.69975 .23307 Mdot
.24331 .93648 Mdot
.87256 .27021 Mdot
.69643 .89523 Mdot
.0231 .17241 Mdot
.18045 .12629 Mdot
.22383 .68039 Mdot
.36424 .3529 Mdot
.98329 .5102 Mdot
.27201 .59155 Mdot
.63624 .77678 Mdot
.21437 .49082 Mdot
.66505 .50937 Mdot
.53257 .69556 Mdot
.40631 .78761 Mdot
.58161 .73629 Mdot
.63055 .03342 Mdot
.58155 .9004 Mdot
.90081 .57685 Mdot
.75474 .25763 Mdot
.17108 .86841 Mdot
.30869 .23612 Mdot
.07534 .49381 Mdot
.45356 .30763 Mdot
.02737 .2531 Mdot
.48802 .78466 Mdot
.5059 .23354 Mdot
.42091 .98411 Mdot
.01528 .67174 Mdot
.26036 .00238 Mdot
.8838 .90743 Mdot
.0126 .51855 Mdot
.33027 .64606 Mdot
.65232 .67881 Mdot
.71671 .56853 Mdot
.73582 .87849 Mdot
.00623 .71398 Mdot
.58678 .88079 Mdot
.33588 .14656 Mdot
.56827 .19518 Mdot
.26248 .76282 Mdot
.63206 .63053 Mdot
.27286 .40079 Mdot
.93127 .86291 Mdot
.18617 .46806 Mdot
.91641 .36756 Mdot
.33888 .3283 Mdot
.0518 .65141 Mdot
.89377 .15301 Mdot
.93748 .59557 Mdot
.40835 .53928 Mdot
.5799 .82886 Mdot
.13096 .27837 Mdot
.17385 .59505 Mdot
.50433 .31614 Mdot
.93891 .30403 Mdot
.0194 .4355 Mdot
.46788 .48757 Mdot
.9521 .52223 Mdot
.42486 .48354 Mdot
.51814 .89803 Mdot
.21531 .54479 Mdot
.76069 .96288 Mdot
.39372 .29357 Mdot
.36834 .41214 Mdot
.10391 .51747 Mdot
.34771 .31159 Mdot
.02261 .44261 Mdot
.74271 .65561 Mdot
.18989 .28584 Mdot
.50814 .45356 Mdot
.18897 .62397 Mdot
.47641 .06065 Mdot
.29224 .61871 Mdot
.09588 .30847 Mdot
.90359 .53832 Mdot
.88938 .66775 Mdot
.11421 .1122 Mdot
.37487 .75853 Mdot
.76324 .91871 Mdot
.80574 .6199 Mdot
.11027 .87314 Mdot
.98435 .54582 Mdot
.14235 .61662 Mdot
.9648 .13343 Mdot
.15288 .97054 Mdot
.23569 .3993 Mdot
.69357 .66115 Mdot
.71596 .15581 Mdot
.17633 .18732 Mdot
.24613 .36707 Mdot
.05053 .99902 Mdot
.59707 .28096 Mdot
.60753 .31842 Mdot
.5397 .01956 Mdot
.0459 .92572 Mdot
.78139 .5418 Mdot
.32601 .97747 Mdot
.28404 .83681 Mdot
.95511 .05596 Mdot
.59147 .90557 Mdot
.31259 .16018 Mdot
.25228 .29396 Mdot
.38574 .64511 Mdot
.9629 .74675 Mdot
.15405 .0298 Mdot
.31676 .99811 Mdot
.88399 .08959 Mdot
.47285 .05117 Mdot
.09705 .15462 Mdot
.17688 .34861 Mdot
.84007 .70121 Mdot
.81592 .06145 Mdot
.01095 .04278 Mdot
.08502 .8594 Mdot
.9967 .39753 Mdot
.92035 .79076 Mdot
.29512 .0265 Mdot
.47327 .67846 Mdot
.16498 .99127 Mdot
.03169 .42614 Mdot
.31341 .64677 Mdot
.66064 .13567 Mdot
.77192 .55855 Mdot
.20425 .19642 Mdot
.24582 .34038 Mdot
.78129 .20228 Mdot
.33294 .41331 Mdot
.2814 .65621 Mdot
.27036 .83226 Mdot
.65979 .5572 Mdot
.08649 .16731 Mdot
.8578 .89784 Mdot
.99554 .77719 Mdot
.65342 .26664 Mdot
.83651 .72206 Mdot
.95999 .55194 Mdot
.8837 .94442 Mdot
.71071 .84431 Mdot
.77755 .87967 Mdot
.07495 .25049 Mdot
.79644 .81042 Mdot
.85024 .89256 Mdot
.18068 .12007 Mdot
.4875 .78298 Mdot
.38209 .0997 Mdot
.38082 .0463 Mdot
.24963 .81153 Mdot
.49093 .92683 Mdot
.14413 .80043 Mdot
.33515 .46696 Mdot
.39441 .3819 Mdot
.70515 .62125 Mdot
.48506 .95758 Mdot
.66108 .05137 Mdot
.39838 .25909 Mdot
.90452 .7468 Mdot
.25812 .66609 Mdot
.05412 .49612 Mdot
.33896 .98033 Mdot
.94633 .21104 Mdot
.09863 .50211 Mdot
.29618 .30932 Mdot
.0485 .00931 Mdot
.70386 .28865 Mdot
.4789 .21795 Mdot
.57186 .86306 Mdot
.15225 .47761 Mdot
.47368 .57755 Mdot
.55051 .52128 Mdot
.36946 .55768 Mdot
.43819 .04143 Mdot
.83746 .8825 Mdot
.1552 .79549 Mdot
.07721 .5027 Mdot
.52373 .28743 Mdot
.07768 .8006 Mdot
.85699 .48019 Mdot
.926 .51298 Mdot
.20439 .6684 Mdot
.47963 .36591 Mdot
.81806 .45842 Mdot
.19147 .47575 Mdot
.74452 .25577 Mdot
.73016 .73022 Mdot
.29517 .79422 Mdot
.22572 .03503 Mdot
.07313 .87849 Mdot
.98013 .80521 Mdot
.78673 .00398 Mdot
.44856 .95805 Mdot
.20504 .91048 Mdot
.68351 .12052 Mdot
.86859 .78738 Mdot
.14896 .08315 Mdot
.74423 .02193 Mdot
.31075 .56245 Mdot
.04171 .50244 Mdot
.68129 .11039 Mdot
.74234 .15472 Mdot
.89314 .99295 Mdot
.38584 .59442 Mdot
.94704 .26478 Mdot
.65332 .92247 Mdot
.77371 .02202 Mdot
.06565 .88866 Mdot
.32962 .73653 Mdot
.15339 .32936 Mdot
.31376 .6779 Mdot
.17573 .03289 Mdot
.37585 .85617 Mdot
.17542 .45369 Mdot
.98914 .25479 Mdot
.49811 .18278 Mdot
.4539 .28275 Mdot
.10494 .40007 Mdot
.92795 .99293 Mdot
.43617 .94172 Mdot
.90137 .57946 Mdot
.23078 .55618 Mdot
.04781 .88298 Mdot
.07723 .91246 Mdot
.31382 .48064 Mdot
.4243 .18361 Mdot
.78509 .60521 Mdot
.6385 .33889 Mdot
.15128 .73324 Mdot
.08917 .26006 Mdot
.0891 .3338 Mdot
.36315 .74711 Mdot
.69925 .34147 Mdot
.59753 .00168 Mdot
.29804 .06226 Mdot
.06929 .30052 Mdot
.66868 .10441 Mdot
.2532 .87674 Mdot
.44154 .78062 Mdot
.88289 .83417 Mdot
.7387 .91279 Mdot
.17445 .38751 Mdot
.31951 .01981 Mdot
.80459 .03346 Mdot
.19535 .30714 Mdot
.5474 .97482 Mdot
.02266 .87635 Mdot
.2307 .65626 Mdot
.08088 .99775 Mdot
.72149 .78636 Mdot
.44615 .58838 Mdot
.51102 .2202 Mdot
.03289 .20736 Mdot
.75613 .49688 Mdot
.46832 .06261 Mdot
.35059 .91427 Mdot
.18642 .23349 Mdot
.07945 .72818 Mdot
.12656 .84477 Mdot
.52279 .78288 Mdot
.3571 .32601 Mdot
.23709 .44097 Mdot
.62635 .97273 Mdot
.49096 .89665 Mdot
.96997 .9821 Mdot
.30785 .89226 Mdot
.98684 .65266 Mdot
.51892 .12129 Mdot
.52424 .9035 Mdot
.46713 .62618 Mdot
.30822 .36423 Mdot
.64448 .5299 Mdot
.10808 .60585 Mdot
.83649 .71414 Mdot
.20389 .25973 Mdot
.11555 .35099 Mdot
.73911 .00011 Mdot
.32989 .89216 Mdot
.93064 .6882 Mdot
.61705 .64573 Mdot
.05291 .22605 Mdot
.50784 .41655 Mdot
.41774 .96618 Mdot
.40208 .54353 Mdot
.45453 .65479 Mdot
.18889 .54285 Mdot
.94326 .54682 Mdot
.43297 .59437 Mdot
.84122 .70083 Mdot
.34212 .12798 Mdot
.91008 .32926 Mdot
.57212 .0612 Mdot
.64251 .69598 Mdot
.49349 .22177 Mdot
.70439 .51719 Mdot
.14688 .31433 Mdot
.87732 .4793 Mdot
.89202 .42448 Mdot
.28859 .04766 Mdot
.75762 .1835 Mdot
.30325 .7126 Mdot
.56243 .63176 Mdot
.69699 .81567 Mdot
.60322 .19114 Mdot
.85986 .44848 Mdot
.65781 .17785 Mdot
.47707 .7302 Mdot
.83082 .74766 Mdot
.3035 .01321 Mdot
.85039 .82749 Mdot
.14857 .00226 Mdot
.36271 .18184 Mdot
.24445 .78092 Mdot
.52972 .389 Mdot
.82306 .37102 Mdot
.02278 .93227 Mdot
.25444 .32422 Mdot
.15874 .05139 Mdot
.38002 .04816 Mdot
.42925 .62422 Mdot
.83301 .01677 Mdot
.32409 .55646 Mdot
.87161 .35289 Mdot
.41421 .61111 Mdot
.41763 .01299 Mdot
.70198 .91238 Mdot
.52607 .11166 Mdot
.97719 .70063 Mdot
.70316 .18101 Mdot
.23844 .74592 Mdot
.97678 .44024 Mdot
.41644 .50185 Mdot
.23463 .14347 Mdot
.27974 .86581 Mdot
.3254 .42459 Mdot
.33509 .49703 Mdot
.50264 .75442 Mdot
.06315 .33342 Mdot
.03152 .26569 Mdot
.89883 .18144 Mdot
.76149 .32116 Mdot
.72375 .86076 Mdot
.49455 .15958 Mdot
.19649 .55034 Mdot
.69541 .78435 Mdot
.29803 .33395 Mdot
.25243 .87893 Mdot
.11908 .36162 Mdot
.1873 .61837 Mdot
.563 .43438 Mdot
.61391 .68382 Mdot
.28751 .65589 Mdot
.36533 .73781 Mdot
.05998 .49806 Mdot
.2199 .84898 Mdot
.25498 .30741 Mdot
.98076 .81026 Mdot
.10249 .43051 Mdot
.48743 .77324 Mdot
.66152 .56433 Mdot
.45119 .44532 Mdot
.32744 .25482 Mdot
.23071 .45538 Mdot
.59273 .89598 Mdot
.64876 .08836 Mdot
.53796 .98489 Mdot
.82179 .31115 Mdot
.78609 .39676 Mdot
.57445 .11845 Mdot
.36288 .43362 Mdot
.51732 .97166 Mdot
.07595 .8859 Mdot
.69552 .77824 Mdot
.99511 .90745 Mdot
.77802 .7939 Mdot
.93025 .14783 Mdot
.83071 .33947 Mdot
.8181 .47412 Mdot
.394 .10699 Mdot
.38972 .87828 Mdot
.47765 .54195 Mdot
.7284 .72203 Mdot
.28945 .29933 Mdot
.14848 .61088 Mdot
.12752 .64704 Mdot
.14464 .38789 Mdot
.09628 .64063 Mdot
.95691 .78899 Mdot
.50519 .93513 Mdot
.54081 .44614 Mdot
.68132 .75304 Mdot
.51283 .79511 Mdot
.33506 .89533 Mdot
.41016 .85998 Mdot
.93942 .13736 Mdot
.8289 .50921 Mdot
.00662 .46072 Mdot
.71414 .64071 Mdot
.62936 .5065 Mdot
.67119 .39062 Mdot
.50731 .0715 Mdot
.38174 .44132 Mdot
.58397 .83867 Mdot
.27223 .95398 Mdot
.20656 .42688 Mdot
.55864 .02344 Mdot
.83171 .7147 Mdot
.11678 .80154 Mdot
.60373 .00598 Mdot
.32866 .96805 Mdot
.30512 .98804 Mdot
.48668 .24247 Mdot
.29166 .02074 Mdot
.51354 .23147 Mdot
.36387 .20263 Mdot
.7556 .89018 Mdot
.61699 .83447 Mdot
.96462 .34543 Mdot
.27587 .86897 Mdot
.23902 .89211 Mdot
.17264 .34025 Mdot
.28391 .59792 Mdot
.41299 .64713 Mdot
.97277 .88632 Mdot
.22929 .01971 Mdot
.11042 .42943 Mdot
.57612 .77132 Mdot
.66348 .99054 Mdot
.51533 .0373 Mdot
.14586 .15667 Mdot
.72721 .22463 Mdot
.61175 .72071 Mdot
.99838 .37232 Mdot
.90106 .9885 Mdot
.25594 .02226 Mdot
.45735 .27981 Mdot
.20669 .26882 Mdot
.82938 .6067 Mdot
.2278 .3471 Mdot
.81857 .84074 Mdot
.21785 .92362 Mdot
.11958 .91968 Mdot
.35318 .3283 Mdot
.86618 .64319 Mdot
.44045 .59926 Mdot
.68142 .4966 Mdot
.71652 .21611 Mdot
.65091 .74337 Mdot
.56763 .22834 Mdot
.52715 .75625 Mdot
.23447 .42501 Mdot
.20862 .39263 Mdot
.90097 .90495 Mdot
.45993 .76977 Mdot
.34294 .17473 Mdot
.90369 .32489 Mdot
.33788 .18031 Mdot
.99928 .2479 Mdot
.99251 .27372 Mdot
.77648 .89903 Mdot
.72495 .66631 Mdot
.05032 .78809 Mdot
.5733 .97573 Mdot
.32625 .90449 Mdot
.08639 .23732 Mdot
.47742 .89324 Mdot
.9605 .87438 Mdot
.852 .72203 Mdot
.30827 .36742 Mdot
.26791 .34025 Mdot
.12294 .42074 Mdot
.01168 .87344 Mdot
.7121 .08058 Mdot
.42021 .69205 Mdot
.6512 .71041 Mdot
.03982 .3576 Mdot
.98548 .02636 Mdot
.95758 .13192 Mdot
.3368 .50797 Mdot
.97061 .94216 Mdot
.55846 .74363 Mdot
.91981 .09978 Mdot
.91177 .24188 Mdot
.62989 .80204 Mdot
.05058 .76376 Mdot
.93979 .98058 Mdot
.86451 .25126 Mdot
.21218 .82984 Mdot
.20112 .83891 Mdot
.74833 .22684 Mdot
.21724 .67681 Mdot
.5758 .75697 Mdot
.04808 .27086 Mdot
.79872 .19105 Mdot
.34342 .91997 Mdot
.61979 .9405 Mdot
.22688 .71677 Mdot
.85146 .80237 Mdot
.78333 .7633 Mdot
.44843 .25886 Mdot
.32074 .12135 Mdot
.27617 .41164 Mdot
.4832 .96688 Mdot
.37027 .88329 Mdot
.64065 .0294 Mdot
.66542 .9064 Mdot
.80213 .44721 Mdot
.67204 .57747 Mdot
.23988 .58699 Mdot
.04373 .38485 Mdot
.05979 .0183 Mdot
.39129 .57477 Mdot
.54833 .59498 Mdot
.04314 .82305 Mdot
.50375 .62 Mdot
.10968 .39163 Mdot
.19863 .0114 Mdot
.25836 .00231 Mdot
.28672 .1448 Mdot
.83025 .73331 Mdot
.38107 .13023 Mdot
.31534 .82451 Mdot
.97399 .31938 Mdot
.30401 .71517 Mdot
.02562 .28184 Mdot
.75877 .52289 Mdot
.12293 .40584 Mdot
.19706 .88948 Mdot
.25583 .61858 Mdot
.31373 .61845 Mdot
.99415 .59107 Mdot
.03233 .26689 Mdot
.36721 .22597 Mdot
.15458 .58067 Mdot
.83769 .16845 Mdot
.04969 .28124 Mdot
.38104 .49391 Mdot
.70666 .99605 Mdot
.37717 .17739 Mdot
.98481 .97892 Mdot
.56408 .11239 Mdot
.26239 .63058 Mdot
.81917 .61007 Mdot
.9003 .37164 Mdot
.15968 .35345 Mdot
.16274 .09122 Mdot
.08588 .20858 Mdot
.46591 .5469 Mdot
.0605 .25342 Mdot
.37402 .88958 Mdot
.45628 .91679 Mdot
.50474 .7969 Mdot
.04907 .30614 Mdot
.676 .26087 Mdot
.03089 .18969 Mdot
.18811 .33633 Mdot
.28664 .50062 Mdot
.21467 .75507 Mdot
.73774 .49804 Mdot
.32014 .555 Mdot
.96606 .63317 Mdot
.64223 .17731 Mdot
.09117 .72984 Mdot
.73722 .92818 Mdot
.44298 .61318 Mdot
.46272 .494 Mdot
.10957 .31058 Mdot
.76191 .5264 Mdot
.81268 .33629 Mdot
.91662 .57312 Mdot
.57458 .37253 Mdot
.33868 .49845 Mdot
.87127 .00485 Mdot
.64228 .88655 Mdot
.78195 .68706 Mdot
.76878 .13071 Mdot
.27388 .61399 Mdot
.58645 .27751 Mdot
.33487 .71299 Mdot
.44546 .95613 Mdot
.24654 .92401 Mdot
.10583 .07959 Mdot
.21755 .30348 Mdot
.44358 .95324 Mdot
.86383 .72683 Mdot
.90686 .02809 Mdot
.42094 .60382 Mdot
.74987 .29374 Mdot
.72341 .55061 Mdot
.32986 .38768 Mdot
.94654 .13173 Mdot
.81173 .92923 Mdot
.44869 .90401 Mdot
.29382 .11393 Mdot
.62714 .26004 Mdot
.70385 .26331 Mdot
.05693 .06242 Mdot
.41385 .19985 Mdot
.51146 .8091 Mdot
.19146 .09789 Mdot
.25149 .21765 Mdot
.1911 .42357 Mdot
.45962 .30819 Mdot
.09997 .90515 Mdot
.83129 .64085 Mdot
.09468 .34283 Mdot
.82835 .96743 Mdot
.81633 .49459 Mdot
.07244 .86202 Mdot
.28915 .04568 Mdot
.25308 .14097 Mdot
.32359 .30189 Mdot
.75171 .87629 Mdot
.95428 .2676 Mdot
.59208 .20492 Mdot
.40811 .50985 Mdot
.18493 .69219 Mdot
.65395 .84568 Mdot
.12611 .28055 Mdot
.16104 .75758 Mdot
.36096 .1225 Mdot
.45599 .13475 Mdot
.65236 .1507 Mdot
.63443 .30221 Mdot
.29382 .49726 Mdot
.69769 .61407 Mdot
.38617 .12482 Mdot
.80666 .21036 Mdot
.47556 .79853 Mdot
.30148 .8998 Mdot
.93654 .04197 Mdot
.39257 .00738 Mdot
.27085 .63664 Mdot
.53449 .21776 Mdot
.31409 .79155 Mdot
.41937 .53172 Mdot
.61105 .54591 Mdot
.30007 .85427 Mdot
.08334 .29739 Mdot
.19195 .06185 Mdot
.65079 .05383 Mdot
.1229 .26769 Mdot
.5143 .55461 Mdot
.18699 .08537 Mdot
.16666 .60398 Mdot
.04902 .11382 Mdot
.92315 .0702 Mdot
.27611 .74684 Mdot
.45673 .85512 Mdot
.66622 .62348 Mdot
.09924 .23653 Mdot
.07655 .37099 Mdot
.92398 .56753 Mdot
.60264 .47773 Mdot
.13316 .3902 Mdot
.8597 .88877 Mdot
.75734 .44143 Mdot
.34935 .84175 Mdot
.75074 .58277 Mdot
.24224 .65281 Mdot
.88044 .50268 Mdot
.23342 .43019 Mdot
.44654 .18962 Mdot
.27601 .83028 Mdot
.08899 .15902 Mdot
.36274 .67943 Mdot
.92149 .29346 Mdot
.32643 .05469 Mdot
.19172 .47356 Mdot
.55491 .11448 Mdot
.92983 .11755 Mdot
.74957 .83933 Mdot
.8301 .80201 Mdot
.2168 .15342 Mdot
.77801 .28725 Mdot
.16415 .67505 Mdot
.36519 .90178 Mdot
.53869 .74377 Mdot
.8715 .017 Mdot
.60171 .93192 Mdot
.52795 .04124 Mdot
.79482 .57696 Mdot
.73612 .57692 Mdot
.48039 .09445 Mdot
.80834 .68291 Mdot
.8237 .44922 Mdot
.16483 .90552 Mdot
.77979 .98338 Mdot
.36511 .51759 Mdot
.08938 .17136 Mdot
.96757 .04707 Mdot
.8891 .42068 Mdot
.20308 .7171 Mdot
.54879 .58567 Mdot
.56608 .49458 Mdot
.54376 .03254 Mdot
.47875 .12892 Mdot
.24261 .06168 Mdot
.8893 .87363 Mdot
.84218 .6361 Mdot
.77731 .65647 Mdot
.5921 .03598 Mdot
.71903 .80886 Mdot
.14263 .14036 Mdot
.92107 .92859 Mdot
.02215 .16405 Mdot
.13226 .65985 Mdot
.0228 .43377 Mdot
.09205 .01404 Mdot
.98384 .92531 Mdot
.75277 .5589 Mdot
.33987 .23202 Mdot
.17945 .62981 Mdot
.22817 .65294 Mdot
.25002 .3644 Mdot
.90539 .08247 Mdot
.32809 .88549 Mdot
.47466 .31212 Mdot
.1234 .88201 Mdot
.85561 .70781 Mdot
.33944 .33688 Mdot
.36398 .84023 Mdot
.0953 .1342 Mdot
.54196 .58017 Mdot
.272 .7878 Mdot
.31067 .60012 Mdot
.74185 .92305 Mdot
.93773 .77869 Mdot
.86249 .08944 Mdot
.16688 .67937 Mdot
.50161 .15159 Mdot
.97815 .8031 Mdot
.68145 .43307 Mdot
.14979 .23098 Mdot
.44074 .83294 Mdot
.2369 .3746 Mdot
.30444 .4165 Mdot
.01078 .36711 Mdot
.09244 .08456 Mdot
.2541 .79276 Mdot
.74614 .56061 Mdot
.67148 .11366 Mdot
.63619 .72939 Mdot
.29321 .66774 Mdot
.09871 .00729 Mdot
.14384 .87299 Mdot
.22528 .77451 Mdot
.53313 .86024 Mdot
.68871 .69773 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`;o00004?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooo000000;o00002oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool3o`0000oooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`09ooooo`;o00000_ooool01?l0003oooooo`000?l00008oooo
o`;o00000oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo000Nooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool2o`0000kooooo0_l0000@ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooool000000_l0000;ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool02oooool2o`000003ooooool0003ooooo00kooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo1?l0000>ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool01?l0003oooooo`000?l00008oooo
o`;o00000oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo0_l00008oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02oooo
o`007_ooool00ol0003oooooooooo`0<ooooo`;o00003_ooool2o`0003Cooooo0_l0000Xooooo`;o
0000@_ooool2o`0002Cooooo0_l0000_ooooo`;o0000;_ooool001kooooo00?o0000ooooooooool0
3?ooool2o`0002kooooo0_l0000Dooooo`;o00002oooool2o`0002?ooooo0_l0001Pooooo`;o0000
D_ooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0000?ooooo`;o00008?oo
ool2o`00027ooooo0_l0000Sooooo`;o0000QOooool2o`0002gooooo0_l0000;ooooo`007_ooool0
0ol0003oooooooooo`09ooooo`;o00001?ooool2o`0000Wooooo0_l0000Zooooo`;o00007?ooool2
o`0001Wooooo0_l0000Zooooo`;o0000?Oooool2o`0001oooooo0_l0000:ooooo`;o0000;_ooool0
01kooooo00?o0000ooooooooool03oooool2o`0003Gooooo0_l00007ooooo`;o00002_ooool2o`00
00Oooooo0_l0000Iooooo`;o0000:_ooool2o`0003gooooo0_l00002ooooo`;o00001oooool2o`00
01kooooo0_l0000^ooooo`007_ooool00ol0003oooooooooo`1?ooooo`;o00002_ooool2o`0003oo
oooo0_l0000Dooooo`;o0000>_ooool2o`0000Oooooo0_l0001>ooooo`007_ooool00ol0003ooooo
ooooo`0Wooooo`;o0000<oooool2o`0003kooooo0_l0000Dooooo`;o0000Koooool2o`0001Oooooo
0_l00009ooooo`007_ooool00ol0003oooooooooo`0Wooooo`;o00001Oooool2o`0002cooooo0_l0
001@ooooo`;o00005?ooool2o`0000Kooooo0_l0001Eooooo`;o00005oooool2o`0000Wooooo000N
ooooo`03o`000?oooooooooo02kooooo0_l00005ooooo`;o00003_ooool2o`0005;ooooo0_l0000B
ooooo`?o00005?ooool2o`0000?ooooo0_l000000ooooooo0000o`00000cooooo`;o0000A?ooool0
01kooooo00?o0000ooooooooool0=Oooool2o`0000kooooo0_l0001Booooo`;o00002?ooool2o`00
00Sooooo0_l0000=ooooo`;o00002oooool2o`0001[ooooo0_l0000Jooooo`;o0000A?ooool001ko
oooo00?o0000ooooooooool0Xoooool2o`0000?ooooo0_l0000Booooo`;o00009oooool2o`00063o
oooo000Nooooo`04o`000?oooooo0000o`0008Wooooo0_l0000Looooo`;o0000P_ooool2o`0001Wo
oooo000Nooooo`04o`000?oooooo0000o`0005Wooooo0_l0000Looooo`;o00004?ooool2o`000:3o
oooo0_l00008ooooo`;o00003oooool001kooooo0ol0001Jooooo`;o00006oooool3o`000;cooooo
0_l0000?ooooo`007_ooool3o`0002oooooo0_l0000Yooooo`;o00006oooool2o`0001gooooo0_l0
000kooooo`;o0000L_ooool001kooooo00?o0000ooooooooool0;oooool2o`0003Gooooo0_l0000^
ooooo`;o0000=oooool2o`0000;ooooo0_l0001Mooooo`;o00004oooool001kooooo00?o0000oooo
ooooool0IOooool3o`0006Oooooo0_l0001Qooooo`;o00004oooool001kooooo00?o0000oooooooo
ool03_ooool2o`0002[ooooo0_l0000?ooooo`;o00004?ooool2o`0000Kooooo0_l0000]ooooo`;o
000000?oooooo`000?l000007Oooool2o`0001Oooooo0_l0000dooooo`;o0000@?ooool001kooooo
00?o0000ooooooooool03_ooool2o`0002[ooooo0_l0000?ooooo`;o00004?ooool2o`00017ooooo
0_l0000Rooooo`;o000000?oooooo`000?l000000oooool2o`0001Sooooo0_l0001=ooooo`;o0000
@?ooool001kooooo00?o0000ooooooooool0L?ooool2o`0002[ooooo0_l0002Yooooo`007_ooool0
0ol0003oooooooooo`2Qooooo`;o0000QOooool2o`0001gooooo000Nooooo`03o`000?oooooooooo
0:7ooooo0_l00025ooooo`;o00007Oooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`0Nooooo`;o0000`oooool2o`0006;ooooo000Nooooo`03o`000?oo
oooooooo01kooooo0_l0000<ooooo`;o0000Q_ooool2o`0002gooooo0_l0000mooooo`;o00008ooo
ool001kooooo00?o0000ooooooooool06_ooool2o`00013ooooo0_l0000;ooooo`;o0000NOooool2
o`0006cooooo0_l0000Sooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o00007Oooool2o`00
09Cooooo0_l00013ooooo`;o00001Oooool2o`0002[ooooo000Nooooo`03o`000?oooooooooo037o
oooo0_l0002Looooo`;o0000@oooool2o`0000Gooooo0_l0000Zooooo`007_ooool00ol0003ooooo
ooooo`0aooooo`;o00002?ooool2o`0005_ooooo0_l0002]ooooo`007_ooool00ol0003ooooooooo
o`0jooooo`?o0000>oooool2o`0001kooooo0_l0002=ooooo`;o00007_ooool001kooooo0_l0000k
ooooo`;o0000??ooool2o`000:gooooo0_l0000Nooooo`007_ooool00ol0003oooooooooo`3Eoooo
o`;o0000L?ooool001kooooo00?o0000ooooooooool0O?ooool2o`0005Oooooo0_l0000Eooooo`;o
0000FOooool001kooooo00?o0000ooooooooool0O?ooool2o`0002Wooooo0_l0000`ooooo`;o0000
4Oooool2o`0005Wooooo000Nooooo`03o`000?oooooooooo00cooooo0_l0000Cooooo`;o0000>?oo
ool2o`0004[ooooo0_l00007ooooo`;o000000?oooooo`000?l000008Oooool2o`000003ooooool0
003o000005oooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o00004oooool2
o`0003Sooooo0_l0001Cooooo`;o000000?oooooo`000?l000008Oooool2o`0005;ooooo0_l0000>
ooooo`;o00002oooool001kooooo00?o0000ooooooooool0=oooool2o`0002_ooooo0_l0000ooooo
o`;o00004?ooool2o`00027ooooo0_l0001>ooooo`;o00006oooool001kooooo00?o0000oooooooo
ool0=oooool2o`0002_ooooo0_l0000;ooooo`;o0000<_ooool2o`00013ooooo0_l0000Qooooo`;o
0000Joooool001kooooo00?o0000ooooooooool0;Oooool2o`0000Sooooo0_l0000hooooo`;o0000
1_ooool2o`0009kooooo0_l0000/ooooo`007_ooool00ol0003oooooooooo`0]ooooo`;o00002?oo
ool2o`0000_ooooo0_l0000Uooooo`;o00002oooool3o`0001gooooo0_l0001oooooo`;o0000;?oo
ool001kooooo00?o0000ooooooooool0A?ooool2o`0002Gooooo0_l0000;ooooo`;o00007_ooool2
o`0005cooooo0_l0000hooooo`;o000000Coooooo`000?l0003ooooo0_l0000?ooooo`007_ooool0
0ol0003oooooooooo`0Kooooo`;o0000G_ooool2o`0001?ooooo0_l00011ooooo`;o00008Oooool2
o`0003Sooooo0_l000001?oooooo0000o`000?ooool2o`0000oooooo000Nooooo`03o`000?oooooo
oooo01_ooooo0_l0001Nooooo`;o00004oooool2o`0003gooooo0_l00002ooooo`;o0000F?ooool2
o`0001Sooooo000Nooooo`03o`000?oooooooooo02[ooooo0_l0000Rooooo`;o0000Doooool2o`00
02[ooooo0_l0001Looooo`;o00006?ooool001kooooo00?o0000ooooooooool0:_ooool2o`0001co
oooo0_l00004ooooo`;o00002Oooool2o`0004Sooooo0_l0002Rooooo`007_ooool00ol0003ooooo
ooooo`0Fooooo`;o0000<?ooool2o`0000oooooo0_l0000>ooooo`;o0000_oooool2o`0000Wooooo
0_l0000@ooooo`007_ooool2o`0001Oooooo0_l0001Aooooo`;o0000=?ooool2o`0002oooooo0_l0
001=ooooo`;o00002Oooool2o`0000Wooooo0_l0000@ooooo`007_ooool00ol0003oooooooooo`0K
ooooo`;o00003_ooool2o`0001Gooooo0_l0001Kooooo`;o0000;oooool2o`0001_ooooo0_l0000_
ooooo`?o00009_ooool001kooooo00?o0000ooooooooool06oooool2o`0000kooooo0_l0000Eoooo
o`;o0000Roooool2o`0001Cooooo0_l00006ooooo`;o0000;oooool2o`0001Cooooo0_l0000Aoooo
o`007_ooool00ol0003oooooooooo`0Iooooo`;o00004?ooool2o`0003Gooooo0_l0000iooooo`;o
0000<?ooool2o`0001Cooooo0_l0001=ooooo`;o00004Oooool001kooooo00?o0000ooooooooool0
0oooool2o`0001Cooooo0_l00017ooooo`;o0000>Oooool2o`0001Wooooo0_l0002=ooooo`007_oo
ool00ol0003oooooooooo`03ooooo`;o00004oooool2o`0009kooooo0_l0002=ooooo`007_ooool0
0ol0003oooooooooo`0Hooooo`;o0000l_ooool2o`0003Wooooo000Nooooo`03o`000?oooooooooo
00?ooooo0_l0000Dooooo`;o0000lOooool2o`0003Wooooo000Nooooo`03o`000?oooooooooo00?o
oooo0_l0000Dooooo`;o0000D?ooool2o`0007_ooooo0_l0001Mooooo`007_ooool00ol0003ooooo
ooooo`1[ooooo`;o00002_ooool2o`0005Cooooo0_l00003ooooo`;o00005?ooool2o`0005gooooo
000Nooooo`03o`000?oooooooooo06[ooooo0_l00006ooooo`;o00000oooool2o`0002Gooooo0_l0
000]ooooo`;o00000oooool2o`0000cooooo0_l0000nooooo`;o00009Oooool001kooooo00?o0000
ooooooooool0J_ooool2o`0000Kooooo0_l00007ooooo`;o00002Oooool2o`0001Kooooo0_l00010
ooooo`;o00004?ooool2o`0002cooooo0_l0000Uooooo`007_ooool00ol0003oooooooooo`0eoooo
o`;o0000A?ooool2o`0000Wooooo0_l0001Zooooo`;o0000Doooool001kooooo00?o0000oooooooo
ool01_ooool2o`0002gooooo0_l0001Fooooo`;o0000<Oooool2o`0003kooooo0_l0000Wooooo`;o
00007?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Ko
oooo00?o0000ooooooooool01_ooool2o`0005;ooooo0_l0000aooooo`;o00009_ooool2o`0000Wo
oooo0_l0000nooooo`;o00009oooool2o`0001cooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo
03kooooo0_l0000Iooooo`?o0000FOooool2o`0005[ooooo0_l0000dooooo`000oooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool3o`0003kooooo0_l0000Ioooo
o`;o00009oooool2o`0000Oooooo0_l00024ooooo`;o0000=?ooool000?ooooo00Go0000oooooooo
ooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0000aooooo`;o0000?oooool2o`00
00kooooo0_l00007ooooo`;o0000KOooool2o`0004_ooooo0003ooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`05ooooo`?o00001oooool2o`0002Sooooo0_l0000ooooo
o`;o0000B?ooool2o`0003cooooo0_l0001;ooooo`000oooool01Ol@413ooooooooooooooooo410@
00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`;o00003oooool2o`00
0:;ooooo0_l00014ooooo`;o0000@oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`0Hooooo`;o0000j?ooool2
o`0002cooooo0_l0000Eooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0>Gooooo0_l00019ooooo`;o00005Ooo
ool001kooooo00?o0000ooooooooool07oooool2o`0002gooooo0_l0000Vooooo`;o00003oooool2
o`0000oooooo0_l0000@ooooo`;o0000>Oooool2o`00063ooooo000Nooooo`03o`000?oooooooooo
01oooooo0_l0000]ooooo`;o00009_ooool2o`0000oooooo0_l0000?ooooo`;o00000_ooool2o`00
00Cooooo0_l00006ooooo`;o0000H?ooool2o`0001kooooo0_l0000Iooooo`007_ooool00ol0003o
ooooooooo`1cooooo`;o00009oooool2o`0000Cooooo0_l00014ooooo`;o00008_ooool2o`0001ko
oooo0_l0000Iooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o0000I?ooool2o`0003oooooo
0_l0000booooo`;o00001Oooool2o`0005Kooooo000Nooooo`03o`000?oooooooooo00gooooo0_l0
000Nooooo`;o0000>oooool2o`0002kooooo0_l00007ooooo`;o00003oooool2o`0003Wooooo0_l0
0019ooooo`;o00002oooool001kooooo00?o0000ooooooooool0;Oooool2o`0000Wooooo0_l00000
0ooooooo0000o`00000]ooooo`;o00005_ooool2o`0001Kooooo0_l00004ooooo`;o000000?ooooo
o`000?l00000>_ooool2o`0005Wooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`0Hoooo
o`;o00000_ooool2o`0001[ooooo0_l000000ooooooo0000o`00000Sooooo`;o00005_ooool2o`00
00Sooooo0_l0000Looooo`;o0000?Oooool2o`0006Kooooo000Nooooo`03o`000?oooooooooo01So
oooo0_l00002ooooo`;o0000@_ooool2o`0001Kooooo0_l0003=ooooo`007_ooool00ol0003ooooo
ooooo`2Jooooo`;o0000R?ooool2o`00027ooooo000Nooooo`03o`000?oooooooooo09[ooooo0_l0
0028ooooo`;o00008Oooool001kooooo00?o0000ooooooooool04Oooool2o`000003ooooool0003o
00000?oooooo;?ooool2o`0000Cooooo000Nooooo`;o00001_ooool2o`0000Wooooo0ol000000ooo
oooo0000o`00003oooooo`;o0000:_ooool2o`0000Cooooo000Nooooo`03o`000?oooooooooo00Go
oooo0_l00003ooooo`;o00001?ooool2o`0005Cooooo0_l00026ooooo`;o00009Oooool2o`0002Ko
oooo0_l00008ooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o0000<_ooool2o`0002Kooooo
0_l0000<ooooo`;o00001oooool2o`0000oooooo0_l00005ooooo`;o0000Eoooool2o`000003oooo
ool0003o000004[ooooo0_l00008ooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o00008ooo
ool2o`0003Cooooo0_l00007ooooo`;o00003oooool2o`0000Gooooo0_l0000aooooo`;o00003_oo
ool2o`0000Wooooo0_l0000<ooooo`;o0000E?ooool001kooooo00?o0000ooooooooool01_ooool2
o`00017ooooo0_l0002]ooooo`;o00003_ooool2o`0000Oooooo1?l0001;ooooo`;o00005Oooool0
01kooooo00?o0000ooooooooool01_ooool2o`0001cooooo0_l0000>ooooo`;o00002Oooool2o`00
08oooooo0_l0000?ooooo`;o0000COooool4o`0001?ooooo000Nooooo`03o`000?oooooooooo00Ko
oooo0_l00004ooooo`;o00005_ooool2o`0000kooooo0_l00009ooooo`;o0000Soooool2o`0004Ko
oooo0_l0000Hooooo`;o00004oooool001kooooo00?o0000ooooooooool02_ooool4o`000?oooooo
2oooool2o`0002Gooooo0_l00006ooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o0000[ooo
ool2o`0002cooooo0_l0000:ooooo`;o0000B?ooool2o`0000Kooooo000Nooooo`03o`000?oooooo
oooo00cooooo0_l0000Gooooo`?o0000JOooool2o`0002Sooooo0_l000000ooooooo0000o`00000Y
ooooo`;o00002_ooool2o`00053ooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l00006oooo
o`;o00005oooool3o`0006Oooooo1?l0000[ooooo`;o0000Qoooool001kooooo00?o0000oooooooo
ool01?ooool2o`0003Cooooo0_l0000nooooo`;o00004oooool2o`0001Gooooo0_l0001Aooooo`;o
0000>Oooool2o`00017ooooo000Nooooo`03o`000?oooooooooo03[ooooo0_l0000nooooo`;o0000
:_ooool2o`0000_ooooo0_l0000/ooooo`;o00005_ooool2o`0003Wooooo0_l0000Aooooo`007_oo
ool00ol0003oooooooooo`1looooo`;o0000=Oooool2o`0001Cooooo0_l0000Fooooo`;o0000A?oo
ool2o`0001kooooo000Nooooo`03o`000?oooooooooo00gooooo0_l0000oooooo`;o0000;?ooool2
o`0004_ooooo0_l0000Uooooo`;o0000=Oooool2o`0001kooooo000Nooooo`03o`000?oooooooooo
00gooooo0_l00008ooooo`;o0000=Oooool2o`0000[ooooo0_l0002Dooooo`;o0000EOooool001ko
oooo0_l0000Cooooo`;o00000oooool2o`00047ooooo0_l00009ooooo`;o0000Hoooool2o`0007_o
oooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0000_ooooo`;o00005_ooool2o`0000Sooooo
0_l0001Sooooo`;o00005Oooool2o`0004[ooooo0_l0000Hooooo`007_ooool00ol0003ooooooooo
o`0<ooooo`;o00003Oooool2o`0001kooooo0_l00006ooooo`;o00002_ooool2o`0000[ooooo0_l0
000booooo`Co0000C_ooool2o`0004[ooooo0_l0000Hooooo`007_ooool00ol0003oooooooooo`0<
ooooo`;o00003Oooool2o`0000?ooooo0_l0000Iooooo`;o00004_ooool2o`0000_ooooo0_l0000?
ooooo`;o00008?ooool4o`0007Cooooo0_l0000nooooo`007_ooool00ol0003oooooooooo`0Moooo
o`;o000000?oooooo`000?l000002_ooool2o`0002kooooo0_l0000?ooooo`;o00009oooool2o`00
06oooooo0_l0000nooooo`007_ooool00ol0003oooooooooo`0Kooooo`Co00003Oooool2o`0000Ko
oooo0_l0001Pooooo`;o00002?ooool2o`000:Gooooo000Nooooo`03o`000?oooooooooo01_ooooo
0_l0000Gooooo`;o0000J_ooool2o`0001oooooo0_l0000`ooooo`;o0000A?ooool2o`0000cooooo
000Nooooo`03o`000?oooooooooo03Cooooo0_l0000Iooooo`;o0000I?ooool2o`0000[ooooo0_l0
000`ooooo`;o0000A?ooool2o`0000cooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0000k
ooooo`;o00007oooool2o`0004?ooooo0_l0001[ooooo`;o00008oooool001kooooo00?o0000oooo
ooooool04_ooool2o`0001[ooooo0_l0000jooooo`;o000000?oooooo`000?l000000ol0002`oooo
o`Co00008Oooool001kooooo00?o0000ooooooooool04?ooool2o`0001cooooo0_l0000jooooo`;o
000000?oooooo`000?l000000_l00003ooooo`;o0000[_ooool2o`00027ooooo000Nooooo`03o`00
0?oooooooooo013ooooo0_l00007ooooo`;o00007_ooool2o`0002;ooooo0_l0000Eooooo`;o0000
0oooool2o`0008Wooooo0_l00007ooooo`;o00004_ooool2o`0002Cooooo000Nooooo`03o`000?oo
oooooooo01Wooooo0_l0000Nooooo`;o00008_ooool2o`0000_ooooo0_l00006ooooo`;o00001Ooo
ool2o`00053ooooo0_l0000gooooo`;o00001?ooool2o`000003ooooool0003o000001;ooooo0_l0
000Tooooo`007_ooool00ol0003oooooooooo`0Kooooo`;o00005oooool2o`0001Kooooo0_l00005
ooooo`;o00005Oooool2o`0000Kooooo0_l0001Gooooo`;o00004_ooool2o`0002Wooooo0_l0000k
ooooo`007_ooool00ol0003oooooooooo`0Kooooo`;o00005oooool2o`0001Kooooo0_l00005oooo
o`;o0000H_ooool2o`0002Kooooo0_l0001Aooooo`;o000000?oooooo`000?l000004?ooool001ko
oooo00?o0000ooooooooool0=Oooool2o`0000oooooo0_l0001_ooooo`;o0000NOooool2o`000003
ooooool0003o0000013ooooo000Nooooo`;o00008_ooool2o`0001;ooooo0_l0000?ooooo`;o0000
ooooool001kooooo00?o0000ooooooooool08Oooool2o`0000gooooo0_l0000Booooo`;o0000;?oo
ool2o`0004oooooo0_l0001Booooo`;o0000;_ooool001kooooo00?o0000ooooooooool02Oooool2
o`0002Gooooo0_l0000Booooo`;o0000;?ooool2o`0004oooooo0_l0001Booooo`;o0000;_ooool0
01kooooo00?o0000ooooooooool02Oooool2o`0005oooooo0_l0000Sooooo`;o0000]_ooool001ko
oooo00?o0000ooooooooool08oooool2o`0003_ooooo0_l00008ooooo`;o00008oooool2o`000;Ko
oooo000Nooooo`04o`000?oooooo0000o`0002;ooooo0_l0000Wooooo`?o00004Oooool2o`0003Ko
oooo0_l0002]ooooo`007_ooool01?l0003oooooo`000?l0001;ooooo`?o00004Oooool2o`0003Ko
oooo0_l0002<ooooo`;o00007oooool001kooooo00?o0000ooooooooool05Oooool2o`0007Kooooo
0_l0000Xooooo`;o0000C_ooool2o`0001Sooooo0_l00003ooooo`;o00006?ooool2o`0000Gooooo
000Nooooo`03o`000?oooooooooo01Gooooo0_l0000booooo`;o0000@_ooool2o`0002Sooooo0_l0
001>ooooo`;o00006?ooool2o`0001gooooo0_l00005ooooo`007_ooool00ol0003oooooooooo`19
ooooo`;o0000o?ooool001kooooo00?o0000ooooooooool01_ooool2o`0001;ooooo0_l0001Poooo
o`;o0000bOooool001kooooo00?o0000ooooooooool01_ooool2o`0000;ooooo0_l0000>ooooo`;o
0000COooool2o`00017ooooo0_l00039ooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o0000
7oooool2o`0000Sooooo0_l0000`ooooo`Co0000g?ooool001kooooo00?o0000ooooooooool00_oo
ool2o`0001cooooo0_l00005ooooo`;o00000_ooool2o`0000Sooooo0_l0000`ooooo`;o0000?ooo
ool2o`0002cooooo0_l0001_ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`02ooooo`;o00007?oo
ool2o`0000Gooooo0_l0000Gooooo`;o0000I_ooool2o`0002cooooo0_l0000Wooooo`;o0000A_oo
ool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo043ooooo0_l00011ooooo`;o0000M_ooool2o`0000;ooooo0_l0
000oooooo`;o00001Oooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001_oo
ool3o`0001kooooo0_l0000Yooooo`;o00002_ooool2o`0001[ooooo0_l0000@ooooo`;o0000M_oo
ool2o`0004?ooooo0_l00005ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00001oooool00ol0003oooooooooo`0Nooooo`;o0000:Oooool2o`0000[ooooo
0_l0000Jooooo`;o00009_ooool2o`000:cooooo0003ooooo`05o`000?ooooooooooooooool00000
2oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo02Cooooo0_l0001Aooooo`;o
00008?ooool2o`0004Gooooo0_l0001Uooooo`000oooool01Ol@413ooooooooooooooooo410@00co
oooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0Tooooo`;o0000DOooool2o`0006Oo
oooo0_l0000_ooooo`;o0000=?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0?Oooool2o`0001Oooooo0_l0000@ooooo`;o
00002_ooool2o`0009_ooooo0_l0000:ooooo`;o0000:?ooool000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0?Oooool2o`0001Oo
oooo0_l00007ooooo`;o00001oooool2o`0000[ooooo0_l0000[ooooo`;o0000N_ooool2o`0002So
oooo000Nooooo`03o`000?oooooooooo05oooooo0_l00010ooooo`;o0000Y?ooool001kooooo00?o
0000ooooooooool09?ooool2o`000?Oooooo0_l0000Xooooo`007_ooool00ol0003oooooooooo`0T
ooooo`;o00005?ooool2o`0000cooooo0_l0000Eooooo`;o00001Oooool2o`0000cooooo0_l0002W
ooooo`?o00009oooool001kooooo00?o0000ooooooooool01_ooool2o`0003;ooooo0_l00003oooo
o`;o00001oooool2o`0001Gooooo0_l00005ooooo`;o00003?ooool2o`000:Sooooo0_l00007oooo
o`;o00007_ooool001kooooo00?o0000ooooooooool01_ooool2o`0001Gooooo0_l000000ooooooo
0000o`00000Mooooo`;o00001oooool2o`0001cooooo0_l0002oooooo`;o00007_ooool001kooooo
00?o0000ooooooooool00oooool2o`0001Sooooo0_l000000ooooooo0000o`00000Jooooo`;o0000
2_ooool2o`0001cooooo0_l0000:ooooo`;o0000?oooool2o`0002Cooooo0_l0001/ooooo`007_oo
ool00ol0003oooooooooo`02ooooo`?o0000=oooool2o`0003Cooooo0_l0000oooooo`;o00009?oo
ool2o`0001oooooo0_l0001;ooooo`007_ooool00ol0003oooooooooo`02ooooo`;o0000AOooool2
o`000:oooooo0_l0000mooooo`;o00003?ooool001kooooo00?o0000ooooooooool00oooool2o`00
04Cooooo0_l0000]ooooo`;o0000N?ooool2o`0001[ooooo0_l0000Yooooo`;o00003?ooool001ko
oooo00?o0000ooooooooool00oooool2o`00013ooooo0_l0001Qooooo`;o00005Oooool2o`0001_o
oooo0_l00014ooooo`;o00003Oooool2o`0000_ooooo0_l0000gooooo`007_ooool00ol0003ooooo
ooooo`0Eooooo`;o0000N?ooool2o`0001_ooooo0_l0001Cooooo`;o00001Oooool2o`0000Wooooo
0_l0000booooo`007_ooool2o`0005oooooo0_l00011ooooo`;o0000IOooool2o`0000Wooooo0_l0
000Pooooo`;o00004?ooool001kooooo00?o0000ooooooooool0=Oooool2o`00013ooooo0_l0000E
ooooo`;o0000@Oooool2o`0009;ooooo0_l0000@ooooo`007_ooool00ol0003oooooooooo`0eoooo
o`;o00004?ooool2o`0006_ooooo0_l00004ooooo`;o0000B_ooool2o`0001kooooo0_l0000Ooooo
o`007_ooool3o`0000Sooooo0_l0002Zooooo`;o00001?ooool2o`0004[ooooo0_l0000Nooooo`;o
00007oooool001kooooo0ol00008ooooo`;o0000SOooool2o`000:kooooo000Nooooo`03o`000?oo
oooooooo03Sooooo0_l0000_ooooo`;o0000;?ooool2o`000:kooooo000Nooooo`03o`000?oooooo
oooo03Sooooo0_l0000_ooooo`;o0000g?ooool001kooooo00?o0000ooooooooool07Oooool2o`00
01_ooooo0_l0003:ooooo`;o0000?oooool001kooooo00?o0000ooooooooool07Oooool2o`0000ko
oooo0_l0000;ooooo`;o00002_ooool2o`0005;ooooo0_l0000Tooooo`;o0000A?ooool2o`0003Ko
oooo0_l00007ooooo`007_ooool00ol0003oooooooooo`0Looooo`;o00003oooool2o`0000_ooooo
0_l0000:ooooo`;o00006_ooool2o`0003Kooooo0_l00006ooooo`;o00007?ooool2o`00057ooooo
0_l00004ooooo`;o00008oooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0
000Aooooo`;o0000A?ooool2o`0002;ooooo0ol0000Iooooo`;o0000Koooool2o`0000Cooooo0_l0
000/ooooo`007_ooool00ol0003oooooooooo`09ooooo`;o0000Noooool3o`000;kooooo000Noooo
o`03o`000?oooooooooo01_ooooo0_l0000hooooo`;o0000?Oooool2o`000;7ooooo000Nooooo`03
o`000?oooooooooo01_ooooo0_l0000Uooooo`;o00004Oooool2o`0003gooooo0_l0001Vooooo`;o
00001?ooool2o`0004?ooooo000Nooooo`03o`000?oooooooooo00gooooo0_l00005ooooo`;o0000
;?ooool2o`0003Cooooo1?l0000Fooooo`;o00008?ooool2o`0002?ooooo0_l0000Qooooo`;o0000
1?ooool2o`000003ooooool0003o000001Cooooo0_l0000Zooooo`007_ooool00ol0003ooooooooo
o`0=ooooo`Co00000oooool2o`0004Gooooo0_l0000<ooooo`?o00003?ooool4o`0001Kooooo0_l0
000Pooooo`;o00008oooool2o`00017ooooo0_l00004ooooo`;o00004Oooool2o`0001Cooooo0_l0
000Zooooo`007_ooool2o`0000[ooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo0_l0000k
ooooo`Co00003?ooool3o`0001Oooooo0_l0001Wooooo`;o00001?ooool2o`0002Kooooo0_l0000[
ooooo`007_ooool00ol0003oooooooooo`09ooooo`;o00002_ooool2o`0000Gooooo1?l0000ioooo
o`;o0000:?ooool2o`0009Gooooo0_l0000[ooooo`007_ooool00ol0003oooooooooo`0Nooooo`;o
0000BOooool2o`0005gooooo0_l0001mooooo`007_ooool00ol0003oooooooooo`1Yooooo`;o0000
5_ooool2o`0004Gooooo0_l0000:ooooo`;o0000<oooool2o`00037ooooo0_l00009ooooo`007_oo
ool00ol0003oooooooooo`21ooooo`;o00002oooool2o`0001oooooo0_l0000Sooooo`;o0000<ooo
ool2o`0001kooooo0_l0000Aooooo`;o00002Oooool001kooooo00?o0000ooooooooool07_ooool2
o`0001Wooooo0_l0000hooooo`;o00006Oooool2o`0001oooooo0_l0000`ooooo`;o0000A_ooool2
o`0001cooooo000Nooooo`03o`000?oooooooooo00;o00007?ooool2o`0001Wooooo0_l0000hoooo
o`;o00007_ooool2o`0004cooooo0_l0001Tooooo`007_ooool00ol0003oooooooooo`02o`00097o
oooo0_l0000Jooooo`;o0000@_ooool2o`0003cooooo0_l0000Dooooo`007_ooool00ol0003ooooo
ooooo`2_ooooo`;o0000=Oooool2o`0000_ooooo0ol0000kooooo`;o00005?ooool001kooooo00?o
0000ooooooooool0cOooool2o`0001Oooooo0_l0000<ooooo`;o0000DOooool001kooooo00?o0000
ooooooooool0Q?ooool2o`0004Oooooo0_l0000Gooooo`;o0000Goooool001kooooo00?o0000oooo
ooooool05_ooool2o`0006cooooo0_l0001Pooooo`;o0000Goooool001kooooo00?o0000oooooooo
ool05_ooool2o`0000_ooooo0_l0001Looooo`;o0000Woooool2o`0002?ooooo000Nooooo`03o`00
0?oooooooooo02?ooooo0_l0001Looooo`;o00005?ooool2o`00067ooooo0_l0000Vooooo`;o0000
8oooool001kooooo00?o0000ooooooooool0>Oooool2o`0000Oooooo0_l0000kooooo`;o00005_oo
ool2o`00067ooooo0_l00010ooooo`;o00002Oooool001kooooo00?o0000ooooooooool0>Oooool2
o`0000Oooooo0_l0000Oooooo`;o00006_ooool2o`0001;ooooo0_l0000^ooooo`;o0000J_ooool2
o`0000_ooooo0_l00009ooooo`007_ooool2o`0003gooooo0_l0000>ooooo`;o00005Oooool2o`00
02kooooo0_l0000^ooooo`;o00008_ooool2o`0001Cooooo0_l00003ooooo`;o0000:oooool2o`00
00?ooooo0_l0000Aooooo`007_ooool00ol0003oooooooooo`0looooo`;o00003_ooool2o`0001Ko
oooo0_l0000mooooo`;o0000@_ooool2o`0001Cooooo0_l00003ooooo`;o0000<?ooool2o`00017o
oooo000Nooooo`03o`000?oooooooooo04Oooooo0_l0000Kooooo`?o00003Oooool2o`0002gooooo
0_l0000]ooooo`;o0000Loooool001kooooo00?o0000ooooooooool0Aoooool2o`0001cooooo0_l0
000=ooooo`;o0000G?ooool2o`0001[ooooo0_l000000ooooooo0000o`000004ooooo`;o0000C_oo
ool001kooooo00?o0000ooooooooool0HOooool2o`0006cooooo0_l0000Mooooo`;o000000?ooooo
o`000?l000001?ooool2o`0004kooooo000Nooooo`03o`000?oooooooooo067ooooo0_l00010oooo
o`;o0000:_ooool2o`0000;ooooo0_l0001booooo`007_ooool00ol0003oooooooooo`2Sooooo`;o
0000;_ooool2o`00013ooooo0_l00011ooooo`;o00007Oooool001kooooo00?o0000ooooooooool0
iOooool2o`0003oooooo1?l0000Mooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o0000KOoo
ool2o`000:Wooooo0_l0000Oooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o0000KOooool2
o`0001Wooooo0_l0000nooooo`;o00004oooool2o`00017ooooo0_l0000Qooooo`;o00009?ooool0
01kooooo00?o0000ooooooooool0;_ooool2o`0006Kooooo0_l0000Dooooo`;o0000:?ooool2o`00
01?ooooo0_l0000Aooooo`;o00008Oooool2o`0002Cooooo000Nooooo`03o`000?oooooooooo02ko
oooo0_l0001looooo`Co00009_ooool2o`0001Sooooo0_l0001Eooooo`007_ooool00ol0003ooooo
ooooo`1:ooooo`;o0000@Oooool2o`0001oooooo0_l00004ooooo`;o00008?ooool2o`0001Sooooo
0_l0001Eooooo`007_ooool00ol0003oooooooooo`1:ooooo`;o00002?ooool2o`0002?ooooo0_l0
000Booooo`;o00009Oooool2o`0002Oooooo0_l0001Pooooo`;o00001_ooool000?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo
00?o0000ooooooooool0=?ooool2o`0001kooooo0_l0000Sooooo`;o00003_ooool2o`0002?ooooo
0_l0000]ooooo`;o00003oooool2o`0004oooooo0_l00006ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003o
ooooooooo`0dooooo`;o00008_ooool2o`0001oooooo0_l0000>ooooo`;o00008oooool2o`0001oo
oooo0_l0000Mooooo`;o0000?Oooool2o`0001Sooooo0003ooooo`05oa0@4?ooooooooooooooool@
41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0001Hooooo`;o00001oooool2o`00
02Sooooo0_l00012ooooo`;o0000G?ooool2o`0001Sooooo0003ooooo`05o`000?oooooooooooooo
ool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool00_l0000`
ooooo`;o0000;Oooool2o`0002;ooooo0_l00004ooooo`;o0000Eoooool2o`00067ooooo0003oooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o
0000ooooooooool00_l0000Mooooo`;o00004Oooool2o`00057ooooo0_l0001Mooooo`;o00004_oo
ool2o`000003ooooool0003o000000gooooo0_l0000kooooo`000oooool01Ol@413ooooooooooooo
oooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`0Oooooo`;o00007_oo
ool2o`000;Oooooo0_l000000ooooooo0000o`000009ooooo`;o00000_ooool2o`0003_ooooo0003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oo
oooooooo00_ooooo0_l0000Oooooo`;o00004Oooool2o`0004;ooooo0_l00007ooooo`;o00004?oo
ool2o`0006Kooooo0_l0000oooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Co
c<c<odA4A?l0003o410@1_ooool01?l0003oooooo`000?l0000:ooooo`;o00007oooool2o`0002Oo
oooo0_l0000/ooooo`;o00001oooool2o`00013ooooo0_l0000oooooo`;o0000I_ooool001kooooo
00Co0000ooooool0003o0000:Oooool2o`0000gooooo0_l0000Dooooo`;o00001?ooool2o`0000Co
oooo0_l00005ooooo`;o00006?ooool4o`0005oooooo0_l0001Vooooo`007_ooool00ol0003ooooo
ooooo`0Zooooo`;o00003Oooool2o`0001Cooooo0_l0000:ooooo`;o00001Oooool2o`0001Sooooo
1?l0000Pooooo`;o0000?oooool2o`0001oooooo0_l00013ooooo`007_ooool00ol0003ooooooooo
o`0iooooo`;o0000C?ooool2o`0001Oooooo0_l0000booooo`;o00002oooool2o`0001oooooo0_l0
0013ooooo`007_ooool00ol0003oooooooooo`0iooooo`;o0000C?ooool2o`0000_ooooo0_l0000W
ooooo`;o00005Oooool2o`00077ooooo000Nooooo`03o`000?oooooooooo03Kooooo0_l0000Ioooo
o`;o0000@Oooool2o`0001gooooo0_l00008ooooo`;o00002_ooool2o`0007cooooo000Nooooo`03
o`000?oooooooooo03Kooooo0_l0000Iooooo`;o0000H?ooool2o`0001Cooooo0_l0001[ooooo`;o
00003oooool001kooooo00?o0000ooooooooool04_ooool2o`00043ooooo0_l0002hooooo`;o0000
9_ooool2o`0000oooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0000>ooooo`;o00001ooo
ool2o`0003Oooooo0_l0001?ooooo`;o0000?Oooool2o`0002Cooooo0_l00002ooooo`;o0000=ooo
ool001kooooo00?o0000ooooooooool00_ooool2o`0001Oooooo0_l00027ooooo`?o0000?Oooool2
o`0002Cooooo0_l00009ooooo`;o0000<?ooool001kooooo00?o0000ooooooooool09Oooool2o`00
03_ooooo0_l00003ooooo`;o00004?ooool2o`0000Oooooo0_l0000Pooooo`;o00007_ooool2o`00
04oooooo0_l0000`ooooo`007_ooool00ol0003oooooooooo`0Uooooo`;o0000>oooool2o`0000?o
oooo0_l0000@ooooo`;o00001oooool2o`00043ooooo0_l00021ooooo`007_ooool2o`0000kooooo
0_l0000dooooo`;o000000?oooooo`000?l000000oooool2o`0004Wooooo0_l0002Uooooo`;o0000
2?ooool001kooooo00?o0000ooooooooool03Oooool2o`0003Cooooo0_l000001?oooooo0000o`00
0?l00002ooooo`;o00002_ooool4o`0003Gooooo0_l00004ooooo`;o0000EOooool2o`0000[ooooo
0_l0000Booooo`;o00002?ooool2o`0002Cooooo0_l00008ooooo`007_ooool00ol0003ooooooooo
o`17ooooo`;o00003_ooool4o`0003Gooooo0_l0000Zooooo`;o0000;oooool2o`0000[ooooo0_l0
000Booooo`;o00002?ooool2o`0002kooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l0000G
ooooo`;o0000>_ooool2o`0003kooooo0_l0000Oooooo`;o0000J?ooool001kooooo00?o0000oooo
ooooool09oooool2o`0001Oooooo0_l0000jooooo`;o0000?Oooool2o`00023ooooo0_l0001Xoooo
o`007_ooool00ol0003oooooooooo`0nooooo`;o00004?ooool2o`0000Wooooo0_l0001Nooooo`;o
0000:oooool2o`0003?ooooo0_l0000Xooooo`007_ooool01?l0003oooooooooooooool2o`0003_o
oooo0_l0000@ooooo`;o00002Oooool2o`0008_ooooo0_l0000cooooo`;o0000:?ooool001kooooo
00Co0000oooooooooooooooo0_l0003oooooodGooooo000Nooooo`03o`000?oooooooooo037ooooo
0_l0000@ooooo`;o00007Oooool2o`00083ooooo0_l0001Qooooo`007_ooool00ol0003ooooooooo
o`0aooooo`?o00003oooool4o`0001_ooooo0_l0000>ooooo`;o00008_ooool2o`0003Sooooo0_l0
000Booooo`;o0000HOooool001kooooo00?o0000ooooooooool0<_ooool2o`00017ooooo0_l0000[
ooooo`;o00008_ooool2o`0002_ooooo0_l0000;ooooo`;o0000<Oooool2o`0004;ooooo000Noooo
o`03o`000?oooooooooo0<?ooooo0_l0000eooooo`;o00001oooool2o`0004;ooooo000Nooooo`03
o`000?oooooooooo0?[ooooo0_l0000^ooooo`;o00004oooool2o`0000Kooooo000Nooooo`03o`00
0?oooooooooo03Sooooo0_l0001:ooooo`;o0000Y?ooool2o`0001?ooooo0_l00006ooooo`007_oo
ool00ol0003oooooooooo`0hooooo`;o0000B_ooool2o`0002?ooooo0_l0000Rooooo`;o0000BOoo
ool2o`0002gooooo000Nooooo`03o`000?oooooooooo0:Wooooo0_l0000Rooooo`;o00003Oooool2
o`0003[ooooo0_l0000]ooooo`007_ooool2o`000=gooooo0_l0000_ooooo`;o0000:oooool2o`00
00_ooooo000Nooooo`03o`000?oooooooooo0?oooooo3_ooool2o`0002_ooooo0_l0000;ooooo`00
7_ooool00ol0003oooooooooo`3ooooooa?ooooo0_l0000cooooo`007_ooool00ol0003ooooooooo
o`38ooooo`;o00001_ooool2o`00043ooooo0_l0000cooooo`007_ooool3o`0005kooooo0_l00009
ooooo`;o0000GOooool2o`0000Kooooo0_l0000hooooo`Co0000>Oooool001kooooo0ol0000noooo
o`;o00001_ooool2o`0001Kooooo0ol00008ooooo`;o0000>_ooool2o`0003Gooooo0_l0000/oooo
o`Co0000>Oooool001kooooo00?o0000ooooooooool0?_ooool2o`0000Kooooo0_l0000Gooooo`;o
0000A?ooool2o`0001cooooo0_l0000Gooooo`;o0000JOooool001kooooo00?o0000ooooooooool0
`oooool2o`0002Cooooo0_l0000Qooooo`;o00000oooool2o`0003Cooooo000Nooooo`03o`000?oo
oooooooo06Oooooo0_l0001>ooooo`;o0000<?ooool2o`0000Oooooo0_l0000Hooooo`;o00000ooo
ool2o`0000;ooooo0_l0000`ooooo`007_ooool00ol0003oooooooooo`0Fooooo`;o00000_ooool2
o`00033ooooo0_l0000Iooooo`;o00002Oooool2o`0002?ooooo0_l0000Nooooo`;o00004_ooool2
o`0001cooooo0_l00007ooooo`;o00008Oooool2o`00033ooooo000Nooooo`03o`000?oooooooooo
00Sooooo0_l0000<ooooo`;o00000_ooool2o`00017ooooo0_l0000Mooooo`;o00009?ooool2o`00
02?ooooo0_l0000booooo`;o00007?ooool2o`0001oooooo0_l0000kooooo`007_ooool00ol0003o
ooooooooo`08ooooo`;o00008oooool2o`0003Sooooo0_l0001@ooooo`;o0000Coooool2o`0003_o
oooo000Nooooo`03o`000?oooooooooo06Oooooo0_l0000:ooooo`;o0000A?ooool2o`0008cooooo
000Nooooo`03o`000?oooooooooo07?ooooo0_l0003Booooo`007_ooool00ol0003oooooooooo`2[
ooooo`;o00001?ooool2o`0001gooooo0_l0001eooooo`007_ooool00ol0003oooooooooo`19oooo
o`;o00002oooool2o`0001[ooooo0_l0000gooooo`;o00001?ooool2o`0001gooooo0_l0000hoooo
o`;o00005_ooool2o`00017ooooo0_l0000@ooooo`007_ooool2o`0004[ooooo0_l0000;ooooo`;o
00006_ooool2o`0009Kooooo0_l0000Fooooo`;o00004Oooool2o`00013ooooo000Nooooo`03o`00
0?oooooooooo03Cooooo0_l0001Oooooo`;o00002?ooool2o`0003Sooooo0_l0001/ooooo`007_oo
ool00ol0003oooooooooo`0`ooooo`;o00000_ooool2o`0000cooooo0_l0001Aooooo`;o00002?oo
ool2o`0000Kooooo0_l0000>ooooo`;o00008?ooool2o`0006cooooo000Nooooo`03o`000?oooooo
oooo033ooooo0_l0000@ooooo`;o0000<_ooool2o`0002oooooo0_l0000>ooooo`;o0000S_ooool0
01kooooo00?o0000ooooooooool03?ooool2o`0004?ooooo0_l0000Sooooo`;o0000Noooool2o`00
00Kooooo0_l0001:ooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o0000:oooool2o`0001Ko
oooo0_l0001mooooo`;o00008Oooool2o`0000Kooooo0_l0001:ooooo`007_ooool00ol0003ooooo
ooooo`0iooooo`;o0000E_ooool2o`0003gooooo0_l0001eooooo`007_ooool00ol0003ooooooooo
o`2Aooooo`;o00001oooool2o`0001_ooooo0_l0002>ooooo`007_ooool00ol0003oooooooooo`15
ooooo`;o0000Doooool2o`0001_ooooo0_l0002>ooooo`007_ooool00ol0003oooooooooo`15oooo
o`;o0000EOooool2o`0002gooooo0_l0000Aooooo`;o0000COooool2o`00017ooooo0_l00005oooo
o`007_ooool00ol0003oooooooooo`0Jooooo`;o0000;oooool2o`0003kooooo0_l0000?ooooo`;o
0000;Oooool2o`00017ooooo0_l0001=ooooo`;o00004Oooool2o`0000Gooooo000Nooooo`03o`00
0?oooooooooo01[ooooo0_l0000_ooooo`;o0000?_ooool2o`0000gooooo0ol00007ooooo`Co0000
=_ooool2o`0006Oooooo000Nooooo`03o`000?oooooooooo00cooooo0_l00016ooooo`;o0000:_oo
ool2o`0001Sooooo0ol00007ooooo`Co0000=_ooool2o`0000Kooooo0_l0000^ooooo`;o0000;ooo
ool001kooooo00?o0000ooooooooool03?ooool2o`0004Kooooo0_l0000<ooooo`;o00007?ooool2
o`0001kooooo0_l00014ooooo`;o0000;_ooool2o`0000oooooo0_l0000:ooooo`;o00004_ooool0
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<00Kooooo00?o0000ooooooooool0C_ooool2o`0000cooooo0_l00004ooooo`;o0000??oo
ool2o`0005Oooooo0_l0000/ooooo`;o00002_ooool2o`0001;ooooo0003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`00
0?oooooooooo02kooooo0_l0000Nooooo`;o00003?ooool2o`0003;ooooo0_l0000>ooooo`;o0000
00?oooooo`000?l00000E?ooool2o`0004cooooo0003ooooo`05oa0@4?ooooooooooooooool@4100
2oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0000Eooooo`;o00005?ooool2o`000003
ooooool0003o0000063ooooo0_l00004ooooo`;o00002?ooool2o`000003ooooool0003o00000:;o
oooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b
00Kooooo00?o0000ooooooooool05Oooool2o`0000_ooooo0_l00006ooooo`?o00004oooool2o`00
05Cooooo0_l0000aooooo`;o0000?oooool2o`0000Gooooo0_l0000Mooooo`;o00002?ooool2o`00
00_ooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003o
c<c<00Kooooo00?o0000ooooooooool08_ooool2o`0000Kooooo0_l0000Dooooo`;o0000Qoooool2
o`0003oooooo0_l00005ooooo`;o00007Oooool2o`0000Sooooo0ol0000:ooooo`000oooool01Ol@
413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oo
oooooooo0:;ooooo0_l00012ooooo`;o0000Doooool2o`0000[ooooo0003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0
COooool2o`0005?ooooo0_l00012ooooo`;o00005oooool2o`0003[ooooo0_l0000:ooooo`000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03
o`000?oooooooooo04gooooo0_l0002?ooooo`;o00007oooool2o`0004Kooooo000Nooooo`03o`00
0?oooooooooo0=kooooo0_l0001Wooooo`007_ooool00ol0003oooooooooo`2mooooo`;o0000R?oo
ool001kooooo00?o0000ooooooooool02_ooool2o`0005Kooooo0_l0001Iooooo`;o0000R?ooool0
01kooooo00?o0000ooooooooool02_ooool2o`0005Kooooo0_l0001?ooooo`;o0000Foooool2o`00
03Gooooo000Nooooo`03o`000?oooooooooo047ooooo0_l0000Cooooo`;o0000Foooool2o`0000?o
oooo0_l0001Fooooo`;o0000=Oooool001kooooo00?o0000ooooooooool0@Oooool2o`00017ooooo
1?l0000cooooo`;o0000:oooool2o`0000[ooooo0_l0001Eooooo`;o0000:_ooool001kooooo00?o
0000ooooooooool04?ooool2o`0004;ooooo0_l00002ooooo`;o0000<Oooool2o`0003Oooooo0_l0
001Eooooo`;o0000:_ooool001kooooo00?o0000ooooooooool04?ooool2o`0002_ooooo0_l0000I
ooooo`;o00006?ooool2o`0004Kooooo0_l0000dooooo`;o00005?ooool2o`0003oooooo000Noooo
o`03o`000?oooooooooo00Kooooo0_l0000eooooo`;o0000;_ooool2o`0000?ooooo0_l00016oooo
o`;o00004oooool2o`0001oooooo0_l0000Dooooo`;o0000?oooool001kooooo00?o0000oooooooo
ool01_ooool2o`0001gooooo0_l00016ooooo`;o0000H?ooool3o`00017ooooo0_l0001Rooooo`00
7_ooool00ol0003oooooooooo`0Uooooo`;o00007?ooool2o`0006Cooooo0_l0000Uooooo`;o0000
4Oooool2o`0006;ooooo000Nooooo`;o0000A?ooool2o`0006Cooooo0_l0001oooooo`;o00001?oo
ool2o`0001Gooooo000Nooooo`03o`000?oooooooooo05gooooo0_l0000Gooooo`;o00006?ooool2
o`0009Sooooo0_l00004ooooo`;o00005Oooool001kooooo00?o0000ooooooooool06?ooool2o`00
04?ooooo0_l0000Gooooo`;o00006?ooool2o`000;Gooooo000Nooooo`03o`000?oooooooooo01?o
oooo0_l00003ooooo`;o0000Ioooool2o`0002Kooooo0_l0000Aooooo`;o0000:Oooool2o`0005ko
oooo000Nooooo`03o`000?oooooooooo01?ooooo0_l0000?ooooo`;o0000Foooool2o`0002Kooooo
0_l0000;ooooo`;o00001?ooool2o`0002Wooooo1?l0000Sooooo`;o00006oooool2o`0001[ooooo
000Nooooo`03o`000?oooooooooo02Cooooo0_l0000>ooooo`;o00008Oooool2o`0005gooooo0_l0
000aooooo`;o00008oooool2o`0001_ooooo0_l0000Jooooo`007_ooool00ol0003oooooooooo`0d
ooooo`;o00008?ooool3o`000>kooooo000Nooooo`03o`000?oooooooooo00;o00007_ooool2o`00
00Wooooo0_l0000Yooooo`;o0000aOooool2o`0001Gooooo0_l0000Aooooo`007_ooool00ol0003o
ooooooooo`02o`000003ooooool0003o000001_ooooo0_l00007ooooo`Co00008Oooool2o`000:3o
oooo0_l0000[ooooo`;o00005Oooool2o`00017ooooo000Nooooo`03o`000?oooooooooo00?ooooo
0_l0000?ooooo`;o00004oooool2o`0002?ooooo0_l0000[ooooo`;o0000?_ooool2o`0002kooooo
0_l00003ooooo`;o00001?ooool2o`000003ooooool0003o000004cooooo000Nooooo`03o`000?oo
oooooooo00_ooooo0_l00007ooooo`;o00003_ooool2o`0000oooooo0_l0000?ooooo`;o00001_oo
ool2o`0002Cooooo0_l00005ooooo`;o0000?_ooool2o`0002kooooo0_l00003ooooo`;o00001?oo
ool2o`000003ooooool0003o0000017ooooo0_l0000iooooo`007_ooool00ol0003oooooooooo`0;
ooooo`;o00002?ooool2o`0000gooooo0_l0000?ooooo`;o00003oooool2o`0001oooooo0_l0000;
ooooo`;o00002_ooool2o`0004_ooooo0_l0000mooooo`;o0000:_ooool2o`0000gooooo000Noooo
o`03o`000?oooooooooo017ooooo0_l00002ooooo`;o00009Oooool2o`0002Wooooo0_l0000<oooo
o`;o00000_ooool4o`0000?ooooo0_l0000=ooooo`;o0000:_ooool2o`00013ooooo0_l0000Soooo
o`;o00002_ooool2o`0001?ooooo0_l0000Sooooo`;o00003Oooool001kooooo00?o0000oooooooo
ool04Oooool2o`0002Wooooo0_l0000<ooooo`;o00005?ooool2o`0000Gooooo0_l0000<ooooo`;o
00000_ooool4o`0001;ooooo0_l00006ooooo`;o00008_ooool2o`0003?ooooo1?l0000:ooooo`;o
00004?ooool2o`000003ooooool0003o000003;ooooo000Nooooo`03o`000?oooooooooo04[ooooo
0_l0000Dooooo`;o00001Oooool4o`0002cooooo0_l0000Tooooo`;o00007oooool2o`00013ooooo
0_l0000Nooooo`;o0000=Oooool001kooooo00?o0000ooooooooool01?ooool2o`0003kooooo0_l0
000Sooooo`;o0000<Oooool2o`0000Kooooo0_l0000Aooooo`;o00001?ooool2o`0001oooooo0_l0
000Hooooo`;o00006Oooool2o`0003;ooooo000Nooooo`;o00001Oooool2o`0001Oooooo0_l0000U
ooooo`;o00006?ooool2o`0001?ooooo0_l0000Wooooo`;o00001_ooool2o`00017ooooo1?l0000m
ooooo`;o00006Oooool2o`0003;ooooo000Nooooo`03o`000?oooooooooo01cooooo0ol0000Boooo
o`;o0000:oooool2o`0000Kooooo0_l0000;ooooo`;o00006Oooool2o`0000Wooooo0_l0000;oooo
o`;o00004Oooool2o`000003ooooool0003o000004;ooooo0_l0000Oooooo`;o00009?ooool001ko
oooo00?o0000ooooooooool07?ooool2o`0001?ooooo0_l0000cooooo`;o00009_ooool2o`0000Wo
oooo0_l0000;ooooo`;o00005?ooool2o`0001Kooooo0_l0000Zooooo`;o00006Oooool2o`0000Co
oooo0_l0000Looooo`;o00001_ooool001kooooo00?o0000ooooooooool0?oooool2o`0006;ooooo
0_l0000_ooooo`;o0000AOooool2o`0002;ooooo0_l00006ooooo`007_ooool00ol0003ooooooooo
o`0Eooooo`;o00008oooool2o`0000?ooooo0_l0000]ooooo`;o0000<oooool2o`0003_ooooo0_l0
000:ooooo`;o0000FOooool001kooooo00?o0000ooooooooool05Oooool2o`0002?ooooo0_l0000b
ooooo`;o00008?ooool2o`0004kooooo0_l0000:ooooo`;o0000FOooool001kooooo00?o0000oooo
ooooool08oooool2o`0001Sooooo0_l0000]ooooo`;o00008_ooool2o`0006;ooooo0_l0001Aoooo
o`007_ooool00ol0003oooooooooo`0Sooooo`;o00006?ooool2o`0000Cooooo0_l00007ooooo`;o
00007_ooool2o`0006;ooooo0_l0000Kooooo`;o00001Oooool2o`00057ooooo000Nooooo`03o`00
0?oooooooooo00_ooooo0_l0000fooooo`;o00001oooool2o`0004gooooo0_l0000cooooo`;o0000
6oooool2o`0002Sooooo0_l0000Sooooo`;o00002Oooool001kooooo00?o0000ooooooooool02ooo
ool2o`0003gooooo0_l0001?ooooo`;o0000Coooool2o`0001Kooooo0_l0000Aooooo`;o00003_oo
ool2o`0001?ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`03ooooo`;o0000AOooool2
o`0007Cooooo0_l0000Zooooo`;o00005_ooool2o`00027ooooo0_l0000Nooooo`007_ooool00ol0
003oooooooooo`03ooooo`;o0000Voooool2o`0001kooooo0_l00025ooooo`007_ooool00ol0003o
ooooooooo`0Qooooo`;o0000:?ooool2o`0005?ooooo0_l0002Uooooo`007_ooool00ol0003ooooo
ooooo`0Qooooo`;o0000:?ooool2o`0003gooooo0_l0000iooooo`;o0000L?ooool2o`0000kooooo
000Nooooo`03o`000?oooooooooo077ooooo0_l0000Gooooo`;o0000>Oooool2o`0005Cooooo0_l0
000Jooooo`;o00003_ooool001kooooo00?o0000ooooooooool0LOooool2o`0002Oooooo0_l0001o
ooooo`;o0000:_ooool001kooooo0_l0002Kooooo`;o0000L_ooool2o`0003Oooooo000Nooooo`03
o`000?oooooooooo05Cooooo0_l0000fooooo`;o0000K?ooool2o`0001;ooooo0_l0000gooooo`00
7_ooool00ol0003oooooooooo`0fooooo`;o00007?ooool2o`0003Kooooo0ol0000;ooooo`;o0000
G_ooool2o`0004_ooooo000Nooooo`03o`000?oooooooooo03Kooooo0_l0001Eooooo`?o00002_oo
ool2o`00053ooooo0_l0001Iooooo`007_ooool00ol0003oooooooooo`26ooooo`;o00001_ooool2
o`0005cooooo0_l00005ooooo`;o0000D_ooool001kooooo00?o0000ooooooooool07Oooool2o`00
04gooooo0_l0000Fooooo`Co00004Oooool2o`0005Sooooo0_l00007ooooo`;o0000BOooool001ko
oooo00?o0000ooooooooool07Oooool2o`0004Sooooo0_l00003ooooo`;o00005_ooool2o`0001?o
oooo0_l0001Qooooo`;o00002oooool2o`0000Kooooo0_l0000dooooo`007_ooool00ol0003ooooo
ooooo`0^ooooo`;o0000=oooool2o`0003_ooooo0_l0000Rooooo`;o0000?oooool2o`0000Kooooo
0_l0000dooooo`007_ooool00ol0003oooooooooo`0^ooooo`;o0000M?ooool2o`0000Sooooo0_l0
0006ooooo`;o00004?ooool2o`0007gooooo000Nooooo`03o`000?oooooooooo06Kooooo0_l00016
ooooo`;o00001_ooool2o`0008Cooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`09oooo
o`;o0000Foooool2o`0000;ooooo0_l00031ooooo`;o00002?ooool2o`0000?ooooo0_l00009oooo
o`007_ooool00ol0003oooooooooo`09ooooo`;o0000Coooool2o`0000kooooo0_l0000Iooooo`;o
00009?ooool2o`0001Cooooo0_l0000fooooo`;o0000<_ooool2o`0000Sooooo0_l0000>ooooo`00
7_ooool00ol0003oooooooooo`1Jooooo`;o00000oooool2o`0002Cooooo0_l0000Tooooo`;o0000
5?ooool2o`0003Kooooo0_l0000Vooooo`;o00009?ooool001kooooo00?o0000ooooooooool0<_oo
ool2o`0002_ooooo0_l0001cooooo`;o0000Boooool2o`0002Cooooo000Dooooo`Co000000?o410@
ooooooooool00oooool00ol0003oooooooooo`02o`00033ooooo0_l0002Pooooo`;o0000B?ooool2
o`0000[ooooo0_l0000Kooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;o00005?ooool2o`000<[ooooo0_l0000jooooo`;o00002_ooool2o`0001_ooooo000Fooooo`03
o`000?oooooooooo00Gooooo0ol0000<ooooo`;o00002?ooool2o`0004_ooooo0_l0001mooooo`;o
0000Hoooool001Kooooo00?o0000ooooooooool05?ooool2o`0005Gooooo0_l0003Rooooo`005_oo
ool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool0
01Kooooo00?o0000ooooooooool0oooooom@ooooo`005?ooool00omEEEGoIVIVo`00003ooooooe;o
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.02442 .23721 Mdot
.30458 .94001 Mdot
.11244 .13808 Mdot
.48579 .88259 Mdot
.21012 .16413 Mdot
.01721 .41579 Mdot
.97969 .24159 Mdot
.10426 .50888 Mdot
.13522 .90586 Mdot
.37513 .01747 Mdot
.5947 .87741 Mdot
.21057 .71959 Mdot
.41537 .28389 Mdot
.55166 .20374 Mdot
.37561 .39252 Mdot
.51677 .53313 Mdot
.59431 .97957 Mdot
.14041 .32601 Mdot
.57543 .02614 Mdot
.01787 .64918 Mdot
.46701 .82482 Mdot
.23172 .09195 Mdot
.12725 .23994 Mdot
.05288 .69597 Mdot
.86379 .47532 Mdot
.42098 .50034 Mdot
.83597 .68467 Mdot
.69291 .40485 Mdot
.54468 .86584 Mdot
.2416 .96555 Mdot
.81904 .90461 Mdot
.46233 .07447 Mdot
.6172 .26057 Mdot
.08361 .14368 Mdot
.83751 .36861 Mdot
.79148 .74785 Mdot
.44956 .94011 Mdot
.40101 .5804 Mdot
.09319 .40186 Mdot
.10728 .87619 Mdot
.91135 .17128 Mdot
.34288 .75344 Mdot
.37935 .16736 Mdot
.27846 .21635 Mdot
.92513 .17433 Mdot
.58115 .58774 Mdot
.77601 .02328 Mdot
.51534 .02406 Mdot
.03665 .09436 Mdot
.2581 .02346 Mdot
.02364 .87934 Mdot
.65706 .58283 Mdot
.05023 .9466 Mdot
.01496 .38967 Mdot
.02129 .55599 Mdot
.07007 .96779 Mdot
.71066 .01233 Mdot
.13712 .78923 Mdot
.31887 .36595 Mdot
.16712 .93338 Mdot
.08191 .26746 Mdot
.99394 .83395 Mdot
.23133 .90105 Mdot
.54457 .62287 Mdot
.83462 .40401 Mdot
.27503 .01734 Mdot
.13646 .93908 Mdot
.59887 .86133 Mdot
.03647 .03429 Mdot
.92661 .17942 Mdot
.91255 .83849 Mdot
.07009 .4664 Mdot
.08457 .55497 Mdot
.43465 .68002 Mdot
.4812 .18082 Mdot
.91527 .16481 Mdot
.10304 .84824 Mdot
.25862 .44349 Mdot
.79787 .59266 Mdot
.21507 .40428 Mdot
.49123 .9039 Mdot
.73628 .90139 Mdot
.20809 .82431 Mdot
.8936 .43178 Mdot
.60578 .67995 Mdot
.92015 .89643 Mdot
.40472 .25021 Mdot
.14225 .7259 Mdot
.53687 .87147 Mdot
.53918 .6225 Mdot
.12779 .82237 Mdot
.68999 .49758 Mdot
.13529 .55983 Mdot
.6357 .33999 Mdot
.25531 .35009 Mdot
.25518 .49443 Mdot
.33187 .99217 Mdot
.7141 .32286 Mdot
.61043 .06913 Mdot
.36333 .89718 Mdot
.4916 .44354 Mdot
.74877 .58222 Mdot
.85857 .95343 Mdot
.35565 .40713 Mdot
.50285 .54631 Mdot
.20217 .64357 Mdot
.43016 .91321 Mdot
.81447 .52661 Mdot
.18308 .80088 Mdot
.53884 .81373 Mdot
.23766 .26645 Mdot
.74931 .71307 Mdot
.92737 .36711 Mdot
.36084 .40809 Mdot
.03644 .60485 Mdot
.62236 .764 Mdot
.25016 .65769 Mdot
.96146 .81471 Mdot
.52845 .50139 Mdot
.5301 .78626 Mdot
.7175 .29015 Mdot
.56881 .29887 Mdot
.05164 .51958 Mdot
.32031 .0304 Mdot
.50225 .54535 Mdot
.15364 .43064 Mdot
.52438 .56682 Mdot
.49806 .86358 Mdot
.72435 .73316 Mdot
.75775 .89775 Mdot
.74333 .97745 Mdot
.01407 .67231 Mdot
.11081 .3565 Mdot
.66052 .78529 Mdot
.31791 .37387 Mdot
.1777 .23915 Mdot
.38752 .90036 Mdot
.03446 .35891 Mdot
.52845 .66226 Mdot
.42214 .00517 Mdot
.18457 .28523 Mdot
.04934 .29926 Mdot
.80815 .87508 Mdot
.95355 .24973 Mdot
.46052 .38804 Mdot
.38651 .67251 Mdot
.53483 .77528 Mdot
.88322 .21037 Mdot
.35038 .34717 Mdot
.09179 .21796 Mdot
.20246 .87538 Mdot
.30778 .21269 Mdot
.77351 .13643 Mdot
.79683 .95101 Mdot
.19695 .35704 Mdot
.54793 .48968 Mdot
.35725 .57549 Mdot
.56216 .32493 Mdot
.63604 .63465 Mdot
.077 .62509 Mdot
.6806 .49456 Mdot
.1941 .92812 Mdot
.97933 .20597 Mdot
.91756 .31716 Mdot
.8694 .64222 Mdot
.4781 .73772 Mdot
.99199 .65566 Mdot
.55144 .59281 Mdot
.35999 .54385 Mdot
.99292 .97999 Mdot
.9035 .41192 Mdot
.43145 .21667 Mdot
.42906 .18117 Mdot
.2614 .50733 Mdot
.75124 .46867 Mdot
.67902 .06298 Mdot
.38088 .52981 Mdot
.59286 .6805 Mdot
.4224 .34653 Mdot
.25537 .41684 Mdot
.03613 .29995 Mdot
.87436 .16409 Mdot
.82041 .85132 Mdot
.16965 .28364 Mdot
.75877 .29992 Mdot
.76419 .31369 Mdot
.39412 .23612 Mdot
.33786 .38516 Mdot
.49431 .42403 Mdot
.13413 .51594 Mdot
.36935 .20401 Mdot
.11629 .4123 Mdot
.74967 .6182 Mdot
.09747 .07385 Mdot
.32795 .05412 Mdot
.65633 .09732 Mdot
.47312 .38464 Mdot
.49673 .25733 Mdot
.3215 .38596 Mdot
.07964 .03412 Mdot
.10406 .76214 Mdot
.39407 .24272 Mdot
.00158 .294 Mdot
.1072 .51062 Mdot
.90235 .66719 Mdot
.37241 .27744 Mdot
.08177 .31734 Mdot
.45656 .44672 Mdot
.42093 .30677 Mdot
.97433 .5648 Mdot
.46053 .23367 Mdot
.62152 .11567 Mdot
.74808 .8901 Mdot
.58551 .45848 Mdot
.36762 .41744 Mdot
.79402 .49349 Mdot
.90609 .93942 Mdot
.19097 .13151 Mdot
.32167 .36305 Mdot
.05999 .89331 Mdot
.84553 .47139 Mdot
.63908 .57575 Mdot
.6436 .74165 Mdot
.78852 .93341 Mdot
.55815 .49627 Mdot
.47222 .79186 Mdot
.95535 .41708 Mdot
.51009 .79368 Mdot
.63852 .8218 Mdot
.53256 .88232 Mdot
.61965 .14152 Mdot
.762 .00778 Mdot
.19436 .5247 Mdot
.74054 .61822 Mdot
.93186 .48945 Mdot
.67556 .59207 Mdot
.57511 .70465 Mdot
.50609 .99584 Mdot
.41424 .76258 Mdot
.87437 .93377 Mdot
.03875 .89098 Mdot
.81638 .40173 Mdot
.84489 .38073 Mdot
.61682 .31833 Mdot
.23259 .894 Mdot
.9414 .10396 Mdot
.54855 .0693 Mdot
.9631 .49887 Mdot
.76416 .17251 Mdot
.20641 .66034 Mdot
.87233 .2354 Mdot
.71841 .97027 Mdot
.38246 .59807 Mdot
.70279 .27745 Mdot
.28236 .90832 Mdot
.88498 .30369 Mdot
.73203 .94568 Mdot
.02349 .15695 Mdot
.18638 .13364 Mdot
.1958 .70155 Mdot
.37468 .38893 Mdot
.02129 .49867 Mdot
.30372 .57051 Mdot
.63099 .74745 Mdot
.2044 .52847 Mdot
.69613 .50159 Mdot
.52491 .71415 Mdot
.39739 .77967 Mdot
.58018 .76351 Mdot
.65328 .07675 Mdot
.60275 .86199 Mdot
.91902 .55596 Mdot
.7359 .23389 Mdot
.18448 .91475 Mdot
.30475 .27219 Mdot
.05175 .51766 Mdot
.41177 .34433 Mdot
.01047 .24945 Mdot
.48652 .76068 Mdot
.54143 .2089 Mdot
.37756 .99509 Mdot
.97856 .63868 Mdot
.22622 .97862 Mdot
.88043 .95287 Mdot
.96623 .50112 Mdot
.35567 .69028 Mdot
.66 .65431 Mdot
.72693 .54815 Mdot
.74552 .84348 Mdot
.99157 .72961 Mdot
.55281 .92894 Mdot
.32553 .14934 Mdot
.53272 .17557 Mdot
.23415 .75434 Mdot
.65067 .67259 Mdot
.31167 .38999 Mdot
.9595 .89771 Mdot
.13985 .46375 Mdot
.90357 .37395 Mdot
.33275 .30818 Mdot
.07894 .63515 Mdot
.87785 .15434 Mdot
.95928 .59066 Mdot
.44767 .57491 Mdot
.58204 .87393 Mdot
.14268 .28442 Mdot
.18688 .63059 Mdot
.51349 .29555 Mdot
.97474 .2767 Mdot
.05661 .45862 Mdot
.46652 .49367 Mdot
.93557 .52904 Mdot
.46973 .47365 Mdot
.47823 .86069 Mdot
.20731 .58425 Mdot
.72415 .93537 Mdot
.42675 .26274 Mdot
.36201 .43067 Mdot
.06732 .50369 Mdot
.36722 .30548 Mdot
.01089 .40796 Mdot
.69454 .6742 Mdot
.21547 .28183 Mdot
.52057 .42195 Mdot
.20542 .60916 Mdot
.49432 .09133 Mdot
.26096 .60488 Mdot
.11943 .31518 Mdot
.90253 .50605 Mdot
.85082 .70559 Mdot
.10355 .15798 Mdot
.36046 .76472 Mdot
.80613 .95244 Mdot
.79682 .64629 Mdot
.1007 .85996 Mdot
.00409 .56235 Mdot
.14935 .57592 Mdot
.99515 .16027 Mdot
.1368 .00715 Mdot
.19675 .38897 Mdot
.71212 .6882 Mdot
.68245 .13398 Mdot
.17881 .20689 Mdot
.2731 .40507 Mdot
.05672 .03192 Mdot
.58552 .25941 Mdot
.59119 .31176 Mdot
.56693 .00317 Mdot
.07108 .90791 Mdot
.73666 .54983 Mdot
.32177 .98162 Mdot
.32443 .82499 Mdot
.96533 .08906 Mdot
.59992 .8605 Mdot
.359 .13235 Mdot
.30018 .26837 Mdot
.36902 .61827 Mdot
.97543 .79212 Mdot
.11863 .05394 Mdot
.34658 .00304 Mdot
.88493 .06775 Mdot
.4805 .09473 Mdot
.05749 .18755 Mdot
.2207 .34747 Mdot
.84762 .7443 Mdot
.79017 .06623 Mdot
.01464 .07396 Mdot
.05734 .83706 Mdot
.96238 .39775 Mdot
.93507 .77269 Mdot
.25015 .04764 Mdot
.50726 .71157 Mdot
.1852 .97489 Mdot
.00137 .46132 Mdot
.31884 .65266 Mdot
.64443 .11233 Mdot
.73245 .5658 Mdot
.165 .23313 Mdot
.24118 .36351 Mdot
.81725 .19097 Mdot
.30472 .4028 Mdot
.26333 .61379 Mdot
.23462 .82893 Mdot
.65902 .53352 Mdot
.10373 .21061 Mdot
.84606 .87929 Mdot
.95386 .77148 Mdot
.6199 .30369 Mdot
.87165 .75403 Mdot
.9986 .51576 Mdot
.88141 .98889 Mdot
.67404 .85244 Mdot
.74403 .89605 Mdot
.1051 .24207 Mdot
.82084 .80339 Mdot
.83053 .85944 Mdot
.15077 .10235 Mdot
.51561 .82352 Mdot
.34764 .06285 Mdot
.41295 .08002 Mdot
.22335 .77944 Mdot
.49926 .95944 Mdot
.18152 .78517 Mdot
.34687 .45038 Mdot
.39349 .38765 Mdot
.65939 .64586 Mdot
.51813 .92437 Mdot
.68024 .05166 Mdot
.39853 .27626 Mdot
.94223 .7571 Mdot
.24208 .68803 Mdot
.02537 .51332 Mdot
.30256 .96535 Mdot
.94314 .24261 Mdot
.09031 .46176 Mdot
.31766 .32643 Mdot
.06523 .0166 Mdot
.71925 .31984 Mdot
.50355 .20145 Mdot
.59689 .86138 Mdot
.11895 .48363 Mdot
.51319 .60877 Mdot
.56818 .55659 Mdot
.37767 .53068 Mdot
.44626 .04238 Mdot
.81601 .85615 Mdot
.15412 .79311 Mdot
.07474 .51526 Mdot
.53507 .31045 Mdot
.10811 .8227 Mdot
.89382 .4834 Mdot
.95793 .50463 Mdot
.24074 .70634 Mdot
.52082 .35874 Mdot
.84496 .42136 Mdot
.16901 .46942 Mdot
.72028 .26027 Mdot
.68851 .68789 Mdot
.3212 .75575 Mdot
.23138 .02905 Mdot
.11337 .84407 Mdot
.0132 .82653 Mdot
.82222 .01583 Mdot
.40643 .95692 Mdot
.18174 .9307 Mdot
.64661 .16557 Mdot
.85826 .80273 Mdot
.18138 .10021 Mdot
.72842 .98659 Mdot
.31496 .57065 Mdot
.04734 .45826 Mdot
.71991 .08069 Mdot
.75403 .17823 Mdot
.85937 .99419 Mdot
.39248 .56896 Mdot
.91622 .21994 Mdot
.64696 .89963 Mdot
.74058 .9808 Mdot
.02816 .90984 Mdot
.30979 .73423 Mdot
.19253 .33479 Mdot
.31766 .7073 Mdot
.15208 .02785 Mdot
.38376 .86016 Mdot
.18714 .46641 Mdot
.00783 .21407 Mdot
.54193 .17797 Mdot
.45026 .24431 Mdot
.11221 .36251 Mdot
.92385 .03733 Mdot
.43124 .91795 Mdot
.86396 .58583 Mdot
.26253 .58429 Mdot
.04456 .92103 Mdot
.07318 .89736 Mdot
.33978 .47283 Mdot
.44455 .20079 Mdot
.76477 .59917 Mdot
.65697 .31976 Mdot
.17971 .7242 Mdot
.07576 .23087 Mdot
.05511 .32401 Mdot
.39588 .77098 Mdot
.67053 .3645 Mdot
.56528 .04468 Mdot
.3193 .09057 Mdot
.08996 .30685 Mdot
.69962 .10123 Mdot
.29034 .91534 Mdot
.46414 .74304 Mdot
.916 .85112 Mdot
.70027 .9404 Mdot
.18099 .40616 Mdot
.36077 .01602 Mdot
.83357 .06249 Mdot
.23373 .3262 Mdot
.56344 .02125 Mdot
.98521 .91123 Mdot
.21367 .63553 Mdot
.05116 .97336 Mdot
.71944 .78882 Mdot
.43687 .55936 Mdot
.51258 .22909 Mdot
.02692 .18825 Mdot
.78928 .46529 Mdot
.4639 .09448 Mdot
.30993 .87722 Mdot
.21403 .2111 Mdot
.0515 .70236 Mdot
.13256 .82606 Mdot
.54648 .83302 Mdot
.33825 .36235 Mdot
.22263 .44793 Mdot
.65723 .99297 Mdot
.52144 .93429 Mdot
.97645 .97151 Mdot
.35141 .92739 Mdot
.94808 .6622 Mdot
.55847 .13148 Mdot
.50499 .89069 Mdot
.47816 .6193 Mdot
.3456 .32858 Mdot
.6698 .52556 Mdot
.10953 .56995 Mdot
.8401 .74174 Mdot
.21135 .24498 Mdot
.13268 .3821 Mdot
.7098 .04043 Mdot
.34302 .84519 Mdot
.89114 .68312 Mdot
.63506 .64567 Mdot
.07618 .26434 Mdot
.46934 .38679 Mdot
.44598 .98415 Mdot
.37006 .56611 Mdot
.42993 .67028 Mdot
.20927 .58315 Mdot
.96287 .51884 Mdot
.38994 .56495 Mdot
.85621 .69781 Mdot
.31174 .09948 Mdot
.91728 .28643 Mdot
.56949 .07805 Mdot
.66682 .65426 Mdot
.48557 .2329 Mdot
.6717 .51307 Mdot
.11749 .35501 Mdot
.90786 .5032 Mdot
.90563 .46792 Mdot
.25027 .04291 Mdot
.75913 .21426 Mdot
.30695 .67491 Mdot
.53967 .65828 Mdot
.65591 .78065 Mdot
.61454 .23627 Mdot
.84196 .41364 Mdot
.64502 .15383 Mdot
.44753 .75647 Mdot
.80027 .73953 Mdot
.29242 .06191 Mdot
.86504 .81112 Mdot
.12204 .98604 Mdot
.32603 .17121 Mdot
.25159 .76644 Mdot
.55969 .41156 Mdot
.82808 .3506 Mdot
.99245 .95648 Mdot
.22021 .30039 Mdot
.19648 .04651 Mdot
.34424 .02483 Mdot
.43503 .58299 Mdot
.85474 .00533 Mdot
.28638 .58055 Mdot
.87487 .39133 Mdot
.37073 .59542 Mdot
.46126 .02451 Mdot
.67578 .9122 Mdot
.50717 .10246 Mdot
.01572 .72953 Mdot
.67587 .16408 Mdot
.20087 .71493 Mdot
.02412 .40102 Mdot
.40912 .47711 Mdot
.20325 .14774 Mdot
.26048 .86677 Mdot
.35492 .43903 Mdot
.31053 .47727 Mdot
.5303 .70817 Mdot
.02919 .35237 Mdot
.02886 .26753 Mdot
.88332 .14261 Mdot
.75074 .29081 Mdot
.68185 .8819 Mdot
.47277 .12111 Mdot
.21526 .55223 Mdot
.66832 .78443 Mdot
.28379 .30645 Mdot
.2453 .90362 Mdot
.0714 .39072 Mdot
.18436 .64763 Mdot
.58532 .4106 Mdot
.58048 .66832 Mdot
.31023 .62209 Mdot
.38661 .70825 Mdot
.08901 .49252 Mdot
.21222 .81012 Mdot
.30144 .33093 Mdot
.96527 .82627 Mdot
.10746 .44465 Mdot
.52201 .81962 Mdot
.67001 .5904 Mdot
.43091 .42072 Mdot
.33181 .2535 Mdot
.20562 .48712 Mdot
.54767 .87967 Mdot
.65443 .1016 Mdot
.52648 .94108 Mdot
.80061 .30724 Mdot
.78004 .38213 Mdot
.60821 .14006 Mdot
.39349 .43643 Mdot
.47723 .99555 Mdot
.05401 .93018 Mdot
.70721 .79137 Mdot
.9942 .90114 Mdot
.77174 .80846 Mdot
.94023 .10506 Mdot
.8607 .37309 Mdot
.78892 .42734 Mdot
.40158 .09017 Mdot
.40395 .90075 Mdot
.49097 .55009 Mdot
.75522 .68944 Mdot
.30315 .32566 Mdot
.1678 .59004 Mdot
.09095 .60767 Mdot
.10117 .41463 Mdot
.12226 .64564 Mdot
.9699 .82823 Mdot
.51988 .93905 Mdot
.53116 .47598 Mdot
.65395 .70957 Mdot
.51815 .7526 Mdot
.30537 .89576 Mdot
.43091 .90652 Mdot
.95771 .15245 Mdot
.80604 .52781 Mdot
.01348 .45354 Mdot
.67082 .66876 Mdot
.64961 .54387 Mdot
.67482 .41418 Mdot
.47145 .0586 Mdot
.33792 .47269 Mdot
.62336 .83303 Mdot
.25278 .98 Mdot
.21273 .45901 Mdot
.55656 .06246 Mdot
.79126 .68735 Mdot
.10917 .77403 Mdot
.60401 .03401 Mdot
.29928 .96216 Mdot
.31925 .01478 Mdot
.50212 .25588 Mdot
.29876 .99991 Mdot
.5261 .24619 Mdot
.37355 .24573 Mdot
.75613 .92922 Mdot
.58139 .78992 Mdot
.0085 .31109 Mdot
.32438 .90424 Mdot
.25086 .91143 Mdot
.16943 .38263 Mdot
.27492 .58872 Mdot
.43779 .61446 Mdot
.97054 .89557 Mdot
.18719 .0383 Mdot
.13575 .46611 Mdot
.57008 .80587 Mdot
.64198 .94709 Mdot
.51059 .05202 Mdot
.11404 .12355 Mdot
.72247 .26591 Mdot
.61796 .70084 Mdot
.9578 .40811 Mdot
.88673 .03473 Mdot
.23154 .04506 Mdot
.47754 .26432 Mdot
.16207 .22957 Mdot
.80075 .60423 Mdot
.23331 .32705 Mdot
.85202 .82525 Mdot
.18454 .92613 Mdot
.14965 .89272 Mdot
.37589 .33291 Mdot
.83672 .59768 Mdot
.44919 .61527 Mdot
.71111 .46348 Mdot
.71668 .24669 Mdot
.61904 .76283 Mdot
.54726 .25345 Mdot
.5675 .7437 Mdot
.26886 .43715 Mdot
.25581 .43052 Mdot
.90522 .8687 Mdot
.43113 .79135 Mdot
.36346 .17736 Mdot
.86348 .33331 Mdot
.38366 .21529 Mdot
.97545 .25453 Mdot
.99832 .23368 Mdot
.7444 .92172 Mdot
.69504 .63758 Mdot
.0305 .79364 Mdot
.56951 .97682 Mdot
.28961 .90799 Mdot
.13087 .22203 Mdot
.43974 .92956 Mdot
.92739 .90956 Mdot
.8835 .69292 Mdot
.26976 .40532 Mdot
.28628 .3598 Mdot
.14947 .45865 Mdot
.03207 .90576 Mdot
.7161 .10275 Mdot
.41588 .68902 Mdot
.62198 .69596 Mdot
.01302 .3883 Mdot
.956 .06347 Mdot
.92428 .09912 Mdot
.28951 .47095 Mdot
.95657 .9716 Mdot
.5807 .70225 Mdot
.9185 .07002 Mdot
.88312 .21977 Mdot
.64831 .78563 Mdot
.06543 .76399 Mdot
.93732 .02381 Mdot
.87464 .21824 Mdot
.18777 .78753 Mdot
.19062 .8034 Mdot
.72831 .19104 Mdot
.20684 .63804 Mdot
.61437 .72316 Mdot
.04861 .23001 Mdot
.80068 .1516 Mdot
.317 .95606 Mdot
.62625 .95745 Mdot
.2531 .72023 Mdot
.81811 .82886 Mdot
.7623 .75392 Mdot
.48536 .27282 Mdot
.36076 .09348 Mdot
.30564 .42073 Mdot
.47989 .01788 Mdot
.40475 .8724 Mdot
.60046 .07326 Mdot
.64752 .88716 Mdot
.82213 .42099 Mdot
.68182 .59386 Mdot
.28758 .60506 Mdot
.04628 .41274 Mdot
.09386 .99297 Mdot
.39666 .55004 Mdot
.58683 .5746 Mdot
.08233 .82961 Mdot
.49488 .61419 Mdot
.07085 .36782 Mdot
.19041 .98485 Mdot
.29681 .02759 Mdot
.31699 .12122 Mdot
.80134 .70189 Mdot
.39898 .12517 Mdot
.32784 .80297 Mdot
.01636 .29426 Mdot
.25981 .68089 Mdot
.99073 .31643 Mdot
.72419 .53304 Mdot
.13433 .42256 Mdot
.24186 .89645 Mdot
.21952 .61665 Mdot
.27357 .64855 Mdot
.99852 .55142 Mdot
.07303 .2777 Mdot
.39136 .23726 Mdot
.13688 .56521 Mdot
.86365 .15878 Mdot
.01913 .25569 Mdot
.40701 .49796 Mdot
.6714 .98514 Mdot
.34021 .22333 Mdot
.95037 .0179 Mdot
.59431 .12787 Mdot
.22342 .59037 Mdot
.8111 .61495 Mdot
.88336 .37837 Mdot
.17019 .39867 Mdot
.11779 .06611 Mdot
.12565 .20169 Mdot
.48158 .53153 Mdot
.02087 .28367 Mdot
.39791 .91038 Mdot
.49832 .95416 Mdot
.50398 .83966 Mdot
.00018 .28953 Mdot
.67674 .27357 Mdot
.05376 .20402 Mdot
.16588 .31403 Mdot
.33619 .51421 Mdot
.18491 .79242 Mdot
.71713 .47564 Mdot
.30411 .56834 Mdot
.93795 .60857 Mdot
.65425 .2004 Mdot
.0653 .73114 Mdot
.71417 .88118 Mdot
.41075 .58134 Mdot
.46458 .48716 Mdot
.11505 .31686 Mdot
.75412 .5032 Mdot
.8321 .3621 Mdot
.89123 .56356 Mdot
.57296 .38926 Mdot
.36614 .51442 Mdot
.85949 .00266 Mdot
.59809 .91624 Mdot
.74101 .64484 Mdot
.79851 .14873 Mdot
.32285 .6458 Mdot
.56642 .2738 Mdot
.32078 .70031 Mdot
.47728 .93181 Mdot
.26891 .91742 Mdot
.13815 .04272 Mdot
.19408 .32304 Mdot
.48485 .92645 Mdot
.89474 .71032 Mdot
.93902 .02816 Mdot
.44789 .5936 Mdot
.78749 .30627 Mdot
.74849 .55023 Mdot
.33921 .36417 Mdot
.95872 .09493 Mdot
.84366 .9622 Mdot
.48117 .9156 Mdot
.26914 .13511 Mdot
.63469 .28711 Mdot
.69878 .25244 Mdot
.06851 .07741 Mdot
.40881 .24181 Mdot
.53928 .79326 Mdot
.18578 .0734 Mdot
.29476 .26709 Mdot
.20902 .40016 Mdot
.43803 .34223 Mdot
.13177 .88133 Mdot
.83468 .62007 Mdot
.10209 .33729 Mdot
.8586 .94804 Mdot
.78922 .45846 Mdot
.05328 .89206 Mdot
.3146 .01078 Mdot
.24121 .12544 Mdot
.2956 .3179 Mdot
.75255 .86879 Mdot
.97713 .26845 Mdot
.56578 .20019 Mdot
.43331 .48622 Mdot
.19689 .65966 Mdot
.6365 .86944 Mdot
.15459 .30478 Mdot
.12438 .7814 Mdot
.35477 .16293 Mdot
.43319 .13892 Mdot
.69418 .14767 Mdot
.60058 .32752 Mdot
.29385 .4585 Mdot
.70512 .6101 Mdot
.38041 .13123 Mdot
.82924 .17543 Mdot
.49035 .79784 Mdot
.28552 .87371 Mdot
.90392 .05505 Mdot
.36222 .02113 Mdot
.28284 .65556 Mdot
.56451 .17945 Mdot
.32639 .75578 Mdot
.4537 .50899 Mdot
.58709 .50933 Mdot
.28734 .90189 Mdot
.12321 .29874 Mdot
.213 .0986 Mdot
.60567 .01972 Mdot
.09886 .27167 Mdot
.55104 .55518 Mdot
.23171 .12644 Mdot
.13344 .62779 Mdot
.01203 .14808 Mdot
.94439 .07246 Mdot
.24174 .76117 Mdot
.4422 .85496 Mdot
.68538 .64302 Mdot
.11136 .27803 Mdot
.05267 .3944 Mdot
.94638 .59695 Mdot
.63668 .46121 Mdot
.16272 .38048 Mdot
.89288 .85503 Mdot
.7529 .45459 Mdot
.39397 .84161 Mdot
.77221 .54011 Mdot
.26301 .68536 Mdot
.88691 .51218 Mdot
.2769 .40958 Mdot
.48071 .20933 Mdot
.28758 .83153 Mdot
.07613 .18883 Mdot
.37671 .66172 Mdot
.94884 .29297 Mdot
.35612 .01415 Mdot
.16287 .50358 Mdot
.58063 .12352 Mdot
.92259 .14167 Mdot
.72591 .85409 Mdot
.86553 .76438 Mdot
.19886 .15775 Mdot
.74245 .27833 Mdot
.17045 .63443 Mdot
.38779 .91044 Mdot
.56733 .77827 Mdot
.83452 .98221 Mdot
.56604 .95435 Mdot
.56221 .00822 Mdot
.77544 .56385 Mdot
.73516 .57467 Mdot
.44187 .09195 Mdot
.8188 .6413 Mdot
.84895 .47933 Mdot
.1654 .91316 Mdot
.74804 .00104 Mdot
.37962 .47964 Mdot
.07716 .2157 Mdot
.99045 .00743 Mdot
.87357 .39539 Mdot
.23466 .75197 Mdot
.51338 .62494 Mdot
.54048 .49917 Mdot
.50316 .02708 Mdot
.48065 .11674 Mdot
.21906 .05742 Mdot
.86733 .90343 Mdot
.81057 .65951 Mdot
.77448 .68104 Mdot
.62176 .05102 Mdot
.74443 .8255 Mdot
.15877 .1502 Mdot
.88631 .95904 Mdot
.03689 .18118 Mdot
.17648 .64209 Mdot
.04261 .41013 Mdot
.08363 .03632 Mdot
.97251 .93635 Mdot
.73042 .51209 Mdot
.3022 .27688 Mdot
.19509 .60988 Mdot
.19825 .64515 Mdot
.2858 .36844 Mdot
.91708 .10094 Mdot
.33818 .89803 Mdot
.51174 .27284 Mdot
.15592 .88075 Mdot
.84467 .74704 Mdot
.32324 .34596 Mdot
.32338 .80418 Mdot
.07866 .14754 Mdot
.56858 .56651 Mdot
.27386 .77664 Mdot
.30979 .63894 Mdot
.75526 .94584 Mdot
.89829 .74787 Mdot
.83258 .0438 Mdot
.13062 .63885 Mdot
.48512 .15278 Mdot
.00437 .77954 Mdot
.64161 .4734 Mdot
.18227 .19599 Mdot
.46777 .82088 Mdot
.27636 .40274 Mdot
.27452 .37595 Mdot
.99255 .3991 Mdot
.095 .0628 Mdot
.2178 .80797 Mdot
.7445 .55654 Mdot
.64296 .09753 Mdot
.60567 .74316 Mdot
.27712 .62991 Mdot
.05548 .02182 Mdot
.16953 .83438 Mdot
.19316 .76533 Mdot
.55567 .82312 Mdot
.72666 .69005 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00co
oooo0_l0000@ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo0_l0000:ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`;o00004?ooool00ol0003o
ooooooooo`0=ooooo`04o`000?oooooo0000o`0000cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`08ooooo`;o00000oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0<ooooo`;o00004?ooool00ol0003oooooooooo`03ooooo`;o00002?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool2o`0000[o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`Co00003?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo0_l00002ooooo`03o`000?oooooooooo00;o
oooo000Nooooo`03o`000?oooooooooo02Sooooo0_l0001Kooooo`;o0000;?ooool2o`0003oooooo
0_l0000Looooo`;o0000:_ooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo06;ooooo0_l0
001?ooooo`;o0000;_ooool2o`0000oooooo0_l0001Aooooo`007_ooool00ol0003oooooooooo`0A
ooooo`;o0000Coooool4o`0000[ooooo0ol0001`ooooo`;o00008_ooool2o`0003kooooo000Noooo
o`03o`000?oooooooooo017ooooo0_l00012ooooo`;o00003Oooool2o`0000[ooooo0ol00003oooo
o`;o00008?ooool2o`0002Oooooo0_l00014ooooo`;o0000:?ooool2o`0001Cooooo000Nooooo`03
o`000?oooooooooo00kooooo0_l00015ooooo`;o00006oooool2o`0000;ooooo0_l0000Pooooo`;o
00006Oooool2o`0000cooooo0_l0001^ooooo`;o00005?ooool001kooooo00?o0000ooooooooool0
3_ooool2o`00043ooooo0_l0000Jooooo`;o00001?ooool2o`0001kooooo0_l0000?ooooo`;o0000
3_ooool2o`0004?ooooo0_l0000cooooo`;o00006?ooool001kooooo00?o0000ooooooooool0;Ooo
ool2o`0001Sooooo0_l00007ooooo`;o00002_ooool2o`0000kooooo0_l0000Tooooo`;o00002ooo
ool2o`0000;ooooo0_l0000Booooo`;o0000?oooool2o`0003?ooooo0_l0000Hooooo`007_ooool0
0ol0003oooooooooo`0>ooooo`;o00007Oooool2o`0001Sooooo0_l0000Cooooo`;o00001_ooool2
o`0003Wooooo0_l0000Fooooo`;o0000M?ooool2o`0001Sooooo000Nooooo`03o`000?oooooooooo
00Sooooo0_l00004ooooo`;o00001_ooool2o`0004cooooo0_l0001Jooooo`;o0000F_ooool2o`00
02Wooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0000<ooooo`?o00008?ooool2o`0008Go
oooo0_l0001Jooooo`;o00002_ooool2o`0001gooooo000Nooooo`03o`000?oooooooooo01Oooooo
0_l0000Pooooo`;o0000Z?ooool2o`0004?ooooo0_l0000Mooooo`007_ooool00ol0003ooooooooo
o`0Yooooo`;o00008_ooool2o`0003kooooo0_l0001Dooooo`;o00009_ooool2o`0003[ooooo000N
ooooo`03o`000?oooooooooo02Wooooo0_l0000Aooooo`;o00002Oooool2o`0000Cooooo0_l0000n
ooooo`;o00009Oooool2o`0005Gooooo0_l0000jooooo`007_ooool00ol0003oooooooooo`0loooo
o`;o00002Oooool2o`0000Cooooo0_l0001Uooooo`;o0000TOooool001kooooo0_l0001>ooooo`;o
0000Doooool2o`0002;ooooo0_l0000Aooooo`;o0000K?ooool001kooooo00?o0000ooooooooool0
8_ooool2o`0004?ooooo0_l0000iooooo`;o00008_ooool2o`00017ooooo0_l00017ooooo`;o0000
8oooool001kooooo00?o0000ooooooooool08_ooool2o`0001oooooo0_l0000Rooooo`;o0000;?oo
ool2o`0008_ooooo0_l0000Sooooo`007_ooool00ol0003oooooooooo`0Kooooo`;o00009_ooool2
o`0001Kooooo0_l0000@ooooo`;o00009_ooool2o`0001[ooooo0_l0001Hooooo`;o0000>_ooool0
01kooooo00?o0000ooooooooool06oooool2o`0003kooooo0_l0000@ooooo`;o0000@_ooool2o`00
02Kooooo0_l0000`ooooo`;o00009_ooool2o`0001;ooooo000Nooooo`03o`000?oooooooooo02;o
oooo0_l0002eooooo`;o00008_ooool2o`0001gooooo0_l0000Eooooo`;o00004_ooool001kooooo
00?o0000ooooooooool08_ooool2o`0008[ooooo0_l0000Booooo`;o0000>Oooool2o`0001gooooo
0_l00009ooooo`;o00007_ooool001kooooo00Co0000oooooooooooooooo0_l0000Iooooo`;o0000
6_ooool2o`0005Sooooo0_l0000Jooooo`;o00003oooool2o`000003ooooool0003o000006?ooooo
0_l00006ooooo`;o00005_ooool001kooooo00Co0000oooooooooooooooo0_l0000?ooooo`;o0000
2?ooool2o`0001[ooooo0_l0001Hooooo`;o00008Oooool2o`0000Sooooo0_l0000?ooooo`;o0000
GOooool2o`0001Kooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0001^ooooo`;o0000<Ooo
ool2o`0001Wooooo0_l0000Dooooo`;o0000Goooool001kooooo00?o0000ooooooooool0P_ooool2
o`0006;ooooo0_l0001Oooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo06Cooooo0_l0000Hooooo`;o0000]_ooool2o`0000oooooo000Nooooo`03o`00
0?oooooooooo04Oooooo0_l0000Kooooo`;o00002oooool2o`0000_ooooo0_l0000<ooooo`;o0000
3oooool2o`0009Oooooo0_l0000?ooooo`007_ooool00ol0003oooooooooo`08ooooo`;o0000?Ooo
ool2o`0002Sooooo0_l0000Iooooo`;o00001Oooool2o`0000?ooooo0_l00003ooooo`;o0000UOoo
ool2o`00017ooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0000gooooo`;o00007_ooool2
o`00033ooooo0_l00003ooooo`;o0000<oooool2o`0000;ooooo0_l0001Eooooo`;o00002_ooool2
o`00017ooooo000Nooooo`;o0000;_ooool2o`0000Sooooo0_l00008ooooo`;o00007_ooool2o`00
03kooooo0_l0000Zooooo`;o00000_ooool2o`0000cooooo0_l00004ooooo`;o0000?oooool4o`00
01gooooo000Nooooo`03o`000?oooooooooo02gooooo0_l00008ooooo`;o0000J?ooool2o`0002ko
oooo0_l0000<ooooo`;o00001?ooool2o`0003oooooo0_l00006ooooo`;o00005oooool001kooooo
00?o0000ooooooooool0ooooool_ooooo`;o00005oooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3=ooooo`;o0000N?ooool001kooooo00?o0000oooo
ooooool0V?ooool2o`0002cooooo0_l00005ooooo`;o0000N?ooool001kooooo00?o0000oooooooo
ool0Hoooool2o`00037ooooo1?l0000/ooooo`;o0000Ooooool001kooooo00?o0000ooooooooool0
8Oooool2o`00043ooooo0_l0000aooooo`;o00008Oooool2o`0008cooooo000Nooooo`03o`000?oo
oooooooo027ooooo0_l0000Tooooo`;o000000?oooooo`000?l00000<_ooool2o`0003Wooooo0_l0
002<ooooo`007_ooool00ol0003oooooooooo`17ooooo`;o000000?oooooo`000?l00000<_ooool2
o`0003gooooo0_l00028ooooo`007_ooool00ol0003oooooooooo`0hooooo`Co0000=Oooool2o`00
00Gooooo0_l0000gooooo`;o00002_ooool2o`0008Sooooo000Nooooo`03o`000?oooooooooo03So
oooo1?l0000Gooooo`;o00007?ooool2o`0000Gooooo0_l0000gooooo`;o00009oooool2o`0001_o
oooo0_l0001>ooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o0000<Oooool2o`0003Cooooo
0_l0001?ooooo`;o00006oooool2o`0004kooooo000Nooooo`03o`000?oooooooooo023ooooo0_l0
001Wooooo`;o0000=oooool2o`000003ooooool0003o000005Cooooo0_l0000;ooooo`;o00007Ooo
ool001kooooo00?o0000ooooooooool05oooool2o`000:Wooooo0_l000000ooooooo0000o`00001D
ooooo`;o00002oooool2o`0001gooooo000Nooooo`03o`000?oooooooooo00;o00004oooool4o`00
02Gooooo0_l0002Nooooo`;o00007oooool2o`0004Kooooo000Nooooo`;o000000?oooooo`000?l0
00004oooool2o`0001Sooooo0_l0000=ooooo`;o00009_ooool2o`0007Kooooo0_l0000Oooooo`?o
0000AOooool001kooooo00?o0000ooooooooool0;oooool2o`0003Gooooo0_l0000booooo`;o0000
<_ooool2o`00033ooooo0_l0000Gooooo`;o00006?ooool2o`0001;ooooo000Nooooo`03o`000?oo
oooooooo00Cooooo0_l0000Hooooo`;o00007Oooool2o`0005_ooooo0_l0000booooo`;o0000BOoo
ool2o`0001Sooooo0_l0000Booooo`007_ooool00ol0003oooooooooo`04ooooo`;o00006?ooool2
o`0001gooooo0_l0003Fooooo`;o0000:?ooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo
043ooooo0_l0000]ooooo`;o0000Ioooool2o`0003_ooooo0_l000000ooooooo0000o`00000Uoooo
o`;o00001_ooool001kooooo00?o0000ooooooooool0@?ooool2o`0002gooooo0_l00006ooooo`;o
0000EOooool2o`0000Sooooo0_l0000nooooo`;o00002oooool2o`00023ooooo000Nooooo`03o`00
0?oooooooooo07Oooooo0_l0001Eooooo`;o0000EOooool2o`00023ooooo000Nooooo`03o`000?oo
oooooooo06Kooooo0_l0002<ooooo`;o0000;_ooool2o`00027ooooo000Nooooo`03o`000?oooooo
oooo06Kooooo0_l00011ooooo`;o0000BOooool2o`0001?ooooo0_l0000Iooooo`;o00000oooool2
o`0001cooooo000Nooooo`03o`000?oooooooooo07;ooooo0_l0000eooooo`;o000000?oooooo`00
0?l000001Oooool2o`0003cooooo0_l0000Fooooo`;o00007_ooool2o`0001cooooo000Nooooo`03
o`000?oooooooooo00Sooooo0_l0001Xooooo`;o00004oooool2o`0000oooooo0_l0000Booooo`;o
00001Oooool2o`0003cooooo0_l0000fooooo`;o00007?ooool001kooooo00?o0000ooooooooool0
2?ooool2o`0007gooooo0_l0000?ooooo`;o0000[Oooool001kooooo00?o0000ooooooooool01Ooo
ool2o`0000Sooooo0_l00004ooooo`;o0000oooooolaooooo`007_ooool00ol0003oooooooooo`05
ooooo`;o00002?ooool2o`0000Cooooo0_l0003Booooo`;o00006oooool2o`0003oooooo0003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooo
oooo0>Wooooo0_l0000Kooooo`;o0000?oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0=ooo
ool2o`000?oooooo3oooool000?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7ok^k^00Oooooo0ol0000gooooo`;o0000Doooool2o`0002Kooooo0_l0000Kooooo`;o0000M?oo
ool000?ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o
0000ooooooooool03Oooool2o`0001Kooooo0_l0001=ooooo`;o00005_ooool2o`0001;ooooo0_l0
000=ooooo`;o00000oooool2o`0001_ooooo0_l0001dooooo`000oooool01Ol0003ooooooooooooo
oooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`0=ooooo`;o00005_oo
ool2o`0000oooooo0_l0000looooo`;o0000:_ooool2o`0000gooooo0_l00029ooooo`;o00002ooo
ool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0=_ooool2o`00063ooooo0_l0000Booooo`;o0000KOooool2o`0001gooooo0_l0
000;ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RH
oa0@4006ooooo`03o`000?oooooooooo01kooooo0_l0000Qooooo`;o00007Oooool2o`0003Kooooo
0_l0000Booooo`;o0000KOooool2o`0002[ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo0ol0000Eooooo`;o00001oooool2o`00027o
oooo0_l0000Cooooo`;o00002?ooool2o`0001Oooooo0_l0000=ooooo`;o0000JOooool2o`0005;o
oooo000Nooooo`?o00005Oooool2o`0000?ooooo0_l0000jooooo`;o00008Oooool2o`0000gooooo
0_l0001Yooooo`;o00008oooool2o`000003ooooool0003o000002[ooooo000Nooooo`03o`000?oo
oooooooo01[ooooo0_l0000:ooooo`;o0000l?ooool2o`000003ooooool0003o000000Wooooo0_l0
000Oooooo`007_ooool00ol0003oooooooooo`0Vooooo`;o0000@_ooool2o`000;[ooooo0_l0000O
ooooo`007_ooool00ol0003oooooooooo`1Zooooo`;o0000foooool001kooooo00?o0000oooooooo
ool03?ooool2o`0000Oooooo0_l0000Jooooo`;o0000L?ooool2o`000:;ooooo000Nooooo`03o`00
0?oooooooooo00cooooo0_l00007ooooo`;o00006_ooool3o`0005kooooo0_l00006ooooo`;o0000
1oooool2o`0004Kooooo0_l0001Cooooo`;o00001Oooool001kooooo00?o0000ooooooooool01?oo
ool2o`0002cooooo0_l00017ooooo`?o00005?ooool2o`0000Kooooo0_l0000Xooooo`;o00009Ooo
ool2o`0002[ooooo0_l0000Wooooo`;o00001Oooool001kooooo00?o0000ooooooooool01?ooool2
o`0001oooooo0_l0000?ooooo`;o0000@oooool3o`0004Kooooo0_l0001Aooooo`;o0000;_ooool0
01kooooo00?o0000ooooooooool07_ooool2o`0000Gooooo0_l0000?ooooo`;o0000A?ooool2o`00
00?ooooo0_l0000;ooooo`;o0000Woooool2o`0000Wooooo0_l0000;ooooo`007_ooool00ol0003o
ooooooooo`0Nooooo`;o00008Oooool2o`0003;ooooo0_l00005ooooo`;o00000oooool2o`0000_o
oooo0_l0000Gooooo`;o0000??ooool2o`0004Sooooo0_l00009ooooo`;o00002oooool001kooooo
00Co0000ooooool0003o0000@?ooool2o`0003;ooooo0_l00008ooooo`;o00009_ooool2o`0003co
oooo0_l0001;ooooo`;o00004oooool001kooooo1?l0001Wooooo`;o00005Oooool2o`0002gooooo
0_l0000_ooooo`;o0000DOooool2o`0001?ooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0
001Tooooo`;o0000=Oooool2o`0000gooooo0_l0000_ooooo`;o0000F?ooool2o`0000cooooo000N
ooooo`03o`000?oooooooooo00;ooooo0_l0002Iooooo`Co00006Oooool2o`0007gooooo0_l0000<
ooooo`007_ooool00ol0003oooooooooo`27ooooo`;o00005?ooool2o`0001_ooooo0_l00009oooo
o`;o00007oooool2o`0005oooooo000Nooooo`03o`000?oooooooooo01Gooooo0_l0001`ooooo`;o
00003_ooool2o`0002cooooo0_l0000Oooooo`?o0000G_ooool001kooooo00?o0000ooooooooool0
1Oooool2o`0000kooooo1?l0000`ooooo`;o00004Oooool3o`0003Sooooo0_l0001>ooooo`;o0000
DOooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo00Gooooo0_l0000@ooooo`;o00000ooo
ool2o`0002_ooooo0_l0000Aooooo`?o0000foooool2o`0000_ooooo000Nooooo`03o`000?oooooo
oooo01cooooo0_l00011ooooo`;o0000>Oooool2o`0000Kooooo0_l0000@ooooo`;o00008_ooool2
o`0006gooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0000:ooooo`;o0000??ooool3o`00
01Cooooo0_l00006ooooo`;o00006oooool2o`0000Kooooo0_l0000@ooooo`;o00008_ooool2o`00
00Kooooo0_l0001Gooooo`;o00003?ooool001kooooo00?o0000ooooooooool05?ooool2o`0000[o
oooo0_l0000looooo`;o00005Oooool2o`0000Kooooo0_l0001Qooooo`;o00002oooool2o`0004[o
oooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`03ooooo`;o0000;_ooool2o`0000gooooo
0_l0000oooooo`;o0000J?ooool2o`0005Sooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0
000Uooooo`;o00001oooool2o`0000?ooooo0_l00008ooooo`;o0000?oooool2o`0004Gooooo0_l0
001Jooooo`;o00007oooool001gooooo0_l0000/ooooo`;o00003?ooool2o`00093ooooo0_l0000I
ooooo`;o0000?oooool2o`0001oooooo000Mooooo`;o0000ioooool2o`0000Wooooo0_l0000noooo
o`;o00005Oooool001gooooo0_l00003ooooo`;o0000X?ooool2o`0004_ooooo0_l0000nooooo`;o
00005Oooool001gooooo0_l00003ooooo`;o00002Oooool2o`0001Kooooo0_l0001mooooo`;o0000
4?ooool2o`00093ooooo000Nooooo`;o00002Oooool2o`0000;ooooo0_l0000Fooooo`;o00007Ooo
ool2o`00073ooooo0_l0000looooo`;o0000D_ooool001kooooo00?o0000ooooooooool02?ooool2
o`0002Cooooo0_l0000Cooooo`;o0000;_ooool2o`00053ooooo0_l0000/ooooo`;o00009oooool2
o`0002Wooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l0000Cooooo`;o0000:?ooool2o`00
00kooooo0_l00009ooooo`;o00004?ooool2o`0003kooooo0_l0000eooooo`;o00000_ooool2o`00
01[ooooo0_l0000Yooooo`007_ooool01?l0003oooooo`000?l0000Hooooo`;o0000?Oooool2o`00
00kooooo0_l0000Kooooo`;o00008oooool2o`00013ooooo0_l0000nooooo`;o00000_ooool2o`00
04Gooooo000Nooooo`04o`000?oooooo0000o`00037ooooo0_l0001fooooo`;o00004?ooool2o`00
03Kooooo0_l0001Aooooo`007_ooool00ol0003oooooooooo`0Fooooo`;o00002Oooool4o`0000go
oooo0_l0000Xooooo`;o0000U_ooool2o`00033ooooo0_l0000Fooooo`;o00001oooool001kooooo
00?o0000ooooooooool05_ooool2o`0000Wooooo1?l0000gooooo`;o0000I_ooool2o`0000_ooooo
0_l0000Cooooo`;o0000?_ooool2o`0001Kooooo0_l00007ooooo`007_ooool00ol0003ooooooooo
o`0>ooooo`;o0000:oooool2o`0008Oooooo0_l0000;ooooo`;o00004Oooool4o`0005oooooo000N
ooooo`03o`000?oooooooooo00kooooo0_l0000Jooooo`;o00003oooool2o`0000_ooooo0_l0000D
ooooo`;o00000oooool2o`0004kooooo0_l0000_ooooo`;o0000HOooool001kooooo00?o0000oooo
ooooool0:_ooool2o`0001cooooo0_l0000Dooooo`;o00000oooool2o`0000Oooooo0_l00015oooo
o`;o00002_ooool2o`0008Kooooo000Nooooo`03o`000?oooooooooo05kooooo0_l0000<ooooo`;o
00002?ooool2o`0004Oooooo0_l0001Dooooo`;o0000<?ooool001kooooo00?o0000ooooooooool0
>_ooool2o`0002;ooooo0_l0000Fooooo`;o0000WOooool2o`00033ooooo000Nooooo`03o`000?oo
oooooooo01gooooo0_l0000Kooooo`;o0000ooooool<ooooo`007_ooool00ol0003oooooooooo`0M
ooooo`;o0000Joooool2o`0003oooooo0_l0001jooooo`007_ooool00ol0003oooooooooo`22oooo
o`;o00001_ooool2o`0003oooooo0_l0001jooooo`007_ooool00ol0003oooooooooo`14ooooo`;o
00007oooool2o`0000Oooooo0_l0000Booooo`;o000000?oooooo`000?l00000`?ooool001kooooo
0_l00015ooooo`;o00002Oooool2o`0001Cooooo0_l00007ooooo`;o00005Oooool2o`0008;ooooo
0_l0000looooo`007_ooool00ol0003oooooooooo`05ooooo`;o00006oooool2o`0002_ooooo0_l0
002hooooo`;o0000??ooool001kooooo00?o0000ooooooooool01Oooool2o`0001Wooooo1?l0000H
ooooo`;o0000ooooool:ooooo`007_ooool00ol0003oooooooooo`07ooooo`;o00005oooool2o`00
01[ooooo0_l0000Kooooo`;o0000B_ooool2o`000:3ooooo000Nooooo`03o`000?oooooooooo00Oo
oooo0_l0000Gooooo`;o0000:?ooool2o`0000gooooo0_l00009ooooo`;o00001?ooool2o`0003Wo
oooo0_l0001Sooooo`;o0000>oooool001kooooo00?o0000ooooooooool08?ooool2o`0002Sooooo
0_l0000Hooooo`;o00001?ooool2o`0006[ooooo0_l0000booooo`;o00007Oooool2o`0001cooooo
000Nooooo`03o`000?oooooooooo01?ooooo0_l00014ooooo`;o00002Oooool2o`00073ooooo0_l0
000dooooo`;o00006oooool2o`0001cooooo000Nooooo`03o`000?oooooooooo01?ooooo0_l00014
ooooo`;o0000/Oooool2o`0000Kooooo0_l0000aooooo`007_ooool00ol0003oooooooooo`1Eoooo
o`;o00003?ooool2o`000:oooooo0_l0000<ooooo`;o00008oooool001kooooo00?o0000oooooooo
ool0EOooool2o`0000cooooo0_l0002fooooo`;o00001Oooool2o`0002?ooooo000Nooooo`03o`00
0?oooooooooo02Oooooo0_l00008ooooo`Co0000a?ooool2o`0001Cooooo0_l0000:ooooo`;o0000
:_ooool001kooooo00?o0000ooooooooool09oooool2o`0000Sooooo1?l0000eooooo`;o0000:_oo
ool2o`00067ooooo0_l0000Dooooo`;o0000=_ooool001kooooo00?o0000ooooooooool00_l0000j
ooooo`;o00009_ooool2o`0000Cooooo0_l0000:ooooo`;o00001?ooool2o`0001Cooooo1_l0002_
ooooo`007_ooool00ol0003oooooooooo`03o`00013ooooo0_l0000Wooooo`;o00008oooool2o`00
0003ooooool0003o0000013ooooo0_l00004ooooo`;o00005?ooool4o`00023ooooo0_l0001Poooo
o`;o0000;Oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`00
0003oa0@4?oooooooooo00Cooooo00Co0000oooooooooooooooo0_l0000:ooooo`;o00001?ooool2
o`0004cooooo0_l0000Cooooo`;o0000?_ooool2o`00063ooooo0_l0000]ooooo`000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool03Oooool2o`0006Oooooo0_l0002Pooooo`;o00006oooool2o`00013ooooo0003oooo
o`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol00004ooooo`;o0000;Oooool2
o`0000_ooooo0_l0003Fooooo`;o00006oooool2o`0000Sooooo0_l00006ooooo`000oooool01Ol0
003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool00ol0003ooooooooo
o`04ooooo`;o00005?ooool2o`0001Oooooo0_l0000;ooooo`Co00004_ooool2o`0000Oooooo0_l0
002Tooooo`;o00001?ooool2o`0003;ooooo0_l00006ooooo`000oooool01Ol0003ooooooooooooo
oooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`0Jooooo`;o0000
6oooool2o`0000Wooooo0_l0000@ooooo`Co00001oooool2o`0000oooooo0_l0001[ooooo`;o0000
9_ooool2o`0000Cooooo0_l0000jooooo`000oooool01Ol@413ooooooooooooooooo410@00cooooo
00?oMgMgolc<c?l000001oooool01?l0003oooooo`000?l00009ooooo`;o0000:oooool2o`0001_o
oooo1?l0000Hooooo`?o0000J_ooool2o`0005Cooooo0_l0000Booooo`000oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool01?l0003oooooo`000?l00009oooo
o`?o00005Oooool2o`0003;ooooo0_l0000Iooooo`;o0000?oooool2o`0000Kooooo0_l0001Voooo
o`;o00003oooool2o`0001;ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omg
MgOo0000ooooo`06ooooo`04o`000?ooooooooooooooo`;o00002?ooool2o`00013ooooo0_l00003
ooooo`;o0000S_ooool2o`0000Kooooo0_l0000Kooooo`;o0000=Oooool2o`0001;ooooo0_l0000S
ooooo`007_ooool01?l0003oooooooooooooool2o`0001[ooooo0_l0000`ooooo`;o00008_ooool2
o`0006;ooooo0_l0000eooooo`;o00008_ooool2o`0001?ooooo000Nooooo`03o`000?oooooooooo
02Sooooo0_l0000Uooooo`;o00003_ooool2o`0001;ooooo0_l0000Cooooo`;o00006oooool2o`00
063ooooo0_l00006ooooo`;o00008Oooool2o`0001?ooooo000Nooooo`03o`000?oooooooooo02So
oooo0_l0000eooooo`;o00009oooool2o`0001?ooooo0_l00006ooooo`;o0000H?ooool2o`0000Ko
oooo0_l0000fooooo`007_ooool00ol0003oooooooooo`2Mooooo`;o0000GOooool2o`0004Wooooo
000Nooooo`03o`000?oooooooooo02kooooo0_l0000Oooooo`;o00008Oooool2o`0008Sooooo0_l0
000Pooooo`;o00009oooool001kooooo00?o0000ooooooooool0;_ooool2o`0001oooooo0_l0000Q
ooooo`;o0000Z_ooool2o`0002Oooooo000Nooooo`03o`000?oooooooooo05?ooooo0_l0000Woooo
o`;o0000bOooool001kooooo00?o0000ooooooooool0Doooool2o`0001[ooooo0_l0000;ooooo`;o
0000bOooool001kooooo00?o0000ooooooooool0D?ooool2o`0001gooooo0_l0000[ooooo`;o0000
ZOooool001kooooo00?o0000ooooooooool07oooool2o`0002oooooo0_l0000nooooo`;o00002_oo
ool2o`000:Wooooo000Nooooo`03o`000?oooooooooo01oooooo0_l0000Sooooo`;o00009oooool2
o`00027ooooo0_l0002eooooo`007_ooool2o`000003ooooool0003o000004;ooooo0_l0000Woooo
o`;o0000f?ooool001kooooo00?o0000ooooooooool00_l0003_ooooo`;o0000E?ooool001kooooo
00?o0000ooooooooool02oooool2o`000003ooooool0003o000001cooooo0_l0000Cooooo`;o0000
6?ooool2o`0005gooooo0_l0000eooooo`;o00002Oooool2o`0004Wooooo000Mooooo`;o00003Ooo
ool2o`000003ooooool0003o000000Wooooo0_l0000Aooooo`;o00004oooool2o`0001Sooooo0_l0
001Mooooo`;o00003oooool2o`0002oooooo0_l00019ooooo`007Oooool2o`0001_ooooo0_l0000>
ooooo`;o0000X?ooool2o`0001Kooooo0_l0000Gooooo`;o0000BOooool001kooooo00?o0000oooo
ooooool04oooool2o`0001?ooooo0ol0000>ooooo`;o0000Z?ooool2o`0000_ooooo0_l0000:oooo
o`;o00009?ooool2o`0002?ooooo000Nooooo`03o`000?oooooooooo01?ooooo0_l0000Cooooo`;o
00002Oooool2o`0000Cooooo0_l0000Oooooo`;o0000U?ooool2o`0001gooooo0_l0000Aooooo`;o
00008oooool001kooooo00?o0000ooooooooool0<oooool2o`0002Gooooo0_l0000>ooooo`;o0000
:Oooool2o`0003Gooooo0_l00011ooooo`;o0000=_ooool001kooooo00?o0000ooooooooool0HOoo
ool2o`0000Oooooo0_l0000Eooooo`;o00004_ooool2o`0001;ooooo0_l0000Qooooo`;o00005ooo
ool2o`0002kooooo0_l0000`ooooo`007_ooool00ol0003oooooooooo`1Qooooo`;o00005?ooool2
o`0000Sooooo0_l0000Vooooo`;o0000>_ooool2o`0002Wooooo0_l00003ooooo`;o0000<?ooool0
01kooooo00?o0000ooooooooool08oooool2o`0005;ooooo0_l0002Gooooo`;o00003?ooool2o`00
02Oooooo000Nooooo`03o`000?oooooooooo02?ooooo0_l0000Jooooo`;o0000B?ooool2o`0000So
oooo0_l00029ooooo`;o00009oooool001kooooo00?o0000ooooooooool0?oooool2o`0004Sooooo
0_l00008ooooo`;o00006Oooool2o`0007_ooooo0_l0000Jooooo`007_ooool00ol0003ooooooooo
o`0Iooooo`;o0000Toooool2o`0004kooooo0_l0000[ooooo`;o00006_ooool001kooooo00?o0000
ooooooooool06Oooool2o`0003Cooooo0_l00013ooooo`;o00006oooool2o`0002Kooooo0_l0000S
ooooo`;o0000Aoooool001kooooo00?o0000ooooooooool00oooool2o`0004[ooooo0_l0000_oooo
o`;o00004_ooool2o`0001Kooooo0_l00003ooooo`;o00009_ooool2o`000003ooooool0003o0000
05Oooooo0_l0000@ooooo`007_ooool2o`0000Cooooo0_l0001kooooo`;o00000oooool2o`00027o
oooo0_l00002ooooo`;o0000;_ooool4o`0005Gooooo0ol0000?ooooo`007_ooool00ol0003ooooo
ooooo`0Booooo`;o00007Oooool2o`0005;ooooo0_l0000Qooooo`;o0000=?ooool2o`00017ooooo
0_l0000`ooooo`;o00003_ooool2o`000003ooooool0003o000000oooooo000Nooooo`03o`000?oo
oooooooo01;ooooo0_l0000:ooooo`;o00004Oooool2o`0001kooooo0_l0002Nooooo`;o0000;_oo
ool4o`0000kooooo0_l0000Booooo`007_ooool00ol0003oooooooooo`0Nooooo`?o0000<?ooool2
o`0003cooooo0_l0000Zooooo`;o0000I?ooool2o`0002Cooooo000Nooooo`03o`000?oooooooooo
00Cooooo0_l0000Iooooo`;o0000B?ooool2o`0000Sooooo0_l0000Jooooo`;o0000:_ooool2o`00
01Wooooo0_l0000Aooooo`;o0000<Oooool2o`0002Wooooo000Nooooo`03o`000?oooooooooo00Co
oooo0_l00007ooooo`;o00001Oooool2o`00017ooooo0_l00010ooooo`;o00002?ooool2o`00067o
oooo0_l0000Aooooo`;o0000<Oooool2o`0002?ooooo0_l00004ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`;o00001Oooool2o`00017ooooo0_l0003oooooo`gooooo0_l0000:ooooo`;o0000
1?ooool001kooooo00?o0000ooooooooool03Oooool2o`000?oooooo9oooool2o`00013ooooo000N
ooooo`03o`000?oooooooooo03_ooooo0_l0002Iooooo`;o0000;Oooool2o`00043ooooo000Noooo
o`03o`000?oooooooooo03_ooooo0_l000000ooooooo0000o`00000hooooo`;o0000G?ooool2o`00
02[ooooo0_l000000ooooooo0000o`00000Uooooo`;o00006Oooool001kooooo00?o0000oooooooo
ool0?_ooool2o`0003Oooooo0ol0000Nooooo`;o00002_ooool2o`0002cooooo0_l0000Cooooo`;o
00006Oooool2o`0002Sooooo0_l0000Iooooo`007_ooool00ol0003oooooooooo`1gooooo`;o0000
7oooool2o`0000[ooooo0_l0000/ooooo`;o00004oooool2o`0005kooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0moooool2o`0004kooooo000Noooo
o`03o`000?oooooooooo077ooooo0_l0000/ooooo`;o0000;_ooool2o`0002Kooooo0_l0001>oooo
o`007_ooool00ol0003oooooooooo`1aooooo`;o0000;?ooool2o`0002kooooo0_l0000Gooooo`;o
0000GOooool001kooooo0_l0001nooooo`;o00007Oooool2o`000003ooooool0003o000004Oooooo
0_l000000ooooooo0000o`000002ooooo`;o0000D?ooool2o`0000Cooooo000Nooooo`03o`000?oo
oooooooo01Oooooo0_l0000Yooooo`;o0000>Oooool2o`0001gooooo0_l0001=ooooo`;o00000_oo
ool2o`00053ooooo0_l00004ooooo`007_ooool00ol0003oooooooooo`03ooooo`;o00004_ooool2
o`0002Wooooo0_l0001[ooooo`;o00001?ooool2o`0003Oooooo0_l0000gooooo`;o00007_ooool0
01kooooo00?o0000ooooooooool00oooool2o`0002?ooooo0_l0001Pooooo`;o00008oooool2o`00
00Cooooo0_l0000gooooo`;o0000=oooool2o`0001kooooo000Nooooo`;o0000:Oooool2o`00063o
oooo0_l0001/ooooo`;o00009?ooool2o`0002Oooooo000Nooooo`;o0000:Oooool2o`0004[ooooo
0_l00005ooooo`;o0000:Oooool2o`0000gooooo0_l0000cooooo`;o00003?ooool2o`0002Cooooo
0_l0000Iooooo`;o00003?ooool001kooooo00?o0000ooooooooool07oooool2o`0000Oooooo0_l0
000eooooo`;o00004oooool2o`0000Gooooo0_l0000Yooooo`;o00003Oooool2o`0003?ooooo0_l0
001=ooooo`;o00003?ooool001kooooo00?o0000ooooooooool07oooool2o`0003kooooo0_l00000
0ooooooo0000o`00000Gooooo`;o0000b_ooool001kooooo00?o0000ooooooooool0;?ooool2o`00
037ooooo0_l000000ooooooo0000o`00000<ooooo`;o00006oooool2o`0002cooooo0_l0000?oooo
o`;o00007Oooool2o`0005[ooooo000Nooooo`03o`000?oooooooooo02cooooo0_l00012ooooo`;o
00006oooool2o`0002cooooo0_l0000?ooooo`;o00007Oooool2o`0005[ooooo000Nooooo`03o`00
0?oooooooooo05Wooooo0_l0000Sooooo`;o000000?oooooo`000?l00000K?ooool2o`0005Kooooo
000Nooooo`03o`000?oooooooooo03oooooo0ol0000?ooooo`;o00001_ooool2o`0002?ooooo0_l0
00000ooooooo0000o`000006ooooo`;o0000Aoooool2o`0001_ooooo0_l0000Tooooo`;o0000<?oo
ool001kooooo00?o0000ooooooooool0?oooool3o`0000oooooo0_l00002ooooo`;o0000<_ooool2
o`0002kooooo0_l0000Gooooo`;o0000@Oooool2o`00033ooooo000Nooooo`03o`000?oooooooooo
03;ooooo0_l0000Aooooo`;o00003_ooool2o`0006;ooooo0_l0000Kooooo`;o0000G?ooool2o`00
017ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b
<_l0003o410@olc<c006ooooo`03o`000?oooooooooo03;ooooo0_l0000Aooooo`;o0000A_ooool2
o`00023ooooo0_l0000Uooooo`Ko00008oooool2o`0003?ooooo0_l0000Aooooo`000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_oo
ool00ol0003oooooooooo`1dooooo`;o00000_ooool2o`0001?ooooo0_l0000Pooooo`;o00009ooo
ool4o`0002?ooooo0_l0000;ooooo`;o00008_ooool2o`0001Gooooo0003ooooo`05oa0@4?oooooo
ooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0001dooooo`;o0000
0_ooool2o`0007_ooooo0_l0000Eooooo`;o00008_ooool2o`0001Gooooo0003ooooo`05o`000?oo
ooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o0000oooooooo
ool0mOooool2o`0000Wooooo0_l00015ooooo`000oooool01Ol0003ooooooooooooooooo000000_o
oooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo00Sooooo0_l00017oooo
o`;o00001_ooool2o`000:Gooooo0_l00015ooooo`000oooool01Ol@413ooooooooooooooooo410@
00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`08ooooo`;o00003oooool2o`00
023ooooo0_l00002ooooo`;o00004?ooool2o`0000Kooooo0_l00018ooooo`;o0000??ooool2o`00
04[ooooo0_l0000Hooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@
4?nHV9P02?ooool00ol0003oooooooooo`0Iooooo`;o00008?ooool2o`0000;ooooo0_l0001Roooo
o`;o0000??ooool2o`0004[ooooo0_l0000Hooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`1Aooooo`;o0000=oooool2
o`0000;ooooo0_l0000=ooooo`;o0000IOooool2o`00047ooooo000Nooooo`03o`000?oooooooooo
04?ooooo0_l0000<ooooo`;o00008Oooool2o`0001Cooooo0_l00002ooooo`;o00001oooool2o`00
00Cooooo0_l0001>ooooo`;o000000?oooooo`000?l000004_ooool2o`00047ooooo000Nooooo`03
o`000?oooooooooo04?ooooo0_l0000Looooo`;o00004Oooool2o`00027ooooo0_l0000Booooo`;o
0000@?ooool2o`000003ooooool0003o000001Wooooo0_l0000jooooo`007_ooool00ol0003ooooo
ooooo`0Eooooo`;o0000B_ooool2o`00043ooooo0_l00006ooooo`Co0000G?ooool2o`0003[ooooo
000Nooooo`03o`000?oooooooooo01Gooooo0_l0000@ooooo`;o0000N_ooool2o`0000Sooooo0_l0
002Hooooo`007_ooool00ol0003oooooooooo`0Wooooo`;o00004?ooool2o`0001_ooooo0_l0003_
ooooo`007_ooool00ol0003oooooooooo`0cooooo`;o00001?ooool2o`0001_ooooo0_l0001coooo
o`;o0000N_ooool001kooooo00?o0000ooooooooool05_ooool2o`0001_ooooo0_l0000:ooooo`Co
0000R?ooool2o`00017ooooo0_l0001Wooooo`007_ooool00ol0003oooooooooo`0Fooooo`;o0000
3_ooool2o`0001Oooooo1?l0000Nooooo`;o0000Noooool2o`0005[ooooo0_l0000;ooooo`007_oo
ool00ol0003oooooooooo`0Vooooo`;o00003Oooool2o`0000Oooooo0_l0000Qooooo`;o0000N?oo
ool2o`0002Wooooo0_l0000?ooooo`;o00008Oooool2o`0000_ooooo000Nooooo`03o`000?oooooo
oooo02Cooooo0_l0000?ooooo`;o00001Oooool4o`0002Gooooo0_l0001Sooooo`;o00001_ooool2
o`0000Oooooo0_l0000@ooooo`;o00004?ooool2o`0000Gooooo0_l0000?ooooo`;o0000;_ooool0
01kooooo00?o0000ooooooooool00_ooool2o`00023ooooo0_l0000Booooo`;o00000_ooool2o`00
01Oooooo0_l0000>ooooo`;o0000Hoooool2o`0000Kooooo0_l0000Iooooo`;o00004?ooool2o`00
04Kooooo000Nooooo`;o00000oooool2o`0003Cooooo0_l0000Kooooo`;o00003Oooool2o`000>7o
oooo000Nooooo`03o`000?oooooooooo05Sooooo0_l0000:ooooo`;o0000K?ooool2o`000003oooo
ool0003o000006Oooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`1=ooooo`;o00002Ooo
ool2o`00057ooooo0_l0000Uooooo`;o000000?oooooo`000?l00000;?ooool2o`0003Wooooo0_l0
0007ooooo`007_ooool00ol0003oooooooooo`0looooo`;o000000?oooooo`000?l000003?ooool2
o`0002Oooooo0_l0000`ooooo`;o000000?oooooo`000?l00000E_ooool2o`0002_ooooo0_l0000E
ooooo`007_ooool00ol0003oooooooooo`0looooo`;o000000?oooooo`000?l00000=Oooool2o`00
033ooooo0_l00026ooooo`;o00005Oooool001kooooo00?o0000ooooooooool0^Oooool2o`0001_o
oooo0_l00019ooooo`;o00009?ooool001kooooo00?o0000ooooooooool0R?ooool2o`0002oooooo
0_l0000Kooooo`;o0000BOooool2o`0002Cooooo000Nooooo`03o`000?oooooooooo00;o0000G_oo
ool2o`0001Sooooo0_l0000<ooooo`;o0000AOooool2o`0000gooooo0_l0001Wooooo`007_ooool0
0ol0003oooooooooo`02o`0005kooooo0_l0000Hooooo`;o0000Doooool2o`0000gooooo0_l0001W
ooooo`007_ooool00ol0003oooooooooo`1@ooooo`;o0000=oooool2o`0003;ooooo0_l00002oooo
o`;o0000=Oooool2o`0004gooooo000Nooooo`03o`000?oooooooooo053ooooo0_l0000gooooo`;o
0000<_ooool2o`0000;ooooo0_l0000eooooo`;o00009?ooool2o`0002Oooooo000Nooooo`03o`00
0?oooooooooo057ooooo0_l0002iooooo`;o00004?ooool2o`0002Oooooo000Nooooo`03o`000?oo
oooooooo04_ooooo0_l00004ooooo`;o00007Oooool2o`00017ooooo0_l0001Gooooo`;o00001Ooo
ool2o`0000?ooooo0_l00007ooooo`;o00002_ooool2o`0000gooooo0_l0000iooooo`007_ooool0
0ol0003oooooooooo`1;ooooo`;o00008oooool2o`00017ooooo0_l0001Gooooo`;o00001Oooool2
o`0000?ooooo0_l00007ooooo`;o00002_ooool2o`0001cooooo0_l0000Zooooo`007_ooool00ol0
003oooooooooo`0=ooooo`;o0000]oooool2o`0005?ooooo0_l0000Zooooo`007_ooool00ol0003o
ooooooooo`0=ooooo`;o0000]oooool2o`0004[ooooo0_l0000cooooo`007_ooool2o`0000kooooo
0_l0000]ooooo`;o00009_ooool2o`0005?ooooo0_l0000:ooooo`;o0000>Oooool2o`00013ooooo
0_l0000cooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o0000;Oooool2o`0002Kooooo0_l0
001Aooooo`Co00002_ooool2o`0003Wooooo0_l0000>ooooo`;o0000=Oooool001kooooo00?o0000
ooooooooool0B_ooool2o`0001Oooooo0_l0000Eooooo`;o0000;?ooool2o`0000gooooo0_l0001G
ooooo`;o0000=Oooool001kooooo00?o0000ooooooooool0B_ooool2o`0001Oooooo0_l0000Eoooo
o`;o00009Oooool2o`0000Gooooo0_l0000Vooooo`;o0000COooool2o`0002Kooooo000Nooooo`03
o`000?oooooooooo03gooooo0_l0001Rooooo`;o00001?ooool2o`0002Oooooo0_l0000Mooooo`;o
0000;_ooool2o`0002Kooooo000Nooooo`03o`000?oooooooooo03gooooo0_l0001Xooooo`;o0000
A_ooool2o`0005Kooooo000Nooooo`03o`000?oooooooooo043ooooo0_l0000<ooooo`;o0000mooo
ool001kooooo00?o0000ooooooooool0=_ooool2o`0000Sooooo0_l0000<ooooo`;o0000M?ooool2
o`00087ooooo000Nooooo`03o`000?oooooooooo02[ooooo0_l0000:ooooo`;o0000S?ooool2o`00
087ooooo000Nooooo`04o`000?ooooooooooooooo`;o00009oooool2o`000?oooooo4oooool2o`00
00Oooooo000Nooooo`04o`000?ooooooooooooooo`;o00003_ooool2o`000=Cooooo0_l0001Eoooo
o`;o00001oooool001kooooo00?o0000ooooooooool04Oooool2o`0004kooooo0_l00024ooooo`;o
0000G_ooool001kooooo00?o0000ooooooooool0HOooool2o`0003Cooooo0_l0001Wooooo`;o0000
AOooool001kooooo00?o0000ooooooooool0Uoooool2o`0003Cooooo0_l0000aooooo`;o00002ooo
ool2o`0003Sooooo000Nooooo`03o`000?oooooooooo09?ooooo0_l0000Oooooo`;o00002oooool2
o`0000[ooooo0_l0000nooooo`Co0000=_ooool001kooooo00?o0000ooooooooool0Toooool2o`00
01oooooo0_l0000;ooooo`;o00001_ooool2o`0003;ooooo0_l0000?ooooo`?o00003oooool2o`00
02Gooooo000Nooooo`;o0000b_ooool2o`0003;ooooo0_l0000?ooooo`;o00004?ooool2o`0002Go
oooo000Nooooo`03o`000?oooooooooo04Sooooo0_l0000Qooooo`;o0000=oooool2o`0004kooooo
0_l0000Qooooo`;o0000;_ooool001kooooo00?o0000ooooooooool0B?ooool2o`0001[ooooo1?l0
0003ooooo`;o00008?ooool2o`0001Gooooo0_l0001>ooooo`;o00008Oooool2o`0001Gooooo0_l0
000Gooooo`007_ooool00ol0003oooooooooo`1Tooooo`Co00009Oooool2o`0000_ooooo0_l0002B
ooooo`;o00005oooool001kooooo00?o0000ooooooooool04Oooool2o`0000_ooooo0_l0000Zoooo
o`;o0000=oooool2o`0001Gooooo0_l0000Mooooo`;o00002_ooool3o`0007oooooo000Nooooo`03
o`000?oooooooooo017ooooo0_l0000;ooooo`;o00006oooool2o`0000gooooo0_l00002ooooo`;o
00008Oooool2o`00013ooooo0_l0000dooooo`;o00002_ooool3o`0004gooooo0_l0000`ooooo`00
7_ooool00ol0003oooooooooo`0kooooo`;o00004Oooool2o`00027ooooo0_l0002Rooooo`;o0000
<?ooool001kooooo00?o0000ooooooooool0OOooool2o`000:gooooo0_l00004ooooo`;o00004ooo
ool001kooooo00?o0000ooooooooool07oooool2o`0005cooooo0_l0000[ooooo`;o0000P?ooool2
o`0000Cooooo0_l0000Cooooo`007_ooool2o`00023ooooo0_l0000Sooooo`;o00003oooool2o`00
05?ooooo0_l00008ooooo`;o0000TOooool001kooooo0_l0000Uooooo`;o00007_ooool2o`0000oo
oooo0_l0000Vooooo`;o0000=Oooool2o`0001_ooooo0_l0001dooooo`007_ooool00ol0003ooooo
ooooo`0Tooooo`;o00004Oooool2o`0004Cooooo0_l0001@ooooo`So0000L?ooool001kooooo00?o
0000ooooooooool0=oooool4o`0006gooooo0_l0000Uooooo`;o00000_ooool4o`0000oooooo0_l0
001Oooooo`007_ooool00ol0003oooooooooo`0Xooooo`;o00003oooool2o`0004gooooo0_l0000;
ooooo`;o00004Oooool2o`0000oooooo0_l0000Wooooo`;o00000_ooool2o`0005oooooo0003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<
c006ooooo`03o`000?oooooooooo00Kooooo0_l0000Pooooo`;o00001?ooool2o`0000Sooooo0_l0
001>ooooo`;o00002oooool2o`0000_ooooo0_l00007ooooo`;o00003?ooool2o`0002Oooooo0_l0
001Eooooo`;o00003?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool01_ooool2o`0002Kooooo
0_l00008ooooo`;o0000HOooool2o`0000Gooooo0_l00007ooooo`;o0000S?ooool2o`0000cooooo
0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Ko
oooo0ol0000gooooo`;o0000H_ooool2o`000:[ooooo0003ooooo`05o`000?ooooooooooooooool0
00002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000ooooooooool0=oooool2o`00
0003ooooool0003o000002Wooooo0ol0002Oooooo`;o00002_ooool2o`0003;ooooo0003ooooo`05
o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000
ooooooooool0>_ooool2o`0002Wooooo0ol0001=ooooo`;o0000D?ooool2o`0000[ooooo0_l0000b
ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@
4006ooooo`03o`000?oooooooooo047ooooo1?l0001`ooooo`;o0000@?ooool2o`0004kooooo0003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo
00?o0000ooooooooool0@Oooool4o`000;;ooooo0_l0000Looooo`;o0000<?ooool000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003o
ooooooooo`2[ooooo`;o0000J?ooool2o`0001gooooo0_l0000Aooooo`007_ooool00ol0003ooooo
ooooo`2[ooooo`;o0000Qoooool2o`00017ooooo000Nooooo`03o`000?oooooooooo02Gooooo0_l0
001]ooooo`;o00004?ooool2o`0002?ooooo0_l0001jooooo`007_ooool00ol0003oooooooooo`0O
ooooo`;o00001?ooool2o`0001Wooooo0_l0000Sooooo`;o0000;Oooool2o`0000kooooo1?l00009
ooooo`;o00006?ooool2o`00027ooooo0_l0000Qooooo`;o0000=?ooool001kooooo00?o0000oooo
ooooool00_l0000Mooooo`;o00001_ooool2o`0001Oooooo0_l0000Sooooo`;o0000;Oooool2o`00
00kooooo0_l0000;ooooo`;o0000>oooool2o`00027ooooo0_l0000Sooooo`?o00003_ooool001ko
oooo00?o0000ooooooooool00_l0000Eooooo`;o00003_ooool2o`0001oooooo0_l0000?ooooo`;o
0000Zoooool2o`0002kooooo0ol0000>ooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o0000
6_ooool2o`0001?ooooo0_l0000?ooooo`;o0000Doooool2o`0001Oooooo0_l0000mooooo`;o0000
=oooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo00oooooo0_l0000Rooooo`;o0000NOoo
ool2o`0001Oooooo0_l0001fooooo`;o00001_ooool001kooooo00?o0000ooooooooool03oooool2
o`0008oooooo0_l00023ooooo`;o00008?ooool001kooooo00?o0000ooooooooool08Oooool2o`00
05Wooooo0_l0000Rooooo`;o0000C?ooool2o`0003Gooooo0_l0000Pooooo`007_ooool00ol0003o
ooooooooo`0Qooooo`;o0000B?ooool2o`0000oooooo0_l0001`ooooo`;o0000Eoooool001kooooo
00?o0000ooooooooool07Oooool2o`0004cooooo0_l0003Jooooo`007_ooool2o`0001kooooo0_l0
002hooooo`;o0000;_ooool2o`0001gooooo0_l0000Oooooo`007_ooool00ol0003oooooooooo`2<
ooooo`;o0000BOooool2o`0000oooooo0_l0000Kooooo`Co00005Oooool2o`0000Kooooo0_l0000O
ooooo`007_ooool00ol0003oooooooooo`2<ooooo`;o0000F_ooool2o`0001_ooooo0_l00003oooo
o`;o00004_ooool2o`0002Oooooo000Nooooo`03o`000?oooooooooo01gooooo0_l0001Jooooo`;o
00007?ooool2o`0002Gooooo1?l00018ooooo`;o0000>oooool001kooooo00?o0000ooooooooool0
7Oooool2o`0005[ooooo0_l0000Looooo`;o00001Oooool2o`0001kooooo1?l00025ooooo`007_oo
ool00ol0003oooooooooo`1Aooooo`;o0000Boooool2o`0000gooooo0_l00012ooooo`;o0000;ooo
ool2o`0002?ooooo000Nooooo`03o`000?oooooooooo057ooooo0_l0001Gooooo`;o000000?ooooo
o`000?l000007?ooool2o`0002Cooooo0_l0000_ooooo`;o00008oooool001kooooo00?o0000oooo
ooooool0FOooool2o`0002Cooooo0_l0000Yooooo`;o00003Oooool2o`00013ooooo0_l0001joooo
o`007_ooool00ol0003oooooooooo`0Oooooo`;o00007Oooool2o`0001Wooooo0_l00006ooooo`;o
00007?ooool2o`0003Sooooo0_l00002ooooo`;o0000A?ooool2o`0004;ooooo000Nooooo`03o`00
0?oooooooooo00Cooooo0_l0000Iooooo`;o00003_ooool2o`0000gooooo0_l0000Qooooo`;o0000
Boooool2o`0000gooooo0_l00014ooooo`;o00002_ooool2o`0003Kooooo000Nooooo`03o`000?oo
oooooooo00Cooooo0_l0000Qooooo`;o00001_ooool2o`0006Wooooo0_l0000=ooooo`;o00000ooo
ool2o`0002[ooooo0_l00008ooooo`;o0000:Oooool2o`0003Kooooo000Nooooo`03o`000?oooooo
oooo02Oooooo0_l0001aooooo`;o00003Oooool2o`0002?ooooo0_l0000:ooooo`;o00002?ooool2
o`00067ooooo000Nooooo`03o`000?oooooooooo0<kooooo0_l0000Oooooo`;o0000E_ooool001ko
oooo00?o0000ooooooooool02?ooool2o`0000?ooooo1?l0000Looooo`;o0000LOooool2o`0004go
oooo0_l0001Fooooo`007_ooool00ol0003oooooooooo`08ooooo`;o00000oooool4o`0001cooooo
0_l0000Hooooo`;o00000_ooool2o`0001;ooooo0_l0000oooooo`;o0000C?ooool2o`0003Oooooo
0_l0000>ooooo`;o00003_ooool001kooooo00?o0000ooooooooool05?ooool2o`00037ooooo0_l0
0002ooooo`;o00004_ooool2o`0000Wooooo0_l00006ooooo`;o0000N_ooool2o`0000;ooooo0_l0
000cooooo`;o00002oooool2o`000003ooooool0003o000000kooooo000Nooooo`;o00005Oooool2
o`00037ooooo0_l0000@ooooo`;o00003oooool2o`0000Kooooo0_l00006ooooo`;o00000oooool2
o`0004gooooo0_l0000Kooooo`;o00001Oooool2o`00043ooooo0_l00009ooooo`;o00001_ooool0
01kooooo00?o0000ooooooooool0Aoooool2o`0000?ooooo0_l0000;ooooo`;o00002_ooool2o`00
01?ooooo0_l00003ooooo`;o00006oooool2o`00033ooooo0_l0000Kooooo`;o00006Oooool2o`00
00kooooo0_l0000Wooooo`;o00001_ooool001kooooo00?o0000ooooooooool01_ooool2o`0000_o
oooo0_l0000Cooooo`;o00008_ooool2o`0000[ooooo1?l00009ooooo`;o00008Oooool2o`0001;o
oooo0_l0001Xooooo`;o00003_ooool2o`0002oooooo000Nooooo`03o`000?oooooooooo00Gooooo
0ol0000;ooooo`;o00004oooool2o`0002?ooooo0_l00009ooooo`Co00007_ooool2o`000003oooo
ool0003o000000Wooooo0_l0002Oooooo`;o00004Oooool2o`0000Wooooo000Nooooo`03o`000?oo
oooooooo00Gooooo0_l0000[ooooo`;o00001?ooool2o`0001?ooooo0_l0000[ooooo`;o000000?o
ooooo`000?l000002Oooool2o`0004kooooo0_l0001?ooooo`;o00004Oooool2o`0000Wooooo000N
ooooo`03o`000?oooooooooo03;ooooo0_l00004ooooo`;o00006Oooool2o`0000Gooooo0_l0000/
ooooo`;o00003_ooool2o`0002Cooooo0_l0000Hooooo`;o0000KOooool001kooooo00?o0000oooo
ooooool02_ooool2o`0004Oooooo0_l00005ooooo`;o0000;?ooool2o`0000kooooo0_l0000Toooo
o`;o0000Qoooool001kooooo00?o0000ooooooooool02_ooool2o`000>;ooooo0_l0001Gooooo`00
7_ooool00ol0003oooooooooo`0hooooo`;o0000H?ooool2o`0000Sooooo0_l00018ooooo`;o0000
Eoooool001kooooo00?o0000ooooooooool03Oooool2o`0002Wooooo0_l000000ooooooo0000o`00
000aooooo`;o00006oooool2o`0000gooooo0_l00008ooooo`;o00002_ooool2o`00043ooooo0_l0
001Cooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o00008oooool2o`0000?ooooo0_l00002
ooooo`;o0000<Oooool2o`0001_ooooo0_l0000:ooooo`;o00005oooool2o`00043ooooo0_l0001C
ooooo`007_ooool00ol0003oooooooooo`0booooo`;o00000oooool2o`0005kooooo0_l0000<oooo
o`;o0000@?ooool2o`0001?ooooo0_l0000Jooooo`;o00007_ooool2o`0000gooooo000Nooooo`03
o`000?oooooooooo02Sooooo0_l0001kooooo`;o0000@?ooool2o`0001?ooooo0_l0000Jooooo`;o
00002?ooool2o`0001Cooooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`0Xooooo`;o0000
=Oooool2o`0002gooooo0_l0000Eooooo`Co0000=oooool2o`00043ooooo0_l0000Sooooo`007_oo
ool00ol0003oooooooooo`1Oooooo`;o0000;Oooool2o`0001Oooooo0_l0000gooooo`;o00002?oo
ool2o`0005_ooooo000Nooooo`03o`000?oooooooooo00cooooo0_l0002oooooo`;o00006oooool2
o`0000Gooooo0_l0000Pooooo`;o0000<_ooool001kooooo0_l0000=ooooo`;o0000_oooool2o`00
02;ooooo0_l0000<ooooo`;o00004_ooool2o`0003;ooooo000Nooooo`03o`000?oooooooooo09ko
oooo0_l0000Dooooo`;o0000BOooool2o`000003ooooool0003o000000oooooo0_l00005ooooo`;o
0000:oooool001kooooo00?o0000ooooooooool0Hoooool2o`0001_ooooo0_l0000Looooo`;o0000
5?ooool2o`00017ooooo0_l0000iooooo`;o00003oooool2o`0000Gooooo0_l0000Sooooo`;o0000
1_ooool001kooooo00?o0000ooooooooool0Hoooool2o`0001_ooooo0_l0000Looooo`;o00009ooo
ool2o`0005?ooooo0_l0000Qooooo`;o00001_ooool001kooooo00?o0000ooooooooool0GOooool2
o`0003oooooo0_l0001^ooooo`;o00003?ooool2o`0002Wooooo000Nooooo`03o`000?oooooooooo
04[ooooo0_l0000Aooooo`?o0000[_ooool2o`0003Oooooo000Nooooo`03o`000?oooooooooo01?o
oooo0_l0000eooooo`;o00004_ooool2o`0008Gooooo0_l0001Pooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`;o00001?ooool2o`000=3ooooo0_l0001<ooooo`;o00001?ooool2o`0000cooooo
000Nooooo`03o`000?oooooooooo00gooooo0_l0000Yooooo`;o0000nOooool2o`0000Cooooo0_l0
000<ooooo`007_ooool00ol0003oooooooooo`0hooooo`;o00002oooool2o`0006kooooo0_l0000g
ooooo`;o0000Eoooool001kooooo00?o0000ooooooooool0AOooool2o`0000Oooooo0_l0000Doooo
o`;o0000Coooool2o`0000Kooooo0_l0000^ooooo`?o00006oooool2o`0003;ooooo0_l00006oooo
o`007_ooool00ol0003oooooooooo`0jooooo`;o00004_ooool2o`0001Cooooo0_l0000Wooooo`;o
0000;_ooool2o`0001Oooooo0_l0000Eooooo`;o00007?ooool2o`0003;ooooo0_l00006ooooo`00
7_ooool00ol0003oooooooooo`0Tooooo`;o00005?ooool2o`00057ooooo0_l00017ooooo`;o0000
4Oooool2o`0005cooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l00033ooooo`;o0000;ooo
ool2o`0002_ooooo000Dooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`0J
ooooo`;o0000C?ooool2o`0006Sooooo0_l0000oooooo`;o00001Oooool2o`0002_ooooo000Foooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06_ooool2o`0004cooooo0_l0000=oooo
o`;o00007_ooool2o`0000Oooooo0_l0000`ooooo`;o0000?oooool2o`0003;ooooo000Fooooo`03
o`000?oooooooooo00Gooooo0ol0001Mooooo`;o00006?ooool2o`0001kooooo0_l00007ooooo`;o
0000YOooool001Kooooo00?o0000ooooooooool0IOooool2o`000>Sooooo000Fooooo`03o`000?oo
oooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0
003oooooooooo`3ooooooe3ooooo000Dooooo`03oeEEEOmVIVKo00000?ooooooD_ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.04415 .27095 Mdot
.26424 .91519 Mdot
.08071 .12322 Mdot
.45628 .85366 Mdot
.19973 .20009 Mdot
.99928 .37124 Mdot
.99898 .19858 Mdot
.11311 .52833 Mdot
.09636 .92907 Mdot
.34757 .01677 Mdot
.59725 .89486 Mdot
.17478 .71002 Mdot
.46101 .3094 Mdot
.52442 .24352 Mdot
.38885 .38469 Mdot
.48292 .55334 Mdot
.58147 .97358 Mdot
.17948 .33741 Mdot
.60297 .02009 Mdot
.98913 .68714 Mdot
.47894 .85375 Mdot
.2704 .0878 Mdot
.08197 .21237 Mdot
.06933 .65921 Mdot
.84503 .45672 Mdot
.3906 .48632 Mdot
.83187 .7141 Mdot
.6843 .40261 Mdot
.50036 .84178 Mdot
.24464 .0019 Mdot
.7934 .94412 Mdot
.44119 .1156 Mdot
.60203 .22765 Mdot
.08854 .1389 Mdot
.82291 .32754 Mdot
.82362 .73317 Mdot
.41435 .97607 Mdot
.40135 .54187 Mdot
.11015 .35716 Mdot
.09054 .88845 Mdot
.92796 .1923 Mdot
.35625 .78102 Mdot
.36759 .201 Mdot
.26701 .23945 Mdot
.8886 .20042 Mdot
.59591 .58731 Mdot
.79353 .04423 Mdot
.53878 .98344 Mdot
.067 .13899 Mdot
.22833 .06386 Mdot
.98691 .92129 Mdot
.6205 .57595 Mdot
.05938 .91361 Mdot
.01057 .38867 Mdot
.99391 .53755 Mdot
.02738 .99607 Mdot
.68783 .00575 Mdot
.12085 .7807 Mdot
.29771 .37147 Mdot
.15466 .91022 Mdot
.09801 .28662 Mdot
.95744 .82707 Mdot
.23359 .9202 Mdot
.49697 .58763 Mdot
.87148 .41448 Mdot
.28551 .02418 Mdot
.17068 .91394 Mdot
.60299 .90104 Mdot
.06126 .07608 Mdot
.92902 .16868 Mdot
.89611 .82491 Mdot
.03449 .42744 Mdot
.08911 .57515 Mdot
.39582 .70824 Mdot
.44634 .22024 Mdot
.87091 .17162 Mdot
.06834 .82053 Mdot
.24222 .39804 Mdot
.78785 .63636 Mdot
.2317 .37608 Mdot
.49618 .85937 Mdot
.71987 .92444 Mdot
.20814 .8464 Mdot
.86785 .43665 Mdot
.63553 .63464 Mdot
.89335 .94031 Mdot
.41973 .21554 Mdot
.11186 .69772 Mdot
.54085 .89375 Mdot
.55807 .6044 Mdot
.11397 .84093 Mdot
.66108 .46257 Mdot
.14953 .58048 Mdot
.65835 .32749 Mdot
.21647 .39466 Mdot
.28137 .51256 Mdot
.30309 .03959 Mdot
.723 .34194 Mdot
.6044 .10823 Mdot
.33408 .90454 Mdot
.5062 .42282 Mdot
.75401 .57181 Mdot
.86394 .93763 Mdot
.34044 .39092 Mdot
.54032 .57358 Mdot
.19807 .67658 Mdot
.45518 .93985 Mdot
.83863 .50231 Mdot
.18009 .83653 Mdot
.51436 .80023 Mdot
.28215 .29909 Mdot
.78386 .7483 Mdot
.90301 .38962 Mdot
.34332 .41141 Mdot
.0631 .59321 Mdot
.59328 .76296 Mdot
.28055 .66182 Mdot
.97582 .82648 Mdot
.56983 .52535 Mdot
.54167 .78823 Mdot
.72305 .31792 Mdot
.56787 .27398 Mdot
.06381 .55572 Mdot
.31624 .00075 Mdot
.4909 .52454 Mdot
.10809 .44956 Mdot
.55063 .52213 Mdot
.54281 .83706 Mdot
.69139 .73938 Mdot
.74651 .91648 Mdot
.70383 .0022 Mdot
.03454 .65608 Mdot
.12698 .3971 Mdot
.62386 .75633 Mdot
.2725 .41012 Mdot
.19222 .27541 Mdot
.38993 .91225 Mdot
.03929 .33744 Mdot
.54014 .68067 Mdot
.42029 .0468 Mdot
.19737 .25397 Mdot
.03023 .27139 Mdot
.81735 .84582 Mdot
.97283 .27837 Mdot
.50325 .37821 Mdot
.37712 .68379 Mdot
.57783 .7728 Mdot
.91365 .2237 Mdot
.33067 .36134 Mdot
.07625 .21787 Mdot
.20562 .83182 Mdot
.33038 .22857 Mdot
.80699 .16382 Mdot
.80614 .9357 Mdot
.17153 .35942 Mdot
.5833 .50119 Mdot
.33008 .55992 Mdot
.55884 .36191 Mdot
.62382 .67174 Mdot
.08772 .61465 Mdot
.63949 .46535 Mdot
.16691 .9576 Mdot
.98009 .18118 Mdot
.93415 .29842 Mdot
.86847 .62862 Mdot
.43585 .75963 Mdot
.96469 .67058 Mdot
.50805 .55995 Mdot
.40236 .54117 Mdot
.00912 .94772 Mdot
.91732 .41194 Mdot
.47263 .24814 Mdot
.41834 .16307 Mdot
.27606 .46489 Mdot
.71633 .44599 Mdot
.64048 .09026 Mdot
.37418 .56294 Mdot
.55849 .65087 Mdot
.39129 .33281 Mdot
.20965 .38119 Mdot
.03126 .32574 Mdot
.87365 .20089 Mdot
.84783 .81325 Mdot
.16752 .2493 Mdot
.7525 .32331 Mdot
.79862 .35164 Mdot
.37542 .23991 Mdot
.36963 .34497 Mdot
.50579 .44475 Mdot
.16852 .55024 Mdot
.36352 .19063 Mdot
.14157 .44437 Mdot
.72315 .62997 Mdot
.0626 .11931 Mdot
.29718 .04208 Mdot
.66204 .13447 Mdot
.49814 .39589 Mdot
.50569 .28326 Mdot
.31588 .34202 Mdot
.11961 .05455 Mdot
.11554 .74354 Mdot
.36024 .26658 Mdot
.96225 .33246 Mdot
.11431 .54699 Mdot
.93014 .6387 Mdot
.36291 .31881 Mdot
.11178 .33856 Mdot
.48343 .41073 Mdot
.45528 .27749 Mdot
.93717 .52604 Mdot
.44841 .20765 Mdot
.59236 .09333 Mdot
.76703 .91707 Mdot
.60548 .45936 Mdot
.39877 .45195 Mdot
.78057 .49409 Mdot
.94169 .95202 Mdot
.22978 .13591 Mdot
.29614 .39636 Mdot
.01859 .88521 Mdot
.84784 .50014 Mdot
.60698 .56716 Mdot
.59887 .76626 Mdot
.82725 .97456 Mdot
.53171 .53613 Mdot
.43937 .79303 Mdot
.94707 .38202 Mdot
.54778 .83301 Mdot
.6277 .80214 Mdot
.49026 .86525 Mdot
.58949 .12657 Mdot
.78605 .05583 Mdot
.20171 .53305 Mdot
.76817 .63465 Mdot
.94851 .52129 Mdot
.70231 .6207 Mdot
.56154 .74464 Mdot
.52066 .96729 Mdot
.46519 .79798 Mdot
.9053 .91606 Mdot
.05234 .88396 Mdot
.85116 .36844 Mdot
.85154 .42724 Mdot
.65756 .2916 Mdot
.27464 .87398 Mdot
.90359 .0944 Mdot
.52954 .05425 Mdot
.93595 .5199 Mdot
.80193 .17003 Mdot
.2036 .65864 Mdot
.90704 .24941 Mdot
.71586 .92957 Mdot
.36895 .57916 Mdot
.70559 .32172 Mdot
.32151 .88026 Mdot
.89838 .33729 Mdot
.7673 .9959 Mdot
.02451 .1419 Mdot
.19244 .14125 Mdot
.1684 .72254 Mdot
.38412 .42501 Mdot
.06003 .48656 Mdot
.33524 .54922 Mdot
.62528 .71825 Mdot
.19472 .56584 Mdot
.72713 .49446 Mdot
.51708 .73303 Mdot
.38843 .77191 Mdot
.57834 .79092 Mdot
.67545 .11966 Mdot
.62333 .82346 Mdot
.93754 .53479 Mdot
.717 .21004 Mdot
.19836 .96102 Mdot
.30048 .30884 Mdot
.02886 .5409 Mdot
.36894 .38113 Mdot
.9945 .24609 Mdot
.48492 .73699 Mdot
.57622 .18399 Mdot
.33402 .00583 Mdot
.94221 .60534 Mdot
.19243 .95474 Mdot
.8772 .99829 Mdot
.92053 .48323 Mdot
.38082 .7343 Mdot
.66735 .63005 Mdot
.737 .52818 Mdot
.75483 .80846 Mdot
.97725 .74535 Mdot
.51834 .97686 Mdot
.31503 .15222 Mdot
.49649 .15566 Mdot
.20608 .74581 Mdot
.66893 .71487 Mdot
.34996 .37916 Mdot
.98808 .93268 Mdot
.09401 .45902 Mdot
.89166 .38041 Mdot
.32605 .28853 Mdot
.10693 .61849 Mdot
.86257 .1556 Mdot
.98145 .58535 Mdot
.48641 .61052 Mdot
.58363 .91887 Mdot
.15467 .29084 Mdot
.20054 .6659 Mdot
.52174 .27475 Mdot
.01165 .24952 Mdot
.09455 .48125 Mdot
.46435 .49997 Mdot
.91952 .5355 Mdot
.5137 .46396 Mdot
.43813 .82343 Mdot
.19979 .62349 Mdot
.68725 .90765 Mdot
.45903 .23198 Mdot
.3549 .44914 Mdot
.03139 .48927 Mdot
.38599 .29968 Mdot
.00012 .37299 Mdot
.64598 .69287 Mdot
.24098 .27831 Mdot
.53201 .39055 Mdot
.22242 .59416 Mdot
.51182 .12173 Mdot
.2298 .59084 Mdot
.1434 .32211 Mdot
.90195 .47353 Mdot
.81199 .74347 Mdot
.09326 .20427 Mdot
.34594 .77099 Mdot
.84896 .98593 Mdot
.7875 .67274 Mdot
.09178 .84697 Mdot
.02448 .57833 Mdot
.15704 .53479 Mdot
.02623 .18749 Mdot
.12121 .04374 Mdot
.15809 .37854 Mdot
.73024 .71526 Mdot
.64844 .11179 Mdot
.18127 .22694 Mdot
.29985 .44293 Mdot
.06339 .06491 Mdot
.57327 .23757 Mdot
.57421 .30492 Mdot
.59362 .98642 Mdot
.09681 .8902 Mdot
.69179 .55824 Mdot
.31753 .98559 Mdot
.36476 .81335 Mdot
.97607 .1223 Mdot
.60775 .8153 Mdot
.4052 .10452 Mdot
.34779 .24337 Mdot
.35194 .59121 Mdot
.98832 .8378 Mdot
.08367 .07825 Mdot
.37631 .00771 Mdot
.88628 .0458 Mdot
.48775 .13804 Mdot
.01847 .22099 Mdot
.26455 .34653 Mdot
.85494 .78746 Mdot
.76445 .07063 Mdot
.01882 .10536 Mdot
.03026 .81499 Mdot
.92902 .39782 Mdot
.94994 .75484 Mdot
.20534 .06866 Mdot
.54113 .74497 Mdot
.20589 .95841 Mdot
.97191 .49603 Mdot
.32405 .65832 Mdot
.62765 .08858 Mdot
.69279 .57339 Mdot
.12584 .27031 Mdot
.23648 .38676 Mdot
.85364 .17959 Mdot
.27602 .39218 Mdot
.24537 .57117 Mdot
.1991 .82566 Mdot
.65802 .51038 Mdot
.12128 .25448 Mdot
.83428 .86081 Mdot
.9124 .76601 Mdot
.58583 .34055 Mdot
.90666 .78611 Mdot
.03795 .47902 Mdot
.8793 .03324 Mdot
.63684 .86049 Mdot
.71017 .91234 Mdot
.13562 .23413 Mdot
.84504 .79645 Mdot
.8107 .82637 Mdot
.12118 .08488 Mdot
.54352 .86427 Mdot
.31306 .02582 Mdot
.44481 .11359 Mdot
.19736 .74735 Mdot
.50722 .99177 Mdot
.21938 .76996 Mdot
.358 .43366 Mdot
.39145 .39348 Mdot
.61332 .67073 Mdot
.5508 .89098 Mdot
.6989 .05156 Mdot
.3979 .29361 Mdot
.98008 .76758 Mdot
.22633 .70976 Mdot
.99735 .52992 Mdot
.2662 .95025 Mdot
.94095 .27433 Mdot
.08265 .42089 Mdot
.33863 .34394 Mdot
.08243 .02394 Mdot
.73459 .35105 Mdot
.52744 .18472 Mdot
.62132 .85958 Mdot
.08619 .4891 Mdot
.55222 .64017 Mdot
.58537 .59233 Mdot
.38538 .50352 Mdot
.45399 .04308 Mdot
.79439 .82983 Mdot
.15362 .79089 Mdot
.07295 .52719 Mdot
.54556 .33329 Mdot
.13925 .84506 Mdot
.93118 .48644 Mdot
.99051 .49584 Mdot
.27736 .74409 Mdot
.56104 .35158 Mdot
.87247 .38446 Mdot
.14693 .46273 Mdot
.6959 .26467 Mdot
.64645 .6456 Mdot
.34709 .71729 Mdot
.2373 .02294 Mdot
.15427 .80984 Mdot
.04678 .84816 Mdot
.8578 .02733 Mdot
.3641 .95567 Mdot
.15892 .95085 Mdot
.60915 .21027 Mdot
.84783 .81823 Mdot
.21404 .11743 Mdot
.7123 .95089 Mdot
.31895 .5786 Mdot
.05373 .4136 Mdot
.75814 .0506 Mdot
.76571 .20155 Mdot
.82573 .99522 Mdot
.39861 .54332 Mdot
.88633 .17517 Mdot
.64006 .87659 Mdot
.70719 .93924 Mdot
.99116 .93115 Mdot
.2898 .73182 Mdot
.23182 .34045 Mdot
.32135 .73649 Mdot
.12887 .02282 Mdot
.39161 .86431 Mdot
.19916 .47883 Mdot
.02738 .17376 Mdot
.58504 .17285 Mdot
.4459 .20585 Mdot
.12004 .32485 Mdot
.92014 .0817 Mdot
.4261 .89414 Mdot
.82648 .59213 Mdot
.29435 .61217 Mdot
.04182 .95918 Mdot
.06969 .88238 Mdot
.36527 .46482 Mdot
.46427 .21794 Mdot
.74414 .59331 Mdot
.67507 .30056 Mdot
.20878 .71506 Mdot
.06285 .20214 Mdot
.02192 .31429 Mdot
.42854 .79498 Mdot
.64159 .38765 Mdot
.53248 .08729 Mdot
.34045 .11868 Mdot
.11118 .31338 Mdot
.73002 .09763 Mdot
.32756 .95404 Mdot
.48661 .70566 Mdot
.94926 .86827 Mdot
.66142 .96779 Mdot
.1879 .42461 Mdot
.40188 .01199 Mdot
.86277 .09124 Mdot
.27204 .34562 Mdot
.57894 .06732 Mdot
.94819 .94627 Mdot
.19714 .61461 Mdot
.02193 .949 Mdot
.71688 .79129 Mdot
.42699 .53031 Mdot
.51333 .23775 Mdot
.02163 .16961 Mdot
.82264 .43401 Mdot
.45911 .12613 Mdot
.26926 .84033 Mdot
.24154 .18917 Mdot
.0242 .67652 Mdot
.13917 .80754 Mdot
.56979 .88325 Mdot
.31872 .39884 Mdot
.20831 .45465 Mdot
.68763 .01285 Mdot
.55152 .97171 Mdot
.98331 .96093 Mdot
.39491 .96254 Mdot
.90948 .67163 Mdot
.59742 .14132 Mdot
.48542 .8778 Mdot
.48873 .6125 Mdot
.38232 .29323 Mdot
.69491 .52179 Mdot
.1118 .53345 Mdot
.84347 .7694 Mdot
.21873 .2307 Mdot
.15033 .41304 Mdot
.68008 .08036 Mdot
.35611 .79839 Mdot
.85148 .67806 Mdot
.65277 .64594 Mdot
.10002 .30298 Mdot
.4297 .35714 Mdot
.47391 .00186 Mdot
.3376 .58849 Mdot
.40501 .68573 Mdot
.23011 .62323 Mdot
.98311 .49042 Mdot
.34641 .53536 Mdot
.87094 .69481 Mdot
.28126 .07078 Mdot
.92555 .2437 Mdot
.56629 .09452 Mdot
.69079 .61277 Mdot
.47687 .24387 Mdot
.63882 .50956 Mdot
.08861 .39565 Mdot
.93891 .52683 Mdot
.91986 .51119 Mdot
.21211 .03803 Mdot
.76071 .24492 Mdot
.31046 .63699 Mdot
.51662 .6851 Mdot
.61427 .74567 Mdot
.62521 .28111 Mdot
.82469 .37899 Mdot
.63167 .12944 Mdot
.41788 .78293 Mdot
.76937 .73139 Mdot
.28135 .1104 Mdot
.87962 .7949 Mdot
.09601 .9698 Mdot
.28918 .16079 Mdot
.25887 .75194 Mdot
.58883 .43431 Mdot
.83369 .33037 Mdot
.96254 .98074 Mdot
.18591 .27708 Mdot
.23455 .04162 Mdot
.30837 .00127 Mdot
.44026 .54167 Mdot
.8766 .99364 Mdot
.24859 .6044 Mdot
.87892 .4299 Mdot
.32684 .5795 Mdot
.50454 .03571 Mdot
.64909 .91183 Mdot
.48782 .09296 Mdot
.05474 .75852 Mdot
.64811 .14682 Mdot
.16388 .68379 Mdot
.0724 .36151 Mdot
.40103 .45239 Mdot
.1719 .15227 Mdot
.24137 .86781 Mdot
.38374 .45338 Mdot
.28568 .45721 Mdot
.55779 .66221 Mdot
.99616 .37124 Mdot
.02708 .26963 Mdot
.86845 .10371 Mdot
.74006 .26048 Mdot
.63944 .90292 Mdot
.45055 .08242 Mdot
.23436 .55386 Mdot
.64066 .78453 Mdot
.26924 .27953 Mdot
.23844 .92833 Mdot
.02449 .41956 Mdot
.18207 .67667 Mdot
.60697 .38701 Mdot
.54677 .65318 Mdot
.33274 .58806 Mdot
.40762 .67858 Mdot
.11867 .48634 Mdot
.20486 .7713 Mdot
.34749 .35487 Mdot
.95011 .84257 Mdot
.11305 .45832 Mdot
.55636 .86618 Mdot
.67825 .61686 Mdot
.40954 .39622 Mdot
.33579 .25261 Mdot
.18074 .51856 Mdot
.50216 .86326 Mdot
.65953 .11442 Mdot
.51456 .89703 Mdot
.7798 .30349 Mdot
.7744 .36777 Mdot
.64132 .16126 Mdot
.42314 .43926 Mdot
.43679 .01909 Mdot
.03259 .97454 Mdot
.71834 .80449 Mdot
.99374 .895 Mdot
.76511 .82305 Mdot
.95078 .06237 Mdot
.89144 .40687 Mdot
.76011 .38085 Mdot
.40892 .07325 Mdot
.41805 .92331 Mdot
.50358 .55843 Mdot
.78162 .65684 Mdot
.31643 .35245 Mdot
.18779 .56886 Mdot
.05529 .56775 Mdot
.05838 .441 Mdot
.14911 .65033 Mdot
.98324 .86777 Mdot
.53416 .94275 Mdot
.52071 .50616 Mdot
.62618 .66623 Mdot
.52331 .71039 Mdot
.2757 .89637 Mdot
.45147 .95307 Mdot
.97672 .16775 Mdot
.78317 .54662 Mdot
.0212 .44591 Mdot
.62716 .69698 Mdot
.6696 .58177 Mdot
.67834 .43806 Mdot
.43522 .04541 Mdot
.29365 .50385 Mdot
.66214 .82735 Mdot
.23356 .00587 Mdot
.21908 .49089 Mdot
.55395 .10111 Mdot
.75041 .66 Mdot
.10234 .74673 Mdot
.60368 .06166 Mdot
.26995 .95617 Mdot
.33334 .04126 Mdot
.51668 .26908 Mdot
.30592 .9788 Mdot
.53784 .26066 Mdot
.38273 .28909 Mdot
.7564 .96808 Mdot
.54532 .74551 Mdot
.05346 .27683 Mdot
.37289 .93964 Mdot
.26293 .93077 Mdot
.16659 .42491 Mdot
.26594 .5793 Mdot
.46212 .58171 Mdot
.9687 .90498 Mdot
.14546 .05689 Mdot
.16157 .50234 Mdot
.56359 .84054 Mdot
.61993 .90337 Mdot
.50541 .06639 Mdot
.08261 .09082 Mdot
.71761 .3071 Mdot
.62384 .68125 Mdot
.91815 .44373 Mdot
.87271 .08084 Mdot
.20736 .06776 Mdot
.49688 .24869 Mdot
.11754 .1908 Mdot
.77175 .60189 Mdot
.23874 .30736 Mdot
.88538 .80988 Mdot
.15169 .92857 Mdot
.18022 .86576 Mdot
.39773 .33771 Mdot
.80705 .55217 Mdot
.45746 .63124 Mdot
.74081 .43087 Mdot
.71666 .27714 Mdot
.58667 .78241 Mdot
.52611 .27832 Mdot
.60754 .73139 Mdot
.3031 .44907 Mdot
.30292 .46822 Mdot
.9096 .83262 Mdot
.40231 .81319 Mdot
.38372 .18016 Mdot
.82406 .34186 Mdot
.42904 .25047 Mdot
.95265 .26137 Mdot
.00509 .19398 Mdot
.71202 .94424 Mdot
.66482 .60903 Mdot
.01124 .79954 Mdot
.56517 .97757 Mdot
.25305 .91161 Mdot
.17556 .20726 Mdot
.40183 .96581 Mdot
.89452 .94488 Mdot
.9148 .66385 Mdot
.23105 .44309 Mdot
.30432 .37953 Mdot
.17645 .49619 Mdot
.05296 .93822 Mdot
.71969 .12452 Mdot
.41126 .6859 Mdot
.59245 .68178 Mdot
.9872 .41875 Mdot
.927 .10066 Mdot
.89154 .06635 Mdot
.24202 .43363 Mdot
.94286 .00104 Mdot
.60269 .6612 Mdot
.91768 .04024 Mdot
.85531 .19766 Mdot
.66616 .76926 Mdot
.08098 .76444 Mdot
.93523 .06701 Mdot
.88556 .18522 Mdot
.16381 .74526 Mdot
.18052 .76795 Mdot
.70813 .15505 Mdot
.19699 .59906 Mdot
.65256 .68958 Mdot
.04982 .18959 Mdot
.8029 .11194 Mdot
.29059 .99208 Mdot
.63213 .9741 Mdot
.2795 .72353 Mdot
.78457 .8554 Mdot
.74086 .74455 Mdot
.52141 .28663 Mdot
.4006 .06547 Mdot
.33469 .42966 Mdot
.47621 .06854 Mdot
.43916 .86164 Mdot
.55964 .11671 Mdot
.62907 .86776 Mdot
.84266 .39501 Mdot
.69137 .6106 Mdot
.33521 .62292 Mdot
.04967 .44027 Mdot
.12844 .96763 Mdot
.40149 .52517 Mdot
.62494 .5547 Mdot
.1222 .83645 Mdot
.48552 .6085 Mdot
.03276 .34387 Mdot
.18266 .95819 Mdot
.33527 .05263 Mdot
.34713 .09757 Mdot
.77203 .67043 Mdot
.41662 .12009 Mdot
.34027 .78162 Mdot
.05978 .2693 Mdot
.21576 .64638 Mdot
.95697 .35107 Mdot
.68951 .54366 Mdot
.14627 .43896 Mdot
.28694 .90345 Mdot
.18364 .61452 Mdot
.23345 .67843 Mdot
.00356 .51122 Mdot
.11435 .28881 Mdot
.41499 .24874 Mdot
.11988 .54926 Mdot
.8902 .14901 Mdot
.98948 .23043 Mdot
.43232 .50199 Mdot
.63566 .97388 Mdot
.30294 .26963 Mdot
.91631 .05687 Mdot
.6239 .14295 Mdot
.18483 .54994 Mdot
.8027 .61991 Mdot
.86726 .38522 Mdot
.18111 .44369 Mdot
.07329 .04121 Mdot
.16562 .19536 Mdot
.49652 .51637 Mdot
.98222 .31412 Mdot
.42168 .93123 Mdot
.54 .99127 Mdot
.50303 .88259 Mdot
.95243 .27305 Mdot
.67713 .28611 Mdot
.07719 .21888 Mdot
.14386 .29205 Mdot
.38541 .52755 Mdot
.15561 .82982 Mdot
.69651 .45377 Mdot
.28789 .58142 Mdot
.91004 .58367 Mdot
.66574 .22319 Mdot
.04015 .73254 Mdot
.69068 .83408 Mdot
.37799 .54935 Mdot
.4656 .48051 Mdot
.12096 .32333 Mdot
.74635 .48044 Mdot
.85215 .3881 Mdot
.866 .55383 Mdot
.57057 .40611 Mdot
.39315 .53021 Mdot
.84786 .00024 Mdot
.55329 .94567 Mdot
.69972 .60273 Mdot
.82847 .16654 Mdot
.37159 .67739 Mdot
.54567 .26985 Mdot
.30648 .6874 Mdot
.50878 .90733 Mdot
.29145 .91087 Mdot
.17091 .00593 Mdot
.17071 .34292 Mdot
.5258 .8995 Mdot
.9255 .69389 Mdot
.97155 .02822 Mdot
.4743 .58333 Mdot
.82541 .31895 Mdot
.77344 .55019 Mdot
.34788 .3408 Mdot
.97143 .05828 Mdot
.87563 .99501 Mdot
.51334 .92708 Mdot
.24441 .15638 Mdot
.64174 .31397 Mdot
.69343 .24141 Mdot
.08059 .09268 Mdot
.40317 .2839 Mdot
.56683 .77766 Mdot
.18038 .049 Mdot
.33775 .3171 Mdot
.22717 .37661 Mdot
.4154 .37633 Mdot
.16414 .85757 Mdot
.83783 .59929 Mdot
.11004 .33179 Mdot
.88893 .92858 Mdot
.76237 .42264 Mdot
.03466 .92224 Mdot
.34004 .97562 Mdot
.22936 .11 Mdot
.26723 .33443 Mdot
.75306 .86124 Mdot
.00104 .26948 Mdot
.53875 .19515 Mdot
.45773 .46267 Mdot
.20946 .62694 Mdot
.61849 .89307 Mdot
.18331 .32935 Mdot
.08844 .80541 Mdot
.34835 .20347 Mdot
.41002 .14301 Mdot
.73555 .14431 Mdot
.56612 .35271 Mdot
.29364 .41946 Mdot
.7123 .60639 Mdot
.37441 .13764 Mdot
.85227 .1404 Mdot
.50507 .79749 Mdot
.26963 .84777 Mdot
.87172 .06806 Mdot
.33171 .03464 Mdot
.29478 .67425 Mdot
.59383 .14081 Mdot
.33854 .72001 Mdot
.4873 .4864 Mdot
.56264 .47327 Mdot
.2747 .94967 Mdot
.16344 .30041 Mdot
.2342 .13542 Mdot
.55994 .98524 Mdot
.07525 .27601 Mdot
.58725 .55612 Mdot
.27646 .16763 Mdot
.10104 .65123 Mdot
.9757 .18273 Mdot
.96612 .07478 Mdot
.20758 .77547 Mdot
.42754 .85493 Mdot
.70421 .66275 Mdot
.12387 .31988 Mdot
.02962 .41752 Mdot
.96905 .62601 Mdot
.67038 .44514 Mdot
.19266 .37067 Mdot
.92613 .82146 Mdot
.74862 .46814 Mdot
.43856 .84165 Mdot
.79357 .49775 Mdot
.28389 .71769 Mdot
.89378 .5215 Mdot
.32014 .38883 Mdot
.51418 .22888 Mdot
.29913 .83292 Mdot
.06373 .21919 Mdot
.39035 .64383 Mdot
.9773 .2926 Mdot
.38567 .97336 Mdot
.1344 .53316 Mdot
.60572 .13217 Mdot
.91605 .16583 Mdot
.7018 .8688 Mdot
.90081 .72687 Mdot
.18094 .16239 Mdot
.70689 .26938 Mdot
.17744 .59354 Mdot
.41027 .91917 Mdot
.59558 .81297 Mdot
.79759 .94717 Mdot
.52984 .97648 Mdot
.59594 .97483 Mdot
.75588 .55098 Mdot
.73399 .57274 Mdot
.40303 .08927 Mdot
.82894 .59973 Mdot
.87459 .50949 Mdot
.16646 .92075 Mdot
.71608 .0183 Mdot
.39349 .4416 Mdot
.06541 .26056 Mdot
.01373 .9678 Mdot
.85882 .37022 Mdot
.2665 .78677 Mdot
.47755 .66441 Mdot
.51417 .5042 Mdot
.46214 .02125 Mdot
.48211 .10433 Mdot
.19576 .05312 Mdot
.84541 .9333 Mdot
.77861 .68294 Mdot
.77125 .70562 Mdot
.65084 .06567 Mdot
.76941 .84213 Mdot
.1751 .16041 Mdot
.85171 .98947 Mdot
.05227 .1988 Mdot
.22138 .62408 Mdot
.06327 .38615 Mdot
.07571 .05872 Mdot
.96157 .94747 Mdot
.70801 .46579 Mdot
.2642 .32235 Mdot
.21134 .58972 Mdot
.16893 .63717 Mdot
.32124 .3726 Mdot
.92934 .11941 Mdot
.34825 .91071 Mdot
.54796 .23333 Mdot
.18896 .87952 Mdot
.8335 .78634 Mdot
.30648 .3553 Mdot
.28269 .76831 Mdot
.06247 .16135 Mdot
.59474 .55327 Mdot
.27573 .76552 Mdot
.3087 .67752 Mdot
.76841 .96839 Mdot
.85876 .71719 Mdot
.80284 .99786 Mdot
.09521 .59801 Mdot
.46807 .15375 Mdot
.03107 .75628 Mdot
.60146 .51424 Mdot
.21472 .16146 Mdot
.49472 .80905 Mdot
.31556 .43075 Mdot
.24435 .33545 Mdot
.9753 .43083 Mdot
.09805 .04127 Mdot
.1818 .82323 Mdot
.7427 .55282 Mdot
.61386 .08099 Mdot
.57473 .75713 Mdot
.26103 .59187 Mdot
.01274 .03641 Mdot
.19571 .79585 Mdot
.16151 .75613 Mdot
.57783 .7861 Mdot
.76418 .68238 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool02_ooool2o`000003ooooool0003ooooo00kooooo00Go0000ooooool0
003o0000ooooo`02o`0000Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo0ol0000=oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool03?ooool2o`0000oooooo00?o0000oooo
ooooool02_ooool2o`000003ooooool0003ooooo00oooooo00?o0000ooooooooool00_ooool001ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool00oooool2o`0000Wooooo00?o0000ooooooooool01oooool2o`000005
ooooool0003o0000ooooool000003oooool00ol0003oooooooooo`07ooooo`;o00001?ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool2o`00
00Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool02Oooool2o`0000;ooooo0ol0000=ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003o
ooooooooo`0cooooo`;o00004oooool2o`0001kooooo0_l0000<ooooo`;o0000I?ooool2o`0006Wo
oooo000Nooooo`03o`000?oooooooooo07Kooooo0_l00007ooooo`;o0000F_ooool2o`0006[ooooo
000Nooooo`03o`000?oooooooooo06gooooo0_l0000@ooooo`;o0000F_ooool2o`0006[ooooo000N
ooooo`03o`000?oooooooooo06gooooo0_l0000Kooooo`;o0000FOooool2o`00063ooooo000Noooo
o`03o`000?oooooooooo02Kooooo0_l0000Qooooo`;o0000?oooool2o`0000Kooooo0_l0000/oooo
o`;o00008oooool2o`00063ooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0000=ooooo`;o
00008Oooool2o`0000kooooo0_l00007ooooo`;o0000;_ooool2o`0002cooooo0_l00025ooooo`00
7_ooool00ol0003oooooooooo`0Gooooo`;o0000@?ooool2o`0000Oooooo0_l0002_ooooo`;o0000
8oooool2o`0000gooooo000Nooooo`03o`000?oooooooooo0?oooooo5?ooool2o`0002?ooooo0_l0
000=ooooo`007_ooool00ol0003oooooooooo`1Xooooo`;o0000/?ooool2o`0002_ooooo000Noooo
o`03o`000?oooooooooo00;o0000?oooool2o`0002Gooooo0_l0000fooooo`;o0000N?ooool2o`00
02_ooooo000Nooooo`03o`000?oooooooooo00;o00004_ooool2o`0000Kooooo0_l0000Sooooo`;o
00006oooool2o`0000Sooooo0_l0000fooooo`;o0000Q?ooool2o`0001oooooo000Nooooo`03o`00
0?oooooooooo01Cooooo0_l00006ooooo`;o00001Oooool2o`0002?ooooo0_l0000Booooo`Co0000
2?ooool2o`0002Gooooo0_l0001]ooooo`;o00009_ooool2o`0001oooooo000Nooooo`03o`000?oo
oooooooo02?ooooo0_l0000Sooooo`;o00004_ooool2o`0002Oooooo0_l00002ooooo`;o00001?oo
ool2o`0006gooooo0_l0000Looooo`;o0000:Oooool001kooooo00?o0000ooooooooool0=oooool2
o`0004cooooo0_l00002ooooo`;o0000Ioooool2o`0002Sooooo0_l0000Yooooo`007_ooool2o`00
03Sooooo0_l00003ooooo`;o0000:oooool2o`0007Cooooo0_l0000Aooooo`;o0000Doooool001ko
oooo00?o0000ooooooooool08oooool2o`0001Oooooo0_l0000[ooooo`;o0000?Oooool2o`0003Go
oooo0_l0000Jooooo`;o0000B_ooool001kooooo00?o0000ooooooooool05?ooool2o`0000gooooo
0_l00006ooooo`;o0000Noooool2o`00057ooooo0_l0000Yooooo`;o00004?ooool2o`0000gooooo
000Nooooo`03o`000?oooooooooo01Cooooo0_l0000Eooooo`;o0000Toooool2o`0006Cooooo0_l0
0009ooooo`;o00001Oooool2o`0000gooooo000Nooooo`03o`000?oooooooooo013ooooo0_l0000d
ooooo`;o0000=_ooool2o`00043ooooo0_l0000=ooooo`;o0000H?ooool2o`0001Cooooo000Noooo
o`03o`000?oooooooooo013ooooo0_l0000]ooooo`;o00001Oooool2o`0003Kooooo0_l0000Goooo
o`;o00001oooool2o`0001Kooooo0_l0000Eooooo`;o0000A_ooool2o`0000Gooooo0_l0000<oooo
o`;o00006Oooool001kooooo00?o0000ooooooooool0?oooool2o`0001Kooooo0_l0000nooooo`;o
00001oooool2o`0001Kooooo0_l0000jooooo`;o00008Oooool2o`0000Gooooo0_l0000<ooooo`;o
00006Oooool001kooooo00?o0000ooooooooool0Eoooool2o`0002Sooooo0_l0001aooooo`;o0000
@?ooool2o`0000oooooo000Nooooo`03o`000?oooooooooo013ooooo0_l00005ooooo`;o0000J?oo
ool2o`000;?ooooo0_l0000?ooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o00001Oooool2
o`000:[ooooo0_l0000Dooooo`;o0000?Oooool2o`0002gooooo000Nooooo`03o`000?oooooooooo
08kooooo0_l0000cooooo`;o00005?ooool2o`0003gooooo0_l0000=ooooo`;o00007_ooool001ko
oooo00?o0000ooooooooool08oooool2o`0006Wooooo0_l0000Iooooo`;o0000O?ooool2o`0001ko
oooo000Nooooo`03o`000?oooooooooo02?ooooo0_l0000_ooooo`;o0000:Oooool2o`0002Sooooo
0_l0000Mooooo`;o00000_ooool2o`0007Wooooo000Nooooo`03o`000?oooooooooo01Kooooo0ol0
000kooooo`;o0000:Oooool2o`0001Wooooo0_l0000Pooooo`;o00002_ooool2o`0000;ooooo0_l0
0016ooooo`;o0000<Oooool001kooooo00?o0000ooooooooool05_ooool3o`00087ooooo0_l0000H
ooooo`;o00001_ooool2o`0005Kooooo0_l0000<ooooo`;o00008oooool001kooooo00?o0000oooo
ooooool0KOooool2o`0004Gooooo0_l0000cooooo`;o0000=oooool2o`0002?ooooo000Nooooo`;o
0000K_ooool2o`00047ooooo0_l0000gooooo`;o0000?_ooool2o`0001cooooo000Nooooo`03o`00
0?oooooooooo00;ooooo0_l0001looooo`;o00005oooool2o`0001Gooooo0_l0001Tooooo`;o0000
4Oooool2o`0001cooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0001looooo`;o00005ooo
ool2o`0002Gooooo0_l0001Dooooo`;o0000;oooool001kooooo00?o0000ooooooooool0A_ooool2
o`0000oooooo0_l0001Wooooo`;o00003Oooool2o`00033ooooo0_l00014ooooo`007_ooool00ol0
003oooooooooo`16ooooo`;o00003oooool2o`0003?ooooo0_l00011ooooo`;o000000?oooooo`00
0?l00000;Oooool2o`0004Cooooo000Nooooo`03o`000?oooooooooo047ooooo0_l00018ooooo`?o
00009?ooool2o`0001kooooo0_l0001cooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o0000
;oooool2o`0002Sooooo0_l0000Fooooo`;o00001_ooool2o`0002Gooooo0_l0000Sooooo`;o0000
DOooool2o`0001_ooooo000Nooooo`03o`000?oooooooooo013ooooo0_l00004ooooo`;o0000Dooo
ool2o`0001Kooooo0_l0000Mooooo`;o0000<oooool2o`00057ooooo0_l0000=ooooo`;o00003?oo
ool001kooooo00?o0000ooooooooool05_ooool2o`0007Wooooo0_l0000?ooooo`;o00006?ooool2
o`0002Sooooo0_l0001Aooooo`;o00003?ooool001kooooo00?o0000ooooooooool0TOooool2o`00
02Wooooo0_l0000;ooooo`;o00006oooool2o`0005oooooo000Nooooo`03o`000?oooooooooo0<7o
oooo0_l00006ooooo`;o0000O?ooool001kooooo00?o0000ooooooooool0Aoooool3o`0007Oooooo
0_l0000@ooooo`;o0000L_ooool001kooooo00?o0000ooooooooool04_ooool2o`0000Gooooo0_l0
000/ooooo`?o0000;?ooool2o`0002;ooooo0_l0000gooooo`;o0000L_ooool001kooooo00?o0000
ooooooooool01?ooool2o`0000cooooo0_l00005ooooo`;o00007oooool2o`0003[ooooo0_l0000R
ooooo`;o00008Oooool3o`00057ooooo0_l0000dooooo`007_ooool00ol0003oooooooooo`04oooo
o`;o0000=?ooool2o`0004Gooooo0_l0000jooooo`?o00001oooool2o`0002;ooooo0_l0000Toooo
o`;o0000=?ooool001kooooo00?o0000ooooooooool0POooool2o`0004Cooooo0_l00006ooooo`;o
00006_ooool2o`00033ooooo0_l0000Xooooo`007_ooool2o`000=3ooooo0_l0001<ooooo`;o0000
:?ooool001kooooo00?o0000ooooooooool0=?ooool2o`0002cooooo0_l0000`ooooo`;o0000C?oo
ool2o`0006?ooooo000Nooooo`03o`000?oooooooooo03Cooooo0_l0000Eooooo`;o00005Oooool2
o`00033ooooo0_l00007ooooo`;o0000@oooool2o`00033ooooo0_l0000aooooo`007_ooool00ol0
003oooooooooo`0@ooooo`;o00008oooool2o`0001Cooooo0_l0000=ooooo`;o0000@Oooool2o`00
02gooooo0_l00016ooooo`;o0000<Oooool001kooooo00?o0000ooooooooool04?ooool2o`0002?o
oooo1?l00009ooooo`;o00005_ooool2o`0002Sooooo0_l00016ooooo`;o0000=?ooool2o`0004?o
oooo000Nooooo`03o`000?oooooooooo03Oooooo0_l00009ooooo`;o0000@?ooool2o`0007cooooo
0_l00005ooooo`;o00006oooool2o`0001oooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0
001Aooooo`;o0000ZOooool2o`0000Kooooo0_l0000Kooooo`;o00000_ooool2o`0000gooooo0_l0
000<ooooo`007_ooool00ol0003oooooooooo`03ooooo`;o0000DOooool2o`0006;ooooo0_l00015
ooooo`;o00005?ooool2o`00017ooooo0_l0000=ooooo`;o00003?ooool001kooooo00?o0000oooo
ooooool01Oooool2o`000;?ooooo0_l0001Kooooo`;o00000oooool2o`0002Wooooo000Nooooo`03
o`000?oooooooooo00Gooooo0_l0003oooooo`_ooooo0_l00009ooooo`;o0000:Oooool001kooooo
00?o0000ooooooooool0NOooool2o`0009Kooooo0_l0000Vooooo`Co00002_ooool001kooooo00?o
0000ooooooooool0NOooool2o`0002cooooo0_l0000>ooooo`;o0000Hoooool2o`0001_ooooo1?l0
000:ooooo`007_ooool00ol0003oooooooooo`04ooooo`;o0000XOooool2o`0000kooooo0_l0001S
ooooo`;o0000:Oooool001kooooo00?o0000ooooooooool01?ooool2o`0000Kooooo0_l0000Doooo
o`;o00009_ooool2o`0002Kooooo0_l0003Cooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001_ooool3o`0000cooooo0_l0000Dooooo`;o00009_ooool2o`00
02Kooooo0_l0000gooooo`;o0000OOooool2o`0001_ooooo0003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`?o0000<_ooool2
o`0007Oooooo0_l0001Uooooo`;o00005_ooool2o`0001_ooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`?o00003Oooool2o`0002?ooooo0_l00009
ooooo`;o0000=?ooool2o`0009gooooo0_l00004ooooo`;o00000oooool2o`0002;ooooo0_l00004
ooooo`000oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01_ooool0
0ol0003oooooooooo`0=ooooo`;o000000?oooooo`000?l000002?ooool2o`00027ooooo0_l0000^
ooooo`;o00001?ooool2o`00083ooooo0_l0000Qooooo`;o00000oooool2o`0002;ooooo0_l00004
ooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool0
0ol0003oooooooooo`0@ooooo`;o00002?ooool2o`0001Wooooo0_l0000fooooo`;o00007_ooool2
o`0006Kooooo0_l0001@ooooo`000oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0eooooo`;o0000E_ooool3o`0003;ooooo0_l0000Q
ooooo`;o0000H?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`0Gooooo`;o0000MOooool2o`0003;ooooo0_l0
000Qooooo`;o0000H?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0Gooooo`;o0000Joooool2o`000<7ooooo
000Nooooo`03o`000?oooooooooo017ooooo0_l00002ooooo`;o0000KOooool2o`0000gooooo0_l0
002booooo`007_ooool00ol0003oooooooooo`02ooooo`;o00003Oooool2o`0000;ooooo0_l0001f
ooooo`;o00001?ooool2o`000;;ooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l00029oooo
o`;o0000AOooool2o`0004oooooo0_l0000Pooooo`007_ooool00ol0003oooooooooo`0gooooo`;o
0000;_ooool2o`0003[ooooo0_l0000Kooooo`;o00004_ooool2o`0004oooooo0_l0000Pooooo`00
7_ooool00ol0003oooooooooo`0gooooo`;o00002_ooool2o`0002;ooooo0_l0000Xooooo`;o0000
4?ooool2o`0001_ooooo0_l0001looooo`;o00001oooool001kooooo00?o0000ooooooooool0:?oo
ool2o`0001Wooooo0_l0001<ooooo`;o00006oooool2o`0008kooooo0_l00007ooooo`007_ooool0
0ol0003oooooooooo`0Xooooo`;o0000NOooool2o`0000Wooooo0_l00006ooooo`;o0000Soooool0
01kooooo00?o0000ooooooooool0Doooool2o`00027ooooo0_l0000[ooooo`;o00004Oooool2o`00
08oooooo000Nooooo`03o`000?oooooooooo05?ooooo0_l0000Hooooo`;o00001oooool2o`0001oo
oooo0_l0000=ooooo`;o0000=Oooool2o`0004[ooooo0_l0000Looooo`007_ooool00ol0003ooooo
ooooo`1]ooooo`;o0000:?ooool2o`0000gooooo0_l0000eooooo`;o00005?ooool2o`0003Cooooo
0_l0000Dooooo`;o00001_ooool001kooooo00?o0000ooooooooool00_l0000`ooooo`;o0000Cooo
ool2o`0000;ooooo0_l0000=ooooo`;o00001Oooool2o`0005Cooooo0_l0000^ooooo`;o00006_oo
ool2o`0000Kooooo000Nooooo`;o000000?oooooo`000?l00000<?ooool2o`0003Gooooo0_l0000H
ooooo`;o00000_ooool2o`0000gooooo0_l00005ooooo`;o0000Q?ooool2o`0002;ooooo000Noooo
o`03o`000?oooooooooo02?ooooo0_l0000Gooooo`;o0000:oooool2o`000=cooooo000Nooooo`03
o`000?oooooooooo02?ooooo0_l0000Gooooo`;o0000ooooool:ooooo`007_ooool00ol0003ooooo
ooooo`0Aooooo`;o0000V?ooool2o`0003oooooo0_l00014ooooo`;o00004oooool001kooooo00?o
0000ooooooooool04Oooool2o`0009Sooooo0_l0000aooooo`;o00003?ooool2o`0004Cooooo0_l0
000Cooooo`007_ooool00ol0003oooooooooo`1aooooo`;o0000Joooool2o`0006Oooooo000Moooo
o`;o00001oooool3o`0000;ooooo0_l00003ooooo`;o00005?ooool2o`0003Oooooo0_l0000Aoooo
o`;o0000<Oooool2o`0000Oooooo0_l0000cooooo`;o0000Hoooool001gooooo0_l00007ooooo`?o
00000_ooool2o`0000?ooooo0_l0000Dooooo`;o0000=oooool2o`0004Cooooo1?l00005ooooo`;o
00001_ooool2o`0002_ooooo0_l0001:ooooo`;o00000_ooool2o`0001?ooooo000Nooooo`03o`00
0?oooooooooo00gooooo0_l00005ooooo`;o00008_ooool4o`0005Cooooo0_l0000Dooooo`;o0000
3Oooool2o`0002kooooo0_l00017ooooo`;o00000_ooool2o`0001?ooooo000Nooooo`03o`000?oo
oooooooo00gooooo0_l00005ooooo`;o00008_ooool4o`0000kooooo0_l00007ooooo`;o0000>ooo
ool2o`0001Gooooo0_l0000Nooooo`;o00007?ooool2o`00057ooooo0_l0000=ooooo`007_ooool0
0ol0003oooooooooo`1:ooooo`;o00001oooool2o`0002[ooooo0_l0000Oooooo`;o00001Oooool2
o`0001kooooo0_l0001_ooooo`;o00003Oooool001kooooo00?o0000ooooooooool07?ooool2o`00
067ooooo0_l0000Oooooo`;o00000oooool2o`00037ooooo0_l0001]ooooo`007_ooool00ol0003o
ooooooooo`0Looooo`;o00000oooool2o`0004?ooooo0_l0000@ooooo`;o0000:oooool2o`00037o
oooo0_l0001]ooooo`007_ooool00ol0003oooooooooo`0Qooooo`;o00002?ooool2o`000003oooo
ool0003o000003Kooooo0_l0000@ooooo`;o00000oooool2o`0005?ooooo0_l0001Vooooo`;o0000
2oooool001kooooo00?o0000ooooooooool0:oooool2o`000003ooooool0003o000004Sooooo0_l0
0003ooooo`;o0000Doooool2o`0006Kooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`1H
ooooo`;o00007oooool2o`000;7ooooo0_l0000Iooooo`007_ooool2o`0003;ooooo0_l0000Uoooo
o`;o00007oooool2o`0005cooooo0_l0001Cooooo`;o00006Oooool001kooooo00?o0000oooooooo
ool07?ooool2o`0001?ooooo0_l00024ooooo`;o00007_ooool2o`00023ooooo0_l0001<ooooo`00
7_ooool00ol0003oooooooooo`0Looooo`;o0000:oooool2o`0001?ooooo0_l0001Gooooo`;o0000
;?ooool2o`0001;ooooo0_l0001<ooooo`007_ooool00ol0003oooooooooo`19ooooo`;o00004ooo
ool2o`0003;ooooo0_l0001Aooooo`;o0000H?ooool001kooooo00?o0000ooooooooool00oooool2
o`0001_ooooo0_l0001`ooooo`;o0000>Oooool2o`0006cooooo0_l0000:ooooo`007_ooool00ol0
003oooooooooo`03ooooo`;o00006oooool2o`0004Sooooo0_l0001Qooooo`;o00006?ooool2o`00
05;ooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0Tooooo`;o0000A?ooool2o`0000Ko
oooo0_l0001cooooo`;o00007oooool2o`0003gooooo000Nooooo`03o`000?oooooooooo02?ooooo
0ol00005ooooo`;o00009Oooool2o`0001kooooo0_l0001]ooooo`;o00003_ooool2o`0001Gooooo
0_l0000mooooo`007_ooool00ol0003oooooooooo`06ooooo`;o00006oooool2o`0000Kooooo0_l0
000Uooooo`;o0000SOooool2o`0000kooooo0_l0001Dooooo`007_ooool00ol0003oooooooooo`06
ooooo`;o00006oooool2o`0001;ooooo0_l0002Iooooo`;o0000<oooool2o`0000;ooooo0_l0000j
ooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o00005Oooool2o`0004;ooooo0_l0000`oooo
o`;o00008oooool2o`0003?ooooo0_l00002ooooo`;o0000:?ooool2o`00013ooooo000Nooooo`03
o`000?oooooooooo023ooooo0_l0000Yooooo`;o00001_ooool2o`0002Kooooo0_l0000`ooooo`;o
0000Q_ooool2o`00013ooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0000Eooooo`;o0000
5?ooool2o`0001?ooooo0_l00006ooooo`;o0000:?ooool2o`000:7ooooo0_l0000Uooooo`007_oo
ool00ol0003oooooooooo`09ooooo`;o00005Oooool2o`0001Cooooo0_l0000?ooooo`;o00006_oo
ool2o`0000Sooooo0_l0000>ooooo`;o0000>oooool2o`0002_ooooo0_l0000Oooooo`;o00005_oo
ool2o`0002Gooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0000Zooooo`;o00004_ooool2
o`0000_ooooo0_l0000=ooooo`;o00001Oooool2o`000003ooooool0003o000000Gooooo0_l00014
ooooo`;o0000:oooool2o`0001oooooo0_l0000mooooo`007_ooool00ol0003oooooooooo`07oooo
o`;o0000:_ooool2o`0001gooooo1?l0000Dooooo`;o00002?ooool2o`000=7ooooo000Nooooo`;o
0000Doooool2o`0005kooooo0_l0000gooooo`;o00004oooool2o`00037ooooo0_l0000Booooo`00
7_ooool00ol0003oooooooooo`1Sooooo`;o00002?ooool2o`0004?ooooo1?l0000eooooo`;o0000
4oooool2o`00037ooooo0_l0000Booooo`007_ooool00ol0003oooooooooo`0Pooooo`;o0000?_oo
ool2o`000003ooooool0003o000000Sooooo0_l0000Iooooo`;o0000:_ooool2o`00097ooooo000N
ooooo`03o`000?oooooooooo023ooooo0_l0000Booooo`;o0000:_ooool2o`0002Kooooo0_l0002m
ooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o00007oooool2o`00037ooooo0_l00019oooo
o`;o0000Toooool001kooooo00?o0000ooooooooool04oooool2o`0005;ooooo0_l00019ooooo`;o
0000Toooool001kooooo00?o0000ooooooooool0n?ooool2o`0001Oooooo1?l0000booooo`007Ooo
ool2o`0003gooooo0_l0000Pooooo`;o00001Oooool2o`0009;ooooo0_l0000Gooooo`Co0000:ooo
ool3o`0000Cooooo000Mooooo`;o0000?Oooool2o`0000Wooooo0ol0000Dooooo`;o00001Oooool2
o`0001gooooo0_l0002kooooo`?o00001?ooool001kooooo00?o0000ooooooooool0;oooool2o`00
01Gooooo0ol0000Fooooo`;o00003Oooool2o`0001?ooooo0_l0000Jooooo`;o0000Ioooool2o`00
03gooooo000Nooooo`03o`000?oooooooooo02oooooo0_l0000?ooooo`;o00007Oooool2o`0000go
oooo0_l00004ooooo`;o0000:Oooool2o`0005;ooooo0_l0000Cooooo`;o00005?ooool2o`00013o
oooo0_l0000Eooooo`007_ooool00ol0003oooooooooo`10ooooo`;o0000<_ooool2o`0000Cooooo
0_l0001gooooo`;o00008Oooool4o`0000Cooooo0_l0000@ooooo`;o00005Oooool001kooooo00Co
0000ooooool0003o00003oooool2o`0003Oooooo0_l0000Iooooo`;o00005?ooool2o`0004Gooooo
0_l00009ooooo`;o0000@oooool2o`0000?ooooo1?l0000]ooooo`007_ooool01?l0003oooooo`00
0?l0000?ooooo`;o0000=oooool2o`0001Wooooo0_l00005ooooo`;o0000??ooool2o`0001Kooooo
0_l00009ooooo`;o0000@oooool2o`0000kooooo0_l0000Tooooo`000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003ooooo
ooooo`12ooooo`;o00004_ooool2o`0001?ooooo0_l0000>ooooo`;o0000;?ooool2o`0006?ooooo
0_l0000Aooooo`;o00009?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Wooooo0_l0000:ooooo`;o0000
6oooool2o`0000Oooooo0_l00009ooooo`;o00001?ooool2o`0001gooooo0_l00004ooooo`;o0000
6oooool2o`0006kooooo0_l0000Jooooo`;o00006oooool000?ooooo00Go410@oooooooooooooooo
oa0@400;ooooo`Go00001_ooool3o`0001Wooooo0_l0000:ooooo`;o00009?ooool2o`0000oooooo
0_l00006ooooo`;o00006oooool2o`0001_ooooo0_l0002:ooooo`;o00006oooool000?ooooo00Go
0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000oooooooo
ool0I?ooool2o`0007Cooooo0_l0001[ooooo`000oooool01Ol0003ooooooooooooooooo000000_o
oooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`2eooooo`;o00008oooool2o`00
04;ooooo0_l0000Wooooo`000oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<
c?l000001oooool00ol0003oooooooooo`1Dooooo`;o0000Goooool2o`0006Oooooo0_l0000Woooo
o`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0
003oooooooooo`0]ooooo`;o00009Oooool2o`0001Kooooo0_l0000[ooooo`;o0000Roooool2o`00
01oooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06oooo
o`03o`000?oooooooooo00gooooo0_l0000Nooooo`;o0000?Oooool2o`0002_ooooo0_l0001loooo
o`;o00003Oooool2o`0001oooooo000Nooooo`03o`000?oooooooooo00Cooooo1?l00005ooooo`;o
0000C?ooool2o`000;[ooooo0_l0000Tooooo`;o00002?ooool001kooooo00?o0000ooooooooool0
1?ooool4o`0000oooooo0_l00012ooooo`;o0000@oooool2o`0005;ooooo0_l00017ooooo`;o0000
2?ooool001kooooo00?o0000ooooooooool05oooool2o`0001Wooooo0_l00005ooooo`;o0000?_oo
ool2o`0002Gooooo0_l0001Booooo`;o0000DOooool001kooooo00?o0000ooooooooool01oooool2
o`0002Wooooo0_l00005ooooo`;o0000?_ooool2o`0009Kooooo0_l0000dooooo`007_ooool00ol0
003oooooooooo`07ooooo`;o0000FOooool2o`0000Gooooo0_l00022ooooo`;o00008_ooool2o`00
00Oooooo0_l0000Mooooo`;o00003?ooool001kooooo00?o0000ooooooooool0Boooool2o`0001Go
oooo0_l00005ooooo`;o00001Oooool2o`0004Wooooo0_l0000`ooooo`;o00006?ooool2o`00017o
oooo0_l0000Mooooo`;o00003?ooool001kooooo00?o0000ooooooooool0Boooool2o`0002?ooooo
0_l00019ooooo`;o00006oooool2o`0002gooooo0_l0000=ooooo`;o0000;oooool001kooooo00?o
0000ooooooooool03?ooool2o`000003ooooool0003o000001[ooooo0_l0001Hooooo`;o0000DOoo
ool2o`0003cooooo0_l0000_ooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o000000?ooooo
o`000?l000006_ooool2o`0000[ooooo0_l0000>ooooo`;o00005?ooool2o`0001gooooo0_l00007
ooooo`;o0000Woooool2o`0001oooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0000Uoooo
o`;o00002oooool2o`0000kooooo0_l0000Dooooo`;o00007Oooool2o`0002;ooooo0_l0000doooo
o`;o00003Oooool2o`0003oooooo0_l0000Oooooo`007_ooool00ol0003oooooooooo`03ooooo`;o
00006_ooool2o`0000Wooooo0_l0000booooo`;o00003oooool2o`0002oooooo0_l0000dooooo`;o
00003Oooool2o`00063ooooo000Nooooo`;o00008?ooool2o`0003gooooo0_l0000?ooooo`;o0000
2?ooool2o`0000?ooooo0_l00037ooooo`007_ooool00ol0003oooooooooo`10ooooo`;o0000=ooo
ool2o`0000?ooooo0_l0001Nooooo`;o0000Ioooool001kooooo00?o0000ooooooooool06_ooool2
o`0000Gooooo0_l0000Mooooo`;o00005oooool2o`0006Kooooo0_l0000Kooooo`;o0000;oooool2
o`0003Kooooo000Nooooo`03o`000?oooooooooo01[ooooo0_l00005ooooo`;o00002Oooool2o`00
02_ooooo0_l0000fooooo`;o0000;_ooool2o`00013ooooo0_l0000jooooo`;o0000=_ooool001ko
oooo00?o0000ooooooooool0;?ooool2o`0002Sooooo0_l0000Kooooo`;o00007?ooool2o`00013o
oooo0_l0000Wooooo`;o00001Oooool2o`0000gooooo0_l0001Sooooo`007_ooool00ol0003ooooo
ooooo`1Fooooo`;o00001_ooool2o`0001?ooooo0_l0000^ooooo`;o00009oooool2o`0001Cooooo
0_l0000;ooooo`;o0000E_ooool001kooooo00?o0000ooooooooool0G_ooool2o`0008oooooo0_l0
001Fooooo`007_ooool00ol0003oooooooooo`2cooooo`;o0000K?ooool2o`0002Cooooo000Noooo
o`03o`000?oooooooooo0;?ooooo0_l0001/ooooo`;o00009?ooool001kooooo00?o0000oooooooo
ool02?ooool2o`00017ooooo0_l0000Pooooo`;o0000E?ooool2o`0005[ooooo0_l0001Fooooo`00
7_ooool00ol0003oooooooooo`08ooooo`;o00004Oooool2o`00023ooooo0_l0001Dooooo`;o0000
F_ooool2o`0003Kooooo0_l0000Nooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o00004Ooo
ool2o`0005Oooooo0_l0000Mooooo`;o0000Roooool2o`0000;ooooo0_l0000Jooooo`007_ooool0
0ol0003oooooooooo`06ooooo`;o00001oooool2o`0000Oooooo0_l00008ooooo`;o0000Eoooool2
o`0001gooooo0_l0002?ooooo`;o00003oooool2o`0000Wooooo000Nooooo`03o`000?oooooooooo
00Kooooo0_l0000@ooooo`;o0000:Oooool2o`000?Oooooo0_l00009ooooo`007_ooool00ol0003o
ooooooooo`0eooooo`;o00003?ooool2o`000:?ooooo0_l0000@ooooo`;o0000??ooool2o`0000Co
oooo0_l00007ooooo`007_ooool00ol0003oooooooooo`0eooooo`;o0000/Oooool2o`00013ooooo
0_l00002ooooo`;o0000>?ooool2o`0000Cooooo0_l00007ooooo`007_ooool2o`00037ooooo0_l0
001Fooooo`;o00002Oooool2o`0002Gooooo0_l00012ooooo`;o00003Oooool2o`000003ooooool0
003o000003Gooooo000Nooooo`03o`000?oooooooooo033ooooo0_l0000Yooooo`;o00007?ooool2
o`0000gooooo0_l00009ooooo`;o00003_ooool2o`0001Gooooo0_l0001Aooooo`;o000000?ooooo
o`000?l00000=Oooool001kooooo00?o0000ooooooooool0Foooool2o`0001cooooo0_l0000Xoooo
o`Co0000X?ooool001kooooo0_l0002Vooooo`;o00009Oooool2o`0000Cooooo0_l00014ooooo`;o
00003Oooool2o`0001kooooo000Nooooo`;o0000F?ooool2o`0006Kooooo0_l0000;ooooo`;o0000
1?ooool2o`0004Cooooo0_l0000=ooooo`;o00007_ooool001kooooo00?o0000ooooooooool0Eooo
ool2o`0004Cooooo0_l0000Pooooo`;o0000Q_ooool001kooooo00?o0000ooooooooool0=oooool2
o`0006Cooooo0_l0002=ooooo`;o00006Oooool001kooooo00?o0000ooooooooool0=oooool2o`00
07Kooooo0_l0000]ooooo`;o0000?_ooool2o`0000cooooo0_l00002ooooo`;o00005Oooool001ko
oooo00?o0000ooooooooool05?ooool2o`0006Sooooo0_l0000Kooooo`;o00004_ooool2o`0000Co
oooo0_l0000Wooooo`;o0000?_ooool2o`0000gooooo0_l000000ooooooo0000o`00000Eooooo`00
7_ooool00ol0003oooooooooo`0Dooooo`;o00002oooool2o`0005Kooooo0_l000000ooooooo0000
o`000002o`0000Oooooo0_l0000Booooo`;o00006?ooool2o`0003Cooooo0_l00010ooooo`;o0000
4Oooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo023ooooo0ol00005ooooo`;o00004ooo
ool2o`0003[ooooo0_l000000ooooooo0000o`000009ooooo`;o0000H_ooool2o`0005?ooooo0_l0
0005ooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o00001_ooool2o`0000Gooooo0_l0000<
ooooo`;o0000;_ooool2o`0003[ooooo0_l0001looooo`;o00001?ooool2o`0001Sooooo000Noooo
o`03o`000?oooooooooo02oooooo0_l0000looooo`;o0000>_ooool2o`0007cooooo0_l00004oooo
o`;o00004?ooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo00Gooooo0_l0001gooooo`?o
00002_ooool2o`000;;ooooo0_l00006ooooo`007_ooool00ol0003oooooooooo`05ooooo`;o0000
M_ooool4o`0000[ooooo0_l0001?ooooo`;o0000JOooool001kooooo00?o0000ooooooooool08Ooo
ool2o`0005[ooooo0_l0001Mooooo`;o00007Oooool2o`0004[ooooo000Nooooo`;o00008_ooool4
o`0000kooooo0_l00003ooooo`;o0000;oooool2o`0000cooooo0_l0001iooooo`;o00000oooool2
o`0000;ooooo0_l0001:ooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o00003_ooool2o`00
00?ooooo0_l0000>ooooo`;o00007oooool2o`0000cooooo0_l0000Pooooo`;o00008_ooool2o`00
00Sooooo0_l0000Tooooo`;o00000oooool2o`0000?ooooo0_l00009ooooo`;o00004Oooool2o`00
033ooooo000Nooooo`03o`000?oooooooooo017ooooo0_l0000eooooo`;o0000Coooool2o`00023o
oooo1?l00008ooooo`;o00009?ooool2o`0001?ooooo0_l0000Aooooo`;o0000<?ooool001kooooo
00?o0000ooooooooool04Oooool2o`0005Cooooo0_l0000gooooo`?o00006?ooool2o`00023ooooo
0_l0001Xooooo`007_ooool00ol0003oooooooooo`1Wooooo`;o00003Oooool2o`0002Sooooo0ol0
000jooooo`;o0000J?ooool001kooooo00?o0000ooooooooool0>oooool2o`0003Wooooo0_l00019
ooooo`;o0000Q?ooool001kooooo00?o0000ooooooooool03_ooool2o`0002Wooooo1?l00024oooo
o`;o0000Q?ooool001kooooo00?o0000ooooooooool03_ooool2o`0002Wooooo0_l0000Aooooo`;o
0000Soooool2o`0000cooooo0_l00004ooooo`;o0000E?ooool001kooooo00?o0000ooooooooool0
6Oooool2o`00037ooooo0_l0001Nooooo`;o00006?ooool2o`0001Gooooo0_l0000<ooooo`;o0000
1?ooool2o`0005Cooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0000Cooooo`;o0000=ooo
ool2o`00013ooooo1?l0000<ooooo`;o0000=_ooool2o`0001Sooooo0_l0001oooooo`007_ooool0
0ol0003oooooooooo`04ooooo`;o00009_ooool2o`0002Cooooo0_l00005ooooo`;o00002Oooool4
o`0000cooooo0_l0000Looooo`;o0000@_ooool2o`0006oooooo000Nooooo`03o`000?oooooooooo
02cooooo0_l0000[ooooo`;o0000=oooool2o`0000;ooooo0_l0000nooooo`;o0000C?ooool2o`00
01Gooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`1Xooooo`Co0000:_ooool2o`0000Go
oooo0_l0000Oooooo`;o0000I?ooool2o`0001Gooooo0_l0000:ooooo`007_ooool00ol0003ooooo
ooooo`11ooooo`;o00001?ooool2o`0000Sooooo0_l0000Eooooo`Co00000_ooool2o`0002gooooo
0_l0000Oooooo`;o0000Qoooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool04?ooool2o`0002Co
oooo0_l00009ooooo`;o000000Coooooo`000?l0003ooooo0_l00008ooooo`;o00006oooool2o`00
04[ooooo0_l0000booooo`;o00006Oooool2o`0003cooooo0003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooo
oooo013ooooo0_l00009ooooo`;o00006Oooool2o`0000cooooo0_l0001dooooo`;o0000<_ooool2
o`0001Wooooo0_l0000looooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`000006ooooo`?o00006oooool2o`0001oooooo0_l0003;ooooo`;o000000?o
ooooo`000?l00000>Oooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0looooo`;o0000XOooool2o`0001Kooooo
0_l0000@ooooo`;o000000?oooooo`000?l00000>Oooool000?ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`1=ooooo`;o
0000H_ooool2o`0002cooooo0_l00002ooooo`;o00004_ooool2o`0003Gooooo0_l0000Gooooo`00
0oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003o
ooooooooo`1=ooooo`;o0000Boooool2o`0001Gooooo0_l0000Qooooo`;o00003Oooool2o`0004Wo
oooo0_l0000Gooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nH
V9P02?ooool00ol0003oooooooooo`1Looooo`;o0000??ooool3o`0003Oooooo0_l00006ooooo`?o
0000J?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@
40Kooooo00?o0000ooooooooool06?ooool2o`0001kooooo0_l00002ooooo`;o00007_ooool2o`00
03cooooo0ol0000oooooo`?o0000J?ooool001kooooo00?o0000ooooooooool06?ooool2o`0000Go
oooo0_l0000Gooooo`;o00000_ooool2o`0009[ooooo0_l0001]ooooo`007_ooool00ol0003ooooo
ooooo`0Oooooo`;o0000]oooool2o`0000Kooooo0_l0000Oooooo`;o0000A?ooool001kooooo00?o
0000ooooooooool0?Oooool2o`0000Gooooo0_l000000ooooooo0000o`00000Pooooo`;o0000MOoo
ool2o`0001oooooo0_l00014ooooo`007_ooool00ol0003oooooooooo`0mooooo`;o000000?ooooo
o`000?l000000_ooool2o`000003ooooool0003o0000023ooooo0_l0002[ooooo`;o00007oooool2
o`0000kooooo000Nooooo`03o`000?oooooooooo043ooooo0_l0001?ooooo`;o0000@_ooool2o`00
013ooooo0_l0000]ooooo`;o00007oooool2o`0000kooooo000Nooooo`03o`000?oooooooooo097o
oooo0_l0000hooooo`;o00002?ooool2o`00013ooooo0_l0000=ooooo`;o0000Coooool001kooooo
00?o0000ooooooooool0<oooool2o`0002cooooo0_l0001Xooooo`;o0000:Oooool2o`0000Cooooo
0_l00019ooooo`007_ooool00ol0003oooooooooo`0cooooo`;o0000;?ooool2o`0004cooooo0_l0
001;ooooo`;o0000;?ooool2o`0001_ooooo000Nooooo`03o`000?oooooooooo07_ooooo0_l0000b
ooooo`;o0000NOooool2o`0001_ooooo000Nooooo`03o`000?oooooooooo04;ooooo0_l0000goooo
o`;o0000DOooool4o`0007Gooooo000Nooooo`03o`000?oooooooooo02cooooo0_l0000Dooooo`;o
0000R_ooool4o`0007Gooooo000Nooooo`;o00007_ooool2o`0000gooooo0_l00020ooooo`;o0000
00?oooooo`000?l00000U?ooool001kooooo00?o0000ooooooooool01oooool2o`0001Cooooo0_l0
002?ooooo`;o000000?oooooo`000?l00000U?ooool001kooooo00?o0000ooooooooool01oooool2
o`0000Wooooo0_l0000Zooooo`;o00009Oooool2o`0009?ooooo0_l0001;ooooo`007_ooool00ol0
003oooooooooo`0Booooo`;o0000:_ooool2o`0001Oooooo0_l0000<ooooo`;o0000B_ooool2o`00
00gooooo0_l0000^ooooo`;o00002?ooool2o`0004_ooooo000Nooooo`03o`000?oooooooooo05Oo
oooo0_l0000nooooo`;o00006?ooool2o`0000gooooo0_l0000Oooooo`;o00003Oooool2o`0003?o
oooo0_l0000Pooooo`007_ooool00ol0003oooooooooo`0mooooo`;o0000F?ooool2o`0002kooooo
0_l0000Hooooo`;o0000@_ooool2o`00023ooooo000Nooooo`03o`000?oooooooooo03gooooo0_l0
0024ooooo`;o00000_ooool2o`0002kooooo0_l0000[ooooo`;o00004?ooool2o`0000oooooo000N
ooooo`03o`000?oooooooooo05cooooo0_l0001Uooooo`;o00000_ooool2o`0002kooooo0_l00003
ooooo`;o00009_ooool2o`00013ooooo0_l0000?ooooo`007_ooool00ol0003oooooooooo`04oooo
o`;o0000<Oooool2o`0000?ooooo0_l0000Nooooo`;o00000_ooool2o`0001?ooooo0_l00025oooo
o`;o00004oooool2o`0003Cooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0000aooooo`;o
00000oooool2o`0000[ooooo0_l0000Fooooo`;o00004oooool2o`0000Wooooo0_l0000Yooooo`;o
0000I?ooool2o`0003Cooooo000Nooooo`03o`000?oooooooooo037ooooo0_l0000Eooooo`;o0000
;?ooool2o`0000Sooooo0_l0000Yooooo`;o00003oooool2o`0000Wooooo0_l0000[ooooo`;o0000
0oooool2o`0004cooooo000Nooooo`03o`000?oooooooooo037ooooo0_l00013ooooo`;o00002?oo
ool4o`00023ooooo0_l0000Fooooo`;o00002Oooool2o`0002_ooooo0_l00003ooooo`;o0000@_oo
ool2o`0000Sooooo000Nooooo`03o`000?oooooooooo063ooooo0_l0000Nooooo`Co00008?ooool2
o`0002[ooooo0_l0001[ooooo`;o00002?ooool001kooooo00?o0000ooooooooool0H?ooool2o`00
06cooooo1?l0001eooooo`007_ooool00ol0003oooooooooo`3>ooooo`;o0000Aoooool2o`00013o
oooo0_l0000Looooo`007_ooool00ol0003oooooooooo`0Pooooo`;o0000Y_ooool2o`0004gooooo
0_l0000@ooooo`;o00007?ooool001kooooo0_l0000Qooooo`;o0000Y_ooool2o`0007gooooo000N
ooooo`03o`000?oooooooooo09[ooooo0_l0001Kooooo`;o0000C_ooool001kooooo00?o0000oooo
ooooool0OOooool2o`0001_ooooo0_l0001Kooooo`;o0000C_ooool001kooooo00?o0000oooooooo
ool0=Oooool2o`0000kooooo0_l0000fooooo`;o00009oooool2o`0009oooooo000Nooooo`03o`00
0?oooooooooo03Gooooo0_l0000>ooooo`;o0000Goooool2o`0002gooooo0_l0000cooooo`;o0000
>oooool001kooooo00?o0000ooooooooool0@?ooool2o`0001Kooooo0_l0000Cooooo`;o0000I_oo
ool2o`0001;ooooo0_l0000Oooooo`;o00001oooool2o`0003;ooooo000Nooooo`03o`000?oooooo
oooo043ooooo0_l0000Fooooo`;o00004?ooool2o`000003ooooool0003o000005Sooooo0_l0000P
ooooo`;o0000:?ooool2o`0003;ooooo000Nooooo`03o`000?oooooooooo03?ooooo0_l0000Roooo
o`;o00004Oooool2o`0005_ooooo0_l0001nooooo`007_ooool00ol0003oooooooooo`0cooooo`;o
00008_ooool2o`000<Sooooo0_l0000Tooooo`007_ooool00ol0003oooooooooo`3oooooob;ooooo
0_l0000Tooooo`007_ooool00ol0003oooooooooo`09ooooo`;o0000Coooool2o`0004Sooooo0_l0
000Kooooo`;o0000<oooool2o`00013ooooo0_l0000mooooo`007_ooool00ol0003oooooooooo`09
ooooo`;o0000Coooool2o`0000Sooooo0_l0000Booooo`;o0000:_ooool2o`0001_ooooo0_l0000c
ooooo`;o00004?ooool2o`0003gooooo000Nooooo`03o`000?oooooooooo06Cooooo0_l0000Boooo
o`;o00008?ooool2o`00047ooooo0_l0001Xooooo`007_ooool00ol0003oooooooooo`2Jooooo`;o
0000@Oooool2o`0006Sooooo000Nooooo`03o`000?oooooooooo027ooooo0_l0000>ooooo`;o0000
8oooool2o`0005Cooooo0ol00003ooooo`;o00004?ooool2o`0002Oooooo0_l0000Eooooo`;o0000
=?ooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo01gooooo0_l00002ooooo`;o00003_oo
ool2o`0000Wooooo0_l000000ooooooo0000o`00000Eooooo`;o0000E?ooool3o`0000?ooooo0_l0
000@ooooo`;o00009oooool2o`0000cooooo0_l00007ooooo`;o0000=?ooool2o`0000_ooooo000N
ooooo`;o00007_ooool2o`0001gooooo0_l000000ooooooo0000o`00002jooooo`;o0000B_ooool0
01kooooo00?o0000ooooooooool0D?ooool2o`000=oooooo0_l0000Dooooo`007_ooool00ol0003o
ooooooooo`06ooooo`;o0000:?ooool2o`0001kooooo0_l0001Uooooo`;o00003_ooool2o`0006So
oooo0_l0000Dooooo`007_ooool00ol0003oooooooooo`06ooooo`;o00001_ooool2o`00023ooooo
0_l0001Hooooo`;o0000:oooool2o`0000kooooo0_l0001nooooo`007_ooool00ol0003ooooooooo
o`0>ooooo`;o0000N_ooool2o`00037ooooo0_l00028ooooo`007_ooool00ol0003oooooooooo`0F
ooooo`;o0000?_ooool2o`0006Gooooo1?l0001Tooooo`;o00008?ooool001kooooo00?o0000oooo
ooooool05_ooool2o`0001oooooo0_l0000:ooooo`;o00004Oooool4o`0006Gooooo0_l0000Coooo
o`;o0000>?ooool2o`0001Gooooo0_l0000Dooooo`;o00002_ooool001kooooo00?o0000oooooooo
ool0=oooool2o`0000Gooooo0_l00003ooooo`;o00004oooool2o`0001;ooooo0_l0000<ooooo`;o
0000??ooool2o`0001[ooooo0_l0000hooooo`;o0000:oooool2o`0000[ooooo000Nooooo`03o`00
0?oooooooooo03kooooo0ol0000[ooooo`;o00003?ooool2o`0003cooooo0_l0002=ooooo`007_oo
ool00ol0003oooooooooo`0oooooo`;o0000Loooool2o`00097ooooo000Nooooo`03o`000?oooooo
oooo02?ooooo0_l00016ooooo`;o00000oooool2o`0004;ooooo0_l00005ooooo`;o0000R_ooool0
01kooooo00?o0000ooooooooool08oooool2o`0004Kooooo0_l00003ooooo`;o00004_ooool2o`00
03Gooooo0_l0000?ooooo`;o0000NOooool001kooooo00?o0000ooooooooool0Doooool2o`0002oo
oooo0_l0000Vooooo`;o00002_ooool2o`0001;ooooo0_l0000mooooo`;o00001Oooool2o`0000oo
oooo0_l0000Rooooo`007_ooool00ol0003oooooooooo`0^ooooo`;o00008oooool2o`0005Oooooo
0_l0000:ooooo`;o0000:oooool2o`0002Cooooo0_l00005ooooo`;o00003oooool2o`0002;ooooo
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o
8B4Qolc<c006ooooo`03o`000?oooooooooo02kooooo0_l0001Gooooo`;o00000_ooool2o`0002_o
oooo0_l0000[ooooo`;o0000<oooool2o`0002_ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo
03cooooo0_l00019ooooo`;o00000_ooool2o`0000Kooooo0_l0000;ooooo`;o0000KOooool2o`00
00Wooooo0_l0000[ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooo
ooooooooooooo`000006ooooo`Go0000>_ooool2o`0003;ooooo0_l0000Qooooo`;o00002oooool2
o`000003ooooool0003o000006[ooooo0_l0000fooooo`000oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooooooo00;o0000K_oo
ool2o`00037ooooo0_l0000Sooooo`;o0000OOooool000?ooooo00Go0000ooooooooooooooooo`00
000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`0Iooooo`;o0000
[Oooool2o`0001_ooooo0_l0001Pooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo
00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo01Wooooo0_l0000>ooooo`;o
00000oooool2o`0006gooooo0_l00016ooooo`;o00002_ooool2o`0002Wooooo0_l0000Yooooo`00
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006oooo
o`03o`000?oooooooooo02Wooooo0_l00003ooooo`;o0000@_ooool2o`0000_ooooo0_l0000Loooo
o`;o00007oooool2o`00037ooooo0_l0000Mooooo`;o00002_ooool2o`0002Wooooo0003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000
ooooooooool01_ooool2o`0006[ooooo0_l0000;ooooo`;o0000?Oooool2o`000003ooooool0003o
000004gooooo0_l0000eooooo`007_ooool00ol0003oooooooooo`06ooooo`;o0000^Oooool2o`00
04gooooo0_l0000eooooo`007_ooool00ol0003oooooooooo`0Booooo`;o0000o?ooool2o`0001Oo
oooo0_l0000Looooo`007_ooool00ol0003oooooooooo`0Booooo`;o00008oooool2o`0000Cooooo
0_l0001;ooooo`;o0000>oooool2o`0002cooooo0_l0000Xooooo`;o00002?ooool2o`0001cooooo
000Nooooo`03o`000?oooooooooo03Oooooo0_l00004ooooo`;o0000Boooool2o`0003_ooooo0_l0
000:ooooo`;o00008?ooool2o`0000cooooo0_l0000Jooooo`;o00004_ooool2o`0000Cooooo0_l0
000<ooooo`007_ooool00ol0003oooooooooo`0^ooooo`;o00003oooool2o`0009;ooooo0_l0000Y
ooooo`;o00000oooool2o`0002kooooo0_l00004ooooo`;o00003?ooool001kooooo00?o0000oooo
ooooool0;_ooool2o`0000oooooo0_l0000Looooo`;o0000Coooool2o`0002cooooo0_l0000Poooo
o`;o00009?ooool2o`00027ooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l0000@ooooo`;o
00009Oooool2o`0004gooooo1?l0000/ooooo`;o0000A_ooool2o`0001Oooooo0_l00008ooooo`00
7_ooool00ol0003oooooooooo`0Qooooo`;o000000?oooooo`000?l000004?ooool2o`0001_ooooo
0_l0001Gooooo`;o00001Oooool2o`0008Sooooo0_l00008ooooo`007_ooool00ol0003ooooooooo
o`0Qooooo`;o0000<?ooool2o`0003Gooooo0_l0000Cooooo`;o00004_ooool2o`00047ooooo0_l0
000iooooo`;o00005?ooool001kooooo00?o0000ooooooooool06_ooool2o`0000gooooo0_l0000E
ooooo`;o0000B?ooool2o`0001?ooooo0_l0001Eooooo`;o00003_ooool2o`0002Wooooo0_l0000D
ooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o00003Oooool2o`0000gooooo0_l0000Eoooo
o`;o00004_ooool2o`000;3ooooo0_l0000oooooo`007_ooool2o`0000cooooo0_l00017ooooo`;o
0000lOooool001kooooo00?o0000ooooooooool0Qoooool2o`0000Oooooo0_l00006ooooo`;o0000
HOooool2o`0004[ooooo000Nooooo`03o`000?oooooooooo037ooooo0_l0001Dooooo`;o00001ooo
ool2o`0000Kooooo0_l00003ooooo`;o00009oooool2o`0003?ooooo0_l0001:ooooo`007_ooool0
0ol0003oooooooooo`0aooooo`;o0000F?ooool2o`00013ooooo0_l0000Wooooo`;o00000oooool2
o`0002Cooooo0_l0000Hooooo`;o0000>_ooool001kooooo00?o0000ooooooooool0Noooool2o`00
00kooooo0_l0000>ooooo`;o00000_ooool2o`0000cooooo0_l0000Looooo`;o00009?ooool2o`00
01Sooooo0_l0000jooooo`007_ooool00ol0003oooooooooo`0fooooo`;o00004_ooool2o`0002oo
oooo0_l0000Nooooo`;o00000_ooool2o`0000cooooo0_l00002ooooo`;o00005Oooool2o`0001Ko
oooo0_l0001?ooooo`;o00002Oooool2o`0000Wooooo000Nooooo`03o`000?oooooooooo03Kooooo
0_l0000Booooo`;o0000IOooool2o`0001Gooooo0_l0000Fooooo`;o0000Coooool2o`0000Wooooo
0_l00009ooooo`007_ooool00ol0003oooooooooo`1Eooooo`;o0000l?ooool001kooooo00?o0000
ooooooooool0EOooool2o`0004?ooooo0_l0000`ooooo`;o0000NOooool001kooooo00?o0000oooo
ooooool0>Oooool2o`0002Wooooo0_l0000dooooo`;o0000<?ooool2o`0007Wooooo000Nooooo`03
o`000?oooooooooo00gooooo0_l00004ooooo`;o00009?ooool2o`0002Wooooo0_l0000iooooo`;o
00005?ooool2o`00093ooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l00009ooooo`;o0000
1?ooool2o`0008[ooooo0_l0000Dooooo`;o0000T?ooool001kooooo00?o0000ooooooooool00_oo
ool2o`0001Gooooo1?l0003oooooob_ooooo000Nooooo`03o`000?oooooooooo01Wooooo1?l0002B
ooooo`;o00005?ooool2o`00083ooooo000Nooooo`03o`000?oooooooooo05Kooooo0_l0000^oooo
o`;o00009?ooool2o`000003ooooool0003o000000gooooo0_l00005ooooo`;o0000N?ooool2o`00
00Kooooo000Nooooo`03o`000?oooooooooo05Kooooo0_l0000^ooooo`;o00006oooool2o`0000;o
oooo0_l00003ooooo`;o00004?ooool2o`0007oooooo0_l00006ooooo`007_ooool2o`000:Cooooo
0_l00002ooooo`;o00005oooool2o`0008Gooooo000Nooooo`03o`000?oooooooooo05Wooooo0_l0
000=ooooo`;o0000E_ooool2o`0000?ooooo0_l00005ooooo`;o0000JOooool2o`0000kooooo000N
ooooo`03o`000?oooooooooo05Wooooo0_l0000=ooooo`;o0000=oooool2o`0002;ooooo0_l00005
ooooo`;o00003Oooool2o`0005[ooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`0^oooo
o`;o00007_ooool2o`0000_ooooo0_l0000@ooooo`;o0000<_ooool2o`0002cooooo0_l0000:oooo
o`;o0000J_ooool001kooooo00?o0000ooooooooool03oooool2o`0001gooooo0_l00003ooooo`;o
00006Oooool2o`0000_ooooo0_l0000@ooooo`;o00003?ooool2o`0005;ooooo0_l0000Booooo`;o
0000H_ooool001kooooo00?o0000ooooooooool03oooool2o`0002;ooooo0_l0000Mooooo`;o0000
9oooool2o`0006Kooooo0_l0000:ooooo`;o00001?ooool2o`0002_ooooo0_l0000Sooooo`007_oo
ool00ol0003oooooooooo`0booooo`;o00005?ooool2o`0000Sooooo0_l0000]ooooo`;o0000=ooo
ool2o`0003?ooooo0_l00004ooooo`;o0000:oooool2o`0002?ooooo000Nooooo`03o`000?oooooo
oooo00Oooooo0_l0000Yooooo`;o00005?ooool2o`0003Oooooo0_l000000ooooooo0000o`00000d
ooooo`;o0000POooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0001koooo
o`;o00007Oooool2o`00047ooooo0_l0001Eooooo`;o00002?ooool001kooooo00?o0000oooooooo
ool06oooool2o`00013ooooo0_l0000Jooooo`;o0000F?ooool2o`00043ooooo0ol0000eooooo`;o
0000:?ooool001kooooo00?o0000ooooooooool06oooool2o`00013ooooo0_l0000Jooooo`;o0000
1_ooool2o`0003;ooooo0_l0001Nooooo`;o0000:?ooool2o`0000cooooo0_l0000Nooooo`?o0000
1oooool001kooooo00?o0000ooooooooool0DOooool2o`0003;ooooo0_l0001kooooo`;o00002ooo
ool2o`0002cooooo0ol00007ooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o0000doooool2
o`0001kooooo0_l0000Aooooo`;o0000<?ooool001kooooo00?o0000ooooooooool03Oooool2o`00
06Kooooo0_l0000Iooooo`;o0000D?ooool2o`00037ooooo0_l00007ooooo`;o00009oooool001ko
oooo00?o0000ooooooooool0MOooool2o`0001Wooooo0_l0000Hooooo`;o00001?ooool2o`00037o
oooo0_l0000Iooooo`;o00007_ooool3o`0002Kooooo000Nooooo`04o`000?oooooo0000o`000:Wo
oooo0_l00004ooooo`;o0000<Oooool2o`0001Wooooo0ol0000Nooooo`;o00003oooool2o`0000?o
oooo0_l0000@ooooo`007_ooool4o`0000;ooooo0_l0000[ooooo`;o00008?ooool2o`000003oooo
ool0003o000008cooooo0_l0000Jooooo`;o0000;oooool2o`0000?ooooo0_l0000@ooooo`007_oo
ool00ol0003oooooooooo`03ooooo`;o0000:oooool2o`0000Sooooo0_l0000Fooooo`;o000000?o
ooooo`000?l000003oooool2o`0002Oooooo0_l0001Booooo`;o0000BOooool2o`0001Oooooo000N
ooooo`03o`000?oooooooooo03;ooooo0_l00006ooooo`;o00006?ooool2o`00013ooooo0_l0000:
ooooo`;o00006oooool2o`0009gooooo0_l0000Gooooo`007_ooool00ol0003oooooooooo`09oooo
o`;o00009oooool2o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000004oooool2o`00
01cooooo0_l00038ooooo`;o00002Oooool001kooooo00?o0000ooooooooool02Oooool2o`0002co
oooo0_l00003ooooo`;o000000?oooooo`000?l00000>oooool2o`000;kooooo0_l00009ooooo`00
7_ooool00ol0003oooooooooo`1looooo`;o000000?oooooo`000?l00000a_ooool001kooooo00?o
0000ooooooooool00_l0000Iooooo`;o00002Oooool2o`0005Oooooo0_l0000Tooooo`;o0000;?oo
ool2o`0001gooooo0_l00002ooooo`;o0000Coooool001kooooo00?o0000ooooooooool00_l0000I
ooooo`;o00002Oooool2o`00057ooooo0_l0000Zooooo`;o00002?ooool2o`0002;ooooo0_l0000M
ooooo`;o00000_ooool2o`0004oooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l0001Roooo
o`;o00003Oooool2o`0000Sooooo0_l0000Zooooo`;o00002?ooool2o`0000?ooooo0_l00009oooo
o`Co0000??ooool2o`0003cooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l0001Gooooo`;o
00002Oooool2o`0001Oooooo0_l0000Oooooo`;o00000_ooool2o`0000[ooooo0_l00003ooooo`;o
00000oooool2o`0000Wooooo1?l0000looooo`;o0000??ooool001kooooo00?o0000ooooooooool0
Goooool2o`0004?ooooo0_l00002ooooo`;o00002_ooool2o`0007oooooo0_l0000@ooooo`007_oo
ool00ol0003oooooooooo`1Sooooo`;o0000A_ooool2o`0000Gooooo0_l00021ooooo`;o00004?oo
ool001kooooo00?o0000ooooooooool0Hoooool2o`0004Kooooo0_l00005ooooo`;o00002Oooool2
o`00057ooooo0_l0000eooooo`007_ooool00ol0003oooooooooo`2Qooooo`;o00002?ooool2o`00
013ooooo0_l0001Aooooo`?o0000=?ooool001Cooooo1?l000000ol@413oooooooooo`03ooooo`03
o`000?oooooooooo05[ooooo0_l00015ooooo`;o00002?ooool2o`0006Cooooo0_l00006ooooo`;o
0000;?ooool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`;o0000
Doooool2o`0009Wooooo0_l0000:ooooo`;o00001Oooool2o`0000oooooo0_l0000/ooooo`005_oo
ool00ol0003oooooooooo`05ooooo`?o00001Oooool2o`000>kooooo0_l0000:ooooo`;o00001Ooo
ool2o`0000oooooo0_l0000/ooooo`005_ooool00ol0003oooooooooo`3oooooob;ooooo0_l0000/
ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?oo
ooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005?ooool00omEEEGoIVIVo`00
003ooooooe;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.0646 .3049 Mdot
.22408 .89045 Mdot
.04932 .10884 Mdot
.42679 .82481 Mdot
.18923 .2366 Mdot
.98223 .32653 Mdot
.01896 .15595 Mdot
.12264 .54725 Mdot
.05799 .9524 Mdot
.31998 .01602 Mdot
.59916 .91205 Mdot
.13962 .70015 Mdot
.50578 .33499 Mdot
.49644 .28318 Mdot
.40117 .37695 Mdot
.44855 .57353 Mdot
.56808 .96734 Mdot
.21881 .34902 Mdot
.62992 .01378 Mdot
.96082 .72494 Mdot
.49085 .88276 Mdot
.30915 .08363 Mdot
.03701 .18529 Mdot
.08663 .62206 Mdot
.8267 .43812 Mdot
.35966 .47204 Mdot
.82745 .74351 Mdot
.67552 .40062 Mdot
.45599 .81783 Mdot
.24798 .03822 Mdot
.76761 .9836 Mdot
.41984 .15666 Mdot
.58613 .19446 Mdot
.09379 .13462 Mdot
.80875 .28665 Mdot
.85545 .71845 Mdot
.37899 .01199 Mdot
.40122 .50302 Mdot
.12766 .31243 Mdot
.07433 .90082 Mdot
.94541 .21339 Mdot
.36962 .80861 Mdot
.35562 .23499 Mdot
.25542 .26312 Mdot
.85295 .22645 Mdot
.61038 .58725 Mdot
.81115 .06499 Mdot
.56179 .94257 Mdot
.0977 .18408 Mdot
.19875 .10431 Mdot
.95059 .96348 Mdot
.58359 .56943 Mdot
.06902 .88079 Mdot
.00698 .38748 Mdot
.96722 .5185 Mdot
.98502 .02451 Mdot
.66454 .99891 Mdot
.10529 .77219 Mdot
.2763 .37713 Mdot
.14262 .88708 Mdot
.11458 .30605 Mdot
.92123 .82046 Mdot
.23612 .93935 Mdot
.44901 .55237 Mdot
.90898 .425 Mdot
.29612 .03095 Mdot
.2053 .88879 Mdot
.60646 .94047 Mdot
.08641 .11824 Mdot
.93218 .15804 Mdot
.87972 .8115 Mdot
.99962 .38814 Mdot
.09454 .59471 Mdot
.35679 .73638 Mdot
.41099 .25976 Mdot
.82723 .17836 Mdot
.03428 .79303 Mdot
.22594 .35252 Mdot
.77736 .68004 Mdot
.24847 .34795 Mdot
.50108 .8149 Mdot
.70292 .94739 Mdot
.20851 .86843 Mdot
.84266 .4415 Mdot
.66491 .58955 Mdot
.86677 .98442 Mdot
.43434 .18106 Mdot
.08238 .66929 Mdot
.54451 .91588 Mdot
.57668 .5865 Mdot
.10077 .85958 Mdot
.63184 .42795 Mdot
.16444 .60064 Mdot
.6806 .31505 Mdot
.17791 .43918 Mdot
.30749 .53027 Mdot
.27438 .08693 Mdot
.73184 .36117 Mdot
.59771 .14704 Mdot
.3049 .91206 Mdot
.51982 .40225 Mdot
.7589 .56153 Mdot
.86942 .92199 Mdot
.32466 .37473 Mdot
.57739 .60103 Mdot
.19449 .70925 Mdot
.48008 .96642 Mdot
.86305 .47791 Mdot
.17752 .87214 Mdot
.48979 .78697 Mdot
.32645 .3324 Mdot
.818 .78348 Mdot
.87945 .4122 Mdot
.32524 .41466 Mdot
.09066 .58091 Mdot
.56372 .76204 Mdot
.31086 .66561 Mdot
.99053 .83853 Mdot
.61069 .54966 Mdot
.553 .79039 Mdot
.72848 .34581 Mdot
.56621 .24893 Mdot
.07677 .59124 Mdot
.31225 .97103 Mdot
.4789 .50382 Mdot
.06316 .46811 Mdot
.57632 .47773 Mdot
.58727 .81059 Mdot
.65778 .7455 Mdot
.73481 .93516 Mdot
.66392 .0267 Mdot
.05572 .63948 Mdot
.14373 .4375 Mdot
.58667 .72744 Mdot
.22702 .44625 Mdot
.20679 .31213 Mdot
.39239 .92425 Mdot
.04492 .31593 Mdot
.55165 .69925 Mdot
.41825 .08835 Mdot
.21017 .22321 Mdot
.01191 .2437 Mdot
.82635 .81659 Mdot
.99308 .3071 Mdot
.54496 .36846 Mdot
.36749 .69488 Mdot
.62041 .77045 Mdot
.94501 .23706 Mdot
.3105 .37571 Mdot
.06109 .21824 Mdot
.20911 .78818 Mdot
.35274 .24495 Mdot
.84085 .19108 Mdot
.81534 .9204 Mdot
.14646 .36188 Mdot
.61812 .51313 Mdot
.30261 .54397 Mdot
.55473 .39896 Mdot
.61122 .70901 Mdot
.0994 .60362 Mdot
.59798 .43653 Mdot
.14015 .98711 Mdot
.98153 .15668 Mdot
.95172 .27975 Mdot
.8674 .61481 Mdot
.39357 .78165 Mdot
.93771 .68529 Mdot
.46417 .52716 Mdot
.44426 .53817 Mdot
.0257 .91567 Mdot
.93189 .41193 Mdot
.51313 .27962 Mdot
.40738 .14506 Mdot
.29066 .42214 Mdot
.68134 .42364 Mdot
.60133 .11723 Mdot
.36709 .59573 Mdot
.52388 .62143 Mdot
.35939 .31935 Mdot
.16422 .34557 Mdot
.02723 .35153 Mdot
.87375 .23763 Mdot
.87512 .77525 Mdot
.16549 .21544 Mdot
.74628 .34687 Mdot
.83341 .38979 Mdot
.35634 .24405 Mdot
.40072 .30503 Mdot
.51634 .46562 Mdot
.2034 .58415 Mdot
.3575 .17756 Mdot
.16737 .47616 Mdot
.69613 .64177 Mdot
.02809 .16523 Mdot
.26649 .02995 Mdot
.66717 .17135 Mdot
.52209 .40726 Mdot
.51378 .30909 Mdot
.30991 .29843 Mdot
.15994 .07526 Mdot
.12783 .72485 Mdot
.32598 .29089 Mdot
.92386 .37092 Mdot
.12217 .58282 Mdot
.95809 .60992 Mdot
.35281 .36058 Mdot
.14231 .35985 Mdot
.50927 .37484 Mdot
.48888 .24829 Mdot
.90053 .48678 Mdot
.43583 .18171 Mdot
.56259 .07072 Mdot
.78563 .94401 Mdot
.62492 .4606 Mdot
.42915 .48633 Mdot
.76716 .49489 Mdot
.97759 .96484 Mdot
.26859 .14057 Mdot
.27038 .4296 Mdot
.97767 .87736 Mdot
.85045 .52876 Mdot
.57452 .55897 Mdot
.55362 .79098 Mdot
.86604 .01573 Mdot
.50472 .5762 Mdot
.40658 .79437 Mdot
.93961 .34692 Mdot
.58515 .8724 Mdot
.61623 .7825 Mdot
.44791 .84821 Mdot
.55867 .11133 Mdot
.81016 .10367 Mdot
.20935 .54113 Mdot
.79532 .65106 Mdot
.96573 .55261 Mdot
.72858 .64941 Mdot
.54769 .7848 Mdot
.53487 .93852 Mdot
.51618 .83359 Mdot
.9365 .8986 Mdot
.06643 .87714 Mdot
.88656 .3353 Mdot
.85872 .47382 Mdot
.69785 .26484 Mdot
.31678 .85405 Mdot
.86629 .08491 Mdot
.51011 .03898 Mdot
.90933 .54045 Mdot
.84007 .16743 Mdot
.20126 .65659 Mdot
.9427 .26345 Mdot
.71275 .88875 Mdot
.35506 .55988 Mdot
.70819 .36611 Mdot
.36071 .85234 Mdot
.91264 .37098 Mdot
.80247 .04596 Mdot
.02599 .12728 Mdot
.19854 .14922 Mdot
.14163 .74327 Mdot
.39274 .46104 Mdot
.09945 .47392 Mdot
.36645 .52754 Mdot
.61912 .68916 Mdot
.18544 .60289 Mdot
.75797 .48772 Mdot
.50916 .7521 Mdot
.37947 .76418 Mdot
.57604 .81843 Mdot
.69706 .1623 Mdot
.64327 .78489 Mdot
.95654 .51313 Mdot
.69785 .18611 Mdot
.21264 .00725 Mdot
.29595 .34615 Mdot
.00671 .56351 Mdot
.32534 .41802 Mdot
.97941 .24294 Mdot
.48329 .71348 Mdot
.6103 .15879 Mdot
.2905 .01652 Mdot
.90617 .57152 Mdot
.15906 .93083 Mdot
.87417 .04386 Mdot
.87544 .46497 Mdot
.40585 .77825 Mdot
.67427 .60593 Mdot
.74686 .50849 Mdot
.76366 .7734 Mdot
.96327 .76118 Mdot
.48351 .02454 Mdot
.30445 .15531 Mdot
.45978 .13565 Mdot
.17842 .73703 Mdot
.68663 .7571 Mdot
.38763 .36842 Mdot
.01705 .96789 Mdot
.04882 .45387 Mdot
.88051 .38696 Mdot
.319 .26948 Mdot
.13591 .60128 Mdot
.8479 .15679 Mdot
.00421 .57943 Mdot
.52486 .64608 Mdot
.58466 .96356 Mdot
.16689 .29763 Mdot
.21472 .70085 Mdot
.52919 .25384 Mdot
.04938 .22256 Mdot
.13313 .50339 Mdot
.46149 .50628 Mdot
.90391 .54151 Mdot
.55683 .45446 Mdot
.39808 .78631 Mdot
.19274 .66239 Mdot
.64967 .87982 Mdot
.49073 .20127 Mdot
.34726 .46742 Mdot
.99616 .47431 Mdot
.40409 .29428 Mdot
.99021 .33787 Mdot
.59695 .71159 Mdot
.26641 .27536 Mdot
.54254 .35927 Mdot
.23968 .57882 Mdot
.52889 .15197 Mdot
.19886 .57647 Mdot
.16773 .32924 Mdot
.90197 .44072 Mdot
.77283 .7813 Mdot
.08323 .25111 Mdot
.33138 .77722 Mdot
.89192 .0195 Mdot
.77772 .69913 Mdot
.0835 .83411 Mdot
.04563 .59367 Mdot
.16522 .49326 Mdot
.05786 .21513 Mdot
.10599 .08057 Mdot
.11988 .36807 Mdot
.74778 .74219 Mdot
.61383 .0893 Mdot
.18374 .24751 Mdot
.32639 .48053 Mdot
.07043 .09825 Mdot
.5603 .21551 Mdot
.5565 .29799 Mdot
.61972 .9694 Mdot
.12307 .87259 Mdot
.64654 .56695 Mdot
.31334 .98952 Mdot
.40514 .80178 Mdot
.98732 .15587 Mdot
.61496 .7701 Mdot
.45129 .07664 Mdot
.39507 .21883 Mdot
.33449 .5638 Mdot
.00161 .88379 Mdot
.04907 .10294 Mdot
.40592 .01234 Mdot
.88797 .02394 Mdot
.4946 .18124 Mdot
.98013 .25477 Mdot
.30832 .34589 Mdot
.86212 .83067 Mdot
.73867 .07477 Mdot
.02341 .1372 Mdot
.00372 .7932 Mdot
.89643 .39788 Mdot
.965 .7371 Mdot
.16074 .08979 Mdot
.57479 .77855 Mdot
.22697 .9419 Mdot
.94312 .53019 Mdot
.32902 .66368 Mdot
.61025 .06454 Mdot
.65274 .58123 Mdot
.08699 .30786 Mdot
.23191 .41 Mdot
.89066 .16813 Mdot
.24722 .38152 Mdot
.2275 .5282 Mdot
.16393 .8223 Mdot
.65664 .48771 Mdot
.13912 .29875 Mdot
.82238 .8424 Mdot
.87096 .76065 Mdot
.55109 .37743 Mdot
.94169 .81834 Mdot
.07801 .44177 Mdot
.87748 .0777 Mdot
.59896 .86842 Mdot
.67569 .92854 Mdot
.16631 .22665 Mdot
.86908 .78955 Mdot
.79064 .79331 Mdot
.0919 .06777 Mdot
.57111 .90496 Mdot
.27854 .98871 Mdot
.47644 .1471 Mdot
.17183 .71503 Mdot
.5148 .02386 Mdot
.25755 .75457 Mdot
.36853 .41682 Mdot
.38843 .39936 Mdot
.56689 .69582 Mdot
.5831 .85742 Mdot
.71706 .05116 Mdot
.39658 .31129 Mdot
.01829 .77824 Mdot
.21092 .73116 Mdot
.97003 .54589 Mdot
.23003 .93519 Mdot
.93971 .30613 Mdot
.07566 .3797 Mdot
.35911 .36177 Mdot
.10003 .03152 Mdot
.74993 .38244 Mdot
.55071 .16781 Mdot
.6451 .85766 Mdot
.05409 .49405 Mdot
.591 .67175 Mdot
.60228 .62839 Mdot
.39263 .47605 Mdot
.46147 .04364 Mdot
.77248 .80349 Mdot
.15367 .78865 Mdot
.07188 .53854 Mdot
.55524 .35612 Mdot
.17093 .86746 Mdot
.96917 .48907 Mdot
.0238 .48646 Mdot
.314 .78163 Mdot
.60049 .34445 Mdot
.90067 .34768 Mdot
.12531 .45573 Mdot
.67119 .26907 Mdot
.60398 .60348 Mdot
.37281 .67864 Mdot
.24349 .01683 Mdot
.19568 .77563 Mdot
.0809 .87002 Mdot
.8936 .03888 Mdot
.32175 .95445 Mdot
.13652 .97103 Mdot
.57097 .25466 Mdot
.83729 .83381 Mdot
.24677 .13487 Mdot
.69568 .91504 Mdot
.32263 .58619 Mdot
.06084 .36865 Mdot
.79625 .02027 Mdot
.77753 .2248 Mdot
.79218 .99623 Mdot
.40427 .51736 Mdot
.85723 .13035 Mdot
.63249 .85341 Mdot
.67324 .89754 Mdot
.95456 .9527 Mdot
.26973 .72916 Mdot
.27116 .34641 Mdot
.32493 .7655 Mdot
.10606 .01797 Mdot
.39954 .86857 Mdot
.21144 .49104 Mdot
.04744 .13389 Mdot
.62746 .16744 Mdot
.4411 .16747 Mdot
.12833 .28734 Mdot
.91688 .12621 Mdot
.42099 .87039 Mdot
.78872 .59832 Mdot
.32593 .63972 Mdot
.03948 .9975 Mdot
.06673 .86755 Mdot
.39025 .45657 Mdot
.48344 .23512 Mdot
.72307 .58756 Mdot
.69281 .28139 Mdot
.23829 .70561 Mdot
.05035 .17391 Mdot
.98964 .30459 Mdot
.46127 .81914 Mdot
.61225 .41099 Mdot
.49924 .12971 Mdot
.36156 .14681 Mdot
.13287 .32009 Mdot
.76011 .09373 Mdot
.36483 .99278 Mdot
.50903 .66843 Mdot
.98283 .88567 Mdot
.62201 .99494 Mdot
.1952 .44292 Mdot
.4428 .00791 Mdot
.89235 .11992 Mdot
.31023 .36536 Mdot
.59388 .11312 Mdot
.91148 .98153 Mdot
.18108 .59334 Mdot
.99309 .92484 Mdot
.71366 .79371 Mdot
.41659 .50106 Mdot
.51335 .24629 Mdot
.01687 .15139 Mdot
.85642 .40285 Mdot
.45403 .15771 Mdot
.22869 .80347 Mdot
.26895 .16773 Mdot
.99753 .65043 Mdot
.14638 .78907 Mdot
.59263 .93332 Mdot
.29878 .43527 Mdot
.19424 .4612 Mdot
.71756 .03246 Mdot
.58113 .00888 Mdot
.99051 .95057 Mdot
.43834 .99771 Mdot
.87085 .68094 Mdot
.63568 .15085 Mdot
.4658 .86491 Mdot
.499 .60565 Mdot
.41841 .25827 Mdot
.71971 .51844 Mdot
.11477 .49642 Mdot
.84664 .79708 Mdot
.22603 .21694 Mdot
.16849 .44379 Mdot
.64982 .11999 Mdot
.36924 .75164 Mdot
.81156 .67294 Mdot
.67005 .64635 Mdot
.12436 .34182 Mdot
.38912 .32761 Mdot
.50151 .01936 Mdot
.30481 .61052 Mdot
.37985 .70104 Mdot
.25119 .66296 Mdot
.00404 .46145 Mdot
.30256 .50538 Mdot
.88545 .69179 Mdot
.25087 .04204 Mdot
.93474 .20103 Mdot
.56255 .11074 Mdot
.71431 .57141 Mdot
.46748 .25482 Mdot
.60552 .5065 Mdot
.0604 .43607 Mdot
.97048 .54996 Mdot
.93461 .55401 Mdot
.17424 .03319 Mdot
.76237 .2756 Mdot
.3137 .59874 Mdot
.49345 .71207 Mdot
.57213 .71079 Mdot
.63531 .32583 Mdot
.80793 .34451 Mdot
.6177 .10477 Mdot
.38828 .8095 Mdot
.738 .72318 Mdot
.2703 .1589 Mdot
.89414 .7788 Mdot
.07045 .9537 Mdot
.25226 .15067 Mdot
.26626 .73725 Mdot
.61736 .45734 Mdot
.83981 .31031 Mdot
.93292 .00521 Mdot
.15169 .25421 Mdot
.27285 .03675 Mdot
.27258 .97764 Mdot
.44498 .5002 Mdot
.89867 .98212 Mdot
.21089 .6279 Mdot
.88359 .46845 Mdot
.28264 .56322 Mdot
.54745 .0467 Mdot
.62174 .91127 Mdot
.46816 .08332 Mdot
.09442 .78759 Mdot
.61975 .1293 Mdot
.12758 .65232 Mdot
.12134 .32191 Mdot
.39215 .42753 Mdot
.14062 .15722 Mdot
.22248 .86887 Mdot
.41188 .46757 Mdot
.26073 .43686 Mdot
.58504 .61644 Mdot
.964 .38997 Mdot
.0261 .27191 Mdot
.85403 .06474 Mdot
.72931 .23019 Mdot
.59636 .92375 Mdot
.4281 .04363 Mdot
.2536 .55516 Mdot
.61237 .78466 Mdot
.25454 .25324 Mdot
.23183 .95306 Mdot
.97832 .4481 Mdot
.18039 .70536 Mdot
.62804 .36359 Mdot
.51283 .63821 Mdot
.35492 .55368 Mdot
.42838 .64877 Mdot
.14889 .47973 Mdot
.19787 .73231 Mdot
.39297 .37904 Mdot
.93523 .85912 Mdot
.11924 .47162 Mdot
.59033 .91267 Mdot
.68606 .64347 Mdot
.38712 .37178 Mdot
.33947 .25223 Mdot
.15621 .54969 Mdot
.45659 .84688 Mdot
.66404 .12694 Mdot
.50246 .85286 Mdot
.75916 .29992 Mdot
.76901 .35361 Mdot
.67381 .1822 Mdot
.45192 .44205 Mdot
.39609 .04252 Mdot
.01154 .01908 Mdot
.72883 .81757 Mdot
.99374 .88913 Mdot
.75806 .83762 Mdot
.96172 .01992 Mdot
.9229 .4407 Mdot
.73151 .33458 Mdot
.41611 .05628 Mdot
.43213 .9459 Mdot
.5157 .56683 Mdot
.80756 .62421 Mdot
.32935 .37952 Mdot
.20821 .54733 Mdot
.02043 .52719 Mdot
.01627 .46699 Mdot
.17672 .65463 Mdot
.99699 .90758 Mdot
.54808 .94624 Mdot
.50957 .53656 Mdot
.59803 .62307 Mdot
.52835 .66835 Mdot
.24616 .89711 Mdot
.47187 .99954 Mdot
.99638 .18335 Mdot
.76011 .56554 Mdot
.02966 .43788 Mdot
.58307 .72532 Mdot
.6892 .61993 Mdot
.6816 .46228 Mdot
.39878 .03212 Mdot
.24927 .53455 Mdot
.70024 .82162 Mdot
.21467 .03171 Mdot
.2256 .5225 Mdot
.55084 .13954 Mdot
.70905 .6326 Mdot
.09637 .71938 Mdot
.60274 .08903 Mdot
.2408 .9502 Mdot
.34744 .06767 Mdot
.53044 .28217 Mdot
.31317 .95768 Mdot
.54883 .275 Mdot
.39129 .33283 Mdot
.75643 .00682 Mdot
.50902 .70127 Mdot
.09911 .24276 Mdot
.4214 .97512 Mdot
.2752 .95016 Mdot
.1642 .46701 Mdot
.25691 .56953 Mdot
.48604 .54882 Mdot
.96724 .91466 Mdot
.10406 .0757 Mdot
.18777 .53822 Mdot
.55669 .8752 Mdot
.59722 .85942 Mdot
.49987 .08057 Mdot
.05153 .05851 Mdot
.71259 .3484 Mdot
.62934 .66181 Mdot
.87917 .47918 Mdot
.85909 .12694 Mdot
.1834 .09057 Mdot
.51547 .23299 Mdot
.07317 .15259 Mdot
.74229 .59958 Mdot
.24414 .28818 Mdot
.91872 .79465 Mdot
.11927 .93103 Mdot
.2112 .83876 Mdot
.41873 .34275 Mdot
.77722 .50669 Mdot
.46545 .6471 Mdot
.77056 .39852 Mdot
.71645 .30764 Mdot
.55382 .80209 Mdot
.50415 .30307 Mdot
.64714 .71922 Mdot
.33713 .46071 Mdot
.34986 .50556 Mdot
.9141 .79674 Mdot
.37359 .83514 Mdot
.40379 .18319 Mdot
.78511 .35058 Mdot
.47385 .28583 Mdot
.93078 .26831 Mdot
.01252 .15466 Mdot
.6791 .96663 Mdot
.6342 .58069 Mdot
.99246 .80575 Mdot
.56032 .97808 Mdot
.2167 .9153 Mdot
.22023 .19302 Mdot
.36382 .00206 Mdot
.86189 .98042 Mdot
.94612 .63462 Mdot
.19249 .48067 Mdot
.32206 .39933 Mdot
.20375 .53342 Mdot
.07429 .97085 Mdot
.72291 .14603 Mdot
.4064 .68268 Mdot
.56261 .66783 Mdot
.96215 .44895 Mdot
.89848 .138 Mdot
.85921 .03366 Mdot
.19465 .39613 Mdot
.92941 .0307 Mdot
.62437 .6204 Mdot
.9172 .01063 Mdot
.82819 .17548 Mdot
.68337 .75288 Mdot
.0973 .76493 Mdot
.93353 .11041 Mdot
.89729 .15215 Mdot
.14045 .70282 Mdot
.17091 .73236 Mdot
.68754 .11885 Mdot
.18761 .55974 Mdot
.69027 .65603 Mdot
.05146 .14964 Mdot
.80537 .07205 Mdot
.26431 .02805 Mdot
.63744 .99051 Mdot
.30589 .72656 Mdot
.7507 .88195 Mdot
.71887 .73509 Mdot
.55663 .30034 Mdot
.44031 .03742 Mdot
.36328 .43843 Mdot
.47223 .11904 Mdot
.47359 .85097 Mdot
.51828 .15992 Mdot
.60996 .84821 Mdot
.86378 .36918 Mdot
.70046 .62748 Mdot
.38253 .64045 Mdot
.05376 .46744 Mdot
.16348 .94237 Mdot
.40581 .49999 Mdot
.66267 .53519 Mdot
.16268 .84336 Mdot
.47586 .60275 Mdot
.99549 .31987 Mdot
.17533 .93153 Mdot
.37374 .07759 Mdot
.37725 .07384 Mdot
.74224 .63892 Mdot
.43408 .11499 Mdot
.35266 .76024 Mdot
.10382 .24457 Mdot
.17208 .61153 Mdot
.92411 .38569 Mdot
.65447 .55464 Mdot
.15872 .4551 Mdot
.33211 .91061 Mdot
.14832 .61201 Mdot
.19361 .70797 Mdot
.00931 .4704 Mdot
.15607 .30019 Mdot
.43809 .26045 Mdot
.1036 .53279 Mdot
.91743 .13921 Mdot
.96065 .2054 Mdot
.45703 .50588 Mdot
.59935 .96238 Mdot
.26544 .31658 Mdot
.88263 .09599 Mdot
.65284 .15774 Mdot
.14665 .50918 Mdot
.79385 .62484 Mdot
.85184 .39218 Mdot
.19241 .48852 Mdot
.02917 .01659 Mdot
.20561 .18958 Mdot
.51076 .50133 Mdot
.94457 .34458 Mdot
.4454 .95211 Mdot
.58123 .02812 Mdot
.50198 .92547 Mdot
.90563 .25667 Mdot
.67715 .29865 Mdot
.101 .2342 Mdot
.12213 .2704 Mdot
.43418 .54056 Mdot
.1268 .86724 Mdot
.6757 .43228 Mdot
.27148 .59414 Mdot
.88232 .55835 Mdot
.67674 .24585 Mdot
.01564 .73392 Mdot
.66648 .78693 Mdot
.34482 .51701 Mdot
.46586 .47389 Mdot
.12732 .32994 Mdot
.73853 .45798 Mdot
.87281 .41425 Mdot
.84086 .54384 Mdot
.56746 .42315 Mdot
.41969 .54568 Mdot
.83638 .99789 Mdot
.50804 .97487 Mdot
.65798 .56076 Mdot
.85892 .18424 Mdot
.42008 .70876 Mdot
.52415 .26576 Mdot
.29199 .67416 Mdot
.54012 .88272 Mdot
.31408 .90446 Mdot
.2041 .9692 Mdot
.14765 .36297 Mdot
.56651 .87241 Mdot
.95629 .67742 Mdot
.0044 .0285 Mdot
.50031 .57297 Mdot
.86378 .33179 Mdot
.79815 .55028 Mdot
.356 .31775 Mdot
.98451 .02188 Mdot
.9078 .02798 Mdot
.54528 .93839 Mdot
.21964 .17798 Mdot
.64832 .34082 Mdot
.68771 .23034 Mdot
.09302 .10837 Mdot
.39686 .3263 Mdot
.59401 .76219 Mdot
.17529 .02472 Mdot
.38028 .3676 Mdot
.24549 .35312 Mdot
.39177 .41054 Mdot
.19695 .8338 Mdot
.8407 .57836 Mdot
.1185 .32637 Mdot
.91947 .90933 Mdot
.7357 .38705 Mdot
.0165 .95262 Mdot
.3655 .94045 Mdot
.21758 .09472 Mdot
.23876 .35134 Mdot
.75308 .85366 Mdot
.02589 .27063 Mdot
.51105 .18991 Mdot
.48133 .43915 Mdot
.22244 .59388 Mdot
.59981 .91648 Mdot
.21226 .35418 Mdot
.05322 .8296 Mdot
.34173 .24442 Mdot
.38666 .14716 Mdot
.77671 .14074 Mdot
.53091 .37793 Mdot
.29323 .38025 Mdot
.71902 .60278 Mdot
.36829 .14413 Mdot
.87581 .10528 Mdot
.51977 .79741 Mdot
.25383 .82186 Mdot
.83989 .08108 Mdot
.30121 .04809 Mdot
.30655 .6926 Mdot
.62247 .10187 Mdot
.35055 .68404 Mdot
.52011 .46393 Mdot
.53752 .43753 Mdot
.26223 .99747 Mdot
.2039 .30243 Mdot
.25542 .17249 Mdot
.51372 .95051 Mdot
.05221 .28059 Mdot
.62307 .55744 Mdot
.32114 .20918 Mdot
.06964 .67424 Mdot
.94007 .21767 Mdot
.98825 .07737 Mdot
.17378 .78961 Mdot
.41294 .855 Mdot
.72249 .68243 Mdot
.13682 .3619 Mdot
.00732 .44036 Mdot
.99216 .65462 Mdot
.70381 .42942 Mdot
.22294 .36093 Mdot
.95954 .78811 Mdot
.74433 .48198 Mdot
.48319 .84181 Mdot
.81502 .45552 Mdot
.30473 .74972 Mdot
.90104 .53045 Mdot
.36296 .36809 Mdot
.54694 .24831 Mdot
.31066 .83436 Mdot
.05177 .24999 Mdot
.40367 .62567 Mdot
.00676 .29228 Mdot
.41513 .93258 Mdot
.10653 .56227 Mdot
.63015 .14052 Mdot
.91027 .19003 Mdot
.67699 .88345 Mdot
.93601 .68941 Mdot
.16305 .16747 Mdot
.67107 .26046 Mdot
.185 .55226 Mdot
.43276 .92796 Mdot
.62325 .84767 Mdot
.76055 .91209 Mdot
.49324 .99838 Mdot
.62907 .94117 Mdot
.73605 .53828 Mdot
.73245 .57098 Mdot
.36407 .08653 Mdot
.83876 .55804 Mdot
.9006 .53937 Mdot
.16793 .92835 Mdot
.68376 .0353 Mdot
.40657 .40346 Mdot
.05423 .30572 Mdot
.03737 .92835 Mdot
.84471 .34519 Mdot
.29843 .82148 Mdot
.44155 .70391 Mdot
.48713 .50943 Mdot
.42082 .01525 Mdot
.48327 .0918 Mdot
.17273 .04892 Mdot
.82352 .96327 Mdot
.74616 .70631 Mdot
.76753 .7301 Mdot
.67936 .08002 Mdot
.79399 .85874 Mdot
.19147 .17106 Mdot
.81724 .01998 Mdot
.06809 .21689 Mdot
.26659 .60574 Mdot
.08463 .36199 Mdot
.06815 .08145 Mdot
.95095 .95883 Mdot
.68543 .41988 Mdot
.22609 .36828 Mdot
.22793 .56924 Mdot
.14025 .62879 Mdot
.35627 .37689 Mdot
.94216 .13801 Mdot
.35837 .92352 Mdot
.58345 .19364 Mdot
.22237 .87823 Mdot
.82214 .82566 Mdot
.28942 .36491 Mdot
.242 .7323 Mdot
.04666 .17564 Mdot
.62052 .54043 Mdot
.27762 .75425 Mdot
.30741 .71579 Mdot
.78138 .99083 Mdot
.81901 .68651 Mdot
.77316 .95182 Mdot
.0608 .55652 Mdot
.45064 .15468 Mdot
.05833 .73312 Mdot
.56082 .55553 Mdot
.24713 .12732 Mdot
.52167 .79746 Mdot
.35444 .45857 Mdot
.21417 .2953 Mdot
.95881 .46229 Mdot
.1015 .02002 Mdot
.1462 .83844 Mdot
.74061 .5493 Mdot
.58413 .06415 Mdot
.54342 .77124 Mdot
.24493 .55348 Mdot
.97032 .05126 Mdot
.22225 .75721 Mdot
.13046 .74679 Mdot
.59953 .74919 Mdot
.8012 .67463 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00Co0000oooooooooooooooo0_l0000;ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo000Nooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool00_l0000;ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool01?l0003oooooooooooooool2o`0000_ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool01?l0003oooooo`000?l0000=ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`07ooooo`;o00001?ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00;ooooo000Nooooo`03o`000?oooooooooo047ooooo0_l00019oooo
o`;o0000:oooool2o`0003Oooooo0_l0000booooo`;o00000oooool2o`0001[ooooo000Nooooo`03
o`000?oooooooooo07Oooooo0_l00007ooooo`;o00002_ooool2o`0002_ooooo0_l0001[ooooo`;o
00007oooool001kooooo00?o0000ooooooooool01Oooool2o`0005?ooooo0_l00008ooooo`;o0000
4Oooool2o`0000Oooooo0_l00003ooooo`;o0000@_ooool2o`0004[ooooo0_l0000`ooooo`007_oo
ool00ol0003oooooooooo`02o`0000?ooooo0_l0000Gooooo`;o0000:oooool2o`0000gooooo0_l0
0008ooooo`;o00007oooool2o`0001Sooooo0_l0000Xooooo`;o0000B_ooool2o`0000Oooooo0_l0
000Wooooo`007_ooool00ol0003oooooooooo`02o`0001_ooooo0ol0000[ooooo`;o0000D_ooool2
o`0005kooooo0_l00005ooooo`;o00005_ooool2o`0001Gooooo0_l00005ooooo`;o00002Oooool0
01kooooo00?o0000ooooooooool07Oooool2o`0001Kooooo0_l0001Rooooo`;o00002?ooool2o`00
05[ooooo0_l00005ooooo`;o00005Oooool2o`0001Kooooo0_l00005ooooo`;o00002Oooool001ko
oooo0_l0000fooooo`;o00006oooool2o`0004Gooooo0_l00008ooooo`;o00005?ooool2o`0001Wo
oooo0_l00017ooooo`;o00001?ooool2o`0001Oooooo0_l00009ooooo`007_ooool2o`0001gooooo
0_l0000Tooooo`;o00003_ooool3o`0000Oooooo0_l0000Pooooo`;o0000>Oooool2o`0001Wooooo
0_l0001=ooooo`;o00001Oooool2o`0001_ooooo000Nooooo`03o`000?oooooooooo01cooooo0_l0
000Gooooo`;o00002oooool2o`0000oooooo0_l00007ooooo`;o00008?ooool2o`0006Gooooo0_l0
000/ooooo`;o00005Oooool2o`0001_ooooo000Nooooo`03o`000?oooooooooo03Gooooo0_l0000F
ooooo`;o00001_ooool2o`0003Cooooo0_l0001=ooooo`;o00002Oooool2o`0002cooooo0_l0000b
ooooo`007_ooool00ol0003oooooooooo`1=ooooo`;o00001_ooool2o`0003Cooooo0_l0000Eoooo
o`;o0000=_ooool2o`0004;ooooo0_l0000Wooooo`007_ooool00ol0003oooooooooo`1=ooooo`;o
0000;_ooool2o`0000Sooooo0_l00009ooooo`;o00003_ooool2o`0007Cooooo0_l00004ooooo`;o
00009oooool001kooooo00?o0000ooooooooool0COooool2o`0002kooooo0_l00008ooooo`;o0000
2Oooool2o`0001[ooooo0_l0001Aooooo`;o00005Oooool2o`0002gooooo000Nooooo`03o`000?oo
oooooooo03Cooooo0_l0000Xooooo`;o0000C_ooool2o`00057ooooo0_l00014ooooo`007_ooool2
o`0003Gooooo0_l0000Xooooo`;o0000QOooool2o`00053ooooo0_l0000>ooooo`007_ooool00ol0
003oooooooooo`23ooooo`;o0000H?ooool2o`00053ooooo0_l0000>ooooo`007_ooool00ol0003o
ooooooooo`0=ooooo`;o0000M?ooool2o`000<;ooooo000Nooooo`03o`000?oooooooooo00gooooo
0_l0003oooooocWooooo000Nooooo`03o`000?oooooooooo0;[ooooo0_l00006ooooo`;o0000@?oo
ool2o`0000cooooo0_l0000cooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o0000DOooool2
o`0004_ooooo0_l00006ooooo`;o0000@?ooool2o`0000cooooo0_l0000cooooo`007_ooool00ol0
003oooooooooo`0Jooooo`;o0000DOooool2o`0004Cooooo0_l0001=ooooo`;o0000@oooool001ko
oooo00?o0000ooooooooool0Moooool2o`0003[ooooo0_l0000gooooo`;o00005?ooool2o`0004?o
oooo000Nooooo`03o`000?oooooooooo01kooooo0_l0000@ooooo`;o0000@oooool4o`0001Kooooo
0_l0001Kooooo`;o0000:oooool2o`0002;ooooo0_l00008ooooo`007_ooool00ol0003ooooooooo
o`0Nooooo`;o00004?ooool2o`0004?ooooo0_l0000Hooooo`;o00003Oooool2o`0003Wooooo0_l0
000booooo`;o00002_ooool2o`0002;ooooo0_l00008ooooo`007_ooool00ol0003oooooooooo`0B
ooooo`;o00002_ooool2o`00043ooooo0_l0000booooo`;o00002?ooool2o`0003Wooooo0_l0000b
ooooo`;o0000>?ooool001kooooo00?o0000ooooooooool04_ooool2o`00047ooooo0_l00009oooo
o`;o00004?ooool2o`00023ooooo0_l00020ooooo`;o0000;oooool001kooooo00?o0000oooooooo
ool0<?ooool2o`0000Kooooo0_l0000Kooooo`;o00006oooool2o`00013ooooo0_l0000jooooo`;o
000000?oooooo`000?l00000DOooool2o`0002oooooo000Nooooo`03o`000?oooooooooo033ooooo
0_l00006ooooo`;o0000B_ooool2o`0001?ooooo0_l0000Uooooo`;o000000?oooooo`000?l00000
P_ooool001kooooo00?o0000ooooooooool0@oooool2o`0005Cooooo0_l0001Hooooo`;o00009_oo
ool2o`0002[ooooo000Nooooo`03o`000?oooooooooo01?ooooo0_l0000^ooooo`;o0000[_ooool2
o`0002Kooooo0_l0000Zooooo`007_ooool2o`0001Cooooo0_l0002aooooo`;o0000Ooooool001ko
oooo00?o0000ooooooooool03?ooool2o`0002kooooo0_l00027ooooo`?o0000>oooool2o`0001Co
oooo0_l0000/ooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o00003?ooool2o`00023ooooo
0_l00027ooooo`;o0000??ooool2o`0001Cooooo0_l0000/ooooo`007_ooool00ol0003ooooooooo
o`0<ooooo`;o00003?ooool2o`0009Kooooo0ol0001fooooo`;o00006_ooool001kooooo00?o0000
ooooooooool0ROooool2o`0002Oooooo0ol00008ooooo`;o0000K?ooool2o`0001[ooooo000Noooo
o`03o`000?oooooooooo01Sooooo0_l0001_ooooo`;o0000<_ooool4o`0008Kooooo000Nooooo`03
o`000?oooooooooo01Sooooo0_l0001kooooo`;o0000:?ooool2o`0000kooooo0_l0000:ooooo`;o
0000@Oooool2o`0002Oooooo000Nooooo`03o`000?oooooooooo09Gooooo0_l0000hooooo`;o0000
2_ooool2o`00047ooooo0_l0000Wooooo`007_ooool00ol0003oooooooooo`04ooooo`;o0000A_oo
ool2o`0008Kooooo0_l0000mooooo`;o00004Oooool2o`0001oooooo000Nooooo`03o`000?oooooo
oooo00Cooooo0_l00016ooooo`;o0000D?ooool2o`0002Gooooo0_l0000=ooooo`;o0000?Oooool2
o`00017ooooo0_l0000Oooooo`007_ooool00ol0003oooooooooo`2Nooooo`;o00009Oooool2o`00
04cooooo0_l0000booooo`007_ooool00ol0003oooooooooo`0;ooooo`;o00003Oooool2o`00033o
oooo0_l00013ooooo`;o0000]?ooool001kooooo00?o0000ooooooooool00oooool2o`0000Kooooo
0_l0000=ooooo`;o0000<?ooool2o`0004?ooooo0_l0000Looooo`;o0000Koooool2o`0000Cooooo
0_l00006ooooo`;o00005oooool001kooooo00?o0000ooooooooool00oooool2o`0004kooooo0_l0
001Jooooo`;o00006?ooool2o`0002gooooo0_l0000Vooooo`;o00001?ooool2o`0000Kooooo0_l0
000Gooooo`007_ooool00ol0003oooooooooo`1Cooooo`;o00007oooool2o`0000[ooooo0_l00017
ooooo`;o0000;Oooool2o`0004gooooo000Nooooo`03o`000?oooooooooo077ooooo0_l000000ooo
oooo0000o`000004ooooo`;o00001?ooool2o`0001Gooooo0_l0000Uooooo`;o00009oooool2o`00
05kooooo000Nooooo`;o00000_ooool2o`0000[ooooo0_l0000]ooooo`;o00004?ooool2o`00027o
oooo0_l00007ooooo`;o00006oooool2o`0000oooooo0_l0000Dooooo`;o00002oooool2o`0001[o
oooo0_l0000gooooo`;o00009Oooool001kooooo00?o0000ooooooooool00ol0000:ooooo`;o0000
1Oooool2o`0002Kooooo0_l0000@ooooo`;o0000?_ooool2o`0001Sooooo0_l0000Qooooo`;o0000
Doooool2o`0002Gooooo000Nooooo`03o`000?oooooooooo00Co00004?ooool2o`0001Cooooo0_l0
000cooooo`;o00008oooool2o`0000Sooooo0ol0000oooooo`;o0000?_ooool2o`0001Wooooo0_l0
000>ooooo`Co00002?ooool001kooooo00?o0000ooooooooool00_ooool2o`0002Kooooo0_l0000X
ooooo`;o00002Oooool2o`0002?ooooo0_l00009ooooo`;o00004oooool2o`0001cooooo0_l0000<
ooooo`;o0000?_ooool2o`0001Wooooo0_l0000>ooooo`Co00002?ooool001kooooo00?o0000oooo
ooooool0E?ooool2o`0004kooooo0_l0000Looooo`;o00006oooool2o`0006Kooooo000Nooooo`03
o`000?oooooooooo00Gooooo0_l0000Zooooo`;o0000F?ooool2o`0003_ooooo0_l0000Eooooo`;o
0000;?ooool2o`0003Sooooo000Nooooo`03o`000?oooooooooo00Gooooo0_l0000Zooooo`;o0000
8?ooool2o`0003Kooooo0_l0000Rooooo`;o00005oooool2o`0004?ooooo0_l0000>ooooo`;o0000
:?ooool001kooooo00?o0000ooooooooool0>_ooool2o`0001?ooooo0_l00002ooooo`;o0000F_oo
ool2o`0002Cooooo0_l00016ooooo`;o0000:?ooool001kooooo00?o0000ooooooooool02oooool3
o`0002cooooo0_l0000Cooooo`;o0000Q?ooool2o`0003;ooooo0_l0000looooo`007_ooool00ol0
003oooooooooo`0;ooooo`?o0000=Oooool2o`0002_ooooo0_l0002Gooooo`;o0000??ooool001ko
oooo00?o0000ooooooooool0@oooool2o`0002_ooooo0_l0000Gooooo`?o00004Oooool2o`0003So
oooo0_l0000`ooooo`;o0000??ooool001kooooo00?o0000ooooooooool02?ooool2o`0001;ooooo
0_l0001Qooooo`;o00002?ooool3o`00017ooooo0_l0000hooooo`;o0000>_ooool2o`0002_ooooo
0_l00005ooooo`007_ooool00ol0003oooooooooo`08ooooo`;o00004_ooool2o`00067ooooo0_l0
001Nooooo`;o0000<_ooool2o`0002_ooooo0_l00005ooooo`007_ooool00ol0003oooooooooo`0o
ooooo`;o0000HOooool2o`0003_ooooo0_l0000/ooooo`;o00005Oooool2o`00027ooooo0003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooo
oooo03oooooo0_l00002ooooo`;o0000GOooool2o`0001Kooooo0_l0001Aooooo`;o00005Oooool2
o`00027ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo04?ooooo0_l0001eooooo`;o0000Rooo
ool000?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0
002Kooooo`;o0000Soooool2o`0001Wooooo0003ooooo`05o`000?ooooooooooooooool000003Ooo
ool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo09_ooooo0_l0002?ooooo`;o00006Ooo
ool000?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o
0000ooooooooool0ooooooleooooo`;o00004Oooool000?ooooo00Go410@oooooooooooooooooa0@
400?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0I?ooool2o`000<kooooo0_l0
000Aooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RH
oa0@4006ooooo`03o`000?oooooooooo06Cooooo0_l00039ooooo`;o00005_ooool000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003o
ooooooooo`0?ooooo`;o00008Oooool2o`0007kooooo0_l0001kooooo`;o00005_ooool001kooooo
00?o0000ooooooooool03oooool5o`0001kooooo0_l0000Aooooo`;o0000=Oooool2o`0003Cooooo
0_l0001jooooo`;o00005oooool001kooooo00?o0000ooooooooool03?ooool2o`0000;ooooo1?l0
000aooooo`;o0000=Oooool2o`000;3ooooo0_l0000Gooooo`007_ooool00ol0003oooooooooo`0<
ooooo`;o0000<_ooool2o`000;Oooooo0_l0001<ooooo`007_ooool00ol0003oooooooooo`0boooo
o`;o00003?ooool2o`000;Oooooo0_l0000Fooooo`;o0000=?ooool001kooooo00?o0000oooooooo
ool0<_ooool2o`000:Oooooo0_l0000<ooooo`;o00009_ooool2o`0003Cooooo000Nooooo`03o`00
0?oooooooooo01gooooo0_l0001@ooooo`;o0000:?ooool2o`0000Sooooo0_l0000fooooo`;o0000
3?ooool2o`0005cooooo000Nooooo`03o`000?oooooooooo01gooooo0_l0000Jooooo`;o0000=?oo
ool2o`0002Sooooo0_l00008ooooo`;o0000Loooool2o`0001Gooooo0_l0000Fooooo`007_ooool0
0ol0003oooooooooo`0iooooo`;o0000gOooool2o`0001Gooooo0_l0000Fooooo`007_ooool00ol0
003oooooooooo`02o`0001[ooooo0_l0001=ooooo`;o00000oooool2o`000<Sooooo0_l0000;oooo
o`007_ooool00ol0003oooooooooo`02o`0001[ooooo1?l0001;ooooo`;o00000_ooool3o`00037o
oooo0_l0000cooooo`;o0000H?ooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo00gooooo
0_l0000?ooooo`;o00006?ooool2o`0003Gooooo0_l0000Zooooo`;o00001_ooool2o`0000Wooooo
0_l00004ooooo`;o00008_ooool2o`0006gooooo000Nooooo`;o00003_ooool2o`0000Sooooo0_l0
000Oooooo`;o00005Oooool2o`0001Wooooo0_l0000_ooooo`;o00004Oooool2o`0000Cooooo0_l0
002Aooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o00005?ooool2o`00023ooooo0_l0000I
ooooo`;o0000:?ooool2o`0001;ooooo0_l0000<ooooo`;o0000J_ooool2o`0001Oooooo0_l0000:
ooooo`007_ooool00ol0003oooooooooo`0]ooooo`;o0000Doooool4o`0000kooooo0_l0000Boooo
o`;o00003?ooool2o`0006[ooooo0_l0000Gooooo`;o00002_ooool001kooooo00?o0000oooooooo
ool0P_ooool4o`0000Cooooo0_l0001:ooooo`;o0000Koooool001kooooo00?o0000ooooooooool0
Coooool2o`0003Wooooo0_l0000Jooooo`;o0000;_ooool2o`0000Oooooo0_l0001=ooooo`;o0000
5oooool001kooooo00?o0000ooooooooool0Coooool2o`0005Gooooo0_l0000gooooo`;o0000BOoo
ool2o`0000;ooooo0_l0000Gooooo`007_ooool00ol0003oooooooooo`04ooooo`;o00007_ooool2
o`0003kooooo0_l0001`ooooo`;o0000D_ooool2o`0001_ooooo000Nooooo`03o`000?oooooooooo
00Cooooo0_l0000Nooooo`;o0000?_ooool2o`0004Sooooo0_l0000Vooooo`;o0000Koooool001ko
oooo00?o0000ooooooooool0D_ooool2o`0005[ooooo0_l00014ooooo`;o0000DOooool001kooooo
00?o0000ooooooooool03Oooool2o`0004?ooooo0_l0001?ooooo`;o0000Coooool2o`0003_ooooo
0_l0000Dooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o0000S_ooool2o`0000Cooooo0_l0
0003ooooo`;o0000<oooool2o`0005;ooooo0_l0000Dooooo`007_ooool00ol0003oooooooooo`0V
ooooo`;o0000K_ooool2o`0000Gooooo0_l00009ooooo`;o0000<oooool2o`0002Cooooo0_l00012
ooooo`007_ooool00ol0003oooooooooo`0Vooooo`;o00008oooool2o`0004Wooooo0_l0001[oooo
o`;o0000@_ooool001kooooo0ol0001;ooooo`;o00006Oooool2o`000=oooooo000Nooooo`?o0000
@_ooool2o`0002;ooooo0_l0000Gooooo`;o0000a_ooool001kooooo00?o0000ooooooooool0:Ooo
ool2o`0000Oooooo0_l0000>ooooo`;o00007Oooool2o`0001cooooo0_l0000`ooooo`;o00009Ooo
ool2o`0006gooooo000Nooooo`;o0000:_ooool2o`0000Cooooo0_l000000ooooooo0000o`00000:
ooooo`;o00008Oooool2o`0004kooooo0_l0000Uooooo`;o00006Oooool2o`0005;ooooo000Noooo
o`03o`000?oooooooooo00kooooo0_l000000ooooooo0000o`00000Looooo`;o00003Oooool2o`00
03kooooo0_l0000Pooooo`;o00003oooool2o`00043ooooo0_l00019ooooo`;o00001oooool001ko
oooo00?o0000ooooooooool03_ooool2o`000003ooooool0003o000000Gooooo0_l00007ooooo`;o
0000Foooool2o`00023ooooo0_l00013ooooo`;o0000A_ooool2o`0000oooooo0ol00006ooooo`00
7_ooool00ol0003oooooooooo`0Hooooo`;o00001oooool2o`0005[ooooo0_l0000Tooooo`;o0000
@?ooool2o`0002Kooooo0_l0000Nooooo`;o00004?ooool2o`0000Kooooo000Nooooo`03o`000?oo
oooooooo02Gooooo0_l0000Hooooo`;o0000??ooool2o`0002Cooooo0_l0000dooooo`;o0000<_oo
ool2o`0003Sooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0000Iooooo`;o00006?ooool2
o`00017ooooo0_l0000Looooo`;o0000Ioooool2o`0006cooooo000Nooooo`03o`000?oooooooooo
00[ooooo0_l0000Kooooo`;o0000:Oooool2o`0001cooooo0ol0003=ooooo`;o00001Oooool001ko
oooo00?o0000ooooooooool08oooool2o`0000;ooooo0_l00018ooooo`;o0000cOooool2o`0000Go
oooo000Nooooo`03o`000?oooooooooo02;ooooo0ol0001Hooooo`;o0000Boooool2o`0006oooooo
0_l0000:ooooo`007_ooool00ol0003oooooooooo`0Rooooo`;o000000?oooooo`000?l000002ooo
ool2o`0004Kooooo0_l000000ooooooo0000o`00001;ooooo`;o0000Koooool2o`0000[ooooo000N
ooooo`03o`000?oooooooooo02Gooooo0_l0000;ooooo`;o0000<_ooool2o`0001;ooooo0ol0002H
ooooo`;o0000<?ooool001kooooo00?o0000ooooooooool0I_ooool2o`0001?ooooo0_l0000Soooo
o`;o0000B?ooool2o`0002Wooooo0_l00005ooooo`;o0000:Oooool001kooooo00?o0000oooooooo
ool0X?ooool2o`0004Sooooo0_l0000`ooooo`;o00008?ooool2o`0000Oooooo000Nooooo`03o`00
0?oooooooooo02Cooooo0_l0001Nooooo`;o0000BOooool2o`0006gooooo0_l00007ooooo`007_oo
ool00ol0003oooooooooo`0Tooooo`;o00002oooool2o`0002gooooo0_l0000Rooooo`;o0000>Ooo
ool2o`0000kooooo0_l0000Hooooo`;o00006?ooool2o`0000[ooooo0_l0000Nooooo`;o00005_oo
ool001kooooo00?o0000ooooooooool0<Oooool2o`0001[ooooo0_l00005ooooo`;o00001_ooool2
o`0000;ooooo0_l0001Mooooo`;o00008oooool2o`0000?ooooo0_l00004ooooo`;o00004_ooool2
o`0000[ooooo0_l0000@ooooo`;o00002_ooool4o`0001Kooooo000Nooooo`;o00001_ooool2o`00
03cooooo0_l00005ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Kooooo0_l00026oooo
o`;o00002Oooool2o`0000[ooooo0_l0000Tooooo`;o00002_ooool2o`0001Sooooo000Nooooo`03
o`000?oooooooooo00Gooooo0_l0000jooooo`Ko00000oooool4o`000:Sooooo0_l00003ooooo`;o
0000B_ooool001kooooo00?o0000ooooooooool0@Oooool2o`0000;ooooo0_l00005ooooo`;o0000
H_ooool2o`0004Cooooo0_l0001?ooooo`007_ooool00ol0003oooooooooo`0Zooooo`;o00006?oo
ool2o`0002Wooooo0_l0000kooooo`;o00000_ooool2o`0003Sooooo0_l0001Kooooo`007_ooool0
0ol0003oooooooooo`0Gooooo`;o00003oooool6o`0001Kooooo0_l0000Yooooo`Co0000>Oooool2
o`0001[ooooo0_l0000Pooooo`;o0000Foooool001kooooo00?o0000ooooooooool05oooool2o`00
00oooooo0_l000001?oooooo0000o`000?l0000/ooooo`;o00001Oooool2o`0000kooooo0_l0001E
ooooo`;o00006?ooool2o`0006?ooooo000Nooooo`03o`000?oooooooooo013ooooo0_l0000Aoooo
o`;o00008?ooool2o`0001?ooooo0_l00005ooooo`;o00003oooool2o`0000Cooooo1?l0000aoooo
o`;o0000<oooool2o`00037ooooo0_l0000`ooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o
00004Oooool2o`00023ooooo0_l0000[ooooo`;o00001?ooool4o`00037ooooo0_l0001Vooooo`;o
00003_ooool2o`000003ooooool0003o000001gooooo000Nooooo`03o`000?oooooooooo067ooooo
0_l00002ooooo`;o00004oooool2o`0002Gooooo0_l00022ooooo`;o000000?oooooo`000?l00000
7Oooool001kooooo00?o0000ooooooooool05?ooool2o`00043ooooo0_l00009ooooo`;o00000_oo
ool4o`0000Oooooo0_l0000:ooooo`Co00008Oooool2o`0000Gooooo0_l00005ooooo`;o0000U_oo
ool001kooooo00?o0000ooooooooool05?ooool2o`0003Kooooo0_l00008ooooo`;o00000oooool2
o`0000[ooooo0_l00007ooooo`;o00002_ooool4o`0002Sooooo0_l00005ooooo`;o0000?oooool2
o`0005Gooooo000Nooooo`03o`000?oooooooooo04cooooo0_l0000=ooooo`;o0000Toooool2o`00
03Kooooo0_l0000Mooooo`007_ooool3o`000>_ooooo0_l0000]ooooo`;o00003?ooool2o`0001Oo
oooo0_l00004ooooo`007_ooool3o`000>_ooooo0_l0000Nooooo`;o00003Oooool2o`0001Wooooo
0_l0000:ooooo`;o00001?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0ooooool<ooooo`;o0000
1?ooool2o`0002;ooooo0_l0000@ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>oooool2o`000=Cooooo
0_l0000<ooooo`;o00009_ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000
1_ooool3o`0003_ooooo0_l0000Xooooo`;o00004oooool2o`0003Cooooo0_l0000Vooooo`;o0000
7?ooool2o`0002Oooooo0_l0000Vooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo
00CoA4A4omgMgOoooooo00001oooool00ol0003oooooooooo`1Uooooo`;o00004oooool2o`0000Co
oooo0_l0000Sooooo`;o00002Oooool2o`0002Kooooo0_l0000Looooo`;o00006_ooool2o`0003?o
oooo0003ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007oooo
o`03o`000?oooooooooo083ooooo0_l0000Sooooo`?o0000J_ooool2o`0003?ooooo0003ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo
04Oooooo0_l0001Mooooo`;o0000Woooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0Aoooool2o`0003;ooooo0_l00016oooo
o`;o0000EOooool2o`0000oooooo0_l0000Jooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00gooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`1Vooooo`;o00004oooool2o`00
04Kooooo0_l0001Cooooo`Co00003oooool2o`0001[ooooo000Nooooo`03o`000?oooooooooo06Ko
oooo0_l0000<ooooo`;o0000X_ooool2o`0002gooooo000Nooooo`03o`000?oooooooooo05[ooooo
0_l0000:ooooo`;o00003?ooool2o`0006Gooooo0_l0001Zooooo`007_ooool00ol0003ooooooooo
o`1Jooooo`;o0000F?ooool2o`0002?ooooo1?l00016ooooo`;o00008_ooool001kooooo00?o0000
ooooooooool0Noooool2o`0003Oooooo0_l0000Cooooo`;o00003_ooool2o`0004Sooooo0_l0000R
ooooo`007_ooool00ol0003oooooooooo`1Dooooo`;o00009Oooool2o`0004cooooo0_l0000Foooo
o`;o0000I?ooool001kooooo00?o0000ooooooooool0E?ooool2o`0008;ooooo0_l00007ooooo`;o
0000I?ooool001kooooo00?o0000ooooooooool01_ooool2o`0000Sooooo0_l0000Iooooo`;o0000
9?ooool2o`0000[ooooo0_l0001<ooooo`;o00004Oooool2o`0001Sooooo0_l0000_ooooo`;o0000
??ooool001kooooo0ol00006ooooo`;o00002?ooool2o`0001Wooooo0_l00009ooooo`;o00006Ooo
ool2o`0000[ooooo0_l0000Cooooo`;o00009?ooool2o`00017ooooo0_l0000Aooooo`;o0000BOoo
ool2o`0001Kooooo0_l00005ooooo`;o00007Oooool001kooooo0ol0000Eooooo`;o00007?ooool2
o`000003ooooool0003o000000?ooooo0_l0000eooooo`;o00006oooool2o`0000Oooooo0_l0001d
ooooo`;o00004Oooool2o`0000Gooooo0_l0000Mooooo`007_ooool00ol0003oooooooooo`0Eoooo
o`;o00007?ooool2o`0000Kooooo0_l00009ooooo`;o0000Aoooool2o`0007gooooo0_l0000goooo
o`007_ooool00ol0003oooooooooo`16ooooo`;o0000kOooool2o`0000?ooooo0_l0000;ooooo`00
7_ooool2o`000?oooooo=oooool2o`0000?ooooo0_l0000;ooooo`007_ooool00ol0003ooooooooo
o`0<ooooo`;o00005oooool2o`0000Sooooo0_l0001:ooooo`;o0000=?ooool2o`0005;ooooo0_l0
0010ooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o00005oooool2o`0000Sooooo0_l0000n
ooooo`;o00002_ooool2o`0003Cooooo0_l0000Booooo`;o00009Oooool2o`0001Oooooo0_l00010
ooooo`007_ooool2o`0003cooooo0_l0000/ooooo`;o00001?ooool2o`0000_ooooo0_l00017oooo
o`Co00004?ooool2o`00017ooooo0_l00016ooooo`;o00004Oooool001kooooo0_l0000looooo`;o
0000;?ooool2o`00017ooooo0_l0000Vooooo`?o00008?ooool2o`00013ooooo0_l0000nooooo`;o
00006Oooool2o`00017ooooo000Nooooo`04o`000?ooooooooooooooo`;o00002_ooool2o`000003
ooooool0003o000001oooooo0_l0000jooooo`;o00004oooool2o`00023ooooo0ol0001booooo`Co
0000:_ooool001kooooo00?o0000ooooool000000ol0000:ooooo`;o000000?oooooo`000?l00000
4Oooool2o`0000cooooo0_l0000jooooo`;o00004oooool2o`0009Oooooo0_l0000Zooooo`007_oo
ool01?l0003oooooo`000?l0000Kooooo`;o00001Oooool2o`0004cooooo0_l0000Pooooo`;o0000
O_ooool2o`0002_ooooo0_l00005ooooo`007_ooool00ol0003oooooooooo`0Looooo`;o00005?oo
ool2o`0003gooooo0_l00009ooooo`;o00005Oooool2o`0002;ooooo0_l0001Jooooo`?o0000:_oo
ool2o`0000Gooooo000Nooooo`03o`000?oooooooooo02cooooo0_l00004ooooo`;o00001_ooool2
o`0002[ooooo0_l0000Dooooo`;o0000>Oooool2o`0005_ooooo0_l00004ooooo`;o0000:oooool0
01kooooo00?o0000ooooooooool0;?ooool2o`0000cooooo0_l0000Zooooo`;o0000Q_ooool2o`00
02[ooooo0_l0000[ooooo`007_ooool00ol0003oooooooooo`04ooooo`;o0000POooool2o`0006Go
oooo0_l0000aooooo`;o00009?ooool001kooooo00?o0000ooooooooool01?ooool2o`0003Cooooo
0_l0001;ooooo`;o0000B?ooool2o`0001oooooo0_l0000]ooooo`;o00005?ooool2o`0000kooooo
000Nooooo`03o`000?oooooooooo03;ooooo0_l00006ooooo`;o00001Oooool2o`0008kooooo0_l0
000Oooooo`;o0000@oooool2o`0000kooooo000Nooooo`03o`000?oooooooooo00gooooo0_l0000B
ooooo`;o00003oooool2o`0000gooooo0_l0002booooo`;o0000D?ooool001kooooo00?o0000oooo
ooooool03Oooool2o`0001;ooooo0_l0003Booooo`;o0000D?ooool001kooooo0_l00021ooooo`;o
000000?oooooo`000?l000002?ooool2o`0001?ooooo0_l0002Sooooo`007_ooool00ol0003ooooo
ooooo`0Wooooo`;o0000=Oooool2o`0000kooooo0_l0000>ooooo`Co000000?oooooo`000?l00000
2?ooool2o`0000Wooooo0_l00008ooooo`;o0000Xoooool001kooooo00?o0000ooooooooool09ooo
ool2o`0003Gooooo0_l0000>ooooo`;o00003_ooool2o`00013ooooo1?l00004ooooo`;o00009ooo
ool2o`0002cooooo0_l00008ooooo`;o0000C?ooool001kooooo00?o0000ooooooooool0;?ooool2
o`0006;ooooo1?l00006ooooo`;o00009Oooool2o`0002cooooo0_l00008ooooo`;o0000C?ooool0
01kooooo00?o0000ooooooooool0;?ooool2o`0006cooooo0_l0000Yooooo`;o0000K?ooool2o`00
01;ooooo000Nooooo`03o`000?oooooooooo06cooooo0_l0000Aooooo`;o0000A?ooool2o`0006co
oooo0_l0000Booooo`007_ooool00ol0003oooooooooo`1/ooooo`;o00004Oooool2o`0006Gooooo
0_l0001>ooooo`;o00003oooool001kooooo00?o0000ooooooooool0AOooool2o`0009oooooo0_l0
001>ooooo`;o00003oooool001kooooo00?o0000ooooooooool00oooool2o`00043ooooo0_l0001<
ooooo`;o0000/_ooool001kooooo00?o0000ooooooooool00oooool2o`00047ooooo0_l0000Hoooo
o`;o00004Oooool2o`0001kooooo0_l0001kooooo`;o00003oooool2o`0000cooooo0_l0000Foooo
o`007_ooool00ol0003oooooooooo`0Nooooo`;o00007_ooool2o`0000Kooooo0_l0000Hooooo`;o
00004Oooool2o`0009_ooooo0_l0000?ooooo`;o00003?ooool2o`0001Kooooo000Nooooo`03o`00
0?oooooooooo01kooooo0_l0000Nooooo`;o00003Oooool2o`0005?ooooo0_l0000_ooooo`;o0000
L_ooool001kooooo00?o0000ooooooooool04oooool2o`0002Cooooo0_l0000Booooo`;o0000?Ooo
ool2o`0001Cooooo0_l0000_ooooo`;o00005_ooool2o`0003Cooooo0_l0000Tooooo`007_ooool0
0ol0003oooooooooo`0Cooooo`;o00009?ooool2o`0000Gooooo0_l00017ooooo`;o000000?ooooo
o`000?l00000>?ooool2o`0002?ooooo0_l0000dooooo`Go00008Oooool001kooooo00?o0000oooo
ooooool0@?ooool2o`0001cooooo0_l0000Tooooo`;o00000oooool2o`0003_ooooo0_l00015oooo
o`;o00004oooool4o`00027ooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l0000Jooooo`;o
00007?ooool2o`0002Cooooo0_l0000Dooooo`;o0000LOooool2o`0002Sooooo0_l0000>ooooo`00
7_ooool2o`0002Gooooo0_l00009ooooo`;o00003oooool2o`0005Sooooo0_l0000Vooooo`;o0000
:Oooool2o`00013ooooo0_l0000fooooo`;o00003_ooool001kooooo00?o0000ooooooooool0;ooo
ool2o`0000Oooooo0_l0000Booooo`;o00008Oooool2o`0001gooooo0_l0000booooo`;o00003Ooo
ool2o`0001[ooooo0_l0000@ooooo`;o0000:oooool2o`0000Sooooo0ol0000>ooooo`007_ooool0
0ol0003oooooooooo`0@ooooo`;o00009_ooool2o`0001;ooooo1?l0000Oooooo`;o00007Oooool2
o`0002;ooooo0_l0000Booooo`;o00002Oooool2o`0003[ooooo0_l0000Mooooo`;o00002?ooool2
o`0000oooooo000Nooooo`03o`000?oooooooooo013ooooo0_l0000Wooooo`;o00004oooool2o`00
01oooooo0_l00011ooooo`;o00000oooool2o`0000gooooo0_l0000:ooooo`;o0000>Oooool2o`00
00cooooo0_l0000Zooooo`007_ooool3o`0001oooooo0_l0000Hooooo`;o00007Oooool2o`0000oo
oooo0_l00004ooooo`;o0000A_ooool2o`0001Wooooo0_l0000Oooooo`;o00009_ooool2o`0002[o
oooo000Nooooo`?o00007oooool2o`0003Oooooo0_l0000?ooooo`;o0000>Oooool2o`0002Sooooo
0_l0000Sooooo`;o0000D_ooool001kooooo00?o0000ooooooooool0A_ooool2o`0000Oooooo0_l0
001Cooooo`;o00005?ooool2o`0001;ooooo0_l0000Sooooo`;o0000D_ooool001kooooo00?o0000
ooooooooool0A_ooool2o`0000Oooooo0_l0000mooooo`;o00003oooool2o`0001Wooooo0_l0000X
ooooo`;o00001?ooool2o`0003Kooooo0_l0000Sooooo`007_ooool00ol0003oooooooooo`0moooo
o`;o0000Coooool2o`0000oooooo0ol00012ooooo`;o00001?ooool2o`0003Kooooo0_l0000Soooo
o`007_ooool2o`0003kooooo0_l0000;ooooo`;o0000E?ooool2o`0006_ooooo0_l0000hooooo`00
7_ooool2o`0001[ooooo0_l0000_ooooo`;o0000O_ooool2o`0000Cooooo0_l0000kooooo`;o0000
>?ooool001kooooo00?o0000ooooooooool06Oooool2o`0000Wooooo0_l0000Hooooo`;o0000R_oo
ool2o`0000Cooooo0_l0001eooooo`007_ooool00ol0003oooooooooo`0Tooooo`;o00006?ooool2
o`0002Gooooo0_l0001@ooooo`;o00002Oooool2o`0002?ooooo0_l0001Nooooo`007_ooool00ol0
003oooooooooo`0Eooooo`;o0000C_ooool2o`00053ooooo0_l00009ooooo`;o00004?ooool2o`00
017ooooo0_l0001Nooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0;ooooo`;o00002?ooool2
o`0000Cooooo0_l0000Jooooo`;o00002oooool2o`0000kooooo0_l0001nooooo`;o0000LOooool0
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonH
V9So8B4Q00Kooooo00?o0000ooooooooool02oooool2o`0000kooooo0_l0000Jooooo`;o00002ooo
ool2o`0000kooooo0_l0000Mooooo`;o0000d_ooool000?ooooo00Go410@oooooooooooooooooa0@
400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`00037ooooo0_l0000_ooooo`;o0000
3oooool2o`0004?ooooo0_l0000cooooo`;o00003Oooool2o`0004Wooooo0003ooooo`05o`000?oo
ooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o0000oooooooo
ool07?ooool2o`0000[ooooo0_l00007ooooo`;o00001Oooool2o`0002Sooooo0_l0000cooooo`;o
00007oooool2o`0000Kooooo0_l0000Tooooo`;o00001Oooool2o`0000gooooo0_l00019ooooo`00
0oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c006oooo
o`03o`000?oooooooooo01cooooo0_l0000:ooooo`;o00003_ooool2o`0001Wooooo0_l00012oooo
o`;o00001Oooool2o`00023ooooo0_l0000Eooooo`;o00003Oooool2o`0005oooooo0003ooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo
05?ooooo0_l00019ooooo`;o0000=oooool2o`0005[ooooo0_l0000Booooo`000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0/oooo
o`;o00001_ooool2o`0002Wooooo0_l0003Booooo`;o00004_ooool000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0;?ooool2
o`0000Kooooo0_l0000Yooooo`;o0000FOooool2o`0005[ooooo0_l0000_ooooo`007_ooool00ol0
003oooooooooo`2jooooo`;o0000F_ooool2o`0002oooooo000Nooooo`03o`000?oooooooooo01So
oooo0_l0002<ooooo`;o00007oooool2o`0001?ooooo0_l0001Yooooo`007_ooool00ol0003ooooo
ooooo`0Hooooo`;o0000IOooool2o`0002Gooooo0_l0000Fooooo`;o00001oooool2o`0001?ooooo
0_l0000Pooooo`;o00000_ooool2o`0004?ooooo000Nooooo`03o`000?oooooooooo02Wooooo0_l0
000Eooooo`;o0000?Oooool2o`0003gooooo1?l0000Nooooo`;o00007?ooool2o`0000;ooooo0_l0
0013ooooo`007_ooool00ol0003oooooooooo`0Yooooo`;o00005Oooool2o`0007kooooo0_l0000N
ooooo`;o0000IOooool001kooooo00?o0000ooooooooool0h_ooool2o`0004_ooooo0_l0000Foooo
o`007_ooool00ol0003oooooooooo`3Rooooo`;o0000Boooool2o`0001Kooooo000Nooooo`03o`00
0?oooooooooo00kooooo0_l0001Fooooo`;o00004?ooool2o`0002Wooooo0_l00018ooooo`;o0000
F?ooool001kooooo00?o0000ooooooooool03_ooool2o`0005Kooooo0_l0000@ooooo`;o0000:Ooo
ool2o`0003Kooooo0_l000000ooooooo0000o`00000=ooooo`;o0000F?ooool001kooooo00?o0000
ooooooooool0Toooool2o`0001;ooooo0_l0000]ooooo`;o00000oooool2o`000003ooooool0003o
000006Oooooo000Nooooo`03o`000?oooooooooo08Oooooo0_l0000:ooooo`;o00004_ooool2o`00
02gooooo0_l0000Aooooo`;o0000G?ooool001kooooo0_l0000Vooooo`;o0000H?ooool2o`00063o
oooo0_l0000Cooooo`;o0000@?ooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo02Gooooo
0_l0000>ooooo`;o0000YOooool2o`00023ooooo0_l0000nooooo`Co00001Oooool001kooooo00?o
0000ooooooooool0=Oooool2o`0000Kooooo0_l0002Mooooo`;o0000H?ooool2o`0000Oooooo000N
ooooo`03o`000?oooooooooo03_ooooo1?l00029ooooo`;o0000OOooool001kooooo00?o0000oooo
ooooool0>oooool2o`00017ooooo0_l0000Aooooo`;o00001?ooool2o`0005oooooo0_l0001moooo
o`007_ooool00ol0003oooooooooo`1>ooooo`;o00004Oooool2o`0000Cooooo0_l0000hooooo`;o
00001Oooool2o`0000Wooooo0_l0002Booooo`007_ooool00ol0003oooooooooo`0Gooooo`;o0000
R?ooool2o`0000Gooooo0_l00009ooooo`;o00001oooool2o`0008Wooooo000Nooooo`03o`000?oo
oooooooo01?ooooo0_l00002ooooo`;o0000@_ooool2o`0005oooooo0_l00012ooooo`;o00000_oo
ool2o`00047ooooo000Nooooo`03o`000?oooooooooo01?ooooo0_l00016ooooo`;o0000Xoooool2
o`0000;ooooo0_l0000]ooooo`;o00004_ooool001kooooo00?o0000ooooooooool0MOooool2o`00
08;ooooo0_l0000Looooo`;o00006_ooool2o`0001;ooooo000Nooooo`03o`000?oooooooooo06ko
oooo0_l00005ooooo`;o00002Oooool2o`0006Gooooo0_l0000@ooooo`;o00007?ooool2o`0002ko
oooo000Nooooo`03o`000?oooooooooo06kooooo0_l0000@ooooo`;o0000IOooool2o`0001gooooo
0_l0000Uooooo`;o00006?ooool001kooooo00?o0000ooooooooool0aOooool2o`0003oooooo0_l0
000Tooooo`?o00006?ooool001kooooo00?o0000ooooooooool0H?ooool2o`0006?ooooo0_l0001E
ooooo`;o00003_ooool2o`0001Wooooo000Nooooo`03o`000?oooooooooo063ooooo0_l0000Aoooo
o`;o0000?oooool2o`0006Kooooo0_l0000Yooooo`007_ooool00ol0003oooooooooo`1cooooo`;o
0000>_ooool2o`0000?ooooo0_l00013ooooo`;o0000C?ooool001kooooo0_l0000Zooooo`;o0000
5oooool2o`0003?ooooo0_l0000Xooooo`;o00003?ooool2o`0004Sooooo0_l0001<ooooo`007_oo
ool00ol0003oooooooooo`0Yooooo`?o00002oooool2o`0000Wooooo0_l00005ooooo`;o0000;?oo
ool2o`0001;ooooo0_l0000Dooooo`;o0000Y?ooool001kooooo00?o0000ooooooooool0:_ooool2
o`0000_ooooo0_l00002ooooo`;o00003?ooool2o`0003Wooooo0_l00005ooooo`;o0000HOooool2
o`0005Oooooo000Nooooo`03o`000?oooooooooo03_ooooo0_l00017ooooo`;o0000<?ooool2o`00
00Kooooo0_l00003ooooo`;o0000:Oooool2o`0005Oooooo000Nooooo`03o`000?oooooooooo03_o
oooo0_l0001Looooo`;o000000?oooooo`000?l000006?ooool2o`0000Kooooo0_l00003ooooo`;o
0000P_ooool001kooooo00?o0000ooooooooool0=?ooool2o`0002[ooooo0_l0000gooooo`;o0000
00?oooooo`000?l00000ZOooool001kooooo00?o0000ooooooooool06oooool2o`0001Oooooo0_l0
000Zooooo`;o0000K?ooool2o`0004;ooooo0_l0000cooooo`007_ooool00ol0003oooooooooo`0K
ooooo`;o0000/Oooool2o`0001cooooo0_l0000Tooooo`;o0000<oooool001kooooo00?o0000oooo
ooooool09Oooool2o`0003Sooooo0_l0001Hooooo`;o0000<Oooool2o`0004Kooooo0_l0000Aoooo
o`007_ooool00ol0003oooooooooo`0Uooooo`;o0000;Oooool2o`0000Wooooo0_l0001Hooooo`Co
0000>?ooool2o`0003gooooo0_l0000Aooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o0000
8_ooool2o`0000Oooooo0_l00002ooooo`;o00002Oooool2o`0000Oooooo0_l0001Uooooo`;o0000
>?ooool2o`00053ooooo000Nooooo`04o`000?ooooooooooooooo`;o00003?ooool2o`0002;ooooo
0_l00007ooooo`;o00000_ooool2o`0000Wooooo0_l0000Sooooo`;o0000M?ooool2o`0005oooooo
000Nooooo`04o`000?ooooooooooooooo`;o0000<oooool2o`0001[ooooo0_l0000Looooo`;o0000
M?ooool2o`0004kooooo0_l0000?ooooo`007_ooool00ol0003oooooooooo`0fooooo`;o00006_oo
ool2o`0009_ooooo0_l00015ooooo`;o00003oooool001kooooo00?o0000ooooooooool0:_ooool2
o`000:Kooooo0_l0000Kooooo`;o00006?ooool2o`0003cooooo000Nooooo`03o`000?oooooooooo
02Kooooo0_l00002ooooo`;o0000Y_ooool2o`0003Gooooo0_l0000looooo`007_ooool2o`0002Oo
oooo0_l0000gooooo`;o00004oooool2o`0004Wooooo0_l00026ooooo`007_ooool00ol0003ooooo
ooooo`1@ooooo`;o00001?ooool2o`0000Oooooo0_l0000Cooooo`;o0000:oooool2o`0001cooooo
0_l0000Iooooo`;o0000Joooool001kooooo00?o0000ooooooooool0A?ooool2o`0000[ooooo0_l0
0004ooooo`;o0000BOooool2o`0003Oooooo0ol0001Zooooo`007_ooool00ol0003oooooooooo`14
ooooo`;o0000:Oooool2o`0006[ooooo0_l0000jooooo`;o0000;_ooool001kooooo00?o0000oooo
ooooool0Koooool2o`0000Kooooo0_l0000jooooo`;o00002?ooool2o`0005Sooooo0_l0000Loooo
o`;o00004?ooool001kooooo00?o0000ooooooooool07?ooool2o`0004Sooooo0_l0000?ooooo`;o
0000>_ooool2o`0000Sooooo0_l0001fooooo`;o00004?ooool001kooooo00?o0000ooooooooool0
7?ooool2o`0004Sooooo0_l0001Looooo`;o0000POooool001kooooo00?o0000ooooooooool07_oo
ool2o`0008gooooo0_l0000Eooooo`Co0000;?ooool2o`00057ooooo000Nooooo`03o`000?oooooo
oooo01kooooo0_l0000Kooooo`;o0000L?ooool2o`0001Oooooo0_l0000/ooooo`;o00008_ooool2
o`0002gooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0000gooooo`;o0000:oooool2o`00
01Kooooo0_l0000eooooo`;o0000Goooool2o`0000Gooooo0_l0000Vooooo`007_ooool00ol0003o
ooooooooo`02ooooo`;o0000G_ooool2o`0000Cooooo0_l0000Booooo`;o00000_ooool2o`0003Go
oooo0_l0000;ooooo`;o0000<Oooool2o`0002Kooooo0_l0000Vooooo`007_ooool00ol0003ooooo
ooooo`1Rooooo`;o00006?ooool2o`00033ooooo0_l0000Cooooo`?o00001oooool2o`0002Sooooo
0_l0000=ooooo`;o0000?oooool001kooooo00?o0000ooooooooool06oooool2o`00017ooooo0_l0
000@ooooo`;o0000>oooool2o`0001cooooo0_l0000Aooooo`;o00004oooool2o`0000Sooooo0_l0
0006ooooo`;o0000;oooool2o`0002cooooo0_l0000Aooooo`007_ooool00ol0003oooooooooo`0K
ooooo`;o00003_ooool2o`000003ooooool0003o000000Cooooo0_l0000:ooooo`;o0000>oooool2
o`0001cooooo0_l0000Cooooo`;o00008oooool2o`0003oooooo0_l0000Looooo`;o00004Oooool0
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<00Kooooo0_l00008ooooo`;o00008_ooool2o`0000Oooooo0_l0001:ooooo`;o0000;_oo
ool2o`0003;ooooo0_l0000Gooooo`;o00005oooool2o`0000oooooo0_l0000Nooooo`000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40
1_ooool2o`0000Sooooo0_l0001gooooo`;o00008oooool2o`0003gooooo0_l0000Gooooo`;o0000
4?ooool2o`0001Cooooo1?l0000Nooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo
00Go0000ooooooooooooooooo`000006ooooo`?o0000YOooool2o`0006Sooooo0_l0000Dooooo`;o
00008?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRH
V?lb<S801_ooool00ol0003oooooooooo`16ooooo`;o0000>?ooool2o`0002kooooo0_l00015oooo
o`;o0000C_ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`01_ooool00ol0003oooooooooo`16ooooo`;o0000>?ooool2o`0002kooooo0_l00015
ooooo`;o0000A_ooool2o`0000Kooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool0
1Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0M?ooool2o`0000Cooooo0_l0
0033ooooo`;o00001_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj
^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`1dooooo`;o00001?ooool2o`0003oooooo
0_l0001Mooooo`;o0000:oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`2Oooooo`;o00006_ooool2o`0005go
oooo0_l0000[ooooo`007_ooool00ol0003oooooooooo`2@ooooo`Co00002oooool2o`0001Kooooo
0_l0000`ooooo`;o00007_ooool2o`0002?ooooo0_l0000Gooooo`007_ooool00ol0003ooooooooo
o`0aooooo`;o00006oooool2o`0000gooooo0_l0000aooooo`Co00008oooool2o`0002Oooooo0_l0
0007ooooo`;o00007_ooool2o`0001cooooo0_l00005ooooo`;o00005oooool001kooooo00?o0000
ooooooooool0<Oooool2o`0001_ooooo0_l0000=ooooo`;o0000:?ooool2o`0005Oooooo0_l0000U
ooooo`;o00007_ooool2o`0001kooooo000Nooooo`03o`000?oooooooooo08Oooooo0_l0001noooo
o`;o0000?_ooool001kooooo00?o0000ooooooooool03Oooool2o`000?oooooo1_ooool2o`00037o
oooo000Nooooo`03o`000?oooooooooo00gooooo0_l00008ooooo`;o00008oooool2o`0002?ooooo
0_l00011ooooo`;o0000I_ooool2o`0000Kooooo0_l0000aooooo`007_ooool00ol0003ooooooooo
o`0Gooooo`;o00008oooool2o`0002?ooooo0_l0000Booooo`;o0000;Oooool2o`0004cooooo0_l0
000Hooooo`;o0000>Oooool001kooooo00?o0000ooooooooool0:oooool2o`0001Cooooo0_l0000b
ooooo`;o0000Noooool2o`0004[ooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`0[oooo
o`;o00001?ooool2o`0000kooooo0_l0001Fooooo`;o0000K?ooool2o`0003Gooooo0_l00007oooo
o`007_ooool00ol0003oooooooooo`0aooooo`;o0000GOooool2o`0000Oooooo0_l0001/ooooo`;o
0000?_ooool001kooooo00?o0000ooooooooool0S_ooool4o`00033ooooo0_l00003ooooo`;o0000
O_ooool001kooooo0_l0001booooo`;o00006oooool2o`0000Kooooo0_l00007ooooo`;o00008Ooo
ool2o`0000?ooooo0_l000000ooooooo0000o`00001kooooo`007_ooool00ol0003oooooooooo`1S
ooooo`;o00003?ooool2o`0000oooooo0_l0000Booooo`;o00001oooool2o`0002Wooooo0_l0000U
ooooo`;o0000E?ooool001kooooo00?o0000ooooooooool07Oooool2o`0004Cooooo0_l0000Moooo
o`;o0000=Oooool2o`0000?ooooo0_l0000>ooooo`;o00008Oooool2o`0000_ooooo0_l0000/oooo
o`;o00006Oooool001kooooo00?o0000ooooooooool07Oooool2o`0009[ooooo0_l00003ooooo`;o
00003_ooool2o`0002kooooo0_l0000/ooooo`;o00006Oooool001kooooo00?o0000ooooooooool0
Toooool2o`000;;ooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0000Aooooo`;o00003?oo
ool2o`0000_ooooo0_l0000looooo`;o00004oooool2o`0002[ooooo0_l00026ooooo`007_ooool0
0ol0003oooooooooo`0Booooo`;o00000_ooool2o`0000gooooo0_l0000<ooooo`;o00002oooool2
o`0000;ooooo0_l0000hooooo`;o00001Oooool2o`0003Sooooo0_l00026ooooo`007_ooool00ol0
003oooooooooo`0Fooooo`;o00003?ooool2o`00013ooooo0_l0000<ooooo`;o0000?oooool2o`00
02gooooo0_l00004ooooo`;o0000Roooool001kooooo00?o0000ooooooooool04Oooool2o`00017o
oooo0_l0000@ooooo`;o0000NOooool2o`000003ooooool0003o000000Cooooo0_l0001nooooo`;o
00002oooool001kooooo00?o0000ooooooooool04Oooool3o`00033ooooo0_l0001[ooooo`;o0000
7?ooool2o`0006Wooooo0_l0000;ooooo`007Oooool2o`0001Cooooo0_l0000`ooooo`;o0000EOoo
ool2o`0000kooooo0_l0000Rooooo`;o00001oooool2o`0001Kooooo0_l0001Eooooo`007Oooool2
o`0002cooooo0_l0001_ooooo`;o00003_ooool2o`0002_ooooo0_l0000Fooooo`;o0000BOooool2
o`0000[ooooo000Nooooo`03o`000?oooooooooo02[ooooo0_l0000Cooooo`;o0000Xoooool2o`00
05Gooooo0_l00002ooooo`;o00001_ooool001kooooo00?o0000ooooooooool0?oooool2o`0000Co
oooo0_l0002Mooooo`;o0000FOooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo04Gooooo
0_l0003oooooo`7ooooo000Nooooo`03o`000?oooooooooo04cooooo0_l00029ooooo`;o0000Dooo
ool2o`0001Wooooo000Nooooo`;o00005Oooool2o`0003Kooooo0_l00029ooooo`;o0000Doooool2
o`0001Wooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0001<ooooo`;o0000D_ooool2o`00
08oooooo000Nooooo`03o`000?oooooooooo06;ooooo0_l0001Booooo`;o0000R?ooool2o`0000Go
oooo000Nooooo`03o`000?oooooooooo06Sooooo0_l0001Looooo`;o0000Goooool2o`0001Oooooo
0_l00005ooooo`007_ooool00ol0003oooooooooo`1Oooooo`;o00001oooool2o`0005;ooooo0_l0
00000ooooooo0000o`000005ooooo`;o0000:oooool2o`0003;ooooo0_l0000=ooooo`;o00003ooo
ool001kooooo00?o0000ooooooooool01?ooool2o`0003cooooo0_l0000Kooooo`;o0000C?ooool2
o`0000gooooo0_l000000ooooooo0000o`00000Mooooo`;o00004oooool2o`00047ooooo0_l0000?
ooooo`007_ooool00ol0003oooooooooo`04ooooo`;o0000??ooool2o`0006Wooooo0_l0000@oooo
o`;o00007Oooool2o`0002Gooooo0_l00010ooooo`007_ooool00ol0003oooooooooo`1`ooooo`;o
0000C?ooool2o`0004Gooooo0_l0000@ooooo`;o0000;_ooool001kooooo00?o0000ooooooooool0
L?ooool2o`0000Wooooo0_l0000Rooooo`;o00007Oooool2o`0005Oooooo0_l0000Vooooo`;o0000
1_ooool001kooooo00?o0000ooooooooool02?ooool2o`0002Sooooo0_l00017ooooo`;o00003?oo
ool2o`0001Cooooo0_l0000gooooo`;o0000IOooool2o`0000Kooooo000Nooooo`03o`000?oooooo
oooo00Sooooo0_l0000Iooooo`;o00002oooool4o`000003ooooool0003o000004cooooo0_l00004
ooooo`;o0000<_ooool2o`0001Wooooo0_l0001]ooooo`007_ooool00ol0003oooooooooo`0Soooo
o`;o00002oooool2o`0000?ooooo0_l0000@ooooo`;o0000>_ooool2o`0003Sooooo0_l0000/oooo
o`;o0000F_ooool001kooooo00?o0000ooooooooool0Aoooool4o`0005oooooo0_l000000ooooooo
0000o`00000looooo`;o0000F_ooool001kooooo00?o0000ooooooooool0<Oooool2o`0001?ooooo
0_l000000ooooooo0000o`00000Xooooo`;o0000=Oooool2o`000003ooooool0003o000000Cooooo
0_l0000<ooooo`;o00001Oooool2o`0007gooooo000Nooooo`03o`000?oooooooooo037ooooo0_l0
000Cooooo`;o0000:oooool2o`0003kooooo0_l0000<ooooo`;o00001Oooool2o`00037ooooo0_l0
001:ooooo`007_ooool00ol0003oooooooooo`28ooooo`;o00009?ooool2o`00033ooooo0_l0000I
ooooo`;o0000B_ooool001kooooo0_l0001;ooooo`;o00002Oooool2o`00037ooooo0_l0000Ioooo
o`;o00002Oooool2o`00033ooooo0_l0000Eooooo`;o0000AOooool2o`0000Oooooo000Nooooo`04
o`000?ooooooooooooooo`;o00003?ooool2o`0000;ooooo0_l0000booooo`;o000000?oooooo`00
0?l000002Oooool2o`0000gooooo0_l0000Wooooo`;o00005?ooool2o`0005;ooooo0_l0000ioooo
o`;o00002_ooool2o`0000Oooooo000Nooooo`04o`000?ooooooooooooooo`;o00003?ooool2o`00
00;ooooo0_l0000booooo`;o00006Oooool4o`0002Oooooo0_l0002Sooooo`;o00004oooool001ko
oooo00?o0000ooooooooool0H_ooool2o`000<gooooo0_l0000Dooooo`007_ooool00ol0003ooooo
ooooo`2jooooo`;o00000oooool2o`0004Oooooo0_l0000Wooooo`;o00005?ooool001kooooo00?o
0000ooooooooool0V?ooool2o`00023ooooo0_l00003ooooo`;o00006?ooool2o`0002gooooo0_l0
000Wooooo`;o00001oooool2o`0000_ooooo000Nooooo`04o`000?ooooooooooooooo`;o0000>ooo
ool2o`0005Sooooo0_l0000Kooooo`;o00003_ooool2o`0001;ooooo0_l0001Oooooo`;o00002ooo
ool001kooooo00Co0000oooooooooooooooo0_l0000Aooooo`;o00004_ooool2o`0001Cooooo0_l0
000Qooooo`;o0000D_ooool2o`0000kooooo0_l00020ooooo`007_ooool00ol0003oooooooooo`0D
ooooo`;o00004_ooool2o`0003Oooooo0_l0000Rooooo`;o00006_ooool2o`000:Cooooo000Noooo
o`03o`000?oooooooooo05Gooooo0_l0000^ooooo`;o00006_ooool2o`0000oooooo0_l0002Coooo
o`007_ooool00ol0003oooooooooo`1Eooooo`;o0000Foooool2o`00063ooooo0_l0000:ooooo`;o
00000_ooool2o`00027ooooo000Nooooo`03o`000?oooooooooo0?Gooooo0_l0000Mooooo`Co0000
2?ooool2o`0000;ooooo0_l0000Qooooo`007_ooool00ol0003oooooooooo`0Yooooo`;o0000:ooo
ool2o`0009gooooo0_l0000Oooooo`;o0000;oooool001kooooo00?o0000ooooooooool0:Oooool2
o`0002_ooooo0_l0000:ooooo`;o0000Ioooool2o`0002gooooo0_l0001;ooooo`005?ooool4o`00
0003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0H_ooool2o`0000kooooo0_l0001Goooo
o`;o0000;Oooool2o`0004_ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool02Oooool2o`0004Kooooo0_l0000Oooooo`;o00005_ooool2o`0003[ooooo0_l0000eooooo`;o
00003Oooool2o`0003Wooooo000Fooooo`03o`000?oooooooooo00Gooooo0ol00009ooooo`;o0000
A_ooool2o`0003Oooooo0_l00009ooooo`;o00001Oooool2o`0002Sooooo0_l0000<ooooo`;o0000
9oooool2o`0000gooooo0_l0000iooooo`005_ooool00ol0003oooooooooo`2Mooooo`;o00001Ooo
ool2o`0003Kooooo0_l0001aooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Foooo
o`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`00
5?ooool00omEEEGoIVIVo`00003ooooooe;ooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.08566 .33894 Mdot
.18412 .86569 Mdot
.01818 .09489 Mdot
.39739 .79597 Mdot
.17874 .27366 Mdot
.96597 .28181 Mdot
.03933 .1137 Mdot
.13288 .56572 Mdot
.01998 .97599 Mdot
.29252 .01533 Mdot
.60048 .92906 Mdot
.1052 .68983 Mdot
.54968 .36062 Mdot
.46768 .32287 Mdot
.41276 .36941 Mdot
.41387 .5934 Mdot
.55421 .96094 Mdot
.25831 .3609 Mdot
.65625 .00726 Mdot
.93285 .76266 Mdot
.50284 .91176 Mdot
.348 .07952 Mdot
.99246 .15863 Mdot
.10484 .58433 Mdot
.80871 .41952 Mdot
.32836 .45743 Mdot
.82271 .77282 Mdot
.66643 .39882 Mdot
.41168 .7939 Mdot
.25149 .07464 Mdot
.74167 .02315 Mdot
.39835 .1979 Mdot
.56955 .16106 Mdot
.09922 .13082 Mdot
.79492 .24594 Mdot
.88704 .70364 Mdot
.34365 .04801 Mdot
.40065 .46369 Mdot
.14556 .2679 Mdot
.0586 .91338 Mdot
.96358 .23461 Mdot
.38311 .83612 Mdot
.34345 .26946 Mdot
.24375 .28738 Mdot
.8179 .2525 Mdot
.62448 .58736 Mdot
.82902 .08575 Mdot
.58441 .90156 Mdot
.12859 .22971 Mdot
.16918 .14509 Mdot
.91458 .00606 Mdot
.54631 .56307 Mdot
.07915 .84814 Mdot
.00399 .38612 Mdot
.94111 .49888 Mdot
.94292 .0533 Mdot
.64068 .99192 Mdot
.09046 .76356 Mdot
.25488 .38296 Mdot
.13097 .86398 Mdot
.13158 .32566 Mdot
.88519 .81402 Mdot
.23886 .95855 Mdot
.40066 .51681 Mdot
.94706 .43541 Mdot
.30688 .03778 Mdot
.24017 .86359 Mdot
.6093 .97971 Mdot
.11176 .16088 Mdot
.93595 .14754 Mdot
.86331 .79817 Mdot
.96535 .34867 Mdot
.10091 .61364 Mdot
.31771 .76435 Mdot
.37524 .29966 Mdot
.78402 .18507 Mdot
.00074 .76567 Mdot
.20981 .30727 Mdot
.76635 .72358 Mdot
.26529 .32014 Mdot
.50598 .77049 Mdot
.68526 .97023 Mdot
.20914 .89039 Mdot
.81786 .4463 Mdot
.6938 .54455 Mdot
.84042 .02889 Mdot
.44874 .14677 Mdot
.05378 .6404 Mdot
.54793 .93791 Mdot
.59498 .56871 Mdot
.08812 .87831 Mdot
.60213 .39357 Mdot
.17989 .62025 Mdot
.70249 .30277 Mdot
.1398 .48359 Mdot
.3334 .54751 Mdot
.24577 .13438 Mdot
.7406 .38058 Mdot
.59035 .18561 Mdot
.27575 .91968 Mdot
.53257 .38179 Mdot
.76343 .55122 Mdot
.87507 .90663 Mdot
.30863 .35872 Mdot
.61421 .62856 Mdot
.19139 .74144 Mdot
.50489 .99297 Mdot
.88786 .45326 Mdot
.17527 .90771 Mdot
.46522 .77377 Mdot
.37047 .36615 Mdot
.85184 .81857 Mdot
.85643 .43478 Mdot
.30691 .41787 Mdot
.1191 .56804 Mdot
.53382 .7612 Mdot
.34097 .66902 Mdot
.00568 .85088 Mdot
.6511 .57421 Mdot
.56402 .79263 Mdot
.73381 .37389 Mdot
.56386 .22382 Mdot
.09062 .62614 Mdot
.30837 .94139 Mdot
.46626 .483 Mdot
.0189 .4863 Mdot
.60138 .43357 Mdot
.63123 .78418 Mdot
.62353 .75155 Mdot
.72257 .9538 Mdot
.62344 .05105 Mdot
.07773 .62235 Mdot
.16103 .47774 Mdot
.54908 .69861 Mdot
.18177 .48226 Mdot
.22144 .34928 Mdot
.39494 .9363 Mdot
.05123 .29446 Mdot
.56293 .71788 Mdot
.41618 .12994 Mdot
.22291 .19305 Mdot
.99424 .21621 Mdot
.83512 .78735 Mdot
.01418 .33583 Mdot
.5859 .35882 Mdot
.35769 .7058 Mdot
.66242 .76814 Mdot
.97713 .25053 Mdot
.29015 .39026 Mdot
.04632 .219 Mdot
.21294 .74431 Mdot
.37488 .26183 Mdot
.87524 .2183 Mdot
.82441 .90523 Mdot
.12184 .3644 Mdot
.65241 .52537 Mdot
.27491 .52756 Mdot
.5499 .43617 Mdot
.59817 .74631 Mdot
.11204 .59197 Mdot
.55589 .40798 Mdot
.1137 .01679 Mdot
.98346 .13248 Mdot
.97013 .26118 Mdot
.86624 .6006 Mdot
.35137 .80361 Mdot
.91095 .69977 Mdot
.41979 .49417 Mdot
.48572 .53487 Mdot
.04273 .88391 Mdot
.94705 .41181 Mdot
.55287 .31112 Mdot
.39635 .12721 Mdot
.3052 .37931 Mdot
.64602 .4015 Mdot
.56153 .14397 Mdot
.35969 .62801 Mdot
.4891 .59194 Mdot
.32708 .30635 Mdot
.11913 .31013 Mdot
.02387 .37724 Mdot
.87455 .27442 Mdot
.90232 .73725 Mdot
.1635 .18213 Mdot
.74006 .37061 Mdot
.86863 .42807 Mdot
.33704 .24869 Mdot
.43128 .26554 Mdot
.52613 .48656 Mdot
.23855 .61759 Mdot
.35142 .16485 Mdot
.19361 .50773 Mdot
.66848 .6535 Mdot
.99398 .21154 Mdot
.23599 .0179 Mdot
.67178 .20814 Mdot
.5452 .41873 Mdot
.52105 .33495 Mdot
.3037 .2555 Mdot
.20041 .09629 Mdot
.14087 .70581 Mdot
.29144 .31581 Mdot
.88614 .4094 Mdot
.1308 .61809 Mdot
.9865 .58052 Mdot
.3423 .40261 Mdot
.17329 .38119 Mdot
.53421 .33903 Mdot
.52185 .21917 Mdot
.8644 .44707 Mdot
.42302 .15597 Mdot
.53232 .04795 Mdot
.80403 .97104 Mdot
.64385 .46213 Mdot
.45896 .52043 Mdot
.75373 .49574 Mdot
.0138 .97802 Mdot
.30742 .14554 Mdot
.24466 .46274 Mdot
.93718 .86984 Mdot
.85324 .55706 Mdot
.54166 .55092 Mdot
.50806 .81578 Mdot
.90509 .05722 Mdot
.47746 .61616 Mdot
.37388 .79568 Mdot
.93288 .31185 Mdot
.62205 .9117 Mdot
.60419 .7629 Mdot
.40564 .83119 Mdot
.52735 .09593 Mdot
.83459 .15141 Mdot
.21723 .54884 Mdot
.82199 .66734 Mdot
.9835 .58332 Mdot
.75424 .67801 Mdot
.53356 .82503 Mdot
.54885 .90965 Mdot
.56709 .86923 Mdot
.96808 .88149 Mdot
.08103 .87049 Mdot
.92267 .30228 Mdot
.86628 .52017 Mdot
.73781 .23821 Mdot
.35901 .8341 Mdot
.82938 .07551 Mdot
.49039 .02365 Mdot
.88309 .56044 Mdot
.8787 .1648 Mdot
.19929 .65403 Mdot
.97917 .27759 Mdot
.70884 .84785 Mdot
.34086 .54011 Mdot
.71059 .41067 Mdot
.40002 .82441 Mdot
.9276 .40472 Mdot
.83783 .09607 Mdot
.02781 .11307 Mdot
.20461 .15765 Mdot
.11551 .76372 Mdot
.40083 .49681 Mdot
.13957 .46097 Mdot
.39734 .50537 Mdot
.61251 .66007 Mdot
.17657 .6394 Mdot
.78875 .48107 Mdot
.50117 .77124 Mdot
.37053 .75636 Mdot
.5733 .84599 Mdot
.71823 .2049 Mdot
.66257 .74631 Mdot
.97611 .49091 Mdot
.67826 .16219 Mdot
.22722 .05355 Mdot
.29129 .38382 Mdot
.98527 .58548 Mdot
.28149 .45486 Mdot
.96503 .23994 Mdot
.48161 .69 Mdot
.64371 .13337 Mdot
.24714 .02727 Mdot
.87038 .53711 Mdot
.12601 .90699 Mdot
.87147 .08968 Mdot
.8308 .44646 Mdot
.43094 .82217 Mdot
.68064 .58185 Mdot
.75654 .4889 Mdot
.77196 .73821 Mdot
.94961 .77707 Mdot
.44847 .07221 Mdot
.29386 .15874 Mdot
.42284 .11568 Mdot
.15127 .7279 Mdot
.70361 .7992 Mdot
.42468 .35792 Mdot
.04633 .00341 Mdot
.00427 .44838 Mdot
.86996 .39359 Mdot
.31174 .25103 Mdot
.1656 .58348 Mdot
.83372 .15796 Mdot
.02769 .57283 Mdot
.56316 .68161 Mdot
.58513 .00806 Mdot
.1793 .30479 Mdot
.22925 .73533 Mdot
.53594 .23292 Mdot
.08755 .19596 Mdot
.1723 .52522 Mdot
.45804 .5124 Mdot
.88864 .54696 Mdot
.59928 .44514 Mdot
.35813 .74915 Mdot
.18612 .70078 Mdot
.61136 .85186 Mdot
.52195 .17063 Mdot
.33931 .48539 Mdot
.96154 .45888 Mdot
.42168 .28931 Mdot
.98106 .3027 Mdot
.54752 .73037 Mdot
.29173 .27301 Mdot
.55229 .32809 Mdot
.25701 .56301 Mdot
.54549 .18214 Mdot
.16822 .56164 Mdot
.19234 .33662 Mdot
.90256 .40771 Mdot
.73318 .81902 Mdot
.07359 .29827 Mdot
.31688 .78327 Mdot
.93519 .05346 Mdot
.76741 .72538 Mdot
.07579 .82134 Mdot
.06761 .60834 Mdot
.17385 .45147 Mdot
.08987 .24317 Mdot
.09095 .11783 Mdot
.08221 .35757 Mdot
.76473 .76897 Mdot
.57859 .06659 Mdot
.18624 .26859 Mdot
.3527 .51775 Mdot
.07768 .13204 Mdot
.54668 .19335 Mdot
.53805 .29107 Mdot
.64519 .95217 Mdot
.1498 .85503 Mdot
.60083 .57584 Mdot
.30929 .99352 Mdot
.44565 .79018 Mdot
.99905 .18976 Mdot
.62161 .72494 Mdot
.49725 .04877 Mdot
.44218 .19467 Mdot
.31676 .5359 Mdot
.01539 .93012 Mdot
.01471 .12807 Mdot
.43551 .01705 Mdot
.88998 .00245 Mdot
.50101 .22448 Mdot
.94254 .2887 Mdot
.35189 .34562 Mdot
.86926 .87398 Mdot
.71268 .07882 Mdot
.02834 .16944 Mdot
.97763 .77164 Mdot
.86445 .39798 Mdot
.98041 .71932 Mdot
.11624 .11127 Mdot
.60804 .81221 Mdot
.24828 .92542 Mdot
.91485 .56379 Mdot
.33378 .66869 Mdot
.59221 .04027 Mdot
.61222 .5892 Mdot
.04868 .34552 Mdot
.22761 .43325 Mdot
.92837 .1567 Mdot
.21856 .371 Mdot
.20978 .48488 Mdot
.12919 .81884 Mdot
.65482 .46532 Mdot
.15727 .3433 Mdot
.81027 .82402 Mdot
.8294 .75527 Mdot
.5156 .41443 Mdot
.97695 .85077 Mdot
.11872 .40423 Mdot
.87606 .12231 Mdot
.56051 .87626 Mdot
.64045 .9446 Mdot
.19707 .21972 Mdot
.89303 .78268 Mdot
.77019 .76014 Mdot
.06284 .05107 Mdot
.5983 .94552 Mdot
.24422 .95166 Mdot
.50778 .18064 Mdot
.14686 .68228 Mdot
.52209 .05587 Mdot
.29588 .73889 Mdot
.37854 .39996 Mdot
.38472 .40536 Mdot
.52018 .72096 Mdot
.61492 .82382 Mdot
.73484 .05069 Mdot
.39473 .32941 Mdot
.05702 .78903 Mdot
.19587 .75217 Mdot
.94328 .56126 Mdot
.19408 .92015 Mdot
.93932 .33803 Mdot
.06928 .33838 Mdot
.37914 .37985 Mdot
.11788 .03945 Mdot
.76532 .414 Mdot
.57341 .15079 Mdot
.66818 .85564 Mdot
.02267 .49859 Mdot
.62943 .7034 Mdot
.61884 .66457 Mdot
.39938 .44823 Mdot
.46879 .04421 Mdot
.75011 .77705 Mdot
.15425 .78626 Mdot
.0716 .54939 Mdot
.56417 .37904 Mdot
.20296 .88983 Mdot
.00774 .4912 Mdot
.05774 .47663 Mdot
.35071 .81897 Mdot
.63932 .33744 Mdot
.92961 .311 Mdot
.10431 .4485 Mdot
.64605 .27355 Mdot
.56119 .56151 Mdot
.39836 .63977 Mdot
.24991 .01079 Mdot
.2375 .74114 Mdot
.11554 .89201 Mdot
.92977 .05074 Mdot
.27949 .95332 Mdot
.11446 .99138 Mdot
.5321 .299 Mdot
.82659 .84943 Mdot
.2795 .15264 Mdot
.67823 .87907 Mdot
.32601 .59331 Mdot
.06856 .3236 Mdot
.83449 .99004 Mdot
.78951 .24808 Mdot
.75869 .99739 Mdot
.40951 .49092 Mdot
.82859 .08554 Mdot
.62425 .83015 Mdot
.63847 .85571 Mdot
.91829 .97463 Mdot
.24975 .72616 Mdot
.31046 .35271 Mdot
.32854 .79431 Mdot
.08352 .01344 Mdot
.4076 .87284 Mdot
.22396 .50301 Mdot
.06779 .09445 Mdot
.66925 .16184 Mdot
.43608 .12925 Mdot
.13695 .25012 Mdot
.91417 .17086 Mdot
.416 .84665 Mdot
.7505 .60437 Mdot
.35726 .66686 Mdot
.03739 .03614 Mdot
.06428 .85289 Mdot
.41468 .4481 Mdot
.50204 .2524 Mdot
.70147 .58181 Mdot
.71021 .26235 Mdot
.26803 .69573 Mdot
.03818 .14612 Mdot
.95822 .29491 Mdot
.49405 .84332 Mdot
.5824 .43456 Mdot
.46567 .17211 Mdot
.38264 .17516 Mdot
.15495 .32697 Mdot
.79017 .08973 Mdot
.40215 .03161 Mdot
.53135 .63118 Mdot
.01686 .90341 Mdot
.58197 .02189 Mdot
.20289 .46114 Mdot
.48362 .00388 Mdot
.92248 .1487 Mdot
.34823 .38534 Mdot
.60818 .1587 Mdot
.87507 .01724 Mdot
.16544 .57155 Mdot
.96468 .90103 Mdot
.70971 .79601 Mdot
.4057 .4714 Mdot
.5127 .25484 Mdot
.01251 .13356 Mdot
.8907 .37176 Mdot
.4487 .1894 Mdot
.18841 .7664 Mdot
.29632 .14673 Mdot
.97151 .62388 Mdot
.15412 .77046 Mdot
.61491 .9832 Mdot
.27875 .47154 Mdot
.18054 .46761 Mdot
.74711 .052 Mdot
.61016 .04585 Mdot
.99806 .94056 Mdot
.48167 .03293 Mdot
.83207 .69006 Mdot
.67334 .16021 Mdot
.44625 .85203 Mdot
.50916 .59863 Mdot
.45409 .22367 Mdot
.74418 .51526 Mdot
.11841 .45907 Mdot
.84964 .82475 Mdot
.23327 .20379 Mdot
.18712 .4744 Mdot
.61898 .15946 Mdot
.38235 .70476 Mdot
.77121 .66768 Mdot
.68678 .64673 Mdot
.14917 .38073 Mdot
.34799 .29847 Mdot
.52887 .03682 Mdot
.2717 .6321 Mdot
.35454 .71625 Mdot
.27236 .70224 Mdot
.02558 .43207 Mdot
.25856 .47493 Mdot
.89986 .68861 Mdot
.22064 .0134 Mdot
.94467 .15847 Mdot
.55829 .12681 Mdot
.73732 .53011 Mdot
.45752 .26593 Mdot
.57167 .50377 Mdot
.03283 .4762 Mdot
.00262 .57248 Mdot
.9498 .59625 Mdot
.13661 .02854 Mdot
.76409 .30644 Mdot
.31661 .56003 Mdot
.47023 .73908 Mdot
.52968 .67597 Mdot
.6449 .37066 Mdot
.79149 .31021 Mdot
.6031 .07988 Mdot
.3588 .83602 Mdot
.70601 .7148 Mdot
.25923 .20781 Mdot
.90866 .76273 Mdot
.04524 .93786 Mdot
.21533 .14095 Mdot
.27377 .72223 Mdot
.64536 .48065 Mdot
.84644 .29044 Mdot
.90359 .0301 Mdot
.11763 .23179 Mdot
.31132 .03196 Mdot
.23698 .95407 Mdot
.44912 .45846 Mdot
.92103 .97105 Mdot
.17346 .65091 Mdot
.88873 .50671 Mdot
.23828 .54648 Mdot
.58992 .05755 Mdot
.59373 .91054 Mdot
.44833 .07366 Mdot
.13479 .81661 Mdot
.59076 .11157 Mdot
.09206 .62033 Mdot
.17073 .28246 Mdot
.38263 .40263 Mdot
.10944 .16267 Mdot
.20381 .86986 Mdot
.43944 .4815 Mdot
.23586 .41638 Mdot
.61201 .57078 Mdot
.93244 .4086 Mdot
.0258 .27434 Mdot
.83994 .02591 Mdot
.7184 .19995 Mdot
.5527 .94438 Mdot
.40558 .00488 Mdot
.27285 .55603 Mdot
.58351 .78484 Mdot
.23975 .22754 Mdot
.22546 .97782 Mdot
.93274 .47629 Mdot
.17924 .73359 Mdot
.64861 .34033 Mdot
.47876 .62319 Mdot
.3768 .51881 Mdot
.44896 .61872 Mdot
.17963 .47287 Mdot
.19131 .69292 Mdot
.43778 .4034 Mdot
.92065 .87594 Mdot
.12606 .48464 Mdot
.62376 .95899 Mdot
.69326 .67002 Mdot
.36407 .34756 Mdot
.34292 .2524 Mdot
.13221 .5804 Mdot
.41108 .83051 Mdot
.66802 .13934 Mdot
.49039 .80871 Mdot
.73855 .29655 Mdot
.76374 .33962 Mdot
.70581 .20307 Mdot
.47994 .4448 Mdot
.3554 .06603 Mdot
.99072 .06396 Mdot
.73864 .83056 Mdot
.99421 .88361 Mdot
.75047 .85213 Mdot
.97294 .97782 Mdot
.95494 .4743 Mdot
.70281 .28849 Mdot
.42327 .03936 Mdot
.44625 .96852 Mdot
.52748 .57518 Mdot
.83306 .5914 Mdot
.34198 .40674 Mdot
.22889 .52542 Mdot
.98627 .48608 Mdot
.9748 .49258 Mdot
.20483 .65842 Mdot
.01121 .94775 Mdot
.56167 .94961 Mdot
.49791 .56694 Mdot
.56957 .58004 Mdot
.53324 .62633 Mdot
.21677 .89788 Mdot
.4921 .04601 Mdot
.01656 .19926 Mdot
.73669 .58442 Mdot
.03872 .42954 Mdot
.53861 .75371 Mdot
.70821 .65808 Mdot
.68451 .48674 Mdot
.36232 .01892 Mdot
.20494 .56485 Mdot
.73753 .81578 Mdot
.19601 .05767 Mdot
.23228 .55377 Mdot
.54721 .17784 Mdot
.66707 .60513 Mdot
.09128 .69169 Mdot
.60114 .11616 Mdot
.21186 .94427 Mdot
.3616 .09414 Mdot
.54345 .29526 Mdot
.32051 .93664 Mdot
.55909 .28932 Mdot
.3993 .37694 Mdot
.75629 .0456 Mdot
.47265 .65709 Mdot
.14508 .20908 Mdot
.4699 .01065 Mdot
.28761 .96962 Mdot
.16228 .50891 Mdot
.24786 .55931 Mdot
.50954 .5158 Mdot
.9662 .92469 Mdot
.06285 .09494 Mdot
.21433 .57374 Mdot
.54949 .90979 Mdot
.57395 .8154 Mdot
.49408 .0947 Mdot
.02069 .02659 Mdot
.70737 .38988 Mdot
.63439 .6424 Mdot
.84064 .51429 Mdot
.84594 .17306 Mdot
.1595 .11369 Mdot
.53342 .21729 Mdot
.02906 .11484 Mdot
.71229 .59721 Mdot
.24946 .26957 Mdot
.95217 .77953 Mdot
.08724 .93364 Mdot
.24247 .81164 Mdot
.43906 .34806 Mdot
.74736 .46121 Mdot
.4733 .66281 Mdot
.80048 .36633 Mdot
.71604 .33833 Mdot
.52065 .82186 Mdot
.48135 .32784 Mdot
.68617 .70698 Mdot
.37087 .47207 Mdot
.3965 .54241 Mdot
.91869 .76096 Mdot
.34498 .85705 Mdot
.42375 .1865 Mdot
.74638 .35949 Mdot
.51795 .32133 Mdot
.90974 .27535 Mdot
.02035 .11572 Mdot
.64554 .98888 Mdot
.60316 .5525 Mdot
.97409 .81223 Mdot
.55502 .97843 Mdot
.18057 .91899 Mdot
.26484 .17939 Mdot
.32586 .0384 Mdot
.82945 .01629 Mdot
.9778 .60491 Mdot
.15428 .51806 Mdot
.33957 .41918 Mdot
.23132 .57031 Mdot
.09595 .00375 Mdot
.72586 .16749 Mdot
.40137 .67933 Mdot
.53251 .65393 Mdot
.93769 .47882 Mdot
.87059 .17541 Mdot
.82716 .00122 Mdot
.14771 .35868 Mdot
.91628 .06072 Mdot
.64564 .57971 Mdot
.91703 .98145 Mdot
.80154 .15327 Mdot
.69987 .73637 Mdot
.11437 .76528 Mdot
.93231 .15401 Mdot
.90968 .11912 Mdot
.11783 .65993 Mdot
.16185 .69639 Mdot
.66645 .08256 Mdot
.17859 .52001 Mdot
.72735 .62238 Mdot
.05341 .11013 Mdot
.8081 .03213 Mdot
.23822 .0641 Mdot
.64214 .00672 Mdot
.3322 .72928 Mdot
.71624 .90846 Mdot
.6962 .72546 Mdot
.5911 .31407 Mdot
.47992 .0094 Mdot
.39143 .44707 Mdot
.46803 .16955 Mdot
.50809 .84031 Mdot
.47646 .2031 Mdot
.59024 .82862 Mdot
.88545 .34346 Mdot
.70892 .64432 Mdot
.42961 .65763 Mdot
.05851 .49424 Mdot
.19884 .9172 Mdot
.40968 .47436 Mdot
.69994 .51589 Mdot
.20356 .85021 Mdot
.46603 .59675 Mdot
.95903 .29584 Mdot
.16831 .9049 Mdot
.41224 .10262 Mdot
.4074 .05017 Mdot
.71187 .6073 Mdot
.45145 .10994 Mdot
.36507 .73871 Mdot
.14816 .22023 Mdot
.12889 .57613 Mdot
.89189 .42031 Mdot
.61897 .56579 Mdot
.17165 .47106 Mdot
.37734 .91785 Mdot
.11365 .60893 Mdot
.15423 .73703 Mdot
.01569 .42914 Mdot
.19804 .31191 Mdot
.4607 .27243 Mdot
.08812 .51589 Mdot
.94526 .12954 Mdot
.93249 .18056 Mdot
.48115 .50955 Mdot
.56242 .95065 Mdot
.22786 .36404 Mdot
.8494 .13521 Mdot
.68122 .17239 Mdot
.109 .4681 Mdot
.78453 .62962 Mdot
.8369 .39925 Mdot
.20405 .53313 Mdot
.98529 .99231 Mdot
.24553 .1844 Mdot
.52429 .48633 Mdot
.90767 .37505 Mdot
.46912 .973 Mdot
.62188 .06477 Mdot
.50092 .96831 Mdot
.85967 .24038 Mdot
.67679 .31133 Mdot
.1251 .24994 Mdot
.10071 .24909 Mdot
.48254 .55321 Mdot
.09845 .90469 Mdot
.65454 .411 Mdot
.25492 .60639 Mdot
.85478 .53254 Mdot
.68731 .26854 Mdot
.99171 .73521 Mdot
.64157 .73972 Mdot
.31138 .48418 Mdot
.46541 .46718 Mdot
.13412 .33669 Mdot
.7306 .43568 Mdot
.894 .4404 Mdot
.81579 .53356 Mdot
.56368 .44038 Mdot
.44584 .56072 Mdot
.82507 .9958 Mdot
.46261 .00402 Mdot
.61576 .51895 Mdot
.88996 .20192 Mdot
.46846 .74011 Mdot
.5019 .26168 Mdot
.27736 .66052 Mdot
.57126 .85805 Mdot
.33675 .89816 Mdot
.23759 .93248 Mdot
.12504 .38307 Mdot
.60685 .84525 Mdot
.98742 .66066 Mdot
.0375 .02913 Mdot
.52604 .56248 Mdot
.90276 .34478 Mdot
.82269 .55026 Mdot
.36372 .29516 Mdot
.99785 .98584 Mdot
.94032 .06133 Mdot
.57693 .94959 Mdot
.19483 .20013 Mdot
.65445 .36782 Mdot
.68158 .21931 Mdot
.10563 .12455 Mdot
.38998 .36907 Mdot
.62071 .7468 Mdot
.17046 .00061 Mdot
.42223 .41832 Mdot
.26388 .32991 Mdot
.36746 .4448 Mdot
.23008 .8099 Mdot
.84346 .55712 Mdot
.12742 .32108 Mdot
.95035 .89044 Mdot
.70899 .35163 Mdot
.99868 .98332 Mdot
.39102 .90536 Mdot
.20584 .07969 Mdot
.21038 .36854 Mdot
.75254 .84603 Mdot
.05142 .27194 Mdot
.48284 .18468 Mdot
.50411 .41564 Mdot
.23559 .56033 Mdot
.58053 .93969 Mdot
.24141 .37926 Mdot
.01854 .85395 Mdot
.33492 .2859 Mdot
.36326 .15151 Mdot
.81801 .13708 Mdot
.49488 .40327 Mdot
.29274 .34119 Mdot
.72514 .59916 Mdot
.36214 .15083 Mdot
.89981 .07023 Mdot
.53435 .7974 Mdot
.23825 .7958 Mdot
.80839 .09414 Mdot
.27084 .0616 Mdot
.31817 .7106 Mdot
.65049 .06271 Mdot
.36238 .64782 Mdot
.55216 .44154 Mdot
.51165 .40192 Mdot
.24999 .04534 Mdot
.24441 .30492 Mdot
.27659 .21004 Mdot
.46735 .91572 Mdot
.02977 .28534 Mdot
.65845 .55896 Mdot
.36572 .25126 Mdot
.03908 .69681 Mdot
.90518 .25272 Mdot
.01069 .08032 Mdot
.14042 .80356 Mdot
.39845 .85507 Mdot
.74012 .70194 Mdot
.15023 .40396 Mdot
.9856 .46285 Mdot
.01588 .6828 Mdot
.73698 .4139 Mdot
.25341 .3514 Mdot
.99323 .75491 Mdot
.73992 .49595 Mdot
.52787 .842 Mdot
.83674 .41329 Mdot
.32556 .78148 Mdot
.90868 .53885 Mdot
.4053 .34757 Mdot
.57901 .26771 Mdot
.32228 .83571 Mdot
.04033 .28106 Mdot
.41674 .60711 Mdot
.03705 .29201 Mdot
.44466 .89184 Mdot
.0795 .59088 Mdot
.65396 .14869 Mdot
.90526 .21427 Mdot
.65136 .89798 Mdot
.97141 .65175 Mdot
.1452 .17307 Mdot
.63481 .25161 Mdot
.19293 .51057 Mdot
.45531 .93677 Mdot
.65028 .88232 Mdot
.72302 .87703 Mdot
.45642 .02026 Mdot
.66154 .90734 Mdot
.71589 .52566 Mdot
.73045 .56923 Mdot
.32515 .08385 Mdot
.84856 .51605 Mdot
.92696 .5687 Mdot
.16973 .936 Mdot
.6509 .05218 Mdot
.41887 .36541 Mdot
.0437 .35095 Mdot
.06142 .88919 Mdot
.83111 .32031 Mdot
.33044 .85605 Mdot
.40545 .7434 Mdot
.45945 .51459 Mdot
.37945 .00932 Mdot
.48422 .07923 Mdot
.1499 .04496 Mdot
.80168 .99344 Mdot
.71311 .72949 Mdot
.76327 .75444 Mdot
.70734 .09424 Mdot
.81822 .87534 Mdot
.20782 .18225 Mdot
.78297 .05064 Mdot
.08426 .2354 Mdot
.31169 .58692 Mdot
.10659 .33776 Mdot
.06082 .10461 Mdot
.94066 .97057 Mdot
.66256 .37417 Mdot
.18819 .41441 Mdot
.24466 .54831 Mdot
.11228 .61987 Mdot
.39085 .38137 Mdot
.95552 .15682 Mdot
.36857 .93641 Mdot
.61826 .15376 Mdot
.256 .87691 Mdot
.81053 .86497 Mdot
.27228 .37476 Mdot
.20152 .69593 Mdot
.0312 .19036 Mdot
.64583 .52784 Mdot
.27961 .7427 Mdot
.30602 .75373 Mdot
.79431 .01338 Mdot
.77885 .6557 Mdot
.74323 .90585 Mdot
.02718 .51446 Mdot
.43298 .15572 Mdot
.08632 .70977 Mdot
.51977 .59694 Mdot
.27957 .09349 Mdot
.54848 .78595 Mdot
.39295 .48614 Mdot
.18399 .25564 Mdot
.9429 .49338 Mdot
.1052 .9991 Mdot
.11106 .85361 Mdot
.73816 .54582 Mdot
.55382 .04711 Mdot
.51186 .78543 Mdot
.22887 .51468 Mdot
.92822 .06646 Mdot
.2491 .71826 Mdot
.10009 .73718 Mdot
.62075 .71235 Mdot
.83774 .66674 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00_o
oooo0ol0000=ooooo`?o00003oooool00ol0003oooooooooo`03ooooo`;o00002Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_l00005ooooo`;o
00001?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`09ooooo`;o
00000_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool00_ooool001kooooo00?o0000ooooooooool02oooool3o`0000gooooo0ol0000?ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03_ooool3o`0000gooooo00?o0000ooooooooool0
0_l00005ooooo`;o00001?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool02_ooool2o`000004ooooool0003o0000o`0000gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool02Oooool2o`0000;ooooo00Co0000oooooooooooooooo0_l0000:ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool00_ooool001kooooo00?o0000ooooooooool0Moooool2o`0000Oo
oooo0_l0000Cooooo`;o000000?oooooo`000?l000008?ooool2o`00017ooooo0_l00002ooooo`;o
0000D_ooool2o`00023ooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0000[ooooo`;o0000
1oooool2o`0002Sooooo0_l0000Looooo`;o000000?oooooo`000?l000008?ooool2o`0004;ooooo
0_l00017ooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o00002?ooool2o`00027ooooo0_l0
0007ooooo`;o00003?ooool2o`000:7ooooo0_l0000:ooooo`;o0000>oooool001kooooo00?o0000
ooooooooool08Oooool2o`0002Kooooo0_l0000@ooooo`;o00005Oooool2o`0001Gooooo0_l0001o
ooooo`;o00003?ooool2o`0002gooooo000Nooooo`03o`000?oooooooooo04Wooooo0_l0000Woooo
o`;o00005Oooool2o`0000Gooooo0_l0000Wooooo`;o0000GOooool2o`0002gooooo000Nooooo`03
o`000?oooooooooo093ooooo0_l00009ooooo`;o00007?ooool2o`0003;ooooo0_l0000Nooooo`;o
0000>?ooool001kooooo00?o0000ooooooooool00oooool2o`0002?ooooo0_l0000Rooooo`;o0000
COooool2o`00053ooooo0_l0000Nooooo`;o0000>?ooool001kooooo00?o0000ooooooooool00ooo
ool2o`0000?ooooo0_l0000Nooooo`;o00008_ooool2o`0001?ooooo0_l0000Looooo`;o0000P_oo
ool2o`0000Sooooo0_l0000Cooooo`;o00008oooool001kooooo00?o0000ooooooooool02?ooool2
o`0005Oooooo0_l0000Looooo`;o00005oooool2o`0006Wooooo0_l0000Mooooo`;o00008oooool0
01kooooo00?o0000ooooooooool02?ooool2o`0005Kooooo0_l0000fooooo`;o00003_ooool2o`00
09gooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0000Hooooo`;o0000??ooool2o`0000Co
oooo0_l0000Mooooo`;o00008Oooool2o`0001;ooooo0_l00029ooooo`007_ooool00ol0003ooooo
ooooo`0Rooooo`;o0000@_ooool2o`0001gooooo0_l0000=ooooo`;o00009_ooool2o`0008Wooooo
000Nooooo`03o`000?oooooooooo02gooooo0_l0000Nooooo`;o0000AOooool2o`0000Kooooo0_l0
000Booooo`;o00004?ooool2o`0002kooooo0_l0001Cooooo`007_ooool00ol0003oooooooooo`0]
ooooo`;o00007_ooool2o`0001gooooo0_l0000Booooo`;o00006_ooool4o`0000Wooooo0_l00005
ooooo`;o00004?ooool2o`0002kooooo0_l00006ooooo`;o0000Boooool001kooooo0_l0000Aoooo
o`;o0000=?ooool2o`0002Cooooo0_l0000Booooo`;o00007?ooool2o`0000Wooooo0_l0000Loooo
o`;o00001oooool2o`0001Wooooo0_l00002ooooo`;o00002Oooool2o`0002kooooo1_l0000Goooo
o`007_ooool00ol0003oooooooooo`0@ooooo`;o0000=?ooool2o`0005kooooo0_l0000Oooooo`;o
00001oooool2o`0001Wooooo0_l00002ooooo`;o0000>Oooool6o`0001Oooooo000Nooooo`03o`00
0?oooooooooo03cooooo0_l0001Xooooo`;o00005?ooool2o`0006Cooooo0_l0000Sooooo`007_oo
ool00ol0003oooooooooo`0looooo`;o00005_ooool2o`0006Kooooo0_l0000Aooooo`;o0000DOoo
ool2o`0000;ooooo0_l00006ooooo`;o00005oooool001kooooo00?o0000ooooooooool0BOooool2
o`0000Wooooo0_l0001`ooooo`;o00001oooool2o`0005Gooooo0_l00006ooooo`;o00003_ooool2
o`0000Oooooo000Nooooo`03o`000?oooooooooo04Wooooo0_l0000Tooooo`;o0000Aoooool2o`00
00cooooo0_l0001Rooooo`;o00004_ooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo06oo
oooo0_l00017ooooo`;o0000I_ooool2o`0000Sooooo0_l0000Kooooo`007_ooool00ol0003ooooo
ooooo`1>ooooo`;o0000?_ooool2o`00093ooooo0_l0000Uooooo`007_ooool00ol0003ooooooooo
o`1>ooooo`;o0000?_ooool2o`0007[ooooo0_l0000kooooo`007_ooool01?l0003oooooo`000?l0
000nooooo`;o0000;?ooool2o`0002[ooooo0_l0000Uooooo`;o00008_ooool2o`0002Cooooo0_l0
000kooooo`007_ooool01?l0003oooooo`000?l0000nooooo`;o00009Oooool2o`0000Gooooo0_l0
000Zooooo`;o00009Oooool2o`0001?ooooo0_l0000=ooooo`;o0000HOooool001kooooo00?o0000
ooooooooool0I_ooool2o`0006gooooo0_l0000booooo`;o0000??ooool001kooooo00?o0000oooo
ooooool0oOooool2o`0000[ooooo0_l0000<ooooo`;o0000;_ooool001kooooo00?o0000oooooooo
ool0Eoooool2o`000:Cooooo0_l0000Hooooo`;o0000;_ooool001kooooo00?o0000ooooooooool0
0_ooool2o`0000cooooo1?l0000Yooooo`;o00006?ooool2o`0001Sooooo0_l0000Zooooo`;o0000
2?ooool2o`0003Wooooo0_l0000Oooooo`;o00001oooool2o`0003Wooooo000Nooooo`03o`000?oo
oooooooo00;ooooo0_l0000<ooooo`Co0000:Oooool2o`0003;ooooo0_l0000Zooooo`;o00002?oo
ool2o`0003Wooooo0_l0000Oooooo`;o00001oooool2o`0003Wooooo000Nooooo`;o0000Poooool2
o`000<?ooooo000Nooooo`03o`000?oooooooooo013ooooo0_l0001`ooooo`;o0000`oooool001ko
oooo00?o0000ooooooooool04?ooool2o`000?oooooo=_ooool001kooooo00?o0000ooooooooool0
3Oooool2o`0001?ooooo0_l0001[ooooo`;o0000:oooool2o`0008Wooooo000Nooooo`03o`000?oo
oooooooo00Gooooo0_l00002ooooo`;o00000_ooool2o`0001?ooooo0_l0000<ooooo`;o0000GOoo
ool2o`0002_ooooo0_l00029ooooo`007_ooool00ol0003oooooooooo`02ooooo`;o000000?ooooo
o`000?l000000_ooool2o`0000kooooo0_l0000Eooooo`;o0000Doooool2o`0003Sooooo0_l00026
ooooo`007_ooool00ol0003oooooooooo`02ooooo`;o00005Oooool2o`0006[ooooo0_l0000hoooo
o`;o0000Hoooool2o`00027ooooo000Nooooo`03o`000?oooooooooo0?oooooo6_ooool2o`0000Wo
oooo0_l0000Qooooo`007_ooool00ol0003oooooooooo`0Nooooo`;o0000GOooool2o`0003;ooooo
0_l0001Vooooo`;o0000;?ooool001kooooo00Co0000oooooooooooooooo0_l0000Kooooo`;o0000
GOooool2o`0000Cooooo0_l00005ooooo`;o00009Oooool2o`0007cooooo0_l0000Fooooo`007_oo
ool00ol0003oooooooooo`03o`0001;ooooo0_l00005ooooo`;o0000IOooool2o`0000Gooooo0_l0
0011ooooo`;o0000H?ooool2o`0000_ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`02
o`0001?ooooo0_l00005ooooo`;o0000;_ooool2o`0007oooooo0_l00011ooooo`;o0000:_ooool2
o`0000Wooooo000Nooooo`03o`000?oooooooooo04cooooo0_l00027ooooo`;o0000;oooool2o`00
00Sooooo0_l0000eooooo`007_ooool00ol0003oooooooooo`12ooooo`;o0000TOooool2o`0002oo
oooo0_l0000oooooo`007_ooool00ol0003oooooooooo`0cooooo`;o00003Oooool2o`0001cooooo
0_l0001@ooooo`;o0000Toooool001kooooo00?o0000ooooooooool02?ooool2o`0002Wooooo0_l0
000Wooooo`;o00000_ooool2o`0002cooooo0_l0000Rooooo`;o00007?ooool2o`0005Kooooo0_l0
0002ooooo`;o00006Oooool001kooooo0_l00009ooooo`;o0000D_ooool2o`0001Cooooo0_l0000J
ooooo`;o00009_ooool2o`0001Sooooo0_l0000iooooo`;o00006oooool2o`0000;ooooo0_l0000I
ooooo`007_ooool00ol0003oooooooooo`1Gooooo`;o00006Oooool2o`0004;ooooo0_l0000=oooo
o`;o0000>Oooool2o`0000Wooooo0_l0000Nooooo`;o00006_ooool001kooooo00?o0000oooooooo
ool0?_ooool2o`0001Oooooo0_l0000/ooooo`;o00000_ooool2o`0003[ooooo0_l0000iooooo`;o
00002Oooool2o`0001gooooo0ol00006ooooo`;o00004_ooool001kooooo00?o0000ooooooooool0
8?ooool2o`0001cooooo0_l0000Kooooo`;o0000:?ooool2o`0000;ooooo0_l0000Zooooo`;o0000
2oooool2o`000003ooooool0003o0000013ooooo0_l0000booooo`;o00007Oooool2o`0000?ooooo
0_l00002ooooo`;o00002_ooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo01oooooo0ol0
000iooooo`;o0000F?ooool2o`0000_ooooo0_l000000ooooooo0000o`00000>ooooo`Go0000EOoo
ool2o`0000kooooo0_l00006ooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o0000COooool2
o`0006Gooooo0_l000000ooooooo0000o`00000>ooooo`;o0000<?ooool2o`0002_ooooo000Noooo
o`03o`000?oooooooooo00Gooooo0_l0001Wooooo`;o00009?ooool2o`0005;ooooo0_l0000`oooo
o`;o0000:oooool001kooooo00?o0000ooooooooool01Oooool2o`0002Cooooo0_l0001Vooooo`?o
00004?ooool2o`00037ooooo0_l0000dooooo`;o00005?ooool2o`00023ooooo000Nooooo`03o`00
0?oooooooooo02_ooooo0_l0001;ooooo`;o00006Oooool2o`00017ooooo0_l0000aooooo`;o0000
=?ooool2o`0000Kooooo0_l0000<ooooo`;o00008?ooool001kooooo00?o0000ooooooooool0D_oo
ool2o`0002Cooooo0_l0000dooooo`;o0000Ioooool2o`0002kooooo000Nooooo`03o`000?oooooo
oooo037ooooo0_l0000<ooooo`;o00004Oooool2o`0004gooooo0_l0000:ooooo`?o0000Noooool2
o`0001[ooooo000Nooooo`03o`000?oooooooooo037ooooo0_l0000<ooooo`;o00002oooool2o`00
04_ooooo0_l00006ooooo`;o00002_ooool2o`0000gooooo0_l0000mooooo`;o0000;_ooool2o`00
01[ooooo000Nooooo`03o`000?oooooooooo04cooooo0_l0000hooooo`;o00004Oooool2o`00027o
oooo0_l0000mooooo`;o0000B_ooool001kooooo00?o0000ooooooooool01_ooool2o`0007kooooo
0_l00006ooooo`;o0000/Oooool2o`0000Cooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo00Kooooo0_l0000looooo`;o0000
A_ooool4o`0001kooooo0_l0002Aooooo`;o00001?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000oooooooo
ool06?ooool2o`0002[ooooo0_l0000gooooo`;o00003Oooool2o`00023ooooo0_l0002Gooooo`00
0oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool3o`000003
ooooool0003o000001Gooooo0_l0000Qooooo`;o0000@?ooool2o`0006Kooooo0_l0001Pooooo`00
0oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01_ooool01?l0003o
ooooooooooooool2o`0003Sooooo0_l0000;ooooo`;o0000COooool2o`0004Sooooo0_l00002oooo
o`;o0000=_ooool2o`0002Sooooo0003ooooo`05o`000?ooooooooooooooool000003_ooool00omg
MgOoIVIVooooo`05ooooo`03o`000?oooooooooo04Sooooo0_l0001=ooooo`;o0000B?ooool2o`00
00;ooooo0_l0000fooooo`;o0000:?ooool000?ooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0:oooool2o`0002?ooooo0_l00004oooo
o`;o0000O_ooool2o`0000gooooo0_l0001Pooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo02_ooooo0_l0000S
ooooo`;o00001?ooool2o`0007kooooo0_l0001Wooooo`;o00001_ooool000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooooooo
o`3oooooob?ooooo0_l0000Kooooo`;o00001_ooool001kooooo00?o0000ooooooooool02oooool2
o`0002oooooo0_l0001Xooooo`;o000000?oooooo`000?l00000;_ooool2o`0003gooooo0_l00008
ooooo`;o00006oooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l0000Ooooo
o`;o00003_ooool2o`0006Sooooo0_l000000ooooooo0000o`00000^ooooo`;o0000?Oooool2o`00
02gooooo000Nooooo`03o`000?oooooooooo02cooooo0_l0001Rooooo`;o00003Oooool2o`0001;o
oooo0_l0002Booooo`007_ooool00ol0003oooooooooo`1:ooooo`;o0000A?ooool2o`0000gooooo
0_l0000Booooo`;o0000T_ooool001kooooo00?o0000ooooooooool08_ooool2o`0000;ooooo0_l0
000Rooooo`;o0000noooool001kooooo00?o0000ooooooooool08_ooool2o`0000;ooooo0_l00022
ooooo`;o0000ROooool2o`00013ooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0002Aoooo
o`;o0000@?ooool2o`0004Oooooo0_l0000@ooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o
0000doooool2o`0002Gooooo0_l0000Qooooo`;o00003oooool001kooooo00?o0000ooooooooool0
6Oooool2o`000?Sooooo0_l0000Qooooo`;o00003oooool001kooooo00?o0000ooooooooool06Ooo
ool2o`000>?ooooo0_l00017ooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o00001_ooool2
o`000003ooooool0003o000003oooooo0_l0002Booooo`?o0000>_ooool2o`0000_ooooo000Noooo
o`;o00007_ooool2o`0000Kooooo0_l000000ooooooo0000o`00000gooooo`;o00001_ooool4o`00
00Kooooo0_l0000Zooooo`;o0000:Oooool2o`00037ooooo0_l00007ooooo`;o00006_ooool2o`00
01Kooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`0hooooo`;o00009Oooool4o`0000So
oooo0_l00006ooooo`;o0000:_ooool2o`0000;ooooo0_l0000Uooooo`;o0000>_ooool2o`0001[o
oooo0_l0000Sooooo`007_ooool00ol0003oooooooooo`0hooooo`;o00009Oooool2o`0004;ooooo
0_l0002Rooooo`007_ooool00ol0003oooooooooo`1fooooo`;o00009oooool2o`0004;ooooo0_l0
001Booooo`;o00003_ooool001kooooo00?o0000ooooooooool0M_ooool2o`00013ooooo0_l00007
ooooo`;o00003?ooool2o`0004;ooooo0_l0001Booooo`;o00003_ooool001kooooo00?o0000oooo
ooooool0:oooool2o`0000_ooooo0_l0001>ooooo`;o00001oooool2o`0002Gooooo0_l0000Qoooo
o`;o0000J_ooool001kooooo00?o0000ooooooooool03Oooool2o`0001cooooo0_l0000;ooooo`;o
00004oooool2o`0001gooooo0_l0001:ooooo`;o00008Oooool2o`0006[ooooo000Nooooo`03o`00
0?oooooooooo00Cooooo0_l00007ooooo`;o00009oooool2o`0001Gooooo0_l0000<ooooo`;o0000
3oooool2o`0002Cooooo0_l0000jooooo`;o0000B?ooool2o`0002gooooo000Nooooo`03o`000?oo
oooooooo00Cooooo0_l0000`ooooo`;o00008oooool2o`0003Gooooo0_l0000jooooo`;o0000B?oo
ool2o`0000[ooooo0_l0000Dooooo`;o00002oooool001kooooo00?o0000ooooooooool02Oooool2
o`000?oooooo6_ooool2o`0001Cooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`09oooo
o`;o0000:?ooool2o`000?oooooo0_ooool2o`0000oooooo000Nooooo`03o`000?oooooooooo00Ko
oooo0_l0000[ooooo`;o00005_ooool2o`0001cooooo0_l0003;ooooo`;o00003oooool001kooooo
00?o0000ooooooooool01_ooool2o`0004?ooooo0_l0000Looooo`;o00006_ooool2o`0002_ooooo
0_l0000/ooooo`;o0000;Oooool2o`0001gooooo0_l0000Gooooo`007_ooool00ol0003ooooooooo
o`08ooooo`;o0000Noooool2o`0002Cooooo0_l00005ooooo`;o0000;?ooool2o`0002gooooo0_l0
000Mooooo`;o00005oooool001kooooo00?o0000ooooooooool02?ooool2o`0000?ooooo0_l0001S
ooooo`;o0000=oooool4o`0003gooooo0_l00015ooooo`?o00004Oooool001kooooo00?o0000oooo
ooooool03Oooool2o`0000Gooooo0_l0001Gooooo`;o00000oooool2o`0000;ooooo0_l0000aoooo
o`;o00000_ooool2o`0003gooooo0_l00015ooooo`?o00004Oooool001kooooo0_l0000Eooooo`;o
0000Eoooool2o`0000Oooooo0_l0000aooooo`;o0000=Oooool2o`0004Kooooo0_l0000Aooooo`;o
00002_ooool001kooooo00?o0000ooooooooool0=_ooool2o`0001?ooooo0_l0002Cooooo`;o0000
A_ooool2o`00017ooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0fooooo`;o00002?oo
ool2o`0000Wooooo0_l0000Iooooo`;o0000S?ooool2o`00057ooooo000Nooooo`03o`000?oooooo
oooo02?ooooo0_l0000Gooooo`;o00000_ooool2o`0002Cooooo0_l00018ooooo`;o00009_ooool2
o`0001[ooooo0_l00007ooooo`;o0000:oooool3o`0001[ooooo000Nooooo`03o`000?oooooooooo
02?ooooo0_l0000Gooooo`;o0000L_ooool2o`0000[ooooo0_l0000Jooooo`;o00008oooool2o`00
02_ooooo0ol0000Jooooo`007_ooool00ol0003oooooooooo`1Kooooo`;o0000Goooool2o`0008Wo
oooo000Nooooo`03o`000?oooooooooo02Gooooo0_l0000[ooooo`;o00001oooool2o`000:gooooo
0_l0000kooooo`007_ooool00ol0003oooooooooo`0Booooo`;o00004Oooool2o`0002_ooooo0_l0
0010ooooo`;o00003_ooool2o`0006Cooooo0_l0000kooooo`007_ooool00ol0003oooooooooo`0B
ooooo`;o00004oooool2o`0000Gooooo0_l0001Tooooo`;o00003_ooool2o`000:7ooooo000Noooo
o`03o`000?oooooooooo02Oooooo0_l00005ooooo`;o00008_ooool2o`0002Sooooo0_l0000Joooo
o`;o00005Oooool2o`0009Kooooo000Nooooo`03o`000?oooooooooo05;ooooo0_l0000Xooooo`;o
00006_ooool2o`0001Gooooo0_l0002Fooooo`007_ooool00ol0003oooooooooo`02o`0002Gooooo
0_l0000Aooooo`;o0000JOooool2o`000:3ooooo000Nooooo`03o`000?oooooooooo00;o00004?oo
ool2o`0000Cooooo0_l00005ooooo`;o00001_ooool2o`00017ooooo0_l0001Yooooo`;o00000ooo
ool2o`00023ooooo0_l0000Gooooo`;o00003Oooool2o`0003Oooooo0_l0000Hooooo`007_ooool0
0ol0003oooooooooo`0Booooo`;o00001?ooool2o`0000Gooooo0_l0000jooooo`;o0000COooool2
o`00023ooooo0_l000000ooooooo0000o`00000Dooooo`;o00003Oooool2o`0003Oooooo0_l0000H
ooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o00008Oooool2o`0002[ooooo0_l0000Aoooo
o`;o0000Goooool2o`0004_ooooo0_l00003ooooo`;o00009?ooool001kooooo00?o0000oooooooo
ool03?ooool2o`00027ooooo0_l0000mooooo`;o00000_ooool2o`0000cooooo0_l00009ooooo`;o
0000Soooool2o`0000?ooooo0_l0000Cooooo`;o00003oooool001kooooo0_l0000;ooooo`;o0000
>?ooool2o`0000Sooooo0_l0000Rooooo`;o00003?ooool2o`0000Wooooo0_l0001Eooooo`;o0000
D_ooool2o`0000oooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0000hooooo`;o00002?oo
ool2o`00017ooooo0_l0001oooooo`;o0000Hoooool001kooooo00?o0000ooooooooool05oooool2
o`0004Sooooo0_l0000Sooooo`;o0000_oooool001kooooo00?o0000ooooooooool05oooool2o`00
01?ooooo0_l0000Rooooo`;o00003_ooool2o`0002Cooooo0_l0000Wooooo`;o00002Oooool2o`00
03?ooooo0_l0001Fooooo`007_ooool00ol0003oooooooooo`0/ooooo`;o00006?ooool2o`0000So
oooo0_l0000>ooooo`;o0000COooool2o`0000Wooooo0_l0000cooooo`;o0000E_ooool001kooooo
00?o0000ooooooooool08oooool2o`00027ooooo0_l0000/ooooo`;o00003_ooool2o`0007[ooooo
0_l00015ooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o00006oooool2o`0003;ooooo0_l0
0005ooooo`;o00001Oooool4o`0004_ooooo0_l0000]ooooo`;o0000AOooool001kooooo00?o0000
ooooooooool0@?ooool2o`000003ooooool0003o000003Kooooo0_l00005ooooo`;o0000B_ooool2
o`000003ooooool0003o000001Wooooo0_l0000_ooooo`;o0000:?ooool001kooooo00?o0000oooo
ooooool0@oooool2o`0000oooooo0_l0001hooooo`;o00000oooool2o`0001Gooooo1?l0000_oooo
o`;o00001?ooool2o`0002;ooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l00014ooooo`;o
00002?ooool2o`0000Wooooo0_l0000Mooooo`;o0000<oooool2o`0001kooooo0_l0000Eooooo`;o
0000=oooool2o`0002;ooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0000Vooooo`;o0000
1_ooool2o`0001Cooooo0_l0000Cooooo`;o00005_ooool2o`0000;ooooo0_l000000ooooooo0000
o`00000Yooooo`;o00002?ooool2o`0003Sooooo0_l0001Hooooo`007_ooool00ol0003ooooooooo
o`0Uooooo`;o00001Oooool2o`0000Kooooo0_l0000Iooooo`;o00002_ooool2o`00013ooooo0_l0
0008ooooo`;o00000_ooool2o`0002cooooo0_l00012ooooo`;o0000F?ooool001kooooo0_l0000V
ooooo`;o0000:?ooool2o`0000[ooooo0_l0000@ooooo`;o0000f?ooool001kooooo0_l0001Koooo
o`;o0000Q_ooool2o`0006?ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo05[ooooo0_l0001Toooo
o`;o00008?ooool2o`0003?ooooo0_l0000^ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0`?ooool2o`00
05?ooooo1?l0000^ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006oooo
o`?o0000Moooool2o`0005cooooo0_l0000eooooo`;o00001oooool2o`00033ooooo0003ooooo`05
o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooo
oooo02;ooooo0_l00009ooooo`;o0000??ooool2o`0000[ooooo0ol0000@ooooo`;o00004Oooool2
o`0000?ooooo0_l0000Zooooo`;o00001Oooool2o`0003Gooooo0_l0000iooooo`000oooool01Ol0
003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003ooooooooo
o`0Rooooo`;o00002Oooool2o`0003cooooo0_l0000;ooooo`?o00003oooool2o`00017ooooo0_l0
0003ooooo`;o0000:_ooool2o`0005Wooooo0_l0000Looooo`000oooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`1[ooooo`;o00003?oo
ool2o`0003Kooooo0_l0001Yooooo`;o00000oooool2o`0000Kooooo1?l0000Jooooo`000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0003ooooooooo
o`2aooooo`;o00007_ooool2o`00013ooooo0_l0000Wooooo`;o00003_ooool2o`0000?ooooo0_l0
0008ooooo`;o00000oooool2o`0001Gooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Ooo
ool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo03Wooooo0_l0000>ooooo`;o0000EOoo
ool2o`0000;ooooo0_l0000[ooooo`;o00004?ooool2o`0000Kooooo0_l00008ooooo`;o00005Ooo
ool2o`0002;ooooo0_l0000Eooooo`007_ooool00ol0003oooooooooo`0iooooo`;o00003_ooool2
o`0001Gooooo0_l00008ooooo`;o00006Oooool2o`0001Wooooo0_l00002ooooo`;o00001oooool2
o`0003cooooo0_l00008ooooo`;o00003?ooool2o`0004;ooooo000Nooooo`03o`000?oooooooooo
063ooooo0_l00008ooooo`;o00006Oooool2o`0002Kooooo0_l0001Dooooo`;o00006Oooool2o`00
02Oooooo000Nooooo`03o`000?oooooooooo0?oooooo7oooool2o`0002Oooooo000Nooooo`03o`00
0?oooooooooo0?oooooo5oooool2o`0002oooooo000Nooooo`04o`000?ooooooooooooooo`;o0000
1Oooool2o`000?oooooo3Oooool2o`0002oooooo000Nooooo`04o`000?ooooooooooooooo`;o0000
00?oooooo`000?l000000_ooool2o`0003cooooo0_l0001aooooo`;o00001?ooool2o`00057ooooo
0_l0000cooooo`007_ooool00ol0003oooooooooo`04ooooo`;o0000@?ooool2o`0006Oooooo0_l0
0008ooooo`;o00001?ooool2o`0002Sooooo0_l0000Wooooo`;o00007?ooool2o`0001Gooooo000N
ooooo`03o`000?oooooooooo0:oooooo0_l00002ooooo`;o0000=?ooool2o`0003Cooooo0_l0000?
ooooo`;o00005Oooool001kooooo00?o0000ooooooooool0[oooool2o`0000;ooooo0_l0001Zoooo
o`;o00009_ooool001kooooo00?o0000ooooooooool0Loooool2o`0000Kooooo0_l0000Kooooo`;o
00005Oooool2o`0000kooooo0_l00015ooooo`;o00000_ooool2o`0000Wooooo0_l0000`ooooo`00
7_ooool2o`0001oooooo0_l0001Cooooo`;o00001_ooool2o`000003ooooool0003o000000?ooooo
0_l0000Cooooo`;o00009Oooool2o`0004Gooooo0_l00002ooooo`;o00002Oooool2o`00033ooooo
000Nooooo`;o00007oooool2o`0001Cooooo0_l00018ooooo`;o00000oooool2o`0009Sooooo0_l0
000Xooooo`007_ooool00ol0003oooooooooo`0dooooo`;o00008Oooool2o`000<Cooooo0_l0000X
ooooo`007_ooool00ol0003oooooooooo`0Rooooo`;o0000<oooool2o`0000kooooo0_l0000Uoooo
o`;o0000Y?ooool2o`00017ooooo000Nooooo`03o`000?oooooooooo02;ooooo0_l00005ooooo`;o
00004oooool2o`0000_ooooo0_l0000Jooooo`;o00009Oooool2o`0003gooooo0_l0000Pooooo`;o
0000@oooool2o`00017ooooo000Nooooo`03o`000?oooooooooo02Wooooo0_l0000Cooooo`;o0000
2oooool2o`00037ooooo0_l0001=ooooo`;o00000_ooool2o`0001cooooo0_l0001;ooooo`;o0000
2Oooool001kooooo00?o0000ooooooooool07oooool2o`0001Kooooo0_l00015ooooo`;o00004ooo
ool2o`0003cooooo0_l0001Yooooo`;o00002Oooool001kooooo00?o0000ooooooooool07oooool2
o`0001?ooooo0_l000000ooooooo0000o`00000Nooooo`;o00009oooool2o`00017ooooo0_l0002b
ooooo`007_ooool00ol0003oooooooooo`0dooooo`Co000000?oooooo`000?l000005Oooool2o`00
00Gooooo0_l0000Kooooo`;o00002_ooool3o`000:oooooo0_l0000Cooooo`007_ooool00ol0003o
ooooooooo`07ooooo`;o00001_ooool2o`0001oooooo0_l00004ooooo`;o000000?oooooo`000?l0
00005Oooool2o`0002;ooooo0_l0000;ooooo`;o0000Z?ooool2o`0000Gooooo0_l0000Cooooo`00
7_ooool00ol0003oooooooooo`07ooooo`;o00001_ooool2o`0001oooooo0_l0002Looooo`;o0000
;?ooool2o`0002gooooo1?l0000Hooooo`007_ooool00ol0003oooooooooo`0Yooooo`;o00003?oo
ool2o`0002Sooooo0_l0000Xooooo`;o00001_ooool2o`0003Wooooo0_l0000/ooooo`;o0000;ooo
ool2o`0001Sooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0000Qooooo`;o00000_ooool2
o`0000cooooo0_l00007ooooo`;o00007oooool2o`0000Oooooo0_l0000@ooooo`;o00003Oooool2
o`0000Kooooo0_l0000Aooooo`?o0000<Oooool2o`00067ooooo0_l00008ooooo`007_ooool00ol0
003oooooooooo`02ooooo`;o00008Oooool2o`0001Wooooo0_l0000Xooooo`;o00004?ooool2o`00
02Sooooo0ol0000aooooo`;o00005_ooool2o`0004Wooooo0_l00008ooooo`007_ooool3o`00087o
oooo0_l0001_ooooo`;o0000>_ooool2o`0000Wooooo0_l0000<ooooo`007_ooool3o`0000oooooo
0_l0001`ooooo`;o000000?oooooo`000?l00000I_ooool2o`0000?ooooo0_l0000kooooo`;o0000
2Oooool2o`0000cooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0000:ooooo`;o0000KOoo
ool2o`0000Cooooo0_l0001Vooooo`;o00000oooool2o`0003_ooooo0_l0000Gooooo`007_ooool2
o`0000Cooooo0_l0001iooooo`;o0000[_ooool2o`0001Oooooo000Nooooo`03o`000?oooooooooo
04Gooooo0_l0000fooooo`;o0000=oooool2o`0008oooooo000Nooooo`03o`000?oooooooooo037o
oooo0_l00008ooooo`;o00002?ooool2o`0003Kooooo0_l0000gooooo`;o0000IOooool2o`0002So
oooo000Nooooo`03o`000?oooooooooo037ooooo0_l00008ooooo`;o0000Foooool2o`0008?ooooo
0_l0000Xooooo`007_ooool00ol0003oooooooooo`05ooooo`;o0000=?ooool2o`0000Wooooo0_l0
0019ooooo`;o00001Oooool2o`0007?ooooo0_l0000hooooo`007_ooool00ol0003oooooooooo`05
ooooo`;o00004_ooool2o`0001?ooooo0_l0000Fooooo`;o00009oooool2o`0000gooooo0_l0000A
ooooo`;o00003oooool2o`0003_ooooo0_l0000=ooooo`;o00007Oooool2o`000003ooooool0003o
000003Gooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l0000Cooooo`;o00001_ooool2o`00
03Oooooo0_l00005ooooo`;o00001_ooool2o`00017ooooo0_l0000?ooooo`;o00008?ooool2o`00
01Wooooo0_l0000=ooooo`;o00008?ooool2o`0000Cooooo0_l0000_ooooo`007_ooool00ol0003o
ooooooooo`0fooooo`;o0000?_ooool2o`0001Wooooo0_l0000aooooo`;o0000D?ooool2o`0002oo
oooo000Nooooo`03o`000?oooooooooo03Cooooo0_l0000@ooooo`;o0000R?ooool2o`0001?ooooo
0_l0001Pooooo`007_ooool00ol0003oooooooooo`0dooooo`;o00004?ooool2o`0000gooooo0_l0
001gooooo`Co00004oooool2o`0000Gooooo0_l0001Iooooo`007_ooool00ol0003oooooooooo`0n
ooooo`;o00005Oooool2o`0007Oooooo0_l0000Looooo`;o00009?ooool2o`0003?ooooo000Noooo
o`03o`000?oooooooooo03kooooo0_l0000Sooooo`;o0000=Oooool2o`0006Wooooo0_l0000;oooo
o`;o0000<oooool001kooooo00?o0000ooooooooool0Hoooool2o`0003Gooooo0_l0001Yooooo`;o
00004?ooool2o`0000[ooooo0_l0000Rooooo`007_ooool00ol0003oooooooooo`1[ooooo`;o0000
4?ooool2o`0009Sooooo0_l0000:ooooo`;o00008_ooool001kooooo00?o0000ooooooooool0Jooo
ool2o`00013ooooo0_l0001Nooooo`;o00003Oooool2o`0005Wooooo000Nooooo`03o`000?oooooo
oooo04?ooooo0_l00004ooooo`Co00006oooool2o`0007?ooooo0_l0000=ooooo`;o0000;oooool2
o`0002Sooooo000Nooooo`;o00005?ooool2o`0002kooooo0_l00004ooooo`Co00006oooool2o`00
04;ooooo0_l00016ooooo`;o00004Oooool2o`0001Cooooo0_l0000Xooooo`007_ooool00ol0003o
ooooooooo`0Cooooo`;o0000<_ooool2o`00053ooooo0_l0000Aooooo`;o00004_ooool2o`0003;o
oooo0_l0000Aooooo`;o0000?_ooool001kooooo00?o0000ooooooooool0Aoooool2o`0000cooooo
0_l00012ooooo`;o00009Oooool2o`0004cooooo0_l000000ooooooo0000o`00000dooooo`007_oo
ool00ol0003oooooooooo`18ooooo`;o00000_ooool2o`0000Oooooo0_l0000<ooooo`;o0000:?oo
ool2o`0004?ooooo0_l0000jooooo`;o000000?oooooo`000?l000002?ooool2o`0002[ooooo000N
ooooo`03o`000?oooooooooo03?ooooo0_l0000Cooooo`;o00000_ooool2o`000003ooooool0003o
000001;ooooo0_l0000Xooooo`;o00006?ooool2o`0000Cooooo0_l00003ooooo`;o00007_ooool2
o`0004Oooooo0_l00008ooooo`;o00002?ooool2o`0001Kooooo000Nooooo`03o`000?oooooooooo
02Oooooo0_l0000:ooooo`;o00002_ooool2o`0000kooooo0_l0001=ooooo`;o00001oooool2o`00
00Cooooo0_l00003ooooo`;o00004Oooool2o`0005kooooo0_l00008ooooo`;o00005_ooool001ko
oooo00?o0000ooooooooool08oooool2o`0000;ooooo0_l0000Fooooo`;o00001_ooool2o`0005Go
oooo0_l0000Mooooo`;o00001_ooool2o`0002;ooooo0_l0000nooooo`;o00007?ooool001kooooo
0_l00006ooooo`;o00007?ooool2o`0000gooooo0_l0000Cooooo`;o0000M?ooool2o`0000Cooooo
0_l0000Tooooo`;o0000?_ooool2o`0001cooooo000Nooooo`;o00001_ooool2o`0001oooooo0_l0
000:ooooo`;o00003_ooool2o`0006?ooooo0_l0000Fooooo`;o00000_ooool2o`0000_ooooo0_l0
001eooooo`007_ooool00ol0003oooooooooo`0Vooooo`;o00006_ooool2o`0006?ooooo0_l0000F
ooooo`;o00003oooool2o`0007Gooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l0002<oooo
o`;o00005oooool2o`0000Wooooo0_l00005ooooo`;o0000Foooool2o`0000Sooooo000Nooooo`03
o`000?oooooooooo01kooooo0_l00007ooooo`;o00002Oooool2o`00087ooooo0_l0000Gooooo`;o
00002Oooool2o`0000Gooooo0_l00009ooooo`;o0000Coooool3o`0000Sooooo000Nooooo`03o`00
0?oooooooooo01kooooo0_l0000Booooo`;o0000;Oooool2o`0006Cooooo0_l0000Rooooo`;o0000
Coooool2o`0000Wooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l00008ooooo`;o0000?ooo
ool2o`0003Sooooo0_l0000Vooooo`;o00000_ooool2o`0004;ooooo0_l0000jooooo`000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0
1_ooool00ol0003oooooooooo`0Fooooo`;o00002?ooool2o`0004Cooooo0_l0000Jooooo`;o0000
5oooool2o`0002Kooooo0_l00016ooooo`;o0000>_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000oooooooo
ool0I_ooool2o`0001[ooooo0_l0000?ooooo`;o00004?ooool2o`0003cooooo0_l0001<ooooo`;o
00005?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool000001_ooool3o`0009?ooooo0_l0000<ooooo`;o00000_ooool2o`0003cooooo0_l00003oooo
o`;o0000;?ooool2o`0001Wooooo0_l0000Dooooo`000oooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0:7ooooo0_l00015
ooooo`;o0000;?ooool2o`0002oooooo0003ooooo`05o`000?ooooooooooooooool000002oooool0
1Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0Coooool2o`0003;ooooo0_l0
001@ooooo`;o00003?ooool2o`0000_ooooo0_l00018ooooo`;o00002oooool000?ooooo00Go410@
oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool04_oo
ool2o`0000gooooo0_l0000/ooooo`;o0000<_ooool2o`00053ooooo0_l0000<ooooo`;o00002ooo
ool2o`0004Sooooo0_l0000;ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o
gMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0Booooo`;o00003Oooool2o`000?oooooo9Ooo
ool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo
00?o0000ooooooooool07Oooool2o`0007Sooooo0_l0002^ooooo`007_ooool00ol0003ooooooooo
o`0Mooooo`;o00001oooool2o`00027ooooo0_l00013ooooo`;o00001oooool2o`000:kooooo000N
ooooo`03o`000?oooooooooo01Gooooo0_l00003ooooo`;o00001?ooool2o`0000Cooooo0_l0000>
ooooo`;o00004Oooool2o`0004?ooooo0_l0001Hooooo`;o0000GOooool001kooooo00?o0000oooo
ooooool05Oooool2o`0000?ooooo0_l00004ooooo`;o00005?ooool2o`00063ooooo0_l0001>oooo
o`;o0000C_ooool2o`0000gooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l0001Fooooo`;o
00009Oooool2o`0000oooooo0_l0000Iooooo`;o0000L_ooool2o`0000gooooo000Nooooo`03o`00
0?oooooooooo01Wooooo0_l0001Fooooo`;o0000=_ooool2o`0001Wooooo0_l0000eooooo`;o0000
B_ooool001kooooo00?o0000ooooooooool0E?ooool2o`0005?ooooo0_l0001@ooooo`;o0000B_oo
ool001kooooo00?o0000ooooooooool0E?ooool2o`000?7ooooo000Nooooo`03o`000?oooooooooo
00gooooo0_l0000Vooooo`;o0000A_ooool2o`000<Sooooo000Nooooo`03o`000?oooooooooo00go
oooo0_l0000Vooooo`;o0000A_ooool2o`0004_ooooo0_l0001kooooo`007_ooool00ol0003ooooo
ooooo`3:ooooo`;o00003oooool2o`0000Gooooo0_l0001Sooooo`007_ooool00ol0003ooooooooo
o`1booooo`;o0000Ioooool2o`0000Gooooo0_l0001Sooooo`007_ooool2o`0003Gooooo0_l0000l
ooooo`;o0000HOooool2o`00067ooooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`0doooo
o`;o00001oooool2o`0006[ooooo0_l0000Zooooo`;o00008_ooool2o`0003gooooo0_l0000=oooo
o`007_ooool00ol0003oooooooooo`0mooooo`?o0000B?ooool2o`0000cooooo0_l0000Aooooo`;o
0000=oooool2o`0001Gooooo0_l0001<ooooo`007_ooool00ol0003oooooooooo`0Rooooo`;o0000
6_ooool2o`0001Kooooo0_l0000`ooooo`;o00003?ooool2o`0002_ooooo0_l0000Mooooo`;o0000
FOooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo02;ooooo0_l0000booooo`;o0000?_oo
ool2o`0002_ooooo1?l0001fooooo`;o00002?ooool001kooooo00?o0000ooooooooool0J?ooool2
o`0000Kooooo0_l0000Tooooo`;o0000;Oooool2o`00033ooooo0_l0000>ooooo`;o00000oooool2
o`0003Wooooo000Nooooo`03o`000?oooooooooo06Sooooo0_l000000ooooooo0000o`000003oooo
o`;o0000Joooool2o`0001Sooooo0_l0000>ooooo`;o00000oooool2o`0003Wooooo000Nooooo`03
o`000?oooooooooo06_ooooo0_l0001`ooooo`;o0000J?ooool001kooooo00?o0000ooooooooool0
Z?ooool2o`0004Oooooo0_l0001Dooooo`007_ooool00ol0003oooooooooo`1nooooo`;o0000:?oo
ool2o`0004Oooooo0_l0001Dooooo`007_ooool01?l0003oooooooooooooool2o`0002Wooooo0_l0
001@ooooo`;o0000<oooool2o`0009;ooooo000Nooooo`04o`000?ooooooooooooooo`;o0000:Ooo
ool2o`0008Gooooo0_l0002Booooo`007_ooool00ol0003oooooooooo`0Nooooo`;o0000N?ooool2
o`00073ooooo0_l0000Dooooo`;o00009Oooool001kooooo00?o0000ooooooooool06_ooool2o`00
00;ooooo0_l0000Jooooo`;o0000G?ooool2o`00073ooooo0_l0000Dooooo`;o00009Oooool001ko
oooo00?o0000ooooooooool06_ooool2o`0001Gooooo0_l00007ooooo`;o000000?oooooo`000?l0
00005?ooool2o`000?;ooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0000Vooooo`;o0000
2_ooool2o`0001Cooooo0_l0001Iooooo`;o0000Uoooool001kooooo0_l0000:ooooo`;o0000;Ooo
ool2o`0001[ooooo0_l0001Hooooo`;o0000?Oooool2o`0003Gooooo0_l0000Qooooo`007_ooool0
0ol0003oooooooooo`0hooooo`;o00006_ooool2o`0002;ooooo0_l0001?ooooo`;o00008_ooool2
o`0002gooooo0_l00006ooooo`;o00008Oooool001kooooo00?o0000ooooooooool0:_ooool2o`00
04Cooooo0_l00006ooooo`;o0000Coooool2o`00013ooooo0_l0000oooooo`;o0000:Oooool001ko
oooo00?o0000ooooooooool06?ooool2o`00013ooooo0_l0000gooooo`;o00002oooool2o`0006Wo
oooo0_l0001Zooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o0000BOooool2o`00067ooooo
0_l0000Iooooo`;o0000I?ooool001kooooo00?o0000ooooooooool0Koooool2o`0004;ooooo0_l0
000Aooooo`;o00006Oooool2o`0006Cooooo000Nooooo`03o`000?oooooooooo04gooooo0_l0000P
ooooo`;o0000=?ooool2o`0000cooooo0_l00026ooooo`;o00002_ooool001kooooo00?o0000oooo
ooooool0COooool2o`0000Kooooo0_l0001>ooooo`;o0000C_ooool2o`0004Cooooo0_l0000:oooo
o`007_ooool00ol0003oooooooooo`1=ooooo`;o00001_ooool2o`0006oooooo0_l0000Fooooo`;o
00005Oooool2o`00053ooooo000Nooooo`03o`000?oooooooooo02gooooo0_l0000Nooooo`;o0000
6Oooool2o`0004Cooooo0_l0000Fooooo`;o00005_ooool2o`0000Cooooo0_l0000?ooooo`;o0000
D?ooool001kooooo00?o0000ooooooooool0;Oooool2o`0003Wooooo0_l00014ooooo`;o0000=?oo
ool2o`00067ooooo000Nooooo`03o`000?oooooooooo03Kooooo0_l0000>ooooo`;o0000Uoooool2
o`0005gooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`0Looooo`;o00004?ooool2o`00
00Kooooo0_l0000>ooooo`;o00005?ooool2o`0001Gooooo0_l0000Pooooo`;o0000B?ooool2o`00
01Kooooo0_l0000Xooooo`;o00006oooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo01co
oooo0_l0000@ooooo`;o00002_ooool2o`0000gooooo0_l0000<ooooo`;o00000oooool2o`0001Go
oooo0_l0000Oooooo`?o0000=Oooool2o`0002Wooooo0_l0000Xooooo`;o00009?ooool001kooooo
00?o0000ooooooooool0>_ooool2o`0000Gooooo0_l00006ooooo`;o00003?ooool2o`0002Oooooo
0_l0000Booooo`;o0000=_ooool2o`0007Wooooo000Nooooo`03o`000?oooooooooo047ooooo0_l0
000mooooo`;o0000??ooool2o`0000Kooooo0_l0000;ooooo`;o0000L_ooool001kooooo0_l0001a
ooooo`;o0000C?ooool2o`0000Kooooo0ol0000:ooooo`;o0000L_ooool001kooooo00?o0000oooo
ooooool0??ooool2o`00027ooooo0_l0000?ooooo`;o0000>Oooool2o`0001[ooooo0_l0000[oooo
o`;o0000BOooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo03cooooo0_l0000Qooooo`;o
00004oooool2o`0003Gooooo0_l00017ooooo`;o00005?ooool2o`0003?ooooo0_l00006ooooo`00
7_ooool00ol0003oooooooooo`1dooooo`;o0000P?ooool2o`0001;ooooo0_l0000Kooooo`;o0000
7_ooool001kooooo00?o0000ooooooooool06Oooool2o`0000Kooooo0_l00026ooooo`;o00005Ooo
ool2o`0003Cooooo0_l0000[ooooo`;o00000_ooool2o`0000;ooooo0_l0000Jooooo`007Oooool2
o`0001_ooooo0_l00006ooooo`;o00005_ooool2o`0002Sooooo0_l00014ooooo`;o00005Oooool2
o`00067ooooo0_l00006ooooo`;o00006_ooool001gooooo0_l0000Sooooo`;o00005_ooool2o`00
02Sooooo0_l0001^ooooo`;o00008?ooool2o`00053ooooo000Nooooo`03o`000?oooooooooo02ko
oooo0_l0001_ooooo`?o0000<Oooool2o`00023ooooo0_l0000@ooooo`;o0000<Oooool2o`0000_o
oooo000Nooooo`03o`000?oooooooooo02kooooo0_l0001Sooooo`;o00002_ooool3o`0006Gooooo
0_l0000aooooo`;o00002oooool001kooooo00?o0000ooooooooool0Toooool2o`0005_ooooo0_l0
000oooooo`;o00005?ooool001kooooo00?o0000ooooooooool0I_ooool2o`0008Sooooo0_l0000/
ooooo`;o00004Oooool2o`0001Cooooo000Nooooo`03o`000?oooooooooo06?ooooo0_l000000ooo
oooo0000o`00000jooooo`;o00005_ooool2o`0000gooooo0_l0001Cooooo`;o00009oooool001ko
oooo00?o0000ooooooooool0;_ooool2o`0003?ooooo0_l0000mooooo`;o00002_ooool2o`0000[o
oooo0_l0000=ooooo`;o0000@?ooool2o`0003[ooooo000Nooooo`03o`000?oooooooooo00kooooo
0_l0000Nooooo`;o0000GOooool2o`0001oooooo0_l0001Kooooo`;o0000>_ooool000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Ko
oooo00?o0000ooooooooool03_ooool2o`0005Oooooo0_l0000Iooooo`;o00002Oooool2o`0002Co
oooo0_l0002Booooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`19ooooo`;o00007?ooool2o`00
00cooooo0_l00006ooooo`;o00000oooool2o`0002Kooooo0_l00007ooooo`;o0000;_ooool2o`00
06;ooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo
000000Kooooo0ol00019ooooo`;o0000:_ooool2o`0000Kooooo0_l0000[ooooo`;o0000=Oooool4
o`00033ooooo0_l0000`ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8b
oiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooooooo02[ooooo0_l00012ooooo`;o0000LOoo
ool2o`0003;ooooo0_l0000`ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go
c<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo02[ooooo0_l00012ooooo`;o0000
eoooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
41001_ooool00ol0003oooooooooo`17ooooo`;o0000D_ooool2o`000:[ooooo0003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000oooo
ooooool0Aoooool2o`0000;ooooo0_l0001>ooooo`;o00009Oooool2o`0007Gooooo0_l0000<oooo
o`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06
ooooo`03o`000?oooooooooo04_ooooo0_l0001Dooooo`;o00004oooool2o`0000[ooooo0_l0000X
ooooo`;o0000;_ooool2o`0001_ooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`0Voooo
o`Co0000A?ooool2o`00037ooooo0_l0000Cooooo`;o0000<_ooool4o`0002?ooooo0_l00009oooo
o`;o0000:Oooool001kooooo00?o0000ooooooooool05Oooool2o`0000oooooo1?l00014ooooo`;o
00006?ooool2o`0001_ooooo0_l00013ooooo`;o00009Oooool2o`0003Cooooo000Nooooo`03o`00
0?oooooooooo01Gooooo0_l0001Wooooo`;o00002?ooool2o`0001_ooooo0_l00002ooooo`;o0000
6Oooool2o`0003gooooo0_l0000;ooooo`;o0000=Oooool001kooooo00?o0000ooooooooool0O_oo
ool2o`0002Wooooo0_l0000Aooooo`;o00001_ooool2o`0003gooooo0_l0000;ooooo`;o0000=Ooo
ool001kooooo00?o0000ooooooooool0P?ooool4o`0003Sooooo0_l00009ooooo`;o00008oooool2
o`0005Wooooo000Nooooo`03o`000?oooooooooo077ooooo0_l0000=ooooo`Co0000@oooool2o`00
02?ooooo0_l0001Iooooo`007_ooool00ol0003oooooooooo`1Uooooo`;o00002_ooool2o`0000Go
oooo0_l0003=ooooo`007_ooool00ol0003oooooooooo`1Uooooo`;o00002_ooool2o`0000Gooooo
0_l0000Wooooo`;o0000Y?ooool001kooooo00?o0000ooooooooool0WOooool2o`0000;ooooo0_l0
0005ooooo`;o0000WOooool001kooooo00?o0000ooooooooool0Poooool2o`0001Sooooo0_l00009
ooooo`;o00003?ooool2o`0000Wooooo0_l0000^ooooo`;o0000E?ooool001kooooo00?o0000oooo
ooooool05_ooool2o`0002Kooooo0_l00013ooooo`;o0000<Oooool2o`0000Wooooo0_l0000Ooooo
o`;o00003Oooool2o`0001Kooooo0_l0000looooo`007_ooool3o`00017ooooo0_l00003ooooo`;o
00009_ooool2o`0004gooooo0_l0000dooooo`;o00007Oooool2o`0000cooooo0_l0000Gooooo`;o
0000;oooool2o`0000_ooooo000Nooooo`?o00000_ooool2o`0000gooooo0_l0000=ooooo`;o0000
2oooool2o`0003Sooooo0_l0000Dooooo`;o00003_ooool2o`0003Cooooo0_l00006ooooo`;o0000
2?ooool2o`0001Wooooo0_l00018ooooo`;o00002oooool001kooooo00?o0000ooooooooool00_oo
ool2o`0001cooooo0_l0000;ooooo`;o0000>?ooool2o`0000?ooooo0_l0000?ooooo`;o0000=ooo
ool2o`0001?ooooo0_l00008ooooo`;o0000L?ooool001kooooo00?o0000ooooooooool0K?ooool2
o`0004Sooooo0_l0002?ooooo`007_ooool00ol0003oooooooooo`0Vooooo`;o00004?ooool2o`00
013ooooo0_l0002gooooo`;o0000@_ooool001kooooo00?o0000ooooooooool09_ooool2o`00013o
oooo0_l0000@ooooo`;o0000]oooool2o`0004;ooooo000Nooooo`03o`000?oooooooooo01Kooooo
0_l0000Vooooo`;o0000M?ooool2o`0007Oooooo0_l0000Hooooo`007_ooool00ol0003ooooooooo
o`0Fooooo`;o00009_ooool2o`00043ooooo0_l0000booooo`;o0000H?ooool2o`0001Gooooo0_l0
000Hooooo`007_ooool00ol0003oooooooooo`1?ooooo`;o0000;oooool2o`00033ooooo0_l0000c
ooooo`;o00007Oooool2o`0000kooooo0_l0000?ooooo`;o00007_ooool001kooooo00?o0000oooo
ooooool06Oooool2o`0003Cooooo0_l0001Qooooo`;o00009?ooool2o`0000gooooo0_l0000Moooo
o`;o00007oooool2o`0001kooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0000=ooooo`;o
0000]?ooool2o`0000Oooooo0_l0001Mooooo`;o00001_ooool2o`0000Kooooo000Nooooo`03o`00
0?oooooooooo00[ooooo0_l00033ooooo`;o0000I_ooool2o`0000Kooooo0_l00006ooooo`007_oo
ool00ol0003oooooooooo`0@ooooo`;o0000;?ooool2o`000?oooooo2?ooool001kooooo00?o0000
ooooooooool04?ooool2o`0000oooooo0_l0000Kooooo`Co0000B_ooool2o`000:?ooooo0_l0000D
ooooo`007_ooool00ol0003oooooooooo`0Qooooo`;o00007Oooool2o`0004[ooooo0_l0002Soooo
o`;o00005?ooool001kooooo00?o0000ooooooooool0@_ooool2o`0002Gooooo0_l0001Uooooo`;o
0000MOooool001kooooo0_l00013ooooo`;o00009Oooool2o`0004oooooo0_l0000Dooooo`;o0000
I?ooool2o`0000oooooo000Nooooo`04o`000?ooooooooooooooo`;o00006Oooool2o`0001Gooooo
0_l00016ooooo`;o0000?Oooool2o`0004cooooo0_l0000/ooooo`;o00003oooool001kooooo00Co
0000oooooooooooooooo0_l0000Iooooo`;o00001oooool2o`0000cooooo1?l00014ooooo`;o0000
E_ooool2o`00013ooooo0_l00007ooooo`;o00006?ooool2o`0000kooooo0_l0000]ooooo`007_oo
ool00ol0003oooooooooo`0Uooooo`;o00003_ooool2o`0006Sooooo0_l0000=ooooo`?o00003?oo
ool2o`0000Oooooo0_l0000;ooooo`;o00004?ooool2o`0000Oooooo0_l0000Xooooo`;o0000;Ooo
ool001kooooo00?o0000ooooooooool03oooool2o`0008kooooo0_l0000=ooooo`?o00003?ooool2
o`0000Oooooo0_l0001oooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o0000;?ooool2o`00
03Sooooo0_l0000Kooooo`;o0000/Oooool001kooooo00?o0000ooooooooool0=oooool2o`0000;o
oooo1?l0000Gooooo`;o00007oooool2o`0001_ooooo0_l0002aooooo`007_ooool00ol0003ooooo
ooooo`0gooooo`;o00000_ooool2o`0001Wooooo0_l0003_ooooo`007_ooool00ol0003ooooooooo
o`1=ooooo`;o0000ioooool2o`0000oooooo000Nooooo`04o`000?ooooooooooooooo`;o0000B_oo
ool2o`00073ooooo0_l0001eooooo`;o00003oooool001kooooo00Co0000oooooooooooooooo0_l0
0016ooooo`;o0000M?ooool2o`0008Kooooo000Nooooo`03o`000?oooooooooo01Sooooo0_l0000I
ooooo`;o00005?ooool2o`0002Wooooo0_l00006ooooo`;o0000bOooool001kooooo00?o0000oooo
ooooool02oooool2o`0000_ooooo0_l0000Iooooo`;o0000;oooool2o`0000kooooo0_l00006oooo
o`;o00004_ooool2o`0001cooooo0_l0002Gooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o
0000Doooool2o`0000;ooooo0_l0000Zooooo`;o00007?ooool2o`0000Wooooo0_l00025ooooo`;o
00001Oooool001kooooo00?o0000ooooooooool0@Oooool2o`0001gooooo0_l0001>ooooo`;o0000
1oooool2o`0000?ooooo0_l0000<ooooo`;o0000L_ooool2o`0000Gooooo000Nooooo`03o`000?oo
oooooooo00;o0000?oooool2o`0006gooooo0_l0000<ooooo`;o00003?ooool2o`0007Wooooo000N
ooooo`;o000000?oooooo`000?l00000BOooool2o`0006Gooooo0ol00002ooooo`;o0000S_ooool0
01kooooo00?o0000ooooooooool0BOooool4o`0000[ooooo0_l0001Iooooo`?o00000_ooool2o`00
01Gooooo0_l0000Gooooo`;o0000G_ooool001kooooo00?o0000ooooooooool0BOooool2o`0000co
oooo0_l0001eooooo`;o00005oooool2o`0005kooooo000Nooooo`03o`000?oooooooooo04[ooooo
0_l0001Tooooo`;o00005Oooool2o`0007kooooo000Nooooo`03o`000?oooooooooo04[ooooo0_l0
001Tooooo`;o00005Oooool2o`0007kooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0FOooool2o`0003;ooooo0_l0000@ooooo`;o0000>_ooool2o`00
06[ooooo000Nooooo`03o`000?oooooooooo05Wooooo0_l0000booooo`;o00001Oooool2o`0000Wo
oooo0_l0000jooooo`;o00009?ooool2o`0002Cooooo0_l00005ooooo`;o00005oooool001kooooo
00?o0000ooooooooool00_ooool2o`00093ooooo0_l0001[ooooo`;o00008oooool3o`0000Gooooo
0_l0000Gooooo`007_ooool00ol0003oooooooooo`04o`00047ooooo0_l0001Yooooo`;o0000M?oo
ool2o`00013ooooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`02o`0004?ooooo0_l0001Y
ooooo`;o00004?ooool2o`0006;ooooo0_l0000@ooooo`;o00003Oooool001kooooo00?o0000oooo
ooooool0`_ooool4o`00063ooooo0_l0000Iooooo`;o00001?ooool001kooooo00?o0000oooooooo
ool0a?ooool2o`0007[ooooo0ol00004ooooo`007_ooool00ol0003oooooooooo`0Qooooo`;o0000
Zoooool2o`0003_ooooo0_l0000cooooo`;o00001Oooool001Cooooo1?l000000ol@413ooooooooo
o`03ooooo`03o`000?oooooooooo027ooooo0_l0000mooooo`;o0000?_ooool2o`0002[ooooo1?l0
000aooooo`;o00002?ooool2o`0002oooooo0_l00009ooooo`005_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo063ooooo0_l0000nooooo`;o0000:_ooool2o`0002Gooooo0_l0000<
ooooo`;o00001Oooool2o`0003;ooooo0_l00009ooooo`005_ooool00ol0003oooooooooo`05oooo
o`?o00007_ooool2o`000=?ooooo0_l0000Cooooo`;o0000?Oooool001Kooooo00?o0000oooooooo
ool09_ooool2o`000?oooooo:?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_oo
ool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool0
01Cooooo00?oEEEEofIVI_l00000oooooomBooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.10725 .37303 Mdot
.14444 .84086 Mdot
.98725 .0814 Mdot
.36811 .76698 Mdot
.1684 .31117 Mdot
.95033 .23715 Mdot
.05989 .0719 Mdot
.14371 .58369 Mdot
.98227 5e-05 Mdot
.26518 .01484 Mdot
.60123 .94604 Mdot
.07158 .67892 Mdot
.59291 .38641 Mdot
.43833 .36282 Mdot
.42387 .36218 Mdot
.37907 .61267 Mdot
.54002 .95453 Mdot
.29792 .37305 Mdot
.68195 .00073 Mdot
.90509 .80029 Mdot
.51486 .94081 Mdot
.38696 .07568 Mdot
.94828 .13226 Mdot
.12382 .54605 Mdot
.7909 .40096 Mdot
.2969 .44255 Mdot
.81762 .802 Mdot
.65693 .39719 Mdot
.36745 .76986 Mdot
.25509 .11138 Mdot
.71545 .06286 Mdot
.37681 .23952 Mdot
.55244 .12764 Mdot
.10471 .12753 Mdot
.78131 .20534 Mdot
.91862 .68855 Mdot
.30845 .08426 Mdot
.3997 .42408 Mdot
.16369 .22374 Mdot
.0433 .92623 Mdot
.98233 .25596 Mdot
.39674 .86348 Mdot
.33107 .3045 Mdot
.23207 .31217 Mdot
.78317 .27868 Mdot
.63813 .58738 Mdot
.8472 .10671 Mdot
.60658 .86055 Mdot
.15968 .27578 Mdot
.13963 .1864 Mdot
.87888 .04923 Mdot
.50861 .55654 Mdot
.0898 .81556 Mdot
.00149 .38461 Mdot
.91548 .47877 Mdot
.90116 .08257 Mdot
.61617 .98488 Mdot
.0763 .75466 Mdot
.23363 .38896 Mdot
.11975 .84088 Mdot
.14898 .34545 Mdot
.84916 .80762 Mdot
.24174 .97779 Mdot
.35204 .48068 Mdot
.9856 .44557 Mdot
.31778 .04486 Mdot
.27522 .83828 Mdot
.6115 .01887 Mdot
.1372 .20402 Mdot
.94021 .13731 Mdot
.84677 .78479 Mdot
.93163 .30916 Mdot
.10806 .63199 Mdot
.27873 .79204 Mdot
.33915 .34013 Mdot
.74096 .19183 Mdot
.96776 .73826 Mdot
.19381 .26245 Mdot
.75476 .76689 Mdot
.2821 .29277 Mdot
.51072 .72604 Mdot
.66693 .99306 Mdot
.20993 .91229 Mdot
.79322 .45102 Mdot
.72221 .49953 Mdot
.81429 .07374 Mdot
.463 .1127 Mdot
.02596 .61091 Mdot
.55108 .95995 Mdot
.61284 .55085 Mdot
.07594 .89716 Mdot
.57183 .35936 Mdot
.19563 .6392 Mdot
.72409 .29069 Mdot
.10226 .52778 Mdot
.35912 .5642 Mdot
.21717 .18232 Mdot
.74925 .40016 Mdot
.58238 .22414 Mdot
.24668 .9273 Mdot
.54462 .36147 Mdot
.76766 .5407 Mdot
.88089 .89164 Mdot
.29251 .34299 Mdot
.65062 .656 Mdot
.18867 .7732 Mdot
.52967 .01962 Mdot
.91306 .42832 Mdot
.17325 .9433 Mdot
.44058 .76049 Mdot
.41416 .4002 Mdot
.88553 .85368 Mdot
.8337 .45724 Mdot
.28855 .42103 Mdot
.14822 .55466 Mdot
.50369 .76032 Mdot
.37095 .67207 Mdot
.02134 .86351 Mdot
.69102 .59869 Mdot
.57466 .7949 Mdot
.739 .40213 Mdot
.56094 .19877 Mdot
.10526 .66044 Mdot
.30456 .91179 Mdot
.45302 .46197 Mdot
.97523 .50413 Mdot
.62586 .38954 Mdot
.6746 .75774 Mdot
.58879 .75755 Mdot
.70973 .97249 Mdot
.58235 .07532 Mdot
.10052 .60461 Mdot
.1788 .51777 Mdot
.51126 .66969 Mdot
.13691 .51805 Mdot
.23628 .38675 Mdot
.39765 .94833 Mdot
.05806 .27308 Mdot
.57393 .73645 Mdot
.41409 .17178 Mdot
.23562 .16353 Mdot
.97704 .18891 Mdot
.84361 .758 Mdot
.03585 .36452 Mdot
.62622 .34934 Mdot
.34781 .7165 Mdot
.70378 .76569 Mdot
.00982 .26411 Mdot
.26985 .40491 Mdot
.03191 .22006 Mdot
.21708 .70001 Mdot
.39679 .27923 Mdot
.9102 .24563 Mdot
.83335 .89031 Mdot
.09774 .36697 Mdot
.68624 .53761 Mdot
.24715 .51064 Mdot
.54439 .47345 Mdot
.5847 .78361 Mdot
.12539 .57974 Mdot
.51313 .37955 Mdot
.08738 .04681 Mdot
.98575 .10863 Mdot
.98913 .2427 Mdot
.86508 .5858 Mdot
.30934 .82536 Mdot
.88431 .71394 Mdot
.375 .46074 Mdot
.5267 .5313 Mdot
.06027 .85243 Mdot
.96267 .41155 Mdot
.59197 .34278 Mdot
.38536 .10965 Mdot
.31972 .33663 Mdot
.61024 .37953 Mdot
.52123 .17067 Mdot
.35216 .65979 Mdot
.4541 .56207 Mdot
.29455 .2939 Mdot
.07444 .27488 Mdot
.02104 .40284 Mdot
.87592 .31135 Mdot
.9296 .69907 Mdot
.16157 .14941 Mdot
.73373 .39452 Mdot
.90419 .46622 Mdot
.31757 .25389 Mdot
.46146 .22644 Mdot
.53525 .50745 Mdot
.27374 .65042 Mdot
.34532 .15256 Mdot
.22014 .53896 Mdot
.64028 .66505 Mdot
.96033 .25805 Mdot
.20562 .00603 Mdot
.67596 .24503 Mdot
.56762 .43031 Mdot
.52764 .36097 Mdot
.29736 .21316 Mdot
.24088 .11777 Mdot
.15453 .68622 Mdot
.25681 .34122 Mdot
.84882 .44781 Mdot
.14004 .65274 Mdot
.01559 .55043 Mdot
.3316 .44473 Mdot
.20469 .4027 Mdot
.55849 .30338 Mdot
.55433 .19016 Mdot
.82858 .40717 Mdot
.41015 .1305 Mdot
.50176 .02519 Mdot
.8224 .99838 Mdot
.66231 .46374 Mdot
.48831 .55419 Mdot
.74014 .4965 Mdot
.05032 .99168 Mdot
.34627 .15097 Mdot
.21909 .49568 Mdot
.89705 .86262 Mdot
.85608 .58486 Mdot
.50834 .54272 Mdot
.46238 .84057 Mdot
.94456 .09915 Mdot
.45002 .65574 Mdot
.34133 .7968 Mdot
.9268 .27684 Mdot
.65832 .95096 Mdot
.59167 .74333 Mdot
.36349 .81404 Mdot
.49572 .08054 Mdot
.85939 .19926 Mdot
.22526 .55605 Mdot
.8483 .6833 Mdot
.00193 .61334 Mdot
.77933 .70634 Mdot
.5192 .86528 Mdot
.56259 .8808 Mdot
.61764 .90489 Mdot
.00012 .86475 Mdot
.09612 .86397 Mdot
.95945 .26937 Mdot
.87407 .56605 Mdot
.77765 .21172 Mdot
.40137 .81398 Mdot
.79276 .06634 Mdot
.47064 .00843 Mdot
.85706 .57984 Mdot
.91787 .16233 Mdot
.19758 .65084 Mdot
.01624 .29179 Mdot
.70414 .80679 Mdot
.32648 .51979 Mdot
.71271 .45538 Mdot
.43945 .79634 Mdot
.94299 .43836 Mdot
.87356 .14635 Mdot
.02983 .0993 Mdot
.21067 .16666 Mdot
.09003 .78386 Mdot
.4086 .53205 Mdot
.18028 .44787 Mdot
.42792 .48264 Mdot
.60551 .6309 Mdot
.16804 .67527 Mdot
.81954 .47429 Mdot
.49305 .79032 Mdot
.36164 .74835 Mdot
.57016 .87358 Mdot
.73914 .24763 Mdot
.68125 .70758 Mdot
.99619 .46826 Mdot
.65825 .13835 Mdot
.2419 .10012 Mdot
.28666 .42163 Mdot
.96451 .60675 Mdot
.23766 .49147 Mdot
.95123 .23708 Mdot
.47978 .66636 Mdot
.67661 .10794 Mdot
.20391 .03822 Mdot
.83479 .50219 Mdot
.09332 .88326 Mdot
.86919 .13579 Mdot
.78637 .42783 Mdot
.45609 .86599 Mdot
.68649 .55768 Mdot
.7661 .46924 Mdot
.77971 .70282 Mdot
.93624 .79294 Mdot
.41342 .12002 Mdot
.28327 .16268 Mdot
.3859 .09595 Mdot
.12467 .71829 Mdot
.71982 .84109 Mdot
.46121 .34772 Mdot
.07581 .03938 Mdot
.96024 .4426 Mdot
.85977 .40023 Mdot
.30433 .23317 Mdot
.19566 .56507 Mdot
.81992 .15923 Mdot
.0519 .56561 Mdot
.60118 .71705 Mdot
.58502 .05248 Mdot
.19191 .31233 Mdot
.24404 .76939 Mdot
.54215 .2121 Mdot
.12593 .16981 Mdot
.21187 .54666 Mdot
.45409 .51819 Mdot
.87365 .55182 Mdot
.64116 .43593 Mdot
.3182 .71177 Mdot
.17991 .7386 Mdot
.57248 .82391 Mdot
.55276 .14007 Mdot
.33115 .50293 Mdot
.92741 .44312 Mdot
.43886 .28482 Mdot
.97254 .26753 Mdot
.49783 .74909 Mdot
.31693 .27124 Mdot
.5614 .29707 Mdot
.27432 .54667 Mdot
.5616 .21235 Mdot
.13796 .54629 Mdot
.21721 .34433 Mdot
.90357 .37462 Mdot
.69285 .85658 Mdot
.06444 .34555 Mdot
.30254 .78904 Mdot
.97883 .08788 Mdot
.75652 .7514 Mdot
.06864 .80857 Mdot
.09037 .62238 Mdot
.18292 .40958 Mdot
.1222 .27153 Mdot
.07597 .15559 Mdot
.04509 .34705 Mdot
.78111 .79556 Mdot
.54282 .04379 Mdot
.18887 .29016 Mdot
.3788 .55442 Mdot
.08505 .1663 Mdot
.53256 .17124 Mdot
.51898 .28432 Mdot
.66999 .93491 Mdot
.17691 .83743 Mdot
.5547 .58465 Mdot
.30537 .9977 Mdot
.48615 .77848 Mdot
.0112 .22389 Mdot
.62782 .6797 Mdot
.54311 .02099 Mdot
.48908 .17078 Mdot
.29885 .50747 Mdot
.0296 .97687 Mdot
.98063 .15359 Mdot
.4652 .02192 Mdot
.89229 .98154 Mdot
.50695 .26787 Mdot
.9056 .3227 Mdot
.39521 .34572 Mdot
.87647 .91752 Mdot
.68633 .08298 Mdot
.03359 .20202 Mdot
.95198 .75005 Mdot
.83283 .39811 Mdot
.99633 .70126 Mdot
.07175 .13325 Mdot
.64074 .84592 Mdot
.2697 .90894 Mdot
.88692 .59675 Mdot
.33842 .67332 Mdot
.57357 .01589 Mdot
.57127 .59709 Mdot
.01091 .38316 Mdot
.22356 .45647 Mdot
.9666 .14551 Mdot
.19016 .36073 Mdot
.19231 .4413 Mdot
.09496 .81528 Mdot
.65254 .44303 Mdot
.17579 .38807 Mdot
.7978 .8056 Mdot
.78751 .74972 Mdot
.47936 .45152 Mdot
.01265 .88348 Mdot
.16005 .36664 Mdot
.87512 .16714 Mdot
.52175 .88411 Mdot
.60456 .96062 Mdot
.22785 .21341 Mdot
.917 .77575 Mdot
.74917 .72678 Mdot
.03391 .03483 Mdot
.62491 .98602 Mdot
.21001 .91465 Mdot
.53872 .2143 Mdot
.12247 .64894 Mdot
.52914 .08792 Mdot
.33426 .72287 Mdot
.38818 .38329 Mdot
.38062 .41151 Mdot
.47329 .74601 Mdot
.64616 .79023 Mdot
.75236 .05034 Mdot
.39247 .34799 Mdot
.09633 .79975 Mdot
.1812 .77277 Mdot
.917 .57599 Mdot
.1583 .90511 Mdot
.93951 .36993 Mdot
.06344 .29707 Mdot
.3988 .39819 Mdot
.13582 .04775 Mdot
.7807 .44566 Mdot
.59558 .13373 Mdot
.69052 .85353 Mdot
.99186 .50274 Mdot
.66743 .73494 Mdot
.63501 .70066 Mdot
.40574 .42025 Mdot
.4761 .0449 Mdot
.72712 .75042 Mdot
.15531 .78364 Mdot
.07207 .55978 Mdot
.57245 .40213 Mdot
.23517 .91215 Mdot
.04688 .49294 Mdot
.09234 .46652 Mdot
.38757 .85611 Mdot
.67767 .33062 Mdot
.9592 .27439 Mdot
.08401 .4411 Mdot
.62043 .27818 Mdot
.51797 .51941 Mdot
.42379 .60046 Mdot
.25647 .00491 Mdot
.27955 .70626 Mdot
.15058 .91411 Mdot
.9663 .06308 Mdot
.23733 .95225 Mdot
.09257 .01201 Mdot
.49259 .34351 Mdot
.81567 .86512 Mdot
.31224 .17092 Mdot
.66 .84299 Mdot
.3292 .59986 Mdot
.0768 .27859 Mdot
.87285 .96024 Mdot
.80169 .27149 Mdot
.72498 .99877 Mdot
.41438 .46402 Mdot
.80027 .04092 Mdot
.61541 .80689 Mdot
.60306 .81384 Mdot
.88235 .99711 Mdot
.22993 .72274 Mdot
.34967 .35931 Mdot
.33233 .82286 Mdot
.06113 .00929 Mdot
.4158 .87699 Mdot
.23665 .51461 Mdot
.08823 .05549 Mdot
.71059 .15631 Mdot
.431 .09124 Mdot
.14578 .2133 Mdot
.91204 .2157 Mdot
.41112 .82281 Mdot
.71175 .61015 Mdot
.38846 .69366 Mdot
.0355 .07524 Mdot
.06236 .83835 Mdot
.43866 .4395 Mdot
.52011 .26983 Mdot
.67931 .57596 Mdot
.72733 .24349 Mdot
.29781 .68542 Mdot
.02625 .11873 Mdot
.92744 .28527 Mdot
.5268 .86749 Mdot
.55193 .45824 Mdot
.43187 .2147 Mdot
.40369 .2039 Mdot
.17736 .33411 Mdot
.82042 .08584 Mdot
.43963 .07064 Mdot
.55343 .59371 Mdot
.0514 .92155 Mdot
.54137 .04877 Mdot
.21089 .47924 Mdot
.52446 .99997 Mdot
.95314 .17772 Mdot
.38602 .40551 Mdot
.62187 .2042 Mdot
.83895 .05344 Mdot
.15019 .5492 Mdot
.93672 .87765 Mdot
.70502 .7981 Mdot
.39442 .44142 Mdot
.51151 .26353 Mdot
.00844 .11612 Mdot
.92545 .3407 Mdot
.44316 .22133 Mdot
.14852 .72899 Mdot
.32371 .12619 Mdot
.94608 .59667 Mdot
.16238 .75155 Mdot
.63653 .033 Mdot
.25871 .5075 Mdot
.16724 .47386 Mdot
.77647 .07169 Mdot
.63856 .08271 Mdot
.00603 .93102 Mdot
.52498 .06826 Mdot
.79296 .6989 Mdot
.71055 .16964 Mdot
.42677 .83908 Mdot
.51909 .59129 Mdot
.48946 .18933 Mdot
.7684 .51199 Mdot
.12272 .42155 Mdot
.85249 .85244 Mdot
.24046 .19129 Mdot
.20612 .50483 Mdot
.58757 .19888 Mdot
.39535 .65772 Mdot
.73031 .66213 Mdot
.70291 .64692 Mdot
.17446 .41973 Mdot
.30659 .26991 Mdot
.55598 .05432 Mdot
.23852 .65315 Mdot
.32916 .73122 Mdot
.29356 .74112 Mdot
.04767 .40246 Mdot
.21462 .44418 Mdot
.91434 .68509 Mdot
.19056 .9849 Mdot
.95509 .11616 Mdot
.55357 .14283 Mdot
.76002 .4887 Mdot
.44711 .27735 Mdot
.53723 .50101 Mdot
.00587 .51602 Mdot
.03548 .59435 Mdot
.96549 .63776 Mdot
.09909 .02421 Mdot
.76584 .33748 Mdot
.31934 .52077 Mdot
.44691 .766 Mdot
.48702 .64101 Mdot
.65402 .41568 Mdot
.77525 .27612 Mdot
.58788 .05486 Mdot
.32946 .86238 Mdot
.67335 .70615 Mdot
.2481 .25734 Mdot
.92327 .74656 Mdot
.02041 .92238 Mdot
.1784 .13175 Mdot
.28135 .70682 Mdot
.6729 .50404 Mdot
.85351 .27073 Mdot
.87462 .05551 Mdot
.0838 .20979 Mdot
.34992 .0274 Mdot
.20151 .93055 Mdot
.4527 .41659 Mdot
.94372 .96052 Mdot
.13642 .67329 Mdot
.89423 .54445 Mdot
.19398 .52924 Mdot
.6318 .06829 Mdot
.56522 .90979 Mdot
.42848 .06416 Mdot
.17565 .84552 Mdot
.56119 .09372 Mdot
.05734 .58775 Mdot
.2203 .24341 Mdot
.37273 .37789 Mdot
.07835 .16862 Mdot
.18536 .87076 Mdot
.46651 .49516 Mdot
.21124 .39595 Mdot
.63854 .52505 Mdot
.90133 .42711 Mdot
.02603 .27685 Mdot
.82606 .98746 Mdot
.70723 .16985 Mdot
.50874 .96502 Mdot
.38326 .96631 Mdot
.29202 .55637 Mdot
.5542 .78507 Mdot
.22494 .20244 Mdot
.21924 .00266 Mdot
.88762 .50408 Mdot
.17853 .76136 Mdot
.66872 .31725 Mdot
.44453 .60781 Mdot
.39843 .48338 Mdot
.46939 .58825 Mdot
.21077 .46583 Mdot
.18512 .65293 Mdot
.48199 .42792 Mdot
.9064 .89308 Mdot
.13353 .49743 Mdot
.65656 .00525 Mdot
.69984 .69634 Mdot
.34072 .32372 Mdot
.34621 .25312 Mdot
.10879 .61055 Mdot
.36569 .81403 Mdot
.67153 .15179 Mdot
.47823 .76453 Mdot
.71783 .29339 Mdot
.75851 .32583 Mdot
.73748 .22408 Mdot
.50729 .44754 Mdot
.31483 .08978 Mdot
.97017 .1093 Mdot
.7478 .84341 Mdot
.9952 .87847 Mdot
.74227 .86656 Mdot
.98447 .93625 Mdot
.98745 .50751 Mdot
.67381 .24259 Mdot
.43053 .02261 Mdot
.46047 .99123 Mdot
.53891 .58329 Mdot
.85839 .5581 Mdot
.35443 .43404 Mdot
.24969 .50307 Mdot
.95264 .44456 Mdot
.93384 .51772 Mdot
.23318 .66159 Mdot
.02582 .98837 Mdot
.5749 .95297 Mdot
.4859 .59704 Mdot
.54072 .53687 Mdot
.53789 .58408 Mdot
.18751 .89861 Mdot
.51226 .09258 Mdot
.03714 .21545 Mdot
.71277 .6031 Mdot
.04836 .42099 Mdot
.4939 .78207 Mdot
.72659 .696 Mdot
.68703 .51129 Mdot
.32604 .00591 Mdot
.16076 .5946 Mdot
.77416 .80979 Mdot
.17741 .08393 Mdot
.23904 .58451 Mdot
.54309 .21617 Mdot
.62455 .57753 Mdot
.087 .66344 Mdot
.59894 .14316 Mdot
.18308 .93837 Mdot
.37587 .12088 Mdot
.55584 .30853 Mdot
.32794 .91562 Mdot
.56874 .30381 Mdot
.40684 .42135 Mdot
.75603 .08454 Mdot
.43613 .61264 Mdot
.19116 .17594 Mdot
.51844 .04631 Mdot
.30012 .98919 Mdot
.16082 .55049 Mdot
.23882 .54855 Mdot
.53243 .48263 Mdot
.96558 .93518 Mdot
.02174 .11465 Mdot
.241 .60867 Mdot
.54205 .9444 Mdot
.55027 .77142 Mdot
.4881 .10892 Mdot
.99008 .99515 Mdot
.70187 .43153 Mdot
.63898 .62287 Mdot
.80225 .54902 Mdot
.83322 .21927 Mdot
.13561 .13731 Mdot
.55087 .20169 Mdot
.98515 .07754 Mdot
.68172 .59468 Mdot
.25477 .25151 Mdot
.98592 .76441 Mdot
.05556 .9365 Mdot
.27402 .78427 Mdot
.45884 .35366 Mdot
.71735 .41574 Mdot
.481 .67828 Mdot
.83061 .3343 Mdot
.71539 .36921 Mdot
.48731 .84163 Mdot
.4579 .35282 Mdot
.72458 .69451 Mdot
.40433 .48309 Mdot
.44292 .57867 Mdot
.92342 .72509 Mdot
.31649 .87882 Mdot
.44359 .19012 Mdot
.70757 .36858 Mdot
.56139 .35698 Mdot
.88938 .28252 Mdot
.02843 .0772 Mdot
.61134 .01109 Mdot
.57165 .52428 Mdot
.95611 .81886 Mdot
.54938 .97877 Mdot
.14465 .92271 Mdot
.3094 .16633 Mdot
.28803 .07497 Mdot
.79718 .05256 Mdot
.01013 .57448 Mdot
.11656 .5551 Mdot
.35691 .43902 Mdot
.25895 .60664 Mdot
.11776 .037 Mdot
.7286 .18906 Mdot
.39621 .67574 Mdot
.50218 .63986 Mdot
.91368 .50828 Mdot
.84321 .21295 Mdot
.79525 .9692 Mdot
.10121 .32138 Mdot
.90356 .09118 Mdot
.66644 .53894 Mdot
.91718 .95283 Mdot
.77516 .13111 Mdot
.71567 .7196 Mdot
.13208 .76534 Mdot
.93159 .19786 Mdot
.92257 .08639 Mdot
.09592 .61644 Mdot
.1533 .65984 Mdot
.64486 .04629 Mdot
.16993 .47989 Mdot
.76386 .58852 Mdot
.0555 .07108 Mdot
.81098 .9925 Mdot
.21221 .10045 Mdot
.6462 .0229 Mdot
.3585 .73173 Mdot
.68103 .93492 Mdot
.67286 .71557 Mdot
.62496 .32797 Mdot
.51956 .9815 Mdot
.4192 .45555 Mdot
.46359 .22024 Mdot
.5425 .82965 Mdot
.4343 .24648 Mdot
.57004 .80908 Mdot
.90764 .31782 Mdot
.71677 .66094 Mdot
.47656 .67449 Mdot
.06395 .52074 Mdot
.23436 .89201 Mdot
.41316 .44839 Mdot
.73681 .49663 Mdot
.2447 .85693 Mdot
.45603 .5903 Mdot
.92322 .27186 Mdot
.16153 .87831 Mdot
.45078 .12787 Mdot
.43767 .02671 Mdot
.68092 .5755 Mdot
.46872 .10505 Mdot
.37748 .71698 Mdot
.19264 .1964 Mdot
.08632 .5402 Mdot
.86008 .4548 Mdot
.58301 .5769 Mdot
.18502 .48685 Mdot
.4227 .92504 Mdot
.07967 .60525 Mdot
.1154 .76566 Mdot
.02259 .38766 Mdot
.24017 .32404 Mdot
.48283 .28472 Mdot
.07339 .49866 Mdot
.97352 .12019 Mdot
.90489 .15591 Mdot
.50469 .513 Mdot
.52512 .93893 Mdot
.19049 .41178 Mdot
.81659 .1746 Mdot
.70918 .18714 Mdot
.07207 .42682 Mdot
.77472 .63408 Mdot
.82225 .40638 Mdot
.21589 .57731 Mdot
.94168 .96856 Mdot
.28541 .17983 Mdot
.53715 .47127 Mdot
.87125 .40552 Mdot
.49291 .99399 Mdot
.66193 .10134 Mdot
.49988 .01124 Mdot
.81422 .2242 Mdot
.67604 .32422 Mdot
.14945 .26606 Mdot
.0796 .2281 Mdot
.53051 .56555 Mdot
.07053 .94231 Mdot
.63294 .38989 Mdot
.23831 .61804 Mdot
.82738 .50627 Mdot
.6975 .29142 Mdot
.96835 .73629 Mdot
.61613 .69241 Mdot
.27779 .45093 Mdot
.46437 .46034 Mdot
.14133 .3436 Mdot
.72247 .41347 Mdot
.91559 .46632 Mdot
.79066 .52294 Mdot
.55926 .45769 Mdot
.47171 .57532 Mdot
.81388 .99414 Mdot
.41724 .03331 Mdot
.57304 .47717 Mdot
.92164 .21971 Mdot
.51673 .77135 Mdot
.47911 .25775 Mdot
.26268 .64641 Mdot
.60202 .8334 Mdot
.35949 .89177 Mdot
.2712 .89578 Mdot
.10299 .40319 Mdot
.64664 .81811 Mdot
.0192 .64337 Mdot
.07079 .03021 Mdot
.55136 .55178 Mdot
.94231 .35783 Mdot
.84715 .54985 Mdot
.37115 .27315 Mdot
.01147 .95031 Mdot
.9732 .09512 Mdot
.60811 .96077 Mdot
.17 .22293 Mdot
.66013 .395 Mdot
.67503 .20841 Mdot
.11828 .14122 Mdot
.38269 .41217 Mdot
.64693 .73136 Mdot
.16578 .97665 Mdot
.46365 .46912 Mdot
.28229 .3071 Mdot
.34286 .4789 Mdot
.26353 .78575 Mdot
.84622 .53541 Mdot
.13674 .31597 Mdot
.98166 .87194 Mdot
.68201 .31639 Mdot
.98116 .01454 Mdot
.41668 .87016 Mdot
.19415 .06504 Mdot
.18229 .38601 Mdot
.75141 .83832 Mdot
.07741 .27339 Mdot
.45432 .17961 Mdot
.52611 .39223 Mdot
.24878 .52624 Mdot
.56079 .96289 Mdot
.27078 .40455 Mdot
.98438 .87855 Mdot
.32788 .32796 Mdot
.33987 .15623 Mdot
.85964 .13353 Mdot
.45807 .42871 Mdot
.2922 .30249 Mdot
.73072 .59534 Mdot
.35601 .15791 Mdot
.92425 .03558 Mdot
.54866 .7974 Mdot
.22297 .76946 Mdot
.77718 .10732 Mdot
.24058 .07539 Mdot
.32973 .72829 Mdot
.67796 .02354 Mdot
.37409 .61118 Mdot
.58354 .41922 Mdot
.48501 .36643 Mdot
.23786 .09345 Mdot
.28493 .3079 Mdot
.29769 .24822 Mdot
.42107 .88093 Mdot
.00787 .29016 Mdot
.69334 .56044 Mdot
.4101 .29387 Mdot
.00925 .71889 Mdot
.87097 .28789 Mdot
.03336 .08372 Mdot
.10757 .81736 Mdot
.3841 .85502 Mdot
.75715 .72118 Mdot
.16418 .44605 Mdot
.9644 .48501 Mdot
.0403 .7105 Mdot
.77 .39851 Mdot
.28397 .34219 Mdot
.02745 .72161 Mdot
.73531 .50987 Mdot
.57237 .8422 Mdot
.85872 .37106 Mdot
.34653 .81297 Mdot
.9167 .54664 Mdot
.44719 .32745 Mdot
.61049 .28722 Mdot
.33404 .83687 Mdot
.0294 .31222 Mdot
.4297 .58799 Mdot
.06788 .29181 Mdot
.47429 .85104 Mdot
.05324 .61888 Mdot
.67728 .15687 Mdot
.90092 .23862 Mdot
.62503 .91244 Mdot
.00736 .61354 Mdot
.12741 .17922 Mdot
.59803 .24286 Mdot
.20116 .46853 Mdot
.47796 .94562 Mdot
.67661 .91691 Mdot
.68476 .84188 Mdot
.41966 .04227 Mdot
.69329 .87343 Mdot
.69537 .513 Mdot
.72799 .56733 Mdot
.28636 .08146 Mdot
.85852 .47365 Mdot
.95372 .59738 Mdot
.17174 .94372 Mdot
.61748 .06904 Mdot
.43066 .32768 Mdot
.03373 .39613 Mdot
.08596 .85026 Mdot
.81786 .29559 Mdot
.36258 .89047 Mdot
.36932 .78275 Mdot
.43129 .51942 Mdot
.33826 .00359 Mdot
.48504 .06677 Mdot
.12715 .04132 Mdot
.77987 .02398 Mdot
.67939 .75243 Mdot
.75842 .77858 Mdot
.73496 .10857 Mdot
.84222 .89209 Mdot
.22415 .19406 Mdot
.74875 .08151 Mdot
.10074 .25424 Mdot
.35659 .56756 Mdot
.12905 .3136 Mdot
.0536 .12824 Mdot
.93069 .98284 Mdot
.63926 .32865 Mdot
.1507 .46063 Mdot
.26143 .52687 Mdot
.08503 .61034 Mdot
.42501 .38612 Mdot
.96934 .1759 Mdot
.37891 .94929 Mdot
.6525 .11382 Mdot
.28976 .87549 Mdot
.79864 .90437 Mdot
.25522 .38481 Mdot
.16138 .65897 Mdot
.01609 .2054 Mdot
.67066 .51525 Mdot
.2817 .73079 Mdot
.30471 .79137 Mdot
.80729 .03625 Mdot
.73817 .62459 Mdot
.7127 .8599 Mdot
.99421 .47198 Mdot
.41521 .157 Mdot
.1151 .68591 Mdot
.47847 .63805 Mdot
.3121 .06 Mdot
.57498 .77445 Mdot
.43114 .51326 Mdot
.15393 .21649 Mdot
.92747 .52399 Mdot
.10906 .97851 Mdot
.07642 .86879 Mdot
.73535 .54221 Mdot
.52311 .03004 Mdot
.48014 .7996 Mdot
.21296 .47546 Mdot
.8865 .08209 Mdot
.27611 .67887 Mdot
.07047 .72716 Mdot
.64155 .67543 Mdot
.87401 .65851 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool00_ooool2o`0000Wooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`09ooooo`;o00000_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`;o00001?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool2o`0000Go
oooo00?o0000ooooooooool00_ooool001kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool3o`0000;ooooo
0_l00009ooooo`?o00003Oooool00ol0003oooooooooo`05ooooo`;o00000_ooool2o`0000;ooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo
0ol0000=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00;ooooo000Nooooo`03o`000?oooooooooo013ooooo0_l0
000]ooooo`;o00003_ooool2o`0001Gooooo0_l0000]ooooo`;o0000>_ooool2o`0007Cooooo000N
ooooo`03o`000?oooooooooo013ooooo0_l00008ooooo`;o0000NOooool2o`0000Oooooo0_l0000S
ooooo`;o0000P_ooool001kooooo00?o0000ooooooooool06_ooool2o`0003Kooooo0_l0001:oooo
o`;o00005_ooool2o`0000_ooooo0_l0001fooooo`;o00002_ooool001kooooo00?o0000oooooooo
ool0D_ooool2o`0005Cooooo0_l0000<ooooo`;o00002oooool2o`0007Kooooo0_l0000:ooooo`00
7_ooool00ol0003oooooooooo`28ooooo`;o00002Oooool2o`0001?ooooo0_l00002ooooo`;o0000
5Oooool2o`0000Wooooo0_l0001gooooo`007_ooool00ol0003oooooooooo`0Looooo`;o0000J_oo
ool2o`0000Wooooo0_l0000:ooooo`;o00002oooool2o`00023ooooo0_l00008ooooo`;o00007ooo
ool2o`0004cooooo000Nooooo`03o`000?oooooooooo01cooooo0_l0001@ooooo`;o00006_ooool2
o`0001?ooooo0_l0000gooooo`;o00007oooool2o`0004cooooo000Nooooo`03o`000?oooooooooo
01?ooooo0_l0001Iooooo`;o00006_ooool2o`0001[ooooo0_l0002Oooooo`007_ooool00ol0003o
ooooooooo`07ooooo`;o00002_ooool2o`0006oooooo0_l0000Pooooo`;o00008oooool2o`0007[o
oooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0000Iooooo`;o00006_ooool2o`0004Cooooo
0_l00015ooooo`;o0000=Oooool2o`0002Cooooo0_l0000Mooooo`007_ooool00ol0003ooooooooo
o`0Eooooo`;o00002oooool2o`000003ooooool0003o000001Oooooo0_l00030ooooo`Co00009?oo
ool2o`0001gooooo000Nooooo`03o`000?oooooooooo01Gooooo0_l0000>ooooo`;o0000GOooool2
o`0002Kooooo0_l0001Booooo`;o0000AOooool001kooooo00?o0000ooooooooool06?ooool2o`00
04Wooooo0_l0000Oooooo`;o00004Oooool2o`0000_ooooo0_l00006ooooo`;o00008?ooool2o`00
07Oooooo000Nooooo`03o`000?oooooooooo01Sooooo0_l0000>ooooo`;o0000>Oooool2o`0003;o
oooo0_l0000;ooooo`;o00001_ooool2o`00023ooooo0_l0000Pooooo`;o0000:?ooool2o`0002_o
oooo000Nooooo`;o0000:Oooool2o`0008;ooooo0_l0000<ooooo`;o0000=?ooool2o`0000gooooo
0_l0000<ooooo`;o00002oooool2o`0002_ooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l0
002Fooooo`;o00001oooool3o`0004;ooooo0_l0000<ooooo`;o00002Oooool2o`0002gooooo000N
ooooo`03o`000?oooooooooo01Wooooo0_l0002Fooooo`;o00002?ooool2o`0005_ooooo0_l0000]
ooooo`007_ooool00ol0003oooooooooo`1Qooooo`;o0000POooool2o`00067ooooo000Nooooo`03
o`000?oooooooooo03_ooooo0_l0000Tooooo`;o00009?ooool2o`0005_ooooo0_l0001@ooooo`;o
00003oooool001kooooo00?o0000ooooooooool0>oooool2o`0004[ooooo0_l0000Aooooo`;o0000
2oooool2o`0001cooooo0_l00002ooooo`;o0000<oooool2o`0003Kooooo0_l0000?ooooo`007_oo
ool00ol0003oooooooooo`0>ooooo`?o0000N_ooool2o`0000gooooo0_l0000;ooooo`;o00007?oo
ool2o`0000;ooooo0_l0000]ooooo`;o00001?ooool2o`0004Oooooo000Nooooo`03o`000?oooooo
oooo00Oooooo0_l00005ooooo`?o0000BOooool2o`0002oooooo0_l0001[ooooo`;o00002oooool2
o`00043ooooo000Nooooo`03o`000?oooooooooo00Gooooo1?l00011ooooo`;o00003_ooool2o`00
01kooooo0_l0000mooooo`;o0000B_ooool2o`0003Gooooo0_l00009ooooo`007_ooool00ol0003o
ooooooooo`05ooooo`;o0000@oooool2o`0002kooooo0_l0000Qooooo`;o00006_ooool2o`00087o
oooo0ol00008ooooo`007_ooool00ol0003oooooooooo`07ooooo`;o0000;Oooool2o`00027ooooo
0_l00005ooooo`;o0000>oooool2o`0002cooooo0_l0000>ooooo`;o00004_ooool2o`0002_ooooo
0_l00003ooooo`;o00006_ooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0
000]ooooo`;o00008Oooool2o`0000Gooooo0_l0001Yooooo`;o00003_ooool2o`0001;ooooo0_l0
00000ooooooo0000o`00000Cooooo`;o00004oooool2o`0000?ooooo0_l00005ooooo`;o00007Ooo
ool001kooooo00?o0000ooooooooool0H_ooool2o`0004Cooooo0_l00018ooooo`;o00004oooool2
o`0001oooooo0_l0000@ooooo`;o00002oooool001kooooo00?o0000ooooooooool0BOooool2o`00
01Oooooo0_l0000Tooooo`;o00006?ooool2o`0000Cooooo0_l0001hooooo`;o00005_ooool2o`00
00_ooooo000Nooooo`03o`000?oooooooooo04Wooooo0_l0000^ooooo`;o00003Oooool2o`0001So
oooo0_l0000>ooooo`;o0000K_ooool2o`0001Cooooo0_l0000=ooooo`007_ooool00ol0003ooooo
ooooo`06ooooo`;o0000LOooool2o`0003Oooooo0_l0001kooooo`;o00001oooool2o`0000gooooo
000Nooooo`;o00001oooool2o`0003Wooooo0_l00008ooooo`;o0000Q_ooool2o`0005[ooooo0_l0
000Fooooo`007_ooool00ol0003oooooooooo`11ooooo`;o00002?ooool2o`0004Oooooo0_l0000m
ooooo`;o0000L_ooool001kooooo00?o0000ooooooooool0U?ooool2o`0000Gooooo0_l0000koooo
o`;o00004Oooool2o`0000cooooo0_l0000Dooooo`;o0000:oooool2o`0000Wooooo000Nooooo`03
o`000?oooooooooo04oooooo0_l0000Xooooo`;o00008?ooool2o`0003_ooooo0_l0000Aooooo`;o
00003?ooool2o`0001Cooooo0_l0000Vooooo`;o00000oooool2o`0000Wooooo000Nooooo`03o`00
0?oooooooooo00?ooooo0_l0001:ooooo`;o0000:?ooool2o`0001Oooooo0_l0000looooo`;o0000
IOooool2o`0000kooooo000Nooooo`04o`000?oooooo0000o`0000;ooooo0_l00015ooooo`;o0000
A_ooool2o`0003cooooo0_l0001Pooooo`;o00004oooool001kooooo00Co0000ooooool0003o0000
0oooool2o`0004Cooooo0_l0000Zooooo`;o00002_ooool2o`000:kooooo0_l00004ooooo`;o0000
3Oooool001kooooo00?o0000ooooooooool01?ooool2o`00073ooooo0_l0000:ooooo`;o0000]?oo
ool2o`0000gooooo000Nooooo`03o`000?oooooooooo01kooooo0_l00015ooooo`;o0000h?ooool0
01kooooo00?o0000ooooooooool03Oooool2o`0000oooooo0_l00015ooooo`;o00006_ooool2o`00
00_ooooo0_l0000Oooooo`;o0000U_ooool001kooooo00?o0000ooooooooool03Oooool2o`0000Co
oooo0_l0000Qooooo`;o0000BOooool2o`0000_ooooo0_l0000Oooooo`;o0000Aoooool2o`0001Wo
oooo0_l0000Kooooo`;o00005Oooool001kooooo00?o0000ooooooooool04oooool2o`00027ooooo
0_l00026ooooo`;o0000>?ooool2o`0001Wooooo0_l000000ooooooo0000o`00000Hooooo`;o0000
5Oooool001kooooo00?o0000ooooooooool0:?ooool2o`0009Cooooo0_l0000Booooo`;o0000@_oo
ool2o`0001Kooooo0_l0000Gooooo`007_ooool00ol0003oooooooooo`0Rooooo`;o00001?ooool2
o`0008Kooooo0_l0000Pooooo`;o0000F_ooool2o`0001Oooooo000Nooooo`03o`000?oooooooooo
02;ooooo0_l0002<ooooo`;o00003Oooool2o`0007Gooooo0_l0000?ooooo`007_ooool00ol0003o
ooooooooo`2oooooo`;o0000Eoooool2o`0001cooooo0_l0000?ooooo`007_ooool2o`00037ooooo
0_l0000jooooo`;o0000J?ooool2o`00043ooooo0_l0000]ooooo`007_ooool00ol0003ooooooooo
o`0`ooooo`;o0000>_ooool2o`0006Sooooo0_l0001Sooooo`;o00002_ooool001kooooo00?o0000
ooooooooool05Oooool2o`0005?ooooo1?l00002ooooo`;o00004Oooool2o`0005?ooooo0_l00009
ooooo`;o0000?Oooool2o`0001Oooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0Eoooo
o`;o0000Doooool2o`0000Cooooo0_l0000Aooooo`;o0000Doooool2o`0000Wooooo0_l0000Qoooo
o`;o00006_ooool2o`0002?ooooo000Nooooo`03o`000?oooooooooo04Sooooo0_l0000>ooooo`;o
0000[?ooool2o`0001kooooo0_l0000Oooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o0000
9_ooool2o`0000Kooooo0_l0000>ooooo`;o00001_ooool2o`000;Kooooo0_l0000<ooooo`;o0000
7oooool001kooooo00?o0000ooooooooool05Oooool2o`000003ooooool0003o000000_ooooo0_l0
000Iooooo`;o00007_ooool2o`00083ooooo0ol0000cooooo`;o0000;Oooool001kooooo00?o0000
ooooooooool05Oooool2o`0000kooooo0_l0000jooooo`;o00008?ooool2o`0001Kooooo0_l00008
ooooo`;o00000_ooool2o`0003Oooooo0ol0001Rooooo`007_ooool00ol0003oooooooooo`0joooo
o`;o00009Oooool2o`00023ooooo0_l0000Fooooo`;o00002?ooool2o`0000;ooooo0_l0001Joooo
o`;o0000<?ooool2o`0000kooooo000Nooooo`03o`000?oooooooooo02Gooooo0_l0000Cooooo`;o
00007Oooool2o`0003Gooooo0_l0001cooooo`;o0000:oooool2o`0000?ooooo0_l0000>ooooo`00
7_ooool00ol0003oooooooooo`0Uooooo`;o00006oooool2o`0001Gooooo0_l0000eooooo`;o0000
X?ooool2o`0001?ooooo000Nooooo`03o`000?oooooooooo04;ooooo0_l0003oooooo`Cooooo000N
ooooo`03o`000?oooooooooo02Wooooo0_l0002gooooo`;o00001Oooool2o`0004oooooo0_l0000;
ooooo`007_ooool00ol0003oooooooooo`0Yooooo`;o00007oooool2o`00043ooooo0_l0000=oooo
o`;o00004oooool2o`00033ooooo0_l00005ooooo`;o00000_ooool2o`0004_ooooo0_l0000;oooo
o`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0
003oooooooooo`15ooooo`;o00000oooool2o`00043ooooo0_l0000=ooooo`;o00004oooool2o`00
03_ooooo0_l0001Hooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`0kooooo`;o00002?ooool2
o`000>Cooooo0_l0000Jooooo`000oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RH
ob4Q8Oo^k^h01oooool3o`0003_ooooo0_l0001eooooo`;o00001oooool2o`0005Kooooo0_l0000F
ooooo`;o00006_ooool000?ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^00Kooooo00?o0000ooooooooool01oooool2o`0001oooooo0_l0000Kooooo`;o0000>?ooool2
o`0002kooooo0_l000000ooooooo0000o`000007ooooo`;o00002Oooool2o`0004_ooooo0_l0000b
ooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool0
1?l0003oooooooooooooool2o`0000Cooooo0_l0000Oooooo`;o00006oooool2o`0003Sooooo0_l0
000^ooooo`;o00005Oooool2o`0003;ooooo0_l0001;ooooo`000oooool01Ol@413ooooooooooooo
oooo410@00oooooo00?o0000ooooooooool01?ooool01?l0003oooooooooooooool2o`0001Cooooo
0_l0002nooooo`;o00008Oooool2o`0004_ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool05oooool2o`0001;o
oooo0_l0000Iooooo`;o00005Oooool2o`0004gooooo0_l00004ooooo`;o00008oooool2o`00023o
oooo0_l0000Cooooo`;o0000=oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`08ooooo`;o00008Oooool2o`00
0003ooooool0003o000001Kooooo0_l0000Eooooo`;o0000:Oooool2o`00027ooooo0ol00004oooo
o`;o0000AOooool2o`0001?ooooo0_l0000Dooooo`;o00008Oooool001kooooo00?o0000oooooooo
ool02?ooool2o`0002Cooooo0_l0001Hooooo`;o00008Oooool3o`0005gooooo0_l0000Gooooo`;o
00000_ooool2o`0001gooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l00024ooooo`;o0000
1Oooool2o`0007Kooooo0_l0000Kooooo`;o00007Oooool001kooooo00?o0000ooooooooool00_l0
0004ooooo`;o0000:Oooool4o`0005Oooooo0_l00005ooooo`;o00009?ooool2o`00037ooooo0_l0
000Gooooo`;o0000@?ooool001kooooo00?o0000ooooooooool00_l0000Dooooo`;o00006Oooool4
o`0005gooooo0_l0000Uooooo`;o0000<Oooool2o`0001Oooooo0_l00010ooooo`007_ooool00ol0
003oooooooooo`0Fooooo`;o0000N_ooool2o`000;?ooooo000Nooooo`03o`000?oooooooooo05oo
oooo0_l0003Vooooo`007_ooool00ol0003oooooooooo`1Oooooo`;o0000d?ooool2o`0001Cooooo
000Nooooo`03o`000?oooooooooo07Kooooo0_l0002Yooooo`;o00003_ooool2o`0001Cooooo000N
ooooo`03o`000?oooooooooo04Cooooo0_l0000`ooooo`;o0000A_ooool2o`0001Oooooo0_l0000?
ooooo`;o0000=oooool2o`0001[ooooo0_l00008ooooo`007_ooool00ol0003oooooooooo`14oooo
o`;o0000@oooool2o`0003?ooooo0_l0000Gooooo`?o00003_ooool2o`0003[ooooo0_l0000Goooo
o`;o00002?ooool001kooooo00?o0000ooooooooool0GOooool2o`0002[ooooo0_l0001=ooooo`;o
00004_ooool2o`0003Kooooo0_l0000Qooooo`007_ooool2o`00053ooooo0_l0000<ooooo`;o0000
3Oooool2o`0007kooooo0_l0001Iooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o0000<?oo
ool2o`0001;ooooo0_l00007ooooo`;o0000cOooool2o`0000[ooooo000Nooooo`03o`000?oooooo
oooo01gooooo0_l0000^ooooo`;o00005?ooool2o`0003?ooooo0_l0002Jooooo`;o00001Oooool2
o`0000[ooooo000Nooooo`03o`000?oooooooooo03_ooooo0_l0000@ooooo`;o0000BOooool2o`00
09[ooooo0_l0000Aooooo`007_ooool01?l0003oooooo`000?l0000jooooo`;o0000IOooool2o`00
0:?ooooo000Nooooo`04o`000?oooooo0000o`0002_ooooo0_l0001cooooo`?o0000U?ooool2o`00
00gooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l00006ooooo`;o0000<_ooool2o`000003
ooooool0003o000003cooooo0_l00002ooooo`;o0000F_ooool2o`0000kooooo0_l0000Eooooo`;o
00002_ooool2o`0000;ooooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o0000
0oooool3o`0000gooooo0_l0000jooooo`;o000000?oooooo`000?l000004?ooool2o`0002kooooo
0_l0001Jooooo`;o00003_ooool2o`0001Gooooo0_l0000:ooooo`;o00004Oooool001kooooo00?o
0000ooooooooool01?ooool2o`0000Wooooo0_l00003ooooo`?o00006Oooool2o`0004?ooooo0_l0
000Fooooo`;o0000=oooool2o`00033ooooo0_l0000_ooooo`;o00002Oooool2o`00017ooooo000N
ooooo`03o`000?oooooooooo00Cooooo0_l0000?ooooo`;o00006Oooool2o`0004_ooooo0_l0000>
ooooo`;o0000=oooool2o`00033ooooo0_l000000ooooooo0000o`00000/ooooo`;o00007?ooool0
01kooooo00?o0000ooooooooool05Oooool2o`0006Kooooo0_l0000Vooooo`;o0000E?ooool2o`00
023ooooo0_l0000Xooooo`007_ooool00ol0003oooooooooo`2;ooooo`;o00003?ooool2o`0000[o
oooo0_l0000Kooooo`;o0000FOooool2o`0000[ooooo0_l0000Looooo`007_ooool3o`0003Wooooo
0_l0001@ooooo`;o00003?ooool2o`0002Oooooo0_l0001Cooooo`;o00004?ooool2o`0001cooooo
000Nooooo`?o000000?oooooo`000?l000003oooool2o`0002Gooooo0_l0000Mooooo`;o0000QOoo
ool2o`0000Cooooo1?l0000^ooooo`;o0000;_ooool001kooooo00Co0000oooooooooooooooo0_l0
000?ooooo`;o0000A?ooool2o`0000;ooooo0_l0000Sooooo`;o0000G?ooool2o`0000Cooooo1?l0
000Mooooo`;o0000?oooool001kooooo00?o0000ooooooooool04Oooool2o`0004Wooooo0_l0000S
ooooo`;o0000;oooool2o`0005;ooooo0_l0000oooooo`007_ooool2o`0001;ooooo0_l00018oooo
o`;o0000EOooool2o`0009?ooooo000Nooooo`03o`000?oooooooooo05_ooooo0_l0000;ooooo`;o
0000Aoooool2o`0000;ooooo0_l0002@ooooo`007_ooool00ol0003oooooooooo`1Hooooo`?o0000
3Oooool2o`0004Oooooo0_l00002ooooo`;o0000T?ooool001kooooo00?o0000ooooooooool0<ooo
ool2o`0002?ooooo0ol0001Fooooo`;o0000I_ooool2o`00013ooooo0_l0000Jooooo`007_ooool0
0ol0003oooooooooo`05ooooo`;o00007oooool2o`0000_ooooo0_l00005ooooo`;o00002oooool2
o`000=3ooooo0_l0000@ooooo`;o00006_ooool001kooooo00?o0000ooooooooool01Oooool2o`00
01oooooo1?l0000@ooooo`;o00002oooool2o`0008cooooo0_l00003ooooo`;o0000Aoooool2o`00
02;ooooo000Nooooo`03o`000?oooooooooo02Sooooo0_l0002[ooooo`;o00000oooool2o`0004Oo
oooo0_l0000Rooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o0000:oooool2o`0001oooooo
0_l0001[ooooo`;o0000B?ooool2o`0002?ooooo000Nooooo`03o`000?oooooooooo01gooooo0_l0
000[ooooo`;o00007oooool2o`00023ooooo0_l00019ooooo`;o00006?ooool2o`0002kooooo0_l0
000Sooooo`007_ooool00ol0003oooooooooo`1Vooooo`;o00008?ooool2o`0000?ooooo0_l0000h
ooooo`;o00000oooool2o`0002Cooooo0_l0001Cooooo`007_ooool00ol0003oooooooooo`1Voooo
o`;o00008?ooool2o`0003gooooo0_l00003ooooo`;o00002_ooool2o`0006gooooo000Nooooo`03
o`000?oooooooooo03Kooooo0_l0000/ooooo`;o0000L_ooool2o`00033ooooo0_l0000kooooo`00
7_ooool00ol0003oooooooooo`0fooooo`;o0000;?ooool2o`0008oooooo0_l0000Cooooo`;o0000
>oooool001kooooo00?o0000ooooooooool0Coooool2o`0000Oooooo0_l0000@ooooo`;o0000D?oo
ool2o`0003Oooooo0_l0000booooo`;o00007?ooool001kooooo00?o0000ooooooooool04Oooool2
o`0001Oooooo1?l0000Dooooo`;o00002oooool2o`0000Oooooo0_l000000ooooooo0000o`00000=
ooooo`;o00004?ooool2o`0001kooooo0_l0000Nooooo`;o0000Joooool2o`0001cooooo000Noooo
o`03o`000?oooooooooo00_ooooo0_l00004ooooo`;o00005oooool4o`0001Cooooo0_l0000Goooo
o`;o00007_ooool3o`0001Cooooo0_l00008ooooo`;o0000ZOooool001kooooo0_l0000<ooooo`;o
0000K_ooool2o`0001Gooooo0_l0000cooooo`;o0000O_ooool001kooooo00?o0000ooooooooool0
TOooool2o`0003Cooooo0_l0001nooooo`007_ooool00ol0003oooooooooo`2Aooooo`;o00007ooo
ool2o`0007[ooooo0_l0000Gooooo`007_ooool00ol0003oooooooooo`0jooooo`;o0000<_ooool2
o`0003Oooooo0_l00009ooooo`;o00000_ooool2o`0007Kooooo0_l0000Gooooo`007_ooool00ol0
003oooooooooo`0jooooo`;o0000<_ooool2o`0001Kooooo0_l00002ooooo`;o00006oooool2o`00
00Cooooo0_l00007ooooo`;o0000Soooool001kooooo00?o0000ooooooooool02?ooool2o`0001;o
oooo0_l0000Booooo`;o0000E?ooool2o`0000;ooooo0_l0000>ooooo`;o00004Oooool2o`0009So
oooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0000Booooo`;o00004_ooool2o`0006Sooooo
0_l00016ooooo`Co0000Aoooool2o`0001Sooooo000Nooooo`03o`000?oooooooooo01oooooo0_l0
000looooo`;o0000Poooool4o`0002gooooo0_l0000Hooooo`;o00006?ooool001kooooo00?o0000
ooooooooool07oooool2o`0003cooooo0_l0002dooooo`;o00003Oooool2o`0002?ooooo000Noooo
o`03o`000?oooooooooo07Gooooo0_l0000/ooooo`;o00007Oooool2o`0005kooooo0_l0000Soooo
o`007_ooool00ol0003oooooooooo`1eooooo`;o0000;?ooool2o`0001gooooo0_l00023ooooo`00
7Oooool2o`000003ooooool0003o000004kooooo0_l0000Yooooo`;o0000boooool001gooooo0_l0
00000ooooooo0000o`000002ooooo`;o0000<?ooool4o`0000oooooo0ol00004ooooo`;o0000:Ooo
ool2o`0000[ooooo0_l0000eooooo`;o0000R?ooool001kooooo00?o0000ooooooooool00oooool2
o`00033ooooo1?l0000?ooooo`?o0000>oooool2o`0003Gooooo0_l00008ooooo`;o000000?ooooo
o`000?l00000Noooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2
o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0Yoooool2o`0001kooooo0_l00000
0ooooooo0000o`000007ooooo`;o00005Oooool2o`0005_ooooo0003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07
ooooo`;o0000>?ooool2o`0003_ooooo0_l0000Wooooo`;o0000:?ooool4o`0001Gooooo0_l0000O
ooooo`;o0000>_ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool3
o`0000Oooooo0_l0000hooooo`;o0000>oooool2o`0000?ooooo0_l0001<ooooo`;o00007?ooool2
o`0000Gooooo0_l00005ooooo`;o00003?ooool2o`0000Kooooo0_l0000booooo`000oooool01Ol0
003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool00ol0003ooooooooo
o`03ooooo`;o00001_ooool2o`00013ooooo0_l0000Oooooo`;o0000@oooool2o`00037ooooo0_l0
000dooooo`;o000000?oooooo`000?l000001Oooool2o`0000Gooooo0_l0000Dooooo`;o0000<_oo
ool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo
00?o0000ooooooooool00oooool2o`0000Kooooo0_l0000@ooooo`;o00007oooool2o`0001Cooooo
0_l0000Sooooo`;o0000>oooool2o`0003Cooooo0_l0000Iooooo`Co00003?ooool2o`0002kooooo
0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007ooooo`03o`00
0?oooooooooo03Oooooo0_l0000Kooooo`;o00008oooool2o`0008cooooo1?l0000<ooooo`;o0000
;_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo
00?o0000ooooooooool0=oooool2o`000003ooooool0003o000003cooooo0_l0001]ooooo`;o0000
C?ooool2o`00013ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000
ooooo`06ooooo`03o`000?oooooooooo03[ooooo0_l0000looooo`;o00005Oooool2o`00043ooooo
0_l0000Booooo`Co0000C?ooool2o`00013ooooo000Nooooo`03o`000?oooooooooo03Gooooo0_l0
001Hooooo`;o0000:Oooool2o`0001Gooooo0_l0000Booooo`;o0000H?ooool001kooooo00?o0000
ooooooooool03?ooool2o`0001Kooooo0_l0000?ooooo`;o00008_ooool3o`0002Cooooo0_l0000h
ooooo`;o0000Roooool001kooooo00?o0000ooooooooool03?ooool2o`0001Kooooo0_l0000coooo
o`?o00008_ooool4o`000<Gooooo000Nooooo`03o`000?oooooooooo01?ooooo0_l0001Yooooo`;o
00004Oooool2o`0000Kooooo0_l0001Qooooo`;o00008oooool2o`0000;ooooo0_l0000Pooooo`00
7_ooool00ol0003oooooooooo`0Cooooo`;o0000O?ooool2o`0000Kooooo0_l0000Iooooo`;o0000
:_ooool2o`0001[ooooo0_l0000Sooooo`;o00000_ooool2o`00023ooooo000Nooooo`03o`000?oo
oooooooo06oooooo0_l00013ooooo`;o0000:_ooool2o`0006Gooooo000Nooooo`03o`000?oooooo
oooo06oooooo0_l0001Kooooo`;o0000NOooool001kooooo00?o0000ooooooooool05oooool2o`00
05Oooooo0_l0000Hooooo`;o0000@?ooool2o`00063ooooo0_l0000Gooooo`007_ooool00ol0003o
ooooooooo`0Gooooo`;o00008Oooool2o`0000Kooooo0_l0000Hooooo`;o00004_ooool2o`0000[o
oooo0_l0000<ooooo`;o0000A?ooool2o`0005Oooooo0_l00003ooooo`;o00001?ooool2o`00017o
oooo000Nooooo`03o`000?oooooooooo037ooooo0_l00007ooooo`;o00001_ooool2o`0001Sooooo
0_l0000:ooooo`;o00004_ooool2o`0005;ooooo0_l0000Xooooo`;o0000;Oooool2o`0000Oooooo
1?l00006ooooo`;o00002Oooool001kooooo00?o0000ooooooooool0<Oooool2o`0000?ooooo0_l0
000`ooooo`;o00006?ooool2o`0001gooooo0_l0001Gooooo`;o00005?ooool2o`00023ooooo0_l0
0008ooooo`;o00002Oooool001kooooo0_l0000gooooo`;o00007_ooool2o`0002[ooooo0_l0000D
ooooo`;o00001oooool2o`0005_ooooo0_l0000@ooooo`;o0000=Oooool001kooooo00?o0000oooo
ooooool0AOooool2o`0000oooooo0_l0000/ooooo`;o00004_ooool2o`0004[ooooo0_l0000Hoooo
o`;o00005?ooool2o`00037ooooo000Nooooo`03o`000?oooooooooo04Gooooo0_l0000mooooo`;o
0000:Oooool2o`000003ooooool0003o0000033ooooo0_l0000Uooooo`;o00001oooool2o`00037o
oooo000Nooooo`03o`000?oooooooooo02gooooo0_l00017ooooo`;o00005oooool2o`0000;ooooo
0_l0000Jooooo`;o000000?oooooo`000?l00000Eoooool2o`0003[ooooo000Nooooo`03o`000?oo
oooooooo02gooooo0_l0000Aooooo`;o0000=?ooool2o`0000_ooooo0_l0000:ooooo`;o00000_oo
ool2o`0003kooooo0_l0001booooo`007_ooool00ol0003oooooooooo`0Jooooo`;o00008Oooool2
o`000003ooooool0003o0000047ooooo0_l0001>ooooo`;o0000COooool2o`0000;ooooo0_l0000H
ooooo`;o00001Oooool001kooooo00?o0000ooooooooool06_ooool2o`00027ooooo0_l0001Doooo
o`;o00005_ooool2o`0004Sooooo0_l0000[ooooo`;o00000_ooool2o`0001Oooooo0ol00005oooo
o`007_ooool00ol0003oooooooooo`0booooo`;o0000Goooool2o`0001Kooooo1?l00016ooooo`;o
00003oooool2o`0000_ooooo0_l0000Zooooo`;o00001_ooool001kooooo00?o0000ooooooooool0
<_ooool2o`0000gooooo0_l0001Zooooo`;o00001oooool2o`0004kooooo0_l0000;ooooo`;o0000
<_ooool001kooooo00?o0000ooooooooool0<oooool2o`0000_ooooo0ol0000Xooooo`;o000000?o
ooooo`000?l00000A_ooool2o`0006kooooo0_l0000Oooooo`007_ooool00ol0003oooooooooo`0c
ooooo`;o00002oooool2o`0002Wooooo0_l000000ooooooo0000o`00000=ooooo`Co00001_ooool2
o`00023ooooo0_l0001kooooo`;o00007oooool001kooooo00?o0000ooooooooool0>?ooool2o`00
04?ooooo1?l00006ooooo`;o00008?ooool2o`0008[ooooo0_l0000@ooooo`007_ooool00ol0003o
ooooooooo`0hooooo`;o0000^Oooool2o`00043ooooo0_l0000@ooooo`007_ooool00ol0003ooooo
ooooo`0;ooooo`;o0000??ooool2o`000:Sooooo0_l0001Booooo`007_ooool00ol0003ooooooooo
o`0;ooooo`;o0000=_ooool2o`0000Cooooo0_l00019ooooo`;o0000EOooool4o`0005Sooooo000N
ooooo`03o`000?oooooooooo01Cooooo0_l0000Aooooo`;o00006_ooool2o`0004oooooo0_l0001A
ooooo`;o00000_ooool4o`0005Sooooo000Nooooo`;o00005Oooool2o`00017ooooo0_l00022oooo
o`;o0000>_ooool2o`0002;ooooo0_l0000aooooo`;o00001oooool001kooooo00?o0000oooooooo
ool0?oooool2o`0000cooooo0_l0000Iooooo`;o0000@Oooool2o`0002[ooooo0_l0000booooo`;o
00003oooool2o`0001_ooooo0_l00003ooooo`;o00001oooool001kooooo00?o0000ooooooooool0
?oooool2o`0000cooooo0_l000000ooooooo0000o`00000;ooooo`;o00002Oooool2o`00043ooooo
0_l0000[ooooo`;o0000<?ooool2o`00017ooooo0_l00007ooooo`;o00004_ooool2o`0000;ooooo
0_l00008ooooo`007_ooool00ol0003oooooooooo`1<ooooo`;o00000_ooool2o`0000_ooooo0_l0
001;ooooo`;o0000;oooool2o`0000kooooo0_l00009ooooo`;o00004Oooool2o`0001[ooooo0_l0
000Fooooo`;o00002?ooool001kooooo00?o0000ooooooooool0BOooool2o`000003ooooool0003o
000003[ooooo0_l0000Fooooo`;o0000>Oooool2o`000003ooooool0003o000000_ooooo0_l00009
ooooo`;o0000Coooool001kooooo0ol0000Xooooo`;o00003?ooool2o`00017ooooo0_l0000moooo
o`;o00005_ooool2o`0003Cooooo0_l00006ooooo`;o0000Boooool2o`0001[ooooo000Nooooo`?o
00004Oooool2o`0001Gooooo0_l0000<ooooo`;o0000;?ooool4o`00023ooooo0_l00006ooooo`;o
00004_ooool2o`00033ooooo0_l0001Cooooo`;o00006_ooool001kooooo00?o0000ooooooooool0
4Oooool2o`00057ooooo1?l0000Pooooo`;o00001_ooool2o`0001;ooooo0_l0000@ooooo`;o0000
AOooool2o`0002[ooooo0_l0000Looooo`007_ooool00ol0003oooooooooo`1=ooooo`;o00000_oo
ool2o`0006?ooooo0_l0000Cooooo`;o0000<?ooool2o`0002[ooooo0_l0000Looooo`007_ooool0
0ol0003oooooooooo`0Mooooo`;o00007?ooool2o`00013ooooo0_l00002ooooo`;o0000N?ooool2
o`0007[ooooo000Nooooo`03o`000?oooooooooo01gooooo0_l0000Looooo`;o0000A?ooool2o`00
02Cooooo0_l0002Nooooo`007_ooool00ol0003oooooooooo`21ooooo`;o00009?ooool2o`0006Ko
oooo0_l0000fooooo`007_ooool00ol0003oooooooooo`13ooooo`;o0000Ioooool2o`0002Oooooo
0_l00004ooooo`;o0000<_ooool2o`0003Kooooo000Nooooo`03o`000?oooooooooo01Sooooo0_l0
000Yooooo`;o0000G?ooool2o`0000Wooooo0_l0000Wooooo`;o00001?ooool2o`0000kooooo0_l0
0008ooooo`;o0000D?ooool001kooooo00?o0000ooooooooool06?ooool2o`0008Oooooo0_l00018
ooooo`;o00002?ooool2o`0002Sooooo0_l0000Vooooo`007_ooool00ol0003oooooooooo`0Toooo
o`;o00000oooool2o`0001Kooooo0_l00007ooooo`;o00002Oooool2o`000<Sooooo0_l00005oooo
o`;o00007oooool001kooooo0_l00002ooooo`;o00008Oooool2o`0000?ooooo0_l00002ooooo`;o
000000?oooooo`000?l000003oooool2o`0000Oooooo0_l00009ooooo`;o0000F?ooool2o`0001;o
oooo0_l0000looooo`;o00003?ooool2o`0000Oooooo0_l0000<ooooo`;o00007oooool001kooooo
00Co0000oooooooooooooooo0_l0000Yooooo`?o000000?oooooo`000?l00000AOooool2o`0002;o
oooo0_l0000Booooo`;o00004_ooool2o`0003cooooo0_l0000<ooooo`;o00001oooool2o`0002go
oooo000Nooooo`03o`000?oooooooooo02;ooooo0_l00008ooooo`;o00005oooool2o`0001Cooooo
0_l0000Jooooo`;o00008_ooool2o`0000Cooooo0_l0000hooooo`;o0000=_ooool2o`0003;ooooo
000Nooooo`03o`000?oooooooooo01?ooooo0_l0000=ooooo`;o00008Oooool2o`0001Cooooo0_l0
0014ooooo`;o0000>?ooool4o`0003Cooooo0_l0000booooo`007_ooool00ol0003oooooooooo`0C
ooooo`;o0000G?ooool2o`0001gooooo0_l0001;ooooo`;o0000J?ooool001kooooo00?o0000oooo
ooooool03Oooool2o`0002cooooo0_l0000dooooo`;o00007Oooool2o`0001Kooooo0_l0000ooooo
o`;o0000;Oooool2o`0002gooooo000Nooooo`03o`000?oooooooooo00gooooo0_l0000/ooooo`;o
0000<oooool2o`0003Kooooo0_l0000oooooo`;o0000;Oooool2o`0002gooooo000Nooooo`03o`00
0?oooooooooo073ooooo0_l0003Eooooo`007_ooool01?l0003oooooo`000?l0002Dooooo`;o0000
@_ooool2o`0004_ooooo0_l0000Oooooo`007_ooool01?l0003oooooo`000?l00011ooooo`;o0000
B?ooool2o`0000Oooooo0_l0000Rooooo`;o00003?ooool2o`00013ooooo0_l0001;ooooo`;o0000
7oooool001kooooo00?o0000ooooooooool09Oooool2o`0001_ooooo0_l00018ooooo`;o0000:ooo
ool2o`0000cooooo0_l0001:ooooo`;o0000<_ooool001kooooo00?o0000ooooooooool09Oooool2
o`0000Cooooo0_l0000Mooooo`;o0000Goooool2o`0000?ooooo0_l0001Pooooo`Go0000<?ooool0
01kooooo00?o0000ooooooooool03oooool2o`0001[ooooo0_l0000Mooooo`;o0000??ooool2o`00
00[ooooo0_l0000Eooooo`;o00000oooool2o`0001Wooooo0_l0000Wooooo`;o00007?ooool2o`00
0003ooooool0003o0000033ooooo000Nooooo`03o`000?oooooooooo00oooooo0_l0001gooooo`;o
00001_ooool2o`0000;ooooo0_l0000?ooooo`;o00009?ooool2o`0002Oooooo0_l0001Aooooo`00
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@
4?o<c<`01_ooool00ol0003oooooooooo`07ooooo`;o00009oooool2o`0005kooooo0_l0000Coooo
o`;o00002Oooool2o`0002Sooooo0_l0001[ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`07
ooooo`;o00009oooool2o`0006Sooooo0_l0000Dooooo`;o00001?ooool2o`0002;ooooo0_l0000=
ooooo`;o0000<Oooool2o`00017ooooo0_l000000ooooooo0000o`00000Cooooo`000oooool01Ol@
413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000Iooo
ool2o`0001gooooo0_l0000Booooo`;o00006_ooool2o`0002Gooooo0_l0000:ooooo`;o0000<Ooo
ool2o`00017ooooo0_l000000ooooooo0000o`00000Cooooo`000oooool01Ol0003ooooooooooooo
oooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo06Oooooo
0_l0000Mooooo`;o0000EOooool2o`0000Gooooo0_l0001Qooooo`000oooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo01Ko
oooo0_l00005ooooo`;o0000<Oooool2o`0009;ooooo0_l0001?ooooo`;o00004?ooool000?ooooo
00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000oooooooo
ool05_ooool4o`0000?ooooo0_l0000[ooooo`;o00001?ooool2o`0003[ooooo0_l0001Eooooo`;o
0000D?ooool2o`00013ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo
410@oiRHV008ooooo`;o00001Oooool2o`0001;ooooo0_l00005ooooo`;o0000:Oooool2o`0002[o
oooo0ol0000Aooooo`Co0000EOooool2o`0006;ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`?o00001?ooool2o`0001Gooooo0_l00002oooo
o`;o0000EOooool3o`00017ooooo0_l0002kooooo`007_ooool3o`0000gooooo0_l0000<ooooo`;o
0000;?ooool2o`000?cooooo000Nooooo`03o`000?oooooooooo00gooooo0_l0000:ooooo`;o0000
;_ooool2o`000?cooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l0002aooooo`;o00007_oo
ool2o`0005Wooooo000Nooooo`03o`000?oooooooooo0<cooooo0_l0000Nooooo`;o0000FOooool0
01kooooo00?o0000ooooooooool0`Oooool2o`0008Cooooo000Nooooo`03o`000?oooooooooo01oo
oooo0_l0002Pooooo`;o0000=Oooool2o`0004gooooo000Nooooo`03o`000?oooooooooo01oooooo
0_l0001fooooo`;o0000Goooool2o`0003cooooo0_l0000?ooooo`007_ooool00ol0003ooooooooo
o`0kooooo`;o0000F_ooool2o`000003ooooool0003o000000?ooooo0_l0002Eooooo`;o00003ooo
ool001kooooo00?o0000ooooooooool00_ooool2o`0003Oooooo0_l0001Mooooo`;o00000oooool2
o`000:Kooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0001=ooooo`;o0000SOooool2o`00
06Gooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l0000[ooooo`;o00000_ooool2o`0008Wo
oooo0_l0001Uooooo`007_ooool2o`0002Gooooo0_l00003ooooo`;o00003Oooool2o`0000;ooooo
0_l0000;ooooo`;o00002_ooool2o`000?3ooooo000Nooooo`03o`000?oooooooooo02Wooooo0_l0
000=ooooo`;o00000_ooool2o`0000_ooooo0_l00013ooooo`;o0000?oooool2o`0007Kooooo000N
ooooo`03o`000?oooooooooo033ooooo0_l0001:ooooo`;o00004?ooool2o`0003oooooo0_l00017
ooooo`;o0000;Oooool001kooooo00?o0000ooooooooool07_ooool2o`0000kooooo1?l0000Foooo
o`;o00009?ooool2o`0000cooooo0_l0001Wooooo`;o00000_ooool2o`0002gooooo0_l0000]oooo
o`007_ooool00ol0003oooooooooo`0Hooooo`;o00001?ooool2o`0000kooooo0_l0000Hooooo`;o
00009?ooool2o`0005cooooo0_l0000Gooooo`;o00000_ooool2o`0005cooooo000Nooooo`03o`00
0?oooooooooo01Sooooo0_l0001nooooo`;o0000<_ooool2o`0007Wooooo000Nooooo`03o`000?oo
oooooooo09Sooooo0_l00008ooooo`;o0000Xoooool001kooooo00?o0000ooooooooool0:?ooool2
o`00043ooooo0_l00008ooooo`;o00008Oooool2o`0000Wooooo0_l0002Sooooo`007_ooool00ol0
003oooooooooo`0Xooooo`;o00002Oooool2o`0003Gooooo0_l00008ooooo`;o00001oooool2o`00
01Sooooo0_l0000cooooo`;o0000NOooool001kooooo00?o0000ooooooooool04oooool2o`0001ko
oooo0_l0000Qooooo`;o00009Oooool2o`0001Wooooo0_l0000^ooooo`;o00000_ooool2o`0007Wo
oooo000Nooooo`03o`000?oooooooooo01?ooooo0_l00011ooooo`;o0000@?ooool2o`0002kooooo
0_l00016ooooo`;o0000=Oooool001kooooo00?o0000ooooooooool08Oooool2o`0000_ooooo0_l0
000]ooooo`;o0000/Oooool2o`0001?ooooo0_l0000Pooooo`007_ooool00ol0003oooooooooo`0Q
ooooo`;o00002oooool2o`0002gooooo0_l00036ooooo`Co00007_ooool001kooooo00?o0000oooo
ooooool0a?ooool2o`00067ooooo0_l0000Nooooo`007_ooool00ol0003oooooooooo`1jooooo`;o
0000B?ooool2o`0001Wooooo0_l00006ooooo`?o0000GOooool001kooooo00?o0000ooooooooool0
N_ooool2o`0006?ooooo0_l00006ooooo`?o00005?ooool2o`0002[ooooo0_l0000Kooooo`007_oo
ool2o`0004?ooooo0_l00026ooooo`;o0000<_ooool2o`0002[ooooo0_l0000Dooooo`;o00001Ooo
ool001kooooo00?o0000ooooooooool0@_ooool2o`0008Kooooo0_l0000]ooooo`;o0000AOooool2
o`0000Gooooo000Nooooo`03o`000?oooooooooo05Oooooo0_l0001nooooo`Co00007_ooool2o`00
04cooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0001<ooooo`;o00002_ooool2o`0007;o
oooo1?l0000Nooooo`;o0000C?ooool001kooooo00?o0000ooooooooool02Oooool2o`0005Sooooo
0_l0002fooooo`;o0000:_ooool001kooooo00?o0000ooooooooool0KOooool2o`0000Sooooo0_l0
0016ooooo`;o00005_ooool2o`0004;ooooo0_l0000Zooooo`007_ooool01?l0003oooooo`000?l0
000Sooooo`;o0000Aoooool2o`0000Sooooo0_l00016ooooo`;o00005_ooool2o`0000cooooo0_l0
001Pooooo`007_ooool01?l0003oooooo`000?l00004ooooo`;o00007Oooool2o`00027ooooo0_l0
000Pooooo`;o0000N_ooool2o`0000_ooooo0_l0001Cooooo`007_ooool00ol0003oooooooooo`05
ooooo`;o00003?ooool2o`0003;ooooo0_l0000Pooooo`;o0000=oooool2o`0004_ooooo0_l00000
0ooooooo0000o`00000dooooo`;o00007Oooool001kooooo00?o0000ooooooooool04oooool2o`00
01Oooooo0_l0000iooooo`;o0000>Oooool2o`0004_ooooo0_l0000gooooo`;o00007Oooool001ko
oooo00?o0000ooooooooool0;?ooool2o`0002Wooooo0_l0000>ooooo`;o00001oooool2o`0005co
oooo0_l0001gooooo`007_ooool00ol0003oooooooooo`1Gooooo`;o00003_ooool2o`0000Oooooo
0_l00014ooooo`;o00005_ooool2o`0000Gooooo0_l0001Pooooo`;o00003_ooool001kooooo00?o
0000ooooooooool0=_ooool2o`0007kooooo0_l0000Mooooo`;o0000H?ooool2o`0000kooooo000N
ooooo`03o`000?oooooooooo03Kooooo0_l0000Sooooo`;o0000f_ooool2o`0000kooooo000Noooo
o`03o`000?oooooooooo05_ooooo0_l0001Oooooo`;o0000ROooool001kooooo00?o0000oooooooo
ool0LOooool2o`0002?ooooo0_l0000Tooooo`;o0000J_ooool2o`0001gooooo000Nooooo`;o0000
<_ooool2o`0003kooooo0_l0000Sooooo`;o00001_ooool2o`0004Sooooo0_l00008ooooo`;o0000
2?ooool2o`0002[ooooo0_l00007ooooo`;o00005?ooool001kooooo00?o0000ooooooooool05Ooo
ool2o`0001[ooooo0_l0001[ooooo`;o0000>Oooool2o`0000gooooo0_l00008ooooo`;o00002?oo
ool2o`0003?ooooo0_l0000Dooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o0000Y?ooool2
o`0001[ooooo1?l0000cooooo`;o0000=oooool001kooooo00?o0000ooooooooool0Roooool2o`00
01?ooooo0_l0000Iooooo`;o00006_ooool2o`0003Gooooo0_l0000gooooo`007_ooool00ol0003o
ooooooooo`0fooooo`;o0000Doooool2o`0001?ooooo0_l0002Uooooo`007_ooool00ol0003ooooo
ooooo`0Qooooo`;o00001?ooool2o`0000gooooo0_l0000looooo`;o00005oooool2o`0000Sooooo
0_l00018ooooo`;o00003_ooool2o`0004Wooooo0_l00009ooooo`007_ooool00ol0003ooooooooo
o`0Qooooo`;o00001?ooool2o`0001_ooooo0_l00005ooooo`;o00009_ooool3o`0001Oooooo0_l0
0008ooooo`;o0000B?ooool2o`0000kooooo0_l00019ooooo`;o00002Oooool001kooooo00?o0000
ooooooooool0=oooool4o`0000Wooooo0_l00005ooooo`;o00009_ooool2o`0002oooooo0_l00009
ooooo`;o0000U_ooool001kooooo00?o0000ooooooooool0=oooool4o`0006Wooooo0_l00009oooo
o`;o00001_ooool2o`0006gooooo0_l0000Oooooo`007_ooool00ol0003oooooooooo`2Jooooo`;o
00006oooool2o`0003Wooooo0_l0000booooo`;o00007oooool001kooooo00?o0000ooooooooool0
V_ooool4o`0005Cooooo0_l0001Cooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o00004ooo
ool2o`0002;ooooo0_l000000ooooooo0000o`00000Mooooo`;o00009_ooool2o`0001;ooooo0_l0
0008ooooo`;o0000Doooool2o`0003Kooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l0000C
ooooo`;o00008_ooool2o`000003ooooool0003o000001gooooo0_l0000jooooo`;o00002?ooool2
o`0005?ooooo0_l0000fooooo`007_ooool00ol0003oooooooooo`1Nooooo`?o0000>oooool2o`00
033ooooo0_l0001gooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Gooooo`;o00001Oooool3
o`0003_ooooo0_l0000Iooooo`;o00005Oooool2o`0005cooooo0_l0000Iooooo`000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_oo
ool00ol0003oooooooooo`1Gooooo`;o00004_ooool2o`0001kooooo0_l0000Qooooo`;o00001ooo
ool2o`00047ooooo0_l0000`ooooo`;o00006Oooool000?ooooo00Go410@oooooooooooooooooa0@
400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`0001_ooooo0_l0001>ooooo`;o0000
7_ooool2o`0000_ooooo0_l0000Dooooo`;o0000<Oooool2o`0001Oooooo0_l0000Vooooo`;o0000
8oooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb
<S801_ooool00ol0003oooooooooo`0Kooooo`;o0000Noooool2o`0004Oooooo0_l0000Sooooo`;o
00006_ooool2o`0002?ooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co
0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0a?ooool2o`0001_ooooo0_l0000Loooo
o`;o00001Oooool2o`0003oooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@
413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool04_ooool2o`000:7ooooo0_l0000=
ooooo`;o00006oooool2o`0001Gooooo0_l00005ooooo`;o00003oooool2o`0003Gooooo0003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o
0000ooooooooool04_ooool2o`0005Wooooo0_l00016ooooo`;o0000@Oooool2o`0001Kooooo0_l0
000eooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@06ooooo`03o`000?oooooooooo01Wooooo1?l0001@ooooo`;o00000oooool3o`0000Wooooo
0_l00010ooooo`;o0000QOooool001kooooo00?o0000ooooooooool06Oooool4o`0000;ooooo0_l0
001Aooooo`?o00002Oooool2o`00043ooooo0_l0000<ooooo`;o0000Hoooool2o`0001;ooooo000N
ooooo`03o`000?oooooooooo01oooooo0_l0002]ooooo`;o0000Hoooool2o`0001;ooooo000Noooo
o`03o`000?oooooooooo063ooooo0_l00006ooooo`;o00006?ooool2o`0003;ooooo0_l0002?oooo
o`007_ooool00ol0003oooooooooo`1Pooooo`;o00001_ooool2o`0001Sooooo0_l0000booooo`;o
0000Soooool001kooooo00?o0000ooooooooool0[?ooool2o`0009Wooooo000Nooooo`03o`000?oo
oooooooo0:cooooo0_l0000Booooo`;o0000QOooool001kooooo00?o0000ooooooooool0=Oooool2
o`00037ooooo0_l0001Fooooo`;o0000QOooool001kooooo00?o0000ooooooooool04?ooool2o`00
017ooooo0_l00006ooooo`;o00002?ooool2o`0001kooooo0_l0000Aooooo`;o00007Oooool2o`00
00Wooooo0_l0001Booooo`;o00002?ooool2o`0005Gooooo000Nooooo`03o`000?oooooooooo013o
oooo0_l0000Aooooo`;o00001_ooool2o`0002Sooooo0_l0000`ooooo`;o00002Oooool2o`0000Ko
oooo0_l0000Jooooo`;o00006_ooool2o`0000Oooooo0_l00009ooooo`;o00001oooool3o`0005Go
oooo000Nooooo`03o`000?oooooooooo03Gooooo0_l0001Sooooo`;o00006_ooool2o`0001Cooooo
0_l00004ooooo`;o00001oooool2o`0001;ooooo0_l0001Fooooo`007_ooool00ol0003ooooooooo
o`0Hooooo`;o00006oooool2o`0009Gooooo0_l0001iooooo`007_ooool2o`00013ooooo0_l00007
ooooo`;o0000O?ooool2o`0007Wooooo0_l0000dooooo`007_ooool00ol0003oooooooooo`0?oooo
o`;o0000J?ooool3o`0001[ooooo0_l00014ooooo`;o0000<oooool2o`0000Wooooo0_l0000Yoooo
o`007_ooool00ol0003oooooooooo`1;ooooo`;o0000;?ooool3o`00063ooooo0ol0000mooooo`;o
0000:Oooool001kooooo00?o0000ooooooooool0Boooool2o`0001[ooooo0_l0001Hooooo`;o0000
6_ooool2o`0000Gooooo0_l0000jooooo`;o00009Oooool001gooooo0_l00005ooooo`;o00005_oo
ool2o`0004[ooooo0_l0000Dooooo`;o00009_ooool2o`0001[ooooo0_l0000Qooooo`;o00007ooo
ool2o`0001Wooooo0_l0000Uooooo`007Oooool2o`0000Gooooo0_l0000@ooooo`;o00001?ooool2
o`00063ooooo0_l0000Aooooo`;o00004oooool4o`0004Cooooo0_l0000Fooooo`;o0000@?ooool0
01kooooo00?o0000ooooooooool05Oooool2o`00027ooooo0_l00019ooooo`;o00002oooool2o`00
01Gooooo0_l00014ooooo`;o0000F?ooool001kooooo00?o0000ooooooooool0>?ooool2o`0004Wo
oooo0_l0000`ooooo`;o00009_ooool2o`0005cooooo0_l0000:ooooo`007_ooool00ol0003ooooo
ooooo`1Jooooo`;o00009oooool2o`00033ooooo0_l0000Vooooo`;o0000COooool2o`0000gooooo
0_l0000:ooooo`007_ooool00ol0003oooooooooo`0`ooooo`;o0000:?ooool2o`0000Oooooo0_l0
000Nooooo`Co0000;?ooool2o`0007Oooooo0_l0000>ooooo`;o000000?oooooo`000?l000001_oo
ool001kooooo00?o0000ooooooooool00_l0000Hooooo`;o00005?ooool2o`00037ooooo0_l0000P
ooooo`;o00007oooool2o`0000_ooooo0_l00027ooooo`;o000000?oooooo`000?l000001_ooool0
01kooooo00?o0000ooooooooool00_l0000Hooooo`;o0000R_ooool2o`0009oooooo000Nooooo`03
o`000?oooooooooo0?oooooo3?ooool2o`0003[ooooo000Nooooo`03o`000?oooooooooo04Sooooo
0_l0000Wooooo`?o0000Uoooool2o`000003ooooool0003o000000[ooooo0_l00007ooooo`;o0000
8_ooool001kooooo00?o0000ooooooooool0B?ooool2o`0000[ooooo0_l0000Kooooo`?o0000V_oo
ool2o`0000[ooooo0_l00007ooooo`;o00008_ooool001kooooo00?o0000ooooooooool05Oooool2
o`0002;ooooo0_l0000Iooooo`;o0000lOooool001kooooo0_l0000Fooooo`;o00008_ooool2o`00
0?oooooo3Oooool001kooooo00?o0000ooooooooool0;oooool2o`0009Cooooo0_l0000iooooo`;o
0000AOooool001kooooo00?o0000ooooooooool0;oooool2o`0009Cooooo0_l0000iooooo`;o0000
AOooool001kooooo00?o0000ooooooooool0E?ooool2o`0000Wooooo0_l0001Cooooo`;o0000TOoo
ool001kooooo00?o0000ooooooooool0;Oooool2o`00017ooooo0_l00006ooooo`;o00002_ooool2
o`0000Wooooo0_l0001Cooooo`;o00004Oooool2o`0007kooooo000Nooooo`03o`000?oooooooooo
02gooooo0_l0000Aooooo`;o00001_ooool2o`0001gooooo0_l0001Nooooo`;o00003oooool2o`00
03oooooo0_l0000/ooooo`007_ooool00ol0003oooooooooo`1Wooooo`;o0000Koooool2o`0003oo
oooo0_l0000/ooooo`007_ooool00ol0003oooooooooo`03ooooo`;o00002?ooool2o`0001cooooo
0_l0003ooooooa_ooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l00005ooooo`;o000000?o
ooooo`000?l000007?ooool2o`0005Sooooo0_l00030ooooo`007_ooool00ol0003oooooooooo`0:
ooooo`;o0000@?ooool2o`0003Oooooo0_l00030ooooo`007_ooool3o`0003gooooo0_l0000=oooo
o`;o0000nOooool001kooooo0ol0000mooooo`;o0000Uoooool2o`000003ooooool0003o000005_o
oooo0_l00004ooooo`;o00002Oooool001kooooo00?o0000ooooooooool03_ooool2o`0002Oooooo
0_l0001^ooooo`;o0000;Oooool2o`000003ooooool0003o000005_ooooo0_l00004ooooo`;o0000
2Oooool001kooooo00?o0000ooooooooool03_ooool2o`0000?ooooo0_l0000Rooooo`;o0000J_oo
ool2o`0000;ooooo0_l0002Nooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o00007oooool2
o`00067ooooo0_l0000:ooooo`;o00001oooool2o`0009Wooooo000Nooooo`03o`000?oooooooooo
03Cooooo0_l00017ooooo`;o00006?ooool2o`0001?ooooo0_l0000Aooooo`;o0000Q_ooool001ko
oooo0_l000000ooooooo0000o`00001eooooo`;o00001?ooool2o`00043ooooo0_l0000Aooooo`;o
0000Loooool001kooooo00?o0000ooooooooool00_l00017ooooo`;o0000;?ooool2o`0003;ooooo
0_l0000:ooooo`;o00006Oooool2o`0005;ooooo0_l0000Oooooo`007_ooool00ol0003ooooooooo
o`19ooooo`;o0000H?ooool2o`0000[ooooo0_l0001]ooooo`;o00007oooool001kooooo00?o0000
ooooooooool0[oooool2o`0000oooooo1?l0001Dooooo`;o00005Oooool2o`0001Kooooo000Noooo
o`03o`000?oooooooooo0:oooooo0_l000000ooooooo0000o`00000<ooooo`Co0000E?ooool2o`00
01Gooooo0_l0000Fooooo`007_ooool00ol0003oooooooooo`1hooooo`;o00009oooool2o`0000oo
oooo0_l0002Cooooo`007_ooool00ol0003oooooooooo`1hooooo`;o00009oooool2o`0005_ooooo
0_l0000^ooooo`;o00005oooool001kooooo00?o0000ooooooooool0hoooool2o`0001Wooooo0_l0
000^ooooo`;o00005oooool001kooooo00?o0000ooooooooool0hoooool2o`0006;ooooo000Noooo
o`03o`000?oooooooooo00Kooooo0_l0000Gooooo`;o00004Oooool2o`0001Kooooo0_l0001Roooo
o`;o0000Uoooool001kooooo00?o0000ooooooooool01_ooool2o`0001Oooooo0_l0000Aooooo`;o
00005_ooool2o`0005Wooooo0_l00007ooooo`;o0000K_ooool2o`0002Oooooo000Nooooo`03o`00
0?oooooooooo03[ooooo0_l0001Yooooo`;o00007Oooool2o`0005Sooooo0_l0000:ooooo`;o0000
6oooool001kooooo00?o0000ooooooooool01?ooool2o`0003Cooooo0_l00028ooooo`;o000000?o
ooooo`000?l00000?oooool2o`00023ooooo0_l0000Kooooo`007_ooool00ol0003oooooooooo`04
ooooo`;o00001_ooool2o`0004oooooo0_l0000cooooo`;o0000<oooool2o`0003oooooo0_l0000m
ooooo`005?ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool03?ooool2o`00
04oooooo0_l0000cooooo`;o00002?ooool2o`0003Oooooo0_l0000]ooooo`;o0000@Oooool001Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Oooooo`;o0000>oooool2o`0003Oo
oooo0_l0000]ooooo`;o00005Oooool2o`00027ooooo0_l00007ooooo`005_ooool00ol0003ooooo
ooooo`05ooooo`?o0000Goooool2o`0004Gooooo0_l00010ooooo`;o00007Oooool2o`0001;ooooo
0_l0000Qooooo`;o00001oooool001Kooooo00?o0000ooooooooool0[_ooool2o`00043ooooo0_l0
000Mooooo`;o0000?_ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0
003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Cooooo
00?oEEEEofIVI_l00000oooooomBooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.12942 .40716 Mdot
.10514 .8159 Mdot
.95659 .06849 Mdot
.33887 .73771 Mdot
.15836 .34906 Mdot
.93514 .19262 Mdot
.08052 .03064 Mdot
.15497 .60103 Mdot
.94489 .02478 Mdot
.23793 .01462 Mdot
.60143 .96315 Mdot
.03863 .6674 Mdot
.63561 .41231 Mdot
.40856 .40309 Mdot
.4346 .35528 Mdot
.34424 .63134 Mdot
.52563 .94831 Mdot
.33755 .38538 Mdot
.70703 .99445 Mdot
.8774 .83788 Mdot
.52681 .97002 Mdot
.42612 .07222 Mdot
.90448 .10635 Mdot
.1434 .50735 Mdot
.77304 .38253 Mdot
.26542 .4275 Mdot
.81211 .83101 Mdot
.64703 .39571 Mdot
.32327 .74552 Mdot
.25875 .14872 Mdot
.68884 .10284 Mdot
.35511 .28168 Mdot
.53498 .09429 Mdot
.11017 .12477 Mdot
.76781 .1649 Mdot
.95043 .67294 Mdot
.27338 .121 Mdot
.3985 .38449 Mdot
.18194 .18011 Mdot
.02839 .93942 Mdot
.00149 .27738 Mdot
.41044 .89064 Mdot
.31856 .34006 Mdot
.22055 .33743 Mdot
.74853 .30506 Mdot
.65131 .5871 Mdot
.86567 .12809 Mdot
.62826 .81957 Mdot
.191 .32226 Mdot
.11017 .22825 Mdot
.84348 .09296 Mdot
.47046 .54961 Mdot
.10098 .78284 Mdot
.99946 .38296 Mdot
.8901 .45827 Mdot
.85983 .11241 Mdot
.59107 .97802 Mdot
.06276 .74539 Mdot
.21262 .3952 Mdot
.10896 .81768 Mdot
.16677 .36548 Mdot
.81291 .80113 Mdot
.24469 .99717 Mdot
.30326 .44415 Mdot
.0246 .45547 Mdot
.32881 .05229 Mdot
.31048 .81269 Mdot
.6131 .0582 Mdot
.16276 .24767 Mdot
.94488 .12751 Mdot
.82998 .77126 Mdot
.89838 .26965 Mdot
.11584 .64971 Mdot
.24002 .81938 Mdot
.30294 .38098 Mdot
.69781 .19877 Mdot
.93524 .71053 Mdot
.17796 .21817 Mdot
.74259 .80992 Mdot
.2989 .26591 Mdot
.51524 .68133 Mdot
.64798 .01612 Mdot
.21088 .93417 Mdot
.76849 .45562 Mdot
.75038 .45432 Mdot
.78826 .119 Mdot
.47722 .07886 Mdot
.99886 .58077 Mdot
.55397 .98217 Mdot
.63023 .53273 Mdot
.06417 .91617 Mdot
.541 .32533 Mdot
.21156 .65739 Mdot
.74546 .27886 Mdot
.06548 .57168 Mdot
.38477 .58029 Mdot
.18858 .23089 Mdot
.75772 .4199 Mdot
.57395 .26282 Mdot
.21772 .93488 Mdot
.55609 .34135 Mdot
.77162 .52979 Mdot
.8869 .8769 Mdot
.2764 .32757 Mdot
.68659 .68317 Mdot
.18631 .80458 Mdot
.55433 .0465 Mdot
.93854 .40319 Mdot
.17138 .97901 Mdot
.41584 .74698 Mdot
.45751 .43445 Mdot
.91932 .88892 Mdot
.81101 .47948 Mdot
.27023 .42415 Mdot
.1778 .54077 Mdot
.47335 .75925 Mdot
.40084 .67471 Mdot
.03751 .87635 Mdot
.73044 .62285 Mdot
.58493 .7971 Mdot
.74398 .43055 Mdot
.55762 .17386 Mdot
.12054 .6941 Mdot
.30083 .88201 Mdot
.43935 .44081 Mdot
.93199 .52154 Mdot
.64988 .34562 Mdot
.71741 .73103 Mdot
.55369 .76345 Mdot
.69631 .99138 Mdot
.54081 .09965 Mdot
.12399 .58627 Mdot
.19696 .55737 Mdot
.47315 .64039 Mdot
.09264 .55351 Mdot
.25136 .42446 Mdot
.40058 .96039 Mdot
.06523 .25185 Mdot
.58463 .75488 Mdot
.41196 .21402 Mdot
.24834 .13463 Mdot
.96022 .16184 Mdot
.85183 .72841 Mdot
.05802 .39313 Mdot
.66608 .34004 Mdot
.33788 .72687 Mdot
.74451 .7629 Mdot
.0429 .27776 Mdot
.24969 .41965 Mdot
.01781 .22133 Mdot
.22149 .6551 Mdot
.41843 .29725 Mdot
.94567 .27309 Mdot
.84219 .87557 Mdot
.07422 .36957 Mdot
.71968 .54965 Mdot
.21948 .49326 Mdot
.53832 .51064 Mdot
.57085 .82084 Mdot
.13928 .56695 Mdot
.46973 .35135 Mdot
.0611 .07732 Mdot
.9883 .08531 Mdot
.00853 .22431 Mdot
.86399 .57034 Mdot
.26751 .8468 Mdot
.85767 .72771 Mdot
.33005 .42705 Mdot
.56717 .52744 Mdot
.07829 .821 Mdot
.97868 .41113 Mdot
.63055 .37462 Mdot
.37451 .09253 Mdot
.33417 .29431 Mdot
.57395 .35768 Mdot
.48064 .19753 Mdot
.34457 .69112 Mdot
.41884 .53169 Mdot
.26198 .28197 Mdot
.03008 .23981 Mdot
.01872 .4283 Mdot
.8777 .34834 Mdot
.95715 .66039 Mdot
.15965 .11727 Mdot
.72719 .41861 Mdot
.93999 .50405 Mdot
.29801 .25967 Mdot
.4914 .18767 Mdot
.54381 .52812 Mdot
.30894 .68271 Mdot
.33924 .1408 Mdot
.24682 .56964 Mdot
.61168 .67636 Mdot
.92714 .30464 Mdot
.17528 .99437 Mdot
.67977 .28213 Mdot
.58947 .44192 Mdot
.53365 .3872 Mdot
.29092 .17147 Mdot
.2814 .13985 Mdot
.16865 .66595 Mdot
.22229 .367 Mdot
.81158 .48603 Mdot
.14975 .68672 Mdot
.04532 .51983 Mdot
.3208 .48669 Mdot
.23644 .42446 Mdot
.58227 .26799 Mdot
.58643 .16129 Mdot
.79282 .3673 Mdot
.39733 .10543 Mdot
.47126 .00269 Mdot
.84073 .02627 Mdot
.68038 .46532 Mdot
.51725 .58751 Mdot
.72634 .49705 Mdot
.08707 .00583 Mdot
.38515 .15693 Mdot
.19374 .52822 Mdot
.85711 .85559 Mdot
.85893 .61203 Mdot
.47454 .53417 Mdot
.41664 .86527 Mdot
.98438 .14165 Mdot
.4224 .69487 Mdot
.30894 .79762 Mdot
.92121 .24189 Mdot
.69399 .99034 Mdot
.57882 .72364 Mdot
.32146 .79662 Mdot
.46401 .06531 Mdot
.88459 .2473 Mdot
.23337 .56264 Mdot
.8744 .69882 Mdot
.02111 .6427 Mdot
.80386 .73437 Mdot
.50467 .90556 Mdot
.57599 .85201 Mdot
.66767 .94064 Mdot
.03268 .84827 Mdot
.11165 .85744 Mdot
.99669 .23651 Mdot
.88198 .6113 Mdot
.81757 .18538 Mdot
.44378 .79363 Mdot
.75615 .05754 Mdot
.45107 .99349 Mdot
.83105 .59861 Mdot
.95749 .1602 Mdot
.19606 .6469 Mdot
.05374 .30601 Mdot
.69876 .76541 Mdot
.31195 .49895 Mdot
.71456 .5001 Mdot
.47883 .76809 Mdot
.95874 .47177 Mdot
.90968 .197 Mdot
.03197 .08609 Mdot
.21675 .1763 Mdot
.06512 .80374 Mdot
.41622 .56672 Mdot
.2214 .43472 Mdot
.45822 .45958 Mdot
.59811 .60146 Mdot
.1599 .71046 Mdot
.8503 .46722 Mdot
.48477 .80927 Mdot
.35275 .74004 Mdot
.56666 .90122 Mdot
.75993 .29057 Mdot
.69943 .66857 Mdot
.01675 .44529 Mdot
.63782 .11465 Mdot
.25663 .14728 Mdot
.28209 .4594 Mdot
.94433 .62733 Mdot
.19397 .5277 Mdot
.93787 .23433 Mdot
.47771 .6423 Mdot
.70912 .08269 Mdot
.16071 .04952 Mdot
.7992 .46685 Mdot
.06103 .85959 Mdot
.86729 .18228 Mdot
.74186 .4092 Mdot
.48122 .90974 Mdot
.69191 .53327 Mdot
.77549 .44941 Mdot
.7869 .66711 Mdot
.92312 .80875 Mdot
.37845 .16822 Mdot
.27266 .16723 Mdot
.34912 .07663 Mdot
.09864 .70811 Mdot
.73539 .88278 Mdot
.49727 .33786 Mdot
.10538 .07585 Mdot
.91661 .43657 Mdot
.84974 .40689 Mdot
.29684 .21593 Mdot
.22589 .54599 Mdot
.80636 .16075 Mdot
.07682 .55788 Mdot
.63891 .75235 Mdot
.58444 .09701 Mdot
.20479 .32031 Mdot
.2591 .80306 Mdot
.54799 .19146 Mdot
.16437 .14418 Mdot
.25158 .56751 Mdot
.4498 .52357 Mdot
.85877 .55611 Mdot
.6826 .42673 Mdot
.27828 .67406 Mdot
.17409 .77589 Mdot
.53323 .79593 Mdot
.58322 .10959 Mdot
.32284 .51996 Mdot
.89359 .42712 Mdot
.45569 .28081 Mdot
.96447 .23241 Mdot
.44793 .7676 Mdot
.34203 .27004 Mdot
.57002 .26631 Mdot
.29157 .52979 Mdot
.57729 .24271 Mdot
.10823 .53049 Mdot
.24231 .35243 Mdot
.90493 .34148 Mdot
.65186 .89398 Mdot
.05577 .39285 Mdot
.28842 .79445 Mdot
.02274 .12287 Mdot
.74505 .77713 Mdot
.06204 .79569 Mdot
.1138 .63581 Mdot
.1924 .36788 Mdot
.1548 .3002 Mdot
.06108 .19381 Mdot
.00845 .33651 Mdot
.79693 .82193 Mdot
.50682 .02117 Mdot
.19173 .31221 Mdot
.40482 .59049 Mdot
.09252 .20102 Mdot
.51811 .14926 Mdot
.49945 .27783 Mdot
.69417 .91772 Mdot
.20435 .81966 Mdot
.50814 .59306 Mdot
.30156 .00209 Mdot
.52649 .76662 Mdot
.0237 .25818 Mdot
.63365 .63426 Mdot
.58876 .99343 Mdot
.53578 .14709 Mdot
.28079 .47856 Mdot
.04413 .02414 Mdot
.94687 .17947 Mdot
.49505 .02706 Mdot
.89486 .96121 Mdot
.51248 .31151 Mdot
.86912 .3567 Mdot
.43823 .34626 Mdot
.88387 .96141 Mdot
.65956 .08735 Mdot
.03912 .23487 Mdot
.92668 .7282 Mdot
.80128 .39829 Mdot
.01289 .68264 Mdot
.02732 .15574 Mdot
.67288 .87954 Mdot
.29122 .89233 Mdot
.8592 .62898 Mdot
.343 .67755 Mdot
.55451 .9917 Mdot
.5299 .60458 Mdot
.97363 .42066 Mdot
.21975 .47956 Mdot
.00518 .1347 Mdot
.1621 .3508 Mdot
.17522 .39772 Mdot
.06126 .81155 Mdot
.64986 .42075 Mdot
.19473 .43308 Mdot
.78481 .78699 Mdot
.74507 .74391 Mdot
.44257 .48858 Mdot
.04885 .91649 Mdot
.2018 .32928 Mdot
.8746 .21227 Mdot
.48281 .89203 Mdot
.5681 .97679 Mdot
.25863 .20772 Mdot
.94112 .76868 Mdot
.72759 .69312 Mdot
.00519 .01915 Mdot
.65091 .02672 Mdot
.17595 .87764 Mdot
.56929 .24813 Mdot
.09863 .61495 Mdot
.53596 .12008 Mdot
.37265 .70652 Mdot
.39757 .36687 Mdot
.3763 .41774 Mdot
.42623 .77082 Mdot
.67686 .75645 Mdot
.76963 .05033 Mdot
.38994 .36699 Mdot
.1362 .81027 Mdot
.16691 .793 Mdot
.89107 .59006 Mdot
.12276 .89011 Mdot
.9401 .40176 Mdot
.05797 .25587 Mdot
.41818 .41672 Mdot
.15378 .0565 Mdot
.79597 .47724 Mdot
.61726 .11671 Mdot
.71219 .85124 Mdot
.96153 .50648 Mdot
.70492 .76623 Mdot
.65081 .73655 Mdot
.41182 .39232 Mdot
.48348 .04583 Mdot
.70353 .72348 Mdot
.15682 .78069 Mdot
.07325 .56971 Mdot
.58016 .42532 Mdot
.2675 .9344 Mdot
.08667 .4944 Mdot
.12769 .45627 Mdot
.42451 .89303 Mdot
.71563 .32402 Mdot
.98925 .23782 Mdot
.0644 .43358 Mdot
.59433 .28303 Mdot
.47422 .47706 Mdot
.44916 .5605 Mdot
.26311 .99926 Mdot
.32169 .67097 Mdot
.18587 .93627 Mdot
.00314 .07602 Mdot
.19527 .95124 Mdot
.07078 .03306 Mdot
.45254 .38829 Mdot
.80448 .88087 Mdot
.34494 .1898 Mdot
.64116 .80679 Mdot
.33233 .60581 Mdot
.08537 .23377 Mdot
.91138 .93093 Mdot
.81404 .29508 Mdot
.69075 .00048 Mdot
.41899 .43688 Mdot
.77191 .99674 Mdot
.60607 .78354 Mdot
.56718 .77192 Mdot
.84662 .02021 Mdot
.21037 .71881 Mdot
.38873 .36622 Mdot
.33628 .85112 Mdot
.03892 .00565 Mdot
.42403 .88098 Mdot
.24946 .52574 Mdot
.10869 .01703 Mdot
.75165 .15098 Mdot
.426 .05354 Mdot
.15474 .17699 Mdot
.91041 .26072 Mdot
.40626 .79876 Mdot
.67251 .61559 Mdot
.41953 .72011 Mdot
.03374 .1149 Mdot
.06093 .82382 Mdot
.46225 .43086 Mdot
.53775 .28752 Mdot
.65668 .56983 Mdot
.74427 .22484 Mdot
.3276 .67472 Mdot
.01448 .09184 Mdot
.89716 .27569 Mdot
.55935 .8917 Mdot
.5209 .48187 Mdot
.39789 .25769 Mdot
.42465 .23309 Mdot
.20009 .3416 Mdot
.85083 .08235 Mdot
.47722 .10995 Mdot
.57509 .55581 Mdot
.08632 .93998 Mdot
.50055 .0758 Mdot
.21917 .49708 Mdot
.56525 .99633 Mdot
.98419 .20701 Mdot
.42357 .42581 Mdot
.63513 .24984 Mdot
.80298 .09014 Mdot
.1354 .52635 Mdot
.90912 .85453 Mdot
.69965 .79985 Mdot
.38293 .41132 Mdot
.5099 .27248 Mdot
.00457 .09918 Mdot
.96062 .30961 Mdot
.43742 .25364 Mdot
.10912 .69104 Mdot
.35118 .1062 Mdot
.92116 .56876 Mdot
.17107 .73219 Mdot
.65759 .08298 Mdot
.23871 .54299 Mdot
.15442 .47992 Mdot
.80576 .09172 Mdot
.66648 .11969 Mdot
.01443 .92196 Mdot
.56811 .10374 Mdot
.7533 .70743 Mdot
.74751 .17927 Mdot
.40729 .82597 Mdot
.52863 .58345 Mdot
.52459 .1552 Mdot
.79243 .50838 Mdot
.12765 .38401 Mdot
.85525 .8802 Mdot
.24764 .17942 Mdot
.22539 .53483 Mdot
.55569 .23842 Mdot
.40827 .61021 Mdot
.6889 .65625 Mdot
.71851 .64679 Mdot
.20019 .45884 Mdot
.26511 .2419 Mdot
.58278 .07195 Mdot
.20545 .67357 Mdot
.30381 .74586 Mdot
.31489 .77963 Mdot
.07034 .37275 Mdot
.17097 .41339 Mdot
.92904 .68105 Mdot
.16055 .95659 Mdot
.96585 .07435 Mdot
.54849 .15895 Mdot
.78254 .44706 Mdot
.43637 .28921 Mdot
.50224 .49806 Mdot
.97946 .55541 Mdot
.06907 .61558 Mdot
.98173 .67865 Mdot
.06163 .0203 Mdot
.76754 .36872 Mdot
.32194 .481 Mdot
.42349 .79269 Mdot
.44408 .60555 Mdot
.66273 .46079 Mdot
.75905 .24224 Mdot
.57217 .02994 Mdot
.30024 .88848 Mdot
.64021 .69724 Mdot
.237 .30744 Mdot
.93809 .73012 Mdot
.99601 .9073 Mdot
.14148 .12316 Mdot
.28902 .69102 Mdot
.70008 .52727 Mdot
.86093 .25116 Mdot
.84594 .08148 Mdot
.05017 .18817 Mdot
.38873 .02314 Mdot
.16617 .90706 Mdot
.4558 .37483 Mdot
.96675 .95053 Mdot
.09989 .695 Mdot
.89995 .5816 Mdot
.14995 .51149 Mdot
.67317 .07915 Mdot
.53636 .90916 Mdot
.40879 .05496 Mdot
.21684 .87428 Mdot
.53126 .07592 Mdot
.02332 .55457 Mdot
.26994 .20494 Mdot
.36262 .35341 Mdot
.04739 .17502 Mdot
.16717 .87157 Mdot
.49313 .50852 Mdot
.18694 .3758 Mdot
.66461 .47912 Mdot
.87048 .44544 Mdot
.02665 .27945 Mdot
.81215 .94952 Mdot
.69579 .13994 Mdot
.46479 .98588 Mdot
.36117 .92783 Mdot
.31108 .55616 Mdot
.52459 .78519 Mdot
.21012 .17799 Mdot
.21308 .0277 Mdot
.84267 .53139 Mdot
.17821 .7887 Mdot
.68844 .29442 Mdot
.41014 .59183 Mdot
.41988 .44752 Mdot
.48956 .55719 Mdot
.24219 .45861 Mdot
.17919 .61221 Mdot
.52561 .45253 Mdot
.89245 .91053 Mdot
.14164 .50999 Mdot
.68874 .05175 Mdot
.70587 .72234 Mdot
.31722 .30033 Mdot
.34935 .25441 Mdot
.08599 .64008 Mdot
.3204 .79729 Mdot
.67467 .1644 Mdot
.46592 .72015 Mdot
.69687 .29047 Mdot
.7532 .31224 Mdot
.76902 .24528 Mdot
.534 .45029 Mdot
.2744 .11403 Mdot
.94993 .15518 Mdot
.7564 .85613 Mdot
.99669 .87366 Mdot
.73354 .88093 Mdot
.99641 .89518 Mdot
.02045 .5403 Mdot
.64444 .19691 Mdot
.43803 .00614 Mdot
.47489 .01419 Mdot
.54992 .59096 Mdot
.88376 .52423 Mdot
.36674 .46125 Mdot
.27056 .48027 Mdot
.91937 .40278 Mdot
.89321 .54237 Mdot
.26166 .66412 Mdot
.04073 .02956 Mdot
.58772 .9565 Mdot
.47358 .62654 Mdot
.51137 .4934 Mdot
.54212 .54139 Mdot
.15845 .89933 Mdot
.53225 .13926 Mdot
.05801 .23189 Mdot
.68836 .62143 Mdot
.05859 .41231 Mdot
.44903 .81028 Mdot
.74442 .73361 Mdot
.68921 .53567 Mdot
.28992 .99315 Mdot
.1169 .62362 Mdot
.81025 .80359 Mdot
.15881 .11074 Mdot
.24581 .61457 Mdot
.53858 .25468 Mdot
.58157 .54965 Mdot
.08339 .63456 Mdot
.59623 .17022 Mdot
.15444 .93254 Mdot
.39024 .14808 Mdot
.56772 .32204 Mdot
.33546 .89446 Mdot
.57789 .31855 Mdot
.41411 .4658 Mdot
.75563 .12379 Mdot
.39948 .5676 Mdot
.23727 .14341 Mdot
.56688 .08216 Mdot
.31274 .00893 Mdot
.15976 .59154 Mdot
.22984 .53722 Mdot
.55474 .44932 Mdot
.96535 .94616 Mdot
.98079 .13488 Mdot
.26768 .64289 Mdot
.53439 .97918 Mdot
.52629 .72732 Mdot
.48201 .12328 Mdot
.95981 .96436 Mdot
.69606 .47328 Mdot
.64312 .60305 Mdot
.76363 .58326 Mdot
.8208 .26565 Mdot
.11173 .16149 Mdot
.56794 .18623 Mdot
.94151 .04082 Mdot
.65065 .59184 Mdot
.26009 .23402 Mdot
.02021 .74909 Mdot
.02423 .93969 Mdot
.30583 .75655 Mdot
.47815 .35959 Mdot
.68709 .37041 Mdot
.48847 .69337 Mdot
.86094 .30239 Mdot
.71448 .4003 Mdot
.45387 .86135 Mdot
.434 .37812 Mdot
.76244 .68171 Mdot
.4376 .4937 Mdot
.48917 .61435 Mdot
.92838 .68884 Mdot
.28812 .90035 Mdot
.46329 .19407 Mdot
.66847 .37788 Mdot
.60427 .39282 Mdot
.86949 .28977 Mdot
.03666 .03926 Mdot
.57653 .03348 Mdot
.53962 .49581 Mdot
.93849 .82554 Mdot
.54348 .97934 Mdot
.10896 .92652 Mdot
.35395 .15389 Mdot
.25032 .11202 Mdot
.76491 .08924 Mdot
.04316 .54346 Mdot
.07948 .5917 Mdot
.3741 .45872 Mdot
.28656 .64229 Mdot
.1396 .07068 Mdot
.73118 .21081 Mdot
.39094 .67175 Mdot
.47154 .6253 Mdot
.88994 .53725 Mdot
.81616 .25065 Mdot
.76314 .93757 Mdot
.05513 .2842 Mdot
.89128 .12221 Mdot
.68682 .49796 Mdot
.91765 .92472 Mdot
.7488 .10922 Mdot
.7309 .70251 Mdot
.15031 .76502 Mdot
.93134 .24192 Mdot
.93587 .05424 Mdot
.07468 .57236 Mdot
.14518 .62261 Mdot
.62274 .01019 Mdot
.16173 .43956 Mdot
.79997 .55419 Mdot
.05767 .03258 Mdot
.81376 .95337 Mdot
.18624 .13742 Mdot
.64968 .03927 Mdot
.38478 .73386 Mdot
.64519 .96145 Mdot
.64902 .70541 Mdot
.65834 .34208 Mdot
.55915 .95385 Mdot
.44669 .46386 Mdot
.4589 .27125 Mdot
.57663 .81896 Mdot
.3919 .2903 Mdot
.54946 .78948 Mdot
.93031 .29218 Mdot
.72408 .67723 Mdot
.52327 .69097 Mdot
.07009 .5469 Mdot
.27003 .86671 Mdot
.41636 .42227 Mdot
.77345 .47716 Mdot
.28605 .86344 Mdot
.44582 .58326 Mdot
.8879 .24795 Mdot
.15504 .85168 Mdot
.48927 .15339 Mdot
.46816 .00352 Mdot
.64951 .54343 Mdot
.48595 .10037 Mdot
.38979 .69494 Mdot
.23714 .1732 Mdot
.04447 .5039 Mdot
.82838 .48905 Mdot
.54658 .58767 Mdot
.19878 .50235 Mdot
.46817 .93219 Mdot
.04639 .60095 Mdot
.07711 .79391 Mdot
.03 .34606 Mdot
.28245 .3366 Mdot
.50456 .29734 Mdot
.0594 .48121 Mdot
.00209 .11132 Mdot
.87778 .13163 Mdot
.52769 .5162 Mdot
.48769 .92736 Mdot
.15351 .4597 Mdot
.78401 .21418 Mdot
.73688 .20208 Mdot
.03578 .38543 Mdot
.76446 .63809 Mdot
.80763 .41356 Mdot
.22781 .62077 Mdot
.89841 .94538 Mdot
.32525 .1759 Mdot
.54942 .45612 Mdot
.83503 .43595 Mdot
.51683 .01526 Mdot
.70156 .13805 Mdot
.49894 .05445 Mdot
.769 .20818 Mdot
.67492 .33733 Mdot
.17401 .28258 Mdot
.05872 .20743 Mdot
.57803 .57749 Mdot
.04292 .98023 Mdot
.61089 .36891 Mdot
.22174 .62899 Mdot
.79994 .47957 Mdot
.70735 .31455 Mdot
.94544 .73703 Mdot
.59037 .64492 Mdot
.24424 .41749 Mdot
.46284 .45338 Mdot
.14896 .35073 Mdot
.7141 .3914 Mdot
.93745 .4919 Mdot
.76535 .51191 Mdot
.55427 .47494 Mdot
.49729 .58938 Mdot
.80261 .99299 Mdot
.37212 .06289 Mdot
.52978 .43525 Mdot
.95379 .23767 Mdot
.56479 .80245 Mdot
.45596 .25413 Mdot
.24803 .63172 Mdot
.63231 .80875 Mdot
.38231 .88518 Mdot
.30493 .8589 Mdot
.08161 .42329 Mdot
.68586 .79082 Mdot
.05168 .62546 Mdot
.1042 .03179 Mdot
.57621 .54076 Mdot
.98228 .37082 Mdot
.87159 .5489 Mdot
.37837 .25173 Mdot
.02549 .91529 Mdot
.00636 .12948 Mdot
.63873 .9721 Mdot
.14529 .24628 Mdot
.66541 .42234 Mdot
.66815 .19768 Mdot
.13093 .15843 Mdot
.37519 .45534 Mdot
.6727 .71572 Mdot
.16122 .95289 Mdot
.50462 .51976 Mdot
.3007 .28476 Mdot
.31813 .51263 Mdot
.29724 .76125 Mdot
.84898 .51319 Mdot
.14641 .31112 Mdot
.01344 .85372 Mdot
.65466 .28141 Mdot
.96397 .0464 Mdot
.44239 .8348 Mdot
.18247 .05086 Mdot
.15459 .40374 Mdot
.74974 .83047 Mdot
.10374 .27504 Mdot
.42565 .17484 Mdot
.54748 .36899 Mdot
.26204 .49164 Mdot
.54073 .98627 Mdot
.30027 .42993 Mdot
.95068 .90346 Mdot
.32073 .37043 Mdot
.31648 .1615 Mdot
.90161 .13035 Mdot
.42077 .45421 Mdot
.29163 .26428 Mdot
.73583 .59113 Mdot
.34988 .1655 Mdot
.94903 .00156 Mdot
.56267 .79732 Mdot
.208 .74273 Mdot
.74598 .1208 Mdot
.21038 .08968 Mdot
.34131 .74565 Mdot
.70486 .9846 Mdot
.38577 .57394 Mdot
.61438 .39694 Mdot
.4578 .3312 Mdot
.22579 .14213 Mdot
.32545 .31135 Mdot
.31871 .28698 Mdot
.37483 .846 Mdot
.98641 .29498 Mdot
.72781 .56167 Mdot
.45415 .33708 Mdot
.98006 .74052 Mdot
.83716 .32317 Mdot
.05617 .08769 Mdot
.07522 .83098 Mdot
.36982 .85474 Mdot
.77361 .74013 Mdot
.17861 .48808 Mdot
.94359 .50679 Mdot
.06537 .73765 Mdot
.80291 .38327 Mdot
.31457 .33331 Mdot
.06231 .68784 Mdot
.73045 .52355 Mdot
.61649 .8424 Mdot
.88091 .32887 Mdot
.36766 .84418 Mdot
.92502 .55385 Mdot
.48866 .30774 Mdot
.64146 .30696 Mdot
.34596 .83775 Mdot
.0189 .3434 Mdot
.44254 .56826 Mdot
.09908 .29173 Mdot
.50385 .81018 Mdot
.02769 .64626 Mdot
.70024 .16523 Mdot
.89709 .26312 Mdot
.59815 .92699 Mdot
.04405 .57467 Mdot
.1097 .18589 Mdot
.56075 .23428 Mdot
.20971 .42631 Mdot
.50067 .95461 Mdot
.70231 .95153 Mdot
.64585 .80655 Mdot
.38313 .06458 Mdot
.72436 .83941 Mdot
.67451 .5002 Mdot
.72514 .56511 Mdot
.24767 .07956 Mdot
.86858 .43094 Mdot
.98102 .62536 Mdot
.1739 .95155 Mdot
.58353 .08599 Mdot
.44207 .29038 Mdot
.02429 .4412 Mdot
.11097 .8113 Mdot
.80483 .27105 Mdot
.3948 .92468 Mdot
.33326 .82183 Mdot
.40287 .52377 Mdot
.29727 .99809 Mdot
.48585 .0545 Mdot
.10442 .03812 Mdot
.7579 .05494 Mdot
.6451 .77508 Mdot
.753 .80245 Mdot
.7624 .12316 Mdot
.86618 .90904 Mdot
.24048 .20651 Mdot
.71435 .11267 Mdot
.11748 .27337 Mdot
.40143 .54761 Mdot
.15186 .28969 Mdot
.04647 .15237 Mdot
.92104 .99572 Mdot
.61551 .28333 Mdot
.11376 .50673 Mdot
.2782 .50492 Mdot
.05845 .6002 Mdot
.45879 .39111 Mdot
.98353 .19525 Mdot
.38944 .96219 Mdot
.68631 .074 Mdot
.32365 .87382 Mdot
.78649 .94395 Mdot
.23833 .39507 Mdot
.12161 .62131 Mdot
.00129 .22065 Mdot
.69512 .50248 Mdot
.28393 .71849 Mdot
.30363 .82865 Mdot
.82025 .05957 Mdot
.69701 .59309 Mdot
.68152 .8138 Mdot
.96172 .42917 Mdot
.39744 .15868 Mdot
.14449 .6614 Mdot
.43691 .67866 Mdot
.34476 .02692 Mdot
.60113 .76285 Mdot
.46906 .53991 Mdot
.12398 .17786 Mdot
.91235 .55408 Mdot
.11308 .95822 Mdot
.04222 .88404 Mdot
.73221 .5383 Mdot
.49231 .01319 Mdot
.44829 .81363 Mdot
.19731 .43599 Mdot
.84517 .09827 Mdot
.30318 .63902 Mdot
.04149 .71665 Mdot
.66195 .63827 Mdot
.91029 .64974 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`;o00003_ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool3o`0000So
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool02Oooool2o`0000;ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0<ooooo`;o00004?ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`09ooooo`;o00000_ooool00ol0003oooooooooo`08ooooo`;o00000oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`;o00003_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Sooooo
0_l00003ooooo`03o`000?oooooooooo00;ooooo0ol00008ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`;o00004?ooool00ol0003ooooo
ooooo`02ooooo`007_ooool00ol0003oooooooooo`09ooooo`;o00003Oooool2o`0004Sooooo0_l0
000Vooooo`;o0000>_ooool2o`0007oooooo000Nooooo`03o`000?oooooooooo06;ooooo0_l0000h
ooooo`;o0000:?ooool2o`0007oooooo000Nooooo`03o`000?oooooooooo04Wooooo0_l0001;oooo
o`;o00001?ooool2o`0000Kooooo0_l0000Yooooo`;o0000M_ooool001kooooo0ol0000Oooooo`;o
0000:?ooool2o`0004_ooooo0_l0000<ooooo`;o0000:Oooool2o`0007Kooooo000Nooooo`?o0000
4?ooool2o`0000gooooo0_l00020ooooo`;o0000K?ooool2o`0003Kooooo000Nooooo`03o`000?oo
oooooooo00[ooooo0_l00004ooooo`;o0000J?ooool2o`0002Gooooo0_l0001/ooooo`;o00007_oo
ool2o`0001Kooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0000eooooo`;o0000:Oooool2
o`0000cooooo0_l0000Qooooo`;o0000<Oooool2o`0003_ooooo0_l0000Pooooo`;o00005_ooool0
01kooooo00?o0000ooooooooool02Oooool2o`0000_ooooo0_l00006ooooo`;o00008Oooool2o`00
02Wooooo0_l0000_ooooo`;o00005oooool2o`0001Sooooo0_l0000kooooo`;o0000>?ooool001ko
oooo00?o0000ooooooooool02Oooool2o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l0
00001_ooool2o`0009Kooooo0ol0002>ooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o0000
0_ooool2o`0000Wooooo0_l0002Gooooo`;o0000S_ooool001kooooo00?o0000ooooooooool02?oo
ool2o`0001Cooooo0_l0002_ooooo`;o0000GOooool2o`0001Oooooo000Nooooo`03o`000?oooooo
oooo00Sooooo0_l00035ooooo`;o0000GOooool2o`0001Oooooo000Nooooo`03o`000?oooooooooo
09Wooooo0_l0000Eooooo`;o0000Poooool2o`00013ooooo000Nooooo`03o`000?oooooooooo033o
oooo0_l0001Wooooo`;o00005Oooool2o`0004Cooooo0_l0000mooooo`;o00004?ooool001kooooo
0_l0000aooooo`;o00001Oooool2o`0002kooooo0_l0000Mooooo`;o0000E?ooool2o`0001Sooooo
0_l0001?ooooo`007_ooool00ol0003oooooooooo`0^ooooo`;o00001oooool2o`0002kooooo0_l0
000Hooooo`;o00000oooool2o`0001;ooooo0_l00002ooooo`;o0000??ooool2o`0001Cooooo0_l0
000hooooo`;o00006Oooool001kooooo00?o0000ooooooooool0;_ooool2o`00057ooooo0_l0000G
ooooo`;o00000_ooool2o`0002?ooooo0_l0000]ooooo`;o00004oooool2o`0002?ooooo0_l0000I
ooooo`007_ooool00ol0003oooooooooo`1eooooo`;o0000C?ooool2o`0002gooooo0_l0000Coooo
o`;o0000?_ooool001kooooo00?o0000ooooooooool0MOooool2o`000003ooooool0003o000001Wo
oooo0_l0002booooo`007_ooool00ol0003oooooooooo`1hooooo`;o00006Oooool2o`0009kooooo
0_l0000Booooo`007_ooool00ol0003oooooooooo`0Yooooo`;o0000S_ooool2o`0007Sooooo0_l0
000Booooo`007_ooool00ol0003oooooooooo`0Yooooo`;o0000Foooool2o`00037ooooo0_l0000P
ooooo`;o0000FOooool2o`0000oooooo000Nooooo`;o00004Oooool2o`0000cooooo0_l0001=oooo
o`;o00005oooool2o`0001Oooooo0_l00008ooooo`;o0000<?ooool2o`0005Wooooo0_l0000?oooo
o`007_ooool2o`00017ooooo0_l0000<ooooo`;o0000;?ooool2o`0001oooooo0_l0000Xooooo`;o
00001_ooool2o`0000Sooooo0_l0000/ooooo`;o0000K_ooool001kooooo00?o0000ooooooooool0
C?ooool2o`0004Wooooo0_l0000Kooooo`;o00007?ooool2o`0000?ooooo0_l00009ooooo`;o0000
:oooool4o`0003Cooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l0002/ooooo`;o00001?oo
ool2o`0001Kooooo0_l0000>ooooo`;o0000:oooool4o`0002[ooooo0_l00008ooooo`007_ooool0
0ol0003oooooooooo`06ooooo`;o00001_ooool2o`00033ooooo0_l0001hooooo`;o00005_ooool2
o`00027ooooo0_l0000:ooooo`;o0000>_ooool2o`0000Sooooo000Nooooo`04o`000?oooooooooo
ooooo`;o00002oooool2o`00033ooooo0_l0000dooooo`;o0000OOooool2o`0000[ooooo0ol0000:
ooooo`;o0000=oooool001kooooo00Co0000oooooooooooooooo0_l0001cooooo`;o0000<_ooool2
o`0005Kooooo0_l0000:ooooo`;o0000=oooool001kooooo0_l0002[ooooo`Co00003?ooool2o`00
05?ooooo0_l0000fooooo`007_ooool2o`0009_ooooo0_l0000@ooooo`;o00003?ooool2o`00023o
oooo0_l0000aooooo`;o0000=_ooool001kooooo00?o0000ooooooooool0OOooool2o`0001_ooooo
0_l0000Iooooo`;o00009Oooool2o`0006Wooooo000Nooooo`03o`000?oooooooooo06kooooo0_l0
000=ooooo`;o0000=_ooool2o`0006_ooooo0_l0000Sooooo`007_ooool2o`00037ooooo0_l0000K
ooooo`;o00007oooool2o`0002Oooooo0_l0000Pooooo`;o0000=?ooool2o`00037ooooo0_l0000S
ooooo`007_ooool2o`0000Sooooo0_l0000Wooooo`;o00006oooool2o`0000Kooooo0_l00010oooo
o`;o00008?ooool2o`00013ooooo0_l0000Gooooo`;o00002Oooool2o`0002;ooooo0_l0000boooo
o`007_ooool00ol0003oooooooooo`07ooooo`;o00009oooool2o`0002?ooooo0_l0001^ooooo`;o
00001?ooool2o`0001Oooooo0_l0000]ooooo`;o0000<_ooool001kooooo00?o0000ooooooooool0
<?ooool2o`0002?ooooo0_l0001Cooooo`;o00006Oooool2o`0000kooooo0_l0000Gooooo`;o0000
3?ooool2o`0004Wooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0000Uooooo`;o0000:Ooo
ool2o`0004;ooooo0_l0000?ooooo`;o0000:Oooool2o`0001Oooooo0_l00002ooooo`Co00001_oo
ool2o`00023ooooo0_l0000Wooooo`007_ooool00ol0003oooooooooo`03ooooo`;o00006oooool2
o`0000Sooooo0_l0001]ooooo`;o0000Eoooool4o`0002Sooooo0_l0000?ooooo`;o00005_ooool0
01kooooo0ol0000Pooooo`;o0000loooool2o`0000[ooooo0_l0000<ooooo`;o00005_ooool001ko
oooo0ol0003ooooooaKooooo0_l00002ooooo`;o00001_ooool2o`0002Cooooo000Nooooo`?o0000
COooool2o`000<[ooooo0_l0000Pooooo`;o00002_ooool001kooooo0ol0000hooooo`;o00004ooo
ool2o`0005[ooooo0_l0000eooooo`;o0000FOooool2o`0000[ooooo000Nooooo`03o`000?oooooo
oooo03Sooooo0_l0000;ooooo`;o00004?ooool2o`00017ooooo0_l0000mooooo`;o0000<oooool4
o`0005[ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`0aooooo`;o00004_ooool2o`00
00;ooooo0_l0000<ooooo`;o00004Oooool2o`0007;ooooo0_l0001Looooo`;o00002Oooool001ko
oooo00?o0000ooooooooool0<Oooool2o`0001Kooooo0_l00004ooooo`?o0000:Oooool2o`0002go
oooo0_l0002Kooooo`007_ooool2o`00053ooooo0ol0000Yooooo`;o00009oooool2o`0000Cooooo
0_l00014ooooo`;o0000EOooool001kooooo00?o0000ooooooooool02oooool2o`0006;ooooo0_l0
000Zooooo`;o00001oooool4o`0004Sooooo0_l0000oooooo`;o00005?ooool001kooooo00?o0000
ooooooooool01Oooool2o`0000Cooooo0_l0001Rooooo`;o00002?ooool2o`00023ooooo0_l00009
ooooo`;o0000ROooool2o`0001Cooooo000Nooooo`03o`000?oooooooooo00Gooooo0_l0000Ooooo
o`;o0000DOooool2o`0000;ooooo0_l0000_ooooo`;o00002oooool2o`0004Gooooo0_l0000_oooo
o`;o00004_ooool001kooooo00?o0000ooooooooool08?ooool2o`0000Cooooo0_l0000kooooo`;o
00006?ooool2o`0002oooooo0_l0000;ooooo`;o00006_ooool2o`0002Wooooo0_l0000_ooooo`?o
00004Oooool001kooooo00?o0000ooooooooool08?ooool2o`0003?ooooo0_l0000<ooooo`;o0000
2Oooool2o`0006Oooooo0_l00007ooooo`;o00005?ooool2o`0003cooooo0_l0000Aooooo`007_oo
ool00ol0003oooooooooo`1Eooooo`;o00005oooool2o`0000Oooooo0_l00015ooooo`;o00008?oo
ool2o`0001Cooooo0_l0001?ooooo`007_ooool00ol0003oooooooooo`19ooooo`;o00003oooool2
o`0001_ooooo0_l00015ooooo`;o0000Qoooool001kooooo00?o0000ooooooooool02oooool2o`00
03Gooooo0_l00005ooooo`;o00003oooool2o`0000[ooooo0_l0000Nooooo`;o0000:Oooool2o`00
09Cooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l0000Gooooo`;o00002?ooool2o`00013o
oooo1?l00008ooooo`;o00006?ooool2o`0001kooooo0_l0000Yooooo`;o0000??ooool2o`0003oo
oooo0_l0000Eooooo`007_ooool00ol0003oooooooooo`0Tooooo`;o00002?ooool2o`0000Oooooo
0_l00007ooooo`;o00002_ooool2o`000:7ooooo0_l0000Uooooo`;o00006?ooool2o`0001Gooooo
000Nooooo`03o`000?oooooooooo023ooooo0_l0000Eooooo`;o0000cOooool2o`0000kooooo0_l0
000_ooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o00004_ooool2o`0007[ooooo0_l0000G
ooooo`;o0000Coooool2o`0003oooooo000Nooooo`03o`000?oooooooooo00cooooo0_l0001Noooo
o`;o0000;_ooool2o`00013ooooo0_l00005ooooo`;o0000T?ooool000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool04?ooool2o`00
05[ooooo0_l0000Uooooo`;o00006Oooool2o`0007cooooo0_l0000Iooooo`000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool0
0ol0003oooooooooo`0@ooooo`;o0000POooool2o`0000?ooooo0_l0000cooooo`;o00001_ooool2
o`0004gooooo0_l00006ooooo`;o00003_ooool2o`0000Wooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`?o00006_ooool2o`0007cooooo0_l0000c
ooooo`;o00001_ooool2o`0000Sooooo0_l00013ooooo`;o00005_ooool2o`0000Wooooo0003oooo
o`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooo
oooo01[ooooo0_l00033ooooo`;o00002_ooool2o`0005[ooooo0003ooooo`05o`000?oooooooooo
ooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo00oooooo0_l0000i
ooooo`;o00002?ooool2o`0009Gooooo0_l0001?ooooo`;o00002Oooool000?ooooo00Go410@oooo
oooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03oooool2
o`0003Wooooo0_l00004ooooo`;o00000_ooool2o`000:3ooooo0_l00014ooooo`;o00002Oooool0
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_oo
ool00ol0003oooooooooo`1@ooooo`;o0000V?ooool2o`0000[ooooo0_l0000Pooooo`;o0000;Ooo
ool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
1_ooool00ol0003oooooooooo`1Looooo`;o00009?ooool2o`0006Kooooo0_l0000?ooooo`;o0000
6oooool2o`0002gooooo000Nooooo`03o`000?oooooooooo03Kooooo0_l0000Tooooo`;o00009?oo
ool2o`0007Oooooo0_l0001:ooooo`007Oooool2o`0000Cooooo0_l0000booooo`;o0000ooooool@
ooooo`007Oooool2o`000004ooooool0003o0000ooooo`;o0000j_ooool2o`0005Oooooo000Noooo
o`04o`000?oooooo0000o`0001oooooo0_l0003<ooooo`;o0000Eoooool001kooooo00?o0000oooo
ooooool03oooool2o`0000oooooo0_l0000Gooooo`;o0000ooooool=ooooo`007_ooool00ol0003o
ooooooooo`09ooooo`;o00001?ooool2o`0000Oooooo0_l0000Oooooo`;o00005Oooool2o`0003Co
oooo0_l0000Zooooo`;o0000NOooool2o`0000Kooooo0_l0000@ooooo`007_ooool00ol0003ooooo
ooooo`09ooooo`;o00003Oooool2o`0003Kooooo0_l0000dooooo`;o0000:_ooool2o`0007Wooooo
0_l00003ooooo`;o000000?oooooo`000?l000001oooool4o`0000Gooooo000Nooooo`03o`000?oo
oooooooo00Kooooo0_l0002Yooooo`;o0000Ooooool2o`0000[ooooo1?l00005ooooo`007_ooool0
0ol0003oooooooooo`06ooooo`;o0000B_ooool2o`0005gooooo0_l00005ooooo`;o0000>Oooool2
o`0003;ooooo0_l00002ooooo`;o00006_ooool001kooooo00?o0000ooooooooool0:oooool2o`00
02Gooooo0_l0001Tooooo`;o0000>Oooool2o`000003ooooool0003o000002?ooooo0_l0000:oooo
o`;o00000_ooool2o`0001[ooooo000Nooooo`03o`000?oooooooooo02_ooooo0_l00004ooooo`;o
0000P_ooool2o`0001?ooooo0_l0000Zooooo`;o00008oooool4o`0002Sooooo000Nooooo`;o0000
4_ooool2o`0001kooooo0_l00014ooooo`;o00004Oooool2o`0002Wooooo0_l0000Cooooo`;o0000
>Oooool2o`0000gooooo0_l00007ooooo`;o0000:?ooool001kooooo00?o0000ooooooooool03ooo
ool4o`0005[ooooo0_l00008ooooo`;o00004Oooool2o`0000Cooooo0_l0000Iooooo`;o0000F?oo
ool2o`0000gooooo0_l0000aooooo`007_ooool00ol0003oooooooooo`04ooooo`;o00002Oooool2
o`0004cooooo0_l0000>ooooo`;o00003_ooool2o`00017ooooo0_l0000Iooooo`;o0000V_ooool0
01kooooo00?o0000ooooooooool01?ooool2o`0005Oooooo0_l0000Nooooo`;o0000=oooool2o`00
06cooooo0_l0000Qooooo`007_ooool00ol0003oooooooooo`1Kooooo`Co0000Eoooool2o`0004oo
oooo0_l0000Gooooo`;o00000_ooool2o`00027ooooo000Nooooo`03o`000?oooooooooo05_ooooo
1?l0001Fooooo`;o00000_ooool2o`0004cooooo0_l0000Gooooo`;o00009Oooool001kooooo00?o
0000ooooooooool0Joooool2o`0002Cooooo0_l0000Rooooo`;o00000_ooool2o`0004Oooooo0_l0
000Looooo`;o00009Oooool001kooooo00?o0000ooooooooool07_ooool2o`0000;ooooo0_l00017
ooooo`;o00009?ooool2o`0000oooooo0_l0001Nooooo`;o00007?ooool2o`0000gooooo0_l0000F
ooooo`007Oooool2o`0000cooooo0_l0000Booooo`;o00000_ooool2o`0007[ooooo0_l00002oooo
o`;o0000O?ooool2o`0000gooooo0_l0000Fooooo`007Oooool2o`0000Oooooo0_l00003ooooo`;o
0000Q?ooool2o`0000cooooo0_l0001>ooooo`;o0000<?ooool2o`0002Gooooo000Nooooo`03o`00
0?oooooooooo00Gooooo0_l00007ooooo`;o00009?ooool2o`0001_ooooo0_l0000Looooo`;o0000
7oooool2o`0002_ooooo0_l00005ooooo`;o00002oooool2o`0000Kooooo0_l0000Cooooo`;o0000
Eoooool001kooooo00?o0000ooooooooool03_ooool2o`0002Cooooo0_l0000Kooooo`;o00002ooo
ool2o`0000?ooooo0_l0000:ooooo`;o0000C?ooool2o`0000Gooooo0_l0000;ooooo`;o00001_oo
ool2o`0006cooooo000Nooooo`03o`000?oooooooooo02gooooo0_l0000_ooooo`;o00000oooool2
o`0001Kooooo0_l0000=ooooo`Co00007Oooool2o`00037ooooo0_l0000gooooo`;o0000;_ooool0
01kooooo00?o0000ooooooooool07?ooool2o`0000oooooo0_l0001<ooooo`;o00003Oooool4o`00
01gooooo0_l0000aooooo`;o00004oooool2o`0002;ooooo0_l0000Aooooo`;o00006oooool001ko
oooo00?o0000ooooooooool07?ooool2o`0004_ooooo0_l0001aooooo`;o00005Oooool2o`00013o
oooo0_l0000Sooooo`;o00004Oooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo06Wooooo
0_l0000Iooooo`;o00006_ooool2o`0003[ooooo0_l0000Wooooo`;o0000=_ooool2o`0000Sooooo
000Nooooo`;o0000;oooool2o`0003?ooooo0_l0000Oooooo`;o00006_ooool2o`0007;ooooo0_l0
000aooooo`007_ooool00ol0003oooooooooo`0^ooooo`;o0000<oooool2o`0008[ooooo0_l0000S
ooooo`;o00004oooool2o`0001cooooo000Nooooo`03o`000?oooooooooo00gooooo0_l0000joooo
o`;o0000D?ooool2o`0002oooooo0_l0000Qooooo`;o0000>?ooool2o`0001cooooo000Nooooo`03
o`000?oooooooooo00gooooo0_l0000Looooo`;o00007?ooool2o`0001_ooooo0_l0000cooooo`;o
00001Oooool2o`0002Sooooo0_l0001Vooooo`;o00004Oooool001kooooo00?o0000ooooooooool0
:oooool2o`0000gooooo0_l0000Zooooo`;o0000>_ooool2o`0003kooooo0_l0000=ooooo`;o0000
@Oooool2o`00017ooooo000Nooooo`03o`000?oooooooooo03[ooooo0_l0002Vooooo`;o00003Ooo
ool2o`0005Cooooo000Nooooo`03o`000?oooooooooo03kooooo0_l0001hooooo`;o0000SOooool0
01kooooo00?o0000ooooooooool0>_ooool2o`0000;ooooo0_l0001dooooo`;o00000_ooool2o`00
02_ooooo0_l0000Uooooo`;o0000>Oooool001kooooo00?o0000ooooooooool0>_ooool2o`00073o
oooo0_l00006ooooo`;o0000;oooool2o`0002Gooooo0_l0000iooooo`007_ooool00ol0003ooooo
ooooo`0mooooo`;o00005oooool2o`0005Cooooo0_l0001/ooooo`;o0000:oooool001kooooo00?o
0000ooooooooool0?Oooool2o`0001Oooooo0_l0000:ooooo`;o0000;Oooool2o`0008Oooooo0_l0
000[ooooo`007_ooool01?l0003oooooo`000?l0001Gooooo`;o00002?ooool2o`0002gooooo0_l0
002dooooo`007_ooool01?l0003oooooo`000?l00013ooooo`;o00004_ooool2o`0003Kooooo0_l0
000<ooooo`;o0000=oooool2o`0006kooooo000Nooooo`03o`000?oooooooooo03gooooo0_l00005
ooooo`;o00007Oooool2o`0002_ooooo0_l0000<ooooo`;o00004Oooool2o`0001oooooo1?l00000
0ooooooo0000o`000019ooooo`;o00008oooool001kooooo00?o0000ooooooooool00_ooool2o`00
03Wooooo0_l0000Tooooo`;o0000C?ooool2o`0001cooooo0_l000000ooooooo0000o`000002o`00
04cooooo0_l0000Sooooo`007_ooool00ol0003oooooooooo`02ooooo`;o00000_ooool2o`0008;o
oooo0_l00013ooooo`;o0000B?ooool2o`0002cooooo000Nooooo`;o00001oooool2o`0002Cooooo
0_l000000ooooooo0000o`000002o`0005Oooooo0_l00009ooooo`;o0000P_ooool2o`0002cooooo
000Nooooo`03o`000?oooooooooo02cooooo0_l000000ooooooo0000o`000002o`0001Sooooo0_l0
000Uooooo`;o00008Oooool2o`000;3ooooo000Nooooo`03o`000?oooooooooo04_ooooo0_l0000U
ooooo`;o00005Oooool2o`0002_ooooo0_l0001Nooooo`;o0000;oooool001kooooo00?o0000oooo
ooooool0ROooool2o`0000cooooo0_l0000Mooooo`;o0000G_ooool2o`0002oooooo000Nooooo`03
o`000?oooooooooo09Oooooo0_l0002^ooooo`007_ooool00ol0003oooooooooo`0booooo`;o0000
4?ooool2o`0003Cooooo1Ol0001oooooo`;o0000Aoooool001kooooo00?o0000ooooooooool05?oo
ool2o`0001cooooo0_l00006ooooo`;o00002?ooool2o`0001kooooo0_l0000Dooooo`Go0000;ooo
ool2o`0001;ooooo0_l0000Gooooo`;o00006?ooool2o`0000Oooooo0_l00017ooooo`007_ooool0
0ol0003oooooooooo`0Cooooo`?o00009?ooool2o`0002Sooooo0_l00018ooooo`;o00004_ooool2
o`0001Oooooo0_l0000Hooooo`;o0000A?ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo
01?ooooo0_l0000Tooooo`;o0000EOooool2o`0003Oooooo0_l0001`ooooo`;o00002_ooool001ko
oooo00?o0000ooooooooool0>Oooool2o`0004kooooo0_l00005ooooo`;o0000=oooool2o`0000[o
oooo0_l0001`ooooo`007_ooool00ol0003oooooooooo`1Nooooo`;o0000:Oooool2o`0004[ooooo
0_l0000Pooooo`;o0000C_ooool001kooooo00?o0000ooooooooool02?ooool2o`0001_ooooo0_l0
000gooooo`;o00002_ooool2o`00017ooooo0_l0001hooooo`;o00002?ooool2o`0003kooooo0_l0
0004ooooo`007_ooool00ol0003oooooooooo`08ooooo`;o00006oooool2o`0004?ooooo0_l0000A
ooooo`;o00004?ooool2o`0001Sooooo0_l0001Fooooo`;o0000?_ooool2o`0000Cooooo000Noooo
o`03o`000?oooooooooo08oooooo1?l0000Fooooo`;o0000>Oooool2o`00067ooooo0003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04oooo
o`03o`000?oooooooooo00kooooo0ol0000hooooo`;o0000=oooool2o`0000gooooo0_l0000]oooo
o`;o00008_ooool2o`00067ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0>ooooo`?o00009?ooool2o`00
00[ooooo0_l00006ooooo`;o0000=oooool2o`0003cooooo0_l00002ooooo`;o00002?ooool2o`00
07Oooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol0000eoooo
o`;o00002_ooool2o`00087ooooo0_l00008ooooo`;o00005?ooool2o`0001[ooooo0_l00015oooo
o`000oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool0
0ol0003oooooooooo`0^ooooo`;o0000DOooool2o`00067ooooo0_l0000Jooooo`;o00009Oooool2
o`0000Cooooo0ol0000Gooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgM
oeEEEOoooooo00001oooool00ol0003oooooooooo`0Vooooo`;o00001_ooool2o`00057ooooo0_l0
002=ooooo`;o00005Oooool2o`0000Cooooo0ol0000Gooooo`000oooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0Vooooo`;o0000aOoo
ool2o`00027ooooo0_l0000eooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o
k^k^odA4A?l000001oooool00ol0003oooooooooo`0?ooooo`;o00008_ooool2o`0004?ooooo0_l0
001Aooooo`;o00008?ooool2o`0001?ooooo0_l0000fooooo`;o00002oooool000?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool03ooo
ool2o`0002;ooooo0_l00013ooooo`;o0000DOooool2o`0003Gooooo0_l0000fooooo`;o00002ooo
ool001kooooo00?o0000ooooooooool0Boooool4o`0002Oooooo0_l0000<ooooo`;o0000H_ooool2
o`0005gooooo000Nooooo`03o`000?oooooooooo04_ooooo1?l0000Wooooo`;o00002oooool3o`00
04Wooooo0_l00003ooooo`;o00004_ooool2o`0000Sooooo0_l00014ooooo`;o00003Oooool001ko
oooo00?o0000ooooooooool05_ooool2o`00037ooooo0_l00003ooooo`;o00001?ooool2o`0002go
oooo0_l000000ooooooo0000o`00000aooooo`;o00005?ooool2o`0000?ooooo0_l0000Looooo`;o
0000A?ooool2o`0000gooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0000Booooo`;o0000
:?ooool2o`0000Oooooo0_l00003ooooo`;o00000_ooool4o`00017ooooo0_l0000Mooooo`;o0000
<Oooool2o`0001oooooo0_l00012ooooo`;o00009oooool001kooooo00?o0000ooooooooool00_oo
ool2o`0003cooooo0_l0000@ooooo`;o00002_ooool2o`0000Oooooo0_l0000Yooooo`;o0000A_oo
ool2o`0001;ooooo0_l0000Vooooo`;o00001_ooool2o`0001Gooooo0_l0000@ooooo`007_ooool0
0ol0003oooooooooo`0Aooooo`;o0000:?ooool2o`0000Oooooo0_l0000Hooooo`;o0000<Oooool3
o`0005[ooooo0_l0000Vooooo`;o00007Oooool2o`00013ooooo000Nooooo`03o`000?oooooooooo
017ooooo0_l0000Xooooo`?o00001_ooool2o`0003kooooo0_l0000;ooooo`;o00005Oooool2o`00
067ooooo0_l0000Iooooo`;o00007oooool001kooooo00?o0000ooooooooool01?ooool2o`0002[o
oooo0_l0000:ooooo`;o0000A_ooool2o`0000Gooooo0_l0000Kooooo`;o0000HOooool2o`0001Wo
oooo0_l0000Oooooo`007_ooool00ol0003oooooooooo`04ooooo`;o0000:_ooool2o`0002cooooo
0_l0000[ooooo`;o0000;oooool2o`0008Wooooo000Nooooo`04o`000?ooooooooooooooo`;o0000
Foooool2o`0005cooooo0_l0000looooo`;o00006oooool2o`0002kooooo000Nooooo`04o`000?oo
ooooooooooooo`;o0000POooool2o`0002?ooooo0_l00005ooooo`;o0000A_ooool4o`0001_ooooo
0_l0000^ooooo`007_ooool2o`0008Gooooo0_l0000<ooooo`;o00004oooool4o`0000Gooooo0_l0
0016ooooo`;o0000COooool001kooooo00?o0000ooooooooool01?ooool2o`0001oooooo0_l0001?
ooooo`;o00003Oooool2o`0000_ooooo0_l0000Cooooo`;o00001_ooool2o`0003oooooo0_l00004
ooooo`;o0000Coooool001kooooo00?o0000ooooooooool01?ooool2o`0001oooooo0_l00007oooo
o`;o00003Oooool2o`0000cooooo0_l0000;ooooo`;o00007?ooool2o`0000gooooo0_l0000:oooo
o`;o00007?ooool2o`0003oooooo0_l00004ooooo`;o00009Oooool2o`0002Sooooo000Nooooo`03
o`000?oooooooooo02kooooo0_l0000=ooooo`;o00003?ooool2o`0000_ooooo0_l0000Iooooo`;o
000000?oooooo`000?l000006Oooool2o`00043ooooo0_l00018ooooo`;o0000:?ooool001kooooo
00?o0000ooooooooool0Loooool2o`0000kooooo0_l00008ooooo`;o0000A?ooool2o`0000Cooooo
0_l0001/ooooo`007_ooool00ol0003oooooooooo`23ooooo`;o00002?ooool2o`0004[ooooo0_l0
000Uooooo`;o00003_ooool2o`0003Gooooo000Nooooo`03o`000?oooooooooo0?oooooo0Oooool2
o`0000kooooo0_l0000Rooooo`;o00004Oooool001kooooo00?o0000ooooooooool0/?ooool2o`00
02cooooo0_l0001Dooooo`;o00004Oooool001kooooo00?o0000ooooooooool0U_ooool2o`0001So
oooo0_l0000/ooooo`;o00005oooool2o`0000Kooooo0_l00016ooooo`007_ooool00ol0003ooooo
ooooo`0?ooooo`;o00007Oooool2o`0001?ooooo0_l0000?ooooo`;o000000?oooooo`000?l00000
3?ooool2o`0002oooooo0_l0000looooo`;o00008Oooool2o`0000Kooooo0ol00002ooooo`;o0000
@Oooool001kooooo00?o0000ooooooooool03oooool2o`0001gooooo0_l0000Cooooo`;o00003ooo
ool2o`000003ooooool0003o000000cooooo0_l0000nooooo`;o0000;Oooool2o`0002[ooooo0_l0
0002ooooo`;o0000@Oooool001kooooo00?o0000ooooooooool0I?ooool2o`0003oooooo0_l0001M
ooooo`;o0000@Oooool001kooooo00?o0000ooooooooool0=_ooool2o`0002cooooo0_l0000Voooo
o`;o0000M_ooool2o`0000?ooooo0_l0000looooo`007_ooool00ol0003oooooooooo`0fooooo`;o
00002oooool2o`0000cooooo0_l0000iooooo`;o00005?ooool2o`0006Gooooo0_l0000Rooooo`;o
00006?ooool001kooooo00?o0000ooooooooool06?ooool2o`0002Wooooo0_l0000<ooooo`;o0000
=oooool2o`0001Kooooo0_l00007ooooo`;o0000P?ooool2o`0001Sooooo000Nooooo`03o`000?oo
oooooooo01Sooooo0_l0000Yooooo`;o00007?ooool2o`0002Oooooo0_l0000Cooooo`;o00002_oo
ool2o`0002kooooo0_l0000;ooooo`;o0000GOooool001kooooo0_l0000nooooo`;o00001?ooool2
o`0001cooooo0_l0000looooo`;o0000=_ooool2o`0000;ooooo0_l000000ooooooo0000o`000004
ooooo`;o00000_ooool2o`0005gooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0000aoooo
o`;o00005oooool2o`0007oooooo0_l00005ooooo`;o00001?ooool2o`0004Oooooo0_l0000Hoooo
o`007_ooool00ol0003oooooooooo`0:ooooo`;o00005Oooool2o`0000Sooooo0_l0000Yooooo`;o
0000A?ooool2o`00063ooooo0_l0000]ooooo`Co00000oooool2o`00017ooooo000Nooooo`03o`00
0?oooooooooo027ooooo0_l00007ooooo`Go0000KOooool2o`0000gooooo0_l00018ooooo`;o0000
1oooool2o`0002oooooo0_l00003ooooo`;o00004Oooool001kooooo00?o0000ooooooooool0:_oo
ool2o`000003ooooool0003o000003Cooooo0_l00016ooooo`;o0000B?ooool2o`0001Wooooo0_l0
000eooooo`007_ooool00ol0003oooooooooo`1Sooooo`;o0000@_ooool2o`0006Oooooo0_l0000e
ooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o0000F?ooool2o`0003Wooooo0_l00005oooo
o`;o0000W_ooool001kooooo00?o0000ooooooooool02oooool2o`0005Sooooo0_l0000Hooooo`;o
00003Oooool2o`00013ooooo0_l00017ooooo`;o0000<?ooool2o`0000kooooo0_l0000Jooooo`00
7_ooool00ol0003oooooooooo`0Xooooo`;o00008oooool2o`00033ooooo0_l0000=ooooo`;o0000
Coooool2o`0000Sooooo0_l0000`ooooo`;o00003_ooool2o`0001[ooooo000Nooooo`03o`000?oo
oooooooo02Sooooo0_l0000Aooooo`;o00004?ooool2o`0000cooooo0_l0001@ooooo`;o00001Ooo
ool2o`0002Wooooo0_l0000Fooooo`;o0000C_ooool001kooooo00?o0000ooooooooool07oooool2
o`0001[ooooo0_l0000Nooooo`;o00009oooool2o`0002Oooooo0_l00005ooooo`;o00004oooool2
o`0001;ooooo0_l0000Hooooo`;o00005Oooool2o`0003Oooooo000Nooooo`03o`000?oooooooooo
01oooooo0_l0000Tooooo`;o0000?Oooool2o`00013ooooo0_l0000aooooo`;o00004Oooool3o`00
02oooooo0_l0000gooooo`007_ooool00ol0003oooooooooo`15ooooo`Co0000COooool2o`0004Co
oooo0_l0000<ooooo`;o0000<Oooool2o`0002Sooooo000Nooooo`03o`000?oooooooooo00?ooooo
0_l0000aooooo`;o00003oooool2o`0004_ooooo0_l0000Fooooo`;o00002Oooool2o`00037ooooo
0_l0000aooooo`?o00009oooool001kooooo00?o0000ooooooooool00oooool2o`0000Gooooo0_l0
000Zooooo`;o00004Oooool2o`0004Wooooo0_l0000Fooooo`;o00002Oooool2o`0001Kooooo0_l0
001=ooooo`;o00009oooool001kooooo00?o0000ooooooooool02_ooool2o`0000Oooooo0_l0000`
ooooo`;o00000_ooool2o`0003?ooooo0_l0001?ooooo`;o0000A_ooool2o`0002kooooo000Noooo
o`;o00005?ooool2o`00033ooooo0_l0000gooooo`;o00005Oooool2o`0002;ooooo0_l0000[oooo
o`;o0000;oooool2o`0002kooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0000Eooooo`;o
0000NOooool2o`0002;ooooo0_l0000[ooooo`;o00006?ooool2o`0002?ooooo0_l00002ooooo`;o
00007?ooool001kooooo00?o0000ooooooooool00oooool2o`00013ooooo0_l00003ooooo`;o0000
8?ooool2o`0002?ooooo0_l0000hooooo`;o00006_ooool2o`0004Oooooo0_l0000Aooooo`;o0000
4?ooool2o`0000;ooooo0_l0000?ooooo`;o00002oooool001kooooo00?o0000ooooooooool05Ooo
ool2o`0002Gooooo0_l0000Sooooo`;o0000:oooool2o`0000_ooooo0_l0000Jooooo`;o0000F_oo
ool2o`0002Gooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`18ooooo`;o0000A?ooool2
o`0005Wooooo0_l0001Looooo`007_ooool00ol0003oooooooooo`0Yooooo`;o00007Oooool2o`00
03Wooooo0_l0001Sooooo`?o0000G?ooool001kooooo00?o0000ooooooooool05?ooool2o`0001?o
oooo0_l0000Qooooo`Co0000;_ooool2o`0000?ooooo0_l00007ooooo`;o0000@oooool2o`0001Go
oooo0_l0000[ooooo`;o00004?ooool2o`0001kooooo000Nooooo`03o`000?oooooooooo017ooooo
0_l000000ooooooo0000o`00000fooooo`Co0000;_ooool2o`0000cooooo0_l00013ooooo`;o0000
@_ooool2o`00013ooooo0_l0000Nooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o00001Ooo
ool2o`000003ooooool0003o000006?ooooo0_l0003<ooooo`007_ooool00ol0003oooooooooo`0:
ooooo`;o0000KOooool2o`0003gooooo0_l0002=ooooo`007_ooool00ol0003oooooooooo`1ioooo
o`;o0000?Oooool2o`0006Kooooo0_l0000Oooooo`;o00001?ooool001kooooo00?o0000oooooooo
ool0NOooool2o`0001;ooooo0_l0000Iooooo`;o0000B_ooool2o`0002[ooooo0_l0000Oooooo`;o
00001?ooool001kooooo00?o0000ooooooooool09?ooool2o`0006Oooooo0_l0000Eooooo`;o0000
0_ooool2o`0000Cooooo0_l0000Pooooo`;o00008_ooool2o`00057ooooo000Nooooo`03o`000?oo
oooooooo01Kooooo0_l0000<ooooo`;o00002_ooool2o`0004gooooo1?l0000Kooooo`;o00001?oo
ool2o`0000Sooooo0ol0000Nooooo`?o00006Oooool2o`00037ooooo0_l0000Wooooo`000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0
1_ooool00ol0003oooooooooo`0Fooooo`;o00006?ooool2o`0004gooooo1?l0000Kooooo`;o0000
00?oooooo`000?l000003?ooool2o`0001kooooo0_l0000=ooooo`;o00002oooool2o`00037ooooo
0_l0000Wooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEE
EOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2Qooooo`;o0000>oooool2o`0006Oo
oooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo0000
00Kooooo0ol0000;ooooo`;o00000_ooool2o`0001gooooo0_l0003Jooooo`;o0000>oooool000?o
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool0
0ol0003oooooooooo`0;ooooo`;o00000_ooool2o`0001gooooo0_l0002>ooooo`;o00003Oooool2
o`0003_ooooo0_l0000kooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000
oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo06Sooooo0_l0000Rooooo`;o00006_oo
ool2o`0001Cooooo0_l0000=ooooo`;o0000N?ooool000?ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0J?ooool2o`0001Oooooo0_l0
0009ooooo`;o00006_ooool2o`0009gooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo03Kooooo0_l00019ooooo`;o0000T?oo
ool2o`0000Kooooo0_l0000Zooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Co
c<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`0Booooo`;o00002?ooool2o`0001Sooooo
0_l0000Dooooo`;o0000COooool2o`0003[ooooo0_l0000jooooo`;o00001_ooool2o`0002[ooooo
000Nooooo`03o`000?oooooooooo01;ooooo0_l00008ooooo`;o0000;_ooool2o`0004gooooo0_l0
000jooooo`;o0000K_ooool001kooooo00?o0000ooooooooool08oooool2o`0000Kooooo0_l0000I
ooooo`;o0000U?ooool2o`0006Wooooo000Nooooo`03o`000?oooooooooo00gooooo0_l0000Coooo
o`?o00001_ooool2o`0001Wooooo0_l0001=ooooo`;o0000AOooool2o`0000_ooooo0_l0001@oooo
o`;o00002_ooool001kooooo00?o0000ooooooooool03Oooool2o`0001?ooooo0_l0001aooooo`?o
0000DOooool2o`0004Cooooo0_l0000:ooooo`;o00002_ooool001kooooo00?o0000ooooooooool0
A?ooool2o`0000Oooooo0_l0000Mooooo`;o0000:?ooool2o`0007_ooooo0_l0000Jooooo`;o0000
5_ooool001kooooo00?o0000ooooooooool05oooool2o`0002_ooooo0_l00007ooooo`;o00007Ooo
ool2o`0005cooooo0_l00017ooooo`;o0000<_ooool001kooooo00?o0000ooooooooool05oooool2
o`0000Sooooo0_l0002Wooooo`;o0000:?ooool2o`00057ooooo000Nooooo`03o`000?oooooooooo
01Sooooo0_l00007ooooo`;o0000>oooool2o`0003Kooooo0_l0000kooooo`;o00007oooool2o`00
057ooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0000Cooooo`;o0000>Oooool2o`0000Co
oooo0_l00003ooooo`;o0000=_ooool3o`0003[ooooo0_l0001booooo`007_ooool00ol0003ooooo
ooooo`03ooooo`Co0000=Oooool2o`0001Gooooo0_l00004ooooo`;o0000??ooool2o`0002?ooooo
0_l0000Wooooo`;o0000H?ooool001kooooo00?o0000ooooooooool01Oooool2o`0001_ooooo0_l0
000Hooooo`;o0000O_ooool2o`0002Oooooo0_l0000mooooo`;o00008Oooool001kooooo0_l0000S
ooooo`;o0000ooooool1ooooo`;o00008Oooool001kooooo00?o0000ooooooooool0A?ooool2o`00
09Kooooo0_l0001Yooooo`007_ooool00ol0003oooooooooo`11ooooo`;o000000?oooooo`000?l0
0000U_ooool2o`0006Wooooo000Nooooo`03o`000?oooooooooo02_ooooo0_l0000Dooooo`;o0000
l?ooool2o`0001;ooooo000Nooooo`03o`000?oooooooooo02_ooooo0_l0000Tooooo`;o0000h?oo
ool2o`0001;ooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0000Yooooo`;o00007?ooool2
o`0008cooooo0_l0000Kooooo`;o0000BOooool001kooooo00?o0000ooooooooool02?ooool2o`00
02Wooooo0_l0000_ooooo`;o00005Oooool2o`0006;ooooo0_l0000Kooooo`;o0000BOooool001ko
oooo00?o0000ooooooooool0?oooool2o`0001Gooooo0_l0000<ooooo`Co00004oooool2o`000003
ooooool0003o00000;7ooooo0_l0000Dooooo`007_ooool00ol0003oooooooooo`0oooooo`;o0000
5Oooool2o`0000kooooo0_l00003ooooo`;o00004Oooool2o`0004?ooooo0_l0000Rooooo`;o0000
B?ooool2o`0001Cooooo000Nooooo`03o`000?oooooooooo06_ooooo0_l0000Mooooo`;o0000=ooo
ool2o`0002;ooooo0_l00011ooooo`;o00003oooool2o`0000[ooooo000Nooooo`03o`000?oooooo
oooo00;o0000G_ooool2o`0002Sooooo0_l0000Gooooo`;o0000=_ooool2o`0001Oooooo0_l0000d
ooooo`;o00003oooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00;o0000:oooool2o`00
037ooooo0_l00011ooooo`;o0000=_ooool2o`0001Oooooo0_l0001Aooooo`007_ooool00ol0003o
ooooooooo`0@ooooo`;o00006oooool2o`000?_ooooo0_l0000Kooooo`007_ooool00ol0003ooooo
ooooo`0@ooooo`;o00003Oooool2o`0003Wooooo0_l0000@ooooo`;o0000;Oooool2o`0000Wooooo
0_l00010ooooo`;o0000@?ooool2o`0001_ooooo000Nooooo`03o`000?oooooooooo01cooooo0_l0
00000ooooooo0000o`000002ooooo`;o0000=Oooool2o`00013ooooo0_l0000=ooooo`;o00002?oo
ool2o`0001Cooooo0_l00009ooooo`;o0000@?ooool2o`0005gooooo000Nooooo`03o`000?oooooo
oooo01cooooo0_l00005ooooo`;o0000E_ooool2o`0000Sooooo0_l00015ooooo`;o0000B_ooool2
o`0002gooooo000Nooooo`;o0000cOooool2o`0001cooooo0_l0000/ooooo`;o0000;Oooool001ko
oooo00?o0000ooooooooool0coooool2o`0001Wooooo0_l0001Kooooo`007_ooool00ol0003ooooo
ooooo`0Looooo`;o0000Eoooool2o`0005Sooooo0_l0000Pooooo`;o0000E?ooool001kooooo00?o
0000ooooooooool07?ooool2o`0001;ooooo0_l00013ooooo`;o0000N_ooool2o`0003Wooooo0_l0
000Iooooo`007_ooool00ol0003oooooooooo`0`ooooo`;o0000n_ooool2o`0001Wooooo000Noooo
o`03o`000?oooooooooo00Wooooo0_l0003<ooooo`;o0000K_ooool001kooooo00?o0000oooooooo
ool02Oooool2o`0003Gooooo0_l0000Fooooo`;o0000:_ooool2o`0000gooooo0_l00012ooooo`;o
0000K_ooool001kooooo00?o0000ooooooooool0@?ooool2o`0001Kooooo0_l0000Zooooo`;o0000
3Oooool2o`0002?ooooo0_l0000Wooooo`;o0000I?ooool001kooooo00?o0000ooooooooool0J_oo
ool2o`0003_ooooo0_l0000?ooooo`;o00009oooool2o`0006Cooooo000Nooooo`03o`000?oooooo
oooo06[ooooo0_l0000kooooo`;o0000J?ooool4o`0001Cooooo0_l00002ooooo`;o00006?ooool0
01kooooo00?o0000ooooooooool0<oooool2o`000;3ooooo0_l0000Zooooo`Co00005?ooool2o`00
00;ooooo0_l0000Hooooo`007_ooool00ol0003oooooooooo`0cooooo`;o0000A?ooool2o`0005Co
oooo0_l0000Dooooo`;o00001oooool2o`00017ooooo0_l00014ooooo`007_ooool00ol0003ooooo
ooooo`0Aooooo`;o0000Eoooool2o`0000gooooo0_l0001Dooooo`;o00007Oooool2o`00017ooooo
0_l0000/ooooo`;o00005_ooool001kooooo00?o0000ooooooooool04Oooool2o`0005Oooooo0_l0
0003ooooo`;o0000Q_ooool2o`0003Kooooo0_l0000:ooooo`;o00002_ooool001kooooo00?o0000
ooooooooool04?ooool2o`0002kooooo0_l0000Sooooo`;o00001?ooool2o`0000;ooooo0_l0001m
ooooo`;o00001oooool2o`0004;ooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0@oooo
o`;o0000;_ooool2o`0001gooooo0_l00004ooooo`;o00001?ooool2o`0001Kooooo0_l0001Yoooo
o`;o0000Eoooool001kooooo0_l00003ooooo`;o0000Foooool2o`0002;ooooo0_l00032ooooo`00
7_ooool00ol0003oooooooooo`02ooooo`;o0000]_ooool2o`00013ooooo0_l0001iooooo`007_oo
ool00ol0003oooooooooo`1Oooooo`;o0000FOooool2o`00013ooooo0_l0000:ooooo`;o0000KOoo
ool001kooooo00?o0000ooooooooool0Goooool2o`0003Gooooo0_l00010ooooo`;o0000KOooool0
01kooooo00?o0000ooooooooool0GOooool2o`0003Oooooo0_l0000Hooooo`;o00003Oooool2o`00
02gooooo0_l0001Gooooo`007_ooool00ol0003oooooooooo`0]ooooo`;o0000;_ooool2o`0004So
oooo0_l00007ooooo`;o00003Oooool2o`0001kooooo1?l0000;ooooo`;o0000Eoooool001kooooo
00?o0000ooooooooool0;Oooool2o`0005oooooo0_l00008ooooo`;o00003Oooool2o`0003Kooooo
1?l0001;ooooo`;o00005oooool001kooooo00?o0000ooooooooool0Q_ooool2o`0000Kooooo0_l0
0008ooooo`;o00006_ooool2o`0005Cooooo0_l0000Rooooo`;o00005oooool001kooooo00?o0000
ooooooooool0=?ooool2o`00053ooooo0_l0000/ooooo`;o00006?ooool2o`0003[ooooo0_l0000k
ooooo`007_ooool00ol0003oooooooooo`0dooooo`;o0000V?ooool2o`0001kooooo0_l0001Goooo
o`007_ooool00ol0003oooooooooo`0_ooooo`;o0000<Oooool2o`0008[ooooo0_l0001Gooooo`00
7_ooool00ol0003oooooooooo`0Mooooo`;o00004?ooool2o`00037ooooo0_l00012ooooo`;o0000
6Oooool2o`0008Cooooo000Nooooo`03o`000?oooooooooo01gooooo0_l0000Gooooo`;o0000K_oo
ool2o`0001Wooooo0_l0000hooooo`;o0000B_ooool001kooooo00?o0000ooooooooool0=_ooool2
o`0007Oooooo0_l0000Zooooo`;o00007_ooool2o`0004[ooooo0003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oo
oooooooo01Gooooo0_l0000Kooooo`;o00009_ooool2o`0002[ooooo0_l00004ooooo`;o00008Ooo
ool2o`0002[ooooo0_l0001Zooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0@ooooo`;o0000
0oooool2o`0001_ooooo0_l0000Vooooo`;o00001?ooool2o`0000;ooooo0_l0000Pooooo`;o0000
1?ooool2o`0001_ooooo0_l00008ooooo`;o00001Oooool2o`0008_ooooo0003ooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0000@ooooo`;o
0000C_ooool2o`0000;ooooo0_l0000Jooooo`;o00009oooool2o`0000Sooooo0_l00005ooooo`;o
00008oooool2o`0002?ooooo0_l00011ooooo`000oooool01Ol0003ooooooooooooooooo000000_o
oooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooooooo017ooooo0_l0000moooo
o`;o0000;_ooool2o`0003;ooooo0_l0000Yooooo`;o00004?ooool2o`00013ooooo0ol00011oooo
o`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006
ooooo`03o`000?oooooooooo017ooooo0_l0000Uooooo`;o00005_ooool2o`0006;ooooo0_l0000F
ooooo`Co00008Oooool2o`00013ooooo0_l00012ooooo`000oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo02Sooooo0_l0
000>ooooo`;o0000E?ooool2o`0000Wooooo0_l00005ooooo`;o00009oooool2o`000003ooooool0
003o000000;o00007Oooool2o`0003Wooooo0_l0000Mooooo`000oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo013ooooo
0_l0000>ooooo`;o00001_ooool2o`0003Oooooo0_l0000[ooooo`;o00002Oooool2o`0000Gooooo
0_l0000Wooooo`;o00008_ooool2o`0003Wooooo0_l0000Mooooo`000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo013o
oooo0_l0000<ooooo`Co0000?oooool2o`0002_ooooo0_l00019ooooo`;o0000K?ooool001kooooo
00?o0000ooooooooool07_ooool3o`0002Wooooo0_l00012ooooo`;o00009oooool2o`0000oooooo
0_l0000?ooooo`;o0000K?ooool001kooooo00?o0000ooooooooool05Oooool2o`0000Sooooo0_l0
000Mooooo`;o00002_ooool2o`0001cooooo0_l0001;ooooo`Co00003oooool2o`0003Gooooo0_l0
0016ooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o00000oooool2o`0002Oooooo0_l0000X
ooooo`;o0000Boooool2o`0004Sooooo0_l0000/ooooo`;o00006?ooool001kooooo00?o0000oooo
ooooool04?ooool2o`0004gooooo0_l0000Oooooo`;o0000Zoooool2o`0001Sooooo000Nooooo`03
o`000?oooooooooo01Cooooo0_l00019ooooo`;o00007oooool2o`0006kooooo0_l0000Booooo`;o
0000@Oooool001kooooo00?o0000ooooooooool05?ooool2o`0007Kooooo0_l0001Rooooo`;o0000
4_ooool2o`00047ooooo000Nooooo`03o`000?oooooooooo06cooooo0_l0000Nooooo`;o0000Rooo
ool2o`0002cooooo000Nooooo`03o`000?oooooooooo06cooooo0_l0001iooooo`;o0000<?ooool2
o`0002cooooo000Nooooo`03o`000?oooooooooo07?ooooo0_l0001?ooooo`;o00008Oooool2o`00
05kooooo000Nooooo`03o`000?oooooooooo05?ooooo0_l0000Nooooo`;o000000?oooooo`000?l0
0000C?ooool2o`00087ooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0001:ooooo`;o0000
8Oooool2o`000<oooooo000Nooooo`;o00002?ooool2o`0002Gooooo0_l0000iooooo`;o0000C?oo
ool2o`0002[ooooo0_l0001Rooooo`007_ooool00ol0003oooooooooo`02o`0002cooooo0_l0000i
ooooo`;o00002Oooool2o`00047ooooo0_l0000Zooooo`;o00003Oooool2o`0001oooooo0_l0000>
ooooo`;o00008_ooool001kooooo00?o0000ooooooooool00_l0000Nooooo`;o0000?Oooool2o`00
01?ooooo0_l0001looooo`;o00007oooool2o`0000kooooo0_l0000Rooooo`007_ooool00ol0003o
ooooooooo`0@ooooo`;o00003_ooool2o`0003gooooo0_l0000^ooooo`;o0000]_ooool001kooooo
00?o0000ooooooooool04?ooool2o`0004Oooooo0_l0000Xooooo`;o00002_ooool2o`000;Kooooo
000Nooooo`03o`000?oooooooooo05Cooooo0_l00003ooooo`;o0000:?ooool2o`000<;ooooo000N
ooooo`03o`000?oooooooooo03;ooooo0_l0000Pooooo`;o0000lOooool001kooooo00?o0000oooo
ooooool0<_ooool2o`0000kooooo0_l0000Qooooo`;o0000fOooool2o`0000Gooooo000Nooooo`03
o`000?oooooooooo00Sooooo0_l0000[ooooo`;o00002oooool2o`00027ooooo0_l0002Wooooo`;o
00003?ooool2o`0002;ooooo0_l00005ooooo`007_ooool00ol0003oooooooooo`08ooooo`;o0000
:oooool2o`0004oooooo0_l0001?ooooo`;o00004Oooool2o`0001Gooooo0_l0000;ooooo`;o0000
0_ooool2o`0000Sooooo0_l0000Yooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o0000D_oo
ool2o`0002Kooooo0_l0001?ooooo`;o00004Oooool3o`0001Cooooo0_l0000?ooooo`;o0000<ooo
ool001kooooo00?o0000ooooooooool02_ooool2o`0005;ooooo0_l0000Hooooo`;o0000LOooool2
o`0005[ooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l0000gooooo`;o00006Oooool2o`00
0:gooooo0_l0000Nooooo`007_ooool00ol0003oooooooooo`0Tooooo`;o0000=Oooool4o`0002;o
oooo0_l00003ooooo`;o00004Oooool2o`0001Oooooo0_l0001cooooo`;o00007_ooool001kooooo
00?o0000ooooooooool0Foooool2o`0000cooooo0_l0000Fooooo`;o00000oooool2o`00017ooooo
0_l0000Gooooo`;o00007?ooool2o`0006kooooo0_l00005ooooo`007_ooool00ol0003ooooooooo
o`0_ooooo`;o0000>?ooool2o`0006Gooooo0_l0001^ooooo`;o00001Oooool001kooooo0_l0000`
ooooo`;o0000:Oooool2o`0005Sooooo0_l0002Aooooo`007_ooool00ol0003oooooooooo`1Joooo
o`;o0000A?ooool2o`0001;ooooo0_l0001kooooo`;o00005?ooool001kooooo00?o0000oooooooo
ool0<_ooool2o`0006cooooo0_l0002?ooooo`;o00003Oooool2o`0000Gooooo000Nooooo`03o`00
0?oooooooooo03;ooooo0_l0001Tooooo`;o00004?ooool2o`0006Wooooo0_l00007ooooo`;o0000
8?ooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo09Sooooo0_l0000@ooooo`;o0000JOoo
ool2o`0000Oooooo0_l0000Wooooo`007_ooool00ol0003oooooooooo`04ooooo`;o00001_ooool2
o`0000?ooooo0_l0003;ooooo`;o0000Ioooool001kooooo00?o0000ooooooooool01?ooool2o`00
00Kooooo0_l00003ooooo`;o0000boooool2o`0006Oooooo000Nooooo`04o`000?oooooooooooooo
o`;o0000oooooom5ooooo`007_ooool01?l0003oooooooooooooool2o`0001cooooo0_l0001Koooo
o`;o0000@?ooool2o`0006Kooooo0_l0000Oooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o
0000D?ooool2o`0000Wooooo0_l0000Looooo`;o00008_ooool2o`0006Kooooo0_l0000Oooooo`00
7_ooool00ol0003oooooooooo`0^ooooo`;o0000@Oooool2o`00027ooooo0_l00004ooooo`;o0000
R?ooool2o`00027ooooo000Nooooo`03o`000?oooooooooo02kooooo0_l00008ooooo`;o00001_oo
ool2o`000003ooooool0003o000000kooooo0_l0000oooooo`;o0000S_ooool2o`00027ooooo000N
ooooo`03o`000?oooooooooo00Gooooo0_l0000aooooo`;o00001_ooool2o`000003ooooool0003o
000000kooooo0_l0002Oooooo`;o0000DOooool001kooooo00?o0000ooooooooool01?ooool3o`00
017ooooo0_l0002kooooo`;o00007Oooool2o`00057ooooo000Nooooo`03o`000?oooooooooo00Co
oooo0_l0000Booooo`;o0000^oooool2o`0002Gooooo0_l0000Rooooo`;o00009Oooool001kooooo
00?o0000ooooooooool0Yoooool2o`0005?ooooo0_l0000Rooooo`;o00005?ooool2o`0000oooooo
000Nooooo`;o0000=Oooool2o`0000Gooooo0_l0001Zooooo`;o0000=oooool2o`0002;ooooo0_l0
000`ooooo`;o00003oooool001kooooo00?o0000ooooooooool0<?ooool2o`0000;ooooo0_l00005
ooooo`;o0000H_ooool2o`00017ooooo0_l0000/ooooo`;o00008_ooool2o`00033ooooo0_l0000?
ooooo`007_ooool00ol0003oooooooooo`0`ooooo`;o0000KOooool2o`00017ooooo0_l00007oooo
o`;o0000Aoooool2o`00047ooooo000Nooooo`03o`000?oooooooooo027ooooo0_l0000=ooooo`;o
0000C?ooool2o`0003_ooooo0_l0002:ooooo`007_ooool00ol0003oooooooooo`0Qooooo`;o0000
Eoooool2o`0000;ooooo0_l0000oooooo`;o00003Oooool2o`0004_ooooo0_l00002ooooo`;o0000
9_ooool001kooooo00?o0000ooooooooool0N_ooool2o`0004?ooooo0_l0000=ooooo`;o0000Booo
ool2o`0000;ooooo0_l0000Cooooo`;o00004Oooool001kooooo00?o0000ooooooooool0Yoooool2
o`0008_ooooo0_l0000Aooooo`007_ooool00ol0003oooooooooo`2Wooooo`;o00008oooool2o`00
07Wooooo000Nooooo`03o`000?oooooooooo0<cooooo0_l0001iooooo`007_ooool00ol0003ooooo
ooooo`0dooooo`;o0000M?ooool2o`000003ooooool0003o000000Kooooo0_l00005ooooo`;o0000
ROooool001kooooo00?o0000ooooooooool02_ooool2o`0002Sooooo0_l0001dooooo`;o000000Co
ooooo`000?l0003ooooo0_l00003ooooo`;o00001Oooool2o`0008Wooooo000Nooooo`03o`000?oo
oooooooo00[ooooo0_l0002Tooooo`;o0000;oooool2o`0006Cooooo000Nooooo`03o`000?oooooo
oooo09?ooooo0_l0000Gooooo`;o0000<oooool2o`0006Cooooo000Nooooo`03o`000?oooooooooo
09?ooooo0_l0000Gooooo`;o00000_ooool2o`0002cooooo0_l0001Wooooo`005?ooool4o`000003
oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0=Oooool2o`0002?ooooo0_l0000cooooo`;o
00007oooool2o`0000Wooooo0_l0000Qooooo`;o00000_ooool2o`0001gooooo0_l00014ooooo`00
5_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Gooooo0_l0000Dooooo`;o0000
3Oooool2o`0003?ooooo0_l0000Sooooo`;o00001Oooool2o`0002Gooooo0_l0000Cooooo`;o0000
2?ooool2o`0002Cooooo0_l0000Nooooo`005_ooool00ol0003oooooooooo`05ooooo`?o0000Booo
ool2o`0000Cooooo0_l0000:ooooo`;o0000EOooool2o`00047ooooo0_l0000^ooooo`;o00007_oo
ool001Kooooo00?o0000ooooooooool0FOooool2o`0000[ooooo0_l0003Xooooo`005_ooool00ol0
003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo
00?o0000ooooooooool0oooooom@ooooo`005?ooool00omEEEGoIVIVo`00003ooooooe;ooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.15219 .44137 Mdot
.06632 .79068 Mdot
.92623 .05627 Mdot
.30964 .70804 Mdot
.14871 .38722 Mdot
.92036 .14844 Mdot
.10123 .98989 Mdot
.16655 .61764 Mdot
.90783 .05013 Mdot
.21071 .01471 Mdot
.60113 .98061 Mdot
.00629 .65526 Mdot
.67795 .43824 Mdot
.37857 .44351 Mdot
.44507 .34874 Mdot
.3094 .64944 Mdot
.51108 .94241 Mdot
.37715 .39792 Mdot
.73152 .98868 Mdot
.8497 .87548 Mdot
.53865 .99961 Mdot
.46554 .0691 Mdot
.86102 .08111 Mdot
.16357 .46836 Mdot
.75498 .36427 Mdot
.23409 .41245 Mdot
.80625 .85991 Mdot
.63677 .39434 Mdot
.27917 .72079 Mdot
.26241 .18673 Mdot
.66187 .14313 Mdot
.33335 .32447 Mdot
.51743 .0611 Mdot
.11555 .12257 Mdot
.75423 .12479 Mdot
.98264 .65672 Mdot
.23834 .15841 Mdot
.39713 .34514 Mdot
.2002 .13711 Mdot
.01381 .953 Mdot
.02094 .29876 Mdot
.42412 .91764 Mdot
.30606 .37601 Mdot
.20929 .36311 Mdot
.71374 .33173 Mdot
.66407 .58632 Mdot
.88437 .15003 Mdot
.64955 .77842 Mdot
.22263 .36922 Mdot
.08077 .27047 Mdot
.80815 .13731 Mdot
.43199 .54214 Mdot
.11269 .74975 Mdot
.99784 .3811 Mdot
.86473 .4375 Mdot
.81868 .14285 Mdot
.5655 .97156 Mdot
.04978 .73568 Mdot
.19196 .40169 Mdot
.09864 .79422 Mdot
.18499 .38578 Mdot
.7762 .79445 Mdot
.24769 .01678 Mdot
.25448 .4075 Mdot
.06412 .46513 Mdot
.34002 .06013 Mdot
.34592 .7867 Mdot
.61428 .09783 Mdot
.18846 .29181 Mdot
.94986 .11831 Mdot
.81283 .75746 Mdot
.86551 .23025 Mdot
.12412 .66679 Mdot
.20158 .84637 Mdot
.26677 .42203 Mdot
.65443 .20591 Mdot
.90301 .68224 Mdot
.16219 .17447 Mdot
.7299 .85266 Mdot
.31569 .23964 Mdot
.51939 .6361 Mdot
.62849 .03964 Mdot
.21194 .95607 Mdot
.74352 .46004 Mdot
.7783 .40898 Mdot
.76212 .16474 Mdot
.49155 .04526 Mdot
.97241 .55008 Mdot
.55662 .0048 Mdot
.64721 .51424 Mdot
.05269 .93538 Mdot
.50973 .2916 Mdot
.22767 .67485 Mdot
.7667 .26731 Mdot
.02936 .6151 Mdot
.4104 .59577 Mdot
.1601 .28006 Mdot
.76596 .43968 Mdot
.56515 .3018 Mdot
.18888 .94247 Mdot
.56713 .32148 Mdot
.77528 .51838 Mdot
.89306 .86234 Mdot
.26039 .31258 Mdot
.72215 .70995 Mdot
.18434 .83561 Mdot
.57879 .07369 Mdot
.96424 .37788 Mdot
.16956 .01496 Mdot
.39088 .73307 Mdot
.50048 .46869 Mdot
.95339 .92441 Mdot
.78806 .50136 Mdot
.25205 .42729 Mdot
.20771 .52634 Mdot
.44276 .75785 Mdot
.43054 .67683 Mdot
.05408 .88932 Mdot
.76945 .64647 Mdot
.59492 .79914 Mdot
.74872 .45895 Mdot
.55406 .14917 Mdot
.13632 .72711 Mdot
.29727 .85188 Mdot
.42539 .41958 Mdot
.88894 .53852 Mdot
.67354 .30193 Mdot
.75975 .70394 Mdot
.51833 .76911 Mdot
.68227 .01076 Mdot
.49917 .12413 Mdot
.14796 .56736 Mdot
.21532 .59631 Mdot
.43474 .61043 Mdot
.04906 .58859 Mdot
.26664 .46221 Mdot
.40377 .97251 Mdot
.07261 .23082 Mdot
.59508 .77308 Mdot
.40971 .25685 Mdot
.26106 .1064 Mdot
.94373 .13523 Mdot
.85986 .69843 Mdot
.08074 .42169 Mdot
.70559 .33099 Mdot
.32797 .73684 Mdot
.78474 .75978 Mdot
.07625 .29147 Mdot
.22974 .43446 Mdot
.00395 .22281 Mdot
.22607 .60948 Mdot
.4399 .3159 Mdot
.98147 .3006 Mdot
.85098 .86091 Mdot
.05121 .37219 Mdot
.75279 .56124 Mdot
.19207 .47549 Mdot
.53176 .54749 Mdot
.5567 .85797 Mdot
.15364 .55362 Mdot
.42596 .32349 Mdot
.0349 .10844 Mdot
.99112 .06271 Mdot
.0282 .2061 Mdot
.86289 .55425 Mdot
.2259 .86789 Mdot
.83088 .74108 Mdot
.28506 .39334 Mdot
.60718 .5232 Mdot
.0968 .78938 Mdot
.99505 .41047 Mdot
.66875 .4066 Mdot
.36389 .07589 Mdot
.34858 .25258 Mdot
.53722 .33601 Mdot
.43989 .22476 Mdot
.33694 .72203 Mdot
.38345 .50079 Mdot
.2295 .27059 Mdot
.98596 .2049 Mdot
.01691 .45353 Mdot
.87962 .38533 Mdot
.98514 .62109 Mdot
.15768 .08574 Mdot
.72039 .44278 Mdot
.97598 .54148 Mdot
.27844 .26603 Mdot
.52118 .14923 Mdot
.55192 .54839 Mdot
.34423 .71458 Mdot
.33322 .12966 Mdot
.27358 .59967 Mdot
.5828 .68731 Mdot
.89425 .35119 Mdot
.14496 .98303 Mdot
.68327 .31952 Mdot
.61087 .45343 Mdot
.53915 .41361 Mdot
.28447 .13049 Mdot
.32193 .16261 Mdot
.1831 .64497 Mdot
.18805 .3931 Mdot
.77409 .52386 Mdot
.15987 .72003 Mdot
.07569 .48891 Mdot
.30996 .52826 Mdot
.26843 .44627 Mdot
.60566 .23288 Mdot
.61823 .1326 Mdot
.75691 .3276 Mdot
.38477 .08081 Mdot
.44096 .98055 Mdot
.85905 .05474 Mdot
.69819 .46676 Mdot
.54578 .62015 Mdot
.7123 .49727 Mdot
.12393 .02044 Mdot
.42407 .16344 Mdot
.1687 .56024 Mdot
.81712 .8486 Mdot
.86177 .63849 Mdot
.44039 .52514 Mdot
.37083 .88978 Mdot
.02448 .18469 Mdot
.39451 .73351 Mdot
.27673 .79803 Mdot
.91601 .20714 Mdot
.72904 .03021 Mdot
.56573 .70366 Mdot
.27956 .7788 Mdot
.43247 .05036 Mdot
.91014 .29554 Mdot
.24159 .56858 Mdot
.90049 .71379 Mdot
.04093 .67146 Mdot
.82792 .76207 Mdot
.48995 .94607 Mdot
.58906 .82324 Mdot
.71718 .97661 Mdot
.06571 .83184 Mdot
.12754 .85078 Mdot
.03421 .20376 Mdot
.89 .65586 Mdot
.85763 .15937 Mdot
.486 .77302 Mdot
.71922 .04926 Mdot
.43174 .97886 Mdot
.80489 .61664 Mdot
.99746 .15854 Mdot
.19474 .64219 Mdot
.09156 .32025 Mdot
.69288 .72363 Mdot
.29737 .47766 Mdot
.71618 .5445 Mdot
.51797 .73955 Mdot
.97476 .50486 Mdot
.94627 .24802 Mdot
.03427 .07356 Mdot
.22284 .1866 Mdot
.04077 .8234 Mdot
.42376 .6008 Mdot
.26282 .42155 Mdot
.48816 .43637 Mdot
.59029 .57148 Mdot
.15216 .74501 Mdot
.88093 .45985 Mdot
.47629 .82808 Mdot
.34383 .73132 Mdot
.56279 .92904 Mdot
.78063 .33379 Mdot
.71718 .62913 Mdot
.03782 .42207 Mdot
.61706 .09118 Mdot
.27138 .19512 Mdot
.27757 .49697 Mdot
.92456 .64726 Mdot
.15057 .5634 Mdot
.92489 .23179 Mdot
.47531 .61759 Mdot
.74123 .05783 Mdot
.11748 .06131 Mdot
.76333 .43122 Mdot
.02915 .83593 Mdot
.86573 .22917 Mdot
.6971 .39069 Mdot
.50623 .95366 Mdot
.69703 .50849 Mdot
.78463 .42944 Mdot
.79366 .63091 Mdot
.91015 .8245 Mdot
.34348 .21701 Mdot
.26205 .17248 Mdot
.31254 .05779 Mdot
.07314 .6973 Mdot
.75057 .92443 Mdot
.53289 .32833 Mdot
.13489 .11286 Mdot
.87309 .4303 Mdot
.83964 .4135 Mdot
.28931 .19937 Mdot
.25627 .52632 Mdot
.79283 .16266 Mdot
.1024 .54975 Mdot
.6763 .78737 Mdot
.58358 .1417 Mdot
.21795 .3288 Mdot
.27443 .83633 Mdot
.55359 .17107 Mdot
.20279 .11916 Mdot
.29137 .58773 Mdot
.44525 .52849 Mdot
.84383 .5598 Mdot
.72377 .41758 Mdot
.23849 .63585 Mdot
.16866 .81276 Mdot
.49373 .76779 Mdot
.6134 .07928 Mdot
.31448 .53649 Mdot
.85981 .41092 Mdot
.47229 .27733 Mdot
.95673 .19746 Mdot
.39782 .78577 Mdot
.36708 .26945 Mdot
.57826 .23586 Mdot
.30882 .51239 Mdot
.59264 .27335 Mdot
.0792 .5144 Mdot
.26763 .36089 Mdot
.90652 .30827 Mdot
.6104 .93142 Mdot
.04765 .44008 Mdot
.27455 .79945 Mdot
.06683 .15848 Mdot
.73307 .80253 Mdot
.05601 .78257 Mdot
.13775 .64861 Mdot
.20225 .3265 Mdot
.18769 .32926 Mdot
.04628 .23241 Mdot
.97217 .32584 Mdot
.8123 .84814 Mdot
.47088 .99891 Mdot
.19487 .33475 Mdot
.43081 .62593 Mdot
.09999 .23614 Mdot
.50356 .1275 Mdot
.47961 .27175 Mdot
.71784 .90064 Mdot
.23211 .80156 Mdot
.46117 .60073 Mdot
.2979 .00666 Mdot
.56657 .75451 Mdot
.03646 .29256 Mdot
.63911 .58835 Mdot
.63397 .96631 Mdot
.58233 .1236 Mdot
.26278 .44932 Mdot
.05887 .07199 Mdot
.91349 .20576 Mdot
.52502 .03255 Mdot
.89769 .94134 Mdot
.51762 .35554 Mdot
.83275 .39071 Mdot
.48098 .34719 Mdot
.89147 .00574 Mdot
.63239 .09201 Mdot
.04486 .26793 Mdot
.90163 .70589 Mdot
.76952 .3986 Mdot
.03007 .66342 Mdot
.98307 .1787 Mdot
.70455 .91314 Mdot
.31291 .87538 Mdot
.83145 .66055 Mdot
.34755 .68132 Mdot
.53522 .96795 Mdot
.48813 .61136 Mdot
.93669 .45793 Mdot
.21622 .50235 Mdot
.044 .12447 Mdot
.13443 .34116 Mdot
.15859 .35434 Mdot
.02809 .80766 Mdot
.64684 .39849 Mdot
.21406 .47811 Mdot
.7713 .76813 Mdot
.70214 .73775 Mdot
.40552 .52531 Mdot
.08536 .94976 Mdot
.24385 .29239 Mdot
.87445 .25771 Mdot
.44371 .90008 Mdot
.53132 .99335 Mdot
.28941 .20272 Mdot
.96552 .76136 Mdot
.70557 .65906 Mdot
.97681 .00412 Mdot
.67639 .06785 Mdot
.14214 .84049 Mdot
.59951 .28225 Mdot
.0754 .58037 Mdot
.54267 .1524 Mdot
.4109 .68974 Mdot
.4068 .35078 Mdot
.37187 .42401 Mdot
.37897 .79528 Mdot
.70712 .72232 Mdot
.78662 .05086 Mdot
.38726 .38632 Mdot
.1765 .82049 Mdot
.15304 .81285 Mdot
.86529 .60344 Mdot
.08749 .87508 Mdot
.94091 .43341 Mdot
.05273 .21484 Mdot
.43733 .43533 Mdot
.1717 .06575 Mdot
.81095 .50848 Mdot
.63859 .09988 Mdot
.73338 .84878 Mdot
.9315 .50983 Mdot
.74191 .79712 Mdot
.66626 .77212 Mdot
.41768 .36459 Mdot
.49099 .04707 Mdot
.67948 .69615 Mdot
.15876 .77733 Mdot
.07508 .57917 Mdot
.58741 .44848 Mdot
.29997 .95655 Mdot
.12719 .49571 Mdot
.16368 .44594 Mdot
.46141 .92986 Mdot
.75334 .31771 Mdot
.0196 .20138 Mdot
.04542 .42596 Mdot
.56781 .28817 Mdot
.43007 .43449 Mdot
.47429 .51996 Mdot
.26982 .99382 Mdot
.36386 .63522 Mdot
.22128 .95849 Mdot
.04025 .08968 Mdot
.15328 .95034 Mdot
.0491 .05464 Mdot
.41212 .4333 Mdot
.79308 .89664 Mdot
.37759 .20935 Mdot
.62193 .77035 Mdot
.33546 .61114 Mdot
.09406 .18924 Mdot
.9502 .90199 Mdot
.82646 .3189 Mdot
.65592 .00272 Mdot
.42338 .40968 Mdot
.74321 .95311 Mdot
.59644 .75999 Mdot
.53104 .72978 Mdot
.81091 .0439 Mdot
.19111 .71427 Mdot
.42765 .37346 Mdot
.34033 .87904 Mdot
.01696 .00257 Mdot
.43222 .88484 Mdot
.2624 .53635 Mdot
.12919 .979 Mdot
.79257 .146 Mdot
.42128 .01617 Mdot
.16368 .14125 Mdot
.90916 .30588 Mdot
.40124 .77438 Mdot
.63283 .62053 Mdot
.45034 .74612 Mdot
.03212 .15521 Mdot
.06002 .80915 Mdot
.48544 .42223 Mdot
.55502 .30557 Mdot
.63366 .56324 Mdot
.76112 .20644 Mdot
.35741 .66357 Mdot
.00292 .06567 Mdot
.86723 .2662 Mdot
.59155 .91606 Mdot
.48936 .50529 Mdot
.3638 .30133 Mdot
.44547 .26285 Mdot
.22315 .34953 Mdot
.88132 .07948 Mdot
.51489 .14949 Mdot
.59631 .51745 Mdot
.12145 .95865 Mdot
.45979 .10305 Mdot
.22772 .51449 Mdot
.60575 .99314 Mdot
.01557 .23655 Mdot
.46087 .44613 Mdot
.64804 .29573 Mdot
.76688 .12741 Mdot
.12118 .50316 Mdot
.88169 .83154 Mdot
.69374 .8012 Mdot
.3713 .38131 Mdot
.50798 .28181 Mdot
.00093 .08297 Mdot
.9961 .27843 Mdot
.43149 .2865 Mdot
.07023 .65243 Mdot
.37881 .08678 Mdot
.89648 .54026 Mdot
.18014 .71225 Mdot
.67825 .13327 Mdot
.21884 .5779 Mdot
.14214 .48578 Mdot
.83494 .11233 Mdot
.69406 .15693 Mdot
.0232 .91327 Mdot
.61102 .13937 Mdot
.71317 .71558 Mdot
.78435 .18918 Mdot
.38769 .81258 Mdot
.53776 .57495 Mdot
.55958 .1213 Mdot
.81616 .50427 Mdot
.13313 .34661 Mdot
.85803 .90809 Mdot
.25481 .16825 Mdot
.24484 .56428 Mdot
.5235 .27826 Mdot
.42112 .56205 Mdot
.64707 .64992 Mdot
.73368 .64618 Mdot
.22629 .49778 Mdot
.22366 .21453 Mdot
.60926 .08981 Mdot
.17262 .69327 Mdot
.27863 .76011 Mdot
.33637 .81774 Mdot
.09353 .34304 Mdot
.1278 .38271 Mdot
.94404 .67639 Mdot
.13063 .92845 Mdot
.97691 .03324 Mdot
.5432 .17528 Mdot
.8048 .40527 Mdot
.42541 .30167 Mdot
.46675 .49485 Mdot
.95354 .5943 Mdot
.10328 .63623 Mdot
.99852 .71892 Mdot
.02433 .01692 Mdot
.76905 .40014 Mdot
.32448 .44088 Mdot
.39988 .81907 Mdot
.40096 .56939 Mdot
.67112 .50577 Mdot
.74278 .20861 Mdot
.55615 .00539 Mdot
.27119 .91422 Mdot
.60678 .68798 Mdot
.2261 .35807 Mdot
.95321 .71323 Mdot
.97201 .89259 Mdot
.1045 .11516 Mdot
.29682 .67479 Mdot
.72699 .55016 Mdot
.86863 .2318 Mdot
.81733 .10806 Mdot
.01666 .16693 Mdot
.42789 .01916 Mdot
.13103 .88355 Mdot
.45854 .33334 Mdot
.99014 .94102 Mdot
.0639 .71607 Mdot
.90584 .6181 Mdot
.10646 .4934 Mdot
.71413 .09034 Mdot
.50723 .90874 Mdot
.38942 .04611 Mdot
.25825 .90283 Mdot
.50126 .05834 Mdot
.98991 .52094 Mdot
.31957 .16717 Mdot
.35243 .3293 Mdot
.01656 .18184 Mdot
.14924 .87225 Mdot
.5193 .52156 Mdot
.16303 .35594 Mdot
.69038 .43299 Mdot
.83959 .46355 Mdot
.02755 .28205 Mdot
.7981 .91191 Mdot
.68403 .11031 Mdot
.42101 .00706 Mdot
.33922 .88923 Mdot
.33013 .55541 Mdot
.49472 .78512 Mdot
.19531 .1542 Mdot
.20689 .05314 Mdot
.79756 .55818 Mdot
.17829 .81564 Mdot
.70784 .27189 Mdot
.3757 .57519 Mdot
.44113 .41154 Mdot
.50933 .52557 Mdot
.27383 .45121 Mdot
.17346 .57072 Mdot
.56873 .47706 Mdot
.87874 .92828 Mdot
.15033 .52225 Mdot
.72044 .09866 Mdot
.71144 .74797 Mdot
.29372 .27747 Mdot
.35243 .25633 Mdot
.06378 .66901 Mdot
.27526 .78014 Mdot
.67752 .17725 Mdot
.45331 .67533 Mdot
.67561 .28787 Mdot
.74774 .29893 Mdot
.80054 .26674 Mdot
.56021 .45297 Mdot
.234 .13896 Mdot
.93002 .20155 Mdot
.7646 .86875 Mdot
.99863 .86908 Mdot
.7244 .89525 Mdot
.00876 .85443 Mdot
.05404 .57267 Mdot
.6148 .15143 Mdot
.44583 .98998 Mdot
.48949 .03751 Mdot
.56051 .598 Mdot
.90911 .48988 Mdot
.37897 .48822 Mdot
.29152 .45715 Mdot
.88627 .36083 Mdot
.85263 .5665 Mdot
.29028 .66608 Mdot
.05586 .07133 Mdot
.60011 .96036 Mdot
.46095 .65536 Mdot
.48153 .44969 Mdot
.54589 .49825 Mdot
.12961 .89999 Mdot
.5521 .18614 Mdot
.07906 .24857 Mdot
.66351 .63927 Mdot
.06941 .40354 Mdot
.40398 .83827 Mdot
.76177 .77085 Mdot
.69108 .55969 Mdot
.25392 .98055 Mdot
.07354 .65202 Mdot
.84587 .7972 Mdot
.14016 .13816 Mdot
.25265 .64392 Mdot
.53376 .29352 Mdot
.53813 .52132 Mdot
.08038 .60508 Mdot
.59322 .19746 Mdot
.12595 .9268 Mdot
.40469 .17582 Mdot
.57916 .33584 Mdot
.34309 .873 Mdot
.58659 .33357 Mdot
.42121 .51001 Mdot
.75504 .16345 Mdot
.3628 .52196 Mdot
.28338 .11156 Mdot
.61509 .11822 Mdot
.32552 .02889 Mdot
.159 .6319 Mdot
.22102 .52532 Mdot
.57656 .41593 Mdot
.96547 .95759 Mdot
.94013 .15569 Mdot
.29446 .67651 Mdot
.52659 .01434 Mdot
.502 .68285 Mdot
.47596 .13788 Mdot
.92989 .93409 Mdot
.69002 .51487 Mdot
.64683 .5827 Mdot
.72466 .61686 Mdot
.8085 .31227 Mdot
.08779 .18618 Mdot
.58474 .171 Mdot
.89819 .00474 Mdot
.61914 .58848 Mdot
.26543 .21718 Mdot
.0551 .73339 Mdot
.99324 .94327 Mdot
.3378 .72843 Mdot
.49704 .36582 Mdot
.65652 .32528 Mdot
.49556 .70793 Mdot
.89147 .27058 Mdot
.71331 .43156 Mdot
.42029 .881 Mdot
.4098 .40369 Mdot
.79986 .66848 Mdot
.47063 .50394 Mdot
.53505 .64928 Mdot
.93363 .65197 Mdot
.2599 .92155 Mdot
.48284 .19843 Mdot
.62904 .38736 Mdot
.64674 .42871 Mdot
.84984 .29713 Mdot
.0451 .00192 Mdot
.54139 .05623 Mdot
.50712 .46707 Mdot
.92114 .83224 Mdot
.5374 .9803 Mdot
.07347 .93046 Mdot
.39854 .14206 Mdot
.21262 .14973 Mdot
.73239 .12641 Mdot
.07681 .51203 Mdot
.04303 .62775 Mdot
.3912 .47822 Mdot
.31423 .6774 Mdot
.1614 .10491 Mdot
.73363 .23279 Mdot
.38551 .66724 Mdot
.44061 .61005 Mdot
.86622 .56572 Mdot
.78924 .28861 Mdot
.73071 .90618 Mdot
.00932 .2471 Mdot
.87933 .15386 Mdot
.70696 .45669 Mdot
.91841 .89698 Mdot
.72221 .08775 Mdot
.74568 .68504 Mdot
.16896 .76424 Mdot
.93147 .28616 Mdot
.94948 .02275 Mdot
.05409 .5278 Mdot
.13744 .58468 Mdot
.60009 .97454 Mdot
.15404 .3992 Mdot
.83578 .51922 Mdot
.06 .99464 Mdot
.8164 .91459 Mdot
.16025 .17501 Mdot
.65267 .05605 Mdot
.4109 .73558 Mdot
.60881 .98832 Mdot
.62487 .69492 Mdot
.69138 .35642 Mdot
.59845 .92653 Mdot
.47387 .47198 Mdot
.45399 .32277 Mdot
.61047 .80818 Mdot
.34938 .33479 Mdot
.52863 .7697 Mdot
.95329 .26655 Mdot
.73097 .69309 Mdot
.56965 .70695 Mdot
.07689 .57269 Mdot
.30591 .84109 Mdot
.41934 .39619 Mdot
.80983 .45739 Mdot
.32759 .8696 Mdot
.43542 .57555 Mdot
.85295 .22424 Mdot
.14887 .82486 Mdot
.52771 .17918 Mdot
.49886 .98069 Mdot
.61771 .51097 Mdot
.50326 .09587 Mdot
.4019 .67242 Mdot
.28165 .15067 Mdot
.00325 .46734 Mdot
.79646 .5229 Mdot
.50974 .59782 Mdot
.21289 .5174 Mdot
.51363 .93953 Mdot
.01375 .59608 Mdot
.03937 .82189 Mdot
.03781 .30437 Mdot
.32482 .34953 Mdot
.52593 .31038 Mdot
.04605 .46356 Mdot
.0309 .10314 Mdot
.85095 .10791 Mdot
.55021 .51905 Mdot
.45018 .91604 Mdot
.11707 .50751 Mdot
.75147 .25403 Mdot
.76448 .21725 Mdot
.99998 .34393 Mdot
.75379 .64154 Mdot
.79281 .42077 Mdot
.23982 .66349 Mdot
.85542 .92261 Mdot
.36507 .17265 Mdot
.56121 .44086 Mdot
.79866 .46624 Mdot
.54076 .03692 Mdot
.74088 .17506 Mdot
.49809 .09793 Mdot
.72378 .19241 Mdot
.67347 .3507 Mdot
.19882 .29959 Mdot
.03797 .18708 Mdot
.62511 .58891 Mdot
.01558 .01863 Mdot
.58842 .34805 Mdot
.20528 .63919 Mdot
.77222 .45251 Mdot
.71693 .33798 Mdot
.92287 .73735 Mdot
.56428 .59698 Mdot
.21092 .38413 Mdot
.46094 .44632 Mdot
.157 .35811 Mdot
.70546 .36951 Mdot
.95948 .51713 Mdot
.73975 .50043 Mdot
.54879 .49201 Mdot
.52247 .6027 Mdot
.7911 .99238 Mdot
.32728 .09286 Mdot
.486 .39333 Mdot
.9863 .2558 Mdot
.61258 .83339 Mdot
.4326 .25102 Mdot
.23349 .61637 Mdot
.66222 .78388 Mdot
.40516 .87834 Mdot
.33882 .82164 Mdot
.06089 .44334 Mdot
.72458 .76316 Mdot
.08479 .60695 Mdot
.13763 .03384 Mdot
.6006 .52931 Mdot
.02259 .38362 Mdot
.89602 .54739 Mdot
.38549 .23095 Mdot
.03986 .88059 Mdot
.03975 .16445 Mdot
.66881 .98381 Mdot
.12071 .27006 Mdot
.67037 .44971 Mdot
.66101 .18716 Mdot
.14355 .17618 Mdot
.3676 .49832 Mdot
.69808 .69971 Mdot
.15675 .9293 Mdot
.54511 .57003 Mdot
.31912 .26297 Mdot
.29334 .54587 Mdot
.33115 .73635 Mdot
.85159 .49049 Mdot
.15639 .30659 Mdot
.0457 .83561 Mdot
.62696 .24672 Mdot
.94709 .07894 Mdot
.46796 .79927 Mdot
.17076 .03716 Mdot
.12742 .42161 Mdot
.74758 .82242 Mdot
.13029 .27692 Mdot
.39694 .17056 Mdot
.56838 .34596 Mdot
.2754 .45664 Mdot
.5205 .01005 Mdot
.32979 .45526 Mdot
.91732 .9287 Mdot
.31359 .41316 Mdot
.2931 .16745 Mdot
.94396 .12777 Mdot
.38327 .47955 Mdot
.29107 .22666 Mdot
.74056 .58633 Mdot
.34376 .17372 Mdot
.97416 .96815 Mdot
.57642 .79707 Mdot
.19334 .71546 Mdot
.71456 .13468 Mdot
.18015 .10458 Mdot
.35291 .76261 Mdot
.73118 .94612 Mdot
.39742 .53609 Mdot
.64482 .37472 Mdot
.43028 .29639 Mdot
.21372 .19147 Mdot
.36596 .3153 Mdot
.33972 .3263 Mdot
.32858 .81077 Mdot
.96523 .29971 Mdot
.76193 .56241 Mdot
.4979 .3807 Mdot
.9514 .76174 Mdot
.80345 .35857 Mdot
.07904 .09231 Mdot
.04335 .84447 Mdot
.35556 .85417 Mdot
.78958 .75874 Mdot
.19349 .52982 Mdot
.923 .52818 Mdot
.09101 .76431 Mdot
.83566 .36817 Mdot
.34518 .32483 Mdot
.09775 .65344 Mdot
.72531 .53683 Mdot
.66022 .84253 Mdot
.90331 .28669 Mdot
.38879 .87508 Mdot
.93357 .56052 Mdot
.52979 .28846 Mdot
.67205 .32699 Mdot
.35794 .83828 Mdot
.00878 .37446 Mdot
.45519 .54791 Mdot
.13056 .29182 Mdot
.53319 .76922 Mdot
.00277 .67304 Mdot
.72293 .17385 Mdot
.89363 .28776 Mdot
.57081 .94177 Mdot
.08139 .5353 Mdot
.09197 .19302 Mdot
.52315 .22598 Mdot
.21861 .38415 Mdot
.52336 .96394 Mdot
.72745 .98642 Mdot
.60653 .77096 Mdot
.34689 .08728 Mdot
.75494 .80518 Mdot
.65338 .4871 Mdot
.72194 .56238 Mdot
.209 .07823 Mdot
.8786 .38805 Mdot
.0089 .65272 Mdot
.17616 .95952 Mdot
.54928 .10313 Mdot
.45327 .25367 Mdot
.01537 .48605 Mdot
.13646 .77207 Mdot
.79187 .24677 Mdot
.42715 .9588 Mdot
.29729 .86053 Mdot
.37438 .52761 Mdot
.25641 .99276 Mdot
.48679 .04251 Mdot
.0817 .0354 Mdot
.73561 .08641 Mdot
.61043 .79744 Mdot
.74705 .82602 Mdot
.78966 .13818 Mdot
.89026 .92623 Mdot
.25681 .21965 Mdot
.67964 .14419 Mdot
.13445 .2928 Mdot
.44621 .52709 Mdot
.17494 .26616 Mdot
.03946 .17699 Mdot
.9117 .00917 Mdot
.59135 .23831 Mdot
.07753 .55263 Mdot
.29501 .48251 Mdot
.03252 .58949 Mdot
.49217 .39632 Mdot
.99803 .21489 Mdot
.40023 .97516 Mdot
.71969 .03456 Mdot
.35767 .87182 Mdot
.77409 .98381 Mdot
.2217 .40555 Mdot
.08234 .58302 Mdot
.98678 .23608 Mdot
.71935 .48943 Mdot
.28633 .70578 Mdot
.30274 .86553 Mdot
.83314 .08348 Mdot
.65542 .56109 Mdot
.64985 .7674 Mdot
.92952 .38611 Mdot
.37971 .1609 Mdot
.17428 .63621 Mdot
.39509 .71874 Mdot
.37767 .99413 Mdot
.62702 .75104 Mdot
.50666 .56606 Mdot
.09401 .13974 Mdot
.8974 .58363 Mdot
.11723 .93817 Mdot
.0084 .89943 Mdot
.72877 .53394 Mdot
.46163 .99671 Mdot
.41627 .82745 Mdot
.18205 .39653 Mdot
.80392 .11507 Mdot
.3303 .59865 Mdot
.01309 .70559 Mdot
.68195 .60065 Mdot
.94681 .64032 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`04o`000?oooooooooooooo
o`;o00002?ooool3o`0000oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=oooo
o`?o00003Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool01Oooool2o`0000Oooooo00?o0000ooooooooool00_ooool001kooooo00Co0000oooooooo
oooooooo0_l00008ooooo`?o00003oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`;o00003oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo0_l00008ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03Oooool01?l0003oooooo`000?l0000=ooooo`03o`000?oooooo
oooo00gooooo0ol0000=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo1?l0000?ooooo`03o`000?oooooo
oooo00Gooooo0_l00007ooooo`03o`000?oooooooooo00;ooooo000Nooooo`03o`000?oooooooooo
05gooooo0_l0000Vooooo`;o00007_ooool2o`0000[ooooo0_l0001[ooooo`Co00000_ooool2o`00
027ooooo000Nooooo`03o`000?oooooooooo0:Gooooo0_l0000cooooo`;o0000B?ooool2o`00027o
oooo000Nooooo`03o`000?oooooooooo03?ooooo0_l0000;ooooo`;o00002_ooool2o`0003Oooooo
0_l0000Pooooo`;o0000<Oooool2o`0006_ooooo000Nooooo`04o`000?ooooooooooooooo`;o0000
00?oooooo`000?l00000;Oooool2o`0000_ooooo0_l0000:ooooo`;o0000=oooool4o`0001kooooo
0_l0002Nooooo`007_ooool01?l0003oooooooooooooool2o`000003ooooool0003o000001kooooo
0_l0001Qooooo`;o0000Z?ooool2o`0001Cooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l0
003oooooo`cooooo0_l0000Dooooo`007_ooool00ol0003oooooooooo`1Vooooo`;o0000goooool0
01kooooo00?o0000ooooooooool0I_ooool2o`00087ooooo0_l0001Looooo`007_ooool00ol0003o
ooooooooo`0Yooooo`;o0000O?ooool2o`0003gooooo0_l000000ooooooo0000o`00001>ooooo`;o
00003?ooool001kooooo00?o0000ooooooooool05_ooool2o`00017ooooo0_l00008ooooo`;o0000
I_ooool2o`0000[ooooo0_l00003ooooo`;o0000>?ooool2o`00057ooooo0_l0000<ooooo`007_oo
ool00ol0003oooooooooo`0Fooooo`;o00006oooool2o`0006Kooooo0_l0000?ooooo`;o00006_oo
ool2o`0007gooooo000Nooooo`03o`000?oooooooooo09[ooooo0_l0000/ooooo`;o0000>_ooool2
o`00047ooooo000Nooooo`03o`000?oooooooooo07[ooooo0_l0000Nooooo`Co0000I_ooool2o`00
047ooooo000Nooooo`03o`000?oooooooooo07[ooooo0_l0000<ooooo`;o00004_ooool2o`0004So
oooo0_l0000kooooo`;o00008_ooool001kooooo0_l00010ooooo`;o0000Aoooool2o`0005cooooo
0_l0000Dooooo`;o00009Oooool2o`0002;ooooo000Nooooo`03o`000?oooooooooo00cooooo0_l0
000aooooo`;o0000Joooool2o`0002;ooooo0_l0000Zooooo`;o00005Oooool2o`0001Cooooo0_l0
000Looooo`007_ooool00ol0003oooooooooo`0<ooooo`;o0000Doooool2o`0003cooooo0_l0000;
ooooo`;o00008_ooool2o`0001_ooooo0_l0000Tooooo`;o00005?ooool2o`0001cooooo000Noooo
o`03o`000?oooooooooo02;ooooo0_l0000mooooo`;o00001oooool2o`0003?ooooo0_l00003oooo
o`;o0000Aoooool2o`0004oooooo0_l00007ooooo`007_ooool2o`0002?ooooo0_l0000@ooooo`;o
0000=?ooool2o`0003Sooooo0_l0002Hooooo`;o00001oooool001kooooo0_l0000eooooo`;o0000
GOooool2o`0004?ooooo0_l0001]ooooo`007_ooool00ol0003oooooooooo`0>ooooo`?o0000P_oo
ool2o`0004?ooooo0_l0001]ooooo`007_ooool00ol0003oooooooooo`07ooooo`;o00001Oooool3
o`000:Oooooo0_l0002=ooooo`007_ooool00ol0003oooooooooo`07ooooo`;o0000=oooool2o`00
033ooooo0_l00014ooooo`;o0000SOooool001kooooo00?o0000ooooooooool0@?ooool2o`00033o
oooo0_l00005ooooo`;o0000B?ooool2o`0004oooooo0_l00004ooooo`;o00005?ooool2o`0001Go
oooo000Mooooo`;o0000Noooool2o`0004Sooooo0_l00016ooooo`;o00001oooool2o`0000Cooooo
0_l0000Dooooo`;o00005Oooool001gooooo0_l0000aooooo`;o0000??ooool2o`0000Sooooo0_l0
001booooo`;o00007_ooool2o`0003[ooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0000T
ooooo`;o0000??ooool2o`0000Sooooo0_l00019ooooo`;o00008?ooool2o`000003ooooool0003o
000000;ooooo0_l0001Jooooo`007_ooool00ol0003oooooooooo`09ooooo`;o00002oooool2o`00
04kooooo0_l0001Jooooo`Co00000oooool2o`0001Wooooo0_l000000ooooooo0000o`00001Noooo
o`007_ooool00ol0003oooooooooo`0Fooooo`;o0000C_ooool2o`0003Sooooo0_l0000Rooooo`;o
00000oooool2o`0007cooooo000Nooooo`03o`000?oooooooooo09kooooo1?l0000Rooooo`;o0000
8?ooool2o`0005oooooo000Nooooo`;o0000Woooool2o`0002Cooooo0_l00005ooooo`;o00006Ooo
ool2o`0005oooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l0000Xooooo`;o00001?ooool2
o`0005Wooooo0_l0000Kooooo`;o00006oooool2o`0007[ooooo000Nooooo`03o`000?oooooooooo
00Kooooo0ol0000Wooooo`;o00001?ooool2o`0001Wooooo0_l0000nooooo`;o00006oooool2o`00
05Kooooo0_l00009ooooo`;o0000=?ooool001kooooo00?o0000ooooooooool01oooool2o`0004So
oooo0_l00005ooooo`;o0000P?ooool2o`0002[ooooo0_l00009ooooo`;o0000=?ooool001kooooo
00?o0000ooooooooool07_ooool2o`0000Sooooo0_l0000^ooooo`;o0000P?ooool2o`0002Gooooo
0_l00008ooooo`;o0000>_ooool001kooooo00?o0000ooooooooool07_ooool2o`0000Sooooo0_l0
002Jooooo`;o0000>oooool2o`0000Sooooo0_l0000Tooooo`;o00005?ooool001kooooo00?o0000
ooooooooool0?_ooool2o`0007;ooooo0_l0000@ooooo`;o0000Joooool2o`0001Cooooo000Noooo
o`03o`000?oooooooooo027ooooo0_l0000Kooooo`;o0000G_ooool2o`0001;ooooo0_l00005oooo
o`;o0000S?ooool001kooooo00?o0000ooooooooool02_ooool2o`0001Gooooo0_l0001kooooo`Co
00005oooool2o`0002oooooo0_l00005ooooo`;o00000_ooool2o`00053ooooo000Nooooo`03o`00
0?oooooooooo00[ooooo0_l0001<ooooo`;o00003_ooool2o`0003Kooooo0_l00018ooooo`;o0000
1Oooool2o`0000;ooooo0_l0000hooooo`;o00005_ooool001kooooo00?o0000ooooooooool0F?oo
ool2o`0000kooooo0_l0001Kooooo`;o00004Oooool2o`0005Gooooo0_l0000Fooooo`007_ooool0
0ol0003oooooooooo`35ooooo`;o00004Oooool2o`0000[ooooo0_l00019ooooo`;o00005_ooool0
01kooooo00?o0000ooooooooool06_ooool2o`0000gooooo0_l0000Booooo`;o00002Oooool2o`00
04gooooo0_l0000Zooooo`;o00007oooool2o`0001Oooooo0_l00004ooooo`;o0000:_ooool2o`00
01Kooooo000Nooooo`03o`000?oooooooooo01[ooooo0_l0000=ooooo`;o00001_ooool2o`0000[o
oooo0_l00009ooooo`;o0000<oooool2o`0001Sooooo0_l0000Qooooo`;o00001oooool2o`0003So
oooo0_l00004ooooo`;o000000?oooooo`000?l00000?oooool001kooooo00?o0000ooooooooool0
<Oooool2o`0004[ooooo0_l0000kooooo`;o00005oooool2o`0000Cooooo0_l0000Sooooo`;o0000
1_ooool2o`0003oooooo000Nooooo`03o`000?oooooooooo0=?ooooo0_l00004ooooo`;o00008ooo
ool2o`0002Oooooo0_l0000Nooooo`007_ooool2o`0004;ooooo0_l0000Dooooo`;o0000B_ooool4
o`0000Wooooo0_l0000Booooo`;o0000EOooool2o`0000[ooooo0_l0000Nooooo`007_ooool00ol0
003oooooooooo`06ooooo`;o0000<oooool2o`0000Cooooo0_l0000Dooooo`;o0000B_ooool4o`00
00Gooooo0_l00002ooooo`;o00004_ooool2o`0005Cooooo0ol0000Zooooo`007_ooool00ol0003o
ooooooooo`06ooooo`;o0000<oooool2o`0006oooooo0_l0000`ooooo`;o0000>_ooool2o`0001;o
oooo0_l0000Gooooo`007_ooool00ol0003oooooooooo`0Booooo`;o0000=Oooool2o`0002cooooo
0_l0001Uooooo`;o0000<oooool2o`0001Wooooo0_l0000@ooooo`;o00001Oooool001kooooo00?o
0000ooooooooool02Oooool2o`0000Oooooo0_l0000eooooo`;o00006_ooool2o`00013ooooo0_l0
000=ooooo`;o0000JOooool2o`0000_ooooo0_l0000Cooooo`;o0000:oooool2o`0000Gooooo000N
ooooo`04o`000?ooooooooooooooo`;o00001_ooool2o`00053ooooo0_l00007ooooo`?o00007ooo
ool2o`0006Wooooo0_l000000ooooooo0000o`000008ooooo`;o0000Aoooool001kooooo00Co0000
oooooooooooooooo0_l0001<ooooo`;o00002_ooool2o`0000Oooooo0_l0000Gooooo`;o0000MOoo
ool2o`00057ooooo000Nooooo`03o`000?oooooooooo04oooooo1?l0000Pooooo`;o00002?ooool2
o`00037ooooo0_l00008ooooo`;o0000Roooool001kooooo00?o0000ooooooooool0:oooool2o`00
00?ooooo0ol0000Nooooo`;o00006Oooool2o`0000Gooooo0_l0000:ooooo`;o0000:oooool2o`00
00;ooooo0_l00008ooooo`;o0000:oooool2o`0000Cooooo0_l0001Hooooo`007_ooool00ol0003o
ooooooooo`09ooooo`;o00008?ooool2o`0000?ooooo0ol0000iooooo`;o00004Oooool2o`0002Ko
oooo0_l00003ooooo`;o0000:_ooool2o`0000gooooo0_l00004ooooo`;o0000C?ooool2o`0000[o
oooo000Nooooo`04o`000?ooooooooooooooo`;o00001_ooool2o`0009cooooo0_l0000_ooooo`;o
0000HOooool2o`0000[ooooo000Nooooo`04o`000?ooooooooooooooo`;o000000?oooooo`000?l0
0000oooooom2ooooo`007_ooool00ol0003oooooooooo`04ooooo`;o00000_ooool2o`0000kooooo
0_l0000Zooooo`;o00002oooool2o`0005cooooo0_l0000Rooooo`;o0000L_ooool001kooooo00?o
0000ooooooooool02?ooool2o`0000kooooo1?l0000Uooooo`;o000000?oooooo`000?l000002ooo
ool2o`0005cooooo0_l0000Rooooo`;o00009_ooool2o`0004[ooooo0003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo01[ooooo0_l0
000Uooooo`;o00004Oooool2o`00097ooooo0_l0000Booooo`;o0000B_ooool000?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo
00?o0000ooooooooool06_ooool2o`0003Sooooo0_l0001Wooooo`;o0000:?ooool2o`0004[ooooo
0_l0000Booooo`000oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0
1oooool3o`0005[ooooo0_l0000mooooo`;o00008_ooool2o`0007Cooooo0_l0000Booooo`000ooo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003ooooo
ooooo`02ooooo`;o00000oooool2o`00057ooooo0_l0000mooooo`;o0000Soooool2o`0001_ooooo
0003ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`00
0?oooooooooo00;ooooo0_l000000ooooooo0000o`000002o`00057ooooo0_l0001eooooo`;o0000
8?ooool2o`00033ooooo0ol00002ooooo`;o00004?ooool2o`0000Wooooo0003ooooo`05oa0@4?oo
ooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo
0_l0001`ooooo`;o0000F?ooool2o`0001[ooooo0_l00004ooooo`;o0000<?ooool3o`0001Cooooo
0_l00009ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo
V9RHoa0@4006ooooo`03o`000?oooooooooo07Oooooo0_l0001dooooo`;o0000F?ooool000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0
003oooooooooo`0=ooooo`;o0000=_ooool2o`000?Wooooo0_l00005ooooo`007_ooool00ol0003o
ooooooooo`0=ooooo`;o0000=_ooool2o`0000Sooooo0_l000000ooooooo0000o`00000Hooooo`;o
0000Q_ooool2o`0004[ooooo0_l00005ooooo`007_ooool2o`00053ooooo0_l000000ooooooo0000
o`00000Hooooo`;o0000Q_ooool2o`00057ooooo000Nooooo`;o0000S?ooool2o`0008Cooooo0_l0
000dooooo`007_ooool00ol0003oooooooooo`1Kooooo`;o0000;_ooool2o`0001Wooooo0_l0001Y
ooooo`;o0000=?ooool001kooooo00?o0000ooooooooool04oooool2o`0004Kooooo0_l0000Loooo
o`;o0000:oooool2o`0006gooooo0ol0000Aooooo`;o00007?ooool001kooooo00?o0000oooooooo
ool02oooool2o`0000Kooooo0_l0001Tooooo`;o0000A_ooool2o`0002Oooooo0_l0000Yooooo`?o
00004Oooool2o`0001cooooo000Nooooo`04o`000?ooooooooooooooo`;o00002?ooool2o`0000oo
oooo0_l0002Jooooo`;o00001oooool2o`0002Oooooo0_l0001Aooooo`;o00002?ooool001kooooo
00Co0000oooooooooooooooo0_l0000Iooooo`;o0000AOooool2o`0005?ooooo0_l00002ooooo`;o
0000Ooooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo06?ooooo0_l0001Gooooo`;o0000
ROooool001kooooo00Co0000ooooool0003o0000aoooool2o`0003?ooooo0_l00018ooooo`007_oo
ool01?l0003oooooo`000?l0000Eooooo`;o0000/?ooool2o`0003?ooooo0_l0000aooooo`;o0000
5Oooool001kooooo0_l0000Gooooo`;o0000EOooool2o`0001[ooooo0_l0002Uooooo`;o00005Ooo
ool001kooooo00?o0000ooooooooool0KOooool3o`0001Wooooo0_l00004ooooo`;o0000Goooool2
o`0004_ooooo0_l00008ooooo`007_ooool00ol0003oooooooooo`1^ooooo`;o00004Oooool2o`00
00cooooo0_l0001Oooooo`;o00009_ooool2o`0002?ooooo0_l00008ooooo`007_ooool00ol0003o
ooooooooo`21ooooo`;o00002_ooool2o`0008Wooooo0_l0000]ooooo`007_ooool00ol0003ooooo
ooooo`1Tooooo`;o00009oooool2o`000;Sooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0
000Yooooo`;o00007oooool2o`0000cooooo0_l0002?ooooo`;o00002Oooool2o`0001Cooooo0_l0
000Jooooo`;o00004oooool001kooooo00?o0000ooooooooool02_ooool2o`0000[ooooo0_l0000;
ooooo`;o00004?ooool2o`0000oooooo0_l0000>ooooo`;o00006oooool2o`0002?ooooo0_l00018
ooooo`;o00004Oooool2o`0000Wooooo0_l0000Dooooo`;o00001_ooool2o`0001;ooooo0_l0000C
ooooo`007_ooool00ol0003oooooooooo`0Fooooo`;o00002oooool2o`00027ooooo0_l0000[oooo
o`;o00008oooool2o`0002?ooooo0_l0000Sooooo`;o0000>_ooool2o`0002Oooooo000Nooooo`03
o`000?oooooooooo02Kooooo0_l0000cooooo`;o0000>?ooool2o`0002Kooooo0_l00028ooooo`00
7_ooool00ol0003oooooooooo`0Vooooo`;o00002?ooool2o`0002Wooooo0_l0000hooooo`;o0000
3oooool2o`0009Sooooo0_l00005ooooo`007_ooool00ol0003oooooooooo`05ooooo`;o0000:Ooo
ool2o`0006oooooo0_l00003ooooo`;o00005oooool2o`0007oooooo0_l00005ooooo`007_ooool0
0ol0003oooooooooo`05ooooo`;o0000POooool2o`0001Oooooo0_l0000Looooo`;o0000HOooool2
o`0000Oooooo0_l0000Jooooo`007_ooool00ol0003oooooooooo`28ooooo`;o00007_ooool2o`00
00[ooooo0_l0000Rooooo`;o00008_ooool2o`00023ooooo0_l00002ooooo`;o00001oooool2o`00
01[ooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0000;ooooo`;o00003oooool4o`0000oo
oooo0_l0000@ooooo`;o0000EOooool2o`0000Cooooo0ol00009ooooo`;o00008_ooool2o`0002;o
oooo0_l0000Pooooo`;o00009oooool001kooooo00?o0000ooooooooool02?ooool2o`0000_ooooo
0_l0000?ooooo`Co00003oooool2o`00013ooooo0_l0000kooooo`;o00006?ooool2o`0000Gooooo
0_l0000Tooooo`;o0000Doooool2o`00027ooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0
000hooooo`;o0000BOooool2o`0004Gooooo0_l0000Nooooo`;o00007oooool2o`0001;ooooo0_l0
000@ooooo`;o00003oooool001kooooo0_l00004ooooo`;o0000>?ooool2o`0003?ooooo0_l0000B
ooooo`;o0000;?ooool2o`00027ooooo0_l0000Fooooo`;o00007oooool2o`0002Cooooo0_l00003
ooooo`;o00002_ooool001kooooo00?o0000ooooooooool02?ooool2o`0006Sooooo0_l0000Boooo
o`;o0000:?ooool2o`0000;ooooo0_l0000Qooooo`;o0000B_ooool2o`0001Kooooo0_l0000:oooo
o`007_ooool00ol0003oooooooooo`08ooooo`;o00009Oooool2o`0007oooooo0_l0001aooooo`;o
00008_ooool001kooooo00?o0000ooooooooool0;oooool2o`0007Kooooo0_l0001jooooo`;o0000
8_ooool001kooooo00?o0000ooooooooool0DOooool2o`0005Cooooo0_l0001Jooooo`;o0000@_oo
ool001kooooo00?o0000ooooooooool0DOooool2o`00023ooooo0_l0000Fooooo`;o0000I?ooool2
o`00013ooooo0_l00012ooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o0000Eoooool2o`00
01Kooooo0_l0001=ooooo`;o00005Oooool2o`0001Kooooo0_l0000looooo`007_ooool00ol0003o
ooooooooo`0Jooooo`;o0000J_ooool2o`0000Oooooo0_l0000Sooooo`;o00009?ooool2o`0002go
oooo0_l0000looooo`007_ooool00ol0003oooooooooo`0nooooo`;o0000:?ooool6o`0001Sooooo
0_l00007ooooo`;o00008oooool2o`0001_ooooo0_l00003ooooo`;o0000H?ooool2o`0000gooooo
000Nooooo`03o`000?oooooooooo03Wooooo0_l00003ooooo`;o00000oooool2o`0002?ooooo2?l0
000iooooo`;o00009_ooool2o`0000?ooooo0_l0000Jooooo`;o0000A?ooool2o`0000gooooo000N
ooooo`03o`000?oooooooooo03Wooooo0_l00008ooooo`;o0000:Oooool2o`00027ooooo0_l0000F
ooooo`;o00004?ooool2o`0002Cooooo0_l000000ooooooo0000o`00000<ooooo`;o0000Doooool0
01kooooo00?o0000ooooooooool0>oooool2o`00033ooooo0_l0000Rooooo`;o00006?ooool2o`00
00_ooooo0_l000000ooooooo0000o`00000Tooooo`;o000000?oooooo`000?l000005?ooool2o`00
04_ooooo000Nooooo`03o`000?oooooooooo03_ooooo0_l0000`ooooo`;o0000??ooool2o`0000_o
oooo0_l0000[ooooo`;o00004oooool2o`0004_ooooo000Nooooo`03o`000?oooooooooo02Sooooo
0_l0002kooooo`;o0000H?ooool001kooooo00?o0000ooooooooool06_ooool2o`0000cooooo0_l0
001Cooooo`;o0000`_ooool2o`0000Cooooo000Nooooo`03o`000?oooooooooo01[ooooo0_l0000;
ooooo`;o0000E?ooool2o`0000kooooo0_l00009ooooo`;o00006oooool2o`0000Cooooo0_l00024
ooooo`;o00001?ooool001kooooo0_l0000Xooooo`;o00006oooool2o`0001oooooo0_l0000Ioooo
o`;o00002oooool2o`0000Wooooo0_l0000Kooooo`;o00001?ooool2o`0001[ooooo0_l00016oooo
o`;o00009_ooool001kooooo00?o0000ooooooooool0;oooool2o`0001?ooooo0_l0000Oooooo`;o
00006Oooool2o`0005Gooooo0_l00016ooooo`;o00009_ooool001kooooo00?o0000ooooooooool0
;oooool4o`0001;ooooo0_l0001Mooooo`;o0000=oooool2o`0006Sooooo000Nooooo`03o`000?oo
oooooooo02oooooo1?l0000Booooo`;o00003?ooool2o`0004oooooo0_l0000gooooo`;o00008_oo
ool2o`0001Wooooo0_l0000Yooooo`007_ooool00ol0003oooooooooo`10ooooo`;o00004Oooool2
o`0009cooooo0_l0000>ooooo`;o00006Oooool2o`0002Wooooo000Nooooo`03o`000?oooooooooo
043ooooo0_l00012ooooo`;o00005oooool2o`0005;ooooo0_l0001Dooooo`007_ooool00ol0003o
ooooooooo`14ooooo`;o0000?_ooool2o`0001Oooooo0_l00012ooooo`;o0000:Oooool2o`0003Wo
oooo000Nooooo`03o`000?oooooooooo00gooooo0_l0000eooooo`;o0000@Oooool2o`0005Sooooo
0_l0000Yooooo`;o0000>Oooool001kooooo00Co0000ooooool0003o00003?ooool2o`00053ooooo
0_l0000Vooooo`;o0000AOooool2o`0007Oooooo000Nooooo`04o`000?oooooo0000o`0005kooooo
0_l0001]ooooo`;o0000IOooool2o`00013ooooo000Nooooo`03o`000?oooooooooo02Gooooo0_l0
001>ooooo`;o00009oooool2o`0009Gooooo0_l00009ooooo`;o00001Oooool001kooooo00?o0000
ooooooooool00oooool2o`00023ooooo0_l0000Aooooo`;o00001_ooool2o`000003ooooool0003o
0000033ooooo0_l0000Wooooo`;o0000N_ooool2o`0002Cooooo0_l00005ooooo`007_ooool00ol0
003oooooooooo`03ooooo`;o00009oooool2o`0000[ooooo0_l00006ooooo`;o000000?oooooo`00
0?l00000=Oooool2o`0004cooooo0_l0001@ooooo`;o00003_ooool2o`0001_ooooo000Nooooo`03
o`000?oooooooooo02cooooo0_l0001<ooooo`;o0000C?ooool2o`0001Gooooo0_l0000Zooooo`;o
00003Oooool2o`0000kooooo0_l0000Kooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0iooooo`;o
00007_ooool2o`0003oooooo0_l0000_ooooo`;o00004_ooool2o`0002[ooooo0_l0000jooooo`00
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0=oooool4o`0001kooooo0_l0000Kooooo`;o00003?ooool2o`0001Co
oooo1?l0000]ooooo`;o0000N_ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go
00001_ooool3o`0002kooooo0_l00007ooooo`;o0000?Oooool2o`0000cooooo0_l0000Fooooo`;o
0000<?ooool2o`0002Kooooo0_l0001?ooooo`000oooool01Ol0003ooooooooooooooooo000000_o
oooo00CoA4A4omgMgOoooooo00001oooool00ol0003oooooooooo`0Booooo`;o00006_ooool2o`00
00[ooooo0_l00015ooooo`;o0000Boooool2o`0002Kooooo0_l0001?ooooo`000oooool01Ol0003o
oooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`0B
ooooo`;o00009_ooool2o`0000Sooooo0_l0000kooooo`;o0000D_ooool2o`0002_ooooo0_l00013
ooooo`000oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool0
0ol0003oooooooooo`14ooooo`;o00002Oooool2o`0003Gooooo0_l0001=ooooo`;o00008_ooool2
o`0000Oooooo0_l0000kooooo`;o00001_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<
ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0B?ooool2o`0000Gooooo0_l0000A
ooooo`;o00008_ooool2o`0000?ooooo0_l0001/ooooo`;o00004_ooool2o`0000Cooooo0_l0000Z
ooooo`;o00001_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003o
oooo00Kooooo00?o0000ooooooooool0B?ooool2o`0001Sooooo0_l0000Wooooo`;o00007_ooool2
o`0000[ooooo0_l0001Dooooo`;o00001?ooool2o`0003;ooooo000Nooooo`03o`000?oooooooooo
08Kooooo0_l0000Sooooo`;o00002_ooool2o`0002kooooo0_l0001Nooooo`007_ooool00ol0003o
ooooooooo`08ooooo`;o00003?ooool2o`0000gooooo0_l0000Zooooo`Co0000<Oooool2o`0001;o
oooo0_l0001;ooooo`;o00005Oooool2o`0004Oooooo000Nooooo`03o`000?oooooooooo00Sooooo
0_l0000<ooooo`;o00003Oooool2o`0002[ooooo1?l0000Pooooo`;o00008oooool2o`0006;ooooo
0_l00017ooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o0000@Oooool2o`0002Gooooo0_l0
001Gooooo`;o0000Moooool001kooooo00?o0000ooooooooool02oooool2o`00047ooooo0_l0001n
ooooo`;o00005?ooool2o`0000kooooo0_l00005ooooo`;o00006oooool2o`0002gooooo000Noooo
o`03o`000?oooooooooo04Oooooo0_l0000iooooo`;o00001?ooool2o`0005;ooooo0_l00006oooo
o`;o00003_ooool2o`0000Gooooo0_l0000Kooooo`;o00005?ooool2o`0001Oooooo000Nooooo`03
o`000?oooooooooo04Oooooo0_l0000iooooo`;o00001?ooool4o`0000oooooo0_l0000oooooo`;o
0000=oooool2o`0001Oooooo0_l0000Gooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o0000
F?ooool2o`0002?ooooo0_l0000?ooooo`;o00005Oooool2o`0002Cooooo0_l0000Kooooo`;o0000
7_ooool2o`00033ooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l00003ooooo`;o00006ooo
ool2o`0003Kooooo0_l0000@ooooo`;o0000>Oooool2o`0002Cooooo0_l0000<ooooo`;o00003Ooo
ool2o`00053ooooo000Nooooo`03o`000?oooooooooo013ooooo0_l0000Kooooo`;o00000_ooool2
o`00023ooooo0_l0000Rooooo`;o00006Oooool2o`0005;ooooo0_l0001Oooooo`007_ooool00ol0
003oooooooooo`0aooooo`;o00007_ooool4o`0003gooooo0_l00004ooooo`;o00008Oooool2o`00
01Wooooo0_l0001_ooooo`007_ooool2o`0000;ooooo0_l0001>ooooo`;o00000_ooool2o`00047o
oooo0_l0000Hooooo`;o00001oooool2o`0000Gooooo0_l0000Booooo`;o00007oooool2o`0004ko
oooo000Nooooo`04o`000?ooooooooooooooo`;o0000D_ooool2o`00013ooooo0_l00019ooooo`;o
00003_ooool2o`0003?ooooo0_l0001>ooooo`007_ooool00ol0003oooooooooo`1Eooooo`;o0000
1?ooool2o`0000[ooooo0_l0001iooooo`;o00002oooool2o`0001;ooooo0_l0000Wooooo`;o0000
6Oooool001kooooo00?o0000ooooooooool0Doooool2o`0000Kooooo0_l00025ooooo`;o00002_oo
ool3o`0001;ooooo0_l0000Eooooo`;o00004?ooool2o`0001Wooooo000Nooooo`03o`000?oooooo
oooo00_ooooo0_l00004ooooo`;o0000@?ooool2o`0009Wooooo0_l0000Mooooo`;o00002oooool2
o`0002_ooooo000Nooooo`;o00003?ooool2o`0000Cooooo0_l0000Nooooo`;o0000K?ooool4o`00
03cooooo0_l0000Oooooo`;o00002oooool2o`0003Sooooo000Nooooo`;o0000<_ooool2o`0006?o
oooo0_l00007ooooo`Co0000??ooool2o`0001oooooo0_l00015ooooo`007_ooool00ol0003ooooo
ooooo`2Fooooo`;o0000[oooool001kooooo00?o0000ooooooooool0>_ooool2o`0000Gooooo0_l0
000Jooooo`;o0000E_ooool2o`00093ooooo000Nooooo`03o`000?oooooooooo03[ooooo0_l00005
ooooo`;o00006_ooool2o`0001Wooooo0_l000000ooooooo0000o`00000hooooo`;o0000T?ooool0
01kooooo00?o0000ooooooooool0G?ooool2o`0001[ooooo0_l000000ooooooo0000o`00003:oooo
o`007_ooool01?l0003oooooooooooooool2o`0002Oooooo0_l0000`ooooo`;o0000L_ooool2o`00
07Gooooo000Nooooo`04o`000?ooooooooooooooo`;o00004Oooool2o`0001Cooooo0_l0001;oooo
o`;o0000Eoooool2o`0001Cooooo0_l0000kooooo`;o00008_ooool001kooooo00?o0000oooooooo
ool05?ooool2o`0000Sooooo0_l0001Gooooo`;o0000=Oooool2o`0003Kooooo0_l0000Yooooo`;o
00004?ooool2o`0002;ooooo000Nooooo`03o`000?oooooooooo01kooooo0_l00005ooooo`;o0000
KOooool2o`0001Sooooo0_l0001Qooooo`;o0000=?ooool001kooooo00?o0000ooooooooool09Ooo
ool2o`0001kooooo0_l0000?ooooo`;o00006oooool2o`0001oooooo0_l0000Gooooo`;o0000=?oo
ool2o`0006;ooooo000Nooooo`;o0000@oooool2o`000003ooooool0003o000000oooooo0_l0000K
ooooo`;o00001?ooool2o`0003;ooooo0_l0000dooooo`;o00001oooool2o`0000kooooo0_l00019
ooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o00007Oooool2o`0003Gooooo0_l0000Joooo
o`;o00001?ooool2o`0003Wooooo0_l0000Dooooo`;o00003_ooool2o`0000Oooooo0_l0000boooo
o`;o00003?ooool001kooooo00?o0000ooooooooool08_ooool3o`00073ooooo0_l00004ooooo`;o
0000>Oooool2o`0000Kooooo0_l0000Tooooo`?o0000<_ooool2o`0000cooooo000Nooooo`03o`00
0?oooooooooo02;ooooo0_l0001Qooooo`;o0000?_ooool2o`0001Oooooo0_l0000Tooooo`;o0000
9Oooool2o`0001[ooooo000Nooooo`03o`000?oooooooooo01Gooooo0ol0000^ooooo`;o00006?oo
ool2o`0002?ooooo0_l0000nooooo`;o00001oooool2o`0000cooooo0_l0001=ooooo`;o00006_oo
ool001kooooo00?o0000ooooooooool05Oooool3o`0002Wooooo0_l00003ooooo`;o00006?ooool2
o`0005cooooo0_l0000>ooooo`;o00003?ooool2o`0005Kooooo0_l0000Aooooo`007_ooool00ol0
003oooooooooo`11ooooo`;o0000Doooool2o`0001Oooooo0_l0000=ooooo`;o0000>?ooool2o`00
01;ooooo0_l0000Vooooo`;o00002?ooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo02go
oooo0_l00013ooooo`;o00008_ooool2o`0000gooooo0_l00004ooooo`;o00000_ooool2o`00013o
oooo0_l0000eooooo`;o00001Oooool2o`0000_ooooo0_l0000`ooooo`;o00001oooool001kooooo
00?o0000ooooooooool0;Oooool2o`00013ooooo0_l00003ooooo`;o00002Oooool2o`00027ooooo
0_l0000<ooooo`;o00002Oooool4o`0001;ooooo0_l00002ooooo`;o00001?ooool2o`0001Cooooo
0_l0000eooooo`;o00001Oooool2o`0004Kooooo000Nooooo`03o`000?oooooooooo00gooooo0_l0
000/ooooo`;o00000_ooool2o`0000?ooooo0_l00009ooooo`;o00004?ooool2o`0001?ooooo0_l0
0008ooooo`;o00002Oooool4o`0001;ooooo0_l0000Looooo`;o0000Ioooool2o`0001gooooo000N
ooooo`03o`000?oooooooooo00gooooo0_l0000/ooooo`;o00009?ooool2o`0001?ooooo0_l0000E
ooooo`;o0000<?ooool2o`0006Oooooo0_l0000Mooooo`007_ooool00ol0003oooooooooo`0Foooo
o`;o0000>Oooool2o`0000oooooo0_l0000Iooooo`;o0000J_ooool2o`0005cooooo000Nooooo`03
o`000?oooooooooo01Kooooo0_l0000iooooo`;o00003oooool2o`0001Wooooo0_l0001Yooooo`?o
0000<_ooool2o`0002Sooooo000Nooooo`03o`000?oooooooooo08Sooooo0_l0001Nooooo`;o0000
<oooool4o`0001Sooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`28ooooo`;o0000Fooo
ool2o`0003Sooooo0_l0000Hooooo`;o00003?ooool001kooooo00?o0000ooooooooool0Foooool2
o`0003?ooooo0_l0000Gooooo`;o00001?ooool2o`0003Cooooo0_l0000hooooo`;o00009_ooool0
01kooooo0_l0000Nooooo`;o0000??ooool2o`0003?ooooo0_l0000Gooooo`;o00001?ooool2o`00
03Oooooo0_l0000eooooo`;o00005oooool2o`0000gooooo000Nooooo`03o`000?oooooooooo01Go
oooo0_l00006ooooo`;o00003oooool2o`000;Sooooo0_l0000Zooooo`;o00008_ooool2o`0000go
oooo000Nooooo`03o`000?oooooooooo01Gooooo0_l0000Gooooo`;o0000=oooool2o`000:_ooooo
0_l0000aooooo`007_ooool00ol0003oooooooooo`0cooooo`;o0000<_ooool2o`0006Sooooo0_l0
000:ooooo`;o00008?ooool2o`0000gooooo0_l0000Kooooo`;o00006_ooool001kooooo00?o0000
ooooooooool0;Oooool2o`0000Cooooo0_l0000Fooooo`;o0000>?ooool2o`0004?ooooo0_l00005
ooooo`;o00002_ooool2o`0000Sooooo0_l00008ooooo`;o000000?oooooo`000?l000002Oooool2
o`0000gooooo0_l0000Kooooo`;o00006_ooool001kooooo00?o0000ooooooooool0;?ooool3o`00
01cooooo0_l0000hooooo`;o00006_ooool2o`0002Oooooo0_l0000Kooooo`;o00002?ooool2o`00
0003ooooool0003o000001_ooooo0_l00003ooooo`;o0000;oooool001kooooo00?o0000oooooooo
ool0;?ooool2o`0001cooooo0_l0000booooo`;o00008Oooool2o`0000[ooooo0_l0001Rooooo`;o
00000oooool2o`0002oooooo000Nooooo`03o`000?oooooooooo00gooooo0_l00006ooooo`;o0000
7Oooool2o`0001Cooooo0_l0000booooo`;o0000;Oooool2o`0000gooooo0_l00029ooooo`007_oo
ool00ol0003oooooooooo`0=ooooo`;o00001_ooool2o`0001gooooo0_l00010ooooo`;o00004Ooo
ool2o`00023ooooo0_l0000?ooooo`;o0000ROooool001kooooo00?o0000ooooooooool05?ooool2
o`0002gooooo0_l0000aooooo`;o00004Oooool2o`00023ooooo0_l0002Jooooo`007_ooool00ol0
003oooooooooo`0Dooooo`;o0000;Oooool2o`0008Wooooo0_l0001gooooo`007_ooool00ol0003o
ooooooooo`0Dooooo`;o000000?oooooo`000?l000004?ooool2o`000:?ooooo0_l0001@ooooo`;o
00009Oooool001kooooo00?o0000ooooooooool03?ooool2o`0000Wooooo0_l0000@ooooo`;o0000
<?ooool2o`0006Sooooo1?l00003ooooo`;o00001_ooool2o`0001Oooooo0_l0000aooooo`;o0000
9Oooool001kooooo00?o0000ooooooooool01_ooool2o`0000Cooooo0_l0001=ooooo`;o0000J?oo
ool4o`0000?ooooo0_l00006ooooo`;o00005oooool2o`0005Sooooo0003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`00
0?oooooooooo00Kooooo0_l0003oooooob_ooooo0_l0000Cooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003o
ooooooooo`02o`00043ooooo0_l0000mooooo`;o00007oooool2o`0000kooooo0ol0001mooooo`;o
00004oooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool000001_ooool5o`00043ooooo0_l0000Aooooo`;o00004?ooool2o`0001Sooooo0_l00003oooo
o`;o00002_ooool2o`0000kooooo0_l0000>ooooo`?o00009Oooool2o`0006_ooooo0003ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o0000
ooooooooool0EOooool2o`00013ooooo0_l0000Mooooo`;o00002_ooool2o`0001;ooooo0_l0000b
ooooo`;o0000>Oooool2o`00033ooooo0003ooooo`05o`000?ooooooooooooooool000002oooool0
1Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool05_ooool3o`0008gooooo0_l0
001]ooooo`;o0000<?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7
QhOooooo00Sooooo00?o0000ooooooooool05_ooool3o`0002cooooo0_l00012ooooo`Co0000^_oo
ool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o
0000ooooooooool0AOooool2o`0002;ooooo0_l0000Nooooo`Co00003_ooool2o`000:[ooooo0003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`00
0?oooooooooo00Gooooo0_l00011ooooo`;o00007oooool2o`00033ooooo0_l0002Zooooo`007_oo
ool00ol0003oooooooooo`05ooooo`;o0000:oooool2o`0001Cooooo0_l0001<ooooo`;o0000Cooo
ool2o`0001Wooooo0_l0000Nooooo`;o00008oooool001kooooo00?o0000ooooooooool0<_ooool2
o`0006;ooooo0_l0000Eooooo`;o00006oooool2o`0001_ooooo0_l0000Iooooo`;o00007_ooool2
o`0001Sooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`2]ooooo`;o00006oooool2o`00
073ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o0000O?ooool2o`000;go
oooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0000Tooooo`;o0000E_ooool2o`0005_ooooo
0_l0000Gooooo`;o0000Aoooool001kooooo00?o0000ooooooooool0<?ooool2o`000;?ooooo0_l0
000Gooooo`;o0000Aoooool001kooooo00?o0000ooooooooool07Oooool2o`0001Kooooo0_l0000B
ooooo`;o00009oooool2o`00037ooooo0_l0002Pooooo`007_ooool00ol0003oooooooooo`0Moooo
o`;o00005_ooool2o`0000Sooooo0_l00008ooooo`;o00009oooool2o`00037ooooo0_l0000]oooo
o`;o0000?_ooool2o`0001[ooooo0_l0000Eooooo`007_ooool00ol0003oooooooooo`0kooooo`;o
00000_ooool2o`0000gooooo0_l00024ooooo`;o00006oooool2o`00027ooooo0_l0000Jooooo`;o
00005Oooool001kooooo00?o0000ooooooooool0=oooool2o`0000;ooooo0_l0000Aooooo`;o0000
V_ooool2o`0000Gooooo0_l00003ooooo`;o0000<?ooool2o`0001gooooo000Nooooo`03o`000?oo
oooooooo02Wooooo0_l0000<ooooo`;o00009oooool2o`0004Sooooo0_l0000Rooooo`;o00006_oo
ool2o`0000[ooooo0_l0000`ooooo`;o00007Oooool001kooooo1?l0000Booooo`?o00001_ooool2
o`0000_ooooo0_l0000eooooo`;o0000B?ooool2o`0002;ooooo0_l0001Kooooo`;o00006_ooool0
01kooooo1?l0000Booooo`?o00001_ooool2o`0007Cooooo0_l00029ooooo`;o00003?ooool2o`00
01[ooooo000Nooooo`?o0000T_ooool2o`0004gooooo0_l0000jooooo`;o00007?ooool2o`0000[o
oooo000Nooooo`03o`000?oooooooooo0>7ooooo0_l0000Wooooo`;o0000;oooool2o`0000[ooooo
000Nooooo`03o`000?oooooooooo00Kooooo0_l00012ooooo`;o00009?ooool2o`0009Sooooo0_l0
000kooooo`007_ooool00ol0003oooooooooo`06ooooo`;o00007?ooool2o`0002Cooooo0_l0000>
ooooo`;o00005?ooool2o`0000Oooooo0_l00025ooooo`;o0000AOooool001kooooo00?o0000oooo
ooooool02Oooool2o`0000Kooooo0_l0000Aooooo`;o0000=?ooool2o`0001gooooo0_l00025oooo
o`;o0000AOooool001kooooo0_l0000:ooooo`;o00001_ooool2o`0003?ooooo0_l0000Dooooo`;o
00008Oooool2o`000<Kooooo000Nooooo`;o0000Aoooool2o`0001Cooooo0_l00004ooooo`;o0000
6oooool2o`0000Oooooo0_l00005ooooo`;o0000W_ooool2o`0001Kooooo000Nooooo`03o`000?oo
oooooooo05cooooo0_l00004ooooo`;o00009?ooool2o`0000Gooooo0_l0002Nooooo`;o00005_oo
ool001kooooo00?o0000ooooooooool0KOooool2o`00033ooooo0_l00020ooooo`;o00009?ooool0
01kooooo00?o0000ooooooooool0KOooool2o`00033ooooo0_l0000Hooooo`;o0000<oooool2o`00
037ooooo0_l0000Tooooo`007_ooool00ol0003oooooooooo`21ooooo`;o0000=_ooool2o`0000Ko
oooo0_l0000[ooooo`;o0000Eoooool001kooooo00?o0000ooooooooool0=?ooool2o`0004_ooooo
0_l0000nooooo`;o00009oooool2o`0005_ooooo000Nooooo`03o`000?oooooooooo03Cooooo0_l0
002Aooooo`;o00004?ooool2o`0000oooooo0_l0001Kooooo`007_ooool00ol0003oooooooooo`0D
ooooo`;o0000/Oooool2o`00013ooooo0_l0000hooooo`;o0000<_ooool001kooooo0_l0000Eoooo
o`;o0000bOooool2o`0003;ooooo0_l0000booooo`007_ooool00ol0003oooooooooo`02o`0005Oo
oooo0_l0001Iooooo`;o0000:Oooool2o`0001;ooooo0_l0001Booooo`007_ooool00ol0003ooooo
ooooo`02o`0005Oooooo0_l00006ooooo`;o0000>_ooool2o`0001Gooooo0ol0000looooo`;o0000
;?ooool2o`0002Cooooo000Nooooo`03o`000?oooooooooo067ooooo0_l0000jooooo`;o00005_oo
ool2o`00033ooooo0_l0000hooooo`;o00009?ooool001kooooo00?o0000ooooooooool0=_ooool2
o`0000;ooooo0_l0000`ooooo`;o0000NOooool2o`0003Sooooo0_l0000?ooooo`;o00004oooool0
01kooooo00?o0000ooooooooool04Oooool2o`0002?ooooo0_l00002ooooo`?o0000;oooool2o`00
07Kooooo0_l0000kooooo`;o00003oooool2o`0001?ooooo000Nooooo`03o`000?oooooooooo017o
oooo0_l0000Mooooo`;o00002Oooool2o`0001[ooooo0_l0000Sooooo`;o0000I_ooool2o`0005_o
oooo0_l00004ooooo`007_ooool00ol0003oooooooooo`0`ooooo`;o00009Oooool2o`00013ooooo
0_l0000Aooooo`;o0000Goooool2o`0000?ooooo0_l0001Mooooo`;o00001?ooool001kooooo00?o
0000ooooooooool0:?ooool2o`0003oooooo0_l0001booooo`;o00000oooool2o`0006?ooooo000N
ooooo`03o`000?oooooooooo02Sooooo0_l00010ooooo`;o0000?Oooool2o`0009cooooo000Noooo
o`03o`000?oooooooooo00kooooo0_l0001Jooooo`Co00003Oooool2o`0002cooooo0_l0002Loooo
o`007_ooool00ol0003oooooooooo`0<ooooo`Co0000F?ooool2o`0000;ooooo0_l0000=ooooo`?o
00000oooool2o`000<Cooooo000Nooooo`03o`000?oooooooooo00cooooo0_l0001Iooooo`?o0000
4_ooool2o`0000?ooooo0_l0000Qooooo`;o0000>_ooool2o`0004Kooooo0_l0000Mooooo`007_oo
ool00ol0003oooooooooo`1Wooooo`;o0000>oooool2o`0003[ooooo0_l0000Xooooo`;o00007?oo
ool2o`0001gooooo000Nooooo`03o`000?oooooooooo02gooooo0_l0003Kooooo`;o0000>oooool0
01kooooo00?o0000ooooooooool0;Oooool2o`0005oooooo0_l0001Cooooo`;o0000H_ooool001ko
oooo0_l0000Rooooo`;o0000Joooool2o`0003Sooooo0_l0000Iooooo`;o0000H_ooool001kooooo
00?o0000ooooooooool08Oooool2o`00097ooooo0_l0000Booooo`;o0000OOooool001kooooo00?o
0000ooooooooool0S?ooool2o`0002Kooooo0_l0001>ooooo`;o0000@Oooool001kooooo00?o0000
ooooooooool0E_ooool2o`0003Cooooo0_l0000`ooooo`;o0000>oooool4o`0000Gooooo0_l00011
ooooo`007_ooool00ol0003oooooooooo`1Fooooo`;o00005oooool2o`0004gooooo0_l0000Woooo
o`;o00004_ooool4o`0000[ooooo0_l0000Vooooo`;o00000oooool2o`0000oooooo000Nooooo`03
o`000?oooooooooo01Wooooo0_l0000Hooooo`;o0000>_ooool2o`0007Kooooo0_l0000Pooooo`;o
00009_ooool2o`0000?ooooo0_l0000?ooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o0000
6?ooool2o`0006Oooooo0_l00006ooooo`;o00000_ooool3o`0001_ooooo0_l00007ooooo`;o0000
9_ooool2o`0004kooooo000Nooooo`03o`000?oooooooooo02Sooooo0_l0001`ooooo`Co00001_oo
ool2o`0000;ooooo0ol0000Booooo`;o00000_ooool2o`0000?ooooo0_l00007ooooo`;o00000ooo
ool2o`0001kooooo0_l000000ooooooo0000o`00001>ooooo`007_ooool00ol0003oooooooooo`0X
ooooo`;o0000E?ooool2o`0001[ooooo0_l0000Qooooo`;o00000_ooool2o`00017ooooo0_l0000N
ooooo`;o0000DOooool001kooooo00?o0000ooooooooool0;oooool2o`0002Kooooo0_l0000Uoooo
o`;o0000Coooool2o`0007Kooooo000Nooooo`03o`000?oooooooooo00kooooo0_l0000Oooooo`;o
00009?ooool4o`0007Kooooo0_l0001fooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o0000
AOooool2o`0004Kooooo0_l0000dooooo`;o0000L_ooool001kooooo00?o0000ooooooooool0K?oo
ool2o`0000oooooo0_l0000Nooooo`;o0000=?ooool2o`0000?ooooo0_l0001]ooooo`007_ooool0
0ol0003oooooooooo`0Aooooo`;o00002?ooool2o`0004oooooo0_l0000?ooooo`;o0000FOooool2
o`0006gooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<
ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo017ooooo0_l00008ooooo`?o0000f_oo
ool2o`0004gooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo01cooooo0_l0000hooooo`;o0000
7oooool2o`0003kooooo0_l00009ooooo`;o0000:Oooool2o`0000Wooooo0_l0000Eooooo`;o0000
=_ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
00001_ooool3o`0005Gooooo0ol0000Oooooo`;o00006oooool2o`00027ooooo0_l00004ooooo`;o
00000oooool2o`0002Wooooo0_l0000Pooooo`;o0000=_ooool000?ooooo00Go0000oooooooooooo
ooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool00ol0003oooooooooo`17oooo
o`;o00003?ooool2o`0003gooooo0_l0000Wooooo`;o00007_ooool2o`0000_ooooo0_l0001Koooo
o`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006
ooooo`03o`000?oooooooooo04Oooooo0_l0002Dooooo`;o00002oooool2o`0000Gooooo0_l0001D
ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@
4006ooooo`03o`000?oooooooooo00Gooooo0_l00008ooooo`;o0000/Oooool2o`0002gooooo0_l0
001Dooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zj
o`000006ooooo`03o`000?oooooooooo00Gooooo0_l00008ooooo`;o00007Oooool2o`0000?ooooo
0_l0000booooo`;o00004Oooool2o`0004Kooooo0_l00023ooooo`000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo02ko
oooo0_l00003ooooo`;o000000?oooooo`000?l00000;oooool2o`00017ooooo0_l0003;ooooo`00
7_ooool00ol0003oooooooooo`0fooooo`;o0000<Oooool2o`0001?ooooo0_l00037ooooo`007_oo
ool00ol0003oooooooooo`09ooooo`;o0000:_ooool2o`0003;ooooo0ol0000Booooo`;o0000Kooo
ool2o`0005Kooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0000Qooooo`;o00001oooool2
o`0003?ooooo0_l0001?ooooo`;o0000<_ooool2o`0003?ooooo0_l0000Qooooo`007_ooool00ol0
003oooooooooo`09ooooo`;o00008Oooool2o`0005Gooooo0_l0000Booooo`;o00008_ooool2o`00
03;ooooo0_l0000cooooo`;o00008Oooool001kooooo00?o0000ooooooooool04Oooool2o`00073o
oooo0_l0000Booooo`;o0000E_ooool2o`0002[ooooo0_l0000Zooooo`007_ooool00ol0003ooooo
ooooo`0Aooooo`;o0000/?ooool2o`0005Kooooo0_l0000:ooooo`;o00007_ooool001kooooo00?o
0000ooooooooool01Oooool2o`0000Cooooo0_l0000[ooooo`;o00006oooool2o`0006cooooo0_l0
001Rooooo`;o00007_ooool001kooooo00?o0000ooooooooool01Oooool2o`0000Cooooo0_l0000M
ooooo`;o00003?ooool2o`0001_ooooo0_l00008ooooo`;o00003oooool2o`0000gooooo0_l00036
ooooo`007_ooool00ol0003oooooooooo`0Zooooo`;o0000<oooool2o`0000oooooo0_l0000=oooo
o`;o0000D_ooool2o`0007;ooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0000aooooo`;o
0000U?ooool2o`0007;ooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0000aooooo`;o0000
Zoooool2o`0001Sooooo1?l0000oooooo`007_ooool2o`0002Kooooo0_l0000fooooo`;o0000R_oo
ool3o`0001Sooooo1?l0000oooooo`007_ooool01?l0003oooooo`000?l0000Tooooo`;o0000=_oo
ool2o`00013ooooo0_l0001hooooo`;o0000G?ooool001kooooo00Co0000ooooool0003o0000K_oo
ool2o`00043ooooo0_l0002Dooooo`007_ooool00ol0003oooooooooo`1Mooooo`;o0000D_ooool2
o`0004oooooo0_l0000=ooooo`;o00002oooool2o`0002Oooooo000Nooooo`03o`000?oooooooooo
05gooooo0ol0002Rooooo`;o00003Oooool2o`0000_ooooo0_l0000Wooooo`007_ooool00ol0003o
ooooooooo`15ooooo`;o00005oooool2o`0009Cooooo0_l0001Aooooo`007_ooool00ol0003ooooo
ooooo`15ooooo`;o00007oooool2o`0000Sooooo0_l00022ooooo`;o0000Boooool2o`0000Cooooo
000Nooooo`03o`000?oooooooooo02cooooo0_l0000hooooo`;o00000oooool2o`0000?ooooo0_l0
003?ooooo`;o00001?ooool001kooooo00?o0000ooooooooool06?ooool2o`0001;ooooo0_l0000d
ooooo`;o00001oooool2o`0000gooooo0_l0002Dooooo`;o0000=Oooool001kooooo00?o0000oooo
ooooool02Oooool2o`0000gooooo0_l00018ooooo`;o00001oooool2o`0000gooooo0_l00004oooo
o`;o00000oooool2o`0008Wooooo0_l0000eooooo`007_ooool00ol0003oooooooooo`09ooooo`;o
00006oooool2o`0004?ooooo0_l0000Cooooo`;o00000oooool2o`000<3ooooo000Nooooo`03o`00
0?oooooooooo02Kooooo0_l0001Pooooo`;o0000_Oooool001kooooo00?o0000ooooooooool03Ooo
ool2o`0005_ooooo0_l00008ooooo`;o00004_ooool2o`000;gooooo000Nooooo`03o`000?oooooo
oooo00gooooo0_l0001Kooooo`;o00002?ooool2o`000<;ooooo0_l0000=ooooo`007_ooool00ol0
003oooooooooo`3Wooooo`;o0000Coooool2o`0000gooooo000Nooooo`04o`000?oooooo0000o`00
0>Kooooo0_l0000Eooooo`;o00009_ooool2o`0001oooooo000Nooooo`Co00009Oooool2o`0006Co
oooo0_l0001Gooooo`;o00005oooool2o`0002Kooooo0_l00009ooooo`;o00005?ooool001kooooo
00?o0000ooooooooool09_ooool2o`0002Sooooo0_l0000jooooo`;o0000Eoooool2o`0004[ooooo
0_l0000Dooooo`007_ooool00ol0003oooooooooo`1@ooooo`;o0000Coooool2o`0004Kooooo0_l0
000Xooooo`;o0000<_ooool001kooooo00?o0000ooooooooool0XOooool2o`0004Kooooo0_l0000X
ooooo`;o0000<_ooool001kooooo00?o0000ooooooooool00oooool2o`0004oooooo0_l0002;oooo
o`;o00007?ooool2o`0000Cooooo0_l00010ooooo`007_ooool00ol0003oooooooooo`03ooooo`;o
0000Coooool2o`00033ooooo0_l00006ooooo`;o0000;?ooool2o`0002?ooooo0_l0000Looooo`;o
00001?ooool2o`00043ooooo000Nooooo`03o`000?oooooooooo08Kooooo0_l00006ooooo`;o0000
;?ooool2o`0008Wooooo000Nooooo`03o`000?oooooooooo053ooooo0_l00030ooooo`;o0000<ooo
ool001kooooo00?o0000ooooooooool09Oooool2o`0002Wooooo0_l0001/ooooo`;o0000<?ooool2
o`00023ooooo0_l00009ooooo`;o00004oooool2o`0001?ooooo000Nooooo`03o`000?oooooooooo
02Gooooo0ol00007ooooo`;o0000HOooool2o`0001oooooo0_l00009ooooo`;o0000<?ooool2o`00
02Sooooo0_l000000ooooooo0000o`000007ooooo`;o00002_ooool2o`0001?ooooo000Nooooo`03
o`000?oooooooooo01Cooooo0_l0000@ooooo`;o00001oooool2o`00067ooooo0_l0000Oooooo`;o
00003Oooool2o`0005Kooooo0_l0000:ooooo`;o00007oooool001kooooo00?o0000ooooooooool0
3Oooool2o`0000Gooooo0_l0002/ooooo`;o0000I_ooool2o`0001_ooooo000Nooooo`03o`000?oo
oooooooo00gooooo0_l0000Cooooo`;o0000Ooooool2o`0008Gooooo0_l0000Kooooo`007_ooool0
0ol0003oooooooooo`0Rooooo`;o00005Oooool2o`0006Oooooo0ol0000@ooooo`;o0000JOooool2
o`0001cooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`0iooooo`;o0000Ioooool2o`00
017ooooo0_l0001Yooooo`;o00007?ooool3o`0000Kooooo000Nooooo`03o`000?oooooooooo09_o
oooo0_l0001=ooooo`;o0000Doooool2o`0000Kooooo000Nooooo`;o00006Oooool2o`0001Cooooo
0_l0001[ooooo`;o0000COooool2o`0005_ooooo000Nooooo`03o`000?oooooooooo00;o00005_oo
ool2o`0001Cooooo0_l0001`ooooo`;o0000C?ooool2o`0005Oooooo000Nooooo`03o`000?oooooo
oooo00;o0000?oooool2o`0001[ooooo0_l00011ooooo`;o0000C?ooool2o`0004Kooooo0_l0000?
ooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o00004?ooool2o`0000[ooooo0_l000000ooo
oooo0000o`00000Gooooo`;o0000:?ooool2o`0003Kooooo0_l0001eooooo`;o00003oooool001ko
oooo00?o0000ooooooooool08oooool2o`00013ooooo0_l0000=ooooo`;o0000@Oooool2o`0001go
oooo0_l0000Gooooo`;o0000Q_ooool001kooooo00?o0000ooooooooool0Y_ooool2o`0002;ooooo
0_l0001kooooo`007_ooool00ol0003oooooooooo`2Zooooo`;o00007_ooool2o`0006gooooo0_l0
000<ooooo`007_ooool00ol0003oooooooooo`1oooooo`;o0000:Oooool2o`0000Sooooo0_l00023
ooooo`;o00003?ooool001kooooo00?o0000ooooooooool0O_ooool3o`0003?ooooo0_l00009oooo
o`;o0000Q_ooool001kooooo00?o0000ooooooooool09_ooool2o`0005Kooooo0_l00008ooooo`;o
0000=Oooool2o`0002Cooooo0_l0001Pooooo`007_ooool00ol0003oooooooooo`0Vooooo`;o0000
9_ooool2o`0003Sooooo0_l000000ooooooo0000o`00000Aooooo`;o00002oooool2o`0001;ooooo
0_l0000Tooooo`;o0000H?ooool001kooooo00?o0000ooooooooool0:oooool2o`00027ooooo0_l0
000kooooo`;o00004Oooool2o`0000_ooooo0_l0000Booooo`;o00005?ooool2o`00027ooooo0_l0
001=ooooo`007_ooool00ol0003oooooooooo`0[ooooo`;o0000UOooool2o`00017ooooo0_l0000A
ooooo`Co00003?ooool2o`0004gooooo000Nooooo`03o`000?oooooooooo01gooooo0_l0001^oooo
o`;o0000<oooool2o`0002Cooooo1?l0001Kooooo`005?ooool4o`000003oa0@4?oooooooooo00?o
oooo00?o0000ooooooooool03oooool2o`0000cooooo0_l0000`ooooo`;o00000oooool2o`00027o
oooo0_l0000Dooooo`;o00006_ooool2o`0001Kooooo0_l0000jooooo`;o0000B?ooool001Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0?ooooo`;o0000?_ooool2o`0000?ooooo
0_l0000Qooooo`;o00006Oooool2o`0001Gooooo0_l0000Fooooo`;o0000>_ooool2o`0004Sooooo
000Fooooo`03o`000?oooooooooo00Gooooo0ol0002Booooo`;o000000?oooooo`000?l000005?oo
ool2o`0009[ooooo000Fooooo`03o`000?oooooooooo09gooooo0_l0000Dooooo`;o0000V_ooool0
01Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3o
oooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Cooooo00?oEEEEofIVI_l00000oooo
oomBooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.17549 .47551 Mdot
.02796 .76516 Mdot
.8961 .04468 Mdot
.28051 .67782 Mdot
.13958 .42551 Mdot
.90585 .10489 Mdot
.12201 .94953 Mdot
.17843 .63355 Mdot
.871 .0761 Mdot
.18345 .01523 Mdot
.60034 .99868 Mdot
.97447 .64255 Mdot
.72005 .4641 Mdot
.34853 .48386 Mdot
.45536 .3426 Mdot
.27464 .66692 Mdot
.49635 .93696 Mdot
.41669 .41067 Mdot
.75557 .98347 Mdot
.82199 .91313 Mdot
.55031 .02978 Mdot
.50518 .0663 Mdot
.81757 .05656 Mdot
.18422 .42916 Mdot
.73666 .34619 Mdot
.20303 .39751 Mdot
.80019 .88875 Mdot
.62625 .39307 Mdot
.23525 .6955 Mdot
.26607 .22545 Mdot
.63463 .18384 Mdot
.31164 .36775 Mdot
.49995 .02826 Mdot
.12093 .12101 Mdot
.74037 .08525 Mdot
.01531 .63991 Mdot
.20328 .19652 Mdot
.39574 .30624 Mdot
.21842 .09477 Mdot
.99954 .96694 Mdot
.04066 .32004 Mdot
.43779 .94469 Mdot
.29359 .41227 Mdot
.1983 .38912 Mdot
.67871 .3587 Mdot
.67646 .58487 Mdot
.90326 .17259 Mdot
.67057 .73686 Mdot
.25451 .41647 Mdot
.05157 .3129 Mdot
.77267 .18227 Mdot
.39335 .5341 Mdot
.12481 .71617 Mdot
.99659 .37901 Mdot
.83913 .41651 Mdot
.77744 .17389 Mdot
.53961 .96564 Mdot
.03727 .72547 Mdot
.17172 .40831 Mdot
.08873 .77044 Mdot
.20361 .40627 Mdot
.7391 .78748 Mdot
.25074 .03678 Mdot
.20591 .37101 Mdot
.10424 .47463 Mdot
.35142 .06843 Mdot
.38135 .76023 Mdot
.61521 .13785 Mdot
.2143 .33653 Mdot
.95509 .10984 Mdot
.79537 .74332 Mdot
.83282 .19123 Mdot
.13283 .68322 Mdot
.16335 .87304 Mdot
.23077 .46316 Mdot
.61086 .21338 Mdot
.87095 .65333 Mdot
.1464 .13139 Mdot
.71692 .89525 Mdot
.33249 .21402 Mdot
.52321 .59008 Mdot
.60856 .06372 Mdot
.21305 .97812 Mdot
.71822 .46422 Mdot
.80586 .36366 Mdot
.7358 .21095 Mdot
.50604 .01202 Mdot
.94634 .51897 Mdot
.559 .02803 Mdot
.66389 .49533 Mdot
.04143 .95483 Mdot
.47822 .25837 Mdot
.24402 .69163 Mdot
.78781 .2561 Mdot
.99377 .65796 Mdot
.43593 .61052 Mdot
.13177 .3297 Mdot
.77384 .45933 Mdot
.55602 .34113 Mdot
.1601 .95016 Mdot
.57783 .3019 Mdot
.77854 .50641 Mdot
.89933 .84786 Mdot
.24449 .2981 Mdot
.75737 .73619 Mdot
.18259 .86631 Mdot
.60304 .10129 Mdot
.99016 .35236 Mdot
.16771 .05136 Mdot
.3657 .71864 Mdot
.54304 .5027 Mdot
.98774 .9602 Mdot
.76468 .52273 Mdot
.23409 .43046 Mdot
.23793 .51139 Mdot
.41188 .75599 Mdot
.45998 .67829 Mdot
.07092 .90235 Mdot
.8081 .66942 Mdot
.60471 .80086 Mdot
.75313 .48712 Mdot
.55044 .1248 Mdot
.15247 .75954 Mdot
.29392 .82132 Mdot
.41124 .39841 Mdot
.84583 .55501 Mdot
.69689 .25859 Mdot
.80173 .67632 Mdot
.48266 .77436 Mdot
.66767 .03078 Mdot
.45767 .14886 Mdot
.17234 .54788 Mdot
.23385 .63451 Mdot
.39615 .57972 Mdot
.00603 .62314 Mdot
.2821 .49977 Mdot
.40728 .98474 Mdot
.08007 .21014 Mdot
.60533 .7909 Mdot
.40743 .30037 Mdot
.27375 .0789 Mdot
.9275 .10928 Mdot
.86784 .66786 Mdot
.10412 .45019 Mdot
.74486 .32224 Mdot
.3181 .74628 Mdot
.82458 .75628 Mdot
.10986 .30529 Mdot
.21008 .44924 Mdot
.99035 .22458 Mdot
.23082 .56314 Mdot
.46127 .3351 Mdot
.01751 .32795 Mdot
.85972 .84625 Mdot
.02868 .37472 Mdot
.78555 .57219 Mdot
.16507 .45742 Mdot
.52485 .58377 Mdot
.54227 .89516 Mdot
.16842 .53976 Mdot
.38213 .29615 Mdot
.00889 .14031 Mdot
.99425 .04082 Mdot
.04804 .18831 Mdot
.86165 .53759 Mdot
.18447 .88871 Mdot
.80386 .75404 Mdot
.24017 .35988 Mdot
.64686 .51854 Mdot
.11574 .75743 Mdot
.01181 .40957 Mdot
.70673 .43866 Mdot
.3535 .05972 Mdot
.363 .2115 Mdot
.50016 .31465 Mdot
.39907 .25262 Mdot
.32931 .75239 Mdot
.34801 .46946 Mdot
.1971 .25984 Mdot
.94211 .17041 Mdot
.01558 .47855 Mdot
.88142 .4222 Mdot
.01363 .58124 Mdot
.15568 .05485 Mdot
.71334 .46683 Mdot
.01237 .57853 Mdot
.25892 .273 Mdot
.551 .11111 Mdot
.55967 .56811 Mdot
.37948 .74591 Mdot
.32725 .11919 Mdot
.30043 .629 Mdot
.55368 .69766 Mdot
.86138 .39766 Mdot
.11467 .97202 Mdot
.68649 .35724 Mdot
.63197 .46478 Mdot
.54427 .44004 Mdot
.278 .09024 Mdot
.36246 .18609 Mdot
.19783 .62328 Mdot
.15423 .41937 Mdot
.7362 .56113 Mdot
.17035 .75271 Mdot
.10668 .45781 Mdot
.29919 .56935 Mdot
.3006 .46801 Mdot
.62882 .19807 Mdot
.6498 .10428 Mdot
.72079 .28818 Mdot
.37249 .05663 Mdot
.41088 .95869 Mdot
.8774 .08384 Mdot
.71575 .46797 Mdot
.57398 .65202 Mdot
.69798 .49707 Mdot
.16082 .03553 Mdot
.46304 .17054 Mdot
.14401 .59167 Mdot
.77693 .84152 Mdot
.86457 .6643 Mdot
.40603 .51562 Mdot
.32505 .91408 Mdot
.06477 .22823 Mdot
.36638 .77163 Mdot
.24474 .79794 Mdot
.91115 .17285 Mdot
.76366 .07069 Mdot
.55238 .68307 Mdot
.23787 .76046 Mdot
.40123 .03575 Mdot
.93589 .34381 Mdot
.24999 .57389 Mdot
.92671 .7282 Mdot
.06125 .69962 Mdot
.85172 .78943 Mdot
.47514 .987 Mdot
.60189 .79429 Mdot
.76623 .01309 Mdot
.09913 .81524 Mdot
.14368 .84393 Mdot
.07189 .17145 Mdot
.89812 .69979 Mdot
.89779 .13393 Mdot
.5279 .75199 Mdot
.68185 .04158 Mdot
.41266 .96446 Mdot
.77843 .63393 Mdot
.0377 .15748 Mdot
.19367 .63675 Mdot
.12973 .33459 Mdot
.68667 .68134 Mdot
.28289 .45612 Mdot
.71747 .58833 Mdot
.55678 .71048 Mdot
.99113 .53765 Mdot
.98313 .29926 Mdot
.03679 .06173 Mdot
.22894 .1976 Mdot
.01686 .84292 Mdot
.43116 .63411 Mdot
.30442 .40847 Mdot
.5177 .4131 Mdot
.58211 .54089 Mdot
.14478 .779 Mdot
.91138 .45219 Mdot
.46754 .84674 Mdot
.33488 .72207 Mdot
.5586 .95725 Mdot
.80112 .37724 Mdot
.73456 .58901 Mdot
.05941 .39869 Mdot
.59601 .06811 Mdot
.28611 .24366 Mdot
.27322 .53414 Mdot
.90502 .66659 Mdot
.10759 .59854 Mdot
.91221 .22957 Mdot
.47263 .59209 Mdot
.77297 .03358 Mdot
.07427 .07368 Mdot
.72713 .3955 Mdot
.99772 .81218 Mdot
.86435 .27643 Mdot
.65215 .37235 Mdot
.53111 .99805 Mdot
.70187 .48326 Mdot
.79338 .40937 Mdot
.80008 .594 Mdot
.89732 .84018 Mdot
.30848 .26651 Mdot
.25143 .17844 Mdot
.27607 .03945 Mdot
.0481 .68587 Mdot
.76552 .96625 Mdot
.5682 .31915 Mdot
.16439 .15053 Mdot
.82937 .42382 Mdot
.82925 .42001 Mdot
.28175 .18352 Mdot
.28685 .50615 Mdot
.77917 .16508 Mdot
.12856 .5412 Mdot
.71338 .82197 Mdot
.58256 .18671 Mdot
.2313 .33776 Mdot
.28998 .86919 Mdot
.55911 .15102 Mdot
.24114 .09481 Mdot
.33124 .60729 Mdot
.44048 .53291 Mdot
.8287 .56288 Mdot
.76469 .40846 Mdot
.19888 .59694 Mdot
.16352 .84924 Mdot
.45391 .73922 Mdot
.64327 .0494 Mdot
.3062 .55252 Mdot
.8258 .39458 Mdot
.48875 .27442 Mdot
.9493 .16299 Mdot
.34745 .80353 Mdot
.39215 .26952 Mdot
.58629 .20573 Mdot
.32615 .49456 Mdot
.60768 .30427 Mdot
.05079 .49805 Mdot
.29307 .3697 Mdot
.90828 .27506 Mdot
.56854 .96923 Mdot
.0401 .48715 Mdot
.26088 .80396 Mdot
.11098 .19466 Mdot
.72072 .82758 Mdot
.05045 .76913 Mdot
.1621 .66074 Mdot
.21231 .28562 Mdot
.22081 .35875 Mdot
.03164 .2713 Mdot
.93613 .31501 Mdot
.82746 .87425 Mdot
.43512 .97708 Mdot
.19826 .35774 Mdot
.45661 .66062 Mdot
.1075 .27164 Mdot
.48914 .10601 Mdot
.45962 .26622 Mdot
.74128 .88359 Mdot
.26011 .78299 Mdot
.41397 .6076 Mdot
.29441 .01149 Mdot
.60641 .74196 Mdot
.04948 .32691 Mdot
.64421 .54177 Mdot
.6787 .9397 Mdot
.62873 .10043 Mdot
.24495 .41998 Mdot
.07375 .1205 Mdot
.88044 .23252 Mdot
.55495 .03849 Mdot
.90072 .9218 Mdot
.5224 .39984 Mdot
.79609 .42471 Mdot
.52345 .34848 Mdot
.89929 .05058 Mdot
.60493 .09712 Mdot
.05081 .3011 Mdot
.87673 .68297 Mdot
.73743 .39901 Mdot
.04776 .64361 Mdot
.9391 .20219 Mdot
.73592 .94685 Mdot
.33477 .85807 Mdot
.80351 .69149 Mdot
.35207 .6845 Mdot
.51572 .9447 Mdot
.44604 .61733 Mdot
.89985 .49491 Mdot
.21301 .52469 Mdot
.08298 .11493 Mdot
.10715 .33174 Mdot
.14233 .31121 Mdot
.99543 .80356 Mdot
.64357 .37633 Mdot
.23373 .52282 Mdot
.75742 .74891 Mdot
.65887 .73108 Mdot
.36837 .56154 Mdot
.12201 .98326 Mdot
.28599 .25609 Mdot
.87448 .30341 Mdot
.40447 .90823 Mdot
.49439 .01047 Mdot
.32017 .19842 Mdot
.99031 .75368 Mdot
.68318 .62437 Mdot
.94874 .98962 Mdot
.70145 .10953 Mdot
.1086 .80309 Mdot
.62941 .31663 Mdot
.05272 .54527 Mdot
.54935 .18505 Mdot
.44889 .67234 Mdot
.41598 .33512 Mdot
.36739 .43034 Mdot
.33154 .81932 Mdot
.73703 .68767 Mdot
.80334 .05201 Mdot
.38451 .40592 Mdot
.21707 .83034 Mdot
.13947 .83235 Mdot
.83949 .61614 Mdot
.05246 .85999 Mdot
.94184 .46481 Mdot
.04759 .1742 Mdot
.45625 .4539 Mdot
.18958 .07559 Mdot
.82554 .5392 Mdot
.65964 .08347 Mdot
.75427 .84614 Mdot
.90157 .51284 Mdot
.77852 .82767 Mdot
.68141 .80725 Mdot
.42343 .33721 Mdot
.49866 .04866 Mdot
.65512 .66826 Mdot
.16103 .77351 Mdot
.07747 .58811 Mdot
.59434 .47152 Mdot
.33265 .97868 Mdot
.1683 .49677 Mdot
.20017 .43551 Mdot
.49824 .96694 Mdot
.79085 .31169 Mdot
.05015 .16537 Mdot
.02699 .41819 Mdot
.54098 .29366 Mdot
.38572 .39189 Mdot
.49911 .47894 Mdot
.27666 .98863 Mdot
.40599 .59881 Mdot
.25675 .98085 Mdot
.07755 .10407 Mdot
.11137 .94962 Mdot
.0276 .07685 Mdot
.37156 .47829 Mdot
.78156 .91242 Mdot
.41017 .22964 Mdot
.60246 .73351 Mdot
.33861 .61579 Mdot
.1027 .14521 Mdot
.9893 .8733 Mdot
.83881 .3429 Mdot
.62052 .00562 Mdot
.42759 .3826 Mdot
.71419 .90982 Mdot
.58661 .73604 Mdot
.49459 .68709 Mdot
.77501 .06821 Mdot
.17217 .70906 Mdot
.46641 .381 Mdot
.34447 .90666 Mdot
.99528 1 Mdot
.44026 .88869 Mdot
.2755 .54644 Mdot
.14974 .94129 Mdot
.83331 .14159 Mdot
.41692 .97908 Mdot
.1726 .10616 Mdot
.90809 .35103 Mdot
.39596 .74956 Mdot
.59281 .62478 Mdot
.48085 .77162 Mdot
.03068 .1961 Mdot
.05955 .79425 Mdot
.50823 .41362 Mdot
.57197 .32398 Mdot
.61028 .55608 Mdot
.77786 .18841 Mdot
.38715 .6518 Mdot
.99166 .04022 Mdot
.83744 .25694 Mdot
.6234 .94073 Mdot
.45746 .52832 Mdot
.32976 .3456 Mdot
.4662 .29322 Mdot
.24642 .35785 Mdot
.91192 .07729 Mdot
.55261 .18935 Mdot
.6172 .4787 Mdot
.15666 .97754 Mdot
.41927 .13059 Mdot
.23655 .53143 Mdot
.64571 .9906 Mdot
.04717 .26633 Mdot
.49788 .46634 Mdot
.66063 .34195 Mdot
.73052 .16526 Mdot
.10757 .47971 Mdot
.85429 .80849 Mdot
.68748 .80213 Mdot
.35963 .35159 Mdot
.50583 .29164 Mdot
.99759 .06754 Mdot
.03184 .2472 Mdot
.42551 .32 Mdot
.03184 .61322 Mdot
.40669 .06782 Mdot
.87177 .5113 Mdot
.18955 .69164 Mdot
.69861 .184 Mdot
.19916 .61214 Mdot
.1304 .49139 Mdot
.86403 .13362 Mdot
.72135 .19459 Mdot
.03227 .9048 Mdot
.65372 .17534 Mdot
.67269 .7232 Mdot
.82111 .19952 Mdot
.36793 .79881 Mdot
.54654 .56576 Mdot
.5945 .08769 Mdot
.83949 .49967 Mdot
.13902 .3094 Mdot
.86088 .93615 Mdot
.26196 .15778 Mdot
.26446 .5931 Mdot
.49108 .31855 Mdot
.43383 .51326 Mdot
.60491 .64297 Mdot
.74849 .64491 Mdot
.25269 .53631 Mdot
.18225 .18783 Mdot
.63547 .10809 Mdot
.14013 .71228 Mdot
.25364 .77383 Mdot
.3579 .85542 Mdot
.11717 .3134 Mdot
.08519 .35214 Mdot
.95935 .67112 Mdot
.10082 .90039 Mdot
.98826 .99275 Mdot
.53785 .19197 Mdot
.82667 .36351 Mdot
.41443 .31475 Mdot
.43096 .49127 Mdot
.92799 .63263 Mdot
.13797 .65624 Mdot
.01581 .75867 Mdot
.98729 .0141 Mdot
.77023 .43166 Mdot
.32706 .40074 Mdot
.37607 .8451 Mdot
.35777 .53259 Mdot
.67923 .55034 Mdot
.72638 .17535 Mdot
.53987 .98143 Mdot
.24231 .93977 Mdot
.57312 .67817 Mdot
.21542 .40904 Mdot
.96866 .69577 Mdot
.94831 .87808 Mdot
.06753 .10781 Mdot
.30475 .65798 Mdot
.75355 .57244 Mdot
.87652 .21281 Mdot
.78854 .13535 Mdot
.98338 .14624 Mdot
.4674 .01547 Mdot
.09607 .85994 Mdot
.4611 .29229 Mdot
.01386 .93186 Mdot
.02836 .73657 Mdot
.91191 .65399 Mdot
.06362 .47513 Mdot
.7547 .10213 Mdot
.47783 .90873 Mdot
.37041 .03757 Mdot
.29983 .93116 Mdot
.47139 .04109 Mdot
.95697 .48699 Mdot
.36918 .13011 Mdot
.34228 .30568 Mdot
.98594 .18916 Mdot
.13151 .87276 Mdot
.54509 .53414 Mdot
.13949 .33634 Mdot
.71594 .38681 Mdot
.80838 .48135 Mdot
.0287 .28467 Mdot
.78392 .87438 Mdot
.67192 .08119 Mdot
.37762 .0285 Mdot
.31738 .85036 Mdot
.34922 .55409 Mdot
.46454 .7847 Mdot
.18048 .13108 Mdot
.20065 .07912 Mdot
.75208 .58428 Mdot
.17863 .84221 Mdot
.72699 .24974 Mdot
.34123 .55791 Mdot
.46213 .37565 Mdot
.52873 .49345 Mdot
.30562 .44371 Mdot
.16806 .52861 Mdot
.61149 .50134 Mdot
.86516 .9463 Mdot
.1595 .53411 Mdot
.75176 .14616 Mdot
.71667 .77311 Mdot
.27027 .25519 Mdot
.35551 .25891 Mdot
.04205 .69733 Mdot
.23033 .76247 Mdot
.68013 .19046 Mdot
.4404 .62982 Mdot
.65405 .28562 Mdot
.7421 .28597 Mdot
.83199 .28853 Mdot
.58606 .4555 Mdot
.19357 .16458 Mdot
.91045 .2484 Mdot
.77257 .88128 Mdot
.00098 .86461 Mdot
.71503 .90958 Mdot
.02155 .81371 Mdot
.08819 .60455 Mdot
.58495 .10628 Mdot
.45387 .97413 Mdot
.50424 .06121 Mdot
.57075 .60428 Mdot
.93439 .4552 Mdot
.39115 .51485 Mdot
.31258 .43389 Mdot
.85313 .3188 Mdot
.81191 .59002 Mdot
.31903 .66744 Mdot
.07114 .11377 Mdot
.61204 .96472 Mdot
.44804 .68344 Mdot
.45132 .40584 Mdot
.5493 .45477 Mdot
.10092 .90062 Mdot
.57187 .23338 Mdot
.10022 .26553 Mdot
.63831 .65645 Mdot
.08084 .39471 Mdot
.35876 .86597 Mdot
.77875 .80772 Mdot
.6926 .58311 Mdot
.21803 .96814 Mdot
.03068 .6798 Mdot
.8813 .79061 Mdot
.12148 .16622 Mdot
.25965 .67259 Mdot
.52865 .33279 Mdot
.49433 .49254 Mdot
.07789 .57499 Mdot
.59004 .225 Mdot
.09758 .92115 Mdot
.41913 .20423 Mdot
.59027 .34987 Mdot
.3508 .85123 Mdot
.59496 .3488 Mdot
.42816 .55377 Mdot
.75426 .20358 Mdot
.32611 .47584 Mdot
.32947 .08044 Mdot
.66307 .15464 Mdot
.33852 .04919 Mdot
.15858 .67155 Mdot
.21248 .5129 Mdot
.59805 .38253 Mdot
.96589 .96942 Mdot
.89974 .1771 Mdot
.32136 .70955 Mdot
.51871 .05003 Mdot
.47735 .63763 Mdot
.47003 .15284 Mdot
.90022 .90414 Mdot
.68369 .55599 Mdot
.65018 .56169 Mdot
.68532 .64976 Mdot
.7961 .35913 Mdot
.06383 .21137 Mdot
.60138 .1561 Mdot
.85513 .96916 Mdot
.58729 .58447 Mdot
.27079 .20102 Mdot
.09046 .71719 Mdot
.96258 .94722 Mdot
.36976 .69978 Mdot
.51556 .37231 Mdot
.62566 .28044 Mdot
.5023 .72181 Mdot
.92222 .23896 Mdot
.71191 .46278 Mdot
.3866 .90057 Mdot
.38546 .42943 Mdot
.83692 .65464 Mdot
.50336 .51378 Mdot
.58061 .68349 Mdot
.93915 .6145 Mdot
.23185 .94262 Mdot
.50236 .20332 Mdot
.58934 .39694 Mdot
.68896 .46457 Mdot
.83025 .30466 Mdot
.05374 .96507 Mdot
.50619 .07938 Mdot
.4742 .43812 Mdot
.90397 .8389 Mdot
.53112 .98179 Mdot
.03816 .93458 Mdot
.44324 .13081 Mdot
.17489 .18812 Mdot
.69957 .16413 Mdot
.11109 .48036 Mdot
.00711 .66323 Mdot
.40823 .49742 Mdot
.34198 .71193 Mdot
.18315 .13981 Mdot
.7359 .25514 Mdot
.37993 .66211 Mdot
.40948 .59404 Mdot
.84241 .5936 Mdot
.76221 .32688 Mdot
.69805 .87486 Mdot
.96376 .21016 Mdot
.86757 .18611 Mdot
.72685 .41525 Mdot
.91939 .86945 Mdot
.69523 .06687 Mdot
.76011 .667 Mdot
.18795 .76295 Mdot
.93182 .33043 Mdot
.96337 .99182 Mdot
.03408 .48293 Mdot
.13012 .54614 Mdot
.57695 .93947 Mdot
.14689 .35893 Mdot
.87129 .48375 Mdot
.06249 .95715 Mdot
.81897 .87594 Mdot
.13423 .21323 Mdot
.65523 .07338 Mdot
.43675 .73677 Mdot
.57192 .01582 Mdot
.60047 .68387 Mdot
.72418 .37102 Mdot
.63735 .89956 Mdot
.50072 .47986 Mdot
.44891 .37478 Mdot
.64409 .79712 Mdot
.30689 .37975 Mdot
.50751 .74951 Mdot
.97654 .24101 Mdot
.7375 .70839 Mdot
.61577 .72236 Mdot
.08426 .59799 Mdot
.34196 .81505 Mdot
.42215 .37031 Mdot
.8458 .43734 Mdot
.36925 .87543 Mdot
.42484 .56715 Mdot
.81815 .20093 Mdot
.14299 .79773 Mdot
.56612 .20536 Mdot
.52955 .95836 Mdot
.58559 .47813 Mdot
.52076 .09158 Mdot
.4138 .64928 Mdot
.32614 .12886 Mdot
.96251 .43052 Mdot
.76413 .55617 Mdot
.47256 .60714 Mdot
.2273 .53196 Mdot
.5589 .94731 Mdot
.98167 .59068 Mdot
.00209 .84971 Mdot
.04589 .26262 Mdot
.36722 .36288 Mdot
.547 .32384 Mdot
.03327 .44573 Mdot
.05992 .09572 Mdot
.82409 .0849 Mdot
.57237 .52148 Mdot
.41258 .90488 Mdot
.08123 .55505 Mdot
.71878 .29424 Mdot
.79197 .23279 Mdot
.9645 .30221 Mdot
.74277 .64432 Mdot
.77759 .42792 Mdot
.25204 .70554 Mdot
.81248 .90006 Mdot
.40489 .17009 Mdot
.57264 .42551 Mdot
.76186 .4962 Mdot
.56458 .05905 Mdot
.78001 .21249 Mdot
.49744 .14161 Mdot
.67838 .17701 Mdot
.67176 .36432 Mdot
.22376 .31721 Mdot
.01735 .16723 Mdot
.67184 .59965 Mdot
.98851 .05759 Mdot
.56561 .32738 Mdot
.18906 .64866 Mdot
.74412 .42523 Mdot
.72627 .3617 Mdot
.9005 .73722 Mdot
.53785 .54829 Mdot
.17792 .351 Mdot
.45874 .43916 Mdot
.16544 .36572 Mdot
.69662 .34785 Mdot
.98178 .54201 Mdot
.71381 .48848 Mdot
.54296 .50876 Mdot
.54731 .61521 Mdot
.77936 .99229 Mdot
.28252 .12348 Mdot
.44183 .35156 Mdot
.01907 .27403 Mdot
.66011 .86419 Mdot
.40919 .24856 Mdot
.2191 .60029 Mdot
.69183 .75861 Mdot
.42792 .87135 Mdot
.37277 .78397 Mdot
.04077 .46326 Mdot
.76294 .73507 Mdot
.11842 .58783 Mdot
.17107 .03638 Mdot
.62466 .51744 Mdot
.06334 .39625 Mdot
.92043 .54539 Mdot
.39257 .21089 Mdot
.05456 .84595 Mdot
.07329 .19997 Mdot
.69836 .9961 Mdot
.09629 .29418 Mdot
.67509 .47695 Mdot
.65365 .17698 Mdot
.15614 .19453 Mdot
.35998 .54089 Mdot
.72313 .68316 Mdot
.15239 .90577 Mdot
.58525 .61964 Mdot
.33757 .24179 Mdot
.26865 .57859 Mdot
.36509 .71093 Mdot
.85391 .4674 Mdot
.1666 .30245 Mdot
.07838 .81739 Mdot
.59901 .21233 Mdot
.93045 .11219 Mdot
.49323 .76342 Mdot
.15902 .02397 Mdot
.10086 .43948 Mdot
.7451 .81411 Mdot
.15701 .27916 Mdot
.36824 .16695 Mdot
.58894 .32314 Mdot
.28891 .42151 Mdot
.50022 .03437 Mdot
.35933 .48048 Mdot
.88419 .95425 Mdot
.30648 .45605 Mdot
.2697 .17412 Mdot
.98657 .12587 Mdot
.34571 .50459 Mdot
.29051 .18969 Mdot
.74493 .58082 Mdot
.33763 .18265 Mdot
.99959 .93516 Mdot
.58995 .79652 Mdot
.179 .68752 Mdot
.68283 .14906 Mdot
.14986 .12014 Mdot
.36446 .77908 Mdot
.75716 .90794 Mdot
.40901 .4977 Mdot
.67499 .35266 Mdot
.40272 .26223 Mdot
.20167 .2415 Mdot
.40651 .31982 Mdot
.36077 .36612 Mdot
.28241 .77508 Mdot
.9443 .30433 Mdot
.79569 .56249 Mdot
.54124 .42452 Mdot
.92305 .78262 Mdot
.76946 .39413 Mdot
.10201 .0976 Mdot
.01187 .85787 Mdot
.34132 .85328 Mdot
.80517 .77698 Mdot
.2087 .57103 Mdot
.90249 .54917 Mdot
.11708 .79056 Mdot
.8682 .3531 Mdot
.37583 .31685 Mdot
.13367 .61841 Mdot
.71984 .54955 Mdot
.70367 .8425 Mdot
.92591 .2446 Mdot
.40987 .90576 Mdot
.94233 .56671 Mdot
.57066 .26963 Mdot
.70236 .34731 Mdot
.36991 .83846 Mdot
.99905 .40531 Mdot
.46759 .52697 Mdot
.16226 .29223 Mdot
.56226 .72784 Mdot
.97836 .69923 Mdot
.74539 .18288 Mdot
.89036 .31251 Mdot
.54312 .95698 Mdot
.11933 .49559 Mdot
.07418 .20065 Mdot
.48544 .21813 Mdot
.22781 .34222 Mdot
.54588 .97376 Mdot
.75216 .02186 Mdot
.567 .735 Mdot
.3108 .11053 Mdot
.78516 .77065 Mdot
.63197 .47369 Mdot
.71839 .55903 Mdot
.17027 .07752 Mdot
.88848 .34504 Mdot
.03731 .67951 Mdot
.17845 .96769 Mdot
.51503 .12054 Mdot
.46438 .21755 Mdot
.00697 .53066 Mdot
.16231 .73239 Mdot
.77884 .22285 Mdot
.45967 .99309 Mdot
.26154 .89883 Mdot
.34586 .53094 Mdot
.21565 .98769 Mdot
.48788 .0309 Mdot
.05908 .03321 Mdot
.71296 .11849 Mdot
.57556 .81948 Mdot
.74076 .84936 Mdot
.81672 .15378 Mdot
.91452 .94371 Mdot
.27317 .23346 Mdot
.64463 .17614 Mdot
.15162 .31256 Mdot
.49078 .50607 Mdot
.19812 .24317 Mdot
.03259 .20214 Mdot
.90263 .02312 Mdot
.56696 .19358 Mdot
.04188 .59812 Mdot
.31192 .45982 Mdot
.00714 .57825 Mdot
.52513 .40167 Mdot
.0128 .23488 Mdot
.41137 .98823 Mdot
.7526 .99574 Mdot
.39173 .86955 Mdot
.76141 .02415 Mdot
.2054 .41617 Mdot
.04361 .54418 Mdot
.97253 .25174 Mdot
.74329 .47599 Mdot
.2889 .6925 Mdot
.30205 .90203 Mdot
.84591 .10808 Mdot
.61349 .5285 Mdot
.6179 .72057 Mdot
.89738 .34286 Mdot
.36203 .16378 Mdot
.20437 .61031 Mdot
.35303 .75827 Mdot
.41096 .96151 Mdot
.65268 .73879 Mdot
.5439 .59153 Mdot
.06403 .10221 Mdot
.88254 .61259 Mdot
.12149 .91826 Mdot
.97492 .91504 Mdot
.725 .52903 Mdot
.43117 .98063 Mdot
.38405 .84099 Mdot
.16724 .3572 Mdot
.76245 .13255 Mdot
.35745 .55758 Mdot
.98518 .69394 Mdot
.70156 .56231 Mdot
.98365 .6303 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`03ooooo`;o00002?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo
000Nooooo`03o`000?oooooooooo09gooooo0_l0000Wooooo`;o0000Ooooool001kooooo00?o0000
ooooooooool0G?ooool2o`0003oooooo0_l000000ooooooo0000o`00001Cooooo`;o0000D?ooool0
01kooooo00?o0000ooooooooool0>?ooool2o`0002;ooooo0_l0000fooooo`;o00002_ooool2o`00
01Cooooo0_l0000mooooo`;o0000A_ooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo03So
oooo0_l0001Jooooo`;o00008?ooool2o`0008Gooooo0_l00008ooooo`007_ooool00ol0003ooooo
ooooo`3`ooooo`;o0000EOooool001kooooo00?o0000ooooooooool0<?ooool2o`000;kooooo0_l0
00000ooooooo0000o`00000/ooooo`;o00009?ooool001kooooo00?o0000ooooooooool0<?ooool2
o`0004Gooooo0_l0000Uooooo`;o00004_ooool2o`0003oooooo0_l0000/ooooo`;o00009?ooool0
01kooooo00?o0000ooooooooool0Moooool2o`00027ooooo0_l00002ooooo`;o00003oooool2o`00
0003ooooool0003o0000027ooooo0_l0001`ooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o
0000ROooool2o`0000?ooooo0_l0000>ooooo`;o00009?ooool2o`00023ooooo0_l0001>ooooo`00
7_ooool00ol0003oooooooooo`0?ooooo`;o00007oooool2o`000003ooooool0003o000001Sooooo
0_l0000Uooooo`;o00002?ooool2o`0001oooooo0_l0001Fooooo`;o0000C_ooool001kooooo00?o
0000ooooooooool0<?ooool2o`000003ooooool0003o000001Sooooo0_l00007ooooo`;o00007?oo
ool2o`0000Sooooo0_l0000Eooooo`;o00006Oooool2o`0008cooooo0ol00006ooooo`007_ooool0
0ol0003oooooooooo`1Fooooo`;o0000?Oooool2o`0001Wooooo0_l0000Xooooo`;o0000H_ooool3
o`0000Kooooo000Nooooo`03o`000?oooooooooo0=[ooooo0_l00013ooooo`;o00009_ooool001ko
oooo00?o0000ooooooooool0J_ooool2o`0003;ooooo0_l00005ooooo`;o00009_ooool2o`00053o
oooo0ol0000Uooooo`007_ooool2o`0003?ooooo0_l0000fooooo`;o0000<_ooool2o`0000Gooooo
0_l0000Vooooo`;o0000<_ooool2o`0001gooooo0_l0000Uooooo`007_ooool00ol0003ooooooooo
o`0^ooooo`;o00000_ooool2o`00047ooooo0_l0002:ooooo`;o00000oooool2o`0003oooooo000N
ooooo`03o`000?oooooooooo02kooooo0_l0000oooooo`;o00001?ooool2o`0003cooooo0_l0001A
ooooo`;o0000=Oooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0001Uoooo
o`;o0000;oooool2o`00017ooooo0_l00028ooooo`;o00002?ooool001kooooo00?o0000oooooooo
ool02?ooool2o`0009Kooooo0_l0000Pooooo`;o0000Poooool001kooooo00?o0000ooooooooool0
K_ooool2o`00013ooooo0_l0000Nooooo`;o00007?ooool2o`0000;ooooo0_l0000Jooooo`;o0000
6?ooool2o`0004Kooooo0_l00005ooooo`007_ooool00ol0003oooooooooo`1^ooooo`;o00004?oo
ool2o`0001kooooo0_l0000Looooo`;o00007_ooool2o`0001Cooooo0_l00002ooooo`;o0000A_oo
ool2o`0000Gooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0002kooooo`;o00008Oooool2
o`00057ooooo000Nooooo`03o`000?oooooooooo00Gooooo0_l0000=ooooo`;o00007Oooool2o`00
00Gooooo0_l0002Eooooo`;o0000A?ooool2o`0000_ooooo0_l0000Qooooo`007_ooool00ol0003o
ooooooooo`05ooooo`;o0000;?ooool2o`0000Gooooo0_l000000ooooooo0000o`00000Fooooo`;o
00004?ooool2o`0003Oooooo0_l0000dooooo`;o0000?oooool2o`0000_ooooo0_l0000Qooooo`00
7_ooool00ol0003oooooooooo`0mooooo`;o00005_ooool2o`00013ooooo0_l0000gooooo`;o0000
<?ooool2o`0000;ooooo0_l00011ooooo`;o0000;?ooool001kooooo00?o0000ooooooooool0d_oo
ool2o`0001Wooooo0_l0000Iooooo`;o00003oooool2o`0002cooooo000Nooooo`03o`000?oooooo
oooo05Kooooo0_l0001Uooooo`;o0000;_ooool2o`0001Wooooo0_l0000mooooo`007_ooool00ol0
003oooooooooo`1Fooooo`;o0000COooool2o`0001Kooooo0_l00028ooooo`007_ooool00ol0003o
ooooooooo`0?ooooo`;o0000<_ooool2o`0000Gooooo0_l0001Iooooo`;o0000X?ooool001kooooo
00?o0000ooooooooool03oooool2o`0000cooooo0_l0000Tooooo`;o00001Oooool2o`0007Gooooo
0_l00024ooooo`007_ooool2o`0001;ooooo0_l0000:ooooo`;o0000XOooool3o`0000Gooooo0_l0
000Wooooo`;o0000E?ooool001kooooo00?o0000ooooooooool04Oooool2o`0000;ooooo0_l00024
ooooo`;o00008oooool2o`0000Kooooo0_l00005ooooo`;o00008?ooool2o`0002oooooo0_l0000S
ooooo`007_ooool00ol0003oooooooooo`0Booooo`;o000000?oooooo`000?l000007Oooool2o`00
06Gooooo0_l0000Mooooo`;o00003_ooool2o`0000?ooooo0_l0000nooooo`;o00004Oooool2o`00
02?ooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0000Pooooo`;o0000:oooool2o`0004co
oooo0_l00009ooooo`;o00003_ooool2o`0001Cooooo0_l0000]ooooo`;o00006?ooool2o`0000Oo
oooo0_l0000Cooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o00000_ooool2o`0004Sooooo
0_l0001<ooooo`;o0000;oooool2o`0004Oooooo0ol00006ooooo`;o00004oooool001kooooo00?o
0000ooooooooool04oooool2o`0000;ooooo0_l0003ooooooa;ooooo0_l0000Kooooo`007_ooool0
0ol0003oooooooooo`0Dooooo`;o00003Oooool2o`0000Sooooo0_l0000gooooo`;o0000>oooool2
o`0003oooooo0_l0001Qooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o00003Oooool2o`00
00Sooooo0_l0000Yooooo`;o00003?ooool2o`0003_ooooo0_l0000oooooo`;o0000HOooool001ko
oooo00?o0000ooooooooool0F?ooool2o`0005Gooooo0_l0002<ooooo`;o00002?ooool001kooooo
00?o0000ooooooooool0I_ooool2o`0000cooooo0_l0000>ooooo`;o0000:Oooool2o`0008cooooo
0_l00008ooooo`007_ooool00ol0003oooooooooo`0[ooooo`;o00002_ooool2o`0002gooooo0_l0
000<ooooo`;o00003_ooool2o`0000Kooooo0_l0001Vooooo`;o00007oooool2o`00033ooooo000N
ooooo`03o`000?oooooooooo02_ooooo0_l0000:ooooo`;o0000Doooool2o`0006Kooooo0_l00006
ooooo`;o00005oooool2o`0000Wooooo0_l0000Uooooo`007_ooool00ol0003oooooooooo`0goooo
o`;o0000Roooool2o`0003Kooooo0_l0000Rooooo`;o00009Oooool001kooooo00Co0000ooooool0
003o0000=_ooool2o`0006Gooooo0_l0000Tooooo`;o0000AOooool2o`0003[ooooo000Nooooo`04
o`000?oooooo0000o`0001cooooo0_l0001oooooo`;o0000Joooool2o`0003[ooooo000Nooooo`03
o`000?oooooooooo01gooooo0_l0001booooo`;o0000Aoooool2o`0001Cooooo0_l0001:ooooo`;o
00002Oooool001kooooo0_l0000booooo`;o0000G_ooool2o`0001oooooo0_l0000Vooooo`;o0000
5?ooool2o`0004[ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`0aooooo`;o0000H_oo
ool2o`0001_ooooo0_l0000Oooooo`;o0000<?ooool2o`00043ooooo000Nooooo`03o`000?oooooo
oooo00Sooooo0_l00017ooooo`;o0000@_ooool2o`0002Sooooo0_l0000Booooo`;o0000<?ooool2
o`00043ooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l00017ooooo`;o0000K?ooool2o`00
08Kooooo000Nooooo`03o`000?oooooooooo07;ooooo0_l0001[ooooo`;o0000D?ooool2o`0001Co
oooo000Nooooo`03o`000?oooooooooo00;ooooo0_l00008ooooo`;o00005Oooool2o`0001Kooooo
0_l0000eooooo`Co0000JOooool2o`0000Sooooo0_l0000>ooooo`;o0000=_ooool2o`0001Cooooo
000Nooooo`03o`000?oooooooooo00;ooooo0_l00008ooooo`;o00005Oooool2o`0001Kooooo0_l0
000gooooo`;o00002_ooool2o`00013ooooo0_l0001Eooooo`;o00003_ooool2o`0003?ooooo0_l0
000Gooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o0000Joooool2o`00013ooooo0_l0002>
ooooo`Co00002?ooool2o`0001Oooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l00006oooo
o`;o0000?oooool2o`0007Oooooo0_l000000ooooooo0000o`00000Fooooo`;o00003oooool2o`00
02Oooooo1?l0000Qooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o0000@Oooool2o`0000Co
oooo0_l0001gooooo`;o000000?oooooo`000?l000001_ooool2o`0000kooooo0_l0000?ooooo`;o
00009Oooool2o`0002Gooooo000Nooooo`03o`000?oooooooooo04kooooo0_l0000Jooooo`;o0000
I?ooool2o`0000Kooooo0_l0000Dooooo`;o00001oooool2o`0002Oooooo0_l0000Uooooo`007_oo
ool00ol0003oooooooooo`1Gooooo`;o00004Oooool2o`0004;ooooo0_l0000Jooooo`;o00004ooo
ool2o`0000gooooo0_l00007ooooo`;o0000C_ooool001kooooo00?o0000ooooooooool02oooool2
o`0002Sooooo1?l0000Nooooo`;o00006Oooool2o`0003[ooooo0_l00009ooooo`;o00003oooool2
o`0001?ooooo0_l0000Hooooo`;o00006oooool2o`0002oooooo000Nooooo`03o`000?oooooooooo
00_ooooo0_l0000Xooooo`Co00008Oooool2o`0001Kooooo0_l0000gooooo`;o00000oooool2o`00
00Oooooo0_l0000Nooooo`;o00007_ooool2o`00013ooooo0_l00009ooooo`;o00009?ooool2o`00
00Wooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006oooo
o`03o`000?oooooooooo023ooooo0_l0000=ooooo`;o0000:Oooool2o`0004oooooo0_l00003oooo
o`;o00000_ooool2o`0002?ooooo0_l0000;ooooo`;o00008oooool2o`0002oooooo0_l00009oooo
o`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@01_ooool00ol0003oooooooooo`06ooooo`;o00006?ooool2o`0000gooooo0_l0000=
ooooo`;o00001_ooool2o`0006cooooo0_l0000Booooo`;o00007?ooool2o`0005oooooo0003oooo
o`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`?o00001_ooool2
o`0000cooooo0_l0000Xooooo`;o00001_ooool2o`0000cooooo0_l0000>ooooo`;o0000H_ooool2
o`0003cooooo0ol0000nooooo`000oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h01_ooool00ol0003oooooooooo`06ooooo`;o00003?ooool2o`0003kooooo0_l0000>
ooooo`;o00007_ooool2o`0001Wooooo0_l0001@ooooo`;o00004oooool3o`0002Cooooo0_l0000H
ooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool0
0ol0003oooooooooo`06ooooo`;o0000O?ooool2o`0001Wooooo0_l0000Cooooo`;o00001?ooool2
o`0003Gooooo0_l0000jooooo`;o00006?ooool000?ooooo00Go410@oooooooooooooooooa0@400?
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05_ooool2o`0009cooooo0_l00004
ooooo`;o0000NOooool2o`00013ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool04Oooool2o`0000?ooooo0_l0
000@ooooo`;o0000B?ooool2o`0000Sooooo0_l00011ooooo`;o000000?oooooo`000?l000009ooo
ool2o`0000cooooo0_l0000Nooooo`;o00006_ooool2o`00013ooooo0003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0
4Oooool2o`0001Gooooo0_l0000nooooo`;o00002?ooool2o`0000Sooooo0_l00011ooooo`;o0000
00?oooooo`000?l000009oooool2o`0000cooooo0_l0000Nooooo`;o0000;?ooool001kooooo00?o
0000ooooooooool0J?ooool2o`0002Wooooo0_l00005ooooo`;o0000Zoooool001kooooo00?o0000
ooooooooool0Toooool2o`0000Gooooo0_l0001Mooooo`;o0000C?ooool001kooooo00?o0000oooo
ooooool0D_ooool2o`0006Sooooo0_l0000kooooo`;o0000@oooool2o`0000Oooooo000Nooooo`03
o`000?oooooooooo017ooooo0_l0000oooooo`;o0000J?ooool2o`00083ooooo0_l00007ooooo`00
7_ooool00ol0003oooooooooo`0Aooooo`;o0000K_ooool2o`000:7ooooo0_l0000Qooooo`007_oo
ool00ol0003oooooooooo`02o`0005?ooooo0_l0000Zooooo`;o0000<oooool2o`0004Gooooo0_l0
000Kooooo`;o00002?ooool2o`00027ooooo000Nooooo`03o`000?oooooooooo00;o0000Doooool2
o`0005oooooo0_l00015ooooo`;o00006oooool2o`0002_ooooo000Nooooo`03o`000?oooooooooo
0?oooooo:Oooool2o`0000oooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`0looooo`?o
00006_ooool2o`0000oooooo0_l0002looooo`;o00003oooool2o`0000cooooo000Nooooo`03o`00
0?oooooooooo00Kooooo0_l0000dooooo`?o00006_ooool2o`0000oooooo0_l0002mooooo`;o0000
7?ooool001kooooo00?o0000ooooooooool01_ooool2o`0007Wooooo0_l0001Uooooo`;o0000>_oo
ool2o`0000?ooooo0_l0000Looooo`007_ooool2o`0007oooooo0_l000000ooooooo0000o`00001U
ooooo`;o0000>_ooool2o`0001;ooooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`1Doooo
o`;o00000oooool2o`0002?ooooo0_l0001[ooooo`;o00003oooool2o`0003[ooooo0_l0000=oooo
o`007_ooool00ol0003oooooooooo`1Dooooo`;o00000oooool2o`0001Cooooo0_l0000Vooooo`;o
0000AOooool2o`0000_ooooo0_l0000?ooooo`;o00003_ooool2o`0003Wooooo000Nooooo`03o`00
0?oooooooooo00_ooooo0_l0000_ooooo`;o0000<Oooool2o`0000kooooo0_l0000Fooooo`;o0000
AOooool2o`0002cooooo0_l0000iooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o00003ooo
ool2o`0001kooooo0_l00011ooooo`;o0000a_ooool001kooooo00?o0000ooooooooool02oooool2
o`0000oooooo0_l00012ooooo`;o0000;oooool2o`000;Cooooo000Nooooo`03o`000?oooooooooo
00Kooooo0_l00003ooooo`;o00004_ooool2o`0003oooooo0_l0000Iooooo`;o00005?ooool2o`00
02;ooooo0_l0002@ooooo`007_ooool00ol0003oooooooooo`02ooooo`;o00000_ooool2o`0001Oo
oooo0_l0000_ooooo`;o0000:Oooool2o`0001kooooo0_l0000Hooooo`;o0000K?ooool2o`0002;o
oooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0001<ooooo`;o0000BOooool2o`0007Sooooo
0_l0000<ooooo`;o00008_ooool001kooooo00?o0000ooooooooool0;oooool2o`0009Kooooo0_l0
001<ooooo`;o0000<?ooool001kooooo00?o0000ooooooooool0;oooool2o`0009Kooooo0_l0001n
ooooo`007_ooool00ol0003oooooooooo`05ooooo`;o0000>_ooool2o`0008kooooo0_l0000Joooo
o`;o0000F?ooool001kooooo00?o0000ooooooooool01Oooool2o`0003[ooooo0_l0002>ooooo`;o
00004oooool2o`0000Gooooo0_l0000Kooooo`;o0000>oooool001kooooo00?o0000ooooooooool0
<Oooool2o`0005oooooo0ol0000;ooooo`;o0000A?ooool2o`0002;ooooo0_l0000kooooo`007_oo
ool00ol0003oooooooooo`0Kooooo`;o00005?ooool2o`0004Gooooo0_l0000Hooooo`?o00002ooo
ool2o`0000[ooooo0_l0000hooooo`;o0000Goooool001kooooo00?o0000ooooooooool06oooool2
o`0002kooooo0_l0000[ooooo`;o0000<_ooool2o`0003Sooooo0_l0001Dooooo`;o00002Oooool0
01kooooo0_l0000=ooooo`;o00009?ooool2o`0001Oooooo0_l0000cooooo`;o0000=_ooool2o`00
07_ooooo0_l00005ooooo`;o00002Oooool001kooooo00?o0000ooooooooool03?ooool2o`0001;o
oooo0_l0000@ooooo`;o0000=oooool2o`0001?ooooo0_l0000fooooo`;o00001oooool2o`0004Oo
oooo0_l0000<ooooo`;o00005Oooool2o`0000Cooooo0_l0000@ooooo`007_ooool00ol0003ooooo
ooooo`0Pooooo`;o0000BOooool2o`00013ooooo0_l00012ooooo`;o0000Aoooool2o`0000cooooo
0_l0000Eooooo`;o00005_ooool001kooooo00?o0000ooooooooool0:Oooool3o`00057ooooo0_l0
001nooooo`;o0000B?ooool001kooooo00?o0000ooooooooool03Oooool2o`0001?ooooo0_l00005
ooooo`?o000000?oooooo`000?l00000E?ooool2o`0001Wooooo0_l0001Mooooo`;o00007_ooool2
o`0000gooooo0_l0000Iooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o00004oooool2o`00
00Wooooo0_l0000Fooooo`;o0000;oooool2o`0000_ooooo0_l0000Iooooo`;o0000:Oooool2o`00
05;ooooo0_l0000=ooooo`;o00006Oooool001kooooo00?o0000ooooooooool02Oooool2o`0003[o
oooo0_l0000_ooooo`;o00002?ooool2o`0000Cooooo0_l0000Dooooo`;o00005oooool2o`0001;o
oooo0_l00016ooooo`;o0000=?ooool001kooooo00?o0000ooooooooool02Oooool2o`0007Gooooo
0_l00004ooooo`;o00005?ooool2o`00013ooooo0_l00005ooooo`?o00000oooool2o`00037ooooo
0_l0000Qooooo`;o0000=?ooool001kooooo00?o0000ooooooooool03?ooool2o`000:3ooooo0_l0
0004ooooo`Co00000oooool2o`00037ooooo0_l00004ooooo`;o0000DOooool001kooooo00?o0000
ooooooooool00_ooool2o`0000Sooooo0_l0000Iooooo`;o0000Roooool2o`0003kooooo0_l0000e
ooooo`;o00006_ooool001kooooo00?o0000ooooooooool00_ooool2o`0001_ooooo0_l00006oooo
o`;o0000Ooooool2o`00087ooooo0_l0000Jooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o
00001Oooool2o`000003ooooool0003o000001Oooooo0_l0000oooooo`;o00003Oooool2o`0001Co
oooo0_l0002Mooooo`007_ooool00ol0003oooooooooo`0Vooooo`;o000000?oooooo`000?l00000
5oooool2o`0000?ooooo0_l0000jooooo`;o000000?oooooo`000?l000002_ooool2o`000;?ooooo
000Nooooo`03o`000?oooooooooo04Kooooo0ol0000mooooo`;o00002?ooool2o`0001oooooo0_l0
000Pooooo`;o0000L_ooool001kooooo00?o0000ooooooooool0A_ooool2o`0001oooooo0_l0000W
ooooo`;o00007oooool2o`00023ooooo0_l0000hooooo`;o00003_ooool2o`000003ooooool0003o
000000[ooooo0_l0000Iooooo`007_ooool00ol0003oooooooooo`1Wooooo`;o0000?Oooool2o`00
01Gooooo0_l0000Oooooo`Co00002Oooool2o`00023ooooo0_l0000>ooooo`;o000000?oooooo`00
0?l000002_ooool2o`0001Wooooo000Nooooo`;o0000=oooool2o`0003Wooooo0_l0000Iooooo`;o
00006?ooool2o`0001Cooooo0ol0000Oooooo`Co00002Oooool2o`0003Kooooo0_l0000Rooooo`00
7_ooool00ol0003oooooooooo`0Hooooo`;o00007?ooool2o`0003Wooooo0_l0000Iooooo`;o0000
;_ooool2o`0001Wooooo0_l0000mooooo`;o00002oooool2o`0001Wooooo0_l00007ooooo`007_oo
ool00ol0003oooooooooo`0Hooooo`;o00006?ooool2o`0000Sooooo0_l0000>ooooo`;o0000ROoo
ool2o`0000;ooooo0_l0000iooooo`;o00009_ooool2o`0000Oooooo000Nooooo`03o`000?oooooo
oooo02cooooo0_l00004ooooo`;o00002?ooool2o`0000Kooooo0_l00004ooooo`Co0000Roooool4
o`0002;ooooo0_l00016ooooo`007_ooool00ol0003oooooooooo`0/ooooo`;o00005_ooool2o`00
00Cooooo0_l0000Wooooo`;o0000HOooool2o`000003ooooool0003o000000gooooo0_l0000Eoooo
o`;o000000?oooooo`000?l000001Oooool2o`0003cooooo000Nooooo`03o`000?oooooooooo03;o
oooo0_l0000mooooo`Co0000HOooool2o`00013ooooo0_l0000Hooooo`;o00001Oooool2o`0003co
oooo000Nooooo`03o`000?oooooooooo03;ooooo0_l0000Wooooo`;o00001?ooool2o`0000kooooo
0_l0000Booooo`;o0000`?ooool001kooooo00?o0000ooooooooool0?oooool2o`0001[ooooo0_l0
0004ooooo`;o00008_ooool2o`0001cooooo0_l0000[ooooo`;o00005Oooool2o`0005kooooo000N
ooooo`03o`000?oooooooooo00Gooooo0_l0000hooooo`;o0000COooool2o`0000;ooooo0_l0000?
ooooo`;o0000:?ooool2o`000003ooooool0003o000001Gooooo0_l0001Nooooo`007_ooool00ol0
003oooooooooo`05ooooo`;o0000FOooool2o`0002cooooo0_l00002ooooo`;o0000>Oooool2o`00
037ooooo0_l0000nooooo`;o00001Oooool001kooooo00?o0000ooooooooool0H?ooool2o`0002Go
oooo0_l0000;ooooo`;o0000:?ooool2o`00043ooooo0_l0000nooooo`;o00001Oooool001kooooo
00?o0000ooooooooool0Qoooool2o`0000_ooooo0_l0000Xooooo`;o0000Qoooool001kooooo00?o
0000ooooooooool0iOooool2o`00063ooooo000Nooooo`03o`000?oooooooooo03cooooo0_l0000k
ooooo`;o0000J_ooool2o`00063ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo01Kooooo0_l0000T
ooooo`;o0000>oooool2o`0004cooooo0_l0000]ooooo`;o00004?ooool2o`0003gooooo0003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0@ooooo`;o00001?ooool2o`0002Kooooo0_l0001kooooo`;o00002_ooool2
o`0001oooooo0_l0000<ooooo`;o00004?ooool2o`0000[ooooo0_l0000aooooo`000oooool01Ol@
413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`?o00003oooool3o`0002cooooo0_l0000V
ooooo`;o00006_ooool2o`0002;ooooo0_l0000Cooooo`;o0000:oooool2o`0000;ooooo0_l0000V
ooooo`;o0000<Oooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgo
ooooo`0000Oooooo00?o0000ooooooooool03oooool2o`0005Gooooo0_l0000Jooooo`;o00008_oo
ool3o`0004?ooooo0_l0001Iooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Co
gMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`0nooooo`;o0000>Oooool2o`0001Cooooo
0_l0000Fooooo`;o0000V?ooool2o`0000Cooooo0003ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo00;o0000<_ooool2o`0000Sooooo
0_l00002ooooo`;o00006oooool2o`0001Sooooo0_l0000Dooooo`;o0000Hoooool2o`0000Sooooo
0_l00011ooooo`;o00001?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^
k_m4A4Co000000Oooooo00?o0000ooooooooool00_l0000booooo`;o00003?ooool2o`0001Oooooo
0_l00002ooooo`;o00008_ooool2o`0001oooooo0_l0001>ooooo`;o00002?ooool2o`0004Oooooo
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`00
0?oooooooooo03oooooo0_l0000>ooooo`;o00002_ooool2o`0002Kooooo0_l0000Looooo`;o0000
00?oooooo`000?l00000@_ooool2o`0002?ooooo0_l0000hooooo`007_ooool00ol0003ooooooooo
o`05ooooo`;o00009oooool2o`0000oooooo0_l0000>ooooo`;o0000D?ooool2o`0004Gooooo0_l0
000Sooooo`;o0000>?ooool001kooooo00?o0000ooooooooool01Oooool2o`0002Oooooo0_l0000L
ooooo`;o00003?ooool2o`000:gooooo0_l0000?ooooo`;o0000:oooool001kooooo00?o0000oooo
ooooool0:Oooool2o`00027ooooo0_l0000<ooooo`;o0000D?ooool2o`0000Sooooo0_l0000foooo
o`;o00003oooool2o`0000Sooooo0ol0000>ooooo`;o0000:oooool001kooooo00?o0000oooooooo
ool0:Oooool2o`00087ooooo0_l00008ooooo`;o0000=_ooool2o`0000Wooooo0_l00004ooooo`;o
00002Oooool2o`0003_ooooo000Nooooo`03o`000?oooooooooo03Sooooo0_l0000>ooooo`;o0000
:Oooool2o`0000Cooooo0_l0001kooooo`;o000000?oooooo`000?l00000>_ooool2o`00013ooooo
000Nooooo`03o`000?oooooooooo03Sooooo0_l0000>ooooo`;o00006?ooool2o`0000oooooo0_l0
0004ooooo`;o0000Noooool2o`0003gooooo0_l0000@ooooo`007_ooool00ol0003oooooooooo`0m
ooooo`;o00008oooool2o`0003;ooooo0_l0001gooooo`;o0000=_ooool001kooooo00?o0000oooo
ooooool07Oooool2o`0001kooooo0_l0001Booooo`;o00000oooool2o`0001Gooooo0_l0000coooo
o`;o0000:oooool2o`0003Kooooo000Nooooo`03o`000?oooooooooo01gooooo0_l00010ooooo`;o
0000<?ooool2o`0001[ooooo0_l0000cooooo`;o0000Hoooool001kooooo00?o0000ooooooooool0
1oooool2o`0005Kooooo0_l0003Vooooo`007_ooool00ol0003oooooooooo`07ooooo`;o00005Ooo
ool2o`00023ooooo0_l0003oooooo`Kooooo000Nooooo`;o00007oooool2o`00023ooooo0_l0003R
ooooo`;o00008Oooool001kooooo00?o0000ooooooooool0F?ooool2o`0000Kooooo0_l0000^oooo
o`;o00007?ooool2o`0000[ooooo0_l0001Xooooo`;o00001_ooool2o`0001Wooooo000Nooooo`03
o`000?oooooooooo01oooooo0_l0000Aooooo`;o00009?ooool2o`0000Kooooo0_l0000^ooooo`;o
00007?ooool2o`0000[ooooo0_l0000kooooo`;o0000<oooool2o`0001Wooooo000Nooooo`03o`00
0?oooooooooo01oooooo0_l0000Aooooo`;o0000;Oooool2o`00083ooooo0_l0000Booooo`;o0000
C_ooool001kooooo00?o0000ooooooooool02Oooool2o`0003cooooo0_l0000Hooooo`;o0000I_oo
ool2o`00017ooooo0_l00005ooooo`Go0000A_ooool2o`0001Oooooo000Nooooo`03o`000?oooooo
oooo00Wooooo0_l0000looooo`;o00005Oooool2o`0003kooooo0_l0000Yooooo`;o00004Oooool2
o`0000Kooooo1?l0000Zooooo`;o00006_ooool2o`0001Oooooo000Nooooo`03o`000?oooooooooo
05kooooo0_l0000=ooooo`;o0000;oooool2o`0001gooooo0_l0000Uooooo`?o0000:oooool2o`00
03?ooooo000Nooooo`03o`000?oooooooooo01kooooo0_l0001=ooooo`;o0000C_ooool2o`0000[o
oooo0_l0001looooo`007_ooool00ol0003oooooooooo`0Aooooo`;o00002oooool2o`0001Gooooo
0_l0000_ooooo`;o0000D_ooool2o`0000gooooo0_l0000<ooooo`;o00005Oooool2o`0005Oooooo
000Nooooo`04o`000?ooooooooooooooo`;o00003_ooool2o`0000cooooo0ol0000Cooooo`;o0000
;oooool2o`0000Wooooo0_l00002ooooo`;o00009oooool3o`0001Wooooo0_l00009ooooo`;o0000
4?ooool2o`0001Gooooo0_l0001Gooooo`007_ooool01?l0003oooooooooooooool2o`0000Cooooo
0_l0000Fooooo`?o0000Boooool2o`0000;ooooo0_l00002ooooo`;o00009oooool3o`0002Cooooo
0_l0000Iooooo`;o00008Oooool2o`0001;ooooo0_l0000^ooooo`007_ooool00ol0003ooooooooo
o`07ooooo`Co0000H_ooool2o`00077ooooo0_l0000?ooooo`;o00004?ooool2o`0001;ooooo0_l0
000Jooooo`;o00004_ooool001kooooo00?o0000ooooooooool02Oooool2o`000=Wooooo0_l0000;
ooooo`;o0000@?ooool2o`0001;ooooo000Nooooo`03o`000?oooooooooo02Kooooo0_l0001Poooo
o`;o00004oooool2o`0000Wooooo0_l0000jooooo`;o0000HOooool001kooooo00?o0000oooooooo
ool08oooool2o`000003ooooool0003o000003kooooo0_l0000Pooooo`;o00004oooool2o`0000Wo
oooo0_l0000Zooooo`;o00007_ooool2o`0002[ooooo0_l0000Uooooo`007_ooool00ol0003ooooo
ooooo`0<ooooo`;o00005Oooool2o`0000kooooo0_l0000aooooo`;o00006Oooool2o`00057ooooo
0_l00009ooooo`;o00004oooool2o`0001Oooooo0_l0000Aooooo`;o00009Oooool001kooooo0_l0
000=ooooo`;o00009Oooool2o`0002?ooooo0_l0000Wooooo`;o0000:Oooool2o`0001Gooooo0_l0
000Jooooo`;o0000;?ooool2o`0003Sooooo000Nooooo`03o`000?oooooooooo05Sooooo0_l0000B
ooooo`;o0000?_ooool2o`0001Gooooo0_l00022ooooo`007_ooool00ol0003oooooooooo`1Ioooo
o`;o00004Oooool2o`0002gooooo0_l0000?ooooo`;o0000Boooool2o`0004cooooo000Nooooo`03
o`000?oooooooooo04Wooooo0_l0000>ooooo`;o0000@?ooool2o`0000oooooo0_l0001;ooooo`;o
00007?ooool2o`0002kooooo000Nooooo`03o`000?oooooooooo047ooooo0_l00006ooooo`;o0000
<?ooool2o`0000cooooo0_l0000Eooooo`;o0000MOooool2o`0000Sooooo0_l0000Tooooo`007_oo
ool00ol0003oooooooooo`11ooooo`;o0000>?ooool2o`0000?ooooo0_l00007ooooo`;o00005Ooo
ool2o`0002Gooooo0_l0001Hooooo`;o00009?ooool001kooooo00?o0000ooooooooool0P?ooool2
o`0004Gooooo0_l00005ooooo`;o0000H?ooool2o`0001Gooooo000Nooooo`03o`000?oooooooooo
04Sooooo0_l0001/ooooo`;o00005_ooool2o`0002Cooooo0_l0000jooooo`;o00005Oooool001ko
oooo00?o0000ooooooooool0@Oooool2o`0000Gooooo0_l0001:ooooo`;o00008?ooool2o`0003co
oooo0_l0001Aooooo`007_ooool00ol0003oooooooooo`0cooooo`;o00003?ooool2o`0004kooooo
0_l000000ooooooo0000o`00000]ooooo`;o00008oooool2o`0005gooooo000Nooooo`?o0000<ooo
ool2o`00017ooooo0_l000000ooooooo0000o`00000Qooooo`;o00000_ooool2o`0001Wooooo0_l0
0004ooooo`;o0000<?ooool2o`0002?ooooo0_l0001Mooooo`007_ooool3o`00033ooooo0_l0000D
ooooo`;o000000?oooooo`000?l000000oooool2o`0000Gooooo0_l0000Eooooo`;o00000_ooool2
o`0000[ooooo0_l0000=ooooo`;o00008?ooool2o`0009Sooooo000Nooooo`03o`000?oooooooooo
033ooooo0_l0000Looooo`;o00001Oooool2o`0002Gooooo0_l0000_ooooo`;o0000FOooool2o`00
00[ooooo0_l0000Xooooo`;o00001oooool001kooooo00?o0000ooooooooool09_ooool2o`0000_o
oooo0_l0000looooo`;o0000A_ooool2o`0001;ooooo0_l0000iooooo`;o00002_ooool2o`0002Go
oooo0_l000000ooooooo0000o`000007ooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o0000
00?oooooo`000?l000005oooool2o`0000_ooooo0_l0000looooo`;o0000A_ooool2o`0001;ooooo
0_l0001Hooooo`;o00004_ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0
00000ooooooo0000o`00000Gooooo`;o00003?ooool2o`0001oooooo0_l0001Dooooo`;o0000N_oo
ool2o`0001kooooo000Nooooo`;o00009oooool2o`0000cooooo0_l0000Oooooo`;o0000E?ooool2
o`0002cooooo0_l0000;ooooo`;o0000>Oooool2o`0002Cooooo000Nooooo`03o`000?oooooooooo
01Kooooo0_l00017ooooo`;o00003?ooool2o`0001Sooooo0_l0001@ooooo`;o00002oooool2o`00
02Oooooo0_l0000@ooooo`;o00009?ooool001kooooo00?o0000ooooooooool05_ooool2o`0004Oo
oooo0_l0000:ooooo`Co000000?oooooo`000?l000005Oooool2o`0003Wooooo0_l0000Fooooo`;o
00006?ooool2o`0001Wooooo0_l0000fooooo`007_ooool00ol0003oooooooooo`1[ooooo`;o0000
0oooool2o`00053ooooo0_l0000Fooooo`;o00002Oooool2o`0000Cooooo0_l00007ooooo`;o0000
DOooool001kooooo00?o0000ooooooooool0Aoooool2o`0002_ooooo0_l0001Iooooo`;o00003ooo
ool2o`0000?ooooo0_l00004ooooo`;o00004_ooool2o`0000Sooooo0_l0000looooo`007_ooool0
0ol0003oooooooooo`17ooooo`;o0000:oooool2o`00013ooooo0_l0000Vooooo`;o00007oooool2
o`0000oooooo0_l0000Mooooo`;o00002?ooool2o`0002?ooooo0_l0000Gooooo`007_ooool00ol0
003oooooooooo`1Mooooo`;o00009oooool2o`0002Kooooo0_l00002ooooo`;o0000N_ooool2o`00
01Oooooo000Nooooo`03o`000?oooooooooo043ooooo0_l0000Kooooo`;o0000Doooool2o`0003go
oooo0_l00008ooooo`;o0000B_ooool001kooooo00?o0000ooooooooool05Oooool2o`0002Wooooo
0_l0000;ooooo`;o0000X_ooool2o`0000Sooooo0_l0001:ooooo`007_ooool5o`0001?ooooo0_l0
000fooooo`;o00001?ooool2o`000?;ooooo000Nooooo`Go0000DOooool2o`0002Sooooo0_l0001_
ooooo`;o0000Eoooool001kooooo00?o0000ooooooooool00_l0001kooooo`;o0000:?ooool2o`00
01;ooooo0_l0000Kooooo`;o00000oooool2o`0000oooooo1?l0001Eooooo`007_ooool00ol0003o
ooooooooo`0Eooooo`;o00002oooool2o`0008?ooooo0_l0000Booooo`;o00006oooool2o`0000?o
oooo0_l00006ooooo`;o00002Oooool2o`0005Gooooo000Nooooo`03o`000?oooooooooo01Gooooo
0_l0000;ooooo`;o00001oooool2o`0007Wooooo0_l00005ooooo`;o0000=_ooool2o`0000Cooooo
0_l0000Gooooo`;o0000=Oooool2o`0000[ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo02_o
oooo0_l0000Uooooo`;o0000;Oooool2o`0001?ooooo0_l0000>ooooo`;o00001Oooool2o`0003co
oooo0_l0000Cooooo`;o00000_ooool2o`0000Sooooo0_l0000[ooooo`;o00002_ooool000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q
00Kooooo00?o0000ooooooooool02Oooool2o`0000cooooo0_l0000Tooooo`;o00004oooool2o`00
02gooooo0_l0000Cooooo`;o0000J?ooool2o`0000cooooo0_l0000gooooo`000oooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o00002Oooool2
o`0000cooooo0_l00006ooooo`;o00007?ooool2o`0000Cooooo0_l0000kooooo`;o0000E?ooool2
o`0006oooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonH
V9So8B4Q00Kooooo00?o0000ooooooooool07oooool2o`0002;ooooo0_l0000kooooo`;o0000<ooo
ool2o`0001oooooo0_l0001_ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go
0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo01Wooooo0_l0001=ooooo`;o0000
;?ooool2o`0001gooooo0_l0002@ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo
00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`0Iooooo`;o00008oooool2o`0002Sooooo
0_l0000Hooooo`;o00004_ooool2o`000:oooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo00Kooooo0_l0000eooooo`?o0000
@_ooool2o`0000Kooooo0_l0002?ooooo`;o0000:_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool01_ooool2o`0003Go
oooo0_l0000[ooooo`;o00007_ooool2o`0002;ooooo0_l0001Mooooo`;o00003?ooool2o`00013o
oooo0_l0000Hooooo`007_ooool00ol0003oooooooooo`0Wooooo`;o0000@Oooool2o`00027ooooo
0_l0000Oooooo`;o00002_ooool2o`00057ooooo0_l0000Nooooo`;o00006?ooool001kooooo00?o
0000ooooooooool09oooool2o`0006Cooooo0_l0000[ooooo`;o0000Roooool001kooooo0ol0000l
ooooo`;o0000Ooooool2o`0001_ooooo0_l0001[ooooo`007_ooool3o`0003cooooo0_l0001ooooo
o`;o00006oooool2o`0006_ooooo000Nooooo`03o`000?oooooooooo05kooooo0_l0000[ooooo`;o
0000[oooool2o`0000Wooooo000Nooooo`03o`000?oooooooooo03Kooooo0_l0000@ooooo`;o0000
5?ooool2o`0002Sooooo0_l000000ooooooo0000o`00001/ooooo`;o0000;oooool2o`00013ooooo
0_l00009ooooo`007_ooool00ol0003oooooooooo`0fooooo`;o00000oooool2o`0000_ooooo0_l0
000nooooo`;o00003Oooool2o`00063ooooo0_l0000_ooooo`;o00006oooool001kooooo00Co0000
oooooooooooooooo0_l0000hooooo`;o0000F_ooool2o`000:kooooo000Nooooo`04o`000?oooooo
ooooooooo`;o00002?ooool2o`000;Cooooo0_l0001fooooo`;o00003?ooool001kooooo00?o0000
ooooooooool02oooool2o`000;Cooooo0_l0000Zooooo`Co0000B?ooool2o`0000cooooo000Noooo
o`03o`000?oooooooooo03Wooooo0_l00017ooooo`;o0000Eoooool2o`00013ooooo1?l0001Foooo
o`007_ooool2o`0003[ooooo0_l0000oooooo`;o00001_ooool2o`0003;ooooo0_l0000Sooooo`;o
0000>_ooool2o`0002kooooo000Nooooo`03o`000?oooooooooo02Wooooo0_l0001?ooooo`;o0000
>_ooool2o`0001?ooooo0_l0000oooooo`;o00002Oooool2o`0000_ooooo0_l0000Qooooo`007_oo
ool00ol0003oooooooooo`0Yooooo`;o0000=?ooool2o`0006[ooooo0_l0000oooooo`;o00005_oo
ool2o`0001Wooooo0_l00006ooooo`007_ooool00ol0003oooooooooo`0aooooo`;o0000;?ooool2
o`0001Kooooo0_l0000Gooooo`;o0000[Oooool2o`0000Kooooo000Nooooo`?o0000<Oooool2o`00
04Cooooo0_l0000Gooooo`;o0000Poooool2o`00033ooooo000Nooooo`?o0000EOooool2o`0000go
oooo0_l0001[ooooo`;o00008?ooool2o`00023ooooo0ol0000:ooooo`;o00008oooool001kooooo
00?o0000ooooooooool0;oooool2o`0002Cooooo0_l0000=ooooo`;o0000Joooool2o`00023ooooo
0_l0000>ooooo`;o00004Oooool2o`0000[ooooo0_l0000@ooooo`;o00004Oooool001kooooo00?o
0000ooooooooool0;oooool2o`0001oooooo0_l0000looooo`;o0000Loooool2o`0002oooooo0_l0
000Aooooo`007_ooool00ol0003oooooooooo`1@ooooo`;o00001Oooool2o`0003Gooooo0_l0001a
ooooo`;o0000A?ooool001kooooo00?o0000ooooooooool01_ooool4o`0004gooooo0_l0000hoooo
o`;o00008oooool2o`0004Wooooo0_l00014ooooo`007_ooool00ol0003oooooooooo`06ooooo`Co
00007Oooool2o`0006Gooooo0_l000000ooooooo0000o`00000Looooo`;o00001Oooool2o`000003
ooooool0003o000000Cooooo0_l0000Jooooo`;o00002_ooool2o`00033ooooo0_l0000/ooooo`00
7_ooool00ol0003oooooooooo`0<ooooo`;o00006Oooool2o`0004Gooooo0_l0000Nooooo`;o0000
3Oooool2o`00013ooooo0_l00008ooooo`;o00001?ooool2o`0001[ooooo0_l0000:ooooo`;o0000
<?ooool2o`0002cooooo000Nooooo`03o`000?oooooooooo00cooooo0_l0000Xooooo`;o0000=_oo
ool2o`0002gooooo0_l0001=ooooo`;o0000FOooool001kooooo00?o0000ooooooooool0=_ooool2
o`0000;ooooo0_l0000?ooooo`;o00003Oooool2o`00093ooooo0_l0000Cooooo`;o0000A?ooool0
01kooooo00?o0000ooooooooool0>_ooool2o`0000cooooo0_l000000ooooooo0000o`00000=oooo
o`;o0000YOooool2o`0003Cooooo0_l00003ooooo`;o00002Oooool001kooooo00?o0000oooooooo
ool02_ooool2o`0000Cooooo0_l0000fooooo`;o0000I_ooool2o`0008Gooooo0_l000000ooooooo
0000o`000002o`0000Wooooo000Nooooo`;o00002oooool2o`0000Cooooo0_l0001Rooooo`;o0000
>_ooool2o`0006kooooo0_l0000Hooooo`;o00002oooool001kooooo00?o0000ooooooooool0C_oo
ool2o`0002Cooooo0_l0002Zooooo`;o00009Oooool001kooooo00?o0000ooooooooool0C_ooool2
o`0009cooooo0_l0001Iooooo`007_ooool00ol0003oooooooooo`0dooooo`;o0000;_ooool2o`00
00Gooooo0_l00006ooooo`;o0000??ooool2o`0003Wooooo0_l0001Iooooo`007_ooool00ol0003o
ooooooooo`0Yooooo`;o00002Oooool2o`0002kooooo0_l00005ooooo`;o00001_ooool2o`0003co
oooo0_l0002Dooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o00002Oooool2o`0000?ooooo
0_l0003ooooooagooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l00009ooooo`;o0000COoo
ool2o`00053ooooo0_l00020ooooo`007_ooool00ol0003oooooooooo`1Yooooo`;o00002?ooool2
o`0002[ooooo0_l0000Sooooo`?o00004?ooool2o`0006kooooo000Nooooo`03o`000?oooooooooo
00Sooooo0_l0001Oooooo`;o0000=?ooool2o`0002?ooooo0_l0000Aooooo`;o0000K_ooool001ko
oooo00?o0000ooooooooool02?ooool2o`000:Wooooo0_l0001dooooo`;o00007?ooool001kooooo
00?o0000ooooooooool0<Oooool2o`00083ooooo0_l0000Mooooo`;o0000EOooool2o`0001cooooo
000Nooooo`03o`000?oooooooooo037ooooo0_l00021ooooo`;o00001Oooool2o`0000?ooooo0_l0
000@ooooo`;o00007_ooool4o`00057ooooo000Nooooo`03o`000?oooooooooo00Gooooo0_l00023
ooooo`;o00000oooool2o`0002?ooooo0_l00005ooooo`;o00000oooool2o`0000kooooo0_l00004
ooooo`;o00006_ooool4o`0002_ooooo0_l0000Tooooo`007_ooool00ol0003oooooooooo`05oooo
o`;o0000Poooool2o`0000?ooooo0_l0000`ooooo`;o00003Oooool2o`0000Cooooo0_l00019oooo
o`;o00009?ooool001kooooo00?o0000ooooooooool0`Oooool2o`0003_ooooo0_l00017ooooo`00
7_ooool00ol0003oooooooooo`1Sooooo`;o00004_ooool2o`0008Gooooo0_l00017ooooo`007_oo
ool2o`0006Cooooo0_l0000Booooo`;o00001?ooool2o`0002;ooooo0_l0001?ooooo`;o0000Dooo
ool001kooooo00?o0000ooooooooool0<oooool2o`0003;ooooo0_l0000Dooooo`;o00008_ooool2
o`0000Gooooo0_l00018ooooo`;o00003Oooool2o`0003_ooooo0_l00007ooooo`007_ooool00ol0
003oooooooooo`0Rooooo`;o00003oooool2o`0003;ooooo0_l0000Iooooo`;o00009?ooool2o`00
05Oooooo0_l00005ooooo`;o0000=?ooool2o`0000Oooooo000Nooooo`04o`000?oooooooooooooo
o`;o00007oooool2o`0000Wooooo0_l0000Jooooo`;o00009?ooool2o`0000Oooooo0_l00008oooo
o`;o0000FOooool2o`0002Wooooo0_l0000mooooo`007_ooool01?l0003oooooooooooooool2o`00
02[ooooo0_l0000:ooooo`;o00003?ooool4o`0002Cooooo0_l00007ooooo`;o00008_ooool2o`00
03oooooo0_l0001Xooooo`007_ooool00ol0003oooooooooo`05ooooo`;o0000<_ooool2o`0000co
oooo0_l0001Cooooo`;o0000ZOooool001kooooo00?o0000ooooooooool01Oooool2o`0000Gooooo
0_l0003ooooooc[ooooo000Nooooo`03o`000?oooooooooo00cooooo0_l0000;ooooo`;o0000F?oo
ool2o`0002?ooooo0_l0001;ooooo`;o00005?ooool2o`0004[ooooo000Nooooo`03o`000?oooooo
oooo01Wooooo0_l0000Eooooo`;o00007?ooool2o`0000Sooooo0_l0000Iooooo`;o00008oooool3
o`0004[ooooo0_l0000Dooooo`;o0000B_ooool001kooooo00?o0000ooooooooool0:oooool2o`00
00?ooooo0_l0000Looooo`;o00002?ooool2o`0001Sooooo0_l0000Uooooo`;o0000Ioooool2o`00
04?ooooo000Nooooo`03o`000?oooooooooo02_ooooo0_l00015ooooo`;o0000S_ooool2o`0002Co
oooo0_l0000Mooooo`007_ooool00ol0003oooooooooo`1@ooooo`;o00008oooool2o`0001cooooo
0_l0002Cooooo`;o00007Oooool001kooooo00?o0000ooooooooool0D?ooool2o`0002?ooooo0_l0
000Looooo`;o0000Eoooool2o`0005Wooooo000Nooooo`03o`000?oooooooooo02;ooooo0_l0002M
ooooo`;o0000:Oooool2o`0002?ooooo0_l00007ooooo`;o0000:oooool000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o
0000ooooooooool03oooool2o`00017ooooo0_l0002Looooo`?o0000C_ooool2o`0000Oooooo0_l0
000[ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0?ooooo`;o00006Oooool2o`0001oooooo
0_l0001_ooooo`;o00000_ooool2o`0000_ooooo0_l0001hooooo`000oooool01Ol@413ooooooooo
oooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000:_ooool2o`0001oo
oooo0_l0000Wooooo`;o0000A_ooool2o`0000;ooooo0_l0000;ooooo`;o0000N?ooool000?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool00ol0
003oooooooooo`0Oooooo`;o0000<?ooool2o`0001[ooooo0_l00005ooooo`;o0000B_ooool2o`00
01Wooooo0_l0001Sooooo`;o00001Oooool000?ooooo00Go0000ooooooooooooooooo`00000;oooo
o`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`0Oooooo`;o0000<?ooool2
o`0001[ooooo0_l0001Zooooo`Co0000Hoooool2o`0000Gooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0fOoo
ool2o`0001kooooo0_l0000Gooooo`;o0000<oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`3iooooo`;o0000
5oooool2o`0002cooooo0_l00005ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo00?ooooo0_l0000Gooooo`;o
0000COooool2o`00087ooooo0_l0001@ooooo`;o00001Oooool001kooooo00?o0000ooooooooool0
0oooool2o`00013ooooo0_l00005ooooo`;o0000B_ooool2o`000003ooooool0003o000004[ooooo
0_l0000eooooo`;o0000Eoooool001kooooo00?o0000ooooooooool05Oooool2o`0004Cooooo0_l0
000;ooooo`;o0000COooool2o`0002_ooooo0_l0001Qooooo`007_ooool00ol0003oooooooooo`1K
ooooo`;o0000Qoooool2o`00067ooooo000Nooooo`03o`000?oooooooooo0>Kooooo0_l0000Aoooo
o`;o0000C?ooool001kooooo00?o0000ooooooooool0@_ooool2o`000:;ooooo0_l0000Aooooo`;o
0000C?ooool001kooooo00?o0000ooooooooool0:Oooool2o`0001Oooooo0_l0003oooooo`Cooooo
000Nooooo`03o`000?oooooooooo02Wooooo0_l0003ooooooagooooo000Nooooo`03o`000?oooooo
oooo07Cooooo0_l00003ooooo`;o0000YOooool4o`0002?ooooo000Nooooo`04o`000?oooooooooo
ooooo`;o0000:?ooool2o`0000Wooooo0_l0000looooo`;o00000oooool2o`0006Kooooo0_l0000E
ooooo`;o00009_ooool4o`0002?ooooo000Nooooo`04o`000?ooooooooooooooo`;o00002oooool2
o`0001_ooooo0_l00009ooooo`;o0000?_ooool2o`0001cooooo0_l0001;ooooo`;o00003_ooool2
o`0000Gooooo0_l0000Iooooo`;o0000<_ooool001kooooo0_l0000?ooooo`;o00008Oooool2o`00
04?ooooo0_l0000Looooo`;o0000Eoooool2o`0000;ooooo0_l0000Pooooo`;o00002oooool2o`00
02Gooooo000Nooooo`;o0000<_ooool2o`00033ooooo0_l00006ooooo`;o000000?oooooo`000?l0
0000OOooool2o`00037ooooo0_l0000Uooooo`007_ooool00ol0003oooooooooo`1Sooooo`;o0000
1_ooool2o`000003ooooool0003o000000;o0000eOooool001kooooo00?o0000ooooooooool00_l0
001Wooooo`;o00001Oooool2o`000=Gooooo000Nooooo`03o`000?oooooooooo00;o00002oooool2
o`0000cooooo0_l0001<ooooo`;o0000g?ooool001gooooo0_l0000?ooooo`;o00003?ooool2o`00
0;Gooooo0_l0001cooooo`007Oooool2o`0003Wooooo0_l0000hooooo`;o0000Goooool2o`0007?o
oooo000Nooooo`03o`000?oooooooooo03Oooooo0_l0000Qooooo`;o00005Oooool2o`0000Sooooo
0_l0000:ooooo`;o0000W_ooool2o`0001kooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l0
0008ooooo`;o00009oooool2o`0001oooooo0_l0000:ooooo`;o0000E_ooool2o`0001[ooooo0_l0
000<ooooo`;o00007?ooool2o`0001Gooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`0W
ooooo`;o00002?ooool2o`00047ooooo0_l0001Yooooo`;o00006_ooool2o`0000Wooooo0_l00000
0ooooooo0000o`00000cooooo`;o00001oooool001kooooo00?o0000ooooooooool0M?ooool2o`00
093ooooo0_l0000Xooooo`;o00005Oooool001kooooo00?o0000ooooooooool0kOooool2o`0000So
oooo0_l0000gooooo`;o00005Oooool001kooooo00?o0000ooooooooool0kOooool2o`0000Sooooo
0_l0001>ooooo`007_ooool00ol0003oooooooooo`0hooooo`;o0000DOooool2o`0007?ooooo0_l0
0015ooooo`007_ooool00ol0003oooooooooo`0hooooo`;o0000DOooool2o`0007?ooooo0_l00015
ooooo`007_ooool00ol0003oooooooooo`2/ooooo`;o0000=oooool2o`00063ooooo000Nooooo`03
o`000?oooooooooo057ooooo0_l0001Iooooo`;o00007Oooool2o`0001Sooooo0_l0001Pooooo`00
7_ooool2o`0001Cooooo0_l00008ooooo`;o0000<_ooool2o`0000_ooooo0_l0000Jooooo`;o0000
Coooool2o`0003Oooooo0_l00011ooooo`007_ooool00ol0003oooooooooo`06ooooo`;o00002ooo
ool2o`0000Sooooo0_l0000oooooo`;o00006_ooool2o`0000Kooooo0_l00020ooooo`;o00006ooo
ool2o`0002Cooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l0000Uooooo`;o0000?Oooool2
o`00017ooooo1Ol0000Cooooo`;o0000FOooool2o`0002gooooo0_l0000Tooooo`007_ooool00ol0
003oooooooooo`0]ooooo`;o0000?Oooool2o`00017ooooo1?l0000Dooooo`;o0000Boooool2o`00
00cooooo0_l0001Cooooo`007_ooool00ol0003oooooooooo`1Vooooo`;o0000O?ooool2o`0001Co
oooo0_l0000;ooooo`;o0000?_ooool001kooooo00?o0000ooooooooool0I_ooool2o`0009;ooooo
0_l0000;ooooo`;o0000<?ooool2o`0000cooooo000Nooooo`03o`000?oooooooooo02?ooooo0_l0
003ooooooaGooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`0Looooo`;o00001Oooool2
o`000?cooooo0_l0000Tooooo`007_ooool00ol0003oooooooooo`0Looooo`;o0000ooooool4oooo
o`;o00009?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`02o`0005_ooooo0_l0003Xooooo`007_ooool00ol0003oooooooooo`02o`0000Kooooo0_l0
001Cooooo`;o0000]Oooool2o`0002_ooooo0_l00004ooooo`007_ooool00ol0003oooooooooo`08
ooooo`;o0000Toooool2o`0001Sooooo0_l0001Kooooo`;o0000:oooool2o`0000Cooooo000Noooo
o`03o`000?oooooooooo02gooooo0_l0000Hooooo`;o00000_ooool2o`00053ooooo0_l0000Hoooo
o`;o00003_ooool2o`00013ooooo0_l0001/ooooo`007_ooool00ol0003oooooooooo`0]ooooo`;o
00006?ooool2o`0000;ooooo0_l0000mooooo`;o00006?ooool2o`00027ooooo0_l0000@ooooo`;o
0000B_ooool2o`00023ooooo000Nooooo`03o`000?oooooooooo08[ooooo0_l0000Hooooo`;o0000
3?ooool2o`0003Oooooo0_l0000Xooooo`;o00003_ooool2o`0000kooooo0_l0000@ooooo`007_oo
ool2o`00027ooooo0_l00002ooooo`;o00002_ooool2o`00083ooooo0_l0000gooooo`;o0000:?oo
ool2o`0001kooooo0_l0000@ooooo`007_ooool00ol0003oooooooooo`09ooooo`;o00005Oooool2
o`0000;ooooo0_l0000:ooooo`;o0000jOooool2o`0002[ooooo000Nooooo`03o`000?oooooooooo
00Wooooo0_l00005ooooo`;o0000V_ooool2o`0000?ooooo0_l0001Xooooo`;o0000:_ooool001ko
oooo00?o0000ooooooooool04?ooool2o`0006oooooo0_l0000Uooooo`;o00000_ooool2o`0000?o
oooo0_l0002:ooooo`;o00002?ooool001kooooo00?o0000ooooooooool0POooool2o`0002Gooooo
0_l0002Cooooo`;o00002?ooool001kooooo00?o0000ooooooooool03Oooool2o`0007;ooooo0ol0
000Jooooo`;o00002oooool2o`0001Kooooo0_l0000`ooooo`;o0000B_ooool2o`0000Cooooo000N
ooooo`03o`000?oooooooooo00gooooo0_l0000Wooooo`;o00002oooool2o`0003gooooo0_l0000J
ooooo`;o00002oooool2o`0000Sooooo0_l0000<ooooo`;o0000<?ooool2o`0001_ooooo0_l0000R
ooooo`;o00002Oooool2o`0000Cooooo000Nooooo`03o`000?oooooooooo027ooooo0_l0000Coooo
o`;o00002oooool2o`00073ooooo0_l0001Kooooo`;o00008_ooool2o`0000oooooo000Nooooo`03
o`000?oooooooooo027ooooo0_l0001/ooooo`;o00007?ooool2o`0009Sooooo000Nooooo`03o`00
0?oooooooooo02oooooo0_l0000@ooooo`;o00009Oooool2o`0001Wooooo0_l00004ooooo`;o0000
1?ooool2o`0001cooooo0_l0002Hooooo`007_ooool00ol0003oooooooooo`0_ooooo`;o00004?oo
ool2o`0000cooooo0_l0000Gooooo`;o00006Oooool2o`0000?ooooo0ol0000Nooooo`Co0000V_oo
ool001kooooo00?o0000ooooooooool09?ooool2o`0002Wooooo0_l0000_ooooo`;o00001_ooool2
o`0001oooooo1?l00015ooooo`;o0000Doooool001kooooo00?o0000ooooooooool09?ooool2o`00
01cooooo0_l0000Booooo`;o0000:?ooool4o`0001;ooooo0_l0001Jooooo`;o0000Doooool001ko
oooo00?o0000ooooooooool0@_ooool2o`0001;ooooo0_l0000Zooooo`;o00004_ooool2o`0003Ko
oooo0_l0001Pooooo`;o00000oooool2o`00013ooooo000Dooooo`Co000000?o410@ooooooooool0
0oooool00ol0003oooooooooo`2Aooooo`;o0000>oooool2o`0002Wooooo0_l0000eooooo`;o0000
0oooool2o`0000Kooooo0_l00008ooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo097ooooo0_l0001<ooooo`;o00004?ooool2o`0000Kooooo0_l00012ooooo`;o00002?oo
ool001Kooooo00?o0000ooooooooool01Oooool3o`000:Wooooo0_l0000Dooooo`;o00007_ooool2
o`00013ooooo0_l0001<ooooo`;o00001_ooool001Kooooo00?o0000ooooooooool0/Oooool2o`00
01Cooooo0_l0001nooooo`;o00001_ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`00
5_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?oo
ool001Cooooo00?oEEEEofIVI_l00000oooooomBooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.19929 .50938 Mdot
.98999 .73926 Mdot
.8661 .03373 Mdot
.25148 .64689 Mdot
.13102 .4637 Mdot
.89143 .06211 Mdot
.14286 .90929 Mdot
.19064 .64877 Mdot
.83419 .10279 Mdot
.1562 .01619 Mdot
.59902 .01757 Mdot
.94298 .62935 Mdot
.76181 .48972 Mdot
.31847 .52394 Mdot
.46554 .33682 Mdot
.23997 .68369 Mdot
.48136 .93204 Mdot
.4561 .42351 Mdot
.77938 .9787 Mdot
.79423 .95086 Mdot
.56178 .0606 Mdot
.54494 .06391 Mdot
.77398 .03267 Mdot
.20533 .3899 Mdot
.71807 .32836 Mdot
.17235 .3827 Mdot
.79402 .91755 Mdot
.61556 .39194 Mdot
.19153 .66945 Mdot
.26974 .26485 Mdot
.60728 .22501 Mdot
.28996 .41146 Mdot
.4825 .99594 Mdot
.12634 .12018 Mdot
.72619 .0465 Mdot
.0484 .62263 Mdot
.16817 .23537 Mdot
.39444 .26793 Mdot
.23655 .05312 Mdot
.98554 .98119 Mdot
.06074 .34133 Mdot
.45146 .972 Mdot
.28117 .44878 Mdot
.18767 .41529 Mdot
.64347 .38592 Mdot
.68859 .5826 Mdot
.92223 .19573 Mdot
.69139 .69465 Mdot
.28659 .46386 Mdot
.02272 .35537 Mdot
.73697 .2278 Mdot
.35456 .52556 Mdot
.13725 .68203 Mdot
.99568 .37674 Mdot
.8131 .3954 Mdot
.73598 .20553 Mdot
.51344 .96033 Mdot
.02514 .71478 Mdot
.15197 .41494 Mdot
.07914 .74628 Mdot
.22262 .42684 Mdot
.70184 .78012 Mdot
.25384 .05724 Mdot
.15761 .33477 Mdot
.14502 .48387 Mdot
.36302 .0772 Mdot
.41654 .73323 Mdot
.61599 .17844 Mdot
.24028 .38168 Mdot
.9605 .10208 Mdot
.77769 .72868 Mdot
.80002 .15276 Mdot
.14188 .69903 Mdot
.1252 .89951 Mdot
.1951 .50412 Mdot
.56722 .22123 Mdot
.83885 .62382 Mdot
.13061 .08904 Mdot
.7039 .93786 Mdot
.34932 .18912 Mdot
.52677 .54328 Mdot
.58833 .08852 Mdot
.21421 .00043 Mdot
.69259 .46817 Mdot
.83303 .31846 Mdot
.70926 .25764 Mdot
.52048 .97937 Mdot
.92038 .48755 Mdot
.56114 .05193 Mdot
.68031 .47602 Mdot
.03036 .9745 Mdot
.44666 .2257 Mdot
.26055 .70767 Mdot
.80872 .2453 Mdot
.95858 .70033 Mdot
.46125 .62447 Mdot
.10378 .37955 Mdot
.78123 .47872 Mdot
.54668 .38072 Mdot
.13136 .958 Mdot
.5883 .28263 Mdot
.78128 .49396 Mdot
.9057 .83327 Mdot
.22863 .28423 Mdot
.79237 .76187 Mdot
.18092 .89676 Mdot
.62712 .12952 Mdot
.0164 .32672 Mdot
.16585 .08833 Mdot
.34036 .70354 Mdot
.5854 .53628 Mdot
.02235 .99629 Mdot
.74083 .54356 Mdot
.21642 .43364 Mdot
.26847 .49601 Mdot
.3807 .75358 Mdot
.48917 .67893 Mdot
.08793 .91533 Mdot
.84652 .69172 Mdot
.61444 .80205 Mdot
.75708 .5149 Mdot
.54685 .10091 Mdot
.16888 .79143 Mdot
.29069 .79027 Mdot
.39699 .37739 Mdot
.80241 .57097 Mdot
.72 .21565 Mdot
.84346 .64804 Mdot
.44666 .77909 Mdot
.65267 .05151 Mdot
.41634 .17411 Mdot
.19717 .52789 Mdot
.25259 .672 Mdot
.3574 .54831 Mdot
.96342 .65725 Mdot
.29775 .53696 Mdot
.41112 .99715 Mdot
.08766 .18998 Mdot
.61551 .80815 Mdot
.40522 .34449 Mdot
.28645 .05202 Mdot
.9114 .08408 Mdot
.8758 .6367 Mdot
.12815 .47848 Mdot
.78388 .31378 Mdot
.30823 .7551 Mdot
.86429 .75236 Mdot
.14378 .31932 Mdot
.19082 .46389 Mdot
.97697 .22671 Mdot
.23584 .51621 Mdot
.48252 .3547 Mdot
.05392 .35525 Mdot
.86847 .83147 Mdot
.0066 .37713 Mdot
.81788 .58246 Mdot
.13858 .43916 Mdot
.51768 .61929 Mdot
.52751 .93274 Mdot
.18367 .52542 Mdot
.33839 .26943 Mdot
.9831 .1728 Mdot
.99759 .01948 Mdot
.06802 .17107 Mdot
.86015 .52046 Mdot
.14309 .90936 Mdot
.77665 .76654 Mdot
.19544 .3268 Mdot
.68631 .51338 Mdot
.13497 .72503 Mdot
.02898 .40847 Mdot
.74444 .47067 Mdot
.34333 .04399 Mdot
.37745 .1712 Mdot
.46289 .29373 Mdot
.35832 .2812 Mdot
.32164 .78215 Mdot
.31255 .43795 Mdot
.1647 .24973 Mdot
.8984 .13649 Mdot
.0147 .50335 Mdot
.8829 .45887 Mdot
.04255 .54101 Mdot
.15367 .02454 Mdot
.70596 .49063 Mdot
.04919 .61521 Mdot
.23944 .28061 Mdot
.58085 .07347 Mdot
.56722 .58715 Mdot
.41451 .77665 Mdot
.32133 .1094 Mdot
.32732 .65759 Mdot
.52434 .70718 Mdot
.82815 .44403 Mdot
.08444 .96125 Mdot
.6895 .39522 Mdot
.65288 .47592 Mdot
.54917 .46636 Mdot
.27152 .05066 Mdot
.40303 .21032 Mdot
.21287 .60088 Mdot
.12095 .44557 Mdot
.69796 .59769 Mdot
.18107 .78479 Mdot
.13832 .42649 Mdot
.2885 .6098 Mdot
.33287 .4896 Mdot
.6519 .16367 Mdot
.68109 .07666 Mdot
.68443 .24911 Mdot
.36047 .03285 Mdot
.38099 .93697 Mdot
.89578 .11368 Mdot
.73299 .46892 Mdot
.60197 .68309 Mdot
.68333 .49643 Mdot
.19771 .05112 Mdot
.50213 .17821 Mdot
.11975 .62252 Mdot
.73661 .83427 Mdot
.86732 .68951 Mdot
.37151 .50566 Mdot
.27944 .93824 Mdot
.10524 .2722 Mdot
.33807 .80923 Mdot
.21288 .79727 Mdot
.90637 .13914 Mdot
.798 .11191 Mdot
.5388 .66166 Mdot
.19633 .74149 Mdot
.37037 .02141 Mdot
.96171 .39199 Mdot
.25859 .57857 Mdot
.95314 .74212 Mdot
.08193 .72723 Mdot
.87547 .81648 Mdot
.46034 .02841 Mdot
.61466 .76477 Mdot
.81503 .05012 Mdot
.13281 .79836 Mdot
.15998 .83679 Mdot
.10967 .13976 Mdot
.90637 .74315 Mdot
.93804 .10919 Mdot
.56955 .73033 Mdot
.64408 .03462 Mdot
.39378 .95023 Mdot
.75164 .65049 Mdot
.07811 .15702 Mdot
.19291 .6306 Mdot
.16827 .34912 Mdot
.68017 .63824 Mdot
.26856 .43449 Mdot
.71846 .63131 Mdot
.59538 .6806 Mdot
.00787 .57015 Mdot
.02028 .35048 Mdot
.03947 .05051 Mdot
.23501 .20932 Mdot
.99333 .86228 Mdot
.43834 .66663 Mdot
.34604 .39567 Mdot
.54701 .38987 Mdot
.57377 .50974 Mdot
.13764 .81253 Mdot
.94167 .44427 Mdot
.45845 .86535 Mdot
.32587 .71217 Mdot
.5541 .98605 Mdot
.82116 .42078 Mdot
.75161 .54807 Mdot
.08157 .37516 Mdot
.57471 .04574 Mdot
.30087 .29288 Mdot
.26906 .5708 Mdot
.8856 .68535 Mdot
.0651 .63311 Mdot
.89961 .22771 Mdot
.4697 .56578 Mdot
.80445 .00995 Mdot
.03118 .0867 Mdot
.69064 .35996 Mdot
.96672 .78818 Mdot
.86293 .32391 Mdot
.607 .35421 Mdot
.55578 .04311 Mdot
.7064 .45768 Mdot
.80162 .38929 Mdot
.80609 .55638 Mdot
.88459 .85575 Mdot
.27354 .31666 Mdot
.24078 .18512 Mdot
.23969 .02157 Mdot
.02344 .6739 Mdot
.78027 .00842 Mdot
.60329 .31026 Mdot
.19386 .18891 Mdot
.78519 .4172 Mdot
.81841 .4264 Mdot
.27419 .16839 Mdot
.3176 .48556 Mdot
.76529 .16813 Mdot
.15527 .53221 Mdot
.75036 .85629 Mdot
.58154 .23216 Mdot
.24477 .34717 Mdot
.30569 .9017 Mdot
.56465 .13145 Mdot
.27943 .07115 Mdot
.37108 .6261 Mdot
.43551 .53678 Mdot
.81321 .56537 Mdot
.80519 .39938 Mdot
.15958 .55736 Mdot
.15851 .88543 Mdot
.4138 .71001 Mdot
.67276 .02025 Mdot
.29798 .56797 Mdot
.79135 .37822 Mdot
.5051 .27203 Mdot
.94202 .12911 Mdot
.29699 .82082 Mdot
.41729 .27026 Mdot
.5943 .17601 Mdot
.34354 .47638 Mdot
.62249 .33546 Mdot
.0229 .48145 Mdot
.31857 .37894 Mdot
.91011 .24198 Mdot
.52634 .00768 Mdot
.03305 .53399 Mdot
.24734 .80791 Mdot
.15518 .23147 Mdot
.70827 .85238 Mdot
.04526 .75531 Mdot
.18679 .6722 Mdot
.22237 .24535 Mdot
.25413 .38858 Mdot
.01729 .31037 Mdot
.90021 .30415 Mdot
.84257 .90032 Mdot
.39952 .95553 Mdot
.20188 .38103 Mdot
.48217 .69451 Mdot
.11525 .30746 Mdot
.47496 .08485 Mdot
.4396 .26128 Mdot
.76465 .86652 Mdot
.28824 .76383 Mdot
.36659 .61368 Mdot
.29111 .01663 Mdot
.6461 .72871 Mdot
.06289 .36128 Mdot
.64909 .49459 Mdot
.72322 .91342 Mdot
.67489 .07795 Mdot
.22737 .39074 Mdot
.08875 .16972 Mdot
.8474 .25965 Mdot
.5847 .04507 Mdot
.9039 .90244 Mdot
.52695 .44425 Mdot
.75891 .45862 Mdot
.5657 .35005 Mdot
.90725 .09606 Mdot
.57728 .10287 Mdot
.05711 .33435 Mdot
.85186 .65947 Mdot
.70503 .39955 Mdot
.06587 .62329 Mdot
.89525 .22616 Mdot
.76711 .98085 Mdot
.35668 .84046 Mdot
.77535 .72178 Mdot
.35647 .68696 Mdot
.49595 .92201 Mdot
.40373 .62248 Mdot
.86281 .53157 Mdot
.21019 .54656 Mdot
.12206 .10611 Mdot
.08029 .32243 Mdot
.12631 .2684 Mdot
.9632 .79919 Mdot
.64011 .35435 Mdot
.25373 .56707 Mdot
.74333 .72918 Mdot
.61539 .72373 Mdot
.33113 .59715 Mdot
.15871 .01706 Mdot
.32819 .22045 Mdot
.87449 .3492 Mdot
.36517 .91642 Mdot
.45746 .02815 Mdot
.35094 .19486 Mdot
.01549 .7456 Mdot
.66054 .58882 Mdot
.92088 .97555 Mdot
.72613 .152 Mdot
.07532 .76537 Mdot
.65907 .35128 Mdot
.03054 .50981 Mdot
.55606 .21817 Mdot
.48665 .65414 Mdot
.42515 .31989 Mdot
.36284 .43672 Mdot
.28411 .84292 Mdot
.76667 .65227 Mdot
.81987 .05382 Mdot
.38169 .42566 Mdot
.25777 .83976 Mdot
.12608 .85153 Mdot
.81347 .6282 Mdot
.0177 .84476 Mdot
.9428 .49595 Mdot
.0426 .13415 Mdot
.47498 .4723 Mdot
.20739 .08605 Mdot
.8397 .56938 Mdot
.68036 .06781 Mdot
.77504 .84334 Mdot
.87148 .51548 Mdot
.81498 .85799 Mdot
.69648 .84201 Mdot
.42914 .31025 Mdot
.50642 .05071 Mdot
.63052 .63956 Mdot
.16354 .76916 Mdot
.08035 .59656 Mdot
.60113 .4943 Mdot
.36558 .00095 Mdot
.20994 .49749 Mdot
.23707 .42501 Mdot
.53491 .0046 Mdot
.82814 .30594 Mdot
.08084 .12997 Mdot
.00902 .41023 Mdot
.51395 .29955 Mdot
.34131 .3495 Mdot
.52369 .43758 Mdot
.28367 .98367 Mdot
.44794 .56162 Mdot
.29234 .00343 Mdot
.11496 .11921 Mdot
.06953 .94902 Mdot
.00628 .09971 Mdot
.33093 .52304 Mdot
.76994 .92827 Mdot
.4428 .25067 Mdot
.58284 .69595 Mdot
.34172 .61969 Mdot
.1114 .10188 Mdot
.02874 .84459 Mdot
.85092 .36699 Mdot
.58464 .0093 Mdot
.4317 .35573 Mdot
.6851 .86664 Mdot
.57662 .71137 Mdot
.45789 .64354 Mdot
.73886 .09323 Mdot
.15353 .70316 Mdot
.505 .38873 Mdot
.34872 .93416 Mdot
.97383 .99786 Mdot
.44808 .89269 Mdot
.28878 .55597 Mdot
.17034 .90368 Mdot
.87394 .13786 Mdot
.41283 .94219 Mdot
.18146 .07178 Mdot
.90694 .39609 Mdot
.39041 .72417 Mdot
.55262 .62825 Mdot
.51103 .7966 Mdot
.02941 .23752 Mdot
.05944 .77903 Mdot
.53079 .40504 Mdot
.5887 .34267 Mdot
.58675 .54829 Mdot
.79439 .17094 Mdot
.41672 .63928 Mdot
.98062 .0153 Mdot
.80755 .24802 Mdot
.65495 .96588 Mdot
.42534 .55081 Mdot
.29576 .39033 Mdot
.48684 .32414 Mdot
.26983 .36655 Mdot
.94265 .07581 Mdot
.59037 .22968 Mdot
.63792 .43965 Mdot
.19192 .99672 Mdot
.37894 .15869 Mdot
.24568 .54787 Mdot
.68523 .98876 Mdot
.07904 .29633 Mdot
.53463 .48629 Mdot
.673 .38843 Mdot
.69391 .20371 Mdot
.09459 .45599 Mdot
.82685 .78519 Mdot
.68112 .80267 Mdot
.34799 .32229 Mdot
.5035 .30196 Mdot
.99449 .05272 Mdot
.06783 .21626 Mdot
.41953 .35398 Mdot
.99389 .57354 Mdot
.43488 .04925 Mdot
.84677 .48193 Mdot
.19926 .67028 Mdot
.71872 .23525 Mdot
.17978 .64568 Mdot
.11926 .4967 Mdot
.8931 .15562 Mdot
.74842 .23276 Mdot
.04161 .89637 Mdot
.69625 .21181 Mdot
.63198 .73013 Mdot
.85773 .21038 Mdot
.34796 .7846 Mdot
.5551 .5559 Mdot
.62925 .05473 Mdot
.86239 .49464 Mdot
.14515 .2725 Mdot
.86376 .96442 Mdot
.26909 .14802 Mdot
.28423 .62122 Mdot
.45848 .35928 Mdot
.44635 .46403 Mdot
.56257 .63521 Mdot
.76301 .64288 Mdot
.27934 .57432 Mdot
.1408 .16185 Mdot
.66145 .12703 Mdot
.10796 .73068 Mdot
.22879 .78694 Mdot
.37938 .89283 Mdot
.14114 .28398 Mdot
.04307 .32158 Mdot
.97493 .66533 Mdot
.07111 .87221 Mdot
.99985 .95266 Mdot
.53255 .20915 Mdot
.8482 .3218 Mdot
.40348 .32836 Mdot
.39499 .48734 Mdot
.90258 .67044 Mdot
.17303 .67563 Mdot
.03351 .79801 Mdot
.95047 .01174 Mdot
.77096 .46308 Mdot
.32962 .36089 Mdot
.35212 .87088 Mdot
.31452 .49529 Mdot
.68707 .59424 Mdot
.70972 .14266 Mdot
.52333 .95812 Mdot
.21354 .96534 Mdot
.53925 .66753 Mdot
.20508 .46011 Mdot
.98443 .67776 Mdot
.92487 .86358 Mdot
.03068 .10119 Mdot
.31271 .64045 Mdot
.77973 .59401 Mdot
.88441 .19427 Mdot
.75953 .16335 Mdot
.9503 .12616 Mdot
.50704 .01223 Mdot
.06128 .83614 Mdot
.46358 .25179 Mdot
.03786 .92288 Mdot
.99322 .75661 Mdot
.91808 .68932 Mdot
.02135 .45662 Mdot
.79496 .11472 Mdot
.44812 .90913 Mdot
.3517 .02936 Mdot
.34163 .95939 Mdot
.44169 .02426 Mdot
.92416 .45278 Mdot
.41892 .09369 Mdot
.3322 .28266 Mdot
.95552 .19699 Mdot
.11389 .87309 Mdot
.57068 .54615 Mdot
.11629 .31694 Mdot
.74125 .34084 Mdot
.77663 .49878 Mdot
.03015 .28738 Mdot
.76964 .83679 Mdot
.65946 .05282 Mdot
.33456 .05023 Mdot
.29563 .81111 Mdot
.36826 .55218 Mdot
.43403 .78382 Mdot
.1656 .10868 Mdot
.19432 .10573 Mdot
.70623 .60962 Mdot
.1791 .86843 Mdot
.74592 .22801 Mdot
.30673 .54003 Mdot
.48297 .33999 Mdot
.54791 .46093 Mdot
.33747 .43623 Mdot
.16314 .48605 Mdot
.6541 .52523 Mdot
.85164 .96458 Mdot
.16917 .54551 Mdot
.78283 .19434 Mdot
.72172 .79778 Mdot
.24686 .23357 Mdot
.35866 .26218 Mdot
.0207 .7251 Mdot
.18556 .74417 Mdot
.68255 .20417 Mdot
.42726 .58351 Mdot
.63227 .2837 Mdot
.73623 .27336 Mdot
.86332 .31057 Mdot
.61175 .45786 Mdot
.15308 .19091 Mdot
.89096 .29552 Mdot
.78045 .89377 Mdot
.00372 .86008 Mdot
.7056 .92402 Mdot
.03473 .77273 Mdot
.12282 .6359 Mdot
.55499 .06171 Mdot
.46197 .95866 Mdot
.5191 .08535 Mdot
.58079 .60977 Mdot
.95966 .42027 Mdot
.4032 .54105 Mdot
.33368 .41073 Mdot
.81986 .27688 Mdot
.77081 .61285 Mdot
.34777 .66809 Mdot
.08654 .15694 Mdot
.62358 .96971 Mdot
.43488 .71072 Mdot
.42094 .3621 Mdot
.55251 .4111 Mdot
.07232 .90112 Mdot
.59157 .28103 Mdot
.12163 .28283 Mdot
.6129 .67283 Mdot
.0929 .38576 Mdot
.31351 .89345 Mdot
.79555 .84431 Mdot
.69386 .60568 Mdot
.18218 .95593 Mdot
.98821 .70705 Mdot
.91677 .78371 Mdot
.10284 .19495 Mdot
.26679 .70054 Mdot
.52334 .37239 Mdot
.45029 .46336 Mdot
.07592 .54444 Mdot
.58679 .25292 Mdot
.0693 .91548 Mdot
.43362 .23342 Mdot
.60118 .36409 Mdot
.35848 .82918 Mdot
.60313 .36423 Mdot
.43492 .59692 Mdot
.75327 .24421 Mdot
.28946 .4295 Mdot
.37567 .04988 Mdot
.71082 .19165 Mdot
.35172 .06992 Mdot
.1585 .71054 Mdot
.20434 .50005 Mdot
.61936 .34927 Mdot
.96655 .98159 Mdot
.85942 .19909 Mdot
.34824 .74191 Mdot
.51085 .08622 Mdot
.45245 .59157 Mdot
.46425 .1683 Mdot
.87068 .8743 Mdot
.67709 .59641 Mdot
.65331 .54 Mdot
.64572 .68183 Mdot
.78331 .40613 Mdot
.04001 .23707 Mdot
.61795 .14169 Mdot
.81209 .93393 Mdot
.55526 .57972 Mdot
.27614 .18557 Mdot
.12618 .70049 Mdot
.93216 .95143 Mdot
.40157 .6704 Mdot
.53385 .37901 Mdot
.5946 .2359 Mdot
.50877 .73492 Mdot
.95306 .20764 Mdot
.71019 .49379 Mdot
.35288 .9201 Mdot
.36104 .45518 Mdot
.87383 .64016 Mdot
.53583 .5231 Mdot
.62596 .71687 Mdot
.94485 .57654 Mdot
.20387 .96375 Mdot
.52195 .20875 Mdot
.54946 .40662 Mdot
.7309 .50021 Mdot
.81053 .31238 Mdot
.06255 .92848 Mdot
.47115 .10291 Mdot
.44106 .40908 Mdot
.88692 .84544 Mdot
.52462 .98392 Mdot
.00308 .93884 Mdot
.48814 .12006 Mdot
.13714 .22721 Mdot
.66647 .20243 Mdot
.146 .44842 Mdot
.9716 .6982 Mdot
.42509 .51628 Mdot
.36965 .74578 Mdot
.20485 .17542 Mdot
.73795 .27788 Mdot
.37418 .65623 Mdot
.37818 .57726 Mdot
.81836 .62084 Mdot
.73492 .36541 Mdot
.66534 .84349 Mdot
.91837 .17366 Mdot
.85579 .21891 Mdot
.74645 .37387 Mdot
.92054 .84192 Mdot
.66785 .04675 Mdot
.77426 .64823 Mdot
.20715 .76104 Mdot
.93225 .37465 Mdot
.97747 .96131 Mdot
.01456 .43783 Mdot
.12332 .50714 Mdot
.5535 .90492 Mdot
.14015 .31882 Mdot
.90649 .44793 Mdot
.06514 .91986 Mdot
.82147 .83724 Mdot
.10826 .25206 Mdot
.65746 .09143 Mdot
.46231 .73733 Mdot
.53468 .04406 Mdot
.57588 .67201 Mdot
.75672 .38582 Mdot
.67612 .87281 Mdot
.52731 .4874 Mdot
.4437 .42703 Mdot
.67763 .78557 Mdot
.26442 .42511 Mdot
.4861 .72868 Mdot
.99999 .21574 Mdot
.74378 .72301 Mdot
.66171 .73702 Mdot
.09211 .62275 Mdot
.37796 .78856 Mdot
.42489 .34469 Mdot
.88137 .41709 Mdot
.41087 .88108 Mdot
.41407 .5581 Mdot
.78319 .17814 Mdot
.13734 .77018 Mdot
.60453 .23198 Mdot
.55998 .93661 Mdot
.55332 .44499 Mdot
.5384 .08767 Mdot
.42548 .62536 Mdot
.37067 .10774 Mdot
.92191 .39348 Mdot
.73137 .58879 Mdot
.43512 .61563 Mdot
.24205 .54603 Mdot
.60386 .95565 Mdot
.94993 .58488 Mdot
.96521 .87742 Mdot
.05424 .22111 Mdot
.40962 .37658 Mdot
.56786 .33762 Mdot
.02097 .4277 Mdot
.08908 .08904 Mdot
.79709 .06266 Mdot
.59436 .52341 Mdot
.37488 .8938 Mdot
.04594 .60218 Mdot
.68584 .33479 Mdot
.81926 .24878 Mdot
.92925 .26048 Mdot
.73146 .64632 Mdot
.76189 .43499 Mdot
.2644 .74686 Mdot
.76947 .87752 Mdot
.4448 .16825 Mdot
.58389 .41012 Mdot
.72457 .52572 Mdot
.58824 .08179 Mdot
.81893 .25042 Mdot
.49698 .18568 Mdot
.63276 .16214 Mdot
.66984 .37816 Mdot
.24877 .33536 Mdot
.99694 .14795 Mdot
.71833 .6095 Mdot
.96167 .09714 Mdot
.54259 .30698 Mdot
.17314 .65742 Mdot
.71566 .39794 Mdot
.73535 .38564 Mdot
.87826 .73664 Mdot
.51119 .49898 Mdot
.1452 .31815 Mdot
.45634 .43191 Mdot
.17424 .3735 Mdot
.68754 .32647 Mdot
.00441 .56659 Mdot
.68752 .47615 Mdot
.53692 .52505 Mdot
.57192 .6269 Mdot
.76742 .99266 Mdot
.23773 .1548 Mdot
.39756 .31013 Mdot
.05214 .2924 Mdot
.70756 .89493 Mdot
.38582 .2468 Mdot
.20498 .58352 Mdot
.72126 .73278 Mdot
.45046 .86435 Mdot
.40649 .74582 Mdot
.02115 .48296 Mdot
.80108 .70641 Mdot
.15253 .56815 Mdot
.2045 .03945 Mdot
.64853 .50508 Mdot
.10467 .40874 Mdot
.94484 .54298 Mdot
.39968 .19164 Mdot
.06953 .81113 Mdot
.10694 .23606 Mdot
.72753 .009 Mdot
.07219 .3185 Mdot
.67955 .50389 Mdot
.64614 .1673 Mdot
.16872 .21356 Mdot
.35231 .58293 Mdot
.74789 .66584 Mdot
.14807 .88215 Mdot
.6252 .66846 Mdot
.35607 .22131 Mdot
.24411 .61064 Mdot
.39887 .68481 Mdot
.85586 .44401 Mdot
.17693 .29877 Mdot
.11134 .79891 Mdot
.57101 .17831 Mdot
.91395 .14617 Mdot
.51819 .727 Mdot
.1473 .01125 Mdot
.07498 .45715 Mdot
.74247 .80552 Mdot
.18384 .28187 Mdot
.33962 .16406 Mdot
.60928 .30056 Mdot
.3025 .38655 Mdot
.48 .05919 Mdot
.38884 .50545 Mdot
.85117 .9801 Mdot
.29943 .49888 Mdot
.24628 .1815 Mdot
.02938 .12463 Mdot
.30814 .52924 Mdot
.28996 .15344 Mdot
.74895 .57455 Mdot
.33153 .19231 Mdot
.02533 .90238 Mdot
.60338 .79541 Mdot
.16497 .65886 Mdot
.65083 .16406 Mdot
.11955 .13644 Mdot
.37583 .79504 Mdot
.78306 .86983 Mdot
.42042 .45896 Mdot
.70494 .33084 Mdot
.37523 .22875 Mdot
.18959 .29221 Mdot
.44709 .32484 Mdot
.38182 .4063 Mdot
.23634 .7388 Mdot
.92353 .30894 Mdot
.82899 .56193 Mdot
.58437 .46831 Mdot
.89488 .80318 Mdot
.73507 .42979 Mdot
.12504 .10366 Mdot
.98076 .87119 Mdot
.3271 .85207 Mdot
.82056 .79487 Mdot
.22423 .61163 Mdot
.88189 .56971 Mdot
.14341 .81644 Mdot
.90054 .33803 Mdot
.40654 .30941 Mdot
.17 .58277 Mdot
.71402 .5616 Mdot
.74704 .84228 Mdot
.94863 .20278 Mdot
.43087 .93651 Mdot
.95123 .57248 Mdot
.61137 .25116 Mdot
.73244 .36792 Mdot
.38175 .83835 Mdot
.98969 .43595 Mdot
.47977 .50549 Mdot
.19407 .2931 Mdot
.59111 .68573 Mdot
.95429 .72486 Mdot
.76763 .19247 Mdot
.88707 .33727 Mdot
.51515 .97278 Mdot
.15788 .45556 Mdot
.0565 .20884 Mdot
.44776 .21084 Mdot
.23715 .30072 Mdot
.56812 .98421 Mdot
.77657 .05789 Mdot
.52728 .69832 Mdot
.27473 .13448 Mdot
.81517 .73571 Mdot
.61036 .46002 Mdot
.71451 .55496 Mdot
.13149 .07746 Mdot
.89823 .30198 Mdot
.06611 .70577 Mdot
.18078 .97609 Mdot
.48093 .13833 Mdot
.47552 .18206 Mdot
.99899 .575 Mdot
.18844 .69209 Mdot
.7656 .19939 Mdot
.49231 .0278 Mdot
.22593 .93693 Mdot
.31733 .53378 Mdot
.17494 .98293 Mdot
.48906 .01976 Mdot
.0366 .03154 Mdot
.68996 .15132 Mdot
.54053 .84117 Mdot
.73438 .87254 Mdot
.84363 .17004 Mdot
.93895 .96145 Mdot
.28954 .24795 Mdot
.60948 .20859 Mdot
.16901 .33267 Mdot
.5351 .48457 Mdot
.22129 .22086 Mdot
.0259 .2278 Mdot
.89373 .03765 Mdot
.54258 .1493 Mdot
.00669 .64315 Mdot
.3289 .43702 Mdot
.98219 .56665 Mdot
.55786 .40712 Mdot
.02781 .25519 Mdot
.42284 .00149 Mdot
.78525 .95742 Mdot
.42565 .86713 Mdot
.74846 .06509 Mdot
.18948 .42682 Mdot
.00537 .50501 Mdot
.9585 .26761 Mdot
.76681 .46223 Mdot
.29153 .67853 Mdot
.30158 .93827 Mdot
.8586 .13346 Mdot
.5714 .49539 Mdot
.58576 .67299 Mdot
.86514 .29954 Mdot
.34441 .16737 Mdot
.23475 .58371 Mdot
.31084 .79724 Mdot
.44445 .92905 Mdot
.67815 .72587 Mdot
.58091 .61622 Mdot
.03419 .06543 Mdot
.86763 .64097 Mdot
.12582 .89832 Mdot
.94172 .93079 Mdot
.72085 .52354 Mdot
.4009 .96482 Mdot
.35165 .85427 Mdot
.15275 .31809 Mdot
.72071 .15075 Mdot
.38453 .51592 Mdot
.95763 .68175 Mdot
.72088 .52323 Mdot
.02085 .61982 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00Co0000oooooooooooooooo0_l0000:ooooo`03o`000?oooooooooo00[ooooo0_l000000ooo
oooo0000ooooo`0>ooooo`03o`000?oooooooooo00;ooooo0_l0000:ooooo`03o`000?oooooooooo
00?ooooo0_l00008ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`02ooooo`007_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool02_ooool2o`000003ooooool0003ooooo00kooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`03ooooo`;o00002?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00Sooooo0_l00003ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo000Nooooo`03o`00
0?oooooooooo0:Oooooo0_l000000ooooooo0000o`00000>ooooo`;o0000;?ooool2o`00013ooooo
0_l00005ooooo`;o0000A?ooool001kooooo00?o0000ooooooooool0;?ooool2o`0007?ooooo0_l0
0004ooooo`;o00004Oooool2o`0002cooooo0_l0000@ooooo`;o00001Oooool2o`0002kooooo0_l0
000Dooooo`007_ooool00ol0003oooooooooo`0/ooooo`;o000000?oooooo`000?l00000:_ooool2
o`0004Cooooo0_l0002>ooooo`;o00002?ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo
02oooooo0_l0000Zooooo`;o0000?_ooool2o`0002;ooooo0_l0001jooooo`;o00000oooool2o`00
00Gooooo000Nooooo`03o`000?oooooooooo02oooooo0_l0000Iooooo`;o0000:?ooool2o`0002Go
oooo0_l0000Rooooo`;o00005_ooool2o`0006Oooooo0_l00005ooooo`007_ooool00ol0003ooooo
ooooo`0^ooooo`;o00006_ooool2o`0002Sooooo0_l0000Eooooo`;o0000B_ooool2o`0006kooooo
000Nooooo`03o`000?oooooooooo02kooooo0_l0001Kooooo`;o00001?ooool3o`0000Sooooo0_l0
002Yooooo`007_ooool00ol0003oooooooooo`08ooooo`;o0000I?ooool2o`00027ooooo0ol00008
ooooo`;o0000ZOooool001kooooo00?o0000ooooooooool02?ooool2o`0006Cooooo0_l000000ooo
oooo0000o`00001Jooooo`;o0000:Oooool2o`0001_ooooo0_l0000`ooooo`007_ooool00ol0003o
ooooooooo`1aooooo`;o0000F_ooool2o`0002Wooooo0_l0000Kooooo`;o00001oooool2o`0002Oo
oooo000Nooooo`03o`000?oooooooooo03kooooo0_l0003Nooooo`;o00009oooool001kooooo00?o
0000ooooooooool0?_ooool2o`0002cooooo0_l0000looooo`;o00001Oooool2o`0009Cooooo000N
ooooo`03o`000?oooooooooo06cooooo0_l0000looooo`;o00001Oooool2o`0000Cooooo0_l00000
0ooooooo0000o`00000Iooooo`;o00004Oooool2o`0005gooooo000Nooooo`03o`000?oooooooooo
00Wooooo0_l0001Nooooo`;o00002oooool2o`00017ooooo0_l0000/ooooo`;o000000?oooooo`00
0?l000006Oooool2o`00017ooooo0_l0000Kooooo`;o0000@?ooool001kooooo0_l0000:ooooo`;o
0000<Oooool2o`0000_ooooo0_l00009ooooo`;o00000oooool2o`0000kooooo0_l0000;ooooo`;o
00004Oooool2o`0001Kooooo0_l0000?ooooo`;o00007?ooool4o`00037ooooo0_l0000hooooo`;o
00001_ooool001kooooo00?o0000ooooooooool0??ooool2o`0000_ooooo0_l00009ooooo`;o0000
0oooool2o`0004Kooooo0_l0000?ooooo`;o00005?ooool2o`0000Kooooo1?l0000booooo`;o0000
=oooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo04kooooo0_l00018ooooo`;o0000;_oo
ool2o`0002kooooo0_l0000<ooooo`;o0000?oooool001kooooo00?o0000ooooooooool0C_ooool2
o`0004Sooooo0_l0000Fooooo`;o000000?oooooo`000?l00000@oooool2o`0000Gooooo0_l0000M
ooooo`;o00009oooool001kooooo00?o0000ooooooooool01oooool2o`000:Cooooo0_l000001?oo
oooo0000o`000?ooool2o`0003[ooooo0_l0000>ooooo`;o00007Oooool2o`0002Oooooo000Noooo
o`03o`000?oooooooooo00Oooooo0_l0002Tooooo`;o0000:_ooool2o`0001Cooooo0_l0001Foooo
o`007_ooool00ol0003oooooooooo`0gooooo`;o00007_ooool2o`0001Gooooo0_l0001Yooooo`;o
0000K?ooool001kooooo00?o0000ooooooooool0=oooool2o`0001kooooo0_l0000Eooooo`;o0000
BOooool2o`0008cooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l00019ooooo`;o0000AOoo
ool2o`0001cooooo1?l0001Cooooo`;o00005oooool001kooooo00?o0000ooooooooool09oooool2
o`0004Wooooo0_l0001Sooooo`Co0000Doooool2o`0001Oooooo000Nooooo`03o`000?oooooooooo
0;_ooooo0_l0001Wooooo`;o00008Oooool001kooooo00?o0000ooooooooool01_ooool2o`0003Oo
oooo0_l0001Eooooo`;o00002_ooool2o`000003ooooool0003o000001Cooooo0_l0001Wooooo`;o
00008Oooool001kooooo00?o0000ooooooooool01_ooool2o`00017ooooo0_l0000;ooooo`;o0000
2_ooool2o`0000_ooooo0_l0001Eooooo`;o00002_ooool2o`000003ooooool0003o000000Cooooo
0_l0000>ooooo`;o0000R_ooool001kooooo00?o0000ooooooooool06Oooool2o`0000_ooooo0_l0
000:ooooo`;o0000D?ooool2o`0002Gooooo0_l0000>ooooo`;o00005Oooool2o`0001Sooooo0_l0
001Iooooo`007_ooool00ol0003oooooooooo`24ooooo`;o0000C?ooool2o`0001Sooooo0_l0000e
ooooo`;o00008_ooool001kooooo0ol0003oooooobCooooo0_l0000@ooooo`;o00004?ooool001ko
oooo0ol00006ooooo`;o00006?ooool2o`0007?ooooo0_l0000Gooooo`;o00002?ooool2o`00057o
oooo0_l0000Wooooo`?o00004?ooool001kooooo00?o0000ooooooooool01_ooool2o`0001Sooooo
0_l00003ooooo`;o00005?ooool2o`0005Sooooo0_l0000Gooooo`;o00002?ooool2o`00057ooooo
0_l0000Wooooo`;o00004Oooool001kooooo00?o0000ooooooooool09?ooool3o`0000_ooooo0_l0
0007ooooo`;o0000=oooool2o`000=7ooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l0000<
ooooo`;o0000<?ooool2o`0000kooooo0_l00029ooooo`;o0000;?ooool2o`0001Sooooo000Noooo
o`03o`000?oooooooooo06Cooooo0_l0002Hooooo`?o00007_ooool2o`0000cooooo0_l0000Hoooo
o`007_ooool00ol0003oooooooooo`3nooooo`;o00007oooool2o`0002Kooooo000Nooooo`03o`00
0?oooooooooo027ooooo0_l00002ooooo`;o0000M?ooool2o`000:[ooooo000Nooooo`03o`000?oo
oooooooo027ooooo0_l00002ooooo`;o0000M?ooool2o`000:[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo0_l0003<ooooo`;o0000G?ooool2o`0001Cooooo000Nooooo`03o`000?oooooooooo
00Gooooo0_l0000?ooooo`;o0000/?ooool2o`0000Wooooo0_l0001Iooooo`;o000000?oooooo`00
0?l000005?ooool001kooooo00?o0000ooooooooool05_ooool2o`0009_ooooo0_l0000Cooooo`;o
0000BOooool2o`0001Wooooo0_l0000Gooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o0000
5oooool2o`00033ooooo0_l0001Looooo`;o0000G_ooool2o`0000_ooooo0_l0000Uooooo`007_oo
ool00ol0003oooooooooo`0:ooooo`;o00005?ooool2o`000003ooooool0003o0000033ooooo0_l0
0011ooooo`;o0000O_ooool2o`0000Kooooo0_l000000ooooooo0000o`00000Rooooo`007_ooool0
0ol0003oooooooooo`0Pooooo`;o0000M_ooool2o`0002_ooooo0_l0000Looooo`;o0000<oooool2
o`0000Wooooo0_l0000Rooooo`007_ooool00ol0003oooooooooo`35ooooo`;o00007?ooool2o`00
06;ooooo000Nooooo`03o`000?oooooooooo05?ooooo0_l0003@ooooo`;o00006Oooool2o`0000Go
oooo000Nooooo`;o0000E?ooool2o`0005Oooooo0_l0000^ooooo`;o00002?ooool4o`0003_ooooo
0_l0000Iooooo`;o00001Oooool001kooooo00?o0000ooooooooool0BOooool2o`0000oooooo0_l0
001@ooooo`;o0000;_ooool2o`0000Sooooo1?l0000Fooooo`;o0000AOooool001kooooo00?o0000
ooooooooool05Oooool2o`000003ooooool0003o000002oooooo0_l0000?ooooo`;o0000Y?ooool2
o`0001cooooo0_l0000Wooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o000000?oooooo`00
0?l00000GOooool2o`000:Gooooo0_l0000Wooooo`007_ooool00ol0003oooooooooo`0Zooooo`;o
0000?_ooool2o`0000_ooooo0_l0001Aooooo`;o00000oooool3o`00027ooooo0_l0001Booooo`00
7_ooool00ol0003oooooooooo`0Zooooo`;o0000?_ooool4o`0005cooooo0_l00002ooooo`Co0000
8Oooool2o`0005;ooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l0000jooooo`;o00005Ooo
ool2o`0001kooooo0_l00005ooooo`;o0000>Oooool2o`0002Gooooo0_l0000Gooooo`;o0000=ooo
ool001kooooo00?o0000ooooooooool04_ooool2o`0000Gooooo0_l0000jooooo`;o00008?ooool2
o`0001?ooooo0_l00005ooooo`;o0000H?ooool2o`0000Oooooo0_l0000>ooooo`;o00005_ooool2
o`0001Cooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`0Booooo`;o0000:_ooool2o`00
03Oooooo0_l0000:ooooo`;o0000>?ooool2o`0003oooooo0_l0000Vooooo`;o00005?ooool2o`00
00Wooooo000Nooooo`03o`000?oooooooooo03kooooo0_l00013ooooo`;o00006_ooool2o`0001Go
oooo0_l00005ooooo`;o00001Oooool2o`0003Gooooo0_l0001:ooooo`007_ooool00ol0003ooooo
ooooo`1<ooooo`;o0000B?ooool2o`0000Oooooo0_l0000Eooooo`;o00003?ooool2o`0003Gooooo
0_l0001:ooooo`007_ooool00ol0003oooooooooo`1:ooooo`Co00002?ooool2o`0003kooooo0_l0
0005ooooo`;o0000Z?ooool001kooooo00?o0000ooooooooool0>oooool2o`0000gooooo0_l0000:
ooooo`;o0000AOooool2o`000:Sooooo000Nooooo`03o`000?oooooooooo01Sooooo0_l0000Doooo
o`;o00002oooool2o`00033ooooo0_l0000?ooooo`;o0000Hoooool2o`0006;ooooo0003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo
01Sooooo0_l00003ooooo`;o00003oooool2o`0003Sooooo0_l00003ooooo`?o00003_ooool2o`00
06?ooooo0_l0000@ooooo`;o00000oooool2o`0001oooooo0_l0000Zooooo`000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool0
0ol0003oooooooooo`0Mooooo`;o0000BOooool2o`0000Cooooo0_l00025ooooo`;o00000oooool2
o`0001oooooo0_l0000;ooooo`;o00002Oooool2o`0001;ooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`?o0000mOooool2o`0001cooooo0_l0000C
ooooo`;o00002Oooool2o`0001;ooooo0003ooooo`05o`000?ooooooooooooooool000003Oooool0
0onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo0=Gooooo0_l00003ooooo`;o000000?ooooo
o`000?l000005_ooool2o`0001cooooo0_l0000Kooooo`;o00005Oooool000?ooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0eOooool2
o`0000?ooooo0_l000000ooooooo0000o`00000<ooooo`;o0000@oooool2o`0001Gooooo0003oooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00kooooo0_l0000hooooo`;o0000=Oooool2o`0002Gooooo0_l000000ooooooo0000o`00000G
ooooo`;o00009oooool2o`0002Kooooo0_l0000Mooooo`;o00004oooool000?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003ooooooooo
o`0>ooooo`;o00008oooool2o`0001?ooooo0_l0000eooooo`;o00003?ooool2o`0001Oooooo0_l0
00000ooooooo0000o`00000Gooooo`;o00006_ooool2o`0003?ooooo0_l0000Mooooo`;o00004ooo
ool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
1_ooool00ol0003oooooooooo`0Booooo`;o00007oooool2o`0005Sooooo0_l0001?ooooo`;o0000
1_ooool2o`0005Wooooo0_l00004ooooo`007_ooool00ol0003oooooooooo`0Booooo`;o0000WOoo
ool2o`0003?ooooo0_l0000Zooooo`;o0000;Oooool2o`0000Cooooo000Nooooo`03o`000?oooooo
oooo00kooooo0_l0000dooooo`;o00008Oooool2o`0000Oooooo0_l0000oooooo`;o000000?ooooo
o`000?l00000G?ooool2o`0003?ooooo000Nooooo`03o`000?oooooooooo00kooooo0_l0000doooo
o`;o00008Oooool2o`0000Oooooo0_l0000Kooooo`;o00009Oooool2o`0000_ooooo0_l00024oooo
o`007_ooool00ol0003oooooooooo`04ooooo`;o00008_ooool2o`0004cooooo0_l0000Eooooo`;o
0000<_ooool2o`0002Sooooo0_l000000ooooooo0000o`00000_ooooo`?o00006?ooool2o`0000_o
oooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0000Rooooo`;o00001?ooool2o`0004Kooooo
0_l00014ooooo`;o00000_ooool2o`0002Wooooo0_l000000ooooooo0000o`00000_ooooo`?o0000
6?ooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo02kooooo0_l0000Looooo`;o0000>ooo
ool2o`0002kooooo0_l000000ooooooo0000o`000002ooooo`;o0000;Oooool2o`0005Kooooo000N
ooooo`03o`000?oooooooooo00Gooooo0_l00002ooooo`;o00005?ooool2o`0001;ooooo0_l0000G
ooooo`;o0000>oooool2o`0002kooooo0_l00002ooooo`;o00009oooool2o`0000Oooooo0_l0001F
ooooo`007_ooool00ol0003oooooooooo`05ooooo`;o00000_ooool2o`0001Cooooo0_l0000Boooo
o`;o0000R?ooool2o`0002Oooooo0_l0001Oooooo`007_ooool00ol0003oooooooooo`3aooooo`;o
0000<Oooool2o`00027ooooo000Nooooo`03o`000?oooooooooo04Cooooo0_l0000cooooo`;o0000
M_ooool2o`00013ooooo0_l0000Oooooo`;o00008Oooool001kooooo00?o0000ooooooooool0<Ooo
ool2o`00017ooooo0_l0000Dooooo`;o00007Oooool2o`0005oooooo0_l0000Vooooo`?o000000?o
ooooo`000?l00000?oooool001kooooo0_l0000Pooooo`;o00004?ooool2o`0002Oooooo0_l0000`
ooooo`;o00001Oooool2o`0002Kooooo0_l00006ooooo`;o00005Oooool2o`0002Kooooo0_l00002
ooooo`;o0000?oooool001kooooo00?o0000ooooooooool01Oooool2o`0001Sooooo0_l0001[oooo
o`;o00001Oooool2o`0002Kooooo0_l00006ooooo`;o0000P_ooool001kooooo00?o0000oooooooo
ool01Oooool2o`000=_ooooo0_l0000[ooooo`;o0000=_ooool001kooooo00?o0000ooooooooool0
L?ooool2o`0001Wooooo0_l0001Eooooo`;o0000:oooool2o`0001Wooooo0_l0000Kooooo`007_oo
ool00ol0003oooooooooo`1Dooooo`;o00006_ooool2o`0001Wooooo0_l0002Mooooo`;o00006ooo
ool001kooooo00?o0000ooooooooool09Oooool2o`0002gooooo0_l0000Vooooo`;o0000]_ooool2
o`00017ooooo000Nooooo`03o`000?oooooooooo02Gooooo0_l00013ooooo`;o00004?ooool2o`00
00Kooooo0_l0000Jooooo`;o0000T_ooool2o`00017ooooo000Nooooo`03o`000?oooooooooo01ko
oooo0_l0000;ooooo`;o0000?Oooool2o`0001Sooooo0_l0000Jooooo`;o0000BOooool2o`0005[o
oooo000Nooooo`03o`000?oooooooooo01kooooo0_l0000;ooooo`;o0000__ooool3o`0001Sooooo
0_l0000oooooo`007_ooool00ol0003oooooooooo`1:ooooo`;o00009?ooool2o`0004[ooooo0_l0
000^ooooo`;o00006?ooool2o`0003oooooo000Nooooo`03o`000?oooooooooo02?ooooo0_l00005
ooooo`;o00003?ooool2o`0000cooooo0_l00002ooooo`;o00007?ooool2o`0000Kooooo0_l00019
ooooo`?o00002oooool2o`0007cooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l0000Koooo
o`;o00001Oooool2o`0000cooooo0_l0000<ooooo`;o00008?ooool2o`00057ooooo0_l0000<oooo
o`;o0000O?ooool001kooooo00?o0000ooooooooool01_ooool2o`000?oooooo@?ooool001kooooo
00?o0000ooooooooool03Oooool2o`0002_ooooo0ol0000Qooooo`;o0000ioooool001kooooo00?o
0000ooooooooool03Oooool2o`0000Oooooo0_l0000Rooooo`?o00008Oooool2o`0003;ooooo0_l0
002:ooooo`;o00009oooool001kooooo00?o0000ooooooooool05_ooool2o`0001gooooo0_l0001K
ooooo`;o00003oooool2o`00073ooooo0_l00007ooooo`;o00009oooool001kooooo0_l0000foooo
o`;o00004_ooool2o`0005Gooooo0_l000000ooooooo0000o`00000Mooooo`;o0000DOooool2o`00
00Wooooo0_l0000Uooooo`007_ooool00ol0003oooooooooo`19ooooo`;o0000EOooool2o`00023o
oooo0_l00015ooooo`;o00005Oooool3o`0002Cooooo000Nooooo`03o`000?oooooooooo027ooooo
0_l00029ooooo`;o0000Foooool2o`0001Kooooo0_l00005ooooo`;o00007Oooool001kooooo00?o
0000ooooooooool00_ooool2o`0001gooooo0_l0001Jooooo`;o000000?oooooo`000?l000001Ooo
ool2o`0002?ooooo0_l0000Booooo`;o0000Doooool2o`00017ooooo0_l0000Mooooo`007_ooool0
0ol0003oooooooooo`02ooooo`;o0000NOooool2o`000003ooooool0003o000000Gooooo0_l0000g
ooooo`;o0000>Oooool2o`0000Kooooo0_l0000@ooooo`;o0000<?ooool001kooooo00?o0000oooo
ooooool08_ooool2o`0000Oooooo0_l000000ooooooo0000o`00000Uooooo`;o0000Y?ooool2o`00
00Kooooo0_l00012ooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o00003Oooool2o`0000Go
oooo1?l000000ooooooo0000o`00000Uooooo`;o0000;oooool2o`0008?ooooo0_l0000jooooo`00
7_ooool00ol0003oooooooooo`0:ooooo`;o00001oooool2o`000003ooooool0003o0000017ooooo
1?l00010ooooo`;o00005oooool2o`0001;ooooo0_l0001_ooooo`;o00000oooool2o`0000;ooooo
0_l0000aooooo`007_ooool01?l0003oooooooooooooool2o`0000Oooooo0_l0000:ooooo`;o0000
8oooool2o`00033ooooo0_l0000Nooooo`;o00002oooool2o`0003oooooo0_l0000cooooo`;o0000
0_ooool2o`00037ooooo000Nooooo`04o`000?ooooooooooooooo`;o0000>?ooool2o`0004;ooooo
0_l0000<ooooo`;o0000C?ooool2o`0000Sooooo0_l0001Pooooo`007_ooool00ol0003ooooooooo
o`0cooooo`;o0000B_ooool2o`00063ooooo0_l00002ooooo`;o0000H?ooool001kooooo00?o0000
ooooooooool03_ooool2o`0001oooooo0_l00002ooooo`;o00006?ooool2o`0007Oooooo0_l0000C
ooooo`;o00001?ooool2o`0006Cooooo000Nooooo`03o`000?oooooooooo00kooooo0_l0000Ooooo
o`;o00007?ooool2o`0004Cooooo0_l0000Pooooo`;o00003oooool2o`0001?ooooo0_l0000ooooo
o`;o00000oooool2o`0002Cooooo000Nooooo`03o`000?oooooooooo013ooooo0_l00021ooooo`;o
00001?ooool2o`0001[ooooo0_l00004ooooo`;o0000<?ooool2o`0002gooooo0_l00003ooooo`;o
00009?ooool001kooooo00?o0000ooooooooool04?ooool2o`0006kooooo0_l00004ooooo`;o0000
4Oooool2o`00023ooooo0_l0000`ooooo`;o0000F?ooool001kooooo00?o0000ooooooooool0Booo
ool2o`0003?ooooo0_l00004ooooo`;o0000_oooool001kooooo0_l00003ooooo`;o0000;oooool2
o`0001Kooooo0_l0000Nooooo`;o0000Aoooool2o`0000oooooo0_l0000;ooooo`;o0000A?ooool2
o`0002gooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0000_ooooo`;o0000=_ooool2o`00
01Oooooo0_l0000Cooooo`;o00006Oooool2o`0000_ooooo0_l00002ooooo`;o00001Oooool2o`00
00Cooooo0_l00014ooooo`;o0000;Oooool001kooooo00?o0000ooooooooool00oooool2o`0000So
oooo0_l0001eooooo`;o00000_ooool2o`0000oooooo0_l0000Vooooo`;o00002Oooool2o`0007Wo
oooo000Nooooo`03o`000?oooooooooo00?ooooo0_l00008ooooo`;o000000?oooooo`000?l00000
EOooool2o`0001oooooo0_l00007ooooo`;o0000BOooool2o`0006Wooooo000Nooooo`03o`000?oo
oooooooo013ooooo0_l0001Eooooo`;o00007?ooool2o`0000[ooooo0_l0000/ooooo`?o00006_oo
ool2o`0006Wooooo000Nooooo`03o`000?oooooooooo05Cooooo0_l0000_ooooo`;o0000>?ooool3
o`0002Wooooo0_l0000Tooooo`;o0000=?ooool001kooooo00?o0000ooooooooool0E?ooool2o`00
09Cooooo0ol0000Tooooo`;o0000=?ooool001kooooo00?o0000ooooooooool0=Oooool2o`0006oo
oooo0_l00012ooooo`;o0000Foooool001kooooo00?o0000ooooooooool05_ooool2o`0001gooooo
0_l0001:ooooo`;o00008oooool2o`0004Oooooo0_l0000jooooo`;o00006_ooool001kooooo0ol0
000Fooooo`;o00001_ooool2o`0004?ooooo0_l0000Hooooo`;o00000_ooool2o`0002Kooooo0_l0
000[ooooo`;o00005oooool2o`0000cooooo0_l0000/ooooo`;o00004oooool2o`0000Gooooo000N
ooooo`?o00007_ooool2o`0001Cooooo0_l00008ooooo`;o00002_ooool2o`0001Oooooo0_l0000H
ooooo`;o0000:_ooool2o`0000?ooooo0_l0000Vooooo`;o00009Oooool2o`00047ooooo0_l00005
ooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o00006?ooool2o`0000Sooooo0_l0000:oooo
o`;o0000H_ooool2o`0003_ooooo0_l00005ooooo`;o0000Doooool001kooooo00?o0000oooooooo
ool06_ooool2o`0003?ooooo0_l0000=ooooo`;o0000@?ooool2o`0002_ooooo0_l00008ooooo`;o
00004_ooool2o`0000Gooooo0_l0001Cooooo`007_ooool00ol0003oooooooooo`0oooooo`;o0000
1Oooool2o`0000Oooooo0_l0000;ooooo`Co0000@?ooool2o`0000cooooo0_l0000Dooooo`;o0000
1oooool2o`0000Sooooo0_l0000Xooooo`;o0000<_ooool2o`00013ooooo0003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`00
0?oooooooooo03oooooo0_l00005ooooo`;o00005?ooool2o`00053ooooo0_l0000Dooooo`;o0000
>oooool2o`0002Gooooo0_l0000;ooooo`;o00004?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06cooooo
0_l0001^ooooo`;o00001oooool2o`0001gooooo0_l0000Mooooo`;o00000oooool2o`0001gooooo
0003ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol0001/ooooo`;o0000
K_ooool2o`0000?ooooo0_l00002ooooo`;o00006oooool4o`0001gooooo0_l0000Rooooo`000ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool00ol0003o
ooooooooo`3Qooooo`;o00007oooool2o`0004?ooooo0003ooooo`05o`000?ooooooooooooooool0
00002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo07Sooooo0_l0000^oooo
o`;o00001Oooool4o`0004Sooooo0_l0001:ooooo`000oooool01Ol@413ooooooooooooooooo410@
00cooooo00?oMgMgolc<c?l000001oooool01?l0003oooooo`000?l00004ooooo`;o00005oooool2
o`0005Sooooo0_l0000Aooooo`;o00006oooool2o`0000Gooooo1?l00007ooooo`;o0000?oooool2
o`0004[ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007
ooooo`04o`000?oooooo0000o`0000Cooooo0_l0000Gooooo`;o0000>_ooool2o`0000cooooo0_l0
000Qooooo`;o00008oooool2o`0000Sooooo0_l0002;ooooo`000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`0]ooooo`;o00002_oo
ool2o`0001oooooo0_l0000<ooooo`;o0000A_ooool2o`0009Gooooo000Nooooo`03o`000?oooooo
oooo02gooooo0_l0000:ooooo`;o0000`?ooool2o`0001gooooo0_l0000[ooooo`007_ooool00ol0
003oooooooooo`3kooooo`;o00002_ooool2o`00017ooooo0_l0000Hooooo`;o00004Oooool001ko
oooo00?o0000ooooooooool0BOooool2o`0000Oooooo0_l0000Tooooo`;o00005_ooool2o`0007Go
oooo0_l0000[ooooo`;o00004Oooool001kooooo00?o0000ooooooooool00oooool2o`0002Cooooo
0_l0000>ooooo`;o00002Oooool2o`0000?ooooo0_l00007ooooo`;o00009?ooool2o`0001;ooooo
0_l00002ooooo`;o0000M?ooool2o`0003oooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0
000Tooooo`;o00003_ooool2o`0000Wooooo0_l0000Dooooo`;o0000<?ooool2o`0000;ooooo0_l0
001Iooooo`;o00006Oooool2o`0003oooooo000Nooooo`03o`000?oooooooooo04;ooooo0_l0000?
ooooo`;o00001Oooool2o`0003Cooooo0_l0001Iooooo`;o00001oooool2o`00057ooooo000Noooo
o`04o`000?ooooooooooooooo`;o0000?oooool2o`0000oooooo0_l0000<ooooo`;o00001?ooool2
o`000003ooooool0003o000000Kooooo0_l0000booooo`;o0000C?ooool2o`0004Sooooo0_l00007
ooooo`007_ooool01?l0003oooooooooooooool2o`0002Kooooo0_l0000fooooo`;o00001?ooool2
o`000003ooooool0003o000000Kooooo0_l0000booooo`;o00008oooool2o`00077ooooo0_l00007
ooooo`007_ooool00ol0003oooooooooo`0Yooooo`;o0000O?ooool2o`0002;ooooo0_l0000loooo
o`;o00001oooool2o`0001[ooooo0_l0000Gooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o
0000P_ooool2o`0000Oooooo0_l0001Gooooo`;o00001oooool2o`0001[ooooo0_l0000Gooooo`00
7_ooool00ol0003oooooooooo`0Sooooo`;o00001_ooool2o`0002[ooooo0_l0001Gooooo`;o0000
LOooool2o`0002;ooooo000Nooooo`;o0000;?ooool2o`0002[ooooo0_l0003:ooooo`;o00000ooo
ool2o`0001gooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0000Fooooo`;o00004_ooool2
o`00043ooooo0_l0002eooooo`;o00007Oooool001kooooo00?o0000ooooooooool00oooool2o`00
00oooooo0_l00005ooooo`;o00004_ooool2o`00043ooooo0_l0000Booooo`;o0000??ooool2o`00
01gooooo0_l0000?ooooo`;o00009_ooool2o`0002[ooooo000Nooooo`03o`000?oooooooooo01Co
oooo0_l0000Yooooo`;o0000A?ooool2o`0002Oooooo0_l0000Booooo`?o00007Oooool2o`0000oo
oooo1?l0000Tooooo`;o0000:_ooool001kooooo00?o0000ooooooooool09_ooool2o`0001;ooooo
0_l00003ooooo`;o00006?ooool2o`0003;ooooo0ol0000Nooooo`;o00004_ooool2o`00037ooooo
1?l0001>ooooo`007_ooool00ol0003oooooooooo`0Vooooo`;o00004_ooool2o`0001gooooo0_l0
000booooo`?o00007_ooool2o`0000[ooooo0_l0000Qooooo`;o00002oooool2o`0000_ooooo0_l0
001>ooooo`007_ooool00ol0003oooooooooo`2^ooooo`;o00002_ooool2o`00027ooooo0_l0000;
ooooo`;o00000_ooool2o`0005Oooooo000Nooooo`03o`000?oooooooooo09Kooooo0_l0001Foooo
o`;o0000Eoooool001kooooo00?o0000ooooooooool0K?ooool2o`0002Sooooo0_l0000hooooo`;o
00001oooool4o`0006[ooooo000Nooooo`03o`000?oooooooooo02Kooooo0_l00014ooooo`;o0000
H_ooool2o`0000Oooooo1?l0000Mooooo`;o0000Boooool001kooooo00?o0000ooooooooool00ooo
ool2o`00027ooooo0_l00003ooooo`;o0000cOooool2o`0001?ooooo0_l0000fooooo`007_ooool0
0ol0003oooooooooo`03ooooo`;o00009_ooool2o`0000Cooooo0_l0000`ooooo`;o00005oooool2
o`0002Wooooo0_l000000ooooooo0000o`00001Sooooo`;o0000=_ooool001kooooo00?o0000oooo
ooooool0<Oooool2o`00033ooooo0_l00003ooooo`;o00004_ooool2o`0002Wooooo0_l000000ooo
oooo0000o`000018ooooo`;o0000<Oooool2o`0001kooooo000Nooooo`03o`000?oooooooooo06So
oooo0_l0001gooooo`;o00004Oooool2o`00037ooooo0_l0000Nooooo`007_ooool00ol0003ooooo
ooooo`1Cooooo`;o00003Oooool2o`0005;ooooo0_l00007ooooo`;o00003_ooool2o`0000Wooooo
0_l00005ooooo`Co00005Oooool2o`0001Sooooo0_l0000Hooooo`;o00005oooool001kooooo00?o
0000ooooooooool08oooool2o`0001_ooooo0_l0000Aooooo`;o00002?ooool2o`0000?ooooo0_l0
000nooooo`;o00004_ooool2o`0000Oooooo0_l0000>ooooo`;o00002Oooool2o`0000Oooooo0_l0
000Cooooo`Co00006?ooool2o`0001Sooooo0_l0000Gooooo`007_ooool2o`0002Cooooo0_l0000I
ooooo`Co00006oooool2o`0004?ooooo0_l00016ooooo`;o00003?ooool2o`0004gooooo000Noooo
o`?o000000?oooooo`000?l00000>?ooool2o`000003ooooool0003o000003Gooooo0_l00003oooo
o`;o00007?ooool2o`0003Gooooo0_l00008ooooo`;o00003oooool2o`0005_ooooo000Nooooo`?o
000000?oooooo`000?l000008Oooool2o`0001Gooooo0_l0000hooooo`;o00000oooool2o`0001co
oooo0_l0000eooooo`;o00002?ooool2o`0006cooooo000Nooooo`03o`000?oooooooooo00Kooooo
0_l0000Looooo`;o00005oooool2o`0007Oooooo0_l0002?ooooo`007_ooool00ol0003ooooooooo
o`06ooooo`;o0000=Oooool2o`0007Oooooo0_l0000Sooooo`;o00005Oooool2o`0005?ooooo000N
ooooo`03o`000?oooooooooo04Wooooo0_l0000^ooooo`;o00002oooool2o`0005?ooooo0_l0000E
ooooo`;o00008oooool2o`0002kooooo000Nooooo`03o`000?oooooooooo04Wooooo0_l0000^oooo
o`;o00002oooool2o`0008cooooo0_l000000ooooooo0000o`00000^ooooo`007_ooool00ol0003o
ooooooooo`1Sooooo`;o00000_ooool2o`00047ooooo0_l0000Aooooo`;o00009oooool2o`0002co
oooo0_l0000aooooo`007_ooool00ol0003oooooooooo`0hooooo`;o0000:Oooool2o`0000;ooooo
0_l00006ooooo`;o0000>Oooool2o`00017ooooo0_l0000Booooo`;o00004oooool3o`0005kooooo
000Nooooo`03o`000?oooooooooo03Sooooo0_l00002ooooo`;o00008_ooool2o`0000gooooo0_l0
000iooooo`;o00009Oooool2o`0001Cooooo0_l0001Nooooo`007_ooool00ol0003oooooooooo`0^
ooooo`;o00003?ooool2o`0002;ooooo0_l0002booooo`;o0000<Oooool001kooooo00?o0000oooo
ooooool01oooool2o`0002Gooooo0_l0000cooooo`;o0000EOooool2o`0005Sooooo0_l0000aoooo
o`007_ooool00ol0003oooooooooo`07ooooo`;o0000E?ooool2o`0000Cooooo0_l0000Tooooo`;o
0000;oooool2o`0008_ooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0001Aooooo`;o0000
00?oooooo`000?l000007Oooool2o`0000Sooooo0_l00015ooooo`;o0000MOooool001kooooo00?o
0000ooooooooool02_ooool2o`0000Wooooo0_l0000Looooo`;o0000:oooool2o`0001gooooo0_l0
000Vooooo`;o00009oooool2o`0001_ooooo0_l00010ooooo`;o00005_ooool001kooooo00?o0000
ooooooooool05Oooool2o`0001cooooo0_l0000;ooooo`;o00002Oooool3o`0002;ooooo0_l0000e
ooooo`;o00003?ooool2o`0000Cooooo0_l0000`ooooo`;o000000?oooooo`000?l00000?Oooool2
o`0001Kooooo000Nooooo`;o0000@Oooool2o`0000Wooooo0ol0000Rooooo`;o00005?ooool2o`00
02gooooo0_l00004ooooo`;o0000<oooool2o`0005Gooooo000Nooooo`03o`000?oooooooooo07Co
oooo0_l0000@ooooo`;o0000G?ooool2o`00067ooooo000Nooooo`03o`000?oooooooooo033ooooo
0_l0000Xooooo`;o00006?ooool2o`0000gooooo0_l0000[ooooo`;o0000<_ooool2o`0001cooooo
0_l00013ooooo`007_ooool00ol0003oooooooooo`0`ooooo`;o0000:?ooool2o`0002Oooooo0_l0
000[ooooo`;o0000D?ooool2o`0004?ooooo000Nooooo`03o`000?oooooooooo08kooooo0_l0001D
ooooo`;o00008oooool2o`0003cooooo000Nooooo`;o0000Coooool2o`0003kooooo0_l00005oooo
o`;o0000COooool2o`0001kooooo0_l00003ooooo`;o0000<?ooool2o`0000[ooooo000Nooooo`?o
0000;Oooool2o`0001oooooo0_l0000=ooooo`;o0000=_ooool2o`0006gooooo0_l00007ooooo`;o
00003?ooool2o`0001kooooo0_l0000:ooooo`007_ooool3o`0002gooooo0_l0000Tooooo`;o0000
2?ooool2o`000:;ooooo0_l0000:ooooo`;o00003?ooool2o`0001Cooooo0_l0000Dooooo`007_oo
ool00ol0003oooooooooo`1Cooooo`;o00000_ooool2o`0009Kooooo0_l0000@ooooo`;o0000;?oo
ool4o`0000cooooo1?l00004ooooo`007_ooool00ol0003oooooooooo`1@ooooo`;o00001Oooool2
o`0001kooooo0_l0001fooooo`;o0000?_ooool2o`0000kooooo1?l00004ooooo`007_ooool00ol0
003oooooooooo`1@ooooo`;o00009Oooool2o`0003Oooooo0_l0000Zooooo`;o0000:?ooool2o`00
03oooooo000Nooooo`03o`000?oooooooooo03?ooooo0_l0000:ooooo`;o00001oooool2o`0002Co
oooo0_l0000Gooooo`;o00009oooool2o`0002[ooooo0_l0000Xooooo`;o0000:Oooool2o`0001Co
oooo000Nooooo`03o`000?oooooooooo03?ooooo0_l0000:ooooo`;o00001oooool2o`0002Cooooo
0_l0000Gooooo`;o0000:oooool2o`0001gooooo0_l0000Eooooo`;o0000AOooool2o`0001Cooooo
000Nooooo`03o`000?oooooooooo08oooooo0_l0000Sooooo`;o00007Oooool2o`0001Gooooo0_l0
001Kooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2?ooooo`;o0000B_ooool2o`0001cooooo
0_l0001<ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEE
EOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0Fooooo`;o0000D?ooool2o`0001oo
oooo0_l0001=ooooo`;o000000?oooooo`000?l000000_ooool2o`0001Sooooo0_l0001<ooooo`00
0oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006oooo
o`?o00005_ooool2o`0002Wooooo0_l0000Uooooo`;o00007oooool2o`0004gooooo0_l00005oooo
o`;o0000I_ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9Sooooo
oiRHV?lQ8B401_ooool00ol0003oooooooooo`0;ooooo`;o0000=?ooool2o`000?oooooo1Oooool0
00?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_oo
ool00ol0003oooooooooo`0;ooooo`;o0000d?ooool2o`0006Sooooo0003ooooo`05oa0@4?oooooo
ooooooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo05[ooooo0_l0
001Mooooo`;o00008_ooool2o`0000;ooooo0_l00002ooooo`;o0000H?ooool000?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0AOoo
ool2o`0000Cooooo0_l0000=ooooo`;o0000GOooool2o`0002Kooooo0_l00002ooooo`;o00003ooo
ool2o`0004oooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`00
0?l@4106ooooo`03o`000?oooooooooo00cooooo0_l0000gooooo`;o00001?ooool2o`0002Kooooo
0_l0000Dooooo`;o0000;_ooool2o`0003_ooooo0_l0001?ooooo`007_ooool00ol0003ooooooooo
o`0<ooooo`;o0000IOooool2o`0001Cooooo0_l0000Iooooo`;o00004oooool2o`0008cooooo000N
ooooo`03o`000?oooooooooo00?ooooo0_l00007ooooo`;o00005Oooool2o`0003?ooooo0_l0000A
ooooo`;o00004_ooool2o`0002?ooooo0_l0001Pooooo`;o0000?oooool001kooooo00?o0000oooo
ooooool00oooool2o`0000Oooooo0_l00003ooooo`;o00001oooool2o`0000Oooooo0_l0000coooo
o`;o00004Oooool2o`0001;ooooo0_l00005ooooo`;o00002_ooool2o`0007;ooooo0_l00005oooo
o`;o0000>?ooool001kooooo00?o0000ooooooooool04Oooool2o`0000Oooooo0_l0001Iooooo`;o
00003oooool2o`0000[ooooo0_l0000Looooo`;o00001?ooool2o`0004cooooo0_l00007ooooo`;o
0000>?ooool001kooooo00?o0000ooooooooool0>oooool2o`0003Sooooo0_l0000iooooo`;o0000
1?ooool2o`0002gooooo0_l0000Mooooo`;o0000:?ooool2o`0001Oooooo000Nooooo`03o`000?oo
oooooooo017ooooo0_l0000Xooooo`;o0000Z?ooool2o`0004Oooooo0_l0000Gooooo`007_ooool0
0ol0003oooooooooo`0Aooooo`;o00004Oooool2o`0008gooooo0_l0001Tooooo`;o0000;?ooool0
01kooooo00?o0000ooooooooool09?ooool2o`0003cooooo0_l0000Oooooo`;o0000;_ooool2o`00
01Cooooo0_l0000>ooooo`;o0000>oooool5o`0002cooooo000Nooooo`?o0000H_ooool2o`0001oo
oooo0_l0000<ooooo`;o0000=_ooool2o`0000kooooo0_l0000Iooooo`;o00008?ooool4o`0002go
oooo000Nooooo`?o0000=_ooool2o`0001Kooooo0_l00011ooooo`;o0000Eoooool2o`0000Sooooo
0_l0001Aooooo`007_ooool00ol0003oooooooooo`0fooooo`;o00000_ooool2o`0001;ooooo0_l0
002Jooooo`;o00003?ooool2o`0001Cooooo0_l0000gooooo`007_ooool2o`0003_ooooo0_l0002d
ooooo`;o00000oooool2o`000003ooooool0003o000001Cooooo0_l0000gooooo`007_ooool00ol0
003oooooooooo`1fooooo`;o00008_ooool2o`0005Cooooo0_l00003ooooo`;o0000D?ooool001ko
oooo00?o0000ooooooooool0<_ooool4o`00033ooooo0_l0000>ooooo`;o00008_ooool2o`0007Go
oooo0_l0000Rooooo`;o00004?ooool001kooooo00?o0000ooooooooool0<_ooool4o`00033ooooo
0_l00013ooooo`;o0000I?ooool2o`0002;ooooo0_l0000@ooooo`007_ooool00ol0003ooooooooo
o`2[ooooo`;o0000S?ooool2o`0000cooooo000Nooooo`03o`000?oooooooooo06gooooo0_l0000K
ooooo`;o00007oooool2o`0001[ooooo0_l0000Vooooo`;o0000B?ooool2o`0000cooooo000Noooo
o`03o`000?oooooooooo03[ooooo0_l000000ooooooo0000o`00000^ooooo`;o00003oooool2o`00
00[ooooo0_l0000Oooooo`;o00006_ooool2o`0002Kooooo0_l0000`ooooo`;o00009?ooool001ko
oooo00?o0000ooooooooool01?ooool2o`0003?ooooo0ol000000ooooooo0000o`00000?ooooo`;o
0000;_ooool2o`0003Oooooo0_l000000ooooooo0000o`000007ooooo`;o0000G?ooool2o`0002Co
oooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0000^ooooo`;o00000oooool2o`0001?ooooo
0_l0001Wooooo`;o000000?oooooo`000?l000001oooool2o`0007Oooooo0_l00009ooooo`007_oo
ool00ol0003oooooooooo`0dooooo`;o00009Oooool2o`0003kooooo0_l0000Pooooo`;o0000OOoo
ool2o`0000Wooooo000Nooooo`03o`000?oooooooooo02Wooooo0_l0000Oooooo`;o00003oooool2
o`0003kooooo0_l0000Pooooo`;o000000?oooooo`000?l000003?ooool2o`0006?ooooo0_l0000B
ooooo`007_ooool00ol0003oooooooooo`0Yooooo`;o00007oooool2o`0002Cooooo0_l0000<oooo
o`;o0000??ooool2o`0000;ooooo0_l0000<ooooo`;o0000C?ooool2o`0001Gooooo0_l0000Boooo
o`007_ooool00ol0003oooooooooo`1`ooooo`;o00003?ooool2o`0003cooooo0_l0001Hooooo`;o
00001?ooool2o`0000Sooooo0_l0000Oooooo`007_ooool00ol0003oooooooooo`0iooooo`;o0000
e?ooool2o`0000Gooooo0_l0000>ooooo`;o00007oooool001kooooo00?o0000ooooooooool0>Ooo
ool2o`0005kooooo0_l0000Nooooo`;o00008_ooool2o`00033ooooo0_l0000fooooo`007_ooool0
0ol0003oooooooooo`0Zooooo`;o0000KOooool2o`0000cooooo0_l0000@ooooo`;o00008_ooool2
o`0005Wooooo0_l0000=ooooo`007_ooool2o`0002Kooooo0_l00003ooooo`;o00009oooool2o`00
05;ooooo0_l0002;ooooo`;o00000_ooool2o`0000gooooo000Nooooo`03o`000?oooooooooo017o
oooo0_l0000Booooo`;o00001oooool2o`0002?ooooo0_l0000Fooooo`;o0000aoooool2o`00017o
oooo000Nooooo`03o`000?oooooooooo017ooooo0_l0000Kooooo`;o00008Oooool2o`0001Sooooo
0_l0000iooooo`;o0000F?ooool2o`0003_ooooo0_l00008ooooo`007_ooool00ol0003ooooooooo
o`0_ooooo`;o00008?ooool2o`0002oooooo0_l00005ooooo`;o00006oooool2o`0000oooooo0_l0
0017ooooo`;o0000>oooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0000Y
ooooo`;o0000=Oooool2o`0001[ooooo0_l00005ooooo`;o0000;?ooool2o`0008kooooo000Noooo
o`03o`000?oooooooooo00Cooooo0_l0001Pooooo`;o0000Goooool2o`0007kooooo000Nooooo`03
o`000?oooooooooo0<Oooooo0_l0001nooooo`007_ooool00ol0003oooooooooo`1kooooo`;o0000
Aoooool2o`0002Sooooo0_l00008ooooo`;o0000COooool001kooooo00?o0000ooooooooool00ooo
ool2o`0001;ooooo0_l0000?ooooo`;o0000DOooool2o`0002Oooooo0_l0000Nooooo`;o00004_oo
ool2o`0001Cooooo0_l00008ooooo`;o0000>?ooool2o`0001?ooooo000Nooooo`03o`000?oooooo
oooo00?ooooo0_l0000Booooo`;o00003oooool2o`00073ooooo0_l00008ooooo`;o00003oooool2
o`0001;ooooo0_l00003ooooo`;o00002?ooool2o`0001Cooooo0_l00009ooooo`;o0000=oooool2
o`0001?ooooo000Nooooo`03o`000?oooooooooo01oooooo0_l0001Rooooo`;o00005Oooool2o`00
01Wooooo0_l0000Booooo`;o00000oooool2o`0001Kooooo0_l00006ooooo`;o00002Oooool2o`00
04cooooo000Nooooo`03o`000?oooooooooo01oooooo0_l0001Rooooo`;o00007?ooool2o`0004?o
oooo0_l0000Mooooo`;o0000@?ooool001kooooo00?o0000ooooooooool0BOooool2o`0004Oooooo
0_l0000=ooooo`;o0000<?ooool2o`00033ooooo0_l0000Booooo`;o00008oooool2o`0000Oooooo
000Nooooo`03o`000?oooooooooo03cooooo0_l0000;ooooo`;o00008_ooool2o`0002?ooooo0_l0
000oooooo`;o0000A?ooool2o`0001Oooooo0_l0000:ooooo`;o00001oooool001kooooo00Co0000
oooooooooooooooo0_l0000eooooo`;o00000_ooool2o`0002oooooo0_l0002dooooo`;o00003Ooo
ool2o`0001?ooooo000Nooooo`04o`000?ooooooooooooooo`;o00004oooool2o`00023ooooo0_l0
000Hooooo`;o00008?ooool2o`0000[ooooo0_l0002Qooooo`;o00008_ooool001kooooo0_l0000G
ooooo`;o0000>_ooool2o`00023ooooo0_l0000:ooooo`;o0000aOooool001kooooo00?o0000oooo
ooooool0N?ooool2o`0009_ooooo0_l0000`ooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o
0000Doooool2o`0001Kooooo0_l0002Kooooo`;o0000:?ooool2o`0000Kooooo000Nooooo`03o`00
0?oooooooooo00_ooooo0_l0000booooo`;o00007oooool2o`000=gooooo0_l00006ooooo`007_oo
ool00ol0003oooooooooo`0oooooo`;o00006Oooool2o`000:7ooooo0_l00018ooooo`007_ooool0
0ol0003oooooooooo`0Dooooo`;o0000A?ooool2o`0006Sooooo0_l0000booooo`;o00000oooool2
o`0004Sooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0000Cooooo`;o00001_ooool2o`00
097ooooo0_l0000booooo`;o0000COooool001kooooo00?o0000ooooooooool01oooool2o`00023o
oooo0_l00006ooooo`;o0000oooooolEooooo`007_ooool00ol0003oooooooooo`07ooooo`;o0000
ooooooloooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o0000L_ooool2o`0000Sooooo0_l0
002hooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o0000Doooool2o`0001gooooo0_l00008
ooooo`;o0000DOooool2o`0006Gooooo000Nooooo`03o`000?oooooooooo03Oooooo0_l0000[oooo
o`;o00001oooool2o`0001[ooooo0_l0001=ooooo`;o00001_ooool2o`0002Oooooo0_l0000Koooo
o`;o00007oooool001kooooo00?o0000ooooooooool0=oooool2o`0000gooooo0_l0000Uooooo`;o
00002?ooool2o`00013ooooo0_l0001=ooooo`;o0000;oooool2o`0001_ooooo0_l0000>ooooo`;o
00003oooool001kooooo00?o0000ooooooooool0<oooool2o`00017ooooo0_l0000Booooo`;o0000
6oooool2o`000;gooooo0_l0000?ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0cooooo`;o
00009Oooool2o`000:_ooooo0_l0000nooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`07oooo
o`;o0000>?ooool2o`0001kooooo0_l0000Cooooo`;o0000:_ooool2o`0001cooooo0_l0000Uoooo
o`;o00007_ooool2o`0003kooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0
003ooooooooooooooooo000000Kooooo0ol00007ooooo`;o00005oooool2o`0000Gooooo0_l0000H
ooooo`;o00007_ooool2o`0001?ooooo0_l0000Zooooo`;o00007?ooool2o`0002Gooooo0_l0001<
ooooo`;o00004?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9So
oooooiRHV?lb<S801_ooool00ol0003oooooooooo`0Pooooo`;o00001Oooool2o`0009_ooooo0_l0
000Cooooo`;o0000A?ooool2o`0001Cooooo0_l0000@ooooo`000oooool01Ol0003ooooooooooooo
oooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo0<Cooooo
0_l0000Cooooo`;o00004_ooool2o`00033ooooo0_l0000Vooooo`000oooool01Ol@413ooooooooo
oooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo04co
oooo0_l0000Looooo`;o0000F?ooool2o`0002Oooooo0_l0001Hooooo`000oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo
01;ooooo0_l0000Eooooo`;o00008Oooool2o`0000kooooo0_l0000<ooooo`;o0000F?ooool2o`00
087ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413o
ZJVY00Kooooo00?o0000ooooooooool04_ooool2o`0001Gooooo1?l0000_ooooo`;o0000^oooool2
o`0002cooooo000Nooooo`03o`000?oooooooooo02_ooooo0_l0003/ooooo`;o0000;?ooool001ko
oooo00?o0000ooooooooool0G?ooool2o`000>Wooooo000Nooooo`03o`000?oooooooooo05cooooo
0_l0003Yooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo073ooooo0_l0002Tooooo`;o0000;oooool001kooooo00?o0000ooooooooool0L?ooool2o`00
07Wooooo0_l0000Yooooo`;o00002_ooool2o`0002?ooooo000Nooooo`03o`000?oooooooooo013o
oooo0_l0000Nooooo`;o0000^Oooool2o`0000Wooooo0_l0000?ooooo`;o00006Oooool2o`0002?o
oooo000Nooooo`03o`000?oooooooooo013ooooo0_l0000Nooooo`;o00007_ooool2o`0001kooooo
0_l00006ooooo`;o0000O?ooool2o`0000oooooo0_l0000nooooo`007_ooool00ol0003ooooooooo
o`1@ooooo`;o00001_ooool2o`0001Kooooo0_l00006ooooo`;o0000<_ooool2o`0002Kooooo0_l0
0008ooooo`;o00003oooool2o`0000Oooooo0_l0000]ooooo`;o00007_ooool001kooooo00?o0000
ooooooooool00_ooool2o`000003ooooool0003o0000057ooooo0_l0001Booooo`;o00009_ooool2
o`0000Sooooo0_l0000?ooooo`;o00001oooool2o`0000Gooooo0_l0000Kooooo`;o00002Oooool2
o`0001kooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l000000ooooooo0000o`00003hoooo
o`;o00006oooool2o`0002Wooooo000Nooooo`;o00009_ooool2o`0003oooooo0_l0001jooooo`;o
0000Hoooool001kooooo00?o0000ooooooooool09Oooool2o`0003oooooo0_l00006ooooo`;o0000
L_ooool2o`0000cooooo0_l0000Yooooo`;o0000:_ooool001kooooo00?o0000ooooooooool0K_oo
ool2o`00083ooooo0_l0000Cooooo`;o00005?ooool2o`0002[ooooo000Nooooo`;o0000ooooool7
ooooo`;o0000>?ooool2o`0000Kooooo000Nooooo`;o0000Soooool2o`000003ooooool0003o0000
09Kooooo0_l0000Dooooo`;o00001_ooool001kooooo00?o0000ooooooooool0=_ooool2o`0004ko
oooo0_l00006ooooo`;o000000?oooooo`000?l00000B?ooool2o`0001Oooooo0_l0000cooooo`;o
00007?ooool001kooooo00?o0000ooooooooool0=_ooool2o`0003Kooooo0_l0000Fooooo`;o0000
Doooool2o`0001Oooooo0_l00004ooooo`;o0000?oooool2o`0000[ooooo000Nooooo`03o`000?oo
oooooooo01?ooooo0_l0000<ooooo`;o0000Boooool2o`0006Sooooo0_l0000Aooooo`;o00003Ooo
ool2o`0001_ooooo0_l0000Rooooo`;o00002_ooool001kooooo00?o0000ooooooooool04oooool2
o`0000cooooo0_l0002eooooo`;o00004Oooool2o`0000Wooooo0_l0000Oooooo`;o00007Oooool2
o`0000oooooo000Nooooo`03o`000?oooooooooo087ooooo0_l0001cooooo`;o0000?_ooool2o`00
00oooooo000Nooooo`03o`000?oooooooooo02cooooo0_l0001Cooooo`;o0000a?ooool001kooooo
00?o0000ooooooooool0;?ooool2o`000003ooooool0003o00000?oooooo5oooool001kooooo00?o
0000ooooooooool0;oooool2o`000?oooooo5oooool001kooooo00?o0000ooooooooool0Moooool2
o`0001Gooooo0_l0002gooooo`007_ooool00ol0003oooooooooo`09ooooo`;o0000Eoooool2o`00
01;ooooo0ol0000Eooooo`;o0000D_ooool2o`0001Kooooo0_l0001;ooooo`007_ooool00ol0003o
ooooooooo`09ooooo`;o00006_ooool2o`00013ooooo0_l0000Yooooo`;o00004_ooool2o`0006[o
oooo0_l0000Fooooo`;o0000Boooool001kooooo0_l00005ooooo`;o00003Oooool2o`00013ooooo
0_l0000@ooooo`;o00009_ooool2o`000:gooooo0_l0000Booooo`;o00008oooool001kooooo00?o
0000ooooooooool01?ooool2o`0000gooooo0_l0000Nooooo`;o0000:_ooool2o`0004oooooo0_l0
001Looooo`;o00004_ooool2o`0002?ooooo000Nooooo`03o`000?oooooooooo03?ooooo0_l0001k
ooooo`;o0000UOooool001kooooo00?o0000ooooooooool0:_ooool2o`0006;ooooo0_l0002goooo
o`007_ooool00ol0003oooooooooo`0Zooooo`;o0000H_ooool2o`0005Oooooo0_l0001Nooooo`00
7_ooool00ol0003oooooooooo`0Booooo`;o00001?ooool2o`0005Wooooo0_l0001booooo`;o0000
5Oooool2o`0004Oooooo000Nooooo`03o`000?oooooooooo017ooooo0ol00004ooooo`;o0000EOoo
ool2o`0000;ooooo0_l00029ooooo`;o0000Aoooool001kooooo00?o0000ooooooooool02?ooool2
o`0000Oooooo0_l0001Looooo`;o0000;?ooool2o`0004;ooooo0_l0001Tooooo`007_ooool00ol0
003oooooooooo`08ooooo`;o0000Toooool2o`0004;ooooo0_l0001Tooooo`007_ooool00ol0003o
ooooooooo`0@ooooo`;o0000N_ooool2o`0006Sooooo0_l0001?ooooo`007_ooool00ol0003ooooo
ooooo`0@ooooo`;o0000N_ooool2o`0000[ooooo0_l0000=ooooo`;o0000COooool2o`0003Kooooo
0_l0000Gooooo`007_ooool00ol0003oooooooooo`1]ooooo`;o0000:Oooool2o`0000gooooo0_l0
001Kooooo`;o0000:?ooool2o`0001Oooooo000Nooooo`;o0000A_ooool2o`00013ooooo0_l00005
ooooo`;o00003Oooool2o`0000Wooooo0_l0000>ooooo`;o0000:?ooool2o`0002gooooo0_l0000Q
ooooo`;o0000@Oooool001kooooo0_l00016ooooo`;o00004?ooool2o`0000Gooooo0_l0000Hoooo
o`;o00002?ooool2o`0000Cooooo0_l0000Xooooo`;o0000;Oooool2o`0006Cooooo000Nooooo`03
o`000?oooooooooo08;ooooo0_l00033ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o00004oooool2o`0006Sooooo0_l00020ooooo`;o0000:oooool2o`0001[ooooo000N
ooooo`03o`000?oooooooooo01;ooooo0_l0001Xooooo`;o0000P?ooool2o`0002_ooooo0_l0000D
ooooo`;o00001?ooool001kooooo00?o0000ooooooooool09oooool2o`0000kooooo0_l00015oooo
o`;o0000@?ooool2o`0003Wooooo0_l00014ooooo`;o00001?ooool001kooooo00?o0000oooooooo
ool09oooool2o`0000kooooo0_l0000booooo`;o00004Oooool2o`0001;ooooo0_l0000?ooooo`;o
000000?oooooo`000?l000006?ooool2o`0003Wooooo0_l0001:ooooo`007_ooool00ol0003ooooo
ooooo`0Gooooo`;o00009Oooool2o`0002_ooooo0_l0000Uooooo`;o00003oooool2o`000003oooo
ool0003o000008Gooooo0_l0000;ooooo`;o00002oooool001kooooo00?o0000ooooooooool05ooo
ool2o`0002Gooooo0_l000000ooooooo0000o`00000kooooo`;o0000DOooool2o`0003kooooo0_l0
0002ooooo`;o00005_ooool2o`0000_ooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`11
ooooo`;o0000>oooool2o`0004Oooooo0_l00008ooooo`;o0000?_ooool2o`0000;ooooo0_l0000`
ooooo`007_ooool00ol0003oooooooooo`2?ooooo`;o00004_ooool2o`0002;ooooo0_l0001noooo
o`007_ooool00ol0003oooooooooo`06ooooo`;o0000;oooool2o`0005Kooooo0_l0000Booooo`;o
0000P_ooool2o`0001kooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l0000_ooooo`;o0000
K?ooool2o`0005;ooooo0_l0000/ooooo`;o00007_ooool001kooooo00?o0000ooooooooool0YOoo
ool2o`0004kooooo0_l00002ooooo`;o00005_ooool2o`0002?ooooo0_l00004ooooo`;o00002Ooo
ool001kooooo00?o0000ooooooooool0=Oooool2o`00027ooooo0_l0001<ooooo`;o00003Oooool2
o`0003kooooo0_l0000Jooooo`;o00008oooool2o`0000Cooooo0_l00009ooooo`007_ooool00ol0
003oooooooooo`0eooooo`;o00008Oooool2o`0004cooooo0_l00008ooooo`;o00000oooool2o`00
02Cooooo0_l0001Zooooo`007_ooool00ol0003oooooooooo`2`ooooo`;o0000:Oooool2o`0006[o
oooo000Dooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3eooooo`;o0000
D?ooool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`;o0000=Ooo
ool2o`0004Kooooo0_l0000Eooooo`;o0000F_ooool2o`00047ooooo0_l0000=ooooo`005_ooool0
0ol0003oooooooooo`05ooooo`?o00000oooool2o`0003Gooooo0_l00016ooooo`;o00005Oooool2
o`0009gooooo0_l0000=ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03
o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_oo
ool00ol0003oooooooooo`3ooooooe3ooooo000Dooooo`03oeEEEOmVIVKo00000?ooooooD_ooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.22368 .54287 Mdot
.95228 .71294 Mdot
.83609 .02334 Mdot
.22262 .61519 Mdot
.12306 .50157 Mdot
.87704 .01998 Mdot
.16376 .86897 Mdot
.20322 .66332 Mdot
.7973 .13024 Mdot
.12906 .01753 Mdot
.59732 .03734 Mdot
.91154 .61574 Mdot
.80302 .51501 Mdot
.28839 .56361 Mdot
.47571 .33141 Mdot
.20546 .69969 Mdot
.46608 .92763 Mdot
.49545 .43633 Mdot
.80308 .97429 Mdot
.76639 .98881 Mdot
.57311 .09212 Mdot
.58463 .06217 Mdot
.73022 .00935 Mdot
.22673 .35084 Mdot
.69918 .31087 Mdot
.14201 .368 Mdot
.78782 .94645 Mdot
.60478 .39095 Mdot
.14812 .64271 Mdot
.27341 .30496 Mdot
.57993 .2667 Mdot
.26833 .45547 Mdot
.46499 .96421 Mdot
.1318 .12008 Mdot
.71177 .00843 Mdot
.08186 .60494 Mdot
.13311 .2749 Mdot
.39322 .23024 Mdot
.25472 .01193 Mdot
.97169 .99574 Mdot
.08125 .36268 Mdot
.46509 .99973 Mdot
.26886 .48534 Mdot
.17745 .44148 Mdot
.60806 .41335 Mdot
.70056 .57942 Mdot
.94112 .21937 Mdot
.71201 .65149 Mdot
.31876 .51121 Mdot
.99424 .39787 Mdot
.70103 .27388 Mdot
.31564 .5166 Mdot
.15004 .64734 Mdot
.99508 .37444 Mdot
.78658 .37432 Mdot
.69429 .23778 Mdot
.48702 .95565 Mdot
.0133 .70366 Mdot
.13269 .42146 Mdot
.06984 .72173 Mdot
.24195 .44746 Mdot
.66464 .77219 Mdot
.25699 .07816 Mdot
.10955 .29883 Mdot
.18641 .49276 Mdot
.37481 .08645 Mdot
.45145 .70549 Mdot
.61674 .21964 Mdot
.26642 .42715 Mdot
.96599 .09495 Mdot
.75991 .71339 Mdot
.76702 .11497 Mdot
.15125 .71427 Mdot
.08711 .92582 Mdot
.16003 .54471 Mdot
.52363 .22961 Mdot
.80644 .5937 Mdot
.11485 .04735 Mdot
.6909 .98073 Mdot
.36624 .16498 Mdot
.53025 .49584 Mdot
.56791 .11406 Mdot
.21549 .02306 Mdot
.66667 .47193 Mdot
.85995 .27344 Mdot
.68247 .30482 Mdot
.5347 .9474 Mdot
.89425 .45579 Mdot
.56311 .07656 Mdot
.69649 .45644 Mdot
.01947 .99441 Mdot
.4152 .19367 Mdot
.27713 .72294 Mdot
.82939 .23496 Mdot
.92356 .74225 Mdot
.48634 .63761 Mdot
.07631 .42927 Mdot
.788 .49783 Mdot
.53731 .42046 Mdot
.10271 .96596 Mdot
.5987 .26381 Mdot
.78338 .48114 Mdot
.91217 .81844 Mdot
.21273 .27101 Mdot
.8273 .78706 Mdot
.17926 .92709 Mdot
.65104 .15849 Mdot
.04299 .3012 Mdot
.16397 .12591 Mdot
.3149 .68762 Mdot
.62781 .56922 Mdot
.05711 .03269 Mdot
.71657 .56376 Mdot
.19911 .43683 Mdot
.29922 .48035 Mdot
.34923 .75053 Mdot
.51817 .67866 Mdot
.10506 .92825 Mdot
.88487 .71343 Mdot
.62425 .80256 Mdot
.7605 .54222 Mdot
.54329 .07759 Mdot
.18547 .82279 Mdot
.28744 .75864 Mdot
.38271 .35661 Mdot
.75842 .58629 Mdot
.74289 .17329 Mdot
.88497 .61916 Mdot
.4103 .78327 Mdot
.63737 .07304 Mdot
.37515 .20005 Mdot
.22257 .50748 Mdot
.27146 .70871 Mdot
.31851 .51637 Mdot
.92096 .69093 Mdot
.31344 .57365 Mdot
.41518 .00984 Mdot
.0954 .1705 Mdot
.62574 .82479 Mdot
.40303 .38897 Mdot
.29922 .02556 Mdot
.89533 .05957 Mdot
.8836 .60502 Mdot
.1528 .50641 Mdot
.82261 .30561 Mdot
.29829 .76325 Mdot
.90403 .748 Mdot
.17797 .33367 Mdot
.17208 .47835 Mdot
.96371 .22924 Mdot
.24125 .46889 Mdot
.50376 .37457 Mdot
.09075 .38257 Mdot
.87727 .81644 Mdot
.98484 .37949 Mdot
.84971 .59209 Mdot
.11263 .42068 Mdot
.51035 .65397 Mdot
.51244 .97089 Mdot
.1995 .51066 Mdot
.29469 .24338 Mdot
.95741 .20579 Mdot
.00108 .99851 Mdot
.08815 .15448 Mdot
.8582 .5029 Mdot
.10175 .92992 Mdot
.74939 .77855 Mdot
.15077 .29417 Mdot
.72553 .50773 Mdot
.15448 .69211 Mdot
.04655 .4072 Mdot
.78167 .50245 Mdot
.33333 .02863 Mdot
.39204 .1316 Mdot
.42564 .27334 Mdot
.31762 .31042 Mdot
.31385 .81133 Mdot
.2771 .40657 Mdot
.13236 .24025 Mdot
.85464 .10324 Mdot
.01416 .52781 Mdot
.88404 .49525 Mdot
.07188 .5004 Mdot
.15177 .99463 Mdot
.69825 .5141 Mdot
.08639 .65147 Mdot
.21993 .28888 Mdot
.61052 .03656 Mdot
.57475 .60541 Mdot
.44917 .80684 Mdot
.3155 .10019 Mdot
.35414 .68537 Mdot
.49481 .71575 Mdot
.79439 .49022 Mdot
.05434 .95063 Mdot
.69222 .43348 Mdot
.67366 .48676 Mdot
.55408 .49237 Mdot
.2651 .01151 Mdot
.4437 .23532 Mdot
.22835 .5778 Mdot
.08825 .47149 Mdot
.65953 .63324 Mdot
.19197 .81629 Mdot
.17049 .39498 Mdot
.2779 .64943 Mdot
.36507 .51096 Mdot
.67483 .12995 Mdot
.71209 .04987 Mdot
.64786 .21054 Mdot
.34867 .00941 Mdot
.35112 .91538 Mdot
.91415 .14425 Mdot
.74979 .46966 Mdot
.62985 .71318 Mdot
.66844 .49539 Mdot
.23462 .06719 Mdot
.54136 .18638 Mdot
.09597 .65287 Mdot
.69637 .82676 Mdot
.87006 .71419 Mdot
.33681 .49537 Mdot
.23393 .96241 Mdot
.14604 .31658 Mdot
.30958 .84635 Mdot
.18113 .79599 Mdot
.90156 .10608 Mdot
.83219 .15387 Mdot
.52508 .63933 Mdot
.15498 .72182 Mdot
.33974 .00739 Mdot
.98764 .44006 Mdot
.26744 .58259 Mdot
.97974 .75564 Mdot
.10294 .75443 Mdot
.89928 .84323 Mdot
.44563 .0703 Mdot
.62743 .73445 Mdot
.86373 .08774 Mdot
.16668 .78107 Mdot
.17639 .82929 Mdot
.14755 .1088 Mdot
.91471 .7861 Mdot
.97834 .08511 Mdot
.61107 .70778 Mdot
.606 .02844 Mdot
.37497 .93616 Mdot
.72458 .66619 Mdot
.11866 .15725 Mdot
.19257 .62377 Mdot
.20706 .3639 Mdot
.67352 .59417 Mdot
.25437 .41297 Mdot
.71922 .67334 Mdot
.63388 .64976 Mdot
.0249 .6023 Mdot
.05778 .40173 Mdot
.04228 .03977 Mdot
.24106 .22182 Mdot
.97007 .88151 Mdot
.4453 .69831 Mdot
.38764 .38317 Mdot
.57629 .36675 Mdot
.56548 .47804 Mdot
.13067 .84566 Mdot
.97192 .43611 Mdot
.449 .88404 Mdot
.31676 .70148 Mdot
.54932 .01562 Mdot
.84069 .46424 Mdot
.76821 .50651 Mdot
.10422 .35153 Mdot
.55317 .02413 Mdot
.31565 .34278 Mdot
.26509 .60683 Mdot
.86619 .70363 Mdot
.02301 .66726 Mdot
.88685 .22625 Mdot
.46656 .53881 Mdot
.83583 .98676 Mdot
.98821 .10032 Mdot
.65387 .32473 Mdot
.93592 .76382 Mdot
.8613 .37149 Mdot
.56177 .33631 Mdot
.58029 .08889 Mdot
.71059 .43199 Mdot
.80936 .36929 Mdot
.8115 .51818 Mdot
.87192 .87113 Mdot
.23861 .36741 Mdot
.23011 .19255 Mdot
.20341 .00405 Mdot
.99908 .6615 Mdot
.79488 .05105 Mdot
.63826 .30175 Mdot
.22328 .22808 Mdot
.74048 .41059 Mdot
.80702 .4327 Mdot
.26665 .15396 Mdot
.34833 .46479 Mdot
.75118 .17186 Mdot
.18256 .52278 Mdot
.7874 .89046 Mdot
.58054 .27813 Mdot
.25831 .35704 Mdot
.32151 .93406 Mdot
.57017 .11249 Mdot
.31776 .04797 Mdot
.41074 .64413 Mdot
.43032 .54014 Mdot
.79718 .56727 Mdot
.84516 .39035 Mdot
.12085 .51728 Mdot
.15354 .92144 Mdot
.37346 .67998 Mdot
.70198 .99182 Mdot
.28982 .58276 Mdot
.75643 .362 Mdot
.52146 .27015 Mdot
.93478 .09585 Mdot
.24651 .83763 Mdot
.4425 .27161 Mdot
.60233 .1469 Mdot
.36085 .45805 Mdot
.63716 .36696 Mdot
.99539 .46455 Mdot
.34408 .3886 Mdot
.91183 .20925 Mdot
.48397 .04686 Mdot
.02639 .58046 Mdot
.23385 .8113 Mdot
.19946 .26894 Mdot
.69596 .87699 Mdot
.04035 .74111 Mdot
.21179 .68297 Mdot
.23239 .2058 Mdot
.2876 .41873 Mdot
.00328 .34962 Mdot
.86415 .29338 Mdot
.8577 .92638 Mdot
.364 .93416 Mdot
.20576 .40455 Mdot
.50753 .72747 Mdot
.12337 .34357 Mdot
.46097 .06415 Mdot
.41965 .25692 Mdot
.78806 .84935 Mdot
.31635 .74401 Mdot
.31903 .61898 Mdot
.28793 .02209 Mdot
.68569 .71458 Mdot
.07674 .39562 Mdot
.65387 .44698 Mdot
.76783 .88726 Mdot
.72076 .05629 Mdot
.21002 .36175 Mdot
.1039 .21964 Mdot
.81416 .28714 Mdot
.61419 .05245 Mdot
.90718 .88306 Mdot
.53148 .48847 Mdot
.72121 .49236 Mdot
.60789 .35188 Mdot
.91523 .14228 Mdot
.54953 .1093 Mdot
.06381 .3677 Mdot
.82684 .6354 Mdot
.6723 .40038 Mdot
.08439 .60254 Mdot
.85125 .25054 Mdot
.79819 .01523 Mdot
.37841 .82255 Mdot
.74707 .7514 Mdot
.36074 .6886 Mdot
.47581 .89986 Mdot
.36115 .62688 Mdot
.82536 .56778 Mdot
.20788 .56793 Mdot
.16119 .09803 Mdot
.05387 .31327 Mdot
.11054 .22606 Mdot
.93117 .79447 Mdot
.63648 .33266 Mdot
.27399 .61072 Mdot
.72913 .70872 Mdot
.57181 .71545 Mdot
.29384 .63197 Mdot
.19552 .05125 Mdot
.37045 .18555 Mdot
.87424 .39501 Mdot
.32587 .92465 Mdot
.42064 .04631 Mdot
.38181 .19205 Mdot
.04095 .73712 Mdot
.6378 .55236 Mdot
.8931 .96182 Mdot
.75055 .1952 Mdot
.04231 .72729 Mdot
.68852 .38624 Mdot
.00876 .474 Mdot
.56283 .25182 Mdot
.52419 .63507 Mdot
.43435 .30512 Mdot
.35822 .44313 Mdot
.23671 .86612 Mdot
.79603 .61608 Mdot
.83631 .05623 Mdot
.37878 .44547 Mdot
.2985 .84877 Mdot
.11282 .87044 Mdot
.78708 .63956 Mdot
.98321 .82934 Mdot
.94372 .52675 Mdot
.03774 .09472 Mdot
.49361 .49039 Mdot
.22515 .09708 Mdot
.85343 .59901 Mdot
.70078 .05294 Mdot
.79583 .84034 Mdot
.84098 .51772 Mdot
.85142 .88818 Mdot
.71168 .87652 Mdot
.4349 .28378 Mdot
.51421 .05332 Mdot
.60584 .60993 Mdot
.16624 .76427 Mdot
.08371 .60458 Mdot
.608 .51659 Mdot
.39874 .02347 Mdot
.25212 .49788 Mdot
.27424 .41461 Mdot
.57137 .043 Mdot
.86519 .30043 Mdot
.11165 .09528 Mdot
.9914 .40213 Mdot
.48689 .30594 Mdot
.29692 .30758 Mdot
.54824 .39608 Mdot
.29081 .9789 Mdot
.48966 .52381 Mdot
.32809 .02628 Mdot
.15243 .13509 Mdot
.02783 .94853 Mdot
.98511 .12314 Mdot
.29024 .56738 Mdot
.7583 .94427 Mdot
.4755 .27231 Mdot
.56309 .65739 Mdot
.34472 .62279 Mdot
.12016 .05931 Mdot
.06843 .81568 Mdot
.86271 .39109 Mdot
.54841 .01385 Mdot
.43579 .32917 Mdot
.65615 .82335 Mdot
.56649 .68574 Mdot
.42096 .59917 Mdot
.70246 .11909 Mdot
.13516 .69665 Mdot
.54357 .39659 Mdot
.35303 .96172 Mdot
.95251 .99609 Mdot
.45558 .89693 Mdot
.30214 .56492 Mdot
.19095 .86596 Mdot
.91449 .13482 Mdot
.40872 .90552 Mdot
.19031 .03796 Mdot
.90557 .44097 Mdot
.38461 .69804 Mdot
.51232 .63086 Mdot
.54089 .82104 Mdot
.02838 .27936 Mdot
.05958 .76347 Mdot
.55333 .39651 Mdot
.60536 .36164 Mdot
.56327 .53983 Mdot
.8107 .15413 Mdot
.44604 .62598 Mdot
.96971 .99079 Mdot
.77742 .23956 Mdot
.68631 .99158 Mdot
.39298 .57274 Mdot
.2618 .43549 Mdot
.50748 .35546 Mdot
.29332 .37569 Mdot
.97345 .07495 Mdot
.62814 .27053 Mdot
.65853 .40052 Mdot
.22729 .01621 Mdot
.33876 .18746 Mdot
.25512 .5638 Mdot
.72455 .98748 Mdot
.11132 .3266 Mdot
.57138 .50581 Mdot
.68512 .43516 Mdot
.6571 .24277 Mdot
.08222 .43193 Mdot
.7994 .76149 Mdot
.67488 .8027 Mdot
.33637 .29353 Mdot
.50115 .31277 Mdot
.99152 .03837 Mdot
.10402 .18589 Mdot
.41354 .38828 Mdot
.95616 .5335 Mdot
.46326 .03112 Mdot
.82127 .45223 Mdot
.20926 .6482 Mdot
.73859 .28704 Mdot
.1608 .67858 Mdot
.10878 .50159 Mdot
.92207 .17824 Mdot
.77525 .27145 Mdot
.05116 .88786 Mdot
.73858 .24888 Mdot
.59119 .73616 Mdot
.89415 .22176 Mdot
.32777 .76983 Mdot
.56363 .54535 Mdot
.66369 .02258 Mdot
.88483 .48924 Mdot
.15145 .23611 Mdot
.86666 .99298 Mdot
.27623 .13893 Mdot
.30409 .64854 Mdot
.42586 .40028 Mdot
.45875 .41458 Mdot
.52015 .62658 Mdot
.77722 .64002 Mdot
.30613 .61167 Mdot
.09941 .13659 Mdot
.68719 .14675 Mdot
.07611 .74865 Mdot
.20403 .79942 Mdot
.40075 .93025 Mdot
.16532 .25502 Mdot
.00134 .29116 Mdot
.99071 .6591 Mdot
.04158 .84386 Mdot
.01166 .91274 Mdot
.52735 .22686 Mdot
.8695 .28024 Mdot
.39256 .3424 Mdot
.3588 .48316 Mdot
.87719 .7078 Mdot
.20841 .69437 Mdot
.05146 .83703 Mdot
.91374 .00983 Mdot
.77112 .49431 Mdot
.33219 .32149 Mdot
.32808 .89649 Mdot
.27126 .45774 Mdot
.69475 .63716 Mdot
.6928 .11074 Mdot
.50652 .93545 Mdot
.18485 .99109 Mdot
.50523 .65597 Mdot
.19521 .51104 Mdot
.00042 .65932 Mdot
.90155 .84894 Mdot
.99396 .0952 Mdot
.32065 .6221 Mdot
.80545 .61479 Mdot
.89214 .17627 Mdot
.73028 .19204 Mdot
.91728 .1067 Mdot
.54659 .00965 Mdot
.02672 .81209 Mdot
.46612 .21187 Mdot
.06206 .91392 Mdot
.95833 .77626 Mdot
.92435 .7242 Mdot
.97945 .43787 Mdot
.83507 .12806 Mdot
.41814 .90985 Mdot
.33319 .02149 Mdot
.38355 .98773 Mdot
.41213 .00787 Mdot
.89122 .4183 Mdot
.46893 .05775 Mdot
.32217 .26029 Mdot
.92511 .20531 Mdot
.09638 .8732 Mdot
.59628 .5575 Mdot
.09347 .29779 Mdot
.76623 .29516 Mdot
.74424 .51582 Mdot
.03194 .29037 Mdot
.75538 .79896 Mdot
.64671 .02523 Mdot
.29166 .07237 Mdot
.27386 .77135 Mdot
.38714 .54973 Mdot
.40313 .78241 Mdot
.15068 .08695 Mdot
.1879 .13296 Mdot
.66019 .63396 Mdot
.17961 .8944 Mdot
.7646 .20681 Mdot
.27225 .52164 Mdot
.50379 .30467 Mdot
.56708 .42813 Mdot
.36927 .42885 Mdot
.15881 .44317 Mdot
.69661 .54853 Mdot
.83811 .98315 Mdot
.1794 .55644 Mdot
.81364 .24314 Mdot
.72686 .82199 Mdot
.22343 .21267 Mdot
.36187 .26611 Mdot
.99963 .75245 Mdot
.14099 .72522 Mdot
.6848 .21847 Mdot
.41386 .53651 Mdot
.61034 .28222 Mdot
.7301 .26117 Mdot
.89445 .33275 Mdot
.63744 .45996 Mdot
.11263 .21801 Mdot
.87131 .34278 Mdot
.78834 .90627 Mdot
.00675 .85542 Mdot
.69624 .93864 Mdot
.04818 .7314 Mdot
.15791 .66674 Mdot
.52493 .01783 Mdot
.46995 .94364 Mdot
.53405 .10999 Mdot
.59082 .61441 Mdot
.985 .38516 Mdot
.41499 .56676 Mdot
.35476 .38782 Mdot
.78637 .2353 Mdot
.72932 .63487 Mdot
.37638 .66792 Mdot
.10207 .2008 Mdot
.63485 .97537 Mdot
.4215 .73716 Mdot
.39054 .31864 Mdot
.5557 .36744 Mdot
.04387 .90151 Mdot
.6112 .32912 Mdot
.14333 .30053 Mdot
.58739 .68824 Mdot
.10547 .37665 Mdot
.26834 .92077 Mdot
.81233 .88072 Mdot
.69495 .62725 Mdot
.14641 .94387 Mdot
.94598 .73386 Mdot
.95236 .77645 Mdot
.08436 .22438 Mdot
.27397 .72769 Mdot
.51799 .41217 Mdot
.40612 .43395 Mdot
.07447 .51346 Mdot
.58354 .28133 Mdot
.04118 .90977 Mdot
.44821 .26325 Mdot
.61201 .37852 Mdot
.36596 .80676 Mdot
.61122 .37986 Mdot
.44141 .63933 Mdot
.75203 .28534 Mdot
.25287 .38335 Mdot
.4221 .01972 Mdot
.75835 .22929 Mdot
.36509 .0911 Mdot
.15868 .74892 Mdot
.19678 .48687 Mdot
.64055 .31627 Mdot
.96734 .99407 Mdot
.8189 .22162 Mdot
.37495 .77358 Mdot
.50311 .1229 Mdot
.4273 .54479 Mdot
.45863 .18433 Mdot
.84119 .84435 Mdot
.67036 .63587 Mdot
.65633 .51765 Mdot
.60597 .71292 Mdot
.77001 .4532 Mdot
.01643 .2632 Mdot
.63439 .12798 Mdot
.76901 .89885 Mdot
.52318 .57422 Mdot
.28153 .17085 Mdot
.16222 .68328 Mdot
.90186 .95585 Mdot
.43314 .64022 Mdot
.55211 .38587 Mdot
.56354 .19188 Mdot
.51499 .74723 Mdot
.98392 .17678 Mdot
.70811 .52443 Mdot
.31918 .93966 Mdot
.33653 .48088 Mdot
.91059 .62517 Mdot
.56827 .53184 Mdot
.6712 .74932 Mdot
.95055 .53818 Mdot
.17597 .98505 Mdot
.54164 .2147 Mdot
.50956 .41635 Mdot
.7724 .53545 Mdot
.79054 .32037 Mdot
.07152 .89191 Mdot
.43634 .12689 Mdot
.40787 .38011 Mdot
.86994 .85176 Mdot
.5179 .98676 Mdot
.96823 .94322 Mdot
.53325 .10976 Mdot
.09952 .26696 Mdot
.63325 .24134 Mdot
.18146 .41625 Mdot
.93629 .73272 Mdot
.44174 .5347 Mdot
.39708 .77896 Mdot
.22648 .21178 Mdot
.73974 .30105 Mdot
.36825 .64955 Mdot
.34667 .55984 Mdot
.79392 .6474 Mdot
.70727 .4042 Mdot
.63273 .81187 Mdot
.87292 .13771 Mdot
.84381 .25219 Mdot
.76566 .33271 Mdot
.9218 .81416 Mdot
.64018 .0274 Mdot
.7881 .62867 Mdot
.2265 .75846 Mdot
.93263 .41877 Mdot
.99176 .93103 Mdot
.99539 .39253 Mdot
.11717 .46772 Mdot
.52977 .87084 Mdot
.13368 .27901 Mdot
.94144 .41183 Mdot
.06795 .88256 Mdot
.82396 .79832 Mdot
.08258 .29137 Mdot
.65941 .11032 Mdot
.4876 .73714 Mdot
.49736 .07295 Mdot
.55118 .65921 Mdot
.78884 .40082 Mdot
.715 .846 Mdot
.55389 .4945 Mdot
.43841 .47926 Mdot
.71124 .77343 Mdot
.22211 .47062 Mdot
.46444 .70705 Mdot
.02363 .1909 Mdot
.74993 .73688 Mdot
.70757 .75085 Mdot
.10045 .64707 Mdot
.41362 .76156 Mdot
.42763 .31943 Mdot
.91662 .39665 Mdot
.45226 .88677 Mdot
.40304 .54847 Mdot
.74801 .156 Mdot
.13192 .74217 Mdot
.64294 .25911 Mdot
.59014 .91545 Mdot
.52105 .41167 Mdot
.55605 .08434 Mdot
.43691 .60067 Mdot
.41541 .08717 Mdot
.88119 .35629 Mdot
.69832 .62053 Mdot
.39743 .62335 Mdot
.25713 .5596 Mdot
.64855 .96465 Mdot
.91823 .57868 Mdot
.92855 .90505 Mdot
.0628 .18011 Mdot
.45199 .39051 Mdot
.58865 .35171 Mdot
.00905 .40947 Mdot
.11834 .08305 Mdot
.76997 .04105 Mdot
.61643 .52474 Mdot
.33708 .88272 Mdot
.01102 .6489 Mdot
.65263 .37569 Mdot
.84633 .26521 Mdot
.89398 .21902 Mdot
.7199 .64741 Mdot
.7457 .44202 Mdot
.27681 .78749 Mdot
.7265 .85492 Mdot
.48488 .16702 Mdot
.59511 .39476 Mdot
.6869 .55469 Mdot
.61171 .10528 Mdot
.85763 .28879 Mdot
.49665 .23028 Mdot
.58703 .14794 Mdot
.66769 .39227 Mdot
.27384 .35401 Mdot
.97666 .12919 Mdot
.76458 .61839 Mdot
.93492 .13733 Mdot
.51951 .28701 Mdot
.15758 .66554 Mdot
.68685 .37089 Mdot
.74405 .40982 Mdot
.85606 .73561 Mdot
.48447 .44917 Mdot
.11273 .28563 Mdot
.45387 .42459 Mdot
.18335 .38145 Mdot
.6782 .30545 Mdot
.02731 .59081 Mdot
.66096 .46356 Mdot
.53084 .54075 Mdot
.59648 .63772 Mdot
.75533 .99346 Mdot
.19292 .18682 Mdot
.35336 .26921 Mdot
.08557 .31104 Mdot
.75517 .92569 Mdot
.36254 .24573 Mdot
.19135 .56614 Mdot
.7506 .70621 Mdot
.47265 .85739 Mdot
.4399 .707 Mdot
.0019 .50235 Mdot
.83909 .67706 Mdot
.1872 .54797 Mdot
.23798 .04294 Mdot
.67232 .49224 Mdot
.14655 .42098 Mdot
.96924 .5402 Mdot
.40692 .17316 Mdot
.08474 .77602 Mdot
.14083 .2727 Mdot
.75648 .02246 Mdot
.04851 .343 Mdot
.68378 .53037 Mdot
.6385 .15829 Mdot
.18133 .23333 Mdot
.3445 .62427 Mdot
.77243 .64767 Mdot
.14382 .85834 Mdot
.66505 .71633 Mdot
.37464 .20156 Mdot
.21986 .64195 Mdot
.43243 .65787 Mdot
.85738 .42039 Mdot
.18732 .29561 Mdot
.14452 .78007 Mdot
.54306 .14488 Mdot
.89741 .18077 Mdot
.54294 .68974 Mdot
.1357 .9989 Mdot
.04964 .4745 Mdot
.73991 .79653 Mdot
.21069 .28516 Mdot
.3111 .16186 Mdot
.62949 .2784 Mdot
.31612 .35204 Mdot
.45989 .0845 Mdot
.41812 .53008 Mdot
.81814 .00631 Mdot
.2924 .54143 Mdot
.22286 .18963 Mdot
.07233 .12399 Mdot
.27058 .55344 Mdot
.28944 .11786 Mdot
.75257 .56751 Mdot
.32552 .20271 Mdot
.05132 .86956 Mdot
.61688 .79357 Mdot
.15131 .62957 Mdot
.61868 .17973 Mdot
.08932 .15346 Mdot
.38686 .81051 Mdot
.80897 .83163 Mdot
.43169 .42006 Mdot
.7346 .30938 Mdot
.34782 .19599 Mdot
.1775 .3435 Mdot
.48769 .33029 Mdot
.40281 .44663 Mdot
.19038 .70181 Mdot
.90272 .31365 Mdot
.86179 .56082 Mdot
.62754 .51177 Mdot
.86679 .82339 Mdot
.70026 .46547 Mdot
.14811 .11046 Mdot
.94991 .88441 Mdot
.31282 .85057 Mdot
.83595 .81238 Mdot
.24014 .65153 Mdot
.86102 .5898 Mdot
.1699 .84192 Mdot
.93271 .32294 Mdot
.43732 .30247 Mdot
.20686 .54658 Mdot
.70793 .57289 Mdot
.79048 .84183 Mdot
.97134 .16144 Mdot
.45176 .96754 Mdot
.96017 .57787 Mdot
.65203 .23319 Mdot
.76216 .38879 Mdot
.39333 .83796 Mdot
.98058 .46641 Mdot
.49183 .48353 Mdot
.22585 .29456 Mdot
.61986 .64264 Mdot
.9304 .75007 Mdot
.78962 .20269 Mdot
.88358 .36205 Mdot
.48695 .98924 Mdot
.19697 .41532 Mdot
.039 .21759 Mdot
.41019 .20421 Mdot
.24646 .25984 Mdot
.59006 .99544 Mdot
.80082 .09458 Mdot
.48738 .66067 Mdot
.23866 .15908 Mdot
.84512 .70022 Mdot
.58877 .44607 Mdot
.71033 .55017 Mdot
.09277 .07802 Mdot
.90784 .25903 Mdot
.09524 .7316 Mdot
.1832 .98472 Mdot
.44703 .15662 Mdot
.48681 .14714 Mdot
.99126 .61899 Mdot
.21483 .65108 Mdot
.75212 .17656 Mdot
.52494 .0631 Mdot
.19037 .97506 Mdot
.28877 .53615 Mdot
.13433 .97842 Mdot
.49022 .00922 Mdot
.01425 .03029 Mdot
.6667 .18491 Mdot
.50525 .86271 Mdot
.7281 .89563 Mdot
.87036 .18693 Mdot
.9635 .97945 Mdot
.30594 .26315 Mdot
.57436 .24159 Mdot
.18659 .35311 Mdot
.57941 .46265 Mdot
.24442 .19931 Mdot
.01941 .2539 Mdot
.88485 .05276 Mdot
.51828 .10557 Mdot
.97176 .68777 Mdot
.34586 .41433 Mdot
.95742 .55469 Mdot
.59057 .4126 Mdot
.0431 .27586 Mdot
.43449 .0151 Mdot
.81781 .91937 Mdot
.45928 .86471 Mdot
.73529 .10675 Mdot
.17399 .43745 Mdot
.96744 .46551 Mdot
.94457 .28376 Mdot
.78978 .44827 Mdot
.29416 .66374 Mdot
.30123 .97451 Mdot
.8712 .15954 Mdot
.52936 .4618 Mdot
.55353 .62446 Mdot
.83273 .25641 Mdot
.3269 .17165 Mdot
.26549 .55646 Mdot
.26857 .83564 Mdot
.47777 .89692 Mdot
.70351 .71211 Mdot
.6179 .64005 Mdot
.00447 .02918 Mdot
.85255 .66882 Mdot
.13022 .87823 Mdot
.90867 .94666 Mdot
.71634 .51751 Mdot
.37075 .94921 Mdot
.31912 .8673 Mdot
.13849 .27934 Mdot
.67872 .16969 Mdot
.4114 .47388 Mdot
.93024 .66911 Mdot
.73983 .48361 Mdot
.05835 .60895 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo0_l0000>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo000Nooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo
0_l0000>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02Oooool2o`0000;ooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool00_ooool2o`0000Wooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0J_ooool2o`000003ooooool0003o000001?ooooo0ol0000Fooooo`;o00004Ooo
ool2o`0003?ooooo0_l00004ooooo`;o00006oooool2o`0001gooooo0_l0000Pooooo`007_ooool0
0ol0003oooooooooo`1?ooooo`;o000000?oooooo`000?l000006Oooool2o`0001?ooooo0ol0000F
ooooo`;o00004Oooool2o`0003?ooooo0_l00004ooooo`;o0000>_ooool2o`00023ooooo000Noooo
o`03o`000?oooooooooo04Kooooo0_l00007ooooo`;o000000?oooooo`000?l00000=Oooool2o`00
02?ooooo0_l0001?ooooo`;o0000A_ooool001kooooo00?o0000ooooooooool09_ooool2o`0001ko
oooo0_l0000mooooo`;o00000_ooool2o`0001cooooo0_l00005ooooo`;o0000Coooool2o`0004Ko
oooo000Nooooo`03o`000?oooooooooo02Kooooo0_l0000aooooo`;o00003Oooool2o`0001_ooooo
0_l0000Pooooo`;o0000:oooool2o`0001cooooo0_l0000Uooooo`;o0000;?ooool001kooooo00?o
0000ooooooooool0@_ooool2o`0001Gooooo0_l00002ooooo`;o00002Oooool2o`0001Cooooo0_l0
000`ooooo`;o00007?ooool2o`0000Cooooo0_l0000Looooo`;o00006?ooool2o`0000_ooooo0_l0
000/ooooo`007_ooool00ol0003oooooooooo`12ooooo`;o00006Oooool2o`0000Sooooo0ol0000D
ooooo`;o0000<?ooool2o`0000oooooo0_l00009ooooo`Co0000??ooool2o`0003Wooooo000Noooo
o`;o00000_ooool2o`0006Cooooo0ol0000Xooooo`;o0000;Oooool2o`0000Wooooo0_l0001ioooo
o`007_ooool2o`0000;ooooo0_l0000;ooooo`;o0000P_ooool2o`000;?ooooo000Nooooo`03o`00
0?oooooooooo00kooooo0_l0000Zooooo`;o0000P_ooool2o`0000;ooooo0_l00023ooooo`007_oo
ool00ol0003oooooooooo`0:ooooo`;o0000;_ooool2o`0008;ooooo0_l00002ooooo`;o0000<_oo
ool2o`0004Kooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o0000?Oooool2
o`0006_ooooo0_l0000nooooo`;o0000A_ooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo
027ooooo0_l0000Vooooo`;o0000>_ooool2o`0001;ooooo0_l0000Kooooo`;o0000Soooool001ko
oooo00?o0000ooooooooool08Oooool2o`00043ooooo0_l0000Pooooo`;o00004_ooool2o`0004So
oooo0_l0001Rooooo`007_ooool2o`0003cooooo0_l0000Vooooo`;o0000?_ooool2o`0001oooooo
0_l0000Jooooo`;o000000?oooooo`000?l000006Oooool2o`0001cooooo0_l0000Yooooo`007_oo
ool00ol0003oooooooooo`0kooooo`;o0000I_ooool2o`0001oooooo0_l0000Jooooo`;o00001?oo
ool2o`0001Kooooo0_l0000<ooooo`;o00003_ooool2o`0002Wooooo000Nooooo`03o`000?oooooo
oooo02?ooooo0_l0001_ooooo`;o0000D?ooool2o`0002Cooooo0_l0000Aooooo`;o00009_ooool0
01kooooo00?o0000ooooooooool08oooool2o`0006oooooo0_l0000Tooooo`;o0000Hoooool2o`00
02Kooooo000Nooooo`03o`000?oooooooooo09;ooooo0_l0000Cooooo`;o00004Oooool2o`0008_o
oooo000Nooooo`03o`000?oooooooooo04Sooooo0_l00018ooooo`;o00004oooool2o`0009kooooo
000Nooooo`03o`000?oooooooooo04Sooooo0_l00013ooooo`;o0000^?ooool001kooooo00?o0000
ooooooooool0Foooool2o`00033ooooo0_l0000?ooooo`;o0000:oooool2o`0006_ooooo0_l0000=
ooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o0000<oooool2o`0000[ooooo0_l00011oooo
o`;o00003Oooool2o`0000Cooooo0_l0000Fooooo`;o0000Joooool2o`0000gooooo000Nooooo`03
o`000?oooooooooo01[ooooo0_l0000cooooo`;o0000G?ooool2o`0000Cooooo0_l0002Booooo`00
7_ooool00ol0003oooooooooo`0Rooooo`;o0000SOooool2o`0009Cooooo000Nooooo`03o`000?oo
oooooooo02;ooooo0_l00009ooooo`;o0000Aoooool2o`0000_ooooo0_l0000<ooooo`;o00007_oo
ool2o`0008Oooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`0]ooooo`;o0000Aoooool2
o`0000_ooooo0_l0000<ooooo`;o00009_ooool2o`0005[ooooo0_l0000Sooooo`;o00002oooool0
01kooooo00?o0000ooooooooool0Loooool2o`00047ooooo0_l000000ooooooo0000o`00001Joooo
o`;o0000<?ooool001kooooo00?o0000ooooooooool02?ooool2o`0001Kooooo0_l0001Aooooo`;o
0000@Oooool2o`0004Sooooo0_l0000Zooooo`;o00002?ooool2o`0000Oooooo0_l00006ooooo`00
7_ooool00ol0003oooooooooo`08ooooo`;o00005_ooool2o`0000kooooo0_l0000Cooooo`;o0000
^Oooool2o`0002[ooooo0_l00008ooooo`;o00001oooool2o`0000Kooooo000Nooooo`;o0000<Ooo
ool2o`0001?ooooo0_l0000Kooooo`;o0000fOooool2o`0000Sooooo000Nooooo`03o`000?oooooo
oooo06;ooooo0_l00010ooooo`;o00007Oooool2o`0004gooooo0_l0000Yooooo`;o00002?ooool0
01kooooo00?o0000ooooooooool0;?ooool2o`0007Kooooo0_l0000Mooooo`;o00009_ooool2o`00
02Gooooo0_l0000=ooooo`;o00000oooool2o`0001oooooo000Nooooo`03o`000?oooooooooo02co
oooo0_l0001kooooo`?o00000oooool2o`00027ooooo0_l00009ooooo`;o00003?ooool2o`0003Co
oooo0_l00003ooooo`;o00007oooool001kooooo00?o0000ooooooooool0;?ooool2o`0007_ooooo
0ol00003ooooo`;o00001?ooool2o`0001_ooooo0_l00009ooooo`;o00005_ooool2o`00053ooooo
000Nooooo`03o`000?oooooooooo05[ooooo0_l0001Iooooo`;o0000?_ooool2o`00053ooooo000N
ooooo`03o`000?oooooooooo02Oooooo0_l0000aooooo`;o0000Q?ooool2o`0006Gooooo000Noooo
o`03o`000?oooooooooo01?ooooo0_l0000Booooo`;o0000M_ooool2o`0003oooooo0_l0001Joooo
o`;o00002Oooool001kooooo00?o0000ooooooooool04oooool2o`0001cooooo0_l0001Gooooo`;o
00004oooool2o`0009_ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`0aooooo`;o0000
Eoooool2o`0003kooooo0_l0000;ooooo`;o00009_ooool2o`0000[ooooo0_l0000/ooooo`;o0000
3?ooool001kooooo00?o0000ooooooooool0>Oooool2o`00043ooooo0_l0001=ooooo`;o00002ooo
ool2o`0002Kooooo0_l0000:ooooo`;o0000;?ooool2o`0000cooooo000Nooooo`03o`000?oooooo
oooo01cooooo0_l0000?ooooo`;o00002_ooool2o`00043ooooo0_l0002Xooooo`;o00008?ooool0
01kooooo00?o0000ooooooooool07?ooool2o`0000oooooo0_l0000Wooooo`;o0000`?ooool2o`00
00_ooooo0_l00005ooooo`;o00006Oooool001kooooo00?o0000ooooooooool0E_ooool2o`000<3o
oooo0_l0000;ooooo`;o00001Oooool2o`0001Wooooo000Nooooo`03o`000?oooooooooo0:cooooo
0_l0001gooooo`;o00008?ooool001kooooo00?o0000ooooooooool0V_ooool2o`00013ooooo0_l0
000=ooooo`;o00000oooool2o`0001Wooooo0_l00018ooooo`;o00008?ooool001kooooo0_l0002K
ooooo`;o00007oooool2o`0000?ooooo0_l0000Iooooo`;o0000J_ooool001kooooo00?o0000oooo
ooooool06Oooool2o`0003Sooooo0_l0002^ooooo`;o00001Oooool2o`0003_ooooo000Nooooo`03
o`000?oooooooooo01Wooooo0_l00007ooooo`;o0000;oooool2o`0003Sooooo0_l0000looooo`;o
00008_ooool2o`0001;ooooo0_l00005ooooo`;o0000>oooool001kooooo00?o0000ooooooooool0
8_ooool2o`0002Gooooo0_l00012ooooo`;o0000??ooool2o`0000?ooooo0_l0000Mooooo`;o0000
9_ooool2o`0002kooooo000Nooooo`03o`000?oooooooooo04Wooooo0_l0000Fooooo`;o0000KOoo
ool2o`0004Gooooo0_l0000Oooooo`;o00003Oooool001kooooo00?o0000ooooooooool0HOooool2
o`00013ooooo0_l0000Uooooo`;o0000W?ooool2o`0000gooooo000Nooooo`03o`000?oooooooooo
01_ooooo0_l0001Fooooo`;o00009Oooool2o`0003gooooo0_l0001/ooooo`007_ooool00ol0003o
ooooooooo`0Kooooo`;o0000>_ooool2o`0000gooooo0_l0000Hooooo`;o0000Eoooool2o`0001;o
oooo0_l000000ooooooo0000o`00001Eooooo`007_ooool00ol0003oooooooooo`1Gooooo`;o0000
3Oooool2o`0001Sooooo0_l0001[ooooo`;o000000?oooooo`000?l00000;?ooool2o`0002Oooooo
000Nooooo`03o`000?oooooooooo0<Gooooo0_l0000Yooooo`;o0000;?ooool2o`0000Sooooo0_l0
000Booooo`;o00002Oooool001kooooo00?o0000ooooooooool04?ooool2o`000;?ooooo0_l0001I
ooooo`;o00001_ooool2o`0001;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`0@oooo
o`;o00003?ooool2o`0005Cooooo0_l0000Kooooo`;o0000@_ooool2o`0004Wooooo0_l0000Uoooo
o`007_ooool00ol0003oooooooooo`0Nooooo`;o00006oooool2o`0002gooooo0_l00008ooooo`;o
00006oooool2o`0001Wooooo0_l0000Wooooo`;o0000@?ooool2o`0002kooooo000Nooooo`03o`00
0?oooooooooo00Cooooo0_l0000eooooo`;o00001oooool2o`0002Cooooo0_l0000<ooooo`;o0000
<_ooool2o`0000Gooooo0_l0000dooooo`;o0000;?ooool2o`0002kooooo0003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo00Cooooo
0_l0000nooooo`;o000000?oooooo`000?l00000;oooool2o`0000Wooooo0_l0000^ooooo`;o0000
=?ooool2o`0000Gooooo0_l0001Eooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`17ooooo`;o
00009?ooool2o`0001Cooooo0_l0001[ooooo`;o0000EOooool000?ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0000Mooooo`;o0000;?ooool2o`00023o
oooo0_l00007ooooo`;o0000coooool000?ooooo00Go0000ooooooooooooooooo`00000=ooooo`03
oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool07Oooool2o`0002cooooo0_l0000Iooooo`;o
00003_ooool2o`0000Wooooo0_l0001jooooo`;o0000B?ooool000?ooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0Aoooool2o`0001go
oooo0_l0000>ooooo`;o00002Oooool2o`00077ooooo0_l00007ooooo`;o0000:_ooool2o`0000So
oooo0_l0000Booooo`000oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`17ooooo`;o0000Q_ooool2o`0002?ooooo0_l0000^ooooo`;o
00000oooool2o`0000Sooooo0_l0000Booooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo04Gooooo0ol0001;oooo
o`;o0000>_ooool2o`0005?ooooo0_l0000Qooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo04Gooooo0ol0001;
ooooo`;o00005oooool2o`0009Wooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0000Coooo
o`Co0000R_ooool2o`0001Kooooo0_l0000Eooooo`;o0000@_ooool2o`0000gooooo0_l0000Goooo
o`007_ooool00ol0003oooooooooo`09ooooo`;o00004oooool4o`0002Sooooo0_l0001hooooo`;o
00005Oooool2o`0002Wooooo0_l0000Gooooo`;o00003Oooool2o`0001Oooooo000Nooooo`03o`00
0?oooooooooo01Oooooo0_l0000aooooo`;o0000^_ooool2o`0001Oooooo0_l0000Vooooo`007_oo
ool00ol0003oooooooooo`0Gooooo`;o00001oooool2o`0002;ooooo0_l0001Qooooo`;o0000Looo
ool2o`0002Wooooo000Nooooo`03o`000?oooooooooo023ooooo0_l0000Rooooo`;o0000=_ooool2
o`0001oooooo0_l00007ooooo`?o0000BOooool2o`0002Sooooo0_l0000Gooooo`;o00004?ooool0
01kooooo00?o0000ooooooooool0=oooool2o`0004?ooooo0_l0000Oooooo`;o00001oooool2o`00
02Sooooo0_l0000Pooooo`;o00005_ooool2o`0002Wooooo0_l0000@ooooo`007_ooool00ol0003o
ooooooooo`0]ooooo`;o00002?ooool2o`0005?ooooo0_l00012ooooo`;o00003?ooool2o`0001co
oooo0_l0000<ooooo`;o0000>oooool001kooooo00?o0000ooooooooool09oooool2o`0000Cooooo
0_l0001Mooooo`;o0000??ooool2o`0001;ooooo0_l0000Iooooo`;o000000?oooooo`000?l00000
BOooool001kooooo00?o0000ooooooooool09oooool2o`0003?ooooo0_l0001Iooooo`;o00004Ooo
ool2o`0000Kooooo0_l0000Uooooo`;o00002Oooool2o`00047ooooo000Nooooo`03o`000?oooooo
oooo05cooooo0_l0000Dooooo`;o0000@oooool2o`0001Wooooo0_l0000`ooooo`;o0000@Oooool0
01kooooo00?o0000ooooooooool0L_ooool2o`0007Sooooo0_l0000Sooooo`;o0000=?ooool001ko
oooo0_l0002dooooo`;o0000=oooool2o`00023ooooo0_l000000ooooooo0000o`00000dooooo`00
7_ooool00ol0003oooooooooo`02ooooo`;o0000;_ooool2o`0007oooooo0_l0001Fooooo`;o0000
00?oooooo`000?l00000=oooool001kooooo00?o0000ooooooooool00_ooool2o`0002kooooo0_l0
001@ooooo`;o0000Aoooool2o`0003cooooo0_l0000Fooooo`;o00008_ooool001kooooo00?o0000
ooooooooool0C?ooool2o`0001Oooooo0_l0000Mooooo`;o0000Aoooool2o`0001[ooooo0_l0000h
ooooo`;o00008_ooool001kooooo00Co0000oooooooooooooooo0_l00019ooooo`;o00004Oooool2
o`0000Cooooo0_l0000Wooooo`;o0000;oooool2o`0002Sooooo0_l0000Tooooo`;o0000=_ooool0
01kooooo00Co0000oooooooooooooooo0_l0000Iooooo`;o00007oooool2o`00023ooooo0_l0000A
ooooo`;o00006_ooool2o`0002Sooooo0_l00005ooooo`;o0000C_ooool2o`0003Kooooo000Noooo
o`03o`000?oooooooooo01cooooo0_l0000Oooooo`;o00000_ooool2o`0002cooooo0_l000000ooo
oooo0000o`00000Hooooo`;o00005oooool2o`00017ooooo0_l0000>ooooo`;o0000;_ooool2o`00
04gooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l000000ooooooo0000o`00000Eooooo`;o
0000;?ooool2o`0001Gooooo0_l00004ooooo`;o00002?ooool2o`0000gooooo0_l0000Qooooo`;o
00005_ooool2o`0001Kooooo0_l0000Iooooo`;o0000<_ooool001kooooo00?o0000ooooooooool0
2_ooool2o`0001_ooooo0_l000000ooooooo0000o`00001Jooooo`;o00003_ooool2o`00027ooooo
0_l0000Uooooo`;o0000<Oooool2o`0003;ooooo000Nooooo`03o`000?oooooooooo00Gooooo0_l0
0003ooooo`;o00006oooool4o`0008kooooo0ol0000=ooooo`;o0000C?ooool2o`0002kooooo000N
ooooo`03o`000?oooooooooo00Gooooo0_l0000Pooooo`Co0000G_ooool2o`0002oooooo0_l00006
ooooo`;o00001Oooool2o`0004cooooo0_l0000Fooooo`;o00005_ooool001kooooo00?o0000oooo
ooooool08Oooool2o`0001gooooo0_l00017ooooo`;o00006_ooool2o`0001_ooooo0_l0000Xoooo
o`;o00000_ooool2o`0001?ooooo0_l0000Xooooo`;o00005_ooool001kooooo00?o0000oooooooo
ool01_ooool2o`0001Wooooo0_l0000Mooooo`;o000000?oooooo`000?l00000H?ooool2o`0004Go
oooo0_l00002ooooo`;o00004oooool2o`0000cooooo0_l0000booooo`007Oooool2o`0000Sooooo
0_l0000?ooooo`;o0000:_ooool2o`0002Cooooo0_l0002Xooooo`Co0000<?ooool001gooooo0_l0
000Iooooo`;o00005?ooool2o`0000[ooooo0_l0000:ooooo`;o00008_ooool2o`0008[ooooo0_l0
000Nooooo`;o0000<?ooool001kooooo00?o0000ooooooooool06_ooool2o`0000?ooooo0_l0000<
ooooo`;o00002_ooool2o`0000[ooooo0_l0002^ooooo`;o0000D?ooool001kooooo0_l0000;oooo
o`;o00003_ooool2o`0000?ooooo0_l00009ooooo`;o0000G_ooool2o`0003oooooo0_l0000Ooooo
o`;o00009oooool2o`00033ooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0000Nooooo`;o
0000:Oooool2o`0003;ooooo0ol0000>ooooo`;o00001?ooool2o`0002Wooooo0_l0000;ooooo`Co
00004?ooool2o`0001Wooooo0_l0000<ooooo`;o0000<?ooool001kooooo00?o0000ooooooooool0
EOooool2o`0000Gooooo0_l0000[ooooo`;o00003oooool2o`0000Cooooo0_l0000fooooo`Co0000
:oooool2o`0003kooooo000Nooooo`03o`000?oooooooooo01Sooooo0_l00012ooooo`;o00001Ooo
ool2o`0007[ooooo0_l0000:ooooo`;o0000F_ooool001kooooo00?o0000ooooooooool03Oooool2
o`0000Wooooo0_l00019ooooo`;o0000>_ooool2o`0003kooooo0_l0000:ooooo`;o0000=?ooool2
o`0002Cooooo000Nooooo`03o`000?oooooooooo00gooooo0_l0000Looooo`;o0000L_ooool2o`00
02_ooooo0_l0001Cooooo`;o00009?ooool001kooooo00?o0000ooooooooool0:oooool2o`0004ko
oooo0_l0000:ooooo`;o0000@oooool2o`0002oooooo0_l00018ooooo`007_ooool00ol0003ooooo
ooooo`1Xooooo`;o00004Oooool2o`0000[ooooo0_l0001dooooo`;o0000;?ooool2o`0001[ooooo
000Nooooo`03o`000?oooooooooo023ooooo0_l00016ooooo`;o0000I_ooool2o`0005Wooooo0_l0
000Jooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o0000J?ooool2o`0000kooooo0_l0000W
ooooo`;o00002oooool2o`0007Gooooo000Nooooo`03o`000?oooooooooo08[ooooo0_l0000;oooo
o`;o000000?oooooo`000?l000009oooool2o`0000Kooooo0_l0000Xooooo`;o0000:?ooool2o`00
02Kooooo000Nooooo`03o`000?oooooooooo03Kooooo0_l0001Oooooo`;o00006_ooool2o`0001Ko
oooo0_l0000Xooooo`;o0000:?ooool2o`0002Kooooo000Nooooo`03o`000?oooooooooo03Kooooo
0_l0001kooooo`;o0000T_ooool001kooooo00?o0000ooooooooool0Hoooool2o`0001Oooooo0_l0
002Iooooo`;o0000;_ooool001kooooo00?o0000ooooooooool03?ooool2o`0001Kooooo0_l0000@
ooooo`;o0000:oooool2o`0001Oooooo0_l0002Iooooo`;o0000;_ooool001kooooo00?o0000oooo
ooooool03?ooool2o`0001Kooooo0_l0000@ooooo`;o0000ooooool@ooooo`007_ooool2o`0001oo
oooo0_l0000Vooooo`;o00006oooool2o`0005Kooooo0_l00005ooooo`;o0000Poooool001kooooo
0_l0000Oooooo`;o00006Oooool2o`0000_ooooo0_l0000=ooooo`;o00003?ooool2o`0005Kooooo
0_l00005ooooo`;o0000Poooool001kooooo00?o0000ooooooooool0>Oooool2o`0001Gooooo0_l0
0003ooooo`;o00008Oooool2o`0002Oooooo0_l0001gooooo`;o0000:oooool001kooooo00?o0000
ooooooooool0D?ooool2o`0002Kooooo0_l0000Wooooo`;o0000Moooool2o`0002_ooooo000Noooo
o`03o`000?oooooooooo01Kooooo0_l0000Wooooo`?o0000Ooooool2o`0002oooooo0_l0000Woooo
o`;o0000:_ooool001kooooo00?o0000ooooooooool05_ooool2o`0002Oooooo0ol00007ooooo`;o
0000I_ooool2o`0000Cooooo0_l00008ooooo`;o00002?ooool2o`0002Gooooo0_l0000Wooooo`;o
0000:_ooool001kooooo00?o0000ooooooooool04Oooool2o`0001Oooooo0_l0000Mooooo`;o0000
I_ooool2o`0000Cooooo0_l0000Booooo`;o0000=_ooool2o`0004;ooooo000Nooooo`03o`000?oo
oooooooo017ooooo0_l0000Gooooo`;o0000[oooool2o`0002Kooooo0_l0000?ooooo`;o0000<Ooo
ool001kooooo00?o0000ooooooooool07_ooool2o`0003_ooooo0_l00013ooooo`;o0000;_ooool2
o`0000Wooooo0_l0000Oooooo`;o00005_ooool2o`0002Wooooo0_l00006ooooo`007_ooool00ol0
003oooooooooo`0Nooooo`;o0000>oooool2o`0004?ooooo0_l0000Qooooo`;o00002oooool2o`00
02[ooooo0_l0000nooooo`;o000000?oooooo`000?l000001_ooool001kooooo00?o0000oooooooo
ool06Oooool2o`0001cooooo0_l00017ooooo`;o0000@Oooool2o`0007Oooooo0_l00009ooooo`00
7_ooool00ol0003oooooooooo`0Iooooo`;o00007?ooool2o`0001Gooooo0_l0000Zooooo`;o0000
1?ooool2o`0002gooooo0_l0000Booooo`;o0000Moooool2o`0000Wooooo000Nooooo`03o`000?oo
oooooooo04kooooo0_l0000Looooo`;o000000?oooooo`000?l000002Oooool2o`0000?ooooo0_l0
00000ooooooo0000o`00000[ooooo`;o0000:oooool2o`0001Kooooo0_l00016ooooo`;o00002Ooo
ool001kooooo00?o0000ooooooooool0K?ooool2o`000003ooooool0003o000000kooooo0_l00000
0ooooooo0000o`00000;ooooo`;o0000<?ooool2o`0001Wooooo0_l0000Fooooo`;o00006Oooool2
o`0000?ooooo0_l0000aooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46
ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0cooooo`;o0000F_ooool2
o`0002cooooo0_l00002ooooo`;o00004_ooool2o`0003Sooooo0_l00003ooooo`;o00000_ooool2
o`0002Kooooo0_l00005ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05Oooool2o`0001cooooo0_l0001h
ooooo`Go00002oooool2o`0001Kooooo0_l00011ooooo`;o00003?ooool2o`0001Oooooo0ol00005
ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`?o00005Oooool2
o`0006oooooo0_l0000Uooooo`Go00008?ooool2o`0000;ooooo0_l0000Tooooo`;o0000:?ooool2
o`0001Oooooo0_l00006ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo00001oooool00ol0003oooooooooo`0?ooooo`;o0000MOooool2o`0004[ooooo0_l0
0002ooooo`;o00002_ooool2o`0001Sooooo0_l00010ooooo`;o00001oooool000?ooooo00Go0000
ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0
2oooool2o`0000;ooooo0_l0000^ooooo`;o00005Oooool2o`0008[ooooo0_l0001Jooooo`;o0000
1oooool000?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo
00Co0000ooooool0003o00002_ooool2o`0003;ooooo0_l0000Eooooo`;o0000U_ooool2o`0005Oo
oooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007ooooo`04
o`000?oooooo0000o`0004kooooo0_l0001Cooooo`?o00005Oooool2o`0000Cooooo0_l0000Yoooo
o`?o0000?_ooool2o`0001Oooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omg
MgOo0000ooooo`06ooooo`03o`000?oooooooooo03Oooooo0_l00003ooooo`;o00004Oooool2o`00
00Cooooo0_l0000Eooooo`;o00008oooool2o`0000oooooo1Ol0000Eooooo`;o00001?ooool2o`00
02Wooooo0_l0000oooooo`;o00005oooool001kooooo00?o0000ooooooooool0=oooool2o`0000?o
oooo0_l0000Gooooo`;o00000_ooool2o`00017ooooo0_l0000Sooooo`;o00003oooool2o`0007[o
oooo0_l0000;ooooo`;o00006_ooool001kooooo00?o0000ooooooooool08?ooool2o`0000Gooooo
0_l00003ooooo`;o0000:oooool2o`0002gooooo0_l0000Qooooo`;o0000I_ooool2o`0000Wooooo
0_l0000;ooooo`;o00006_ooool001kooooo00?o0000ooooooooool08?ooool2o`0000Gooooo0_l0
0003ooooo`;o0000F_ooool2o`0000Gooooo0_l0000Jooooo`;o0000I_ooool2o`0003;ooooo000N
ooooo`03o`000?oooooooooo05;ooooo0_l0000Pooooo`;o00006Oooool2o`0002?ooooo0_l0002A
ooooo`007_ooool00ol0003oooooooooo`0Eooooo`Co0000>Oooool2o`00023ooooo0_l0000noooo
o`;o0000;Oooool2o`0006;ooooo000Nooooo`03o`000?oooooooooo01Gooooo1?l0001Wooooo`;o
0000Foooool2o`0000Cooooo0_l0000Mooooo`;o0000@oooool001kooooo00?o0000ooooooooool0
=?ooool2o`0000Oooooo0_l0000Booooo`;o0000;Oooool2o`0001_ooooo0_l0000looooo`Co0000
8oooool2o`0003Cooooo1?l0000;ooooo`007_ooool00ol0003oooooooooo`0dooooo`;o00001ooo
ool2o`0001;ooooo0_l0001:ooooo`;o0000??ooool2o`0004Gooooo0_l0000Dooooo`Co000000?o
ooooo`000?l000002?ooool001kooooo00?o0000ooooooooool0<?ooool2o`0000Cooooo0_l0000h
ooooo`;o0000O?ooool2o`0003;ooooo0_l0000Iooooo`;o00002?ooool001kooooo00?o0000oooo
ooooool0<?ooool2o`0000Cooooo0_l0000hooooo`;o00001Oooool2o`0000Kooooo0_l0000joooo
o`;o00004oooool2o`0001cooooo0_l0001Gooooo`007_ooool00ol0003oooooooooo`1;ooooo`;o
0000:_ooool2o`0000Kooooo0_l0000Hooooo`;o00008?ooool2o`0001?ooooo0_l0000[ooooo`;o
0000B?ooool001kooooo0_l0001<ooooo`;o0000C?ooool2o`0005_ooooo0_l00005ooooo`;o0000
2?ooool2o`0003kooooo000Nooooo`03o`000?oooooooooo05?ooooo0_l00029ooooo`;o00005_oo
ool2o`0000oooooo0_l0000Fooooo`;o00009_ooool001kooooo00?o0000ooooooooool0Doooool3
o`0001_ooooo0_l0001[ooooo`;o0000?oooool2o`0002Kooooo000Nooooo`03o`000?oooooooooo
05Cooooo0_l0000Kooooo`;o0000=Oooool2o`0000kooooo0_l0000Aooooo`;o0000N_ooool001ko
oooo00?o0000ooooooooool0KOooool2o`0003Wooooo0_l0000>ooooo`;o00004Oooool2o`0000Ko
oooo0_l0000;ooooo`;o0000:oooool2o`0002Oooooo0_l00008ooooo`;o00001Oooool001kooooo
00?o0000ooooooooool08_ooool2o`0002Kooooo0_l0000Qooooo`;o0000I?ooool2o`0000_ooooo
0_l0000[ooooo`;o00009oooool2o`0000?ooooo0_l00003ooooo`;o00001Oooool001kooooo00?o
0000ooooooooool06Oooool2o`0000Oooooo0_l0000Pooooo`;o00001?ooool2o`0008Wooooo0_l0
000Iooooo`;o0000BOooool2o`0000[ooooo000Nooooo`04o`000?oooooo0000o`0000_ooooo0_l0
000;ooooo`;o0000:Oooool2o`0003cooooo0_l0001Aooooo`;o00006Oooool2o`0005Gooooo000N
ooooo`04o`000?oooooo0000o`0000_ooooo0_l0001dooooo`;o0000<?ooool2o`00097ooooo000N
ooooo`03o`000?oooooooooo03Cooooo0_l0000Wooooo`;o00002_ooool2o`0001oooooo0_l0000X
ooooo`;o0000AOooool2o`0004[ooooo000Nooooo`03o`000?oooooooooo03Cooooo0_l0000Woooo
o`;o00002_ooool2o`0000Kooooo0_l0000Gooooo`;o00004?ooool2o`0004kooooo0_l0000=oooo
o`;o0000B_ooool001kooooo00?o0000ooooooooool0??ooool2o`0001Gooooo0_l0000Looooo`;o
0000:Oooool2o`0003Wooooo0_l0000Cooooo`;o0000FOooool001kooooo00?o0000ooooooooool0
??ooool2o`0001Gooooo0_l00017ooooo`;o00002oooool2o`0002cooooo0_l0000Uooooo`;o0000
7?ooool2o`0002Wooooo000Nooooo`03o`000?oooooooooo03Sooooo0_l0001Rooooo`;o00002ooo
ool2o`0000Gooooo0_l0000Tooooo`;o00003_ooool2o`0001Kooooo0_l0000Looooo`;o0000:Ooo
ool001kooooo00?o0000ooooooooool0>?ooool2o`0002oooooo0_l0000mooooo`;o00001_ooool2
o`0002?ooooo0ol0000>ooooo`;o00003oooool2o`0002;ooooo0_l0000Zooooo`007_ooool00ol0
003oooooooooo`1>ooooo`;o00006Oooool2o`0003gooooo0_l00006ooooo`;o00008oooool2o`00
023ooooo0_l00003ooooo`;o00007Oooool2o`0002[ooooo000Mooooo`?o00005?ooool2o`0000[o
oooo0_l00003ooooo`;o0000:?ooool2o`000:[ooooo1?l00019ooooo`007Oooool2o`0001Gooooo
0_l0000:ooooo`;o00000oooool2o`00093ooooo0_l00012ooooo`;o00005oooool2o`0003;ooooo
000Nooooo`03o`000?oooooooooo02kooooo0_l0000Dooooo`;o0000L?ooool2o`00033ooooo0_l0
000<ooooo`;o00006oooool2o`0003;ooooo000Nooooo`03o`000?oooooooooo02kooooo0_l0000;
ooooo`Co00001Oooool2o`0001kooooo0_l0000=ooooo`;o0000Doooool2o`0001kooooo0_l0000<
ooooo`;o0000Coooool001kooooo00?o0000ooooooooool05?ooool2o`0002Gooooo1?l0000Uoooo
o`;o00003Oooool2o`0005?ooooo0_l0000Eooooo`;o00008?ooool2o`0004Cooooo000Nooooo`03
o`000?oooooooooo01Cooooo0_l0000=ooooo`;o0000?_ooool2o`0005gooooo0_l0000=ooooo`;o
00003?ooool2o`0000Cooooo0_l00007ooooo`;o00004Oooool2o`0000[ooooo0_l0000hooooo`00
7_ooool00ol0003oooooooooo`0Sooooo`;o0000?_ooool2o`0005gooooo0_l0000=ooooo`;o0000
4_ooool2o`0000Oooooo0_l0000Dooooo`;o00001oooool2o`0003Sooooo000Nooooo`03o`000?oo
oooooooo03Oooooo0_l0000Kooooo`;o0000AOooool2o`0006Oooooo0_l00011ooooo`007_ooool0
0ol0003oooooooooo`0gooooo`;o00006oooool2o`0004Gooooo0_l0000Wooooo`;o00007?ooool2
o`0004_ooooo0_l0000Fooooo`007_ooool00ol0003oooooooooo`02o`0008;ooooo0_l0000noooo
o`;o00005?ooool2o`0000Kooooo0_l0001;ooooo`;o00005_ooool001kooooo00?o0000oooooooo
ool00_l00022ooooo`;o0000;oooool2o`0002?ooooo0_l0001Gooooo`;o00004_ooool001kooooo
00?o0000ooooooooool0F_ooool2o`0002Kooooo0_l00007ooooo`;o0000:?ooool2o`00043ooooo
0_l0000jooooo`;o00004_ooool001kooooo00?o0000ooooooooool0F_ooool2o`0002Kooooo0_l0
0007ooooo`;o00001oooool2o`00067ooooo0_l0000hooooo`;o00005?ooool001kooooo00?o0000
ooooooooool0Foooool2o`0002_ooooo0_l0000:ooooo`;o00004_ooool2o`0000Wooooo0_l0000n
ooooo`;o0000??ooool2o`0000Cooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`0`oooo
o`;o00004oooool2o`0001Cooooo0_l0000Zooooo`?o00007_ooool2o`0000Wooooo0_l0000noooo
o`;o0000@_ooool2o`0000kooooo000Nooooo`03o`000?oooooooooo033ooooo0_l00007ooooo`;o
00001?ooool2o`0000Cooooo0_l0000hooooo`;o00001_ooool2o`0002[ooooo0_l0000Yooooo`;o
0000Ioooool001kooooo0_l0000jooooo`;o00001?ooool2o`0003Wooooo0_l00003ooooo`;o0000
GOooool2o`0000?ooooo0_l0001Rooooo`007_ooool00ol0003oooooooooo`1Dooooo`;o00009?oo
ool2o`0004oooooo0_l0000>ooooo`;o00001_ooool2o`0004kooooo0_l0000Booooo`007_ooool0
0ol0003oooooooooo`0fooooo`;o00006_ooool4o`0006Sooooo0_l0000;ooooo`;o00003_ooool2
o`0005Kooooo0_l0000Booooo`007_ooool00ol0003oooooooooo`0fooooo`;o00005oooool2o`00
0003ooooool0003o000001Wooooo0_l0001?ooooo`;o0000E?ooool2o`00037ooooo000Nooooo`03
o`000?oooooooooo04oooooo0_l00009ooooo`;o00004Oooool2o`0007Kooooo0_l0000]ooooo`;o
0000<Oooool001kooooo00?o0000ooooooooool0>_ooool2o`0001?ooooo0_l00009ooooo`;o0000
0_ooool2o`0002?ooooo0_l0001Pooooo`;o00006?ooool2o`0004Kooooo000Nooooo`03o`000?oo
oooooooo03[ooooo0_l00003ooooo`;o00006Oooool2o`0000;ooooo0_l0000Sooooo`;o0000@ooo
ool2o`0002Oooooo0_l0000<ooooo`;o00001oooool2o`0003gooooo000Nooooo`03o`000?oooooo
oooo03oooooo0_l0000kooooo`;o0000B_ooool2o`0001Sooooo0_l0000=ooooo`;o00005Oooool2
o`0003gooooo000Nooooo`03o`000?oooooooooo06;ooooo0_l0000Hooooo`;o0000:?ooool2o`00
03[ooooo0_l0001Sooooo`007_ooool00ol0003oooooooooo`16ooooo`;o00006_ooool2o`0004;o
oooo0_l0000hooooo`;o0000A?ooool2o`0000cooooo0_l0000Aooooo`007_ooool00ol0003ooooo
ooooo`04ooooo`;o0000@?ooool2o`0000_ooooo0_l00005ooooo`;o0000Q?ooool2o`0004Cooooo
0_l0000<ooooo`;o00004Oooool001kooooo00?o0000ooooooooool01?ooool2o`0004gooooo0_l0
0005ooooo`;o0000joooool001kooooo00?o0000ooooooooool0l_ooool2o`0005?ooooo000Noooo
o`03o`000?oooooooooo00Gooooo0_l0003[ooooo`;o00008?ooool2o`00037ooooo0003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006
ooooo`03o`000?oooooooooo00Gooooo0_l0003@ooooo`;o0000:Oooool2o`0000cooooo0_l00002
ooooo`;o0000<Oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0eoooool2o`0002Wooooo0_l0
000<ooooo`;o0000=Oooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oo
ooooooooooooool000001_ooool3o`0008Gooooo0_l00003ooooo`;o0000QOooool2o`0003Cooooo
0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Ko
oooo00?o0000ooooooooool01?ooool2o`00017ooooo0_l0001/ooooo`;o00000oooool2o`0008Go
oooo0_l0000dooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0
003o410@olc<c006ooooo`03o`000?oooooooooo00Cooooo0_l0000@ooooo`?o0000>Oooool2o`00
06?ooooo0_l0001Rooooo`;o0000:_ooool000?ooooo00Go410@oooooooooooooooooa0@400;oooo
o`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool03oooool2o`0000Gooooo0ol0000ioooo
o`;o0000Hoooool2o`0000Sooooo0_l0001Hooooo`;o0000:_ooool000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool03oooool2o`00
04Cooooo0_l00008ooooo`;o0000H?ooool2o`0008Cooooo0003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo04Cooooo0_l0000?
ooooo`;o00002?ooool2o`0005_ooooo0_l00011ooooo`;o000000?oooooo`000?l000008?ooool2
o`00027ooooo000Nooooo`03o`000?oooooooooo04Cooooo0_l0000Nooooo`;o0000E_ooool2o`00
03Kooooo0_l00009ooooo`;o000000?oooooo`000?l000006?ooool2o`0000Kooooo0_l0000Hoooo
o`;o00001oooool001kooooo00?o0000ooooooooool0I?ooool2o`0007Wooooo0_l0000Cooooo`;o
00009_ooool2o`00023ooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`0jooooo`;o0000
:?ooool2o`0000Kooooo0_l0000?ooooo`;o0000<Oooool2o`0002gooooo0_l00013ooooo`;o0000
8Oooool001kooooo00?o0000ooooooooool0>_ooool2o`00033ooooo0_l00003ooooo`;o00002_oo
ool2o`0000kooooo0_l0000Fooooo`;o00002Oooool2o`0002cooooo0_l0000Looooo`;o00009_oo
ool2o`00027ooooo000Nooooo`03o`000?oooooooooo02gooooo0_l0000/ooooo`;o00005?ooool2
o`0001[ooooo0_l0000Cooooo`;o000000?oooooo`000?l00000=oooool2o`0001cooooo0_l00019
ooooo`007_ooool00ol0003oooooooooo`0]ooooo`;o0000;?ooool2o`0004Gooooo0_l0000^oooo
o`?o00005?ooool2o`0005cooooo000Nooooo`03o`000?oooooooooo09[ooooo0_l0000:ooooo`;o
00005_ooool2o`0001;ooooo0ol000000ooooooo0000o`000006ooooo`;o00002Oooool2o`0001ko
oooo0_l0000looooo`007_ooool00ol0003oooooooooo`29ooooo`Co00003Oooool2o`0000[ooooo
0ol0000Eooooo`;o00001Oooool2o`0000oooooo0_l00006ooooo`;o00006Oooool2o`000003oooo
ool0003o000000_ooooo0_l0000looooo`007_ooool00ol0003oooooooooo`0/ooooo`;o00005Ooo
ool2o`0003cooooo0_l00006ooooo`Co00006_ooool2o`0001cooooo0_l0000booooo`;o000000?o
ooooo`000?l00000BOooool001kooooo00?o0000ooooooooool07Oooool2o`0000gooooo0ol0000D
ooooo`;o0000??ooool2o`0004;ooooo0_l00020ooooo`007_ooool01?l0003oooooo`000?l0000L
ooooo`;o00003_ooool2o`00017ooooo0_l0000Dooooo`;o00001oooool2o`0001?ooooo0_l0001D
ooooo`;o00006_ooool2o`0000oooooo0_l00005ooooo`;o0000Aoooool001kooooo1?l0000Goooo
o`;o000000?oooooo`000?l000008oooool4o`0000Kooooo0_l0000:ooooo`;o00001oooool2o`00
01?ooooo0_l0001Dooooo`;o00005oooool2o`000003ooooool0003o000000oooooo0_l00005oooo
o`;o0000Aoooool001kooooo00?o0000ooooooooool06?ooool2o`000003ooooool0003o000002Go
oooo0_l00006ooooo`;o0000E?ooool4o`0003oooooo0_l0001Rooooo`007Oooool2o`0008[ooooo
0_l0000Fooooo`Co00002oooool2o`0000;ooooo0_l00029ooooo`;o00001oooool001gooooo0_l0
002:ooooo`;o00004?ooool2o`0001?ooooo0_l00002ooooo`;o0000ROooool2o`000003ooooool0
003o000000Cooooo000Nooooo`03o`000?oooooooooo02oooooo0_l0000=ooooo`;o00007?ooool2
o`0003cooooo0_l0002Uooooo`;o00001?ooool001kooooo00?o0000ooooooooool00oooool2o`00
02[ooooo0_l0000=ooooo`;o00007?ooool2o`0001Sooooo0_l0001_ooooo`;o0000:?ooool2o`00
03Cooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0000Zooooo`;o0000AOooool2o`0006oo
oooo0_l0000Xooooo`;o00005oooool2o`0001_ooooo000Nooooo`03o`000?oooooooooo0>Kooooo
0_l00012ooooo`;o00006oooool001kooooo00?o0000ooooooooool0i_ooool2o`0002Gooooo0_l0
000hooooo`007_ooool00ol0003oooooooooo`0`ooooo`;o0000@oooool2o`0002gooooo0_l0001W
ooooo`;o0000>?ooool001kooooo00?o0000ooooooooool0<?ooool3o`0000kooooo0_l0000boooo
o`;o0000;Oooool2o`000:7ooooo000Nooooo`03o`000?oooooooooo037ooooo0_l0000>ooooo`;o
0000;?ooool2o`0004?ooooo0_l0002Aooooo`007_ooool00ol0003oooooooooo`1Rooooo`;o0000
2oooool4o`0003Wooooo0_l00006ooooo`;o00001Oooool2o`0007_ooooo0_l0000=ooooo`007_oo
ool00ol0003oooooooooo`0^ooooo`;o0000<_ooool2o`0000gooooo0_l0000iooooo`;o00003Ooo
ool2o`0006[ooooo0_l0000?ooooo`;o00003Oooool001kooooo00?o0000ooooooooool0;_ooool2
o`00013ooooo0_l0003Uooooo`;o00007_ooool001kooooo00?o0000ooooooooool0:?ooool2o`00
01Kooooo0_l0000gooooo`;o00004_ooool2o`000;Sooooo000Nooooo`;o0000:Oooool2o`00013o
oooo0_l00003ooooo`;o00008_ooool2o`0001Cooooo0_l0000Booooo`;o0000P?ooool2o`0003Ko
oooo000Nooooo`03o`000?oooooooooo00;o0000>?ooool2o`0000?ooooo0_l0000Rooooo`;o0000
:_ooool2o`0007kooooo0_l00004ooooo`;o0000<?ooool001kooooo00?o0000ooooooooool00_l0
001Booooo`;o0000=Oooool2o`0000;ooooo0_l00002ooooo`;o0000;_ooool2o`0002Cooooo0_l0
0005ooooo`;o00008oooool2o`0000;ooooo0_l0000/ooooo`007_ooool00ol0003oooooooooo`1D
ooooo`;o0000=Oooool2o`0000Kooooo0_l0000^ooooo`;o00009?ooool2o`0000Gooooo0_l0000W
ooooo`;o0000;?ooool001kooooo00?o0000ooooooooool0;Oooool2o`0009;ooooo0_l00006oooo
o`;o00004?ooool2o`0000Cooooo0_l0000@ooooo`;o00008_ooool2o`0000?ooooo0_l0000Coooo
o`;o00005?ooool001kooooo00?o0000ooooooooool0;Oooool2o`0006kooooo0_l0000Gooooo`;o
00002Oooool2o`0000Kooooo0_l00009ooooo`;o00001Oooool2o`0000Cooooo0_l0000@ooooo`;o
00008_ooool2o`0000?ooooo0_l0000Cooooo`;o00005?ooool001kooooo00?o0000ooooooooool0
WOooool2o`0001Oooooo0_l0000Looooo`;o0000LOooool001kooooo00?o0000ooooooooool04ooo
ool2o`0001Wooooo0_l0000Vooooo`;o0000d?ooool2o`0001gooooo000Nooooo`03o`000?oooooo
oooo00[ooooo0_l00007ooooo`;o00005Oooool2o`0000;ooooo0_l0000Vooooo`;o0000d?ooool2
o`0001gooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0000Nooooo`;o0000:Oooool2o`00
04[ooooo0_l0002Tooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o00003Oooool2o`0003So
oooo0_l0001:ooooo`;o0000ROooool2o`0001Wooooo000Nooooo`03o`000?oooooooooo00cooooo
0_l0000=ooooo`;o0000Woooool2o`0000[ooooo0_l00018ooooo`;o00006?ooool2o`000003oooo
ool0003o000001Kooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0001jooooo`;o00004ooo
ool2o`00023ooooo0_l0000:ooooo`;o00009_ooool2o`00023ooooo0_l0000Kooooo`;o00005_oo
ool001kooooo00?o0000ooooooooool02Oooool2o`0001cooooo0_l0001Looooo`;o00004oooool2
o`0005Cooooo0_l0000fooooo`;o00007Oooool001kooooo00?o0000ooooooooool02Oooool2o`00
01cooooo0_l0000jooooo`;o0000`oooool2o`0001gooooo000Nooooo`03o`000?oooooooooo01Go
oooo0_l0001<ooooo`;o0000?_ooool2o`0007gooooo0_l0000Sooooo`007_ooool2o`0001Kooooo
0_l0000Hooooo`;o0000??ooool2o`0003Cooooo0_l0000aooooo`;o00002_ooool2o`0000_ooooo
0_l0000aooooo`;o00001_ooool2o`0001_ooooo000Nooooo`03o`000?oooooooooo01gooooo0_l0
000@ooooo`;o0000??ooool2o`0006Oooooo0_l0000:ooooo`;o00002oooool2o`0003Wooooo0_l0
000Eooooo`;o00001?ooool001kooooo00?o0000ooooooooool07Oooool2o`000?oooooo7?ooool2
o`0000Gooooo0_l00004ooooo`007_ooool00ol0003oooooooooo`16ooooo`;o00004Oooool2o`00
0=oooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o0000=Oooool2o`00017o
oooo0_l00002ooooo`;o00008oooool2o`0007cooooo0_l0000Zooooo`;o00006Oooool001kooooo
00?o0000ooooooooool03oooool2o`00027ooooo0_l0000Yooooo`;o00008oooool2o`0007cooooo
0_l0000Zooooo`;o00006Oooool001kooooo00?o0000ooooooooool0<_ooool2o`0003;ooooo0_l0
003Oooooo`007_ooool00ol0003oooooooooo`1Eooooo`;o00003oooool2o`0006cooooo0_l0000=
ooooo`;o0000H_ooool001kooooo00?o0000ooooooooool05oooool2o`0003cooooo0_l0000Ooooo
o`;o0000G?ooool2o`0000gooooo0_l0001=ooooo`?o00004_ooool001kooooo00?o0000oooooooo
ool05oooool2o`0005gooooo0_l00005ooooo`;o0000LOooool2o`00043ooooo0ol0000Booooo`00
7_ooool00ol0003oooooooooo`0[ooooo`;o00001Oooool2o`0004Wooooo1?l0001_ooooo`;o0000
EOooool001kooooo00?o0000ooooooooool0:oooool2o`0000Gooooo0_l0001;ooooo`Co0000a?oo
ool001kooooo00?o0000ooooooooool0E_ooool2o`0002Wooooo0_l00026ooooo`;o00006_ooool2
o`00023ooooo000Nooooo`03o`000?oooooooooo05Kooooo0_l0002aooooo`;o00006_ooool2o`00
023ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q
8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0<Cooooo0_l0001Uooooo`;o00006_ooool0
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonH
V9So8B4Q00Kooooo00?o0000ooooooooool0=oooool2o`0008_ooooo0_l0000Vooooo`;o0000?Ooo
ool2o`0001[ooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000000Kooooo0ol0000gooooo`;o00001Oooool2o`000:cooooo0_l00003ooooo`;o0000
5Oooool2o`0003gooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RH
oooooonHV9So<S8b00Kooooo00?o0000ooooooooool0?_ooool2o`0008Oooooo0_l0000>ooooo`;o
00006?ooool2o`0001Gooooo0_l0000mooooo`000oooool01Ol0003ooooooooooooooooo000000_o
oooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo07?ooooo0_l0000Ioooo
o`;o0000=oooool2o`0000kooooo0_l0001^ooooo`000oooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo07?ooooo0_l0000I
ooooo`;o0000]oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooookZj^_l000001_ooool00ol0003oooooooooo`05ooooo`;o0000@Oooool2o`0001Sooooo0_l0
000Fooooo`;o0000C_ooool2o`00043ooooo0_l0000iooooo`000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo00Gooooo
0_l0000;ooooo`;o00009_ooool2o`0000cooooo0_l0000Hooooo`;o00005_ooool2o`0004kooooo
0_l00010ooooo`;o00002oooool2o`0000gooooo0_l0000Mooooo`007_ooool00ol0003ooooooooo
o`0Booooo`;o00009_ooool2o`000=gooooo0_l00009ooooo`;o00000_ooool2o`0001gooooo000N
ooooo`03o`000?oooooooooo07Oooooo0_l0000cooooo`;o0000>_ooool2o`0003[ooooo0_l0000Q
ooooo`007_ooool00ol0003oooooooooo`0hooooo`;o0000?Oooool2o`0003?ooooo0_l0000Ioooo
o`;o00002?ooool2o`0001Gooooo0_l0000/ooooo`;o0000;oooool001kooooo00?o0000oooooooo
ool0>?ooool2o`0008gooooo0_l00008ooooo`;o00002oooool2o`0003Kooooo0_l0000_ooooo`00
7_ooool00ol0003oooooooooo`0eooooo`;o0000Yoooool2o`0002?ooooo0_l0000gooooo`;o0000
2Oooool001kooooo00?o0000ooooooooool0=Oooool2o`000<cooooo0_l0000gooooo`;o00002Ooo
ool001kooooo00?o0000ooooooooool03Oooool2o`0003gooooo0_l00005ooooo`;o00009oooool2
o`000<Wooooo000Nooooo`03o`000?oooooooooo00gooooo0_l0000mooooo`;o00001Oooool2o`00
02Oooooo0_l00021ooooo`;o0000A_ooool001kooooo00?o0000ooooooooool02Oooool2o`0002So
oooo0_l00038ooooo`Co00007oooool2o`0002Gooooo000Nooooo`03o`000?oooooooooo00Wooooo
0_l0000Kooooo`;o00002oooool2o`0002cooooo0_l00021ooooo`;o00005oooool2o`0000kooooo
0_l0000Aooooo`;o00009Oooool001kooooo00?o0000ooooooooool09_ooool2o`0003Gooooo0_l0
0002ooooo`;o0000POooool2o`0001Kooooo0_l0000?ooooo`;o00004_ooool2o`0002Cooooo000N
ooooo`;o0000G_ooool2o`0000?ooooo0_l0002Hooooo`;o00006Oooool2o`0000Sooooo0_l0000T
ooooo`007_ooool3o`0006;ooooo0_l00024ooooo`;o0000;Oooool2o`0002kooooo000Nooooo`?o
0000:oooool2o`0006Wooooo0_l0001@ooooo`;o0000GOooool001kooooo00?o0000ooooooooool0
:oooool2o`0006Wooooo0_l0002_ooooo`007_ooool00ol0003oooooooooo`2Aooooo`;o00003Ooo
ool2o`000:Gooooo000Nooooo`03o`000?oooooooooo03[ooooo0_l0000=ooooo`;o00006Oooool2
o`0002_ooooo0_l0000=ooooo`;o0000YOooool001kooooo00?o0000ooooooooool03Oooool2o`00
01;ooooo0_l0000>ooooo`;o00001oooool2o`0000gooooo0_l0000Iooooo`;o0000@_ooool2o`00
06gooooo0_l0000^ooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o00003?ooool2o`0000Co
oooo0_l0000>ooooo`;o0000MOooool2o`0006gooooo0_l0000^ooooo`007_ooool00ol0003ooooo
ooooo`0Kooooo`;o0000`Oooool2o`0000?ooooo0_l0001Rooooo`007_ooool00ol0003ooooooooo
o`0Vooooo`;o0000]_ooool2o`0000?ooooo0_l0000Oooooo`;o0000@Oooool001kooooo00?o0000
ooooooooool04_ooool2o`0001;ooooo0_l00011ooooo`;o00008oooool2o`0007Cooooo0_l0000M
ooooo`;o00004_ooool2o`0000kooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0001Eoooo
o`;o00008oooool3o`0006Gooooo0_l0000[ooooo`;o00003?ooool2o`0000Cooooo0_l0000>oooo
o`007_ooool00ol0003oooooooooo`0=ooooo`;o0000P?ooool2o`0006Gooooo0_l0000Iooooo`;o
00007_ooool2o`0001Cooooo000Nooooo`03o`000?oooooooooo00gooooo0_l00004ooooo`;o0000
ioooool2o`0001?ooooo0_l0000dooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o00008Ooo
ool2o`0002oooooo0_l00020ooooo`;o00004Oooool2o`0004Wooooo000Nooooo`03o`000?oooooo
oooo03Kooooo0_l0000_ooooo`;o00009oooool2o`0000Gooooo0_l0001@ooooo`;o00002oooool2
o`0004oooooo000Nooooo`;o00002oooool2o`0008Cooooo0_l00005ooooo`;o0000GOooool2o`00
04oooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0001eooooo`;o00005?ooool2o`00097o
oooo0_l0000Kooooo`007_ooool00ol0003oooooooooo`21ooooo`;o0000NOooool2o`0002cooooo
0_l0000Kooooo`007_ooool00ol0003oooooooooo`09ooooo`;o0000NOooool2o`0007Kooooo0_l0
0019ooooo`007_ooool00ol0003oooooooooo`02o`0000Oooooo0_l00005ooooo`;o0000L_ooool2
o`000<7ooooo000Nooooo`03o`000?oooooooooo00;o00003_ooool2o`0005cooooo0_l0001<oooo
o`;o0000ROooool001kooooo00?o0000ooooooooool0Doooool2o`0001Wooooo0_l0001<ooooo`;o
0000B?ooool2o`0003oooooo000Nooooo`03o`000?oooooooooo02kooooo0_l0000Sooooo`;o0000
/Oooool2o`0003oooooo000Nooooo`03o`000?oooooooooo01Sooooo0_l0000Dooooo`;o00001_oo
ool2o`0002kooooo0_l00029ooooo`;o00008?ooool2o`0003;ooooo000Nooooo`03o`000?oooooo
oooo01Sooooo0_l00003ooooo`?o00005_ooool2o`0002kooooo0_l0000Fooooo`;o00004oooool2
o`0005cooooo0_l0000Pooooo`;o0000<_ooool001kooooo00?o0000ooooooooool07Oooool3o`00
05kooooo0_l0000Cooooo`;o0000ZOooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo06Co
oooo0_l0000<ooooo`;o00000_ooool2o`0002Wooooo0_l0002Kooooo`;o00001oooool001kooooo
00?o0000ooooooooool0I?ooool2o`0000cooooo0_l00002ooooo`;o0000:Oooool2o`0003_ooooo
0_l0001Wooooo`007_ooool00ol0003oooooooooo`1Tooooo`;o0000N?ooool2o`0006Oooooo000N
ooooo`03o`000?oooooooooo02_ooooo0_l0000gooooo`;o0000;oooool2o`0005_ooooo0_l00013
ooooo`;o00003_ooool001kooooo00?o0000ooooooooool01Oooool2o`0002Cooooo0_l0001Xoooo
o`;o00004oooool2o`0004Kooooo0_l00008ooooo`;o00009Oooool2o`0001;ooooo0_l0000>oooo
o`007_ooool2o`0000Kooooo0_l00007ooooo`;o0000I?ooool2o`0003Cooooo0_l0001@ooooo`;o
00009Oooool2o`0002;ooooo000Nooooo`03o`000?oooooooooo00kooooo0_l0001Tooooo`;o0000
dOooool001kooooo00?o0000ooooooooool0V_ooool2o`0008Gooooo0_l0000Tooooo`007_ooool0
0ol0003oooooooooo`2Jooooo`;o0000QOooool2o`0002Cooooo000Nooooo`03o`000?oooooooooo
04Sooooo0_l0000Uooooo`;o0000[Oooool2o`0002Oooooo000Nooooo`03o`000?oooooooooo01go
oooo0_l0000Yooooo`;o00009Oooool2o`0002;ooooo0_l0000jooooo`;o0000COooool2o`0002Oo
oooo000Nooooo`03o`000?oooooooooo01gooooo0_l0001`ooooo`;o00000_ooool2o`0003[ooooo
0_l0001fooooo`007_ooool00ol0003oooooooooo`2?ooooo`;o00004Oooool2o`000:?ooooo000N
ooooo`03o`000?oooooooooo03[ooooo0_l0000Rooooo`;o0000@_ooool2o`0002Kooooo0_l0000e
ooooo`;o0000A?ooool001kooooo00?o0000ooooooooool0:?ooool2o`00013ooooo0_l0000Noooo
o`;o00000_ooool2o`0006[ooooo0_l0000eooooo`;o0000<_ooool2o`00013ooooo000Nooooo`03
o`000?oooooooooo02Sooooo0_l0000`ooooo`;o0000POooool2o`0005Kooooo0_l0000@ooooo`00
7_ooool00ol0003oooooooooo`0eooooo`Co0000Y?ooool2o`0002gooooo0_l0000iooooo`007_oo
ool00ol0003oooooooooo`0eooooo`Co0000@?ooool2o`0002Wooooo0_l00011ooooo`;o00008ooo
ool2o`0003Wooooo000Nooooo`03o`000?oooooooooo03Sooooo0_l0000oooooo`;o00007oooool2
o`0000Sooooo0_l0000eooooo`;o00000oooool2o`0000Gooooo0_l0000<ooooo`;o00005Oooool2
o`0002Wooooo0_l0000>ooooo`005?ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool2o`0002Wooooo0_l00009ooooo`;o0000H?ooool2o`0003oooooo0_l00003oooo
o`;o00003oooool2o`0000;ooooo0_l0000Oooooo`;o00007_ooool3o`0000kooooo000Fooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool2o`0002Wooooo0_l0002=ooooo`;o
0000<oooool2o`0002?ooooo0_l0000Jooooo`;o00000_ooool4o`0000gooooo000Fooooo`03o`00
0?oooooooooo00Cooooo1?l0000Xooooo`;o0000JOooool2o`0002Oooooo0_l0001dooooo`;o0000
1?ooool2o`0000gooooo000Fooooo`03o`000?oooooooooo00Cooooo0_l0000Zooooo`;o0000JOoo
ool2o`000;;ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000oooo
ooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Dooooo`03oeEE
EOmVIVKo00000?ooooooD_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.2485 .57592 Mdot
.91463 .68627 Mdot
.80604 .01336 Mdot
.19417 .58282 Mdot
.11575 .53899 Mdot
.86262 .97827 Mdot
.18468 .8284 Mdot
.21615 .67716 Mdot
.7603 .15838 Mdot
.10204 .0192 Mdot
.5954 .058 Mdot
.87985 .60178 Mdot
.8435 .53995 Mdot
.25833 .60276 Mdot
.48604 .32639 Mdot
.17113 .71493 Mdot
.45053 .92365 Mdot
.53492 .44898 Mdot
.82677 .97011 Mdot
.73852 .02713 Mdot
.58431 .12435 Mdot
.62414 .06123 Mdot
.68638 .98656 Mdot
.2482 .31217 Mdot
.67998 .2939 Mdot
.112 .35339 Mdot
.78167 .97551 Mdot
.59396 .39005 Mdot
.10517 .61543 Mdot
.27702 .34564 Mdot
.5526 .30904 Mdot
.24681 .49949 Mdot
.44732 .93299 Mdot
.13735 .12063 Mdot
.69726 .97095 Mdot
.11582 .58687 Mdot
.0983 .31495 Mdot
.39208 .1932 Mdot
.273 .97106 Mdot
.95791 .01056 Mdot
.10218 .38404 Mdot
.47866 .02805 Mdot
.25666 .52176 Mdot
.16764 .46754 Mdot
.57263 .44074 Mdot
.71241 .57538 Mdot
.95991 .24346 Mdot
.73253 .60737 Mdot
.35083 .55831 Mdot
.966 .44029 Mdot
.66484 .32058 Mdot
.27663 .50738 Mdot
.16328 .61211 Mdot
.99472 .37218 Mdot
.75957 .35344 Mdot
.65239 .27072 Mdot
.46035 .95153 Mdot
.00165 .69217 Mdot
.11385 .4278 Mdot
.06083 .6968 Mdot
.26149 .4681 Mdot
.6276 .76348 Mdot
.26018 .09957 Mdot
.06188 .26328 Mdot
.22835 .50133 Mdot
.3868 .09622 Mdot
.48615 .67683 Mdot
.61745 .26153 Mdot
.29266 .47277 Mdot
.97151 .08832 Mdot
.74207 .69732 Mdot
.73386 .07788 Mdot
.16088 .72894 Mdot
.04911 .95213 Mdot
.12555 .58485 Mdot
.4801 .23859 Mdot
.77352 .56286 Mdot
.0992 .0061 Mdot
.67789 .02413 Mdot
.38327 .14147 Mdot
.53384 .44785 Mdot
.54741 .14026 Mdot
.21688 .04606 Mdot
.64061 .4754 Mdot
.88659 .22876 Mdot
.65543 .35255 Mdot
.54867 .91604 Mdot
.86778 .42377 Mdot
.56498 .10189 Mdot
.71237 .43674 Mdot
.00866 .01456 Mdot
.38382 .1623 Mdot
.29362 .73736 Mdot
.84982 .22514 Mdot
.88858 .7838 Mdot
.51126 .64989 Mdot
.0493 .4787 Mdot
.79408 .51666 Mdot
.52804 .4601 Mdot
.07417 .97404 Mdot
.60908 .24565 Mdot
.78483 .46811 Mdot
.91867 .80328 Mdot
.19681 .25845 Mdot
.8623 .81183 Mdot
.1776 .95742 Mdot
.67478 .18819 Mdot
.06994 .27608 Mdot
.16215 .16415 Mdot
.28929 .67079 Mdot
.67031 .60133 Mdot
.09197 .06944 Mdot
.69209 .58323 Mdot
.18217 .44 Mdot
.3299 .46466 Mdot
.31752 .74675 Mdot
.54705 .67742 Mdot
.12225 .94115 Mdot
.9232 .73472 Mdot
.63423 .80237 Mdot
.76346 .56899 Mdot
.53968 .05492 Mdot
.2021 .85365 Mdot
.28405 .72624 Mdot
.36848 .33617 Mdot
.71406 .60083 Mdot
.7656 .13167 Mdot
.92618 .58988 Mdot
.37357 .78689 Mdot
.62184 .09533 Mdot
.33404 .22669 Mdot
.24839 .48674 Mdot
.29027 .74454 Mdot
.27952 .48417 Mdot
.8785 .72426 Mdot
.32906 .60977 Mdot
.41932 .02295 Mdot
.10337 .15174 Mdot
.63612 .84096 Mdot
.40089 .43364 Mdot
.31208 .99945 Mdot
.87926 .03559 Mdot
.89104 .57294 Mdot
.17807 .53393 Mdot
.861 .29774 Mdot
.28819 .77066 Mdot
.94377 .74326 Mdot
.21229 .34841 Mdot
.15386 .49252 Mdot
.95046 .2322 Mdot
.24691 .42147 Mdot
.52517 .3946 Mdot
.12802 .40975 Mdot
.88611 .80108 Mdot
.96329 .38187 Mdot
.88109 .60119 Mdot
.08717 .40195 Mdot
.50289 .68774 Mdot
.49715 .0097 Mdot
.21589 .49553 Mdot
.25101 .218 Mdot
.93167 .23926 Mdot
.00465 .9778 Mdot
.10847 .13856 Mdot
.85567 .48502 Mdot
.06048 .95048 Mdot
.72226 .78996 Mdot
.10629 .26204 Mdot
.76441 .50168 Mdot
.17431 .65861 Mdot
.06447 .40575 Mdot
.81825 .53394 Mdot
.32344 .01366 Mdot
.40681 .0926 Mdot
.38851 .25352 Mdot
.27689 .34019 Mdot
.30587 .83997 Mdot
.24169 .37546 Mdot
.10026 .23141 Mdot
.81083 .07064 Mdot
.01386 .55185 Mdot
.8847 .53129 Mdot
.10177 .45931 Mdot
.14998 .96499 Mdot
.69035 .5371 Mdot
.12403 .68734 Mdot
.20038 .29777 Mdot
.63996 .00051 Mdot
.58234 .62276 Mdot
.48347 .83659 Mdot
.30976 .0915 Mdot
.38075 .71226 Mdot
.46509 .7234 Mdot
.75992 .53618 Mdot
.02435 .9401 Mdot
.69459 .47176 Mdot
.6943 .49723 Mdot
.55912 .51784 Mdot
.25878 .97268 Mdot
.48447 .26093 Mdot
.24425 .55415 Mdot
.05611 .49699 Mdot
.6211 .66781 Mdot
.2029 .84725 Mdot
.20295 .36354 Mdot
.26732 .68825 Mdot
.39709 .532 Mdot
.69752 .09698 Mdot
.7429 .02372 Mdot
.61119 .1727 Mdot
.33697 .98631 Mdot
.3212 .8939 Mdot
.93243 .17539 Mdot
.7661 .47023 Mdot
.65776 .74224 Mdot
.65346 .49391 Mdot
.27159 .08373 Mdot
.58061 .19517 Mdot
.07266 .68282 Mdot
.6564 .81879 Mdot
.87276 .7384 Mdot
.30199 .48489 Mdot
.18849 .98675 Mdot
.18709 .36133 Mdot
.28099 .88315 Mdot
.14947 .79411 Mdot
.89671 .07366 Mdot
.86626 .19649 Mdot
.51129 .6161 Mdot
.11388 .70158 Mdot
.3092 .99369 Mdot
.01373 .4879 Mdot
.27646 .58599 Mdot
.00643 .76881 Mdot
.12423 .78124 Mdot
.92312 .86971 Mdot
.43108 .11273 Mdot
.64026 .70318 Mdot
.91239 .12597 Mdot
.20068 .7632 Mdot
.19285 .82135 Mdot
.18549 .07847 Mdot
.92308 .82868 Mdot
.01867 .06148 Mdot
.65261 .68417 Mdot
.5677 .02316 Mdot
.35612 .9223 Mdot
.69742 .68097 Mdot
.15938 .15818 Mdot
.19274 .61631 Mdot
.24597 .379 Mdot
.66684 .54917 Mdot
.2403 .39165 Mdot
.71988 .71443 Mdot
.6724 .6179 Mdot
.04216 .6341 Mdot
.09567 .45281 Mdot
.04518 .02939 Mdot
.24712 .23506 Mdot
.94694 .90065 Mdot
.45205 .72905 Mdot
.42929 .3709 Mdot
.6056 .34386 Mdot
.55733 .44587 Mdot
.1238 .87851 Mdot
.00228 .42772 Mdot
.43924 .90291 Mdot
.30748 .68985 Mdot
.54438 .04598 Mdot
.85967 .5075 Mdot
.78424 .46461 Mdot
.1273 .32796 Mdot
.53148 .00332 Mdot
.33041 .39315 Mdot
.26129 .64214 Mdot
.84672 .72143 Mdot
.98113 .70104 Mdot
.87386 .22523 Mdot
.46333 .51126 Mdot
.86718 .96386 Mdot
.94528 .11438 Mdot
.61692 .29 Mdot
.90516 .7391 Mdot
.85936 .41912 Mdot
.51658 .31881 Mdot
.60465 .1354 Mdot
.71437 .40635 Mdot
.81664 .34946 Mdot
.81624 .47962 Mdot
.85932 .88636 Mdot
.20376 .41852 Mdot
.21947 .20076 Mdot
.16726 .98684 Mdot
.97487 .64875 Mdot
.80941 .0942 Mdot
.67311 .29384 Mdot
.2527 .26798 Mdot
.69528 .40413 Mdot
.79506 .43898 Mdot
.25915 .14018 Mdot
.37897 .44395 Mdot
.7369 .17632 Mdot
.21045 .51293 Mdot
.8246 .92459 Mdot
.57955 .32474 Mdot
.27189 .36731 Mdot
.33734 .96655 Mdot
.5756 .09421 Mdot
.35619 .02521 Mdot
.45011 .66136 Mdot
.42493 .54297 Mdot
.78056 .56856 Mdot
.88478 .38134 Mdot
.08276 .47675 Mdot
.14859 .95743 Mdot
.33288 .64908 Mdot
.73115 .96394 Mdot
.28168 .59693 Mdot
.72107 .34606 Mdot
.53793 .26886 Mdot
.92754 .06315 Mdot
.19599 .85401 Mdot
.46784 .27352 Mdot
.61023 .1185 Mdot
.37808 .43966 Mdot
.65167 .39873 Mdot
.96808 .44732 Mdot
.3696 .39856 Mdot
.91336 .17698 Mdot
.44163 .08662 Mdot
.01999 .62656 Mdot
.22034 .81412 Mdot
.24372 .30707 Mdot
.68394 .90152 Mdot
.03563 .72654 Mdot
.23701 .69299 Mdot
.24244 .16702 Mdot
.32108 .44913 Mdot
.98957 .38904 Mdot
.8278 .28287 Mdot
.87288 .95249 Mdot
.32845 .91298 Mdot
.20988 .42821 Mdot
.53271 .75954 Mdot
.13185 .37984 Mdot
.44709 .04399 Mdot
.3998 .25316 Mdot
.81163 .83196 Mdot
.34426 .7234 Mdot
.27136 .62352 Mdot
.28484 .02789 Mdot
.72529 .6995 Mdot
.091 .42978 Mdot
.6585 .39922 Mdot
.81264 .86106 Mdot
.76644 .03527 Mdot
.19278 .3331 Mdot
.11934 .27024 Mdot
.7806 .31499 Mdot
.64345 .06066 Mdot
.91049 .86354 Mdot
.53611 .5322 Mdot
.68317 .52579 Mdot
.65004 .35404 Mdot
.92313 .18906 Mdot
.52175 .11635 Mdot
.0709 .40104 Mdot
.80148 .61068 Mdot
.63923 .4014 Mdot
.10342 .58142 Mdot
.80699 .27534 Mdot
.82919 .04999 Mdot
.39984 .80426 Mdot
.71886 .78032 Mdot
.36479 .68934 Mdot
.4553 .87813 Mdot
.31834 .63051 Mdot
.78736 .60346 Mdot
.2061 .58877 Mdot
.20036 .09055 Mdot
.02782 .30443 Mdot
.09505 .18439 Mdot
.89918 .78938 Mdot
.63272 .31141 Mdot
.29437 .65363 Mdot
.71488 .68738 Mdot
.52822 .70616 Mdot
.25651 .66599 Mdot
.2324 .08588 Mdot
.41279 .15131 Mdot
.87374 .44075 Mdot
.28657 .93299 Mdot
.38395 .06495 Mdot
.41276 .18993 Mdot
.06661 .72827 Mdot
.61511 .51516 Mdot
.86534 .94827 Mdot
.77482 .23915 Mdot
.00951 .68883 Mdot
.71758 .42146 Mdot
.98722 .43782 Mdot
.56964 .2861 Mdot
.56166 .61511 Mdot
.44369 .29085 Mdot
.35354 .44956 Mdot
.18928 .88906 Mdot
.82496 .5791 Mdot
.8527 .05916 Mdot
.3758 .46524 Mdot
.33915 .85746 Mdot
.09964 .88917 Mdot
.76037 .65014 Mdot
.94881 .81367 Mdot
.94447 .55716 Mdot
.03295 .05578 Mdot
.51229 .50802 Mdot
.24293 .10866 Mdot
.86673 .62811 Mdot
.72099 .03874 Mdot
.81677 .83711 Mdot
.80989 .5196 Mdot
.88796 .91828 Mdot
.72717 .91094 Mdot
.44078 .25786 Mdot
.52199 .05657 Mdot
.58128 .57936 Mdot
.16911 .75879 Mdot
.08757 .61221 Mdot
.61504 .53821 Mdot
.43203 .04639 Mdot
.29452 .49805 Mdot
.31147 .40444 Mdot
.60767 .08221 Mdot
.90195 .29516 Mdot
.14255 .0612 Mdot
.97399 .39394 Mdot
.46 .31286 Mdot
.25246 .26623 Mdot
.57287 .35463 Mdot
.29803 .97435 Mdot
.53137 .48542 Mdot
.36393 .0495 Mdot
.18999 .15164 Mdot
.98625 .94814 Mdot
.96397 .14704 Mdot
.24956 .61118 Mdot
.74676 .96049 Mdot
.50833 .29451 Mdot
.54332 .61785 Mdot
.34755 .62511 Mdot
.12903 .0172 Mdot
.10828 .78646 Mdot
.87419 .41518 Mdot
.51201 .01921 Mdot
.44001 .30301 Mdot
.62739 .77957 Mdot
.55633 .65907 Mdot
.38373 .55407 Mdot
.66577 .14568 Mdot
.11713 .68962 Mdot
.58224 .40449 Mdot
.35737 .98951 Mdot
.93122 .99461 Mdot
.46277 .90149 Mdot
.31546 .57335 Mdot
.21155 .82797 Mdot
.95496 .13235 Mdot
.40443 .86905 Mdot
.19924 .00454 Mdot
.90396 .48562 Mdot
.37856 .67101 Mdot
.47192 .6326 Mdot
.57058 .84509 Mdot
.02765 .32163 Mdot
.05992 .74754 Mdot
.57594 .38802 Mdot
.62198 .38088 Mdot
.5399 .53067 Mdot
.82689 .138 Mdot
.47512 .61187 Mdot
.95886 .96654 Mdot
.74706 .2317 Mdot
.7176 .01789 Mdot
.36032 .59406 Mdot
.22794 .48075 Mdot
.52827 .38705 Mdot
.3168 .38522 Mdot
.00429 .07452 Mdot
.66583 .31203 Mdot
.67886 .36154 Mdot
.26278 .03604 Mdot
.29866 .21692 Mdot
.26481 .57921 Mdot
.76383 .98668 Mdot
.14399 .35711 Mdot
.60828 .5247 Mdot
.69694 .48188 Mdot
.62016 .28251 Mdot
.07034 .40756 Mdot
.77197 .73728 Mdot
.66888 .80207 Mdot
.32476 .26534 Mdot
.49897 .32407 Mdot
.98861 .02435 Mdot
.14047 .15626 Mdot
.40762 .42276 Mdot
.91836 .49308 Mdot
.49167 .01354 Mdot
.79519 .42241 Mdot
.21963 .62541 Mdot
.75816 .33935 Mdot
.14215 .71087 Mdot
.09896 .50601 Mdot
.95092 .20137 Mdot
.80178 .31064 Mdot
.06083 .87925 Mdot
.78066 .28657 Mdot
.55044 .74124 Mdot
.93033 .23358 Mdot
.30737 .75437 Mdot
.57226 .53407 Mdot
.69797 .99116 Mdot
.90681 .48352 Mdot
.15792 .20041 Mdot
.86954 .02186 Mdot
.28342 .13046 Mdot
.32385 .67501 Mdot
.39332 .44139 Mdot
.47125 .36512 Mdot
.47765 .61708 Mdot
.79115 .63635 Mdot
.33286 .64825 Mdot
.05818 .11202 Mdot
.7127 .16723 Mdot
.0445 .76625 Mdot
.1793 .81125 Mdot
.42204 .9679 Mdot
.18961 .2267 Mdot
.95991 .26117 Mdot
.0066 .65252 Mdot
.01217 .8153 Mdot
.02362 .87283 Mdot
.5222 .24517 Mdot
.89052 .23898 Mdot
.38172 .35681 Mdot
.32249 .4788 Mdot
.85176 .74473 Mdot
.24399 .71236 Mdot
.06955 .8758 Mdot
.87703 .00829 Mdot
.77069 .52525 Mdot
.33476 .2826 Mdot
.30401 .92211 Mdot
.22808 .4202 Mdot
.70236 .6791 Mdot
.67557 .07956 Mdot
.48939 .91333 Mdot
.15628 .01709 Mdot
.47108 .64349 Mdot
.18592 .56158 Mdot
.01656 .64053 Mdot
.87827 .83405 Mdot
.95728 .08963 Mdot
.32847 .60297 Mdot
.83072 .63484 Mdot
.89968 .15881 Mdot
.70087 .22149 Mdot
.88423 .08784 Mdot
.58596 .00789 Mdot
.99226 .78775 Mdot
.46873 .17255 Mdot
.08637 .90493 Mdot
.9235 .79556 Mdot
.93065 .75873 Mdot
.93768 .41888 Mdot
.87508 .14206 Mdot
.38798 .91083 Mdot
.31478 .01397 Mdot
.42554 .0164 Mdot
.38264 .9919 Mdot
.85803 .38366 Mdot
.51903 .02237 Mdot
.31215 .23856 Mdot
.89455 .21411 Mdot
.07897 .87314 Mdot
.62204 .56806 Mdot
.07108 .27901 Mdot
.79088 .24991 Mdot
.71143 .53244 Mdot
.03407 .29377 Mdot
.7413 .76063 Mdot
.63376 .99842 Mdot
.24882 .09496 Mdot
.252 .73087 Mdot
.40575 .54677 Mdot
.37185 .78044 Mdot
.13582 .06578 Mdot
.18152 .16086 Mdot
.61413 .65732 Mdot
.1801 .92025 Mdot
.78311 .18633 Mdot
.23787 .50296 Mdot
.52478 .26989 Mdot
.58634 .39517 Mdot
.40105 .42153 Mdot
.15494 .4001 Mdot
.73897 .57115 Mdot
.82457 .00199 Mdot
.19023 .56688 Mdot
.84422 .29247 Mdot
.73224 .84577 Mdot
.20002 .19255 Mdot
.36514 .27064 Mdot
.97868 .77945 Mdot
.09669 .70573 Mdot
.68689 .23351 Mdot
.40024 .48901 Mdot
.58836 .28138 Mdot
.72372 .24959 Mdot
.92535 .35502 Mdot
.66309 .46179 Mdot
.07246 .2458 Mdot
.85139 .39015 Mdot
.79638 .91879 Mdot
.00991 .85059 Mdot
.68703 .95355 Mdot
.06185 .68969 Mdot
.19339 .697 Mdot
.49473 .97468 Mdot
.47769 .9291 Mdot
.54904 .13523 Mdot
.60095 .61811 Mdot
.01055 .35003 Mdot
.4265 .59187 Mdot
.37586 .36518 Mdot
.75266 .19432 Mdot
.68767 .65597 Mdot
.40475 .66691 Mdot
.11789 .24542 Mdot
.64599 .98173 Mdot
.40782 .76284 Mdot
.36023 .27563 Mdot
.55896 .324 Mdot
.01554 .90185 Mdot
.63077 .37767 Mdot
.16525 .3187 Mdot
.56188 .70259 Mdot
.11849 .36745 Mdot
.22318 .94812 Mdot
.82923 .91704 Mdot
.69597 .64783 Mdot
.1107 .93186 Mdot
.90381 .76031 Mdot
.98799 .76882 Mdot
.06617 .25444 Mdot
.28108 .75402 Mdot
.51278 .45191 Mdot
.36192 .40451 Mdot
.07356 .48202 Mdot
.58029 .31039 Mdot
.01318 .90403 Mdot
.4629 .29366 Mdot
.62278 .39312 Mdot
.37312 .78386 Mdot
.61925 .39566 Mdot
.44766 .68092 Mdot
.75049 .32696 Mdot
.21636 .33751 Mdot
.46861 .99001 Mdot
.80567 .26759 Mdot
.37864 .1128 Mdot
.15906 .78673 Mdot
.18974 .4734 Mdot
.6616 .28381 Mdot
.96819 .00683 Mdot
.77818 .24475 Mdot
.40134 .80463 Mdot
.49552 .16011 Mdot
.40194 .49745 Mdot
.4531 .20097 Mdot
.81179 .81417 Mdot
.6636 .67434 Mdot
.65934 .49473 Mdot
.56625 .74297 Mdot
.75616 .50018 Mdot
.9931 .28979 Mdot
.65062 .11501 Mdot
.72613 .86379 Mdot
.49108 .56797 Mdot
.28696 .15681 Mdot
.19859 .66546 Mdot
.87159 .96043 Mdot
.46445 .60922 Mdot
.57045 .39283 Mdot
.53248 .1485 Mdot
.52103 .75873 Mdot
.0148 .1464 Mdot
.70582 .55456 Mdot
.2855 .95935 Mdot
.31191 .50645 Mdot
.94712 .60983 Mdot
.60084 .53989 Mdot
.71654 .78091 Mdot
.95614 .49944 Mdot
.14818 .00658 Mdot
.56137 .22128 Mdot
.4698 .42601 Mdot
.81337 .5702 Mdot
.77015 .32867 Mdot
.08059 .85523 Mdot
.40171 .15143 Mdot
.37474 .35134 Mdot
.85301 .85786 Mdot
.51098 .9903 Mdot
.93349 .94771 Mdot
.57839 .10005 Mdot
.06228 .3072 Mdot
.59995 .28092 Mdot
.21724 .38408 Mdot
.90103 .76688 Mdot
.45823 .55259 Mdot
.42414 .81156 Mdot
.24812 .24892 Mdot
.74121 .32469 Mdot
.36208 .64205 Mdot
.31499 .54188 Mdot
.76917 .6732 Mdot
.67916 .44321 Mdot
.60029 .77965 Mdot
.82736 .10238 Mdot
.83157 .28592 Mdot
.78448 .2919 Mdot
.92311 .78607 Mdot
.61232 .00884 Mdot
.80159 .60833 Mdot
.2459 .75516 Mdot
.93294 .46272 Mdot
.00618 .90081 Mdot
.97646 .34718 Mdot
.1116 .42792 Mdot
.50575 .83689 Mdot
.12747 .23972 Mdot
.97639 .37559 Mdot
.07087 .84513 Mdot
.82655 .75901 Mdot
.05729 .3311 Mdot
.66108 .12994 Mdot
.51266 .73612 Mdot
.46013 .1024 Mdot
.52644 .64543 Mdot
.82044 .41594 Mdot
.75415 .8189 Mdot
.5806 .50104 Mdot
.43305 .53117 Mdot
.74501 .76057 Mdot
.18016 .51599 Mdot
.44258 .68448 Mdot
.04738 .1666 Mdot
.7561 .75001 Mdot
.75353 .76389 Mdot
.10926 .67099 Mdot
.44895 .73391 Mdot
.4305 .29462 Mdot
.95177 .3761 Mdot
.49334 .89268 Mdot
.39173 .53832 Mdot
.71264 .13459 Mdot
.12675 .71366 Mdot
.68124 .28691 Mdot
.62015 .89472 Mdot
.4889 .37831 Mdot
.57364 .08168 Mdot
.44808 .57524 Mdot
.46037 .06712 Mdot
.84023 .31914 Mdot
.66517 .65129 Mdot
.35941 .63032 Mdot
.27244 .57265 Mdot
.69317 .97424 Mdot
.88625 .57214 Mdot
.89196 .93261 Mdot
.07153 .13976 Mdot
.49447 .40457 Mdot
.60945 .36612 Mdot
.9974 .39111 Mdot
.14768 .07763 Mdot
.74273 .01995 Mdot
.63863 .52539 Mdot
.29919 .87159 Mdot
.97629 .69527 Mdot
.61919 .41684 Mdot
.87312 .28203 Mdot
.85846 .17801 Mdot
.70822 .64756 Mdot
.72903 .44902 Mdot
.28909 .82746 Mdot
.68378 .8321 Mdot
.52505 .16636 Mdot
.60632 .37945 Mdot
.64913 .58294 Mdot
.63495 .12951 Mdot
.89604 .32743 Mdot
.49641 .27546 Mdot
.54121 .13443 Mdot
.66523 .4066 Mdot
.2989 .3731 Mdot
.9564 .11091 Mdot
.81051 .62644 Mdot
.90812 .17806 Mdot
.49655 .26763 Mdot
.14242 .67308 Mdot
.65768 .34418 Mdot
.75225 .43414 Mdot
.83384 .7341 Mdot
.45785 .39914 Mdot
.08062 .25355 Mdot
.45147 .41722 Mdot
.1927 .38958 Mdot
.66861 .28499 Mdot
.05047 .61468 Mdot
.63427 .45072 Mdot
.52481 .55578 Mdot
.62112 .64755 Mdot
.74319 .99468 Mdot
.14814 .21963 Mdot
.3092 .22889 Mdot
.11943 .32999 Mdot
.80293 .9566 Mdot
.33932 .24528 Mdot
.17831 .54823 Mdot
.77986 .67879 Mdot
.49449 .85044 Mdot
.47308 .66727 Mdot
.98286 .52129 Mdot
.87694 .64713 Mdot
.22245 .52731 Mdot
.27154 .04685 Mdot
.69599 .47899 Mdot
.18884 .43309 Mdot
.99363 .53703 Mdot
.41428 .15532 Mdot
.10017 .74054 Mdot
.17494 .3099 Mdot
.78534 .03642 Mdot
.02519 .36764 Mdot
.6879 .55627 Mdot
.6307 .15001 Mdot
.194 .25382 Mdot
.33652 .66484 Mdot
.7967 .62869 Mdot
.13962 .83427 Mdot
.70491 .76322 Mdot
.39329 .18251 Mdot
.19594 .67256 Mdot
.46575 .63008 Mdot
.85852 .39669 Mdot
.19772 .29302 Mdot
.17786 .76073 Mdot
.51513 .11206 Mdot
.88068 .2159 Mdot
.5676 .65145 Mdot
.12422 .98681 Mdot
.02471 .49146 Mdot
.73755 .78699 Mdot
.2375 .28909 Mdot
.28265 .1603 Mdot
.64961 .25687 Mdot
.32971 .31796 Mdot
.43995 .11034 Mdot
.44718 .55422 Mdot
.78504 .03287 Mdot
.28537 .5836 Mdot
.19946 .19854 Mdot
.1154 .12396 Mdot
.23316 .57718 Mdot
.28898 .08284 Mdot
.75583 .55978 Mdot
.31956 .21382 Mdot
.07743 .8366 Mdot
.63054 .79097 Mdot
.13814 .59975 Mdot
.58645 .19612 Mdot
.05928 .17116 Mdot
.39754 .82555 Mdot
.83501 .79316 Mdot
.443 .38117 Mdot
.76392 .28838 Mdot
.32048 .16393 Mdot
.16557 .39513 Mdot
.52846 .33614 Mdot
.42373 .48687 Mdot
.14463 .66411 Mdot
.88169 .3185 Mdot
.89412 .55928 Mdot
.6708 .55462 Mdot
.83876 .84328 Mdot
.66515 .50099 Mdot
.17125 .11787 Mdot
.91915 .89751 Mdot
.29844 .84877 Mdot
.85142 .82956 Mdot
.25624 .69067 Mdot
.83972 .6094 Mdot
.19644 .86703 Mdot
.96481 .30802 Mdot
.46823 .29606 Mdot
.24426 .50991 Mdot
.70167 .58337 Mdot
.83406 .84115 Mdot
.99405 .12058 Mdot
.47254 .99905 Mdot
.96904 .58291 Mdot
.69258 .2159 Mdot
.7914 .40986 Mdot
.40461 .83732 Mdot
.97157 .49654 Mdot
.50395 .46115 Mdot
.25759 .29662 Mdot
.64866 .59855 Mdot
.90655 .77492 Mdot
.81146 .21362 Mdot
.87985 .38686 Mdot
.45861 .00634 Mdot
.23637 .37514 Mdot
.02169 .22691 Mdot
.37269 .19826 Mdot
.25574 .21963 Mdot
.61177 .00759 Mdot
.82499 .13191 Mdot
.44733 .62211 Mdot
.20263 .18436 Mdot
.87498 .66416 Mdot
.56727 .43185 Mdot
.70596 .54472 Mdot
.05415 .07912 Mdot
.91723 .21639 Mdot
.12469 .75703 Mdot
.18574 .99358 Mdot
.41325 .17549 Mdot
.49822 .11277 Mdot
.98364 .66264 Mdot
.24154 .60935 Mdot
.73848 .15446 Mdot
.55757 .09903 Mdot
.15491 .01339 Mdot
.26023 .53816 Mdot
.09383 .9741 Mdot
.49129 .99934 Mdot
.99197 .02936 Mdot
.64331 .21923 Mdot
.4696 .88434 Mdot
.72209 .91876 Mdot
.89691 .2044 Mdot
.98812 .99767 Mdot
.32233 .27898 Mdot
.53926 .27524 Mdot
.20432 .37388 Mdot
.62384 .44036 Mdot
.26759 .17853 Mdot
.01316 .28046 Mdot
.87595 .06839 Mdot
.49408 .06239 Mdot
.93694 .73203 Mdot
.3628 .39182 Mdot
.93257 .54236 Mdot
.62331 .41802 Mdot
.0587 .29698 Mdot
.44618 .0292 Mdot
.85047 .88137 Mdot
.49257 .86234 Mdot
.7219 .14911 Mdot
.15891 .44796 Mdot
.92955 .42569 Mdot
.93063 .30022 Mdot
.81214 .43424 Mdot
.29671 .64809 Mdot
.30096 .01096 Mdot
.88366 .18622 Mdot
.48742 .42786 Mdot
.5213 .57501 Mdot
.80005 .21371 Mdot
.30947 .17659 Mdot
.2964 .52873 Mdot
.22622 .87363 Mdot
.51071 .86517 Mdot
.72885 .69741 Mdot
.65495 .66288 Mdot
.97483 .99324 Mdot
.8373 .69613 Mdot
.13466 .85797 Mdot
.87566 .96264 Mdot
.71155 .51102 Mdot
.34059 .93382 Mdot
.28652 .88015 Mdot
.12447 .24111 Mdot
.63655 .18938 Mdot
.43815 .4316 Mdot
.90281 .65611 Mdot
.75834 .44374 Mdot
.09624 .59771 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool01oooool2o`0000Cooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`09ooooo`;o00000_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`02ooooo`007_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
0_l0000>ooooo`;o00003oooool2o`0000oooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool01?l0003ooooo
o`000?l0000<ooooo`03o`000?oooooooooo00Oooooo0_l00004ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool2o`0000Wo
oooo00?o0000ooooooooool00_ooool001kooooo00?o0000ooooooooool07?ooool2o`0000kooooo
0_l0000?ooooo`;o0000D_ooool2o`0000_ooooo0_l0000Jooooo`;o00001oooool2o`0005Cooooo
0_l0000Hooooo`;o00000_ooool2o`0000kooooo000Nooooo`03o`000?oooooooooo02kooooo0_l0
000^ooooo`;o00001Oooool2o`0003Gooooo1?l0000Jooooo`;o00001oooool2o`0003gooooo0_l0
000Eooooo`;o00006?ooool2o`0001;ooooo000Nooooo`04o`000?oooooo0000o`0002gooooo0_l0
000^ooooo`;o00000_ooool2o`000003ooooool0003o000001oooooo0_l0000Dooooo`;o0000I?oo
ool2o`0004?ooooo000Nooooo`04o`000?oooooo0000o`0001cooooo0_l00007ooooo`;o00001ooo
ool2o`00037ooooo0_l0000Rooooo`;o00006_ooool2o`00047ooooo0_l0001Pooooo`007_ooool0
0ol0003oooooooooo`0Mooooo`;o00001oooool2o`0000Oooooo0_l0001Cooooo`;o00007?ooool2
o`000003ooooool0003o000003kooooo0_l00006ooooo`;o0000:?ooool2o`0002kooooo000Noooo
o`03o`000?oooooooooo073ooooo0_l0000Booooo`;o00007oooool2o`0000gooooo0_l0000Roooo
o`;o00004oooool2o`0002Sooooo0_l0000Tooooo`;o00002?ooool001kooooo00?o0000oooooooo
ool0F?ooool2o`0001Kooooo0_l0000Vooooo`;o00006_ooool2o`0002;ooooo0_l0000Booooo`?o
0000C_ooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l0001;ooooo`;o0000
<oooool2o`0000Wooooo0_l0001Booooo`;o0000D?ooool2o`0000Oooooo000Nooooo`03o`000?oo
oooooooo00_ooooo0_l00020ooooo`;o0000I_ooool2o`0000Cooooo0_l00011ooooo`;o00001ooo
ool001kooooo00?o0000ooooooooool0DOooool2o`000:;ooooo0_l00004ooooo`;o00007Oooool2
o`0002_ooooo000Nooooo`03o`000?oooooooooo057ooooo0_l0002Cooooo`;o00004oooool2o`00
01gooooo0_l0000[ooooo`007_ooool00ol0003oooooooooo`2=ooooo`;o0000Eoooool2o`0005oo
oooo000Nooooo`03o`000?oooooooooo04;ooooo0_l0000@ooooo`;o0000<_ooool2o`0000?ooooo
0_l0000Nooooo`;o0000V?ooool001kooooo00?o0000ooooooooool0@_ooool2o`00013ooooo0_l0
000Looooo`;o00005?ooool2o`0002?ooooo0_l0001Jooooo`;o0000??ooool001kooooo0_l0001c
ooooo`;o0000UOooool2o`0003cooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0002Moooo
o`;o00000oooool2o`0009[ooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0002Mooooo`;o
00000oooool2o`00013ooooo0_l0001Booooo`;o0000=?ooool001kooooo00?o0000ooooooooool0
0_ooool2o`0002Kooooo0_l0001aooooo`;o00007_ooool2o`0000Sooooo0_l00004ooooo`;o0000
@_ooool2o`0003Cooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0000Tooooo`Co0000COoo
ool2o`0002;ooooo0_l0000Xooooo`;o00001?ooool2o`0005[ooooo0_l0000Looooo`007_ooool0
0ol0003oooooooooo`0Xooooo`;o0000Coooool2o`0001Oooooo0_l00025ooooo`;o00003_ooool2
o`0001cooooo000Nooooo`03o`000?oooooooooo01[ooooo0_l0001fooooo`;o0000Koooool2o`00
01Cooooo0_l0000/ooooo`007_ooool2o`0001_ooooo0_l0003Wooooo`;o00006_ooool2o`0002Ko
oooo000Nooooo`;o0000;Oooool2o`000;cooooo0_l0000cooooo`;o00009_ooool001kooooo00?o
0000ooooooooool03Oooool2o`0001gooooo0_l0000:ooooo`;o0000W_ooool2o`00013ooooo0_l0
001Kooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o0000:Oooool2o`0001[ooooo0_l00004
ooooo`;o0000F_ooool2o`0000Wooooo0_l0000Eooooo`;o0000KOooool001kooooo00?o0000oooo
ooooool0Aoooool2o`0000_ooooo0_l00004ooooo`;o0000;oooool2o`0002Wooooo0_l00009oooo
o`;o0000Q?ooool001kooooo00?o0000ooooooooool0?Oooool2o`0000Sooooo0_l00012ooooo`;o
0000S_ooool2o`0001Kooooo0_l00003ooooo`;o00003Oooool001kooooo00?o0000ooooooooool0
?Oooool2o`0002;ooooo0_l0000Mooooo`;o0000VOooool2o`0001Kooooo0_l00003ooooo`;o0000
3Oooool001kooooo00?o0000ooooooooool0COooool2o`0001;ooooo0_l0000Gooooo`;o00001?oo
ool2o`0003Gooooo0_l0000=ooooo`;o0000>oooool2o`0004;ooooo000Nooooo`03o`000?oooooo
oooo04gooooo0_l000000ooooooo0000o`00000Xooooo`;o0000=Oooool2o`0000Cooooo0_l0000=
ooooo`;o00005oooool2o`0002;ooooo0_l00012ooooo`007_ooool2o`00057ooooo0_l0000ooooo
o`;o00007_ooool2o`000003ooooool0003o000000;ooooo0_l0000Uooooo`;o0000:?ooool2o`00
03cooooo000Nooooo`03o`000?oooooooooo097ooooo0_l0000Qooooo`;o00000_ooool2o`0004oo
oooo0_l0000looooo`007_ooool00ol0003oooooooooo`1;ooooo`;o0000n_ooool001kooooo00?o
0000ooooooooool03oooool2o`0003[ooooo0_l0000nooooo`;o00005_ooool2o`0008kooooo0_l0
000Booooo`007_ooool00ol0003oooooooooo`0?ooooo`;o0000I_ooool2o`0000oooooo0_l00000
0ooooooo0000o`00000Aooooo`;o00000oooool2o`0002[ooooo0_l0001Nooooo`;o00000_ooool2
o`0001;ooooo000Nooooo`03o`000?oooooooooo03Cooooo0_l00011ooooo`;o00003oooool2o`00
01Cooooo0_l00006ooooo`;o00009oooool2o`0005kooooo0_l0000Fooooo`007_ooool00ol0003o
ooooooooo`0Yooooo`;o00002Oooool2o`00073ooooo0_l0000Jooooo`;o0000Noooool2o`0000Ko
oooo000Nooooo`03o`000?oooooooooo027ooooo0_l00006ooooo`;o0000Soooool2o`0000Kooooo
0_l0001kooooo`;o00001_ooool001kooooo00?o0000ooooooooool08Oooool2o`0009Oooooo0_l0
001Yooooo`;o00008?ooool001kooooo00?o0000ooooooooool0F?ooool2o`00073ooooo0_l00007
ooooo`;o0000D?ooool2o`00023ooooo000Nooooo`03o`000?oooooooooo05Sooooo0_l0001`oooo
o`;o00001oooool2o`00023ooooo0_l0000Aooooo`;o0000:?ooool2o`0001?ooooo000Nooooo`03
o`000?oooooooooo0:cooooo1?l0000@ooooo`;o00008_ooool2o`0000oooooo0_l0000Aooooo`;o
0000:?ooool2o`0001?ooooo000Nooooo`03o`000?oooooooooo01?ooooo0_l0000:ooooo`;o0000
Roooool4o`00013ooooo0_l0000Rooooo`;o00008oooool2o`0003cooooo000Nooooo`03o`000?oo
oooooooo01?ooooo0_l0000:ooooo`;o0000;oooool2o`0002Kooooo0_l0000dooooo`;o0000FOoo
ool2o`0000gooooo0_l0000]ooooo`007_ooool00ol0003oooooooooo`1@ooooo`;o00009_ooool2
o`0003Cooooo0_l0000Tooooo`;o0000@_ooool2o`0002gooooo000Nooooo`04o`000?oooooooooo
ooooo`;o0000Y_ooool2o`0002Wooooo0_l0001Oooooo`;o00004?ooool001kooooo0_l00002oooo
o`;o00006_ooool2o`0001_ooooo0_l00012ooooo`;o00000_ooool2o`0002Gooooo0_l0000Noooo
o`;o00007?ooool2o`0004cooooo0_l0000@ooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o
00006oooool2o`0004;ooooo0_l00002ooooo`;o0000AOooool2o`0001cooooo0_l00003ooooo`;o
0000FOooool001kooooo00?o0000ooooooooool0:_ooool2o`0000Cooooo0_l0000Wooooo`;o0000
:?ooool2o`0006Oooooo0_l0001Iooooo`007_ooool00ol0003oooooooooo`0Zooooo`;o00001?oo
ool2o`0000Gooooo0_l0000Oooooo`?o0000:?ooool2o`0001Sooooo0_l0001Dooooo`;o0000:ooo
ool2o`0002Gooooo000Nooooo`03o`000?oooooooooo037ooooo0_l00004ooooo`;o00007oooool2
o`0000[ooooo0_l0000Cooooo`;o00008_ooool2o`0005Cooooo0_l0000[ooooo`;o00009Oooool0
01kooooo00?o0000ooooooooool02oooool2o`0002Cooooo0_l0000Hooooo`;o00005oooool2o`00
01?ooooo0_l0000/ooooo`;o0000>oooool2o`00067ooooo000Nooooo`03o`000?oooooooooo00_o
oooo0_l0000nooooo`;o0000F_ooool2o`0003_ooooo0_l0001Qooooo`007_ooool00ol0003ooooo
ooooo`0?ooooo`;o0000Poooool2o`0002gooooo0_l00022ooooo`007_ooool00ol0003ooooooooo
o`0?ooooo`;o0000Coooool2o`00023ooooo0_l0000@ooooo`;o0000;Oooool2o`0002Kooooo0_l0
000nooooo`;o00006_ooool001kooooo00?o0000ooooooooool0Doooool2o`0000_ooooo0_l0000P
ooooo`;o0000Ioooool2o`0002Kooooo0_l0000>ooooo`Co00001?ooool2o`0001[ooooo000Noooo
o`03o`000?oooooooooo05?ooooo0_l0000Wooooo`;o0000UOooool2o`0000kooooo1?l0000Poooo
o`007_ooool00ol0003oooooooooo`0Kooooo`;o00008Oooool2o`0003cooooo0_l00039ooooo`00
7_ooool00ol0003oooooooooo`0Kooooo`;o00008Oooool2o`0009Oooooo0_l0000Qooooo`;o0000
7oooool2o`0000_ooooo0_l0000Mooooo`007_ooool00ol0003oooooooooo`22ooooo`;o0000Aooo
ool2o`0000[ooooo0_l0000Qooooo`;o00007oooool2o`0000_ooooo0_l0000Mooooo`000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003ooooooooo
o`0mooooo`;o0000??ooool2o`0000Gooooo0_l0000eooooo`;o00004?ooool2o`0002Cooooo0_l0
001Dooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`0mooooo`;o0000=_ooool2o`0000Cooooo
0_l0000looooo`Co0000=?ooool2o`0002?ooooo0_l0000_ooooo`000oooool01Ol@413ooooooooo
oooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool3o`0002oooooo0_l0000<ooooo`;o0000
1?ooool2o`00033ooooo0_l0000Hooooo`;o0000:_ooool2o`0005Wooooo0_l0000_ooooo`000ooo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003ooooo
ooooo`0_ooooo`;o00003?ooool2o`0000Cooooo0_l0001:ooooo`;o0000S_ooool2o`00013ooooo
0_l0000Dooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool0
1Oooool00ol0003oooooooooo`3oooooob3ooooo0_l0000@ooooo`;o00005?ooool000?ooooo00Go
410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo
V9RHoa0@4006ooooo`03o`000?oooooooooo0?oooooo1Oooool2o`00047ooooo0003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000oooo
ooooool0I?ooool2o`0007Oooooo0_l0000Qooooo`;o00000_ooool2o`0001Cooooo0_l00003oooo
o`;o00001Oooool2o`0001oooooo000Nooooo`03o`000?oooooooooo02cooooo0_l0000Oooooo`Co
00003?ooool2o`0000Gooooo0_l0001Wooooo`;o00003_ooool2o`00027ooooo0_l0000Hooooo`;o
00000oooool2o`0000Gooooo0_l0000Oooooo`007_ooool00ol0003oooooooooo`0/ooooo`;o0000
7oooool4o`0000cooooo0_l0001Cooooo`;o00006Oooool2o`00017ooooo0_l0001Uooooo`007_oo
ool00ol0003oooooooooo`2booooo`;o0000;?ooool2o`0002kooooo0_l00006ooooo`;o0000;Ooo
ool001kooooo00?o0000ooooooooool00oooool2o`0003Gooooo0_l0000Tooooo`;o00001_ooool2
o`000:Kooooo0_l00006ooooo`;o00000_ooool2o`0002Wooooo000Nooooo`03o`000?oooooooooo
00?ooooo0_l0000Gooooo`;o00007?ooool2o`0002Cooooo0_l00006ooooo`;o0000QOooool2o`00
02_ooooo0_l0000Yooooo`007_ooool00ol0003oooooooooo`0Looooo`;o0000;_ooool2o`0008go
oooo0_l0000Booooo`;o0000>Oooool2o`0000Gooooo0_l0000Dooooo`007_ooool00ol0003ooooo
ooooo`1<ooooo`;o0000SOooool2o`0004gooooo0_l00005ooooo`;o00005?ooool001kooooo00?o
0000ooooooooool09?ooool3o`0003[ooooo0_l0000eooooo`;o0000G_ooool2o`0002?ooooo0_l0
000<ooooo`;o00006_ooool001kooooo00?o0000ooooooooool09?ooool3o`0003[ooooo0_l0000e
ooooo`;o0000G_ooool2o`0002?ooooo0_l0000<ooooo`;o00001oooool2o`00017ooooo000Noooo
o`03o`000?oooooooooo01?ooooo0_l0000=ooooo`;o0000A_ooool2o`0003[ooooo0_l0000Joooo
o`;o0000=Oooool2o`0003Wooooo0_l0000Aooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o
00003Oooool2o`0002Wooooo0_l0000Kooooo`;o0000>_ooool2o`0001[ooooo0_l0000Sooooo`;o
00004?ooool2o`0000;ooooo0_l00018ooooo`007_ooool2o`0001Oooooo0_l0000eooooo`;o0000
:oooool2o`0000;ooooo0_l0001Wooooo`;o00005?ooool2o`0004Sooooo000Nooooo`03o`000?oo
oooooooo017ooooo0_l00003ooooo`;o00008oooool2o`0003gooooo0_l00002ooooo`;o0000aooo
ool001kooooo00?o0000ooooooooool04Oooool2o`0002Sooooo0ol0001=ooooo`;o0000@_ooool2
o`0007Kooooo000Nooooo`03o`000?oooooooooo01kooooo0_l0000Looooo`;o0000COooool2o`00
00cooooo0_l0000Zooooo`;o00002?ooool2o`0006?ooooo0_l0000Aooooo`007_ooool00ol0003o
ooooooooo`0@ooooo`;o00003?ooool2o`0004Gooooo0_l0000booooo`;o0000:_ooool2o`0006go
oooo0_l0000Aooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o0000??ooool2o`0001Gooooo
0_l0000fooooo`;o00003?ooool2o`0005Gooooo0_l00013ooooo`007_ooool00ol0003ooooooooo
o`0Sooooo`;o0000:Oooool2o`0002?ooooo0_l0000Xooooo`;o00001oooool2o`0000?ooooo0_l0
000Sooooo`;o0000<?ooool2o`0004?ooooo000Nooooo`03o`000?oooooooooo02?ooooo0_l0001>
ooooo`;o00007oooool2o`00013ooooo0_l0000Xooooo`;o0000MOooool001kooooo00?o0000oooo
ooooool04oooool2o`0005cooooo0_l0000Qooooo`;o00001oooool2o`0000cooooo0_l0001Eoooo
o`;o0000@oooool001kooooo00?o0000ooooooooool00_l0000Aooooo`;o0000D?ooool2o`0000[o
oooo0_l0000Zooooo`;o00003?ooool2o`0001;ooooo0_l00011ooooo`;o0000@oooool001kooooo
00?o0000ooooooooool00_l0000Aooooo`;o0000D?ooool2o`0000;ooooo0_l0001@ooooo`;o0000
0_ooool2o`0000Gooooo0_l0000;ooooo`;o0000=?ooool2o`0000gooooo0_l0000]ooooo`007_oo
ool00ol0003oooooooooo`1Yooooo`;o0000B_ooool2o`0000Cooooo0_l00009ooooo`;o00002ooo
ool4o`0000;ooooo0_l0000Oooooo`;o00003Oooool3o`0000cooooo0_l0000]ooooo`007_ooool0
0ol0003oooooooooo`19ooooo`;o0000J_ooool2o`0000gooooo0_l0000?ooooo`;o00000_ooool2
o`0001Wooooo0_l00004ooooo`;o00003_ooool2o`0003?ooooo0_l00006ooooo`007_ooool00ol0
003oooooooooo`0looooo`;o00002oooool2o`00047ooooo0_l0000fooooo`;o0000;_ooool2o`00
00Gooooo0_l0000Aooooo`;o0000;oooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo00Oo
oooo0_l0000cooooo`;o00004_ooool2o`0003Kooooo0_l00002ooooo`;o00001?ooool4o`0000_o
oooo0_l0000dooooo`Co00008?ooool2o`00017ooooo0_l0000Aooooo`;o00009?ooool001kooooo
00?o0000ooooooooool01oooool2o`0000Kooooo0_l0000/ooooo`;o00004Oooool2o`0003Kooooo
0_l00008ooooo`Co00002oooool2o`0003Cooooo1?l0000iooooo`;o00002oooool2o`0002Cooooo
000Nooooo`;o00004?ooool2o`0002cooooo0_l0003Eooooo`;o00005?ooool2o`0001_ooooo000N
ooooo`03o`000?oooooooooo00Gooooo0_l00024ooooo`;o0000WOooool2o`0001_ooooo000Noooo
o`03o`000?oooooooooo00Gooooo0_l00009ooooo`;o0000>Oooool2o`0003kooooo0_l0002Yoooo
o`;o00003oooool001kooooo00?o0000ooooooooool04?ooool2o`0002?ooooo0_l0000Dooooo`;o
0000Hoooool2o`0000Oooooo0_l0000?ooooo`;o00002?ooool2o`0002_ooooo0_l0000cooooo`;o
00003oooool001kooooo00?o0000ooooooooool07?ooool2o`0001Oooooo0_l0000Fooooo`;o0000
@_ooool2o`0001gooooo0_l00007ooooo`;o00003oooool2o`0000Sooooo0_l0000Tooooo`;o0000
1Oooool2o`0004Cooooo000Nooooo`03o`000?oooooooooo01cooooo0_l0000_ooooo`;o00006?oo
ool2o`0002Sooooo0_l0001Wooooo`;o0000Boooool001kooooo00?o0000ooooooooool0<_ooool2
o`0003?ooooo0_l0000kooooo`;o0000;_ooool2o`0003Oooooo0_l0000<ooooo`;o0000:_ooool0
01kooooo00?o0000ooooooooool01Oooool2o`0002_ooooo0_l0001Zooooo`;o00001?ooool2o`00
00cooooo0_l0000Pooooo`;o0000=oooool2o`0000cooooo0_l0000Zooooo`007_ooool00ol0003o
ooooooooo`05ooooo`;o0000Toooool2o`0000;ooooo0_l0000Booooo`;o00001?ooool2o`0003?o
oooo0_l000000ooooooo0000o`00000]ooooo`;o00009_ooool001kooooo00?o0000ooooooooool0
8oooool4o`0007?ooooo0_l0000Looooo`;o0000<oooool2o`000003ooooool0003o000000Cooooo
0_l0000Wooooo`;o00009_ooool001kooooo00?o0000ooooooooool03oooool2o`0001;ooooo1?l0
000Dooooo`;o0000^Oooool2o`0004oooooo000Nooooo`03o`000?oooooooooo00oooooo0_l0000Z
ooooo`;o0000=oooool2o`0003;ooooo0_l0002Mooooo`007_ooool00ol0003oooooooooo`12oooo
o`;o0000<?ooool2o`0003;ooooo0_l00018ooooo`;o0000Doooool001kooooo00?o0000oooooooo
ool0@_ooool2o`0001;ooooo0_l0002Jooooo`;o0000Doooool001kooooo00?o0000ooooooooool0
E_ooool2o`0006Wooooo0_l0000?ooooo`;o0000Loooool001kooooo00?o0000ooooooooool0@Ooo
ool2o`0001?ooooo0_l0001Yooooo`;o00003oooool2o`0001;ooooo0_l0001Aooooo`;o00003?oo
ool001kooooo1?l00010ooooo`;o0000<oooool2o`0006kooooo0_l0000Mooooo`;o0000<_ooool2
o`0000cooooo000Nooooo`04o`000?oooooo0000o`0001oooooo0_l0001Dooooo`;o0000?_ooool2
o`0001Oooooo1?l0000Pooooo`;o00004?ooool2o`0002;ooooo0_l0000Looooo`007_ooool00ol0
003oooooooooo`0Pooooo`;o00002Oooool2o`0004_ooooo0_l0000looooo`;o00005oooool4o`00
023ooooo0_l0000dooooo`;o00007?ooool001kooooo00?o0000ooooooooool0:oooool2o`0004_o
oooo0_l0003=ooooo`007_ooool00ol0003oooooooooo`0iooooo`;o00000oooool2o`0009Wooooo
0_l0001/ooooo`007_ooool00ol0003oooooooooo`0Rooooo`;o00005Oooool2o`0000?ooooo0_l0
000Dooooo`;o00008?ooool2o`0001gooooo0_l0000[ooooo`;o00005Oooool2o`0006cooooo000N
ooooo`03o`000?oooooooooo00Cooooo0_l0000Looooo`;o0000<?ooool2o`00023ooooo0_l0000M
ooooo`;o0000:oooool2o`0008?ooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0001Goooo
o`;o0000:?ooool2o`000;Kooooo0_l00006ooooo`007_ooool00ol0003oooooooooo`0nooooo`;o
00002Oooool3o`00017ooooo0_l0000Xooooo`;o0000Z?ooool2o`0000Kooooo0_l00004ooooo`;o
00001_ooool001kooooo00?o0000ooooooooool0?_ooool2o`0000Wooooo1Ol0001=ooooo`;o0000
9?ooool2o`0000Kooooo0_l0001Vooooo`;o00001_ooool2o`0000cooooo000Nooooo`03o`000?oo
oooooooo02Oooooo0_l0000Sooooo`;o0000?_ooool2o`0000gooooo0_l0000Tooooo`;o00000ooo
ool2o`000003ooooool0003o0000057ooooo0_l0000Gooooo`;o00004?ooool001kooooo00?o0000
ooooooooool07Oooool2o`0000Sooooo0_l0000Jooooo`;o00007_ooool2o`0002Oooooo0_l0000h
ooooo`;o0000Boooool2o`0000Oooooo0_l0000Gooooo`;o00004?ooool001kooooo00?o0000oooo
ooooool07Oooool2o`0002Cooooo0_l0000Nooooo`;o0000@oooool2o`0000gooooo0_l0001Joooo
o`;o00001Oooool2o`0002_ooooo000Nooooo`03o`000?oooooooooo03_ooooo0_l0000=ooooo`;o
00009_ooool2o`0003Cooooo0_l0000=ooooo`;o00001?ooool2o`0005;ooooo0_l00007ooooo`;o
00008_ooool4o`0000Gooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo03;ooooo0_l00007ooooo`;o
00003Oooool2o`0001_ooooo0_l00009ooooo`;o0000<oooool2o`0000cooooo0_l00006ooooo`;o
00001oooool2o`0004Wooooo0_l0000Vooooo`;o00000oooool4o`0000Gooooo0003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0booooo`;o0000<oooool2o`0003kooooo0_l0000<ooooo`;o00001?ooool2o`0000So
oooo0ol0001;ooooo`;o00009?ooool2o`0000cooooo0003ooooo`05oa0@4?ooooooooooooooool@
41002oooool5o`0000Kooooo0ol0000Cooooo`;o00006Oooool2o`0004Cooooo0_l0000Kooooo`;o
0000:?ooool2o`0000Sooooo0_l00009ooooo`Co0000?oooool2o`0003;ooooo0003ooooo`05o`00
0?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo
01?ooooo0_l00003ooooo`;o00005?ooool2o`0004Cooooo0_l0000Kooooo`;o0000>Oooool2o`00
00;ooooo1?l0000:ooooo`;o0000Ioooool000?ooooo00Go0000ooooooooooooooooo`00000;oooo
o`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool04Oooool2o`0000Gooooo0_l00017
ooooo`;o00003oooool2o`0002Wooooo0_l0000Jooooo`;o00004Oooool2o`0000Kooooo0_l00008
ooooo`;o00001?ooool2o`00067ooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo017ooooo1?l0000Aooooo`;o0000>Oooool2
o`0000oooooo0_l0000Yooooo`;o00006_ooool2o`0001Wooooo0_l0000>ooooo`;o00005oooool2
o`0004Sooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007
ooooo`03o`000?oooooooooo01?ooooo0_l0000Aooooo`;o0000eOooool2o`0004Sooooo0003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooo
oooo0?oooooo2?ooool2o`0000oooooo0_l0000]ooooo`007_ooool00ol0003oooooooooo`0noooo
o`;o0000Coooool2o`0003Cooooo1?l0000nooooo`;o00002_ooool2o`0000?ooooo0_l0000Coooo
o`;o00006?ooool001kooooo00?o0000ooooooooool0?_ooool2o`0000Kooooo0_l00004ooooo`;o
0000<?ooool4o`0000gooooo0_l0000dooooo`Co00007?ooool2o`0001Oooooo0_l0000Cooooo`;o
00006?ooool2o`0001Sooooo000Nooooo`03o`000?oooooooooo04Kooooo0_l00004ooooo`;o0000
<?ooool4o`0006?ooooo0_l0000Gooooo`;o00005_ooool2o`0001;ooooo0_l0000Kooooo`007_oo
ool2o`00027ooooo0ol0000Mooooo`;o0000Doooool2o`0000?ooooo0_l0001jooooo`;o00004_oo
ool2o`0001_ooooo000Nooooo`;o00006_ooool2o`0000Gooooo0ol0000Mooooo`;o0000B?ooool2
o`0000Wooooo0_l00003ooooo`;o00006?ooool2o`00097ooooo000Nooooo`03o`000?oooooooooo
01Wooooo0_l0000Nooooo`;o0000@oooool2o`0000[ooooo0_l0000Xooooo`;o0000>_ooool2o`00
01;ooooo0_l00011ooooo`007_ooool00ol0003oooooooooo`0iooooo`;o0000@oooool2o`0006?o
oooo0_l0000;ooooo`;o00004_ooool2o`0003Oooooo0_l00008ooooo`007_ooool00ol0003ooooo
ooooo`0gooooo`;o0000?_ooool2o`0003gooooo0_l0000?ooooo`;o00006_ooool2o`0001Wooooo
0_l0000Hooooo`;o00007?ooool2o`0000Gooooo0_l00008ooooo`007_ooool00ol0003ooooooooo
o`0gooooo`;o0000?_ooool2o`0000?ooooo0_l0000hooooo`;o00003oooool2o`00013ooooo0_l0
000Gooooo`;o00002_ooool2o`0001Sooooo0_l0000Looooo`;o00003oooool001kooooo00?o0000
ooooooooool0Moooool2o`0000?ooooo0_l0000cooooo`;o00009_ooool2o`0001Oooooo0_l00013
ooooo`;o00003_ooool001kooooo00?o0000ooooooooool0<?ooool2o`0003;ooooo0_l00009oooo
o`;o0000>?ooool3o`0000Gooooo0_l0000fooooo`;o0000C?ooool2o`0000kooooo000Nooooo`;o
00007?ooool2o`0001?ooooo0_l0000booooo`;o00002Oooool2o`0003;ooooo0_l00004ooooo`?o
00007_ooool2o`0001gooooo0_l0001Looooo`007_ooool00ol0003oooooooooo`0Kooooo`;o0000
Q_ooool2o`0002Gooooo0_l0001kooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o0000oooo
oolYooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o0000POooool2o`0000Kooooo0_l0000Y
ooooo`;o0000E_ooool2o`0001[ooooo000Nooooo`03o`000?oooooooooo06Oooooo0_l0000=oooo
o`;o0000:?ooool2o`0000Kooooo0_l0000Yooooo`;o00009_ooool2o`0002kooooo0_l0000Joooo
o`007_ooool00ol0003oooooooooo`0booooo`;o00007Oooool2o`0001Cooooo0_l0000=ooooo`;o
0000Poooool2o`0004[ooooo000Nooooo`03o`000?oooooooooo03;ooooo0_l0000Mooooo`;o0000
Roooool2o`0001Gooooo0_l00004ooooo`;o0000B_ooool001kooooo00?o0000ooooooooool0>_oo
ool2o`0001oooooo0_l00021ooooo`;o00005Oooool2o`00053ooooo000Nooooo`03o`000?oooooo
oooo01Oooooo0_l0000Qooooo`;o00007oooool2o`0006oooooo0_l0001iooooo`007_ooool00ol0
003oooooooooo`0<ooooo`;o00002Oooool2o`0002gooooo0_l0000Mooooo`;o0000IOooool2o`00
013ooooo0_l0000Uooooo`;o0000@?ooool001kooooo00?o0000ooooooooool03?ooool2o`0000Ko
oooo0_l0000`ooooo`;o00003oooool2o`0000cooooo0_l0001gooooo`;o00009Oooool2o`0001co
oooo0_l0000Rooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o0000=oooool2o`0000Sooooo
0_l00005ooooo`;o00009_ooool2o`00027ooooo0_l0000cooooo`;o0000<_ooool2o`0000kooooo
0ol0000Rooooo`007_ooool00ol0003oooooooooo`02o`0004_ooooo0_l0000?ooooo`;o00007_oo
ool2o`0000Kooooo0_l0000Qooooo`;o0000Ioooool2o`0000kooooo0_l0000Sooooo`007_ooool0
0ol0003oooooooooo`02o`0000;ooooo0_l0000Xooooo`;o0000C_ooool2o`000:Kooooo0_l0000O
ooooo`007_ooool00ol0003oooooooooo`04ooooo`;o0000:?ooool2o`0001;ooooo0_l0002<oooo
o`Co0000D_ooool2o`00013ooooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o
0000<_ooool2o`0000Sooooo0_l0000>ooooo`;o00008Oooool2o`0004oooooo1?l0000:ooooo`;o
0000Doooool2o`0000?ooooo0_l0000=ooooo`007_ooool2o`0000oooooo0_l0000fooooo`;o0000
1?ooool2o`0000kooooo0_l0000Qooooo`;o0000>?ooool2o`0001Wooooo0_l00008ooooo`;o0000
4_ooool4o`0003gooooo0_l0000Booooo`007_ooool00ol0003oooooooooo`16ooooo`;o000000?o
ooooo`000?l00000K_ooool2o`0001Wooooo0_l0000Looooo`Co0000DOooool001kooooo00?o0000
ooooooooool07?ooool2o`0002_ooooo0_l0000;ooooo`;o00002Oooool2o`0003oooooo0_l0001_
ooooo`;o0000<_ooool001kooooo00?o0000ooooooooool07?ooool2o`0002gooooo0_l00009oooo
o`;o00002Oooool2o`00033ooooo0_l0000=ooooo`;o0000?oooool2o`0002kooooo0_l0000boooo
o`007_ooool00ol0003oooooooooo`10ooooo`;o00002Oooool2o`0004Kooooo0_l0001>ooooo`;o
0000H_ooool001kooooo00?o0000ooooooooool0=_ooool2o`0000Sooooo0_l0001`ooooo`;o0000
4?ooool2o`0003Sooooo0_l00017ooooo`007_ooool00ol0003oooooooooo`0fooooo`;o0000N_oo
ool2o`00013ooooo0_l0000hooooo`;o00000oooool2o`0004;ooooo000Nooooo`03o`000?oooooo
oooo04oooooo0_l0002booooo`;o0000=_ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo
04Cooooo0_l00009ooooo`;o0000LOooool2o`0000Sooooo0_l0000<ooooo`;o00006_ooool2o`00
04?ooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`14ooooo`;o00005_ooool2o`0006Co
oooo0_l00008ooooo`;o00003?ooool2o`0001[ooooo0_l0001?ooooo`007_ooool00ol0003ooooo
ooooo`1Looooo`;o00007oooool2o`0000[ooooo0_l0000Oooooo`?o0000=_ooool2o`0003Oooooo
0_l0000Yooooo`007_ooool00ol0003oooooooooo`0fooooo`;o0000AOooool2o`0000[ooooo0_l0
000Oooooo`?o00002Oooool2o`0002_ooooo0_l0000>ooooo`;o00004Oooool2o`0001Cooooo0_l0
000Yooooo`007_ooool00ol0003oooooooooo`0Rooooo`;o00004_ooool2o`0001Sooooo0_l0000Y
ooooo`;o0000>Oooool2o`0000cooooo0_l0000Fooooo`;o00005Oooool2o`00017ooooo0_l0000g
ooooo`;o00001_ooool001kooooo00?o0000ooooooooool08_ooool2o`0002cooooo0_l0000@oooo
o`;o00005oooool2o`0004;ooooo0_l00003ooooo`;o00005_ooool2o`00033ooooo0_l0000Koooo
o`;o00004_ooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo06;ooooo0_l0000Rooooo`;o
0000=oooool2o`00023ooooo0_l0000[ooooo`;o00006oooool2o`0001[ooooo000Nooooo`03o`00
0?oooooooooo03Kooooo0_l00018ooooo`;o00001?ooool2o`0005Wooooo0_l0001Tooooo`007_oo
ool2o`000003ooooool0003o000003Cooooo0_l00018ooooo`;o0000Doooool2o`00073ooooo000N
ooooo`03o`000?oooooooooo00;o0000BOooool2o`0002cooooo0_l0000Booooo`;o00000_ooool2
o`0004;ooooo0ol00009ooooo`;o0000I?ooool001kooooo00?o0000ooooooooool0Boooool2o`00
02cooooo0_l0000Booooo`;o00000_ooool2o`0001Cooooo0_l0000]ooooo`;o00001?ooool2o`00
00?ooooo0_l0001<ooooo`;o00005_ooool001kooooo00?o0000ooooooooool0K_ooool2o`0003Oo
oooo0_l0000cooooo`;o00005?ooool2o`0002_ooooo0_l0000>ooooo`;o00005_ooool001kooooo
00?o0000ooooooooool0>?ooool2o`0003Cooooo0_l00022ooooo`;o00000oooool2o`0002Kooooo
0_l0000Vooooo`007_ooool00ol0003oooooooooo`0hooooo`Co0000^oooool2o`0004kooooo000N
ooooo`03o`000?oooooooooo03[ooooo0_l0001Pooooo`;o0000:?ooool2o`0002cooooo0_l00004
ooooo`;o00002?ooool2o`00047ooooo000Nooooo`03o`000?oooooooooo05Cooooo0_l0000<oooo
o`;o0000>?ooool2o`0002Sooooo0_l0000Tooooo`;o00001_ooool2o`0000Cooooo0_l00008oooo
o`;o00005_ooool4o`0002Oooooo000Nooooo`03o`000?oooooooooo04gooooo0_l00005ooooo`;o
00003?ooool2o`0002[ooooo0_l0000Eooooo`;o0000??ooool2o`0000Oooooo0_l0000^ooooo`Co
00009oooool001kooooo00?o0000ooooooooool0B?ooool2o`0000?ooooo0_l00003ooooo`;o0000
>_ooool2o`0001Gooooo0_l0000Booooo`;o0000:?ooool2o`0002?ooooo0_l0000mooooo`007_oo
ool00ol0003oooooooooo`0Nooooo`;o0000:?ooool2o`0000Sooooo0_l0001Uooooo`;o0000COoo
ool2o`0003gooooo000Nooooo`03o`000?oooooooooo01kooooo0_l00005ooooo`;o00005?ooool2
o`0001cooooo0_l0001dooooo`;o00003?ooool2o`000003ooooool0003o000005Gooooo0_l0000>
ooooo`007_ooool00ol0003oooooooooo`0Rooooo`;o000000?oooooo`000?l000005?ooool2o`00
00;ooooo0_l0000Eooooo`;o000000?oooooo`000?l00000M?ooool2o`0000cooooo0_l000000ooo
oooo0000o`00001Eooooo`;o00003_ooool001kooooo00?o0000ooooooooool08_ooool2o`0001_o
oooo0_l0000Eooooo`;o0000;oooool2o`000:3ooooo0_l0000Looooo`000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0
003oooooooooo`1aooooo`;o00005?ooool2o`000:3ooooo0_l0000Looooo`000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool0
0ol0003oooooooooo`0Kooooo`;o0000>_ooool2o`0001Sooooo0_l0003Dooooo`000oooool01Ol@
413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o00006ooo
ool2o`0000cooooo0_l0000/ooooo`;o0000M_ooool2o`0001?ooooo0_l0000dooooo`;o0000:ooo
ool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40
1_ooool00ol0003oooooooooo`0Yooooo`;o00009Oooool2o`0001Gooooo0_l0001Vooooo`;o0000
1Oooool2o`0000cooooo0_l0000Fooooo`;o00007?ooool2o`0002_ooooo0003ooooo`05o`000?oo
ooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000oooooooo
ool0D?ooool2o`0001Gooooo0_l0001]ooooo`;o00009?ooool2o`0001cooooo0_l0000[ooooo`00
0oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003o
ooooooooo`1:ooooo`;o00006oooool2o`0002[ooooo0_l0001Eooooo`;o00005?ooool2o`0000_o
oooo0_l0000Qooooo`;o00005Oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03
omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool06?ooool2o`0001Oooooo0_l0000Gooooo`;o
000000?oooooo`000?l000006?ooool2o`0002[ooooo0_l000000ooooooo0000o`00001Booooo`;o
00005?ooool2o`0000_ooooo0_l0000Qooooo`;o00005Oooool000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool03?ooool2o`00
00[ooooo0_l00004ooooo`;o00004Oooool2o`0000Sooooo0_l0000@ooooo`;o0000Aoooool2o`00
00[ooooo0_l0000>ooooo`;o0000C?ooool2o`0004Gooooo000Nooooo`03o`000?oooooooooo00co
oooo0_l0000@ooooo`;o00006oooool2o`0005[ooooo0_l00009ooooo`;o00002Oooool2o`0000?o
oooo0_l0000;ooooo`;o00005Oooool2o`0006oooooo000Nooooo`03o`000?oooooooooo08gooooo
0_l00008ooooo`;o00005?ooool2o`00013ooooo0_l0000Eooooo`;o0000Koooool001kooooo00?o
0000ooooooooool0@oooool2o`0000oooooo0_l0000Gooooo`;o00007_ooool2o`0002[ooooo0_l0
002<ooooo`007_ooool00ol0003oooooooooo`02ooooo`;o0000?oooool2o`0000oooooo0_l0000G
ooooo`;o0000B_ooool2o`0004Cooooo0_l00002ooooo`;o00004Oooool2o`0002oooooo000Noooo
o`03o`000?oooooooooo00;ooooo0_l0001Oooooo`;o00003?ooool2o`00023ooooo0_l0001Zoooo
o`;o00000_ooool2o`00017ooooo0_l0000_ooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o
0000Eoooool2o`0000cooooo0_l0000Pooooo`Co0000Loooool2o`0003_ooooo000Nooooo`03o`00
0?oooooooooo00[ooooo0_l00029ooooo`;o0000I_ooool2o`0000_ooooo0_l0000kooooo`007_oo
ool01?l0003oooooooooooooool2o`000?[ooooo0_l00018ooooo`007_ooool01?l0003ooooooooo
ooooool2o`0004kooooo0_l0000Oooooo`;o00008Oooool2o`000;3ooooo000Nooooo`03o`000?oo
oooooooo057ooooo0_l0000Oooooo`;o00008Oooool2o`00013ooooo0_l0001`ooooo`;o0000;?oo
ool001kooooo00?o0000ooooooooool0G?ooool2o`0000[ooooo0_l0000hooooo`;o00000oooool2
o`0001gooooo0_l0000Fooooo`;o00000_ooool2o`0000oooooo0_l0000Tooooo`;o00007_ooool2
o`0000cooooo000Nooooo`?o0000G?ooool2o`0000[ooooo0_l0000hooooo`;o00004?ooool2o`00
013ooooo0_l0000<ooooo`;o00002?ooool2o`0000;ooooo0_l0000?ooooo`;o0000A?ooool2o`00
00cooooo000Nooooo`?o0000G?ooool2o`0005Kooooo0_l0000Nooooo`;o00001Oooool2o`0004Co
oooo0_l0000Tooooo`007_ooool00ol0003oooooooooo`0eooooo`;o00009Oooool2o`0005?ooooo
0_l0000Aooooo`;o00005Oooool2o`0004Cooooo0_l0000Tooooo`007_ooool00ol0003ooooooooo
o`0eooooo`;o0000Eoooool2o`00027ooooo0_l0000Aooooo`;o0000M_ooool2o`0000Wooooo000N
ooooo`03o`000?oooooooooo02_ooooo0_l0000?ooooo`;o0000:oooool2o`0002?ooooo0_l00011
ooooo`;o0000AOooool2o`0002;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`0[oooo
o`;o00003oooool2o`00017ooooo0_l0000Hooooo`;o00005?ooool2o`0001Gooooo0_l0000^oooo
o`;o00002Oooool2o`0004Gooooo0_l0000]ooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o
0000;_ooool2o`0000Wooooo0_l0000Kooooo`;o00001_ooool2o`0001Gooooo0_l0000^ooooo`;o
0000Ooooool001kooooo00?o0000ooooooooool07oooool2o`0000Wooooo0_l0000@ooooo`;o0000
7?ooool2o`0000Wooooo0_l0000@ooooo`;o0000Foooool2o`00023ooooo0_l0001?ooooo`007_oo
ool00ol0003oooooooooo`0Zooooo`;o00004?ooool2o`0000Cooooo0_l0000Qooooo`;o0000<ooo
ool2o`0001;ooooo0_l0000Tooooo`;o00008?ooool2o`0004oooooo000Nooooo`03o`000?oooooo
oooo04;ooooo0_l00019ooooo`;o00002oooool2o`0001;ooooo0_l0000_ooooo`?o00005oooool2
o`0004cooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0001gooooo`;o0000@Oooool2o`00
00gooooo0ol0000Gooooo`;o0000C?ooool001kooooo00?o0000ooooooooool05?ooool2o`0007Ko
oooo0_l00012ooooo`;o0000Doooool2o`00023ooooo000Nooooo`04o`000?oooooo0000o`0000oo
oooo0_l0000@ooooo`Co0000;Oooool2o`0000_ooooo0_l0000@ooooo`;o00006?ooool2o`00017o
oooo0_l00013ooooo`;o0000?oooool2o`00023ooooo000Mooooo`;o000000?oooooo`000?l00000
3oooool2o`00013ooooo1?l0000Sooooo`;o00001?ooool2o`0000;ooooo0_l0000;ooooo`;o0000
4?ooool2o`0002_ooooo0_l00013ooooo`;o0000HOooool001gooooo0_l0001;ooooo`;o00001?oo
ool2o`000;_ooooo0_l0000[ooooo`;o00003?ooool001kooooo00?o0000ooooooooool04?ooool2
o`0002Wooooo0_l0002[ooooo`?o00000_ooool2o`0001gooooo0_l0000[ooooo`;o00003?ooool0
01kooooo0_l0000Aooooo`;o00003oooool2o`0001Sooooo0_l0001fooooo`;o0000<oooool3o`00
00;ooooo0_l0001<ooooo`;o00002_ooool001kooooo00?o0000ooooooooool06oooool2o`0000Co
oooo0_l0002@ooooo`;o00005oooool2o`0006gooooo0_l0000:ooooo`007_ooool00ol0003ooooo
ooooo`0Kooooo`;o0000Roooool2o`0002;ooooo0_l0001iooooo`007_ooool00ol0003ooooooooo
o`0Zooooo`;o0000O?ooool2o`0009gooooo000Nooooo`03o`000?oooooooooo02Gooooo0_l00003
ooooo`;o00002?ooool2o`0001Gooooo0_l0000[ooooo`;o0000K?ooool2o`0005oooooo000Noooo
o`03o`000?oooooooooo02Gooooo0_l0000=ooooo`;o00005Oooool2o`0002_ooooo0_l0001/oooo
o`;o0000Goooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`1/ooooo`;o00009Oooool2o`0007[ooooo0_l0000fooooo`007_ooool00ol0003ooooooooo
o`07ooooo`;o0000Coooool2o`0001;ooooo0_l0000Uooooo`;o0000N_ooool2o`0000Sooooo0_l0
000/ooooo`007_ooool00ol0003oooooooooo`07ooooo`;o00002Oooool2o`0001cooooo0_l0000V
ooooo`;o0000=Oooool2o`0008Sooooo0_l0000/ooooo`007_ooool00ol0003oooooooooo`0Boooo
o`;o00007?ooool2o`0001cooooo0_l0000oooooo`;o0000Voooool2o`0001Wooooo000Nooooo`03
o`000?oooooooooo04kooooo0_l0000nooooo`;o00004oooool2o`0006Kooooo0_l0000Kooooo`;o
00000_ooool2o`0001Wooooo000Nooooo`03o`000?oooooooooo05_ooooo0_l0000aooooo`;o0000
4oooool2o`0005;ooooo0_l0000Booooo`;o00002oooool2o`0000Sooooo0_l00004ooooo`;o0000
7Oooool001kooooo00?o0000ooooooooool07?ooool2o`0003gooooo0_l0001Booooo`;o00008Ooo
ool2o`0002?ooooo0_l0000Oooooo`;o00002?ooool2o`0002?ooooo000Nooooo`03o`000?oooooo
oooo01cooooo0_l0000looooo`;o0000Doooool2o`0000?ooooo0_l0000Looooo`;o0000?Oooool2
o`0001cooooo0_l0000Fooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o0000BOooool2o`00
00Oooooo0_l0001?ooooo`;o0000Foooool2o`0001cooooo0_l0000Fooooo`007_ooool2o`00013o
oooo0_l0001Booooo`;o0000SOooool2o`0005?ooooo000Nooooo`03o`000?oooooooooo05Oooooo
0_l00007ooooo`;o0000T?ooool2o`0005?ooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l0
000Vooooo`;o00002Oooool2o`0000Oooooo0_l0003Uooooo`007_ooool00ol0003oooooooooo`0T
ooooo`;o00003Oooool2o`000003ooooool0003o000001Cooooo0_l0001Gooooo`;o00000_ooool2
o`0004;ooooo0ol0000Iooooo`;o00005oooool2o`0000Kooooo0_l0000Kooooo`007_ooool00ol0
003oooooooooo`0cooooo`;o000000?oooooo`000?l000001Oooool2o`00047ooooo0_l0000Soooo
o`;o00000_ooool2o`0001gooooo0_l0000Gooooo`;o00002_ooool3o`000003ooooool0003o0000
01Kooooo0_l0000Gooooo`;o00001_ooool2o`0001_ooooo000Nooooo`03o`000?oooooooooo00[o
oooo0_l0000aooooo`;o0000@Oooool2o`0004Kooooo0_l0000Gooooo`;o00003_ooool2o`0002ko
oooo0_l0000Tooooo`007_ooool3o`0000[ooooo0_l0003ooooooaKooooo0_l0000Jooooo`;o0000
2?ooool001kooooo0ol0001Jooooo`;o0000hOooool2o`0000Sooooo000Nooooo`03o`000?oooooo
oooo05[ooooo0_l00037ooooo`;o00008_ooool001kooooo00?o0000ooooooooool0b?ooool2o`00
05Wooooo0_l0000Eooooo`;o00002oooool001kooooo00?o0000ooooooooool09?ooool2o`0004oo
oooo0_l00018ooooo`;o00001oooool2o`0001_ooooo0ol0001Booooo`;o00002oooool001kooooo
00?o0000ooooooooool09?ooool2o`0004oooooo0_l00018ooooo`;o00009?ooool3o`0003Gooooo
0_l0000Xooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o00003oooool2o`0004?ooooo0_l0
001eooooo`;o0000;oooool2o`0000Wooooo0_l0000Dooooo`;o00001oooool001kooooo00?o0000
ooooooooool07oooool2o`0000oooooo0_l00013ooooo`;o0000D_ooool2o`0001cooooo0_l00003
ooooo`;o0000<_ooool2o`0000Kooooo0_l0000Dooooo`;o00001oooool000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o
0000ooooooooool0;?ooool2o`0009_ooooo0_l0000Looooo`;o00008_ooool2o`0001?ooooo0_l0
000Uooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0/ooooo`;o0000gOooool2o`0001_ooooo
0_l0000Mooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooooooo
ooooo`000006ooooo`?o0000oooooolMooooo`;o00002_ooool2o`0001gooooo0003ooooo`05o`00
0?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000oooo
ooooool0b_ooool2o`0000Wooooo0_l00015ooooo`;o00002Oooool2o`0001kooooo0003ooooo`05
o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000
ooooooooool0O_ooool2o`0004[ooooo0_l00009ooooo`;o0000D?ooool2o`0001kooooo0003oooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o
0000ooooooooool0O_ooool2o`000<Oooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0=_ooool2o`0004kooooo
0_l0002<ooooo`;o0000<Oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`02o`0003Cooooo0_l0000<ooooo`;o
0000@?ooool2o`0007cooooo0_l0000>ooooo`;o00006_ooool2o`0001Gooooo000Nooooo`03o`00
0?oooooooooo00;o0000@_ooool2o`0008_ooooo0_l0000Nooooo`;o00004Oooool2o`0002[ooooo
0_l0000Eooooo`007_ooool00ol0003oooooooooo`0kooooo`;o0000U?ooool2o`0001kooooo0_l0
001Dooooo`007_ooool00ol0003oooooooooo`0kooooo`;o0000@?ooool2o`000<Sooooo000Noooo
o`03o`000?oooooooooo03Sooooo0_l00007ooooo`;o00005oooool2o`00027ooooo0_l0002Yoooo
o`;o00007Oooool001kooooo00?o0000ooooooooool0>?ooool2o`0000Oooooo0_l0000Gooooo`;o
0000]Oooool2o`0001Gooooo0_l0000Mooooo`007_ooool00ol0003oooooooooo`0Yooooo`;o0000
[oooool2o`0002Sooooo0_l0000;ooooo`;o00001_ooool2o`0002cooooo000Nooooo`03o`000?oo
oooooooo01Gooooo0_l0000Booooo`;o0000E?ooool2o`0001Sooooo0_l00005ooooo`;o0000>?oo
ool2o`0002Sooooo0ol0000Booooo`;o0000;?ooool001kooooo00?o0000ooooooooool05Oooool2
o`0004Sooooo0_l0000Nooooo`;o00006?ooool2o`0000Gooooo0_l0000Yooooo`;o0000>?ooool2
o`00043ooooo000Nooooo`03o`000?oooooooooo05oooooo0_l0001Zooooo`;o0000?_ooool4o`00
03Sooooo000Nooooo`03o`000?oooooooooo01?ooooo0_l0000Yooooo`;o0000MOooool2o`0003?o
oooo0_l0000Oooooo`Co0000>?ooool001kooooo00?o0000ooooooooool04oooool2o`0002Wooooo
0_l0000Mooooo`;o0000E_ooool2o`0003?ooooo0_l0001Kooooo`007_ooool4o`0005cooooo0_l0
000nooooo`;o0000Z?ooool001kooooo00Co0000ooooool0003o00005Oooool2o`0002Cooooo1?l0
001Mooooo`;o0000Z?ooool001kooooo00?o0000ooooooooool05_ooool2o`00013ooooo0_l0000B
ooooo`Co0000:_ooool2o`000:Gooooo0_l0000dooooo`007_ooool00ol0003oooooooooo`0Xoooo
o`;o0000@?ooool2o`00033ooooo0_l0001Vooooo`;o00002oooool2o`0003Cooooo000Nooooo`03
o`000?oooooooooo09cooooo0_l00004ooooo`;o0000A?ooool2o`0001[ooooo0_l0000Nooooo`;o
00008Oooool001kooooo00?o0000ooooooooool0??ooool2o`0006Cooooo0_l00014ooooo`;o0000
>_ooool2o`00027ooooo000Nooooo`03o`000?oooooooooo03cooooo0_l0000Oooooo`;o00008?oo
ool2o`000:Oooooo0_l0000Mooooo`007_ooool00ol0003oooooooooo`04ooooo`;o00004?ooool2
o`0002gooooo0_l0000Fooooo`;o00008?ooool2o`000:Oooooo0_l0000Mooooo`007_ooool00ol0
003oooooooooo`04ooooo`;o00003?ooool2o`0000;ooooo0_l0000]ooooo`;o0000ooooool1oooo
o`007_ooool00ol0003oooooooooo`0@ooooo`Co00004?ooool2o`0003?ooooo0_l0000eooooo`;o
0000]Oooool001kooooo00?o0000ooooooooool04?ooool2o`0001;ooooo0_l0000aooooo`Co0000
=Oooool2o`0007kooooo0_l0000eooooo`007_ooool00ol0003oooooooooo`1Gooooo`;o0000??oo
ool2o`0007Wooooo0_l000000ooooooo0000o`00000booooo`007_ooool00ol0003oooooooooo`0L
ooooo`;o00006oooool2o`0005[ooooo0_l0001looooo`;o0000<_ooool001kooooo00?o0000oooo
ooooool07?ooool2o`0001_ooooo0_l0001Qooooo`;o0000ZOooool001kooooo00?o0000oooooooo
ool0I?ooool2o`0003Kooooo0_l0000Xooooo`;o0000Ooooool001kooooo00?o0000ooooooooool0
I?ooool2o`00063ooooo0_l0001Oooooo`;o00007_ooool001kooooo0ol000000ooooooo0000o`00
002?ooooo`;o0000A_ooool2o`0004_ooooo0_l00007ooooo`;o00005Oooool001kooooo1_l0000E
ooooo`;o0000LOooool2o`0000Gooooo0_l00016ooooo`;o0000E?ooool2o`0001Gooooo000Noooo
o`03o`000?oooooooooo00;o00005_ooool2o`00077ooooo0_l0002jooooo`007_ooool00ol0003o
ooooooooo`1jooooo`;o0000K?ooool2o`0005gooooo000Nooooo`03o`000?oooooooooo06Oooooo
0_l0000Aooooo`;o00007oooool2o`0004_ooooo0_l0001Mooooo`007_ooool00ol0003ooooooooo
o`1Wooooo`;o0000<_ooool2o`00017ooooo0_l0001Iooooo`;o0000??ooool001kooooo00?o0000
ooooooooool0=_ooool2o`0007Kooooo0_l0000gooooo`;o00005_ooool2o`0000Sooooo0_l0000B
ooooo`;o0000:?ooool001kooooo00?o0000ooooooooool0=_ooool2o`0002Oooooo0_l0000?oooo
o`;o00007?ooool2o`0005Oooooo0_l0000Fooooo`;o00007?ooool2o`0002Sooooo000Nooooo`03
o`000?oooooooooo05oooooo0_l0000?ooooo`;o00007?ooool2o`0007Sooooo0_l0000mooooo`00
7_ooool00ol0003oooooooooo`2Gooooo`;o0000Koooool2o`0003gooooo000Nooooo`03o`000?oo
oooooooo023ooooo0_l0000gooooo`;o0000<_ooool2o`0000Sooooo0_l00025ooooo`;o00009ooo
ool001kooooo00?o0000ooooooooool08?ooool2o`0003Oooooo0_l0000@ooooo`;o00008?ooool2
o`0008oooooo0_l0000Wooooo`007_ooool00ol0003oooooooooo`1[ooooo`;o0000f_ooool001ko
oooo00?o0000ooooooooool01?ooool2o`0001kooooo0_l0003oooooob;ooooo000Nooooo`03o`00
0?oooooooooo00Cooooo0_l0000Nooooo`;o0000oooooolRooooo`007_ooool00ol0003ooooooooo
o`14ooooo`;o0000coooool2o`0001Cooooo0_l0000@ooooo`;o00002?ooool001kooooo0_l0000A
ooooo`;o0000<_ooool2o`0004cooooo0_l00021ooooo`;o00005?ooool2o`00013ooooo0_l00008
ooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o00000_ooool2o`00083ooooo0_l00017oooo
o`;o0000>oooool2o`0002gooooo000Nooooo`03o`000?oooooooooo00cooooo0_l0000Nooooo`;o
00002?ooool2o`000:?ooooo0_l0000Tooooo`;o00005Oooool2o`0002gooooo000Nooooo`03o`00
0?oooooooooo02cooooo0_l00008ooooo`;o00008Oooool2o`0009Cooooo0_l0000@ooooo`;o0000
5?ooool2o`0002kooooo000Nooooo`03o`000?oooooooooo05Wooooo0_l0002?ooooo`;o00000ooo
ool2o`0002Gooooo1Ol0000/ooooo`007_ooool00ol0003oooooooooo`0]ooooo`;o0000>oooool2
o`0007kooooo0_l0000Zooooo`;o000000?oooooo`000?l000006Oooool2o`00017ooooo000Noooo
o`03o`000?oooooooooo02gooooo0_l0000kooooo`;o00006Oooool2o`0008;ooooo0_l0000Yoooo
o`;o00004Oooool001kooooo00?o0000ooooooooool0D?ooool2o`0000?ooooo0_l0000^ooooo`;o
0000F?ooool2o`0002Sooooo0_l0000looooo`007_ooool00ol0003oooooooooo`0Dooooo`;o0000
1?ooool2o`0003Cooooo0_l00003ooooo`;o00001_ooool2o`0003kooooo0_l0000nooooo`Co0000
6Oooool2o`0004_ooooo000Nooooo`;o00005Oooool2o`0000Cooooo0_l00011ooooo`;o0000?_oo
ool2o`0003kooooo0_l0000Kooooo`;o00006?ooool2o`00037ooooo000Nooooo`;o0000coooool2
o`0004Cooooo0_l0000aooooo`007_ooool00ol0003oooooooooo`3>ooooo`;o0000Moooool001ko
oooo00?o0000ooooooooool09?ooool2o`0000cooooo0_l00005ooooo`;o0000;_ooool2o`00073o
oooo0_l0000Gooooo`;o0000DOooool001kooooo00?o0000ooooooooool09?ooool2o`0000cooooo
0_l00005ooooo`;o0000;_ooool2o`0000Gooooo0_l0000Rooooo`;o00003?ooool2o`0003Oooooo
0_l00002ooooo`;o00004oooool2o`00057ooooo000Dooooo`Co000000?o410@ooooooooool00ooo
ool00ol0003oooooooooo`0hooooo`;o00009_ooool2o`0000kooooo0_l00006ooooo`;o00006_oo
ool2o`0000cooooo0_l0000kooooo`;o00003Oooool2o`0003_ooooo0_l0000<ooooo`;o00003?oo
ool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0hooooo`;o00009_ooool2
o`0001Kooooo0_l0001dooooo`;o0000>oooool2o`0000cooooo0_l00002ooooo`;o00002?ooool0
01Kooooo00?o0000ooooooooool01Oooool3o`00067ooooo0_l0000cooooo`;o00001?ooool2o`00
02cooooo0_l0001aooooo`;o00002?ooool001Kooooo00?o0000ooooooooool0JOooool2o`0003?o
oooo0_l00004ooooo`;o0000;?ooool2o`0007_ooooo000Fooooo`03o`000?oooooooooo0?oooooo
D?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3o
oooooe3ooooo000Dooooo`03oeEEEOmVIVKo00000?ooooooD_ooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.27353 .60848 Mdot
.87689 .65933 Mdot
.77598 .0037 Mdot
.16623 .54994 Mdot
.10904 .57606 Mdot
.84823 .93671 Mdot
.2056 .78738 Mdot
.22925 .69024 Mdot
.72318 .18719 Mdot
.07512 .02107 Mdot
.5933 .07948 Mdot
.84768 .5874 Mdot
.88345 .56455 Mdot
.22841 .64129 Mdot
.49667 .32179 Mdot
.137 .72952 Mdot
.43475 .92004 Mdot
.5746 .46133 Mdot
.85054 .9661 Mdot
.71064 .06595 Mdot
.59538 .1573 Mdot
.66346 .06106 Mdot
.64263 .96432 Mdot
.26969 .27401 Mdot
.66051 .27765 Mdot
.08236 .33899 Mdot
.77563 .00484 Mdot
.5832 .38921 Mdot
.0628 .58781 Mdot
.28063 .38673 Mdot
.52538 .35202 Mdot
.22551 .54336 Mdot
.42945 .90217 Mdot
.1431 .1217 Mdot
.68291 .9339 Mdot
.15037 .56846 Mdot
.06385 .35541 Mdot
.39095 .15672 Mdot
.29127 .93043 Mdot
.94412 .02558 Mdot
.12355 .40541 Mdot
.49218 .05698 Mdot
.24463 .55794 Mdot
.15829 .49344 Mdot
.53738 .46785 Mdot
.72412 .57063 Mdot
.9786 .26802 Mdot
.75288 .56242 Mdot
.38272 .60494 Mdot
.93774 .48251 Mdot
.62838 .36788 Mdot
.23766 .498 Mdot
.17704 .57639 Mdot
.99451 .36997 Mdot
.73214 .33289 Mdot
.61033 .30442 Mdot
.4335 .94789 Mdot
.99013 .68039 Mdot
.09549 .43401 Mdot
.05208 .67147 Mdot
.28114 .48872 Mdot
.59075 .75389 Mdot
.26351 .1215 Mdot
.01444 .22826 Mdot
.27063 .50969 Mdot
.39892 .10653 Mdot
.52072 .64721 Mdot
.61807 .3042 Mdot
.31885 .51842 Mdot
.977 .08203 Mdot
.72422 .68031 Mdot
.70055 .04134 Mdot
.1707 .74299 Mdot
.01115 .9785 Mdot
.09168 .62461 Mdot
.43672 .2482 Mdot
.74015 .53149 Mdot
.08363 .96502 Mdot
.66484 .06818 Mdot
.40039 .11853 Mdot
.53763 .39958 Mdot
.52688 .16712 Mdot
.21838 .06948 Mdot
.61458 .47851 Mdot
.91301 .18456 Mdot
.62815 .40071 Mdot
.56243 .88508 Mdot
.84093 .3917 Mdot
.56674 .12788 Mdot
.72782 .4171 Mdot
.99788 .03488 Mdot
.35249 .13148 Mdot
.30988 .75091 Mdot
.87007 .21589 Mdot
.8536 .82502 Mdot
.53616 .66126 Mdot
.02262 .52779 Mdot
.79955 .53522 Mdot
.51898 .49941 Mdot
.04569 .98223 Mdot
.61941 .22828 Mdot
.78571 .45499 Mdot
.92514 .78781 Mdot
.18102 .24651 Mdot
.89742 .83625 Mdot
.17601 .98786 Mdot
.69839 .21869 Mdot
.09715 .25147 Mdot
.16054 .20303 Mdot
.26351 .65307 Mdot
.71285 .63252 Mdot
.12696 .10653 Mdot
.66759 .60189 Mdot
.16557 .44313 Mdot
.3605 .44897 Mdot
.28554 .74214 Mdot
.57596 .67514 Mdot
.13951 .9541 Mdot
.96149 .75574 Mdot
.64445 .80145 Mdot
.76604 .59518 Mdot
.53598 .03294 Mdot
.21871 .88417 Mdot
.28047 .69297 Mdot
.35435 .31612 Mdot
.66962 .61451 Mdot
.78818 .09066 Mdot
.96706 .56024 Mdot
.33652 .78991 Mdot
.60608 .11835 Mdot
.29294 .2539 Mdot
.27442 .46589 Mdot
.30886 .77954 Mdot
.24057 .45192 Mdot
.83598 .75723 Mdot
.3445 .64519 Mdot
.42346 .03663 Mdot
.1116 .13353 Mdot
.64667 .85675 Mdot
.39875 .4783 Mdot
.32495 .97369 Mdot
.86313 .01195 Mdot
.89801 .54049 Mdot
.20387 .56108 Mdot
.89908 .29016 Mdot
.27786 .77733 Mdot
.98349 .73823 Mdot
.24674 .36353 Mdot
.13619 .5064 Mdot
.93707 .23565 Mdot
.25267 .37421 Mdot
.54683 .4146 Mdot
.16569 .43689 Mdot
.89498 .78537 Mdot
.94176 .38424 Mdot
.912 .60987 Mdot
.06214 .38312 Mdot
.49535 .72049 Mdot
.48173 .04918 Mdot
.23268 .48019 Mdot
.2074 .19326 Mdot
.90576 .27318 Mdot
.00824 .95721 Mdot
.12902 .12318 Mdot
.85263 .46694 Mdot
.01927 .9711 Mdot
.69545 .80063 Mdot
.06214 .23048 Mdot
.80278 .49539 Mdot
.1945 .62449 Mdot
.08277 .4042 Mdot
.85425 .56508 Mdot
.31357 .99908 Mdot
.42172 .05415 Mdot
.35148 .23422 Mdot
.23615 .37039 Mdot
.29768 .86827 Mdot
.20635 .34467 Mdot
.0685 .22319 Mdot
.76697 .03849 Mdot
.01372 .57554 Mdot
.88487 .56703 Mdot
.1322 .41795 Mdot
.14827 .93545 Mdot
.68234 .55955 Mdot
.162 .72268 Mdot
.18092 .30722 Mdot
.66935 .96526 Mdot
.59009 .63913 Mdot
.5175 .86614 Mdot
.30413 .08331 Mdot
.40704 .73827 Mdot
.43516 .73017 Mdot
.72502 .58172 Mdot
.99438 .9296 Mdot
.69669 .50988 Mdot
.71475 .5074 Mdot
.56437 .54266 Mdot
.25248 .93407 Mdot
.52544 .28715 Mdot
.26038 .53009 Mdot
.02436 .5221 Mdot
.58282 .70131 Mdot
.21381 .87783 Mdot
.23556 .33242 Mdot
.25666 .72618 Mdot
.42889 .55258 Mdot
.71994 .06462 Mdot
.77371 .99805 Mdot
.57444 .13564 Mdot
.32525 .96358 Mdot
.29112 .87248 Mdot
.95055 .20705 Mdot
.7819 .47069 Mdot
.68587 .77036 Mdot
.63848 .492 Mdot
.30866 .10076 Mdot
.61985 .20473 Mdot
.04966 .71237 Mdot
.61668 .81024 Mdot
.87543 .76225 Mdot
.26709 .4744 Mdot
.14314 .0113 Mdot
.22832 .40639 Mdot
.25227 .91987 Mdot
.11789 .79169 Mdot
.8918 .04169 Mdot
.90015 .23973 Mdot
.4975 .59204 Mdot
.0731 .68082 Mdot
.27867 .98033 Mdot
.03998 .53535 Mdot
.28551 .58885 Mdot
.03309 .78166 Mdot
.14566 .80756 Mdot
.94698 .89598 Mdot
.41664 .1557 Mdot
.65323 .67082 Mdot
.96094 .16474 Mdot
.23473 .74467 Mdot
.20931 .81291 Mdot
.22359 .04863 Mdot
.93143 .87097 Mdot
.05903 .0381 Mdot
.69427 .65949 Mdot
.52924 .01869 Mdot
.33713 .90863 Mdot
.67034 .6947 Mdot
.20031 .15974 Mdot
.19338 .60827 Mdot
.28495 .39442 Mdot
.66015 .50349 Mdot
.22632 .3706 Mdot
.72064 .75456 Mdot
.71098 .5851 Mdot
.05971 .66559 Mdot
.13408 .50363 Mdot
.04814 .01922 Mdot
.25326 .24892 Mdot
.92385 .91965 Mdot
.45855 .75894 Mdot
.47113 .35885 Mdot
.63487 .32141 Mdot
.54937 .41341 Mdot
.11698 .9112 Mdot
.03279 .41915 Mdot
.42924 .92206 Mdot
.29796 .67725 Mdot
.53933 .07706 Mdot
.87813 .55051 Mdot
.7997 .42262 Mdot
.15069 .30476 Mdot
.50964 .98328 Mdot
.34516 .44381 Mdot
.25754 .67672 Mdot
.8272 .73874 Mdot
.93935 .73454 Mdot
.86066 .22472 Mdot
.46009 .48326 Mdot
.89857 .94104 Mdot
.90229 .1289 Mdot
.57985 .25604 Mdot
.87435 .71411 Mdot
.85703 .46671 Mdot
.47166 .30182 Mdot
.62885 .18268 Mdot
.71766 .38091 Mdot
.82352 .32986 Mdot
.82037 .44092 Mdot
.84687 .90141 Mdot
.16915 .46973 Mdot
.20898 .20967 Mdot
.13119 .96984 Mdot
.95067 .6357 Mdot
.82387 .13784 Mdot
.70771 .28665 Mdot
.28216 .30846 Mdot
.64961 .3979 Mdot
.78253 .44523 Mdot
.25176 .12698 Mdot
.40957 .4231 Mdot
.72248 .18153 Mdot
.23877 .50279 Mdot
.862 .95873 Mdot
.5786 .37191 Mdot
.28547 .37795 Mdot
.35313 .99933 Mdot
.58089 .07662 Mdot
.39467 .00291 Mdot
.48928 .6777 Mdot
.41939 .54526 Mdot
.76348 .56931 Mdot
.92412 .37236 Mdot
.04517 .4359 Mdot
.14371 .99352 Mdot
.29207 .61736 Mdot
.76049 .93639 Mdot
.27354 .61049 Mdot
.6853 .33056 Mdot
.55453 .26826 Mdot
.92026 .03082 Mdot
.14546 .87007 Mdot
.49339 .27603 Mdot
.61794 .09086 Mdot
.39527 .42128 Mdot
.66594 .43065 Mdot
.94075 .42987 Mdot
.39517 .40873 Mdot
.91469 .14525 Mdot
.39938 .12692 Mdot
.01378 .67236 Mdot
.20676 .81639 Mdot
.28801 .34572 Mdot
.67221 .92616 Mdot
.03106 .71162 Mdot
.26227 .70218 Mdot
.2526 .12888 Mdot
.35449 .47961 Mdot
.976 .42843 Mdot
.79116 .27279 Mdot
.88811 .97863 Mdot
.29277 .89193 Mdot
.21424 .45195 Mdot
.55782 .79083 Mdot
.14069 .41622 Mdot
.43323 .0244 Mdot
.38006 .24992 Mdot
.83547 .81425 Mdot
.37189 .70191 Mdot
.22371 .62736 Mdot
.2818 .03407 Mdot
.76493 .68343 Mdot
.10574 .46376 Mdot
.66286 .35161 Mdot
.85773 .83465 Mdot
.8121 .01469 Mdot
.17568 .30487 Mdot
.1351 .32141 Mdot
.74666 .34327 Mdot
.67254 .0696 Mdot
.91384 .84377 Mdot
.5409 .57529 Mdot
.64504 .55872 Mdot
.69197 .35661 Mdot
.93084 .23638 Mdot
.494 .12397 Mdot
.07838 .4343 Mdot
.77565 .58529 Mdot
.606 .4025 Mdot
.12306 .55997 Mdot
.76246 .30065 Mdot
.86016 .08514 Mdot
.42094 .7855 Mdot
.69093 .80846 Mdot
.36854 .68917 Mdot
.4345 .85652 Mdot
.27535 .63338 Mdot
.74893 .63845 Mdot
.20479 .60907 Mdot
.23968 .08361 Mdot
.00196 .29603 Mdot
.07987 .14335 Mdot
.86716 .78398 Mdot
.6288 .29084 Mdot
.31458 .69572 Mdot
.70068 .66503 Mdot
.48458 .69584 Mdot
.21919 .69922 Mdot
.26941 .12103 Mdot
.45521 .11764 Mdot
.87286 .48638 Mdot
.24719 .94146 Mdot
.34736 .08412 Mdot
.44372 .18837 Mdot
.09247 .719 Mdot
.59263 .47728 Mdot
.83766 .93476 Mdot
.79891 .28376 Mdot
.97688 .65007 Mdot
.74617 .45682 Mdot
.96578 .40142 Mdot
.57649 .32112 Mdot
.59924 .59422 Mdot
.45326 .27714 Mdot
.34881 .45601 Mdot
.14184 .91185 Mdot
.85336 .54162 Mdot
.86903 .0625 Mdot
.37273 .48491 Mdot
.37959 .86596 Mdot
.08652 .9078 Mdot
.73348 .6599 Mdot
.91434 .7977 Mdot
.94501 .58723 Mdot
.0282 .0171 Mdot
.53111 .52514 Mdot
.26084 .1208 Mdot
.87965 .65675 Mdot
.74116 .02508 Mdot
.83796 .83357 Mdot
.77818 .5212 Mdot
.92457 .94825 Mdot
.74299 .94546 Mdot
.44682 .23252 Mdot
.52971 .06045 Mdot
.5569 .5479 Mdot
.17209 .7527 Mdot
.09196 .61953 Mdot
.62229 .55907 Mdot
.46536 .06987 Mdot
.33687 .49815 Mdot
.34865 .39456 Mdot
.64375 .12219 Mdot
.93846 .2901 Mdot
.17358 .0275 Mdot
.95666 .38569 Mdot
.43338 .32026 Mdot
.20805 .22546 Mdot
.59759 .31349 Mdot
.30523 .97007 Mdot
.57328 .44657 Mdot
.39984 .07321 Mdot
.22773 .16883 Mdot
.94469 .94779 Mdot
.94275 .17141 Mdot
.20906 .65435 Mdot
.73538 .97698 Mdot
.54144 .31734 Mdot
.52363 .57742 Mdot
.35015 .62669 Mdot
.13799 .97534 Mdot
.14828 .75677 Mdot
.88534 .43921 Mdot
.4755 .02524 Mdot
.44449 .27739 Mdot
.59884 .73498 Mdot
.54624 .63139 Mdot
.34628 .50845 Mdot
.62889 .173 Mdot
.09944 .68208 Mdot
.62101 .41233 Mdot
.3617 .01771 Mdot
.90993 .99329 Mdot
.46967 .90638 Mdot
.32864 .58127 Mdot
.23212 .7895 Mdot
.99535 .13034 Mdot
.3999 .83255 Mdot
.20829 .97142 Mdot
.90195 .53001 Mdot
.37222 .64311 Mdot
.43141 .6335 Mdot
.60024 .86889 Mdot
.02712 .36425 Mdot
.06042 .73122 Mdot
.59865 .37958 Mdot
.63851 .40029 Mdot
.51668 .52086 Mdot
.843 .12245 Mdot
.50412 .59698 Mdot
.94802 .94236 Mdot
.71652 .22455 Mdot
.74892 .04473 Mdot
.32744 .61472 Mdot
.19439 .52589 Mdot
.54931 .41867 Mdot
.34025 .39509 Mdot
.03514 .07436 Mdot
.70327 .35418 Mdot
.69885 .32296 Mdot
.29834 .05626 Mdot
.25854 .24699 Mdot
.2746 .5941 Mdot
.80319 .98623 Mdot
.17696 .38786 Mdot
.64542 .54287 Mdot
.7085 .5284 Mdot
.5831 .32303 Mdot
.05883 .38308 Mdot
.74463 .71234 Mdot
.66317 .8007 Mdot
.31315 .23769 Mdot
.49711 .33582 Mdot
.98571 .01053 Mdot
.17714 .12723 Mdot
.40175 .45727 Mdot
.88021 .45236 Mdot
.51998 .99663 Mdot
.76856 .39263 Mdot
.23031 .60199 Mdot
.77731 .39204 Mdot
.12377 .74258 Mdot
.08975 .51004 Mdot
.97959 .22506 Mdot
.82795 .35023 Mdot
.07054 .87052 Mdot
.82244 .32479 Mdot
.5097 .74543 Mdot
.96634 .24586 Mdot
.2867 .7381 Mdot
.58111 .52208 Mdot
.73236 .96028 Mdot
.92841 .47755 Mdot
.16463 .16541 Mdot
.87239 .05103 Mdot
.29069 .12254 Mdot
.34338 .70058 Mdot
.36075 .48248 Mdot
.48402 .31586 Mdot
.43506 .60678 Mdot
.80473 .63197 Mdot
.35936 .68402 Mdot
.01705 .08785 Mdot
.73802 .18844 Mdot
.01297 .78347 Mdot
.1546 .82255 Mdot
.44323 .00601 Mdot
.21408 .19906 Mdot
.91839 .2316 Mdot
.02264 .64565 Mdot
.98267 .78644 Mdot
.03558 .8328 Mdot
.51718 .26415 Mdot
.91131 .19816 Mdot
.37099 .37155 Mdot
.28608 .47441 Mdot
.82634 .7812 Mdot
.27955 .7295 Mdot
.08767 .91444 Mdot
.84028 .00699 Mdot
.76977 .55585 Mdot
.33736 .24423 Mdot
.27982 .94787 Mdot
.18507 .38279 Mdot
.71005 .72001 Mdot
.65814 .04902 Mdot
.47196 .89165 Mdot
.12782 .04337 Mdot
.43681 .63015 Mdot
.17715 .61169 Mdot
.03287 .62144 Mdot
.85507 .81887 Mdot
.92057 .08445 Mdot
.33611 .58318 Mdot
.85563 .65431 Mdot
.90706 .14191 Mdot
.67127 .25174 Mdot
.85112 .06948 Mdot
.62518 .00701 Mdot
.9577 .76308 Mdot
.4714 .13384 Mdot
.11072 .89591 Mdot
.88863 .81454 Mdot
.9369 .79295 Mdot
.8958 .39979 Mdot
.91498 .15662 Mdot
.35764 .91199 Mdot
.29639 .00684 Mdot
.46753 .04564 Mdot
.35315 .97639 Mdot
.8245 .34908 Mdot
.56901 .98768 Mdot
.30212 .21739 Mdot
.86376 .22341 Mdot
.06161 .87294 Mdot
.64797 .57776 Mdot
.04895 .26075 Mdot
.81533 .20527 Mdot
.67841 .54858 Mdot
.03638 .29764 Mdot
.72743 .72153 Mdot
.62075 .97241 Mdot
.20612 .11808 Mdot
.23006 .68959 Mdot
.42415 .54327 Mdot
.34026 .77784 Mdot
.1211 .04499 Mdot
.17532 .18941 Mdot
.56824 .67962 Mdot
.1806 .94607 Mdot
.80156 .16659 Mdot
.20378 .48407 Mdot
.54594 .23578 Mdot
.60567 .36223 Mdot
.43287 .41427 Mdot
.15139 .3571 Mdot
.78107 .59313 Mdot
.81102 .02111 Mdot
.20157 .57687 Mdot
.87449 .34216 Mdot
.73797 .8692 Mdot
.17679 .17314 Mdot
.36849 .2757 Mdot
.95765 .80615 Mdot
.05271 .68578 Mdot
.68879 .24932 Mdot
.38644 .44123 Mdot
.56636 .28132 Mdot
.7171 .23872 Mdot
.95611 .37738 Mdot
.68861 .4634 Mdot
.03253 .27416 Mdot
.8311 .43756 Mdot
.80468 .93136 Mdot
.01302 .84558 Mdot
.678 .96884 Mdot
.0758 .64759 Mdot
.22906 .72652 Mdot
.46435 .93214 Mdot
.48519 .915 Mdot
.56399 .16113 Mdot
.61128 .6208 Mdot
.03628 .31508 Mdot
.43781 .61626 Mdot
.39705 .34286 Mdot
.71884 .15411 Mdot
.64608 .67606 Mdot
.4328 .66504 Mdot
.13401 .29065 Mdot
.65712 .98875 Mdot
.39383 .78787 Mdot
.33001 .23315 Mdot
.56232 .2811 Mdot
.98723 .90215 Mdot
.65022 .42645 Mdot
.18738 .33732 Mdot
.53643 .71586 Mdot
.13189 .35839 Mdot
.17804 .97558 Mdot
.84634 .95334 Mdot
.69703 .66743 Mdot
.07504 .91987 Mdot
.8616 .78647 Mdot
.02358 .76089 Mdot
.04821 .28506 Mdot
.28799 .77956 Mdot
.5078 .49136 Mdot
.31776 .37528 Mdot
.07312 .45024 Mdot
.57706 .34011 Mdot
.98519 .89826 Mdot
.47786 .32465 Mdot
.63347 .40782 Mdot
.37998 .76035 Mdot
.62721 .41152 Mdot
.4537 .72158 Mdot
.74856 .36904 Mdot
.17995 .2921 Mdot
.515 .96091 Mdot
.85274 .30642 Mdot
.39232 .13505 Mdot
.15952 .82397 Mdot
.18314 .45977 Mdot
.68244 .25208 Mdot
.96905 .01977 Mdot
.73726 .26853 Mdot
.42741 .8352 Mdot
.48798 .19792 Mdot
.37639 .44979 Mdot
.44759 .21823 Mdot
.78267 .78359 Mdot
.65695 .71176 Mdot
.66233 .4714 Mdot
.52659 .77211 Mdot
.74183 .54692 Mdot
.96984 .31682 Mdot
.66664 .10274 Mdot
.68359 .82851 Mdot
.459 .56106 Mdot
.29246 .14335 Mdot
.23526 .64695 Mdot
.84135 .96508 Mdot
.49565 .57744 Mdot
.58892 .39981 Mdot
.50143 .10577 Mdot
.52697 .76946 Mdot
.04567 .11646 Mdot
.70338 .58408 Mdot
.25179 .97925 Mdot
.28719 .5319 Mdot
.98347 .59417 Mdot
.63365 .54715 Mdot
.76217 .81172 Mdot
.96157 .46034 Mdot
.12049 .02835 Mdot
.58112 .2286 Mdot
.43025 .43555 Mdot
.85379 .60446 Mdot
.74937 .33737 Mdot
.08972 .81834 Mdot
.36715 .17653 Mdot
.34172 .32293 Mdot
.83626 .86373 Mdot
.5039 .99454 Mdot
.89877 .9522 Mdot
.62338 .09104 Mdot
.02531 .34787 Mdot
.56658 .32129 Mdot
.25317 .35218 Mdot
.86573 .80075 Mdot
.47465 .5699 Mdot
.45091 .84373 Mdot
.26983 .28666 Mdot
.74229 .34881 Mdot
.35565 .63376 Mdot
.28319 .5236 Mdot
.74428 .69818 Mdot
.65078 .48218 Mdot
.56803 .74661 Mdot
.78173 .06757 Mdot
.81904 .32006 Mdot
.80297 .25158 Mdot
.92438 .75767 Mdot
.58432 .99116 Mdot
.8146 .58732 Mdot
.26521 .75113 Mdot
.93305 .50644 Mdot
.02061 .87055 Mdot
.95759 .30199 Mdot
.10652 .38799 Mdot
.48148 .80276 Mdot
.12155 .20105 Mdot
.0114 .33938 Mdot
.07384 .80745 Mdot
.82922 .7192 Mdot
.03228 .37112 Mdot
.66255 .15028 Mdot
.53761 .73424 Mdot
.42299 .13237 Mdot
.50171 .63072 Mdot
.85154 .43107 Mdot
.79363 .79131 Mdot
.60757 .50695 Mdot
.42757 .58259 Mdot
.77899 .74696 Mdot
.13873 .56103 Mdot
.42048 .66098 Mdot
.07123 .14284 Mdot
.76243 .7624 Mdot
.7997 .77621 Mdot
.11849 .69445 Mdot
.48403 .70545 Mdot
.43359 .27035 Mdot
.9869 .35557 Mdot
.5341 .89892 Mdot
.38021 .52769 Mdot
.67706 .11386 Mdot
.12185 .6846 Mdot
.71927 .31541 Mdot
.65016 .87416 Mdot
.45707 .34502 Mdot
.59108 .07975 Mdot
.45912 .54915 Mdot
.50537 .04762 Mdot
.79893 .28227 Mdot
.63212 .68104 Mdot
.32114 .63651 Mdot
.2878 .58524 Mdot
.73794 .9843 Mdot
.85379 .56523 Mdot
.85543 .9601 Mdot
.08043 .09989 Mdot
.53727 .41854 Mdot
.63021 .3808 Mdot
.98591 .3727 Mdot
.17717 .07264 Mdot
.71551 .99934 Mdot
.66094 .52541 Mdot
.26114 .86032 Mdot
.94163 .74136 Mdot
.58574 .45793 Mdot
.89964 .29918 Mdot
.82281 .13762 Mdot
.69655 .64676 Mdot
.71192 .456 Mdot
.30117 .86698 Mdot
.64138 .80878 Mdot
.56525 .16636 Mdot
.61753 .3643 Mdot
.61144 .61033 Mdot
.65801 .15448 Mdot
.93419 .36623 Mdot
.49643 .32125 Mdot
.49537 .12156 Mdot
.66248 .42105 Mdot
.32391 .39256 Mdot
.93609 .09305 Mdot
.85604 .63385 Mdot
.88114 .21933 Mdot
.47382 .24888 Mdot
.12761 .68007 Mdot
.62826 .31794 Mdot
.75996 .45849 Mdot
.81161 .73207 Mdot
.43146 .34912 Mdot
.04879 .22205 Mdot
.44925 .40982 Mdot
.20225 .3979 Mdot
.6588 .26526 Mdot
.07397 .63824 Mdot
.60757 .43765 Mdot
.51888 .57013 Mdot
.64591 .65635 Mdot
.73113 .99632 Mdot
.10362 .25311 Mdot
.26503 .18916 Mdot
.15361 .34928 Mdot
.85083 .98766 Mdot
.31612 .24539 Mdot
.1658 .52992 Mdot
.80897 .65059 Mdot
.51605 .84343 Mdot
.50612 .62662 Mdot
.9638 .53985 Mdot
.9145 .6168 Mdot
.25808 .50634 Mdot
.30517 .05117 Mdot
.7194 .46555 Mdot
.23146 .44521 Mdot
.01807 .53349 Mdot
.42171 .13805 Mdot
.11587 .70459 Mdot
.20922 .3476 Mdot
.81418 .05079 Mdot
.0021 .39237 Mdot
.69196 .58151 Mdot
.62276 .14249 Mdot
.20681 .27495 Mdot
.32829 .70454 Mdot
.82059 .60901 Mdot
.13549 .80984 Mdot
.74504 .80923 Mdot
.41196 .16402 Mdot
.1723 .70246 Mdot
.49893 .60146 Mdot
.85931 .37301 Mdot
.20823 .29101 Mdot
.21131 .74076 Mdot
.48722 .07978 Mdot
.86374 .25157 Mdot
.59237 .61215 Mdot
.11282 .97487 Mdot
1e-05 .50802 Mdot
.73548 .77675 Mdot
.26435 .29357 Mdot
.25426 .15932 Mdot
.66958 .23612 Mdot
.34332 .28435 Mdot
.42012 .13672 Mdot
.47615 .57778 Mdot
.75193 .05982 Mdot
.27831 .62523 Mdot
.17624 .20816 Mdot
.15867 .12442 Mdot
.19604 .60042 Mdot
.28862 .0483 Mdot
.75871 .5515 Mdot
.3136 .22552 Mdot
.10361 .80335 Mdot
.64442 .78759 Mdot
.12556 .56953 Mdot
.5542 .21329 Mdot
.02938 .18941 Mdot
.40793 .84025 Mdot
.86121 .75426 Mdot
.45452 .34242 Mdot
.79293 .26794 Mdot
.29319 .13245 Mdot
.15392 .44686 Mdot
.56945 .34238 Mdot
.44456 .52681 Mdot
.09926 .62587 Mdot
.86037 .32355 Mdot
.92598 .5574 Mdot
.71406 .59679 Mdot
.81093 .8629 Mdot
.63 .53607 Mdot
.19455 .12586 Mdot
.88845 .91043 Mdot
.28386 .84667 Mdot
.86705 .84643 Mdot
.27231 .72894 Mdot
.81795 .62845 Mdot
.22297 .89187 Mdot
.9969 .29343 Mdot
.49942 .29023 Mdot
.28191 .47303 Mdot
.69534 .59306 Mdot
.87786 .84018 Mdot
.01672 .0801 Mdot
.4932 .03119 Mdot
.97782 .58761 Mdot
.73296 .19941 Mdot
.8201 .431 Mdot
.41561 .83644 Mdot
.9625 .52629 Mdot
.51627 .43845 Mdot
.28933 .29922 Mdot
.67755 .55353 Mdot
.88266 .79946 Mdot
.83319 .22523 Mdot
.87582 .41168 Mdot
.43019 .02406 Mdot
.27584 .33527 Mdot
.00442 .23677 Mdot
.33519 .19287 Mdot
.2651 .18005 Mdot
.63335 .02063 Mdot
.84908 .16982 Mdot
.4071 .58275 Mdot
.16677 .21034 Mdot
.90462 .62771 Mdot
.54594 .41741 Mdot
.70142 .53871 Mdot
.01561 .08055 Mdot
.92642 .17426 Mdot
.15433 .78194 Mdot
.18837 .00269 Mdot
.37952 .19493 Mdot
.5097 .0789 Mdot
.97608 .706 Mdot
.26848 .56701 Mdot
.72468 .13305 Mdot
.5901 .13561 Mdot
.11954 .05199 Mdot
.23183 .53984 Mdot
.0534 .96987 Mdot
.49222 .99013 Mdot
.9697 .02864 Mdot
.61982 .25436 Mdot
.43366 .90618 Mdot
.71638 .94203 Mdot
.92323 .2224 Mdot
.01276 .01605 Mdot
.33872 .29534 Mdot
.50428 .30958 Mdot
.22221 .39492 Mdot
.66829 .41786 Mdot
.29083 .15838 Mdot
.00701 .3075 Mdot
.867 .08445 Mdot
.46987 .01978 Mdot
.90209 .77601 Mdot
.37979 .36956 Mdot
.90744 .52969 Mdot
.65601 .42338 Mdot
.07455 .31857 Mdot
.45786 .04388 Mdot
.88331 .84319 Mdot
.52558 .86001 Mdot
.70831 .19217 Mdot
.14425 .45837 Mdot
.89149 .38575 Mdot
.91653 .31697 Mdot
.83396 .4202 Mdot
.29908 .63163 Mdot
.30071 .04776 Mdot
.89593 .21347 Mdot
.44573 .39376 Mdot
.48914 .52484 Mdot
.76729 .17173 Mdot
.29206 .18212 Mdot
.32724 .50076 Mdot
.18382 .91141 Mdot
.54339 .83349 Mdot
.75422 .68173 Mdot
.69211 .68468 Mdot
.94519 .95744 Mdot
.82191 .72289 Mdot
.13916 .83745 Mdot
.84267 .97869 Mdot
.70651 .50418 Mdot
.31032 .91864 Mdot
.25376 .89291 Mdot
.11074 .20349 Mdot
.59429 .20987 Mdot
.465 .38924 Mdot
.87515 .64282 Mdot
.77635 .40386 Mdot
.13473 .58616 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wo
oooo0_l00003ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo0_l000000ooooooo0000ooooo`0>ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00Gooooo0_l00007ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool00_ooool001kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool02Oooool2o`0000?ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0;ooooo`?o00003oooool00ol0003oooooooooo`0;ooooo`;o0000
00?oooooo`000?ooool02oooool2o`000003ooooool0003ooooo00kooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`;o0000
1oooool00ol0003oooooooooo`09ooooo`;o00000_ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_oo
ool00ol0003oooooooooo`1Looooo`;o0000;_ooool2o`0003Wooooo0_l0000_ooooo`;o00004ooo
ool2o`0002gooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`0Zooooo`;o0000jOooool2
o`0002Gooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`02o`0002Sooooo0_l0003Hoooo
o`;o00003oooool2o`00033ooooo000Nooooo`03o`000?oooooooooo00;o00000oooool2o`0000Go
oooo0_l0001Sooooo`;o00008_ooool2o`00017ooooo0_l0001Jooooo`;o0000<Oooool2o`0000ko
oooo000Nooooo`03o`000?oooooooooo00Gooooo0_l00005ooooo`;o00001_ooool2o`0005_ooooo
0_l0000Rooooo`;o00004Oooool2o`00023ooooo0_l0000hooooo`;o0000<Oooool2o`0000kooooo
000Nooooo`03o`000?oooooooooo01Cooooo0_l0001booooo`?o00002oooool2o`0003;ooooo0_l0
000Qooooo`;o00005Oooool2o`0002Wooooo0_l0000Fooooo`007_ooool00ol0003oooooooooo`0S
ooooo`;o00003oooool2o`0005;ooooo0ol0000;ooooo`;o0000EOooool2o`00043ooooo0_l00006
ooooo`;o00003_ooool001kooooo00?o0000ooooooooool08oooool2o`0000oooooo0_l0001Voooo
o`;o0000ROooool2o`0000kooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`1Gooooo`;o
0000@oooool2o`0000cooooo0_l0001kooooo`;o00005oooool2o`0000Gooooo000Nooooo`03o`00
0?oooooooooo00oooooo0_l00016ooooo`;o0000;Oooool2o`0002;ooooo0_l0002Dooooo`;o0000
1Oooool001kooooo00?o0000ooooooooool03oooool2o`0007Gooooo0_l0001Hooooo`;o00004ooo
ool2o`00053ooooo000Nooooo`03o`000?oooooooooo02Gooooo0_l0001Zooooo`;o0000COooool2
o`0001?ooooo0_l0000Wooooo`;o00009oooool001kooooo00?o0000ooooooooool08oooool4o`00
06[ooooo0_l000000ooooooo0000o`00001Iooooo`;o0000;Oooool2o`0002Oooooo000Nooooo`03
o`000?oooooooooo02?ooooo0_l0000Pooooo`;o00004oooool2o`0000;ooooo0_l0000dooooo`;o
00000oooool2o`0000Gooooo0_l0000`ooooo`;o00006oooool2o`0005Kooooo000Nooooo`;o0000
9?ooool2o`00023ooooo0_l0000Cooooo`;o00000_ooool3o`0003Sooooo0_l00005ooooo`;o0000
<?ooool2o`00037ooooo0_l0000Aooooo`;o0000;Oooool001kooooo00?o0000ooooooooool08ooo
ool2o`0003Sooooo1?l0000Tooooo`;o0000O_ooool2o`00017ooooo0_l0000]ooooo`007_ooool0
0ol0003oooooooooo`1Mooooo`;o00009_ooool2o`0001Gooooo0_l0001Booooo`;o0000EOooool0
01kooooo00?o0000ooooooooool0W?ooool2o`0000[ooooo0_l0000Zooooo`;o00006_ooool2o`00
02Cooooo0_l0000_ooooo`007_ooool00ol0003oooooooooo`2Xooooo`;o0000:_ooool2o`0000go
oooo0_l000000ooooooo0000o`00000^ooooo`;o0000;oooool001kooooo00?o0000ooooooooool0
e?ooool2o`0000gooooo0_l000000ooooooo0000o`00000Booooo`;o0000Boooool001kooooo00?o
0000ooooooooool0@oooool2o`0004kooooo0_l0000oooooo`;o000000?oooooo`000?l000008Ooo
ool2o`0001Gooooo0_l0000dooooo`007_ooool00ol0003oooooooooo`07ooooo`;o0000;?ooool2
o`0000cooooo0_l0000iooooo`;o00004oooool2o`0004;ooooo0_l0000hooooo`;o0000=?ooool0
01kooooo00?o0000ooooooooool01oooool2o`0002cooooo0_l00017ooooo`;o0000:oooool2o`00
00cooooo0_l0002<ooooo`007_ooool01?l0003oooooooooooooool2o`0009Oooooo0_l00006oooo
o`;o00001oooool2o`0000cooooo0_l000001?oooooo0000o`000?l00028ooooo`007_ooool01?l0
003oooooooooooooool2o`0004Oooooo0_l0000Cooooo`;o00003?ooool2o`0002_ooooo0_l00006
ooooo`;o00006?ooool3o`0005Oooooo0_l0000?ooooo`;o00004Oooool2o`0000_ooooo000Noooo
o`03o`000?oooooooooo04[ooooo0_l0000Cooooo`;o00003?ooool2o`000:Gooooo1?l0000?oooo
o`;o00004Oooool2o`0000_ooooo000Nooooo`04o`000?ooooooooooooooo`;o0000oooooolBoooo
o`;o0000<Oooool001kooooo00Co0000oooooooooooooooo0_l00032ooooo`Co0000<oooool2o`00
02kooooo0_l0000Iooooo`007_ooool00ol0003oooooooooo`35ooooo`Co0000<oooool2o`0002ko
oooo0_l0000Iooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o00005ooo
ool2o`0004Sooooo0_l0001cooooo`;o0000L?ooool001kooooo00?o0000ooooooooool05_ooool2
o`0004Sooooo0_l0000mooooo`;o0000=?ooool2o`00073ooooo000Nooooo`03o`000?oooooooooo
02Gooooo0_l0001Gooooo`;o00007oooool2o`000:Kooooo000Nooooo`03o`000?oooooooooo02Go
oooo0_l0001Gooooo`;o0000aoooool001kooooo00?o0000ooooooooool0f?ooool2o`0006gooooo
000Nooooo`03o`000?oooooooooo00_ooooo0_l0000booooo`;o0000Coooool2o`0004Kooooo0_l0
001]ooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o0000<_ooool2o`00013ooooo1?l0000Y
ooooo`;o00004?ooool2o`0002oooooo0_l00024ooooo`007_ooool00ol0003oooooooooo`0Voooo
o`;o00000_ooool2o`0000?ooooo0_l0000Pooooo`Co00001Oooool2o`0002;ooooo0_l0000Loooo
o`?o00008_ooool2o`0000[ooooo0_l0000oooooo`;o0000=oooool001kooooo00?o0000oooooooo
ool09_ooool2o`0000;ooooo0_l00003ooooo`;o00001?ooool2o`0000Cooooo0_l0000Aooooo`;o
00000_ooool2o`0000Kooooo0_l0000Rooooo`;o00007?ooool3o`0002kooooo0_l0000oooooo`;o
0000=oooool001kooooo00?o0000ooooooooool0=Oooool2o`0000Cooooo0_l0000Aooooo`;o0000
;_ooool2o`0003Cooooo0_l0001[ooooo`;o00007?ooool2o`0000Kooooo000Nooooo`03o`000?oo
oooooooo023ooooo0_l0000/ooooo`;o00002oooool2o`00017ooooo0_l0000Eooooo`;o0000;Ooo
ool2o`00037ooooo0_l0000hooooo`;o00007?ooool2o`0000Kooooo000Nooooo`03o`000?oooooo
oooo023ooooo0_l0000iooooo`;o00004Oooool2o`0000_ooooo0_l00007ooooo`?o00003_ooool2
o`00023ooooo0_l00003ooooo`;o0000:Oooool2o`0005kooooo000Nooooo`03o`000?oooooooooo
07_ooooo0_l00007ooooo`?o00003_ooool2o`00023ooooo0_l00003ooooo`;o0000BOooool3o`00
03gooooo000Nooooo`03o`000?oooooooooo01?ooooo0_l0001`ooooo`;o0000?oooool2o`0003oo
oooo0ol0000Iooooo`;o00008_ooool001kooooo00?o0000ooooooooool04oooool2o`000003oooo
ool0003o000004?ooooo0_l0001Yooooo`;o0000Foooool4o`00023ooooo000Nooooo`03o`000?oo
oooooooo01Kooooo0_l00013ooooo`;o0000b?ooool2o`00023ooooo000Nooooo`;o0000e?ooool2
o`0007;ooooo000Nooooo`03o`000?oooooooooo0=;ooooo0ol0000Aooooo`;o0000Goooool001ko
oooo00?o0000ooooooooool0Noooool2o`0000Kooooo0_l0000hooooo`;o00004oooool2o`0001;o
oooo0_l0000mooooo`;o00008?ooool001kooooo00?o0000ooooooooool0?Oooool2o`00013ooooo
0_l00009ooooo`;o00007oooool2o`0000Kooooo0_l0000^ooooo`;o00002?ooool2o`0006Kooooo
0_l0000Pooooo`007_ooool00ol0003oooooooooo`0mooooo`;o00004?ooool2o`0000Wooooo0_l0
000Vooooo`;o0000;oooool2o`0009;ooooo000Nooooo`03o`000?oooooooooo037ooooo0_l0001?
ooooo`;o00008oooool2o`0000_ooooo0_l0001:ooooo`;o0000<_ooool2o`00017ooooo000Noooo
o`03o`000?oooooooooo037ooooo0_l0000Cooooo`;o0000Goooool2o`0000_ooooo0_l0001:oooo
o`;o00003_ooool2o`0002;ooooo0_l0000Aooooo`007_ooool00ol0003oooooooooo`0eooooo`;o
00003oooool2o`00083ooooo0_l0000[ooooo`;o00006Oooool2o`0001cooooo0_l0000Gooooo`00
7_ooool00ol0003oooooooooo`0eooooo`;o0000??ooool2o`0005?ooooo0_l0000[ooooo`;o0000
<_ooool2o`0000?ooooo0_l0000Gooooo`007_ooool00ol0003oooooooooo`1cooooo`;o0000]?oo
ool2o`0001cooooo000Nooooo`03o`000?oooooooooo05;ooooo0_l00007ooooo`;o0000Joooool2
o`0001gooooo0_l0001Nooooo`007_ooool00ol0003oooooooooo`1Booooo`;o00001oooool2o`00
06_ooooo0_l0000Mooooo`;o0000??ooool2o`00023ooooo000Nooooo`03o`000?oooooooooo08co
oooo0_l0001Iooooo`;o00000oooool2o`0003Oooooo0_l0000Pooooo`007_ooool00ol0003ooooo
ooooo`05ooooo`;o0000;_ooool2o`0001_ooooo0_l0000hooooo`;o0000FOooool2o`0000?ooooo
0_l0001Iooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000
1_ooool00ol0003oooooooooo`05ooooo`;o0000;_ooool2o`0000Sooooo0_l0000Aooooo`;o0000
5Oooool2o`0000cooooo0_l0001Yooooo`;o0000Hoooool000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000oooooooo
ool0?oooool2o`0002Sooooo0_l0000<ooooo`;o00008_ooool2o`0004Gooooo0_l00010ooooo`;o
00008Oooool000?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo0ol0000Sooooo`;o00007?ooool2o`0005Sooooo0_l0001=ooooo`;o0000>?ooool2o`00027o
oooo0003ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`03
o`000?oooooooooo023ooooo0_l000000ooooooo0000o`00000;ooooo`;o00003oooool2o`000:Oo
oooo0_l0001Kooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_oo
ool01Oooool00ol0003oooooooooo`0Pooooo`;o00003_ooool2o`0009?ooooo0_l0000nooooo`;o
0000:_ooool2o`0001Cooooo0003ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo03;ooooo0_l000000ooooooo0000o`000009ooooo`;o
0000Noooool2o`0000Kooooo0_l0000nooooo`;o0000:_ooool2o`0001Cooooo0003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000oooo
ooooool0<_ooool2o`000003ooooool0003o000000Wooooo0_l0001^ooooo`;o00002oooool2o`00
063ooooo0_l0000Vooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;3ooooo0_l0001Uooooo`;o00001_ooool2
o`0002Kooooo000Nooooo`03o`000?oooooooooo05kooooo0_l0000]ooooo`;o0000D?ooool2o`00
03Kooooo0_l000000ooooooo0000o`00000[ooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o
0000D?ooool2o`0002gooooo0_l0001@ooooo`;o0000>Oooool2o`0000cooooo0_l0000Mooooo`00
7_ooool00ol0003oooooooooo`0<ooooo`;o00001?ooool2o`0002cooooo0_l0000Pooooo`;o0000
POooool2o`0002Cooooo0_l00007ooooo`?o00004Oooool2o`00013ooooo0_l0000;ooooo`007_oo
ool01?l0003oooooooooooooool2o`0000oooooo0_l0000/ooooo`;o00008?ooool2o`0005Gooooo
0_l0000:ooooo`;o00007_ooool2o`0002Cooooo0_l00007ooooo`?o00008oooool2o`0000_ooooo
000Nooooo`04o`000?ooooooooooooooo`;o00003Oooool2o`000:Oooooo0_l0000:ooooo`;o0000
Goooool2o`0001oooooo000Nooooo`03o`000?oooooooooo013ooooo0_l0001Eooooo`;o00001Ooo
ool2o`0001gooooo0_l0002Gooooo`;o00007oooool001kooooo0_l0001Sooooo`;o00000oooool2
o`0000Gooooo0_l0000Mooooo`;o00007_ooool2o`0002Oooooo0_l0001Cooooo`Co00006?ooool0
01kooooo0_l0001Sooooo`;o0000BOooool2o`0002Oooooo0_l0000=ooooo`;o0000>_ooool2o`00
00Sooooo1?l0000Hooooo`007_ooool00ol0003oooooooooo`1Zooooo`;o0000NOooool2o`0003[o
oooo0_l0000Tooooo`007_ooool00ol0003oooooooooo`0gooooo`;o00005oooool2o`00017ooooo
0_l00005ooooo`;o0000b_ooool2o`0000oooooo000Nooooo`03o`000?oooooooooo03Oooooo0_l0
000Eooooo`Co00004Oooool2o`0001;ooooo0_l0000Aooooo`;o00002_ooool2o`0004Cooooo0_l0
001Hooooo`;o00003oooool001kooooo0_l0000Looooo`;o000000?oooooo`000?l00000;_ooool2
o`0002Oooooo0_l0000Aooooo`;o00002_ooool2o`0003kooooo0_l00002ooooo`Co00008oooool2
o`0001;ooooo0_l0000`ooooo`007_ooool00ol0003oooooooooo`0Kooooo`;o000000?oooooo`00
0?l00000>oooool2o`0005_ooooo0_l0000;ooooo`;o00003oooool2o`0000;ooooo0_l0000Uoooo
o`;o00004_ooool2o`00033ooooo000Nooooo`03o`000?oooooooooo05_ooooo0_l0001Kooooo`;o
00002oooool2o`00083ooooo000Nooooo`03o`000?oooooooooo00cooooo0_l0003ooooooc[ooooo
000Nooooo`03o`000?oooooooooo00cooooo0_l0002Fooooo`;o0000;?ooool2o`0007?ooooo000N
ooooo`03o`000?oooooooooo0:Cooooo0_l0000:ooooo`;o00008?ooool2o`0001Sooooo0_l0000@
ooooo`;o0000>_ooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo08Wooooo0_l0000Uoooo
o`;o0000>_ooool2o`00013ooooo0_l0000jooooo`;o00002oooool001kooooo00?o0000oooooooo
ool01_ooool2o`0003Oooooo0_l0000Cooooo`;o0000<oooool2o`0007;ooooo0_l0000Sooooo`;o
00008oooool001kooooo00?o0000ooooooooool01_ooool2o`0003Oooooo0_l0000Cooooo`;o0000
7_ooool2o`0001Kooooo0_l000000ooooooo0000o`00000;ooooo`;o0000=Oooool2o`0002Sooooo
0_l0000Sooooo`;o00008oooool001kooooo00?o0000ooooooooool0M?ooool2o`0001Kooooo0_l0
00000ooooooo0000o`00000;ooooo`;o00005Oooool3o`0001gooooo0_l0001booooo`007_ooool0
0ol0003oooooooooo`1/ooooo`;o0000AOooool3o`0004[ooooo0_l00015ooooo`007_ooool00ol0
003oooooooooo`0<ooooo`;o0000A_ooool2o`0001Kooooo0_l0000iooooo`;o0000>Oooool2o`00
01cooooo0_l00015ooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o0000A_ooool2o`0004So
oooo0_l00007ooooo`;o0000>Oooool2o`0003cooooo0_l0000;ooooo`;o00006?ooool001kooooo
00?o0000ooooooooool09oooool2o`0000gooooo0_l00008ooooo`;o00004?ooool2o`0004[ooooo
0_l0000Xooooo`;o0000E_ooool2o`0000_ooooo0_l0000Aooooo`;o00001Oooool001kooooo0_l0
000Xooooo`;o00003Oooool2o`0000Sooooo0_l0000@ooooo`;o00005_ooool2o`0005cooooo0_l0
001fooooo`;o00001Oooool001kooooo0_l00009ooooo`;o0000D?ooool2o`0000kooooo0_l0002d
ooooo`;o00009Oooool001kooooo0_l00009ooooo`;o0000D?ooool2o`0003Wooooo0_l0001Moooo
o`;o0000:_ooool2o`00017ooooo0_l0000Booooo`007_ooool00ol0003oooooooooo`0]ooooo`;o
00001_ooool2o`0005kooooo0_l0000[ooooo`;o000000?oooooo`000?l00000;Oooool2o`0003go
oooo0_l0000Booooo`007_ooool3o`0002gooooo0_l00006ooooo`Co00007oooool2o`0006Sooooo
0_l000000ooooooo0000o`00001:ooooo`;o0000=?ooool001kooooo0ol0000gooooo`;o00007ooo
ool2o`0004Kooooo0_l0001_ooooo`;o0000=?ooool001kooooo00?o0000ooooooooool02?ooool2
o`0009Kooooo0_l0000Looooo`;o0000Qoooool001kooooo00?o0000ooooooooool02?ooool2o`00
06Gooooo0_l0000Xooooo`;o00004Oooool2o`00013ooooo0_l00008ooooo`;o00007?ooool2o`00
03kooooo0_l0000?ooooo`;o00003_ooool001kooooo00?o0000ooooooooool05?ooool2o`0005Wo
oooo0_l0000Hooooo`;o00003_ooool2o`0000;ooooo0_l0000=ooooo`;o00001_ooool2o`000003
ooooool0003o000000oooooo0_l0000Looooo`;o00007_ooool2o`0001kooooo0_l0000?ooooo`;o
00003_ooool001kooooo00?o0000ooooooooool05?ooool2o`0001;ooooo0_l00011ooooo`;o0000
7?ooool2o`0001;ooooo0_l0000Eooooo`;o000000?oooooo`000?l000000_l0000?ooooo`;o0000
4oooool2o`0002Gooooo0_l0000<ooooo`;o0000<Oooool001kooooo00?o0000ooooooooool0:?oo
ool2o`00047ooooo0_l0000Zooooo`;o00001?ooool2o`0001[ooooo0_l0000?ooooo`;o00004ooo
ool2o`0002Kooooo0_l0000;ooooo`;o0000<Oooool001kooooo00?o0000ooooooooool0Uoooool2
o`0006kooooo0ol0000mooooo`007_ooool00ol0003oooooooooo`18ooooo`;o0000TOooool2o`00
00gooooo0_l0000Looooo`;o0000?Oooool001kooooo00?o0000ooooooooool0B?ooool2o`0000co
oooo0_l00016ooooo`;o0000>oooool2o`0000gooooo0_l0001Kooooo`007_ooool00ol0003ooooo
ooooo`02o`0001Gooooo0_l0000Pooooo`;o00006oooool2o`0004Kooooo0_l0001@ooooo`;o0000
EOooool001kooooo00?o0000ooooooooool00_l0000Eooooo`;o00008?ooool2o`0005Gooooo0_l0
000Sooooo`Co0000=oooool2o`0002Kooooo0_l0000]ooooo`007_ooool00ol0003oooooooooo`0o
ooooo`;o00006Oooool2o`00027ooooo0_l0000Aooooo`;o00008oooool4o`0003Kooooo0_l0000W
ooooo`;o0000;Oooool001kooooo00?o0000ooooooooool01?ooool2o`0003Wooooo0ol0000Hoooo
o`;o00008Oooool2o`00017ooooo0_l0001Kooooo`Co0000E_ooool001kooooo0_l00005ooooo`;o
0000:?ooool2o`00013ooooo0_l00016ooooo`;o00007Oooool2o`0002[ooooo0_l0000Hooooo`;o
00006Oooool3o`0003cooooo000Nooooo`03o`000?oooooooooo02kooooo0_l0000Nooooo`;o0000
>?ooool2o`0001gooooo0_l0000Zooooo`;o00003?ooool2o`0002Gooooo0ol0000looooo`007_oo
ool00ol0003oooooooooo`0Aooooo`;o00006_ooool2o`0001oooooo0_l0002=ooooo`;o00000_oo
ool2o`0005[ooooo0_l00008ooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o00005?ooool2
o`0000Cooooo0_l0001Vooooo`;o0000A_ooool2o`0005kooooo0_l00008ooooo`007_ooool00ol0
003oooooooooo`05ooooo`;o00008?ooool2o`0002?ooooo0_l00017ooooo`;o0000:_ooool2o`00
00;ooooo0_l00020ooooo`007_ooool00ol0003oooooooooo`05ooooo`;o0000AOooool2o`0007?o
oooo0_l00002ooooo`;o0000IOooool2o`0001Wooooo000Nooooo`03o`000?oooooooooo04Wooooo
0_l0000/ooooo`;o0000Coooool2o`0002Gooooo0_l0000kooooo`;o00004Oooool2o`0000Kooooo
000Nooooo`03o`000?oooooooooo00Kooooo0_l0000mooooo`;o00000_ooool2o`0002Wooooo0_l0
00000ooooooo0000o`00000oooooo`;o00003_ooool2o`0002Gooooo0_l0000Rooooo`;o00004ooo
ool2o`0001;ooooo0_l000000ooooooo0000o`000006ooooo`007_ooool00ol0003oooooooooo`06
ooooo`;o0000?Oooool2o`0000Oooooo0_l0000Cooooo`;o00003oooool2o`0004;ooooo0_l0001I
ooooo`;o00004oooool2o`0001;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`1>oooo
o`;o00002Oooool2o`0000Sooooo0_l0001Jooooo`;o0000L_ooool2o`0001;ooooo000Nooooo`03
o`000?oooooooooo03Sooooo0_l0000Oooooo`;o0000I?ooool2o`0000Sooooo0_l0000Jooooo`;o
0000C?ooool2o`0001;ooooo000Nooooo`03o`000?oooooooooo00oooooo0ol0000Vooooo`;o0000
Soooool2o`0001[ooooo0_l0000gooooo`;o00003_ooool2o`0000?ooooo0_l0000Booooo`007_oo
ool00ol0003oooooooooo`0?ooooo`?o00003Oooool2o`0001Cooooo0_l0000Pooooo`;o0000aOoo
ool2o`0000kooooo0_l00003ooooo`;o00004_ooool001kooooo00?o0000ooooooooool07oooool2
o`0001Cooooo0_l0000Pooooo`;o0000>_ooool2o`0002Cooooo0_l0000nooooo`;o00004_ooool2
o`0003Sooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l00000
0ol@413oooooooooo`04ooooo`;o0000AOooool2o`0001?ooooo0_l0000:ooooo`;o00001?ooool4
o`0001kooooo0_l00004ooooo`;o00009?ooool2o`0003_ooooo0_l000000ooooooo0000o`00000B
ooooo`;o0000>?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool0
0ol0003oooooooooo`05ooooo`;o0000?oooool2o`0000Cooooo0_l0000Cooooo`;o00002_ooool2
o`0000Cooooo1?l0000Nooooo`;o0000@?ooool2o`0002Gooooo0_l0001?ooooo`000oooool01Ol@
413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`?o0000?_ooool2o`0006_ooooo0_l0000>
ooooo`;o00002oooool2o`000003ooooool0003o000000;ooooo0_l0001>ooooo`;o00009_ooool0
00?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o
0000ooooooooool05oooool2o`0009;ooooo0_l0000>ooooo`;o00001?ooool2o`0000Gooooo0_l0
00000ooooooo0000o`00000[ooooo`;o00009Oooool2o`0001Gooooo0_l0000?ooooo`000oooool0
1Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003ooooo
ooooo`0Gooooo`;o00002oooool2o`00023ooooo0_l0001iooooo`;o0000=Oooool2o`0003cooooo
0_l0000?ooooo`000oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000
1oooool00ol0003oooooooooo`0Tooooo`;o00008?ooool2o`0003Cooooo0_l0000@ooooo`;o0000
>_ooool2o`0007_ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4
o`000007ooooo`03o`000?oooooooooo07cooooo0_l0000@ooooo`;o00007_ooool2o`0001Kooooo
1_l0001=ooooo`;o0000;?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMg
Mol0003ooooo00Kooooo00?o0000ooooooooool0:_ooool2o`0005gooooo0_l0000Sooooo`;o0000
5_ooool4o`0004oooooo0_l0000/ooooo`007_ooool00ol0003oooooooooo`07ooooo`;o00007_oo
ool2o`000003ooooool0003o000005gooooo0_l0000Pooooo`Go00009Oooool2o`0001;ooooo0_l0
001Looooo`007_ooool00ol0003oooooooooo`07ooooo`;o00007_ooool2o`0005?ooooo0_l0000]
ooooo`Go00008oooool4o`0001;ooooo0_l0000Eooooo`;o00002Oooool2o`0003[ooooo000Noooo
o`03o`000?oooooooooo07cooooo0_l00003ooooo`;o0000C_ooool4o`0002_ooooo0_l00009oooo
o`;o0000>_ooool001kooooo00?o0000ooooooooool0POooool2o`0004cooooo1?l0001Vooooo`;o
00003?ooool001kooooo00?o0000ooooooooool0coooool2o`0000?ooooo0_l0000aooooo`;o0000
2?ooool2o`0001_ooooo0_l00009ooooo`;o00003?ooool001kooooo00?o0000ooooooooool05Ooo
ool2o`0000Cooooo0_l0002gooooo`;o0000<Oooool2o`0000Sooooo0_l0000Kooooo`;o00005ooo
ool001kooooo00?o0000ooooooooool02oooool2o`0000Sooooo0_l00004ooooo`;o00005Oooool2
o`0005Cooooo0_l0000gooooo`;o0000Aoooool2o`0003_ooooo000Nooooo`03o`000?oooooooooo
00_ooooo0_l0000Uooooo`;o0000A_ooool2o`0000cooooo0_l0000Jooooo`;o00006oooool2o`00
04Cooooo0_l000000ooooooo0000o`00000@ooooo`;o0000:Oooool001kooooo00?o0000oooooooo
ool0<_ooool2o`0003Sooooo0_l0000<ooooo`;o0000:?ooool2o`00067ooooo0_l0000Cooooo`;o
0000:Oooool001kooooo00?o0000ooooooooool0;_ooool2o`0000;ooooo0_l0000Cooooo`;o0000
8oooool2o`0004Sooooo0_l00012ooooo`;o0000Boooool001kooooo00?o0000ooooooooool05?oo
ool2o`0001Sooooo0_l0000Gooooo`;o0000:?ooool2o`0000?ooooo0_l0000nooooo`;o0000@_oo
ool2o`0004_ooooo000Nooooo`;o00005Oooool2o`0002cooooo0_l00006ooooo`;o00009Oooool2
o`0000?ooooo0_l0002Rooooo`;o0000:oooool001kooooo00?o0000ooooooooool0@_ooool2o`00
00Kooooo0_l0000Qooooo`;o0000M?ooool2o`0001Kooooo0_l0000Mooooo`;o0000:oooool001ko
oooo00?o0000ooooooooool0:oooool2o`00043ooooo0_l0000?ooooo`;o0000>_ooool2o`0002Oo
oooo0_l00009ooooo`;o00000oooool2o`0000Kooooo0_l0001:ooooo`007_ooool00ol0003ooooo
ooooo`0[ooooo`;o00002_ooool2o`0004Gooooo0_l0000gooooo`;o000000?oooooo`000?l00000
<_ooool2o`0000?ooooo0_l00010ooooo`;o00004?ooool001kooooo00?o0000ooooooooool07_oo
ool2o`0001Oooooo0_l0001nooooo`;o00008oooool2o`0000Sooooo0_l0001=ooooo`;o00004?oo
ool001kooooo00?o0000ooooooooool07_ooool2o`0003Gooooo0_l0001Dooooo`;o0000;oooool2
o`0000Sooooo0_l0000Yooooo`Co0000<_ooool001kooooo00?o0000ooooooooool0<oooool2o`00
023ooooo0_l0001Dooooo`;o00009_ooool2o`0002Gooooo0_l0000Eooooo`Co0000<_ooool001ko
oooo00?o0000ooooooooool0<oooool2o`0001kooooo0_l00003ooooo`?o0000N?ooool2o`0002Go
oooo0_l0001;ooooo`007_ooool00ol0003oooooooooo`1Cooooo`;o00000oooool3o`0006;ooooo
0_l0001[ooooo`;o00006oooool001kooooo00?o0000ooooooooool0B?ooool2o`0002Gooooo0_l0
000=ooooo`;o0000?Oooool2o`0000Gooooo0_l0001Tooooo`;o00006oooool001kooooo00?o0000
ooooooooool0?_ooool2o`0000Sooooo0_l0000Uooooo`Co00002oooool2o`00017ooooo0_l0000a
ooooo`;o00002Oooool2o`0005cooooo0_l0000Hooooo`007_ooool00ol0003oooooooooo`0noooo
o`;o0000<Oooool2o`0000;ooooo0_l0000Jooooo`;o0000??ooool2o`0004Oooooo0_l0000Coooo
o`;o00006?ooool001kooooo00?o0000ooooooooool0Eoooool2o`0001cooooo0_l0002Qooooo`;o
0000;Oooool001kooooo00?o0000ooooooooool0;oooool2o`0002Kooooo0_l00018ooooo`;o0000
:?ooool2o`0007[ooooo000Nooooo`03o`000?oooooooooo02oooooo0_l0001`ooooo`;o0000:?oo
ool2o`0003Cooooo0_l00014ooooo`007_ooool00ol0003oooooooooo`19ooooo`;o00007_ooool2
o`0003[ooooo0_l0001Jooooo`;o0000A?ooool001kooooo0_l0001:ooooo`?o00006_ooool2o`00
0003ooooool0003o000003[ooooo0_l0002Pooooo`007_ooool00ol0003oooooooooo`0Wooooo`;o
00008Oooool2o`0001[ooooo0_l0001[ooooo`;o00003Oooool2o`0006?ooooo000Mooooo`;o0000
:Oooool3o`0002Kooooo0_l0000Jooooo`;o0000Doooool2o`00013ooooo0_l0000=ooooo`Co0000
AOooool2o`0001[ooooo000Mooooo`;o00006oooool2o`0000gooooo0_l0000Vooooo`;o00000_oo
ool2o`0001Kooooo0_l0001Cooooo`;o00006oooool2o`0000Cooooo0_l00015ooooo`;o00006_oo
ool001kooooo00?o0000ooooooooool06Oooool2o`0003Wooooo0_l00028ooooo`;o0000Ioooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`1Tooooo`;o
0000?_ooool2o`0005?ooooo0_l0001<ooooo`007_ooool00ol0003oooooooooo`04ooooo`;o0000
D_ooool2o`0000[ooooo0_l0000nooooo`;o00004oooool2o`0003kooooo0_l0001<ooooo`007_oo
ool00ol0003oooooooooo`04ooooo`;o0000=Oooool2o`0001_ooooo0_l0000booooo`;o00003Ooo
ool2o`0000cooooo0_l0000>ooooo`;o00006?ooool2o`00063ooooo0_l0000@ooooo`007_ooool0
0ol0003oooooooooo`03ooooo`;o0000;Oooool2o`0000Oooooo0_l0000Dooooo`;o00009?ooool2
o`0001?ooooo0_l0000=ooooo`;o00003?ooool2o`0002Sooooo0_l0000=ooooo`;o0000?Oooool4
o`00013ooooo0_l0000@ooooo`007_ooool00ol0003oooooooooo`02ooooo`?o0000;Oooool2o`00
01gooooo0_l00006ooooo`;o00007?ooool2o`0006Wooooo0_l00009ooooo`;o0000<_ooool4o`00
02;ooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l00005ooooo`;o0000C_ooool2o`0006ko
oooo0_l0000Rooooo`;o00004Oooool2o`0004Gooooo000Nooooo`03o`000?oooooooooo00Wooooo
0_l0002nooooo`;o00005Oooool2o`0001kooooo0_l00015ooooo`007_ooool00ol0003ooooooooo
o`17ooooo`;o0000J_ooool2o`0002_ooooo0_l0000_ooooo`;o00003Oooool2o`0001?ooooo0_l0
000@ooooo`007_ooool00ol0003oooooooooo`15ooooo`Co0000>oooool4o`0002_ooooo0_l0000I
ooooo`;o0000@Oooool2o`0000gooooo0_l0000Cooooo`;o00004?ooool001kooooo00?o0000oooo
ooooool0AOooool2o`0003gooooo1?l0000Yooooo`;o00005oooool2o`0000;ooooo0_l00008oooo
o`;o00004oooool2o`0005Sooooo000Nooooo`;o0000<oooool2o`0005gooooo0_l0000Nooooo`;o
00005oooool2o`0000cooooo0_l0000Cooooo`;o00001?ooool2o`0002Cooooo0_l0000/ooooo`00
7_ooool00ol0003oooooooooo`0booooo`;o0000Doooool2o`0000Sooooo0_l00015ooooo`;o0000
6Oooool2o`0002Cooooo0_l0000/ooooo`007_ooool00ol0003oooooooooo`1;ooooo`;o0000>_oo
ool2o`0004oooooo0_l0000Looooo`;o0000<Oooool2o`0001cooooo000Nooooo`03o`000?oooooo
oooo02Cooooo0_l00003ooooo`;o00004oooool2o`0000_ooooo0_l00014ooooo`;o0000<oooool2
o`0000Kooooo0_l0000:ooooo`;o00006_ooool2o`00037ooooo0_l0000;ooooo`;o00003oooool0
01kooooo00?o0000ooooooooool09?ooool2o`0000?ooooo0_l0000Cooooo`;o0000DOooool2o`00
03?ooooo0_l00006ooooo`;o00002_ooool2o`0001Gooooo0_l00013ooooo`;o00003oooool001ko
oooo00?o0000ooooooooool0Doooool2o`0009cooooo0_l0000Nooooo`?o00001oooool3o`0002Wo
oooo000Nooooo`03o`000?oooooooooo02Gooooo0_l00006ooooo`;o00009?ooool2o`00047ooooo
0_l0000=ooooo`;o0000COooool2o`0001_ooooo0ol00007ooooo`?o0000:Oooool001kooooo00?o
0000ooooooooool09Oooool2o`0000Kooooo0_l0001Wooooo`;o00003Oooool2o`00043ooooo0_l0
000;ooooo`;o0000DOooool001kooooo00?o0000ooooooooool00_l0000Mooooo`;o00005?ooool2
o`0007Gooooo0_l0000iooooo`;o0000G_ooool001kooooo00?o0000ooooooooool00_l0000Moooo
o`;o00005?ooool2o`0000Kooooo0_l0001Hooooo`;o00001?ooool2o`0000Oooooo0_l00004oooo
o`;o00008Oooool2o`0007Kooooo000Nooooo`03o`000?oooooooooo03gooooo0_l0000Xooooo`;o
00005oooool2o`0000Gooooo0_l0000>ooooo`;o00001?ooool2o`0000Oooooo0_l0000Wooooo`;o
00003?ooool2o`0000Wooooo0_l0001Mooooo`007_ooool00ol0003oooooooooo`1Iooooo`;o0000
3?ooool4o`0001Gooooo0_l00005ooooo`;o0000E?ooool2o`0000;ooooo1?l00003ooooo`;o0000
3_ooool2o`0004gooooo000Nooooo`03o`000?oooooooooo013ooooo0_l0000Fooooo`;o0000;ooo
ool2o`0000kooooo0_l0001fooooo`Co00004oooool2o`0000_ooooo0_l00008ooooo`;o00007_oo
ool2o`0000Wooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o00005_ooool2
o`0002oooooo0_l0002Zooooo`;o00002?ooool2o`0001kooooo0_l00009ooooo`;o00002oooool0
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0EOooool2o`0004Oooooo0_l0000Oooooo`;o00007Ooo
ool2o`0001[ooooo0_l00010ooooo`;o00002Oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0
EOooool2o`0004Oooooo1?l0000Mooooo`;o00007Oooool2o`0000Cooooo0_l0000?ooooo`;o0000
0oooool2o`00043ooooo0_l00009ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo
00Go0000ooooooooooooooooo`000006ooooo`?o0000??ooool2o`0006;ooooo0_l00012ooooo`;o
00003oooool2o`00053ooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003o
V9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0??ooool2o`0000Wooooo0_l0001Eoooo
o`;o0000=Oooool2o`00073ooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0
003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0Aoooool2o`0002oooooo0_l0000?
ooooo`;o00004oooool2o`0003Gooooo0_l0000jooooo`;o0000=?ooool000?ooooo00Go410@oooo
oooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0>oooool2
o`000003ooooool0003o000001Gooooo0_l0000Qooooo`;o00003oooool2o`0003Sooooo0_l00012
ooooo`;o00002?ooool2o`00017ooooo0_l0000Qooooo`000oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0eooooo`;o00001?ooool2
o`000003ooooool0003o000001Gooooo0_l0001Uooooo`;o00001Oooool2o`0004;ooooo0_l0000K
ooooo`;o00008Oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co
0000oa0@40Kooooo00?o0000ooooooooool0=Oooool2o`0001kooooo0_l0000?ooooo`;o00008_oo
ool2o`00033ooooo0_l0000Hooooo`;o0000Koooool001kooooo00?o0000ooooooooool06_ooool2
o`0003oooooo0_l00009ooooo`;o00008_ooool2o`0004[ooooo0_l0001=ooooo`;o00008?ooool0
01kooooo00?o0000ooooooooool01oooool2o`00017ooooo0_l0000oooooo`;o0000I_ooool2o`00
063ooooo0_l0000Pooooo`007_ooool00ol0003oooooooooo`07ooooo`;o00004Oooool2o`0001oo
oooo0_l0000Iooooo`;o0000Joooool2o`0008;ooooo000Nooooo`03o`000?oooooooooo01[ooooo
1?l0000Mooooo`;o00002?ooool2o`0000oooooo0_l0000Fooooo`;o0000<?ooool2o`0006Cooooo
0_l0000Jooooo`;o00008oooool001kooooo00?o0000ooooooooool07?ooool2o`0002Oooooo0_l0
000Fooooo`;o00003oooool2o`0001[ooooo0_l0000Cooooo`?o00002oooool2o`0005?ooooo0_l0
0002ooooo`;o00006_ooool2o`0002?ooooo000Nooooo`03o`000?oooooooooo05Gooooo0_l00006
ooooo`;o00004Oooool2o`0001Kooooo1?l0000Cooooo`;o00003?ooool2o`0003Gooooo0_l0000L
ooooo`;o00003_ooool2o`0003?ooooo000Nooooo`03o`000?oooooooooo05Gooooo0_l0000=oooo
o`;o00002_ooool2o`0001Kooooo0_l0001Jooooo`;o0000;?ooool2o`0001gooooo0_l0000Doooo
o`007_ooool00ol0003oooooooooo`0Dooooo`;o0000C_ooool2o`0005Kooooo0_l0000aooooo`;o
0000@?ooool2o`0001Cooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0000`ooooo`;o0000
;Oooool2o`0004Gooooo0_l0000aooooo`;o00009oooool2o`0002gooooo000Nooooo`03o`000?oo
oooooooo00?ooooo0_l00011ooooo`Co00008_ooool2o`0000Oooooo0_l0000^ooooo`;o0000=ooo
ool2o`0003Sooooo0_l0000]ooooo`007_ooool00ol0003oooooooooo`03ooooo`;o00004?ooool2
o`00037ooooo0_l0000Rooooo`;o0000=oooool2o`0003Oooooo0_l0001Iooooo`;o00003?ooool0
01kooooo0_l0000Fooooo`;o0000>oooool2o`000:oooooo0_l0000dooooo`;o00003?ooool001ko
oooo00?o0000ooooooooool0@?ooool2o`00013ooooo0_l0001jooooo`;o0000<oooool2o`0000go
oooo0_l0000cooooo`007_ooool00ol0003oooooooooo`10ooooo`;o0000S?ooool2o`0000kooooo
0_l0000booooo`;o00001Oooool3o`0002_ooooo000Nooooo`03o`000?oooooooooo08Gooooo0_l0
000Sooooo`;o0000<_ooool2o`0000[ooooo0_l0000]ooooo`?o0000:oooool001kooooo00?o0000
ooooooooool03oooool2o`0007Cooooo0_l00002ooooo`;o00007oooool2o`0003Cooooo0_l00008
ooooo`;o0000Foooool001kooooo00?o0000ooooooooool03oooool2o`0007Sooooo0_l0001Coooo
o`Co0000IOooool001kooooo00?o0000ooooooooool03Oooool2o`000<7ooooo0_l0000<ooooo`;o
0000Ioooool001kooooo00?o0000ooooooooool00_l0000;ooooo`;o0000`Oooool2o`0007Gooooo
000Nooooo`03o`000?oooooooooo00;o0000C_ooool2o`0000_ooooo0_l0000looooo`;o00006_oo
ool2o`0001Gooooo0_l0001gooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o00003oooool2
o`0002Wooooo0_l0000;ooooo`;o0000??ooool2o`0001Sooooo1?l0000@ooooo`;o00000oooool2
o`0001Oooooo0_l0001Eooooo`;o00001oooool001kooooo00?o0000ooooooooool05?ooool2o`00
00Kooooo0_l00007ooooo`;o0000B_ooool2o`0004;ooooo0_l0000Booooo`;o00007?ooool2o`00
00Sooooo0_l00002ooooo`;o0000Aoooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo00go
oooo0_l0000=ooooo`;o00001Oooool2o`0004cooooo0_l0001Zooooo`;o00004_ooool2o`0000;o
oooo0_l0001@ooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o00005?ooool2o`00027ooooo
0ol0000[ooooo`;o0000Ioooool2o`0006Sooooo000Nooooo`03o`000?oooooooooo04Kooooo0ol0
000>ooooo`;o00006oooool2o`000=7ooooo000Nooooo`03o`000?oooooooooo02;ooooo0_l0000c
ooooo`;o00002Oooool2o`0003Gooooo0_l0000kooooo`;o0000Koooool001kooooo00?o0000oooo
ooooool08_ooool2o`0001oooooo0_l0000Mooooo`;o0000=Oooool2o`0003_ooooo0_l0000Foooo
o`;o0000Eoooool001kooooo0_l0000eooooo`;o00003Oooool2o`0000cooooo0_l0000Iooooo`;o
00001oooool2o`0004;ooooo0_l0000cooooo`;o0000Eoooool001kooooo00?o0000ooooooooool0
8_ooool2o`00013ooooo0_l0000Kooooo`;o00005?ooool2o`0000?ooooo0_l00007ooooo`;o0000
8_ooool2o`0001kooooo0_l0002<ooooo`007_ooool00ol0003oooooooooo`0Rooooo`;o0000@ooo
ool2o`00033ooooo0_l0002Nooooo`;o00003?ooool001kooooo00?o0000ooooooooool01_ooool2
o`000<Wooooo0_l0001Vooooo`;o00003?ooool001kooooo00?o0000ooooooooool01_ooool2o`00
00Cooooo0_l00033ooooo`;o00006oooool2o`0002Sooooo0_l0000]ooooo`007_ooool00ol0003o
ooooooooo`0<ooooo`;o0000W?ooool2o`0004;ooooo0_l0000Xooooo`;o0000;Oooool001kooooo
00?o0000ooooooooool06_ooool2o`00087ooooo0_l0000;ooooo`;o0000=oooool2o`0002Cooooo
0_l0000looooo`007_ooool00ol0003oooooooooo`0Jooooo`;o00005Oooool2o`0005cooooo0_l0
000<ooooo`;o0000A?ooool2o`0000?ooooo0_l0000Mooooo`Co0000??ooool001kooooo00?o0000
ooooooooool0<Oooool2o`0001?ooooo0_l00007ooooo`;o0000?_ooool2o`0005Oooooo0_l0000M
ooooo`;o0000?_ooool001kooooo00?o0000ooooooooool0:?ooool2o`0001cooooo0_l00007oooo
o`;o00000oooool2o`000003ooooool0003o0000033ooooo0_l0002looooo`007_ooool00ol0003o
ooooooooo`0@ooooo`;o00005_ooool2o`0002[ooooo0_l000000ooooooo0000o`00000`ooooo`;o
0000NOooool2o`00047ooooo000Nooooo`03o`000?oooooooooo013ooooo0_l0002Iooooo`;o0000
4_ooool2o`0004?ooooo0_l0000Wooooo`;o00006?ooool001kooooo00?o0000ooooooooool0FOoo
ool2o`0002Gooooo0_l0000Yooooo`;o00004_ooool2o`0004Sooooo0_l0000Rooooo`;o00003Ooo
ool2o`0000Wooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l0000Kooooo`;o00005_ooool2
o`0002Gooooo0_l00027ooooo`;o00008oooool2o`0000cooooo0_l00009ooooo`007_ooool00ol0
003oooooooooo`0Tooooo`;o00003Oooool2o`0000cooooo0_l00005ooooo`;o00003oooool2o`00
04Oooooo0_l0002:ooooo`;o00005oooool001kooooo00?o0000ooooooooool0<oooool2o`0001?o
oooo0_l0001Hooooo`;o00004Oooool2o`0004;ooooo0_l0001<ooooo`007_ooool2o`0005?ooooo
0_l0000=ooooo`;o0000D_ooool2o`0004;ooooo0_l0001<ooooo`007_ooool00ol0003ooooooooo
o`0dooooo`;o00007?ooool2o`0000gooooo0_l0001Iooooo`;o0000:?ooool2o`0002cooooo0_l0
000aooooo`007_ooool00ol0003oooooooooo`0/ooooo`;o00001_ooool2o`0008Kooooo0_l0000X
ooooo`;o00009?ooool2o`0000Kooooo0_l0000Booooo`;o00002_ooool2o`00017ooooo000Noooo
o`03o`000?oooooooooo00Cooooo0_l0000Vooooo`;o0000BOooool2o`0001Sooooo0_l0001ioooo
o`;o00006_ooool2o`0000[ooooo0_l0000Aooooo`007_ooool00ol0003oooooooooo`04ooooo`;o
0000LOooool2o`0001Sooooo0_l0001Qooooo`;o00008oooool2o`0001Sooooo0_l0000Booooo`00
7_ooool00ol0003oooooooooo`3dooooo`;o00008oooool2o`0001Sooooo0_l0000Booooo`007_oo
ool00ol0003oooooooooo`2Wooooo`;o0000<_ooool2o`0006[ooooo000Nooooo`03o`000?oooooo
oooo0:Oooooo0_l0000booooo`;o0000J_ooool001kooooo00?o0000ooooooooool0Yoooool2o`00
05Oooooo0_l0000Oooooo`;o00009?ooool001kooooo00?o0000ooooooooool0E_ooool2o`0000;o
oooo0_l00004ooooo`;o00002Oooool2o`0007kooooo0_l0000Cooooo`;o00007oooool2o`0002Co
oooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0000Uooooo`;o00009_ooool2o`0000;ooooo
0_l00004ooooo`;o00002Oooool2o`0007kooooo0_l0000Looooo`;o0000??ooool001kooooo00?o
0000ooooooooool00_l00005ooooo`;o00009Oooool2o`0005Gooooo0_l0001cooooo`;o00003Ooo
ool2o`0000_ooooo0_l00007ooooo`;o00009_ooool001kooooo00?o0000ooooooooool00_l0000m
ooooo`;o0000>oooool2o`0000Oooooo0_l00016ooooo`;o0000:oooool2o`0001Sooooo1?l00007
ooooo`;o00002?ooool2o`00013ooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0Roooo
o`;o00006oooool2o`0000Kooooo0_l0000Pooooo`;o00004Oooool2o`0003?ooooo0_l0000Joooo
o`;o0000;oooool2o`0001Cooooo0_l0000Cooooo`;o00004?ooool2o`0000[ooooo0003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006
ooooo`03o`000?oooooooooo02;ooooo0_l0000Sooooo`;o00008?ooool2o`0004Kooooo0_l0001;
ooooo`;o0000;?ooool2o`0001Wooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?oooooo9_oo
ool2o`0000Gooooo0_l0000Iooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000doooool2o`0000Wooooo0_l0000eooooo`;o0000
1?ooool2o`0000Sooooo0_l0000Pooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo
00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooooooo01kooooo0_l0001hooooo`;o
0000<oooool2o`0000Cooooo0_l00009ooooo`;o0000=Oooool2o`0000Cooooo0_l0000Zooooo`00
0oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006oooo
o`03o`000?oooooooooo01kooooo0_l0001hooooo`;o0000<oooool2o`0006Cooooo0_l0000Boooo
o`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006
ooooo`03o`000?oooooooooo01Cooooo0_l0000Booooo`;o000000?oooooo`000?l00000Uoooool2
o`0000Kooooo0_l0000?ooooo`;o00003oooool2o`0004?ooooo0_l0000Booooo`000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oo
oooooooo01Cooooo0_l0000Booooo`;o000000?oooooo`000?l000004oooool2o`0008;ooooo0_l0
0006ooooo`;o00003oooool2o`0000oooooo0_l00004ooooo`;o0000DOooool000?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003ooooo
ooooo`0oooooo`?o0000/_ooool2o`0001Kooooo0_l0000?ooooo`;o0000:?ooool001kooooo00?o
0000ooooooooool06Oooool2o`0002Cooooo0_l0003;ooooo`;o00001?ooool2o`0000Wooooo0_l0
000Xooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o00004oooool2o`000>;ooooo0_l0000c
ooooo`007_ooool00ol0003oooooooooo`0^ooooo`Co0000goooool2o`0003Cooooo000Nooooo`03
o`000?oooooooooo033ooooo0_l0002Xooooo`;o0000=Oooool2o`0003Cooooo000Nooooo`03o`00
0?oooooooooo0=[ooooo0_l0001[ooooo`007_ooool00ol0003oooooooooo`07ooooo`;o0000MOoo
ool2o`0002gooooo0_l0001Mooooo`;o00001Oooool2o`0003;ooooo000Nooooo`03o`000?oooooo
oooo00Oooooo0_l0000Pooooo`;o0000Doooool2o`0000?ooooo0_l00002ooooo`;o00009?ooool2
o`0005gooooo0_l00005ooooo`;o00002oooool2o`0002Gooooo000Nooooo`03o`000?oooooooooo
02Wooooo0_l0001Fooooo`Co00000_ooool2o`00093ooooo0_l00005ooooo`;o00009Oooool001ko
oooo00?o0000ooooooooool0POooool2o`0000_ooooo0_l0000Dooooo`;o0000Loooool4o`0000So
oooo0_l0000Pooooo`007_ooool00ol0003oooooooooo`02o`0005Kooooo0_l0000dooooo`;o0000
5?ooool2o`00073ooooo0_l00003ooooo`;o00002?ooool2o`00023ooooo000Nooooo`03o`000?oo
oooooooo00;o0000E_ooool2o`000;cooooo0_l0000_ooooo`007_ooool2o`000?ooooooBOooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`29ooooo`;o
0000@oooool2o`0007Oooooo000Nooooo`03o`000?oooooooooo057ooooo0_l0000fooooo`;o0000
7?ooool2o`0002Gooooo0_l0001gooooo`007_ooool00ol0003oooooooooo`1Aooooo`;o0000E?oo
ool2o`0005_ooooo0_l00006ooooo`;o0000>Oooool001kooooo00?o0000ooooooooool0GOooool3
o`0001Oooooo0_l0000[ooooo`;o0000G_ooool2o`0000Kooooo0_l0000iooooo`007_ooool00ol0
003oooooooooo`03ooooo`;o00003_ooool2o`0001Kooooo0_l0000`ooooo`?o00005oooool2o`00
02_ooooo0_l0000Iooooo`;o0000:oooool2o`0003gooooo0_l0000Jooooo`007_ooool00ol0003o
ooooooooo`03ooooo`;o00002oooool2o`000003ooooool0003o000001Kooooo0_l0000^ooooo`;o
0000H_ooool2o`0000kooooo0_l0000Kooooo`;o0000?Oooool2o`0001[ooooo000Nooooo`03o`00
0?oooooooooo013ooooo0_l0000_ooooo`;o00006?ooool2o`0007;ooooo0_l0001fooooo`007_oo
ool00ol0003oooooooooo`11ooooo`;o0000ooooool5ooooo`007_ooool00ol0003oooooooooo`13
ooooo`;o0000ooooool3ooooo`007_ooool00ol0003oooooooooo`13ooooo`;o0000K_ooool2o`00
09;ooooo000Nooooo`03o`000?oooooooooo0;?ooooo0_l0002Booooo`007_ooool00ol0003ooooo
ooooo`14ooooo`;o00002?ooool2o`0000_ooooo0_l0000hooooo`;o0000/?ooool001kooooo00?o
0000ooooooooool08?ooool2o`0002;ooooo0_l00008ooooo`;o00002oooool2o`0003Sooooo0_l0
002Iooooo`;o00005Oooool001kooooo00?o0000ooooooooool08?ooool2o`0008Sooooo0_l00024
ooooo`;o00002_ooool2o`0000Wooooo000Nooooo`;o0000ROooool2o`00023ooooo0_l0001Soooo
o`;o0000:oooool3o`0000Sooooo000Nooooo`03o`000?oooooooooo08Sooooo0_l00025ooooo`;o
0000;?ooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo01Sooooo0_l0001?ooooo`;o0000
7_ooool2o`0000[ooooo0_l0002`ooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o00002?oo
ool2o`0000Kooooo0_l0000<ooooo`;o0000;oooool2o`0001kooooo0_l0000:ooooo`;o0000Q_oo
ool2o`0002Sooooo000Nooooo`03o`000?oooooooooo01Sooooo0_l00008ooooo`;o00001_ooool2
o`0000cooooo0_l0000fooooo`;o0000Zoooool2o`0002Sooooo000Nooooo`03o`000?oooooooooo
01Sooooo0_l0001Fooooo`;o0000:?ooool2o`000:_ooooo000Nooooo`03o`000?oooooooooo01Co
oooo0_l0000hooooo`;o00004Oooool2o`0002Kooooo0_l0000?ooooo`;o0000S?ooool2o`0001go
oooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0000hooooo`;o00004Oooool2o`0002Cooooo
1?l0002Mooooo`;o00007Oooool001kooooo00?o0000ooooooooool0Qoooool2o`0004gooooo0_l0
001_ooooo`007_ooool00ol0003oooooooooo`3Fooooo`;o0000Ioooool2o`0000Kooooo000Noooo
o`03o`000?oooooooooo05_ooooo0_l0000fooooo`;o0000K?ooool2o`0003cooooo0_l00006oooo
o`007_ooool00ol0003oooooooooo`0/ooooo`;o00008?ooool2o`0000_ooooo0_l0000fooooo`;o
0000AOooool2o`0001Oooooo0_l0000<ooooo`;o00002Oooool2o`0003Wooooo000Nooooo`03o`00
0?oooooooooo02cooooo0_l0000Pooooo`;o0000R_ooool2o`0001Oooooo0_l0000Gooooo`;o0000
0_ooool2o`0003Gooooo000Nooooo`03o`000?oooooooooo04cooooo0_l0002Gooooo`;o0000:Ooo
ool2o`0000kooooo0_l0000>ooooo`;o00005Oooool001kooooo00?o0000ooooooooool0C?ooool2
o`0009Oooooo0_l00006ooooo`;o0000<Oooool2o`0000kooooo0_l0000Eooooo`007_ooool00ol0
003oooooooooo`0gooooo`;o00007_ooool2o`00033ooooo0_l0001Rooooo`;o0000>Oooool2o`00
00Gooooo0_l0000Fooooo`007_ooool2o`0003Sooooo0_l0000Nooooo`;o0000<?ooool2o`0009go
oooo0_l00005ooooo`;o00005_ooool001kooooo00?o0000ooooooooool0:Oooool2o`000>Cooooo
0_l0000?ooooo`;o00009Oooool001kooooo00Co0000ooooool0003o0000:?ooool2o`000>Cooooo
0_l0000?ooooo`;o00003Oooool2o`0001Kooooo000Nooooo`04o`000?oooooo0000o`000:;ooooo
0_l00015ooooo`;o00009_ooool4o`0001Wooooo0_l0000Fooooo`007_ooool00ol0003ooooooooo
o`1Vooooo`;o0000>oooool2o`0004Gooooo0_l0000Vooooo`Co0000<Oooool001kooooo00?o0000
ooooooooool05oooool2o`0004gooooo0_l0001Uooooo`;o00001_ooool2o`0003Kooooo0_l00000
0ooooooo0000o`00000eooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o00002?ooool2o`00
00kooooo0_l0000fooooo`;o0000K?ooool2o`0000Kooooo0_l000000ooooooo0000o`00000coooo
o`;o000000?oooooo`000?l00000=Oooool001kooooo00?o0000ooooooooool00_ooool2o`0000Wo
oooo0_l0000Hooooo`;o00005oooool2o`0001gooooo0_l0001Uooooo`;o00004?ooool2o`0006go
oooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0000Mooooo`;o00001_ooool2o`0000_ooooo
0_l00008ooooo`;o00009?ooool2o`0000Oooooo0_l0001Eooooo`;o0000Ooooool001kooooo00?o
0000ooooooooool00_l0000Oooooo`;o00001_ooool2o`0000_ooooo0_l0000Fooooo`;o00005_oo
ool2o`0000Oooooo0_l0001jooooo`;o00008Oooool2o`0000gooooo0_l0000Xooooo`007_ooool0
0ol0003oooooooooo`02o`0000Wooooo0_l00011ooooo`;o00001_ooool2o`0009?ooooo0_l0000Q
ooooo`;o00003Oooool2o`0002Sooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l00019oooo
o`;o0000B_ooool2o`0004Sooooo0_l0001Iooooo`007_ooool00ol0003oooooooooo`0eooooo`;o
0000Joooool2o`00017ooooo0_l0000Kooooo`;o00006?ooool2o`0001?ooooo0_l0000>ooooo`;o
0000=?ooool001kooooo00?o0000ooooooooool0=Oooool2o`0006Gooooo0_l0000Gooooo`;o0000
0oooool2o`0001Kooooo0_l0000]ooooo`;o00003_ooool2o`0003Cooooo000Dooooo`Co000000?o
410@ooooooooool00oooool00ol0003oooooooooo`0[ooooo`;o0000Koooool2o`0000;ooooo0_l0
000Hooooo`;o0000J?ooool2o`00027ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0:oooool2o`0007?ooooo0_l00003ooooo`;o0000@oooool2o`0003Sooooo0_l0000Q
ooooo`005_ooool00ol0003oooooooooo`05ooooo`?o0000H_ooool2o`0000_ooooo0_l0000doooo
o`;o0000?_ooool2o`0000?ooooo0_l0000;ooooo`;o0000C_ooool001Kooooo00?o0000oooooooo
ool0J_ooool2o`0000_ooooo0_l0001dooooo`;o00004?ooool2o`0004kooooo000Fooooo`03o`00
0?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool0
0ol0003oooooooooo`3ooooooe3ooooo000Dooooo`03oeEEEOmVIVKo00000?ooooooD_ooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.29852 .64051 Mdot
.83888 .63202 Mdot
.7461 .99432 Mdot
.13876 .51681 Mdot
.10284 .61287 Mdot
.834 .89511 Mdot
.22651 .74575 Mdot
.24242 .70256 Mdot
.68586 .21675 Mdot
.04819 .02309 Mdot
.59107 .10174 Mdot
.81507 .57258 Mdot
.92297 .5888 Mdot
.19865 .67922 Mdot
.50767 .31763 Mdot
.10307 .74354 Mdot
.41874 .91667 Mdot
.61452 .47333 Mdot
.87439 .96213 Mdot
.68275 .1053 Mdot
.60639 .19111 Mdot
.70275 .06153 Mdot
.59899 .94252 Mdot
.29127 .23628 Mdot
.64079 .26216 Mdot
.0529 .32487 Mdot
.76976 .03445 Mdot
.57259 .38846 Mdot
.02076 .55994 Mdot
.2843 .42807 Mdot
.49847 .39528 Mdot
.2045 .58696 Mdot
.41131 .8715 Mdot
.1491 .12321 Mdot
.66884 .89706 Mdot
.18539 .54975 Mdot
.02954 .39606 Mdot
.38978 .12078 Mdot
.3094 .8899 Mdot
.93023 .04072 Mdot
.14523 .42687 Mdot
.50561 .08649 Mdot
.23277 .5938 Mdot
.14941 .51922 Mdot
.50239 .49464 Mdot
.73565 .56529 Mdot
.99716 .29303 Mdot
.77291 .51699 Mdot
.41444 .6509 Mdot
.90921 .52453 Mdot
.59184 .4155 Mdot
.19896 .48855 Mdot
.19123 .54032 Mdot
.99424 .36778 Mdot
.70429 .31287 Mdot
.56815 .3389 Mdot
.40648 .94461 Mdot
.97868 .66829 Mdot
.0775 .44019 Mdot
.04357 .64577 Mdot
.30083 .5093 Mdot
.55408 .74343 Mdot
.26697 .144 Mdot
.96691 .19379 Mdot
.31299 .51793 Mdot
.41103 .11742 Mdot
.55536 .61667 Mdot
.61855 .34766 Mdot
.34496 .56388 Mdot
.98242 .07599 Mdot
.70642 .66237 Mdot
.66734 .00535 Mdot
.18065 .75642 Mdot
.97308 .00493 Mdot
.05824 .66409 Mdot
.39344 .25836 Mdot
.70646 .49977 Mdot
.06804 .92397 Mdot
.65174 .11288 Mdot
.41748 .09615 Mdot
.54175 .35127 Mdot
.50638 .19471 Mdot
.22006 .09337 Mdot
.5887 .48116 Mdot
.93932 .14089 Mdot
.60082 .44895 Mdot
.5761 .85415 Mdot
.81369 .35975 Mdot
.56842 .15463 Mdot
.74281 .39763 Mdot
.98701 .05536 Mdot
.32117 .10123 Mdot
.32585 .76372 Mdot
.89021 .20721 Mdot
.81876 .86594 Mdot
.56115 .67166 Mdot
.99605 .57662 Mdot
.80448 .55348 Mdot
.51016 .53832 Mdot
.01714 .99048 Mdot
.62966 .21178 Mdot
.78608 .44183 Mdot
.93146 .7721 Mdot
.16553 .23509 Mdot
.93249 .86047 Mdot
.17445 .01848 Mdot
.72172 .24997 Mdot
.12458 .22735 Mdot
.15925 .24245 Mdot
.23769 .63469 Mdot
.75537 .66286 Mdot
.16216 .14399 Mdot
.64315 .6197 Mdot
.14935 .44629 Mdot
.3911 .43326 Mdot
.25334 .73676 Mdot
.60504 .67184 Mdot
.15677 .96708 Mdot
.99968 .77648 Mdot
.65496 .79979 Mdot
.76829 .62076 Mdot
.53219 .01162 Mdot
.23527 .91449 Mdot
.27671 .65886 Mdot
.34032 .29648 Mdot
.62525 .62731 Mdot
.81072 .04996 Mdot
.0078 .53032 Mdot
.29917 .79231 Mdot
.59019 .14219 Mdot
.25186 .28158 Mdot
.30051 .44507 Mdot
.32716 .81386 Mdot
.20182 .41974 Mdot
.7935 .78976 Mdot
.35969 .6799 Mdot
.42756 .05087 Mdot
.12006 .11571 Mdot
.65744 .87225 Mdot
.39654 .52276 Mdot
.33772 .94825 Mdot
.847 .98843 Mdot
.90456 .50775 Mdot
.23006 .58791 Mdot
.93705 .28293 Mdot
.26732 .78331 Mdot
.02318 .7329 Mdot
.28134 .37894 Mdot
.11901 .52011 Mdot
.92355 .2396 Mdot
.25857 .32722 Mdot
.56879 .4345 Mdot
.20372 .46409 Mdot
.90374 .76944 Mdot
.92006 .38662 Mdot
.94258 .61818 Mdot
.03727 .36436 Mdot
.48773 .75231 Mdot
.46623 .08924 Mdot
.24974 .46481 Mdot
.16409 .1691 Mdot
.87972 .30748 Mdot
.01173 .93665 Mdot
.14981 .1082 Mdot
.84913 .44875 Mdot
.97795 .99177 Mdot
.66906 .81051 Mdot
.01809 .19943 Mdot
.84059 .48892 Mdot
.21503 .58985 Mdot
.10133 .40267 Mdot
.88979 .59585 Mdot
.30365 .9849 Mdot
.43659 .01627 Mdot
.31444 .21542 Mdot
.19559 .40086 Mdot
.28927 .89636 Mdot
.17128 .31422 Mdot
.03687 .2155 Mdot
.72319 .00667 Mdot
.01364 .59895 Mdot
.88462 .60241 Mdot
.16297 .37667 Mdot
.14657 .90591 Mdot
.67429 .58139 Mdot
.20016 .7574 Mdot
.16174 .3171 Mdot
.69894 .93041 Mdot
.59806 .65452 Mdot
.55137 .89564 Mdot
.29855 .07564 Mdot
.433 .76354 Mdot
.40498 .73612 Mdot
.68995 .62662 Mdot
.96431 .91911 Mdot
.69857 .54773 Mdot
.73491 .51732 Mdot
.56985 .5668 Mdot
.24611 .89554 Mdot
.56663 .31404 Mdot
.27662 .50583 Mdot
.99271 .54695 Mdot
.54472 .73376 Mdot
.22469 .90818 Mdot
.26837 .30166 Mdot
.24589 .76333 Mdot
.46063 .57264 Mdot
.74236 .03276 Mdot
.80472 .97266 Mdot
.53761 .09936 Mdot
.31342 .94112 Mdot
.26084 .85087 Mdot
.96853 .23929 Mdot
.79719 .47107 Mdot
.7143 .79759 Mdot
.62355 .48966 Mdot
.34581 .11835 Mdot
.65904 .21518 Mdot
.02686 .74151 Mdot
.57718 .80103 Mdot
.87804 .78579 Mdot
.23229 .46391 Mdot
.09783 .03606 Mdot
.26976 .45166 Mdot
.22346 .9566 Mdot
.0864 .78879 Mdot
.88682 .00989 Mdot
.93394 .28342 Mdot
.48379 .56726 Mdot
.0326 .65967 Mdot
.24808 .96725 Mdot
.06644 .58256 Mdot
.29447 .59126 Mdot
.05967 .79415 Mdot
.16713 .83338 Mdot
.97081 .92211 Mdot
.40216 .19922 Mdot
.66637 .63744 Mdot
.00938 .20399 Mdot
.26875 .72541 Mdot
.22572 .80393 Mdot
.26181 .0192 Mdot
.93973 .9131 Mdot
.0994 .0149 Mdot
.73603 .63383 Mdot
.49069 .01489 Mdot
.31793 .89503 Mdot
.64342 .70736 Mdot
.24154 .16187 Mdot
.19439 .59975 Mdot
.32399 .41007 Mdot
.65342 .45742 Mdot
.21254 .34982 Mdot
.72168 .79383 Mdot
.74945 .55162 Mdot
.07752 .69671 Mdot
.17299 .55429 Mdot
.05106 .00918 Mdot
.25954 .26327 Mdot
.90075 .93852 Mdot
.46487 .78813 Mdot
.5133 .34702 Mdot
.66396 .29959 Mdot
.54169 .38086 Mdot
.11018 .94381 Mdot
.06341 .41047 Mdot
.419 .94145 Mdot
.28819 .66386 Mdot
.53419 .10879 Mdot
.89614 .5932 Mdot
.81467 .38071 Mdot
.17431 .28199 Mdot
.48765 .96382 Mdot
.35991 .4945 Mdot
.25373 .71054 Mdot
.80768 .75557 Mdot
.89748 .76778 Mdot
.84733 .22477 Mdot
.45698 .455 Mdot
.92995 .91812 Mdot
.85922 .14382 Mdot
.54279 .2229 Mdot
.8434 .68878 Mdot
.85425 .51419 Mdot
.42704 .28536 Mdot
.65297 .23081 Mdot
.72049 .35582 Mdot
.83009 .31067 Mdot
.82402 .40221 Mdot
.83467 .91633 Mdot
.13495 .5209 Mdot
.19878 .21914 Mdot
.09514 .95291 Mdot
.92633 .62234 Mdot
.83825 .1819 Mdot
.74194 .28016 Mdot
.31168 .34932 Mdot
.60376 .39183 Mdot
.7695 .45151 Mdot
.24454 .11434 Mdot
.44025 .40227 Mdot
.70786 .18746 Mdot
.26734 .49256 Mdot
.89948 .99287 Mdot
.57778 .41929 Mdot
.2991 .38885 Mdot
.36886 .03259 Mdot
.58606 .05978 Mdot
.43309 .98114 Mdot
.52841 .69308 Mdot
.41376 .54708 Mdot
.74604 .56955 Mdot
.96325 .36345 Mdot
.00775 .39493 Mdot
.13885 .02975 Mdot
.25111 .58508 Mdot
.79016 .90894 Mdot
.26535 .62352 Mdot
.64916 .31562 Mdot
.57121 .26841 Mdot
.91289 .99862 Mdot
.09495 .88588 Mdot
.51922 .27915 Mdot
.62551 .06398 Mdot
.41252 .40296 Mdot
.67999 .46258 Mdot
.91321 .4123 Mdot
.42082 .41901 Mdot
.91594 .11396 Mdot
.35711 .16779 Mdot
.0077 .71783 Mdot
.19313 .81813 Mdot
.33235 .38469 Mdot
.66072 .95099 Mdot
.02664 .69632 Mdot
.28744 .71054 Mdot
.26293 .0913 Mdot
.38785 .50998 Mdot
.96232 .46765 Mdot
.75427 .26334 Mdot
.90331 .00478 Mdot
.25689 .87082 Mdot
.21892 .47574 Mdot
.583 .82144 Mdot
.14985 .45269 Mdot
.4193 .00538 Mdot
.36036 .24718 Mdot
.85953 .79618 Mdot
.39917 .67956 Mdot
.17626 .63065 Mdot
.27878 .04067 Mdot
.80448 .66659 Mdot
.12093 .49765 Mdot
.66694 .30445 Mdot
.90295 .80798 Mdot
.85785 .99431 Mdot
.15885 .27707 Mdot
.15107 .37295 Mdot
.71231 .37202 Mdot
.70158 .07916 Mdot
.91711 .8238 Mdot
.54586 .61764 Mdot
.607 .59094 Mdot
.73348 .35962 Mdot
.93843 .2842 Mdot
.46623 .13218 Mdot
.08616 .46749 Mdot
.74944 .55937 Mdot
.57285 .40363 Mdot
.14321 .53828 Mdot
.7176 .32659 Mdot
.89107 .12057 Mdot
.44177 .76615 Mdot
.66341 .83588 Mdot
.37196 .68814 Mdot
.41346 .83476 Mdot
.23227 .63564 Mdot
.71035 .67269 Mdot
.20383 .62888 Mdot
.27917 .07719 Mdot
.97599 .28804 Mdot
.06484 .10271 Mdot
.83516 .77827 Mdot
.62471 .27107 Mdot
.33451 .73695 Mdot
.68658 .64169 Mdot
.44086 .68451 Mdot
.18198 .73165 Mdot
.30655 .15673 Mdot
.49761 .08454 Mdot
.87151 .53185 Mdot
.20776 .95002 Mdot
.3108 .10384 Mdot
.47468 .18742 Mdot
.11861 .70929 Mdot
.57039 .43892 Mdot
.81017 .92122 Mdot
.82273 .32898 Mdot
.94422 .61101 Mdot
.77433 .49216 Mdot
.94421 .36493 Mdot
.58339 .35675 Mdot
.63708 .5724 Mdot
.46305 .26399 Mdot
.34405 .46245 Mdot
.09441 .93455 Mdot
.88129 .50384 Mdot
.88532 .06607 Mdot
.36959 .5044 Mdot
.41975 .87432 Mdot
.0734 .92637 Mdot
.70655 .66882 Mdot
.87974 .78152 Mdot
.94532 .61698 Mdot
.02339 .97854 Mdot
.55015 .54173 Mdot
.27889 .13349 Mdot
.8923 .68503 Mdot
.76147 .01183 Mdot
.85938 .82974 Mdot
.74599 .52252 Mdot
.96113 .97816 Mdot
.75912 .98014 Mdot
.45294 .20776 Mdot
.53734 .06497 Mdot
.53274 .51576 Mdot
.17518 .746 Mdot
.09679 .62656 Mdot
.6297 .57917 Mdot
.49863 .09392 Mdot
.37914 .49811 Mdot
.3859 .38487 Mdot
.67969 .16292 Mdot
.97485 .28543 Mdot
.20472 .99409 Mdot
.93919 .37741 Mdot
.40699 .3281 Mdot
.16392 .18523 Mdot
.62226 .27307 Mdot
.31234 .96607 Mdot
.61541 .40746 Mdot
.43574 .0975 Mdot
.2657 .18659 Mdot
.90307 .9474 Mdot
.92141 .19627 Mdot
.16879 .69689 Mdot
.72429 .99379 Mdot
.57473 .34073 Mdot
.50409 .53627 Mdot
.35254 .6276 Mdot
.14697 .93357 Mdot
.18842 .72652 Mdot
.89611 .46318 Mdot
.4389 .03188 Mdot
.44916 .25231 Mdot
.5705 .68944 Mdot
.53629 .60281 Mdot
.30873 .46262 Mdot
.59191 .20116 Mdot
.08211 .67411 Mdot
.6598 .42017 Mdot
.36599 .04641 Mdot
.88854 .99201 Mdot
.47633 .91151 Mdot
.34166 .58872 Mdot
.25259 .75041 Mdot
.03566 .12869 Mdot
.39506 .79574 Mdot
.21737 .93845 Mdot
.89953 .57414 Mdot
.36563 .61448 Mdot
.39076 .63362 Mdot
.62993 .89253 Mdot
.02661 .40695 Mdot
.06108 .71448 Mdot
.62145 .37134 Mdot
.65494 .41983 Mdot
.49368 .51059 Mdot
.85904 .10728 Mdot
.53321 .58134 Mdot
.93712 .91814 Mdot
.68571 .21816 Mdot
.78031 .07196 Mdot
.29437 .63478 Mdot
.16128 .57084 Mdot
.57063 .45017 Mdot
.36375 .40516 Mdot
.06598 .07443 Mdot
.74026 .3968 Mdot
.71842 .28498 Mdot
.33393 .07697 Mdot
.21856 .27753 Mdot
.28436 .60853 Mdot
.84274 .98594 Mdot
.21021 .41883 Mdot
.68263 .5604 Mdot
.71984 .57456 Mdot
.54608 .36416 Mdot
.04749 .35865 Mdot
.71734 .68654 Mdot
.6578 .79857 Mdot
.30154 .21052 Mdot
.49563 .3479 Mdot
.9827 .99682 Mdot
.21409 .09872 Mdot
.39587 .49167 Mdot
.84167 .41155 Mdot
.54816 .98036 Mdot
.74146 .36307 Mdot
.2412 .57809 Mdot
.79601 .44496 Mdot
.10557 .77378 Mdot
.08102 .51387 Mdot
.00813 .2493 Mdot
.85378 .39014 Mdot
.08023 .86162 Mdot
.86391 .36344 Mdot
.46891 .74879 Mdot
.00221 .25863 Mdot
.2658 .72106 Mdot
.59022 .50942 Mdot
.76705 .92964 Mdot
.94971 .47139 Mdot
.17164 .13093 Mdot
.87519 .0804 Mdot
.29805 .11517 Mdot
.36258 .72526 Mdot
.32812 .52343 Mdot
.49712 .26706 Mdot
.39239 .59576 Mdot
.81794 .62704 Mdot
.38556 .71896 Mdot
.9759 .06392 Mdot
.76317 .21038 Mdot
.9813 .80037 Mdot
.12991 .83341 Mdot
.46434 .0447 Mdot
.23883 .17199 Mdot
.87675 .20254 Mdot
.03881 .63847 Mdot
.953 .75729 Mdot
.04743 .79251 Mdot
.51236 .28382 Mdot
.93198 .15789 Mdot
.36036 .38654 Mdot
.2497 .47002 Mdot
.80108 .81724 Mdot
.31491 .74586 Mdot
.1058 .95302 Mdot
.80359 .00585 Mdot
.76844 .58603 Mdot
.33996 .20634 Mdot
.25554 .97379 Mdot
.14233 .34562 Mdot
.71792 .75993 Mdot
.6407 .01914 Mdot
.45428 .87012 Mdot
.09945 .0699 Mdot
.40241 .61603 Mdot
.16877 .66136 Mdot
.04935 .60206 Mdot
.83199 .80338 Mdot
.88378 .07955 Mdot
.3436 .56289 Mdot
.88024 .67336 Mdot
.91436 .12543 Mdot
.64142 .28276 Mdot
.81798 .05137 Mdot
.66442 .00683 Mdot
.92303 .73814 Mdot
.47406 .09571 Mdot
.1351 .88677 Mdot
.85371 .83329 Mdot
.943 .82694 Mdot
.85361 .38069 Mdot
.95477 .17165 Mdot
.32709 .91326 Mdot
.27797 9e-05 Mdot
.50944 .07546 Mdot
.32357 .96125 Mdot
.79063 .31482 Mdot
.61892 .95364 Mdot
.29207 .19674 Mdot
.83284 .23328 Mdot
.04423 .87258 Mdot
.67399 .58669 Mdot
.02686 .24297 Mdot
.83967 .16128 Mdot
.64534 .56417 Mdot
.03867 .30195 Mdot
.7137 .68152 Mdot
.60777 .94694 Mdot
.16369 .14175 Mdot
.20818 .64754 Mdot
.44248 .5393 Mdot
.30837 .7746 Mdot
.10648 .02444 Mdot
.16943 .21851 Mdot
.5225 .70089 Mdot
.18113 .97192 Mdot
.81992 .14737 Mdot
.1701 .46514 Mdot
.56718 .20245 Mdot
.62503 .32961 Mdot
.46486 .40702 Mdot
.14809 .31437 Mdot
.82277 .61455 Mdot
.79756 .04043 Mdot
.21331 .58648 Mdot
.90453 .3921 Mdot
.74409 .89241 Mdot
.15387 .15428 Mdot
.37193 .28123 Mdot
.93645 .83259 Mdot
.00896 .66544 Mdot
.6904 .2659 Mdot
.37266 .39344 Mdot
.54442 .28202 Mdot
.7102 .22859 Mdot
.98673 .39975 Mdot
.71384 .46495 Mdot
.99259 .30299 Mdot
.81035 .48497 Mdot
.81331 .94394 Mdot
.01598 .84038 Mdot
.66921 .98454 Mdot
.09009 .60515 Mdot
.26475 .75529 Mdot
.43376 .88994 Mdot
.49245 .90121 Mdot
.57892 .18782 Mdot
.62183 .62253 Mdot
.06201 .28047 Mdot
.44902 .63991 Mdot
.4184 .32087 Mdot
.68483 .11457 Mdot
.60467 .69512 Mdot
.46066 .66232 Mdot
.15035 .33634 Mdot
.6684 .99632 Mdot
.37951 .81233 Mdot
.29977 .19116 Mdot
.56575 .23895 Mdot
.95882 .90239 Mdot
.66953 .47523 Mdot
.20978 .35629 Mdot
.51103 .72815 Mdot
.14554 .34959 Mdot
.13293 .00318 Mdot
.86359 .98965 Mdot
.69819 .68603 Mdot
.03937 .90784 Mdot
.81943 .8123 Mdot
.05914 .75261 Mdot
.03028 .31613 Mdot
.29464 .80442 Mdot
.50306 .53047 Mdot
.27363 .34631 Mdot
.07298 .41835 Mdot
.57391 .3703 Mdot
.95712 .89243 Mdot
.49315 .35604 Mdot
.64409 .42257 Mdot
.38651 .73617 Mdot
.63516 .42741 Mdot
.45954 .76138 Mdot
.74619 .41147 Mdot
.14381 .24714 Mdot
.56123 .9323 Mdot
.8996 .34568 Mdot
.40596 .15786 Mdot
.15999 .86078 Mdot
.17692 .44615 Mdot
.703 .22112 Mdot
.9698 .03282 Mdot
.69604 .29299 Mdot
.45321 .86548 Mdot
.48051 .23643 Mdot
.35084 .4021 Mdot
.44213 .2361 Mdot
.75385 .75243 Mdot
.6505 .74813 Mdot
.66519 .44784 Mdot
.48691 .80053 Mdot
.72719 .59324 Mdot
.94646 .34414 Mdot
.68248 .09113 Mdot
.64143 .79268 Mdot
.42694 .55359 Mdot
.29801 .13043 Mdot
.27205 .6278 Mdot
.81124 .96977 Mdot
.52696 .54501 Mdot
.60754 .4068 Mdot
.47034 .06359 Mdot
.53289 .77946 Mdot
.07659 .08685 Mdot
.70087 .61289 Mdot
.21806 .9994 Mdot
.26244 .55714 Mdot
.01974 .57822 Mdot
.6666 .55371 Mdot
.8082 .84199 Mdot
.96684 .42104 Mdot
.09286 .05031 Mdot
.60088 .23677 Mdot
.39083 .44502 Mdot
.89379 .63826 Mdot
.72819 .34656 Mdot
.09891 .78108 Mdot
.33255 .20216 Mdot
.30878 .2949 Mdot
.81975 .86937 Mdot
.49669 .9994 Mdot
.86401 .95661 Mdot
.66823 .08279 Mdot
.98835 .38872 Mdot
.53331 .36225 Mdot
.28923 .32059 Mdot
.83048 .8343 Mdot
.49113 .58659 Mdot
.47744 .87569 Mdot
.29163 .32483 Mdot
.74296 .37338 Mdot
.34899 .62477 Mdot
.25139 .50514 Mdot
.7194 .72229 Mdot
.62237 .52083 Mdot
.53589 .7127 Mdot
.73611 .03307 Mdot
.80621 .35466 Mdot
.82127 .21189 Mdot
.92551 .72902 Mdot
.55626 .97416 Mdot
.82713 .56584 Mdot
.28437 .74637 Mdot
.93286 .54992 Mdot
.03493 .84016 Mdot
.9386 .25717 Mdot
.10173 .34818 Mdot
.45706 .76811 Mdot
.11592 .1629 Mdot
.04638 .30337 Mdot
.07681 .76939 Mdot
.8318 .6789 Mdot
.00733 .41121 Mdot
.66387 .17137 Mdot
.56259 .73145 Mdot
.38584 .16291 Mdot
.47704 .61517 Mdot
.88223 .4462 Mdot
.83345 .76318 Mdot
.63476 .51222 Mdot
.42201 .63337 Mdot
.81309 .7327 Mdot
.09778 .60581 Mdot
.39815 .63666 Mdot
.09521 .11946 Mdot
.76898 .77411 Mdot
.84612 .788 Mdot
.12803 .71741 Mdot
.51902 .67599 Mdot
.43686 .24661 Mdot
.02194 .33514 Mdot
.57469 .90535 Mdot
.36856 .5167 Mdot
.64131 .09379 Mdot
.11728 .65506 Mdot
.75691 .34453 Mdot
.68038 .85343 Mdot
.42552 .31204 Mdot
.60839 .07858 Mdot
.4702 .52254 Mdot
.55028 .02873 Mdot
.75737 .24602 Mdot
.59927 .70974 Mdot
.28266 .64204 Mdot
.30307 .59739 Mdot
.78297 .99469 Mdot
.82087 .55795 Mdot
.81899 .9876 Mdot
.08947 .06031 Mdot
.58038 .43239 Mdot
.65089 .39571 Mdot
.97435 .35431 Mdot
.20686 .06807 Mdot
.68856 .97919 Mdot
.68322 .52493 Mdot
.22293 .84877 Mdot
.90688 .78718 Mdot
.55251 .49866 Mdot
.92604 .31664 Mdot
.78709 .09764 Mdot
.68495 .64501 Mdot
.69443 .46298 Mdot
.31302 .90628 Mdot
.59926 .78479 Mdot
.60543 .16716 Mdot
.6287 .34949 Mdot
.57397 .63677 Mdot
.68091 .18022 Mdot
.97216 .4051 Mdot
.4968 .36748 Mdot
.44951 .10927 Mdot
.6595 .43557 Mdot
.34896 .41225 Mdot
.91572 .07549 Mdot
.90122 .64081 Mdot
.85404 .26114 Mdot
.45127 .23074 Mdot
.11313 .68656 Mdot
.59869 .29236 Mdot
.76722 .48281 Mdot
.78937 .72949 Mdot
.40529 .2994 Mdot
.01701 .19107 Mdot
.44728 .40241 Mdot
.21206 .40645 Mdot
.64876 .24631 Mdot
.09781 .66148 Mdot
.581 .42437 Mdot
.51311 .5838 Mdot
.67087 .66415 Mdot
.71931 .99838 Mdot
.05931 .28707 Mdot
.22097 .14997 Mdot
.18806 .36888 Mdot
.89878 .01882 Mdot
.29292 .24598 Mdot
.15376 .51141 Mdot
.83776 .62184 Mdot
.53748 .8362 Mdot
.53922 .58513 Mdot
.94458 .55813 Mdot
.95174 .58611 Mdot
.29385 .48526 Mdot
.33882 .05597 Mdot
.74244 .45206 Mdot
.27431 .4574 Mdot
.04259 .52967 Mdot
.4291 .12135 Mdot
.13185 .66813 Mdot
.24376 .38563 Mdot
.84304 .06539 Mdot
.979 .417 Mdot
.69597 .60605 Mdot
.6147 .13578 Mdot
.21991 .29655 Mdot
.31976 .74337 Mdot
.84404 .58883 Mdot
.1314 .78494 Mdot
.78557 .85465 Mdot
.43059 .14608 Mdot
.14889 .73169 Mdot
.53219 .57209 Mdot
.85979 .34949 Mdot
.21901 .28945 Mdot
.24481 .72008 Mdot
.45926 .04807 Mdot
.84665 .28774 Mdot
.61738 .57191 Mdot
.10143 .96299 Mdot
.97527 .5243 Mdot
.73374 .76576 Mdot
.29132 .29846 Mdot
.22603 .1589 Mdot
.68933 .21616 Mdot
.35699 .25119 Mdot
.40027 .16367 Mdot
.50517 .60069 Mdot
.71885 .08717 Mdot
.27117 .66627 Mdot
.15333 .21834 Mdot
.20221 .12536 Mdot
.15931 .6232 Mdot
.28829 .01421 Mdot
.76123 .5428 Mdot
.30763 .23772 Mdot
.12988 .76966 Mdot
.65859 .78342 Mdot
.11348 .53905 Mdot
.522 .23127 Mdot
.99945 .20822 Mdot
.41803 .85468 Mdot
.88738 .71501 Mdot
.46632 .30399 Mdot
.8217 .24812 Mdot
.26595 .10151 Mdot
.14266 .49861 Mdot
.61055 .34905 Mdot
.4654 .56634 Mdot
.05436 .58733 Mdot
.83883 .32894 Mdot
.95752 .55521 Mdot
.75723 .6382 Mdot
.78346 .8823 Mdot
.59499 .5705 Mdot
.21815 .13439 Mdot
.85782 .92319 Mdot
.26907 .84422 Mdot
.88278 .86306 Mdot
.2882 .76643 Mdot
.79581 .64699 Mdot
.24944 .91656 Mdot
.02888 .27926 Mdot
.53093 .28499 Mdot
.31959 .43615 Mdot
.68899 .60199 Mdot
.9217 .83898 Mdot
.03936 .03984 Mdot
.51377 .06395 Mdot
.98651 .59203 Mdot
.77313 .18368 Mdot
.84834 .45217 Mdot
.42633 .83527 Mdot
.95325 .55578 Mdot
.52892 .41555 Mdot
.32111 .30222 Mdot
.7064 .50792 Mdot
.85873 .82374 Mdot
.85479 .23745 Mdot
.87145 .4365 Mdot
.40171 .04234 Mdot
.3154 .29575 Mdot
.98703 .24716 Mdot
.29766 .18801 Mdot
.27457 .14102 Mdot
.65494 .03434 Mdot
.87307 .20825 Mdot
.36673 .54278 Mdot
.13123 .23686 Mdot
.93393 .59091 Mdot
.5249 .40286 Mdot
.69671 .53227 Mdot
.97703 .08221 Mdot
.9355 .13263 Mdot
.18403 .80631 Mdot
.19106 .01204 Mdot
.34571 .21489 Mdot
.52112 .04562 Mdot
.96855 .74905 Mdot
.29545 .52432 Mdot
.71071 .11224 Mdot
.62254 .17301 Mdot
.08429 .09083 Mdot
.20368 .54129 Mdot
.01291 .9657 Mdot
.49301 .98152 Mdot
.94733 .02806 Mdot
.59622 .29033 Mdot
.39746 .9282 Mdot
.711 .9655 Mdot
.94942 .24093 Mdot
.03731 .03456 Mdot
.35519 .31214 Mdot
.46964 .34444 Mdot
.24031 .4162 Mdot
.71248 .39545 Mdot
.31411 .13877 Mdot
.00078 .33491 Mdot
.858 .10079 Mdot
.44556 .97776 Mdot
.86711 .81978 Mdot
.39689 .34755 Mdot
.88191 .51676 Mdot
.68853 .42877 Mdot
.09052 .34054 Mdot
.46948 .05913 Mdot
.91618 .80479 Mdot
.55845 .85758 Mdot
.6945 .23601 Mdot
.13 .46874 Mdot
.85315 .34586 Mdot
.90229 .33398 Mdot
.85534 .40619 Mdot
.30126 .61455 Mdot
.30047 .08503 Mdot
.90809 .24125 Mdot
.4043 .35973 Mdot
.45714 .47423 Mdot
.73439 .13036 Mdot
.27467 .18819 Mdot
.358 .47266 Mdot
.14142 .9491 Mdot
.57603 .80146 Mdot
.77953 .66524 Mdot
.72941 .70543 Mdot
.91549 .92163 Mdot
.80645 .74913 Mdot
.14369 .81657 Mdot
.80978 .99482 Mdot
.7012 .49711 Mdot
.27988 .90355 Mdot
.2209 .90557 Mdot
.0973 .16639 Mdot
.55203 .23125 Mdot
.49218 .34694 Mdot
.84717 .62914 Mdot
.79389 .36416 Mdot
.1737 .57432 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`;o00001?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool2o`0000Ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;o
oooo000Nooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`07ooooo`;o00001?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool00_ooool2o`0000Wooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool01?l0003ooooo
ooooooooool3o`0000Wooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000oooooooo
ool03_ooool2o`0000kooooo00?o0000ooooooooool03Oooool3o`0000gooooo00?o0000oooooooo
ool01?ooool2o`0000Sooooo00?o0000ooooooooool00_ooool001kooooo00?o0000ooooooooool0
3?ooool2o`0007Kooooo0_l0001>ooooo`?o00004?ooool2o`0001Sooooo0_l0000Iooooo`;o0000
1?ooool2o`0001Cooooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o0000;?oo
ool2o`0006gooooo0_l00018ooooo`;o00009oooool2o`0002Wooooo000Nooooo`03o`000?oooooo
oooo01cooooo0_l0000Looooo`;o00007_ooool2o`0002kooooo0_l0000?ooooo`;o00003?ooool2
o`0004Sooooo0_l0001Booooo`007_ooool00ol0003oooooooooo`0Looooo`;o00005oooool2o`00
01[ooooo0_l00007ooooo`;o0000;_ooool2o`0000oooooo0_l0000_ooooo`;o0000D_ooool2o`00
02Gooooo000Nooooo`03o`000?oooooooooo03Gooooo0_l0000Jooooo`;o0000NOooool2o`0005;o
oooo0_l0000Uooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o00004?ooool2o`000?oooooo
:?ooool001kooooo00?o0000ooooooooool03?ooool2o`00013ooooo0_l0002?ooooo`;o0000Oooo
ool2o`0001Gooooo000Nooooo`03o`000?oooooooooo02Wooooo0_l0001Pooooo`;o00008_ooool2
o`0007oooooo0_l0000Eooooo`007_ooool00ol0003oooooooooo`08ooooo`;o00007oooool2o`00
04Wooooo0_l0000Eooooo`;o0000A?ooool2o`0001Sooooo1?l00007ooooo`;o0000?oooool2o`00
00kooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0000Booooo`;o0000E_ooool2o`0005_o
oooo0_l0000Hooooo`Co00001oooool2o`0003oooooo0_l0000>ooooo`007_ooool00ol0003ooooo
ooooo`09ooooo`;o00004Oooool2o`0003Wooooo0_l0002Vooooo`;o0000:Oooool2o`0001_ooooo
000Nooooo`03o`000?oooooooooo00Wooooo0_l0001<ooooo`;o00009Oooool2o`0007oooooo0_l0
000Yooooo`;o00006oooool001kooooo00?o0000ooooooooool0Loooool2o`0000Wooooo0_l0000C
ooooo`;o00004?ooool2o`000:3ooooo000Nooooo`03o`000?oooooooooo01[ooooo0_l0001Goooo
o`;o00007?ooool4o`00013ooooo0_l0001Looooo`;o0000@_ooool001kooooo0_l0000Kooooo`;o
0000Joooool2o`0000Sooooo0_l0001`ooooo`;o000000?oooooo`000?l00000?oooool001kooooo
00?o0000ooooooooool0J_ooool2o`0001_ooooo0_l0001mooooo`;o0000=Oooool2o`0000Sooooo
000Nooooo`03o`000?oooooooooo06[ooooo0_l0000Yooooo`;o00008oooool2o`00087ooooo0_l0
0008ooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o0000N_ooool2o`0002?ooooo0_l0000T
ooooo`;o0000IOooool001kooooo00?o0000ooooooooool06Oooool2o`0007[ooooo0_l0000<oooo
o`;o00001_ooool2o`0001[ooooo0_l0000Gooooo`;o0000;?ooool2o`0002Wooooo0_l0000<oooo
o`007_ooool00ol0003oooooooooo`0oooooo`;o0000E?ooool2o`0000cooooo0_l00006ooooo`;o
00006_ooool2o`0004Gooooo0_l0000<ooooo`;o00006oooool2o`0000cooooo000Nooooo`03o`00
0?oooooooooo01cooooo0_l0000Qooooo`;o0000^Oooool2o`00023ooooo0_l0000Yooooo`007_oo
ool00ol0003oooooooooo`0Aooooo`;o00002Oooool2o`000=cooooo0_l0001;ooooo`007_ooool0
0ol0003oooooooooo`0Aooooo`;o0000A?ooool2o`0000Cooooo0_l00009ooooo`;o0000>?ooool2
o`0008;ooooo0_l0000Cooooo`;o00002_ooool001kooooo00?o0000ooooooooool0Eoooool2o`00
00Cooooo0_l00009ooooo`;o0000>?ooool2o`0001kooooo0_l0000Looooo`;o0000=_ooool2o`00
0003ooooool0003o000000Wooooo0_l0000Cooooo`;o00002_ooool001kooooo00?o0000oooooooo
ool0`_ooool2o`00017ooooo0_l00009ooooo`;o0000=_ooool2o`000003ooooool0003o000001go
oooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o0000Aoooool2o`0003kooooo
1?l0000cooooo`;o00003oooool2o`0005;ooooo0_l0000;ooooo`007_ooool00ol0003ooooooooo
o`0Eooooo`;o0000Aoooool2o`0003?ooooo0_l00009ooooo`Co0000A?ooool2o`0005oooooo000N
ooooo`03o`000?oooooooooo01Oooooo0_l0000Zooooo`;o00003?ooool2o`00043ooooo0_l00015
ooooo`;o0000Joooool001kooooo00?o0000ooooooooool05oooool2o`0002[ooooo0_l0000<oooo
o`;o0000<Oooool2o`00013ooooo0_l00006ooooo`;o0000;?ooool2o`0000cooooo0_l0001[oooo
o`007_ooool00ol0003oooooooooo`11ooooo`;o0000@Oooool2o`0000Cooooo0_l0000:ooooo`;o
00001_ooool2o`0000_ooooo0_l0000Oooooo`;o0000;_ooool2o`0004Wooooo000Nooooo`;o0000
4_ooool2o`0002kooooo0_l0000?ooooo`;o00004?ooool2o`0002Cooooo0_l0000Oooooo`;o0000
3oooool2o`0003kooooo0_l0000Eooooo`;o0000<_ooool001kooooo00?o0000ooooooooool04Ooo
ool2o`0003oooooo0_l0000=ooooo`;o000000?oooooo`000?l00000E_ooool2o`0001cooooo0_l0
000gooooo`;o0000<_ooool001kooooo00?o0000ooooooooool0;Oooool2o`0003;ooooo0_l00017
ooooo`;o0000;_ooool2o`0003Oooooo0_l0000booooo`007_ooool00ol0003oooooooooo`0]oooo
o`;o0000Goooool2o`0001[ooooo0_l0001Wooooo`;o0000<_ooool001kooooo00?o0000oooooooo
ool0Boooool2o`00013ooooo0_l0000_ooooo`;o0000@?ooool2o`0000Wooooo0_l00006ooooo`;o
0000@Oooool2o`0001oooooo000Nooooo`03o`000?oooooooooo02?ooooo0_l0000Vooooo`;o0000
4?ooool2o`0002?ooooo0_l0001<ooooo`;o00002Oooool2o`0000Kooooo0_l00011ooooo`;o0000
7oooool001kooooo00?o0000ooooooooool06oooool2o`0000Kooooo0_l00017ooooo`;o00003Ooo
ool2o`0000Gooooo0_l00003ooooo`;o0000UOooool2o`0002Oooooo000Nooooo`03o`000?oooooo
oooo01_ooooo0_l0000?ooooo`;o0000?_ooool2o`0000gooooo0_l0000:ooooo`;o0000UOooool2
o`0002Oooooo000Nooooo`03o`000?oooooooooo02cooooo0_l0000@ooooo`;o0000iOooool2o`00
023ooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0000eooooo`;o00007Oooool2o`0008co
oooo0_l0000hooooo`;o00008?ooool001kooooo00?o0000ooooooooool01oooool2o`0002_ooooo
0_l0000Qooooo`;o00001?ooool2o`0003Cooooo0_l0001Fooooo`;o0000?oooool2o`0001Wooooo
000Nooooo`03o`000?oooooooooo03Cooooo0_l0000=ooooo`;o00004_ooool2o`0003[ooooo0_l0
000_ooooo`;o0000I_ooool2o`0001Wooooo000Nooooo`03o`000?oooooooooo04?ooooo0_l0000M
ooooo`;o0000H?ooool2o`00087ooooo000Nooooo`03o`000?oooooooooo037ooooo0_l0000Roooo
o`;o00002oooool2o`0005Sooooo0_l0001_ooooo`;o00006?ooool001kooooo00?o0000oooooooo
ool0<Oooool2o`00023ooooo1?l0001Uooooo`;o0000EOooool2o`0001Sooooo0_l0000Hooooo`00
7_ooool00ol0003oooooooooo`0aooooo`;o00008?ooool2o`0003?ooooo0_l0001looooo`;o0000
2oooool2o`0003;ooooo000Nooooo`;o0000AOooool2o`0004;ooooo0_l0001looooo`;o0000?ooo
ool001kooooo00?o0000ooooooooool0;_ooool2o`0001Cooooo0_l0001_ooooo`;o0000T?ooool0
01kooooo00?o0000ooooooooool0;_ooool2o`00033ooooo0_l0000Nooooo`;o0000<oooool2o`00
07Cooooo0_l0000Jooooo`007_ooool00ol0003oooooooooo`15ooooo`;o00006Oooool2o`0001ko
oooo0_l0002;ooooo`;o00007?ooool2o`0001[ooooo000Nooooo`03o`000?oooooooooo02;ooooo
0_l0000Qooooo`;o00000oooool2o`0002gooooo0_l00003ooooo`;o0000FOooool2o`0003;ooooo
0_l0000hooooo`007_ooool00ol0003oooooooooo`0Looooo`;o00001?ooool2o`0002Kooooo0_l0
000]ooooo`;o00000oooool2o`00047ooooo0_l0000Fooooo`;o0000K?ooool001kooooo00?o0000
ooooooooool07?ooool2o`0001?ooooo0_l0000mooooo`;o0000Coooool2o`0008Cooooo000Noooo
o`03o`000?oooooooooo037ooooo0_l0000Gooooo`;o00009?ooool2o`0005Cooooo0_l0000<oooo
o`;o0000G?ooool2o`0001?ooooo000Nooooo`03o`000?oooooooooo04[ooooo0_l0001jooooo`;o
00003?ooool2o`0005cooooo0_l0000Cooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0=Wooooo0_l0000aooooo`;o0000>Oooool001kooooo00?o0000
ooooooooool0<Oooool2o`000:Kooooo0_l0000Looooo`;o00004oooool2o`0003Wooooo000Noooo
o`03o`000?oooooooooo037ooooo0_l0000Oooooo`;o000000?oooooo`000?l000001_ooool2o`00
03Oooooo0_l0000Pooooo`;o0000:?ooool2o`0001?ooooo0_l0001>ooooo`007_ooool01?l0003o
ooooooooooooool2o`0004oooooo0_l000000ooooooo0000o`000006ooooo`;o0000=oooool2o`00
023ooooo0_l00007ooooo`;o00007oooool2o`0006?ooooo0003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`04o`000?ooooooooooooooo`;o0000F_ooool2
o`0004;ooooo0_l0000Nooooo`;o0000Loooool2o`0000oooooo0003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oo
oooooooo05_ooooo0_l00014ooooo`;o0000Q?ooool2o`0000gooooo0_l0000?ooooo`000oooool0
1Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool3o`0000;ooooo0_l0
001Gooooo`;o00008_ooool2o`0003_ooooo0_l0001Yooooo`;o00007_ooool000?ooooo00Go0000
ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00Go0000ooooool0003o0000
ooooo`02o`0006Cooooo0_l0000Eooooo`;o0000<oooool2o`0000Kooooo0_l0001Kooooo`;o0000
;?ooool000?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo
00Co0000ooooool0003o0000Ioooool4o`0004Sooooo0_l0001Sooooo`;o00000_ooool2o`0002So
oooo0003ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo05kooooo0_l0000:ooooo`;o00008oooool2o`0006?ooooo0_l0000Rooooo`;o
00000oooool2o`0002;ooooo0_l00004ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo05kooooo0_l0000_oooo
o`;o0000>?ooool2o`0002Wooooo0_l0000Aooooo`;o00003oooool2o`0002Oooooo0_l00004oooo
o`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006
ooooo`03o`000?oooooooooo00Sooooo0_l0001Hooooo`;o00002?ooool2o`0005_ooooo0_l00007
ooooo`;o00002?ooool2o`0002Wooooo0_l0000nooooo`007_ooool00ol0003oooooooooo`08oooo
o`;o00009?ooool2o`0000?ooooo0_l00008ooooo`;o00008oooool2o`0000Sooooo0_l0001Toooo
o`;o00001oooool3o`0006Wooooo000Nooooo`03o`000?oooooooooo02kooooo0_l00003ooooo`;o
00002?ooool2o`0009cooooo0_l00003ooooo`;o0000IOooool001kooooo00?o0000ooooooooool0
[?ooool2o`0003;ooooo0_l0000]ooooo`;o0000=_ooool001kooooo00?o0000ooooooooool09?oo
ool2o`0008Kooooo0_l0000eooooo`;o0000:_ooool2o`0003Kooooo000Nooooo`03o`000?oooooo
oooo02Cooooo0_l0001Yooooo`;o00005Oooool2o`0000Oooooo0_l0000Oooooo`;o00004Oooool2
o`0006;ooooo000Nooooo`03o`000?oooooooooo03;ooooo0_l0001Kooooo`;o00005Oooool2o`00
00Oooooo0_l0000Oooooo`;o0000>Oooool2o`0003[ooooo000Nooooo`03o`000?oooooooooo02Oo
oooo0_l00009ooooo`;o00009oooool2o`0000?ooooo0_l0000Zooooo`;o00002_ooool2o`0002Go
oooo0_l0000Mooooo`;o0000:oooool2o`0000Gooooo0_l0000cooooo`007_ooool00ol0003ooooo
ooooo`0Wooooo`;o0000<_ooool2o`0000?ooooo0_l0000Zooooo`;o00002_ooool2o`0001[ooooo
0_l00009ooooo`;o00007Oooool2o`0003;ooooo0_l0000?ooooo`;o00000oooool2o`0000Oooooo
0_l00004ooooo`;o00003_ooool001kooooo00?o0000ooooooooool01Oooool2o`0002Wooooo0_l0
0022ooooo`;o0000KOooool2o`0000?ooooo0_l00007ooooo`;o00001?ooool2o`0000kooooo000N
ooooo`03o`000?oooooooooo00Gooooo0_l0000Tooooo`;o00000oooool2o`0002Wooooo0_l0000D
ooooo`;o00005oooool2o`0004?ooooo0_l0000Qooooo`;o0000BOooool2o`0000Sooooo000Noooo
o`04o`000?oooooo0000o`0002[ooooo0_l0000^ooooo`;o00005?ooool2o`0001Oooooo0_l00013
ooooo`;o00005_ooool2o`0000Wooooo0_l0000Cooooo`;o0000=?ooool2o`0000Sooooo000Noooo
o`Co0000Koooool2o`0001cooooo0_l0001Gooooo`;o00007_ooool2o`0003kooooo000Nooooo`03
o`000?oooooooooo073ooooo0_l0000Looooo`;o0000]oooool001kooooo0_l0001mooooo`;o0000
[oooool2o`0001Sooooo000Nooooo`;o0000OOooool2o`0004kooooo0_l00014ooooo`;o00006Ooo
ool2o`0001Sooooo000Nooooo`03o`000?oooooooooo053ooooo0_l00010ooooo`;o0000>?ooool2
o`0000kooooo0_l0000Cooooo`;o00007oooool2o`0003?ooooo000Nooooo`03o`000?oooooooooo
053ooooo0_l00010ooooo`;o00002_ooool2o`0001Kooooo0_l0000Tooooo`;o00004oooool2o`00
05Cooooo000Nooooo`03o`000?oooooooooo09kooooo0_l0000Fooooo`;o00003oooool2o`0007ko
oooo000Nooooo`03o`000?oooooooooo0<Kooooo0ol0001nooooo`007_ooool00ol0003ooooooooo
o`0`ooooo`;o00004Oooool2o`00087ooooo0_l0001oooooo`007_ooool00ol0003oooooooooo`05
ooooo`;o00002Oooool2o`0001kooooo0_l0000Aooooo`;o0000<?ooool2o`0002kooooo0_l00016
ooooo`;o0000F?ooool001kooooo00?o0000ooooooooool01Oooool2o`0000Wooooo0_l0000Soooo
o`;o00005oooool2o`0002Gooooo0_l0000[ooooo`;o000000?oooooo`000?l000001_ooool2o`00
01gooooo0_l0000Oooooo`;o0000?Oooool3o`0001Sooooo000Nooooo`03o`000?oooooooooo00oo
oooo0_l0000Tooooo`;o00005oooool2o`0003Oooooo0_l0000Iooooo`;o00001?ooool2o`0000?o
oooo0_l0000Mooooo`;o00005oooool2o`0004Gooooo0ol0000:ooooo`;o00003?ooool001kooooo
00?o0000ooooooooool03oooool2o`0003;ooooo0_l00012ooooo`;o00007oooool2o`0001Cooooo
0_l0000Uooooo`;o0000:?ooool2o`0002Sooooo0_l0000<ooooo`007_ooool00ol0003ooooooooo
o`13ooooo`;o0000NOooool3o`0001gooooo0_l0000_ooooo`;o0000:?ooool2o`0000Gooooo0_l0
0005ooooo`007_ooool00ol0003oooooooooo`13ooooo`;o00006oooool4o`0000Oooooo0_l0001B
ooooo`;o00007Oooool2o`00063ooooo0_l00005ooooo`007_ooool00ol0003oooooooooo`13oooo
o`;o00005_ooool2o`0000?ooooo1?l00007ooooo`;o00004oooool2o`0005;ooooo0_l0001aoooo
o`007_ooool2o`0000Wooooo0_l00019ooooo`;o00001_ooool2o`0000Oooooo0_l0000Jooooo`;o
0000D_ooool2o`00077ooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l000000ooooooo0000
o`000016ooooo`;o00003oooool2o`0002gooooo0_l00010ooooo`;o0000J?ooool2o`0000Kooooo
000Nooooo`03o`000?oooooooooo00_ooooo0_l00026ooooo`;o0000@?ooool2o`0004?ooooo0_l0
000Sooooo`;o00001_ooool001kooooo00?o0000ooooooooool0Q_ooool2o`0008;ooooo0_l0000>
ooooo`;o0000:oooool001kooooo00?o0000ooooooooool0;?ooool2o`0000Kooooo0_l0000ioooo
o`;o00005Oooool2o`0002cooooo0_l0000[ooooo`;o00006_ooool2o`0000_ooooo0_l0000koooo
o`007_ooool00ol0003oooooooooo`06ooooo`;o00009?ooool2o`0000;ooooo0_l00002ooooo`;o
0000>Oooool2o`00033ooooo0_l0000Aooooo`;o00006Oooool2o`00013ooooo0_l0000Jooooo`;o
0000:_ooool2o`0001cooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l0000Xooooo`;o0000
:?ooool2o`0002Sooooo0_l0000Kooooo`;o0000;?ooool2o`0005Sooooo0_l0000Looooo`007_oo
ool00ol0003oooooooooo`1Jooooo`;o0000:?ooool2o`000<7ooooo000Nooooo`03o`000?oooooo
oooo00gooooo0_l00011ooooo`;o00002Oooool2o`0008Sooooo0_l0001Pooooo`007_ooool00ol0
003oooooooooo`0=ooooo`;o0000@Oooool2o`0000Wooooo0_l0000Sooooo`;o0000AOooool2o`00
01cooooo0_l0000Pooooo`;o00001?ooool2o`0003Sooooo000Nooooo`03o`000?oooooooooo083o
oooo0_l00015ooooo`;o0000?_ooool2o`0000Cooooo0_l0000hooooo`007Oooool2o`0000Gooooo
0_l0000Xooooo`;o0000l_ooool2o`0002Cooooo000Mooooo`;o00001Oooool2o`0002Sooooo0_l0
0026ooooo`;o0000J_ooool2o`0002Cooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l0002J
ooooo`Co0000S_ooool001kooooo00?o0000ooooooooool06Oooool2o`0000oooooo0_l0001Yoooo
o`;o00008?ooool2o`0003Wooooo0_l0000Mooooo`;o00003Oooool2o`0000kooooo0_l0000Eoooo
o`007_ooool00ol0003oooooooooo`0Mooooo`;o00002oooool2o`0002Wooooo0_l0000Vooooo`;o
00005_ooool2o`0000Gooooo0ol00004ooooo`;o00008?ooool2o`0002;ooooo0_l00007ooooo`;o
00007Oooool2o`0000gooooo0_l0000>ooooo`;o00005Oooool001kooooo0_l0000Nooooo`;o0000
3?ooool2o`0001Cooooo0_l0000Booooo`;o00002_ooool2o`0001[ooooo0_l0000Mooooo`?o0000
1?ooool2o`0000Oooooo0_l0000Dooooo`;o000000Coooooo`000?l0003ooooo0_l0000Oooooo`;o
0000:?ooool2o`0003;ooooo000Nooooo`03o`000?oooooooooo02_ooooo0_l0000Dooooo`;o0000
7_ooool2o`0004Wooooo0_l0000Dooooo`;o00001?ooool2o`0003Sooooo0_l0000?ooooo`;o0000
9?ooool2o`0000cooooo000Nooooo`03o`000?oooooooooo043ooooo0_l0001Jooooo`;o00007?oo
ool2o`0002[ooooo0_l0000Jooooo`;o0000=Oooool2o`0000cooooo000Nooooo`03o`000?oooooo
oooo00_ooooo0_l0000cooooo`;o0000?Oooool2o`0001_ooooo0_l0000Looooo`;o0000:_ooool2
o`0000;ooooo0_l0000Hooooo`;o0000@Oooool001kooooo00?o0000ooooooooool02?ooool2o`00
0003ooooool0003o000007;ooooo0_l0000Xooooo`;o00000_ooool2o`0003_ooooo0_l000000ooo
oooo0000o`00000?ooooo`;o00001?ooool2o`0000oooooo0_l0000Nooooo`;o00004?ooool001ko
oooo00?o0000ooooooooool02?ooool2o`0009oooooo0_l00002ooooo`;o0000?_ooool2o`0000oo
oooo0_l0000Eooooo`;o00006?ooool2o`0000Cooooo0_l0000@ooooo`007_ooool00ol0003ooooo
ooooo`0iooooo`;o0000H_ooool2o`0001Oooooo0_l0001gooooo`;o00003_ooool2o`0000Kooooo
000Nooooo`03o`000?oooooooooo02gooooo0_l0000:ooooo`;o0000H_ooool2o`0001Oooooo0_l0
000>ooooo`;o00006oooool2o`0000Sooooo0_l0001@ooooo`;o00001_ooool001kooooo00?o0000
ooooooooool0;Oooool2o`0000;ooooo0_l0002Cooooo`;o00006oooool2o`0000Sooooo0_l0001H
ooooo`007_ooool00ol0003oooooooooo`0aooooo`;o00009?ooool2o`000=Cooooo0_l0000Hoooo
o`007_ooool00ol0003oooooooooo`1Gooooo`;o0000Doooool2o`0005Oooooo0_l0000:ooooo`;o
00006_ooool2o`0001Sooooo000Nooooo`03o`000?oooooooooo04_ooooo0_l0000Kooooo`;o0000
3oooool2o`00037ooooo0_l0001Gooooo`;o00002_ooool2o`0003Cooooo000Nooooo`03o`000?oo
oooooooo04_ooooo0_l0000@ooooo`;o00002Oooool2o`0000Oooooo0_l00006ooooo`;o0000>ooo
ool2o`0006oooooo0_l0000Dooooo`;o00002?ooool001kooooo00?o0000ooooooooool0GOooool2
o`0001;ooooo0_l00013ooooo`;o00002?ooool2o`0004oooooo0_l0000Dooooo`;o00005?ooool2
o`0000Sooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l00000
0ol@413oooooooooo`04ooooo`?o0000MOooool2o`0004Wooooo0_l0001?ooooo`;o00003oooool2
o`0002?ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool01Oooool3o`0000Gooooo0_l0001^ooooo`;o00009oooool2o`0002oooooo0_l0000C
ooooo`;o00001oooool2o`0003?ooooo0_l0000Sooooo`000oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol00006ooooo`?o00001Oooool2o`0003Cooooo0_l0001Qooooo`;o0000;oooool2
o`0001?ooooo0_l00007ooooo`;o0000C_ooool2o`0000Sooooo0003ooooo`05o`000?oooooooooo
ooooool000002oooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo01gooooo0_l0
000Looooo`;o0000<Oooool2o`0001;ooooo0_l00007ooooo`Co00006?ooool2o`0000gooooo0_l0
001@ooooo`;o0000<oooool2o`0000Sooooo0003ooooo`05o`000?ooooooooooooooool000002ooo
ool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo00Gooooo0_l0000Fooooo`;o0000
8_ooool2o`0002_ooooo0_l00002ooooo`;o00003_ooool2o`0000Oooooo1?l00004ooooo`;o0000
4_ooool2o`0000gooooo0_l00009ooooo`;o0000AOooool2o`0000Sooooo0_l0000Tooooo`;o0000
3Oooool000?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo
00?o0000ooooooooool01Oooool2o`0000Wooooo0_l0000_ooooo`;o00008_ooool2o`0000_ooooo
0_l0000Oooooo`;o0000;?ooool2o`000003ooooool0003o000004cooooo0_l0000Tooooo`;o0000
3Oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo
0ol0000@ooooo`;o0000Doooool2o`0000Kooooo0_l0001Eooooo`;o0000:?ooool2o`0001kooooo
0_l0000Eooooo`;o00008?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMg
Mol0003ooooo00Kooooo0ol0001:ooooo`;o00008Oooool2o`0003Wooooo0_l0000Booooo`;o0000
<?ooool2o`0001kooooo0_l0000Eooooo`;o00008?ooool001kooooo00?o0000ooooooooool05?oo
ool2o`0002Oooooo0_l000000ooooooo0000o`000008ooooo`;o0000>Oooool2o`00027ooooo0_l0
000>ooooo`;o00000_ooool2o`0007cooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`0D
ooooo`;o00009oooool2o`000003ooooool0003o000004?ooooo0_l0000aooooo`;o00004oooool2
o`0000;ooooo0ol0001Rooooo`;o00000_ooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo
0;Wooooo0_l0000Booooo`;o00000_ooool3o`0006;ooooo0_l0000?ooooo`007_ooool00ol0003o
ooooooooo`0[ooooo`;o0000:oooool2o`0005oooooo0_l0000?ooooo`;o00004?ooool2o`0006Wo
oooo000Nooooo`03o`000?oooooooooo02_ooooo0_l0000[ooooo`;o0000L?ooool2o`00013ooooo
0_l0001Yooooo`007_ooool00ol0003oooooooooo`1kooooo`;o0000>?ooool2o`0000;ooooo0_l0
002<ooooo`007_ooool00ol0003oooooooooo`1Tooooo`;o00005Oooool2o`0003Sooooo0_l00002
ooooo`;o00005oooool2o`0004?ooooo0_l0000^ooooo`007_ooool00ol0003oooooooooo`0Eoooo
o`;o0000COooool2o`0004oooooo0_l0000Kooooo`;o0000@oooool2o`0002kooooo000Nooooo`03
o`000?oooooooooo01Gooooo0_l0002Nooooo`;o0000A?ooool2o`0004[ooooo000Nooooo`03o`00
0?oooooooooo02cooooo0_l00007ooooo`;o00009oooool2o`0001_ooooo0_l0001nooooo`;o0000
0_ooool2o`0001[ooooo0_l0000Zooooo`007_ooool00ol0003oooooooooo`0/ooooo`;o00001ooo
ool2o`0002Oooooo0_l0000Kooooo`;o0000>?ooool2o`0000Sooooo0_l0000Cooooo`;o0000:Ooo
ool2o`0000oooooo0_l00009ooooo`;o0000:_ooool001kooooo0_l0000^ooooo`;o00009Oooool2
o`0005oooooo0_l00008ooooo`;o00004oooool2o`0001Oooooo0_l00007ooooo`;o00006?ooool2
o`0003Gooooo000Nooooo`03o`000?oooooooooo02gooooo0_l0000Uooooo`;o0000>_ooool2o`00
05_ooooo0_l00007ooooo`;o00006?ooool2o`0003Gooooo000Nooooo`03o`000?oooooooooo05Go
oooo0_l0000iooooo`;o0000?_ooool2o`0007Gooooo000Nooooo`03o`000?oooooooooo05Gooooo
0_l00009ooooo`;o00002_ooool2o`0006;ooooo0_l00007ooooo`;o0000K?ooool001kooooo00?o
0000ooooooooool0<oooool2o`0000Wooooo0_l00007ooooo`;o00001?ooool2o`00017ooooo0_l0
000:ooooo`;o0000Joooool2o`0000?ooooo0_l00004ooooo`;o0000>Oooool2o`0002Kooooo000N
ooooo`03o`000?oooooooooo01Sooooo0_l0000<ooooo`;o00002oooool2o`0000Wooooo0_l00007
ooooo`;o00001?ooool2o`0008oooooo0_l00004ooooo`;o0000>Oooool2o`0001Cooooo0_l0000@
ooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o00003?ooool2o`0002Gooooo0_l0002`oooo
o`;o0000<?ooool2o`0000;ooooo0_l0000@ooooo`007_ooool00ol0003oooooooooo`1=ooooo`;o
00008Oooool2o`0001oooooo0_l0000aooooo`;o0000>Oooool2o`00033ooooo0_l0000Dooooo`00
7_ooool00ol0003oooooooooo`13ooooo`;o0000:oooool2o`0001oooooo0_l0000aooooo`;o0000
4?ooool2o`0006oooooo000Nooooo`03o`000?oooooooooo04?ooooo0_l0001fooooo`;o00006Ooo
ool2o`0006oooooo000Nooooo`03o`000?oooooooooo0;_ooooo0_l0000hooooo`;o0000D?ooool0
01kooooo00?o0000ooooooooool0Foooool2o`0009Sooooo0_l0000<ooooo`;o0000@_ooool001ko
oooo00?o0000ooooooooool0?Oooool2o`0001cooooo0_l0001Zooooo`;o0000>_ooool2o`0000So
oooo0_l0000hooooo`007_ooool00ol0003oooooooooo`0mooooo`;o00005?ooool2o`0002Sooooo
0_l00018ooooo`;o0000;oooool2o`0001?ooooo0_l0000hooooo`007_ooool00ol0003ooooooooo
o`1Cooooo`;o00007?ooool2o`0000[ooooo0_l0000Pooooo`;o0000Eoooool2o`0004gooooo000N
ooooo`03o`000?oooooooooo02?ooooo0_l00005ooooo`;o0000AOooool2o`0000Cooooo0_l0000V
ooooo`;o00003oooool2o`0002kooooo0_l0001Uooooo`007_ooool2o`0002Cooooo0_l00005oooo
o`;o0000Boooool2o`0003Oooooo0_l0000^ooooo`Co0000Hoooool001kooooo00?o0000oooooooo
ool0C_ooool2o`0000Kooooo0_l0000Looooo`;o0000K?ooool2o`0003Kooooo0_l0000[ooooo`00
7_ooool00ol0003oooooooooo`1>ooooo`;o00001_ooool2o`0001cooooo0_l0001/ooooo`;o0000
=_ooool2o`0000Kooooo0_l0000Sooooo`007_ooool00ol0003oooooooooo`0^ooooo`;o0000;_oo
ool2o`0001[ooooo0_l0000Pooooo`;o00007_ooool2o`0002Cooooo0_l0000nooooo`;o00008ooo
ool001kooooo00?o0000ooooooooool05_ooool2o`0001Kooooo0_l0000^ooooo`;o00006_ooool2
o`00023ooooo0_l0000Nooooo`;o00003?ooool2o`0004Kooooo0_l0000cooooo`007_ooool00ol0
003oooooooooo`0Fooooo`;o00004Oooool2o`0003Oooooo0_l0000@ooooo`;o0000<oooool2o`00
01oooooo0_l0000Oooooo`;o00002_ooool2o`0001Wooooo0_l00007ooooo`;o0000:_ooool001ko
oooo00?o0000ooooooooool08oooool2o`0000?ooooo0ol000000ooooooo0000o`00000dooooo`;o
00004?ooool2o`0003?ooooo0_l0000Kooooo`;o00008oooool2o`0000[ooooo0_l0000Rooooo`;o
0000:_ooool001kooooo00?o0000ooooooooool08oooool2o`0000?ooooo0_l00002ooooo`;o0000
;_ooool2o`0000Wooooo0_l0000Dooooo`;o00005_ooool2o`0002oooooo0_l0000Vooooo`;o0000
BOooool2o`0000cooooo000Nooooo`03o`000?oooooooooo05cooooo0_l00009ooooo`;o00005?oo
ool2o`0001Kooooo0_l00013ooooo`;o00004_ooool2o`0003?ooooo0_l0000Dooooo`;o00003?oo
ool001kooooo0ol0000:ooooo`;o0000Toooool2o`0003Wooooo0_l00017ooooo`;o00008_ooool0
01kooooo0ol0000:ooooo`;o0000Toooool2o`0003gooooo0_l0000gooooo`;o0000;_ooool001ko
oooo00?o0000ooooooooool0X?ooool2o`0003cooooo0_l0000gooooo`;o0000;_ooool001kooooo
00?o0000ooooooooool08Oooool2o`0000Oooooo0_l0001Pooooo`;o00004_ooool4o`000:?ooooo
000Nooooo`03o`000?oooooooooo027ooooo0_l00007ooooo`;o00003_ooool2o`0000;ooooo0_l0
001<ooooo`;o00005?ooool2o`0000_ooooo0_l0002Fooooo`007_ooool00ol0003oooooooooo`0j
ooooo`;o00000_ooool2o`0003?ooooo0_l0000booooo`;o00001_ooool2o`0004;ooooo0_l0001B
ooooo`007_ooool00ol0003oooooooooo`1cooooo`;o00003Oooool2o`0002?ooooo0_l0000foooo
o`;o00004_ooool2o`0004[ooooo0_l00006ooooo`007_ooool2o`0003Wooooo0_l00018ooooo`;o
0000Foooool2o`0000oooooo0_l0000iooooo`;o00004_ooool2o`0000Kooooo000Nooooo`03o`00
0?oooooooooo03Cooooo0_l00002ooooo`;o0000COooool2o`0004cooooo0_l0000Iooooo`;o0000
3oooool2o`0002Sooooo0_l0000Jooooo`007_ooool00ol0003oooooooooo`0dooooo`;o00006ooo
ool2o`0003Cooooo0_l0001<ooooo`;o0000:_ooool2o`0000Cooooo0_l0000Vooooo`;o000000Co
ooooo`000?l0003o00004_ooool001kooooo00?o0000ooooooooool00oooool2o`0004cooooo0_l0
0027ooooo`;o00005?ooool2o`0001Gooooo0_l0000Vooooo`;o000000Coooooo`000?l0003o0000
4_ooool001kooooo00?o0000ooooooooool00oooool2o`0006Oooooo0_l0001Pooooo`;o00002_oo
ool2o`0001Cooooo0_l0001Eooooo`007_ooool00ol0003oooooooooo`1/ooooo`;o00009Oooool2
o`0000Cooooo0_l0000Jooooo`;o00005oooool2o`0001_ooooo0_l0000Looooo`;o0000??ooool0
01kooooo00?o0000ooooooooool0Toooool2o`0000Cooooo0_l0000Jooooo`;o0000=?ooool2o`00
0003ooooool0003o000001Wooooo0_l0000looooo`007_ooool00ol0003oooooooooo`0`ooooo`;o
0000H?ooool2o`0001Gooooo0_l0000Booooo`;o00001_ooool2o`0000Cooooo0_l0000Qooooo`;o
00005Oooool2o`00043ooooo000Nooooo`03o`000?oooooooooo033ooooo0_l00002ooooo`;o0000
G?ooool2o`0001Gooooo0_l0000Booooo`;o00001_ooool2o`0000Cooooo0_l0000Iooooo`;o0000
7Oooool2o`0001Wooooo0_l0000Uooooo`007_ooool00ol0003oooooooooo`02ooooo`;o0000<?oo
ool2o`0001Cooooo0_l0001mooooo`;o00006oooool2o`0003Sooooo0_l0000Nooooo`;o00001Ooo
ool001kooooo00?o0000ooooooooool00_ooool2o`0000gooooo0_l0000gooooo`;o0000GOooool2
o`0001kooooo0_l0000<ooooo`;o0000Ioooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo
017ooooo0_l0000kooooo`;o0000Doooool2o`0000Cooooo1?l0000Zooooo`;o0000K_ooool001ko
oooo00?o0000ooooooooool03_ooool2o`0002kooooo0_l000000ooooooo0000o`000004ooooo`;o
00001Oooool2o`0001_ooooo0_l0000_ooooo`;o00001Oooool2o`0000Kooooo0_l0000Zooooo`;o
00007Oooool2o`0001Kooooo0_l0000Hooooo`;o00001oooool2o`0001Cooooo000Nooooo`03o`00
0?oooooooooo00kooooo0_l0000^ooooo`;o000000Coooooo`000?l0003o00000oooool2o`0001?o
oooo0_l0000=ooooo`;o0000;oooool2o`0002?ooooo0_l0000Dooooo`;o00007Oooool2o`0001Ko
oooo0_l0000Hooooo`;o00000_ooool2o`0000?ooooo0_l0000Dooooo`000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0
003oooooooooo`12ooooo`;o00001?ooool2o`0001;ooooo0_l0001Sooooo`;o00009Oooool2o`00
03Gooooo0_l0000;ooooo`;o00003oooool2o`0000Sooooo0003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooo
oooo04Sooooo0_l0000Dooooo`;o00006oooool2o`0006_ooooo0_l0000cooooo`Co00007?ooool2
o`0000Sooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooo
oooo000000Kooooo1Ol0000iooooo`;o00008Oooool2o`0001_ooooo0_l0000Sooooo`;o0000Nooo
ool2o`0002Sooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooo
oonHV9So8B4Q00Kooooo00?o0000ooooooooool00_l0000:ooooo`;o0000;Oooool2o`0006?ooooo
0_l00008ooooo`;o0000<?ooool2o`0003gooooo0_l0000Zooooo`000oooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo00co
oooo0_l0000;ooooo`;o000000?oooooo`000?l00000S?ooool2o`00033ooooo1?l0000kooooo`;o
0000:_ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00So
oooo00?o0000ooooooooool06Oooool2o`000003ooooool0003o000003[ooooo0_l00024ooooo`;o
0000Ioooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00So
oooo00?o0000ooooooooool07Oooool2o`0003Wooooo0_l00026ooooo`;o0000COooool2o`0001Ko
oooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106oooo
o`03o`000?oooooooooo01gooooo0_l0000oooooo`;o00004oooool2o`0000[ooooo0_l0000Foooo
o`;o0000Aoooool2o`0002Gooooo0_l0000Vooooo`;o00005_ooool001kooooo00?o0000oooooooo
ool0G_ooool2o`0001?ooooo0_l0000:ooooo`;o00005_ooool2o`0001Cooooo0_l000000ooooooo
0000o`00001Eooooo`;o00009Oooool3o`0001Kooooo000Nooooo`03o`000?oooooooooo0:gooooo
0_l000000ooooooo0000o`00000Dooooo`;o00001Oooool2o`0002Oooooo0_l0000Dooooo`;o0000
6oooool2o`0000?ooooo0ol0000Fooooo`007_ooool00ol0003oooooooooo`0`ooooo`;o00008?oo
ool2o`0001Wooooo0_l0001Gooooo`;o00001Oooool2o`0002Oooooo0_l0000Dooooo`;o00006ooo
ool2o`0001cooooo000Nooooo`03o`000?oooooooooo01_ooooo0_l0000Cooooo`;o00003?ooool2
o`0001;ooooo1?l0000Gooooo`?o0000Eoooool2o`0001?ooooo0_l0000Xooooo`;o0000?oooool0
01kooooo00?o0000ooooooooool06oooool2o`0001Sooooo0_l00007ooooo`;o00005?ooool2o`00
01Sooooo0_l0001Gooooo`;o00004oooool2o`0002Sooooo0_l00007ooooo`;o0000=_ooool001ko
oooo00?o0000ooooooooool0=Oooool2o`0001;ooooo0_l0000Aooooo`;o00007Oooool2o`0000So
oooo0_l0001Tooooo`;o00008?ooool4o`0003Kooooo000Nooooo`03o`000?oooooooooo04Oooooo
1?l0000Aooooo`;o00007Oooool4o`0000Kooooo0_l0000_ooooo`;o00007Oooool2o`0001Cooooo
0_l0000Pooooo`;o0000>?ooool001kooooo00?o0000ooooooooool02?ooool2o`0003gooooo0_l0
000Dooooo`;o00007_ooool2o`0000oooooo0_l0000Vooooo`;o00007Oooool2o`0001_ooooo0_l0
000Zooooo`;o000000?oooooo`000?l000009?ooool001kooooo00?o0000ooooooooool02?ooool2
o`0004kooooo0_l00003ooooo`;o0000;oooool2o`0004_ooooo0_l0000Eooooo`;o0000:_ooool2
o`000003ooooool0003o000002Cooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0001<oooo
o`;o0000POooool2o`0002;ooooo0_l00016ooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o
0000=?ooool2o`0009Wooooo0_l0000Rooooo`;o0000A_ooool001kooooo0_l00011ooooo`;o0000
@Oooool2o`000<;ooooo000Nooooo`03o`000?oooooooooo02;ooooo0_l0001Oooooo`;o0000>Ooo
ool2o`0008Oooooo000Nooooo`03o`000?oooooooooo02;ooooo0_l0000booooo`;o0000I_ooool2
o`0008Oooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l0000Dooooo`;o00005Oooool2o`00
027ooooo0_l0000jooooo`;o0000C_ooool2o`0006?ooooo000Nooooo`04o`000?oooooo0000o`00
00Gooooo0_l00007ooooo`;o00002oooool2o`0001Gooooo0_l0000Uooooo`;o0000=_ooool2o`00
04;ooooo0_l0000:ooooo`;o00003Oooool2o`0000Kooooo0_l0001<ooooo`007_ooool01?l0003o
ooooo`000?l0000>ooooo`;o00005_ooool2o`0002_ooooo0_l00004ooooo`;o0000N_ooool2o`00
00[ooooo0_l0000=ooooo`;o00001_ooool2o`0000Kooooo0_l0000gooooo`;o00002oooool001ko
oooo00?o0000ooooooooool09oooool2o`0002_ooooo0_l0001Looooo`;o00003Oooool2o`0001oo
oooo0_l0000Mooooo`;o0000=oooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo01Oooooo
0_l0002Iooooo`;o00003Oooool2o`00023ooooo0_l0000eooooo`;o0000:oooool001kooooo00?o
0000ooooooooool05oooool2o`0008cooooo0_l0000looooo`;o0000=Oooool2o`0002_ooooo000N
ooooo`03o`000?oooooooooo03cooooo0_l0000cooooo`;o00002oooool2o`0002Gooooo0_l0001S
ooooo`;o0000>oooool001kooooo00?o0000ooooooooool0??ooool2o`0003?ooooo0_l0000;oooo
o`;o0000I?ooool2o`0002Cooooo0_l0000kooooo`007_ooool00ol0003oooooooooo`0Qooooo`;o
0000J?ooool2o`0005;ooooo0_l00003ooooo`?o0000=oooool2o`0002Oooooo000Nooooo`03o`00
0?oooooooooo027ooooo0_l0001Booooo`;o00005?ooool2o`0002Sooooo0_l0000Xooooo`;o0000
1?ooool2o`0002Oooooo0_l0000>ooooo`;o00009oooool001kooooo00?o0000ooooooooool0MOoo
ool2o`00037ooooo0_l0000;ooooo`;o0000Eoooool2o`0003Oooooo000Nooooo`03o`000?oooooo
oooo00Gooooo0_l0002Qooooo`;o00005_ooool2o`0008Gooooo000Nooooo`03o`000?oooooooooo
00Gooooo0_l0000>ooooo`;o00007?ooool2o`0008_ooooo0_l00025ooooo`007_ooool2o`0001Ko
oooo0_l0000Looooo`;o00005_ooool2o`0005Wooooo0_l0002Oooooo`007_ooool00ol0003ooooo
ooooo`1;ooooo`;o0000FOooool2o`00047ooooo0_l0001Looooo`007_ooool00ol0003ooooooooo
o`3=ooooo`;o00006_ooool2o`0005cooooo000Nooooo`03o`000?oooooooooo02;ooooo0_l0000Z
ooooo`;o00002Oooool2o`0006Cooooo0_l0000<ooooo`;o0000N?ooool001kooooo00?o0000oooo
ooooool04?ooool2o`00013ooooo0_l0000Zooooo`;o00002Oooool2o`0004oooooo0_l0000Coooo
o`;o0000Foooool2o`0002Wooooo000Nooooo`?o00004?ooool2o`0001Cooooo0_l00022ooooo`;o
0000L?ooool2o`0002Wooooo000Nooooo`?o00009_ooool2o`0002?ooooo0_l00005ooooo`;o0000
9Oooool2o`000<cooooo000Nooooo`03o`000?oooooooooo04_ooooo0_l00005ooooo`;o00009Ooo
ool2o`0006_ooooo0_l0001Oooooo`007_ooool00ol0003oooooooooo`0iooooo`;o00006?ooool2
o`0001gooooo0_l0001booooo`;o0000Goooool001kooooo00?o0000ooooooooool0>Oooool2o`00
01Sooooo0_l0000Mooooo`;o0000;_ooool2o`0005Wooooo0_l0000Zooooo`;o00007?ooool001ko
oooo00?o0000ooooooooool00oooool2o`0002Oooooo0_l00009ooooo`;o0000JOooool2o`0000oo
oooo0_l00018ooooo`;o00001Oooool2o`0002?ooooo0_l0000Looooo`007_ooool00ol0003ooooo
ooooo`03ooooo`;o00009oooool2o`0000Wooooo0_l00011ooooo`;o00001?ooool2o`0002_ooooo
0_l00004ooooo`;o0000Coooool2o`00047ooooo000Nooooo`03o`000?oooooooooo04kooooo0_l0
000Iooooo`;o00003oooool2o`0000Cooooo0_l0000[ooooo`;o0000NOooool2o`0001gooooo000N
ooooo`03o`000?oooooooooo00Gooooo0_l00017ooooo`;o00006Oooool2o`000;gooooo0_l0000M
ooooo`007_ooool00ol0003oooooooooo`05ooooo`;o00005_ooool2o`0002Oooooo0_l0000Loooo
o`;o0000B_ooool2o`0009Gooooo000Nooooo`03o`000?oooooooooo01gooooo0_l0000Fooooo`;o
00003oooool2o`00013ooooo0_l00008ooooo`Co0000;_ooool2o`0001[ooooo0_l0000Mooooo`;o
0000M_ooool001kooooo0_l0000fooooo`;o00005oooool2o`0000Sooooo0_l00008ooooo`;o0000
<?ooool2o`0003Wooooo0_l0000aooooo`;o0000<oooool2o`0000kooooo000Nooooo`03o`000?oo
oooooooo00oooooo0_l0000mooooo`;o0000B_ooool2o`0005Gooooo0_l0000?ooooo`;o0000<ooo
ool2o`0000kooooo000Nooooo`03o`000?oooooooooo00oooooo0_l0000Vooooo`;o00001?ooool2
o`0001?ooooo0_l00016ooooo`;o0000EOooool2o`0000oooooo0_l0000^ooooo`;o00004oooool0
01kooooo00?o0000ooooooooool0=oooool2o`0000Cooooo0_l0000Cooooo`;o0000TOooool2o`00
01_ooooo0_l0000^ooooo`;o00004oooool001kooooo00?o0000ooooooooool0C?ooool2o`0001So
oooo0_l0000Qooooo`;o00001_ooool2o`0005;ooooo0_l0000Tooooo`;o0000>_ooool001kooooo
00?o0000ooooooooool0C?ooool2o`0000cooooo0_l0000:ooooo`;o00008Oooool2o`000003oooo
ool0003o000000?ooooo0_l0001Gooooo`;o00007oooool2o`0003[ooooo000Nooooo`03o`000?oo
oooooooo01Gooooo0_l0000?ooooo`;o0000<_ooool2o`00033ooooo0_l00002ooooo`;o0000F?oo
ool2o`0003Cooooo1?l0000Sooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o00003oooool2
o`0006Sooooo0_l0002>ooooo`Co00001oooool2o`0001[ooooo000Nooooo`03o`000?oooooooooo
01kooooo0_l00010ooooo`;o0000U?ooool2o`0003?ooooo0_l0000Dooooo`;o00001?ooool001ko
oooo00?o0000ooooooooool07_ooool2o`00043ooooo0_l00017ooooo`;o0000Boooool2o`0001?o
oooo0_l0000dooooo`;o00001?ooool001kooooo00?o0000ooooooooool07?ooool2o`0008_ooooo
0_l0001Pooooo`;o00003Oooool2o`0002_ooooo000Nooooo`03o`000?oooooooooo01cooooo0_l0
0009ooooo`;o0000:_ooool2o`0006[ooooo0_l0000Aooooo`;o0000A_ooool2o`0002_ooooo000N
ooooo`03o`000?oooooooooo01Sooooo0_l0000=ooooo`;o0000:_ooool2o`0003kooooo0_l0000Z
ooooo`;o00004Oooool2o`0003_ooooo0_l00008ooooo`;o00002?ooool2o`0002;ooooo000Noooo
o`03o`000?oooooooooo01Sooooo0_l0001iooooo`;o0000JOooool2o`0000oooooo0_l00008oooo
o`;o00002?ooool2o`0002;ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo00_ooooo0_l00002
ooooo`;o0000C?ooool2o`0006gooooo0_l0000Iooooo`;o00005Oooool2o`0004Oooooo0003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q
8@06ooooo`03o`000?oooooooooo00_ooooo0_l00002ooooo`;o0000C?ooool2o`0001gooooo0_l0
001>ooooo`;o00005_ooool2o`000003ooooool0003o000002[ooooo0_l0000booooo`000oooool0
1Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000
O?ooool2o`0001cooooo0_l0000Looooo`;o00005oooool3o`00013ooooo0_l0000]ooooo`;o0000
9_ooool2o`0000[ooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RH
oooooonHV9So<S8b00Kooooo00?o0000ooooooooool0AOooool2o`0005?ooooo0_l0000Kooooo`?o
00005oooool3o`0003Kooooo0_l0000_ooooo`;o00002_ooool000?ooooo00Go0000oooooooooooo
ooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`0hoooo
o`;o00002oooool2o`0001Gooooo0_l0001Iooooo`;o0000DOooool2o`0001[ooooo0_l0000Ooooo
o`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006
ooooo`03o`000?oooooooooo03Sooooo0_l0000Rooooo`;o0000`oooool2o`0000?ooooo0_l0000O
ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00
0006ooooo`03o`000?oooooooooo07Oooooo0_l0001Looooo`;o0000;oooool2o`0001Wooooo0_l0
000Tooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@06ooooo`03o`000?oooooooooo06Kooooo0_l0000?ooooo`;o0000G?ooool2o`0002oooooo
0_l0000oooooo`007_ooool00ol0003oooooooooo`0[ooooo`;o00003_ooool2o`0002Wooooo0_l0
002Hooooo`;o0000AOooool001kooooo00?o0000ooooooooool0:oooool2o`0000kooooo0_l0001l
ooooo`;o0000AOooool2o`0001Cooooo0_l0000_ooooo`007_ooool00ol0003oooooooooo`2ioooo
o`;o0000F?ooool2o`000003ooooool0003o000000kooooo0_l0000Oooooo`007_ooool00ol0003o
ooooooooo`3ooooooaCooooo0_l0000Aooooo`;o00001_ooool2o`0001Oooooo000Nooooo`03o`00
0?oooooooooo0?oooooo5?ooool2o`0001Wooooo0_l0000Gooooo`007_ooool00ol0003ooooooooo
o`0Vooooo`;o00002_ooool2o`0004kooooo0_l00026ooooo`;o00001Oooool4o`0001Oooooo0_l0
000Iooooo`007_ooool00ol0003oooooooooo`0Vooooo`;o00002_ooool2o`0004kooooo0_l00002
ooooo`;o00008oooool2o`0002Oooooo0_l0000dooooo`;o00001Oooool2o`0001Wooooo0_l0000I
ooooo`007_ooool01?l0003oooooooooooooool2o`0000Cooooo0_l0001mooooo`;o00008oooool2
o`0002Oooooo0_l0001Booooo`;o00007Oooool001kooooo00Co0000oooooooooooooooo0_l00004
ooooo`;o0000n_ooool2o`0002?ooooo0_l0000Mooooo`007_ooool00ol0003oooooooooo`1Coooo
o`;o0000[_ooool2o`0004;ooooo000Nooooo`03o`000?oooooooooo04Cooooo0_l0000=ooooo`;o
0000l_ooool001kooooo0_l00015ooooo`;o00002oooool2o`0008Kooooo0_l0001/ooooo`007_oo
ool00ol0003oooooooooo`1Aooooo`;o0000<Oooool2o`00037ooooo0_l0000Pooooo`;o00008?oo
ool2o`0004[ooooo000Nooooo`03o`000?oooooooooo08Cooooo0_l0000[ooooo`;o00001?ooool2
o`0004;ooooo0_l0001:ooooo`007_ooool00ol0003oooooooooo`0Fooooo`;o00006?ooool2o`00
07oooooo0_l0001hooooo`;o00006_ooool001kooooo00?o0000ooooooooool05_ooool2o`0001So
oooo0_l0001Mooooo`;o0000R_ooool2o`0000kooooo0_l0000Jooooo`007_ooool00ol0003ooooo
ooooo`2?ooooo`;o0000MOooool2o`0001?ooooo0_l0000Zooooo`007_ooool00ol0003ooooooooo
o`1?ooooo`;o0000<Oooool2o`0000cooooo0_l0001dooooo`;o0000?oooool001kooooo00?o0000
ooooooooool02_ooool2o`0004?ooooo0_l0000aooooo`Co00002_ooool2o`00043ooooo0_l0000b
ooooo`;o0000?oooool001kooooo00?o0000ooooooooool02_ooool2o`0007Sooooo0_l0000Aoooo
o`;o0000>Oooool2o`0007?ooooo000Nooooo`03o`000?oooooooooo09Oooooo0_l0002^ooooo`00
7_ooool00ol0003oooooooooo`3kooooo`;o0000B_ooool001kooooo00?o0000ooooooooool06ooo
ool2o`0000_ooooo0_l0003Aooooo`;o0000B_ooool001kooooo00?o0000ooooooooool06oooool2
o`0000_ooooo0_l0000fooooo`;o00009oooool2o`000;cooooo000Nooooo`03o`000?oooooooooo
063ooooo0_l0000Wooooo`;o0000?_ooool2o`0002?ooooo0_l00013ooooo`;o00004_ooool001ko
oooo00?o0000ooooooooool0C?ooool2o`0000cooooo0_l00007ooooo`;o0000B_ooool2o`0001So
oooo0_l0000Sooooo`;o00006oooool2o`0002Kooooo0_l0000Booooo`007_ooool00ol0003ooooo
ooooo`1<ooooo`;o00003?ooool2o`0000Oooooo0_l0001:ooooo`;o00009?ooool2o`0003Cooooo
0_l0000jooooo`007_ooool2o`0009gooooo0_l0000gooooo`;o0000GOooool2o`00017ooooo000N
ooooo`03o`000?oooooooooo04Cooooo0_l0000Aooooo`;o0000@oooool2o`0001Wooooo0_l0001k
ooooo`;o00004Oooool001kooooo00?o0000ooooooooool02Oooool2o`00027ooooo0_l0000Foooo
o`?o00004?ooool2o`0000Wooooo0_l0001Cooooo`;o0000S_ooool001kooooo00?o0000oooooooo
ool02Oooool2o`00027ooooo0_l0000Gooooo`;o00006oooool2o`0003?ooooo0_l0001Tooooo`;o
0000B?ooool001kooooo00?o0000ooooooooool0B?ooool2o`0001cooooo0_l0000_ooooo`;o0000
I?ooool2o`0002kooooo0_l0000Hooooo`007_ooool00ol0003oooooooooo`18ooooo`;o00000ooo
ool2o`0001Oooooo0_l0000Looooo`;o0000QOooool2o`00023ooooo0_l0000Hooooo`007_ooool0
0ol0003oooooooooo`1=ooooo`;o0000=Oooool2o`0008Gooooo0_l0000Mooooo`;o000000?ooooo
o`000?l000001_ooool2o`00013ooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0003_oooo
o`;o00003_ooool2o`00017ooooo0_l00002ooooo`;o000000?oooooo`000?l000001_ooool2o`00
0003ooooool0003o000000gooooo000Nooooo`03o`000?oooooooooo01;ooooo1?l0003]ooooo`;o
00003_ooool2o`00017ooooo0_l0000@ooooo`;o00003Oooool001kooooo00?o0000ooooooooool0
5?ooool2o`0006Oooooo0_l0001fooooo`;o0000D?ooool001kooooo00?o0000ooooooooool0OOoo
ool2o`0003?ooooo0_l0000[ooooo`;o00005?ooool2o`00053ooooo000Nooooo`03o`000?oooooo
oooo01_ooooo0_l0000?ooooo`;o0000Q?ooool2o`0002_ooooo0_l0001Vooooo`007_ooool00ol0
003oooooooooo`02o`0001Wooooo0_l0000?ooooo`;o00005Oooool2o`000=cooooo0_l0000Toooo
o`007_ooool00ol0003oooooooooo`02o`00047ooooo0_l0000Mooooo`;o00008?ooool2o`0003Wo
oooo0_l0001Pooooo`;o00009?ooool001kooooo00?o0000ooooooooool08?ooool2o`00043ooooo
0_l0000Looooo`;o00000_ooool2o`0003Wooooo0_l00013ooooo`;o0000@Oooool001kooooo00?o
0000ooooooooool08?ooool2o`0004Sooooo0_l0000Dooooo`;o0000?oooool2o`00047ooooo0_l0
000Kooooo`;o00009?ooool001kooooo0_l0000[ooooo`;o00004oooool2o`0002Wooooo0_l0001E
ooooo`;o00004?ooool2o`0004cooooo0_l0000Tooooo`007_ooool00ol0003oooooooooo`0Koooo
o`;o000000?oooooo`000?l000002_ooool2o`0001?ooooo0_l00024ooooo`;o00003?ooool2o`00
07;ooooo000Nooooo`03o`000?oooooooooo01_ooooo0_l000000ooooooo0000o`00000Uooooo`;o
0000O_ooool2o`0004kooooo0_l0000`ooooo`007_ooool00ol0003oooooooooo`15ooooo`;o0000
c_ooool2o`00033ooooo000Nooooo`03o`000?oooooooooo01gooooo0_l00016ooooo`;o0000<ooo
ool2o`0007cooooo0_l0000]ooooo`007_ooool00ol0003oooooooooo`02o`0001_ooooo0_l0000@
ooooo`;o0000<?ooool2o`0000;ooooo0_l0000cooooo`;o0000Aoooool2o`0003?ooooo0_l0000]
ooooo`007_ooool00ol0003oooooooooo`02o`0002gooooo0_l0000Looooo`;o00004_ooool2o`00
083ooooo0_l0000Oooooo`;o0000@Oooool001kooooo00?o0000ooooooooool0=oooool2o`0001Co
oooo0_l0002cooooo`Co0000@Oooool001kooooo00?o0000ooooooooool0=oooool2o`0001Kooooo
0_l0001Pooooo`;o0000Coooool2o`0004?ooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0
001:ooooo`;o0000??ooool2o`0002;ooooo0_l0000Yooooo`;o0000E_ooool2o`00017ooooo000N
ooooo`03o`000?oooooooooo00?ooooo0_l00024ooooo`;o00000_ooool2o`0000gooooo0_l0000@
ooooo`;o0000;?ooool2o`0001Gooooo0_l0000oooooo`;o00004Oooool001kooooo00?o0000oooo
ooooool0Goooool2o`0002Sooooo0_l0000Aooooo`;o00004?ooool2o`0002Gooooo0_l0000Loooo
o`;o0000D_ooool001kooooo00?o0000ooooooooool0Goooool2o`0007Cooooo0_l0000_ooooo`;o
00001_ooool3o`0003Kooooo000Nooooo`04o`000?ooooooooooooooo`;o0000ooooool4ooooo`;o
00001_ooool3o`0000Cooooo0_l0000Sooooo`;o00002oooool001Cooooo1?l000000ol@413ooooo
ooooo`03ooooo`04o`000?ooooooooooooooo`;o0000>oooool2o`000:Oooooo0_l00005ooooo`;o
00002_ooool2o`0000Oooooo0_l0000>ooooo`Co00001_ooool2o`000003ooooool0003o000001So
oooo0_l0000;ooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03kooooo
0_l0002Eooooo`;o00004?ooool2o`0000Gooooo0_l0000:ooooo`;o00001oooool2o`0000kooooo
0_l00008ooooo`;o000000?oooooo`000?l000006Oooool2o`0000[ooooo000Fooooo`03o`000?oo
oooooooo00Gooooo0ol00013ooooo`;o0000F?ooool2o`0003Kooooo0_l0000?ooooo`;o0000?Ooo
ool2o`0001Cooooo0_l0000:ooooo`005_ooool00ol0003oooooooooo`1;ooooo`;o0000F?ooool2
o`0004Oooooo0_l0000mooooo`;o00008?ooool001Kooooo00?o0000ooooooooool0oooooom@oooo
o`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?oooooo
D?ooool001Cooooo00?oEEEEofIVI_l00000oooooomBooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.32332 .67196 Mdot
.80062 .60425 Mdot
.71657 .98517 Mdot
.11166 .48367 Mdot
.09694 .64946 Mdot
.82002 .85345 Mdot
.24738 .70348 Mdot
.25554 .71417 Mdot
.64826 .24705 Mdot
.02118 .0252 Mdot
.58876 .12479 Mdot
.7821 .55738 Mdot
.96224 .61276 Mdot
.16902 .71653 Mdot
.51892 .31397 Mdot
.06935 .7571 Mdot
.40248 .91338 Mdot
.65459 .48502 Mdot
.89823 .95813 Mdot
.65479 .14523 Mdot
.61742 .2258 Mdot
.74218 .06247 Mdot
.55548 .92091 Mdot
.31301 .19893 Mdot
.62093 .24743 Mdot
.02336 .31106 Mdot
.76408 .06422 Mdot
.56214 .38784 Mdot
.97871 .5319 Mdot
.28813 .46954 Mdot
.47194 .43858 Mdot
.18374 .63025 Mdot
.39288 .84067 Mdot
.15534 .12499 Mdot
.65512 .86022 Mdot
.22074 .5309 Mdot
.99512 .43667 Mdot
.38848 .08545 Mdot
.32731 .84921 Mdot
.91622 .0559 Mdot
.16718 .44851 Mdot
.51894 .11663 Mdot
.22104 .62929 Mdot
.1409 .54498 Mdot
.46764 .52107 Mdot
.74697 .55946 Mdot
.01557 .31847 Mdot
.79254 .47134 Mdot
.44595 .69614 Mdot
.88031 .5664 Mdot
.55543 .4631 Mdot
.16063 .47918 Mdot
.20575 .50414 Mdot
.99378 .36564 Mdot
.67605 .29344 Mdot
.52609 .37384 Mdot
.37923 .94154 Mdot
.96721 .6558 Mdot
.05965 .44643 Mdot
.03518 .61974 Mdot
.3205 .52978 Mdot
.51752 .73216 Mdot
.2706 .16699 Mdot
.91929 .15984 Mdot
.35532 .52601 Mdot
.42301 .12892 Mdot
.59022 .5853 Mdot
.619 .39155 Mdot
.37096 .60894 Mdot
.98777 .07008 Mdot
.68867 .64351 Mdot
.63445 .96983 Mdot
.19068 .76926 Mdot
.93483 .0314 Mdot
.02497 .70317 Mdot
.35017 .269 Mdot
.67254 .4679 Mdot
.05239 .88292 Mdot
.63856 .15825 Mdot
.43444 .0744 Mdot
.54608 .30331 Mdot
.48594 .22297 Mdot
.22195 .11769 Mdot
.56306 .48343 Mdot
.96557 .09749 Mdot
.57366 .49699 Mdot
.58986 .82292 Mdot
.78612 .3282 Mdot
.57009 .18216 Mdot
.75741 .37845 Mdot
.97602 .07595 Mdot
.28984 .07163 Mdot
.34155 .7759 Mdot
.91031 .19899 Mdot
.78422 .90673 Mdot
.58631 .68114 Mdot
.96938 .62523 Mdot
.809 .5714 Mdot
.50155 .5767 Mdot
.98841 .99879 Mdot
.63984 .19611 Mdot
.78602 .42879 Mdot
.93761 .75614 Mdot
.15036 .22403 Mdot
.9674 .88457 Mdot
.17289 .04934 Mdot
.74471 .28193 Mdot
.15218 .20358 Mdot
.15824 .28225 Mdot
.21192 .61579 Mdot
.79783 .69248 Mdot
.19766 .18177 Mdot
.61888 .63666 Mdot
.13343 .44961 Mdot
.42179 .41756 Mdot
.22102 .73073 Mdot
.63438 .66758 Mdot
.17399 .98016 Mdot
.03772 .7969 Mdot
.66579 .79746 Mdot
.77036 .64574 Mdot
.52837 .9909 Mdot
.25174 .94475 Mdot
.27282 .62414 Mdot
.32644 .27718 Mdot
.5811 .63922 Mdot
.83335 .00928 Mdot
.04848 .50024 Mdot
.26157 .79413 Mdot
.57427 .16685 Mdot
.21105 .30959 Mdot
.3267 .42432 Mdot
.34519 .84769 Mdot
.16342 .3878 Mdot
.75135 .82192 Mdot
.37462 .71388 Mdot
.43153 .06569 Mdot
.12874 .09809 Mdot
.66853 .88756 Mdot
.39426 .56687 Mdot
.35031 .92299 Mdot
.83094 .9649 Mdot
.91069 .47492 Mdot
.2564 .61439 Mdot
.97495 .27615 Mdot
.25661 .78871 Mdot
.0629 .72715 Mdot
.31614 .39457 Mdot
.10222 .53381 Mdot
.90998 .24402 Mdot
.26473 .28052 Mdot
.59095 .45429 Mdot
.24211 .49142 Mdot
.91232 .75328 Mdot
.89813 .38909 Mdot
.97299 .62617 Mdot
.01231 .34573 Mdot
.48005 .78342 Mdot
.45061 .12992 Mdot
.26701 .44952 Mdot
.1211 .14527 Mdot
.85359 .34225 Mdot
.01504 .91611 Mdot
.17084 .09349 Mdot
.84522 .4306 Mdot
.93645 .01247 Mdot
.64302 .81979 Mdot
.97397 .16893 Mdot
.87793 .48239 Mdot
.23576 .55487 Mdot
.12001 .40131 Mdot
.92505 .62627 Mdot
.29358 .97107 Mdot
.45134 .97895 Mdot
.27749 .19704 Mdot
.15538 .43162 Mdot
.28066 .92429 Mdot
.13647 .28413 Mdot
.0052 .20828 Mdot
.67978 .97519 Mdot
.01353 .62214 Mdot
.88409 .63742 Mdot
.194 .33566 Mdot
.14485 .87628 Mdot
.66626 .60255 Mdot
.23837 .79151 Mdot
.14279 .32734 Mdot
.72899 .89571 Mdot
.6063 .66897 Mdot
.58523 .92514 Mdot
.29296 .06858 Mdot
.45872 .78818 Mdot
.37449 .74139 Mdot
.65492 .67067 Mdot
.93407 .9086 Mdot
.70033 .58513 Mdot
.75479 .52701 Mdot
.57558 .59024 Mdot
.23962 .85684 Mdot
.60791 .34153 Mdot
.29295 .48151 Mdot
.96096 .57161 Mdot
.5067 .76537 Mdot
.23549 .93843 Mdot
.30141 .27121 Mdot
.23502 .79987 Mdot
.49243 .59211 Mdot
.765 .00117 Mdot
.836 .94727 Mdot
.50068 .06377 Mdot
.30141 .91878 Mdot
.23041 .82891 Mdot
.98641 .27203 Mdot
.81201 .47143 Mdot
.74314 .82419 Mdot
.60876 .48695 Mdot
.38291 .13655 Mdot
.69806 .22641 Mdot
.00407 .77025 Mdot
.53781 .79119 Mdot
.88056 .8091 Mdot
.19777 .45352 Mdot
.05256 .06095 Mdot
.31137 .49701 Mdot
.19457 .99344 Mdot
.05498 .78547 Mdot
.88174 .97809 Mdot
.96765 .32757 Mdot
.47022 .54188 Mdot
.99221 .63814 Mdot
.21739 .95435 Mdot
.09307 .62958 Mdot
.30331 .59324 Mdot
.08624 .80627 Mdot
.18861 .85883 Mdot
.99446 .94823 Mdot
.38752 .24329 Mdot
.67962 .60317 Mdot
.05772 .24381 Mdot
.30262 .70547 Mdot
.24206 .79441 Mdot
.29997 .99018 Mdot
.94789 .95518 Mdot
.13974 .99183 Mdot
.77772 .60743 Mdot
.45204 .01169 Mdot
.29849 .8813 Mdot
.61672 .71901 Mdot
.28304 .16444 Mdot
.19567 .59088 Mdot
.36318 .42585 Mdot
.64663 .41124 Mdot
.19911 .32937 Mdot
.72311 .83246 Mdot
.78766 .51773 Mdot
.09558 .72736 Mdot
.21222 .60481 Mdot
.05386 .99925 Mdot
.26607 .27796 Mdot
.87752 .95735 Mdot
.47103 .81673 Mdot
.55575 .33552 Mdot
.6928 .27846 Mdot
.53426 .34847 Mdot
.10335 .97645 Mdot
.09405 .40183 Mdot
.40856 .96105 Mdot
.27824 .64983 Mdot
.52896 .14121 Mdot
.91387 .63555 Mdot
.82927 .33912 Mdot
.19822 .25961 Mdot
.46555 .94476 Mdot
.37464 .54503 Mdot
.24983 .74367 Mdot
.78829 .77199 Mdot
.85543 .80077 Mdot
.83386 .22535 Mdot
.45407 .42658 Mdot
.96119 .89516 Mdot
.81607 .15898 Mdot
.50583 .1905 Mdot
.8123 .66299 Mdot
.85102 .56152 Mdot
.38253 .26941 Mdot
.67693 .27972 Mdot
.72292 .33116 Mdot
.83642 .29205 Mdot
.8273 .36372 Mdot
.82269 .93122 Mdot
.10113 .57206 Mdot
.18903 .22899 Mdot
.05905 .93603 Mdot
.9018 .60864 Mdot
.85252 .22639 Mdot
.77581 .27432 Mdot
.34137 .39042 Mdot
.55797 .38591 Mdot
.75606 .45784 Mdot
.2375 .1022 Mdot
.47118 .3815 Mdot
.69297 .19409 Mdot
.29605 .48232 Mdot
.9368 .027 Mdot
.57714 .46664 Mdot
.31291 .39994 Mdot
.38449 .06637 Mdot
.59123 .04363 Mdot
.47137 .95981 Mdot
.56761 .70753 Mdot
.40808 .54844 Mdot
.72838 .56931 Mdot
.0022 .35465 Mdot
.97015 .35387 Mdot
.13401 .06619 Mdot
.21021 .55245 Mdot
.82024 .88147 Mdot
.25712 .63606 Mdot
.61283 .30131 Mdot
.58796 .26932 Mdot
.90536 .96642 Mdot
.04445 .90159 Mdot
.54522 .28291 Mdot
.63311 .03775 Mdot
.42995 .38472 Mdot
.69386 .49447 Mdot
.88539 .39477 Mdot
.44664 .42931 Mdot
.91713 .0828 Mdot
.31477 .20919 Mdot
.00166 .76286 Mdot
.17951 .81941 Mdot
.37685 .42384 Mdot
.64956 .97605 Mdot
.02235 .68055 Mdot
.31238 .71818 Mdot
.27335 .05425 Mdot
.42115 .54006 Mdot
.94842 .50678 Mdot
.71706 .25453 Mdot
.91836 .03092 Mdot
.22088 .84946 Mdot
.2239 .49962 Mdot
.60831 .85153 Mdot
.15934 .48929 Mdot
.40526 .98689 Mdot
.3407 .24487 Mdot
.88361 .77787 Mdot
.42617 .65645 Mdot
.12905 .63351 Mdot
.27572 .04775 Mdot
.84385 .64924 Mdot
.13652 .53159 Mdot
.67077 .25795 Mdot
.94798 .78114 Mdot
.90363 .97392 Mdot
.14226 .24966 Mdot
.16727 .42477 Mdot
.67757 .40115 Mdot
.73067 .08922 Mdot
.92021 .80367 Mdot
.55102 .65916 Mdot
.56923 .62235 Mdot
.77461 .36307 Mdot
.94594 .33247 Mdot
.43837 .141 Mdot
.09419 .50074 Mdot
.72297 .53301 Mdot
.53988 .40479 Mdot
.1637 .51651 Mdot
.67234 .35307 Mdot
.92193 .15613 Mdot
.46239 .74618 Mdot
.63623 .86287 Mdot
.3751 .68637 Mdot
.39211 .81267 Mdot
.18927 .63739 Mdot
.67184 .706 Mdot
.20306 .64822 Mdot
.31869 .07132 Mdot
.94989 .2805 Mdot
.04994 .06222 Mdot
.80326 .77223 Mdot
.62054 .25207 Mdot
.35416 .77749 Mdot
.67254 .61746 Mdot
.39697 .67237 Mdot
.14486 .76348 Mdot
.34375 .19296 Mdot
.5399 .05205 Mdot
.86976 .57713 Mdot
.16827 .95864 Mdot
.27425 .12422 Mdot
.50564 .1871 Mdot
.14498 .69905 Mdot
.54836 .40041 Mdot
.78302 .90765 Mdot
.84627 .37471 Mdot
.9114 .57163 Mdot
.80205 .5274 Mdot
.92247 .32858 Mdot
.59039 .39274 Mdot
.67507 .54988 Mdot
.47296 .25141 Mdot
.33934 .46884 Mdot
.04695 .95727 Mdot
.90877 .46596 Mdot
.90154 .06967 Mdot
.3664 .52367 Mdot
.45962 .88256 Mdot
.06023 .94493 Mdot
.67969 .67681 Mdot
.84505 .76509 Mdot
.94546 .64641 Mdot
.01841 .94003 Mdot
.56943 .55772 Mdot
.29707 .14672 Mdot
.90476 .71294 Mdot
.78207 .99876 Mdot
.88085 .82572 Mdot
.71349 .52358 Mdot
.99751 .00808 Mdot
.7756 .01498 Mdot
.45905 .18361 Mdot
.54491 .07013 Mdot
.50882 .48315 Mdot
.17836 .73871 Mdot
.10191 .63332 Mdot
.63731 .59853 Mdot
.53179 .11859 Mdot
.42138 .49785 Mdot
.4233 .37535 Mdot
.71546 .20435 Mdot
.01111 .28119 Mdot
.23579 .96092 Mdot
.92151 .36924 Mdot
.38074 .33629 Mdot
.12014 .14536 Mdot
.64686 .23341 Mdot
.31928 .96231 Mdot
.65757 .36842 Mdot
.4715 .12241 Mdot
.30389 .20477 Mdot
.86132 .94698 Mdot
.90003 .22161 Mdot
.12869 .7388 Mdot
.71358 .0109 Mdot
.60814 .36457 Mdot
.48475 .49461 Mdot
.35474 .6279 Mdot
.15592 .89179 Mdot
.22865 .69565 Mdot
.90649 .48714 Mdot
.40218 .03909 Mdot
.45391 .22779 Mdot
.54234 .64293 Mdot
.52654 .57343 Mdot
.27124 .4168 Mdot
.55499 .2302 Mdot
.06503 .66573 Mdot
.69842 .42811 Mdot
.37018 .07566 Mdot
.86705 .9907 Mdot
.4828 .91675 Mdot
.35454 .59568 Mdot
.27294 .71068 Mdot
.07599 .12731 Mdot
.3899 .75841 Mdot
.22638 .90551 Mdot
.89679 .61799 Mdot
.35886 .58525 Mdot
.34989 .63307 Mdot
.65985 .91611 Mdot
.026 .4496 Mdot
.0619 .69728 Mdot
.64422 .36339 Mdot
.67122 .43946 Mdot
.47088 .49991 Mdot
.87502 .09218 Mdot
.56251 .56499 Mdot
.92607 .89389 Mdot
.65463 .21252 Mdot
.81176 .09933 Mdot
.26112 .65428 Mdot
.12847 .61558 Mdot
.59217 .48146 Mdot
.38741 .41535 Mdot
.09689 .07463 Mdot
.77685 .4397 Mdot
.73762 .24765 Mdot
.36947 .09828 Mdot
.17892 .30845 Mdot
.29401 .62248 Mdot
.88238 .98564 Mdot
.24379 .45002 Mdot
.71981 .57737 Mdot
.73105 .62014 Mdot
.50927 .40556 Mdot
.03608 .3344 Mdot
.69013 .65981 Mdot
.65276 .79576 Mdot
.29004 .18376 Mdot
.49446 .36031 Mdot
.97949 .98314 Mdot
.25127 .07063 Mdot
.38995 .52584 Mdot
.80276 .37091 Mdot
.57636 .96456 Mdot
.71398 .33393 Mdot
.25221 .55387 Mdot
.81426 .49797 Mdot
.08752 .80452 Mdot
.07259 .51767 Mdot
.03653 .27403 Mdot
.8793 .43026 Mdot
.08992 .85254 Mdot
.90514 .40238 Mdot
.428 .75143 Mdot
.03794 .2719 Mdot
.24475 .70333 Mdot
.59959 .49623 Mdot
.80214 .89904 Mdot
.97075 .46514 Mdot
.17893 .09678 Mdot
.87794 .10981 Mdot
.30545 .10842 Mdot
.38148 .74925 Mdot
.29544 .56416 Mdot
.51042 .21887 Mdot
.34956 .58413 Mdot
.8309 .62163 Mdot
.41144 .75317 Mdot
.93466 .04011 Mdot
.78805 .23294 Mdot
.94942 .81702 Mdot
.10527 .84394 Mdot
.48534 .08398 Mdot
.26387 .14534 Mdot
.83505 .17395 Mdot
.05508 .63097 Mdot
.92319 .72784 Mdot
.05924 .75187 Mdot
.50774 .30411 Mdot
.95259 .11796 Mdot
.34988 .40169 Mdot
.21352 .46569 Mdot
.7762 .85299 Mdot
.35 .76155 Mdot
.1239 .99164 Mdot
.76711 .00471 Mdot
.76686 .61567 Mdot
.34258 .16891 Mdot
.23115 .99993 Mdot
.09977 .30876 Mdot
.72608 .79909 Mdot
.62347 .98978 Mdot
.43639 .84845 Mdot
.07122 .09655 Mdot
.36784 .60126 Mdot
.1606 .71052 Mdot
.06594 .58246 Mdot
.8091 .78762 Mdot
.84693 .07468 Mdot
.35098 .5422 Mdot
.90467 .69201 Mdot
.92159 .10913 Mdot
.61142 .31451 Mdot
.78491 .03329 Mdot
.70396 .00712 Mdot
.88821 .71289 Mdot
.47659 .0582 Mdot
.15947 .8775 Mdot
.81888 .85186 Mdot
.94892 .86076 Mdot
.81113 .36184 Mdot
.99451 .18709 Mdot
.2963 .9145 Mdot
.25943 .99374 Mdot
.55125 .1059 Mdot
.29381 .94634 Mdot
.75642 .28117 Mdot
.66901 .91985 Mdot
.28215 .1765 Mdot
.80175 .24369 Mdot
.02674 .87211 Mdot
.70006 .5949 Mdot
.00468 .22567 Mdot
.8639 .11763 Mdot
.61238 .57911 Mdot
.04087 .30664 Mdot
.70005 .64058 Mdot
.59494 .92168 Mdot
.12154 .16575 Mdot
.18646 .60496 Mdot
.46084 .53487 Mdot
.27622 .77075 Mdot
.09187 .00403 Mdot
.16389 .24798 Mdot
.47681 .72123 Mdot
.1816 .9979 Mdot
.83818 .12844 Mdot
.13676 .44633 Mdot
.58849 .16993 Mdot
.6443 .29755 Mdot
.49716 .3998 Mdot
.14498 .27201 Mdot
.86418 .6355 Mdot
.78425 .05979 Mdot
.22527 .59576 Mdot
.93431 .44213 Mdot
.75065 .9156 Mdot
.13123 .13573 Mdot
.37546 .28717 Mdot
.91506 .85888 Mdot
.96526 .64471 Mdot
.69167 .28316 Mdot
.35903 .34578 Mdot
.5226 .28341 Mdot
.70297 .21916 Mdot
.01714 .42202 Mdot
.73878 .4665 Mdot
.95249 .33222 Mdot
.78911 .5323 Mdot
.82222 .95651 Mdot
.01878 .835 Mdot
.66077 .00062 Mdot
.10465 .56249 Mdot
.30029 .78344 Mdot
.40291 .84769 Mdot
.49955 .88749 Mdot
.59389 .21535 Mdot
.6326 .62339 Mdot
.08769 .24627 Mdot
.46016 .6628 Mdot
.43989 .29927 Mdot
.65074 .07562 Mdot
.5635 .71318 Mdot
.48845 .6588 Mdot
.16689 .38235 Mdot
.68002 .00434 Mdot
.36488 .83633 Mdot
.26964 .14961 Mdot
.56926 .19757 Mdot
.93026 .90261 Mdot
.68873 .52386 Mdot
.23253 .37559 Mdot
.48564 .73961 Mdot
.15939 .34109 Mdot
.08778 .03095 Mdot
.88084 .02595 Mdot
.69947 .70362 Mdot
.00358 .89579 Mdot
.77752 .83785 Mdot
.09477 .74391 Mdot
.01224 .34753 Mdot
.30106 .82873 Mdot
.49853 .5691 Mdot
.22973 .31759 Mdot
.07292 .38654 Mdot
.5709 .40074 Mdot
.92888 .88655 Mdot
.50875 .38771 Mdot
.65463 .43738 Mdot
.39272 .7113 Mdot
.64307 .4433 Mdot
.46522 .80051 Mdot
.74342 .45413 Mdot
.10789 .20254 Mdot
.60749 .90388 Mdot
.94632 .38522 Mdot
.41947 .18125 Mdot
.16047 .89733 Mdot
.17105 .4327 Mdot
.72323 .19087 Mdot
.97041 .04595 Mdot
.65444 .31811 Mdot
.4788 .8956 Mdot
.47314 .27555 Mdot
.32544 .35454 Mdot
.4367 .25452 Mdot
.72525 .72064 Mdot
.6443 .78365 Mdot
.66792 .42427 Mdot
.44713 .82841 Mdot
.71243 .63889 Mdot
.92293 .37171 Mdot
.69831 .08009 Mdot
.59954 .75615 Mdot
.39485 .54562 Mdot
.30362 .1181 Mdot
.30875 .60814 Mdot
.78138 .97446 Mdot
.55848 .512 Mdot
.62623 .41384 Mdot
.43914 .022 Mdot
.53884 .7888 Mdot
.10764 .05737 Mdot
.69835 .64091 Mdot
.18425 .01983 Mdot
.23775 .58212 Mdot
.05601 .56207 Mdot
.69956 .55972 Mdot
.85458 .87205 Mdot
.97189 .38167 Mdot
.0653 .07241 Mdot
.62067 .24579 Mdot
.35147 .45445 Mdot
.93356 .6717 Mdot
.70663 .35623 Mdot
.10821 .74338 Mdot
.29797 .22824 Mdot
.27601 .26716 Mdot
.80355 .8749 Mdot
.48938 .00487 Mdot
.8293 .96099 Mdot
.71309 .07511 Mdot
.95119 .42951 Mdot
.50029 .40348 Mdot
.3255 .28927 Mdot
.79545 .86765 Mdot
.50775 .60259 Mdot
.5038 .90756 Mdot
.31363 .36326 Mdot
.74323 .39832 Mdot
.34215 .61518 Mdot
.21977 .48666 Mdot
.69468 .74551 Mdot
.59413 .55896 Mdot
.50382 .67788 Mdot
.69072 .99887 Mdot
.79304 .3897 Mdot
.83938 .17275 Mdot
.92651 .70004 Mdot
.52823 .95759 Mdot
.83928 .54402 Mdot
.30332 .74095 Mdot
.9324 .5932 Mdot
.04914 .80958 Mdot
.91954 .21281 Mdot
.09699 .30864 Mdot
.43248 .73282 Mdot
.1105 .12502 Mdot
.08126 .26774 Mdot
.07987 .73091 Mdot
.83423 .63811 Mdot
.98221 .45118 Mdot
.66503 .19321 Mdot
.58771 .7278 Mdot
.34856 .19401 Mdot
.45242 .59887 Mdot
.91255 .46136 Mdot
.87334 .7347 Mdot
.66208 .51705 Mdot
.4163 .68345 Mdot
.84723 .71799 Mdot
.05712 .65038 Mdot
.37561 .61165 Mdot
.11938 .09626 Mdot
.77582 .7853 Mdot
.89262 .7995 Mdot
.13777 .73984 Mdot
.55409 .64564 Mdot
.44016 .22342 Mdot
.05686 .31495 Mdot
.61533 .9118 Mdot
.35685 .50545 Mdot
.60552 .0744 Mdot
.11299 .62512 Mdot
.79417 .37413 Mdot
.71099 .83241 Mdot
.39413 .27949 Mdot
.62568 .07815 Mdot
.4814 .49551 Mdot
.59518 .01044 Mdot
.71551 .2104 Mdot
.56665 .73747 Mdot
.24404 .64701 Mdot
.31819 .60907 Mdot
.82828 .00516 Mdot
.78756 .55034 Mdot
.78274 .0151 Mdot
.09859 .02087 Mdot
.62367 .44613 Mdot
.6714 .41082 Mdot
.96262 .33606 Mdot
.2367 .06387 Mdot
.66201 .95939 Mdot
.70542 .52409 Mdot
.18466 .83687 Mdot
.87194 .8328 Mdot
.51953 .53896 Mdot
.95235 .33449 Mdot
.75135 .05777 Mdot
.67343 .64236 Mdot
.6767 .46996 Mdot
.32465 .9455 Mdot
.55732 .76008 Mdot
.64561 .16882 Mdot
.63979 .33511 Mdot
.53674 .66233 Mdot
.70361 .20669 Mdot
.00991 .44389 Mdot
.49751 .41392 Mdot
.40353 .09759 Mdot
.65639 .45011 Mdot
.37415 .43204 Mdot
.89525 .05797 Mdot
.94618 .64743 Mdot
.8268 .30349 Mdot
.42874 .21318 Mdot
.09891 .69258 Mdot
.56913 .26755 Mdot
.77406 .50707 Mdot
.7672 .72639 Mdot
.37924 .25014 Mdot
.98515 .16062 Mdot
.44558 .39506 Mdot
.2222 .41526 Mdot
.63856 .22813 Mdot
.12194 .68434 Mdot
.55461 .41103 Mdot
.50752 .59678 Mdot
.69596 .67101 Mdot
.7079 .00077 Mdot
.01495 .32143 Mdot
.17721 .1112 Mdot
.22283 .38878 Mdot
.9466 .04997 Mdot
.26988 .24691 Mdot
.1421 .49291 Mdot
.86629 .59263 Mdot
.55891 .8286 Mdot
.57254 .5429 Mdot
.92513 .57619 Mdot
.9888 .55516 Mdot
.32968 .46416 Mdot
.37239 .06133 Mdot
.7651 .43864 Mdot
.31731 .46967 Mdot
.06721 .52576 Mdot
.43638 .10526 Mdot
.14809 .63121 Mdot
.27858 .42392 Mdot
.87191 .08002 Mdot
.95568 .44153 Mdot
.69997 .62979 Mdot
.6066 .12987 Mdot
.23334 .31851 Mdot
.31095 .78154 Mdot
.86718 .56824 Mdot
.1274 .75956 Mdot
.8265 .89987 Mdot
.4491 .12875 Mdot
.12562 .76036 Mdot
.56567 .54204 Mdot
.86003 .32633 Mdot
.23014 .28826 Mdot
.27824 .69873 Mdot
.43119 .01694 Mdot
.82938 .32448 Mdot
.64261 .53093 Mdot
.09 .95119 Mdot
.95037 .54042 Mdot
.73229 .75409 Mdot
.31848 .30365 Mdot
.1981 .1589 Mdot
.70879 .19695 Mdot
.37072 .21845 Mdot
.38025 .19119 Mdot
.53434 .62285 Mdot
.68577 .11495 Mdot
.26391 .70669 Mdot
.13072 .22887 Mdot
.24605 .12669 Mdot
.12284 .64562 Mdot
.28785 .98057 Mdot
.76344 .53375 Mdot
.30178 .25029 Mdot
.15626 .73548 Mdot
.67306 .77851 Mdot
.10175 .50852 Mdot
.48992 .24994 Mdot
.9694 .22761 Mdot
.42784 .86888 Mdot
.91339 .6754 Mdot
.47833 .26608 Mdot
.85026 .22888 Mdot
.23884 .07114 Mdot
.13179 .55041 Mdot
.65166 .35615 Mdot
.48633 .60528 Mdot
.00959 .5486 Mdot
.81704 .33481 Mdot
.98888 .55281 Mdot
.80027 .67895 Mdot
.75641 .9016 Mdot
.56026 .60419 Mdot
.24202 .14334 Mdot
.82729 .9359 Mdot
.25411 .8414 Mdot
.89847 .87957 Mdot
.30388 .80329 Mdot
.77346 .66499 Mdot
.2758 .9412 Mdot
.06075 .26552 Mdot
.56259 .28041 Mdot
.35737 .39934 Mdot
.68266 .61013 Mdot
.96538 .83764 Mdot
.06194 .9997 Mdot
.53425 .09733 Mdot
.99509 .5962 Mdot
.8131 .16849 Mdot
.87616 .47338 Mdot
.43678 .83376 Mdot
.9438 .58505 Mdot
.54188 .39263 Mdot
.35307 .30552 Mdot
.73504 .46211 Mdot
.83486 .84783 Mdot
.87626 .25019 Mdot
.86671 .46139 Mdot
.3731 .06118 Mdot
.35513 .25652 Mdot
.9695 .25807 Mdot
.26023 .1836 Mdot
.28417 .10251 Mdot
.67672 .04859 Mdot
.897 .24716 Mdot
.32628 .50244 Mdot
.09587 .26374 Mdot
.96303 .55382 Mdot
.50417 .38833 Mdot
.69187 .52546 Mdot
.93839 .084 Mdot
.94452 .09124 Mdot
.21375 .83018 Mdot
.19372 .02165 Mdot
.31192 .2353 Mdot
.53246 .01296 Mdot
.96092 .79176 Mdot
.3224 .48147 Mdot
.69667 .09193 Mdot
.65494 .21123 Mdot
.04919 .12981 Mdot
.17585 .54262 Mdot
.97225 .96156 Mdot
.4937 .97341 Mdot
.92483 .02752 Mdot
.57264 .32706 Mdot
.361 .95035 Mdot
.70605 .98923 Mdot
.97553 .25994 Mdot
.06178 .05317 Mdot
.3718 .32927 Mdot
.43526 .37963 Mdot
.25869 .43769 Mdot
.75626 .37335 Mdot
.33743 .11973 Mdot
.99438 .36254 Mdot
.84894 .11719 Mdot
.42112 .93618 Mdot
.83213 .86335 Mdot
.41412 .32583 Mdot
.85596 .5037 Mdot
.72077 .43429 Mdot
.1065 .36278 Mdot
.48098 .075 Mdot
.94885 .7662 Mdot
.59136 .8549 Mdot
.68036 .28056 Mdot
.11609 .47921 Mdot
.81456 .30636 Mdot
.88795 .35132 Mdot
.87639 .39235 Mdot
.30326 .59696 Mdot
.30024 .12293 Mdot
.92021 .26949 Mdot
.36302 .32595 Mdot
.42529 .42339 Mdot
.70138 .08945 Mdot
.25747 .19469 Mdot
.38878 .44446 Mdot
.09899 .98684 Mdot
.60879 .7688 Mdot
.80472 .64814 Mdot
.7668 .7253 Mdot
.88565 .88577 Mdot
.79111 .77494 Mdot
.14826 .79528 Mdot
.77711 .01096 Mdot
.69568 .4899 Mdot
.24926 .88834 Mdot
.18797 .91811 Mdot
.08401 .12955 Mdot
.50986 .25338 Mdot
.51966 .30496 Mdot
.81894 .61502 Mdot
.81105 .32488 Mdot
.21296 .56226 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool02_ooool2o`000003ooooool0003ooooo00kooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`02o`0000Cooooo0_l00005ooooo`04o`000?oooooo0000o`00
00cooooo00?o0000ooooooooool00_ooool2o`0000[ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`02ooooo`007_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[o
oooo0_l000000ooooooo0000ooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo0_l00002ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00Kooooo0_l00005ooooo`?o00003Oooool00ol0003oooooooooo`02ooooo`;o
00002_ooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`00
7_ooool00ol0003oooooooooo`2Kooooo`;o00008?ooool2o`0002;ooooo0_l0000Booooo`;o0000
4_ooool4o`0003?ooooo0_l00005ooooo`007_ooool00ol0003oooooooooo`2?ooooo`;o00006?oo
ool2o`0001;ooooo0_l0000Uooooo`;o00004oooool2o`00013ooooo0_l0000Oooooo`;o00004_oo
ool2o`0000Gooooo000Nooooo`03o`000?oooooooooo08oooooo0_l0000Hooooo`;o0000>Oooool2
o`0001;ooooo1?l0000`ooooo`;o00006Oooool001kooooo00?o0000ooooooooool0>?ooool2o`00
04kooooo0_l0001^ooooo`Co0000Boooool001kooooo00?o0000ooooooooool07?ooool2o`0001[o
oooo0_l000000ooooooo0000o`00001;ooooo`;o000000?oooooo`000?l00000^_ooool001kooooo
00?o0000ooooooooool00oooool2o`0001Oooooo0_l0000Mooooo`;o0000C_ooool2o`0008gooooo
0_l0000[ooooo`007_ooool00ol0003oooooooooo`03ooooo`;o0000oooooolFooooo`;o00003Ooo
ool2o`000003ooooool0003o000001Wooooo000Nooooo`03o`000?oooooooooo01Sooooo0_l0003o
ooooo`gooooo0_l000001?oooooo0000o`000?ooool2o`0001Wooooo000Nooooo`03o`000?oooooo
oooo01Sooooo0_l0003Qooooo`;o0000:Oooool2o`0000Cooooo0_l0000Iooooo`007_ooool00ol0
003oooooooooo`3:ooooo`;o0000;oooool2o`0004[ooooo000Nooooo`03o`000?oooooooooo07oo
oooo0_l00019ooooo`;o0000H?ooool2o`0001Wooooo000Nooooo`03o`000?oooooooooo07oooooo
0_l0000kooooo`;o0000K_ooool2o`0001Wooooo000Nooooo`03o`000?oooooooooo0;cooooo0_l0
001iooooo`;o00003_ooool001kooooo00?o0000ooooooooool0=?ooool2o`00023ooooo0_l00020
ooooo`;o0000E_ooool2o`0000Gooooo0_l0000>ooooo`007_ooool2o`00017ooooo0_l0000Roooo
o`;o00008?ooool2o`0005?ooooo0_l0000[ooooo`;o0000E_ooool2o`0001Gooooo000Nooooo`03
o`000?oooooooooo013ooooo0_l00013ooooo`;o0000E?ooool2o`0007Wooooo0_l0000Oooooo`00
7_ooool00ol0003oooooooooo`0Oooooo`;o0000=?ooool2o`00043ooooo0_l0001Gooooo`;o0000
2Oooool2o`0002;ooooo0_l00005ooooo`;o00007oooool001kooooo00?o0000ooooooooool03?oo
ool3o`00013ooooo0_l0001Dooooo`;o00008?ooool2o`0005Cooooo0_l000000ooooooo0000o`00
0009ooooo`;o00008_ooool2o`0002Kooooo000Nooooo`03o`000?oooooooooo00cooooo0ol0000j
ooooo`;o0000:_ooool2o`00017ooooo0_l0000Eooooo`;o0000C?ooool2o`0000Gooooo0_l0001A
ooooo`007_ooool00ol0003oooooooooo`0Wooooo`;o00008?ooool2o`00013ooooo0_l0000Loooo
o`;o00003Oooool2o`0001Gooooo0_l0001Cooooo`;o0000DOooool001kooooo00?o0000oooooooo
ool09oooool2o`00027ooooo0_l00002ooooo`;o00002_ooool3o`0000Kooooo0_l0000Dooooo`;o
0000<_ooool2o`0007;ooooo0_l0000Jooooo`;o00002?ooool001kooooo00?o0000ooooooooool0
4Oooool2o`0000Sooooo0_l0000]ooooo`;o00000_ooool2o`0000[ooooo0_l00007ooooo`;o0000
9?ooool2o`0000gooooo0_l0000Cooooo`;o00004_ooool2o`00027ooooo0_l0000Yooooo`;o0000
4?ooool2o`0001[ooooo0_l00008ooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o00002?oo
ool2o`0005Oooooo0_l0000Cooooo`;o00003Oooool2o`0002Oooooo0_l00004ooooo`;o00001_oo
ool2o`0001?ooooo0_l0000Yooooo`;o0000:?ooool2o`0000cooooo000Nooooo`03o`000?oooooo
oooo07Cooooo0_l0001Aooooo`;o00001_ooool2o`0000kooooo0_l0000fooooo`;o00008?ooool2
o`0000cooooo000Nooooo`03o`000?oooooooooo09[ooooo0_l00013ooooo`;o0000=_ooool2o`00
00gooooo0_l00005ooooo`;o00006?ooool001kooooo00?o0000ooooooooool0N_ooool2o`0001ko
oooo0_l0002:ooooo`;o00001Oooool2o`0001Sooooo000Nooooo`03o`000?oooooooooo07[ooooo
0_l0001Tooooo`;o00001oooool2o`0005cooooo000Nooooo`03o`000?oooooooooo03?ooooo0_l0
002Yooooo`Co00001oooool2o`0002gooooo0_l0000Eooooo`;o00005_ooool001kooooo00?o0000
ooooooooool04oooool2o`0000kooooo0_l0000>ooooo`;o000000?oooooo`000?l00000Y_ooool2
o`0003Sooooo0_l0000Eooooo`;o00005_ooool001kooooo00?o0000ooooooooool04oooool2o`00
00kooooo0_l000000ooooooo0000o`00000>ooooo`;o0000??ooool2o`0000Wooooo0_l0000Yoooo
o`;o0000F?ooool2o`00033ooooo0_l0000?ooooo`007_ooool2o`0002Oooooo0_l0000Qooooo`;o
00003Oooool2o`0001[ooooo0_l00009ooooo`;o0000:Oooool2o`0005Sooooo0_l0000`ooooo`;o
00003oooool001kooooo00?o0000ooooooooool0BOooool2o`0000gooooo0_l0000`ooooo`;o0000
8oooool2o`0009Kooooo000Nooooo`03o`000?oooooooooo05oooooo0_l0000Yooooo`;o00008ooo
ool2o`0009Kooooo000Nooooo`03o`000?oooooooooo03Gooooo0_l0000Xooooo`;o0000^?ooool2
o`0000gooooo0_l0000Mooooo`007_ooool00ol0003oooooooooo`0eooooo`;o0000Y?ooool2o`00
03cooooo0_l0000=ooooo`;o00007Oooool001kooooo00?o0000ooooooooool0A?ooool2o`0001Wo
oooo0_l00014ooooo`;o0000=?ooool2o`0003?ooooo0_l00003ooooo`;o00006oooool2o`0001?o
oooo000Nooooo`03o`000?oooooooooo04Cooooo0_l0000Iooooo`;o00002Oooool2o`0003Wooooo
0_l00002ooooo`;o0000IOooool2o`0000?ooooo0_l0000Kooooo`;o00004oooool001kooooo00?o
0000ooooooooool0EOooool2o`0000Kooooo0_l0000;ooooo`;o0000:Oooool2o`0001;ooooo0_l0
002Looooo`007_ooool00ol0003oooooooooo`0Eooooo`;o00002Oooool2o`0000cooooo0_l0000L
ooooo`;o00001oooool2o`0000Kooooo0_l0000fooooo`;o00009?ooool2o`0008[ooooo000Noooo
o`03o`000?oooooooooo00cooooo0_l00007ooooo`Co00001oooool2o`0000cooooo0_l0000Loooo
o`;o0000=oooool2o`0000Oooooo0_l0000[ooooo`;o00001?ooool2o`0004Wooooo0_l0000ioooo
o`007_ooool00ol0003oooooooooo`0<ooooo`;o00002Oooool2o`0006cooooo0_l00007ooooo`;o
0000<Oooool2o`0004Wooooo0_l0000iooooo`007_ooool00ol0003oooooooooo`0Wooooo`;o0000
Coooool2o`000<gooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l0001?ooooo`;o0000cOoo
ool001kooooo00?o0000ooooooooool0R_ooool2o`0001cooooo0_l0002Mooooo`007_ooool00ol0
003oooooooooo`0Sooooo`;o00009_ooool2o`0000Gooooo0_l0000fooooo`;o00007?ooool2o`00
02Oooooo0_l0001dooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o00009_ooool2o`0000Go
oooo0_l00008ooooo`;o0000Loooool2o`0007Cooooo000Nooooo`;o0000EOooool2o`0000Kooooo
0_l0003Yooooo`007_ooool00ol0003oooooooooo`1Dooooo`;o0000lOooool001kooooo00?o0000
ooooooooool0boooool2o`0005_ooooo0_l0000Mooooo`007_ooool00ol0003oooooooooo`0loooo
o`;o0000SOooool2o`0003Sooooo0_l0000Pooooo`?o00004_ooool2o`0000Wooooo000Nooooo`03
o`000?oooooooooo03cooooo0_l0000Jooooo`;o0000Zoooool2o`00023ooooo0_l0000Cooooo`;o
00002Oooool001kooooo00?o0000ooooooooool08oooool2o`0002oooooo0_l00002ooooo`;o0000
GOooool2o`0008kooooo000Nooooo`03o`000?oooooooooo02?ooooo0_l0000_ooooo`;o00005Ooo
ool2o`0004[ooooo0_l00002ooooo`;o00004Oooool2o`0003Cooooo0_l0000cooooo`;o00003?oo
ool001kooooo00?o0000ooooooooool0Joooool2o`0004kooooo0_l0000Aooooo`;o0000=?ooool2
o`0000Oooooo0_l0000Zooooo`;o00003?ooool001kooooo00?o0000ooooooooool0F?ooool2o`00
0;7ooooo1?l0000hooooo`007_ooool00ol0003oooooooooo`1Hooooo`;o0000/Oooool2o`0003[o
oooo000Nooooo`03o`000?oooooooooo03cooooo0_l00016ooooo`;o0000;oooool2o`00093ooooo
000Nooooo`03o`000?oooooooooo03cooooo0_l0000Booooo`;o00002?ooool2o`0002Sooooo0_l0
000;ooooo`;o00008_ooool2o`00093ooooo000Nooooo`03o`000?oooooooooo053ooooo0_l00008
ooooo`;o0000=Oooool2o`0000gooooo0_l0002Mooooo`;o00001_ooool001kooooo00?o0000oooo
ooooool0N?ooool2o`0002Kooooo0_l00015ooooo`;o0000E_ooool2o`0000Kooooo0003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo
053ooooo0_l0000Jooooo`?o00002Oooool2o`0002Kooooo0_l0000booooo`;o00001oooool2o`00
00Sooooo0_l0001Nooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1@ooooo`;o00001?ooool2
o`0001Cooooo0ol00016ooooo`;o00005Oooool2o`0000Kooooo0_l00007ooooo`;o00000oooool2
o`0006?ooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP07
ooooo`?o0000E_ooool2o`0000[ooooo0_l0001Aooooo`;o00005Oooool2o`0001Cooooo0_l00010
ooooo`;o00008Oooool000?ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^00Kooooo00?o0000ooooooooool07oooool2o`0000cooooo0_l0000cooooo`;o0000P?ooool2
o`0003kooooo0_l0000Qooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMg
ofIVI_ooool01Oooool00ol0003oooooooooo`0Oooooo`;o00003?ooool2o`00033ooooo0_l00020
ooooo`;o000000?oooooo`000?l00000HOooool000?ooooo00Go410@oooooooooooooooooa0@400?
ooooo`03o`000?oooooooooo00Cooooo0ol0001Oooooo`;o000000?oooooo`000?l00000OOooool2
o`0000;ooooo0_l0001Pooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000
okZj^_ooooooV9RHoa0@4006ooooo`?o0000H_ooool2o`0002?ooooo0_l00018ooooo`;o00004_oo
ool2o`00043ooooo0_l0000Nooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo08Oooooo0_l0000dooooo`;o0000
4_ooool2o`0005Cooooo0_l0000Nooooo`007_ooool00ol0003oooooooooo`1dooooo`;o0000;?oo
ool2o`0001Wooooo0_l0000Qooooo`;o0000IOooool001kooooo00?o0000ooooooooool0M?ooool2
o`0002cooooo0_l0000looooo`;o0000?_ooool2o`0002Gooooo000Nooooo`;o0000;_ooool2o`00
05cooooo0_l0000=ooooo`;o0000:Oooool2o`0004Cooooo0_l0000Cooooo`;o00009Oooool001ko
oooo0_l0000Wooooo`;o00001Oooool2o`0000[ooooo0_l0000Rooooo`;o0000;?ooool2o`0000;o
oooo0_l00009ooooo`;o0000:Oooool2o`0000Cooooo0_l0000Booooo`;o0000:_ooool2o`0000?o
oooo0ol0000Tooooo`;o00003_ooool001kooooo00?o0000ooooooooool09_ooool2o`00017ooooo
0_l0000Rooooo`;o0000<?ooool2o`0001oooooo0_l0000Iooooo`;o00004_ooool2o`0002oooooo
0ol0000Tooooo`;o00003_ooool001kooooo00?o0000ooooooooool0/?ooool2o`0001cooooo0_l0
000/ooooo`;o0000BOooool001kooooo00?o0000ooooooooool0HOooool2o`0006_ooooo0_l0000/
ooooo`;o0000BOooool001kooooo00?o0000ooooooooool0HOooool2o`000>Cooooo000Nooooo`03
o`000?oooooooooo00oooooo0_l0001Yooooo`;o0000QOooool2o`00027ooooo0_l0000Qooooo`00
7_ooool00ol0003oooooooooo`0?ooooo`;o00001oooool2o`0003[ooooo0_l0000Eooooo`;o0000
3Oooool2o`0004[ooooo0_l00007ooooo`;o0000<?ooool2o`0001gooooo0_l00002ooooo`;o0000
8Oooool001kooooo00?o0000ooooooooool06?ooool2o`00013ooooo0_l00005ooooo`;o00008Ooo
ool2o`0000Sooooo0_l0000;ooooo`;o00002_ooool2o`0002;ooooo0_l0000Yooooo`;o00001ooo
ool2o`0001_ooooo0_l0000[ooooo`;o00001Oooool2o`0002Gooooo000Nooooo`;o0000:oooool2
o`0000Gooooo0_l0000[ooooo`;o00005oooool2o`0001gooooo0_l00003ooooo`;o00001Oooool2
o`0002;ooooo0_l0000Tooooo`;o0000:oooool2o`0002cooooo000Nooooo`03o`000?oooooooooo
06oooooo0_l0000Iooooo`;o00002_ooool2o`0000[ooooo0_l0000Rooooo`;o00007Oooool2o`00
063ooooo000Nooooo`03o`000?oooooooooo03cooooo0_l0000aooooo`;o00006Oooool2o`0004[o
oooo0_l0000=ooooo`;o0000D?ooool2o`0000kooooo000Nooooo`03o`000?oooooooooo03cooooo
0_l0002Hooooo`;o0000Goooool4o`0000cooooo000Nooooo`03o`000?oooooooooo013ooooo0_l0
0009ooooo`;o0000oooooolMooooo`;o00003?ooool001kooooo00?o0000ooooooooool04?ooool2
o`0000Cooooo0_l00003ooooo`;o0000>Oooool2o`0001Kooooo0_l0000Wooooo`;o00007?ooool2
o`00093ooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0000<ooooo`;o00004oooool2o`00
02Wooooo0_l00006ooooo`;o00003_ooool2o`0000Sooooo0_l0000Mooooo`;o00007?ooool2o`00
00Cooooo0_l0001Zooooo`;o00005?ooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo00So
oooo0_l0000Qooooo`;o0000<Oooool2o`0001Sooooo0_l00011ooooo`;o0000>oooool2o`0002go
oooo0_l0000Dooooo`;o00002?ooool001kooooo00?o0000ooooooooool02?ooool2o`0004Sooooo
0_l0000Booooo`;o0000;_ooool2o`00063ooooo0_l0000oooooo`;o00003?ooool001kooooo00Co
0000ooooool0003o0000DOooool2o`0001;ooooo0_l0000Dooooo`;o00006?ooool2o`0001_ooooo
0_l0000Sooooo`?o00000_ooool2o`0001?ooooo0_l0000mooooo`;o00001_ooool2o`0000cooooo
000Nooooo`04o`000?oooooo0000o`0002Oooooo0_l00005ooooo`;o00008Oooool2o`0002Sooooo
0_l0000Xooooo`;o00001Oooool2o`0000Cooooo0_l0000Sooooo`?o00000_ooool2o`0000oooooo
0_l00002ooooo`;o0000?Oooool2o`0001Cooooo000Nooooo`03o`000?oooooooooo02Sooooo0_l0
0005ooooo`;o0000AOooool2o`0002kooooo0_l00005ooooo`;o0000;_ooool2o`0000oooooo0_l0
001Gooooo`007_ooool00ol0003oooooooooo`17ooooo`;o00007Oooool2o`0000kooooo0_l0003?
ooooo`007_ooool00ol0003oooooooooo`17ooooo`;o00007Oooool2o`00073ooooo0_l0000boooo
o`;o0000>Oooool001kooooo00?o0000ooooooooool0f?ooool2o`0003;ooooo0_l0000iooooo`00
7_ooool00ol0003oooooooooo`2;ooooo`;o0000@?ooool2o`0007Sooooo000Nooooo`;o0000S?oo
ool2o`0003Kooooo0_l00008ooooo`;o0000N?ooool001kooooo00?o0000ooooooooool0Hoooool2
o`0000[ooooo0_l0000`ooooo`;o00000_ooool2o`0000Kooooo0_l0000Dooooo`;o0000A?ooool2
o`0003cooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0000@ooooo`?o00006?ooool2o`00
02_ooooo0_l0000:ooooo`;o0000<?ooool2o`0000;ooooo0_l00006ooooo`;o0000E_ooool2o`00
00;ooooo0_l0000looooo`007_ooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`00013o
oooo0ol0000Hooooo`;o00002?ooool2o`000<?ooooo0_l00010ooooo`007_ooool00ol0003ooooo
ooooo`03ooooo`;o00002Oooool2o`00033ooooo0_l0001Sooooo`;o00007?ooool2o`0008;ooooo
000Nooooo`03o`000?oooooooooo00kooooo0_l0000gooooo`;o0000G?ooool2o`0001cooooo0_l0
000<ooooo`;o0000M?ooool001kooooo00Co0000oooooooooooooooo0_l00014ooooo`?o0000Qooo
ool2o`0007Cooooo000Nooooo`04o`000?ooooooooooooooo`;o0000AOooool2o`000?gooooo000N
ooooo`04o`000?ooooooooooooooo`;o00009oooool2o`0004Kooooo0_l0000?ooooo`;o0000<Ooo
ool2o`0004cooooo0_l00004ooooo`;o00001oooool2o`0003;ooooo000Nooooo`03o`000?oooooo
oooo02[ooooo0_l0000Aooooo`;o0000<oooool2o`000003ooooool0003o000000cooooo0_l0000a
ooooo`;o0000@oooool2o`0000Oooooo0_l00004ooooo`;o00001oooool2o`0001?ooooo0_l0000<
ooooo`;o00003oooool001kooooo00?o0000ooooooooool0?Oooool2o`0003Kooooo0_l0001`oooo
o`;o00004_ooool2o`0002_ooooo0_l00005ooooo`;o000000?oooooo`000?l000000_ooool2o`00
00oooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0000aooooo`;o0000>oooool2o`0003Oo
oooo0_l0000Iooooo`;o00005_ooool2o`000003ooooool0003o000001gooooo0_l0000Wooooo`;o
000000Coooooo`000?l0003ooooo0_l0000@ooooo`007_ooool00ol0003oooooooooo`08ooooo`;o
0000<Oooool2o`0003_ooooo0_l0000gooooo`;o00006Oooool2o`0001Kooooo0_l0000Pooooo`;o
000000?oooooo`000?l000009oooool2o`000003ooooool0003o0000013ooooo000Nooooo`03o`00
0?oooooooooo033ooooo0_l0002@ooooo`;o0000AOooool2o`0000Kooooo0_l0000dooooo`007_oo
ool00ol0003oooooooooo`02o`0002kooooo0_l0000oooooo`;o0000Coooool2o`0004gooooo0_l0
000dooooo`007_ooool00ol0003oooooooooo`02o`0006oooooo0_l0000gooooo`;o0000Voooool0
01kooooo0_l000000ooooooo0000o`00002Xooooo`;o0000LOooool2o`0002Sooooo000Nooooo`;o
0000Ioooool2o`0006kooooo0_l00015ooooo`;o00006?ooool2o`0000kooooo000Nooooo`;o0000
Ioooool2o`0006Sooooo0_l00004ooooo`;o00002_ooool2o`0005?ooooo0_l0000>ooooo`007_oo
ool00ol0003oooooooooo`2Mooooo`;o0000<Oooool2o`00013ooooo0_l0001Sooooo`007_ooool0
0ol0003oooooooooo`0Oooooo`;o0000@Oooool2o`0003Wooooo0_l0000^ooooo`;o0000:Oooool2
o`0000[ooooo0_l00003ooooo`;o0000=?ooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo
01oooooo0_l00011ooooo`;o0000G_ooool2o`0000Wooooo0_l0000Yooooo`;o00002_ooool2o`00
00?ooooo0_l0000dooooo`;o00001_ooool001kooooo00?o0000ooooooooool0`_ooool2o`0000ko
oooo0_l0001Cooooo`;o00005_ooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo0=;ooooo
0_l0000Nooooo`;o00003Oooool2o`0002Cooooo0ol0000Mooooo`007_ooool00ol0003ooooooooo
o`17ooooo`;o0000?Oooool2o`0001oooooo0_l00019ooooo`;o00002_ooool2o`000003ooooool0
003o000000cooooo0_l0000Gooooo`;o00007Oooool001kooooo00?o0000ooooooooool0Aoooool2
o`0003gooooo0_l000000ooooooo0000o`00000Looooo`;o0000BOooool2o`0000[ooooo0_l0000?
ooooo`;o0000=_ooool001kooooo00?o0000ooooooooool0<_ooool2o`0005Gooooo0_l0000:oooo
o`;o0000Foooool2o`0004Cooooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`0booooo`;o
0000E?ooool2o`0000_ooooo0_l0000Jooooo`;o0000OOooool2o`0000Kooooo0_l0000=ooooo`00
7_ooool00ol0003oooooooooo`0Dooooo`;o00006oooool2o`00017ooooo0_l00012ooooo`;o0000
5_ooool3o`0000kooooo1?l0001kooooo`;o00005Oooool001kooooo00?o0000ooooooooool05?oo
ool2o`0001_ooooo0_l0000Aooooo`;o00009Oooool2o`0003?ooooo0ol0000@ooooo`;o00004?oo
ool2o`0003Oooooo0_l0000Pooooo`;o00009Oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0Hooo
ool2o`0000Kooooo0_l0000Pooooo`;o00007Oooool2o`0000kooooo0_l00007ooooo`;o0000=ooo
ool2o`0001Wooooo0_l000000ooooooo0000o`000002ooooo`;o00009Oooool000?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo06?ooooo0_l0000Xooooo`;o00007Oooool2o`0000kooooo0_l0001Kooooo`;o000000?o
ooooo`000?l00000:Oooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001_oo
ool3o`0006;ooooo0_l0000<ooooo`;o0000;?ooool2o`0000kooooo0_l00005ooooo`;o00008Ooo
ool2o`0001Cooooo0_l0001Gooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00001oooool00ol0003oooooooooo`0Jooooo`;o00001oooool2o`0003gooooo
0_l0000:ooooo`Co0000;?ooool3o`0000gooooo0_l00005ooooo`;o00008Oooool2o`0001Cooooo
0_l0000booooo`;o00008oooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgM
gOmEEEGoooooo`0000Oooooo00?o0000ooooooooool06_ooool2o`0000Oooooo0_l00019ooooo`;o
0000;oooool4o`0000Sooooo0_l0001eooooo`;o00008oooool000?ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0XOooool2o`0000So
oooo0_l0002Jooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l0
00001oooool00ol0003oooooooooo`2`ooooo`;o00007?ooool2o`0000Kooooo0_l0001_ooooo`00
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003o
ooooooooo`14ooooo`;o0000=?ooool2o`0002;ooooo0_l0000@ooooo`;o00005Oooool2o`0000Go
oooo0_l00006ooooo`;o0000Koooool001kooooo00?o0000ooooooooool0A?ooool2o`0000kooooo
0_l0000Tooooo`;o00002Oooool2o`0001Oooooo0_l0000Wooooo`;o0000O_ooool001kooooo00Co
0000oooooooooooooooo0_l0001Aooooo`;o0000;oooool2o`000<3ooooo000Nooooo`04o`000?oo
ooooooooooooo`;o0000;oooool2o`0002;ooooo0_l0000>ooooo`;o00002_ooool2o`0000;ooooo
0_l0000>ooooo`;o0000COooool2o`00073ooooo000Nooooo`03o`000?oooooooooo03;ooooo0_l0
000Rooooo`;o00003_ooool2o`0000[ooooo0_l00002ooooo`;o00003_ooool2o`0000Sooooo0_l0
0013ooooo`;o00002?ooool2o`0001[ooooo0_l0001:ooooo`007_ooool00ol0003oooooooooo`0^
ooooo`;o0000A_ooool2o`0001Gooooo0_l000000ooooooo0000o`00001=ooooo`;o00006_ooool2
o`0001;ooooo0_l00009ooooo`;o00005Oooool2o`0001Cooooo000Nooooo`03o`000?oooooooooo
02kooooo0_l00003ooooo`;o0000@Oooool2o`0001Gooooo0_l0001Gooooo`;o00009oooool2o`00
00Wooooo0_l0000Eooooo`;o00005?ooool001kooooo00?o0000ooooooooool0<oooool2o`0001_o
oooo0_l0001oooooo`;o00004oooool2o`0005Oooooo0_l00006ooooo`007_ooool00ol0003ooooo
ooooo`1@ooooo`;o0000@oooool2o`0003[ooooo0_l00003ooooo`;o00007Oooool2o`000003oooo
ool0003o000004Gooooo0_l00006ooooo`007_ooool01?l0003oooooo`000?l0002Dooooo`;o0000
=_ooool2o`0000Oooooo0_l0000Mooooo`;o000000?oooooo`000?l00000<_ooool2o`0000Gooooo
0_l0000Booooo`007_ooool01?l0003oooooo`000?l0000>ooooo`;o00005oooool2o`00053ooooo
0_l0001;ooooo`;o00001?ooool2o`0005gooooo0_l00005ooooo`;o00004_ooool001kooooo00?o
0000ooooooooool01?ooool2o`0000Wooooo0_l0000Fooooo`?o00002?ooool2o`0001Oooooo0_l0
0006ooooo`;o00009Oooool2o`0004_ooooo0_l00008ooooo`;o0000M?ooool001kooooo0_l00005
ooooo`;o00008Oooool2o`0000Wooooo0_l00008ooooo`;o00003Oooool2o`0000Kooooo0_l0001l
ooooo`;o0000J?ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo03cooooo0_l0000`oooo
o`;o0000C?ooool2o`00033ooooo0_l0001;ooooo`;o00002_ooool001kooooo00?o0000oooooooo
ool0K_ooool2o`0004cooooo0_l0000`ooooo`;o00000_ooool2o`0005?ooooo000Nooooo`03o`00
0?oooooooooo0>_ooooo0_l00005ooooo`;o00008_ooool2o`0000gooooo0_l0000Pooooo`007_oo
ool00ol0003oooooooooo`11ooooo`;o00009?ooool2o`0004Oooooo0_l0000iooooo`;o0000:Ooo
ool2o`0000gooooo0_l0000@ooooo`;o00003_ooool001kooooo00?o0000ooooooooool0@Oooool2
o`0002Cooooo0_l000000ooooooo0000o`000014ooooo`;o00001_ooool2o`0001gooooo0_l0000C
ooooo`;o0000=Oooool2o`0001;ooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`1Joooo
o`;o00001oooool2o`0000Gooooo0_l0001<ooooo`;o00007Oooool3o`0001;ooooo0_l0000@oooo
o`;o00001?ooool2o`0001gooooo0_l0000Rooooo`007_ooool00ol0003oooooooooo`1Jooooo`;o
00001oooool2o`0007?ooooo0_l0000Tooooo`;o00001?ooool2o`0001?ooooo0_l00009ooooo`;o
00008Oooool001kooooo00?o0000ooooooooool0oooooolJooooo`;o00002Oooool2o`00027ooooo
000Nooooo`03o`000?oooooooooo02;ooooo0_l0000<ooooo`;o0000oooooolFooooo`007_ooool0
0ol0003oooooooooo`0Pooooo`Co00003?ooool2o`0002Wooooo0ol00007ooooo`;o0000>_ooool2
o`00013ooooo0_l00007ooooo`;o0000Foooool2o`0002cooooo000Nooooo`03o`000?oooooooooo
023ooooo0_l0000Qooooo`;o00005_ooool3o`0000Oooooo0_l0000jooooo`;o00004?ooool2o`00
00Oooooo0_l00004ooooo`;o00003Oooool2o`0004Kooooo0_l00008ooooo`;o00008_ooool001ko
oooo00?o0000ooooooooool0<?ooool2o`00017ooooo0_l0001mooooo`;o00003Oooool2o`0000_o
oooo0_l00013ooooo`;o00008_ooool001kooooo00?o0000ooooooooool0:_ooool2o`0000Cooooo
0_l0000Iooooo`;o0000TOooool2o`0006Oooooo000Nooooo`03o`000?oooooooooo02[ooooo0_l0
000Oooooo`;o0000Boooool3o`0002Cooooo0_l0000Looooo`;o0000J?ooool001kooooo00?o0000
ooooooooool0AOooool2o`0001[ooooo0_l0000Rooooo`;o00004Oooool3o`0001_ooooo0_l00007
ooooo`;o00007?ooool2o`0002Kooooo0_l00010ooooo`007_ooool2o`0000gooooo0_l0000=oooo
o`;o0000:?ooool2o`0001[ooooo0_l00003ooooo`;o00007Oooool2o`0000kooooo0_l0000Ooooo
o`;o0000COooool2o`00043ooooo000Nooooo`03o`000?oooooooooo00cooooo0_l0000=ooooo`;o
00008_ooool2o`0002Gooooo0_l00008ooooo`;o00008oooool2o`0007_ooooo0_l0000cooooo`00
7_ooool00ol0003oooooooooo`0Mooooo`;o00008?ooool2o`0002oooooo0_l00026ooooo`;o0000
6?ooool2o`0001cooooo0_l0000Eooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o0000T_oo
ool2o`0004Gooooo0_l0000fooooo`;o00005Oooool001kooooo00?o0000ooooooooool0/Oooool2
o`0009Cooooo000Nooooo`03o`000?oooooooooo01?ooooo0_l0000Looooo`;o0000X?ooool2o`00
02Oooooo0_l00019ooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o00007?ooool2o`00067o
oooo0_l0000mooooo`;o00009oooool2o`0004Wooooo000Nooooo`03o`000?oooooooooo07?ooooo
0_l0000Oooooo`;o0000A_ooool2o`0000?ooooo0_l000000ooooooo0000o`00001Qooooo`007_oo
ool00ol0003oooooooooo`0Booooo`;o0000Foooool2o`0000;ooooo0_l00006ooooo`;o0000Gooo
ool3o`0000;ooooo0_l000000ooooooo0000o`00000;ooooo`;o0000E?ooool001kooooo00?o0000
ooooooooool04_ooool2o`00053ooooo0_l00009ooooo`;o00002_ooool2o`00063ooooo0_l0000B
ooooo`;o00003_ooool2o`0004Cooooo000Nooooo`03o`000?oooooooooo02Sooooo0_l0000Joooo
o`;o00007_ooool2o`0006Oooooo0_l0000Hooooo`;o00004oooool2o`0000?ooooo0_l0000goooo
o`;o00002oooool001kooooo00?o0000ooooooooool07Oooool2o`0000Wooooo0_l0000Jooooo`;o
0000C?ooool2o`0003Wooooo0_l0000Hooooo`;o00002oooool2o`0000Kooooo0_l0000looooo`;o
00002oooool001kooooo00?o0000ooooooooool07Oooool2o`0007?ooooo0_l0000Aooooo`;o0000
COooool2o`00057ooooo000Nooooo`03o`000?oooooooooo03Gooooo0_l0000gooooo`;o00005Ooo
ool2o`0000kooooo0_l0000>ooooo`;o00003Oooool2o`0007_ooooo0_l0000Dooooo`007_ooool0
0ol0003oooooooooo`0Zooooo`;o00002Oooool2o`0003Oooooo0_l00006ooooo`;o00001?ooool2
o`0000Oooooo0_l0000>ooooo`;o00007Oooool4o`0005Gooooo0_l0000Rooooo`;o00005?ooool0
01kooooo00Co0000ooooool0003o0000:Oooool2o`0004[ooooo0_l00004ooooo`;o00000oooool2
o`0003?ooooo0_l0001Eooooo`;o0000>?ooool001kooooo1?l0000Vooooo`;o0000F?ooool2o`00
05Cooooo0_l0000Sooooo`;o0000BOooool001kooooo00?o0000ooooooooool09oooool2o`0001Oo
oooo0_l00007ooooo`;o00000oooool2o`0008Oooooo0_l0000Sooooo`;o0000=oooool2o`0000Ko
oooo0_l00008ooooo`007_ooool00ol0003oooooooooo`10ooooo`;o00001oooool2o`0000?ooooo
0_l0001Uooooo`;o0000@oooool2o`0003Wooooo0_l00006ooooo`;o00002?ooool001kooooo00?o
0000ooooooooool0]Oooool2o`0000Kooooo0_l0000Pooooo`;o00003_ooool2o`0000Wooooo0_l0
0011ooooo`;o00002?ooool001kooooo00?o0000ooooooooool03_ooool2o`0000kooooo0_l0000Q
ooooo`;o00006Oooool2o`0005oooooo0_l0000Pooooo`;o00003_ooool2o`00023ooooo0_l0000d
ooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o00003_ooool2o`00027ooooo0_l0000Ioooo
o`;o00007_ooool2o`0003Gooooo0_l0001Looooo`;o00001oooool2o`0002_ooooo000Nooooo`03
o`000?oooooooooo07cooooo0_l0000Pooooo`;o00004oooool2o`0003Cooooo0_l0000[ooooo`;o
00000_ooool2o`0002_ooooo000Nooooo`03o`000?oooooooooo01gooooo0_l0001oooooo`;o0000
1oooool2o`00043ooooo0_l0000Hooooo`;o00004Oooool2o`0000cooooo0_l0000>ooooo`;o0000
4Oooool001kooooo00?o0000ooooooooool07Oooool2o`0008Sooooo0_l0001Jooooo`;o00007ooo
ool2o`0000?ooooo0_l00009ooooo`;o00004Oooool001kooooo00?o0000ooooooooool0Woooool2
o`0002;ooooo0_l0000Qooooo`;o0000;oooool2o`00013ooooo0_l0000Looooo`007_ooool00ol0
003oooooooooo`0Aooooo`;o0000=_ooool2o`0005Cooooo0_l0000Rooooo`;o00008Oooool2o`00
02oooooo0_l0000^ooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o0000=_ooool2o`0002?o
oooo0_l000000ooooooo0000o`000019ooooo`;o00008_ooool2o`0004gooooo0_l0000Fooooo`00
7_ooool00ol0003oooooooooo`1^ooooo`;o000000?oooooo`000?l00000BOooool2o`0002;ooooo
0_l0001=ooooo`;o00005_ooool001kooooo00?o0000ooooooooool0>oooool2o`0007[ooooo0_l0
002>ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0kooooo`;o00008Oooool2o`0003cooooo
0_l0000Iooooo`;o00009_ooool2o`0003Gooooo0_l0000Cooooo`;o00006_ooool000?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Ko
oooo00?o0000ooooooooool0AOooool2o`0001Oooooo0_l0000?ooooo`;o0000:oooool2o`0000?o
oooo0_l0000looooo`;o0000=Oooool2o`0001?ooooo0_l0000Booooo`;o00001_ooool000?ooooo
00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`00
04Gooooo0_l0000Gooooo`;o00003oooool2o`0001kooooo0_l0000@ooooo`;o0000:?ooool2o`00
07;ooooo0_l00006ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRH
V?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo07?ooooo0_l0000Jooooo`;o00004?ooool2
o`0000oooooo0_l0000Gooooo`;o00001oooool2o`0000?ooooo0_l0000Uooooo`;o0000AOooool0
00?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_oo
ool00ol0003oooooooooo`0iooooo`;o00001_ooool2o`00033ooooo0_l0000Uooooo`;o00001Ooo
ool2o`0000oooooo0_l0000Pooooo`;o00000oooool2o`0002Gooooo0_l00015ooooo`000oooool0
1Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003ooooooooo
o`0iooooo`;o00001_ooool2o`0001gooooo0_l000000ooooooo0000o`00000?ooooo`;o00009?oo
ool2o`0003kooooo0_l0000Mooooo`;o00009_ooool2o`0002Cooooo0003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo063ooooo0_l0
00000ooooooo0000o`00000?ooooo`Co0000H_ooool2o`0001gooooo0_l0000Vooooo`;o00004_oo
ool2o`00013ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`00
0?l@4106ooooo`03o`000?oooooooooo02Kooooo0_l0000Iooooo`;o00003?ooool2o`0001[ooooo
0_l00009ooooo`;o0000OOooool2o`0000oooooo0_l0000]ooooo`;o00004?ooool001kooooo00?o
0000ooooooooool09_ooool2o`0001Wooooo0_l0000<ooooo`;o00006_ooool2o`0006[ooooo0_l0
000Looooo`;o00003oooool2o`0001Oooooo0_l0000Vooooo`007_ooool00ol0003oooooooooo`02
o`0000Gooooo0_l0001Booooo`;o0000F?ooool2o`00023ooooo0_l0000Aooooo`;o00007_ooool2
o`0001?ooooo0_l0000Vooooo`007_ooool00ol0003oooooooooo`02o`0000Gooooo0_l0000Hoooo
o`;o0000<_ooool2o`0000Cooooo0_l0001=ooooo`;o00002Oooool2o`0001?ooooo0_l0000Noooo
o`;o00007_ooool2o`0002_ooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`0Qooooo`;o
0000<_ooool2o`0001Sooooo0_l0000iooooo`;o00007_ooool2o`0005gooooo0_l0000<ooooo`?o
00003Oooool001kooooo00?o0000ooooooooool03_ooool2o`0000[ooooo0_l0000@ooooo`;o0000
2_ooool2o`0000[ooooo0_l0000Yooooo`;o0000K_ooool2o`0004Sooooo0_l0000=ooooo`;o0000
3Oooool001kooooo00?o0000ooooooooool03_ooool2o`0000[ooooo0_l000000ooooooo0000o`00
0007ooooo`;o00001?ooool2o`0000[ooooo0_l0000:ooooo`;o0000:?ooool2o`0006oooooo0_l0
001Vooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o00001oooool2o`00017ooooo0_l0000D
ooooo`;o00007Oooool2o`0005Gooooo0_l00014ooooo`;o00002?ooool2o`0000Cooooo0_l00008
ooooo`;o00008?ooool001kooooo00?o0000ooooooooool0>Oooool2o`0001Cooooo0_l0001Xoooo
o`;o00002_ooool2o`0001Sooooo0_l00003ooooo`;o00009Oooool2o`0000Sooooo0_l00004oooo
o`;o00002?ooool2o`0001Oooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`2/ooooo`;o
00002oooool2o`0001cooooo0_l00003ooooo`;o000000?oooooo`000?l000000oooool2o`0005So
oooo0_l00007ooooo`007_ooool00ol0003oooooooooo`0Tooooo`;o00009Oooool2o`0005oooooo
0_l00002ooooo`;o00009Oooool2o`0000?ooooo0_l0000Hooooo`;o0000=oooool2o`0000Gooooo
0_l0000?ooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o00002oooool2o`0000Oooooo0_l0
000Hooooo`;o00002oooool2o`0000Wooooo0_l0001Hooooo`;o0000A?ooool2o`0000[ooooo0_l0
000:ooooo`;o00007oooool3o`0000Cooooo0_l0000?ooooo`007_ooool2o`0000oooooo0_l0000;
ooooo`;o00008Oooool2o`0001Kooooo0_l0002Zooooo`;o00002_ooool2o`00023ooooo0_l0000E
ooooo`007_ooool00ol0003oooooooooo`1Aooooo`;o0000<oooool2o`000:kooooo0_l0000?oooo
o`007_ooool00ol0003oooooooooo`1Aooooo`;o0000<oooool2o`0001?ooooo0_l0000Booooo`;o
0000QOooool2o`0000oooooo000Nooooo`03o`000?oooooooooo09_ooooo0_l0000=ooooo`;o0000
0oooool2o`0002_ooooo0_l0001Yooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o0000O_oo
ool2o`0001Oooooo0_l0000`ooooo`;o00006Oooool2o`0000_ooooo0_l00011ooooo`007_ooool0
0ol0003oooooooooo`0Aooooo`;o0000O_ooool2o`0003Oooooo0_l0000[ooooo`;o00002oooool2
o`00047ooooo000Nooooo`03o`000?oooooooooo0<7ooooo0_l00007ooooo`;o00001Oooool2o`00
00_ooooo0_l0001;ooooo`;o00006_ooool001kooooo00?o0000ooooooooool0IOooool2o`0001Ko
oooo0_l00012ooooo`;o00003_ooool2o`0000_ooooo0_l0001;ooooo`;o00006_ooool001kooooo
00?o0000ooooooooool0IOooool2o`0001Kooooo0_l0000Qooooo`;o0000=oooool2o`0004[ooooo
0_l0000Pooooo`007_ooool00ol0003oooooooooo`03ooooo`;o0000Voooool2o`0001Wooooo0_l0
000Looooo`;o00009Oooool2o`0002?ooooo0_l0000Pooooo`007_ooool00ol0003oooooooooo`03
ooooo`;o0000O_ooool2o`0003Kooooo0_l00013ooooo`;o0000AOooool001kooooo00?o0000oooo
ooooool09?ooool2o`00053ooooo0_l0000;ooooo`;o0000`_ooool001kooooo00?o0000oooooooo
ool09?ooool2o`00053ooooo0_l0003?ooooo`007_ooool00ol0003oooooooooo`0Looooo`;o0000
hOooool2o`00027ooooo0_l0000Sooooo`007_ooool00ol0003oooooooooo`0Looooo`;o0000:?oo
ool2o`0004Gooooo0_l0001`ooooo`;o00008Oooool2o`0002?ooooo000Nooooo`03o`000?oooooo
oooo013ooooo0_l0000Iooooo`;o00006Oooool2o`0000kooooo0_l0000eooooo`;o0000^?ooool0
01kooooo0_l0000Aooooo`;o00006Oooool2o`0002Wooooo0_l0003Aooooo`;o00007?ooool001ko
oooo00?o0000ooooooooool01?ooool2o`0004Gooooo0ol0000@ooooo`;o0000Ooooool2o`0004So
oooo0_l0000Looooo`007_ooool00ol0003oooooooooo`04ooooo`;o0000AOooool3o`0000Cooooo
0_l0000:ooooo`;o0000E?ooool2o`00023ooooo0_l00007ooooo`;o0000I_ooool001kooooo00?o
0000ooooooooool0<?ooool2o`00023ooooo0_l000000ooooooo0000o`00000Uooooo`;o0000=_oo
ool2o`00023ooooo0_l0001_ooooo`007_ooool00ol0003oooooooooo`0`ooooo`;o00007Oooool2
o`0000Cooooo0_l0000Oooooo`;o00001?ooool2o`0003Gooooo0_l0001Xooooo`;o00000oooool2
o`0002?ooooo000Nooooo`03o`000?oooooooooo03?ooooo0_l0000Jooooo`;o00009Oooool2o`00
03_ooooo0_l0001Jooooo`;o00003?ooool2o`0000?ooooo0_l0000Sooooo`007_ooool00ol0003o
ooooooooo`0cooooo`;o0000;?ooool2o`00067ooooo0_l0000Rooooo`;o00009Oooool2o`0003Ko
oooo000Nooooo`03o`000?oooooooooo067ooooo0_l0000dooooo`;o0000:oooool2o`0002;ooooo
0_l0001Mooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o0000QOooool2o`0005cooooo0_l0
001@ooooo`007_ooool00ol0003oooooooooo`0@ooooo`;o00002Oooool2o`0009kooooo0_l0000h
ooooo`;o0000<Oooool2o`0001gooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l00003oooo
o`;o00009oooool2o`0004;ooooo0_l0000Jooooo`;o00005Oooool2o`0006_ooooo0_l0000Moooo
o`007_ooool00ol0003oooooooooo`0Fooooo`;o00005oooool2o`0001?ooooo0_l00012ooooo`;o
00006_ooool2o`0007;ooooo0_l0000]ooooo`007_ooool00ol0003oooooooooo`0Vooooo`;o0000
1oooool2o`0000Gooooo0_l0001Rooooo`;o00006?ooool2o`0006;ooooo0_l0000]ooooo`007_oo
ool00ol0003oooooooooo`0Vooooo`;o000000?oooooo`000?l000002oooool2o`0002Kooooo0_l0
000Fooooo`;o00008_ooool2o`0001Sooooo0_l0002Aooooo`007_ooool00ol0003oooooooooo`0K
ooooo`;o00000_ooool2o`0000Sooooo0_l0000Rooooo`;o00003oooool2o`0001Kooooo0_l0001V
ooooo`;o0000Ioooool001kooooo00?o0000ooooooooool06oooool2o`0000;ooooo0_l0000/oooo
o`;o0000@oooool2o`0004[ooooo0_l0001Wooooo`007_ooool2o`00013ooooo0_l0001Wooooo`;o
00003Oooool2o`0000Wooooo0_l0002cooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o0000
Ioooool2o`0000Sooooo0_l00003ooooo`;o0000HOooool2o`0003Sooooo0_l0000Qooooo`007_oo
ool00ol0003oooooooooo`0Booooo`;o0000K_ooool2o`0003_ooooo0_l0000Yooooo`;o0000>?oo
ool2o`0000Oooooo0_l0000Hooooo`007_ooool00ol0003oooooooooo`0Booooo`;o00004Oooool2
o`0005Cooooo0_l0000dooooo`;o00003?ooool2o`0006cooooo0_l0000Hooooo`007Oooool2o`00
02Oooooo0_l00004ooooo`;o0000@Oooool2o`0000_ooooo0_l0000dooooo`;o0000U?ooool001go
oooo0_l0000]ooooo`;o0000@Oooool2o`00037ooooo0_l0001/ooooo`;o00007oooool2o`0001Go
oooo000Nooooo`;o0000>oooool2o`0006Gooooo0_l0000Oooooo`;o0000Boooool2o`0001oooooo
0_l0000Eooooo`007_ooool2o`0003_ooooo0_l0000Jooooo`;o0000J_ooool2o`0003Sooooo0_l0
0003ooooo`;o0000A?ooool001kooooo00?o0000ooooooooool0E_ooool2o`0001?ooooo0_l0002?
ooooo`?o00000_ooool2o`0004Cooooo000Nooooo`03o`000?oooooooooo06_ooooo0_l00002oooo
o`;o0000I_ooool2o`0002Cooooo0_l0000Looooo`;o0000:_ooool001kooooo00?o0000oooooooo
ool0HOooool2o`0000cooooo0_l0001Vooooo`;o0000@_ooool2o`0001?ooooo0_l0000Eooooo`00
7_ooool00ol0003oooooooooo`0>ooooo`;o0000C_ooool2o`000003ooooool0003o000003Gooooo
0_l0000cooooo`;o0000:Oooool2o`0003Kooooo0_l0000Eooooo`007_ooool00ol0003ooooooooo
o`0>ooooo`;o0000?oooool2o`0000gooooo0_l0000aooooo`;o00001Oooool2o`00017ooooo0_l0
000Pooooo`;o0000:Oooool2o`0000Wooooo0_l00012ooooo`007_ooool00ol0003oooooooooo`19
ooooo`;o00001?ooool2o`00043ooooo0_l0000Hooooo`;o0000E_ooool2o`0002oooooo0_l0000A
ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`19ooooo`Co00001?ooool2o`0005Sooooo0_l0
0027ooooo`;o00004Oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool02?ooool2o`0002;ooooo
0_l0000Mooooo`;o00001?ooool2o`0007gooooo0_l00002ooooo`;o0000LOooool000?ooooo00Go
410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`0000So
oooo0_l0000Rooooo`;o00006_ooool2o`0004Wooooo0_l0000kooooo`;o00000_ooool2o`0001;o
oooo0_l0000Xooooo`;o00002_ooool2o`0002Oooooo0003ooooo`05o`000?ooooooooooooooool0
00002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000ooooooooool0B?ooool2o`00
01Gooooo0_l0000booooo`;o0000Doooool2o`0002Sooooo0_l0000:ooooo`;o00001oooool2o`00
01kooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003o
c<c<00Kooooo00?o0000ooooooooool06?ooool2o`0004Gooooo0_l00036ooooo`;o00007_ooool0
00?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_oo
ool00ol0003oooooooooo`0<ooooo`;o00002_ooool2o`000?oooooo0Oooool2o`0002_ooooo0003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo
00?o0000ooooooooool03?ooool2o`0006gooooo0_l0002Mooooo`;o0000:oooool000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003o
ooooooooo`1kooooo`;o0000b_ooool001kooooo00?o0000ooooooooool0=_ooool2o`0005gooooo
0_l0002Jooooo`;o00005?ooool001kooooo00?o0000ooooooooool0=_ooool2o`0005gooooo0_l0
000fooooo`;o00008Oooool2o`0003oooooo0_l0000Dooooo`007_ooool00ol0003oooooooooo`2l
ooooo`;o00003oooool2o`0001kooooo0_l000000ooooooo0000o`00000Xooooo`;o0000:oooool0
01kooooo00?o0000ooooooooool0G_ooool2o`0002gooooo0_l0000Sooooo`;o00002?ooool2o`00
02oooooo0_l0000[ooooo`;o0000:oooool001kooooo00?o0000ooooooooool0@Oooool2o`0000Co
oooo0_l0000Eooooo`;o0000;Oooool2o`0002?ooooo0_l0002Cooooo`007_ooool00ol0003ooooo
ooooo`11ooooo`;o00001?ooool2o`00047ooooo0_l0001Gooooo`;o00000_ooool2o`0002kooooo
0_l0000^ooooo`007_ooool00ol0003oooooooooo`02ooooo`;o0000=?ooool2o`0003Wooooo0_l0
000Eooooo`;o0000Eoooool2o`0000;ooooo0_l0000@ooooo`;o00007?ooool2o`0001gooooo0_l0
000?ooooo`007_ooool00ol0003oooooooooo`02ooooo`;o0000=?ooool2o`0003Wooooo0_l00007
ooooo`;o0000Noooool2o`0003_ooooo0_l0000?ooooo`007_ooool00ol0003oooooooooo`0Noooo
o`;o0000;_ooool2o`0002cooooo0_l00039ooooo`007_ooool00ol0003oooooooooo`0Nooooo`;o
0000;_ooool2o`000?Oooooo000Nooooo`03o`000?oooooooooo04Cooooo0_l0000Pooooo`;o0000
1?ooool2o`00017ooooo0_l00009ooooo`;o0000Ooooool2o`0003[ooooo000Nooooo`;o00006_oo
ool2o`0002Wooooo0_l0000Pooooo`;o00001?ooool2o`00017ooooo0_l00009ooooo`;o0000=_oo
ool2o`0003Cooooo0_l0000<ooooo`;o00000oooool2o`0003[ooooo000Nooooo`03o`000?oooooo
oooo01Wooooo0_l0002Qooooo`;o00001?ooool2o`0003Cooooo0_l0000<ooooo`;o0000?oooool0
01kooooo00?o0000ooooooooool0>Oooool2o`0000oooooo0_l0001`ooooo`;o0000B?ooool2o`00
01gooooo0_l0000Pooooo`007_ooool00ol0003oooooooooo`0iooooo`;o00003oooool2o`0008Go
oooo0_l0001Booooo`;o00002Oooool2o`0001Gooooo000Nooooo`03o`000?oooooooooo0<_ooooo
0_l00004ooooo`;o0000=oooool2o`0002Cooooo0_l0000Eooooo`007_ooool00ol0003ooooooooo
o`3;ooooo`;o0000<Oooool2o`0000[ooooo0_l0000kooooo`007_ooool00ol0003oooooooooo`27
ooooo`;o0000MOooool2o`0004Oooooo000Nooooo`03o`000?oooooooooo00Gooooo0_l00020oooo
o`;o0000N?ooool2o`0000oooooo0_l0000cooooo`007_ooool00ol0003oooooooooo`05ooooo`;o
00009?ooool2o`0000?ooooo0_l0003?ooooo`;o00003oooool2o`0003?ooooo000Nooooo`03o`00
0?oooooooooo02_ooooo0_l00003ooooo`;o0000k_ooool2o`0002Gooooo000Nooooo`03o`000?oo
oooooooo00gooooo0_l0001>ooooo`;o0000<_ooool2o`0007Cooooo0_l0000Gooooo`;o00009Ooo
ool001kooooo00?o0000ooooooooool03Oooool2o`0004kooooo0_l0000booooo`;o0000M?ooool2
o`0001?ooooo0_l0000<ooooo`;o00002_ooool2o`0000oooooo000Nooooo`03o`000?oooooooooo
04gooooo0_l0001?ooooo`;o0000=Oooool2o`0004Gooooo0_l0000<ooooo`;o00002_ooool2o`00
00oooooo000Nooooo`03o`000?oooooooooo02oooooo0_l0000Looooo`;o0000Coooool2o`0003Go
oooo0_l0001`ooooo`007_ooool2o`00033ooooo0_l0001Wooooo`;o0000Coooool2o`0003kooooo
0_l00009ooooo`;o00004Oooool001kooooo0_l0000aooooo`;o0000I_ooool2o`0004oooooo0_l0
000Fooooo`;o00009_ooool2o`0000Wooooo0_l0000Aooooo`007_ooool2o`0000_ooooo0_l0000T
ooooo`;o0000`?ooool2o`0000gooooo0_l00006ooooo`;o00007oooool2o`0001_ooooo000Noooo
o`03o`000?oooooooooo00[ooooo0_l0000iooooo`;o0000N_ooool2o`0002oooooo0_l0000Eoooo
o`;o00007oooool2o`0001_ooooo000Nooooo`03o`000?oooooooooo04Gooooo0_l0001Iooooo`;o
00007oooool2o`0003Oooooo0ol0000_ooooo`;o00006Oooool001kooooo00?o0000ooooooooool0
X?ooool2o`0002;ooooo0_l0000dooooo`?o0000;oooool2o`0001Wooooo000Nooooo`03o`000?oo
oooooooo05cooooo0_l0000Qooooo`;o0000@oooool2o`00087ooooo000Nooooo`04o`000?oooooo
ooooooooo`;o0000FOooool2o`00027ooooo0_l0000Hooooo`;o0000=oooool2o`0001cooooo0_l0
001Eooooo`007_ooool01?l0003oooooooooooooool2o`0003Kooooo0_l0000Sooooo`;o0000>Ooo
ool2o`0001Gooooo0_l0000Pooooo`;o000000?oooooo`000?l000006Oooool2o`0005Gooooo000N
ooooo`03o`000?oooooooooo03Wooooo0_l0000Sooooo`;o00003_ooool2o`00043ooooo0_l0000;
ooooo`;o00005_ooool2o`00073ooooo000Nooooo`03o`000?oooooooooo05Oooooo0_l0000Eoooo
o`;o0000B_ooool2o`000003ooooool0003o000008Sooooo000Nooooo`03o`000?oooooooooo05Oo
oooo0_l0001Qooooo`;o0000Roooool001kooooo00?o0000ooooooooool0ooooool8ooooo`;o0000
?_ooool001kooooo00?o0000ooooooooool03oooool2o`0007Cooooo0_l00020ooooo`Co0000??oo
ool001kooooo00?o0000ooooooooool03oooool2o`0003Oooooo0_l0000kooooo`;o0000P_ooool2
o`0003cooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l00014ooooo`;o00003?ooool2o`00
01oooooo0_l0003>ooooo`007_ooool00ol0003oooooooooo`02ooooo`;o00002oooool2o`0003go
oooo0_l00006ooooo`;o00003Oooool2o`00013ooooo0_l0000Jooooo`;o0000/_ooool001kooooo
00?o0000ooooooooool03oooool2o`0003gooooo0_l0000;ooooo`;o00002?ooool2o`0002cooooo
0_l0001gooooo`;o00001_ooool2o`0002Wooooo0_l00006ooooo`007_ooool2o`0001[ooooo0_l0
0010ooooo`;o00005?ooool2o`0009Wooooo0_l00006ooooo`;o0000:Oooool2o`0000Kooooo000N
ooooo`03o`000?oooooooooo01Wooooo0_l0000Xooooo`;o0000;?ooool2o`000=Cooooo000Noooo
o`03o`000?oooooooooo00_ooooo0_l0000fooooo`;o0000Hoooool2o`0005gooooo0_l0000@oooo
o`;o00005Oooool2o`0001Gooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l0000Vooooo`;o
00005?ooool2o`0003Kooooo0_l0000Booooo`;o00004Oooool2o`0002Wooooo0_l0000booooo`;o
000000?oooooo`000?l000003Oooool2o`0000Gooooo0_l0000>ooooo`;o00005Oooool001kooooo
00?o0000ooooooooool0<oooool2o`0001Cooooo0_l0000Iooooo`;o00006oooool2o`0001;ooooo
0_l0000looooo`;o0000=Oooool2o`0001Cooooo0_l0000Fooooo`;o00003Oooool001kooooo00?o
0000ooooooooool0I?ooool2o`00057ooooo0_l0001Aooooo`;o00005_ooool2o`0001Cooooo0_l0
000=ooooo`007_ooool00ol0003oooooooooo`2gooooo`;o00004Oooool2o`0003kooooo0_l0000F
ooooo`;o00008oooool001kooooo00?o0000ooooooooool0Foooool2o`0006gooooo0_l0001koooo
o`007_ooool00ol0003oooooooooo`0Mooooo`;o0000??ooool2o`0003oooooo0_l0000aooooo`;o
00002?ooool2o`0001oooooo0_l0000Vooooo`;o00008oooool001kooooo00?o0000ooooooooool0
7Oooool2o`00073ooooo0_l0000;ooooo`;o0000<Oooool2o`0000Sooooo0_l0000Oooooo`;o0000
7oooool2o`0000Gooooo0_l0000Sooooo`007_ooool00ol0003oooooooooo`0dooooo`;o00008ooo
ool2o`0003Cooooo0_l0002:ooooo`;o0000:_ooool001kooooo00?o0000ooooooooool0=?ooool2
o`0002?ooooo0_l0002:ooooo`;o0000=?ooool2o`0001gooooo0_l0000;ooooo`007_ooool00ol0
003oooooooooo`0Looooo`;o0000H_ooool2o`0006?ooooo0_l0000dooooo`;o00007Oooool2o`00
00_ooooo000Nooooo`03o`000?oooooooooo01cooooo0_l00006ooooo`;o00000oooool2o`0003;o
oooo0_l0000Qooooo`;o00009_ooool2o`0001gooooo0_l0000Hooooo`;o0000<oooool2o`0002oo
oooo000Dooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`0Tooooo`;o0000
0oooool2o`00013ooooo0_l0000Cooooo`;o00002oooool2o`0004Wooooo0_l0000Mooooo`;o0000
6?ooool2o`0003?ooooo0_l0000_ooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo03Oooooo0_l00002ooooo`;o00004oooool2o`000?Gooooo000Fooooo`03o`000?oooooo
oooo00Gooooo0ol0000=ooooo`;o000000?oooooo`000?l000009Oooool2o`0000kooooo0_l0002C
ooooo`;o00007?ooool2o`00047ooooo0_l00008ooooo`005_ooool00ol0003oooooooooo`0Eoooo
o`;o000000?oooooo`000?l00000=Oooool2o`0009?ooooo0_l0000Looooo`;o0000@Oooool2o`00
00Sooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0
oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Dooooo`03oeEEEOmVIVKo
00000?ooooooD_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.34794 .70286 Mdot
.76214 .57597 Mdot
.68746 .97615 Mdot
.08474 .45072 Mdot
.09118 .68577 Mdot
.80625 .81172 Mdot
.26816 .66065 Mdot
.26854 .72522 Mdot
.61056 .27804 Mdot
.994 .02736 Mdot
.58647 .14857 Mdot
.74885 .54184 Mdot
.00138 .63645 Mdot
.13943 .75334 Mdot
.53035 .31086 Mdot
.03569 .77021 Mdot
.38596 .91002 Mdot
.69469 .49659 Mdot
.92194 .95412 Mdot
.6268 .1858 Mdot
.62845 .26126 Mdot
.78178 .06357 Mdot
.51209 .89933 Mdot
.3349 .16189 Mdot
.60106 .23342 Mdot
.99369 .2976 Mdot
.75857 .09406 Mdot
.55179 .3874 Mdot
.93651 .50381 Mdot
.29213 .51112 Mdot
.44564 .48181 Mdot
.1631 .67323 Mdot
.37415 .80946 Mdot
.16177 .12696 Mdot
.64176 .82316 Mdot
.25626 .51208 Mdot
.96047 .47731 Mdot
.38697 .05071 Mdot
.34498 .80816 Mdot
.90213 .07102 Mdot
.18935 .47038 Mdot
.53218 .14744 Mdot
.20937 .66444 Mdot
.13258 .57077 Mdot
.43303 .54712 Mdot
.75814 .55324 Mdot
.03384 .34425 Mdot
.8118 .42573 Mdot
.47734 .74065 Mdot
.85112 .60806 Mdot
.51921 .51052 Mdot
.12252 .47001 Mdot
.22049 .46812 Mdot
.99308 .36366 Mdot
.64762 .27458 Mdot
.48421 .409 Mdot
.35175 .93855 Mdot
.95567 .64296 Mdot
.04178 .45279 Mdot
.02679 .59348 Mdot
.3402 .55013 Mdot
.48096 .72014 Mdot
.27442 .19034 Mdot
.87161 .12605 Mdot
.39766 .53389 Mdot
.43479 .14103 Mdot
.62537 .55327 Mdot
.61938 .43565 Mdot
.39685 .65351 Mdot
.993 .06417 Mdot
.671 .62383 Mdot
.60192 .93449 Mdot
.2007 .78159 Mdot
.89646 .05783 Mdot
.99178 .74181 Mdot
.30705 .27995 Mdot
.63856 .43601 Mdot
.03656 .84176 Mdot
.62535 .20433 Mdot
.4512 .05322 Mdot
.55054 .25594 Mdot
.46558 .25189 Mdot
.22402 .14233 Mdot
.53763 .48542 Mdot
.99175 .05406 Mdot
.54675 .5447 Mdot
.60378 .79124 Mdot
.75822 .29719 Mdot
.57182 .21049 Mdot
.7717 .35963 Mdot
.96494 .09652 Mdot
.25848 .04254 Mdot
.357 .78752 Mdot
.93032 .19104 Mdot
.75006 .94753 Mdot
.61167 .68975 Mdot
.9426 .67355 Mdot
.81323 .58895 Mdot
.4931 .61449 Mdot
.95946 .0071 Mdot
.64996 .18123 Mdot
.78563 .41593 Mdot
.94368 .73986 Mdot
.13542 .21322 Mdot
.00206 .90865 Mdot
.17135 .0804 Mdot
.76742 .31448 Mdot
.18008 .18004 Mdot
.15736 .32231 Mdot
.18626 .59659 Mdot
.8403 .72152 Mdot
.23355 .21979 Mdot
.59483 .65282 Mdot
.11767 .45314 Mdot
.45274 .4019 Mdot
.18866 .72416 Mdot
.6639 .66246 Mdot
.19113 .99338 Mdot
.07573 .81696 Mdot
.6769 .79458 Mdot
.77235 .67008 Mdot
.52463 .97052 Mdot
.26808 .97503 Mdot
.26889 .58902 Mdot
.31277 .25812 Mdot
.53719 .65036 Mdot
.85608 .96849 Mdot
.08921 .47026 Mdot
.22384 .79543 Mdot
.5584 .19228 Mdot
.17049 .33787 Mdot
.35315 .40371 Mdot
.36297 .88116 Mdot
.12521 .35613 Mdot
.70953 .85382 Mdot
.3893 .74724 Mdot
.43531 .08107 Mdot
.13755 .0806 Mdot
.68003 .90284 Mdot
.39193 .61058 Mdot
.36266 .89769 Mdot
.81502 .94129 Mdot
.91647 .44215 Mdot
.28274 .64053 Mdot
.01274 .26981 Mdot
.24578 .79358 Mdot
.10271 .72096 Mdot
.35126 .4104 Mdot
.08561 .54759 Mdot
.89632 .24881 Mdot
.27115 .23403 Mdot
.61326 .47394 Mdot
.28069 .51889 Mdot
.92081 .73681 Mdot
.8759 .3918 Mdot
.00329 .63387 Mdot
.98717 .32733 Mdot
.47223 .81393 Mdot
.43484 .17123 Mdot
.28452 .4344 Mdot
.07826 .12161 Mdot
.8272 .37746 Mdot
.01807 .89557 Mdot
.19201 .07897 Mdot
.84097 .41262 Mdot
.8948 .03314 Mdot
.61726 .82863 Mdot
.92978 .1387 Mdot
.91489 .47589 Mdot
.25662 .5198 Mdot
.13875 .40018 Mdot
.96015 .65639 Mdot
.28333 .95745 Mdot
.46598 .94193 Mdot
.24078 .17894 Mdot
.11535 .46261 Mdot
.27188 .95218 Mdot
.10172 .25431 Mdot
.97347 .2015 Mdot
.63679 .94389 Mdot
.01336 .64508 Mdot
.8834 .67207 Mdot
.22528 .29494 Mdot
.1431 .84643 Mdot
.65834 .62299 Mdot
.27649 .8251 Mdot
.1239 .33785 Mdot
.75951 .86105 Mdot
.61477 .68258 Mdot
.61931 .95467 Mdot
.28734 .06204 Mdot
.48427 .81224 Mdot
.34375 .74606 Mdot
.62004 .71385 Mdot
.90362 .89811 Mdot
.7021 .62191 Mdot
.77443 .53649 Mdot
.58158 .61301 Mdot
.23305 .81782 Mdot
.64919 .36944 Mdot
.30942 .45728 Mdot
.92903 .59611 Mdot
.46863 .79632 Mdot
.24619 .96867 Mdot
.33469 .24094 Mdot
.22408 .83589 Mdot
.52438 .61096 Mdot
.78793 .96956 Mdot
.86741 .92183 Mdot
.46365 .02876 Mdot
.28918 .89636 Mdot
.19991 .80653 Mdot
.00419 .3052 Mdot
.82643 .47184 Mdot
.77233 .85052 Mdot
.59417 .48399 Mdot
.41985 .15531 Mdot
.7368 .23832 Mdot
.98123 .79867 Mdot
.49844 .78077 Mdot
.88304 .83225 Mdot
.16351 .44337 Mdot
.00723 .0859 Mdot
.35306 .54237 Mdot
.16559 .03046 Mdot
.02357 .78174 Mdot
.8766 .94625 Mdot
.0012 .37207 Mdot
.45677 .51604 Mdot
.95175 .6163 Mdot
.18662 .94149 Mdot
.11984 .6764 Mdot
.31207 .59487 Mdot
.11285 .81792 Mdot
.21009 .88396 Mdot
.01785 .97436 Mdot
.3729 .28778 Mdot
.69295 .56818 Mdot
.10604 .28396 Mdot
.33629 .68493 Mdot
.25831 .78437 Mdot
.33794 .96149 Mdot
.95585 .99727 Mdot
.17999 .96894 Mdot
.81924 .58047 Mdot
.41326 .00895 Mdot
.27884 .86732 Mdot
.5902 .72982 Mdot
.3247 .16738 Mdot
.19711 .58181 Mdot
.40261 .44172 Mdot
.63973 .36523 Mdot
.18593 .30921 Mdot
.72492 .87083 Mdot
.82552 .4837 Mdot
.11376 .75755 Mdot
.25159 .65505 Mdot
.0565 .98942 Mdot
.27286 .29287 Mdot
.85425 .97616 Mdot
.47704 .84486 Mdot
.59831 .32447 Mdot
.7214 .25791 Mdot
.52698 .31645 Mdot
.09641 .00923 Mdot
.12467 .39341 Mdot
.39789 .98086 Mdot
.2682 .63534 Mdot
.5237 .17433 Mdot
.93144 .67757 Mdot
.84359 .29801 Mdot
.22245 .23748 Mdot
.44335 .92585 Mdot
.38936 .59524 Mdot
.24583 .77624 Mdot
.7691 .78809 Mdot
.81344 .83361 Mdot
.82016 .2264 Mdot
.45139 .39815 Mdot
.99218 .8722 Mdot
.77281 .17442 Mdot
.4689 .15881 Mdot
.78112 .63667 Mdot
.84749 .6086 Mdot
.33813 .25384 Mdot
.70069 .32922 Mdot
.72507 .30699 Mdot
.8425 .274 Mdot
.83028 .32563 Mdot
.81092 .94608 Mdot
.06747 .62319 Mdot
.17963 .23909 Mdot
.02277 .91915 Mdot
.87705 .59467 Mdot
.86658 .27132 Mdot
.80938 .26909 Mdot
.37138 .4317 Mdot
.51229 .38016 Mdot
.74233 .46426 Mdot
.23058 .09044 Mdot
.50238 .36092 Mdot
.67783 .20143 Mdot
.32489 .47216 Mdot
.97401 .06109 Mdot
.57669 .51379 Mdot
.32703 .41124 Mdot
.39991 .1007 Mdot
.59656 .02796 Mdot
.50957 .9387 Mdot
.60695 .72112 Mdot
.40239 .54942 Mdot
.71062 .56858 Mdot
.04094 .34605 Mdot
.93233 .31305 Mdot
.12922 .10277 Mdot
.16949 .51976 Mdot
.85057 .85398 Mdot
.24887 .64819 Mdot
.5765 .28759 Mdot
.60478 .2709 Mdot
.89769 .93421 Mdot
.99372 .91726 Mdot
.57135 .28731 Mdot
.64095 .01192 Mdot
.44766 .36665 Mdot
.70764 .52629 Mdot
.85727 .37748 Mdot
.4727 .4396 Mdot
.91828 .05156 Mdot
.27259 .25089 Mdot
.99558 .80756 Mdot
.16589 .82024 Mdot
.4216 .46306 Mdot
.63877 .00132 Mdot
.0181 .66438 Mdot
.33713 .72522 Mdot
.28374 .01765 Mdot
.45447 .56977 Mdot
.93428 .54591 Mdot
.67957 .24634 Mdot
.9333 .05702 Mdot
.18482 .82774 Mdot
.22908 .52365 Mdot
.63384 .88132 Mdot
.16904 .52608 Mdot
.39101 .96876 Mdot
.32117 .24288 Mdot
.90764 .75932 Mdot
.45305 .63272 Mdot
.08197 .63612 Mdot
.27261 .05527 Mdot
.88309 .63142 Mdot
.1523 .5656 Mdot
.67441 .2121 Mdot
.99293 .75405 Mdot
.94926 .95352 Mdot
.12583 .22249 Mdot
.18368 .47684 Mdot
.64262 .43054 Mdot
.75986 .09953 Mdot
.9232 .78336 Mdot
.55634 .69989 Mdot
.5317 .65303 Mdot
.81543 .36693 Mdot
.95327 .38109 Mdot
.41037 .15043 Mdot
.10241 .53417 Mdot
.69638 .50638 Mdot
.50706 .40604 Mdot
.18441 .49486 Mdot
.6269 .37996 Mdot
.95272 .19182 Mdot
.48287 .72555 Mdot
.60934 .88964 Mdot
.37802 .68399 Mdot
.37047 .79009 Mdot
.14637 .63881 Mdot
.63347 .7384 Mdot
.20236 .66719 Mdot
.35813 .06601 Mdot
.92369 .27339 Mdot
.03499 .0218 Mdot
.77154 .76593 Mdot
.61636 .23377 Mdot
.37355 .81749 Mdot
.65861 .59248 Mdot
.35287 .65962 Mdot
.10779 .7948 Mdot
.38098 .22958 Mdot
.58219 .0201 Mdot
.86774 .62214 Mdot
.12871 .96732 Mdot
.2378 .14505 Mdot
.53664 .18749 Mdot
.17143 .68835 Mdot
.52645 .36201 Mdot
.75626 .89408 Mdot
.86951 .42077 Mdot
.87831 .53208 Mdot
.82941 .56245 Mdot
.90055 .29262 Mdot
.59741 .42889 Mdot
.71311 .52694 Mdot
.48298 .23943 Mdot
.33477 .47524 Mdot
.9993 .98002 Mdot
.9359 .42815 Mdot
.91771 .07319 Mdot
.36324 .54272 Mdot
.49936 .8906 Mdot
.04687 .96351 Mdot
.65295 .6839 Mdot
.8104 .74837 Mdot
.94549 .6755 Mdot
.01317 .90153 Mdot
.58896 .57317 Mdot
.31534 .16041 Mdot
.91714 .74043 Mdot
.80292 .98558 Mdot
.90227 .82158 Mdot
.68088 .52443 Mdot
.03367 .03801 Mdot
.79233 .04976 Mdot
.46511 .16007 Mdot
.55246 .07589 Mdot
.48511 .45023 Mdot
.18156 .73092 Mdot
.10717 .63986 Mdot
.64512 .61718 Mdot
.56488 .14394 Mdot
.46369 .49733 Mdot
.46097 .36604 Mdot
.75094 .24647 Mdot
.04727 .27737 Mdot
.26675 .92784 Mdot
.90359 .36133 Mdot
.35473 .34476 Mdot
.0765 .10564 Mdot
.67136 .19448 Mdot
.32601 .95874 Mdot
.69958 .32971 Mdot
.50712 .14796 Mdot
.34225 .22325 Mdot
.81958 .94652 Mdot
.87855 .24727 Mdot
.08867 .78024 Mdot
.70324 .0282 Mdot
.64152 .38871 Mdot
.4656 .45261 Mdot
.35681 .6277 Mdot
.16483 .84985 Mdot
.26882 .66423 Mdot
.91651 .51113 Mdot
.36524 .0468 Mdot
.45869 .20385 Mdot
.51434 .59566 Mdot
.517 .54347 Mdot
.23404 .3712 Mdot
.51815 .25998 Mdot
.04804 .65701 Mdot
.73683 .43624 Mdot
.37419 .10548 Mdot
.84555 .98933 Mdot
.48921 .922 Mdot
.36734 .60221 Mdot
.29316 .67037 Mdot
.11639 .12605 Mdot
.38445 .72049 Mdot
.23532 .87241 Mdot
.89385 .66153 Mdot
.35202 .55561 Mdot
.3089 .63203 Mdot
.69017 .93974 Mdot
.02527 .49231 Mdot
.06284 .67965 Mdot
.66687 .35578 Mdot
.68738 .45918 Mdot
.44823 .48889 Mdot
.89102 .07701 Mdot
.59206 .54806 Mdot
.91482 .86964 Mdot
.62342 .20763 Mdot
.84332 .12667 Mdot
.22782 .67332 Mdot
.09581 .66013 Mdot
.61392 .5125 Mdot
.41134 .42563 Mdot
.12784 .07494 Mdot
.81312 .48276 Mdot
.75653 .21094 Mdot
.40484 .1202 Mdot
.13947 .33965 Mdot
.30357 .63602 Mdot
.92196 .9853 Mdot
.27762 .48141 Mdot
.75692 .59381 Mdot
.74222 .66503 Mdot
.47269 .44702 Mdot
.02452 .31042 Mdot
.66301 .63223 Mdot
.64798 .79239 Mdot
.27872 .15733 Mdot
.49352 .373 Mdot
.97606 .96945 Mdot
.28847 .04294 Mdot
.38404 .55973 Mdot
.76353 .33065 Mdot
.60477 .94894 Mdot
.68622 .30525 Mdot
.26331 .52953 Mdot
.83209 .55094 Mdot
.0695 .83477 Mdot
.06427 .52157 Mdot
.06486 .29913 Mdot
.90448 .47054 Mdot
.09956 .84317 Mdot
.94606 .44151 Mdot
.38687 .75346 Mdot
.07359 .28553 Mdot
.22362 .68504 Mdot
.6092 .48273 Mdot
.83759 .86845 Mdot
.99157 .45894 Mdot
.18638 .06284 Mdot
.88069 .13918 Mdot
.31287 .10225 Mdot
.40011 .77264 Mdot
.26274 .60468 Mdot
.5238 .17139 Mdot
.30667 .57212 Mdot
.84366 .61575 Mdot
.43706 .78678 Mdot
.8933 .01625 Mdot
.81262 .25609 Mdot
.91741 .83351 Mdot
.08061 .85411 Mdot
.50619 .12388 Mdot
.28907 .11908 Mdot
.7932 .14567 Mdot
.0714 .62323 Mdot
.89331 .69801 Mdot
.0711 .7108 Mdot
.50331 .325 Mdot
.97315 .07805 Mdot
.33973 .41702 Mdot
.1776 .46158 Mdot
.75166 .88864 Mdot
.38484 .77667 Mdot
.1419 .03045 Mdot
.73091 .00354 Mdot
.76515 .64472 Mdot
.34519 .13193 Mdot
.20663 .02634 Mdot
.05713 .27217 Mdot
.73456 .83783 Mdot
.60658 .96067 Mdot
.41829 .82644 Mdot
.04302 .12326 Mdot
.33317 .58602 Mdot
.15248 .75918 Mdot
.08258 .56276 Mdot
.7864 .77165 Mdot
.81014 .06974 Mdot
.35836 .52127 Mdot
.929 .71022 Mdot
.9288 .09278 Mdot
.58141 .3468 Mdot
.75204 .01515 Mdot
.7439 .00762 Mdot
.85331 .68721 Mdot
.479 .02125 Mdot
.18382 .86799 Mdot
.78428 .87035 Mdot
.95464 .89451 Mdot
.76833 .34341 Mdot
.03417 .20291 Mdot
.26531 .91564 Mdot
.24074 .98768 Mdot
.593 .13704 Mdot
.26386 .93151 Mdot
.72191 .24813 Mdot
.71954 .88614 Mdot
.27243 .15661 Mdot
.77034 .25468 Mdot
.00905 .87153 Mdot
.72613 .60244 Mdot
.98244 .2088 Mdot
.88814 .07397 Mdot
.57967 .59342 Mdot
.04295 .31168 Mdot
.68646 .59882 Mdot
.58235 .89644 Mdot
.07957 .18994 Mdot
.1649 .56214 Mdot
.47931 .53003 Mdot
.24391 .76635 Mdot
.07714 .98381 Mdot
.15859 .2777 Mdot
.43104 .74084 Mdot
.18197 .02409 Mdot
.85642 .1096 Mdot
.10358 .42774 Mdot
.60984 .1382 Mdot
.66348 .26607 Mdot
.52972 .39265 Mdot
.14198 .2299 Mdot
.90544 .65604 Mdot
.7711 .07914 Mdot
.23734 .60479 Mdot
.9638 .49226 Mdot
.75764 .93881 Mdot
.10875 .11735 Mdot
.37914 .29348 Mdot
.89351 .88511 Mdot
.92146 .62365 Mdot
.6927 .30099 Mdot
.34567 .29837 Mdot
.50094 .28544 Mdot
.69546 .21041 Mdot
.04734 .44433 Mdot
.76347 .4681 Mdot
.91221 .36179 Mdot
.76754 .57942 Mdot
.83132 .969 Mdot
.02144 .82941 Mdot
.65271 .01696 Mdot
.11937 .51983 Mdot
.33562 .81104 Mdot
.37176 .80509 Mdot
.50662 .87364 Mdot
.60892 .24369 Mdot
.64358 .62348 Mdot
.11338 .21234 Mdot
.47126 .685 Mdot
.46156 .27818 Mdot
.61677 .03715 Mdot
.52245 .73041 Mdot
.51628 .65455 Mdot
.18362 .42864 Mdot
.69204 .01259 Mdot
.34998 .85993 Mdot
.23967 .10845 Mdot
.57283 .157 Mdot
.90148 .90286 Mdot
.7079 .57225 Mdot
.25558 .39514 Mdot
.46017 .75037 Mdot
.17338 .33287 Mdot
.04256 .05887 Mdot
.89805 .06218 Mdot
.70087 .72026 Mdot
.96748 .88374 Mdot
.73594 .86327 Mdot
.13053 .73474 Mdot
.99401 .37915 Mdot
.30727 .85261 Mdot
.49417 .60716 Mdot
.18608 .28912 Mdot
.07276 .3549 Mdot
.56796 .4313 Mdot
.90044 .88067 Mdot
.52458 .41953 Mdot
.66509 .45226 Mdot
.39867 .68581 Mdot
.65095 .45921 Mdot
.47073 .83909 Mdot
.74039 .49689 Mdot
.07212 .15818 Mdot
.65401 .87542 Mdot
.99276 .42493 Mdot
.43283 .20519 Mdot
.16091 .93372 Mdot
.16539 .41949 Mdot
.7432 .16127 Mdot
.97088 .05905 Mdot
.61271 .34373 Mdot
.50431 .9256 Mdot
.46592 .31526 Mdot
.30033 .30718 Mdot
.43133 .27347 Mdot
.69679 .68808 Mdot
.63833 .81855 Mdot
.67051 .40084 Mdot
.40715 .85586 Mdot
.6977 .68378 Mdot
.89915 .39953 Mdot
.71427 .06942 Mdot
.55784 .7189 Mdot
.36274 .53731 Mdot
.30927 .10632 Mdot
.34536 .58807 Mdot
.75182 .97908 Mdot
.59024 .47861 Mdot
.64487 .421 Mdot
.40778 .9809 Mdot
.5448 .79755 Mdot
.1387 .02802 Mdot
.69589 .66811 Mdot
.15039 .04046 Mdot
.21315 .60689 Mdot
.09232 .54587 Mdot
.7325 .56528 Mdot
.90102 .90208 Mdot
.97668 .34243 Mdot
.03771 .09457 Mdot
.64045 .25552 Mdot
.3123 .4639 Mdot
.97324 .70474 Mdot
.6848 .3663 Mdot
.11763 .70519 Mdot
.2636 .25458 Mdot
.24349 .23962 Mdot
.78767 .88039 Mdot
.48203 .01078 Mdot
.79473 .9653 Mdot
.7581 .06775 Mdot
.91374 .47039 Mdot
.46751 .44478 Mdot
.36198 .25817 Mdot
.76076 .90096 Mdot
.52453 .61794 Mdot
.53015 .93938 Mdot
.33592 .40188 Mdot
.74322 .42357 Mdot
.3352 .60513 Mdot
.18837 .46835 Mdot
.67019 .76798 Mdot
.56617 .59653 Mdot
.4718 .64228 Mdot
.64576 .96488 Mdot
.77954 .42506 Mdot
.85735 .1339 Mdot
.92746 .67061 Mdot
.50026 .9412 Mdot
.85111 .52199 Mdot
.32207 .73496 Mdot
.93174 .63624 Mdot
.06331 .77863 Mdot
.90039 .16878 Mdot
.09217 .26939 Mdot
.40769 .69688 Mdot
.10521 .08726 Mdot
.11611 .2324 Mdot
.08304 .69198 Mdot
.83649 .59686 Mdot
.95687 .49118 Mdot
.66604 .2158 Mdot
.61299 .72335 Mdot
.31129 .22551 Mdot
.42784 .58198 Mdot
.94253 .47659 Mdot
.91319 .70584 Mdot
.68944 .52161 Mdot
.41041 .73288 Mdot
.88135 .70283 Mdot
.01654 .69466 Mdot
.35296 .58615 Mdot
.14366 .07316 Mdot
.7829 .79619 Mdot
.93903 .81083 Mdot
.14759 .76177 Mdot
.58934 .61452 Mdot
.44344 .20079 Mdot
.09166 .29507 Mdot
.65625 .91824 Mdot
.3452 .49406 Mdot
.56983 .05559 Mdot
.10883 .59497 Mdot
.83111 .40411 Mdot
.742 .81108 Mdot
.36285 .24736 Mdot
.64308 .07826 Mdot
.49278 .46814 Mdot
.64035 .99252 Mdot
.67336 .17547 Mdot
.53414 .76444 Mdot
.2054 .65155 Mdot
.3332 .62035 Mdot
.87372 .01551 Mdot
.75396 .54243 Mdot
.74672 .04253 Mdot
.10765 .98159 Mdot
.667 .45984 Mdot
.69175 .42614 Mdot
.9507 .31814 Mdot
.26657 .06001 Mdot
.63587 .93975 Mdot
.72754 .52303 Mdot
.14639 .82458 Mdot
.83699 .87832 Mdot
.48675 .57877 Mdot
.97848 .35267 Mdot
.71579 .01802 Mdot
.66201 .63891 Mdot
.65889 .47693 Mdot
.33607 .98481 Mdot
.51547 .73469 Mdot
.68573 .1712 Mdot
.65078 .32117 Mdot
.49964 .6871 Mdot
.72602 .23386 Mdot
.04748 .48272 Mdot
.49848 .46038 Mdot
.35732 .08653 Mdot
.65323 .46468 Mdot
.39958 .45189 Mdot
.87474 .04038 Mdot
.99103 .6537 Mdot
.79928 .34643 Mdot
.40616 .19616 Mdot
.08486 .69819 Mdot
.53965 .24342 Mdot
.78057 .53123 Mdot
.74513 .7227 Mdot
.35324 .20128 Mdot
.95323 .13042 Mdot
.44416 .38783 Mdot
.23264 .42433 Mdot
.62829 .21069 Mdot
.1462 .70681 Mdot
.52834 .39774 Mdot
.50209 .60911 Mdot
.72114 .67698 Mdot
.69691 .00335 Mdot
.97045 .35611 Mdot
.13364 .07264 Mdot
.25791 .40896 Mdot
.9943 .08108 Mdot
.24711 .24808 Mdot
.13064 .4746 Mdot
.89457 .5631 Mdot
.58041 .82058 Mdot
.60611 .50018 Mdot
.90545 .59407 Mdot
.02572 .5241 Mdot
.36566 .4431 Mdot
.40578 .06724 Mdot
.78747 .42537 Mdot
.36046 .48199 Mdot
.09193 .5219 Mdot
.44345 .0898 Mdot
.16445 .59403 Mdot
.31366 .46239 Mdot
.90079 .09457 Mdot
.93209 .46612 Mdot
.70402 .65275 Mdot
.59852 .1247 Mdot
.24704 .34072 Mdot
.30194 .81917 Mdot
.89002 .54742 Mdot
.12348 .73368 Mdot
.86766 .94511 Mdot
.46746 .11204 Mdot
.10243 .78852 Mdot
.5994 .51149 Mdot
.86004 .30364 Mdot
.24152 .28731 Mdot
.31152 .67679 Mdot
.40296 .98628 Mdot
.81184 .36174 Mdot
.66798 .48959 Mdot
.07845 .93943 Mdot
.92525 .55646 Mdot
.73105 .74183 Mdot
.34589 .30902 Mdot
.17051 .15915 Mdot
.72797 .17842 Mdot
.38444 .18613 Mdot
.36014 .21917 Mdot
.5637 .64429 Mdot
.6527 .14321 Mdot
.25652 .74654 Mdot
.10828 .23966 Mdot
.29006 .1284 Mdot
.0865 .66775 Mdot
.28725 .94719 Mdot
.7654 .52447 Mdot
.29614 .26308 Mdot
.18269 .7008 Mdot
.6878 .77298 Mdot
.09023 .47814 Mdot
.45796 .26926 Mdot
.93926 .24741 Mdot
.43742 .88282 Mdot
.9393 .63538 Mdot
.49048 .22878 Mdot
.87861 .21008 Mdot
.21176 .04113 Mdot
.1211 .60223 Mdot
.69264 .36363 Mdot
.50736 .64358 Mdot
.96473 .5098 Mdot
.79495 .34118 Mdot
.02009 .55032 Mdot
.84328 .71913 Mdot
.72979 .92095 Mdot
.52578 .63717 Mdot
.26611 .15264 Mdot
.79694 .94857 Mdot
.23904 .8382 Mdot
.914 .89608 Mdot
.31934 .83964 Mdot
.75108 .68235 Mdot
.30199 .96586 Mdot
.09258 .2521 Mdot
.59436 .27649 Mdot
.39548 .36271 Mdot
.67639 .61753 Mdot
.00889 .83616 Mdot
.08436 .95969 Mdot
.55464 .13138 Mdot
.00353 .60018 Mdot
.85291 .15363 Mdot
.9036 .49464 Mdot
.44701 .83185 Mdot
.93415 .61412 Mdot
.55497 .36985 Mdot
.38523 .3091 Mdot
.76345 .41637 Mdot
.81114 .87184 Mdot
.89758 .26336 Mdot
.86159 .48636 Mdot
.34431 .08057 Mdot
.39497 .21764 Mdot
.95188 .2694 Mdot
.22305 .1795 Mdot
.29381 .06455 Mdot
.69873 .0632 Mdot
.92082 .28646 Mdot
.28589 .46206 Mdot
.0605 .29088 Mdot
.99194 .51662 Mdot
.48369 .37394 Mdot
.68699 .51841 Mdot
.89969 .08574 Mdot
.95349 .04979 Mdot
.24343 .85362 Mdot
.19634 .03148 Mdot
.2783 .25598 Mdot
.54387 .98072 Mdot
.9532 .83423 Mdot
.34947 .43863 Mdot
.68271 .07202 Mdot
.68721 .25022 Mdot
.0141 .16891 Mdot
.14821 .54395 Mdot
.93135 .95742 Mdot
.49435 .9656 Mdot
.9022 .02694 Mdot
.54915 .36427 Mdot
.32432 .97261 Mdot
.70154 .01314 Mdot
.00155 .27938 Mdot
.08619 .07186 Mdot
.38864 .34668 Mdot
.40116 .41501 Mdot
.27732 .45936 Mdot
.79975 .35162 Mdot
.36069 .10126 Mdot
.98774 .39035 Mdot
.83989 .1336 Mdot
.39648 .89466 Mdot
.79733 .90687 Mdot
.43156 .30447 Mdot
.82961 .4906 Mdot
.75277 .43998 Mdot
.12246 .38527 Mdot
.49234 .09145 Mdot
.98145 .72733 Mdot
.62446 .85192 Mdot
.66602 .3257 Mdot
.10234 .48987 Mdot
.77568 .26745 Mdot
.87338 .36903 Mdot
.89713 .37875 Mdot
.30517 .57901 Mdot
.30006 .16136 Mdot
.93224 .29817 Mdot
.32197 .29244 Mdot
.3937 .37258 Mdot
.66846 .04892 Mdot
.24056 .20147 Mdot
.41976 .41626 Mdot
.05645 .02473 Mdot
.64174 .73547 Mdot
.82979 .6305 Mdot
.8043 .74457 Mdot
.85572 .84992 Mdot
.77597 .80046 Mdot
.15286 .77345 Mdot
.74469 .02703 Mdot
.69007 .48265 Mdot
.21853 .87291 Mdot
.155 .93055 Mdot
.07081 .09283 Mdot
.46781 .27617 Mdot
.54732 .26358 Mdot
.79051 .60041 Mdot
.82791 .28613 Mdot
.2524 .5501 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Wo
oooo0_l00002ooooo`03o`000?oooooooooo00_ooooo0ol00009ooooo`;o00001?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`?o00002Oooool2o`0000Cooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`02o`0000cooooo00?o0000ooooooooool0
0_ooool001kooooo00?o0000ooooooooool06oooool2o`0006Gooooo0_l0001Zooooo`;o0000A?oo
ool2o`00017ooooo000Nooooo`03o`000?oooooooooo01_ooooo0_l0001Uooooo`;o00005Oooool2
o`00037ooooo0_l0000?ooooo`;o000000?oooooo`000?l000003?ooool2o`0005Oooooo000Noooo
o`03o`000?oooooooooo09Wooooo0_l0000aooooo`;o00003oooool2o`000003ooooool0003o0000
00kooooo0_l0000Vooooo`;o00001?ooool2o`0002Oooooo000Nooooo`03o`000?oooooooooo05So
oooo0_l0001fooooo`;o00004oooool2o`0000Wooooo0_l0000Vooooo`;o00001?ooool2o`0002Oo
oooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0001?ooooo`;o0000?_ooool2o`0001oooooo
0_l0000Eooooo`;o00004oooool2o`00063ooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0
0005ooooo`;o00009oooool2o`0005oooooo0_l0000Oooooo`;o0000S?ooool001kooooo00?o0000
ooooooooool03_ooool2o`0001Wooooo0_l0000<ooooo`;o00001_ooool2o`0005;ooooo0_l0000Y
ooooo`;o00008Oooool2o`0000_ooooo0_l0000aooooo`;o00007?ooool2o`0000Kooooo000Noooo
o`03o`000?oooooooooo02Wooooo0ol00006ooooo`;o00002?ooool2o`000003ooooool0003o0000
05;ooooo0_l0000Yooooo`;o00008Oooool2o`0000_ooooo0_l0000aooooo`;o00007?ooool2o`00
00Kooooo000Nooooo`03o`000?oooooooooo02[ooooo0_l00006ooooo`;o00002?ooool2o`000>7o
oooo0_l0000Vooooo`007_ooool00ol0003oooooooooo`07ooooo`;o0000^oooool2o`0005Wooooo
0_l0000Vooooo`007_ooool00ol0003oooooooooo`07ooooo`;o00009?ooool2o`0001;ooooo0_l0
0021ooooo`;o0000D_ooool2o`0002gooooo000Nooooo`03o`000?oooooooooo02gooooo0_l0000B
ooooo`;o00003Oooool2o`0000Sooooo0_l0002Cooooo`;o00009oooool2o`0002gooooo000Noooo
o`03o`000?oooooooooo053ooooo0_l00008ooooo`;o00005oooool2o`0007[ooooo0_l0001Foooo
o`007_ooool00ol0003oooooooooo`1cooooo`;o0000H?ooool2o`0002Kooooo0_l0000cooooo`;o
00004oooool001kooooo0_l0001kooooo`;o00004oooool2o`0004Cooooo0_l0000Vooooo`;o0000
9oooool2o`0000[ooooo0_l0000Cooooo`007_ooool00ol0003oooooooooo`1Eooooo`;o00008ooo
ool2o`0001?ooooo0_l0000Tooooo`;o0000Koooool2o`0001Kooooo0_l00007ooooo`007_ooool0
0ol0003oooooooooo`0:ooooo`;o0000BOooool2o`0005kooooo0_l0001Xooooo`;o00002_ooool2
o`0000_ooooo0_l00004ooooo`;o00001oooool001kooooo00?o0000ooooooooool02_ooool2o`00
02cooooo0_l0000Iooooo`;o00001?ooool2o`000<Cooooo0ol00009ooooo`;o00002oooool3o`00
00cooooo000Nooooo`03o`000?oooooooooo03Sooooo0_l0000Iooooo`;o00001?ooool4o`0001?o
oooo0_l0001]ooooo`;o00006Oooool2o`0002Cooooo0_l0000Gooooo`;o00001?ooool2o`0000Ko
oooo000Nooooo`03o`000?oooooooooo05_ooooo0_l0000Cooooo`;o00003_ooool2o`0005gooooo
0_l0000Aooooo`;o00001_ooool2o`0004?ooooo0_l00006ooooo`007_ooool00ol0003ooooooooo
o`0Hooooo`;o0000I_ooool2o`0005Sooooo0_l00008ooooo`;o00003?ooool2o`0000oooooo0_l0
000Looooo`;o00009?ooool001kooooo00?o0000ooooooooool06?ooool2o`0000_ooooo1?l00002
ooooo`;o0000[Oooool2o`0000Sooooo0_l0000Mooooo`;o00006?ooool2o`0000;ooooo0_l00003
ooooo`;o00007oooool001kooooo00?o0000ooooooooool09Oooool4o`0000;ooooo0_l00022oooo
o`;o00007?ooool2o`0004kooooo0ol00006ooooo`;o00004?ooool2o`0000gooooo000Nooooo`03
o`000?oooooooooo02Wooooo0_l00009ooooo`;o00001?ooool2o`00033ooooo0_l0000Kooooo`;o
00009?ooool2o`0001cooooo0_l0000Xooooo`;o00009Oooool2o`0001Sooooo0_l00005ooooo`;o
00001_ooool001kooooo00?o0000ooooooooool0:Oooool2o`0000Wooooo0_l00004ooooo`;o0000
<?ooool2o`0001_ooooo0_l0001/ooooo`;o0000A_ooool2o`0000Kooooo000Nooooo`?o00007_oo
ool2o`00053ooooo0_l0002^ooooo`;o00009Oooool001kooooo0ol0000Nooooo`;o00009oooool2
o`0002Oooooo0_l0000Jooooo`;o0000T_ooool2o`0002Gooooo000Nooooo`03o`000?oooooooooo
01?ooooo0_l0000booooo`;o0000@oooool2o`0000kooooo0_l0002<ooooo`;o00006oooool001ko
oooo00?o0000ooooooooool02?ooool2o`0000Wooooo0_l00027ooooo`;o0000EOooool2o`0002co
oooo0_l00007ooooo`;o00002_ooool2o`0000oooooo000Nooooo`03o`000?oooooooooo00Sooooo
0_l0003Yooooo`;o0000;?ooool2o`0001?ooooo0_l0000?ooooo`007_ooool2o`0002Oooooo0_l0
000jooooo`;o00003Oooool2o`0000_ooooo0_l0001cooooo`;o0000D_ooool001kooooo00?o0000
ooooooooool05Oooool2o`0000oooooo0_l0000jooooo`;o00003Oooool2o`0000?ooooo0_l00006
ooooo`;o0000aoooool001kooooo00?o0000ooooooooool05Oooool2o`0003?ooooo0_l0000Doooo
o`;o00005?ooool2o`000<oooooo000Nooooo`03o`000?oooooooooo04[ooooo0_l0000Dooooo`;o
0000<_ooool2o`0007cooooo0_l0000cooooo`007_ooool00ol0003oooooooooo`2Dooooo`;o0000
O?ooool2o`0003?ooooo000Nooooo`03o`000?oooooooooo01oooooo0_l0003oooooobOooooo000N
ooooo`03o`000?oooooooooo01oooooo0_l0000iooooo`;o00009?ooool2o`000<Gooooo000Noooo
o`03o`000?oooooooooo00[ooooo0_l00009ooooo`;o0000@oooool2o`0002Cooooo0_l0000Noooo
o`;o0000YOooool001kooooo00?o0000ooooooooool02_ooool2o`0000Wooooo0_l0000;ooooo`;o
00003?ooool2o`0006kooooo0_l0000Looooo`;o0000C_ooool2o`0000Oooooo0_l0000^ooooo`00
7_ooool00ol0003oooooooooo`0Rooooo`;o00003?ooool2o`0002Sooooo0_l0001Rooooo`;o0000
C_ooool2o`0000Oooooo0_l0000Iooooo`;o00004oooool001kooooo00?o0000ooooooooool0F_oo
ool2o`00013ooooo0_l00012ooooo`;o0000Foooool2o`0002?ooooo0_l0000Cooooo`007_ooool0
0ol0003oooooooooo`1/ooooo`;o0000@_ooool2o`0005_ooooo0_l00004ooooo`;o0000<_ooool0
01kooooo00?o0000ooooooooool0_Oooool2o`0000?ooooo0_l0001?ooooo`;o00001Oooool2o`00
00kooooo0_l0000Kooooo`007_ooool00ol0003oooooooooo`15ooooo`;o0000@_ooool2o`0003;o
oooo0_l00003ooooo`;o0000E_ooool2o`0000kooooo0_l0000Kooooo`007_ooool00ol0003ooooo
ooooo`15ooooo`;o00000_ooool2o`0003kooooo0_l0000Yooooo`;o00006_ooool2o`0002cooooo
0_l00017ooooo`007_ooool00ol0003oooooooooo`19ooooo`;o0000E_ooool2o`0000Kooooo0_l0
0009ooooo`;o00001Oooool2o`0001?ooooo0_l0000/ooooo`;o0000Aoooool001kooooo0_l00022
ooooo`;o00007_ooool2o`0000Kooooo0_l0000@ooooo`;o0000R_ooool001kooooo00?o0000oooo
ooooool0D_ooool2o`0002gooooo0_l0002>ooooo`;o0000=?ooool001kooooo00?o0000oooooooo
ool04oooool2o`0003gooooo1_l0000/ooooo`;o0000<?ooool2o`0005Wooooo0_l0000dooooo`00
7_ooool00ol0003oooooooooo`0Cooooo`;o00007_ooool2o`0001oooooo1?l00005ooooo`;o0000
0oooool2o`00023ooooo0_l0000=ooooo`?o00008?ooool2o`0003Kooooo0_l0001Gooooo`007_oo
ool00ol0003oooooooooo`0cooooo`;o0000:?ooool2o`0000?ooooo0_l00005ooooo`;o0000:?oo
ool3o`0005Sooooo0_l0001Gooooo`007_ooool00ol0003oooooooooo`1Uooooo`;o00000_ooool2
o`000=cooooo000Nooooo`03o`000?oooooooooo00;o0000Hoooool2o`000;[ooooo0_l0000Toooo
o`007_ooool00ol0003oooooooooo`02o`0008Oooooo0_l0000Kooooo`;o0000<oooool2o`0004Co
oooo0_l0000Tooooo`007_ooool00ol0003oooooooooo`29ooooo`;o00006oooool2o`0002oooooo
0_l00002ooooo`;o00006_ooool2o`0004kooooo000Nooooo`03o`000?oooooooooo04Cooooo0_l0
0004ooooo`;o0000F_ooool2o`0002oooooo0_l0000@ooooo`;o00003?ooool2o`0004kooooo000N
ooooo`03o`000?oooooooooo03Kooooo0_l0000<ooooo`;o00001?ooool2o`0008?ooooo0_l0000H
ooooo`;o0000G?ooool001kooooo00?o0000ooooooooool0=_ooool2o`00093ooooo0_l00005oooo
o`;o0000M_ooool001kooooo00?o0000ooooooooool0NOooool2o`0002oooooo0_l0000Looooo`;o
0000OOooool001kooooo00?o0000ooooooooool05_ooool2o`0003gooooo0_l0000Rooooo`;o0000
;oooool2o`0007kooooo0_l00006ooooo`;o00004oooool000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool05_ooool2o`0003gooooo
0_l0001Jooooo`;o00008oooool2o`0005;ooooo0_l00006ooooo`;o00004oooool000?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Ko
oooo00?o0000ooooooooool0P?ooool2o`0002oooooo0_l0000Sooooo`;o0000Koooool000?ooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0001_ooooo`;o
00003oooool2o`0000[ooooo0_l0002iooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`07ooooo`;o0000@Oooool2o`0002?o
oooo0_l0000Kooooo`;o00000oooool2o`0003Cooooo0_l0000?ooooo`;o0000G_ooool2o`0000go
oooo0003ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03
o`000?oooooooooo00Oooooo0_l00011ooooo`;o0000?Oooool2o`0000Kooooo0_l0000dooooo`;o
00003oooool2o`0005kooooo0_l0000=ooooo`000oooool01Ol@413ooooooooooooooooo410@00oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`29ooooo`;o0000:oooool2o`0000oo
oooo0_l0000Eooooo`;o0000>_ooool2o`0001oooooo0_l0000:ooooo`000oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo
027ooooo0_l00005ooooo`;o0000S?ooool2o`0000oooooo0ol0000=ooooo`;o00001Oooool2o`00
01;ooooo0_l0000Vooooo`;o00007oooool2o`0000[ooooo0003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool08Oooool2
o`0000Gooooo0_l0002Nooooo`;o00002_ooool2o`000003ooooool0003o000001Wooooo0_l0001C
ooooo`007_ooool00ol0003oooooooooo`18ooooo`;o00009oooool2o`0000Wooooo0_l0001Foooo
o`;o0000LOooool001kooooo00?o0000ooooooooool09Oooool2o`00027ooooo0_l0000Wooooo`;o
00002Oooool2o`000<Wooooo000Nooooo`03o`000?oooooooooo02Gooooo0_l0000jooooo`;o0000
2?ooool2o`000=[ooooo000Nooooo`03o`000?oooooooooo067ooooo0_l00008ooooo`;o0000;_oo
ool2o`0006[ooooo0_l0000nooooo`007_ooool00ol0003oooooooooo`0Zooooo`;o0000C?ooool2
o`00027ooooo0_l0001Zooooo`;o0000?_ooool001kooooo00?o0000ooooooooool08_ooool2o`00
00Kooooo0_l0000Xooooo`;o00008_ooool2o`0004Gooooo0_l00003ooooo`;o00008_ooool2o`00
05gooooo000Nooooo`03o`000?oooooooooo02;ooooo0_l0000Pooooo`;o00003_ooool2o`0006Wo
oooo0_l00003ooooo`;o00008_ooool2o`0005gooooo000Nooooo`03o`000?oooooooooo01oooooo
0_l0000Eooooo`;o00003?ooool2o`0000Gooooo0_l0000Looooo`;o0000;_ooool2o`00053ooooo
0_l0001Jooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o00005Oooool2o`0001?ooooo0_l0
000Gooooo`;o00000oooool2o`0002kooooo0_l0000@ooooo`;o00005Oooool2o`0002Oooooo0_l0
001Jooooo`007_ooool00ol0003oooooooooo`1Tooooo`;o00003?ooool2o`0003Oooooo0_l0000E
ooooo`;o00005Oooool2o`0001Gooooo0_l0000Xooooo`;o00004Oooool2o`0001Sooooo000Noooo
o`03o`000?oooooooooo04cooooo0_l0000Tooooo`;o0000IOooool4o`0000[ooooo0_l00007oooo
o`;o0000:?ooool2o`0000?ooooo0_l0000<ooooo`;o00006?ooool001kooooo0_l0000Kooooo`;o
0000<?ooool2o`0000Oooooo0_l0000looooo`;o0000A_ooool2o`0000[ooooo0_l0000fooooo`;o
00009_ooool001kooooo00?o0000ooooooooool06_ooool2o`000003ooooool0003o000003?ooooo
0_l000001?oooooo0000o`000?l0000Booooo`;o00009oooool2o`0001[ooooo0_l0000Kooooo`;o
0000:?ooool2o`0000cooooo0_l00011ooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o0000
<oooool2o`0000;ooooo0_l0000:ooooo`;o00001_ooool2o`0000Kooooo0_l0000kooooo`;o0000
6oooool2o`0001Sooooo0_l0000>ooooo`;o00003?ooool2o`00047ooooo000Nooooo`03o`000?oo
oooooooo06;ooooo0_l0000>ooooo`;o0000<?ooool2o`0002;ooooo0_l0000Looooo`;o0000Gooo
ool001kooooo00?o0000ooooooooool0G?ooool2o`0004Kooooo0_l00008ooooo`;o00006?ooool2
o`0005Kooooo0_l0000Uooooo`007_ooool00ol0003oooooooooo`1Looooo`;o0000D?ooool2o`00
02Cooooo0_l0000Rooooo`;o00009_ooool2o`0002Gooooo000Nooooo`03o`000?oooooooooo00;o
00006?ooool2o`0007Gooooo0_l0000^ooooo`;o00004Oooool2o`0002;ooooo0_l00009ooooo`;o
00004Oooool2o`0001Wooooo0_l0000Dooooo`007_ooool00ol0003oooooooooo`02o`0000cooooo
0_l0000:ooooo`;o0000K?ooool2o`0000Oooooo0_l0000^ooooo`;o00002oooool2o`0003?ooooo
0_l00009ooooo`;o00001_ooool2o`00013ooooo0_l00007ooooo`;o00005?ooool001kooooo00?o
0000ooooooooool02oooool2o`000003ooooool0003o000001oooooo0_l0001Gooooo`;o00002?oo
ool4o`0002Oooooo0_l00003ooooo`;o00002_ooool2o`0003kooooo0_l0000Hooooo`;o00007Ooo
ool001gooooo0_l0000=ooooo`;o00008_ooool2o`0002oooooo0_l0000`ooooo`Co00009oooool2
o`0000?ooooo0_l00023ooooo`007Oooool2o`00023ooooo0_l00010ooooo`;o0000iOooool001ko
oooo00?o0000ooooooooool05?ooool2o`0000Sooooo0_l0000Zooooo`;o0000Doooool2o`0001Go
oooo0_l0001Aooooo`;o00007?ooool2o`0001kooooo000Nooooo`03o`000?oooooooooo01Cooooo
0_l0000Rooooo`;o00004?ooool2o`0002Wooooo0_l0000Xooooo`;o00005Oooool3o`00053ooooo
0_l0000Looooo`;o00007_ooool001kooooo00?o0000ooooooooool04?ooool2o`0002Kooooo0_l0
000Kooooo`;o00003_ooool2o`0000kooooo1?l0000nooooo`;o0000J?ooool2o`0002Cooooo000N
ooooo`03o`000?oooooooooo013ooooo0_l00008ooooo`;o0000:Oooool2o`0000kooooo0_l0000>
ooooo`;o00004?ooool2o`000:Sooooo0_l0000Tooooo`007_ooool00ol0003oooooooooo`0Aoooo
o`;o00001oooool2o`0002Wooooo0_l0000Uooooo`;o0000Q?ooool2o`0001[ooooo0_l0000Koooo
o`;o00004_ooool2o`0000Kooooo000Nooooo`;o00004_ooool2o`0005Wooooo0_l0001_ooooo`;o
00004oooool2o`0001[ooooo0_l0000Kooooo`;o00004_ooool2o`0000Kooooo000Nooooo`;o0000
ROooool2o`00057ooooo1?l0000dooooo`;o0000<_ooool001kooooo0_l0001Oooooo`;o0000:?oo
ool2o`00057ooooo0_l0000;ooooo`;o0000:Oooool2o`0003;ooooo000Nooooo`03o`000?oooooo
oooo00Cooooo0_l00004ooooo`;o0000;?ooool2o`0002Cooooo0_l0000<ooooo`;o00002oooool2
o`0002gooooo0_l0000nooooo`;o0000GOooool001kooooo00?o0000ooooooooool01?ooool2o`00
00Cooooo0_l0000/ooooo`;o0000<_ooool2o`0000_ooooo0_l0000]ooooo`;o0000Boooool2o`00
03Cooooo0_l0000Jooooo`007_ooool00ol0003oooooooooo`2Cooooo`;o00004_ooool2o`0004co
oooo0_l0000dooooo`;o00001?ooool2o`0001Cooooo000Nooooo`03o`000?oooooooooo09?ooooo
0_l0000Booooo`;o00009_ooool2o`00063ooooo0_l0000Dooooo`007_ooool00ol0003ooooooooo
o`0_ooooo`;o0000W_ooool2o`0007Kooooo000Nooooo`03o`000?oooooooooo02oooooo0_l0001_
ooooo`;o00007?ooool2o`0001Cooooo0_l0000dooooo`;o0000<Oooool2o`0000Sooooo000Noooo
o`03o`000?oooooooooo0:3ooooo0_l0000Looooo`;o00005?ooool2o`0000Wooooo0ol0000Xoooo
o`;o0000<Oooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo03Cooooo0_l0002Yooooo`?o
00004_ooool2o`00057ooooo000Nooooo`03o`000?oooooooooo03Cooooo0_l0002nooooo`;o0000
DOooool001kooooo00?o0000ooooooooool09?ooool2o`0000?ooooo0_l00008ooooo`;o0000oooo
oolCooooo`007_ooool00ol0003oooooooooo`0Tooooo`;o00000oooool2o`0000Sooooo0_l0000G
ooooo`;o0000/?ooool2o`0003Wooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`07oooo
o`;o0000@oooool2o`00027ooooo0_l0001Booooo`;o0000<Oooool2o`0000Kooooo0_l0000ioooo
o`;o00003?ooool001kooooo00?o0000ooooooooool01oooool4o`0006Cooooo0_l00009ooooo`;o
0000?Oooool2o`0000Sooooo0_l0000aooooo`;o00002?ooool2o`0004Gooooo000Nooooo`;o0000
2_ooool2o`0006oooooo0_l0000mooooo`;o0000AOooool2o`0004Gooooo000Nooooo`03o`000?oo
oooooooo01Cooooo0_l0003Zooooo`;o0000>?ooool2o`0000_ooooo000Nooooo`03o`000?oooooo
oooo01Cooooo0_l0000?ooooo`;o0000[_ooool2o`00063ooooo0_l000000ooooooo0000o`00000;
ooooo`007_ooool00ol0003oooooooooo`0Uooooo`;o0000N?ooool2o`0003Cooooo0_l0000Poooo
o`;o0000?_ooool2o`0000kooooo000Nooooo`03o`000?oooooooooo07cooooo0_l0000Qooooo`;o
00001_ooool2o`0000Gooooo0_l0000]ooooo`;o00006?ooool2o`0000_ooooo0_l0000Looooo`Co
00006Oooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo07cooooo0_l0000?ooooo`;o0000
0oooool2o`0001?ooooo0_l00005ooooo`;o00007?ooool2o`0000gooooo1?l0000Uooooo`?o0000
6oooool4o`0001Wooooo0_l00006ooooo`007_ooool00ol0003oooooooooo`2=ooooo`;o00000ooo
ool2o`0001cooooo0_l0000Jooooo`;o000000?oooooo`000?l000002_ooool2o`0002Sooooo0_l0
000Aooooo`;o0000;Oooool001gooooo0_l0001:ooooo`;o0000<_ooool2o`0001kooooo0_l0000B
ooooo`;o00007Oooool2o`0004Oooooo0_l0000]ooooo`007Oooool2o`0004[ooooo0_l0000boooo
o`;o00006oooool2o`000003ooooool0003o00000:Wooooo000Nooooo`03o`000?oooooooooo09Wo
oooo0_l0001^ooooo`;o00002?ooool2o`0000_ooooo0_l0000Mooooo`;o00001_ooool001kooooo
00?o0000ooooooooool0X_ooool2o`0002Cooooo0_l0000oooooo`;o00002?ooool2o`0000_ooooo
0_l0000@ooooo`;o00002oooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l0
001looooo`;o00009?ooool2o`0006Sooooo0_l0000Cooooo`007_ooool00ol0003oooooooooo`0T
ooooo`;o0000I_ooool2o`00027ooooo0_l0000Kooooo`;o0000NOooool001kooooo00?o0000oooo
ooooool0S?ooool2o`00027ooooo0_l0000Kooooo`;o0000Boooool2o`0002;ooooo0_l00008oooo
o`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@oooo
ooooool01?ooool00ol0003oooooooooo`0Tooooo`;o0000P_ooool2o`0006oooooo0_l0000Roooo
o`;o00002?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo02Cooooo0_l0000Yooooo`;o0000?_ooool2o`00
01Oooooo0_l0002Mooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006oooo
o`?o0000:Oooool2o`0002Cooooo0_l0000nooooo`;o00005oooool2o`0002cooooo0_l00018oooo
o`;o00009Oooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgooooo
o`0000Oooooo00?o0000ooooooooool0:Oooool2o`0003kooooo0_l00004ooooo`;o00007_ooool2
o`0004Gooooo0_l0000booooo`;o00005?ooool2o`0002Gooooo0003ooooo`05o`000?oooooooooo
ooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo06Wooooo0_l0
0004ooooo`;o00007_ooool2o`00013ooooo0_l0001Wooooo`;o0000>oooool000?ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0D?oo
ool2o`0001cooooo0_l0000Yooooo`;o00001_ooool2o`000:Cooooo0003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo053ooooo0_l0
000Dooooo`;o00001_ooool2o`0002Wooooo0_l0001booooo`;o0000>?ooool000?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0I_oo
ool2o`0001Kooooo0_l00004ooooo`;o0000K_ooool2o`0000Gooooo0_l0000@ooooo`;o0000>?oo
ool001kooooo00?o0000ooooooooool0<_ooool2o`0003Kooooo0_l0000Booooo`;o00001?ooool2
o`00023ooooo0_l0001<ooooo`;o00001Oooool2o`0004[ooooo000Nooooo`03o`000?oooooooooo
03;ooooo0_l0000fooooo`;o0000>_ooool2o`0002Kooooo0_l00017ooooo`;o0000;_ooool001ko
oooo00?o0000ooooooooool0B?ooool2o`0003Sooooo0_l0001:ooooo`;o00007_ooool2o`0000Wo
oooo0_l000000ooooooo0000o`000006ooooo`;o00004Oooool2o`0002Kooooo0_l00006ooooo`00
7_ooool00ol0003oooooooooo`0Nooooo`;o00006?ooool2o`0000kooooo0_l0000hooooo`;o0000
>_ooool2o`0001gooooo0_l0000?ooooo`;o00002Oooool2o`000003ooooool0003o000000Kooooo
0_l0000Vooooo`;o00004Oooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo01kooooo0_l0
000Hooooo`;o0000>oooool2o`0003kooooo0_l00007ooooo`;o00003Oooool2o`0000kooooo0_l0
001=ooooo`;o00006Oooool001kooooo00?o0000ooooooooool0F?ooool2o`0001_ooooo0_l0000n
ooooo`;o00005_ooool2o`0007Sooooo000Nooooo`03o`000?oooooooooo05Sooooo0_l0001[oooo
o`;o00001?ooool2o`0001kooooo0_l0001Jooooo`007_ooool00ol0003oooooooooo`1]ooooo`;o
00009oooool2o`0002gooooo0_l00004ooooo`;o00007_ooool2o`0000Cooooo0_l0001Dooooo`00
7_ooool00ol0003oooooooooo`0;ooooo`;o00009?ooool2o`0003[ooooo0_l00004ooooo`;o0000
2_ooool2o`0001Gooooo0_l0001Iooooo`;o0000<oooool2o`0000Oooooo0_l0000Fooooo`007_oo
ool00ol0003oooooooooo`0;ooooo`;o00009?ooool2o`00043ooooo0_l0000:ooooo`;o00004ooo
ool4o`0008kooooo0_l00007ooooo`;o00005_ooool001kooooo00?o0000ooooooooool0U?ooool4
o`0000;ooooo0_l0002[ooooo`007_ooool2o`0000[ooooo0_l0000<ooooo`;o00002Oooool2o`00
05[ooooo0_l0000Cooooo`;o00001Oooool2o`0003Sooooo0_l0001aooooo`007_ooool00ol0003o
ooooooooo`09ooooo`;o00003?ooool2o`0000Wooooo0_l0001Jooooo`;o00004oooool2o`0003oo
oooo0_l0001aooooo`007_ooool00ol0003oooooooooo`1Fooooo`;o00002?ooool2o`0006kooooo
0_l00009ooooo`;o0000HOooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo027ooooo0_l0
000Cooooo`;o00007_ooool2o`000003ooooool0003o000000Gooooo1?l0000jooooo`;o0000<?oo
ool2o`0000?ooooo0_l00004ooooo`;o0000HOooool2o`0000Oooooo000Nooooo`03o`000?oooooo
oooo027ooooo0_l0000Cooooo`;o00008Oooool2o`0000Kooooo0ol0000Qooooo`;o00005oooool2
o`00033ooooo0_l00003ooooo`;o00005_ooool2o`0005Sooooo000Nooooo`03o`000?oooooooooo
03Wooooo0_l00009ooooo`;o00006oooool2o`0002;ooooo0_l0000Eooooo`;o0000<_ooool2o`00
01_ooooo0_l00005ooooo`;o0000=Oooool2o`0001[ooooo000Nooooo`03o`000?oooooooooo01Wo
oooo0_l00009ooooo`;o00004oooool2o`0000Wooooo0_l0001Fooooo`;o0000E_ooool2o`0001?o
oooo0_l0000Gooooo`;o000000?oooooo`000?l000001?ooool2o`0001[ooooo000Nooooo`03o`00
0?oooooooooo01Wooooo0_l00009ooooo`Co00004Oooool2o`0002_ooooo0_l0001Kooooo`;o0000
A?ooool2o`0001Oooooo0_l000000ooooooo0000o`00000Pooooo`007_ooool00ol0003ooooooooo
o`0Iooooo`;o00002oooool2o`00013ooooo0_l0000/ooooo`;o000000?oooooo`000?l00000F?oo
ool2o`0000gooooo0_l0001Aooooo`;o00001oooool2o`0000Cooooo0_l0000Aooooo`007_ooool0
0ol0003oooooooooo`0Iooooo`;o00007Oooool2o`0002oooooo0_l0001Aooooo`;o00005?ooool2
o`00057ooooo0_l00007ooooo`;o00001?ooool2o`00017ooooo000Nooooo`03o`000?oooooooooo
00_ooooo0_l00019ooooo`;o00006Oooool2o`0001[ooooo0_l0000]ooooo`?o00000oooool2o`00
01Sooooo0_l0000Vooooo`;o00000_ooool2o`0003gooooo000Nooooo`03o`000?oooooooooo00_o
oooo0_l00019ooooo`;o00006Oooool2o`0001[ooooo0_l0000Looooo`;o00004?ooool2o`0000?o
oooo0_l0000Hooooo`;o00009_ooool2o`0000;ooooo0_l0000:ooooo`;o0000<Oooool001kooooo
00?o0000ooooooooool07Oooool2o`0006oooooo0_l0000Kooooo`;o0000:?ooool2o`0003gooooo
0_l0000aooooo`007_ooool00ol0003oooooooooo`04ooooo`;o00005oooool2o`0006oooooo0_l0
0015ooooo`;o0000<oooool2o`0002Oooooo1?l0000@ooooo`007_ooool00ol0003oooooooooo`04
ooooo`;o0000<_ooool2o`0003;ooooo0_l0001`ooooo`;o0000:_ooool2o`0001Kooooo0_l0000?
ooooo`Co00004?ooool001kooooo00?o0000ooooooooool0>?ooool2o`0003;ooooo0_l0000Uoooo
o`;o0000BOooool2o`0000gooooo0_l0000cooooo`;o00008oooool001kooooo0_l0002Dooooo`;o
0000;?ooool2o`0002[ooooo0_l0001Hooooo`007_ooool00ol0003oooooooooo`31ooooo`;o0000
JOooool2o`0001Wooooo000Nooooo`03o`000?oooooooooo0=kooooo0_l0001<ooooo`;o00006Ooo
ool001kooooo00?o0000ooooooooool0Foooool2o`0004Sooooo0_l0000Hooooo`;o00007Oooool2
o`0004Kooooo0_l0000>ooooo`;o00003oooool001kooooo00?o0000ooooooooool0Coooool2o`00
00[ooooo0_l00018ooooo`;o00004?ooool2o`0000Kooooo0_l00002ooooo`;o0000HOooool2o`00
00kooooo0_l0000?ooooo`007_ooool00ol0003oooooooooo`1?ooooo`;o0000?oooool2o`0002Go
oooo0_l0000:ooooo`;o0000NOooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo02?ooooo
0_l0000>ooooo`;o00006_ooool2o`0000Kooooo0_l0000gooooo`;o0000BOooool2o`00067ooooo
0_l00007ooooo`007_ooool00ol0003oooooooooo`04ooooo`;o00002oooool2o`0000Oooooo0_l0
0007ooooo`;o00003_ooool2o`00017ooooo0_l00007ooooo`;o00001_ooool2o`0001Oooooo0_l0
001Yooooo`?o00002_ooool2o`0002Oooooo0_l0000dooooo`007_ooool00ol0003oooooooooo`04
ooooo`;o00002oooool2o`0000Oooooo0_l0000Gooooo`;o00004Oooool2o`0002Sooooo0_l0001W
ooooo`;o000000?oooooo`000?l000001?ooool4o`0000;ooooo0_l0000;ooooo`;o00006_ooool2
o`0003Cooooo000Nooooo`03o`000?oooooooooo03?ooooo0_l0000Looooo`;o0000AOooool2o`00
03oooooo0_l00007ooooo`Co00003oooool2o`00053ooooo000Nooooo`03o`000?oooooooooo057o
oooo0_l00015ooooo`;o0000H?ooool2o`0001gooooo0_l0000/ooooo`007_ooool00ol0003ooooo
ooooo`0Mooooo`;o0000G_ooool2o`0007Wooooo1?l0000Mooooo`;o0000;?ooool001kooooo00?o
0000ooooooooool07Oooool2o`0005?ooooo0_l00009ooooo`;o0000NOooool2o`0004gooooo000N
ooooo`03o`000?oooooooooo06oooooo0_l000000ooooooo0000o`00001kooooo`Co0000E?ooool0
01kooooo00?o0000ooooooooool0;?ooool2o`00047ooooo0_l000000ooooooo0000o`00000`oooo
o`;o00002?ooool2o`0003oooooo1?l0001Dooooo`007_ooool00ol0003oooooooooo`0Hooooo`Co
00004?ooool2o`0005_ooooo0_l0000Iooooo`;o00002?ooool2o`0000cooooo0_l0001Oooooo`;o
00003Oooool2o`0001Wooooo000Nooooo`;o00000oooool2o`0001Cooooo1?l0000booooo`;o0000
6_ooool2o`0001?ooooo0_l00008ooooo`;o0000<Oooool2o`0004cooooo0_l0000Aooooo`;o0000
3Oooool2o`0001Wooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0001:ooooo`;o00006_oo
ool2o`0001?ooooo0_l00016ooooo`;o0000:Oooool2o`0001Kooooo0_l0000kooooo`007_ooool0
0ol0003oooooooooo`1^ooooo`;o0000Eoooool2o`0002Wooooo0_l0000eooooo`;o00007?ooool0
01kooooo00?o0000ooooooooool0K_ooool2o`0000Wooooo0_l0002^ooooo`;o00007?ooool001ko
oooo00?o0000ooooooooool05oooool2o`0001Sooooo0_l00016ooooo`;o0000Soooool2o`0001?o
oooo0_l0000Vooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o00005?ooool2o`0000;ooooo
0_l0002gooooo`;o00007_ooool2o`0001?ooooo0_l0000Vooooo`007_ooool00ol0003ooooooooo
o`0]ooooo`;o0000HOooool2o`0004_ooooo0_l00004ooooo`;o00001Oooool2o`0005_ooooo000N
ooooo`03o`000?oooooooooo02Oooooo0_l0000gooooo`;o0000;_ooool2o`0002Wooooo0_l0000P
ooooo`;o00000oooool3o`0006;ooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l0000goooo
o`;o0000FOooool2o`0002Gooooo0_l0000@ooooo`;o0000DOooool001kooooo00?o0000oooooooo
ool0Goooool2o`0003Wooooo0_l0001Hooooo`?o0000D?ooool001kooooo00?o0000ooooooooool0
??ooool2o`00027ooooo0_l0000Vooooo`;o00004Oooool2o`0005Wooooo0_l0000?ooooo`;o0000
?oooool001kooooo00?o0000ooooooooool0??ooool2o`0004Wooooo0_l0001mooooo`;o0000?ooo
ool001kooooo00?o0000ooooooooool0J?ooool2o`0000;ooooo0_l000000ooooooo0000o`00003F
ooooo`007_ooool00ol0003oooooooooo`1Cooooo`;o00004oooool2o`0000;ooooo0_l000000ooo
oooo0000o`00002Cooooo`;o0000@Oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool01Oooool2
o`0001Sooooo0_l0000@ooooo`;o00008?ooool2o`0000cooooo0_l0001Eooooo`;o00006?ooool2
o`0001kooooo0_l0000@ooooo`;o00004oooool2o`0000Oooooo0_l0000Sooooo`000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_oo
ool00ol0003oooooooooo`05ooooo`;o00006?ooool2o`00013ooooo0_l00005ooooo`;o00009ooo
ool2o`0001Oooooo0_l0000Wooooo`;o00003oooool2o`0000;ooooo0_l0000Hooooo`;o00007_oo
ool2o`0001Sooooo0_l0000;ooooo`;o00001oooool2o`0000Kooooo0_l0000Kooooo`000oooool0
1Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000
>?ooool2o`00043ooooo0_l0000Wooooo`;o00003oooool2o`0002Gooooo0_l0000Pooooo`;o0000
3Oooool2o`0001cooooo0_l0000Kooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo
00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`;o00009?ooool2o`0004kooooo0_l0001Vooooo`;o
00002oooool2o`0001?ooooo0_l00018ooooo`000oooool01Ol0003ooooooooooooooooo000000_o
oooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo02?ooooo0_l0000Loooo
o`;o00001_ooool2o`0000Kooooo0_l0000Fooooo`;o00002?ooool2o`0002Sooooo0_l00019oooo
o`;o0000GOooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo
00Sooooo00?o0000ooooooooool0@Oooool2o`0000Kooooo0_l00006ooooo`;o00005_ooool2o`00
03;ooooo1?l0001^ooooo`Co0000=?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0Noooool2o`0002;ooooo0_l00005oooo
o`;o00004Oooool2o`0005Cooooo1?l0000dooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`1kooooo`;o00007oooool2
o`0000Sooooo0_l0000Aooooo`Co0000DOooool2o`0001cooooo0_l00003ooooo`;o00005?ooool0
01kooooo00?o0000ooooooooool0W?ooool2o`0000Sooooo0_l0000Cooooo`;o00004Oooool2o`00
00Sooooo0_l0000dooooo`;o00007?ooool2o`0000?ooooo0_l0000Dooooo`007_ooool00ol0003o
ooooooooo`1Xooooo`;o0000??ooool2o`0002Kooooo0_l00008ooooo`;o00001_ooool2o`0003Co
oooo0_l0000_ooooo`007_ooool00ol0003oooooooooo`0Booooo`?o0000Doooool2o`0006?ooooo
0_l00003ooooo`;o00000_ooool2o`0000Sooooo0_l0000dooooo`;o00003oooool2o`0001kooooo
000Nooooo`03o`000?oooooooooo01;ooooo0ol0001Kooooo`;o0000Foooool2o`0000?ooooo0_l0
0002ooooo`;o0000Coooool2o`0001kooooo000Nooooo`03o`000?oooooooooo073ooooo0_l0002H
ooooo`;o00003oooool2o`0002[ooooo000Nooooo`;o0000HOooool2o`0002gooooo0_l00012oooo
o`;o0000=Oooool2o`0000oooooo0_l0000Zooooo`007Oooool3o`0001Sooooo0_l0000jooooo`;o
00002_ooool3o`0002gooooo0_l0000Fooooo`;o0000:_ooool2o`0002Gooooo0_l0000_ooooo`Co
00006?ooool001gooooo0_l0000Iooooo`;o00001_ooool2o`0000[ooooo0_l0000Vooooo`;o0000
0oooool2o`0000Gooooo0_l00016ooooo`;o0000:_ooool2o`0002Gooooo0_l0000_ooooo`Co0000
6?ooool001kooooo00?o0000ooooooooool07oooool2o`0000[ooooo0_l0000[ooooo`;o0000>ooo
ool2o`0000[ooooo0_l0000`ooooo`;o0000G_ooool2o`0001;ooooo000Nooooo`03o`000?oooooo
oooo00;o0000Toooool2o`0000[ooooo0_l0000@ooooo`;o0000@?ooool2o`0003cooooo0_l0000B
ooooo`007_ooool00ol0003oooooooooo`02o`0004_ooooo0_l0001Looooo`;o00001_ooool2o`00
043ooooo0_l0001@ooooo`007_ooool2o`00043ooooo0_l0000<ooooo`;o0000F_ooool4o`00013o
oooo0_l0000Rooooo`;o0000I?ooool001kooooo00?o0000ooooooooool0?oooool2o`0000gooooo
0_l0000]ooooo`;o00009Oooool2o`0000?ooooo0_l0000Booooo`;o00008_ooool2o`0003oooooo
0_l0000@ooooo`;o00002?ooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l0
0011ooooo`;o00007oooool2o`0000cooooo0_l0000Uooooo`;o0000O?ooool2o`00013ooooo0_l0
0008ooooo`;o00001oooool001kooooo00?o0000ooooooooool02oooool2o`0000kooooo0_l0000f
ooooo`;o00006_ooool2o`0006?ooooo0_l00018ooooo`;o00009oooool001kooooo00?o0000oooo
ooooool00_ooool2o`0001Oooooo0_l0000Sooooo`;o00004Oooool2o`0007oooooo0_l0000Goooo
o`;o0000;oooool2o`0002Oooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0000Dooooo`;o
00009?ooool4o`00017ooooo0_l00029ooooo`;o00003Oooool2o`0005Sooooo000Nooooo`03o`00
0?oooooooooo01Sooooo0_l0000Tooooo`;o00006oooool2o`00087ooooo0_l0000Gooooo`;o0000
<?ooool2o`0001cooooo000Nooooo`03o`000?oooooooooo037ooooo0_l0000Cooooo`;o00004ooo
ool2o`0009[ooooo0_l0000Rooooo`;o00003?ooool2o`0000?ooooo0_l0000Gooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`;o00003?ooool2o`0001?ooooo0_l0000Iooooo`;o0000Poooool2
o`0003?ooooo0_l0000>ooooo`;o000000Coooooo`000?l0003o00005_ooool001kooooo00?o0000
ooooooooool04?ooool2o`00017ooooo0_l0000looooo`;o0000Poooool2o`0004?ooooo0_l00002
ooooo`;o00005_ooool001kooooo00?o0000ooooooooool04?ooool2o`0006Gooooo0_l0001;oooo
o`;o00002_ooool2o`0000gooooo0_l0000?ooooo`;o0000EOooool001kooooo00?o0000oooooooo
ool06_ooool2o`0002Wooooo0_l0000Rooooo`;o00003?ooool2o`0000Cooooo0_l0000Fooooo`;o
00001oooool2o`0002Cooooo0_l0000:ooooo`;o00003Oooool2o`0000oooooo0_l0000Oooooo`;o
0000=?ooool001kooooo00?o0000ooooooooool06_ooool2o`0001Sooooo0_l0000?ooooo`;o0000
8_ooool2o`0001;ooooo0_l0000Fooooo`;o00001oooool2o`0002?ooooo0_l0000Iooooo`;o0000
<Oooool2o`0003Cooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0000Kooooo`;o0000SOoo
ool2o`0001Wooooo0_l0001Wooooo`007_ooool01?l0003oooooooooooooool2o`0001Cooooo0_l0
003ooooooboooooo000Nooooo`04o`000?ooooooooooooooo`;o00005?ooool2o`0006Oooooo0_l0
002Looooo`;o00009oooool001kooooo0_l0000Hooooo`;o00007_ooool2o`0004Oooooo0_l0000_
ooooo`;o0000Joooool2o`0002Oooooo000Nooooo`03o`000?oooooooooo02;ooooo0_l0000Coooo
o`;o0000=?ooool2o`0004;ooooo0_l0001Wooooo`;o00007?ooool2o`0000gooooo000Nooooo`03
o`000?oooooooooo02;ooooo0_l00007ooooo`;o0000@?ooool2o`000:_ooooo0_l00009ooooo`;o
00004Oooool2o`0000gooooo000Nooooo`03o`000?oooooooooo01?ooooo0_l0000Fooooo`;o0000
n?ooool2o`0000?ooooo0_l0000Kooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o0000/?oo
ool2o`0006?ooooo0_l0000Kooooo`007_ooool00ol0003oooooooooo`35ooooo`;o0000P?ooool0
01kooooo00?o0000ooooooooool07Oooool2o`0005[ooooo0_l0000Mooooo`;o00005oooool2o`00
00kooooo0_l0000Mooooo`;o0000;?ooool2o`0003Oooooo000Nooooo`03o`000?oooooooooo01go
oooo0_l0000Jooooo`;o0000?_ooool2o`0001gooooo0_l0000Gooooo`;o00003_ooool4o`0001_o
oooo0_l0000<ooooo`;o00007Oooool3o`0003Oooooo000Nooooo`03o`000?oooooooooo03Wooooo
0_l0000Hooooo`;o00005?ooool2o`0002kooooo0_l0000Xooooo`;o0000:Oooool2o`0001gooooo
0_l0000hooooo`007_ooool00ol0003oooooooooo`1Cooooo`;o00005?ooool2o`0002kooooo0_l0
000Qooooo`;o0000OOooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo03Oooooo0_l00018
ooooo`;o00008oooool2o`0001Cooooo0_l0001mooooo`;o00002_ooool001kooooo00?o0000oooo
ooooool09?ooool4o`0000oooooo0_l0000/ooooo`;o00006_ooool2o`00023ooooo0_l000000ooo
oooo0000o`00000Uooooo`;o0000N?ooool001kooooo00?o0000ooooooooool09?ooool4o`0003go
oooo0_l0000looooo`;o00009Oooool2o`000003ooooool0003o000005Sooooo0_l0000Nooooo`00
7_ooool00ol0003oooooooooo`28ooooo`;o00003Oooool2o`00037ooooo0_l0000Nooooo`;o0000
>_ooool3o`0000Kooooo0_l0000=ooooo`;o00001oooool001kooooo00?o0000ooooooooool0R?oo
ool2o`0000gooooo0_l0001Aooooo`;o00005Oooool2o`0002?ooooo0_l00007ooooo`;o00003Ooo
ool2o`0000Oooooo000Nooooo`03o`000?oooooooooo04oooooo0_l0000Kooooo`;o00003?ooool2
o`0008Gooooo1?l00012ooooo`007_ooool2o`00053ooooo0_l0000Kooooo`;o00003?ooool2o`00
01Gooooo0_l0001`ooooo`;o0000@_ooool001kooooo00?o0000ooooooooool0:Oooool2o`0004oo
oooo0_l0000Eooooo`;o0000[?ooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo027ooooo
0_l00006ooooo`;o0000Coooool2o`000<?ooooo0_l00006ooooo`007_ooool00ol0003ooooooooo
o`0Qooooo`;o00002_ooool2o`000?Cooooo0_l0000Rooooo`007_ooool00ol0003oooooooooo`0/
ooooo`?o0000m?ooool2o`0002;ooooo000Nooooo`03o`000?oooooooooo02cooooo0_l0000Moooo
o`;o0000GOooool2o`0004_ooooo0_l0001>ooooo`007_ooool00ol0003oooooooooo`07ooooo`;o
0000@_ooool2o`0005gooooo0_l0000Zooooo`;o00007oooool2o`0004kooooo000Nooooo`03o`00
0?oooooooooo00Oooooo0_l0000Uooooo`;o0000C_ooool2o`0005Kooooo0_l00003ooooo`;o0000
7oooool2o`0004Wooooo000Nooooo`03o`000?oooooooooo02kooooo0_l0000Looooo`;o0000<?oo
ool2o`0005_ooooo0_l0000Oooooo`;o0000BOooool001kooooo00?o0000ooooooooool04?ooool2
o`0003[ooooo0_l0000[ooooo`;o0000c?ooool001kooooo00?o0000ooooooooool01?ooool2o`00
00[ooooo0_l00007ooooo`;o00008_ooool2o`0003[ooooo0_l0000Sooooo`;o0000Yoooool001ko
oooo00?o0000ooooooooool01?ooool2o`0001?ooooo0_l0000Rooooo`;o00004Oooool2o`0004co
oooo0_l00028ooooo`;o00007Oooool001kooooo00?o0000ooooooooool07Oooool2o`00037ooooo
0_l0000Nooooo`;o00006?ooool2o`0006[ooooo0_l0000`ooooo`;o00007Oooool001kooooo00?o
0000ooooooooool07Oooool2o`00057ooooo0_l00002ooooo`;o00005?ooool2o`0003Cooooo0_l0
000dooooo`;o0000Coooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool07oooool2o`0002_ooooo
0_l0000Vooooo`;o0000B_ooool2o`0000gooooo0_l00007ooooo`;o0000KOooool000?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Ko
oooo00?o0000ooooooooool07oooool2o`0002Cooooo0_l00005ooooo`;o0000A_ooool2o`0001Oo
oooo0_l0000Pooooo`;o00001oooool2o`00023ooooo0_l0001;ooooo`000oooool01Ol@413ooooo
oooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000AOooool2o`00
04gooooo0_l0000Gooooo`;o0000BOooool4o`0003oooooo0_l0000:ooooo`000oooool01Ol0003o
oooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooo
oooo0?Sooooo0_l00011ooooo`;o00002_ooool000?ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`0mooooo`;o0000=_oo
ool2o`000=3ooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooo
oonj^[[o410@00Kooooo00?o0000ooooooooool0?Oooool2o`0002gooooo0_l00007ooooo`?o0000
b?ooool2o`0000Gooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zj
oooooonj^[[o000000Kooooo00?o0000ooooooooool0JOooool2o`000003ooooool0003o000000So
oooo0_l0000Qooooo`;o0000D_ooool2o`0001?ooooo0_l0000Yooooo`;o00004Oooool2o`0000Go
oooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY
00Kooooo00?o0000ooooooooool0JOooool2o`0002[ooooo0_l00002ooooo`;o0000D_ooool2o`00
01?ooooo0_l0000Yooooo`;o00006?ooool001kooooo00?o0000ooooooooool05Oooool2o`0000[o
oooo0_l0000Uooooo`;o00005?ooool2o`0001Gooooo0_l0000Nooooo`;o0000=?ooool2o`0007[o
oooo000Nooooo`03o`000?oooooooooo01Gooooo0_l0000:ooooo`;o00003oooool2o`0001Cooooo
0_l0000Dooooo`;o00005Oooool2o`0004;ooooo0_l0000@ooooo`;o0000E?ooool2o`0002Cooooo
000Nooooo`03o`000?oooooooooo02_ooooo0_l00005ooooo`;o00008_ooool2o`00067ooooo0_l0
000Booooo`;o0000D_ooool2o`0002Cooooo000Nooooo`03o`000?oooooooooo02_ooooo0_l0000;
ooooo`;o00007?ooool2o`0002cooooo0_l0000oooooo`;o00001_ooool2o`0007Sooooo000Noooo
o`03o`000?oooooooooo00?ooooo0_l0000cooooo`;o0000B_ooool2o`0000Oooooo0_l0000foooo
o`;o0000P?ooool001kooooo00?o0000ooooooooool00oooool2o`0000gooooo0_l0001iooooo`;o
0000MOooool2o`0001Gooooo0_l00009ooooo`;o00002_ooool2o`0001?ooooo000Nooooo`04o`00
0?oooooo0000o`00017ooooo0_l0000aooooo`;o0000Y?ooool2o`0001Oooooo0_l0000Eooooo`;o
00002Oooool2o`0000[ooooo0_l0000Cooooo`007_ooool01?l0003oooooo`000?l00014ooooo`;o
00000oooool2o`0001Sooooo0_l0000_ooooo`;o0000E?ooool2o`0005[ooooo000Nooooo`03o`00
0?oooooooooo00Sooooo0_l0000Booooo`;o0000;?ooool2o`0001Sooooo0_l0000_ooooo`;o0000
/?ooool001kooooo00?o0000ooooooooool02?ooool2o`0001;ooooo0_l0000<ooooo`;o0000Jooo
ool2o`000:kooooo000Nooooo`03o`000?oooooooooo02[ooooo0_l00005ooooo`;o0000I?ooool2
o`0007Wooooo0_l0000cooooo`007_ooool2o`0003;ooooo0_l0000]ooooo`;o0000IOooool2o`00
02kooooo0_l0000Iooooo`;o0000<oooool001kooooo00?o0000ooooooooool05_ooool2o`0003?o
oooo0_l0000Cooooo`;o00007_ooool2o`0004Gooooo0_l0000Jooooo`;o00004_ooool2o`0001Oo
oooo0_l0000eooooo`007_ooool00ol0003oooooooooo`0Fooooo`;o0000<oooool2o`0003?ooooo
0_l0001Qooooo`;o0000:oooool2o`0003Gooooo000Nooooo`03o`000?oooooooooo06kooooo0_l0
0023ooooo`;o0000D_ooool001kooooo00?o0000ooooooooool0K_ooool2o`0007_ooooo0_l00006
ooooo`;o0000D_ooool001kooooo00?o0000ooooooooool0>?ooool2o`0001gooooo0_l0002Boooo
o`;o00007oooool2o`0003Wooooo000Nooooo`04o`000?oooooo0000o`0003Oooooo0_l0000Moooo
o`;o0000Soooool2o`00017ooooo0_l00007ooooo`;o00001_ooool2o`0001Oooooo0_l0000Poooo
o`007_ooool01?l0003oooooo`000?l00012ooooo`;o00000oooool2o`0005Oooooo0_l00015oooo
o`;o00004Oooool2o`0000Oooooo0_l0000Oooooo`;o00005oooool2o`0000Oooooo000Nooooo`03
o`000?oooooooooo04?ooooo0_l00003ooooo`;o0000Eoooool2o`0002kooooo0_l0001[ooooo`;o
00001oooool001kooooo00?o0000ooooooooool0dOooool2o`0002Wooooo0_l0000>ooooo`;o0000
4oooool2o`0002Cooooo000Nooooo`03o`000?oooooooooo043ooooo0_l0000`ooooo`;o00005_oo
ool2o`0003kooooo0_l0000`ooooo`;o00003_ooool2o`0001?ooooo0_l0000Cooooo`;o00003ooo
ool001kooooo00?o0000ooooooooool0@?ooool2o`00033ooooo0_l0000Fooooo`;o0000?_ooool2
o`0001[ooooo0_l0000fooooo`;o00005_ooool2o`0000oooooo000Nooooo`03o`000?oooooooooo
0<;ooooo0_l0000Rooooo`;o00002?ooool2o`0002cooooo0_l0000Wooooo`007_ooool00ol0003o
ooooooooo`2Nooooo`;o00008_ooool2o`0002cooooo0_l0001Eooooo`007_ooool00ol0003ooooo
ooooo`02ooooo`;o0000E_ooool2o`00027ooooo0_l0000Oooooo`;o00006Oooool2o`0003Oooooo
0_l0000aooooo`;o00002oooool2o`0001?ooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0
001Fooooo`;o00005_ooool2o`0000Wooooo0_l0000Sooooo`;o00005Oooool2o`0003Oooooo0_l0
000^ooooo`;o000000?oooooo`000?l000002oooool2o`0001?ooooo000Nooooo`;o000000?ooooo
o`000?l00000L?ooool2o`0002kooooo0_l0001?ooooo`;o0000;?ooool3o`0002?ooooo000Noooo
o`03o`000?oooooooooo00;o0000eoooool2o`0001Sooooo0_l0000/ooooo`;o00009?ooool001ko
oooo0_l0003Jooooo`;o00009?ooool2o`00023ooooo0_l0000Tooooo`007_ooool2o`0007[ooooo
0_l00024ooooo`;o0000A_ooool001kooooo00?o0000ooooooooool0NOooool2o`000<cooooo000N
ooooo`03o`000?oooooooooo05;ooooo0_l0003[ooooo`;o00001_ooool001kooooo00?o0000oooo
ooooool00oooool2o`0004gooooo0_l0001mooooo`;o00005_ooool2o`0005Cooooo0_l00006oooo
o`007_ooool00ol0003oooooooooo`03ooooo`;o0000U_ooool2o`0003Cooooo0_l0000Fooooo`;o
0000:oooool2o`0002oooooo000Nooooo`03o`000?oooooooooo08cooooo0_l0000=ooooo`;o0000
0oooool2o`0007Cooooo0_l0000_ooooo`007_ooool00ol0003oooooooooo`1Cooooo`;o0000=ooo
ool2o`0001;ooooo0_l0002Uooooo`007_ooool00ol0003oooooooooo`0^ooooo`;o00008_ooool3
o`000?;ooooo000Nooooo`03o`000?oooooooooo02kooooo1?l0000Pooooo`;o0000K?ooool2o`00
05kooooo0_l0000Uooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o00006Oooool2o`0003co
oooo0_l0000booooo`;o00001?ooool2o`0001Kooooo0_l0000`ooooo`;o0000;?ooool2o`0002Go
oooo000Nooooo`03o`000?oooooooooo01Gooooo0_l0000Rooooo`;o0000<oooool2o`0002?ooooo
0_l0000:ooooo`;o000000?oooooo`000?l000001?ooool2o`00027ooooo0_l0000?ooooo`;o0000
5?ooool2o`00017ooooo0_l00010ooooo`007_ooool00ol0003oooooooooo`0iooooo`;o0000F?oo
ool2o`0000[ooooo0_l0000Zooooo`;o00003oooool2o`0002Oooooo0_l0000?ooooo`;o0000;ooo
ool001kooooo00?o0000ooooooooool0FOooool2o`00073ooooo0_l0000Sooooo`;o00003Oooool2
o`0000?ooooo1?l0000>ooooo`;o000000?oooooo`000?l00000;?ooool001kooooo0_l0001Joooo
o`;o0000I_ooool2o`0002gooooo0_l0000=ooooo`;o00000oooool4o`00017ooooo0_l0000/oooo
o`007_ooool00ol0003oooooooooo`1Dooooo`;o0000Joooool2o`0000;ooooo0_l0001Qooooo`;o
00001oooool2o`0001Cooooo000Nooooo`03o`000?oooooooooo05Cooooo0_l00002ooooo`;o0000
Joooool2o`00067ooooo0_l000000ooooooo0000o`000004ooooo`;o00005?ooool001kooooo00?o
0000ooooooooool05oooool2o`0003oooooo0_l0000<ooooo`;o0000FOooool2o`0006Sooooo0_l0
000Jooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o00002_ooool2o`0004gooooo0_l00002
ooooo`;o0000EOooool2o`0008Cooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l0001Aoooo
o`;o00002_ooool2o`00037ooooo0_l0000_ooooo`;o0000;_ooool2o`0004Oooooo000Nooooo`03
o`000?oooooooooo02Kooooo0_l0000>ooooo`;o00005?ooool2o`00013ooooo0_l0000Kooooo`;o
00008?ooool2o`0002oooooo0_l0000/ooooo`Co00002_ooool2o`0000Kooooo0_l0000Uooooo`;o
00003?ooool001kooooo00?o0000ooooooooool09_ooool2o`0000kooooo0_l0000Dooooo`;o0000
5oooool2o`0001Cooooo0_l0000Yooooo`;o0000E?ooool2o`0000cooooo0_l00006ooooo`;o0000
9Oooool2o`0000cooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0001?ooooo`;o00004?oo
ool2o`0003oooooo0_l0000cooooo`;o0000=Oooool2o`0003?ooooo000Nooooo`03o`000?oooooo
oooo00;ooooo0_l0001?ooooo`;o0000Q_ooool2o`0001?ooooo0_l0000Pooooo`;o0000<oooool0
01kooooo00?o0000ooooooooool07oooool2o`0005cooooo0_l000000ooooooo0000o`00000[oooo
o`;o0000@Oooool2o`0004oooooo0_l00004ooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o
00002?ooool2o`0004Sooooo0_l0000Booooo`;o000000?oooooo`000?l00000:oooool2o`0005;o
oooo0_l0000Uooooo`;o00005oooool2o`0000Cooooo000Nooooo`03o`000?oooooooooo01Gooooo
0_l0000cooooo`;o00007Oooool2o`0001Cooooo0_l00020ooooo`;o00009Oooool2o`0001gooooo
000Nooooo`03o`000?oooooooooo00kooooo0_l0000jooooo`;o0000<oooool2o`0008kooooo0_l0
000fooooo`005?ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool03_ooool2
o`0002[ooooo0_l0002@ooooo`;o0000@Oooool2o`0003Kooooo000Fooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0>_ooool2o`00093ooooo0_l0001Uooooo`;o00004_ooool001Ko
oooo00?o0000ooooooooool01Oooool3o`000?oooooo=?ooool2o`0001;ooooo000Fooooo`03o`00
0?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool0
0ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Co
oooo00?oEEEEofIVI_l00000oooooomBooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.37245 .73324 Mdot
.72356 .54727 Mdot
.65875 .96715 Mdot
.05773 .418 Mdot
.08542 .72181 Mdot
.79264 .76996 Mdot
.2889 .61744 Mdot
.28142 .73581 Mdot
.57288 .30951 Mdot
.96656 .02947 Mdot
.58424 .17305 Mdot
.71549 .52605 Mdot
.04041 .65998 Mdot
.1098 .78971 Mdot
.54192 .3082 Mdot
.00206 .78294 Mdot
.36925 .90645 Mdot
.73474 .50815 Mdot
.94547 .95013 Mdot
.59877 .22708 Mdot
.63945 .29725 Mdot
.82162 .06461 Mdot
.46874 .87754 Mdot
.35683 .12525 Mdot
.58123 .22005 Mdot
.96389 .28453 Mdot
.75327 .12396 Mdot
.54147 .38713 Mdot
.89406 .47583 Mdot
.29633 .55284 Mdot
.41948 .52491 Mdot
.14241 .71597 Mdot
.35522 .77779 Mdot
.1683 .12907 Mdot
.62862 .78578 Mdot
.29195 .49342 Mdot
.92558 .5181 Mdot
.38523 .01638 Mdot
.36247 .76666 Mdot
.88805 .08598 Mdot
.21165 .49251 Mdot
.54542 .17894 Mdot
.19766 .69933 Mdot
.1243 .59659 Mdot
.39845 .57286 Mdot
.76918 .54672 Mdot
.05193 .37031 Mdot
.83077 .38033 Mdot
.50863 .78457 Mdot
.82179 .64936 Mdot
.48316 .55766 Mdot
.0844 .46109 Mdot
.2354 .43235 Mdot
.99216 .36194 Mdot
.61911 .25622 Mdot
.44249 .44426 Mdot
.32408 .93552 Mdot
.94405 .62986 Mdot
.02375 .45935 Mdot
.01827 .56717 Mdot
.35999 .57033 Mdot
.44434 .70749 Mdot
.27848 .21392 Mdot
.82396 .09219 Mdot
.44004 .54154 Mdot
.44645 .15372 Mdot
.66071 .52086 Mdot
.61981 .47981 Mdot
.42266 .69761 Mdot
.998 .05816 Mdot
.65343 .60349 Mdot
.56972 .89916 Mdot
.21062 .79346 Mdot
.85808 .08413 Mdot
.95861 .78013 Mdot
.26422 .29104 Mdot
.60459 .40424 Mdot
.02061 .8003 Mdot
.6121 .25114 Mdot
.46782 .03248 Mdot
.55509 .20916 Mdot
.44533 .28136 Mdot
.22625 .16716 Mdot
.51238 .48723 Mdot
.01771 .01055 Mdot
.52001 .59204 Mdot
.61782 .75905 Mdot
.73009 .26672 Mdot
.5736 .23953 Mdot
.78576 .34121 Mdot
.95374 .11694 Mdot
.22707 .01371 Mdot
.37228 .79867 Mdot
.95022 .18323 Mdot
.71624 .98831 Mdot
.63714 .69762 Mdot
.91582 .72152 Mdot
.8173 .6061 Mdot
.4847 .65178 Mdot
.93029 .01536 Mdot
.65998 .16702 Mdot
.78499 .40331 Mdot
.94981 .72324 Mdot
.12065 .20258 Mdot
.03631 .93267 Mdot
.16984 .1116 Mdot
.78988 .34755 Mdot
.20822 .15665 Mdot
.15653 .36259 Mdot
.16071 .57732 Mdot
.88288 .75012 Mdot
.26972 .25798 Mdot
.57095 .66831 Mdot
.10188 .45692 Mdot
.48394 .38639 Mdot
.15617 .71724 Mdot
.6935 .65661 Mdot
.20821 .00672 Mdot
.11373 .83655 Mdot
.68825 .7913 Mdot
.77439 .69384 Mdot
.52099 .95022 Mdot
.2843 .00543 Mdot
.26505 .55371 Mdot
.29935 .23926 Mdot
.49335 .66087 Mdot
.87885 .92765 Mdot
.12989 .44051 Mdot
.186 .79626 Mdot
.54258 .21845 Mdot
.13001 .36636 Mdot
.38002 .38331 Mdot
.38058 .91434 Mdot
.08696 .32471 Mdot
.66808 .88562 Mdot
.40384 .78009 Mdot
.4389 .09698 Mdot
.14633 .06322 Mdot
.69198 .91816 Mdot
.38955 .65386 Mdot
.37484 .87213 Mdot
.79929 .91765 Mdot
.92194 .4096 Mdot
.30908 .66629 Mdot
.05042 .26379 Mdot
.23483 .79799 Mdot
.14251 .7144 Mdot
.38678 .42643 Mdot
.06898 .56147 Mdot
.88248 .25391 Mdot
.27783 .18773 Mdot
.63572 .49353 Mdot
.31945 .54646 Mdot
.92937 .71996 Mdot
.85337 .39482 Mdot
.03348 .64142 Mdot
.96185 .30927 Mdot
.46424 .84397 Mdot
.41902 .2131 Mdot
.30236 .41951 Mdot
.03539 .09801 Mdot
.80053 .41302 Mdot
.02075 .87491 Mdot
.21323 .0646 Mdot
.83641 .39489 Mdot
.85312 .05372 Mdot
.59169 .83712 Mdot
.88552 .10842 Mdot
.95155 .46955 Mdot
.27765 .48485 Mdot
.15749 .39934 Mdot
.9952 .68622 Mdot
.27294 .94388 Mdot
.48055 .90486 Mdot
.20431 .16104 Mdot
.0753 .49386 Mdot
.26298 .98008 Mdot
.06697 .22472 Mdot
.94167 .19491 Mdot
.59419 .91262 Mdot
.01311 .66783 Mdot
.88274 .70626 Mdot
.25676 .25435 Mdot
.14129 .81617 Mdot
.65055 .64276 Mdot
.31449 .8583 Mdot
.10497 .34861 Mdot
.79034 .82636 Mdot
.62335 .69544 Mdot
.65376 .98424 Mdot
.28165 .05584 Mdot
.50964 .83583 Mdot
.31286 .75023 Mdot
.58527 .75631 Mdot
.873 .88772 Mdot
.70392 .65802 Mdot
.79389 .54577 Mdot
.58776 .63518 Mdot
.22638 .77837 Mdot
.6904 .39766 Mdot
.3262 .43323 Mdot
.8969 .62044 Mdot
.43038 .82677 Mdot
.2568 .99898 Mdot
.36816 .21094 Mdot
.21306 .87152 Mdot
.55641 .62927 Mdot
.81112 .93783 Mdot
.89883 .89644 Mdot
.42653 .99407 Mdot
.27683 .87373 Mdot
.16932 .78368 Mdot
.02182 .33875 Mdot
.84056 .47234 Mdot
.80178 .87682 Mdot
.57979 .4809 Mdot
.45668 .17462 Mdot
.77527 .25078 Mdot
.95843 .82681 Mdot
.45892 .7698 Mdot
.88553 .85535 Mdot
.12933 .43348 Mdot
.9617 .11075 Mdot
.39483 .58759 Mdot
.13657 .06764 Mdot
.99219 .77764 Mdot
.87143 .91443 Mdot
.03452 .4168 Mdot
.44342 .48995 Mdot
.91114 .59428 Mdot
.15582 .92856 Mdot
.14659 .72297 Mdot
.3209 .5962 Mdot
.13944 .82904 Mdot
.23156 .90881 Mdot
.04091 .00048 Mdot
.35848 .33258 Mdot
.70631 .53275 Mdot
.15429 .32435 Mdot
.36987 .66389 Mdot
.27443 .77388 Mdot
.37572 .93287 Mdot
.96358 .03933 Mdot
.22018 .94609 Mdot
.86058 .55315 Mdot
.37427 .00649 Mdot
.25908 .85306 Mdot
.56378 .73995 Mdot
.36645 .17069 Mdot
.19869 .57272 Mdot
.44231 .45765 Mdot
.63277 .31951 Mdot
.17288 .28922 Mdot
.72711 .90916 Mdot
.86307 .44974 Mdot
.13194 .78727 Mdot
.29092 .70496 Mdot
.0589 .97967 Mdot
.27992 .30789 Mdot
.83102 .9949 Mdot
.48292 .8726 Mdot
.64091 .31375 Mdot
.74975 .2379 Mdot
.51983 .28486 Mdot
.08932 .04217 Mdot
.15524 .38526 Mdot
.38699 .00083 Mdot
.25817 .62053 Mdot
.51847 .20815 Mdot
.94904 .7192 Mdot
.85768 .25744 Mdot
.24695 .21552 Mdot
.42103 .9068 Mdot
.40403 .64507 Mdot
.2417 .80837 Mdot
.75009 .804 Mdot
.77161 .86643 Mdot
.80621 .2279 Mdot
.44897 .36989 Mdot
.02289 .84913 Mdot
.7294 .19025 Mdot
.43193 .12776 Mdot
.74991 .6098 Mdot
.84382 .6553 Mdot
.29392 .23854 Mdot
.72429 .37915 Mdot
.72702 .28329 Mdot
.84836 .25644 Mdot
.83299 .28803 Mdot
.79936 .96087 Mdot
.03377 .6742 Mdot
.17044 .24935 Mdot
.98615 .9022 Mdot
.85211 .58042 Mdot
.88044 .31669 Mdot
.84269 .26439 Mdot
.4017 .47312 Mdot
.46671 .37461 Mdot
.72844 .47079 Mdot
.22371 .07891 Mdot
.53371 .34061 Mdot
.66246 .20945 Mdot
.35399 .46214 Mdot
.01103 .09509 Mdot
.57647 .5607 Mdot
.34158 .42275 Mdot
.41507 .13561 Mdot
.60222 .01257 Mdot
.54781 .91752 Mdot
.6464 .73401 Mdot
.3967 .55012 Mdot
.69286 .56743 Mdot
.07952 .33774 Mdot
.89432 .27265 Mdot
.12444 .13946 Mdot
.12886 .48724 Mdot
.88097 .82649 Mdot
.2406 .66001 Mdot
.54025 .27433 Mdot
.62163 .27298 Mdot
.88989 .90206 Mdot
.9426 .93289 Mdot
.59756 .29218 Mdot
.64916 .98622 Mdot
.46562 .34884 Mdot
.72137 .55794 Mdot
.82885 .36053 Mdot
.49893 .44987 Mdot
.91936 .0202 Mdot
.23067 .29277 Mdot
.9895 .85198 Mdot
.15223 .8206 Mdot
.46654 .50225 Mdot
.62839 .02668 Mdot
.01381 .64798 Mdot
.36175 .73175 Mdot
.29399 .9813 Mdot
.48784 .5991 Mdot
.91991 .58504 Mdot
.64189 .23873 Mdot
.94815 .083 Mdot
.1487 .80558 Mdot
.23441 .54782 Mdot
.65969 .91101 Mdot
.17884 .56303 Mdot
.37654 .95072 Mdot
.30186 .24112 Mdot
.93173 .74046 Mdot
.47991 .60848 Mdot
.03487 .63859 Mdot
.26943 .06308 Mdot
.92223 .61325 Mdot
.16816 .59966 Mdot
.67784 .1669 Mdot
.0379 .72664 Mdot
.99467 .93312 Mdot
.10953 .19551 Mdot
.2002 .52917 Mdot
.60767 .46006 Mdot
.78926 .10991 Mdot
.92622 .76281 Mdot
.56172 .73989 Mdot
.49424 .68308 Mdot
.85597 .37117 Mdot
.96033 .42999 Mdot
.38223 .16039 Mdot
.11063 .56772 Mdot
.66973 .4797 Mdot
.47434 .40737 Mdot
.20523 .47346 Mdot
.58142 .40709 Mdot
.98342 .22767 Mdot
.50328 .70429 Mdot
.58275 .91632 Mdot
.38085 .6811 Mdot
.34863 .76702 Mdot
.10348 .64007 Mdot
.59522 .77015 Mdot
.20161 .68591 Mdot
.3974 .06113 Mdot
.89732 .26666 Mdot
.01979 .9814 Mdot
.73997 .75933 Mdot
.61217 .2161 Mdot
.39275 .85703 Mdot
.64481 .56692 Mdot
.30871 .6464 Mdot
.07075 .82554 Mdot
.41828 .2666 Mdot
.62478 .9884 Mdot
.86561 .66679 Mdot
.08902 .97604 Mdot
.20151 .16611 Mdot
.56769 .18859 Mdot
.1978 .67737 Mdot
.50465 .32387 Mdot
.72985 .88056 Mdot
.89244 .46709 Mdot
.84496 .4925 Mdot
.85655 .59726 Mdot
.87845 .25711 Mdot
.60448 .4651 Mdot
.75108 .50382 Mdot
.49311 .22806 Mdot
.33045 .48175 Mdot
.95131 .00275 Mdot
.96274 .39056 Mdot
.93385 .07656 Mdot
.36014 .5616 Mdot
.53907 .8984 Mdot
.03325 .9821 Mdot
.62628 .69024 Mdot
.77588 .73135 Mdot
.94554 .70423 Mdot
.00755 .86295 Mdot
.60871 .58815 Mdot
.33371 .17446 Mdot
.9296 .76755 Mdot
.82397 .97225 Mdot
.92368 .81734 Mdot
.64829 .5251 Mdot
.06962 .06794 Mdot
.80928 .08442 Mdot
.47112 .13715 Mdot
.56007 .08216 Mdot
.46154 .41725 Mdot
.18465 .72275 Mdot
.11244 .64625 Mdot
.65306 .63519 Mdot
.59801 .16997 Mdot
.50612 .49659 Mdot
.49886 .35698 Mdot
.78615 .28912 Mdot
.08334 .27385 Mdot
.29761 .89467 Mdot
.88538 .35378 Mdot
.32905 .35347 Mdot
.0328 .06595 Mdot
.69566 .15622 Mdot
.33257 .95523 Mdot
.74144 .29142 Mdot
.54273 .1742 Mdot
.38076 .24204 Mdot
.77803 .94602 Mdot
.85689 .27326 Mdot
.04867 .82115 Mdot
.69321 .04555 Mdot
.67484 .41312 Mdot
.44661 .41056 Mdot
.35884 .62708 Mdot
.17369 .80751 Mdot
.30894 .63243 Mdot
.92627 .53522 Mdot
.3281 .0549 Mdot
.4635 .18052 Mdot
.48643 .54791 Mdot
.50759 .51315 Mdot
.19709 .32583 Mdot
.48143 .29035 Mdot
.03101 .64808 Mdot
.77508 .44457 Mdot
.37802 .13583 Mdot
.82412 .98786 Mdot
.49561 .9271 Mdot
.38011 .60834 Mdot
.31331 .62961 Mdot
.15682 .12489 Mdot
.37889 .68205 Mdot
.24422 .83902 Mdot
.89091 .70466 Mdot
.34525 .52577 Mdot
.2679 .63058 Mdot
.72092 .9634 Mdot
.02441 .53517 Mdot
.06377 .66176 Mdot
.68943 .34852 Mdot
.70349 .47902 Mdot
.42571 .47771 Mdot
.90705 .06168 Mdot
.62185 .53075 Mdot
.90344 .84541 Mdot
.59217 .20345 Mdot
.87494 .15399 Mdot
.19444 .69205 Mdot
.06314 .70448 Mdot
.63589 .54333 Mdot
.43557 .43601 Mdot
.15877 .07536 Mdot
.84908 .52588 Mdot
.77516 .17476 Mdot
.44 .14268 Mdot
.1 .37108 Mdot
.31313 .64916 Mdot
.96139 .98494 Mdot
.31169 .51302 Mdot
.79398 .60973 Mdot
.75342 .70928 Mdot
.43626 .48843 Mdot
.01283 .28677 Mdot
.63599 .60397 Mdot
.64339 .78857 Mdot
.26756 .13119 Mdot
.49274 .38592 Mdot
.97234 .95575 Mdot
.32558 .01556 Mdot
.37814 .59334 Mdot
.72407 .29087 Mdot
.63355 .93337 Mdot
.65831 .27702 Mdot
.27457 .50527 Mdot
.8497 .60371 Mdot
.05142 .86462 Mdot
.05589 .52561 Mdot
.09306 .32453 Mdot
.92935 .51099 Mdot
.10914 .83335 Mdot
.98669 .48084 Mdot
.34558 .75498 Mdot
.10915 .29943 Mdot
.20238 .66642 Mdot
.61902 .46912 Mdot
.87315 .83788 Mdot
.01216 .45288 Mdot
.19385 .02905 Mdot
.88342 .16852 Mdot
.32024 .09654 Mdot
.41857 .79552 Mdot
.23013 .64496 Mdot
.53721 .1246 Mdot
.26389 .55993 Mdot
.85631 .60948 Mdot
.46249 .81986 Mdot
.8519 .99232 Mdot
.83693 .27974 Mdot
.88534 .84989 Mdot
.05585 .86393 Mdot
.52698 .16445 Mdot
.31432 .0932 Mdot
.75136 .11758 Mdot
.08768 .61537 Mdot
.86355 .66767 Mdot
.08296 .66939 Mdot
.49905 .34632 Mdot
.99355 .03802 Mdot
.32996 .43254 Mdot
.14178 .45772 Mdot
.72749 .92432 Mdot
.41951 .7913 Mdot
.15983 .06941 Mdot
.69503 .0023 Mdot
.76345 .67318 Mdot
.34775 .0954 Mdot
.1821 .0529 Mdot
.0144 .23586 Mdot
.74335 .87644 Mdot
.59006 .93162 Mdot
.39999 .80399 Mdot
.01475 .14998 Mdot
.29856 .57048 Mdot
.1443 .8074 Mdot
.0992 .54312 Mdot
.76386 .75546 Mdot
.77356 .06469 Mdot
.36584 .50026 Mdot
.95342 .72799 Mdot
.93596 .07626 Mdot
.55144 .37939 Mdot
.71944 .99693 Mdot
.78414 .00804 Mdot
.8185 .66102 Mdot
.48136 .98459 Mdot
.20814 .85815 Mdot
.74995 .88885 Mdot
.96008 .92826 Mdot
.7253 .32542 Mdot
.07384 .21895 Mdot
.23423 .91664 Mdot
.22196 .98175 Mdot
.63482 .16885 Mdot
.23382 .91661 Mdot
.68715 .21564 Mdot
.77048 .85244 Mdot
.26286 .137 Mdot
.73868 .26621 Mdot
.99108 .8708 Mdot
.75222 .60936 Mdot
.96012 .19214 Mdot
.91241 .03017 Mdot
.54717 .60718 Mdot
.04489 .31704 Mdot
.67294 .55644 Mdot
.56999 .87109 Mdot
.03768 .2143 Mdot
.14342 .51938 Mdot
.49788 .52487 Mdot
.21147 .76151 Mdot
.06222 .96367 Mdot
.15337 .30761 Mdot
.38515 .7599 Mdot
.18232 .05043 Mdot
.87477 .09065 Mdot
.07033 .4094 Mdot
.63126 .10713 Mdot
.68252 .23512 Mdot
.56234 .38566 Mdot
.13914 .18798 Mdot
.94666 .67621 Mdot
.75818 .09847 Mdot
.2495 .61364 Mdot
.99307 .54252 Mdot
.76497 .96202 Mdot
.08627 .09906 Mdot
.38303 .3001 Mdot
.87187 .91142 Mdot
.87754 .60233 Mdot
.69356 .31928 Mdot
.33256 .25118 Mdot
.47944 .28803 Mdot
.68766 .20231 Mdot
.07739 .46684 Mdot
.78795 .4698 Mdot
.87166 .39172 Mdot
.74587 .62611 Mdot
.84054 .98141 Mdot
.02401 .82354 Mdot
.64501 .03342 Mdot
.13411 .47735 Mdot
.37079 .83821 Mdot
.34043 .76201 Mdot
.51365 .85949 Mdot
.62397 .27263 Mdot
.6547 .62292 Mdot
.1392 .17859 Mdot
.48233 .70659 Mdot
.48339 .25758 Mdot
.5831 .99897 Mdot
.48137 .74698 Mdot
.54415 .64969 Mdot
.20047 .4752 Mdot
.70441 .02088 Mdot
.33491 .8832 Mdot
.20977 .06755 Mdot
.57645 .11713 Mdot
.87255 .90321 Mdot
.72708 .62018 Mdot
.27895 .41496 Mdot
.43458 .76056 Mdot
.18745 .32486 Mdot
.99716 .08679 Mdot
.91526 .09827 Mdot
.70235 .73621 Mdot
.93111 .87163 Mdot
.6947 .88864 Mdot
.16624 .72517 Mdot
.97553 .41101 Mdot
.31333 .87619 Mdot
.48985 .64472 Mdot
.14258 .26081 Mdot
.07246 .32354 Mdot
.5651 .46189 Mdot
.87189 .87486 Mdot
.54051 .4514 Mdot
.67554 .46723 Mdot
.40453 .6598 Mdot
.65887 .47517 Mdot
.47609 .87727 Mdot
.7372 .53965 Mdot
.03637 .11393 Mdot
.70088 .84686 Mdot
.03896 .46481 Mdot
.44621 .22966 Mdot
.16128 .97 Mdot
.15981 .40656 Mdot
.76306 .13206 Mdot
.97118 .07206 Mdot
.57097 .36966 Mdot
.52984 .95549 Mdot
.4589 .3554 Mdot
.27554 .25993 Mdot
.4261 .29287 Mdot
.66836 .65475 Mdot
.63258 .8531 Mdot
.67302 .3777 Mdot
.36698 .88293 Mdot
.683 .72789 Mdot
.87502 .42765 Mdot
.73043 .05889 Mdot
.51618 .68096 Mdot
.3307 .52884 Mdot
.31489 .09499 Mdot
.38199 .56769 Mdot
.72255 .98362 Mdot
.62221 .44509 Mdot
.66349 .42833 Mdot
.37621 .93995 Mdot
.55072 .80578 Mdot
.16968 .99883 Mdot
.69346 .69457 Mdot
.11649 .06125 Mdot
.18866 .63153 Mdot
.12862 .52977 Mdot
.76539 .57045 Mdot
.94731 .93222 Mdot
.98126 .30352 Mdot
.01 .11669 Mdot
.66016 .26581 Mdot
.27341 .47353 Mdot
.01297 .7374 Mdot
.66285 .37673 Mdot
.12702 .66669 Mdot
.2295 .28107 Mdot
.21123 .21226 Mdot
.77207 .8859 Mdot
.47464 .01692 Mdot
.7604 .9695 Mdot
.80333 .06039 Mdot
.87599 .51144 Mdot
.43491 .48605 Mdot
.39863 .22739 Mdot
.72643 .93431 Mdot
.54139 .63274 Mdot
.5566 .97117 Mdot
.35864 .44072 Mdot
.74303 .44906 Mdot
.32826 .59472 Mdot
.15709 .4503 Mdot
.64586 .78994 Mdot
.53839 .63356 Mdot
.43978 .60613 Mdot
.60119 .93095 Mdot
.7658 .46065 Mdot
.87534 .09505 Mdot
.92842 .64079 Mdot
.47231 .92476 Mdot
.86266 .49994 Mdot
.34068 .72847 Mdot
.93099 .67902 Mdot
.07751 .74723 Mdot
.88116 .12477 Mdot
.08729 .23037 Mdot
.38282 .6604 Mdot
.09987 .0496 Mdot
.15105 .19726 Mdot
.0862 .65277 Mdot
.8386 .55523 Mdot
.93129 .53132 Mdot
.66688 .23905 Mdot
.63839 .71819 Mdot
.27426 .25725 Mdot
.40326 .56471 Mdot
.97225 .49198 Mdot
.95314 .6765 Mdot
.71679 .52602 Mdot
.40439 .78178 Mdot
.91559 .68715 Mdot
.97596 .73862 Mdot
.33033 .56033 Mdot
.16792 .05018 Mdot
.79015 .80698 Mdot
.98544 .82197 Mdot
.15736 .78325 Mdot
.62478 .58279 Mdot
.44675 .17872 Mdot
.12635 .27545 Mdot
.69757 .9247 Mdot
.33371 .48273 Mdot
.53429 .03721 Mdot
.1047 .5648 Mdot
.86776 .43437 Mdot
.77325 .78957 Mdot
.33171 .21556 Mdot
.66065 .07876 Mdot
.5043 .44063 Mdot
.68593 .97466 Mdot
.63107 .14114 Mdot
.5016 .79082 Mdot
.16676 .65588 Mdot
.34821 .63123 Mdot
.91917 .02575 Mdot
.72022 .53428 Mdot
.71096 .06994 Mdot
.11655 .94242 Mdot
.71033 .47362 Mdot
.71201 .4417 Mdot
.93859 .30061 Mdot
.2964 .05643 Mdot
.6101 .92014 Mdot
.74955 .52183 Mdot
.10807 .81182 Mdot
.80215 .92388 Mdot
.45403 .61815 Mdot
.0044 .37115 Mdot
.68055 .97827 Mdot
.6507 .63476 Mdot
.64112 .48389 Mdot
.34729 .02429 Mdot
.47356 .70866 Mdot
.72571 .17415 Mdot
.6617 .30762 Mdot
.46252 .71121 Mdot
.74815 .2616 Mdot
.08494 .52173 Mdot
.49958 .50672 Mdot
.31094 .07596 Mdot
.65011 .47927 Mdot
.42523 .47176 Mdot
.85426 .02268 Mdot
.03581 .65974 Mdot
.7715 .38982 Mdot
.38353 .17962 Mdot
.07079 .70349 Mdot
.51027 .21991 Mdot
.78688 .55522 Mdot
.72317 .71843 Mdot
.32733 .15278 Mdot
.92122 .10015 Mdot
.443 .3808 Mdot
.24332 .43366 Mdot
.61796 .19395 Mdot
.17038 .72895 Mdot
.50214 .38458 Mdot
.49673 .62093 Mdot
.74636 .68224 Mdot
.68628 .00592 Mdot
.92571 .39109 Mdot
.09004 .0342 Mdot
.29331 .4294 Mdot
.04181 .11209 Mdot
.22459 .24941 Mdot
.11921 .45653 Mdot
.92261 .53347 Mdot
.60201 .81214 Mdot
.63994 .45728 Mdot
.88557 .61175 Mdot
.06251 .49314 Mdot
.40193 .42216 Mdot
.43893 .07362 Mdot
.80957 .41231 Mdot
.40379 .49435 Mdot
.11663 .5182 Mdot
.45033 .07491 Mdot
.18091 .55679 Mdot
.34905 .50105 Mdot
.9297 .10893 Mdot
.90823 .49089 Mdot
.70811 .67499 Mdot
.59053 .12018 Mdot
.26099 .3631 Mdot
.29277 .85641 Mdot
.91262 .52654 Mdot
.11952 .70741 Mdot
.90882 .99036 Mdot
.48568 .09595 Mdot
.07926 .81612 Mdot
.63339 .48071 Mdot
.85982 .28147 Mdot
.25314 .28649 Mdot
.34472 .65436 Mdot
.37449 .95582 Mdot
.79403 .39939 Mdot
.69337 .44821 Mdot
.06667 .92761 Mdot
.89991 .57245 Mdot
.72994 .72904 Mdot
.37357 .31462 Mdot
.14309 .15953 Mdot
.74695 .16041 Mdot
.39812 .15425 Mdot
.34014 .24751 Mdot
.59317 .66511 Mdot
.61963 .17204 Mdot
.249 .78594 Mdot
.08588 .25064 Mdot
.33414 .13048 Mdot
.05015 .68966 Mdot
.2865 .91382 Mdot
.76717 .51504 Mdot
.29079 .27602 Mdot
.20899 .66581 Mdot
.70273 .76698 Mdot
.07866 .44798 Mdot
.42614 .28908 Mdot
.90899 .2675 Mdot
.44688 .89645 Mdot
.96511 .5951 Mdot
.50273 .19212 Mdot
.90679 .19152 Mdot
.18469 .01129 Mdot
.11045 .65398 Mdot
.73349 .37148 Mdot
.52843 .6813 Mdot
.91966 .4711 Mdot
.77259 .34801 Mdot
.05117 .54786 Mdot
.8864 .75887 Mdot
.70358 .94033 Mdot
.49136 .66957 Mdot
.29035 .16221 Mdot
.76684 .96117 Mdot
.22388 .83463 Mdot
.92935 .91266 Mdot
.33465 .87563 Mdot
.72876 .69906 Mdot
.32802 .99062 Mdot
.12439 .23891 Mdot
.62617 .27304 Mdot
.43392 .32633 Mdot
.67021 .62427 Mdot
.05227 .83445 Mdot
.10657 .91968 Mdot
.57505 .1661 Mdot
.0118 .60408 Mdot
.89268 .13886 Mdot
.93076 .51605 Mdot
.45707 .82951 Mdot
.92434 .64299 Mdot
.56812 .3473 Mdot
.41763 .31301 Mdot
.79164 .37089 Mdot
.78764 .89587 Mdot
.91872 .27688 Mdot
.85618 .51143 Mdot
.31538 .1004 Mdot
.43482 .17919 Mdot
.93412 .28108 Mdot
.18614 .17556 Mdot
.30339 .02695 Mdot
.72096 .07797 Mdot
.94446 .32616 Mdot
.2458 .4219 Mdot
.02502 .31832 Mdot
.02068 .4795 Mdot
.46337 .35978 Mdot
.6821 .51122 Mdot
.86101 .0873 Mdot
.96231 .00825 Mdot
.27304 .87674 Mdot
.19896 .04145 Mdot
.24496 .27682 Mdot
.55547 .94858 Mdot
.94539 .87655 Mdot
.37686 .39594 Mdot
.66894 .05235 Mdot
.71928 .28976 Mdot
.97895 .20813 Mdot
.12064 .5454 Mdot
.89027 .95329 Mdot
.49501 .95783 Mdot
.87953 .02627 Mdot
.52571 .40173 Mdot
.28746 .99501 Mdot
.69737 .03707 Mdot
.02745 .29917 Mdot
.11051 .09063 Mdot
.40578 .36438 Mdot
.36741 .45054 Mdot
.29622 .48127 Mdot
.84297 .33032 Mdot
.3838 .08331 Mdot
.98084 .41837 Mdot
.83089 .15004 Mdot
.37165 .85286 Mdot
.76282 .95042 Mdot
.4492 .28352 Mdot
.80296 .47756 Mdot
.78457 .44586 Mdot
.13837 .40803 Mdot
.50358 .10852 Mdot
.01409 .68811 Mdot
.6578 .8487 Mdot
.65157 .37124 Mdot
.08859 .50077 Mdot
.73654 .22909 Mdot
.85852 .3871 Mdot
.91757 .36549 Mdot
.30719 .56084 Mdot
.30002 .20013 Mdot
.94409 .32729 Mdot
.2812 .25909 Mdot
.36245 .32202 Mdot
.6358 .0086 Mdot
.22394 .20843 Mdot
.45104 .38818 Mdot
.01371 .0627 Mdot
.6748 .70149 Mdot
.85479 .61242 Mdot
.84193 .76352 Mdot
.82586 .81405 Mdot
.76102 .82587 Mdot
.15742 .75115 Mdot
.71253 .04306 Mdot
.6844 .47544 Mdot
.18777 .85718 Mdot
.12196 .94287 Mdot
.05752 .05612 Mdot
.42592 .29948 Mdot
.57508 .22276 Mdot
.76197 .5853 Mdot
.84451 .24792 Mdot
.29197 .53794 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00Wo
oooo0_l00002ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo0_l00003ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`?o00003oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`;o00003oooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`04o`000?oooooo0000o`0000cooooo00?o0000ooooooooool01oooool2o`0000Co
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`;o00001oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02?ooool2o`000004
ooooool0003o0000o`0000oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool2o`0000oooooo00?o0000oooo
ooooool00_ooool001kooooo00?o0000ooooooooool00_ooool2o`0003cooooo0_l0000Fooooo`;o
00007?ooool2o`0005?ooooo0_l0000>ooooo`;o00007_ooool2o`0003Sooooo0_l0000@ooooo`00
7_ooool00ol0003oooooooooo`02ooooo`;o0000=?ooool2o`0000cooooo0_l0001hooooo`;o0000
2Oooool2o`0002kooooo0_l0000hooooo`;o00004?ooool001kooooo00?o0000ooooooooool0>?oo
ool2o`0000cooooo0_l0000Nooooo`;o00004Oooool2o`0004Gooooo0_l0001Xooooo`;o00006ooo
ool001kooooo00?o0000ooooooooool0I_ooool2o`00017ooooo0_l0000Kooooo`;o0000T_ooool2
o`0001_ooooo000Nooooo`03o`000?oooooooooo09Kooooo0_l00019ooooo`;o0000;oooool2o`00
01?ooooo0_l0000Nooooo`007_ooool00ol0003oooooooooo`1]ooooo`;o0000L_ooool2o`0002oo
oooo0_l0000Cooooo`;o00007_ooool001kooooo00?o0000ooooooooool0>oooool2o`0002;ooooo
0_l0000<ooooo`;o0000FOooool2o`00053ooooo0_l0000;ooooo`;o00007_ooool001kooooo00?o
0000ooooooooool0>oooool2o`0002;ooooo0_l0001Wooooo`;o0000D?ooool2o`0000Wooooo0_l0
000?ooooo`;o00003oooool001kooooo00?o0000ooooooooool06Oooool2o`0007Wooooo0_l0000h
ooooo`;o0000EOooool2o`0000oooooo0_l0000?ooooo`007_ooool00ol0003oooooooooo`0Ioooo
o`;o0000NOooool2o`0001Cooooo0_l0000Rooooo`;o00003oooool2o`0005kooooo0_l00006oooo
o`007_ooool00ol0003oooooooooo`2Zooooo`;o0000<oooool2o`0005Cooooo0_l00008ooooo`;o
00001_ooool001kooooo00?o0000ooooooooool06Oooool2o`0002;ooooo0_l0002Uooooo`;o0000
Coooool2o`00013ooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l0000Rooooo`;o0000W_oo
ool2o`0000Gooooo0_l0001Qooooo`007_ooool00ol0003oooooooooo`0Looooo`;o00005?ooool2
o`0000?ooooo0_l0002Tooooo`;o0000J?ooool001kooooo0_l0000Mooooo`;o00005?ooool2o`00
00?ooooo0_l0002Looooo`;o0000>_ooool2o`0003Cooooo000Nooooo`03o`000?oooooooooo00oo
oooo0_l0000Vooooo`;o00007_ooool2o`0000?ooooo0_l00009ooooo`;o0000K?ooool2o`0003[o
oooo0_l0000dooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o0000A_ooool2o`0000?ooooo
0_l00009ooooo`;o0000P?ooool2o`0005Gooooo0_l00005ooooo`007_ooool00ol0003ooooooooo
o`02o`00023ooooo0_l0001Iooooo`;o0000J_ooool2o`0001Kooooo0_l0000Pooooo`;o00006ooo
ool2o`0000Gooooo000Nooooo`03o`000?oooooooooo00;o00001Oooool2o`0001Wooooo0_l00007
ooooo`;o00005?ooool2o`00013ooooo0_l0000Xooooo`;o0000N?ooool2o`0000Sooooo0_l00004
ooooo`;o00006_ooool2o`0002;ooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0000:oooo
o`;o00004oooool2o`000003ooooool0003o000001?ooooo0ol0000@ooooo`;o0000X_ooool2o`00
00kooooo0_l0000nooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o00004oooool2o`0000Ko
oooo0_l0000>ooooo`;o0000XOooool2o`0005?ooooo0_l0000=ooooo`007_ooool00ol0003ooooo
ooooo`0`ooooo`;o0000FOooool2o`000003ooooool0003o000005?ooooo0_l0001Cooooo`;o0000
3Oooool001kooooo00?o0000ooooooooool0;oooool2o`00033ooooo0_l0000Xooooo`;o000000?o
ooooo`000?l00000E_ooool2o`0004?ooooo0ol0000Iooooo`007_ooool00ol0003oooooooooo`0_
ooooo`;o00005?ooool2o`0001[ooooo0_l0001`ooooo`;o00004Oooool2o`0004?ooooo0ol0000I
ooooo`007_ooool00ol0003oooooooooo`15ooooo`;o0000<_ooool2o`0003Oooooo0_l0000Ooooo
o`;o0000;_ooool2o`0000kooooo0_l0000Kooooo`;o00005Oooool001kooooo00?o0000oooooooo
ool0NOooool2o`0003Oooooo0_l0001?ooooo`;o00003_ooool3o`0000Oooooo0_l0000Aooooo`;o
00003_ooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo023ooooo0_l0003booooo`;o0000
1oooool2o`00027ooooo0_l00005ooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o0000@?oo
ool2o`000:Cooooo0_l0000>ooooo`;o0000;Oooool001kooooo00Co0000ooooool0003o0000HOoo
ool4o`0000Oooooo0_l0000[ooooo`;o0000K?ooool2o`0000kooooo0_l0000]ooooo`007_ooool0
1?l0003oooooo`000?l00006ooooo`;o00003oooool2o`0004Sooooo1?l00007ooooo`;o00007?oo
ool2o`0000gooooo0_l0001Fooooo`;o00009?ooool2o`0000_ooooo0_l0000Pooooo`007_ooool2
o`0000Sooooo0_l0000?ooooo`;o0000B?ooool2o`0002Oooooo0_l0001Uooooo`;o0000<Oooool4
o`0001kooooo000Nooooo`03o`000?oooooooooo06;ooooo0_l00033ooooo`;o00007_ooool001ko
oooo00?o0000ooooooooool0X?ooool2o`0002Oooooo0_l0001Aooooo`;o00003?ooool2o`0001_o
oooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0000Xooooo`;o0000Joooool2o`0002Oooooo
0_l0000aooooo`;o00007_ooool2o`0000cooooo0_l00009ooooo`;o00004?ooool001kooooo00?o
0000ooooooooool02?ooool3o`0002Sooooo0_l00037ooooo`;o0000=oooool2o`00013ooooo000N
ooooo`04o`000?oooooo0000o`0000Oooooo0_l0002]ooooo`;o0000=oooool2o`00043ooooo0_l0
000Cooooo`007_ooool01?l0003oooooo`000?l0002fooooo`;o00000oooool2o`0003;ooooo0_l0
0010ooooo`;o00004oooool001kooooo00?o0000ooooooooool0_?ooool2o`0003?ooooo0_l0001D
ooooo`007_ooool00ol0003oooooooooo`0_ooooo`;o0000?oooool2o`0003Wooooo0_l00014oooo
o`;o00009oooool2o`0002_ooooo000Nooooo`03o`000?oooooooooo02oooooo0_l00002ooooo`;o
0000=?ooool2o`0000Gooooo0_l0000Fooooo`;o00008Oooool2o`0006gooooo0_l0000[ooooo`00
7_ooool00ol0003oooooooooo`0cooooo`;o00007_ooool2o`0001Cooooo0_l0000Mooooo`;o0000
J_ooool2o`00057ooooo000Nooooo`03o`000?oooooooooo05?ooooo0_l0000Rooooo`;o00002_oo
ool2o`0006oooooo0_l0001Aooooo`007_ooool00ol0003oooooooooo`0Tooooo`;o0000:oooool2
o`0002Cooooo0_l0000:ooooo`;o00004?ooool2o`0008Oooooo0_l0000Wooooo`007_ooool00ol0
003oooooooooo`0Tooooo`;o0000:oooool2o`0003Sooooo0_l00008ooooo`;o0000<_ooool2o`00
05?ooooo0_l0000Wooooo`007_ooool00ol0003oooooooooo`2;ooooo`;o0000??ooool2o`0007co
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l00002ooooo`;o0000oooo
ool8ooooo`;o0000>oooool001kooooo00Co0000oooooooooooooooo0_l0001Sooooo`;o00005Ooo
ool2o`0000kooooo0_l0001kooooo`;o00003?ooool2o`0002gooooo000Nooooo`03o`000?oooooo
oooo043ooooo0_l0000Tooooo`;o00005Oooool2o`0000kooooo0_l0001?ooooo`;o0000>?ooool2
o`0002gooooo000Nooooo`03o`000?oooooooooo02[ooooo0_l0000Booooo`Co0000=_ooool2o`00
06Cooooo0_l0000?ooooo`;o0000E_ooool001kooooo00?o0000ooooooooool0:_ooool2o`0001;o
oooo0_l0000Jooooo`;o00007?ooool2o`0002gooooo0_l00016ooooo`;o0000E_ooool001kooooo
00?o0000ooooooooool0?Oooool2o`0000Kooooo0_l0000Cooooo`;o0000Boooool2o`0000kooooo
0_l0000Iooooo`;o00001?ooool2o`0006gooooo000Nooooo`03o`000?oooooooooo03gooooo0_l0
0006ooooo`;o0000L?ooool2o`0000Gooooo0_l0000:ooooo`;o00001_ooool2o`0000Cooooo0_l0
0011ooooo`;o0000:_ooool001kooooo00?o0000ooooooooool0Loooool2o`0004Gooooo0_l00002
ooooo`;o00001Oooool2o`0000?ooooo0_l0001?ooooo`;o0000:_ooool001kooooo00?o0000oooo
ooooool0>?ooool2o`0002kooooo0_l00009ooooo`;o00006oooool2o`0001[ooooo0_l0000<oooo
o`;o00002Oooool2o`00027ooooo0_l0000>ooooo`;o0000COooool001kooooo00?o0000oooooooo
ool0:Oooool2o`0000gooooo0_l0000^ooooo`;o00003oooool2o`0000kooooo0_l00002ooooo`;o
000000?oooooo`000?l000006_ooool3o`0003Wooooo0_l0000>ooooo`;o0000COooool001kooooo
00?o0000ooooooooool0:Oooool2o`0004kooooo0_l0000>ooooo`;o00000_ooool2o`0000Cooooo
0_l0000Hooooo`;o0000V?ooool001kooooo00?o0000ooooooooool0Toooool2o`0009cooooo0_l0
000Dooooo`007_ooool00ol0003oooooooooo`0Yooooo`;o0000:oooool2o`0005cooooo0_l0001k
ooooo`;o00005?ooool001kooooo00?o0000ooooooooool0:Oooool2o`0002_ooooo0_l00017oooo
o`;o00004oooool2o`0003?ooooo0_l0000hooooo`;o00008_ooool000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0Woooool2o`00
02Cooooo0_l0000Rooooo`;o0000>?ooool2o`0000Wooooo0_l00004ooooo`;o00004Oooool000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400Kooooo00?o0000ooooooooool07oooool2o`0000cooooo0_l0002Fooooo`;o0000Ioooool2
o`0000Cooooo0_l0000Aooooo`000oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RH
ob4Q8Oo^k^h01oooool3o`0001oooooo0_l0000<ooooo`;o0000;_ooool2o`000>Sooooo0003oooo
o`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooo
oooo02?ooooo0_l0000hooooo`;o0000GOooool2o`0001gooooo0_l0001Zooooo`000oooool01Ol0
003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`0S
ooooo`;o0000Uoooool2o`0001gooooo0_l0001Zooooo`000oooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`15ooooo`;o0000GOooool2
o`0000[ooooo0_l0000Qooooo`;o0000IOooool2o`0000_ooooo0003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0@Ooo
ool2o`0000;ooooo0_l0000]ooooo`;o00003_ooool2o`0001kooooo0_l0000:ooooo`;o00008Ooo
ool2o`0006Gooooo0_l0000;ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo00Sooooo0_l0000gooooo`;o0000
2Oooool2o`0000Sooooo0_l0000@ooooo`;o00002_ooool2o`0000kooooo0_l0000mooooo`;o0000
5_ooool2o`0006[ooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0000:ooooo`;o0000=_oo
ool2o`0000Sooooo0_l0000@ooooo`;o0000@_ooool2o`0001Gooooo0_l0000Fooooo`;o0000J_oo
ool001kooooo00?o0000ooooooooool05?ooool2o`0008cooooo0_l00008ooooo`;o00002Oooool4
o`0008cooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0002>ooooo`;o00004oooool4o`00
08cooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0001Yooooo`;o00007Oooool2o`00027o
oooo0_l00011ooooo`;o0000>?ooool2o`0000Wooooo000Nooooo`03o`000?oooooooooo01Sooooo
0_l0001Sooooo`;o00003_ooool2o`0000gooooo0_l0000Qooooo`;o0000:_ooool2o`0001Gooooo
0_l0000hooooo`;o00002Oooool001kooooo00?o0000ooooooooool06?ooool2o`0007?ooooo0_l0
001;ooooo`;o00003oooool2o`0005[ooooo000Nooooo`04o`000?ooooooooooooooo`;o0000eooo
ool2o`0001Cooooo0_l0001Eooooo`007_ooool01?l0003oooooooooooooool2o`00027ooooo0_l0
000eooooo`Go0000E_ooool2o`0001Gooooo0_l00006ooooo`;o00006Oooool2o`0005Gooooo000N
ooooo`03o`000?oooooooooo02Cooooo0_l0000eooooo`Go00006?ooool2o`0003cooooo0_l0000E
ooooo`;o00001_ooool2o`00073ooooo000Nooooo`03o`000?oooooooooo07Sooooo0_l0003=oooo
o`007_ooool00ol0003oooooooooo`0cooooo`;o00004?ooool2o`0002?ooooo0_l0002Rooooo`;o
0000=oooool001kooooo0_l0000Iooooo`;o00006Oooool2o`00013ooooo0_l0000Qooooo`Co0000
Eoooool2o`0003?ooooo0_l0000Dooooo`;o0000=oooool001kooooo00?o0000ooooooooool06?oo
ool2o`0003Gooooo0_l0000Gooooo`;o0000FOooool4o`00037ooooo0_l0000Fooooo`;o00002Ooo
ool2o`0002[ooooo000Nooooo`03o`000?oooooooooo04oooooo0_l00003ooooo`Go0000@?ooool2
o`0002[ooooo0_l00019ooooo`;o000000?oooooo`000?l000001?ooool4o`0002[ooooo000Noooo
o`03o`000?oooooooooo02[ooooo0_l0000Xooooo`Go0000@?ooool2o`0005Cooooo0_l0000Roooo
o`;o00001?ooool2o`0002cooooo000Nooooo`03o`000?oooooooooo00cooooo0_l0000Looooo`;o
0000:Oooool2o`0007cooooo0_l0000Jooooo`;o00007Oooool2o`0003Oooooo000Nooooo`03o`00
0?oooooooooo00cooooo0_l0001fooooo`;o0000COooool2o`0001Cooooo0_l000000ooooooo0000
o`00000Pooooo`;o00004?ooool2o`000003ooooool0003o000002;ooooo000Nooooo`03o`000?oo
oooooooo08Cooooo0_l0001Sooooo`;o000000?oooooo`000?l00000<_ooool2o`000003ooooool0
003o000002;ooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0002Cooooo`;o00006?ooool3
o`0004Wooooo0_l0000;ooooo`;o00009_ooool001kooooo00?o0000ooooooooool05oooool2o`00
00cooooo0_l0000Uooooo`;o00003?ooool2o`00053ooooo0_l0000Hooooo`?o00002Oooool2o`00
03kooooo0_l0000;ooooo`;o00001_ooool2o`0001kooooo000Nooooo`03o`000?oooooooooo02Go
oooo0_l0000Oooooo`;o00001?ooool2o`0000cooooo0_l0001fooooo`;o0000>?ooool2o`0001Wo
oooo0_l00003ooooo`;o00006Oooool001kooooo00?o0000ooooooooool0A_ooool2o`0004Gooooo
0ol0001Hooooo`;o00008_ooool2o`0000Gooooo0_l0000Gooooo`;o00006Oooool001kooooo00?o
0000ooooooooool00_l0001<ooooo`;o0000?Oooool3o`0001Gooooo0_l00011ooooo`;o0000:Ooo
ool2o`00023ooooo0_l0000@ooooo`007_ooool00ol0003oooooooooo`02o`0003;ooooo0_l0000H
ooooo`;o0000=_ooool2o`00013ooooo0_l0000;ooooo`;o0000?oooool2o`0001?ooooo0_l0000>
ooooo`;o0000:?ooool2o`00013ooooo000Nooooo`03o`000?oooooooooo03Cooooo0_l0000Aoooo
o`;o00002Oooool2o`0003;ooooo0_l0000@ooooo`;o00009?ooool2o`0002Kooooo0ol00004oooo
o`;o00003?ooool2o`0000kooooo0_l0000jooooo`007_ooool00ol0003oooooooooo`17ooooo`;o
00002Oooool2o`0003;ooooo0_l0000fooooo`;o00009oooool2o`0000Cooooo0_l0001Hooooo`00
7_ooool00ol0003oooooooooo`05ooooo`;o00006?ooool2o`0006Gooooo0_l00014ooooo`;o0000
NOooool001kooooo0_l00006ooooo`;o00006?ooool2o`0005Oooooo0_l0000<ooooo`;o0000A?oo
ool2o`0005oooooo0_l0000Hooooo`007_ooool00ol0003oooooooooo`1hooooo`;o0000/oooool2
o`0000cooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0^ooooo`;o00009oooool2o`00
05?ooooo0_l0000Uooooo`;o0000I_ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo02ko
oooo0_l0000Wooooo`;o0000Doooool2o`0000Sooooo0_l0000Kooooo`;o0000H?ooool2o`00013o
oooo000Nooooo`03o`000?oooooooooo07Gooooo0_l0000=ooooo`;o0000<?ooool2o`0001Cooooo
0_l0001Wooooo`;o00004?ooool001kooooo00?o0000ooooooooool02_ooool2o`0006Wooooo0_l0
000=ooooo`;o0000A_ooool2o`0004cooooo0_l0000[ooooo`007_ooool00ol0003oooooooooo`04
ooooo`;o00001?ooool2o`000;kooooo0_l0000Aooooo`;o0000>oooool2o`0002_ooooo000Noooo
o`03o`000?oooooooooo00Cooooo0_l0000=ooooo`;o00006Oooool2o`0004;ooooo0_l0000/oooo
o`;o0000:?ooool2o`00017ooooo0_l0001Xooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o
00000oooool4o`0001;ooooo0_l00009ooooo`;o000000?oooooo`000?l00000=?ooool2o`0001Go
oooo0_l0000Eooooo`;o0000A_ooool2o`0004Gooooo0_l0000Fooooo`007_ooool00ol0003ooooo
ooooo`0Hooooo`Co00007Oooool2o`000003ooooool0003o000004_ooooo0_l0001Mooooo`;o0000
9?ooool2o`0001oooooo0_l0000Fooooo`007_ooool00ol0003oooooooooo`1`ooooo`;o0000W?oo
ool2o`0003Oooooo000Nooooo`03o`000?oooooooooo073ooooo0_l0003Eooooo`007_ooool00ol0
003oooooooooo`03ooooo`;o00004Oooool2o`000?oooooo<?ooool001kooooo00?o0000oooooooo
ool00oooool2o`00017ooooo0_l0002Aooooo`;o0000D?ooool2o`0004[ooooo000Nooooo`03o`00
0?oooooooooo0:Wooooo0_l0001@ooooo`;o0000B_ooool001kooooo00?o0000ooooooooool07_oo
ool2o`0007?ooooo0_l00009ooooo`;o00005Oooool2o`0002Gooooo0_l0000Iooooo`;o00001?oo
ool2o`0004Sooooo000Nooooo`;o00007oooool2o`0007?ooooo0_l00009ooooo`;o00005Oooool2
o`0002Gooooo0_l0000Iooooo`;o00001?ooool2o`0004Sooooo000Nooooo`03o`000?oooooooooo
06Oooooo0_l0002cooooo`;o0000:Oooool001kooooo00?o0000ooooooooool0Ioooool2o`0002So
oooo0_l0000;ooooo`;o0000O?ooool2o`0002Wooooo000Nooooo`03o`000?oooooooooo097ooooo
1?l00009ooooo`;o0000JOooool2o`0003cooooo000Nooooo`03o`000?oooooooooo02oooooo0_l0
000Pooooo`;o0000;Oooool2o`00017ooooo0_l0001dooooo`;o0000<oooool2o`0000Oooooo000N
ooooo`03o`000?oooooooooo02Kooooo0_l00007ooooo`;o00008?ooool2o`0002gooooo0_l0002T
ooooo`;o00005_ooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo00gooooo0_l0000Goooo
o`;o0000I_ooool2o`0002Kooooo0_l0001^ooooo`;o00007oooool001kooooo0_l0000>ooooo`;o
00003Oooool2o`00073ooooo0_l0000Vooooo`;o00006?ooool2o`0001Sooooo0_l0000Aooooo`;o
00004oooool2o`0003?ooooo000Nooooo`;o00007Oooool2o`0007Kooooo0_l0000jooooo`;o0000
6?ooool2o`00017ooooo0_l0000Cooooo`;o0000<oooool001kooooo00?o0000ooooooooool0U?oo
ool2o`0001Wooooo0_l0000Rooooo`;o00000_ooool2o`0000kooooo0_l0001Nooooo`007_ooool0
0ol0003oooooooooo`2<ooooo`;o00008Oooool2o`0002;ooooo0_l00002ooooo`;o00003_ooool2
o`00027ooooo0_l0000kooooo`007_ooool00ol0003oooooooooo`0^ooooo`;o0000Aoooool2o`00
01?ooooo0_l0000Aooooo`;o00004_ooool2o`0005Gooooo0_l0000kooooo`007_ooool00ol0003o
ooooooooo`0^ooooo`;o0000Aoooool2o`0001Kooooo0_l00008ooooo`;o000000Coooooo`000?l0
003ooooo0_l0000;ooooo`;o00001Oooool2o`0005kooooo0_l0000booooo`007_ooool00ol0003o
ooooooooo`2?ooooo`;o00002?ooool2o`000003ooooool0003o000000kooooo0_l00019ooooo`;o
00006_ooool2o`0000;ooooo0_l0000@ooooo`;o00002_ooool2o`00013ooooo0003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03
o`000?oooooooooo0?Oooooo0_l0000Cooooo`;o00000oooool2o`0000Cooooo0_l0000@ooooo`;o
00002_ooool2o`00013ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1fooooo`;o0000I?ooool2o`0002ko
oooo0_l00003ooooo`;o0000=?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go
00001_ooool3o`0002oooooo0_l00015ooooo`;o0000I?ooool2o`00023ooooo0_l00017ooooo`00
0oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool00ol0
003oooooooooo`0_ooooo`;o0000M_ooool2o`0001Oooooo0_l0000iooooo`;o000000?oooooo`00
0?l00000Aoooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0000Oooooo00?o0000ooooooooool0<?ooool2o`0006Cooooo0_l0000?ooooo`;o00004?ooool2
o`0000Gooooo0_l0000iooooo`;o0000B_ooool000?ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool04oooool2o`0001Cooooo0_l00005
ooooo`;o0000I?ooool2o`00027ooooo0_l0001]ooooo`;o00007Oooool000?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool04oooool2
o`0001Cooooo0_l0001Rooooo`;o0000B?ooool2o`0002Oooooo0_l000000ooooooo0000o`00000S
ooooo`;o00003oooool2o`0000cooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool0
0omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo05Oooooo0_l0000dooooo`;o0000B?ooool2
o`0002Oooooo0_l000000ooooooo0000o`00000dooooo`;o00003?ooool001kooooo00?o0000oooo
ooooool01oooool2o`0000Kooooo0_l00016ooooo`;o00001Oooool2o`0003;ooooo0_l0002Woooo
o`;o00002_ooool001kooooo00?o0000ooooooooool01oooool2o`0000Kooooo0_l0000kooooo`;o
00004?ooool2o`0000_ooooo0_l0000Booooo`;o00004Oooool2o`000:Oooooo0_l0000:ooooo`00
7_ooool00ol0003oooooooooo`1<ooooo`;o00007Oooool2o`0001;ooooo0_l00036ooooo`007_oo
ool00ol0003oooooooooo`1jooooo`;o0000F?ooool2o`0004;ooooo0_l0000]ooooo`007_ooool0
0ol0003oooooooooo`1Kooooo`;o00007Oooool2o`0005Sooooo0_l00012ooooo`;o00006_ooool2
o`00017ooooo000Nooooo`03o`000?oooooooooo02Kooooo0_l0000Pooooo`;o000000?oooooo`00
0?l000003_ooool2o`0000Wooooo0ol0002]ooooo`;o00007?ooool2o`00017ooooo000Nooooo`03
o`000?oooooooooo02Kooooo0_l0000Pooooo`;o000000?oooooo`000?l000006Oooool3o`00023o
oooo0_l0002;ooooo`;o0000;oooool001kooooo00?o0000ooooooooool09_ooool2o`0004Sooooo
0_l0000Gooooo`;o00005Oooool2o`000:Gooooo000Nooooo`03o`000?oooooooooo02Kooooo0_l0
0018ooooo`;o00006_ooool2o`0001;ooooo0_l00011ooooo`;o0000H_ooool001kooooo00?o0000
ooooooooool0S?ooool2o`0003Sooooo0_l0000Kooooo`;o00004oooool2o`000003ooooool0003o
000004[ooooo000Nooooo`03o`000?oooooooooo01Gooooo0_l0000Hooooo`;o0000KOooool2o`00
02Kooooo0_l0000Eooooo`;o00003_ooool2o`0000Wooooo0_l000000ooooooo0000o`00000Goooo
o`;o0000<Oooool001kooooo0_l000000ooooooo0000o`00000Cooooo`;o00006?ooool2o`0004;o
oooo0_l0000Yooooo`;o00003?ooool2o`0002oooooo0_l0000>ooooo`;o00009Oooool2o`00037o
oooo000Nooooo`03o`000?oooooooooo00;o00008Oooool2o`0004kooooo0_l0000gooooo`;o0000
VOooool001kooooo00?o0000ooooooooool01?ooool2o`0001Oooooo0_l00004ooooo`;o00001Ooo
ool2o`00063ooooo0_l0000nooooo`;o0000NOooool001kooooo00?o0000ooooooooool01?ooool2
o`00017ooooo0_l00004ooooo`;o00002oooool2o`0004?ooooo0_l0000Kooooo`;o00009_ooool2
o`0000_ooooo0_l00009ooooo`;o00009oooool2o`00053ooooo000Nooooo`03o`000?oooooooooo
00Wooooo0_l0000<ooooo`;o0000E_ooool2o`0004?ooooo0_l0000:ooooo`?o0000<_ooool2o`00
053ooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0000:ooooo`;o0000ZOooool2o`0001Ko
oooo0_l00014ooooo`;o00009oooool001kooooo00?o0000ooooooooool05Oooool2o`0006oooooo
0_l0000mooooo`;o00004Oooool2o`0000oooooo0_l0000Aooooo`;o00008?ooool2o`0000Oooooo
0_l00008ooooo`;o00005?ooool001kooooo00?o0000ooooooooool0?oooool2o`0001Cooooo0_l0
000Wooooo`;o00001_ooool2o`0003gooooo0_l0000Looooo`;o00001?ooool2o`00017ooooo0_l0
000?ooooo`;o00006?ooool2o`0000Sooooo0_l0000Dooooo`007_ooool00ol0003oooooooooo`0W
ooooo`;o00005?ooool4o`0001Cooooo0_l0000Wooooo`;o00001_ooool2o`0004[ooooo0_l00006
ooooo`;o00001oooool2o`0001cooooo0_l0000:ooooo`;o00004?ooool2o`0002Kooooo000Noooo
o`03o`000?oooooooooo00?ooooo0_l0000Rooooo`;o00005?ooool2o`0004Oooooo0_l0000`oooo
o`;o00002oooool2o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`00
00;ooooo0_l00005ooooo`;o00007_ooool2o`0001cooooo0_l0000Looooo`;o00002?ooool001ko
oooo00?o0000ooooooooool00oooool2o`0005Oooooo0_l00009ooooo`?o0000C_ooool2o`0000_o
oooo0_l00003ooooo`Co000000?oooooo`000?l000001Oooool2o`0000Wooooo0_l0001Jooooo`;o
00002?ooool001kooooo00?o0000ooooooooool09_ooool2o`0002kooooo0_l00004ooooo`;o0000
2Oooool3o`0001oooooo0_l0000Gooooo`;o0000:?ooool2o`0007Wooooo000Nooooo`03o`000?oo
oooooooo02Kooooo0_l0000^ooooo`;o0000<Oooool5o`0001Cooooo0_l0002Sooooo`007_ooool0
0ol0003oooooooooo`0@ooooo`;o0000;oooool2o`0001Sooooo0_l0000]ooooo`Co0000?Oooool2
o`0004;ooooo0_l0000Booooo`;o00004oooool2o`0000gooooo000Nooooo`03o`000?oooooooooo
013ooooo0_l00002ooooo`;o0000:oooool2o`0001Sooooo0_l0000Rooooo`;o00007oooool2o`00
02Wooooo0_l00012ooooo`;o00004_ooool2o`0001?ooooo0_l0000=ooooo`007_ooool00ol0003o
ooooooooo`0Dooooo`;o0000JOooool2o`0001oooooo0_l0002Uooooo`007_ooool2o`0001[ooooo
0_l0001Booooo`;o00001?ooool2o`0001oooooo0_l0001nooooo`;o0000<Oooool001kooooo00?o
0000ooooooooool06Oooool2o`0003[ooooo0_l0000Fooooo`;o00001?ooool2o`0001oooooo0_l0
001Jooooo`;o00008_ooool2o`00037ooooo000Nooooo`03o`000?oooooooooo05Gooooo0_l00017
ooooo`;o0000Boooool2o`0000?ooooo0_l0001Eooooo`007_ooool00ol0003oooooooooo`2Noooo
o`;o0000>_ooool2o`0000oooooo0_l0000Uooooo`;o00001Oooool2o`0000oooooo0_l0000Koooo
o`007_ooool00ol0003oooooooooo`1Qooooo`;o0000?_ooool2o`0003Oooooo0_l0000Iooooo`;o
00006oooool2o`0000Gooooo0_l0000?ooooo`;o00006oooool001kooooo00?o0000ooooooooool0
HOooool2o`0003kooooo0_l0001Booooo`;o0000<_ooool3o`0001_ooooo000Nooooo`03o`000?oo
oooooooo02;ooooo0_l00007ooooo`;o0000Y_ooool2o`0005Cooooo0ol0000Kooooo`007_ooool0
0ol0003oooooooooo`0Gooooo`;o00002Oooool2o`0000Oooooo0_l0002Vooooo`;o00006oooool2
o`0005Gooooo000Nooooo`03o`000?oooooooooo00kooooo0_l00007ooooo`;o0000Doooool2o`00
01Kooooo0_l0000Hooooo`;o0000;oooool2o`0001Cooooo0_l00009ooooo`;o00007_ooool2o`00
01?ooooo0_l0000Pooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o00005_ooool2o`0001Go
oooo0_l0000Xooooo`;o00000oooool2o`0001Kooooo0_l0000Hooooo`;o0000;oooool2o`0001Co
oooo0_l0000Yooooo`;o00004oooool2o`00023ooooo000Nooooo`03o`000?oooooooooo02Kooooo
0_l0000Eooooo`;o0000:?ooool2o`0005gooooo0_l0000Jooooo`;o0000A?ooool2o`000003oooo
ool0003o000001[ooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l00030ooooo`;o00006_oo
ool2o`0000;ooooo0_l00010ooooo`Go00006_ooool001kooooo00?o0000ooooooooool01?ooool2
o`0005Gooooo0_l00029ooooo`;o00001?ooool2o`0003_ooooo0_l0000Looooo`007_ooool00ol0
003oooooooooo`1Kooooo`;o0000;_ooool2o`0005oooooo0_l0001Aooooo`;o00001_ooool001ko
oooo00?o0000ooooooooool07?ooool2o`0000Gooooo0_l0001Vooooo`;o0000?_ooool2o`00037o
oooo0_l0000oooooo`;o00001_ooool001kooooo00?o0000ooooooooool03Oooool2o`0000gooooo
0_l00005ooooo`;o00008oooool2o`0001[ooooo0_l0000dooooo`;o0000;oooool2o`0001[ooooo
0_l0000=ooooo`;o00001_ooool2o`0004Oooooo000Nooooo`;o00003_ooool2o`0003Wooooo0_l0
000Jooooo`;o00005oooool2o`0001_ooooo0_l0001;ooooo`;o00003Oooool2o`0004oooooo000N
ooooo`03o`000?oooooooooo05;ooooo0_l00008ooooo`;o00007oooool2o`0009Gooooo0_l0000a
ooooo`007_ooool00ol0003oooooooooo`0gooooo`;o00006Oooool2o`0000Sooooo0_l0000koooo
o`;o0000??ooool2o`0000gooooo0_l0000Dooooo`;o00003oooool2o`0000Gooooo0_l0000aoooo
o`007_ooool00ol0003oooooooooo`0gooooo`;o00006Oooool2o`0000cooooo0_l00005ooooo`;o
0000<?ooool2o`0001cooooo0_l0000Nooooo`;o00003Oooool2o`0001Cooooo0_l0000?ooooo`;o
0000>?ooool001kooooo00?o0000ooooooooool04_ooool2o`0002;ooooo0_l0000Jooooo`;o0000
3?ooool2o`0000Gooooo0_l00008ooooo`;o0000A?ooool2o`0008kooooo000Nooooo`03o`000?oo
oooooooo00;ooooo0_l0000>ooooo`;o00002_ooool2o`0001Kooooo0_l0000iooooo`;o00003?oo
ool2o`0004gooooo0_l0001gooooo`007_ooool00ol0003oooooooooo`02ooooo`;o00006_ooool4
o`0004oooooo0_l00005ooooo`;o00001Oooool2o`0004gooooo0_l0000=ooooo`;o00005_ooool2
o`00053ooooo000Nooooo`03o`000?oooooooooo023ooooo0_l0000Jooooo`;o00007oooool2o`00
01;ooooo0_l00005ooooo`;o00000oooool2o`0005kooooo0_l0000Fooooo`;o0000:Oooool2o`00
02Gooooo000Nooooo`03o`000?oooooooooo03cooooo0_l0000Oooooo`;o00007_ooool2o`000:7o
oooo0_l0000Uooooo`007_ooool00ol0003oooooooooo`0`ooooo`;o0000oooooolFooooo`007_oo
ool00ol0003oooooooooo`0`ooooo`;o0000goooool2o`0003Cooooo000Nooooo`03o`000?oooooo
oooo0<Oooooo0_l0000[ooooo`;o00006oooool2o`0001Cooooo0_l0000Nooooo`007_ooool00ol0
003oooooooooo`1looooo`;o0000A?ooool2o`0000?ooooo0_l0000[ooooo`;o0000<Oooool2o`00
01kooooo000Nooooo`03o`000?oooooooooo07cooooo0_l00014ooooo`;o0000Poooool000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
00Kooooo00?o0000ooooooooool0Ioooool2o`0000kooooo0_l0000/ooooo`;o0000OOooool2o`00
027ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMg
MoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo02Cooooo0_l0000nooooo`;o000000?ooooo
o`000?l000003_ooool2o`0002cooooo0_l0001[ooooo`;o00004?ooool2o`00013ooooo0_l0000?
ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00
0006ooooo`?o00009?ooool2o`0000gooooo0_l0000_ooooo`;o0000=?ooool2o`0007Kooooo0_l0
000Rooooo`;o00003oooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`02o`00037ooooo0_l0001Uooooo`;o0000
;oooool2o`0000?ooooo0_l0000nooooo`;o00001oooool2o`0002cooooo0003ooooo`05o`000?oo
ooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000oooooooo
ool00_l00029ooooo`;o00008Oooool2o`0001_ooooo0_l00003ooooo`;o0000=?ooool2o`0000So
oooo0_l00007ooooo`;o0000;?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03
oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0Moooool2o`0001;ooooo0_l0000;ooooo`;o
00005?ooool2o`00043ooooo0_l0000<ooooo`;o00001_ooool2o`0000[ooooo0_l0000cooooo`00
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003o
ooooooooo`1gooooo`;o00007oooool2o`0005Kooooo0_l0000<ooooo`;o00004_ooool2o`0000So
oooo0_l0000:ooooo`;o00007Oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04
olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool06?ooool2o`0003?ooooo0_l00033oooo
o`;o00002?ooool2o`0000[ooooo0_l0000Mooooo`007_ooool00ol0003oooooooooo`0Hooooo`;o
0000<oooool2o`0000_ooooo0_l0000cooooo`;o0000]_ooool001kooooo00?o0000ooooooooool0
D?ooool2o`0000Sooooo0_l0000cooooo`;o00003?ooool2o`0004Wooooo0_l0000eooooo`;o0000
9_ooool001kooooo00?o0000ooooooooool0D?ooool2o`0004_ooooo0_l0000booooo`;o00000ooo
ool2o`00013ooooo0_l0000eooooo`;o00009_ooool001kooooo00?o0000ooooooooool0LOooool2
o`0005kooooo0_l00003ooooo`;o00005_ooool2o`0005Oooooo000Nooooo`03o`000?oooooooooo
03Wooooo0_l0000Hooooo`;o00003Oooool2o`0000Wooooo0_l00002ooooo`;o0000?_ooool2o`00
03_ooooo0_l0000oooooo`;o00005_ooool001kooooo00?o0000ooooooooool0>Oooool2o`0001So
oooo0_l0000;ooooo`Co00002Oooool2o`0003cooooo0ol00003ooooo`;o00007?ooool2o`0005ko
oooo0_l0000Fooooo`007_ooool00ol0003oooooooooo`1Pooooo`;o0000BOooool3o`0000gooooo
0_l0000Booooo`?o0000MOooool001kooooo00?o0000ooooooooool01oooool2o`0001Gooooo0_l0
002Kooooo`;o00004oooool2o`0005Sooooo0_l0000Kooooo`007_ooool00ol0003oooooooooo`07
ooooo`;o00005Oooool2o`000:oooooo0_l0001Gooooo`Co00006oooool001kooooo00?o0000oooo
ooooool01oooool2o`0001Oooooo0_l0000Uooooo`;o00005oooool2o`0001gooooo0_l0000Joooo
o`;o0000<_ooool2o`0005Oooooo0_l0000Mooooo`007_ooool00ol0003oooooooooo`02o`0000Co
oooo0_l0000Hooooo`;o00009Oooool2o`0001Oooooo1?l0000Kooooo`;o00006_ooool2o`00013o
oooo0_l0001Hooooo`;o0000?_ooool001kooooo0_l000000ooooooo0000o`000004ooooo`;o0000
4?ooool2o`0004Sooooo0_l0000eooooo`;o00004_ooool2o`0005Sooooo0_l0000nooooo`007_oo
ool00ol0003oooooooooo`0Hooooo`;o00001_ooool2o`00013ooooo0_l0000hooooo`;o00003Ooo
ool2o`0001cooooo0_l0000jooooo`;o0000=oooool2o`0003Oooooo000Nooooo`03o`000?oooooo
oooo023ooooo0_l0000@ooooo`;o0000>?ooool2o`0000gooooo0_l0001Hooooo`;o00001_ooool2
o`0000;ooooo0_l0000[ooooo`;o0000=oooool001kooooo00?o0000ooooooooool02?ooool3o`00
00Kooooo0_l0000gooooo`;o0000;?ooool2o`0000Gooooo0_l0000Kooooo`;o0000?oooool2o`00
00;ooooo0_l0000Sooooo`;o0000?oooool001kooooo00?o0000ooooooooool02?ooool3o`0000Ko
oooo0_l0000gooooo`;o0000:?ooool2o`0000;ooooo0_l00005ooooo`;o00006oooool2o`0001oo
oooo0_l00017ooooo`;o0000?oooool001kooooo00?o0000ooooooooool00_l0000Sooooo`;o0000
5oooool4o`0001kooooo0_l0000Booooo`;o0000@?ooool2o`0000Gooooo0_l0001Fooooo`;o0000
<?ooool001kooooo00?o0000ooooooooool00_l0000Eooooo`;o00003?ooool2o`0001Oooooo1?l0
000Nooooo`;o0000>_ooool2o`0001Sooooo0_l0001Mooooo`;o0000<?ooool001kooooo00?o0000
ooooooooool01oooool2o`0000kooooo0_l00023ooooo`;o0000A?ooool2o`00013ooooo0_l0001A
ooooo`007_ooool00ol0003oooooooooo`07ooooo`;o0000<oooool2o`000:Cooooo0_l0000@oooo
o`;o0000>_ooool4o`0001?ooooo000Nooooo`03o`000?oooooooooo03cooooo0_l0000jooooo`;o
0000:_ooool2o`0008Gooooo0_l00003ooooo`Co00004oooool001kooooo00?o0000ooooooooool0
Moooool3o`0002?ooooo0_l00005ooooo`;o00000_ooool2o`0004Gooooo0_l0000jooooo`;o0000
6_ooool001kooooo00?o0000ooooooooool0?Oooool2o`0003Sooooo0_l0000Tooooo`;o00002Ooo
ool2o`0004Gooooo0_l0000eooooo`;o00005oooool2o`0000Kooooo000Nooooo`03o`000?oooooo
oooo00;o00002_ooool2o`0002oooooo0_l00028ooooo`;o0000GOooool2o`0001Oooooo0_l00006
ooooo`007_ooool00ol0003oooooooooo`02o`0000[ooooo0_l0000]ooooo`;o0000R_ooool2o`00
07kooooo000Nooooo`03o`000?oooooooooo03_ooooo0_l0002:ooooo`;o00005?ooool2o`0001Wo
oooo0_l0001=ooooo`007_ooool00ol0003oooooooooo`0looooo`;o0000Aoooool2o`00043ooooo
0_l00002ooooo`;o00004?ooool2o`0000[ooooo0_l0000=ooooo`;o0000COooool001kooooo0_l0
000mooooo`;o0000Aoooool2o`0004Cooooo0_l0000:ooooo`;o00004?ooool2o`0005cooooo000N
ooooo`03o`000?oooooooooo013ooooo0_l000000ooooooo0000o`000015ooooo`;o0000A?ooool2
o`0003Gooooo0_l00015ooooo`;o00003oooool2o`0001Kooooo000Nooooo`03o`000?oooooooooo
013ooooo0_l000000ooooooo0000o`00000>ooooo`;o0000=Oooool2o`00033ooooo0_l00008oooo
o`;o000000?oooooo`000?l000001Oooool2o`0007Wooooo0_l000000ooooooo0000o`00000?oooo
o`;o00005_ooool001kooooo00?o0000ooooooooool08oooool2o`0006Oooooo0_l00004ooooo`;o
00000_ooool2o`000003ooooool0003o000005Kooooo0_l0000Xooooo`;o0000:_ooool001kooooo
00?o0000ooooooooool0:_ooool2o`0006Kooooo0_l0001Mooooo`;o0000E?ooool001kooooo00?o
0000ooooooooool0:_ooool2o`0000?ooooo0_l0003ooooooaOooooo000Nooooo`03o`000?oooooo
oooo02[ooooo0_l00003ooooo`;o0000V_ooool2o`0001[ooooo0_l00011ooooo`;o00001?ooool2
o`0001Gooooo000Nooooo`03o`000?oooooooooo01Sooooo0_l0000Booooo`;o00002_ooool2o`00
097ooooo0_l0000Jooooo`;o0000?Oooool2o`0000;ooooo0_l00004ooooo`?o00005?ooool001ko
oooo00?o0000ooooooooool02?ooool2o`0000kooooo0_l0000Booooo`;o00001?ooool2o`0000Co
oooo0_l0003/ooooo`;o00002Oooool2o`0001Cooooo000Nooooo`03o`000?oooooooooo00Sooooo
0_l0000Xooooo`?o0000=_ooool2o`0006gooooo0_l0000=ooooo`;o0000Aoooool2o`0001?ooooo
000Nooooo`03o`000?oooooooooo03?ooooo0_l0000fooooo`;o00001?ooool2o`0000;ooooo0_l0
001Sooooo`;o00003Oooool2o`0000gooooo0_l0000hooooo`;o00004oooool001kooooo00?o0000
ooooooooool0Eoooool2o`0001Sooooo0_l00002ooooo`;o0000Eoooool2o`00013ooooo0_l0000F
ooooo`;o0000COooool001kooooo00?o0000ooooooooool00_l0001Eooooo`;o0000MOooool2o`00
013ooooo0_l0001Gooooo`;o00003?ooool001kooooo00?o0000ooooooooool00_l0002aooooo`;o
0000M_ooool2o`0000cooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`2cooooo`;o0000
M_ooool2o`0001[ooooo000Nooooo`03o`000?oooooooooo01Gooooo0_l00021ooooo`;o0000[Ooo
ool001kooooo0_l0000Fooooo`;o00006?ooool2o`00037ooooo0_l0000dooooo`;o0000POooool2
o`0002[ooooo000Nooooo`03o`000?oooooooooo02oooooo0_l0000aooooo`;o00002?ooool2o`00
0:gooooo0_l0000Zooooo`007_ooool00ol0003oooooooooo`1/ooooo`;o0000C?ooool2o`0003So
oooo0_l0001Aooooo`007_ooool00ol0003oooooooooo`1iooooo`;o00003_ooool2o`0002oooooo
0_l00009ooooo`;o00009Oooool2o`0000Kooooo0_l0000Vooooo`;o0000:Oooool001kooooo00?o
0000ooooooooool0@Oooool2o`0002Sooooo0_l0000<ooooo`;o00003_ooool2o`0003[ooooo0_l0
000Uooooo`;o00008?ooool2o`0000cooooo0_l0000;ooooo`;o00007?ooool001kooooo00?o0000
ooooooooool0@Oooool2o`0002Sooooo1?l00003ooooo`;o0000K?ooool2o`0002cooooo0_l0000I
ooooo`;o00007?ooool001kooooo00?o0000ooooooooool0KOooool2o`0000?ooooo0_l0000Moooo
o`;o0000:_ooool2o`00027ooooo0_l0000Looooo`;o0000:_ooool2o`0001_ooooo000Nooooo`03
o`000?oooooooooo097ooooo0_l0000Zooooo`;o0000?oooool2o`0002[ooooo0_l0000Kooooo`00
7_ooool00ol0003oooooooooo`1Eooooo`;o0000l?ooool001kooooo00?o0000ooooooooool0AOoo
ool2o`0000kooooo0_l0000Hooooo`;o0000cOooool2o`0000Oooooo000Nooooo`03o`000?oooooo
oooo04Gooooo0_l0000Xooooo`;o00003_ooool2o`000;?ooooo0_l00008ooooo`;o00001oooool0
01kooooo0_l0000`ooooo`;o00000_ooool2o`0004[ooooo0_l0000Pooooo`;o0000TOooool2o`00
017ooooo000Nooooo`;o0000:?ooool2o`0000Kooooo0_l00002ooooo`;o00006?ooool2o`0005;o
oooo0_l0000Uooooo`;o00000oooool2o`0007Sooooo000Nooooo`03o`000?oooooooooo023ooooo
0_l00005ooooo`;o00009?ooool2o`0003Gooooo0_l0000Iooooo`;o00009oooool2o`0000?ooooo
0ol0000<ooooo`;o00006Oooool2o`0004kooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo023o
oooo0_l0000Nooooo`;o0000@_ooool2o`0001Wooooo0_l0000]ooooo`;o00003?ooool2o`0001Wo
oooo0_l0001>ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0hooooo`;o00001_ooool2o`00
00Kooooo0_l0000jooooo`;o0000`Oooool000?ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000001_ooool3o`0000?ooooo0_l0000cooooo`;o00003_ooool2
o`0002_ooooo0_l0000=ooooo`;o0000`Oooool000?ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool00ol0003oooooooooo`03ooooo`;o0000L?oo
ool2o`0000Oooooo0_l0001`ooooo`;o0000EOooool000?ooooo00Go0000ooooooooooooooooo`00
000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`0/ooooo`;o0000
D?ooool2o`0002oooooo0_l0000oooooo`;o00002oooool2o`0004Sooooo0003ooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000oooooooo
ool0:oooool3o`0000Kooooo0_l0000Dooooo`;o0000Hoooool2o`0004cooooo0_l00018ooooo`00
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006oooo
o`03o`000?oooooooooo01oooooo0_l0000:ooooo`;o00001oooool2o`0001Cooooo0_l0001doooo
o`;o0000QOooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000
oa0@4?nYZJT01_ooool00ol0003oooooooooo`0Fooooo`;o00001oooool2o`0000Wooooo0_l0002D
ooooo`;o0000A_ooool2o`0003gooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l0000Boooo
o`;o0000g?ooool2o`0001kooooo0_l0000Mooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o
00007oooool2o`0006?ooooo0_l0002Dooooo`;o00004_ooool2o`0000Wooooo000Nooooo`03o`00
0?oooooooooo00Cooooo0_l00006ooooo`;o00001Oooool2o`0001Sooooo0_l0001Sooooo`;o0000
Z?ooool2o`0000Wooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0000=ooooo`;o0000Looo
ool2o`0006Wooooo0_l00008ooooo`;o00006oooool2o`0001Oooooo0_l0000Booooo`007_ooool0
0ol0003oooooooooo`0Yooooo`;o0000GOooool2o`0000Kooooo0_l0001Qooooo`;o00002?ooool2
o`0001_ooooo0_l0000Gooooo`;o00004_ooool001kooooo00?o0000ooooooooool03Oooool2o`00
013ooooo0_l00008ooooo`;o00006_ooool2o`0004Wooooo0_l0002eooooo`007_ooool00ol0003o
ooooooooo`0=ooooo`;o00004?ooool4o`0002;ooooo0_l0001Kooooo`;o00006?ooool2o`0005[o
oooo0_l0000]ooooo`007_ooool00ol0003oooooooooo`0Qooooo`;o0000:?ooool2o`0002Oooooo
0_l0000/ooooo`;o00006?ooool2o`0005[ooooo0_l0000]ooooo`007_ooool00ol0003ooooooooo
o`1;ooooo`;o00009oooool2o`0001gooooo0_l0002booooo`007_ooool00ol0003oooooooooo`2C
ooooo`;o0000Boooool2o`00043ooooo0_l0000Sooooo`007_ooool00ol0003oooooooooo`03oooo
o`;o0000cOooool2o`0000cooooo0_l0000jooooo`;o00001?ooool2o`0002?ooooo000Nooooo`;o
00001?ooool2o`0004_ooooo0_l0000Sooooo`;o0000Doooool2o`0000Kooooo0_l0000Rooooo`;o
00009?ooool2o`00023ooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`1@ooooo`;o0000
2Oooool2o`0001Sooooo0_l0001Cooooo`;o0000:_ooool2o`0002Cooooo0_l0000Pooooo`;o0000
1oooool001kooooo00?o0000ooooooooool0>Oooool2o`0000Gooooo0_l0000Iooooo`;o00001Ooo
ool2o`0001Sooooo0_l0000Uooooo`;o0000Moooool2o`0002Wooooo000Nooooo`03o`000?oooooo
oooo03Wooooo0_l00005ooooo`;o00008?ooool2o`0001Sooooo0_l0000Uooooo`;o0000X_ooool0
01kooooo0ol0000=ooooo`?o0000oooooolhooooo`007_ooool3o`0000gooooo0ol0003Wooooo`;o
0000C_ooool001kooooo00?o0000ooooooooool0@Oooool2o`0007;ooooo0_l00010ooooo`;o0000
<_ooool2o`00017ooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`03ooooo`;o0000??oo
ool2o`0001?ooooo0_l0000Nooooo`;o00008Oooool2o`0001[ooooo0_l0001Pooooo`;o00004_oo
ool2o`00017ooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`03ooooo`;o0000D?ooool3
o`0000[ooooo0_l00005ooooo`;o00002oooool2o`0001cooooo0_l000000ooooooo0000o`000002
o`0005?ooooo0_l0000Aooooo`;o00005?ooool2o`0001Kooooo0_l0000Fooooo`007_ooool00ol0
003oooooooooo`1Eooooo`;o00002oooool2o`0000Gooooo0_l0000Yooooo`;o000000?oooooo`00
0?l00000D?ooool2o`0000?ooooo0_l0000Aooooo`;o0000;?ooool2o`0001Kooooo000Nooooo`03
o`000?oooooooooo06Wooooo0_l00008ooooo`;o0000M?ooool2o`0005cooooo000Nooooo`03o`00
0?oooooooooo06Wooooo0_l00008ooooo`;o0000H?ooool2o`00023ooooo0_l0001>ooooo`007_oo
ool00ol0003oooooooooo`3Eooooo`;o00001oooool2o`00013ooooo0_l00005ooooo`;o00007ooo
ool2o`0002gooooo000Nooooo`03o`000?oooooooooo0=kooooo0_l0000@ooooo`;o00009_ooool2
o`0002gooooo000Nooooo`03o`000?oooooooooo05gooooo0_l0000^ooooo`;o0000KOooool2o`00
02;ooooo0_l0000Uooooo`007_ooool00ol0003oooooooooo`1Mooooo`;o0000;_ooool2o`0001co
oooo0_l00008ooooo`;o0000AOooool2o`0002;ooooo0_l0000Uooooo`007_ooool2o`000:cooooo
0_l00008ooooo`;o0000I_ooool2o`0001gooooo0_l00009ooooo`007_ooool00ol0003ooooooooo
o`2Hooooo`;o0000O_ooool2o`0000?ooooo0_l0000Mooooo`;o00002Oooool001kooooo00?o0000
ooooooooool0M?ooool2o`0000oooooo0_l0000Aooooo`;o0000O_ooool2o`0002gooooo000Noooo
o`03o`000?oooooooooo04Oooooo0_l0000[ooooo`;o00003oooool2o`0004_ooooo0_l0000Doooo
o`;o0000;Oooool2o`0002kooooo000Nooooo`03o`000?oooooooooo04Oooooo0_l0000@ooooo`;o
00007Oooool2o`0004?ooooo0_l0000Cooooo`;o00005?ooool2o`0002gooooo0_l0000Aooooo`;o
00006oooool001kooooo00?o0000ooooooooool0B?ooool2o`0000oooooo0_l0000Mooooo`;o0000
=?ooool2o`0000Wooooo0_l00002ooooo`;o0000@Oooool2o`0001Gooooo0_l0000Aooooo`;o0000
6oooool001kooooo00?o0000ooooooooool07oooool2o`0002Oooooo0_l0001Tooooo`;o00002Ooo
ool2o`0000Oooooo0_l0000Iooooo`;o00008Oooool2o`0004Gooooo000Nooooo`03o`000?oooooo
oooo01oooooo0_l0002Qooooo`;o00006Oooool2o`0002;ooooo0_l00014ooooo`007_ooool00ol0
003oooooooooo`2Eooooo`;o00001_ooool2o`00043ooooo0_l00007ooooo`;o00005oooool2o`00
04Cooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0000Kooooo`;o0000I?ooool2o`0000Ko
oooo0_l00010ooooo`;o00001oooool2o`00033ooooo0_l0000Hooooo`;o00004Oooool001kooooo
00?o0000ooooooooool02?ooool2o`0000Sooooo0_l0000Kooooo`;o0000AOooool2o`0004Cooooo
0_l000000ooooooo0000o`000009ooooo`;o0000C_ooool2o`0001;ooooo1?l00002ooooo`;o0000
2Oooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0001Kooooo`;o00003ooo
ool2o`0004Cooooo0_l000000ooooooo0000o`000009ooooo`;o00007?ooool2o`0004Cooooo1?l0
000=ooooo`;o00001_ooool001kooooo00?o0000ooooooooool0IOooool2o`00087ooooo0_l0000J
ooooo`;o0000@Oooool001kooooo00?o0000ooooooooool08_ooool2o`0005;ooooo0_l0001Yoooo
o`;o00008Oooool2o`00047ooooo000Nooooo`03o`000?oooooooooo02;ooooo1?l0000_ooooo`;o
00007oooool2o`0006Wooooo0_l0001Tooooo`007_ooool00ol0003oooooooooo`0Tooooo`;o0000
7Oooool2o`00013ooooo0_l0001Iooooo`;o0000Aoooool2o`0004cooooo000Nooooo`;o0000A?oo
ool2o`00037ooooo0_l0000]ooooo`;o00002Oooool2o`0004;ooooo0_l00003ooooo`;o0000=?oo
ool2o`0001Kooooo000Nooooo`03o`000?oooooooooo07Kooooo0_l0000]ooooo`;o0000COooool2
o`0002Oooooo0_l0000@ooooo`;o00005_ooool001kooooo00?o0000ooooooooool0J?ooool2o`00
00cooooo0_l0000Uooooo`;o00002Oooool2o`0007?ooooo0_l0000Iooooo`;o00003Oooool001ko
oooo00?o0000ooooooooool0J?ooool2o`0000cooooo0_l0000Uooooo`;o00002Oooool2o`0005Ko
oooo0_l0000fooooo`;o00003Oooool001kooooo00?o0000ooooooooool04?ooool2o`000=Cooooo
0_l0000=ooooo`;o00002Oooool2o`0004Gooooo000Nooooo`03o`000?oooooooooo013ooooo0_l0
0030ooooo`;o00004_ooool2o`0000gooooo0_l0001@ooooo`007_ooool00ol0003oooooooooo`0`
ooooo`;o0000X?ooool2o`0001oooooo0_l0001Booooo`007_ooool00ol0003oooooooooo`0`oooo
o`;o0000Ooooool2o`00043ooooo0_l0000Cooooo`;o0000?Oooool001kooooo00?o0000oooooooo
ool06Oooool2o`0009Kooooo0_l0000Xooooo`;o0000:oooool2o`0003gooooo000Nooooo`03o`00
0?oooooooooo01Wooooo0_l0002nooooo`Co0000J_ooool001kooooo00?o0000ooooooooool00_oo
ool2o`0000?ooooo0_l00006ooooo`;o0000<oooool2o`0000_ooooo0_l00008ooooo`;o0000O?oo
ool2o`0003;ooooo0_l0000hooooo`007_ooool00ol0003oooooooooo`02ooooo`;o00000oooool2
o`0000Kooooo0_l0000cooooo`;o00002oooool2o`0000Sooooo0_l0000kooooo`;o0000=_ooool2
o`0001Gooooo0_l0000Tooooo`;o00009Oooool2o`00017ooooo000Nooooo`03o`000?oooooooooo
09Sooooo0_l0000]ooooo`;o00001_ooool3o`0001?ooooo1?l0000Oooooo`;o0000:_ooool2o`00
017ooooo000Nooooo`03o`000?oooooooooo06Oooooo0_l0001Nooooo`;o00001_ooool2o`0001Co
oooo0_l0000Qooooo`;o00006Oooool2o`0002;ooooo000Dooooo`Co000000?o410@ooooooooool0
0oooool00ol0003oooooooooo`1Wooooo`;o00007_ooool2o`00087ooooo0_l00005ooooo`;o0000
4?ooool2o`0002;ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0FOoo
ool2o`0002cooooo0_l0001Mooooo`;o00008_ooool2o`0000Gooooo0_l0000dooooo`005_ooool0
0ol0003oooooooooo`05ooooo`?o0000<oooool2o`0001[ooooo0_l00008ooooo`;o0000G_ooool2
o`0002_ooooo0_l0001Oooooo`005_ooool00ol0003oooooooooo`0kooooo`;o00006_ooool2o`00
06Sooooo0_l0002<ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`00
0?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005?ooool0
0omEEEGoIVIVo`00003ooooooe;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.3969 .76317 Mdot
.68501 .51832 Mdot
.63044 .95813 Mdot
.03058 .38559 Mdot
.0796 .75762 Mdot
.77916 .72803 Mdot
.30979 .57396 Mdot
.2942 .74604 Mdot
.53523 .34124 Mdot
.93889 .0315 Mdot
.58209 .19812 Mdot
.68215 .51012 Mdot
.07937 .68344 Mdot
.08013 .8256 Mdot
.55357 .30586 Mdot
.96848 .79535 Mdot
.35242 .9026 Mdot
.77474 .51965 Mdot
.9688 .94611 Mdot
.57076 .26888 Mdot
.65038 .33354 Mdot
.86156 .0655 Mdot
.4253 .85541 Mdot
.37868 .08892 Mdot
.56144 .20723 Mdot
.9339 .27176 Mdot
.74807 .15389 Mdot
.53119 .38703 Mdot
.85129 .44807 Mdot
.30081 .59456 Mdot
.39333 .56791 Mdot
.1216 .75852 Mdot
.33618 .74573 Mdot
.17489 .13123 Mdot
.6156 .74808 Mdot
.328 .47506 Mdot
.89044 .55903 Mdot
.38322 .98214 Mdot
.37986 .72476 Mdot
.87397 .10077 Mdot
.23407 .51491 Mdot
.55878 .21107 Mdot
.18577 .73411 Mdot
.11602 .62244 Mdot
.36384 .59835 Mdot
.78014 .53997 Mdot
.06989 .3967 Mdot
.84948 .33531 Mdot
.53976 .82805 Mdot
.79249 .69023 Mdot
.44703 .60453 Mdot
.04617 .45241 Mdot
.2505 .39687 Mdot
.99105 .36054 Mdot
.59056 .23825 Mdot
.40093 .47962 Mdot
.29629 .93238 Mdot
.93234 .61662 Mdot
.00558 .46615 Mdot
.00959 .54096 Mdot
.37987 .59035 Mdot
.40765 .69436 Mdot
.28271 .23763 Mdot
.77645 .05816 Mdot
.48238 .549 Mdot
.45813 .16692 Mdot
.69618 .48829 Mdot
.62042 .52393 Mdot
.44843 .74124 Mdot
.00272 .052 Mdot
.636 .58266 Mdot
.53774 .8637 Mdot
.22037 .8049 Mdot
.81977 .11026 Mdot
.92555 .81818 Mdot
.22161 .30222 Mdot
.5706 .37259 Mdot
.00471 .75847 Mdot
.59882 .29837 Mdot
.48438 .01191 Mdot
.55974 .163 Mdot
.4253 .31125 Mdot
.22863 .19209 Mdot
.48714 .48888 Mdot
.04338 .967 Mdot
.49321 .63902 Mdot
.63197 .72646 Mdot
.70175 .23668 Mdot
.57543 .26906 Mdot
.79961 .32326 Mdot
.94239 .13717 Mdot
.19562 .98495 Mdot
.38741 .80943 Mdot
.96999 .17538 Mdot
.68273 .02902 Mdot
.6627 .70493 Mdot
.8892 .76915 Mdot
.82133 .62285 Mdot
.47618 .68862 Mdot
.90099 .02358 Mdot
.66996 .15323 Mdot
.78416 .39104 Mdot
.95605 .70633 Mdot
.10604 .19206 Mdot
.07029 .95655 Mdot
.16836 .14286 Mdot
.81213 .38107 Mdot
.2365 .13333 Mdot
.15568 .40311 Mdot
.13522 .55815 Mdot
.92562 .77845 Mdot
.3061 .29627 Mdot
.54711 .6833 Mdot
.08599 .46096 Mdot
.51526 .37107 Mdot
.12355 .71013 Mdot
.72319 .65022 Mdot
.2253 .02014 Mdot
.15164 .85569 Mdot
.69976 .78776 Mdot
.77649 .71709 Mdot
.51749 .92978 Mdot
.30037 .03587 Mdot
.26145 .51845 Mdot
.28613 .22053 Mdot
.44939 .67093 Mdot
.90156 .88685 Mdot
.1705 .41104 Mdot
.14801 .79662 Mdot
.52688 .24522 Mdot
.08947 .39515 Mdot
.4073 .36323 Mdot
.39803 .94726 Mdot
.04863 .29361 Mdot
.62695 .91747 Mdot
.41824 .81251 Mdot
.44234 .11336 Mdot
.15507 .04588 Mdot
.70428 .93359 Mdot
.38713 .69673 Mdot
.38688 .84625 Mdot
.78368 .89407 Mdot
.92708 .37738 Mdot
.33544 .69166 Mdot
.08805 .258 Mdot
.22372 .802 Mdot
.1822 .70765 Mdot
.42265 .44272 Mdot
.05224 .57543 Mdot
.86844 .25926 Mdot
.28464 .14156 Mdot
.65836 .51304 Mdot
.35844 .57404 Mdot
.93808 .7028 Mdot
.83052 .3982 Mdot
.06358 .64893 Mdot
.93631 .29157 Mdot
.45613 .87363 Mdot
.40331 .25544 Mdot
.32064 .40497 Mdot
.9923 .07427 Mdot
.77363 .44887 Mdot
.0232 .85404 Mdot
.23448 .05032 Mdot
.83157 .37752 Mdot
.81148 .07416 Mdot
.56628 .84539 Mdot
.84127 .07796 Mdot
.98797 .46345 Mdot
.29899 .4502 Mdot
.17618 .39879 Mdot
.03024 .71591 Mdot
.26249 .93024 Mdot
.49509 .86751 Mdot
.16799 .14322 Mdot
.03515 .52529 Mdot
.25399 .00797 Mdot
.03225 .19525 Mdot
.90973 .18833 Mdot
.55191 .88128 Mdot
.01282 .6905 Mdot
.88226 .74004 Mdot
.28844 .21386 Mdot
.1394 .78544 Mdot
.64286 .66203 Mdot
.35241 .89128 Mdot
.08595 .35968 Mdot
.82132 .79167 Mdot
.63203 .70777 Mdot
.68864 .01377 Mdot
.27587 .04976 Mdot
.53492 .85905 Mdot
.28188 .75402 Mdot
.55056 .79836 Mdot
.84236 .87738 Mdot
.70582 .69357 Mdot
.8132 .55483 Mdot
.59405 .65689 Mdot
.21956 .73855 Mdot
.73162 .42624 Mdot
.34337 .4095 Mdot
.86468 .64454 Mdot
.39197 .8568 Mdot
.26732 .02933 Mdot
.40175 .18129 Mdot
.20203 .90683 Mdot
.58847 .64715 Mdot
.83436 .90612 Mdot
.93014 .8711 Mdot
.38921 .95938 Mdot
.26445 .85089 Mdot
.1386 .76041 Mdot
.0393 .37262 Mdot
.8544 .47299 Mdot
.83136 .90319 Mdot
.56558 .4777 Mdot
.4936 .19448 Mdot
.81352 .26365 Mdot
.93564 .85474 Mdot
.41925 .75838 Mdot
.88804 .87841 Mdot
.09507 .42388 Mdot
.91601 .1354 Mdot
.43656 .63251 Mdot
.10748 .10485 Mdot
.96088 .77325 Mdot
.86621 .88265 Mdot
.06768 .46183 Mdot
.43012 .46382 Mdot
.87035 .57212 Mdot
.12496 .91542 Mdot
.17322 .76932 Mdot
.32988 .59726 Mdot
.16594 .83972 Mdot
.25305 .93345 Mdot
.06373 .02659 Mdot
.34441 .37766 Mdot
.71974 .49714 Mdot
.20256 .36493 Mdot
.40344 .64244 Mdot
.29043 .76305 Mdot
.41333 .90406 Mdot
.9711 .08128 Mdot
.26038 .92312 Mdot
.90173 .52573 Mdot
.33502 .00409 Mdot
.23926 .83852 Mdot
.53737 .74963 Mdot
.40823 .17434 Mdot
.20039 .56376 Mdot
.48213 .47364 Mdot
.62577 .27406 Mdot
.15989 .26934 Mdot
.72958 .94763 Mdot
.90032 .416 Mdot
.15005 .81654 Mdot
.33018 .75446 Mdot
.06107 .96987 Mdot
.28726 .32301 Mdot
.80779 .01355 Mdot
.48873 .90001 Mdot
.68344 .30331 Mdot
.77785 .21829 Mdot
.51282 .25371 Mdot
.08207 .07512 Mdot
.18577 .37739 Mdot
.37581 .02084 Mdot
.24826 .60556 Mdot
.51342 .24262 Mdot
.96674 .76055 Mdot
.87154 .21717 Mdot
.27163 .19365 Mdot
.39858 .88743 Mdot
.41865 .69449 Mdot
.23743 .84013 Mdot
.73125 .81981 Mdot
.72995 .89931 Mdot
.79205 .22971 Mdot
.44679 .3419 Mdot
.05347 .82578 Mdot
.68574 .20642 Mdot
.39488 .09717 Mdot
.71876 .58245 Mdot
.84019 .70161 Mdot
.24992 .22337 Mdot
.74782 .42947 Mdot
.72878 .26003 Mdot
.85399 .23921 Mdot
.83548 .25089 Mdot
.78786 .97563 Mdot
2e-05 .72511 Mdot
.16138 .25971 Mdot
.94922 .88515 Mdot
.82704 .56596 Mdot
.89403 .36245 Mdot
.87578 .26006 Mdot
.43219 .51465 Mdot
.42131 .36931 Mdot
.7145 .47742 Mdot
.21685 .06748 Mdot
.5651 .32057 Mdot
.64689 .21796 Mdot
.38338 .45235 Mdot
.04778 .12889 Mdot
.57638 .60728 Mdot
.35651 .43457 Mdot
.43015 .17096 Mdot
.60839 .99724 Mdot
.58624 .89619 Mdot
.68596 .74644 Mdot
.39101 .55067 Mdot
.67521 .56592 Mdot
.11799 .32974 Mdot
.85607 .23254 Mdot
.11968 .17621 Mdot
.08819 .45496 Mdot
.91146 .79891 Mdot
.23232 .67165 Mdot
.50409 .26151 Mdot
.63844 .27541 Mdot
.88201 .86996 Mdot
.89129 .94849 Mdot
.62377 .29731 Mdot
.65781 .96049 Mdot
.48377 .33133 Mdot
.73515 .58929 Mdot
.80018 .34399 Mdot
.52517 .46011 Mdot
.92033 .98879 Mdot
.18892 .33471 Mdot
.98329 .89618 Mdot
.13846 .8205 Mdot
.51147 .54131 Mdot
.61843 .05211 Mdot
.00943 .63155 Mdot
.3863 .73786 Mdot
.3041 .94496 Mdot
.52108 .62807 Mdot
.90536 .62408 Mdot
.6041 .23156 Mdot
.96286 .1088 Mdot
.11249 .78294 Mdot
.23992 .57212 Mdot
.68588 .94076 Mdot
.18871 .60011 Mdot
.36186 .93255 Mdot
.28276 .23951 Mdot
.95596 .72131 Mdot
.50665 .58386 Mdot
.98768 .64103 Mdot
.2662 .07102 Mdot
.96125 .59493 Mdot
.18408 .63377 Mdot
.68117 .12207 Mdot
.08287 .699 Mdot
.03975 .91263 Mdot
.09336 .16865 Mdot
.21684 .58171 Mdot
.57285 .48957 Mdot
.81882 .1202 Mdot
.92938 .74199 Mdot
.56711 .77943 Mdot
.45665 .71263 Mdot
.89622 .37579 Mdot
.96714 .47917 Mdot
.35407 .17074 Mdot
.11881 .60135 Mdot
.64318 .45305 Mdot
.44177 .40886 Mdot
.22615 .45233 Mdot
.53593 .43434 Mdot
.014 .26361 Mdot
.52357 .6825 Mdot
.55646 .94291 Mdot
.38366 .67778 Mdot
.3267 .74356 Mdot
.06053 .64127 Mdot
.55706 .80152 Mdot
.20073 .70454 Mdot
.43642 .0565 Mdot
.87073 .26019 Mdot
.00431 .94096 Mdot
.70853 .75243 Mdot
.60796 .19898 Mdot
.4118 .8962 Mdot
.63115 .541 Mdot
.26462 .63282 Mdot
.03365 .85586 Mdot
.4558 .30402 Mdot
.66787 .95667 Mdot
.86354 .71107 Mdot
.04914 .98471 Mdot
.16538 .18724 Mdot
.59882 .19033 Mdot
.22406 .66632 Mdot
.48296 .28609 Mdot
.70371 .86714 Mdot
.91504 .51364 Mdot
.81133 .45301 Mdot
.88359 .63178 Mdot
.85613 .22186 Mdot
.6117 .50127 Mdot
.78894 .48067 Mdot
.50343 .21728 Mdot
.32642 .48851 Mdot
.90312 .02546 Mdot
.98932 .3533 Mdot
.94987 .07976 Mdot
.35713 .58034 Mdot
.57891 .90599 Mdot
.01935 .00064 Mdot
.59971 .69604 Mdot
.74146 .71396 Mdot
.9457 .73267 Mdot
.00175 .82414 Mdot
.62863 .60271 Mdot
.35214 .18876 Mdot
.94218 .79442 Mdot
.84505 .95887 Mdot
.94516 .81292 Mdot
.61586 .52558 Mdot
.10539 .09783 Mdot
.8264 .11893 Mdot
.47714 .11479 Mdot
.56785 .08889 Mdot
.43814 .38442 Mdot
.18759 .71438 Mdot
.11765 .65258 Mdot
.66112 .65269 Mdot
.63121 .1966 Mdot
.54855 .49566 Mdot
.53685 .34819 Mdot
.82115 .33228 Mdot
.11939 .27057 Mdot
.32844 .86135 Mdot
.86687 .3466 Mdot
.30374 .36244 Mdot
.98887 .02616 Mdot
.71989 .11823 Mdot
.33898 .95164 Mdot
.7831 .25359 Mdot
.57845 .20107 Mdot
.41946 .26118 Mdot
.73661 .94553 Mdot
.835 .29962 Mdot
.00864 .86168 Mdot
.68348 .06288 Mdot
.70819 .4378 Mdot
.42785 .36871 Mdot
.3609 .62611 Mdot
.18242 .76471 Mdot
.34917 .60029 Mdot
.93579 .5594 Mdot
.29081 .06316 Mdot
.46842 .15775 Mdot
.45846 .49989 Mdot
.49816 .48259 Mdot
.16021 .28057 Mdot
.4449 .32117 Mdot
.01391 .63911 Mdot
.81316 .45309 Mdot
.38177 .16655 Mdot
.80271 .9863 Mdot
.50202 .93199 Mdot
.39287 .61413 Mdot
.33357 .58851 Mdot
.19729 .12379 Mdot
.37329 .64318 Mdot
.25303 .8053 Mdot
.88817 .74739 Mdot
.33867 .49599 Mdot
.227 .62892 Mdot
.75197 .98706 Mdot
.02339 .57818 Mdot
.06463 .64378 Mdot
.71192 .34164 Mdot
.71964 .49892 Mdot
.4033 .46657 Mdot
.92303 .0462 Mdot
.65184 .51323 Mdot
.89209 .8211 Mdot
.56094 .19989 Mdot
.90649 .18127 Mdot
.16091 .71068 Mdot
.03043 .74866 Mdot
.65804 .5739 Mdot
.46 .44654 Mdot
.18966 .07583 Mdot
.8848 .56897 Mdot
.79365 .13878 Mdot
.47515 .16566 Mdot
.06042 .40285 Mdot
.32275 .66193 Mdot
.0006 .98455 Mdot
.34607 .54482 Mdot
.83104 .6252 Mdot
.7647 .75303 Mdot
.3999 .52984 Mdot
.00099 .26342 Mdot
.60912 .57523 Mdot
.63892 .78445 Mdot
.25642 .10521 Mdot
.49204 .39903 Mdot
.96836 .94199 Mdot
.36249 .98825 Mdot
.37224 .62664 Mdot
.68442 .25152 Mdot
.6627 .9178 Mdot
.63029 .24916 Mdot
.28613 .48128 Mdot
.86722 .65618 Mdot
.03317 .89417 Mdot
.04739 .52979 Mdot
.12119 .35024 Mdot
.95397 .55161 Mdot
.11864 .82308 Mdot
.02714 .52038 Mdot
.30419 .7561 Mdot
.14468 .31361 Mdot
.18107 .64775 Mdot
.62898 .45548 Mdot
.90879 .80725 Mdot
.0326 .44707 Mdot
.20134 .99532 Mdot
.88604 .19783 Mdot
.32752 .09108 Mdot
.43686 .81798 Mdot
.19754 .68512 Mdot
.55071 .0784 Mdot
.22132 .54776 Mdot
.86887 .6029 Mdot
.48777 .85254 Mdot
.81048 .96833 Mdot
.86102 .30382 Mdot
.85332 .86623 Mdot
.03093 .87343 Mdot
.54788 .20564 Mdot
.33948 .06755 Mdot
.70964 .08949 Mdot
.1039 .6075 Mdot
.83386 .63694 Mdot
.09475 .62788 Mdot
.4949 .36793 Mdot
.01367 .99788 Mdot
.32058 .44837 Mdot
.10592 .45412 Mdot
.70359 .96009 Mdot
.45402 .80549 Mdot
.17773 .10842 Mdot
.65951 .00098 Mdot
.76181 .70114 Mdot
.35018 .05916 Mdot
.15757 .07953 Mdot
.97158 .19968 Mdot
.75237 .91513 Mdot
.57391 .90252 Mdot
.38154 .78111 Mdot
.98631 .17661 Mdot
.2642 .55485 Mdot
.13603 .85515 Mdot
.11575 .52358 Mdot
.74144 .73899 Mdot
.73716 .05953 Mdot
.37349 .47937 Mdot
.97795 .74549 Mdot
.94301 .05957 Mdot
.52149 .41215 Mdot
.68714 .97861 Mdot
.82446 .00834 Mdot
.78373 .63439 Mdot
.48373 .94788 Mdot
.23242 .84795 Mdot
.71585 .90747 Mdot
.96529 .96197 Mdot
.68213 .30786 Mdot
.11355 .23511 Mdot
.20317 .91744 Mdot
.20317 .97583 Mdot
.67664 .20115 Mdot
.20379 .90151 Mdot
.65213 .1836 Mdot
.8216 .81878 Mdot
.25333 .11754 Mdot
.7068 .27817 Mdot
.97292 .8699 Mdot
.77836 .6158 Mdot
.93767 .17548 Mdot
.9366 .98628 Mdot
.51467 .62054 Mdot
.0467 .32272 Mdot
.65956 .51375 Mdot
.55779 .84554 Mdot
.99576 .23875 Mdot
.12194 .4768 Mdot
.51641 .51947 Mdot
.17887 .75634 Mdot
.04705 .94345 Mdot
.14817 .3377 Mdot
.33916 .77853 Mdot
.18266 .07683 Mdot
.89316 .07151 Mdot
.03693 .3914 Mdot
.65288 .07645 Mdot
.70135 .2046 Mdot
.59497 .37883 Mdot
.13643 .14615 Mdot
.98794 .69614 Mdot
.74547 .11773 Mdot
.26179 .62236 Mdot
.02216 .59291 Mdot
.77246 .9852 Mdot
.06367 .08074 Mdot
.38723 .30704 Mdot
.85017 .93778 Mdot
.8335 .58077 Mdot
.69431 .33795 Mdot
.31967 .20421 Mdot
.45813 .29107 Mdot
.67957 .19467 Mdot
.10733 .48959 Mdot
.8122 .47158 Mdot
.83077 .422 Mdot
.72426 .6723 Mdot
.84975 .99376 Mdot
.02655 .81733 Mdot
.63769 .04995 Mdot
.14881 .43511 Mdot
.40582 .86503 Mdot
.30899 .71855 Mdot
.52065 .84502 Mdot
.63898 .30191 Mdot
.66594 .62185 Mdot
.16515 .14493 Mdot
.49329 .72766 Mdot
.50541 .2375 Mdot
.54991 .96078 Mdot
.44015 .76309 Mdot
.57201 .64436 Mdot
.21741 .52204 Mdot
.7171 .0291 Mdot
.31976 .90623 Mdot
.1799 .02674 Mdot
.58021 .07781 Mdot
.84357 .90363 Mdot
.74635 .6676 Mdot
.30267 .43511 Mdot
.40886 .7703 Mdot
.20157 .31698 Mdot
.95149 .1145 Mdot
.93242 .13415 Mdot
.70393 .75171 Mdot
.89465 .85946 Mdot
.65379 .91412 Mdot
.20181 .71538 Mdot
.95683 .44316 Mdot
.31933 .89956 Mdot
.48543 .68185 Mdot
.09915 .23266 Mdot
.07207 .29248 Mdot
.56234 .49244 Mdot
.84333 .86906 Mdot
.55649 .48324 Mdot
.68607 .48229 Mdot
.41035 .63339 Mdot
.66689 .49115 Mdot
.48139 .91512 Mdot
.73399 .58221 Mdot
.00044 .06956 Mdot
.748 .81826 Mdot
.08501 .50493 Mdot
.45976 .25463 Mdot
.1616 .00623 Mdot
.15419 .39392 Mdot
.78298 .1029 Mdot
.97126 .08489 Mdot
.52924 .39576 Mdot
.55554 .98527 Mdot
.45209 .39583 Mdot
.25097 .21278 Mdot
.42113 .31266 Mdot
.64003 .62088 Mdot
.62707 .88753 Mdot
.6755 .35489 Mdot
.32669 .9097 Mdot
.6684 .77152 Mdot
.85056 .45606 Mdot
.74683 .0483 Mdot
.47444 .64253 Mdot
.2989 .52044 Mdot
.32043 .08389 Mdot
.41865 .54711 Mdot
.69358 .9881 Mdot
.65426 .41162 Mdot
.68214 .43586 Mdot
.34445 .89884 Mdot
.5566 .81366 Mdot
.20062 .96969 Mdot
.69111 .72044 Mdot
.08248 .08205 Mdot
.16419 .65618 Mdot
.16489 .51382 Mdot
.79826 .57528 Mdot
.99339 .96233 Mdot
.98564 .26494 Mdot
.98205 .13863 Mdot
.67974 .27649 Mdot
.23484 .48347 Mdot
.05273 .76984 Mdot
.64088 .38747 Mdot
.13633 .6281 Mdot
.19555 .30763 Mdot
.17917 .18496 Mdot
.75665 .89151 Mdot
.46724 .02316 Mdot
.72625 .97366 Mdot
.84869 .05288 Mdot
.83797 .55259 Mdot
.40237 .52731 Mdot
.43542 .19702 Mdot
.69238 .96773 Mdot
.55825 .6471 Mdot
.58337 .0029 Mdot
.3817 .47983 Mdot
.74275 .47472 Mdot
.32146 .58404 Mdot
.12579 .43251 Mdot
.62167 .8116 Mdot
.51058 .67016 Mdot
.40766 .56962 Mdot
.55701 .89696 Mdot
.75191 .49636 Mdot
.89337 .056 Mdot
.92934 .61077 Mdot
.44432 .90808 Mdot
.87392 .478 Mdot
.35923 .72155 Mdot
.93032 .7215 Mdot
.09168 .71552 Mdot
.86191 .08063 Mdot
.08248 .19152 Mdot
.35792 .62352 Mdot
.09438 .01195 Mdot
.18615 .16221 Mdot
.08928 .61347 Mdot
.84054 .51344 Mdot
.90549 .57156 Mdot
.66754 .26273 Mdot
.66388 .71254 Mdot
.23743 .28909 Mdot
.37864 .54722 Mdot
.00177 .50757 Mdot
.99313 .64695 Mdot
.74417 .53028 Mdot
.39824 .83025 Mdot
.94997 .67113 Mdot
.93545 .78233 Mdot
.30789 .53441 Mdot
.19216 .02726 Mdot
.79756 .81773 Mdot
.03185 .83284 Mdot
.16702 .8043 Mdot
.66038 .55067 Mdot
.45014 .15719 Mdot
.16107 .25603 Mdot
.73924 .93126 Mdot
.32252 .47163 Mdot
.49893 .01902 Mdot
.10051 .53469 Mdot
.90409 .4649 Mdot
.80465 .76794 Mdot
.30072 .18399 Mdot
.67848 .07942 Mdot
.51585 .41312 Mdot
.73189 .95678 Mdot
.58888 .10726 Mdot
.46886 .81677 Mdot
.12806 .66017 Mdot
.36327 .64175 Mdot
.9645 .03593 Mdot
.68652 .52594 Mdot
.67544 .09733 Mdot
.1253 .90309 Mdot
.75366 .48749 Mdot
.73227 .45748 Mdot
.92626 .28344 Mdot
.32611 .053 Mdot
.58471 .90049 Mdot
.77149 .5205 Mdot
.06971 .79856 Mdot
.76742 .96948 Mdot
.42122 .65715 Mdot
.03013 .38994 Mdot
.64569 .93849 Mdot
.63951 .63011 Mdot
.6235 .49082 Mdot
.3583 .06388 Mdot
.43156 .68213 Mdot
.76552 .17739 Mdot
.67254 .2944 Mdot
.42532 .73482 Mdot
.77007 .28977 Mdot
.12231 .56088 Mdot
.50064 .55284 Mdot
.26446 .06556 Mdot
.64711 .49386 Mdot
.45101 .49168 Mdot
.83378 .00488 Mdot
.08052 .66571 Mdot
.74356 .43358 Mdot
.36094 .16346 Mdot
.05668 .70863 Mdot
.48107 .19702 Mdot
.79308 .57894 Mdot
.70129 .71368 Mdot
.30144 .10453 Mdot
.88914 .06967 Mdot
.44211 .37404 Mdot
.25421 .44329 Mdot
.6076 .17778 Mdot
.19442 .75086 Mdot
.47601 .3716 Mdot
.49124 .63236 Mdot
.77165 .68697 Mdot
.67603 .00842 Mdot
.88065 .42641 Mdot
.04627 .99577 Mdot
.32912 .45019 Mdot
.08914 .14298 Mdot
.20224 .25081 Mdot
.1077 .43873 Mdot
.95042 .50392 Mdot
.62375 .80344 Mdot
.67387 .41442 Mdot
.86557 .62919 Mdot
.09919 .46238 Mdot
.43855 .40146 Mdot
.47193 .08035 Mdot
.83143 .39956 Mdot
.4472 .50675 Mdot
.14128 .51467 Mdot
.45709 .0604 Mdot
.19744 .51971 Mdot
.38465 .53988 Mdot
.95852 .12309 Mdot
.88406 .51587 Mdot
.71228 .69668 Mdot
.58271 .11621 Mdot
.2752 .38572 Mdot
.28354 .89344 Mdot
.93496 .50577 Mdot
.11547 .68095 Mdot
.94987 .03559 Mdot
.50384 .0804 Mdot
.05606 .84328 Mdot
.66754 .44989 Mdot
.85938 .25968 Mdot
.26496 .28574 Mdot
.37794 .63155 Mdot
.34581 .92524 Mdot
.77601 .43739 Mdot
.71881 .40702 Mdot
.05465 .91561 Mdot
.87436 .58836 Mdot
.72892 .71582 Mdot
.40159 .32051 Mdot
.11576 .15999 Mdot
.76585 .14258 Mdot
.41176 .12279 Mdot
.32034 .27608 Mdot
.62275 .68542 Mdot
.58659 .2014 Mdot
.24134 .82498 Mdot
.06351 .26183 Mdot
.37818 .13282 Mdot
.01375 .71143 Mdot
.28572 .88031 Mdot
.7688 .50552 Mdot
.2857 .28907 Mdot
.23523 .63075 Mdot
.71781 .76064 Mdot
.06696 .4181 Mdot
.39457 .30929 Mdot
.87849 .28786 Mdot
.45625 .90976 Mdot
.99075 .55482 Mdot
.51517 .15612 Mdot
.93483 .17296 Mdot
.1576 .98152 Mdot
.09973 .70567 Mdot
.77424 .37973 Mdot
.54945 .71851 Mdot
.8743 .43264 Mdot
.75005 .35528 Mdot
.08213 .54552 Mdot
.9297 .79834 Mdot
.6777 .95977 Mdot
.45683 .7015 Mdot
.31466 .17195 Mdot
.7369 .97374 Mdot
.20862 .83069 Mdot
.94452 .92925 Mdot
.34987 .91139 Mdot
.70649 .71521 Mdot
.35384 .0154 Mdot
.1563 .22587 Mdot
.65794 .26995 Mdot
.47262 .2903 Mdot
.66416 .6305 Mdot
.09558 .83237 Mdot
.12861 .87942 Mdot
.59555 .20142 Mdot
.01991 .60803 Mdot
.93239 .12398 Mdot
.95766 .5376 Mdot
.46699 .82677 Mdot
.91451 .67163 Mdot
.58128 .32496 Mdot
.45033 .31727 Mdot
.81962 .32581 Mdot
.76428 .92001 Mdot
.93965 .29068 Mdot
.8505 .53656 Mdot
.28637 .12047 Mdot
.47474 .14125 Mdot
.91614 .29305 Mdot
.14939 .1717 Mdot
.31281 .98943 Mdot
.74342 .09271 Mdot
.96787 .36622 Mdot
.20592 .38204 Mdot
.98939 .34608 Mdot
.04926 .4426 Mdot
.44324 .3459 Mdot
.6773 .50394 Mdot
.82238 .08868 Mdot
.97091 .96667 Mdot
.30261 .89963 Mdot
.2016 .0515 Mdot
.2118 .29773 Mdot
.56733 .91636 Mdot
.93744 .91879 Mdot
.40468 .35358 Mdot
.6555 .03275 Mdot
.75115 .32973 Mdot
.94367 .24737 Mdot
.09304 .54696 Mdot
.8491 .94916 Mdot
.49571 .94993 Mdot
.85681 .02552 Mdot
.50231 .43932 Mdot
.25043 .01743 Mdot
.6935 .06095 Mdot
.05321 .31929 Mdot
.13473 .10942 Mdot
.4233 .3824 Mdot
.33395 .4863 Mdot
.31551 .50348 Mdot
.88593 .30947 Mdot
.4067 .06567 Mdot
.97373 .44667 Mdot
.82186 .16648 Mdot
.34669 .81072 Mdot
.72848 .99397 Mdot
.46706 .26299 Mdot
.77604 .46458 Mdot
.81617 .45191 Mdot
.15421 .4311 Mdot
.51481 .12617 Mdot
.0467 .64876 Mdot
.69138 .84539 Mdot
.6371 .41705 Mdot
.07474 .51185 Mdot
.69715 .19113 Mdot
.84335 .40552 Mdot
.93769 .35258 Mdot
.30945 .54261 Mdot
.30012 .23905 Mdot
.95571 .35675 Mdot
.24065 .22585 Mdot
.33154 .27173 Mdot
.60361 .96827 Mdot
.20751 .21548 Mdot
.48256 .36034 Mdot
.9707 .10054 Mdot
.70794 .66694 Mdot
.87972 .59401 Mdot
.87971 .78225 Mdot
.79613 .77814 Mdot
.74624 .85124 Mdot
.16186 .72853 Mdot
.68065 .05904 Mdot
.6788 .46828 Mdot
.15696 .84107 Mdot
.08878 .95502 Mdot
.04403 .01937 Mdot
.3843 .32318 Mdot
.60289 .18249 Mdot
.73344 .56979 Mdot
.86091 .21002 Mdot
.33184 .52587 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00;o
oooo0_l00009ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`08ooooo`;o00000oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00So
oooo0_l00004ooooo`03o`000?oooooooooo00gooooo00Co0000ooooool0003o00003?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`02ooooo`007_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02o`0000cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo0_l00003ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool02?ooool2o`0000Cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`07ooooo`;o00001?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`00
7_ooool00ol0003oooooooooo`0`ooooo`;o00007?ooool2o`0008Sooooo0_l0000^ooooo`;o0000
00?oooooo`000?l00000>_ooool001kooooo00?o0000ooooooooool06oooool2o`00037ooooo0_l0
0019ooooo`;o0000?Oooool2o`0002Wooooo0_l00003ooooo`;o0000?Oooool001kooooo00?o0000
ooooooooool06oooool2o`0005;ooooo0_l0000Xooooo`;o0000@Oooool2o`0002Gooooo0_l00012
ooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o0000@Oooool2o`00023ooooo0_l0000]oooo
o`;o0000??ooool2o`0006Wooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0000iooooo`;o
00001_ooool2o`0002Oooooo0_l0000Vooooo`;o0000Yoooool001kooooo00?o0000ooooooooool0
AOooool2o`0002oooooo0_l0000Looooo`;o0000O?ooool2o`0000gooooo0ol0000Sooooo`007_oo
ool00ol0003oooooooooo`0Aooooo`;o00008oooool2o`0000;ooooo0_l0001Hooooo`;o0000A?oo
ool2o`0000Wooooo0_l0000[ooooo`;o00003Oooool3o`0001Wooooo0_l00008ooooo`007_ooool0
0ol0003oooooooooo`0Aooooo`;o00008oooool2o`0000;ooooo0_l0000Gooooo`;o0000QOooool2
o`0000Wooooo0_l00016ooooo`;o00003_ooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo
05?ooooo0_l0001looooo`;o0000F_ooool2o`0001Sooooo000Nooooo`03o`000?oooooooooo05ko
oooo0_l0001aooooo`;o0000G_ooool2o`0000;ooooo0_l0000@ooooo`007_ooool00ol0003ooooo
ooooo`1Nooooo`;o0000dOooool2o`0000;ooooo0_l0000@ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo02kooooo0_l0003hooooo`;o00007Oooool0
01kooooo00?o0000ooooooooool0;_ooool2o`0001Sooooo0_l0000<ooooo`;o0000Loooool2o`00
02;ooooo0_l0000gooooo`;o00007Oooool001kooooo0_l0000nooooo`;o00002Oooool2o`0000co
oooo0_l0000>ooooo`;o0000GOooool2o`0000Cooooo0_l0000Rooooo`;o00007oooool2o`0003Go
oooo000Nooooo`;o0000?_ooool2o`0002Oooooo0_l0000Rooooo`;o0000>Oooool2o`0004Wooooo
0_l0000<ooooo`;o00009oooool001kooooo00?o0000ooooooooool0K_ooool2o`0001[ooooo0_l0
001=ooooo`;o00004Oooool2o`0000[ooooo0_l0000Tooooo`;o00003_ooool2o`0001Oooooo000N
ooooo`03o`000?oooooooooo06kooooo0_l0000Pooooo`;o0000Aoooool3o`000003ooooool0003o
000000gooooo0_l0000:ooooo`;o0000=?ooool2o`0001Oooooo000Nooooo`03o`000?oooooooooo
05;ooooo0_l00006ooooo`;o00005?ooool2o`0000kooooo0_l0000>ooooo`;o0000B?ooool2o`00
0003ooooool0003o000003Gooooo0_l0000aooooo`007_ooool00ol0003oooooooooo`12ooooo`;o
00003_ooool2o`0000Kooooo0_l0000>ooooo`;o00001?ooool2o`0000kooooo0_l0002Booooo`;o
0000<Oooool001gooooo0_l00014ooooo`;o00003_ooool2o`0001Kooooo0_l0002aooooo`?o0000
9oooool001gooooo0_l0000Iooooo`;o0000>Oooool2o`000;3ooooo0_l0000Gooooo`?o00007_oo
ool2o`0000Oooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0000Nooooo`;o000000?ooooo
o`000?l00000OOooool2o`0001Gooooo0_l0000booooo`;o00001oooool2o`0002oooooo0_l00007
ooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o00007?ooool2o`0000Kooooo0_l000000ooo
oooo0000o`00001Iooooo`;o00002Oooool2o`0000gooooo0_l00008ooooo`;o00005Oooool2o`00
00Kooooo0_l0000cooooo`;o00001Oooool2o`0001_ooooo0_l00005ooooo`;o00003Oooool001ko
oooo00?o0000ooooooooool04Oooool2o`0000Cooooo0_l0000Fooooo`;o0000<oooool2o`0002oo
oooo0_l00009ooooo`;o00003Oooool2o`0002Oooooo0_l0000jooooo`;o00006oooool2o`0000Go
oooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o0000Boooool2o`000=;ooooo
0_l0000=ooooo`007_ooool00ol0003oooooooooo`1gooooo`;o0000>oooool2o`0002gooooo0_l0
000Rooooo`;o0000;oooool2o`0000gooooo000Nooooo`03o`000?oooooooooo06Kooooo0_l0000?
ooooo`;o0000>oooool2o`0002gooooo0_l00009ooooo`;o00005oooool2o`0003kooooo000Noooo
o`03o`000?oooooooooo06Kooooo0_l00026ooooo`;o0000Eoooool001kooooo00?o0000oooooooo
ool07_ooool2o`0005cooooo0_l0001Iooooo`;o0000K_ooool001kooooo0_l0000Oooooo`;o0000
G?ooool2o`0005Wooooo0_l0000Qooooo`;o00007?ooool2o`0001gooooo0_l0000>ooooo`007_oo
ool00ol0003oooooooooo`0Oooooo`;o0000;_ooool2o`0000gooooo0_l0002Jooooo`;o00007?oo
ool2o`0001gooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o00005Oooool2
o`0001Oooooo0_l0000=ooooo`;o0000Foooool2o`0007Sooooo0_l0000@ooooo`007_ooool00ol0
003oooooooooo`0Xooooo`;o00003?ooool2o`0008?ooooo0_l00019ooooo`;o0000;Oooool2o`00
013ooooo000Nooooo`03o`000?oooooooooo02Sooooo0_l0001Rooooo`;o00002Oooool2o`0006go
oooo0_l0000Yooooo`;o00005?ooool001kooooo00?o0000ooooooooool0C_ooool2o`0003cooooo
0_l00009ooooo`;o00008?ooool2o`0002_ooooo0_l00006ooooo`;o0000@Oooool2o`0001Cooooo
000Nooooo`03o`000?oooooooooo04kooooo0_l00009ooooo`;o0000G_ooool2o`0002_ooooo0_l0
0006ooooo`;o00005_ooool2o`000003ooooool0003o000003cooooo000Nooooo`03o`000?oooooo
oooo03cooooo0_l0000Kooooo`;o00009oooool2o`0005Gooooo0_l0000[ooooo`;o000000?ooooo
o`000?l000008?ooool2o`0000Oooooo0_l0000Aooooo`007_ooool00ol0003oooooooooo`0loooo
o`;o0000A?ooool2o`0001oooooo0_l0000dooooo`;o0000D?ooool2o`0000Oooooo0_l0000Aoooo
o`007_ooool00ol0003oooooooooo`0;ooooo`;o0000U_ooool2o`000:;ooooo000Nooooo`03o`00
0?oooooooooo00_ooooo0_l0000Xooooo`;o00004_ooool2o`0002cooooo0_l0003>ooooo`007_oo
ool00ol0003oooooooooo`0eooooo`;o00004_ooool2o`0002cooooo0_l0002]ooooo`;o00000ooo
ool2o`0001[ooooo000Nooooo`03o`000?oooooooooo0?kooooo0_l0000Vooooo`;o00000oooool2
o`000003ooooool0003o000000_ooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0coooo
o`;o00008oooool2o`0003cooooo0_l0001Mooooo`;o00001oooool2o`0002kooooo0_l0000;oooo
o`;o00002_ooool001kooooo00?o0000ooooooooool06Oooool2o`0001Oooooo0ol0000Sooooo`;o
0000??ooool2o`0005gooooo0_l0001@ooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o0000
3Oooool2o`0000Sooooo0_l0003ooooooaCooooo000Nooooo`;o0000:Oooool2o`000?oooooo7_oo
ool001kooooo00?o0000ooooooooool0e_ooool2o`0001Oooooo0_l0001Fooooo`007_ooool00ol0
003oooooooooo`2>ooooo`;o00001?ooool2o`0000gooooo0_l0000aooooo`;o00005oooool2o`00
05Kooooo000Nooooo`03o`000?oooooooooo02;ooooo0_l0001Zooooo`;o00001?ooool2o`0000go
oooo0_l0002Rooooo`007_ooool00ol0003oooooooooo`0Rooooo`;o00005?ooool2o`0003Oooooo
0_l0000oooooo`;o0000Toooool001kooooo00?o0000ooooooooool0>?ooool2o`0003Oooooo0_l0
0005ooooo`;o00005oooool2o`0000?ooooo0_l0000Jooooo`;o0000Doooool2o`0003kooooo000N
ooooo`03o`000?oooooooooo01[ooooo0_l0001Looooo`;o00005oooool2o`0000?ooooo0_l0001_
ooooo`;o0000?_ooool001kooooo00?o0000ooooooooool06_ooool2o`00013ooooo0_l0000doooo
o`;o00002oooool2o`0001Oooooo0_l0002Rooooo`;o00006Oooool001kooooo00?o0000oooooooo
ool08oooool2o`0000Oooooo0_l0000dooooo`;o00002oooool2o`00013ooooo0_l00005ooooo`;o
0000X_ooool3o`0000Sooooo0_l00004ooooo`;o00002?ooool001kooooo00?o0000ooooooooool0
8oooool2o`0005cooooo0_l0000nooooo`;o0000<_ooool2o`0003Kooooo0_l00008ooooo`;o0000
1?ooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo07kooooo0_l00010ooooo`?o0000<_oo
ool2o`0002cooooo0_l0000Rooooo`007_ooool00ol0003oooooooooo`0fooooo`;o00009_ooool2
o`0001kooooo0_l00010ooooo`;o00003_ooool2o`00057ooooo0_l0000Rooooo`007_ooool00ol0
003oooooooooo`0booooo`;o00000_ooool2o`0002Kooooo0_l0000>ooooo`;o0000H?ooool2o`00
05;ooooo0_l0000Qooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o00001Oooool2o`0001;o
oooo0_l0000Booooo`;o00009_ooool2o`0004oooooo0_l0000Nooooo`;o0000@oooool2o`00027o
oooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03
o`000?oooooooooo01Oooooo0_l00005ooooo`;o00009_ooool2o`0000cooooo0_l00016ooooo`;o
00008Oooool2o`0001Sooooo0_l00004ooooo`;o0000I_ooool000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000oooo
ooooool01_ooool2o`0004cooooo0_l0000cooooo`;o00003Oooool2o`0000;ooooo0_l0000Koooo
o`;o00003_ooool2o`0000kooooo0_l00011ooooo`;o0000:Oooool000?ooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol00006ooooo`;o0000POooool2o`00
00gooooo0_l0000Hooooo`;o00001?ooool3o`0000Oooooo0_l00005ooooo`;o00003Oooool2o`00
04;ooooo0_l0000Jooooo`;o00003Oooool000?ooooo00Go0000ooooooooooooooooo`00000=oooo
o`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0I?ooool2o`0004cooooo0_l00004oooo
o`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00005?ooool2o`0005kooooo0_l0000=
ooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool0
0ol0003oooooooooo`1Tooooo`;o0000B?ooool2o`0000;ooooo0_l00007ooooo`;o000000?ooooo
o`000?l000006oooool2o`0000?ooooo0_l0001Uooooo`000oooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2^ooooo`;o00000_ooool2
o`0002Oooooo0_l00003ooooo`;o0000<_ooool2o`00037ooooo0003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0COoo
ool2o`0006?ooooo0_l0001Pooooo`;o0000<Oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0oooooo`;o0000
3?ooool2o`0000_ooooo0_l0001Fooooo`;o0000Toooool001kooooo00?o0000ooooooooool0?ooo
ool2o`0001Wooooo0_l00014ooooo`;o0000;?ooool2o`0002Wooooo0_l0000Looooo`;o0000;_oo
ool001kooooo00?o0000ooooooooool0FOooool2o`0004Gooooo0_l0000/ooooo`;o0000:Oooool2
o`0001Oooooo0_l00003ooooo`;o0000;_ooool001kooooo00?o0000ooooooooool0;oooool2o`00
01Wooooo0_l000000ooooooo0000o`00000:ooooo`;o0000]oooool2o`0003?ooooo000Nooooo`03
o`000?oooooooooo02oooooo0_l0000Iooooo`;o000000?oooooo`000?l00000n?ooool001kooooo
00?o0000ooooooooool0`?ooool2o`0003_ooooo0_l00018ooooo`007_ooool00ol0003ooooooooo
o`0Looooo`;o00000oooool2o`0009gooooo0_l0000kooooo`;o00004oooool2o`0003?ooooo000N
ooooo`03o`000?oooooooooo01cooooo0_l00003ooooo`;o0000=Oooool2o`0004Kooooo0_l0000J
ooooo`;o00008_ooool2o`00033ooooo0_l0000cooooo`007_ooool00ol0003oooooooooo`1Hoooo
o`;o00000oooool2o`00047ooooo0_l0000Jooooo`;o00008_ooool2o`00033ooooo0_l0000/oooo
o`;o00001Oooool001kooooo00?o0000ooooooooool0F?ooool2o`0000?ooooo0_l00014ooooo`;o
0000KOooool2o`0002cooooo0_l00005ooooo`007_ooool00ol0003oooooooooo`2Sooooo`;o0000
0_ooool2o`0008Kooooo0_l0000Fooooo`007_ooool00ol0003oooooooooo`2Wooooo`;o00008?oo
ool2o`0006Cooooo0_l0000Fooooo`007_ooool2o`0003oooooo0_l00029ooooo`;o00003oooool2
o`0001kooooo0_l0000@ooooo`;o0000>Oooool001kooooo00?o0000ooooooooool0<?ooool2o`00
00cooooo0_l0000oooooo`;o00004?ooool2o`00013ooooo0_l0000eooooo`;o00007_ooool2o`00
013ooooo0_l0000iooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o00005Oooool2o`0004go
oooo0_l0000@ooooo`;o00004?ooool2o`0006kooooo0_l000000ooooooo0000o`00000_ooooo`00
7_ooool00ol0003oooooooooo`0Aooooo`;o00001_ooool2o`0001Gooooo0_l0001Booooo`;o0000
6_ooool2o`0003?ooooo0_l0000Booooo`;o0000:?ooool2o`000003ooooool0003o000000?o0000
;?ooool001gooooo0_l00002ooooo`;o00003oooool2o`00077ooooo0_l0000>ooooo`;o00002_oo
ool2o`0003?ooooo0_l0000Booooo`;o00006Oooool2o`00017ooooo1?l0000Qooooo`;o00002Ooo
ool001gooooo0_l00002ooooo`;o0000T_ooool2o`0001oooooo0_l0001=ooooo`;o0000=_ooool2
o`0000Wooooo000Nooooo`03o`000?oooooooooo02?ooooo0_l0000;ooooo`;o0000=_ooool2o`00
04_ooooo1?l0000Iooooo`;o0000F?ooool2o`0001Wooooo000Nooooo`03o`000?oooooooooo02?o
oooo0_l0000;ooooo`;o0000=_ooool2o`0004gooooo0_l0000>ooooo`;o00002Oooool2o`0005So
oooo0_l0000Iooooo`007_ooool00ol0003oooooooooo`1Tooooo`;o0000HOooool2o`0000;ooooo
0_l0000<ooooo`;o00001oooool2o`0006?ooooo000Nooooo`03o`000?oooooooooo033ooooo0_l0
000booooo`;o0000IOooool2o`0000cooooo0_l00007ooooo`;o0000Hoooool001kooooo00?o0000
ooooooooool0<?ooool2o`000?Oooooo0_l0000Looooo`007_ooool00ol0003oooooooooo`1Boooo
o`;o0000AOooool2o`0008kooooo0_l0000Looooo`007_ooool00ol0003oooooooooo`19ooooo`;o
00001oooool2o`0000Gooooo0_l0000kooooo`;o000000?oooooo`000?l00000Foooool2o`00027o
oooo0_l0000/ooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o00001Oooool2o`0003Cooooo
0_l0000>ooooo`;o0000=_ooool2o`0000?ooooo0_l0001Nooooo`;o00008Oooool2o`0000_ooooo
0_l00004ooooo`?o00006?ooool001kooooo00?o0000ooooooooool03?ooool2o`0000Gooooo0_l0
001:ooooo`;o0000<?ooool2o`0004Cooooo0_l0001=ooooo`;o00001?ooool3o`0001Sooooo000N
ooooo`03o`000?oooooooooo047ooooo0_l0000Looooo`;o0000G_ooool2o`0000Kooooo0_l0000>
ooooo`;o0000<_ooool2o`0003[ooooo000Nooooo`;o0000@_ooool2o`000003ooooool0003o0000
07Wooooo0_l00006ooooo`;o00000oooool2o`0003gooooo0_l0000jooooo`007_ooool00ol0003o
ooooooooo`14ooooo`;o0000B_ooool2o`0001kooooo0_l0000Jooooo`;o00003?ooool2o`0003So
oooo0_l0000aooooo`007_ooool00ol0003oooooooooo`0kooooo`;o0000?Oooool2o`0001Cooooo
0_l0000Nooooo`;o0000:?ooool2o`0003Sooooo0_l0000aooooo`007_ooool00ol0003ooooooooo
o`0kooooo`;o0000?Oooool4o`0000Sooooo0_l0001Booooo`;o0000@?ooool2o`0002Wooooo000N
ooooo`03o`000?oooooooooo02_ooooo0_l0001?ooooo`;o00001oooool3o`0009Cooooo0_l0000Y
ooooo`007_ooool00ol0003oooooooooo`0[ooooo`;o00004?ooool2o`0004Kooooo0_l00007oooo
o`;o0000]oooool001kooooo00?o0000ooooooooool03Oooool2o`0002kooooo0_l0000oooooo`;o
00003Oooool3o`0002Cooooo0_l0002Aooooo`007_ooool00ol0003oooooooooo`0;ooooo`Co0000
B_ooool2o`0001kooooo0_l00003ooooo`;o00003Oooool2o`0002Gooooo0_l0001:ooooo`;o0000
AOooool001kooooo00?o0000ooooooooool02oooool2o`0004cooooo0_l0000Nooooo`;o0000?_oo
ool2o`0004Gooooo0_l00004ooooo`;o0000?oooool001kooooo00?o0000ooooooooool08_ooool2
o`0009Gooooo0_l0000eooooo`;o00005?ooool2o`0003oooooo000Nooooo`03o`000?oooooooooo
02;ooooo0_l0001eooooo`;o0000=?ooool2o`0001oooooo0_l0000Eooooo`;o0000?_ooool001ko
oooo00?o0000ooooooooool0>Oooool2o`0005kooooo0_l0000dooooo`;o0000=_ooool2o`0000Oo
oooo0_l0000eooooo`007_ooool00ol0003oooooooooo`0/ooooo`;o00002oooool2o`000:?ooooo
0_l0000`ooooo`;o0000=Oooool001kooooo00?o0000ooooooooool0;?ooool2o`0005oooooo0_l0
000Kooooo`;o0000<_ooool2o`0000?ooooo0_l0001Rooooo`007_ooool00ol0003oooooooooo`2<
ooooo`?o00006oooool2o`0003Oooooo0_l0000Kooooo`;o0000AOooool001kooooo00?o0000oooo
ooooool0S?ooool2o`0001cooooo0_l0001Dooooo`;o00005?ooool2o`0002Kooooo0_l00007oooo
o`007_ooool2o`0002Cooooo0_l00025ooooo`;o0000J_ooool2o`0002Kooooo0_l00007ooooo`00
7_ooool00ol0003oooooooooo`0Sooooo`;o0000F_ooool2o`0005Kooooo0_l0001Dooooo`;o0000
3oooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo07oooooo0_l0001Fooooo`;o00005ooo
ool2o`0003_ooooo0_l00004ooooo`;o00002Oooool2o`0000Oooooo000Nooooo`03o`000?oooooo
oooo01Sooooo0_l0001oooooo`;o0000EOooool2o`00047ooooo0_l00009ooooo`;o00001oooool0
01kooooo00?o0000ooooooooool06?ooool2o`0004Gooooo0_l0000Oooooo`;o00005oooool2o`00
08Cooooo0_l0000Mooooo`;o00001oooool001kooooo00?o0000ooooooooool0?_ooool2o`0001oo
oooo0_l0000Oooooo`;o0000WOooool2o`0001Kooooo0_l0000>ooooo`007_ooool00ol0003ooooo
ooooo`0nooooo`;o0000AOooool4o`0001Cooooo0_l0002Hooooo`;o00003_ooool001kooooo00?o
0000ooooooooool02Oooool2o`0007[ooooo1?l0000>ooooo`;o00001?ooool2o`0000Cooooo0_l0
000@ooooo`;o0000T?ooool001kooooo00?o0000ooooooooool02Oooool2o`00087ooooo0_l00009
ooooo`;o00002_ooool2o`00013ooooo0_l0001Xooooo`;o00009_ooool001kooooo00?o0000oooo
ooooool0>?ooool2o`0003;ooooo0_l0000Nooooo`;o0000;oooool2o`0003Wooooo0_l0000@oooo
o`;o00004oooool2o`0000Sooooo0_l0000Looooo`007_ooool00ol0003oooooooooo`0hooooo`;o
00001Oooool2o`0002_ooooo0_l0000Hooooo`;o0000=Oooool2o`0003Wooooo0_l0000:ooooo`;o
00001?ooool2o`0001gooooo0_l0000Looooo`007_ooool00ol0003oooooooooo`06ooooo`;o0000
=oooool2o`0001Cooooo0_l0000_ooooo`;o00000_ooool2o`0007Sooooo0_l00011ooooo`007_oo
ool00ol0003oooooooooo`06ooooo`;o0000COooool2o`0003?ooooo0_l0000Mooooo`;o00008Ooo
ool2o`0007Wooooo000Nooooo`03o`000?oooooooooo00Kooooo1?l0002Oooooo`;o00008Oooool2
o`0002gooooo0_l0001:ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46
ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`06ooooo`Co00009?ooool2
o`000<_ooooo0_l0001:ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool2o`0000Cooooo0_l0000C
ooooo`;o00007Oooool2o`00043ooooo0_l0000Gooooo`;o0000H?ooool2o`0003_ooooo0003oooo
o`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol0000Cooooo`;o00001?ooool2
o`0001[ooooo0_l0000Fooooo`;o0000@?ooool2o`0000_ooooo0_l0000:ooooo`;o0000H?ooool2
o`0003_ooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool0
0007ooooo`03o`000?oooooooooo013ooooo0_l0000Looooo`;o00001Oooool2o`0005?ooooo0_l0
000@ooooo`;o0000K?ooool2o`0003_ooooo0003ooooo`05o`000?ooooooooooooooool000002ooo
ool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo013ooooo0_l0000Looooo`;o0000
=?ooool2o`0002Cooooo0_l0001Jooooo`;o00009_ooool2o`0003Oooooo0003ooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo06Cooooo
0_l00006ooooo`;o00007_ooool2o`0005Sooooo0_l0000Vooooo`;o0000=oooool000?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0
<oooool2o`0003Oooooo0_l0000Nooooo`;o00005_ooool3o`0002[ooooo0_l0001dooooo`000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooo
ooooo`0cooooo`;o0000Koooool3o`0002[ooooo0_l00004ooooo`;o0000B?ooool2o`0002Cooooo
000Nooooo`03o`000?oooooooooo01;ooooo0_l0002gooooo`;o00002_ooool2o`0004Sooooo0_l0
000Tooooo`007_ooool00ol0003oooooooooo`0Booooo`;o0000]oooool2o`0003gooooo0_l0000k
ooooo`007_ooool00ol0003oooooooooo`0Kooooo`;o0000kOooool2o`0003_ooooo000Nooooo`03
o`000?oooooooooo01_ooooo0_l0003=ooooo`;o0000;_ooool2o`0002_ooooo000Nooooo`03o`00
0?oooooooooo02kooooo0_l0002jooooo`;o00000oooool2o`0002Wooooo0_l0000[ooooo`007_oo
ool00ol0003oooooooooo`0Uooooo`;o00001Oooool4o`0002kooooo0_l0000@ooooo`;o0000>?oo
ool2o`0004;ooooo0ol0000Wooooo`;o0000;Oooool001kooooo00?o0000ooooooooool09Oooool2
o`0000Gooooo0_l0000`ooooo`;o00004?ooool2o`0003Sooooo0_l0000^ooooo`;o00001_ooool2
o`0000[ooooo0_l00008ooooo`;o00007_ooool2o`0002gooooo000Nooooo`03o`000?oooooooooo
01oooooo0_l0001nooooo`;o0000>Oooool2o`0000Kooooo0_l0000Dooooo`;o0000COooool001ko
oooo00?o0000ooooooooool03?ooool2o`00017ooooo0_l0000^ooooo`;o0000=?ooool2o`0001So
oooo0_l0002Booooo`;o00004_ooool001kooooo00?o0000ooooooooool01_ooool2o`0000Cooooo
0_l00011ooooo`;o0000=?ooool2o`0000[ooooo0_l0002Pooooo`;o00000oooool2o`0000gooooo
000Nooooo`03o`000?oooooooooo00Kooooo0_l0001Eooooo`;o00001Oooool2o`000003ooooool0
003o000002Sooooo0_l00012ooooo`;o00008?ooool2o`0001Sooooo0_l0000Uooooo`;o00003Ooo
ool001kooooo0_l0000<ooooo`;o0000>?ooool2o`0001Kooooo0_l00005ooooo`;o000000?ooooo
o`000?l000004?ooool2o`0005;ooooo0_l00006ooooo`;o00008?ooool2o`0000_ooooo0ol0000:
ooooo`;o0000=?ooool001kooooo00?o0000ooooooooool02oooool2o`0000cooooo0_l00003oooo
o`;o00009Oooool2o`0003;ooooo0_l0001=ooooo`;o00000oooool2o`0003Gooooo0ol00009oooo
o`;o0000=Oooool001kooooo00?o0000ooooooooool06Oooool2o`0000?ooooo0_l0002Xooooo`;o
00008?ooool2o`0002Cooooo0_l0000eooooo`007_ooool00ol0003oooooooooo`0Booooo`;o0000
1?ooool2o`0000;ooooo0_l00029ooooo`;o0000@Oooool2o`0005_ooooo000Nooooo`03o`000?oo
oooooooo01;ooooo0_l00004ooooo`;o00000_ooool2o`0006[ooooo0_l0000Mooooo`;o0000Cooo
ool2o`0002Sooooo0_l0000Iooooo`;o00002?ooool001kooooo0ol0001oooooo`;o00001oooool2
o`0004oooooo0_l0000Mooooo`;o0000:?ooool2o`0001Wooooo0_l00008ooooo`007_ooool3o`00
06Gooooo0_l0000Hooooo`;o0000F?ooool2o`0002Wooooo0_l00011ooooo`007_ooool00ol0003o
ooooooooo`1Uooooo`Co0000<?ooool2o`0005;ooooo0_l0000Eooooo`;o00003?ooool2o`0003?o
oooo000Nooooo`03o`000?oooooooooo02Cooooo0_l00011ooooo`;o0000<?ooool2o`0001Wooooo
0_l0000^ooooo`;o00001oooool2o`0002?ooooo0_l00004ooooo`;o0000;Oooool001kooooo00?o
0000ooooooooool09?ooool2o`0004oooooo0_l000000ooooooo0000o`000004ooooo`;o0000=?oo
ool2o`0002kooooo0_l0000Fooooo`;o00006_ooool2o`0001cooooo0_l0000?ooooo`007_ooool0
0ol0003oooooooooo`18ooooo`;o00003oooool2o`0001[ooooo0_l000000ooooooo0000o`000004
ooooo`;o00007_ooool2o`00017ooooo0_l0000Xooooo`;o00007oooool2o`0003Sooooo0_l0000?
ooooo`007_ooool00ol0003oooooooooo`18ooooo`;o00003oooool2o`0000gooooo0_l0000doooo
o`;o00004Oooool2o`0002Sooooo0_l0001Zooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o
0000AOooool4o`00033ooooo0_l0000Jooooo`;o00009_ooool2o`00017ooooo0_l0001Dooooo`00
7_ooool00ol0003oooooooooo`0Oooooo`;o0000AOooool2o`0002Oooooo0_l00009ooooo`;o0000
5oooool2o`000003ooooool0003o000000oooooo0_l0000<ooooo`;o00001oooool2o`00017ooooo
0_l0001Dooooo`007_ooool00ol0003oooooooooo`1Zooooo`;o00008oooool2o`0001gooooo0_l0
0003ooooo`;o00004_ooool2o`0000Gooooo0_l00005ooooo`;o00006Oooool2o`0005Gooooo000N
ooooo`03o`000?oooooooooo06[ooooo0_l00012ooooo`;o00007_ooool2o`0001Kooooo0_l00008
ooooo`;o0000EOooool001kooooo0_l0002Booooo`;o0000<?ooool2o`00027ooooo0_l0001Ooooo
o`007_ooool00ol0003oooooooooo`0Hooooo`;o0000B?ooool2o`0002gooooo0_l0000`ooooo`;o
00004oooool2o`0001cooooo0_l0000dooooo`;o00000oooool2o`0001Cooooo000Mooooo`;o0000
6_ooool2o`0004Sooooo0_l0000Yooooo`;o0000BOooool2o`0001cooooo0_l0000dooooo`;o0000
0oooool2o`0001Cooooo000Mooooo`;o00005_ooool2o`0007Oooooo0_l0001;ooooo`;o0000Jooo
ool001kooooo00?o0000ooooooooool05?ooool2o`0001Cooooo0_l00005ooooo`;o00005Oooool2
o`0003kooooo0_l00016ooooo`Co00001_ooool2o`00037ooooo0_l0000Fooooo`;o00008?ooool0
01kooooo00?o0000ooooooooool0:_ooool2o`0000Gooooo0_l0000Eooooo`;o0000?_ooool2o`00
04Kooooo1?l0000iooooo`;o00003?ooool2o`0000Sooooo0_l0000Pooooo`007_ooool00ol0003o
ooooooooo`05ooooo`;o0000=Oooool2o`0001?ooooo0_l0000:ooooo`;o0000AOooool2o`0003Go
oooo0_l0000Jooooo`?o00008Oooool2o`0002[ooooo000Nooooo`03o`000?oooooooooo00Gooooo
0_l0000Kooooo`;o00006?ooool2o`0000Gooooo0_l0000<ooooo`;o00002_ooool2o`0004Gooooo
0_l0000Pooooo`;o00004oooool2o`0001[ooooo0ol0001=ooooo`007_ooool00ol0003ooooooooo
o`07ooooo`;o00006Oooool2o`0001oooooo0_l0000Sooooo`;o00005Oooool2o`0004?ooooo1?l0
000Cooooo`;o0000A?ooool2o`0002Cooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l00002
ooooo`;o0000Foooool2o`0001Cooooo0ol00013ooooo`;o00005Oooool2o`00017ooooo0_l0000a
ooooo`;o00009?ooool001kooooo00?o0000ooooooooool02oooool2o`00077ooooo0_l0001^oooo
o`;o0000Eoooool001kooooo00?o0000ooooooooool07Oooool2o`00047ooooo0_l0002^ooooo`;o
0000=Oooool001kooooo00?o0000ooooooooool07Oooool2o`00047ooooo0_l0002^ooooo`;o0000
8Oooool2o`0001;ooooo000Nooooo`04o`000?oooooo0000o`0005oooooo0_l0000Gooooo`;o0000
9oooool2o`0002Gooooo0_l0000_ooooo`;o0000=oooool2o`0001;ooooo000Nooooo`04o`000?oo
oooo0000o`0001Kooooo0_l00017ooooo`;o00002_ooool2o`0000_ooooo0_l0000Wooooo`;o0000
9Oooool2o`0002oooooo0_l0001;ooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o000000?o
ooooo`000?l00000:?ooool2o`0002Kooooo0_l00009ooooo`;o00002oooool2o`000<7ooooo000N
ooooo`;o00006oooool2o`0002Sooooo0_l0000aooooo`;o00000_ooool2o`0000Oooooo0_l0000C
ooooo`;o0000>?ooool2o`0005gooooo0_l0000Cooooo`007_ooool00ol0003oooooooooo`1Boooo
o`;o00009oooool2o`0001cooooo0_l00004ooooo`;o0000<_ooool2o`0002oooooo0_l00006oooo
o`;o00009?ooool2o`0000[ooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`0Xooooo`;o
0000:?ooool2o`0004_ooooo0_l0001Sooooo`;o00001_ooool2o`00033ooooo0_l00007ooooo`00
7_ooool00ol0003oooooooooo`0Tooooo`;o00000_ooool2o`000??ooooo0_l0000=ooooo`;o0000
6Oooool001kooooo00?o0000ooooooooool09?ooool2o`0001Oooooo0_l0003Nooooo`;o00003Ooo
ool2o`0001Wooooo000Nooooo`03o`000?oooooooooo03gooooo0_l0002Hooooo`;o0000<?ooool2
o`0003cooooo000Nooooo`03o`000?oooooooooo07cooooo0_l00002ooooo`;o0000EOooool2o`00
017ooooo0_l0000Mooooo`;o00004Oooool2o`0002Wooooo000Nooooo`03o`000?oooooooooo04[o
oooo0_l0000`ooooo`;o00000_ooool2o`0006Sooooo0_l0000[ooooo`;o00000oooool2o`0000Co
oooo0_l0000Sooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o0000>oooool2o`0001Gooooo
0_l0000=ooooo`;o0000D?ooool2o`0000kooooo0_l0000[ooooo`;o00005_ooool2o`0000Wooooo
0_l0000Sooooo`007_ooool00ol0003oooooooooo`03ooooo`;o00002?ooool2o`0005;ooooo0_l0
000=ooooo`;o0000D?ooool2o`0000kooooo0_l0000Zooooo`?o0000A_ooool001kooooo00?o0000
ooooooooool00oooool2o`0003gooooo0_l0000/ooooo`;o0000FOooool2o`0001Wooooo0_l00003
ooooo`;o00004Oooool2o`0000_ooooo0_l0000jooooo`007_ooool00ol0003oooooooooo`12oooo
o`;o00008?ooool2o`0000[ooooo0_l0000_ooooo`;o0000:?ooool2o`0001Wooooo0_l00003oooo
o`;o00007_ooool2o`0003[ooooo000Nooooo`03o`000?oooooooooo06Cooooo0_l00002ooooo`;o
0000=oooool2o`0007Gooooo0_l0000]ooooo`007_ooool00ol0003oooooooooo`1Xooooo`;o0000
3Oooool2o`0007;ooooo0_l0000[ooooo`;o0000;Oooool000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000oooooooo
ool00oooool2o`0005Wooooo0_l0000Gooooo`;o0000L_ooool2o`0002gooooo0_l0000Hooooo`;o
00004Oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGo
MgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool00oooool2o`0005Wooooo0_l00007oooo
o`;o0000/Oooool2o`0001Sooooo0_l0000Aooooo`000oooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000>Oooool2o`0002cooooo0_l00004
ooooo`;o00000oooool2o`000=?ooooo0003ooooo`05o`000?ooooooooooooooool000002oooool0
1Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool08oooool2o`0001Cooooo0_l0
000booooo`;o00000oooool2o`0005Cooooo0_l0001<ooooo`;o0000;oooool000?ooooo00Go0000
ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003ooooo
ooooo`0Sooooo`;o0000:?ooool2o`0003kooooo0_l0000Xooooo`;o00003oooool2o`0004cooooo
0_l0000_ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
2?ooool00ol0003oooooooooo`02ooooo`;o00006_ooool2o`0002gooooo0_l0000nooooo`;o0000
:?ooool2o`0008kooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@
oiRHV008ooooo`03o`000?oooooooooo00;ooooo0_l0000Eooooo`;o00000oooool2o`000?oooooo
2oooool2o`0001_ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4
o`000?l@4106ooooo`03o`000?oooooooooo01Wooooo0_l0001Qooooo`;o0000Noooool2o`0002oo
oooo0_l0000Kooooo`007_ooool00ol0003oooooooooo`1looooo`;o0000Noooool2o`00033ooooo
0_l0000Jooooo`007_ooool00ol0003oooooooooo`0Rooooo`;o0000;Oooool2o`00053ooooo0_l0
000Wooooo`;o00001_ooool2o`0005Gooooo0_l0000Jooooo`007_ooool00ol0003oooooooooo`0R
ooooo`;o0000;Oooool2o`0001gooooo0_l0000aooooo`;o00009oooool2o`0000Kooooo0_l0000a
ooooo`;o000000?oooooo`000?l000005_ooool2o`0002?ooooo000Nooooo`03o`000?oooooooooo
01_ooooo0_l0000;ooooo`;o0000A_ooool3o`0000;ooooo0_l0000^ooooo`;o0000H?ooool2o`00
0003ooooool0003o000001Kooooo0_l0000Sooooo`007_ooool01?l0003oooooo`000?l0000Joooo
o`;o00002oooool2o`0001cooooo1?l0000Wooooo`;o00000_ooool4o`0002cooooo0_l0000Uoooo
o`;o00001_ooool2o`0003oooooo0_l00004ooooo`;o0000:_ooool001kooooo00Co0000ooooool0
003o0000=oooool2o`0000cooooo1?l00008ooooo`;o00008oooool2o`0000Sooooo0_l00007oooo
o`;o00004?ooool2o`0002kooooo0_l00006ooooo`;o00009Oooool2o`0001Sooooo0_l00004oooo
o`;o0000:_ooool001kooooo00?o0000ooooooooool0>?ooool2o`0001Sooooo0_l0000]ooooo`;o
00001oooool2o`00013ooooo0_l0001Mooooo`;o00003_ooool2o`0003[ooooo000Nooooo`03o`00
0?oooooooooo00;o0000V_ooool2o`0006gooooo0_l0000`ooooo`;o00002?ooool001kooooo00?o
0000ooooooooool00_l0000>ooooo`?o0000Goooool2o`000003ooooool0003o000000Sooooo0_l0
000Eooooo`;o00001?ooool2o`0009oooooo0_l00008ooooo`007_ooool00ol0003oooooooooo`0@
ooooo`?o0000Goooool2o`000003ooooool0003o000000Sooooo0_l0000Eooooo`;o00006Oooool2
o`0000?ooooo0_l00003ooooo`;o0000F?ooool2o`0002Sooooo0_l00006ooooo`007_ooool00ol0
003oooooooooo`0;ooooo`;o00001?ooool2o`0002Cooooo0_l0001hooooo`;o00000oooool2o`00
00?ooooo0_l0000Zooooo`;o0000;?ooool2o`0002Sooooo0_l00006ooooo`007_ooool2o`0000co
oooo0_l00004ooooo`;o00003oooool2o`0001?ooooo0_l0002Jooooo`;o00004_ooool2o`0005ko
oooo000Nooooo`03o`000?oooooooooo02;ooooo0_l0000=ooooo`;o0000X?ooool2o`00047ooooo
0_l0000_ooooo`007_ooool00ol0003oooooooooo`0aooooo`;o0000D_ooool2o`0003Kooooo0_l0
001Gooooo`;o0000;oooool001kooooo00?o0000ooooooooool09_ooool2o`0003gooooo0_l0000N
ooooo`;o0000=_ooool2o`0000kooooo0_l0001hooooo`007_ooool00ol0003oooooooooo`0Foooo
o`;o00003_ooool2o`0003gooooo0_l0001Vooooo`;o0000N?ooool001kooooo00?o0000oooooooo
ool05_ooool2o`0002gooooo0_l0002Kooooo`;o00002oooool2o`0005Kooooo000Nooooo`03o`00
0?oooooooooo04Gooooo1?l00015ooooo`;o00004_ooool2o`0003kooooo0_l0000;ooooo`;o0000
=?ooool2o`0000[ooooo0_l0000Dooooo`007_ooool00ol0003oooooooooo`17ooooo`;o0000AOoo
ool2o`0001;ooooo0_l00013ooooo`;o0000??ooool2o`0000[ooooo0_l0000Dooooo`007_ooool0
0ol0003oooooooooo`1iooooo`;o0000K?ooool2o`0005kooooo000Nooooo`03o`000?oooooooooo
027ooooo0_l0001Fooooo`;o0000c?ooool001kooooo00?o0000ooooooooool05_ooool2o`0000Wo
oooo0_l0001Uooooo`;o00004?ooool2o`0000[ooooo0_l00006ooooo`;o0000Uoooool001kooooo
00?o0000ooooooooool05_ooool2o`0002Cooooo0_l0001:ooooo`;o00004?ooool2o`0000[ooooo
0_l00006ooooo`;o00005_ooool2o`0002oooooo0_l0001>ooooo`007_ooool00ol0003ooooooooo
o`0looooo`;o0000FOooool2o`0002gooooo0_l0000_ooooo`;o00001Oooool2o`0004Oooooo000N
ooooo`03o`000?oooooooooo00;o0000Ioooool2o`0002cooooo0_l0001Uooooo`;o0000Aoooool0
01kooooo00?o0000ooooooooool00_l0001Wooooo`;o00005Oooool2o`0000;ooooo0_l0000ioooo
o`;o00008?ooool2o`0005[ooooo0_l00008ooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o
0000HOooool2o`0000Cooooo0_l00002ooooo`;o0000>Oooool2o`00023ooooo1?l0001Hooooo`;o
00002?ooool001kooooo0_l0000Hooooo`;o0000HOooool2o`0001Cooooo0_l0001Aooooo`;o0000
3oooool2o`0001Oooooo0_l0000hooooo`007_ooool00ol0003oooooooooo`0Looooo`;o00007ooo
ool2o`00057ooooo0_l00011ooooo`;o00007oooool2o`0001Oooooo0_l0000Nooooo`;o00006?oo
ool001kooooo00?o0000ooooooooool03_ooool2o`0000cooooo0_l0000Iooooo`;o00001?ooool2
o`0008[ooooo0_l00008ooooo`;o0000F?ooool2o`0000Cooooo0_l0000Booooo`007_ooool00ol0
003oooooooooo`02o`0000cooooo0_l0000Dooooo`;o00002_ooool2o`0000Gooooo0_l0002@oooo
o`;o0000B_ooool2o`0001cooooo0_l0000Booooo`007_ooool00ol0003oooooooooo`02o`0002;o
oooo0_l0000:ooooo`;o00001oooool2o`0005Gooooo0_l00012ooooo`;o00002_ooool2o`0000_o
oooo0_l0000Vooooo`;o0000<?ooool001kooooo00?o0000ooooooooool01_ooool2o`0001;ooooo
0_l0000Mooooo`;o00000_ooool2o`00057ooooo0_l00012ooooo`;o00002_ooool4o`0000Gooooo
0_l00002ooooo`;o00002Oooool2o`0004gooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l0
000Booooo`;o00008Oooool2o`00027ooooo0_l0001=ooooo`;o0000;?ooool2o`0000?ooooo0_l0
0005ooooo`;o00003Oooool2o`0004gooooo000Nooooo`03o`000?oooooooooo063ooooo0_l0000?
ooooo`;o0000??ooool2o`0002cooooo0_l0001;ooooo`;o00001oooool2o`0001;ooooo000Moooo
o`;o0000Loooool2o`0000Cooooo0_l0001@ooooo`;o0000Goooool2o`0000Oooooo0_l0000Boooo
o`007Oooool2o`0003?ooooo0_l00014ooooo`;o00008oooool2o`0002_ooooo0_l0000^ooooo`;o
0000C?ooool001kooooo00?o0000ooooooooool0<Oooool2o`0006Wooooo0_l0001Kooooo`;o0000
=?ooool2o`0001Kooooo000Nooooo`03o`000?oooooooooo03Sooooo0_l0001<ooooo`;o0000Yooo
ool2o`0001Kooooo000Nooooo`03o`000?oooooooooo03Sooooo0_l00009ooooo`;o0000=?ooool2
o`0000_ooooo0_l0001Uooooo`;o0000F?ooool001kooooo00?o0000ooooooooool0@oooool2o`00
03Cooooo0_l0000Cooooo`;o0000GOooool2o`0002cooooo0_l0000=ooooo`;o00006oooool001ko
oooo00?o0000ooooooooool0I_ooool2o`000003ooooool0003o000002?ooooo0_l0002;ooooo`;o
00003Oooool2o`0000kooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`06ooooo`;o0000
E?ooool2o`0000Sooooo0_l000000ooooooo0000o`00001Iooooo`;o00005Oooool2o`00043ooooo
0_l0000Kooooo`;o00002oooool001kooooo0_l00007ooooo`;o0000<oooool2o`0001oooooo0_l0
001=ooooo`;o00005oooool2o`0001Gooooo0_l00004ooooo`;o0000>_ooool2o`0002Sooooo000N
ooooo`03o`000?oooooooooo03_ooooo0_l0000Kooooo`;o00003Oooool2o`0004;ooooo0_l0000d
ooooo`?o00004?ooool2o`00057ooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l0000Noooo
o`;o00008?ooool2o`0000Gooooo0_l00006ooooo`;o0000NOooool2o`00013ooooo0_l0001Aoooo
o`007_ooool2o`0001Oooooo0_l0000;ooooo`;o00001?ooool2o`0000_ooooo0_l0000Wooooo`;o
00008oooool2o`0005oooooo0_l0001?ooooo`;o00003oooool001kooooo0_l0000Tooooo`;o0000
1?ooool2o`0002oooooo0_l0000Qooooo`;o00001Oooool2o`0000Gooooo0_l0001Hooooo`;o0000
Coooool2o`0000oooooo000Nooooo`03o`000?oooooooooo03Oooooo0_l0000Qooooo`;o00008Ooo
ool2o`0000cooooo0_l0002jooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o00009Oooool2
o`000003ooooool0003o000004Sooooo0_l0001nooooo`;o00006_ooool2o`0002Sooooo000Noooo
o`03o`000?oooooooooo00gooooo0_l0000Uooooo`;o0000Boooool2o`0005;ooooo0_l0000Zoooo
o`;o00006_ooool2o`0001Gooooo0_l0000Aooooo`007_ooool00ol0003oooooooooo`3Eooooo`;o
0000GOooool2o`00017ooooo000Nooooo`03o`000?oooooooooo06[ooooo0_l00018ooooo`;o0000
BOooool2o`0002Sooooo0_l0000Looooo`007_ooool00ol0003oooooooooo`1Zooooo`;o00003?oo
ool2o`0003[ooooo0_l00019ooooo`;o00006Oooool2o`0000gooooo0_l000000ooooooo0000o`00
000Iooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o00001oooool2o`0004gooooo0_l0001B
ooooo`;o0000C?ooool2o`00013ooooo0_l0000Iooooo`007_ooool00ol0003oooooooooo`0Poooo
o`;o00001oooool2o`000:7ooooo0_l0000Aooooo`;o0000I_ooool001kooooo00?o0000oooooooo
ool0goooool2o`0002Kooooo0_l0000nooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooo
o`Sooooo0_l0000Uooooo`;o00005oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0;?ooool2
o`000?oooooo0Oooool2o`0000Oooooo0_l0000>ooooo`000oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o00004oooool2o`0001Oooooo0_l0
0021ooooo`;o0000Loooool2o`0000Cooooo0_l0000;ooooo`;o00003_ooool000?ooooo00Go0000
ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool00ol0003ooooo
ooooo`0Cooooo`;o0000<?ooool2o`0006Sooooo1?l0000Dooooo`;o0000Foooool2o`0000Cooooo
0_l0000Kooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o
0000olc<c006ooooo`03o`000?oooooooooo03;ooooo0_l0000@ooooo`?o00001oooool2o`0003oo
oooo0_l0000Pooooo`;o00005?ooool2o`0005[ooooo0_l0000Rooooo`000oooool01Ol@413ooooo
oooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo
03;ooooo0_l0000@ooooo`;o00002?ooool2o`0002[ooooo0_l0000Cooooo`;o0000T_ooool2o`00
02;ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o
000000Kooooo00?o0000ooooooooool0KOooool2o`0000_ooooo0_l00008ooooo`;o0000@?ooool2
o`0006Oooooo0_l0000Fooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVY
oa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo06gooooo0_l0000Eooooo`;o0000:ooo
ool2o`0001?ooooo0_l0001Wooooo`;o00005_ooool001kooooo00?o0000ooooooooool01Oooool2
o`0002Kooooo0_l0001Kooooo`;o00002?ooool2o`0001_ooooo0_l0000looooo`;o00003_ooool2
o`0000Kooooo0_l0000Pooooo`;o00007?ooool001kooooo00?o0000ooooooooool01Oooool2o`00
02;ooooo0_l00002ooooo`;o0000Foooool2o`0000Sooooo0_l0001Dooooo`;o00000oooool2o`00
00kooooo0_l00006ooooo`;o00005Oooool2o`0000Wooooo0_l0000Looooo`007Oooool2o`0001So
oooo0_l0000:ooooo`;o00001Oooool2o`0001oooooo0_l0002Nooooo`;o0000<_ooool2o`0002Oo
oooo000Mooooo`;o00003oooool2o`0000Oooooo0_l0000:ooooo`;o00009_ooool2o`0004Sooooo
0_l0000Eooooo`;o0000V_ooool001kooooo00?o0000ooooooooool03Oooool2o`00037ooooo0_l0
000kooooo`;o00005Oooool2o`0001Gooooo0_l0002Jooooo`007_ooool00ol0003oooooooooo`06
ooooo`;o00004oooool2o`0002?ooooo0_l0000kooooo`;o0000b?ooool001kooooo00?o0000oooo
ooooool01_ooool2o`0001?ooooo0_l0003oooooob_ooooo000Nooooo`03o`000?oooooooooo02oo
oooo0_l000000ooooooo0000o`00000Eooooo`?o0000noooool001kooooo00?o0000ooooooooool0
3_ooool2o`0001oooooo0_l000000ooooooo0000o`00000Eooooo`?o0000noooool001kooooo00?o
0000ooooooooool03_ooool2o`0006[ooooo0_l0000Yooooo`;o00002_ooool2o`000003ooooool0
003o000002Oooooo0_l0001Xooooo`007_ooool00ol0003oooooooooo`17ooooo`;o0000<Oooool2
o`0002Wooooo0_l0000:ooooo`;o000000?oooooo`000?l000009oooool2o`0006Sooooo000Noooo
o`;o0000B?ooool2o`0000Wooooo0_l00016ooooo`;o0000D_ooool2o`0005Oooooo000Nooooo`03
o`000?oooooooooo00?ooooo0_l00002ooooo`;o00007oooool2o`0000?ooooo0_l0000Sooooo`;o
0000<_ooool2o`0001;ooooo0_l0001Booooo`;o0000??ooool2o`0001Wooooo000Nooooo`03o`00
0?oooooooooo00?ooooo0_l00002ooooo`;o00007oooool2o`0000?ooooo0_l0001<ooooo`;o0000
2Oooool2o`0002;ooooo0_l0001cooooo`;o00002oooool2o`0001Wooooo000Nooooo`04o`000?oo
oooo0000o`0006Kooooo0_l0000Booooo`;o0000;Oooool2o`0007?ooooo0_l0000Vooooo`007_oo
ool01?l0003oooooo`000?l0001Vooooo`;o00005oooool2o`0002Wooooo0_l0002Jooooo`007_oo
ool00ol0003oooooooooo`20ooooo`;o00006oooool2o`0000cooooo0_l0000dooooo`;o0000;_oo
ool2o`0003Cooooo000Nooooo`03o`000?oooooooooo09gooooo0_l00012ooooo`;o0000:oooool2
o`000003ooooool0003o000000Sooooo0_l0000=ooooo`;o00003?ooool2o`0000gooooo000Noooo
o`03o`000?oooooooooo00Kooooo0_l00028ooooo`;o0000O?ooool2o`0000_ooooo0_l0000=oooo
o`;o00003?ooool2o`0000gooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l00028ooooo`;o
0000O?ooool2o`0003Oooooo000Nooooo`03o`000?oooooooooo02Kooooo0_l0000aooooo`;o0000
/oooool2o`0000gooooo0_l0000Xooooo`007_ooool00ol0003oooooooooo`0Vooooo`;o0000<Ooo
ool2o`0005Cooooo0_l0001Uooooo`;o00001Oooool2o`0002Sooooo000Nooooo`03o`000?oooooo
oooo0:oooooo0_l0001Uooooo`;o00002Oooool2o`0000gooooo0_l0000Eooooo`007_ooool00ol0
003oooooooooo`1mooooo`;o0000BOooool2o`0005Oooooo0_l0000=ooooo`;o00005Oooool001ko
oooo00?o0000ooooooooool0K_ooool2o`0000gooooo0_l00019ooooo`;o0000:?ooool2o`0005?o
oooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0001?ooooo`;o00005?ooool2o`0001;ooooo
0_l0000fooooo`;o0000=_ooool2o`0000Oooooo0_l0000oooooo`;o00002Oooool001kooooo00?o
0000ooooooooool01oooool2o`0004oooooo0_l0000:ooooo`;o00001_ooool2o`0001Cooooo0_l0
000]ooooo`;o00001oooool2o`0002gooooo0_l0000@ooooo`;o0000?oooool2o`0000Wooooo000N
ooooo`;o0000?oooool2o`0001kooooo0_l00004ooooo`;o00001_ooool4o`0002_ooooo0_l0000D
ooooo`;o00000oooool2o`0000;ooooo0_l0000]ooooo`;o0000G?ooool001kooooo00?o0000oooo
ooooool09Oooool2o`0001Oooooo0_l0000Nooooo`;o00003_ooool2o`0001;ooooo0_l0000Goooo
o`;o00006Oooool2o`0000;ooooo0_l0001>ooooo`;o00000_ooool2o`0003Oooooo000Nooooo`03
o`000?oooooooooo02Gooooo0_l0000Gooooo`;o00009?ooool2o`0001cooooo0_l00008ooooo`;o
0000:_ooool2o`0002_ooooo0_l0000Sooooo`?o000000?oooooo`000?l00000=oooool001kooooo
00?o0000ooooooooool0?_ooool2o`0002Cooooo1?l00006ooooo`;o00007?ooool2o`0000;ooooo
0_l0000Vooooo`;o0000:oooool2o`0002Cooooo0_l0000jooooo`007_ooool00ol0003ooooooooo
o`09ooooo`;o0000Foooool2o`0000Kooooo0_l0000Pooooo`;o0000?_ooool2o`0007Gooooo000N
ooooo`03o`000?oooooooooo00Wooooo0_l00003ooooo`;o00005Oooool2o`0001Oooooo0_l0001H
ooooo`;o00006_ooool2o`0001;ooooo0_l00006ooooo`;o000000?oooooo`000?l000006oooool2
o`0005Gooooo000Nooooo`03o`000?oooooooooo00kooooo0_l0000Eooooo`;o00005oooool2o`00
05Sooooo0_l0000Jooooo`;o00004_ooool2o`0000Wooooo0_l0000Kooooo`;o00000_ooool2o`00
03Oooooo0_l0000Hooooo`007_ooool00ol0003oooooooooo`1Aooooo`;o0000XOooool2o`0003Oo
oooo0_l0000Hooooo`007_ooool00ol0003oooooooooo`1Aooooo`;o00006Oooool2o`000=Wooooo
000Nooooo`03o`000?oooooooooo057ooooo0_l0000Iooooo`;o0000=_ooool2o`0008Wooooo0_l0
000Fooooo`007_ooool00ol0003oooooooooo`1Aooooo`;o00002Oooool2o`0001Cooooo0_l0000[
ooooo`;o00000oooool2o`0004Kooooo0_l00011ooooo`;o00005_ooool001kooooo00?o0000oooo
ooooool0C_ooool2o`0000cooooo0_l0000Dooooo`;o0000:oooool2o`00043ooooo0_l00009oooo
o`;o0000FOooool001kooooo00?o0000ooooooooool0C_ooool2o`0007kooooo0_l0000Aooooo`;o
0000;Oooool2o`0003Gooooo000Nooooo`;o0000coooool2o`0000_ooooo0_l0000cooooo`;o0000
9Oooool2o`0000kooooo000Nooooo`;o00003?ooool2o`0005;ooooo0_l0001@ooooo`;o0000:?oo
ool2o`0000kooooo0_l0001:ooooo`;o00003_ooool001kooooo00?o0000ooooooooool02oooool2
o`0005;ooooo0_l0000Looooo`;o00006_ooool2o`0001Kooooo0_l0000fooooo`Co0000<Oooool2
o`0001Oooooo0_l0000>ooooo`007_ooool2o`0006_ooooo0_l0000Aooooo`;o00006_ooool2o`00
00;ooooo0_l0001:ooooo`;o00009Oooool2o`0000cooooo0_l0000Gooooo`;o00003_ooool001ko
oooo00?o0000ooooooooool0J_ooool2o`00037ooooo0_l0001aooooo`;o0000=Oooool001kooooo
00?o0000ooooooooool04oooool2o`0000Cooooo0_l0002jooooo`;o00004oooool2o`0005_ooooo
000Nooooo`03o`000?oooooooooo01?ooooo0_l00004ooooo`;o0000Goooool2o`0003?ooooo0_l0
000Hooooo`;o00001oooool2o`000004ooooool0003o0000ooooo`;o00001oooool2o`0000Oooooo
0_l0000Sooooo`;o0000=_ooool001kooooo00?o0000ooooooooool0N_ooool2o`0003?ooooo0_l0
000Hooooo`;o00001oooool2o`0000Cooooo0_l00007ooooo`;o0000;?ooool2o`0002Gooooo0_l0
0007ooooo`;o00001_ooool001kooooo00?o0000ooooooooool02_ooool2o`000?oooooo:oooool4
o`0000Gooooo0_l00006ooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o00001?ooool2o`00
02_ooooo0_l00021ooooo`;o00006oooool2o`0001Kooooo0_l0000<ooooo`;o0000<oooool2o`00
00gooooo000Nooooo`03o`000?oooooooooo013ooooo0_l0000[ooooo`;o0000POooool2o`0001_o
oooo0_l0000Fooooo`;o00003?ooool2o`0004;ooooo000Nooooo`03o`000?oooooooooo03kooooo
0_l0002Xooooo`;o000000?oooooo`000?l000003oooool2o`0004Wooooo000Nooooo`03o`000?oo
oooooooo03kooooo0_l0002Kooooo`;o00002oooool2o`000003ooooool0003o000000oooooo0_l0
0019ooooo`007_ooool00ol0003oooooooooo`0_ooooo`;o0000Aoooool2o`00067ooooo0_l0001Z
ooooo`007Oooool2o`0000kooooo0_l0000Qooooo`;o00002_ooool2o`0003_ooooo0_l0000foooo
o`;o0000AOooool2o`0004kooooo000Mooooo`;o00003_ooool2o`0002gooooo0_l0000eooooo`;o
0000??ooool2o`0002_ooooo0_l0000Aooooo`;o00001Oooool2o`0000Sooooo0_l0000Yooooo`;o
00006Oooool001kooooo00?o0000ooooooooool0H_ooool2o`0000kooooo0_l0001Yooooo`;o0000
4Oooool2o`0000oooooo0_l0000Tooooo`;o00000oooool2o`0001Wooooo000Dooooo`Co000000?o
410@ooooooooool00oooool00ol0003oooooooooo`1Rooooo`;o0000QOooool2o`0002Gooooo0_l0
000Eooooo`;o00007_ooool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02
o`0000Wooooo0_l0000`ooooo`;o0000Poooool2o`0002Gooooo0_l0000Uooooo`;o0000=Oooool0
01Kooooo00?o0000ooooooooool01Oooool5o`0000Wooooo0_l0000`ooooo`;o0000Poooool2o`00
08?ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0
oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooo
oooo0?ooooooD?ooool001Cooooo00?oEEEEofIVI_l00000oooooomBooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.42127 .79275 Mdot
.64663 .48929 Mdot
.60251 .94908 Mdot
.00332 .35356 Mdot
.07372 .79316 Mdot
.76575 .6858 Mdot
.33097 .53044 Mdot
.30695 .75601 Mdot
.49761 .37314 Mdot
.91103 .03337 Mdot
.58003 .22364 Mdot
.64898 .49414 Mdot
.11828 .70684 Mdot
.05034 .86111 Mdot
.56525 .30367 Mdot
.93497 .80759 Mdot
.33556 .89845 Mdot
.81457 .53107 Mdot
.99194 .94192 Mdot
.54278 .31087 Mdot
.66127 .37001 Mdot
.90143 .06625 Mdot
.38177 .83293 Mdot
.40043 .05271 Mdot
.54181 .19485 Mdot
.90364 .25914 Mdot
.7428 .18382 Mdot
.52087 .38705 Mdot
.80821 .42055 Mdot
.30558 .63613 Mdot
.36713 .61087 Mdot
.10067 .80077 Mdot
.31711 .71337 Mdot
.1815 .13338 Mdot
.60271 .71014 Mdot
.36438 .45704 Mdot
.85511 .59997 Mdot
.38106 .94765 Mdot
.39721 .68249 Mdot
.8598 .11539 Mdot
.25667 .53758 Mdot
.57229 .24363 Mdot
.17368 .76873 Mdot
.10766 .64837 Mdot
.32926 .62368 Mdot
.79097 .53306 Mdot
.08774 .42349 Mdot
.86794 .29062 Mdot
.57083 .87136 Mdot
.76316 .73073 Mdot
.4107 .65116 Mdot
.00783 .44406 Mdot
.26574 .36172 Mdot
.98977 .35946 Mdot
.56203 .22055 Mdot
.3595 .51522 Mdot
.2685 .92904 Mdot
.92059 .60336 Mdot
.98731 .47324 Mdot
.00083 .51496 Mdot
.39971 .61023 Mdot
.3709 .68083 Mdot
.28706 .26142 Mdot
.72898 .02401 Mdot
.52458 .55629 Mdot
.47004 .18056 Mdot
.73179 .45576 Mdot
.62126 .56793 Mdot
.47405 .78454 Mdot
.00714 .0456 Mdot
.61874 .56151 Mdot
.50576 .82806 Mdot
.22995 .81603 Mdot
.78144 .13623 Mdot
.89263 .8561 Mdot
.1791 .31351 Mdot
.53659 .34108 Mdot
.98883 .71648 Mdot
.58549 .34559 Mdot
.50105 .99123 Mdot
.56458 .11729 Mdot
.40562 .34153 Mdot
.23107 .21703 Mdot
.46186 .49042 Mdot
.06879 .92324 Mdot
.46614 .68571 Mdot
.64627 .69358 Mdot
.67318 .20684 Mdot
.57729 .29878 Mdot
.8133 .30572 Mdot
.93085 .15725 Mdot
.16419 .95609 Mdot
.40246 .81986 Mdot
.98956 .16742 Mdot
.64954 .06967 Mdot
.68841 .7119 Mdot
.86281 .81667 Mdot
.82537 .6393 Mdot
.46746 .72514 Mdot
.87158 .0317 Mdot
.67994 .13959 Mdot
.78318 .37919 Mdot
.96243 .68935 Mdot
.09147 .18154 Mdot
.10402 .9802 Mdot
.16691 .17411 Mdot
.83417 .41499 Mdot
.26478 .11002 Mdot
.15474 .44395 Mdot
.10967 .53917 Mdot
.96854 .80665 Mdot
.34275 .33473 Mdot
.52322 .69797 Mdot
.06998 .46532 Mdot
.54658 .35591 Mdot
.09082 .70289 Mdot
.753 .64344 Mdot
.24235 .03348 Mdot
.18945 .87445 Mdot
.71142 .78402 Mdot
.77864 .74002 Mdot
.51406 .90914 Mdot
.31628 .06622 Mdot
.25811 .48345 Mdot
.27301 .20186 Mdot
.40527 .68066 Mdot
.92432 .84591 Mdot
.21103 .38186 Mdot
.10986 .7966 Mdot
.51137 .27236 Mdot
.04882 .42437 Mdot
.43497 .34353 Mdot
.41535 .97984 Mdot
.01017 .26278 Mdot
.58606 .94934 Mdot
.43253 .8446 Mdot
.44582 .13006 Mdot
.16375 .02849 Mdot
.71678 .94916 Mdot
.38468 .7392 Mdot
.39885 .82002 Mdot
.76815 .87062 Mdot
.93194 .34543 Mdot
.36184 .71668 Mdot
.12567 .25238 Mdot
.21244 .80571 Mdot
.22169 .70082 Mdot
.45871 .45923 Mdot
.03542 .58955 Mdot
.85416 .26477 Mdot
.29142 .09543 Mdot
.68121 .53248 Mdot
.39753 .60156 Mdot
.94693 .68555 Mdot
.80743 .40195 Mdot
.09364 .65646 Mdot
.91051 .27406 Mdot
.44793 .90297 Mdot
.38795 .29818 Mdot
.33928 .39087 Mdot
.94893 .05026 Mdot
.74656 .48495 Mdot
.02551 .8329 Mdot
.25568 .03599 Mdot
.8265 .36052 Mdot
.76983 .09444 Mdot
.54091 .85352 Mdot
.79698 .04735 Mdot
.02427 .45765 Mdot
.32072 .41596 Mdot
.19478 .39851 Mdot
.06533 .74552 Mdot
.25206 .91638 Mdot
.50954 .8299 Mdot
.1317 .12538 Mdot
.99489 .55696 Mdot
.24492 .03576 Mdot
.9974 .16573 Mdot
.8776 .1817 Mdot
.5097 .84979 Mdot
.01259 .71315 Mdot
.88196 .77369 Mdot
.3202 .17341 Mdot
.13736 .75435 Mdot
.63534 .68092 Mdot
.39031 .92395 Mdot
.06686 .37113 Mdot
.85253 .75688 Mdot
.64086 .71976 Mdot
.72386 .04324 Mdot
.26999 .04362 Mdot
.56018 .88208 Mdot
.25084 .75758 Mdot
.51578 .84024 Mdot
.81181 .86704 Mdot
.70785 .72876 Mdot
.83237 .56371 Mdot
.60048 .67825 Mdot
.21255 .69854 Mdot
.77287 .45516 Mdot
.36091 .38618 Mdot
.83247 .66844 Mdot
.35349 .88648 Mdot
.27773 .05959 Mdot
.43553 .15197 Mdot
.19106 .94185 Mdot
.62064 .66468 Mdot
.85765 .87445 Mdot
.96145 .84561 Mdot
.35176 .92439 Mdot
.25204 .82782 Mdot
.10775 .73685 Mdot
.05667 .40686 Mdot
.86791 .47381 Mdot
.86098 .92962 Mdot
.5515 .47447 Mdot
.53088 .21487 Mdot
.8516 .27679 Mdot
.91287 .88252 Mdot
.37948 .74661 Mdot
.89062 .90137 Mdot
.0607 .41467 Mdot
.87015 .15993 Mdot
.47811 .67716 Mdot
.07833 .14203 Mdot
.92966 .76871 Mdot
.86106 .85083 Mdot
.10072 .50718 Mdot
.41692 .43786 Mdot
.82943 .54988 Mdot
.09396 .90193 Mdot
.19966 .81539 Mdot
.33903 .59816 Mdot
.19233 .85002 Mdot
.27455 .95788 Mdot
.08631 .05256 Mdot
.33072 .42314 Mdot
.73321 .46153 Mdot
.2508 .40569 Mdot
.43691 .62071 Mdot
.30638 .75199 Mdot
.45086 .87486 Mdot
.97839 .123 Mdot
.30061 .89993 Mdot
.9426 .49846 Mdot
.2956 .0015 Mdot
.21936 .82371 Mdot
.51086 .75905 Mdot
.45017 .17834 Mdot
.20212 .55503 Mdot
.52194 .48958 Mdot
.6187 .22874 Mdot
.14695 .2496 Mdot
.73221 .98618 Mdot
.93722 .38253 Mdot
.16802 .84542 Mdot
.36941 .80368 Mdot
.06299 .95986 Mdot
.29484 .33835 Mdot
.78448 .03212 Mdot
.4945 .92712 Mdot
.72587 .29309 Mdot
.80579 .19884 Mdot
.50603 .22295 Mdot
.07468 .10798 Mdot
.21624 .36974 Mdot
.36447 .0407 Mdot
.2385 .59059 Mdot
.50861 .2775 Mdot
.98454 .80176 Mdot
.88521 .17696 Mdot
.29636 .1718 Mdot
.37604 .86766 Mdot
.43318 .74352 Mdot
.2331 .8716 Mdot
.71259 .83553 Mdot
.68844 .93239 Mdot
.77773 .23171 Mdot
.44486 .31423 Mdot
.08395 .80209 Mdot
.64185 .2228 Mdot
.35775 .06677 Mdot
.68775 .55477 Mdot
.8366 .74765 Mdot
.206 .20824 Mdot
.77131 .4801 Mdot
.73036 .23701 Mdot
.85943 .22211 Mdot
.83778 .21394 Mdot
.77635 .99038 Mdot
.96635 .77594 Mdot
.15236 .27019 Mdot
.91222 .86793 Mdot
.80184 .55131 Mdot
.90729 .40848 Mdot
.90863 .25588 Mdot
.46267 .55622 Mdot
.37624 .36435 Mdot
.70063 .48414 Mdot
.20998 .05602 Mdot
.5965 .30065 Mdot
.63121 .22675 Mdot
.41302 .44286 Mdot
.08439 .16255 Mdot
.57634 .65352 Mdot
.37178 .44676 Mdot
.44543 .2067 Mdot
.61511 .98182 Mdot
.62483 .87479 Mdot
.72565 .75859 Mdot
.38532 .55124 Mdot
.65774 .56414 Mdot
.15644 .32205 Mdot
.81763 .19254 Mdot
.11495 .21295 Mdot
.0474 .423 Mdot
.94217 .77122 Mdot
.22397 .68322 Mdot
.46817 .24907 Mdot
.65516 .27798 Mdot
.87422 .83778 Mdot
.83994 .964 Mdot
.64991 .3025 Mdot
.6668 .93475 Mdot
.50206 .3141 Mdot
.74904 .6203 Mdot
.77133 .32787 Mdot
.55141 .4703 Mdot
.92117 .95726 Mdot
.14716 .37681 Mdot
.9769 .9402 Mdot
.12457 .82 Mdot
.55629 .58014 Mdot
.60889 .07767 Mdot
.00505 .61519 Mdot
.4108 .74358 Mdot
.31416 .90842 Mdot
.55414 .65674 Mdot
.89077 .66304 Mdot
.5663 .22467 Mdot
.97734 .13436 Mdot
.07616 .75993 Mdot
.24558 .59654 Mdot
.71232 .9706 Mdot
.19859 .63739 Mdot
.34711 .91409 Mdot
.26378 .23796 Mdot
.98031 .70207 Mdot
.53317 .55899 Mdot
.9405 .64351 Mdot
.26288 .07893 Mdot
.0002 .57666 Mdot
.19994 .66799 Mdot
.68464 .07728 Mdot
.12779 .67128 Mdot
.0846 .89186 Mdot
.07719 .14178 Mdot
.23355 .63441 Mdot
.53821 .51902 Mdot
.84836 .13035 Mdot
.9327 .72107 Mdot
.57248 .81879 Mdot
.41891 .74184 Mdot
.93614 .38067 Mdot
.97378 .52861 Mdot
.32599 .18127 Mdot
.12692 .63511 Mdot
.61677 .42651 Mdot
.40939 .41059 Mdot
.24716 .4315 Mdot
.49043 .46162 Mdot
.04437 .2997 Mdot
.5437 .66041 Mdot
.53039 .96936 Mdot
.38643 .6741 Mdot
.30474 .7198 Mdot
.01753 .64252 Mdot
.51884 .83275 Mdot
.19962 .72311 Mdot
.47542 .05194 Mdot
.84391 .25389 Mdot
.98855 .90032 Mdot
.67724 .74526 Mdot
.60374 .18225 Mdot
.43076 .93497 Mdot
.61771 .51492 Mdot
.22066 .61913 Mdot
.9964 .88589 Mdot
.49358 .34181 Mdot
.71125 .92496 Mdot
.86158 .75514 Mdot
.00899 .99318 Mdot
.12932 .20837 Mdot
.63 .19248 Mdot
.25024 .65522 Mdot
.4615 .24867 Mdot
.67772 .85381 Mdot
.93736 .56038 Mdot
.77741 .41373 Mdot
.91062 .66616 Mdot
.83362 .1867 Mdot
.61921 .5374 Mdot
.82654 .45759 Mdot
.51408 .207 Mdot
.32273 .4956 Mdot
.85483 .04805 Mdot
.01572 .31635 Mdot
.96569 .08274 Mdot
.35421 .59899 Mdot
.61892 .9135 Mdot
.00515 .019 Mdot
.57332 .70151 Mdot
.70712 .69624 Mdot
.946 .761 Mdot
.99587 .78511 Mdot
.6487 .6169 Mdot
.37069 .20326 Mdot
.9549 .82114 Mdot
.86608 .94546 Mdot
.96674 .80835 Mdot
.58367 .52594 Mdot
.14109 .12769 Mdot
.84348 .15331 Mdot
.48326 .09285 Mdot
.57589 .09599 Mdot
.41499 .35188 Mdot
.19031 .70591 Mdot
.12278 .65892 Mdot
.66934 .66981 Mdot
.66435 .22357 Mdot
.59108 .49463 Mdot
.57486 .33955 Mdot
.85595 .37583 Mdot
.15546 .26749 Mdot
.35926 .82779 Mdot
.84807 .33973 Mdot
.27877 .37177 Mdot
.94464 .98616 Mdot
.74421 .08018 Mdot
.3453 .94781 Mdot
.8246 .21602 Mdot
.61427 .22837 Mdot
.45849 .28072 Mdot
.69534 .94512 Mdot
.8129 .32632 Mdot
.96846 .90198 Mdot
.67403 .08017 Mdot
.74164 .46277 Mdot
.40939 .32719 Mdot
.36298 .6249 Mdot
.19096 .72165 Mdot
.38948 .56798 Mdot
.94517 .58366 Mdot
.25339 .07138 Mdot
.47356 .13543 Mdot
.43047 .45186 Mdot
.48867 .45191 Mdot
.12337 .23547 Mdot
.40865 .35234 Mdot
.9968 .6302 Mdot
.85094 .46181 Mdot
.38563 .19753 Mdot
.78121 .98471 Mdot
.50846 .93663 Mdot
.40553 .61971 Mdot
.35399 .54728 Mdot
.23779 .12267 Mdot
.36769 .60404 Mdot
.26171 .77134 Mdot
.88561 .78999 Mdot
.33238 .46651 Mdot
.18613 .62729 Mdot
.78312 .01069 Mdot
.0223 .62134 Mdot
.06545 .62583 Mdot
.73438 .3351 Mdot
.73583 .51882 Mdot
.38105 .45568 Mdot
.93885 .03058 Mdot
.68204 .49563 Mdot
.88094 .7967 Mdot
.52988 .19679 Mdot
.93785 .20849 Mdot
.12722 .72921 Mdot
.99772 .79267 Mdot
.68036 .60418 Mdot
.48449 .45716 Mdot
.22057 .07626 Mdot
.92037 .61203 Mdot
.81212 .10272 Mdot
.51054 .1891 Mdot
.02075 .43503 Mdot
.33246 .67441 Mdot
.03949 .98396 Mdot
.38063 .5767 Mdot
.8681 .64038 Mdot
.77611 .79654 Mdot
.36354 .57133 Mdot
.98892 .2402 Mdot
.58243 .54621 Mdot
.63457 .78016 Mdot
.24524 .07924 Mdot
.49134 .41226 Mdot
.96418 .92807 Mdot
.39924 .9607 Mdot
.36632 .65971 Mdot
.6446 .21238 Mdot
.69208 .90232 Mdot
.6022 .2215 Mdot
.29804 .45765 Mdot
.88477 .70845 Mdot
.0147 .92344 Mdot
.03879 .53419 Mdot
.14927 .37629 Mdot
.97845 .59236 Mdot
.128 .8124 Mdot
.0675 .56015 Mdot
.26278 .75698 Mdot
.18021 .32802 Mdot
.15967 .62914 Mdot
.63909 .44194 Mdot
.94464 .77652 Mdot
.05294 .44159 Mdot
.20884 .96153 Mdot
.88848 .22713 Mdot
.33468 .08567 Mdot
.45503 .84012 Mdot
.16477 .72527 Mdot
.56445 .03252 Mdot
.17887 .53581 Mdot
.88139 .59614 Mdot
.51293 .88496 Mdot
.769 .94433 Mdot
.88486 .32819 Mdot
.82141 .88254 Mdot
.00582 .88265 Mdot
.56898 .24731 Mdot
.3645 .04189 Mdot
.66813 .0613 Mdot
.12004 .59974 Mdot
.80417 .60593 Mdot
.10647 .58643 Mdot
.49078 .38972 Mdot
.03348 .95756 Mdot
.31157 .46459 Mdot
.06994 .45086 Mdot
.67994 .99591 Mdot
.48838 .81941 Mdot
.19564 .1474 Mdot
.62442 .99957 Mdot
.76019 .72873 Mdot
.35247 .02291 Mdot
.13301 .10613 Mdot
.92856 .16343 Mdot
.76149 .95397 Mdot
.5579 .87331 Mdot
.36301 .75791 Mdot
.95765 .20311 Mdot
.23008 .53934 Mdot
.12765 .90249 Mdot
.13219 .50426 Mdot
.71913 .72224 Mdot
.70091 .05426 Mdot
.38134 .45877 Mdot
.00256 .76287 Mdot
.94986 .04269 Mdot
.4915 .44499 Mdot
.65515 .96028 Mdot
.8647 .00856 Mdot
.74899 .60739 Mdot
.48612 .91093 Mdot
.25664 .83748 Mdot
.6819 .92628 Mdot
.97029 .99551 Mdot
.63886 .29051 Mdot
.15331 .25138 Mdot
.17216 .91798 Mdot
.18439 .96979 Mdot
.71825 .23369 Mdot
.17382 .8861 Mdot
.61703 .15183 Mdot
.87294 .78506 Mdot
.24378 .09809 Mdot
.67476 .29037 Mdot
.95465 .86881 Mdot
.80456 .62187 Mdot
.91503 .15873 Mdot
.96061 .94227 Mdot
.48194 .6336 Mdot
.0484 .32871 Mdot
.64638 .47099 Mdot
.54562 .81985 Mdot
.95362 .26324 Mdot
.10036 .4345 Mdot
.53488 .51388 Mdot
.14608 .75093 Mdot
.03165 .92298 Mdot
.14295 .36804 Mdot
.29311 .7969 Mdot
.18301 .1032 Mdot
.91143 .05224 Mdot
.00343 .37378 Mdot
.67481 .04585 Mdot
.71991 .17426 Mdot
.62757 .37212 Mdot
.13374 .1043 Mdot
.02933 .71602 Mdot
.73282 .13689 Mdot
.27422 .63101 Mdot
.05118 .64345 Mdot
.77997 .00835 Mdot
.04089 .06229 Mdot
.39184 .31437 Mdot
.82846 .96412 Mdot
.78937 .55901 Mdot
.69504 .35694 Mdot
.30687 .15734 Mdot
.43709 .29448 Mdot
.67129 .18724 Mdot
.13714 .51261 Mdot
.83614 .47349 Mdot
.78961 .45259 Mdot
.70276 .71812 Mdot
.85887 .00606 Mdot
.02901 .81084 Mdot
.63076 .06655 Mdot
.16344 .39317 Mdot
.44075 .89147 Mdot
.27758 .67477 Mdot
.52756 .83035 Mdot
.6539 .33129 Mdot
.67734 .62041 Mdot
.19112 .11126 Mdot
.50402 .74845 Mdot
.5277 .21787 Mdot
.51697 .92245 Mdot
.3988 .77887 Mdot
.59991 .63869 Mdot
.23446 .56913 Mdot
.73001 .03723 Mdot
.30463 .92902 Mdot
.15001 .98587 Mdot
.5843 .0388 Mdot
.81462 .90407 Mdot
.76568 .71465 Mdot
.32678 .45568 Mdot
.38306 .7797 Mdot
.21573 .30922 Mdot
.90562 .14202 Mdot
.94939 .16988 Mdot
.70565 .76694 Mdot
.8583 .84719 Mdot
.61309 .9397 Mdot
.23717 .70549 Mdot
.93793 .47561 Mdot
.32537 .9227 Mdot
.48076 .71868 Mdot
.05575 .20462 Mdot
.07161 .26171 Mdot
.55973 .5229 Mdot
.81489 .86324 Mdot
.57259 .51501 Mdot
.69675 .4974 Mdot
.41604 .60671 Mdot
.6751 .50715 Mdot
.48666 .95268 Mdot
.73088 .62444 Mdot
.9642 .02493 Mdot
.79531 .78959 Mdot
.13092 .54528 Mdot
.47359 .28002 Mdot
.16184 .04238 Mdot
.14848 .3816 Mdot
.80296 .07357 Mdot
.9711 .09749 Mdot
.48746 .42199 Mdot
.58159 .01493 Mdot
.44545 .43651 Mdot
.22647 .16565 Mdot
.41651 .33285 Mdot
.61186 .58663 Mdot
.62173 .92198 Mdot
.678 .33238 Mdot
.2864 .93622 Mdot
.65393 .81493 Mdot
.82578 .48468 Mdot
.76336 .03761 Mdot
.43247 .6038 Mdot
.26749 .51228 Mdot
.32584 .07281 Mdot
.45525 .52651 Mdot
.66492 .99255 Mdot
.68639 .37845 Mdot
.70092 .44365 Mdot
.31269 .85743 Mdot
.56245 .82139 Mdot
.23159 .94042 Mdot
.68889 .74599 Mdot
.04834 .10277 Mdot
.13962 .68087 Mdot
.20116 .49813 Mdot
.83106 .57983 Mdot
.0392 .99225 Mdot
.98979 .22651 Mdot
.95386 .16038 Mdot
.69918 .28737 Mdot
.19644 .49371 Mdot
.09244 .80201 Mdot
.61894 .39847 Mdot
.14557 .58959 Mdot
.16164 .33431 Mdot
.14718 .15765 Mdot
.74134 .89727 Mdot
.45988 .02933 Mdot
.69228 .97783 Mdot
.89399 .04526 Mdot
.79977 .59364 Mdot
.36984 .56867 Mdot
.4725 .16708 Mdot
.65861 .00117 Mdot
.57507 .66113 Mdot
.61064 .03454 Mdot
.40494 .5192 Mdot
.74242 .5005 Mdot
.31489 .57326 Mdot
.0944 .41506 Mdot
.59758 .83315 Mdot
.48254 .70645 Mdot
.37546 .53304 Mdot
.51293 .86284 Mdot
.7379 .53208 Mdot
.91129 .01684 Mdot
.9302 .58072 Mdot
.41626 .89107 Mdot
.88484 .45624 Mdot
.37776 .71427 Mdot
.92979 .76388 Mdot
.10579 .68365 Mdot
.84259 .03634 Mdot
.07766 .15266 Mdot
.33305 .58641 Mdot
.08869 .97417 Mdot
.22131 .12715 Mdot
.0923 .57427 Mdot
.84218 .47168 Mdot
.87953 .61181 Mdot
.66807 .28661 Mdot
.68952 .70655 Mdot
.20073 .32105 Mdot
.35408 .52977 Mdot
.0312 .52341 Mdot
.03315 .61744 Mdot
.77154 .53443 Mdot
.392 .87836 Mdot
.98442 .65506 Mdot
.89509 .82592 Mdot
.28579 .50865 Mdot
.2164 .00429 Mdot
.80519 .82844 Mdot
.07814 .84342 Mdot
.17651 .82497 Mdot
.69617 .51833 Mdot
.45371 .13607 Mdot
.19585 .23671 Mdot
.78104 .93794 Mdot
.31168 .46088 Mdot
.46372 .00079 Mdot
.0962 .50479 Mdot
.94008 .49567 Mdot
.83623 .74614 Mdot
.26976 .15246 Mdot
.69658 .08008 Mdot
.52735 .38567 Mdot
.778 .93896 Mdot
.54696 .07381 Mdot
.43597 .84245 Mdot
.08926 .66445 Mdot
.37833 .65201 Mdot
.0096 .04591 Mdot
.65297 .51749 Mdot
.64016 .12473 Mdot
.13391 .86336 Mdot
.79689 .50141 Mdot
.75253 .47345 Mdot
.91365 .26645 Mdot
.35568 .04951 Mdot
.55947 .88077 Mdot
.79327 .51909 Mdot
.03127 .78494 Mdot
.73273 .0151 Mdot
.38829 .69585 Mdot
.05577 .40912 Mdot
.61113 .89873 Mdot
.62847 .62509 Mdot
.60612 .49774 Mdot
.36917 .10347 Mdot
.38944 .65525 Mdot
.8052 .18069 Mdot
.68326 .28136 Mdot
.38801 .75808 Mdot
.79184 .31828 Mdot
.1596 .60023 Mdot
.50152 .59872 Mdot
.21789 .05514 Mdot
.64432 .50845 Mdot
.4768 .51164 Mdot
.81321 .987 Mdot
.12519 .67167 Mdot
.71558 .47764 Mdot
.33842 .14751 Mdot
.04256 .71367 Mdot
.45221 .17464 Mdot
.79925 .60237 Mdot
.67954 .70858 Mdot
.27543 .05632 Mdot
.85696 .03906 Mdot
.44145 .36757 Mdot
.2653 .45327 Mdot
.5973 .16202 Mdot
.21825 .77256 Mdot
.44998 .35884 Mdot
.48549 .64351 Mdot
.79695 .69133 Mdot
.66616 .01085 Mdot
.83527 .462 Mdot
.00223 .95717 Mdot
.36527 .47134 Mdot
.13642 .17384 Mdot
.17996 .25227 Mdot
.09607 .42128 Mdot
.97802 .47461 Mdot
.64558 .7946 Mdot
.7079 .3719 Mdot
.84557 .64644 Mdot
.13573 .43193 Mdot
.47539 .38103 Mdot
.50499 .08736 Mdot
.85305 .38718 Mdot
.4906 .51915 Mdot
.16588 .51139 Mdot
.46387 .04601 Mdot
.21403 .48289 Mdot
.4203 .57878 Mdot
.98712 .13706 Mdot
.85959 .54098 Mdot
.71656 .71799 Mdot
.57513 .11267 Mdot
.28967 .40871 Mdot
.27436 .93025 Mdot
.95706 .48521 Mdot
.11133 .65445 Mdot
.99071 .08065 Mdot
.52213 .06519 Mdot
.03272 .87009 Mdot
.70183 .41924 Mdot
.85872 .23807 Mdot
.27695 .28512 Mdot
.41113 .60848 Mdot
.31709 .89438 Mdot
.75782 .47567 Mdot
.74432 .36625 Mdot
.04241 .9033 Mdot
.84871 .60415 Mdot
.72801 .70226 Mdot
.43001 .32682 Mdot
.08844 .16045 Mdot
.78472 .12471 Mdot
.4254 .0916 Mdot
.30078 .30484 Mdot
.6525 .70538 Mdot
.55361 .2312 Mdot
.23357 .86374 Mdot
.04106 .2732 Mdot
.42221 .13537 Mdot
.97743 .73313 Mdot
.28498 .8466 Mdot
.77026 .49598 Mdot
.28082 .30225 Mdot
.26152 .59568 Mdot
.73303 .75406 Mdot
.05516 .3886 Mdot
.36341 .32992 Mdot
.84774 .30842 Mdot
.46556 .92274 Mdot
.01629 .51472 Mdot
.52786 .12062 Mdot
.96268 .15431 Mdot
.13044 .9516 Mdot
.08892 .75722 Mdot
.81488 .3884 Mdot
.57043 .75544 Mdot
.82861 .39444 Mdot
.72743 .36295 Mdot
.11297 .54336 Mdot
.97316 .83769 Mdot
.65212 .97924 Mdot
.42214 .73307 Mdot
.33899 .18176 Mdot
.70712 .98633 Mdot
.19325 .82642 Mdot
.95958 .94568 Mdot
.36506 .94684 Mdot
.68436 .73102 Mdot
.3795 .04001 Mdot
.18826 .21289 Mdot
.68959 .26703 Mdot
.51156 .25464 Mdot
.65827 .63635 Mdot
.13876 .82987 Mdot
.15051 .83875 Mdot
.61609 .23716 Mdot
.02797 .61211 Mdot
.97191 .10893 Mdot
.98442 .55932 Mdot
.47676 .82377 Mdot
.90476 .70018 Mdot
.59443 .3027 Mdot
.48328 .32189 Mdot
.8474 .28111 Mdot
.74101 .94428 Mdot
.9603 .30469 Mdot
.84458 .56167 Mdot
.25728 .14058 Mdot
.51484 .10375 Mdot
.89789 .30522 Mdot
.11268 .16783 Mdot
.32207 .95172 Mdot
.76601 .10731 Mdot
.99107 .40658 Mdot
.16601 .3424 Mdot
.95357 .37415 Mdot
.07773 .40604 Mdot
.42338 .33235 Mdot
.67269 .49662 Mdot
.78375 .0899 Mdot
.97928 .92491 Mdot
.33224 .92233 Mdot
.20426 .06151 Mdot
.17871 .31876 Mdot
.57937 .88402 Mdot
.9294 .96088 Mdot
.43289 .31161 Mdot
.64243 .01314 Mdot
.78292 .37007 Mdot
.90817 .2867 Mdot
.06532 .54871 Mdot
.8079 .94501 Mdot
.49646 .9418 Mdot
.83402 .02467 Mdot
.47885 .4769 Mdot
.21334 .03976 Mdot
.68991 .08476 Mdot
.07886 .33972 Mdot
.15893 .12818 Mdot
.44112 .40075 Mdot
.30081 .52238 Mdot
.33515 .526 Mdot
.92862 .28885 Mdot
.4295 .0481 Mdot
.96647 .47527 Mdot
.81272 .18291 Mdot
.32165 .76833 Mdot
.69434 .03748 Mdot
.48519 .24287 Mdot
.74893 .45175 Mdot
.84748 .45817 Mdot
.16997 .45448 Mdot
.52623 .14429 Mdot
.07929 .60945 Mdot
.72512 .84207 Mdot
.62269 .46309 Mdot
.06076 .52316 Mdot
.65752 .15332 Mdot
.82791 .42429 Mdot
.95754 .33994 Mdot
.31205 .52449 Mdot
.30035 .27806 Mdot
.96708 .3865 Mdot
.20019 .19265 Mdot
.30089 .22166 Mdot
.57187 .92787 Mdot
.19115 .22254 Mdot
.51418 .33272 Mdot
.92745 .13812 Mdot
.7412 .63201 Mdot
.90457 .57549 Mdot
.91771 .80088 Mdot
.7666 .74208 Mdot
.73162 .87664 Mdot
.16612 .70575 Mdot
.64905 .07498 Mdot
.67335 .46125 Mdot
.12603 .82459 Mdot
.05537 .96691 Mdot
.03027 .98245 Mdot
.34308 .34726 Mdot
.63076 .14263 Mdot
.70499 .554 Mdot
.87711 .17216 Mdot
.37197 .51398 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00Co0000oooooooooooooooo0_l0000:ooooo`03o`000?oooooooooo00_ooooo0ol0000?oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool01?l0003oooooooooooooool2
o`0000[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00gooooo00Co0000ooooool0003o00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0>ooooo`04o`000?ooooooooooooooo`;o00002_ooool00ol0003ooooooooo
o`0;ooooo`?o00003oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`04o`000?oooooo0000o`0000cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo
000Nooooo`03o`000?oooooooooo0?Wooooo0_l0000Hooooo`Co0000<?ooool001kooooo00?o0000
ooooooooool0cOooool2o`0000Gooooo0_l0000Sooooo`?o00006Oooool2o`00033ooooo000Noooo
o`03o`000?oooooooooo0;Wooooo0_l0000Booooo`;o00001Oooool2o`0001Cooooo0_l0000>oooo
o`;o0000Boooool001kooooo0ol0002iooooo`;o0000;oooool2o`0003Sooooo0_l0000Qooooo`00
7_ooool3o`0006kooooo0_l0002dooooo`;o00008Oooool001kooooo00?o0000ooooooooool0K_oo
ool2o`0007Wooooo0_l0000Pooooo`;o0000:?ooool2o`00013ooooo000Nooooo`03o`000?oooooo
oooo037ooooo0_l0002fooooo`;o00008?ooool2o`0002Sooooo0_l0000@ooooo`007_ooool00ol0
003oooooooooo`0aooooo`;o0000G_ooool2o`0006Sooooo0_l0000Jooooo`;o00005?ooool2o`00
01Sooooo000Nooooo`03o`000?oooooooooo04_ooooo0_l00014ooooo`;o00008?ooool2o`0000go
oooo0_l0000gooooo`;o00006_ooool2o`0000_ooooo0_l00007ooooo`;o00006?ooool001kooooo
00?o0000ooooooooool0Boooool3o`000003ooooool0003o000006;ooooo0_l0000=ooooo`;o0000
6_ooool2o`0000Wooooo0_l00009ooooo`;o00006?ooool2o`0001Cooooo0_l0000Qooooo`007_oo
ool00ol0003oooooooooo`11ooooo`;o00002Oooool2o`000003ooooool0003o0000027ooooo0_l0
0003ooooo`;o0000@Oooool2o`0002;ooooo0_l00009ooooo`;o00002Oooool2o`0001Sooooo0_l0
0002ooooo`;o0000<oooool001kooooo00?o0000ooooooooool0<?ooool2o`0000oooooo0_l0000A
ooooo`;o00007?ooool2o`0000?ooooo0_l00011ooooo`;o0000:oooool2o`0002Wooooo0_l0000M
ooooo`;o00005?ooool001kooooo1?l0000_ooooo`;o00008_ooool2o`0001cooooo0_l0000Ooooo
o`;o0000@_ooool2o`0000kooooo0_l0000Fooooo`;o00007_ooool2o`00013ooooo0_l0000Doooo
o`007_ooool4o`0006oooooo0_l0000Fooooo`;o00002Oooool2o`0004;ooooo0_l0000Vooooo`;o
00004Oooool2o`0000_ooooo0_l0000?ooooo`;o00005Oooool001kooooo0_l0000Iooooo`;o0000
E_ooool2o`0000cooooo0_l00008ooooo`;o00003?ooool2o`0007[ooooo0_l0000@ooooo`;o0000
2_ooool2o`0001Gooooo000Nooooo`03o`000?oooooooooo01Sooooo0_l0000Vooooo`;o000000?o
ooooo`000?l000004?ooool2o`0002Oooooo0_l0000Fooooo`;o0000B?ooool2o`0004;ooooo0_l0
000Qooooo`007_ooool00ol0003oooooooooo`10ooooo`;o000000?oooooo`000?l000004?ooool3
o`0008Sooooo0_l0001Uooooo`007_ooool00ol0003oooooooooo`09ooooo`;o0000<oooool2o`00
01Kooooo0_l0001mooooo`;o0000L?ooool001kooooo00?o0000ooooooooool02Oooool2o`0003?o
oooo0_l0001Vooooo`;o0000;Oooool2o`00073ooooo000Nooooo`03o`000?oooooooooo06?ooooo
0_l0000;ooooo`;o0000=?ooool2o`00027ooooo0_l0001Fooooo`;o00009?ooool001kooooo00?o
0000ooooooooool0C_ooool2o`0001?ooooo0_l0000;ooooo`;o0000Eoooool2o`0000Cooooo0_l0
001@ooooo`;o00009?ooool001kooooo00?o0000ooooooooool0C_ooool2o`0001Kooooo0_l00016
ooooo`;o00007oooool2o`00033ooooo0_l00014ooooo`007_ooool00ol0003oooooooooo`14oooo
o`;o00008?ooool2o`0004Kooooo0_l0000Booooo`;o00002oooool2o`0000Wooooo0_l0000Uoooo
o`;o0000A?ooool001kooooo00?o0000ooooooooool0A?ooool2o`0000Kooooo0_l00003ooooo`;o
0000Koooool2o`0001?ooooo0_l000000ooooooo0000o`000002ooooo`;o00003_ooool2o`0004ko
oooo0_l00007ooooo`007_ooool00ol0003oooooooooo`1<ooooo`;o00000oooool2o`0008Cooooo
0_l00005ooooo`;o00003_ooool2o`0004Kooooo0_l00006ooooo`;o00001oooool001kooooo00?o
0000ooooooooool0JOooool2o`0003Gooooo0_l0000jooooo`;o0000F?ooool2o`0000oooooo000N
ooooo`03o`000?oooooooooo06Wooooo0_l0000eooooo`;o0000>_ooool2o`0001gooooo0_l0001:
ooooo`007_ooool00ol0003oooooooooo`26ooooo`;o00004Oooool2o`00063ooooo0_l0001:oooo
o`007_ooool00ol0003oooooooooo`1Kooooo`;o0000:Oooool2o`00017ooooo0_l0000Looooo`;o
0000?Oooool2o`0004oooooo000Nooooo`03o`000?oooooooooo04_ooooo0_l0000>ooooo`;o0000
F_ooool2o`0003gooooo0_l00010ooooo`;o00003Oooool001kooooo0_l0000=ooooo`;o0000?Ooo
ool2o`000;Oooooo0_l0000booooo`;o00003Oooool001kooooo00?o0000ooooooooool03?ooool2
o`0001Wooooo0_l0000>ooooo`;o0000>oooool2o`0002gooooo0_l0001Oooooo`;o0000@Oooool0
01kooooo00?o0000ooooooooool05?ooool2o`00017ooooo0_l0000>ooooo`;o0000>oooool2o`00
02gooooo0_l0001@ooooo`;o0000@Oooool2o`0000gooooo000Nooooo`03o`000?oooooooooo01Co
oooo0_l0000Aooooo`;o00004Oooool2o`0001Kooooo0_l0002Qooooo`;o0000@Oooool2o`0000go
oooo000Nooooo`03o`000?oooooooooo03[ooooo0_l0000Fooooo`;o0000Hoooool2o`0008kooooo
000Nooooo`03o`000?oooooooooo0;?ooooo0_l00002ooooo`;o0000F_ooool2o`0003;ooooo000N
ooooo`03o`000?oooooooooo0:Oooooo0_l0000:ooooo`;o0000G_ooool2o`0003;ooooo000Noooo
o`03o`000?oooooooooo04Wooooo0_l0001Looooo`;o0000TOooool2o`0000_ooooo000Nooooo`03
o`000?oooooooooo02Oooooo0_l0000Kooooo`;o00000oooool2o`00087ooooo0_l0000]ooooo`;o
0000?Oooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo02Oooooo0_l000000ooooooo0000
o`000004ooooo`;o00004_ooool2o`0004Oooooo0_l0000mooooo`;o0000;Oooool2o`0001?ooooo
0_l0000eooooo`007_ooool00ol0003oooooooooo`0Zooooo`;o00001?ooool2o`0000Gooooo0_l0
001Dooooo`;o0000POooool2o`0003Gooooo000Nooooo`03o`000?oooooooooo03Oooooo0_l0001<
ooooo`;o00002?ooool2o`0000Gooooo0_l0001Rooooo`;o0000?_ooool2o`0000_ooooo000Noooo
o`03o`000?oooooooooo08Gooooo0_l00008ooooo`;o00001Oooool2o`00047ooooo0_l0000?oooo
o`;o00003_ooool2o`0002gooooo0_l0000?ooooo`;o000000?oooooo`000?l000002?ooool001ko
oooo00?o0000ooooooooool05Oooool2o`0003Wooooo0_l0001gooooo`;o00003_ooool2o`0000oo
oooo0_l0000fooooo`;o00001Oooool2o`0001;ooooo0_l00008ooooo`007_ooool00ol0003ooooo
ooooo`0Eooooo`;o0000>Oooool2o`0005Gooooo0_l0000Pooooo`;o0000Eoooool2o`0002?ooooo
000Nooooo`03o`000?oooooooooo03_ooooo0_l0000]ooooo`;o0000>oooool2o`0009kooooo000N
ooooo`;o0000??ooool2o`0002gooooo0_l0000Mooooo`;o0000>Oooool2o`00087ooooo000Noooo
o`03o`000?oooooooooo01Gooooo0_l0000mooooo`;o0000<oooool2o`0003Wooooo0_l0000<oooo
o`;o0000>_ooool2o`0002Gooooo0_l0000@ooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o
00005Oooool2o`0002Kooooo0_l0000:ooooo`;o0000L?ooool2o`0003[ooooo0_l0000Kooooo`;o
00002?ooool2o`00013ooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l0000Aooooo`;o0000
<_ooool2o`000;Gooooo0_l0000<ooooo`;o00001?ooool2o`0000Gooooo0_l0000Cooooo`007_oo
ool00ol0003oooooooooo`0Gooooo`Co0000Xoooool2o`0005Oooooo0_l0000<ooooo`;o00000ooo
ool2o`0000Kooooo0_l0000Cooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o0000;Oooool2
o`0004gooooo0_l0000Wooooo`;o0000J_ooool2o`0001;ooooo1?l00005ooooo`007_ooool00ol0
003oooooooooo`0Qooooo`;o00008oooool2o`0004gooooo0_l0002Jooooo`;o00002oooool4o`00
00Gooooo000Nooooo`03o`000?oooooooooo027ooooo0_l0000iooooo`;o00001_ooool2o`000;?o
oooo0_l0000Fooooo`;o00005?ooool001kooooo00?o0000ooooooooool0:?ooool2o`0000Sooooo
0_l0000Xooooo`;o00001_ooool2o`0002Wooooo0_l0001Eooooo`;o0000<Oooool2o`0002cooooo
000Nooooo`03o`000?oooooooooo02Sooooo0_l00008ooooo`;o0000F_ooool3o`0005Gooooo0_l0
000dooooo`;o0000:Oooool001kooooo00?o0000ooooooooool06_ooool2o`0004[ooooo0_l00002
ooooo`;o00008_ooool2o`0000Gooooo0_l0000Yooooo`;o0000@?ooool2o`0001Gooooo0_l00000
0ooooooo0000o`00000Yooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o0000B_ooool2o`00
00;ooooo0_l0000Yooooo`;o0000:Oooool2o`0002_ooooo0_l0000Cooooo`Co00004oooool2o`00
02cooooo000Nooooo`03o`000?oooooooooo0=Kooooo0_l0000Eooooo`;o00005Oooool2o`0000Go
oooo0_l0000jooooo`007_ooool00ol0003oooooooooo`2Rooooo`;o0000<_ooool2o`0003?ooooo
0_l0000jooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000
1_ooool00ol0003oooooooooo`0mooooo`;o0000Hoooool2o`0000Sooooo0_l0000Kooooo`;o0000
>oooool2o`0003oooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo
00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo03gooooo0_l0000jooooo`;o
0000;Oooool2o`0000;ooooo0_l0000Kooooo`;o0000>oooool2o`0003oooooo0003ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`?o0000NOooool2o`0002go
oooo0_l0001Hooooo`;o0000@oooool000?ooooo00Go0000ooooooooooooooooo`00000=ooooo`03
oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0EOooool2o`0001gooooo0_l0002<ooooo`;o
0000;oooool2o`0001;ooooo0003ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOo
IVIVooooo`05ooooo`03o`000?oooooooooo00kooooo0_l00015ooooo`;o00007Oooool2o`0001Oo
oooo0_l0000Dooooo`;o0000<_ooool2o`0005[ooooo0_l0000Booooo`000oooool01Ol@413ooooo
oooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0>ooooo`;o
00005_ooool2o`0001Oooooo0_l0001<ooooo`;o00005?ooool2o`0003;ooooo0_l0001Dooooo`;o
00006?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRH
V?l@41001_ooool00ol0003oooooooooo`0Qooooo`;o00000oooool2o`00017ooooo0_l00004oooo
o`;o0000S?ooool2o`0005kooooo0_l0000Hooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo027ooooo0_l0000F
ooooo`;o0000KOooool2o`0002?ooooo0_l0000iooooo`;o00000_ooool2o`0003Wooooo000Noooo
o`03o`000?oooooooooo04Oooooo0_l0001Nooooo`?o0000G_ooool2o`0000;ooooo0_l0000ioooo
o`007_ooool00ol0003oooooooooo`0jooooo`;o00002oooool2o`0001Gooooo0_l00017ooooo`;o
00002_ooool2o`0000_ooooo0_l0000;ooooo`;o0000A?ooool2o`0003;ooooo000Nooooo`03o`00
0?oooooooooo03[ooooo0_l0000Rooooo`;o0000@?ooool2o`00017ooooo0ol00002ooooo`;o0000
1_ooool2o`0000_ooooo0_l00005ooooo`;o0000?Oooool2o`0003;ooooo000Nooooo`03o`000?oo
oooooooo0:3ooooo0_l0000Booooo`;o00000_ooool2o`0000[ooooo0ol00002ooooo`;o00002Ooo
ool2o`0004Oooooo0_l0000Oooooo`;o00001oooool001kooooo00?o0000ooooooooool0/?ooool2
o`0001;ooooo0ol00002ooooo`;o0000;_ooool2o`0002;ooooo0_l0000Oooooo`;o00001oooool0
01kooooo00?o0000ooooooooool0/?ooool2o`0003?ooooo0_l0000Booooo`;o0000C?ooool001ko
oooo00?o0000ooooooooool09?ooool2o`0001Kooooo0_l0000Dooooo`;o0000L?ooool2o`0001oo
oooo0_l00002ooooo`;o0000:?ooool2o`0003;ooooo000Nooooo`03o`000?oooooooooo02Cooooo
0_l0000Fooooo`;o00005?ooool2o`00073ooooo0_l0000Sooooo`;o0000:?ooool2o`0002Sooooo
0_l00008ooooo`007_ooool00ol0003oooooooooo`2Jooooo`;o00006_ooool2o`0008Gooooo0_l0
0008ooooo`007_ooool00ol0003oooooooooo`2Jooooo`;o00006Oooool3o`0008oooooo000Noooo
o`03o`000?oooooooooo02cooooo0_l0001Tooooo`Co00007oooool2o`00093ooooo000Nooooo`;o
00009_ooool2o`0000Gooooo1?l00006ooooo`;o0000F_ooool4o`000;7ooooo000Nooooo`03o`00
0?oooooooooo02Gooooo0_l00007ooooo`;o00001_ooool2o`0006[ooooo0_l0001Zooooo`;o0000
4oooool2o`0002;ooooo000Nooooo`03o`000?oooooooooo0:;ooooo0_l0001Zooooo`;o00004_oo
ool3o`0002;ooooo000Nooooo`04o`000?oooooo0000o`0001;ooooo0_l00014ooooo`;o0000aooo
ool2o`0002?ooooo000Nooooo`04o`000?oooooo0000o`0001;ooooo0_l00014ooooo`;o0000]ooo
ool2o`0001kooooo0_l0000Cooooo`007_ooool00ol0003oooooooooo`0^ooooo`;o0000[?ooool2
o`0003Cooooo0_l0000Aooooo`;o00002oooool2o`0001?ooooo000Nooooo`03o`000?oooooooooo
02gooooo0ol0002/ooooo`;o0000Aoooool2o`00023ooooo000Nooooo`03o`000?oooooooooo00Wo
oooo0_l0000Rooooo`;o0000Loooool2o`00083ooooo0_l0000Qooooo`007_ooool00ol0003ooooo
ooooo`09ooooo`;o0000Doooool2o`00047ooooo0ol0000]ooooo`;o0000?_ooool2o`00017ooooo
0_l0000Qooooo`007_ooool00ol0003oooooooooo`1Nooooo`;o0000<Oooool2o`0000?ooooo0_l0
0009ooooo`;o0000;_ooool2o`0003cooooo1?l0000dooooo`007_ooool00ol0003oooooooooo`2A
ooooo`;o00000oooool2o`0004;ooooo0_l0000cooooo`;o0000=_ooool001kooooo00?o0000oooo
ooooool0E_ooool2o`0007gooooo0_l00003ooooo`;o00000oooool2o`0004;ooooo0_l0000Roooo
o`007_ooool00ol0003oooooooooo`1Fooooo`;o0000M?ooool2o`0000Oooooo1?l00006ooooo`;o
0000@_ooool2o`0000Gooooo0_l0000Kooooo`007_ooool00ol0003oooooooooo`3<ooooo`;o0000
2Oooool2o`0000oooooo0_l0000/ooooo`;o00004_ooool2o`0001_ooooo000Nooooo`03o`000?oo
oooooooo08[ooooo0_l0001Looooo`;o0000;?ooool2o`0002oooooo000Nooooo`03o`000?oooooo
oooo00[ooooo0_l0001^ooooo`;o00003_ooool2o`0002cooooo0_l0002=ooooo`007_ooool2o`00
00_ooooo0_l0001;ooooo`;o00008Oooool2o`0003cooooo0_l00003ooooo`?o00003oooool2o`00
07Kooooo000Nooooo`03o`000?oooooooooo05Oooooo0_l00005ooooo`;o0000E?ooool2o`0000Oo
oooo0ol0000?ooooo`;o0000<oooool2o`0001[ooooo0_l0000Booooo`;o00004Oooool001kooooo
00?o0000ooooooooool0G_ooool2o`0005Cooooo0_l0001>ooooo`;o00002Oooool2o`0000oooooo
0_l0000Booooo`;o00004Oooool001kooooo00?o0000ooooooooool0@_ooool2o`0004Gooooo0_l0
000Qooooo`;o0000HOooool2o`0003Kooooo000Nooooo`03o`000?oooooooooo03Kooooo0_l0000:
ooooo`;o0000=oooool2o`0000cooooo0_l00002ooooo`;o00004?ooool2o`0000_ooooo0_l0002I
ooooo`007_ooool01?l0003oooooooooooooool2o`0003?ooooo0_l00013ooooo`;o00004?ooool2
o`00013ooooo0_l0002Vooooo`007_ooool01?l0003oooooooooooooool2o`0003?ooooo0_l00005
ooooo`;o0000__ooool2o`0004Sooooo000Nooooo`03o`000?oooooooooo02oooooo0_l00005oooo
o`;o00001Oooool2o`0005[ooooo0_l0001Rooooo`;o0000B?ooool001kooooo00?o0000oooooooo
ool0;oooool2o`00053ooooo0_l00005ooooo`;o00003oooool2o`0006Wooooo0_l00011ooooo`00
7_ooool00ol0003oooooooooo`0<ooooo`;o0000:?ooool2o`0003[ooooo0_l0000=ooooo`;o0000
1Oooool2o`0006gooooo0_l0000;ooooo`;o00005_ooool2o`0002Wooooo000Nooooo`03o`000?oo
oooooooo00cooooo0_l0000Xooooo`;o0000>_ooool2o`0000oooooo0_l000000ooooooo0000o`00
000Kooooo`;o0000:oooool2o`0000Kooooo0_l0000Mooooo`;o00008oooool2o`0002Wooooo000N
ooooo`03o`000?oooooooooo033ooooo0_l0000iooooo`;o00005_ooool2o`000003ooooool0003o
000001_ooooo0_l0000[ooooo`;o00001_ooool2o`00017ooooo0_l0001Jooooo`007_ooool00ol0
003oooooooooo`0Fooooo`;o00006?ooool2o`0002[ooooo0_l0000=ooooo`;o0000B_ooool2o`00
03;ooooo0_l0000Sooooo`;o0000=Oooool001kooooo00?o0000ooooooooool05_ooool2o`0001[o
oooo0_l0000Xooooo`;o00008_ooool2o`0001[ooooo0_l0000<ooooo`;o00002oooool2o`0005Oo
oooo0_l0000Qooooo`;o00004_ooool001kooooo00?o0000ooooooooool0<_ooool2o`0004cooooo
0_l00007ooooo`;o00004Oooool2o`0000cooooo0_l0000>ooooo`;o0000Koooool2o`0000Kooooo
0_l0000Booooo`007_ooool00ol0003oooooooooo`1[ooooo`;o00007?ooool2o`0002oooooo0_l0
001_ooooo`;o00006_ooool001kooooo0_l0001/ooooo`;o00005_ooool2o`000<;ooooo000Noooo
o`;o0000P_ooool4o`000<;ooooo000Nooooo`;o0000P_ooool2o`0002_ooooo0_l0000^ooooo`;o
0000Ioooool001kooooo00?o0000ooooooooool0S_ooool2o`0001kooooo0_l0000^ooooo`;o0000
:Oooool2o`0003?ooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`1Booooo`;o00008_oo
ool2o`0001Kooooo0_l0001Hooooo`;o00007oooool2o`0003?ooooo0_l00007ooooo`007_ooool0
0ol0003oooooooooo`1Booooo`;o00008_ooool2o`00073ooooo0_l00004ooooo`;o0000Eoooool0
01kooooo00?o0000ooooooooool0:_ooool2o`0001Kooooo0_l00017ooooo`;o0000A_ooool2o`00
01Wooooo0_l0000:ooooo`;o0000Boooool001kooooo00?o0000ooooooooool04_ooool2o`0001Ko
oooo0_l0000Fooooo`;o00004oooool2o`0003;ooooo0_l0000Aooooo`;o0000:?ooool2o`0000Wo
oooo0_l0000=ooooo`;o00005_ooool2o`0004_ooooo000Nooooo`;o00004oooool2o`0001Sooooo
0_l0000Yooooo`;o0000AOooool2o`0002Sooooo0_l0000Hooooo`;o0000;_ooool2o`0001kooooo
0_l0000Cooooo`007_ooool2o`0002gooooo0_l0002]ooooo`;o00007_ooool2o`0001Gooooo0_l0
000Nooooo`;o00004oooool001kooooo00?o0000ooooooooool0;?ooool2o`0001;ooooo0_l0001D
ooooo`;o0000@oooool2o`0001kooooo0_l0000_ooooo`?o00006?ooool001kooooo00?o0000oooo
ooooool0;?ooool2o`0001;ooooo0_l0001Dooooo`;o00003oooool2o`0008?ooooo0ol0000Hoooo
o`007_ooool00ol0003oooooooooo`0>ooooo`;o0000HOooool2o`0003;ooooo1?l0001Looooo`;o
00002_ooool2o`0002?ooooo0_l0000?ooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o0000
F_ooool2o`0000Gooooo0_l0000Xooooo`;o00002?ooool2o`0005kooooo0_l0000:ooooo`;o0000
8oooool2o`0000oooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo
0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo037ooooo0_l0000gooooo`;o0000
;oooool2o`0006cooooo0_l0000looooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<Oooool2o`000=Kooooo
0_l0000looooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`?o0000
>oooool2o`0004kooooo0_l0000hooooo`;o0000P?ooool000?ooooo00Go0000oooooooooooooooo
o`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0>oooool2o`0004ko
oooo0_l0000hooooo`;o0000>oooool2o`0004?ooooo0003ooooo`05o`000?ooooooooooooooool0
00002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo00kooooo0_l00005oooo
o`;o0000=_ooool2o`000;?ooooo0_l0000jooooo`;o00001oooool000?ooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool03_ooool2o`00
00Gooooo0_l0000fooooo`;o00002oooool2o`000<Oooooo0_l0000Iooooo`;o00001oooool000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000oooo
ooooool03_ooool2o`0004[ooooo0_l0000Uooooo`;o00006Oooool2o`0008Gooooo0_l0000Roooo
o`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0
003oooooooooo`0@ooooo`;o00002Oooool2o`0004Oooooo0_l0000Kooooo`;o00006Oooool2o`00
05_ooooo0_l0000@ooooo`;o0000>_ooool001kooooo00?o0000ooooooooool04?ooool2o`0000Wo
oooo0_l00017ooooo`;o0000N_ooool2o`0001Oooooo0_l0000@ooooo`;o0000>_ooool001kooooo
00?o0000ooooooooool06oooool2o`0007gooooo0_l00014ooooo`;o00008Oooool2o`0004;ooooo
000Nooooo`03o`000?oooooooooo00_ooooo0ol0000:ooooo`;o000000?oooooo`000?l00000B_oo
ool2o`00037ooooo0_l0001Wooooo`;o00001?ooool2o`0003cooooo000Nooooo`03o`000?oooooo
oooo00_ooooo0ol0000:ooooo`;o0000COooool2o`0005_ooooo0_l00013ooooo`;o0000??ooool0
01kooooo00?o0000ooooooooool0:?ooool2o`0002;ooooo0_l0001fooooo`;o0000POooool001ko
oooo00?o0000ooooooooool00oooool2o`0001Sooooo0_l00009ooooo`;o00008_ooool2o`000?Wo
oooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0000Hooooo`;o0000I?ooool2o`0000Sooooo
0_l0002hooooo`007_ooool00ol0003oooooooooo`23ooooo`;o00002?ooool2o`000;Sooooo000N
ooooo`?o00003Oooool2o`0001oooooo0_l0001Booooo`;o0000B?ooool2o`0001;ooooo0_l0001U
ooooo`007_ooool3o`0000gooooo0_l0000Oooooo`;o0000AOooool2o`0000_ooooo0_l0000Hoooo
o`;o0000;_ooool2o`0001;ooooo0_l0001Uooooo`007_ooool00ol0003oooooooooo`1eooooo`;o
00009Oooool2o`000:Wooooo000Nooooo`;o00005?ooool2o`0003gooooo0_l0000dooooo`;o0000
4Oooool2o`0005;ooooo0_l0000<ooooo`;o0000B?ooool001kooooo00?o0000ooooooooool04ooo
ool2o`0001kooooo0_l0000Mooooo`;o00004_ooool2o`00013ooooo0_l0000>ooooo`;o00004Ooo
ool2o`0004gooooo0_l00003ooooo`;o00001_ooool2o`0000Cooooo0_l0000Mooooo`;o0000:Ooo
ool001kooooo00?o0000ooooooooool01?ooool2o`0002gooooo0_l0000Xooooo`;o00001oooool2
o`0000[ooooo0_l00004ooooo`;o00005oooool2o`0000Kooooo0_l0001?ooooo`;o00002oooool2
o`00013ooooo0_l00004ooooo`;o00002oooool2o`0002Wooooo000Nooooo`03o`000?oooooooooo
00Cooooo0_l0001Gooooo`;o00000_ooool2o`0000oooooo0_l00004ooooo`;o00005oooool2o`00
00Kooooo1?l0000jooooo`;o00004Oooool2o`000003ooooool0003o000001[ooooo1?l00002oooo
o`Co0000=?ooool001kooooo00?o0000ooooooooool04oooool2o`0004cooooo0_l0000hooooo`;o
0000:Oooool2o`0000oooooo0_l0000Aooooo`;o000000?oooooo`000?l000007?ooool2o`0000Co
oooo0_l0000dooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o0000C?ooool2o`0000Gooooo
0_l0001Looooo`;o0000Ooooool001kooooo00?o0000ooooooooool0J?ooool2o`0000Wooooo0_l0
000jooooo`;o00007Oooool2o`0003kooooo0_l0000gooooo`007_ooool00ol0003oooooooooo`1c
ooooo`;o0000>_ooool2o`0001gooooo0_l0000Qooooo`;o00006Oooool4o`0000Kooooo0_l0000R
ooooo`;o000000?oooooo`000?l000002?ooool001kooooo00?o0000ooooooooool0V?ooool2o`00
01Gooooo0_l0000dooooo`;o00002_ooool3o`0001Sooooo0_l00008ooooo`;o00005Oooool2o`00
00Oooooo0_l00002ooooo`;o000000?oooooo`000?l000002?ooool001kooooo00?o0000oooooooo
ool0V?ooool2o`0004_ooooo0_l0000;ooooo`;o00000oooool2o`0003Cooooo0_l00007ooooo`;o
00003oooool001kooooo00?o0000ooooooooool0@Oooool2o`0000gooooo0_l0002>ooooo`;o0000
5Oooool2o`0004kooooo000Nooooo`03o`000?oooooooooo047ooooo0_l0000=ooooo`;o0000S_oo
ool2o`0000gooooo0_l0000Gooooo`;o0000:Oooool2o`0001;ooooo000Nooooo`03o`000?oooooo
oooo09;ooooo0_l0000Booooo`;o00009_ooool2o`0001oooooo0_l0000Gooooo`;o0000:Oooool2
o`0001;ooooo000Nooooo`03o`000?oooooooooo09;ooooo0_l0000Booooo`;o00009_ooool2o`00
07Oooooo000Nooooo`03o`000?oooooooooo03cooooo0_l0000Wooooo`;o0000EOooool2o`00017o
oooo0_l00006ooooo`;o000000?oooooo`000?l000006_ooool2o`0003Kooooo0_l0000Gooooo`00
7_ooool00ol0003oooooooooo`0looooo`?o00009_ooool2o`0005Gooooo0_l00003ooooo`;o0000
3?ooool2o`0000Kooooo0_l000000ooooooo0000o`000002ooooo`;o00005_ooool2o`0003Kooooo
0_l0000Gooooo`007_ooool2o`0003kooooo0_l00022ooooo`;o00006oooool2o`0000gooooo0_l0
000@ooooo`;o0000;Oooool2o`0001Oooooo000Nooooo`03o`000?oooooooooo01_ooooo0_l0000:
ooooo`;o0000a?ooool2o`00013ooooo0_l00016ooooo`007_ooool00ol0003oooooooooo`0Koooo
o`Co00002?ooool2o`00033ooooo0_l0001booooo`;o00002?ooool2o`0006kooooo000Nooooo`03
o`000?oooooooooo01gooooo0_l0000Cooooo`;o00009Oooool2o`0003cooooo0_l0000dooooo`;o
00002?ooool2o`0006kooooo000Mooooo`;o00000oooool2o`0002Gooooo0_l00008ooooo`;o0000
7oooool2o`00023ooooo0_l0000Pooooo`;o00004Oooool2o`0000[ooooo0_l0000=ooooo`;o0000
P?ooool001gooooo0_l00003ooooo`;o00009Oooool2o`0002Wooooo0_l0000Looooo`;o00000_oo
ool2o`0003?ooooo0_l0000:ooooo`;o00003Oooool2o`0000Wooooo0_l0001eooooo`007_ooool0
0ol0003oooooooooo`1aooooo`;o00003Oooool2o`0001Wooooo0_l0000>ooooo`;o00008oooool2
o`0000cooooo0_l0000;ooooo`;o00004Oooool2o`0004Oooooo000Nooooo`03o`000?oooooooooo
00Kooooo0_l00008ooooo`;o0000C?ooool2o`00023ooooo0_l0000Iooooo`;o00003_ooool2o`00
00Gooooo0_l0000Zooooo`;o00002oooool2o`00017ooooo0_l00017ooooo`007_ooool00ol0003o
ooooooooo`06ooooo`;o00002?ooool2o`0004cooooo0_l000000ooooooo0000o`000006ooooo`;o
00009Oooool2o`00023ooooo0_l00006ooooo`;o0000Roooool001kooooo00?o0000ooooooooool0
HOooool2o`0000Cooooo1?l00004ooooo`;o00007oooool2o`0002Sooooo0_l0001looooo`;o0000
3Oooool001kooooo00?o0000ooooooooool0Ioooool2o`0000Kooooo0_l00005ooooo`;o0000HOoo
ool2o`00017ooooo0_l0000?ooooo`;o00001_ooool2o`00037ooooo0_l0000=ooooo`007_ooool0
0ol0003oooooooooo`08ooooo`;o0000;?ooool2o`0003kooooo0_l0001Qooooo`;o00004Oooool2
o`0000Wooooo0_l00004ooooo`;o00001_ooool2o`00043ooooo000Nooooo`03o`000?oooooooooo
00Sooooo0_l0000Fooooo`;o00005?ooool2o`0000oooooo0_l00006ooooo`;o0000M?ooool2o`00
033ooooo0_l0001>ooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o00009Oooool2o`0000Ko
oooo0_l0001dooooo`;o0000C?ooool2o`0003;ooooo000Nooooo`03o`000?oooooooooo027ooooo
0_l00003ooooo`;o0000joooool2o`0003;ooooo000Nooooo`03o`000?oooooooooo017ooooo0_l0
000>ooooo`;o00000oooool2o`0004Oooooo0_l00018ooooo`;o0000S?ooool001kooooo0_l0000B
ooooo`;o0000G?ooool2o`0000Sooooo0_l0000nooooo`;o0000A_ooool2o`0000Oooooo0_l0000k
ooooo`007_ooool00ol0003oooooooooo`0nooooo`;o0000>Oooool2o`00063ooooo0_l00004oooo
o`;o00007_ooool2o`0000Oooooo0_l0000kooooo`007_ooool00ol0003oooooooooo`0nooooo`;o
0000D_ooool2o`0001;ooooo0_l0000cooooo`;o00001?ooool2o`0005cooooo0_l00006ooooo`00
7_ooool00ol0003oooooooooo`0Booooo`;o0000O_ooool2o`0001;ooooo0_l000000ooooooo0000
o`00001Booooo`;o0000;_ooool2o`0000gooooo0_l000000ooooooo0000o`000006ooooo`007_oo
ool00ol0003oooooooooo`0Booooo`;o0000UOooool2o`0001[ooooo0_l0000;ooooo`;o0000:Ooo
ool2o`0000cooooo0_l000000ooooooo0000o`00000Mooooo`;o00003Oooool2o`0000Wooooo000N
ooooo`03o`000?oooooooooo0<Gooooo0_l0000;ooooo`;o0000=oooool2o`000003ooooool0003o
000003Oooooo000Nooooo`03o`000?oooooooooo04Sooooo0_l0000Zooooo`;o00001Oooool2o`00
04Wooooo0_l0001oooooo`007_ooool00ol0003oooooooooo`18ooooo`;o00006?ooool2o`0000ko
oooo1?l00005ooooo`;o0000BOooool2o`0007oooooo000Nooooo`03o`000?oooooooooo01[ooooo
0_l00016ooooo`;o00003_ooool2o`000:kooooo0_l0000Sooooo`007Oooool2o`0001cooooo0_l0
001Looooo`;o00002oooool2o`0009_ooooo0_l0000Sooooo`007Oooool2o`0007[ooooo0_l0000;
ooooo`;o0000:_ooool2o`0005Oooooo0_l0000Nooooo`;o00006oooool001kooooo00?o0000oooo
ooooool0/Oooool2o`0005Oooooo0_l0000Nooooo`;o00000oooool2o`0001Kooooo000Nooooo`03
o`000?oooooooooo01kooooo0_l00018ooooo`;o0000FOooool2o`0006[ooooo0_l0000Fooooo`00
7_ooool00ol0003oooooooooo`07ooooo`;o00005Oooool2o`0000_ooooo0_l0000Looooo`;o0000
7Oooool2o`0005Wooooo0_l00022ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`07ooooo`;o
00008_ooool2o`0001cooooo0_l0002eooooo`;o0000>?ooool2o`0000_ooooo0003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06oooo
o`03o`000?oooooooooo04cooooo0_l00003ooooo`;o0000[Oooool2o`0001Sooooo0_l0000Noooo
o`;o00002oooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooo
ooooool000001_ooool3o`0002?ooooo0_l0000;ooooo`;o00006_ooool2o`0000?ooooo0_l0000G
ooooo`;o00000oooool2o`0002kooooo0_l0001aooooo`;o00001_ooool2o`0002_ooooo0003oooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o
0000ooooooooool08oooool2o`0000_ooooo0_l0000hooooo`;o00000oooool2o`0000;ooooo0_l0
0008ooooo`;o00002Oooool2o`0001Gooooo0_l0000hooooo`;o00009Oooool2o`0000kooooo1?l0
000Cooooo`;o00007_ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mE
EEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`1cooooo`;o00002?ooool2o`0000Cooooo
0_l00003ooooo`;o0000Coooool2o`0002Gooooo0ol0000=ooooo`;o00005Oooool2o`0001kooooo
0003ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`00
0?oooooooooo01Kooooo0_l0001Vooooo`;o00000_ooool3o`0006[ooooo0_l0000@ooooo`;o0000
A?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo
00?o0000ooooooooool01Oooool2o`0000oooooo0_l0001Kooooo`;o00002Oooool2o`0000;ooooo
0_l0001[ooooo`;o0000:Oooool2o`0000_ooooo0_l0000Nooooo`000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_ooool3o`0000Gooooo0_l0001/ooooo`;o
0000YOooool2o`0000_ooooo0_l0000Nooooo`007_ooool3o`0000Oooooo0_l0000kooooo`;o0000
ROooool2o`0007Kooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l00002ooooo`;o0000>ooo
ool2o`0003[ooooo0_l00008ooooo`;o0000@oooool2o`0000Oooooo0_l0000Eooooo`;o00004?oo
ool2o`0004Cooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0001Rooooo`;o00002Oooool2
o`0000cooooo0_l00008ooooo`;o0000??ooool2o`0000kooooo0_l0000@ooooo`;o00000oooool2
o`00013ooooo0_l00014ooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o00009Oooool2o`00
02gooooo0_l00009ooooo`;o0000E?ooool2o`00023ooooo0_l0001Kooooo`007_ooool00ol0003o
ooooooooo`0Aooooo`;o00007Oooool2o`0000Kooooo0_l0000Kooooo`;o0000jOooool2o`0000Go
oooo000Nooooo`03o`000?oooooooooo033ooooo0_l0000Fooooo`;o00002oooool2o`0004;ooooo
0_l0001Booooo`;o0000DOooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo02Gooooo0_l0
000Eooooo`;o00002_ooool2o`0001Gooooo0_l0000hooooo`;o0000=oooool2o`0001Wooooo0_l0
001Hooooo`007_ooool00ol0003oooooooooo`0Uooooo`;o00005Oooool2o`00027ooooo0_l0001N
ooooo`;o00004Oooool2o`0003Cooooo0_l0000<ooooo`;o0000;oooool001kooooo00?o0000oooo
ooooool00_ooool2o`0000Wooooo0_l0002;ooooo`;o00008oooool2o`00033ooooo0_l0000Eoooo
o`;o00003?ooool2o`0001Kooooo0_l0000Gooooo`007_ooool00ol0003oooooooooo`02ooooo`;o
00002Oooool2o`0008_ooooo0_l0001Eooooo`;o00007?ooool2o`0001gooooo0_l0000Gooooo`00
7_ooool00ol0003oooooooooo`0Oooooo`;o0000k_ooool2o`0003Kooooo000Nooooo`;o00008?oo
ool2o`0005Kooooo0_l00008ooooo`;o0000a?ooool001kooooo00?o0000ooooooooool06_ooool2
o`0000Cooooo0_l0000[ooooo`;o0000:?ooool2o`000003ooooool0003o000000Gooooo0_l0000d
ooooo`;o0000Poooool2o`0000Wooooo000Nooooo`03o`000?oooooooooo01[ooooo0_l00004oooo
o`;o00000_ooool2o`0002Oooooo0_l0000[ooooo`;o0000=?ooool2o`0000Gooooo0_l00023oooo
o`;o00002Oooool001kooooo00?o0000ooooooooool09?ooool2o`0004gooooo0_l0000hooooo`;o
000000?oooooo`000?l000001Oooool2o`0008kooooo000Nooooo`03o`000?oooooooooo01Wooooo
0_l0001Hooooo`;o0000>?ooool2o`0000Sooooo0_l0000=ooooo`;o0000EOooool2o`0002Sooooo
000Nooooo`03o`000?oooooooooo01Wooooo0_l0000Rooooo`;o0000Qoooool2o`0004?ooooo0_l0
000@ooooo`;o00001Oooool2o`00027ooooo000Nooooo`03o`000?oooooooooo02Gooooo0_l0000F
ooooo`;o0000U_ooool2o`0003Cooooo0_l0000Gooooo`;o00008Oooool001kooooo00?o0000oooo
ooooool09Oooool2o`0002oooooo0_l0000@ooooo`;o00004?ooool2o`0005Wooooo0_l0001`oooo
o`007_ooool00ol0003oooooooooo`1Fooooo`;o00004?ooool2o`00013ooooo0_l0000Kooooo`;o
0000[_ooool001kooooo00?o0000ooooooooool0:Oooool2o`0004Wooooo0_l0000:ooooo`;o0000
5Oooool2o`0002Kooooo0_l00009ooooo`;o0000Noooool001kooooo00?o0000ooooooooool07_oo
ool2o`0000Wooooo0_l0000Jooooo`;o0000;Oooool2o`0000Oooooo0_l000000ooooooo0000o`00
000mooooo`;o00002Oooool2o`0007_ooooo000Nooooo`03o`000?oooooooooo01kooooo0_l0000U
ooooo`;o0000=_ooool2o`0001Cooooo0_l0001Pooooo`;o0000>Oooool2o`0001Gooooo000Noooo
o`03o`000?oooooooooo09?ooooo0_l0001Pooooo`;o0000>Oooool2o`0000?ooooo0_l0000@oooo
o`007_ooool00ol0003oooooooooo`3oooooo`;o0000=?ooool2o`00013ooooo000Nooooo`03o`00
0?oooooooooo07[ooooo0_l0001Booooo`;o00004_ooool2o`0001_ooooo0_l00016ooooo`007_oo
ool00ol0003oooooooooo`11ooooo`;o0000=oooool2o`0002[ooooo0_l0000Vooooo`;o00004_oo
ool2o`0006?ooooo000Nooooo`;o0000@_ooool2o`000003ooooool0003o0000063ooooo0_l0000>
ooooo`;o0000<Oooool2o`0003Oooooo0_l0000Gooooo`;o00002_ooool001kooooo00?o0000oooo
ooooool06Oooool2o`0001Oooooo0_l0000@ooooo`;o00000oooool2o`0006_ooooo0_l0000Hoooo
o`;o00005oooool2o`0003Oooooo0_l0000Gooooo`;o00002_ooool001kooooo00?o0000oooooooo
ool06Oooool2o`0000Oooooo0_l0000>ooooo`;o00001_ooool2o`0000gooooo0_l0001>ooooo`;o
0000=Oooool2o`0000Oooooo0_l000000ooooooo0000o`00000nooooo`;o0000:Oooool001kooooo
00?o0000ooooooooool08_ooool2o`0001Kooooo0_l0001Mooooo`;o00009Oooool2o`0001Oooooo
0_l000000ooooooo0000o`00000nooooo`;o0000:Oooool001kooooo00?o0000ooooooooool00_l0
0008ooooo`;o0000Eoooool2o`0001;ooooo0_l00017ooooo`;o00006_ooool2o`0001Oooooo0_l0
001@ooooo`007_ooool00ol0003oooooooooo`02o`0000?ooooo0_l00003ooooo`;o0000Eoooool2
o`0000gooooo0_l00003ooooo`;o0000K?ooool2o`0000kooooo0_l00016ooooo`;o00002?ooool0
01kooooo00?o0000ooooooooool01Oooool2o`0005Sooooo0_l0000Aooooo`;o00009?ooool2o`00
03;ooooo0_l0000Booooo`;o00000oooool2o`0004Cooooo0_l0000@ooooo`;o00002?ooool001ko
oooo00?o0000ooooooooool0>_ooool2o`000003ooooool0003o0000023ooooo0_l0000gooooo`;o
0000<_ooool2o`0001;ooooo0_l00004ooooo`;o0000@oooool2o`0001[ooooo000Nooooo`03o`00
0?oooooooooo037ooooo0_l00007ooooo`;o000000?oooooo`000?l00000EOooool2o`00053ooooo
0_l0001Oooooo`007_ooool00ol0003oooooooooo`0Uooooo`;o00002_ooool2o`00067ooooo0_l0
001<ooooo`;o00003oooool2o`0005;ooooo000Nooooo`03o`000?oooooooooo02Gooooo0_l0001N
ooooo`;o0000Doooool2o`0000Kooooo0_l0000?ooooo`?o0000A?ooool2o`0000_ooooo000Noooo
o`03o`000?oooooooooo08Gooooo0_l0001Cooooo`;o00006?ooool2o`0004Cooooo0_l0000;oooo
o`007_ooool00ol0003oooooooooo`0Oooooo`;o0000F?ooool2o`000<cooooo000Nooooo`03o`00
0?oooooooooo01oooooo0_l0001Hooooo`;o00002Oooool2o`0006oooooo0_l00002ooooo`;o0000
C?ooool001kooooo00?o0000ooooooooool04Oooool2o`0006kooooo0_l000000ooooooo0000o`00
0003ooooo`;o0000COooool2o`0001_ooooo0_l00002ooooo`;o0000C?ooool001kooooo00?o0000
ooooooooool04Oooool2o`0006Cooooo0_l00008ooooo`;o00001_ooool2o`0001Gooooo0_l0000f
ooooo`;o00000_ooool2o`0002kooooo0_l0000iooooo`007_ooool2o`0002cooooo0_l0001:oooo
o`;o00009oooool2o`0003[ooooo0_l0000^ooooo`;o0000>Oooool001kooooo00?o0000oooooooo
ool0:Oooool4o`0003;ooooo0_l00029ooooo`;o0000Foooool001kooooo00?o0000ooooooooool0
6Oooool2o`0000kooooo0_l0000Rooooo`;o00000_ooool2o`0000cooooo0ol0000@ooooo`;o0000
1_ooool2o`0003Wooooo0_l0000cooooo`;o00009Oooool2o`000003ooooool0003o0000037ooooo
000Nooooo`03o`000?oooooooooo01Gooooo0_l00002ooooo`;o0000<_ooool2o`0000;ooooo0_l0
000=ooooo`;o00004?ooool2o`0000Kooooo0_l0000Vooooo`;o00004Oooool2o`00037ooooo0_l0
000Wooooo`;o000000?oooooo`000?l000006Oooool2o`0001Kooooo000Nooooo`;o00005_ooool2
o`0008_ooooo0_l00014ooooo`;o0000@?ooool2o`0000?ooooo0_l0000Fooooo`007_ooool2o`00
0>;ooooo0_l00017ooooo`;o00006oooool001kooooo00?o0000ooooooooool0=?ooool2o`0002ko
oooo0_l0001kooooo`;o0000Aoooool2o`0001_ooooo000Nooooo`03o`000?oooooooooo03Cooooo
0_l0000=ooooo`;o00003?ooool2o`00017ooooo0_l00034ooooo`;o00000_ooool2o`0001Oooooo
000Nooooo`03o`000?oooooooooo04?ooooo0_l0000<ooooo`;o0000b?ooool2o`00017ooooo0ol0
0005ooooo`;o00003oooool001kooooo00?o0000ooooooooool0O_ooool2o`0009_ooooo0_l0000B
ooooo`;o00001Oooool2o`0000oooooo000Nooooo`03o`000?oooooooooo07Sooooo0_l00004oooo
o`;o0000B_ooool2o`0007_ooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l0001`ooooo`;o
00007?ooool2o`0003;ooooo0_l0000Gooooo`;o0000<oooool2o`0002Kooooo0_l00005ooooo`00
7_ooool00ol0003oooooooooo`06ooooo`;o0000S_ooool2o`0004_ooooo0_l0000cooooo`;o0000
9_ooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo0?kooooo0_l0000Looooo`;o0000:Ooo
ool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`00
0?lQ8B7oc<c<00Kooooo00?o0000ooooooooool05?ooool2o`0006oooooo0_l00017ooooo`;o0000
;_ooool2o`0001cooooo0_l0000Rooooo`;o00001Oooool000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000oooooooo
ool05?ooool2o`0000[ooooo0_l0000iooooo`;o0000:?ooool2o`0004Oooooo0_l0000Xooooo`;o
00008?ooool2o`0002Cooooo0_l00005ooooo`000oooool01Ol@413ooooooooooooooooo410@00_o
oooo00Go0000ooooooooooooooooo`000006ooooo`?o00007Oooool2o`000003ooooool0003o0000
03Wooooo0_l0002Kooooo`;o00008?ooool2o`0000[ooooo0_l0000Oooooo`000oooool01Ol0003o
oooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooo
oooo01Oooooo0_l000001?oooooo0000o`000?ooool2o`0005Gooooo0_l0002`ooooo`;o00005?oo
ool2o`0000Wooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`00
0?l0003oc<c<00Kooooo00?o0000ooooooooool05oooool2o`000003ooooool0003o000002Gooooo
0_l0000aooooo`;o0000`Oooool2o`0000?ooooo0_l00009ooooo`000oooool01Ol@413ooooooooo
oooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo047o
oooo0_l0003Yooooo`;o00002?ooool3o`0000kooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool01Oooool2o`00
01kooooo0_l0003oooooo`Kooooo0_l00008ooooo`;o00003oooool000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`05
ooooo`;o00007_ooool2o`0001Kooooo0_l00008ooooo`;o0000Qoooool2o`0007Gooooo000Noooo
o`03o`000?oooooooooo03gooooo0_l00008ooooo`;o0000D_ooool2o`0001Wooooo0_l0000Hoooo
o`;o0000@_ooool2o`00037ooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l0001Hooooo`?o
00006_ooool2o`00013ooooo0_l00004ooooo`;o000000?oooooo`000?l00000G?ooool2o`0001co
oooo0_l0000Cooooo`007_ooool00ol0003oooooooooo`0Tooooo`?o00003_ooool2o`0000cooooo
0_l0000iooooo`?o00005_ooool2o`0001Cooooo0_l00004ooooo`;o0000OOooool2o`0001?ooooo
000Nooooo`03o`000?oooooooooo02Gooooo0_l0000>ooooo`;o00001?ooool2o`0000Kooooo0_l0
0009ooooo`;o00008Oooool2o`0002Cooooo0_l00007ooooo`;o0000H?ooool2o`0001_ooooo0_l0
000Vooooo`007_ooool00ol0003oooooooooo`0Yooooo`;o00004?ooool2o`00017ooooo0_l0000Q
ooooo`;o0000;Oooool4o`0000?ooooo0_l0001Iooooo`;o00006oooool2o`0002Kooooo000Noooo
o`03o`000?oooooooooo00Cooooo0_l0000Sooooo`;o0000COooool2o`0002Sooooo0_l000000ooo
oooo0000o`000002o`0001Gooooo0_l00027ooooo`007_ooool00ol0003oooooooooo`04ooooo`;o
0000BOooool2o`0002Oooooo0_l0000[ooooo`;o00005oooool2o`0002Cooooo0_l0000booooo`;o
00007_ooool2o`0000gooooo000Nooooo`03o`000?oooooooooo02gooooo0_l0000Pooooo`;o0000
?oooool2o`0001;ooooo0_l0000nooooo`;o0000<_ooool2o`0001kooooo0_l0000=ooooo`007_oo
ool00ol0003oooooooooo`0Eooooo`;o00005_ooool2o`0005_ooooo0_l00004ooooo`;o00004_oo
ool2o`0004;ooooo0_l0001Mooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o00007?ooool2
o`0002Cooooo0_l0000^ooooo`?o0000G?ooool2o`0002Wooooo0_l0000Cooooo`;o00002_ooool2
o`00017ooooo000Nooooo`03o`000?oooooooooo03?ooooo0_l00005ooooo`;o00007Oooool2o`00
02kooooo0_l0000Gooooo`;o0000Koooool2o`0001?ooooo0_l0000:ooooo`;o00004Oooool001ko
oooo0_l0000kooooo`;o0000I_ooool2o`00073ooooo0_l0000aooooo`007_ooool00ol0003ooooo
ooooo`2/ooooo`;o0000:_ooool2o`0003[ooooo0_l00008ooooo`;o00009oooool001kooooo00?o
0000ooooooooool0H_ooool2o`0004Sooooo0_l0000Zooooo`;o0000A?ooool2o`0002Oooooo000N
ooooo`03o`000?oooooooooo00cooooo0_l0001Dooooo`;o0000hoooool001kooooo00?o0000oooo
ooooool03?ooool2o`0001Wooooo0_l0000Oooooo`;o0000FOooool2o`00063ooooo0_l00010oooo
o`007_ooool00ol0003oooooooooo`0Wooooo`;o00007oooool2o`0002cooooo0_l0000[ooooo`;o
0000Goooool3o`0001gooooo0_l0000Qooooo`007_ooool00ol0003oooooooooo`07ooooo`;o0000
?oooool2o`0002cooooo0_l0000mooooo`;o0000?oooool2o`0000cooooo0_l0000Nooooo`;o0000
3?ooool2o`0001?ooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l0000`ooooo`;o00003Ooo
ool2o`0004Cooooo0_l0000Qooooo`;o00000_ooool2o`00013ooooo0_l0000]ooooo`;o00006ooo
ool2o`0001gooooo0_l0000Cooooo`007_ooool00ol0003oooooooooo`0iooooo`;o0000Doooool2
o`00027ooooo0_l0000Dooooo`;o00008Oooool2o`0002Oooooo0_l0000booooo`007_ooool00ol0
003oooooooooo`1kooooo`;o0000=Oooool2o`0003Kooooo0_l0001Kooooo`007_ooool3o`0007_o
oooo0_l0000eooooo`;o00001?ooool2o`0004gooooo0_l0000Looooo`;o00008?ooool001kooooo
0ol0000dooooo`;o0000>Oooool2o`0003;ooooo0_l0000=ooooo`;o00001?ooool2o`0004gooooo
0_l0000Looooo`;o00006Oooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo03Cooooo0_l0
000iooooo`;o0000<_ooool2o`0009_ooooo0_l00005ooooo`007_ooool00ol0003oooooooooo`0G
ooooo`;o0000J_ooool2o`0000Kooooo0_l0002jooooo`007_ooool00ol0003oooooooooo`0Goooo
o`;o0000B_ooool2o`0001kooooo0_l00006ooooo`;o0000^_ooool001kooooo00?o0000oooooooo
ool0Hoooool2o`0000Cooooo0_l0001Hooooo`;o0000:?ooool2o`0005Sooooo000Nooooo`;o0000
6oooool2o`0000Wooooo0_l0000gooooo`;o00002Oooool2o`0005Sooooo0_l0000Hooooo`;o0000
3_ooool2o`0002kooooo0_l0000Hooooo`;o00001?ooool2o`0000Sooooo000Nooooo`03o`000?oo
oooooooo00[ooooo0_l0000>ooooo`;o00002Oooool2o`0003Oooooo0_l0000^ooooo`;o0000COoo
ool2o`0002Kooooo0_l0000Fooooo`;o00006?ooool2o`0000Cooooo0_l00008ooooo`007_ooool0
0ol0003oooooooooo`0:ooooo`;o0000E_ooool2o`0002[ooooo0_l0001eooooo`;o0000@?ooool0
01kooooo00?o0000ooooooooool0H_ooool2o`0003Kooooo0_l00007ooooo`;o0000X_ooool001ko
oooo00?o0000ooooooooool0KOooool2o`0002_ooooo0_l00007ooooo`;o00008?ooool2o`00083o
oooo000Nooooo`03o`000?oooooooooo03Cooooo0_l0000Hooooo`;o00007Oooool2o`0005Kooooo
0_l00020ooooo`007_ooool00ol0003oooooooooo`0dooooo`;o00006?ooool2o`000?Oooooo000N
ooooo`04o`000?ooooooooooooooo`;o00000oooool2o`0000[ooooo0_l0001Booooo`Co00004Ooo
ool2o`0001Kooooo0_l0000?ooooo`;o00008?ooool2o`0007oooooo000Nooooo`04o`000?oooooo
ooooooooo`;o00000oooool2o`0000[ooooo0_l0001Booooo`Co00001?ooool2o`0000_ooooo0_l0
000Fooooo`;o00002?ooool2o`0000Gooooo0_l0000Pooooo`;o00004_ooool2o`0000Oooooo0_l0
001Eooooo`;o00002oooool001kooooo00?o0000ooooooooool0Doooool4o`0000Sooooo0_l0000=
ooooo`;o0000;Oooool2o`0001Oooooo0_l0000Rooooo`;o00001oooool2o`0002oooooo0_l0000O
ooooo`;o00000oooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo05?ooooo1?l00008oooo
o`;o0000EOooool2o`0002Cooooo0_l0000fooooo`;o00007oooool2o`00013ooooo000Nooooo`03
o`000?oooooooooo05Wooooo0_l0000]ooooo`;o0000Boooool2o`0000Gooooo0_l0001Yooooo`00
7_ooool00ol0003oooooooooo`1Iooooo`;o0000;Oooool2o`0001Oooooo0_l0000booooo`;o0000
8_ooool3o`0004_ooooo000Nooooo`03o`000?oooooooooo03[ooooo0_l0000;ooooo`;o0000E?oo
ool2o`0000;ooooo0_l0000Pooooo`;o0000=?ooool3o`0003Sooooo0_l00003ooooo`;o00000ooo
ool2o`0000Oooooo000Nooooo`03o`000?oooooooooo03[ooooo0_l0000;ooooo`;o0000E?ooool2
o`0002Cooooo0_l0000Iooooo`;o00003Oooool2o`0000Oooooo0_l0000;ooooo`;o00004?ooool2
o`0001gooooo0_l00003ooooo`;o00000oooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo
06cooooo0_l00005ooooo`;o00000oooool2o`0006Cooooo0_l0000=ooooo`;o00001oooool2o`00
00_ooooo0_l0000@ooooo`;o00007Oooool2o`00017ooooo000Nooooo`;o00009oooool2o`0003go
oooo0_l00005ooooo`;o00001Oooool2o`0000?ooooo0_l00010ooooo`;o00001?ooool2o`0002?o
oooo0_l0001Pooooo`007_ooool00ol0003oooooooooo`0Vooooo`;o0000?Oooool2o`0003?ooooo
0_l0000Nooooo`;o00001?ooool2o`0002?ooooo0_l0000<ooooo`;o0000D_ooool001kooooo0_l0
0008ooooo`;o0000:?ooool2o`0002;ooooo0_l00013ooooo`;o0000Eoooool2o`0003;ooooo0_l0
000Nooooo`007_ooool2o`0000Sooooo0_l00007ooooo`;o00007oooool2o`0002;ooooo0_l0000W
ooooo`;o0000DOooool2o`0005Cooooo0_l000000ooooooo0000o`00000Kooooo`007_ooool00ol0
003oooooooooo`0@ooooo`;o0000;_ooool2o`0003cooooo0_l0001Aooooo`;o0000=_ooool2o`00
00;ooooo0_l0000Kooooo`;o00006oooool001kooooo00?o0000ooooooooool03_ooool2o`00033o
oooo0_l00037ooooo`;o00000_ooool2o`0003Sooooo000Nooooo`03o`000?oooooooooo00kooooo
0_l0000Xooooo`;o0000K_ooool2o`0009gooooo000Nooooo`03o`000?oooooooooo03Sooooo0_l0
001^ooooo`;o0000>Oooool2o`0006;ooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l00038
ooooo`;o0000H_ooool001kooooo00?o0000ooooooooool06Oooool2o`000;Gooooo0_l0000;oooo
o`;o0000J?ooool001kooooo00?o0000ooooooooool01_ooool2o`0001Kooooo0_l0001Sooooo`;o
0000?oooool2o`0000[ooooo0_l0000;ooooo`;o0000J?ooool001kooooo00?o0000ooooooooool0
1_ooool2o`000003ooooool0003o000001?ooooo0_l0001Sooooo`;o0000?oooool2o`0003Cooooo
0_l0001;ooooo`007_ooool00ol0003oooooooooo`09ooooo`;o00008_ooool2o`000;?ooooo0_l0
0006ooooo`;o00003_ooool2o`0000Sooooo0_l0000Yooooo`;o00005_ooool001kooooo00?o0000
ooooooooool0;Oooool2o`00073ooooo0_l00011ooooo`;o00001_ooool2o`0000cooooo0_l0000:
ooooo`;o0000:Oooool2o`0001Kooooo000Dooooo`Co000000?o410@ooooooooool00oooool01?l0
003oooooo`000?l00008ooooo`;o0000U?ooool2o`0003?ooooo0_l0000Rooooo`;o0000COooool0
01Kooooo00?o0000ooooooooool01Oooool01?l0003oooooo`000?l00008ooooo`;o0000bOooool2
o`0000?ooooo0_l0001Looooo`;o00003_ooool001Kooooo00?o0000ooooooooool01Oooool3o`00
0<Oooooo0_l0000@ooooo`;o0000G?ooool2o`0000kooooo000Fooooo`03o`000?oooooooooo0<oo
oooo0_l0001nooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oo
oooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005?ooool00omE
EEGoIVIVo`00003ooooooe;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.44558 .8221 Mdot
.60845 .46033 Mdot
.57483 .94006 Mdot
.97588 .32186 Mdot
.06771 .82846 Mdot
.75234 .64332 Mdot
.35234 .48716 Mdot
.3197 .76579 Mdot
.45999 .40515 Mdot
.88296 .03507 Mdot
.57803 .24931 Mdot
.61603 .47821 Mdot
.15716 .73022 Mdot
.02038 .89625 Mdot
.57696 .3015 Mdot
.90162 .81977 Mdot
.31877 .89395 Mdot
.85412 .54249 Mdot
.01485 .93739 Mdot
.51489 .35295 Mdot
.67219 .40674 Mdot
.94109 .06688 Mdot
.33825 .81015 Mdot
.42223 .01628 Mdot
.52245 .18275 Mdot
.87312 .24652 Mdot
.73746 .21369 Mdot
.51052 .38718 Mdot
.76488 .3934 Mdot
.31053 .6776 Mdot
.3409 .65379 Mdot
.07956 .84268 Mdot
.29805 .68079 Mdot
.18811 .13544 Mdot
.59002 .672 Mdot
.40097 .4394 Mdot
.81973 .6408 Mdot
.37893 .91276 Mdot
.41443 .63996 Mdot
.84546 .12988 Mdot
.27946 .56052 Mdot
.58587 .27632 Mdot
.1614 .80312 Mdot
.09925 .67443 Mdot
.29478 .64894 Mdot
.80157 .52611 Mdot
.10547 .45073 Mdot
.88617 .246 Mdot
.60188 .91467 Mdot
.73391 .77103 Mdot
.37419 .69765 Mdot
.96946 .43607 Mdot
.28117 .32696 Mdot
.98832 .3587 Mdot
.53365 .20306 Mdot
.3182 .5511 Mdot
.24074 .9254 Mdot
.9088 .59018 Mdot
.96898 .48065 Mdot
.99207 .48923 Mdot
.41938 .63009 Mdot
.33407 .66707 Mdot
.29151 .28536 Mdot
.68158 .98979 Mdot
.56667 .56341 Mdot
.48238 .1945 Mdot
.76743 .42346 Mdot
.62229 .61176 Mdot
.49948 .8278 Mdot
.01124 .03887 Mdot
.60168 .54022 Mdot
.47361 .79238 Mdot
.23938 .82687 Mdot
.74305 .16204 Mdot
.8599 .89391 Mdot
.1366 .32499 Mdot
.50261 .30966 Mdot
.9731 .67457 Mdot
.57213 .39287 Mdot
.51799 .97028 Mdot
.5697 .07176 Mdot
.38633 .37226 Mdot
.23347 .2419 Mdot
.4366 .49203 Mdot
.09396 .87903 Mdot
.43883 .73228 Mdot
.66074 .66048 Mdot
.64449 .17704 Mdot
.57914 .32849 Mdot
.82685 .28842 Mdot
.91904 .17724 Mdot
.13268 .92691 Mdot
.41751 .82998 Mdot
.00882 .1593 Mdot
.61659 .11026 Mdot
.71425 .71865 Mdot
.83668 .86415 Mdot
.82938 .65553 Mdot
.45851 .76156 Mdot
.84197 .03968 Mdot
.68994 .12584 Mdot
.78207 .36776 Mdot
.96893 .67246 Mdot
.07686 .17096 Mdot
.13752 .00348 Mdot
.16542 .20526 Mdot
.85597 .44923 Mdot
.29297 .08657 Mdot
.15375 .48516 Mdot
.08403 .5205 Mdot
.01153 .83479 Mdot
.37973 .37361 Mdot
.49916 .71257 Mdot
.05386 .47005 Mdot
.57791 .34084 Mdot
.0581 .69565 Mdot
.78287 .63639 Mdot
.2594 .04666 Mdot
.22718 .89281 Mdot
.72325 .78011 Mdot
.78087 .76276 Mdot
.51067 .88828 Mdot
.3321 .09637 Mdot
.25498 .44882 Mdot
.25982 .1831 Mdot
.361 .69016 Mdot
.94721 .80485 Mdot
.25158 .35298 Mdot
.07153 .79625 Mdot
.49614 .29972 Mdot
.00809 .45399 Mdot
.46293 .32418 Mdot
.43274 .01205 Mdot
.97141 .23206 Mdot
.5454 .98119 Mdot
.4468 .87642 Mdot
.44957 .1469 Mdot
.17238 .01093 Mdot
.72938 .96485 Mdot
.38216 .78139 Mdot
.41083 .79347 Mdot
.75274 .84729 Mdot
.93655 .31363 Mdot
.38817 .74142 Mdot
.16327 .24686 Mdot
.20096 .80911 Mdot
.26105 .69394 Mdot
.4948 .47587 Mdot
.01861 .60385 Mdot
.83971 .27035 Mdot
.29804 .04913 Mdot
.70424 .55186 Mdot
.43644 .62908 Mdot
.9559 .66839 Mdot
.78413 .40614 Mdot
.12368 .66411 Mdot
.88442 .25657 Mdot
.43977 .93196 Mdot
.37306 .3414 Mdot
.35825 .37724 Mdot
.90529 .02602 Mdot
.7194 .52114 Mdot
.02772 .81155 Mdot
.27685 .02148 Mdot
.82123 .34383 Mdot
.72812 .1145 Mdot
.51546 .8616 Mdot
.75253 .0166 Mdot
.06052 .45219 Mdot
.34276 .3822 Mdot
.21335 .39856 Mdot
.10039 .77503 Mdot
.24166 .90219 Mdot
.52382 .79225 Mdot
.09539 .10747 Mdot
.95466 .58882 Mdot
.23582 .06338 Mdot
.96225 .13604 Mdot
.84527 .17503 Mdot
.46737 .81821 Mdot
.01249 .73586 Mdot
.8819 .80732 Mdot
.35194 .13293 Mdot
.13518 .72307 Mdot
.628 .6996 Mdot
.42825 .95621 Mdot
.04765 .38299 Mdot
.88393 .72204 Mdot
.64985 .73157 Mdot
.75915 .07259 Mdot
.26404 .03728 Mdot
.58542 .90509 Mdot
.2197 .76095 Mdot
.48087 .88206 Mdot
.78141 .85675 Mdot
.71 .76373 Mdot
.85137 .57253 Mdot
.60711 .69938 Mdot
.2054 .65851 Mdot
.81393 .48432 Mdot
.37877 .36331 Mdot
.80025 .69218 Mdot
.31505 .9158 Mdot
.28805 .08967 Mdot
.46962 .12284 Mdot
.18009 .97655 Mdot
.65299 .68197 Mdot
.88108 .84272 Mdot
.9928 .81996 Mdot
.31436 .88904 Mdot
.23954 .80448 Mdot
.07681 .71318 Mdot
.07394 .44153 Mdot
.88109 .47483 Mdot
.89062 .95595 Mdot
.53751 .47125 Mdot
.56847 .23554 Mdot
.88949 .29002 Mdot
.89022 .9101 Mdot
.33965 .73457 Mdot
.89331 .92415 Mdot
.02622 .40589 Mdot
.8241 .18439 Mdot
.51941 .7217 Mdot
.0491 .17912 Mdot
.89861 .76418 Mdot
.8561 .81895 Mdot
.13364 .55285 Mdot
.40389 .41219 Mdot
.78829 .52761 Mdot
.06269 .88789 Mdot
.22591 .86112 Mdot
.34829 .59905 Mdot
.2186 .85995 Mdot
.29606 .98202 Mdot
.10873 .07833 Mdot
.31731 .46906 Mdot
.74669 .42614 Mdot
.29919 .44689 Mdot
.47014 .59888 Mdot
.32234 .74074 Mdot
.48838 .84536 Mdot
.98538 .1645 Mdot
.3409 .87646 Mdot
.98328 .47143 Mdot
.25613 .99863 Mdot
.19932 .80859 Mdot
.48412 .76848 Mdot
.49252 .1826 Mdot
.2039 .5466 Mdot
.56178 .50546 Mdot
.61157 .18352 Mdot
.13398 .22991 Mdot
.73492 .02475 Mdot
.9739 .34928 Mdot
.18583 .8739 Mdot
.40863 .85264 Mdot
.06464 .94946 Mdot
.30269 .35408 Mdot
.76105 .0506 Mdot
.50036 .95396 Mdot
.76816 .28306 Mdot
.8337 .17933 Mdot
.49964 .1925 Mdot
.06719 .14072 Mdot
.24676 .36239 Mdot
.35313 .06031 Mdot
.22883 .57579 Mdot
.50406 .3126 Mdot
.00237 .84293 Mdot
.89865 .1367 Mdot
.32099 .14986 Mdot
.35355 .84754 Mdot
.44757 .79235 Mdot
.22874 .90273 Mdot
.69407 .85125 Mdot
.64703 .96565 Mdot
.76334 .23375 Mdot
.44327 .28692 Mdot
.11427 .7781 Mdot
.59788 .23927 Mdot
.32059 .03617 Mdot
.65693 .52697 Mdot
.83315 .79361 Mdot
.16203 .193 Mdot
.79458 .53088 Mdot
.73182 .21405 Mdot
.86469 .20501 Mdot
.83997 .17698 Mdot
.76474 .00512 Mdot
.93279 .82676 Mdot
.14334 .28077 Mdot
.87536 .85054 Mdot
.77644 .53655 Mdot
.92029 .45467 Mdot
.94121 .2517 Mdot
.49299 .59773 Mdot
.33153 .35983 Mdot
.68692 .49097 Mdot
.20314 .04446 Mdot
.62783 .28065 Mdot
.61546 .23562 Mdot
.44282 .43369 Mdot
.12093 .19614 Mdot
.57636 .69955 Mdot
.38726 .45933 Mdot
.46116 .24276 Mdot
.62221 .96639 Mdot
.66343 .8535 Mdot
.76549 .77056 Mdot
.37962 .55196 Mdot
.64046 .56221 Mdot
.19488 .3146 Mdot
.77913 .15249 Mdot
.1102 .24967 Mdot
.00652 .39146 Mdot
.97304 .74355 Mdot
.21553 .69477 Mdot
.43264 .23695 Mdot
.67176 .28063 Mdot
.86666 .80553 Mdot
.7885 .97944 Mdot
.67594 .30775 Mdot
.67592 .90916 Mdot
.52053 .29704 Mdot
.76302 .65102 Mdot
.74236 .31205 Mdot
.57774 .4805 Mdot
.9219 .92551 Mdot
.10533 .41928 Mdot
.97032 .98389 Mdot
.11047 .81912 Mdot
.60108 .61878 Mdot
.59966 .10329 Mdot
.00074 .59896 Mdot
.43521 .74904 Mdot
.32428 .87157 Mdot
.58715 .68523 Mdot
.87622 .70205 Mdot
.52862 .21797 Mdot
.99153 .15973 Mdot
.03977 .73677 Mdot
.25136 .6211 Mdot
.73889 .00052 Mdot
.2084 .67483 Mdot
.33241 .89527 Mdot
.24482 .23646 Mdot
.00482 .68292 Mdot
.55961 .53395 Mdot
.89337 .6461 Mdot
.25948 .08669 Mdot
.03919 .55858 Mdot
.21568 .70229 Mdot
.68824 .03232 Mdot
.17266 .64363 Mdot
.12921 .87059 Mdot
.06094 .1148 Mdot
.25029 .68721 Mdot
.50363 .54838 Mdot
.87774 .14037 Mdot
.93616 .70021 Mdot
.57777 .85816 Mdot
.38105 .7708 Mdot
.97585 .38576 Mdot
.98036 .57828 Mdot
.29793 .1918 Mdot
.13497 .66903 Mdot
.59044 .40014 Mdot
.37724 .41267 Mdot
.26834 .41106 Mdot
.44492 .48889 Mdot
.07454 .33605 Mdot
.56374 .63815 Mdot
.50458 .99563 Mdot
.38909 .67021 Mdot
.2828 .69585 Mdot
.97462 .64388 Mdot
.48049 .86393 Mdot
.19833 .7416 Mdot
.51467 .04732 Mdot
.81694 .24765 Mdot
.97267 .85935 Mdot
.64607 .73791 Mdot
.59955 .16568 Mdot
.44979 .97338 Mdot
.60452 .48884 Mdot
.1767 .6056 Mdot
.95903 .91563 Mdot
.53149 .37976 Mdot
.75473 .89345 Mdot
.85981 .79918 Mdot
.96849 .00129 Mdot
.09322 .22944 Mdot
.66116 .19474 Mdot
.27645 .64412 Mdot
.44044 .21157 Mdot
.65182 .84055 Mdot
.95959 .60727 Mdot
.74335 .37485 Mdot
.93771 .70063 Mdot
.811 .15148 Mdot
.62694 .57347 Mdot
.86381 .43475 Mdot
.52514 .19704 Mdot
.31929 .50304 Mdot
.80635 .07051 Mdot
.04187 .27968 Mdot
.98123 .08549 Mdot
.35132 .61763 Mdot
.65901 .92112 Mdot
.99061 .037 Mdot
.54702 .7068 Mdot
.67289 .67828 Mdot
.94644 .78934 Mdot
.99 .74606 Mdot
.66894 .63082 Mdot
.38952 .21796 Mdot
.96771 .84778 Mdot
.88708 .93193 Mdot
.98839 .80372 Mdot
.55168 .52625 Mdot
.17678 .15748 Mdot
.86042 .18759 Mdot
.48968 .07105 Mdot
.58423 .10322 Mdot
.39218 .31973 Mdot
.19288 .69743 Mdot
.12785 .66536 Mdot
.67773 .6867 Mdot
.69739 .25061 Mdot
.63384 .49364 Mdot
.61284 .33097 Mdot
.89052 .41962 Mdot
.19152 .26451 Mdot
.39008 .79395 Mdot
.82907 .33305 Mdot
.25403 .38152 Mdot
.90018 .9459 Mdot
.76853 .0419 Mdot
.35164 .94364 Mdot
.86601 .17845 Mdot
.65004 .25578 Mdot
.49788 .3006 Mdot
.65419 .94486 Mdot
.79065 .3533 Mdot
.92819 .94198 Mdot
.66474 .09731 Mdot
.77505 .48795 Mdot
.39134 .28611 Mdot
.36503 .62362 Mdot
.19933 .67852 Mdot
.42973 .53577 Mdot
.9545 .60805 Mdot
.21592 .07946 Mdot
.47905 .11333 Mdot
.40259 .40405 Mdot
.47917 .42125 Mdot
.08649 .1904 Mdot
.37275 .38393 Mdot
.97979 .62142 Mdot
.8884 .47075 Mdot
.38983 .22874 Mdot
.75962 .98312 Mdot
.51502 .94104 Mdot
.41801 .62523 Mdot
.37451 .50623 Mdot
.27825 .12145 Mdot
.36204 .56489 Mdot
.2703 .73718 Mdot
.88332 .83257 Mdot
.32634 .43742 Mdot
.1452 .62586 Mdot
.81414 .03426 Mdot
.02127 .66465 Mdot
.06625 .60806 Mdot
.75677 .32886 Mdot
.75201 .53872 Mdot
.35899 .44516 Mdot
.95442 .01473 Mdot
.71242 .47809 Mdot
.87007 .77228 Mdot
.49916 .19399 Mdot
.96892 .23568 Mdot
.09344 .74763 Mdot
.96501 .83664 Mdot
.70288 .63419 Mdot
.50898 .46781 Mdot
.25148 .07659 Mdot
.95592 .65517 Mdot
.83047 .06646 Mdot
.54636 .21287 Mdot
.98102 .46759 Mdot
.3422 .6867 Mdot
.07809 .98301 Mdot
.41515 .60865 Mdot
.90514 .65552 Mdot
.78778 .83997 Mdot
.32722 .61292 Mdot
.97653 .21702 Mdot
.55588 .51709 Mdot
.63028 .77577 Mdot
.23401 .05315 Mdot
.49058 .42557 Mdot
.95988 .91384 Mdot
.43603 .93276 Mdot
.36034 .69262 Mdot
.6047 .17334 Mdot
.72152 .88711 Mdot
.57407 .19397 Mdot
.31027 .43444 Mdot
.90243 .76075 Mdot
.99602 .95234 Mdot
.03016 .53885 Mdot
.17729 .40268 Mdot
.00296 .63324 Mdot
.13717 .80135 Mdot
.1078 .60018 Mdot
.2213 .75768 Mdot
.21574 .34264 Mdot
.1382 .61072 Mdot
.64933 .42857 Mdot
.98064 .74579 Mdot
.07319 .43649 Mdot
.21637 .92749 Mdot
.89067 .25643 Mdot
.34176 .08009 Mdot
.47313 .86207 Mdot
.13185 .76534 Mdot
.57858 .9866 Mdot
.13644 .52417 Mdot
.89384 .58939 Mdot
.53806 .91721 Mdot
.72753 .92042 Mdot
.90845 .35264 Mdot
.78961 .89889 Mdot
.98057 .89157 Mdot
.59017 .28909 Mdot
.38952 .01599 Mdot
.62682 .033 Mdot
.1361 .59222 Mdot
.77447 .57462 Mdot
.11809 .54523 Mdot
.48664 .41163 Mdot
.05302 .91685 Mdot
.30284 .48121 Mdot
.03386 .44798 Mdot
.65654 .03174 Mdot
.52257 .83328 Mdot
.21354 .1863 Mdot
.58975 .99813 Mdot
.75865 .75611 Mdot
.35475 .98637 Mdot
.10844 .13266 Mdot
.88528 .12709 Mdot
.77062 .99289 Mdot
.54186 .84408 Mdot
.34444 .73445 Mdot
.9287 .22955 Mdot
.19608 .52411 Mdot
.11907 .94932 Mdot
.14858 .48528 Mdot
.69693 .70528 Mdot
.6648 .04883 Mdot
.38937 .43852 Mdot
.02721 .78026 Mdot
.95645 .02557 Mdot
.46149 .47784 Mdot
.62338 .94202 Mdot
.90474 .00866 Mdot
.71435 .5801 Mdot
.48856 .87369 Mdot
.2808 .82673 Mdot
.64807 .94528 Mdot
.97498 .02874 Mdot
.59549 .2732 Mdot
.19305 .26771 Mdot
.14109 .9181 Mdot
.1656 .96349 Mdot
.75972 .26628 Mdot
.14378 .87026 Mdot
.58204 .12016 Mdot
.92454 .75131 Mdot
.23417 .07853 Mdot
.64258 .30269 Mdot
.93639 .86751 Mdot
.83072 .62764 Mdot
.89213 .14191 Mdot
.98448 .89796 Mdot
.44892 .64652 Mdot
.04992 .33502 Mdot
.63337 .42834 Mdot
.53332 .79416 Mdot
.91117 .2878 Mdot
.07864 .39264 Mdot
.55342 .50821 Mdot
.11315 .74536 Mdot
.01601 .90211 Mdot
.13767 .39873 Mdot
.24702 .81512 Mdot
.18338 .1295 Mdot
.92949 .03281 Mdot
.96981 .35653 Mdot
.69694 .01516 Mdot
.73838 .14383 Mdot
.66016 .36558 Mdot
.13104 .06239 Mdot
.07081 .73595 Mdot
.72015 .15588 Mdot
.28679 .63964 Mdot
.08024 .69412 Mdot
.78737 .03146 Mdot
.01788 .04359 Mdot
.39689 .32219 Mdot
.80666 .99041 Mdot
.74511 .53709 Mdot
.6958 .37625 Mdot
.29398 .11037 Mdot
.41645 .29828 Mdot
.66293 .17983 Mdot
.1669 .53595 Mdot
.85974 .47559 Mdot
.7482 .48345 Mdot
.68138 .76372 Mdot
.8678 .01822 Mdot
.03139 .80418 Mdot
.6241 .08313 Mdot
.17801 .3516 Mdot
.47572 .91756 Mdot
.24621 .63088 Mdot
.53434 .81565 Mdot
.66876 .36082 Mdot
.68894 .61871 Mdot
.21712 .07752 Mdot
.5145 .76924 Mdot
.55031 .19852 Mdot
.48412 .88391 Mdot
.35741 .79436 Mdot
.62798 .63278 Mdot
.25162 .61645 Mdot
.74298 .04526 Mdot
.28953 .95152 Mdot
.12 .94473 Mdot
.58879 .99979 Mdot
.78574 .90459 Mdot
.78505 .76146 Mdot
.35115 .47666 Mdot
.35723 .78881 Mdot
.22995 .30164 Mdot
.8595 .16946 Mdot
.96608 .20551 Mdot
.70753 .78198 Mdot
.82216 .83486 Mdot
.57259 .96533 Mdot
.27243 .69551 Mdot
.91882 .5083 Mdot
.33145 .9455 Mdot
.47585 .75543 Mdot
.01221 .17651 Mdot
.07103 .23107 Mdot
.55723 .55329 Mdot
.7866 .85747 Mdot
.58885 .54675 Mdot
.70759 .51257 Mdot
.42154 .57999 Mdot
.68349 .52316 Mdot
.49208 .98996 Mdot
.7279 .66641 Mdot
.92767 .98001 Mdot
.84288 .76084 Mdot
.17678 .58594 Mdot
.48777 .3057 Mdot
.16205 .07838 Mdot
.1427 .36964 Mdot
.8228 .04406 Mdot
.97067 .10984 Mdot
.44566 .4483 Mdot
.60808 .04452 Mdot
.43889 .47738 Mdot
.20192 .11842 Mdot
.41228 .35345 Mdot
.58385 .55216 Mdot
.6165 .95653 Mdot
.68044 .31008 Mdot
.24614 .96244 Mdot
.63953 .8583 Mdot
.80064 .51347 Mdot
.77984 .02681 Mdot
.39026 .56501 Mdot
.2363 .50444 Mdot
.33116 .06154 Mdot
.4918 .50593 Mdot
.63655 .997 Mdot
.71861 .34561 Mdot
.71987 .4517 Mdot
.28096 .81577 Mdot
.56821 .82912 Mdot
.26259 .91084 Mdot
.68681 .77135 Mdot
.01403 .12332 Mdot
.11498 .70561 Mdot
.23752 .4828 Mdot
.86375 .58425 Mdot
.08469 .02181 Mdot
.99362 .18806 Mdot
.9254 .18201 Mdot
.71847 .29842 Mdot
.15812 .50431 Mdot
.13197 .83386 Mdot
.59701 .40967 Mdot
.15476 .55134 Mdot
.12771 .36125 Mdot
.11516 .13026 Mdot
.72611 .90325 Mdot
.45273 .03531 Mdot
.65851 .98206 Mdot
.93908 .03749 Mdot
.76153 .6344 Mdot
.33732 .61013 Mdot
.50998 .13741 Mdot
.62517 .0346 Mdot
.59197 .67497 Mdot
.63831 .06618 Mdot
.42818 .5588 Mdot
.74201 .52633 Mdot
.30854 .56256 Mdot
.06287 .39807 Mdot
.57346 .85473 Mdot
.45426 .74266 Mdot
.34331 .49667 Mdot
.46877 .8286 Mdot
.72391 .56775 Mdot
.929 .97748 Mdot
.931 .55079 Mdot
.38826 .87365 Mdot
.89545 .43469 Mdot
.39621 .70671 Mdot
.92945 .80628 Mdot
.11987 .65184 Mdot
.82308 .99193 Mdot
.07276 .11371 Mdot
.30833 .54934 Mdot
.08274 .93603 Mdot
.25645 .092 Mdot
.09522 .53532 Mdot
.84348 .43013 Mdot
.85352 .65206 Mdot
.66846 .31059 Mdot
.71528 .70034 Mdot
.16405 .35317 Mdot
.32964 .51255 Mdot
.0606 .53953 Mdot
.0732 .58809 Mdot
.79875 .53851 Mdot
.3858 .92607 Mdot
.01899 .63911 Mdot
.85497 .86943 Mdot
.26396 .48322 Mdot
.24067 .98116 Mdot
.81306 .83914 Mdot
.12425 .85361 Mdot
.18583 .84528 Mdot
.73213 .48599 Mdot
.45759 .11511 Mdot
.23059 .21736 Mdot
.82283 .94471 Mdot
.30113 .45055 Mdot
.42871 .98224 Mdot
.09176 .47522 Mdot
.97587 .52669 Mdot
.86793 .72425 Mdot
.2387 .12082 Mdot
.71479 .08051 Mdot
.53881 .35833 Mdot
.82411 .92122 Mdot
.50537 .04045 Mdot
.40304 .86788 Mdot
.05046 .66884 Mdot
.3933 .66213 Mdot
.05439 .05557 Mdot
.61964 .50904 Mdot
.60501 .15213 Mdot
.14233 .82318 Mdot
.83973 .51541 Mdot
.77268 .48958 Mdot
.90076 .24947 Mdot
.38523 .04579 Mdot
.53422 .86102 Mdot
.81476 .51769 Mdot
.99279 .7712 Mdot
.69811 .06067 Mdot
.35524 .73426 Mdot
.08131 .42872 Mdot
.57658 .85909 Mdot
.61761 .61981 Mdot
.589 .50471 Mdot
.38006 .14297 Mdot
.34719 .6282 Mdot
.84483 .1839 Mdot
.69384 .26845 Mdot
.35065 .78104 Mdot
.81347 .34708 Mdot
.19685 .63983 Mdot
.50206 .6444 Mdot
.17133 .04459 Mdot
.64176 .52305 Mdot
.50256 .53156 Mdot
.79247 .96909 Mdot
.1698 .67769 Mdot
.68769 .52184 Mdot
.31591 .13152 Mdot
.02851 .71874 Mdot
.42375 .15252 Mdot
.8054 .62549 Mdot
.65793 .70326 Mdot
.24934 .00792 Mdot
.8246 .00831 Mdot
.44102 .3614 Mdot
.27661 .46364 Mdot
.58712 .14641 Mdot
.2419 .79404 Mdot
.42416 .34636 Mdot
.47944 .65453 Mdot
.82218 .69543 Mdot
.65656 .01326 Mdot
.78956 .49781 Mdot
.95791 .9182 Mdot
.4016 .49286 Mdot
.18368 .20462 Mdot
.15766 .25374 Mdot
.08431 .40427 Mdot
.00553 .44559 Mdot
.66746 .78567 Mdot
.74201 .32975 Mdot
.82555 .66356 Mdot
.17219 .40188 Mdot
.51229 .36078 Mdot
.53838 .09452 Mdot
.87442 .37508 Mdot
.53394 .53146 Mdot
.19049 .50844 Mdot
.47088 .03151 Mdot
.23073 .44643 Mdot
.45578 .61769 Mdot
.01542 .15082 Mdot
.83489 .56615 Mdot
.72094 .73908 Mdot
.56783 .10929 Mdot
.30442 .43219 Mdot
.26522 .96676 Mdot
.979 .46492 Mdot
.10714 .62806 Mdot
.03126 .12541 Mdot
.54076 .05003 Mdot
.00923 .89657 Mdot
.73629 .38896 Mdot
.85787 .21649 Mdot
.28909 .28472 Mdot
.44412 .58538 Mdot
.28843 .86322 Mdot
.7395 .5141 Mdot
.76979 .32586 Mdot
.02995 .89056 Mdot
.82303 .61982 Mdot
.72716 .68847 Mdot
.45879 .33351 Mdot
.06108 .16082 Mdot
.80352 .10666 Mdot
.43919 .06037 Mdot
.28147 .33393 Mdot
.68241 .72513 Mdot
.52081 .26119 Mdot
.22577 .90217 Mdot
.0184 .28473 Mdot
.46649 .13802 Mdot
.94124 .75488 Mdot
.28423 .81264 Mdot
.77148 .48652 Mdot
.27614 .31572 Mdot
.28797 .56072 Mdot
.74839 .7473 Mdot
.04325 .35953 Mdot
.33263 .35099 Mdot
.8168 .32915 Mdot
.47495 .9354 Mdot
.04182 .4749 Mdot
.54087 .08533 Mdot
.99024 .13552 Mdot
.1031 .9213 Mdot
.07804 .80861 Mdot
.85531 .39747 Mdot
.59137 .7923 Mdot
.7827 .3566 Mdot
.70481 .37097 Mdot
.14373 .54151 Mdot
.01662 .87689 Mdot
.62683 .99873 Mdot
.38731 .76441 Mdot
.3634 .19161 Mdot
.6775 .99895 Mdot
.17771 .8218 Mdot
.97447 .96181 Mdot
.38029 .98193 Mdot
.66236 .74664 Mdot
.40517 .06437 Mdot
.22018 .19982 Mdot
.7211 .26423 Mdot
.55081 .21922 Mdot
.65256 .64195 Mdot
.18175 .82698 Mdot
.17223 .7977 Mdot
.63657 .27298 Mdot
.03607 .61634 Mdot
.01117 .09366 Mdot
.01118 .58122 Mdot
.48639 .82067 Mdot
.89513 .72882 Mdot
.60751 .28039 Mdot
.51646 .32672 Mdot
.87501 .23652 Mdot
.71779 .96867 Mdot
.98064 .31886 Mdot
.8385 .58675 Mdot
.22812 .16057 Mdot
.55528 .06646 Mdot
.87935 .31741 Mdot
.07595 .16389 Mdot
.33136 .9137 Mdot
.78856 .12168 Mdot
.01422 .44732 Mdot
.12607 .30301 Mdot
.91756 .40247 Mdot
.10609 .36992 Mdot
.40388 .31919 Mdot
.66826 .48936 Mdot
.74503 .09091 Mdot
.98749 .88284 Mdot
.36192 .94468 Mdot
.20696 .07143 Mdot
.14563 .33997 Mdot
.59139 .85171 Mdot
.92123 .00272 Mdot
.46149 .27004 Mdot
.62971 .99349 Mdot
.81456 .41081 Mdot
.87238 .32605 Mdot
.03754 .55073 Mdot
.76666 .94089 Mdot
.49734 .93339 Mdot
.81103 .02371 Mdot
.45541 .5145 Mdot
.17626 .06197 Mdot
.68643 .10836 Mdot
.10439 .3605 Mdot
.18312 .14687 Mdot
.45908 .41935 Mdot
.26796 .55873 Mdot
.35498 .54877 Mdot
.97101 .26829 Mdot
.45243 .03034 Mdot
.95908 .50416 Mdot
.80352 .19925 Mdot
.2966 .72574 Mdot
.66036 .08088 Mdot
.50372 .22305 Mdot
.72176 .43917 Mdot
.87848 .46465 Mdot
.18572 .47821 Mdot
.53799 .16267 Mdot
.11184 .57034 Mdot
.75901 .83878 Mdot
.60845 .50924 Mdot
.04672 .53477 Mdot
.61792 .1155 Mdot
.8122 .44338 Mdot
.97715 .32751 Mdot
.3149 .50663 Mdot
.30075 .3173 Mdot
.97832 .41655 Mdot
.15966 .15933 Mdot
.27025 .1716 Mdot
.54027 .88743 Mdot
.17476 .22953 Mdot
.5459 .30524 Mdot
.88394 .17559 Mdot
.77457 .59681 Mdot
.92929 .55707 Mdot
.95595 .81948 Mdot
.73717 .70584 Mdot
.7171 .9022 Mdot
.17027 .68296 Mdot
.61768 .09086 Mdot
.66807 .45438 Mdot
.0949 .80771 Mdot
.02169 .97843 Mdot
.01621 .94516 Mdot
.30218 .37178 Mdot
.65874 .10282 Mdot
.67672 .53809 Mdot
.89312 .13425 Mdot
.4122 .50237 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`09ooooo`;o00000_ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02Oooool2o`0000;o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool00oooool2o`0000Sooooo00?o0000ooooooooool00oooool2o`0000Wo
oooo00?o0000ooooooooool00_ooool001kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Wooooo0_l00002ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo
0_l0000:ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`03ooooo`;o00002?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo
000Nooooo`03o`000?oooooooooo04gooooo0_l0002Vooooo`;o00004Oooool2o`0001Sooooo0_l0
000Sooooo`007_ooool00ol0003oooooooooo`0dooooo`;o00005oooool2o`0003[ooooo0_l00016
ooooo`;o0000=Oooool2o`0001Sooooo0_l0000Sooooo`007_ooool00ol0003oooooooooo`0doooo
o`;o0000AOooool2o`0000Sooooo0_l00002ooooo`;o0000A_ooool2o`0000_ooooo0_l0000Aoooo
o`;o0000?oooool2o`0001?ooooo000Nooooo`03o`000?oooooooooo07_ooooo0_l00008ooooo`;o
0000Eoooool2o`00017ooooo0_l0000Sooooo`;o00006_ooool2o`0001?ooooo000Nooooo`03o`00
0?oooooooooo01Oooooo0_l0000mooooo`;o0000__ooool2o`0002oooooo000Nooooo`03o`000?oo
oooooooo01Oooooo0_l0000mooooo`;o0000Toooool2o`0001Oooooo0_l0000Looooo`;o00003ooo
ool2o`0001;ooooo000Nooooo`03o`000?oooooooooo0>_ooooo0_l0000<ooooo`;o00002Oooool2
o`0001cooooo0_l0000?ooooo`;o00001?ooool2o`0000cooooo000Nooooo`03o`000?oooooooooo
08oooooo0_l00004ooooo`;o0000>_ooool2o`0002Kooooo0_l000000ooooooo0000o`00000koooo
o`;o00003?ooool001kooooo00?o0000ooooooooool0Soooool2o`0000Cooooo0_l0000`ooooo`?o
00001oooool2o`0000Wooooo0_l0000Nooooo`;o00001oooool2o`0001Cooooo0_l0000=ooooo`;o
00006oooool001kooooo00?o0000ooooooooool0D_ooool2o`00013ooooo0_l0000Yooooo`;o0000
=_ooool3o`0001;ooooo0_l0000Wooooo`;o00005?ooool2o`0000gooooo0_l000000ooooooo0000
o`00000?ooooo`;o00001oooool001kooooo00?o0000ooooooooool00_l0001@ooooo`;o00004?oo
ool2o`0002Wooooo0_l0000?ooooo`;o0000K?ooool2o`0001gooooo0_l0000?ooooo`;o00001ooo
ool001kooooo00?o0000ooooooooool01?l0000jooooo`;o0000H?ooool2o`0005Cooooo0_l0000?
ooooo`;o00001Oooool2o`0003Oooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0000`oooo
o`;o00002?ooool2o`00013ooooo0_l0000Wooooo`;o0000:?ooool2o`0001gooooo0_l0000Yoooo
o`;o00001oooool2o`0000oooooo0_l0000nooooo`007_ooool00ol0003oooooooooo`0dooooo`;o
00006_ooool2o`0000_ooooo0_l0000Jooooo`;o0000:?ooool2o`0000Oooooo0_l0000Dooooo`;o
00004?ooool2o`0001Oooooo0_l00004ooooo`;o0000D_ooool001kooooo0_l00019ooooo`;o0000
4oooool2o`0004gooooo0_l0000Vooooo`;o00007Oooool2o`0005;ooooo000Nooooo`03o`000?oo
oooooooo00kooooo0_l0000hooooo`;o0000oOooool001kooooo00?o0000ooooooooool03_ooool2
o`000?oooooo>?ooool001kooooo00?o0000ooooooooool09_ooool2o`0000gooooo0_l0000aoooo
o`;o00001Oooool2o`0001[ooooo0_l0001Booooo`;o0000I_ooool001kooooo00?o0000oooooooo
ool09_ooool2o`0000gooooo0_l0000Booooo`;o00007Oooool2o`0000Gooooo0_l0000?ooooo`;o
00002Oooool2o`0005;ooooo0_l0001Vooooo`007_ooool00ol0003oooooooooo`19ooooo`;o0000
=Oooool2o`0002kooooo0_l0000Iooooo`;o0000?Oooool2o`0002;ooooo0_l0000Gooooo`007_oo
ool00ol0003oooooooooo`0oooooo`;o0000F_ooool2o`0001?ooooo0_l00003ooooo`;o00005?oo
ool2o`0003Gooooo0_l00006ooooo`;o00008_ooool2o`0001Oooooo000Nooooo`03o`000?oooooo
oooo03oooooo0_l0001Jooooo`;o00006?ooool2o`0003cooooo0_l0000=ooooo`;o0000@oooool0
01kooooo00?o0000ooooooooool07oooool2o`00027ooooo0_l0000:ooooo`;o0000Xoooool2o`00
05;ooooo000Nooooo`03o`000?oooooooooo01oooooo0_l0000@ooooo`;o00003oooool2o`0000Co
oooo0_l00004ooooo`;o00006oooool2o`0006Kooooo0_l0000?ooooo`;o0000HOooool001kooooo
00?o0000ooooooooool0<Oooool2o`0000oooooo0_l00004ooooo`;o00008Oooool2o`0005[ooooo
0_l0000:ooooo`;o00003oooool2o`00067ooooo000Nooooo`03o`000?oooooooooo053ooooo0_l0
0009ooooo`;o0000Coooool2o`0001Wooooo0_l0001booooo`;o00002_ooool001kooooo00?o0000
ooooooooool0D?ooool2o`0000Sooooo0ol0001?ooooo`;o0000SOooool2o`0000[ooooo000Noooo
o`03o`000?oooooooooo00;o0000COooool2o`0000Wooooo0_l0001Yooooo`;o00009oooool2o`00
05Oooooo000Nooooo`03o`000?oooooooooo00;o0000COooool2o`0001Oooooo0_l00011ooooo`;o
00006?ooool2o`0002Oooooo0_l0001Gooooo`007_ooool00ol0003oooooooooo`1Xooooo`;o0000
@Oooool2o`0002Oooooo0_l0001aooooo`007_ooool2o`000=?ooooo1?l0001aooooo`007_ooool0
0ol0003oooooooooo`2jooooo`;o00000oooool2o`00017ooooo0_l0001cooooo`007_ooool00ol0
003oooooooooo`0Kooooo`;o0000WOooool2o`0000?ooooo0_l0000Jooooo`;o00009?ooool2o`00
04Cooooo000Nooooo`03o`000?oooooooooo01_ooooo0_l0000nooooo`;o0000Eoooool2o`0000ko
oooo0_l0000Eooooo`;o00009?ooool2o`0003Cooooo0_l0000>ooooo`007_ooool00ol0003ooooo
ooooo`0@ooooo`;o00000_ooool2o`0004Gooooo0_l0000dooooo`;o00001Oooool2o`0001[ooooo
0_l0000>ooooo`;o00008oooool2o`0004cooooo0_l0000>ooooo`007_ooool00ol0003ooooooooo
o`0@ooooo`;o00000_ooool2o`0007_ooooo0_l00005ooooo`;o0000:oooool2o`0002;ooooo0_l0
001Looooo`007_ooool00ol0003oooooooooo`0nooooo`;o00002Oooool2o`0006kooooo0_l0000:
ooooo`;o0000P?ooool001kooooo00?o0000ooooooooool00_l0000looooo`;o00002Oooool2o`00
00_ooooo0_l0000mooooo`;o00008_ooool2o`00047ooooo0_l00019ooooo`007_ooool00ol0003o
ooooooooo`02o`0000Cooooo0_l0001>ooooo`;o0000?Oooool2o`0004Gooooo0_l0000Nooooo`;o
00007_ooool2o`0002Wooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l0000Iooooo`;o0000
5Oooool2o`000:;ooooo0_l0000aooooo`;o00002oooool2o`0002Wooooo000Nooooo`03o`000?oo
oooooooo01oooooo1?l0000Eooooo`;o0000:Oooool2o`0000Wooooo0_l0002Oooooo`;o0000=_oo
ool001kooooo00?o0000ooooooooool07oooool2o`0001Sooooo0_l0000Xooooo`;o00002Oooool2
o`000:kooooo1?l0000Cooooo`;o00001oooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo
03Wooooo0_l0001Iooooo`;o00003?ooool2o`0007[ooooo1?l0000Cooooo`;o00001oooool2o`00
00Oooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l00020ooooo`;o00003?ooool2o`0007Go
oooo0_l00003ooooo`;o00009oooool001kooooo00?o0000ooooooooool04_ooool2o`0006?ooooo
0_l0001cooooo`;o0000:oooool2o`0000?ooooo0_l0000Wooooo`007_ooool00ol0003ooooooooo
o`0gooooo`;o0000?_ooool2o`0001Gooooo0_l0000[ooooo`;o0000;oooool2o`0005Wooooo000N
ooooo`;o00000_ooool2o`0003Cooooo0_l0000[ooooo`;o0000:?ooool2o`0002_ooooo0_l00004
ooooo`;o0000@Oooool2o`00047ooooo000Nooooo`04o`000?ooooooooooooooo`;o0000HOooool2
o`00023ooooo0_l0000iooooo`;o0000=_ooool2o`0000Wooooo0_l00011ooooo`007_ooool00ol0
003oooooooooo`0eooooo`;o0000Coooool2o`0005kooooo0_l0000Aooooo`;o0000C?ooool001ko
oooo00Co0000ooooool0003o00003oooool2o`0001kooooo0_l00003ooooo`;o00003oooool2o`00
09kooooo0_l0001Fooooo`;o00001oooool001kooooo00Co0000ooooool0003o00003oooool2o`00
00?ooooo0_l0000Iooooo`;o00005?ooool2o`0006?ooooo0_l00010ooooo`;o0000Coooool2o`00
00Oooooo000Nooooo`03o`000?oooooooooo01Gooooo0_l0002Dooooo`;o00004_ooool2o`0002co
oooo0_l0001=ooooo`;o00002Oooool001kooooo00?o0000ooooooooool0_oooool2o`0005;ooooo
0_l0000Wooooo`;o00002Oooool001kooooo00?o0000ooooooooool05Oooool2o`0003gooooo0_l0
001Zooooo`;o0000DOooool2o`0003;ooooo000Nooooo`03o`000?oooooooooo00;o00004oooool2
o`0003gooooo0_l0001Zooooo`;o0000COooool2o`0000[ooooo0_l0000Zooooo`007_ooool00ol0
003oooooooooo`02o`0000[ooooo0_l0002oooooo`;o00001?ooool2o`0003Kooooo1_l00004oooo
o`;o00001?ooool2o`0000[ooooo0_l0000Nooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o
0000S_ooool2o`0000Sooooo0_l0000Uooooo`;o00001?ooool2o`0003Kooooo1?l00006ooooo`;o
00004?ooool4o`0001cooooo000Nooooo`03o`000?oooooooooo053ooooo0_l0001:ooooo`;o0000
2?ooool2o`0001_ooooo0_l00013ooooo`;o00001Oooool2o`0001Sooooo0_l0000Looooo`007_oo
ool00ol0003oooooooooo`11ooooo`;o00003Oooool2o`00077ooooo0_l00013ooooo`;o00001Ooo
ool2o`0000?ooooo0_l0000Yooooo`;o00001_ooool001kooooo00?o0000ooooooooool06?ooool2
o`0002Oooooo0_l0000Jooooo`;o00004oooool2o`000:3ooooo0_l0000Yooooo`;o00001_ooool0
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000
ooooooooool06?ooool2o`0001Oooooo0_l0000Zooooo`;o00004oooool2o`0002Gooooo0_l00003
ooooo`;o00005oooool2o`0001[ooooo0_l0001booooo`000oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003ooooooooo
o`0Sooooo`;o00003?ooool2o`0006Kooooo0_l00003ooooo`;o00001oooool2o`0000kooooo0_l0
000Jooooo`;o0000L_ooool000?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7ok^k^00Oooooo0ol0000Sooooo`;o00007_ooool2o`0006;ooooo0_l00006ooooo`;o0000D?oo
ool2o`0004Cooooo0003ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^
kP06ooooo`03o`000?oooooooooo04?ooooo0_l0001Tooooo`;o00001?ooool2o`00053ooooo0_l0
0014ooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Ooo
ool00ol0003oooooooooo`0booooo`;o00001?ooool2o`0006oooooo0_l0001Zooooo`;o00007ooo
ool2o`0000oooooo0003ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo03;ooooo0_l00004ooooo`;o0000foooool2o`0001oooooo0_l0
000?ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RH
oa0@4006ooooo`03o`000?oooooooooo08_ooooo0_l0000Qooooo`;o0000Uoooool000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003o
ooooooooo`2;ooooo`;o00008Oooool2o`0003[ooooo1?l0000Uooooo`;o0000<_ooool001kooooo
00?o0000ooooooooool0Aoooool2o`0003;ooooo0_l0000[ooooo`;o00001Oooool2o`0003Wooooo
1?l0000Uooooo`;o00009?ooool2o`0000cooooo000Nooooo`03o`000?oooooooooo04Oooooo0_l0
000booooo`;o0000:oooool2o`0000Gooooo0_l00028ooooo`;o00003?ooool001kooooo00?o0000
ooooooooool0X?ooool2o`000:Gooooo000Nooooo`03o`000?oooooooooo07_ooooo0_l0000Soooo
o`;o0000YOooool001kooooo00?o0000ooooooooool04oooool2o`0000Gooooo0_l0000;ooooo`;o
00003?ooool2o`0004Cooooo0_l0002]ooooo`;o00003?ooool2o`0000gooooo000Nooooo`03o`00
0?oooooooooo01?ooooo0_l00005ooooo`;o00002oooool2o`0000cooooo0_l0002mooooo`;o0000
=?ooool2o`0000cooooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`1;ooooo`;o0000??oo
ool2o`0002[ooooo0_l0000=ooooo`;o0000;_ooool2o`0002;ooooo0_l0000Mooooo`;o00003_oo
ool001kooooo00?o0000ooooooooool0Boooool2o`0003cooooo0_l0000Zooooo`;o00001oooool2
o`0000Cooooo0_l0001Booooo`;o00007Oooool2o`0000kooooo000Nooooo`03o`000?oooooooooo
04Sooooo0_l00018ooooo`;o0000:_ooool2o`0008Oooooo000Nooooo`03o`000?oooooooooo037o
oooo0_l0000Eooooo`;o0000B?ooool2o`0008Cooooo0_l00002ooooo`;o0000:Oooool001kooooo
00?o0000ooooooooool08?ooool2o`0000oooooo0_l00025ooooo`;o0000Boooool2o`00017ooooo
0_l00002ooooo`;o00000oooool2o`0002Cooooo000Nooooo`;o00008Oooool2o`0009Kooooo0_l0
000Uooooo`;o00009?ooool2o`0001[ooooo0_l0000;ooooo`;o00005oooool001kooooo00?o0000
ooooooooool0;oooool2o`0009kooooo0_l0000>ooooo`;o0000>_ooool4o`0000oooooo0_l0000G
ooooo`007_ooool00ol0003oooooooooo`0_ooooo`;o0000W_ooool2o`0004[ooooo1?l0000Xoooo
o`007_ooool00ol0003oooooooooo`2Uooooo`;o0000X?ooool001kooooo00?o0000ooooooooool0
>_ooool2o`0006Wooooo0_l0000oooooo`;o0000Goooool001kooooo00?o0000ooooooooool0>_oo
ool3o`000:3ooooo0_l00007ooooo`;o00002oooool2o`0004?ooooo0_l0000=ooooo`007_ooool0
0ol0003oooooooooo`0kooooo`;o0000EOooool2o`0004Wooooo0_l0000Dooooo`;o00006?ooool2
o`0002Wooooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`2Booooo`;o0000:Oooool2o`00
00cooooo0_l00010ooooo`;o0000>?ooool001kooooo00?o0000ooooooooool0^_ooool2o`000003
ooooool0003o000000cooooo0_l0001jooooo`007_ooool00ol0003oooooooooo`09ooooo`;o0000
7oooool2o`0008kooooo0_l00005ooooo`;o00001Oooool2o`0000cooooo0_l0001_ooooo`007_oo
ool00ol0003oooooooooo`09ooooo`;o00007oooool2o`0009Gooooo0_l00005ooooo`;o00003?oo
ool2o`0001kooooo0_l0001?ooooo`007_ooool00ol0003oooooooooo`02ooooo`;o0000E_ooool3
o`0001kooooo0_l0000?ooooo`;o0000J?ooool2o`0004oooooo000Nooooo`03o`000?oooooooooo
00;ooooo0_l0001Fooooo`?o00007_ooool2o`0000oooooo0_l0000^ooooo`;o0000Boooool2o`00
01;ooooo0_l00005ooooo`;o00008Oooool001kooooo00?o0000ooooooooool0_?ooool2o`0004_o
oooo0_l0000Booooo`;o00001Oooool2o`00027ooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0Poooool2o`0001Sooooo0_l00006ooooo`;o0000?_oo
ool2o`00063ooooo000Nooooo`;o0000B?ooool2o`0003[ooooo0_l0000Hooooo`?o00001Oooool2
o`00013ooooo0_l0000Dooooo`;o00005_ooool2o`00063ooooo000Nooooo`03o`000?oooooooooo
02Gooooo0_l0000Pooooo`;o0000DOooool2o`0000;ooooo0_l0000=ooooo`;o00002?ooool2o`00
01Cooooo0_l0001hooooo`007_ooool00ol0003oooooooooo`0Uooooo`;o0000Loooool2o`00017o
oooo0_l0000Yooooo`;o0000KOooool001kooooo00?o0000ooooooooool0Woooool2o`0003Cooooo
0_l000001?oooooo0000o`000?l0000Booooo`;o0000F?ooool001kooooo00?o0000ooooooooool0
>oooool2o`0006;ooooo0ol0000cooooo`;o00000_ooool2o`0001;ooooo0_l0000mooooo`;o0000
6Oooool001kooooo00?o0000ooooooooool0>oooool2o`0001Wooooo0_l00006ooooo`;o0000@?oo
ool2o`0007Sooooo0_l0000@ooooo`;o00006Oooool001kooooo00?o0000ooooooooool0E_ooool2
o`0000Kooooo0_l0000Kooooo`;o00000_ooool2o`0009Wooooo0_l0000Oooooo`;o00002_ooool0
01kooooo00?o0000ooooooooool0Noooool6o`00017ooooo0_l0002Uooooo`Co00002_ooool001ko
oooo00?o0000ooooooooool0:?ooool2o`0002gooooo0_l0000Tooooo`;o00004oooool2o`00013o
oooo0_l0001@ooooo`;o00008?ooool2o`0001oooooo0_l0000<ooooo`007_ooool00ol0003ooooo
ooooo`0Xooooo`;o0000;Oooool2o`0004_ooooo0_l0000Booooo`;o0000<oooool2o`0000?ooooo
0_l00002ooooo`;o00003Oooool2o`00017ooooo0_l0000Pooooo`;o00002oooool001kooooo00?o
0000ooooooooool0TOooool2o`0002Gooooo0_l00009ooooo`;o0000:?ooool2o`0000?ooooo0_l0
000Aooooo`;o00000_ooool2o`0002oooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`0<
ooooo`;o00001_ooool2o`00047ooooo0_l0000hooooo`;o0000<?ooool2o`0004Cooooo0_l0000l
ooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o00001_ooool2o`00047ooooo0_l0003^oooo
o`007_ooool00ol0003oooooooooo`0[ooooo`;o00005Oooool2o`00037ooooo0_l00011ooooo`;o
0000SOooool001kooooo00?o0000ooooooooool0:oooool2o`0001Gooooo0_l0000aooooo`;o0000
@Oooool2o`0002cooooo0_l0000Oooooo`;o0000?_ooool001kooooo00?o0000ooooooooool0Q_oo
ool2o`0005kooooo0_l0000Looooo`;o000000?oooooo`000?l00000?_ooool001kooooo0_l0000g
ooooo`;o0000<?ooool2o`0001cooooo0_l0001looooo`;o0000<oooool2o`0000cooooo000Noooo
o`03o`000?oooooooooo037ooooo0_l00003ooooo`;o00005_ooool2o`0000kooooo0_l00008oooo
o`;o00006?ooool2o`0001oooooo0_l0001Hooooo`;o00009?ooool2o`0001Cooooo0_l0000<oooo
o`007_ooool00ol0003oooooooooo`0aooooo`;o00006oooool2o`0000kooooo0_l0000Rooooo`;o
00007oooool2o`0005Gooooo0_l000000ooooooo0000o`00000Tooooo`;o00004_ooool2o`0000ko
oooo000Nooooo`03o`000?oooooooooo00[ooooo0_l0000Booooo`;o00001Oooool2o`00047ooooo
0_l0000hooooo`;o00001oooool2o`0002Sooooo0_l0000Sooooo`;o0000>oooool2o`0000Cooooo
0_l00008ooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o00004_ooool2o`0000Gooooo0_l0
000Uooooo`;o00006_ooool2o`0000gooooo0_l0000Booooo`;o00005Oooool2o`0000Oooooo0_l0
000Xooooo`;o0000I_ooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo04cooooo0_l0000Y
ooooo`;o00004_ooool2o`0004Kooooo0_l0001booooo`007_ooool00ol0003oooooooooo`0Noooo
o`;o00002_ooool2o`000:Oooooo0_l0000Uooooo`;o0000Boooool001kooooo00?o0000oooooooo
ool07_ooool2o`0000[ooooo0_l0000booooo`;o00006Oooool2o`0006Kooooo0_l0000Gooooo`;o
0000Boooool001kooooo00?o0000ooooooooool0G_ooool2o`0001Oooooo1?l0001Sooooo`;o0000
00?oooooo`000?l000002oooool2o`0002Sooooo0_l0000]ooooo`007_ooool00ol0003ooooooooo
o`1`ooooo`;o00001Oooool2o`0006Gooooo0_l0000>ooooo`;o0000:?ooool2o`0002gooooo000N
ooooo`03o`000?oooooooooo04kooooo0_l0000Kooooo`;o00000oooool2o`0003Oooooo0_l0002L
ooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o0000@Oooool2o`0001_ooooo0_l00008oooo
o`;o0000<_ooool2o`0008kooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o
0000J?ooool2o`0002_ooooo0_l00017ooooo`;o0000C?ooool2o`0000cooooo000Nooooo`?o0000
X_ooool2o`0004Oooooo0_l0001Jooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool3o`0001Gooooo0_l0002Oooooo`;o0000
?Oooool2o`00053ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0@ooooo`;o00000oooool2o`0009oooooo
0_l0000mooooo`;o00006oooool2o`0003?ooooo0003ooooo`05oa0@4?ooooooooooooooool@4100
2oooool5o`0000Kooooo0ol0000@ooooo`;o00005oooool2o`0001Kooooo0_l0001iooooo`;o0000
E?ooool2o`0003?ooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgM
ooooool00007ooooo`03o`000?oooooooooo01Oooooo0_l0000@ooooo`;o00002Oooool4o`0000Wo
oooo0_l0000looooo`;o0000>oooool2o`0006Sooooo0_l0000Oooooo`000oooool01Ol0003ooooo
oooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`04oooo
o`;o00004Oooool2o`0001_ooooo1?l00017ooooo`;o00004?ooool2o`0004?ooooo0_l0000Soooo
o`;o0000:Oooool2o`0001oooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omg
MgOoc<c<o`000007ooooo`03o`000?oooooooooo00Cooooo0_l0002;ooooo`;o0000:oooool2o`00
01Kooooo0_l0000Sooooo`;o0000B_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0Doooool2o`0002;ooooo0_l00006oooo
o`;o00006Oooool2o`0002;ooooo0_l00015ooooo`;o0000@?ooool000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0Doooool2o`00
02;ooooo0_l00006ooooo`;o00006Oooool2o`0006Wooooo0_l0000cooooo`;o00002oooool001ko
oooo00?o0000ooooooooool07_ooool2o`00077ooooo0_l0002:ooooo`;o00006oooool2o`0000_o
oooo000Nooooo`03o`000?oooooooooo01kooooo0_l0001aooooo`;o00001Oooool2o`0008?ooooo
0_l0000Xooooo`007_ooool00ol0003oooooooooo`2Hooooo`;o000000?oooooo`000?l00000F?oo
ool2o`00053ooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l00023ooooo`;o0000;Oooool2
o`0000?ooooo0_l0000Nooooo`;o00001?ooool2o`00053ooooo000Nooooo`03o`000?oooooooooo
01Kooooo0_l0002booooo`;o00000oooool2o`0001kooooo0_l0000Mooooo`;o0000=oooool001ko
oooo00?o0000ooooooooool0Goooool4o`0002Wooooo0_l00020ooooo`;o00001Oooool2o`0000So
oooo0_l0000Vooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o0000BOooool4o`0000?ooooo
0_l0000Tooooo`;o0000Qoooool2o`0000Sooooo0_l0000Fooooo`;o00003_ooool001kooooo00?o
0000ooooooooool05?ooool2o`00053ooooo0_l0000Booooo`;o00000_ooool2o`0006Oooooo0_l0
001>ooooo`;o00003_ooool001kooooo00?o0000ooooooooool05?ooool2o`0006Cooooo0_l00002
ooooo`;o0000Ioooool2o`0001_ooooo0_l00011ooooo`007_ooool3o`000003ooooool0003o0000
017ooooo0_l0000aooooo`;o00005?ooool2o`0001;ooooo0_l0002Aooooo`;o0000@Oooool001ko
oooo0ol000000ooooooo0000o`000004ooooo`;o0000?_ooool2o`0000Kooooo0_l0000<ooooo`;o
00004_ooool2o`0001[ooooo0_l00023ooooo`;o0000<oooool001kooooo0_l00008ooooo`;o0000
1oooool2o`0000cooooo0_l0000_ooooo`;o00003Oooool2o`0002gooooo0_l0001Gooooo`;o0000
:_ooool2o`0003?ooooo000Nooooo`04o`000?oooooo0000o`0000oooooo0_l0000<ooooo`;o0000
?_ooool2o`0007Gooooo0_l0000?ooooo`;o0000?oooool2o`0001kooooo000Nooooo`04o`000?oo
oooo0000o`0007Wooooo0_l0001Iooooo`;o0000D?ooool2o`0001kooooo000Nooooo`03o`000?oo
oooooooo07[ooooo0_l00016ooooo`;o0000Poooool001kooooo00?o0000ooooooooool0E_ooool2
o`0006[ooooo0_l0001Eooooo`;o00007oooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo
05Kooooo0_l00019ooooo`;o0000M_ooool2o`0001oooooo0ol0000:ooooo`007_ooool00ol0003o
ooooooooo`0=ooooo`;o0000E?ooool2o`0003cooooo0_l00008ooooo`;o0000L?ooool2o`0001co
oooo0ol00009ooooo`007_ooool00ol0003oooooooooo`09ooooo`;o00000_ooool2o`0005Cooooo
0_l00016ooooo`;o0000KOooool2o`000003ooooool0003o000001gooooo0_l00009ooooo`007_oo
ool00ol0003oooooooooo`09ooooo`;o00003oooool2o`0005;ooooo0_l0000Kooooo`;o00001Ooo
ool2o`0000Wooooo0_l00015ooooo`;o0000;Oooool2o`0000Gooooo0_l0000[ooooo`007_ooool0
0ol0003oooooooooo`0Jooooo`;o00007?ooool2o`0002Cooooo0_l0000>ooooo`;o00006oooool2
o`0000Gooooo0_l00009ooooo`;o00006Oooool2o`0000[ooooo0_l0000Nooooo`;o0000;Oooool2
o`0002;ooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`0hooooo`;o00003oooool2o`00
00Oooooo0_l0000:ooooo`;o0000F?ooool2o`0000[ooooo0_l0000Yooooo`;o00005?ooool2o`00
033ooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`0/ooooo`Co00006Oooool2o`0000Oo
oooo0_l0000Jooooo`;o0000N_ooool2o`0000?ooooo0_l00006ooooo`;o00003?ooool2o`00043o
oooo000Nooooo`03o`000?oooooooooo02cooooo1?l0000nooooo`;o00007Oooool2o`00037ooooo
0_l0000Cooooo`;o00004oooool2o`0000_ooooo0ol00014ooooo`;o00001oooool001kooooo00?o
0000ooooooooool0O_ooool2o`0000[ooooo0_l000000ooooooo0000o`00000aooooo`;o00004ooo
ool2o`0000Cooooo0_l0000Jooooo`?o0000A?ooool2o`0000Oooooo000Nooooo`03o`000?oooooo
oooo07kooooo0_l0000:ooooo`;o0000?_ooool2o`0000oooooo0_l0001Zooooo`007_ooool00ol0
003oooooooooo`1[ooooo`;o0000GOooool2o`00037ooooo0_l00018ooooo`007_ooool2o`0006co
oooo0_l0000Eooooo`;o0000NOooool2o`0004Sooooo000Nooooo`03o`000?oooooooooo02oooooo
0_l0000Hooooo`;o00006Oooool2o`0001cooooo0_l0000_ooooo`;o00001_ooool2o`0007Oooooo
0_l0000Aooooo`007_ooool00ol0003oooooooooo`0_ooooo`;o00002Oooool2o`0000gooooo0_l0
000Gooooo`Co00004?ooool2o`0002Cooooo0_l0000Booooo`;o000000?oooooo`000?l000001_oo
ool2o`0006[ooooo0_l0000;ooooo`;o00004Oooool001kooooo00?o0000ooooooooool0>_ooool2
o`0002Kooooo0_l0000Booooo`;o00009?ooool2o`0001;ooooo0_l0000@ooooo`;o000000?ooooo
o`000?l00000H?ooool2o`0001kooooo000Nooooo`03o`000?oooooooooo06Oooooo0_l0000Woooo
o`;o0000<?ooool2o`000003ooooool0003o000001_ooooo0_l00008ooooo`;o00004_ooool2o`00
04Gooooo000Nooooo`03o`000?oooooooooo06Oooooo0_l0000Wooooo`;o00007oooool2o`0002oo
oooo0_l00008ooooo`;o00004_ooool2o`0000?ooooo0_l00006ooooo`;o0000>?ooool001kooooo
00?o0000ooooooooool05oooool2o`0009Sooooo0_l0000cooooo`;o00007Oooool2o`0000Kooooo
0_l0000hooooo`007_ooool00ol0003oooooooooo`0Gooooo`;o00003oooool2o`0001;ooooo0_l0
002?ooooo`;o00002oooool3o`0000Wooooo0_l0001Oooooo`007_ooool00ol0003oooooooooo`0X
ooooo`;o00004_ooool2o`00077ooooo0_l0000Looooo`;o00000_ooool2o`0000Oooooo0ol0000@
ooooo`;o00004Oooool2o`0003Oooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`2_oooo
o`;o00008?ooool2o`0001[ooooo0_l0000=ooooo`;o00000_ooool2o`0003Oooooo0_l0000<oooo
o`007_ooool00ol0003oooooooooo`2Oooooo`;o00002?ooool2o`00057ooooo1?l00017ooooo`00
7_ooool00ol0003oooooooooo`0;ooooo`;o00003_ooool2o`0001Gooooo0_l0001Dooooo`;o0000
5Oooool2o`0000Sooooo0_l00007ooooo`;o0000A?ooool2o`0000Cooooo0_l00017ooooo`007_oo
ool00ol0003oooooooooo`06ooooo`;o00000oooool2o`0000?ooooo0_l00009ooooo`;o00005Ooo
ool2o`0005Cooooo0_l0000Xooooo`;o00009?ooool2o`0001Cooooo1?l00006ooooo`;o00001_oo
ool2o`0004Gooooo000Nooooo`03o`000?oooooooooo00Kooooo0_l00008ooooo`;o00006Oooool2
o`0009;ooooo0_l0000Gooooo`;o00005?ooool4o`0000kooooo0_l0000@ooooo`;o0000<oooool0
01kooooo00?o0000ooooooooool08_ooool2o`0000Oooooo0_l0002Booooo`;o0000DOooool2o`00
03?ooooo000Nooooo`03o`000?oooooooooo02;ooooo0_l0000Jooooo`;o0000;oooool2o`0002oo
oooo0_l0000Iooooo`;o0000R_ooool001kooooo0_l00009ooooo`;o00009?ooool2o`0000kooooo
0_l0000Pooooo`;o000000?oooooo`000?l000002_ooool2o`0000Kooooo0_l0000Wooooo`;o0000
6Oooool2o`0002Cooooo0_l00018ooooo`;o00006_ooool001kooooo00?o0000ooooooooool02?oo
ool2o`0001gooooo0_l00005ooooo`;o0000<?ooool2o`000003ooooool0003o000001;ooooo0_l0
000hooooo`;o00001oooool2o`0002Gooooo0_l00018ooooo`;o00006_ooool001kooooo00?o0000
ooooooooool09oooool2o`0008Sooooo0_l00007ooooo`;o0000K_ooool2o`0001_ooooo000Noooo
o`03o`000?oooooooooo00Wooooo0_l00018ooooo`;o00000_ooool2o`000003ooooool0003o0000
02_ooooo0_l0002Qooooo`;o00006oooool001kooooo00?o0000ooooooooool02Oooool2o`0004So
oooo0_l00002ooooo`;o000000?oooooo`000?l000001?ooool2o`0002Gooooo0_l0000[ooooo`;o
00005_ooool2o`0007Wooooo000Nooooo`03o`000?oooooooooo063ooooo0_l0000@ooooo`;o0000
1oooool2o`0003Oooooo0_l0000Fooooo`;o0000?Oooool2o`0003[ooooo000Nooooo`03o`000?oo
oooooooo023ooooo0_l0001@ooooo`;o00001oooool2o`0006[ooooo0_l0000Rooooo`;o0000>_oo
ool001kooooo00?o0000ooooooooool08?ooool2o`000:Kooooo0_l0000Mooooo`;o0000:?ooool2
o`0003Cooooo000Nooooo`03o`000?oooooooooo04Kooooo0_l00020ooooo`;o0000;_ooool2o`00
01Oooooo0_l0000dooooo`007_ooool00ol0003oooooooooo`16ooooo`;o0000/?ooool2o`00047o
oooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`02o`0008?ooooo0_l0001Mooooo`;o0000
EOooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00;o0000Poooool2o`0000Gooooo0_l0
001Fooooo`;o0000;oooool2o`00033ooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0000O
ooooo`;o0000EOooool2o`0007kooooo0_l00007ooooo`;o00006oooool2o`0001?ooooo000Noooo
o`03o`000?oooooooooo01Cooooo0_l0000Oooooo`;o0000eOooool2o`00013ooooo0_l00003oooo
o`;o00003Oooool2o`0001?ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo02Sooooo0_l0003d
ooooo`;o00000oooool2o`0002;ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo02Sooooo0_l0
001booooo`;o0000F_ooool2o`0004gooooo0003ooooo`05oa0@4?ooooooooooooooool@41002ooo
ool01Ol0003ooooooooooooooooo000000Gooooo1?l0000Oooooo`;o0000C?ooool2o`0002Kooooo
0_l00005ooooo`;o0000F_ooool2o`0004gooooo0003ooooo`05o`000?ooooooooooooooool00000
2oooool01Ol0003oV9RHoooooonHV9So8B4Q00Gooooo0_l00004ooooo`;o00006oooool2o`0004co
oooo0_l0000Vooooo`;o0000/?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05
o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`02ooooo`;o0000<Oooool2o`00
0?gooooo0_l0000Aooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7
Qoooool02?ooool00ol0003oooooooooo`0Aooooo`;o00008_ooool2o`0003?ooooo0_l0000Goooo
o`;o0000[Oooool4o`00017ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooM
gMgo410@oiRHV008ooooo`03o`000?oooooooooo017ooooo0_l0000Fooooo`;o0000>oooool2o`00
00;ooooo0_l0000Gooooo`;o0000@Oooool2o`0006[ooooo0_l0000Cooooo`000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`08
ooooo`;o00007oooool2o`0002?ooooo0_l0000Fooooo`;o0000G_ooool2o`0007oooooo000Noooo
o`03o`000?oooooooooo00Sooooo0_l00014ooooo`;o00007_ooool2o`00023ooooo0_l0000]oooo
o`;o00006oooool2o`0006Wooooo000Nooooo`03o`000?oooooooooo04kooooo0_l0000Nooooo`;o
00008?ooool2o`0002gooooo0_l00004ooooo`;o00005Oooool2o`0002Wooooo0_l0000aooooo`;o
00002oooool001kooooo00?o0000ooooooooool0C_ooool2o`0002?ooooo0_l0000?ooooo`;o0000
?oooool2o`0003_ooooo0_l00003ooooo`;o0000<Oooool2o`0000_ooooo000Nooooo`03o`000?oo
oooooooo01oooooo0_l0000:ooooo`;o0000@?ooool2o`0000Cooooo0_l0000?ooooo`;o0000O?oo
ool2o`0000Kooooo0_l0000kooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o00002_ooool2
o`0001oooooo0_l0000Oooooo`;o00005Oooool2o`0000Cooooo0_l00019ooooo`;o0000<oooool2
o`0003_ooooo000Nooooo`;o0000COooool2o`0003Kooooo0_l00004ooooo`;o0000??ooool2o`00
00_ooooo0_l00009ooooo`;o00004Oooool2o`0005;ooooo000Nooooo`;o0000bOooool2o`0001Ko
oooo0_l0000Aooooo`;o00001Oooool2o`0004_ooooo000Nooooo`03o`000?oooooooooo00;ooooo
0_l0000hooooo`;o00006oooool2o`0002Sooooo0_l0000^ooooo`;o0000AOooool2o`0000[ooooo
0_l0000oooooo`007_ooool00ol0003oooooooooo`02ooooo`;o0000<?ooool2o`0000Kooooo0_l0
000Hooooo`;o000000?oooooo`000?l00000:?ooool2o`0002kooooo0_l0000Kooooo`;o00007_oo
ool2o`0001Cooooo0_l0000aooooo`;o00003?ooool001kooooo00?o0000ooooooooool0=?ooool2
o`00023ooooo0_l0000fooooo`;o00003oooool2o`0002oooooo0_l0000Nooooo`;o0000;?ooool2
o`0001Wooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`1Looooo`;o0000<?ooool2o`00
00oooooo0_l0001mooooo`;o00009oooool001kooooo0_l0000Tooooo`;o0000=oooool2o`0009Ko
oooo0_l0000Kooooo`;o0000=?ooool001kooooo00?o0000ooooooooool08oooool2o`0004Kooooo
0_l0000[ooooo`;o0000F_ooool2o`0001Cooooo0_l00005ooooo`;o00003oooool2o`0000oooooo
0_l0000Booooo`007_ooool00ol0003oooooooooo`0oooooo`;o0000:_ooool2o`0002_ooooo0_l0
001`ooooo`;o00005_ooool2o`0000oooooo0_l0000Booooo`007_ooool00ol0003oooooooooo`0o
ooooo`;o0000>oooool2o`0005Gooooo0_l0001booooo`007_ooool00ol0003oooooooooo`03oooo
o`;o00007oooool3o`0005Gooooo0_l0001Eooooo`;o0000<oooool2o`0003gooooo000Nooooo`03
o`000?oooooooooo00?ooooo0_l00007ooooo`;o00005_ooool3o`00047ooooo0_l0001oooooo`;o
00007Oooool2o`0002Wooooo0_l0000Booooo`007_ooool00ol0003oooooooooo`0<ooooo`;o0000
6_ooool2o`0003kooooo0_l0000@ooooo`;o0000KOooool2o`0004Sooooo0_l0000Booooo`007_oo
ool00ol0003oooooooooo`0Looooo`;o00002_ooool2o`0001Kooooo0_l0000hooooo`;o0000@?oo
ool2o`0007Wooooo0ol0000=ooooo`007_ooool00ol0003oooooooooo`0Looooo`;o00005Oooool2
o`0000_ooooo0_l0000Oooooo`;o0000FOooool2o`0007Wooooo0ol0000=ooooo`007_ooool00ol0
003oooooooooo`0cooooo`;o00002?ooool2o`0001kooooo0_l00002ooooo`;o0000M?ooool2o`00
06kooooo000Nooooo`;o0000=?ooool2o`0000Sooooo0_l0000Nooooo`;o0000LOooool2o`0000Go
oooo0_l0001^ooooo`007_ooool2o`0003Cooooo0_l0000Hooooo`;o00007?ooool2o`0004kooooo
0_l0000Cooooo`;o00001_ooool2o`0006gooooo000Nooooo`03o`000?oooooooooo04gooooo0_l0
000Looooo`;o00001?ooool2o`0004Sooooo0_l0000Kooooo`;o00003_ooool2o`0005gooooo000N
ooooo`03o`000?oooooooooo077ooooo0_l0001eooooo`;o00005_ooool2o`0004Gooooo000Noooo
o`03o`000?oooooooooo00oooooo0_l00005ooooo`;o0000:_ooool2o`0000gooooo0_l000000ooo
oooo0000o`000002ooooo`;o00005oooool2o`0008gooooo0_l00005ooooo`;o0000?_ooool001ko
oooo00?o0000ooooooooool03oooool2o`0000Gooooo0_l0000Sooooo`;o00001Oooool2o`0000go
oooo0_l000000ooooooo0000o`000002ooooo`;o00007?ooool2o`0003oooooo0_l00008ooooo`;o
00001Oooool2o`0003gooooo0_l0000nooooo`007_ooool2o`0003cooooo0_l00005ooooo`;o0000
<_ooool2o`0003oooooo0_l00008ooooo`;o00001Oooool2o`0001[ooooo0_l0000cooooo`;o0000
4Oooool3o`0001Sooooo000Nooooo`03o`000?oooooooooo027ooooo0_l0000Oooooo`;o0000S_oo
ool2o`0000[ooooo0_l00004ooooo`;o0000<oooool2o`00017ooooo0ol0000Hooooo`007_ooool0
0ol0003oooooooooo`0Qooooo`;o0000F_ooool2o`0002oooooo0_l0000Rooooo`;o00002_ooool2
o`0000cooooo0_l0001Iooooo`007_ooool00ol0003oooooooooo`1mooooo`;o0000;oooool2o`00
03cooooo0_l0001Iooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o0000Qoooool2o`000:Oo
oooo000Nooooo`03o`000?oooooooooo01Gooooo0_l00027ooooo`;o0000Yoooool001kooooo00?o
0000ooooooooool01Oooool2o`000=gooooo0_l0001Qooooo`007_ooool00ol0003oooooooooo`05
ooooo`;o00008Oooool2o`0007_ooooo0_l0000mooooo`;o0000=Oooool2o`0002[ooooo000Noooo
o`03o`000?oooooooooo02Sooooo0_l0000booooo`;o0000Aoooool2o`0003?ooooo0_l0000joooo
o`;o00000oooool2o`0002[ooooo000Nooooo`03o`000?oooooooooo02oooooo0_l0000[ooooo`;o
0000O?ooool2o`0003[ooooo0_l00007ooooo`;o00009_ooool001kooooo00?o0000ooooooooool0
;oooool2o`0005[ooooo0_l00012ooooo`;o0000C_ooool2o`0002Kooooo000Nooooo`03o`000?oo
oooooooo00;o00004Oooool2o`0005Gooooo1?l000000ooooooo0000o`00000Jooooo`;o0000@_oo
ool2o`0007Kooooo000Nooooo`03o`000?oooooooooo00;o00001oooool2o`0000Sooooo0_l0000o
ooooo`;o00005?ooool4o`000003ooooool0003o000005gooooo0_l0000Fooooo`;o0000Goooool0
01kooooo00?o0000ooooooooool02Oooool2o`00037ooooo0_l0000Fooooo`;o00003oooool2o`00
01?ooooo0_l0000Dooooo`;o0000??ooool2o`0001Kooooo0_l0001Oooooo`007_ooool00ol0003o
ooooooooo`0Qooooo`;o00006Oooool2o`0002Oooooo0_l0000Cooooo`;o00005?ooool2o`000:Ko
oooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o00001Oooool2o`000;3ooooo
0_l0000Jooooo`;o0000Aoooool2o`000004ooooool0003o0000ooooo`;o00001oooool001kooooo
0_l0000Kooooo`;o0000KOooool2o`0004Sooooo0_l0000Jooooo`;o0000=oooool2o`00017ooooo
0_l000000ooooooo0000o`000007ooooo`007_ooool00ol0003oooooooooo`29ooooo`;o0000WOoo
ool2o`0000Cooooo0_l0000Gooooo`007_ooool00ol0003oooooooooo`14ooooo`;o0000DOooool2
o`0005[ooooo0_l0000iooooo`;o00005oooool001kooooo00?o0000ooooooooool0@oooool3o`00
057ooooo0_l0001Jooooo`;o00006Oooool2o`00017ooooo0_l0000Tooooo`007_ooool00ol0003o
ooooooooo`13ooooo`;o0000C?ooool2o`0004Kooooo0_l00008ooooo`;o00005Oooool3o`00017o
oooo0_l0000@ooooo`?o00009?ooool001kooooo00?o0000ooooooooool09oooool2o`0003_ooooo
0_l0000Dooooo`;o00005Oooool2o`0004Kooooo0_l00008ooooo`;o00005Oooool3o`0002?ooooo
0_l0000Uooooo`007_ooool00ol0003oooooooooo`0Wooooo`;o0000>oooool2o`0001Cooooo0_l0
000Mooooo`;o00002?ooool2o`000:;ooooo000Nooooo`03o`000?oooooooooo07Sooooo0_l0000O
ooooo`;o00002?ooool2o`0003Kooooo0_l0000=ooooo`;o00002Oooool2o`00023ooooo0_l0000V
ooooo`;o00001_ooool001kooooo00?o0000ooooooooool07Oooool2o`0005Wooooo0_l0001?oooo
o`;o00004?ooool2o`0000gooooo0_l00009ooooo`;o00008?ooool2o`0002Kooooo0_l00006oooo
o`007_ooool00ol0003oooooooooo`0Mooooo`;o00000_ooool2o`000:Kooooo0_l0001looooo`00
7_ooool00ol0003oooooooooo`05ooooo`;o00006_ooool2o`0004_ooooo0_l00008ooooo`;o0000
J?ooool2o`0000?ooooo0_l0001Nooooo`007_ooool00ol0003oooooooooo`05ooooo`;o0000Iooo
ool2o`0000Sooooo0_l0001Kooooo`;o00002oooool2o`0000?ooooo0_l0001Nooooo`007_ooool0
0ol0003oooooooooo`1`ooooo`;o0000Hoooool2o`00073ooooo000Nooooo`03o`000?oooooooooo
073ooooo0_l0002nooooo`;o00005Oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0Boooool2
o`0002?ooooo0_l00009ooooo`;o00001?ooool2o`0000[ooooo0_l00007ooooo`;o00003_ooool2
o`000003ooooool0003o0000017ooooo0_l0001=ooooo`;o00008oooool2o`0001Gooooo0003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q
8@06ooooo`03o`000?oooooooooo01?ooooo0_l0000Oooooo`;o00005Oooool2o`0002?ooooo0_l0
0009ooooo`;o00001?ooool2o`0000[ooooo0_l00007ooooo`;o00003_ooool2o`000003ooooool0
003o0000017ooooo0_l0001=ooooo`;o0000>_ooool000?ooooo00Go410@oooooooooooooooooa0@
400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`0001?ooooo0_l0000Oooooo`;o0000
gOooool2o`0003;ooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RH
oooooonHV9So<S8b00Kooooo00?o0000ooooooooool01_ooool2o`00023ooooo0_l00006ooooo`;o
0000hOooool2o`0002Sooooo0_l00008ooooo`000oooool01Ol0003ooooooooooooooooo000000_o
oooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo00Kooooo0_l0000Poooo
o`;o00001_ooool2o`0001Sooooo0_l0003:ooooo`;o00004_ooool2o`0000Cooooo0_l0000;oooo
o`;o00002?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooo
okZj^_l@41001_ooool00ol0003oooooooooo`0Eooooo`;o00001?ooool2o`00023ooooo0_l0000;
ooooo`;o00007_ooool2o`000:[ooooo0_l00003ooooo`;o00003Oooool2o`0000Cooooo0_l0000E
ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00
0006ooooo`03o`000?oooooooooo00Gooooo0_l0000>ooooo`;o00001?ooool2o`00023ooooo0_l0
000Iooooo`;o00004?ooool2o`000:oooooo0_l0000Zooooo`000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo00Gooooo
0_l00015ooooo`;o00002Oooool3o`00053ooooo0_l0002Kooooo`007_ooool00ol0003ooooooooo
o`0Pooooo`;o0000:_ooool2o`0000Wooooo0_l0000kooooo`;o00005?ooool2o`0006Kooooo0_l0
000Oooooo`;o00004_ooool001kooooo00?o0000ooooooooool08?ooool2o`0001Cooooo0_l0001E
ooooo`;o00001Oooool2o`0000Cooooo0_l0001fooooo`;o00003Oooool2o`00013ooooo0_l0000:
ooooo`;o00001_ooool001kooooo00?o0000ooooooooool0:_ooool2o`0000[ooooo0_l0001Eoooo
o`;o00002oooool2o`0008Gooooo0_l0000Looooo`;o00001_ooool001kooooo00?o0000oooooooo
ool04_ooool2o`0001Kooooo0_l0000;ooooo`;o00004Oooool2o`0000_ooooo0_l0000kooooo`;o
00002?ooool2o`0008_ooooo0_l0000Jooooo`007_ooool00ol0003oooooooooo`0Booooo`;o0000
8oooool2o`00017ooooo0_l0000;ooooo`;o0000:oooool2o`0000kooooo0_l00008ooooo`;o0000
5Oooool2o`0007Cooooo0_l0000Jooooo`007_ooool00ol0003oooooooooo`02o`0002Gooooo0_l0
001Kooooo`;o00008?ooool2o`0000gooooo0_l0001@ooooo`;o00004_ooool2o`0002[ooooo000N
ooooo`03o`000?oooooooooo00;o00009Oooool2o`0007gooooo0_l0001Oooooo`;o00004_ooool2
o`0001Wooooo0_l0000?ooooo`007_ooool00ol0003oooooooooo`3@ooooo`;o00008Oooool2o`00
00Oooooo0_l00006ooooo`;o0000<?ooool2o`0000oooooo000Nooooo`;o00005oooool2o`0009Co
oooo0_l0000Rooooo`;o00008Oooool2o`0000Oooooo0_l00006ooooo`;o00005?ooool2o`0002_o
oooo000Nooooo`;o00005oooool2o`00023ooooo0_l0001Qooooo`;o00003oooool2o`0006cooooo
0_l0000[ooooo`007_ooool00ol0003oooooooooo`0hooooo`;o0000=Oooool2o`0002[ooooo0_l0
001Dooooo`;o0000A?ooool2o`0000kooooo000Nooooo`;o0000L?ooool2o`00013ooooo0_l0000i
ooooo`;o00008?ooool2o`00017ooooo0_l0000Uooooo`;o00007Oooool2o`0000kooooo000Noooo
o`03o`000?oooooooooo02Cooooo0_l0001Kooooo`;o0000<oooool2o`0000Cooooo0_l0000Foooo
o`;o00002?ooool2o`0003Sooooo0_l0000]ooooo`007_ooool00ol0003oooooooooo`0Tooooo`;o
0000T?ooool4o`0001;ooooo0_l00006ooooo`;o00009?ooool4o`0003[ooooo0_l0000=ooooo`00
7_ooool00ol0003oooooooooo`13ooooo`Co0000Coooool2o`0000_ooooo0_l00005ooooo`;o0000
2oooool3o`0001;ooooo0_l0000/ooooo`Co0000>_ooool2o`0000gooooo000Nooooo`03o`000?oo
oooooooo04?ooooo1?l0000Cooooo`;o0000>_ooool4o`0000Wooooo0_l00005ooooo`;o0000H?oo
ool2o`0003Wooooo000Nooooo`03o`000?oooooooooo05[ooooo0_l0000Sooooo`;o00005oooool2
o`0007;ooooo0_l0000Nooooo`;o00006Oooool001kooooo00?o0000ooooooooool09_ooool2o`00
00?ooooo0_l0000hooooo`;o00006?ooool2o`00097ooooo0_l0000Hooooo`;o00006Oooool001ko
oooo00?o0000ooooooooool09_ooool2o`0000?ooooo0_l0000;ooooo`;o0000:oooool2o`0001?o
oooo0_l0000Oooooo`;o0000MOooool2o`0003?ooooo000Nooooo`04o`000?ooooooooooooooo`;o
0000=Oooool2o`00037ooooo0_l0000=ooooo`;o00004Oooool2o`0000cooooo0_l0002Zooooo`00
7_ooool01?l0003oooooooooooooool2o`0001Oooooo0_l0001?ooooo`;o00008?ooool2o`000;So
oooo000Nooooo`03o`000?oooooooooo01[ooooo0_l0001looooo`?o0000X_ooool2o`0000Sooooo
000Nooooo`03o`000?oooooooooo09Sooooo0ol0001;ooooo`;o0000EOooool2o`0000Sooooo000N
ooooo`03o`000?oooooooooo013ooooo0_l0001@ooooo`;o0000?_ooool2o`0000Sooooo0_l0000h
ooooo`;o0000Goooool001kooooo00?o0000ooooooooool01_ooool2o`0000Sooooo0_l0000doooo
o`;o00006_ooool2o`0003kooooo0_l00008ooooo`;o0000SOooool2o`0000[ooooo000Nooooo`03
o`000?oooooooooo00?ooooo0_l000000ooooooo0000o`00000nooooo`;o00007?ooool2o`0000;o
oooo0_l00027ooooo`;o00008?ooool2o`0002Kooooo0_l0000:ooooo`007_ooool01?l0003ooooo
o`000?l00002ooooo`;o0000Goooool2o`0000;ooooo0_l00027ooooo`;o00002_ooool2o`0001Co
oooo0_l0000Wooooo`;o00002Oooool001kooooo1_l00012ooooo`;o00000oooool2o`0009Wooooo
0_l0000Fooooo`;o0000?Oooool2o`0000Wooooo000Nooooo`04o`000?ooooooooooooooo`;o0000
@_ooool3o`0000;ooooo0_l0001^ooooo`;o0000:Oooool2o`000003ooooool0003o0000017ooooo
0_l0001:ooooo`007_ooool00ol0003oooooooooo`16ooooo`;o0000L_ooool2o`0002cooooo0_l0
000Aooooo`;o0000B_ooool001kooooo00?o0000ooooooooool0DOooool2o`0008Gooooo0_l00013
ooooo`;o0000:?ooool001kooooo00?o0000ooooooooool0DOooool2o`0001Gooooo0_l0000=oooo
o`;o0000Aoooool2o`0001Kooooo0_l00013ooooo`;o00005Oooool2o`00017ooooo000Nooooo`03
o`000?oooooooooo00gooooo0_l0001Cooooo`;o00001?ooool2o`0000gooooo0_l0000Nooooo`;o
00004_ooool2o`0001?ooooo0_l0001booooo`;o00004Oooool001kooooo00?o0000ooooooooool0
3Oooool2o`0001_ooooo0_l0000fooooo`;o0000<oooool2o`0001;ooooo0_l0000kooooo`;o0000
BOooool3o`00017ooooo000Nooooo`03o`000?oooooooooo01gooooo0_l0000;ooooo`;o0000Y_oo
ool2o`0001Cooooo0_l0000Nooooo`;o00005?ooool2o`0001?ooooo0_l0000Booooo`007_ooool0
0ol0003oooooooooo`0Mooooo`;o00002?ooool2o`00027ooooo0_l0000]ooooo`;o0000Eoooool2
o`0003Cooooo0_l0000Dooooo`;o00002?ooool2o`0001gooooo000Nooooo`03o`000?oooooooooo
02Oooooo0_l0000Iooooo`;o00001_ooool2o`0002gooooo0_l0002]ooooo`;o00007Oooool001ko
oooo00?o0000ooooooooool0@_ooool2o`0004Kooooo0ol0000Aooooo`;o0000O?ooool2o`0002Wo
oooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0001aooooo`?o00002Oooool2o`0000Kooooo
0_l0001looooo`;o0000:Oooool001kooooo00Co0000oooooooooooooooo0_l0000Dooooo`;o0000
OOooool2o`000:oooooo000Nooooo`04o`000?ooooooooooooooo`;o0000X?ooool2o`0001;ooooo
0_l0000>ooooo`;o0000;?ooool2o`0003?ooooo0_l0000Kooooo`007_ooool01?l0003ooooooooo
ooooool2o`00023ooooo0_l00013ooooo`;o00001?ooool2o`0000;ooooo0_l0000_ooooo`;o0000
4_ooool2o`0000kooooo0_l00006ooooo`Co00008_ooool2o`00013ooooo0_l0000Qooooo`;o0000
6oooool001kooooo00Co0000oooooooooooooooo0_l0000Pooooo`;o0000@oooool2o`0000Cooooo
0_l00002ooooo`;o0000Foooool4o`0003Cooooo0_l0000Hooooo`;o00009?ooool001kooooo0_l0
000Booooo`;o00004?ooool2o`0003Gooooo0_l00035ooooo`;o00009?ooool001kooooo00?o0000
ooooooooool04Oooool2o`00013ooooo0_l0000eooooo`;o0000@oooool2o`0009oooooo0_l00005
ooooo`007_ooool00ol0003oooooooooo`27ooooo`;o00005_ooool2o`0002?ooooo0_l0001Goooo
o`;o00008Oooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo08Oooooo0_l0000kooooo`;o
0000Eoooool2o`0002Sooooo000Nooooo`03o`000?oooooooooo03;ooooo0_l0000Hooooo`;o0000
joooool2o`0000cooooo000Nooooo`03o`000?oooooooooo03;ooooo0_l0000Hooooo`;o00001?oo
ool2o`0006;ooooo0_l0000>ooooo`;o00001_ooool2o`0001Wooooo0_l0001>ooooo`;o00003?oo
ool001kooooo00?o0000ooooooooool0D_ooool2o`00053ooooo0_l0000@ooooo`;o00003_ooool2
o`0000Kooooo0_l0000Eooooo`;o00000_ooool2o`0001?ooooo0_l00017ooooo`007_ooool00ol0
003oooooooooo`2>ooooo`;o00005?ooool2o`0003oooooo0_l0000Gooooo`;o0000Aoooool001ko
oooo00?o0000ooooooooool0S_ooool2o`000;Oooooo000Nooooo`03o`000?oooooooooo00?ooooo
0_l0000aooooo`;o0000a?ooool2o`0002cooooo0_l0000Kooooo`007_ooool00ol0003ooooooooo
o`03ooooo`;o0000<Oooool2o`0001;ooooo0_l0000@ooooo`;o00006_ooool2o`0000gooooo0_l0
000Tooooo`;o00008oooool2o`0002Sooooo0_l0000[ooooo`?o00006oooool001kooooo00?o0000
ooooooooool05Oooool2o`0003?ooooo0_l0000@ooooo`;o00006_ooool2o`0000gooooo0_l0000T
ooooo`;o00008oooool2o`0001oooooo0_l0000dooooo`;o00003?ooool2o`0000kooooo000Noooo
o`03o`000?oooooooooo01Gooooo0_l0001Hooooo`;o0000Aoooool2o`0003Wooooo0_l00012oooo
o`;o00003_ooool001kooooo00?o0000ooooooooool0Koooool2o`0002_ooooo0_l0000Jooooo`;o
00007oooool2o`0002Oooooo0_l00013ooooo`005?ooool4o`000003oa0@4?oooooooooo00?ooooo
00?o0000ooooooooool0W?ooool2o`0002_ooooo0_l0000>ooooo`;o00006oooool2o`0000[ooooo
0_l00003ooooo`;o0000?_ooool001Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`2Pooooo`;o00009oooool4o`0002Wooooo0_l0000?ooooo`;o0000?_ooool001Kooooo00?o0000
ooooooooool01Oooool3o`0004oooooo0_l0001?ooooo`;o00006Oooool3o`0000[ooooo0_l00000
0ooooooo0000o`00000;ooooo`;o0000KOooool001Kooooo00?o0000ooooooooool0Eoooool2o`00
06[ooooo0ol0000:ooooo`;o00003_ooool2o`0006gooooo000Fooooo`03o`000?oooooooooo0?oo
ooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003ooooooooo
o`3ooooooe3ooooo000Dooooo`03oeEEEOmVIVKo00000?ooooooD_ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.46984 .85141 Mdot
.57039 .43147 Mdot
.54723 .93114 Mdot
.94819 .29031 Mdot
.06158 .86349 Mdot
.73896 .60073 Mdot
.37384 .44412 Mdot
.33238 .77541 Mdot
.42237 .43737 Mdot
.85461 .03651 Mdot
.57611 .27492 Mdot
.5832 .46238 Mdot
.19601 .75361 Mdot
.99023 .93096 Mdot
.58872 .29927 Mdot
.86849 .83198 Mdot
.30203 .88907 Mdot
.8935 .55402 Mdot
.03749 .93239 Mdot
.48709 .3951 Mdot
.68317 .4437 Mdot
.98045 .06724 Mdot
.29473 .78712 Mdot
.44433 .97945 Mdot
.50356 .1707 Mdot
.84238 .23383 Mdot
.73205 .24347 Mdot
.50013 .38739 Mdot
.72146 .36656 Mdot
.31538 .71909 Mdot
.31453 .69676 Mdot
.0583 .88424 Mdot
.2789 .64821 Mdot
.19467 .13733 Mdot
.5775 .63379 Mdot
.43762 .42206 Mdot
.78433 .68158 Mdot
.37696 .87747 Mdot
.43138 .59745 Mdot
.83094 .14416 Mdot
.30236 .58371 Mdot
.59949 .30893 Mdot
.14899 .83723 Mdot
.09087 .70066 Mdot
.26027 .67428 Mdot
.81194 .51922 Mdot
.12308 .47838 Mdot
.90418 .2013 Mdot
.63288 .95823 Mdot
.70481 .81129 Mdot
.3374 .74415 Mdot
.931 .42839 Mdot
.29683 .29266 Mdot
.9867 .3582 Mdot
.50563 .18561 Mdot
.27699 .58718 Mdot
.213 .92133 Mdot
.897 .57717 Mdot
.95057 .48834 Mdot
.98328 .46382 Mdot
.4388 .64996 Mdot
.2971 .65334 Mdot
.29614 .30968 Mdot
.63423 .95561 Mdot
.60885 .57043 Mdot
.49528 .20856 Mdot
.80295 .39145 Mdot
.62349 .65543 Mdot
.52475 .87119 Mdot
.015 .03176 Mdot
.58478 .51889 Mdot
.44128 .75685 Mdot
.24874 .83739 Mdot
.70456 .18763 Mdot
.8273 .93166 Mdot
.09403 .33673 Mdot
.4689 .27831 Mdot
.95748 .63286 Mdot
.55875 .44025 Mdot
.53524 .94914 Mdot
.57515 .0261 Mdot
.36728 .40346 Mdot
.23583 .26679 Mdot
.41133 .49371 Mdot
.11889 .83429 Mdot
.4113 .77892 Mdot
.67537 .62728 Mdot
.61577 .14709 Mdot
.58103 .35818 Mdot
.84021 .27113 Mdot
.90697 .19711 Mdot
.10099 .8972 Mdot
.43259 .83994 Mdot
.02776 .151 Mdot
.58378 .15064 Mdot
.74019 .72533 Mdot
.81071 .91167 Mdot
.83338 .67176 Mdot
.44939 .79808 Mdot
.81213 .04743 Mdot
.69984 .11179 Mdot
.78082 .35658 Mdot
.97557 .65578 Mdot
.06205 .16025 Mdot
.17092 .02639 Mdot
.16377 .23627 Mdot
.87755 .48369 Mdot
.32107 .06276 Mdot
.15279 .52679 Mdot
.05833 .50217 Mdot
.05445 .86279 Mdot
.41695 .41298 Mdot
.47492 .72738 Mdot
.03768 .47515 Mdot
.60927 .32579 Mdot
.02547 .68858 Mdot
.81273 .62922 Mdot
.27644 .0595 Mdot
.2649 .91071 Mdot
.73523 .77615 Mdot
.78325 .7855 Mdot
.50729 .86735 Mdot
.34791 .12615 Mdot
.25206 .41464 Mdot
.24653 .16418 Mdot
.31648 .69967 Mdot
.97023 .76382 Mdot
.29231 .32453 Mdot
.03313 .79575 Mdot
.48122 .32717 Mdot
.96732 .48397 Mdot
.49117 .30507 Mdot
.45045 .04386 Mdot
.93232 .20128 Mdot
.50505 .01294 Mdot
.46114 .90803 Mdot
.45382 .1637 Mdot
.18101 .99304 Mdot
.74198 .9806 Mdot
.37959 .82345 Mdot
.42277 .76683 Mdot
.73749 .82404 Mdot
.94089 .28187 Mdot
.41432 .76612 Mdot
.20076 .24133 Mdot
.18934 .81219 Mdot
.30034 .6871 Mdot
.53089 .49251 Mdot
.00189 .61841 Mdot
.82507 .27591 Mdot
.30464 .00245 Mdot
.72737 .57125 Mdot
.47513 .65659 Mdot
.96498 .65144 Mdot
.76069 .41066 Mdot
.15373 .67195 Mdot
.85809 .23901 Mdot
.4318 .96061 Mdot
.35848 .38514 Mdot
.37747 .36411 Mdot
.86135 .00149 Mdot
.69226 .5574 Mdot
.02989 .7901 Mdot
.29805 .0066 Mdot
.81577 .3273 Mdot
.68625 .13423 Mdot
.48996 .86972 Mdot
.70799 .98576 Mdot
.09669 .44713 Mdot
.36507 .34895 Mdot
.23202 .39906 Mdot
.13539 .8044 Mdot
.23126 .88754 Mdot
.53791 .7548 Mdot
.05898 .08943 Mdot
.91448 .62089 Mdot
.22674 .09072 Mdot
.92681 .10617 Mdot
.81281 .16822 Mdot
.42493 .78668 Mdot
.01247 .75868 Mdot
.88207 .84101 Mdot
.38382 .09223 Mdot
.133 .69184 Mdot
.62086 .7182 Mdot
.46644 .98808 Mdot
.02831 .39523 Mdot
.91548 .68735 Mdot
.65896 .74332 Mdot
.79427 .10167 Mdot
.25811 .03061 Mdot
.61061 .92831 Mdot
.18848 .76419 Mdot
.44599 .92375 Mdot
.75118 .84656 Mdot
.71229 .79863 Mdot
.87028 .58139 Mdot
.61397 .72046 Mdot
.19826 .61869 Mdot
.85472 .51367 Mdot
.39689 .34093 Mdot
.76799 .71586 Mdot
.27668 .94472 Mdot
.29829 .11938 Mdot
.50423 .09362 Mdot
.16911 .01086 Mdot
.68551 .69918 Mdot
.90471 .81097 Mdot
.02414 .79426 Mdot
.277 .85332 Mdot
.22695 .78085 Mdot
.04593 .6896 Mdot
.09111 .47661 Mdot
.89403 .47604 Mdot
.92014 .98204 Mdot
.52357 .46805 Mdot
.60619 .25616 Mdot
.92712 .30319 Mdot
.86765 .93751 Mdot
.29968 .72244 Mdot
.89602 .94673 Mdot
.99167 .39752 Mdot
.77799 .2087 Mdot
.56058 .76642 Mdot
.01961 .21607 Mdot
.86778 .75978 Mdot
.85138 .78712 Mdot
.16654 .59889 Mdot
.39095 .38691 Mdot
.74698 .50539 Mdot
.03121 .87336 Mdot
.25211 .90645 Mdot
.35745 .60003 Mdot
.24481 .86947 Mdot
.31763 .00579 Mdot
.13105 .1039 Mdot
.30415 .51536 Mdot
.76011 .391 Mdot
.34788 .48854 Mdot
.50321 .57694 Mdot
.33818 .72939 Mdot
.52582 .8159 Mdot
.99205 .20583 Mdot
.38127 .85262 Mdot
.0239 .44472 Mdot
.21672 .99541 Mdot
.17915 .79316 Mdot
.45718 .7781 Mdot
.53545 .18695 Mdot
.20577 .53858 Mdot
.60175 .52136 Mdot
.60444 .13816 Mdot
.12088 .21019 Mdot
.73754 .0632 Mdot
.0104 .31624 Mdot
.20356 .90193 Mdot
.44793 .90135 Mdot
.06603 .93855 Mdot
.31084 .37036 Mdot
.73747 .06887 Mdot
.50648 .98056 Mdot
.81031 .27309 Mdot
.86152 .15968 Mdot
.49384 .16217 Mdot
.05952 .17331 Mdot
.27745 .35546 Mdot
.34189 .07954 Mdot
.21923 .56133 Mdot
.49977 .34776 Mdot
.02012 .88393 Mdot
.91185 .09631 Mdot
.34563 .1277 Mdot
.33109 .82712 Mdot
.46185 .84124 Mdot
.22437 .93339 Mdot
.67564 .86706 Mdot
.60572 .99903 Mdot
.74888 .23575 Mdot
.44211 .25992 Mdot
.1445 .75395 Mdot
.55389 .25562 Mdot
.28347 .00519 Mdot
.62623 .49919 Mdot
.82993 .83962 Mdot
.11789 .1776 Mdot
.81766 .58171 Mdot
.73319 .191 Mdot
.86981 .18782 Mdot
.84204 .13989 Mdot
.75302 .01977 Mdot
.89935 .87756 Mdot
.13423 .29148 Mdot
.83869 .83314 Mdot
.7509 .52183 Mdot
.93312 .50109 Mdot
.97349 .24748 Mdot
.52317 .6391 Mdot
.2871 .35583 Mdot
.67329 .49791 Mdot
.19635 .03263 Mdot
.6591 .2606 Mdot
.59967 .24439 Mdot
.47264 .42472 Mdot
.15731 .22961 Mdot
.57651 .74559 Mdot
.4028 .47216 Mdot
.47737 .27901 Mdot
.62943 .95109 Mdot
.70206 .83234 Mdot
.80549 .78253 Mdot
.37383 .55279 Mdot
.62333 .56022 Mdot
.23334 .30733 Mdot
.74054 .11222 Mdot
.10531 .28644 Mdot
.96556 .36029 Mdot
.00401 .716 Mdot
.20708 .70644 Mdot
.39762 .22508 Mdot
.68826 .2833 Mdot
.85933 .77335 Mdot
.73695 .99484 Mdot
.70186 .31307 Mdot
.68506 .8838 Mdot
.53926 .28001 Mdot
.77702 .68165 Mdot
.71325 .29636 Mdot
.60417 .49077 Mdot
.9226 .89348 Mdot
.06336 .46219 Mdot
.96341 .02715 Mdot
.09624 .81794 Mdot
.64605 .65725 Mdot
.59065 .12873 Mdot
.99654 .58298 Mdot
.45943 .75455 Mdot
.33444 .83437 Mdot
.62033 .71368 Mdot
.86179 .74122 Mdot
.49131 .21131 Mdot
.00539 .18491 Mdot
.00343 .71368 Mdot
.25715 .64588 Mdot
.76539 .0304 Mdot
.21821 .71245 Mdot
.31779 .87606 Mdot
.22582 .23497 Mdot
.02946 .66396 Mdot
.58614 .50886 Mdot
.84631 .64886 Mdot
.25604 .09414 Mdot
.0782 .54078 Mdot
.23139 .73668 Mdot
.69183 .98725 Mdot
.21753 .61623 Mdot
.17364 .84882 Mdot
.0445 .08767 Mdot
.26698 .74007 Mdot
.469 .57764 Mdot
.90691 .15025 Mdot
.93977 .67957 Mdot
.58296 .89769 Mdot
.3431 .79966 Mdot
.01544 .39116 Mdot
.987 .62819 Mdot
.26982 .2022 Mdot
.14304 .70314 Mdot
.56412 .37391 Mdot
.34525 .41518 Mdot
.28977 .39114 Mdot
.39941 .51624 Mdot
.10456 .37271 Mdot
.58385 .61579 Mdot
.47919 .0216 Mdot
.39146 .66634 Mdot
.26077 .67189 Mdot
.93182 .64546 Mdot
.44213 .89505 Mdot
.19697 .76004 Mdot
.5544 .04252 Mdot
.78986 .24137 Mdot
.95676 .81818 Mdot
.61501 .73053 Mdot
.59543 .14897 Mdot
.46911 .01142 Mdot
.59147 .46283 Mdot
.13274 .59241 Mdot
.92155 .94503 Mdot
.56939 .41779 Mdot
.79831 .86212 Mdot
.85828 .84327 Mdot
.92762 .00895 Mdot
.05696 .2505 Mdot
.69223 .19688 Mdot
.30264 .63314 Mdot
.41992 .17465 Mdot
.62592 .8274 Mdot
.98189 .65437 Mdot
.70923 .33624 Mdot
.96494 .73532 Mdot
.78829 .11605 Mdot
.63482 .60942 Mdot
.90089 .41213 Mdot
.53662 .18715 Mdot
.31604 .51075 Mdot
.75765 .09272 Mdot
.06778 .24313 Mdot
.99648 .08798 Mdot
.3483 .63634 Mdot
.69911 .92896 Mdot
.97571 .05461 Mdot
.52072 .7122 Mdot
.63879 .66024 Mdot
.94702 .81775 Mdot
.98423 .70712 Mdot
.68934 .64464 Mdot
.40883 .23287 Mdot
.98053 .87427 Mdot
.90806 .91821 Mdot
.01007 .79911 Mdot
.51976 .52653 Mdot
.21236 .18711 Mdot
.87722 .22175 Mdot
.49663 .04907 Mdot
.59286 .11029 Mdot
.36976 .28812 Mdot
.19545 .68907 Mdot
.13293 .672 Mdot
.68624 .70351 Mdot
.73029 .27763 Mdot
.67674 .49274 Mdot
.65081 .32238 Mdot
.9249 .4636 Mdot
.22752 .26156 Mdot
.4209 .75997 Mdot
.80987 .3265 Mdot
.2295 .39175 Mdot
.85564 .90538 Mdot
.7927 .00345 Mdot
.35811 .93905 Mdot
.90726 .14075 Mdot
.68573 .28313 Mdot
.53759 .32055 Mdot
.6131 .94476 Mdot
.76825 .3805 Mdot
.88781 .98167 Mdot
.65543 .11415 Mdot
.80827 .51328 Mdot
.37376 .24553 Mdot
.36692 .6224 Mdot
.2077 .63556 Mdot
.46989 .50359 Mdot
.9639 .63265 Mdot
.17846 .08729 Mdot
.48507 .09112 Mdot
.37481 .35666 Mdot
.46963 .39071 Mdot
.04944 .14522 Mdot
.33709 .416 Mdot
.96288 .61285 Mdot
.92563 .47988 Mdot
.3945 .26021 Mdot
.73796 .98151 Mdot
.52178 .9453 Mdot
.43025 .63075 Mdot
.39507 .46535 Mdot
.31861 .11994 Mdot
.35634 .52584 Mdot
.27881 .70293 Mdot
.88124 .87515 Mdot
.32054 .40876 Mdot
.10427 .6247 Mdot
.84495 .05763 Mdot
.02034 .70816 Mdot
.06708 .59055 Mdot
.77902 .32279 Mdot
.76814 .55864 Mdot
.33708 .43499 Mdot
.96964 .99849 Mdot
.74282 .46069 Mdot
.85941 .74794 Mdot
.46903 .19132 Mdot
.99967 .2628 Mdot
.05964 .76603 Mdot
.93233 .88052 Mdot
.72552 .66412 Mdot
.53347 .47846 Mdot
.28237 .07663 Mdot
.99157 .69852 Mdot
.84859 .02996 Mdot
.58246 .23665 Mdot
.94122 .50047 Mdot
.35174 .69901 Mdot
.11643 .98158 Mdot
.44944 .6406 Mdot
.94228 .67087 Mdot
.79965 .88349 Mdot
.29084 .65461 Mdot
.96379 .19372 Mdot
.52943 .48794 Mdot
.626 .7714 Mdot
.2228 .02675 Mdot
.48979 .43896 Mdot
.95548 .89928 Mdot
.47302 .90446 Mdot
.35413 .72553 Mdot
.56483 .13414 Mdot
.75105 .87208 Mdot
.54609 .16637 Mdot
.32278 .41171 Mdot
.92029 .81318 Mdot
.97705 .98078 Mdot
.02153 .54382 Mdot
.20532 .42951 Mdot
.02759 .67435 Mdot
.14622 .79004 Mdot
.14806 .64051 Mdot
.17973 .75825 Mdot
.25136 .35757 Mdot
.11673 .59261 Mdot
.65964 .41538 Mdot
.01673 .71518 Mdot
.09333 .43181 Mdot
.22391 .893 Mdot
.89261 .28565 Mdot
.3489 .07415 Mdot
.49122 .88394 Mdot
.09887 .80529 Mdot
.59297 .9407 Mdot
.09401 .51291 Mdot
.90626 .58278 Mdot
.56326 .94944 Mdot
.68611 .89668 Mdot
.93181 .37716 Mdot
.75793 .91539 Mdot
.95523 .90015 Mdot
.61137 .33079 Mdot
.41477 .98965 Mdot
.58568 .00466 Mdot
.15214 .58504 Mdot
.7447 .54324 Mdot
.12969 .50439 Mdot
.48245 .43366 Mdot
.07232 .87563 Mdot
.29437 .4982 Mdot
.99772 .44547 Mdot
.63323 .0675 Mdot
.55662 .84728 Mdot
.2313 .22501 Mdot
.55536 .99673 Mdot
.75724 .78347 Mdot
.35718 .94941 Mdot
.08377 .15906 Mdot
.84176 .0906 Mdot
.77964 .03174 Mdot
.52571 .81496 Mdot
.32573 .71091 Mdot
.89947 .25592 Mdot
.1622 .5093 Mdot
.1103 .99564 Mdot
.16499 .46671 Mdot
.67483 .68824 Mdot
.62872 .04327 Mdot
.39749 .4186 Mdot
.05187 .79764 Mdot
.96269 .00808 Mdot
.43147 .51077 Mdot
.59166 .92395 Mdot
.94447 .00843 Mdot
.6798 .55275 Mdot
.49101 .83637 Mdot
.30492 .81568 Mdot
.61428 .96444 Mdot
.97932 .06157 Mdot
.55211 .25579 Mdot
.23274 .28408 Mdot
.10987 .91769 Mdot
.14676 .95677 Mdot
.80108 .29889 Mdot
.11358 .85393 Mdot
.5473 .08834 Mdot
.97631 .7177 Mdot
.22456 .0587 Mdot
.61033 .315 Mdot
.9182 .86604 Mdot
.85686 .63338 Mdot
.869 .12495 Mdot
.00822 .85328 Mdot
.41567 .65946 Mdot
.05128 .34161 Mdot
.62043 .38586 Mdot
.52082 .76867 Mdot
.86844 .3123 Mdot
.05679 .35121 Mdot
.57205 .50254 Mdot
.08018 .73974 Mdot
.00019 .88079 Mdot
.1323 .42987 Mdot
.20085 .83302 Mdot
.18371 .15563 Mdot
.94723 .01307 Mdot
.93601 .33949 Mdot
.71906 .98443 Mdot
.75673 .11315 Mdot
.69274 .35919 Mdot
.12827 .02024 Mdot
.11231 .75592 Mdot
.70736 .17463 Mdot
.29934 .64838 Mdot
.10935 .74493 Mdot
.7946 .05439 Mdot
.99455 .02451 Mdot
.40234 .33053 Mdot
.7847 .0166 Mdot
.70081 .5152 Mdot
.69657 .39579 Mdot
.28099 .06306 Mdot
.39627 .30255 Mdot
.6545 .17225 Mdot
.1967 .55969 Mdot
.8831 .4779 Mdot
.70669 .51445 Mdot
.66011 .80926 Mdot
.87647 .03014 Mdot
.03373 .79746 Mdot
.6176 .09954 Mdot
.19258 .31034 Mdot
.51084 .94342 Mdot
.21485 .58719 Mdot
.54096 .80113 Mdot
.68362 .3905 Mdot
.70067 .61691 Mdot
.24313 .04353 Mdot
.52478 .79024 Mdot
.57319 .17916 Mdot
.45131 .84524 Mdot
.316 .80966 Mdot
.65622 .62673 Mdot
.2688 .664 Mdot
.75584 .0531 Mdot
.27449 .97363 Mdot
.0898 .90308 Mdot
.59355 .96081 Mdot
.75696 .90525 Mdot
.80455 .80828 Mdot
.37566 .49793 Mdot
.33136 .79776 Mdot
.24426 .2943 Mdot
.81322 .19676 Mdot
.98244 .24102 Mdot
.70955 .79695 Mdot
.78622 .8226 Mdot
.53227 .991 Mdot
.30761 .68555 Mdot
.89952 .54122 Mdot
.33763 .96791 Mdot
.47075 .79234 Mdot
.96834 .14823 Mdot
.07025 .20042 Mdot
.5548 .5836 Mdot
.75848 .8518 Mdot
.60526 .57843 Mdot
.71848 .52782 Mdot
.42685 .55327 Mdot
.69198 .53923 Mdot
.49789 .02692 Mdot
.72499 .70829 Mdot
.89087 .93474 Mdot
.89063 .73216 Mdot
.22265 .62696 Mdot
.50226 .33151 Mdot
.16224 .11418 Mdot
.13686 .35805 Mdot
.84243 .01434 Mdot
.96996 .12198 Mdot
.40387 .47476 Mdot
.6348 .07407 Mdot
.43234 .51836 Mdot
.17736 .07101 Mdot
.40831 .37449 Mdot
.55598 .51761 Mdot
.61137 .99124 Mdot
.68278 .28787 Mdot
.20592 .98828 Mdot
.62509 .90183 Mdot
.77525 .54236 Mdot
.79616 .01585 Mdot
.34792 .52629 Mdot
.20529 .49699 Mdot
.33652 .0499 Mdot
.52835 .48532 Mdot
.60834 .00152 Mdot
.75076 .31297 Mdot
.73883 .45995 Mdot
.24917 .77381 Mdot
.57383 .837 Mdot
.2936 .88084 Mdot
.68484 .79665 Mdot
.97945 .14365 Mdot
.09037 .73046 Mdot
.27406 .46787 Mdot
.89639 .58873 Mdot
.12998 .05099 Mdot
.99708 .14944 Mdot
.89667 .20352 Mdot
.73761 .30958 Mdot
.11984 .51531 Mdot
.17137 .86534 Mdot
.57511 .42101 Mdot
.16397 .51346 Mdot
.09369 .38854 Mdot
.08305 .10274 Mdot
.71094 .90944 Mdot
.44596 .04097 Mdot
.62482 .98637 Mdot
.98385 .0294 Mdot
.72331 .67504 Mdot
.30473 .65169 Mdot
.54802 .10772 Mdot
.5919 .06798 Mdot
.60905 .68872 Mdot
.66609 .09766 Mdot
.45129 .59842 Mdot
.74156 .55222 Mdot
.30229 .55206 Mdot
.03121 .38151 Mdot
.54924 .87647 Mdot
.42577 .77898 Mdot
.31129 .46055 Mdot
.42452 .79438 Mdot
.70996 .60339 Mdot
.94645 .93778 Mdot
.93172 .52108 Mdot
.36037 .8559 Mdot
.90586 .41333 Mdot
.41434 .69916 Mdot
.92926 .84871 Mdot
.13396 .62025 Mdot
.8034 .94736 Mdot
.06771 .0746 Mdot
.28373 .5125 Mdot
.07654 .89735 Mdot
.29154 .05654 Mdot
.09808 .49672 Mdot
.84458 .38882 Mdot
.82753 .69236 Mdot
.66877 .33464 Mdot
.74113 .69406 Mdot
.12735 .38561 Mdot
.30534 .49557 Mdot
.08997 .55597 Mdot
.11324 .55903 Mdot
.82578 .54262 Mdot
.37978 .97336 Mdot
.05365 .62337 Mdot
.81502 .91294 Mdot
.24235 .45818 Mdot
.26499 .95767 Mdot
.82113 .84992 Mdot
.17019 .86338 Mdot
.19503 .8652 Mdot
.76804 .45378 Mdot
.46194 .09402 Mdot
.26523 .19792 Mdot
.86461 .95145 Mdot
.29088 .44067 Mdot
.39398 .96329 Mdot
.08723 .44603 Mdot
.01163 .55798 Mdot
.89977 .70249 Mdot
.2076 .08894 Mdot
.73287 .08064 Mdot
.55033 .33105 Mdot
.87028 .9035 Mdot
.46429 .00687 Mdot
.37023 .893 Mdot
.01173 .67341 Mdot
.40799 .67226 Mdot
.09894 .06492 Mdot
.58646 .50063 Mdot
.56995 .17938 Mdot
.15062 .78267 Mdot
.88234 .52955 Mdot
.79266 .50587 Mdot
.88761 .23241 Mdot
.41499 .04169 Mdot
.5089 .84135 Mdot
.83601 .5164 Mdot
.95436 .75754 Mdot
.66341 .10601 Mdot
.32203 .7726 Mdot
.10672 .44876 Mdot
.54193 .81962 Mdot
.60692 .61437 Mdot
.57204 .51173 Mdot
.39123 .18233 Mdot
.30482 .60122 Mdot
.88436 .18698 Mdot
.70429 .25557 Mdot
.31323 .80385 Mdot
.83494 .37607 Mdot
.23411 .67969 Mdot
.50245 .69008 Mdot
.12477 .03378 Mdot
.63933 .53768 Mdot
.5283 .5514 Mdot
.77165 .95114 Mdot
.21442 .6839 Mdot
.65989 .56609 Mdot
.29337 .11526 Mdot
.01455 .72394 Mdot
.39574 .13036 Mdot
.81151 .64849 Mdot
.63647 .69788 Mdot
.22332 .95918 Mdot
.79202 .97738 Mdot
.44076 .35554 Mdot
.28817 .47443 Mdot
.5771 .13068 Mdot
.26545 .81526 Mdot
.39861 .33427 Mdot
.47319 .66558 Mdot
.84743 .69953 Mdot
.64708 .01566 Mdot
.7436 .53376 Mdot
.91349 .87889 Mdot
.43791 .51452 Mdot
.23077 .23525 Mdot
.13527 .25525 Mdot
.0724 .38771 Mdot
.033 .41693 Mdot
.68942 .77672 Mdot
.77599 .28776 Mdot
.80552 .68067 Mdot
.20865 .37227 Mdot
.54926 .3406 Mdot
.57224 .10155 Mdot
.89561 .36313 Mdot
.57732 .54371 Mdot
.21521 .50592 Mdot
.47831 .01671 Mdot
.2476 .4104 Mdot
.49107 .65656 Mdot
.04343 .16439 Mdot
.81007 .59135 Mdot
.72543 .76011 Mdot
.56086 .10577 Mdot
.31948 .45616 Mdot
.25612 .00289 Mdot
.00088 .44494 Mdot
.10293 .60193 Mdot
.07156 .16999 Mdot
.55979 .03473 Mdot
.98556 .92263 Mdot
.77072 .35896 Mdot
.85689 .19482 Mdot
.3014 .2847 Mdot
.47695 .56224 Mdot
.25977 .83169 Mdot
.72112 .55262 Mdot
.79512 .28562 Mdot
.01732 .87739 Mdot
.79731 .63541 Mdot
.72637 .6746 Mdot
.48782 .34046 Mdot
.03349 .16106 Mdot
.82212 .08831 Mdot
.45334 .02886 Mdot
.2624 .3635 Mdot
.71244 .74481 Mdot
.48833 .29123 Mdot
.21796 .94013 Mdot
.99547 .29638 Mdot
.51128 .14063 Mdot
.90518 .77676 Mdot
.28343 .7784 Mdot
.77253 .47723 Mdot
.27166 .32962 Mdot
.31454 .526 Mdot
.76387 .7405 Mdot
.03119 .33078 Mdot
.30215 .37258 Mdot
.78566 .35 Mdot
.48453 .9478 Mdot
.0673 .43543 Mdot
.55433 .04992 Mdot
.01749 .11652 Mdot
.07551 .89043 Mdot
.06706 .85978 Mdot
.89557 .40678 Mdot
.6122 .82926 Mdot
.73665 .319 Mdot
.68218 .37923 Mdot
.17449 .54003 Mdot
.05994 .91575 Mdot
.60172 .01828 Mdot
.35238 .79565 Mdot
.38812 .2015 Mdot
.64793 .0116 Mdot
.16204 .81685 Mdot
.98908 .97753 Mdot
.39572 .01658 Mdot
.64045 .76221 Mdot
.43111 .08837 Mdot
.25194 .18658 Mdot
.75248 .26145 Mdot
.5903 .18379 Mdot
.647 .64744 Mdot
.22461 .82374 Mdot
.19383 .75637 Mdot
.65698 .30875 Mdot
.04423 .62082 Mdot
.05016 .07814 Mdot
.03801 .60339 Mdot
.49588 .81768 Mdot
.88567 .75764 Mdot
.62055 .25798 Mdot
.5498 .33161 Mdot
.90241 .19185 Mdot
.69457 .99312 Mdot
.00073 .33317 Mdot
.83235 .61182 Mdot
.19887 .18036 Mdot
.5961 .02904 Mdot
.86057 .32959 Mdot
.03903 .15983 Mdot
.34072 .87529 Mdot
.81095 .13578 Mdot
.03731 .48843 Mdot
.08606 .26385 Mdot
.8814 .431 Mdot
.13431 .33421 Mdot
.38479 .30655 Mdot
.66392 .48221 Mdot
.70615 .09159 Mdot
.9956 .84045 Mdot
.39175 .96662 Mdot
.20969 .0811 Mdot
.1125 .36149 Mdot
.60331 .81958 Mdot
.91272 .04421 Mdot
.49052 .22868 Mdot
.61716 .97392 Mdot
.84603 .45186 Mdot
.83635 .36543 Mdot
.00977 .55304 Mdot
.72542 .93685 Mdot
.49841 .92478 Mdot
.78785 .02257 Mdot
.43193 .5521 Mdot
.13918 .08393 Mdot
.68285 .13162 Mdot
.12979 .38165 Mdot
.20723 .16539 Mdot
.47704 .43815 Mdot
.23521 .59536 Mdot
.3748 .57169 Mdot
.01308 .24775 Mdot
.47574 .01226 Mdot
.95159 .53331 Mdot
.79435 .21548 Mdot
.27146 .68306 Mdot
.62642 .12405 Mdot
.52274 .20334 Mdot
.69459 .42681 Mdot
.90925 .47133 Mdot
.20157 .50237 Mdot
.55015 .18101 Mdot
.14434 .53157 Mdot
.79306 .83556 Mdot
.59438 .55543 Mdot
.03266 .54669 Mdot
.57845 .07748 Mdot
.79629 .46272 Mdot
.99652 .31524 Mdot
.31795 .48905 Mdot
.30142 .35705 Mdot
.98947 .44694 Mdot
.11902 .12584 Mdot
.23951 .12136 Mdot
.50864 .84705 Mdot
.15823 .23645 Mdot
.57777 .27775 Mdot
.84024 .21294 Mdot
.80792 .56147 Mdot
.95395 .53886 Mdot
.99427 .83806 Mdot
.7078 .66953 Mdot
.70265 .92797 Mdot
.17443 .66033 Mdot
.58648 .10655 Mdot
.66286 .44766 Mdot
.06366 .79059 Mdot
.98768 .98946 Mdot
.00187 .9074 Mdot
.26161 .39685 Mdot
.68673 .06272 Mdot
.64856 .5222 Mdot
.90888 .0962 Mdot
.4524 .49087 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool3o`0000gooooo0ol0000=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool01?l0003oooooo`000?l0000<ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`;o000000?oooooo`00
0?ooool03_ooool00ol0003oooooooooo`02o`0000_ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool3o`0000Oooooo0_l00003ooooo`Co00000_ooool2o`0000Wo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`04o`000?oooooooooooooo
o`;o00002_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo0_l00004oooo
o`04o`000?oooooo0000o`0000cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00_ooooo0_l000000ooooooo0000ooooo`0>ooooo`03o`000?oooooo
oooo00;o00002oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool00_ooool001kooooo00?o0000ooooooooool0F?ooool2o`0000?ooooo0_l00004oooo
o`;o0000;_ooool2o`0002Gooooo0_l0001]ooooo`;o00001?ooool2o`0000Cooooo0_l0000@oooo
o`007_ooool00ol0003oooooooooo`0cooooo`;o0000Goooool2o`000003ooooool0003o000000Oo
oooo0_l0000]ooooo`;o0000F?ooool2o`0000Cooooo0ol00003ooooo`;o00004?ooool001kooooo
00?o0000ooooooooool0<oooool2o`0004Sooooo0_l0000Eooooo`;o000000?oooooo`000?l00000
1oooool2o`0002cooooo0ol0000Zooooo`;o00000_ooool2o`0000gooooo0_l0000Pooooo`;o0000
5Oooool001kooooo00?o0000ooooooooool0OOooool2o`0001Sooooo0_l0000Wooooo`;o00003?oo
ool2o`00027ooooo0_l00008ooooo`;o00000_ooool2o`0000gooooo0_l0000gooooo`007_ooool0
0ol0003oooooooooo`0Vooooo`;o0000L?ooool2o`0002Kooooo0_l0000_ooooo`;o00002Oooool2
o`0004Wooooo000Nooooo`03o`000?oooooooooo02Kooooo0_l0001`ooooo`;o0000H_ooool2o`00
047ooooo0_l00006ooooo`007_ooool00ol0003oooooooooo`0cooooo`;o00003oooool2o`0004Wo
oooo0_l0000=ooooo`;o00005oooool2o`0000Gooooo0_l0001eooooo`;o00002?ooool2o`0000Ko
oooo000Nooooo`04o`000?ooooooooooooooo`;o0000<?ooool2o`0000oooooo0_l0000:ooooo`;o
0000?Oooool2o`0000gooooo0_l0000Gooooo`;o00001Oooool2o`0003Gooooo0_l00002ooooo`;o
00005Oooool2o`0000Oooooo0_l0000Jooooo`;o00001Oooool2o`0000Wooooo000Nooooo`04o`00
0?ooooooooooooooo`;o00008Oooool2o`0001Kooooo0_l0000Booooo`;o0000H?ooool2o`00047o
oooo0_l00002ooooo`;o00005Oooool2o`0000Oooooo0_l0000Qooooo`;o00002Oooool001kooooo
00?o0000ooooooooool09?ooool2o`0001Kooooo0_l0001dooooo`;o0000G_ooool2o`0003?ooooo
000Nooooo`03o`000?oooooooooo08gooooo0_l00023ooooo`;o0000<oooool001kooooo00?o0000
ooooooooool0Boooool2o`0003Kooooo0_l00008ooooo`?o00008?ooool2o`0001Kooooo0_l0001K
ooooo`;o00008?ooool001kooooo00?o0000ooooooooool0Boooool2o`0003Kooooo0_l00009oooo
o`;o00008?ooool2o`0001Kooooo0_l0000jooooo`;o00007oooool2o`00023ooooo000Nooooo`03
o`000?oooooooooo06Wooooo0_l0000booooo`;o00004Oooool2o`0005;ooooo0_l00011ooooo`00
7_ooool2o`0002Oooooo0_l00011ooooo`;o0000<_ooool2o`00017ooooo0_l00010ooooo`;o0000
Doooool001kooooo00?o0000ooooooooool09_ooool2o`0003?ooooo0_l0002Eooooo`;o00002_oo
ool2o`0003Wooooo0_l0000<ooooo`007_ooool00ol0003oooooooooo`15ooooo`;o00003oooool2
o`0000?ooooo0_l0002Qooooo`;o00003oooool2o`0002Sooooo0_l0000<ooooo`007_ooool00ol0
003oooooooooo`15ooooo`;o00003oooool2o`0000cooooo0_l0001eooooo`;o0000<_ooool2o`00
02Wooooo0_l0000;ooooo`007_ooool00ol0003oooooooooo`0Looooo`;o0000>Oooool2o`0000_o
oooo0_l0001eooooo`;o00003oooool2o`0004cooooo0_l0000;ooooo`007_ooool00ol0003ooooo
ooooo`0Looooo`;o0000>Oooool2o`0006?ooooo0_l0000<ooooo`;o00008?ooool2o`0004gooooo
0_l0000:ooooo`007_ooool00ol0003oooooooooo`0fooooo`;o0000Q?ooool2o`0000cooooo0_l0
000Pooooo`;o0000COooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0000R
ooooo`;o0000=Oooool2o`0005_ooooo0_l0001kooooo`007_ooool00ol0003oooooooooo`0<oooo
o`;o00001?ooool2o`0004Cooooo0_l0000Cooooo`;o0000BOooool2o`00013ooooo0_l0001koooo
o`007_ooool00ol0003oooooooooo`0<ooooo`;o0000<_ooool2o`0001Kooooo0_l0000Aooooo`;o
0000Boooool2o`00033ooooo0_l0001Kooooo`007_ooool00ol0003oooooooooo`0Yooooo`;o0000
5Oooool2o`0002Wooooo0_l0001mooooo`;o0000Foooool001kooooo00?o0000ooooooooool0:Ooo
ool2o`0000_ooooo0_l0003ooooooa3ooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l00003
ooooo`;o00009Oooool2o`0000Oooooo0_l00017ooooo`;o00009?ooool2o`0005Oooooo0_l00005
ooooo`;o0000<?ooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l00003oooo
o`;o0000;_ooool2o`0000Gooooo0_l0000aooooo`;o00003Oooool2o`00013ooooo0_l00004oooo
o`;o00003?ooool2o`00037ooooo0_l0000?ooooo`;o00004oooool2o`0000Gooooo0_l0000`oooo
o`;o00001Oooool001kooooo00?o0000ooooooooool0A_ooool2o`0000Oooooo0_l0000Xooooo`;o
00005oooool2o`0000Kooooo0_l00004ooooo`;o0000?oooool2o`0000oooooo0_l0000_ooooo`?o
00008Oooool001kooooo00?o0000ooooooooool0Coooool2o`00047ooooo0_l0000aooooo`;o0000
3Oooool2o`0004gooooo0ol0000Qooooo`007_ooool2o`0001Sooooo0_l0002Mooooo`;o00003Ooo
ool2o`0000gooooo0_l0000Xooooo`;o0000Aoooool001kooooo00?o0000ooooooooool05oooool2
o`0000gooooo0_l0002:ooooo`;o00000_ooool2o`0001cooooo0_l0000Xooooo`;o0000Aoooool0
01kooooo00?o0000ooooooooool09_ooool2o`0008Kooooo0_l00002ooooo`;o00001oooool2o`00
01Oooooo0_l0001Cooooo`;o00007?ooool001kooooo00?o0000ooooooooool0[_ooool2o`0000_o
oooo1?l0000Pooooo`;o0000B?ooool2o`0001cooooo000Nooooo`03o`000?oooooooooo037ooooo
0_l0002:ooooo`;o00004_ooool2o`0000cooooo0_l0000<ooooo`;o00000oooool2o`0005?ooooo
000Nooooo`03o`000?oooooooooo00;ooooo0_l0000]ooooo`;o0000:?ooool2o`0007Cooooo0_l0
000Jooooo`;o00000oooool2o`0000Sooooo0_l00019ooooo`007_ooool00ol0003oooooooooo`02
ooooo`;o0000A_ooool2o`0000oooooo1?l00004ooooo`;o0000Uoooool2o`0004Wooooo000Noooo
o`03o`000?oooooooooo04[ooooo0_l0000Aooooo`;o00001?ooool2o`0006?ooooo0_l0001]oooo
o`;o00003_ooool001kooooo00?o0000ooooooooool08oooool2o`0004Sooooo0_l0001Iooooo`;o
0000C?ooool2o`0001oooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o0000
Aoooool3o`0000kooooo0_l0000mooooo`;o0000F?ooool2o`0002oooooo000Nooooo`03o`000?oo
oooooooo06cooooo0_l0000?ooooo`;o0000>Oooool2o`0000;ooooo0_l0000Looooo`;o0000Jooo
ool001kooooo00?o0000ooooooooool0]?ooool2o`0000;ooooo0_l0000Pooooo`?o00009oooool2
o`00047ooooo000Nooooo`03o`000?oooooooooo03_ooooo0_l0001gooooo`;o00002_ooool2o`00
01Wooooo0_l0000Wooooo`;o0000@Oooool001kooooo00?o0000ooooooooool0>oooool2o`0006Go
oooo0_l0000Looooo`;o0000C?ooool2o`0001?ooooo0_l0000Rooooo`007_ooool00ol0003ooooo
ooooo`0<ooooo`;o0000U?ooool2o`0006Kooooo0_l00002ooooo`;o00004oooool2o`0001Gooooo
0_l0000;ooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o0000[oooool2o`0000Gooooo0_l0
0014ooooo`;o0000:oooool2o`000003ooooool0003o000000_ooooo000Nooooo`;o00001_ooool2
o`000;?ooooo0_l000000ooooooo0000o`000005ooooo`;o0000GOooool2o`0001;ooooo0_l00007
ooooo`;o00001Oooool001kooooo00?o0000ooooooooool01Oooool2o`000;?ooooo0_l0001Woooo
o`;o00006oooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo03Sooooo0_l0003oooooo`ko
oooo000Nooooo`03o`000?oooooooooo00Oooooo1?l00005ooooo`;o00001Oooool2o`0001oooooo
0_l0003Jooooo`;o0000<Oooool001kooooo00?o0000ooooooooool01oooool5o`0000Cooooo0_l0
0005ooooo`;o0000<oooool2o`00047ooooo0_l0000;ooooo`;o0000M_ooool2o`00037ooooo000N
ooooo`03o`000?oooooooooo00[ooooo0_l0000cooooo`;o00002oooool2o`00047ooooo0_l0000;
ooooo`;o00003oooool2o`0009Sooooo000Nooooo`03o`000?oooooooooo01?ooooo0_l0000Zoooo
o`;o0000K?ooool2o`0005Gooooo0_l00011ooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o
00000_ooool2o`0008_ooooo0_l0000_ooooo`;o0000<Oooool2o`00047ooooo000Nooooo`03o`00
0?oooooooooo00oooooo0_l0001cooooo`;o00006_ooool2o`0002oooooo0_l0000?ooooo`;o0000
Hoooool001kooooo00?o0000ooooooooool08_ooool2o`00063ooooo0_l0000_ooooo`?o0000:_oo
ool2o`0006?ooooo000Nooooo`03o`000?oooooooooo02;ooooo0_l0000Iooooo`;o0000??ooool2
o`0003;ooooo0_l00004ooooo`?o0000Soooool001kooooo0ol0000mooooo`;o0000??ooool2o`00
02?ooooo0_l0000=ooooo`;o00002oooool2o`0008Wooooo000Nooooo`?o0000@Oooool2o`0000_o
oooo0_l0001@ooooo`;o00002?ooool2o`00013ooooo0_l0000Sooooo`;o0000=?ooool2o`0000;o
oooo0_l0000Zooooo`007_ooool00ol0003oooooooooo`11ooooo`;o00002oooool2o`0004Cooooo
0_l0000Dooooo`;o0000=Oooool2o`0000Oooooo0_l0000[ooooo`;o00000_ooool2o`0000Cooooo
0_l0000Tooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000
1_ooool00ol0003oooooooooo`2Dooooo`;o0000E?ooool2o`0002Kooooo0_l0000=ooooo`;o0000
4_ooool2o`00013ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo
00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo05;ooooo0_l00029ooooo`;o
00009Oooool2o`0000cooooo0_l0000?ooooo`;o00004?ooool2o`00013ooooo0003ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`?o00004oooool2o`0003go
oooo0_l00029ooooo`;o00009Oooool2o`0001cooooo0ol00006ooooo`;o00006_ooool000?ooooo
00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000oooooooo
ool04oooool2o`0003oooooo0_l0000Tooooo`;o0000:_ooool2o`0007Oooooo0_l000000ooooooo
0000o`000007ooooo`;o00006_ooool000?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0E?ooool2o`0002Cooooo0_l0000Zooooo`;o
0000Moooool2o`0001gooooo0_l00007ooooo`000oooool01Ol@413ooooooooooooooooo410@00oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Sooooo`;o0000N?ooool2o`0005[o
oooo0_l00013ooooo`;o00001oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`0Sooooo`;o0000Moooool3o`00
05[ooooo0_l0000Booooo`;o0000>?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`02ooooo`;o0000V?ooool2
o`00063ooooo0_l0000=ooooo`;o0000>?ooool001kooooo00?o0000ooooooooool00_ooool2o`00
0?[ooooo0_l00017ooooo`007_ooool00ol0003oooooooooo`3ooooooa[ooooo0_l0000/ooooo`00
7_ooool00ol0003oooooooooo`17ooooo`;o0000=?ooool2o`0009[ooooo0_l0000/ooooo`007_oo
ool00ol0003oooooooooo`17ooooo`;o0000=?ooool2o`0001cooooo0_l0002Zooooo`007_ooool0
0ol0003oooooooooo`0_ooooo`;o0000J_ooool2o`000:[ooooo000Nooooo`03o`000?oooooooooo
02oooooo0_l0000Dooooo`;o0000>_ooool2o`0008_ooooo0_l0000<ooooo`;o0000:Oooool001ko
oooo00?o0000ooooooooool0;oooool4o`0001;ooooo1?l0000hooooo`;o0000=_ooool2o`0003Co
oooo0_l0000Mooooo`;o00003?ooool2o`0002Wooooo000Nooooo`03o`000?oooooooooo02oooooo
1?l0000:ooooo`;o00002?ooool2o`00073ooooo0_l0000dooooo`;o00008_ooool2o`0002Kooooo
0_l0000:ooooo`007_ooool00ol0003oooooooooo`0Booooo`;o0000:Oooool2o`00083ooooo0_l0
000Yooooo`;o00004Oooool2o`0001Cooooo0_l0000Vooooo`;o00002_ooool001kooooo00?o0000
ooooooooool04_ooool2o`00067ooooo0_l00018ooooo`;o0000:Oooool2o`00017ooooo0_l0000i
ooooo`;o00003Oooool001kooooo00?o0000ooooooooool00_l0000<ooooo`;o0000IOooool2o`00
0<7ooooo0_l0000=ooooo`007_ooool2o`000003ooooool0003o000000cooooo0_l0003oooooocSo
oooo000Nooooo`03o`000?oooooooooo02Sooooo0_l00025ooooo`?o00003oooool2o`0001kooooo
0_l0000mooooo`;o00009Oooool001kooooo00?o0000ooooooooool0:?ooool2o`0008Gooooo0ol0
000?ooooo`;o00000oooool2o`0001Wooooo0_l0000mooooo`;o00009Oooool001kooooo00?o0000
ooooooooool0A_ooool2o`0003Cooooo0_l0000>ooooo`;o0000>?ooool2o`0000[ooooo0_l0000M
ooooo`;o0000C_ooool2o`0000Cooooo000Nooooo`03o`000?oooooooooo01Sooooo0_l0000/oooo
o`;o0000=?ooool2o`0000kooooo0_l00014ooooo`;o00007Oooool2o`0004kooooo0_l00004oooo
o`007_ooool00ol0003oooooooooo`0Hooooo`;o0000;oooool2o`000?cooooo000Nooooo`03o`00
0?oooooooooo04Wooooo0_l00032ooooo`;o0000>?ooool001kooooo00?o0000ooooooooool0]ooo
ool2o`0004[ooooo0_l00008ooooo`;o0000>?ooool001kooooo00?o0000ooooooooool0]oooool3
o`0002oooooo0_l0000Hooooo`;o00000oooool2o`0003gooooo000Nooooo`03o`000?oooooooooo
09Cooooo0_l000000ooooooo0000o`00000Booooo`;o00002oooool2o`0002oooooo0_l0000Moooo
o`;o0000?Oooool001kooooo00?o0000ooooooooool0B?ooool2o`0004[ooooo0_l000000ooooooo
0000o`00000Booooo`;o0000;_ooool3o`00053ooooo0_l0000Gooooo`007_ooool00ol0003ooooo
ooooo`0Nooooo`;o0000:?ooool2o`0001Cooooo0_l0001kooooo`?o00008?ooool2o`0001kooooo
0_l0000>ooooo`;o00005oooool001kooooo00?o0000ooooooooool07_ooool2o`0003kooooo0_l0
000Dooooo`;o0000I?ooool2o`0001cooooo0_l00004ooooo`;o00007_ooool2o`00013ooooo0_l0
000Eooooo`007_ooool00ol0003oooooooooo`0Xooooo`;o0000<_ooool2o`0001Kooooo0_l0000U
ooooo`;o0000?Oooool2o`0001cooooo0_l0000fooooo`;o00005Oooool001kooooo00?o0000oooo
ooooool0:?ooool2o`00027ooooo0_l0000?ooooo`;o0000?Oooool2o`0004Oooooo0_l0001Joooo
o`;o00001Oooool001kooooo00?o0000ooooooooool0Boooool2o`0006kooooo0_l0000Wooooo`;o
00006_ooool2o`0003kooooo0_l00005ooooo`007_ooool2o`0007kooooo0_l0000looooo`;o0000
@oooool2o`0004Gooooo000Nooooo`03o`000?oooooooooo07gooooo0_l0000Mooooo`;o0000Rooo
ool2o`0001cooooo000Nooooo`03o`000?oooooooooo04Sooooo0_l0000_ooooo`;o00008Oooool2
o`00027ooooo0_l0000@ooooo`;o0000E_ooool2o`0001cooooo000Nooooo`03o`000?oooooooooo
03[ooooo0_l0000<ooooo`;o00004_ooool2o`0001_ooooo0_l00014ooooo`;o00004?ooool2o`00
01Wooooo0_l0001Iooooo`007_ooool00ol0003oooooooooo`0jooooo`;o00008?ooool2o`0006Co
oooo0_l0000Looooo`;o00002_ooool2o`0000;ooooo0_l0000Tooooo`;o0000;oooool001kooooo
00Co0000ooooool0003o0000`Oooool2o`0001cooooo0_l0000>ooooo`;o00009?ooool2o`0002So
oooo0_l00005ooooo`007_ooool01?l0003oooooo`000?l0002Zooooo`;o0000?_ooool2o`0005?o
oooo0_l00005ooooo`007_ooool00ol0003oooooooooo`2[ooooo`;o00008_ooool2o`0001[ooooo
0_l0000<ooooo`;o0000C?ooool001kooooo00?o0000ooooooooool0Foooool2o`0003_ooooo0_l0
000Xooooo`;o00002oooool2o`0002Sooooo0_l00008ooooo`Co0000@?ooool001kooooo00?o0000
ooooooooool0E?ooool2o`0000Gooooo0_l0000Rooooo`;o00005oooool2o`0002Sooooo0_l0000o
ooooo`Co00003Oooool2o`00037ooooo000Mooooo`;o00002?ooool2o`0004cooooo0_l0000Yoooo
o`;o00007_ooool2o`0000kooooo0_l0000Booooo`;o0000Coooool2o`00037ooooo000Mooooo`;o
00002?ooool2o`00023ooooo0_l0001Cooooo`;o00008?ooool2o`0000kooooo0_l0000Booooo`;o
00004?ooool2o`0000_ooooo0_l0001Sooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o0000
3?ooool2o`0005?ooooo0_l0001Fooooo`;o00002oooool2o`0004Sooooo0_l0000Iooooo`007_oo
ool00ol0003oooooooooo`0=ooooo`;o00002oooool2o`00067ooooo0_l0000Kooooo`;o00004_oo
ool2o`0007cooooo0_l0000Iooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o0000K_ooool2
o`0001_ooooo0_l0000Booooo`;o0000Uoooool001kooooo00?o0000ooooooooool0Loooool2o`00
02Wooooo0_l0002Wooooo`007_ooool2o`0000oooooo0_l0001Sooooo`;o0000:Oooool2o`0005_o
oooo0_l0001:ooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o0000joooool2o`0004[ooooo
000Nooooo`03o`000?oooooooooo02Sooooo0_l0000Tooooo`;o00001_ooool2o`000003ooooool0
003o000000?ooooo0_l0000Fooooo`;o00004oooool2o`0002cooooo0_l0000oooooo`;o0000@Ooo
ool2o`0000Sooooo000Nooooo`03o`000?oooooooooo02Sooooo0_l0000Tooooo`;o00001_ooool2
o`000003ooooool0003o000000?ooooo0_l0000Fooooo`;o00004oooool2o`0002cooooo0_l0000R
ooooo`;o00005oooool2o`0000;ooooo0_l0000jooooo`;o00001Oooool2o`0000Sooooo000Noooo
o`03o`000?oooooooooo023ooooo0_l0000_ooooo`;o00009?ooool2o`0006Cooooo0_l0000Goooo
o`;o00009oooool2o`0001Gooooo0_l0000?ooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o
0000;oooool2o`0002Cooooo0_l0001]ooooo`;o00009?ooool2o`00017ooooo0_l0000Vooooo`00
7_ooool00ol0003oooooooooo`1Qooooo`;o0000Poooool2o`0002Cooooo0_l0000iooooo`007_oo
ool00ol0003oooooooooo`0Nooooo`;o00008?ooool2o`0001cooooo0_l000000ooooooo0000o`00
003Tooooo`007_ooool00ol0003oooooooooo`0Nooooo`;o00008?ooool2o`0001cooooo0_l0000Q
ooooo`;o0000<?ooool2o`0005Kooooo0_l0000jooooo`007_ooool00ol0003oooooooooo`21oooo
o`;o0000<?ooool2o`0002Gooooo0_l0000_ooooo`;o00007_ooool2o`0001[ooooo000Nooooo`03
o`000?oooooooooo00Kooooo0_l0000Nooooo`;o0000/_ooool2o`0001[ooooo0_l0000cooooo`;o
00006_ooool001kooooo00?o0000ooooooooool01_ooool2o`0001gooooo0ol00018ooooo`;o0000
E?ooool2o`0002kooooo0_l0001?ooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o00001Ooo
ool2o`0000Wooooo0_l00019ooooo`;o00002Oooool2o`00027ooooo0_l0000Vooooo`;o0000A_oo
ool2o`0003Oooooo000Nooooo`04o`000?ooooooooooooooo`;o00004?ooool2o`0000Gooooo0_l0
000Zooooo`;o00004_ooool2o`0001oooooo0_l0000Hooooo`;o00001oooool2o`0003[ooooo0_l0
000Gooooo`;o00003?ooool2o`0000_ooooo0_l0000gooooo`000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool01?l0003ooooooooo
ooooool2o`0004?ooooo0_l0000Booooo`;o0000>Oooool2o`0000?ooooo0_l0000nooooo`;o0000
5oooool2o`0000cooooo0_l00014ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`0004[ooooo
0_l00017ooooo`;o0000@_ooool2o`0005kooooo0_l00007ooooo`000oooool01Ol@413ooooooooo
oooooooo410@00_ooooo1Ol00006ooooo`?o00001Oooool2o`00043ooooo0_l00008ooooo`;o0000
Roooool2o`0005kooooo0_l00007ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo
00CoA4A4omgMgOoooooo00001oooool00ol0003oooooooooo`17ooooo`;o0000:_ooool2o`000=;o
oooo0003ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007oooo
o`03o`000?oooooooooo07?ooooo0_l0002Zooooo`;o00009_ooool000?ooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0C?ooool2o`00
01Kooooo0_l0002iooooo`;o00009_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0C?ooool2o`0001Kooooo0ol0000Loooo
o`;o0000K_ooool2o`0002cooooo0ol0000Sooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00gooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`1>ooooo`;o00005Oooool2o`00
00;ooooo0_l000000ooooooo0000o`00000Eooooo`;o0000COooool2o`0001oooooo0_l0000/oooo
o`?o00008oooool001kooooo00?o0000ooooooooool01oooool2o`0004Gooooo0_l0000Iooooo`;o
000000?oooooo`000?l000003oooool2o`0003Kooooo0_l0000Kooooo`;o0000Loooool001kooooo
00?o0000ooooooooool01oooool2o`0007Cooooo0_l0000;ooooo`;o0000:Oooool4o`0008kooooo
000Nooooo`03o`000?oooooooooo08[ooooo0_l0000:ooooo`;o00007oooool2o`0008kooooo000N
ooooo`03o`000?oooooooooo09Kooooo0_l00016ooooo`;o0000Boooool2o`0001[ooooo000Noooo
o`03o`000?oooooooooo01[ooooo0_l0000;ooooo`;o00005_ooool2o`0007Cooooo0_l0000Woooo
o`;o0000>_ooool2o`0000oooooo0_l0000Jooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o
00002oooool2o`0001Kooooo0_l0000Xooooo`;o0000;_ooool2o`0001[ooooo0_l0001Sooooo`;o
0000:oooool001kooooo00?o0000ooooooooool04_ooool2o`0005Gooooo0_l0000Jooooo`;o0000
4?ooool4o`000:cooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l00016ooooo`;o0000:Ooo
ool2o`00013ooooo0_l00002ooooo`;o00005Oooool2o`0009?ooooo000Nooooo`03o`000?oooooo
oooo05[ooooo0_l0000Iooooo`;o00009?ooool2o`0001Gooooo0_l0000Vooooo`;o0000Joooool0
01gooooo0_l00006ooooo`;o00004_ooool2o`000003ooooool0003o000005Sooooo0_l0001Soooo
o`;o0000H_ooool4o`0000Gooooo000Mooooo`;o00001_ooool2o`0001;ooooo0_l000000ooooooo
0000o`000002ooooo`;o0000/_ooool2o`0006Wooooo1?l00005ooooo`007_ooool2o`00023ooooo
0_l0002booooo`;o0000>_ooool2o`0003Kooooo000Nooooo`03o`000?oooooooooo06Cooooo0_l0
002@ooooo`;o00005oooool2o`0003Kooooo000Nooooo`03o`000?oooooooooo04_ooooo0_l0000G
ooooo`;o0000T?ooool2o`0004oooooo000Nooooo`03o`000?oooooooooo013ooooo0_l0000ioooo
o`;o00005?ooool2o`0005Kooooo0_l0000aooooo`?o00004?ooool2o`0004Kooooo000Nooooo`03
o`000?oooooooooo013ooooo0_l0001?ooooo`;o00006Oooool2o`0003_ooooo0_l000000ooooooo
0000o`00000^ooooo`?o00004?ooool2o`0002Sooooo0_l0000Aooooo`;o00002Oooool001kooooo
00?o0000ooooooooool0<_ooool2o`00027ooooo0_l0000Uooooo`;o0000:?ooool2o`0001Cooooo
0_l0001[ooooo`;o00004Oooool2o`0000Wooooo000Nooooo`03o`000?oooooooooo03;ooooo0_l0
000Qooooo`;o0000Coooool2o`0007_ooooo0_l0000Rooooo`007_ooool00ol0003oooooooooo`1J
ooooo`;o00008oooool2o`000:;ooooo0_l0000Rooooo`007_ooool00ol0003oooooooooo`08oooo
o`;o00004?ooool2o`0003kooooo0_l0000Sooooo`;o0000M_ooool2o`0002;ooooo0_l00002oooo
o`;o00009_ooool001kooooo00?o0000ooooooooool02?ooool2o`00013ooooo0_l00008ooooo`;o
0000Poooool2o`0004cooooo0_l0000Rooooo`;o00000_ooool2o`0000Sooooo0_l0000Looooo`00
7_ooool00ol0003oooooooooo`0Tooooo`;o0000Poooool2o`0002Wooooo0_l00013ooooo`;o0000
3_ooool2o`0000_ooooo0_l0000?ooooo`007_ooool00ol0003oooooooooo`2Xooooo`;o0000:_oo
ool2o`0004?ooooo0_l0000Kooooo`;o00003oooool001kooooo00?o0000ooooooooool02?ooool2
o`0005Wooooo0_l00008ooooo`;o0000>Oooool2o`0008Oooooo0_l0000Dooooo`007_ooool00ol0
003oooooooooo`08ooooo`;o0000FOooool2o`0000Sooooo0_l0000Pooooo`;o00005oooool2o`00
01Kooooo0_l0000Fooooo`;o0000Eoooool2o`0001Cooooo000Nooooo`03o`000?oooooooooo05oo
oooo0_l0000Qooooo`;o00002oooool2o`0001Oooooo0_l0000Fooooo`;o00005_ooool2o`0006go
oooo000Nooooo`03o`000?oooooooooo01cooooo0_l0000Qooooo`;o00006oooool2o`000003oooo
ool0003o000001Gooooo0_l0000:ooooo`;o0000@oooool2o`0000kooooo0_l0001^ooooo`007_oo
ool2o`00013ooooo0_l0000;ooooo`;o00007oooool4o`0001_ooooo0_l0000Hooooo`;o0000?_oo
ool2o`0000?ooooo0_l0000:ooooo`;o00003_ooool2o`0005;ooooo0_l000000ooooooo0000o`00
000Gooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o00005Oooool2o`0001Gooooo0_l0001F
ooooo`;o00007oooool2o`0000?ooooo0_l0000booooo`;o0000>_ooool2o`000003ooooool0003o
000001Oooooo000Nooooo`03o`000?oooooooooo02Kooooo0_l0000Jooooo`;o0000DOooool2o`00
02?ooooo0_l0000cooooo`;o00003Oooool2o`0004Oooooo000Nooooo`03o`000?oooooooooo037o
oooo0_l0000?ooooo`;o00007oooool2o`0002?ooooo0_l0000/ooooo`;o00000_ooool2o`0004;o
oooo0_l00017ooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o00005Oooool2o`0002Gooooo
0_l00009ooooo`;o00008oooool4o`0002[ooooo0_l0000Zooooo`;o00007oooool2o`0000gooooo
0_l0000cooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o00001oooool2o`0000cooooo0_l0
000Uooooo`;o00001Oooool2o`0001gooooo0_l0000:ooooo`;o00009Oooool2o`0002gooooo1?l0
000Oooooo`;o00001oooool2o`0000Cooooo0_l0000cooooo`007_ooool00ol0003oooooooooo`0S
ooooo`;o0000>_ooool2o`0001gooooo0_l00008ooooo`;o00009oooool2o`0000Oooooo0_l0000T
ooooo`;o00008_ooool2o`0000Kooooo0_l0000Mooooo`;o00006_ooool001kooooo00?o0000oooo
ooooool0R?ooool2o`00033ooooo0_l00004ooooo`;o00003Oooool2o`0001oooooo0_l0000Boooo
o`;o00009Oooool2o`0001[ooooo000Nooooo`03o`000?oooooooooo02kooooo0_l0000booooo`;o
00002Oooool2o`000003ooooool0003o000003?ooooo0_l0000Iooooo`;o00003Oooool2o`0001oo
oooo0_l0001Eooooo`007_ooool00ol0003oooooooooo`0^ooooo`;o0000<_ooool2o`0000Wooooo
0_l000000ooooooo0000o`00000cooooo`;o0000?_ooool2o`0003Cooooo0_l0000Zooooo`007_oo
ool00ol0003oooooooooo`0[ooooo`;o0000^?ooool2o`0003Cooooo0_l0000Dooooo`;o00005?oo
ool001kooooo00?o0000ooooooooool0:oooool2o`000<7ooooo0_l00011ooooo`;o00005?ooool0
01kooooo00?o0000ooooooooool0?oooool2o`0008_ooooo0_l0000?ooooo`;o00003oooool2o`00
04;ooooo0_l0000Cooooo`007_ooool00ol0003oooooooooo`0Eooooo`;o00007_ooool2o`0000So
oooo0_l0002;ooooo`;o00003oooool2o`0001Wooooo0_l0000>ooooo`;o00005_ooool2o`00013o
oooo0_l0000Cooooo`007_ooool00ol0003oooooooooo`03ooooo`;o00004?ooool2o`0001kooooo
0_l00021ooooo`;o0000=?ooool2o`0000Sooooo0_l0000>ooooo`;o00005_ooool2o`0002Gooooo
000Nooooo`03o`000?oooooooooo00?ooooo0_l000000ooooooo0000o`00002`ooooo`;o0000=?oo
ool2o`0005Oooooo000Nooooo`;o00001oooool2o`000:3ooooo0_l0002Mooooo`007_ooool01?l0
003oooooo`000?l0001Mooooo`;o00005Oooool2o`00013ooooo0ol0000Nooooo`;o0000;oooool2
o`0000_ooooo0_l00005ooooo`;o0000;oooool2o`0002Oooooo000Nooooo`03o`000?oooooo0000
00;o00005oooool2o`0004?ooooo0_l0000Eooooo`;o00004?ooool3o`0003?ooooo0_l0000Joooo
o`;o00000_ooool2o`0000Oooooo0_l00005ooooo`;o0000;oooool2o`0002Oooooo000Nooooo`03
o`000?oooooooooo00;o00005oooool2o`0000Kooooo0_l0000Iooooo`;o0000Ooooool2o`0000So
oooo0_l0000Dooooo`;o00005oooool2o`0004oooooo000Nooooo`03o`000?oooooooooo027ooooo
0_l0000Iooooo`;o00001Oooool2o`0005;ooooo0_l0000^ooooo`;o0000;Oooool2o`0000_ooooo
0_l00012ooooo`007_ooool00ol0003oooooooooo`13ooooo`;o0000D_ooool2o`0003Wooooo0_l0
000_ooooo`;o0000@_ooool001kooooo00?o0000ooooooooool0`_ooool2o`0000kooooo0_l0001c
ooooo`007_ooool00ol0003oooooooooo`1fooooo`;o0000B_ooool2o`0002Cooooo0_l0001Moooo
o`007_ooool00ol0003oooooooooo`1fooooo`;o0000L?ooool2o`0005gooooo000Nooooo`03o`00
0?oooooooooo09Cooooo0_l00009ooooo`;o00008?ooool2o`0005gooooo0_l0000Uooooo`007_oo
ool00ol0003oooooooooo`2Dooooo`;o00002Oooool2o`00023ooooo0_l00013ooooo`;o00003ooo
ool2o`0000Oooooo0_l0000Uooooo`007_ooool00ol0003oooooooooo`0]ooooo`;o0000;oooool2
o`00053ooooo0_l0001Dooooo`;o00003oooool2o`0000[ooooo0_l0000Kooooo`;o00001Oooool0
01kooooo00?o0000ooooooooool0;Oooool2o`0001?ooooo0_l0000Booooo`;o00001_ooool2o`00
053ooooo0_l0001]ooooo`;o00000_ooool2o`0001_ooooo0_l00005ooooo`007_ooool00ol0003o
ooooooooo`0Booooo`;o0000;_ooool2o`0001;ooooo0_l0002[ooooo`;o00006_ooool2o`0002Ko
oooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0
003o410@olc<c006ooooo`03o`000?oooooooooo01;ooooo0_l0000>ooooo`;o00000oooool2o`00
0=[ooooo0_l00012ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0Rooooo`;o00000oooool2
o`0001oooooo0_l0000nooooo`;o0000_Oooool000?ooooo00Go410@oooooooooooooooooa0@400;
ooooo`05o`000?ooooooooooooooool000001_ooool3o`0003;ooooo0_l0000Dooooo`;o00009_oo
ool2o`0001Kooooo0_l00005ooooo`;o0000Foooool2o`0005Wooooo0003ooooo`05o`000?oooooo
ooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0
2?ooool2o`0001?ooooo0_l0000Cooooo`;o0000:oooool2o`0000oooooo0_l0000Mooooo`;o0000
D_ooool2o`0000Oooooo0_l0001Iooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo
00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo00Sooooo0_l0000Cooooo`;o
0000@?ooool2o`0008;ooooo0_l0001Rooooo`000oooool01Ol@413ooooooooooooooooo410@00_o
oooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`3:ooooo`;o0000Noooool000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000oooooooo
ool0b_ooool2o`0003kooooo0_l0000Yooooo`;o00004?ooool000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0@oooool2o`00
07Gooooo0_l00005ooooo`;o0000Aoooool2o`0002Wooooo0_l0000@ooooo`007Oooool2o`0003ko
oooo0_l00005ooooo`;o0000MOooool2o`0000Gooooo0_l0000Mooooo`;o0000IOooool001gooooo
0_l0000<ooooo`;o00006oooool2o`0001?ooooo0_l0000eooooo`;o0000Joooool2o`0004?ooooo
0_l0000Pooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o000000?oooooo`000?l000003ooo
ool2o`0000Oooooo0_l0001:ooooo`;o0000/?ooool2o`00023ooooo000Nooooo`03o`000?oooooo
oooo00gooooo0_l0000?ooooo`;o00009?ooool2o`0008_ooooo0_l00004ooooo`;o0000I?ooool2
o`0000Sooooo000Nooooo`03o`000?oooooooooo04Cooooo0_l00012ooooo`;o0000Aoooool2o`00
00Cooooo0_l0000[ooooo`;o0000=oooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo05ko
oooo0_l0000Xooooo`;o0000;_ooool2o`0004[ooooo0_l0000<ooooo`;o00007oooool4o`00013o
oooo000Nooooo`03o`000?oooooooooo03oooooo0_l0000Mooooo`;o00003Oooool2o`0004Wooooo
0_l00015ooooo`;o00004Oooool2o`0001oooooo1?l0000@ooooo`007_ooool00ol0003ooooooooo
o`0/ooooo`;o00004Oooool2o`0002cooooo0_l0000Oooooo`;o00005_ooool2o`0005Oooooo0_l0
0016ooooo`007_ooool00ol0003oooooooooo`0/ooooo`;o0000H?ooool2o`0001Kooooo0_l0002O
ooooo`007_ooool00ol0003oooooooooo`1?ooooo`;o0000Roooool2o`0004gooooo0_l0000Joooo
o`007_ooool00ol0003oooooooooo`1?ooooo`;o00001_ooool2o`0000Cooooo0_l0000/ooooo`;o
0000@Oooool2o`0000cooooo0_l0000Vooooo`;o00002Oooool2o`0001[ooooo0_l0000Jooooo`00
7_ooool2o`0005Sooooo0_l00003ooooo`Go0000:_ooool2o`00047ooooo0_l0000dooooo`;o0000
2Oooool2o`0002Gooooo0_l0000?ooooo`007_ooool00ol0003oooooooooo`1Jooooo`Co000000?o
ooooo`000?l00000>oooool2o`0002Wooooo0_l0001]ooooo`;o000000?oooooo`000?l000000_l0
000:ooooo`007_ooool00ol0003oooooooooo`1Jooooo`;o00009oooool2o`00017ooooo0_l00004
ooooo`;o0000:Oooool2o`0000Gooooo0_l0001Yooooo`Co00002_ooool001kooooo00?o0000oooo
ooooool0=Oooool2o`0004cooooo0_l0000Aooooo`;o0000=?ooool4o`0007Oooooo000Nooooo`03
o`000?oooooooooo00Gooooo0_l0000^ooooo`;o00007?ooool2o`00047ooooo0_l0000dooooo`;o
00006_ooool2o`0005gooooo000Nooooo`03o`000?oooooooooo00Gooooo0_l0001<ooooo`;o0000
9_ooool2o`0001Wooooo0_l0001@ooooo`;o0000GOooool001kooooo00?o0000ooooooooool0;_oo
ool2o`00027ooooo0_l0000Xooooo`;o0000IOooool2o`0002Oooooo0_l0000Qooooo`;o00005ooo
ool001kooooo00?o0000ooooooooool00_l00003ooooo`;o00008?ooool2o`0000Gooooo0_l0000P
ooooo`?o0000;_ooool2o`0005oooooo0_l00004ooooo`;o00008Oooool2o`00027ooooo0_l0000G
ooooo`007_ooool00ol0003oooooooooo`02o`0000?ooooo0_l0000Pooooo`;o00009oooool2o`00
02oooooo0_l0001Tooooo`?o0000GOooool001kooooo00?o0000ooooooooool0B?ooool2o`0009go
oooo0_l0000Iooooo`;o0000:Oooool2o`0001Sooooo000Nooooo`03o`000?oooooooooo04;ooooo
0_l00004ooooo`;o00002_ooool2o`000:?ooooo1?l00005ooooo`;o0000:Oooool2o`0001Sooooo
000Nooooo`03o`000?oooooooooo04;ooooo0_l0000@ooooo`;o00002?ooool4o`0009Oooooo1?l0
001:ooooo`007_ooool00ol0003oooooooooo`04ooooo`;o00001Oooool2o`0002kooooo0_l0000Q
ooooo`Co0000?Oooool2o`00027ooooo0_l0000Cooooo`;o0000COooool2o`0001oooooo000Noooo
o`03o`000?oooooooooo00Cooooo0_l00005ooooo`;o00006_ooool2o`0001;ooooo0_l0001Roooo
o`;o00008Oooool2o`0001?ooooo0_l0000`ooooo`;o00006oooool2o`0001oooooo000Nooooo`03
o`000?oooooooooo02Oooooo0_l00034ooooo`;o00006_ooool2o`0003cooooo000Nooooo`03o`00
0?oooooooooo06;ooooo0_l0000:ooooo`;o00004oooool2o`0004Kooooo0_l0000>ooooo`;o0000
4?ooool2o`00023ooooo0_l0000]ooooo`;o00001oooool001kooooo0_l0000Jooooo`;o0000Aooo
ool3o`0000Wooooo0_l0000Cooooo`;o0000A_ooool2o`0000kooooo0_l0000booooo`;o00003ooo
ool2o`0001cooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o00003oooool2
o`0002_ooooo0_l0000:ooooo`;o0000M_ooool2o`0004?ooooo0_l0000Uooooo`007_ooool00ol0
003oooooooooo`02ooooo`;o00009_ooool2o`0001?ooooo0_l0000Fooooo`;o0000P_ooool2o`00
00_ooooo0_l0001Booooo`;o00002Oooool001kooooo00?o0000ooooooooool00_ooool2o`0003_o
oooo0_l0000Uooooo`;o0000P?ooool2o`0005;ooooo0_l00009ooooo`007_ooool2o`0004Cooooo
0_l0000Qooooo`;o0000?Oooool2o`0001oooooo0_l0001oooooo`007_ooool2o`0000;ooooo0_l0
0010ooooo`;o0000H?ooool2o`0001oooooo0_l0000^ooooo`;o0000@Oooool2o`0000cooooo000N
ooooo`;o00000_ooool2o`0005oooooo0_l0001Oooooo`;o000000?oooooo`000?l00000;_ooool2
o`00047ooooo0_l0000<ooooo`007_ooool01?l0003oooooooooooooool2o`0005[ooooo0_l00003
ooooo`;o0000Goooool2o`000003ooooool0003o000007oooooo000Nooooo`04o`000?oooooooooo
ooooo`;o0000F_ooool2o`00013ooooo0_l0001looooo`;o0000F?ooool001kooooo00?o0000oooo
ooooool0J_ooool2o`0000?ooooo0_l0000Uooooo`;o0000EOooool2o`0005Sooooo000Nooooo`03
o`000?oooooooooo01Wooooo0_l0001?ooooo`;o0000:_ooool2o`0002cooooo0_l0001Gooooo`;o
0000:?ooool001kooooo00?o0000ooooooooool06Oooool2o`000:Wooooo0_l0001Gooooo`;o0000
5oooool2o`0000oooooo000Nooooo`03o`000?oooooooooo04Oooooo0_l0003]ooooo`;o00003ooo
ool001kooooo00?o0000ooooooooool05_ooool2o`0002oooooo0_l0000:ooooo`;o0000Woooool2
o`0001kooooo0_l0000aooooo`007_ooool00ol0003oooooooooo`0Fooooo`;o00001oooool2o`00
03;ooooo0_l0000Eooooo`;o0000Boooool2o`0001Wooooo0_l0000@ooooo`;o00003_ooool2o`00
01kooooo0_l0000aooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o0000BOooool2o`0004_o
oooo0_l0000Iooooo`;o00004?ooool2o`0002gooooo0_l0000booooo`007_ooool2o`000?oooooo
5Oooool2o`0003;ooooo000Nooooo`03o`000?oooooooooo02_ooooo0_l0000?ooooo`;o0000Dooo
ool2o`0001Sooooo0_l0002Jooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o00002Oooool2
o`0000kooooo0ol0001=ooooo`;o00001?ooool2o`0001Sooooo0_l0001_ooooo`;o00005?ooool2
o`0001?ooooo000Nooooo`03o`000?oooooooooo00;o00007_ooool2o`0001Cooooo0_l00003oooo
o`?o0000Aoooool2o`0000Cooooo0_l0001Kooooo`;o0000;?ooool2o`0000Cooooo0_l0000Doooo
o`;o00004oooool001kooooo00?o0000ooooooooool00_l0000dooooo`;o000000Coooooo`000?l0
003ooooo0_l00017ooooo`;o0000AOooool2o`0001[ooooo0_l0000/ooooo`;o00007oooool2o`00
00kooooo000Nooooo`03o`000?oooooooooo00oooooo0_l0000Xooooo`;o0000B?ooool4o`0002_o
oooo0_l0000Hooooo`;o0000JOooool2o`0000kooooo000Nooooo`03o`000?oooooooooo00oooooo
0_l0001booooo`Co00007_ooool2o`0000_ooooo0_l0002Cooooo`007_ooool00ol0003ooooooooo
o`1Uooooo`;o0000?_ooool2o`00023ooooo0_l0001:ooooo`;o0000<_ooool001kooooo00?o0000
ooooooooool0COooool2o`0001Kooooo0_l000000ooooooo0000o`00001Mooooo`;o00008_ooool2
o`0002Kooooo0_l0000booooo`007_ooool00ol0003oooooooooo`1=ooooo`;o00002Oooool2o`00
00kooooo0_l0000Hooooo`;o00000_ooool2o`0000Wooooo0_l00019ooooo`;o00003Oooool2o`00
03Gooooo0_l0000Sooooo`007_ooool00ol0003oooooooooo`0]ooooo`;o00005oooool2o`00013o
oooo0_l0000Xooooo`;o00000_ooool2o`0000Wooooo0_l00019ooooo`;o00009?ooool2o`0001ko
oooo0_l0000Sooooo`007_ooool00ol0003oooooooooo`0]ooooo`;o00005oooool2o`000:[ooooo
0_l00007ooooo`;o00001Oooool2o`0004?ooooo000Nooooo`03o`000?oooooooooo05cooooo0_l0
000Xooooo`;o0000J_ooool2o`0000Oooooo0_l0000Dooooo`;o0000=?ooool001kooooo00?o0000
ooooooooool01_ooool2o`0000Wooooo0_l0000Hooooo`;o0000;oooool2o`0002Sooooo0_l0000N
ooooo`;o0000JOooool2o`0003Cooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo00Cooooo1?l0
0009ooooo`;o00006?ooool2o`0000Wooooo0_l0001>ooooo`;o00003Oooool2o`0000oooooo0_l0
002Oooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`04ooooo`;o000000?oooooo`000?l00000
1?ooool2o`0002Oooooo0_l0000`ooooo`;o00001?ooool2o`0001Kooooo0_l0000=ooooo`;o0000
A?ooool2o`0000Kooooo0_l0001Rooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo
00Go0000ooooooooooooooooo`000006ooooo`Co00001_ooool2o`0000Cooooo0_l0001Iooooo`;o
000000Coooooo`000?l0003ooooo0_l0000Nooooo`;o00007?ooool2o`0002gooooo0_l00006oooo
o`;o0000H_ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9Sooooo
oiRHV?lb<S801_ooool01?l0003oooooo`000?l0001Qooooo`;o00001oooool2o`00027ooooo0_l0
000Looooo`;o0000=Oooool2o`0006;ooooo0003ooooo`05o`000?ooooooooooooooool000002ooo
ool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool07?ooool2o`0000[ooooo
0_l0000hooooo`;o0000hoooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@
4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`0Looooo`;o00002_ooool2o`0003Wo
oooo0_l0001]ooooo`;o0000;Oooool2o`0004Cooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0>Oooool2o`00
02Sooooo0_l0001]ooooo`;o00003Oooool2o`0001kooooo0_l0000Oooooo`;o00000oooool2o`00
01kooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413o
ZJVY00Kooooo00?o0000ooooooooool0>Oooool2o`0001Oooooo0_l0000;ooooo`;o0000A_ooool2
o`0003Sooooo0_l0000oooooo`;o00000oooool2o`0001kooooo000Nooooo`03o`000?oooooooooo
01_ooooo0_l0000Dooooo`;o00007oooool2o`0000_ooooo0_l0000looooo`;o00002?ooool2o`00
01Oooooo0_l0001^ooooo`;o000000?oooooo`000?l000004_ooool001kooooo00?o0000oooooooo
ool06oooool2o`0001Cooooo0_l0001Zooooo`;o00003Oooool2o`0001;ooooo0_l0000iooooo`;o
0000<oooool2o`000003ooooool0003o000001;ooooo000Nooooo`03o`000?oooooooooo04Gooooo
0_l0000`ooooo`;o0000<oooool2o`0003kooooo0_l0000=ooooo`;o0000B_ooool001kooooo00?o
0000ooooooooool0AOooool2o`00027ooooo0_l0000=ooooo`;o0000C_ooool2o`0002?ooooo0_l0
001Iooooo`007_ooool00ol0003oooooooooo`1@ooooo`;o00005_ooool2o`0005Wooooo0_l00002
ooooo`;o0000O_ooool001kooooo00?o0000ooooooooool08oooool2o`0001Sooooo0_l0000Aoooo
o`;o00005oooool2o`0005Sooooo0_l0000Kooooo`;o0000:oooool2o`0000Oooooo0_l0000_oooo
o`007_ooool00ol0003oooooooooo`0Sooooo`;o00001oooool2o`0000oooooo0_l0000>ooooo`;o
00006_ooool2o`00037ooooo0_l0000Hooooo`;o0000:?ooool2o`0001cooooo0_l0000=ooooo`;o
00001oooool2o`0002oooooo000Nooooo`03o`000?oooooooooo02cooooo0_l0000Oooooo`;o0000
>_ooool2o`00017ooooo0_l0000Hooooo`;o0000A_ooool2o`0000[ooooo0_l0000?ooooo`;o0000
8_ooool3o`0000Gooooo000Nooooo`03o`000?oooooooooo08Wooooo0_l00007ooooo`;o00003Ooo
ool2o`0006Oooooo0_l00007ooooo`;o00001_ooool2o`0002;ooooo0ol00005ooooo`007_ooool0
0ol0003oooooooooo`2?ooooo`;o000000?oooooo`000?l000003Oooool2o`0004gooooo0_l0000Q
ooooo`;o0000<_ooool001kooooo00?o0000ooooooooool0=?ooool2o`0005Wooooo0_l0000@oooo
o`;o00003_ooool2o`0003gooooo0_l0000Eooooo`;o00008Oooool2o`0001_ooooo000Nooooo`Co
0000<oooool2o`00023ooooo0_l0000Pooooo`;o00006oooool2o`0001[ooooo0_l0000oooooo`;o
00004oooool2o`00027ooooo0_l0000Kooooo`007_ooool01?l0003oooooo`000?l0000Pooooo`;o
0000<oooool2o`0001Wooooo0_l00005ooooo`;o00006oooool2o`0005_ooooo0_l0001Cooooo`00
7_ooool00ol0003oooooooooo`0Qooooo`;o0000C_ooool2o`000=Cooooo000Nooooo`03o`000?oo
oooooooo01;ooooo0_l0003[ooooo`;o0000A_ooool001kooooo00?o0000ooooooooool03_ooool6
o`0001oooooo0ol00005ooooo`;o0000`_ooool2o`0004Kooooo000Nooooo`03o`000?oooooooooo
00kooooo1?l0000Qooooo`?o00001Oooool2o`0006Cooooo0_l0000eooooo`;o0000C?ooool2o`00
01oooooo000Nooooo`03o`000?oooooooooo04_ooooo0_l0001>ooooo`;o00001?ooool2o`0000?o
oooo0_l0000`ooooo`;o0000C?ooool2o`0001oooooo000Nooooo`03o`000?oooooooooo00Kooooo
0_l00013ooooo`;o0000C_ooool2o`0000Wooooo0_l00018ooooo`;o0000BOooool2o`0000[ooooo
000Nooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o00002oooool2o`0004kooooo0_l0
0006ooooo`;o00002Oooool2o`0003Kooooo0_l00010ooooo`;o0000:?ooool2o`0000Cooooo0_l0
000Iooooo`;o00002_ooool001gooooo0_l00004ooooo`;o00003oooool2o`0004Kooooo0_l00006
ooooo`;o00001_ooool2o`0000Wooooo0_l0000fooooo`;o0000J_ooool2o`0000Cooooo0_l00003
ooooo`;o00001?ooool2o`0001[ooooo000Mooooo`;o00001?ooool2o`0005Oooooo0_l0000ooooo
o`;o0000?Oooool2o`0002?ooooo0_l0000Sooooo`;o00001?ooool2o`0001[ooooo000Nooooo`03
o`000?oooooooooo00;ooooo0_l0000;ooooo`;o0000Roooool2o`0003gooooo0_l0000Sooooo`;o
0000AOooool001kooooo00?o0000ooooooooool03oooool2o`0003Kooooo0_l0000Eooooo`;o0000
ioooool001kooooo00?o0000ooooooooool05?ooool2o`0002oooooo1?l0000Eooooo`;o00005?oo
ool2o`000=7ooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0000_ooooo`;o0000;Oooool2
o`0001Kooooo0_l0002Jooooo`;o00007Oooool001kooooo00?o0000ooooooooool05Oooool2o`00
00Kooooo0_l0001]ooooo`;o0000:oooool2o`00023ooooo0_l0001;ooooo`;o00002Oooool2o`00
01;ooooo000Nooooo`;o00005_ooool2o`0000Kooooo0_l0000Oooooo`;o0000C_ooool2o`0002Wo
oooo0_l0000<ooooo`;o00004_ooool2o`0005Gooooo0ol0000Booooo`007_ooool00ol0003ooooo
ooooo`0Iooooo`;o00008oooool2o`0004kooooo0_l00006ooooo`;o0000;oooool2o`0002Wooooo
0_l0000Nooooo`;o00000oooool2o`0001Wooooo0_l0000Cooooo`007Oooool2o`0001_ooooo0_l0
000cooooo`;o0000@_ooool2o`0000;ooooo0_l0001Jooooo`;o00007_ooool2o`0000?ooooo0_l0
000^ooooo`007Oooool2o`00053ooooo0_l00002ooooo`;o0000?_ooool2o`0004oooooo0_l0000N
ooooo`;o0000@_ooool001kooooo00?o0000ooooooooool0D_ooool2o`0008oooooo0_l0000Noooo
o`Co0000@?ooool001kooooo00?o0000ooooooooool03oooool2o`0000oooooo0_l0003@ooooo`;o
00004Oooool2o`00043ooooo000Nooooo`03o`000?oooooooooo00oooooo0_l0000?ooooo`;o0000
d?ooool2o`0002oooooo0_l0000Rooooo`007_ooool00ol0003oooooooooo`11ooooo`;o0000B_oo
ool2o`0002gooooo0_l0001Uooooo`;o00005oooool2o`0000Wooooo000Nooooo`03o`000?oooooo
oooo047ooooo0_l0001:ooooo`;o00003oooool2o`0001cooooo0_l0001nooooo`;o00002Oooool0
01kooooo00?o0000ooooooooool0W_ooool2o`0002;ooooo0_l0000Kooooo`?o0000IOooool001ko
oooo00?o0000ooooooooool02?ooool2o`0003_ooooo0_l0001Wooooo`;o00004_ooool2o`0001_o
oooo0ol0000Wooooo`;o0000<oooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo00Sooooo
0_l0000kooooo`;o0000Ioooool2o`0005Wooooo0_l0000Cooooo`;o00007_ooool2o`0000Oooooo
000Nooooo`03o`000?oooooooooo017ooooo0_l0001Mooooo`;o0000M_ooool2o`0002cooooo0_l0
0006ooooo`;o00004?ooool2o`0001Gooooo000Nooooo`03o`000?oooooooooo017ooooo0_l0000`
ooooo`;o0000:oooool2o`0004_ooooo0_l0000Yooooo`;o0000;?ooool2o`0001Sooooo0_l0000E
ooooo`007_ooool00ol0003oooooooooo`13ooooo`;o00004Oooool2o`0004[ooooo0_l00002oooo
o`;o00005Oooool2o`0000Cooooo0_l0001Rooooo`;o00007_ooool001kooooo00?o0000oooooooo
ool0E_ooool2o`00047ooooo0_l00007ooooo`;o00000_ooool2o`0001_ooooo0_l0000looooo`;o
00007?ooool2o`0000Kooooo0_l0000Nooooo`007_ooool2o`00077ooooo0_l0000Wooooo`;o0000
3oooool2o`0000Oooooo0_l0000Dooooo`;o0000;?ooool2o`0000Sooooo0_l0000Booooo`;o0000
2?ooool2o`0002Kooooo000Nooooo`03o`000?oooooooooo073ooooo0_l0000hooooo`;o00001ooo
ool2o`0001Cooooo0_l0000/ooooo`;o00007?ooool2o`00033ooooo000Nooooo`03o`000?oooooo
oooo02cooooo0_l0000Tooooo`;o0000M_ooool2o`0007_ooooo000Nooooo`03o`000?oooooooooo
02cooooo0_l0000Fooooo`;o00003?ooool2o`0003Cooooo0_l0000cooooo`;o00002oooool2o`00
07_ooooo000Nooooo`03o`000?oooooooooo04Cooooo0_l0000fooooo`;o00002_ooool2o`0003?o
oooo0_l0000;ooooo`;o0000Noooool001kooooo00?o0000ooooooooool0Noooool3o`0004Kooooo
0_l00021ooooo`007_ooool00ol0003oooooooooo`1Zooooo`;o00003oooool2o`0004Oooooo0_l0
0021ooooo`007_ooool00ol0003oooooooooo`1Zooooo`;o00002oooool2o`000<kooooo000Noooo
o`03o`000?oooooooooo05Gooooo0_l0000Pooooo`;o0000C?ooool2o`00083ooooo000Nooooo`03
o`000?oooooooooo05Gooooo0_l0000eooooo`;o0000=oooool2o`0003Kooooo0_l0000nooooo`;o
00002?ooool001kooooo00?o0000ooooooooool08_ooool2o`0006Sooooo0_l0000Cooooo`;o0000
BOooool3o`0000kooooo0_l0000Nooooo`;o00002?ooool2o`00017ooooo0_l000000ooooooo0000
o`000008ooooo`007_ooool00ol0003oooooooooo`0Rooooo`;o0000OOooool2o`0004?ooooo0_l0
0004ooooo`?o0000;_ooool2o`0000Sooooo0_l0000Aooooo`;o00002oooool001kooooo00?o0000
ooooooooool0?oooool2o`0005?ooooo0_l0000aooooo`;o00005?ooool2o`0000?ooooo0_l00002
ooooo`;o0000Goooool001kooooo00?o0000ooooooooool0?oooool2o`0004;ooooo0_l0000?oooo
o`;o00004oooool2o`0001Sooooo0_l00002ooooo`;o00005?ooool2o`0000?ooooo0_l0001Ioooo
o`;o00002?ooool001Cooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo03Oo
oooo0_l0001:ooooo`;o00009?ooool2o`0001Sooooo0_l0000Iooooo`;o00002oooool2o`00053o
oooo0_l00008ooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo023ooooo
0_l0000Eooooo`;o00002Oooool2o`0006cooooo0_l0000/ooooo`;o00002oooool2o`0005[ooooo
000Fooooo`03o`000?oooooooooo00Gooooo0ol0000Pooooo`;o00008?ooool2o`0006cooooo0_l0
000?ooooo`;o0000M?ooool2o`0000kooooo000Fooooo`03o`000?oooooooooo0<Wooooo0_l0001d
ooooo`;o00003_ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003o
ooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Cooooo00?o
EEEEofIVI_l00000oooooomBooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.49414 .88082 Mdot
.53234 .40274 Mdot
.51978 .92234 Mdot
.9202 .25869 Mdot
.05533 .89815 Mdot
.72558 .55824 Mdot
.39536 .40137 Mdot
.34489 .78489 Mdot
.38472 .46982 Mdot
.82599 .03767 Mdot
.5744 .30035 Mdot
.55043 .44666 Mdot
.23498 .77695 Mdot
.95984 .96527 Mdot
.60067 .2969 Mdot
.83545 .84427 Mdot
.28529 .88368 Mdot
.9329 .56575 Mdot
.05991 .92692 Mdot
.45925 .43743 Mdot
.69408 .48079 Mdot
.01948 .06728 Mdot
.25109 .76379 Mdot
.46689 .9423 Mdot
.48527 .15837 Mdot
.81145 .22098 Mdot
.72652 .27312 Mdot
.48973 .38774 Mdot
.67796 .33976 Mdot
.31997 .76069 Mdot
.28787 .73994 Mdot
.03687 .92535 Mdot
.25961 .61592 Mdot
.20114 .13891 Mdot
.56516 .59556 Mdot
.47424 .40497 Mdot
.74891 .7225 Mdot
.3751 .84186 Mdot
.44813 .55493 Mdot
.8162 .1582 Mdot
.32512 .60723 Mdot
.61327 .34141 Mdot
.13655 .871 Mdot
.0825 .72711 Mdot
.22569 .69986 Mdot
.82221 .51253 Mdot
.1407 .50648 Mdot
.92193 .1564 Mdot
.66382 .00197 Mdot
.67579 .85162 Mdot
.30037 .79068 Mdot
.89248 .42101 Mdot
.31271 .25891 Mdot
.98495 .35791 Mdot
.47818 .16792 Mdot
.23568 .62362 Mdot
.18525 .91673 Mdot
.88524 .56435 Mdot
.93214 .49635 Mdot
.97448 .43874 Mdot
.45796 .66997 Mdot
.25991 .63988 Mdot
.30101 .33459 Mdot
.58682 .92162 Mdot
.65121 .5774 Mdot
.50874 .22244 Mdot
.8383 .35948 Mdot
.62488 .69911 Mdot
.55008 .91477 Mdot
.01842 .02423 Mdot
.56799 .49761 Mdot
.40873 .72154 Mdot
.25808 .84749 Mdot
.66595 .21301 Mdot
.79467 .96935 Mdot
.05129 .34883 Mdot
.43558 .24706 Mdot
.94197 .59143 Mdot
.54541 .48775 Mdot
.55272 .92803 Mdot
.58081 .98035 Mdot
.34832 .43511 Mdot
.23827 .29187 Mdot
.386 .49544 Mdot
.14377 .78924 Mdot
.38358 .82563 Mdot
.69009 .59412 Mdot
.58711 .11673 Mdot
.583 .38791 Mdot
.85331 .25371 Mdot
.89464 .21677 Mdot
.06912 .8669 Mdot
.44767 .84988 Mdot
.04636 .14247 Mdot
.55117 .19062 Mdot
.76618 .73212 Mdot
.78479 .9592 Mdot
.83743 .68815 Mdot
.44013 .83477 Mdot
.78204 .05494 Mdot
.70946 .09738 Mdot
.77937 .3454 Mdot
.9823 .63938 Mdot
.04695 .14933 Mdot
.20433 .04885 Mdot
.16199 .26725 Mdot
.89905 .51841 Mdot
.34932 .03845 Mdot
.15188 .56884 Mdot
.03263 .48421 Mdot
.09726 .89042 Mdot
.45414 .45267 Mdot
.45049 .74252 Mdot
.02149 .48063 Mdot
.64074 .31066 Mdot
.9929 .68175 Mdot
.84254 .62219 Mdot
.29355 .07184 Mdot
.30261 .92807 Mdot
.74729 .77229 Mdot
.78569 .80838 Mdot
.50399 .8466 Mdot
.36398 .15557 Mdot
.24939 .38096 Mdot
.23321 .14503 Mdot
.27167 .70939 Mdot
.99337 .72287 Mdot
.33329 .29665 Mdot
.99479 .79517 Mdot
.46653 .35475 Mdot
.92654 .51428 Mdot
.51973 .28603 Mdot
.46873 .07529 Mdot
.89293 .17029 Mdot
.46526 .04444 Mdot
.47571 .93953 Mdot
.45865 .18029 Mdot
.18971 .97467 Mdot
.7544 .99631 Mdot
.37697 .86534 Mdot
.4345 .74033 Mdot
.7223 .80088 Mdot
.94491 .25002 Mdot
.44024 .79094 Mdot
.2382 .23579 Mdot
.17777 .81499 Mdot
.33939 .68047 Mdot
.56706 .50916 Mdot
.98524 .63334 Mdot
.81018 .28134 Mdot
.31136 .95527 Mdot
.75046 .59074 Mdot
.51368 .68428 Mdot
.97418 .63476 Mdot
.73714 .41526 Mdot
.18387 .68004 Mdot
.83154 .22129 Mdot
.42423 .98895 Mdot
.34405 .42935 Mdot
.39683 .35145 Mdot
.81714 .97665 Mdot
.6651 .59377 Mdot
.03211 .7686 Mdot
.31936 .99123 Mdot
.81005 .31071 Mdot
.64421 .15363 Mdot
.46455 .87796 Mdot
.66323 .9549 Mdot
.13279 .44254 Mdot
.38758 .31619 Mdot
.25093 .40008 Mdot
.17039 .83357 Mdot
.22084 .87238 Mdot
.55194 .71766 Mdot
.02233 .07111 Mdot
.8744 .65317 Mdot
.21765 .11761 Mdot
.89106 .07606 Mdot
.78021 .16119 Mdot
.38232 .75526 Mdot
.01252 .78155 Mdot
.88233 .87476 Mdot
.41609 .05107 Mdot
.13089 .66082 Mdot
.61388 .73693 Mdot
.50513 .01966 Mdot
.0089 .40785 Mdot
.94722 .65288 Mdot
.66817 .7552 Mdot
.82912 .13042 Mdot
.25226 .02345 Mdot
.63574 .95182 Mdot
.15735 .76733 Mdot
.41141 .96524 Mdot
.721 .83647 Mdot
.71466 .8336 Mdot
.8892 .59042 Mdot
.62098 .74166 Mdot
.19121 .57925 Mdot
.89546 .54324 Mdot
.4152 .319 Mdot
.73576 .73968 Mdot
.23835 .97313 Mdot
.30856 .14866 Mdot
.53956 .06398 Mdot
.15817 .04471 Mdot
.71815 .71648 Mdot
.92846 .77935 Mdot
.05554 .7685 Mdot
.2396 .81714 Mdot
.21438 .75701 Mdot
.0151 .66626 Mdot
.10824 .51212 Mdot
.90691 .47753 Mdot
.94938 .00776 Mdot
.50967 .4649 Mdot
.64402 .27653 Mdot
.96443 .31628 Mdot
.845 .96476 Mdot
.25949 .71038 Mdot
.8986 .96906 Mdot
.95707 .38947 Mdot
.7318 .23286 Mdot
.60172 .81141 Mdot
.98974 .25287 Mdot
.83708 .75556 Mdot
.84675 .75544 Mdot
.19951 .64528 Mdot
.37805 .36206 Mdot
.70553 .48336 Mdot
.9996 .85847 Mdot
.27829 .95124 Mdot
.36636 .60117 Mdot
.27099 .87852 Mdot
.33937 .02906 Mdot
.15322 .12917 Mdot
.29106 .56191 Mdot
.7734 .35592 Mdot
.39662 .53037 Mdot
.53632 .55495 Mdot
.35374 .71813 Mdot
.56318 .78675 Mdot
.99831 .24697 Mdot
.42167 .82856 Mdot
.06449 .41839 Mdot
.17743 .99171 Mdot
.15902 .77751 Mdot
.43007 .78795 Mdot
.57878 .19102 Mdot
.20772 .53102 Mdot
.64183 .53731 Mdot
.59742 .09237 Mdot
.10753 .19034 Mdot
.73989 .10141 Mdot
.04667 .28332 Mdot
.22125 .9294 Mdot
.48745 .9499 Mdot
.06721 .92713 Mdot
.31926 .38719 Mdot
.71362 .08687 Mdot
.51308 .00699 Mdot
.85221 .26299 Mdot
.88911 .13981 Mdot
.48867 .13155 Mdot
.05153 .2057 Mdot
.30839 .34908 Mdot
.33088 .09829 Mdot
.20969 .54729 Mdot
.49562 .38301 Mdot
.03772 .92454 Mdot
.92475 .05569 Mdot
.37053 .1052 Mdot
.30858 .80638 Mdot
.47613 .89021 Mdot
.22002 .96353 Mdot
.6572 .88304 Mdot
.56441 .03252 Mdot
.7343 .23761 Mdot
.44138 .23306 Mdot
.1748 .72978 Mdot
.51017 .27179 Mdot
.24647 .97372 Mdot
.59557 .47155 Mdot
.8268 .88573 Mdot
.07351 .16202 Mdot
.84068 .63269 Mdot
.73446 .16776 Mdot
.87473 .17042 Mdot
.84389 .10255 Mdot
.74106 .03428 Mdot
.86595 .92829 Mdot
.12502 .30241 Mdot
.80209 .81583 Mdot
.72526 .50727 Mdot
.94592 .5478 Mdot
.00543 .24315 Mdot
.55338 .68055 Mdot
.24294 .3524 Mdot
.65958 .50501 Mdot
.18962 .02035 Mdot
.69038 .24039 Mdot
.58399 .25287 Mdot
.50243 .41592 Mdot
.19353 .26302 Mdot
.57672 .79184 Mdot
.41829 .48513 Mdot
.49396 .31532 Mdot
.63659 .93599 Mdot
.74075 .81126 Mdot
.84554 .79464 Mdot
.36789 .55371 Mdot
.60633 .55822 Mdot
.27196 .30044 Mdot
.70168 .07161 Mdot
.10024 .32342 Mdot
.92446 .3293 Mdot
.03507 .68864 Mdot
.19879 .71827 Mdot
.3631 .21335 Mdot
.70471 .28589 Mdot
.85212 .74133 Mdot
.68519 .01017 Mdot
.72772 .31839 Mdot
.6942 .8586 Mdot
.55828 .26289 Mdot
.791 .71241 Mdot
.68405 .28063 Mdot
.63069 .50115 Mdot
.92326 .86128 Mdot
.02136 .50552 Mdot
.95614 .07002 Mdot
.08198 .81654 Mdot
.69118 .69575 Mdot
.58182 .15374 Mdot
.9924 .56739 Mdot
.48345 .76033 Mdot
.34455 .79685 Mdot
.65369 .74223 Mdot
.84748 .78058 Mdot
.45454 .2045 Mdot
.01885 .2099 Mdot
.96717 .6908 Mdot
.26288 .67095 Mdot
.79165 .06009 Mdot
.22813 .75019 Mdot
.30317 .85639 Mdot
.20681 .2335 Mdot
.05416 .64529 Mdot
.61278 .48385 Mdot
.79929 .65177 Mdot
.2526 .10111 Mdot
.11723 .52333 Mdot
.24715 .77108 Mdot
.69524 .9422 Mdot
.26245 .5892 Mdot
.21805 .82666 Mdot
.0278 .06024 Mdot
.28358 .79292 Mdot
.43432 .60687 Mdot
.93579 .1599 Mdot
.94353 .65916 Mdot
.58811 .93756 Mdot
.30504 .82829 Mdot
.05497 .3969 Mdot
.99372 .67844 Mdot
.24171 .21253 Mdot
.1512 .73745 Mdot
.53786 .34776 Mdot
.31341 .41813 Mdot
.3115 .37177 Mdot
.35377 .54362 Mdot
.13445 .40983 Mdot
.60415 .59336 Mdot
.45439 .04726 Mdot
.39342 .66267 Mdot
.23867 .64818 Mdot
.88914 .64727 Mdot
.40397 .92601 Mdot
.19573 .7784 Mdot
.59448 .03749 Mdot
.76264 .23496 Mdot
.94093 .77699 Mdot
.58409 .72328 Mdot
.59145 .13184 Mdot
.489 .04913 Mdot
.57848 .43694 Mdot
.08885 .57953 Mdot
.88391 .97414 Mdot
.60731 .45596 Mdot
.84196 .83089 Mdot
.85683 .88744 Mdot
.88641 .01622 Mdot
.02042 .27156 Mdot
.7232 .1988 Mdot
.32862 .62245 Mdot
.39997 .13761 Mdot
.59998 .81449 Mdot
.00428 .70177 Mdot
.67503 .29763 Mdot
.99231 .77016 Mdot
.76532 .08032 Mdot
.64287 .64533 Mdot
.93789 .38978 Mdot
.54851 .17696 Mdot
.31284 .51869 Mdot
.70868 .1146 Mdot
.09342 .20657 Mdot
.01141 .09018 Mdot
.34499 .65527 Mdot
.73914 .9369 Mdot
.96046 .07188 Mdot
.49438 .71791 Mdot
.60487 .64224 Mdot
.94768 .84617 Mdot
.97857 .6684 Mdot
.70982 .65853 Mdot
.42862 .24793 Mdot
.99325 .9005 Mdot
.92899 .9043 Mdot
.03182 .79442 Mdot
.48791 .52678 Mdot
.24784 .21654 Mdot
.89379 .25573 Mdot
.50425 .02675 Mdot
.60168 .11692 Mdot
.34765 .25696 Mdot
.1982 .68093 Mdot
.13808 .67887 Mdot
.69487 .72041 Mdot
.76307 .30459 Mdot
.71955 .492 Mdot
.68882 .31374 Mdot
.95923 .50787 Mdot
.26358 .25876 Mdot
.45147 .72614 Mdot
.79041 .31989 Mdot
.2052 .4025 Mdot
.81113 .8648 Mdot
.81665 .96483 Mdot
.3648 .93403 Mdot
.94822 .10283 Mdot
.72138 .31041 Mdot
.57752 .3405 Mdot
.57196 .94491 Mdot
.74569 .40773 Mdot
.84719 .02104 Mdot
.64605 .1306 Mdot
.84139 .53881 Mdot
.35655 .20519 Mdot
.3685 .62133 Mdot
.21616 .59294 Mdot
.51007 .4714 Mdot
.97341 .65753 Mdot
.14095 .09474 Mdot
.4918 .0685 Mdot
.3472 .30974 Mdot
.46008 .36039 Mdot
.01208 .09981 Mdot
.30159 .44852 Mdot
.94605 .60459 Mdot
.96282 .48931 Mdot
.39958 .29198 Mdot
.71612 .97986 Mdot
.52883 .94954 Mdot
.44223 .63637 Mdot
.41557 .42463 Mdot
.3591 .11801 Mdot
.35059 .48694 Mdot
.28717 .66886 Mdot
.87922 .91771 Mdot
.31499 .38061 Mdot
.06338 .62378 Mdot
.87549 .08073 Mdot
.01949 .75189 Mdot
.06795 .57335 Mdot
.80105 .31665 Mdot
.78418 .5787 Mdot
.31532 .42522 Mdot
.98448 .98181 Mdot
.7731 .44344 Mdot
.84887 .72378 Mdot
.43946 .18848 Mdot
.03009 .28989 Mdot
.02587 .78443 Mdot
.89963 .92424 Mdot
.74822 .69415 Mdot
.55801 .48916 Mdot
.3133 .07615 Mdot
.02733 .74212 Mdot
.86644 .99318 Mdot
.61873 .26016 Mdot
.90141 .53365 Mdot
.3609 .71155 Mdot
.15465 .97964 Mdot
.48352 .67266 Mdot
.97956 .68645 Mdot
.81159 .92708 Mdot
.25427 .69657 Mdot
.9507 .17023 Mdot
.50305 .45882 Mdot
.62176 .76722 Mdot
.21168 .99989 Mdot
.48898 .45245 Mdot
.95097 .88444 Mdot
.51023 .87611 Mdot
.34759 .75858 Mdot
.52529 .09455 Mdot
.78062 .85716 Mdot
.51849 .13843 Mdot
.33552 .38946 Mdot
.93826 .8657 Mdot
.95774 .0088 Mdot
.01294 .54916 Mdot
.23353 .45686 Mdot
.05229 .71573 Mdot
.1553 .77857 Mdot
.18839 .68112 Mdot
.13826 .75877 Mdot
.28721 .37298 Mdot
.0953 .57477 Mdot
.66991 .4023 Mdot
.0529 .68477 Mdot
.11339 .42762 Mdot
.23141 .85799 Mdot
.89424 .31473 Mdot
.35629 .06773 Mdot
.50946 .90588 Mdot
.06589 .84508 Mdot
.60734 .89506 Mdot
.05157 .50203 Mdot
.91873 .57637 Mdot
.58858 .98179 Mdot
.64467 .87312 Mdot
.95505 .40189 Mdot
.72626 .93196 Mdot
.92978 .90846 Mdot
.63267 .37244 Mdot
.44048 .96291 Mdot
.54466 .97636 Mdot
.16825 .57821 Mdot
.71485 .512 Mdot
.1413 .46397 Mdot
.47824 .45581 Mdot
.09147 .83397 Mdot
.28604 .51547 Mdot
.96156 .44331 Mdot
.60991 .103 Mdot
.59063 .86156 Mdot
.24903 .26371 Mdot
.52124 .99529 Mdot
.75589 .81094 Mdot
.35984 .912 Mdot
.05883 .18526 Mdot
.79795 .05382 Mdot
.78843 .0704 Mdot
.50948 .78616 Mdot
.30672 .68754 Mdot
.86994 .28211 Mdot
.12837 .49495 Mdot
.10141 .04146 Mdot
.18146 .44864 Mdot
.65286 .67127 Mdot
.59263 .03757 Mdot
.40559 .39902 Mdot
.07657 .81493 Mdot
.96857 .99017 Mdot
.40141 .54369 Mdot
.55991 .90618 Mdot
.98385 .00779 Mdot
.64525 .5255 Mdot
.49343 .79927 Mdot
.32895 .80424 Mdot
.58045 .9838 Mdot
.98332 .09408 Mdot
.509 .23821 Mdot
.27254 .30072 Mdot
.07847 .9167 Mdot
.12785 .94953 Mdot
.84213 .3314 Mdot
.0833 .83722 Mdot
.51301 .05613 Mdot
.0282 .68429 Mdot
.21499 .03841 Mdot
.57821 .32721 Mdot
.90004 .8645 Mdot
.88305 .63928 Mdot
.8456 .10775 Mdot
.03189 .80834 Mdot
.38206 .67259 Mdot
.05246 .34847 Mdot
.60751 .34346 Mdot
.50823 .74352 Mdot
.82541 .33671 Mdot
.03478 .31009 Mdot
.59077 .49694 Mdot
.04724 .73421 Mdot
.98422 .85914 Mdot
.12694 .46152 Mdot
.15469 .85056 Mdot
.18392 .1815 Mdot
.96463 .99292 Mdot
.90199 .32254 Mdot
.74099 .95368 Mdot
.77482 .08215 Mdot
.72528 .35285 Mdot
.1254 .97764 Mdot
.15382 .77589 Mdot
.69442 .19315 Mdot
.31167 .6574 Mdot
.13848 .7958 Mdot
.80158 .07707 Mdot
.97084 .00502 Mdot
.408 .33931 Mdot
.76251 .04261 Mdot
.65638 .49348 Mdot
.69729 .41542 Mdot
.26805 .01525 Mdot
.37638 .30729 Mdot
.64603 .16436 Mdot
.22659 .58388 Mdot
.90639 .48046 Mdot
.66506 .54563 Mdot
.63886 .85495 Mdot
.88484 .04174 Mdot
.03613 .79065 Mdot
.61117 .1155 Mdot
.20723 .26933 Mdot
.54627 .96923 Mdot
.18352 .54392 Mdot
.54746 .78692 Mdot
.69843 .42027 Mdot
.71245 .61518 Mdot
.26921 .00907 Mdot
.53495 .81158 Mdot
.5963 .15944 Mdot
.41852 .8066 Mdot
.2745 .82463 Mdot
.68459 .62069 Mdot
.28587 .7118 Mdot
.76843 .06071 Mdot
.25952 .99524 Mdot
.05941 .86085 Mdot
.59834 .92204 Mdot
.72821 .90599 Mdot
.82413 .85524 Mdot
.40015 .51929 Mdot
.30538 .80645 Mdot
.25872 .28734 Mdot
.76686 .22389 Mdot
.99846 .27642 Mdot
.71166 .81199 Mdot
.75035 .81046 Mdot
.49233 .01657 Mdot
.34253 .67581 Mdot
.88023 .57436 Mdot
.344 .98985 Mdot
.46549 .82951 Mdot
.92412 .11972 Mdot
.06914 .1696 Mdot
.5525 .61383 Mdot
.73042 .84624 Mdot
.62187 .61004 Mdot
.72928 .54322 Mdot
.43203 .52656 Mdot
.70042 .55542 Mdot
.50433 .06358 Mdot
.72215 .75027 Mdot
.85399 .88927 Mdot
.93856 .70367 Mdot
.26856 .66832 Mdot
.51696 .35737 Mdot
.16231 .14965 Mdot
.13098 .34688 Mdot
.8618 .98436 Mdot
.96893 .13389 Mdot
.36201 .50135 Mdot
.66149 .10331 Mdot
.42573 .55935 Mdot
.15277 .02319 Mdot
.40441 .39594 Mdot
.5282 .48308 Mdot
.60622 .02607 Mdot
.68509 .26559 Mdot
.1658 .01364 Mdot
.6106 .9457 Mdot
.74977 .57141 Mdot
.81225 .00471 Mdot
.30553 .48772 Mdot
.17438 .49005 Mdot
.3421 .03777 Mdot
.56497 .46474 Mdot
.58013 .00613 Mdot
.78273 .28029 Mdot
.75767 .46834 Mdot
.21736 .73167 Mdot
.5794 .84518 Mdot
.32459 .85034 Mdot
.68294 .82203 Mdot
.94452 .16376 Mdot
.06577 .75542 Mdot
.31078 .45334 Mdot
.92908 .59339 Mdot
.17515 .07978 Mdot
.00018 .1106 Mdot
.86769 .22483 Mdot
.7566 .32069 Mdot
.08159 .52671 Mdot
.21072 .89637 Mdot
.55323 .43248 Mdot
.17324 .47605 Mdot
.05955 .41635 Mdot
.05071 .07497 Mdot
.69576 .91575 Mdot
.43975 .04624 Mdot
.59109 .9908 Mdot
.02826 .02091 Mdot
.68515 .71578 Mdot
.2719 .69351 Mdot
.58652 .07761 Mdot
.5588 .10108 Mdot
.62636 .70255 Mdot
.69374 .12875 Mdot
.47427 .63801 Mdot
.74103 .57825 Mdot
.296 .54186 Mdot
.99946 .3653 Mdot
.52504 .89845 Mdot
.3971 .81543 Mdot
.27944 .42478 Mdot
.38013 .76025 Mdot
.69604 .63909 Mdot
.96372 .89776 Mdot
.93244 .49165 Mdot
.3325 .83785 Mdot
.9162 .39225 Mdot
.43203 .69191 Mdot
.92912 .89109 Mdot
.1481 .58893 Mdot
.78365 .90275 Mdot
.06242 .03518 Mdot
.25922 .47596 Mdot
.07014 .85812 Mdot
.32669 .02058 Mdot
.10094 .45852 Mdot
.84554 .34763 Mdot
.80159 .73283 Mdot
.66908 .35868 Mdot
.76702 .68789 Mdot
.09062 .41854 Mdot
.28117 .47886 Mdot
.11938 .57272 Mdot
.15332 .5303 Mdot
.85273 .54692 Mdot
.3741 .02022 Mdot
.08837 .60793 Mdot
.7751 .95645 Mdot
.22091 .4336 Mdot
.28937 .93366 Mdot
.82928 .86079 Mdot
.21608 .8727 Mdot
.20422 .88466 Mdot
.80383 .42171 Mdot
.46693 .07251 Mdot
.29986 .17839 Mdot
.90625 .95799 Mdot
.28086 .43122 Mdot
.35962 .94393 Mdot
.08265 .41731 Mdot
.04743 .58965 Mdot
.93185 .68093 Mdot
.17648 .05664 Mdot
.75067 .08046 Mdot
.56201 .30378 Mdot
.91647 .8857 Mdot
.42375 .97296 Mdot
.33757 .91775 Mdot
.97308 .67827 Mdot
.42225 .68261 Mdot
.14331 .07394 Mdot
.55337 .49231 Mdot
.53513 .20626 Mdot
.15895 .74203 Mdot
.92492 .54392 Mdot
.81252 .52235 Mdot
.8742 .21517 Mdot
.44524 .03715 Mdot
.48356 .82192 Mdot
.85718 .51532 Mdot
.91607 .744 Mdot
.62859 .15095 Mdot
.28865 .81079 Mdot
.13209 .46927 Mdot
.5072 .78045 Mdot
.59645 .60885 Mdot
.55517 .51879 Mdot
.40291 .22164 Mdot
.26225 .57457 Mdot
.92366 .18986 Mdot
.71466 .24258 Mdot
.27571 .82631 Mdot
.85622 .40513 Mdot
.2714 .7198 Mdot
.50276 .73609 Mdot
.0781 .02254 Mdot
.63696 .55238 Mdot
.55413 .57121 Mdot
.75075 .93318 Mdot
.25917 .69033 Mdot
.63215 .61039 Mdot
.27086 .09854 Mdot
.00067 .7293 Mdot
.36822 .10791 Mdot
.81759 .67163 Mdot
.61519 .69259 Mdot
.19735 .90993 Mdot
.7593 .94635 Mdot
.44063 .34998 Mdot
.2999 .48558 Mdot
.56735 .11452 Mdot
.28895 .83612 Mdot
.37326 .32264 Mdot
.4668 .67686 Mdot
.87277 .70381 Mdot
.6375 .01804 Mdot
.69755 .56987 Mdot
.86909 .83949 Mdot
.47418 .53617 Mdot
.27785 .26591 Mdot
.11272 .25681 Mdot
.06038 .37161 Mdot
.06042 .38867 Mdot
.71146 .76785 Mdot
.80975 .24568 Mdot
.78548 .69794 Mdot
.2453 .3431 Mdot
.58637 .32044 Mdot
.60642 .10814 Mdot
.91662 .35129 Mdot
.62084 .55595 Mdot
.24003 .50388 Mdot
.48632 .0016 Mdot
.2647 .3749 Mdot
.52628 .69562 Mdot
.07111 .17775 Mdot
.78518 .61668 Mdot
.73 .78123 Mdot
.55428 .10181 Mdot
.3347 .48049 Mdot
.24714 .03853 Mdot
.02275 .42531 Mdot
.09878 .57604 Mdot
.11157 .21437 Mdot
.57913 .01925 Mdot
.96167 .94831 Mdot
.80497 .32896 Mdot
.85574 .17296 Mdot
.31393 .28518 Mdot
.50975 .53905 Mdot
.23108 .79978 Mdot
.70268 .59127 Mdot
.82018 .24527 Mdot
.00453 .86386 Mdot
.77154 .65114 Mdot
.72564 .66083 Mdot
.51703 .34752 Mdot
.00557 .16108 Mdot
.84044 .06967 Mdot
.46804 .99697 Mdot
.24357 .39358 Mdot
.74255 .76457 Mdot
.4562 .32132 Mdot
.21018 .97756 Mdot
.97226 .30808 Mdot
.5567 .14289 Mdot
.8693 .79881 Mdot
.28254 .74392 Mdot
.77345 .4681 Mdot
.26741 .34403 Mdot
.34114 .49152 Mdot
.77938 .73382 Mdot
.01894 .30225 Mdot
.27196 .39474 Mdot
.75432 .37083 Mdot
.49449 .96005 Mdot
.09272 .39642 Mdot
.56815 .01425 Mdot
.04443 .09728 Mdot
.04774 .85905 Mdot
.05597 .91059 Mdot
.93576 .41636 Mdot
.63298 .8665 Mdot
.69046 .28136 Mdot
.65952 .38756 Mdot
.20533 .53899 Mdot
.10305 .95409 Mdot
.57666 .03785 Mdot
.31732 .82672 Mdot
.41336 .21142 Mdot
.61827 .02425 Mdot
.14639 .81162 Mdot
.00335 .9928 Mdot
.4116 .05077 Mdot
.61862 .77792 Mdot
.4576 .11195 Mdot
.28367 .17319 Mdot
.78371 .25857 Mdot
.62993 .14798 Mdot
.6416 .65296 Mdot
.26748 .82014 Mdot
.21553 .71499 Mdot
.67743 .34445 Mdot
.05245 .62561 Mdot
.08889 .06232 Mdot
.06491 .6259 Mdot
.50528 .815 Mdot
.87638 .78664 Mdot
.63368 .23535 Mdot
.58331 .3365 Mdot
.92956 .14698 Mdot
.67115 .01757 Mdot
.02062 .34764 Mdot
.82619 .63703 Mdot
.16948 .19994 Mdot
.637 .99156 Mdot
.84153 .34174 Mdot
.00178 .15554 Mdot
.35013 .83647 Mdot
.83312 .14961 Mdot
.06041 .52991 Mdot
.04581 .22477 Mdot
.84516 .45977 Mdot
.16246 .29884 Mdot
.36597 .29439 Mdot
.65954 .4752 Mdot
.66697 .09192 Mdot
.00368 .79786 Mdot
.42194 .98815 Mdot
.21242 .09036 Mdot
.07926 .38344 Mdot
.61517 .78774 Mdot
.9039 .08537 Mdot
.52005 .18722 Mdot
.60458 .95451 Mdot
.87738 .49311 Mdot
.80013 .40485 Mdot
.98205 .55574 Mdot
.68412 .93286 Mdot
.49977 .91614 Mdot
.76444 .02124 Mdot
.40834 .58971 Mdot
.10199 .10556 Mdot
.6791 .15454 Mdot
.15515 .4033 Mdot
.23125 .18365 Mdot
.49498 .45707 Mdot
.20246 .63238 Mdot
.39442 .5947 Mdot
.05482 .22714 Mdot
.49962 .99386 Mdot
.94411 .56277 Mdot
.78509 .23155 Mdot
.24619 .64061 Mdot
.5925 .16681 Mdot
.54221 .18339 Mdot
.66735 .41457 Mdot
.93997 .47829 Mdot
.21751 .52705 Mdot
.56265 .19903 Mdot
.17689 .4932 Mdot
.82718 .83246 Mdot
.58047 .6016 Mdot
.01864 .55897 Mdot
.53923 .03911 Mdot
.78023 .48221 Mdot
.01566 .30306 Mdot
.3211 .47173 Mdot
.30236 .39738 Mdot
.00061 .47767 Mdot
.07819 .09211 Mdot
.20875 .07074 Mdot
.47701 .80689 Mdot
.14157 .24335 Mdot
.60983 .2501 Mdot
.79638 .25013 Mdot
.84119 .52629 Mdot
.97863 .52096 Mdot
.03257 .85646 Mdot
.67851 .63331 Mdot
.68812 .95384 Mdot
.17871 .63796 Mdot
.55551 .12179 Mdot
.65762 .44108 Mdot
.03245 .77339 Mdot
.9533 5e-05 Mdot
.98732 .86924 Mdot
.22131 .42247 Mdot
.7145 .02237 Mdot
.62041 .50641 Mdot
.92435 .05792 Mdot
.4926 .47938 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00So
oooo0_l00003ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0=ooooo`04o`000?ooooooooooooooo`;o00002_ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00gooooo0ol0000>ooooo`03o`000?oooooooooo00;ooooo000Nooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00Sooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00002_ooool00ol0
003oooooooooo`06ooooo`;o00001_ooool00ol0003oooooooooo`0=ooooo`04o`000?oooooooooo
ooooo`;o00002_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool00_l0000;ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`04ooooo`;o00002?ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0
003oooooooooo`1Cooooo`;o0000C_ooool2o`0001?ooooo0_l0000Qooooo`;o00009oooool2o`00
02_ooooo1?l00003ooooo`;o00000_ooool2o`0000Wooooo000Nooooo`03o`000?oooooooooo03;o
oooo0_l0000Oooooo`;o0000Q_ooool2o`0005Cooooo1?l00007ooooo`;o00002Oooool001kooooo
00?o0000ooooooooool0<_ooool2o`0001oooooo0_l00017ooooo`;o00005oooool2o`0006Gooooo
0_l0000Yooooo`007_ooool00ol0003oooooooooo`1Cooooo`;o0000Aoooool2o`0000;ooooo0_l0
000Cooooo`;o000000?oooooo`000?l000004Oooool2o`0000Wooooo0_l00014ooooo`;o0000:Ooo
ool001kooooo00?o0000ooooooooool01Oooool2o`0000kooooo0_l0000Sooooo`;o0000:_ooool2
o`0000kooooo0_l0000Xooooo`;o00005_ooool2o`00017ooooo0_l00009ooooo`;o00003?ooool2
o`0000kooooo0_l0000Iooooo`;o0000=_ooool001kooooo00?o0000ooooooooool00_ooool2o`00
0003ooooool0003o000000kooooo0_l0000Gooooo`;o00002_ooool2o`0001;ooooo0_l0000Foooo
o`;o00003_ooool2o`0004gooooo0_l0000Mooooo`;o00003_ooool2o`0001Wooooo0_l0000foooo
o`007_ooool00ol0003oooooooooo`02ooooo`;o0000:_ooool2o`0001kooooo0_l0000Jooooo`;o
0000=?ooool2o`0001oooooo0_l00002ooooo`;o0000P?ooool001kooooo00?o0000ooooooooool0
J_ooool2o`0003Cooooo0_l0000Oooooo`;o0000Q?ooool001kooooo00?o0000ooooooooool04?oo
ool2o`000:7ooooo0_l0000hooooo`;o0000F?ooool001kooooo00?o0000ooooooooool04?ooool2
o`0005Wooooo0_l0000Pooooo`;o00009?ooool2o`0000;ooooo0_l00004ooooo`;o0000;_ooool2
o`0001Wooooo0_l0000mooooo`007_ooool00ol0003oooooooooo`12ooooo`;o00002?ooool2o`00
01gooooo1?l0000Nooooo`;o00007?ooool2o`0000[ooooo0_l00004ooooo`;o0000BOooool2o`00
03gooooo000Nooooo`03o`000?oooooooooo01gooooo0_l0000Sooooo`;o00002?ooool2o`0001oo
oooo0_l0000Tooooo`;o00005_ooool2o`0004Oooooo0_l0000Vooooo`;o0000:Oooool001kooooo
00?o0000ooooooooool07Oooool2o`00013ooooo0_l0001Jooooo`;o00000oooool2o`000003oooo
ool0003o000005oooooo0_l0000Vooooo`;o0000:Oooool001kooooo00?o0000ooooooooool0;ooo
ool2o`0000gooooo0_l0001;ooooo`;o00000oooool2o`0000Wooooo0_l0002Zooooo`007_ooool2
o`0003oooooo0_l00012ooooo`?o00005_ooool2o`000:[ooooo000Nooooo`03o`000?oooooooooo
03Gooooo0_l0001;ooooo`?o00007_ooool2o`0005Gooooo0_l00003ooooo`;o0000:?ooool2o`00
01cooooo000Nooooo`03o`000?oooooooooo03Gooooo0_l0001/ooooo`;o0000EOooool2o`0000?o
oooo0_l0000Wooooo`?o00007?ooool001kooooo00?o0000ooooooooool01Oooool2o`0001;ooooo
0_l0003Kooooo`;o00001Oooool2o`0002Wooooo0_l0000Mooooo`007_ooool00ol0003ooooooooo
o`05ooooo`;o00004_ooool2o`0008Gooooo0_l00009ooooo`;o0000BOooool2o`0000Gooooo0_l0
0018ooooo`007_ooool00ol0003oooooooooo`02ooooo`;o0000K?ooool2o`0002[ooooo0_l00002
ooooo`;o00002Oooool2o`0009[ooooo000Nooooo`03o`000?oooooooooo00;ooooo0ol0000koooo
o`;o00006Oooool2o`0001?ooooo0_l0000Zooooo`;o0000@_ooool2o`0001[ooooo0_l0000?oooo
o`;o00009?ooool3o`00017ooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l00007ooooo`;o
00007?ooool2o`0001Cooooo0_l0000Iooooo`;o0000=oooool2o`0004[ooooo0_l0000Jooooo`;o
00003oooool2o`0002Cooooo0ol0000Aooooo`007_ooool00ol0003oooooooooo`0<ooooo`;o0000
7?ooool2o`0003Kooooo0_l0000`ooooo`;o00009Oooool2o`0004?ooooo0_l0000Looooo`;o0000
9oooool001kooooo00?o0000ooooooooool0=Oooool2o`0002_ooooo0_l0000`ooooo`;o00009Ooo
ool2o`0003?ooooo0_l00003ooooo`;o00002Oooool2o`0001Oooooo0_l00003ooooo`;o00009ooo
ool001kooooo00?o0000ooooooooool0=Oooool2o`000;Wooooo0_l00003ooooo`;o000000?ooooo
o`000?l000007oooool2o`0002cooooo000Nooooo`03o`000?oooooooooo0>Cooooo0_l0000Boooo
o`;o0000:?ooool2o`0002?ooooo000Nooooo`03o`000?oooooooooo00;o0000?oooool2o`000:7o
oooo0_l0000looooo`;o00008oooool001kooooo00?o0000ooooooooool00_l0000Cooooo`;o0000
:_ooool2o`0007_ooooo0_l0000Eooooo`;o0000L?ooool001kooooo00?o0000ooooooooool05Ooo
ool2o`0001?ooooo0_l0001kooooo`;o00005Oooool2o`0001Gooooo0_l0001Uooooo`;o00002Ooo
ool001kooooo00?o0000ooooooooool00_l00008ooooo`;o00007_ooool2o`0002Sooooo0_l0000A
ooooo`;o0000?_ooool2o`0003[ooooo0_l0001Gooooo`;o00002Oooool001kooooo0_l000000ooo
oooo0000o`000008ooooo`;o0000@_ooool2o`0000Cooooo0_l0000Aooooo`;o0000Aoooool4o`00
02oooooo0_l00007ooooo`;o00008?ooool2o`00023ooooo0_l0000Eooooo`007_ooool00ol0003o
ooooooooo`0Mooooo`;o0000;oooool2o`0002Cooooo0_l0000jooooo`Co00003_ooool2o`0000oo
oooo0_l0000Gooooo`;o00008?ooool2o`00023ooooo0_l0000Eooooo`007_ooool00ol0003ooooo
ooooo`0Mooooo`;o0000EOooool2o`0004_ooooo0ol0000?ooooo`;o0000>_ooool2o`0003Kooooo
000Mooooo`;o0000M_ooool2o`0001_ooooo0_l0000^ooooo`;o0000C?ooool2o`0003Kooooo000M
ooooo`;o0000Toooool2o`00027ooooo0_l0000/ooooo`;o0000Hoooool001kooooo00?o0000oooo
ooooool0@oooool2o`0002cooooo0_l00011ooooo`;o00001Oooool2o`0000;ooooo0_l00002oooo
o`;o00007Oooool2o`0006?ooooo000Nooooo`03o`000?oooooooooo04?ooooo0_l0000/ooooo`;o
0000B?ooool2o`0000;ooooo0_l00002ooooo`;o0000Hoooool2o`0001gooooo000Nooooo`03o`00
0?oooooooooo0;3ooooo0_l0001fooooo`;o00007Oooool001kooooo00?o0000ooooooooool0/?oo
ool2o`0009Gooooo000Nooooo`03o`000?oooooooooo02kooooo0_l0002Nooooo`;o00003Oooool2
o`0002[ooooo0_l0000looooo`007_ooool00ol0003oooooooooo`0^ooooo`;o0000Joooool2o`00
01oooooo0_l0000@ooooo`;o00003Oooool2o`0002[ooooo0_l0000looooo`007_ooool00ol0003o
ooooooooo`2Kooooo`;o00007oooool2o`0007Wooooo0_l0000>ooooo`007_ooool00ol0003ooooo
ooooo`0mooooo`;o0000?oooool2o`0002Cooooo0_l0001gooooo`;o00006?ooool2o`0000kooooo
000Nooooo`03o`000?oooooooooo00_ooooo0_l0000`ooooo`;o0000?oooool2o`0002Cooooo0_l0
000;ooooo`;o0000J_ooool2o`0002Sooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l0000k
ooooo`;o0000Ioooool2o`0009Cooooo000Nooooo`03o`000?oooooooooo04Sooooo0_l0000Foooo
o`;o0000Ioooool2o`0005oooooo0_l0000Kooooo`007_ooool2o`0000cooooo0_l0000Tooooo`;o
0000;Oooool2o`0006Kooooo0ol00010ooooo`;o00007Oooool2o`0001_ooooo000Nooooo`03o`00
0?oooooooooo00_ooooo0_l0000Tooooo`;o0000Q_ooool2o`0000gooooo0_l00003ooooo`;o0000
2_ooool2o`00033ooooo0_l0000jooooo`007Oooool2o`0007Cooooo0_l00015ooooo`;o00004_oo
ool2o`0000[ooooo0_l0000Zooooo`;o00008Oooool2o`0001gooooo000Mooooo`Co0000L_ooool2
o`0002Kooooo0_l0000Rooooo`;o0000>_ooool2o`0000Wooooo0_l0000Qooooo`;o00000_ooool2
o`0001Wooooo000Nooooo`?o00005?ooool2o`0008Cooooo0_l0000Rooooo`;o00003_ooool2o`00
02[ooooo0_l0000`ooooo`;o000000?oooooo`000?l000005_ooool001kooooo00?o0000oooooooo
ool05?ooool2o`000:Oooooo0_l0000?ooooo`;o0000Goooool2o`0001Kooooo000Nooooo`03o`00
0?oooooooooo01;ooooo0_l00023ooooo`;o00009?ooool2o`0002cooooo0_l0000[ooooo`;o0000
1?ooool2o`00017ooooo0_l0000Dooooo`007_ooool00ol0003oooooooooo`0Booooo`;o0000A?oo
ool2o`0003gooooo0_l0001Booooo`;o00009Oooool2o`0000Cooooo0_l00004ooooo`;o00004Ooo
ool2o`0001Cooooo000Nooooo`03o`000?oooooooooo05Sooooo0_l0002hooooo`;o0000<oooool0
01kooooo00?o0000ooooooooool04oooool2o`0004Sooooo0_l0001?ooooo`;o0000Uoooool001ko
oooo00?o0000ooooooooool04oooool2o`0002?ooooo0_l0000Sooooo`;o0000<_ooool2o`0001_o
oooo0_l0002Gooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o00009oooool2o`0000gooooo
0_l00018ooooo`;o00006Oooool2o`0009Wooooo000Nooooo`03o`000?oooooooooo00oooooo0_l0
000fooooo`;o0000@_ooool2o`0001Sooooo0_l00005ooooo`;o0000VOooool001kooooo00?o0000
ooooooooool07oooool2o`0006[ooooo0_l0000Hooooo`;o00002?ooool2o`0000Oooooo0_l0001^
ooooo`;o00007Oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0000Kooooo00?o0000ooooooooool07oooool2o`0008kooooo0_l00007ooooo`;o00009?ooool2
o`0004Sooooo0_l0000Mooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`3Nooooo`;o0000Iooo
ool000?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0
000cooooo`;o0000O_ooool2o`0003;ooooo0_l0001Nooooo`000oooool01Ol0003ooooooooooooo
oooo000000gooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`0cooooo`;o0000O_oo
ool2o`0003;ooooo0_l0001Nooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool01Oooool00ol0003oooooooooo`0=ooooo`;o00002oooool2o`0005Cooooo0_l0
000Nooooo`;o00006?ooool2o`0009_ooooo0003ooooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo0_l00009ooooo`;o00002ooo
ool2o`0005Cooooo0_l0000Nooooo`;o00006?ooool2o`0009_ooooo0003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
0_ooool2o`0004Kooooo0_l0000Vooooo`;o00003_ooool2o`00053ooooo0_l0001aooooo`000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03
o`000?oooooooooo023ooooo0_l0000Xooooo`Co00009?ooool2o`0000kooooo0_l0001@ooooo`;o
0000@_ooool2o`0002gooooo000Nooooo`03o`000?oooooooooo023ooooo0_l0000Zooooo`;o0000
b_ooool2o`0000Gooooo0_l0000Vooooo`007_ooool00ol0003oooooooooo`1oooooo`;o00008?oo
ool2o`00067ooooo0_l00004ooooo`;o00004oooool2o`0002Kooooo000Nooooo`03o`000?oooooo
oooo00_ooooo0_l0001booooo`;o00008?ooool2o`0005;ooooo0_l0000=ooooo`;o00001?ooool2
o`0000[ooooo0_l0000_ooooo`007_ooool00ol0003oooooooooo`0;ooooo`;o000000?oooooo`00
0?l00000iOooool2o`0001oooooo0_l0000_ooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o
0000joooool2o`0004[ooooo000Nooooo`03o`000?oooooooooo03oooooo0_l0001:ooooo`;o0000
GOooool2o`0000Sooooo0_l00005ooooo`;o0000B_ooool001kooooo00?o0000ooooooooool0?ooo
ool2o`0000Sooooo0_l00010ooooo`;o00005?ooool2o`0002Oooooo0_l0000Nooooo`?o00001ooo
ool2o`00057ooooo000Nooooo`03o`000?oooooooooo04Wooooo0_l0001Fooooo`;o00009oooool2
o`00013ooooo0_l0000=ooooo`;o0000F_ooool001kooooo0ol0000Zooooo`;o0000/?ooool2o`00
00Kooooo0_l0001Qooooo`007_ooool3o`0002[ooooo0_l0001Mooooo`;o0000FOooool2o`0001go
oooo0_l00002ooooo`;o0000=oooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo08Oooooo
1?l0000gooooo`;o0000>oooool2o`0000;ooooo0_l00002ooooo`;o00009_ooool2o`0000oooooo
0_l00005ooooo`007_ooool2o`0008Sooooo0_l0000aooooo`;o00001_ooool2o`0003_ooooo0_l0
000^ooooo`;o00003Oooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo0;[ooooo0_l0001E
ooooo`;o00002oooool2o`0001kooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`0Qoooo
o`;o0000;oooool2o`0000kooooo0_l00009ooooo`;o0000S?ooool2o`0001Cooooo0_l0000;oooo
o`;o00001oooool2o`0001kooooo000Nooooo`03o`000?oooooooooo027ooooo0_l0000_ooooo`;o
00003_ooool2o`0000Wooooo0_l0001Fooooo`;o0000=?ooool2o`0002[ooooo0_l0000Nooooo`00
7_ooool00ol0003oooooooooo`0kooooo`;o00004?ooool2o`0000Oooooo0_l0001Iooooo`;o0000
4_ooool2o`0001Cooooo0_l0000dooooo`;o0000=?ooool001kooooo00?o0000ooooooooool0<Ooo
ool2o`0000Sooooo0_l0000@ooooo`;o00001oooool2o`0005Wooooo0_l0000Xooooo`;o0000=?oo
ool2o`0003Cooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0000/ooooo`;o00003?ooool2
o`00067ooooo0_l0002Sooooo`007_ooool00ol0003oooooooooo`03ooooo`;o0000>_ooool2o`00
067ooooo0_l00014ooooo`;o0000GOooool001kooooo00?o0000ooooooooool0cOooool2o`0001Wo
oooo0_l0001Fooooo`;o00001Oooool001kooooo00?o0000ooooooooool0cOooool2o`0000_ooooo
0_l0000Nooooo`;o0000A?ooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l0
003=ooooo`Co00007?ooool2o`0000Oooooo0_l0000Booooo`;o0000;_ooool001kooooo00?o0000
ooooooooool02oooool2o`0004?ooooo0_l0000@ooooo`;o0000@Oooool2o`0003Gooooo0_l00003
ooooo`;o00008?ooool2o`0001;ooooo0_l0000^ooooo`007_ooool00ol0003oooooooooo`06oooo
o`;o0000B?ooool2o`00013ooooo0_l00011ooooo`;o0000>_ooool2o`0006Cooooo000Nooooo`03
o`000?oooooooooo00Kooooo0_l00011ooooo`;o0000<oooool2o`000<Oooooo000Nooooo`03o`00
0?oooooooooo04Wooooo0_l0000Mooooo`;o00002Oooool2o`0000Wooooo0_l00037ooooo`007_oo
ool00ol0003oooooooooo`0aooooo`;o0000=Oooool2o`0000Wooooo0_l0001:ooooo`;o00005_oo
ool2o`0006kooooo000Nooooo`;o00000oooool2o`00027ooooo0_l0000:ooooo`;o00008Oooool2
o`00067ooooo0_l00006ooooo`;o00005_ooool2o`0006kooooo000Nooooo`04o`000?oooooooooo
ooooo`?o00008Oooool2o`0002gooooo0_l0001Mooooo`;o00000_ooool2o`0003_ooooo0_l0001A
ooooo`007_ooool01?l0003oooooooooooooool2o`0007?ooooo0_l0000kooooo`;o0000?oooool2
o`0004;ooooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`07ooooo`;o0000I?ooool2o`00
00Oooooo0_l0001Dooooo`;o00006?ooool2o`0001_ooooo0_l0000cooooo`;o00003Oooool001ko
oooo00?o0000ooooooooool01oooool2o`0006Cooooo0_l0001Mooooo`;o00003_ooool2o`0000So
oooo0_l0000Kooooo`;o00006_ooool2o`0002Kooooo000Nooooo`03o`000?oooooooooo07[ooooo
0_l0000Pooooo`;o0000?_ooool2o`0002;ooooo0_l0000Mooooo`;o00005?ooool2o`00013ooooo
000Nooooo`03o`000?oooooooooo07[ooooo0_l00007ooooo`;o00005oooool2o`0001gooooo0_l0
000[ooooo`;o00002?ooool2o`0000Wooooo0_l000000ooooooo0000o`00000cooooo`;o00004?oo
ool001kooooo00?o0000ooooooooool07?ooool2o`0005Oooooo0_l0000<ooooo`;o00002oooool2
o`0002Wooooo0_l0000[ooooo`;o00002?ooool2o`0000Wooooo0_l0000Rooooo`;o00009?ooool0
01kooooo00?o0000ooooooooool07?ooool2o`0005Oooooo0_l0000Iooooo`;o00009_ooool2o`00
06Oooooo0_l0000Tooooo`007_ooool00ol0003oooooooooo`2hooooo`;o0000B?ooool2o`0002Co
oooo0_l0000Mooooo`007_ooool00ol0003oooooooooo`3oooooo`?ooooo0_l0000:ooooo`;o0000
6?ooool2o`0001gooooo000Nooooo`03o`000?oooooooooo05kooooo0_l0001Jooooo`;o0000D_oo
ool2o`0003Oooooo000Nooooo`03o`000?oooooooooo05kooooo0_l0000Qooooo`;o0000=oooool2
o`0001cooooo0_l0000^ooooo`;o0000?Oooool001kooooo00?o0000ooooooooool0POooool2o`00
03Gooooo0_l00009ooooo`;o00004oooool2o`0002kooooo0_l00003ooooo`;o0000>?ooool001ko
oooo00?o0000ooooooooool0C?ooool2o`0000Gooooo0_l0001Sooooo`;o00001oooool4o`0001?o
oooo0_l0000Oooooo`;o00004_ooool2o`0003Sooooo000Nooooo`03o`000?oooooooooo00?ooooo
0_l00008ooooo`;o00005oooool2o`0002Cooooo0_l00005ooooo`;o0000Coooool2o`0000Gooooo
0_l0000Dooooo`;o00005Oooool2o`0001oooooo0_l0000Dooooo`;o0000=_ooool001kooooo0_l0
0004ooooo`;o00002?ooool2o`0001Oooooo0_l0000hooooo`;o00006oooool2o`0000cooooo0_l0
000Gooooo`;o00001Oooool2o`0006;ooooo0_l0000Eooooo`;o00007oooool001kooooo00?o0000
ooooooooool0Boooool2o`0001?ooooo0_l0000Kooooo`;o00003?ooool2o`0000Oooooo0_l0001B
ooooo`;o0000??ooool2o`0001oooooo000Nooooo`03o`000?oooooooooo04_ooooo0_l00017oooo
o`;o00003_ooool2o`0004;ooooo0_l0000=ooooo`;o0000@oooool2o`0000Wooooo000Nooooo`03
o`000?oooooooooo097ooooo0_l0000Aooooo`;o0000;oooool2o`00023ooooo0_l0000Cooooo`;o
0000;_ooool2o`0000Wooooo000Nooooo`03o`000?oooooooooo07Oooooo0_l0000Hooooo`;o0000
@_ooool2o`0003Gooooo0_l0000iooooo`007_ooool00ol0003oooooooooo`1gooooo`;o0000b?oo
ool2o`0000Cooooo000Nooooo`03o`000?oooooooooo0?oooooo@_ooool2o`0000Cooooo000Noooo
o`03o`000?oooooooooo013ooooo0_l00017ooooo`;o00001_ooool2o`0006Oooooo0_l0000Uoooo
o`;o0000E?ooool001kooooo00?o0000ooooooooool04?ooool2o`00043ooooo0_l00005ooooo`;o
00001_ooool2o`0006Oooooo0_l0000Uooooo`;o0000E?ooool001kooooo00?o0000ooooooooool0
D_ooool2o`000??ooooo000Nooooo`03o`000?oooooooooo04gooooo0_l0000Cooooo`;o0000hooo
ool001kooooo00?o0000ooooooooool05_ooool2o`0003Gooooo0_l0000Cooooo`;o0000>Oooool2
o`000:Sooooo000Nooooo`03o`000?oooooooooo013ooooo0_l00004ooooo`;o0000C?ooool2o`00
03Gooooo1?l0000Jooooo`;o00005oooool2o`0007?ooooo000Nooooo`03o`000?oooooooooo013o
oooo0_l0001Booooo`;o00000oooool2o`00033ooooo0_l0000Looooo`;o00005oooool2o`0005Wo
oooo0_l00004ooooo`;o00004_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0Boooool2o`0000Oo
oooo0_l0000Cooooo`;o0000^oooool2o`0000Gooooo0_l00004ooooo`;o00004_ooool000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00kooooo0_l0000:ooooo`;o0000;oooool2o`0000Oooooo0_l00008ooooo`;o
00007oooool2o`000:Gooooo0_l0000Oooooo`000oooool01Ol@413ooooooooooooooooo410@00_o
oooo1Ol00006ooooo`?o00003_ooool2o`0000[ooooo0_l0000aooooo`;o00003oooool2o`0001oo
oooo0ol00035ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoo
oooo00001oooool00ol0003oooooooooo`0^ooooo`;o00003oooool2o`0000cooooo0_l0000]oooo
o`;o00000_ooool2o`0002Oooooo0_l0000[ooooo`;o0000F_ooool2o`0001?ooooo0003ooooo`05
o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooo
oooo02kooooo0_l0000?ooooo`;o0000>oooool2o`0001Sooooo0_l0000Aooooo`;o0000:oooool2
o`0002Sooooo0_l0000@ooooo`;o00007_ooool2o`0001?ooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00omgMgOoc<c<o`000007ooooo`04o`000?oooooo0000o`0002Oooooo0_l0
001/ooooo`;o0000E_ooool2o`00013ooooo0_l0000@ooooo`;o0000<oooool000?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00Co0000ooooool0003o0000
9oooool2o`000<Cooooo0_l0001Gooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo
00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`0?ooooo`;o0000S_ooool2o`0003Cooooo
0_l00008ooooo`;o00002oooool2o`0003kooooo0_l0000Iooooo`007_ooool00ol0003ooooooooo
o`0?ooooo`Co00001?ooool4o`0004Oooooo0_l0000kooooo`;o0000=?ooool2o`0000Sooooo0_l0
000;ooooo`;o0000?_ooool2o`0001Wooooo000Nooooo`03o`000?oooooooooo017ooooo0_l00004
ooooo`Co0000:Oooool2o`0001cooooo0_l0001kooooo`;o00008?ooool2o`0001_ooooo0_l0000W
ooooo`007_ooool00ol0003oooooooooo`03ooooo`;o0000?oooool2o`00017ooooo0_l00009oooo
o`;o00007oooool2o`0005[ooooo0_l0000Pooooo`;o00006oooool2o`0002Oooooo000Nooooo`03
o`000?oooooooooo00?ooooo0_l0000Looooo`;o0000=?ooool2o`0000Wooooo0_l0000Oooooo`;o
0000`_ooool001kooooo00?o0000ooooooooool08Oooool2o`0003Cooooo0_l0000Cooooo`;o0000
fOooool001kooooo00?o0000ooooooooool0A?ooool2o`00017ooooo0_l0000Cooooo`?o0000@Ooo
ool2o`0009Gooooo000Nooooo`03o`000?oooooooooo04Cooooo0_l0000Wooooo`;o00008_ooool2
o`0001gooooo0_l00006ooooo`;o0000SOooool001kooooo00?o0000ooooooooool0TOooool2o`00
02Gooooo0_l0000Hooooo`;o0000IOooool2o`0000cooooo000Nooooo`03o`000?oooooooooo02Oo
oooo0_l0002Yooooo`;o00008oooool2o`0003cooooo0_l00002ooooo`;o00003?ooool001kooooo
00?o0000ooooooooool09oooool2o`0008Kooooo0_l00016ooooo`;o0000??ooool2o`00013ooooo
000Nooooo`03o`000?oooooooooo03Oooooo0_l0000Uooooo`;o0000Coooool2o`0009Kooooo000N
ooooo`;o0000>?ooool2o`0002Gooooo0_l000000ooooooo0000o`00000]ooooo`;o00002Oooool2
o`000:[ooooo000Nooooo`03o`000?oooooooooo067ooooo0_l0000]ooooo`;o00001Oooool2o`00
00;ooooo0_l0000Tooooo`;o0000Q?ooool001kooooo00?o0000ooooooooool07Oooool2o`0002Wo
oooo0_l0001=ooooo`;o00001?ooool4o`00023ooooo0_l00024ooooo`007_ooool00ol0003ooooo
ooooo`0Mooooo`;o00001_ooool2o`00027ooooo0_l0001Cooooo`Co0000K_ooool2o`0003Kooooo
000Nooooo`03o`000?oooooooooo02Gooooo0_l00003ooooo`;o0000M_ooool2o`00013ooooo0_l0
001Iooooo`;o0000=_ooool001kooooo00?o0000ooooooooool0:_ooool2o`0007Kooooo0_l0000@
ooooo`;o0000??ooool2o`0000?ooooo0_l0001>ooooo`007_ooool00ol0003oooooooooo`0Woooo
o`;o0000>oooool2o`0001?ooooo0_l0000Wooooo`;o00006_ooool2o`0003;ooooo0_l00003oooo
o`;o0000C_ooool001kooooo00?o0000ooooooooool09oooool2o`0003_ooooo0_l0000Cooooo`;o
00009oooool2o`0001[ooooo0_l00027ooooo`007Oooool2o`0003Kooooo0_l0000Jooooo`;o0000
P?ooool2o`0004oooooo0_l0000Rooooo`007Oooool2o`0000Gooooo0_l0000_ooooo`;o00006_oo
ool2o`0000Gooooo0_l0000@ooooo`;o0000<Oooool2o`0003Cooooo0_l0000:ooooo`;o0000@ooo
ool2o`0000Sooooo0_l0000Hooooo`007_ooool00ol0003oooooooooo`03ooooo`;o000000?ooooo
o`000?l00000Coooool2o`00013ooooo0_l0000aooooo`;o00002_ooool2o`0001Wooooo0_l0000I
ooooo`;o000000?oooooo`000?l000005oooool2o`0002Oooooo0_l00008ooooo`;o00006?ooool0
01kooooo00?o0000ooooooooool01_ooool2o`0005Gooooo0_l0000?ooooo`;o00005?ooool2o`00
02;ooooo0_l0000Iooooo`;o00007?ooool2o`0001Oooooo0_l0001;ooooo`007_ooool00ol0003o
ooooooooo`0eooooo`;o00009_ooool4o`0000gooooo0_l0000Dooooo`;o00009oooool2o`0000;o
oooo0_l00022ooooo`;o00004?ooool001kooooo00?o0000ooooooooool0=Oooool2o`0002Sooooo
0_l0000:ooooo`;o0000@?ooool2o`000004ooooool0003o0000o`0001kooooo0_l0000Cooooo`;o
0000<Oooool2o`00013ooooo0_l00008ooooo`;o00004?ooool001kooooo00?o0000ooooooooool0
9_ooool2o`0000gooooo0_l0000dooooo`;o00003?ooool2o`0003Gooooo0_l0000Oooooo`;o0000
4oooool2o`00037ooooo0_l0000@ooooo`;o00006_ooool001kooooo00?o0000ooooooooool09_oo
ool2o`00057ooooo0_l0000jooooo`;o00001Oooool2o`0006gooooo0_l0000Jooooo`007_ooool2
o`0000kooooo0_l0001Sooooo`;o0000@Oooool2o`0000Gooooo0_l0000;ooooo`;o0000O?ooool0
01kooooo00?o0000ooooooooool00oooool2o`0000Sooooo0_l0000kooooo`;o00009_ooool2o`00
05Gooooo0_l00007ooooo`;o0000Loooool001kooooo00?o0000ooooooooool00oooool2o`0002Go
oooo0_l0000Nooooo`;o0000N_ooool2o`0000[ooooo0_l0000Dooooo`;o0000B_ooool2o`00017o
oooo000Nooooo`03o`000?oooooooooo02[ooooo0_l00028ooooo`;o00004?ooool2o`0001cooooo
0_l00002ooooo`;o0000B_ooool2o`00017ooooo000Nooooo`03o`000?oooooooooo01oooooo0_l0
002Cooooo`;o0000;_ooool2o`00027ooooo0_l0000Pooooo`;o00007?ooool001kooooo00?o0000
ooooooooool07oooool2o`0003Sooooo0_l0002/ooooo`;o00002_ooool2o`0001Cooooo0_l0000L
ooooo`007_ooool00ol0003oooooooooo`1Iooooo`;o00001oooool2o`0001[ooooo0_l0000`oooo
o`;o0000HOooool2o`0000_ooooo0_l0000Hooooo`;o00002oooool001kooooo00?o0000oooooooo
ool08_ooool2o`0003kooooo0_l0000Jooooo`;o0000<?ooool2o`0005;ooooo0_l0000Jooooo`;o
00006?ooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo01Kooooo0_l0000:ooooo`;o0000
7oooool2o`0004?ooooo0_l0000Aooooo`;o0000<Oooool2o`0003Cooooo0_l00007ooooo`;o0000
>?ooool001kooooo00?o0000ooooooooool04?ooool2o`0000Cooooo0_l0000Fooooo`;o00004ooo
ool2o`0003Sooooo0_l00009ooooo`;o00004Oooool2o`00037ooooo0_l0000mooooo`;o0000>?oo
ool001kooooo00?o0000ooooooooool04?ooool2o`0001cooooo0_l0000?ooooo`;o0000??ooool2
o`000<Sooooo000Nooooo`03o`000?oooooooooo03oooooo0_l0001Eooooo`;o0000ROooool2o`00
02Cooooo000Nooooo`03o`000?oooooooooo03oooooo0_l0001Eooooo`;o00002_ooool2o`0002Wo
oooo0_l0000nooooo`;o00004_ooool2o`0002Cooooo000Nooooo`03o`000?oooooooooo03oooooo
0_l0000Kooooo`;o0000A?ooool2o`0002Wooooo0_l0000nooooo`;o0000>?ooool001kooooo00?o
0000ooooooooool0>?ooool2o`0002;ooooo0_l0000Aooooo`;o00003Oooool2o`0005Cooooo0_l0
000Cooooo`;o0000=?ooool2o`0000Sooooo0_l0000Looooo`007_ooool00ol0003oooooooooo`0h
ooooo`;o00001_ooool2o`0002gooooo0_l0000=ooooo`;o0000E?ooool2o`0001?ooooo0_l0000V
ooooo`;o00003?ooool2o`0000Sooooo0_l00004ooooo`;o00005_ooool001kooooo0_l000000ooo
oooo0000o`00000nooooo`;o0000coooool2o`0001cooooo0_l0000Fooooo`007_ooool00ol0003o
ooooooooo`02o`00077ooooo0_l0000Iooooo`;o00006_ooool2o`0001oooooo0_l0001jooooo`00
7_ooool00ol0003oooooooooo`1cooooo`;o00006Oooool2o`0001[ooooo0_l0000Jooooo`;o0000
0oooool2o`0001?ooooo0_l0001Iooooo`;o00002_ooool001kooooo00?o0000ooooooooool00_oo
ool2o`0008;ooooo0_l0000iooooo`;o00000oooool2o`0001Sooooo0_l00006ooooo`;o0000DOoo
ool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0001Gooooo`;o0000:Oooool2
o`0003Wooooo0_l0000Uooooo`;o0000AOooool2o`0001Kooooo000Nooooo`03o`000?oooooooooo
05_ooooo0_l0002oooooo`;o00003Oooool2o`0000;ooooo0_l0000Fooooo`007_ooool00ol0003o
ooooooooo`0]ooooo`;o0000/?ooool2o`0003_ooooo0_l0000=ooooo`;o00004_ooool2o`0000Ko
oooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0000?ooooo`;o00002?ooool2o`00087ooooo
0_l0000]ooooo`;o00003oooool2o`0004gooooo0_l00006ooooo`007_ooool00ol0003ooooooooo
o`0Booooo`;o00001oooool3o`0000Gooooo0_l0000/ooooo`;o0000GOooool2o`0003kooooo0_l0
000Xooooo`;o00002oooool2o`0001kooooo000Nooooo`03o`000?oooooooooo01Wooooo1Ol0000E
ooooo`;o00001Oooool2o`0001Gooooo0_l0001mooooo`;o00006oooool2o`0000cooooo0_l0000M
ooooo`;o00002oooool2o`0001kooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l0000Hoooo
o`;o00001Oooool2o`0009Cooooo0_l0000Kooooo`;o00003?ooool2o`0004[ooooo000Nooooo`03
o`000?oooooooooo04Kooooo0_l0003oooooo`007_ooool00ol0003oooooooooo`16ooooo`;o0000
ooooool001kooooo00?o0000ooooooooool02oooool2o`0001oooooo0_l0000Sooooo`;o0000;_oo
ool2o`0005gooooo0_l0000>ooooo`;o0000:oooool2o`0000oooooo0_l0000Gooooo`000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0
1_ooool00ol0003oooooooooo`0;ooooo`;o00007oooool2o`0001Cooooo0_l0000=ooooo`;o0000
:Oooool2o`0000?ooooo0_l0000mooooo`;o00004_ooool2o`0000Kooooo0_l00002ooooo`;o0000
3_ooool2o`0002_ooooo0_l0000;ooooo`;o00000_ooool2o`0001Oooooo0003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03
o`000?oooooooooo04;ooooo0_l0000hooooo`;o0000=_ooool2o`0000[ooooo0_l0000Booooo`;o
00001_ooool2o`0004cooooo0_l0000Kooooo`000oooool01Ol@413ooooooooooooooooo410@00_o
oooo00Go0000ooooooooooooooooo`000006ooooo`?o0000Loooool2o`0003oooooo0_l0002Aoooo
o`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06
ooooo`03o`000?oooooooooo07?ooooo0_l00014ooooo`;o0000S?ooool000?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003ooooooooo
o`1Vooooo`;o00008Oooool2o`0002kooooo0_l0001dooooo`;o00005_ooool000?ooooo00Go410@
oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool06Ooo
ool2o`0004_ooooo0_l0000Qooooo`;o0000<oooool2o`0000Kooooo0_l000000ooooooo0000o`00
001Tooooo`;o00005_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@
413oV9RH00Sooooo00?o0000ooooooooool06Oooool2o`000:?ooooo0_l00006ooooo`;o000000?o
ooooo`000?l00000O?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0D?ooool2o`0005kooooo0_l0000booooo`;o0000
HOooool001kooooo00?o0000ooooooooool0D?ooool2o`0005kooooo0_l0000booooo`;o00005Ooo
ool2o`0004[ooooo000Nooooo`03o`000?oooooooooo06Oooooo0_l0000;ooooo`;o0000I?ooool2
o`0001oooooo0_l0000Aooooo`;o0000=oooool001kooooo00?o0000ooooooooool03Oooool2o`00
0003ooooool0003o000003Oooooo0_l0000Looooo`;o00002oooool2o`0006Cooooo0_l0000boooo
o`;o0000=oooool001kooooo00?o0000ooooooooool03Oooool2o`000004ooooool0003o0000o`00
03Kooooo0_l0003looooo`007_ooool00ol0003oooooooooo`0Aooooo`;o0000ooooooleooooo`00
7_ooool00ol0003oooooooooo`0nooooo`;o0000V?ooool2o`0003?ooooo0_l0000Zooooo`;o0000
00?oooooo`000?l000002Oooool001kooooo00?o0000ooooooooool0=_ooool2o`0000Kooooo0_l0
001<ooooo`;o00002?ooool2o`00043ooooo0_l0000^ooooo`;o00000oooool2o`0002[ooooo0_l0
00000ooooooo0000o`000009ooooo`007_ooool00ol0003oooooooooo`0fooooo`;o00005?ooool2
o`0000;ooooo0_l0000jooooo`;o00002?ooool2o`0004Kooooo0_l0000Xooooo`;o00004Oooool2
o`0001kooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`1<ooooo`;o00000_ooool2o`00
06oooooo0_l0000Kooooo`;o0000>oooool2o`0001kooooo0_l0000:ooooo`007_ooool00ol0003o
ooooooooo`0=ooooo`;o0000;_ooool2o`0008;ooooo0_l0000:ooooo`;o0000C_ooool2o`0002So
oooo000Nooooo`03o`000?oooooooooo00gooooo0_l0000^ooooo`;o00002_ooool2o`0008;ooooo
0_l0001>ooooo`;o0000:?ooool001kooooo0_l0001:ooooo`;o0000POooool2o`0002Wooooo0_l0
0007ooooo`;o00005_ooool2o`0001Kooooo0_l0000Eooooo`007_ooool00ol0003oooooooooo`1/
ooooo`;o0000G_ooool2o`0002Wooooo0_l00007ooooo`;o00005_ooool2o`0001Kooooo0_l0000E
ooooo`007_ooool00ol0003oooooooooo`1Qooooo`;o00002Oooool2o`0007Gooooo0_l0001:oooo
o`;o00001oooool2o`0000gooooo000Nooooo`03o`000?oooooooooo02Kooooo0_l0000iooooo`;o
00006Oooool2o`0006Gooooo0_l00003ooooo`;o0000AOooool2o`0000Oooooo0_l0000=ooooo`00
7_ooool00ol0003oooooooooo`0Vooooo`;o0000E?ooool2o`0006[ooooo0_l0001Mooooo`007_oo
ool01?l0003oooooooooooooool2o`00053ooooo0_l00004ooooo`;o0000goooool2o`0000_ooooo
000Nooooo`04o`000?ooooooooooooooo`;o0000C_ooool4o`0000Cooooo0_l0000fooooo`;o0000
?Oooool2o`0003Cooooo0_l0000booooo`;o00002oooool001kooooo00?o0000ooooooooool0DOoo
ool2o`0002Gooooo0_l0000Gooooo`;o00001_ooool2o`0003Gooooo0_l0000dooooo`;o0000?ooo
ool001kooooo00?o0000ooooooooool0Joooool2o`0000_ooooo0_l0000Jooooo`;o00000oooool2
o`000:cooooo000Nooooo`03o`000?oooooooooo02Wooooo0_l0000=ooooo`?o000000?oooooo`00
0?l00000;?ooool3o`0002Oooooo0_l0000Jooooo`;o0000NOooool2o`0000_ooooo0_l00005oooo
o`;o00001_ooool001kooooo00?o0000ooooooooool0:Oooool2o`0000gooooo0ol000000ooooooo
0000o`00000/ooooo`;o00006Oooool2o`0002Wooooo0_l0001iooooo`;o00002oooool2o`0000Go
oooo0_l00006ooooo`007_ooool00ol0003oooooooooo`05ooooo`;o00001_ooool2o`0007Kooooo
0_l0000Looooo`;o0000UOooool2o`0000?ooooo0_l00006ooooo`007_ooool00ol0003ooooooooo
o`05ooooo`Co00001?ooool2o`00047ooooo0_l0000>ooooo`;o0000@Oooool2o`00053ooooo0_l0
000Eooooo`;o0000;?ooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo00Oooooo0_l00017
ooooo`;o00003_ooool2o`0002Kooooo0_l0000jooooo`;o0000;oooool2o`0001Gooooo0_l0000X
ooooo`;o00003oooool001kooooo00?o0000ooooooooool0E?ooool2o`0003;ooooo0_l0000Moooo
o`;o00006oooool2o`0001Oooooo0_l0000@ooooo`;o0000AOooool2o`0000oooooo000Nooooo`03
o`000?oooooooooo04oooooo0_l00003ooooo`;o0000DOooool2o`0001kooooo0_l0000Dooooo`;o
00004?ooool2o`0000[ooooo0_l0001:ooooo`007_ooool2o`0004Kooooo0_l00008ooooo`;o0000
M_ooool3o`00037ooooo0_l0001:ooooo`007_ooool2o`0004Kooooo0_l00021ooooo`;o0000C_oo
ool2o`0001?ooooo0_l0000Hooooo`007_ooool00ol0003oooooooooo`3ooooooaWooooo0_l0000C
ooooo`;o00006?ooool001kooooo00?o0000ooooooooool0D?ooool2o`0000;ooooo0_l00003oooo
o`;o00005_ooool2o`000=Cooooo000Nooooo`03o`000?oooooooooo04;ooooo0_l0000<ooooo`;o
00000_ooool2o`0000?ooooo0_l0000Fooooo`;o0000R_ooool2o`0004Sooooo000Nooooo`03o`00
0?oooooooooo00gooooo0_l0000cooooo`;o0000FOooool2o`00013ooooo0_l0000Zooooo`;o0000
2?ooool2o`0001Kooooo0_l00018ooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o0000;_oo
ool2o`0001Gooooo0_l0000Iooooo`;o0000;?ooool2o`00013ooooo0_l0000Zooooo`;o000000?o
ooooo`000?l000001Oooool2o`00063ooooo000Nooooo`03o`000?oooooooooo03gooooo0_l0000E
ooooo`;o00006Oooool2o`00013ooooo0_l0000gooooo`;o00008_ooool2o`0000oooooo0_l0000O
ooooo`;o0000;Oooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0001Xoooo
o`;o00003?ooool2o`0002Wooooo0_l0000cooooo`;o00007oooool2o`0002gooooo0_l00006oooo
o`007Oooool2o`0001Wooooo0_l0000Looooo`;o0000F?ooool2o`000;Kooooo000Mooooo`;o0000
=oooool2o`0000cooooo0_l0002`ooooo`;o00002Oooool2o`0004Gooooo000Nooooo`03o`000?oo
oooooooo00_ooooo0_l0000fooooo`;o0000F_ooool2o`0005Cooooo0_l00002ooooo`;o00001Ooo
ool2o`0004Gooooo000Nooooo`03o`000?oooooooooo00_ooooo0_l0000Pooooo`;o0000L?ooool2
o`0002;ooooo0_l0000dooooo`;o0000C?ooool001kooooo00?o0000ooooooooool01Oooool2o`00
02Kooooo0_l000000ooooooo0000o`00000Wooooo`;o0000;_ooool2o`0000?ooooo0_l0000coooo
o`;o000000?oooooo`000?l000002?ooool2o`0001Wooooo0_l0000Tooooo`;o0000=?ooool001ko
oooo00?o0000ooooooooool01Oooool2o`0002Wooooo0_l0000Vooooo`?o0000;_ooool2o`0000?o
oooo0_l0000Aooooo`;o00008oooool2o`0000Sooooo0_l0000Iooooo`;o00009?ooool2o`0001?o
oooo0_l0000Oooooo`007_ooool00ol0003oooooooooo`1Hooooo`;o0000Aoooool2o`0008?ooooo
0_l0000Oooooo`007_ooool2o`0000?ooooo0_l00012ooooo`;o0000Woooool2o`0005kooooo000N
ooooo`03o`000?oooooooooo00;ooooo0_l00012ooooo`;o0000Woooool2o`0005kooooo000Noooo
o`03o`000?oooooooooo017ooooo0_l0000_ooooo`;o0000=?ooool2o`0005_ooooo0_l0000eoooo
o`;o000000?oooooo`000?l00000=_ooool001kooooo00?o0000ooooooooool04Oooool2o`0001Ko
oooo0_l0000Gooooo`;o00008?ooool2o`0000Oooooo0_l00008ooooo`?o00007oooool2o`0003[o
oooo0_l0000eooooo`;o000000?oooooo`000?l00000=_ooool001kooooo00?o0000ooooooooool0
:Oooool2o`0002?ooooo0_l0000Dooooo`;o00001oooool2o`0000Sooooo0_l0000Pooooo`;o0000
[?ooool001kooooo00?o0000ooooooooool0C_ooool2o`0007Kooooo0_l0000Uooooo`;o0000F?oo
ool001kooooo00?o0000ooooooooool01_ooool2o`0000Kooooo0_l0000Oooooo`;o0000UOooool2
o`0001_ooooo0_l00008ooooo`;o0000D?ooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo
00Kooooo0_l00006ooooo`;o00007oooool2o`0001_ooooo0_l0002Eooooo`;o00002_ooool2o`00
04kooooo0_l00006ooooo`007_ooool00ol0003oooooooooo`06ooooo`;o00009_ooool2o`0001co
oooo0_l0002Qooooo`;o0000E_ooool001kooooo00?o0000ooooooooool0;_ooool4o`0000[ooooo
0_l0000:ooooo`;o0000Noooool2o`0006?ooooo0_l00002ooooo`;o00005oooool001kooooo00?o
0000ooooooooool00_l0000/ooooo`Co00002_ooool2o`0000[ooooo0_l0001Gooooo`;o00008_oo
ool2o`0002;ooooo0_l0000Tooooo`;o00006Oooool2o`0000;ooooo0_l0000Gooooo`007_ooool0
0ol0003oooooooooo`02o`0000;ooooo0_l0001Vooooo`;o0000<oooool2o`0004Kooooo0_l0000T
ooooo`;o0000=_ooool001kooooo00?o0000ooooooooool01?ooool2o`0006Kooooo0_l0000Joooo
o`;o00006?ooool2o`0000[ooooo0_l00003ooooo`;o00003oooool2o`0005?ooooo0_l0000/oooo
o`007_ooool00ol0003oooooooooo`08ooooo`;o00008Oooool2o`00037ooooo0_l0000Xooooo`;o
000000?oooooo`000?l000005Oooool2o`0000[ooooo0_l00003ooooo`;o00000_ooool2o`0000_o
oooo0_l0001Cooooo`;o0000;?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool01_ooool4o`00
027ooooo0_l0000[ooooo`;o00001?ooool2o`0002_ooooo0_l0000Zooooo`;o0000E_ooool2o`00
03Kooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRH
V?ooooooV9RHob4Q8@06ooooo`;o00001oooool2o`00027ooooo0_l0000]ooooo`;o00004_ooool2
o`000:7ooooo0_l0000^ooooo`;o00001_ooool000?ooooo00Go410@oooooooooooooooooa0@400;
ooooo`05o`000?ooooooooooooooool000001_ooool3o`0002Wooooo0_l0000Looooo`;o00008ooo
ool2o`0002kooooo0_l00019ooooo`;o0000;_ooool2o`0002Kooooo0_l00006ooooo`000oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`00
0?oooooooooo04Oooooo0_l0001Cooooo`;o0000BOooool2o`0002kooooo0_l0000^ooooo`000ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03
o`000?oooooooooo05oooooo0ol00005ooooo`;o00006oooool2o`00017ooooo0_l0002^ooooo`00
0oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006oooo
o`03o`000?oooooooooo00Kooooo0_l0001Gooooo`?o00001Oooool2o`0001_ooooo0_l0000Aoooo
o`;o0000H_ooool2o`0004[ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool01_ooool2o`0002?ooooo0_l0000]
ooooo`;o0000C_ooool2o`0001Cooooo0_l0000Qooooo`;o00002?ooool2o`000003ooooool0003o
000000;o00001oooool2o`0004[ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool05Oooool2o`0001Cooooo0_l0
0009ooooo`;o00008_ooool2o`00027ooooo0_l0000Qooooo`;o00002?ooool2o`0001?ooooo0ol0
000Qooooo`;o00002?ooool2o`000003ooooool0003o000000;o00003Oooool2o`0004Cooooo000N
ooooo`03o`000?oooooooooo01Gooooo1?l0000Mooooo`;o00004_ooool2o`00037ooooo0_l0000Q
ooooo`;o00007Oooool2o`00043ooooo0_l00014ooooo`007_ooool00ol0003oooooooooo`0Goooo
o`;o0000<Oooool2o`0000Oooooo0_l00014ooooo`;o0000?oooool2o`0006_ooooo000Nooooo`03
o`000?oooooooooo05?ooooo1?l0000Rooooo`;o00007_ooool2o`0003oooooo0_l0001[ooooo`00
7_ooool00ol0003oooooooooo`13ooooo`;o00004?ooool3o`0000Oooooo0_l00002ooooo`;o0000
5?ooool2o`0000[ooooo0_l00030ooooo`007_ooool00ol0003oooooooooo`13ooooo`;o00004Ooo
ool2o`0000Oooooo0_l00002ooooo`;o00008?ooool2o`0000cooooo0_l0001iooooo`;o0000=ooo
ool001kooooo00?o0000ooooooooool06_ooool2o`0001Oooooo0_l0001Fooooo`;o00001_ooool2
o`0004oooooo0_l0000Sooooo`;o00000oooool2o`0003Oooooo000Nooooo`03o`000?oooooooooo
01Oooooo0_l000000ooooooo0000o`00000Gooooo`;o00009Oooool2o`0000cooooo0_l00004oooo
o`;o00006oooool2o`0005Oooooo1?l0000Qooooo`;o0000??ooool001kooooo00?o0000oooooooo
ool05oooool2o`00047ooooo0_l0000<ooooo`;o00001?ooool2o`0007Kooooo0_l0000^ooooo`;o
0000;oooool001kooooo00?o0000ooooooooool0M_ooool2o`0009kooooo0_l0000_ooooo`007_oo
ool00ol0003oooooooooo`0Aooooo`;o0000Hoooool2o`0002Sooooo0_l0000Fooooo`;o0000;ooo
ool2o`00027ooooo0_l0000Rooooo`;o00005Oooool001kooooo00?o0000ooooooooool04Oooool2
o`0003gooooo0_l0000Cooooo`;o00009_ooool2o`00017ooooo0_l0000Fooooo`;o0000;oooool2
o`00027ooooo0_l0000Rooooo`;o00005Oooool001kooooo0_l0000_ooooo`;o00008?ooool2o`00
01?ooooo0_l0000Vooooo`;o0000BOooool2o`0006gooooo000Nooooo`03o`000?oooooooooo00Ko
oooo0_l0000Vooooo`;o0000;_ooool2o`0006cooooo0_l0000:ooooo`;o0000;_ooool2o`0003go
oooo000Nooooo`03o`000?oooooooooo00Kooooo0_l00003ooooo`;o00001_ooool2o`0003;ooooo
0_l0000Eooooo`;o0000K?ooool2o`00013ooooo0_l0000Jooooo`;o00003?ooool2o`0003;ooooo
0_l00003ooooo`;o00001?ooool001kooooo00?o0000ooooooooool02oooool2o`0000;ooooo0_l0
0002ooooo`;o0000<_ooool2o`0007?ooooo0_l0000Pooooo`;o00006_ooool2o`0000gooooo0_l0
000Mooooo`;o00004_ooool2o`0000?ooooo0_l00004ooooo`007_ooool2o`00013ooooo0_l0001U
ooooo`;o0000A?ooool2o`0004Kooooo0_l00003ooooo`;o00005_ooool2o`0000Gooooo0_l00003
ooooo`;o00006?ooool001kooooo0_l0000Cooooo`;o0000H_ooool2o`0005;ooooo0_l0000hoooo
o`;o00006oooool2o`0000[ooooo0_l0000Hooooo`007_ooool00ol0003oooooooooo`0Booooo`;o
00005?ooool2o`000:3ooooo0_l0001aooooo`;o00002?ooool001kooooo00?o0000ooooooooool0
:?ooool2o`0001Sooooo1?l00027ooooo`;o0000C?ooool2o`00023ooooo0_l00008ooooo`007_oo
ool00ol0003oooooooooo`12ooooo`Co0000COooool2o`0000gooooo0_l0000Yooooo`;o0000C?oo
ool2o`0002[ooooo000Nooooo`03o`000?oooooooooo05Cooooo0_l0000mooooo`;o00002?ooool2
o`0000?ooooo0_l0002Sooooo`007_ooool00ol0003oooooooooo`1Dooooo`;o00000oooool2o`00
04;ooooo0_l0000cooooo`;o0000Loooool001kooooo00?o0000ooooooooool0?_ooool2o`0001Wo
oooo0_l0001gooooo`;o0000=Oooool2o`0001_ooooo0_l00009ooooo`;o00005?ooool001kooooo
00?o0000ooooooooool0?_ooool2o`0005Oooooo0_l0001`ooooo`;o00001oooool2o`0001;ooooo
0_l00009ooooo`;o00005?ooool001kooooo00?o0000ooooooooool07?ooool2o`0007Wooooo0_l0
001iooooo`;o00005_ooool2o`0001_ooooo000Nooooo`03o`000?oooooooooo01cooooo0_l0000R
ooooo`;o0000Ooooool2o`0006Oooooo0_l0000Kooooo`007_ooool00ol0003oooooooooo`0>oooo
o`;o0000<?ooool2o`0006Gooooo0_l0000Hooooo`;o0000L_ooool2o`00013ooooo000Nooooo`;o
00003oooool2o`0009Oooooo0_l0002<ooooo`;o00002?ooool2o`0000Kooooo000Nooooo`03o`00
0?oooooooooo0?_ooooo0_l0000]ooooo`;o00004oooool2o`0000Kooooo000Nooooo`03o`000?oo
oooooooo0:;ooooo0_l0000>ooooo`;o0000=Oooool2o`00013ooooo0_l0000]ooooo`;o00006ooo
ool001kooooo00?o0000ooooooooool03_ooool2o`0002cooooo0_l0001Tooooo`;o00003_ooool2
o`0003Gooooo0_l0000oooooo`;o00006oooool001kooooo00?o0000ooooooooool03_ooool2o`00
02cooooo0_l0000cooooo`;o0000??ooool2o`0009Kooooo000Nooooo`03o`000?oooooooooo01Go
oooo0_l0000Qooooo`;o0000<?ooool2o`0000Gooooo0_l0000[ooooo`;o00003oooool2o`0002go
oooo0_l0000jooooo`;o0000:oooool001kooooo00?o0000ooooooooool05Oooool2o`00027ooooo
0_l0000`ooooo`;o0000<_ooool2o`0003kooooo0_l0000jooooo`;o0000:oooool001kooooo00?o
0000ooooooooool0YOooool2o`0001Cooooo0_l000000ooooooo0000o`000027ooooo`007_ooool0
0ol0003oooooooooo`08ooooo`;o00001Oooool2o`000003ooooool0003o000006_ooooo0_l0000T
ooooo`;o00005?ooool2o`000003ooooool0003o000004Cooooo0_l0000Jooooo`;o00009Oooool0
01kooooo00?o0000ooooooooool02?ooool2o`0000Gooooo0_l000000ooooooo0000o`00000`oooo
o`;o00006?ooool2o`0001oooooo0_l0000_ooooo`;o0000D_ooool2o`0000oooooo0_l00009oooo
o`;o00009Oooool001kooooo00?o0000ooooooooool0A?ooool2o`0001Sooooo0_l0001@ooooo`;o
0000:?ooool2o`0000cooooo0_l00006ooooo`;o00008oooool2o`00033ooooo000Nooooo`03o`00
0?oooooooooo05[ooooo0_l0000Fooooo`;o0000Eoooool2o`0000gooooo0_l0000<ooooo`;o0000
1_ooool2o`0005Gooooo000Nooooo`03o`000?oooooooooo05[ooooo0_l0000Fooooo`;o00008ooo
ool2o`0002;ooooo0_l0000>ooooo`;o00007oooool2o`0005Wooooo000Nooooo`03o`000?oooooo
oooo09Cooooo0_l000000ooooooo0000o`00000Rooooo`;o00008Oooool2o`0000cooooo0_l0001I
ooooo`007_ooool00ol0003oooooooooo`1aooooo`;o00008Oooool2o`00023ooooo0_l0000:oooo
o`;o00006_ooool2o`0006Oooooo000Nooooo`03o`000?oooooooooo077ooooo0_l00013ooooo`;o
00002_ooool2o`0002oooooo0_l00010ooooo`;o00004?ooool001kooooo0_l0000Vooooo`;o0000
;oooool2o`0004;ooooo0_l0000<ooooo`;o00008Oooool2o`0002Kooooo0_l00010ooooo`;o0000
4?ooool001kooooo00?o0000ooooooooool07Oooool2o`0000Kooooo0_l0000_ooooo`;o0000@_oo
ool2o`0000cooooo0_l0000Fooooo`;o00002Oooool2o`0000Oooooo0_l00006ooooo`;o00003ooo
ool2o`0005Sooooo000Nooooo`03o`000?oooooooooo01gooooo0_l00012ooooo`;o0000GOooool2
o`0001;ooooo0_l00006ooooo`;o00003oooool2o`0000Wooooo0_l0000Yooooo`;o00008_ooool0
01kooooo00?o0000ooooooooool0HOooool2o`0003[ooooo0_l0001Iooooo`;o000000?oooooo`00
0?l000009_ooool2o`0002;ooooo000Nooooo`03o`000?oooooooooo04?ooooo0_l00016ooooo`;o
00004?ooool2o`0005cooooo0_l0001:ooooo`007_ooool00ol0003oooooooooo`13ooooo`;o0000
?Oooool2o`0000Oooooo0_l0001hooooo`;o00002?ooool2o`0002?ooooo0_l0000Aooooo`007_oo
ool00ol0003oooooooooo`22ooooo`;o0000:Oooool2o`0004oooooo0_l00005ooooo`;o00002?oo
ool2o`0000oooooo0_l0000Booooo`;o00004Oooool001kooooo00?o0000ooooooooool0BOooool2
o`0003_ooooo0_l0000Uooooo`;o0000Coooool2o`00023ooooo0_l0000Uooooo`007_ooool00ol0
003oooooooooo`0jooooo`;o00003Oooool2o`000003ooooool0003o000003Sooooo0_l0000Uoooo
o`;o0000K?ooool2o`0002[ooooo000Nooooo`03o`000?oooooooooo02Gooooo0_l0000Cooooo`;o
00001?ooool2o`0000[ooooo0_l0001Oooooo`;o0000Eoooool2o`0001?ooooo0_l0000Zooooo`00
7_ooool00ol0003oooooooooo`0Uooooo`;o00001oooool2o`00013ooooo0_l0001gooooo`Co0000
:?ooool2o`0001oooooo0_l0000dooooo`;o00002Oooool001kooooo00?o0000ooooooooool0;_oo
ool2o`0008Wooooo1?l0000Xooooo`;o0000;Oooool2o`0002Kooooo0_l00009ooooo`007_ooool0
0ol0003oooooooooo`25ooooo`;o0000<_ooool2o`0005Wooooo0_l0000aooooo`007_ooool00ol0
003oooooooooo`0fooooo`;o0000;?ooool2o`0000Kooooo0_l0000Gooooo`?o0000=?ooool2o`00
00gooooo0_l0001Zooooo`;o00003_ooool001Cooooo1?l000000ol@413oooooooooo`03ooooo`;o
0000=oooool2o`0002cooooo0_l00006ooooo`;o00006?ooool2o`0001Kooooo0_l0000Looooo`;o
00003Oooool2o`0004Wooooo0_l0000Nooooo`?o00003_ooool001Kooooo00?o0000ooooooooool0
1Oooool2o`00057ooooo0_l00012ooooo`;o00002?ooool2o`0000Gooooo0_l0001:ooooo`;o0000
8oooool2o`0001kooooo0_l0000?ooooo`005_ooool00ol0003oooooooooo`05ooooo`?o0000@Ooo
ool2o`0000gooooo0_l00012ooooo`;o00003oooool2o`0004[ooooo0_l0001Dooooo`005_ooool0
0ol0003oooooooooo`19ooooo`;o0000ooooool5ooooo`005_ooool00ol0003oooooooooo`3ooooo
oe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0
oooooom@ooooo`005?ooool00omEEEGoIVIVo`00003ooooooe;ooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.5187 .91048 Mdot
.49431 .37417 Mdot
.49265 .91374 Mdot
.89188 .22691 Mdot
.04892 .93233 Mdot
.71206 .51598 Mdot
.41684 .35889 Mdot
.35717 .7943 Mdot
.34701 .50243 Mdot
.79711 .03854 Mdot
.57294 .32561 Mdot
.51769 .43103 Mdot
.27402 .80012 Mdot
.92916 .99926 Mdot
.61286 .29428 Mdot
.80237 .85667 Mdot
.26854 .87768 Mdot
.97242 .57781 Mdot
.08213 .92096 Mdot
.43143 .47991 Mdot
.70475 .51807 Mdot
.05814 .06691 Mdot
.20744 .74042 Mdot
.48991 .90509 Mdot
.46762 .14554 Mdot
.78023 .20792 Mdot
.72086 .30256 Mdot
.47939 .38828 Mdot
.63442 .31284 Mdot
.32432 .80233 Mdot
.261 .78327 Mdot
.01523 .96602 Mdot
.24019 .58405 Mdot
.20757 .14009 Mdot
.55303 .55735 Mdot
.51087 .38809 Mdot
.7135 .76369 Mdot
.37319 .80606 Mdot
.46483 .51249 Mdot
.80118 .17196 Mdot
.34764 .63109 Mdot
.62714 .37378 Mdot
.12411 .90431 Mdot
.0742 .75372 Mdot
.19118 .72578 Mdot
.83248 .50609 Mdot
.15839 .53501 Mdot
.93936 .11114 Mdot
.69448 .04565 Mdot
.64671 .89215 Mdot
.26315 .837 Mdot
.85396 .41389 Mdot
.32886 .2255 Mdot
.98308 .35782 Mdot
.45136 .14977 Mdot
.19432 .66049 Mdot
.15754 .91153 Mdot
.87363 .5518 Mdot
.9138 .50477 Mdot
.9657 .41402 Mdot
.47695 .69033 Mdot
.2226 .62683 Mdot
.30612 .36003 Mdot
.5394 .88794 Mdot
.6936 .5845 Mdot
.52267 .23596 Mdot
.87343 .32744 Mdot
.62642 .74303 Mdot
.57557 .95864 Mdot
.02148 .0163 Mdot
.55126 .4764 Mdot
.37585 .68652 Mdot
.26742 .85714 Mdot
.62728 .23806 Mdot
.76185 .00692 Mdot
.00844 .36124 Mdot
.40263 .21578 Mdot
.92658 .55032 Mdot
.53213 .53529 Mdot
.57037 .90714 Mdot
.58646 .93466 Mdot
.32938 .46702 Mdot
.24093 .31736 Mdot
.36061 .49728 Mdot
.16878 .74404 Mdot
.35573 .87224 Mdot
.70474 .56115 Mdot
.55859 .08581 Mdot
.58497 .41772 Mdot
.86608 .23609 Mdot
.88199 .23615 Mdot
.03718 .83621 Mdot
.46283 .85991 Mdot
.06461 .13362 Mdot
.51891 .23008 Mdot
.79215 .73918 Mdot
.75869 .00665 Mdot
.84152 .70483 Mdot
.43086 .87155 Mdot
.75168 .06215 Mdot
.71872 .08261 Mdot
.77769 .33405 Mdot
.98912 .62333 Mdot
.0315 .13809 Mdot
.23777 .07073 Mdot
.1602 .2984 Mdot
.92071 .55349 Mdot
.378 .01363 Mdot
.15101 .61129 Mdot
.00695 .46668 Mdot
.13996 .91753 Mdot
.49135 .49248 Mdot
.42587 .758 Mdot
.00531 .48653 Mdot
.67233 .29535 Mdot
.96042 .67522 Mdot
.87243 .61545 Mdot
.31084 .08365 Mdot
.34039 .94477 Mdot
.75933 .76863 Mdot
.78803 .83143 Mdot
.50082 .82618 Mdot
.38052 .18475 Mdot
.24693 .34779 Mdot
.21994 .12554 Mdot
.22669 .71946 Mdot
.01661 .6821 Mdot
.3745 .26924 Mdot
.95659 .79448 Mdot
.45196 .38249 Mdot
.88587 .54498 Mdot
.5486 .26687 Mdot
.48773 .10619 Mdot
.85323 .13896 Mdot
.42617 .07551 Mdot
.49074 .97101 Mdot
.46407 .19652 Mdot
.19847 .95571 Mdot
.76654 .01188 Mdot
.37441 .90699 Mdot
.44597 .71413 Mdot
.70711 .77791 Mdot
.94861 .21801 Mdot
.46597 .81594 Mdot
.27577 .23037 Mdot
.16634 .81745 Mdot
.37811 .67425 Mdot
.60328 .52589 Mdot
.96866 .64864 Mdot
.79495 .28657 Mdot
.31824 .90749 Mdot
.77347 .61052 Mdot
.55222 .71236 Mdot
.98346 .61842 Mdot
.71341 .41983 Mdot
.21418 .68845 Mdot
.80469 .20334 Mdot
.41728 .01697 Mdot
.32966 .47386 Mdot
.41624 .33907 Mdot
.77274 .95165 Mdot
.63796 .63027 Mdot
.03445 .74708 Mdot
.34093 .97529 Mdot
.80399 .29394 Mdot
.6021 .17258 Mdot
.43937 .88631 Mdot
.61828 .92412 Mdot
.16895 .43846 Mdot
.41022 .28376 Mdot
.27006 .4016 Mdot
.20552 .86236 Mdot
.21049 .85669 Mdot
.56602 .68089 Mdot
.98529 .05238 Mdot
.83446 .68565 Mdot
.20856 .14403 Mdot
.85503 .04557 Mdot
.74734 .15389 Mdot
.33941 .72398 Mdot
.01271 .80436 Mdot
.88254 .90854 Mdot
.44906 .00947 Mdot
.12886 .63011 Mdot
.607 .75594 Mdot
.54443 .05097 Mdot
.98952 .42083 Mdot
.97911 .61866 Mdot
.67744 .76731 Mdot
.86368 .15883 Mdot
.24654 .0157 Mdot
.66071 .97547 Mdot
.12637 .7704 Mdot
.37737 .00643 Mdot
.69078 .82653 Mdot
.717 .86872 Mdot
.9083 .59968 Mdot
.62809 .76314 Mdot
.18418 .54027 Mdot
.93634 .57312 Mdot
.43363 .29732 Mdot
.70354 .76373 Mdot
.20013 .00094 Mdot
.31909 .1777 Mdot
.57531 .03391 Mdot
.14714 .07803 Mdot
.75083 .734 Mdot
.95236 .74784 Mdot
.08704 .74272 Mdot
.20226 .7806 Mdot
.20196 .73313 Mdot
.98433 .64325 Mdot
.12542 .54801 Mdot
.91988 .47939 Mdot
.97829 .03312 Mdot
.49585 .46178 Mdot
.68195 .29663 Mdot
.0015 .32943 Mdot
.82216 .99185 Mdot
.21921 .69865 Mdot
.90095 .99117 Mdot
.92244 .38169 Mdot
.68543 .2568 Mdot
.64286 .85681 Mdot
.95956 .28958 Mdot
.80638 .75156 Mdot
.84216 .72399 Mdot
.23258 .69207 Mdot
.36523 .33752 Mdot
.66384 .46152 Mdot
.96792 .84331 Mdot
.30456 .99539 Mdot
.37501 .60258 Mdot
.29719 .88699 Mdot
.36149 .05182 Mdot
.17522 .15407 Mdot
.27783 .60878 Mdot
.78647 .32068 Mdot
.44522 .57234 Mdot
.56955 .53297 Mdot
.36896 .70717 Mdot
.60054 .75799 Mdot
.00425 .28801 Mdot
.46201 .80451 Mdot
.10509 .39251 Mdot
.13818 .98743 Mdot
.13906 .76174 Mdot
.40276 .79795 Mdot
.62234 .19454 Mdot
.20972 .52394 Mdot
.68189 .55342 Mdot
.59043 .04607 Mdot
.09391 .17029 Mdot
.74191 .13924 Mdot
.08269 .25051 Mdot
.23902 .95627 Mdot
.52746 .99845 Mdot
.06821 .91521 Mdot
.32782 .40442 Mdot
.6894 .10454 Mdot
.52022 .03322 Mdot
.89378 .25269 Mdot
.91641 .11958 Mdot
.48419 .10036 Mdot
.04323 .23789 Mdot
.33955 .34317 Mdot
.32023 .11652 Mdot
.20018 .53373 Mdot
.49155 .41843 Mdot
.0551 .96472 Mdot
.93734 .01468 Mdot
.39597 .08221 Mdot
.2859 .78536 Mdot
.4907 .93934 Mdot
.21577 .99306 Mdot
.63869 .89926 Mdot
.52327 .06579 Mdot
.71955 .23925 Mdot
.44107 .20611 Mdot
.20527 .70574 Mdot
.46681 .28782 Mdot
.20958 .94163 Mdot
.5649 .44403 Mdot
.82359 .93187 Mdot
.02881 .14615 Mdot
.86376 .68395 Mdot
.73548 .14423 Mdot
.87934 .1527 Mdot
.84545 .06482 Mdot
.72879 .04856 Mdot
.83242 .97895 Mdot
.11572 .31364 Mdot
.76539 .79868 Mdot
.69941 .49295 Mdot
.95881 .59489 Mdot
.03706 .23872 Mdot
.58368 .72228 Mdot
.19902 .34944 Mdot
.64572 .51231 Mdot
.18294 .0075 Mdot
.72157 .21994 Mdot
.56854 .26099 Mdot
.53226 .40727 Mdot
.22985 .2966 Mdot
.57693 .8385 Mdot
.43374 .49819 Mdot
.5108 .35169 Mdot
.64361 .92107 Mdot
.7794 .79036 Mdot
.88558 .80695 Mdot
.36178 .55483 Mdot
.58947 .5563 Mdot
.31084 .29405 Mdot
.66245 .03071 Mdot
.09501 .36073 Mdot
.88311 .29836 Mdot
.06621 .66157 Mdot
.19071 .73028 Mdot
.32897 .20166 Mdot
.72111 .28829 Mdot
.84497 .70953 Mdot
.63311 .02538 Mdot
.75346 .32354 Mdot
.70327 .83356 Mdot
.57758 .24549 Mdot
.80494 .7435 Mdot
.65484 .26468 Mdot
.65713 .51171 Mdot
.9239 .82907 Mdot
.97937 .54928 Mdot
.94853 .11249 Mdot
.06777 .81495 Mdot
.73639 .73446 Mdot
.57319 .17819 Mdot
.9883 .55223 Mdot
.50739 .76649 Mdot
.35445 .75919 Mdot
.68713 .77104 Mdot
.83318 .82013 Mdot
.41831 .19742 Mdot
.03196 .23466 Mdot
.93105 .66815 Mdot
.26848 .69643 Mdot
.81765 .08949 Mdot
.23813 .78796 Mdot
.28849 .83624 Mdot
.18786 .23206 Mdot
.07891 .62693 Mdot
.63938 .45898 Mdot
.75223 .65505 Mdot
.24926 .10756 Mdot
.15631 .50626 Mdot
.26292 .80538 Mdot
.69841 .89717 Mdot
.30724 .56258 Mdot
.26258 .8041 Mdot
.01075 .03241 Mdot
.30007 .84554 Mdot
.39947 .63627 Mdot
.96435 .16921 Mdot
.94745 .63899 Mdot
.59324 .97769 Mdot
.26686 .85655 Mdot
.09449 .40308 Mdot
.00053 .72899 Mdot
.21369 .22288 Mdot
.15949 .77184 Mdot
.51173 .32164 Mdot
.28167 .42143 Mdot
.33341 .35285 Mdot
.308 .57118 Mdot
.16442 .44751 Mdot
.62471 .57095 Mdot
.43028 .07248 Mdot
.39502 .65931 Mdot
.21653 .62487 Mdot
.84665 .64926 Mdot
.36619 .95672 Mdot
.19469 .79657 Mdot
.63451 .03227 Mdot
.73518 .22833 Mdot
.92523 .73588 Mdot
.55326 .71634 Mdot
.58758 .11416 Mdot
.50957 .08642 Mdot
.5655 .41117 Mdot
.04499 .56696 Mdot
.84603 .00303 Mdot
.6452 .49425 Mdot
.88557 .79978 Mdot
.85531 .93164 Mdot
.84493 .02316 Mdot
.9836 .29264 Mdot
.75397 .20048 Mdot
.35433 .61211 Mdot
.38064 .10023 Mdot
.57405 .802 Mdot
.02677 .74942 Mdot
.64087 .25882 Mdot
.01981 .80499 Mdot
.74205 .04426 Mdot
.65104 .68139 Mdot
.97485 .36769 Mdot
.56077 .16624 Mdot
.30958 .52681 Mdot
.65936 .13613 Mdot
.11876 .16984 Mdot
.02595 .09197 Mdot
.34138 .67456 Mdot
.77898 .94482 Mdot
.94486 .08875 Mdot
.46796 .72409 Mdot
.57116 .62434 Mdot
.94834 .87451 Mdot
.97301 .62997 Mdot
.7303 .67263 Mdot
.44879 .26299 Mdot
.00575 .92639 Mdot
.94978 .89025 Mdot
.0537 .78961 Mdot
.45615 .527 Mdot
.28343 .24601 Mdot
.91002 .2895 Mdot
.51249 .00412 Mdot
.61055 .12299 Mdot
.32582 .22605 Mdot
.20112 .67312 Mdot
.14334 .68604 Mdot
.70358 .73751 Mdot
.79562 .33134 Mdot
.76214 .49147 Mdot
.72681 .30494 Mdot
.99363 .55257 Mdot
.29984 .25625 Mdot
.48183 .69268 Mdot
.77064 .31308 Mdot
.18115 .41381 Mdot
.76655 .82431 Mdot
.84043 .92609 Mdot
.37177 .92859 Mdot
.98885 .06451 Mdot
.75693 .33751 Mdot
.61758 .36038 Mdot
.53088 .94526 Mdot
.72297 .43491 Mdot
.80631 .06013 Mdot
.63656 .14659 Mdot
.87456 .56463 Mdot
.33972 .16486 Mdot
.3698 .62055 Mdot
.2246 .55079 Mdot
.55034 .43922 Mdot
.98301 .68272 Mdot
.10323 .10174 Mdot
.49925 .04537 Mdot
.3198 .26325 Mdot
.45063 .33026 Mdot
.97432 .05399 Mdot
.26616 .48133 Mdot
.92934 .59663 Mdot
6e-05 .49914 Mdot
.40484 .32401 Mdot
.69399 .97812 Mdot
.53619 .95388 Mdot
.45403 .64222 Mdot
.43604 .38412 Mdot
.40007 .11566 Mdot
.34479 .44819 Mdot
.29529 .63522 Mdot
.87707 .9602 Mdot
.30959 .35288 Mdot
.02253 .62319 Mdot
.90575 .10345 Mdot
.01874 .79567 Mdot
.06886 .5565 Mdot
.82275 .31032 Mdot
.80018 .59907 Mdot
.29365 .41578 Mdot
.99898 .96476 Mdot
.80323 .42622 Mdot
.8384 .69985 Mdot
.41047 .18538 Mdot
.06025 .31708 Mdot
.99222 .80276 Mdot
.8668 .96787 Mdot
.77091 .72446 Mdot
.5826 .49991 Mdot
.3445 .07515 Mdot
.06319 .78581 Mdot
.88403 .95615 Mdot
.65515 .28333 Mdot
.86175 .56716 Mdot
.36971 .72443 Mdot
.19286 .97715 Mdot
.51751 .70509 Mdot
.01695 .70229 Mdot
.82343 .97064 Mdot
.21763 .73892 Mdot
.93726 .14641 Mdot
.47675 .42975 Mdot
.61758 .76335 Mdot
.20066 .97244 Mdot
.48823 .46602 Mdot
.94635 .86944 Mdot
.54766 .84806 Mdot
.34078 .79172 Mdot
.48632 .05434 Mdot
.81011 .84234 Mdot
.49146 .10991 Mdot
.34837 .3676 Mdot
.95619 .91814 Mdot
.93808 .03645 Mdot
.00436 .55492 Mdot
.26187 .48466 Mdot
.07707 .75731 Mdot
.16453 .76698 Mdot
.22889 .72206 Mdot
.09691 .75927 Mdot
.32325 .38887 Mdot
.07392 .55725 Mdot
.68007 .38923 Mdot
.08914 .65463 Mdot
.13348 .42395 Mdot
.23899 .82248 Mdot
.89556 .34374 Mdot
.36415 .06081 Mdot
.52802 .92806 Mdot
.03288 .88458 Mdot
.62165 .84981 Mdot
.00916 .49155 Mdot
.93135 .57025 Mdot
.61385 .01423 Mdot
.60317 .84983 Mdot
.9783 .42693 Mdot
.6944 .94854 Mdot
.90418 .91662 Mdot
.65396 .41405 Mdot
.46671 .93596 Mdot
.50388 .94808 Mdot
.18439 .5718 Mdot
.68478 .481 Mdot
.15299 .42403 Mdot
.47408 .47803 Mdot
.11064 .79205 Mdot
.27766 .53296 Mdot
.92542 .44151 Mdot
.58658 .13796 Mdot
.62464 .87625 Mdot
.26696 .3027 Mdot
.48756 .99372 Mdot
.75449 .83858 Mdot
.36271 .87417 Mdot
.03356 .21121 Mdot
.75389 .01675 Mdot
.79693 .10873 Mdot
.4932 .75777 Mdot
.2874 .66462 Mdot
.84007 .30813 Mdot
.0946 .48104 Mdot
.0923 .08683 Mdot
.19809 .43109 Mdot
.631 .6545 Mdot
.55651 .03166 Mdot
.41365 .37971 Mdot
.10133 .83204 Mdot
.9741 .9719 Mdot
.37118 .57676 Mdot
.52828 .88874 Mdot
.02285 .00677 Mdot
.61063 .49841 Mdot
.49579 .76254 Mdot
.3528 .79259 Mdot
.54663 .00321 Mdot
.98693 .12617 Mdot
.46633 .22033 Mdot
.31261 .31787 Mdot
.04692 .91519 Mdot
.10886 .94172 Mdot
.88291 .3638 Mdot
.05301 .82023 Mdot
.47933 .02347 Mdot
.08016 .65116 Mdot
.20548 .01755 Mdot
.54627 .33931 Mdot
.88186 .86301 Mdot
.90941 .64538 Mdot
.82192 .09017 Mdot
.05566 .76324 Mdot
.34809 .68605 Mdot
.05353 .35565 Mdot
.59469 .30097 Mdot
.49559 .7188 Mdot
.78211 .36098 Mdot
.01255 .26916 Mdot
.60951 .49146 Mdot
.01438 .72881 Mdot
.96819 .83726 Mdot
.12163 .49365 Mdot
.1086 .86769 Mdot
.18403 .20714 Mdot
.98168 .97241 Mdot
.86771 .30555 Mdot
.76271 .92288 Mdot
.79261 .0508 Mdot
.75769 .34638 Mdot
.12245 .9345 Mdot
.19549 .79576 Mdot
.6813 .21139 Mdot
.32372 .66683 Mdot
.16774 .84649 Mdot
.80828 .09941 Mdot
.94677 .98516 Mdot
.41373 .34836 Mdot
.74003 .06838 Mdot
.61182 .47194 Mdot
.69784 .43505 Mdot
.25526 .96684 Mdot
.35666 .31238 Mdot
.63749 .15604 Mdot
.25644 .60852 Mdot
.92978 .4834 Mdot
.62335 .57698 Mdot
.61757 .90095 Mdot
.89293 .053 Mdot
.03864 .78374 Mdot
.60475 .13093 Mdot
.22204 .22853 Mdot
.58194 .99509 Mdot
.15226 .50112 Mdot
.55395 .77312 Mdot
.71307 .45006 Mdot
.72416 .61367 Mdot
.29545 .97401 Mdot
.54512 .83332 Mdot
.61953 .13917 Mdot
.38555 .76803 Mdot
.23294 .83922 Mdot
.71295 .61484 Mdot
.30271 .75997 Mdot
.78074 .06803 Mdot
.24469 .01624 Mdot
.02896 .81827 Mdot
.60305 .8836 Mdot
.69933 .90681 Mdot
.84363 .90229 Mdot
.42452 .54076 Mdot
.27923 .81485 Mdot
.27342 .28079 Mdot
.72026 .25081 Mdot
.01417 .31181 Mdot
.71377 .8272 Mdot
.71443 .79849 Mdot
.45304 .04185 Mdot
.37712 .66646 Mdot
.86107 .60777 Mdot
.35075 .01127 Mdot
.46026 .86689 Mdot
.87959 .09082 Mdot
.06771 .13851 Mdot
.55037 .64413 Mdot
.7023 .8408 Mdot
.63866 .64171 Mdot
.73992 .55887 Mdot
.43716 .49991 Mdot
.70868 .57184 Mdot
.51145 .09976 Mdot
.71934 .79247 Mdot
.81703 .84382 Mdot
.98667 .67536 Mdot
.31432 .7101 Mdot
.53179 .38333 Mdot
.16224 .1848 Mdot
.12509 .33614 Mdot
.88094 .95414 Mdot
.96754 .14543 Mdot
.3201 .52805 Mdot
.68798 .13212 Mdot
.41899 .60046 Mdot
.12811 .97483 Mdot
.40047 .41764 Mdot
.5005 .44857 Mdot
.60096 .06079 Mdot
.68737 .24308 Mdot
.12568 .03844 Mdot
.59598 .98978 Mdot
.7242 .60072 Mdot
.82811 .99335 Mdot
.26313 .44934 Mdot
.14357 .48359 Mdot
.34808 .02512 Mdot
.60161 .44425 Mdot
.55194 .01069 Mdot
.81442 .24739 Mdot
.77635 .47685 Mdot
.18569 .68965 Mdot
.58498 .85375 Mdot
.35552 .81944 Mdot
.68104 .84763 Mdot
.90925 .18353 Mdot
.04126 .78043 Mdot
.34755 .43907 Mdot
.96192 .59832 Mdot
.22024 .10805 Mdot
.00288 .07135 Mdot
.83839 .24588 Mdot
.77539 .33162 Mdot
.04337 .53848 Mdot
.25013 .92681 Mdot
.53137 .44406 Mdot
.18261 .43913 Mdot
.02541 .4446 Mdot
.01803 .04679 Mdot
.68039 .92212 Mdot
.43422 .05109 Mdot
.55728 .99528 Mdot
.07233 .012 Mdot
.64707 .75674 Mdot
.2389 .73575 Mdot
.6251 .04705 Mdot
.52603 .13358 Mdot
.64379 .71662 Mdot
.72108 .15949 Mdot
.49718 .67783 Mdot
.74042 .60453 Mdot
.2896 .53193 Mdot
.96763 .34934 Mdot
.50108 .92074 Mdot
.36825 .85182 Mdot
.24774 .38941 Mdot
.33544 .72624 Mdot
.68211 .67501 Mdot
.98082 .8575 Mdot
.93325 .46263 Mdot
.30455 .81948 Mdot
.92649 .37142 Mdot
.44944 .68504 Mdot
.92888 .93337 Mdot
.16228 .558 Mdot
.76383 .85817 Mdot
.05685 .99531 Mdot
.23478 .43976 Mdot
.0637 .81855 Mdot
.36216 .98407 Mdot
.10381 .42078 Mdot
.84625 .30637 Mdot
.77557 .77361 Mdot
.66934 .38264 Mdot
.79289 .68204 Mdot
.05387 .45199 Mdot
.25703 .46241 Mdot
.14882 .58981 Mdot
.19346 .50199 Mdot
.87975 .5515 Mdot
.36897 .06663 Mdot
.12313 .59278 Mdot
.735 .99989 Mdot
.19965 .40952 Mdot
.31382 .909 Mdot
.83737 .87174 Mdot
.26206 .88149 Mdot
.2135 .90357 Mdot
.83946 .38958 Mdot
.47264 .05049 Mdot
.33472 .1588 Mdot
.94769 .96433 Mdot
.27097 .42216 Mdot
.32555 .92412 Mdot
.07805 .38908 Mdot
.08327 .62169 Mdot
.9641 .65956 Mdot
.14531 .0238 Mdot
.76815 .07996 Mdot
.57395 .27636 Mdot
.96258 .86785 Mdot
.38378 .93877 Mdot
.30506 .94197 Mdot
.93455 .68339 Mdot
.43622 .69331 Mdot
.18752 .08247 Mdot
.52034 .48404 Mdot
.50071 .23268 Mdot
.16744 .70145 Mdot
.96763 .55863 Mdot
.83236 .53909 Mdot
.86048 .19766 Mdot
.47618 .03221 Mdot
.45824 .8028 Mdot
.87841 .51455 Mdot
.87794 .73061 Mdot
.59375 .19541 Mdot
.25516 .84865 Mdot
.15752 .49025 Mdot
.47244 .7417 Mdot
.58624 .60336 Mdot
.53839 .5259 Mdot
.41504 .26094 Mdot
.21958 .5483 Mdot
.96263 .19242 Mdot
.72488 .22938 Mdot
.23814 .8484 Mdot
.8774 .43428 Mdot
.30855 .76018 Mdot
.50303 .78256 Mdot
.03119 .01083 Mdot
.63462 .56721 Mdot
.5801 .59104 Mdot
.72968 .91521 Mdot
.30381 .69717 Mdot
.60457 .65477 Mdot
.24849 .0813 Mdot
.98689 .73481 Mdot
.34123 .08498 Mdot
.82366 .6951 Mdot
.59407 .68751 Mdot
.17144 .86009 Mdot
.72639 .91528 Mdot
.44059 .34463 Mdot
.31162 .49692 Mdot
.55787 .09778 Mdot
.31238 .85654 Mdot
.34805 .31136 Mdot
.46026 .6885 Mdot
.89827 .7083 Mdot
.62771 .02032 Mdot
.65137 .60619 Mdot
.82467 .80019 Mdot
.51049 .55784 Mdot
.32517 .29692 Mdot
.08997 .25846 Mdot
.0483 .3559 Mdot
.08782 .36085 Mdot
.73354 .75918 Mdot
.8432 .20338 Mdot
.76539 .71555 Mdot
.28218 .31441 Mdot
.62367 .30014 Mdot
.64061 .11419 Mdot
.93746 .33956 Mdot
.66444 .56829 Mdot
.2649 .50221 Mdot
.49497 .98625 Mdot
.28202 .33988 Mdot
.56149 .73508 Mdot
.09847 .19087 Mdot
.76026 .64234 Mdot
.73458 .80254 Mdot
.54807 .09725 Mdot
.34991 .50499 Mdot
.23827 .07359 Mdot
.04463 .40607 Mdot
.09466 .55046 Mdot
.15133 .25864 Mdot
.59851 .00365 Mdot
.93753 .9737 Mdot
.83892 .29878 Mdot
.85429 .1508 Mdot
.32673 .28613 Mdot
.54267 .51586 Mdot
.20247 .76754 Mdot
.68413 .63014 Mdot
.84494 .20471 Mdot
.99167 .85004 Mdot
.74574 .66719 Mdot
.72491 .64731 Mdot
.5464 .35466 Mdot
.97727 .16078 Mdot
.85848 .05068 Mdot
.48338 .96483 Mdot
.22495 .42416 Mdot
.77266 .78455 Mdot
.42426 .35156 Mdot
.20249 .0144 Mdot
.94878 .31982 Mdot
.60245 .14459 Mdot
.83345 .82105 Mdot
.28147 .70956 Mdot
.77424 .45907 Mdot
.26339 .35894 Mdot
.36769 .45719 Mdot
.79485 .72743 Mdot
.00643 .27383 Mdot
.24196 .41738 Mdot
.7228 .39154 Mdot
.50497 .97228 Mdot
.11811 .35792 Mdot
.58208 .97848 Mdot
.07101 .07763 Mdot
.01992 .82734 Mdot
.0447 .96092 Mdot
.97595 .42625 Mdot
.65371 .90406 Mdot
.64425 .24352 Mdot
.63677 .39587 Mdot
.23621 .53843 Mdot
.14603 .99189 Mdot
.55169 .05719 Mdot
.28213 .85747 Mdot
.43909 .22125 Mdot
.58846 .03679 Mdot
.13084 .80612 Mdot
.01725 .00769 Mdot
.42817 .08453 Mdot
.59683 .79398 Mdot
.48481 .13496 Mdot
.31558 .15969 Mdot
.81466 .25548 Mdot
.66952 .11169 Mdot
.63632 .65863 Mdot
.31031 .81618 Mdot
.23737 .67383 Mdot
.69785 .38004 Mdot
.06072 .63074 Mdot
.12734 .04608 Mdot
.09186 .64873 Mdot
.51469 .81269 Mdot
.86716 .81582 Mdot
.64688 .21235 Mdot
.61697 .3413 Mdot
.95638 .10174 Mdot
.64743 .0419 Mdot
.0404 .36236 Mdot
.82004 .66255 Mdot
.13997 .21935 Mdot
.67768 .9541 Mdot
.82223 .3538 Mdot
.96415 .15093 Mdot
.35946 .7974 Mdot
.85502 .16313 Mdot
.08353 .57178 Mdot
.00525 .18557 Mdot
.80888 .48873 Mdot
.19068 .26379 Mdot
.34736 .2826 Mdot
.655 .46836 Mdot
.62756 .09186 Mdot
.01191 .75515 Mdot
.45275 .00936 Mdot
.21515 .09906 Mdot
.04598 .40585 Mdot
.62706 .75625 Mdot
.89479 .12614 Mdot
.55008 .14525 Mdot
.59188 .9353 Mdot
.90883 .5347 Mdot
.76372 .44414 Mdot
.95437 .55885 Mdot
.64261 .92894 Mdot
.50153 .90768 Mdot
.74075 .01971 Mdot
.38452 .62749 Mdot
.06447 .12682 Mdot
.67516 .17711 Mdot
.18064 .42551 Mdot
.2553 .20176 Mdot
.513 .47604 Mdot
.16977 .66982 Mdot
.41377 .61792 Mdot
.09626 .20643 Mdot
.52411 .9753 Mdot
.93674 .59258 Mdot
.77556 .24741 Mdot
.22085 .59857 Mdot
.55873 .20902 Mdot
.56208 .16292 Mdot
.63999 .40236 Mdot
.97075 .48564 Mdot
.2335 .55218 Mdot
.57544 .21654 Mdot
.20954 .45532 Mdot
.86124 .82949 Mdot
.5668 .64779 Mdot
.00464 .57168 Mdot
.5004 .00044 Mdot
.76407 .50185 Mdot
.03454 .29101 Mdot
.32427 .45461 Mdot
.30347 .43814 Mdot
.01176 .50881 Mdot
.03703 .05798 Mdot
.17801 .01956 Mdot
.44533 .76703 Mdot
.12479 .25029 Mdot
.64207 .22206 Mdot
.75221 .28711 Mdot
.8745 .49139 Mdot
.00336 .50349 Mdot
.07081 .87455 Mdot
.64924 .59726 Mdot
.67335 .97972 Mdot
.18306 .61598 Mdot
.5249 .13644 Mdot
.65225 .43459 Mdot
.00136 .75616 Mdot
.91857 .01027 Mdot
.97267 .83082 Mdot
.18121 .4486 Mdot
.74192 .98185 Mdot
.59223 .49078 Mdot
.9395 .01925 Mdot
.53289 .46788 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo0_l0000?ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool2o`0000;o
oooo0_l00009ooooo`;o00003_ooool3o`0000oooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02oooool3o`0000oo
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;o
oooo000Nooooo`03o`000?oooooooooo00?ooooo0_l00008ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`;o00001Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`06ooooo`;o00001_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00Co0000oooooooooooooooo0_l00009ooooo`;o00003_ooool3o`0000oooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?o00002oooool00ol0003o
ooooooooo`0;ooooo`?o00003oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool00_ooool001kooooo00Co0000oooooooooooooooo1?l0000booooo`;o
0000?_ooool2o`0001Gooooo0ol0001Rooooo`?o0000<Oooool2o`0001kooooo000Nooooo`04o`00
0?ooooooooooooooo`;o00000oooool2o`0000_ooooo0_l0001Iooooo`;o00001oooool2o`0001Go
oooo0ol0000Nooooo`;o0000A?ooool2o`00033ooooo0_l0000Nooooo`007_ooool00ol0003ooooo
ooooo`03ooooo`;o000000?oooooo`000?l000002oooool2o`0002Wooooo0_l0000;ooooo`?o0000
8?ooool2o`0000Oooooo0_l0000fooooo`;o00004_ooool2o`0002cooooo0_l00002ooooo`;o0000
=_ooool2o`0001Sooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0000aooooo`;o00001_oo
ool3o`0000[ooooo0ol0000fooooo`;o0000?Oooool2o`0002Sooooo0_l00002ooooo`;o0000>_oo
ool2o`0001Sooooo000Nooooo`03o`000?oooooooooo03Kooooo0_l00007ooooo`;o0000@oooool2
o`0004;ooooo0_l0000Sooooo`;o0000?_ooool2o`0001Sooooo000Nooooo`03o`000?oooooooooo
02_ooooo0_l00010ooooo`;o0000:Oooool2o`0002kooooo1?l00013ooooo`;o0000=_ooool001ko
oooo00?o0000ooooooooool0:oooool2o`00043ooooo0_l0000Yooooo`;o0000<?ooool2o`0004?o
oooo0_l0000fooooo`007_ooool00ol0003oooooooooo`2aooooo`;o00008?ooool2o`0007;ooooo
000Nooooo`04o`000?oooooo0000o`0009Kooooo0_l0000<ooooo`;o00002_ooool2o`0000Cooooo
0_l0000Aooooo`;o00001oooool2o`0006Gooooo0_l0000;ooooo`007_ooool01?l0003oooooo`00
0?l0002Fooooo`;o00003?ooool2o`00013ooooo0_l00002ooooo`;o00003Oooool2o`00067ooooo
0_l0000;ooooo`;o00002oooool001kooooo00?o0000ooooooooool09Oooool2o`0009Cooooo0_l0
0012ooooo`;o0000;?ooool2o`0001Sooooo000Nooooo`03o`000?oooooooooo02Gooooo0_l0001X
ooooo`;o0000?Oooool2o`0001gooooo0_l0000@ooooo`;o0000A_ooool001kooooo00?o0000oooo
ooooool00_ooool2o`00027ooooo0_l0001Xooooo`;o00003Oooool2o`0001cooooo0_l00009oooo
o`;o00001Oooool2o`0000kooooo0_l0000=ooooo`;o00008oooool2o`0003?ooooo000Nooooo`03
o`000?oooooooooo00;ooooo0_l0000Qooooo`;o0000Koooool2o`0000Kooooo0_l0000Looooo`;o
00002Oooool2o`0001Gooooo0_l00009ooooo`;o00009oooool2o`0003?ooooo000Nooooo`;o0000
L_ooool2o`0001Kooooo0_l0000;ooooo`;o00005Oooool2o`0003[ooooo0_l0000Cooooo`;o0000
4oooool2o`0000Wooooo0_l0000Looooo`;o00002Oooool001kooooo00?o0000ooooooooool0LOoo
ool2o`0001Kooooo0_l0000?ooooo`;o00004Oooool2o`0004oooooo0_l0000Cooooo`;o00002Ooo
ool2o`0001Wooooo0_l000000ooooooo0000o`000009ooooo`007_ooool00ol0003oooooooooo`08
ooooo`;o0000T?ooool2o`0001?ooooo0_l00028ooooo`;o00003?ooool001kooooo00?o0000oooo
ooooool02?ooool2o`0006Sooooo0_l0000kooooo`;o00003_ooool2o`0002oooooo0_l0000@oooo
o`;o0000@oooool001kooooo00?o0000ooooooooool0L_ooool2o`0003;ooooo0_l0000Gooooo`;o
0000;oooool2o`00013ooooo0_l0000;ooooo`;o0000;?ooool2o`0000Sooooo000Nooooo`03o`00
0?oooooooooo00oooooo0_l0001Sooooo`;o0000<?ooool2o`0004Cooooo0_l0000<ooooo`;o0000
4oooool2o`0002cooooo0_l00008ooooo`007_ooool2o`00013ooooo0_l0000hooooo`;o0000:Ooo
ool2o`0007Kooooo0_l0000<ooooo`;o0000Boooool001kooooo0_l0001:ooooo`;o00008Oooool2
o`0001[ooooo0_l0002mooooo`007_ooool00ol0003oooooooooo`0Cooooo`;o00005oooool2o`00
01_ooooo0_l0000Qooooo`;o00006?ooool4o`000;gooooo000Nooooo`03o`000?oooooooooo01?o
oooo0_l0000Gooooo`;o00007oooool2o`0003Oooooo0_l0001^ooooo`;o0000Coooool001kooooo
00?o0000ooooooooool0>Oooool2o`0001;ooooo0_l0000Booooo`;o00006_ooool2o`0006Oooooo
0_l0000>ooooo`;o0000Coooool001kooooo00?o0000ooooooooool06_ooool2o`0001gooooo0_l0
000Vooooo`;o00002?ooool2o`00013ooooo0_l00008ooooo`;o00006Oooool2o`0000gooooo0_l0
000cooooo`;o0000Goooool001kooooo00?o0000ooooooooool06_ooool2o`0004oooooo0_l0000J
ooooo`;o00006Oooool2o`0000gooooo0_l0001Cooooo`?o00009_ooool2o`0001Kooooo000Noooo
o`03o`000?oooooooooo00Cooooo0_l00032ooooo`;o0000??ooool3o`00017ooooo0_l0000Coooo
o`;o00005_ooool001kooooo00?o0000ooooooooool01?ooool2o`000<;ooooo0_l0001@ooooo`;o
0000:oooool001kooooo00?o0000ooooooooool0@_ooool2o`0005kooooo0_l0000:ooooo`;o0000
00?oooooo`000?l00000D?ooool2o`0004;ooooo000Nooooo`;o00007_ooool2o`0002?ooooo0_l0
000dooooo`;o00007oooool2o`0000Oooooo0_l0000:ooooo`;o000000?oooooo`000?l00000D?oo
ool2o`0002kooooo0_l0000Booooo`007_ooool00ol0003oooooooooo`0Mooooo`;o0000FOooool2
o`0001oooooo0_l00011ooooo`;o0000A?ooool2o`0000oooooo0_l0000Booooo`007_ooool00ol0
003oooooooooo`13ooooo`;o00002?ooool2o`0004_ooooo0_l00010ooooo`;o00008Oooool2o`00
027ooooo0_l0000Sooooo`007_ooool00ol0003oooooooooo`13ooooo`;o00002?ooool2o`0004_o
oooo1?l0000hooooo`;o00009oooool2o`0002cooooo0_l0000Hooooo`007_ooool00ol0003ooooo
ooooo`2Looooo`;o00007Oooool2o`0000oooooo0_l00008ooooo`;o0000EOooool2o`000003oooo
ool0003o000001Gooooo000Nooooo`03o`000?oooooooooo06Cooooo0_l0000Hooooo`;o0000>ooo
ool2o`0000oooooo0_l0001Rooooo`;o00005Oooool001kooooo00?o0000ooooooooool0I?ooool2
o`0001Sooooo0_l0002Vooooo`;o00007oooool001kooooo00?o0000ooooooooool0`_ooool2o`00
06;ooooo0_l0000Oooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o0000<?ooool2o`0007go
oooo0_l0001Kooooo`;o00007?ooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo017ooooo
0_l0000`ooooo`;o0000f_ooool2o`0001cooooo0_l00008ooooo`007_ooool00ol0003ooooooooo
o`0Aooooo`;o0000U?ooool2o`0001Oooooo0_l0000Jooooo`;o0000JOooool001kooooo00?o0000
ooooooooool04Oooool2o`0008Oooooo0_l0000;ooooo`;o00005oooool2o`00013ooooo0_l00008
ooooo`;o0000JOooool001kooooo00?o0000ooooooooool01_ooool2o`0000[ooooo0_l00026oooo
o`;o00002oooool2o`0001;ooooo0_l00008ooooo`;o00002oooool2o`0001Wooooo0_l0000Roooo
o`;o0000=?ooool001kooooo00?o0000ooooooooool01_ooool2o`0000[ooooo0_l0000[ooooo`;o
0000N_ooool2o`0000Sooooo0_l0000Vooooo`;o00008_ooool2o`0003Cooooo000Nooooo`03o`00
0?oooooooooo03oooooo0ol0001Booooo`;o00006Oooool2o`0000oooooo0_l0000Yooooo`;o0000
BOooool2o`0000oooooo000Nooooo`03o`000?oooooooooo00Gooooo0_l0000iooooo`;o0000D_oo
ool2o`0001Wooooo0_l0000?ooooo`;o00002Oooool2o`0001kooooo0_l00010ooooo`;o00001ooo
ool2o`0000oooooo000Nooooo`;o00001_ooool2o`0008Sooooo0_l0000jooooo`;o0000AOooool2
o`0001Wooooo0_l00006ooooo`;o00004?ooool001kooooo00?o0000ooooooooool0=Oooool2o`00
05Sooooo0_l0001Nooooo`;o00008Oooool2o`0000Kooooo0_l0000Iooooo`;o00004?ooool001ko
oooo00?o0000ooooooooool0=Oooool2o`0009Cooooo0_l0000Rooooo`;o0000:Oooool2o`0002_o
oooo000Nooooo`03o`000?oooooooooo06;ooooo0_l00005ooooo`;o0000H?ooool2o`0001Wooooo
0_l0000]ooooo`;o00008oooool2o`0000_ooooo000Nooooo`03o`000?oooooooooo06;ooooo0_l0
0005ooooo`;o0000B?ooool2o`00037ooooo0_l0000Zooooo`;o000000?oooooo`000?l000008ooo
ool2o`0000_ooooo000Nooooo`03o`000?oooooooooo06[ooooo0_l00016ooooo`?o0000GOooool2
o`0003?ooooo000Nooooo`03o`000?oooooooooo01[ooooo0_l00006ooooo`;o0000A_ooool2o`00
04Kooooo0_l00021ooooo`;o00004?ooool001kooooo00?o0000ooooooooool06_ooool2o`0000Ko
oooo0_l0002Looooo`;o0000?_ooool2o`0003?ooooo0_l0000@ooooo`007_ooool00ol0003ooooo
ooooo`30ooooo`;o0000?_ooool2o`0004Gooooo000Nooooo`03o`000?oooooooooo06Cooooo0_l0
001@ooooo`;o00007oooool2o`0006kooooo000Nooooo`03o`000?oooooooooo06Cooooo0_l0001@
ooooo`;o00007oooool2o`0006kooooo000Nooooo`?o0000<Oooool2o`0004Gooooo0_l00007oooo
o`;o0000X?ooool2o`0002;ooooo000Nooooo`?o0000<Oooool2o`0004Gooooo0_l00007ooooo`;o
0000X?ooool2o`0002;ooooo000Nooooo`03o`000?oooooooooo01cooooo0_l0003oooooob[ooooo
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`00
0?oooooooooo01cooooo0_l0002Xooooo`;o0000KOooool2o`00013ooooo0003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03
o`000?oooooooooo08Cooooo0_l0000=ooooo`;o0000:?ooool2o`0000Oooooo0_l0001<ooooo`;o
00007oooool2o`00013ooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000Q?ooool2o`0000gooooo0_l0000Xooooo`;o0000<_ooool2o`00027o
oooo0_l0000aooooo`000oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^
k^h01_ooool00ol0003oooooooooo`1?ooooo`;o00005_ooool2o`0008Sooooo0_l0000?ooooo`;o
00002_ooool2o`0003Oooooo0003ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOo
IVIVooooo`05ooooo`03o`000?oooooooooo01_ooooo0_l0000Kooooo`;o00005Oooool2o`0001Ko
oooo0_l0000Rooooo`;o0000MOooool2o`0000[ooooo0ol0000fooooo`000oooool01Ol@413ooooo
oooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Kooooo`;o
00006oooool2o`00057ooooo0_l0000Uooooo`;o0000A_ooool2o`0001?ooooo0_l0000fooooo`00
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006oooo
o`03o`000?oooooooooo00Oooooo0_l0002Yooooo`;o00006_ooool2o`0000Wooooo0_l0000Ooooo
o`;o0000Boooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`07ooooo`;o0000M_ooool2o`0003Kooooo0_l0000E
ooooo`;o00002Oooool2o`0006cooooo000Nooooo`03o`000?oooooooooo02Wooooo0_l0001Doooo
o`;o0000=_ooool2o`0007Oooooo0_l0000Eooooo`007_ooool00ol0003oooooooooo`0Yooooo`;o
00005_ooool2o`0004Sooooo0_l00006ooooo`;o0000>?ooool2o`0001Oooooo0_l00018ooooo`;o
00005Oooool001kooooo00?o0000ooooooooool0@Oooool2o`0002Cooooo0_l0000Rooooo`;o0000
1_ooool2o`0003Sooooo0_l0000Gooooo`;o0000Goooool001kooooo00?o0000ooooooooool0A?oo
ool2o`00023ooooo0ol00022ooooo`;o0000<Oooool2o`0002Oooooo000Nooooo`03o`000?oooooo
oooo03Wooooo0_l00009ooooo`;o00004?ooool2o`0000kooooo0_l0000mooooo`;o0000@Oooool2
o`000003ooooool0003o0000037ooooo0_l0000Wooooo`007_ooool00ol0003oooooooooo`06oooo
o`;o0000<Oooool2o`0001_ooooo0_l00017ooooo`;o00001?ooool2o`00047ooooo0_l0001Moooo
o`007_ooool00ol0003oooooooooo`06ooooo`;o00000_ooool2o`0009?ooooo0_l00005ooooo`;o
00008?ooool2o`0004_ooooo0_l00004ooooo`;o0000:_ooool001kooooo00?o0000ooooooooool0
2?ooool4o`0009[ooooo0_l0000Pooooo`;o00007?ooool2o`0002gooooo0_l00004ooooo`;o0000
:_ooool001kooooo00?o0000ooooooooool02?ooool2o`000<?ooooo0_l0000<ooooo`;o00002Ooo
ool2o`0005oooooo000Nooooo`03o`000?oooooooooo05Sooooo0_l0001Nooooo`;o00004oooool2
o`0000cooooo0_l0000Kooooo`;o00002oooool2o`0000Gooooo0_l0000iooooo`007_ooool00ol0
003oooooooooo`0Gooooo`;o00002oooool2o`0003;ooooo0_l0001Nooooo`;o0000?_ooool2o`00
00_ooooo0_l00005ooooo`;o0000>Oooool001kooooo0_l0000Hooooo`;o00002oooool2o`000<3o
oooo0_l0000fooooo`;o00009oooool001kooooo00?o0000ooooooooool0GOooool2o`0008Oooooo
0_l0000Mooooo`;o00005oooool2o`0002Oooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l0
000Booooo`;o0000;_ooool2o`0006gooooo0_l0000=ooooo`;o0000:?ooool2o`00043ooooo000N
ooooo`03o`000?oooooooooo01Wooooo0_l0000Booooo`;o0000E?ooool2o`00033ooooo0_l0000E
ooooo`;o00003Oooool2o`0006[ooooo000Nooooo`03o`000?oooooooooo03[ooooo0_l0000Xoooo
o`;o00007Oooool2o`0000Wooooo0_l0000Uooooo`;o00006_ooool2o`0007Cooooo000Nooooo`03
o`000?oooooooooo03[ooooo0_l0000Xooooo`;o0000:?ooool2o`0001kooooo0_l0000Qooooo`;o
0000M?ooool001kooooo00?o0000ooooooooool00_l0001dooooo`;o0000=_ooool2o`0009Oooooo
000Nooooo`Go0000M?ooool2o`000<oooooo000Nooooo`?o0000]_ooool2o`0008oooooo000Noooo
o`03o`000?oooooooooo05Gooooo0_l0001Oooooo`;o0000Soooool001kooooo00?o0000oooooooo
ool0EOooool2o`0001Kooooo0_l0000Booooo`;o0000C_ooool2o`0007Cooooo000Nooooo`03o`00
0?oooooooooo06Kooooo0_l00005ooooo`;o00004_ooool2o`0004kooooo0_l0000Mooooo`;o0000
3?ooool2o`0004Oooooo000Nooooo`;o0000Ioooool2o`0002cooooo0_l0001@ooooo`;o00002?oo
ool2o`0000cooooo0_l0000Tooooo`;o00003_ooool2o`00017ooooo000Nooooo`;o00002?ooool2
o`0008_ooooo0_l0001@ooooo`;o0000??ooool2o`0000kooooo0_l00006ooooo`;o00002Oooool0
01kooooo00?o0000ooooooooool01oooool2o`0003kooooo0_l0000Hooooo`;o0000H?ooool2o`00
017ooooo0_l00002ooooo`;o00009Oooool2o`0003Wooooo0_l00009ooooo`007_ooool00ol0003o
ooooooooo`0`ooooo`;o00005Oooool2o`0001Sooooo0_l00003ooooo`;o00008Oooool2o`0003So
oooo0_l0000Aooooo`;o00000_ooool2o`0002Gooooo0_l0000:ooooo`;o00003?ooool2o`0002[o
oooo000Nooooo`;o0000<Oooool2o`00027ooooo0_l0000Aooooo`;o00008Oooool2o`0003;ooooo
0_l00008ooooo`;o00007Oooool2o`0002Gooooo0_l0000<ooooo`;o0000:_ooool001kooooo00?o
0000ooooooooool0Doooool2o`0006Sooooo0_l00008ooooo`;o00007Oooool4o`0002cooooo0_l0
000_ooooo`007_ooool00ol0003oooooooooo`3Xooooo`;o00008oooool4o`0000Gooooo0_l0000_
ooooo`007_ooool00ol0003oooooooooo`02o`0006_ooooo0_l0002Hooooo`;o00001?ooool4o`00
03Kooooo000Nooooo`03o`000?oooooooooo00;o00008?ooool2o`0003Cooooo0_l0000Cooooo`;o
000000?oooooo`000?l00000F?ooool2o`0002[ooooo0_l0000?ooooo`;o0000?_ooool001kooooo
00?o0000ooooooooool03oooool2o`00017ooooo0_l0000Vooooo`;o00003?ooool2o`0000Sooooo
0_l0000<ooooo`;o0000F?ooool2o`0002[ooooo0_l0001?ooooo`007_ooool00ol0003ooooooooo
o`0?ooooo`;o0000>Oooool2o`0001Kooooo0_l0002Hooooo`;o0000<_ooool2o`0001Gooooo000N
ooooo`03o`000?oooooooooo083ooooo0_l0000Pooooo`;o0000COooool2o`0000Wooooo0_l0000b
ooooo`;o00005Oooool001kooooo00?o0000ooooooooool0P?ooool2o`00023ooooo0_l0000Boooo
o`;o0000>Oooool2o`0002Gooooo0_l0000]ooooo`007Oooool2o`00093ooooo0_l0000Vooooo`;o
0000H?ooool2o`0002gooooo000Mooooo`;o0000T?ooool2o`0006Sooooo0_l00005ooooo`;o0000
A_ooool001kooooo00?o0000ooooooooool09Oooool2o`000=7ooooo0ol00004ooooo`;o0000A_oo
ool001kooooo00?o0000ooooooooool09Oooool2o`0004cooooo0_l0000>ooooo`;o0000:?ooool2
o`0004?ooooo0_l00005ooooo`;o0000<_ooool2o`0001Sooooo000Nooooo`03o`000?oooooooooo
05Sooooo0_l0000Iooooo`;o00003_ooool2o`0002Sooooo0_l0000Eooooo`;o0000;?ooool2o`00
03Wooooo0_l0000Hooooo`007_ooool00ol0003oooooooooo`1Hooooo`;o00004?ooool2o`0001oo
oooo0_l0000gooooo`;o0000FOooool2o`0002Kooooo000Nooooo`03o`000?oooooooooo04cooooo
0_l0000Looooo`;o00005_ooool2o`0000Oooooo0_l0001Uooooo`;o0000:oooool2o`0002Kooooo
000Nooooo`;o0000?_ooool2o`0000gooooo0_l0000dooooo`;o00000_ooool2o`0001[ooooo0_l0
001>ooooo`;o0000@_ooool2o`0000oooooo000Nooooo`03o`000?oooooooooo03gooooo0_l0000R
ooooo`;o00001Oooool2o`0001cooooo0_l0000Jooooo`;o00002_ooool2o`0005Oooooo0_l0000]
ooooo`;o00003oooool001kooooo00?o0000ooooooooool03?ooool3o`0001?ooooo0_l0000moooo
o`;o00001Oooool2o`0004Cooooo0_l0001Gooooo`;o0000<_ooool2o`0000[ooooo000Nooooo`04
o`000?oooooo0000o`0000_ooooo0ol00009ooooo`;o000000?oooooo`000?l000001Oooool2o`00
02kooooo0_l0000;ooooo`;o00008_ooool2o`00043ooooo0_l0000cooooo`;o0000?oooool2o`00
00[ooooo000Nooooo`04o`000?oooooo0000o`0000Sooooo0_l0000=ooooo`;o000000?oooooo`00
0?l00000=Oooool2o`0000_ooooo0_l0000Rooooo`;o0000@?ooool2o`0003?ooooo0_l0000Ooooo
o`;o0000:_ooool001kooooo00?o0000ooooooooool02Oooool2o`000?oooooo4Oooool2o`0002[o
oooo000Nooooo`03o`000?oooooooooo06gooooo0_l0003:ooooo`;o00003?ooool001kooooo00?o
0000ooooooooool0KOooool2o`000;[ooooo0_l0000>ooooo`;o00003?ooool001kooooo00?o0000
ooooooooool0WOooool2o`0002Wooooo0_l0001Oooooo`;o00007?ooool001kooooo00?o0000oooo
ooooool0P_ooool2o`0001Wooooo0_l0000Yooooo`;o0000OOooool001kooooo00?o0000oooooooo
ool0P_ooool2o`0000_ooooo0_l00014ooooo`;o00002?ooool2o`0004Oooooo0_l0000Mooooo`00
7_ooool00ol0003oooooooooo`2:ooooo`;o00000oooool2o`0001Sooooo0_l0000Zooooo`;o0000
2?ooool2o`0004Oooooo0_l0000Mooooo`007_ooool00ol0003oooooooooo`1Uooooo`;o00008ooo
ool2o`0000cooooo0_l00008ooooo`;o00001Oooool2o`0009cooooo000Nooooo`03o`000?oooooo
oooo01Gooooo0_l0000eooooo`;o00005oooool2o`00037ooooo0_l00008ooooo`;o0000=Oooool2
o`0000cooooo0_l0000Tooooo`;o0000>?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool05Oooool2
o`0000Oooooo0_l0000/ooooo`;o0000Roooool2o`0000cooooo0_l0000Tooooo`;o0000>?ooool0
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01kooooo0_l0002[ooooo`;o0000N_ooool000?ooooo00Go410@oooo
oooooooooooooa0@400;ooooo`Go00001_ooool3o`000<_ooooo0_l0001jooooo`000oooool01Ol0
003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool00ol0003ooooooooo
o`0Kooooo`;o0000=oooool2o`0007Kooooo0_l0001iooooo`000oooool01Ol0003ooooooooooooo
oooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`0:ooooo`?o0000
3_ooool2o`0003Oooooo0_l0000@ooooo`;o0000@Oooool2o`00027ooooo0_l0001iooooo`000ooo
ool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003ooooo
ooooo`0:ooooo`?o0000<?ooool2o`0002Oooooo0_l00011ooooo`;o0000W?ooool000?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0
?Oooool2o`0007Gooooo0_l0002Aooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo
00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`0gooooo`;o00008_ooool2o`0005Oooooo
0_l0000Jooooo`;o0000@?ooool2o`0002;ooooo0_l0000?ooooo`007_ooool00ol0003ooooooooo
o`0gooooo`;o00004_ooool2o`0000kooooo0_l0000Qooooo`;o00007?ooool2o`0001cooooo0_l0
000Dooooo`;o0000@?ooool2o`0002;ooooo0_l0000?ooooo`007_ooool00ol0003oooooooooo`0N
ooooo`;o0000:oooool2o`0000Oooooo0_l000000ooooooo0000o`00000Uooooo`;o00007?ooool2
o`0001cooooo0_l0000Xooooo`;o0000F?ooool2o`0000Oooooo000Nooooo`03o`000?oooooooooo
01kooooo0_l00007ooooo`;o00001Oooool2o`0000Oooooo0_l0000<ooooo`;o00003Oooool2o`00
0003ooooool0003o000008_ooooo0_l0001Hooooo`;o00001oooool001kooooo00?o0000oooooooo
ool09oooool2o`0000Gooooo0_l00007ooooo`;o00003?ooool2o`000;[ooooo0_l0000fooooo`?o
00002oooool001kooooo00?o0000ooooooooool0??ooool2o`0005Wooooo0_l0000;ooooo`;o0000
Foooool2o`0003Kooooo0ol0000;ooooo`007_ooool00ol0003oooooooooo`0looooo`;o0000FOoo
ool2o`0000_ooooo0_l0000Zooooo`;o00003Oooool2o`0000Kooooo0_l0000`ooooo`;o0000;?oo
ool001kooooo00?o0000ooooooooool0Goooool2o`0006oooooo0_l0000=ooooo`;o00001_ooool2
o`00033ooooo0_l0000/ooooo`007_ooool00ol0003oooooooooo`0cooooo`;o00000_ooool2o`00
00oooooo0_l0000Eooooo`;o00003?ooool2o`00043ooooo0_l0002Fooooo`007_ooool00ol0003o
ooooooooo`0cooooo`;o00000_ooool2o`0000oooooo0_l0000Sooooo`;o0000>_ooool2o`0000Co
oooo0_l00003ooooo`;o00002Oooool2o`0003?ooooo0_l0000cooooo`;o00007?ooool001kooooo
00?o0000ooooooooool01?ooool2o`000:?ooooo0_l00009ooooo`;o00002Oooool2o`0003?ooooo
0_l0000cooooo`;o00007?ooool001kooooo00?o0000ooooooooool01?ooool2o`0002_ooooo0_l0
0004ooooo`;o00006?ooool2o`0001Wooooo0_l0000aooooo`;o0000@oooool2o`00067ooooo000N
ooooo`;o00003_ooool2o`0002;ooooo0_l00004ooooo`;o00006?ooool2o`0001Wooooo0_l0000a
ooooo`;o0000@oooool2o`00067ooooo000Nooooo`03o`000?oooooooooo00gooooo0_l0000aoooo
o`;o00008oooool2o`000>3ooooo000Nooooo`03o`000?oooooooooo043ooooo0_l0000Sooooo`;o
00003?ooool2o`0005Oooooo0_l0000Zooooo`;o0000COooool001kooooo00?o0000ooooooooool0
Coooool2o`0002;ooooo0_l0000Xooooo`;o0000;Oooool2o`0000Kooooo0_l0000Rooooo`;o0000
<Oooool2o`0001[ooooo000Nooooo`03o`000?oooooooooo04oooooo0_l0001<ooooo`;o0000=Ooo
ool2o`0005Gooooo0_l0000Jooooo`007_ooool3o`0006Oooooo0_l0000booooo`;o00003?ooool2
o`0002Kooooo0_l0001dooooo`007_ooool3o`0006Oooooo0_l0000booooo`;o00003?ooool2o`00
01Sooooo0_l0000<ooooo`;o0000M?ooool001kooooo00?o0000ooooooooool0Ioooool2o`0005[o
oooo0_l00022ooooo`007_ooool00ol0003oooooooooo`1Wooooo`;o0000;Oooool2o`0000_ooooo
0_l0000:ooooo`;o0000Aoooool2o`0004gooooo000Nooooo`03o`000?oooooooooo01_ooooo0_l0
001[ooooo`;o00003?ooool2o`0000_ooooo0_l0000:ooooo`;o0000:_ooool2o`0001_ooooo0_l0
000]ooooo`;o00007_ooool001kooooo00?o0000ooooooooool06oooool2o`0000kooooo0_l0000U
ooooo`;o0000=?ooool2o`0001_ooooo0_l0000dooooo`;o0000B_ooool2o`000003ooooool0003o
000001_ooooo000Nooooo`?o0000:oooool2o`0002Cooooo0ol0001Aooooo`;o0000Poooool2o`00
00_ooooo0_l0000>ooooo`007_ooool3o`0002oooooo0_l0000Pooooo`;o0000/?ooool2o`0003;o
oooo0_l0000>ooooo`007_ooool01?l0003oooooo`000?l0000^ooooo`;o0000Joooool2o`0001ko
oooo0_l00004ooooo`;o00006oooool2o`0001?ooooo0_l0000=ooooo`;o00004oooool2o`0002go
oooo000Nooooo`04o`000?oooooo0000o`0002;ooooo0_l0001gooooo`;o00007_ooool2o`0000Co
oooo0_l0000:ooooo`;o00003oooool2o`0001?ooooo0_l0000Rooooo`;o0000;Oooool001gooooo
0_l0000Uooooo`;o0000??ooool2o`0000kooooo0_l0000Fooooo`;o0000=oooool2o`0000[ooooo
0_l0001gooooo`007Oooool3o`0002kooooo0_l0000<ooooo`;o00005Oooool2o`0000gooooo0_l0
000:ooooo`;o00000_ooool2o`0001Kooooo0ol0000]ooooo`;o00001oooool2o`00033ooooo0_l0
001Aooooo`007_ooool2o`0002kooooo0_l0000<ooooo`;o00005Oooool2o`0001Wooooo0ol0000J
ooooo`;o0000;Oooool2o`0003Wooooo0_l0000_ooooo`;o00008?ooool001kooooo0_l000000ooo
oooo0000o`00000]ooooo`;o0000?Oooool2o`0009_ooooo0_l0000Hooooo`;o00008?ooool001ko
oooo00?o0000ooooooooool00_l0000]ooooo`;o0000XOooool2o`0003Oooooo0_l0000jooooo`00
7_ooool00ol0003oooooooooo`2Cooooo`;o0000>Oooool2o`0000;ooooo0_l00015ooooo`;o0000
;?ooool001kooooo00?o0000ooooooooool0Toooool2o`0001Oooooo0_l0000Pooooo`;o00004Ooo
ool4o`0003Cooooo0_l0000/ooooo`007_ooool00ol0003oooooooooo`2/ooooo`;o0000<oooool4
o`0006;ooooo000Nooooo`03o`000?oooooooooo043ooooo0_l0003oooooo`Kooooo000Nooooo`03
o`000?oooooooooo043ooooo0_l0000Oooooo`;o0000;Oooool2o`0001Wooooo0_l0000Cooooo`;o
0000QOooool001kooooo00?o0000ooooooooool0HOooool2o`000003ooooool0003o000002[ooooo
0_l0000Iooooo`;o00004oooool2o`0008Gooooo000Nooooo`03o`000?oooooooooo05Kooooo0_l0
0002ooooo`;o00002?ooool2o`0004oooooo0_l0002@ooooo`007_ooool00ol0003oooooooooo`0_
ooooo`;o00003?ooool2o`0001Oooooo0_l00002ooooo`;o0000COooool2o`0000[ooooo0_l0001/
ooooo`;o00008_ooool001kooooo00?o0000ooooooooool02_ooool2o`0002?ooooo0_l0000<oooo
o`;o00002_ooool2o`0005kooooo0_l0001Oooooo`;o00005oooool2o`0002;ooooo000Nooooo`03
o`000?oooooooooo00[ooooo0_l0000/ooooo`;o00003oooool2o`0003_ooooo0_l00022ooooo`;o
0000>oooool001kooooo00?o0000ooooooooool0>?ooool2o`0004cooooo0_l0002Dooooo`;o0000
:Oooool001kooooo00?o0000ooooooooool09Oooool2o`0001cooooo0_l0003Gooooo`;o0000:Ooo
ool001kooooo0_l0000Looooo`;o00002?ooool2o`0001cooooo1?l0003Aooooo`Co00003Oooool2
o`0000oooooo0_l0000;ooooo`007_ooool2o`0001cooooo0_l0000Xooooo`;o000000?oooooo`00
0?l00000:?ooool2o`0006Kooooo0_l0000looooo`Co00002oooool4o`0000oooooo0_l000000ooo
oooo0000o`000002o`0000Kooooo000Nooooo`;o00004oooool4o`0001_ooooo0_l0000Eooooo`;o
0000:?ooool2o`0002kooooo0_l0000<ooooo`;o00002_ooool2o`0001cooooo0_l0001;ooooo`;o
00005?ooool4o`0000Kooooo000Nooooo`03o`000?oooooooooo01;ooooo1?l0000Kooooo`;o0000
Koooool2o`0000cooooo0_l0000:ooooo`;o00008oooool2o`0000Wooooo0_l00014ooooo`;o0000
0_ooool2o`0000oooooo000Nooooo`03o`000?oooooooooo063ooooo0_l0001oooooo`;o00002Ooo
ool2o`0004Cooooo0_l00002ooooo`;o00003oooool001kooooo00?o0000ooooooooool02oooool2
o`0005?ooooo0_l0001Xooooo`;o0000B?ooool2o`0000;ooooo0_l0000]ooooo`007_ooool00ol0
003oooooooooo`0;ooooo`;o0000_Oooool2o`0000Sooooo0_l0000nooooo`;o00000_ooool2o`00
017ooooo0_l0000Jooooo`007_ooool2o`0001Sooooo0_l0000Oooooo`;o00009_ooool2o`0002_o
oooo0_l0000hooooo`;o00002oooool2o`0000cooooo0_l00017ooooo`?o00006Oooool001kooooo
0_l0000Hooooo`;o00007oooool2o`0002Kooooo0_l0000[ooooo`;o0000>?ooool2o`0001Wooooo
0_l00018ooooo`;o00006Oooool001kooooo00?o0000ooooooooool0MOooool2o`00053ooooo0_l0
001_ooooo`;o00003Oooool001kooooo00?o0000ooooooooool0MOooool2o`00053ooooo0_l0001_
ooooo`;o00003Oooool001kooooo00?o0000ooooooooool0B_ooool2o`00097ooooo0_l0001Xoooo
o`007_ooool00ol0003oooooooooo`1:ooooo`;o0000TOooool2o`0006Sooooo000Nooooo`03o`00
0?oooooooooo02cooooo0_l0002:ooooo`;o0000SOooool000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000oooooooo
ool09?ooool2o`0000Kooooo0_l0002:ooooo`;o0000L_ooool2o`0000Kooooo0_l0000Aooooo`00
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRH
V?lQ8B401_ooool00ol0003oooooooooo`0Tooooo`;o0000ZOooool2o`0005Wooooo1?l00006oooo
o`;o00004Oooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooo
ooooool000001_ooool3o`0004Cooooo0_l0000nooooo`;o0000BOooool2o`0001Kooooo0_l0000G
ooooo`;o00008Oooool2o`0000Gooooo0_l00009ooooo`;o00004?ooool000?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool00ol0003ooooooooo
o`14ooooo`;o0000<?ooool2o`0000cooooo0_l0000dooooo`;o0000:oooool2o`0001Oooooo0_l0
000Qooooo`;o00004?ooool2o`00013ooooo0003ooooo`05o`000?ooooooooooooooool000002ooo
ool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0M_ooool2o`0004;ooooo
0_l0000Dooooo`;o00006oooool2o`0005Sooooo0003ooooo`05oa0@4?ooooooooooooooool@4100
2oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo04oooooo0_l00005ooooo`;o0000
N?ooool2o`0001_ooooo0_l0000Uooooo`;o0000<Oooool000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0;Oooool2o`00023ooooo
0_l00005ooooo`;o00005oooool2o`0008Kooooo0_l0000Kooooo`;o0000<Oooool000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000oooooooo
ool0;Oooool2o`0000Sooooo0_l0000fooooo`;o0000Loooool2o`000003ooooool0003o000000ko
oooo0_l0000Oooooo`;o0000;Oooool001kooooo00?o0000ooooooooool0=oooool2o`0004Wooooo
0_l0001Pooooo`;o000000?oooooo`000?l00000;oooool2o`00023ooooo1?l00009ooooo`007_oo
ool00ol0003oooooooooo`0Gooooo`;o0000Foooool2o`0000cooooo0_l0002fooooo`Co00002Ooo
ool001kooooo00?o0000ooooooooool00oooool2o`0001;ooooo0_l0000Yooooo`;o0000<?ooool2
o`00043ooooo0_l00025ooooo`;o00002?ooool001kooooo00?o0000ooooooooool00oooool2o`00
017ooooo0_l0000Zooooo`Co0000<oooool2o`0003_ooooo0_l00025ooooo`;o00002?ooool001ko
oooo00?o0000ooooooooool04?ooool2o`0000Cooooo0_l0000>ooooo`;o00007?ooool2o`0002Oo
oooo0_l0000:ooooo`;o0000D?ooool2o`0000gooooo0_l0001Looooo`;o00003Oooool001kooooo
00?o0000ooooooooool04?ooool2o`0001Cooooo0_l00015ooooo`;o0000G?ooool2o`0000gooooo
0_l0001Looooo`;o00003Oooool001kooooo00?o0000ooooooooool0G?ooool2o`00023ooooo0_l0
0037ooooo`007_ooool00ol0003oooooooooo`1Looooo`;o00008?ooool2o`000;3ooooo0_l0000E
ooooo`007_ooool00ol0003oooooooooo`2?ooooo`;o00007_ooool2o`0001_ooooo0_l0000Uoooo
o`;o0000>oooool2o`0000[ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`2?ooooo`;o
00007_ooool2o`0001_ooooo0_l0000Jooooo`;o00002Oooool2o`0002oooooo0_l0000Fooooo`;o
00002Oooool001kooooo00?o0000ooooooooool06_ooool2o`0009Sooooo0_l0000booooo`;o0000
9Oooool2o`0001?ooooo0_l0000Aooooo`;o00003_ooool001kooooo0_l0000Gooooo`;o00000_oo
ool2o`0009Sooooo0_l0001Iooooo`;o00009_ooool2o`0000kooooo000Nooooo`03o`000?oooooo
oooo01Kooooo0_l000000ooooooo0000o`00002Uooooo`;o00001oooool2o`0002Gooooo0_l0001E
ooooo`007_ooool00ol0003oooooooooo`0Iooooo`;o0000HOooool2o`0004;ooooo0_l00007oooo
o`Co00008oooool2o`0004?ooooo0_l0000@ooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o
0000:?ooool2o`0003oooooo0_l0001=ooooo`;o0000>Oooool2o`0002gooooo0_l0000@ooooo`00
7_ooool00ol0003oooooooooo`0Aooooo`;o0000:?ooool2o`0001cooooo0_l0002[ooooo`;o0000
?oooool001kooooo00?o0000ooooooooool0FOooool2o`0000[ooooo0_l0000?ooooo`;o0000M_oo
ool2o`0003_ooooo0_l0000Jooooo`007_ooool00ol0003oooooooooo`0cooooo`;o0000<?ooool2
o`0000oooooo0_l0001fooooo`;o0000>oooool2o`0001[ooooo000Nooooo`03o`000?oooooooooo
03?ooooo0_l00008ooooo`;o00002_ooool2o`00023ooooo0_l0000:ooooo`;o0000HOooool2o`00
00gooooo0_l0001Looooo`007_ooool00ol0003oooooooooo`0mooooo`;o00002_ooool2o`00023o
oooo0_l0000:ooooo`;o00009Oooool2o`0003[ooooo0_l0000=ooooo`;o0000BOooool2o`0000Oo
oooo0_l00008ooooo`007_ooool00ol0003oooooooooo`2Nooooo`;o00005?ooool2o`0007kooooo
0_l00007ooooo`;o00002?ooool001kooooo00Co0000oooooooooooooooo0_l0002aooooo`;o0000
6_ooool2o`0002cooooo0_l0000Eooooo`;o00005Oooool2o`0000gooooo0_l0000:ooooo`007_oo
ool01?l0003oooooooooooooool2o`0002Oooooo0_l00011ooooo`;o00001oooool2o`0001Kooooo
0_l00010ooooo`;o0000;?ooool2o`0000_ooooo0_l00008ooooo`;o00005Oooool2o`0000gooooo
0_l0000:ooooo`007_ooool00ol0003oooooooooo`0Zooooo`;o00003?ooool2o`0000Sooooo0_l0
000Yooooo`;o00001oooool2o`0001Kooooo0_l00002ooooo`;o00000oooool2o`0002Cooooo0_l0
001<ooooo`;o0000>_ooool001kooooo00?o0000ooooooooool0>?ooool2o`0000Sooooo0_l00003
ooooo`;o0000@Oooool2o`0000Kooooo0_l00003ooooo`Co00008_ooool2o`0008Sooooo000Noooo
o`03o`000?oooooooooo04Oooooo0_l0000:ooooo`;o0000=Oooool2o`0000gooooo0_l0001]oooo
o`;o0000?Oooool001kooooo00?o0000ooooooooool0@oooool2o`0000kooooo0_l0000:ooooo`;o
0000Yoooool2o`0003gooooo000Nooooo`;o00000_ooool2o`0002oooooo0_l0000?ooooo`;o0000
6_ooool2o`000:_ooooo0_l0000iooooo`007_ooool01?l0003oooooooooooooool2o`0002oooooo
0_l0000;ooooo`;o0000Hoooool2o`0006Kooooo0ol0000hooooo`007_ooool00ol0003ooooooooo
o`0oooooo`;o0000<oooool2o`0002kooooo0_l0001Wooooo`;o00004Oooool2o`0002Gooooo000N
ooooo`03o`000?oooooooooo05Oooooo0_l00009ooooo`;o00004?ooool2o`0009Wooooo0_l0000?
ooooo`;o00009Oooool001kooooo00?o0000ooooooooool0Eoooool2o`0000Wooooo0_l0000Yoooo
o`;o00008?ooool2o`0005kooooo0_l0000fooooo`007_ooool00ol0003oooooooooo`2=ooooo`;o
00008?ooool3o`0001_ooooo0_l0000Vooooo`;o0000D?ooool001kooooo00?o0000ooooooooool0
A_ooool2o`0005Gooooo0_l0000Aooooo`;o00006oooool2o`0002Kooooo0_l0001@ooooo`007_oo
ool00ol0003oooooooooo`16ooooo`;o00008_ooool2o`0002Sooooo0_l00007ooooo`;o00006ooo
ool2o`0005;ooooo0_l0000gooooo`007_ooool00ol0003oooooooooo`0jooooo`;o00002_ooool2
o`00027ooooo0ol00008ooooo`;o00007_ooool2o`0002Cooooo0_l0000kooooo`;o00005Oooool2
o`0003Oooooo000Mooooo`;o00000oooool2o`0003Oooooo0_l0000]ooooo`;o00002Oooool2o`00
087ooooo0_l00005ooooo`;o0000Aoooool001gooooo0_l00003ooooo`;o0000=oooool2o`0000;o
oooo0_l0002nooooo`;o00006Oooool2o`0002cooooo000Nooooo`03o`000?oooooooooo03kooooo
0_l0000:ooooo`;o0000I_ooool2o`0003Oooooo0_l00003ooooo`;o00009oooool2o`0000kooooo
0_l0000Booooo`;o00002?ooool001kooooo00?o0000ooooooooool0@oooool2o`0000Gooooo0_l0
001Vooooo`;o0000;Oooool2o`0000Sooooo0_l00003ooooo`;o00002oooool2o`0002[ooooo0_l0
000Booooo`;o00002?ooool001kooooo00?o0000ooooooooool0?oooool2o`0000;ooooo0_l0001@
ooooo`;o0000B_ooool2o`0001[ooooo0_l00018ooooo`007_ooool00ol0003oooooooooo`0Hoooo
o`;o00006Oooool2o`0000[ooooo0_l0001Dooooo`;o0000<Oooool2o`0003Sooooo0_l00013oooo
o`007_ooool00ol0003oooooooooo`07ooooo`;o00003oooool2o`0001Wooooo0_l0002Cooooo`;o
0000>?ooool2o`0002kooooo0_l0000Cooooo`007_ooool2o`0000Kooooo1?l0003iooooo`;o0000
;_ooool2o`0001?ooooo000Nooooo`03o`000?oooooooooo00Gooooo0_l0000=ooooo`;o0000k?oo
ool2o`0004?ooooo000Mooooo`;o00000_ooool2o`0001;ooooo0ol0001_ooooo`;o00005?ooool2
o`00027ooooo1?l00005ooooo`;o00001?ooool2o`0007Oooooo000Mooooo`;o00000_ooool2o`00
01?ooooo0_l00004ooooo`;o0000@Oooool4o`0000gooooo0_l0000Eooooo`;o00005?ooool2o`00
027ooooo1?l00005ooooo`;o00001?ooool2o`0001[ooooo0_l0001Kooooo`007_ooool00ol0003o
ooooooooo`0>ooooo`;o00002oooool2o`0000cooooo0_l0000cooooo`Co00003Oooool2o`0002co
oooo0_l0000Vooooo`;o000000?oooooo`000?l000005oooool2o`000003ooooool0003o000000Co
oooo0_l0001Kooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o00006Oooool2o`0000Kooooo
0_l0001Jooooo`;o00003_ooool2o`0000;ooooo0_l0000Rooooo`;o000000?oooooo`000?l00000
5oooool2o`000003ooooool0003o0000067ooooo000Nooooo`03o`000?oooooooooo037ooooo0_l0
000;ooooo`;o0000>Oooool2o`0001;ooooo0_l0000Booooo`;o0000=Oooool2o`0001Wooooo0_l0
001Booooo`007_ooool00ol0003oooooooooo`0Uooooo`;o00002Oooool2o`0000cooooo0_l0000i
ooooo`;o0000=Oooool2o`0002Kooooo0_l000000ooooooo0000o`00000Fooooo`;o0000D_ooool0
01kooooo00?o0000ooooooooool09Oooool2o`0000Wooooo0_l0001nooooo`;o0000:Oooool2o`00
01_ooooo0_l0001=ooooo`007_ooool00ol0003oooooooooo`3Rooooo`;o00005?ooool2o`0004go
oooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0000cooooo`;o0000Goooool2o`00047ooooo
0_l0001Sooooo`007_ooool00ol0003oooooooooo`08ooooo`?o0000<oooool2o`00017ooooo0_l0
0006ooooo`;o0000A?ooool2o`0005Kooooo0_l0001>ooooo`007_ooool00ol0003oooooooooo`08
ooooo`;o00001_ooool2o`0003Oooooo0_l00006ooooo`;o00001_ooool2o`0009cooooo0_l0001>
ooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o000000?oooooo`000?l00000=oooool2o`00
023ooooo0_l0002<ooooo`;o0000C?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool03Oooool2
o`00017ooooo0_l00019ooooo`;o00000_ooool3o`0004cooooo0_l0000Vooooo`;o00004Oooool2
o`0003Sooooo0_l0000Booooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`02ooooo`;o00007?oo
ool2o`0001Wooooo0_l0000booooo`Co00003?ooool2o`0003gooooo0_l0000Vooooo`;o0000Booo
ool2o`0001;ooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000000Kooooo0ol00002ooooo`;o0000=oooool2o`0001Sooooo0_l0000Jooooo`;o0000
3?ooool2o`0006?ooooo0_l0000?ooooo`;o00004Oooool2o`0001;ooooo0_l0000Yooooo`000ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03
o`000?oooooooooo057ooooo0_l00002ooooo`;o00003_ooool2o`0002[ooooo0_l0000Tooooo`;o
0000:oooool2o`0000Gooooo0_l00008ooooo`;o00004Oooool2o`0001;ooooo0_l0000Pooooo`;o
00001oooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`00
0?o<c<`01_ooool00ol0003oooooooooo`04o`0002;ooooo0_l0000Yooooo`;o00004_ooool2o`00
00kooooo0_l0000Jooooo`?o00008oooool2o`0003;ooooo0_l0000_ooooo`;o00008?ooool2o`00
00Oooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o
410@00Kooooo00?o0000ooooooooool01?l0000Rooooo`;o0000:Oooool2o`0002;ooooo0_l0000K
ooooo`;o0000R?ooool2o`0002Wooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0Xoooool2o`000:;ooooo0003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo
00?o0000ooooooooool04_ooool2o`0004?ooooo0_l00008ooooo`;o0000<?ooool2o`0000kooooo
0_l0001aooooo`;o0000;oooool001kooooo00?o0000ooooooooool01Oooool2o`0000[ooooo0ol0
000Nooooo`;o00008oooool2o`0000Kooooo1?l0000<ooooo`;o00008_ooool2o`00087ooooo0_l0
000_ooooo`007_ooool00ol0003oooooooooo`05ooooo`;o00001_ooool2o`0000;ooooo0_l0000O
ooooo`;o00005_ooool2o`0001?ooooo0_l0000>ooooo`;o0000V_ooool2o`0003[ooooo000Noooo
o`03o`000?oooooooooo00gooooo0_l0000kooooo`;o0000ZOooool2o`0001Cooooo0_l0000joooo
o`007_ooool00ol0003oooooooooo`02ooooo`;o0000Voooool2o`0003_ooooo0_l00006ooooo`;o
00003oooool2o`00053ooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0002Kooooo`;o0000
>oooool2o`0000Kooooo0_l0000Fooooo`;o00005_ooool2o`0001;ooooo0_l0000>ooooo`;o0000
3Oooool001kooooo00?o0000ooooooooool07Oooool2o`0008kooooo0_l0000booooo`;o00006Ooo
ool2o`0001Kooooo0_l0000Booooo`;o00003_ooool2o`0000gooooo000Nooooo`03o`000?oooooo
oooo00Sooooo0_l0000Cooooo`;o0000<_ooool2o`0000Oooooo0_l0001Aooooo`;o0000<_ooool2
o`0005Cooooo0_l0000>ooooo`007_ooool00ol0003oooooooooo`08ooooo`;o0000?_ooool2o`00
00Oooooo0_l00007ooooo`;o0000Foooool2o`0002Oooooo0_l0000?ooooo`;o0000A?ooool2o`00
00kooooo000Nooooo`03o`000?oooooooooo04Sooooo0_l0001]ooooo`;o00009oooool2o`0000oo
oooo0_l0000@ooooo`;o000000?oooooo`000?l00000;oooool2o`0000kooooo000Nooooo`03o`00
0?oooooooooo03;ooooo0_l0000Yooooo`;o0000Y?ooool2o`000003ooooool0003o000002oooooo
0_l0000>ooooo`007_ooool00ol0003oooooooooo`0booooo`;o00005Oooool2o`0000Cooooo0_l0
000<ooooo`;o0000Coooool2o`00013ooooo0_l00004ooooo`;o00004Oooool2o`0006?ooooo0_l0
0007ooooo`007_ooool2o`0004[ooooo0_l00004ooooo`;o00008oooool2o`0003Sooooo0_l0000@
ooooo`;o00001?ooool2o`00017ooooo0_l0001Sooooo`;o00001oooool001kooooo00?o0000oooo
ooooool0M?ooool2o`0004Cooooo0_l0002;ooooo`007_ooool00ol0003oooooooooo`10ooooo`;o
00004Oooool2o`0000?ooooo0_l00007ooooo`;o0000Eoooool2o`00017ooooo0_l0000Uooooo`;o
00002oooool2o`0003Sooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0dooooo`;o0000
2Oooool3o`00017ooooo0_l00003ooooo`;o00001oooool2o`0002oooooo0_l0000iooooo`;o0000
9Oooool2o`0000_ooooo0_l0000hooooo`;o00002_ooool001kooooo00?o0000ooooooooool0=?oo
ool2o`0000Wooooo0_l0001Aooooo`;o0000Qoooool2o`0002[ooooo000Nooooo`03o`000?oooooo
oooo01oooooo0_l0001aooooo`;o0000DOooool2o`0003Cooooo0_l0000Hooooo`;o00004?ooool0
01kooooo00?o0000ooooooooool07oooool2o`0006Oooooo0_l00008ooooo`;o0000DOooool2o`00
02Gooooo0_l0000Rooooo`;o00000oooool2o`00013ooooo000Nooooo`03o`000?oooooooooo01?o
oooo0_l0001Kooooo`Co00005?ooool2o`0008;ooooo0_l0000Rooooo`;o00005Oooool001kooooo
00?o0000ooooooooool04oooool2o`0003kooooo0_l0000Kooooo`Co0000Doooool2o`0006Oooooo
0_l0000Eooooo`007_ooool00ol0003oooooooooo`1Cooooo`;o0000L_ooool2o`0007kooooo000N
ooooo`03o`000?oooooooooo057ooooo0_l0001]ooooo`;o0000QOooool001kooooo00?o0000oooo
ooooool01oooool2o`0004Sooooo0_l0000:ooooo`;o0000;?ooool2o`0003?ooooo0_l00025oooo
o`007_ooool00ol0003oooooooooo`07ooooo`;o0000E?ooool2o`0002cooooo0_l0000Kooooo`;o
000000?oooooo`000?l00000Q?ooool2o`0001Cooooo000Nooooo`03o`000?oooooooooo0:Sooooo
0_l000000ooooooo0000o`00000Qooooo`;o0000HOooool2o`0001Cooooo000Nooooo`03o`000?oo
oooooooo0<kooooo0_l0001gooooo`007_ooool00ol0003oooooooooo`3<ooooo`;o00004Oooool2
o`0006Kooooo000Nooooo`;o0000a_ooool2o`0000Gooooo0_l0000Aooooo`;o0000;Oooool2o`00
03Oooooo000Nooooo`03o`000?oooooooooo02Cooooo0_l0000Kooooo`;o0000F?ooool2o`0002So
oooo0_l00009ooooo`;o0000??ooool2o`0003Oooooo000Nooooo`03o`000?oooooooooo02Cooooo
0_l0000Kooooo`;o00008?ooool2o`00017ooooo0_l0000Sooooo`;o00000_ooool2o`0001Cooooo
0_l0000Iooooo`;o00003Oooool2o`0003[ooooo0_l0000Zooooo`007_ooool00ol0003ooooooooo
o`0_ooooo`;o0000<Oooool3o`00017ooooo0_l0000Wooooo`;o00001?ooool2o`0000kooooo0_l0
000Xooooo`;o0000>_ooool2o`0002[ooooo000Nooooo`03o`000?oooooooooo02oooooo0_l0000a
ooooo`;o0000>?ooool2o`0000Oooooo0_l0002Pooooo`007_ooool00ol0003oooooooooo`0;oooo
o`;o00001Oooool2o`0001Gooooo0_l0001aooooo`;o0000B_ooool3o`0003Oooooo0_l0000Soooo
o`007_ooool00ol0003oooooooooo`0;ooooo`;o00001Oooool2o`0000?ooooo0_l0000@ooooo`;o
0000M?ooool2o`0002cooooo0_l0000Iooooo`?o0000=oooool2o`0000oooooo0_l0000Booooo`00
7_ooool00ol0003oooooooooo`0Gooooo`;o0000COooool2o`0003Oooooo0_l0000Tooooo`;o0000
1_ooool2o`0000[ooooo0_l0000Iooooo`;o0000?Oooool2o`0001;ooooo000Nooooo`?o0000COoo
ool2o`0001Oooooo0_l0001Mooooo`;o00004_ooool2o`0001Wooooo0_l0000Gooooo`;o0000>?oo
ool001kooooo0ol0001=ooooo`;o00009_ooool2o`00037ooooo0_l0000Sooooo`;o0000?_ooool2
o`0003Sooooo000Nooooo`03o`000?oooooooooo00cooooo0_l0001Wooooo`;o0000<Oooool2o`00
02?ooooo0_l0000iooooo`;o00002?ooool2o`0001Kooooo0_l0000Kooooo`007_ooool00ol0003o
ooooooooo`0<ooooo`;o00005_ooool2o`0006kooooo0_l0000Uooooo`?o0000B_ooool2o`0000So
oooo0_l0000Fooooo`;o00006oooool001kooooo00?o0000ooooooooool09?ooool2o`0005?ooooo
0_l0000Iooooo`;o00001Oooool2o`0001kooooo0ol00029ooooo`007_ooool00ol0003ooooooooo
o`0Oooooo`;o00007oooool2o`0001gooooo0_l0000Hooooo`;o00008?ooool2o`000:[ooooo000N
ooooo`03o`000?oooooooooo01oooooo0_l0000Oooooo`;o00007Oooool2o`0000[ooooo0_l0000k
ooooo`;o0000Coooool2o`0004cooooo000Nooooo`03o`000?oooooooooo06_ooooo0_l0000coooo
o`;o00001_ooool2o`0003Cooooo0_l0000Iooooo`;o0000C?ooool001kooooo0_l0002Qooooo`;o
0000??ooool2o`0001Oooooo0_l0001>ooooo`007_ooool00ol0003oooooooooo`2Zooooo`;o0000
;?ooool2o`0001gooooo0_l0000Qooooo`;o0000:oooool001kooooo00?o0000ooooooooool0??oo
ool2o`0000cooooo0_l0000Wooooo`;o0000=Oooool2o`0002cooooo0_l00010ooooo`?o0000:_oo
ool001kooooo00?o0000ooooooooool02_ooool2o`00033ooooo0_l0000<ooooo`;o00009oooool2
o`0004;ooooo0_l0001Pooooo`Co0000:_ooool001kooooo00?o0000ooooooooool02_ooool2o`00
0:_ooooo0_l0001Pooooo`;o0000;?ooool001kooooo00Co0000oooooooooooooooo0_l0000;oooo
o`;o0000?oooool2o`0004Sooooo0_l0002Eooooo`;o00003oooool2o`0000Cooooo000Nooooo`04
o`000?ooooooooooooooo`;o00002oooool2o`0003oooooo0_l00018ooooo`;o0000Noooool2o`00
01Sooooo0_l0000?ooooo`;o00001?ooool001kooooo00?o0000ooooooooool0?Oooool2o`0005co
oooo0_l00003ooooo`;o0000I_ooool2o`0000cooooo0_l0000Qooooo`Co00002_ooool001kooooo
00?o0000ooooooooool09_ooool2o`0001Gooooo0_l0000Mooooo`;o00003Oooool2o`0002kooooo
0_l00003ooooo`;o00001?ooool2o`0002_ooooo0_l0000cooooo`;o00008oooool2o`0000[ooooo
1?l0000:ooooo`007_ooool00ol0003oooooooooo`0Vooooo`;o00004oooool2o`0001oooooo0_l0
000=ooooo`;o0000>Oooool2o`00017ooooo0_l00002ooooo`;o00005?ooool2o`0000Wooooo0_l0
000[ooooo`;o00008?ooool2o`0001Sooooo000Nooooo`03o`000?oooooooooo03_ooooo0_l0001l
ooooo`;o00000_ooool2o`0001Sooooo0_l00005ooooo`;o00003Oooool2o`0001cooooo0_l0000j
ooooo`007_ooool00ol0003oooooooooo`1booooo`;o0000Hoooool2o`0001Cooooo0_l00011oooo
o`;o00005Oooool001kooooo00?o0000ooooooooool0:Oooool2o`0004Oooooo0_l0000Yooooo`;o
0000TOooool2o`0001Gooooo000Nooooo`03o`000?oooooooooo02Wooooo0_l0001booooo`;o0000
7oooool2o`00067ooooo0_l0000Tooooo`005?ooool4o`000003oa0@4?oooooooooo00?ooooo00?o
0000ooooooooool0:oooool2o`0001Gooooo0_l0001Fooooo`;o00008_ooool2o`0004Oooooo1?l0
000Fooooo`;o00009?ooool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0>
ooooo`;o00006oooool2o`0001Gooooo0_l0000Kooooo`;o0000>Oooool2o`0001Gooooo0_l00006
ooooo`;o0000C?ooool4o`0003cooooo000Fooooo`03o`000?oooooooooo00Gooooo0ol0000>oooo
o`;o0000Coooool2o`0004Kooooo0_l00008ooooo`;o00001_ooool2o`00033ooooo0_l0000moooo
o`;o00006oooool001Kooooo00?o0000ooooooooool0[oooool2o`0004;ooooo0_l0000mooooo`;o
00006oooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003ooooooooo
o`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Cooooo00?oEEEEofIV
I_l00000oooooomBooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.54364 .9405 Mdot
.45642 .34569 Mdot
.46597 .90544 Mdot
.86315 .19481 Mdot
.04236 .9661 Mdot
.69825 .47395 Mdot
.4384 .31648 Mdot
.36919 .80371 Mdot
.30913 .53523 Mdot
.76795 .03917 Mdot
.57163 .35069 Mdot
.48506 .41546 Mdot
.31292 .82314 Mdot
.8982 .03301 Mdot
.62522 .29133 Mdot
.76898 .86913 Mdot
.25183 .87112 Mdot
.01206 .59028 Mdot
.10427 .91451 Mdot
.40361 .52245 Mdot
.71512 .55557 Mdot
.09643 .06602 Mdot
.1639 .71713 Mdot
.51336 .86822 Mdot
.45057 .13211 Mdot
.74867 .19457 Mdot
.71508 .33169 Mdot
.46917 .38893 Mdot
.59096 .28564 Mdot
.32841 .84389 Mdot
.23405 .82652 Mdot
.99331 .00632 Mdot
.22065 .55259 Mdot
.21409 .14088 Mdot
.54101 .51924 Mdot
.54763 .37131 Mdot
.67808 .80526 Mdot
.37105 .77023 Mdot
.48161 .47007 Mdot
.78582 .18539 Mdot
.36986 .65535 Mdot
.64095 .40607 Mdot
.11168 .93706 Mdot
.06606 .78036 Mdot
.15681 .75188 Mdot
.84281 .50002 Mdot
.17613 .564 Mdot
.95639 .06537 Mdot
.72475 .08902 Mdot
.6175 .93294 Mdot
.2259 .88296 Mdot
.81537 .4068 Mdot
.34538 .19218 Mdot
.98115 .35798 Mdot
.42513 .13109 Mdot
.15302 .69775 Mdot
.12991 .90575 Mdot
.86229 .53968 Mdot
.89574 .51373 Mdot
.95702 .38966 Mdot
.49587 .71117 Mdot
.18522 .61422 Mdot
.31138 .3858 Mdot
.49222 .85468 Mdot
.73587 .59186 Mdot
.53695 .24904 Mdot
.9083 .29524 Mdot
.62803 .78738 Mdot
.60109 .00262 Mdot
.02417 .00794 Mdot
.53458 .45521 Mdot
.34267 .65192 Mdot
.27677 .86633 Mdot
.58869 .26266 Mdot
.72871 .04431 Mdot
.96554 .37395 Mdot
.37011 .18433 Mdot
.91146 .50965 Mdot
.51897 .58286 Mdot
.58812 .88664 Mdot
.59211 .88922 Mdot
.31031 .49915 Mdot
.24389 .34328 Mdot
.33508 .49929 Mdot
.19395 .69889 Mdot
.32793 .91856 Mdot
.7192 .52844 Mdot
.53027 .05429 Mdot
.58691 .44758 Mdot
.87847 .21815 Mdot
.86894 .25522 Mdot
.00531 .8053 Mdot
.4782 .87018 Mdot
.08251 .12434 Mdot
.48704 .26907 Mdot
.81799 .74662 Mdot
.73227 .0539 Mdot
.84563 .72184 Mdot
.42178 .90841 Mdot
.72098 .06904 Mdot
.72762 .06746 Mdot
.77574 .3224 Mdot
.99601 .60759 Mdot
.01565 .12641 Mdot
.27138 .09203 Mdot
.15854 .32992 Mdot
.94266 .58901 Mdot
.40739 .98843 Mdot
.15011 .65416 Mdot
.98135 .44968 Mdot
.18268 .94407 Mdot
.52872 .53221 Mdot
.40106 .77372 Mdot
.9892 .493 Mdot
.70392 .27971 Mdot
.92807 .66889 Mdot
.90259 .60907 Mdot
.32859 .09497 Mdot
.37847 .96099 Mdot
.77126 .76528 Mdot
.79011 .85458 Mdot
.49782 .8062 Mdot
.39756 .21375 Mdot
.2447 .31507 Mdot
.20679 .10561 Mdot
.18174 .7298 Mdot
.03997 .64155 Mdot
.41597 .24189 Mdot
.91853 .79377 Mdot
.43748 .41032 Mdot
.8455 .57612 Mdot
.57773 .24739 Mdot
.50737 .13635 Mdot
.81318 .10722 Mdot
.38784 .10612 Mdot
.50635 .00249 Mdot
.47 .21227 Mdot
.20733 .93611 Mdot
.77837 .02725 Mdot
.37209 .94836 Mdot
.4573 .68835 Mdot
.69193 .75531 Mdot
.95192 .18572 Mdot
.49173 .84122 Mdot
.31367 .22511 Mdot
.15507 .81957 Mdot
.41655 .66844 Mdot
.63953 .54271 Mdot
.95222 .66419 Mdot
.77939 .29145 Mdot
.32521 .85913 Mdot
.79652 .63077 Mdot
.59079 .74092 Mdot
.99284 .60241 Mdot
.6894 .42434 Mdot
.24452 .69724 Mdot
.77748 .18511 Mdot
.41112 .0447 Mdot
.31513 .51857 Mdot
.43574 .32674 Mdot
.72801 .92658 Mdot
.61091 .66705 Mdot
.03694 .72562 Mdot
.3629 .95884 Mdot
.7976 .27681 Mdot
.56008 .19094 Mdot
.41446 .89476 Mdot
.5732 .89357 Mdot
.20527 .43492 Mdot
.43303 .25132 Mdot
.28925 .40355 Mdot
.24081 .89064 Mdot
.2003 .8405 Mdot
.58015 .64452 Mdot
.94786 .03318 Mdot
.79458 .71853 Mdot
.19956 .17008 Mdot
.81872 .01478 Mdot
.71415 .14624 Mdot
.2962 .69305 Mdot
.01307 .82703 Mdot
.8826 .94235 Mdot
.48276 .96762 Mdot
.12683 .59977 Mdot
.60022 .77541 Mdot
.58401 .08185 Mdot
.97023 .43425 Mdot
.0111 .58476 Mdot
.68676 .77983 Mdot
.89787 .18685 Mdot
.24097 .0073 Mdot
.68538 .99904 Mdot
.09554 .77341 Mdot
.34403 .04725 Mdot
.6605 .81689 Mdot
.71911 .90397 Mdot
.92775 .60928 Mdot
.63529 .78508 Mdot
.17722 .50175 Mdot
.97748 .60341 Mdot
.45221 .27564 Mdot
.67133 .78818 Mdot
.16195 .02808 Mdot
.33005 .20668 Mdot
.61108 .00356 Mdot
.13597 .11079 Mdot
.78348 .75194 Mdot
.97637 .7164 Mdot
.11869 .71703 Mdot
.16509 .74386 Mdot
.18967 .70938 Mdot
.95366 .62051 Mdot
.14263 .58434 Mdot
.93308 .48174 Mdot
.00681 .05808 Mdot
.48219 .45866 Mdot
.71986 .31642 Mdot
.03841 .34278 Mdot
.79904 .0188 Mdot
.17896 .68731 Mdot
.90307 .0131 Mdot
.88779 .37406 Mdot
.63897 .28039 Mdot
.68396 .90255 Mdot
.92906 .32624 Mdot
.77554 .74786 Mdot
.83756 .69282 Mdot
.26562 .73927 Mdot
.35254 .31316 Mdot
.62192 .43977 Mdot
.93627 .82803 Mdot
.3311 .03887 Mdot
.38336 .60436 Mdot
.32339 .89486 Mdot
.38426 .07413 Mdot
.1972 .17862 Mdot
.26436 .65605 Mdot
.79925 .28511 Mdot
.49375 .61453 Mdot
.60287 .51107 Mdot
.38391 .69662 Mdot
.63801 .72969 Mdot
.00991 .32912 Mdot
.50232 .78074 Mdot
.14577 .36713 Mdot
.09883 .98257 Mdot
.11923 .74593 Mdot
.37518 .80799 Mdot
.66597 .19753 Mdot
.21179 .51729 Mdot
.72179 .56975 Mdot
.58337 .99943 Mdot
.08001 .14996 Mdot
.7436 .1767 Mdot
.11848 .21773 Mdot
.25691 .98248 Mdot
.56787 .04687 Mdot
.06912 .90283 Mdot
.3364 .42191 Mdot
.66485 .12178 Mdot
.52781 .05911 Mdot
.93496 .24211 Mdot
.94335 .09886 Mdot
.48037 .06844 Mdot
.03463 .27 Mdot
.37085 .33752 Mdot
.31007 .13438 Mdot
.19075 .52062 Mdot
.48761 .45394 Mdot
.07226 .00445 Mdot
.94961 .97338 Mdot
.42222 .05879 Mdot
.26303 .76431 Mdot
.50579 .98863 Mdot
.21159 .02193 Mdot
.62004 .91576 Mdot
.48259 .09852 Mdot
.70458 .24057 Mdot
.44124 .1788 Mdot
.23584 .68202 Mdot
.42366 .30377 Mdot
.17282 .90889 Mdot
.53425 .41655 Mdot
.82012 .97798 Mdot
.98372 .12986 Mdot
.88694 .73549 Mdot
.73617 .12034 Mdot
.88359 .13457 Mdot
.84672 .02674 Mdot
.71616 .06255 Mdot
.79863 .02948 Mdot
.10636 .32521 Mdot
.72852 .78174 Mdot
.67321 .47881 Mdot
.97188 .64234 Mdot
.06839 .2342 Mdot
.61404 .76446 Mdot
.15535 .34703 Mdot
.63171 .51976 Mdot
.17625 .99401 Mdot
.75251 .19917 Mdot
.55333 .26873 Mdot
.56217 .39872 Mdot
.2665 .33058 Mdot
.57726 .88562 Mdot
.44919 .51131 Mdot
.5278 .38807 Mdot
.65045 .90633 Mdot
.81786 .76966 Mdot
.92562 .81933 Mdot
.35544 .55623 Mdot
.57273 .55449 Mdot
.35005 .28801 Mdot
.6229 .98954 Mdot
.08977 .39845 Mdot
.84141 .26718 Mdot
.09743 .63479 Mdot
.18277 .74244 Mdot
.29526 .18998 Mdot
.73737 .29038 Mdot
.83784 .67804 Mdot
.58077 .04036 Mdot
.77897 .32838 Mdot
.71223 .80876 Mdot
.59711 .22764 Mdot
.81874 .77493 Mdot
.62565 .24836 Mdot
.68338 .52242 Mdot
.92457 .79686 Mdot
.9375 .59351 Mdot
.94051 .15444 Mdot
.05367 .81316 Mdot
.78158 .7736 Mdot
.56479 .20203 Mdot
.98427 .53755 Mdot
.53136 .77312 Mdot
.36408 .72169 Mdot
.7206 .80026 Mdot
.8187 .85977 Mdot
.38257 .19006 Mdot
.04478 .25932 Mdot
.8951 .64569 Mdot
.27389 .72238 Mdot
.84334 .11847 Mdot
.24815 .82555 Mdot
.2737 .81576 Mdot
.16903 .23068 Mdot
.10368 .60892 Mdot
.66582 .43419 Mdot
.70516 .6588 Mdot
.24615 .11352 Mdot
.1955 .48965 Mdot
.27861 .83946 Mdot
.70127 .8522 Mdot
.35176 .53627 Mdot
.30703 .78133 Mdot
.99329 .00413 Mdot
.31644 .89779 Mdot
.36434 .66605 Mdot
.99249 .17812 Mdot
.95155 .61909 Mdot
.59825 .01784 Mdot
.22869 .88435 Mdot
.1341 .40975 Mdot
.00749 .77963 Mdot
.18585 .23326 Mdot
.16794 .80613 Mdot
.48581 .29548 Mdot
.24994 .42509 Mdot
.35545 .33418 Mdot
.26196 .59907 Mdot
.19453 .48571 Mdot
.64533 .5487 Mdot
.40693 .09724 Mdot
.39635 .65634 Mdot
.19433 .602 Mdot
.8043 .65165 Mdot
.32885 .98705 Mdot
.19383 .81443 Mdot
.6743 .02679 Mdot
.70748 .22139 Mdot
.90964 .69486 Mdot
.52246 .70987 Mdot
.58375 .09585 Mdot
.5307 .12301 Mdot
.5525 .38546 Mdot
.00115 .55483 Mdot
.8079 .03174 Mdot
.68291 .53267 Mdot
.92919 .76876 Mdot
.85357 .9758 Mdot
.80317 .02988 Mdot
.94648 .31375 Mdot
.78443 .20185 Mdot
.37975 .60216 Mdot
.36206 .06239 Mdot
.54825 .78999 Mdot
.04942 .79712 Mdot
.60676 .21962 Mdot
.04747 .83969 Mdot
.71843 .0079 Mdot
.65927 .71785 Mdot
.01178 .34585 Mdot
.5733 .15489 Mdot
.30607 .53518 Mdot
.60985 .15719 Mdot
.1439 .13284 Mdot
.04006 .09319 Mdot
.33746 .69429 Mdot
.81851 .95268 Mdot
.92888 .1051 Mdot
.44146 .73072 Mdot
.5376 .60667 Mdot
.94894 .90276 Mdot
.96757 .59184 Mdot
.75078 .6872 Mdot
.46924 .27791 Mdot
.01808 .95195 Mdot
.97048 .87609 Mdot
.07572 .7847 Mdot
.42441 .5273 Mdot
.31936 .2757 Mdot
.92589 .32308 Mdot
.52126 .98132 Mdot
.61935 .12849 Mdot
.30437 .19524 Mdot
.20412 .6657 Mdot
.14872 .69354 Mdot
.71232 .75505 Mdot
.82787 .35777 Mdot
.80453 .49114 Mdot
.76467 .29583 Mdot
.02809 .59773 Mdot
.33647 .254 Mdot
.51212 .65972 Mdot
.75063 .30594 Mdot
.15728 .42573 Mdot
.72175 .78397 Mdot
.86397 .88731 Mdot
.37908 .92283 Mdot
.02904 .02568 Mdot
.79225 .36433 Mdot
.65764 .38015 Mdot
.49013 .94578 Mdot
.69996 .46207 Mdot
.76514 .09891 Mdot
.62696 .16207 Mdot
.908 .59087 Mdot
.32339 .12436 Mdot
.37081 .62016 Mdot
.23301 .50905 Mdot
.59066 .40709 Mdot
.99273 .7081 Mdot
.06519 .10824 Mdot
.50733 .0218 Mdot
.29273 .21698 Mdot
.44131 .30017 Mdot
.93617 .00771 Mdot
.23065 .51445 Mdot
.91292 .58903 Mdot
.03738 .50959 Mdot
.41018 .35609 Mdot
.67148 .97624 Mdot
.54385 .95834 Mdot
.46572 .64844 Mdot
.45659 .34369 Mdot
.44181 .11288 Mdot
.33892 .40963 Mdot
.30313 .602 Mdot
.87471 .0026 Mdot
.30435 .32547 Mdot
.98172 .62292 Mdot
.93567 .12567 Mdot
.01818 .83933 Mdot
.06979 .54008 Mdot
.84412 .30368 Mdot
.81626 .61999 Mdot
.27197 .40666 Mdot
.01319 .94738 Mdot
.83315 .40889 Mdot
.82795 .67629 Mdot
.382 .182 Mdot
.09026 .34453 Mdot
.95876 .82098 Mdot
.83373 .01139 Mdot
.79356 .7552 Mdot
.6072 .51072 Mdot
.37628 .07367 Mdot
.0992 .82942 Mdot
.90142 .91903 Mdot
.69161 .30616 Mdot
.82233 .6011 Mdot
.37824 .73763 Mdot
.23113 .974 Mdot
.5515 .73803 Mdot
.05448 .71833 Mdot
.83499 .01409 Mdot
.18105 .78139 Mdot
.92343 .12214 Mdot
.45056 .40074 Mdot
.6135 .75993 Mdot
.18973 .94434 Mdot
.48764 .47957 Mdot
.94169 .85435 Mdot
.58527 .82045 Mdot
.33371 .82485 Mdot
.44801 .01365 Mdot
.83934 .82759 Mdot
.46506 .08064 Mdot
.3613 .34594 Mdot
.97396 .9704 Mdot
.9181 .06374 Mdot
.99583 .56116 Mdot
.29014 .51277 Mdot
.102 .79891 Mdot
.17392 .75531 Mdot
.2694 .76325 Mdot
.0557 .7598 Mdot
.35935 .40503 Mdot
.05254 .54016 Mdot
.69001 .37607 Mdot
.12546 .62482 Mdot
.15369 .4208 Mdot
.2466 .78663 Mdot
.8967 .37269 Mdot
.37268 .05344 Mdot
.54692 .95051 Mdot
.99983 .92374 Mdot
.63599 .80497 Mdot
.96683 .48166 Mdot
.94424 .56453 Mdot
.63889 .0465 Mdot
.56173 .827 Mdot
.00164 .45239 Mdot
.66218 .96505 Mdot
.87845 .92477 Mdot
.67505 .45567 Mdot
.49344 .90909 Mdot
.46361 .91994 Mdot
.20052 .56585 Mdot
.65442 .45014 Mdot
.16483 .38465 Mdot
.47005 .50025 Mdot
.12992 .74997 Mdot
.2691 .55076 Mdot
.88943 .44007 Mdot
.56333 .1723 Mdot
.6586 .8913 Mdot
.28521 .34209 Mdot
.45452 .99202 Mdot
.75288 .86637 Mdot
.36564 .83608 Mdot
.00797 .23695 Mdot
.70949 .97947 Mdot
.80514 .14665 Mdot
.47694 .72983 Mdot
.26781 .64216 Mdot
.80988 .33387 Mdot
.06091 .4676 Mdot
.08285 .13168 Mdot
.2149 .41414 Mdot
.60923 .63804 Mdot
.52056 .02546 Mdot
.42177 .36047 Mdot
.12614 .84885 Mdot
.97935 .95334 Mdot
.3407 .61015 Mdot
.49693 .87172 Mdot
.0615 .00534 Mdot
.57594 .47142 Mdot
.49818 .72628 Mdot
.37639 .78094 Mdot
.51305 .02248 Mdot
.99011 .15774 Mdot
.4241 .20206 Mdot
.35294 .33537 Mdot
.01525 .91326 Mdot
.08978 .93337 Mdot
.92355 .39616 Mdot
.02283 .80304 Mdot
.44633 .99052 Mdot
.13219 .61836 Mdot
.19603 .99604 Mdot
.51447 .35134 Mdot
.86358 .86158 Mdot
.93603 .65172 Mdot
.79794 .07217 Mdot
.07958 .71813 Mdot
.31383 .69995 Mdot
.05456 .36317 Mdot
.58208 .25818 Mdot
.48293 .6946 Mdot
.73853 .38498 Mdot
.99002 .22822 Mdot
.62819 .48607 Mdot
.98168 .72351 Mdot
.95221 .81528 Mdot
.11642 .52624 Mdot
.06254 .88439 Mdot
.18422 .2327 Mdot
.99844 .9516 Mdot
.83308 .28833 Mdot
.7841 .89206 Mdot
.81011 .01917 Mdot
.78985 .33964 Mdot
.11945 .89079 Mdot
.23733 .81532 Mdot
.66803 .22925 Mdot
.33546 .67672 Mdot
.19713 .89674 Mdot
.81469 .12133 Mdot
.92242 .96505 Mdot
.41955 .35747 Mdot
.7172 .09379 Mdot
.56716 .45049 Mdot
.69809 .45469 Mdot
.24261 .91776 Mdot
.33712 .31768 Mdot
.62887 .14721 Mdot
.28611 .63358 Mdot
.95338 .48685 Mdot
.58174 .6085 Mdot
.5962 .9473 Mdot
.90074 .06392 Mdot
.04132 .77675 Mdot
.59831 .14577 Mdot
.23706 .18781 Mdot
.61754 .02087 Mdot
.1211 .45877 Mdot
.56053 .75978 Mdot
.72741 .4799 Mdot
.73583 .61254 Mdot
.32187 .93826 Mdot
.55544 .8555 Mdot
.6427 .11835 Mdot
.35231 .72958 Mdot
.19147 .85339 Mdot
.74125 .60933 Mdot
.31927 .80828 Mdot
.79273 .07501 Mdot
.23002 .03659 Mdot
.99863 .77552 Mdot
.60776 .84559 Mdot
.67011 .90764 Mdot
.86291 .94936 Mdot
.4488 .56242 Mdot
.25296 .82303 Mdot
.28846 .27458 Mdot
.67347 .2774 Mdot
.02967 .34738 Mdot
.71577 .84266 Mdot
.67848 .78686 Mdot
.41447 .06674 Mdot
.41143 .65752 Mdot
.84217 .64158 Mdot
.35805 .03222 Mdot
.45525 .9045 Mdot
.83474 .06147 Mdot
.06593 .107 Mdot
.54833 .67474 Mdot
.67405 .8356 Mdot
.65554 .67368 Mdot
.75044 .57483 Mdot
.4423 .47331 Mdot
.71678 .58854 Mdot
.51912 .13516 Mdot
.71649 .835 Mdot
.77983 .79844 Mdot
.03489 .64727 Mdot
.35976 .75232 Mdot
.54671 .40935 Mdot
.16213 .21975 Mdot
.11922 .32579 Mdot
.89986 .92385 Mdot
.96573 .15651 Mdot
.27795 .555 Mdot
.71417 .16052 Mdot
.41203 .64191 Mdot
.10335 .92591 Mdot
.39653 .43943 Mdot
.47296 .41408 Mdot
.59555 .09511 Mdot
.68952 .22023 Mdot
.08537 .06268 Mdot
.5812 .03382 Mdot
.69856 .63039 Mdot
.84371 .98185 Mdot
.22073 .41133 Mdot
.11287 .47761 Mdot
.35461 .01199 Mdot
.63819 .42382 Mdot
.52394 .01508 Mdot
.84575 .21418 Mdot
.79486 .4855 Mdot
.15412 .64798 Mdot
.59065 .86278 Mdot
.38628 .78844 Mdot
.67903 .87348 Mdot
.87358 .20291 Mdot
.01691 .80537 Mdot
.38426 .425 Mdot
.99492 .60361 Mdot
.26545 .13578 Mdot
.00513 .03157 Mdot
.80873 .26663 Mdot
.79392 .34224 Mdot
.00519 .55074 Mdot
.28966 .95658 Mdot
.50959 .45568 Mdot
.19215 .40277 Mdot
.99136 .47335 Mdot
.98495 .01813 Mdot
.66474 .92855 Mdot
.42946 .05552 Mdot
.52362 .99967 Mdot
.11612 .00259 Mdot
.60907 .79814 Mdot
.20588 .77817 Mdot
.66348 .01616 Mdot
.4937 .16539 Mdot
.66129 .73112 Mdot
.74812 .18987 Mdot
.52008 .71812 Mdot
.73977 .63122 Mdot
.28298 .52227 Mdot
.9357 .33354 Mdot
.4776 .94332 Mdot
.33937 .88805 Mdot
.21617 .35453 Mdot
.29046 .69256 Mdot
.6682 .71133 Mdot
.99792 .81707 Mdot
.93422 .43405 Mdot
.27641 .8009 Mdot
.93673 .35071 Mdot
.4667 .67861 Mdot
.92846 .97554 Mdot
.17648 .52751 Mdot
.74374 .81368 Mdot
.05099 .95499 Mdot
.21043 .40404 Mdot
.05735 .77878 Mdot
.39818 .94714 Mdot
.10677 .38352 Mdot
.84663 .26484 Mdot
.74939 .81466 Mdot
.66942 .4065 Mdot
.81875 .6767 Mdot
.01721 .48593 Mdot
.23288 .44633 Mdot
.17823 .60734 Mdot
.23373 .47414 Mdot
.90706 .55652 Mdot
.36453 .1126 Mdot
.15784 .57804 Mdot
.69454 .04313 Mdot
.17859 .38609 Mdot
.33836 .88374 Mdot
.84524 .88273 Mdot
.30809 .88971 Mdot
.22293 .92184 Mdot
.87494 .35733 Mdot
.47904 .02802 Mdot
.37007 .13903 Mdot
.98888 .97045 Mdot
.26111 .41349 Mdot
.29166 .90376 Mdot
.07353 .3613 Mdot
.1191 .65409 Mdot
.99649 .63844 Mdot
.11402 .99038 Mdot
.78531 .07908 Mdot
.5861 .2486 Mdot
.00866 .84987 Mdot
.34424 .90431 Mdot
.2727 .96554 Mdot
.89616 .68868 Mdot
.45 .70445 Mdot
.23172 .09041 Mdot
.48745 .47573 Mdot
.46671 .25866 Mdot
.17607 .6612 Mdot
.01048 .5738 Mdot
.8523 .55622 Mdot
.84636 .17982 Mdot
.50779 .02692 Mdot
.43287 .78393 Mdot
.89988 .51425 Mdot
.83988 .71738 Mdot
.55909 .23927 Mdot
.2217 .88609 Mdot
.18307 .5117 Mdot
.43761 .70337 Mdot
.57624 .59802 Mdot
.52173 .53303 Mdot
.42742 .30016 Mdot
.1769 .52246 Mdot
.00119 .19463 Mdot
.73487 .21586 Mdot
.20065 .87004 Mdot
.89865 .46364 Mdot
.34542 .80071 Mdot
.50335 .82948 Mdot
.98394 .9987 Mdot
.63231 .58221 Mdot
.60626 .61102 Mdot
.70829 .89723 Mdot
.34813 .70451 Mdot
.57711 .69944 Mdot
.22633 .0635 Mdot
.97326 .7404 Mdot
.31482 .06159 Mdot
.82975 .719 Mdot
.57302 .68282 Mdot
.14568 .80976 Mdot
.69315 .8842 Mdot
.44066 .33932 Mdot
.32313 .50846 Mdot
.5486 .08038 Mdot
.33573 .87659 Mdot
.32305 .3003 Mdot
.4536 .7006 Mdot
.92388 .71289 Mdot
.61766 .02239 Mdot
.60524 .64275 Mdot
.78006 .761 Mdot
.54693 .57959 Mdot
.37278 .32824 Mdot
.06702 .26019 Mdot
.03617 .34053 Mdot
.1152 .33342 Mdot
.75557 .75087 Mdot
.87627 .16078 Mdot
.74526 .73362 Mdot
.31937 .28612 Mdot
.66112 .27952 Mdot
.67463 .11972 Mdot
.95812 .32788 Mdot
.70798 .58085 Mdot
.28965 .50082 Mdot
.50423 .97083 Mdot
.29957 .30526 Mdot
.59677 .775 Mdot
.12558 .20378 Mdot
.73534 .66848 Mdot
.73905 .82413 Mdot
.54213 .09201 Mdot
.36494 .52968 Mdot
.22957 .10808 Mdot
.06661 .38729 Mdot
.09056 .52531 Mdot
.19111 .30306 Mdot
.61769 .98794 Mdot
.91313 .99887 Mdot
.87252 .2683 Mdot
.85249 .12824 Mdot
.33982 .28734 Mdot
.57569 .49266 Mdot
.17402 .7352 Mdot
.66556 .66933 Mdot
.86931 .16383 Mdot
.97884 .83603 Mdot
.71993 .68371 Mdot
.72415 .6342 Mdot
.57589 .36176 Mdot
.94856 .16006 Mdot
.87623 .03137 Mdot
.49929 .93271 Mdot
.20647 .45528 Mdot
.80259 .80476 Mdot
.39241 .38186 Mdot
.19485 .05059 Mdot
.92506 .33158 Mdot
.64822 .14569 Mdot
.79742 .84337 Mdot
.28016 .67563 Mdot
.77483 .45011 Mdot
.25956 .37428 Mdot
.39418 .42302 Mdot
.81022 .72145 Mdot
.99364 .24543 Mdot
.21207 .4405 Mdot
.691 .41209 Mdot
.51598 .98452 Mdot
.14354 .31986 Mdot
.59598 .94271 Mdot
.09722 .05747 Mdot
.9922 .79544 Mdot
.03321 .01082 Mdot
.01623 .43656 Mdot
.67425 .94182 Mdot
.59806 .20526 Mdot
.61388 .40417 Mdot
.26705 .53827 Mdot
.18892 .02909 Mdot
.52694 .07608 Mdot
.24691 .88776 Mdot
.46524 .2308 Mdot
.55856 .04903 Mdot
.11543 .80039 Mdot
.03078 .02217 Mdot
.4455 .11777 Mdot
.57519 .81053 Mdot
.51262 .15729 Mdot
.34793 .14604 Mdot
.84526 .25207 Mdot
.70885 .07494 Mdot
.63112 .66464 Mdot
.35295 .81204 Mdot
.25914 .63309 Mdot
.71802 .41549 Mdot
.06902 .63621 Mdot
.16559 .02928 Mdot
.11886 .67189 Mdot
.52423 .81083 Mdot
.85786 .84509 Mdot
.66007 .18889 Mdot
.65068 .34593 Mdot
.98279 .05595 Mdot
.62344 .06592 Mdot
.06014 .37742 Mdot
.81396 .68853 Mdot
.11039 .23872 Mdot
.71805 .91659 Mdot
.80267 .36561 Mdot
.92611 .14587 Mdot
.36852 .75831 Mdot
.87655 .17627 Mdot
.10664 .61407 Mdot
.9643 .14603 Mdot
.77254 .51792 Mdot
.21909 .22897 Mdot
.32902 .27099 Mdot
.65026 .4616 Mdot
.58796 .09129 Mdot
.0203 .71245 Mdot
.48429 .03032 Mdot
.21798 .10718 Mdot
.01279 .42871 Mdot
.63903 .72521 Mdot
.88533 .16645 Mdot
.58041 .10263 Mdot
.57914 .91633 Mdot
.94059 .57677 Mdot
.72708 .48342 Mdot
.92688 .5624 Mdot
.60091 .92517 Mdot
.50374 .8996 Mdot
.7167 .01794 Mdot
.36041 .66566 Mdot
.0266 .14763 Mdot
.67104 .19926 Mdot
.20631 .4483 Mdot
.27962 .21989 Mdot
.53117 .49498 Mdot
.13716 .70763 Mdot
.43289 .6415 Mdot
.13746 .18556 Mdot
.549 .95673 Mdot
.92963 .62276 Mdot
.76573 .26296 Mdot
.19541 .55697 Mdot
.52526 .25065 Mdot
.5822 .14181 Mdot
.61246 .39014 Mdot
.00166 .49355 Mdot
.24943 .5777 Mdot
.58848 .23349 Mdot
.24233 .41795 Mdot
.89519 .8266 Mdot
.55323 .69428 Mdot
.99067 .58482 Mdot
.4622 .96161 Mdot
.74774 .52173 Mdot
.05319 .27908 Mdot
.32733 .43771 Mdot
.3045 .47917 Mdot
.02298 .54052 Mdot
.99549 .02335 Mdot
.14724 .96775 Mdot
.41351 .72746 Mdot
.10791 .25731 Mdot
.67431 .19358 Mdot
.70784 .32375 Mdot
.908 .45693 Mdot
.02815 .48661 Mdot
.10905 .89225 Mdot
.62003 .56144 Mdot
.65825 .00548 Mdot
.1874 .59443 Mdot
.49472 .1504 Mdot
.64668 .42814 Mdot
.97043 .73894 Mdot
.88357 .02024 Mdot
.95809 .7923 Mdot
.14127 .47528 Mdot
.76899 .94118 Mdot
.56403 .47521 Mdot
.95433 .98027 Mdot
.57328 .45638 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool00oooool2o`0000Sooooo00?o0000ooooooooool00_ooool2o`0000Wo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool01?l0003oooooo`000?l0000<ooooo`03o`000?oooooooooo
00gooooo0_l00002ooooo`;o00002oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00Cooooo0_l00007ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool2o`00
0003ooooool0003ooooo00?ooooo000Nooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool00_l000000ooooooo0000o`000008ooooo`03o`000?oooooooooo00;ooooo0_l00009ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool02Oooool2o`0000;ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`04o`000?oooooo0000o`0000cooooo00?o0000oooo
ooooool03Oooool2o`0000;ooooo0_l0000;ooooo`04o`000?oooooo0000o`0000cooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;
ooooo`;o000000?oooooo`000?ooool00oooool001kooooo00?o0000ooooooooool01?ooool2o`00
00[ooooo0_l0000hooooo`;o0000Q_ooool2o`00017ooooo0_l00015ooooo`;o00004Oooool2o`00
00Kooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l000000ooooooo0000o`00001Vooooo`;o
00007Oooool2o`0005Gooooo0_l0000Tooooo`;o00005?ooool2o`0000Wooooo0_l0000Iooooo`00
7_ooool00ol0003oooooooooo`07ooooo`;o0000I_ooool2o`0001gooooo0_l0000Fooooo`;o0000
;?ooool2o`00033ooooo0_l00003ooooo`;o00005?ooool2o`0002Cooooo000Nooooo`03o`000?oo
oooooooo0:Kooooo0_l0000Fooooo`;o00005?ooool2o`0000oooooo0_l0000Iooooo`;o000000Co
ooooo`000?l0003ooooo0_l00003ooooo`;o0000;oooool2o`0000Wooooo000Nooooo`03o`000?oo
oooooooo00Kooooo0_l0000iooooo`;o0000G_ooool4o`0001Wooooo0_l00005ooooo`;o00007_oo
ool2o`0001Wooooo0_l000000ooooooo0000o`00000Fooooo`;o00007oooool2o`0000Wooooo000N
ooooo`03o`000?oooooooooo00Gooooo0ol0000iooooo`;o0000G_ooool6o`0001kooooo0_l0001D
ooooo`;o00008oooool2o`0000Gooooo000Nooooo`03o`000?oooooooooo00Gooooo0_l0000Zoooo
o`;o00001_ooool2o`0005gooooo0_l00007ooooo`;o00000_ooool2o`00033ooooo0_l0000Poooo
o`;o00005?ooool2o`0002oooooo0_l00005ooooo`007_ooool3o`00037ooooo0ol00005ooooo`;o
0000GOooool3o`0000Kooooo0_l0000dooooo`;o00008?ooool2o`0000Gooooo1Ol0000:ooooo`;o
00002?ooool2o`0002cooooo000Nooooo`?o0000<_ooool2o`0003cooooo0_l0000Wooooo`;o0000
7_ooool2o`0004Gooooo1Ol0000Dooooo`;o00001Oooool2o`0000kooooo0_l0000Eooooo`007_oo
ool00ol0003oooooooooo`17ooooo`;o00009oooool2o`0004Oooooo0_l0001Uooooo`;o00003_oo
ool2o`0001Gooooo000Nooooo`03o`000?oooooooooo04Oooooo0_l0000Oooooo`;o0000Coooool2
o`0003_ooooo0_l0001?ooooo`007_ooool00ol0003oooooooooo`1Xooooo`;o0000Coooool2o`00
02?ooooo0_l00009ooooo`;o00002oooool2o`0004oooooo000Nooooo`03o`000?oooooooooo06co
oooo0_l0000Dooooo`;o0000<Oooool2o`0001Gooooo0_l0000@ooooo`;o00002Oooool2o`0005co
oooo000Nooooo`03o`000?oooooooooo03_ooooo0_l0000_ooooo`;o00005?ooool2o`0002gooooo
0_l00002ooooo`;o00005Oooool2o`0007Wooooo000Nooooo`;o0000??ooool2o`0003Sooooo0_l0
000jooooo`;o0000U?ooool001kooooo00?o0000ooooooooool0MOooool2o`00017ooooo0_l0000N
ooooo`;o0000@?ooool2o`0004oooooo0_l0000:ooooo`007_ooool3o`0001_ooooo0_l0001Xoooo
o`;o000000?oooooo`000?l000007Oooool3o`00043ooooo0_l0001?ooooo`;o00002_ooool001ko
oooo0ol0000Hooooo`;o000000?oooooo`000?l00000AOooool2o`0000kooooo0_l0000Aooooo`;o
00008?ooool2o`0003cooooo0_l0000Tooooo`;o0000>_ooool001kooooo00?o0000ooooooooool0
6?ooool2o`000003ooooool0003o000002Sooooo0_l0000Kooooo`;o00003_ooool2o`0005?ooooo
0_l0000Looooo`;o00009?ooool2o`0001Cooooo0_l00003ooooo`;o00002oooool2o`0001;ooooo
000Nooooo`03o`000?oooooooooo01_ooooo0_l0000Xooooo`;o0000??ooool2o`0001?ooooo0_l0
000]ooooo`;o00007Oooool4o`0003Oooooo0_l00003ooooo`;o00002oooool2o`0001;ooooo000N
ooooo`03o`000?oooooooooo08?ooooo0_l0000Cooooo`;o0000C?ooool4o`0001Gooooo0_l00016
ooooo`007_ooool00ol0003oooooooooo`1fooooo`;o000000?oooooo`000?l00000Ioooool2o`00
01[ooooo0ol00016ooooo`007_ooool00ol0003oooooooooo`1fooooo`;o000000?oooooo`000?l0
0000;?ooool2o`0003Wooooo0_l0000Jooooo`;o0000Aoooool001kooooo00?o0000ooooooooool0
Toooool2o`0001;ooooo0_l00005ooooo`;o0000Boooool2o`0004[ooooo000Nooooo`03o`000?oo
oooooooo09?ooooo0_l0000Iooooo`;o00002_ooool2o`0003oooooo0_l0001:ooooo`007_ooool0
0ol0003oooooooooo`2jooooo`;o0000Roooool001kooooo00?o0000ooooooooool0Aoooool2o`00
09oooooo0_l0001Mooooo`007_ooool00ol0003oooooooooo`09ooooo`;o0000??ooool2o`0000_o
oooo0_l0001Fooooo`;o00003Oooool2o`0002_ooooo0_l0001Mooooo`007_ooool00ol0003ooooo
ooooo`09ooooo`;o0000BOooool2o`00017ooooo0_l00013ooooo`;o00003?ooool3o`000003oooo
ool0003o000002Gooooo0_l0001Pooooo`007_ooool00ol0003oooooooooo`1Wooooo`;o00005ooo
ool2o`0001Oooooo0_l0000Oooooo`;o00000_ooool2o`0002Gooooo0_l0000>ooooo`;o0000>?oo
ool2o`0001Kooooo000Nooooo`;o0000POooool2o`0001Oooooo0_l0000Nooooo`;o0000>_ooool2
o`0003Sooooo0_l0000Fooooo`007_ooool00ol0003oooooooooo`0oooooo`;o0000N?ooool2o`00
06oooooo0_l0000Kooooo`007_ooool00ol0003oooooooooo`0Aooooo`;o0000;?ooool2o`0000;o
oooo0_l00002ooooo`;o0000<Oooool2o`0008Sooooo0_l0000Tooooo`;o00006oooool001kooooo
00?o0000ooooooooool04Oooool2o`0001Gooooo0_l0000Iooooo`;o00000_ooool2o`00037ooooo
0_l00028ooooo`;o0000@Oooool001kooooo00?o0000ooooooooool0:?ooool2o`0002;ooooo0_l0
000Tooooo`;o00006?ooool2o`000;Wooooo000Nooooo`03o`000?oooooooooo04cooooo0_l0000T
ooooo`;o00006?ooool3o`000;Sooooo000Nooooo`03o`000?oooooooooo08gooooo0_l0000noooo
o`;o00002?ooool2o`0001;ooooo0_l0000Hooooo`;o00001oooool2o`0003Oooooo000Nooooo`03
o`000?oooooooooo01Oooooo0_l0001<ooooo`;o0000@Oooool2o`0002?ooooo0_l00005ooooo`;o
000000?oooooo`000?l000004_ooool2o`0001Sooooo0_l00007ooooo`;o00006?ooool2o`0001go
oooo000Nooooo`04o`000?ooooooooooooooo`;o00005?ooool2o`0004cooooo0_l00011ooooo`;o
0000:_ooool2o`0005;ooooo0_l00002ooooo`;o00006Oooool001kooooo00Co0000oooooooooooo
oooo0_l00032ooooo`;o0000B_ooool2o`0001Wooooo0_l0000>ooooo`;o00002Oooool001kooooo
00?o0000ooooooooool05oooool2o`0001;ooooo0_l0001Iooooo`;o00001_ooool2o`0003Gooooo
0_l0001:ooooo`;o0000:Oooool2o`0000Wooooo000Nooooo`03o`000?oooooooooo01Oooooo0_l0
000Booooo`;o00009Oooool2o`0000gooooo0_l0000Sooooo`;o00001_ooool2o`00017ooooo0_l0
0002ooooo`;o0000M?ooool2o`0002[ooooo000Nooooo`03o`000?oooooooooo05;ooooo0_l0000=
ooooo`;o00004Oooool2o`0002_ooooo0_l00002ooooo`;o0000M?ooool2o`0002[ooooo000Noooo
o`03o`000?oooooooooo047ooooo0_l0000aooooo`;o0000@oooool2o`0008cooooo000Nooooo`03
o`000?oooooooooo047ooooo0_l0001fooooo`;o00000oooool2o`0000oooooo0_l0001Hooooo`;o
00007?ooool001kooooo00?o0000ooooooooool01Oooool2o`0006Kooooo0_l0001?ooooo`;o0000
2?ooool2o`0000Gooooo0_l0000Cooooo`;o00007?ooool2o`0002Gooooo0_l0000:ooooo`;o0000
4?ooool001kooooo0_l00006ooooo`;o00003oooool2o`0005Gooooo0_l0000^ooooo`;o0000:Ooo
ool2o`0001[ooooo0_l0000Looooo`;o0000<Oooool2o`00013ooooo000Nooooo`03o`000?oooooo
oooo01Kooooo0_l00025ooooo`;o00005oooool2o`0007Kooooo0_l0000Gooooo`007_ooool00ol0
003oooooooooo`2Sooooo`;o00004Oooool2o`0000[ooooo0_l0001Zooooo`;o00001_ooool2o`00
00Kooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`2Sooooo`;o00007Oooool2o`00023o
oooo0_l0000cooooo`;o00005Oooool2o`0000Cooooo0_l00006ooooo`;o00001oooool001kooooo
00?o0000ooooooooool0b?ooool2o`0001[ooooo0_l0000aooooo`Co00005Oooool2o`0001Gooooo
000Nooooo`03o`000?oooooooooo09cooooo0_l0000Zooooo`;o0000COooool2o`0000?ooooo0_l0
000Yooooo`007_ooool00ol0003oooooooooo`0mooooo`;o0000GOooool2o`0007kooooo0_l0000Y
ooooo`007_ooool00ol0003oooooooooo`0mooooo`;o0000M?ooool2o`0009;ooooo000Nooooo`03
o`000?oooooooooo0;?ooooo0_l0000iooooo`;o0000:Oooool2o`0002cooooo000Nooooo`03o`00
0?oooooooooo03cooooo0_l0001=ooooo`;o0000HOooool2o`0001oooooo0_l00008ooooo`;o0000
9?ooool2o`0000Kooooo000Nooooo`03o`000?oooooooooo03cooooo0_l0000jooooo`;o00004Ooo
ool2o`0008;ooooo0_l0000^ooooo`;o00001_ooool001kooooo00?o0000ooooooooool0:Oooool2
o`0004Wooooo0_l00002ooooo`;o0000Ooooool4o`0003Cooooo0_l0000Dooooo`007_ooool00ol0
003oooooooooo`0Yooooo`;o00007_ooool2o`0002Wooooo0_l0001Looooo`;o00009Oooool4o`00
02?ooooo0_l0000?ooooo`;o00005?ooool001kooooo00?o0000ooooooooool0BOooool2o`00017o
oooo0_l0000Jooooo`;o0000>?ooool2o`0001kooooo0_l0000Kooooo`;o0000;oooool2o`0002Go
oooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00005ooooo`;o
0000G_ooool2o`0000kooooo0_l0000:ooooo`;o0000>?ooool2o`0002?ooooo0_l0000Fooooo`;o
00009?ooool2o`00033ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o0000HOooool2o`0000_ooooo0_l0001Voooo
o`;o000000?oooooo`000?l000005_ooool2o`0002Cooooo0_l0000`ooooo`000oooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool3o`0005oooooo0_l0001coooo
o`Co00006Oooool2o`0005Cooooo0003ooooo`05o`000?ooooooooooooooool000003Oooool00onH
V9So8B4Qonk^kP06ooooo`03o`000?oooooooooo02Gooooo0_l0001Oooooo`;o0000;?ooool2o`00
023ooooo0_l0000Iooooo`;o00002?ooool2o`0001_ooooo0_l0000]ooooo`000oooool01Ol0003o
oooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`0Uoooo
o`;o0000@?ooool2o`0001gooooo0_l0000/ooooo`;o00002?ooool2o`0003_ooooo0_l0000Koooo
o`;o0000;Oooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0Ioooool2o`0005Gooooo0_l00027ooooo`000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooo
oooo09Gooooo0_l0002`ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo07gooooo0_l0000Fooooo`;o0000E?oo
ool2o`0002;ooooo0_l0000fooooo`007_ooool00ol0003oooooooooo`0Rooooo`;o00003Oooool2
o`0002Sooooo0_l0000Pooooo`;o0000@_ooool2o`0002Sooooo0_l0000Rooooo`;o00002?ooool2
o`0002cooooo000Nooooo`03o`000?oooooooooo02;ooooo0_l0000=ooooo`;o00009?ooool2o`00
00;ooooo0_l0001Tooooo`;o00006Oooool2o`0000Cooooo0_l0000eooooo`;o0000;?ooool001ko
oooo00?o0000ooooooooool0Eoooool2o`0000Wooooo0_l0001hooooo`;o00001?ooool2o`0006?o
oooo000Nooooo`03o`000?oooooooooo04?ooooo0_l0000Mooooo`;o0000F_ooool2o`0007kooooo
0_l00007ooooo`007_ooool00ol0003oooooooooo`0cooooo`;o00003_ooool2o`0004kooooo0_l0
000Yooooo`;o00005Oooool2o`0006Oooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`0B
ooooo`;o00007oooool2o`0000?ooooo0_l0001Iooooo`;o00009_ooool2o`0001Sooooo0_l0001`
ooooo`007_ooool3o`0001;ooooo0_l0000Tooooo`;o0000POooool2o`0008[ooooo000Nooooo`?o
00008?ooool2o`00093ooooo0_l0000]ooooo`;o0000I?ooool001kooooo00?o0000ooooooooool0
8?ooool2o`00067ooooo0_l0000]ooooo`;o0000;Oooool2o`0004Wooooo0_l0000Iooooo`007_oo
ool00ol0003oooooooooo`23ooooo`;o0000<oooool2o`0007;ooooo0_l0000Aooooo`;o00001_oo
ool001kooooo00?o0000ooooooooool0Z_ooool2o`0000cooooo1?l0000;ooooo`;o0000M_ooool2
o`0000Kooooo000Nooooo`;o0000R_ooool2o`0001cooooo0_l000000ooooooo0000o`00000>oooo
o`;o00002oooool2o`0004Kooooo0_l0000fooooo`007_ooool00ol0003oooooooooo`1Yooooo`;o
00007_ooool2o`0001cooooo0_l0001Vooooo`;o00001Oooool2o`0002oooooo000Nooooo`03o`00
0?oooooooooo00[ooooo0_l0000Cooooo`;o0000B?ooool2o`0002Wooooo0_l0000Sooooo`;o0000
Foooool2o`0002oooooo000Nooooo`03o`000?oooooooooo00[ooooo0_l00006ooooo`;o00002ooo
ool2o`0007?ooooo0_l0000Sooooo`Co0000R_ooool001kooooo00?o0000ooooooooool04_ooool2
o`000:Oooooo0_l0000hooooo`;o00006?ooool2o`0003Kooooo000Nooooo`03o`000?oooooooooo
0;3ooooo0_l00013ooooo`;o00003?ooool2o`0000Sooooo1?l00007ooooo`;o0000;Oooool001ko
oooo00?o0000ooooooooool01oooool2o`0005kooooo0_l0000aooooo`;o00005?ooool2o`00057o
oooo0_l00008ooooo`;o00002Oooool2o`0002gooooo000Nooooo`03o`000?oooooooooo00Oooooo
0_l0001Aooooo`;o00002oooool2o`00037ooooo0_l0002[ooooo`007_ooool00ol0003ooooooooo
o`1Jooooo`;o00002?ooool2o`0002Wooooo0_l00003ooooo`;o0000@Oooool2o`0002Kooooo0_l0
0016ooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o0000EOooool2o`0002Wooooo0_l00003
ooooo`;o0000=_ooool2o`0000Gooooo0_l00002ooooo`;o00002?ooool2o`0001cooooo0_l00016
ooooo`007_ooool00ol0003oooooooooo`0=ooooo`;o0000_Oooool2o`0000Gooooo0_l0000<oooo
o`;o0000I?ooool001kooooo00?o0000ooooooooool0I?ooool2o`0000Cooooo0_l0001@ooooo`;o
0000@_ooool2o`0004Gooooo000Nooooo`03o`000?oooooooooo06Cooooo0_l00004ooooo`;o0000
0_ooool2o`0004cooooo0_l0000^ooooo`;o00004_ooool2o`0000Wooooo0_l0000jooooo`007_oo
ool00ol0003oooooooooo`1^ooooo`;o0000Eoooool2o`0002?ooooo0_l0000;ooooo`;o00004?oo
ool2o`0003[ooooo000Nooooo`03o`000?oooooooooo09[ooooo0_l0000[ooooo`;o0000:oooool2
o`0000?ooooo0_l0000Xooooo`;o00008_ooool001kooooo00?o0000ooooooooool0V_ooool2o`00
05Sooooo0_l0000]ooooo`;o00008_ooool001kooooo0_l0001Vooooo`;o00008?ooool2o`0000;o
oooo0_l0002jooooo`007_ooool00ol0003oooooooooo`0jooooo`;o00008Oooool2o`0000Kooooo
0_l0000Oooooo`?o00000_ooool2o`0006?ooooo0_l0000Looooo`;o0000=oooool001kooooo00?o
0000ooooooooool0>_ooool2o`00027ooooo0_l0000Wooooo`;o0000EOooool2o`00017ooooo0_l0
000Looooo`;o0000=oooool001kooooo00?o0000ooooooooool0gOooool2o`0006Sooooo000Noooo
o`03o`000?oooooooooo04_ooooo0_l0000Qooooo`;o0000`?ooool2o`0001Gooooo000Nooooo`03
o`000?oooooooooo04_ooooo0_l0000Looooo`;o00000oooool2o`0001[ooooo0_l0001Jooooo`;o
0000B?ooool2o`0001Gooooo000Nooooo`03o`000?oooooooooo02_ooooo0_l0000looooo`;o0000
7oooool2o`0005[ooooo0_l0001Oooooo`007_ooool00ol0003oooooooooo`0[ooooo`;o0000]Ooo
ool2o`0001Cooooo0_l0000_ooooo`;o00007?ooool001kooooo00?o0000ooooooooool07_ooool2
o`0000?ooooo0_l0000jooooo`;o0000:Oooool2o`0005Kooooo0_l0000Dooooo`;o0000;oooool3
o`0001_ooooo000Nooooo`04o`000?oooooo0000o`0001gooooo0_l00003ooooo`;o00002_ooool2
o`0002kooooo0_l0000Dooooo`;o00004oooool2o`0006gooooo0_l0000_ooooo`;o00001oooool2
o`0001;ooooo000Nooooo`04o`000?oooooo0000o`00023ooooo0_l0000<ooooo`;o00008_ooool2
o`00023ooooo0_l0001]ooooo`;o00004oooool2o`0002kooooo0_l000000ooooooo0000o`000005
ooooo`;o00004_ooool001kooooo00?o0000ooooooooool08Oooool2o`00033ooooo0_l0000Joooo
o`;o0000Loooool2o`0001gooooo0_l0000Tooooo`;o000000?oooooo`000?l000006Oooool001ko
oooo00?o0000ooooooooool0Koooool2o`0000?ooooo0_l0000Eooooo`;o0000L?ooool2o`0000Co
oooo0_l00012ooooo`007_ooool00ol0003oooooooooo`08ooooo`;o0000Coooool2o`0001Wooooo
0_l0000Eooooo`;o0000L?ooool3o`0004Oooooo000Nooooo`03o`000?oooooooooo00;o00001_oo
ool2o`0000oooooo0_l0000`ooooo`;o00003?ooool2o`0003Gooooo0_l0001/ooooo`;o0000Aooo
ool001kooooo00?o0000ooooooooool00_l00004ooooo`;o00004Oooool2o`0001?ooooo0_l0000K
ooooo`;o00009?ooool2o`0001gooooo0_l0000mooooo`;o0000M_ooool001kooooo0_l00007oooo
o`;o00009_ooool2o`00047ooooo0_l0000`ooooo`;o00004Oooool2o`0001Oooooo0_l0001Koooo
o`;o00006Oooool001kooooo00?o0000ooooooooool0@_ooool2o`0005oooooo0_l0000Aooooo`;o
0000M?ooool2o`0001Wooooo000Nooooo`03o`000?oooooooooo04;ooooo0_l0000mooooo`;o0000
00?oooooo`000?l00000Poooool2o`0000gooooo0_l0000Qooooo`;o00002_ooool001kooooo00?o
0000ooooooooool05?ooool2o`0006_ooooo0_l000001?oooooo0000o`000?l00022ooooo`;o0000
3Oooool2o`00027ooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`0>ooooo`;o00001?oo
ool2o`0006oooooo0_l0000`ooooo`;o0000A?ooool2o`0004Sooooo000Nooooo`03o`000?oooooo
oooo00kooooo0_l0000Kooooo`;o0000R_ooool2o`0004Cooooo0_l00002ooooo`;o0000A?ooool0
01kooooo00?o0000ooooooooool0:oooool2o`000=Cooooo0_l00014ooooo`007_ooool00ol0003o
ooooooooo`2^ooooo`;o0000Koooool2o`0002Kooooo000Nooooo`03o`000?oooooooooo053ooooo
0_l0001Looooo`;o0000;?ooool2o`0003oooooo1?l0000Eooooo`;o00003oooool001kooooo00?o
0000ooooooooool03oooool2o`0003oooooo0_l0002:ooooo`;o0000?oooool2o`0001Oooooo0_l0
000?ooooo`007_ooool00ol0003oooooooooo`0?ooooo`;o0000J_ooool2o`0005Gooooo0_l0001c
ooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o00004?ooool2o`0002kooooo0_l0000Hoooo
o`;o0000<oooool2o`00023ooooo0_l0000Hooooo`;o0000FOooool001kooooo00?o0000oooooooo
ool04_ooool2o`0000_ooooo0_l0000@ooooo`;o00000oooool2o`0002Wooooo0_l0000aooooo`;o
00004Oooool2o`0000Oooooo0_l0000jooooo`;o0000FOooool001kooooo00?o0000ooooooooool0
4_ooool2o`0002;ooooo0_l0001Looooo`;o00004Oooool2o`0001[ooooo0_l0001^ooooo`;o0000
4_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@
4?oooooooooo00Cooooo00?o0000ooooooooool0`oooool2o`0006kooooo0_l0000Booooo`000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolYooooo`;o00007Oooool000?ooooo00Go410@oooooooooooooooo
oa0@400;ooooo`Go00001_ooool3o`0001Wooooo0_l0001cooooo`;o00008oooool2o`0007?ooooo
0_l0000Mooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo
00001oooool00ol0003oooooooooo`0Iooooo`;o00007oooool2o`0000Cooooo0_l0000Hooooo`;o
0000<_ooool2o`0002?ooooo0_l0000>ooooo`;o0000P_ooool000?ooooo00Go0000oooooooooooo
ooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0>_ooool2o`00
00Cooooo0_l0000Booooo`;o00001?ooool2o`0001Gooooo0_l00019ooooo`;o00001Oooool2o`00
00Oooooo0_l00008ooooo`;o0000;Oooool2o`00043ooooo0003ooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo02Oooooo0_l0000[oooo
o`;o00005?ooool2o`0000Gooooo0_l0000Gooooo`;o00008_ooool2o`0000cooooo0_l0000>oooo
o`;o00002?ooool2o`0002gooooo0_l00004ooooo`;o0000>_ooool000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool09oooool2o`00
01_ooooo0_l0000;ooooo`;o00005oooool2o`0001kooooo0_l0000Rooooo`;o0000;Oooool2o`00
02cooooo0_l0000jooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`00
0?ooool01_ooool00ol0003oooooooooo`12ooooo`Co00002oooool2o`0004?ooooo0_l00002oooo
o`;o00003_ooool2o`00037ooooo0_l00006ooooo`;o0000H?ooool001kooooo00?o0000oooooooo
ool0@_ooool2o`0000Oooooo0_l00019ooooo`;o00000_ooool2o`0000kooooo0_l0000iooooo`;o
0000H?ooool001kooooo00?o0000ooooooooool0;_ooool2o`0001_ooooo0_l0000Looooo`;o0000
g?ooool001kooooo00?o0000ooooooooool0;_ooool3o`0001cooooo0_l0000Jooooo`;o00003_oo
ool2o`000003ooooool0003o000004gooooo0_l0000?ooooo`;o0000JOooool001kooooo00?o0000
ooooooooool00_l0000]ooooo`;o00007?ooool2o`0002[ooooo0_l000000ooooooo0000o`00001=
ooooo`;o000000?oooooo`000?l000003?ooool2o`0006Wooooo000Nooooo`03o`000?oooooooooo
00;o0000c?ooool2o`0007Oooooo000Nooooo`03o`000?oooooooooo03oooooo0_l0002Cooooo`;o
0000E_ooool2o`0000Wooooo0_l0000>ooooo`007_ooool01?l0003oooooooooooooool2o`0003co
oooo0_l0000Uooooo`;o0000K?ooool2o`0005Kooooo0_l00009ooooo`;o00003_ooool001kooooo
00Co0000oooooooooooooooo0_l0000nooooo`;o00008oooool2o`0001Gooooo0_l00017ooooo`;o
0000EOooool2o`0002Sooooo000Nooooo`03o`000?oooooooooo047ooooo0_l0000jooooo`;o0000
Aoooool2o`0005Gooooo0_l0000Xooooo`007_ooool00ol0003oooooooooo`18ooooo`;o0000oOoo
ool001kooooo00?o0000ooooooooool0?oooool2o`0000Oooooo0_l0001Zooooo`;o00001Oooool2
o`0001Cooooo0_l0000Uooooo`;o0000@Oooool2o`0000[ooooo000Mooooo`?o0000@?ooool2o`00
07?ooooo0_l00005ooooo`;o00005?ooool2o`0002Gooooo0_l00011ooooo`;o00002_ooool001go
oooo0_l00011ooooo`;o0000FOooool2o`0000Kooooo0_l00006ooooo`;o00002_ooool2o`0001oo
oooo0_l00006ooooo`;o0000I_ooool001kooooo00?o0000ooooooooool08oooool2o`0001[ooooo
0_l0001Hooooo`?o00001_ooool2o`0000Kooooo0_l0000:ooooo`;o00007oooool2o`0000Kooooo
0_l00012ooooo`;o00008_ooool001kooooo00?o0000ooooooooool08oooool2o`0007Cooooo0_l0
000dooooo`;o00003_ooool2o`0004;ooooo0_l0000Rooooo`007_ooool00ol0003oooooooooo`3?
ooooo`;o00003_ooool2o`0003oooooo0_l0000Uooooo`007_ooool00ol0003oooooooooo`0@oooo
o`;o0000ooooool?ooooo`;o00009Oooool001kooooo00?o0000ooooooooool04?ooool2o`0008Ko
oooo0_l0000Mooooo`;o0000S_ooool001kooooo00?o0000ooooooooool0B?ooool2o`0004;ooooo
0_l0000:ooooo`;o00007Oooool2o`0002Kooooo0_l0001Mooooo`;o00001oooool001kooooo00?o
0000ooooooooool08Oooool2o`0000Oooooo0_l0000Looooo`;o0000@_ooool2o`0000cooooo0_l0
000Gooooo`;o0000:_ooool2o`0005gooooo0_l00007ooooo`007_ooool00ol0003oooooooooo`0Q
ooooo`;o00001oooool2o`0003?ooooo0_l0000iooooo`;o00005oooool2o`0002;ooooo0_l0000?
ooooo`;o0000GOooool001kooooo00?o0000ooooooooool0Goooool2o`0003Wooooo0_l0000koooo
o`;o00003oooool2o`00047ooooo0_l00009ooooo`;o00003oooool001kooooo00Co0000oooooooo
oooooooo0_l00002ooooo`;o0000=?ooool2o`0008_ooooo0_l0000Nooooo`;o00005?ooool2o`00
02_ooooo0_l00005ooooo`;o00000_ooool2o`0000oooooo000Nooooo`04o`000?oooooooooooooo
o`;o00000_ooool2o`0003Cooooo0_l0002;ooooo`;o0000=?ooool2o`0003;ooooo0_l0000Coooo
o`007Oooool2o`0003gooooo0_l0001jooooo`;o0000B?ooool2o`0003[ooooo0_l00008ooooo`00
7Oooool2o`000:_ooooo0_l0000<ooooo`;o0000B?ooool2o`0003[ooooo0_l00008ooooo`007_oo
ool00ol0003oooooooooo`1Qooooo`;o00001_ooool2o`0003kooooo0_l0002Looooo`007_ooool2
o`0003Kooooo0_l0000Sooooo`;o00001Oooool2o`0000Kooooo0_l0000Zooooo`;o0000Moooool2
o`0003Oooooo000Nooooo`03o`000?oooooooooo03Gooooo0_l0000Sooooo`;o0000>Oooool2o`00
07Oooooo0_l0000gooooo`007_ooool00ol0003oooooooooo`1Uooooo`;o0000h?ooool001kooooo
00?o0000ooooooooool02?ooool2o`0002gooooo0_l0000?ooooo`;o00006oooool2o`0002Oooooo
0_l0000`ooooo`?o0000HOooool2o`00027ooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0
000]ooooo`;o00003_ooool3o`00013ooooo0_l0000booooo`;o0000<?ooool3o`0005cooooo0ol0
0002ooooo`;o00008Oooool001kooooo00?o0000ooooooooool0@Oooool2o`0000Cooooo0_l0000A
ooooo`;o0000Voooool2o`0002Kooooo0ol0000Uooooo`007_ooool00ol0003oooooooooo`0joooo
o`;o00001Oooool2o`0001oooooo0_l00018ooooo`;o00006oooool2o`0002cooooo0_l0001>oooo
o`007_ooool00ol0003oooooooooo`0eooooo`;o00000oooool2o`0001cooooo0_l00008ooooo`;o
00006oooool2o`0002_ooooo0_l0000Kooooo`;o00003oooool2o`0001?ooooo0_l0001Fooooo`00
7_ooool00ol0003oooooooooo`0Iooooo`;o00001oooool2o`00017ooooo0_l0000Qooooo`;o0000
9Oooool2o`0000Gooooo0_l0001Booooo`;o00004oooool2o`0005Kooooo000Nooooo`03o`000?oo
oooooooo01Wooooo0_l00007ooooo`;o00004Oooool2o`0003cooooo0_l0000Aooooo`;o0000G_oo
ool2o`0005oooooo000Nooooo`03o`000?oooooooooo03Gooooo0_l0000looooo`;o0000<Oooool4
o`00033ooooo0_l0000:ooooo`;o0000Goooool001kooooo00?o0000ooooooooool0Goooool3o`00
00cooooo0_l0000fooooo`Co0000<?ooool2o`0006_ooooo000Nooooo`03o`000?oooooooooo05?o
oooo0_l0000:ooooo`?o00003?ooool2o`000:Cooooo0_l0000Vooooo`;o00002Oooool001kooooo
00?o0000ooooooooool00oooool2o`0000Sooooo0_l00004ooooo`;o0000?_ooool2o`0007Oooooo
0_l00016ooooo`;o00009_ooool2o`0000Wooooo000Nooooo`03o`000?oooooooooo00?ooooo0_l0
0008ooooo`;o00001?ooool2o`000;Oooooo0_l0001iooooo`007_ooool00ol0003oooooooooo`3>
ooooo`;o0000Moooool001kooooo0ol0001Cooooo`;o0000NOooool2o`0007Oooooo000Mooooo`Co
0000A?ooool2o`0000gooooo0_l000000ooooooo0000o`00001Nooooo`;o0000Soooool001gooooo
0_l0000mooooo`;o00001oooool2o`00013ooooo0_l0000Gooooo`;o0000AOooool2o`0002cooooo
0_l0000[ooooo`;o00004?ooool2o`0002;ooooo000Nooooo`03o`000?oooooooooo03_ooooo0_l0
000booooo`;o0000Loooool2o`0002_ooooo0_l0000@ooooo`;o00006oooool2o`0000Gooooo000N
ooooo`03o`000?oooooooooo03Gooooo0_l0001Gooooo`;o0000=Oooool2o`0006;ooooo0_l0000E
ooooo`;o00001Oooool001kooooo00?o0000ooooooooool0=Oooool2o`0000Kooooo0_l0001?oooo
o`;o0000=Oooool2o`0006;ooooo0_l00004ooooo`;o00005_ooool001kooooo00?o0000oooooooo
ool0?Oooool2o`000:Sooooo0_l00016ooooo`;o00005_ooool001kooooo00?o0000ooooooooool0
ioooool2o`0005kooooo000Nooooo`04o`000?oooooo0000o`000>oooooo0_l0000Mooooo`;o0000
=_ooool001kooooo00Co0000ooooool0003o0000;_ooool2o`0001cooooo0_l0001Oooooo`;o0000
@?ooool2o`0001gooooo0_l0000Mooooo`;o00005oooool001kooooo00?o0000ooooooooool0;ooo
ool2o`0001cooooo0_l0001Oooooo`;o00006Oooool2o`0001Oooooo0_l0001:ooooo`;o00005ooo
ool001kooooo00Co0000ooooool0003o0000:Oooool2o`0007Wooooo0_l0000Rooooo`;o00005ooo
ool2o`0005[ooooo0_l00007ooooo`007_ooool01?l0003oooooo`000?l0000Yooooo`;o0000NOoo
ool2o`0003kooooo0_l0001Gooooo`;o00001oooool001kooooo00?o0000ooooooooool00_l0003S
ooooo`;o00001?ooool2o`0003Kooooo1?l00007ooooo`;o00001_ooool2o`0000oooooo0003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<
c006ooooo`03o`000?oooooooooo00;o0000=oooool2o`000;3ooooo0_l0000fooooo`Co00001_oo
ool3o`0000Kooooo0_l0000?ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`05ooooo`;o0000
<_ooool2o`0007cooooo0_l0001dooooo`;o00006?ooool000?ooooo00Go410@oooooooooooooooo
oa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`0000Gooooo0_l0000Nooooo`;o
0000:_ooool2o`0006Cooooo0_l0001>ooooo`;o0000?_ooool000?ooooo00Go0000oooooooooooo
ooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0Uoooo
o`;o00005?ooool2o`0001Cooooo0_l0000;ooooo`;o00005oooool2o`0008kooooo0_l0000aoooo
o`;o00000oooool2o`0000Kooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0
003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0=_ooool2o`0000?ooooo0_l0000Q
ooooo`;o00005oooool4o`00033ooooo0_l0002=ooooo`;o00000oooool2o`0000Kooooo0003oooo
o`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooo
oooo01kooooo0_l0000Fooooo`;o0000<oooool2o`0000cooooo0_l0000`ooooo`;o00003?ooool2
o`0003;ooooo0_l0000booooo`;o00001oooool2o`0001Cooooo0_l00005ooooo`000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0N
ooooo`;o0000Boooool2o`0004cooooo0_l00006ooooo`;o0000:?ooool4o`0003;ooooo0_l00007
ooooo`;o00005?ooool2o`0000Gooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool0
1?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo01oooooo0_l0000Gooooo`;o0000H_oo
ool2o`0002?ooooo0_l0000Xooooo`;o0000F_ooool001kooooo00?o0000ooooooooool07oooool2
o`0000Kooooo0_l0000?ooooo`;o0000H_ooool2o`0009?ooooo0_l0000Dooooo`007_ooool00ol0
003oooooooooo`0Wooooo`;o0000Boooool2o`0008oooooo0_l0000Zooooo`?o00004oooool001ko
oooo00?o0000ooooooooool09Oooool2o`0004gooooo0_l0002?ooooo`;o00008oooool2o`0000Ko
oooo0_l00007ooooo`;o00002_ooool001kooooo00?o0000ooooooooool09Oooool2o`000?oooooo
1?ooool2o`0000oooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`3Oooooo`;o00002ooo
ool2o`00017ooooo0_l00016ooooo`007_ooool00ol0003oooooooooo`0Looooo`;o0000<_ooool2
o`0000Oooooo0_l00024ooooo`;o00001_ooool2o`0000?ooooo0_l0000Aooooo`;o0000A_ooool0
01kooooo00?o0000ooooooooool04_ooool2o`0000Sooooo0_l0000booooo`;o00001oooool2o`00
06Oooooo0_l0000Sooooo`;o0000G_ooool001kooooo00?o0000ooooooooool04_ooool2o`000:ko
oooo0_l0001looooo`;o00001Oooool001kooooo00?o0000ooooooooool02Oooool2o`0004Sooooo
0_l0000]ooooo`;o00001Oooool2o`0003Kooooo0_l0001;ooooo`;o0000:?ooool2o`0000Kooooo
0_l00005ooooo`007_ooool00ol0003oooooooooo`07ooooo`Co0000B?ooool2o`0002gooooo0_l0
0005ooooo`;o0000;Oooool2o`0000Oooooo0_l0001;ooooo`;o00003oooool2o`0001Oooooo0_l0
000=ooooo`007_ooool00ol0003oooooooooo`07ooooo`;o00009Oooool2o`0006?ooooo0_l0000S
ooooo`;o0000IOooool2o`0002Kooooo000Nooooo`;o0000;oooool2o`0003_ooooo0_l0000Voooo
o`;o0000K?ooool2o`0002Wooooo0_l0000Iooooo`007_ooool00ol0003oooooooooo`0Sooooo`;o
00002?ooool2o`0002?ooooo0_l0000Gooooo`;o00001oooool2o`0000Oooooo0_l00022ooooo`;o
0000:Oooool2o`0001Wooooo000Nooooo`03o`000?oooooooooo02?ooooo0_l00008ooooo`;o0000
8oooool2o`00023ooooo0_l00007ooooo`;o00000oooool2o`0005gooooo0_l0001Tooooo`007_oo
ool00ol0003oooooooooo`0eooooo`;o0000Boooool2o`0001kooooo0_l0000mooooo`;o0000I?oo
ool001kooooo00?o0000ooooooooool0=Oooool2o`0000Oooooo0_l0000aooooo`;o0000;oooool2
o`0002Gooooo0_l0001Vooooo`;o00005?ooool001kooooo00?o0000ooooooooool0?_ooool2o`00
037ooooo0ol0000?ooooo`;o0000?Oooool2o`0000Gooooo0_l0000Pooooo`;o0000A?ooool2o`00
01Cooooo000Nooooo`03o`000?oooooooooo02?ooooo0_l0001=ooooo`;o00003oooool2o`0003go
oooo0_l0000@ooooo`;o00005Oooool2o`0003gooooo0_l0000Kooooo`007_ooool00ol0003ooooo
ooooo`0Sooooo`;o0000ROooool2o`00027ooooo0_l000000ooooooo0000o`00001Dooooo`;o0000
6oooool001kooooo00?o0000ooooooooool0Eoooool2o`00013ooooo0_l00013ooooo`;o00008Ooo
ool2o`0003?ooooo0_l000001?oooooo0000o`000?ooool2o`0003Wooooo000Nooooo`03o`000?oo
oooooooo05Oooooo0_l0000@ooooo`;o0000:Oooool2o`00073ooooo0_l000001?oooooo0000o`00
0?ooool2o`0003Wooooo000Nooooo`03o`000?oooooooooo04Wooooo0_l00019ooooo`;o00008?oo
ool2o`0002kooooo0_l0001Oooooo`007_ooool00ol0003oooooooooo`0fooooo`;o00004Oooool2
o`0006_ooooo0_l0000^ooooo`;o00002?ooool2o`0005Gooooo000Nooooo`03o`000?oooooooooo
03Kooooo0_l0001Iooooo`;o0000GOooool2o`0001?ooooo0_l0000Hooooo`;o00009_ooool001ko
oooo00?o0000ooooooooool0F_ooool4o`0003?ooooo0_l0001booooo`;o00001Oooool2o`00017o
oooo0_l0000Vooooo`007_ooool00ol0003oooooooooo`0/ooooo`;o0000;?ooool4o`0000cooooo
0_l0000]ooooo`;o00005Oooool2o`0005[ooooo0_l0000Fooooo`;o00008Oooool001kooooo00?o
0000ooooooooool0;?ooool4o`0000_ooooo0_l0000>ooooo`;o00007Oooool2o`0000gooooo0_l0
000Nooooo`;o00005Oooool2o`0000Kooooo0_l0001Zooooo`;o00008Oooool001kooooo0_l0000_
ooooo`;o00002oooool2o`0000kooooo0_l0000Eooooo`;o00005Oooool2o`0001Cooooo0_l0000W
ooooo`;o0000SOooool001kooooo00?o0000ooooooooool0H_ooool2o`0000Wooooo0_l0000Koooo
o`;o00000_ooool3o`000;Kooooo000Nooooo`03o`000?oooooooooo02Sooooo0_l00013ooooo`;o
00006oooool2o`0000;ooooo0_l0002_ooooo`;o00001_ooool001kooooo00?o0000ooooooooool0
:?ooool2o`00013ooooo0_l0001Qooooo`;o00001oooool2o`0002gooooo0_l0001Xooooo`;o0000
1_ooool001kooooo00?o0000ooooooooool00_ooool2o`0003Kooooo0_l0001Qooooo`;o00001ooo
ool2o`0002gooooo0_l0001Aooooo`;o00007Oooool001kooooo00?o0000ooooooooool00_ooool2
o`0001kooooo0_l0000=ooooo`;o0000Woooool2o`0003Wooooo0_l0000Iooooo`;o00003oooool2
o`0000cooooo000Nooooo`03o`000?oooooooooo00kooooo0_l00006ooooo`;o00002_ooool2o`00
00gooooo0_l0001booooo`;o0000:oooool2o`0002[ooooo0_l0000:ooooo`;o000000?oooooo`00
0?l00000:_ooool2o`0000cooooo000Nooooo`03o`000?oooooooooo00kooooo0_l00006ooooo`;o
0000?Oooool2o`0001_ooooo0_l0000aooooo`;o0000Eoooool2o`0000?ooooo0_l00005ooooo`;o
00000oooool2o`0002[ooooo0_l0000:ooooo`007_ooool00ol0003oooooooooo`08ooooo`;o0000
Boooool2o`0001_ooooo0_l0000Zooooo`;o0000;?ooool2o`0003Gooooo0_l0000:ooooo`;o0000
:_ooool2o`0000[ooooo000Nooooo`03o`000?oooooooooo00Sooooo0_l0000]ooooo`;o0000=Ooo
ool2o`0001;ooooo0_l0000Cooooo`;o00001Oooool2o`0002_ooooo0ol0001iooooo`007_ooool0
0ol0003oooooooooo`0gooooo`;o0000=Oooool2o`0001;ooooo0_l00007ooooo`;o00002_ooool2
o`0003;ooooo0_l00006ooooo`;o0000L_ooool001kooooo00?o0000ooooooooool0=?ooool2o`00
05Gooooo0_l00016ooooo`;o00006Oooool2o`0002cooooo0_l0000Yooooo`007_ooool00ol0003o
ooooooooo`0dooooo`;o00007?ooool2o`0002?ooooo0_l0000fooooo`;o0000?Oooool2o`0002co
oooo0_l0000Iooooo`;o00003_ooool001kooooo00?o0000ooooooooool0=oooool2o`0001Wooooo
0_l0000Sooooo`;o0000=_ooool2o`0000_ooooo0_l0001iooooo`?o00003Oooool001kooooo00?o
0000ooooooooool0<_ooool2o`0000?ooooo0_l00023ooooo`;o0000N_ooool2o`0000gooooo000N
ooooo`03o`000?oooooooooo02?ooooo0_l0000=ooooo`;o0000a?ooool2o`0000cooooo0_l0000o
ooooo`007_ooool2o`0002Cooooo0_l000000ooooooo0000o`000007ooooo`;o0000`Oooool2o`00
00Cooooo0_l0000<ooooo`;o0000?oooool001kooooo00?o0000ooooooooool09_ooool2o`0000Oo
oooo0_l00010ooooo`;o0000Ooooool2o`0000Oooooo0_l0001:ooooo`007_ooool00ol0003ooooo
ooooo`0dooooo`;o0000>oooool2o`0006[ooooo0_l00004ooooo`;o00005_ooool2o`000003oooo
ool0003o000004Oooooo000Nooooo`03o`000?oooooooooo00kooooo0_l0000Tooooo`;o0000?_oo
ool2o`0003cooooo0_l0000?ooooo`;o00006?ooool2o`0000Cooooo0_l0000Dooooo`;o00000ooo
ool2o`0004Oooooo000Nooooo`03o`000?oooooooooo00kooooo0_l00013ooooo`;o00007oooool2
o`0003cooooo0_l0000?ooooo`;o0000=?ooool2o`0004cooooo000Nooooo`03o`000?oooooooooo
057ooooo1?l0001_ooooo`;o0000<Oooool2o`0004kooooo000Nooooo`03o`000?oooooooooo057o
oooo0_l0000Rooooo`;o0000COooool2o`00037ooooo0_l0000=ooooo`;o00008_ooool2o`0001_o
oooo000Nooooo`03o`000?oooooooooo01_ooooo0_l0001Hooooo`;o0000<_ooool2o`0005_ooooo
0_l0000Rooooo`;o00006oooool001kooooo00?o0000ooooooooool06oooool2o`00067ooooo0_l0
000Yooooo`;o00004oooool3o`0003Wooooo0_l0000:ooooo`;o0000>Oooool2o`0000Cooooo000N
ooooo`03o`000?oooooooooo00Wooooo0_l00004ooooo`;o0000;_ooool2o`0003gooooo0_l0000n
ooooo`?o0000>Oooool2o`0000[ooooo0_l0000iooooo`;o00001?ooool001kooooo0ol00009oooo
o`;o00001?ooool4o`0002Cooooo0_l00006ooooo`;o00007oooool2o`0001Cooooo0_l0000Woooo
o`;o0000>_ooool2o`0000cooooo0_l0001Looooo`007_ooool3o`00017ooooo0_l000000ooooooo
0000o`00000Qooooo`;o00009oooool2o`0001Cooooo0_l0000Aooooo`;o00005?ooool2o`0002Wo
oooo0_l0000?ooooo`;o00002_ooool4o`0005cooooo000Nooooo`03o`000?oooooooooo01Cooooo
0_l0000fooooo`;o0000:oooool2o`0000kooooo0_l0000mooooo`Co00002_ooool4o`0000gooooo
0_l0001Nooooo`007_ooool00ol0003oooooooooo`1<ooooo`;o0000:oooool2o`0003?ooooo0_l0
000Hooooo`;o00003?ooool4o`0006gooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0:kooooo
0_l0001gooooo`;o00002_ooool2o`0001;ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo00co
oooo0_l0003ooooooa[ooooo0ol00009ooooo`;o00002Oooool2o`0000Oooooo0003ooooo`05oa0@
4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0000<oooo
o`;o00003oooool2o`0000;ooooo0_l0000cooooo`;o00005?ooool2o`0005Cooooo0_l0000Roooo
o`;o00004Oooool2o`0002gooooo0_l0000Dooooo`;o00001oooool000?ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool00ol0003oooooooooo`03
ooooo`;o00006?ooool2o`0000;ooooo0_l0000cooooo`;o00005?ooool2o`0000Kooooo0_l0001<
ooooo`;o00008_ooool2o`00017ooooo0_l0001<ooooo`000oooool01Ol0003ooooooooooooooooo
000000_ooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`?o000000?oooooo`000?l000000_l0
000]ooooo`;o0000@?ooool2o`0002Sooooo0_l0000[ooooo`;o00002oooool2o`0002Oooooo0_l0
0014ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zj
oa0@4006ooooo`?o000000?oooooo`000?l00000:?ooool2o`0000Gooooo0_l0000`ooooo`;o0000
4?ooool2o`0002Kooooo0_l0000[ooooo`;o00002oooool2o`0000Wooooo0_l0000Looooo`;o0000
A?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l0
00001_ooool00ol0003oooooooooo`0=ooooo`;o00007?ooool2o`0003Oooooo0_l00009ooooo`;o
00001Oooool2o`0002kooooo0_l0000?ooooo`;o0000:_ooool2o`0006;ooooo0003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000oooo
ooooool03Oooool2o`0002cooooo0_l0000<ooooo`;o00002_ooool2o`0001Sooooo0_l0000eoooo
o`;o00003oooool2o`0003Gooooo1?l0000oooooo`;o00005?ooool001kooooo00?o0000oooooooo
ool0;_ooool2o`0000_ooooo0_l0000<ooooo`;o00002_ooool2o`0007cooooo0_l0000Iooooo`Co
0000=oooool2o`0000Kooooo0_l0000=ooooo`;o00001Oooool001kooooo00?o0000ooooooooool0
;_ooool2o`0008[ooooo0_l0000Gooooo`;o0000E?ooool2o`0000Wooooo0_l0000:ooooo`;o0000
1Oooool001kooooo00?o0000ooooooooool0COooool3o`0001;ooooo0_l00004ooooo`;o0000D?oo
ool2o`00033ooooo0_l00016ooooo`;o00004Oooool001kooooo00?o0000ooooooooool00_l00016
ooooo`;o00000oooool3o`0001;ooooo0_l00004ooooo`;o0000BOooool2o`0003Oooooo0_l0000O
ooooo`;o00004?ooool2o`0000_ooooo0_l0000Iooooo`007_ooool00ol0003oooooooooo`02o`00
01[ooooo0_l0000Zooooo`;o0000E_ooool2o`00017ooooo0_l0001Hooooo`;o00004?ooool2o`00
00_ooooo0_l0000Iooooo`007_ooool00ol0003oooooooooo`0Looooo`;o0000P_ooool2o`000:Go
oooo000Nooooo`03o`000?oooooooooo07?ooooo0_l0001Rooooo`;o00003?ooool2o`0005?ooooo
0_l0000;ooooo`007_ooool00ol0003oooooooooo`02ooooo`;o00001oooool2o`00033ooooo0_l0
000Gooooo`;o00006oooool2o`0006;ooooo0_l0000<ooooo`;o0000Doooool2o`0000_ooooo000N
ooooo`03o`000?oooooooooo00;ooooo0_l00007ooooo`;o0000<?ooool2o`0001Oooooo0_l0000?
ooooo`;o0000<oooool2o`0004Oooooo0_l0000Hooooo`;o0000A_ooool001kooooo00?o0000oooo
ooooool0Ioooool2o`0003?ooooo0_l0000Sooooo`;o00008_ooool2o`0001Sooooo0_l0000Boooo
o`;o0000<_ooool001kooooo00Co0000ooooool0003o00009?ooool2o`0009[ooooo0_l0001@oooo
o`;o0000<_ooool001kooooo1?l0000Tooooo`;o00004oooool2o`000:Cooooo0_l0001Uooooo`00
7_ooool00ol0003oooooooooo`0jooooo`;o0000H?ooool2o`0001;ooooo0_l0000^ooooo`;o0000
6oooool2o`0002oooooo0_l0000Gooooo`007_ooool00ol0003oooooooooo`1Vooooo`;o0000=?oo
ool2o`0001;ooooo0_l0001;ooooo`;o0000;oooool2o`0001Oooooo000Nooooo`03o`000?oooooo
oooo06Kooooo0_l0002Nooooo`;o00003Oooool2o`00033ooooo000Nooooo`03o`000?oooooooooo
0;cooooo0_l00018ooooo`;o00003Oooool2o`00033ooooo000Nooooo`03o`000?oooooooooo05Ko
oooo0_l0001;ooooo`;o00005oooool2o`0003?ooooo0_l0001Dooooo`007_ooool00ol0003ooooo
ooooo`0mooooo`;o00003oooool2o`0000Kooooo0_l0000oooooo`;o00001?ooool2o`0000Cooooo
0_l0001<ooooo`;o00000oooool2o`0004oooooo000Nooooo`03o`000?oooooooooo03gooooo0_l0
000?ooooo`;o0000Aoooool2o`0000Cooooo0_l0000jooooo`;o00006oooool2o`0004oooooo000N
ooooo`03o`000?oooooooooo06Wooooo0_l0001^ooooo`;o0000G?ooool2o`0000kooooo000Noooo
o`03o`000?oooooooooo06Wooooo0_l0003<ooooo`;o00003_ooool001kooooo00?o0000oooooooo
ool0AOooool2o`0002?ooooo0_l0002Sooooo`;o0000=_ooool001kooooo00?o0000ooooooooool0
4?ooool2o`0003;ooooo1?l0000Rooooo`;o0000C?ooool2o`000003ooooool0003o0000023ooooo
0_l0000`ooooo`;o0000=_ooool001kooooo00?o0000ooooooooool04?ooool2o`0003;ooooo1?l0
0004ooooo`;o00004_ooool2o`0000Sooooo0_l0001<ooooo`;o000000Coooooo`000?l0003o0000
7oooool2o`0003Kooooo0_l0000`ooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o00000_oo
ool2o`0002Gooooo1?l0000Booooo`;o00002?ooool2o`00053ooooo0_l0000Dooooo`;o00009ooo
ool2o`0001Sooooo0_l0000`ooooo`007_ooool00ol0003oooooooooo`0Oooooo`;o00000_ooool2
o`0002Gooooo0_l0000Iooooo`;o00007?ooool2o`00037ooooo0_l0000Jooooo`;o00009oooool2
o`0004[ooooo000Nooooo`03o`000?oooooooooo03cooooo0_l0000Uooooo`Co00007?ooool2o`00
037ooooo0_l0000Zooooo`;o0000Hoooool001kooooo0_l0000mooooo`;o00009Oooool2o`0003_o
oooo0_l0000hooooo`;o00001_ooool2o`0006?ooooo000Nooooo`03o`000?oooooooooo01;ooooo
0_l00017ooooo`;o00003oooool2o`0002;ooooo0_l000000ooooooo0000o`00000;ooooo`;o0000
>?ooool2o`0000[ooooo0_l00018ooooo`;o00005Oooool001kooooo00?o0000ooooooooool04_oo
ool2o`0001;ooooo0_l0000cooooo`;o00003oooool2o`0001Oooooo0_l00009ooooo`;o000000?o
ooooo`000?l00000>_ooool2o`0000Gooooo0_l0000>ooooo`;o0000B?ooool2o`0001Gooooo000N
ooooo`03o`000?oooooooooo02Kooooo0_l0000<ooooo`;o0000Coooool2o`0001Gooooo0_l0000a
ooooo`;o00001Oooool2o`0006oooooo000Nooooo`04o`000?ooooooooooooooo`;o00006oooool2
o`0001Cooooo0_l0001Vooooo`;o0000ZOooool001kooooo00Co0000oooooooooooooooo0_l0000K
ooooo`;o0000:oooool2o`0006_ooooo0_l0000;ooooo`;o00007_ooool2o`00063ooooo000Noooo
o`03o`000?oooooooooo04_ooooo0_l0000Iooooo`;o0000:oooool2o`0002?ooooo0_l0000;oooo
o`;o00007_ooool2o`0003[ooooo0_l0000Tooooo`007_ooool00ol0003oooooooooo`14ooooo`;o
00008?ooool2o`0000oooooo0_l0000Jooooo`;o0000Roooool3o`0001kooooo0_l00004ooooo`00
7_ooool00ol0003oooooooooo`0Mooooo`;o00009Oooool2o`00037ooooo0_l00016ooooo`;o0000
:?ooool2o`0002kooooo0_l00005ooooo`;o00007oooool2o`0000Cooooo000Nooooo`03o`000?oo
oooooooo01gooooo0_l0002Pooooo`;o00004oooool2o`0001?ooooo0_l0000^ooooo`;o0000;?oo
ool001kooooo00?o0000ooooooooool06Oooool2o`0008?ooooo0_l0000Uooooo`;o00003Oooool2
o`00077ooooo000Nooooo`03o`000?oooooooooo01Wooooo0_l0000Tooooo`;o0000GOooool2o`00
02Gooooo0_l00020ooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o00007Oooool2o`0002Co
oooo0_l0003Pooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o0000@oooool2o`0004Kooooo
0_l0000Xooooo`;o00007Oooool2o`0002?ooooo0_l0000Zooooo`007_ooool00ol0003ooooooooo
o`0gooooo`;o000000?oooooo`000?l00000Foooool2o`0001Cooooo0_l0000?ooooo`;o00005ooo
ool2o`0001gooooo0_l0000Sooooo`;o0000:_ooool001kooooo00?o0000ooooooooool00_l0000e
ooooo`;o000000?oooooo`000?l00000>Oooool2o`0000Kooooo0_l0000Hooooo`;o00000_ooool2
o`00027ooooo0_l00027ooooo`007_ooool2o`000003ooooool0003o000007?ooooo0_l00006oooo
o`;o00007?ooool2o`00017ooooo0_l0000>ooooo`;o0000E?ooool2o`0002[ooooo0_l00005oooo
o`007_ooool00ol0003oooooooooo`02ooooo`;o0000Z_ooool2o`0005Kooooo0_l0000<ooooo`;o
00009?ooool2o`0000Cooooo0_l00005ooooo`007_ooool00ol0003oooooooooo`02ooooo`;o0000
2?ooool2o`0004cooooo0_l0001Booooo`;o0000E_ooool2o`0003;ooooo0_l0000;ooooo`007_oo
ool00ol0003oooooooooo`0<ooooo`;o0000C?ooool2o`0001Kooooo0_l00003ooooo`;o0000=?oo
ool3o`0009Oooooo000Nooooo`03o`000?oooooooooo07;ooooo0_l00003ooooo`;o00006Oooool2
o`0001Wooooo0_l0002Hooooo`007_ooool00ol0003oooooooooo`0:ooooo`;o0000BOooool2o`00
03_ooooo0_l0000oooooo`;o0000Doooool2o`0001gooooo000Nooooo`03o`000?oooooooooo00[o
oooo0_l0000Pooooo`;o00009oooool2o`0004;ooooo0_l0000hooooo`;o0000Doooool2o`0001go
oooo000Nooooo`03o`000?oooooooooo02cooooo0_l0001[ooooo`;o00001Oooool2o`0008oooooo
0_l00006ooooo`;o00000_ooool2o`0000Sooooo000Nooooo`03o`000?oooooooooo04Oooooo0_l0
001Gooooo`;o0000=?ooool2o`0003Wooooo0_l0000Gooooo`;o00001Oooool2o`0000Kooooo0_l0
0002ooooo`;o00002?ooool001kooooo00?o0000ooooooooool0Aoooool2o`0008gooooo0_l0000;
ooooo`;o00008_ooool2o`0000Sooooo0_l0000Gooooo`;o00006oooool001kooooo00?o0000oooo
ooooool07?ooool2o`00037ooooo0_l0001Dooooo`;o0000??ooool2o`0002;ooooo0_l00005oooo
o`;o00008_ooool2o`0001?ooooo000Nooooo`03o`000?oooooooooo01cooooo0_l0000aooooo`;o
0000Doooool3o`0006Oooooo0_l0000Rooooo`;o00004oooool001kooooo00?o0000ooooooooool0
Ioooool2o`0001Oooooo0_l0000Nooooo`;o00000_ooool2o`0001oooooo0_l00020ooooo`007_oo
ool00ol0003oooooooooo`0Qooooo`;o0000A?ooool2o`0001Oooooo0_l0000;ooooo`;o00004Ooo
ool2o`0002?ooooo0ol0001oooooo`005?ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool08Oooool2o`0001;ooooo0_l0001Fooooo`;o000000?oooooo`000?l00000=?ooool2
o`0007oooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=Oooool2o`00
00Gooooo0_l0001Booooo`;o0000]Oooool001Kooooo00?o0000ooooooooool01Oooool3o`0003co
oooo0_l0001Xooooo`;o00004_ooool2o`0001oooooo0_l00018ooooo`;o00005Oooool2o`0000Wo
oooo000Fooooo`03o`000?oooooooooo0:kooooo0_l0000Booooo`;o00007oooool2o`0004Sooooo
0_l0000Eooooo`;o00002Oooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool0
0ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Co
oooo00?oEEEEofIVI_l00000oooooomBooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[Table[{n\ \[CapitalDelta]t, kineticenergy[n]}, {n, 0, 60}], 
        PlotJoined \[Rule] True, 
        PlotLabel \[Rule] \ "\<kinetic energy versus time\>", \ 
        AxesLabel \[Rule] {"\<t\>", "\<\>"}, 
        PlotRange \[Rule] {0, 400000}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.89"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 10.582 0 1.54508e-06 [
[.23545 -0.0125 -12 -9 ]
[.23545 -0.0125 12 0 ]
[.44709 -0.0125 -12 -9 ]
[.44709 -0.0125 12 0 ]
[.65873 -0.0125 -12 -9 ]
[.65873 -0.0125 12 0 ]
[.87037 -0.0125 -12 -9 ]
[.87037 -0.0125 12 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -36 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -36 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -36 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -36 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -36 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -36 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -36 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -80 0 ]
[.5 .63053 80 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23545 0 m
.23545 .00625 L
s
[(0.02)] .23545 -0.0125 0 1 Mshowa
.44709 0 m
.44709 .00625 L
s
[(0.04)] .44709 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(0.06)] .65873 -0.0125 0 1 Mshowa
.87037 0 m
.87037 .00625 L
s
[(0.08)] .87037 -0.0125 0 1 Mshowa
.125 Mabswid
.07672 0 m
.07672 .00375 L
s
.12963 0 m
.12963 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.28836 0 m
.28836 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.39418 0 m
.39418 .00375 L
s
.5 0 m
.5 .00375 L
s
.55291 0 m
.55291 .00375 L
s
.60582 0 m
.60582 .00375 L
s
.71164 0 m
.71164 .00375 L
s
.76455 0 m
.76455 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.92328 0 m
.92328 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(50000)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(100000)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(150000)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(200000)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(250000)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(300000)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(350000)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(400000)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -141 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(kinetic) show
111.000 13.000 moveto
(energy) show
153.000 13.000 moveto
(versus) show
195.000 13.000 moveto
(time) show
219.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .47793 m
.03968 .47783 L
.05556 .47781 L
.07143 .47788 L
.0873 .47802 L
.10317 .47816 L
.11905 .47828 L
.13492 .47847 L
.15079 .47871 L
.16667 .47899 L
.18254 .47927 L
.19841 .47956 L
.21429 .47983 L
.23016 .48007 L
.24603 .48025 L
.2619 .48029 L
.27778 .48019 L
.29365 .48002 L
.30952 .4798 L
.3254 .47954 L
.34127 .47926 L
.35714 .47893 L
.37302 .47866 L
.38889 .47862 L
.40476 .47887 L
.42063 .47939 L
.43651 .48016 L
.45238 .48105 L
.46825 .48185 L
.48413 .48249 L
.5 .48297 L
.51587 .48324 L
.53175 .48329 L
.54762 .48321 L
.56349 .48305 L
.57937 .4827 L
.59524 .48219 L
.61111 .48166 L
.62698 .48121 L
.64286 .48084 L
.65873 .48057 L
.6746 .48043 L
.69048 .48046 L
.70635 .48061 L
.72222 .48077 L
.7381 .48097 L
.75397 .48118 L
.76984 .48127 L
.78571 .48111 L
.80159 .4807 L
Mistroke
.81746 .48009 L
.83333 .47943 L
.84921 .47883 L
.86508 .47835 L
.88095 .47806 L
.89683 .47793 L
.9127 .47798 L
.92857 .47831 L
.94444 .47885 L
.96032 .4793 L
.97619 .47953 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Hoooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool5o`00027ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_l000000ol@413oooooooooo`0Oooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`08_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<02gooooo001Soooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@08Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0Poooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B408_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OlQ8B7oV9RHoooooonHV9So
8B4Q02gooooo001Sooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooo
oooo410@00Cooooo00?oV9RHob4Q8Oo^k^h08_ooool01Ol@413ooooooooooooooooo410@00_ooooo
00Go410@oooooooooooooooooa0@4003ooooo`Go00008Oooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go410@oooooooooooooooooa0@4003ooooo`05o`000?ooooooooooooooool000008_oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4003ooooo`05
o`000?ooooooooooooooool00000;Oooool006?ooooo00Go0000ooooooooooooooooo`00000;oooo
o`05o`000?ooooooooooooooool000001Oooool00onHV9So8B4Qonk^kP0Qooooo`05o`000?oooooo
ooooooooool000002oooool01Ol0003ooooooooooooooooo000000?ooooo00CoA4A4omgMgOoooooo
00008_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?nHV9SooooooiRHV?lQ8B408_ooool01Ol0003ooooooooooooooooo000000_ooooo
00Go0000ooooooooooooooooo`000003ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80;Oooool006?o
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?ooooooooooooooool000001_ooool0
0omgMgOoIVIVooooo`0Pooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooo
oooooooo000000?ooooo00CogMgMoeEEEOoooooo00008_ooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?mEEEGo0000oa0@4?o<c<`08_oo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000003ooooo`05
olc<c?l0003o0000o`000?o<c<`0;Oooool006?ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05oa0@4?ooooooooooooooool@41001oooool00ol0003oooooooooo`0Oooooo`05oa0@4?oooooo
ooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Cooooo00?oMgMgolc<c?l00000
8_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4003oooo
o`03oeEEEOn7QhOooooo02Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?oooooo
ooooooooool@41000oooool01Ol@413o^[Zjoooooonj^[[o410@02gooooo001Sooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go0000okZj^_oo
ooooV9RHoa0@400Qooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Cooooo00?ok^k^odA4A?l000008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03omgMgOl@413oV9RH02Cooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Ol0003o^[Zjoooooonj
^[[o000002gooooo001Sooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Qooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?oMgMgo`000?ooool08Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`04olc<
c?m4A4Co0000oa0@42;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01OnYZJWo410@o`000?l@413oZJVY02gooooo003oooooofWooooo003ooooo
ofWooooo003oooooof3ooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`00oooooomPooooo`05
oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00?ooooooH?ooool00ol0003oooooooooo`06ooooo`00
;Oooooooo`0002So00002oooool00ol0003oooooooooo`06ooooo`00=?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo00Kooooo000dooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03cooooo00?o0000
ooooooooool0;Oooool00ol@413o0000o`000003o`0000Gooooo000dooooo`03o`000?oooooooooo
0?oooooo:Oooool00ol0003oooooooooo`06ooooo`00=?ooool00ol0003oooooooooo`3oooooobWo
oooo00?o0000ooooooooool01_ooool003Cooooo0_l0003ooooooc?ooooo000dooooo`03o`000?oo
oooooooo0?oooooo<_ooool003Cooooo00?o0000ooooooooool0oooooolbooooo`00=?ooool00ol0
003oooooooooo`3ooooooc;ooooo000dooooo`;o0000oooooolcooooo`00=?ooool00ol0003ooooo
ooooo`3ooooooc;ooooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Cooooo00?o0000
ooooooooool0oooooolbooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo000dooooo`;o
0000oooooolcooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo000dooooo`03o`000?oo
oooooooo0?oooooo<_ooool003Cooooo00?o0000ooooooooool0oooooolbooooo`00=?ooool2o`00
0?oooooo<oooool003Cooooo00?o0000ooooooooool0oooooolbooooo`002_ooool01Om4A4Co0000
o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo0?oooooo<_ooool000gooooo00WoMgMgoc8b<_oooooooooo
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003ooooo
ooooo`3ooooooc;ooooo000>ooooo`04o`000?oooooooooooa0@40?ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo
410@00?ooooo00?o410@ooooooooool01?ooool00ol0003oooooooooo`3ooooooc;ooooo000=oooo
o`05ogMgMolb<S;oooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`04ooooo`?o0000oooooolbooooo`002_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo0?oooooo<_ooool000[ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41000oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0oooooolb
ooooo`002_ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc;ooooo000:ooooo`Co0000
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo0_l0
003ooooooc?ooooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Cooooo00?o0000oooo
ooooool0oooooolbooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo000dooooo`03o`00
0?oooooooooo0?oooooo<_ooool003Cooooo0_l0003ooooooc?ooooo000dooooo`03o`000?oooooo
oooo0?oooooo<_ooool003Cooooo00?o0000ooooooooool0oooooolbooooo`00=?ooool00ol0003o
ooooooooo`3ooooooc;ooooo000dooooo`;o0000oooooolcooooo`00=?ooool00ol0003ooooooooo
o`3ooooooc;ooooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Cooooo00?o0000oooo
ooooool0oooooolbooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo000dooooo`;o0000
oooooolcooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo0002ooooo`Co000000So410@
ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?oooooo<_ooool000Cooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo<_oo
ool000Cooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooo
oooo0?oooooo<_ooool000Cooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000006oooo
o`?o0000oooooolbooooo`001?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool0oooooolbooooo`001?ooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooo
oooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooo
oooooooo410@00Kooooo00?o0000ooooooooool0oooooolbooooo`001?ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolbooooo`000_ooool0
0omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo0_l0003ooooooc?ooooo000doooo
o`03o`000?oooooooooo0?oooooo<_ooool003Cooooo00?o0000ooooooooool0oooooolbooooo`00
=?ooool00ol0003oooooooooo`3ooooooc;ooooo000dooooo`03o`000?oooooooooo0?oooooo<_oo
ool003Cooooo0_l0003ooooooc?ooooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Co
oooo00?o0000ooooooooool0oooooolbooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo
000dooooo`;o0000oooooolcooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo000doooo
o`03o`000?oooooooooo0?oooooo<_ooool003Cooooo00?o0000ooooooooool0oooooolbooooo`00
=?ooool00ol0003oooooooooo`3ooooooc;ooooo000dooooo`;o0000oooooolcooooo`00=?ooool0
0ol0003oooooooooo`3ooooooc;ooooo0002ooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Kooooo00?o0000ooooooooool0oooooolbooooo`001?ooool00ol0003oooooooooo`06
ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Kooooo00?o0000ooooooooool0oooooolbooooo`001?ooool00ol0003oooooooooo`07
ooooo`04o`000?oooooooooooa0@40?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@
4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooo
ooooool01?ooool3o`000?oooooo<_ooool000Cooooo00?o0000ooooooooool01_ooool01OmgMgOo
<S8boooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`3ooooooc;ooooo0004ooooo`03o`000?oooooooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3ooooooc;ooooo0004ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@00Kooooo00?o0000ooooooooool0oooooolbooooo`001?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo<_ooool000;ooooo00?o
EEEEofIVI_l000001Oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP06ooooo`;o0000oooooolcooooo`00=?ooool00ol0003oooooooooo`3ooooo
oc;ooooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Cooooo00?o0000ooooooooool0
oooooolbooooo`00=?ooool2o`000?oooooo<oooool003Cooooo00?o0000ooooooooool0oooooolb
ooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo000dooooo`03o`000?oooooooooo0?oo
oooo<_ooool003Cooooo00?o0000ooooooooool0oooooolbooooo`00=?ooool2o`000?oooooo<ooo
ool003Cooooo00?o0000ooooooooool0oooooolbooooo`00=?ooool00ol0003oooooooooo`3ooooo
oc;ooooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Cooooo0_l0003ooooooc?ooooo
000dooooo`03o`000?oooooooooo0?oooooo<_ooool00003ooooool0003o000000?o00000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?oooooo<_ooool00006oooooonHV9So8B4Q
onk^k_ooooooA4A40oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo<_oo
ool000;ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooo
oooo0?oooooo<_ooool000?ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000006oooo
o`?o0000oooooolbooooo`001?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool0oooooolbooooo`001Oooool01Ol0003ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@
4?oooooooooo00Cooooo00?o0000ooooooooool0oooooolbooooo`0000Koooooo`000?nj^[[ooooo
oiRHV?l@4103ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolbooooo`00
00KooooooiRHV?l@413o0000ob4Q8Oo<c<`3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo0_l0003ooooo
oc?ooooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Cooooo00?o0000ooooooooool0
oooooolbooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo000dooooo`03o`000?oooooo
oooo0?oooooo<_ooool003Cooooo0_l0003ooooooc?ooooo000dooooo`03o`000?oooooooooo0?oo
oooo<_ooool003Cooooo00?o0000ooooooooool0oooooolbooooo`00=?ooool00ol0003ooooooooo
o`3ooooooc;ooooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Cooooo0_l0003ooooo
oc?ooooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Cooooo00?o0000ooooooooool0
oooooolbooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo000dooooo`;o0000oooooolc
ooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo00000ooooooo0000o`000003o`0000Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooooc;ooooo00001_ooooooV9RH
ob4Q8Oo^k^koooooodA4A0Oooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc;ooooo0002oooo
o`03oiRHV?lQ8B7ok^k^00Wooooo00Co0000oooooooooooo410@0oooool01Ol@413ooooooooooooo
oooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
41000oooool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo<_ooool000?ooooo
00?oV9RHob4Q8Oo^k^h01oooool01OmgMgOo<S8boooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool01?ooool3o`000?oooooo<_ooool000Cooooo00?oMgMg
ofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo<_ooool0
00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05oa0@4?oooooooooo
ooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooo
oa0@4003ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`3ooooooc;o
oooo00001_oooooo0000okZj^_ooooooV9RHoa0@40Cooooo00?o0000ooooooooool01?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000oooooooo
ool0oooooolbooooo`0000KooooooiRHV?l@413o0000ob4Q8Oo<c<`4ooooo`Co00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo0_l0003ooooooc?o
oooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Cooooo00?o0000ooooooooool0oooo
oolbooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo000dooooo`03o`000?oooooooooo
0?oooooo<_ooool003Cooooo0_l0003ooooooc?ooooo000dooooo`03o`000?oooooooooo0?oooooo
<_ooool003Cooooo00?o0000ooooooooool0oooooolbooooo`00=?ooool00ol0003oooooooooo`3o
oooooc;ooooo000dooooo`;o0000oooooolcooooo`00=?ooool00ol0003oooooooooo`3ooooooc;o
oooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Cooooo00?o0000ooooooooool0oooo
oolbooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo000dooooo`;o0000oooooolcoooo
o`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo00001_ooooooV9RHoa0@4?l0003o<S8bolc<
c0?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooooc;ooooo00001_oooooo
410@okZj^_ooooooMgMgoc8b<P?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3o
oooooc;ooooo0005ooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01?ooool3o`00
0?oooooo<_ooool000Cooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo0?oooooo<_ooool000?ooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0?oooooo<_ooool000Cooooo00?o^[Zjob4Q8Oooool00_oo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@
oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0?oooooo<_ooool00006ooooool@413o
V9RHoooooonj^[[o00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo
<_ooool00006oooooonYZJWo410@o`000?l@413oZJVY0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06oooooh7o
0000<ooooolQo`0000gooooo=ol0000Kooooo`00=?ooool00ol0003oooooooooo`1noooooc?o0000
8Oooool=o`0005;ooooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Cooooo00?o0000
ooooooooool0oooooolbooooo`00=?ooool2o`000?oooooo<oooool003Cooooo00?o0000oooooooo
ool0oooooolbooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo000dooooo`03o`000?oo
oooooooo0?oooooo<_ooool003Cooooo00?o0000ooooooooool0oooooolbooooo`00=?ooool2o`00
0?oooooo<oooool003Cooooo00?o0000ooooooooool0oooooolbooooo`00=?ooool00ol0003ooooo
ooooo`3ooooooc;ooooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Cooooo00?o0000
ooooooooool0oooooolbooooo`00=?ooool2o`000?oooooo<oooool003Cooooo00?o0000oooooooo
ool0oooooolbooooo`0000KooooooiRHV?l@413o0000oc8b<_o<c<`4ooooo`05odA4A?l0003o0000
oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Kooooo00?o0000ooooooooool0oooooolbooooo`0000Kooooooa0@4?nj^[[oooooogMgMolb<S87
ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Kooooo00?o0000ooooooooool0oooooolbooooo`001Oooool00ol0003oooooooooo`06
ooooo`04o`000?oooooooooooa0@40?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@
4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooo
ooooool01?ooool3o`000?oooooo<_ooool000Cooooo00?oZJVYoa0@4?ooool01_ooool01OmgMgOo
<S8boooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`3ooooooc;ooooo0003ooooo`03oa0@4?l0003o^[Zj00Cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3ooooooc;ooooo0004ooooo`03okZj^_lQ8B7o
oooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@00Kooooo00?o0000ooooooooool0oooooolbooooo`0000Kooooooa0@4?nH
V9SooooookZj^_l00004ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo<_ooool00006
oooooonYZJWo410@o`000?l@413oZJVY1?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`;o0000oooooolcooooo`00=?ooool00ol0003o
ooooooooo`3ooooooc;ooooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Cooooo00?o
0000ooooooooool0oooooolbooooo`00=?ooool2o`000?oooooo<oooool003Cooooo00?o0000oooo
ooooool0oooooolbooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo000dooooo`03o`00
0?oooooooooo0?oooooo<_ooool003Cooooo00?o0000ooooooooool0oooooolbooooo`00=?ooool2
o`000?oooooo<oooool003Cooooo00?o0000ooooooooool0oooooolbooooo`00=?ooool00ol0003o
ooooooooo`3ooooooc;ooooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Cooooo0_l0
003ooooooc?ooooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool000?ooooo0_l000002Ol@
413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooooc;ooooo0004
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3o
oooooc;ooooo00000ooooooo0000o`000003o`0000?ooooo00Go410@oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0
003oooooooooo`3ooooooc;ooooo00001OooooooA4A4omgMgOoooooo000000Cooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000001_ooool3o`000?oooooo<_ooool00005oooooooMgMgoEEEEooooool000001?ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`00003ooooooc_ooooo0002ooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooo
oooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
4100oooooolkooooo`000_ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?oooooo
>oooool000?ooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP3ooooooc_ooooo002l
ooooo`06ob4Q8Ol0003o0000odA4A?oMgMgooooo0ol000000ol@413oooooooooo`2Pooooo`00_ooo
ool00omgMgOo<S8booooo`02ooooo`03oa0@4?nj^[[ooooo0:7ooooo0030ooooo`06o`000?oooooo
oooooooooonHV9So<S8bX_ooool005oooooo0_l00002ooooo`03oa0@4?l0003o000000;ooooo1Ol0
0002ooooo`04oa0@4?l0003o0000ooooo`;o000000Co410@ooooooo^k^koEEEE0_l000000om4A4Co
^[Zjooooo`02ooooo`05oiRHV?l0003o0000odA4A?nj^[X00oooool5o`0000?ooooo00GoIVIVo`00
0?l0003oA4A4olc<c006ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj0_ooool01?l@413o0000
o`000?ooool2o`000004oa0@4?ooooook^k^oeEEE@;o000000CoA4A4okZj^_oooooo410@1Ol00003
ooooo`06onk^k_mEEEGo0000oa0@4?o<c<co00000oooool00ooMgMgo0000okZj^P0;ooooo`03ob4Q
8Olb<S;ooooo00?ooooo00Sok^k^oeEEEOl0003o0000odA4A?nj^[[ooooooa0@40Go00000oooool0
1_l@413o<S8bo`000?l0003o410@ojVYZ@?ooooo00WoV9RHo`000?l0003oMgMgo`000?l@413ooooo
oa0@4?lb<S800_l000000ol@413oZJVYooooo`06ooooo`05oiRHV?l0003o0000odA4A?nj^[X00ooo
ool5o`000003ooooool0003o000000;ooooo00Oo0000oooooooooooo0000oa0@4?o^k^koEEEE00;o
000000?oA4A4okZj^_ooool0AOooool0063ooooo00Go0000ooooooo^k^ko<S8bolc<c005ooooo`03
o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`06oeEEEOmgMgOooooo
onk^k_mgMgOo410@0oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Gooooo00?o0000ooooooooool0
0_ooool01_mVIVKoMgMgooooooooooooQhN7oa0@40Kooooo00KoEEEEogMgMoooooook^k^ogMgMol@
4103ooooo`05o`000?ooooooooooooooool000000_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@
40?ooooo00?o0000ooooooooool01?ooool01_mEEEGoMgMgooooooo^k^koEEEEo`0000?ooooo00?o
EEEEogMgMom4A4@02_ooool01?nHV9So<S8boa0@4?nj^[X3ooooo`06oeEEEOmgMgOoooooonk^k_mg
MgOo410@0oooool00ol0003oooooooooo`04ooooo`06o`000?nYZJWooooooooooonj^[[o00000ooo
ool01Ol0003oZJVYoooooon7QhOo000000;ooooo00Ko0000ojVYZOoooooooooookZj^_l00007oooo
o`05oa0@4?nj^[[ok^k^ogMgMol@41001Oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00So0000oooooomEEEGoMgMgooooooo^k^koMgMgoa0@44Kooooo001Pooooo`04
o`000?nHV9So<S8bolc<c0Kooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo
000000;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`05o`000?oooooo
ooooooooool000000_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00Ko
0000ooooooooooooooooonk^k_l00002ooooo`05omgMgOl@413oooooob4Q8OoMgMd02Oooool01?l@
413o^[ZjoiRHV?lb<S83ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
1Onj^[[oQhN7ofIVI_mVIVKo410@00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05okZj
^_n7QhOoIVIVofIVI_l@41001oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`00001;ooooo`00H?ooool00ol0003o
410@oiRHV007ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002oooo
o`Ko00000oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool02Oooool6o`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`Ko00000oooool0
0ol0003oooooooooo`04ooooo`06o`000?ooooooooooooooooo^k^ko00000_ooool01OmVIVKoQhN7
oooooonHV9SoEEEE00Sooooo00KoV9RHoc8b<_oooooooooooa0@4?nj^[X2ooooo`Ko00000oooool0
0ol0003oooooooooo`04ooooo`06oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^0oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Ko<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^h7ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooo000000Go0000A_ooool0063ooooo00Co0000onk^k_mEEEGoQhN71_ooool00ol0003ooooooooo
o`03ooooo`05o`000?n7QhOoooooojVYZOl000000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b
<P?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`06ofIVI_mgMgOooooo
oooooon7QhOo00001_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P?ooooo00Go0000ohN7Qooo
ooooZJVYo`000002ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b0oooool00ol0003o<S8bomgM
g@04ooooo`0:oeEEEOmgMgOoooooonk^k_mEEEGo0000ooooooo^k^ko0000onk^kP;ooooo00?o0000
omgMgOooool01Oooool00oo^k^ko0000omgMg@02ooooo`0:oiRHV?lb<S;ooooooooooomEEEGoQhN7
onk^k_ooooooQhN7oc8b<P?ooooo00?o0000oc8b<_oMgMd01?ooool01_l0003o^[Zjooooooo^k^ko
MgMgo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`06o`000?nj^[[oooooonk^k_mg
MgOo00001oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00ko0000olc<
c?o<c<co0000ojVYZOoMgMgo8B4QoooooomEEEGoQhN7onk^k_ooooooQhN7oc8b<TKooooo001Poooo
o`05o`000?ooooooA4A4o`000?l@41000oooool00ol@413o0000o`000004ooooo`03oa0@4?l0003o
MgMg00;o000000GoV9RHooooooooooook^k^oeEEE@02o`000004odA4A?o^k^kooooooa0@40Go0000
1?ooool00ol@413o0000o`000004ooooo`06onk^k_mVIVKo0000o`000?m4A4Co00001_ooool01_o^
k^koEEEEo`000?l0003oA4A4onk^kP;ooooo00?o410@o`000?mgMgL00_l000001OnHV9Sooooooooo
ooo^k^koEEEE00;o000000CoA4A4onk^k_oooooooooo0_l000001?nYZJWo8B4Qo`000?lQ8B42oooo
o`06onk^k_mEEEGo0000ob4Q8OnYZJWo00000_l@4102o`000004ooooool0003o0000oa0@40Kooooo
00?o410@o`000?l000000_ooool3o`000003ooooooo^k^koEEEE00;o000000CoA4A4onk^k_oooooo
oooo0_l000001?nYZJWo8B4Qo`000?lQ8B42ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o00000_oo
ool01?l@413o0000ooooooooool2o`0000;ooooo00KoZJVYob4Q8Ol0003o0000oc8b<_l00005oooo
o`03oa0@4?l0003o000000?o00001?ooool00ol@413o0000o`000003ooooo`0;oa0@4?l0003o8B4Q
o`000?mgMgOo410@o`000?nYZJWoooooonk^k_mEEED00_l000000om4A4Cok^k^ooooo`15ooooo`00
H?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0
H?ooool0063ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo05Kooooo001Oooooo`;o00002Oooool00ol@413oooooooooo`0Mooooo`03oa0@4?oooooo
oooo08;ooooo00?o410@ooooooooool0E_ooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {221.375, 0}} -> {-0.0167958, -39614.6, \
0.000401908, 2752.6}}]
}, Open  ]],

Cell[TextData[{
  "The gas no longer collapses.  To understand this theoretically, consider \
the linearized version of the Navier-Stokes equations ",
  ButtonBox["(7.2.35)",
    ButtonData:>{"Chapter7.nb", "(7.2.35)"},
    ButtonStyle->"Hyperlink"],
  " -",
  ButtonBox["(7.2.37)",
    ButtonData:>{"Chapter7.nb", "(7.2.37)"},
    ButtonStyle->"Hyperlink"],
  "  for the gas, including the effect of gravity. The perturbed mass density \
",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\[Rho]\)]],
  ", velocity ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[Delta]", 
            StyleBox["u",
              FontWeight->"Bold",
              FontSlant->"Plain"]}]], TraditionalForm]]],
  ", and gravitational potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\[Phi]\)]],
  " obey"
}], "Text",
  CellTags->"i:83"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[PartialD]\[Delta]\[Rho]\/\[PartialD]t\), "=", " ", 
          RowBox[{\(-\ \[Rho]\_o\), 
            RowBox[{"\[Del]", 
              RowBox[{"\[CenterDot]", 
                StyleBox[
                  RowBox[{"\[Delta]", 
                    StyleBox["u",
                      FontWeight->"Bold",
                      FontSlant->"Plain"]}]]}]}]}]}], TraditionalForm]]],
  ",\n",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{\(\[Rho]\_o\), 
              FractionBox[
                RowBox[{"\[PartialD]", 
                  StyleBox[
                    RowBox[{"\[Delta]", 
                      StyleBox["u",
                        FontWeight->"Bold",
                        FontSlant->"Plain"]}]]}], \(\[PartialD]t\)]}], "=", 
            " ", \(\(-\ \[Del]\[Delta]p\) - \(\[Rho]\_o\) \
\[Del]\[Delta]\[Phi]\)}], ","}], TraditionalForm]]],
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]p\  = \ \[Gamma] \( p\_o\/\[Rho]\_o\) \
\[Delta]\[Rho]\)]],
  ",\n",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Del]\^2 \[Delta]\[Phi] = 
        4  \[Pi]\ G\ \[Delta]\[Rho]\)\(,\)\)\)]]
}], "NE3",
  CellTags->"(7.3.13)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_o\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`p\_o\)]],
  " are the equilibrium density and pressure of the uniform gas, we have \
neglected viscosity ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\)]],
  " (our system is assumed to be dissipationless), and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\)]],
  " is the ratio of specific heats. If one Fourier-transforms these equations \
in space and time, one finds the following dispersion relation for sound \
waves in the gas (see the exercises):"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\^2 = \(c\^\(\(2\)\(\ \)\)\) k\^2 - 
          4\ \[Pi]\ G\ \[Rho]\_o\)]],
  ","
}], "NE3",
  CellTags->{"i:81", "(7.3.14)"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(c\)\(=\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\@\(\[Gamma]\ p\_o/\[Rho]\_o\)\)]],
  " is the speed of sound.  A similar dispersion relation can also be derived \
directly from the collisionless Boltzmann equation, Eq. ",
  ButtonBox["(7.3.1)",
    ButtonData:>{"Chapter7.nb", "(7.3.1)"},
    ButtonStyle->"Hyperlink"],
  "  (see the exercises). "
}], "Text"],

Cell[TextData[{
  "\tFor wavenumbers that are sufficiently small, the square of the wave \
frequency is negative; that is, the frequency is imaginary. There are two \
imaginary roots to Eq. ",
  ButtonBox["(7.3.14)",
    ButtonData:>{"Chapter7.nb", "(7.3.14)"},
    ButtonStyle->"Hyperlink"],
  " , ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\  = \ \(\[PlusMinus]\[ImaginaryI]\)\ \@\(4\ \
\[Pi]\ G\ \[Rho]\_o - \(c\^\(\(2\)\(\ \)\)\) k\^2\)\)]],
  ".  Waves of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Omega]\ t\)\
\)]],
  " will then either grow or decay; but over time the growing wave will \
dominate. As a result, the equilibrium is unstable to waves with sufficiently \
small wavenumbers: "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`k\  < \ \@\(4  \[Pi]\ G\ \[Rho]\_o/c\^2\)\)]],
  " for instability."
}], "NE3",
  CellTags->"(7.3.15)"],

Cell[TextData[{
  "On the other hand, in our system",
  ",",
  " the minimum wavenumber that fits into our box is ",
  Cell[BoxData[
      \(TraditionalForm\`k\_min = \ 2\ \[Pi]/L\)]],
  ". Therefore, if ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(2\ \[Pi]/
            L\)\(\ \)\(>\)\(\@\(4  \[Pi]\ G\ \[Rho]\_o/c\^2\)\)\(\ \)\)\)]],
  ", the system is stable to all waves that can fit into the box.  Written as \
a condition on the sound speed, this becomes"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`c\^2 \[GreaterEqual] \ \ \(G\ \[Rho]\_o\ \
L\^2\)\/\(\(\[Pi]\)\(\ \ \)\)\)]],
  " for stability."
}], "NE3",
  CellTags->"(7.3.16)"],

Cell[TextData[{
  "Roughly the same stability criterion holds for any cloud of size ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " and mean density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_o\)]],
  " in free space. Note that the ",
  "right-hand",
  " side is on the order of the escape velocity at the surface of such a \
system. The cloud will not collapse if the sound speed is on the order of the \
escape velocity. Since the sound speed  ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " is on the order of the mean thermal speed of gas particles, this implies \
that a stable cloud will be diffuse, with particle speeds on the order of or \
even above the escape velocity.  This sort of final state is what we observed \
in our first simulation. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Rotation", "Section",
  CellTags->"c:39"],

Cell[TextData[{
  "\tNaturally occurring gas clouds have finite angular momentum, and as they \
collapse they rotate. The smaller the cloud's radius becomes, the faster the \
rotation. This can be understood by considering the angular momentum ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(L\_z\), " ", "=", " ", 
          RowBox[{
            OverscriptBox[
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"], "^"], "\[CenterDot]", 
            RowBox[{\(\[Sum]\+i\), 
              RowBox[{
                SubscriptBox[
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "i"], " ", "\[Times]", 
                SubscriptBox[
                  StyleBox["p",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "i"]}]}]}]}], TraditionalForm]]],
  ". For a system rotating with uniform angular speed ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Omega]", Cell[""]}], TraditionalForm]]],
  " about the ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  "-axis, we have ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox["p",
              FontWeight->"Bold",
              FontSlant->"Plain"], "i"], "=", 
          RowBox[{"m", " ", "\[Omega]", " ", 
            OverscriptBox[
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"], "^"], "\[Times]", 
            StyleBox[\(r\_i\),
              FontWeight->"Bold",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  " and this implies ",
  Cell[BoxData[
      \(TraditionalForm\`L\_z = \ I\ \[Omega]\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`I = \[Sum]\+i 
            m\ r\_\(\(\[UpTee]\)\(\ \)\(i\)\)\%2\)]],
  " is the moment of inertia of the cloud, and  where ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{\(r\_\(\(\[UpTee]\)\(\ \)\(i\)\)\), " ", "=", " ", 
            RowBox[{"|", 
              RowBox[{
                OverscriptBox[
                  StyleBox["z",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "^"], "\[Times]", 
                StyleBox[
                  SubscriptBox["r", 
                    StyleBox["i",
                      FontWeight->"Plain"]],
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}], "|"}]}]}], TraditionalForm]]],
  ". As the cloud collapses, ",
  Cell[BoxData[
      \(TraditionalForm\`I\)]],
  " decreases and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  " must increase to compensate so that ",
  Cell[BoxData[
      \(TraditionalForm\`L\_z\)]],
  " is conserved.  "
}], "Text"],

Cell[TextData[{
  "\tIf the cloud rotates sufficiently rapidly, it will not collapse, because \
the centrifugal force balances the gravitational attraction. For a uniform \
cylindrical cloud of radius ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " and mass ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " per unit length, an equilibrium will exist if"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega] = \@\(2\ G\ \(\(M/R\^2\)\(\ \)\)\)\)]],
  "."
}], "NE3",
  CellTags->"(7.3.17)"],

Cell[TextData[{
  "In Cells ",
  ButtonBox["7.90",
    ButtonData:>"Cell 7.90",
    ButtonStyle->"Hyperlink"],
  "-",
  ButtonBox["7.92",
    ButtonData:>"Cell 7.92",
    ButtonStyle->"Hyperlink"],
  ", we simulate a cloud that is rotating at 70% of this rate.  "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(m = 1/2; M = 40; 
    L = 1; \[CapitalDelta]x\  = \ \(\[CapitalDelta]y\  = \ 
        L/M\); \[CapitalDelta]t = 0.0012;\n\), "\[IndentingNewLine]", 
    \(\(Clear[r, p];\)\), "\n", 
    \(rad\  = \ 0.1; 
    r0 = Table[rp = Sqrt[Random[]]; 
        t = 2  Pi\ Random[]; { .5,  .5} + rad\ rp {Sin[t], Cos[t]}, {n, 1, 
          1000}];\n\), "\[IndentingNewLine]", 
    \(\(\[Omega]\  = \  .7\ Sqrt[2\ G\ \ Npart\ m/rad^2];\)\), "\n", 
    \(\(Npart = Length[r0];\)\), "\n", 
    \(\(vval[x_]\  := \ \[Omega] {\(-x[\([2]\)]\), x[\([1]\)]};\)\), "\n", 
    \(\(p0 = m\ Map[vval, r0];\)\), "\n", 
    \(px\  := \ Sum[\(p0[\([i]\)]\)[\([1]\)], {i, 1, Npart}]\ \), "\n", 
    \(py := \ Sum[\(p0[\([i]\)]\)[\([2]\)], {i, 1, Npart}]\ \), "\n", 
    \(\(mom\  = {px, py}/Npart;\)\), "\n", 
    \(\(\(p0\  = \ 
        Table[p0[\([i]\)]\  - \ mom, {i, 1, Npart}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(Timing[leapfrog[r0, p0, 50, \[CapitalDelta]t]]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.90"],

Cell[BoxData[
    \({68.76`\ Second, Null}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Table[
        ListPlot[r[n], PlotRange \[Rule] {{0, 1}, {0, 1}}, 
          AspectRatio \[Rule] 1], {n, 0, 50, 1}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.91"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.53654 .57102 Mdot
.52519 .45086 Mdot
.53835 .4178 Mdot
.53144 .45917 Mdot
.55734 .49108 Mdot
.49745 .57867 Mdot
.56683 .42631 Mdot
.57124 .52247 Mdot
.41807 .45168 Mdot
.46202 .55561 Mdot
.52451 .55231 Mdot
.47824 .49381 Mdot
.49692 .58335 Mdot
.58472 .48314 Mdot
.46365 .41393 Mdot
.45438 .55221 Mdot
.57104 .48221 Mdot
.44124 .57181 Mdot
.45893 .56148 Mdot
.44889 .47957 Mdot
.57999 .50449 Mdot
.41003 .52002 Mdot
.54887 .52633 Mdot
.54254 .57858 Mdot
.57022 .53455 Mdot
.47819 .50674 Mdot
.4437 .43501 Mdot
.4603 .56433 Mdot
.54021 .47965 Mdot
.51117 .58354 Mdot
.53978 .42942 Mdot
.55561 .46866 Mdot
.51083 .50533 Mdot
.47834 .42852 Mdot
.50312 .58399 Mdot
.51748 .41462 Mdot
.47301 .51455 Mdot
.42625 .45955 Mdot
.55812 .51297 Mdot
.46316 .50189 Mdot
.47528 .53007 Mdot
.43498 .49468 Mdot
.51224 .43071 Mdot
.50757 .48882 Mdot
.56657 .48069 Mdot
.44732 .54275 Mdot
.58535 .47864 Mdot
.5531 .43529 Mdot
.52033 .42008 Mdot
.40205 .48162 Mdot
.55702 .50169 Mdot
.47828 .59 Mdot
.53298 .47448 Mdot
.56491 .51015 Mdot
.4446 .56099 Mdot
.44183 .52737 Mdot
.47668 .46206 Mdot
.47661 .59478 Mdot
.56212 .48039 Mdot
.47837 .45467 Mdot
.42667 .54545 Mdot
.4589 .53001 Mdot
.4643 .44603 Mdot
.459 .54834 Mdot
.54935 .50366 Mdot
.41594 .44866 Mdot
.55928 .45367 Mdot
.43769 .54107 Mdot
.43974 .5068 Mdot
.44726 .55707 Mdot
.51867 .40468 Mdot
.55507 .47803 Mdot
.46729 .46963 Mdot
.50756 .47053 Mdot
.52083 .58585 Mdot
.46368 .42524 Mdot
.43036 .52247 Mdot
.45417 .57145 Mdot
.53387 .40755 Mdot
.51641 .53698 Mdot
.43061 .46532 Mdot
.56871 .52962 Mdot
.5782 .52165 Mdot
.46769 .53223 Mdot
.46881 .43984 Mdot
.51735 .47075 Mdot
.4804 .41997 Mdot
.44559 .5359 Mdot
.46224 .49728 Mdot
.46598 .57672 Mdot
.54008 .48851 Mdot
.44549 .54935 Mdot
.44885 .44429 Mdot
.4099 .4589 Mdot
.55062 .41892 Mdot
.4177 .53085 Mdot
.44199 .53434 Mdot
.55076 .43682 Mdot
.58428 .47445 Mdot
.48527 .45415 Mdot
.47152 .42576 Mdot
.45166 .44579 Mdot
.56745 .49411 Mdot
.40066 .49924 Mdot
.42536 .44261 Mdot
.50318 .50712 Mdot
.59817 .50959 Mdot
.54823 .49702 Mdot
.54253 .4419 Mdot
.44385 .55112 Mdot
.55179 .5689 Mdot
.55342 .47565 Mdot
.49087 .46802 Mdot
.41366 .47324 Mdot
.57929 .48467 Mdot
.4737 .58724 Mdot
.43446 .44202 Mdot
.44061 .56865 Mdot
.55223 .42789 Mdot
.44509 .44623 Mdot
.50027 .55238 Mdot
.4882 .50068 Mdot
.4565 .5585 Mdot
.52961 .42374 Mdot
.55152 .46058 Mdot
.40791 .49356 Mdot
.53909 .57848 Mdot
.48555 .50328 Mdot
.50207 .49488 Mdot
.47363 .53582 Mdot
.51101 .54451 Mdot
.57716 .4891 Mdot
.52275 .59403 Mdot
.49361 .42324 Mdot
.54889 .54068 Mdot
.5421 .58641 Mdot
.40329 .522 Mdot
.52322 .48661 Mdot
.45495 .48905 Mdot
.4934 .47866 Mdot
.54554 .49331 Mdot
.42575 .44516 Mdot
.504 .50039 Mdot
.53467 .4647 Mdot
.52421 .5084 Mdot
.43885 .55269 Mdot
.52866 .5761 Mdot
.41752 .52175 Mdot
.58155 .4888 Mdot
.52123 .42186 Mdot
.47509 .43671 Mdot
.45829 .56572 Mdot
.54877 .48863 Mdot
.5866 .49387 Mdot
.51596 .54729 Mdot
.45276 .55346 Mdot
.46615 .52624 Mdot
.51254 .59174 Mdot
.43094 .5213 Mdot
.53577 .50438 Mdot
.48511 .40931 Mdot
.43185 .50984 Mdot
.48698 .56042 Mdot
.42926 .56066 Mdot
.46723 .48452 Mdot
.47983 .47281 Mdot
.43236 .43484 Mdot
.42387 .48386 Mdot
.41728 .51206 Mdot
.41859 .47076 Mdot
.49354 .54151 Mdot
.51738 .4233 Mdot
.51797 .44527 Mdot
.46453 .4864 Mdot
.51021 .40308 Mdot
.45379 .52499 Mdot
.4146 .52985 Mdot
.53976 .5057 Mdot
.58636 .54364 Mdot
.49505 .42562 Mdot
.52802 .46013 Mdot
.41763 .53591 Mdot
.51092 .47785 Mdot
.53502 .47426 Mdot
.48801 .58454 Mdot
.48224 .4886 Mdot
.50317 .41178 Mdot
.42324 .54236 Mdot
.40868 .46436 Mdot
.45304 .43781 Mdot
.4985 .48437 Mdot
.51245 .51899 Mdot
.55772 .56738 Mdot
.54871 .49168 Mdot
.42165 .46648 Mdot
.48946 .52103 Mdot
.40359 .47401 Mdot
.51032 .4989 Mdot
.54546 .51052 Mdot
.51909 .45464 Mdot
.49269 .44985 Mdot
.43108 .53999 Mdot
.50236 .54813 Mdot
.42374 .49583 Mdot
.45913 .55272 Mdot
.51293 .44322 Mdot
.58204 .5214 Mdot
.4873 .44826 Mdot
.49931 .41505 Mdot
.55178 .49298 Mdot
.56904 .48343 Mdot
.48486 .50893 Mdot
.45048 .50451 Mdot
.50046 .56292 Mdot
.48773 .50051 Mdot
.58997 .49442 Mdot
.44232 .54872 Mdot
.43399 .5194 Mdot
.4246 .44682 Mdot
.5435 .49804 Mdot
.52924 .52098 Mdot
.49143 .59535 Mdot
.44017 .55172 Mdot
.57645 .55489 Mdot
.53583 .54998 Mdot
.55655 .54123 Mdot
.5504 .46698 Mdot
.4475 .56336 Mdot
.51078 .4116 Mdot
.52522 .53742 Mdot
.41451 .54592 Mdot
.48989 .50617 Mdot
.41906 .46036 Mdot
.47491 .51858 Mdot
.46023 .51693 Mdot
.45618 .48593 Mdot
.41223 .48043 Mdot
.47332 .41932 Mdot
.54785 .45347 Mdot
.48202 .48874 Mdot
.44933 .5629 Mdot
.46273 .41619 Mdot
.53281 .57765 Mdot
.4098 .48826 Mdot
.56218 .42846 Mdot
.44071 .56151 Mdot
.4631 .42414 Mdot
.56461 .53172 Mdot
.42564 .55917 Mdot
.43631 .43753 Mdot
.5067 .43269 Mdot
.4814 .58463 Mdot
.45091 .42489 Mdot
.55654 .4232 Mdot
.49452 .46975 Mdot
.47491 .48612 Mdot
.53454 .52771 Mdot
.44266 .51536 Mdot
.47023 .43708 Mdot
.4399 .43122 Mdot
.42576 .4826 Mdot
.49849 .51955 Mdot
.53489 .5046 Mdot
.50745 .55311 Mdot
.45719 .46321 Mdot
.45702 .45603 Mdot
.52984 .53676 Mdot
.48437 .5521 Mdot
.49646 .51639 Mdot
.58264 .55105 Mdot
.54491 .44152 Mdot
.49026 .46844 Mdot
.41061 .45959 Mdot
.49024 .47528 Mdot
.52649 .41235 Mdot
.47924 .41398 Mdot
.43407 .52916 Mdot
.46743 .55467 Mdot
.44753 .48574 Mdot
.49196 .53205 Mdot
.44835 .49729 Mdot
.46121 .51233 Mdot
.5701 .45179 Mdot
.52378 .4998 Mdot
.42532 .45485 Mdot
.40735 .46429 Mdot
.59308 .52379 Mdot
.53706 .5256 Mdot
.53927 .45009 Mdot
.58912 .50601 Mdot
.46979 .48718 Mdot
.58167 .48528 Mdot
.46866 .58614 Mdot
.50932 .42828 Mdot
.4802 .47222 Mdot
.56765 .50937 Mdot
.47638 .55469 Mdot
.48418 .43251 Mdot
.4351 .4897 Mdot
.53537 .46094 Mdot
.51473 .49178 Mdot
.55435 .54294 Mdot
.4242 .44116 Mdot
.43336 .55891 Mdot
.47298 .49131 Mdot
.53404 .461 Mdot
.55866 .57874 Mdot
.57489 .54906 Mdot
.56763 .53898 Mdot
.46094 .45895 Mdot
.51506 .46064 Mdot
.52077 .50155 Mdot
.52476 .52963 Mdot
.54204 .5622 Mdot
.51017 .45331 Mdot
.58716 .51136 Mdot
.46173 .50371 Mdot
.4409 .5394 Mdot
.46333 .47783 Mdot
.42287 .46714 Mdot
.50158 .42423 Mdot
.52449 .55674 Mdot
.52128 .55928 Mdot
.44844 .52696 Mdot
.48286 .54672 Mdot
.41253 .49011 Mdot
.50189 .48626 Mdot
.49992 .4951 Mdot
.40919 .47839 Mdot
.44064 .46186 Mdot
.5253 .57898 Mdot
.48506 .5879 Mdot
.48906 .46814 Mdot
.46501 .5539 Mdot
.50116 .41535 Mdot
.5134 .52377 Mdot
.47729 .43538 Mdot
.54435 .46794 Mdot
.53067 .55965 Mdot
.45529 .53118 Mdot
.55775 .45051 Mdot
.58266 .53405 Mdot
.58698 .46338 Mdot
.50638 .50144 Mdot
.41204 .50596 Mdot
.57215 .4734 Mdot
.5245 .498 Mdot
.57097 .51146 Mdot
.42562 .48049 Mdot
.46702 .53295 Mdot
.47202 .47489 Mdot
.51679 .59445 Mdot
.57438 .49022 Mdot
.47065 .51868 Mdot
.47831 .57906 Mdot
.47575 .47593 Mdot
.58933 .53113 Mdot
.56571 .46939 Mdot
.46303 .58354 Mdot
.50521 .50769 Mdot
.54869 .50786 Mdot
.58737 .5167 Mdot
.48273 .47314 Mdot
.58719 .5333 Mdot
.56641 .46869 Mdot
.5695 .44834 Mdot
.57072 .43943 Mdot
.42132 .48811 Mdot
.58521 .5496 Mdot
.51815 .47265 Mdot
.53686 .50409 Mdot
.52913 .48806 Mdot
.50469 .59445 Mdot
.5303 .54648 Mdot
.54437 .42283 Mdot
.46116 .55347 Mdot
.52876 .54129 Mdot
.47524 .42091 Mdot
.43816 .49381 Mdot
.47918 .51014 Mdot
.47332 .44143 Mdot
.54929 .41616 Mdot
.54517 .47305 Mdot
.55573 .57323 Mdot
.55461 .47099 Mdot
.50534 .57322 Mdot
.45915 .56506 Mdot
.52061 .52442 Mdot
.44658 .52269 Mdot
.47505 .44059 Mdot
.54687 .5855 Mdot
.43996 .49665 Mdot
.49458 .42696 Mdot
.55732 .47047 Mdot
.54559 .5228 Mdot
.57428 .51312 Mdot
.42369 .55432 Mdot
.51681 .50425 Mdot
.47955 .54955 Mdot
.55615 .57828 Mdot
.5684 .56947 Mdot
.48405 .4302 Mdot
.52727 .5962 Mdot
.46265 .51076 Mdot
.48634 .43332 Mdot
.51663 .41588 Mdot
.53548 .47213 Mdot
.54078 .50083 Mdot
.4973 .44296 Mdot
.50832 .53596 Mdot
.49164 .48218 Mdot
.48244 .54212 Mdot
.50988 .47197 Mdot
.54844 .43211 Mdot
.51716 .4757 Mdot
.45414 .44219 Mdot
.44234 .55411 Mdot
.56851 .55829 Mdot
.49431 .43532 Mdot
.4493 .56211 Mdot
.50125 .53088 Mdot
.44373 .54358 Mdot
.50924 .47804 Mdot
.47301 .54748 Mdot
.49415 .59824 Mdot
.49203 .42278 Mdot
.45052 .4203 Mdot
.48702 .52034 Mdot
.45051 .49007 Mdot
.45056 .50682 Mdot
.58758 .52573 Mdot
.44698 .55702 Mdot
.58136 .52752 Mdot
.50512 .53116 Mdot
.4177 .50595 Mdot
.55627 .56963 Mdot
.41632 .51107 Mdot
.47568 .46263 Mdot
.58316 .53754 Mdot
.46586 .48451 Mdot
.51703 .42593 Mdot
.44959 .57984 Mdot
.58613 .49484 Mdot
.50987 .55249 Mdot
.50311 .50764 Mdot
.50099 .54306 Mdot
.5543 .48237 Mdot
.46217 .54909 Mdot
.4858 .42298 Mdot
.54062 .48575 Mdot
.57262 .44964 Mdot
.48537 .48471 Mdot
.46965 .53334 Mdot
.46201 .49053 Mdot
.45273 .45149 Mdot
.41532 .46115 Mdot
.47466 .43773 Mdot
.42573 .46383 Mdot
.53541 .49742 Mdot
.4465 .51103 Mdot
.42883 .49216 Mdot
.50449 .46668 Mdot
.55615 .43546 Mdot
.47957 .5163 Mdot
.49837 .42732 Mdot
.57597 .55813 Mdot
.48199 .51933 Mdot
.50479 .47886 Mdot
.57131 .46693 Mdot
.44122 .51378 Mdot
.52481 .5656 Mdot
.50069 .52571 Mdot
.58817 .45507 Mdot
.48437 .40363 Mdot
.48139 .54613 Mdot
.41803 .45386 Mdot
.53348 .4221 Mdot
.48622 .40249 Mdot
.47282 .42416 Mdot
.53414 .58979 Mdot
.51758 .50159 Mdot
.57406 .49008 Mdot
.56607 .53206 Mdot
.56975 .49256 Mdot
.44032 .54516 Mdot
.42669 .496 Mdot
.47127 .54797 Mdot
.53578 .57254 Mdot
.51027 .42363 Mdot
.47415 .42141 Mdot
.4553 .58631 Mdot
.50398 .41282 Mdot
.41151 .46386 Mdot
.54438 .50802 Mdot
.49608 .43895 Mdot
.47629 .58093 Mdot
.42471 .45027 Mdot
.5404 .50948 Mdot
.42926 .49688 Mdot
.55557 .54574 Mdot
.59489 .49147 Mdot
.45117 .42285 Mdot
.58275 .44726 Mdot
.51537 .522 Mdot
.48187 .48718 Mdot
.43432 .56612 Mdot
.5639 .55164 Mdot
.48108 .53487 Mdot
.5089 .40764 Mdot
.40425 .47386 Mdot
.44012 .49689 Mdot
.472 .43765 Mdot
.50949 .43345 Mdot
.48872 .57879 Mdot
.55307 .54553 Mdot
.44881 .55472 Mdot
.50618 .43398 Mdot
.50249 .5832 Mdot
.57284 .45162 Mdot
.5368 .56325 Mdot
.42622 .55995 Mdot
.55203 .44712 Mdot
.54943 .55476 Mdot
.47313 .51047 Mdot
.47665 .48054 Mdot
.44159 .53294 Mdot
.4989 .42233 Mdot
.47169 .58989 Mdot
.50434 .54023 Mdot
.48547 .54174 Mdot
.44393 .47089 Mdot
.43833 .55287 Mdot
.43544 .52803 Mdot
.5028 .46702 Mdot
.40757 .46889 Mdot
.48541 .49284 Mdot
.53353 .58639 Mdot
.43737 .54295 Mdot
.48238 .45264 Mdot
.44882 .56532 Mdot
.49255 .47067 Mdot
.47727 .56645 Mdot
.43785 .55534 Mdot
.54635 .57865 Mdot
.51387 .54217 Mdot
.45076 .43062 Mdot
.5397 .47029 Mdot
.46016 .57339 Mdot
.55993 .48327 Mdot
.5158 .53093 Mdot
.46382 .49696 Mdot
.55964 .52763 Mdot
.51897 .50655 Mdot
.59636 .51008 Mdot
.55145 .47117 Mdot
.5261 .5193 Mdot
.53811 .49256 Mdot
.48076 .4413 Mdot
.45865 .58567 Mdot
.43985 .44322 Mdot
.446 .45245 Mdot
.47484 .42927 Mdot
.463 .5499 Mdot
.52589 .47461 Mdot
.44393 .48231 Mdot
.53383 .52798 Mdot
.57278 .43158 Mdot
.4984 .52952 Mdot
.54901 .5779 Mdot
.53046 .4217 Mdot
.58226 .55152 Mdot
.48637 .50553 Mdot
.48947 .43571 Mdot
.56762 .49704 Mdot
.48592 .48633 Mdot
.46181 .54252 Mdot
.46269 .57441 Mdot
.46344 .4985 Mdot
.47129 .42173 Mdot
.47844 .50029 Mdot
.5192 .40993 Mdot
.55411 .47812 Mdot
.58942 .46741 Mdot
.50008 .44352 Mdot
.43182 .5129 Mdot
.59269 .50419 Mdot
.55442 .53831 Mdot
.55653 .45366 Mdot
.58565 .51283 Mdot
.45791 .45274 Mdot
.47942 .48875 Mdot
.45505 .53898 Mdot
.54359 .51302 Mdot
.49626 .4891 Mdot
.46724 .54402 Mdot
.52712 .57878 Mdot
.56131 .56661 Mdot
.41512 .53359 Mdot
.48701 .55998 Mdot
.51667 .44792 Mdot
.42101 .49489 Mdot
.41837 .54819 Mdot
.5319 .56854 Mdot
.48671 .57259 Mdot
.45484 .54008 Mdot
.53566 .43643 Mdot
.49486 .52466 Mdot
.5683 .43912 Mdot
.45985 .52875 Mdot
.49789 .49423 Mdot
.43748 .56902 Mdot
.55154 .56626 Mdot
.53841 .53052 Mdot
.58905 .48856 Mdot
.5366 .57316 Mdot
.54872 .48446 Mdot
.55331 .51429 Mdot
.44171 .56248 Mdot
.54903 .50278 Mdot
.49131 .4059 Mdot
.56265 .42224 Mdot
.47583 .59115 Mdot
.49792 .464 Mdot
.46581 .52602 Mdot
.57033 .43717 Mdot
.46929 .4467 Mdot
.54528 .4877 Mdot
.53341 .49274 Mdot
.54815 .58269 Mdot
.53543 .4489 Mdot
.43149 .54528 Mdot
.45483 .55382 Mdot
.52499 .4216 Mdot
.46696 .57037 Mdot
.4735 .56906 Mdot
.52999 .55743 Mdot
.46289 .42788 Mdot
.50084 .47968 Mdot
.5647 .48622 Mdot
.59303 .52428 Mdot
.56865 .52255 Mdot
.43113 .52521 Mdot
.5722 .44287 Mdot
.48952 .51823 Mdot
.47693 .53425 Mdot
.49452 .5661 Mdot
.48228 .57694 Mdot
.49241 .51199 Mdot
.56342 .42495 Mdot
.54937 .41427 Mdot
.54451 .55743 Mdot
.52247 .50615 Mdot
.49571 .50635 Mdot
.54164 .44143 Mdot
.48797 .46209 Mdot
.50661 .4316 Mdot
.42215 .43823 Mdot
.50024 .48203 Mdot
.4455 .47405 Mdot
.49423 .4906 Mdot
.56107 .48393 Mdot
.51606 .50873 Mdot
.58588 .53651 Mdot
.47736 .59633 Mdot
.59129 .48224 Mdot
.47431 .43701 Mdot
.41649 .49034 Mdot
.54627 .58811 Mdot
.54472 .57204 Mdot
.45332 .41396 Mdot
.53218 .44989 Mdot
.49483 .59712 Mdot
.56612 .57203 Mdot
.41376 .5411 Mdot
.48794 .52657 Mdot
.42461 .56042 Mdot
.46176 .4728 Mdot
.56578 .48049 Mdot
.46545 .56278 Mdot
.56799 .51344 Mdot
.4223 .54368 Mdot
.44438 .45388 Mdot
.53108 .44142 Mdot
.43908 .45473 Mdot
.56557 .47678 Mdot
.42801 .53811 Mdot
.54548 .45621 Mdot
.48397 .58393 Mdot
.45849 .49218 Mdot
.45477 .47662 Mdot
.42252 .52541 Mdot
.52456 .41522 Mdot
.4819 .59153 Mdot
.45352 .52022 Mdot
.48108 .43716 Mdot
.57155 .5411 Mdot
.5972 .50465 Mdot
.51111 .49299 Mdot
.44615 .55083 Mdot
.53917 .46342 Mdot
.54921 .53574 Mdot
.48426 .49439 Mdot
.56805 .45082 Mdot
.5498 .50302 Mdot
.56225 .43314 Mdot
.54519 .41124 Mdot
.44513 .53204 Mdot
.55572 .49719 Mdot
.46316 .44333 Mdot
.47343 .54727 Mdot
.40623 .48292 Mdot
.4975 .49214 Mdot
.46821 .43385 Mdot
.42124 .55988 Mdot
.58987 .51615 Mdot
.44426 .43525 Mdot
.41594 .5541 Mdot
.57948 .53259 Mdot
.50334 .5771 Mdot
.4722 .5591 Mdot
.51893 .46792 Mdot
.50263 .53632 Mdot
.45497 .48341 Mdot
.50826 .46551 Mdot
.55788 .55971 Mdot
.47573 .47033 Mdot
.44595 .57522 Mdot
.49838 .56455 Mdot
.53401 .58619 Mdot
.42299 .52934 Mdot
.51674 .54847 Mdot
.46512 .53617 Mdot
.47316 .47716 Mdot
.47423 .52312 Mdot
.46739 .58875 Mdot
.55666 .41796 Mdot
.45947 .51952 Mdot
.41157 .52551 Mdot
.47192 .55154 Mdot
.43746 .51976 Mdot
.44651 .54469 Mdot
.49498 .58652 Mdot
.45588 .51678 Mdot
.54598 .55359 Mdot
.52752 .51511 Mdot
.56152 .50136 Mdot
.54473 .50676 Mdot
.4482 .53411 Mdot
.50272 .49602 Mdot
.52177 .57001 Mdot
.5081 .4193 Mdot
.53276 .50015 Mdot
.47099 .47036 Mdot
.5596 .49681 Mdot
.41069 .53894 Mdot
.5734 .55647 Mdot
.427 .44364 Mdot
.45902 .55577 Mdot
.53905 .42975 Mdot
.51067 .5288 Mdot
.50733 .57989 Mdot
.50398 .57451 Mdot
.4811 .40253 Mdot
.43307 .50388 Mdot
.45033 .5753 Mdot
.49986 .46946 Mdot
.55069 .57795 Mdot
.53834 .47023 Mdot
.50389 .48887 Mdot
.52377 .41633 Mdot
.5103 .55978 Mdot
.54806 .43432 Mdot
.50673 .58484 Mdot
.52056 .47484 Mdot
.50964 .4146 Mdot
.44035 .44521 Mdot
.45639 .41429 Mdot
.55502 .551 Mdot
.5026 .47557 Mdot
.44356 .50928 Mdot
.50493 .52098 Mdot
.56834 .46784 Mdot
.50495 .58222 Mdot
.45437 .58366 Mdot
.49814 .59767 Mdot
.48346 .41195 Mdot
.49567 .45376 Mdot
.47707 .53066 Mdot
.48013 .55013 Mdot
.42402 .50803 Mdot
.51287 .45375 Mdot
.49708 .55057 Mdot
.52065 .4624 Mdot
.42721 .46047 Mdot
.5379 .43985 Mdot
.4118 .50016 Mdot
.53838 .43644 Mdot
.59709 .51806 Mdot
.46556 .54659 Mdot
.58164 .45973 Mdot
.49457 .52047 Mdot
.48289 .45356 Mdot
.49891 .40976 Mdot
.46032 .40884 Mdot
.53905 .56913 Mdot
.46616 .54335 Mdot
.46889 .48323 Mdot
.55701 .54467 Mdot
.57565 .4963 Mdot
.46573 .56572 Mdot
.53776 .46912 Mdot
.44986 .4315 Mdot
.52575 .46439 Mdot
.51899 .5663 Mdot
.46335 .54944 Mdot
.50916 .4308 Mdot
.42096 .53516 Mdot
.47822 .46294 Mdot
.56248 .54828 Mdot
.52976 .42439 Mdot
.48549 .51699 Mdot
.49649 .46688 Mdot
.484 .41132 Mdot
.46862 .55402 Mdot
.55667 .55456 Mdot
.43104 .56627 Mdot
.54859 .50627 Mdot
.54079 .4489 Mdot
.53647 .44011 Mdot
.45399 .51763 Mdot
.5926 .48969 Mdot
.55632 .44849 Mdot
.56186 .434 Mdot
.44473 .54075 Mdot
.49364 .50473 Mdot
.48866 .52615 Mdot
.4386 .48976 Mdot
.51575 .53765 Mdot
.50141 .46164 Mdot
.42459 .45871 Mdot
.53954 .57066 Mdot
.4463 .5456 Mdot
.41824 .5345 Mdot
.50353 .40447 Mdot
.54001 .41004 Mdot
.44797 .45859 Mdot
.45183 .4145 Mdot
.44199 .48438 Mdot
.44093 .5476 Mdot
.46514 .473 Mdot
.5494 .4571 Mdot
.48937 .56664 Mdot
.58605 .48212 Mdot
.56373 .57435 Mdot
.51916 .40262 Mdot
.48559 .48439 Mdot
.50279 .51222 Mdot
.48816 .57674 Mdot
.50654 .47799 Mdot
.54889 .4946 Mdot
.46079 .44313 Mdot
.48484 .48433 Mdot
.52201 .50246 Mdot
.43844 .45382 Mdot
.48364 .54998 Mdot
.48275 .42232 Mdot
.50658 .4464 Mdot
.46143 .56628 Mdot
.51783 .45059 Mdot
.46374 .5924 Mdot
.49729 .54717 Mdot
.42369 .45989 Mdot
.55302 .43182 Mdot
.52606 .57923 Mdot
.57119 .5436 Mdot
.51841 .47362 Mdot
.56308 .51497 Mdot
.44949 .54638 Mdot
.46435 .49603 Mdot
.47216 .5897 Mdot
.5898 .47848 Mdot
.50691 .59446 Mdot
.57597 .47712 Mdot
.53328 .47928 Mdot
.44559 .57664 Mdot
.56575 .48397 Mdot
.45691 .49707 Mdot
.46063 .54468 Mdot
.48561 .41366 Mdot
.50992 .59351 Mdot
.42318 .52177 Mdot
.50185 .50429 Mdot
.49638 .41148 Mdot
.51062 .53065 Mdot
.53817 .50981 Mdot
.40488 .4784 Mdot
.54869 .48135 Mdot
.53134 .43713 Mdot
.48773 .4735 Mdot
.49042 .46399 Mdot
.51498 .55446 Mdot
.49225 .45015 Mdot
.58255 .50064 Mdot
.51254 .45136 Mdot
.40542 .4954 Mdot
.52121 .46804 Mdot
.48264 .41567 Mdot
.45864 .48431 Mdot
.56761 .5111 Mdot
.58338 .49165 Mdot
.44872 .46519 Mdot
.4259 .48803 Mdot
.48344 .48058 Mdot
.55285 .51719 Mdot
.54683 .45945 Mdot
.47626 .49852 Mdot
.45181 .44953 Mdot
.58258 .4523 Mdot
.54582 .5732 Mdot
.43454 .44659 Mdot
.46055 .53474 Mdot
.50759 .49239 Mdot
.59146 .52359 Mdot
.44567 .46088 Mdot
.44772 .42559 Mdot
.51137 .46445 Mdot
.56624 .50673 Mdot
.47212 .49295 Mdot
.43646 .42567 Mdot
.52902 .47016 Mdot
.49323 .45462 Mdot
.43247 .49411 Mdot
.41884 .44751 Mdot
.55131 .45703 Mdot
.50649 .48052 Mdot
.40311 .4753 Mdot
.4627 .52758 Mdot
.59259 .49444 Mdot
.44089 .435 Mdot
.47331 .41595 Mdot
.50277 .59027 Mdot
.56853 .53673 Mdot
.5091 .42275 Mdot
.515 .465 Mdot
.42649 .53612 Mdot
.53771 .57449 Mdot
.55646 .44433 Mdot
.56288 .44505 Mdot
.49092 .43634 Mdot
.55596 .57237 Mdot
.45501 .56627 Mdot
.49164 .47715 Mdot
.44667 .57359 Mdot
.54487 .44967 Mdot
.52294 .45897 Mdot
.48233 .55277 Mdot
.45786 .43896 Mdot
.44431 .555 Mdot
.59454 .51663 Mdot
.49418 .40451 Mdot
.43225 .47786 Mdot
.51574 .47686 Mdot
.41056 .52577 Mdot
.48876 .50807 Mdot
.48762 .51585 Mdot
.51639 .42668 Mdot
.51383 .41054 Mdot
.4948 .4498 Mdot
.46434 .53771 Mdot
.43749 .44987 Mdot
.45077 .46751 Mdot
.56314 .55728 Mdot
.47577 .58838 Mdot
.42025 .4888 Mdot
.58421 .55142 Mdot
.44522 .55738 Mdot
.59596 .48892 Mdot
.51315 .47818 Mdot
.46751 .50893 Mdot
.44585 .5719 Mdot
.45237 .57857 Mdot
.54098 .49875 Mdot
.57039 .49729 Mdot
.54611 .54782 Mdot
.57725 .47559 Mdot
.55488 .42988 Mdot
.56231 .55427 Mdot
.49604 .45976 Mdot
.43601 .55834 Mdot
.51877 .52518 Mdot
.53619 .57108 Mdot
.55154 .51509 Mdot
.57564 .54689 Mdot
.48925 .53297 Mdot
.46959 .54509 Mdot
.42723 .53866 Mdot
.45026 .43739 Mdot
.53825 .41399 Mdot
.51779 .40383 Mdot
.45801 .57391 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go
00001_ooool3o`000?ooooooB?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04
odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0V?ooool4o`0000Kooooo1Ol0002Poooo
o`000oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool0
0ol0003oooooooooo`2Hooooo`Oo000000?oooooo`000?l000001Ol0002Pooooo`000oooool01Ol@
413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`2B
ooooo`;o00001_ooool9o`0000;ooooo0_l00002ooooo`Co0000V_ooool000?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0T_ooool2
o`0000Gooooo0ol000000ooooooo0000o`00000@o`0009Sooooo0003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo08oooooo1_l00000
0ooooooo0000o`000004o`000003ooooool0003o000000[o00000_ooool5o`0009Oooooo000Noooo
o`03o`000?oooooooooo08oooooo1_l000000ooooooo0000o`000004o`0000;ooooo2_l00003oooo
o`;o000000?oooooo`000?l000000ol0002Dooooo`007_ooool00ol0003oooooooooo`2>ooooo`;o
00001Oooool6o`000003ooooool0003o000000;o000000?oooooo`000?l000000_ooool8o`0000;o
oooo1_l0002Booooo`007_ooool00ol0003oooooooooo`2:ooooo`;o000000?oooooo`000?l00000
0_l000000ooooooo0000o`00000Go`0000;ooooo0_l00002ooooo`Co0000T_ooool001kooooo00?o
0000ooooooooool0R_ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000001Ol0
00000ooooooo0000o`00000:o`0000;ooooo0_l00003ooooo`Wo0000TOooool001kooooo00?o0000
ooooooooool0Roooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`Go00000_ooool3
o`000003ooooool0003o000000?o00001Oooool2o`0000;ooooo0ol000000ooooooo0000o`000003
o`0008oooooo000Nooooo`03o`000?oooooooooo08Sooooo0_l000000ooooooo0000o`000003o`00
00Cooooo1?l000001?oooooo0000o`000?l00004ooooo`Co00001oooool2o`000003ooooool0003o
000000;o000000Coooooo`000?l0003ooooo0_l0002?ooooo`007_ooool00ol0003oooooooooo`28
ooooo`Wo00000oooool;o`000003ooooool0003o000000;o00001Oooool4o`000003ooooool0003o
000000Oo0000T?ooool001kooooo00?o0000ooooooooool0QOooool3o`0000;ooooo2Ol000000ooo
oooo0000o`000004o`000003ooooool0003o000000;o00002_ooool4o`0000;ooooo1?l00002oooo
o`;o0000T?ooool001kooooo00?o0000ooooooooool0QOooool8o`000003ooooool0003o000000[o
00000oooool3o`0000?ooooo0_l00004ooooo`Ko00000_ooool2o`0000;ooooo0ol0002?ooooo`00
7_ooool00ol0003oooooooooo`26oooooaCo00001?ooool2o`000003ooooool0003o000000?o0000
0oooool2o`000003ooooool0003o000000Oo000000Coooooo`000?l0003ooooo0_l0002<ooooo`00
7_ooool00ol0003oooooooooo`23ooooo`Go000000?oooooo`000?l000001_l00002ooooo`?o0000
1?ooool5o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`oo000000?oooooo`000?l00000
S?ooool001kooooo0_l00024ooooo`Go00000_ooool2o`000003ooooool0003o000000Co00001_oo
ool6o`0000?ooooo1?l000000ooooooo0000o`000007o`000003ooooool0003o000000;ooooo0ol0
00000ooooooo0000o`00002<ooooo`007_ooool00ol0003oooooooooo`24ooooo`Co00000_ooool9
o`0000Cooooo2?l00003ooooo`Oo00001?ooool3o`000005ooooool0003o0000o`000?ooool00ol0
00000ooooooo0000o`000002o`0008[ooooo000Nooooo`03o`000?oooooooooo087ooooo0_l00000
0ooooooo0000o`000002o`0000;ooooo2_l00003ooooo`;o000000?oooooo`000?l000000ol00004
ooooo`Go000000?oooooo`000?l000000_ooool7o`0000Gooooo1?l0002:ooooo`007_ooool00ol0
003oooooooooo`21ooooo`So00000_ooool5o`0000;ooooo0_l00003ooooo`;o00000_ooool6o`00
00;ooooo2Ol00002ooooo`?o00002?ooool2o`0008cooooo000Nooooo`03o`000?oooooooooo083o
oooo2_l000000ooooooo0000o`000003o`000003ooooool0003o000000Cooooo0_l00002oooooa;o
00000_ooool2o`0000[ooooo0_l0002:ooooo`007_ooool00ol0003oooooooooo`20ooooo`Co0000
00?oooooo`000?l000000ol00004ooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo
3_l000000ooooooo0000o`000007o`000003ooooool0003o000000;o00000oooool3o`0008Wooooo
000Nooooo`03o`000?oooooooooo083ooooo0_l00002ooooo`?o00001Oooool4o`0000Cooooo1Ol0
0002ooooo`co000000Coooooo`000?l0003ooooo2?l000000ooooooo0000o`000002o`0000Cooooo
0_l00029ooooo`007_ooool00ol0003oooooooooo`1oooooo`;o000000?oooooo`000?l000000_l0
0006ooooo`?o00000oooool>o`000003ooooool0003o0000013o000000?oooooo`000?l000000_l0
0002ooooo`;o0000Roooool001kooooo00?o0000ooooooooool0Ooooool2o`000003ooooool0003o
000000Cooooo0_l00003ooooo`;o000000?oooooo`000?l000003?l000000ooooooo0000o`00000;
o`000004ooooool0003o0000ooooo`;o00000_ooool8o`0008_ooooo000Nooooo`03o`000?oooooo
oooo07oooooo1Ol00002ooooo`Co00001?ooool4o`000004ooooool0003o0000ooooo`So000000?o
ooooo`000?l000001Ol00003ooooo`;o000000?oooooo`000?l000000_ooool2o`000005ooooool0
003o0000o`000?ooool01ol00029ooooo`007_ooool00ol0003oooooooooo`1oooooo`Go00000_oo
ool2o`0000Cooooo1ol000001?oooooo0000o`000?ooool7o`000003ooooool0003o000000;o0000
1_ooool2o`000003ooooool0003o000000[o00000_ooool4o`0008Wooooo000Nooooo`03o`000?oo
oooooooo07oooooo0ol00004ooooo`;o00001?ooool3o`000003ooooool0003o000000Ko000000?o
ooooo`000?l000001_l00005ooooo`;o00001?oooolBo`0008Wooooo000Nooooo`03o`000?oooooo
oooo087ooooo1ol000000ooooooo0000o`000007o`000003ooooool0003o000000Oo000000?ooooo
o`000?l000001?l00003ooooo`Co000000?oooooo`000?l000000ol00003ooooo`;o00000_ooool9
o`0008Oooooo000Nooooo`03o`000?oooooooooo083ooooo3?l00002ooooo`Ko000000?oooooo`00
0?l000001Ol000000ooooooo0000o`000006o`0000?ooooo2ol00002ooooo`_o0000Qoooool001ko
oooo00?o0000ooooooooool0P?ooool2o`0000?ooooo1ol00005ooooo`_o000000?oooooo`000?l0
00001_l00004ooooo`[o000000?oooooo`000?l000000ol000000ooooooo0000o`000003o`0008So
oooo000Nooooo`03o`000?oooooooooo07kooooo1?l00003ooooo`So000000?oooooo`000?l00000
1Ol00002ooooo`Co00000oooool3o`000003ooooool0003o000000;ooooo0_l00002ooooo`Ko0000
00?oooooo`000?l000001_l000000ooooooo0000o`000003o`0008Sooooo000Nooooo`;o0000Oooo
ool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o000000Go00000_oo
ool2o`000004ooooool0003o0000o`0000?ooooo2?l000000ooooooo0000o`000005o`000003oooo
ool0003o000000Co00000_ooool2o`0008cooooo000Nooooo`03o`000?oooooooooo08;ooooo0_l0
0005ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l0
00000ooooooo0000o`000007o`000003ooooool0003o000000Wo00001?ooool3o`0000;ooooo0ol0
0027ooooo`007_ooool00ol0003oooooooooo`22ooooo`Ko000000?oooooo`000?l000000_l00000
0ooooooo0000o`000002ooooo`Co000000Coooooo`000?l0003ooooo3_l00002ooooo`Oo00000ooo
ool2o`0000;ooooo0_l000000ooooooo0000o`000003o`0008Oooooo000Nooooo`03o`000?oooooo
oooo08;ooooo2?l000000ooooooo0000o`000003o`0000;ooooo4?l00002ooooo`Co00000oooool5
o`0000Cooooo1?l00003ooooo`;o000000?oooooo`000?l00000Qoooool001kooooo00?o0000oooo
ooooool0Poooool3o`0000;ooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l00002oooo
o`Co00000_ooool2o`000003ooooool0003o000000[ooooo3_l000001Ooooooo0000o`000?l0003o
oooo00;o0000Qoooool001kooooo00?o0000ooooooooool0Q?ooool2o`0000;ooooo0_l000001Ooo
oooo0000o`000?l0003ooooo00Go00000_ooool6o`000003ooooool0003o000000;o00001_ooool2
o`0000Cooooo3?l000000ooooooo0000o`000004o`0008Oooooo000Nooooo`03o`000?oooooooooo
087ooooo0_l00006ooooo`Go000000?oooooo`000?l000000ol000000ooooooo0000o`00000=o`00
00?ooooo0ol00006ooooo`;o00002Oooool5o`0008Oooooo000Nooooo`03o`000?oooooooooo07oo
oooo1?l000001Ooooooo0000o`000?l0003ooooo00Co000000?oooooo`000?l000001?l00002oooo
o`?o000000?oooooo`000?l000002_l00002ooooo`?o00000oooool2o`0000Kooooo1_l000001?oo
oooo0000o`000?l00028ooooo`007_ooool00ol0003oooooooooo`1oooooo`So000000?oooooo`00
0?l000000_ooool5o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`Ko00000_ooool4o`00
00?ooooo0_l000001?oooooo0000o`000?l00005ooooo`[o0000R?ooool001kooooo00?o0000oooo
ooooool0POooool6o`000005ooooool0003o0000o`000?ooool02Ol000000ooooooo0000o`000003
ooooo`Ko000000Coooooo`000?l0003ooooo0ol000001?oooooo0000o`000?l00002ooooo`;o0000
0_ooool2o`000003ooooool0003o000000;ooooo1?l0002:ooooo`007_ooool00ol0003ooooooooo
o`23ooooo`Co00000_ooool6o`000003ooooool0003o000000Oo00000_ooool=o`000003ooooool0
003o000000;o00001Oooool5o`000003ooooool0003o000000?o0000R_ooool001kooooo00?o0000
ooooooooool0Poooool6o`0000;ooooo3ol000001Ooooooo0000o`000?l0003ooooo00Oo00001Ooo
ool2o`000003ooooool0003o000000?ooooo1?l000000ooooooo0000o`000003o`0008[ooooo000N
ooooo`03o`000?oooooooooo087ooooo2?l00002ooooo`[o000000?oooooo`000?l000000_l00005
ooooo`Co000000Coooooo`000?l0003ooooo0ol00004ooooo`Co00000_ooool3o`0000;ooooo0ol0
002;ooooo`007_ooool00ol0003oooooooooo`21ooooo`?o000000?oooooo`000?l000002?l00000
0ooooooo0000o`000003o`0000Cooooo1Ol00002ooooo`;o000000Goooooo`000?l0003o0000oooo
o`03o`0000Cooooo1Ol000000ooooooo0000o`000002o`000003ooooool0003o000008cooooo000N
ooooo`03o`000?oooooooooo08;ooooo0_l000000ooooooo0000o`000008o`000003ooooool0003o
000000Go00000_ooool5o`000003ooooool0003o000000Co00000oooool2o`0000Cooooo1Ol00003
ooooo`;o00000oooool2o`0008[ooooo000Nooooo`03o`000?oooooooooo08?ooooo3Ol000000ooo
oooo0000o`000008o`0000?ooooo0ol000000ooooooo0000o`000002o`0000;ooooo0_l00003oooo
o`;o000000?oooooo`000?l000000ol000001?oooooo0000o`000?l00002ooooo`;o0000R_ooool0
01kooooo0_l00024ooooo`?o00001Oooool5o`000003ooooool0003o000000So00000_ooool4o`00
00?ooooo0_l00002ooooo`Co000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000002
ooooo`Go0000Roooool001kooooo00?o0000ooooooooool0Poooool2o`000003ooooool0003o0000
00;ooooo4Ol00002ooooo`So000000?oooooo`000?l000000_ooool2o`000003ooooool0003o0000
00Ko00000_ooool5o`0008_ooooo000Nooooo`03o`000?oooooooooo08?ooooo0_l000000ooooooo
0000o`000002ooooo`co000000?oooooo`000?l000000_l00004ooooo`Ko000000?oooooo`000?l0
00000_l00003ooooo`So000000Coooooo`000?l0003o0000S_ooool001kooooo00?o0000oooooooo
ool0QOooool:o`000003ooooool0003o000000;o000000?oooooo`000?l000000oooool2o`0000Ko
oooo0_l000000ooooooo0000o`000003o`0000?ooooo0_l00002ooooo`So0000S_ooool001kooooo
00?o0000ooooooooool0QOoooolBo`0000?ooooo0_l00003ooooo`;o000000Coooooo`000?l0003o
oooo0_l000000ooooooo0000o`000004o`0000?ooooo0_l00002ooooo`;o0000T?ooool001kooooo
00?o0000ooooooooool0R?ooool=o`0000;ooooo0_l00002ooooo`Ko00001?ooool4o`000003oooo
ool0003o000000;o000000?oooooo`000?l000000ol0002Cooooo`007_ooool00ol0003ooooooooo
o`28ooooo`Go000000?oooooo`000?l000002Ol00002ooooo`Go00001Oooool8o`0000;ooooo1Ol0
00000ooooooo0000o`00002@ooooo`007_ooool00ol0003oooooooooo`2:ooooo`Go000000Gooooo
o`000?l0003o0000ooooo`04o`0000;ooooo0_l00004ooooo`;o00001?ooool2o`000003ooooool0
003o000000So000000Coooooo`000?l0003o0000T?ooool001kooooo00?o0000ooooooooool0Rooo
ool9o`0000Kooooo0_l00004ooooo`;o00001_ooool7o`0000;ooooo1Ol0002Aooooo`007_ooool0
0ol0003oooooooooo`2=ooooo`So00000_ooool6o`000003ooooool0003o000000;o00001Oooool>
o`0009;ooooo000Nooooo`03o`000?oooooooooo08gooooo1?l00002ooooo`;o00000_ooool6o`00
0003ooooool0003o000000?o00001?ooool=o`0009?ooooo000Nooooo`03o`000?oooooooooo08ko
oooo1_l00003ooooo`go00002_ooool2o`0009Oooooo000Nooooo`03o`000?oooooooooo093ooooo
5?l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000_l0002Gooooo`007_oo
ool00ol0003oooooooooo`2@ooooo`;o00000_ooool8o`000003ooooool0003o000000;o00000_oo
ool4o`0000;ooooo1_l0002Hooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2Cooooo`So0000
1?ooool9o`0000;ooooo0_l0002Kooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2Cooooo`;o
00000_ooool2o`0000?ooooo3Ol0002Nooooo`000oooool01Ol@413ooooooooooooooooo410@00_o
oooo00Go0000ooooooooooooooooo`000006ooooo`?o0000Uoooool2o`0000?ooooo1?l00007oooo
o`;o0000W_ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9Sooooo
oiRHV?lQ8B401_ooool00ol0003oooooooooo`2Mooooo`;o0000Z?ooool000?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003ooooooooo
o`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7oooo
o`08ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0oooooom8ooooo`000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o
0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<
ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo
00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo
00Go0000ooooooooooooooooo`000006ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooo
oooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooooooo
0?ooooooB?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0oooo
oom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zj
o`000006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000D
ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3oooooodSooooo000Foooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom8ooooo`005_ooool00ol0003o
ooooooooo`05ooooo`?o0000oooooom8ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo
000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@
ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Dooooo`03oeEEEOmVIVKo00000?oo
ooooD_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.51337 .5718 Mdot
.534 .46471 Mdot
.55428 .4386 Mdot
.53711 .47341 Mdot
.55134 .50698 Mdot
.47656 .56793 Mdot
.57756 .45261 Mdot
.55597 .53776 Mdot
.44061 .43706 Mdot
.45195 .53846 Mdot
.50712 .55186 Mdot
.48312 .4897 Mdot
.47493 .57218 Mdot
.5779 .5075 Mdot
.49058 .41575 Mdot
.44672 .53383 Mdot
.56536 .5032 Mdot
.43027 .54743 Mdot
.44796 .54264 Mdot
.46176 .4701 Mdot
.56809 .52458 Mdot
.41642 .4955 Mdot
.53529 .53501 Mdot
.51688 .58044 Mdot
.55219 .54825 Mdot
.4794 .50072 Mdot
.46796 .42955 Mdot
.44834 .54537 Mdot
.53932 .49301 Mdot
.48764 .57633 Mdot
.55227 .44955 Mdot
.55542 .48772 Mdot
.50728 .50702 Mdot
.49985 .43334 Mdot
.4803 .57451 Mdot
.53694 .43054 Mdot
.47273 .50634 Mdot
.44636 .44642 Mdot
.5467 .52582 Mdot
.46817 .49319 Mdot
.46996 .52016 Mdot
.44568 .47974 Mdot
.52808 .44388 Mdot
.50891 .4924 Mdot
.56188 .50073 Mdot
.44356 .52446 Mdot
.5797 .50377 Mdot
.56245 .45784 Mdot
.53787 .43636 Mdot
.41834 .45889 Mdot
.54847 .51584 Mdot
.4569 .57335 Mdot
.53435 .48687 Mdot
.5533 .52528 Mdot
.43631 .53886 Mdot
.4431 .51037 Mdot
.49003 .46215 Mdot
.45422 .57748 Mdot
.5581 .49931 Mdot
.49323 .45618 Mdot
.42554 .52161 Mdot
.45654 .51672 Mdot
.48328 .44489 Mdot
.45148 .53176 Mdot
.54134 .51543 Mdot
.43922 .43367 Mdot
.56272 .47561 Mdot
.43605 .52069 Mdot
.44679 .49181 Mdot
.43963 .53614 Mdot
.54081 .42151 Mdot
.55259 .4955 Mdot
.48018 .46629 Mdot
.51373 .4772 Mdot
.49576 .58117 Mdot
.48805 .4264 Mdot
.43469 .50309 Mdot
.44139 .54989 Mdot
.55346 .42772 Mdot
.50366 .53598 Mdot
.44886 .45263 Mdot
.55204 .54342 Mdot
.5624 .53898 Mdot
.46311 .52038 Mdot
.4888 .44069 Mdot
.52194 .47978 Mdot
.50373 .42608 Mdot
.44397 .51845 Mdot
.46864 .48897 Mdot
.44988 .5574 Mdot
.53702 .5003 Mdot
.44029 .52938 Mdot
.47021 .43915 Mdot
.43109 .44097 Mdot
.56496 .44241 Mdot
.42092 .50704 Mdot
.4414 .51626 Mdot
.55992 .45869 Mdot
.5798 .49988 Mdot
.49919 .45752 Mdot
.49471 .42903 Mdot
.47229 .44124 Mdot
.55931 .51228 Mdot
.41277 .47429 Mdot
.44945 .43106 Mdot
.50014 .50664 Mdot
.58408 .53409 Mdot
.54202 .50949 Mdot
.55132 .46126 Mdot
.43846 .53044 Mdot
.52731 .57409 Mdot
.55174 .49309 Mdot
.50039 .47092 Mdot
.43133 .45478 Mdot
.57232 .50742 Mdot
.45363 .56946 Mdot
.45785 .43313 Mdot
.43068 .54458 Mdot
.56376 .45102 Mdot
.46638 .43984 Mdot
.48516 .54523 Mdot
.48946 .49773 Mdot
.44675 .53954 Mdot
.54492 .442 Mdot
.55404 .47971 Mdot
.42102 .47123 Mdot
.51385 .57938 Mdot
.48652 .49937 Mdot
.50258 .49606 Mdot
.46691 .52465 Mdot
.49683 .54119 Mdot
.56914 .51065 Mdot
.49545 .58936 Mdot
.51414 .4326 Mdot
.53179 .54802 Mdot
.51472 .5877 Mdot
.40951 .49546 Mdot
.52286 .49439 Mdot
.46457 .48002 Mdot
.49972 .4806 Mdot
.5406 .50568 Mdot
.44923 .43347 Mdot
.50275 .50109 Mdot
.53839 .47899 Mdot
.51807 .513 Mdot
.43392 .53054 Mdot
.50516 .57423 Mdot
.42309 .49904 Mdot
.57338 .51155 Mdot
.53814 .43825 Mdot
.495 .43964 Mdot
.44634 .54604 Mdot
.54455 .50265 Mdot
.57691 .51726 Mdot
.50058 .54502 Mdot
.44509 .53448 Mdot
.46359 .51502 Mdot
.48684 .5844 Mdot
.43549 .50222 Mdot
.52925 .51253 Mdot
.51042 .41745 Mdot
.43917 .49239 Mdot
.47158 .54886 Mdot
.4234 .53517 Mdot
.47634 .47915 Mdot
.49006 .47228 Mdot
.45763 .4261 Mdot
.43844 .46703 Mdot
.42532 .4904 Mdot
.4366 .45403 Mdot
.4822 .53409 Mdot
.53441 .43861 Mdot
.52926 .45805 Mdot
.4735 .48009 Mdot
.53381 .41804 Mdot
.45375 .51139 Mdot
.41822 .50538 Mdot
.53242 .5147 Mdot
.56502 .56112 Mdot
.51475 .43515 Mdot
.53391 .47337 Mdot
.41954 .51143 Mdot
.51464 .48418 Mdot
.53616 .4872 Mdot
.46675 .57081 Mdot
.48783 .48623 Mdot
.52534 .4244 Mdot
.42318 .51822 Mdot
.42869 .44548 Mdot
.47556 .43462 Mdot
.50239 .48654 Mdot
.50491 .51912 Mdot
.53296 .57437 Mdot
.54376 .50515 Mdot
.44052 .45118 Mdot
.48458 .51548 Mdot
.4216 .45255 Mdot
.5086 .5014 Mdot
.5362 .52031 Mdot
.52773 .46642 Mdot
.50655 .45576 Mdot
.43086 .51814 Mdot
.48808 .54204 Mdot
.43545 .4777 Mdot
.45039 .53538 Mdot
.52548 .45501 Mdot
.56609 .53987 Mdot
.50239 .45295 Mdot
.52114 .42647 Mdot
.54609 .50705 Mdot
.56332 .5037 Mdot
.48428 .50408 Mdot
.45671 .49265 Mdot
.48291 .55463 Mdot
.48911 .49749 Mdot
.57997 .51863 Mdot
.43785 .5281 Mdot
.43856 .50136 Mdot
.44782 .43465 Mdot
.53763 .50912 Mdot
.51915 .52512 Mdot
.46711 .58199 Mdot
.43528 .53005 Mdot
.55301 .56839 Mdot
.51784 .55291 Mdot
.53847 .55056 Mdot
.55133 .48497 Mdot
.43806 .54153 Mdot
.53195 .4261 Mdot
.51143 .53876 Mdot
.41379 .5193 Mdot
.48927 .50282 Mdot
.43956 .44509 Mdot
.4731 .51023 Mdot
.46139 .50568 Mdot
.46644 .47759 Mdot
.42828 .46073 Mdot
.4978 .42355 Mdot
.55278 .47266 Mdot
.48761 .4863 Mdot
.43972 .54155 Mdot
.48925 .41761 Mdot
.50847 .57685 Mdot
.42411 .467 Mdot
.57262 .45363 Mdot
.43292 .53843 Mdot
.48779 .42521 Mdot
.54791 .54418 Mdot
.42062 .53309 Mdot
.46062 .42966 Mdot
.52285 .44425 Mdot
.46096 .56907 Mdot
.47689 .42246 Mdot
.56909 .44762 Mdot
.50298 .47332 Mdot
.48247 .48242 Mdot
.52217 .53249 Mdot
.44702 .50012 Mdot
.49073 .43866 Mdot
.46543 .42505 Mdot
.44046 .46644 Mdot
.49261 .51617 Mdot
.52843 .51248 Mdot
.49146 .54781 Mdot
.47288 .45798 Mdot
.47442 .45167 Mdot
.51574 .53942 Mdot
.47122 .54095 Mdot
.4918 .51302 Mdot
.55971 .56671 Mdot
.55349 .46149 Mdot
.49978 .47112 Mdot
.43163 .44181 Mdot
.49803 .477 Mdot
.54548 .43057 Mdot
.50419 .42019 Mdot
.43612 .50985 Mdot
.45654 .53898 Mdot
.459 .47521 Mdot
.48353 .52553 Mdot
.45676 .48569 Mdot
.46353 .50187 Mdot
.5728 .47656 Mdot
.52 .50549 Mdot
.44663 .44201 Mdot
.42743 .44502 Mdot
.576 .54521 Mdot
.52494 .53125 Mdot
.5463 .46761 Mdot
.57637 .52844 Mdot
.47781 .48206 Mdot
.57443 .50856 Mdot
.44961 .56708 Mdot
.52621 .44104 Mdot
.4905 .47186 Mdot
.55587 .52537 Mdot
.4638 .54118 Mdot
.50378 .43836 Mdot
.44702 .47533 Mdot
.54001 .47594 Mdot
.51427 .49659 Mdot
.5361 .55152 Mdot
.44869 .42939 Mdot
.42764 .53448 Mdot
.47941 .48636 Mdot
.53885 .47565 Mdot
.53134 .5853 Mdot
.55288 .56258 Mdot
.54883 .55151 Mdot
.47716 .45528 Mdot
.5227 .47057 Mdot
.51692 .50624 Mdot
.51297 .53165 Mdot
.52036 .56544 Mdot
.5205 .46309 Mdot
.57327 .53252 Mdot
.46645 .49446 Mdot
.43915 .52013 Mdot
.47474 .47237 Mdot
.44148 .45209 Mdot
.52064 .43555 Mdot
.50605 .55578 Mdot
.50255 .55714 Mdot
.44876 .51176 Mdot
.47144 .53598 Mdot
.42623 .46943 Mdot
.50475 .48892 Mdot
.50067 .49571 Mdot
.42587 .45805 Mdot
.4586 .45233 Mdot
.50147 .57599 Mdot
.46334 .57318 Mdot
.49886 .47056 Mdot
.45479 .53775 Mdot
.52265 .42721 Mdot
.50443 .52347 Mdot
.49721 .43906 Mdot
.54583 .48426 Mdot
.5109 .56008 Mdot
.45325 .51694 Mdot
.56225 .47248 Mdot
.56369 .55132 Mdot
.58556 .49072 Mdot
.50451 .50259 Mdot
.42188 .4835 Mdot
.5686 .49599 Mdot
.52108 .50415 Mdot
.55829 .52807 Mdot
.44083 .46454 Mdot
.46235 .52084 Mdot
.48304 .47212 Mdot
.48999 .58811 Mdot
.56625 .51087 Mdot
.46954 .50942 Mdot
.45969 .56289 Mdot
.48592 .47396 Mdot
.57075 .5507 Mdot
.56403 .4909 Mdot
.44555 .56305 Mdot
.50175 .50763 Mdot
.53972 .51887 Mdot
.57223 .53727 Mdot
.49238 .4733 Mdot
.5682 .552 Mdot
.56483 .49047 Mdot
.57326 .47333 Mdot
.57709 .4655 Mdot
.43504 .47011 Mdot
.56254 .5662 Mdot
.52211 .4816 Mdot
.53029 .51256 Mdot
.52762 .49711 Mdot
.47913 .58478 Mdot
.51375 .54828 Mdot
.55817 .44468 Mdot
.45182 .53648 Mdot
.51365 .54319 Mdot
.49909 .42556 Mdot
.4487 .47983 Mdot
.4792 .50387 Mdot
.49227 .4433 Mdot
.56464 .43946 Mdot
.54524 .48879 Mdot
.52984 .5792 Mdot
.55395 .48945 Mdot
.48494 .56509 Mdot
.44722 .54569 Mdot
.51061 .5259 Mdot
.44836 .50759 Mdot
.49397 .44302 Mdot
.51921 .58821 Mdot
.44956 .48284 Mdot
.51401 .4362 Mdot
.55645 .4897 Mdot
.53324 .531 Mdot
.5608 .53042 Mdot
.42025 .5285 Mdot
.51276 .50758 Mdot
.46777 .53758 Mdot
.52915 .5841 Mdot
.5423 .5795 Mdot
.50426 .43631 Mdot
.499 .59265 Mdot
.46519 .50081 Mdot
.5054 .43963 Mdot
.53584 .43151 Mdot
.5371 .48553 Mdot
.53455 .51077 Mdot
.51222 .4509 Mdot
.49669 .53291 Mdot
.49732 .48309 Mdot
.47243 .53197 Mdot
.5153 .47901 Mdot
.55918 .45395 Mdot
.52048 .48392 Mdot
.47539 .43876 Mdot
.4364 .53255 Mdot
.54499 .56925 Mdot
.51164 .44345 Mdot
.43992 .54087 Mdot
.49182 .52662 Mdot
.44038 .52424 Mdot
.51317 .48393 Mdot
.46297 .53428 Mdot
.46881 .58546 Mdot
.51293 .43177 Mdot
.47749 .41795 Mdot
.48273 .51436 Mdot
.46049 .47983 Mdot
.45615 .49471 Mdot
.57033 .54532 Mdot
.43942 .53604 Mdot
.564 .5451 Mdot
.49514 .52783 Mdot
.42724 .48506 Mdot
.53115 .57604 Mdot
.42466 .48927 Mdot
.48906 .4624 Mdot
.56334 .55458 Mdot
.47516 .47879 Mdot
.53342 .44088 Mdot
.43512 .5563 Mdot
.57622 .51796 Mdot
.4938 .54793 Mdot
.49993 .50707 Mdot
.48826 .53725 Mdot
.55085 .49892 Mdot
.45381 .5331 Mdot
.50758 .43031 Mdot
.53817 .49816 Mdot
.57575 .47523 Mdot
.49147 .48371 Mdot
.46439 .52172 Mdot
.47024 .48305 Mdot
.47178 .44654 Mdot
.43579 .44465 Mdot
.49437 .44042 Mdot
.44487 .45001 Mdot
.53073 .5065 Mdot
.45149 .49734 Mdot
.44088 .47581 Mdot
.51214 .47315 Mdot
.56513 .45867 Mdot
.47768 .50926 Mdot
.51711 .43748 Mdot
.55182 .57123 Mdot
.4788 .5124 Mdot
.50919 .48352 Mdot
.56959 .49019 Mdot
.44621 .49834 Mdot
.50425 .56372 Mdot
.49274 .52195 Mdot
.5892 .48346 Mdot
.5112 .41199 Mdot
.47033 .53513 Mdot
.44007 .43899 Mdot
.54876 .44145 Mdot
.51311 .41144 Mdot
.49622 .42792 Mdot
.50676 .58858 Mdot
.51415 .50549 Mdot
.56599 .51067 Mdot
.54912 .54488 Mdot
.56167 .5116 Mdot
.43715 .52469 Mdot
.43808 .47867 Mdot
.46143 .53429 Mdot
.51233 .57296 Mdot
.52822 .43716 Mdot
.49803 .42573 Mdot
.43807 .56393 Mdot
.52576 .42556 Mdot
.43151 .44589 Mdot
.53588 .51788 Mdot
.51222 .44708 Mdot
.45747 .56411 Mdot
.44715 .4378 Mdot
.53202 .51811 Mdot
.44012 .48015 Mdot
.53648 .55437 Mdot
.58537 .51739 Mdot
.47754 .42058 Mdot
.58628 .47519 Mdot
.50665 .52244 Mdot
.48792 .48495 Mdot
.42615 .54102 Mdot
.54244 .56194 Mdot
.47341 .52549 Mdot
.53142 .42196 Mdot
.42226 .4526 Mdot
.44965 .4831 Mdot
.4921 .43964 Mdot
.52503 .44561 Mdot
.4688 .56557 Mdot
.53431 .55352 Mdot
.44155 .53457 Mdot
.52208 .44525 Mdot
.47994 .5736 Mdot
.57538 .47704 Mdot
.51548 .56494 Mdot
.4209 .5339 Mdot
.55816 .46813 Mdot
.52876 .56083 Mdot
.47406 .50283 Mdot
.48544 .47811 Mdot
.44143 .51502 Mdot
.51887 .43311 Mdot
.45121 .5715 Mdot
.492 .53562 Mdot
.47516 .53236 Mdot
.45942 .46113 Mdot
.43344 .53057 Mdot
.43757 .50925 Mdot
.51063 .47303 Mdot
.42657 .44916 Mdot
.48929 .49053 Mdot
.50703 .58522 Mdot
.43529 .52215 Mdot
.49712 .45547 Mdot
.43862 .54348 Mdot
.50111 .47362 Mdot
.46179 .55152 Mdot
.43236 .53252 Mdot
.52025 .58159 Mdot
.50003 .5399 Mdot
.4754 .42766 Mdot
.54121 .48506 Mdot
.4459 .55294 Mdot
.5555 .50115 Mdot
.50468 .53044 Mdot
.47006 .48905 Mdot
.54451 .53913 Mdot
.51401 .51009 Mdot
.58226 .53401 Mdot
.55116 .4888 Mdot
.51681 .52286 Mdot
.53431 .50314 Mdot
.49863 .44515 Mdot
.44118 .56407 Mdot
.46244 .43572 Mdot
.46562 .44555 Mdot
.49669 .43308 Mdot
.45425 .53396 Mdot
.52819 .48516 Mdot
.45669 .47117 Mdot
.52148 .53255 Mdot
.58153 .45867 Mdot
.48973 .52477 Mdot
.52278 .58163 Mdot
.54623 .44035 Mdot
.55924 .56703 Mdot
.48653 .50149 Mdot
.50744 .44255 Mdot
.55874 .5148 Mdot
.49148 .4852 Mdot
.45538 .52762 Mdot
.44774 .55447 Mdot
.46933 .49031 Mdot
.49547 .42523 Mdot
.4815 .49523 Mdot
.53977 .42657 Mdot
.55173 .49533 Mdot
.58676 .49487 Mdot
.51443 .4521 Mdot
.43837 .49508 Mdot
.58017 .52785 Mdot
.53729 .54735 Mdot
.56031 .47493 Mdot
.5715 .53337 Mdot
.476 .44903 Mdot
.48547 .4857 Mdot
.4509 .52324 Mdot
.53393 .52198 Mdot
.49926 .48992 Mdot
.45934 .53008 Mdot
.50314 .57631 Mdot
.5364 .57471 Mdot
.41774 .50878 Mdot
.47171 .54848 Mdot
.52747 .46005 Mdot
.4331 .47609 Mdot
.4169 .5221 Mdot
.50987 .5683 Mdot
.4685 .55938 Mdot
.45042 .52408 Mdot
.54684 .45471 Mdot
.48808 .51977 Mdot
.57493 .4647 Mdot
.45768 .51585 Mdot
.49922 .49454 Mdot
.42792 .54424 Mdot
.52774 .57164 Mdot
.52494 .53605 Mdot
.58056 .51332 Mdot
.5129 .57375 Mdot
.54552 .49918 Mdot
.54218 .52563 Mdot
.43346 .53949 Mdot
.54128 .51459 Mdot
.51666 .41593 Mdot
.57499 .44796 Mdot
.45447 .57379 Mdot
.5073 .46924 Mdot
.46338 .51476 Mdot
.57744 .46333 Mdot
.48746 .44683 Mdot
.54174 .50097 Mdot
.53017 .50208 Mdot
.52097 .58593 Mdot
.54332 .4656 Mdot
.42984 .52262 Mdot
.44665 .53526 Mdot
.54147 .43894 Mdot
.45229 .55217 Mdot
.458 .55276 Mdot
.51083 .55792 Mdot
.48671 .42857 Mdot
.50562 .48324 Mdot
.55889 .50489 Mdot
.57584 .54563 Mdot
.55366 .53711 Mdot
.43466 .5057 Mdot
.57742 .46896 Mdot
.48545 .51309 Mdot
.4701 .52404 Mdot
.47693 .55584 Mdot
.46362 .562 Mdot
.48968 .50837 Mdot
.57482 .45069 Mdot
.56533 .43764 Mdot
.52372 .56187 Mdot
.51716 .51062 Mdot
.49405 .50425 Mdot
.55067 .46062 Mdot
.49947 .46507 Mdot
.52305 .44327 Mdot
.44738 .4261 Mdot
.50448 .48503 Mdot
.46008 .46432 Mdot
.49718 .49069 Mdot
.55632 .50201 Mdot
.51088 .51124 Mdot
.56619 .55449 Mdot
.45449 .57917 Mdot
.58438 .5084 Mdot
.49426 .4397 Mdot
.42992 .47075 Mdot
.51809 .59051 Mdot
.52032 .57499 Mdot
.4813 .41272 Mdot
.54027 .46564 Mdot
.46969 .58459 Mdot
.53964 .58121 Mdot
.41441 .51497 Mdot
.48167 .51991 Mdot
.41925 .53399 Mdot
.47461 .46758 Mdot
.56125 .50035 Mdot
.45294 .54537 Mdot
.55522 .52895 Mdot
.42192 .51912 Mdot
.46383 .44637 Mdot
.54156 .45796 Mdot
.45892 .44567 Mdot
.56199 .49718 Mdot
.42867 .51583 Mdot
.54999 .47444 Mdot
.46337 .56911 Mdot
.46678 .48363 Mdot
.4676 .46906 Mdot
.42691 .50358 Mdot
.54293 .43283 Mdot
.45967 .57578 Mdot
.45487 .50714 Mdot
.49996 .44161 Mdot
.5518 .55447 Mdot
.58432 .52951 Mdot
.51085 .49671 Mdot
.44043 .53075 Mdot
.5426 .47904 Mdot
.53329 .54362 Mdot
.48792 .49156 Mdot
.5712 .47523 Mdot
.5419 .515 Mdot
.57128 .45791 Mdot
.56252 .43378 Mdot
.44462 .5152 Mdot
.54844 .51167 Mdot
.48299 .44222 Mdot
.46337 .5342 Mdot
.42199 .46124 Mdot
.49946 .49272 Mdot
.48982 .43529 Mdot
.41615 .53288 Mdot
.57472 .5375 Mdot
.46841 .42992 Mdot
.41277 .52676 Mdot
.561 .54906 Mdot
.48221 .5681 Mdot
.45932 .54393 Mdot
.52403 .47774 Mdot
.49155 .53175 Mdot
.46607 .47507 Mdot
.51565 .47307 Mdot
.53502 .56753 Mdot
.48726 .4691 Mdot
.43333 .55131 Mdot
.48069 .55551 Mdot
.5075 .58517 Mdot
.42635 .50709 Mdot
.50099 .54629 Mdot
.45988 .52311 Mdot
.48343 .47436 Mdot
.47118 .51401 Mdot
.44782 .56928 Mdot
.57084 .44271 Mdot
.46001 .50778 Mdot
.41648 .50079 Mdot
.46096 .53742 Mdot
.44142 .5026 Mdot
.44238 .52584 Mdot
.47243 .57462 Mdot
.4578 .50463 Mdot
.52599 .55885 Mdot
.51919 .51962 Mdot
.55244 .5168 Mdot
.53651 .5169 Mdot
.44662 .51766 Mdot
.50282 .49716 Mdot
.50047 .56679 Mdot
.52755 .4326 Mdot
.52772 .50811 Mdot
.48323 .4679 Mdot
.55188 .51242 Mdot
.41207 .51236 Mdot
.54984 .56896 Mdot
.45071 .43245 Mdot
.44949 .53786 Mdot
.55155 .44967 Mdot
.50069 .5272 Mdot
.4851 .57184 Mdot
.48342 .56587 Mdot
.50862 .41007 Mdot
.44173 .48743 Mdot
.43711 .55226 Mdot
.5075 .47441 Mdot
.52427 .58216 Mdot
.54005 .48466 Mdot
.50575 .49156 Mdot
.54194 .43368 Mdot
.4925 .55453 Mdot
.55823 .45583 Mdot
.48334 .57631 Mdot
.52357 .48402 Mdot
.53015 .42861 Mdot
.46239 .43762 Mdot
.48399 .41394 Mdot
.53467 .55896 Mdot
.5082 .48028 Mdot
.44943 .49502 Mdot
.49776 .51892 Mdot
.56673 .49023 Mdot
.48238 .57336 Mdot
.43807 .56109 Mdot
.47248 .586 Mdot
.50833 .41946 Mdot
.50807 .45989 Mdot
.47128 .52104 Mdot
.46809 .53822 Mdot
.43272 .48868 Mdot
.52268 .46413 Mdot
.48276 .54282 Mdot
.52697 .47344 Mdot
.44699 .44749 Mdot
.54787 .45829 Mdot
.4231 .47824 Mdot
.54918 .4554 Mdot
.58112 .54128 Mdot
.45725 .53182 Mdot
.58147 .48623 Mdot
.48905 .5161 Mdot
.49733 .4564 Mdot
.52221 .42147 Mdot
.48872 .40997 Mdot
.51603 .57078 Mdot
.45866 .52928 Mdot
.47812 .47847 Mdot
.53803 .55379 Mdot
.56593 .51638 Mdot
.45243 .54792 Mdot
.53985 .48357 Mdot
.4744 .42821 Mdot
.5308 .47643 Mdot
.49884 .56273 Mdot
.45466 .53366 Mdot
.52542 .4432 Mdot
.42292 .51161 Mdot
.49111 .46331 Mdot
.54199 .55852 Mdot
.54488 .44264 Mdot
.48243 .51115 Mdot
.50536 .47135 Mdot
.50896 .41902 Mdot
.45765 .53871 Mdot
.53524 .56258 Mdot
.42315 .5405 Mdot
.54003 .51748 Mdot
.54793 .46696 Mdot
.54656 .45816 Mdot
.45599 .50496 Mdot
.58365 .51523 Mdot
.56155 .47035 Mdot
.57067 .45861 Mdot
.44195 .52218 Mdot
.49279 .50241 Mdot
.4824 .51971 Mdot
.45009 .47634 Mdot
.50289 .5364 Mdot
.51086 .46808 Mdot
.44507 .44522 Mdot
.51609 .5723 Mdot
.44195 .52652 Mdot
.42049 .51035 Mdot
.52763 .4177 Mdot
.55819 .4315 Mdot
.46587 .45146 Mdot
.47986 .41279 Mdot
.45444 .47247 Mdot
.43701 .52684 Mdot
.47751 .46865 Mdot
.55314 .47618 Mdot
.47225 .55492 Mdot
.57943 .50696 Mdot
.53691 .58264 Mdot
.54183 .41969 Mdot
.49174 .48349 Mdot
.49836 .51089 Mdot
.46881 .56347 Mdot
.5109 .48323 Mdot
.5432 .50764 Mdot
.48096 .44139 Mdot
.49114 .48327 Mdot
.51775 .50734 Mdot
.45857 .4447 Mdot
.47114 .53895 Mdot
.50515 .42888 Mdot
.51924 .45623 Mdot
.44877 .5473 Mdot
.52775 .46264 Mdot
.44366 .57189 Mdot
.48388 .53991 Mdot
.44396 .44601 Mdot
.56336 .45471 Mdot
.50209 .57644 Mdot
.55089 .55664 Mdot
.52207 .48248 Mdot
.55056 .52891 Mdot
.44437 .52794 Mdot
.47076 .48837 Mdot
.45167 .57144 Mdot
.58399 .50474 Mdot
.48112 .58539 Mdot
.57114 .50014 Mdot
.53341 .49092 Mdot
.43258 .55257 Mdot
.56035 .50328 Mdot
.46414 .48754 Mdot
.45382 .52913 Mdot
.50976 .42162 Mdot
.48405 .58534 Mdot
.42846 .50056 Mdot
.49979 .50389 Mdot
.51957 .42241 Mdot
.50016 .52883 Mdot
.52997 .51782 Mdot
.42179 .45683 Mdot
.54625 .4966 Mdot
.5429 .45425 Mdot
.49642 .47485 Mdot
.50104 .46733 Mdot
.49798 .55111 Mdot
.5061 .4559 Mdot
.5714 .52196 Mdot
.52304 .462 Mdot
.41822 .47218 Mdot
.52593 .47841 Mdot
.5067 .42268 Mdot
.469 .4768 Mdot
.55544 .52684 Mdot
.57441 .51448 Mdot
.465 .45744 Mdot
.43929 .47132 Mdot
.49101 .47979 Mdot
.54107 .52799 Mdot
.55027 .47757 Mdot
.48019 .49324 Mdot
.47146 .44456 Mdot
.58458 .47975 Mdot
.52101 .57635 Mdot
.45683 .43723 Mdot
.45656 .52095 Mdot
.50799 .49535 Mdot
.57451 .54455 Mdot
.46331 .45285 Mdot
.47385 .42217 Mdot
.51856 .47293 Mdot
.55526 .52271 Mdot
.47822 .48755 Mdot
.46345 .41884 Mdot
.53204 .48221 Mdot
.50579 .46 Mdot
.44362 .47855 Mdot
.44226 .43353 Mdot
.55482 .47659 Mdot
.51018 .48531 Mdot
.42085 .45356 Mdot
.46036 .51545 Mdot
.58245 .51936 Mdot
.46544 .42875 Mdot
.49859 .4204 Mdot
.47844 .58032 Mdot
.55017 .54974 Mdot
.52746 .43605 Mdot
.52149 .47429 Mdot
.42785 .51379 Mdot
.51356 .57527 Mdot
.56285 .4667 Mdot
.56832 .46883 Mdot
.50851 .44348 Mdot
.53025 .57848 Mdot
.44349 .54573 Mdot
.49869 .47892 Mdot
.43443 .55005 Mdot
.55124 .46864 Mdot
.52986 .47109 Mdot
.46927 .54102 Mdot
.47948 .43694 Mdot
.43777 .53374 Mdot
.57903 .53928 Mdot
.51951 .41538 Mdot
.44735 .46404 Mdot
.51898 .48452 Mdot
.41545 .50075 Mdot
.48778 .5042 Mdot
.48455 .51063 Mdot
.53267 .44138 Mdot
.53489 .42585 Mdot
.50836 .45626 Mdot
.4588 .52421 Mdot
.45869 .44097 Mdot
.46627 .46002 Mdot
.54037 .56683 Mdot
.45512 .57112 Mdot
.43386 .47043 Mdot
.56117 .56756 Mdot
.43786 .53593 Mdot
.58703 .51545 Mdot
.51644 .48499 Mdot
.4698 .50028 Mdot
.43421 .54845 Mdot
.43788 .55576 Mdot
.53526 .50907 Mdot
.56108 .51578 Mdot
.52755 .55373 Mdot
.57276 .49915 Mdot
.56559 .45337 Mdot
.54037 .56388 Mdot
.50682 .46512 Mdot
.43 .53461 Mdot
.50879 .52609 Mdot
.51305 .57175 Mdot
.54043 .52583 Mdot
.5541 .56083 Mdot
.48095 .52572 Mdot
.46092 .5315 Mdot
.42783 .51608 Mdot
.47323 .43348 Mdot
.55537 .43491 Mdot
.54027 .4205 Mdot
.44396 .55287 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go
00001_ooool3o`000?ooooooB?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04
odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol0003o
oooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`3o
ooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007
ooooo`03o`000?oooooooooo09_ooooo0_l00004ooooo`;o0000Y?ooool000?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0V?ooool2
o`000003ooooool0003o000000Cooooo1?l0002Rooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`2Hooooo`Go00001Oooool5
o`000:3ooooo000Nooooo`03o`000?oooooooooo09?ooooo0_l00002ooooo`Ko00001?ooool:o`00
0003ooooool0003o000009Wooooo000Nooooo`03o`000?oooooooooo09?ooooo0_l000001?oooooo
0000o`000?l00002ooooo`;o000000?oooooo`000?l000001?l000000ooooooo0000o`000004o`00
0003ooooool0003o000009Wooooo000Nooooo`03o`000?oooooooooo09?ooooo0_l000001Ooooooo
0000o`000?l0003ooooo00;o000000?oooooo`000?l000001Ol000000ooooooo0000o`000007o`00
09Wooooo000Nooooo`03o`000?oooooooooo08gooooo0_l00002ooooo`Co000000?oooooo`000?l0
00000_ooool8o`0000?ooooo2?l00003ooooo`;o0000UOooool001kooooo00?o0000ooooooooool0
SOooool3o`000003ooooool0003o000000Go00000_ooool5o`000003ooooool0003o000000go0000
00Coooooo`000?l0003o0000U?ooool001kooooo00?o0000ooooooooool0Roooool5o`000003oooo
ool0003o000000Go00001Oooool3o`000003ooooool0003o000000Ko000000?oooooo`000?l00000
0ol000000ooooooo0000o`000003o`0009;ooooo000Nooooo`03o`000?oooooooooo08_ooooo2Ol0
0002ooooo`Co000000?oooooo`000?l000001Ol000000ooooooo0000o`000005o`000004ooooool0
003o0000o`0000;ooooo0_l000001?oooooo0000o`000?l0002Aooooo`007_ooool00ol0003ooooo
ooooo`28ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000008o`000003oooo
ool0003o000000Go000000?oooooo`000?l000002_l000001?oooooo0000o`000?ooool3o`00097o
oooo000Nooooo`03o`000?oooooooooo08Sooooo0_l000000ooooooo0000o`000002o`0000;ooooo
0_l000000ooooooo0000o`00000>o`0000;ooooo3?l000000ooooooo0000o`000002o`00093ooooo
000Nooooo`03o`000?oooooooooo08Oooooo2?l00002ooooo`Ko000000?oooooo`000?l000001_l0
00001?oooooo0000o`000?l00002ooooo`Go00000_ooool3o`000004ooooool0003o0000ooooo`?o
0000T?ooool001kooooo00?o0000ooooooooool0Qoooool8o`0000;ooooo2ol00002ooooo`;o0000
0_ooool2o`0000;ooooo0ol00006ooooo`Co00000_ooool4o`0008kooooo000Nooooo`;o0000Q_oo
ool4o`0000;ooooo1Ol000000ooooooo0000o`000002o`000004ooooool0003o0000o`0000Kooooo
0_l000001?oooooo0000o`000?l0000:ooooo`;o00000_ooool7o`0008gooooo000Nooooo`03o`00
0?oooooooooo08Gooooo0_l000000ooooooo0000o`000003o`000004ooooool0003o0000ooooo`Co
000000Coooooo`000?l0003o00000oooool=o`0000?ooooo1?l000000ooooooo0000o`000007o`00
08gooooo000Nooooo`03o`000?oooooooooo08Cooooo2?l00007ooooo`;o000000Coooooo`000?l0
003o00000oooool7o`0000;ooooo1Ol00002ooooo`Co000000?oooooo`000?l000001Ol000000ooo
oooo0000o`00002<ooooo`007_ooool00ol0003oooooooooo`24ooooo`Go00002?ooool4o`000003
ooooool0003o000000?ooooo0_l000000ooooooo0000o`000003o`0000?ooooo1?l00002ooooo`co
000000?oooooo`000?l00000S?ooool001kooooo00?o0000ooooooooool0QOooool4o`0000;ooooo
1?l00002ooooo`Co00001_ooool8o`0000;ooooo1_l000000ooooooo0000o`000004o`0000Gooooo
0ol0002=ooooo`007_ooool00ol0003oooooooooo`26ooooo`;o00000_ooool5o`0000;ooooo0_l0
0003ooooo`Go000000?oooooo`000?l000001_l000000ooooooo0000o`000004o`000003ooooool0
003o000000co0000SOooool001kooooo00?o0000ooooooooool0QOooool8o`0000?ooooo3Ol00000
0ooooooo0000o`000004o`0000;ooooo1?l00003ooooo`[o000000?oooooo`000?l00000SOooool0
01kooooo00?o0000ooooooooool0P_ooool;o`0000?ooooo2?l000000ooooooo0000o`00000Bo`00
00;ooooo1_l000000ooooooo0000o`000002o`0008gooooo000Nooooo`03o`000?oooooooooo08;o
oooo1?l00003ooooo`oo000000?oooooo`000?l000004_l00002ooooo`Ko000000Goooooo`000?l0
003o0000ooooo`02o`0008_ooooo000Nooooo`03o`000?oooooooooo08Gooooo0_l00002ooooo`Oo
000000?oooooo`000?l000001_l000000ooooooo0000o`000004o`000003ooooool0003o000000;o
000000?oooooo`000?l000000_l000001Ooooooo0000o`000?l0003ooooo00?o000000Coooooo`00
0?l0003ooooo0ol000000ooooooo0000o`00002;ooooo`007_ooool00ol0003oooooooooo`25oooo
o`;o00000oooool6o`0000;ooooo2Ol000000ooooooo0000o`00000Ao`000003ooooool0003o0000
00Sooooo0ol0002:ooooo`007_ooool00ol0003oooooooooo`25ooooo`Co00001Oooool4o`0000;o
oooo7Ol00008ooooo`Co0000R_ooool001kooooo00?o0000ooooooooool0Q_ooool7o`0000?ooooo
0_l000000ooooooo0000o`00000Bo`000003ooooool0003o000000Wo000000Coooooo`000?l0003o
00000_ooool2o`0008cooooo000Nooooo`03o`000?oooooooooo08Kooooo0_l000000ooooooo0000
o`000004o`000004ooooool0003o0000ooooo`[o000000?oooooo`000?l000000ol00006ooooo`ko
00000oooool2o`0008_ooooo000Nooooo`03o`000?oooooooooo087ooooo1?l00005ooooo`So0000
0_ooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool7o`000004ooooool0003o0000oooo
o`Wo000000?oooooo`000?l000000_l00003ooooo`?o0000R_ooool001kooooo00?o0000oooooooo
ool0POooool6o`0000?ooooo0_l000000ooooooo0000o`000003o`0000;ooooo0_l00002ooooo`Go
000000?oooooo`000?l000001Ol000001?oooooo0000o`000?l00002ooooo`go00000oooool2o`00
08[ooooo000Nooooo`;o0000Q?ooool>o`0000;ooooo1?l000000ooooooo0000o`000004o`000003
ooooool0003o000000?o00000oooool>o`000003ooooool0003o000000;o0000SOooool001kooooo
00?o0000ooooooooool0Poooool3o`000003ooooool0003o000000Ko000000?oooooo`000?l00000
5Ol000000ooooooo0000o`000005o`000003ooooool0003o000000[o0000Roooool001kooooo00?o
0000ooooooooool0Q?ooool7o`0000?ooooo1_l00002oooooa_o000000?oooooo`000?l000002?l0
002;ooooo`007_ooool00ol0003oooooooooo`24ooooo`Co00000_ooool9o`0000;ooooo2?l00000
0ooooooo0000o`000006o`000003ooooool0003o000000So000000?oooooo`000?l000002?l0002;
ooooo`007_ooool00ol0003oooooooooo`22ooooo`Oo000000?oooooo`000?l000001Ol00002oooo
o`go00000_ooool4o`0000;ooooo2Ol000000ooooooo0000o`000007o`0008cooooo000Nooooo`03
o`000?oooooooooo08;ooooo0ol00002ooooo`?o000000?oooooo`000?l000002_l000000ooooooo
0000o`000004o`0000Kooooo0_l00002ooooo`Wo000000?oooooo`000?l000000_l000000ooooooo
0000o`000004o`0008[ooooo000Nooooo`03o`000?oooooooooo08;ooooo0_l000000ooooooo0000
o`00000=o`000004ooooool0003o0000ooooo`[o00000oooool2o`000003ooooool0003o000000Oo
000000?oooooo`000?l000000_l000000ooooooo0000o`000004o`0008[ooooo000Nooooo`03o`00
0?oooooooooo08;ooooo5Ol000000ooooooo0000o`000009o`000004ooooool0003o0000o`0000;o
oooo1?l00003ooooo`;o00001?ooool5o`0008cooooo000Nooooo`03o`000?oooooooooo08;ooooo
0ol000000ooooooo0000o`000008o`000003ooooool0003o000000_o000000?oooooo`000?l00000
1_l00002ooooo`;o000000?oooooo`000?l000001Ol00002ooooo`?o0000Soooool001kooooo00?o
0000ooooooooool0P_ooool2o`000003ooooool0003o000000;ooooo1Ol000000ooooooo0000o`00
0002o`000003ooooool0003o000000ko000000?oooooo`000?l000001Oooool8o`000003ooooool0
003o000000Go0000Roooool001kooooo00?o0000ooooooooool0Poooool4o`000003ooooool0003o
000000Co000000?oooooo`000?l000000ol000001?oooooo0000o`000?l00004ooooo`Ko000000?o
ooooo`000?l000001_l000001?oooooo0000o`000?ooool5o`0000;ooooo1_l0002;ooooo`007_oo
ool00ol0003oooooooooo`23oooooaGo000000Coooooo`000?l0003ooooo1_l000000ooooooo0000
o`000007o`0000[ooooo0_l000001?oooooo0000o`000?l0002;ooooo`007_ooool00ol0003ooooo
ooooo`24oooooa?o00000_ooool5o`000003ooooool0003o000000Go000000Coooooo`000?l0003o
oooo0_l000001?oooooo0000o`000?ooool5o`000003ooooool0003o000000Co0000Roooool001ko
oooo00?o0000ooooooooool0QOooool3o`000003ooooool0003o000000co00000_ooool7o`0000;o
oooo1?l00007ooooo`;o000000?oooooo`000?l000002Ol0002<ooooo`007_ooool00ol0003ooooo
ooooo`25oooooa;o00000_ooool8o`0000;ooooo0_l00004ooooo`;o00000oooool3o`0000;ooooo
2?l0002<ooooo`007_ooool00ol0003oooooooooo`27ooooo`co00000_ooool2o`0000;ooooo1Ol0
00000ooooooo0000o`000002ooooo`;o00001?ooool4o`000004ooooool0003o0000o`0000;ooooo
1_l0002>ooooo`007_ooool2o`0008Wooooo2Ol000001?oooooo0000o`000?ooool2o`0000Gooooo
2Ol00004ooooo`Co000000Goooooo`000?l0003o0000ooooo`05o`00093ooooo000Nooooo`03o`00
0?oooooooooo08Wooooo2ol000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l00000
0_l000001?oooooo0000o`000?ooool2o`000004ooooool0003o0000ooooo`?o000000Goooooo`00
0?l0003o0000ooooo`05o`00093ooooo000Nooooo`03o`000?oooooooooo08Wooooo2_l00002oooo
o`Ko000000Coooooo`000?l0003ooooo1ol000001?oooooo0000o`000?ooool3o`0000;ooooo0_l0
0002ooooo`?o0000TOooool001kooooo00?o0000ooooooooool0ROooool3o`0000;ooooo0_l00004
ooooo`;o000000Coooooo`000?l0003o00001Oooool5o`0000?ooooo1ol000001?oooooo0000o`00
0?l00002ooooo`;o0000TOooool001kooooo00?o0000ooooooooool0R_ooool5o`0000;ooooo1Ol0
0008ooooo`Ko00000_ooool8o`0000;ooooo0_l00002ooooo`;o0000TOooool001kooooo00?o0000
ooooooooool0R_ooool6o`000003ooooool0003o000000?o00000oooool3o`0000;ooooo1?l00000
0ooooooo0000o`000003o`0000;ooooo1?l00002ooooo`Go0000T_ooool001kooooo00?o0000oooo
ooooool0SOooool4o`000003ooooool0003o000000;o000000?oooooo`000?l000000ol00003oooo
o`;o000000?oooooo`000?l000000ol00003ooooo`_o0000T_ooool001kooooo00?o0000oooooooo
ool0S?ooool@o`0000Kooooo1?l000001?oooooo0000o`000?ooool2o`000003ooooool0003o0000
00Go0000Toooool001kooooo00?o0000ooooooooool0S?ooool2o`000003ooooool0003o000000_o
00000oooool=o`0000?ooooo0_l0002Fooooo`007_ooool00ol0003oooooooooo`2@ooooo`?o0000
0_ooool2o`000003ooooool0003o000000;o00000oooool?o`0009Wooooo000Nooooo`03o`000?oo
oooooooo093ooooo0_l00002ooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo3Ol0
002Iooooo`007_ooool00ol0003oooooooooo`2Dooooo`So000000?oooooo`000?l000000_ooool2
o`000003ooooool0003o000000Oo0000V_ooool001kooooo00?o0000ooooooooool0U?ooool3o`00
0003ooooool0003o000000?o00001?ooool6o`000004ooooool0003o0000o`0009cooooo000Noooo
o`03o`000?oooooooooo09Gooooo0_l00004ooooo`Co00000_ooool6o`000:3ooooo0003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006
ooooo`03o`000?oooooooooo09gooooo0ol00004ooooo`;o0000XOooool000?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o
0000ooooooooool0W_ooool2o`000:Oooooo0003ooooo`05oa0@4?ooooooooooooooool@41002ooo
ool01Ol0003ooooooooooooooooo000000Kooooo0ol0003oooooodSooooo0003ooooo`05o`000?oo
ooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o0000oooooooo
ool0oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0
003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooo
oooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0oooooom8oooo
o`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0
003oooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<
c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000oooo
ooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`3oooooodSooooo0003oooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodSooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooo
oonHV9So<S8b00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol0003ooooooooo
oooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj
^_l@41001_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0oooooom8
ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVY
Z@06ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?oo
ooooBOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001Cooooo1?l000000ol@413oooooooooo`03ooooo`03
o`000?oooooooooo0?ooooooB?ooool001Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3oooooodSooooo000Fooooo`03o`000?oooooooooo00Gooooo0ol0003oooooodSooooo000F
ooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@oooo
o`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?oooooo
D?ooool001Cooooo00?oEEEEofIVI_l00000oooooomBooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.48767 .56136 Mdot
.53633 .48475 Mdot
.56154 .46881 Mdot
.53557 .49236 Mdot
.53615 .52104 Mdot
.45815 .54581 Mdot
.57684 .4856 Mdot
.53174 .54642 Mdot
.47177 .43172 Mdot
.44903 .51446 Mdot
.48768 .54231 Mdot
.49103 .48759 Mdot
.45577 .54914 Mdot
.55833 .53057 Mdot
.51907 .4303 Mdot
.44741 .50984 Mdot
.54827 .52335 Mdot
.43025 .51506 Mdot
.44482 .51607 Mdot
.48174 .46645 Mdot
.54508 .54022 Mdot
.43562 .4727 Mdot
.5156 .53706 Mdot
.4884 .57061 Mdot
.52596 .5538 Mdot
.48403 .49462 Mdot
.49754 .43543 Mdot
.44407 .51804 Mdot
.53096 .50704 Mdot
.46529 .55706 Mdot
.55584 .47813 Mdot
.54515 .50867 Mdot
.50169 .50638 Mdot
.52157 .4497 Mdot
.45966 .55297 Mdot
.55021 .45748 Mdot
.47675 .4972 Mdot
.47498 .44199 Mdot
.52731 .53333 Mdot
.47894 .48639 Mdot
.4685 .50656 Mdot
.466 .46916 Mdot
.53884 .46664 Mdot
.50816 .49671 Mdot
.54623 .5203 Mdot
.4491 .50273 Mdot
.56117 .52823 Mdot
.56146 .48711 Mdot
.54896 .46292 Mdot
.44604 .44206 Mdot
.53141 .52646 Mdot
.44125 .54469 Mdot
.52903 .50116 Mdot
.53274 .5353 Mdot
.43824 .51029 Mdot
.4541 .49289 Mdot
.50534 .46937 Mdot
.43781 .54804 Mdot
.54367 .51794 Mdot
.50943 .46585 Mdot
.43745 .49505 Mdot
.46107 .50123 Mdot
.50537 .45355 Mdot
.45139 .50991 Mdot
.52592 .52363 Mdot
.47105 .42816 Mdot
.55507 .50162 Mdot
.44532 .49771 Mdot
.46326 .47964 Mdot
.44168 .50925 Mdot
.55662 .44988 Mdot
.54049 .51333 Mdot
.49701 .46941 Mdot
.51701 .48797 Mdot
.47079 .56438 Mdot
.51463 .43981 Mdot
.45028 .48468 Mdot
.43743 .51926 Mdot
.56488 .45842 Mdot
.48912 .5278 Mdot
.4756 .44803 Mdot
.52706 .5497 Mdot
.53686 .54976 Mdot
.46383 .50518 Mdot
.5109 .45195 Mdot
.52199 .49221 Mdot
.52657 .44464 Mdot
.45171 .49882 Mdot
.48082 .48328 Mdot
.44092 .52774 Mdot
.52695 .51121 Mdot
.4449 .50493 Mdot
.49673 .4443 Mdot
.46196 .43141 Mdot
.56953 .47427 Mdot
.4371 .48329 Mdot
.45071 .49648 Mdot
.55899 .48726 Mdot
.56233 .52525 Mdot
.51331 .46883 Mdot
.519 .44434 Mdot
.49784 .44678 Mdot
.54095 .52787 Mdot
.43709 .4533 Mdot
.48122 .42994 Mdot
.49626 .50391 Mdot
.55828 .55374 Mdot
.52816 .51949 Mdot
.55092 .48726 Mdot
.44322 .50507 Mdot
.49832 .56813 Mdot
.54055 .51136 Mdot
.50981 .47934 Mdot
.45949 .44341 Mdot
.55304 .52878 Mdot
.43987 .54009 Mdot
.48792 .43478 Mdot
.43178 .51307 Mdot
.56511 .48181 Mdot
.49336 .44351 Mdot
.47085 .5296 Mdot
.49226 .49484 Mdot
.44517 .51364 Mdot
.55259 .46973 Mdot
.54661 .5023 Mdot
.44612 .45361 Mdot
.48618 .56855 Mdot
.48956 .49531 Mdot
.50209 .49717 Mdot
.4644 .509 Mdot
.48184 .52996 Mdot
.5494 .53018 Mdot
.46833 .57232 Mdot
.53221 .45334 Mdot
.50933 .54715 Mdot
.485 .57696 Mdot
.42868 .47041 Mdot
.51786 .50236 Mdot
.48088 .47526 Mdot
.50593 .48605 Mdot
.52816 .51625 Mdot
.4805 .43195 Mdot
.50036 .50061 Mdot
.53467 .49687 Mdot
.50811 .51416 Mdot
.44006 .50378 Mdot
.48038 .5607 Mdot
.44144 .47785 Mdot
.55288 .53224 Mdot
.54853 .46469 Mdot
.51593 .45319 Mdot
.44243 .51791 Mdot
.53211 .51549 Mdot
.55483 .53773 Mdot
.48389 .53434 Mdot
.44607 .50976 Mdot
.46655 .50156 Mdot
.46239 .56479 Mdot
.45116 .48429 Mdot
.51717 .51742 Mdot
.53416 .43828 Mdot
.45702 .47756 Mdot
.45904 .52813 Mdot
.43018 .50442 Mdot
.49018 .47807 Mdot
.50229 .47715 Mdot
.48944 .42867 Mdot
.4632 .45603 Mdot
.44582 .47138 Mdot
.46449 .4447 Mdot
.47214 .51996 Mdot
.54547 .46403 Mdot
.53501 .47819 Mdot
.48771 .47793 Mdot
.55225 .44492 Mdot
.46142 .4969 Mdot
.43484 .48121 Mdot
.51903 .52011 Mdot
.53464 .56997 Mdot
.53185 .45571 Mdot
.53313 .49131 Mdot
.43452 .48619 Mdot
.51526 .49302 Mdot
.53032 .502 Mdot
.44962 .54535 Mdot
.49561 .48644 Mdot
.54308 .44922 Mdot
.43624 .49205 Mdot
.45891 .4345 Mdot
.50245 .44242 Mdot
.50551 .49083 Mdot
.49544 .51461 Mdot
.50294 .57032 Mdot
.53078 .51698 Mdot
.46871 .44381 Mdot
.48122 .50656 Mdot
.45069 .43792 Mdot
.50474 .50264 Mdot
.52042 .52556 Mdot
.53091 .4841 Mdot
.5192 .4698 Mdot
.44258 .49424 Mdot
.47422 .52794 Mdot
.45806 .46397 Mdot
.44922 .51195 Mdot
.53318 .47473 Mdot
.53997 .55182 Mdot
.5171 .46634 Mdot
.53926 .44997 Mdot
.53204 .51917 Mdot
.54652 .523 Mdot
.48596 .49821 Mdot
.47071 .48326 Mdot
.46659 .53655 Mdot
.49211 .49458 Mdot
.55759 .53983 Mdot
.44376 .50331 Mdot
.45377 .48468 Mdot
.47896 .43242 Mdot
.52482 .51772 Mdot
.50506 .52361 Mdot
.44668 .55641 Mdot
.4412 .50384 Mdot
.52174 .572 Mdot
.49643 .54688 Mdot
.51413 .55138 Mdot
.54271 .5054 Mdot
.43838 .51261 Mdot
.54773 .45237 Mdot
.49486 .53269 Mdot
.42636 .4906 Mdot
.49001 .49847 Mdot
.46919 .4383 Mdot
.47523 .50011 Mdot
.46905 .49432 Mdot
.48315 .47391 Mdot
.4554 .4473 Mdot
.52285 .44044 Mdot
.54796 .49663 Mdot
.49543 .48643 Mdot
.43956 .51304 Mdot
.51758 .43168 Mdot
.48242 .56429 Mdot
.45016 .45112 Mdot
.5718 .48567 Mdot
.43603 .50911 Mdot
.51473 .43868 Mdot
.52347 .54893 Mdot
.42839 .50231 Mdot
.49117 .43282 Mdot
.53479 .46545 Mdot
.4456 .54196 Mdot
.5068 .43229 Mdot
.5711 .47977 Mdot
.51079 .48195 Mdot
.49341 .48222 Mdot
.50551 .53081 Mdot
.46072 .48659 Mdot
.51299 .45094 Mdot
.49651 .43064 Mdot
.46508 .45625 Mdot
.48685 .50897 Mdot
.51653 .51712 Mdot
.47542 .53366 Mdot
.49369 .46053 Mdot
.49657 .45611 Mdot
.4983 .53467 Mdot
.46112 .52207 Mdot
.48755 .50649 Mdot
.52843 .57304 Mdot
.55263 .48798 Mdot
.50932 .4793 Mdot
.46232 .43238 Mdot
.50614 .4831 Mdot
.55705 .45949 Mdot
.52861 .43914 Mdot
.44915 .49014 Mdot
.45182 .51622 Mdot
.47816 .46974 Mdot
.47621 .51364 Mdot
.47304 .47758 Mdot
.47217 .49198 Mdot
.56312 .50503 Mdot
.51208 .50913 Mdot
.47626 .43832 Mdot
.45782 .43362 Mdot
.54789 .55984 Mdot
.50813 .53061 Mdot
.54471 .4908 Mdot
.55169 .54622 Mdot
.49019 .48063 Mdot
.5546 .53031 Mdot
.43756 .53669 Mdot
.53834 .4638 Mdot
.50272 .47696 Mdot
.53478 .53634 Mdot
.45582 .52002 Mdot
.52283 .455 Mdot
.4684 .46593 Mdot
.5369 .49518 Mdot
.5107 .50115 Mdot
.51193 .55149 Mdot
.48085 .42818 Mdot
.43405 .50477 Mdot
.48974 .4842 Mdot
.53611 .4946 Mdot
.49951 .58038 Mdot
.52293 .56669 Mdot
.52233 .55546 Mdot
.49772 .45985 Mdot
.52572 .48572 Mdot
.50946 .50875 Mdot
.4981 .52716 Mdot
.49506 .55835 Mdot
.52679 .47945 Mdot
.54792 .54837 Mdot
.47721 .48697 Mdot
.44768 .49835 Mdot
.49129 .47245 Mdot
.46935 .4449 Mdot
.53599 .45773 Mdot
.48579 .54525 Mdot
.48249 .5452 Mdot
.45775 .49581 Mdot
.46306 .51843 Mdot
.45165 .45393 Mdot
.50634 .49312 Mdot
.50078 .49635 Mdot
.45379 .44421 Mdot
.48365 .45117 Mdot
.47694 .56113 Mdot
.44632 .54647 Mdot
.50886 .47859 Mdot
.45114 .51484 Mdot
.54014 .45103 Mdot
.49349 .51769 Mdot
.51776 .45346 Mdot
.53866 .50313 Mdot
.48875 .55057 Mdot
.45878 .50064 Mdot
.55583 .49902 Mdot
.53531 .56056 Mdot
.57127 .51931 Mdot
.50116 .50225 Mdot
.44409 .46438 Mdot
.55307 .51905 Mdot
.51335 .50849 Mdot
.53603 .53941 Mdot
.46584 .45482 Mdot
.46313 .50532 Mdot
.4975 .47484 Mdot
.46403 .56942 Mdot
.54683 .52938 Mdot
.47312 .49876 Mdot
.44634 .53585 Mdot
.49896 .47715 Mdot
.54193 .56257 Mdot
.55106 .51372 Mdot
.4357 .53196 Mdot
.49714 .50513 Mdot
.52365 .52565 Mdot
.54601 .55188 Mdot
.50355 .47864 Mdot
.53933 .56282 Mdot
.55184 .51365 Mdot
.56468 .5025 Mdot
.57134 .49662 Mdot
.45946 .45745 Mdot
.53128 .57367 Mdot
.5215 .49355 Mdot
.51798 .51779 Mdot
.52065 .50577 Mdot
.45578 .56278 Mdot
.49424 .54157 Mdot
.56268 .47511 Mdot
.44971 .51309 Mdot
.49553 .5372 Mdot
.52331 .44279 Mdot
.46846 .47026 Mdot
.48246 .49687 Mdot
.51272 .45526 Mdot
.57042 .47141 Mdot
.5368 .50616 Mdot
.49932 .57385 Mdot
.54344 .50946 Mdot
.4658 .54601 Mdot
.44317 .51793 Mdot
.49778 .52156 Mdot
.45902 .49262 Mdot
.51409 .45561 Mdot
.48864 .57897 Mdot
.46827 .47308 Mdot
.53097 .45634 Mdot
.54536 .51043 Mdot
.51499 .53303 Mdot
.53748 .54222 Mdot
.42987 .49883 Mdot
.50577 .50848 Mdot
.4598 .51859 Mdot
.49784 .57841 Mdot
.51002 .5786 Mdot
.52384 .45347 Mdot
.47049 .57663 Mdot
.47381 .49157 Mdot
.5236 .45654 Mdot
.549 .45809 Mdot
.53156 .50115 Mdot
.52189 .51788 Mdot
.5249 .46774 Mdot
.48422 .52308 Mdot
.50332 .48701 Mdot
.46531 .5157 Mdot
.51751 .4897 Mdot
.5601 .48325 Mdot
.51956 .49464 Mdot
.50108 .44581 Mdot
.44093 .50589 Mdot
.51453 .56994 Mdot
.5269 .46154 Mdot
.43997 .51262 Mdot
.48223 .51658 Mdot
.447 .50154 Mdot
.51428 .4924 Mdot
.45783 .51485 Mdot
.44701 .56043 Mdot
.53159 .45227 Mdot
.50808 .42797 Mdot
.48035 .50532 Mdot
.47783 .47392 Mdot
.46959 .4848 Mdot
.54263 .55785 Mdot
.44158 .50912 Mdot
.53694 .55539 Mdot
.48451 .51846 Mdot
.44886 .46749 Mdot
.50107 .57126 Mdot
.44548 .47021 Mdot
.50458 .46925 Mdot
.53431 .56337 Mdot
.48946 .47745 Mdot
.54394 .46568 Mdot
.43015 .52349 Mdot
.55396 .53803 Mdot
.47736 .53454 Mdot
.49593 .50416 Mdot
.47591 .52415 Mdot
.53808 .51511 Mdot
.45234 .51145 Mdot
.52814 .44946 Mdot
.5285 .51015 Mdot
.56624 .50464 Mdot
.49908 .48572 Mdot
.46408 .50639 Mdot
.48414 .47921 Mdot
.49587 .45101 Mdot
.46573 .43648 Mdot
.51521 .45362 Mdot
.47284 .44446 Mdot
.52018 .51344 Mdot
.46512 .4857 Mdot
.46314 .46423 Mdot
.51728 .48456 Mdot
.56343 .48836 Mdot
.47894 .50043 Mdot
.5328 .4583 Mdot
.51998 .57412 Mdot
.47833 .50297 Mdot
.51155 .49092 Mdot
.55579 .51491 Mdot
.46068 .48486 Mdot
.4823 .55134 Mdot
.48463 .51321 Mdot
.57749 .51402 Mdot
.53644 .43317 Mdot
.46257 .51749 Mdot
.47087 .43318 Mdot
.55582 .47023 Mdot
.53812 .43319 Mdot
.52047 .44389 Mdot
.47811 .57516 Mdot
.50757 .50734 Mdot
.54666 .52914 Mdot
.52428 .54992 Mdot
.543 .52824 Mdot
.44463 .5008 Mdot
.46003 .46567 Mdot
.45681 .51442 Mdot
.48653 .56201 Mdot
.54115 .46115 Mdot
.52245 .44258 Mdot
.42942 .53143 Mdot
.54301 .45041 Mdot
.46147 .43593 Mdot
.52087 .52364 Mdot
.52613 .46467 Mdot
.44433 .53628 Mdot
.4777 .43492 Mdot
.5177 .52253 Mdot
.4613 .46761 Mdot
.51144 .5541 Mdot
.56336 .54069 Mdot
.50764 .43063 Mdot
.57721 .50651 Mdot
.49567 .51762 Mdot
.49616 .48557 Mdot
.43005 .50939 Mdot
.51429 .56262 Mdot
.46849 .51111 Mdot
.54882 .44826 Mdot
.45136 .43824 Mdot
.46826 .47332 Mdot
.51373 .4522 Mdot
.53595 .46717 Mdot
.45257 .5412 Mdot
.5099 .55269 Mdot
.44365 .50875 Mdot
.5339 .46604 Mdot
.45957 .55203 Mdot
.56525 .50602 Mdot
.49122 .55626 Mdot
.42831 .50298 Mdot
.55405 .49448 Mdot
.50327 .55725 Mdot
.47929 .49494 Mdot
.49711 .48001 Mdot
.4512 .49565 Mdot
.53548 .45511 Mdot
.4374 .54129 Mdot
.4795 .52392 Mdot
.46716 .5167 Mdot
.48213 .45847 Mdot
.43972 .50365 Mdot
.45041 .4902 Mdot
.51624 .48403 Mdot
.45628 .43696 Mdot
.49494 .48982 Mdot
.47916 .57197 Mdot
.44427 .49846 Mdot
.51246 .46659 Mdot
.438 .5141 Mdot
.50941 .4816 Mdot
.45117 .52696 Mdot
.43816 .5047 Mdot
.49088 .57285 Mdot
.48492 .52988 Mdot
.50437 .43655 Mdot
.53486 .50219 Mdot
.43954 .52287 Mdot
.54108 .51834 Mdot
.49158 .52349 Mdot
.48185 .48371 Mdot
.52202 .54356 Mdot
.50588 .51074 Mdot
.55647 .55298 Mdot
.54139 .50811 Mdot
.50385 .52116 Mdot
.524 .51227 Mdot
.51686 .45891 Mdot
.43186 .5321 Mdot
.49117 .43864 Mdot
.49115 .44803 Mdot
.51929 .4484 Mdot
.45227 .51214 Mdot
.52483 .49792 Mdot
.47738 .46567 Mdot
.50492 .53063 Mdot
.57853 .49136 Mdot
.48124 .51458 Mdot
.49292 .57374 Mdot
.55419 .46861 Mdot
.5279 .57315 Mdot
.48867 .49685 Mdot
.52414 .45954 Mdot
.53981 .52952 Mdot
.49851 .48675 Mdot
.45563 .50823 Mdot
.44034 .52463 Mdot
.48086 .48447 Mdot
.52062 .44128 Mdot
.48776 .4911 Mdot
.55384 .45457 Mdot
.53986 .51292 Mdot
.57115 .52298 Mdot
.5261 .46932 Mdot
.45557 .47951 Mdot
.55563 .54716 Mdot
.51401 .54827 Mdot
.55332 .50045 Mdot
.54618 .54842 Mdot
.49853 .45454 Mdot
.49419 .4854 Mdot
.45454 .50423 Mdot
.5181 .52605 Mdot
.50202 .49213 Mdot
.45719 .51092 Mdot
.47821 .562 Mdot
.50577 .57181 Mdot
.43343 .48367 Mdot
.45925 .52788 Mdot
.53298 .4792 Mdot
.45635 .46185 Mdot
.42872 .49338 Mdot
.48575 .55716 Mdot
.45393 .53571 Mdot
.45387 .50466 Mdot
.54969 .48078 Mdot
.482 .51049 Mdot
.56947 .49556 Mdot
.4622 .50087 Mdot
.50021 .49517 Mdot
.42991 .51221 Mdot
.49934 .56616 Mdot
.50686 .53474 Mdot
.55951 .53592 Mdot
.48678 .5629 Mdot
.53387 .5134 Mdot
.52372 .53158 Mdot
.43596 .51002 Mdot
.52611 .52298 Mdot
.53944 .43857 Mdot
.57617 .48105 Mdot
.43922 .54437 Mdot
.51519 .48019 Mdot
.46653 .50134 Mdot
.57254 .4948 Mdot
.50798 .45654 Mdot
.53042 .51333 Mdot
.52109 .51007 Mdot
.49058 .57733 Mdot
.54316 .48831 Mdot
.44037 .49701 Mdot
.44679 .51074 Mdot
.55091 .46616 Mdot
.44438 .52421 Mdot
.44812 .52667 Mdot
.48925 .54872 Mdot
.51296 .44119 Mdot
.50906 .48964 Mdot
.54269 .52228 Mdot
.54764 .56012 Mdot
.53001 .54503 Mdot
.44944 .48662 Mdot
.57033 .49964 Mdot
.48289 .50504 Mdot
.46682 .50931 Mdot
.46139 .53558 Mdot
.44953 .53629 Mdot
.48796 .50261 Mdot
.57486 .48358 Mdot
.57179 .46976 Mdot
.49882 .55647 Mdot
.50817 .5121 Mdot
.49278 .50065 Mdot
.55061 .48658 Mdot
.51108 .47464 Mdot
.53525 .46471 Mdot
.48026 .42476 Mdot
.50758 .49047 Mdot
.48188 .46124 Mdot
.50029 .49207 Mdot
.54148 .51926 Mdot
.50302 .51062 Mdot
.53699 .56434 Mdot
.43743 .5499 Mdot
.56471 .53325 Mdot
.51535 .45299 Mdot
.4547 .45628 Mdot
.48722 .58084 Mdot
.49242 .56652 Mdot
.51212 .42403 Mdot
.54081 .48741 Mdot
.44799 .5598 Mdot
.50742 .57934 Mdot
.42827 .48746 Mdot
.47713 .50908 Mdot
.42664 .50278 Mdot
.49252 .46864 Mdot
.54583 .5198 Mdot
.44719 .51949 Mdot
.53333 .53895 Mdot
.4347 .49238 Mdot
.48947 .44809 Mdot
.54449 .48179 Mdot
.48562 .44579 Mdot
.54741 .51774 Mdot
.44168 .49194 Mdot
.54504 .49723 Mdot
.44743 .54274 Mdot
.48132 .4787 Mdot
.48662 .46751 Mdot
.44381 .48254 Mdot
.55421 .46097 Mdot
.4427 .54785 Mdot
.4639 .49401 Mdot
.51899 .45648 Mdot
.52403 .55907 Mdot
.55947 .55006 Mdot
.50809 .50017 Mdot
.44444 .50588 Mdot
.53787 .49827 Mdot
.51171 .54383 Mdot
.4936 .49018 Mdot
.56219 .50359 Mdot
.52648 .52349 Mdot
.56898 .48901 Mdot
.5708 .46559 Mdot
.45343 .49686 Mdot
.53255 .52338 Mdot
.50595 .45125 Mdot
.45812 .51491 Mdot
.44926 .44545 Mdot
.50108 .49403 Mdot
.51334 .44785 Mdot
.42389 .50146 Mdot
.54818 .55296 Mdot
.49782 .43591 Mdot
.42287 .49614 Mdot
.53332 .55762 Mdot
.46279 .54779 Mdot
.45192 .52057 Mdot
.52416 .49139 Mdot
.48037 .52065 Mdot
.48373 .47183 Mdot
.5198 .48553 Mdot
.50654 .56507 Mdot
.50134 .47383 Mdot
.43088 .51864 Mdot
.46455 .53656 Mdot
.47957 .57208 Mdot
.44237 .48495 Mdot
.4839 .53554 Mdot
.46048 .50629 Mdot
.49709 .47669 Mdot
.47216 .50244 Mdot
.4354 .5384 Mdot
.57469 .47544 Mdot
.4672 .49557 Mdot
.43434 .47713 Mdot
.45525 .51648 Mdot
.45555 .48657 Mdot
.44774 .50326 Mdot
.45318 .55058 Mdot
.46697 .49279 Mdot
.50155 .55466 Mdot
.50685 .51949 Mdot
.53428 .52863 Mdot
.52165 .52311 Mdot
.45391 .49919 Mdot
.50187 .49797 Mdot
.47839 .55263 Mdot
.54213 .45699 Mdot
.51731 .51359 Mdot
.49882 .47163 Mdot
.53504 .5252 Mdot
.42667 .48485 Mdot
.51868 .57131 Mdot
.48201 .43162 Mdot
.44765 .51331 Mdot
.5552 .47805 Mdot
.48923 .51951 Mdot
.46431 .55208 Mdot
.46435 .54617 Mdot
.53497 .43053 Mdot
.46052 .47426 Mdot
.43332 .52016 Mdot
.51355 .48414 Mdot
.49404 .57476 Mdot
.5341 .50152 Mdot
.50612 .49518 Mdot
.55311 .4615 Mdot
.47465 .53961 Mdot
.55862 .48456 Mdot
.4617 .55568 Mdot
.52175 .49565 Mdot
.54547 .45414 Mdot
.49063 .44023 Mdot
.51408 .4262 Mdot
.50866 .55753 Mdot
.51201 .48847 Mdot
.46432 .48319 Mdot
.48974 .5123 Mdot
.55345 .51406 Mdot
.46167 .55259 Mdot
.43052 .52865 Mdot
.44987 .56202 Mdot
.53195 .43963 Mdot
.51891 .47338 Mdot
.469 .50746 Mdot
.45979 .51915 Mdot
.45281 .4723 Mdot
.528 .48087 Mdot
.46959 .52696 Mdot
.52781 .48917 Mdot
.47527 .44312 Mdot
.54924 .48392 Mdot
.44662 .46032 Mdot
.55127 .48201 Mdot
.55387 .55861 Mdot
.45511 .51155 Mdot
.56851 .51469 Mdot
.48425 .50807 Mdot
.51232 .46736 Mdot
.54177 .44554 Mdot
.51881 .42391 Mdot
.49008 .56139 Mdot
.45708 .5102 Mdot
.49174 .47809 Mdot
.51287 .55407 Mdot
.54515 .53334 Mdot
.44595 .52107 Mdot
.53429 .50067 Mdot
.50342 .43667 Mdot
.52969 .49258 Mdot
.47801 .54865 Mdot
.45266 .51206 Mdot
.53703 .46533 Mdot
.43788 .48728 Mdot
.50575 .47061 Mdot
.51484 .55947 Mdot
.55233 .47028 Mdot
.48153 .50292 Mdot
.51311 .48119 Mdot
.53256 .43939 Mdot
.45263 .51638 Mdot
.50811 .56085 Mdot
.42758 .5085 Mdot
.5243 .52471 Mdot
.5462 .49079 Mdot
.54827 .48343 Mdot
.46556 .49265 Mdot
.56216 .53842 Mdot
.55605 .49711 Mdot
.56819 .48948 Mdot
.44887 .50067 Mdot
.49265 .49901 Mdot
.47776 .50911 Mdot
.47066 .46783 Mdot
.48835 .5279 Mdot
.51811 .48038 Mdot
.47413 .44048 Mdot
.48973 .56273 Mdot
.44718 .50357 Mdot
.43577 .48565 Mdot
.54736 .4432 Mdot
.56774 .46275 Mdot
.48978 .45298 Mdot
.51092 .4236 Mdot
.47522 .46601 Mdot
.44368 .5022 Mdot
.49439 .4704 Mdot
.54702 .49943 Mdot
.45795 .53326 Mdot
.56005 .53062 Mdot
.50478 .57976 Mdot
.55819 .44826 Mdot
.49934 .48565 Mdot
.49327 .50656 Mdot
.45311 .53929 Mdot
.51289 .49124 Mdot
.52962 .51856 Mdot
.50462 .44988 Mdot
.49902 .48532 Mdot
.50973 .50983 Mdot
.48559 .44486 Mdot
.46172 .52056 Mdot
.52679 .4475 Mdot
.52823 .47387 Mdot
.44366 .51947 Mdot
.53229 .48126 Mdot
.43109 .54008 Mdot
.47146 .525 Mdot
.47296 .44074 Mdot
.5634 .48474 Mdot
.47732 .56177 Mdot
.5227 .56067 Mdot
.52118 .49414 Mdot
.52957 .53718 Mdot
.44827 .50527 Mdot
.48263 .48338 Mdot
.43777 .54136 Mdot
.5653 .53023 Mdot
.45728 .56401 Mdot
.55391 .52298 Mdot
.52705 .50359 Mdot
.42976 .51967 Mdot
.5443 .52163 Mdot
.47798 .48103 Mdot
.45399 .50882 Mdot
.53237 .44216 Mdot
.45977 .56486 Mdot
.44597 .48075 Mdot
.49702 .50179 Mdot
.53946 .44572 Mdot
.48831 .5207 Mdot
.51614 .52163 Mdot
.44998 .44163 Mdot
.53521 .51189 Mdot
.5468 .47927 Mdot
.5058 .48108 Mdot
.51144 .47684 Mdot
.48009 .53855 Mdot
.51883 .46976 Mdot
.54859 .5394 Mdot
.52901 .47937 Mdot
.44307 .45341 Mdot
.52533 .49244 Mdot
.52976 .44231 Mdot
.4854 .47407 Mdot
.53405 .53735 Mdot
.55307 .53478 Mdot
.48756 .45742 Mdot
.46293 .4599 Mdot
.50028 .48287 Mdot
.52218 .53309 Mdot
.54424 .49963 Mdot
.48764 .48935 Mdot
.49618 .44925 Mdot
.57389 .51002 Mdot
.49264 .56804 Mdot
.48605 .43792 Mdot
.45924 .50406 Mdot
.50642 .49838 Mdot
.54656 .55871 Mdot
.48735 .4532 Mdot
.50433 .43093 Mdot
.52192 .48628 Mdot
.53497 .53411 Mdot
.48843 .48474 Mdot
.4958 .42375 Mdot
.52874 .49714 Mdot
.51724 .47277 Mdot
.46464 .46746 Mdot
.47399 .42925 Mdot
.54826 .5002 Mdot
.51163 .4924 Mdot
.44972 .43849 Mdot
.46418 .50117 Mdot
.55991 .54124 Mdot
.4956 .43383 Mdot
.52428 .43762 Mdot
.45648 .55812 Mdot
.52389 .55433 Mdot
.54092 .45999 Mdot
.52353 .48816 Mdot
.44168 .49025 Mdot
.48691 .56446 Mdot
.5585 .49446 Mdot
.56225 .49754 Mdot
.52462 .46063 Mdot
.49982 .5733 Mdot
.44054 .51694 Mdot
.50587 .48461 Mdot
.43225 .51778 Mdot
.54818 .49308 Mdot
.53086 .4883 Mdot
.45966 .52156 Mdot
.50481 .44569 Mdot
.44138 .5071 Mdot
.55215 .55611 Mdot
.54182 .43882 Mdot
.4715 .45672 Mdot
.51827 .49458 Mdot
.43332 .47677 Mdot
.48838 .49912 Mdot
.4833 .50304 Mdot
.54319 .46589 Mdot
.55014 .45284 Mdot
.52034 .47072 Mdot
.45928 .50678 Mdot
.48666 .44177 Mdot
.48792 .4599 Mdot
.51126 .56625 Mdot
.44051 .54207 Mdot
.45833 .45733 Mdot
.52969 .57439 Mdot
.44054 .50862 Mdot
.56552 .5397 Mdot
.51628 .49411 Mdot
.47737 .49217 Mdot
.43275 .5166 Mdot
.43248 .52353 Mdot
.52296 .51686 Mdot
.54139 .53112 Mdot
.50427 .55078 Mdot
.55564 .52272 Mdot
.56583 .48409 Mdot
.51205 .56366 Mdot
.51625 .47695 Mdot
.43564 .5055 Mdot
.49622 .52114 Mdot
.48743 .56121 Mdot
.52227 .53113 Mdot
.52445 .56558 Mdot
.47415 .51314 Mdot
.45764 .51233 Mdot
.44095 .49186 Mdot
.5009 .44064 Mdot
.56389 .46552 Mdot
.55658 .44875 Mdot
.43815 .52232 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go
00001_ooool3o`000?ooooooB?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04
odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol0003o
oooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`3o
ooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007
ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<
ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`2Hooooo`;o00000oooool2o`0000?ooooo
0_l000000ooooooo0000o`00002Pooooo`007_ooool00ol0003oooooooooo`2Eooooo`;o000000Co
ooooo`000?l0003ooooo1?l00002ooooo`Ko0000X?ooool001kooooo00?o0000ooooooooool0T_oo
ool2o`000003ooooool0003o000000So000000?oooooo`000?l000001Ol00003ooooo`;o0000Vooo
ool001kooooo00?o0000ooooooooool0TOooool3o`000003ooooool0003o000000So000000Gooooo
o`000?l0003o0000ooooo`03o`0000?ooooo0ol0002Jooooo`007_ooool00ol0003oooooooooo`2>
oooooaGo00000oooool2o`0000;ooooo0ol0002Jooooo`007_ooool00ol0003oooooooooo`2>oooo
o`_o000000?oooooo`000?l000001_l000001?oooooo0000o`000?ooool8o`0009Wooooo000Noooo
o`03o`000?oooooooooo08gooooo1_l000000ooooooo0000o`000003o`000003ooooool0003o0000
00Go00000_ooool=o`0009Oooooo000Nooooo`03o`000?oooooooooo08gooooo2ol00002ooooo`So
00000oooool<o`0009Kooooo000Nooooo`03o`000?oooooooooo08kooooo1?l000000ooooooo0000
o`000004o`000003ooooool0003o000000Ko000000?oooooo`000?l000001Ol000000ooooooo0000
o`000006o`0009Cooooo000Nooooo`;o0000Roooool6o`0000Oooooo2?l000000ooooooo0000o`00
000Ao`0009Cooooo000Nooooo`03o`000?oooooooooo08[ooooo2ol00004ooooo`oo000000?ooooo
o`000?l000001ol0002Eooooo`007_ooool00ol0003oooooooooo`2=ooooo`[o00000_ooool3o`00
0005ooooool0003o0000o`000?ooool01ol000000ooooooo0000o`000008o`000003ooooool0003o
0000097ooooo000Nooooo`03o`000?oooooooooo08gooooo0_l000000ooooooo0000o`000002o`00
0003ooooool0003o000000;ooooo1ol00004ooooo`oo000000?oooooo`000?l00000TOooool001ko
oooo00?o0000ooooooooool0S?ooool3o`000003ooooool0003o000000;o00000oooool9o`0000;o
oooo0_l00002ooooo`?o000000?oooooo`000?l000001_l000000ooooooo0000o`000002o`00093o
oooo000Nooooo`03o`000?oooooooooo08cooooo1?l000000ooooooo0000o`00000;o`0000Cooooo
1?l000000ooooooo0000o`00000>o`00093ooooo000Nooooo`03o`000?oooooooooo08Oooooo0_l0
0004ooooo`?o00000_oooolLo`000003ooooool0003o000000?o000000Coooooo`000?l0003o0000
Soooool001kooooo00?o0000ooooooooool0Qoooool2o`000004ooooool0003o0000ooooo`Co0000
00?oooooo`000?l000000_l000000ooooooo0000o`00000Bo`0000Cooooo1?l00002ooooo`?o0000
Soooool001kooooo00?o0000ooooooooool0ROooool4o`0000;ooooo4_l000000ooooooo0000o`00
0003o`000004ooooool0003o0000o`0000Gooooo2Ol0002>ooooo`007_ooool00ol0003ooooooooo
o`29ooooo`Ko000000?oooooo`000?l000000_l00002oooooa3o000000?oooooo`000?l000000ol0
0002ooooo`Oo000000Coooooo`000?l0003o0000S_ooool001kooooo00?o0000ooooooooool0ROoo
oolMo`000003ooooool0003o000000?o000000?oooooo`000?l000000_l000000ooooooo0000o`00
0005o`0008kooooo000Nooooo`03o`000?oooooooooo08Oooooo<_l0002>ooooo`007_ooool00ol0
003oooooooooo`27ooooobOo000000?oooooo`000?l000002?l0002>ooooo`007_ooool00ol0003o
ooooooooo`26ooooo`Oo000000?oooooo`000?l000002Ol000000ooooooo0000o`00000Fo`000003
ooooool0003o000000;o000000?oooooo`000?l00000SOooool001kooooo00?o0000ooooooooool0
QOoooolIo`000003ooooool0003o000000_o000000?oooooo`000?l000001?l00002ooooo`Go0000
SOooool001kooooo00?o0000ooooooooool0QOooool2o`000003ooooool0003o000001Co000000?o
ooooo`000?l000000_l000000ooooooo0000o`00000Bo`0008oooooo000Nooooo`;o0000Qoooool4
o`000003ooooool0003o000001Wo000000?oooooo`000?l000003_l0002@ooooo`007_ooool00ol0
003oooooooooo`26ooooobco000000Coooooo`000?l0003o0000TOooool001kooooo00?o0000oooo
ooooool0Qoooool?o`000003ooooool0003o000001Ko00001?ooool3o`0000;ooooo0_l0002=oooo
o`007_ooool00ol0003oooooooooo`27ooooo`oo000000?oooooo`000?l000001Ol000000ooooooo
0000o`00000>o`0000Gooooo1_l0002=ooooo`007_ooool00ol0003oooooooooo`28ooooob_o0000
0_ooool5o`0008gooooo000Nooooo`03o`000?oooooooooo08Sooooo5ol00002ooooo`;o000000?o
ooooo`000?l000003Ol00002ooooo`;o000000?oooooo`000?l00000SOooool001kooooo00?o0000
ooooooooool0R?ooool?o`000003ooooool0003o000000Go000000Goooooo`000?l0003o0000oooo
o`0>o`0000Cooooo0_l0002?ooooo`007_ooool00ol0003oooooooooo`28ooooo`co000000?ooooo
o`000?l000003?l000000ooooooo0000o`00000=o`0000?ooooo0_l0002?ooooo`007_ooool00ol0
003oooooooooo`28ooooo`co000000?oooooo`000?l000001?l000000ooooooo0000o`000004o`00
00;ooooo4Ol000000ooooooo0000o`00002?ooooo`007_ooool00ol0003oooooooooo`28ooooo`;o
000000Coooooo`000?l0003ooooo1Ol00002ooooo`?o000000?oooooo`000?l000000_l000000ooo
oooo0000o`000004ooooo`Co000000?oooooo`000?l000002ol0002Aooooo`007_ooool00ol0003o
ooooooooo`27ooooo`Ko00001?ooool2o`0000;ooooo0ol000000ooooooo0000o`000004o`000003
ooooool0003o000000?o000000Goooooo`000?l0003o0000ooooo`0<o`00097ooooo000Nooooo`03
o`000?oooooooooo08Oooooo5?l00002ooooo`So000000?oooooo`000?l000001ol000000ooooooo
0000o`000003o`0009;ooooo000Nooooo`03o`000?oooooooooo08Wooooo2?l000000ooooooo0000
o`000007o`0000;ooooo0ol000001?oooooo0000o`000?ooool2o`0000;ooooo1?l00002ooooo`So
0000TOooool001kooooo00?o0000ooooooooool0R?ooool9o`0000Gooooo1_l000000ooooooo0000
o`000005ooooo`;o00000_ooool>o`00097ooooo000Nooooo`03o`000?oooooooooo08Sooooo2ol0
0006ooooo`?o000000?oooooo`000?l000000oooool2o`0000;ooooo1?l000000ooooooo0000o`00
0002o`0000;ooooo1?l0002Booooo`007_ooool00ol0003oooooooooo`2:ooooo`Ko000000?ooooo
o`000?l000000_l00002ooooo`So00000_ooool4o`000003ooooool0003o000000?o00000_ooool6
o`0009Cooooo000Nooooo`;o0000Roooool;o`0000;ooooo2?l000000ooooooo0000o`000003o`00
0003ooooool0003o000000co0000Toooool001kooooo00?o0000ooooooooool0R_ooool2o`0000?o
oooo1_l00002ooooo`Ko00000_ooool6o`000005ooooool0003o0000o`000?ooool01_l000001?oo
oooo0000o`000?l0002Cooooo`007_ooool00ol0003oooooooooo`2=ooooo`;o000000?oooooo`00
0?l000000ol00002ooooo`;o000000?oooooo`000?l000002Ol000000ooooooo0000o`00000;o`00
09Cooooo000Nooooo`03o`000?oooooooooo08gooooo2?l00002ooooo`ko000000Coooooo`000?l0
003ooooo2Ol0002Eooooo`007_ooool00ol0003oooooooooo`2=ooooo`Ko00001?ooool8o`0000;o
oooo1?l000000ooooooo0000o`000002ooooo`So0000UOooool001kooooo00?o0000ooooooooool0
S_ooool6o`000003ooooool0003o000000Wo000000?oooooo`000?l000000_l000000ooooooo0000
o`000002ooooo`Co0000VOooool001kooooo00?o0000ooooooooool0TOooool6o`0000?ooooo2ol0
00000ooooooo0000o`000002ooooo`;o0000Voooool001kooooo00?o0000ooooooooool0Toooool3
o`0000;ooooo2_l000000ooooooo0000o`000007o`0009_ooooo000Nooooo`03o`000?oooooooooo
09Cooooo0_l000001Ooooooo0000o`000?l0003ooooo00Oo00000oooool6o`0009cooooo000Noooo
o`03o`000?oooooooooo09Gooooo1?l000000ooooooo0000o`000004o`000005ooooool0003o0000
o`000?ooool00_l000001?oooooo0000o`000?l0002Looooo`007_ooool00ol0003oooooooooo`2E
ooooo`;o00000oooool3o`000003ooooool0003o000000Co0000Xoooool001kooooo00?o0000oooo
ooooool0V_ooool2o`0000;ooooo1?l0002Uooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000oooooooo
ool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0003o
ooooodSooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonH
V9So8B4Q00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol0003ooooooooooooo
oooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo
B?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo
00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003ooooo
odWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`00
0?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003o
oooooooooooooooo000000Kooooo0ol0003oooooodSooooo0003ooooo`05o`000?oooooooooooooo
ool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000ooooooooool0oooooom8
ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@
400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`3oooooodSooooo
0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Ko
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000
oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001Cooooo1?l0
00000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB?ooool001Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`3oooooodSooooo000Fooooo`03o`000?oooooooooo
00Gooooo0ol0003oooooodSooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo
00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000F
ooooo`03o`000?oooooooooo0?ooooooD?ooool001Cooooo00?oEEEEofIVI_l00000oooooomBoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.46399 .53782 Mdot
.52877 .50849 Mdot
.55552 .50542 Mdot
.52417 .51294 Mdot
.51181 .52891 Mdot
.44766 .51212 Mdot
.56104 .521 Mdot
.50054 .54375 Mdot
.50845 .44006 Mdot
.45759 .48644 Mdot
.47023 .52175 Mdot
.50086 .4888 Mdot
.44492 .51396 Mdot
.52597 .54675 Mdot
.54371 .45954 Mdot
.46012 .48355 Mdot
.51904 .53729 Mdot
.44524 .47943 Mdot
.45388 .48515 Mdot
.50656 .47228 Mdot
.51188 .54634 Mdot
.46812 .45748 Mdot
.49217 .52901 Mdot
.46177 .5469 Mdot
.49414 .54683 Mdot
.49193 .4897 Mdot
.5278 .45583 Mdot
.45203 .48571 Mdot
.51407 .51856 Mdot
.4491 .52513 Mdot
.5461 .51161 Mdot
.52296 .52707 Mdot
.49508 .50261 Mdot
.53824 .47887 Mdot
.44637 .51902 Mdot
.5517 .49387 Mdot
.48559 .48871 Mdot
.50926 .45068 Mdot
.50147 .53162 Mdot
.49469 .48368 Mdot
.47363 .49094 Mdot
.49473 .46765 Mdot
.53977 .49751 Mdot
.5046 .50101 Mdot
.51884 .53435 Mdot
.4667 .48123 Mdot
.52938 .54637 Mdot
.5464 .51899 Mdot
.54822 .49791 Mdot
.48372 .43639 Mdot
.50667 .52931 Mdot
.43644 .5057 Mdot
.51534 .51456 Mdot
.50453 .53604 Mdot
.45392 .47957 Mdot
.47604 .47853 Mdot
.51933 .48524 Mdot
.43238 .50816 Mdot
.51806 .53155 Mdot
.52324 .48487 Mdot
.4636 .47088 Mdot
.47447 .48591 Mdot
.52652 .4746 Mdot
.46243 .4856 Mdot
.5041 .52441 Mdot
.50826 .43654 Mdot
.53361 .52698 Mdot
.46748 .47656 Mdot
.48876 .47425 Mdot
.45688 .48045 Mdot
.56074 .48847 Mdot
.51781 .52723 Mdot
.5148 .48135 Mdot
.51519 .50162 Mdot
.45088 .5344 Mdot
.53811 .46713 Mdot
.47779 .47199 Mdot
.44689 .48366 Mdot
.56353 .49702 Mdot
.47621 .51079 Mdot
.50823 .45611 Mdot
.49619 .54383 Mdot
.50344 .5489 Mdot
.47249 .48865 Mdot
.53065 .47583 Mdot
.51548 .50626 Mdot
.54339 .47628 Mdot
.471 .48068 Mdot
.4977 .48266 Mdot
.4442 .49055 Mdot
.50955 .5183 Mdot
.46226 .47995 Mdot
.52437 .46318 Mdot
.49975 .43482 Mdot
.55977 .51116 Mdot
.46702 .46492 Mdot
.47185 .47892 Mdot
.54421 .51848 Mdot
.53121 .54482 Mdot
.52385 .48867 Mdot
.53905 .47302 Mdot
.52432 .46589 Mdot
.51257 .53593 Mdot
.47303 .44186 Mdot
.5167 .44315 Mdot
.49258 .49886 Mdot
.52178 .56325 Mdot
.5071 .52337 Mdot
.53738 .51616 Mdot
.46105 .47916 Mdot
.46933 .54843 Mdot
.51868 .52623 Mdot
.51636 .4935 Mdot
.49597 .44416 Mdot
.52128 .54315 Mdot
.4375 .50129 Mdot
.5206 .45063 Mdot
.44771 .4788 Mdot
.55223 .51626 Mdot
.52215 .46088 Mdot
.46179 .50502 Mdot
.49637 .49273 Mdot
.45584 .48419 Mdot
.54761 .5043 Mdot
.52667 .52403 Mdot
.48225 .44648 Mdot
.46079 .54404 Mdot
.49454 .49198 Mdot
.50045 .49798 Mdot
.46951 .49069 Mdot
.46981 .50963 Mdot
.5177 .54221 Mdot
.4465 .54171 Mdot
.5426 .48551 Mdot
.48461 .53458 Mdot
.45771 .55209 Mdot
.46163 .45254 Mdot
.50742 .5088 Mdot
.50234 .47821 Mdot
.51022 .49505 Mdot
.50835 .52162 Mdot
.51572 .44457 Mdot
.49722 .49863 Mdot
.52122 .51515 Mdot
.49565 .51014 Mdot
.45995 .47692 Mdot
.459 .5341 Mdot
.47275 .46376 Mdot
.5202 .54533 Mdot
.54707 .49923 Mdot
.53315 .47893 Mdot
.45107 .48494 Mdot
.51129 .5235 Mdot
.52087 .54984 Mdot
.46983 .51387 Mdot
.45933 .48282 Mdot
.47685 .48787 Mdot
.44432 .53222 Mdot
.47854 .47216 Mdot
.50048 .51643 Mdot
.55084 .47218 Mdot
.48532 .47034 Mdot
.45477 .49883 Mdot
.45259 .47347 Mdot
.5066 .48358 Mdot
.5139 .48867 Mdot
.5233 .44601 Mdot
.49643 .45606 Mdot
.47852 .46096 Mdot
.49998 .4477 Mdot
.46716 .49927 Mdot
.5454 .49782 Mdot
.53129 .50386 Mdot
.50513 .48246 Mdot
.55988 .48286 Mdot
.47801 .48394 Mdot
.46538 .46281 Mdot
.50071 .51891 Mdot
.49779 .56581 Mdot
.54122 .48717 Mdot
.52308 .51117 Mdot
.46374 .46547 Mdot
.51118 .50316 Mdot
.51584 .51569 Mdot
.44221 .50847 Mdot
.50422 .49022 Mdot
.55105 .48557 Mdot
.46359 .469 Mdot
.49678 .43609 Mdot
.52911 .46418 Mdot
.5067 .49704 Mdot
.48641 .50467 Mdot
.47203 .55234 Mdot
.50982 .52351 Mdot
.50373 .44906 Mdot
.48133 .49511 Mdot
.48902 .43513 Mdot
.49897 .5019 Mdot
.49961 .52273 Mdot
.52544 .50574 Mdot
.52656 .49195 Mdot
.4676 .47306 Mdot
.46472 .50514 Mdot
.49045 .46007 Mdot
.45961 .48541 Mdot
.53187 .50096 Mdot
.50547 .55215 Mdot
.52725 .48875 Mdot
.54835 .48519 Mdot
.5098 .52543 Mdot
.51802 .53609 Mdot
.49028 .49225 Mdot
.49188 .47926 Mdot
.45652 .50841 Mdot
.49648 .49256 Mdot
.52327 .5526 Mdot
.46272 .47857 Mdot
.48009 .47358 Mdot
.5144 .44424 Mdot
.50555 .52056 Mdot
.48943 .5141 Mdot
.43553 .51885 Mdot
.46065 .47751 Mdot
.48599 .56176 Mdot
.47539 .52923 Mdot
.48658 .5399 Mdot
.52264 .52408 Mdot
.45231 .4808 Mdot
.55252 .48928 Mdot
.47891 .51703 Mdot
.45475 .46501 Mdot
.49245 .49375 Mdot
.50517 .44455 Mdot
.48234 .48975 Mdot
.48369 .4849 Mdot
.50441 .47821 Mdot
.4919 .44555 Mdot
.54288 .47099 Mdot
.53032 .52119 Mdot
.50413 .49013 Mdot
.45275 .48144 Mdot
.54233 .46033 Mdot
.45937 .5384 Mdot
.48684 .44642 Mdot
.55604 .52028 Mdot
.45337 .47807 Mdot
.53857 .46616 Mdot
.49385 .54158 Mdot
.45226 .47193 Mdot
.52359 .45047 Mdot
.53786 .49519 Mdot
.44069 .50448 Mdot
.53539 .45688 Mdot
.55843 .51575 Mdot
.51539 .49544 Mdot
.50591 .48712 Mdot
.48729 .51986 Mdot
.48383 .4778 Mdot
.53239 .47601 Mdot
.52833 .45112 Mdot
.49783 .45711 Mdot
.48331 .49829 Mdot
.50016 .51593 Mdot
.46353 .50986 Mdot
.51638 .4739 Mdot
.51996 .47241 Mdot
.48086 .52003 Mdot
.45895 .49615 Mdot
.48541 .49721 Mdot
.49161 .56574 Mdot
.53846 .51715 Mdot
.51613 .49325 Mdot
.49997 .43587 Mdot
.51235 .49374 Mdot
.55628 .49684 Mdot
.5469 .47152 Mdot
.47431 .47453 Mdot
.45781 .48871 Mdot
.5031 .47312 Mdot
.4732 .49714 Mdot
.49629 .47661 Mdot
.48712 .48464 Mdot
.539 .53209 Mdot
.50052 .50914 Mdot
.51106 .4481 Mdot
.49594 .43475 Mdot
.51058 .56288 Mdot
.48917 .5208 Mdot
.53119 .51605 Mdot
.51608 .55388 Mdot
.505 .48492 Mdot
.52227 .54492 Mdot
.43755 .49768 Mdot
.5409 .49531 Mdot
.51419 .48878 Mdot
.5056 .53795 Mdot
.45728 .49263 Mdot
.53624 .4832 Mdot
.4976 .4661 Mdot
.52358 .5153 Mdot
.5036 .50434 Mdot
.485 .53918 Mdot
.51671 .44142 Mdot
.45533 .47471 Mdot
.50246 .48656 Mdot
.52335 .51458 Mdot
.46745 .56121 Mdot
.48818 .55733 Mdot
.49098 .54673 Mdot
.5192 .47545 Mdot
.52124 .50441 Mdot
.49901 .50766 Mdot
.48324 .51385 Mdot
.4704 .53843 Mdot
.52541 .50116 Mdot
.51237 .55341 Mdot
.49333 .48343 Mdot
.46867 .47826 Mdot
.51027 .4807 Mdot
.50401 .45029 Mdot
.54261 .49012 Mdot
.46789 .52326 Mdot
.46541 .52177 Mdot
.47667 .48191 Mdot
.46227 .49505 Mdot
.48757 .44935 Mdot
.50571 .49849 Mdot
.50012 .49695 Mdot
.49106 .44212 Mdot
.51292 .46257 Mdot
.45644 .53317 Mdot
.43937 .50854 Mdot
.5163 .49263 Mdot
.45845 .4877 Mdot
.54835 .48628 Mdot
.48338 .50562 Mdot
.5341 .47994 Mdot
.52091 .52076 Mdot
.46843 .52885 Mdot
.47384 .48485 Mdot
.53549 .52553 Mdot
.4999 .55741 Mdot
.5423 .5438 Mdot
.49687 .49996 Mdot
.4782 .45442 Mdot
.52453 .53722 Mdot
.50163 .50942 Mdot
.50555 .5409 Mdot
.4988 .45639 Mdot
.47203 .48846 Mdot
.51273 .48512 Mdot
.44404 .5375 Mdot
.51602 .54041 Mdot
.48234 .48842 Mdot
.44375 .49938 Mdot
.51232 .48708 Mdot
.50511 .56233 Mdot
.52507 .53289 Mdot
.43861 .49318 Mdot
.49256 .49992 Mdot
.50182 .52442 Mdot
.51024 .55519 Mdot
.51369 .4901 Mdot
.50291 .56137 Mdot
.52576 .53322 Mdot
.54143 .5308 Mdot
.55032 .52805 Mdot
.49311 .45552 Mdot
.49415 .56767 Mdot
.51445 .5067 Mdot
.50089 .51705 Mdot
.50766 .512 Mdot
.43997 .52809 Mdot
.47549 .52398 Mdot
.55339 .5108 Mdot
.45901 .48616 Mdot
.47791 .52096 Mdot
.5423 .47344 Mdot
.49617 .46956 Mdot
.48924 .49037 Mdot
.53023 .47901 Mdot
.56203 .50877 Mdot
.51837 .52141 Mdot
.46861 .55422 Mdot
.52145 .52667 Mdot
.45298 .5153 Mdot
.45153 .48526 Mdot
.48498 .5097 Mdot
.47936 .48062 Mdot
.53089 .47985 Mdot
.45978 .55561 Mdot
.49505 .47172 Mdot
.54036 .4873 Mdot
.52237 .52817 Mdot
.49308 .52562 Mdot
.50576 .54375 Mdot
.45536 .47048 Mdot
.49673 .50575 Mdot
.46029 .49379 Mdot
.46659 .55843 Mdot
.47563 .56357 Mdot
.5376 .48253 Mdot
.44683 .54685 Mdot
.48835 .48491 Mdot
.53588 .48461 Mdot
.55059 .49407 Mdot
.51705 .51592 Mdot
.5035 .5191 Mdot
.53075 .49301 Mdot
.47428 .50549 Mdot
.50812 .49416 Mdot
.46528 .49447 Mdot
.51446 .50275 Mdot
.54719 .51608 Mdot
.51272 .50621 Mdot
.52695 .46656 Mdot
.45893 .47845 Mdot
.48095 .55686 Mdot
.5352 .48946 Mdot
.45332 .4814 Mdot
.47568 .50084 Mdot
.46615 .47951 Mdot
.51098 .50236 Mdot
.46183 .49097 Mdot
.43413 .52328 Mdot
.54276 .48449 Mdot
.53705 .45309 Mdot
.48164 .49416 Mdot
.50112 .47608 Mdot
.49037 .47982 Mdot
.50647 .55857 Mdot
.45691 .48033 Mdot
.5023 .55369 Mdot
.47644 .50275 Mdot
.48214 .45922 Mdot
.47046 .55245 Mdot
.47845 .45986 Mdot
.51901 .48479 Mdot
.49854 .55952 Mdot
.50654 .48294 Mdot
.54358 .49858 Mdot
.43972 .485 Mdot
.51991 .54961 Mdot
.46474 .51133 Mdot
.49221 .49888 Mdot
.46756 .50308 Mdot
.5154 .5268 Mdot
.46168 .48675 Mdot
.5421 .48113 Mdot
.51105 .51867 Mdot
.54199 .53276 Mdot
.50668 .49146 Mdot
.47159 .4893 Mdot
.50212 .48172 Mdot
.52143 .46848 Mdot
.50243 .44124 Mdot
.53251 .47891 Mdot
.50697 .45172 Mdot
.50409 .51573 Mdot
.48712 .47889 Mdot
.4942 .46247 Mdot
.5173 .49993 Mdot
.54746 .52032 Mdot
.48432 .49109 Mdot
.54042 .48939 Mdot
.48402 .56298 Mdot
.48206 .49225 Mdot
.51029 .50025 Mdot
.52859 .53584 Mdot
.48461 .47664 Mdot
.46339 .52662 Mdot
.47914 .49976 Mdot
.55075 .54172 Mdot
.55465 .46765 Mdot
.46256 .49436 Mdot
.50742 .44089 Mdot
.54994 .50554 Mdot
.55583 .46809 Mdot
.54013 .47325 Mdot
.45324 .54765 Mdot
.49845 .50595 Mdot
.51598 .54016 Mdot
.4941 .54266 Mdot
.51381 .5374 Mdot
.46513 .47782 Mdot
.49146 .46228 Mdot
.46165 .49029 Mdot
.46296 .53791 Mdot
.54404 .49434 Mdot
.54186 .47289 Mdot
.43463 .49195 Mdot
.5504 .48662 Mdot
.49881 .43863 Mdot
.50064 .52182 Mdot
.53311 .49137 Mdot
.44222 .49916 Mdot
.51293 .44583 Mdot
.49886 .5196 Mdot
.49179 .46441 Mdot
.48377 .54133 Mdot
.52903 .556 Mdot
.53624 .45555 Mdot
.55283 .53628 Mdot
.4851 .50648 Mdot
.50514 .49005 Mdot
.44932 .47613 Mdot
.483 .55011 Mdot
.46999 .49319 Mdot
.55536 .48574 Mdot
.48961 .43573 Mdot
.49495 .47191 Mdot
.53226 .47725 Mdot
.53764 .49685 Mdot
.44567 .50608 Mdot
.48316 .53949 Mdot
.45855 .48113 Mdot
.53702 .49528 Mdot
.44662 .51808 Mdot
.54053 .5334 Mdot
.46832 .53491 Mdot
.4518 .47228 Mdot
.53633 .5219 Mdot
.47682 .54094 Mdot
.48889 .48832 Mdot
.50949 .4877 Mdot
.47266 .47873 Mdot
.5436 .48795 Mdot
.43524 .50174 Mdot
.47037 .50426 Mdot
.46571 .49568 Mdot
.50948 .46688 Mdot
.45982 .47669 Mdot
.47516 .47524 Mdot
.51705 .49916 Mdot
.49427 .43702 Mdot
.50147 .49154 Mdot
.45489 .54484 Mdot
.46635 .47638 Mdot
.52454 .4868 Mdot
.45097 .48137 Mdot
.5149 .49458 Mdot
.4509 .49413 Mdot
.45803 .47651 Mdot
.4629 .55003 Mdot
.47221 .51075 Mdot
.53258 .45987 Mdot
.5188 .51824 Mdot
.44601 .48652 Mdot
.51615 .5303 Mdot
.47966 .50855 Mdot
.49805 .48327 Mdot
.49452 .53683 Mdot
.49573 .50711 Mdot
.52001 .56161 Mdot
.5206 .52491 Mdot
.48959 .51213 Mdot
.50714 .51719 Mdot
.5309 .48347 Mdot
.43593 .4928 Mdot
.522 .45557 Mdot
.51914 .46374 Mdot
.53747 .47673 Mdot
.46108 .48703 Mdot
.51407 .51065 Mdot
.50399 .46979 Mdot
.48693 .51948 Mdot
.56037 .52532 Mdot
.47603 .49934 Mdot
.46407 .55166 Mdot
.54946 .50382 Mdot
.49111 .56559 Mdot
.49288 .49246 Mdot
.53464 .48696 Mdot
.51124 .53636 Mdot
.50564 .49168 Mdot
.46594 .48682 Mdot
.44552 .48788 Mdot
.497 .48331 Mdot
.54124 .47096 Mdot
.49659 .4892 Mdot
.55609 .49223 Mdot
.51755 .52666 Mdot
.541 .54628 Mdot
.53059 .49455 Mdot
.48351 .47102 Mdot
.51995 .55664 Mdot
.4875 .53727 Mdot
.53263 .52562 Mdot
.511 .55256 Mdot
.52187 .47231 Mdot
.50415 .48908 Mdot
.46873 .48467 Mdot
.49779 .52191 Mdot
.50379 .49579 Mdot
.46456 .48873 Mdot
.45708 .53453 Mdot
.47372 .55489 Mdot
.46336 .46364 Mdot
.45501 .49875 Mdot
.52945 .50364 Mdot
.48962 .45769 Mdot
.45618 .46723 Mdot
.46402 .53326 Mdot
.44862 .50222 Mdot
.46803 .48457 Mdot
.53972 .51138 Mdot
.47912 .49743 Mdot
.54894 .52698 Mdot
.4753 .48612 Mdot
.50063 .49617 Mdot
.44713 .47775 Mdot
.47075 .54711 Mdot
.48694 .52361 Mdot
.52602 .55089 Mdot
.46284 .53881 Mdot
.5133 .52344 Mdot
.49963 .52848 Mdot
.45266 .47855 Mdot
.50445 .52415 Mdot
.55421 .47382 Mdot
.56236 .5175 Mdot
.43511 .50491 Mdot
.51864 .4965 Mdot
.47702 .48775 Mdot
.55233 .52693 Mdot
.5268 .47787 Mdot
.51102 .52139 Mdot
.50609 .51441 Mdot
.46158 .55453 Mdot
.53148 .51373 Mdot
.46468 .47334 Mdot
.45901 .48364 Mdot
.54803 .50105 Mdot
.44832 .48911 Mdot
.44925 .49255 Mdot
.4694 .52755 Mdot
.53649 .46764 Mdot
.50961 .49838 Mdot
.51574 .53347 Mdot
.51031 .56299 Mdot
.49969 .54179 Mdot
.47629 .47269 Mdot
.54797 .53 Mdot
.48347 .49486 Mdot
.47049 .49171 Mdot
.45335 .50547 Mdot
.44568 .50075 Mdot
.4883 .49527 Mdot
.55976 .51937 Mdot
.56409 .50745 Mdot
.47385 .53842 Mdot
.49662 .50898 Mdot
.49248 .49584 Mdot
.53745 .51562 Mdot
.51956 .49142 Mdot
.53852 .49484 Mdot
.51675 .43809 Mdot
.50817 .49798 Mdot
.5084 .46868 Mdot
.50291 .49491 Mdot
.51607 .53105 Mdot
.49387 .50569 Mdot
.50068 .56167 Mdot
.43125 .50994 Mdot
.53193 .55131 Mdot
.53289 .47852 Mdot
.48954 .45256 Mdot
.45826 .55713 Mdot
.46562 .5445 Mdot
.54057 .45059 Mdot
.53038 .51213 Mdot
.43518 .52279 Mdot
.47357 .56331 Mdot
.45739 .46386 Mdot
.47685 .49506 Mdot
.45045 .47184 Mdot
.51255 .47871 Mdot
.51877 .53383 Mdot
.45302 .4879 Mdot
.50381 .53905 Mdot
.46204 .46863 Mdot
.51794 .46298 Mdot
.53574 .50999 Mdot
.5159 .45914 Mdot
.5207 .5335 Mdot
.46808 .47138 Mdot
.52794 .52043 Mdot
.44166 .50566 Mdot
.50068 .48033 Mdot
.50925 .47522 Mdot
.47353 .46749 Mdot
.55324 .49751 Mdot
.43614 .50891 Mdot
.48128 .48319 Mdot
.53335 .48265 Mdot
.49113 .55074 Mdot
.52343 .56078 Mdot
.50247 .50246 Mdot
.46124 .48017 Mdot
.52265 .51755 Mdot
.48733 .53284 Mdot
.50046 .49113 Mdot
.53877 .53085 Mdot
.50452 .52464 Mdot
.55188 .52208 Mdot
.56535 .50365 Mdot
.47333 .48049 Mdot
.50855 .52809 Mdot
.52788 .47319 Mdot
.46194 .49114 Mdot
.48668 .44105 Mdot
.50192 .49613 Mdot
.53398 .47362 Mdot
.44837 .47065 Mdot
.51177 .55718 Mdot
.52787 .45639 Mdot
.44936 .46731 Mdot
.49882 .55384 Mdot
.45029 .51555 Mdot
.45499 .49087 Mdot
.51714 .50691 Mdot
.47248 .50262 Mdot
.50577 .47698 Mdot
.5181 .50163 Mdot
.47647 .54919 Mdot
.51516 .48627 Mdot
.44311 .48162 Mdot
.45514 .50756 Mdot
.45516 .54509 Mdot
.47146 .46805 Mdot
.46943 .51482 Mdot
.4699 .48792 Mdot
.51156 .48595 Mdot
.47889 .49004 Mdot
.43518 .49887 Mdot
.5637 .51274 Mdot
.48181 .48499 Mdot
.46595 .46021 Mdot
.45933 .49059 Mdot
.48033 .47549 Mdot
.46541 .48072 Mdot
.44268 .51424 Mdot
.48374 .48348 Mdot
.4765 .53799 Mdot
.49246 .51259 Mdot
.50781 .53245 Mdot
.50138 .52192 Mdot
.47213 .48197 Mdot
.49981 .4982 Mdot
.46008 .526 Mdot
.54668 .4914 Mdot
.5021 .51429 Mdot
.51488 .48365 Mdot
.50954 .53062 Mdot
.45653 .46175 Mdot
.48362 .55982 Mdot
.51696 .44501 Mdot
.4576 .48522 Mdot
.54559 .51139 Mdot
.47942 .50507 Mdot
.45001 .51992 Mdot
.45189 .51482 Mdot
.55474 .46465 Mdot
.48905 .4695 Mdot
.44368 .4831 Mdot
.51556 .498 Mdot
.4646 .55307 Mdot
.51858 .51748 Mdot
.50427 .49926 Mdot
.5521 .49772 Mdot
.46118 .51408 Mdot
.54526 .51657 Mdot
.44692 .5225 Mdot
.51338 .50786 Mdot
.5502 .49009 Mdot
.52114 .4567 Mdot
.54139 .45361 Mdot
.48062 .54333 Mdot
.51212 .49939 Mdot
.48787 .477 Mdot
.48332 .5011 Mdot
.52694 .53424 Mdot
.44794 .51941 Mdot
.43695 .48952 Mdot
.4358 .52554 Mdot
.54882 .47293 Mdot
.52439 .49414 Mdot
.47315 .49155 Mdot
.45991 .49407 Mdot
.48415 .46473 Mdot
.52536 .50252 Mdot
.46198 .50261 Mdot
.52063 .50742 Mdot
.50921 .4518 Mdot
.5378 .51331 Mdot
.48157 .45224 Mdot
.54031 .51279 Mdot
.51671 .56502 Mdot
.46302 .48809 Mdot
.54095 .53984 Mdot
.48224 .49693 Mdot
.52407 .48724 Mdot
.5522 .48148 Mdot
.5453 .45296 Mdot
.4657 .5389 Mdot
.46507 .48834 Mdot
.50752 .48427 Mdot
.4848 .54185 Mdot
.51368 .54203 Mdot
.45118 .48805 Mdot
.51908 .51711 Mdot
.53188 .45956 Mdot
.52009 .51029 Mdot
.46102 .52251 Mdot
.46135 .48718 Mdot
.53927 .49594 Mdot
.46665 .46734 Mdot
.51892 .48625 Mdot
.48441 .54748 Mdot
.54713 .50467 Mdot
.48412 .49328 Mdot
.517 .49611 Mdot
.54932 .47285 Mdot
.45809 .4892 Mdot
.47906 .54606 Mdot
.44792 .47518 Mdot
.50262 .52416 Mdot
.53219 .51668 Mdot
.53742 .5126 Mdot
.4831 .48299 Mdot
.52824 .55384 Mdot
.53666 .5243 Mdot
.55097 .52224 Mdot
.46799 .48014 Mdot
.49357 .49494 Mdot
.47726 .49529 Mdot
.49866 .46856 Mdot
.47558 .51056 Mdot
.52008 .49793 Mdot
.50891 .44894 Mdot
.46499 .53994 Mdot
.4648 .48056 Mdot
.46509 .46566 Mdot
.55713 .48033 Mdot
.564 .50094 Mdot
.51651 .46688 Mdot
.53986 .44964 Mdot
.50246 .46911 Mdot
.4635 .47799 Mdot
.5129 .48076 Mdot
.52821 .52256 Mdot
.45204 .50218 Mdot
.52771 .54751 Mdot
.47149 .56268 Mdot
.56299 .48697 Mdot
.50689 .49155 Mdot
.48905 .49925 Mdot
.4467 .50468 Mdot
.51088 .5011 Mdot
.50844 .52368 Mdot
.52764 .47162 Mdot
.50693 .49124 Mdot
.49869 .50841 Mdot
.51614 .45831 Mdot
.46015 .49564 Mdot
.54222 .47891 Mdot
.52934 .49838 Mdot
.45079 .48618 Mdot
.5279 .50461 Mdot
.43118 .49983 Mdot
.46412 .5019 Mdot
.50788 .44857 Mdot
.54927 .51785 Mdot
.45652 .53397 Mdot
.48967 .55167 Mdot
.51393 .50683 Mdot
.50174 .53565 Mdot
.46425 .48193 Mdot
.49872 .48337 Mdot
.43546 .5019 Mdot
.53316 .54941 Mdot
.44068 .52985 Mdot
.52374 .54001 Mdot
.51292 .51464 Mdot
.44178 .48221 Mdot
.51705 .53402 Mdot
.49736 .48039 Mdot
.46465 .48635 Mdot
.54799 .47558 Mdot
.44228 .5315 Mdot
.47597 .46756 Mdot
.49429 .49795 Mdot
.55067 .48107 Mdot
.47825 .50547 Mdot
.49813 .51832 Mdot
.48791 .43807 Mdot
.51484 .52345 Mdot
.53857 .50926 Mdot
.51343 .49254 Mdot
.51856 .49286 Mdot
.46556 .51554 Mdot
.52637 .49177 Mdot
.51473 .54766 Mdot
.52682 .50207 Mdot
.47915 .44484 Mdot
.51725 .50805 Mdot
.54631 .47499 Mdot
.50577 .47926 Mdot
.5048 .53828 Mdot
.51973 .54707 Mdot
.51348 .46878 Mdot
.49524 .45895 Mdot
.50933 .49065 Mdot
.49802 .52885 Mdot
.52618 .52148 Mdot
.49776 .48828 Mdot
.52228 .46725 Mdot
.54796 .53803 Mdot
.46535 .54605 Mdot
.5184 .45248 Mdot
.47118 .48645 Mdot
.50248 .50079 Mdot
.50954 .56125 Mdot
.51478 .46581 Mdot
.53398 .45461 Mdot
.51882 .50303 Mdot
.50646 .53655 Mdot
.50133 .4863 Mdot
.52884 .44392 Mdot
.51711 .51231 Mdot
.52384 .49301 Mdot
.49428 .46571 Mdot
.51075 .43902 Mdot
.52872 .52352 Mdot
.5094 .50096 Mdot
.488 .43514 Mdot
.47602 .48691 Mdot
.52539 .55471 Mdot
.52679 .45349 Mdot
.54474 .46873 Mdot
.44219 .52337 Mdot
.49243 .54632 Mdot
.54446 .49338 Mdot
.51862 .50486 Mdot
.46885 .4705 Mdot
.46242 .5403 Mdot
.54012 .52323 Mdot
.54172 .52648 Mdot
.53434 .48793 Mdot
.46909 .55389 Mdot
.45055 .48374 Mdot
.51118 .49434 Mdot
.44455 .48133 Mdot
.53233 .519 Mdot
.52315 .50827 Mdot
.45841 .49525 Mdot
.52939 .46805 Mdot
.45831 .47927 Mdot
.51521 .56192 Mdot
.55567 .47465 Mdot
.5026 .46056 Mdot
.51201 .50549 Mdot
.46503 .45954 Mdot
.49101 .49353 Mdot
.48514 .49393 Mdot
.54298 .49848 Mdot
.55389 .49021 Mdot
.52667 .49305 Mdot
.46889 .48768 Mdot
.5178 .45615 Mdot
.51285 .47064 Mdot
.47964 .55218 Mdot
.43705 .50322 Mdot
.49223 .45494 Mdot
.49257 .5676 Mdot
.45663 .47962 Mdot
.53144 .55633 Mdot
.51112 .5042 Mdot
.48994 .48631 Mdot
.44574 .4809 Mdot
.44119 .48542 Mdot
.50462 .5191 Mdot
.51178 .53837 Mdot
.47983 .53567 Mdot
.5254 .54065 Mdot
.55169 .51793 Mdot
.48104 .55015 Mdot
.52099 .49512 Mdot
.4558 .4758 Mdot
.48398 .50882 Mdot
.46387 .53758 Mdot
.49877 .52743 Mdot
.48971 .55695 Mdot
.47215 .49617 Mdot
.46368 .48961 Mdot
.46757 .47096 Mdot
.52866 .46195 Mdot
.55919 .50294 Mdot
.56136 .4873 Mdot
.44545 .48578 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go
00001_ooool3o`000?ooooooB?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04
odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol0003o
oooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`3o
ooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007
ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<
ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`2Mooooo`?o0000Yoooool001kooooo00?o0000ooooooooool0VOooool7o`000004
ooooool0003o0000ooooo`;o0000XOooool001kooooo00?o0000ooooooooool0VOooool=o`000:7o
oooo000Nooooo`03o`000?oooooooooo09Kooooo0_l00002ooooo`co00000_ooool2o`0009gooooo
000Nooooo`03o`000?oooooooooo09Kooooo2Ol000001?oooooo0000o`000?ooool7o`0009gooooo
000Nooooo`03o`000?oooooooooo09Sooooo4?l00003ooooo`;o0000V_ooool001kooooo0_l0002C
ooooo`;o00001?ooool5o`000003ooooool0003o000000oo0000V?ooool001kooooo00?o0000oooo
ooooool0T_ooool2o`0000?ooooo0ol000000ooooooo0000o`000003o`000004ooooool0003o0000
ooooo`_o0000V?ooool001kooooo00?o0000ooooooooool0Toooool3o`000003ooooool0003o0000
00Oo000000Coooooo`000?l0003ooooo2ol0002Hooooo`007_ooool00ol0003oooooooooo`2@oooo
o`;o000000Goooooo`000?l0003o0000ooooo`0:o`0000;ooooo3?l0002Hooooo`007_ooool00ol0
003oooooooooo`2@oooooa7o00000_ooool8o`000003ooooool0003o000000;ooooo0_l0002Eoooo
o`007_ooool00ol0003oooooooooo`2>ooooo`go000000?oooooo`000?l000000_l000000ooooooo
0000o`00000<o`000004ooooool0003o0000o`0009Cooooo000Nooooo`03o`000?oooooooooo08ko
oooo9Ol0002Dooooo`007_ooool00ol0003oooooooooo`2>ooooo`Co000000?oooooo`000?l00000
7_l0002Dooooo`007_ooool00ol0003oooooooooo`2=oooooaKo000000?oooooo`000?l000003Ol0
002Dooooo`007_ooool00ol0003oooooooooo`2=ooooobKo0000U?ooool001kooooo00?o0000oooo
ooooool0S?oooolIo`0000?ooooo1_l000000ooooooo0000o`000003o`0009?ooooo000Nooooo`03
o`000?oooooooooo08_ooooo:_l0002Booooo`007_ooool00ol0003oooooooooo`2:oooooaoo0000
00?oooooo`000?l000002Ol0002Booooo`007_ooool00ol0003oooooooooo`29ooooob_o0000Tooo
ool001kooooo00?o0000ooooooooool0ROoooolZo`0009Cooooo000Nooooo`03o`000?oooooooooo
08Wooooo;?l0002Booooo`007_ooool2o`0008Wooooo;Ol0002Booooo`007_ooool00ol0003ooooo
ooooo`28ooooo`Wo000000?oooooo`000?l000005ol00003ooooo`So0000TOooool001kooooo00?o
0000ooooooooool0R?oooolSo`0000?ooooo2?l0002Aooooo`007_ooool00ol0003oooooooooo`28
ooooo`Oo000000Coooooo`000?l0003ooooo2Ol000000ooooooo0000o`00000@o`000003ooooool0
003o000000?o0000T_ooool001kooooo00?o0000ooooooooool0R?ooool2o`0000;ooooo1Ol00000
0ooooooo0000o`00000Ko`000003ooooool0003o000000?o0000T_ooool001kooooo00?o0000oooo
ooooool0S?ooool5o`000003ooooool0003o000000?o000000?oooooo`000?l000006ol0002Boooo
o`007_ooool00ol0003oooooooooo`29ooooo`;o00000_ooool4o`0000;ooooo0_l00002ooooo`Ko
000000?oooooo`000?l000005Ol0002Booooo`007_ooool00ol0003oooooooooo`29ooooo`;o0000
00?oooooo`000?l000000_l00002ooooo`_o000000?oooooo`000?l000005?l0002Cooooo`007_oo
ool00ol0003oooooooooo`29ooooo`Oo000000?oooooo`000?l000001Ol00002oooooaOo000000?o
ooooo`000?l00000Toooool001kooooo00?o0000ooooooooool0R_ooool3o`000004ooooool0003o
0000ooooo`Oo00001?ooool<o`000003ooooool0003o000000Ko000000?oooooo`000?l00000Tooo
ool001kooooo00?o0000ooooooooool0Roooool3o`0000;ooooo0_l000000ooooooo0000o`000003
o`0000;ooooo3ol00002ooooo`Ko0000U_ooool001kooooo00?o0000ooooooooool0S?ooool:o`00
00;ooooo1?l00003ooooo`_o000000Coooooo`000?l0003o00000_ooool2o`0009Gooooo000Noooo
o`03o`000?oooooooooo08cooooo4?l000000ooooooo0000o`00000;o`0000Cooooo1?l0002Eoooo
o`007_ooool00ol0003oooooooooo`2<ooooo`?o00000_oooolHo`0000?ooooo1Ol0002Fooooo`00
7_ooool00ol0003oooooooooo`2=ooooo`;o000000?oooooo`000?l000000ol00002ooooo`_o0000
00?oooooo`000?l000001_l000001?oooooo0000o`000?ooool2o`0009Kooooo000Nooooo`03o`00
0?oooooooooo08gooooo2_l000001Ooooooo0000o`000?l0003ooooo00oo000000?oooooo`000?l0
0000VOooool001kooooo0_l0002>ooooo`Co000000?oooooo`000?l000002ol000000ooooooo0000
o`000009o`000003ooooool0003o000009Wooooo000Nooooo`03o`000?oooooooooo097ooooo6_l0
002Looooo`007_ooool00ol0003oooooooooo`2Aooooo`Wo000000Coooooo`000?l0003ooooo3Ol0
002Looooo`007_ooool00ol0003oooooooooo`2Aooooo`;o000000?oooooo`000?l000000_ooool5
o`000004ooooool0003o0000ooooo`?o000000?oooooo`000?l000001?l0002Looooo`007_ooool0
0ol0003oooooooooo`2Dooooo`So00000_ooool:o`0009oooooo000Nooooo`03o`000?oooooooooo
09Gooooo4ol0002Oooooo`007_ooool00ol0003oooooooooo`2Looooo`Co00001?ooool2o`000:7o
oooo000Nooooo`03o`000?oooooooooo09cooooo0ol0002Xooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0
1_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool000001_ooool3o`000?ooooooB?ooool000?ooooo00Go0000ooooooooooooooooo`00000;oooo
o`05o`000?nHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`3oooooodSooooo0003oooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o
0000ooooooooool0oooooom8ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00?o
EEEEohN7Qoooool02?ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo0?ooooooB?oo
ool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodSooooo0003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RH
ob4Q8@06ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooo
oa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool000?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool00ol0
003oooooooooo`3oooooodSooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Oo<
c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol@
413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj
^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`00
0?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`005?ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom8
ooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB?ooool001Ko
oooo00?o0000ooooooooool01Oooool3o`000?ooooooB?ooool001Kooooo00?o0000ooooooooool0
oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooo
oooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005?ooool00omEEEGo
IVIVo`00003ooooooe;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.45087 .50188 Mdot
.50923 .52867 Mdot
.53155 .54005 Mdot
.50244 .52793 Mdot
.48332 .52448 Mdot
.45327 .47298 Mdot
.52838 .55024 Mdot
.46939 .52507 Mdot
.54264 .46584 Mdot
.48054 .4629 Mdot
.46333 .49142 Mdot
.5095 .4951 Mdot
.45012 .47308 Mdot
.48492 .54723 Mdot
.55557 .50105 Mdot
.48628 .46325 Mdot
.48296 .53735 Mdot
.47715 .45074 Mdot
.47848 .45917 Mdot
.52782 .49057 Mdot
.47471 .53628 Mdot
.50967 .4575 Mdot
.47217 .50842 Mdot
.44529 .50965 Mdot
.46421 .5236 Mdot
.5022 .489 Mdot
.54894 .49132 Mdot
.47615 .458 Mdot
.49161 .52163 Mdot
.44759 .48376 Mdot
.51982 .54068 Mdot
.49179 .5341 Mdot
.49019 .49679 Mdot
.5411 .51631 Mdot
.44853 .47775 Mdot
.53529 .53207 Mdot
.49924 .48459 Mdot
.54041 .47684 Mdot
.47576 .51655 Mdot
.51143 .48842 Mdot
.48834 .47791 Mdot
.52426 .47986 Mdot
.52534 .52916 Mdot
.49867 .5044 Mdot
.48455 .53517 Mdot
.49547 .46721 Mdot
.48821 .54938 Mdot
.51519 .54387 Mdot
.52977 .53333 Mdot
.52518 .448 Mdot
.47994 .51953 Mdot
.44904 .46406 Mdot
.4953 .52133 Mdot
.4751 .52259 Mdot
.48494 .45645 Mdot
.50581 .47358 Mdot
.52482 .50774 Mdot
.44434 .46534 Mdot
.48575 .53253 Mdot
.52706 .51063 Mdot
.5012 .4582 Mdot
.49682 .47592 Mdot
.53713 .50666 Mdot
.48628 .46635 Mdot
.48143 .51366 Mdot
.54317 .46229 Mdot
.50002 .54182 Mdot
.50027 .46536 Mdot
.51707 .48077 Mdot
.48647 .45899 Mdot
.54734 .53027 Mdot
.48837 .52948 Mdot
.52591 .5018 Mdot
.50637 .51438 Mdot
.44446 .49359 Mdot
.54903 .50588 Mdot
.51216 .47148 Mdot
.47328 .45334 Mdot
.54411 .53624 Mdot
.47251 .48765 Mdot
.53771 .48041 Mdot
.46673 .52216 Mdot
.46892 .531 Mdot
.49093 .47591 Mdot
.53872 .50988 Mdot
.50209 .51737 Mdot
.54524 .51677 Mdot
.5 .47053 Mdot
.51436 .49014 Mdot
.46475 .45559 Mdot
.48856 .51686 Mdot
.4922 .46287 Mdot
.54303 .49586 Mdot
.5374 .45598 Mdot
.53247 .54458 Mdot
.50684 .4598 Mdot
.50229 .47034 Mdot
.51385 .54277 Mdot
.49022 .54986 Mdot
.52399 .51356 Mdot
.54557 .51185 Mdot
.54163 .49818 Mdot
.47982 .53016 Mdot
.51573 .44759 Mdot
.54725 .47343 Mdot
.49148 .49332 Mdot
.47939 .55619 Mdot
.48382 .51633 Mdot
.50996 .53866 Mdot
.49182 .46146 Mdot
.44891 .5142 Mdot
.48963 .52971 Mdot
.51541 .51052 Mdot
.53338 .46283 Mdot
.48211 .54238 Mdot
.45294 .46091 Mdot
.54656 .48335 Mdot
.48039 .45202 Mdot
.52207 .54505 Mdot
.5429 .49267 Mdot
.46613 .47662 Mdot
.50124 .49353 Mdot
.48139 .46024 Mdot
.52522 .53704 Mdot
.49622 .53551 Mdot
.52324 .45716 Mdot
.446 .50651 Mdot
.50097 .49183 Mdot
.49813 .49927 Mdot
.48547 .47502 Mdot
.46882 .48372 Mdot
.47985 .53919 Mdot
.43769 .49995 Mdot
.53762 .52303 Mdot
.46547 .50872 Mdot
.44072 .51363 Mdot
.50457 .4504 Mdot
.4938 .51091 Mdot
.52167 .49154 Mdot
.50958 .50612 Mdot
.48567 .51692 Mdot
.54619 .47435 Mdot
.49476 .49659 Mdot
.49888 .52676 Mdot
.485 .50079 Mdot
.49305 .45933 Mdot
.44952 .49607 Mdot
.51232 .46375 Mdot
.48062 .54274 Mdot
.52813 .53373 Mdot
.53787 .51332 Mdot
.47615 .45691 Mdot
.4864 .52072 Mdot
.47999 .54528 Mdot
.46667 .48636 Mdot
.48626 .46219 Mdot
.49535 .47855 Mdot
.4404 .49001 Mdot
.51252 .47219 Mdot
.48409 .50739 Mdot
.5514 .51516 Mdot
.51773 .47594 Mdot
.46624 .46797 Mdot
.49038 .45254 Mdot
.51942 .49671 Mdot
.51908 .5053 Mdot
.55005 .48013 Mdot
.53032 .4727 Mdot
.51761 .46565 Mdot
.5353 .46876 Mdot
.47427 .47672 Mdot
.5284 .53214 Mdot
.51462 .52789 Mdot
.5195 .49519 Mdot
.55034 .52576 Mdot
.50206 .47754 Mdot
.50609 .45804 Mdot
.48272 .50853 Mdot
.46132 .54437 Mdot
.53548 .52342 Mdot
.50308 .52617 Mdot
.50382 .45756 Mdot
.50194 .51161 Mdot
.49486 .52227 Mdot
.45159 .46769 Mdot
.51033 .49838 Mdot
.54169 .5267 Mdot
.50221 .45789 Mdot
.53523 .45536 Mdot
.54559 .49901 Mdot
.50449 .50431 Mdot
.48261 .49133 Mdot
.44879 .51924 Mdot
.48544 .51918 Mdot
.53741 .47221 Mdot
.48835 .48439 Mdot
.52978 .44973 Mdot
.49332 .49968 Mdot
.4798 .50895 Mdot
.50874 .52495 Mdot
.52246 .51764 Mdot
.50298 .46314 Mdot
.46782 .47841 Mdot
.52531 .4717 Mdot
.4837 .46391 Mdot
.51729 .52674 Mdot
.46921 .53526 Mdot
.52593 .51604 Mdot
.54058 .52552 Mdot
.48424 .52007 Mdot
.48301 .53553 Mdot
.49775 .48907 Mdot
.51491 .48487 Mdot
.46104 .4755 Mdot
.50154 .49353 Mdot
.48154 .54874 Mdot
.49404 .46244 Mdot
.51244 .47432 Mdot
.54548 .47328 Mdot
.48458 .51368 Mdot
.4781 .49744 Mdot
.44046 .47533 Mdot
.4931 .4602 Mdot
.45366 .53504 Mdot
.46334 .49964 Mdot
.46363 .51403 Mdot
.49355 .53225 Mdot
.48215 .45592 Mdot
.53972 .52958 Mdot
.47112 .493 Mdot
.49646 .45153 Mdot
.49725 .49118 Mdot
.53946 .46851 Mdot
.49561 .48304 Mdot
.50366 .48179 Mdot
.52279 .49282 Mdot
.53049 .4617 Mdot
.5487 .5117 Mdot
.50101 .53695 Mdot
.51036 .49827 Mdot
.48173 .4565 Mdot
.55447 .50128 Mdot
.44773 .50043 Mdot
.52706 .45958 Mdot
.52331 .54836 Mdot
.48619 .45532 Mdot
.54986 .50521 Mdot
.46647 .51905 Mdot
.49135 .45189 Mdot
.54836 .48488 Mdot
.52623 .5267 Mdot
.45306 .46433 Mdot
.55323 .49532 Mdot
.52852 .5468 Mdot
.51287 .51088 Mdot
.51515 .49791 Mdot
.47426 .49941 Mdot
.51176 .47909 Mdot
.53966 .51103 Mdot
.55138 .48766 Mdot
.53075 .47435 Mdot
.48609 .48677 Mdot
.48421 .50691 Mdot
.46431 .48061 Mdot
.53199 .49893 Mdot
.53514 .50058 Mdot
.47089 .49589 Mdot
.47117 .46997 Mdot
.48866 .48782 Mdot
.45665 .54153 Mdot
.51017 .53958 Mdot
.51555 .51017 Mdot
.53742 .45715 Mdot
.51273 .5071 Mdot
.53743 .53491 Mdot
.54994 .51355 Mdot
.50766 .47029 Mdot
.47822 .46456 Mdot
.52564 .48889 Mdot
.48033 .47986 Mdot
.5196 .48677 Mdot
.50605 .48389 Mdot
.50193 .54811 Mdot
.48883 .50443 Mdot
.54229 .47536 Mdot
.53482 .4535 Mdot
.47032 .5489 Mdot
.47476 .50107 Mdot
.50547 .53466 Mdot
.47543 .54469 Mdot
.51688 .4962 Mdot
.48229 .54402 Mdot
.4554 .45824 Mdot
.52792 .52844 Mdot
.51912 .50564 Mdot
.47476 .525 Mdot
.47349 .46669 Mdot
.53611 .51807 Mdot
.52667 .48044 Mdot
.50032 .52877 Mdot
.49474 .50509 Mdot
.46322 .5127 Mdot
.54775 .4717 Mdot
.49127 .4546 Mdot
.51327 .49512 Mdot
.50072 .52822 Mdot
.44284 .52717 Mdot
.45654 .53142 Mdot
.46248 .52199 Mdot
.53252 .50213 Mdot
.50724 .52114 Mdot
.48896 .50248 Mdot
.47496 .4934 Mdot
.45499 .50546 Mdot
.51255 .52243 Mdot
.4729 .54147 Mdot
.51096 .48741 Mdot
.5 .4673 Mdot
.52424 .49788 Mdot
.53722 .47352 Mdot
.53356 .52608 Mdot
.46099 .49112 Mdot
.45993 .48884 Mdot
.50343 .47562 Mdot
.4748 .47196 Mdot
.52699 .46278 Mdot
.50213 .50418 Mdot
.49889 .49854 Mdot
.53053 .45777 Mdot
.53709 .48845 Mdot
.44845 .49412 Mdot
.44936 .46695 Mdot
.51627 .50993 Mdot
.47994 .46444 Mdot
.53963 .52624 Mdot
.47972 .48962 Mdot
.53765 .51458 Mdot
.49471 .52925 Mdot
.45859 .49576 Mdot
.49797 .47494 Mdot
.50238 .54196 Mdot
.46445 .53686 Mdot
.50106 .55545 Mdot
.49345 .49691 Mdot
.51869 .46129 Mdot
.48701 .54174 Mdot
.4893 .50554 Mdot
.47338 .52717 Mdot
.53165 .47453 Mdot
.49084 .47547 Mdot
.52202 .50218 Mdot
.43763 .49533 Mdot
.47963 .53672 Mdot
.49764 .48244 Mdot
.45869 .46151 Mdot
.51989 .50286 Mdot
.4668 .54488 Mdot
.48961 .53944 Mdot
.45919 .45558 Mdot
.49061 .49367 Mdot
.48015 .51155 Mdot
.4713 .54146 Mdot
.51748 .50599 Mdot
.46558 .54261 Mdot
.49006 .54016 Mdot
.50448 .54854 Mdot
.51303 .55021 Mdot
.52849 .47029 Mdot
.45821 .54459 Mdot
.501 .51669 Mdot
.48395 .508 Mdot
.49156 .51247 Mdot
.439 .48489 Mdot
.46606 .49553 Mdot
.52647 .54269 Mdot
.48224 .46389 Mdot
.4688 .49491 Mdot
.5469 .51383 Mdot
.52411 .48214 Mdot
.49949 .48758 Mdot
.53599 .51162 Mdot
.53597 .54347 Mdot
.49264 .52713 Mdot
.44597 .51977 Mdot
.49111 .53253 Mdot
.45507 .47781 Mdot
.4762 .45741 Mdot
.47806 .49238 Mdot
.5064 .47703 Mdot
.53574 .51256 Mdot
.44036 .51837 Mdot
.52238 .48308 Mdot
.53487 .52304 Mdot
.49072 .53425 Mdot
.47447 .50632 Mdot
.47222 .52945 Mdot
.49484 .45305 Mdot
.4889 .49969 Mdot
.47464 .4699 Mdot
.44327 .52376 Mdot
.44708 .5327 Mdot
.53749 .51845 Mdot
.43562 .50522 Mdot
.5064 .48478 Mdot
.53463 .5188 Mdot
.53425 .53182 Mdot
.49551 .52352 Mdot
.48423 .51117 Mdot
.52396 .5212 Mdot
.47427 .48363 Mdot
.50887 .50378 Mdot
.47763 .47384 Mdot
.50478 .51438 Mdot
.51773 .54297 Mdot
.50022 .51477 Mdot
.5429 .50009 Mdot
.49055 .45945 Mdot
.45245 .52776 Mdot
.52987 .52156 Mdot
.48227 .45689 Mdot
.47866 .48251 Mdot
.49655 .4658 Mdot
.50257 .51098 Mdot
.4791 .46944 Mdot
.43694 .47924 Mdot
.53859 .52244 Mdot
.55542 .49264 Mdot
.48967 .48426 Mdot
.52265 .48972 Mdot
.51361 .48411 Mdot
.46837 .54212 Mdot
.48662 .45895 Mdot
.46691 .53467 Mdot
.47757 .48381 Mdot
.52062 .46656 Mdot
.4478 .51867 Mdot
.51783 .46489 Mdot
.52507 .50718 Mdot
.46307 .53837 Mdot
.52004 .49636 Mdot
.52673 .53176 Mdot
.46667 .45076 Mdot
.47926 .54453 Mdot
.46439 .48215 Mdot
.49122 .49307 Mdot
.47111 .47871 Mdot
.48699 .52683 Mdot
.48411 .4665 Mdot
.54111 .51987 Mdot
.48938 .51857 Mdot
.50415 .55 Mdot
.5108 .50097 Mdot
.4892 .47564 Mdot
.51817 .49285 Mdot
.53858 .49866 Mdot
.53828 .46377 Mdot
.53748 .51293 Mdot
.53864 .47632 Mdot
.48668 .51043 Mdot
.51277 .48171 Mdot
.52642 .4757 Mdot
.50928 .5152 Mdot
.51513 .54488 Mdot
.49517 .4848 Mdot
.53301 .52443 Mdot
.4519 .53547 Mdot
.49222 .48384 Mdot
.5041 .50917 Mdot
.49129 .54386 Mdot
.513 .47915 Mdot
.4562 .49123 Mdot
.48176 .4844 Mdot
.50987 .55808 Mdot
.55743 .51144 Mdot
.47576 .47188 Mdot
.54174 .46611 Mdot
.5261 .5386 Mdot
.55803 .51205 Mdot
.54597 .51259 Mdot
.44005 .50736 Mdot
.48987 .50121 Mdot
.47971 .53652 Mdot
.46604 .51999 Mdot
.4798 .53244 Mdot
.49713 .46398 Mdot
.52497 .47388 Mdot
.47976 .46884 Mdot
.45014 .50148 Mdot
.53061 .52941 Mdot
.54706 .51309 Mdot
.45772 .45409 Mdot
.54039 .52729 Mdot
.53626 .45915 Mdot
.48095 .50949 Mdot
.5269 .52157 Mdot
.45774 .46082 Mdot
.54414 .47407 Mdot
.48112 .50716 Mdot
.52419 .47566 Mdot
.46148 .51407 Mdot
.48644 .5554 Mdot
.55408 .4945 Mdot
.51348 .55589 Mdot
.48031 .49116 Mdot
.51123 .49899 Mdot
.48519 .45175 Mdot
.45673 .52158 Mdot
.48235 .4766 Mdot
.54455 .52763 Mdot
.53018 .45066 Mdot
.52223 .48317 Mdot
.53862 .51173 Mdot
.5246 .52763 Mdot
.45559 .46744 Mdot
.46213 .51218 Mdot
.48731 .46062 Mdot
.52566 .52628 Mdot
.44921 .47706 Mdot
.50264 .54965 Mdot
.45539 .50124 Mdot
.49072 .45181 Mdot
.50535 .54062 Mdot
.45795 .51065 Mdot
.50199 .48646 Mdot
.51719 .50097 Mdot
.50314 .47093 Mdot
.53594 .52514 Mdot
.45096 .46064 Mdot
.47229 .48086 Mdot
.47658 .47465 Mdot
.53261 .4889 Mdot
.49317 .4591 Mdot
.50782 .47146 Mdot
.50995 .51454 Mdot
.53347 .45471 Mdot
.50665 .49698 Mdot
.44227 .50514 Mdot
.49944 .46426 Mdot
.52603 .51288 Mdot
.48031 .45524 Mdot
.51348 .50991 Mdot
.46738 .46196 Mdot
.49174 .45766 Mdot
.44456 .5131 Mdot
.46988 .48557 Mdot
.55029 .49677 Mdot
.49508 .52618 Mdot
.46954 .45415 Mdot
.48527 .52984 Mdot
.47564 .48841 Mdot
.51392 .49063 Mdot
.4693 .51585 Mdot
.48724 .49949 Mdot
.47798 .55359 Mdot
.49174 .53074 Mdot
.4795 .49678 Mdot
.48769 .51398 Mdot
.53278 .51496 Mdot
.45783 .45483 Mdot
.54526 .48816 Mdot
.53986 .49336 Mdot
.54217 .51424 Mdot
.4832 .46621 Mdot
.49729 .51844 Mdot
.52807 .48707 Mdot
.47426 .49897 Mdot
.52567 .55185 Mdot
.48016 .4822 Mdot
.44443 .51531 Mdot
.52677 .53736 Mdot
.45629 .54117 Mdot
.49922 .4909 Mdot
.53179 .51962 Mdot
.47882 .5292 Mdot
.50972 .50027 Mdot
.48799 .46996 Mdot
.46782 .45451 Mdot
.51322 .48989 Mdot
.54806 .51097 Mdot
.50591 .49202 Mdot
.54055 .53214 Mdot
.48857 .52888 Mdot
.49916 .55612 Mdot
.52241 .52205 Mdot
.51622 .47511 Mdot
.47826 .54941 Mdot
.46547 .51232 Mdot
.49994 .54046 Mdot
.47231 .53967 Mdot
.53634 .50189 Mdot
.51159 .4977 Mdot
.49364 .47089 Mdot
.47906 .50722 Mdot
.50338 .50108 Mdot
.4842 .47007 Mdot
.44819 .49572 Mdot
.44877 .52258 Mdot
.50408 .45683 Mdot
.46644 .46811 Mdot
.51347 .52655 Mdot
.52567 .46964 Mdot
.4969 .45281 Mdot
.45326 .49763 Mdot
.46034 .46611 Mdot
.49313 .47028 Mdot
.51495 .53749 Mdot
.48421 .48371 Mdot
.51227 .54917 Mdot
.49707 .47663 Mdot
.50022 .49856 Mdot
.48112 .45118 Mdot
.45059 .5136 Mdot
.47242 .50146 Mdot
.48418 .54943 Mdot
.4496 .50229 Mdot
.48777 .52281 Mdot
.47651 .51265 Mdot
.48508 .4551 Mdot
.48178 .51393 Mdot
.55256 .51739 Mdot
.53148 .5489 Mdot
.44856 .46311 Mdot
.51356 .51431 Mdot
.49564 .47861 Mdot
.51571 .55027 Mdot
.53482 .50884 Mdot
.48755 .5196 Mdot
.4888 .51183 Mdot
.44185 .51768 Mdot
.50738 .53347 Mdot
.50034 .46063 Mdot
.48506 .46243 Mdot
.52742 .53523 Mdot
.46925 .45695 Mdot
.46741 .45982 Mdot
.45995 .49515 Mdot
.54777 .50559 Mdot
.50551 .50759 Mdot
.4831 .5315 Mdot
.47011 .54885 Mdot
.46979 .52296 Mdot
.51057 .47071 Mdot
.51015 .55056 Mdot
.49008 .48568 Mdot
.48477 .47623 Mdot
.46101 .47158 Mdot
.45919 .46321 Mdot
.49275 .48902 Mdot
.52769 .54931 Mdot
.53865 .54294 Mdot
.45745 .50703 Mdot
.48647 .50108 Mdot
.49465 .4921 Mdot
.51037 .53847 Mdot
.51927 .51203 Mdot
.52693 .52685 Mdot
.54868 .46837 Mdot
.50474 .50611 Mdot
.53096 .48934 Mdot
.50368 .49979 Mdot
.48477 .53024 Mdot
.48704 .49731 Mdot
.46409 .54162 Mdot
.44232 .46671 Mdot
.48977 .55384 Mdot
.53802 .51291 Mdot
.52727 .46625 Mdot
.43878 .51968 Mdot
.44846 .50892 Mdot
.55808 .49158 Mdot
.50775 .5318 Mdot
.43805 .47885 Mdot
.44598 .53166 Mdot
.49893 .45288 Mdot
.48529 .48152 Mdot
.49004 .45112 Mdot
.52674 .49859 Mdot
.48481 .53476 Mdot
.47475 .45994 Mdot
.47329 .52427 Mdot
.50109 .45677 Mdot
.5396 .49201 Mdot
.51319 .53414 Mdot
.54033 .48761 Mdot
.48631 .5363 Mdot
.50454 .46253 Mdot
.49977 .535 Mdot
.45298 .46551 Mdot
.5186 .49132 Mdot
.52722 .49452 Mdot
.51143 .46561 Mdot
.53412 .53457 Mdot
.44667 .46651 Mdot
.50481 .47947 Mdot
.53495 .51593 Mdot
.46083 .52573 Mdot
.4808 .55497 Mdot
.49549 .50314 Mdot
.49097 .46219 Mdot
.49803 .52917 Mdot
.46776 .50877 Mdot
.50638 .49601 Mdot
.50232 .54728 Mdot
.48153 .51417 Mdot
.51789 .54754 Mdot
.5419 .54058 Mdot
.50215 .47234 Mdot
.48177 .52053 Mdot
.53906 .50633 Mdot
.47899 .46963 Mdot
.52741 .45426 Mdot
.50137 .49965 Mdot
.54228 .5099 Mdot
.48863 .45003 Mdot
.47182 .54442 Mdot
.54873 .49181 Mdot
.49096 .44954 Mdot
.46462 .53276 Mdot
.45332 .47658 Mdot
.47345 .46344 Mdot
.50254 .51926 Mdot
.47509 .48137 Mdot
.52441 .493 Mdot
.50811 .5169 Mdot
.45341 .51794 Mdot
.52208 .50492 Mdot
.47243 .45044 Mdot
.46077 .4741 Mdot
.44231 .50548 Mdot
.50937 .464 Mdot
.46594 .48674 Mdot
.48986 .47365 Mdot
.52056 .50161 Mdot
.49317 .48095 Mdot
.45301 .45861 Mdot
.53533 .5464 Mdot
.50248 .48059 Mdot
.50735 .45762 Mdot
.47742 .46718 Mdot
.51111 .47561 Mdot
.49464 .46586 Mdot
.44834 .47236 Mdot
.50572 .48124 Mdot
.45936 .50786 Mdot
.48118 .49923 Mdot
.47885 .52301 Mdot
.48132 .51021 Mdot
.49978 .47211 Mdot
.49734 .49878 Mdot
.45424 .48901 Mdot
.53439 .52872 Mdot
.48635 .50799 Mdot
.5242 .5031 Mdot
.48084 .52326 Mdot
.49875 .45167 Mdot
.45271 .53205 Mdot
.54675 .4755 Mdot
.48189 .46219 Mdot
.51957 .54038 Mdot
.47761 .48672 Mdot
.45087 .47974 Mdot
.45465 .47688 Mdot
.55956 .50857 Mdot
.52036 .47786 Mdot
.47113 .45132 Mdot
.51034 .51261 Mdot
.4441 .51702 Mdot
.49546 .52564 Mdot
.50012 .50326 Mdot
.53291 .53439 Mdot
.46072 .4818 Mdot
.51591 .54238 Mdot
.44721 .48093 Mdot
.49916 .51635 Mdot
.53728 .52926 Mdot
.54427 .48861 Mdot
.55719 .49476 Mdot
.45878 .51448 Mdot
.50648 .51034 Mdot
.51467 .48146 Mdot
.48333 .48773 Mdot
.4906 .54168 Mdot
.44954 .47861 Mdot
.46105 .45288 Mdot
.43709 .48142 Mdot
.54974 .51542 Mdot
.51899 .51754 Mdot
.48706 .47788 Mdot
.47403 .46977 Mdot
.52002 .4714 Mdot
.51134 .52314 Mdot
.46788 .47521 Mdot
.50438 .52238 Mdot
.53996 .47768 Mdot
.51221 .53741 Mdot
.52184 .46159 Mdot
.51448 .53857 Mdot
.47512 .55466 Mdot
.48367 .46845 Mdot
.50093 .55272 Mdot
.48689 .4856 Mdot
.52539 .5128 Mdot
.5456 .52356 Mdot
.55964 .49533 Mdot
.45144 .5037 Mdot
.48516 .47022 Mdot
.51937 .49771 Mdot
.46175 .51498 Mdot
.47752 .53556 Mdot
.47291 .45852 Mdot
.49603 .52594 Mdot
.55003 .4962 Mdot
.5018 .52342 Mdot
.45655 .48689 Mdot
.48327 .46653 Mdot
.52639 .52796 Mdot
.50562 .46002 Mdot
.52373 .50806 Mdot
.45875 .51982 Mdot
.52467 .5371 Mdot
.49238 .48552 Mdot
.51307 .51268 Mdot
.55001 .51548 Mdot
.4779 .46516 Mdot
.4565 .51625 Mdot
.4849 .45098 Mdot
.48073 .51212 Mdot
.50574 .53572 Mdot
.51246 .53674 Mdot
.50608 .48062 Mdot
.48593 .5532 Mdot
.50409 .54187 Mdot
.51684 .54722 Mdot
.49778 .46771 Mdot
.49646 .49247 Mdot
.48532 .48185 Mdot
.52604 .48289 Mdot
.47226 .48716 Mdot
.51285 .51635 Mdot
.54074 .47501 Mdot
.45042 .50434 Mdot
.49417 .46527 Mdot
.50491 .45856 Mdot
.54992 .52348 Mdot
.54207 .53867 Mdot
.53664 .49407 Mdot
.55812 .49032 Mdot
.52773 .48559 Mdot
.49537 .46273 Mdot
.52543 .49995 Mdot
.4984 .53617 Mdot
.4625 .46836 Mdot
.48642 .54878 Mdot
.44484 .53024 Mdot
.55036 .52918 Mdot
.51086 .50118 Mdot
.48886 .49099 Mdot
.4572 .46687 Mdot
.50373 .51018 Mdot
.48446 .51781 Mdot
.5401 .50493 Mdot
.51125 .50104 Mdot
.48821 .50255 Mdot
.54083 .48708 Mdot
.47258 .47071 Mdot
.54281 .51826 Mdot
.51791 .52357 Mdot
.47448 .45725 Mdot
.51155 .52602 Mdot
.44958 .45879 Mdot
.46971 .47595 Mdot
.54019 .47407 Mdot
.51814 .54451 Mdot
.44813 .49494 Mdot
.45961 .52609 Mdot
.50051 .51627 Mdot
.47379 .51991 Mdot
.49225 .46558 Mdot
.51423 .49115 Mdot
.45101 .46082 Mdot
.4912 .55337 Mdot
.43866 .48686 Mdot
.48507 .54272 Mdot
.49351 .51893 Mdot
.47099 .45023 Mdot
.48361 .53319 Mdot
.51656 .489 Mdot
.48742 .46863 Mdot
.5475 .51768 Mdot
.43913 .48887 Mdot
.51339 .46768 Mdot
.49339 .49421 Mdot
.54487 .52285 Mdot
.47667 .48613 Mdot
.4814 .50607 Mdot
.52867 .45199 Mdot
.48884 .52442 Mdot
.51571 .53553 Mdot
.51479 .50729 Mdot
.51727 .51205 Mdot
.46289 .48511 Mdot
.52252 .51739 Mdot
.47594 .53952 Mdot
.51282 .52391 Mdot
.52083 .45393 Mdot
.50162 .51998 Mdot
.54722 .51673 Mdot
.52278 .4942 Mdot
.47418 .52454 Mdot
.47974 .54326 Mdot
.53368 .49313 Mdot
.52849 .47387 Mdot
.5138 .5026 Mdot
.47536 .51186 Mdot
.49759 .53413 Mdot
.50789 .49246 Mdot
.53978 .4982 Mdot
.50774 .55491 Mdot
.44759 .51029 Mdot
.54458 .48361 Mdot
.49316 .47377 Mdot
.49709 .50235 Mdot
.46979 .54674 Mdot
.53626 .49205 Mdot
.55343 .49281 Mdot
.50719 .51835 Mdot
.47596 .52477 Mdot
.51276 .4942 Mdot
.55386 .48018 Mdot
.49823 .52192 Mdot
.51984 .51638 Mdot
.52495 .47815 Mdot
.54446 .46608 Mdot
.49808 .53695 Mdot
.50268 .50876 Mdot
.52896 .44916 Mdot
.4963 .47751 Mdot
.48307 .5517 Mdot
.54927 .4889 Mdot
.55087 .51024 Mdot
.44314 .48061 Mdot
.46341 .52228 Mdot
.53163 .52901 Mdot
.50538 .51933 Mdot
.50579 .46274 Mdot
.44856 .50351 Mdot
.50756 .54305 Mdot
.50688 .54568 Mdot
.53074 .52009 Mdot
.4464 .51961 Mdot
.47714 .45602 Mdot
.51116 .50648 Mdot
.47385 .45096 Mdot
.50415 .53714 Mdot
.5053 .52466 Mdot
.47166 .46913 Mdot
.54334 .50259 Mdot
.4891 .45943 Mdot
.47403 .5509 Mdot
.55296 .51847 Mdot
.53214 .47984 Mdot
.50035 .51369 Mdot
.50669 .4567 Mdot
.49658 .49011 Mdot
.49228 .48642 Mdot
.52646 .5314 Mdot
.53999 .53059 Mdot
.52146 .51843 Mdot
.48935 .47279 Mdot
.5427 .48627 Mdot
.53215 .49396 Mdot
.45385 .5223 Mdot
.45122 .4623 Mdot
.52814 .46939 Mdot
.457 .54382 Mdot
.48715 .45837 Mdot
.48873 .55741 Mdot
.50089 .51213 Mdot
.50548 .48631 Mdot
.47565 .45157 Mdot
.4672 .45149 Mdot
.4849 .51224 Mdot
.47813 .53121 Mdot
.46242 .50733 Mdot
.48616 .5442 Mdot
.52039 .54552 Mdot
.45562 .52078 Mdot
.51624 .51546 Mdot
.49053 .45564 Mdot
.47798 .49135 Mdot
.45091 .50159 Mdot
.47658 .51126 Mdot
.45767 .53166 Mdot
.48055 .47895 Mdot
.48233 .46995 Mdot
.50439 .46184 Mdot
.54656 .49687 Mdot
.5364 .53922 Mdot
.54868 .52936 Mdot
.46982 .45351 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go
00001_ooool3o`000?ooooooB?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04
odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol0003o
oooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`3o
ooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007
ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<
ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0UOooool2o`00
00Cooooo0ol00002ooooo`;o00000_ooool2o`000004ooooool0003o0000o`0009gooooo000Noooo
o`;o0000Toooool@o`0000;ooooo0_l000000ooooooo0000o`000003o`0009_ooooo000Nooooo`03
o`000?oooooooooo097ooooo3ol00005ooooo`So0000V_ooool001kooooo00?o0000ooooooooool0
S_ooool@o`000003ooooool0003o000000?o000000?oooooo`000?l000001_l0002Jooooo`007_oo
ool00ol0003oooooooooo`2>ooooo`Go000000?oooooo`000?l000003_l000000ooooooo0000o`00
0007o`0009Wooooo000Nooooo`03o`000?oooooooooo08cooooo1ol000000ooooooo0000o`00000H
o`0009Wooooo000Nooooo`03o`000?oooooooooo08cooooo9?l0002Gooooo`007_ooool00ol0003o
ooooooooo`2<ooooobCo0000Uoooool001kooooo00?o0000ooooooooool0S_ooool3o`000004oooo
ool0003o0000oooooa_o0000Uoooool001kooooo00?o0000ooooooooool0Roooool2o`000003oooo
ool0003o0000023o0000Uoooool001kooooo00?o0000ooooooooool0R_oooolXo`0009Gooooo000N
ooooo`03o`000?oooooooooo08[ooooo1_l00002ooooob3o0000UOooool001kooooo00?o0000oooo
ooooool0R_ooool5o`000003ooooool0003o000001So00000_ooool4o`0009Oooooo000Nooooo`03
o`000?oooooooooo08[ooooo0ol00003ooooob?o0000U?ooool001kooooo00?o0000ooooooooool0
Roooool2o`0000?ooooo8ol0002Dooooo`007_ooool00ol0003oooooooooo`2:ooooob[o0000Tooo
ool001kooooo00?o0000ooooooooool0R_oooolZo`0009?ooooo000Nooooo`;o0000Roooool2o`00
0003ooooool0003o000000?o000000?oooooo`000?l000007_l0002Dooooo`007_ooool00ol0003o
ooooooooo`2:ooooo`So00000oooool3o`0000;ooooo6Ol0002Dooooo`007_ooool00ol0003ooooo
ooooo`2:oooooaoo000000Goooooo`000?l0003o0000ooooo`03o`000003ooooool0003o000009?o
oooo000Nooooo`03o`000?oooooooooo08_ooooo1Ol000000ooooooo0000o`00000;o`000003oooo
ool0003o000000So000000?oooooo`000?l000002?l0002Cooooo`007_ooool00ol0003ooooooooo
o`2;ooooo`Go000000?oooooo`000?l000000_l000000ooooooo0000o`000006o`000003ooooool0
003o000001;o0000U?ooool001kooooo00?o0000ooooooooool0Roooool;o`000003ooooool0003o
000001[o0000U?ooool001kooooo00?o0000ooooooooool0RooooolWo`0009Gooooo000Nooooo`03
o`000?oooooooooo08_ooooo9ol0002Eooooo`007_ooool00ol0003oooooooooo`2<ooooobGo0000
U_ooool001kooooo00?o0000ooooooooool0S?oooolUo`0009Kooooo000Nooooo`03o`000?oooooo
oooo08gooooo6?l000000ooooooo0000o`000009o`0009Kooooo000Nooooo`03o`000?oooooooooo
08gooooo6Ol000000ooooooo0000o`000006o`0009Sooooo000Nooooo`03o`000?oooooooooo08oo
oooo0_l000000ooooooo0000o`00000Ko`0009Sooooo000Nooooo`03o`000?oooooooooo093ooooo
3Ol000000ooooooo0000o`00000>o`0009Wooooo000Nooooo`03o`000?oooooooooo093ooooo7_l0
002Iooooo`007_ooool00ol0003oooooooooo`2@ooooo`ko000000?oooooo`000?l000003?l0002J
ooooo`007_ooool2o`0009Kooooo2?l00002ooooo`go0000Voooool001kooooo00?o0000oooooooo
ool0U_ooool8o`000003ooooool0003o000000Go000000Coooooo`000?l0003o0000WOooool001ko
oooo00?o0000ooooooooool0U_ooool?o`000:;ooooo000Nooooo`03o`000?oooooooooo09Sooooo
1Ol000001Ooooooo0000o`000?l0003ooooo00?o0000X_ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@
4?o<c<`01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooo
oooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooo
ooooooooool000001_ooool3o`000?ooooooB?ooool000?ooooo00Go0000ooooooooooooooooo`00
000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`3oooooodSooooo
0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Ko
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol@413ooooooooooooooooo410@00_o
oooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@
40Kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooo
oom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodSo
oooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?oo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool0
00?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_oo
ool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`000?ooooooooooooooool000002ooo
ool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom8ooooo`000ooo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03
o`000?oooooooooo0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`005?ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0
oooooom8ooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Kooooo00?o0000ooooooooool01Oooool3o`000?ooooooB?ooool001Kooooo00?o0000oooo
ooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`00
0?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005?ooool0
0omEEEGoIVIVo`00003ooooooe;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.45569 .46477 Mdot
.48563 .53625 Mdot
.49637 .56051 Mdot
.47958 .53025 Mdot
.46209 .50925 Mdot
.47518 .44251 Mdot
.48627 .56221 Mdot
.45055 .4962 Mdot
.56247 .50324 Mdot
.51012 .45361 Mdot
.4708 .46377 Mdot
.51326 .50399 Mdot
.47254 .4406 Mdot
.449 .53015 Mdot
.54842 .543 Mdot
.51659 .45752 Mdot
.45342 .52284 Mdot
.51585 .44005 Mdot
.51022 .44853 Mdot
.53618 .51381 Mdot
.44739 .51247 Mdot
.54601 .47427 Mdot
.46426 .48391 Mdot
.44663 .46896 Mdot
.44795 .49108 Mdot
.5107 .49355 Mdot
.55179 .53068 Mdot
.50826 .44583 Mdot
.47282 .51475 Mdot
.46387 .44719 Mdot
.48576 .55421 Mdot
.4638 .52698 Mdot
.4896 .49214 Mdot
.52803 .54793 Mdot
.46832 .44335 Mdot
.50584 .5586 Mdot
.51222 .48777 Mdot
.55609 .5126 Mdot
.46083 .49424 Mdot
.52216 .49889 Mdot
.50721 .47453 Mdot
.54193 .50181 Mdot
.50002 .54881 Mdot
.49326 .50562 Mdot
.45632 .52196 Mdot
.52451 .46721 Mdot
.45085 .53398 Mdot
.47813 .55204 Mdot
.49976 .55611 Mdot
.5574 .47689 Mdot
.46206 .50117 Mdot
.4774 .43269 Mdot
.47729 .51813 Mdot
.45659 .49951 Mdot
.52016 .45 Mdot
.53151 .48099 Mdot
.51853 .52752 Mdot
.47225 .43182 Mdot
.45917 .52018 Mdot
.51855 .5324 Mdot
.53643 .46261 Mdot
.51913 .4772 Mdot
.53246 .5368 Mdot
.5145 .46068 Mdot
.46706 .49672 Mdot
.5642 .50019 Mdot
.46615 .5397 Mdot
.53114 .4691 Mdot
.53665 .49659 Mdot
.51981 .45349 Mdot
.51764 .56214 Mdot
.46374 .51913 Mdot
.52466 .52235 Mdot
.49454 .52052 Mdot
.45611 .45429 Mdot
.54132 .54328 Mdot
.53991 .48382 Mdot
.50802 .43973 Mdot
.51017 .5639 Mdot
.48051 .46896 Mdot
.55217 .5132 Mdot
.45034 .49158 Mdot
.44614 .50141 Mdot
.51216 .47394 Mdot
.53122 .54069 Mdot
.48769 .52026 Mdot
.53004 .55149 Mdot
.52728 .47373 Mdot
.52373 .50263 Mdot
.49603 .43528 Mdot
.47262 .5077 Mdot
.52368 .46093 Mdot
.54467 .53098 Mdot
.56305 .49127 Mdot
.49431 .56281 Mdot
.54236 .47096 Mdot
.5301 .47512 Mdot
.47806 .55059 Mdot
.4523 .5362 Mdot
.51296 .53295 Mdot
.53472 .54689 Mdot
.54217 .53207 Mdot
.45543 .51207 Mdot
.55194 .47146 Mdot
.56127 .51356 Mdot
.49389 .49058 Mdot
.44317 .5313 Mdot
.46772 .50192 Mdot
.47845 .54567 Mdot
.52422 .45933 Mdot
.44615 .47484 Mdot
.46485 .52047 Mdot
.50719 .52312 Mdot
.55847 .4949 Mdot
.44944 .52564 Mdot
.48288 .43205 Mdot
.55533 .52283 Mdot
.51873 .44303 Mdot
.48363 .55718 Mdot
.54683 .52807 Mdot
.48351 .45675 Mdot
.50503 .49739 Mdot
.51294 .45147 Mdot
.4927 .55556 Mdot
.4671 .53215 Mdot
.55452 .48378 Mdot
.44918 .46645 Mdot
.50635 .49555 Mdot
.49654 .50077 Mdot
.50682 .47007 Mdot
.48039 .46369 Mdot
.44962 .52126 Mdot
.44715 .45778 Mdot
.51796 .55166 Mdot
.46016 .47902 Mdot
.44134 .47085 Mdot
.54402 .46743 Mdot
.48292 .50784 Mdot
.53035 .50942 Mdot
.50432 .5146 Mdot
.46934 .50454 Mdot
.56019 .51393 Mdot
.49444 .49594 Mdot
.47695 .526 Mdot
.48125 .49068 Mdot
.52715 .45806 Mdot
.45818 .45882 Mdot
.54553 .47866 Mdot
.44806 .52418 Mdot
.49807 .55529 Mdot
.5274 .54298 Mdot
.5091 .44478 Mdot
.46748 .50862 Mdot
.44618 .52405 Mdot
.47677 .4636 Mdot
.51728 .45648 Mdot
.51467 .47913 Mdot
.45441 .45026 Mdot
.53969 .48488 Mdot
.4749 .49477 Mdot
.53356 .5534 Mdot
.54104 .493 Mdot
.48971 .44836 Mdot
.52991 .4499 Mdot
.52272 .51203 Mdot
.51511 .52012 Mdot
.55905 .52184 Mdot
.5512 .50114 Mdot
.54828 .48455 Mdot
.55715 .50183 Mdot
.49211 .46323 Mdot
.50004 .55397 Mdot
.49153 .53979 Mdot
.52429 .51079 Mdot
.52302 .55994 Mdot
.52376 .48189 Mdot
.54277 .4701 Mdot
.47255 .4941 Mdot
.43661 .50889 Mdot
.51567 .55044 Mdot
.48167 .52906 Mdot
.54066 .46676 Mdot
.49173 .51456 Mdot
.4761 .51847 Mdot
.4769 .43669 Mdot
.51128 .50763 Mdot
.5169 .55809 Mdot
.53812 .4639 Mdot
.56209 .48922 Mdot
.54417 .53511 Mdot
.50005 .50964 Mdot
.4864 .48132 Mdot
.44301 .47938 Mdot
.46748 .50622 Mdot
.55674 .50648 Mdot
.49987 .48039 Mdot
.56043 .4809 Mdot
.49067 .49737 Mdot
.46912 .49095 Mdot
.48811 .53264 Mdot
.50805 .53584 Mdot
.53541 .46872 Mdot
.48355 .45963 Mdot
.54826 .49589 Mdot
.51313 .45658 Mdot
.49506 .54083 Mdot
.44415 .50554 Mdot
.51282 .53676 Mdot
.51749 .55627 Mdot
.46561 .50573 Mdot
.45465 .52093 Mdot
.50552 .49097 Mdot
.53025 .49789 Mdot
.48001 .45119 Mdot
.50539 .49757 Mdot
.44603 .52713 Mdot
.52607 .46173 Mdot
.53794 .48714 Mdot
.56043 .51237 Mdot
.47049 .50054 Mdot
.47676 .48131 Mdot
.46283 .43856 Mdot
.52657 .45894 Mdot
.43609 .49728 Mdot
.46597 .4696 Mdot
.45482 .48242 Mdot
.46698 .52671 Mdot
.51729 .44768 Mdot
.51244 .55929 Mdot
.47565 .47119 Mdot
.53747 .45705 Mdot
.50272 .49265 Mdot
.55955 .50404 Mdot
.50984 .48414 Mdot
.52081 .4874 Mdot
.53001 .51145 Mdot
.55738 .4919 Mdot
.53628 .54881 Mdot
.4711 .53727 Mdot
.51142 .50754 Mdot
.51624 .44799 Mdot
.54759 .54261 Mdot
.45433 .4618 Mdot
.55641 .48773 Mdot
.48213 .55892 Mdot
.52262 .44968 Mdot
.54226 .54319 Mdot
.45234 .48879 Mdot
.53176 .45041 Mdot
.55542 .52539 Mdot
.50325 .54698 Mdot
.48045 .4349 Mdot
.55231 .53611 Mdot
.48876 .56146 Mdot
.50427 .52162 Mdot
.51693 .5102 Mdot
.47297 .47857 Mdot
.53323 .49041 Mdot
.53114 .54235 Mdot
.55618 .52915 Mdot
.55037 .50299 Mdot
.49457 .48078 Mdot
.47541 .49452 Mdot
.47879 .45822 Mdot
.53348 .52534 Mdot
.53532 .52943 Mdot
.47341 .47279 Mdot
.49431 .45492 Mdot
.49645 .48361 Mdot
.43481 .50457 Mdot
.47774 .54627 Mdot
.50761 .52283 Mdot
.56271 .49234 Mdot
.50702 .51753 Mdot
.5054 .56088 Mdot
.53448 .55133 Mdot
.53623 .47932 Mdot
.50644 .45395 Mdot
.53584 .51044 Mdot
.49558 .47078 Mdot
.53315 .50355 Mdot
.5212 .4909 Mdot
.46384 .54539 Mdot
.48221 .49744 Mdot
.55773 .51259 Mdot
.56243 .48727 Mdot
.43951 .51835 Mdot
.47196 .48027 Mdot
.47736 .53874 Mdot
.44358 .51931 Mdot
.52042 .5098 Mdot
.44861 .52667 Mdot
.48671 .43133 Mdot
.50333 .55004 Mdot
.51489 .52054 Mdot
.45487 .50148 Mdot
.49959 .45317 Mdot
.52149 .54607 Mdot
.54317 .50413 Mdot
.47684 .52923 Mdot
.48822 .50331 Mdot
.45573 .48099 Mdot
.56248 .51203 Mdot
.52871 .45218 Mdot
.51743 .50638 Mdot
.47769 .52903 Mdot
.43498 .48494 Mdot
.43953 .49491 Mdot
.44814 .48867 Mdot
.53164 .52881 Mdot
.48993 .5281 Mdot
.48395 .49587 Mdot
.47795 .47509 Mdot
.45628 .47005 Mdot
.49401 .53353 Mdot
.44316 .51457 Mdot
.52276 .49757 Mdot
.52954 .47069 Mdot
.5264 .51691 Mdot
.55593 .50764 Mdot
.51116 .55167 Mdot
.4691 .46172 Mdot
.46967 .45948 Mdot
.52714 .48098 Mdot
.49749 .4597 Mdot
.55517 .49052 Mdot
.49745 .5079 Mdot
.49798 .50071 Mdot
.55879 .48827 Mdot
.54609 .51974 Mdot
.45854 .45648 Mdot
.47559 .43505 Mdot
.50856 .52312 Mdot
.50846 .45488 Mdot
.51595 .55636 Mdot
.48492 .47756 Mdot
.52612 .54394 Mdot
.47065 .52486 Mdot
.46457 .46364 Mdot
.52146 .47685 Mdot
.46811 .54152 Mdot
.44108 .50362 Mdot
.45914 .54796 Mdot
.49281 .49507 Mdot
.55068 .48339 Mdot
.45417 .53017 Mdot
.48182 .49889 Mdot
.45229 .50238 Mdot
.55099 .50395 Mdot
.51247 .47346 Mdot
.52066 .51903 Mdot
.44932 .45403 Mdot
.45114 .51885 Mdot
.5129 .48469 Mdot
.48675 .43579 Mdot
.51784 .51803 Mdot
.43909 .51245 Mdot
.45795 .53041 Mdot
.49189 .43177 Mdot
.4926 .49002 Mdot
.4674 .49338 Mdot
.44243 .51299 Mdot
.51289 .51968 Mdot
.43938 .50961 Mdot
.45795 .53128 Mdot
.46561 .54757 Mdot
.47095 .55377 Mdot
.5515 .49757 Mdot
.43463 .50788 Mdot
.48704 .51874 Mdot
.47427 .4951 Mdot
.47921 .50708 Mdot
.45578 .44555 Mdot
.47041 .46823 Mdot
.48969 .55897 Mdot
.51145 .45567 Mdot
.47271 .47027 Mdot
.53385 .54971 Mdot
.54025 .50346 Mdot
.50912 .49066 Mdot
.52701 .54015 Mdot
.49821 .5638 Mdot
.47002 .52071 Mdot
.44071 .4787 Mdot
.46429 .52474 Mdot
.47336 .44766 Mdot
.50877 .44529 Mdot
.48091 .47774 Mdot
.52921 .48442 Mdot
.52594 .54076 Mdot
.43832 .4755 Mdot
.53868 .50275 Mdot
.51544 .54966 Mdot
.46267 .5262 Mdot
.4674 .48387 Mdot
.44982 .50356 Mdot
.53432 .45404 Mdot
.48613 .49343 Mdot
.49895 .4575 Mdot
.43712 .48157 Mdot
.43446 .49207 Mdot
.52253 .54741 Mdot
.44242 .46184 Mdot
.52056 .49198 Mdot
.51933 .54571 Mdot
.50509 .55783 Mdot
.47591 .52015 Mdot
.47204 .49806 Mdot
.50631 .54027 Mdot
.48531 .46796 Mdot
.50529 .5119 Mdot
.49904 .46366 Mdot
.49283 .51933 Mdot
.48143 .55355 Mdot
.48755 .51628 Mdot
.54165 .53451 Mdot
.52423 .45655 Mdot
.44011 .48917 Mdot
.5119 .5448 Mdot
.51656 .44871 Mdot
.49068 .47111 Mdot
.52669 .46665 Mdot
.49288 .51443 Mdot
.50427 .45991 Mdot
.45729 .44048 Mdot
.51945 .55183 Mdot
.55528 .53525 Mdot
.50156 .48123 Mdot
.53306 .50874 Mdot
.52973 .49614 Mdot
.44087 .51116 Mdot
.52002 .45355 Mdot
.4433 .50323 Mdot
.48832 .47119 Mdot
.54946 .48778 Mdot
.4426 .47843 Mdot
.54875 .48432 Mdot
.51923 .52713 Mdot
.43979 .50433 Mdot
.52372 .51214 Mdot
.4989 .55237 Mdot
.50325 .43291 Mdot
.446 .52305 Mdot
.47778 .45924 Mdot
.49385 .49016 Mdot
.48636 .46238 Mdot
.46413 .51512 Mdot
.51191 .45961 Mdot
.52434 .55133 Mdot
.47237 .50996 Mdot
.46451 .54808 Mdot
.50962 .51038 Mdot
.51043 .47273 Mdot
.52521 .50785 Mdot
.53979 .53029 Mdot
.56084 .49888 Mdot
.52736 .54236 Mdot
.55523 .51089 Mdot
.47524 .50024 Mdot
.53159 .49336 Mdot
.54615 .50034 Mdot
.49694 .52359 Mdot
.47701 .55243 Mdot
.50729 .48546 Mdot
.51223 .54959 Mdot
.43486 .49702 Mdot
.505 .48264 Mdot
.49591 .51384 Mdot
.45695 .53488 Mdot
.53439 .49167 Mdot
.46533 .45841 Mdot
.49203 .47535 Mdot
.46572 .55594 Mdot
.54179 .5522 Mdot
.49868 .46032 Mdot
.56181 .50302 Mdot
.49208 .55713 Mdot
.54187 .5528 Mdot
.53436 .54787 Mdot
.44476 .46457 Mdot
.4859 .49562 Mdot
.45133 .51875 Mdot
.4513 .48926 Mdot
.45398 .51451 Mdot
.52856 .4653 Mdot
.54642 .49759 Mdot
.50542 .45964 Mdot
.45548 .46402 Mdot
.50497 .55297 Mdot
.53453 .54909 Mdot
.49307 .43017 Mdot
.51538 .55797 Mdot
.56142 .49338 Mdot
.46986 .49271 Mdot
.50886 .54268 Mdot
.48651 .43468 Mdot
.55936 .51239 Mdot
.47195 .49124 Mdot
.54475 .49849 Mdot
.45389 .48115 Mdot
.44785 .53649 Mdot
.55324 .53602 Mdot
.46964 .55714 Mdot
.48418 .47913 Mdot
.51176 .50877 Mdot
.5248 .44557 Mdot
.4461 .48498 Mdot
.50168 .46977 Mdot
.51771 .55986 Mdot
.56046 .48196 Mdot
.53854 .50269 Mdot
.52952 .54219 Mdot
.50079 .54679 Mdot
.48032 .43905 Mdot
.45568 .47986 Mdot
.51958 .4556 Mdot
.50306 .54611 Mdot
.46941 .44321 Mdot
.46347 .54675 Mdot
.45923 .46658 Mdot
.53121 .44987 Mdot
.47209 .54304 Mdot
.45481 .47605 Mdot
.51326 .49108 Mdot
.51652 .51441 Mdot
.53065 .4763 Mdot
.51416 .55241 Mdot
.48166 .43087 Mdot
.48569 .46468 Mdot
.49709 .46371 Mdot
.54166 .51636 Mdot
.52745 .4579 Mdot
.53562 .48061 Mdot
.4982 .52338 Mdot
.56142 .48741 Mdot
.50838 .50402 Mdot
.44767 .46348 Mdot
.53093 .46739 Mdot
.51557 .53387 Mdot
.51565 .44585 Mdot
.50568 .52102 Mdot
.49478 .44295 Mdot
.52692 .45556 Mdot
.44388 .47171 Mdot
.4799 .46558 Mdot
.54906 .53567 Mdot
.47343 .52213 Mdot
.50244 .43763 Mdot
.46049 .51685 Mdot
.48237 .47252 Mdot
.52271 .50276 Mdot
.45669 .4882 Mdot
.48457 .49174 Mdot
.4429 .52779 Mdot
.46621 .52342 Mdot
.47873 .48227 Mdot
.47372 .50432 Mdot
.52095 .54074 Mdot
.49207 .43063 Mdot
.55136 .52588 Mdot
.54452 .52642 Mdot
.53054 .54685 Mdot
.51106 .45878 Mdot
.48167 .51752 Mdot
.53921 .51078 Mdot
.4733 .47826 Mdot
.48223 .56069 Mdot
.4926 .47223 Mdot
.44235 .47385 Mdot
.49364 .5568 Mdot
.43473 .50411 Mdot
.50528 .4936 Mdot
.5157 .54444 Mdot
.45527 .51007 Mdot
.50901 .50905 Mdot
.51388 .46566 Mdot
.49996 .4366 Mdot
.52266 .50156 Mdot
.53678 .54764 Mdot
.51191 .49876 Mdot
.51069 .56095 Mdot
.46435 .51866 Mdot
.45724 .54681 Mdot
.50409 .53997 Mdot
.54045 .49106 Mdot
.44391 .52447 Mdot
.45716 .4822 Mdot
.46702 .53876 Mdot
.44365 .5124 Mdot
.53553 .53159 Mdot
.51326 .50777 Mdot
.5198 .46983 Mdot
.46985 .48903 Mdot
.50124 .5059 Mdot
.50945 .46362 Mdot
.45744 .45779 Mdot
.44112 .48244 Mdot
.54146 .46734 Mdot
.48984 .44869 Mdot
.49151 .53766 Mdot
.54997 .49457 Mdot
.53679 .45702 Mdot
.45982 .46228 Mdot
.48541 .44113 Mdot
.5197 .46886 Mdot
.48409 .54871 Mdot
.49574 .47676 Mdot
.471 .55295 Mdot
.51873 .47808 Mdot
.49952 .50156 Mdot
.5204 .44272 Mdot
.44796 .47504 Mdot
.47011 .47811 Mdot
.44758 .52983 Mdot
.45451 .46447 Mdot
.46758 .51188 Mdot
.46394 .49112 Mdot
.52155 .44876 Mdot
.46725 .49739 Mdot
.53266 .5555 Mdot
.49043 .56384 Mdot
.47762 .43172 Mdot
.50216 .52584 Mdot
.51495 .47937 Mdot
.47338 .55516 Mdot
.5283 .53689 Mdot
.46956 .50892 Mdot
.47652 .50373 Mdot
.43956 .47525 Mdot
.4801 .53912 Mdot
.53397 .46433 Mdot
.51572 .45596 Mdot
.49601 .55598 Mdot
.49998 .43972 Mdot
.4962 .44089 Mdot
.46593 .46396 Mdot
.54076 .54229 Mdot
.49873 .51334 Mdot
.45736 .51665 Mdot
.4394 .51817 Mdot
.45217 .4947 Mdot
.53889 .48182 Mdot
.46853 .55235 Mdot
.50044 .48275 Mdot
.50484 .47087 Mdot
.48261 .44741 Mdot
.48593 .43744 Mdot
.49987 .48761 Mdot
.48618 .56204 Mdot
.5009 .56461 Mdot
.45705 .4726 Mdot
.48251 .49233 Mdot
.49876 .49184 Mdot
.47902 .5459 Mdot
.50995 .52766 Mdot
.50383 .54766 Mdot
.5647 .50911 Mdot
.49898 .51146 Mdot
.53985 .51535 Mdot
.50257 .50484 Mdot
.45975 .51682 Mdot
.48602 .48976 Mdot
.43905 .50777 Mdot
.46954 .43221 Mdot
.45063 .5378 Mdot
.52791 .54274 Mdot
.55333 .49345 Mdot
.43661 .4764 Mdot
.44917 .46994 Mdot
.55725 .53578 Mdot
.48175 .53789 Mdot
.45847 .44042 Mdot
.43445 .4906 Mdot
.53883 .46064 Mdot
.49954 .47579 Mdot
.53143 .44912 Mdot
.52828 .52003 Mdot
.45683 .52175 Mdot
.50524 .44676 Mdot
.45411 .49932 Mdot
.53778 .46246 Mdot
.54532 .525 Mdot
.48511 .54428 Mdot
.54883 .52167 Mdot
.45719 .52463 Mdot
.5375 .4693 Mdot
.47152 .53468 Mdot
.47953 .43579 Mdot
.52729 .50689 Mdot
.53243 .51712 Mdot
.54322 .47819 Mdot
.50256 .5592 Mdot
.47335 .4335 Mdot
.5249 .48559 Mdot
.52229 .5432 Mdot
.4449 .491 Mdot
.44403 .53121 Mdot
.49051 .50219 Mdot
.52273 .45947 Mdot
.47415 .52775 Mdot
.46141 .48077 Mdot
.50893 .50294 Mdot
.46471 .54525 Mdot
.46679 .4973 Mdot
.47727 .55539 Mdot
.50511 .56469 Mdot
.52841 .47695 Mdot
.46301 .5039 Mdot
.5344 .53773 Mdot
.50402 .46005 Mdot
.55781 .48354 Mdot
.50005 .50331 Mdot
.53402 .54306 Mdot
.53117 .44838 Mdot
.4415 .51605 Mdot
.55132 .53096 Mdot
.53392 .45088 Mdot
.44297 .49996 Mdot
.47301 .44525 Mdot
.50142 .44947 Mdot
.48674 .52252 Mdot
.4884 .46729 Mdot
.53115 .513 Mdot
.49435 .52443 Mdot
.44699 .48007 Mdot
.51841 .52208 Mdot
.50996 .43676 Mdot
.48076 .44964 Mdot
.44747 .4638 Mdot
.54199 .47492 Mdot
.47592 .46324 Mdot
.51301 .47092 Mdot
.51957 .51728 Mdot
.50945 .48048 Mdot
.48496 .43044 Mdot
.49576 .56488 Mdot
.52078 .48547 Mdot
.54432 .47189 Mdot
.50396 .45639 Mdot
.53558 .48737 Mdot
.52446 .46538 Mdot
.47111 .43882 Mdot
.52396 .48799 Mdot
.45769 .47436 Mdot
.47855 .4857 Mdot
.45915 .5036 Mdot
.46968 .49375 Mdot
.52584 .4751 Mdot
.49595 .49978 Mdot
.46518 .45534 Mdot
.50885 .55508 Mdot
.47676 .49784 Mdot
.52184 .522 Mdot
.46052 .50573 Mdot
.53937 .4607 Mdot
.43724 .49394 Mdot
.55982 .51547 Mdot
.51215 .45375 Mdot
.48585 .5539 Mdot
.48553 .47344 Mdot
.46918 .44594 Mdot
.47371 .44658 Mdot
.54587 .55048 Mdot
.54147 .49683 Mdot
.50722 .43654 Mdot
.50024 .52161 Mdot
.44108 .47537 Mdot
.47426 .52196 Mdot
.49583 .50563 Mdot
.50153 .55852 Mdot
.47501 .45573 Mdot
.48036 .55195 Mdot
.4652 .44505 Mdot
.48525 .51705 Mdot
.51045 .55765 Mdot
.55045 .52554 Mdot
.55439 .53823 Mdot
.45233 .47995 Mdot
.49774 .51659 Mdot
.5338 .49488 Mdot
.4904 .4793 Mdot
.45758 .53281 Mdot
.4688 .44449 Mdot
.49643 .43105 Mdot
.456 .442 Mdot
.53231 .55294 Mdot
.50486 .53334 Mdot
.50575 .47378 Mdot
.49826 .45694 Mdot
.5461 .49081 Mdot
.49219 .53321 Mdot
.48625 .45703 Mdot
.48611 .52685 Mdot
.55531 .5129 Mdot
.4816 .54651 Mdot
.55246 .48594 Mdot
.4828 .54912 Mdot
.44128 .52674 Mdot
.51003 .46151 Mdot
.46023 .54633 Mdot
.49681 .48037 Mdot
.51494 .53328 Mdot
.52217 .55721 Mdot
.55538 .53974 Mdot
.4549 .46671 Mdot
.51043 .46436 Mdot
.52173 .5129 Mdot
.45329 .48211 Mdot
.45022 .51536 Mdot
.50371 .44399 Mdot
.47464 .5228 Mdot
.54927 .53504 Mdot
.48267 .52548 Mdot
.46816 .45543 Mdot
.51093 .45916 Mdot
.50224 .54843 Mdot
.54072 .46899 Mdot
.51728 .52696 Mdot
.44829 .48459 Mdot
.49227 .55525 Mdot
.50329 .48421 Mdot
.50301 .52372 Mdot
.53229 .55312 Mdot
.50573 .45444 Mdot
.44984 .48024 Mdot
.52568 .44521 Mdot
.46749 .49454 Mdot
.47681 .53993 Mdot
.48236 .54609 Mdot
.52512 .48754 Mdot
.44795 .53422 Mdot
.46971 .5427 Mdot
.47644 .55462 Mdot
.52682 .46934 Mdot
.50047 .49339 Mdot
.4992 .47608 Mdot
.54099 .50556 Mdot
.48069 .46839 Mdot
.49967 .5275 Mdot
.55712 .51134 Mdot
.45382 .46677 Mdot
.52432 .46451 Mdot
.54111 .46821 Mdot
.52471 .55859 Mdot
.50647 .56404 Mdot
.54151 .52452 Mdot
.55812 .53459 Mdot
.54017 .50915 Mdot
.52739 .46289 Mdot
.52567 .52011 Mdot
.46903 .53463 Mdot
.48604 .44527 Mdot
.4496 .53194 Mdot
.43448 .4888 Mdot
.52058 .56203 Mdot
.50951 .51061 Mdot
.49329 .48649 Mdot
.48199 .43964 Mdot
.49476 .51451 Mdot
.46735 .50392 Mdot
.53638 .53712 Mdot
.51006 .51073 Mdot
.48311 .49522 Mdot
.54949 .5216 Mdot
.49563 .45681 Mdot
.52709 .55109 Mdot
.49842 .53827 Mdot
.50669 .44395 Mdot
.49005 .53571 Mdot
.4829 .42929 Mdot
.48729 .45906 Mdot
.55731 .51006 Mdot
.48011 .55444 Mdot
.45785 .45706 Mdot
.4442 .4908 Mdot
.48681 .51796 Mdot
.45719 .49568 Mdot
.5219 .46351 Mdot
.52253 .50347 Mdot
.48155 .43104 Mdot
.4518 .53863 Mdot
.45447 .44716 Mdot
.45176 .52917 Mdot
.47693 .51441 Mdot
.50873 .43557 Mdot
.45673 .51895 Mdot
.52743 .50317 Mdot
.51422 .46385 Mdot
.52938 .5538 Mdot
.45386 .44899 Mdot
.54386 .48163 Mdot
.49515 .49293 Mdot
.52242 .55642 Mdot
.48523 .47206 Mdot
.47313 .4908 Mdot
.55919 .48227 Mdot
.46769 .51433 Mdot
.48637 .54752 Mdot
.50909 .51911 Mdot
.50789 .52617 Mdot
.47449 .45976 Mdot
.50832 .53565 Mdot
.44626 .51664 Mdot
.49304 .5349 Mdot
.55387 .47989 Mdot
.4852 .52245 Mdot
.53054 .55285 Mdot
.52865 .51255 Mdot
.45468 .50046 Mdot
.44706 .52339 Mdot
.53943 .52118 Mdot
.54895 .50054 Mdot
.51156 .51381 Mdot
.46379 .48952 Mdot
.46982 .53229 Mdot
.51379 .50041 Mdot
.54103 .53077 Mdot
.46475 .55304 Mdot
.44764 .47075 Mdot
.55402 .52153 Mdot
.51676 .47286 Mdot
.49295 .50266 Mdot
.43983 .51631 Mdot
.54266 .52233 Mdot
.55431 .53414 Mdot
.49223 .52522 Mdot
.45595 .50245 Mdot
.51775 .50521 Mdot
.56127 .52353 Mdot
.48008 .52116 Mdot
.50668 .53274 Mdot
.54345 .50108 Mdot
.56345 .50449 Mdot
.468 .53501 Mdot
.49462 .51244 Mdot
.56001 .47985 Mdot
.51689 .47857 Mdot
.44618 .5305 Mdot
.55355 .52899 Mdot
.53834 .54881 Mdot
.46175 .4433 Mdot
.4483 .48949 Mdot
.50628 .55333 Mdot
.48964 .5248 Mdot
.53876 .47048 Mdot
.45282 .46506 Mdot
.47191 .54597 Mdot
.46924 .54715 Mdot
.5142 .54412 Mdot
.4411 .47872 Mdot
.5111 .44457 Mdot
.50578 .51594 Mdot
.51108 .43818 Mdot
.47412 .53994 Mdot
.48505 .52952 Mdot
.49559 .45444 Mdot
.54009 .53702 Mdot
.52257 .45561 Mdot
.44135 .5224 Mdot
.53207 .55647 Mdot
.54791 .50828 Mdot
.48847 .51534 Mdot
.54415 .47104 Mdot
.50306 .4912 Mdot
.50217 .48493 Mdot
.49898 .55182 Mdot
.51168 .56017 Mdot
.50642 .5359 Mdot
.51319 .46965 Mdot
.55115 .52234 Mdot
.53738 .52069 Mdot
.4444 .48429 Mdot
.48056 .43236 Mdot
.55186 .49657 Mdot
.43415 .50675 Mdot
.5211 .45332 Mdot
.44916 .54008 Mdot
.49017 .51428 Mdot
.51762 .49292 Mdot
.51303 .43987 Mdot
.50281 .43382 Mdot
.47195 .49972 Mdot
.45346 .51153 Mdot
.45969 .47573 Mdot
.45177 .53099 Mdot
.48144 .55621 Mdot
.44615 .48369 Mdot
.50396 .52908 Mdot
.52712 .45278 Mdot
.48175 .477 Mdot
.4559 .46453 Mdot
.46494 .48996 Mdot
.43996 .49561 Mdot
.49691 .47033 Mdot
.50744 .46239 Mdot
.53776 .46854 Mdot
.54642 .53382 Mdot
.50125 .56224 Mdot
.51921 .56182 Mdot
.50341 .43733 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go
00001_ooool3o`000?ooooooB?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04
odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol0003o
oooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`3o
ooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007
ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<
ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0UOooool:o`000:Sooooo000Noooo
o`03o`000?oooooooooo09Gooooo3?l0002Vooooo`007_ooool00ol0003oooooooooo`2Eooooo`Oo
000000?oooooo`000?l000001Ol0002Sooooo`007_ooool00ol0003oooooooooo`2Aooooo`?o0000
00?oooooo`000?l000001Ol000000ooooooo0000o`000007o`000:7ooooo000Nooooo`03o`000?oo
oooooooo093ooooo3?l000000ooooooo0000o`000008o`000:3ooooo000Nooooo`03o`000?oooooo
oooo093ooooo2?l000001Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`000?l000001ol0
002Nooooo`007_ooool00ol0003oooooooooo`2?ooooo`?o000000?oooooo`000?l000002?l00002
ooooo`co0000W?ooool001kooooo0_l0002@ooooo`?o00001?ooool4o`000004ooooool0003o0000
ooooo`?o000000?oooooo`000?l000001ol0002Looooo`007_ooool00ol0003oooooooooo`2>oooo
o`co00000oooool?o`0009_ooooo000Nooooo`03o`000?oooooooooo08gooooo3ol000000ooooooo
0000o`00000:o`000004ooooool0003o0000o`0009[ooooo000Nooooo`03o`000?oooooooooo08co
oooo0ol000000ooooooo0000o`00000:o`000003ooooool0003o000000[o000000Coooooo`000?l0
003o0000V_ooool001kooooo00?o0000ooooooooool0S?oooolIo`000003ooooool0003o000000Go
0000V_ooool001kooooo00?o0000ooooooooool0S?oooolDo`0000;ooooo3Ol0002Hooooo`007_oo
ool00ol0003oooooooooo`2;ooooobKo0000U_ooool001kooooo00?o0000ooooooooool0Roooool:
o`000003ooooool0003o000001Wo0000U_ooool001kooooo00?o0000ooooooooool0R_ooool9o`00
00;ooooo5Ol00002ooooo`?o00000_ooool2o`0009Cooooo000Nooooo`03o`000?oooooooooo08[o
oooo2_l000000ooooooo0000o`00000:o`000003ooooool0003o000000_o000000?oooooo`000?l0
00000_l0002Cooooo`007_ooool00ol0003oooooooooo`2:ooooob[o0000Toooool001kooooo00?o
0000ooooooooool0ROooool=o`000003ooooool0003o000001co0000T_ooool001kooooo00?o0000
ooooooooool0ROooool9o`000003ooooool0003o000000Co000000?oooooo`000?l000004Ol00000
0ooooooo0000o`000005o`0009;ooooo000Nooooo`03o`000?oooooooooo08Wooooo2Ol000000ooo
oooo0000o`00000Po`0009;ooooo000Nooooo`03o`000?oooooooooo08Wooooo7_l000000ooooooo
0000o`00000;o`0009;ooooo000Nooooo`03o`000?oooooooooo08Wooooo1?l000000ooooooo0000
o`00000?o`000003ooooool0003o000000;o00000_ooool>o`0009?ooooo000Nooooo`;o0000R_oo
oolLo`000003ooooool0003o000000;o000000?oooooo`000?l000002?l0002Booooo`007_ooool0
0ol0003oooooooooo`29oooooa3o00000_oooolJo`0009;ooooo000Nooooo`03o`000?oooooooooo
08Wooooo1ol000000ooooooo0000o`00000Ho`000003ooooool0003o000000Oo0000T_ooool001ko
oooo00?o0000ooooooooool0ROooool4o`0000;ooooo3?l00003oooooaOo0000T_ooool001kooooo
00?o0000ooooooooool0Roooool>o`0000;ooooo4ol000000ooooooo0000o`000004o`0009;ooooo
000Nooooo`03o`000?oooooooooo08_ooooo8ol000000ooooooo0000o`000004o`0009;ooooo000N
ooooo`03o`000?oooooooooo08_ooooo9?l00003ooooo`;o0000Toooool001kooooo00?o0000oooo
ooooool0RooooolOo`000003ooooool0003o000000Oo0000Toooool001kooooo00?o0000oooooooo
ool0RooooolHo`000003ooooool0003o000000;o000000Coooooo`000?l0003ooooo2?l0002Coooo
o`007_ooool00ol0003oooooooooo`2;oooooaco00000_ooool:o`0009Cooooo000Nooooo`03o`00
0?oooooooooo08cooooo1ol000000ooooooo0000o`00000@o`0000?ooooo2_l0002Dooooo`007_oo
ool00ol0003oooooooooo`2<ooooo`Oo000000Coooooo`000?l0003o00000oooool4o`0000;ooooo
1_l00004ooooo`Wo0000U?ooool001kooooo00?o0000ooooooooool0SOooool5o`000003ooooool0
003o000000_o000000?oooooo`000?l000000ol00002ooooo`_o0000U?ooool001kooooo00?o0000
ooooooooool0S_ooool3o`0000;ooooo2?l000000ooooooo0000o`00000Do`0009Gooooo000Noooo
o`03o`000?oooooooooo08kooooo0_l00003ooooo`Ko000000?oooooo`000?l000000ol000000ooo
oooo0000o`00000@o`0009Gooooo000Nooooo`03o`000?oooooooooo097ooooo2ol00002oooooa;o
0000Uoooool001kooooo0_l0002Booooo`_o00000_oooolAo`0009Sooooo000Nooooo`03o`000?oo
oooooooo09?ooooo2Ol00002oooooa7o0000V?ooool001kooooo00?o0000ooooooooool0TooooolH
o`000003ooooool0003o000009Wooooo000Nooooo`03o`000?oooooooooo09?ooooo5Ol000000ooo
oooo0000o`00002Looooo`007_ooool00ol0003oooooooooo`2Iooooo`oo0000Woooool001kooooo
00?o0000ooooooooool0V_ooool=o`000:3ooooo000Nooooo`03o`000?oooooooooo09gooooo1Ol0
002Uooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006
ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0oooo
oom8ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooooooooooo
o`000006ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo
00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0
003oooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool00omE
EEGoQhN7ooooo`08ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0oooooom8oooo
o`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000oooooom8ooooo`000oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<
c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05oa0@
4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000oooo
ooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000
oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Dooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3oooooodSo
oooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom8ooooo`005_oo
ool00ol0003oooooooooo`05ooooo`?o0000oooooom8ooooo`005_ooool00ol0003oooooooooo`3o
oooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000oooooooo
ool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Dooooo`03oeEEEOmV
IVKo00000?ooooooD_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.47214 .43725 Mdot
.46603 .53308 Mdot
.46224 .5653 Mdot
.46239 .52344 Mdot
.45169 .49126 Mdot
.50318 .42635 Mdot
.44771 .55857 Mdot
.446 .46855 Mdot
.56641 .54052 Mdot
.53599 .45772 Mdot
.48611 .44638 Mdot
.51229 .51185 Mdot
.5014 .42239 Mdot
.42694 .50428 Mdot
.52836 .57438 Mdot
.54109 .46409 Mdot
.43711 .50118 Mdot
.54954 .44449 Mdot
.53827 .45239 Mdot
.53348 .53352 Mdot
.43472 .48491 Mdot
.5685 .49896 Mdot
.46632 .46438 Mdot
.4616 .43651 Mdot
.4462 .4612 Mdot
.51521 .50015 Mdot
.54048 .56238 Mdot
.53733 .44843 Mdot
.46162 .50341 Mdot
.48891 .42385 Mdot
.4558 .55278 Mdot
.44595 .51159 Mdot
.49151 .49007 Mdot
.50671 .5665 Mdot
.49561 .42272 Mdot
.4749 .56978 Mdot
.52075 .49471 Mdot
.55661 .54566 Mdot
.45707 .47382 Mdot
.52544 .50975 Mdot
.5233 .47888 Mdot
.54678 .52382 Mdot
.47481 .55414 Mdot
.48919 .50532 Mdot
.44048 .5019 Mdot
.54511 .47678 Mdot
.42678 .50888 Mdot
.44745 .54547 Mdot
.46995 .5636 Mdot
.57449 .51241 Mdot
.45509 .48263 Mdot
.51053 .41658 Mdot
.46553 .50942 Mdot
.45064 .47674 Mdot
.54847 .45788 Mdot
.54699 .49419 Mdot
.5062 .53963 Mdot
.5059 .41328 Mdot
.44418 .50156 Mdot
.50411 .54511 Mdot
.56065 .47738 Mdot
.53475 .48529 Mdot
.51825 .55711 Mdot
.53758 .46645 Mdot
.46205 .48099 Mdot
.56911 .53872 Mdot
.44159 .52614 Mdot
.55197 .48182 Mdot
.54478 .51381 Mdot
.54633 .46136 Mdot
.48342 .57872 Mdot
.44937 .50288 Mdot
.51548 .53681 Mdot
.4837 .52059 Mdot
.4787 .42677 Mdot
.52229 .56966 Mdot
.5553 .50132 Mdot
.53989 .44143 Mdot
.47374 .57583 Mdot
.49374 .45946 Mdot
.55177 .54297 Mdot
.44816 .46357 Mdot
.43834 .47146 Mdot
.52899 .47981 Mdot
.51458 .56059 Mdot
.47637 .51709 Mdot
.50638 .57262 Mdot
.54536 .48472 Mdot
.52521 .51445 Mdot
.52751 .43071 Mdot
.46437 .49635 Mdot
.54703 .47029 Mdot
.53357 .55807 Mdot
.57295 .52928 Mdot
.45768 .56519 Mdot
.56512 .49063 Mdot
.54799 .48737 Mdot
.4488 .54376 Mdot
.42714 .51235 Mdot
.49767 .54298 Mdot
.51415 .5696 Mdot
.53065 .55762 Mdot
.44383 .49028 Mdot
.57348 .50354 Mdot
.55978 .55091 Mdot
.4975 .49087 Mdot
.42115 .49807 Mdot
.46081 .48714 Mdot
.45329 .53928 Mdot
.54834 .46893 Mdot
.45753 .44257 Mdot
.44999 .50489 Mdot
.49619 .52906 Mdot
.568 .52899 Mdot
.43097 .50098 Mdot
.51617 .41873 Mdot
.54926 .55671 Mdot
.55108 .4489 Mdot
.4497 .55414 Mdot
.53732 .55613 Mdot
.5052 .44912 Mdot
.50656 .50219 Mdot
.53989 .45667 Mdot
.46231 .55893 Mdot
.44715 .51922 Mdot
.57065 .51548 Mdot
.46559 .4354 Mdot
.50907 .50076 Mdot
.49525 .50224 Mdot
.52552 .47406 Mdot
.49719 .45414 Mdot
.43368 .49671 Mdot
.46932 .42604 Mdot
.49303 .56604 Mdot
.46589 .45568 Mdot
.45621 .43542 Mdot
.57054 .49363 Mdot
.47657 .50256 Mdot
.52944 .52489 Mdot
.49707 .51891 Mdot
.46168 .49097 Mdot
.55877 .5506 Mdot
.49511 .49672 Mdot
.46139 .51726 Mdot
.48254 .48363 Mdot
.55229 .46873 Mdot
.47755 .43249 Mdot
.56495 .50031 Mdot
.42989 .49822 Mdot
.46867 .56165 Mdot
.50872 .5609 Mdot
.53879 .4475 Mdot
.45778 .49399 Mdot
.42693 .49563 Mdot
.49315 .45128 Mdot
.54227 .46333 Mdot
.52875 .48601 Mdot
.47951 .42303 Mdot
.55457 .50242 Mdot
.4727 .484 Mdot
.50676 .57817 Mdot
.55172 .51263 Mdot
.51561 .44302 Mdot
.56011 .46108 Mdot
.51855 .52408 Mdot
.50601 .52931 Mdot
.55293 .5585 Mdot
.55698 .53007 Mdot
.56444 .50859 Mdot
.56348 .53516 Mdot
.51181 .46049 Mdot
.47181 .56073 Mdot
.47079 .53997 Mdot
.52112 .52347 Mdot
.48958 .57924 Mdot
.5373 .49163 Mdot
.56665 .49082 Mdot
.47005 .4817 Mdot
.42771 .47106 Mdot
.4912 .56325 Mdot
.46527 .52317 Mdot
.56535 .48533 Mdot
.48335 .51325 Mdot
.46395 .50904 Mdot
.5074 .42057 Mdot
.50814 .5148 Mdot
.48754 .57456 Mdot
.56259 .47994 Mdot
.57332 .52634 Mdot
.53036 .56223 Mdot
.49487 .51224 Mdot
.49371 .47713 Mdot
.45182 .44513 Mdot
.45875 .49151 Mdot
.56069 .53974 Mdot
.51094 .48246 Mdot
.57575 .51743 Mdot
.49016 .49607 Mdot
.46711 .47589 Mdot
.47064 .53063 Mdot
.49092 .54372 Mdot
.55682 .48333 Mdot
.50358 .45236 Mdot
.55667 .52202 Mdot
.53787 .46183 Mdot
.47416 .54292 Mdot
.43419 .47424 Mdot
.49559 .54702 Mdot
.48956 .5723 Mdot
.45678 .4898 Mdot
.43919 .49979 Mdot
.51093 .49571 Mdot
.53586 .51175 Mdot
.50426 .44037 Mdot
.50687 .5025 Mdot
.42489 .49764 Mdot
.54932 .47204 Mdot
.5516 .50413 Mdot
.55989 .54896 Mdot
.46476 .4875 Mdot
.48179 .47103 Mdot
.49327 .41548 Mdot
.55118 .46942 Mdot
.43449 .46016 Mdot
.47779 .44838 Mdot
.45865 .45611 Mdot
.44966 .51297 Mdot
.54658 .45397 Mdot
.48188 .57381 Mdot
.48681 .45802 Mdot
.56747 .47411 Mdot
.50667 .49649 Mdot
.56399 .53922 Mdot
.52039 .49009 Mdot
.53081 .49681 Mdot
.52776 .52709 Mdot
.56885 .52491 Mdot
.51388 .57322 Mdot
.44933 .5266 Mdot
.50833 .51476 Mdot
.5452 .45399 Mdot
.52796 .5734 Mdot
.47272 .43333 Mdot
.57045 .5198 Mdot
.44575 .55421 Mdot
.55136 .45838 Mdot
.52313 .57022 Mdot
.45173 .46193 Mdot
.56249 .46245 Mdot
.54772 .55963 Mdot
.47933 .55357 Mdot
.51198 .42066 Mdot
.53757 .56817 Mdot
.45196 .56052 Mdot
.49374 .5261 Mdot
.51293 .51969 Mdot
.47912 .46438 Mdot
.54411 .50483 Mdot
.51356 .56232 Mdot
.54645 .5637 Mdot
.555 .53158 Mdot
.50416 .48074 Mdot
.47345 .48405 Mdot
.49894 .4476 Mdot
.52481 .54491 Mdot
.52501 .55042 Mdot
.4832 .45793 Mdot
.51864 .45283 Mdot
.50476 .4845 Mdot
.42908 .46641 Mdot
.45189 .53939 Mdot
.49678 .52894 Mdot
.57222 .53001 Mdot
.49854 .52296 Mdot
.47205 .57125 Mdot
.50962 .57587 Mdot
.55336 .49472 Mdot
.53214 .45668 Mdot
.535 .5294 Mdot
.51169 .47049 Mdot
.53628 .51965 Mdot
.52912 .50067 Mdot
.43545 .52993 Mdot
.48033 .49148 Mdot
.55789 .54717 Mdot
.57444 .52473 Mdot
.42398 .48279 Mdot
.47689 .46561 Mdot
.45578 .53132 Mdot
.42661 .48836 Mdot
.51715 .52075 Mdot
.42912 .50128 Mdot
.52039 .42018 Mdot
.47787 .55706 Mdot
.50559 .52968 Mdot
.44807 .47764 Mdot
.52536 .45323 Mdot
.50032 .56122 Mdot
.54656 .52725 Mdot
.45983 .52081 Mdot
.48459 .50074 Mdot
.46058 .455 Mdot
.56156 .55002 Mdot
.55697 .46313 Mdot
.51564 .51593 Mdot
.46087 .52103 Mdot
.44275 .44635 Mdot
.43804 .45972 Mdot
.44821 .45868 Mdot
.52117 .54772 Mdot
.4751 .52666 Mdot
.48314 .49075 Mdot
.48695 .46447 Mdot
.46934 .44316 Mdot
.47688 .53471 Mdot
.42843 .4835 Mdot
.52691 .50852 Mdot
.54939 .48268 Mdot
.5201 .53137 Mdot
.55934 .54042 Mdot
.48553 .56279 Mdot
.48541 .44299 Mdot
.48743 .44132 Mdot
.54175 .49205 Mdot
.52046 .45921 Mdot
.56807 .52152 Mdot
.49282 .50941 Mdot
.49694 .50286 Mdot
.57162 .52243 Mdot
.54155 .54593 Mdot
.47915 .43027 Mdot
.50722 .41812 Mdot
.49766 .52969 Mdot
.53381 .4584 Mdot
.48787 .57171 Mdot
.49409 .47245 Mdot
.50668 .56122 Mdot
.45479 .51276 Mdot
.47992 .44163 Mdot
.53748 .48566 Mdot
.44267 .52911 Mdot
.43318 .46939 Mdot
.42782 .52737 Mdot
.49368 .49492 Mdot
.56769 .51095 Mdot
.43401 .50964 Mdot
.4792 .49285 Mdot
.44505 .47696 Mdot
.55531 .53303 Mdot
.52959 .47941 Mdot
.51251 .53065 Mdot
.47334 .42418 Mdot
.43661 .4951 Mdot
.52349 .4916 Mdot
.5174 .42541 Mdot
.50984 .52821 Mdot
.42684 .47663 Mdot
.43793 .51233 Mdot
.52569 .42387 Mdot
.4962 .48958 Mdot
.46385 .47742 Mdot
.42867 .48084 Mdot
.50382 .52783 Mdot
.42868 .47399 Mdot
.43745 .51315 Mdot
.43605 .53322 Mdot
.43672 .54281 Mdot
.55938 .52634 Mdot
.42709 .46914 Mdot
.47635 .51519 Mdot
.47177 .48396 Mdot
.47253 .49972 Mdot
.48279 .41904 Mdot
.48277 .45015 Mdot
.45573 .55985 Mdot
.53651 .46029 Mdot
.48405 .45444 Mdot
.51137 .57248 Mdot
.54405 .52432 Mdot
.51527 .49666 Mdot
.50985 .55769 Mdot
.461 .5681 Mdot
.45579 .50791 Mdot
.45027 .44324 Mdot
.44752 .50925 Mdot
.49853 .43124 Mdot
.53816 .44799 Mdot
.48891 .47 Mdot
.54242 .49655 Mdot
.50822 .55775 Mdot
.45122 .43886 Mdot
.54306 .52212 Mdot
.4914 .56221 Mdot
.44511 .51007 Mdot
.4694 .46643 Mdot
.44196 .47664 Mdot
.56352 .46747 Mdot
.48691 .48938 Mdot
.52312 .4575 Mdot
.44625 .44399 Mdot
.4378 .45332 Mdot
.50073 .56318 Mdot
.46257 .42752 Mdot
.52769 .50163 Mdot
.49813 .5598 Mdot
.47464 .56855 Mdot
.46297 .5106 Mdot
.46772 .48581 Mdot
.48659 .54769 Mdot
.50018 .46176 Mdot
.49942 .51665 Mdot
.52029 .46421 Mdot
.48239 .51855 Mdot
.45047 .54926 Mdot
.478 .51295 Mdot
.52858 .56 Mdot
.54965 .46616 Mdot
.44303 .45342 Mdot
.49028 .55525 Mdot
.54516 .45499 Mdot
.50498 .46842 Mdot
.54785 .47718 Mdot
.48468 .51366 Mdot
.52763 .46211 Mdot
.48695 .41487 Mdot
.4946 .56701 Mdot
.54112 .56965 Mdot
.51244 .48399 Mdot
.53315 .5256 Mdot
.53624 .5095 Mdot
.42869 .4771 Mdot
.54652 .4615 Mdot
.43494 .47089 Mdot
.50204 .46723 Mdot
.56347 .51326 Mdot
.45201 .44401 Mdot
.56504 .50896 Mdot
.50713 .53953 Mdot
.43209 .46912 Mdot
.51963 .52464 Mdot
.47153 .55807 Mdot
.53818 .4311 Mdot
.42733 .4947 Mdot
.49714 .44784 Mdot
.4977 .49042 Mdot
.50513 .45693 Mdot
.45144 .49878 Mdot
.5354 .46448 Mdot
.50034 .56878 Mdot
.46312 .49843 Mdot
.43439 .53273 Mdot
.50485 .5169 Mdot
.52782 .478 Mdot
.524 .52077 Mdot
.52944 .55394 Mdot
.56757 .53496 Mdot
.50901 .56022 Mdot
.55668 .5432 Mdot
.47072 .49027 Mdot
.54029 .50721 Mdot
.55189 .52561 Mdot
.48486 .52499 Mdot
.44558 .54522 Mdot
.51653 .4906 Mdot
.48782 .56059 Mdot
.43392 .45927 Mdot
.51567 .48678 Mdot
.48827 .51449 Mdot
.4343 .51588 Mdot
.5449 .50695 Mdot
.48348 .43688 Mdot
.5042 .47389 Mdot
.43014 .53958 Mdot
.51537 .58024 Mdot
.52156 .46039 Mdot
.56604 .53986 Mdot
.46031 .56038 Mdot
.51499 .58081 Mdot
.51314 .57055 Mdot
.4629 .43062 Mdot
.48555 .49159 Mdot
.43686 .49513 Mdot
.45041 .46178 Mdot
.44133 .4921 Mdot
.5506 .47661 Mdot
.55381 .52271 Mdot
.52889 .46224 Mdot
.47246 .4363 Mdot
.47801 .56172 Mdot
.51241 .57217 Mdot
.52916 .42237 Mdot
.48622 .57368 Mdot
.57088 .5299 Mdot
.46723 .47835 Mdot
.48804 .55151 Mdot
.51787 .42397 Mdot
.55916 .54816 Mdot
.47061 .47819 Mdot
.55169 .52243 Mdot
.45916 .45389 Mdot
.4227 .50767 Mdot
.53854 .56892 Mdot
.43354 .54381 Mdot
.49224 .47359 Mdot
.50805 .51615 Mdot
.55643 .45398 Mdot
.44996 .45265 Mdot
.52005 .47201 Mdot
.48618 .57702 Mdot
.5754 .51836 Mdot
.54296 .52193 Mdot
.51171 .56123 Mdot
.47679 .55224 Mdot
.50952 .42547 Mdot
.46156 .45361 Mdot
.5451 .46337 Mdot
.47955 .55249 Mdot
.49688 .42321 Mdot
.43406 .53079 Mdot
.47388 .44123 Mdot
.56213 .46163 Mdot
.44679 .53291 Mdot
.46414 .44861 Mdot
.51977 .49846 Mdot
.51025 .52386 Mdot
.54811 .48881 Mdot
.48829 .56523 Mdot
.51594 .4167 Mdot
.50279 .4588 Mdot
.51802 .46346 Mdot
.53826 .53966 Mdot
.55271 .46868 Mdot
.55215 .49574 Mdot
.48633 .52532 Mdot
.57382 .52382 Mdot
.50685 .51003 Mdot
.46619 .43121 Mdot
.55248 .47993 Mdot
.50009 .54531 Mdot
.54573 .45113 Mdot
.49553 .52607 Mdot
.52297 .4389 Mdot
.55321 .4661 Mdot
.4573 .43778 Mdot
.4953 .4556 Mdot
.53429 .56563 Mdot
.45919 .51126 Mdot
.53394 .43672 Mdot
.44694 .49866 Mdot
.4938 .46496 Mdot
.52393 .5142 Mdot
.45632 .46417 Mdot
.48594 .4867 Mdot
.42237 .49431 Mdot
.45018 .50882 Mdot
.48374 .47332 Mdot
.46711 .49357 Mdot
.50263 .55516 Mdot
.52731 .42247 Mdot
.54299 .5569 Mdot
.53623 .55248 Mdot
.5101 .56686 Mdot
.5349 .46333 Mdot
.47096 .51133 Mdot
.53844 .53188 Mdot
.47969 .46429 Mdot
.44345 .55413 Mdot
.50677 .47067 Mdot
.45469 .43932 Mdot
.46235 .56096 Mdot
.42929 .46598 Mdot
.50902 .49837 Mdot
.4948 .55669 Mdot
.44457 .48787 Mdot
.50488 .51532 Mdot
.53481 .47145 Mdot
.53132 .43445 Mdot
.52454 .51286 Mdot
.51536 .57194 Mdot
.51356 .50599 Mdot
.4781 .57435 Mdot
.4502 .50269 Mdot
.42635 .52479 Mdot
.48437 .54626 Mdot
.5522 .5101 Mdot
.42432 .49242 Mdot
.46081 .45746 Mdot
.44322 .52582 Mdot
.43 .48156 Mdot
.52426 .55289 Mdot
.51024 .51573 Mdot
.53906 .47766 Mdot
.46906 .47435 Mdot
.49798 .50913 Mdot
.5312 .46786 Mdot
.47751 .43097 Mdot
.44838 .44696 Mdot
.56649 .48708 Mdot
.51564 .44351 Mdot
.47184 .53766 Mdot
.55927 .52187 Mdot
.56581 .47281 Mdot
.47686 .43717 Mdot
.51371 .43094 Mdot
.5394 .4766 Mdot
.45801 .54567 Mdot
.50807 .47697 Mdot
.43767 .54223 Mdot
.53382 .4861 Mdot
.4982 .50428 Mdot
.55323 .44911 Mdot
.45931 .4437 Mdot
.47604 .46152 Mdot
.42499 .50166 Mdot
.47133 .43627 Mdot
.45656 .4974 Mdot
.46155 .47244 Mdot
.55076 .45682 Mdot
.46202 .48187 Mdot
.50422 .5799 Mdot
.45184 .56295 Mdot
.51131 .41569 Mdot
.48949 .5298 Mdot
.52893 .48635 Mdot
.43835 .54528 Mdot
.51322 .55491 Mdot
.46016 .49564 Mdot
.47075 .49472 Mdot
.45208 .43922 Mdot
.45854 .53319 Mdot
.55705 .47809 Mdot
.54086 .46222 Mdot
.46581 .56149 Mdot
.53001 .43796 Mdot
.52533 .43717 Mdot
.48096 .44284 Mdot
.52251 .56815 Mdot
.49162 .51525 Mdot
.44377 .49664 Mdot
.42399 .48254 Mdot
.44831 .46812 Mdot
.55512 .49863 Mdot
.43536 .53986 Mdot
.51014 .48516 Mdot
.5229 .47426 Mdot
.50859 .43735 Mdot
.51556 .42682 Mdot
.50643 .4901 Mdot
.44825 .55918 Mdot
.46303 .57014 Mdot
.46835 .44618 Mdot
.48321 .48613 Mdot
.50259 .49423 Mdot
.45387 .53987 Mdot
.49712 .53539 Mdot
.47962 .5546 Mdot
.56484 .54829 Mdot
.49281 .51353 Mdot
.53673 .53744 Mdot
.49993 .50861 Mdot
.44617 .49821 Mdot
.48859 .48552 Mdot
.42959 .47182 Mdot
.503 .4124 Mdot
.42455 .51127 Mdot
.50947 .56093 Mdot
.56418 .52322 Mdot
.44957 .43897 Mdot
.46337 .43929 Mdot
.54235 .57188 Mdot
.46095 .53274 Mdot
.48796 .41523 Mdot
.43883 .45177 Mdot
.56729 .47908 Mdot
.5135 .47749 Mdot
.5633 .46082 Mdot
.52091 .53606 Mdot
.44109 .50197 Mdot
.53361 .4483 Mdot
.44825 .47471 Mdot
.56317 .47849 Mdot
.53782 .55132 Mdot
.46139 .54141 Mdot
.54312 .55008 Mdot
.44018 .50527 Mdot
.55893 .48494 Mdot
.45129 .52404 Mdot
.51051 .42114 Mdot
.52716 .52068 Mdot
.5276 .53517 Mdot
.56181 .49759 Mdot
.47042 .56831 Mdot
.50573 .41543 Mdot
.53653 .496 Mdot
.50278 .55845 Mdot
.4438 .45881 Mdot
.42141 .49902 Mdot
.48771 .50079 Mdot
.54669 .46846 Mdot
.4575 .51784 Mdot
.4658 .45863 Mdot
.50805 .50915 Mdot
.43663 .53047 Mdot
.46149 .48146 Mdot
.44301 .54829 Mdot
.46714 .57281 Mdot
.54519 .48847 Mdot
.45484 .48623 Mdot
.51978 .55914 Mdot
.52731 .46217 Mdot
.57292 .51773 Mdot
.49795 .50615 Mdot
.51607 .56482 Mdot
.56433 .4605 Mdot
.42633 .48317 Mdot
.53979 .56233 Mdot
.56679 .46543 Mdot
.43666 .46721 Mdot
.49945 .42786 Mdot
.52847 .45 Mdot
.4743 .51899 Mdot
.50464 .46288 Mdot
.52813 .52961 Mdot
.48164 .52469 Mdot
.4548 .4479 Mdot
.50866 .5331 Mdot
.54417 .4386 Mdot
.5058 .43903 Mdot
.4658 .43144 Mdot
.56172 .49358 Mdot
.49242 .45026 Mdot
.53148 .47684 Mdot
.51211 .52818 Mdot
.52219 .48595 Mdot
.51965 .41805 Mdot
.45733 .56728 Mdot
.53192 .49472 Mdot
.56799 .4945 Mdot
.52878 .45828 Mdot
.54884 .50317 Mdot
.54588 .47497 Mdot
.50044 .4196 Mdot
.53406 .49835 Mdot
.46763 .4485 Mdot
.48177 .47672 Mdot
.45121 .48321 Mdot
.46657 .47939 Mdot
.54305 .48548 Mdot
.49504 .50105 Mdot
.48508 .43362 Mdot
.48089 .56656 Mdot
.47361 .48864 Mdot
.51239 .53486 Mdot
.45153 .48656 Mdot
.56843 .48038 Mdot
.4375 .45733 Mdot
.55753 .55211 Mdot
.53806 .45866 Mdot
.45622 .55249 Mdot
.49724 .46826 Mdot
.49506 .42578 Mdot
.49948 .43013 Mdot
.5203 .58009 Mdot
.54984 .51727 Mdot
.54068 .43735 Mdot
.48941 .52427 Mdot
.45272 .44024 Mdot
.46022 .51151 Mdot
.49207 .50649 Mdot
.46987 .56717 Mdot
.49604 .44195 Mdot
.45057 .54677 Mdot
.49148 .42263 Mdot
.47516 .51266 Mdot
.48083 .57095 Mdot
.54221 .55576 Mdot
.53783 .57278 Mdot
.45915 .4514 Mdot
.48899 .518 Mdot
.54224 .51012 Mdot
.49982 .47729 Mdot
.43618 .51436 Mdot
.49557 .42408 Mdot
.53176 .4254 Mdot
.48465 .41558 Mdot
.50612 .57693 Mdot
.48889 .53947 Mdot
.52213 .47763 Mdot
.52255 .45663 Mdot
.55821 .51354 Mdot
.47499 .53344 Mdot
.50815 .45108 Mdot
.47145 .52323 Mdot
.55555 .54529 Mdot
.45644 .54197 Mdot
.56801 .51492 Mdot
.45628 .5453 Mdot
.42223 .4915 Mdot
.53271 .46581 Mdot
.42997 .52717 Mdot
.50717 .48121 Mdot
.49964 .54435 Mdot
.49264 .5762 Mdot
.53745 .57506 Mdot
.4703 .4389 Mdot
.53187 .46896 Mdot
.51693 .52457 Mdot
.4579 .45461 Mdot
.43719 .49038 Mdot
.53282 .44444 Mdot
.4603 .51263 Mdot
.53489 .56507 Mdot
.46816 .51978 Mdot
.48806 .43602 Mdot
.53461 .46368 Mdot
.4775 .55475 Mdot
.56354 .48686 Mdot
.50515 .53833 Mdot
.45208 .45386 Mdot
.46212 .55829 Mdot
.5126 .48779 Mdot
.4914 .52784 Mdot
.50583 .57722 Mdot
.53126 .45692 Mdot
.45713 .45009 Mdot
.55834 .45398 Mdot
.46344 .47882 Mdot
.4546 .53231 Mdot
.45748 .54191 Mdot
.53566 .4982 Mdot
.42359 .50577 Mdot
.44382 .53117 Mdot
.44269 .54714 Mdot
.54682 .47992 Mdot
.50365 .49648 Mdot
.51288 .47766 Mdot
.54345 .52718 Mdot
.49429 .45896 Mdot
.48602 .53054 Mdot
.55823 .54534 Mdot
.46943 .43832 Mdot
.54612 .47406 Mdot
.56499 .48693 Mdot
.49281 .57901 Mdot
.46933 .57353 Mdot
.53414 .54841 Mdot
.54393 .57108 Mdot
.5404 .5306 Mdot
.55033 .47371 Mdot
.51768 .53482 Mdot
.44831 .52284 Mdot
.51287 .43662 Mdot
.42648 .50589 Mdot
.43995 .45003 Mdot
.48549 .57969 Mdot
.5046 .51709 Mdot
.49915 .48625 Mdot
.51084 .42721 Mdot
.48669 .51462 Mdot
.45952 .48902 Mdot
.5222 .55954 Mdot
.50514 .51743 Mdot
.48248 .48958 Mdot
.54377 .5505 Mdot
.51949 .45541 Mdot
.50348 .57012 Mdot
.47917 .54172 Mdot
.53635 .4456 Mdot
.47121 .53483 Mdot
.51939 .41558 Mdot
.5081 .45391 Mdot
.5591 .54406 Mdot
.44773 .54945 Mdot
.47827 .43045 Mdot
.44366 .45807 Mdot
.47644 .51428 Mdot
.45287 .47288 Mdot
.54399 .47205 Mdot
.52333 .51489 Mdot
.51571 .41684 Mdot
.42512 .51319 Mdot
.48098 .42014 Mdot
.43184 .50691 Mdot
.46672 .50558 Mdot
.54347 .43656 Mdot
.44217 .49883 Mdot
.52939 .51661 Mdot
.53595 .46964 Mdot
.50319 .57606 Mdot
.47965 .42168 Mdot
.56097 .50145 Mdot
.49771 .49397 Mdot
.49373 .57542 Mdot
.49767 .46643 Mdot
.47235 .47855 Mdot
.5744 .51767 Mdot
.45566 .49989 Mdot
.4611 .54558 Mdot
.50002 .5255 Mdot
.49556 .53277 Mdot
.49298 .44571 Mdot
.49132 .54364 Mdot
.43126 .48879 Mdot
.47501 .53557 Mdot
.57185 .51201 Mdot
.47262 .51813 Mdot
.50544 .57529 Mdot
.52542 .52758 Mdot
.44833 .47638 Mdot
.42888 .49645 Mdot
.53341 .54363 Mdot
.55468 .52786 Mdot
.50519 .52114 Mdot
.46242 .47048 Mdot
.4505 .52078 Mdot
.51477 .50835 Mdot
.53043 .55527 Mdot
.43083 .53713 Mdot
.46137 .43921 Mdot
.54867 .55413 Mdot
.53443 .48003 Mdot
.49024 .50238 Mdot
.42517 .4814 Mdot
.53647 .54672 Mdot
.54114 .56737 Mdot
.47898 .52454 Mdot
.44868 .4795 Mdot
.51668 .51484 Mdot
.55344 .56154 Mdot
.46732 .51396 Mdot
.49113 .53965 Mdot
.54871 .52433 Mdot
.5665 .54246 Mdot
.44683 .52275 Mdot
.4875 .51253 Mdot
.57578 .5162 Mdot
.53152 .48608 Mdot
.42335 .50077 Mdot
.54344 .56193 Mdot
.51539 .57482 Mdot
.48913 .41932 Mdot
.44761 .4598 Mdot
.47923 .56285 Mdot
.47639 .52282 Mdot
.55985 .48683 Mdot
.46943 .43606 Mdot
.44429 .53557 Mdot
.44018 .53515 Mdot
.4933 .55562 Mdot
.45058 .44346 Mdot
.5412 .44795 Mdot
.49798 .52084 Mdot
.54466 .44077 Mdot
.45155 .53094 Mdot
.4688 .52553 Mdot
.52035 .45289 Mdot
.52551 .56184 Mdot
.54831 .46455 Mdot
.42368 .48762 Mdot
.50287 .58063 Mdot
.54941 .53504 Mdot
.47941 .51247 Mdot
.56842 .49387 Mdot
.50794 .4951 Mdot
.51081 .48813 Mdot
.47195 .55739 Mdot
.48034 .57444 Mdot
.48915 .543 Mdot
.53229 .47552 Mdot
.54503 .55265 Mdot
.53136 .54193 Mdot
.44959 .45064 Mdot
.51385 .41784 Mdot
.56044 .52552 Mdot
.42742 .46794 Mdot
.54781 .46168 Mdot
.42267 .51195 Mdot
.48176 .51224 Mdot
.52364 .50172 Mdot
.54618 .44337 Mdot
.53689 .43211 Mdot
.4669 .48758 Mdot
.44217 .48831 Mdot
.46807 .45146 Mdot
.43064 .5087 Mdot
.44765 .55185 Mdot
.45113 .45123 Mdot
.48998 .53423 Mdot
.55482 .46327 Mdot
.49042 .46977 Mdot
.47245 .43712 Mdot
.46318 .47184 Mdot
.43775 .46071 Mdot
.51375 .47063 Mdot
.52971 .46587 Mdot
.55957 .48428 Mdot
.53328 .56213 Mdot
.4659 .56937 Mdot
.48478 .57908 Mdot
.53535 .43678 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go
00001_ooool3o`000?ooooooB?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04
odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol0003o
oooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`3o
ooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007
ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<
ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0Woooool3o`000:Gooooo0003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooo
oooo09Wooooo1Ol000000ooooooo0000o`000003o`000003ooooool0003o00000:3ooooo000Noooo
o`03o`000?oooooooooo09Wooooo1Ol000000ooooooo0000o`000006o`000:3ooooo000Nooooo`03
o`000?oooooooooo09Sooooo4_l0002Mooooo`007_ooool00ol0003oooooooooo`2Fooooo`Co0000
00?oooooo`000?l000003_l0002Looooo`007_ooool00ol0003oooooooooo`2Booooo`So000000?o
ooooo`000?l000001?l000000ooooooo0000o`000002o`000003ooooool0003o000000;o0000W?oo
ool001kooooo00?o0000ooooooooool0T_ooool4o`000004ooooool0003o0000o`0000Cooooo0ol0
00001?oooooo0000o`000?l00002ooooo`;o00000_ooool2o`0009[ooooo000Nooooo`03o`000?oo
oooooooo09;ooooo0ol000000ooooooo0000o`000004o`0000;ooooo0_l00003ooooo`;o00000_oo
ool6o`0009[ooooo000Nooooo`03o`000?oooooooooo093ooooo3Ol00004ooooo`Co00000_ooool8
o`0009Sooooo000Nooooo`03o`000?oooooooooo08kooooo3ol00003ooooo`Go000000?oooooo`00
0?l000001ol0002Hooooo`007_ooool00ol0003oooooooooo`2=ooooo`oo000000Coooooo`000?l0
003ooooo0_l00002ooooo`Co00000oooool4o`0009Sooooo000Nooooo`03o`000?oooooooooo08co
oooo1ol000000ooooooo0000o`000002ooooo`Oo00001Oooool2o`0000?ooooo2?l0002Fooooo`00
7_ooool00ol0003oooooooooo`2;ooooo`_o000000?oooooo`000?l000002Ol00006ooooo`Ko0000
00Coooooo`000?l0003o0000UOooool001kooooo0_l0002;ooooo`co000000?oooooo`000?l00000
0_l000000ooooooo0000o`000005o`0000;ooooo3Ol0002Eooooo`007_ooool00ol0003ooooooooo
o`2:ooooo`co00000oooool2o`000003ooooool0003o000000Go00000_ooool4o`0000;ooooo1Ol0
00000ooooooo0000o`00002Dooooo`007_ooool00ol0003oooooooooo`29ooooo`co00001?ooool:
o`0000;ooooo3_l0002Dooooo`007_ooool00ol0003oooooooooo`29ooooo`So000000Coooooo`00
0?l0003o00000_ooool=o`000003ooooool0003o000000[o000000Coooooo`000?l0003o0000T_oo
ool001kooooo00?o0000ooooooooool0ROooool3o`000003ooooool0003o000000?o000000?ooooo
o`000?l000000_oooolOo`00097ooooo000Nooooo`03o`000?oooooooooo08Oooooo0_l000001?oo
oooo0000o`000?ooool5o`000005ooooool0003o0000o`000?ooool02ol00002ooooo`?o000000?o
ooooo`000?l000003?l0002Aooooo`007_ooool00ol0003oooooooooo`27ooooo`Go000000Cooooo
o`000?l0003o00000_ooool4o`0000?ooooo1?l000000ooooooo0000o`000007o`0000;ooooo1?l0
00000ooooooo0000o`000002o`000003ooooool0003o000009;ooooo000Nooooo`03o`000?oooooo
oooo08Oooooo1Ol00002ooooo`So00000oooool6o`000003ooooool0003o000000[o000000?ooooo
o`000?l000000_l00003ooooo`;o0000TOooool001kooooo00?o0000ooooooooool0Qoooool4o`00
0003ooooool0003o000000So00000oooool2o`000003ooooool0003o000000Oo000000?oooooo`00
0?l000003_l0002Aooooo`007_ooool00ol0003oooooooooo`27ooooo`;o00000oooool4o`0000;o
oooo1Ol00002ooooo`;o000000?oooooo`000?l000001ol000000ooooooo0000o`00000?o`00093o
oooo000Nooooo`03o`000?oooooooooo08Kooooo1?l00004ooooo`[o000000?oooooo`000?l00000
1Oooool4o`0000;ooooo1_l00002ooooo`Wo0000T?ooool001kooooo00?o0000ooooooooool0Q_oo
ool5o`0000Cooooo2Ol000000ooooooo0000o`000002o`000003ooooool0003o000001Ko0000TOoo
ool001kooooo00?o0000ooooooooool0Q_ooool8o`000003ooooool0003o000000Oo000000?ooooo
o`000?l000005Ol00002ooooo`Co0000TOooool001kooooo00?o0000ooooooooool0QOooool9o`00
0003ooooool0003o000000oo000000?oooooo`000?l000001Ol00003ooooo`Go00001?ooool2o`00
097ooooo000Nooooo`03o`000?oooooooooo08Gooooo1?l000001?oooooo0000o`000?l00002oooo
o`So000000?oooooo`000?l000003_l000000ooooooo0000o`000007o`000003ooooool0003o0000
00;o0000T?ooool001kooooo00?o0000ooooooooool0QOoooolBo`0000Cooooo3?l000000ooooooo
0000o`000008o`000003ooooool0003o000000;o0000T?ooool001kooooo0_l00026ooooo`oo0000
0_ooool9o`0000;ooooo2ol00004ooooo`Oo0000T?ooool001kooooo00?o0000ooooooooool0Q_oo
oolJo`000003ooooool0003o000000;o000000?oooooo`000?l000000_l00003ooooo`_o0000Sooo
ool001kooooo00?o0000ooooooooool0QOooool5o`000004ooooool0003o0000ooooo`So00001Ooo
ool5o`0000?ooooo0_l00002ooooo`;o00000oooool5o`0000;ooooo0_l000000ooooooo0000o`00
002?ooooo`007_ooool00ol0003oooooooooo`25ooooo`Ko00000_ooool:o`0000Gooooo1?l00000
0ooooooo0000o`000002o`0000;ooooo0_l000000ooooooo0000o`000005o`0000;ooooo1Ol0002?
ooooo`007_ooool00ol0003oooooooooo`25ooooo`Oo000000?oooooo`000?l000004Ol000000ooo
oooo0000o`000006o`000003ooooool0003o000000go0000S_ooool001kooooo00?o0000oooooooo
ool0Q_ooool6o`0000;ooooo7?l00003ooooo`co0000S_ooool001kooooo00?o0000ooooooooool0
ROooool2o`0000;ooooo0ol000000ooooooo0000o`00000Io`0000?ooooo0_l00004ooooo`Co0000
S_ooool001kooooo00?o0000ooooooooool0SOoooolLo`000003ooooool0003o000000go0000S_oo
ool001kooooo00?o0000ooooooooool0Q_ooool4o`000003ooooool0003o000000Co000000?ooooo
o`000?l000003?l00002ooooo`Wo000000?oooooo`000?l000002ol0002>ooooo`007_ooool00ol0
003oooooooooo`26ooooo`[o00001?oooolHo`000003ooooool0003o000000Go000000?oooooo`00
0?l000000_l0002>ooooo`007_ooool00ol0003oooooooooo`29ooooo`oo00000_oooolDo`0000;o
oooo0ol00002ooooo`?o0000Soooool001kooooo00?o0000ooooooooool0ROooool@o`000003oooo
ool0003o000000Co000000?oooooo`000?l000002ol000001Ooooooo0000o`000?l0003ooooo00?o
0000TOooool001kooooo00?o0000ooooooooool0R?ooool2o`000005ooooool0003o0000o`000?oo
ool00_l00004ooooo`Co00000_ooool>o`000004ooooool0003o0000o`0000;ooooo0_l00002oooo
o`Co0000T?ooool001kooooo00?o0000ooooooooool0R?ooool4o`0000?ooooo1Ol000001?oooooo
0000o`000?ooool2o`000004ooooool0003o0000o`0000;ooooo1Ol00004ooooo`Co00001Oooool5
o`00093ooooo000Nooooo`03o`000?oooooooooo08Wooooo0ol000000ooooooo0000o`000005o`00
0003ooooool0003o000000?o000000?oooooo`000?l000001Ol00005ooooo`Co00001?ooool7o`00
097ooooo000Nooooo`03o`000?oooooooooo08Wooooo2ol00002ooooo`;o000000?oooooo`000?l0
00001ol00003ooooo`Wo000000?oooooo`000?l000001Ol0002Aooooo`007_ooool2o`0008gooooo
1?l00009ooooo`Ko00001_ooool4o`000003ooooool0003o000000?o00000_ooool5o`00097ooooo
000Nooooo`03o`000?oooooooooo08cooooo1_l00004ooooo`Co000000?oooooo`000?l000001_oo
ool2o`000003ooooool0003o000000So000000Coooooo`000?l0003o0000Toooool001kooooo00?o
0000ooooooooool0S?ooool6o`0000?ooooo1Ol000000ooooooo0000o`00000Co`000003ooooool0
003o000009Cooooo000Nooooo`03o`000?oooooooooo08gooooo1ol000000ooooooo0000o`000002
o`000003ooooool0003o000001Ko0000UOooool001kooooo00?o0000ooooooooool0SOoooolUo`00
09Gooooo000Nooooo`03o`000?oooooooooo08oooooo5ol000000ooooooo0000o`000009o`0009Go
oooo000Nooooo`03o`000?oooooooooo097ooooo2Ol000000ooooooo0000o`00000;o`0000;ooooo
1?l0002Iooooo`007_ooool00ol0003oooooooooo`2Booooo`_o00000_ooool6o`000003ooooool0
003o000000;o000000?oooooo`000?l000000_l0002Hooooo`007_ooool00ol0003oooooooooo`2D
ooooo`[o000000?oooooo`000?l000001?l00003ooooo`;o000000?oooooo`000?l000000_l0002H
ooooo`007_ooool00ol0003oooooooooo`2Fooooo`So000000?oooooo`000?l000001?l00003oooo
o`;o000000?oooooo`000?l00000V_ooool001kooooo00?o0000ooooooooool0VOooool5o`000003
ooooool0003o000000Ko0000X?ooool001kooooo00?o0000ooooooooool0V_ooool2o`0000?ooooo
0ol000000ooooooo0000o`000002o`000:3ooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003ooooooooo
o`3oooooodSooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
EEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go
410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?oo
ooooB?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRH
V?lQ8B401_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`000?oooooooooooooo
ool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0oooooom8
ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool0
0ol0003oooooooooo`3oooooodSooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
0ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?oooooo
BOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000
ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oo
ooooooooooooool000001_ooool3o`000?ooooooB?ooool000?ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool00ol0003oooooooooo`3oooooodSo
oooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<
00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool0
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_oo
ool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003o
ooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`005?ooool4o`00
0003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom8ooooo`005_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB?ooool001Kooooo00?o0000ooooooooool0
1Oooool3o`000?ooooooB?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool0
0ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Ko
oooo00?o0000ooooooooool0oooooom@ooooo`005?ooool00omEEEGoIVIVo`00003ooooooe;ooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.49324 .42119 Mdot
.45324 .52314 Mdot
.43504 .55852 Mdot
.45285 .51163 Mdot
.45052 .47488 Mdot
.53007 .42321 Mdot
.41859 .5446 Mdot
.45149 .44709 Mdot
.55858 .57116 Mdot
.55449 .47036 Mdot
.50347 .43923 Mdot
.50816 .51739 Mdot
.52951 .41745 Mdot
.4187 .47709 Mdot
.50275 .59291 Mdot
.55695 .4778 Mdot
.43282 .47889 Mdot
.57345 .45944 Mdot
.55852 .46588 Mdot
.52363 .54681 Mdot
.43426 .46019 Mdot
.57766 .52416 Mdot
.47432 .45198 Mdot
.48311 .41544 Mdot
.45435 .43887 Mdot
.51594 .50685 Mdot
.52158 .58328 Mdot
.55889 .46131 Mdot
.45779 .49135 Mdot
.51557 .41374 Mdot
.43433 .54127 Mdot
.43869 .49351 Mdot
.49468 .49049 Mdot
.48382 .57279 Mdot
.52323 .41534 Mdot
.44886 .56833 Mdot
.52451 .50271 Mdot
.5466 .57069 Mdot
.46128 .45872 Mdot
.52279 .51858 Mdot
.53469 .48754 Mdot
.54186 .54139 Mdot
.45445 .54899 Mdot
.48682 .50427 Mdot
.43605 .48109 Mdot
.55586 .49077 Mdot
.41645 .48156 Mdot
.42688 .53006 Mdot
.44583 .55946 Mdot
.57776 .54632 Mdot
.45657 .46758 Mdot
.54143 .41371 Mdot
.46048 .49877 Mdot
.45402 .45863 Mdot
.56659 .47418 Mdot
.55216 .5082 Mdot
.49219 .54383 Mdot
.53819 .40808 Mdot
.43992 .48229 Mdot
.48847 .54886 Mdot
.57243 .49633 Mdot
.54285 .49619 Mdot
.50018 .56671 Mdot
.5528 .47891 Mdot
.46403 .46918 Mdot
.56187 .57103 Mdot
.4284 .50699 Mdot
.56152 .49787 Mdot
.54332 .52829 Mdot
.56306 .47693 Mdot
.45221 .58182 Mdot
.44482 .48575 Mdot
.5027 .54401 Mdot
.47591 .51642 Mdot
.50488 .41221 Mdot
.49867 .58361 Mdot
.55913 .5184 Mdot
.56398 .45403 Mdot
.44233 .57448 Mdot
.50779 .45813 Mdot
.54127 .56494 Mdot
.45563 .44273 Mdot
.44187 .44708 Mdot
.5398 .48971 Mdot
.49481 .56922 Mdot
.46966 .51045 Mdot
.48124 .58057 Mdot
.5535 .49849 Mdot
.52081 .52333 Mdot
.55346 .43849 Mdot
.46281 .4858 Mdot
.56018 .48542 Mdot
.51589 .57467 Mdot
.56975 .56274 Mdot
.42871 .55618 Mdot
.57494 .51213 Mdot
.55534 .50183 Mdot
.42955 .5283 Mdot
.4156 .4856 Mdot
.48246 .54439 Mdot
.49057 .57974 Mdot
.51302 .57266 Mdot
.44289 .47023 Mdot
.58114 .53553 Mdot
.54767 .57959 Mdot
.50121 .49356 Mdot
.41333 .46476 Mdot
.46121 .47499 Mdot
.43745 .52497 Mdot
.56197 .48458 Mdot
.47635 .42094 Mdot
.4449 .48802 Mdot
.48551 .529 Mdot
.56503 .5584 Mdot
.42564 .47566 Mdot
.54619 .41857 Mdot
.53393 .5807 Mdot
.57315 .46484 Mdot
.42532 .54099 Mdot
.52054 .57405 Mdot
.52557 .45144 Mdot
.50613 .50688 Mdot
.55861 .4706 Mdot
.439 .55146 Mdot
.43774 .50204 Mdot
.57353 .54489 Mdot
.48781 .41594 Mdot
.50931 .5061 Mdot
.49439 .50371 Mdot
.53922 .48332 Mdot
.51417 .45366 Mdot
.43034 .47243 Mdot
.49666 .40716 Mdot
.46925 .56816 Mdot
.47757 .44107 Mdot
.47854 .4114 Mdot
.58343 .52128 Mdot
.47453 .49704 Mdot
.5219 .53547 Mdot
.48991 .51938 Mdot
.46121 .47925 Mdot
.5468 .57857 Mdot
.49627 .49868 Mdot
.45356 .50483 Mdot
.48678 .48025 Mdot
.56628 .48541 Mdot
.50065 .41832 Mdot
.57152 .5221 Mdot
.42504 .47216 Mdot
.44519 .55669 Mdot
.48805 .56742 Mdot
.56069 .46058 Mdot
.45609 .48052 Mdot
.42148 .46766 Mdot
.51037 .4485 Mdot
.55836 .47749 Mdot
.53668 .49562 Mdot
.50798 .40902 Mdot
.55801 .51932 Mdot
.47534 .4767 Mdot
.47849 .58938 Mdot
.55156 .52979 Mdot
.53824 .44856 Mdot
.57862 .47934 Mdot
.5099 .53127 Mdot
.49513 .53251 Mdot
.5373 .58532 Mdot
.55169 .55373 Mdot
.568 .53131 Mdot
.55814 .56261 Mdot
.52906 .46578 Mdot
.44898 .55619 Mdot
.45579 .53212 Mdot
.51293 .53144 Mdot
.45794 .58497 Mdot
.54265 .50283 Mdot
.57739 .51339 Mdot
.47291 .47319 Mdot
.43186 .43874 Mdot
.46825 .56421 Mdot
.45592 .51237 Mdot
.57705 .50666 Mdot
.478 .50935 Mdot
.45882 .49772 Mdot
.5361 .41768 Mdot
.50271 .51904 Mdot
.4605 .57759 Mdot
.57439 .49967 Mdot
.57122 .55937 Mdot
.51055 .57821 Mdot
.49022 .51254 Mdot
.50198 .47809 Mdot
.46932 .42121 Mdot
.4578 .47849 Mdot
.55347 .56621 Mdot
.51962 .48839 Mdot
.57732 .5515 Mdot
.49114 .49603 Mdot
.47099 .46586 Mdot
.45907 .52232 Mdot
.47531 .54285 Mdot
.56633 .50099 Mdot
.52263 .45451 Mdot
.55381 .54427 Mdot
.55475 .47472 Mdot
.45829 .53643 Mdot
.43634 .44804 Mdot
.4789 .54792 Mdot
.46353 .57519 Mdot
.45612 .47587 Mdot
.43536 .47833 Mdot
.51358 .50159 Mdot
.53355 .52321 Mdot
.52731 .44068 Mdot
.50632 .50724 Mdot
.41795 .46815 Mdot
.56176 .48772 Mdot
.55424 .52008 Mdot
.54862 .57715 Mdot
.46554 .47708 Mdot
.48983 .46684 Mdot
.52442 .40575 Mdot
.56476 .4858 Mdot
.44444 .43034 Mdot
.49309 .43711 Mdot
.46997 .43846 Mdot
.44237 .49627 Mdot
.56622 .46953 Mdot
.4548 .57506 Mdot
.49998 .45322 Mdot
.58421 .49583 Mdot
.50874 .50142 Mdot
.55688 .56787 Mdot
.52641 .49809 Mdot
.53386 .50667 Mdot
.51922 .53741 Mdot
.56751 .55392 Mdot
.48854 .58452 Mdot
.43789 .51021 Mdot
.50292 .51906 Mdot
.56481 .46925 Mdot
.50282 .59146 Mdot
.49569 .41686 Mdot
.57137 .54882 Mdot
.41924 .53969 Mdot
.56944 .47528 Mdot
.49924 .58477 Mdot
.46013 .44262 Mdot
.58121 .4812 Mdot
.53116 .58363 Mdot
.45933 .54976 Mdot
.54089 .41961 Mdot
.51588 .58862 Mdot
.42399 .54881 Mdot
.48406 .52513 Mdot
.50565 .5252 Mdot
.48867 .4574 Mdot
.54536 .51806 Mdot
.49304 .57075 Mdot
.52826 .58752 Mdot
.54886 .55457 Mdot
.51273 .4851 Mdot
.47616 .47706 Mdot
.51891 .44707 Mdot
.51084 .55584 Mdot
.50949 .56177 Mdot
.49561 .45142 Mdot
.53922 .46025 Mdot
.51185 .48901 Mdot
.43594 .43445 Mdot
.43563 .52457 Mdot
.48613 .52906 Mdot
.56877 .56299 Mdot
.48983 .52361 Mdot
.44402 .56893 Mdot
.48269 .58695 Mdot
.55912 .51089 Mdot
.55134 .46816 Mdot
.52665 .54273 Mdot
.52544 .47643 Mdot
.53148 .53191 Mdot
.53034 .51012 Mdot
.41909 .50843 Mdot
.48188 .48759 Mdot
.54744 .57354 Mdot
.57291 .55839 Mdot
.42232 .45042 Mdot
.48562 .45793 Mdot
.44315 .51739 Mdot
.42336 .45944 Mdot
.5097 .52749 Mdot
.42311 .47515 Mdot
.54997 .42214 Mdot
.45663 .5532 Mdot
.49461 .53276 Mdot
.45106 .45825 Mdot
.54614 .46278 Mdot
.4788 .56476 Mdot
.54032 .54531 Mdot
.45094 .50793 Mdot
.48357 .49841 Mdot
.47249 .43788 Mdot
.54979 .57952 Mdot
.57379 .48098 Mdot
.50997 .52229 Mdot
.45197 .50853 Mdot
.46043 .41746 Mdot
.44758 .43204 Mdot
.45787 .43679 Mdot
.50619 .55742 Mdot
.4653 .51969 Mdot
.48521 .48789 Mdot
.49798 .46113 Mdot
.48755 .42692 Mdot
.4643 .52887 Mdot
.427 .45554 Mdot
.52484 .51767 Mdot
.55835 .49782 Mdot
.50914 .53962 Mdot
.55177 .56623 Mdot
.46259 .56217 Mdot
.50392 .43497 Mdot
.50704 .4341 Mdot
.54718 .50443 Mdot
.53938 .46699 Mdot
.5682 .54909 Mdot
.48915 .50925 Mdot
.49596 .50488 Mdot
.57122 .55311 Mdot
.5287 .56354 Mdot
.50321 .41653 Mdot
.53715 .41445 Mdot
.48676 .53013 Mdot
.55227 .4703 Mdot
.46203 .57402 Mdot
.50416 .47335 Mdot
.48566 .56701 Mdot
.44792 .49782 Mdot
.49845 .4305 Mdot
.54536 .49716 Mdot
.42837 .51064 Mdot
.43736 .44099 Mdot
.40963 .50117 Mdot
.49533 .4963 Mdot
.57174 .5369 Mdot
.42637 .48678 Mdot
.48024 .48858 Mdot
.44813 .45613 Mdot
.54887 .55626 Mdot
.54056 .48946 Mdot
.50125 .5361 Mdot
.50187 .40748 Mdot
.43411 .47199 Mdot
.52887 .50015 Mdot
.54425 .42813 Mdot
.49925 .53263 Mdot
.42802 .44541 Mdot
.42979 .49139 Mdot
.55426 .42904 Mdot
.50016 .49178 Mdot
.46689 .46613 Mdot
.42811 .45237 Mdot
.49342 .53024 Mdot
.43101 .44348 Mdot
.4289 .49201 Mdot
.41828 .51237 Mdot
.41381 .52401 Mdot
.55576 .55058 Mdot
.43259 .43616 Mdot
.47024 .50859 Mdot
.47429 .47628 Mdot
.47094 .49267 Mdot
.51242 .40578 Mdot
.49774 .44178 Mdot
.42998 .54993 Mdot
.55405 .47289 Mdot
.49783 .44758 Mdot
.48643 .5822 Mdot
.5386 .54061 Mdot
.51772 .50348 Mdot
.49046 .56432 Mdot
.43083 .56056 Mdot
.45023 .4933 Mdot
.46872 .4183 Mdot
.44104 .49156 Mdot
.5235 .42718 Mdot
.55988 .461 Mdot
.49867 .46862 Mdot
.54627 .50906 Mdot
.48859 .5638 Mdot
.47262 .41319 Mdot
.53831 .53729 Mdot
.46884 .56306 Mdot
.43825 .49156 Mdot
.47671 .45579 Mdot
.44494 .45437 Mdot
.58033 .48672 Mdot
.48984 .48791 Mdot
.54274 .46611 Mdot
.46475 .41656 Mdot
.452 .42311 Mdot
.47851 .56706 Mdot
.48893 .40567 Mdot
.52842 .51078 Mdot
.47702 .56251 Mdot
.44912 .56683 Mdot
.45728 .49881 Mdot
.46928 .47657 Mdot
.46929 .54563 Mdot
.51478 .46339 Mdot
.49312 .51809 Mdot
.53754 .47206 Mdot
.47526 .51399 Mdot
.42919 .53532 Mdot
.47263 .50709 Mdot
.50977 .5746 Mdot
.56435 .4824 Mdot
.45615 .42647 Mdot
.47034 .55502 Mdot
.5644 .47032 Mdot
.51818 .4724 Mdot
.55848 .49201 Mdot
.47922 .51022 Mdot
.54548 .47198 Mdot
.51839 .40257 Mdot
.47058 .56977 Mdot
.51955 .59242 Mdot
.5206 .49027 Mdot
.52596 .5375 Mdot
.53472 .52087 Mdot
.42963 .44755 Mdot
.56319 .47712 Mdot
.43844 .44417 Mdot
.5152 .4702 Mdot
.56513 .53659 Mdot
.47001 .42004 Mdot
.56867 .53225 Mdot
.49316 .54405 Mdot
.43665 .43975 Mdot
.51084 .53216 Mdot
.44961 .55283 Mdot
.56599 .44118 Mdot
.42238 .467 Mdot
.51663 .44649 Mdot
.50161 .49316 Mdot
.52266 .46013 Mdot
.44809 .48246 Mdot
.55158 .47647 Mdot
.47602 .5735 Mdot
.46084 .48726 Mdot
.41629 .51098 Mdot
.49849 .52004 Mdot
.53955 .48769 Mdot
.51716 .52951 Mdot
.51312 .56755 Mdot
.56214 .56537 Mdot
.48862 .56678 Mdot
.54751 .56793 Mdot
.47152 .48247 Mdot
.54014 .51946 Mdot
.54708 .54624 Mdot
.47563 .52117 Mdot
.42444 .52932 Mdot
.52201 .49778 Mdot
.46562 .56014 Mdot
.44458 .42893 Mdot
.52286 .49378 Mdot
.48261 .51229 Mdot
.42409 .4933 Mdot
.54566 .52067 Mdot
.50421 .4269 Mdot
.51546 .4782 Mdot
.40672 .51611 Mdot
.48597 .5949 Mdot
.54017 .46851 Mdot
.55851 .57016 Mdot
.43593 .55266 Mdot
.48523 .59544 Mdot
.48912 .5805 Mdot
.48724 .40878 Mdot
.48761 .48967 Mdot
.43437 .47215 Mdot
.4588 .44189 Mdot
.43983 .47102 Mdot
.56151 .49231 Mdot
.55032 .54374 Mdot
.54657 .47248 Mdot
.49403 .42017 Mdot
.45526 .55893 Mdot
.48763 .58228 Mdot
.55968 .42744 Mdot
.45965 .57609 Mdot
.56751 .56169 Mdot
.4705 .46852 Mdot
.46934 .55021 Mdot
.54541 .42641 Mdot
.54828 .57562 Mdot
.47446 .46975 Mdot
.54803 .54226 Mdot
.4718 .43571 Mdot
.41159 .47692 Mdot
.51677 .59018 Mdot
.40904 .52267 Mdot
.50152 .47384 Mdot
.50208 .5203 Mdot
.57708 .47107 Mdot
.46313 .42965 Mdot
.53448 .48004 Mdot
.45719 .58068 Mdot
.57658 .55213 Mdot
.53828 .537 Mdot
.49132 .56888 Mdot
.45722 .54747 Mdot
.5364 .425 Mdot
.47429 .43647 Mdot
.56105 .47842 Mdot
.45991 .54862 Mdot
.52445 .41646 Mdot
.4168 .5087 Mdot
.49283 .42682 Mdot
.58114 .48026 Mdot
.43199 .51604 Mdot
.47971 .43112 Mdot
.52157 .50615 Mdot
.50125 .52841 Mdot
.55501 .50323 Mdot
.46454 .56594 Mdot
.54707 .41569 Mdot
.51912 .46124 Mdot
.53536 .47067 Mdot
.527 .55548 Mdot
.56679 .48545 Mdot
.55746 .51141 Mdot
.47698 .52197 Mdot
.57274 .55658 Mdot
.5033 .51418 Mdot
.49039 .41107 Mdot
.56266 .49617 Mdot
.48422 .54769 Mdot
.56643 .4663 Mdot
.48584 .52568 Mdot
.54648 .4463 Mdot
.56836 .48313 Mdot
.47806 .41502 Mdot
.51122 .45444 Mdot
.513 .58416 Mdot
.45298 .49793 Mdot
.55885 .4473 Mdot
.44358 .48046 Mdot
.5061 .46465 Mdot
.51952 .52274 Mdot
.46401 .44729 Mdot
.48964 .48477 Mdot
.41596 .46153 Mdot
.44398 .49213 Mdot
.49145 .4701 Mdot
.46661 .48425 Mdot
.48348 .55892 Mdot
.55722 .42728 Mdot
.52642 .57784 Mdot
.52077 .56883 Mdot
.48743 .57462 Mdot
.55155 .47524 Mdot
.46588 .50288 Mdot
.52959 .54695 Mdot
.48938 .45756 Mdot
.41474 .53795 Mdot
.51952 .47537 Mdot
.47491 .41575 Mdot
.43808 .55405 Mdot
.4364 .4341 Mdot
.51034 .50378 Mdot
.47465 .55803 Mdot
.44439 .46793 Mdot
.49916 .51857 Mdot
.54849 .48291 Mdot
.55656 .4441 Mdot
.52065 .52153 Mdot
.49071 .58334 Mdot
.51176 .51212 Mdot
.44977 .57445 Mdot
.44573 .48589 Mdot
.40893 .49747 Mdot
.46752 .54334 Mdot
.55299 .52712 Mdot
.4188 .46149 Mdot
.4715 .44113 Mdot
.43058 .50733 Mdot
.42934 .45426 Mdot
.50794 .56419 Mdot
.50449 .52055 Mdot
.54993 .48982 Mdot
.47374 .46502 Mdot
.49459 .51079 Mdot
.54659 .47855 Mdot
.50134 .41652 Mdot
.46495 .42151 Mdot
.57838 .50928 Mdot
.53817 .44914 Mdot
.45773 .53006 Mdot
.55696 .54539 Mdot
.58185 .4935 Mdot
.49769 .42358 Mdot
.53897 .43315 Mdot
.55064 .48888 Mdot
.44016 .53358 Mdot
.51872 .48225 Mdot
.41557 .52372 Mdot
.5416 .49676 Mdot
.4967 .50655 Mdot
.57559 .46533 Mdot
.47779 .42288 Mdot
.48586 .45261 Mdot
.41661 .47265 Mdot
.49294 .41965 Mdot
.45383 .48333 Mdot
.46618 .45937 Mdot
.5694 .47347 Mdot
.46381 .47009 Mdot
.47481 .59065 Mdot
.42197 .55107 Mdot
.54269 .41289 Mdot
.47863 .52763 Mdot
.5367 .49599 Mdot
.41435 .52712 Mdot
.49524 .56247 Mdot
.4583 .48322 Mdot
.47035 .48699 Mdot
.47295 .41414 Mdot
.44533 .52043 Mdot
.56817 .4959 Mdot
.55745 .47603 Mdot
.44203 .55577 Mdot
.5541 .44765 Mdot
.54932 .44511 Mdot
.49896 .43245 Mdot
.49962 .58182 Mdot
.48578 .51415 Mdot
.44094 .47702 Mdot
.42244 .45015 Mdot
.45412 .44786 Mdot
.55976 .51551 Mdot
.41378 .52 Mdot
.51753 .49091 Mdot
.5365 .48292 Mdot
.53254 .43885 Mdot
.54176 .42913 Mdot
.5113 .49501 Mdot
.41969 .54588 Mdot
.43184 .56352 Mdot
.485 .43001 Mdot
.48676 .48311 Mdot
.50543 .49828 Mdot
.43791 .52582 Mdot
.48445 .53592 Mdot
.45928 .55099 Mdot
.55373 .57948 Mdot
.48763 .51299 Mdot
.52598 .55245 Mdot
.49675 .51094 Mdot
.44293 .47967 Mdot
.49301 .48465 Mdot
.43291 .44129 Mdot
.53559 .406 Mdot
.41244 .48207 Mdot
.48888 .56772 Mdot
.56281 .54914 Mdot
.47131 .41246 Mdot
.48383 .41971 Mdot
.51995 .59617 Mdot
.44802 .52086 Mdot
.51908 .40335 Mdot
.4539 .42181 Mdot
.58247 .50137 Mdot
.52472 .48404 Mdot
.58318 .47945 Mdot
.50882 .54502 Mdot
.43666 .48142 Mdot
.55524 .46014 Mdot
.45213 .45517 Mdot
.57581 .49848 Mdot
.52282 .5681 Mdot
.4453 .53024 Mdot
.52892 .56918 Mdot
.43466 .48447 Mdot
.56819 .50334 Mdot
.44104 .50816 Mdot
.53913 .4197 Mdot
.5208 .53034 Mdot
.51673 .54642 Mdot
.56794 .51749 Mdot
.44386 .56518 Mdot
.53674 .41068 Mdot
.54003 .50697 Mdot
.48242 .56255 Mdot
.45289 .43451 Mdot
.41301 .46656 Mdot
.48688 .49965 Mdot
.56058 .48362 Mdot
.44939 .50406 Mdot
.47617 .44468 Mdot
.50489 .51368 Mdot
.4204 .50954 Mdot
.46331 .46944 Mdot
.41922 .53218 Mdot
.43519 .56827 Mdot
.55206 .502 Mdot
.45521 .47129 Mdot
.50101 .56958 Mdot
.54518 .47195 Mdot
.57454 .54931 Mdot
.49572 .50811 Mdot
.49472 .57474 Mdot
.58541 .47953 Mdot
.42482 .45346 Mdot
.52079 .58289 Mdot
.58702 .48598 Mdot
.44182 .44071 Mdot
.5255 .42328 Mdot
.54986 .46066 Mdot
.46696 .51157 Mdot
.51979 .4661 Mdot
.51883 .54044 Mdot
.47251 .5198 Mdot
.47079 .42579 Mdot
.49663 .53746 Mdot
.56996 .4515 Mdot
.52934 .43974 Mdot
.48986 .41116 Mdot
.56897 .51345 Mdot
.50988 .44697 Mdot
.54342 .48736 Mdot
.50158 .53337 Mdot
.53019 .49428 Mdot
.5505 .41876 Mdot
.42654 .55808 Mdot
.53594 .50484 Mdot
.57838 .51835 Mdot
.54784 .46862 Mdot
.55149 .51803 Mdot
.55725 .48935 Mdot
.52922 .4137 Mdot
.5365 .5088 Mdot
.48308 .4326 Mdot
.48805 .47279 Mdot
.45254 .46613 Mdot
.4695 .46935 Mdot
.55085 .49852 Mdot
.49459 .5026 Mdot
.5073 .42391 Mdot
.45659 .5658 Mdot
.47516 .48198 Mdot
.49993 .54077 Mdot
.45176 .46999 Mdot
.58407 .50368 Mdot
.44878 .42859 Mdot
.54493 .57983 Mdot
.55612 .47189 Mdot
.43501 .54101 Mdot
.50926 .46982 Mdot
.52138 .41873 Mdot
.52487 .4262 Mdot
.49085 .59644 Mdot
.54775 .53442 Mdot
.56638 .44942 Mdot
.48039 .52186 Mdot
.47264 .41595 Mdot
.45402 .49858 Mdot
.48942 .50634 Mdot
.44387 .56374 Mdot
.51739 .43902 Mdot
.43049 .53237 Mdot
.51886 .41345 Mdot
.46986 .50578 Mdot
.45489 .57139 Mdot
.52585 .57601 Mdot
.51441 .59519 Mdot
.47331 .4324 Mdot
.4821 .51576 Mdot
.5415 .52325 Mdot
.50913 .48048 Mdot
.42695 .49265 Mdot
.52268 .41691 Mdot
.56099 .43248 Mdot
.51549 .40244 Mdot
.47855 .58735 Mdot
.47486 .53766 Mdot
.5341 .48608 Mdot
.54239 .46512 Mdot
.55866 .53388 Mdot
.46277 .52688 Mdot
.52821 .45482 Mdot
.46256 .51476 Mdot
.54537 .56967 Mdot
.43991 .52904 Mdot
.57064 .54162 Mdot
.43835 .5325 Mdot
.41724 .45755 Mdot
.54869 .47699 Mdot
.41257 .5024 Mdot
.51592 .48627 Mdot
.48403 .54656 Mdot
.46437 .58161 Mdot
.51279 .59794 Mdot
.49067 .4223 Mdot
.54678 .47979 Mdot
.50799 .53126 Mdot
.47014 .43605 Mdot
.43603 .46707 Mdot
.55542 .4556 Mdot
.45381 .49973 Mdot
.51387 .58378 Mdot
.46003 .50993 Mdot
.50971 .4283 Mdot
.55116 .47549 Mdot
.45706 .5505 Mdot
.57362 .5072 Mdot
.49153 .542 Mdot
.46474 .43224 Mdot
.43911 .55055 Mdot
.51903 .49409 Mdot
.48118 .52619 Mdot
.47805 .58774 Mdot
.55049 .46812 Mdot
.47219 .42974 Mdot
.57984 .47125 Mdot
.46608 .46748 Mdot
.44156 .518 Mdot
.44102 .52935 Mdot
.53822 .50896 Mdot
.41334 .47572 Mdot
.42884 .51326 Mdot
.41948 .53083 Mdot
.55654 .49426 Mdot
.50556 .50075 Mdot
.52393 .48406 Mdot
.53682 .5437 Mdot
.50862 .45779 Mdot
.47493 .52732 Mdot
.54864 .57146 Mdot
.49017 .42116 Mdot
.55784 .48859 Mdot
.57593 .50812 Mdot
.46208 .5858 Mdot
.43788 .57016 Mdot
.51985 .56316 Mdot
.52198 .59592 Mdot
.53217 .54627 Mdot
.5622 .48953 Mdot
.5056 .54264 Mdot
.43804 .50605 Mdot
.53688 .43964 Mdot
.41721 .47818 Mdot
.45593 .42048 Mdot
.45297 .58385 Mdot
.49816 .52015 Mdot
.50486 .48937 Mdot
.53715 .42767 Mdot
.48095 .51184 Mdot
.4593 .47634 Mdot
.5034 .57098 Mdot
.49859 .52063 Mdot
.48485 .48642 Mdot
.52945 .57006 Mdot
.53946 .46302 Mdot
.47893 .57629 Mdot
.46391 .53681 Mdot
.55878 .45781 Mdot
.45811 .52689 Mdot
.55221 .41499 Mdot
.5271 .45795 Mdot
.55006 .57046 Mdot
.42534 .53494 Mdot
.50231 .41629 Mdot
.45334 .43337 Mdot
.47062 .50777 Mdot
.45739 .45555 Mdot
.55657 .48603 Mdot
.51862 .52329 Mdot
.54676 .4158 Mdot
.41236 .4847 Mdot
.51047 .40636 Mdot
.42484 .48284 Mdot
.46288 .49565 Mdot
.57002 .44878 Mdot
.43868 .4786 Mdot
.52469 .5267 Mdot
.55017 .48148 Mdot
.47616 .58472 Mdot
.50873 .4076 Mdot
.56578 .52105 Mdot
.50027 .49678 Mdot
.46608 .58084 Mdot
.51032 .46785 Mdot
.4764 .47085 Mdot
.57591 .55052 Mdot
.45213 .48534 Mdot
.44346 .5346 Mdot
.4904 .52654 Mdot
.48372 .53266 Mdot
.51233 .44201 Mdot
.47574 .54291 Mdot
.42916 .46292 Mdot
.46192 .52905 Mdot
.57634 .54249 Mdot
.46546 .51009 Mdot
.47906 .58417 Mdot
.51634 .53716 Mdot
.45173 .45702 Mdot
.42416 .4698 Mdot
.52049 .5578 Mdot
.54956 .55023 Mdot
.49716 .52415 Mdot
.46787 .45743 Mdot
.44124 .50471 Mdot
.51206 .51468 Mdot
.51372 .56957 Mdot
.40914 .51438 Mdot
.48174 .41874 Mdot
.53403 .57709 Mdot
.54479 .49111 Mdot
.48899 .50201 Mdot
.42433 .45004 Mdot
.5229 .56231 Mdot
.52047 .58924 Mdot
.46989 .51875 Mdot
.45112 .46062 Mdot
.51152 .52149 Mdot
.53625 .58947 Mdot
.461 .50386 Mdot
.47703 .53857 Mdot
.54387 .54308 Mdot
.55787 .57348 Mdot
.43632 .50552 Mdot
.48251 .51021 Mdot
.57777 .5503 Mdot
.53936 .49626 Mdot
.41474 .47038 Mdot
.52527 .58423 Mdot
.48922 .58752 Mdot
.51801 .40861 Mdot
.4566 .43798 Mdot
.45615 .56067 Mdot
.46785 .5161 Mdot
.56868 .50561 Mdot
.49118 .41863 Mdot
.42739 .51807 Mdot
.42234 .51625 Mdot
.47345 .55638 Mdot
.4689 .4187 Mdot
.56301 .46164 Mdot
.49007 .52145 Mdot
.56962 .45423 Mdot
.43881 .51547 Mdot
.45889 .51617 Mdot
.54104 .46084 Mdot
.5057 .57543 Mdot
.56371 .48049 Mdot
.41999 .45498 Mdot
.47294 .5911 Mdot
.54093 .55536 Mdot
.47423 .50717 Mdot
.57934 .51806 Mdot
.5107 .50033 Mdot
.51692 .49403 Mdot
.45029 .5521 Mdot
.4528 .57538 Mdot
.47377 .54148 Mdot
.5447 .48625 Mdot
.53019 .57341 Mdot
.51878 .55517 Mdot
.46413 .42669 Mdot
.5443 .4165 Mdot
.55735 .55011 Mdot
.43362 .43508 Mdot
.56438 .47765 Mdot
.41011 .4811 Mdot
.47672 .50783 Mdot
.52409 .51006 Mdot
.57028 .4575 Mdot
.56401 .44225 Mdot
.46793 .47807 Mdot
.44183 .46724 Mdot
.48188 .43668 Mdot
.42261 .48423 Mdot
.42373 .53772 Mdot
.46516 .42837 Mdot
.47771 .53242 Mdot
.5713 .48076 Mdot
.50059 .46895 Mdot
.4936 .42119 Mdot
.46808 .45948 Mdot
.44665 .43315 Mdot
.52784 .47709 Mdot
.54598 .47623 Mdot
.56913 .50291 Mdot
.51368 .57944 Mdot
.4368 .56432 Mdot
.45308 .58284 Mdot
.56046 .44766 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go
00001_ooool3o`000?ooooooB?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04
odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0Xoooool4o`000:3ooooo0003ooooo`05
o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooo
oooo09_ooooo1?l00003ooooo`Ko00000_ooool2o`0009_ooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo09[ooooo3_l00002
ooooo`?o0000V_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co
000000Oooooo00?o0000ooooooooool0UOooool4o`000004ooooool0003o0000o`0000;ooooo1?l0
00001?oooooo0000o`000?l00003ooooo`Co0000VOooool000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0Toooool:o`0000;ooooo
0ol00002ooooo`go0000U_ooool001kooooo00?o0000ooooooooool0T_ooool?o`0000?ooooo3Ol0
002Fooooo`007_ooool00ol0003oooooooooo`2?oooooa;o00001?ooool<o`0009Kooooo000Noooo
o`03o`000?oooooooooo08oooooo0ol000000ooooooo0000o`000004o`0000;ooooo1Ol000000ooo
oooo0000o`000004ooooo`Go00000oooool2o`0009Kooooo000Nooooo`03o`000?oooooooooo08co
oooo1_l000000ooooooo0000o`000004o`000003ooooool0003o000000So00000_ooool9o`0000;o
oooo0ol0002Cooooo`007_ooool00ol0003oooooooooo`2<ooooo`_o000000?oooooo`000?l00000
2_l00002ooooo`?o00000_ooool4o`000003ooooool0003o000000;o0000Toooool001kooooo00?o
0000ooooooooool0ROooool8o`000003ooooool0003o000000So00000_ooool5o`0000Sooooo0ol0
0002ooooo`Co0000Toooool001kooooo00?o0000ooooooooool0ROooool3o`000003ooooool0003o
000000Wo000000Coooooo`000?l0003ooooo1ol00008ooooo`;o00001Oooool2o`0009?ooooo000N
ooooo`03o`000?oooooooooo08Sooooo1_l00002ooooo`?o00000_ooool6o`000003ooooool0003o
000000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000000ol00004ooooo`;o00000_ooool2
o`00097ooooo000Nooooo`03o`000?oooooooooo08Sooooo1_l00002ooooo`?o00000_ooool4o`00
00Gooooo2?l000000ooooooo0000o`000003o`0000Cooooo1_l0002Aooooo`007_ooool00ol0003o
ooooooooo`27ooooo`Oo000000?oooooo`000?l000001?l00002ooooo`;o00001Oooool2o`0000;o
oooo1Ol00007ooooo`;o000000?oooooo`000?l000000_l0002Booooo`007_ooool00ol0003ooooo
ooooo`25ooooo`Wo000000Goooooo`000?l0003o0000ooooo`02o`0000;ooooo0_l00005ooooo`;o
00000_ooool5o`0000Cooooo0_l000000ooooooo0000o`000007o`00093ooooo000Nooooo`;o0000
Q_ooool7o`0000Cooooo0_l00004ooooo`;o00000_ooool2o`000004ooooool0003o0000o`0000;o
oooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo1ol0002@ooooo`007_ooool00ol0003ooooo
ooooo`24ooooo`Go00001?ooool6o`0000?ooooo0ol000001?oooooo0000o`000?ooool3o`0000;o
oooo0ol000000ooooooo0000o`000002o`0000Kooooo0_l000000ooooooo0000o`000002o`00093o
oooo000Nooooo`03o`000?oooooooooo08Cooooo1Ol00004ooooo`Wo000000Coooooo`000?l0003o
oooo0ol00004ooooo`Co000000?oooooo`000?l000000_l00006ooooo`So0000Soooool001kooooo
00?o0000ooooooooool0Poooool5o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000
o`000002o`0000Cooooo0ol000001?oooooo0000o`000?ooool2o`0000;ooooo1?l00002ooooo`go
0000Soooool001kooooo00?o0000ooooooooool0P_ooool4o`000003ooooool0003o000000;o0000
1?ooool2o`0000Cooooo0ol00006ooooo`Co000000?oooooo`000?l000001Ol000000ooooooo0000
o`000008o`000004ooooool0003o0000o`0008kooooo000Nooooo`03o`000?oooooooooo08;ooooo
1ol000000ooooooo0000o`000002o`000005ooooool0003o0000o`000?ooool01Ol00003ooooo`;o
000000?oooooo`000?l000001ol000001?oooooo0000o`000?ooool8o`000003ooooool0003o0000
00?o0000S_ooool001kooooo00?o0000ooooooooool0P_ooool6o`000003ooooool0003o000000?o
000000Goooooo`000?l0003o0000ooooo`06o`0000;ooooo3?l00003ooooo`co00000_ooool2o`00
08gooooo000Nooooo`03o`000?oooooooooo08?ooooo0_l000000ooooooo0000o`00000Ao`0000;o
oooo0ol000000ooooooo0000o`000005o`0000Cooooo3Ol000000ooooooo0000o`00002=ooooo`00
7_ooool00ol0003oooooooooo`22ooooo`_o000000?oooooo`000?l000002Ol00002ooooo`;o0000
0_ooool3o`0000;ooooo1Ol00002ooooo`co0000T?ooool001kooooo00?o0000ooooooooool0POoo
ool7o`000003ooooool0003o000000?o00000_ooool9o`000003ooooool0003o000000?ooooo2_l0
00001?oooooo0000o`000?ooool?o`0008_ooooo000Nooooo`03o`000?oooooooooo087ooooo1ol0
00000ooooooo0000o`00000=o`0000;ooooo0_l00005ooooo`Oo00000_ooool3o`000003ooooool0
003o000000co0000Roooool001kooooo00?o0000ooooooooool0P_oooolFo`0000;ooooo1?l00005
ooooo`Go00000_ooool=o`0000;ooooo1?l0002:ooooo`007_ooool00ol0003oooooooooo`22oooo
o`?o00000_ooool4o`0000;ooooo1?l000001?oooooo0000o`000?ooool2o`000003ooooool0003o
000000Co00000_ooool7o`0000?ooooo3?l00003ooooo`Co0000R_ooool001kooooo00?o0000oooo
ooooool0Q_ooool:o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`00000=o`00
00?ooooo2ol00004ooooo`;o0000S?ooool001kooooo00?o0000ooooooooool0Q_ooool:o`000005
ooooool0003o0000o`000?ooool00_l00005ooooo`Go000000?oooooo`000?l000002ol00002oooo
o`Oo000000Coooooo`000?l0003o0000Roooool001kooooo00?o0000ooooooooool0POooool2o`00
00Wooooo2?l00002ooooo`;o000000?oooooo`000?l000007_l000000ooooooo0000o`00002;oooo
o`007_ooool2o`0008;ooooo0ol00006ooooo`;o00000_ooool6o`0000;ooooo0_l000000ooooooo
0000o`00000:o`000003ooooool0003o000000;o00000_ooool:o`000003ooooool0003o000000;o
0000S?ooool001kooooo00?o0000ooooooooool0POooool3o`0000Kooooo0ol000001Ooooooo0000
o`000?l0003ooooo00Go00000oooool5o`000003ooooool0003o0000013o00000_ooool3o`0000;o
oooo0ol0002;ooooo`007_ooool00ol0003oooooooooo`23ooooo`?o000000?oooooo`000?l00000
1?l000001Ooooooo0000o`000?l0003ooooo00Oo000000?oooooo`000?l000000ol000000ooooooo
0000o`000005o`0000;ooooo2Ol00003ooooo`Co000000?oooooo`000?l00000Roooool001kooooo
00?o0000ooooooooool0Poooool:o`000003ooooool0003o000000oo000000Goooooo`000?l0003o
0000ooooo`0@o`0000;ooooo1?l0002=ooooo`007_ooool00ol0003oooooooooo`21ooooo`So0000
00?oooooo`000?l000000oooool@o`000003ooooool0003o000000;o00000_ooool4o`000003oooo
ool0003o000000;o00000_ooool3o`000003ooooool0003o000000?o0000SOooool001kooooo00?o
0000ooooooooool0P?ooool3o`000003ooooool0003o000000Co000000Coooooo`000?l0003o0000
0_ooool>o`0000;ooooo1?l00003ooooo`;o00001?ooool4o`000004ooooool0003o0000ooooo`Go
0000SOooool001kooooo00?o0000ooooooooool0P?ooool4o`000003ooooool0003o000000?o0000
00?oooooo`000?l000000ol000000ooooooo0000o`00000@o`0000?ooooo0ol000000ooooooo0000
o`00000;o`000003ooooool0003o000008gooooo000Nooooo`03o`000?oooooooooo087ooooo1?l0
0008ooooo`go000000Coooooo`000?l0003ooooo2_l000000ooooooo0000o`000004o`000003oooo
ool0003o000000[o0000Roooool001kooooo00?o0000ooooooooool0POooool4o`0000Gooooo0_l0
0003ooooo`Go00000_ooool7o`000003ooooool0003o000000So000000Coooooo`000?l0003ooooo
0_l00002ooooo`;o00001?ooool6o`0008_ooooo000Nooooo`03o`000?oooooooooo08?ooooo0_l0
00000ooooooo0000o`000007o`0000;ooooo1?l000000ooooooo0000o`000006o`000003ooooool0
003o000000Oo00001Oooool5o`0009Gooooo000Nooooo`03o`000?oooooooooo08Cooooo2ol00000
0ooooooo0000o`000003o`0000;ooooo4?l00002ooooo`;o00000_ooool4o`0000Cooooo0_l0002@
ooooo`007_ooool00ol0003oooooooooo`24ooooo`[o00000_ooool3o`0000Cooooo1?l00002oooo
o`So000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00000_ooool5o`0000;ooooo0_l0002<
ooooo`007_ooool00ol0003oooooooooo`23ooooo`Ko00000_ooool3o`0000?ooooo1?l000000ooo
oooo0000o`000003o`0000;ooooo1_l000000ooooooo0000o`000003o`0000;ooooo0_l000000ooo
oooo0000o`000002ooooo`Ko000000?oooooo`000?l00000S?ooool001kooooo00?o0000oooooooo
ool0Poooool5o`000003ooooool0003o000000Sooooo0_l000001?oooooo0000o`000?l00003oooo
o`Oo000000?oooooo`000?l000000ol00002ooooo`Go00001Oooool4o`0008kooooo000Nooooo`03
o`000?oooooooooo08Cooooo1?l000000ooooooo0000o`000009ooooo`Oo000000?oooooo`000?l0
00001Ol00002ooooo`Co000000?oooooo`000?l000001ol00002ooooo`Co0000S_ooool001kooooo
00?o0000ooooooooool0Q?ooool4o`0000Wooooo0_l000000ooooooo0000o`000008o`000003oooo
ool0003o000000;o000000?oooooo`000?l000003Ol00003ooooo`Co0000SOooool001kooooo0_l0
0025ooooo`Ko000000?oooooo`000?l000000oooool3o`000003ooooool0003o000000;ooooo1Ol0
0007ooooo`Oo00000oooool<o`0008gooooo000Nooooo`03o`000?oooooooooo08Gooooo0_l00000
0ooooooo0000o`000003o`000003ooooool0003o000000?o000000Coooooo`000?l0003o00004?oo
ool2o`0000Gooooo3?l0002=ooooo`007_ooool00ol0003oooooooooo`27ooooo`;o000000?ooooo
o`000?l000001_l00003ooooo`?o00002?ooool4o`000003ooooool0003o000000;o00000oooool5
o`0000?ooooo1Ol0002>ooooo`007_ooool00ol0003oooooooooo`27ooooo`Co000000?oooooo`00
0?l000001?l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000Gooooo1?l00000
0ooooooo0000o`000002o`0000?ooooo1?l00004ooooo`Co0000Soooool001kooooo00?o0000oooo
ooooool0R?ooool3o`000005ooooool0003o0000o`000?ooool01_l000000ooooooo0000o`000006
o`0000;ooooo0ol000000ooooooo0000o`000003o`0000Oooooo0_l000000ooooooo0000o`000002
o`0008oooooo000Nooooo`03o`000?oooooooooo08Sooooo3_l000000ooooooo0000o`000007o`00
0005ooooool0003o0000o`000?ooool01Ol00002ooooo`;o000000?oooooo`000?l000001_l0002@
ooooo`007_ooool00ol0003oooooooooo`29ooooo`Wo000000?oooooo`000?l000003?l00002oooo
o`Oo00000_ooool9o`0009;ooooo000Nooooo`03o`000?oooooooooo08Wooooo2Ol00002ooooo`ko
000000?oooooo`000?l000001Ol00003ooooo`So0000T_ooool001kooooo00?o0000ooooooooool0
S?ooool9o`0000;ooooo2?l000000ooooooo0000o`000008o`0000Cooooo1ol0002Booooo`007_oo
ool00ol0003oooooooooo`2<ooooo`Wo00000oooool4o`000004ooooool0003o0000ooooo`Wo0000
00?oooooo`000?l000000_ooool4o`0009Gooooo000Nooooo`03o`000?oooooooooo08oooooo1_l0
0003ooooo`Go000000?oooooo`000?l000000_ooool3o`0000;ooooo1Ol000000ooooooo0000o`00
0003o`0009Gooooo000Nooooo`03o`000?oooooooooo08oooooo1_l00002ooooo`Ko000000?ooooo
o`000?l000000oooool<o`0009Sooooo000Nooooo`03o`000?oooooooooo08oooooo1Ol00003oooo
o`Ko000000?oooooo`000?l000000oooool:o`0009[ooooo000Nooooo`03o`000?oooooooooo09Ko
oooo1ol00002ooooo`;o00000oooool3o`000003ooooool0003o000000;o0000Voooool000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
00Kooooo00?o0000ooooooooool0U_ooool3o`000003ooooool0003o000000?ooooo0_l00003oooo
o`?o00000oooool2o`0009_ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo09[ooooo0ol00002
ooooo`;o00000_ooool5o`0009oooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool0
1Ol0003ooooooooooooooooo000000Kooooo0ol0002Jooooo`?o00001_ooool5o`0009oooooo0003
ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo
00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo
00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo
00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000oooooooo
ool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nH
V9P02?ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000
oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Ko
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`3ooooo
odSooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo
000000Kooooo0ol0003oooooodSooooo0003ooooo`05o`000?ooooooooooooooool000002oooool0
1Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@
4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000oooo
ooooool0oooooom8ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@
4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001Cooooo1?l000000ol@413ooooo
ooooo`03ooooo`03o`000?oooooooooo0?ooooooB?ooool001Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Fooooo`03o`000?oooooooooo00Gooooo0ol0003o
ooooodSooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000oooooooo
ool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oo
oooooooo0?ooooooD?ooool001Cooooo00?oEEEEofIVI_l00000oooooomBooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.51477 .41594 Mdot
.44826 .50928 Mdot
.41696 .54381 Mdot
.45114 .49771 Mdot
.45667 .46268 Mdot
.55243 .43043 Mdot
.40041 .52475 Mdot
.46366 .43389 Mdot
.54268 .59269 Mdot
.56447 .48821 Mdot
.5198 .44098 Mdot
.50199 .51993 Mdot
.55336 .42316 Mdot
.42232 .4528 Mdot
.47652 .59932 Mdot
.56365 .49532 Mdot
.43889 .45959 Mdot
.58613 .48063 Mdot
.56964 .48517 Mdot
.50962 .55283 Mdot
.44331 .44147 Mdot
.57513 .54577 Mdot
.48533 .44709 Mdot
.5066 .40565 Mdot
.46879 .42564 Mdot
.51361 .51255 Mdot
.49942 .59303 Mdot
.57141 .48067 Mdot
.4606 .48069 Mdot
.53982 .41472 Mdot
.42267 .52374 Mdot
.44119 .4761 Mdot
.49831 .49337 Mdot
.46304 .5683 Mdot
.54742 .41886 Mdot
.43034 .55735 Mdot
.52401 .51026 Mdot
.52969 .58612 Mdot
.47069 .45028 Mdot
.51558 .52404 Mdot
.54074 .49835 Mdot
.53009 .55264 Mdot
.4411 .53646 Mdot
.48637 .50301 Mdot
.4415 .46299 Mdot
.5574 .5057 Mdot
.41812 .45646 Mdot
.41735 .51022 Mdot
.42971 .54694 Mdot
.57017 .57441 Mdot
.46419 .4579 Mdot
.56681 .42139 Mdot
.46185 .48829 Mdot
.46382 .44717 Mdot
.57377 .49481 Mdot
.54855 .51992 Mdot
.47887 .54077 Mdot
.5656 .41372 Mdot
.44494 .46562 Mdot
.47413 .54464 Mdot
.57207 .51517 Mdot
.54386 .50706 Mdot
.48156 .56622 Mdot
.55964 .49499 Mdot
.47089 .46265 Mdot
.54628 .59443 Mdot
.42651 .48644 Mdot
.56076 .51334 Mdot
.53433 .53783 Mdot
.56946 .49637 Mdot
.42749 .57427 Mdot
.44888 .47072 Mdot
.48881 .54387 Mdot
.47217 .50958 Mdot
.53004 .409 Mdot
.47489 .58599 Mdot
.55321 .53202 Mdot
.57854 .47403 Mdot
.41881 .56329 Mdot
.52045 .46372 Mdot
.5245 .57787 Mdot
.46916 .43058 Mdot
.45341 .43075 Mdot
.54427 .50111 Mdot
.47538 .56748 Mdot
.46797 .50218 Mdot
.45854 .57715 Mdot
.55268 .51144 Mdot
.51203 .52795 Mdot
.57167 .45538 Mdot
.46681 .4778 Mdot
.56344 .50265 Mdot
.49553 .58057 Mdot
.55711 .58848 Mdot
.40964 .53963 Mdot
.57266 .53138 Mdot
.55339 .5149 Mdot
.42107 .50859 Mdot
.41613 .4605 Mdot
.46968 .53856 Mdot
.46804 .57855 Mdot
.49309 .57718 Mdot
.45043 .45485 Mdot
.57748 .56297 Mdot
.52887 .59802 Mdot
.50436 .49825 Mdot
.41707 .43589 Mdot
.46706 .46728 Mdot
.4315 .50669 Mdot
.5654 .5025 Mdot
.49821 .41027 Mdot
.44847 .47286 Mdot
.47696 .52394 Mdot
.55292 .58032 Mdot
.43179 .45365 Mdot
.56985 .42871 Mdot
.51369 .59401 Mdot
.58365 .48627 Mdot
.41183 .52202 Mdot
.50043 .58143 Mdot
.54231 .46161 Mdot
.50422 .51082 Mdot
.56804 .48959 Mdot
.42466 .53661 Mdot
.43837 .48413 Mdot
.5657 .56841 Mdot
.51133 .40769 Mdot
.50758 .51078 Mdot
.49408 .5052 Mdot
.54693 .49549 Mdot
.52895 .46064 Mdot
.43758 .45211 Mdot
.52416 .4001 Mdot
.4499 .5602 Mdot
.49191 .43524 Mdot
.5035 .39896 Mdot
.58443 .54592 Mdot
.47643 .49244 Mdot
.51007 .54016 Mdot
.48405 .51655 Mdot
.46634 .47121 Mdot
.52819 .5963 Mdot
.49768 .50173 Mdot
.45341 .49136 Mdot
.49255 .48095 Mdot
.56926 .50415 Mdot
.52313 .41512 Mdot
.56679 .54033 Mdot
.43163 .44996 Mdot
.42985 .54365 Mdot
.46881 .56377 Mdot
.57328 .48019 Mdot
.46094 .47036 Mdot
.42741 .4441 Mdot
.52578 .4537 Mdot
.56503 .4955 Mdot
.53859 .50559 Mdot
.53512 .40653 Mdot
.55185 .53261 Mdot
.48101 .47389 Mdot
.45292 .58873 Mdot
.54284 .54194 Mdot
.55519 .46254 Mdot
.58449 .50066 Mdot
.49883 .53301 Mdot
.48444 .53007 Mdot
.51656 .60134 Mdot
.53861 .56995 Mdot
.56104 .54937 Mdot
.54452 .58186 Mdot
.54238 .47713 Mdot
.43388 .54352 Mdot
.44803 .51911 Mdot
.50182 .53396 Mdot
.43182 .57973 Mdot
.54076 .51274 Mdot
.57603 .53363 Mdot
.47914 .46962 Mdot
.44501 .41486 Mdot
.44992 .55561 Mdot
.45389 .49939 Mdot
.57639 .52645 Mdot
.47621 .50415 Mdot
.46037 .48671 Mdot
.55973 .42532 Mdot
.49612 .51999 Mdot
.43905 .56985 Mdot
.57372 .51867 Mdot
.55938 .58506 Mdot
.48888 .58316 Mdot
.48685 .51096 Mdot
.50964 .48371 Mdot
.49087 .40817 Mdot
.46303 .46919 Mdot
.53851 .58386 Mdot
.52535 .49676 Mdot
.56826 .57922 Mdot
.49321 .49744 Mdot
.47852 .46163 Mdot
.45437 .51022 Mdot
.46344 .53505 Mdot
.56472 .51758 Mdot
.53848 .46409 Mdot
.54263 .56015 Mdot
.56297 .49213 Mdot
.44914 .52417 Mdot
.44729 .42965 Mdot
.46518 .54108 Mdot
.44274 .56732 Mdot
.46184 .46608 Mdot
.44146 .46001 Mdot
.5137 .5076 Mdot
.52496 .53039 Mdot
.5463 .4499 Mdot
.50426 .51116 Mdot
.42255 .44284 Mdot
.56398 .505 Mdot
.5478 .53221 Mdot
.53037 .5952 Mdot
.47108 .47083 Mdot
.49882 .46856 Mdot
.55228 .40745 Mdot
.56761 .50416 Mdot
.46192 .41026 Mdot
.5088 .435 Mdot
.48515 .42992 Mdot
.44436 .47979 Mdot
.57522 .49011 Mdot
.4343 .56579 Mdot
.51264 .45579 Mdot
.58823 .51766 Mdot
.50903 .50667 Mdot
.54175 .58768 Mdot
.52805 .50641 Mdot
.53102 .51499 Mdot
.5069 .54156 Mdot
.55657 .57597 Mdot
.46452 .58421 Mdot
.4364 .49193 Mdot
.49632 .52007 Mdot
.57405 .48961 Mdot
.47704 .59748 Mdot
.51879 .41149 Mdot
.56199 .57149 Mdot
.40383 .51985 Mdot
.57596 .49628 Mdot
.47512 .58766 Mdot
.47388 .43199 Mdot
.58727 .50258 Mdot
.51015 .59671 Mdot
.44552 .53834 Mdot
.56405 .42892 Mdot
.4918 .59749 Mdot
.40673 .53035 Mdot
.47687 .51974 Mdot
.49658 .52609 Mdot
.49928 .45734 Mdot
.53876 .5277 Mdot
.47317 .56863 Mdot
.5061 .60012 Mdot
.53528 .56993 Mdot
.51933 .49267 Mdot
.48181 .47449 Mdot
.53601 .45477 Mdot
.49471 .55811 Mdot
.49207 .56377 Mdot
.50811 .45248 Mdot
.55403 .47454 Mdot
.51698 .49603 Mdot
.45123 .41145 Mdot
.42949 .50587 Mdot
.47748 .52417 Mdot
.55599 .58819 Mdot
.48242 .52008 Mdot
.42391 .55726 Mdot
.45791 .58629 Mdot
.55506 .52458 Mdot
.56262 .48529 Mdot
.51355 .54935 Mdot
.53605 .48698 Mdot
.5209 .5388 Mdot
.52612 .51756 Mdot
.41466 .48545 Mdot
.48586 .48642 Mdot
.53002 .58999 Mdot
.56139 .58488 Mdot
.43123 .42515 Mdot
.49582 .45709 Mdot
.43972 .50051 Mdot
.43105 .4363 Mdot
.4998 .52932 Mdot
.42875 .45234 Mdot
.57251 .43426 Mdot
.44199 .54138 Mdot
.48392 .53017 Mdot
.46095 .44557 Mdot
.55995 .47886 Mdot
.46019 .55849 Mdot
.52757 .55659 Mdot
.45019 .49346 Mdot
.485 .49696 Mdot
.48789 .42994 Mdot
.53105 .59883 Mdot
.57822 .50171 Mdot
.50184 .52462 Mdot
.45104 .49437 Mdot
.48326 .39947 Mdot
.46436 .41407 Mdot
.4733 .42423 Mdot
.48972 .55818 Mdot
.46134 .50941 Mdot
.4892 .48775 Mdot
.50883 .46437 Mdot
.50705 .42104 Mdot
.45767 .51823 Mdot
.43599 .43412 Mdot
.51789 .52359 Mdot
.55755 .51235 Mdot
.49603 .54127 Mdot
.53661 .58314 Mdot
.44517 .55237 Mdot
.52132 .43632 Mdot
.52513 .43635 Mdot
.54463 .51509 Mdot
.55253 .48067 Mdot
.55842 .5702 Mdot
.48696 .5079 Mdot
.49525 .50671 Mdot
.56075 .57703 Mdot
.51126 .57201 Mdot
.52637 .41386 Mdot
.56201 .42142 Mdot
.47772 .52539 Mdot
.56262 .48749 Mdot
.44169 .56573 Mdot
.51338 .47959 Mdot
.46644 .56269 Mdot
.44955 .48286 Mdot
.51657 .42925 Mdot
.54569 .5083 Mdot
.42531 .49029 Mdot
.45 .42105 Mdot
.4038 .4745 Mdot
.49738 .49916 Mdot
.565 .55774 Mdot
.43026 .46551 Mdot
.48399 .48683 Mdot
.4585 .44227 Mdot
.53502 .57166 Mdot
.54508 .50105 Mdot
.48906 .53535 Mdot
.52988 .40253 Mdot
.44157 .45303 Mdot
.52936 .50851 Mdot
.56462 .44078 Mdot
.48804 .53136 Mdot
.439 .42199 Mdot
.43273 .47137 Mdot
.5752 .44382 Mdot
.5037 .49632 Mdot
.47428 .46056 Mdot
.43768 .43099 Mdot
.48355 .52736 Mdot
.44266 .421 Mdot
.43158 .47166 Mdot
.41241 .48957 Mdot
.40271 .50195 Mdot
.54381 .56786 Mdot
.44691 .41186 Mdot
.46904 .50071 Mdot
.48001 .47313 Mdot
.47374 .48719 Mdot
.54024 .40419 Mdot
.51245 .44202 Mdot
.41431 .53295 Mdot
.5631 .49031 Mdot
.51137 .44869 Mdot
.46315 .58045 Mdot
.5267 .5506 Mdot
.51695 .50991 Mdot
.47208 .56114 Mdot
.41012 .54506 Mdot
.45268 .47952 Mdot
.49124 .40438 Mdot
.44391 .47489 Mdot
.54476 .43324 Mdot
.57241 .48051 Mdot
.50818 .47308 Mdot
.54224 .51924 Mdot
.47029 .5601 Mdot
.49746 .39893 Mdot
.52704 .54653 Mdot
.4508 .55447 Mdot
.44116 .47405 Mdot
.48671 .45219 Mdot
.45566 .43927 Mdot
.58448 .50764 Mdot
.49397 .48925 Mdot
.55598 .48074 Mdot
.48779 .40018 Mdot
.47284 .40352 Mdot
.45925 .56084 Mdot
.5165 .39575 Mdot
.52399 .51788 Mdot
.45912 .55567 Mdot
.43113 .55573 Mdot
.45858 .48708 Mdot
.47492 .47169 Mdot
.45664 .53633 Mdot
.52726 .47139 Mdot
.48749 .51649 Mdot
.54939 .48507 Mdot
.47227 .50722 Mdot
.41852 .51623 Mdot
.47175 .50026 Mdot
.48915 .57839 Mdot
.56843 .50134 Mdot
.4754 .40997 Mdot
.45472 .54629 Mdot
.57329 .4906 Mdot
.52905 .48168 Mdot
.55942 .50751 Mdot
.4771 .50531 Mdot
.55646 .48696 Mdot
.54738 .40202 Mdot
.45078 .56222 Mdot
.49521 .60344 Mdot
.52559 .49859 Mdot
.51393 .5433 Mdot
.52682 .52834 Mdot
.44026 .42567 Mdot
.56951 .49656 Mdot
.45035 .42567 Mdot
.52631 .47874 Mdot
.5568 .55463 Mdot
.49194 .40703 Mdot
.56171 .55079 Mdot
.47972 .54126 Mdot
.44971 .41893 Mdot
.49949 .53413 Mdot
.43542 .53984 Mdot
.58462 .45958 Mdot
.42875 .44386 Mdot
.53352 .45339 Mdot
.50491 .49797 Mdot
.53712 .47008 Mdot
.45271 .46889 Mdot
.55967 .49266 Mdot
.45505 .56734 Mdot
.46451 .47831 Mdot
.41017 .48749 Mdot
.49172 .5197 Mdot
.54505 .49934 Mdot
.50664 .53309 Mdot
.49445 .57122 Mdot
.54813 .58747 Mdot
.46956 .56325 Mdot
.53129 .5834 Mdot
.47623 .47804 Mdot
.53287 .52799 Mdot
.53489 .56012 Mdot
.47056 .51379 Mdot
.41462 .50915 Mdot
.52381 .50552 Mdot
.44847 .5507 Mdot
.46273 .40847 Mdot
.52644 .50209 Mdot
.47967 .50824 Mdot
.42574 .47128 Mdot
.53851 .53042 Mdot
.52373 .42716 Mdot
.52463 .48693 Mdot
.3955 .49051 Mdot
.45818 .59735 Mdot
.55288 .48229 Mdot
.54288 .59145 Mdot
.42082 .53753 Mdot
.45717 .59782 Mdot
.46635 .57907 Mdot
.513 .39867 Mdot
.49124 .49022 Mdot
.4418 .4533 Mdot
.47276 .43075 Mdot
.44732 .45439 Mdot
.56219 .50863 Mdot
.53892 .55835 Mdot
.55716 .48773 Mdot
.51594 .41492 Mdot
.43926 .54753 Mdot
.46432 .58091 Mdot
.58219 .44186 Mdot
.43886 .56782 Mdot
.55489 .58577 Mdot
.47753 .46416 Mdot
.45516 .54101 Mdot
.56631 .4389 Mdot
.53036 .59299 Mdot
.4814 .4667 Mdot
.53671 .55576 Mdot
.48805 .42696 Mdot
.41265 .44894 Mdot
.49253 .59977 Mdot
.39653 .49858 Mdot
.51024 .47942 Mdot
.49503 .52089 Mdot
.58538 .49261 Mdot
.48134 .41677 Mdot
.54392 .49179 Mdot
.43408 .57356 Mdot
.56718 .57945 Mdot
.52706 .54617 Mdot
.47184 .56619 Mdot
.44425 .53545 Mdot
.55786 .43475 Mdot
.49023 .42868 Mdot
.56705 .49706 Mdot
.4464 .5373 Mdot
.5484 .42052 Mdot
.41155 .48515 Mdot
.51223 .42274 Mdot
.58748 .50168 Mdot
.42787 .49652 Mdot
.49776 .42358 Mdot
.51945 .51284 Mdot
.49125 .52788 Mdot
.55267 .51607 Mdot
.44598 .55697 Mdot
.5719 .42503 Mdot
.5328 .4703 Mdot
.5477 .48326 Mdot
.51128 .56306 Mdot
.56976 .50428 Mdot
.5532 .52449 Mdot
.47153 .51489 Mdot
.5616 .58232 Mdot
.49859 .51608 Mdot
.51555 .40248 Mdot
.56236 .51222 Mdot
.47039 .54232 Mdot
.57662 .48695 Mdot
.47825 .52077 Mdot
.56304 .46248 Mdot
.57212 .50268 Mdot
.50154 .40359 Mdot
.5253 .46063 Mdot
.48961 .59133 Mdot
.45448 .48469 Mdot
.57517 .46624 Mdot
.44886 .46525 Mdot
.51726 .47058 Mdot
.51098 .52715 Mdot
.47638 .43854 Mdot
.49452 .48619 Mdot
.42085 .43378 Mdot
.4467 .4764 Mdot
.49991 .47246 Mdot
.47094 .47786 Mdot
.46647 .55354 Mdot
.5793 .44159 Mdot
.5058 .58805 Mdot
.50187 .57524 Mdot
.46631 .57138 Mdot
.56015 .49164 Mdot
.46637 .49405 Mdot
.51576 .55485 Mdot
.50003 .45773 Mdot
.3973 .51689 Mdot
.52983 .48498 Mdot
.49832 .40349 Mdot
.42279 .53953 Mdot
.45187 .41124 Mdot
.50957 .50897 Mdot
.45812 .55039 Mdot
.45237 .45306 Mdot
.49291 .51865 Mdot
.55449 .49715 Mdot
.57357 .4624 Mdot
.51248 .52629 Mdot
.46707 .5832 Mdot
.50745 .5163 Mdot
.42878 .56425 Mdot
.44972 .47119 Mdot
.4039 .47016 Mdot
.45569 .53354 Mdot
.54494 .53944 Mdot
.42449 .43576 Mdot
.48578 .4336 Mdot
.42893 .48739 Mdot
.4387 .43376 Mdot
.48996 .56583 Mdot
.49724 .52173 Mdot
.55267 .50311 Mdot
.4816 .46163 Mdot
.49166 .51097 Mdot
.55477 .49306 Mdot
.5245 .41317 Mdot
.48622 .40687 Mdot
.578 .52968 Mdot
.55503 .46318 Mdot
.4506 .51756 Mdot
.54599 .56251 Mdot
.58521 .51467 Mdot
.51823 .42058 Mdot
.55845 .44496 Mdot
.55365 .50251 Mdot
.43164 .51637 Mdot
.52677 .49115 Mdot
.40524 .50192 Mdot
.54248 .50733 Mdot
.4953 .50827 Mdot
.58603 .48688 Mdot
.49909 .41288 Mdot
.49711 .45114 Mdot
.42005 .44714 Mdot
.51506 .41395 Mdot
.45814 .472 Mdot
.47522 .4529 Mdot
.5766 .49449 Mdot
.47052 .46345 Mdot
.44858 .58951 Mdot
.40273 .53235 Mdot
.56843 .42062 Mdot
.47131 .52075 Mdot
.53843 .50591 Mdot
.40205 .50532 Mdot
.47749 .56041 Mdot
.46269 .47368 Mdot
.47424 .48181 Mdot
.49723 .40042 Mdot
.44104 .50423 Mdot
.56787 .51364 Mdot
.56482 .49402 Mdot
.42674 .54218 Mdot
.57018 .46592 Mdot
.56595 .46196 Mdot
.51649 .43171 Mdot
.47641 .58403 Mdot
.48205 .51083 Mdot
.44708 .46093 Mdot
.43145 .42492 Mdot
.46618 .43575 Mdot
.55454 .52933 Mdot
.40409 .49736 Mdot
.52215 .49866 Mdot
.54462 .49466 Mdot
.55165 .44946 Mdot
.56181 .44132 Mdot
.51416 .50135 Mdot
.402 .52649 Mdot
.40986 .54866 Mdot
.50331 .42386 Mdot
.49189 .48367 Mdot
.50706 .50338 Mdot
.43174 .50768 Mdot
.47399 .53044 Mdot
.44512 .53962 Mdot
.53535 .60071 Mdot
.48422 .51047 Mdot
.51088 .55956 Mdot
.49361 .51177 Mdot
.44842 .46425 Mdot
.49809 .48722 Mdot
.44522 .41903 Mdot
.56366 .41061 Mdot
.41249 .45495 Mdot
.46959 .56431 Mdot
.55219 .56844 Mdot
.49663 .39735 Mdot
.50618 .41112 Mdot
.49481 .60849 Mdot
.44365 .50545 Mdot
.54762 .40316 Mdot
.47526 .40251 Mdot
.58502 .52288 Mdot
.53253 .49373 Mdot
.59039 .50095 Mdot
.49471 .54663 Mdot
.44201 .46355 Mdot
.56843 .47878 Mdot
.46266 .4428 Mdot
.57586 .51798 Mdot
.50409 .57507 Mdot
.43799 .51429 Mdot
.51017 .57848 Mdot
.43931 .4658 Mdot
.56609 .52042 Mdot
.44032 .49068 Mdot
.56221 .42864 Mdot
.51017 .53475 Mdot
.5027 .55029 Mdot
.56311 .53431 Mdot
.42535 .5531 Mdot
.5629 .41671 Mdot
.53667 .51613 Mdot
.4644 .55708 Mdot
.46855 .41978 Mdot
.41626 .43828 Mdot
.48794 .49924 Mdot
.56453 .50126 Mdot
.44966 .48927 Mdot
.48936 .43909 Mdot
.50032 .51605 Mdot
.41604 .48698 Mdot
.47014 .46265 Mdot
.40679 .51165 Mdot
.41194 .55491 Mdot
.55017 .51406 Mdot
.46202 .46115 Mdot
.4816 .56962 Mdot
.55622 .48685 Mdot
.56549 .57458 Mdot
.49376 .50917 Mdot
.47375 .57366 Mdot
.5938 .50134 Mdot
.43394 .43057 Mdot
.49862 .59231 Mdot
.59454 .50822 Mdot
.4549 .42284 Mdot
.5476 .42912 Mdot
.56365 .47823 Mdot
.4651 .50227 Mdot
.53231 .47535 Mdot
.50589 .5447 Mdot
.46805 .5116 Mdot
.4907 .41426 Mdot
.4845 .53543 Mdot
.58553 .47191 Mdot
.54851 .44945 Mdot
.51497 .40242 Mdot
.56502 .53077 Mdot
.52558 .45183 Mdot
.54847 .4998 Mdot
.49004 .53276 Mdot
.53334 .50354 Mdot
.57447 .42967 Mdot
.40577 .54127 Mdot
.53379 .51365 Mdot
.57685 .53933 Mdot
.55961 .48458 Mdot
.54543 .52927 Mdot
.5592 .50497 Mdot
.55391 .41865 Mdot
.53259 .51727 Mdot
.50047 .42644 Mdot
.49556 .4741 Mdot
.46066 .45458 Mdot
.47637 .46466 Mdot
.55013 .51068 Mdot
.49467 .50441 Mdot
.52791 .4247 Mdot
.43871 .55557 Mdot
.47998 .47888 Mdot
.48676 .53977 Mdot
.45899 .45836 Mdot
.58714 .52597 Mdot
.46722 .40998 Mdot
.52599 .59721 Mdot
.56531 .49004 Mdot
.42353 .52355 Mdot
.51987 .47705 Mdot
.54442 .42239 Mdot
.54636 .43246 Mdot
.46236 .60046 Mdot
.53774 .54603 Mdot
.58246 .4694 Mdot
.47459 .51572 Mdot
.49605 .4029 Mdot
.45536 .48564 Mdot
.48821 .5056 Mdot
.42596 .55153 Mdot
.53595 .4451 Mdot
.42094 .51318 Mdot
.54342 .41533 Mdot
.4695 .49811 Mdot
.43557 .56175 Mdot
.50546 .58564 Mdot
.48894 .60556 Mdot
.4909 .42322 Mdot
.47805 .51098 Mdot
.53339 .53206 Mdot
.517 .48779 Mdot
.42923 .47161 Mdot
.54639 .42054 Mdot
.58191 .44858 Mdot
.54423 .40112 Mdot
.4537 .58603 Mdot
.46481 .52968 Mdot
.54089 .497 Mdot
.55591 .47977 Mdot
.54982 .54901 Mdot
.45679 .51581 Mdot
.54428 .46603 Mdot
.45991 .50378 Mdot
.52844 .58455 Mdot
.43285 .51157 Mdot
.56279 .56269 Mdot
.43 .51475 Mdot
.42331 .42927 Mdot
.55711 .4923 Mdot
.40743 .47698 Mdot
.52226 .49426 Mdot
.47052 .54118 Mdot
.44093 .57596 Mdot
.48632 .60858 Mdot
.51186 .41645 Mdot
.55442 .49414 Mdot
.49695 .53249 Mdot
.48626 .42689 Mdot
.44433 .44873 Mdot
.56966 .47427 Mdot
.45493 .48662 Mdot
.49063 .59116 Mdot
.45852 .49837 Mdot
.52945 .43064 Mdot
.55973 .49173 Mdot
.44317 .53862 Mdot
.5716 .52586 Mdot
.47874 .53869 Mdot
.48215 .42044 Mdot
.42508 .53553 Mdot
.52237 .50176 Mdot
.47401 .52001 Mdot
.45306 .5865 Mdot
.56195 .48499 Mdot
.49089 .41953 Mdot
.58898 .49279 Mdot
.47323 .46168 Mdot
.43793 .50066 Mdot
.43388 .5122 Mdot
.53415 .51766 Mdot
.41516 .44864 Mdot
.425 .4931 Mdot
.40767 .51027 Mdot
.55687 .50876 Mdot
.50622 .50559 Mdot
.53167 .49362 Mdot
.5241 .55357 Mdot
.52145 .46358 Mdot
.46815 .51947 Mdot
.53188 .58794 Mdot
.51183 .41483 Mdot
.56003 .50454 Mdot
.57459 .52757 Mdot
.4363 .58144 Mdot
.41484 .55765 Mdot
.50221 .56861 Mdot
.49704 .60884 Mdot
.51859 .55491 Mdot
.56375 .50656 Mdot
.49195 .54339 Mdot
.43775 .48797 Mdot
.5554 .45176 Mdot
.41988 .4532 Mdot
.47782 .40167 Mdot
.42671 .57726 Mdot
.49137 .5197 Mdot
.50954 .49512 Mdot
.55793 .43814 Mdot
.47824 .50729 Mdot
.46491 .4678 Mdot
.48365 .57191 Mdot
.49158 .52022 Mdot
.48915 .48623 Mdot
.51053 .57972 Mdot
.55363 .4771 Mdot
.45726 .57133 Mdot
.45445 .52601 Mdot
.57229 .47705 Mdot
.45199 .51446 Mdot
.57829 .42453 Mdot
.54236 .46905 Mdot
.53365 .58737 Mdot
.41402 .5154 Mdot
.52556 .41323 Mdot
.46952 .41836 Mdot
.46963 .50012 Mdot
.46771 .44531 Mdot
.55991 .50199 Mdot
.50992 .52745 Mdot
.57153 .42512 Mdot
.41178 .45793 Mdot
.53838 .40424 Mdot
.42953 .46094 Mdot
.46495 .48652 Mdot
.58652 .4688 Mdot
.44457 .46157 Mdot
.51494 .53203 Mdot
.55644 .49638 Mdot
.45225 .58179 Mdot
.53641 .40514 Mdot
.56 .53705 Mdot
.50241 .50107 Mdot
.44307 .57517 Mdot
.52142 .47515 Mdot
.48326 .46844 Mdot
.56675 .57702 Mdot
.456 .47311 Mdot
.43471 .5183 Mdot
.48193 .52288 Mdot
.47429 .52704 Mdot
.52956 .44697 Mdot
.46383 .53522 Mdot
.43745 .44248 Mdot
.45516 .51774 Mdot
.56984 .56745 Mdot
.46403 .5004 Mdot
.45539 .58149 Mdot
.50392 .54057 Mdot
.46188 .44455 Mdot
.43083 .44733 Mdot
.50407 .56331 Mdot
.53685 .5655 Mdot
.48893 .52278 Mdot
.47742 .45123 Mdot
.4415 .48753 Mdot
.50672 .51853 Mdot
.49458 .57371 Mdot
.39959 .48964 Mdot
.5043 .40933 Mdot
.51432 .58956 Mdot
.54788 .50321 Mdot
.48927 .50194 Mdot
.43398 .42601 Mdot
.50554 .56876 Mdot
.49683 .59958 Mdot
.46589 .50983 Mdot
.46049 .44808 Mdot
.50364 .52427 Mdot
.51427 .60635 Mdot
.4611 .49309 Mdot
.4665 .53118 Mdot
.53196 .55536 Mdot
.54129 .5951 Mdot
.43602 .48707 Mdot
.48024 .50645 Mdot
.56905 .5782 Mdot
.5407 .50655 Mdot
.41792 .44374 Mdot
.50337 .5954 Mdot
.46426 .58843 Mdot
.5443 .40928 Mdot
.47155 .42535 Mdot
.43964 .54965 Mdot
.46471 .50671 Mdot
.56612 .52278 Mdot
.51371 .41221 Mdot
.42175 .49771 Mdot
.41619 .49481 Mdot
.45743 .54839 Mdot
.49128 .40495 Mdot
.5751 .48162 Mdot
.48343 .51834 Mdot
.58424 .47483 Mdot
.43586 .49736 Mdot
.45584 .50404 Mdot
.55565 .4756 Mdot
.48465 .57807 Mdot
.56862 .49954 Mdot
.42715 .42858 Mdot
.44641 .58973 Mdot
.5261 .56778 Mdot
.47327 .50093 Mdot
.57831 .53945 Mdot
.51142 .50605 Mdot
.52025 .50137 Mdot
.43628 .53913 Mdot
.43212 .56585 Mdot
.46243 .53326 Mdot
.55002 .49911 Mdot
.51067 .58389 Mdot
.5029 .56003 Mdot
.48359 .41319 Mdot
.56874 .42556 Mdot
.54572 .56783 Mdot
.44849 .41102 Mdot
.57037 .49732 Mdot
.4098 .45242 Mdot
.47545 .50239 Mdot
.52008 .5166 Mdot
.58375 .47827 Mdot
.58212 .46076 Mdot
.47333 .47262 Mdot
.45004 .45127 Mdot
.49777 .43117 Mdot
.42638 .46169 Mdot
.41087 .51827 Mdot
.48393 .41579 Mdot
.46903 .52519 Mdot
.57586 .5012 Mdot
.51026 .47395 Mdot
.51512 .41606 Mdot
.47707 .45369 Mdot
.46288 .41514 Mdot
.53831 .488 Mdot
.55523 .49094 Mdot
.56717 .52029 Mdot
.49181 .58568 Mdot
.41642 .55074 Mdot
.42769 .57588 Mdot
.57677 .46682 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo09gooooo0_l00005ooooo`;o0000XOooool000?ooooo00Go410@oooooooooooo
oooooa0@400;ooooo`Go00001_ooool3o`0009Wooooo0ol000000ooooooo0000o`000003o`000003
ooooool0003o000000?o00001Oooool2o`0009Sooooo0003ooooo`05o`000?ooooooooooooooool0
00002oooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo09Kooooo1_l000000ooo
oooo0000o`000003o`000004ooooool0003o0000ooooo`Co000000?oooooo`000?l000000ol0002G
ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001ooo
ool00ol0003oooooooooo`2Fooooo`?o000000?oooooo`000?l000002Ol00003ooooo`So0000Uooo
ool000?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o
0000ooooooooool0T_ooool6o`0000;ooooo2_l00004ooooo`Co000000?oooooo`000?l000000_l0
002Fooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001ooo
ool00ol0003oooooooooo`2=ooooo`Co000000?oooooo`000?l000001?l000000ooooooo0000o`00
0002o`000003ooooool0003o000000[o00000oooool4o`0000;ooooo0_l0002Booooo`000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooooooo
o`2=ooooo`Co000000Coooooo`000?l0003o00001?ooool4o`000003ooooool0003o000000Wo0000
0_ooool4o`0000Cooooo0ol0002Aooooo`007_ooool00ol0003oooooooooo`2=ooooo`?o00000_oo
ool5o`000003ooooool0003o000000?o00001Oooool7o`0000;ooooo1ol000001?oooooo0000o`00
0?l0002Aooooo`007_ooool00ol0003oooooooooo`2;ooooo`Go00001?ooool3o`000003ooooool0
003o000000?o00001?ooool5o`0000Oooooo1Ol000000ooooooo0000o`000002o`00093ooooo000N
ooooo`03o`000?oooooooooo08Sooooo0_l000000ooooooo0000o`000005o`0000;ooooo1?l00000
0ooooooo0000o`000002o`000003ooooool0003o000000Ko00000_ooool2o`0000?ooooo3Ol0002=
ooooo`007_ooool00ol0003oooooooooo`27ooooo`Ko000000?oooooo`000?l000000_l00002oooo
o`Co00000_ooool3o`000003ooooool0003o000000;o00001?ooool4o`0000Kooooo2_l0002=oooo
o`007_ooool00ol0003oooooooooo`26ooooo`Ko000000?oooooo`000?l000000_l00003ooooo`Co
00000_ooool3o`000004ooooool0003o0000o`0000?ooooo1_l00004ooooo`?o00000_ooool6o`00
08kooooo000Nooooo`03o`000?oooooooooo08Gooooo0ol000000ooooooo0000o`000006o`0000;o
oooo1Ol00002ooooo`?o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000002oooo
o`;o00000oooool6o`0000?ooooo0ol0002>ooooo`007_ooool00ol0003oooooooooo`23ooooo`[o
00001_ooool2o`0000Gooooo1?l00003ooooo`;o00000_ooool4o`0000Cooooo0ol000000ooooooo
0000o`000003ooooo`;o0000Soooool001kooooo00?o0000ooooooooool0Poooool2o`000003oooo
ool0003o000000;o00001_ooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`?o0000
1oooool4o`0000Sooooo1Ol0002Aooooo`007_ooool00ol0003oooooooooo`23ooooo`Ko000000?o
ooooo`000?l000000_l00002ooooo`Co00000oooool2o`0000;ooooo0_l00005ooooo`;o000000?o
ooooo`000?l000003?ooool3o`000003ooooool0003o000000;o0000S?ooool001kooooo00?o0000
ooooooooool0Q?ooool:o`0000?ooooo1Ol00004ooooo`;o00001_ooool2o`0000Cooooo1?l00005
ooooo`Co00000_ooool4o`0008cooooo000Nooooo`03o`000?oooooooooo08;ooooo1?l00002oooo
o`;o00000_ooool2o`0000Cooooo1Ol00003ooooo`;o00001_ooool2o`0000Cooooo1?l000000ooo
oooo0000o`000004o`0000Kooooo0_l0002<ooooo`007_ooool2o`0008;ooooo4?l000001?oooooo
0000o`000?ooool4o`000003ooooool0003o000000;ooooo0_l000001?oooooo0000o`000?l00003
ooooo`Co00000_ooool5o`0000Oooooo0_l0002<ooooo`007_ooool00ol0003oooooooooo`21oooo
oa3o000000?oooooo`000?l000000_ooool3o`000003ooooool0003o000000;ooooo0_l000000ooo
oooo0000o`000002o`0000;ooooo1Ol00004ooooo`;o00001?ooool2o`0008oooooo000Nooooo`03
o`000?oooooooooo08;ooooo1?l00002ooooo`;o000000?oooooo`000?l000000ol000000ooooooo
0000o`000002o`0000;ooooo0_l00004ooooo`?o00000oooool2o`0000;ooooo0_l000000ooooooo
0000o`00000:ooooo`;o00000_ooool2o`0008_ooooo000Nooooo`03o`000?oooooooooo08;ooooo
0ol00002ooooo`?o000000?oooooo`000?l000000_l000000ooooooo0000o`000008o`0000?ooooo
0ol00007ooooo`?o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000003o`000004oooo
ool0003o0000o`0008_ooooo000Nooooo`03o`000?oooooooooo08?ooooo0_l00002ooooo`?o0000
00?oooooo`000?l000001ol000000ooooooo0000o`000003o`0000Oooooo0_l00002ooooo`Go0000
00Coooooo`000?l0003o00000_ooool2o`000003ooooool0003o000000?o000000?oooooo`000?l0
0000S?ooool001kooooo00?o0000ooooooooool0R?ooool2o`000003ooooool0003o000000Co0000
00?oooooo`000?l000001ol00003ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Cooooo
1?l000000ooooooo0000o`000003ooooo`Co00000_ooool2o`0008[ooooo000Nooooo`03o`000?oo
oooooooo07oooooo0_l00005ooooo`Go00000oooool=o`0000?ooooo0_l00004ooooo`;o000000?o
ooooo`000?l000001_l00006ooooo`So0000R_ooool001kooooo00?o0000ooooooooool0Ooooool2
o`0000Gooooo5Ol00002ooooo`?o000000?oooooo`000?l000000ol000000ooooooo0000o`000005
o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l0002;ooooo`007_ooool00ol0
003oooooooooo`1oooooo`?o00002Oooool@o`0000;ooooo0ol000001Ooooooo0000o`000?l0003o
oooo00;o00000_ooool2o`000003ooooool0003o000000;ooooo0ol00002ooooo`Oo0000Roooool0
01kooooo00?o0000ooooooooool0P?ooool2o`0000Wooooo1_l000000ooooooo0000o`000006o`00
00;ooooo0_l00004ooooo`Wo000000?oooooo`000?l000000_ooool8o`0000;ooooo0_l0002;oooo
o`007_ooool00ol0003oooooooooo`2:ooooo`Oo000000Goooooo`000?l0003o0000ooooo`04o`00
00;ooooo0_l00004ooooo`?o00000_ooool3o`0000Cooooo2ol000000ooooooo0000o`00002;oooo
o`007_ooool00ol0003oooooooooo`22ooooo`?o00000_ooool2o`000003ooooool0003o000000;o
oooo1ol000001?oooooo0000o`000?ooool7o`0000;ooooo0_l00002ooooo`Ko00000_ooool;o`00
0003ooooool0003o000008_ooooo000Nooooo`03o`000?oooooooooo07kooooo0_l000000ooooooo
0000o`000002o`000005ooooool0003o0000o`000?ooool00ol000000ooooooo0000o`000005o`00
0004ooooool0003o0000ooooo`Oo00001?ooool9o`000004ooooool0003o0000ooooo`So000000?o
ooooo`000?l00000Roooool001kooooo00?o0000ooooooooool0O?ooool4o`000004ooooool0003o
0000o`0000;ooooo0_l00002ooooo`?o000000Goooooo`000?l0003o0000ooooo`02o`0000?ooooo
0_l00002ooooo`Go00001?ooool5o`0000;ooooo1?l000000ooooooo0000o`000007o`000004oooo
ool0003o0000o`0008[ooooo000Nooooo`03o`000?oooooooooo07cooooo0_l00005ooooo`;o0000
00Goooooo`000?l0003o0000ooooo`03o`000005ooooool0003o0000o`000?ooool01?l000000ooo
oooo0000o`000005ooooo`go00000_ooool<o`000004ooooool0003o0000o`0008[ooooo000Noooo
o`03o`000?oooooooooo07gooooo1?l00002ooooo`Ko000000?oooooo`000?l000000oooool4o`00
0004ooooool0003o0000o`0000?ooooo4Ol000000ooooooo0000o`00000;o`0008kooooo000Noooo
o`;o0000O_ooool5o`0000?ooooo0_l00003ooooo`?o00000_ooool9o`0000;ooooo2?l000000ooo
oooo0000o`000004o`0000?ooooo4ol00028ooooo`007_ooool00ol0003oooooooooo`1oooooo`?o
00002?ooool4o`0000;ooooo2Ol000000ooooooo0000o`00000So`0008Sooooo000Nooooo`03o`00
0?oooooooooo07oooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0ol00002ooooo`oo
000000?oooooo`000?l000000ol000000ooooooo0000o`00000?o`0000?ooooo0_l000000ooooooo
0000o`000028ooooo`007_ooool00ol0003oooooooooo`20ooooo`;o000000?oooooo`000?l00000
0_l000001?oooooo0000o`000?l00003oooooa7o000000?oooooo`000?l000002?l000000ooooooo
0000o`000008o`0000Gooooo0_l000000ooooooo0000o`000028ooooo`007_ooool00ol0003ooooo
ooooo`20ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000002o`0000;ooooo
4?l00002ooooo`So000000Coooooo`000?l0003ooooo2ol00003ooooo`;o0000Roooool001kooooo
00?o0000ooooooooool0OOooool2o`0000?ooooo1Ol000000ooooooo0000o`000002o`0000;ooooo
1?l00003ooooo`?o000000Coooooo`000?l0003o00000_oooolKo`000004ooooool0003o0000o`00
08[ooooo000Nooooo`03o`000?oooooooooo07gooooo2Ol00002ooooo`?o00000oooool5o`000003
ooooool0003o000000go00000_ooool=o`000003ooooool0003o000000Co00000_ooool2o`0008[o
oooo000Nooooo`03o`000?oooooooooo07oooooo1Ol000001Ooooooo0000o`000?l0003ooooo00;o
00000oooool2o`000004ooooool0003o0000ooooo`oo000000?oooooo`000?l000001_ooool4o`00
00Cooooo1?l00002ooooo`;o0000Roooool001kooooo00?o0000ooooooooool0O_ooool3o`000004
ooooool0003o0000ooooo`?o00001_ooool4o`0000;ooooo4_l0000:ooooo`;o00000_ooool5o`00
0004ooooool0003o0000o`0008[ooooo000Nooooo`03o`000?oooooooooo07kooooo1?l0000>oooo
o`;o000000?oooooo`000?l000001_l000000ooooooo0000o`000003o`000003ooooool0003o0000
00?ooooo2?l000000ooooooo0000o`000004ooooo`Co000000?oooooo`000?l00000R_ooool001ko
oooo00?o0000ooooooooool0Ooooool3o`000003ooooool0003o000000_ooooo2?l000000ooooooo
0000o`000005o`000003ooooool0003o000000;o00000_ooool;o`0000;ooooo1_l0002=ooooo`00
7_ooool00ol0003oooooooooo`1oooooo`;o00000_ooool2o`000003ooooool0003o000000?ooooo
0ol00002ooooo`Ko00000oooool<o`0000Cooooo0_l00003ooooo`Co000000?oooooo`000?l00000
1?l0002>ooooo`007_ooool00ol0003oooooooooo`21ooooo`;o00000_ooool3o`0000;ooooo1Ol0
00001?oooooo0000o`000?ooool4o`000003ooooool0003o000000?o000000Goooooo`000?l0003o
0000ooooo`02o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000003ooooo`?o
00000_ooool3o`0008gooooo000Nooooo`03o`000?oooooooooo083ooooo0ol00002ooooo`[o0000
00Coooooo`000?l0003ooooo1?l000000ooooooo0000o`000002o`000004ooooool0003o0000oooo
o`Co000000?oooooo`000?l000000oooool5o`0000?ooooo1?l000001?oooooo0000o`000?l0002=
ooooo`007_ooool00ol0003oooooooooo`20ooooo`Go00000_ooool4o`000003ooooool0003o0000
00;ooooo0_l000000ooooooo0000o`00000:o`000003ooooool0003o000000?o00001oooool2o`00
00Kooooo0_l000000ooooooo0000o`00002>ooooo`007_ooool00ol0003oooooooooo`21ooooo`Co
00000oooool5o`0000?ooooo0ol00003ooooo`;o00000oooool4o`000004ooooool0003o0000oooo
o`;o00000_ooool2o`0000;ooooo0_l0000:ooooo`;o000000?oooooo`000?l00000Roooool001ko
oooo0_l00022ooooo`Co000000?oooooo`000?l000000_l000001?oooooo0000o`000?ooool5o`00
00[ooooo1?l00002ooooo`;o00000_ooool2o`0000;ooooo0_l00002ooooo`;o000000Coooooo`00
0?l0003o00001Oooool2o`0008_ooooo000Nooooo`03o`000?oooooooooo08;ooooo0ol000000ooo
oooo0000o`000003ooooo`Go000000Coooooo`000?l0003ooooo0_l00009ooooo`;o000000?ooooo
o`000?l000001_l00005ooooo`Ko0000T_ooool001kooooo00?o0000ooooooooool0P_ooool3o`00
0003ooooool0003o000000;o000000?oooooo`000?l000000ol000000ooooooo0000o`000003o`00
00Oooooo0_l00003ooooo`[o00001Oooool2o`000003ooooool0003o0000097ooooo000Nooooo`03
o`000?oooooooooo08?ooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000?o
000000?oooooo`000?l000001_l00002ooooo`Ko000000?oooooo`000?l000000oooool7o`0000Ko
oooo0_l0002Aooooo`007_ooool00ol0003oooooooooo`24ooooo`;o000000?oooooo`000?l00000
0_l00003ooooo`;o000000Coooooo`000?l0003ooooo1Ol00002ooooo`?o000000?oooooo`000?l0
00000ol00006ooooo`Go00001?ooool2o`0000?ooooo0_l0002=ooooo`007_ooool00ol0003ooooo
ooooo`24ooooo`;o000000?oooooo`000?l000002Ol00002ooooo`?o000000Coooooo`000?l0003o
oooo0ol00002ooooo`Co00001_ooool2o`000003ooooool0003o000000Cooooo0_l00003ooooo`;o
0000SOooool001kooooo00?o0000ooooooooool0R?ooool6o`0000;ooooo1?l000000ooooooo0000
o`000003o`000003ooooool0003o000000;ooooo0ol00005ooooo`;o000000?oooooo`000?l00000
1ol000001?oooooo0000o`000?l0002@ooooo`007_ooool00ol0003oooooooooo`2;ooooo`;o0000
1?ooool4o`000003ooooool0003o000000?o00000_ooool7o`0000?ooooo0_l000000ooooooo0000
o`00000;o`00093ooooo000Nooooo`03o`000?oooooooooo08Oooooo1ol00003ooooo`Co000000Co
ooooo`000?l0003ooooo0_l00002ooooo`Oo00001_ooool2o`0000Gooooo1_l0002@ooooo`007_oo
ool00ol0003oooooooooo`27ooooo`Oo00000oooool7o`000003ooooool0003o000000Wo00000_oo
ool2o`0000Wooooo1_l0002@ooooo`007_ooool00ol0003oooooooooo`27ooooo`Go00000oooool7
o`0000?ooooo2?l000000ooooooo0000o`000002ooooo`;o00001Oooool2o`000003ooooool0003o
000000Go0000T?ooool001kooooo00?o0000ooooooooool0R?ooool4o`0000?ooooo1ol000000ooo
oooo0000o`000002ooooo`Wo00001?ooool7o`000003ooooool0003o000000;o0000Toooool001ko
oooo00?o0000ooooooooool0Soooool:o`0000;ooooo0ol00002ooooo`Co00001?ooool<o`0009?o
oooo000Nooooo`03o`000?oooooooooo08gooooo2?l000000ooooooo0000o`000003ooooo`;o0000
0oooool2o`000003ooooool0003o000000?ooooo0ol000000ooooooo0000o`000002o`000003oooo
ool0003o000009Cooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo08gooooo0ol0000;ooooo`;o
000000?oooooo`000?l000000oooool2o`0000?ooooo0_l00002ooooo`?o0000V?ooool000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q
00Kooooo00?o0000ooooooooool0TOooool2o`0000Cooooo0_l00003ooooo`Wo00000_ooool3o`00
00;ooooo0ol0002Hooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooo
ooooooooooooo`000006ooooo`?o0000TOooool3o`0000?ooooo0_l00003ooooo`?o000000?ooooo
o`000?l000000_l00003ooooo`Oo0000VOooool000?ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2Booooo`;o00000ooo
ool2o`0000?ooooo0ol000000ooooooo0000o`000002ooooo`;o00000oooool3o`0009_ooooo0003
ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo
00?o0000ooooooooool0Voooool4o`0000Cooooo0ol0002Qooooo`000oooool01Ol@413ooooooooo
oooooooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`2Jooooo`Go0000
1?ooool2o`000:;ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@
oiRHV008ooooo`03o`000?oooooooooo09[ooooo0_l000000ooooooo0000o`00002Xooooo`000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Go
c<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Ko
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol@413ooooooooooooooooo410@00_o
oooo00Go0000ooooooooooooooooo`000006ooooo`?o0000oooooom8ooooo`000oooool01Ol0003o
oooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooo
oooo0?ooooooB?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o
0000o`000?o<c<`01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05oa0@4?oooooo
ooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0
oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo
^[Zjo`000006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Dooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3oooooodSooooo000F
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom8ooooo`005_ooool00ol0
003oooooooooo`05ooooo`?o0000oooooom8ooooo`005_ooool00ol0003oooooooooo`3ooooooe3o
oooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooo
oom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Dooooo`03oeEEEOmVIVKo0000
0?ooooooD_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.5342 .42037 Mdot
.45162 .49386 Mdot
.40916 .52409 Mdot
.45735 .48388 Mdot
.46852 .45619 Mdot
.56844 .44594 Mdot
.3937 .50225 Mdot
.47992 .42965 Mdot
.5217 .60425 Mdot
.56497 .50842 Mdot
.53323 .45057 Mdot
.49473 .51909 Mdot
.57093 .43752 Mdot
.43602 .43415 Mdot
.45285 .59424 Mdot
.56079 .51371 Mdot
.45328 .44578 Mdot
.58714 .5049 Mdot
.57046 .50733 Mdot
.49355 .55068 Mdot
.45942 .43057 Mdot
.56257 .56104 Mdot
.49723 .44989 Mdot
.5291 .40652 Mdot
.48669 .42215 Mdot
.50886 .5164 Mdot
.47702 .59171 Mdot
.57349 .50381 Mdot
.46901 .47334 Mdot
.55932 .42511 Mdot
.42157 .5033 Mdot
.45241 .46205 Mdot
.50159 .49864 Mdot
.44683 .55464 Mdot
.56601 .4314 Mdot
.42071 .53946 Mdot
.51985 .51629 Mdot
.50889 .59156 Mdot
.48296 .4494 Mdot
.50529 .52505 Mdot
.54119 .50983 Mdot
.51354 .55611 Mdot
.43622 .51904 Mdot
.48778 .50202 Mdot
.45507 .45003 Mdot
.55044 .51938 Mdot
.43018 .43639 Mdot
.41886 .48918 Mdot
.42295 .52861 Mdot
.55427 .59464 Mdot
.47599 .45475 Mdot
.58475 .43731 Mdot
.4689 .47989 Mdot
.47763 .44347 Mdot
.56944 .5162 Mdot
.53768 .52734 Mdot
.46836 .53106 Mdot
.58607 .42796 Mdot
.45773 .45387 Mdot
.46321 .53332 Mdot
.56072 .53078 Mdot
.5386 .51662 Mdot
.46489 .55644 Mdot
.55771 .5121 Mdot
.48085 .46224 Mdot
.5253 .60787 Mdot
.43536 .46753 Mdot
.5509 .52595 Mdot
.51984 .54108 Mdot
.56513 .51633 Mdot
.41125 .55824 Mdot
.46038 .46004 Mdot
.47597 .53657 Mdot
.47287 .50136 Mdot
.55149 .4158 Mdot
.4539 .57767 Mdot
.53938 .53972 Mdot
.58218 .49869 Mdot
.40467 .54519 Mdot
.53018 .47556 Mdot
.50424 .58116 Mdot
.48603 .42773 Mdot
.4705 .42364 Mdot
.54258 .51252 Mdot
.45877 .55634 Mdot
.47136 .49383 Mdot
.44087 .56387 Mdot
.54415 .52194 Mdot
.50066 .52755 Mdot
.5806 .47869 Mdot
.4751 .47385 Mdot
.55704 .51921 Mdot
.4752 .57618 Mdot
.53799 .60513 Mdot
.40123 .51875 Mdot
.5599 .54511 Mdot
.54356 .52477 Mdot
.4235 .48784 Mdot
.42727 .4399 Mdot
.46128 .52662 Mdot
.44922 .56724 Mdot
.47347 .57162 Mdot
.46444 .4461 Mdot
.56456 .58343 Mdot
.50654 .60571 Mdot
.50648 .50446 Mdot
.43013 .41398 Mdot
.47683 .46503 Mdot
.43566 .48746 Mdot
.55878 .51975 Mdot
.51999 .40997 Mdot
.45964 .46174 Mdot
.47219 .51461 Mdot
.53429 .59331 Mdot
.447 .4376 Mdot
.58546 .44669 Mdot
.49155 .59646 Mdot
.58236 .5099 Mdot
.40939 .50052 Mdot
.47971 .57849 Mdot
.55353 .47829 Mdot
.50112 .51347 Mdot
.56728 .51057 Mdot
.4205 .51732 Mdot
.44824 .46834 Mdot
.54973 .58417 Mdot
.53327 .40986 Mdot
.50423 .51411 Mdot
.49424 .50666 Mdot
.54818 .50884 Mdot
.53986 .4741 Mdot
.453 .43821 Mdot
.54862 .40387 Mdot
.43715 .54433 Mdot
.50653 .43788 Mdot
.52793 .39772 Mdot
.57524 .56486 Mdot
.48155 .48976 Mdot
.49603 .53821 Mdot
.48051 .51102 Mdot
.47562 .46813 Mdot
.50607 .60336 Mdot
.49896 .50563 Mdot
.46059 .47912 Mdot
.49856 .48596 Mdot
.56149 .52183 Mdot
.54255 .42158 Mdot
.55271 .55235 Mdot
.44715 .43416 Mdot
.42395 .5252 Mdot
.45336 .55124 Mdot
.57514 .50362 Mdot
.47096 .46506 Mdot
.44258 .42735 Mdot
.53766 .46587 Mdot
.56186 .5143 Mdot
.53501 .51471 Mdot
.5581 .4141 Mdot
.53797 .53991 Mdot
.48837 .47621 Mdot
.43268 .57782 Mdot
.52759 .54737 Mdot
.56491 .48287 Mdot
.57792 .52158 Mdot
.48715 .52905 Mdot
.4759 .52242 Mdot
.49373 .60622 Mdot
.5202 .5774 Mdot
.54562 .56048 Mdot
.52527 .59179 Mdot
.55013 .49362 Mdot
.42777 .52534 Mdot
.44858 .50319 Mdot
.48963 .53064 Mdot
.41339 .56562 Mdot
.53286 .52017 Mdot
.56398 .54833 Mdot
.48726 .4716 Mdot
.46419 .40083 Mdot
.43828 .5396 Mdot
.45935 .48632 Mdot
.56466 .54117 Mdot
.47811 .49871 Mdot
.46781 .47797 Mdot
.57639 .44127 Mdot
.48949 .51755 Mdot
.42508 .55356 Mdot
.5619 .53378 Mdot
.54072 .60194 Mdot
.46816 .57763 Mdot
.48526 .50793 Mdot
.51553 .49326 Mdot
.51329 .40576 Mdot
.47299 .46497 Mdot
.51864 .59191 Mdot
.52773 .50641 Mdot
.55136 .59884 Mdot
.49589 .50039 Mdot
.48791 .46377 Mdot
.45709 .49645 Mdot
.45708 .52181 Mdot
.55339 .53044 Mdot
.5493 .47998 Mdot
.52534 .56796 Mdot
.56187 .51111 Mdot
.44818 .50829 Mdot
.46454 .42045 Mdot
.45642 .52797 Mdot
.42914 .55102 Mdot
.47241 .46173 Mdot
.45555 .44723 Mdot
.51154 .51286 Mdot
.51196 .53222 Mdot
.55932 .46642 Mdot
.50098 .51369 Mdot
.43672 .4242 Mdot
.55647 .52112 Mdot
.53414 .53838 Mdot
.50838 .60272 Mdot
.47985 .46978 Mdot
.50698 .47621 Mdot
.57441 .41866 Mdot
.56001 .5215 Mdot
.48359 .40064 Mdot
.52283 .44115 Mdot
.50157 .43046 Mdot
.45471 .46619 Mdot
.57269 .51239 Mdot
.42193 .54861 Mdot
.52307 .46518 Mdot
.58039 .53649 Mdot
.50763 .51149 Mdot
.52148 .59776 Mdot
.52566 .51396 Mdot
.52338 .5206 Mdot
.49281 .53885 Mdot
.53859 .58949 Mdot
.44458 .57356 Mdot
.4445 .47463 Mdot
.48963 .51766 Mdot
.57198 .51182 Mdot
.45377 .59213 Mdot
.53937 .41613 Mdot
.54492 .58609 Mdot
.39984 .49786 Mdot
.57062 .51769 Mdot
.45376 .57976 Mdot
.49028 .43056 Mdot
.58084 .52328 Mdot
.48771 .59869 Mdot
.43961 .52169 Mdot
.57973 .44623 Mdot
.46848 .59498 Mdot
.40051 .50857 Mdot
.47343 .51095 Mdot
.48732 .52228 Mdot
.50897 .46399 Mdot
.52603 .53194 Mdot
.45641 .55707 Mdot
.48306 .60133 Mdot
.51676 .57645 Mdot
.52323 .50241 Mdot
.48905 .47704 Mdot
.54835 .4694 Mdot
.47862 .5517 Mdot
.47508 .55667 Mdot
.5188 .46058 Mdot
.56163 .49439 Mdot
.51969 .50466 Mdot
.47188 .39869 Mdot
.43369 .48635 Mdot
.47252 .51496 Mdot
.53679 .60424 Mdot
.47767 .5131 Mdot
.41334 .53894 Mdot
.43795 .57535 Mdot
.54272 .53296 Mdot
.56487 .50547 Mdot
.49782 .54816 Mdot
.54185 .50061 Mdot
.50656 .53931 Mdot
.51764 .52187 Mdot
.42149 .46418 Mdot
.49129 .48846 Mdot
.50877 .59622 Mdot
.54291 .60267 Mdot
.44801 .40877 Mdot
.50557 .46301 Mdot
.44561 .48335 Mdot
.44713 .42092 Mdot
.48908 .52596 Mdot
.44383 .4355 Mdot
.58653 .45388 Mdot
.4355 .52407 Mdot
.47547 .52236 Mdot
.47533 .44075 Mdot
.56542 .49945 Mdot
.44672 .54413 Mdot
.51044 .55978 Mdot
.45741 .47976 Mdot
.48841 .49689 Mdot
.50418 .43099 Mdot
.50859 .60743 Mdot
.57055 .52181 Mdot
.49257 .52247 Mdot
.45794 .48086 Mdot
.50799 .39277 Mdot
.48512 .40643 Mdot
.49159 .4215 Mdot
.47405 .55027 Mdot
.46364 .49764 Mdot
.49416 .49069 Mdot
.51785 .47382 Mdot
.52525 .42447 Mdot
.45793 .50469 Mdot
.45269 .42092 Mdot
.50756 .52516 Mdot
.54819 .52422 Mdot
.4828 .53606 Mdot
.51673 .59043 Mdot
.43508 .53569 Mdot
.53568 .44582 Mdot
.53979 .44673 Mdot
.53547 .52265 Mdot
.5586 .49867 Mdot
.54123 .58315 Mdot
.48654 .50576 Mdot
.49479 .50817 Mdot
.54294 .59255 Mdot
.49179 .57099 Mdot
.54612 .4209 Mdot
.57988 .4368 Mdot
.47231 .51611 Mdot
.56386 .50724 Mdot
.42869 .54923 Mdot
.52044 .49045 Mdot
.45138 .54967 Mdot
.45895 .4704 Mdot
.53223 .43663 Mdot
.53946 .51781 Mdot
.43315 .47109 Mdot
.46845 .41101 Mdot
.40945 .45066 Mdot
.49936 .5034 Mdot
.54975 .5713 Mdot
.44394 .44863 Mdot
.4895 .48817 Mdot
.47375 .43657 Mdot
.5163 .5781 Mdot
.54331 .51263 Mdot
.47802 .52862 Mdot
.55428 .40806 Mdot
.45668 .44054 Mdot
.52554 .5156 Mdot
.5771 .46086 Mdot
.47826 .52468 Mdot
.45688 .40791 Mdot
.44537 .45508 Mdot
.58697 .46559 Mdot
.50626 .50272 Mdot
.48412 .46146 Mdot
.45466 .41821 Mdot
.47607 .51966 Mdot
.46081 .40807 Mdot
.44412 .45498 Mdot
.41789 .46801 Mdot
.40337 .47982 Mdot
.52584 .57662 Mdot
.467 .39761 Mdot
.47272 .49306 Mdot
.48754 .47518 Mdot
.47996 .48445 Mdot
.56347 .41267 Mdot
.52501 .45004 Mdot
.4093 .51222 Mdot
.56286 .50969 Mdot
.52278 .45711 Mdot
.44419 .56858 Mdot
.51039 .55292 Mdot
.51342 .51503 Mdot
.45707 .54922 Mdot
.3999 .52466 Mdot
.46222 .46891 Mdot
.51464 .4014 Mdot
.4551 .46185 Mdot
.56045 .44754 Mdot
.57434 .5038 Mdot
.51596 .48314 Mdot
.53179 .52545 Mdot
.45561 .54781 Mdot
.52249 .39594 Mdot
.51127 .54853 Mdot
.43935 .53858 Mdot
.45275 .46018 Mdot
.49739 .45584 Mdot
.47166 .43258 Mdot
.57649 .52703 Mdot
.49834 .49354 Mdot
.56153 .49959 Mdot
.51221 .39507 Mdot
.49678 .39497 Mdot
.44522 .54633 Mdot
.54208 .39677 Mdot
.51555 .52182 Mdot
.44656 .54108 Mdot
.42201 .53786 Mdot
.46611 .4775 Mdot
.48308 .47205 Mdot
.45049 .52168 Mdot
.53616 .48507 Mdot
.48352 .51223 Mdot
.55462 .50152 Mdot
.47368 .49953 Mdot
.41871 .49521 Mdot
.47527 .49385 Mdot
.46939 .57201 Mdot
.56185 .51981 Mdot
.49741 .40416 Mdot
.44539 .53105 Mdot
.57096 .51254 Mdot
.53609 .49511 Mdot
.55148 .52137 Mdot
.47852 .49995 Mdot
.5595 .50478 Mdot
.57116 .41147 Mdot
.43741 .54649 Mdot
.47124 .60302 Mdot
.5272 .50785 Mdot
.49917 .5421 Mdot
.51426 .53066 Mdot
.45784 .41306 Mdot
.56507 .5165 Mdot
.46815 .41688 Mdot
.53397 .49199 Mdot
.54062 .5653 Mdot
.51462 .40473 Mdot
.54629 .56232 Mdot
.46891 .53175 Mdot
.46853 .40807 Mdot
.4874 .53023 Mdot
.43017 .52173 Mdot
.5929 .48329 Mdot
.44416 .4276 Mdot
.54595 .46732 Mdot
.50711 .50432 Mdot
.54672 .48591 Mdot
.46403 .46007 Mdot
.55905 .51038 Mdot
.43979 .55232 Mdot
.47294 .47324 Mdot
.41546 .46547 Mdot
.48578 .51602 Mdot
.54432 .51136 Mdot
.49435 .53096 Mdot
.47586 .56523 Mdot
.5283 .60005 Mdot
.45419 .55086 Mdot
.51093 .58909 Mdot
.48347 .47802 Mdot
.5202 .53125 Mdot
.51752 .5658 Mdot
.47026 .50419 Mdot
.41596 .48793 Mdot
.5222 .51278 Mdot
.4383 .53445 Mdot
.48499 .39857 Mdot
.52641 .51059 Mdot
.47982 .50319 Mdot
.43806 .45277 Mdot
.52526 .53454 Mdot
.54001 .43617 Mdot
.53054 .49882 Mdot
.39587 .46599 Mdot
.43486 .58899 Mdot
.55842 .50003 Mdot
.52212 .60285 Mdot
.41601 .51796 Mdot
.43367 .58939 Mdot
.44752 .56753 Mdot
.53711 .39958 Mdot
.49559 .49348 Mdot
.45687 .4409 Mdot
.48955 .42892 Mdot
.46171 .44433 Mdot
.55349 .52305 Mdot
.52181 .56495 Mdot
.55967 .50564 Mdot
.53561 .41942 Mdot
.43147 .52999 Mdot
.44517 .56937 Mdot
.5954 .46285 Mdot
.42566 .55122 Mdot
.53583 .60076 Mdot
.48658 .4659 Mdot
.44747 .52594 Mdot
.57919 .45885 Mdot
.50865 .59996 Mdot
.48988 .46951 Mdot
.51988 .56139 Mdot
.50523 .42743 Mdot
.42397 .42653 Mdot
.46898 .59784 Mdot
.39577 .47479 Mdot
.51709 .48968 Mdot
.48815 .51788 Mdot
.58151 .51516 Mdot
.50148 .41405 Mdot
.54739 .50555 Mdot
.41883 .55772 Mdot
.55004 .59859 Mdot
.51133 .54814 Mdot
.4557 .55431 Mdot
.43945 .51859 Mdot
.57231 .45241 Mdot
.5068 .42991 Mdot
.56276 .51613 Mdot
.44074 .52083 Mdot
.56661 .43351 Mdot
.41765 .46332 Mdot
.52972 .42779 Mdot
.58128 .52256 Mdot
.43436 .47738 Mdot
.51555 .42522 Mdot
.51414 .51752 Mdot
.48212 .52241 Mdot
.54255 .52545 Mdot
.43453 .54059 Mdot
.58862 .44231 Mdot
.54217 .48517 Mdot
.55367 .49968 Mdot
.49341 .56179 Mdot
.56187 .52202 Mdot
.54094 .53225 Mdot
.47071 .50539 Mdot
.54334 .59948 Mdot
.4934 .51551 Mdot
.53869 .40468 Mdot
.55268 .52563 Mdot
.46066 .53031 Mdot
.57535 .50992 Mdot
.47415 .51225 Mdot
.57125 .48479 Mdot
.56453 .52143 Mdot
.52466 .40309 Mdot
.53596 .47328 Mdot
.46716 .58751 Mdot
.46289 .47382 Mdot
.58118 .49069 Mdot
.46134 .45516 Mdot
.52585 .48225 Mdot
.5 .52664 Mdot
.49094 .43839 Mdot
.49948 .49109 Mdot
.43483 .41345 Mdot
.45741 .46414 Mdot
.5074 .4805 Mdot
.47876 .47568 Mdot
.45375 .54033 Mdot
.59218 .4627 Mdot
.48408 .58763 Mdot
.48208 .57177 Mdot
.44924 .55859 Mdot
.55998 .50978 Mdot
.47195 .48649 Mdot
.49907 .55456 Mdot
.50967 .46458 Mdot
.39136 .49414 Mdot
.5362 .4981 Mdot
.52176 .40219 Mdot
.41767 .52029 Mdot
.47263 .39864 Mdot
.50699 .51319 Mdot
.44716 .5356 Mdot
.46641 .4451 Mdot
.48726 .51563 Mdot
.55267 .51205 Mdot
.5807 .48654 Mdot
.50165 .52624 Mdot
.44721 .57272 Mdot
.50141 .51787 Mdot
.41656 .54651 Mdot
.46106 .4608 Mdot
.4102 .44607 Mdot
.45065 .51877 Mdot
.53008 .54524 Mdot
.43928 .41752 Mdot
.50114 .43484 Mdot
.43773 .46899 Mdot
.45545 .42165 Mdot
.47271 .55821 Mdot
.48972 .51913 Mdot
.54784 .51578 Mdot
.49091 .46462 Mdot
.4896 .50976 Mdot
.55519 .50912 Mdot
.54446 .41961 Mdot
.50895 .40302 Mdot
.56667 .54493 Mdot
.56468 .48353 Mdot
.45149 .50232 Mdot
.52858 .5715 Mdot
.57669 .53318 Mdot
.53621 .42685 Mdot
.57063 .46415 Mdot
.54891 .51565 Mdot
.43307 .49698 Mdot
.53127 .50238 Mdot
.40657 .48002 Mdot
.53727 .51656 Mdot
.49413 .50928 Mdot
.58453 .51043 Mdot
.52017 .41299 Mdot
.50769 .45684 Mdot
.43338 .42774 Mdot
.53507 .41809 Mdot
.46822 .46521 Mdot
.48641 .45376 Mdot
.57197 .51628 Mdot
.48042 .46285 Mdot
.4281 .57823 Mdot
.39462 .51021 Mdot
.58664 .43658 Mdot
.46871 .51031 Mdot
.53469 .51491 Mdot
.40148 .48307 Mdot
.46232 .54958 Mdot
.47203 .46866 Mdot
.48118 .48031 Mdot
.52174 .39795 Mdot
.44588 .48726 Mdot
.55726 .52845 Mdot
.56245 .51313 Mdot
.42128 .52343 Mdot
.57671 .48985 Mdot
.57381 .48489 Mdot
.53154 .43944 Mdot
.4558 .57566 Mdot
.481 .50601 Mdot
.46047 .45048 Mdot
.44829 .4086 Mdot
.48197 .43245 Mdot
.54119 .53743 Mdot
.40612 .47514 Mdot
.52378 .50742 Mdot
.54662 .50778 Mdot
.56415 .46739 Mdot
.57426 .46098 Mdot
.51488 .50835 Mdot
.39566 .50424 Mdot
.39828 .52852 Mdot
.52071 .4268 Mdot
.49744 .48808 Mdot
.5073 .50884 Mdot
.43566 .48846 Mdot
.46764 .51978 Mdot
.43884 .52288 Mdot
.51289 .61133 Mdot
.48307 .50656 Mdot
.49363 .55805 Mdot
.49099 .51106 Mdot
.46111 .45406 Mdot
.50272 .4932 Mdot
.46371 .40651 Mdot
.5851 .42403 Mdot
.42307 .4328 Mdot
.45398 .55195 Mdot
.53466 .57943 Mdot
.52224 .3935 Mdot
.52749 .41271 Mdot
.47007 .60948 Mdot
.44813 .48905 Mdot
.57092 .4129 Mdot
.49948 .39436 Mdot
.57603 .54037 Mdot
.53597 .50518 Mdot
.58488 .52205 Mdot
.48067 .54063 Mdot
.45544 .45076 Mdot
.5718 .50168 Mdot
.47742 .43857 Mdot
.56451 .53378 Mdot
.4842 .57221 Mdot
.44003 .49629 Mdot
.48961 .57783 Mdot
.45251 .45181 Mdot
.55409 .5332 Mdot
.4487 .47437 Mdot
.57799 .44566 Mdot
.49727 .53324 Mdot
.48754 .54604 Mdot
.54916 .54522 Mdot
.41649 .53471 Mdot
.58219 .43133 Mdot
.52771 .52217 Mdot
.4509 .54353 Mdot
.4877 .41513 Mdot
.42901 .41669 Mdot
.49057 .49992 Mdot
.55859 .5185 Mdot
.45786 .47592 Mdot
.50308 .44175 Mdot
.49495 .51595 Mdot
.4229 .46595 Mdot
.4802 .46197 Mdot
.4058 .48988 Mdot
.39869 .53569 Mdot
.54096 .5231 Mdot
.4735 .45709 Mdot
.46412 .56009 Mdot
.55937 .50462 Mdot
.54857 .59177 Mdot
.4923 .50929 Mdot
.45578 .56266 Mdot
.58933 .52271 Mdot
.45087 .41616 Mdot
.47629 .59071 Mdot
.58949 .5291 Mdot
.47321 .41484 Mdot
.56387 .4434 Mdot
.56847 .50032 Mdot
.46882 .49279 Mdot
.54061 .49001 Mdot
.49134 .54166 Mdot
.46875 .50158 Mdot
.5114 .41288 Mdot
.47436 .52746 Mdot
.58993 .49665 Mdot
.56145 .46651 Mdot
.53812 .40449 Mdot
.55158 .54246 Mdot
.53776 .46379 Mdot
.54677 .51243 Mdot
.47952 .52653 Mdot
.53183 .51251 Mdot
.5899 .44823 Mdot
.39575 .52008 Mdot
.52651 .51996 Mdot
.5649 .55448 Mdot
.56293 .50382 Mdot
.53241 .53482 Mdot
.55231 .5195 Mdot
.57241 .43245 Mdot
.52358 .52249 Mdot
.51721 .42917 Mdot
.50271 .48089 Mdot
.47348 .44989 Mdot
.48543 .466 Mdot
.54216 .52057 Mdot
.49513 .50638 Mdot
.54483 .43436 Mdot
.42883 .53834 Mdot
.48682 .48013 Mdot
.47507 .5322 Mdot
.47135 .45307 Mdot
.57876 .544 Mdot
.48929 .40194 Mdot
.50378 .60381 Mdot
.56481 .51015 Mdot
.42258 .50318 Mdot
.52768 .48933 Mdot
.56208 .43491 Mdot
.56211 .447 Mdot
.43783 .5934 Mdot
.52189 .55053 Mdot
.58768 .49412 Mdot
.47292 .50698 Mdot
.51979 .40089 Mdot
.46348 .47496 Mdot
.48854 .5046 Mdot
.41771 .53313 Mdot
.5498 .45874 Mdot
.42222 .49239 Mdot
.56286 .42652 Mdot
.47384 .49115 Mdot
.42439 .54456 Mdot
.48396 .58477 Mdot
.46451 .60456 Mdot
.50913 .42346 Mdot
.47742 .5046 Mdot
.51984 .53517 Mdot
.5224 .49821 Mdot
.44172 .45417 Mdot
.56456 .43312 Mdot
.59324 .47097 Mdot
.56808 .40995 Mdot
.4342 .57455 Mdot
.46033 .51692 Mdot
.54208 .50887 Mdot
.56178 .49885 Mdot
.53364 .55691 Mdot
.45785 .50222 Mdot
.55457 .48346 Mdot
.46374 .49223 Mdot
.50771 .58948 Mdot
.43568 .49251 Mdot
.54684 .57616 Mdot
.43178 .49506 Mdot
.43815 .40904 Mdot
.55733 .50927 Mdot
.41369 .45416 Mdot
.5256 .50406 Mdot
.46115 .52931 Mdot
.42457 .56109 Mdot
.46113 .60795 Mdot
.53128 .42026 Mdot
.55433 .50983 Mdot
.48564 .52811 Mdot
.50353 .42701 Mdot
.45974 .43754 Mdot
.57405 .49802 Mdot
.46295 .47558 Mdot
.46822 .58757 Mdot
.46365 .48706 Mdot
.54531 .44147 Mdot
.55961 .50971 Mdot
.43743 .52153 Mdot
.55899 .53932 Mdot
.46885 .52902 Mdot
.50135 .41852 Mdot
.42124 .51618 Mdot
.52263 .50979 Mdot
.47112 .51038 Mdot
.43348 .57509 Mdot
.56451 .50499 Mdot
.51029 .41903 Mdot
.58575 .51526 Mdot
.48302 .46219 Mdot
.44381 .48305 Mdot
.43653 .49336 Mdot
.52476 .52298 Mdot
.42714 .4273 Mdot
.43209 .47375 Mdot
.40729 .48861 Mdot
.54878 .52137 Mdot
.50554 .51031 Mdot
.53517 .50497 Mdot
.50738 .5555 Mdot
.53126 .47562 Mdot
.46657 .50836 Mdot
.51104 .59438 Mdot
.53174 .4183 Mdot
.55324 .51947 Mdot
.56233 .54177 Mdot
.41769 .56793 Mdot
.40156 .53892 Mdot
.48359 .56465 Mdot
.47225 .61044 Mdot
.50176 .55541 Mdot
.55563 .52211 Mdot
.47885 .537 Mdot
.44681 .47144 Mdot
.56684 .47096 Mdot
.43274 .43369 Mdot
.50228 .39404 Mdot
.40878 .5621 Mdot
.48548 .51591 Mdot
.51258 .5028 Mdot
.57162 .45634 Mdot
.47888 .5019 Mdot
.47486 .46459 Mdot
.46551 .56309 Mdot
.48543 .51635 Mdot
.49439 .48938 Mdot
.48978 .57936 Mdot
.56061 .49627 Mdot
.44092 .55703 Mdot
.45235 .5112 Mdot
.57538 .50079 Mdot
.45369 .49973 Mdot
.59593 .44169 Mdot
.55209 .48614 Mdot
.51296 .59432 Mdot
.41378 .49408 Mdot
.54549 .41994 Mdot
.48906 .4135 Mdot
.47341 .49284 Mdot
.48143 .44305 Mdot
.55428 .51747 Mdot
.49894 .52666 Mdot
.58822 .4424 Mdot
.42186 .43579 Mdot
.56187 .41225 Mdot
.44392 .44397 Mdot
.47204 .47989 Mdot
.59198 .4933 Mdot
.4581 .45 Mdot
.50222 .5318 Mdot
.55453 .51207 Mdot
.43403 .56891 Mdot
.55985 .41278 Mdot
.54556 .54691 Mdot
.50374 .50637 Mdot
.42698 .56021 Mdot
.52957 .48783 Mdot
.49142 .47175 Mdot
.54974 .59541 Mdot
.46611 .46519 Mdot
.43558 .49951 Mdot
.47625 .51517 Mdot
.46907 .51668 Mdot
.5428 .45938 Mdot
.45737 .52207 Mdot
.45358 .42948 Mdot
.45569 .50361 Mdot
.55478 .58486 Mdot
.46834 .49082 Mdot
.43702 .56882 Mdot
.49015 .53722 Mdot
.47638 .44006 Mdot
.44641 .43151 Mdot
.4864 .55981 Mdot
.51889 .57225 Mdot
.48207 .51738 Mdot
.48882 .45252 Mdot
.45066 .472 Mdot
.49969 .51927 Mdot
.47552 .56801 Mdot
.40179 .46613 Mdot
.52608 .41029 Mdot
.49254 .59146 Mdot
.54423 .51476 Mdot
.4909 .50244 Mdot
.45126 .4109 Mdot
.48679 .56585 Mdot
.47338 .59842 Mdot
.46739 .4994 Mdot
.47443 .44317 Mdot
.49437 .52265 Mdot
.49056 .61213 Mdot
.46718 .48355 Mdot
.46119 .51875 Mdot
.51511 .5597 Mdot
.51985 .60657 Mdot
.44529 .47028 Mdot
.48095 .50207 Mdot
.55235 .59805 Mdot
.53623 .51573 Mdot
.43087 .42341 Mdot
.48082 .59541 Mdot
.44332 .57879 Mdot
.56552 .4196 Mdot
.48959 .42249 Mdot
.43121 .53221 Mdot
.46723 .49635 Mdot
.55369 .53518 Mdot
.53431 .41579 Mdot
.42716 .47761 Mdot
.42129 .47401 Mdot
.44716 .53352 Mdot
.51452 .40209 Mdot
.57607 .50507 Mdot
.47923 .51214 Mdot
.58758 .49962 Mdot
.44262 .47946 Mdot
.45996 .49118 Mdot
.56276 .4957 Mdot
.46508 .57052 Mdot
.56283 .51847 Mdot
.44278 .41053 Mdot
.42577 .57835 Mdot
.50735 .57127 Mdot
.47645 .49502 Mdot
.56685 .5551 Mdot
.51017 .51142 Mdot
.52074 .50921 Mdot
.43115 .52109 Mdot
.41979 .54848 Mdot
.45685 .51986 Mdot
.54838 .51228 Mdot
.48941 .58408 Mdot
.48591 .55608 Mdot
.50474 .41005 Mdot
.58535 .44264 Mdot
.52785 .57708 Mdot
.46897 .39712 Mdot
.56539 .5173 Mdot
.42001 .42885 Mdot
.47798 .49706 Mdot
.51264 .5203 Mdot
.58579 .50267 Mdot
.58991 .48468 Mdot
.48158 .47226 Mdot
.46463 .44242 Mdot
.51327 .43428 Mdot
.44031 .44387 Mdot
.40916 .49675 Mdot
.50433 .41337 Mdot
.46547 .51364 Mdot
.56842 .52109 Mdot
.51802 .48448 Mdot
.5345 .4206 Mdot
.488 .45513 Mdot
.48326 .40739 Mdot
.54364 .50177 Mdot
.55668 .50766 Mdot
.55512 .53341 Mdot
.47053 .5813 Mdot
.40615 .53143 Mdot
.41065 .56034 Mdot
.58266 .49131 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo09gooooo1ol00002ooooo`;o
0000Woooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo09Cooooo0_l00007ooooo`Oo00000_ooool4o`0000;o
oooo0_l0002Iooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`?o
0000Toooool5o`000004ooooool0003o0000o`0000Wooooo1Ol000001?oooooo0000o`000?l0002I
ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001ooo
ool00ol0003oooooooooo`2Cooooo`Go000000?oooooo`000?l000000_l000001?oooooo0000o`00
0?ooool7o`0000?ooooo0_l000000ooooooo0000o`00002Gooooo`000oooool01Ol0003ooooooooo
oooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`2Cooooo`;o
00001?ooool4o`000004ooooool0003o0000ooooo`Co000000?oooooo`000?l000000_l000001?oo
oooo0000o`000?ooool2o`0009Oooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo08[ooooo0_l00002ooooo`So00000oooool3
o`0000Cooooo0_l000000ooooooo0000o`000008o`0000?ooooo0_l00003ooooo`;o0000T?ooool0
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000
ooooooooool0ROooool=o`0000Gooooo0_l00003ooooo`Co000000?oooooo`000?l000001?l00005
ooooo`So0000Soooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003o
oooo00Kooooo00?o0000ooooooooool0R?ooool3o`000003ooooool0003o000000Go000000?ooooo
o`000?l000000_l00002ooooo`?o00000_ooool5o`000003ooooool0003o000000;o000000Cooooo
o`000?l0003o00000_ooool9o`0008oooooo000Nooooo`03o`000?oooooooooo08Oooooo0ol00000
1?oooooo0000o`000?ooool4o`0000;ooooo1?l00002ooooo`;o00000oooool2o`000003ooooool0
003o000000Gooooo2_l000001?oooooo0000o`000?ooool2o`0008kooooo000Nooooo`03o`000?oo
oooooooo08Oooooo0_l00002ooooo`Oo000000Coooooo`000?l0003o00001?ooool4o`000004oooo
ool0003o0000ooooo`;o00001Oooool6o`0000Gooooo0_l000000ooooooo0000o`00002>ooooo`00
7_ooool00ol0003oooooooooo`28ooooo`Co000000?oooooo`000?l000000ol000000ooooooo0000
o`000002o`0000?ooooo1?l00003ooooo`Co00000_ooool8o`0000?ooooo0_l00006ooooo`;o0000
Roooool001kooooo00?o0000ooooooooool0Q?ooool:o`0000Oooooo0_l00003ooooo`?o00000ooo
ool<o`0000Kooooo0ol00005ooooo`;o0000Roooool001kooooo00?o0000ooooooooool0Q?ooool7
o`000003ooooool0003o000000Go00001Oooool5o`0000;ooooo1?l000001Ooooooo0000o`000?l0
003ooooo00Co00001oooool3o`0000?ooooo0ol0002;ooooo`007_ooool00ol0003oooooooooo`25
ooooo`;o00000_ooool3o`000003ooooool0003o000000Co00000_ooool2o`000003ooooool0003o
000000?o00000_ooool7o`0000Oooooo0_l00004ooooo`Go000000?oooooo`000?l00000S?ooool0
01kooooo00?o0000ooooooooool0QOooool2o`000003ooooool0003o000000Go00000_ooool2o`00
00;ooooo0ol000000ooooooo0000o`000004ooooo`Ko00001?ooool6o`0000Cooooo2_l0002:oooo
o`007_ooool00ol0003oooooooooo`25ooooo`Go00000_ooool7o`0000?ooooo0ol00002ooooo`;o
00001?ooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`0000Wooooo1ol0002:ooooo`00
7_ooool00ol0003oooooooooo`27ooooo`;o00000_ooool3o`000003ooooool0003o000000Co0000
00?oooooo`000?l000000_l000000ooooooo0000o`000002ooooo`;o00001Oooool2o`000003oooo
ool0003o000000;ooooo0_l00004ooooo`;o00000_ooool2o`000005ooooool0003o0000o`000?oo
ool00_l00027ooooo`007_ooool00ol0003oooooooooo`21ooooo`;o00002?ooool3o`000003oooo
ool0003o000000Wo00001Oooool2o`0000Wooooo1Ol00004ooooo`Co000000?oooooo`000?l00000
0ol000000ooooooo0000o`000027ooooo`007_ooool00ol0003oooooooooo`21ooooo`;o00002Ooo
ool2o`000003ooooool0003o000000Oo000000?oooooo`000?l000000oooool2o`0000Oooooo0_l0
00001?oooooo0000o`000?l00005ooooo`Go000000?oooooo`000?l000001?l00029ooooo`007_oo
ool2o`0008;ooooo0_l00007ooooo`Co000000?oooooo`000?l000000ol000001Ooooooo0000o`00
0?l0003ooooo00Co000000?oooooo`000?l000001oooool4o`0000Oooooo0_l00002ooooo`;o0000
1?ooool2o`0008Wooooo000Nooooo`03o`000?oooooooooo087ooooo0ol00006ooooo`oo000000Go
ooooo`000?l0003o0000ooooo`02o`0000Wooooo0_l0000;ooooo`;o00000oooool2o`0008[ooooo
000Nooooo`03o`000?oooooooooo08;ooooo0_l00007ooooo`Co00000_ooool8o`000005ooooool0
003o0000o`000?ooool00_l000000ooooooo0000o`000003ooooo`;o00001?ooool2o`000003oooo
ool0003o000000Gooooo1?l000000ooooooo0000o`00002:ooooo`007_ooool00ol0003ooooooooo
o`2?ooooo`co00001_ooool2o`0000;ooooo0ol00004ooooo`;o000000?oooooo`000?l000001_oo
ool3o`0000;ooooo0_l00029ooooo`007_ooool00ol0003oooooooooo`23ooooo`Co00002?ooool>
o`0000?ooooo1?l000001?oooooo0000o`000?l00003ooooo`;o00002?ooool5o`000003ooooool0
003o000000;o0000R?ooool001kooooo00?o0000ooooooooool0OOooool4o`0000;ooooo1?l00002
ooooo`;o00000oooool?o`0000?ooooo1?l00002ooooo`;o00000oooool4o`0000?ooooo1Ol00004
ooooo`Co0000R?ooool001kooooo00?o0000ooooooooool0OOooool4o`0000?ooooo0ol00002oooo
o`?o000000?oooooo`000?l000001Ol000000ooooooo0000o`000007o`0000oooooo0ol00002oooo
o`Co00001oooool2o`0008Sooooo000Nooooo`03o`000?oooooooooo07gooooo0_l00006ooooo`;o
000000?oooooo`000?l000001_l000000ooooooo0000o`00000;o`0000Kooooo0_l00004ooooo`?o
000000?oooooo`000?l000001?ooool2o`0000Oooooo0_l00028ooooo`007_ooool00ol0003ooooo
ooooo`1mooooo`;o000000?oooooo`000?l000000oooool6o`000003ooooool0003o000000;o0000
00?oooooo`000?l000002_l00004ooooo`;o000000?oooooo`000?l000000_ooool5o`0009[ooooo
000Nooooo`03o`000?oooooooooo07oooooo0ol00005ooooo`Co000000?oooooo`000?l000000ooo
ool6o`000003ooooool0003o000000?o00000_ooool4o`0000Gooooo0ol00003ooooo`Co00001ooo
ool2o`0008cooooo000Nooooo`03o`000?oooooooooo07kooooo1?l0000:ooooo`?o00000_ooool6
o`000003ooooool0003o000000;o00000oooool4o`000004ooooool0003o0000ooooo`;o00001Ooo
ool4o`000004ooooool0003o0000o`0000?ooooo0_l00002ooooo`;o0000R?ooool001kooooo00?o
0000ooooooooool0O_ooool2o`0000Wooooo0_l000001?oooooo0000o`000?l00002ooooo`Ko0000
00?oooooo`000?l000001?ooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool8o`000003
ooooool0003o000000?o000000Coooooo`000?l0003ooooo0ol00028ooooo`007_ooool00ol0003o
ooooooooo`20ooooo`;o000000?oooooo`000?l000000ol000001Ooooooo0000o`000?l0003ooooo
00?o000000?oooooo`000?l000001?l000001?oooooo0000o`000?ooool5o`0000Cooooo3Ol00005
ooooo`Go000000?oooooo`000?l00000ROooool001kooooo00?o0000ooooooooool0P?ooool2o`00
0003ooooool0003o000000?o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000007o`00
0003ooooool0003o000000Co00000_ooool8o`000003ooooool0003o000000Wooooo1?l000000ooo
oooo0000o`000029ooooo`007_ooool00ol0003oooooooooo`1kooooo`;o00001Oooool5o`000003
ooooool0003o000000?o00000_ooool:o`0000Cooooo1?l00002ooooo`;o00001?ooool3o`0000?o
oooo0_l000001?oooooo0000o`000?l00004ooooo`Go0000ROooool001kooooo00?o0000oooooooo
ool0Noooool2o`000004ooooool0003o0000ooooo`Go00000_ooool5o`0000;ooooo0ol000000ooo
oooo0000o`000004o`0000;ooooo0_l00002ooooo`;o00001Oooool6o`0000?ooooo1ol000000ooo
oooo0000o`000005o`0008Wooooo000Nooooo`;o0000OOooool4o`000003ooooool0003o000000Ko
oooo0_l00004oooooa?o00001?ooool9o`000003ooooool0003o000000co0000ROooool001kooooo
00?o0000ooooooooool0O?ooool3o`0000;ooooo0_l00002ooooo`;o00001oooool5o`000003oooo
ool0003o000002?o000000Coooooo`000?l0003o0000R_ooool001kooooo00?o0000ooooooooool0
OOooool3o`0000Gooooo0_l00007ooooo`Go000000?oooooo`000?l000004ol000000ooooooo0000
o`000004o`000003ooooool0003o000000Ko00000_ooool2o`0008[ooooo000Nooooo`03o`000?oo
oooooooo07cooooo1?l0000>ooooo`?o00000oooool;o`000003ooooool0003o000000Oo00000ooo
ool@o`0008_ooooo000Nooooo`03o`000?oooooooooo07cooooo0_l00003ooooo`;o00003?ooool2
o`0000;ooooo:Ol0002;ooooo`007_ooool00ol0003oooooooooo`21ooooo`Ko00002ooooolVo`00
0004ooooool0003o0000o`0008_ooooo000Nooooo`03o`000?oooooooooo07gooooo0ol00003oooo
o`Co000000?oooooo`000?l000000ol000000ooooooo0000o`00000Xo`000004ooooool0003o0000
o`0008_ooooo000Nooooo`03o`000?oooooooooo07gooooo0ol000001?oooooo0000o`000?ooool3
o`000003ooooool0003o000000?o000000?oooooo`000?l000004?l00003oooooaCo000000?ooooo
o`000?l000000ol0002:ooooo`007_ooool00ol0003oooooooooo`1nooooo`;o000000?oooooo`00
0?l000000_ooool?o`0000;ooooo9ol0002:ooooo`007_ooool00ol0003oooooooooo`1mooooo`?o
00001Oooool5o`0000?ooooo0_l000000ooooooo0000o`00000;o`000003ooooool0003o000000?o
00001_ooool:o`0000Cooooo0_l00003ooooo`;o0000ROooool001kooooo00?o0000ooooooooool0
OOooool2o`000003ooooool0003o000000;ooooo0ol000000ooooooo0000o`000003ooooo`;o0000
00?oooooo`000?l000001ol000000ooooooo0000o`000005o`000003ooooool0003o000000Go0000
0oooool2o`0000;ooooo1?l00003ooooo`;o00000oooool2o`0008Wooooo000Nooooo`03o`000?oo
oooooooo07kooooo1?l000001?oooooo0000o`000?l00002ooooo`Co000000?oooooo`000?l00000
0oooool?o`000003ooooool0003o000000Oo000000?oooooo`000?l000000_ooool5o`0000;ooooo
1?l0002<ooooo`007_ooool00ol0003oooooooooo`1nooooo`;o00000_ooool=o`0000Sooooo2?l0
0002ooooo`;o00000_ooool9o`0000;ooooo1Ol00004ooooo`;o0000S?ooool001kooooo00?o0000
ooooooooool0O_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000:o`0000Oooooo0_l00000
0ooooooo0000o`000003o`000003ooooool0003o000000;ooooo0_l00003ooooo`Co000000Cooooo
o`000?l0003ooooo0ol00002ooooo`;o0000S_ooool001kooooo00?o0000ooooooooool0Ooooool2
o`0000Gooooo0_l000001Ooooooo0000o`000?l0003ooooo00Co00001oooool2o`0000;ooooo1?l0
0005ooooo`;o000000Coooooo`000?l0003ooooo0_l000001Ooooooo0000o`000?l0003ooooo00Co
000000Coooooo`000?l0003o0000SOooool001kooooo00?o0000ooooooooool0Ooooool2o`0000;o
oooo1Ol00002ooooo`;o000000?oooooo`000?l000000ol00008ooooo`;o00000_ooool2o`0000;o
oooo0_l00003ooooo`?o00000oooool3o`0000;ooooo1?l00002ooooo`;o0000SOooool001kooooo
0_l00024ooooo`Ko000000Coooooo`000?l0003ooooo1ol00002ooooo`?o000000?oooooo`000?l0
00001?l00002ooooo`;o00000_ooool3o`0000Cooooo0_l00004ooooo`;o0000T_ooool001kooooo
00?o0000ooooooooool0Q_ooool3o`0000;ooooo2Ol00002ooooo`?o00000oooool4o`0000;ooooo
0_l00002ooooo`;o00002?ooool2o`0000;ooooo0_l0002Aooooo`007_ooool00ol0003ooooooooo
o`24ooooo`Co00000oooool4o`000003ooooool0003o000000?o000000?oooooo`000?l000000_oo
ool;o`0000Cooooo0_l00005ooooo`;o00000_ooool2o`00097ooooo000Nooooo`03o`000?oooooo
oooo087ooooo2?l00002ooooo`;o000000?oooooo`000?l000001Ol000000ooooooo0000o`000002
ooooo`Co000000?oooooo`000?l000001?l00004ooooo`;o00000_ooool2o`0000Cooooo0ol0002A
ooooo`007_ooool00ol0003oooooooooo`21ooooo`?o00000_ooool3o`0000;ooooo0_l000000ooo
oooo0000o`000002o`000004ooooool0003o0000ooooo`;o00000_ooool4o`0000Cooooo1Ol00006
ooooo`;o00001?ooool2o`0009;ooooo000Nooooo`03o`000?oooooooooo087ooooo0ol00007oooo
o`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000002ooooo`Oo00001_ooool4o`00
00Cooooo0ol00008ooooo`;o0000S_ooool001kooooo00?o0000ooooooooool0P_ooool4o`0000?o
oooo1ol00006ooooo`Ko00002?ooool5o`0000?ooooo0_l00009ooooo`;o0000S_ooool001kooooo
00?o0000ooooooooool0Q?ooool2o`0000?ooooo1_l00004ooooo`Go000000Coooooo`000?l0003o
oooo0_l00003ooooo`;o00000_ooool5o`0000Gooooo0_l0002Fooooo`007_ooool00ol0003ooooo
ooooo`29ooooo`Ko000000Coooooo`000?l0003ooooo1Ol000001?oooooo0000o`000?ooool2o`00
00?ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00001?ooool3o`0009Kooooo000Noooo
o`03o`000?oooooooooo08Kooooo2?l000001?oooooo0000o`000?l00002ooooo`Ko000000?ooooo
o`000?l000001oooool5o`000003ooooool0003o000000;ooooo0_l0002Gooooo`007_ooool00ol0
003oooooooooo`26ooooo`Go000000Coooooo`000?l0003ooooo0_l00003ooooo`?o000000Cooooo
o`000?l0003ooooo0_l00003ooooo`;o00000_ooool5o`000003ooooool0003o000009_ooooo000N
ooooo`03o`000?oooooooooo08oooooo0_l00004ooooo`;o00000_ooool4o`0000?ooooo0_l0000:
ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0009;ooooo000Nooooo`03o`000?oooooo
oooo09Cooooo0_l00003ooooo`Co00003oooool6o`000003ooooool0003o000009;ooooo000Noooo
o`03o`000?oooooooooo08Wooooo0_l00009ooooo`;o000000?oooooo`000?l000000_l000000ooo
oooo0000o`000003ooooo`So00000_ooool5o`0009Oooooo0003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooo
oooo08Wooooo0ol00003ooooo`;o00000oooool2o`000003ooooool0003o000000?ooooo0_l00003
ooooo`So000000?oooooo`000?l000001_l0002Eooooo`000oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooooooo
o`2:ooooo`;o00000oooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo1_l0
0003ooooo`Co000000Coooooo`000?l0003o0000UOooool000?ooooo00Go410@oooooooooooooooo
oa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`0009Cooooo2_l00003ooooo`;o
00000_ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000000_l0002Fooooo`00
0oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06oooo
o`03o`000?oooooooooo09Gooooo0ol000001?oooooo0000o`000?l00004ooooo`?o00000_ooool<
o`0009Kooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0Toooool4o`0000;ooooo0_l000000ooooooo0000o`00
0002ooooo`?o00000_ooool3o`0000;ooooo1?l0002Iooooo`000oooool01Ol@413ooooooooooooo
oooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`2Booooo`Go00001Ooo
ool2o`0000?ooooo0_l00002ooooo`Co00000_ooool2o`0009[ooooo0003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo09;ooooo0_l0
00000ooooooo0000o`000004ooooo`;o00001?ooool4o`0000;ooooo0_l0002Nooooo`000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003ooooo
ooooo`2Kooooo`;o00001_ooool2o`000:;ooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003ooooo
odWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?ooooooB?oo
ool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooo
oonHV9So8B4Q00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol@413ooooooooo
oooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000oooooom8ooooo`00
0oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06oooo
o`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go0000ooooooooooooooooo`00000;oooo
o`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`3oooooodSooooo0003oooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o
0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Dooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3o
ooooodSooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom8oooo
o`005_ooool00ol0003oooooooooo`05ooooo`?o0000oooooom8ooooo`005_ooool00ol0003ooooo
ooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000
ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Dooooo`03
oeEEEOmVIVKo00000?ooooooD_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.54935 .43354 Mdot
.46369 .4795 Mdot
.41269 .50186 Mdot
.47076 .4729 Mdot
.48417 .4571 Mdot
.57647 .46783 Mdot
.39846 .47984 Mdot
.49798 .43524 Mdot
.49824 .6051 Mdot
.55521 .5282 Mdot
.54183 .4671 Mdot
.48791 .51459 Mdot
.58051 .45874 Mdot
.45779 .42342 Mdot
.43418 .57878 Mdot
.54838 .53028 Mdot
.47428 .43984 Mdot
.57564 .52907 Mdot
.56001 .52921 Mdot
.47778 .53946 Mdot
.48041 .42912 Mdot
.54181 .56773 Mdot
.50773 .46057 Mdot
.54813 .41736 Mdot
.50565 .42871 Mdot
.50234 .51752 Mdot
.45702 .57957 Mdot
.5638 .52746 Mdot
.48164 .47117 Mdot
.57212 .44348 Mdot
.43159 .48292 Mdot
.4711 .45381 Mdot
.5035 .50569 Mdot
.43755 .53331 Mdot
.57721 .45136 Mdot
.42142 .51691 Mdot
.51259 .51977 Mdot
.48675 .58638 Mdot
.4962 .45684 Mdot
.49387 .52097 Mdot
.53543 .52072 Mdot
.4946 .55037 Mdot
.44114 .49921 Mdot
.49077 .50148 Mdot
.47507 .44464 Mdot
.53577 .52966 Mdot
.45105 .42371 Mdot
.43154 .46989 Mdot
.42685 .50701 Mdot
.53219 .60559 Mdot
.49001 .45948 Mdot
.59393 .45944 Mdot
.48047 .47553 Mdot
.49335 .44867 Mdot
.55392 .53504 Mdot
.52115 .5294 Mdot
.46292 .51558 Mdot
.59812 .44892 Mdot
.47653 .44929 Mdot
.45804 .51623 Mdot
.53997 .54058 Mdot
.52751 .52361 Mdot
.45256 .53802 Mdot
.54681 .52788 Mdot
.49233 .46877 Mdot
.50155 .61068 Mdot
.45392 .45319 Mdot
.53318 .53331 Mdot
.50221 .53683 Mdot
.55041 .53373 Mdot
.40477 .53604 Mdot
.47756 .45585 Mdot
.4667 .52236 Mdot
.47834 .49318 Mdot
.56711 .4313 Mdot
.43824 .55943 Mdot
.51965 .54001 Mdot
.5736 .52459 Mdot
.40125 .52236 Mdot
.53488 .49335 Mdot
.48296 .57416 Mdot
.50394 .43461 Mdot
.4907 .4268 Mdot
.53446 .52256 Mdot
.4474 .53684 Mdot
.47949 .48699 Mdot
.43046 .54232 Mdot
.5289 .52829 Mdot
.48874 .52161 Mdot
.57888 .50592 Mdot
.48626 .47535 Mdot
.54171 .53242 Mdot
.45741 .56164 Mdot
.51472 .61166 Mdot
.40446 .49608 Mdot
.53853 .55087 Mdot
.52709 .52966 Mdot
.43701 .46905 Mdot
.44774 .42624 Mdot
.45936 .50996 Mdot
.43664 .54693 Mdot
.45669 .55616 Mdot
.48285 .44568 Mdot
.54437 .59531 Mdot
.48337 .60247 Mdot
.50684 .5111 Mdot
.45053 .40072 Mdot
.48891 .46936 Mdot
.44993 .47025 Mdot
.54291 .5335 Mdot
.53921 .41958 Mdot
.4767 .45683 Mdot
.47226 .5024 Mdot
.51143 .59623 Mdot
.46931 .42985 Mdot
.5919 .47023 Mdot
.47017 .58793 Mdot
.56871 .53247 Mdot
.41842 .47938 Mdot
.46099 .56529 Mdot
.55713 .50046 Mdot
.4971 .51406 Mdot
.55581 .53048 Mdot
.42731 .49627 Mdot
.46652 .45733 Mdot
.52742 .59057 Mdot
.55125 .42161 Mdot
.49962 .51526 Mdot
.49468 .50766 Mdot
.54219 .52194 Mdot
.54474 .4937 Mdot
.4747 .43285 Mdot
.56778 .41718 Mdot
.43298 .52245 Mdot
.51923 .44888 Mdot
.54923 .40702 Mdot
.55699 .57582 Mdot
.48905 .48973 Mdot
.4821 .52901 Mdot
.48019 .50351 Mdot
.48754 .47123 Mdot
.48314 .59947 Mdot
.49948 .50951 Mdot
.47408 .47068 Mdot
.50321 .49497 Mdot
.54393 .53545 Mdot
.55683 .43656 Mdot
.53109 .55528 Mdot
.46955 .427 Mdot
.42879 .50392 Mdot
.44408 .53104 Mdot
.56494 .52755 Mdot
.48453 .46612 Mdot
.46471 .41953 Mdot
.54395 .48443 Mdot
.54893 .53111 Mdot
.52615 .5218 Mdot
.57486 .43026 Mdot
.5184 .53979 Mdot
.49604 .48399 Mdot
.41987 .55795 Mdot
.50809 .54431 Mdot
.56533 .50746 Mdot
.55903 .53873 Mdot
.47735 .51925 Mdot
.47153 .51003 Mdot
.47143 .60006 Mdot
.49876 .57504 Mdot
.52371 .56238 Mdot
.50278 .59139 Mdot
.55053 .51348 Mdot
.4321 .50419 Mdot
.45836 .4869 Mdot
.47881 .52125 Mdot
.40418 .54466 Mdot
.52004 .52402 Mdot
.54299 .55478 Mdot
.49583 .47956 Mdot
.48702 .39768 Mdot
.43534 .51822 Mdot
.47168 .47577 Mdot
.54347 .54869 Mdot
.4836 .49404 Mdot
.47992 .47359 Mdot
.58454 .46365 Mdot
.4843 .51174 Mdot
.42069 .5307 Mdot
.54064 .54267 Mdot
.51746 .6088 Mdot
.45091 .56197 Mdot
.48585 .5038 Mdot
.51834 .50576 Mdot
.53402 .41378 Mdot
.48605 .46724 Mdot
.49631 .58951 Mdot
.52583 .51631 Mdot
.52859 .6089 Mdot
.49835 .50457 Mdot
.49755 .47269 Mdot
.46752 .48343 Mdot
.45805 .5049 Mdot
.53386 .53738 Mdot
.55301 .50129 Mdot
.50427 .56638 Mdot
.55104 .52897 Mdot
.45631 .49125 Mdot
.48569 .42147 Mdot
.45482 .51025 Mdot
.42477 .52819 Mdot
.48612 .46425 Mdot
.47585 .44229 Mdot
.50722 .51639 Mdot
.49693 .52788 Mdot
.56446 .48888 Mdot
.49682 .51411 Mdot
.45827 .41433 Mdot
.54011 .53334 Mdot
.51535 .53742 Mdot
.48532 .59931 Mdot
.49048 .47477 Mdot
.51244 .48966 Mdot
.58897 .43773 Mdot
.54291 .53485 Mdot
.50692 .40216 Mdot
.53318 .45494 Mdot
.51694 .43999 Mdot
.4722 .45797 Mdot
.55843 .53305 Mdot
.41951 .52551 Mdot
.52933 .48102 Mdot
.5612 .54957 Mdot
.5045 .51489 Mdot
.49857 .5972 Mdot
.51941 .51967 Mdot
.51229 .52253 Mdot
.47936 .52881 Mdot
.51578 .59319 Mdot
.43114 .55353 Mdot
.46164 .46122 Mdot
.48437 .51186 Mdot
.5583 .53255 Mdot
.43544 .57644 Mdot
.55526 .42973 Mdot
.52215 .59116 Mdot
.40752 .47646 Mdot
.55386 .53617 Mdot
.43768 .56187 Mdot
.50709 .43851 Mdot
.56204 .53999 Mdot
.4665 .5896 Mdot
.44314 .50213 Mdot
.58656 .46945 Mdot
.44849 .58168 Mdot
.40597 .48617 Mdot
.47463 .50007 Mdot
.48001 .51389 Mdot
.51584 .47732 Mdot
.50945 .53021 Mdot
.44521 .53718 Mdot
.46175 .59141 Mdot
.49562 .57312 Mdot
.5234 .51344 Mdot
.49649 .4849 Mdot
.55394 .49032 Mdot
.46499 .53641 Mdot
.46096 .54047 Mdot
.52578 .4754 Mdot
.55991 .517 Mdot
.5191 .5139 Mdot
.49535 .39703 Mdot
.44815 .469 Mdot
.47234 .50278 Mdot
.51352 .61012 Mdot
.47673 .50356 Mdot
.41341 .51626 Mdot
.42507 .55522 Mdot
.52395 .535 Mdot
.55692 .52599 Mdot
.48179 .53814 Mdot
.54136 .51635 Mdot
.49081 .53245 Mdot
.50643 .52208 Mdot
.439 .44744 Mdot
.49698 .49376 Mdot
.48629 .59165 Mdot
.51962 .61053 Mdot
.47036 .40249 Mdot
.51282 .4757 Mdot
.46064 .46881 Mdot
.46939 .41516 Mdot
.47998 .51723 Mdot
.46622 .42697 Mdot
.59098 .47859 Mdot
.43877 .50366 Mdot
.47128 .50982 Mdot
.492 .44511 Mdot
.56067 .52191 Mdot
.44073 .52338 Mdot
.49135 .5536 Mdot
.47167 .46959 Mdot
.49308 .4984 Mdot
.5191 .44091 Mdot
.48508 .60513 Mdot
.55143 .53792 Mdot
.48422 .51576 Mdot
.47181 .47073 Mdot
.53185 .39697 Mdot
.5073 .40964 Mdot
.51038 .42869 Mdot
.46151 .53368 Mdot
.4724 .48654 Mdot
.49887 .49659 Mdot
.52307 .48935 Mdot
.53996 .43644 Mdot
.46576 .49048 Mdot
.47492 .41761 Mdot
.49581 .52164 Mdot
.53144 .53125 Mdot
.47197 .52398 Mdot
.49457 .5873 Mdot
.43425 .5143 Mdot
.5451 .46248 Mdot
.54913 .46418 Mdot
.52099 .52591 Mdot
.55572 .51895 Mdot
.51867 .58655 Mdot
.488 .5031 Mdot
.49451 .50881 Mdot
.5199 .59832 Mdot
.47276 .56002 Mdot
.5604 .43646 Mdot
.58921 .4587 Mdot
.47171 .50362 Mdot
.55506 .5269 Mdot
.42505 .52643 Mdot
.52381 .50479 Mdot
.44283 .52925 Mdot
.4747 .46297 Mdot
.54344 .45175 Mdot
.52726 .5244 Mdot
.45103 .45601 Mdot
.49019 .41163 Mdot
.42536 .43215 Mdot
.50043 .50823 Mdot
.52772 .57568 Mdot
.46569 .43888 Mdot
.49564 .49276 Mdot
.49159 .44031 Mdot
.49505 .57461 Mdot
.535 .52282 Mdot
.47058 .51608 Mdot
.57288 .42265 Mdot
.47752 .43654 Mdot
.51791 .5204 Mdot
.58014 .48624 Mdot
.4722 .51275 Mdot
.47936 .40428 Mdot
.4662 .44522 Mdot
.58855 .49177 Mdot
.50704 .51002 Mdot
.49487 .46937 Mdot
.47681 .41547 Mdot
.47273 .50785 Mdot
.48311 .40569 Mdot
.46499 .44468 Mdot
.43422 .45051 Mdot
.41541 .46027 Mdot
.50415 .57572 Mdot
.49034 .39427 Mdot
.48081 .48709 Mdot
.49551 .48285 Mdot
.48861 .48531 Mdot
.58018 .42961 Mdot
.53344 .46511 Mdot
.41569 .49041 Mdot
.55273 .52832 Mdot
.53017 .47234 Mdot
.43196 .54783 Mdot
.49208 .5461 Mdot
.50754 .51785 Mdot
.44776 .52966 Mdot
.40134 .50179 Mdot
.47734 .4637 Mdot
.53629 .40915 Mdot
.47317 .45479 Mdot
.56891 .46839 Mdot
.56434 .52757 Mdot
.52034 .49785 Mdot
.51664 .52666 Mdot
.44694 .52817 Mdot
.54502 .40363 Mdot
.49338 .54174 Mdot
.43654 .5174 Mdot
.47165 .45239 Mdot
.5066 .46689 Mdot
.49062 .43557 Mdot
.55635 .5415 Mdot
.5017 .50045 Mdot
.55757 .52045 Mdot
.53526 .4008 Mdot
.521 .39748 Mdot
.4387 .52518 Mdot
.56324 .40778 Mdot
.50465 .52164 Mdot
.44168 .52055 Mdot
.42324 .5155 Mdot
.47867 .47227 Mdot
.49251 .47827 Mdot
.45276 .50372 Mdot
.53945 .50326 Mdot
.48215 .50579 Mdot
.55157 .51976 Mdot
.47968 .49229 Mdot
.43012 .47521 Mdot
.48273 .48903 Mdot
.453 .55578 Mdot
.54545 .53476 Mdot
.51957 .40921 Mdot
.44451 .51132 Mdot
.55721 .53284 Mdot
.5376 .51148 Mdot
.53561 .53123 Mdot
.48352 .49514 Mdot
.55332 .5233 Mdot
.58797 .42915 Mdot
.43247 .52445 Mdot
.45021 .59161 Mdot
.52463 .51696 Mdot
.48395 .53301 Mdot
.4994 .52708 Mdot
.48004 .41074 Mdot
.55025 .53382 Mdot
.48933 .41853 Mdot
.53635 .50863 Mdot
.51869 .56673 Mdot
.53548 .4129 Mdot
.52433 .56463 Mdot
.46305 .51636 Mdot
.49061 .40797 Mdot
.47712 .52032 Mdot
.43521 .50105 Mdot
.58962 .50951 Mdot
.46638 .42038 Mdot
.55194 .4876 Mdot
.50748 .51116 Mdot
.54947 .50624 Mdot
.48024 .45791 Mdot
.54924 .52723 Mdot
.4324 .53017 Mdot
.48471 .47357 Mdot
.43154 .44768 Mdot
.48201 .50928 Mdot
.53689 .52236 Mdot
.48257 .52272 Mdot
.45989 .54967 Mdot
.50513 .60208 Mdot
.44488 .5308 Mdot
.48894 .5843 Mdot
.4921 .48295 Mdot
.50445 .52859 Mdot
.49733 .56202 Mdot
.47521 .49402 Mdot
.42853 .46858 Mdot
.51714 .51847 Mdot
.43711 .51354 Mdot
.50873 .3998 Mdot
.52235 .51818 Mdot
.48329 .49798 Mdot
.45926 .44065 Mdot
.50826 .53226 Mdot
.55113 .45284 Mdot
.53171 .51298 Mdot
.40701 .44502 Mdot
.4181 .57132 Mdot
.55499 .51985 Mdot
.49878 .60352 Mdot
.42233 .49657 Mdot
.4168 .57173 Mdot
.4351 .54704 Mdot
.55714 .41069 Mdot
.49951 .49925 Mdot
.47764 .43695 Mdot
.5069 .43661 Mdot
.481 .44263 Mdot
.53647 .533 Mdot
.50133 .56218 Mdot
.55292 .52401 Mdot
.55089 .43271 Mdot
.43356 .50868 Mdot
.43262 .54883 Mdot
.59812 .48786 Mdot
.42209 .52824 Mdot
.51263 .60552 Mdot
.49616 .4742 Mdot
.44835 .50703 Mdot
.58263 .48407 Mdot
.48581 .59599 Mdot
.49828 .47857 Mdot
.49988 .55773 Mdot
.5211 .43695 Mdot
.44406 .41186 Mdot
.44871 .585 Mdot
.40617 .45389 Mdot
.52059 .50349 Mdot
.48299 .5114 Mdot
.56528 .53551 Mdot
.52109 .42143 Mdot
.54376 .52004 Mdot
.41312 .53531 Mdot
.5271 .60811 Mdot
.49349 .54139 Mdot
.44529 .53437 Mdot
.44419 .49927 Mdot
.57818 .47595 Mdot
.52176 .43998 Mdot
.54852 .5327 Mdot
.44444 .50155 Mdot
.57732 .45375 Mdot
.43444 .44599 Mdot
.5432 .44112 Mdot
.56271 .53963 Mdot
.45094 .46161 Mdot
.53094 .43569 Mdot
.50645 .51924 Mdot
.47595 .51228 Mdot
.52596 .52973 Mdot
.43215 .51884 Mdot
.59619 .46527 Mdot
.54523 .5046 Mdot
.55157 .51843 Mdot
.47581 .55097 Mdot
.54414 .53564 Mdot
.52251 .53381 Mdot
.47504 .49505 Mdot
.52005 .60673 Mdot
.48883 .51218 Mdot
.55747 .41668 Mdot
.53482 .53388 Mdot
.45728 .51311 Mdot
.56194 .53184 Mdot
.47456 .50132 Mdot
.56913 .51077 Mdot
.54661 .53624 Mdot
.54484 .41298 Mdot
.54102 .49207 Mdot
.44825 .57321 Mdot
.47689 .46774 Mdot
.57561 .51745 Mdot
.47912 .45225 Mdot
.52998 .49878 Mdot
.48854 .52073 Mdot
.50554 .44707 Mdot
.50309 .4991 Mdot
.45572 .40213 Mdot
.47457 .45767 Mdot
.51227 .49359 Mdot
.4888 .47878 Mdot
.4478 .52092 Mdot
.59475 .48805 Mdot
.46389 .57657 Mdot
.464 .55834 Mdot
.4387 .53763 Mdot
.55045 .52721 Mdot
.48175 .48187 Mdot
.48187 .54495 Mdot
.51641 .47807 Mdot
.39673 .47226 Mdot
.53704 .51369 Mdot
.5426 .41142 Mdot
.4236 .49893 Mdot
.49613 .39715 Mdot
.50279 .51552 Mdot
.44417 .51561 Mdot
.48444 .44563 Mdot
.48348 .50968 Mdot
.54281 .52571 Mdot
.57658 .51357 Mdot
.49014 .52087 Mdot
.43361 .5528 Mdot
.49453 .51621 Mdot
.41458 .52337 Mdot
.47796 .45683 Mdot
.42651 .42763 Mdot
.45409 .50114 Mdot
.51065 .54286 Mdot
.46082 .40846 Mdot
.51529 .44479 Mdot
.45604 .45505 Mdot
.47736 .41947 Mdot
.45865 .54151 Mdot
.48362 .51277 Mdot
.53576 .52614 Mdot
.49992 .47431 Mdot
.48885 .50714 Mdot
.54713 .52476 Mdot
.55914 .43468 Mdot
.53054 .40988 Mdot
.54586 .55254 Mdot
.56503 .50805 Mdot
.46125 .48682 Mdot
.50702 .57102 Mdot
.55658 .54603 Mdot
.54956 .44138 Mdot
.57377 .48882 Mdot
.53675 .5265 Mdot
.44495 .47835 Mdot
.53096 .51504 Mdot
.41922 .46075 Mdot
.52643 .52324 Mdot
.49331 .50915 Mdot
.57061 .53281 Mdot
.53859 .42277 Mdot
.51566 .46968 Mdot
.45466 .41663 Mdot
.55076 .43114 Mdot
.48244 .46463 Mdot
.49801 .46241 Mdot
.5557 .53549 Mdot
.49192 .4691 Mdot
.41544 .55823 Mdot
.398 .4873 Mdot
.59603 .45868 Mdot
.4716 .49801 Mdot
.52572 .52183 Mdot
.41236 .46302 Mdot
.45205 .53076 Mdot
.48477 .46958 Mdot
.49008 .48326 Mdot
.54377 .40616 Mdot
.45994 .47233 Mdot
.53774 .53773 Mdot
.55022 .53057 Mdot
.4267 .50211 Mdot
.57191 .51649 Mdot
.57097 .51136 Mdot
.54215 .45475 Mdot
.44031 .55739 Mdot
.48302 .5004 Mdot
.47918 .44779 Mdot
.47067 .40241 Mdot
.49922 .43871 Mdot
.52166 .53848 Mdot
.41941 .45606 Mdot
.5217 .51611 Mdot
.54162 .52096 Mdot
.56818 .49099 Mdot
.57745 .4861 Mdot
.51294 .51488 Mdot
.40086 .48187 Mdot
.39816 .50559 Mdot
.53507 .43828 Mdot
.50195 .49605 Mdot
.5058 .51358 Mdot
.44969 .47113 Mdot
.46687 .50531 Mdot
.44205 .50309 Mdot
.48901 .61115 Mdot
.48457 .50182 Mdot
.47664 .54714 Mdot
.4894 .50866 Mdot
.47911 .4512 Mdot
.50567 .50196 Mdot
.48599 .40467 Mdot
.59833 .44445 Mdot
.44281 .41787 Mdot
.44442 .53182 Mdot
.51242 .58082 Mdot
.54544 .40032 Mdot
.54535 .4238 Mdot
.44814 .59968 Mdot
.46168 .47443 Mdot
.58719 .43082 Mdot
.52372 .39726 Mdot
.5561 .55127 Mdot
.53395 .51733 Mdot
.56693 .53962 Mdot
.46921 .52713 Mdot
.47525 .44545 Mdot
.56373 .52569 Mdot
.49418 .44361 Mdot
.5433 .54343 Mdot
.46574 .55937 Mdot
.45196 .47907 Mdot
.4698 .56694 Mdot
.47275 .44502 Mdot
.53386 .53964 Mdot
.4657 .46205 Mdot
.58503 .46871 Mdot
.48434 .52527 Mdot
.47368 .53343 Mdot
.52795 .54771 Mdot
.41831 .51239 Mdot
.59306 .4527 Mdot
.51468 .52411 Mdot
.44441 .52347 Mdot
.50788 .42084 Mdot
.44939 .40358 Mdot
.49413 .5017 Mdot
.54345 .53259 Mdot
.47285 .46678 Mdot
.51504 .45262 Mdot
.48991 .51301 Mdot
.44049 .44933 Mdot
.49189 .46825 Mdot
.41626 .46963 Mdot
.39665 .51295 Mdot
.52553 .52768 Mdot
.48774 .46054 Mdot
.451 .54168 Mdot
.55334 .52313 Mdot
.52573 .59942 Mdot
.49158 .5082 Mdot
.4433 .54288 Mdot
.57235 .54067 Mdot
.47339 .41175 Mdot
.45644 .57832 Mdot
.57231 .54573 Mdot
.49425 .41748 Mdot
.57268 .46438 Mdot
.56248 .52399 Mdot
.47773 .48496 Mdot
.54279 .50847 Mdot
.47762 .53088 Mdot
.475 .49154 Mdot
.53047 .42142 Mdot
.46854 .51385 Mdot
.58194 .5225 Mdot
.56628 .48941 Mdot
.55698 .4164 Mdot
.53051 .54623 Mdot
.54439 .48221 Mdot
.538 .52374 Mdot
.47241 .51478 Mdot
.52551 .52007 Mdot
.59586 .47202 Mdot
.39723 .49704 Mdot
.51533 .52278 Mdot
.54423 .56118 Mdot
.55641 .52391 Mdot
.51454 .53386 Mdot
.53736 .53059 Mdot
.58293 .45344 Mdot
.51112 .52352 Mdot
.53124 .44042 Mdot
.50774 .49264 Mdot
.48887 .45366 Mdot
.49523 .47388 Mdot
.5278 .52673 Mdot
.49567 .50799 Mdot
.55619 .45175 Mdot
.42876 .51629 Mdot
.49447 .48605 Mdot
.46733 .51832 Mdot
.48681 .45573 Mdot
.55973 .55524 Mdot
.5124 .40495 Mdot
.48103 .59941 Mdot
.55405 .52936 Mdot
.43274 .48289 Mdot
.53096 .50534 Mdot
.57262 .45472 Mdot
.57048 .46807 Mdot
.41941 .57677 Mdot
.50252 .54611 Mdot
.58078 .52037 Mdot
.47598 .49704 Mdot
.54118 .40954 Mdot
.4771 .46894 Mdot
.49031 .50345 Mdot
.42014 .51097 Mdot
.55712 .47893 Mdot
.43462 .473 Mdot
.57528 .44551 Mdot
.48226 .48627 Mdot
.42322 .52189 Mdot
.46398 .57338 Mdot
.44359 .59282 Mdot
.52573 .43289 Mdot
.48062 .49764 Mdot
.50322 .53174 Mdot
.52408 .51085 Mdot
.46275 .4431 Mdot
.57543 .45304 Mdot
.5938 .49703 Mdot
.58523 .42719 Mdot
.42218 .55412 Mdot
.46273 .50122 Mdot
.53692 .52044 Mdot
.55812 .52004 Mdot
.51247 .55568 Mdot
.46654 .48842 Mdot
.55701 .50557 Mdot
.47377 .4823 Mdot
.48573 .58386 Mdot
.4487 .47478 Mdot
.52459 .58038 Mdot
.44409 .4764 Mdot
.45936 .39819 Mdot
.54869 .52573 Mdot
.43034 .43654 Mdot
.52494 .51474 Mdot
.4581 .51235 Mdot
.41739 .53901 Mdot
.4396 .59678 Mdot
.54671 .43288 Mdot
.54592 .52489 Mdot
.47653 .51801 Mdot
.5197 .43627 Mdot
.48021 .43521 Mdot
.56675 .52347 Mdot
.47661 .46908 Mdot
.4492 .57347 Mdot
.47478 .47829 Mdot
.55545 .4596 Mdot
.5502 .527 Mdot
.44134 .50163 Mdot
.53764 .54564 Mdot
.46408 .51384 Mdot
.51994 .42641 Mdot
.42836 .49521 Mdot
.51934 .51709 Mdot
.47328 .49882 Mdot
.42141 .55474 Mdot
.55694 .52547 Mdot
.52803 .42802 Mdot
.57006 .53559 Mdot
.49394 .46963 Mdot
.45899 .46809 Mdot
.4493 .47573 Mdot
.51179 .52399 Mdot
.4477 .41384 Mdot
.44943 .4582 Mdot
.41831 .46863 Mdot
.53323 .52998 Mdot
.50336 .51388 Mdot
.53332 .51707 Mdot
.48906 .54816 Mdot
.53592 .49361 Mdot
.4709 .49583 Mdot
.48868 .59013 Mdot
.54765 .43072 Mdot
.53821 .53097 Mdot
.54097 .54859 Mdot
.40804 .54707 Mdot
.39936 .51624 Mdot
.46656 .55109 Mdot
.45006 .6012 Mdot
.48407 .54657 Mdot
.5388 .53348 Mdot
.4688 .52364 Mdot
.46456 .45925 Mdot
.56933 .49557 Mdot
.45398 .42194 Mdot
.52646 .39743 Mdot
.40044 .54066 Mdot
.48182 .50908 Mdot
.51312 .51148 Mdot
.57659 .4803 Mdot
.48303 .49663 Mdot
.48748 .468 Mdot
.45148 .54512 Mdot
.48153 .50933 Mdot
.49927 .49574 Mdot
.46977 .5687 Mdot
.55837 .51796 Mdot
.43211 .5351 Mdot
.45867 .49469 Mdot
.56643 .52572 Mdot
.46388 .48517 Mdot
.60411 .46414 Mdot
.55426 .50763 Mdot
.49052 .59062 Mdot
.42486 .47389 Mdot
.56004 .43524 Mdot
.50952 .41907 Mdot
.48146 .4873 Mdot
.49649 .4496 Mdot
.54025 .53011 Mdot
.48768 .52045 Mdot
.59579 .46535 Mdot
.44128 .42058 Mdot
.57896 .42879 Mdot
.4661 .43456 Mdot
.48298 .47746 Mdot
.58521 .5192 Mdot
.47741 .44613 Mdot
.48871 .52535 Mdot
.54424 .5265 Mdot
.42357 .54762 Mdot
.57699 .42902 Mdot
.52439 .5481 Mdot
.50367 .51155 Mdot
.41987 .53799 Mdot
.53294 .50452 Mdot
.49922 .48112 Mdot
.52683 .60422 Mdot
.48081 .46336 Mdot
.44674 .48111 Mdot
.47466 .50439 Mdot
.46923 .5031 Mdot
.55014 .47836 Mdot
.45817 .50518 Mdot
.47547 .42585 Mdot
.46425 .48902 Mdot
.53309 .59317 Mdot
.47784 .48324 Mdot
.42611 .54759 Mdot
.4775 .52681 Mdot
.49302 .44476 Mdot
.4688 .42451 Mdot
.46999 .54693 Mdot
.49799 .56936 Mdot
.47814 .50852 Mdot
.50022 .46166 Mdot
.46806 .46083 Mdot
.4921 .51638 Mdot
.45907 .55259 Mdot
.41495 .4464 Mdot
.54461 .42099 Mdot
.47133 .58258 Mdot
.53389 .52429 Mdot
.49343 .50343 Mdot
.47388 .406 Mdot
.46918 .55326 Mdot
.45276 .5862 Mdot
.47469 .48937 Mdot
.4908 .44725 Mdot
.48568 .51644 Mdot
.46765 .60698 Mdot
.47835 .47731 Mdot
.46258 .503 Mdot
.49569 .55475 Mdot
.49618 .60731 Mdot
.46335 .45796 Mdot
.48472 .49785 Mdot
.52972 .60844 Mdot
.52628 .52259 Mdot
.45175 .41147 Mdot
.46024 .58446 Mdot
.42878 .5596 Mdot
.57978 .43801 Mdot
.50833 .42956 Mdot
.4326 .51072 Mdot
.47545 .48695 Mdot
.53315 .54091 Mdot
.55072 .42847 Mdot
.44337 .46077 Mdot
.4374 .45679 Mdot
.44501 .51375 Mdot
.53601 .4099 Mdot
.56493 .52864 Mdot
.47852 .50366 Mdot
.5784 .52528 Mdot
.45872 .46473 Mdot
.47102 .48003 Mdot
.5603 .51832 Mdot
.4495 .55331 Mdot
.54705 .53426 Mdot
.46448 .40215 Mdot
.41316 .55836 Mdot
.48707 .56493 Mdot
.48339 .49052 Mdot
.54649 .5624 Mdot
.50689 .51543 Mdot
.51791 .51644 Mdot
.43623 .50054 Mdot
.41751 .52531 Mdot
.45868 .50315 Mdot
.53942 .52418 Mdot
.46899 .57379 Mdot
.47028 .54293 Mdot
.52509 .41722 Mdot
.59296 .46554 Mdot
.50602 .57669 Mdot
.4925 .39419 Mdot
.54998 .53446 Mdot
.43917 .41258 Mdot
.48404 .49281 Mdot
.50306 .52027 Mdot
.57537 .52745 Mdot
.58618 .51113 Mdot
.49138 .47768 Mdot
.4835 .44221 Mdot
.5263 .44574 Mdot
.46243 .4334 Mdot
.41891 .47602 Mdot
.52388 .42102 Mdot
.46794 .49961 Mdot
.54993 .53715 Mdot
.52219 .49946 Mdot
.54956 .43386 Mdot
.49908 .4642 Mdot
.50525 .41047 Mdot
.54243 .51734 Mdot
.54939 .52433 Mdot
.5347 .54017 Mdot
.45241 .56661 Mdot
.40705 .50883 Mdot
.40326 .53852 Mdot
.57685 .51796 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo09_ooooo0ol0002Yooooo`00
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0TOooool2o`0000Oooooo1Ol00006ooooo`Ko0000W?ooool000?ooooo
00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool3o`0008kooooo0_l000000ooooooo
0000o`000007ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo1ol000000ooooooo
0000o`00002Hooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoo
oooo00001oooool00ol0003oooooooooo`2>ooooo`Co000000?oooooo`000?l000000_l000000ooo
oooo0000o`000007ooooo`;o00001oooool2o`000003ooooool0003o000009Sooooo0003ooooo`05
o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooo
oooo08kooooo1?l000000ooooooo0000o`000007o`0000Gooooo0ol00009ooooo`?o0000Uoooool0
00?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000
ooooooooool0T_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000?ooooo1?l00000
1?oooooo0000o`000?ooool8o`0000?ooooo0_l0002Booooo`000oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2;ooooo`?o000000Co
ooooo`000?l0003ooooo0_l00002ooooo`Co000000?oooooo`000?l000000oooool3o`0000;ooooo
0_l000000ooooooo0000o`000005o`0000;ooooo1?l0002Booooo`000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`2;ooooo`So0000
00?oooooo`000?l000001?l000000ooooooo0000o`00000=ooooo`Go00000_ooool2o`0009Cooooo
000Nooooo`03o`000?oooooooooo08cooooo0ol000000ooooooo0000o`000007o`0000;ooooo1?l0
0003ooooo`;o00000oooool2o`000005ooooool0003o0000o`000?ooool00_l000001?oooooo0000
o`000?ooool2o`00097ooooo000Nooooo`03o`000?oooooooooo08_ooooo0ol000000ooooooo0000
o`000002ooooo`Ko000000?oooooo`000?l000000ol00002ooooo`?o000000?oooooo`000?l00000
0ol000000ooooooo0000o`000006o`000003ooooool0003o000000;o0000Soooool001kooooo00?o
0000ooooooooool0Roooool2o`0000;ooooo1?l000000ooooooo0000o`000002o`0000;ooooo0_l0
0005ooooo`;o00000_ooool5o`000003ooooool0003o000000Co00001Oooool2o`0008oooooo000N
ooooo`03o`000?oooooooooo08Oooooo0_l00004ooooo`_o00000oooool2o`0000?ooooo1?l00000
1?oooooo0000o`000?ooool2o`0000?ooooo1?l00007ooooo`Co0000Roooool001kooooo00?o0000
ooooooooool0Qoooool2o`0000Cooooo0_l00004ooooo`Co000000Coooooo`000?l0003ooooo0_l0
0003ooooo`Co000000Coooooo`000?l0003ooooo0_l00004ooooo`Co00000_ooool2o`000003oooo
ool0003o000000Co0000R_ooool001kooooo00?o0000ooooooooool0Q_ooool2o`0000[ooooo2?l0
0006ooooo`?o00001?ooool2o`0000Gooooo2?l000000ooooooo0000o`000004o`0008[ooooo000N
ooooo`03o`000?oooooooooo08Kooooo1?l00008ooooo`?o000000?oooooo`000?l000000_l00000
1?oooooo0000o`000?ooool5o`0000;ooooo1Ol000001?oooooo0000o`000?ooool6o`0000Cooooo
0_l000000ooooooo0000o`00002:ooooo`007_ooool00ol0003oooooooooo`28ooooo`;o00001ooo
ool4o`000003ooooool0003o000000;o000000?oooooo`000?l000000ol000001?oooooo0000o`00
0?ooool:o`0000?ooooo0ol00004ooooo`;o000000?oooooo`000?l00000R_ooool001kooooo00?o
0000ooooooooool0TOooool4o`000003ooooool0003o000000?o000000?oooooo`000?l000000_l0
00001?oooooo0000o`000?ooool4o`000003ooooool0003o000000?o000000?oooooo`000?l00000
1Oooool2o`0008oooooo000Nooooo`03o`000?oooooooooo083ooooo0_l000000ooooooo0000o`00
0004ooooo`;o00001oooool3o`000003ooooool0003o000000Oo000000Coooooo`000?l0003ooooo
0_l00002ooooo`;o00001_ooool2o`0000Gooooo0ol00005ooooo`;o0000Qoooool001kooooo00?o
0000ooooooooool0P?ooool2o`000003ooooool0003o000000?ooooo1Ol00006ooooo`;o000000?o
ooooo`000?l000001ol000001?oooooo0000o`000?ooool6o`0000kooooo0_l00005ooooo`;o0000
Qoooool001kooooo0_l00029ooooo`Go00000_ooool2o`0000Cooooo1Ol00002ooooo`?o00001?oo
ool4o`0000Kooooo1_l00004ooooo`Co00000_ooool3o`0008Oooooo000Nooooo`03o`000?oooooo
oooo083ooooo0_l00002ooooo`;o00000oooool2o`0000Cooooo0ol00003ooooo`So00001_ooool2
o`0000Cooooo0_l000000ooooooo0000o`000005o`0000?ooooo1Ol00002ooooo`;o0000R?ooool0
01kooooo00?o0000ooooooooool0P?ooool2o`0000;ooooo0_l00004ooooo`;o00000_ooool4o`00
0003ooooool0003o000000[o00002_ooool2o`000003ooooool0003o000000;ooooo0_l00004oooo
o`[o0000Qoooool001kooooo00?o0000ooooooooool0Poooool3o`0000Cooooo1_l00002oooooa7o
00002_ooool2o`000003ooooool0003o000000Oooooo1ol00027ooooo`007_ooool00ol0003ooooo
ooooo`22ooooo`Co00001_ooool4o`000003ooooool0003o000000Wo00000_ooool5o`0000Kooooo
0_l00002ooooo`?o00001_ooool2o`0000;ooooo0_l000000ooooooo0000o`000003o`0008Gooooo
000Nooooo`03o`000?oooooooooo08;ooooo1?l000000ooooooo0000o`000008ooooo`?o00000_oo
ool:o`000003ooooool0003o000000Kooooo0_l000000ooooooo0000o`000002o`0000Gooooo1?l0
00001?oooooo0000o`000?ooool5o`0008Gooooo000Nooooo`03o`000?oooooooooo08?ooooo0ol0
00000ooooooo0000o`000003o`0000;ooooo0_l000001Ooooooo0000o`000?l0003ooooo00[o0000
0_ooool2o`000003ooooool0003o000000Kooooo0_l00007ooooo`Co000000?oooooo`000?l00000
1?l00027ooooo`007_ooool00ol0003oooooooooo`1mooooo`;o00001?ooool2o`000003ooooool0
003o000000Co00000_ooool2o`000005ooooool0003o0000o`000?ooool02ol00004ooooo`;o0000
0_ooool2o`00017ooooo1Ol00027ooooo`007_ooool00ol0003oooooooooo`1mooooo`;o000000?o
ooooo`000?l000000_ooool7o`000003ooooool0003o000000;o000000Goooooo`000?l0003o0000
ooooo`0;o`0000?ooooo0ol000001?oooooo0000o`000?l0000>ooooo`;o0000SOooool001kooooo
00?o0000ooooooooool0OOooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o0000
0_ooool5o`0000;ooooo3Ol00003ooooo`?o000000Coooooo`000?l0003o00001Oooool4o`0000Co
oooo0ol00002ooooo`;o0000ROooool001kooooo00?o0000ooooooooool0OOooool3o`0000Cooooo
0_l00002ooooo`?o00000_ooool4o`0000;ooooo3Ol00008ooooo`;o00000oooool6o`0000Cooooo
1?l000000ooooooo0000o`000029ooooo`007_ooool00ol0003oooooooooo`1mooooo`Go00001_oo
ool3o`0000Kooooo3_l0000>ooooo`;o00002Oooool3o`0008cooooo000Nooooo`03o`000?oooooo
oooo07gooooo0_l000001?oooooo0000o`000?ooool2o`0000cooooo3_l00003ooooo`;o00000_oo
ool2o`0000Gooooo1Ol000000ooooooo0000o`000005o`0000?ooooo0ol00027ooooo`007_ooool0
0ol0003oooooooooo`23ooooo`;o00002oooool2o`000003ooooool0003o000000[o00000_ooool3
o`0000;ooooo0_l00002ooooo`Co000000Goooooo`000?l0003o0000ooooo`05o`0000?ooooo1Ol0
0027ooooo`007_ooool00ol0003oooooooooo`1oooooo`;o00001?ooool4o`0000Oooooo0ol00002
ooooo`Ko00000_ooool7o`0000Kooooo1Ol00006ooooo`;o00001?ooool2o`0008[ooooo000Noooo
o`03o`000?oooooooooo07gooooo1?l00004ooooo`Co00000_ooool3o`0000?ooooo0_l000000ooo
oooo0000o`000005o`000003ooooool0003o000000?o000000Coooooo`000?l0003ooooo1ol00000
0ooooooo0000o`000006ooooo`;o00001_ooool2o`0008Sooooo000Nooooo`;o0000O_ooool3o`00
00;ooooo0_l00002ooooo`So00000_oooolBo`0000?ooooo1Ol00006ooooo`?o00002_ooool2o`00
08Sooooo000Nooooo`03o`000?oooooooooo07gooooo0ol00002ooooo`;o00000oooool7o`000003
ooooool0003o0000017o00000_ooool4o`000003ooooool0003o000000Co000000Coooooo`000?l0
003o0000U?ooool001kooooo00?o0000ooooooooool0OOooool2o`000003ooooool0003o000000Go
oooo6ol00002ooooo`Co000000?oooooo`000?l000002?l000000ooooooo0000o`000002ooooo`;o
0000SOooool001kooooo00?o0000ooooooooool0P?ooool2o`0000;ooooo0_l000000ooooooo0000
o`000002o`000003ooooool0003o000000Go00000_ooool@o`000003ooooool0003o000000;ooooo
1?l000001?oooooo0000o`000?l00002ooooo`[o0000ROooool001kooooo00?o0000ooooooooool0
OOooool2o`0000Gooooo0_l00003ooooo`Ko000000?oooooo`000?l000006ol00002ooooo`;o0000
1?ooool4o`000003ooooool0003o000000;o0000ROooool001kooooo00?o0000ooooooooool0OOoo
ool3o`0000;ooooo3Ol00002oooooago000000?oooooo`000?l000000ol00002ooooo`?o0000S_oo
ool001kooooo00?o0000ooooooooool0O_ooool2o`0000;ooooo0_l000000ooooooo0000o`000008
o`0000;ooooo8ol00002ooooo`Ko0000Roooool001kooooo00?o0000ooooooooool0O_ooool2o`00
00?ooooo1?l000000ooooooo0000o`000005o`0000Gooooo8_l00003ooooo`?o0000Roooool001ko
oooo00?o0000ooooooooool0O_ooool2o`0000?ooooo2ol00006ooooobOo0000S?ooool001kooooo
00?o0000ooooooooool0Q?ooool6o`000003ooooool0003o000000;o00001Oooool2o`000003oooo
ool0003o0000027o0000SOooool001kooooo00?o0000ooooooooool0QOooool<o`0000Gooooo3_l0
00000ooooooo0000o`00000Bo`0008kooooo000Nooooo`03o`000?oooooooooo07oooooo0_l00000
1?oooooo0000o`000?ooool2o`000003ooooool0003o000000Oo000000Goooooo`000?l0003o0000
ooooo`07o`0000;ooooo1_l000001?oooooo0000o`000?ooool>o`00093ooooo000Nooooo`03o`00
0?oooooooooo07oooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l000000ooooooo0000
o`000004o`000004ooooool0003o0000o`0000;ooooo1?l00004ooooo`;o00000_ooool5o`000003
ooooool0003o000000co0000T?ooool001kooooo00?o0000ooooooooool0O_ooool3o`0000?ooooo
0_l00002ooooo`;o000000?oooooo`000?l000001ol00003ooooo`Co000000Coooooo`000?l0003o
oooo0_l00002ooooo`Co00000_ooool5o`000003ooooool0003o000000Oo0000Soooool001kooooo
00?o0000ooooooooool0O_ooool3o`0000Oooooo0_l00002ooooo`;o000000?oooooo`000?l00000
0ol000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000oooool6o`0000;ooooo
1_l00002ooooo`Co000000?oooooo`000?l00000Soooool001kooooo00?o0000ooooooooool0Oooo
ool4o`0000?ooooo2?l000000ooooooo0000o`000004ooooo`Wo000000?oooooo`000?l000000ol0
0002ooooo`Co000000?oooooo`000?l000000_l00002ooooo`;o00000oooool2o`0008oooooo000N
ooooo`;o0000P_ooool2o`0000?ooooo1_l00005ooooo`;o000000?oooooo`000?l000002ol00005
ooooo`Co000000?oooooo`000?l000000_l00002ooooo`?o0000Toooool001kooooo00?o0000oooo
ooooool0QOooool2o`000004ooooool0003o0000o`0000?ooooo0_l000001?oooooo0000o`000?oo
ool2o`000003ooooool0003o000000?ooooo0ol0000<ooooo`Co00000_ooool3o`0009?ooooo000N
ooooo`03o`000?oooooooooo08Cooooo2Ol000000ooooooo0000o`000003o`000003ooooool0003o
000000Kooooo1?l00002ooooo`;o00001Oooool2o`000004ooooool0003o0000o`0000?ooooo0_l0
002Cooooo`007_ooool00ol0003oooooooooo`22ooooo`Oo000000Coooooo`000?l0003o00000_oo
ool3o`000004ooooool0003o0000ooooo`;o00001_ooool2o`0000;ooooo0_l00005ooooo`;o0000
0_ooool2o`0000?ooooo0_l0002Cooooo`007_ooool00ol0003oooooooooo`22ooooo`?o00000_oo
ool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000002o`000003ooooool0
003o000000Kooooo0ol00005ooooo`;o00001Oooool3o`0009Oooooo000Nooooo`03o`000?oooooo
oooo08[ooooo0_l00002ooooo`Ko000000?oooooo`000?l000000oooool2o`0000;ooooo1?l00003
ooooo`?o00001_ooool2o`0009Oooooo000Nooooo`03o`000?oooooooooo08oooooo0_l000001?oo
oooo0000o`000?ooool2o`0000?ooooo0_l00002ooooo`Co00000oooool3o`0000Cooooo0_l0002I
ooooo`007_ooool00ol0003oooooooooo`23ooooo`?o00002?ooool2o`0000?ooooo1?l00006oooo
o`?o000000?oooooo`000?l000002Oooool2o`0009Wooooo000Nooooo`03o`000?oooooooooo08?o
oooo0ol00003ooooo`;o00000oooool2o`0000?ooooo0ol00003ooooo`;o00000_ooool6o`0000Co
oooo0_l00008ooooo`;o0000U?ooool001kooooo00?o0000ooooooooool0Q?ooool2o`0000?ooooo
0_l00005ooooo`;o000000Coooooo`000?l0003o00000oooool2o`0000;ooooo1Ol00005ooooo`;o
00002?ooool2o`0009Cooooo000Nooooo`03o`000?oooooooooo08Cooooo0_l00003ooooo`;o0000
0oooool4o`0000?ooooo0_l00009ooooo`Co00000_ooool2o`0009oooooo000Nooooo`03o`000?oo
oooooooo08kooooo0_l00002ooooo`;o000000?oooooo`000?l000000oooool3o`0000Gooooo0_l0
0002ooooo`;o0000Woooool001kooooo00?o0000ooooooooool0S_ooool3o`000004ooooool0003o
0000ooooo`;o00000oooool5o`0000Kooooo0_l0002Pooooo`007_ooool00ol0003oooooooooo`2>
ooooo`?o000000?oooooo`000?l000000ol00003ooooo`Oo00001?ooool4o`0009kooooo0003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<
c006ooooo`03o`000?oooooooooo08cooooo1?l00002ooooo`Co00001?ooool7o`0000?ooooo1ol0
002Looooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2;ooooo`?o00003?ooool2o`0000;ooooo
0_l00002ooooo`Co00000oooool2o`0000;ooooo0_l0002Hooooo`000oooool01Ol@413ooooooooo
oooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000Roooool2o`000003
ooooool0003o000000Gooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00002ooooo`;o
000000?oooooo`000?l000000_l00004ooooo`;o0000V?ooool000?ooooo00Go0000oooooooooooo
ooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2>oooo
o`;o00001Oooool2o`000003ooooool0003o000000;o00000_ooool4o`0000?ooooo1?l0002Noooo
o`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c006
ooooo`03o`000?oooooooooo09Cooooo0_l00003ooooo`?o000000?oooooo`000?l000000ol00000
0ooooooo0000o`000006o`0009cooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool0
0omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo09Cooooo0_l00004ooooo`;o000000Cooooo
o`000?l0003o00000oooool8o`0009cooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo09_ooooo0_l00002ooooo`;o00000_oo
ool7o`0009gooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`00
0?l@4106ooooo`03o`000?oooooooooo09_ooooo0_l00002ooooo`;o00000_ooool4o`000:3ooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2
o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo0003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<
c006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0
oooooom8ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooooooo
ooooo`000006ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000_o
oooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool0
1Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Dooooo`Co000000?o410@
ooooooooool00oooool00ol0003oooooooooo`3oooooodSooooo000Fooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0oooooom8ooooo`005_ooool00ol0003oooooooooo`05ooooo`?o
0000oooooom8ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oo
oooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0
003oooooooooo`3ooooooe3ooooo000Dooooo`03oeEEEOmVIVKo00000?ooooooD_ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.55789 .45464 Mdot
.4831 .46994 Mdot
.42863 .48006 Mdot
.48968 .4683 Mdot
.50148 .46685 Mdot
.57453 .494 Mdot
.415 .46015 Mdot
.51489 .45137 Mdot
.47474 .59447 Mdot
.53455 .54373 Mdot
.54297 .48973 Mdot
.48342 .50642 Mdot
.58036 .48477 Mdot
.48556 .42316 Mdot
.42286 .554 Mdot
.52642 .54182 Mdot
.49908 .44448 Mdot
.55027 .54918 Mdot
.538 .54666 Mdot
.46605 .51934 Mdot
.5038 .43895 Mdot
.51473 .56313 Mdot
.51451 .47926 Mdot
.56131 .43738 Mdot
.52281 .44583 Mdot
.49521 .51471 Mdot
.4422 .55698 Mdot
.5418 .54719 Mdot
.49677 .4759 Mdot
.57619 .4682 Mdot
.45316 .46601 Mdot
.49465 .45468 Mdot
.5032 .51261 Mdot
.43818 .50656 Mdot
.57912 .47686 Mdot
.43414 .49236 Mdot
.50312 .51945 Mdot
.46602 .56994 Mdot
.50786 .47312 Mdot
.48395 .51152 Mdot
.52285 .52894 Mdot
.47667 .53391 Mdot
.45743 .48018 Mdot
.49444 .50127 Mdot
.49885 .44953 Mdot
.5146 .53459 Mdot
.47902 .42099 Mdot
.45531 .45582 Mdot
.4428 .48505 Mdot
.50613 .60591 Mdot
.50409 .47273 Mdot
.59283 .48566 Mdot
.49497 .4774 Mdot
.50841 .46364 Mdot
.52823 .54763 Mdot
.50145 .52551 Mdot
.46504 .49645 Mdot
.60017 .47468 Mdot
.49886 .45465 Mdot
.46128 .49564 Mdot
.51221 .54199 Mdot
.51173 .52665 Mdot
.44813 .51261 Mdot
.52661 .5393 Mdot
.50312 .48268 Mdot
.47742 .60217 Mdot
.48091 .447 Mdot
.50972 .53418 Mdot
.48468 .52412 Mdot
.52592 .54512 Mdot
.40988 .5098 Mdot
.49814 .46069 Mdot
.46416 .50252 Mdot
.48798 .48675 Mdot
.57477 .45432 Mdot
.43069 .53267 Mdot
.49708 .53158 Mdot
.55093 .54727 Mdot
.4102 .49718 Mdot
.53178 .5156 Mdot
.46371 .55613 Mdot
.51989 .45178 Mdot
.51146 .44119 Mdot
.51986 .5293 Mdot
.44465 .51085 Mdot
.49122 .48349 Mdot
.43008 .51441 Mdot
.50882 .5294 Mdot
.4794 .50996 Mdot
.5645 .53352 Mdot
.49855 .48325 Mdot
.51857 .5397 Mdot
.44546 .5374 Mdot
.48954 .60717 Mdot
.42007 .47444 Mdot
.51087 .54544 Mdot
.50627 .52886 Mdot
.46127 .45578 Mdot
.47578 .42221 Mdot
.46585 .49119 Mdot
.43311 .51924 Mdot
.44605 .53134 Mdot
.50321 .45535 Mdot
.51864 .59673 Mdot
.46192 .58786 Mdot
.50502 .5162 Mdot
.47649 .39792 Mdot
.50132 .48096 Mdot
.47433 .45892 Mdot
.519 .54105 Mdot
.55343 .43861 Mdot
.49742 .46083 Mdot
.47834 .48946 Mdot
.48672 .58778 Mdot
.49601 .43305 Mdot
.58767 .49703 Mdot
.45225 .5684 Mdot
.54248 .55008 Mdot
.43929 .46184 Mdot
.44748 .54204 Mdot
.55024 .526 Mdot
.49319 .51149 Mdot
.53352 .54553 Mdot
.44625 .47666 Mdot
.49075 .45467 Mdot
.50105 .58582 Mdot
.56291 .44216 Mdot
.49464 .51297 Mdot
.49521 .50733 Mdot
.52783 .53228 Mdot
.54075 .51778 Mdot
.49995 .43861 Mdot
.5796 .43881 Mdot
.43985 .49712 Mdot
.52732 .46811 Mdot
.56502 .42611 Mdot
.53131 .57625 Mdot
.4973 .49278 Mdot
.47203 .5124 Mdot
.48377 .49515 Mdot
.50017 .48134 Mdot
.46202 .58415 Mdot
.49901 .51172 Mdot
.49226 .46907 Mdot
.50488 .50662 Mdot
.5182 .54232 Mdot
.5638 .45895 Mdot
.50465 .54691 Mdot
.4962 .431 Mdot
.44564 .4828 Mdot
.4442 .50541 Mdot
.54225 .54756 Mdot
.49969 .47481 Mdot
.49157 .42276 Mdot
.54186 .50806 Mdot
.52638 .54266 Mdot
.51276 .52548 Mdot
.58307 .45374 Mdot
.49619 .53098 Mdot
.50211 .49645 Mdot
.41677 .53079 Mdot
.48763 .53143 Mdot
.55403 .53294 Mdot
.52953 .54891 Mdot
.47244 .50409 Mdot
.47324 .49491 Mdot
.45224 .58268 Mdot
.47711 .56146 Mdot
.49815 .55288 Mdot
.4796 .57954 Mdot
.54079 .53345 Mdot
.44821 .48306 Mdot
.47686 .47369 Mdot
.47261 .50598 Mdot
.40606 .51872 Mdot
.50412 .52329 Mdot
.51499 .55007 Mdot
.5027 .4932 Mdot
.51103 .40635 Mdot
.44339 .49407 Mdot
.48939 .47114 Mdot
.51493 .54549 Mdot
.49167 .49116 Mdot
.49508 .47575 Mdot
.58257 .49022 Mdot
.48219 .50295 Mdot
.42779 .50369 Mdot
.51231 .54256 Mdot
.49187 .60462 Mdot
.44033 .53694 Mdot
.48873 .49905 Mdot
.51628 .51945 Mdot
.5505 .43177 Mdot
.50027 .47701 Mdot
.47415 .57569 Mdot
.51889 .52459 Mdot
.50231 .60827 Mdot
.49956 .50855 Mdot
.50486 .48861 Mdot
.48452 .47437 Mdot
.46791 .48714 Mdot
.50857 .53668 Mdot
.5466 .52612 Mdot
.48238 .55364 Mdot
.53002 .54229 Mdot
.47373 .47638 Mdot
.50829 .43402 Mdot
.4625 .49059 Mdot
.43193 .50141 Mdot
.50096 .47467 Mdot
.49969 .4478 Mdot
.50126 .51674 Mdot
.4831 .51653 Mdot
.5592 .51488 Mdot
.49284 .51134 Mdot
.48524 .41514 Mdot
.51637 .53931 Mdot
.49444 .52828 Mdot
.46379 .58445 Mdot
.50091 .48637 Mdot
.51322 .5073 Mdot
.59438 .46278 Mdot
.51784 .54159 Mdot
.52913 .41524 Mdot
.53729 .47579 Mdot
.52854 .45858 Mdot
.49443 .45832 Mdot
.53316 .54823 Mdot
.42893 .49903 Mdot
.52849 .50248 Mdot
.53204 .55304 Mdot
.50005 .51535 Mdot
.47557 .58508 Mdot
.50968 .52216 Mdot
.49935 .51975 Mdot
.47027 .51134 Mdot
.49048 .58559 Mdot
.42691 .52575 Mdot
.48592 .45537 Mdot
.48216 .50305 Mdot
.53361 .54793 Mdot
.42451 .55137 Mdot
.56419 .45137 Mdot
.49598 .58498 Mdot
.42695 .45857 Mdot
.52701 .54807 Mdot
.42964 .53533 Mdot
.52135 .45629 Mdot
.53231 .54959 Mdot
.44911 .56959 Mdot
.45782 .48276 Mdot
.58295 .49628 Mdot
.43455 .55822 Mdot
.42349 .46604 Mdot
.48132 .48901 Mdot
.4769 .50174 Mdot
.51729 .49683 Mdot
.49179 .52165 Mdot
.44285 .51088 Mdot
.44473 .57072 Mdot
.47474 .55864 Mdot
.51866 .52361 Mdot
.50223 .49725 Mdot
.54994 .5156 Mdot
.45753 .5134 Mdot
.45333 .5163 Mdot
.52592 .49652 Mdot
.54665 .53839 Mdot
.51444 .52177 Mdot
.51903 .40708 Mdot
.47279 .45761 Mdot
.47813 .48977 Mdot
.48844 .60492 Mdot
.4807 .49298 Mdot
.42565 .49183 Mdot
.42194 .52757 Mdot
.50157 .52976 Mdot
.53762 .54291 Mdot
.46921 .5194 Mdot
.53255 .53103 Mdot
.47723 .51775 Mdot
.49439 .51726 Mdot
.466 .43852 Mdot
.50112 .50159 Mdot
.46526 .57573 Mdot
.49381 .60744 Mdot
.496 .40789 Mdot
.51506 .49486 Mdot
.48335 .46079 Mdot
.4955 .42082 Mdot
.47516 .50379 Mdot
.49342 .42936 Mdot
.5844 .50587 Mdot
.4534 .48322 Mdot
.47322 .49461 Mdot
.50845 .45949 Mdot
.54403 .54185 Mdot
.445 .4986 Mdot
.47365 .53669 Mdot
.49113 .46631 Mdot
.49757 .50118 Mdot
.52995 .45967 Mdot
.46305 .59153 Mdot
.5227 .54679 Mdot
.47914 .50491 Mdot
.49088 .46733 Mdot
.5523 .41199 Mdot
.52813 .42411 Mdot
.52684 .44616 Mdot
.45585 .51002 Mdot
.48672 .4787 Mdot
.50156 .50449 Mdot
.52187 .50962 Mdot
.54883 .45652 Mdot
.48076 .47858 Mdot
.50027 .42608 Mdot
.48522 .5126 Mdot
.5093 .5323 Mdot
.46702 .50542 Mdot
.4728 .5728 Mdot
.44465 .49096 Mdot
.54707 .48532 Mdot
.55066 .48755 Mdot
.50336 .52412 Mdot
.54183 .53758 Mdot
.49313 .57863 Mdot
.49109 .50014 Mdot
.49448 .50776 Mdot
.49388 .59289 Mdot
.45758 .53862 Mdot
.56709 .45932 Mdot
.58847 .48499 Mdot
.47722 .49009 Mdot
.53528 .54268 Mdot
.43306 .49992 Mdot
.52122 .52113 Mdot
.44395 .50372 Mdot
.4948 .46352 Mdot
.54782 .47359 Mdot
.51052 .52678 Mdot
.47811 .44855 Mdot
.51269 .42388 Mdot
.45045 .42147 Mdot
.50015 .51185 Mdot
.50129 .56863 Mdot
.49283 .4392 Mdot
.50061 .50003 Mdot
.50945 .45438 Mdot
.47412 .55996 Mdot
.5201 .52965 Mdot
.46933 .49925 Mdot
.58341 .44514 Mdot
.50141 .44336 Mdot
.50716 .52163 Mdot
.57195 .51418 Mdot
.47207 .49734 Mdot
.50404 .41256 Mdot
.49259 .44502 Mdot
.57841 .51952 Mdot
.50548 .51614 Mdot
.50416 .48463 Mdot
.50173 .42451 Mdot
.47526 .49383 Mdot
.50714 .41515 Mdot
.49164 .444 Mdot
.46048 .44036 Mdot
.43835 .44608 Mdot
.48146 .56355 Mdot
.51446 .40258 Mdot
.49211 .4845 Mdot
.50199 .49544 Mdot
.498 .49028 Mdot
.58825 .45362 Mdot
.53508 .48673 Mdot
.43423 .47064 Mdot
.5321 .54264 Mdot
.5306 .49388 Mdot
.42922 .51983 Mdot
.47528 .52925 Mdot
.50013 .51706 Mdot
.44759 .50466 Mdot
.4153 .47921 Mdot
.4961 .46639 Mdot
.55363 .42707 Mdot
.49569 .45681 Mdot
.56789 .49389 Mdot
.54194 .54741 Mdot
.51881 .51607 Mdot
.49913 .52232 Mdot
.44761 .50335 Mdot
.56259 .42149 Mdot
.47693 .52561 Mdot
.44465 .49357 Mdot
.49525 .45395 Mdot
.51201 .48541 Mdot
.50994 .44921 Mdot
.52619 .54806 Mdot
.50256 .50868 Mdot
.54225 .53922 Mdot
.55442 .41727 Mdot
.54282 .41118 Mdot
.44256 .49976 Mdot
.57794 .42775 Mdot
.4932 .51643 Mdot
.44713 .4965 Mdot
.43647 .49135 Mdot
.49464 .47374 Mdot
.50122 .49036 Mdot
.46508 .48537 Mdot
.53436 .52441 Mdot
.48419 .49795 Mdot
.53809 .53622 Mdot
.4894 .48708 Mdot
.45297 .45985 Mdot
.49287 .48718 Mdot
.44329 .53043 Mdot
.52048 .54322 Mdot
.53913 .42508 Mdot
.45419 .48986 Mdot
.53263 .54766 Mdot
.53137 .52818 Mdot
.51335 .53528 Mdot
.49115 .49185 Mdot
.53636 .53898 Mdot
.59603 .45347 Mdot
.43856 .49861 Mdot
.43466 .5698 Mdot
.51733 .52416 Mdot
.47208 .51594 Mdot
.4853 .51669 Mdot
.50446 .42022 Mdot
.5257 .54509 Mdot
.51138 .43168 Mdot
.53106 .52647 Mdot
.49377 .5568 Mdot
.55198 .43105 Mdot
.49858 .55553 Mdot
.46471 .4971 Mdot
.51342 .41957 Mdot
.47178 .50474 Mdot
.45195 .48092 Mdot
.57363 .53506 Mdot
.49311 .4243 Mdot
.54867 .51254 Mdot
.50555 .5165 Mdot
.54237 .52886 Mdot
.49917 .46448 Mdot
.52947 .54003 Mdot
.43566 .50336 Mdot
.49806 .48055 Mdot
.4575 .43728 Mdot
.48181 .50015 Mdot
.52239 .53024 Mdot
.47469 .50829 Mdot
.4499 .52492 Mdot
.48103 .59266 Mdot
.44492 .50529 Mdot
.46808 .56825 Mdot
.5003 .49266 Mdot
.48855 .51913 Mdot
.47745 .54725 Mdot
.48532 .48522 Mdot
.45227 .45446 Mdot
.50888 .52115 Mdot
.44695 .49071 Mdot
.53124 .41261 Mdot
.51412 .52328 Mdot
.48956 .49359 Mdot
.48715 .43803 Mdot
.49038 .52266 Mdot
.55481 .47584 Mdot
.52633 .52679 Mdot
.42814 .43002 Mdot
.41013 .54569 Mdot
.54063 .53779 Mdot
.47535 .59269 Mdot
.44092 .47654 Mdot
.4087 .54619 Mdot
.43189 .51925 Mdot
.57094 .43096 Mdot
.5013 .50646 Mdot
.50145 .4438 Mdot
.52183 .45426 Mdot
.50266 .45126 Mdot
.51291 .53665 Mdot
.48057 .54836 Mdot
.53542 .53932 Mdot
.55945 .45394 Mdot
.44717 .48651 Mdot
.42943 .52084 Mdot
.58918 .51418 Mdot
.43012 .50139 Mdot
.4876 .59906 Mdot
.50379 .48929 Mdot
.45975 .48717 Mdot
.57495 .51187 Mdot
.46446 .58061 Mdot
.50419 .49358 Mdot
.47995 .54311 Mdot
.53292 .45548 Mdot
.47088 .40692 Mdot
.43432 .56194 Mdot
.4271 .43836 Mdot
.51856 .51944 Mdot
.48122 .50197 Mdot
.53727 .55007 Mdot
.53758 .43891 Mdot
.53136 .53243 Mdot
.41882 .50849 Mdot
.50072 .60683 Mdot
.47708 .52535 Mdot
.44391 .50844 Mdot
.46011 .48069 Mdot
.57362 .50303 Mdot
.5324 .45878 Mdot
.52486 .54351 Mdot
.45925 .48255 Mdot
.57864 .47934 Mdot
.46085 .4363 Mdot
.55034 .46201 Mdot
.53308 .54974 Mdot
.47701 .45279 Mdot
.54138 .45473 Mdot
.4976 .51682 Mdot
.47494 .49866 Mdot
.50529 .52823 Mdot
.44103 .49436 Mdot
.59314 .49169 Mdot
.53911 .52672 Mdot
.53906 .53578 Mdot
.46192 .52984 Mdot
.51819 .54246 Mdot
.50071 .52835 Mdot
.48461 .48582 Mdot
.49404 .60294 Mdot
.48623 .50591 Mdot
.5697 .4375 Mdot
.51084 .53553 Mdot
.46257 .49317 Mdot
.5369 .54871 Mdot
.48048 .48988 Mdot
.55462 .53664 Mdot
.51994 .54414 Mdot
.55969 .43246 Mdot
.53767 .51544 Mdot
.43577 .54896 Mdot
.49475 .46899 Mdot
.55636 .54244 Mdot
.49983 .45887 Mdot
.5268 .51922 Mdot
.47967 .50936 Mdot
.51726 .46512 Mdot
.50387 .50889 Mdot
.48164 .40156 Mdot
.49597 .45995 Mdot
.51258 .51022 Mdot
.49928 .48753 Mdot
.45159 .49763 Mdot
.58571 .5149 Mdot
.44814 .55488 Mdot
.45099 .53504 Mdot
.43763 .51056 Mdot
.5307 .54062 Mdot
.49428 .48193 Mdot
.46778 .52564 Mdot
.51766 .49762 Mdot
.41347 .45377 Mdot
.53035 .5289 Mdot
.55842 .43043 Mdot
.44186 .47862 Mdot
.51975 .40738 Mdot
.49766 .51457 Mdot
.45155 .49301 Mdot
.50404 .45625 Mdot
.4829 .5013 Mdot
.52453 .53548 Mdot
.55915 .53957 Mdot
.48089 .51005 Mdot
.42901 .52503 Mdot
.48858 .51064 Mdot
.42463 .49734 Mdot
.49817 .46175 Mdot
.45165 .41733 Mdot
.46744 .48365 Mdot
.48985 .53098 Mdot
.48711 .41037 Mdot
.52555 .46357 Mdot
.48243 .44916 Mdot
.50205 .42901 Mdot
.45134 .51686 Mdot
.4808 .5031 Mdot
.51706 .53216 Mdot
.50582 .49087 Mdot
.48973 .50308 Mdot
.52951 .53699 Mdot
.56639 .45724 Mdot
.54839 .4271 Mdot
.51741 .54903 Mdot
.55365 .53335 Mdot
.47908 .47443 Mdot
.48412 .5593 Mdot
.52677 .54973 Mdot
.55602 .46314 Mdot
.5657 .51626 Mdot
.51774 .53295 Mdot
.46754 .46426 Mdot
.52441 .52666 Mdot
.44281 .447 Mdot
.51115 .52604 Mdot
.49307 .50718 Mdot
.54385 .55023 Mdot
.55196 .44179 Mdot
.51844 .48944 Mdot
.48202 .4159 Mdot
.5598 .45226 Mdot
.49886 .47186 Mdot
.50741 .47925 Mdot
.52903 .54842 Mdot
.50286 .4827 Mdot
.41258 .53128 Mdot
.41339 .46628 Mdot
.59509 .48483 Mdot
.48059 .48613 Mdot
.51232 .5253 Mdot
.43429 .44792 Mdot
.4503 .50606 Mdot
.49906 .47769 Mdot
.4992 .49085 Mdot
.56085 .42445 Mdot
.48197 .46342 Mdot
.51158 .53939 Mdot
.52804 .54295 Mdot
.44431 .48132 Mdot
.55393 .54164 Mdot
.55546 .53749 Mdot
.54588 .47671 Mdot
.43284 .53062 Mdot
.48802 .495 Mdot
.50074 .45511 Mdot
.4963 .40793 Mdot
.51488 .45527 Mdot
.49895 .53125 Mdot
.44339 .44297 Mdot
.51532 .52292 Mdot
.52836 .53166 Mdot
.56134 .51766 Mdot
.56949 .51396 Mdot
.50816 .51919 Mdot
.418 .46209 Mdot
.41044 .48244 Mdot
.54395 .45794 Mdot
.50372 .50634 Mdot
.50259 .51591 Mdot
.47393 .45955 Mdot
.47318 .48955 Mdot
.45643 .48331 Mdot
.46608 .59977 Mdot
.48862 .49694 Mdot
.46343 .52632 Mdot
.48939 .50439 Mdot
.50003 .45801 Mdot
.50558 .51194 Mdot
.50962 .41465 Mdot
.60179 .46995 Mdot
.46978 .41245 Mdot
.44418 .50612 Mdot
.48802 .57087 Mdot
.56378 .41751 Mdot
.55738 .44379 Mdot
.43149 .57951 Mdot
.48289 .46563 Mdot
.59465 .4553 Mdot
.5453 .41128 Mdot
.52695 .55184 Mdot
.52524 .52783 Mdot
.53735 .55053 Mdot
.46391 .50683 Mdot
.49881 .45038 Mdot
.54319 .54621 Mdot
.51026 .45872 Mdot
.51449 .54393 Mdot
.45209 .5365 Mdot
.4739 .46643 Mdot
.45401 .54554 Mdot
.49724 .44834 Mdot
.50792 .53779 Mdot
.48898 .45739 Mdot
.58173 .49551 Mdot
.47502 .51046 Mdot
.46488 .51283 Mdot
.5025 .53951 Mdot
.43229 .48886 Mdot
.59396 .47879 Mdot
.49955 .52102 Mdot
.44783 .49917 Mdot
.52635 .43739 Mdot
.47563 .40079 Mdot
.49739 .50393 Mdot
.52009 .54077 Mdot
.4927 .46497 Mdot
.5227 .47175 Mdot
.48661 .50694 Mdot
.46761 .4405 Mdot
.50303 .48197 Mdot
.43813 .45394 Mdot
.40686 .48912 Mdot
.5061 .52703 Mdot
.50267 .47239 Mdot
.44573 .51587 Mdot
.53651 .53886 Mdot
.49917 .59601 Mdot
.49182 .50548 Mdot
.43943 .51595 Mdot
.54309 .55213 Mdot
.49909 .41909 Mdot
.44189 .55552 Mdot
.5434 .55482 Mdot
.51539 .43156 Mdot
.57189 .4901 Mdot
.54422 .54461 Mdot
.49073 .48091 Mdot
.53621 .52836 Mdot
.46845 .51235 Mdot
.4864 .4835 Mdot
.5454 .43962 Mdot
.46931 .49667 Mdot
.56015 .54565 Mdot
.5605 .51564 Mdot
.56932 .43716 Mdot
.50464 .53978 Mdot
.54269 .50583 Mdot
.52195 .53154 Mdot
.47118 .49898 Mdot
.51462 .52476 Mdot
.59092 .4987 Mdot
.411 .47479 Mdot
.50178 .52105 Mdot
.5166 .55668 Mdot
.53859 .54097 Mdot
.49469 .52551 Mdot
.51557 .53612 Mdot
.58386 .47954 Mdot
.49714 .51943 Mdot
.54 .45986 Mdot
.50895 .50779 Mdot
.50467 .46669 Mdot
.50338 .48858 Mdot
.50886 .52803 Mdot
.49606 .50823 Mdot
.55976 .47534 Mdot
.44031 .49213 Mdot
.50107 .49611 Mdot
.46631 .49979 Mdot
.50323 .46739 Mdot
.53139 .5565 Mdot
.53377 .41923 Mdot
.46032 .58361 Mdot
.53267 .54397 Mdot
.45437 .4661 Mdot
.52722 .52344 Mdot
.57399 .48 Mdot
.56927 .49372 Mdot
.40935 .55184 Mdot
.48306 .53152 Mdot
.56019 .54429 Mdot
.48407 .48774 Mdot
.55776 .42815 Mdot
.49453 .47008 Mdot
.49305 .50201 Mdot
.43474 .48783 Mdot
.55531 .50387 Mdot
.45811 .45863 Mdot
.57869 .4706 Mdot
.49342 .48502 Mdot
.43391 .49632 Mdot
.44853 .55145 Mdot
.42854 .57108 Mdot
.53806 .45135 Mdot
.48744 .49144 Mdot
.48661 .52083 Mdot
.52043 .52354 Mdot
.48992 .44161 Mdot
.577 .47845 Mdot
.58231 .52384 Mdot
.59375 .45136 Mdot
.42008 .52647 Mdot
.47318 .48539 Mdot
.52458 .52949 Mdot
.54305 .53924 Mdot
.4895 .54329 Mdot
.48217 .47739 Mdot
.54875 .52966 Mdot
.48892 .47671 Mdot
.46532 .56703 Mdot
.47216 .46235 Mdot
.49841 .57321 Mdot
.46712 .4626 Mdot
.48494 .3983 Mdot
.53012 .53857 Mdot
.45619 .42684 Mdot
.51924 .52427 Mdot
.46361 .49279 Mdot
.42125 .5118 Mdot
.42399 .57585 Mdot
.55581 .45359 Mdot
.52825 .53646 Mdot
.47248 .50287 Mdot
.53203 .45468 Mdot
.50316 .44374 Mdot
.54653 .54597 Mdot
.49423 .4697 Mdot
.43653 .54935 Mdot
.49067 .47491 Mdot
.55751 .48357 Mdot
.5306 .54034 Mdot
.45653 .48207 Mdot
.50998 .54204 Mdot
.46672 .49535 Mdot
.53531 .44416 Mdot
.44751 .47583 Mdot
.5123 .522 Mdot
.4812 .48744 Mdot
.41925 .52717 Mdot
.53798 .5425 Mdot
.54158 .44631 Mdot
.5419 .55035 Mdot
.50368 .48438 Mdot
.48219 .45968 Mdot
.4725 .46324 Mdot
.49723 .51978 Mdot
.47495 .41035 Mdot
.47632 .44993 Mdot
.44069 .45341 Mdot
.51182 .53304 Mdot
.49994 .51474 Mdot
.52489 .52758 Mdot
.47263 .53052 Mdot
.53267 .51605 Mdot
.48141 .48427 Mdot
.46747 .57454 Mdot
.55723 .45138 Mdot
.51615 .53683 Mdot
.51276 .54468 Mdot
.40922 .5207 Mdot
.40957 .49203 Mdot
.45452 .52779 Mdot
.43295 .5815 Mdot
.46908 .52775 Mdot
.5149 .5385 Mdot
.46512 .50415 Mdot
.48875 .45504 Mdot
.56049 .52281 Mdot
.48174 .42042 Mdot
.54772 .41185 Mdot
.40354 .51492 Mdot
.48177 .49991 Mdot
.51039 .51905 Mdot
.57086 .50752 Mdot
.49001 .49248 Mdot
.50085 .47883 Mdot
.44496 .5192 Mdot
.48132 .49989 Mdot
.50198 .5043 Mdot
.45373 .54747 Mdot
.54476 .53822 Mdot
.43364 .50779 Mdot
.47384 .47959 Mdot
.54459 .54717 Mdot
.48151 .47412 Mdot
.6017 .48981 Mdot
.54598 .53073 Mdot
.46899 .57555 Mdot
.44758 .45828 Mdot
.56707 .45796 Mdot
.52813 .43545 Mdot
.49252 .48511 Mdot
.51006 .46581 Mdot
.51865 .53744 Mdot
.47916 .50885 Mdot
.59274 .49179 Mdot
.46822 .41472 Mdot
.58746 .45254 Mdot
.49342 .43554 Mdot
.49613 .48083 Mdot
.56501 .54298 Mdot
.49999 .45242 Mdot
.47801 .51216 Mdot
.5252 .53686 Mdot
.42344 .51961 Mdot
.58557 .45256 Mdot
.49968 .53847 Mdot
.50206 .51478 Mdot
.4238 .51065 Mdot
.52893 .52361 Mdot
.50433 .49592 Mdot
.50031 .60213 Mdot
.49816 .46951 Mdot
.46857 .46678 Mdot
.47856 .49227 Mdot
.47601 .48872 Mdot
.54892 .50262 Mdot
.46783 .48737 Mdot
.50059 .43384 Mdot
.48026 .47706 Mdot
.50686 .59055 Mdot
.49134 .47989 Mdot
.42535 .51947 Mdot
.46967 .5092 Mdot
.5092 .45947 Mdot
.49548 .42877 Mdot
.45833 .52453 Mdot
.47712 .55534 Mdot
.47879 .49731 Mdot
.50885 .47908 Mdot
.4912 .45762 Mdot
.486 .50944 Mdot
.44859 .52785 Mdot
.4382 .43308 Mdot
.5575 .44079 Mdot
.45356 .56274 Mdot
.51732 .52995 Mdot
.49603 .50431 Mdot
.49946 .41296 Mdot
.45613 .53068 Mdot
.43757 .56357 Mdot
.48714 .48189 Mdot
.50717 .46121 Mdot
.47995 .50594 Mdot
.44794 .59094 Mdot
.49316 .4768 Mdot
.47199 .4867 Mdot
.47701 .53895 Mdot
.47271 .59665 Mdot
.48806 .45372 Mdot
.49086 .49455 Mdot
.50345 .60816 Mdot
.51186 .52578 Mdot
.47879 .40982 Mdot
.44432 .56288 Mdot
.42332 .5324 Mdot
.58511 .46287 Mdot
.52493 .44697 Mdot
.4455 .48801 Mdot
.48852 .48074 Mdot
.5071 .53798 Mdot
.56058 .44945 Mdot
.46957 .45064 Mdot
.46362 .44641 Mdot
.45325 .49172 Mdot
.55319 .42786 Mdot
.54141 .54803 Mdot
.4822 .4942 Mdot
.55509 .54767 Mdot
.48274 .45696 Mdot
.48774 .47373 Mdot
.54618 .53936 Mdot
.44117 .52735 Mdot
.5223 .54376 Mdot
.49016 .40508 Mdot
.41041 .53161 Mdot
.46849 .54771 Mdot
.49286 .48867 Mdot
.51887 .55852 Mdot
.50192 .51653 Mdot
.5115 .52138 Mdot
.45297 .48062 Mdot
.42713 .49887 Mdot
.46935 .48597 Mdot
.52285 .53249 Mdot
.45246 .55277 Mdot
.45962 .52078 Mdot
.54201 .43452 Mdot
.59006 .49206 Mdot
.48293 .565 Mdot
.51656 .40288 Mdot
.52491 .54536 Mdot
.46537 .40566 Mdot
.4925 .49068 Mdot
.49307 .5155 Mdot
.55088 .54847 Mdot
.56957 .53678 Mdot
.5008 .48908 Mdot
.50418 .45234 Mdot
.53414 .4652 Mdot
.49028 .43315 Mdot
.44039 .45935 Mdot
.54002 .43865 Mdot
.47736 .4857 Mdot
.52198 .54613 Mdot
.52015 .51791 Mdot
.55798 .45501 Mdot
.5076 .48126 Mdot
.52608 .42487 Mdot
.5327 .53158 Mdot
.53198 .53785 Mdot
.50841 .53852 Mdot
.44056 .54219 Mdot
.42036 .48561 Mdot
.40735 .51246 Mdot
.55738 .54273 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo09Oooooo0_l0002^ooooo`000oooool01Ol@413ooooooooooooooooo410@00_o
oooo1Ol00006ooooo`?o0000Uoooool2o`000003ooooool0003o00000:_ooooo0003ooooo`05o`00
0?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo
09Oooooo1Ol00007ooooo`?o0000XOooool000?ooooo00Go0000ooooooooooooooooo`00000;oooo
o`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0Toooool4o`000004ooooool0003o
0000ooooo`;o00001Oooool5o`000:3ooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo09?ooooo3?l00003ooooo`;o000000?o
ooooo`000?l00000X?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000000Oooooo00?o0000ooooooooool0UOooool7o`000003ooooool0003o000000?o00001ooo
ool2o`000003ooooool0003o000000?o0000U_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0U?ooool3o`0000;ooooo0ol0
0002ooooo`Ko00001?ooool3o`000003ooooool0003o000000?o0000U_ooool001kooooo00?o0000
ooooooooool0Soooool2o`0000?ooooo0_l00003ooooo`?o00000_ooool2o`000003ooooool0003o
000000;o00000oooool3o`0000Gooooo0_l000000ooooooo0000o`00002Booooo`007_ooool00ol0
003oooooooooo`2>ooooo`?o00001_ooool4o`000003ooooool0003o000000Co000000?oooooo`00
0?l000001?ooool2o`0000Gooooo0_l000000ooooooo0000o`00002Booooo`007_ooool00ol0003o
ooooooooo`2>ooooo`;o00001oooool;o`000003ooooool0003o000000;ooooo0ol000000ooooooo
0000o`000005ooooo`?o0000T_ooool001kooooo00?o0000ooooooooool0T?ooool2o`0000Sooooo
1ol00002ooooo`;o00000_ooool3o`000004ooooool0003o0000ooooo`So00000_ooool2o`0008go
oooo000Nooooo`03o`000?oooooooooo08Oooooo0_l00007ooooo`;o00002_ooool5o`000004oooo
ool0003o0000o`0000Wooooo1Ol000000ooooooo0000o`000004o`0008gooooo000Nooooo`03o`00
0?oooooooooo08Oooooo0_l000000ooooooo0000o`00000?ooooo`[o00001oooool2o`000003oooo
ool0003o000000?o00000_ooool2o`0008oooooo000Nooooo`03o`000?oooooooooo08[ooooo0_l0
0005ooooo`?o00001_ooool9o`0000Cooooo0ol00002ooooo`;o00001?ooool2o`000003ooooool0
003o0000093ooooo000Nooooo`03o`000?oooooooooo08Oooooo0_l00008ooooo`Go00001?ooool:
o`0000?ooooo0ol000000ooooooo0000o`000002o`000003ooooool0003o000000;o000000Cooooo
o`000?l0003ooooo0_l0002=ooooo`007_ooool00ol0003oooooooooo`27ooooo`;o00000oooool2
o`0000Cooooo1?l00005ooooo`Wo00001_ooool;o`0000?ooooo0_l0002=ooooo`007_ooool00ol0
003oooooooooo`2:ooooo`Co00001Oooool2o`0000?ooooo0_l000000ooooooo0000o`000004o`00
00Gooooo0ol000000ooooooo0000o`000002o`000003ooooool0003o000000Co00001Oooool2o`00
08_ooooo000Nooooo`03o`000?oooooooooo08Wooooo1Ol00005ooooo`;o00000_ooool4o`000003
ooooool0003o000000;o00000_ooool2o`0000;ooooo0ol00003ooooo`;o00001?ooool2o`0000Ko
oooo0_l0002;ooooo`007_ooool2o`0008[ooooo1?l00008ooooo`Ko00000oooool9o`0000Cooooo
0_l00004ooooo`Co00001Oooool6o`0008Oooooo000Nooooo`03o`000?oooooooooo08;ooooo0_l0
0006ooooo`?o00000_ooool5o`000003ooooool0003o000000;o000000?oooooo`000?l000003?l0
00000ooooooo0000o`000005o`000003ooooool0003o000000;o00000_ooool9o`0008Oooooo000N
ooooo`03o`000?oooooooooo08;ooooo0_l00003ooooo`;o000000?oooooo`000?l000002?l00002
ooooo`;o000000?oooooo`000?l000004?l000000ooooooo0000o`000002o`000003ooooool0003o
000000?o000000?oooooo`000?l000001_l00028ooooo`007_ooool00ol0003oooooooooo`23oooo
o`?o000000?oooooo`000?l000000_ooool8o`000003ooooool0003o000000;o000000?oooooo`00
0?l000001Ol000001?oooooo0000o`000?l00004ooooo`Wo00000_ooool3o`0000Oooooo0_l00028
ooooo`007_ooool00ol0003oooooooooo`23ooooo`?o00001Oooool2o`0000;ooooo0_l00003oooo
o`?o00000_ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000000ol000001?oo
oooo0000o`000?ooool3o`0000;ooooo1?l00007ooooo`;o000000?oooooo`000?l00000R?ooool0
01kooooo00?o0000ooooooooool0P_ooool2o`0000;ooooo0_l00007ooooo`?o00000_ooool4o`00
0003ooooool0003o000000_o000000Coooooo`000?l0003ooooo0_l00005ooooo`;o00001?ooool2
o`000003ooooool0003o000008_ooooo000Nooooo`03o`000?oooooooooo08;ooooo0_l00002oooo
o`;o000000?oooooo`000?l000001?ooool3o`0000;ooooo1?l000000ooooooo0000o`000007o`00
00Cooooo0ol0000>ooooo`?o00001_ooool2o`0008Gooooo000Nooooo`03o`000?oooooooooo08;o
oooo1?l00003ooooo`;o00003?ooool<o`0000?ooooo0_l00006ooooo`;o00002?ooool2o`0000Go
oooo0ol00025ooooo`007_ooool00ol0003oooooooooo`22ooooo`Co00001Oooool4o`0000Oooooo
3Ol00008ooooo`Wo00001?ooool2o`0000Gooooo0_l00026ooooo`007_ooool00ol0003ooooooooo
o`23ooooo`;o00000_ooool2o`0000;ooooo2?l00003ooooo`oo00001_ooool4o`000003ooooool0
003o000000;o00000_ooool6o`000003ooooool0003o000008Sooooo000Nooooo`03o`000?oooooo
oooo087ooooo1?l00002ooooo`;o00000oooool7o`000003ooooool0003o000000oo00003?ooool2
o`0000?ooooo1_l000000ooooooo0000o`000028ooooo`007_ooool00ol0003oooooooooo`21oooo
o`;o00000_ooool2o`0000Gooooo6?l00006ooooo`;o00000_ooool2o`000003ooooool0003o0000
00Kooooo1_l00028ooooo`007_ooool00ol0003oooooooooo`20ooooo`;o00000oooool2o`000005
ooooool0003o0000o`000?ooool00ol000000ooooooo0000o`00000Do`0000Cooooo1ol00005oooo
o`;o000000?oooooo`000?l000001?l000000ooooooo0000o`000025ooooo`007_ooool00ol0003o
ooooooooo`20ooooo`?o00000oooool?o`000003ooooool0003o000000[o00000_ooool2o`0000Ko
oooo0_l000000ooooooo0000o`000005ooooo`;o000000Coooooo`000?l0003ooooo0ol000000ooo
oooo0000o`000025ooooo`007_ooool00ol0003oooooooooo`21ooooo`;o00000oooool2o`000003
ooooool0003o000000Ko000000?oooooo`000?l000003_l000000ooooooo0000o`000002ooooo`?o
00002oooool6o`000004ooooool0003o0000o`0008Sooooo000Nooooo`03o`000?oooooooooo087o
oooo0_l00003ooooo`_o000000?oooooo`000?l000002Ol00002ooooo`?o000000Goooooo`000?l0
003o0000ooooo`03o`0000_ooooo2Ol00029ooooo`007_ooool2o`0008;ooooo0_l00003ooooo`_o
00000_ooool>o`0000?ooooo0_l00002ooooo`;o00001?ooool2o`0000_ooooo0ol00029ooooo`00
7_ooool00ol0003oooooooooo`27ooooo`So00001?ooool>o`0000Oooooo0_l00002ooooo`Ko0000
1?ooool2o`0008oooooo000Nooooo`03o`000?oooooooooo08Cooooo0_l000000ooooooo0000o`00
0007o`0000?ooooo4_l00007ooooo`;o00000_ooool2o`0000?ooooo0ol00002ooooo`;o0000Rooo
ool001kooooo00?o0000ooooooooool0POooool2o`000003ooooool0003o000000;o000000?ooooo
o`000?l000001ol000000ooooooo0000o`00000@o`000003ooooool0003o000000Cooooo0_l00007
ooooo`Co000000?oooooo`000?l00000Roooool001kooooo00?o0000ooooooooool0Ooooool4o`00
00;ooooo7Ol000001?oooooo0000o`000?ooool2o`0000Kooooo0_l00002ooooo`;o000000?ooooo
o`000?l000000_l000001?oooooo0000o`000?l0002:ooooo`007_ooool00ol0003oooooooooo`1o
ooooo`?o00001_ooool2o`000003ooooool0003o000001Go00000oooool2o`0000;ooooo2?l00000
0ooooooo0000o`000004o`0000;ooooo0ol0002:ooooo`007_ooool00ol0003oooooooooo`20oooo
o`?o00000ooooolXo`000004ooooool0003o0000ooooo`Co00000_ooool2o`0008gooooo000Noooo
o`03o`000?oooooooooo083ooooo0ol00003ooooo`Go00000_ooool2o`0000;ooooo1Ol00003oooo
oa7o00002?ooool2o`0000Cooooo0ol0002<ooooo`007_ooool00ol0003oooooooooo`24ooooo`;o
000000?oooooo`000?l000000_ooool2o`000004ooooool0003o0000ooooo`Go000000?oooooo`00
0?l000005?l000001Ooooooo0000o`000?l0003ooooo00;o00001Oooool2o`0008cooooo000Noooo
o`03o`000?oooooooooo08Cooooo1Ol00002ooooo`ko00001?oooolDo`0009Kooooo000Nooooo`03
o`000?oooooooooo087ooooo2_l000000ooooooo0000o`00000:o`000003ooooool0003o000001Oo
000000?oooooo`000?l00000T_ooool001kooooo00?o0000ooooooooool0POooool4o`000003oooo
ool0003o000000?o00000_ooool5o`0000Cooooo2_l000000ooooooo0000o`00000<o`000004oooo
ool0003o0000ooooo`;o000000?oooooo`000?l00000Soooool001kooooo00?o0000ooooooooool0
R?ooool2o`000003ooooool0003o000000Ko00000oooool3o`0000Gooooo5_l000001?oooooo0000
o`000?l0002?ooooo`007_ooool00ol0003oooooooooo`2;ooooo`Co00000_ooool2o`0000?ooooo
0ol00005oooooaKo000000?oooooo`000?l00000T?ooool001kooooo00?o0000ooooooooool0POoo
ool2o`0000Sooooo1_l00007ooooo`;o000000?oooooo`000?l000000oooool?o`000003ooooool0
003o000000Co0000TOooool001kooooo00?o0000ooooooooool0POooool2o`0000cooooo0_l00003
ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000?ooooo5_l0002Aooooo`007_ooool2
o`0008;ooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo0ol00003ooooo`;o000000Cooooo
o`000?l0003o00001_ooool2o`000003ooooool0003o000000go0000UOooool001kooooo00?o0000
ooooooooool0POooool2o`0000;ooooo0ol00002ooooo`;o00000_ooool3o`0000Sooooo0_l00003
ooooo`;o00000oooool3o`000003ooooool0003o000000So0000U_ooool001kooooo00?o0000oooo
ooooool0QOooool2o`0000Gooooo1Ol00002ooooo`;o00000_ooool4o`000003ooooool0003o0000
00;o00001?ooool2o`0000?ooooo0_l000001?oooooo0000o`000?l0002Hooooo`007_ooool00ol0
003oooooooooo`29ooooo`;o000000?oooooo`000?l000001Oooool2o`000003ooooool0003o0000
00?o000000?oooooo`000?l000000_l00004ooooo`?o00000_ooool2o`0009cooooo000Nooooo`03
o`000?oooooooooo08Wooooo1Ol000000ooooooo0000o`000005ooooo`Go00002?ooool4o`000:3o
oooo000Nooooo`03o`000?oooooooooo08Wooooo1Ol000000ooooooo0000o`000002ooooo`;o0000
0_ooool4o`0000Sooooo0_l0002Rooooo`007_ooool00ol0003oooooooooo`29ooooo`;o00000ooo
ool3o`0000;ooooo0ol00003ooooo`;o00001?ooool2o`000:Kooooo000Nooooo`03o`000?oooooo
oooo08Oooooo1?l000000ooooooo0000o`000003o`0000;ooooo1Ol00003ooooo`;o000000Cooooo
o`000?l0003o0000Y_ooool001kooooo00?o0000ooooooooool0Q_ooool3o`0000?ooooo0_l00005
ooooo`Go00000oooool2o`000003ooooool0003o000000Wooooo0_l0002Looooo`007_ooool00ol0
003oooooooooo`26ooooo`Co00002Oooool7o`0000;ooooo0_l0000;ooooo`;o0000W?ooool001ko
oooo00?o0000ooooooooool0R?ooool3o`0000Cooooo0_l00002ooooo`;o00000oooool2o`0000;o
oooo0_l0002Yooooo`007_ooool00ol0003oooooooooo`29ooooo`;o00001?ooool2o`000005oooo
ool0003o0000o`000?ooool00_l00003ooooo`Ko0000Y_ooool001kooooo00?o0000ooooooooool0
T_ooool3o`000003ooooool0003o000000;ooooo1ol0002Vooooo`007_ooool00ol0003ooooooooo
o`2>ooooo`;o00000_ooool2o`0000Kooooo0_l00005ooooo`;o0000Y?ooool000?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo
00?o0000ooooooooool0S_ooool2o`0000;ooooo0_l00002ooooo`Co00000_ooool2o`0000?ooooo
0_l0002Tooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEE
EOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2Fooooo`Co00000_ooool4o`0000Go
oooo0_l0002Pooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooo
ooooooooo`000006ooooo`?o0000Toooool2o`000003ooooool0003o000000;ooooo0_l00002oooo
o`;o00001Oooool2o`000:3ooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0
003oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0Toooool2o`0000;ooooo0_l00000
1?oooooo0000o`000?ooool4o`000:Kooooo0003ooooo`05o`000?ooooooooooooooool000002ooo
ool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0Uoooool2o`0000;ooooo
1ol0002Uooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
2?ooool00ol0003oooooooooo`2Kooooo`?o000000Coooooo`000?l0003o0000YOooool000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000oooooooo
ool0W?ooool2o`000004ooooool0003o0000o`000:Gooooo0003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o
0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<
00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`3o
ooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooo
oooo000000Kooooo0ol0003oooooodSooooo0003ooooo`05o`000?ooooooooooooooool000002ooo
ool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000ooooooooool0oooooom8ooooo`000ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03
o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05
oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000
ooooooooool0oooooom8ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVY
oa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001Cooooo1?l000000ol@413o
ooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB?ooool001Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`3oooooodSooooo000Fooooo`03o`000?oooooooooo00Gooooo0ol0
003oooooodSooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000oooo
ooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`00
0?oooooooooo0?ooooooD?ooool001Cooooo00?oEEEEofIVI_l00000oooooomBooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.55662 .48219 Mdot
.50652 .46956 Mdot
.45809 .46289 Mdot
.51011 .47309 Mdot
.51606 .48604 Mdot
.56034 .52109 Mdot
.44335 .44648 Mdot
.527 .47817 Mdot
.45441 .57154 Mdot
.50518 .54962 Mdot
.5329 .51573 Mdot
.48319 .4961 Mdot
.56832 .51266 Mdot
.51605 .43634 Mdot
.4222 .5215 Mdot
.49756 .5436 Mdot
.52325 .46209 Mdot
.51261 .55973 Mdot
.5067 .55384 Mdot
.46356 .49298 Mdot
.52566 .46172 Mdot
.48497 .54443 Mdot
.51415 .50416 Mdot
.56563 .46558 Mdot
.53376 .47328 Mdot
.48886 .50729 Mdot
.43647 .52493 Mdot
.50954 .55692 Mdot
.51028 .48851 Mdot
.56902 .49691 Mdot
.48557 .4576 Mdot
.51849 .46732 Mdot
.50057 .51631 Mdot
.4522 .47858 Mdot
.56945 .50523 Mdot
.46063 .46997 Mdot
.4924 .5135 Mdot
.45071 .54179 Mdot
.51454 .49721 Mdot
.47846 .49819 Mdot
.50272 .5319 Mdot
.46563 .50757 Mdot
.48459 .46713 Mdot
.49734 .50121 Mdot
.52191 .4671 Mdot
.48956 .53104 Mdot
.51093 .43136 Mdot
.48876 .45174 Mdot
.47168 .46718 Mdot
.47865 .59402 Mdot
.51427 .49416 Mdot
.57978 .51326 Mdot
.50857 .4867 Mdot
.51917 .48797 Mdot
.49594 .54846 Mdot
.48207 .51361 Mdot
.47677 .47832 Mdot
.59052 .50283 Mdot
.52014 .47181 Mdot
.47494 .47634 Mdot
.4821 .53231 Mdot
.49238 .52327 Mdot
.45596 .48398 Mdot
.4991 .54193 Mdot
.50995 .5024 Mdot
.45581 .58143 Mdot
.51248 .45333 Mdot
.48409 .52604 Mdot
.47234 .50318 Mdot
.49511 .54543 Mdot
.4287 .48242 Mdot
.5175 .47624 Mdot
.47143 .48178 Mdot
.49954 .48484 Mdot
.5717 .48303 Mdot
.4352 .4998 Mdot
.47641 .51346 Mdot
.51582 .561 Mdot
.43316 .47293 Mdot
.51806 .537 Mdot
.45129 .527 Mdot
.52978 .47897 Mdot
.52893 .46754 Mdot
.49888 .53015 Mdot
.45455 .48228 Mdot
.50355 .48558 Mdot
.44316 .48378 Mdot
.4865 .52276 Mdot
.47609 .49479 Mdot
.53667 .55622 Mdot
.50837 .49684 Mdot
.49074 .53725 Mdot
.44398 .5053 Mdot
.46507 .59056 Mdot
.44891 .45788 Mdot
.48162 .52777 Mdot
.48411 .52003 Mdot
.4943 .45295 Mdot
.5085 .43115 Mdot
.48169 .47514 Mdot
.44251 .48754 Mdot
.44639 .49935 Mdot
.52129 .47637 Mdot
.48974 .58544 Mdot
.44536 .56166 Mdot
.50077 .51713 Mdot
.50557 .40742 Mdot
.51031 .49888 Mdot
.50563 .4585 Mdot
.49041 .53843 Mdot
.55921 .46616 Mdot
.51716 .4755 Mdot
.49038 .47998 Mdot
.46352 .56655 Mdot
.52315 .44976 Mdot
.57114 .52402 Mdot
.4417 .53809 Mdot
.50608 .55688 Mdot
.47168 .45221 Mdot
.44388 .5102 Mdot
.52945 .54857 Mdot
.49034 .50538 Mdot
.50298 .55018 Mdot
.47761 .46348 Mdot
.51653 .46376 Mdot
.47394 .56764 Mdot
.56526 .47029 Mdot
.4904 .50667 Mdot
.49548 .50502 Mdot
.50495 .53659 Mdot
.5248 .54049 Mdot
.52451 .4577 Mdot
.58155 .46732 Mdot
.46034 .47284 Mdot
.52613 .49432 Mdot
.5725 .45427 Mdot
.50016 .56231 Mdot
.50348 .49869 Mdot
.4702 .49142 Mdot
.49101 .48848 Mdot
.50972 .4977 Mdot
.44596 .55722 Mdot
.49751 .51052 Mdot
.51093 .4767 Mdot
.50272 .51736 Mdot
.4882 .53851 Mdot
.56043 .487 Mdot
.47866 .5255 Mdot
.52328 .44864 Mdot
.47518 .46645 Mdot
.45739 .47863 Mdot
.50924 .55751 Mdot
.51207 .49163 Mdot
.5199 .43967 Mdot
.52788 .53239 Mdot
.49705 .54412 Mdot
.49528 .52329 Mdot
.58051 .48257 Mdot
.47609 .51262 Mdot
.50426 .51096 Mdot
.4263 .49884 Mdot
.47148 .50893 Mdot
.5293 .55352 Mdot
.49325 .547 Mdot
.47558 .48729 Mdot
.48273 .48126 Mdot
.43942 .55425 Mdot
.46008 .53566 Mdot
.47463 .52953 Mdot
.4593 .55508 Mdot
.51976 .54776 Mdot
.47687 .46675 Mdot
.5019 .46912 Mdot
.47446 .48845 Mdot
.42119 .49035 Mdot
.48718 .51579 Mdot
.48456 .5319 Mdot
.50553 .50981 Mdot
.5333 .42795 Mdot
.4647 .47172 Mdot
.50864 .47542 Mdot
.48352 .53029 Mdot
.50006 .49149 Mdot
.50933 .48584 Mdot
.56852 .51794 Mdot
.48459 .49315 Mdot
.44919 .47644 Mdot
.48166 .5312 Mdot
.46669 .58814 Mdot
.44068 .50451 Mdot
.49312 .49492 Mdot
.50811 .52977 Mdot
.55925 .45927 Mdot
.51145 .49426 Mdot
.45585 .54954 Mdot
.50538 .52844 Mdot
.4751 .59548 Mdot
.49903 .5103 Mdot
.50759 .50879 Mdot
.50495 .47375 Mdot
.48662 .47345 Mdot
.4817 .5261 Mdot
.52701 .54785 Mdot
.46496 .52839 Mdot
.50126 .54602 Mdot
.49873 .46943 Mdot
.52868 .45938 Mdot
.48023 .47381 Mdot
.45326 .47479 Mdot
.51264 .49316 Mdot
.52262 .46609 Mdot
.49431 .51212 Mdot
.47438 .49954 Mdot
.5407 .53961 Mdot
.49003 .50507 Mdot
.51471 .42914 Mdot
.48863 .53545 Mdot
.47603 .51016 Mdot
.44711 .55789 Mdot
.50796 .50277 Mdot
.50754 .52487 Mdot
.58859 .49167 Mdot
.48854 .53787 Mdot
.5468 .44018 Mdot
.53105 .50184 Mdot
.53184 .48534 Mdot
.51685 .46979 Mdot
.50006 .55202 Mdot
.45278 .4733 Mdot
.51673 .52653 Mdot
.49576 .54408 Mdot
.49482 .51114 Mdot
.45593 .56059 Mdot
.49664 .51927 Mdot
.48658 .51069 Mdot
.46974 .48994 Mdot
.46612 .56499 Mdot
.43566 .49301 Mdot
.5133 .46111 Mdot
.48449 .4932 Mdot
.50092 .55208 Mdot
.42446 .51854 Mdot
.56311 .47957 Mdot
.46988 .56554 Mdot
.4582 .44789 Mdot
.49395 .54789 Mdot
.43351 .50246 Mdot
.5287 .48326 Mdot
.49513 .54722 Mdot
.43936 .53896 Mdot
.48336 .46861 Mdot
.56704 .52351 Mdot
.43017 .52586 Mdot
.45358 .45208 Mdot
.49273 .48162 Mdot
.48044 .48875 Mdot
.51027 .51952 Mdot
.47694 .50591 Mdot
.45325 .48207 Mdot
.43556 .53972 Mdot
.4591 .53218 Mdot
.50734 .5296 Mdot
.50399 .51145 Mdot
.5327 .53992 Mdot
.46084 .48647 Mdot
.45701 .4876 Mdot
.51526 .52141 Mdot
.52117 .55299 Mdot
.50461 .52524 Mdot
.53983 .42963 Mdot
.5045 .45723 Mdot
.48999 .4801 Mdot
.46425 .58748 Mdot
.48964 .48471 Mdot
.45217 .46958 Mdot
.43175 .49511 Mdot
.47968 .51549 Mdot
.50873 .55078 Mdot
.4654 .49418 Mdot
.51403 .54039 Mdot
.47078 .49681 Mdot
.48377 .5069 Mdot
.49993 .44155 Mdot
.50184 .50983 Mdot
.44929 .548 Mdot
.46814 .59219 Mdot
.52208 .42673 Mdot
.50957 .51737 Mdot
.50998 .46345 Mdot
.52227 .44029 Mdot
.47778 .48874 Mdot
.5217 .44537 Mdot
.56522 .53231 Mdot
.47979 .46773 Mdot
.48294 .48098 Mdot
.52095 .48392 Mdot
.5161 .55371 Mdot
.4626 .47443 Mdot
.46319 .50972 Mdot
.51161 .47276 Mdot
.49994 .50428 Mdot
.5323 .48634 Mdot
.44561 .56627 Mdot
.48882 .54371 Mdot
.47992 .49225 Mdot
.51104 .47348 Mdot
.56636 .43739 Mdot
.54399 .4505 Mdot
.53641 .47352 Mdot
.46141 .4835 Mdot
.50354 .47795 Mdot
.50115 .51181 Mdot
.51159 .53028 Mdot
.54829 .48329 Mdot
.50071 .47384 Mdot
.52528 .44859 Mdot
.4787 .49935 Mdot
.48497 .52483 Mdot
.47125 .48497 Mdot
.45529 .5461 Mdot
.46811 .47023 Mdot
.5379 .51167 Mdot
.54081 .514 Mdot
.48512 .51511 Mdot
.51679 .54929 Mdot
.46824 .55733 Mdot
.49467 .49756 Mdot
.49453 .50456 Mdot
.46812 .5746 Mdot
.45148 .50823 Mdot
.56326 .48763 Mdot
.57581 .51286 Mdot
.48917 .47977 Mdot
.50648 .54926 Mdot
.45524 .47389 Mdot
.51083 .53448 Mdot
.45827 .47749 Mdot
.51469 .47428 Mdot
.5417 .50007 Mdot
.49068 .52248 Mdot
.51065 .45353 Mdot
.53271 .44923 Mdot
.48294 .42183 Mdot
.49846 .51208 Mdot
.4748 .54757 Mdot
.52113 .45262 Mdot
.50205 .50822 Mdot
.52356 .47926 Mdot
.45838 .53333 Mdot
.49877 .5305 Mdot
.47675 .48246 Mdot
.58364 .47376 Mdot
.52413 .46308 Mdot
.49398 .5172 Mdot
.55051 .54033 Mdot
.47999 .48256 Mdot
.52788 .43433 Mdot
.52017 .45764 Mdot
.55491 .54458 Mdot
.50132 .51817 Mdot
.50916 .50516 Mdot
.5261 .44753 Mdot
.48506 .48166 Mdot
.52982 .43796 Mdot
.51974 .45617 Mdot
.4945 .44167 Mdot
.47143 .44121 Mdot
.46249 .53877 Mdot
.53649 .42359 Mdot
.50362 .48718 Mdot
.50461 .51035 Mdot
.50505 .49888 Mdot
.58552 .48273 Mdot
.52594 .51256 Mdot
.46534 .45739 Mdot
.50325 .54744 Mdot
.52012 .51918 Mdot
.43967 .48793 Mdot
.4661 .50312 Mdot
.4922 .511 Mdot
.46029 .4786 Mdot
.44258 .46061 Mdot
.51402 .47877 Mdot
.56338 .45481 Mdot
.51806 .47023 Mdot
.55476 .52074 Mdot
.50929 .5572 Mdot
.50989 .53237 Mdot
.48228 .51075 Mdot
.46125 .47782 Mdot
.57238 .44878 Mdot
.46793 .5007 Mdot
.46592 .47167 Mdot
.51899 .46741 Mdot
.51083 .509 Mdot
.52582 .47439 Mdot
.49003 .54243 Mdot
.50067 .51499 Mdot
.51585 .55057 Mdot
.56667 .44386 Mdot
.5591 .43592 Mdot
.45996 .47469 Mdot
.58351 .45567 Mdot
.48344 .50594 Mdot
.46568 .4736 Mdot
.46328 .46962 Mdot
.50995 .4836 Mdot
.50638 .50614 Mdot
.48681 .47161 Mdot
.51846 .5426 Mdot
.4897 .4909 Mdot
.51421 .5459 Mdot
.50044 .4863 Mdot
.48619 .45377 Mdot
.50287 .48979 Mdot
.44485 .49824 Mdot
.49062 .54087 Mdot
.55257 .45205 Mdot
.47567 .47143 Mdot
.50028 .55123 Mdot
.51533 .54053 Mdot
.48772 .53047 Mdot
.49933 .49154 Mdot
.5097 .54682 Mdot
.59324 .48252 Mdot
.4584 .47347 Mdot
.42774 .53856 Mdot
.50402 .52677 Mdot
.46849 .49334 Mdot
.47559 .50066 Mdot
.52788 .44336 Mdot
.49488 .54528 Mdot
.53073 .45755 Mdot
.51582 .54056 Mdot
.47121 .53338 Mdot
.5607 .45867 Mdot
.47455 .53254 Mdot
.47605 .47864 Mdot
.53375 .44416 Mdot
.47465 .48733 Mdot
.48068 .46635 Mdot
.5442 .55561 Mdot
.52102 .44201 Mdot
.53256 .53711 Mdot
.50105 .51764 Mdot
.52321 .54738 Mdot
.51625 .48108 Mdot
.5018 .54402 Mdot
.45271 .47616 Mdot
.5092 .49401 Mdot
.49136 .43818 Mdot
.4861 .49097 Mdot
.50068 .53229 Mdot
.47448 .49075 Mdot
.45115 .49348 Mdot
.4592 .57073 Mdot
.45797 .47864 Mdot
.4525 .54042 Mdot
.50519 .50537 Mdot
.47618 .5033 Mdot
.46334 .52083 Mdot
.49847 .4814 Mdot
.48605 .45029 Mdot
.49748 .51864 Mdot
.46971 .47059 Mdot
.54917 .43718 Mdot
.50102 .52345 Mdot
.49703 .49158 Mdot
.51767 .44841 Mdot
.47585 .5055 Mdot
.54763 .50284 Mdot
.51201 .53658 Mdot
.45829 .4239 Mdot
.41349 .51415 Mdot
.51543 .54864 Mdot
.45506 .56951 Mdot
.47222 .46265 Mdot
.4119 .51482 Mdot
.4417 .48751 Mdot
.57568 .4594 Mdot
.50041 .51237 Mdot
.52405 .46352 Mdot
.52996 .48135 Mdot
.5225 .47202 Mdot
.48627 .53096 Mdot
.46499 .52248 Mdot
.5085 .54661 Mdot
.55816 .48164 Mdot
.47351 .46818 Mdot
.43934 .48873 Mdot
.56758 .53858 Mdot
.45245 .47476 Mdot
.46366 .58009 Mdot
.50714 .50844 Mdot
.48171 .47122 Mdot
.55412 .53808 Mdot
.44805 .55348 Mdot
.50562 .51156 Mdot
.46559 .51724 Mdot
.53647 .48223 Mdot
.50196 .41421 Mdot
.42922 .52983 Mdot
.45792 .43133 Mdot
.50957 .53243 Mdot
.4843 .49183 Mdot
.50051 .55313 Mdot
.54691 .46612 Mdot
.50967 .53892 Mdot
.43854 .4806 Mdot
.47356 .59329 Mdot
.46809 .50056 Mdot
.45541 .48058 Mdot
.48637 .46804 Mdot
.55641 .5299 Mdot
.53448 .4854 Mdot
.49493 .54375 Mdot
.48461 .46887 Mdot
.56828 .50751 Mdot
.49467 .43822 Mdot
.54762 .4888 Mdot
.49582 .54792 Mdot
.50902 .45591 Mdot
.54304 .48135 Mdot
.48903 .50912 Mdot
.48136 .48518 Mdot
.48362 .51873 Mdot
.46332 .4716 Mdot
.57798 .51878 Mdot
.52139 .5453 Mdot
.51589 .54658 Mdot
.45731 .50043 Mdot
.488 .53856 Mdot
.47965 .51405 Mdot
.49753 .48136 Mdot
.46814 .58674 Mdot
.48673 .4978 Mdot
.5725 .46596 Mdot
.48441 .52791 Mdot
.47795 .4753 Mdot
.50308 .5545 Mdot
.49146 .4818 Mdot
.52691 .55666 Mdot
.48866 .54087 Mdot
.56613 .46075 Mdot
.52284 .53796 Mdot
.43353 .51622 Mdot
.51214 .47946 Mdot
.52426 .56017 Mdot
.51886 .47654 Mdot
.51395 .53787 Mdot
.47668 .49469 Mdot
.5222 .49147 Mdot
.50149 .51685 Mdot
.5101 .41367 Mdot
.51694 .47307 Mdot
.507 .52577 Mdot
.50693 .50073 Mdot
.46799 .47512 Mdot
.56384 .53974 Mdot
.44119 .52334 Mdot
.44819 .50371 Mdot
.44973 .48129 Mdot
.50282 .54512 Mdot
.50615 .48807 Mdot
.4626 .49808 Mdot
.5103 .52025 Mdot
.44143 .44176 Mdot
.51415 .53945 Mdot
.56606 .45854 Mdot
.47286 .46398 Mdot
.54039 .43006 Mdot
.49244 .50915 Mdot
.47139 .47252 Mdot
.52109 .47796 Mdot
.48642 .49251 Mdot
.49897 .53775 Mdot
.52864 .55918 Mdot
.4771 .49573 Mdot
.43729 .49223 Mdot
.48528 .50166 Mdot
.44926 .47244 Mdot
.51709 .47718 Mdot
.48372 .41807 Mdot
.4897 .47138 Mdot
.47279 .50956 Mdot
.5154 .42541 Mdot
.52713 .4901 Mdot
.51302 .45573 Mdot
.52597 .45227 Mdot
.45562 .48764 Mdot
.48308 .49231 Mdot
.49334 .53085 Mdot
.50682 .51116 Mdot
.49202 .49831 Mdot
.50359 .54154 Mdot
.56325 .48555 Mdot
.55906 .45452 Mdot
.4857 .53249 Mdot
.52888 .55363 Mdot
.50256 .47054 Mdot
.4649 .53483 Mdot
.49104 .54068 Mdot
.55229 .4904 Mdot
.54428 .54189 Mdot
.49355 .53191 Mdot
.49836 .45982 Mdot
.50941 .53416 Mdot
.47642 .44299 Mdot
.49245 .52251 Mdot
.4934 .5032 Mdot
.50657 .557 Mdot
.55674 .46907 Mdot
.51264 .51364 Mdot
.5125 .42824 Mdot
.55905 .48004 Mdot
.51303 .48776 Mdot
.5117 .50262 Mdot
.49565 .54938 Mdot
.50991 .5021 Mdot
.42228 .49979 Mdot
.44106 .45057 Mdot
.58223 .51239 Mdot
.4946 .47887 Mdot
.49499 .52288 Mdot
.46671 .44169 Mdot
.46109 .47983 Mdot
.51077 .4931 Mdot
.50546 .50192 Mdot
.57003 .45225 Mdot
.50842 .46477 Mdot
.48304 .5307 Mdot
.4987 .54531 Mdot
.47463 .46564 Mdot
.52309 .55959 Mdot
.52681 .55757 Mdot
.53897 .50311 Mdot
.43745 .49783 Mdot
.49486 .49148 Mdot
.52066 .47407 Mdot
.52233 .42689 Mdot
.52537 .48189 Mdot
.47765 .51439 Mdot
.477 .43978 Mdot
.50357 .52514 Mdot
.50639 .53659 Mdot
.54106 .54249 Mdot
.5483 .54018 Mdot
.50023 .51884 Mdot
.44718 .4484 Mdot
.43601 .46247 Mdot
.54362 .48454 Mdot
.50201 .51568 Mdot
.49778 .51377 Mdot
.50513 .45877 Mdot
.48726 .47712 Mdot
.48195 .46854 Mdot
.44702 .5766 Mdot
.49425 .49336 Mdot
.45962 .49753 Mdot
.49108 .49893 Mdot
.51927 .47602 Mdot
.50223 .51929 Mdot
.53151 .43781 Mdot
.59382 .49825 Mdot
.50149 .41933 Mdot
.45695 .47909 Mdot
.46559 .54776 Mdot
.5746 .44409 Mdot
.56035 .4715 Mdot
.42287 .54994 Mdot
.50818 .46671 Mdot
.59121 .4844 Mdot
.56111 .43619 Mdot
.49193 .53942 Mdot
.50796 .53386 Mdot
.49905 .54992 Mdot
.46839 .4843 Mdot
.52163 .46788 Mdot
.51196 .55721 Mdot
.522 .48384 Mdot
.48279 .53291 Mdot
.44837 .50534 Mdot
.50306 .46352 Mdot
.44712 .51459 Mdot
.52152 .46438 Mdot
.48073 .52567 Mdot
.51432 .46399 Mdot
.56614 .52285 Mdot
.47338 .49179 Mdot
.46559 .48809 Mdot
.47775 .52 Mdot
.45999 .46824 Mdot
.5831 .50701 Mdot
.48474 .51119 Mdot
.4644 .47528 Mdot
.5388 .46474 Mdot
.50526 .41042 Mdot
.49903 .50549 Mdot
.49166 .53899 Mdot
.51304 .47312 Mdot
.5214 .49773 Mdot
.48637 .49868 Mdot
.5016 .44368 Mdot
.51025 .50169 Mdot
.47088 .44698 Mdot
.43056 .4673 Mdot
.48529 .51884 Mdot
.51413 .49258 Mdot
.45266 .48609 Mdot
.50994 .5468 Mdot
.47201 .57975 Mdot
.4929 .5013 Mdot
.44823 .4854 Mdot
.50378 .55265 Mdot
.52473 .44034 Mdot
.43656 .52335 Mdot
.5047 .55275 Mdot
.53306 .45799 Mdot
.55907 .51738 Mdot
.51485 .55631 Mdot
.50454 .48324 Mdot
.51881 .54404 Mdot
.46817 .48966 Mdot
.5004 .48101 Mdot
.55243 .46682 Mdot
.47873 .48038 Mdot
.52563 .56106 Mdot
.54143 .54042 Mdot
.57229 .46562 Mdot
.47876 .52216 Mdot
.5291 .5306 Mdot
.49902 .53296 Mdot
.4782 .48327 Mdot
.49884 .52415 Mdot
.57366 .52529 Mdot
.4377 .4569 Mdot
.48774 .5129 Mdot
.48597 .53841 Mdot
.51074 .54973 Mdot
.47722 .50876 Mdot
.48972 .5328 Mdot
.57307 .50802 Mdot
.48399 .5091 Mdot
.53964 .48633 Mdot
.50517 .52217 Mdot
.51691 .4889 Mdot
.50738 .50751 Mdot
.48754 .52199 Mdot
.49599 .5062 Mdot
.55234 .50277 Mdot
.46524 .47024 Mdot
.50407 .50825 Mdot
.47466 .48117 Mdot
.5164 .48825 Mdot
.49631 .54494 Mdot
.54992 .44505 Mdot
.44493 .5563 Mdot
.50307 .54865 Mdot
.48664 .45786 Mdot
.51402 .53864 Mdot
.56371 .50794 Mdot
.55592 .52066 Mdot
.41012 .52052 Mdot
.46906 .50732 Mdot
.52679 .56079 Mdot
.49571 .48258 Mdot
.56638 .45616 Mdot
.51153 .48026 Mdot
.4957 .50039 Mdot
.46286 .46787 Mdot
.54106 .52967 Mdot
.49105 .45406 Mdot
.57074 .4993 Mdot
.50423 .4889 Mdot
.45855 .47203 Mdot
.4421 .51981 Mdot
.42243 .54036 Mdot
.54213 .47812 Mdot
.49637 .48824 Mdot
.47432 .50289 Mdot
.50951 .5324 Mdot
.51902 .45305 Mdot
.56695 .5066 Mdot
.55752 .54742 Mdot
.59153 .48061 Mdot
.431 .49427 Mdot
.49137 .47433 Mdot
.50412 .53336 Mdot
.51669 .55109 Mdot
.47026 .51907 Mdot
.50218 .47392 Mdot
.52712 .54968 Mdot
.50567 .47884 Mdot
.45065 .53863 Mdot
.50298 .46016 Mdot
.47224 .55219 Mdot
.49838 .45867 Mdot
.51247 .41106 Mdot
.50332 .54319 Mdot
.48924 .42864 Mdot
.50681 .52953 Mdot
.47898 .47542 Mdot
.43903 .4828 Mdot
.41716 .54613 Mdot
.55527 .48099 Mdot
.50252 .54045 Mdot
.47646 .4865 Mdot
.53622 .4815 Mdot
.52453 .46496 Mdot
.51472 .5594 Mdot
.51156 .47943 Mdot
.434 .51664 Mdot
.50746 .47977 Mdot
.54823 .51063 Mdot
.50286 .54485 Mdot
.48282 .46788 Mdot
.48072 .52714 Mdot
.47856 .47822 Mdot
.54328 .47127 Mdot
.479 .46319 Mdot
.50092 .52205 Mdot
.49389 .48026 Mdot
.43004 .49505 Mdot
.50929 .55065 Mdot
.54702 .47319 Mdot
.50377 .55418 Mdot
.50927 .50447 Mdot
.50971 .46212 Mdot
.50305 .46089 Mdot
.48352 .50922 Mdot
.50628 .41948 Mdot
.50928 .45403 Mdot
.47378 .44721 Mdot
.48738 .52774 Mdot
.49568 .51114 Mdot
.50796 .53369 Mdot
.46408 .50364 Mdot
.51868 .53752 Mdot
.4966 .47796 Mdot
.45109 .54702 Mdot
.55721 .47893 Mdot
.4899 .53368 Mdot
.48228 .52889 Mdot
.42362 .49141 Mdot
.4335 .4695 Mdot
.45288 .49708 Mdot
.42362 .55228 Mdot
.46265 .50033 Mdot
.48742 .53381 Mdot
.47103 .48323 Mdot
.51513 .4625 Mdot
.53789 .54738 Mdot
.51287 .43207 Mdot
.56294 .43699 Mdot
.41999 .48744 Mdot
.48622 .49077 Mdot
.50367 .52237 Mdot
.55227 .53403 Mdot
.49802 .49109 Mdot
.51098 .4966 Mdot
.45046 .48849 Mdot
.48581 .49046 Mdot
.50143 .51241 Mdot
.44646 .51647 Mdot
.51937 .55159 Mdot
.44882 .47911 Mdot
.49658 .4713 Mdot
.51176 .55896 Mdot
.5038 .47158 Mdot
.58735 .51616 Mdot
.52501 .54931 Mdot
.45203 .54845 Mdot
.48113 .45175 Mdot
.56364 .4863 Mdot
.54075 .46269 Mdot
.50361 .488 Mdot
.5187 .49088 Mdot
.49207 .53584 Mdot
.4767 .49409 Mdot
.57758 .51889 Mdot
.50021 .42109 Mdot
.58521 .48155 Mdot
.52178 .44983 Mdot
.50785 .49061 Mdot
.53185 .55998 Mdot
.52131 .47093 Mdot
.47393 .49464 Mdot
.49887 .53926 Mdot
.4368 .48811 Mdot
.58342 .48146 Mdot
.47653 .51753 Mdot
.49884 .51385 Mdot
.44178 .48169 Mdot
.51514 .53979 Mdot
.50486 .51308 Mdot
.473 .58749 Mdot
.5137 .48477 Mdot
.49858 .4618 Mdot
.48833 .48263 Mdot
.48975 .47799 Mdot
.53551 .52836 Mdot
.48637 .47355 Mdot
.52504 .45539 Mdot
.50145 .47279 Mdot
.479 .57471 Mdot
.50542 .48323 Mdot
.4381 .4878 Mdot
.47049 .48839 Mdot
.52125 .48418 Mdot
.52279 .44675 Mdot
.45685 .49488 Mdot
.4614 .52923 Mdot
.48522 .48687 Mdot
.51196 .503 Mdot
.51564 .46564 Mdot
.48341 .49942 Mdot
.44919 .49616 Mdot
.47038 .4295 Mdot
.56153 .46863 Mdot
.44339 .53228 Mdot
.49539 .52907 Mdot
.49761 .50432 Mdot
.5249 .43365 Mdot
.45303 .5002 Mdot
.4313 .53156 Mdot
.50189 .48049 Mdot
.51978 .48508 Mdot
.47982 .49331 Mdot
.43444 .56417 Mdot
.50782 .48393 Mdot
.4894 .47469 Mdot
.46478 .51263 Mdot
.45256 .57382 Mdot
.51521 .46136 Mdot
.49763 .49339 Mdot
.47612 .59575 Mdot
.49373 .52284 Mdot
.50923 .42095 Mdot
.43687 .53139 Mdot
.43039 .49971 Mdot
.57933 .49196 Mdot
.53473 .47436 Mdot
.47129 .46869 Mdot
.50333 .48097 Mdot
.48009 .52463 Mdot
.56075 .47739 Mdot
.50303 .45232 Mdot
.49763 .44758 Mdot
.47354 .47217 Mdot
.56276 .45557 Mdot
.50783 .55711 Mdot
.49021 .48669 Mdot
.51928 .56139 Mdot
.5109 .46049 Mdot
.5066 .47592 Mdot
.52003 .55328 Mdot
.44455 .49509 Mdot
.49213 .54239 Mdot
.51719 .42113 Mdot
.42016 .50045 Mdot
.45686 .5195 Mdot
.50217 .49082 Mdot
.48763 .54078 Mdot
.49569 .51284 Mdot
.501 .52151 Mdot
.48148 .46639 Mdot
.45128 .47323 Mdot
.48855 .47328 Mdot
.49919 .53422 Mdot
.44443 .52165 Mdot
.4591 .49239 Mdot
.55175 .46167 Mdot
.57503 .51929 Mdot
.46318 .54059 Mdot
.53826 .42417 Mdot
.49382 .54498 Mdot
.49627 .41054 Mdot
.50095 .49192 Mdot
.48469 .50578 Mdot
.51405 .56018 Mdot
.53963 .55702 Mdot
.50682 .50453 Mdot
.52258 .47421 Mdot
.53269 .49148 Mdot
.51995 .44621 Mdot
.47312 .45099 Mdot
.54881 .46583 Mdot
.49316 .47652 Mdot
.48903 .54335 Mdot
.51041 .53412 Mdot
.55657 .48256 Mdot
.51091 .50436 Mdot
.54211 .45132 Mdot
.51328 .54031 Mdot
.50578 .54356 Mdot
.48074 .52645 Mdot
.43915 .50972 Mdot
.44748 .46555 Mdot
.42498 .4849 Mdot
.52505 .56025 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go
00001_ooool3o`000?ooooooB?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04
odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol0003o
oooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`2P
ooooo`;o0000YOooool000?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co
000000Oooooo00?o0000ooooooooool0X?ooool2o`000:Gooooo0003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo09gooooo0_l00000
0ooooooo0000o`000002o`000:?ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool0
0omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo09gooooo1?l000000ooooooo0000o`00002S
ooooo`007_ooool00ol0003oooooooooo`2Iooooo`;o00001?ooool5o`000:?ooooo000Nooooo`03
o`000?oooooooooo09Wooooo0_l00004ooooo`Co000000?oooooo`000?l00000XOooool001kooooo
00?o0000ooooooooool0TOooool2o`0000Kooooo0_l00004ooooo`Oo00001?ooool3o`0009[ooooo
000Nooooo`03o`000?oooooooooo097ooooo0_l00008ooooo`;o00001_ooool2o`000004ooooool0
003o0000ooooo`Co0000V_ooool001kooooo00?o0000ooooooooool0TOooool2o`0000;ooooo0_l0
0004ooooo`;o00001?ooool4o`000004ooooool0003o0000ooooo`Go0000VOooool001kooooo00?o
0000ooooooooool0TOooool2o`0000;ooooo0_l0000:ooooo`Co00000_ooool3o`000004ooooool0
003o0000o`0009Wooooo000Nooooo`03o`000?oooooooooo09cooooo0_l00005ooooo`?o000000?o
ooooo`000?l000000_l00003ooooo`;o00000_ooool4o`00097ooooo000Nooooo`03o`000?oooooo
oooo09Gooooo1?l00003ooooo`?o00001Oooool7o`0000?ooooo0_l00002ooooo`Co0000TOooool0
01kooooo00?o0000ooooooooool0Roooool2o`0000Oooooo1Ol00004ooooo`Co00001?ooool6o`00
00?ooooo0_l00004ooooo`;o000000?oooooo`000?l00000S_ooool001kooooo00?o0000oooooooo
ool0Roooool3o`0000Kooooo1Ol00004ooooo`Co00001?ooool6o`0000Cooooo0_l00003ooooo`;o
000000?oooooo`000?l00000S_ooool001kooooo00?o0000ooooooooool0S?ooool3o`0000;ooooo
0_l00002ooooo`?o00000_ooool2o`0000;ooooo0_l00004ooooo`Oo00000_ooool4o`0000Gooooo
0_l0002?ooooo`007_ooool2o`0008cooooo2?l00002ooooo`co000000?oooooo`000?l000001ol0
00001Ooooooo0000o`000?l0003ooooo00;o00000oooool3o`0008oooooo000Nooooo`03o`000?oo
oooooooo08_ooooo0_l00002ooooo`;o00001?oooolDo`0000?ooooo0_l00002ooooo`So00000_oo
ool2o`0008_ooooo000Nooooo`03o`000?oooooooooo08[ooooo0_l00002ooooo`;o00000oooool2
o`0000Gooooo4Ol00007ooooo`Oo000000?oooooo`000?l00000Roooool001kooooo00?o0000oooo
ooooool0R_ooool6o`0000?ooooo1?l00003ooooo`;o00000_ooool=o`000004ooooool0003o0000
ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`00002>ooooo`007_ooool00ol0
003oooooooooo`2:ooooo`Go00000_ooool2o`0000;ooooo1Ol00004ooooo`_o00000_ooool6o`00
00?ooooo1?l0002?ooooo`007_ooool00ol0003oooooooooo`28ooooo`;o00000oooool2o`0000;o
oooo0ol000000ooooooo0000o`000005o`0000?ooooo2ol000001?oooooo0000o`000?ooool3o`00
0003ooooool0003o000000Co000000?oooooo`000?l00000S?ooool001kooooo00?o0000oooooooo
ool0R?ooool3o`0000Cooooo5?l000000ooooooo0000o`000004o`0000?ooooo2ol000000ooooooo
0000o`00002<ooooo`007_ooool00ol0003oooooooooo`29ooooo`;o00000ooooolNo`000005oooo
ool0003o0000o`000?ooool01Ol00004ooooo`;o0000Roooool001kooooo00?o0000ooooooooool0
ROooool2o`0000?ooooo8_l00002ooooo`;o00001_ooool2o`0008_ooooo000Nooooo`03o`000?oo
oooooooo08[ooooo0_l00002oooooaco00000_ooool2o`0000;ooooo1Ol00007ooooo`;o0000ROoo
ool001kooooo00?o0000ooooooooool0Qoooool2o`000003ooooool0003o000002Wo000000Cooooo
o`000?l0003ooooo1_l00028ooooo`007_ooool00ol0003oooooooooo`26ooooo`?o00000_oooolU
o`000003ooooool0003o000000;o000000Coooooo`000?l0003ooooo1_l00028ooooo`007_ooool0
0ol0003oooooooooo`24ooooo`Co00000_oooolWo`000004ooooool0003o0000o`0000Oooooo0_l0
0029ooooo`007_ooool00ol0003oooooooooo`24ooooo`Co00000_oooolQo`0000?ooooo0ol00002
ooooo`;o00000oooool2o`000003ooooool0003o000008[ooooo000Nooooo`03o`000?oooooooooo
08Kooooo9Ol0000=ooooo`;o000000?oooooo`000?l00000R_ooool001kooooo00?o0000oooooooo
ool0Q_oooolIo`000003ooooool0003o000000Oo00003?ooool2o`0000Kooooo0_l00028ooooo`00
7_ooool2o`0008Gooooo2?l000000ooooooo0000o`00000Ho`0000;ooooo0_l000001?oooooo0000
o`000?ooool2o`0000Cooooo0_l00006ooooo`;o0000R?ooool001kooooo00?o0000ooooooooool0
Q?ooool3o`0000;ooooo7?l00004ooooo`So00001?ooool2o`0000Gooooo0_l00029ooooo`007_oo
ool00ol0003oooooooooo`2;ooooo`Ko00000_oooolBo`0000Kooooo0_l000000ooooooo0000o`00
0003ooooo`Go000000Coooooo`000?l0003ooooo0_l00029ooooo`007_ooool00ol0003ooooooooo
o`2;ooooo`?o000000Coooooo`000?l0003ooooo4_l00007ooooo`;o000000?oooooo`000?l00000
0oooool5o`000003ooooool0003o000008cooooo000Nooooo`03o`000?oooooooooo08;ooooo0_l0
0007ooooo`Co00000oooool3o`000003ooooool0003o000000go00000_ooool2o`0000;ooooo1Ol0
0005ooooo`Ko0000S?ooool001kooooo00?o0000ooooooooool0P_ooool2o`0000Gooooo0_l00002
ooooo`;o00001?ooool2o`0000;ooooo3_l00002ooooo`Co000000?oooooo`000?l000001?ooool2
o`000003ooooool0003o000000Ko0000R_ooool001kooooo00?o0000ooooooooool0POooool2o`00
00?ooooo0_l000001?oooooo0000o`000?ooool3o`000004ooooool0003o0000ooooo`ko000000Co
ooooo`000?l0003ooooo0_l00002ooooo`;o00001Oooool4o`000003ooooool0003o000000?o0000
00?oooooo`000?l00000R_ooool001kooooo00?o0000ooooooooool0POooool2o`0000;ooooo0ol0
0002ooooo`Co00000_ooool2o`000003ooooool0003o000001;o00002Oooool:o`0008gooooo000N
ooooo`03o`000?oooooooooo08Gooooo0_l000000ooooooo0000o`000004o`000003ooooool0003o
000000;ooooo0_l00003ooooo`ko00003_ooool4o`0008oooooo000Nooooo`03o`000?oooooooooo
08Oooooo1Ol00003ooooo`;o000000Goooooo`000?l0003o0000ooooo`06o`000003ooooool0003o
000000Oo00001?ooool4o`0000?ooooo0_l00003ooooo`;o0000Soooool001kooooo00?o0000oooo
ooooool0Qoooool7o`0000?ooooo4ol00004ooooo`Ko00000oooool2o`000003ooooool0003o0000
097ooooo000Nooooo`03o`000?oooooooooo08Sooooo1_l00003oooooa?o00001?ooool2o`0000Go
oooo0_l00003ooooo`;o0000TOooool001kooooo00?o0000ooooooooool0Qoooool2o`0000;ooooo
0_l000001?oooooo0000o`000?ooool4o`0000Gooooo3_l000001?oooooo0000o`000?ooool2o`00
0004ooooool0003o0000o`0000;ooooo0_l0002Aooooo`007_ooool00ol0003oooooooooo`25oooo
o`So000000Goooooo`000?l0003o0000ooooo`02o`0000Kooooo4Ol000000ooooooo0000o`000004
o`000004ooooool0003o0000o`00097ooooo000Nooooo`03o`000?oooooooooo08Gooooo0_l00002
ooooo`;o00000oooool3o`000003ooooool0003o000000Kooooo2?l000000ooooooo0000o`000006
o`000003ooooool0003o000000Co000000?oooooo`000?l00000T_ooool001kooooo00?o0000oooo
ooooool0Q?ooool2o`0000Sooooo1?l000001?oooooo0000o`000?ooool2o`0000;ooooo4?l00000
0ooooooo0000o`000003ooooo`?o0000U?ooool001kooooo0_l00025ooooo`?o00001oooool4o`00
0004ooooool0003o0000ooooo`;o00001?ooool>o`000003ooooool0003o000000Cooooo0_l0002D
ooooo`007_ooool00ol0003oooooooooo`25ooooo`?o00000oooool2o`000003ooooool0003o0000
00;o00000oooool2o`0000Kooooo3Ol0002Mooooo`007_ooool00ol0003oooooooooo`26ooooo`;o
00000oooool5o`000004ooooool0003o0000ooooo`?o00001ooooolAo`0009Sooooo000Nooooo`03
o`000?oooooooooo08gooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00002_ooool?o`00
09Sooooo000Nooooo`03o`000?oooooooooo08Wooooo0_l00002ooooo`;o000000?oooooo`000?l0
00003?ooool2o`0000;ooooo2Ol0002Looooo`007_ooool00ol0003oooooooooo`29ooooo`;o0000
0_ooool2o`0000Cooooo1?l00007ooooo`;o00001Oooool2o`000:3ooooo000Nooooo`03o`000?oo
oooooooo08gooooo0_l000001?oooooo0000o`000?ooool5o`000:oooooo000Nooooo`03o`000?oo
oooooooo093ooooo0ol00003ooooo`;o0000[oooool001kooooo00?o0000ooooooooool0SOooool6
o`000003ooooool0003o000000;ooooo0_l0002]ooooo`007_ooool00ol0003oooooooooo`2=oooo
o`Co00000oooool2o`0000;ooooo0_l0002]ooooo`007_ooool00ol0003oooooooooo`2@ooooo`;o
000000?oooooo`000?l000000_l0002`ooooo`007_ooool00ol0003oooooooooo`2@ooooo`;o0000
00?oooooo`000?l000000_l00004ooooo`;o0000Z_ooool001kooooo00?o0000ooooooooool0Tooo
ool5o`0000?ooooo0_l0002Zooooo`007_ooool00ol0003oooooooooo`2Cooooo`Go0000[oooool0
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0Toooool6o`000:kooooo0003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`00
0?oooooooooo09Cooooo1Ol0002^ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo
00Go0000ooooooooooooooooo`000006ooooo`?o0000U_ooool3o`000:kooooo0003ooooo`05o`00
0?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o0000oooo
ooooool0oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEE
EOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooo
oooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0oooooom8
ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool0
0ol0003oooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool0
1?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000
ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`3oooooodSooooo0003
ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo
0ol0003oooooodSooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RH
oooooonHV9So<S8b00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol0003ooooo
oooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo
0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooo
okZj^_l@41001_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0oooo
oom8ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@06ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`00
0?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001Cooooo1?l000000ol@413oooooooooo`03oooo
o`03o`000?oooooooooo0?ooooooB?ooool001Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`3oooooodSooooo000Fooooo`03o`000?oooooooooo00Gooooo0ol0003oooooodSooooo
000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@
ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?oo
ooooD?ooool001Cooooo00?oEEEEofIVI_l00000oooooomBooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.54092 .51258 Mdot
.52636 .48022 Mdot
.49913 .45684 Mdot
.52529 .48751 Mdot
.52213 .50949 Mdot
.53229 .54341 Mdot
.48271 .44447 Mdot
.52757 .51055 Mdot
.44192 .53608 Mdot
.47337 .53972 Mdot
.50947 .53718 Mdot
.4886 .48719 Mdot
.54228 .53745 Mdot
.54295 .46468 Mdot
.43638 .48497 Mdot
.46877 .53086 Mdot
.53896 .49034 Mdot
.47033 .55474 Mdot
.47251 .5451 Mdot
.47352 .46862 Mdot
.53845 .49491 Mdot
.46019 .51175 Mdot
.50505 .52733 Mdot
.55656 .49953 Mdot
.53275 .50724 Mdot
.48537 .49724 Mdot
.44543 .48697 Mdot
.47352 .55093 Mdot
.51733 .50517 Mdot
.54751 .52525 Mdot
.52221 .46368 Mdot
.53478 .48982 Mdot
.495 .51453 Mdot
.48103 .45732 Mdot
.54558 .53176 Mdot
.49902 .45748 Mdot
.48285 .5028 Mdot
.44768 .504 Mdot
.51245 .52172 Mdot
.48109 .48515 Mdot
.4796 .5242 Mdot
.46672 .47811 Mdot
.51642 .46634 Mdot
.49853 .50114 Mdot
.53625 .49411 Mdot
.46749 .51681 Mdot
.54081 .45731 Mdot
.52551 .46358 Mdot
.50958 .461 Mdot
.45365 .56824 Mdot
.51602 .51714 Mdot
.55307 .53801 Mdot
.5165 .50096 Mdot
.52005 .5155 Mdot
.46464 .53342 Mdot
.46919 .49651 Mdot
.49669 .46901 Mdot
.56739 .5299 Mdot
.53266 .49738 Mdot
.49748 .46667 Mdot
.45844 .51165 Mdot
.47442 .51156 Mdot
.4778 .46041 Mdot
.47094 .53049 Mdot
.5097 .52115 Mdot
.44076 .54808 Mdot
.54024 .47396 Mdot
.46409 .50843 Mdot
.47064 .48048 Mdot
.46543 .53082 Mdot
.46351 .45915 Mdot
.52855 .49932 Mdot
.48874 .46805 Mdot
.50906 .48967 Mdot
.55438 .51398 Mdot
.45597 .46667 Mdot
.46516 .48998 Mdot
.47518 .5595 Mdot
.4715 .45526 Mdot
.49554 .54794 Mdot
.45294 .49034 Mdot
.52771 .51131 Mdot
.53594 .50238 Mdot
.47641 .52062 Mdot
.47876 .4593 Mdot
.51221 .49367 Mdot
.47192 .45758 Mdot
.46856 .50778 Mdot
.48197 .48128 Mdot
.4984 .56688 Mdot
.51191 .51154 Mdot
.46548 .52243 Mdot
.45827 .47127 Mdot
.44515 .56088 Mdot
.49031 .45238 Mdot
.45919 .50015 Mdot
.46752 .50377 Mdot
.52904 .46584 Mdot
.53975 .45581 Mdot
.50353 .46939 Mdot
.46768 .45907 Mdot
.46273 .46681 Mdot
.52963 .50427 Mdot
.46181 .55865 Mdot
.43882 .52456 Mdot
.49353 .51227 Mdot
.53412 .43125 Mdot
.51211 .51697 Mdot
.53473 .47193 Mdot
.46456 .52312 Mdot
.55157 .49979 Mdot
.52878 .49802 Mdot
.50469 .47896 Mdot
.44759 .53192 Mdot
.54368 .48049 Mdot
.54099 .54611 Mdot
.44422 .49959 Mdot
.46711 .54747 Mdot
.51183 .45773 Mdot
.45575 .47528 Mdot
.4978 .55914 Mdot
.48955 .49741 Mdot
.47093 .5386 Mdot
.51604 .46328 Mdot
.53591 .48393 Mdot
.45251 .53476 Mdot
.55377 .50333 Mdot
.48821 .49804 Mdot
.49511 .50122 Mdot
.47858 .52903 Mdot
.49768 .55266 Mdot
.54086 .48849 Mdot
.57024 .50029 Mdot
.49315 .45781 Mdot
.51216 .52095 Mdot
.56754 .48958 Mdot
.46837 .53108 Mdot
.5052 .50543 Mdot
.47914 .47333 Mdot
.50007 .48676 Mdot
.51238 .51472 Mdot
.44047 .51958 Mdot
.49446 .50589 Mdot
.52372 .49271 Mdot
.49678 .5223 Mdot
.46188 .52206 Mdot
.54265 .51674 Mdot
.46107 .49458 Mdot
.54382 .48033 Mdot
.51284 .46233 Mdot
.48404 .459 Mdot
.47258 .55164 Mdot
.51707 .51115 Mdot
.5434 .47135 Mdot
.50163 .54837 Mdot
.46802 .53094 Mdot
.47771 .51284 Mdot
.564 .51351 Mdot
.46557 .48918 Mdot
.50183 .52193 Mdot
.45224 .46716 Mdot
.46617 .48272 Mdot
.49444 .5614 Mdot
.45886 .52986 Mdot
.48784 .47539 Mdot
.49787 .47532 Mdot
.43785 .51603 Mdot
.45472 .49999 Mdot
.46112 .49581 Mdot
.44849 .51826 Mdot
.49031 .54898 Mdot
.51305 .46263 Mdot
.52505 .47639 Mdot
.48588 .47526 Mdot
.45223 .46406 Mdot
.47415 .50249 Mdot
.45945 .50283 Mdot
.50325 .52325 Mdot
.54936 .46352 Mdot
.49713 .45931 Mdot
.52296 .48893 Mdot
.45794 .50459 Mdot
.5058 .49586 Mdot
.51766 .50112 Mdot
.54063 .54168 Mdot
.4919 .48608 Mdot
.48592 .45641 Mdot
.4577 .50911 Mdot
.44604 .55833 Mdot
.4569 .4705 Mdot
.49813 .49315 Mdot
.49453 .53061 Mdot
.55531 .49419 Mdot
.51531 .51331 Mdot
.44825 .51185 Mdot
.48748 .52294 Mdot
.45081 .56908 Mdot
.49615 .50874 Mdot
.50433 .5261 Mdot
.52197 .48339 Mdot
.50927 .47059 Mdot
.46167 .50597 Mdot
.49671 .55746 Mdot
.45921 .49399 Mdot
.47132 .5345 Mdot
.52299 .47449 Mdot
.53986 .49547 Mdot
.50453 .46764 Mdot
.48898 .45632 Mdot
.51659 .51372 Mdot
.53672 .494 Mdot
.4875 .50333 Mdot
.47578 .48209 Mdot
.50963 .55535 Mdot
.48943 .49704 Mdot
.54137 .45859 Mdot
.46435 .51975 Mdot
.4672 .48782 Mdot
.44084 .52045 Mdot
.50873 .51823 Mdot
.49627 .53436 Mdot
.5692 .5211 Mdot
.46277 .52168 Mdot
.55478 .4765 Mdot
.5113 .52611 Mdot
.52251 .51518 Mdot
.53197 .49071 Mdot
.46656 .53902 Mdot
.49091 .45598 Mdot
.4957 .54278 Mdot
.46028 .52056 Mdot
.48944 .50315 Mdot
.44543 .52394 Mdot
.48272 .50966 Mdot
.47793 .49766 Mdot
.48001 .47203 Mdot
.44893 .53072 Mdot
.46049 .46184 Mdot
.53569 .47906 Mdot
.49177 .48605 Mdot
.4675 .53957 Mdot
.4396 .48213 Mdot
.5477 .51096 Mdot
.45035 .53194 Mdot
.49908 .45103 Mdot
.46257 .53217 Mdot
.45352 .46879 Mdot
.52391 .5141 Mdot
.45917 .5294 Mdot
.44265 .50028 Mdot
.51406 .46634 Mdot
.53743 .54578 Mdot
.44045 .48804 Mdot
.49464 .45094 Mdot
.50533 .48208 Mdot
.49085 .48021 Mdot
.4964 .53598 Mdot
.47114 .48752 Mdot
.47829 .45882 Mdot
.43946 .50094 Mdot
.45567 .49655 Mdot
.49093 .52608 Mdot
.5013 .52193 Mdot
.50354 .55452 Mdot
.47702 .46395 Mdot
.47456 .46268 Mdot
.49573 .53979 Mdot
.48735 .55384 Mdot
.49043 .52027 Mdot
.55329 .4652 Mdot
.53451 .47113 Mdot
.50428 .47884 Mdot
.44496 .55689 Mdot
.50111 .48291 Mdot
.49257 .45644 Mdot
.45778 .4637 Mdot
.46555 .49526 Mdot
.47607 .54324 Mdot
.47363 .47054 Mdot
.48867 .53788 Mdot
.47518 .47652 Mdot
.47865 .49383 Mdot
.53429 .46092 Mdot
.49894 .51495 Mdot
.44495 .50989 Mdot
.4465 .5637 Mdot
.54388 .46078 Mdot
.49746 .53429 Mdot
.53247 .47816 Mdot
.54352 .47432 Mdot
.48853 .47804 Mdot
.54419 .47574 Mdot
.53278 .55253 Mdot
.51267 .46426 Mdot
.49822 .47519 Mdot
.52322 .51272 Mdot
.48181 .55103 Mdot
.49215 .45939 Mdot
.46533 .47902 Mdot
.52633 .48869 Mdot
.49932 .50636 Mdot
.5219 .51576 Mdot
.43755 .52984 Mdot
.45843 .52659 Mdot
.48791 .48251 Mdot
.52556 .48902 Mdot
.57006 .47214 Mdot
.54935 .48785 Mdot
.53361 .5071 Mdot
.4796 .46259 Mdot
.51718 .48624 Mdot
.49746 .51531 Mdot
.49452 .54164 Mdot
.53342 .51292 Mdot
.51882 .48003 Mdot
.54319 .48495 Mdot
.4802 .48591 Mdot
.46585 .50823 Mdot
.48569 .47017 Mdot
.44895 .50848 Mdot
.5017 .46011 Mdot
.51504 .53439 Mdot
.51719 .53641 Mdot
.47184 .50048 Mdot
.48467 .54707 Mdot
.4514 .52234 Mdot
.49801 .49632 Mdot
.49443 .49998 Mdot
.44777 .54209 Mdot
.46053 .47485 Mdot
.54505 .51746 Mdot
.5493 .53781 Mdot
.50392 .47798 Mdot
.4747 .54036 Mdot
.49118 .45639 Mdot
.49437 .53725 Mdot
.48579 .45892 Mdot
.52751 .49363 Mdot
.52142 .52522 Mdot
.47308 .51008 Mdot
.53992 .47297 Mdot
.54431 .48732 Mdot
.51892 .43733 Mdot
.49475 .50832 Mdot
.4569 .51255 Mdot
.54303 .47955 Mdot
.49974 .51387 Mdot
.52683 .50972 Mdot
.45484 .49743 Mdot
.47603 .52086 Mdot
.49255 .47269 Mdot
.5702 .50582 Mdot
.53795 .49304 Mdot
.48123 .50671 Mdot
.51583 .55818 Mdot
.49482 .47486 Mdot
.54563 .47039 Mdot
.54095 .48251 Mdot
.5185 .56099 Mdot
.49396 .51406 Mdot
.50746 .52392 Mdot
.54334 .48434 Mdot
.49949 .47711 Mdot
.54573 .47458 Mdot
.54139 .48104 Mdot
.53025 .4592 Mdot
.51137 .45166 Mdot
.45453 .50332 Mdot
.5523 .45826 Mdot
.51134 .49522 Mdot
.50249 .52192 Mdot
.50701 .50808 Mdot
.56909 .51381 Mdot
.50373 .53433 Mdot
.5059 .45731 Mdot
.47254 .53685 Mdot
.49872 .53879 Mdot
.46598 .45909 Mdot
.46898 .47526 Mdot
.48547 .50109 Mdot
.48573 .45995 Mdot
.48306 .45168 Mdot
.52474 .49831 Mdot
.56083 .49046 Mdot
.53263 .49281 Mdot
.52768 .54271 Mdot
.47296 .5512 Mdot
.49507 .5386 Mdot
.47177 .49503 Mdot
.48735 .46009 Mdot
.57026 .484 Mdot
.47059 .47483 Mdot
.498 .45984 Mdot
.535 .49064 Mdot
.50235 .52957 Mdot
.53067 .50643 Mdot
.45686 .52305 Mdot
.49578 .5163 Mdot
.48286 .54762 Mdot
.56776 .47932 Mdot
.56544 .47089 Mdot
.49001 .45844 Mdot
.5768 .48955 Mdot
.47935 .49307 Mdot
.49531 .46032 Mdot
.50131 .45813 Mdot
.51926 .49941 Mdot
.50599 .51995 Mdot
.5124 .46912 Mdot
.49415 .54888 Mdot
.49761 .48773 Mdot
.48395 .54221 Mdot
.50898 .49164 Mdot
.52343 .46309 Mdot
.50921 .49682 Mdot
.46241 .46592 Mdot
.46346 .52516 Mdot
.55423 .48854 Mdot
.50544 .46407 Mdot
.46747 .5381 Mdot
.49195 .54114 Mdot
.46593 .51513 Mdot
.50519 .49523 Mdot
.47855 .54038 Mdot
.57713 .51338 Mdot
.49114 .45725 Mdot
.43423 .50049 Mdot
.48674 .52043 Mdot
.47616 .47277 Mdot
.47556 .48378 Mdot
.5443 .48027 Mdot
.46526 .53061 Mdot
.54083 .49438 Mdot
.49305 .54297 Mdot
.45889 .49922 Mdot
.55677 .49372 Mdot
.46029 .4986 Mdot
.49591 .46884 Mdot
.54604 .48165 Mdot
.48699 .47476 Mdot
.51551 .46415 Mdot
.50346 .56514 Mdot
.54361 .47431 Mdot
.5043 .55256 Mdot
.49346 .51282 Mdot
.49421 .55341 Mdot
.52512 .50367 Mdot
.47257 .53346 Mdot
.48435 .45659 Mdot
.51391 .50957 Mdot
.52763 .45514 Mdot
.49455 .4855 Mdot
.47686 .52336 Mdot
.48396 .47656 Mdot
.46788 .46345 Mdot
.44464 .53576 Mdot
.48434 .45919 Mdot
.44914 .50292 Mdot
.50499 .51642 Mdot
.47322 .4857 Mdot
.46159 .48728 Mdot
.51026 .4857 Mdot
.52387 .46232 Mdot
.48474 .50967 Mdot
.50223 .46117 Mdot
.55742 .473 Mdot
.48499 .51554 Mdot
.50331 .49347 Mdot
.54332 .47344 Mdot
.47093 .48577 Mdot
.52602 .52804 Mdot
.49133 .53532 Mdot
.49526 .431 Mdot
.43153 .48039 Mdot
.48362 .54553 Mdot
.4428 .53384 Mdot
.51203 .46155 Mdot
.42961 .48118 Mdot
.4673 .45901 Mdot
.56754 .49388 Mdot
.49654 .51425 Mdot
.53773 .49337 Mdot
.52594 .51283 Mdot
.53269 .50077 Mdot
.46416 .5146 Mdot
.46144 .48883 Mdot
.47755 .5395 Mdot
.54246 .51225 Mdot
.50852 .46151 Mdot
.46514 .45943 Mdot
.53316 .55609 Mdot
.48937 .45621 Mdot
.44531 .54763 Mdot
.50468 .52485 Mdot
.50955 .46651 Mdot
.52005 .55659 Mdot
.44259 .51562 Mdot
.50193 .52577 Mdot
.46323 .4852 Mdot
.52707 .51274 Mdot
.53315 .43653 Mdot
.43837 .49184 Mdot
.49644 .43771 Mdot
.49482 .53529 Mdot
.49242 .48497 Mdot
.46316 .53941 Mdot
.54331 .50035 Mdot
.48278 .53343 Mdot
.47397 .45785 Mdot
.44968 .56611 Mdot
.47073 .47487 Mdot
.48094 .45898 Mdot
.51665 .46747 Mdot
.52564 .55044 Mdot
.52366 .51497 Mdot
.46611 .52958 Mdot
.51466 .46704 Mdot
.54378 .53344 Mdot
.53015 .45628 Mdot
.53058 .5171 Mdot
.45956 .53039 Mdot
.53801 .47309 Mdot
.53101 .51161 Mdot
.48327 .49813 Mdot
.49413 .47771 Mdot
.46774 .50224 Mdot
.49705 .45866 Mdot
.54924 .5421 Mdot
.49436 .55166 Mdot
.48574 .54406 Mdot
.46689 .47008 Mdot
.46157 .52201 Mdot
.46635 .49431 Mdot
.5095 .48501 Mdot
.44668 .55697 Mdot
.49107 .49054 Mdot
.56187 .49963 Mdot
.46342 .51037 Mdot
.50091 .46759 Mdot
.46771 .5438 Mdot
.5042 .48146 Mdot
.48985 .56335 Mdot
.46089 .52432 Mdot
.55966 .49561 Mdot
.49737 .55033 Mdot
.44655 .47972 Mdot
.523 .49712 Mdot
.48383 .56386 Mdot
.52905 .50142 Mdot
.49406 .54534 Mdot
.48258 .48175 Mdot
.51579 .51948 Mdot
.49583 .51916 Mdot
.5372 .44053 Mdot
.53016 .49475 Mdot
.49612 .53292 Mdot
.50868 .51371 Mdot
.49501 .46211 Mdot
.5291 .55728 Mdot
.44896 .48584 Mdot
.46115 .47064 Mdot
.47728 .45761 Mdot
.47307 .53487 Mdot
.51319 .49892 Mdot
.47028 .4705 Mdot
.4961 .53643 Mdot
.47983 .44109 Mdot
.49099 .53841 Mdot
.561 .49364 Mdot
.51234 .4619 Mdot
.55354 .46566 Mdot
.48827 .50057 Mdot
.50076 .46246 Mdot
.52833 .50604 Mdot
.49394 .4868 Mdot
.47248 .52726 Mdot
.48903 .56543 Mdot
.48204 .48272 Mdot
.46158 .46122 Mdot
.48661 .49193 Mdot
.48876 .45576 Mdot
.52777 .49988 Mdot
.51897 .43362 Mdot
.51466 .47049 Mdot
.46631 .48417 Mdot
.54096 .45597 Mdot
.51619 .51838 Mdot
.53935 .47593 Mdot
.5422 .48856 Mdot
.47411 .46212 Mdot
.49101 .48455 Mdot
.47081 .51892 Mdot
.5022 .5278 Mdot
.4954 .49443 Mdot
.47517 .53256 Mdot
.54574 .51579 Mdot
.55753 .49032 Mdot
.45878 .50491 Mdot
.49403 .56114 Mdot
.52379 .47806 Mdot
.45673 .50009 Mdot
.45784 .5183 Mdot
.53403 .5187 Mdot
.51015 .55841 Mdot
.4705 .51995 Mdot
.52926 .46959 Mdot
.48888 .53102 Mdot
.51616 .45483 Mdot
.47509 .51091 Mdot
.49412 .4983 Mdot
.46655 .54762 Mdot
.54779 .502 Mdot
.4989 .53343 Mdot
.54073 .45615 Mdot
.54391 .51106 Mdot
.51973 .50768 Mdot
.5082 .52485 Mdot
.46341 .53422 Mdot
.50989 .52063 Mdot
.44819 .46844 Mdot
.48041 .44607 Mdot
.55579 .53732 Mdot
.50906 .48066 Mdot
.4777 .51235 Mdot
.50674 .4502 Mdot
.48445 .4606 Mdot
.51549 .51081 Mdot
.50644 .51249 Mdot
.56702 .48776 Mdot
.53112 .47806 Mdot
.46056 .5114 Mdot
.46911 .53255 Mdot
.51316 .46233 Mdot
.4842 .5634 Mdot
.48896 .56422 Mdot
.51813 .52757 Mdot
.45821 .46524 Mdot
.50157 .4918 Mdot
.53131 .50075 Mdot
.54401 .46105 Mdot
.52419 .51299 Mdot
.46514 .49189 Mdot
.51637 .45234 Mdot
.48789 .51887 Mdot
.48034 .52982 Mdot
.50838 .5578 Mdot
.51399 .55795 Mdot
.48958 .51205 Mdot
.48752 .44701 Mdot
.47527 .451 Mdot
.52945 .5139 Mdot
.49676 .51979 Mdot
.49135 .50699 Mdot
.53428 .47183 Mdot
.50499 .47428 Mdot
.51318 .46565 Mdot
.43598 .54161 Mdot
.49999 .49283 Mdot
.46937 .46888 Mdot
.49433 .49406 Mdot
.52955 .50136 Mdot
.49534 .52013 Mdot
.5464 .47456 Mdot
.57244 .52613 Mdot
.53343 .4417 Mdot
.48332 .459 Mdot
.45286 .51198 Mdot
.574 .47868 Mdot
.54933 .50418 Mdot
.42655 .51265 Mdot
.52961 .47929 Mdot
.57432 .51508 Mdot
.56688 .47108 Mdot
.45904 .51399 Mdot
.48572 .52919 Mdot
.46074 .53273 Mdot
.48377 .46752 Mdot
.53571 .49464 Mdot
.47613 .55278 Mdot
.52311 .51321 Mdot
.4572 .51075 Mdot
.46033 .47204 Mdot
.53043 .47359 Mdot
.45539 .4793 Mdot
.53761 .49066 Mdot
.46088 .50407 Mdot
.53398 .48192 Mdot
.53683 .5453 Mdot
.48173 .47598 Mdot
.47806 .46739 Mdot
.46181 .49285 Mdot
.49953 .45782 Mdot
.55855 .53342 Mdot
.47501 .49715 Mdot
.49254 .46047 Mdot
.53973 .50028 Mdot
.53441 .43464 Mdot
.49819 .50554 Mdot
.46546 .52432 Mdot
.52706 .49043 Mdot
.50855 .52334 Mdot
.49015 .49088 Mdot
.53553 .46311 Mdot
.51025 .52065 Mdot
.51107 .45547 Mdot
.46885 .45262 Mdot
.4694 .50368 Mdot
.51732 .5149 Mdot
.47449 .4604 Mdot
.47879 .5405 Mdot
.44929 .54911 Mdot
.4946 .49687 Mdot
.47262 .45896 Mdot
.46265 .5369 Mdot
.5442 .47595 Mdot
.44601 .48562 Mdot
.46385 .53453 Mdot
.54104 .49499 Mdot
.53226 .54049 Mdot
.47981 .55306 Mdot
.51446 .49238 Mdot
.49302 .54748 Mdot
.47907 .4705 Mdot
.51222 .48678 Mdot
.54599 .50041 Mdot
.49557 .47208 Mdot
.48263 .56251 Mdot
.50978 .55611 Mdot
.56186 .49935 Mdot
.46122 .49616 Mdot
.503 .54749 Mdot
.47476 .52312 Mdot
.49298 .47428 Mdot
.48118 .51509 Mdot
.54286 .54689 Mdot
.47717 .44864 Mdot
.47726 .50003 Mdot
.45995 .5076 Mdot
.47826 .54352 Mdot
.46869 .48835 Mdot
.4668 .51832 Mdot
.54822 .53428 Mdot
.47627 .49529 Mdot
.5258 .51525 Mdot
.49671 .52919 Mdot
.52007 .51426 Mdot
.50545 .52399 Mdot
.47007 .50791 Mdot
.49505 .50226 Mdot
.5304 .52847 Mdot
.50098 .45867 Mdot
.50251 .51778 Mdot
.49219 .47006 Mdot
.52075 .51254 Mdot
.46188 .51853 Mdot
.55525 .48147 Mdot
.44026 .51845 Mdot
.4718 .53753 Mdot
.5228 .46407 Mdot
.49383 .54245 Mdot
.53923 .53347 Mdot
.52864 .54277 Mdot
.42498 .48613 Mdot
.46643 .48001 Mdot
.48474 .56351 Mdot
.50718 .48497 Mdot
.56252 .49155 Mdot
.52217 .49741 Mdot
.49747 .499 Mdot
.5021 .4585 Mdot
.51359 .54842 Mdot
.5266 .46491 Mdot
.54848 .52719 Mdot
.51091 .49739 Mdot
.49587 .45699 Mdot
.45059 .48295 Mdot
.42951 .5031 Mdot
.53273 .50945 Mdot
.50458 .49028 Mdot
.47221 .48328 Mdot
.49286 .53114 Mdot
.54232 .4781 Mdot
.54271 .53263 Mdot
.52005 .56215 Mdot
.5759 .51199 Mdot
.45813 .46335 Mdot
.51152 .47401 Mdot
.48022 .52626 Mdot
.48347 .54871 Mdot
.46212 .48777 Mdot
.51979 .48113 Mdot
.49498 .55717 Mdot
.51838 .48933 Mdot
.44868 .50105 Mdot
.53233 .47175 Mdot
.45442 .51706 Mdot
.52977 .46922 Mdot
.53828 .43828 Mdot
.47427 .53373 Mdot
.52493 .4462 Mdot
.48949 .52525 Mdot
.50149 .46818 Mdot
.47254 .45834 Mdot
.42272 .50972 Mdot
.5403 .51154 Mdot
.47462 .5311 Mdot
.4891 .4754 Mdot
.52753 .5123 Mdot
.53658 .49584 Mdot
.47757 .5576 Mdot
.52257 .49644 Mdot
.44669 .48004 Mdot
.51947 .49237 Mdot
.52471 .53445 Mdot
.4732 .53471 Mdot
.51446 .46574 Mdot
.45874 .50243 Mdot
.49783 .46999 Mdot
.53819 .50456 Mdot
.51705 .46362 Mdot
.48663 .51452 Mdot
.50729 .48153 Mdot
.45707 .46401 Mdot
.47661 .54349 Mdot
.53864 .50548 Mdot
.46384 .54166 Mdot
.50809 .523 Mdot
.53333 .47699 Mdot
.53203 .47214 Mdot
.47549 .4951 Mdot
.53691 .44397 Mdot
.53934 .47263 Mdot
.51386 .45685 Mdot
.46693 .5126 Mdot
.49082 .50379 Mdot
.48604 .52915 Mdot
.46805 .47488 Mdot
.49569 .54846 Mdot
.51141 .48114 Mdot
.44629 .50902 Mdot
.54279 .51003 Mdot
.46652 .51913 Mdot
.45826 .50291 Mdot
.45418 .46405 Mdot
.47229 .45411 Mdot
.4664 .46653 Mdot
.42634 .51514 Mdot
.46914 .47204 Mdot
.46393 .51772 Mdot
.48713 .46867 Mdot
.53573 .48156 Mdot
.5035 .56115 Mdot
.54146 .4592 Mdot
.56797 .47187 Mdot
.45214 .46258 Mdot
.49477 .48543 Mdot
.4929 .51817 Mdot
.5202 .55336 Mdot
.50438 .49383 Mdot
.51381 .51533 Mdot
.47148 .46091 Mdot
.49459 .48494 Mdot
.4975 .51647 Mdot
.45425 .48073 Mdot
.48614 .55109 Mdot
.4794 .45671 Mdot
.5193 .47456 Mdot
.47453 .55517 Mdot
.5233 .48002 Mdot
.55977 .53955 Mdot
.4937 .5552 Mdot
.44636 .51053 Mdot
.5201 .46099 Mdot
.54584 .51642 Mdot
.54181 .49841 Mdot
.51086 .49594 Mdot
.51741 .51819 Mdot
.46744 .52222 Mdot
.48309 .48133 Mdot
.54883 .54219 Mdot
.53271 .44317 Mdot
.56924 .51272 Mdot
.54393 .47827 Mdot
.51392 .50393 Mdot
.48939 .56397 Mdot
.53357 .4979 Mdot
.47985 .47877 Mdot
.47176 .52843 Mdot
.4661 .45956 Mdot
.56745 .51257 Mdot
.46279 .48978 Mdot
.49347 .50829 Mdot
.47541 .45773 Mdot
.49401 .5444 Mdot
.50063 .52597 Mdot
.44945 .55889 Mdot
.52172 .50505 Mdot
.52845 .47058 Mdot
.50126 .4803 Mdot
.50606 .47655 Mdot
.50906 .54706 Mdot
.50894 .47053 Mdot
.54148 .48922 Mdot
.5206 .47958 Mdot
.45469 .54341 Mdot
.51526 .49327 Mdot
.46674 .45918 Mdot
.48186 .47174 Mdot
.52293 .51312 Mdot
.54387 .47893 Mdot
.46951 .46629 Mdot
.45784 .49419 Mdot
.49622 .48184 Mdot
.50719 .52565 Mdot
.53374 .48438 Mdot
.48638 .4894 Mdot
.46564 .46492 Mdot
.50854 .4407 Mdot
.55188 .50192 Mdot
.44696 .49428 Mdot
.47358 .51811 Mdot
.49742 .50319 Mdot
.54478 .46905 Mdot
.46513 .46879 Mdot
.43907 .49324 Mdot
.51392 .48735 Mdot
.52251 .51307 Mdot
.48696 .48315 Mdot
.43117 .52765 Mdot
.51729 .49716 Mdot
.50958 .47328 Mdot
.46477 .48162 Mdot
.44019 .53854 Mdot
.5367 .4809 Mdot
.50283 .49539 Mdot
.45155 .5697 Mdot
.47628 .51177 Mdot
.53836 .44747 Mdot
.44338 .4931 Mdot
.45381 .46696 Mdot
.55951 .52158 Mdot
.53227 .50789 Mdot
.50631 .46068 Mdot
.51485 .48906 Mdot
.46077 .50206 Mdot
.54657 .50908 Mdot
.5357 .46962 Mdot
.53261 .46515 Mdot
.50281 .46335 Mdot
.55996 .49112 Mdot
.47107 .55021 Mdot
.50045 .48484 Mdot
.47689 .56028 Mdot
.53494 .47671 Mdot
.52125 .48747 Mdot
.486 .55327 Mdot
.46386 .46371 Mdot
.46411 .52717 Mdot
.54129 .45233 Mdot
.44592 .4693 Mdot
.4588 .48504 Mdot
.50804 .49705 Mdot
.46033 .50984 Mdot
.4889 .50477 Mdot
.48752 .51427 Mdot
.5158 .46452 Mdot
.49009 .45586 Mdot
.5109 .4715 Mdot
.47423 .52428 Mdot
.4512 .4847 Mdot
.47209 .46608 Mdot
.54862 .49636 Mdot
.54629 .54252 Mdot
.45416 .50509 Mdot
.55344 .45893 Mdot
.46432 .52991 Mdot
.52813 .43003 Mdot
.50636 .49693 Mdot
.48132 .49379 Mdot
.47216 .55652 Mdot
.49908 .56555 Mdot
.50707 .51851 Mdot
.53099 .50346 Mdot
.51814 .51894 Mdot
.54425 .47378 Mdot
.51326 .45824 Mdot
.54443 .4999 Mdot
.5101 .47733 Mdot
.45948 .52662 Mdot
.49472 .5398 Mdot
.54073 .51287 Mdot
.5068 .52585 Mdot
.54784 .48881 Mdot
.48733 .5371 Mdot
.47638 .53541 Mdot
.46038 .50472 Mdot
.45333 .47456 Mdot
.48843 .45486 Mdot
.45874 .46072 Mdot
.48417 .5638 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go
00001_ooool3o`000?ooooooB?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04
odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol0003o
oooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`3o
ooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007
ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<
ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0WOooool2o`0000Wooooo1?l0002K
ooooo`007_ooool00ol0003oooooooooo`2Mooooo`;o00001_ooool2o`000003ooooool0003o0000
00;o0000Voooool001kooooo00?o0000ooooooooool0WOooool2o`0000Kooooo0_l00002ooooo`?o
0000Voooool001kooooo00?o0000ooooooooool0V?ooool2o`0000?ooooo0_l00002ooooo`;o0000
0_ooool2o`0000;ooooo1?l0002Jooooo`007_ooool00ol0003oooooooooo`2Hooooo`;o00001ooo
ool2o`0000Kooooo1?l0002Jooooo`007_ooool00ol0003oooooooooo`2Hooooo`Co00002oooool5
o`0009_ooooo000Nooooo`03o`000?oooooooooo09Oooooo1Ol00005ooooo`;o00001?ooool2o`00
00;ooooo0_l0002Jooooo`007_ooool2o`0009Gooooo3?l000000ooooooo0000o`000003o`0000Go
oooo0ol0002Iooooo`007_ooool00ol0003oooooooooo`2Dooooo`Co000000?oooooo`000?l00000
1Ol00002ooooo`Co000000Goooooo`000?l0003o0000ooooo`03o`0009Wooooo000Nooooo`03o`00
0?oooooooooo09?ooooo4ol000001Ooooooo0000o`000?l0003ooooo00?o000000Coooooo`000?l0
003o0000UOooool001kooooo00?o0000ooooooooool0SooooolSo`0009Gooooo000Nooooo`03o`00
0?oooooooooo08oooooo8ol0002Eooooo`007_ooool00ol0003oooooooooo`2>ooooobCo0000UOoo
ool001kooooo00?o0000ooooooooool0SOoooolIo`0000;ooooo1?l000000ooooooo0000o`000005
ooooo`?o0000T?ooool001kooooo00?o0000ooooooooool0SOoooolSo`000004ooooool0003o0000
ooooo`?o0000T?ooool001kooooo00?o0000ooooooooool0SooooolEo`000003ooooool0003o0000
00co00000_ooool2o`00093ooooo000Nooooo`03o`000?oooooooooo08Sooooo0_l00003ooooo`;o
000000Coooooo`000?l0003ooooo4Ol000000ooooooo0000o`000008o`000003ooooool0003o0000
00;ooooo1?l0002?ooooo`007_ooool00ol0003oooooooooo`28ooooo`;o000000?oooooo`000?l0
00001Ol000000ooooooo0000o`00000?o`000003ooooool0003o000000So000000?oooooo`000?l0
00000_ooool4o`0008oooooo000Nooooo`03o`000?oooooooooo08Kooooo0_l00002oooooako0000
00?oooooo`000?l000001?l000000ooooooo0000o`000003ooooo`;o0000T?ooool001kooooo00?o
0000ooooooooool0Q_ooool2o`0000;ooooo;?l000000ooooooo0000o`00002>ooooo`007_ooool0
0ol0003oooooooooo`2:ooooo`Co000000Coooooo`000?l0003ooooo1Ol000000ooooooo0000o`00
000Lo`000003ooooool0003o000008kooooo000Nooooo`03o`000?oooooooooo08[ooooo1Ol00000
0ooooooo0000o`00000To`00097ooooo000Nooooo`03o`000?oooooooooo08cooooo0ol000000ooo
oooo0000o`00000To`00097ooooo000Nooooo`;o0000R_oooolGo`000003ooooool0003o000001Co
0000T?ooool001kooooo00?o0000ooooooooool0R?oooolJo`000003ooooool0003o000000go0000
0oooool2o`00093ooooo000Nooooo`03o`000?oooooooooo08Sooooo0_l00003ooooo`[o000000?o
ooooo`000?l000004ol000000ooooooo0000o`000002o`0000?ooooo0_l0002@ooooo`007_ooool0
0ol0003oooooooooo`25ooooo`;o00001_ooool>o`000003ooooool0003o000000;o000000?ooooo
o`000?l000002?l000000ooooooo0000o`000002o`0000Oooooo0_l0002>ooooo`007_ooool00ol0
003oooooooooo`25ooooo`Co00001?oooolCo`000003ooooool0003o000000So000000?oooooo`00
0?l000001?l000000ooooooo0000o`000005o`0008gooooo000Nooooo`03o`000?oooooooooo08Ko
oooo0ol000000ooooooo0000o`000002o`0000;ooooo6ol000001Ooooooo0000o`000?l0003ooooo
00;o000000?oooooo`000?l000001Ol0002=ooooo`007_ooool00ol0003oooooooooo`26ooooo`;o
00000_ooool?o`000003ooooool0003o000001?o00001_ooool2o`00093ooooo000Nooooo`03o`00
0?oooooooooo08_ooooo6ol00004ooooo`;o00001_ooool2o`000003ooooool0003o0000093ooooo
000Nooooo`03o`000?oooooooooo08_ooooo6Ol000000ooooooo0000o`000007ooooo`;o00000_oo
ool2o`0000;ooooo0_l0002?ooooo`007_ooool00ol0003oooooooooo`28ooooo`Go00001?oooolI
o`0000Cooooo0_l00004ooooo`Co0000Soooool001kooooo00?o0000ooooooooool0R?ooool4o`00
0005ooooool0003o0000o`000?ooool04?l00003ooooo`;o000000Goooooo`000?l0003o0000oooo
o`04o`0000;ooooo0_l000000ooooooo0000o`00002Aooooo`007_ooool00ol0003oooooooooo`2<
ooooo`Go000000?oooooo`000?l000003_l000000ooooooo0000o`000003o`0000?ooooo1Ol00000
0ooooooo0000o`00002Dooooo`007_ooool00ol0003oooooooooo`2;ooooo`?o000000Coooooo`00
0?l0003ooooo1ol000000ooooooo0000o`00000<o`0000Cooooo2?l0002Cooooo`007_ooool00ol0
003oooooooooo`2:ooooo`Go00000oooool>o`0000;ooooo0_l00003ooooo`Co000000?oooooo`00
0?l000001_l0002Cooooo`007_ooool00ol0003oooooooooo`2:ooooo`;o000000Coooooo`000?l0
003ooooo0_l000000ooooooo0000o`00000:o`0000Sooooo2Ol0002Gooooo`007_ooool00ol0003o
ooooooooo`2;ooooo`Co000000?oooooo`000?l000000_oooolAo`0000Cooooo1Ol0002Iooooo`00
7_ooool2o`0008cooooo1Ol00004ooooo`Co000000?oooooo`000?l000002_l00002ooooo`;o0000
0oooool2o`0009Wooooo000Nooooo`03o`000?oooooooooo08kooooo0_l00005ooooo`go00000ooo
ool6o`0009cooooo000Nooooo`03o`000?oooooooooo08gooooo0_l00006oooooa;o000000Cooooo
o`000?l0003o0000W?ooool001kooooo00?o0000ooooooooool0SOooool3o`0000;ooooo0_l00000
0ooooooo0000o`000002o`0000?ooooo2ol000001?oooooo0000o`000?l0002Looooo`007_ooool0
0ol0003oooooooooo`2=ooooo`?o00000_ooool2o`0000;ooooo4Ol0002Pooooo`007_ooool00ol0
003oooooooooo`2=ooooo`?o00002Oooool9o`0000?ooooo0_l0002Pooooo`007_ooool00ol0003o
ooooooooo`2>ooooo`?o00002_ooool2o`000003ooooool0003o000000;o0000YOooool001kooooo
00?o0000ooooooooool0S_ooool3o`000;Kooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0oooooom8ooooo`00
0oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006oooo
o`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRH
V?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003ooooooooo
o`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7oooo
o`08ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0oooooom8ooooo`000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o
0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<
ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo
00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo
00Go0000ooooooooooooooooo`000006ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooo
oooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooooooo
0?ooooooB?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0oooo
oom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zj
o`000006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000D
ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3oooooodSooooo000Foooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom8ooooo`005_ooool00ol0003o
ooooooooo`05ooooo`?o0000oooooom8ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo
000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@
ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Dooooo`03oeEEEOmVIVKo00000?oo
ooooD_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.51104 .53695 Mdot
.53585 .49824 Mdot
.53988 .46683 Mdot
.5302 .50589 Mdot
.51857 .52746 Mdot
.49379 .55228 Mdot
.52689 .45991 Mdot
.51684 .53703 Mdot
.44422 .49176 Mdot
.44917 .51653 Mdot
.48056 .54501 Mdot
.49806 .48324 Mdot
.50391 .55079 Mdot
.55679 .50377 Mdot
.4675 .45296 Mdot
.44962 .5077 Mdot
.54074 .52071 Mdot
.4351 .53387 Mdot
.44574 .52166 Mdot
.49311 .45593 Mdot
.53728 .52828 Mdot
.4488 .47537 Mdot
.4917 .53918 Mdot
.5302 .53193 Mdot
.51924 .53665 Mdot
.48712 .488 Mdot
.47123 .45361 Mdot
.44419 .52869 Mdot
.51672 .51819 Mdot
.51135 .54418 Mdot
.55078 .48288 Mdot
.53825 .51483 Mdot
.48978 .50645 Mdot
.51609 .45134 Mdot
.50821 .5479 Mdot
.53717 .46082 Mdot
.47933 .49081 Mdot
.46161 .46556 Mdot
.50376 .53645 Mdot
.49083 .47799 Mdot
.46274 .5073 Mdot
.47978 .45704 Mdot
.54202 .4781 Mdot
.49961 .4998 Mdot
.53724 .52168 Mdot
.45633 .49676 Mdot
.55903 .496 Mdot
.55315 .4884 Mdot
.54375 .46918 Mdot
.43727 .52859 Mdot
.51012 .53195 Mdot
.51304 .55256 Mdot
.51725 .51321 Mdot
.5119 .53535 Mdot
.44396 .50763 Mdot
.46743 .48094 Mdot
.51739 .47181 Mdot
.52975 .54958 Mdot
.53269 .52212 Mdot
.52046 .46987 Mdot
.44872 .4874 Mdot
.46543 .49562 Mdot
.50725 .45109 Mdot
.45181 .50854 Mdot
.50383 .53045 Mdot
.43888 .50384 Mdot
.55437 .50344 Mdot
.45641 .48813 Mdot
.47981 .4654 Mdot
.44638 .50607 Mdot
.50946 .44909 Mdot
.52816 .5207 Mdot
.50991 .46655 Mdot
.51451 .49793 Mdot
.521 .53934 Mdot
.49055 .44432 Mdot
.46629 .47047 Mdot
.43999 .54133 Mdot
.51885 .45279 Mdot
.47189 .54245 Mdot
.47056 .45749 Mdot
.51431 .53746 Mdot
.52957 .53439 Mdot
.46174 .5034 Mdot
.51016 .45092 Mdot
.51553 .50325 Mdot
.50978 .44599 Mdot
.46158 .4902 Mdot
.49466 .47522 Mdot
.45862 .56027 Mdot
.50954 .52039 Mdot
.45152 .49986 Mdot
.48637 .44723 Mdot
.43608 .51886 Mdot
.53445 .46399 Mdot
.45094 .47293 Mdot
.46238 .48639 Mdot
.55369 .49073 Mdot
.55974 .49371 Mdot
.5236 .47562 Mdot
.50305 .44431 Mdot
.49123 .44558 Mdot
.52621 .52862 Mdot
.44237 .51709 Mdot
.4487 .48116 Mdot
.4874 .50206 Mdot
.5558 .47022 Mdot
.50766 .52712 Mdot
.55181 .49521 Mdot
.45027 .49989 Mdot
.52668 .53156 Mdot
.52892 .51944 Mdot
.51672 .48636 Mdot
.44683 .48847 Mdot
.54938 .51725 Mdot
.49968 .55549 Mdot
.46399 .46186 Mdot
.43675 .52341 Mdot
.54762 .47849 Mdot
.4826 .44933 Mdot
.46449 .55254 Mdot
.49232 .49004 Mdot
.44724 .51428 Mdot
.5485 .47653 Mdot
.54235 .50915 Mdot
.44507 .49191 Mdot
.52529 .53362 Mdot
.49011 .4898 Mdot
.496 .49624 Mdot
.45862 .5109 Mdot
.46868 .54776 Mdot
.54284 .52212 Mdot
.54145 .53211 Mdot
.52784 .45831 Mdot
.49173 .5381 Mdot
.54546 .52662 Mdot
.44633 .48939 Mdot
.5039 .50894 Mdot
.49602 .46571 Mdot
.50856 .49004 Mdot
.50882 .52465 Mdot
.45156 .4769 Mdot
.49258 .49831 Mdot
.52669 .51024 Mdot
.48986 .51787 Mdot
.448 .49821 Mdot
.51053 .53923 Mdot
.45707 .46599 Mdot
.5495 .5181 Mdot
.54565 .47205 Mdot
.51594 .45423 Mdot
.44277 .52965 Mdot
.51427 .52475 Mdot
.55284 .51219 Mdot
.47216 .54779 Mdot
.44886 .50736 Mdot
.46776 .49755 Mdot
.5313 .53986 Mdot
.46731 .47001 Mdot
.49645 .52343 Mdot
.49299 .44588 Mdot
.47297 .46318 Mdot
.45903 .55215 Mdot
.43718 .50333 Mdot
.50459 .47342 Mdot
.5134 .47948 Mdot
.45309 .47397 Mdot
.46493 .46488 Mdot
.46118 .46397 Mdot
.45404 .47612 Mdot
.46165 .53365 Mdot
.54431 .47225 Mdot
.53827 .49295 Mdot
.50259 .47203 Mdot
.49762 .44875 Mdot
.47057 .48836 Mdot
.44833 .47321 Mdot
.49742 .52667 Mdot
.55111 .50937 Mdot
.53002 .46209 Mdot
.52784 .50578 Mdot
.44675 .47777 Mdot
.50868 .50095 Mdot
.51836 .51428 Mdot
.5011 .55323 Mdot
.50194 .4844 Mdot
.52708 .45209 Mdot
.44801 .48435 Mdot
.43666 .51609 Mdot
.4872 .44656 Mdot
.50332 .49358 Mdot
.48061 .51967 Mdot
.53429 .52942 Mdot
.51193 .52568 Mdot
.45727 .47095 Mdot
.47253 .50832 Mdot
.43553 .52919 Mdot
.49355 .50307 Mdot
.49705 .5324 Mdot
.53006 .49905 Mdot
.52805 .47921 Mdot
.45482 .48412 Mdot
.46505 .54997 Mdot
.4676 .46214 Mdot
.44997 .51135 Mdot
.53816 .48968 Mdot
.53669 .53147 Mdot
.52671 .47396 Mdot
.52804 .4537 Mdot
.51283 .52741 Mdot
.53736 .52251 Mdot
.48484 .49286 Mdot
.48648 .47176 Mdot
.47377 .55465 Mdot
.49245 .48977 Mdot
.55611 .5004 Mdot
.45184 .49733 Mdot
.47016 .47028 Mdot
.4511 .47768 Mdot
.50439 .52539 Mdot
.48386 .53099 Mdot
.53428 .54473 Mdot
.44917 .49817 Mdot
.54635 .51949 Mdot
.48521 .53916 Mdot
.50328 .53735 Mdot
.53499 .51383 Mdot
.4426 .51365 Mdot
.53169 .45467 Mdot
.47358 .54398 Mdot
.4378 .49026 Mdot
.48744 .49347 Mdot
.45117 .48044 Mdot
.47451 .49617 Mdot
.47746 .48552 Mdot
.4978 .46498 Mdot
.44703 .4877 Mdot
.49744 .44292 Mdot
.54536 .50422 Mdot
.50185 .48431 Mdot
.44332 .51444 Mdot
.47153 .45126 Mdot
.51651 .53712 Mdot
.44581 .48917 Mdot
.53964 .47206 Mdot
.44254 .50619 Mdot
.48824 .4453 Mdot
.50873 .53763 Mdot
.43588 .50228 Mdot
.46325 .46214 Mdot
.53934 .4767 Mdot
.49701 .55493 Mdot
.46772 .45418 Mdot
.5369 .46754 Mdot
.51537 .48954 Mdot
.50446 .47957 Mdot
.48131 .53915 Mdot
.47598 .47407 Mdot
.51065 .45031 Mdot
.46077 .46251 Mdot
.46747 .46262 Mdot
.47582 .51217 Mdot
.49584 .52298 Mdot
.47096 .55223 Mdot
.50135 .45463 Mdot
.50103 .45123 Mdot
.47516 .5439 Mdot
.45529 .53787 Mdot
.47811 .50704 Mdot
.55197 .51016 Mdot
.55264 .49511 Mdot
.51645 .48606 Mdot
.43723 .51411 Mdot
.51163 .48782 Mdot
.53502 .45923 Mdot
.4968 .44387 Mdot
.46367 .47706 Mdot
.4499 .52118 Mdot
.49163 .45804 Mdot
.46514 .52188 Mdot
.48923 .46554 Mdot
.48149 .48316 Mdot
.5579 .49295 Mdot
.49471 .51344 Mdot
.45742 .46935 Mdot
.43515 .52255 Mdot
.55296 .50638 Mdot
.48373 .53832 Mdot
.54309 .50074 Mdot
.55028 .51681 Mdot
.50346 .47616 Mdot
.5519 .51406 Mdot
.4908 .55844 Mdot
.54069 .47407 Mdot
.51374 .47955 Mdot
.51538 .53477 Mdot
.45136 .53171 Mdot
.52399 .45937 Mdot
.47983 .45633 Mdot
.53048 .50796 Mdot
.49788 .50511 Mdot
.50181 .53732 Mdot
.44528 .48626 Mdot
.44124 .50087 Mdot
.50028 .4797 Mdot
.5297 .50777 Mdot
.55753 .5129 Mdot
.53813 .52796 Mdot
.5181 .53621 Mdot
.50488 .45533 Mdot
.52367 .49931 Mdot
.49303 .5121 Mdot
.47685 .53828 Mdot
.50599 .53605 Mdot
.52927 .49388 Mdot
.54625 .52552 Mdot
.48916 .47804 Mdot
.45852 .48896 Mdot
.50529 .4669 Mdot
.45934 .46872 Mdot
.53416 .46495 Mdot
.48495 .54414 Mdot
.48577 .54547 Mdot
.46882 .48582 Mdot
.45554 .52898 Mdot
.45026 .48046 Mdot
.50156 .49588 Mdot
.49594 .49473 Mdot
.44122 .49867 Mdot
.48324 .45078 Mdot
.51208 .53997 Mdot
.50955 .55206 Mdot
.51669 .48506 Mdot
.45012 .51783 Mdot
.52968 .4548 Mdot
.47746 .52648 Mdot
.51792 .45529 Mdot
.52931 .51397 Mdot
.49137 .53898 Mdot
.46494 .49406 Mdot
.55577 .50152 Mdot
.54067 .5286 Mdot
.55002 .46969 Mdot
.49194 .50067 Mdot
.45337 .4737 Mdot
.55031 .51294 Mdot
.49586 .51326 Mdot
.51898 .53455 Mdot
.46679 .46294 Mdot
.46124 .50346 Mdot
.51085 .4738 Mdot
.5398 .53552 Mdot
.53801 .524 Mdot
.47497 .49353 Mdot
.47518 .56007 Mdot
.51129 .4774 Mdot
.54891 .51561 Mdot
.54754 .51274 Mdot
.47582 .56167 Mdot
.48742 .50389 Mdot
.50074 .53224 Mdot
.5457 .5256 Mdot
.51363 .48187 Mdot
.54656 .51941 Mdot
.54878 .51186 Mdot
.55626 .49032 Mdot
.54728 .47917 Mdot
.46206 .46729 Mdot
.55445 .50392 Mdot
.51403 .50407 Mdot
.49719 .52401 Mdot
.50509 .51297 Mdot
.53646 .5407 Mdot
.47773 .5431 Mdot
.54399 .47288 Mdot
.44989 .51384 Mdot
.47512 .54428 Mdot
.50286 .44376 Mdot
.48325 .45696 Mdot
.48384 .49044 Mdot
.51583 .45594 Mdot
.52875 .45978 Mdot
.52511 .51665 Mdot
.54125 .52768 Mdot
.53486 .51661 Mdot
.49064 .55075 Mdot
.44344 .52903 Mdot
.47951 .5309 Mdot
.47164 .48136 Mdot
.51752 .45699 Mdot
.55115 .52239 Mdot
.48419 .45873 Mdot
.53023 .46306 Mdot
.53809 .516 Mdot
.4905 .53833 Mdot
.52352 .53417 Mdot
.43765 .49622 Mdot
.49078 .5106 Mdot
.45351 .52869 Mdot
.55207 .51939 Mdot
.55584 .51263 Mdot
.5231 .45742 Mdot
.55308 .52501 Mdot
.48294 .48289 Mdot
.52608 .46186 Mdot
.53834 .46225 Mdot
.52036 .51373 Mdot
.50134 .52491 Mdot
.53304 .47847 Mdot
.4692 .53853 Mdot
.50595 .48917 Mdot
.45719 .52402 Mdot
.51346 .4995 Mdot
.55223 .48564 Mdot
.51134 .504 Mdot
.49211 .44508 Mdot
.44811 .50088 Mdot
.53905 .52738 Mdot
.5328 .47028 Mdot
.44403 .51273 Mdot
.46898 .52725 Mdot
.4556 .49464 Mdot
.50844 .49995 Mdot
.45312 .52014 Mdot
.54496 .54081 Mdot
.52647 .45667 Mdot
.45835 .46289 Mdot
.47288 .50594 Mdot
.49295 .46278 Mdot
.4849 .47335 Mdot
.54574 .52325 Mdot
.44635 .50586 Mdot
.53635 .53157 Mdot
.4702 .53035 Mdot
.46083 .46578 Mdot
.53576 .52926 Mdot
.45988 .46556 Mdot
.51686 .47119 Mdot
.54284 .52454 Mdot
.50416 .47234 Mdot
.54451 .47516 Mdot
.45997 .55769 Mdot
.55168 .51506 Mdot
.4723 .5512 Mdot
.48697 .50244 Mdot
.46459 .54247 Mdot
.52338 .52286 Mdot
.45165 .51144 Mdot
.52101 .45264 Mdot
.51207 .51996 Mdot
.55503 .4871 Mdot
.50467 .48565 Mdot
.46051 .50569 Mdot
.49949 .47176 Mdot
.49518 .44601 Mdot
.44482 .49161 Mdot
.51586 .45455 Mdot
.46272 .4651 Mdot
.50111 .52002 Mdot
.48034 .47377 Mdot
.47325 .45867 Mdot
.51756 .49522 Mdot
.55316 .48778 Mdot
.4769 .49673 Mdot
.53346 .46635 Mdot
.54957 .51615 Mdot
.47342 .50142 Mdot
.50773 .49725 Mdot
.55465 .50716 Mdot
.47674 .47165 Mdot
.49349 .54137 Mdot
.47149 .52117 Mdot
.53313 .45588 Mdot
.46634 .45186 Mdot
.45527 .52702 Mdot
.4456 .48961 Mdot
.54729 .47455 Mdot
.46416 .45241 Mdot
.50317 .44418 Mdot
.54214 .52888 Mdot
.4924 .50987 Mdot
.53769 .52407 Mdot
.51096 .53749 Mdot
.53032 .52723 Mdot
.45408 .49337 Mdot
.47136 .45956 Mdot
.45276 .51888 Mdot
.51222 .53701 Mdot
.54014 .46909 Mdot
.50173 .44345 Mdot
.48962 .55939 Mdot
.52949 .45355 Mdot
.44006 .50359 Mdot
.49809 .53056 Mdot
.53353 .47451 Mdot
.47888 .55945 Mdot
.45381 .47371 Mdot
.49502 .52914 Mdot
.47381 .45886 Mdot
.50647 .53651 Mdot
.55686 .47421 Mdot
.46471 .45667 Mdot
.53558 .46202 Mdot
.4795 .52511 Mdot
.50308 .48397 Mdot
.43626 .51359 Mdot
.52431 .53246 Mdot
.46031 .51592 Mdot
.51808 .44989 Mdot
.4355 .52568 Mdot
.48426 .45894 Mdot
.51284 .45217 Mdot
.54056 .47912 Mdot
.48578 .5557 Mdot
.50252 .5369 Mdot
.44784 .50553 Mdot
.53906 .47762 Mdot
.50624 .54858 Mdot
.55617 .48871 Mdot
.50159 .53727 Mdot
.43574 .50329 Mdot
.55404 .49953 Mdot
.50693 .53571 Mdot
.48357 .48766 Mdot
.50879 .47924 Mdot
.46331 .48518 Mdot
.53127 .46112 Mdot
.50786 .55422 Mdot
.46662 .54106 Mdot
.4583 .52647 Mdot
.48792 .45053 Mdot
.44768 .4981 Mdot
.46505 .47694 Mdot
.51729 .49421 Mdot
.43672 .51472 Mdot
.49843 .48677 Mdot
.53385 .53194 Mdot
.45488 .48949 Mdot
.52302 .47247 Mdot
.44113 .51934 Mdot
.51482 .48841 Mdot
.45361 .55298 Mdot
.44577 .49964 Mdot
.53598 .53036 Mdot
.47006 .54568 Mdot
.47621 .45014 Mdot
.52421 .51422 Mdot
.44595 .55059 Mdot
.52763 .52376 Mdot
.47366 .53712 Mdot
.49504 .47606 Mdot
.50172 .53845 Mdot
.48982 .51336 Mdot
.55562 .48224 Mdot
.53163 .51684 Mdot
.48419 .52761 Mdot
.50559 .52014 Mdot
.52333 .46333 Mdot
.48581 .56009 Mdot
.4735 .45355 Mdot
.48711 .44787 Mdot
.51243 .44899 Mdot
.45136 .51272 Mdot
.51442 .50879 Mdot
.4886 .45385 Mdot
.48079 .53922 Mdot
.52361 .45769 Mdot
.4687 .52365 Mdot
.53878 .52928 Mdot
.54715 .47381 Mdot
.55184 .51053 Mdot
.4881 .49134 Mdot
.52932 .46665 Mdot
.52414 .5299 Mdot
.50337 .48615 Mdot
.4548 .50704 Mdot
.45045 .5546 Mdot
.49373 .47656 Mdot
.49767 .44271 Mdot
.49273 .4852 Mdot
.53166 .4551 Mdot
.5272 .52062 Mdot
.5497 .46597 Mdot
.53382 .48099 Mdot
.47188 .46491 Mdot
.55502 .49957 Mdot
.49749 .53802 Mdot
.55212 .50441 Mdot
.54369 .52761 Mdot
.50159 .45018 Mdot
.50204 .48284 Mdot
.45805 .50023 Mdot
.49426 .53309 Mdot
.50005 .49226 Mdot
.45435 .51214 Mdot
.51321 .53927 Mdot
.53903 .52778 Mdot
.44597 .47606 Mdot
.45875 .55154 Mdot
.53553 .49409 Mdot
.4635 .46581 Mdot
.4385 .49006 Mdot
.50317 .53853 Mdot
.47134 .55853 Mdot
.45727 .50086 Mdot
.54968 .49036 Mdot
.47035 .51625 Mdot
.55029 .48255 Mdot
.46652 .49531 Mdot
.49659 .49346 Mdot
.43528 .52362 Mdot
.52236 .53233 Mdot
.48296 .54049 Mdot
.55748 .49709 Mdot
.51385 .53666 Mdot
.51776 .52289 Mdot
.49938 .53626 Mdot
.44208 .50822 Mdot
.50421 .5299 Mdot
.48966 .44682 Mdot
.52542 .45894 Mdot
.51591 .5525 Mdot
.51956 .49001 Mdot
.46806 .49716 Mdot
.54416 .47649 Mdot
.51299 .45577 Mdot
.51303 .5228 Mdot
.50347 .51706 Mdot
.54696 .52554 Mdot
.54229 .49936 Mdot
.45137 .48852 Mdot
.44892 .50888 Mdot
.54674 .47284 Mdot
.44777 .55026 Mdot
.45218 .55381 Mdot
.48875 .54032 Mdot
.49205 .44392 Mdot
.50712 .49484 Mdot
.52977 .52515 Mdot
.55289 .50668 Mdot
.51255 .53719 Mdot
.46501 .47266 Mdot
.55018 .48149 Mdot
.47524 .50499 Mdot
.45991 .51216 Mdot
.47137 .55658 Mdot
.47409 .55961 Mdot
.48169 .50017 Mdot
.53132 .4633 Mdot
.52237 .45645 Mdot
.50357 .53622 Mdot
.49073 .51551 Mdot
.48729 .49698 Mdot
.55153 .49481 Mdot
.52037 .48186 Mdot
.53932 .4756 Mdot
.43914 .49766 Mdot
.50517 .4946 Mdot
.48984 .45152 Mdot
.49928 .4911 Mdot
.5281 .52419 Mdot
.48825 .51251 Mdot
.54602 .51947 Mdot
.53603 .54766 Mdot
.55712 .47948 Mdot
.51519 .45375 Mdot
.45579 .47274 Mdot
.55651 .51752 Mdot
.52161 .53364 Mdot
.44762 .47308 Mdot
.53986 .49944 Mdot
.54131 .54179 Mdot
.55665 .51254 Mdot
.43981 .48413 Mdot
.46687 .51354 Mdot
.43427 .5053 Mdot
.50493 .46303 Mdot
.53658 .52175 Mdot
.44606 .53183 Mdot
.51414 .53564 Mdot
.44597 .48538 Mdot
.48566 .44866 Mdot
.54667 .4935 Mdot
.47879 .4516 Mdot
.5401 .51898 Mdot
.45453 .48144 Mdot
.54126 .50591 Mdot
.49673 .55461 Mdot
.49707 .46978 Mdot
.49851 .4589 Mdot
.45925 .46864 Mdot
.53865 .46314 Mdot
.52002 .55088 Mdot
.47463 .48429 Mdot
.52285 .46034 Mdot
.5262 .53372 Mdot
.55616 .47402 Mdot
.49705 .50263 Mdot
.45048 .50123 Mdot
.53027 .51024 Mdot
.49035 .53869 Mdot
.49732 .48645 Mdot
.55822 .49451 Mdot
.50447 .53032 Mdot
.54721 .4799 Mdot
.51646 .45348 Mdot
.4644 .48738 Mdot
.51249 .52987 Mdot
.50508 .44882 Mdot
.45324 .52036 Mdot
.43936 .5059 Mdot
.49787 .49311 Mdot
.50607 .44684 Mdot
.43237 .50972 Mdot
.54887 .51941 Mdot
.47227 .45294 Mdot
.43373 .50536 Mdot
.53436 .53209 Mdot
.49474 .55057 Mdot
.44921 .53319 Mdot
.51818 .50352 Mdot
.46704 .5347 Mdot
.49776 .46264 Mdot
.51879 .49722 Mdot
.52342 .53187 Mdot
.51369 .4749 Mdot
.44259 .54707 Mdot
.47337 .55538 Mdot
.53405 .53183 Mdot
.45722 .47193 Mdot
.47332 .54813 Mdot
.45886 .50475 Mdot
.51012 .47568 Mdot
.46958 .50018 Mdot
.50078 .5559 Mdot
.52361 .45765 Mdot
.47519 .48713 Mdot
.44758 .47456 Mdot
.45141 .52263 Mdot
.47152 .47255 Mdot
.45493 .49751 Mdot
.50981 .55014 Mdot
.47743 .48335 Mdot
.50099 .53643 Mdot
.48702 .5247 Mdot
.51424 .5324 Mdot
.49919 .53008 Mdot
.46308 .49113 Mdot
.49531 .49675 Mdot
.49689 .54269 Mdot
.53583 .46254 Mdot
.49805 .51943 Mdot
.5123 .47063 Mdot
.51591 .53024 Mdot
.44003 .48597 Mdot
.54397 .52274 Mdot
.45223 .4759 Mdot
.44874 .51389 Mdot
.55067 .48328 Mdot
.47328 .53136 Mdot
.50237 .54773 Mdot
.49129 .55106 Mdot
.45702 .45514 Mdot
.47585 .46037 Mdot
.44499 .54927 Mdot
.51535 .49299 Mdot
.54155 .52815 Mdot
.52348 .5139 Mdot
.49966 .49724 Mdot
.54009 .46458 Mdot
.47983 .55134 Mdot
.55269 .48827 Mdot
.51166 .54553 Mdot
.5127 .5057 Mdot
.53408 .45782 Mdot
.47561 .45232 Mdot
.45429 .46568 Mdot
.51087 .53546 Mdot
.51046 .49562 Mdot
.4805 .47026 Mdot
.47655 .51804 Mdot
.55123 .51028 Mdot
.50548 .54787 Mdot
.47611 .56129 Mdot
.54395 .54014 Mdot
.49812 .4441 Mdot
.52689 .4841 Mdot
.4622 .50928 Mdot
.45361 .53004 Mdot
.46724 .46123 Mdot
.52935 .49546 Mdot
.46202 .5476 Mdot
.52342 .50312 Mdot
.46374 .46378 Mdot
.55026 .49348 Mdot
.45158 .47667 Mdot
.55061 .49081 Mdot
.55557 .48018 Mdot
.45301 .51258 Mdot
.55315 .48042 Mdot
.47412 .51089 Mdot
.52296 .47334 Mdot
.5151 .44836 Mdot
.44554 .4718 Mdot
.51123 .53637 Mdot
.4546 .51078 Mdot
.50572 .47424 Mdot
.50755 .53655 Mdot
.53515 .52652 Mdot
.44527 .53913 Mdot
.52412 .51323 Mdot
.47604 .45027 Mdot
.52332 .50681 Mdot
.49101 .54532 Mdot
.45157 .5127 Mdot
.54057 .47639 Mdot
.451 .47732 Mdot
.51744 .47359 Mdot
.51922 .53433 Mdot
.54878 .47737 Mdot
.47617 .5011 Mdot
.5174 .48999 Mdot
.49731 .44441 Mdot
.45019 .52171 Mdot
.5163 .53396 Mdot
.43394 .51639 Mdot
.50174 .53142 Mdot
.54489 .50018 Mdot
.54963 .49345 Mdot
.47665 .48296 Mdot
.55838 .48341 Mdot
.55617 .50047 Mdot
.54896 .48188 Mdot
.45774 .49318 Mdot
.48875 .49445 Mdot
.46739 .51362 Mdot
.48365 .45576 Mdot
.4715 .54284 Mdot
.52136 .4916 Mdot
.4583 .46881 Mdot
.51364 .53599 Mdot
.45425 .49798 Mdot
.4486 .47638 Mdot
.49863 .44784 Mdot
.51981 .45434 Mdot
.49116 .44766 Mdot
.44634 .47518 Mdot
.48669 .45418 Mdot
.45242 .49566 Mdot
.50775 .46613 Mdot
.54352 .50673 Mdot
.4661 .55796 Mdot
.55803 .49854 Mdot
.55685 .51306 Mdot
.49847 .44897 Mdot
.5049 .48573 Mdot
.48309 .50638 Mdot
.48065 .55703 Mdot
.50845 .49826 Mdot
.50985 .52668 Mdot
.50199 .44696 Mdot
.50503 .48529 Mdot
.49272 .51338 Mdot
.4775 .45205 Mdot
.45518 .53384 Mdot
.51677 .44971 Mdot
.53431 .48796 Mdot
.44333 .53488 Mdot
.53344 .49604 Mdot
.51903 .5535 Mdot
.46197 .54409 Mdot
.45743 .46992 Mdot
.55188 .48418 Mdot
.51305 .53959 Mdot
.5279 .53278 Mdot
.51327 .50437 Mdot
.50794 .53689 Mdot
.4535 .50082 Mdot
.49584 .47599 Mdot
.50749 .55423 Mdot
.55686 .48077 Mdot
.53697 .53995 Mdot
.55127 .51363 Mdot
.51369 .51423 Mdot
.44787 .55089 Mdot
.53309 .52381 Mdot
.49348 .47136 Mdot
.4536 .5076 Mdot
.50598 .4444 Mdot
.53519 .53962 Mdot
.46212 .46607 Mdot
.4895 .49891 Mdot
.51733 .44874 Mdot
.47241 .53358 Mdot
.49361 .528 Mdot
.43693 .51727 Mdot
.5204 .52154 Mdot
.54795 .49018 Mdot
.51319 .48584 Mdot
.51959 .4846 Mdot
.47746 .54995 Mdot
.52777 .47902 Mdot
.54336 .52556 Mdot
.53143 .49421 Mdot
.44268 .50002 Mdot
.51857 .50486 Mdot
.50579 .44413 Mdot
.5 .46608 Mdot
.5146 .53517 Mdot
.55013 .51777 Mdot
.49261 .44971 Mdot
.46884 .46164 Mdot
.50824 .48403 Mdot
.49743 .53731 Mdot
.53945 .50809 Mdot
.49428 .48345 Mdot
.49335 .4457 Mdot
.54412 .46947 Mdot
.52514 .53275 Mdot
.46754 .4587 Mdot
.46072 .50054 Mdot
.49742 .50004 Mdot
.55058 .51401 Mdot
.48901 .44839 Mdot
.46406 .45739 Mdot
.52004 .49856 Mdot
.51538 .53419 Mdot
.49887 .47965 Mdot
.44418 .48513 Mdot
.51936 .51005 Mdot
.52572 .48254 Mdot
.47727 .45765 Mdot
.44233 .49421 Mdot
.54515 .50677 Mdot
.50635 .49845 Mdot
.43573 .53005 Mdot
.4671 .49631 Mdot
.55757 .48879 Mdot
.46698 .45747 Mdot
.49162 .44476 Mdot
.52426 .54416 Mdot
.51744 .53664 Mdot
.53868 .46726 Mdot
.52007 .50069 Mdot
.45506 .47917 Mdot
.51673 .53605 Mdot
.55636 .49726 Mdot
.55676 .49451 Mdot
.53057 .46842 Mdot
.54011 .52802 Mdot
.44169 .52743 Mdot
.50999 .48886 Mdot
.43935 .54245 Mdot
.54652 .50123 Mdot
.52716 .50311 Mdot
.45423 .53647 Mdot
.49471 .44448 Mdot
.44749 .50283 Mdot
.55429 .49738 Mdot
.48736 .44742 Mdot
.47495 .45627 Mdot
.51015 .50337 Mdot
.44645 .47587 Mdot
.48561 .49442 Mdot
.47752 .50118 Mdot
.54418 .47575 Mdot
.53183 .45452 Mdot
.52877 .4809 Mdot
.45774 .50541 Mdot
.47434 .45342 Mdot
.49487 .45203 Mdot
.52877 .53048 Mdot
.50533 .55415 Mdot
.46068 .46842 Mdot
.55482 .50436 Mdot
.44588 .505 Mdot
.55413 .46543 Mdot
.50868 .50216 Mdot
.48484 .48415 Mdot
.43671 .53667 Mdot
.45678 .55681 Mdot
.50277 .52416 Mdot
.5273 .52946 Mdot
.49513 .53747 Mdot
.55394 .50986 Mdot
.54856 .48051 Mdot
.52432 .53201 Mdot
.52273 .48721 Mdot
.44281 .50122 Mdot
.4784 .53125 Mdot
.51075 .53705 Mdot
.49783 .53631 Mdot
.53736 .52874 Mdot
.46377 .52067 Mdot
.45388 .51496 Mdot
.45365 .48175 Mdot
.48307 .44845 Mdot
.53286 .46045 Mdot
.5049 .44885 Mdot
.44573 .55041 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go
00001_ooool3o`000?ooooooB?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04
odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol0003o
oooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`3o
ooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007
ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<
ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`2Kooooo`Oo0000YOoo
ool001kooooo00?o0000ooooooooool0V_ooool:o`000:?ooooo000Nooooo`03o`000?oooooooooo
09Oooooo3ol0002Qooooo`007_ooool2o`0009Cooooo5ol0002Mooooo`007_ooool00ol0003ooooo
ooooo`2@ooooo`;o000000?oooooo`000?l000005_l0002Looooo`007_ooool00ol0003ooooooooo
o`2@ooooo`;o000000?oooooo`000?l000003Ol000000ooooooo0000o`000007o`0009_ooooo000N
ooooo`03o`000?oooooooooo09;ooooo2Ol000000ooooooo0000o`000002o`0000Cooooo2Ol0002J
ooooo`007_ooool00ol0003oooooooooo`2@ooooo`[o000000?oooooo`000?l000001Ol00004oooo
o`Oo00000oooool2o`0009Gooooo000Nooooo`03o`000?oooooooooo093ooooo2_l000000ooooooo
0000o`000007o`0000;ooooo1ol00002ooooo`?o0000UOooool001kooooo00?o0000ooooooooool0
SOooool2o`000003ooooool0003o000001Go000000?oooooo`000?l000002Ol0002Dooooo`007_oo
ool00ol0003oooooooooo`2=ooooobKo0000U?ooool001kooooo00?o0000ooooooooool0SOooool5
o`000003ooooool0003o000000[o000000?oooooo`000?l000003_l000000ooooooo0000o`00002D
ooooo`007_ooool00ol0003oooooooooo`2=ooooo`Go000000Coooooo`000?l0003o00001Oooool:
o`000003ooooool0003o000000_o0000U?ooool001kooooo00?o0000ooooooooool0Roooool2o`00
0003ooooool0003o000000;o00000_ooool8o`000003ooooool0003o000000co000000?oooooo`00
0?l000001Ol0002Dooooo`007_ooool00ol0003oooooooooo`2;oooooako00001Oooool5o`0009Co
oooo000Nooooo`03o`000?oooooooooo08[ooooo7_l00002ooooo`?o000000?oooooo`000?l00000
0ol0002Dooooo`007_ooool00ol0003oooooooooo`2:ooooo`[o000000?oooooo`000?l000004?l0
0003ooooo`?o000000?oooooo`000?l000000ol0002Dooooo`007_ooool00ol0003oooooooooo`2:
oooooago000000?oooooo`000?l000000ol000000ooooooo0000o`000004o`0009?ooooo000Noooo
o`03o`000?oooooooooo08[ooooo2?l000000ooooooo0000o`000004o`000003ooooool0003o0000
01;o000000?oooooo`000?l000000ol0002Cooooo`007_ooool2o`0008_ooooo5_l000000ooooooo
0000o`00000@o`0009Cooooo000Nooooo`03o`000?oooooooooo08Wooooo2ol000000ooooooo0000
o`000009o`000003ooooool0003o000000Ko00000oooool7o`0009Cooooo000Nooooo`03o`000?oo
oooooooo08Wooooo2ol00002oooooaCo000000?oooooo`000?l000001_l0002Dooooo`007_ooool0
0ol0003oooooooooo`28ooooo`;o000000?oooooo`000?l000001ol00002ooooo`So00000_ooool2
o`000003ooooool0003o000000Go000000?oooooo`000?l000001Ol0002Eooooo`007_ooool00ol0
003oooooooooo`28oooooa7o00000_ooool4o`000004ooooool0003o0000oooooa3o0000U?ooool0
01kooooo00?o0000ooooooooool0ROooool@o`0000;ooooo1?l000001?oooooo0000o`000?ooool:
o`000003ooooool0003o000000?o0000U?ooool001kooooo00?o0000ooooooooool0ROooool8o`00
0003ooooool0003o000000Ko000000Coooooo`000?l0003ooooo2?l000000ooooooo0000o`00000:
o`0009Cooooo000Nooooo`03o`000?oooooooooo08Wooooo3_l000000ooooooo0000o`000003oooo
oaCo0000U_ooool001kooooo00?o0000ooooooooool0ROooool3o`000003ooooool0003o000000Oo
000000?oooooo`000?l000000ol000000ooooooo0000o`00000Co`0009Gooooo000Nooooo`03o`00
0?oooooooooo08Wooooo1Ol000000ooooooo0000o`000002o`000003ooooool0003o000001co0000
UOooool001kooooo00?o0000ooooooooool0ROooool9o`0000?ooooo1_l000000ooooooo0000o`00
000Ao`0009Sooooo000Nooooo`03o`000?oooooooooo08Wooooo0_l000000ooooooo0000o`00000=
o`0000;ooooo4Ol0002Iooooo`007_ooool00ol0003oooooooooo`29ooooo`Ko000000?oooooo`00
0?l000006ol0002Jooooo`007_ooool00ol0003oooooooooo`2:ooooo`Go000000Coooooo`000?l0
003ooooo5?l00002ooooo`Ko0000V?ooool001kooooo00?o0000ooooooooool0Roooool2o`0000Go
oooo3Ol00003ooooo`;o00000_ooool2o`000003ooooool0003o000000Co0000V?ooool001kooooo
00?o0000ooooooooool0S?ooool2o`0000Cooooo3?l000000ooooooo0000o`000003o`0000;ooooo
0_l00002ooooo`;o0000Voooool001kooooo0_l0002=ooooo`?o00000_ooool9o`000003ooooool0
003o000000Oo000000Coooooo`000?l0003ooooo1?l0002Kooooo`007_ooool00ol0003ooooooooo
o`2=ooooo`go000000?oooooo`000?l000002_l000000ooooooo0000o`00002Mooooo`007_ooool0
0ol0003oooooooooo`2>oooooaWo0000X?ooool001kooooo00?o0000ooooooooool0T?ooool=o`00
0004ooooool0003o0000o`000:Kooooo000Nooooo`03o`000?oooooooooo097ooooo0_l00002oooo
o`So0000Z_ooool001kooooo00?o0000ooooooooool0Uoooool2o`000:kooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o
0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`00
0?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool000?ooooo00Go0000oooooooooooo
ooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`3ooooo
odSooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413o
c<c<00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol@413ooooooooooooooooo
410@00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`3oooooodSooooo0003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooo
oooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co
0000oa0@40Kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o
0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3o
ooooodSooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4Q
oiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@
oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?oooooo
B?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb
<S801_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`000?ooooooooooooooool0
00002oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom8oooo
o`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006
ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`3oooooodSooooo0003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`005?ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooo
ooooool0oooooom8ooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool001Kooooo00?o0000ooooooooool01Oooool3o`000?ooooooB?ooool001Kooooo00?o
0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Foooo
o`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`00
5?ooool00omEEEGoIVIVo`00003ooooooe;ooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.47802 .54871 Mdot
.53425 .5175 Mdot
.569 .48751 Mdot
.52583 .52275 Mdot
.50959 .53568 Mdot
.45655 .54493 Mdot
.56267 .48818 Mdot
.50104 .55081 Mdot
.46158 .45021 Mdot
.43864 .48759 Mdot
.4569 .53905 Mdot
.50813 .48494 Mdot
.46396 .54748 Mdot
.55417 .5418 Mdot
.50758 .43505 Mdot
.44446 .48174 Mdot
.52958 .54364 Mdot
.41398 .50478 Mdot
.43288 .49113 Mdot
.51447 .45726 Mdot
.52451 .55174 Mdot
.45176 .44788 Mdot
.48094 .53824 Mdot
.49454 .55329 Mdot
.49986 .55346 Mdot
.49241 .48264 Mdot
.50522 .43437 Mdot
.42848 .49785 Mdot
.51135 .52491 Mdot
.47165 .54824 Mdot
.564 .50824 Mdot
.52967 .53469 Mdot
.4877 .49616 Mdot
.54575 .46074 Mdot
.46808 .54805 Mdot
.56461 .47627 Mdot
.48141 .48155 Mdot
.48609 .43797 Mdot
.49442 .53882 Mdot
.5031 .47805 Mdot
.45623 .48765 Mdot
.4987 .44937 Mdot
.55485 .49774 Mdot
.50107 .49887 Mdot
.52645 .54146 Mdot
.45749 .4776 Mdot
.56071 .53607 Mdot
.56505 .51732 Mdot
.56511 .48748 Mdot
.43533 .48126 Mdot
.50164 .53574 Mdot
.46884 .55039 Mdot
.51302 .52109 Mdot
.50041 .54308 Mdot
.43813 .47939 Mdot
.47476 .47164 Mdot
.5327 .48416 Mdot
.48337 .55315 Mdot
.52245 .53891 Mdot
.53707 .4832 Mdot
.45341 .46761 Mdot
.46601 .48084 Mdot
.53401 .45734 Mdot
.44606 .48348 Mdot
.49767 .52927 Mdot
.45282 .45856 Mdot
.55227 .53194 Mdot
.46106 .47191 Mdot
.49469 .46125 Mdot
.44189 .47924 Mdot
.55206 .45495 Mdot
.51901 .53472 Mdot
.52787 .47604 Mdot
.51571 .50756 Mdot
.4811 .55124 Mdot
.52745 .43808 Mdot
.47682 .46055 Mdot
.41767 .51304 Mdot
.55997 .46527 Mdot
.45573 .52429 Mdot
.49648 .43766 Mdot
.49667 .55082 Mdot
.51415 .55464 Mdot
.45772 .48471 Mdot
.53796 .45813 Mdot
.51433 .5123 Mdot
.54437 .45048 Mdot
.46537 .47579 Mdot
.50882 .47734 Mdot
.42721 .53964 Mdot
.50502 .52213 Mdot
.45134 .47712 Mdot
.51818 .439 Mdot
.44235 .47163 Mdot
.56841 .48708 Mdot
.45649 .45522 Mdot
.46778 .47353 Mdot
.56249 .51891 Mdot
.56322 .53364 Mdot
.53643 .4904 Mdot
.53711 .44588 Mdot
.52189 .4404 Mdot
.51466 .5428 Mdot
.43751 .47024 Mdot
.47296 .44451 Mdot
.48483 .49106 Mdot
.56257 .51816 Mdot
.50175 .52777 Mdot
.55307 .52037 Mdot
.45015 .47648 Mdot
.49352 .55229 Mdot
.52007 .534 Mdot
.52372 .49881 Mdot
.46075 .44901 Mdot
.53931 .54781 Mdot
.458 .54811 Mdot
.49362 .43587 Mdot
.42138 .49277 Mdot
.56896 .50701 Mdot
.51446 .43896 Mdot
.4395 .53178 Mdot
.49727 .48601 Mdot
.4376 .48514 Mdot
.5663 .49822 Mdot
.53544 .53136 Mdot
.45258 .45179 Mdot
.48894 .5522 Mdot
.49477 .4849 Mdot
.49815 .49269 Mdot
.45011 .48884 Mdot
.4476 .52906 Mdot
.53116 .54776 Mdot
.50013 .5532 Mdot
.55393 .47202 Mdot
.47394 .54279 Mdot
.50903 .55421 Mdot
.43902 .45135 Mdot
.50202 .50961 Mdot
.51389 .46919 Mdot
.51457 .49705 Mdot
.50347 .52587 Mdot
.47642 .44261 Mdot
.49286 .49137 Mdot
.52149 .5246 Mdot
.48655 .5073 Mdot
.44868 .47487 Mdot
.47536 .54841 Mdot
.46479 .44818 Mdot
.53936 .54936 Mdot
.56492 .4913 Mdot
.54254 .46403 Mdot
.42667 .49908 Mdot
.50769 .52953 Mdot
.54615 .54891 Mdot
.44991 .53321 Mdot
.44381 .48115 Mdot
.46665 .48269 Mdot
.48926 .55298 Mdot
.47816 .46052 Mdot
.49333 .51682 Mdot
.53538 .44069 Mdot
.48745 .45511 Mdot
.43302 .52909 Mdot
.43162 .47598 Mdot
.51989 .48032 Mdot
.52486 .49079 Mdot
.48159 .44115 Mdot
.48483 .44077 Mdot
.47185 .44336 Mdot
.47264 .44255 Mdot
.44306 .50792 Mdot
.56238 .49137 Mdot
.53969 .51244 Mdot
.51845 .47807 Mdot
.5433 .44945 Mdot
.47507 .4778 Mdot
.45145 .45288 Mdot
.49358 .52089 Mdot
.53689 .55204 Mdot
.55382 .47699 Mdot
.52421 .52121 Mdot
.45014 .45874 Mdot
.50916 .50626 Mdot
.5137 .52266 Mdot
.46083 .54807 Mdot
.51148 .48809 Mdot
.55973 .46268 Mdot
.4528 .46512 Mdot
.44271 .46938 Mdot
.52091 .43848 Mdot
.50769 .49649 Mdot
.47262 .502 Mdot
.50266 .5544 Mdot
.50561 .52896 Mdot
.47819 .43976 Mdot
.46518 .49056 Mdot
.43482 .48176 Mdot
.49301 .49646 Mdot
.49144 .52774 Mdot
.52897 .51583 Mdot
.53828 .4953 Mdot
.46077 .46786 Mdot
.44192 .52838 Mdot
.48499 .44201 Mdot
.4424 .48414 Mdot
.54159 .50889 Mdot
.52232 .55675 Mdot
.5407 .48936 Mdot
.55842 .46549 Mdot
.50572 .53145 Mdot
.52617 .5429 Mdot
.48632 .48458 Mdot
.50093 .47056 Mdot
.44425 .53905 Mdot
.49761 .48593 Mdot
.55444 .54228 Mdot
.45302 .47568 Mdot
.48146 .46227 Mdot
.47527 .44303 Mdot
.49989 .52365 Mdot
.47649 .51748 Mdot
.48956 .55406 Mdot
.44995 .47516 Mdot
.52314 .55547 Mdot
.46341 .53975 Mdot
.4835 .54688 Mdot
.52704 .53224 Mdot
.43338 .48403 Mdot
.56307 .46727 Mdot
.45856 .53206 Mdot
.43125 .46304 Mdot
.48891 .48585 Mdot
.4708 .44404 Mdot
.47311 .48347 Mdot
.48312 .47786 Mdot
.51604 .46929 Mdot
.45977 .44896 Mdot
.5347 .44042 Mdot
.54073 .52818 Mdot
.51145 .48796 Mdot
.43373 .48476 Mdot
.5116 .43517 Mdot
.48035 .55057 Mdot
.45609 .45011 Mdot
.56836 .50263 Mdot
.43765 .4783 Mdot
.526 .43779 Mdot
.49117 .54836 Mdot
.42897 .47469 Mdot
.49389 .43567 Mdot
.55269 .49539 Mdot
.45694 .54752 Mdot
.50391 .43412 Mdot
.56826 .49473 Mdot
.52083 .50101 Mdot
.51675 .48589 Mdot
.47153 .53006 Mdot
.48748 .46893 Mdot
.53926 .45756 Mdot
.49273 .43565 Mdot
.4883 .44028 Mdot
.46754 .49392 Mdot
.49276 .51607 Mdot
.4455 .53536 Mdot
.52488 .45986 Mdot
.52673 .45538 Mdot
.46135 .53484 Mdot
.43442 .51076 Mdot
.47187 .49113 Mdot
.5346 .55169 Mdot
.55486 .52097 Mdot
.52366 .49841 Mdot
.44497 .46738 Mdot
.5187 .49721 Mdot
.5673 .47461 Mdot
.53631 .44036 Mdot
.47199 .46668 Mdot
.43712 .49173 Mdot
.51186 .45888 Mdot
.45133 .49839 Mdot
.50624 .4656 Mdot
.48939 .47785 Mdot
.5652 .52734 Mdot
.4927 .50735 Mdot
.48169 .43886 Mdot
.43903 .47526 Mdot
.54592 .54994 Mdot
.47472 .5302 Mdot
.5402 .5235 Mdot
.54105 .55329 Mdot
.51734 .48229 Mdot
.54353 .54751 Mdot
.45064 .54809 Mdot
.55644 .49298 Mdot
.52509 .49105 Mdot
.50303 .54484 Mdot
.43334 .50248 Mdot
.54815 .47242 Mdot
.50018 .44724 Mdot
.52523 .52489 Mdot
.4975 .50231 Mdot
.48166 .54626 Mdot
.46785 .44737 Mdot
.43968 .47493 Mdot
.51261 .48372 Mdot
.52471 .52428 Mdot
.52854 .5496 Mdot
.51502 .55825 Mdot
.49712 .55287 Mdot
.52828 .4624 Mdot
.52306 .51353 Mdot
.49118 .50477 Mdot
.4657 .5231 Mdot
.47718 .54691 Mdot
.5308 .51053 Mdot
.53455 .55688 Mdot
.50111 .47736 Mdot
.46287 .47339 Mdot
.5231 .47447 Mdot
.48097 .43912 Mdot
.55649 .48106 Mdot
.45896 .54005 Mdot
.45816 .54029 Mdot
.47442 .47567 Mdot
.43808 .50149 Mdot
.46328 .4457 Mdot
.50485 .49715 Mdot
.49871 .4914 Mdot
.4503 .45573 Mdot
.5108 .44204 Mdot
.4755 .54892 Mdot
.46663 .54962 Mdot
.52443 .4976 Mdot
.43901 .48905 Mdot
.55917 .46721 Mdot
.46738 .50691 Mdot
.54415 .46591 Mdot
.52205 .5296 Mdot
.464 .54002 Mdot
.46653 .47975 Mdot
.55525 .52976 Mdot
.5244 .55994 Mdot
.56659 .51199 Mdot
.49148 .49286 Mdot
.46301 .44413 Mdot
.54164 .54177 Mdot
.49391 .50815 Mdot
.5054 .54743 Mdot
.48794 .43996 Mdot
.45725 .48457 Mdot
.5258 .48378 Mdot
.49764 .55363 Mdot
.52601 .54625 Mdot
.47541 .48203 Mdot
.44007 .54664 Mdot
.52431 .4877 Mdot
.53659 .55526 Mdot
.53902 .5385 Mdot
.43836 .5469 Mdot
.4845 .49231 Mdot
.4947 .52956 Mdot
.5335 .55763 Mdot
.52365 .49303 Mdot
.53252 .55725 Mdot
.54066 .53853 Mdot
.5662 .52471 Mdot
.56883 .51421 Mdot
.48007 .4417 Mdot
.54036 .54844 Mdot
.5127 .51204 Mdot
.494 .51777 Mdot
.50233 .51353 Mdot
.4933 .5545 Mdot
.45782 .53876 Mdot
.56894 .49782 Mdot
.44093 .48594 Mdot
.45827 .53651 Mdot
.5385 .44479 Mdot
.50231 .45215 Mdot
.48661 .48276 Mdot
.5407 .46599 Mdot
.56562 .48066 Mdot
.51777 .52927 Mdot
.50877 .55519 Mdot
.52615 .53461 Mdot
.45579 .54289 Mdot
.4276 .49831 Mdot
.47008 .5132 Mdot
.47933 .47367 Mdot
.54197 .46766 Mdot
.51596 .55279 Mdot
.50227 .45562 Mdot
.55331 .47815 Mdot
.52918 .53576 Mdot
.48161 .53462 Mdot
.50907 .55002 Mdot
.43457 .47066 Mdot
.48884 .50128 Mdot
.43632 .50041 Mdot
.52027 .55268 Mdot
.5299 .55029 Mdot
.54875 .47002 Mdot
.51316 .55178 Mdot
.49121 .47819 Mdot
.54868 .47574 Mdot
.56433 .4781 Mdot
.51541 .5235 Mdot
.49768 .52116 Mdot
.54363 .49555 Mdot
.45247 .51653 Mdot
.51259 .49455 Mdot
.44201 .49755 Mdot
.51403 .50821 Mdot
.56547 .51329 Mdot
.51031 .51029 Mdot
.52369 .44036 Mdot
.44728 .47615 Mdot
.51164 .55656 Mdot
.55028 .48649 Mdot
.43517 .48329 Mdot
.45477 .50438 Mdot
.45782 .47584 Mdot
.50934 .50526 Mdot
.44033 .49288 Mdot
.50029 .55576 Mdot
.55346 .46982 Mdot
.49374 .43674 Mdot
.46645 .48907 Mdot
.51159 .46473 Mdot
.49842 .47156 Mdot
.53255 .55779 Mdot
.44202 .4791 Mdot
.52078 .558 Mdot
.45571 .50801 Mdot
.47353 .44314 Mdot
.50368 .55461 Mdot
.47046 .44339 Mdot
.53256 .48326 Mdot
.52597 .55851 Mdot
.52 .47912 Mdot
.56007 .49505 Mdot
.42497 .53619 Mdot
.54369 .55057 Mdot
.44729 .53524 Mdot
.48416 .49113 Mdot
.44395 .51911 Mdot
.5145 .53386 Mdot
.44405 .48533 Mdot
.55077 .46364 Mdot
.50716 .52338 Mdot
.56659 .52344 Mdot
.51346 .49083 Mdot
.45515 .4858 Mdot
.51511 .47627 Mdot
.52347 .44471 Mdot
.45998 .45028 Mdot
.5421 .46439 Mdot
.48655 .43824 Mdot
.49808 .5167 Mdot
.4929 .4703 Mdot
.49259 .44282 Mdot
.51964 .50702 Mdot
.56675 .51755 Mdot
.47522 .48444 Mdot
.55469 .48247 Mdot
.52591 .55351 Mdot
.46899 .48634 Mdot
.50999 .50246 Mdot
.54972 .53861 Mdot
.48904 .46657 Mdot
.46294 .54119 Mdot
.45983 .4998 Mdot
.56131 .49427 Mdot
.51034 .43765 Mdot
.4388 .49948 Mdot
.46325 .44892 Mdot
.56832 .49661 Mdot
.50834 .43771 Mdot
.53771 .44569 Mdot
.50369 .55389 Mdot
.49089 .50215 Mdot
.52569 .54605 Mdot
.49286 .54937 Mdot
.5185 .54399 Mdot
.45701 .47433 Mdot
.48937 .44277 Mdot
.44075 .49167 Mdot
.47845 .54914 Mdot
.55993 .48686 Mdot
.53741 .44389 Mdot
.44815 .54646 Mdot
.56065 .46523 Mdot
.45047 .45853 Mdot
.49304 .52585 Mdot
.54733 .49148 Mdot
.44241 .54678 Mdot
.47806 .44106 Mdot
.49051 .5226 Mdot
.49194 .44525 Mdot
.4843 .54787 Mdot
.56511 .52004 Mdot
.50064 .43453 Mdot
.56432 .49823 Mdot
.47056 .50647 Mdot
.51288 .4885 Mdot
.425 .48405 Mdot
.49775 .55321 Mdot
.44877 .49283 Mdot
.55615 .45768 Mdot
.43629 .47827 Mdot
.50227 .45593 Mdot
.54036 .46053 Mdot
.55213 .4983 Mdot
.44916 .54517 Mdot
.48112 .54633 Mdot
.44393 .47951 Mdot
.55159 .49622 Mdot
.46651 .54753 Mdot
.5662 .52492 Mdot
.47263 .54484 Mdot
.42827 .47545 Mdot
.55388 .52635 Mdot
.48117 .54765 Mdot
.48835 .48108 Mdot
.52079 .4879 Mdot
.46915 .47304 Mdot
.55611 .47588 Mdot
.46385 .54963 Mdot
.44752 .51831 Mdot
.44207 .49999 Mdot
.51233 .44651 Mdot
.4484 .47473 Mdot
.47355 .46737 Mdot
.51993 .50601 Mdot
.44226 .46838 Mdot
.50634 .48754 Mdot
.49549 .55333 Mdot
.45912 .47222 Mdot
.53802 .48681 Mdot
.42919 .48903 Mdot
.52101 .49973 Mdot
.42767 .52912 Mdot
.44558 .475 Mdot
.50124 .55464 Mdot
.45048 .52765 Mdot
.51297 .43589 Mdot
.51806 .52658 Mdot
.41965 .52478 Mdot
.51761 .53753 Mdot
.46058 .51749 Mdot
.50887 .47829 Mdot
.48755 .54444 Mdot
.48724 .50297 Mdot
.55831 .52984 Mdot
.52323 .53306 Mdot
.47739 .51307 Mdot
.50175 .51958 Mdot
.54426 .47654 Mdot
.44547 .5469 Mdot
.50575 .43549 Mdot
.51659 .4409 Mdot
.54334 .45623 Mdot
.44302 .48605 Mdot
.51157 .51597 Mdot
.51006 .45173 Mdot
.47092 .52975 Mdot
.55979 .48784 Mdot
.45531 .50086 Mdot
.50458 .55479 Mdot
.56784 .49491 Mdot
.5341 .55182 Mdot
.49123 .48489 Mdot
.54894 .48181 Mdot
.51248 .54319 Mdot
.51188 .49034 Mdot
.44972 .4842 Mdot
.42252 .53047 Mdot
.50717 .47814 Mdot
.534 .44064 Mdot
.50091 .48338 Mdot
.56517 .46823 Mdot
.5182 .53403 Mdot
.56636 .50892 Mdot
.54266 .4984 Mdot
.48538 .45665 Mdot
.5528 .54352 Mdot
.47995 .54496 Mdot
.54886 .53154 Mdot
.53151 .55698 Mdot
.52811 .45415 Mdot
.51253 .48699 Mdot
.45709 .48116 Mdot
.48865 .5273 Mdot
.50487 .49292 Mdot
.4461 .4874 Mdot
.47674 .5494 Mdot
.50835 .55547 Mdot
.44781 .45552 Mdot
.43301 .52817 Mdot
.53632 .51273 Mdot
.48034 .44232 Mdot
.43499 .46497 Mdot
.47173 .54534 Mdot
.43892 .54371 Mdot
.45606 .48119 Mdot
.55469 .51477 Mdot
.46018 .49583 Mdot
.56911 .51659 Mdot
.46719 .48095 Mdot
.50015 .49097 Mdot
.41917 .49317 Mdot
.49006 .55136 Mdot
.47183 .53485 Mdot
.55779 .53911 Mdot
.47973 .54971 Mdot
.51071 .52996 Mdot
.49135 .53542 Mdot
.43584 .4797 Mdot
.49815 .52886 Mdot
.53381 .44112 Mdot
.56234 .48498 Mdot
.47104 .55096 Mdot
.52418 .50333 Mdot
.46718 .48252 Mdot
.5682 .51121 Mdot
.53716 .46508 Mdot
.5072 .52673 Mdot
.50039 .51579 Mdot
.51192 .5541 Mdot
.54025 .52137 Mdot
.45601 .4697 Mdot
.44278 .48206 Mdot
.5664 .49274 Mdot
.42288 .52428 Mdot
.42585 .53 Mdot
.46267 .54011 Mdot
.52776 .43879 Mdot
.51067 .50004 Mdot
.51889 .54043 Mdot
.54567 .55016 Mdot
.49727 .54869 Mdot
.47467 .4625 Mdot
.56873 .51734 Mdot
.46932 .48902 Mdot
.45056 .49016 Mdot
.44095 .54052 Mdot
.43998 .54607 Mdot
.47873 .48795 Mdot
.5657 .49135 Mdot
.56224 .47579 Mdot
.47712 .54624 Mdot
.48799 .5059 Mdot
.48673 .48787 Mdot
.553 .51982 Mdot
.52955 .49599 Mdot
.55354 .49426 Mdot
.45824 .45453 Mdot
.50896 .49856 Mdot
.51307 .44943 Mdot
.50459 .4913 Mdot
.51788 .53828 Mdot
.48494 .50057 Mdot
.53097 .55736 Mdot
.48964 .5543 Mdot
.56507 .52385 Mdot
.54198 .46321 Mdot
.47114 .44288 Mdot
.52265 .55068 Mdot
.48726 .55141 Mdot
.48299 .44274 Mdot
.5377 .52032 Mdot
.49674 .55553 Mdot
.53002 .55 Mdot
.43608 .45933 Mdot
.45725 .4931 Mdot
.42424 .47663 Mdot
.52435 .47054 Mdot
.52588 .54104 Mdot
.42914 .50149 Mdot
.50105 .54584 Mdot
.4495 .46504 Mdot
.515 .441 Mdot
.54838 .51601 Mdot
.50843 .43887 Mdot
.52988 .54052 Mdot
.46107 .4654 Mdot
.53559 .52815 Mdot
.45704 .54741 Mdot
.51313 .47345 Mdot
.51911 .46363 Mdot
.46794 .4546 Mdot
.56662 .47999 Mdot
.47516 .5516 Mdot
.48115 .47629 Mdot
.54586 .47302 Mdot
.50453 .55544 Mdot
.56252 .52168 Mdot
.49706 .49903 Mdot
.44956 .47752 Mdot
.52413 .52681 Mdot
.47511 .54147 Mdot
.50533 .48663 Mdot
.5645 .52776 Mdot
.49818 .52954 Mdot
.56898 .51161 Mdot
.5586 .46911 Mdot
.46932 .47519 Mdot
.50433 .53443 Mdot
.53367 .45324 Mdot
.44031 .49313 Mdot
.44506 .46101 Mdot
.50189 .49185 Mdot
.53729 .45081 Mdot
.41853 .48018 Mdot
.53792 .55587 Mdot
.50651 .43462 Mdot
.42014 .47495 Mdot
.5172 .55823 Mdot
.45826 .54443 Mdot
.43132 .50325 Mdot
.51653 .51408 Mdot
.44991 .51121 Mdot
.51689 .46685 Mdot
.51977 .50934 Mdot
.49362 .55216 Mdot
.5276 .48631 Mdot
.41469 .52013 Mdot
.4433 .53973 Mdot
.49584 .5534 Mdot
.46519 .4572 Mdot
.45063 .53464 Mdot
.45444 .48448 Mdot
.52416 .48537 Mdot
.46626 .48474 Mdot
.45803 .54813 Mdot
.56246 .48021 Mdot
.47983 .4781 Mdot
.44964 .45048 Mdot
.43753 .49387 Mdot
.48229 .46561 Mdot
.45583 .47735 Mdot
.46806 .54932 Mdot
.48475 .47663 Mdot
.47647 .54527 Mdot
.48192 .51176 Mdot
.50436 .53932 Mdot
.49422 .52587 Mdot
.4664 .47715 Mdot
.49701 .49248 Mdot
.46436 .54279 Mdot
.56022 .47818 Mdot
.49529 .51439 Mdot
.52855 .48103 Mdot
.50652 .53737 Mdot
.4337 .4579 Mdot
.51867 .55577 Mdot
.47778 .44209 Mdot
.43953 .48543 Mdot
.56318 .50853 Mdot
.46036 .51028 Mdot
.46456 .54608 Mdot
.45593 .54338 Mdot
.50027 .43726 Mdot
.49226 .45307 Mdot
.41704 .52277 Mdot
.51897 .50395 Mdot
.50764 .55493 Mdot
.51768 .52577 Mdot
.50218 .49672 Mdot
.5665 .48182 Mdot
.45121 .53912 Mdot
.56309 .51581 Mdot
.47115 .54858 Mdot
.51093 .51249 Mdot
.56234 .47164 Mdot
.50786 .43638 Mdot
.4915 .43912 Mdot
.48601 .54933 Mdot
.51332 .50295 Mdot
.49423 .46674 Mdot
.46709 .49874 Mdot
.54414 .53893 Mdot
.46634 .54714 Mdot
.43736 .54497 Mdot
.49966 .55588 Mdot
.53823 .44121 Mdot
.53407 .50012 Mdot
.45466 .4889 Mdot
.43579 .50176 Mdot
.48144 .44665 Mdot
.52997 .51208 Mdot
.4383 .52461 Mdot
.52142 .51659 Mdot
.48877 .43779 Mdot
.55256 .51774 Mdot
.4625 .44476 Mdot
.55587 .51585 Mdot
.55722 .52863 Mdot
.44467 .48696 Mdot
.5659 .52139 Mdot
.46598 .49257 Mdot
.53735 .4877 Mdot
.55265 .45423 Mdot
.48275 .44306 Mdot
.47899 .54877 Mdot
.44714 .48659 Mdot
.52056 .48173 Mdot
.48563 .54835 Mdot
.52268 .54772 Mdot
.4256 .51011 Mdot
.51834 .52568 Mdot
.51254 .4358 Mdot
.52015 .51945 Mdot
.45971 .54164 Mdot
.44325 .48617 Mdot
.55438 .49548 Mdot
.45719 .46048 Mdot
.53167 .48623 Mdot
.49443 .55223 Mdot
.56573 .49927 Mdot
.47206 .48684 Mdot
.52229 .50239 Mdot
.53789 .44112 Mdot
.43708 .49236 Mdot
.48916 .55071 Mdot
.41984 .48681 Mdot
.49578 .52908 Mdot
.54235 .52372 Mdot
.55175 .51733 Mdot
.48418 .47615 Mdot
.56388 .5281 Mdot
.55658 .52835 Mdot
.56912 .51351 Mdot
.46046 .47595 Mdot
.48981 .4869 Mdot
.45783 .49328 Mdot
.50393 .4505 Mdot
.45487 .52446 Mdot
.52488 .50557 Mdot
.48184 .43876 Mdot
.48052 .54961 Mdot
.45493 .47731 Mdot
.45332 .45835 Mdot
.54305 .44775 Mdot
.56084 .46907 Mdot
.51817 .4447 Mdot
.48095 .44389 Mdot
.508 .45072 Mdot
.45443 .47498 Mdot
.52582 .47468 Mdot
.5376 .52978 Mdot
.43607 .54027 Mdot
.55805 .53851 Mdot
.52931 .55008 Mdot
.54481 .45138 Mdot
.51364 .49105 Mdot
.4781 .49225 Mdot
.44554 .54518 Mdot
.51015 .50382 Mdot
.50367 .52865 Mdot
.53146 .44919 Mdot
.51403 .49078 Mdot
.49066 .50572 Mdot
.50739 .43818 Mdot
.43568 .50624 Mdot
.54852 .45849 Mdot
.53881 .506 Mdot
.42531 .50506 Mdot
.53331 .51408 Mdot
.47248 .55074 Mdot
.43967 .52032 Mdot
.48031 .43924 Mdot
.56817 .51299 Mdot
.47635 .54931 Mdot
.50538 .55579 Mdot
.5119 .5118 Mdot
.49639 .54303 Mdot
.45273 .4789 Mdot
.50974 .4786 Mdot
.46363 .54956 Mdot
.56524 .52459 Mdot
.49401 .55433 Mdot
.54259 .54424 Mdot
.50972 .51975 Mdot
.41778 .52495 Mdot
.52218 .5411 Mdot
.50887 .4733 Mdot
.44836 .48397 Mdot
.54374 .4455 Mdot
.49264 .55378 Mdot
.47188 .45309 Mdot
.48848 .48988 Mdot
.55355 .45556 Mdot
.45854 .51224 Mdot
.4894 .5205 Mdot
.43973 .47082 Mdot
.51303 .53039 Mdot
.5526 .5135 Mdot
.52117 .49652 Mdot
.52719 .49831 Mdot
.45176 .53796 Mdot
.53812 .49504 Mdot
.53144 .55268 Mdot
.53264 .51148 Mdot
.4461 .45662 Mdot
.51641 .51536 Mdot
.54278 .44536 Mdot
.51796 .47148 Mdot
.50201 .54512 Mdot
.5404 .55022 Mdot
.51758 .44894 Mdot
.48853 .44096 Mdot
.51781 .49182 Mdot
.4889 .53648 Mdot
.53279 .52925 Mdot
.50381 .483 Mdot
.52258 .44257 Mdot
.56678 .5083 Mdot
.49057 .55213 Mdot
.4971 .43574 Mdot
.45884 .48245 Mdot
.49835 .49714 Mdot
.5404 .55403 Mdot
.51584 .4438 Mdot
.4988 .43439 Mdot
.52019 .51107 Mdot
.50376 .54352 Mdot
.51113 .48297 Mdot
.47218 .44764 Mdot
.51572 .51982 Mdot
.53403 .49822 Mdot
.49638 .44684 Mdot
.45985 .45178 Mdot
.53935 .53048 Mdot
.50815 .50252 Mdot
.43437 .48269 Mdot
.46697 .48173 Mdot
.56066 .53376 Mdot
.49967 .43475 Mdot
.53144 .43868 Mdot
.48138 .55176 Mdot
.49734 .55281 Mdot
.5597 .48445 Mdot
.51932 .51289 Mdot
.4621 .46369 Mdot
.48188 .55063 Mdot
.56069 .52597 Mdot
.56465 .52579 Mdot
.54906 .48399 Mdot
.50776 .55512 Mdot
.42635 .49658 Mdot
.51659 .49699 Mdot
.41462 .51441 Mdot
.54345 .52566 Mdot
.52482 .51841 Mdot
.43395 .50882 Mdot
.52667 .44147 Mdot
.4454 .47742 Mdot
.55116 .54351 Mdot
.5322 .44137 Mdot
.49845 .441 Mdot
.50947 .50902 Mdot
.44718 .45033 Mdot
.48626 .48576 Mdot
.47354 .48728 Mdot
.55919 .49567 Mdot
.56415 .46711 Mdot
.53787 .49723 Mdot
.45304 .48444 Mdot
.50502 .43645 Mdot
.51883 .45323 Mdot
.50002 .55393 Mdot
.46244 .54905 Mdot
.47807 .44195 Mdot
.53993 .54851 Mdot
.44213 .47839 Mdot
.56586 .51086 Mdot
.50864 .50715 Mdot
.49253 .47961 Mdot
.41491 .50792 Mdot
.42365 .53428 Mdot
.4989 .52135 Mdot
.51513 .54506 Mdot
.47392 .54358 Mdot
.54744 .54271 Mdot
.56907 .50985 Mdot
.49666 .55289 Mdot
.52848 .502 Mdot
.44148 .47543 Mdot
.46847 .51264 Mdot
.47774 .5486 Mdot
.49005 .53458 Mdot
.51528 .55864 Mdot
.45026 .49713 Mdot
.444 .48924 Mdot
.46007 .46529 Mdot
.51761 .43797 Mdot
.56756 .47845 Mdot
.54911 .45298 Mdot
.41893 .5245 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go
00001_ooool3o`000?ooooooB?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04
odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol0003o
oooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`3o
ooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007
ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<
ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`2Nooooo`Go0000Y?ooool001kooooo00?o0000ooooooooool0V_ooool<o`000003
ooooool0003o000009kooooo000Nooooo`03o`000?oooooooooo09Oooooo5_l0002Jooooo`007_oo
ool00ol0003oooooooooo`2Booooo`;o000000?oooooo`000?l000002Ol000000ooooooo0000o`00
000:o`0009[ooooo000Nooooo`03o`000?oooooooooo09;ooooo3_l00002ooooo`go0000V?ooool0
01kooooo00?o0000ooooooooool0SOooool=o`0000;ooooo3?l000000ooooooo0000o`000004o`00
09Sooooo000Nooooo`;o0000S?ooool<o`0000Gooooo2ol00002ooooo`Oo0000Uoooool001kooooo
00?o0000ooooooooool0Roooool8o`000004ooooool0003o0000o`0000?ooooo1?l000000ooooooo
0000o`000003o`000003ooooool0003o000000_o0000UOooool001kooooo00?o0000ooooooooool0
ROooool3o`000003ooooool0003o000000Oo00001?ooool2o`0000?ooooo0_l000001?oooooo0000
o`000?l00002ooooo`co0000U?ooool001kooooo00?o0000ooooooooool0ROooool3o`000003oooo
ool0003o000000Ko000000?oooooo`000?l000000_l00003ooooo`;o00000oooool3o`0000;ooooo
2Ol000001?oooooo0000o`000?l0002Cooooo`007_ooool00ol0003oooooooooo`28ooooo`?o0000
0_ooool7o`0000;ooooo1Ol00002ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000
o`000003o`000003ooooool0003o000000Oo0000Toooool001kooooo00?o0000ooooooooool0R?oo
ool3o`000003ooooool0003o000000Ko000000Goooooo`000?l0003o0000ooooo`06o`000003oooo
ool0003o000000Go00001?ooool;o`00097ooooo000Nooooo`03o`000?oooooooooo08Wooooo2ol0
00001?oooooo0000o`000?l00002ooooo`Oo00000_ooool5o`0000Cooooo2_l0002Aooooo`007_oo
ool00ol0003oooooooooo`24ooooo`;o000000?oooooo`000?l000004Ol00002ooooo`go00001?oo
ool9o`00097ooooo000Nooooo`03o`000?oooooooooo08Cooooo1_l000000ooooooo0000o`00000@
o`0000;ooooo2ol00003ooooo`Wo0000TOooool001kooooo00?o0000ooooooooool0Q?oooolJo`00
0003ooooool0003o000000Ko000000?oooooo`000?l000000oooool9o`00097ooooo000Nooooo`03
o`000?oooooooooo08Cooooo1?l000000ooooooo0000o`00000Co`000003ooooool0003o000000_o
00000_ooool8o`00097ooooo000Nooooo`03o`000?oooooooooo08Cooooo1?l000000ooooooo0000
o`00000Ro`000003ooooool0003o000000Oo0000T?ooool001kooooo00?o0000ooooooooool0Q?oo
ool2o`000003ooooool0003o000002Go000000Coooooo`000?l0003ooooo1Ol0002@ooooo`007_oo
ool00ol0003oooooooooo`24ooooobGo000000?oooooo`000?l000001?l000000ooooooo0000o`00
0004o`00093ooooo000Nooooo`03o`000?oooooooooo08Cooooo1?l000000ooooooo0000o`000002
o`000004ooooool0003o0000oooooaWo000000?oooooo`000?l000002_l0002@ooooo`007_ooool0
0ol0003oooooooooo`26ooooo`?o000000?oooooo`000?l000001ol000000ooooooo0000o`000004
oooooago0000T?ooool001kooooo0_l00028ooooo`co000000?oooooo`000?l000000_l00002oooo
oaCo000000Goooooo`000?l0003o0000ooooo`04o`00093ooooo000Nooooo`03o`000?oooooooooo
08;ooooo0_l00002ooooo`So00000_ooool3o`0000?ooooo0_l00002ooooo`Ko000000?oooooo`00
0?l000002Ol00009ooooo`;o0000T?ooool001kooooo00?o0000ooooooooool0P_ooool3o`000003
ooooool0003o000000Ko00000_ooool2o`0000;ooooo0ol00003ooooo`Co00000oooool8o`0000;o
oooo0ol00005ooooo`Co0000T?ooool001kooooo00?o0000ooooooooool0Poooool2o`000004oooo
ool0003o0000ooooo`ko00000_ooool5o`000003ooooool0003o000000Ko000000?oooooo`000?l0
00001?l00005ooooo`Co0000T?ooool001kooooo00?o0000ooooooooool0Poooool5o`000003oooo
ool0003o000000?ooooo0_l000000ooooooo0000o`000008o`0000;ooooo1?l000000ooooooo0000
o`000009o`0000?ooooo0_l00002ooooo`?o0000T?ooool001kooooo00?o0000ooooooooool0Pooo
ool3o`0000Wooooo2_l00003ooooo`Go000000?oooooo`000?l000002Ol000000ooooooo0000o`00
0007o`00093ooooo000Nooooo`03o`000?oooooooooo08?ooooo0_l00006ooooo`Ko000000?ooooo
o`000?l000000oooool2o`0000;ooooo1_l000000ooooooo0000o`000009o`000003ooooool0003o
000000Oo0000T?ooool001kooooo00?o0000ooooooooool0Poooool4o`0000Cooooo1?l000001?oo
oooo0000o`000?ooool2o`0000Kooooo3_l00002ooooo`?o00000_ooool2o`000004ooooool0003o
0000o`00097ooooo000Nooooo`03o`000?oooooooooo08?ooooo1?l00003ooooo`;o00001?ooool2
o`000003ooooool0003o000000Kooooo3_l00003ooooo`?o000000?oooooo`000?l000001?l0002A
ooooo`007_ooool00ol0003oooooooooo`24ooooo`ko00000oooool3o`0000?ooooo5?l000000ooo
oooo0000o`000004o`00097ooooo000Nooooo`03o`000?oooooooooo08Gooooo2ol000000ooooooo
0000o`000002ooooo`?o00001?oooolIo`0009;ooooo000Nooooo`03o`000?oooooooooo08Kooooo
0_l00003ooooo`Go000000Goooooo`000?l0003o0000ooooo`02o`000004ooooool0003o0000oooo
o`?o000000?oooooo`000?l000003?l000001Ooooooo0000o`000?l0003ooooo00?o0000T_ooool0
01kooooo00?o0000ooooooooool0Q_ooool3o`0000?ooooo2?l000001?oooooo0000o`000?ooool2
o`000003ooooool0003o000000go000000?oooooo`000?l000002?l0002Booooo`007_ooool00ol0
003oooooooooo`27ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000004o`00
0003ooooool0003o000000;o00000oooool2o`000005ooooool0003o0000o`000?ooool01_l00000
0ooooooo0000o`000006o`0009Cooooo000Nooooo`03o`000?oooooooooo08[ooooo4_l000000ooo
oooo0000o`00000;o`0000;ooooo1_l0002Eooooo`007_ooool00ol0003oooooooooo`2:ooooobSo
0000UOooool001kooooo0_l0002;oooooa_o000000?oooooo`000?l000001ol0002Hooooo`007_oo
ool00ol0003oooooooooo`2Boooooago0000V?ooool001kooooo00?o0000ooooooooool0VOoooolE
o`0009Wooooo000Nooooo`03o`000?oooooooooo09gooooo4?l0002Jooooo`007_ooool00ol0003o
ooooooooo`2Sooooo`Ko0000W_ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^
k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_oo
ool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41002ooo
ool01Ol0003ooooooooooooooooo000000Kooooo0ol0003oooooodSooooo0003ooooo`05o`000?oo
ooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o0000oooooooo
ool0oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0
003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooo
oooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0oooooom8oooo
o`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0
003oooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<
c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000oooo
ooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`3oooooodSooooo0003oooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodSooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooo
oonHV9So<S8b00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol0003ooooooooo
oooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj
^_l@41001_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0oooooom8
ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVY
Z@06ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?oo
ooooBOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001Cooooo1?l000000ol@413oooooooooo`03ooooo`03
o`000?oooooooooo0?ooooooB?ooool001Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3oooooodSooooo000Fooooo`03o`000?oooooooooo00Gooooo0ol0003oooooodSooooo000F
ooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@oooo
o`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?oooooo
D?ooool001Cooooo00?oEEEEofIVI_l00000oooooomBooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.45116 .54848 Mdot
.52371 .53313 Mdot
.58383 .5113 Mdot
.51452 .53457 Mdot
.49836 .53507 Mdot
.4295 .52735 Mdot
.58483 .51958 Mdot
.48496 .55103 Mdot
.48667 .4214 Mdot
.44105 .46068 Mdot
.44331 .52413 Mdot
.51579 .49145 Mdot
.43293 .5331 Mdot
.53916 .57066 Mdot
.54556 .43119 Mdot
.45123 .45951 Mdot
.5104 .55554 Mdot
.40741 .47428 Mdot
.43392 .46172 Mdot
.53181 .46951 Mdot
.50484 .56181 Mdot
.46439 .43325 Mdot
.47567 .52826 Mdot
.46037 .56097 Mdot
.48055 .55632 Mdot
.49877 .48214 Mdot
.53759 .4293 Mdot
.42732 .46648 Mdot
.50356 .52616 Mdot
.43951 .54073 Mdot
.56312 .53226 Mdot
.51315 .5461 Mdot
.48864 .48693 Mdot
.56505 .47949 Mdot
.43615 .53681 Mdot
.57863 .49734 Mdot
.48678 .47681 Mdot
.51281 .4243 Mdot
.48706 .53153 Mdot
.51385 .4846 Mdot
.45918 .47005 Mdot
.51706 .45437 Mdot
.55457 .51852 Mdot
.50273 .49918 Mdot
.50831 .55068 Mdot
.4676 .46358 Mdot
.54936 .56864 Mdot
.56286 .5428 Mdot
.57262 .509 Mdot
.44699 .43774 Mdot
.49333 .53069 Mdot
.43267 .53626 Mdot
.50578 .52451 Mdot
.48912 .5396 Mdot
.4454 .45552 Mdot
.48635 .46921 Mdot
.53969 .50142 Mdot
.44145 .54361 Mdot
.50597 .54585 Mdot
.54442 .50154 Mdot
.46795 .45578 Mdot
.47346 .4703 Mdot
.55278 .47404 Mdot
.45195 .46163 Mdot
.49305 .52139 Mdot
.47658 .42372 Mdot
.53758 .55331 Mdot
.4736 .46246 Mdot
.5098 .46718 Mdot
.44981 .45686 Mdot
.58357 .47086 Mdot
.50477 .54017 Mdot
.53875 .49256 Mdot
.51288 .51633 Mdot
.44639 .55045 Mdot
.55833 .44501 Mdot
.49146 .46057 Mdot
.4096 .4818 Mdot
.58882 .48539 Mdot
.44967 .50028 Mdot
.52248 .43178 Mdot
.47997 .55076 Mdot
.49492 .56098 Mdot
.46275 .46899 Mdot
.557 .47548 Mdot
.50959 .51923 Mdot
.56921 .46631 Mdot
.47593 .46708 Mdot
.52013 .48616 Mdot
.40865 .51148 Mdot
.50002 .5192 Mdot
.46173 .45964 Mdot
.54566 .44415 Mdot
.46078 .43094 Mdot
.58816 .5134 Mdot
.47096 .44889 Mdot
.47928 .46701 Mdot
.55745 .54322 Mdot
.55336 .56669 Mdot
.53997 .5085 Mdot
.5631 .45947 Mdot
.54743 .4484 Mdot
.4991 .54592 Mdot
.44555 .43004 Mdot
.50232 .42114 Mdot
.48554 .48228 Mdot
.5555 .5624 Mdot
.49633 .52217 Mdot
.54143 .54113 Mdot
.4609 .45853 Mdot
.46214 .55954 Mdot
.50582 .54021 Mdot
.52419 .51286 Mdot
.48251 .42241 Mdot
.51929 .56675 Mdot
.42627 .52974 Mdot
.52394 .42402 Mdot
.42111 .46298 Mdot
.57568 .53449 Mdot
.54274 .44208 Mdot
.42659 .50396 Mdot
.50249 .48626 Mdot
.4411 .45873 Mdot
.56974 .52085 Mdot
.51935 .54618 Mdot
.46982 .42398 Mdot
.45559 .55755 Mdot
.50016 .48443 Mdot
.50081 .49179 Mdot
.4525 .4683 Mdot
.43783 .50346 Mdot
.51112 .56127 Mdot
.45882 .56036 Mdot
.56795 .49259 Mdot
.46335 .53734 Mdot
.47018 .56788 Mdot
.44307 .42431 Mdot
.50033 .50881 Mdot
.52776 .48116 Mdot
.51674 .50594 Mdot
.49816 .52143 Mdot
.50562 .4218 Mdot
.4947 .48708 Mdot
.51066 .53345 Mdot
.48702 .4952 Mdot
.46052 .45745 Mdot
.44706 .54581 Mdot
.47944 .4433 Mdot
.51926 .5686 Mdot
.57022 .51296 Mdot
.55929 .48267 Mdot
.42539 .46773 Mdot
.49967 .52743 Mdot
.5282 .57419 Mdot
.4388 .51085 Mdot
.45081 .45885 Mdot
.47234 .47155 Mdot
.45012 .55275 Mdot
.49284 .461 Mdot
.49273 .50681 Mdot
.57038 .44796 Mdot
.50382 .4585 Mdot
.41979 .49966 Mdot
.44041 .45382 Mdot
.52984 .49328 Mdot
.52961 .50565 Mdot
.51331 .42193 Mdot
.50725 .4303 Mdot
.48779 .43611 Mdot
.49634 .42243 Mdot
.43645 .4791 Mdot
.56675 .51293 Mdot
.53086 .52959 Mdot
.52929 .49069 Mdot
.5795 .46166 Mdot
.48389 .47243 Mdot
.4646 .44455 Mdot
.49231 .51077 Mdot
.51345 .58217 Mdot
.56535 .49777 Mdot
.51408 .53205 Mdot
.46399 .4501 Mdot
.50758 .51101 Mdot
.50584 .52614 Mdot
.43003 .53183 Mdot
.51785 .49584 Mdot
.58029 .48134 Mdot
.46756 .45453 Mdot
.46074 .42978 Mdot
.54977 .44379 Mdot
.5102 .50133 Mdot
.47126 .48303 Mdot
.47036 .56532 Mdot
.49852 .52556 Mdot
.50304 .42231 Mdot
.46536 .47422 Mdot
.44779 .43799 Mdot
.49435 .49119 Mdot
.48893 .51698 Mdot
.52016 .52947 Mdot
.53866 .51348 Mdot
.47468 .45949 Mdot
.43067 .5002 Mdot
.50487 .43538 Mdot
.44712 .45993 Mdot
.53433 .52666 Mdot
.50212 .56802 Mdot
.54448 .50819 Mdot
.57665 .48499 Mdot
.49771 .52802 Mdot
.50765 .5523 Mdot
.49029 .48031 Mdot
.51419 .47754 Mdot
.42637 .51491 Mdot
.50297 .48641 Mdot
.54038 .57491 Mdot
.4643 .45974 Mdot
.49582 .46384 Mdot
.50404 .42182 Mdot
.49654 .5169 Mdot
.47557 .50017 Mdot
.44762 .54984 Mdot
.46166 .45801 Mdot
.49376 .57761 Mdot
.45059 .53116 Mdot
.46839 .5447 Mdot
.51178 .54284 Mdot
.43807 .45746 Mdot
.58176 .48698 Mdot
.45326 .51272 Mdot
.43795 .44355 Mdot
.4924 .48207 Mdot
.49593 .4209 Mdot
.47697 .47438 Mdot
.49144 .4758 Mdot
.52982 .48207 Mdot
.48056 .42307 Mdot
.56468 .45045 Mdot
.52571 .54567 Mdot
.51788 .4957 Mdot
.43797 .45792 Mdot
.54878 .43301 Mdot
.44964 .55145 Mdot
.4753 .42382 Mdot
.58247 .53316 Mdot
.44595 .45507 Mdot
.55798 .44356 Mdot
.47613 .54659 Mdot
.43689 .45254 Mdot
.52517 .42336 Mdot
.55323 .51578 Mdot
.42701 .5293 Mdot
.53873 .42829 Mdot
.58517 .52356 Mdot
.52062 .51347 Mdot
.52447 .49686 Mdot
.46937 .51434 Mdot
.50063 .47186 Mdot
.55887 .47501 Mdot
.52557 .42293 Mdot
.51092 .43162 Mdot
.46646 .4762 Mdot
.49231 .50593 Mdot
.43158 .51053 Mdot
.54213 .47543 Mdot
.54585 .47065 Mdot
.45683 .51777 Mdot
.42673 .48037 Mdot
.47172 .47669 Mdot
.50839 .58054 Mdot
.54402 .54232 Mdot
.52438 .51246 Mdot
.46422 .42837 Mdot
.52074 .50851 Mdot
.58593 .49582 Mdot
.5683 .4493 Mdot
.48542 .46452 Mdot
.43748 .46315 Mdot
.52862 .47033 Mdot
.44818 .47343 Mdot
.52096 .4749 Mdot
.49866 .47848 Mdot
.55862 .55608 Mdot
.4931 .50001 Mdot
.50912 .4222 Mdot
.45589 .43353 Mdot
.52768 .58179 Mdot
.47282 .51549 Mdot
.52702 .541 Mdot
.522 .57744 Mdot
.52647 .49396 Mdot
.52438 .56969 Mdot
.42172 .52706 Mdot
.55908 .5141 Mdot
.52966 .50605 Mdot
.49005 .54314 Mdot
.42894 .4715 Mdot
.56104 .49252 Mdot
.51969 .45105 Mdot
.5132 .5362 Mdot
.49831 .49971 Mdot
.46669 .54376 Mdot
.49667 .42148 Mdot
.45096 .45466 Mdot
.52137 .49289 Mdot
.51307 .53533 Mdot
.49166 .57348 Mdot
.4881 .57419 Mdot
.47694 .55578 Mdot
.5447 .47917 Mdot
.51624 .52529 Mdot
.49199 .49669 Mdot
.46304 .50273 Mdot
.45477 .54634 Mdot
.52415 .52547 Mdot
.51467 .57508 Mdot
.51195 .48332 Mdot
.47463 .46419 Mdot
.53487 .48951 Mdot
.50593 .42331 Mdot
.56611 .50203 Mdot
.44269 .52676 Mdot
.44042 .52585 Mdot
.48435 .47128 Mdot
.43351 .47221 Mdot
.4834 .42399 Mdot
.50714 .50015 Mdot
.5018 .49108 Mdot
.46973 .424 Mdot
.53543 .44655 Mdot
.44577 .54595 Mdot
.43215 .53547 Mdot
.52545 .51204 Mdot
.44075 .46186 Mdot
.57635 .487 Mdot
.46506 .48496 Mdot
.56016 .48495 Mdot
.50888 .53822 Mdot
.44551 .53182 Mdot
.47479 .47001 Mdot
.54183 .55149 Mdot
.50206 .57696 Mdot
.56885 .55209 Mdot
.49298 .48723 Mdot
.4797 .42769 Mdot
.5225 .56067 Mdot
.49411 .50166 Mdot
.49037 .54773 Mdot
.51095 .43068 Mdot
.46242 .46869 Mdot
.53395 .49899 Mdot
.45615 .55786 Mdot
.50666 .5565 Mdot
.48043 .47458 Mdot
.4168 .52368 Mdot
.53082 .50231 Mdot
.51553 .58207 Mdot
.52055 .55507 Mdot
.41283 .5227 Mdot
.48502 .48259 Mdot
.49091 .52014 Mdot
.51339 .57636 Mdot
.52725 .50719 Mdot
.5107 .58173 Mdot
.52225 .55606 Mdot
.56201 .55396 Mdot
.57587 .54658 Mdot
.50162 .42966 Mdot
.51611 .58125 Mdot
.50832 .51796 Mdot
.4932 .50792 Mdot
.49976 .51163 Mdot
.45193 .55452 Mdot
.44782 .5255 Mdot
.57927 .52375 Mdot
.44451 .46052 Mdot
.45124 .52033 Mdot
.56592 .45784 Mdot
.52 .45944 Mdot
.49168 .47958 Mdot
.55604 .48459 Mdot
.58882 .50619 Mdot
.50587 .53501 Mdot
.47397 .56862 Mdot
.51027 .54409 Mdot
.43122 .52524 Mdot
.42644 .46696 Mdot
.46813 .49218 Mdot
.49028 .47249 Mdot
.55657 .48651 Mdot
.47635 .56956 Mdot
.51898 .46387 Mdot
.56415 .49887 Mdot
.51243 .54675 Mdot
.47809 .5229 Mdot
.49202 .55251 Mdot
.44493 .45152 Mdot
.49 .49182 Mdot
.43232 .47062 Mdot
.48284 .57241 Mdot
.49584 .57507 Mdot
.56309 .4901 Mdot
.46956 .56501 Mdot
.50049 .47943 Mdot
.55975 .49599 Mdot
.57686 .49919 Mdot
.50674 .52812 Mdot
.49563 .51303 Mdot
.54314 .51451 Mdot
.4463 .48984 Mdot
.51593 .5024 Mdot
.43909 .47012 Mdot
.51108 .51588 Mdot
.56453 .53843 Mdot
.50693 .51497 Mdot
.54979 .44877 Mdot
.45787 .45691 Mdot
.48121 .57154 Mdot
.55553 .50651 Mdot
.4399 .4571 Mdot
.4506 .47896 Mdot
.46886 .46272 Mdot
.50811 .51027 Mdot
.44014 .46609 Mdot
.45559 .55641 Mdot
.56855 .49024 Mdot
.52979 .42464 Mdot
.4672 .47409 Mdot
.52678 .47609 Mdot
.51127 .47766 Mdot
.51163 .57893 Mdot
.45007 .45684 Mdot
.49988 .57025 Mdot
.45113 .48256 Mdot
.49117 .43391 Mdot
.47065 .56589 Mdot
.48658 .43454 Mdot
.54 .50046 Mdot
.50257 .57841 Mdot
.53047 .49225 Mdot
.56204 .51664 Mdot
.40316 .50774 Mdot
.52501 .57416 Mdot
.43367 .51123 Mdot
.48477 .48197 Mdot
.43506 .49071 Mdot
.50194 .53658 Mdot
.44844 .46187 Mdot
.56915 .48323 Mdot
.50112 .52179 Mdot
.56396 .55495 Mdot
.51862 .49941 Mdot
.45948 .46851 Mdot
.52643 .48778 Mdot
.54612 .45616 Mdot
.48323 .42169 Mdot
.55859 .48302 Mdot
.51252 .42527 Mdot
.49647 .51009 Mdot
.50596 .47477 Mdot
.5128 .44038 Mdot
.51649 .51814 Mdot
.56607 .54384 Mdot
.47836 .47554 Mdot
.56337 .50321 Mdot
.49521 .57736 Mdot
.47099 .47399 Mdot
.50988 .50811 Mdot
.53259 .56125 Mdot
.5027 .47018 Mdot
.44145 .53148 Mdot
.4572 .47693 Mdot
.57579 .53449 Mdot
.55163 .43716 Mdot
.43511 .47054 Mdot
.4882 .4211 Mdot
.57483 .51992 Mdot
.55021 .43675 Mdot
.56409 .45919 Mdot
.46426 .56494 Mdot
.49204 .49424 Mdot
.50641 .55606 Mdot
.47678 .54835 Mdot
.50149 .54933 Mdot
.46895 .46141 Mdot
.50895 .43939 Mdot
.44127 .46526 Mdot
.45071 .54913 Mdot
.56644 .50811 Mdot
.56512 .45647 Mdot
.41811 .52335 Mdot
.57948 .48451 Mdot
.47125 .42392 Mdot
.49077 .5156 Mdot
.54936 .51118 Mdot
.41766 .52436 Mdot
.50628 .42203 Mdot
.48934 .51134 Mdot
.51106 .4448 Mdot
.46656 .54718 Mdot
.55929 .5618 Mdot
.53584 .42668 Mdot
.57893 .5354 Mdot
.46879 .48566 Mdot
.51916 .497 Mdot
.42915 .45754 Mdot
.47184 .56014 Mdot
.44837 .47002 Mdot
.5827 .47467 Mdot
.45053 .4355 Mdot
.51889 .46423 Mdot
.55857 .47849 Mdot
.55085 .51852 Mdot
.42389 .52461 Mdot
.46504 .54433 Mdot
.45205 .45789 Mdot
.55141 .51635 Mdot
.43525 .5353 Mdot
.5621 .55594 Mdot
.45108 .54173 Mdot
.43578 .45285 Mdot
.54082 .54734 Mdot
.46071 .54776 Mdot
.49495 .47954 Mdot
.5272 .50078 Mdot
.48073 .46738 Mdot
.56848 .4967 Mdot
.42878 .53345 Mdot
.43971 .49053 Mdot
.4381 .47182 Mdot
.53335 .45526 Mdot
.46033 .45732 Mdot
.48675 .46584 Mdot
.51724 .51741 Mdot
.4598 .42937 Mdot
.51239 .49245 Mdot
.45837 .56099 Mdot
.47177 .46164 Mdot
.54347 .50526 Mdot
.43183 .46044 Mdot
.52148 .51238 Mdot
.41505 .4991 Mdot
.45714 .45616 Mdot
.46622 .56481 Mdot
.44186 .50291 Mdot
.54656 .43547 Mdot
.50732 .53287 Mdot
.40707 .49387 Mdot
.50285 .54188 Mdot
.45671 .49338 Mdot
.51987 .48698 Mdot
.477 .53929 Mdot
.48815 .49198 Mdot
.54785 .57104 Mdot
.50849 .54121 Mdot
.47666 .49553 Mdot
.4984 .51502 Mdot
.55459 .49608 Mdot
.4167 .52366 Mdot
.53625 .43147 Mdot
.54199 .44716 Mdot
.56451 .47377 Mdot
.44684 .46181 Mdot
.50609 .52006 Mdot
.52851 .46172 Mdot
.46877 .51371 Mdot
.58268 .52125 Mdot
.45183 .47614 Mdot
.46918 .56622 Mdot
.57412 .51762 Mdot
.50763 .58039 Mdot
.49583 .48266 Mdot
.55677 .50191 Mdot
.49745 .54529 Mdot
.51716 .49803 Mdot
.45561 .46435 Mdot
.40803 .50032 Mdot
.51815 .48621 Mdot
.56315 .45113 Mdot
.50839 .48669 Mdot
.58572 .48821 Mdot
.50437 .5391 Mdot
.56871 .55039 Mdot
.54057 .51704 Mdot
.50121 .45944 Mdot
.53831 .57779 Mdot
.46807 .54091 Mdot
.53342 .55149 Mdot
.51168 .57294 Mdot
.5478 .46943 Mdot
.51954 .49549 Mdot
.46526 .46613 Mdot
.48682 .51557 Mdot
.50847 .49636 Mdot
.44946 .46466 Mdot
.44677 .5474 Mdot
.47547 .56905 Mdot
.4603 .44602 Mdot
.42008 .49856 Mdot
.52766 .52899 Mdot
.50067 .43232 Mdot
.44436 .44751 Mdot
.44785 .54137 Mdot
.41844 .51993 Mdot
.46424 .46554 Mdot
.54661 .53618 Mdot
.45883 .47511 Mdot
.57343 .54743 Mdot
.47442 .47082 Mdot
.50368 .49169 Mdot
.41807 .46346 Mdot
.4605 .55723 Mdot
.46827 .52127 Mdot
.5454 .57282 Mdot
.45127 .5504 Mdot
.50126 .53 Mdot
.48621 .52609 Mdot
.44312 .45543 Mdot
.49352 .52125 Mdot
.57077 .44795 Mdot
.58579 .51485 Mdot
.43375 .53727 Mdot
.52215 .51703 Mdot
.47295 .47167 Mdot
.57777 .54394 Mdot
.55254 .48323 Mdot
.50019 .52467 Mdot
.49814 .51149 Mdot
.47365 .5688 Mdot
.52789 .53868 Mdot
.46986 .45826 Mdot
.44887 .45887 Mdot
.57187 .51472 Mdot
.41179 .49303 Mdot
.41297 .49997 Mdot
.44568 .53063 Mdot
.55737 .44675 Mdot
.51161 .50634 Mdot
.50282 .54539 Mdot
.52732 .58189 Mdot
.48282 .5473 Mdot
.48886 .46172 Mdot
.57281 .54981 Mdot
.46992 .47503 Mdot
.45202 .46928 Mdot
.42239 .51588 Mdot
.41772 .5231 Mdot
.48011 .47838 Mdot
.58602 .5218 Mdot
.58895 .50095 Mdot
.45709 .54503 Mdot
.48867 .49512 Mdot
.4888 .48193 Mdot
.54157 .54055 Mdot
.53086 .51228 Mdot
.55491 .51487 Mdot
.48584 .42296 Mdot
.51059 .50397 Mdot
.53267 .45981 Mdot
.50869 .49469 Mdot
.50282 .5427 Mdot
.48555 .48838 Mdot
.50841 .58176 Mdot
.446 .54736 Mdot
.55899 .56325 Mdot
.55907 .48169 Mdot
.49189 .42639 Mdot
.48232 .57055 Mdot
.45642 .55614 Mdot
.52129 .42584 Mdot
.5258 .5368 Mdot
.45307 .55515 Mdot
.49522 .57462 Mdot
.44462 .44344 Mdot
.457 .47308 Mdot
.42975 .45278 Mdot
.53749 .48631 Mdot
.50795 .54987 Mdot
.42655 .46975 Mdot
.48786 .54394 Mdot
.46375 .45333 Mdot
.54059 .44659 Mdot
.53785 .53516 Mdot
.53571 .43976 Mdot
.51162 .55195 Mdot
.47549 .45793 Mdot
.52071 .54388 Mdot
.42748 .52941 Mdot
.52534 .48475 Mdot
.53464 .47797 Mdot
.48292 .45211 Mdot
.58081 .5016 Mdot
.43709 .53986 Mdot
.49063 .47421 Mdot
.55805 .49272 Mdot
.48171 .563 Mdot
.55508 .56483 Mdot
.49824 .4964 Mdot
.45964 .45892 Mdot
.51149 .53718 Mdot
.46687 .53446 Mdot
.5117 .49116 Mdot
.55699 .55528 Mdot
.4933 .52198 Mdot
.57621 .54124 Mdot
.58836 .49185 Mdot
.47992 .46887 Mdot
.49558 .53057 Mdot
.55441 .46892 Mdot
.43997 .46629 Mdot
.46197 .42547 Mdot
.50546 .49359 Mdot
.56006 .46635 Mdot
.41985 .45428 Mdot
.51805 .57955 Mdot
.53887 .4304 Mdot
.42186 .44946 Mdot
.49566 .57008 Mdot
.43167 .52812 Mdot
.42734 .47151 Mdot
.51069 .52203 Mdot
.44376 .48381 Mdot
.53139 .48003 Mdot
.5155 .52016 Mdot
.46558 .55899 Mdot
.53427 .50229 Mdot
.40062 .48926 Mdot
.42493 .51548 Mdot
.45877 .56122 Mdot
.48006 .4533 Mdot
.43899 .51307 Mdot
.45986 .4672 Mdot
.53177 .49992 Mdot
.46993 .47244 Mdot
.42524 .52937 Mdot
.58798 .50763 Mdot
.48783 .47443 Mdot
.46202 .43902 Mdot
.43671 .46536 Mdot
.49587 .46741 Mdot
.46609 .46239 Mdot
.43452 .5368 Mdot
.4943 .47592 Mdot
.45855 .54319 Mdot
.48179 .49621 Mdot
.49369 .53625 Mdot
.49176 .5161 Mdot
.47628 .46849 Mdot
.49947 .49084 Mdot
.44066 .53296 Mdot
.57159 .4992 Mdot
.49452 .50655 Mdot
.53745 .49723 Mdot
.49574 .53513 Mdot
.43981 .43881 Mdot
.48842 .57485 Mdot
.50736 .42179 Mdot
.44312 .4596 Mdot
.56169 .53235 Mdot
.45656 .48593 Mdot
.43554 .53369 Mdot
.43084 .52581 Mdot
.54282 .43337 Mdot
.50952 .45771 Mdot
.40284 .49173 Mdot
.51752 .51506 Mdot
.47171 .56766 Mdot
.50743 .53184 Mdot
.50444 .49799 Mdot
.57909 .50344 Mdot
.4336 .51796 Mdot
.55957 .54021 Mdot
.43829 .53998 Mdot
.50666 .5171 Mdot
.5777 .49195 Mdot
.53793 .43433 Mdot
.52981 .42636 Mdot
.46507 .55064 Mdot
.51281 .51065 Mdot
.50823 .47203 Mdot
.46519 .47858 Mdot
.52604 .55849 Mdot
.4357 .53534 Mdot
.41062 .51962 Mdot
.45551 .55731 Mdot
.57044 .45059 Mdot
.53224 .51719 Mdot
.45698 .47014 Mdot
.43122 .47175 Mdot
.49894 .44514 Mdot
.5226 .52659 Mdot
.42691 .49578 Mdot
.51374 .52676 Mdot
.51548 .42572 Mdot
.542 .53824 Mdot
.48061 .42593 Mdot
.54792 .53763 Mdot
.54575 .57088 Mdot
.4482 .46349 Mdot
.56451 .55799 Mdot
.46531 .47512 Mdot
.54231 .50599 Mdot
.5791 .47024 Mdot
.52294 .42774 Mdot
.45263 .54912 Mdot
.4511 .46465 Mdot
.52989 .49493 Mdot
.46776 .54791 Mdot
.50371 .5564 Mdot
.42042 .47826 Mdot
.50791 .53234 Mdot
.54595 .43517 Mdot
.51172 .52801 Mdot
.43802 .52838 Mdot
.44705 .46204 Mdot
.55521 .51623 Mdot
.47219 .45356 Mdot
.53777 .50332 Mdot
.47118 .55661 Mdot
.56836 .52189 Mdot
.4737 .47524 Mdot
.52109 .5154 Mdot
.57065 .45013 Mdot
.43711 .4637 Mdot
.46502 .55444 Mdot
.42086 .45943 Mdot
.49182 .52014 Mdot
.52902 .54194 Mdot
.54108 .53753 Mdot
.49403 .47545 Mdot
.55565 .56695 Mdot
.54392 .55007 Mdot
.57473 .54263 Mdot
.47128 .46435 Mdot
.49277 .48295 Mdot
.45751 .47332 Mdot
.52251 .45768 Mdot
.44847 .50017 Mdot
.52156 .51931 Mdot
.50852 .42254 Mdot
.45285 .55086 Mdot
.46523 .46185 Mdot
.46774 .45082 Mdot
.57819 .45926 Mdot
.58928 .49079 Mdot
.54064 .45459 Mdot
.51893 .42593 Mdot
.52673 .45961 Mdot
.46614 .46023 Mdot
.53726 .49064 Mdot
.52201 .54591 Mdot
.41823 .51436 Mdot
.54533 .5703 Mdot
.49375 .57421 Mdot
.5813 .46495 Mdot
.51869 .49971 Mdot
.47792 .47957 Mdot
.422 .5236 Mdot
.50946 .50946 Mdot
.49733 .52406 Mdot
.55361 .46345 Mdot
.51924 .4997 Mdot
.49141 .49707 Mdot
.53515 .43803 Mdot
.42931 .47612 Mdot
.56946 .47692 Mdot
.53324 .52341 Mdot
.42207 .47334 Mdot
.52443 .52941 Mdot
.43328 .53578 Mdot
.42963 .49142 Mdot
.50666 .42234 Mdot
.57 .53939 Mdot
.44626 .54695 Mdot
.48147 .56458 Mdot
.50773 .51723 Mdot
.48614 .53812 Mdot
.46216 .46168 Mdot
.52062 .4876 Mdot
.42875 .53332 Mdot
.55959 .56328 Mdot
.45265 .55491 Mdot
.52328 .56435 Mdot
.50374 .52118 Mdot
.40135 .49403 Mdot
.50506 .54788 Mdot
.52133 .48286 Mdot
.45433 .4634 Mdot
.57232 .45831 Mdot
.45207 .55429 Mdot
.48705 .45208 Mdot
.48986 .48359 Mdot
.57854 .47218 Mdot
.45414 .48721 Mdot
.48874 .50873 Mdot
.4551 .43099 Mdot
.50253 .53205 Mdot
.54435 .53411 Mdot
.52341 .50932 Mdot
.5274 .5137 Mdot
.43698 .51726 Mdot
.53868 .51321 Mdot
.51139 .5668 Mdot
.52524 .52677 Mdot
.46041 .42379 Mdot
.5101 .52291 Mdot
.57076 .45836 Mdot
.53103 .48491 Mdot
.48907 .54322 Mdot
.52055 .57055 Mdot
.53798 .46063 Mdot
.50996 .43388 Mdot
.52258 .50284 Mdot
.48385 .5269 Mdot
.51755 .54356 Mdot
.5119 .48781 Mdot
.54646 .45241 Mdot
.57507 .54579 Mdot
.45858 .5582 Mdot
.52663 .42693 Mdot
.46567 .46803 Mdot
.50004 .49578 Mdot
.52062 .58161 Mdot
.53865 .45219 Mdot
.53318 .42568 Mdot
.51498 .52179 Mdot
.49134 .54152 Mdot
.52017 .49161 Mdot
.50551 .42314 Mdot
.5082 .52545 Mdot
.53337 .51541 Mdot
.51549 .449 Mdot
.48548 .42168 Mdot
.52348 .5471 Mdot
.50813 .50699 Mdot
.44676 .43873 Mdot
.47351 .47115 Mdot
.55061 .57168 Mdot
.53183 .4263 Mdot
.56462 .44546 Mdot
.44359 .54656 Mdot
.47798 .55524 Mdot
.56755 .50566 Mdot
.5135 .52281 Mdot
.47675 .45725 Mdot
.45205 .55256 Mdot
.55147 .54913 Mdot
.55861 .55168 Mdot
.55566 .50399 Mdot
.47337 .56815 Mdot
.42592 .46561 Mdot
.51876 .50706 Mdot
.404 .48337 Mdot
.52934 .54428 Mdot
.51575 .52989 Mdot
.42699 .47826 Mdot
.55256 .45138 Mdot
.45508 .45707 Mdot
.53584 .57982 Mdot
.5701 .44792 Mdot
.52157 .43933 Mdot
.50668 .5134 Mdot
.45844 .43712 Mdot
.48949 .4808 Mdot
.47498 .47594 Mdot
.5607 .51714 Mdot
.58369 .48677 Mdot
.53715 .5152 Mdot
.45852 .46644 Mdot
.53408 .43345 Mdot
.53788 .46612 Mdot
.47131 .56334 Mdot
.42874 .53257 Mdot
.49944 .42901 Mdot
.51497 .5809 Mdot
.45074 .45649 Mdot
.56333 .55435 Mdot
.50672 .51134 Mdot
.50104 .48072 Mdot
.40753 .47722 Mdot
.40377 .50517 Mdot
.49636 .51412 Mdot
.49875 .5489 Mdot
.4599 .53932 Mdot
.5293 .56568 Mdot
.57499 .53751 Mdot
.46993 .56005 Mdot
.52652 .51747 Mdot
.45267 .45522 Mdot
.46629 .49073 Mdot
.45095 .5482 Mdot
.48552 .52465 Mdot
.48936 .57417 Mdot
.44762 .47247 Mdot
.44609 .46499 Mdot
.47462 .45742 Mdot
.54798 .441 Mdot
.58844 .50148 Mdot
.58261 .46778 Mdot
.40583 .4936 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go
00001_ooool3o`000?ooooooB?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04
odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol0003o
oooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`3o
ooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007
ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<
ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0VOooool<o`000:;ooooo000Nooooo`03o`000?oooooooooo08cooooo0_l00004ooooo`;o0000
00?oooooo`000?l000005?l0002Looooo`007_ooool00ol0003oooooooooo`2<ooooo`;o00001?oo
ool<o`0000;ooooo0_l000000ooooooo0000o`000008o`0009[ooooo000Nooooo`03o`000?oooooo
oooo08gooooo0_l000000ooooooo0000o`000003o`0000?ooooo0_l00002ooooo`So000000?ooooo
o`000?l000002?l0002Hooooo`007_ooool00ol0003oooooooooo`2=ooooo`;o000000?oooooo`00
0?l000000ol00005ooooo`[o00000_ooool2o`0000;ooooo1_l0002Gooooo`007_ooool00ol0003o
ooooooooo`2=ooooo`So00001Oooool4o`000003ooooool0003o000000?o00001_ooool7o`0009Ko
oooo000Nooooo`03o`000?oooooooooo08_ooooo1Ol000001?oooooo0000o`000?l00006ooooo`;o
00001?ooool7o`0000?ooooo0_l000000ooooooo0000o`000002o`0009Kooooo000Nooooo`03o`00
0?oooooooooo08[ooooo1Ol00003ooooo`;o00001?ooool2o`0000Oooooo1_l00003ooooo`Wo0000
U?ooool001kooooo00?o0000ooooooooool0R_ooool4o`0000Cooooo0ol00003ooooo`;o00001?oo
ool2o`0000;ooooo0_l00006ooooo`_o0000T_ooool001kooooo00?o0000ooooooooool0QOooool2
o`0000Gooooo0_l00004ooooo`Go00001oooool2o`0000;ooooo0ol00005ooooo`go0000T?ooool0
01kooooo0_l00026ooooo`;o000000?oooooo`000?l000001Ol00004ooooo`Co000000?oooooo`00
0?l000000_l00007ooooo`Co00001?ooool2o`000003ooooool0003o000000;o000000?oooooo`00
0?l000000_l0002@ooooo`007_ooool00ol0003oooooooooo`24ooooo`;o00000_ooool?o`000003
ooooool0003o000000;o00002?ooool3o`0000;ooooo2Ol000000ooooooo0000o`000002o`00093o
oooo000Nooooo`03o`000?oooooooooo08Cooooo1Ol000000ooooooo0000o`00000=o`0000Kooooo
3?l000001?oooooo0000o`000?l00004ooooo`Oo0000SOooool001kooooo00?o0000ooooooooool0
QOoooolDo`0000;ooooo0ol000000ooooooo0000o`000003o`000003ooooool0003o000000Ko0000
1_ooool7o`0008gooooo000Nooooo`03o`000?oooooooooo08Cooooo5?l00002ooooo`Go00001_oo
ool2o`000003ooooool0003o000000?o00000oooool2o`0000Kooooo0ol0002<ooooo`007_ooool0
0ol0003oooooooooo`24ooooo`Go000000?oooooo`000?l000004?l000000ooooooo0000o`000003
ooooo`;o000000?oooooo`000?l000001?ooool2o`0000?ooooo1?l000000ooooooo0000o`000002
ooooo`;o0000S?ooool001kooooo00?o0000ooooooooool0Q_ooool7o`000003ooooool0003o0000
00co000000?oooooo`000?l000001Ol00004ooooo`co000000Coooooo`000?l0003ooooo1?l0002;
ooooo`007_ooool00ol0003oooooooooo`20ooooo`;o00000ooooolHo`0000;ooooo1?l00002oooo
o`;o000000Coooooo`000?l0003o00000_ooool8o`0000?ooooo1?l0002;ooooo`007_ooool00ol0
003oooooooooo`20ooooo`;o00000oooool6o`0000;ooooo4_l000000ooooooo0000o`000007o`00
0003ooooool0003o000000;o00000_ooool7o`000004ooooool0003o0000o`0008cooooo000Noooo
o`03o`000?oooooooooo083ooooo0_l00003ooooo`Co000000?oooooo`000?l000000_oooolCo`00
0004ooooool0003o0000o`0000;ooooo2?l00002ooooo`;o000000Coooooo`000?l0003o0000T?oo
ool001kooooo00?o0000ooooooooool0Ooooool4o`0000;ooooo1?l000000ooooooo0000o`000005
o`0000;ooooo3_l000001?oooooo0000o`000?ooool6o`0000;ooooo0_l000000ooooooo0000o`00
0005o`0000;ooooo0_l0002<ooooo`007_ooool00ol0003oooooooooo`1oooooo`Co00002Oooool2
o`000005ooooool0003o0000o`000?ooool01?l00002oooooaCo00000oooool4o`000003ooooool0
003o000000Ko0000R_ooool001kooooo00?o0000ooooooooool0O_ooool2o`0000gooooo0_l00000
1?oooooo0000o`000?ooool3o`0000Cooooo4ol00004ooooo`co0000R_ooool001kooooo00?o0000
ooooooooool0O_ooool3o`000003ooooool0003o000000Cooooo1ol000001?oooooo0000o`000?oo
ool3o`0000Cooooo4ol00004ooooo`Ko000000?oooooo`000?l000000ol0002:ooooo`007_ooool0
0ol0003oooooooooo`1nooooo`Ko00000oooool6o`0000?ooooo0_l000001Ooooooo0000o`000?l0
003ooooo01?o000000?oooooo`000?l000000oooool4o`000004ooooool0003o0000ooooo`Go0000
R_ooool001kooooo00?o0000ooooooooool0O_ooool4o`000005ooooool0003o0000o`000?ooool0
0_l0000>ooooo`co000000?oooooo`000?l000001ol00003ooooo`co0000Roooool001kooooo0_l0
0022ooooo`Go00000_ooool2o`0000Cooooo0_l00002ooooo`;o00000_ooool2o`0000Cooooo4ol0
0002ooooo`co0000R_ooool001kooooo00?o0000ooooooooool0Ooooool5o`0000?ooooo2Ol00002
ooooo`;o00000_ooool2o`0000Cooooo0ol00002ooooo`ko00000_ooool5o`0000;ooooo1Ol0002:
ooooo`007_ooool00ol0003oooooooooo`1oooooo`;o00001_ooool2o`000003ooooool0003o0000
00;o00003Oooool?o`000003ooooool0003o000000;o000000?oooooo`000?l000001?l00002oooo
o`;o000000?oooooo`000?l00000R_ooool001kooooo00?o0000ooooooooool0Ooooool4o`0000Go
oooo1Ol0000>ooooo`oo000000?oooooo`000?l000001Ol00002ooooo`Co00000_ooool3o`0008[o
oooo000Nooooo`03o`000?oooooooooo087ooooo0_l000001?oooooo0000o`000?ooool6o`0000;o
oooo0_l00003ooooo`;o00001Oooool5o`000003ooooool0003o000000Oo000000?oooooo`000?l0
00002ol00002ooooo`?o0000R_ooool001kooooo00?o0000ooooooooool0Q?ooool9o`0000;ooooo
0ol00002ooooo`Co00000_ooool6o`000003ooooool0003o000000_o000000?oooooo`000?l00000
2?l000001?oooooo0000o`000?l0002:ooooo`007_ooool00ol0003oooooooooo`21ooooo`;o0000
00?oooooo`000?l000000_l000001?oooooo0000o`000?l00003ooooo`?o00001?ooool2o`0000;o
oooo5?l000000ooooooo0000o`000008o`000003ooooool0003o000008_ooooo000Nooooo`03o`00
0?oooooooooo087ooooo1_l00005ooooo`;o000000?oooooo`000?l000000oooool2o`000003oooo
ool0003o000000;ooooo3?l00002ooooo`;o00001?ooool3o`0000?ooooo1ol0002;ooooo`007_oo
ool00ol0003oooooooooo`22ooooo`So000000?oooooo`000?l000000_l00005ooooo`;o000000?o
ooooo`000?l000004ol00009ooooo`;o000000?oooooo`000?l000000_l0002;ooooo`007_ooool0
0ol0003oooooooooo`24ooooo`_o00002?ooool5o`0000;ooooo3_l0002Kooooo`007_ooool00ol0
003oooooooooo`26ooooo`[o00001oooool2o`000003ooooool0003o000000ko00002?ooool3o`00
00Cooooo0_l0002<ooooo`007_ooool00ol0003oooooooooo`27ooooo`Wo00001?ooool2o`0000Co
oooo2ol000000ooooooo0000o`000003ooooo`Go00000_ooool3o`0000;ooooo1?l0002<ooooo`00
7_ooool00ol0003oooooooooo`28ooooo`Co00001Oooool5o`000004ooooool0003o0000ooooo`_o
00000_ooool3o`000003ooooool0003o000000?o00000oooool7o`0008gooooo000Nooooo`03o`00
0?oooooooooo08Wooooo3Ol000001?oooooo0000o`000?ooool4o`000003ooooool0003o000000?o
00000oooool3o`0000;ooooo1?l00002ooooo`Oo0000S_ooool001kooooo00?o0000ooooooooool0
R_ooool<o`0000Cooooo4?l00002ooooo`?o00000_ooool5o`000004ooooool0003o0000o`0008go
oooo000Nooooo`03o`000?oooooooooo08_ooooo2ol000000ooooooo0000o`000004o`000003oooo
ool0003o000000[o00000_ooool2o`0000?ooooo2Ol0002=ooooo`007_ooool2o`0008gooooo2_l0
00000ooooooo0000o`000004o`000003ooooool0003o000000So000000Coooooo`000?l0003ooooo
1ol00002ooooo`Co0000S_ooool001kooooo00?o0000ooooooooool0SOooool4o`0000;ooooo0_l0
0003ooooo`Ko000000?oooooo`000?l000000ol000000ooooooo0000o`000002ooooo`oo0000Sooo
ool001kooooo00?o0000ooooooooool0S_ooool<o`0000;ooooo0_l00002ooooo`Co000000Cooooo
o`000?l0003o00000oooool2o`0000Cooooo1_l0002@ooooo`007_ooool00ol0003oooooooooo`2?
ooooo`_o00000oooool2o`000003ooooool0003o000000;o00000_ooool3o`0000Sooooo1?l0002B
ooooo`007_ooool00ol0003oooooooooo`2Aooooo`Ko000000?oooooo`000?l000000oooool2o`00
0003ooooool0003o000000;o00000_ooool5o`0000Gooooo1?l0002Cooooo`007_ooool00ol0003o
ooooooooo`2Cooooo`Co000000?oooooo`000?l000001_ooool4o`000003ooooool0003o000000Co
00001Oooool4o`0009?ooooo000Nooooo`03o`000?oooooooooo09?ooooo1ol00003ooooo`Co0000
00Coooooo`000?l0003ooooo1Ol00003ooooo`Ko0000U?ooool001kooooo00?o0000ooooooooool0
UOooool6o`000003ooooool0003o000000?o000000Coooooo`000?l0003ooooo0ol00003ooooo`Ko
0000U_ooool001kooooo00?o0000ooooooooool0V?ooool7o`0000?ooooo2?l000000ooooooo0000
o`000004o`0009Kooooo000Nooooo`03o`000?oooooooooo09_ooooo1_l000000ooooooo0000o`00
0006o`000004ooooool0003o0000o`0009Wooooo000Nooooo`03o`000?oooooooooo09cooooo3Ol0
00001?oooooo0000o`000?l0002Jooooo`007_ooool00ol0003oooooooooo`2Qooooo`So000000?o
ooooo`000?l00000Voooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooB?ooool0
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonH
V9So8B4Q00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol@413ooooooooooooo
oooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000oooooom8ooooo`000ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`03
o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05
o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo
0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH
00Sooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?oo
ooooBOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006oooo
o`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0oooooom8
ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00
0006ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go
<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go
0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o
^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooo
oooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o
0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Dooooo`Co000000?o410@oooooooo
ool00oooool00ol0003oooooooooo`3oooooodSooooo000Fooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooom8ooooo`005_ooool00ol0003oooooooooo`05ooooo`?o0000oooo
oom8ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo
0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003ooooo
ooooo`3ooooooe3ooooo000Dooooo`03oeEEEOmVIVKo00000?ooooooD_ooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.43315 .53959 Mdot
.50703 .54159 Mdot
.58585 .53361 Mdot
.49975 .53884 Mdot
.48815 .52669 Mdot
.41382 .50519 Mdot
.59434 .54822 Mdot
.47177 .54102 Mdot
.51318 .40572 Mdot
.45381 .44033 Mdot
.43932 .50539 Mdot
.51927 .50124 Mdot
.41283 .5132 Mdot
.51759 .5879 Mdot
.57627 .438 Mdot
.46668 .44455 Mdot
.48899 .55598 Mdot
.41401 .44696 Mdot
.4464 .4384 Mdot
.54217 .489 Mdot
.48422 .55955 Mdot
.48193 .43092 Mdot
.47669 .51302 Mdot
.43308 .55798 Mdot
.46493 .54848 Mdot
.50431 .48687 Mdot
.56371 .43539 Mdot
.43878 .44006 Mdot
.49574 .52153 Mdot
.41754 .52629 Mdot
.55099 .5509 Mdot
.49363 .54756 Mdot
.49167 .48067 Mdot
.57306 .50234 Mdot
.41477 .51939 Mdot
.57975 .51915 Mdot
.49353 .47726 Mdot
.53682 .42306 Mdot
.48332 .5178 Mdot
.52061 .49601 Mdot
.46956 .45716 Mdot
.5313 .46881 Mdot
.54319 .53608 Mdot
.50444 .50077 Mdot
.48829 .54894 Mdot
.4827 .45651 Mdot
.52995 .59055 Mdot
.55 .56131 Mdot
.56754 .52928 Mdot
.46674 .4053 Mdot
.48734 .51907 Mdot
.40745 .51604 Mdot
.49782 .52243 Mdot
.48054 .5279 Mdot
.46209 .43975 Mdot
.49903 .47356 Mdot
.53756 .51928 Mdot
.40948 .52657 Mdot
.48823 .54271 Mdot
.54188 .5203 Mdot
.4869 .45302 Mdot
.48493 .46523 Mdot
.56172 .49616 Mdot
.46647 .44648 Mdot
.49111 .50898 Mdot
.50341 .40228 Mdot
.51558 .56479 Mdot
.48963 .46056 Mdot
.52141 .48117 Mdot
.46657 .44244 Mdot
.6031 .4914 Mdot
.48972 .53674 Mdot
.54089 .51159 Mdot
.50706 .52187 Mdot
.42111 .54074 Mdot
.58025 .46074 Mdot
.5059 .46935 Mdot
.41457 .45272 Mdot
.60505 .50789 Mdot
.45304 .4746 Mdot
.54411 .4374 Mdot
.46711 .54086 Mdot
.47668 .55521 Mdot
.47429 .45848 Mdot
.56572 .49789 Mdot
.5029 .52211 Mdot
.58296 .48801 Mdot
.48974 .46484 Mdot
.52604 .49953 Mdot
.40267 .48139 Mdot
.49611 .51218 Mdot
.47827 .44988 Mdot
.56554 .45878 Mdot
.48475 .40272 Mdot
.59511 .53798 Mdot
.48876 .45342 Mdot
.49331 .46721 Mdot
.54219 .56027 Mdot
.53503 .58957 Mdot
.53432 .5255 Mdot
.57894 .48003 Mdot
.56501 .4654 Mdot
.48389 .53886 Mdot
.46135 .40161 Mdot
.53068 .41055 Mdot
.48853 .47724 Mdot
.53955 .59706 Mdot
.49285 .51178 Mdot
.52126 .55413 Mdot
.47794 .44857 Mdot
.43742 .55628 Mdot
.49048 .53754 Mdot
.51813 .52473 Mdot
.50635 .40903 Mdot
.49553 .5733 Mdot
.40633 .50637 Mdot
.5498 .42431 Mdot
.43357 .43858 Mdot
.57039 .55671 Mdot
.56385 .45496 Mdot
.42552 .47502 Mdot
.5065 .49091 Mdot
.45484 .43938 Mdot
.561 .5401 Mdot
.49875 .55118 Mdot
.49115 .40948 Mdot
.43001 .55282 Mdot
.50467 .48878 Mdot
.50328 .49394 Mdot
.46379 .45259 Mdot
.43869 .47636 Mdot
.48882 .56272 Mdot
.42464 .55697 Mdot
.56991 .51487 Mdot
.45997 .52523 Mdot
.43658 .56956 Mdot
.45466 .40927 Mdot
.49957 .5067 Mdot
.53476 .49868 Mdot
.51475 .51451 Mdot
.49437 .51233 Mdot
.53331 .41367 Mdot
.49725 .48639 Mdot
.4975 .53492 Mdot
.49088 .4839 Mdot
.47867 .4483 Mdot
.42811 .53518 Mdot
.49596 .44992 Mdot
.49551 .57523 Mdot
.56318 .53267 Mdot
.56518 .50499 Mdot
.43706 .44107 Mdot
.49276 .51917 Mdot
.50533 .58668 Mdot
.4381 .48611 Mdot
.46655 .44397 Mdot
.48241 .46548 Mdot
.41987 .54319 Mdot
.50705 .47022 Mdot
.49479 .49554 Mdot
.5951 .46324 Mdot
.51779 .47118 Mdot
.41878 .46986 Mdot
.45928 .43991 Mdot
.53243 .509 Mdot
.52688 .5203 Mdot
.54233 .41519 Mdot
.52764 .43192 Mdot
.50455 .4409 Mdot
.51995 .41521 Mdot
.44146 .45266 Mdot
.55905 .53252 Mdot
.51446 .54052 Mdot
.53289 .50667 Mdot
.60422 .4798 Mdot
.49448 .47292 Mdot
.48261 .44732 Mdot
.49382 .49849 Mdot
.4879 .59888 Mdot
.56484 .51938 Mdot
.5006 .53583 Mdot
.48285 .45191 Mdot
.50469 .51393 Mdot
.49722 .52376 Mdot
.41051 .51026 Mdot
.51963 .50589 Mdot
.58848 .50332 Mdot
.48673 .45333 Mdot
.4843 .40276 Mdot
.57049 .45844 Mdot
.51057 .50702 Mdot
.47546 .46631 Mdot
.44333 .56463 Mdot
.49288 .51646 Mdot
.52675 .4176 Mdot
.47176 .46181 Mdot
.46878 .40535 Mdot
.49694 .48849 Mdot
.48999 .50264 Mdot
.50612 .53664 Mdot
.53006 .52937 Mdot
.49162 .45951 Mdot
.43084 .47127 Mdot
.52289 .44046 Mdot
.46126 .44271 Mdot
.5188 .53889 Mdot
.48158 .56618 Mdot
.53834 .52594 Mdot
.58244 .50733 Mdot
.49121 .51838 Mdot
.48744 .55053 Mdot
.49521 .48079 Mdot
.52306 .49103 Mdot
.42032 .48803 Mdot
.50701 .49126 Mdot
.51983 .59556 Mdot
.48112 .45162 Mdot
.50915 .47381 Mdot
.53154 .41334 Mdot
.49506 .50666 Mdot
.48119 .48126 Mdot
.41501 .53677 Mdot
.47944 .44904 Mdot
.46555 .58598 Mdot
.44651 .5175 Mdot
.45948 .53429 Mdot
.49384 .54414 Mdot
.45338 .43812 Mdot
.58788 .50906 Mdot
.45671 .49059 Mdot
.45432 .43371 Mdot
.49656 .48284 Mdot
.52104 .41071 Mdot
.48429 .46998 Mdot
.49993 .47969 Mdot
.53643 .50008 Mdot
.50375 .41046 Mdot
.58479 .46855 Mdot
.5047 .55364 Mdot
.51971 .50578 Mdot
.45288 .4382 Mdot
.57825 .44122 Mdot
.42795 .54319 Mdot
.49778 .41096 Mdot
.58447 .55898 Mdot
.46357 .44009 Mdot
.58109 .45826 Mdot
.46593 .53601 Mdot
.45536 .43874 Mdot
.55184 .42316 Mdot
.54276 .53349 Mdot
.40876 .50615 Mdot
.56719 .43369 Mdot
.58952 .54903 Mdot
.515 .52356 Mdot
.52572 .50999 Mdot
.47442 .49538 Mdot
.51174 .48233 Mdot
.56799 .49755 Mdot
.55378 .42233 Mdot
.5309 .43483 Mdot
.47146 .462 Mdot
.49462 .4947 Mdot
.4289 .48351 Mdot
.55076 .49681 Mdot
.55612 .49215 Mdot
.46062 .49737 Mdot
.43187 .45243 Mdot
.47647 .46597 Mdot
.48088 .59579 Mdot
.52434 .55587 Mdot
.5185 .52445 Mdot
.48843 .4022 Mdot
.51735 .51883 Mdot
.59163 .51792 Mdot
.59012 .46625 Mdot
.49998 .47005 Mdot
.44886 .44043 Mdot
.53875 .48913 Mdot
.45509 .45172 Mdot
.52995 .49132 Mdot
.5067 .48522 Mdot
.54252 .57602 Mdot
.49604 .49297 Mdot
.5345 .41811 Mdot
.4792 .40383 Mdot
.50507 .60079 Mdot
.4778 .49735 Mdot
.50741 .54995 Mdot
.49917 .58841 Mdot
.52877 .5084 Mdot
.50064 .57932 Mdot
.40486 .50155 Mdot
.55024 .53293 Mdot
.52675 .52071 Mdot
.47936 .53244 Mdot
.43717 .44446 Mdot
.56247 .51445 Mdot
.53488 .46459 Mdot
.4981 .53958 Mdot
.50044 .49804 Mdot
.45823 .53325 Mdot
.52535 .4085 Mdot
.47069 .44303 Mdot
.52451 .50509 Mdot
.4984 .53864 Mdot
.45636 .5838 Mdot
.46339 .57661 Mdot
.46112 .54831 Mdot
.55202 .50085 Mdot
.50533 .53138 Mdot
.49523 .48959 Mdot
.46833 .48042 Mdot
.44062 .53748 Mdot
.51087 .53473 Mdot
.49222 .57982 Mdot
.51917 .49443 Mdot
.48975 .46214 Mdot
.5386 .5079 Mdot
.52929 .42015 Mdot
.56357 .52304 Mdot
.43612 .50921 Mdot
.43265 .50729 Mdot
.49589 .47306 Mdot
.44095 .44669 Mdot
.50549 .4155 Mdot
.50822 .50427 Mdot
.50435 .49399 Mdot
.49325 .40559 Mdot
.55377 .46067 Mdot
.42552 .53493 Mdot
.4087 .51537 Mdot
.51962 .52455 Mdot
.45295 .44094 Mdot
.58102 .5093 Mdot
.46964 .46458 Mdot
.56513 .50723 Mdot
.49383 .53843 Mdot
.4364 .5184 Mdot
.48674 .46589 Mdot
.5204 .56381 Mdot
.47948 .5801 Mdot
.56051 .5843 Mdot
.4956 .48496 Mdot
.49887 .42432 Mdot
.49873 .56794 Mdot
.49663 .4952 Mdot
.47732 .53805 Mdot
.53136 .43336 Mdot
.47415 .45808 Mdot
.53397 .51556 Mdot
.42232 .55196 Mdot
.4859 .55508 Mdot
.48812 .47215 Mdot
.40579 .49689 Mdot
.52968 .51755 Mdot
.492 .59552 Mdot
.49763 .56055 Mdot
.39971 .49492 Mdot
.48798 .47649 Mdot
.49026 .50649 Mdot
.49099 .58158 Mdot
.52375 .52075 Mdot
.48721 .5927 Mdot
.49905 .56244 Mdot
.5479 .5748 Mdot
.57149 .57206 Mdot
.52203 .42993 Mdot
.48928 .60072 Mdot
.5024 .52016 Mdot
.49497 .49659 Mdot
.49829 .50765 Mdot
.41906 .54495 Mdot
.44683 .50834 Mdot
.57708 .54607 Mdot
.45792 .44183 Mdot
.45295 .50073 Mdot
.58299 .47797 Mdot
.53292 .47554 Mdot
.49729 .48147 Mdot
.56074 .50658 Mdot
.59904 .53105 Mdot
.49298 .53299 Mdot
.4439 .56983 Mdot
.49209 .54396 Mdot
.41782 .50341 Mdot
.43805 .44046 Mdot
.47303 .47125 Mdot
.50152 .4778 Mdot
.5604 .50838 Mdot
.44107 .57385 Mdot
.53085 .48046 Mdot
.56299 .52024 Mdot
.49285 .54763 Mdot
.48057 .50674 Mdot
.4765 .5441 Mdot
.46455 .44153 Mdot
.49347 .4843 Mdot
.44043 .44494 Mdot
.44856 .57901 Mdot
.46262 .58598 Mdot
.5659 .51242 Mdot
.43135 .5667 Mdot
.50825 .48671 Mdot
.55934 .51746 Mdot
.57645 .52074 Mdot
.49697 .52646 Mdot
.49563 .50233 Mdot
.53296 .53095 Mdot
.45017 .46342 Mdot
.51536 .5109 Mdot
.44732 .44689 Mdot
.50572 .52043 Mdot
.55255 .55732 Mdot
.50245 .51675 Mdot
.56761 .46608 Mdot
.47538 .44598 Mdot
.45422 .57359 Mdot
.54953 .52574 Mdot
.45497 .43833 Mdot
.45613 .45564 Mdot
.48453 .45683 Mdot
.50539 .51366 Mdot
.45072 .44449 Mdot
.41871 .54714 Mdot
.5716 .51278 Mdot
.5606 .42444 Mdot
.47371 .46319 Mdot
.53528 .49418 Mdot
.52031 .49024 Mdot
.48881 .58654 Mdot
.46692 .44256 Mdot
.4791 .56906 Mdot
.45608 .45859 Mdot
.50917 .43686 Mdot
.44285 .56546 Mdot
.50378 .43791 Mdot
.53827 .51848 Mdot
.47883 .58448 Mdot
.53349 .50833 Mdot
.55235 .53548 Mdot
.39413 .47794 Mdot
.50183 .58473 Mdot
.43104 .48491 Mdot
.48782 .47655 Mdot
.4375 .46286 Mdot
.48945 .53114 Mdot
.46218 .44489 Mdot
.57572 .50615 Mdot
.49585 .51542 Mdot
.55134 .57806 Mdot
.51906 .50949 Mdot
.47107 .45638 Mdot
.53099 .50344 Mdot
.56064 .47571 Mdot
.50843 .40629 Mdot
.56426 .50527 Mdot
.53581 .4247 Mdot
.49669 .50166 Mdot
.516 .48638 Mdot
.52985 .44893 Mdot
.50919 .52556 Mdot
.55452 .56315 Mdot
.48473 .4712 Mdot
.56012 .52378 Mdot
.46545 .5874 Mdot
.47785 .46598 Mdot
.50773 .51275 Mdot
.50928 .57281 Mdot
.51399 .48154 Mdot
.42984 .51659 Mdot
.46279 .45689 Mdot
.57827 .56946 Mdot
.58481 .4465 Mdot
.44315 .44572 Mdot
.51432 .40638 Mdot
.56878 .54011 Mdot
.58408 .44577 Mdot
.58023 .47967 Mdot
.431 .56463 Mdot
.49532 .4879 Mdot
.48577 .55445 Mdot
.46528 .53814 Mdot
.48417 .54373 Mdot
.48542 .45608 Mdot
.52594 .44722 Mdot
.45236 .44427 Mdot
.4319 .54033 Mdot
.56084 .52826 Mdot
.58262 .47633 Mdot
.4003 .49642 Mdot
.58584 .50662 Mdot
.4959 .40266 Mdot
.49165 .50209 Mdot
.54069 .52911 Mdot
.40514 .49798 Mdot
.53287 .41565 Mdot
.49162 .49767 Mdot
.52714 .45498 Mdot
.45519 .53782 Mdot
.5443 .59427 Mdot
.56504 .43031 Mdot
.58155 .56737 Mdot
.47328 .46641 Mdot
.52049 .50756 Mdot
.44526 .43785 Mdot
.45108 .5562 Mdot
.4578 .45141 Mdot
.59709 .4959 Mdot
.4723 .40439 Mdot
.53067 .48082 Mdot
.56617 .50092 Mdot
.53875 .53545 Mdot
.41064 .49988 Mdot
.45569 .53424 Mdot
.46855 .44403 Mdot
.54035 .53365 Mdot
.41464 .51715 Mdot
.54822 .57839 Mdot
.43832 .53136 Mdot
.45402 .43846 Mdot
.51967 .55948 Mdot
.44754 .53918 Mdot
.50132 .48345 Mdot
.52657 .51483 Mdot
.49455 .46846 Mdot
.56857 .51848 Mdot
.40516 .51165 Mdot
.4427 .46315 Mdot
.44549 .44744 Mdot
.54801 .47277 Mdot
.47861 .44821 Mdot
.50084 .4718 Mdot
.51017 .52532 Mdot
.48302 .40297 Mdot
.51522 .50037 Mdot
.42842 .55803 Mdot
.4883 .45873 Mdot
.53918 .52331 Mdot
.44615 .43817 Mdot
.51626 .52297 Mdot
.41484 .4688 Mdot
.47574 .44581 Mdot
.43708 .56358 Mdot
.44345 .47659 Mdot
.57264 .44528 Mdot
.49522 .53188 Mdot
.40727 .46345 Mdot
.48772 .53693 Mdot
.46142 .46888 Mdot
.52555 .50003 Mdot
.47165 .52669 Mdot
.49183 .4827 Mdot
.52969 .60123 Mdot
.49193 .54032 Mdot
.48173 .4776 Mdot
.49649 .50747 Mdot
.55387 .5169 Mdot
.40021 .4966 Mdot
.56062 .43847 Mdot
.56021 .46275 Mdot
.5747 .49639 Mdot
.46024 .44403 Mdot
.49977 .51985 Mdot
.54086 .47998 Mdot
.47389 .49452 Mdot
.59296 .55158 Mdot
.45781 .4541 Mdot
.43922 .56594 Mdot
.56785 .5376 Mdot
.47998 .59532 Mdot
.50035 .48522 Mdot
.5532 .52214 Mdot
.48313 .53745 Mdot
.51812 .50752 Mdot
.46942 .45061 Mdot
.40617 .46976 Mdot
.52421 .4988 Mdot
.58256 .46967 Mdot
.51328 .49433 Mdot
.59361 .51025 Mdot
.48987 .5355 Mdot
.56032 .58408 Mdot
.52919 .53256 Mdot
.51499 .47146 Mdot
.51783 .59996 Mdot
.46263 .52938 Mdot
.51119 .56146 Mdot
.48978 .57555 Mdot
.55845 .49097 Mdot
.52148 .50639 Mdot
.47914 .45723 Mdot
.48903 .50053 Mdot
.51019 .50185 Mdot
.46219 .44765 Mdot
.42618 .53705 Mdot
.44709 .57028 Mdot
.47864 .44729 Mdot
.41941 .46873 Mdot
.51188 .53901 Mdot
.51989 .43442 Mdot
.46282 .43983 Mdot
.43316 .53026 Mdot
.41018 .49282 Mdot
.47835 .45613 Mdot
.52896 .55096 Mdot
.4653 .45767 Mdot
.56648 .57111 Mdot
.48549 .46607 Mdot
.50624 .4955 Mdot
.42969 .4389 Mdot
.43794 .55295 Mdot
.47198 .50372 Mdot
.52573 .59515 Mdot
.43163 .54206 Mdot
.49235 .5233 Mdot
.48521 .51147 Mdot
.46016 .43915 Mdot
.49146 .50912 Mdot
.59742 .46278 Mdot
.59648 .54271 Mdot
.40728 .51732 Mdot
.51418 .52737 Mdot
.48297 .46589 Mdot
.57578 .57028 Mdot
.55767 .50512 Mdot
.49427 .51707 Mdot
.49736 .50509 Mdot
.44016 .57124 Mdot
.50885 .54792 Mdot
.48783 .45531 Mdot
.46405 .44302 Mdot
.56492 .53444 Mdot
.4134 .46239 Mdot
.41255 .46956 Mdot
.43804 .51618 Mdot
.57803 .46341 Mdot
.50996 .51213 Mdot
.48626 .5403 Mdot
.50464 .60074 Mdot
.47184 .53651 Mdot
.50339 .46938 Mdot
.56581 .57476 Mdot
.4757 .46503 Mdot
.46255 .45291 Mdot
.41591 .48842 Mdot
.4077 .49635 Mdot
.48463 .47288 Mdot
.59374 .54919 Mdot
.60258 .52621 Mdot
.44497 .53574 Mdot
.49235 .48534 Mdot
.49236 .48018 Mdot
.52156 .55365 Mdot
.52443 .52658 Mdot
.54513 .533 Mdot
.51501 .40454 Mdot
.50997 .5095 Mdot
.54573 .47848 Mdot
.51071 .50052 Mdot
.48737 .53765 Mdot
.48913 .47848 Mdot
.48456 .59256 Mdot
.41184 .53209 Mdot
.54387 .59322 Mdot
.56536 .50403 Mdot
.5132 .42278 Mdot
.44524 .57758 Mdot
.43326 .55097 Mdot
.55549 .42106 Mdot
.50746 .54545 Mdot
.41767 .54508 Mdot
.46136 .58544 Mdot
.46193 .43779 Mdot
.46487 .45679 Mdot
.44689 .43676 Mdot
.54228 .50595 Mdot
.48821 .54783 Mdot
.43684 .44232 Mdot
.47737 .53301 Mdot
.48328 .45117 Mdot
.55919 .46161 Mdot
.51899 .54741 Mdot
.55678 .45091 Mdot
.49077 .55236 Mdot
.49267 .45929 Mdot
.50092 .55028 Mdot
.40955 .50647 Mdot
.53096 .50093 Mdot
.54243 .49812 Mdot
.49901 .45994 Mdot
.58202 .52324 Mdot
.40945 .52136 Mdot
.50036 .47832 Mdot
.55904 .51426 Mdot
.4623 .55882 Mdot
.53895 .59812 Mdot
.50037 .4955 Mdot
.47633 .44815 Mdot
.49627 .53942 Mdot
.46553 .52126 Mdot
.51496 .49901 Mdot
.54002 .57397 Mdot
.49103 .50974 Mdot
.57174 .56472 Mdot
.60529 .51603 Mdot
.49301 .46888 Mdot
.48867 .52005 Mdot
.56542 .49064 Mdot
.45044 .44459 Mdot
.48418 .40302 Mdot
.50776 .498 Mdot
.57264 .48809 Mdot
.43348 .4352 Mdot
.49521 .58992 Mdot
.56479 .4372 Mdot
.43567 .43176 Mdot
.47499 .56867 Mdot
.41618 .50714 Mdot
.43621 .44372 Mdot
.50255 .52518 Mdot
.44812 .4578 Mdot
.53854 .49878 Mdot
.5074 .5267 Mdot
.44368 .55529 Mdot
.53272 .51882 Mdot
.39956 .45948 Mdot
.41856 .48842 Mdot
.4288 .55838 Mdot
.49658 .45944 Mdot
.43769 .48888 Mdot
.47236 .45546 Mdot
.53158 .51571 Mdot
.47862 .46482 Mdot
.40435 .50565 Mdot
.60057 .53416 Mdot
.49675 .47662 Mdot
.47979 .43916 Mdot
.44712 .44217 Mdot
.50844 .47705 Mdot
.48164 .45462 Mdot
.41171 .5181 Mdot
.50337 .48146 Mdot
.44835 .53338 Mdot
.48637 .48066 Mdot
.48495 .52541 Mdot
.49223 .50298 Mdot
.48943 .46595 Mdot
.50195 .49241 Mdot
.42694 .51766 Mdot
.57034 .52072 Mdot
.49602 .49763 Mdot
.5377 .51502 Mdot
.48654 .52525 Mdot
.45494 .43 Mdot
.46032 .58029 Mdot
.53516 .41414 Mdot
.45669 .4407 Mdot
.54904 .55073 Mdot
.46125 .46264 Mdot
.41715 .51567 Mdot
.41697 .50395 Mdot
.57839 .44006 Mdot
.52357 .4716 Mdot
.40157 .46146 Mdot
.51162 .52333 Mdot
.44083 .56838 Mdot
.49581 .53083 Mdot
.50614 .50086 Mdot
.57876 .52479 Mdot
.42692 .49362 Mdot
.54549 .5579 Mdot
.41573 .52461 Mdot
.50137 .51823 Mdot
.58036 .51391 Mdot
.56161 .44297 Mdot
.56286 .42537 Mdot
.45061 .54265 Mdot
.50934 .51667 Mdot
.51886 .4848 Mdot
.46979 .46136 Mdot
.50252 .56679 Mdot
.41565 .51761 Mdot
.39638 .49117 Mdot
.41914 .54871 Mdot
.59219 .46778 Mdot
.52244 .53098 Mdot
.46725 .45594 Mdot
.43896 .44561 Mdot
.51501 .45463 Mdot
.50915 .53519 Mdot
.42755 .46705 Mdot
.50279 .53096 Mdot
.53901 .42595 Mdot
.52267 .55152 Mdot
.50114 .42033 Mdot
.53029 .55262 Mdot
.52685 .60198 Mdot
.46121 .44604 Mdot
.55332 .58596 Mdot
.47091 .46136 Mdot
.53772 .52374 Mdot
.59365 .4912 Mdot
.55875 .4243 Mdot
.43489 .54065 Mdot
.46408 .44849 Mdot
.53182 .51053 Mdot
.45604 .53863 Mdot
.48397 .55333 Mdot
.42838 .44918 Mdot
.49596 .53183 Mdot
.57193 .44483 Mdot
.50065 .53033 Mdot
.42662 .5105 Mdot
.4604 .44431 Mdot
.54487 .53423 Mdot
.49042 .45648 Mdot
.53506 .52061 Mdot
.45325 .55068 Mdot
.55893 .54091 Mdot
.47964 .46781 Mdot
.51432 .52551 Mdot
.59294 .46699 Mdot
.44824 .44076 Mdot
.44726 .54831 Mdot
.43446 .43806 Mdot
.4908 .50696 Mdot
.50902 .55155 Mdot
.52174 .55058 Mdot
.5034 .48108 Mdot
.53884 .59578 Mdot
.52288 .56269 Mdot
.56874 .56532 Mdot
.48626 .45969 Mdot
.49642 .48339 Mdot
.46522 .45706 Mdot
.53605 .47378 Mdot
.45164 .47427 Mdot
.51247 .52905 Mdot
.53321 .4189 Mdot
.43371 .54299 Mdot
.48098 .45368 Mdot
.4863 .45369 Mdot
.60198 .47709 Mdot
.60492 .51408 Mdot
.55581 .47302 Mdot
.55319 .42015 Mdot
.53972 .47707 Mdot
.48299 .45326 Mdot
.54026 .50959 Mdot
.50126 .55234 Mdot
.41264 .48594 Mdot
.52519 .59097 Mdot
.45939 .58463 Mdot
.60614 .48393 Mdot
.51901 .5098 Mdot
.48152 .47045 Mdot
.41054 .49805 Mdot
.50686 .51372 Mdot
.49273 .51417 Mdot
.56637 .48452 Mdot
.51954 .51005 Mdot
.49475 .48925 Mdot
.5568 .44832 Mdot
.43562 .44904 Mdot
.57878 .49979 Mdot
.5195 .53595 Mdot
.43205 .4452 Mdot
.50902 .53831 Mdot
.40497 .51482 Mdot
.43152 .46318 Mdot
.53132 .41809 Mdot
.56044 .55962 Mdot
.42561 .53634 Mdot
.46101 .56144 Mdot
.5022 .51915 Mdot
.47929 .52547 Mdot
.47777 .45164 Mdot
.526 .50083 Mdot
.40532 .51149 Mdot
.54485 .59257 Mdot
.41965 .54583 Mdot
.49933 .57245 Mdot
.49769 .51801 Mdot
.39786 .46358 Mdot
.48685 .54412 Mdot
.52808 .49774 Mdot
.46847 .44915 Mdot
.58988 .47788 Mdot
.41998 .54525 Mdot
.50262 .46138 Mdot
.49267 .48121 Mdot
.59154 .49356 Mdot
.45868 .46291 Mdot
.49165 .49506 Mdot
.47698 .40346 Mdot
.49211 .52654 Mdot
.52675 .54832 Mdot
.51938 .52094 Mdot
.52042 .5267 Mdot
.43271 .49346 Mdot
.53025 .52916 Mdot
.48917 .56824 Mdot
.51098 .53614 Mdot
.48016 .40401 Mdot
.50168 .52541 Mdot
.58788 .47817 Mdot
.5367 .50288 Mdot
.47862 .53235 Mdot
.49688 .57809 Mdot
.55109 .48023 Mdot
.52883 .43848 Mdot
.52141 .51448 Mdot
.4834 .51197 Mdot
.49818 .54854 Mdot
.51663 .49671 Mdot
.56235 .47083 Mdot
.57189 .57643 Mdot
.43385 .55403 Mdot
.55127 .42996 Mdot
.47825 .45925 Mdot
.50221 .49649 Mdot
.49752 .596 Mdot
.55455 .46949 Mdot
.5619 .42867 Mdot
.50609 .52779 Mdot
.48106 .53077 Mdot
.52389 .50355 Mdot
.53731 .41131 Mdot
.49918 .52535 Mdot
.52458 .52979 Mdot
.53088 .46123 Mdot
.51272 .40473 Mdot
.50216 .55383 Mdot
.50662 .51074 Mdot
.46733 .40572 Mdot
.48412 .46582 Mdot
.53256 .59872 Mdot
.55848 .42955 Mdot
.58823 .46069 Mdot
.41552 .53325 Mdot
.4628 .5473 Mdot
.56317 .52623 Mdot
.50448 .52771 Mdot
.49388 .45985 Mdot
.4308 .54517 Mdot
.53282 .56384 Mdot
.54274 .56918 Mdot
.55097 .5237 Mdot
.44378 .56903 Mdot
.43829 .43974 Mdot
.51614 .51652 Mdot
.40642 .45423 Mdot
.50863 .55386 Mdot
.50282 .53477 Mdot
.43292 .45047 Mdot
.56978 .46976 Mdot
.47236 .44486 Mdot
.515 .60386 Mdot
.59776 .46249 Mdot
.54036 .44845 Mdot
.50286 .51529 Mdot
.47577 .43562 Mdot
.49392 .48038 Mdot
.48051 .4687 Mdot
.55064 .53576 Mdot
.59063 .50877 Mdot
.5277 .53046 Mdot
.47136 .45412 Mdot
.55724 .44135 Mdot
.54935 .48627 Mdot
.44778 .56142 Mdot
.4065 .51063 Mdot
.52004 .42851 Mdot
.4876 .5999 Mdot
.46797 .4427 Mdot
.55081 .58947 Mdot
.50374 .51361 Mdot
.50806 .48755 Mdot
.4133 .4493 Mdot
.39666 .47503 Mdot
.49571 .50407 Mdot
.48266 .54193 Mdot
.45349 .52809 Mdot
.50566 .57687 Mdot
.56905 .55945 Mdot
.44865 .55641 Mdot
.51748 .5295 Mdot
.47193 .44356 Mdot
.47114 .46919 Mdot
.43305 .5392 Mdot
.48534 .50974 Mdot
.46542 .57612 Mdot
.45506 .45134 Mdot
.45805 .44631 Mdot
.49208 .45849 Mdot
.57052 .45371 Mdot
.59625 .52456 Mdot
.60431 .4876 Mdot
.40556 .46323 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go
00001_ooool3o`000?ooooooB?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04
odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0T_ooool2o`0000?ooooo2?l000000ooo
oooo0000o`00002Uooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEE
EOoooooo00001oooool00ol0003oooooooooo`2Booooo`go000000?oooooo`000?l000000ol0002R
ooooo`000oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool0
0ol0003oooooooooo`2@ooooo`;o00000_ooool3o`0000Gooooo0_l00002ooooo`Go00000_ooool2
o`0009kooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007
ooooo`03o`000?oooooooooo093ooooo0_l0000:ooooo`Oo00000_ooool8o`0009[ooooo0003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooo
oooo09kooooo1?l00003ooooo`;o000000?oooooo`000?l000001?l0002Iooooo`007_ooool00ol0
003oooooooooo`2Pooooo`;o00000oooool9o`0009Wooooo000Nooooo`03o`000?oooooooooo09oo
oooo0_l00002ooooo`;o00000_ooool5o`0000Cooooo0_l0002Eooooo`007_ooool00ol0003ooooo
ooooo`2Nooooo`?o00000_ooool2o`0000?ooooo1?l00003ooooo`Ko0000T_ooool001kooooo00?o
0000ooooooooool0W_ooool2o`0000Gooooo0_l00003ooooo`?o00000_ooool2o`000004ooooool0
003o0000o`0009;ooooo000Nooooo`03o`000?oooooooooo08[ooooo0_l00004ooooo`;o00001ooo
ool2o`0000[ooooo1?l00002ooooo`;o00000_ooool7o`00097ooooo000Nooooo`03o`000?oooooo
oooo08[ooooo0_l00004ooooo`;o00001oooool2o`0000[ooooo1_l00004ooooo`Co000000?ooooo
o`000?l00000TOooool001kooooo00?o0000ooooooooool0ROooool2o`0000;ooooo1ol00003oooo
o`;o00001oooool3o`0000;ooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00001?ooool3
o`000003ooooool0003o000008kooooo000Nooooo`03o`000?oooooooooo08Sooooo3Ol00002oooo
o`?o00001_ooool3o`0000?ooooo1?l00003ooooo`;o00000oooool4o`000004ooooool0003o0000
o`0008gooooo000Nooooo`03o`000?oooooooooo08Sooooo3ol000000ooooooo0000o`000006oooo
o`;o00001?ooool4o`0000Oooooo0ol00004ooooo`;o0000SOooool001kooooo00?o0000oooooooo
ool0P_ooool2o`0000Cooooo4ol0000<ooooo`;o00002?ooool3o`0000;ooooo0_l00002ooooo`;o
0000Roooool001kooooo00?o0000ooooooooool0P_ooool2o`0000?ooooo2Ol000000ooooooo0000
o`000008o`0000;ooooo0_l00008ooooo`?o00000_ooool2o`0000?ooooo0_l00003ooooo`;o0000
0_ooool2o`0008_ooooo000Nooooo`;o0000Poooool3o`0000;ooooo2?l000000ooooooo0000o`00
0004o`000003ooooool0003o000000Ko00002Oooool2o`0000;ooooo0_l00003ooooo`;o0000U?oo
ool001kooooo00?o0000ooooooooool0P?ooool2o`000003ooooool0003o000000?ooooo0_l00000
0ooooooo0000o`000003ooooo`go00001_ooool2o`0000;ooooo0_l00008ooooo`Ko0000T?ooool0
01kooooo00?o0000ooooooooool0O_ooool4o`0000cooooo4Ol00004ooooo`;o00000_ooool2o`00
00[ooooo1?l00002ooooo`;o0000S?ooool001kooooo00?o0000ooooooooool0O_ooool2o`0000;o
oooo0_l0000:oooooa?o00001oooool2o`0000Kooooo1ol00002ooooo`Co000000?oooooo`000?l0
0000Qoooool001kooooo00?o0000ooooooooool0OOooool7o`0000Cooooo2?l000001Ooooooo0000
o`000?l0003ooooo00co00001oooool4o`0000Cooooo1_l00002ooooo`So0000Qoooool001kooooo
00?o0000ooooooooool0OOooool2o`000004ooooool0003o0000ooooo`?o000000?oooooo`000?l0
00001ol000001Ooooooo0000o`000?l0003ooooo00[o00002_ooool3o`0000Sooooo0_l00002oooo
o`Oo0000R?ooool001kooooo00?o0000ooooooooool0P?ooool6o`000004ooooool0003o0000o`00
00Sooooo0_l000000ooooooo0000o`00000Ao`000003ooooool0003o000000Gooooo0_l000000ooo
oooo0000o`000002o`0000;ooooo1_l00028ooooo`007_ooool00ol0003oooooooooo`1mooooo`;o
000000?oooooo`000?l000002?l00005ooooo`;o00001?oooolCo`0000;ooooo0_l00002ooooo`Wo
00000_ooool2o`0008cooooo000Nooooo`03o`000?oooooooooo07cooooo0ol00007ooooo`;o0000
0oooool3o`000003ooooool0003o000000Sooooo2_l00006ooooo`Co000000Coooooo`000?l0003o
oooo0ol00005ooooo`Go00000_ooool2o`0008Gooooo000Nooooo`03o`000?oooooooooo07cooooo
0_l0000=ooooo`?o00001_ooool2o`0000;ooooo2ol00002ooooo`;o000000?oooooo`000?l00000
1ol000000ooooooo0000o`000004ooooo`Ko00000_ooool2o`0008Gooooo000Nooooo`03o`000?oo
oooooooo07oooooo0_l00006ooooo`;o00002oooool2o`0000;ooooo3ol000000ooooooo0000o`00
0002ooooo`Go00001oooool3o`0000Gooooo0ol00024ooooo`007_ooool00ol0003oooooooooo`1o
ooooo`;o000000?oooooo`000?l000000oooool5o`0000oooooo3?l00007ooooo`;o00001?ooool2
o`0000_ooooo0_l00024ooooo`007_ooool00ol0003oooooooooo`22ooooo`Go000000?oooooo`00
0?l000000_l0000@ooooo`Oo000000Coooooo`000?l0003o00001?ooool5o`0000Cooooo1?l00000
0ooooooo0000o`000005ooooo`;o0000QOooool001kooooo00?o0000ooooooooool0OOooool2o`00
00;ooooo1_l00002ooooo`?o00001?ooool2o`0000_ooooo1_l00002ooooo`Go000000Coooooo`00
0?l0003o00000oooool2o`000003ooooool0003o000000;o000000Coooooo`000?l0003ooooo0ol0
00000ooooooo0000o`000025ooooo`007_ooool00ol0003oooooooooo`1mooooo`Ko00001?ooool4
o`0000Gooooo0_l00004ooooo`;o00001?ooool@o`0000Gooooo1Ol000000ooooooo0000o`000003
ooooo`Ko0000QOooool001kooooo00?o0000ooooooooool0O_ooool5o`0000Cooooo0_l00009oooo
o`;o00000_ooool3o`0000?ooooo4_l000000ooooooo0000o`000002ooooo`Ko00001Oooool2o`00
08Oooooo000Nooooo`;o0000POooool3o`0000cooooo0_l000000ooooooo0000o`000003ooooo`;o
00000_oooolCo`000003ooooool0003o000000?ooooo1_l0002=ooooo`007_ooool00ol0003ooooo
ooooo`1oooooo`Oo00001Oooool2o`0000;ooooo0_l00004ooooo`;o00001?oooolAo`0000?ooooo
2ol000000ooooooo0000o`00002:ooooo`007_ooool00ol0003oooooooooo`1oooooo`Oo00000ooo
ool6o`0000Kooooo0_l000001?oooooo0000o`000?ooool5o`000003ooooool0003o000000_o0000
0oooool5o`000003ooooool0003o000000Go00000oooool2o`0008Cooooo000Nooooo`03o`000?oo
oooooooo083ooooo1Ol00002ooooo`Go000000?oooooo`000?l000002Oooool8o`000003ooooool0
003o000000_o00001?ooool4o`000003ooooool0003o000000Ko00000_ooool2o`0008Cooooo000N
ooooo`03o`000?oooooooooo083ooooo1?l00003ooooo`;o000000?oooooo`000?l000002oooool8
o`000003ooooool0003o000000co00001?ooool6o`000003ooooool0003o000000Co00000_ooool2
o`0008Cooooo000Nooooo`03o`000?oooooooooo083ooooo1_l000000ooooooo0000o`000003o`00
0003ooooool0003o000000Sooooo1?l000000ooooooo0000o`00000?o`0000?ooooo2?l000001?oo
oooo0000o`000?ooool2o`0000?ooooo0_l00024ooooo`007_ooool00ol0003oooooooooo`20oooo
o`Ko000000?oooooo`000?l000000ol000000ooooooo0000o`00000:ooooo`[o000000?oooooo`00
0?l000002?l00002ooooo`[o00000_ooool2o`0000?ooooo0_l00024ooooo`007_ooool00ol0003o
ooooooooo`21ooooo`Co00001Oooool2o`0000Oooooo0_l00005oooooaCo000000?oooooo`000?l0
00002_l0002<ooooo`007_ooool00ol0003oooooooooo`21ooooo`Go00002oooool6o`000003oooo
ool0003o000000ko00000_ooool3o`0000;ooooo1_l00003ooooo`?o00000oooool4o`0008Gooooo
000Nooooo`03o`000?oooooooooo087ooooo1Ol00003ooooo`;o00001?ooool5o`000004ooooool0
003o0000oooooaKo000000Coooooo`000?l0003ooooo1?l00002ooooo`;o00001?ooool4o`0008Go
oooo000Nooooo`03o`000?oooooooooo08;ooooo0ol00004ooooo`?o00000_ooool6o`0000?ooooo
0ol000000ooooooo0000o`00000>o`000003ooooool0003o000000?o000000?oooooo`000?l00000
0_l00009ooooo`;o0000Q_ooool001kooooo00?o0000ooooooooool0P_ooool3o`000005ooooool0
003o0000o`000?ooool00_l000000ooooooo0000o`00000;o`000003ooooool0003o000000Oo0000
00?oooooo`000?l000002_l000000ooooooo0000o`000002o`0000Cooooo0_l00003ooooo`;o0000
Q_ooool001kooooo00?o0000ooooooooool0Poooool2o`000003ooooool0003o000000Oo000000?o
ooooo`000?l000004_l000000ooooooo0000o`000004ooooo`Ko00000oooool2o`0000Cooooo0_l0
00000ooooooo0000o`000002o`0008Kooooo000Nooooo`03o`000?oooooooooo08?ooooo3ol00000
0ooooooo0000o`00000Bo`0000_ooooo1Ol00006ooooo`?o0000Qoooool001kooooo00?o0000oooo
ooooool0Q?ooool7o`0000?ooooo0_l00004ooooo`[o00000oooool4o`0000gooooo0_l000000ooo
oooo0000o`000007ooooo`;o0000Qoooool001kooooo00?o0000ooooooooool0Q?ooool2o`000003
ooooool0003o000000;o00000_ooool2o`0000?ooooo0ol00002ooooo`Wo000000?oooooo`000?l0
00000_ooool4o`0000oooooo0_l00003ooooo`;o0000R?ooool001kooooo0_l00025ooooo`?o0000
0_ooool2o`0000;ooooo1?l000001?oooooo0000o`000?l00005ooooo`Wo00000_ooool5o`0000Co
oooo0ol00007ooooo`;o00000_ooool3o`0008Sooooo000Nooooo`03o`000?oooooooooo08Gooooo
0_l000000ooooooo0000o`000002o`0000?ooooo0_l00008ooooo`Co000000?oooooo`000?l00000
0ol00002ooooo`Go00001?ooool3o`0000_ooooo0ol00028ooooo`007_ooool00ol0003ooooooooo
o`26ooooo`_o00001_ooool6o`0000;ooooo1?l00002ooooo`Go00000oooool2o`000003ooooool0
003o000000?ooooo0_l0002@ooooo`007_ooool00ol0003oooooooooo`26ooooo`_o000000?ooooo
o`000?l000000oooool6o`000003ooooool0003o000000Gooooo0ol00004ooooo`?o000000?ooooo
o`000?l000000_l000000ooooooo0000o`000003ooooo`;o0000Roooool001kooooo00?o0000oooo
ooooool0Qoooool2o`000004ooooool0003o0000ooooo`;o00000oooool2o`0000Gooooo1?l00000
0ooooooo0000o`000002ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`000004ooooool0
003o0000ooooo`Go000000?oooooo`000?l000000oooool2o`0008_ooooo000Nooooo`03o`000?oo
oooooooo08Sooooo1ol00003ooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`?o0000
00?oooooo`000?l000001?l000000ooooooo0000o`000004ooooo`?o00000oooool3o`000003oooo
ool0003o000008cooooo000Nooooo`03o`000?oooooooooo08Sooooo1ol00007ooooo`Co000000Co
ooooo`000?l0003ooooo0ol00003ooooo`;o00001_ooool2o`0000Oooooo1_l0002<ooooo`007_oo
ool00ol0003oooooooooo`2:ooooo`Go00001oooool4o`000003ooooool0003o000000?o000000?o
ooooo`000?l000002Oooool2o`0000Kooooo1_l0002=ooooo`007_ooool00ol0003oooooooooo`2;
ooooo`;o00000oooool2o`000003ooooool0003o000000Kooooo1Ol000000ooooooo0000o`000008
ooooo`Go00001?ooool4o`0008oooooo000Nooooo`03o`000?oooooooooo08_ooooo1ol000000ooo
oooo0000o`000006ooooo`Oo00002Oooool6o`0000?ooooo1?l0002?ooooo`007_ooool00ol0003o
ooooooooo`2=ooooo`?o00000_ooool2o`0000Cooooo0_l00002ooooo`Ko00003?ooool3o`0009Ko
oooo000Nooooo`03o`000?oooooooooo093ooooo1?l00004ooooo`;o00000_ooool2o`000003oooo
ool0003o0000017ooooo0_l0002Cooooo`007_ooool00ol0003oooooooooo`2@ooooo`Go00000ooo
ool2o`000004ooooool0003o0000ooooo`Co00000_ooool2o`0000[ooooo1?l0002Cooooo`007_oo
ool00ol0003oooooooooo`2Booooo`?o00001_ooool7o`0000;ooooo0_l000000ooooooo0000o`00
0003o`0000?ooooo0ol0002Eooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2Iooooo`?o0000
00?oooooo`000?l000002?ooool5o`000003ooooool0003o000000;o0000U_ooool000?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Ko
oooo00?o0000ooooooooool0V?ooool8o`0000Gooooo1?l00002ooooo`Co0000V?ooool000?ooooo
00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`00
09Sooooo2_l00002ooooo`Wo0000V_ooool000?ooooo00Go0000ooooooooooooooooo`00000;oooo
o`05o`000?nHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2Jooooo`?o00000oooool2
o`000005ooooool0003o0000o`000?ooool01?l0002Looooo`000oooool01Ol0003ooooooooooooo
oooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0:?ooooo
0_l00002ooooo`?o0000WOooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEE
EOn7QhOooooo00Sooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`3oooooodSooooo
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom8ooooo`000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ
8B401_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@
41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0003oooooodSooooo0003ooooo`05
o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000
ooooooooool0oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<
o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@
oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooo
ooooo`3oooooodSooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zj
oooooonj^[[o000000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003o
ooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001Cooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodSooooo000Foooo
o`03o`000?oooooooooo00Gooooo0ol0003oooooodSooooo000Fooooo`03o`000?oooooooooo0?oo
ooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003ooooooooo
o`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Cooooo00?oEEEEofIV
I_l00000oooooomBooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.42457 .5253 Mdot
.48891 .54073 Mdot
.57669 .55164 Mdot
.48557 .53421 Mdot
.48208 .51259 Mdot
.40894 .48232 Mdot
.59349 .57148 Mdot
.46505 .52365 Mdot
.53739 .4016 Mdot
.47402 .42918 Mdot
.44489 .48563 Mdot
.51731 .51239 Mdot
.40361 .49155 Mdot
.49353 .59337 Mdot
.59813 .45213 Mdot
.48676 .43911 Mdot
.46977 .54566 Mdot
.43164 .42577 Mdot
.46735 .4241 Mdot
.54345 .512 Mdot
.4666 .54659 Mdot
.50067 .44084 Mdot
.4851 .49492 Mdot
.41454 .54725 Mdot
.45573 .53246 Mdot
.5082 .4957 Mdot
.58186 .44954 Mdot
.45956 .42189 Mdot
.49014 .51199 Mdot
.40618 .50849 Mdot
.5303 .56112 Mdot
.47565 .53878 Mdot
.49615 .47861 Mdot
.56955 .52549 Mdot
.40415 .49947 Mdot
.56919 .53838 Mdot
.50083 .48291 Mdot
.5556 .43186 Mdot
.48513 .50034 Mdot
.52138 .51003 Mdot
.48485 .45124 Mdot
.53804 .49041 Mdot
.5231 .54701 Mdot
.50564 .50322 Mdot
.4709 .53711 Mdot
.49929 .4577 Mdot
.50667 .60125 Mdot
.52946 .57076 Mdot
.5515 .54505 Mdot
.48988 .38501 Mdot
.48582 .50337 Mdot
.39344 .49369 Mdot
.49155 .51513 Mdot
.47797 .51068 Mdot
.48426 .43394 Mdot
.51019 .48475 Mdot
.52673 .53367 Mdot
.38855 .50611 Mdot
.47354 .53072 Mdot
.53006 .53546 Mdot
.50584 .45968 Mdot
.4983 .46661 Mdot
.55985 .51992 Mdot
.48576 .4405 Mdot
.49262 .49474 Mdot
.52906 .39272 Mdot
.49057 .56483 Mdot
.50572 .4667 Mdot
.52651 .50091 Mdot
.4879 .43789 Mdot
.61091 .51314 Mdot
.47775 .52552 Mdot
.53382 .52924 Mdot
.50006 .5224 Mdot
.40603 .52572 Mdot
.59219 .4818 Mdot
.51701 .48578 Mdot
.43084 .42919 Mdot
.6095 .52971 Mdot
.46574 .45054 Mdot
.5591 .45179 Mdot
.46108 .52394 Mdot
.46318 .53963 Mdot
.48981 .45496 Mdot
.56335 .52156 Mdot
.49638 .51982 Mdot
.58542 .51185 Mdot
.50402 .46975 Mdot
.52445 .51493 Mdot
.40813 .45342 Mdot
.49431 .50264 Mdot
.49662 .44972 Mdot
.57632 .47956 Mdot
.50986 .38672 Mdot
.59105 .55828 Mdot
.50611 .46742 Mdot
.507 .47455 Mdot
.52001 .56773 Mdot
.51229 .60153 Mdot
.52052 .53724 Mdot
.58397 .50394 Mdot
.5732 .48799 Mdot
.47302 .524 Mdot
.48109 .38501 Mdot
.55483 .41069 Mdot
.49362 .47658 Mdot
.5191 .62094 Mdot
.49237 .49892 Mdot
.49641 .55635 Mdot
.49688 .44838 Mdot
.42115 .54531 Mdot
.47799 .52687 Mdot
.50736 .53096 Mdot
.52855 .40741 Mdot
.47232 .56752 Mdot
.39765 .48208 Mdot
.56904 .43402 Mdot
.45568 .42232 Mdot
.55581 .57147 Mdot
.57617 .47441 Mdot
.43521 .44871 Mdot
.50857 .49879 Mdot
.4757 .42948 Mdot
.5424 .55306 Mdot
.47845 .54498 Mdot
.51267 .40723 Mdot
.41374 .54094 Mdot
.50759 .49679 Mdot
.50505 .49851 Mdot
.48096 .44454 Mdot
.44974 .45111 Mdot
.46852 .55292 Mdot
.39999 .54621 Mdot
.56049 .53517 Mdot
.46501 .50913 Mdot
.4108 .56218 Mdot
.47134 .40598 Mdot
.49994 .50361 Mdot
.5332 .5182 Mdot
.509 .52036 Mdot
.49316 .50066 Mdot
.55645 .41605 Mdot
.50012 .48944 Mdot
.48564 .52846 Mdot
.49674 .47604 Mdot
.49854 .449 Mdot
.41904 .5199 Mdot
.50987 .4672 Mdot
.47228 .56944 Mdot
.54565 .54725 Mdot
.55992 .52727 Mdot
.45832 .42241 Mdot
.48887 .50668 Mdot
.48166 .58688 Mdot
.44736 .46232 Mdot
.48693 .43871 Mdot
.49514 .46547 Mdot
.39983 .52803 Mdot
.51774 .48696 Mdot
.49884 .48573 Mdot
.60923 .48296 Mdot
.52602 .49122 Mdot
.42882 .44346 Mdot
.48429 .43572 Mdot
.52686 .52397 Mdot
.51689 .53082 Mdot
.5659 .41849 Mdot
.54315 .44347 Mdot
.51804 .45668 Mdot
.54029 .41905 Mdot
.45658 .43248 Mdot
.54107 .54683 Mdot
.49465 .54254 Mdot
.52824 .52257 Mdot
.61764 .50041 Mdot
.50489 .47964 Mdot
.50139 .46027 Mdot
.49788 .48697 Mdot
.46392 .60352 Mdot
.55322 .53809 Mdot
.4876 .53135 Mdot
.50261 .46312 Mdot
.50131 .51403 Mdot
.49045 .51583 Mdot
.40201 .48731 Mdot
.51591 .51591 Mdot
.58478 .52524 Mdot
.50597 .46148 Mdot
.50905 .38799 Mdot
.58181 .47908 Mdot
.50845 .51203 Mdot
.48446 .45452 Mdot
.42383 .55513 Mdot
.49022 .50377 Mdot
.54642 .42355 Mdot
.48313 .4553 Mdot
.49291 .38495 Mdot
.50017 .48902 Mdot
.49483 .48788 Mdot
.49099 .53548 Mdot
.51407 .53907 Mdot
.50797 .468 Mdot
.44163 .44531 Mdot
.5358 .45523 Mdot
.48127 .43486 Mdot
.49868 .54263 Mdot
.46423 .55325 Mdot
.52352 .53855 Mdot
.57647 .52903 Mdot
.48815 .50473 Mdot
.46995 .5385 Mdot
.50051 .48596 Mdot
.5251 .50826 Mdot
.42488 .46242 Mdot
.50899 .49927 Mdot
.49676 .60454 Mdot
.49925 .45286 Mdot
.51863 .49082 Mdot
.55466 .41545 Mdot
.49595 .49527 Mdot
.49152 .4649 Mdot
.39293 .51904 Mdot
.49875 .44985 Mdot
.44174 .58318 Mdot
.4516 .50129 Mdot
.45841 .51843 Mdot
.47759 .53587 Mdot
.47603 .42836 Mdot
.58215 .53024 Mdot
.46901 .46864 Mdot
.47742 .43434 Mdot
.50088 .48805 Mdot
.54288 .41166 Mdot
.49425 .47083 Mdot
.50723 .48924 Mdot
.53426 .51977 Mdot
.52555 .40971 Mdot
.59441 .49106 Mdot
.48264 .55031 Mdot
.51602 .51587 Mdot
.47525 .42801 Mdot
.59868 .45644 Mdot
.41603 .52911 Mdot
.51955 .41017 Mdot
.57694 .57814 Mdot
.48635 .43514 Mdot
.59431 .4785 Mdot
.46302 .51932 Mdot
.48078 .43455 Mdot
.57181 .43233 Mdot
.52347 .54499 Mdot
.40162 .48213 Mdot
.58751 .4471 Mdot
.58361 .56874 Mdot
.50565 .52829 Mdot
.51967 .52207 Mdot
.48717 .47616 Mdot
.51887 .49808 Mdot
.56593 .52133 Mdot
.57522 .43102 Mdot
.54551 .44763 Mdot
.48152 .45363 Mdot
.49887 .48509 Mdot
.4366 .45807 Mdot
.54908 .5201 Mdot
.55608 .51611 Mdot
.47306 .47649 Mdot
.44791 .43059 Mdot
.48568 .46041 Mdot
.45585 .59916 Mdot
.49941 .55866 Mdot
.50779 .53088 Mdot
.51331 .38819 Mdot
.50942 .52522 Mdot
.5855 .53792 Mdot
.60138 .48759 Mdot
.51244 .48317 Mdot
.46869 .4265 Mdot
.54014 .51156 Mdot
.47009 .4371 Mdot
.53103 .51129 Mdot
.5123 .49649 Mdot
.52062 .58563 Mdot
.50034 .48807 Mdot
.55505 .42432 Mdot
.50435 .3865 Mdot
.48195 .60763 Mdot
.48979 .47891 Mdot
.48612 .54788 Mdot
.47643 .58691 Mdot
.52336 .52225 Mdot
.47666 .5764 Mdot
.39938 .47574 Mdot
.53162 .54609 Mdot
.51661 .53112 Mdot
.47462 .51544 Mdot
.45532 .42491 Mdot
.5529 .53447 Mdot
.54257 .48538 Mdot
.48393 .53404 Mdot
.50319 .49773 Mdot
.45775 .51754 Mdot
.55035 .40656 Mdot
.49401 .44151 Mdot
.52053 .51768 Mdot
.48464 .5332 Mdot
.42644 .5834 Mdot
.44366 .56804 Mdot
.45208 .53296 Mdot
.5488 .52368 Mdot
.49367 .53023 Mdot
.49972 .48529 Mdot
.48099 .45965 Mdot
.43542 .52341 Mdot
.49517 .53617 Mdot
.47082 .57229 Mdot
.5208 .50843 Mdot
.50505 .46781 Mdot
.53335 .52585 Mdot
.54828 .42744 Mdot
.54999 .5404 Mdot
.4392 .49027 Mdot
.43468 .48764 Mdot
.50683 .48125 Mdot
.45823 .42847 Mdot
.52588 .41877 Mdot
.50757 .5084 Mdot
.50588 .49935 Mdot
.51677 .39931 Mdot
.56367 .48129 Mdot
.41533 .51935 Mdot
.39638 .49322 Mdot
.5086 .53149 Mdot
.47287 .42902 Mdot
.57396 .53065 Mdot
.47996 .44921 Mdot
.55894 .52903 Mdot
.48079 .53024 Mdot
.43691 .50249 Mdot
.50014 .4683 Mdot
.49501 .56493 Mdot
.45986 .57149 Mdot
.54538 .60718 Mdot
.4989 .48654 Mdot
.5169 .43307 Mdot
.47504 .56304 Mdot
.50057 .49044 Mdot
.47023 .52117 Mdot
.54644 .4457 Mdot
.48985 .45456 Mdot
.52572 .52957 Mdot
.39838 .53926 Mdot
.46801 .54318 Mdot
.49752 .47508 Mdot
.4061 .47037 Mdot
.52087 .52957 Mdot
.46955 .59678 Mdot
.47509 .55436 Mdot
.39825 .46763 Mdot
.49315 .47481 Mdot
.49331 .49156 Mdot
.46981 .57459 Mdot
.51367 .52996 Mdot
.46542 .5916 Mdot
.47595 .55695 Mdot
.52739 .58568 Mdot
.55876 .58926 Mdot
.53829 .44059 Mdot
.46383 .60812 Mdot
.49679 .51774 Mdot
.49877 .48652 Mdot
.49831 .50239 Mdot
.39641 .52957 Mdot
.45508 .48964 Mdot
.56461 .56222 Mdot
.47795 .43239 Mdot
.46373 .48035 Mdot
.5892 .50158 Mdot
.53789 .4981 Mdot
.50271 .48822 Mdot
.55449 .52829 Mdot
.5978 .55251 Mdot
.48261 .52371 Mdot
.42104 .56162 Mdot
.47601 .53445 Mdot
.41495 .48111 Mdot
.45909 .42212 Mdot
.48387 .45373 Mdot
.51099 .48924 Mdot
.55331 .52959 Mdot
.41302 .56842 Mdot
.53484 .50269 Mdot
.55082 .53851 Mdot
.47497 .53833 Mdot
.48943 .48887 Mdot
.46659 .52746 Mdot
.48918 .44139 Mdot
.4982 .48049 Mdot
.45823 .42682 Mdot
.42064 .57534 Mdot
.43408 .58585 Mdot
.55753 .53323 Mdot
.40156 .55985 Mdot
.51324 .49822 Mdot
.54809 .53637 Mdot
.56441 .53933 Mdot
.48906 .51864 Mdot
.49783 .4916 Mdot
.51509 .54107 Mdot
.4636 .44102 Mdot
.51078 .51776 Mdot
.46483 .43116 Mdot
.4996 .52034 Mdot
.53243 .56755 Mdot
.49824 .51485 Mdot
.57583 .48879 Mdot
.49537 .44509 Mdot
.43333 .56527 Mdot
.53331 .54042 Mdot
.47704 .42921 Mdot
.46966 .43857 Mdot
.50124 .45931 Mdot
.50196 .51432 Mdot
.46992 .43103 Mdot
.39203 .53179 Mdot
.5632 .53373 Mdot
.58409 .43316 Mdot
.48498 .45794 Mdot
.53527 .5151 Mdot
.52331 .50664 Mdot
.46751 .58203 Mdot
.48825 .43815 Mdot
.46179 .55668 Mdot
.46917 .44017 Mdot
.52378 .45068 Mdot
.42257 .55616 Mdot
.51807 .45248 Mdot
.52773 .53326 Mdot
.45808 .5788 Mdot
.52821 .52386 Mdot
.53293 .54834 Mdot
.39646 .4505 Mdot
.47831 .58285 Mdot
.43866 .45993 Mdot
.49313 .47552 Mdot
.45031 .43929 Mdot
.48047 .51903 Mdot
.48169 .43698 Mdot
.57064 .52865 Mdot
.49276 .5057 Mdot
.53219 .59137 Mdot
.51424 .51845 Mdot
.48712 .45154 Mdot
.52748 .51995 Mdot
.56549 .50009 Mdot
.53182 .40261 Mdot
.55882 .52745 Mdot
.5539 .43416 Mdot
.49882 .49344 Mdot
.52112 .5025 Mdot
.5406 .46624 Mdot
.50006 .527 Mdot
.53515 .5736 Mdot
.49375 .4719 Mdot
.54601 .54046 Mdot
.44003 .58625 Mdot
.48876 .46331 Mdot
.50409 .51499 Mdot
.48429 .5723 Mdot
.52067 .49841 Mdot
.42816 .49954 Mdot
.47487 .44335 Mdot
.57194 .59676 Mdot
.60854 .46218 Mdot
.46071 .42845 Mdot
.538 .40315 Mdot
.55244 .55441 Mdot
.60856 .4612 Mdot
.58553 .5035 Mdot
.4063 .556 Mdot
.49966 .48474 Mdot
.46805 .54241 Mdot
.46096 .52149 Mdot
.47076 .52937 Mdot
.5026 .45936 Mdot
.537 .46414 Mdot
.47163 .43161 Mdot
.42261 .52605 Mdot
.54456 .54383 Mdot
.58935 .4999 Mdot
.39413 .4698 Mdot
.58039 .5282 Mdot
.52026 .39345 Mdot
.49584 .48838 Mdot
.52322 .54147 Mdot
.40398 .47175 Mdot
.55489 .41973 Mdot
.497 .48475 Mdot
.53673 .47363 Mdot
.45172 .52269 Mdot
.52423 .61625 Mdot
.58639 .44228 Mdot
.57521 .59203 Mdot
.48303 .45191 Mdot
.51608 .51762 Mdot
.46987 .42719 Mdot
.43758 .54412 Mdot
.47459 .44021 Mdot
.59953 .51792 Mdot
.49677 .38563 Mdot
.53458 .50299 Mdot
.56257 .52408 Mdot
.51846 .54558 Mdot
.40838 .47508 Mdot
.45443 .51894 Mdot
.4892 .43995 Mdot
.5208 .54456 Mdot
.40481 .49678 Mdot
.52809 .59082 Mdot
.43489 .51673 Mdot
.47949 .43362 Mdot
.49447 .56056 Mdot
.44274 .525 Mdot
.50652 .49216 Mdot
.51863 .52637 Mdot
.50777 .47661 Mdot
.55737 .5376 Mdot
.39287 .48827 Mdot
.45574 .43994 Mdot
.46238 .43041 Mdot
.55389 .49607 Mdot
.49862 .44896 Mdot
.51279 .48507 Mdot
.50095 .5273 Mdot
.50759 .38883 Mdot
.51394 .50973 Mdot
.40763 .54747 Mdot
.50505 .46412 Mdot
.526 .53688 Mdot
.46894 .42494 Mdot
.50691 .52839 Mdot
.42576 .44204 Mdot
.49675 .44553 Mdot
.41604 .55389 Mdot
.45504 .45185 Mdot
.58975 .46211 Mdot
.48515 .52372 Mdot
.41872 .43714 Mdot
.47615 .52428 Mdot
.4738 .44781 Mdot
.52378 .51502 Mdot
.47402 .50927 Mdot
.4971 .47722 Mdot
.50815 .6202 Mdot
.47772 .53077 Mdot
.49105 .46288 Mdot
.49656 .49861 Mdot
.54259 .53522 Mdot
.39537 .46984 Mdot
.57711 .45343 Mdot
.56946 .48437 Mdot
.57344 .5202 Mdot
.47984 .4353 Mdot
.49461 .51506 Mdot
.54457 .50342 Mdot
.48668 .47519 Mdot
.59312 .57618 Mdot
.47129 .43882 Mdot
.41705 .55687 Mdot
.55117 .55197 Mdot
.45493 .59841 Mdot
.50415 .49215 Mdot
.53912 .53869 Mdot
.47343 .52213 Mdot
.51411 .51644 Mdot
.48744 .44556 Mdot
.41559 .44262 Mdot
.52314 .51356 Mdot
.59149 .4926 Mdot
.51441 .50467 Mdot
.58957 .53124 Mdot
.47849 .52434 Mdot
.54514 .60845 Mdot
.5107 .54122 Mdot
.52363 .49082 Mdot
.49525 .61038 Mdot
.46518 .51304 Mdot
.48667 .55997 Mdot
.46931 .56598 Mdot
.55874 .51508 Mdot
.51732 .51719 Mdot
.49556 .4561 Mdot
.49529 .48548 Mdot
.5095 .50812 Mdot
.48086 .43921 Mdot
.41559 .52181 Mdot
.42564 .56189 Mdot
.4987 .45855 Mdot
.42979 .44247 Mdot
.49338 .54036 Mdot
.53481 .44678 Mdot
.4866 .44216 Mdot
.42814 .51513 Mdot
.41299 .46646 Mdot
.49506 .4547 Mdot
.50516 .55552 Mdot
.47772 .44674 Mdot
.55148 .58625 Mdot
.49839 .46765 Mdot
.50731 .50149 Mdot
.45133 .42219 Mdot
.42397 .5413 Mdot
.48378 .48477 Mdot
.50279 .60603 Mdot
.4215 .52799 Mdot
.48658 .51139 Mdot
.48928 .49436 Mdot
.48308 .4328 Mdot
.49277 .49514 Mdot
.61343 .48197 Mdot
.59644 .56588 Mdot
.39202 .49506 Mdot
.5028 .53144 Mdot
.49552 .46615 Mdot
.56507 .58872 Mdot
.552 .52708 Mdot
.49096 .50571 Mdot
.49831 .49804 Mdot
.4141 .56429 Mdot
.48782 .5466 Mdot
.50578 .46136 Mdot
.48445 .43673 Mdot
.54749 .54886 Mdot
.42622 .43606 Mdot
.42329 .44258 Mdot
.43996 .49947 Mdot
.58866 .48526 Mdot
.5061 .51576 Mdot
.47337 .52696 Mdot
.48151 .60742 Mdot
.46773 .51916 Mdot
.5151 .4847 Mdot
.55104 .59092 Mdot
.48602 .46035 Mdot
.47931 .44402 Mdot
.42026 .4622 Mdot
.40888 .46994 Mdot
.49202 .47201 Mdot
.59116 .57106 Mdot
.60457 .54867 Mdot
.44156 .52144 Mdot
.49773 .47891 Mdot
.49711 .48283 Mdot
.49678 .55598 Mdot
.51135 .53494 Mdot
.52621 .54514 Mdot
.54171 .39764 Mdot
.50708 .51362 Mdot
.54986 .5023 Mdot
.51014 .50755 Mdot
.47551 .5248 Mdot
.49473 .47281 Mdot
.46277 .59139 Mdot
.38846 .51277 Mdot
.52365 .61269 Mdot
.56049 .52652 Mdot
.53179 .43042 Mdot
.41485 .57453 Mdot
.41923 .53875 Mdot
.58289 .42553 Mdot
.48749 .54402 Mdot
.39254 .52924 Mdot
.43233 .58528 Mdot
.48463 .44244 Mdot
.47872 .44719 Mdot
.47227 .43009 Mdot
.53762 .52565 Mdot
.4712 .53593 Mdot
.45686 .42269 Mdot
.47326 .51579 Mdot
.5035 .45861 Mdot
.56896 .48281 Mdot
.49569 .54948 Mdot
.56976 .46925 Mdot
.47187 .54211 Mdot
.50894 .46926 Mdot
.48095 .54545 Mdot
.40267 .48263 Mdot
.52849 .51868 Mdot
.54077 .52017 Mdot
.5125 .47692 Mdot
.57154 .54169 Mdot
.3929 .50007 Mdot
.50864 .48843 Mdot
.5492 .53391 Mdot
.44894 .54546 Mdot
.51843 .6206 Mdot
.50287 .49656 Mdot
.49531 .44712 Mdot
.48242 .53287 Mdot
.4724 .50435 Mdot
.51415 .5086 Mdot
.51738 .58223 Mdot
.49225 .49549 Mdot
.55843 .58037 Mdot
.61055 .53863 Mdot
.506 .47567 Mdot
.48588 .50521 Mdot
.56572 .51471 Mdot
.46961 .43099 Mdot
.50759 .39282 Mdot
.50828 .50407 Mdot
.57428 .51227 Mdot
.4564 .42473 Mdot
.473 .58797 Mdot
.58261 .45188 Mdot
.45823 .42334 Mdot
.45852 .55632 Mdot
.41133 .4852 Mdot
.45501 .42349 Mdot
.4947 .52232 Mdot
.46212 .43706 Mdot
.53669 .51941 Mdot
.49801 .527 Mdot
.42974 .54381 Mdot
.52311 .53184 Mdot
.40967 .43408 Mdot
.42288 .46259 Mdot
.40794 .5479 Mdot
.51114 .47458 Mdot
.4463 .46539 Mdot
.48891 .45138 Mdot
.52344 .52884 Mdot
.49098 .46295 Mdot
.39487 .4811 Mdot
.60191 .55705 Mdot
.50514 .48466 Mdot
.49906 .45047 Mdot
.46633 .42735 Mdot
.5175 .4931 Mdot
.49873 .45549 Mdot
.39985 .49703 Mdot
.51054 .49231 Mdot
.44674 .51886 Mdot
.49402 .46852 Mdot
.48128 .50927 Mdot
.49585 .48947 Mdot
.50325 .47029 Mdot
.50399 .49672 Mdot
.42329 .50011 Mdot
.5577 .53918 Mdot
.49936 .48983 Mdot
.52918 .53048 Mdot
.48199 .51002 Mdot
.47635 .43239 Mdot
.43737 .57486 Mdot
.55823 .41688 Mdot
.47707 .43115 Mdot
.52799 .56057 Mdot
.47319 .4443 Mdot
.40936 .49564 Mdot
.41367 .48155 Mdot
.60497 .45381 Mdot
.53067 .49283 Mdot
.41154 .43543 Mdot
.50308 .52624 Mdot
.41749 .55999 Mdot
.48612 .52283 Mdot
.50675 .50463 Mdot
.56677 .54258 Mdot
.4304 .46987 Mdot
.52395 .56638 Mdot
.4039 .50608 Mdot
.49672 .51523 Mdot
.57132 .53416 Mdot
.57716 .4592 Mdot
.58837 .43315 Mdot
.44412 .52843 Mdot
.5039 .51921 Mdot
.52374 .50249 Mdot
.47974 .45001 Mdot
.47843 .56302 Mdot
.40632 .49761 Mdot
.39369 .46362 Mdot
.39293 .53379 Mdot
.60324 .48912 Mdot
.50676 .53793 Mdot
.48285 .44885 Mdot
.45659 .42687 Mdot
.52597 .47334 Mdot
.49377 .53584 Mdot
.43906 .44207 Mdot
.49186 .52794 Mdot
.55696 .43597 Mdot
.49819 .55415 Mdot
.52033 .4267 Mdot
.50648 .55743 Mdot
.50486 .62176 Mdot
.48031 .43737 Mdot
.53588 .60412 Mdot
.48161 .45355 Mdot
.52445 .53682 Mdot
.59651 .51359 Mdot
.58736 .42987 Mdot
.42642 .52659 Mdot
.48256 .44095 Mdot
.52569 .52496 Mdot
.4521 .5234 Mdot
.46756 .54006 Mdot
.44751 .4266 Mdot
.48585 .52411 Mdot
.58902 .46156 Mdot
.49028 .52554 Mdot
.42527 .49125 Mdot
.47994 .43559 Mdot
.5255 .54602 Mdot
.50809 .46838 Mdot
.524 .53397 Mdot
.44264 .5371 Mdot
.53979 .55343 Mdot
.48935 .4655 Mdot
.50406 .52972 Mdot
.60454 .48805 Mdot
.46791 .42651 Mdot
.43746 .53518 Mdot
.45756 .42495 Mdot
.49333 .49241 Mdot
.48699 .5501 Mdot
.4974 .553 Mdot
.51083 .49211 Mdot
.51754 .61383 Mdot
.49732 .56424 Mdot
.55415 .57994 Mdot
.50214 .4629 Mdot
.50033 .48813 Mdot
.47884 .44745 Mdot
.54151 .49636 Mdot
.46432 .45001 Mdot
.5005 .53215 Mdot
.55319 .42559 Mdot
.42388 .52921 Mdot
.49833 .45434 Mdot
.50508 .4658 Mdot
.61447 .49777 Mdot
.60884 .536 Mdot
.56171 .49679 Mdot
.58083 .42376 Mdot
.54427 .5003 Mdot
.50086 .45537 Mdot
.5341 .52767 Mdot
.48024 .54744 Mdot
.41805 .45906 Mdot
.50165 .60018 Mdot
.43009 .58417 Mdot
.61962 .50488 Mdot
.5141 .51869 Mdot
.48865 .46605 Mdot
.41009 .47265 Mdot
.50306 .51528 Mdot
.49115 .50125 Mdot
.56869 .50882 Mdot
.51445 .51914 Mdot
.49946 .48424 Mdot
.57047 .46601 Mdot
.45247 .42872 Mdot
.57641 .52328 Mdot
.5009 .5406 Mdot
.45248 .42421 Mdot
.49169 .53861 Mdot
.388 .49187 Mdot
.44415 .43924 Mdot
.55148 .42427 Mdot
.54241 .57156 Mdot
.41501 .52095 Mdot
.44659 .54891 Mdot
.49704 .51671 Mdot
.47897 .50782 Mdot
.49554 .45073 Mdot
.5239 .51574 Mdot
.39321 .4881 Mdot
.5249 .61142 Mdot
.39684 .53081 Mdot
.47532 .56809 Mdot
.49334 .5108 Mdot
.40556 .43703 Mdot
.47191 .53133 Mdot
.52708 .51496 Mdot
.48698 .4438 Mdot
.59636 .50068 Mdot
.39807 .53032 Mdot
.51501 .47959 Mdot
.49667 .48307 Mdot
.59281 .51613 Mdot
.47102 .44332 Mdot
.4974 .48267 Mdot
.50099 .38831 Mdot
.4848 .51513 Mdot
.5031 .55249 Mdot
.51018 .52805 Mdot
.50806 .53367 Mdot
.43841 .47008 Mdot
.5144 .53896 Mdot
.4687 .55802 Mdot
.49426 .5374 Mdot
.50162 .39659 Mdot
.49383 .52183 Mdot
.59397 .50125 Mdot
.53359 .52177 Mdot
.47431 .51524 Mdot
.47353 .57318 Mdot
.5548 .50442 Mdot
.54223 .45255 Mdot
.5143 .52359 Mdot
.48852 .49442 Mdot
.47931 .54273 Mdot
.51666 .50792 Mdot
.56873 .49447 Mdot
.56063 .59862 Mdot
.41802 .54249 Mdot
.56896 .44196 Mdot
.49387 .45763 Mdot
.50425 .49899 Mdot
.47479 .59804 Mdot
.56146 .4925 Mdot
.58302 .44026 Mdot
.49631 .5273 Mdot
.47642 .51392 Mdot
.52066 .51634 Mdot
.5643 .40988 Mdot
.49149 .51921 Mdot
.50921 .53761 Mdot
.53921 .48124 Mdot
.53774 .39936 Mdot
.48036 .54918 Mdot
.50396 .51261 Mdot
.49124 .38491 Mdot
.49693 .46669 Mdot
.51075 .61463 Mdot
.57772 .44147 Mdot
.6016 .48089 Mdot
.39804 .51572 Mdot
.45432 .53152 Mdot
.54785 .54256 Mdot
.49507 .52611 Mdot
.50983 .47107 Mdot
.41905 .53159 Mdot
.50851 .56809 Mdot
.52057 .57667 Mdot
.53589 .53933 Mdot
.42146 .5606 Mdot
.45998 .42214 Mdot
.50933 .52271 Mdot
.42003 .43019 Mdot
.48602 .55226 Mdot
.48978 .53165 Mdot
.44971 .42913 Mdot
.57709 .4931 Mdot
.49286 .44261 Mdot
.4925 .61621 Mdot
.61478 .48144 Mdot
.55221 .46577 Mdot
.49917 .51393 Mdot
.49538 .44578 Mdot
.49908 .48455 Mdot
.48965 .46647 Mdot
.53097 .54827 Mdot
.5857 .52993 Mdot
.51122 .53917 Mdot
.48832 .44974 Mdot
.57265 .45715 Mdot
.5512 .5101 Mdot
.43155 .55088 Mdot
.39551 .48723 Mdot
.53681 .43859 Mdot
.46183 .60684 Mdot
.48943 .43884 Mdot
.53238 .61452 Mdot
.5006 .51311 Mdot
.51244 .49842 Mdot
.43032 .42728 Mdot
.40095 .44768 Mdot
.49725 .49356 Mdot
.47096 .52666 Mdot
.45565 .51275 Mdot
.48098 .57571 Mdot
.55409 .57369 Mdot
.43484 .54472 Mdot
.50403 .53489 Mdot
.49448 .44204 Mdot
.48199 .45151 Mdot
.42461 .52487 Mdot
.49021 .49269 Mdot
.44626 .567 Mdot
.47058 .43739 Mdot
.47693 .43608 Mdot
.50872 .46828 Mdot
.58387 .47285 Mdot
.59225 .54476 Mdot
.61446 .50902 Mdot
.41654 .43697 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo09Sooooo0_l000000ooooooo0000o`000002o`000:Sooooo000Nooooo`03o`000?oooooooooo
09Sooooo0_l000000ooooooo0000o`000008o`000:;ooooo000Nooooo`03o`000?oooooooooo09oo
oooo1_l0002Rooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o
000000?o410@ooooooooool01?ooool00ol0003oooooooooo`2Qooooo`;o00000_ooool2o`000003
ooooool0003o000009gooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Oooooo`Co00000_ooool2o`000003
ooooool0003o000000;ooooo0_l0002Iooooo`000oooool01Ol@413ooooooooooooooooo410@00_o
oooo1Ol00006ooooo`?o0000Woooool2o`0000?ooooo0_l00005ooooo`?o0000VOooool000?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000oooo
ooooool0Y?ooool2o`0000?ooooo1?l0002Jooooo`000oooool01Ol0003ooooooooooooooooo0000
00_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`2Eooooo`;o00003?ooool2
o`0000?ooooo1Ol00002ooooo`;o0000U_ooool000?ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0UOooool2o`0000cooooo1ol00005
ooooo`;o00000_ooool2o`0009;ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0:Gooooo1?l00003ooooo`;o00000_ooool2
o`000003ooooool0003o000009;ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool0
0omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0:cooooo0_l00002ooooo`?o0000U?ooool0
01kooooo00?o0000ooooooooool0Yoooool2o`0000?ooooo0_l00002ooooo`?o000000?oooooo`00
0?l00000TOooool001kooooo00?o0000ooooooooool0Soooool4o`0001Cooooo0_l00003ooooo`;o
00000_ooool3o`000003ooooool0003o0000097ooooo000Nooooo`03o`000?oooooooooo08Sooooo
0_l00005ooooo`Co000000?oooooo`000?l000006?ooool4o`0000Oooooo0_l0002<ooooo`007_oo
ool00ol0003oooooooooo`28ooooo`;o00000oooool<o`0000cooooo0_l00007ooooo`Co00001ooo
ool2o`0008cooooo000Nooooo`03o`000?oooooooooo08Cooooo0_l00002ooooo`;o00000oooool<
o`0000cooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000000Cooooo0_l00002
ooooo`;o0000R_ooool001kooooo00?o0000ooooooooool0POooool2o`000003ooooool0003o0000
00;ooooo0_l00004ooooo`go00002Oooool2o`0000?ooooo0_l00005ooooo`?o00000_ooool4o`00
0004ooooool0003o0000o`0008[ooooo000Nooooo`03o`000?oooooooooo083ooooo2?l00008oooo
o`Co000000?oooooo`000?l000001_l00007ooooo`;o00002_ooool3o`0000;ooooo0ol00002oooo
o`?o0000R_ooool001kooooo00?o0000ooooooooool0P?ooool8o`0000Cooooo4Ol00002ooooo`;o
00002Oooool3o`0000Cooooo0_l00006ooooo`;o0000S?ooool001kooooo00?o0000ooooooooool0
Poooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000001Ol000000ooooooo0000
o`00000<o`0000Wooooo1?l00007ooooo`;o000000?oooooo`000?l000000ol0002:ooooo`007_oo
ool00ol0003oooooooooo`23ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`00
0008ooooo`[o00002oooool6o`0000Gooooo0_l000001?oooooo0000o`000?ooool2o`0008[ooooo
000Nooooo`03o`000?oooooooooo07gooooo0ol00009ooooo`Co00001_ooool2o`000003ooooool0
003o000000So00002_ooool2o`000004ooooool0003o0000o`0000Wooooo1?l0002:ooooo`007_oo
ool2o`0007kooooo0ol000000ooooooo0000o`000006ooooo`;o00000oooool4o`000004ooooool0
003o0000ooooo`[o00001?ooool4o`0000Cooooo0ol00003ooooo`;o00001?ooool3o`0000?ooooo
0_l00027ooooo`007_ooool00ol0003oooooooooo`21ooooo`;o00002oooool4o`000003ooooool0
003o000000?ooooo2Ol00003ooooo`Co00000_ooool4o`0000Cooooo0_l00004ooooo`?o00000ooo
ool5o`0008Cooooo000Nooooo`03o`000?oooooooooo08Cooooo0_l00004ooooo`;o00003?ooool:
o`0000;ooooo0_l00004ooooo`;o00002_ooool4o`0000Gooooo1?l00024ooooo`007_ooool00ol0
003oooooooooo`24ooooo`Co00000_ooool2o`000003ooooool0003o000000Wooooo2_l00002oooo
o`;o00004?ooool4o`000004ooooool0003o0000o`0000Cooooo0_l00023ooooo`007_ooool00ol0
003oooooooooo`1looooo`;o00001oooool3o`0000;ooooo0_l000000ooooooo0000o`00000;oooo
o`So00002?ooool2o`0000?ooooo0_l0000:ooooo`?o00001?ooool2o`0008?ooooo000Nooooo`03
o`000?oooooooooo07cooooo0ol00003ooooo`;o00002Oooool2o`0000Gooooo0_l00005ooooo`Wo
00001_ooool4o`000003ooooool0003o000000Cooooo0_l0002@ooooo`007_ooool00ol0003ooooo
ooooo`1looooo`So00001?ooool4o`0000Sooooo0_l00005ooooo`Wo00002?ooool2o`0000Oooooo
0_l0002@ooooo`007_ooool00ol0003oooooooooo`1looooo`;o000000?oooooo`000?l000000_l0
0005ooooo`Co00004?ooool8o`0000?ooooo0_l000000ooooooo0000o`000009ooooo`Co000000?o
ooooo`000?l00000Roooool001kooooo00?o0000ooooooooool0O_ooool2o`000003ooooool0003o
000001?ooooo0_l00002ooooo`_o00000_ooool2o`000003ooooool0003o000000_ooooo0_l00000
0ooooooo0000o`00002;ooooo`007_ooool00ol0003oooooooooo`1looooo`Co00000oooool2o`00
00kooooo0_l000000ooooooo0000o`000002ooooo`_o00001_ooool2o`0000[ooooo1?l00002oooo
o`Co0000Q_ooool001kooooo00?o0000ooooooooool0O?ooool9o`0000kooooo0_l00006ooooo`[o
00001_ooool2o`0000Kooooo2?l000000ooooooo0000o`000003o`000003ooooool0003o000000;o
0000POooool001kooooo00?o0000ooooooooool0O?ooool8o`0000Wooooo0_l0000:ooooo`;o0000
0_ooool9o`0000Kooooo0_l00005ooooo`Co00001?ooool3o`0000Cooooo1?l00021ooooo`007_oo
ool00ol0003oooooooooo`1looooo`;o000000Coooooo`000?l0003ooooo0_l00005ooooo`Ko0000
00?oooooo`000?l000001oooool=o`0000Gooooo0ol00007ooooo`Co00000_ooool2o`0000;ooooo
0ol00025ooooo`007_ooool00ol0003oooooooooo`1jooooo`Oo00001Oooool2o`000003ooooool0
003o000000;o00000oooool2o`0000Wooooo3ol000000ooooooo0000o`000005ooooo`;o00000_oo
ool4o`0000;ooooo1_l00025ooooo`007_ooool00ol0003oooooooooo`1jooooo`Wo00000oooool2
o`0001;ooooo4?l00002ooooo`;o00000_ooool4o`000004ooooool0003o0000ooooo`;o00000_oo
ool3o`0008Sooooo000Nooooo`03o`000?oooooooooo07_ooooo2?l00004ooooo`;o00000_ooool2
o`0000gooooo3Ol00004ooooo`?o00000_ooool2o`000003ooooool0003o000000;o00003Oooool2
o`00087ooooo000Nooooo`;o0000OOooool6o`0000Cooooo0ol000001?oooooo0000o`000?l00002
ooooo`;o00002Oooool?o`000003ooooool0003o000000Go00000_ooool3o`0000Gooooo1Ol00004
ooooo`?o0000P?ooool001kooooo00?o0000ooooooooool0O?ooool2o`0000Sooooo0_l00002oooo
o`;o00000oooool2o`0000Cooooo0_l00003ooooo`oo000000Coooooo`000?l0003ooooo1Ol00002
ooooo`;o00001?ooool6o`0000Gooooo0_l00020ooooo`007_ooool00ol0003oooooooooo`1joooo
o`;o00000oooool3o`0001?ooooo0_l000000ooooooo0000o`00000?o`000004ooooool0003o0000
ooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo0_l00009ooooo`;o0000P?ooool0
01kooooo00?o0000ooooooooool0N_ooool2o`0000?ooooo0ol0000Aooooo`;o000000?oooooo`00
0?l000001_l00003oooooa3o00001?ooool2o`0000?ooooo0_l00008ooooo`;o0000POooool001ko
oooo00?o0000ooooooooool0N_ooool2o`0001Cooooo0_l000001?oooooo0000o`000?oooolKo`00
0003ooooool0003o000000;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00000_ooool4
o`00087ooooo000Nooooo`03o`000?oooooooooo07[ooooo0_l000000ooooooo0000o`000008oooo
o`Co00001Oooool5o`000003ooooool0003o0000017o000000?oooooo`000?l000001Oooool5o`00
0003ooooool0003o000000Cooooo1?l000000ooooooo0000o`000023ooooo`007_ooool00ol0003o
ooooooooo`1looooo`?o00001?ooool3o`000003ooooool0003o000000;o00000_ooool2o`000003
ooooool0003o000001ko000000Coooooo`000?l0003o00000_ooool2o`0000Gooooo1?l00026oooo
o`007_ooool00ol0003oooooooooo`1looooo`;o00001Oooool3o`0000?ooooo9ol00002ooooo`Oo
0000S_ooool001kooooo00?o0000ooooooooool0P?ooool2o`000003ooooool0003o000000Wo0000
00Coooooo`000?l0003ooooo6ol000001Ooooooo0000o`000?l0003ooooo00Oo000000?oooooo`00
0?l00000Roooool001kooooo00?o0000ooooooooool0O?ooool6o`000003ooooool0003o000000Co
00000oooool2o`0000Kooooo6Ol00002ooooo`Go000000?oooooo`000?l000001Ol00006ooooo`;o
0000Poooool001kooooo00?o0000ooooooooool0Noooool5o`0000?ooooo1Ol00004ooooo`;o0000
00Coooooo`000?l0003o00000_ooool:o`000003ooooool0003o000000_o00001?ooool4o`000003
ooooool0003o000000Oo00001?ooool2o`0008?ooooo000Nooooo`03o`000?oooooooooo07_ooooo
1?l00005ooooo`;o00001?ooool2o`0000?ooooo0ol00003oooooaGo00000_ooool9o`000003oooo
ool0003o000000Cooooo0_l00004ooooo`;o0000Poooool001kooooo00?o0000ooooooooool0O?oo
ool3o`0000Gooooo0_l00004ooooo`Co00001?ooool2o`000003ooooool0003o000000So000000?o
ooooo`000?l000005_l00002ooooo`;o00001_ooool2o`0008?ooooo000Nooooo`03o`000?oooooo
oooo07gooooo0_l00003ooooo`Ko00001?ooool2o`0000Cooooo2?l000000ooooooo0000o`00000K
o`0000;ooooo0_l00006ooooo`;o0000Poooool001kooooo00?o0000ooooooooool0P_ooool:o`00
00;ooooo0_l00004ooooo`go000000?oooooo`000?l000001ol00002ooooo`Co00000oooool4o`00
00Cooooo0_l00029ooooo`007_ooool00ol0003oooooooooo`1nooooo`Wo000000?oooooo`000?l0
00000_l000001?oooooo0000o`000?l00004ooooo`So00002?ooool7o`000003ooooool0003o0000
00?o00002oooool2o`0000;ooooo0_l00025ooooo`007_ooool2o`0007oooooo1ol00003ooooo`;o
00000oooool2o`0000Gooooo0_l00002ooooo`Co000000?oooooo`000?l000001oooool5o`000003
ooooool0003o000000?o00001_ooool2o`0000Oooooo0_l00025ooooo`007_ooool00ol0003ooooo
ooooo`23ooooo`;o00000oooool2o`0000Wooooo2Ol000000ooooooo0000o`000002o`0000[ooooo
0ol000000ooooooo0000o`000006ooooo`;o00001Oooool2o`0008Oooooo000Nooooo`03o`000?oo
oooooooo083ooooo0_l000000ooooooo0000o`000003o`0000Wooooo2?l000001?oooooo0000o`00
0?ooool6o`0000Sooooo0ol000000ooooooo0000o`00000=ooooo`Co0000QOooool001kooooo00?o
0000ooooooooool0O_ooool4o`000003ooooool0003o000000?o00002Oooool5o`000004ooooool0
003o0000ooooo`;o000000?oooooo`000?l000001?l00005ooooo`;o00004_ooool2o`0000;ooooo
0_l00025ooooo`007_ooool00ol0003oooooooooo`1nooooo`;o000000?oooooo`000?l000001Ol0
000>ooooo`?o000000Coooooo`000?l0003ooooo0ol00008ooooo`;o00002Oooool2o`0000Oooooo
0_l00029ooooo`007_ooool00ol0003oooooooooo`21ooooo`Oo000000?oooooo`000?l000000_oo
ool2o`0000Gooooo1Ol00002ooooo`Go00001_ooool2o`0000_ooooo0_l00009ooooo`;o0000Qooo
ool001kooooo00?o0000ooooooooool0P_ooool2o`0000Gooooo0_l000001?oooooo0000o`000?l0
0005ooooo`Co00000oooool4o`0000;ooooo0_l00002ooooo`?o000000?oooooo`000?l000003ooo
ool2o`0000;ooooo0_l00027ooooo`007_ooool00ol0003oooooooooo`22ooooo`;o00002?ooool2
o`0000?ooooo0_l00002ooooo`?o000000?oooooo`000?l000001_ooool2o`0000;ooooo0_l00000
1Ooooooo0000o`000?l0003ooooo00;o00000oooool2o`0000Oooooo1Ol00028ooooo`007_ooool0
0ol0003oooooooooo`23ooooo`Co00000oooool2o`0000Gooooo0_l00002ooooo`Ko00003Oooool6
o`0000;ooooo0ol00009ooooo`?o0000R?ooool001kooooo00?o0000ooooooooool0Poooool4o`00
00?ooooo0_l00005ooooo`;o00000_ooool5o`0000_ooooo0_l00003ooooo`;o00001?ooool2o`00
00Gooooo0_l00004ooooo`;o0000R?ooool001kooooo00?o0000ooooooooool0TOooool2o`000003
ooooool0003o000000kooooo0ol00009ooooo`?o00001?ooool2o`0008kooooo000Nooooo`03o`00
0?oooooooooo08Oooooo0ol000000ooooooo0000o`000007ooooo`;o000000?oooooo`000?l00000
2oooool5o`0000Oooooo0ol0002Dooooo`007_ooool00ol0003oooooooooo`27ooooo`Ko00002Ooo
ool4o`0000_ooooo1?l00006ooooo`;o00000oooool2o`00097ooooo000Nooooo`03o`000?oooooo
oooo08Wooooo1?l00005ooooo`?o000000?oooooo`000?l000000_l0000>ooooo`?o00001?ooool2
o`000003ooooool0003o000000;o0000TOooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0T_oo
ool3o`0000Oooooo0_l0000:ooooo`?o00001?ooool2o`000003ooooool0003o000000?ooooo0_l0
002>ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2Eooooo`?o00001?ooool2o`0001Sooooo
0ol0002>ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooooooo
ooooo`000006ooooo`?o0000T?ooool2o`0000?ooooo0ol00007ooooo`;o00004Oooool2o`0000;o
oooo0_l0002?ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo093ooooo0_l000000ooooooo0000o`00000:oooo
o`Go00001_ooool2o`0000Kooooo0_l0002Cooooo`000oooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo09;ooooo0ol00008
ooooo`Oo00001_ooool2o`000003ooooool0003o000009Sooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo09;ooooo0ol00003
ooooo`?o00000_ooool4o`0000cooooo0_l0002Hooooo`000oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`2Cooooo`;o00000oooool3
o`0000;ooooo0_l00007ooooo`?o00001?ooool2o`0009Sooooo0003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo09cooooo0_l0
0004ooooo`Wo0000W?ooool001kooooo00?o0000ooooooooool0W?ooool2o`0000Cooooo1_l00000
0ooooooo0000o`00002Looooo`007_ooool00ol0003oooooooooo`2Pooooo`?o000000Coooooo`00
0?l0003o0000X?ooool001kooooo00?o0000ooooooooool0X?ooool3o`000004ooooool0003o0000
o`000:3ooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003o
ooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oooooo
B?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RH
oooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol@413ooooo
oooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000oooooom8oooo
o`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06
ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`3oooooodSooooo0003
ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo
00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Dooooo`Co000000?o410@ooooooooool00oooool00ol0003ooooooooo
o`3oooooodSooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom8
ooooo`005_ooool00ol0003oooooooooo`05ooooo`?o0000oooooom8ooooo`005_ooool00ol0003o
ooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o
0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Doooo
o`03oeEEEOmVIVKo00000?ooooooD_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.42622 .50824 Mdot
.47367 .53059 Mdot
.5576 .56304 Mdot
.47555 .52195 Mdot
.48228 .49623 Mdot
.41423 .46149 Mdot
.58414 .58823 Mdot
.46723 .5024 Mdot
.55718 .40763 Mdot
.49782 .42947 Mdot
.4603 .46785 Mdot
.50989 .52139 Mdot
.40486 .4709 Mdot
.47004 .58721 Mdot
.61038 .47108 Mdot
.50807 .44435 Mdot
.45711 .52661 Mdot
.45805 .41298 Mdot
.49268 .42142 Mdot
.53456 .53415 Mdot
.4558 .52499 Mdot
.51668 .46257 Mdot
.49904 .47834 Mdot
.4056 .53105 Mdot
.45568 .51134 Mdot
.50941 .5063 Mdot
.5909 .46931 Mdot
.4861 .41462 Mdot
.48823 .4998 Mdot
.40538 .48984 Mdot
.50434 .56049 Mdot
.46412 .52229 Mdot
.50157 .4815 Mdot
.55461 .54537 Mdot
.40408 .47967 Mdot
.54809 .55232 Mdot
.50759 .49285 Mdot
.56715 .4486 Mdot
.49264 .48352 Mdot
.51517 .52292 Mdot
.50285 .45388 Mdot
.53499 .51552 Mdot
.49789 .54754 Mdot
.50531 .50536 Mdot
.4607 .51828 Mdot
.51411 .46841 Mdot
.48251 .60073 Mdot
.5044 .56895 Mdot
.52623 .55336 Mdot
.51368 .37611 Mdot
.48966 .48752 Mdot
.39007 .472 Mdot
.48844 .50423 Mdot
.48307 .49194 Mdot
.50798 .43939 Mdot
.51757 .50021 Mdot
.50905 .5409 Mdot
.37834 .48504 Mdot
.46636 .51293 Mdot
.51108 .54334 Mdot
.52141 .47533 Mdot
.51098 .4756 Mdot
.54688 .54133 Mdot
.50667 .44488 Mdot
.49703 .48199 Mdot
.55132 .39355 Mdot
.46701 .55303 Mdot
.51882 .48058 Mdot
.52266 .52252 Mdot
.51005 .4443 Mdot
.60781 .53379 Mdot
.47283 .50929 Mdot
.51855 .54126 Mdot
.49347 .51658 Mdot
.40167 .50789 Mdot
.59357 .5054 Mdot
.52196 .50657 Mdot
.45605 .41361 Mdot
.60319 .54881 Mdot
.48581 .43301 Mdot
.56553 .47257 Mdot
.46431 .50323 Mdot
.45746 .51708 Mdot
.50665 .4601 Mdot
.54976 .5426 Mdot
.49143 .51226 Mdot
.57657 .53474 Mdot
.516 .48186 Mdot
.51511 .52797 Mdot
.42354 .43038 Mdot
.495 .49276 Mdot
.5135 .46021 Mdot
.57693 .50364 Mdot
.53355 .38172 Mdot
.57755 .5726 Mdot
.5204 .48904 Mdot
.51766 .48827 Mdot
.49439 .56352 Mdot
.48808 .6024 Mdot
.50155 .54062 Mdot
.57782 .52809 Mdot
.57087 .51307 Mdot
.4703 .50483 Mdot
.50243 .3799 Mdot
.57292 .41982 Mdot
.50048 .48106 Mdot
.49692 .6345 Mdot
.49504 .48675 Mdot
.47211 .54661 Mdot
.51422 .45901 Mdot
.41434 .52889 Mdot
.47236 .51088 Mdot
.49478 .52936 Mdot
.54669 .41625 Mdot
.45356 .55076 Mdot
.39949 .45979 Mdot
.58025 .45094 Mdot
.48431 .41653 Mdot
.53408 .57688 Mdot
.57853 .49771 Mdot
.45451 .42806 Mdot
.50793 .50779 Mdot
.49984 .43109 Mdot
.51634 .55658 Mdot
.46335 .52946 Mdot
.5317 .41645 Mdot
.40736 .52439 Mdot
.50811 .50629 Mdot
.50542 .504 Mdot
.50156 .44562 Mdot
.47039 .43131 Mdot
.45429 .53342 Mdot
.3855 .53063 Mdot
.54068 .55033 Mdot
.47939 .49213 Mdot
.39391 .54832 Mdot
.49115 .41525 Mdot
.50087 .49965 Mdot
.52289 .53482 Mdot
.5008 .52111 Mdot
.49487 .48925 Mdot
.57318 .42713 Mdot
.50301 .4952 Mdot
.47828 .51559 Mdot
.50321 .47375 Mdot
.51626 .46071 Mdot
.42029 .50251 Mdot
.51959 .49209 Mdot
.45335 .55256 Mdot
.51974 .55342 Mdot
.54369 .54578 Mdot
.4856 .41449 Mdot
.48922 .49302 Mdot
.46021 .57543 Mdot
.46625 .44281 Mdot
.50846 .4442 Mdot
.50821 .47291 Mdot
.39059 .50985 Mdot
.52203 .50786 Mdot
.50319 .47947 Mdot
.61284 .5046 Mdot
.52524 .51498 Mdot
.44835 .42327 Mdot
.51099 .4425 Mdot
.51366 .53405 Mdot
.50239 .53416 Mdot
.58242 .42995 Mdot
.55113 .46297 Mdot
.52508 .48134 Mdot
.55509 .43242 Mdot
.47891 .4214 Mdot
.5153 .55239 Mdot
.47621 .53439 Mdot
.5157 .53406 Mdot
.62033 .52119 Mdot
.51321 .49155 Mdot
.518 .48226 Mdot
.50265 .47866 Mdot
.44352 .59753 Mdot
.53173 .55079 Mdot
.47837 .51965 Mdot
.52006 .48279 Mdot
.49797 .51031 Mdot
.48717 .5042 Mdot
.404 .46582 Mdot
.50736 .52266 Mdot
.56953 .54424 Mdot
.5219 .47828 Mdot
.53245 .38429 Mdot
.58286 .50289 Mdot
.50392 .51435 Mdot
.49661 .45068 Mdot
.41319 .53903 Mdot
.49142 .49063 Mdot
.55992 .43848 Mdot
.49819 .4564 Mdot
.51738 .3759 Mdot
.50338 .49237 Mdot
.50149 .47603 Mdot
.47847 .52594 Mdot
.49465 .53963 Mdot
.52071 .48398 Mdot
.46181 .42556 Mdot
.54046 .47774 Mdot
.50371 .43788 Mdot
.47891 .53586 Mdot
.45339 .531 Mdot
.50285 .54268 Mdot
.55913 .54712 Mdot
.48961 .49047 Mdot
.45963 .51924 Mdot
.50552 .49469 Mdot
.51879 .52516 Mdot
.43904 .44096 Mdot
.50813 .50833 Mdot
.47392 .60228 Mdot
.51522 .46456 Mdot
.52147 .51127 Mdot
.5715 .42639 Mdot
.4986 .48524 Mdot
.50344 .45563 Mdot
.38161 .49937 Mdot
.51584 .46164 Mdot
.42428 .5711 Mdot
.46686 .48563 Mdot
.46694 .49996 Mdot
.46753 .52036 Mdot
.50174 .43036 Mdot
.56517 .5478 Mdot
.48959 .45091 Mdot
.50392 .44563 Mdot
.50489 .49634 Mdot
.55937 .4222 Mdot
.50533 .478 Mdot
.51197 .50193 Mdot
.52326 .53621 Mdot
.54338 .41953 Mdot
.59315 .51504 Mdot
.4644 .53622 Mdot
.50746 .5227 Mdot
.50081 .42961 Mdot
.60933 .47612 Mdot
.4144 .51177 Mdot
.53793 .42039 Mdot
.56163 .58942 Mdot
.5102 .44142 Mdot
.59703 .50155 Mdot
.46932 .49968 Mdot
.50873 .44124 Mdot
.5837 .4487 Mdot
.49883 .54656 Mdot
.40494 .46015 Mdot
.59869 .46606 Mdot
.56913 .5814 Mdot
.49498 .52563 Mdot
.50783 .5293 Mdot
.504 .46152 Mdot
.51941 .51588 Mdot
.55259 .54254 Mdot
.58845 .44685 Mdot
.55219 .46789 Mdot
.49567 .45291 Mdot
.50339 .47918 Mdot
.45393 .43729 Mdot
.53667 .54088 Mdot
.54502 .53849 Mdot
.4941 .45888 Mdot
.47231 .41744 Mdot
.49814 .46197 Mdot
.43531 .59224 Mdot
.47437 .54925 Mdot
.49515 .52953 Mdot
.5364 .38509 Mdot
.499 .52513 Mdot
.56858 .55346 Mdot
.60181 .51056 Mdot
.52029 .50097 Mdot
.49283 .42401 Mdot
.53171 .53314 Mdot
.49033 .43196 Mdot
.52329 .5302 Mdot
.51372 .50965 Mdot
.49589 .58378 Mdot
.50452 .48623 Mdot
.56887 .43901 Mdot
.52862 .38035 Mdot
.46062 .60339 Mdot
.50502 .46482 Mdot
.46799 .53524 Mdot
.45663 .57385 Mdot
.511 .53148 Mdot
.45591 .56178 Mdot
.40433 .45267 Mdot
.50646 .54976 Mdot
.50203 .53427 Mdot
.4783 .49602 Mdot
.48029 .41567 Mdot
.53319 .54915 Mdot
.54036 .51027 Mdot
.47439 .52106 Mdot
.5052 .49838 Mdot
.46694 .49939 Mdot
.5697 .41401 Mdot
.51652 .45114 Mdot
.51026 .5268 Mdot
.47536 .52043 Mdot
.40363 .57452 Mdot
.43116 .55074 Mdot
.45251 .51264 Mdot
.53492 .54318 Mdot
.48411 .52152 Mdot
.50418 .48467 Mdot
.4985 .44548 Mdot
.44046 .50652 Mdot
.48093 .5287 Mdot
.45365 .55362 Mdot
.51558 .52174 Mdot
.51763 .48103 Mdot
.51971 .53888 Mdot
.56074 .44336 Mdot
.52687 .55112 Mdot
.45216 .47283 Mdot
.44648 .4697 Mdot
.51507 .49434 Mdot
.48204 .42023 Mdot
.54172 .43246 Mdot
.50475 .51085 Mdot
.50573 .5055 Mdot
.53787 .40416 Mdot
.56341 .50557 Mdot
.41557 .50171 Mdot
.39468 .47182 Mdot
.49542 .53057 Mdot
.49658 .42846 Mdot
.55566 .54808 Mdot
.4945 .44199 Mdot
.54196 .54672 Mdot
.47351 .51572 Mdot
.44749 .48682 Mdot
.51233 .47821 Mdot
.47023 .55398 Mdot
.44579 .55271 Mdot
.52592 .62026 Mdot
.50251 .49148 Mdot
.53016 .45262 Mdot
.45586 .5472 Mdot
.50442 .48819 Mdot
.47166 .50072 Mdot
.55374 .46556 Mdot
.50682 .45977 Mdot
.51043 .53726 Mdot
.38483 .52248 Mdot
.45707 .52323 Mdot
.50721 .48387 Mdot
.41656 .44713 Mdot
.50632 .53494 Mdot
.45042 .58693 Mdot
.45775 .53776 Mdot
.40707 .44381 Mdot
.50017 .47858 Mdot
.49888 .47875 Mdot
.45281 .5564 Mdot
.49994 .53196 Mdot
.44756 .57965 Mdot
.45766 .54084 Mdot
.50328 .58535 Mdot
.53989 .59716 Mdot
.54741 .45977 Mdot
.4418 .60506 Mdot
.49265 .51059 Mdot
.50293 .47979 Mdot
.49946 .49669 Mdot
.38444 .51112 Mdot
.47311 .47269 Mdot
.54367 .57024 Mdot
.50102 .43403 Mdot
.48366 .46271 Mdot
.58425 .52564 Mdot
.53292 .52303 Mdot
.50716 .4981 Mdot
.53755 .5459 Mdot
.58666 .56879 Mdot
.47792 .50938 Mdot
.40677 .54643 Mdot
.46667 .51813 Mdot
.42201 .46101 Mdot
.486 .4146 Mdot
.498 .44421 Mdot
.51653 .50403 Mdot
.53566 .54643 Mdot
.39342 .55596 Mdot
.52923 .52629 Mdot
.52892 .55056 Mdot
.46377 .52147 Mdot
.50206 .47356 Mdot
.46518 .50607 Mdot
.51445 .45187 Mdot
.50322 .48138 Mdot
.48243 .41898 Mdot
.40053 .56365 Mdot
.41212 .57681 Mdot
.53873 .54912 Mdot
.38111 .54715 Mdot
.51376 .51133 Mdot
.52723 .54929 Mdot
.54209 .55225 Mdot
.48501 .50648 Mdot
.50096 .48305 Mdot
.49362 .54168 Mdot
.48379 .42678 Mdot
.50312 .5204 Mdot
.48789 .42559 Mdot
.49404 .51454 Mdot
.50722 .56685 Mdot
.49507 .50893 Mdot
.57349 .5138 Mdot
.51422 .45513 Mdot
.42032 .54901 Mdot
.50986 .547 Mdot
.50203 .43173 Mdot
.48866 .43065 Mdot
.51575 .47103 Mdot
.49835 .51114 Mdot
.4937 .42824 Mdot
.37586 .51331 Mdot
.54418 .54989 Mdot
.59913 .44842 Mdot
.49952 .46013 Mdot
.52611 .53407 Mdot
.51848 .52306 Mdot
.45033 .5665 Mdot
.51032 .4447 Mdot
.45099 .53497 Mdot
.48801 .43053 Mdot
.53083 .4737 Mdot
.41113 .54022 Mdot
.52596 .47646 Mdot
.51018 .54105 Mdot
.44261 .56283 Mdot
.51511 .53461 Mdot
.50698 .55134 Mdot
.40869 .42799 Mdot
.45758 .56932 Mdot
.45592 .43943 Mdot
.50033 .47979 Mdot
.47194 .4231 Mdot
.478 .50321 Mdot
.50371 .4396 Mdot
.55432 .54742 Mdot
.49262 .49488 Mdot
.50919 .59389 Mdot
.50523 .52326 Mdot
.50512 .45557 Mdot
.51604 .53276 Mdot
.5593 .5259 Mdot
.55119 .4093 Mdot
.54246 .5458 Mdot
.56471 .45147 Mdot
.50162 .48697 Mdot
.51897 .51972 Mdot
.54235 .48996 Mdot
.49128 .52093 Mdot
.51082 .57309 Mdot
.50416 .47865 Mdot
.52292 .55015 Mdot
.42088 .57587 Mdot
.5021 .46766 Mdot
.49955 .51334 Mdot
.46152 .55993 Mdot
.52009 .51739 Mdot
.43637 .48305 Mdot
.49214 .4384 Mdot
.55925 .61563 Mdot
.62242 .48147 Mdot
.48434 .42142 Mdot
.55714 .41002 Mdot
.5276 .56009 Mdot
.62324 .48031 Mdot
.57966 .5276 Mdot
.39102 .54152 Mdot
.50396 .48539 Mdot
.45735 .52247 Mdot
.46596 .50155 Mdot
.46526 .50966 Mdot
.51723 .47182 Mdot
.53925 .48791 Mdot
.49523 .42966 Mdot
.42356 .50889 Mdot
.51978 .55158 Mdot
.58495 .52415 Mdot
.39829 .4463 Mdot
.56353 .54637 Mdot
.542 .39503 Mdot
.50153 .47751 Mdot
.50019 .54468 Mdot
.41306 .44866 Mdot
.57041 .43247 Mdot
.50329 .47551 Mdot
.53697 .49832 Mdot
.45838 .50441 Mdot
.50182 .62784 Mdot
.59884 .46015 Mdot
.56203 .60852 Mdot
.49619 .44557 Mdot
.50684 .52391 Mdot
.49863 .42796 Mdot
.43317 .52597 Mdot
.49623 .43823 Mdot
.59058 .53817 Mdot
.52115 .3782 Mdot
.52894 .52645 Mdot
.54774 .54411 Mdot
.49399 .54541 Mdot
.41623 .45311 Mdot
.46308 .50104 Mdot
.51041 .44667 Mdot
.49647 .54551 Mdot
.40547 .47684 Mdot
.50449 .59224 Mdot
.44162 .50028 Mdot
.50775 .43974 Mdot
.4701 .5497 Mdot
.44822 .50756 Mdot
.50954 .50333 Mdot
.50543 .53183 Mdot
.51779 .49072 Mdot
.53607 .551 Mdot
.39117 .46612 Mdot
.47673 .42444 Mdot
.48521 .42342 Mdot
.54894 .52172 Mdot
.51645 .46073 Mdot
.52005 .50264 Mdot
.49181 .52178 Mdot
.53093 .38586 Mdot
.50828 .51748 Mdot
.39668 .53167 Mdot
.51889 .47772 Mdot
.50634 .54251 Mdot
.49582 .42347 Mdot
.49587 .5265 Mdot
.44619 .42158 Mdot
.51617 .45633 Mdot
.40421 .53806 Mdot
.47555 .4328 Mdot
.59707 .4833 Mdot
.47998 .51026 Mdot
.43954 .41737 Mdot
.47217 .50707 Mdot
.49209 .43432 Mdot
.5145 .52757 Mdot
.48517 .49084 Mdot
.50291 .47709 Mdot
.48589 .62863 Mdot
.47011 .51508 Mdot
.50194 .45556 Mdot
.49832 .49038 Mdot
.52237 .54733 Mdot
.40086 .44623 Mdot
.58446 .47389 Mdot
.56839 .50904 Mdot
.56071 .54171 Mdot
.50229 .43724 Mdot
.49163 .50646 Mdot
.53781 .52809 Mdot
.5037 .46053 Mdot
.58511 .59402 Mdot
.49001 .43278 Mdot
.40388 .54139 Mdot
.52585 .55777 Mdot
.43451 .59126 Mdot
.50664 .50139 Mdot
.51687 .54802 Mdot
.47193 .5029 Mdot
.50588 .52179 Mdot
.50688 .45033 Mdot
.43458 .42145 Mdot
.51469 .52628 Mdot
.58953 .51693 Mdot
.51083 .51494 Mdot
.57437 .54874 Mdot
.47401 .50838 Mdot
.5257 .62303 Mdot
.48966 .54011 Mdot
.52381 .5139 Mdot
.47309 .6098 Mdot
.47694 .49499 Mdot
.46457 .54703 Mdot
.45375 .5458 Mdot
.54796 .53781 Mdot
.50791 .52443 Mdot
.51138 .46426 Mdot
.5031 .47386 Mdot
.50595 .51294 Mdot
.50249 .44084 Mdot
.41544 .50422 Mdot
.4126 .54626 Mdot
.51727 .47907 Mdot
.44963 .42255 Mdot
.47665 .53211 Mdot
.54211 .46761 Mdot
.51185 .4547 Mdot
.43322 .4985 Mdot
.4257 .44378 Mdot
.51123 .46276 Mdot
.48016 .54811 Mdot
.49485 .44409 Mdot
.53055 .59156 Mdot
.51065 .47666 Mdot
.50622 .50781 Mdot
.48031 .41551 Mdot
.41953 .52467 Mdot
.50121 .4688 Mdot
.47945 .60579 Mdot
.42156 .51077 Mdot
.48566 .49723 Mdot
.49739 .47883 Mdot
.50777 .43779 Mdot
.49694 .48258 Mdot
.61904 .50308 Mdot
.58747 .58304 Mdot
.38743 .47332 Mdot
.4909 .5273 Mdot
.50835 .47377 Mdot
.54785 .59832 Mdot
.53562 .54512 Mdot
.49121 .49334 Mdot
.50032 .49169 Mdot
.3967 .55053 Mdot
.46963 .53485 Mdot
.52047 .47609 Mdot
.50656 .44126 Mdot
.52157 .55472 Mdot
.44837 .41668 Mdot
.44357 .42179 Mdot
.45196 .48345 Mdot
.58867 .50938 Mdot
.50067 .51542 Mdot
.46837 .50865 Mdot
.46022 .603 Mdot
.47243 .49875 Mdot
.52129 .50451 Mdot
.53065 .59725 Mdot
.49948 .46284 Mdot
.49997 .44414 Mdot
.43432 .44013 Mdot
.42011 .44686 Mdot
.50143 .47699 Mdot
.58009 .58628 Mdot
.59658 .56661 Mdot
.4484 .50445 Mdot
.50349 .4775 Mdot
.50265 .48958 Mdot
.47247 .54634 Mdot
.49541 .53489 Mdot
.50142 .54751 Mdot
.56385 .4007 Mdot
.50228 .51449 Mdot
.54302 .52763 Mdot
.50647 .51333 Mdot
.47142 .50732 Mdot
.50144 .47314 Mdot
.44518 .57953 Mdot
.3758 .49221 Mdot
.50106 .62165 Mdot
.54457 .54538 Mdot
.54452 .4477 Mdot
.39248 .56388 Mdot
.415 .52201 Mdot
.6022 .43708 Mdot
.47058 .53272 Mdot
.37803 .51048 Mdot
.41 .5763 Mdot
.50943 .45702 Mdot
.497 .44593 Mdot
.50169 .43451 Mdot
.52394 .54078 Mdot
.46146 .51726 Mdot
.48321 .41363 Mdot
.47766 .4961 Mdot
.5209 .47533 Mdot
.56846 .50727 Mdot
.47325 .5399 Mdot
.57307 .49215 Mdot
.45961 .52373 Mdot
.52136 .48651 Mdot
.46554 .531 Mdot
.40622 .46077 Mdot
.51788 .53316 Mdot
.52946 .53923 Mdot
.52117 .4999 Mdot
.55063 .55448 Mdot
.38706 .47877 Mdot
.51383 .50194 Mdot
.52939 .54816 Mdot
.44433 .52519 Mdot
.49623 .63273 Mdot
.50471 .49882 Mdot
.5132 .4568 Mdot
.47369 .51929 Mdot
.48837 .48755 Mdot
.50885 .51694 Mdot
.49221 .57882 Mdot
.49652 .48259 Mdot
.53846 .58669 Mdot
.60553 .55782 Mdot
.51636 .48857 Mdot
.48836 .48974 Mdot
.55482 .53746 Mdot
.49341 .42804 Mdot
.52969 .39396 Mdot
.50632 .50979 Mdot
.5646 .5355 Mdot
.48592 .42469 Mdot
.4541 .57464 Mdot
.5912 .47198 Mdot
.4869 .42561 Mdot
.44896 .53497 Mdot
.41661 .46502 Mdot
.48057 .4136 Mdot
.4889 .51362 Mdot
.48274 .42509 Mdot
.52568 .53702 Mdot
.48957 .51998 Mdot
.42507 .52672 Mdot
.50728 .53786 Mdot
.42902 .4151 Mdot
.43684 .44088 Mdot
.3969 .53211 Mdot
.52128 .49615 Mdot
.46454 .44585 Mdot
.50676 .45645 Mdot
.50877 .53567 Mdot
.50495 .46846 Mdot
.39589 .45858 Mdot
.59371 .57478 Mdot
.51155 .49677 Mdot
.51605 .47269 Mdot
.49041 .42356 Mdot
.52038 .51208 Mdot
.51406 .46624 Mdot
.39866 .47629 Mdot
.51406 .50582 Mdot
.4554 .50196 Mdot
.50267 .4631 Mdot
.48426 .49174 Mdot
.501 .47857 Mdot
.51505 .48173 Mdot
.50496 .50227 Mdot
.42956 .483 Mdot
.53507 .55163 Mdot
.50301 .48463 Mdot
.51321 .53969 Mdot
.48384 .49317 Mdot
.50121 .44575 Mdot
.42147 .5605 Mdot
.57475 .42822 Mdot
.50059 .43286 Mdot
.50192 .55937 Mdot
.49072 .43422 Mdot
.41191 .47623 Mdot
.42037 .4613 Mdot
.62195 .47195 Mdot
.52844 .51737 Mdot
.4308 .41579 Mdot
.494 .52202 Mdot
.40294 .54492 Mdot
.48107 .50967 Mdot
.50545 .50776 Mdot
.54463 .55429 Mdot
.44342 .44951 Mdot
.4983 .56337 Mdot
.40269 .48693 Mdot
.49359 .50823 Mdot
.55137 .54986 Mdot
.58335 .48047 Mdot
.60538 .44727 Mdot
.44766 .51035 Mdot
.49765 .51661 Mdot
.52037 .52148 Mdot
.49405 .44663 Mdot
.45819 .54814 Mdot
.40744 .47797 Mdot
.40116 .43972 Mdot
.37719 .51554 Mdot
.60346 .5119 Mdot
.48948 .53558 Mdot
.50165 .4504 Mdot
.48095 .41823 Mdot
.52787 .49882 Mdot
.48024 .52778 Mdot
.45984 .42371 Mdot
.48365 .51802 Mdot
.56736 .4536 Mdot
.47392 .54475 Mdot
.53491 .44389 Mdot
.48124 .55028 Mdot
.48249 .631 Mdot
.50234 .43904 Mdot
.51478 .61198 Mdot
.49637 .45342 Mdot
.50497 .54186 Mdot
.58803 .53475 Mdot
.60761 .44202 Mdot
.42811 .50953 Mdot
.50365 .44335 Mdot
.51216 .5341 Mdot
.45827 .50487 Mdot
.45844 .51941 Mdot
.47476 .41333 Mdot
.48042 .51093 Mdot
.59636 .48272 Mdot
.48321 .51449 Mdot
.43364 .47331 Mdot
.50234 .4375 Mdot
.50044 .54778 Mdot
.52213 .4877 Mdot
.50663 .53991 Mdot
.44149 .51831 Mdot
.51357 .55624 Mdot
.50146 .46989 Mdot
.49294 .52615 Mdot
.60537 .51063 Mdot
.49205 .42362 Mdot
.43731 .51736 Mdot
.48703 .42239 Mdot
.49841 .47981 Mdot
.46778 .53756 Mdot
.47346 .54345 Mdot
.5145 .50587 Mdot
.4945 .62129 Mdot
.47197 .55361 Mdot
.53311 .58489 Mdot
.51583 .47462 Mdot
.50412 .4959 Mdot
.49688 .44614 Mdot
.53679 .52151 Mdot
.48455 .43226 Mdot
.48865 .52674 Mdot
.56647 .44078 Mdot
.42412 .5121 Mdot
.51397 .46504 Mdot
.52101 .48581 Mdot
.6162 .51889 Mdot
.60228 .55466 Mdot
.55674 .52253 Mdot
.60052 .43462 Mdot
.5383 .52551 Mdot
.51632 .46751 Mdot
.51957 .54048 Mdot
.4638 .53254 Mdot
.43324 .43663 Mdot
.47776 .59802 Mdot
.40765 .57504 Mdot
.62247 .52558 Mdot
.50505 .52333 Mdot
.49849 .46816 Mdot
.41966 .45032 Mdot
.49871 .51278 Mdot
.49317 .48851 Mdot
.55984 .53285 Mdot
.50511 .52388 Mdot
.50418 .48315 Mdot
.57461 .48847 Mdot
.47699 .41775 Mdot
.56247 .54401 Mdot
.48214 .53508 Mdot
.48023 .41326 Mdot
.47663 .52981 Mdot
.38168 .46972 Mdot
.46578 .42246 Mdot
.56511 .4391 Mdot
.51843 .57315 Mdot
.41485 .50332 Mdot
.44071 .52903 Mdot
.49328 .50982 Mdot
.48614 .48926 Mdot
.51227 .46012 Mdot
.51429 .52801 Mdot
.3917 .46596 Mdot
.50241 .61975 Mdot
.38467 .51259 Mdot
.45536 .55249 Mdot
.49166 .50104 Mdot
.42261 .41653 Mdot
.4646 .51271 Mdot
.51791 .52994 Mdot
.50695 .44846 Mdot
.59165 .52385 Mdot
.38685 .51219 Mdot
.5218 .50333 Mdot
.50163 .48895 Mdot
.5827 .53714 Mdot
.48916 .43203 Mdot
.50382 .47444 Mdot
.52443 .38457 Mdot
.48279 .50062 Mdot
.47865 .54465 Mdot
.49832 .52813 Mdot
.49371 .5323 Mdot
.4537 .45012 Mdot
.49503 .53967 Mdot
.45386 .53775 Mdot
.4792 .52959 Mdot
.52233 .40096 Mdot
.4883 .51264 Mdot
.58888 .5247 Mdot
.52184 .53682 Mdot
.47846 .49577 Mdot
.45404 .55683 Mdot
.54752 .52951 Mdot
.54742 .47403 Mdot
.50314 .52702 Mdot
.49795 .47845 Mdot
.46562 .52802 Mdot
.51128 .51828 Mdot
.56432 .52006 Mdot
.5437 .61165 Mdot
.41187 .52597 Mdot
.57827 .46062 Mdot
.50962 .46477 Mdot
.50522 .50225 Mdot
.45485 .58867 Mdot
.5577 .51798 Mdot
.59542 .458 Mdot
.48797 .5196 Mdot
.47981 .49489 Mdot
.51104 .52606 Mdot
.58479 .41696 Mdot
.48688 .50837 Mdot
.49161 .53634 Mdot
.5379 .50608 Mdot
.55842 .40417 Mdot
.46297 .53415 Mdot
.50044 .51129 Mdot
.51565 .37546 Mdot
.50955 .475 Mdot
.48788 .61987 Mdot
.58829 .45972 Mdot
.60433 .50342 Mdot
.39137 .4965 Mdot
.4552 .5109 Mdot
.52346 .55164 Mdot
.48751 .51767 Mdot
.5217 .48928 Mdot
.4174 .51442 Mdot
.48255 .56026 Mdot
.49529 .57238 Mdot
.51313 .54732 Mdot
.40777 .54524 Mdot
.48737 .41547 Mdot
.50002 .52313 Mdot
.4428 .4134 Mdot
.46635 .53957 Mdot
.47987 .52106 Mdot
.47469 .41682 Mdot
.57363 .51823 Mdot
.51294 .45125 Mdot
.47069 .6178 Mdot
.62144 .50232 Mdot
.55486 .48874 Mdot
.49622 .50874 Mdot
.51386 .4668 Mdot
.5044 .49254 Mdot
.50118 .4708 Mdot
.50504 .55076 Mdot
.5695 .54761 Mdot
.49203 .53858 Mdot
.50666 .4547 Mdot
.57886 .47833 Mdot
.54211 .53368 Mdot
.42418 .53365 Mdot
.39509 .46522 Mdot
.54669 .45745 Mdot
.43969 .60338 Mdot
.51134 .44598 Mdot
.51092 .62945 Mdot
.49774 .50902 Mdot
.51265 .51078 Mdot
.45623 .41339 Mdot
.4151 .42564 Mdot
.50001 .48478 Mdot
.46739 .50661 Mdot
.46769 .49591 Mdot
.45888 .5627 Mdot
.53227 .5783 Mdot
.43014 .527 Mdot
.48969 .53145 Mdot
.5161 .45166 Mdot
.49658 .44191 Mdot
.42639 .50781 Mdot
.49873 .47752 Mdot
.43429 .54908 Mdot
.49129 .43289 Mdot
.49955 .43613 Mdot
.52154 .4855 Mdot
.58717 .49569 Mdot
.57787 .5601 Mdot
.61382 .52979 Mdot
.43689 .41719 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0:?ooooo0ol0002Qooooo`007_ooool00ol0003ooooo
ooooo`2Sooooo`Co0000X?ooool001kooooo00?o0000ooooooooool0Woooool2o`0000Cooooo0_l0
00001?oooooo0000o`000?l0002Looooo`007_ooool00ol0003oooooooooo`2Oooooo`;o00001Ooo
ool6o`0009_ooooo000Nooooo`03o`000?oooooooooo0:Kooooo1_l0002Kooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0:Sooooo0_l00002oooo
o`;o000000?oooooo`000?l00000U_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:Sooooo0_l00002oooo
o`;o000000?oooooo`000?l00000U_ooool000?ooooo00Go410@oooooooooooooooooa0@400;oooo
o`Go00001_ooool3o`000:Kooooo0_l0000;ooooo`;o0000T_ooool000?ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0Y_ooool2
o`0000?ooooo0_l00004ooooo`Co0000T_ooool000?ooooo00Go0000ooooooooooooooooo`00000;
ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0Zoooool2o`0000Cooooo0_l0
002Dooooo`000oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001ooo
ool00ol0003oooooooooo`2_ooooo`Co0000U?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0S?ooool2o`0000;ooooo0ol0
0003ooooo`Co00005Oooool4o`0009Cooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Ooo
ool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo08Gooooo1Ol00002ooooo`;o00000_oo
ool3o`0000?ooooo2?l0000;ooooo`;o00000oooool2o`0000Gooooo0_l0002@ooooo`007_ooool0
0ol0003oooooooooo`25ooooo`So000000?oooooo`000?l000000_l00003ooooo`Wo00002oooool2
o`0000;ooooo0ol00005ooooo`;o00000oooool2o`0008_ooooo000Nooooo`03o`000?oooooooooo
08Wooooo1ol00003ooooo`_o00003Oooool4o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`00
08_ooooo000Nooooo`03o`000?oooooooooo08?ooooo0_l00004ooooo`;o000000?oooooo`000?l0
00000_l000000ooooooo0000o`00000<o`0000cooooo0_l00005ooooo`;o00000_ooool2o`0008oo
oooo000Nooooo`03o`000?oooooooooo087ooooo1?l00009ooooo`Ko000000?oooooo`000?l00000
2Ol0000Fooooo`?o0000S_ooool001kooooo00?o0000ooooooooool0POooool2o`0000?ooooo0_l0
0008ooooo`;o00000oooool2o`0000;ooooo2?l0000Eooooo`Go0000S?ooool001kooooo00?o0000
ooooooooool0Q_ooool2o`0000gooooo0ol000000ooooooo0000o`000006o`0000_ooooo0_l00002
ooooo`;o00000oooool2o`0000;ooooo0_l00004ooooo`;o0000Q_ooool001kooooo00?o0000oooo
ooooool0ROooool2o`0000Cooooo0_l00005ooooo`;o000000?oooooo`000?l000002?l00009oooo
o`;o00000_ooool2o`0000?ooooo0_l00008ooooo`?o0000QOooool001kooooo00?o0000oooooooo
ool0O_ooool2o`0000Wooooo1?l00002ooooo`?o00002_ooool7o`0000oooooo1Ol00009ooooo`;o
0000QOooool001kooooo00?o0000ooooooooool0O_ooool4o`0000Cooooo0_l000000ooooooo0000
o`000002o`0000?ooooo0_l000000ooooooo0000o`000007ooooo`So00001_ooool2o`0000Kooooo
1Ol0000:ooooo`;o0000Q?ooool001kooooo00?o0000ooooooooool0OOooool5o`000003ooooool0
003o000000?o00002oooool2o`0000Sooooo1ol00006ooooo`;o00001_ooool2o`0000Oooooo0_l0
0004ooooo`;o0000Q?ooool001kooooo00?o0000ooooooooool0OOooool3o`0000;ooooo1?l00006
ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Sooooo1ol00009ooooo`;o00001Oooool2
o`0000Cooooo0ol00002ooooo`Co0000Q?ooool001kooooo0_l00020ooooo`;o000000?oooooo`00
0?l000000_l00006ooooo`;o000000?oooooo`000?l000002_ooool;o`0000;ooooo0_l00003oooo
o`;o00001?ooool3o`0000?ooooo0ol00003ooooo`;o0000Q_ooool001kooooo00?o0000oooooooo
ool0Ooooool2o`0000;ooooo0_l0000Fooooo`_o00000_ooool2o`0000Wooooo0ol00003ooooo`;o
0000S?ooool001kooooo00?o0000ooooooooool0OOooool2o`0001kooooo2Ol00008ooooo`;o0000
1?ooool2o`0000Gooooo1?l00028ooooo`007_ooool00ol0003oooooooooo`1mooooo`Go000000?o
ooooo`000?l000000_l0000Booooo`;o00000_ooool9o`0000Sooooo0_l00008ooooo`;o000000?o
ooooo`000?l000001?l00026ooooo`007_ooool00ol0003oooooooooo`1looooo`Ko000000?ooooo
o`000?l000000_l0000Booooo`;o00000oooool8o`0000Sooooo1?l00006ooooo`;o00001Oooool2
o`0008Kooooo000Nooooo`03o`000?oooooooooo07_ooooo0ol000000ooooooo0000o`000002oooo
o`;o00003Oooool2o`0000[ooooo2?l00006ooooo`;o000000Coooooo`000?l0003o00003Oooool2
o`0008Kooooo000Nooooo`03o`000?oooooooooo07Sooooo0_l000001?oooooo0000o`000?l00002
ooooo`;o00002oooool2o`0000?ooooo0_l0000:ooooo`Co000000Coooooo`000?l0003o00001_oo
ool2o`000003ooooool0003o000000_ooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo
0_l0001oooooo`007_ooool00ol0003oooooooooo`1hooooo`Ko00000_ooool2o`0000Oooooo0_l0
0002ooooo`Co00001Oooool2o`0000Oooooo1ol00002ooooo`;o00001?ooool2o`0000Cooooo0_l0
0004ooooo`Co00001?ooool2o`0000;ooooo0_l0001oooooo`007_ooool00ol0003oooooooooo`1j
ooooo`;o000000Coooooo`000?l0003ooooo1?l00005ooooo`;o00001?ooool2o`0000Gooooo0_l0
0006ooooo`co00000_ooool4o`0000Cooooo0_l00004ooooo`;o00001_ooool2o`0008?ooooo000N
ooooo`03o`000?oooooooooo07[ooooo0_l000000ooooooo0000o`000005o`0001[ooooo2ol00003
ooooo`;o00002_ooool4o`0000Kooooo0_l00003ooooo`;o0000O_ooool001kooooo00?o0000oooo
ooooool0N_ooool2o`0000?ooooo0_l00007ooooo`Co00000oooool2o`0000_ooooo3Ol0000?oooo
o`Co00000_ooool2o`0000Kooooo0ol0001nooooo`007_ooool00ol0003oooooooooo`1gooooo`;o
00001_ooool2o`0000Oooooo1?l000000ooooooo0000o`000002o`0000?ooooo0_l00006ooooo`go
00005Oooool2o`0000Kooooo0_l0001oooooo`007_ooool00ol0003oooooooooo`1gooooo`;o0000
1_ooool3o`0000_ooooo0_l00005ooooo`;o00001?ooool8o`0000;ooooo1?l00003ooooo`?o0000
0_ooool2o`0000Gooooo0_l0002>ooooo`007_ooool00ol0003oooooooooo`1fooooo`;o00002?oo
ool2o`0001Kooooo4?l00003ooooo`?o00000_ooool2o`0000Cooooo0ol0002>ooooo`007_ooool0
0ol0003oooooooooo`1fooooo`;o00000oooool2o`0001Oooooo0_l000000ooooooo0000o`00000>
o`0000oooooo0_l00003ooooo`;o0000R_ooool001kooooo00?o0000ooooooooool0N?ooool2o`00
0003ooooool0003o000000cooooo0_l00009oooooa?o000000?oooooo`000?l000000_l0000<oooo
o`;o000000?oooooo`000?l00000R_ooool001kooooo0_l0001iooooo`;o00002Oooool4o`0000;o
oooo1?l00003ooooo`Oo00000_ooool>o`000003ooooool0003o000000;o00003?ooool2o`0000Co
oooo0_l00006ooooo`;o0000Ooooool001kooooo00?o0000ooooooooool0Poooool4o`0000Cooooo
0_l000000ooooooo0000o`00000>o`0000;ooooo2?l0000;ooooo`;o00000_ooool4o`0000;ooooo
1Ol000000ooooooo0000o`000003o`0007oooooo000Nooooo`03o`000?oooooooooo07kooooo0_l0
0003ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`000004ooooool0003o0000ooooo`So
000000?oooooo`000?l000000ol000000ooooooo0000o`000006o`0000?ooooo0_l00006ooooo`So
00000_ooool2o`000004ooooool0003o0000ooooo`Co0000P?ooool001kooooo00?o0000oooooooo
ool0Moooool6o`000003ooooool0003o000000?ooooo1_l00002ooooo`Oo000000?oooooo`000?l0
00004ol00003ooooo`?o00001oooool2o`0000Cooooo0_l00003ooooo`?o0000Q?ooool001kooooo
00?o0000ooooooooool0M_ooool7o`0000Kooooo1_l00004ooooo`Go000000?oooooo`000?l00000
5?l00003ooooo`;o00001oooool3o`0000?ooooo1?l000001?oooooo0000o`000?l00024ooooo`00
7_ooool00ol0003oooooooooo`1fooooo`Ko00002?ooool4o`0000;ooooo0_l00003oooooaGo0000
00?oooooo`000?l000001Ol00005ooooo`;o00000_ooool3o`0000Cooooo0ol00028ooooo`007_oo
ool00ol0003oooooooooo`1gooooo`;o00004Oooool3o`0000Cooooo4ol000001?oooooo0000o`00
0?ooool4o`0000Gooooo1?l000000ooooooo0000o`000004ooooo`;o00001_ooool4o`0007oooooo
000Nooooo`03o`000?oooooooooo07Wooooo0_l00008ooooo`;o00001_ooool2o`0000?ooooo6?l0
00001?oooooo0000o`000?l00002ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000
o`000002ooooo`Co00001_ooool4o`0007oooooo000Nooooo`03o`000?oooooooooo07Wooooo0_l0
0005ooooo`_o000000?oooooo`000?l000000_ooool5o`000003ooooool0003o000001Go000000Co
ooooo`000?l0003ooooo0ol00006ooooo`Co00002?ooool2o`0007oooooo000Nooooo`03o`000?oo
oooooooo083ooooo3_l00002ooooo`;o000000?oooooo`000?l000000_ooool3o`000003ooooool0
003o000000go000000?oooooo`000?l000000ol00002ooooo`;o00001?ooool5o`0000Kooooo0_l0
00000ooooooo0000o`00001oooooo`007_ooool00ol0003oooooooooo`1iooooo`;o00000_ooool2
o`000004ooooool0003o0000ooooo`;o00001_ooool2o`0000;ooooo0ol000000ooooooo0000o`00
0005o`000003ooooool0003o000000_o000000?oooooo`000?l000001Ol00002ooooo`;o00001?oo
ool2o`0000Wooooo0_l00022ooooo`007_ooool00ol0003oooooooooo`1iooooo`;o00000_ooool2
o`000003ooooool0003o000000Cooooo0_l00006ooooob3o00001?ooool3o`0000;ooooo0_l00002
ooooo`;o00001?ooool2o`0008Cooooo000Nooooo`03o`000?oooooooooo07oooooo0_l000000ooo
oooo0000o`000002ooooo`;o00001_oooolTo`000003ooooool0003o000000;ooooo1ol00003oooo
o`;o0000Q?ooool001kooooo00?o0000ooooooooool0Noooool2o`0000;ooooo0_l000000ooooooo
0000o`00000;ooooo`Wo00000ooooolAo`000003ooooool0003o000000Go00001Oooool2o`000003
ooooool0003o000008Wooooo000Nooooo`03o`000?oooooooooo07_ooooo0_l00002ooooo`Go0000
2oooool4o`0000?ooooo0ol00002ooooo`go00000_ooool=o`00093ooooo000Nooooo`03o`000?oo
oooooooo07Sooooo0_l00002ooooo`;o000000?oooooo`000?l000000ol0000;ooooo`_o00000_oo
ool5o`000003ooooool0003o000001Go00001oooool2o`0008Gooooo000Nooooo`;o0000NOooool2
o`0000;ooooo0ol000000ooooooo0000o`000002o`000004ooooool0003o0000ooooo`?o00001?oo
ool;o`0000Cooooo6ol00007ooooo`;o0000QOooool001kooooo00?o0000ooooooooool0OOooool2
o`0000Kooooo0_l000001?oooooo0000o`000?l00002ooooo`Go00000_ooool6o`0000Kooooo4Ol0
0004ooooo`;o00002Oooool2o`0008Gooooo000Nooooo`03o`000?oooooooooo07cooooo0_l0000?
ooooo`Go00000_ooool3o`0000cooooo1_l00003ooooo`Go00001?ooool2o`0000Wooooo0ol00024
ooooo`007_ooool00ol0003oooooooooo`1looooo`;o00001oooool2o`0000Sooooo0_l000000ooo
oooo0000o`000005ooooo`;o00001?ooool3o`000005ooooool0003o0000o`000?ooool00_l0000?
ooooo`;o00001oooool2o`0008Cooooo000Nooooo`03o`000?oooooooooo07_ooooo0_l000000ooo
oooo0000o`000005ooooo`;o00001Oooool2o`0000;ooooo1?l00005ooooo`;o00000_ooool5o`00
00Gooooo0_l00008ooooo`;o00001Oooool2o`0008gooooo000Nooooo`03o`000?oooooooooo07_o
oooo0_l000000ooooooo0000o`00000<ooooo`Oo00002_ooool3o`000003ooooool0003o000000ko
oooo0_l0000;ooooo`;o0000Qoooool001kooooo00?o0000ooooooooool0S_ooool2o`000003oooo
ool0003o000000gooooo0ol0000:ooooo`;o00003?ooool2o`000003ooooool0003o000008Oooooo
000Nooooo`03o`000?oooooooooo08Kooooo0_l00009ooooo`;o00002_ooool2o`000003ooooool0
003o000000Co00001oooool2o`0000Wooooo0_l000000ooooooo0000o`00002:ooooo`007_ooool0
0ol0003oooooooooo`1oooooo`Co00000_ooool3o`0000Sooooo1?l00009ooooo`;o00000oooool4
o`0001;ooooo0_l00003ooooo`;o0000R?ooool001kooooo00?o0000ooooooooool0Ooooool5o`00
0003ooooool0003o000000Kooooo0_l000000ooooooo0000o`000002o`0000Sooooo0_l0000;oooo
o`?o00004Oooool2o`0008Sooooo000Nooooo`03o`000?oooooooooo08;ooooo0_l00009ooooo`;o
00003Oooool2o`0000_ooooo0ol00009ooooo`;o0000T?ooool001kooooo00?o0000ooooooooool0
WOooool2o`000003ooooool0003o000000Oooooo0_l0000:ooooo`;o00001?ooool2o`0008[ooooo
000Nooooo`03o`000?oooooooooo08kooooo1?l00003ooooo`;o00001_ooool2o`000003ooooool0
003o000000Oooooo1?l0000;ooooo`Go0000R_ooool001kooooo00?o0000ooooooooool0ROooool2
o`0000?ooooo1?l00003ooooo`;o00004Oooool2o`000003ooooool0003o000000Gooooo0_l00004
ooooo`Co0000Roooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool0
1Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0ROooool2o`0001Gooooo0ol0
0005ooooo`;o00002?ooool2o`0000Kooooo0_l0002;ooooo`000oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`29ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Oooooo0ol00005ooooo`;o0000
00?oooooo`000?l000003Oooool2o`0008_ooooo0003ooooo`05oa0@4?ooooooooooooooool@4100
2oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0002<ooooo`;o00002Oooool4o`0000go
oooo0_l000001?oooooo0000o`000?ooool2o`0009Oooooo0003ooooo`05o`000?oooooooooooooo
ool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0Roooool2
o`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l0000Aooooo`;o0000Uoooool0
00?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_oo
ool00ol0003oooooooooo`2;ooooo`?o00001?ooool2o`0000;ooooo1?l000000ooooooo0000o`00
002Zooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool02?oo
ool00ol0003oooooooooo`2<ooooo`;o00002?ooool4o`0001Wooooo0_l0002Booooo`000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003ooooooooo
o`2Fooooo`;o00002oooool2o`0000Sooooo0_l00004ooooo`;o0000T_ooool000?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0
Xoooool2o`0000Sooooo0_l00003ooooo`;o0000Toooool001kooooo00?o0000ooooooooool0UOoo
ool2o`0001_ooooo0_l0002Cooooo`007_ooool00ol0003oooooooooo`2Eooooo`;o00000oooool2
o`000003ooooool0003o000000;o00001_ooool2o`0009kooooo000Nooooo`03o`000?oooooooooo
09[ooooo0_l000000ooooooo0000o`000002o`0000Kooooo0_l0002Nooooo`007_ooool00ol0003o
ooooooooo`2Jooooo`;o00000oooool2o`0000Kooooo0_l0002Nooooo`007_ooool00ol0003ooooo
ooooo`2Iooooo`?o00000oooool2o`000003ooooool0003o00000:?ooooo000Nooooo`03o`000?oo
oooooooo09Wooooo0_l00002ooooo`;o00000oooool2o`000:?ooooo000Nooooo`03o`000?oooooo
oooo09gooooo0_l0002Xooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`00
0?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooo
oom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0003oooooodSo
oooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b
00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo0000
00_ooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo0?ooooooB?ooool0
00?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_oo
ool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0oooooom8ooooo`000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001Cooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooo
oooo0?ooooooB?ooool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooo
odSooooo000Fooooo`03o`000?oooooooooo00Gooooo0ol0003oooooodSooooo000Fooooo`03o`00
0?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool0
0ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Co
oooo00?oEEEEofIVI_l00000oooooomBooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.43913 .49075 Mdot
.46621 .51339 Mdot
.52998 .56571 Mdot
.47359 .50474 Mdot
.48904 .48225 Mdot
.42893 .44507 Mdot
.5676 .59751 Mdot
.47934 .48247 Mdot
.57078 .42256 Mdot
.52138 .44265 Mdot
.48509 .45627 Mdot
.4987 .52494 Mdot
.41599 .45347 Mdot
.45012 .56979 Mdot
.61265 .49269 Mdot
.52699 .46074 Mdot
.45464 .50276 Mdot
.49032 .41035 Mdot
.51878 .43156 Mdot
.51669 .54996 Mdot
.45551 .49902 Mdot
.527 .49256 Mdot
.51418 .46743 Mdot
.40728 .51164 Mdot
.46649 .48926 Mdot
.50669 .51562 Mdot
.58971 .49243 Mdot
.51477 .41968 Mdot
.49051 .48882 Mdot
.41512 .47255 Mdot
.47777 .54689 Mdot
.46216 .50153 Mdot
.50701 .48924 Mdot
.52944 .5584 Mdot
.41419 .4622 Mdot
.51781 .55767 Mdot
.51132 .50491 Mdot
.56934 .4715 Mdot
.50334 .47132 Mdot
.50339 .53039 Mdot
.52038 .46663 Mdot
.52156 .53838 Mdot
.47357 .53571 Mdot
.5026 .50632 Mdot
.46061 .49649 Mdot
.52408 .48646 Mdot
.46005 .58915 Mdot
.47872 .55397 Mdot
.49527 .55046 Mdot
.53632 .37779 Mdot
.49761 .4755 Mdot
.3967 .45304 Mdot
.48934 .49315 Mdot
.49457 .4764 Mdot
.52926 .45645 Mdot
.51766 .51626 Mdot
.48901 .5379 Mdot
.37837 .4654 Mdot
.46883 .49341 Mdot
.48933 .54058 Mdot
.5288 .49699 Mdot
.51996 .49074 Mdot
.52393 .5561 Mdot
.52563 .46043 Mdot
.50316 .47408 Mdot
.5685 .40369 Mdot
.44997 .53057 Mdot
.5247 .49938 Mdot
.51061 .53944 Mdot
.5292 .46179 Mdot
.59433 .55145 Mdot
.47698 .49227 Mdot
.49826 .54375 Mdot
.48887 .50638 Mdot
.40814 .48947 Mdot
.58398 .52882 Mdot
.51818 .52649 Mdot
.48736 .40798 Mdot
.58684 .56342 Mdot
.50913 .42659 Mdot
.56109 .49729 Mdot
.47774 .48361 Mdot
.46225 .49206 Mdot
.52167 .47416 Mdot
.52589 .55703 Mdot
.48924 .50179 Mdot
.55663 .55365 Mdot
.52191 .49863 Mdot
.50055 .53433 Mdot
.44723 .41451 Mdot
.4976 .48525 Mdot
.52597 .47944 Mdot
.56637 .52798 Mdot
.55406 .38672 Mdot
.55576 .57926 Mdot
.52657 .51373 Mdot
.52136 .50521 Mdot
.47002 .54638 Mdot
.46496 .59215 Mdot
.48233 .53321 Mdot
.56042 .5492 Mdot
.55717 .53715 Mdot
.4771 .48627 Mdot
.52362 .38609 Mdot
.58339 .43658 Mdot
.50784 .49052 Mdot
.47486 .6383 Mdot
.4999 .47835 Mdot
.45428 .52646 Mdot
.52693 .47856 Mdot
.41838 .5092 Mdot
.47578 .4936 Mdot
.48368 .51971 Mdot
.55854 .4345 Mdot
.44318 .52501 Mdot
.411 .4416 Mdot
.58195 .47312 Mdot
.51553 .42286 Mdot
.50746 .57038 Mdot
.56984 .52197 Mdot
.48122 .41635 Mdot
.50395 .51503 Mdot
.5233 .44566 Mdot
.48696 .54799 Mdot
.4574 .50805 Mdot
.54523 .43643 Mdot
.41192 .50533 Mdot
.50518 .51446 Mdot
.50335 .50872 Mdot
.52184 .45799 Mdot
.4974 .42123 Mdot
.44997 .50805 Mdot
.38129 .5124 Mdot
.51264 .55621 Mdot
.50152 .47851 Mdot
.38671 .5299 Mdot
.51205 .43727 Mdot
.50113 .49607 Mdot
.50558 .54383 Mdot
.49201 .51574 Mdot
.49871 .48104 Mdot
.58184 .44554 Mdot
.50461 .50247 Mdot
.47831 .49963 Mdot
.50934 .4781 Mdot
.52852 .481 Mdot
.4327 .48551 Mdot
.52143 .51938 Mdot
.44263 .52659 Mdot
.48958 .54787 Mdot
.51834 .55633 Mdot
.51512 .41887 Mdot
.49363 .482 Mdot
.4439 .55303 Mdot
.4927 .43153 Mdot
.52748 .46084 Mdot
.51881 .48704 Mdot
.39197 .4909 Mdot
.51763 .52758 Mdot
.50699 .47854 Mdot
.60594 .52605 Mdot
.515 .53603 Mdot
.47544 .41198 Mdot
.53439 .46046 Mdot
.49623 .53588 Mdot
.48713 .52826 Mdot
.59056 .44804 Mdot
.54851 .48813 Mdot
.52226 .51068 Mdot
.56196 .45388 Mdot
.50534 .4217 Mdot
.48631 .54597 Mdot
.46466 .51817 Mdot
.49829 .53749 Mdot
.6128 .54032 Mdot
.51627 .50593 Mdot
.52768 .5088 Mdot
.50713 .4759 Mdot
.42844 .58194 Mdot
.50348 .55312 Mdot
.47634 .50356 Mdot
.52971 .50688 Mdot
.49504 .50386 Mdot
.48838 .49249 Mdot
.41574 .44799 Mdot
.49594 .52338 Mdot
.54359 .55753 Mdot
.52936 .50046 Mdot
.55262 .39071 Mdot
.57283 .52697 Mdot
.49764 .5128 Mdot
.51023 .45722 Mdot
.41282 .51846 Mdot
.49596 .48053 Mdot
.56487 .46077 Mdot
.51441 .4671 Mdot
.54032 .37732 Mdot
.5053 .49792 Mdot
.50851 .47039 Mdot
.47283 .51008 Mdot
.47681 .52983 Mdot
.52535 .50412 Mdot
.48861 .41552 Mdot
.53414 .50477 Mdot
.52483 .4529 Mdot
.46515 .52051 Mdot
.4528 .50343 Mdot
.48166 .53566 Mdot
.53154 .55831 Mdot
.49509 .47939 Mdot
.45951 .49682 Mdot
.50825 .50508 Mdot
.50573 .53638 Mdot
.46155 .42647 Mdot
.50385 .51549 Mdot
.45368 .58921 Mdot
.52601 .48422 Mdot
.51599 .52969 Mdot
.58037 .44481 Mdot
.50223 .4792 Mdot
.51469 .45615 Mdot
.38075 .47992 Mdot
.5276 .48186 Mdot
.41488 .55122 Mdot
.492 .47443 Mdot
.48551 .48353 Mdot
.4667 .50089 Mdot
.52629 .44527 Mdot
.53777 .55878 Mdot
.51376 .44273 Mdot
.52936 .46812 Mdot
.50679 .50589 Mdot
.56862 .44116 Mdot
.51502 .49083 Mdot
.51168 .51462 Mdot
.50531 .54471 Mdot
.55483 .43902 Mdot
.58085 .53772 Mdot
.45454 .51475 Mdot
.49599 .5235 Mdot
.52539 .44428 Mdot
.60984 .49811 Mdot
.42384 .49344 Mdot
.55011 .44079 Mdot
.54003 .59148 Mdot
.531 .45902 Mdot
.58885 .52482 Mdot
.48543 .48218 Mdot
.53404 .45934 Mdot
.58617 .47037 Mdot
.47484 .53593 Mdot
.41782 .44241 Mdot
.59981 .48839 Mdot
.54739 .58544 Mdot
.48571 .51576 Mdot
.49327 .52889 Mdot
.52002 .45563 Mdot
.5126 .53038 Mdot
.52886 .55734 Mdot
.59234 .46791 Mdot
.5479 .4932 Mdot
.51165 .46211 Mdot
.50728 .47867 Mdot
.47911 .42454 Mdot
.51571 .55401 Mdot
.52401 .55465 Mdot
.51766 .45017 Mdot
.50166 .41529 Mdot
.51193 .4722 Mdot
.42084 .57629 Mdot
.45528 .5286 Mdot
.48387 .52007 Mdot
.55594 .39195 Mdot
.48862 .5177 Mdot
.54161 .56204 Mdot
.59139 .53273 Mdot
.5198 .51925 Mdot
.51773 .43433 Mdot
.51455 .54834 Mdot
.51251 .43855 Mdot
.50787 .54264 Mdot
.50966 .5208 Mdot
.47168 .56935 Mdot
.50725 .48807 Mdot
.57397 .46044 Mdot
.55016 .3844 Mdot
.44303 .58887 Mdot
.51908 .45888 Mdot
.4579 .51508 Mdot
.44249 .55016 Mdot
.49503 .53283 Mdot
.44213 .53727 Mdot
.41866 .43454 Mdot
.48017 .54095 Mdot
.48683 .52813 Mdot
.49006 .47928 Mdot
.50867 .41821 Mdot
.50632 .5539 Mdot
.52706 .53422 Mdot
.47322 .50347 Mdot
.50489 .4998 Mdot
.48617 .48339 Mdot
.58192 .42946 Mdot
.53381 .47095 Mdot
.4963 .52908 Mdot
.47428 .5032 Mdot
.38893 .55885 Mdot
.42808 .5264 Mdot
.46412 .49115 Mdot
.51298 .5543 Mdot
.47971 .50748 Mdot
.50741 .48812 Mdot
.51661 .4425 Mdot
.45694 .48975 Mdot
.47258 .51414 Mdot
.44455 .52576 Mdot
.5046 .52996 Mdot
.52348 .49907 Mdot
.50046 .54304 Mdot
.56425 .46625 Mdot
.49779 .55088 Mdot
.47494 .4608 Mdot
.46791 .45701 Mdot
.51719 .5093 Mdot
.50914 .42374 Mdot
.55014 .45546 Mdot
.49983 .5105 Mdot
.50304 .51046 Mdot
.55421 .41925 Mdot
.55155 .52997 Mdot
.42688 .48446 Mdot
.40299 .45325 Mdot
.48353 .52129 Mdot
.5203 .44077 Mdot
.52728 .55818 Mdot
.51055 .44588 Mdot
.51621 .55604 Mdot
.47496 .49835 Mdot
.46881 .47457 Mdot
.52014 .49363 Mdot
.45149 .53197 Mdot
.44047 .52557 Mdot
.50396 .62321 Mdot
.50523 .49882 Mdot
.53487 .48129 Mdot
.44511 .52268 Mdot
.50676 .48915 Mdot
.48265 .48215 Mdot
.55029 .49064 Mdot
.5219 .47397 Mdot
.49213 .53569 Mdot
.38176 .5038 Mdot
.45653 .49925 Mdot
.51444 .49691 Mdot
.4359 .42956 Mdot
.48985 .53123 Mdot
.43682 .56698 Mdot
.44949 .51412 Mdot
.42488 .42562 Mdot
.50797 .48795 Mdot
.50568 .47152 Mdot
.44368 .52895 Mdot
.48616 .52502 Mdot
.43583 .55776 Mdot
.44816 .51709 Mdot
.47867 .57245 Mdot
.51673 .59457 Mdot
.54635 .48529 Mdot
.42477 .59267 Mdot
.49085 .50097 Mdot
.50664 .47834 Mdot
.50064 .49212 Mdot
.38296 .49182 Mdot
.50064 .46254 Mdot
.51618 .56755 Mdot
.5233 .44823 Mdot
.50958 .45289 Mdot
.56809 .54707 Mdot
.5181 .544 Mdot
.50851 .50886 Mdot
.51243 .55483 Mdot
.56681 .57834 Mdot
.48099 .49397 Mdot
.40235 .52622 Mdot
.46675 .49857 Mdot
.43829 .44558 Mdot
.51505 .41941 Mdot
.51279 .44596 Mdot
.51534 .5184 Mdot
.51019 .55425 Mdot
.38307 .53843 Mdot
.51442 .54488 Mdot
.50069 .55194 Mdot
.4622 .50059 Mdot
.51484 .46494 Mdot
.47377 .48496 Mdot
.5352 .47247 Mdot
.50757 .48714 Mdot
.50976 .42299 Mdot
.38925 .54605 Mdot
.39799 .56042 Mdot
.5119 .55574 Mdot
.37025 .53056 Mdot
.50883 .52198 Mdot
.50018 .55153 Mdot
.51153 .55589 Mdot
.4862 .49368 Mdot
.50429 .47897 Mdot
.47399 .53152 Mdot
.50723 .4241 Mdot
.49405 .51734 Mdot
.51303 .43217 Mdot
.4903 .50496 Mdot
.48084 .55315 Mdot
.49337 .5009 Mdot
.55983 .5377 Mdot
.52853 .47474 Mdot
.41705 .52666 Mdot
.48424 .54199 Mdot
.52585 .44701 Mdot
.50996 .43442 Mdot
.52465 .48961 Mdot
.49501 .50493 Mdot
.51824 .43799 Mdot
.37 .49383 Mdot
.51633 .55725 Mdot
.60469 .46841 Mdot
.51491 .47138 Mdot
.50907 .54589 Mdot
.50691 .53431 Mdot
.44025 .54133 Mdot
.52931 .46228 Mdot
.45037 .50742 Mdot
.5093 .43253 Mdot
.5278 .50253 Mdot
.40989 .51978 Mdot
.52403 .50608 Mdot
.48995 .53867 Mdot
.43501 .5381 Mdot
.49737 .53712 Mdot
.47979 .5418 Mdot
.42928 .41218 Mdot
.44287 .54533 Mdot
.48101 .42687 Mdot
.50818 .48935 Mdot
.49905 .41753 Mdot
.48353 .48829 Mdot
.52449 .45405 Mdot
.52792 .55891 Mdot
.4952 .48606 Mdot
.48495 .58459 Mdot
.49411 .52169 Mdot
.52186 .46935 Mdot
.4995 .53785 Mdot
.5416 .54876 Mdot
.5645 .42521 Mdot
.51718 .55604 Mdot
.56595 .47486 Mdot
.50412 .48402 Mdot
.50978 .53264 Mdot
.53272 .51622 Mdot
.4852 .50927 Mdot
.48477 .55948 Mdot
.51364 .49093 Mdot
.49461 .54856 Mdot
.40948 .55764 Mdot
.51546 .47974 Mdot
.49485 .50791 Mdot
.44524 .53721 Mdot
.51198 .53274 Mdot
.45492 .46989 Mdot
.51134 .4447 Mdot
.54195 .62572 Mdot
.62636 .50237 Mdot
.51076 .42633 Mdot
.56992 .42573 Mdot
.49738 .55424 Mdot
.62801 .5011 Mdot
.56256 .54876 Mdot
.38568 .52324 Mdot
.50708 .48993 Mdot
.45704 .49868 Mdot
.48105 .48317 Mdot
.46964 .4892 Mdot
.52561 .49098 Mdot
.53042 .51462 Mdot
.51929 .44028 Mdot
.43573 .49118 Mdot
.49064 .54773 Mdot
.56933 .54597 Mdot
.41168 .42801 Mdot
.53625 .5581 Mdot
.55926 .40648 Mdot
.50747 .47247 Mdot
.47743 .53606 Mdot
.43115 .43105 Mdot
.5776 .45232 Mdot
.50919 .47257 Mdot
.52608 .52424 Mdot
.4758 .48689 Mdot
.47911 .62935 Mdot
.60141 .48184 Mdot
.54374 .61619 Mdot
.51063 .45016 Mdot
.49493 .52377 Mdot
.52684 .44188 Mdot
.43993 .50429 Mdot
.51864 .44799 Mdot
.57093 .55446 Mdot
.54354 .38123 Mdot
.51413 .54484 Mdot
.52305 .557 Mdot
.47128 .5336 Mdot
.43316 .43634 Mdot
.48212 .48483 Mdot
.52852 .46424 Mdot
.47332 .53465 Mdot
.41618 .45957 Mdot
.48021 .58164 Mdot
.45989 .48524 Mdot
.53362 .45746 Mdot
.45217 .528 Mdot
.46522 .49014 Mdot
.5085 .51404 Mdot
.49042 .52884 Mdot
.5207 .50752 Mdot
.50735 .55452 Mdot
.39931 .44723 Mdot
.5026 .4199 Mdot
.5107 .42841 Mdot
.53237 .54494 Mdot
.52876 .48108 Mdot
.51915 .52025 Mdot
.48518 .51037 Mdot
.5511 .39314 Mdot
.49933 .52075 Mdot
.39619 .51288 Mdot
.52555 .49686 Mdot
.48517 .53731 Mdot
.5227 .43515 Mdot
.48593 .51714 Mdot
.47407 .40999 Mdot
.53032 .47645 Mdot
.40264 .51828 Mdot
.50207 .42369 Mdot
.59386 .50641 Mdot
.4818 .4953 Mdot
.4676 .40631 Mdot
.47744 .48977 Mdot
.51203 .43252 Mdot
.50016 .53348 Mdot
.50196 .47574 Mdot
.50841 .48288 Mdot
.46471 .62713 Mdot
.47162 .49688 Mdot
.51271 .45809 Mdot
.50089 .48489 Mdot
.49675 .54878 Mdot
.41558 .42794 Mdot
.58133 .49751 Mdot
.55587 .5333 Mdot
.53736 .55742 Mdot
.52379 .45133 Mdot
.49144 .49675 Mdot
.52105 .54812 Mdot
.52001 .45481 Mdot
.57031 .6044 Mdot
.51081 .43835 Mdot
.40081 .5216 Mdot
.49522 .55201 Mdot
.42025 .57515 Mdot
.50616 .51064 Mdot
.49072 .54608 Mdot
.47988 .48489 Mdot
.49529 .52124 Mdot
.52443 .46571 Mdot
.46125 .40854 Mdot
.50101 .53267 Mdot
.57647 .53974 Mdot
.50298 .52161 Mdot
.54849 .56017 Mdot
.47851 .49188 Mdot
.50385 .62762 Mdot
.47151 .52883 Mdot
.51493 .53445 Mdot
.45346 .5987 Mdot
.49732 .4799 Mdot
.44984 .52445 Mdot
.44702 .51744 Mdot
.52677 .55477 Mdot
.49547 .52519 Mdot
.52354 .48052 Mdot
.51062 .46887 Mdot
.49988 .51442 Mdot
.52327 .45422 Mdot
.42636 .48667 Mdot
.40944 .52531 Mdot
.52932 .50486 Mdot
.47692 .41163 Mdot
.46688 .51625 Mdot
.53895 .49426 Mdot
.53343 .47695 Mdot
.44959 .48322 Mdot
.447 .4273 Mdot
.52381 .47917 Mdot
.46001 .5293 Mdot
.51355 .45236 Mdot
.50587 .5855 Mdot
.51931 .49157 Mdot
.50243 .51227 Mdot
.51269 .42063 Mdot
.42625 .50512 Mdot
.51904 .46038 Mdot
.45809 .59474 Mdot
.43279 .49271 Mdot
.48999 .48501 Mdot
.50726 .46889 Mdot
.53005 .45457 Mdot
.50282 .47471 Mdot
.61431 .52412 Mdot
.57089 .59304 Mdot
.39289 .45414 Mdot
.48173 .5158 Mdot
.51863 .48793 Mdot
.52573 .59791 Mdot
.51129 .55443 Mdot
.49477 .48342 Mdot
.50231 .48769 Mdot
.38891 .53187 Mdot
.45931 .5155 Mdot
.52736 .49669 Mdot
.52667 .4573 Mdot
.49104 .5489 Mdot
.47748 .40654 Mdot
.47138 .40972 Mdot
.47442 .47152 Mdot
.57762 .53291 Mdot
.49468 .51069 Mdot
.47294 .48982 Mdot
.44272 .5883 Mdot
.48665 .48069 Mdot
.51892 .52394 Mdot
.50678 .59255 Mdot
.51385 .47393 Mdot
.52071 .45578 Mdot
.45676 .4249 Mdot
.44012 .42957 Mdot
.51117 .48793 Mdot
.56174 .59375 Mdot
.57965 .57866 Mdot
.46682 .4882 Mdot
.50867 .4819 Mdot
.50733 .4992 Mdot
.45462 .52631 Mdot
.48081 .5255 Mdot
.47668 .53751 Mdot
.57996 .41244 Mdot
.49632 .51133 Mdot
.52553 .54891 Mdot
.5001 .51569 Mdot
.47664 .48968 Mdot
.50855 .48025 Mdot
.43386 .55793 Mdot
.37342 .47244 Mdot
.47821 .62022 Mdot
.51937 .55647 Mdot
.54827 .47298 Mdot
.37888 .54777 Mdot
.42184 .50285 Mdot
.61262 .45382 Mdot
.46163 .51419 Mdot
.37389 .49095 Mdot
.39557 .56011 Mdot
.5314 .48098 Mdot
.51634 .45565 Mdot
.53016 .4514 Mdot
.50366 .54695 Mdot
.46176 .49586 Mdot
.51225 .4167 Mdot
.49039 .47913 Mdot
.53033 .49808 Mdot
.55654 .53155 Mdot
.45776 .52125 Mdot
.56533 .51667 Mdot
.45743 .501 Mdot
.52533 .50738 Mdot
.45887 .51014 Mdot
.41932 .44313 Mdot
.50163 .53998 Mdot
.51043 .55025 Mdot
.52112 .52363 Mdot
.52048 .55874 Mdot
.3914 .45955 Mdot
.51325 .51549 Mdot
.50292 .55226 Mdot
.45094 .50116 Mdot
.47421 .63502 Mdot
.50439 .50174 Mdot
.52688 .47581 Mdot
.47349 .5017 Mdot
.50893 .47463 Mdot
.50004 .52099 Mdot
.46814 .56264 Mdot
.50266 .4744 Mdot
.5137 .58194 Mdot
.59112 .57212 Mdot
.52027 .50464 Mdot
.49535 .47767 Mdot
.53314 .55492 Mdot
.51804 .43761 Mdot
.54834 .40566 Mdot
.50166 .51309 Mdot
.54393 .55421 Mdot
.51796 .43666 Mdot
.44105 .55084 Mdot
.58947 .49519 Mdot
.51791 .43992 Mdot
.44972 .50792 Mdot
.43136 .44901 Mdot
.50935 .41563 Mdot
.48676 .50176 Mdot
.50674 .42475 Mdot
.50721 .54672 Mdot
.48444 .50777 Mdot
.43156 .50626 Mdot
.48941 .53421 Mdot
.45569 .4043 Mdot
.45918 .42606 Mdot
.39629 .51329 Mdot
.52275 .51928 Mdot
.49064 .43413 Mdot
.52276 .47109 Mdot
.49147 .53345 Mdot
.51779 .48149 Mdot
.40654 .44016 Mdot
.57724 .58593 Mdot
.51316 .51014 Mdot
.52725 .50148 Mdot
.51585 .43232 Mdot
.51538 .52876 Mdot
.52462 .48468 Mdot
.40757 .45803 Mdot
.51185 .51836 Mdot
.47518 .48643 Mdot
.51105 .4662 Mdot
.49319 .4774 Mdot
.50658 .47326 Mdot
.52118 .49786 Mdot
.50364 .50755 Mdot
.44606 .46887 Mdot
.50524 .55405 Mdot
.50591 .48351 Mdot
.4936 .5393 Mdot
.49175 .47923 Mdot
.52587 .4704 Mdot
.41447 .5392 Mdot
.58308 .44671 Mdot
.52334 .4473 Mdot
.47577 .54509 Mdot
.51025 .43569 Mdot
.4244 .45981 Mdot
.43633 .44565 Mdot
.62917 .49239 Mdot
.51656 .53885 Mdot
.45739 .40442 Mdot
.48667 .5117 Mdot
.39832 .52521 Mdot
.48263 .49512 Mdot
.50174 .50902 Mdot
.51406 .55683 Mdot
.46499 .43556 Mdot
.47321 .5472 Mdot
.41191 .46935 Mdot
.49248 .49943 Mdot
.5216 .55757 Mdot
.57888 .5043 Mdot
.61306 .4659 Mdot
.46269 .49167 Mdot
.49191 .50936 Mdot
.50955 .53585 Mdot
.51035 .45381 Mdot
.44601 .52412 Mdot
.41863 .46097 Mdot
.41756 .4215 Mdot
.37178 .49608 Mdot
.59288 .53375 Mdot
.47522 .52409 Mdot
.52032 .46271 Mdot
.50873 .42132 Mdot
.51933 .52537 Mdot
.47288 .51287 Mdot
.48728 .41504 Mdot
.48086 .5039 Mdot
.56808 .47693 Mdot
.45607 .52514 Mdot
.54139 .47042 Mdot
.46047 .53125 Mdot
.46146 .63046 Mdot
.52349 .45267 Mdot
.49205 .60913 Mdot
.51276 .46321 Mdot
.48434 .53612 Mdot
.56868 .55225 Mdot
.61887 .45884 Mdot
.44107 .49186 Mdot
.52367 .45719 Mdot
.49486 .53487 Mdot
.47519 .48699 Mdot
.45966 .49562 Mdot
.50637 .41151 Mdot
.48179 .496 Mdot
.59316 .50588 Mdot
.48181 .50038 Mdot
.45171 .45963 Mdot
.52378 .45153 Mdot
.47568 .53702 Mdot
.52738 .51039 Mdot
.48753 .53565 Mdot
.45166 .49724 Mdot
.48466 .54678 Mdot
.51391 .48164 Mdot
.4839 .51537 Mdot
.59547 .53241 Mdot
.51714 .43346 Mdot
.44847 .49751 Mdot
.51868 .43203 Mdot
.50483 .47254 Mdot
.45642 .51703 Mdot
.45613 .52404 Mdot
.51227 .51865 Mdot
.47181 .61839 Mdot
.45248 .53174 Mdot
.50772 .57829 Mdot
.52377 .4926 Mdot
.50614 .50503 Mdot
.51603 .45577 Mdot
.52174 .54333 Mdot
.50831 .42555 Mdot
.48027 .51424 Mdot
.57094 .46274 Mdot
.43559 .49395 Mdot
.5249 .48365 Mdot
.52866 .50959 Mdot
.60754 .53851 Mdot
.58601 .56843 Mdot
.54015 .54585 Mdot
.6114 .45091 Mdot
.52202 .5467 Mdot
.52606 .48709 Mdot
.49966 .54403 Mdot
.45617 .51107 Mdot
.45674 .42129 Mdot
.45618 .58477 Mdot
.39324 .55884 Mdot
.6152 .54429 Mdot
.49394 .52156 Mdot
.50972 .47793 Mdot
.43813 .4335 Mdot
.49451 .50674 Mdot
.49798 .47921 Mdot
.53989 .55266 Mdot
.49371 .52205 Mdot
.50774 .4865 Mdot
.56782 .5129 Mdot
.5058 .41816 Mdot
.53799 .55862 Mdot
.46853 .52097 Mdot
.51126 .41421 Mdot
.46874 .51394 Mdot
.38529 .4503 Mdot
.4934 .4159 Mdot
.57007 .46091 Mdot
.49146 .56185 Mdot
.42575 .48584 Mdot
.44574 .50486 Mdot
.49165 .50066 Mdot
.49864 .47431 Mdot
.52506 .4783 Mdot
.49972 .53352 Mdot
.40001 .44711 Mdot
.47953 .6176 Mdot
.38299 .49337 Mdot
.44337 .52757 Mdot
.49282 .49186 Mdot
.4472 .40381 Mdot
.46712 .49249 Mdot
.50277 .53802 Mdot
.52496 .46394 Mdot
.57584 .54468 Mdot
.38616 .4931 Mdot
.51976 .527 Mdot
.50618 .49785 Mdot
.5617 .55404 Mdot
.50957 .43234 Mdot
.50965 .47272 Mdot
.54526 .39137 Mdot
.48704 .48749 Mdot
.45964 .52628 Mdot
.48679 .52024 Mdot
.48118 .52227 Mdot
.4774 .43696 Mdot
.47714 .52999 Mdot
.44859 .51082 Mdot
.47051 .51459 Mdot
.53991 .41663 Mdot
.48666 .50064 Mdot
.57264 .54568 Mdot
.50363 .54368 Mdot
.49063 .47901 Mdot
.44223 .53107 Mdot
.5292 .55056 Mdot
.54124 .50011 Mdot
.4907 .52292 Mdot
.50895 .46815 Mdot
.46094 .50752 Mdot
.50156 .52414 Mdot
.54838 .54364 Mdot
.52281 .61495 Mdot
.41669 .50662 Mdot
.57763 .48378 Mdot
.52238 .47996 Mdot
.5038 .50523 Mdot
.4399 .56895 Mdot
.54228 .54173 Mdot
.598 .47987 Mdot
.4835 .50692 Mdot
.49073 .47867 Mdot
.49741 .52919 Mdot
.59764 .43106 Mdot
.48678 .49616 Mdot
.47642 .52562 Mdot
.52558 .53069 Mdot
.57308 .41788 Mdot
.45434 .51229 Mdot
.49643 .50682 Mdot
.53873 .3765 Mdot
.51911 .48961 Mdot
.466 .61476 Mdot
.58898 .48219 Mdot
.5963 .52591 Mdot
.39527 .47778 Mdot
.467 .48944 Mdot
.49383 .54939 Mdot
.48402 .50489 Mdot
.52491 .51052 Mdot
.42687 .49587 Mdot
.46011 .54023 Mdot
.47084 .55495 Mdot
.48738 .54391 Mdot
.404 .52495 Mdot
.51665 .42121 Mdot
.49039 .51676 Mdot
.47239 .40567 Mdot
.45452 .51859 Mdot
.47659 .50552 Mdot
.50434 .41573 Mdot
.55883 .54165 Mdot
.52902 .47016 Mdot
.45144 .60926 Mdot
.61783 .52319 Mdot
.54575 .51413 Mdot
.49433 .50142 Mdot
.52763 .49544 Mdot
.508 .5027 Mdot
.51317 .48233 Mdot
.47834 .54057 Mdot
.54274 .55905 Mdot
.47512 .52801 Mdot
.52318 .46953 Mdot
.57442 .5024 Mdot
.52302 .55179 Mdot
.42752 .51216 Mdot
.40448 .44666 Mdot
.54663 .483 Mdot
.42275 .59068 Mdot
.52983 .46398 Mdot
.48842 .63449 Mdot
.49537 .5026 Mdot
.50781 .52078 Mdot
.4882 .40949 Mdot
.43748 .41074 Mdot
.50327 .48005 Mdot
.47359 .48665 Mdot
.48966 .48182 Mdot
.4433 .53947 Mdot
.50584 .57093 Mdot
.43656 .50572 Mdot
.4784 .51978 Mdot
.53262 .47139 Mdot
.51208 .44368 Mdot
.43944 .49041 Mdot
.5086 .46824 Mdot
.43178 .52405 Mdot
.51375 .44015 Mdot
.52188 .44853 Mdot
.52586 .50656 Mdot
.57953 .51952 Mdot
.55393 .56868 Mdot
.6029 .54807 Mdot
.46452 .40596 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0:_ooooo0_l0002Jooooo`007_ooool00ol0003ooooo
ooooo`2Zooooo`Co0000VOooool001kooooo00?o0000ooooooooool0Z_ooool5o`0009Sooooo000N
ooooo`03o`000?oooooooooo0:gooooo1?l0002Fooooo`007_ooool00ol0003oooooooooo`2Voooo
o`;o00001oooool3o`0009Gooooo000Nooooo`03o`000?oooooooooo0:Kooooo0_l00005ooooo`;o
000000Coooooo`000?l0003o0000U?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0[Oooool6o`00
09Cooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`2_ooooo`;o0000U_ooool000?ooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go00001_ooool3o`000?ooooooB?ooool000?ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0SOooool2
o`000003ooooool0003o000002?ooooo0_l0002@ooooo`000oooool01Ol0003ooooooooooooooooo
000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`2=ooooo`;o000000?o
ooooo`000?l000001ol0000Eooooo`;o00000_ooool2o`000003ooooool0003o0000093ooooo0003
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oo
oooooooo097ooooo2?l000001?oooooo0000o`000?l0000Aooooo`;o00000_ooool2o`0009?ooooo
0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007ooooo`03o`00
0?oooooooooo08Oooooo0_l000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l00000
0_l000001?oooooo0000o`000?l00004ooooo`;o00005Oooool2o`0008gooooo0003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo08Oo
oooo0_l000001?oooooo0000o`000?ooool2o`0000Oooooo2?l000000ooooooo0000o`000003o`00
00Oooooo0_l0000;ooooo`;o0000SOooool001kooooo00?o0000ooooooooool0SOooool2o`0000Wo
oooo3Ol00006ooooo`;o00000oooool2o`0000Cooooo0_l0002?ooooo`007_ooool00ol0003ooooo
ooooo`24ooooo`;o00002_ooool2o`0000cooooo2?l0000:ooooo`;o00000oooool3o`0008oooooo
000Nooooo`03o`000?oooooooooo08Cooooo1?l00008ooooo`;o00001_ooool2o`0000Cooooo2?l0
000=ooooo`Co0000T?ooool001kooooo00?o0000ooooooooool0P_ooool3o`000003ooooool0003o
000000Gooooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l00005ooooo`Ko00003_ooool4
o`00093ooooo000Nooooo`03o`000?oooooooooo08;ooooo0ol00003ooooo`Oo00000_ooool3o`00
00Cooooo0_l00002ooooo`;o00000oooool3o`000003ooooool0003o000001;ooooo0_l00003oooo
o`;o0000Qoooool001kooooo00?o0000ooooooooool0Q?ooool2o`0000;ooooo1Ol0000>ooooo`?o
00000oooool6o`0000[ooooo0_l00006ooooo`;o00000oooool2o`0008Oooooo000Nooooo`03o`00
0?oooooooooo08Cooooo0_l00003ooooo`?o00001oooool2o`0000;ooooo0_l00002ooooo`;o0000
1?ooool7o`0000Gooooo0_l00002ooooo`;o00001oooool2o`0008_ooooo000Nooooo`03o`000?oo
oooooooo083ooooo0_l00007ooooo`;o00002?ooool2o`0000;ooooo0_l00009ooooo`Ko00001Ooo
ool5o`0000?ooooo0_l00003ooooo`;o0000Roooool001kooooo00?o0000ooooooooool0P?ooool6
o`0001cooooo1ol00006ooooo`?o00000oooool2o`00093ooooo000Nooooo`03o`000?oooooooooo
07kooooo0ol000000ooooooo0000o`000002o`000004ooooool0003o0000ooooo`;o00005_ooool7
o`00013ooooo0_l0002<ooooo`007_ooool00ol0003oooooooooo`1iooooo`;o00000oooool3o`00
00;ooooo0_l00002ooooo`Go00005_ooool7o`00013ooooo0_l000000ooooooo0000o`000029oooo
o`007_ooool2o`0007[ooooo0_l00002ooooo`Co00000_ooool2o`0000?ooooo0_l0000Hooooo`So
00003_ooool2o`0000;ooooo0_l00005ooooo`;o0000P_ooool001kooooo00?o0000ooooooooool0
O?ooool5o`0000;ooooo0_l0000Eooooo`;o00001_ooool8o`0000Gooooo0_l00002ooooo`;o0000
0oooool2o`0000Wooooo0_l00022ooooo`007_ooool00ol0003oooooooooo`1kooooo`?o00000_oo
ool2o`000003ooooool0003o000000[ooooo0_l00003ooooo`;o00001?ooool2o`0000Kooooo2_l0
0003ooooo`;o00000_ooool2o`0000kooooo1?l00020ooooo`007_ooool00ol0003oooooooooo`1k
ooooo`;o00000oooool2o`000003ooooool0003o000000?o00001oooool2o`0000?ooooo1?l00007
ooooo`;o000000?oooooo`000?l000002?l00008ooooo`Co00003Oooool2o`00083ooooo000Noooo
o`03o`000?oooooooooo07Oooooo0_l0000:ooooo`Go00003_ooool2o`0000Oooooo0_l000000ooo
oooo0000o`000008o`0000Sooooo1?l0002?ooooo`007_ooool00ol0003oooooooooo`1gooooo`;o
00005?ooool2o`0001;ooooo2Ol00009ooooo`;o00001oooool2o`0000;ooooo0_l000000ooooooo
0000o`000022ooooo`007_ooool00ol0003oooooooooo`22ooooo`;o00002Oooool2o`000003oooo
ool0003o000000Cooooo0_l00008ooooo`_o000000?oooooo`000?l000001Oooool4o`0000?ooooo
1?l00002ooooo`;o000000?oooooo`000?l00000P_ooool001kooooo00?o0000ooooooooool0MOoo
ool2o`0000_ooooo0ol0000;ooooo`;o00000_ooool4o`0000Cooooo5?l00004ooooo`?o00000_oo
ool3o`0008_ooooo000Nooooo`03o`000?oooooooooo07Gooooo0_l00005ooooo`;o00001Oooool2
o`0000oooooo0_l00006oooooa3o00000_ooool2o`0000Cooooo0ol00002ooooo`;o0000S?ooool0
01kooooo00?o0000ooooooooool0N?ooool2o`0000;ooooo0_l0000Looooo`_o000000?oooooo`00
0?l000000ol0000:ooooo`;o00001oooool2o`0008Oooooo000Nooooo`03o`000?oooooooooo07So
oooo0_l0000Dooooo`;o00001ooooolEo`0000;ooooo0_l00008ooooo`;o000000Coooooo`000?l0
003ooooo0ol00026ooooo`007_ooool00ol0003oooooooooo`26ooooo`Go00000oooool2o`000003
ooooool0003o000000?ooooo4ol000000ooooooo0000o`000002ooooo`;o00002?ooool2o`000003
ooooool0003o000000;ooooo0_l00026ooooo`007_ooool00ol0003oooooooooo`21ooooo`;o0000
0oooool7o`0000?ooooo6Ol00005ooooo`;o00003oooool2o`0008Kooooo000Nooooo`03o`000?oo
oooooooo07Gooooo0_l000000ooooooo0000o`000003o`0000Cooooo0_l00003ooooo`;o000000?o
ooooo`000?l000000_l00003ooooo`ko000000?oooooo`000?l000002?l00005ooooo`?o00002ooo
ool2o`000003ooooool0003o000000;ooooo0_l00003ooooo`;o0000OOooool001kooooo00?o0000
ooooooooool0M?ooool3o`000003ooooool0003o000000?o00002Oooool7o`0000Cooooo1Ol00000
0ooooooo0000o`000005o`000003ooooool0003o000000So00000_ooool2o`000004ooooool0003o
0000o`0000_ooooo0_l00005ooooo`;o00000oooool2o`0007gooooo000Nooooo`03o`000?oooooo
oooo07Cooooo0ol0000@ooooo`Co00000oooool@o`000003ooooool0003o000000Wo000000?ooooo
o`000?l000001Oooool2o`0000Gooooo0_l000000ooooooo0000o`000004ooooo`;o0000Poooool0
01kooooo0_l0002?oooooa7o000000?oooooo`000?l000002?l00002ooooo`;o00001?ooool2o`00
00?ooooo1?l00007ooooo`;o00001?ooool2o`0007gooooo000Nooooo`03o`000?oooooooooo07So
oooo0_l00008ooooo`;o000000Coooooo`000?l0003o00000_oooolEo`000003ooooool0003o0000
00;o000000?oooooo`000?l000001ol00009ooooo`?o00003_ooool2o`0007gooooo000Nooooo`03
o`000?oooooooooo07Sooooo0_l00008oooooa;o00000_oooolFo`0000cooooo0_l00003ooooo`;o
0000R?ooool001kooooo00?o0000ooooooooool0P?ooool2o`000004ooooool0003o0000o`0000;o
oooo0_l00004ooooo`Ko00000_oooolDo`0001?ooooo0_l00028ooooo`007_ooool00ol0003ooooo
ooooo`1hooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000
o`000005oooooaco00000oooool2o`0000Gooooo0_l0002Aooooo`007_ooool00ol0003ooooooooo
o`1hooooo`;o00000oooool2o`0000Sooooo0_l00004oooooaWo000000?oooooo`000?l000000_l0
0002ooooo`;o00001Oooool2o`00097ooooo000Nooooo`03o`000?oooooooooo07oooooo1Ol00009
ooooo`Wo000000?oooooo`000?l000003ol000000ooooooo0000o`000009ooooo`;o00000_ooool2
o`0008gooooo000Nooooo`03o`000?oooooooooo07Wooooo0_l00003ooooo`Ko00001?ooool2o`00
00?ooooo0_l000000ooooooo0000o`00000Go`0000cooooo0_l000000ooooooo0000o`00000:oooo
o`?o0000P?ooool001kooooo00?o0000ooooooooool0NOooool2o`0000;ooooo2?l00002ooooo`?o
000000?oooooo`000?l000001_l00003ooooo`go000000?oooooo`000?l000000ol0000<ooooo`?o
00000oooool2o`000004ooooool0003o0000ooooo`;o000000Coooooo`000?l0003o0000P?ooool0
01kooooo00?o0000ooooooooool0N_ooool2o`000003ooooool0003o000000Ko00000_ooool2o`00
00;ooooo2?l00002ooooo`go000000?oooooo`000?l000000_l00008ooooo`;o00000oooool4o`00
00;ooooo0ol000001?oooooo0000o`000?ooool2o`0008Cooooo000Nooooo`03o`000?oooooooooo
07Cooooo0_l00004ooooo`;o00004?ooool8o`000003ooooool0003o000000oo000000?oooooo`00
0?l000001_ooool4o`000003ooooool0003o000000;ooooo1ol00028ooooo`007_ooool00ol0003o
ooooooooo`1dooooo`;o00001?ooool2o`00013ooooo1Ol000001?oooooo0000o`000?ooool@o`00
00;ooooo0_l00008ooooo`;o00001Oooool2o`0000;ooooo0ol00028ooooo`007_ooool00ol0003o
ooooooooo`1hooooo`;o00002Oooool2o`0000Cooooo0_l000001?oooooo0000o`000?l00006oooo
oaCo00002?ooool3o`0000Gooooo0_l00002ooooo`;o00000_ooool2o`0008Cooooo000Nooooo`03
o`000?oooooooooo07Sooooo0_l00009ooooo`;o00001?ooool6o`0000;ooooo0_l00004oooooa3o
00001Oooool2o`0000?ooooo0ol00003ooooo`Co00001_ooool4o`0008;ooooo000Nooooo`03o`00
0?oooooooooo08_ooooo0ol00003ooooo`;o00001?ooool6o`000003ooooool0003o000000So0000
00?oooooo`000?l000001Ol00002ooooo`;o00000_ooool3o`0000[ooooo0ol00021ooooo`007_oo
ool00ol0003oooooooooo`1gooooo`;o000000?oooooo`000?l000004?ooool2o`0000Oooooo6ol0
0003ooooo`Ko00001oooool2o`0000;ooooo0_l00021ooooo`007_ooool2o`0007Sooooo0_l00000
0ooooooo0000o`000007ooooo`;o00001_ooool3o`0000Oooooo5Ol00002ooooo`;o00001?ooool5
o`0000Kooooo0_l000000ooooooo0000o`000025ooooo`007_ooool00ol0003oooooooooo`23oooo
o`;o00001_ooool3o`0000Oooooo0_l000000ooooooo0000o`000002oooooa?o00000_ooool7o`00
00Gooooo0_l00028ooooo`007_ooool00ol0003oooooooooo`21ooooo`;o00001_ooool5o`0000Oo
oooo0_l000000ooooooo0000o`000003oooooa;o00000_ooool7o`0008oooooo000Nooooo`03o`00
0?oooooooooo07[ooooo1Ol00002ooooo`;o00001_ooool3o`0000gooooo0_l00007ooooo`ko0000
Uoooool001kooooo00?o0000ooooooooool0N_ooool5o`0001Gooooo0_l00003ooooo`;o000000?o
ooooo`000?l000001oooool;o`0000_ooooo0_l0002:ooooo`007_ooool00ol0003oooooooooo`2:
ooooo`;o00002?ooool2o`0000Kooooo0_l0000:ooooo`;o00000_ooool2o`0000gooooo0_l0002:
ooooo`007_ooool00ol0003oooooooooo`2:ooooo`?o000000?oooooo`000?l000001Oooool2o`00
00[ooooo0_l000000ooooooo0000o`000002ooooo`;o00001_ooool2o`0000Sooooo0_l0002;oooo
o`007_ooool00ol0003oooooooooo`2;ooooo`;o000000?oooooo`000?l000001Oooool2o`000003
ooooool0003o000000Kooooo0ol000000ooooooo0000o`00000:ooooo`;o00002?ooool4o`0008Wo
oooo000Nooooo`03o`000?oooooooooo08Gooooo0_l0000Aooooo`;o00001_ooool2o`0001[ooooo
0_l00029ooooo`007_ooool00ol0003oooooooooo`25ooooo`;o00006_ooool2o`0000kooooo0_l0
00000ooooooo0000o`000002ooooo`;o0000SOooool001kooooo00?o0000ooooooooool0Qoooool2
o`0000oooooo0_l00007ooooo`Co00003?ooool2o`000003ooooool0003o000000;ooooo0_l0002=
ooooo`007_ooool00ol0003oooooooooo`27ooooo`;o00001oooool2o`0000Kooooo1?l00004oooo
o`;o000000?oooooo`000?l000002Oooool2o`0009Oooooo000Nooooo`03o`000?oooooooooo08co
oooo0_l00002ooooo`;o00002?ooool2o`0000Cooooo0_l0000<ooooo`;o00002?ooool2o`0008go
oooo000Nooooo`03o`000?oooooooooo08Gooooo0_l00005ooooo`;o000000?oooooo`000?l00000
0_l0000Hooooo`;o00002oooool2o`0008gooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo08Go
oooo0ol00007ooooo`Ko00003?ooool2o`000003ooooool0003o000000Gooooo0_l00006ooooo`Co
0000T?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGo
MgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0Q_ooool2o`0000Wooooo1?l0000<oooo
o`;o000000Coooooo`000?l0003ooooo0_l0000:ooooo`Co0000T?ooool000?ooooo00Go410@oooo
oooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`0008oooooo0_l0
000Fooooo`;o00002oooool2o`00097ooooo0003ooooo`05o`000?ooooooooooooooool000002ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0Soooool2o`000;Kooooo
0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Ko
oooo00?o0000ooooooooool0]Oooool2o`00093ooooo0003ooooo`05oa0@4?ooooooooooooooool@
41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo08oooooo0_l0000;ooooo`;o
00005oooool2o`00093ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo
410@oiRHV008ooooo`03o`000?oooooooooo08oooooo0_l0000;ooooo`;o0000ZOooool000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000oooo
ooooool0Toooool2o`00017ooooo0_l00005ooooo`;o0000V?ooool001kooooo00?o0000oooooooo
ool0Toooool4o`000003ooooool0003o000000cooooo0_l00005ooooo`;o0000V?ooool001kooooo
00?o0000ooooooooool0UOooool5o`000:gooooo000Nooooo`03o`000?oooooooooo09Oooooo0_l0
0007ooooo`;o00002_ooool2o`0009Wooooo000Nooooo`03o`000?oooooooooo09?ooooo0_l0000;
ooooo`;o00002_ooool2o`0009Wooooo000Nooooo`03o`000?oooooooooo09;ooooo0ol00003oooo
o`;o00001_ooool2o`000:Gooooo000Nooooo`03o`000?oooooooooo09;ooooo0_l00002ooooo`Co
000000?oooooo`000?l00000Z_ooool001kooooo00?o0000ooooooooool0U_ooool2o`0000?ooooo
0_l0002Zooooo`007_ooool00ol0003oooooooooo`2Fooooo`;o0000[oooool001kooooo00?o0000
ooooooooool0U_ooool2o`000:oooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0
003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7o
V9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000oooooom8
ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go0000ooooooooooooooooo`00
000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`3oooooodSooooo
0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Ko
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Dooooo`Co000000?o410@ooooooooool00oooool00ol0003ooooo
ooooo`3oooooodSooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooo
oom8ooooo`005_ooool00ol0003oooooooooo`05ooooo`?o0000oooooom8ooooo`005_ooool00ol0
003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo
00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000D
ooooo`03oeEEEOmVIVKo00000?ooooooD_ooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.46423 .47647 Mdot
.46846 .49368 Mdot
.49613 .55647 Mdot
.48037 .48786 Mdot
.50042 .47504 Mdot
.45208 .43565 Mdot
.54489 .59803 Mdot
.4991 .46951 Mdot
.5761 .44556 Mdot
.54053 .4678 Mdot
.51541 .45547 Mdot
.48672 .52137 Mdot
.43643 .44168 Mdot
.4375 .54199 Mdot
.60432 .51494 Mdot
.53831 .48585 Mdot
.46417 .48014 Mdot
.52469 .41995 Mdot
.54154 .45448 Mdot
.4938 .55386 Mdot
.46711 .47535 Mdot
.52695 .52349 Mdot
.52572 .465 Mdot
.42083 .49116 Mdot
.48726 .472 Mdot
.50046 .52071 Mdot
.57695 .51636 Mdot
.54135 .43777 Mdot
.49648 .48254 Mdot
.43552 .4593 Mdot
.45753 .52136 Mdot
.47096 .48232 Mdot
.51005 .50056 Mdot
.49719 .56011 Mdot
.43424 .44956 Mdot
.48283 .55059 Mdot
.50991 .51559 Mdot
.55943 .4981 Mdot
.51468 .46806 Mdot
.48947 .52947 Mdot
.53186 .48744 Mdot
.50047 .55214 Mdot
.45695 .51463 Mdot
.49813 .50595 Mdot
.47148 .47761 Mdot
.52476 .50721 Mdot
.4423 .56663 Mdot
.45865 .52622 Mdot
.46575 .53414 Mdot
.55616 .38963 Mdot
.50811 .47215 Mdot
.41294 .43872 Mdot
.49405 .4855 Mdot
.50943 .46931 Mdot
.543 .48289 Mdot
.51016 .52785 Mdot
.47193 .52469 Mdot
.38815 .44881 Mdot
.48096 .4777 Mdot
.4705 .52696 Mdot
.5253 .51842 Mdot
.52105 .50779 Mdot
.49444 .55912 Mdot
.5373 .4849 Mdot
.50986 .47471 Mdot
.57901 .42242 Mdot
.44449 .5016 Mdot
.52018 .51725 Mdot
.49461 .54624 Mdot
.5402 .48754 Mdot
.57077 .56395 Mdot
.48925 .47942 Mdot
.47828 .5343 Mdot
.48762 .49539 Mdot
.42612 .47288 Mdot
.56322 .549 Mdot
.50678 .53956 Mdot
.52103 .41442 Mdot
.56121 .57168 Mdot
.53163 .43311 Mdot
.54356 .52217 Mdot
.49928 .47066 Mdot
.47762 .47104 Mdot
.5293 .49459 Mdot
.49518 .55983 Mdot
.4904 .49205 Mdot
.52658 .56476 Mdot
.51858 .5149 Mdot
.48506 .53116 Mdot
.47707 .40799 Mdot
.50187 .48332 Mdot
.52906 .50318 Mdot
.54417 .5485 Mdot
.56984 .40108 Mdot
.52675 .57616 Mdot
.5222 .53454 Mdot
.51599 .52015 Mdot
.45337 .518 Mdot
.44588 .57075 Mdot
.46824 .51684 Mdot
.53243 .56323 Mdot
.53212 .55564 Mdot
.49215 .47363 Mdot
.54273 .40365 Mdot
.58446 .45967 Mdot
.51234 .50308 Mdot
.45438 .63272 Mdot
.50636 .47768 Mdot
.44771 .50026 Mdot
.53014 .50281 Mdot
.43489 .48872 Mdot
.48771 .48017 Mdot
.47744 .50483 Mdot
.56117 .46113 Mdot
.445 .49418 Mdot
.43128 .42957 Mdot
.57201 .49834 Mdot
.5444 .4423 Mdot
.47943 .54972 Mdot
.54935 .54334 Mdot
.51167 .41615 Mdot
.49751 .51824 Mdot
.54162 .47191 Mdot
.4613 .52684 Mdot
.46282 .48613 Mdot
.55015 .46603 Mdot
.42868 .48615 Mdot
.49934 .51876 Mdot
.49918 .51134 Mdot
.53644 .4801 Mdot
.52604 .42379 Mdot
.45827 .48233 Mdot
.38781 .4932 Mdot
.48122 .5493 Mdot
.52455 .47238 Mdot
.39012 .50864 Mdot
.53148 .47173 Mdot
.50074 .49446 Mdot
.48627 .54128 Mdot
.48514 .50634 Mdot
.50425 .47971 Mdot
.58042 .46977 Mdot
.50375 .50945 Mdot
.48577 .48566 Mdot
.51305 .48919 Mdot
.53087 .50527 Mdot
.45691 .47209 Mdot
.5143 .5415 Mdot
.44398 .49533 Mdot
.46239 .52968 Mdot
.48803 .5546 Mdot
.54249 .43627 Mdot
.50124 .47769 Mdot
.43707 .52128 Mdot
.52208 .43238 Mdot
.53879 .48612 Mdot
.52227 .50424 Mdot
.40431 .47322 Mdot
.5059 .5402 Mdot
.50935 .48448 Mdot
.58834 .54508 Mdot
.49907 .54802 Mdot
.50677 .41186 Mdot
.54879 .48644 Mdot
.47938 .52784 Mdot
.47534 .5145 Mdot
.5886 .47131 Mdot
.53248 .51503 Mdot
.51007 .53677 Mdot
.55773 .4818 Mdot
.53179 .43492 Mdot
.46119 .5275 Mdot
.46294 .49785 Mdot
.48087 .53058 Mdot
.59534 .55606 Mdot
.51225 .51841 Mdot
.52662 .53253 Mdot
.51035 .4808 Mdot
.42063 .5578 Mdot
.47436 .542 Mdot
.48235 .48816 Mdot
.52833 .52862 Mdot
.49326 .49719 Mdot
.49378 .48444 Mdot
.43645 .4362 Mdot
.48479 .51749 Mdot
.50882 .56135 Mdot
.52569 .52155 Mdot
.56789 .40669 Mdot
.55129 .54768 Mdot
.4913 .50804 Mdot
.5226 .47435 Mdot
.42451 .49564 Mdot
.5031 .47755 Mdot
.55829 .48838 Mdot
.52696 .48632 Mdot
.56015 .38864 Mdot
.50471 .50451 Mdot
.51405 .47327 Mdot
.47589 .49265 Mdot
.46604 .51192 Mdot
.51943 .5223 Mdot
.51804 .41753 Mdot
.5162 .53004 Mdot
.53976 .47857 Mdot
.46106 .50025 Mdot
.4645 .47689 Mdot
.46579 .51913 Mdot
.49661 .55846 Mdot
.50353 .4758 Mdot
.47053 .47722 Mdot
.50705 .51421 Mdot
.49014 .53787 Mdot
.49018 .42195 Mdot
.49714 .51848 Mdot
.43873 .56569 Mdot
.52711 .50709 Mdot
.50394 .54049 Mdot
.57919 .46917 Mdot
.50639 .48037 Mdot
.52312 .46719 Mdot
.39014 .46248 Mdot
.52955 .50586 Mdot
.41543 .5249 Mdot
.52136 .47223 Mdot
.50975 .47357 Mdot
.47589 .48319 Mdot
.5449 .4717 Mdot
.50237 .55945 Mdot
.53595 .44667 Mdot
.54589 .49754 Mdot
.50531 .51403 Mdot
.56799 .46716 Mdot
.51885 .50601 Mdot
.50603 .52332 Mdot
.48551 .54143 Mdot
.55658 .46689 Mdot
.55766 .55603 Mdot
.45634 .49072 Mdot
.48477 .51766 Mdot
.54424 .47066 Mdot
.59959 .52029 Mdot
.44568 .47693 Mdot
.55237 .46985 Mdot
.51348 .58253 Mdot
.54362 .48527 Mdot
.56944 .54541 Mdot
.5073 .47155 Mdot
.55055 .4857 Mdot
.5773 .49525 Mdot
.45836 .5159 Mdot
.43935 .43117 Mdot
.58982 .51186 Mdot
.51949 .57901 Mdot
.48066 .50198 Mdot
.48002 .52039 Mdot
.5313 .46006 Mdot
.50045 .53694 Mdot
.498 .56085 Mdot
.58522 .49224 Mdot
.53019 .51929 Mdot
.52548 .48097 Mdot
.50959 .48496 Mdot
.50894 .42298 Mdot
.49034 .5548 Mdot
.49627 .55919 Mdot
.53786 .45299 Mdot
.53167 .42602 Mdot
.52267 .49028 Mdot
.41427 .5524 Mdot
.4471 .50143 Mdot
.47737 .50525 Mdot
.57031 .40815 Mdot
.48135 .50564 Mdot
.5066 .56047 Mdot
.57009 .55145 Mdot
.51095 .53236 Mdot
.53952 .45725 Mdot
.49291 .55176 Mdot
.53309 .45751 Mdot
.48964 .544 Mdot
.50093 .52628 Mdot
.45265 .54231 Mdot
.50757 .49382 Mdot
.56788 .48661 Mdot
.56731 .39802 Mdot
.43148 .56468 Mdot
.52841 .46267 Mdot
.45888 .49213 Mdot
.43818 .51738 Mdot
.47992 .5251 Mdot
.43941 .50577 Mdot
.44122 .42344 Mdot
.45961 .52145 Mdot
.4752 .51415 Mdot
.50633 .47019 Mdot
.5363 .4337 Mdot
.47777 .54542 Mdot
.50433 .5503 Mdot
.48088 .48669 Mdot
.50206 .50171 Mdot
.51085 .47388 Mdot
.58524 .45179 Mdot
.54104 .49676 Mdot
.48259 .5232 Mdot
.48187 .48686 Mdot
.38327 .53806 Mdot
.43733 .49779 Mdot
.48602 .47392 Mdot
.48744 .55281 Mdot
.48198 .49259 Mdot
.50816 .49545 Mdot
.53183 .4516 Mdot
.48462 .47737 Mdot
.47285 .49658 Mdot
.44756 .49262 Mdot
.49104 .52997 Mdot
.51942 .51637 Mdot
.48082 .53542 Mdot
.55579 .49378 Mdot
.46946 .53708 Mdot
.50562 .45886 Mdot
.49728 .45399 Mdot
.51188 .52148 Mdot
.53539 .44027 Mdot
.54699 .48561 Mdot
.49412 .50762 Mdot
.49833 .5128 Mdot
.56303 .4438 Mdot
.52775 .54953 Mdot
.44991 .47048 Mdot
.42087 .43961 Mdot
.47651 .50623 Mdot
.54002 .46519 Mdot
.49205 .55672 Mdot
.52571 .4618 Mdot
.48607 .55292 Mdot
.48509 .4835 Mdot
.49971 .47103 Mdot
.51979 .51012 Mdot
.44395 .50309 Mdot
.44735 .49344 Mdot
.48131 .61568 Mdot
.50539 .50693 Mdot
.52859 .51358 Mdot
.44661 .49362 Mdot
.5068 .49373 Mdot
.50027 .47055 Mdot
.53317 .51698 Mdot
.52952 .49454 Mdot
.47574 .52437 Mdot
.38948 .48503 Mdot
.46772 .47752 Mdot
.51557 .51055 Mdot
.46267 .42031 Mdot
.47595 .51891 Mdot
.4314 .538 Mdot
.45367 .48828 Mdot
.45036 .41539 Mdot
.51307 .50119 Mdot
.51212 .47294 Mdot
.44638 .49575 Mdot
.47617 .51099 Mdot
.43327 .52728 Mdot
.45104 .49029 Mdot
.45793 .54628 Mdot
.4913 .57958 Mdot
.53229 .51316 Mdot
.41446 .57196 Mdot
.49183 .49229 Mdot
.50907 .48385 Mdot
.50177 .49081 Mdot
.39213 .47354 Mdot
.53029 .46283 Mdot
.48521 .55151 Mdot
.54033 .47393 Mdot
.53481 .45444 Mdot
.54125 .56225 Mdot
.49728 .55444 Mdot
.50577 .51727 Mdot
.48391 .55104 Mdot
.53922 .57914 Mdot
.49074 .48209 Mdot
.40933 .50304 Mdot
.47685 .48144 Mdot
.46276 .43782 Mdot
.54197 .43725 Mdot
.52593 .45967 Mdot
.50741 .52778 Mdot
.48192 .54918 Mdot
.38275 .51748 Mdot
.49486 .55244 Mdot
.4724 .53966 Mdot
.47142 .48158 Mdot
.52397 .46521 Mdot
.49146 .47015 Mdot
.54546 .49867 Mdot
.50947 .49707 Mdot
.53609 .44 Mdot
.38778 .52405 Mdot
.39299 .5383 Mdot
.48187 .54953 Mdot
.36928 .51162 Mdot
.49953 .52661 Mdot
.47323 .54009 Mdot
.47788 .54667 Mdot
.49226 .48427 Mdot
.50729 .48193 Mdot
.46216 .51298 Mdot
.53028 .43439 Mdot
.48611 .50967 Mdot
.53639 .45147 Mdot
.48941 .495 Mdot
.45961 .52659 Mdot
.49353 .4937 Mdot
.5349 .5561 Mdot
.53331 .49996 Mdot
.42579 .5006 Mdot
.4631 .52595 Mdot
.54374 .4737 Mdot
.53035 .45078 Mdot
.52381 .50997 Mdot
.49279 .49816 Mdot
.53947 .46009 Mdot
.37428 .47502 Mdot
.48416 .55207 Mdot
.59967 .49124 Mdot
.52606 .49031 Mdot
.48906 .54596 Mdot
.49227 .5364 Mdot
.44089 .5087 Mdot
.54008 .48802 Mdot
.46233 .4797 Mdot
.52984 .4472 Mdot
.51389 .52981 Mdot
.42055 .49696 Mdot
.51199 .53337 Mdot
.4724 .52587 Mdot
.43853 .5069 Mdot
.4799 .5294 Mdot
.45844 .5214 Mdot
.45657 .4048 Mdot
.43845 .51296 Mdot
.5106 .42564 Mdot
.51312 .50235 Mdot
.52738 .42475 Mdot
.49511 .47848 Mdot
.53906 .47892 Mdot
.49467 .55884 Mdot
.50015 .48265 Mdot
.46288 .5623 Mdot
.48396 .51408 Mdot
.53165 .49047 Mdot
.48259 .53248 Mdot
.51425 .56283 Mdot
.56947 .44965 Mdot
.48723 .55393 Mdot
.55469 .50169 Mdot
.5059 .48654 Mdot
.49641 .53696 Mdot
.51199 .53849 Mdot
.48373 .49595 Mdot
.46241 .5326 Mdot
.51783 .50565 Mdot
.46788 .53395 Mdot
.40748 .53303 Mdot
.52366 .49736 Mdot
.49126 .50096 Mdot
.43998 .50722 Mdot
.49894 .5396 Mdot
.48354 .4645 Mdot
.52936 .46305 Mdot
.52138 .62647 Mdot
.62024 .52311 Mdot
.53595 .44424 Mdot
.57419 .44948 Mdot
.46797 .53468 Mdot
.6228 .52183 Mdot
.53485 .56305 Mdot
.39118 .5028 Mdot
.5077 .49783 Mdot
.46834 .47728 Mdot
.50323 .47151 Mdot
.48357 .47369 Mdot
.52393 .5115 Mdot
.51067 .53751 Mdot
.53967 .46308 Mdot
.46014 .47637 Mdot
.46417 .53123 Mdot
.54299 .56176 Mdot
.43313 .41677 Mdot
.50105 .55939 Mdot
.57005 .42715 Mdot
.51224 .47574 Mdot
.46137 .51794 Mdot
.45694 .42141 Mdot
.57418 .47764 Mdot
.51318 .47772 Mdot
.50489 .5441 Mdot
.50188 .47515 Mdot
.45782 .621 Mdot
.59298 .50527 Mdot
.52164 .61415 Mdot
.52419 .46653 Mdot
.48365 .51691 Mdot
.54919 .46752 Mdot
.4595 .48313 Mdot
.53742 .46941 Mdot
.54116 .56398 Mdot
.56233 .39414 Mdot
.49467 .55218 Mdot
.49216 .55797 Mdot
.45669 .51315 Mdot
.45797 .42735 Mdot
.50783 .4748 Mdot
.53832 .48964 Mdot
.45795 .51477 Mdot
.43663 .44745 Mdot
.45894 .55811 Mdot
.4888 .47574 Mdot
.55098 .48386 Mdot
.44571 .5001 Mdot
.49236 .47729 Mdot
.50331 .52096 Mdot
.47773 .51782 Mdot
.51483 .52183 Mdot
.47667 .54487 Mdot
.41679 .43352 Mdot
.52907 .42825 Mdot
.53501 .44628 Mdot
.50686 .55891 Mdot
.53111 .50537 Mdot
.51012 .53247 Mdot
.48313 .49693 Mdot
.56628 .41012 Mdot
.48948 .51823 Mdot
.40703 .49298 Mdot
.52178 .51575 Mdot
.46819 .52214 Mdot
.54503 .45936 Mdot
.4801 .50339 Mdot
.50615 .40952 Mdot
.5345 .50163 Mdot
.41264 .49657 Mdot
.52942 .42745 Mdot
.57929 .52888 Mdot
.48995 .48344 Mdot
.50002 .40604 Mdot
.49075 .47736 Mdot
.53046 .44341 Mdot
.48498 .53005 Mdot
.51973 .46896 Mdot
.51147 .49405 Mdot
.44613 .61609 Mdot
.48238 .48159 Mdot
.52124 .47091 Mdot
.50401 .48494 Mdot
.47212 .53706 Mdot
.43827 .41694 Mdot
.56624 .5214 Mdot
.53175 .55245 Mdot
.50589 .5629 Mdot
.53965 .47647 Mdot
.49406 .48927 Mdot
.49774 .55704 Mdot
.53167 .45958 Mdot
.54968 .60632 Mdot
.53053 .45631 Mdot
.40917 .4995 Mdot
.466 .53276 Mdot
.41398 .55114 Mdot
.50247 .51713 Mdot
.46717 .53189 Mdot
.49521 .47311 Mdot
.48526 .51479 Mdot
.5344 .48897 Mdot
.49288 .40598 Mdot
.48615 .52999 Mdot
.55251 .55776 Mdot
.49288 .52226 Mdot
.51353 .5625 Mdot
.49063 .47962 Mdot
.48133 .622 Mdot
.46166 .50991 Mdot
.50026 .54629 Mdot
.43846 .57744 Mdot
.51993 .47211 Mdot
.44724 .49653 Mdot
.45266 .48596 Mdot
.49836 .56042 Mdot
.48343 .51877 Mdot
.52702 .5012 Mdot
.51589 .47244 Mdot
.49289 .51211 Mdot
.53827 .47806 Mdot
.44918 .47203 Mdot
.41806 .50116 Mdot
.53034 .52867 Mdot
.50822 .41199 Mdot
.46663 .49687 Mdot
.52362 .52145 Mdot
.54447 .50395 Mdot
.47756 .47336 Mdot
.47519 .41981 Mdot
.52771 .50035 Mdot
.44995 .50354 Mdot
.53016 .47192 Mdot
.48027 .56589 Mdot
.52029 .50821 Mdot
.49681 .51359 Mdot
.54342 .43877 Mdot
.44583 .48556 Mdot
.53201 .46139 Mdot
.44122 .57311 Mdot
.4564 .47711 Mdot
.49846 .47868 Mdot
.51626 .46785 Mdot
.54485 .48102 Mdot
.50939 .47534 Mdot
.59918 .54308 Mdot
.54762 .59456 Mdot
.40794 .43936 Mdot
.47825 .50047 Mdot
.52179 .50493 Mdot
.50041 .58561 Mdot
.48385 .55096 Mdot
.50105 .47974 Mdot
.50399 .48819 Mdot
.3917 .51013 Mdot
.4598 .49317 Mdot
.52358 .51711 Mdot
.53965 .48284 Mdot
.46309 .53014 Mdot
.51014 .40781 Mdot
.50354 .4086 Mdot
.50578 .46897 Mdot
.55543 .55251 Mdot
.48977 .50352 Mdot
.48664 .47589 Mdot
.43131 .56396 Mdot
.50634 .46992 Mdot
.50852 .5371 Mdot
.48191 .57499 Mdot
.52422 .49234 Mdot
.53644 .47767 Mdot
.48548 .41936 Mdot
.46742 .42082 Mdot
.51689 .50244 Mdot
.53718 .59203 Mdot
.55467 .58305 Mdot
.49515 .47705 Mdot
.5114 .49195 Mdot
.50858 .50931 Mdot
.44798 .50023 Mdot
.47195 .50894 Mdot
.45884 .5177 Mdot
.58841 .43176 Mdot
.49083 .50549 Mdot
.50026 .55937 Mdot
.49268 .51387 Mdot
.49016 .47698 Mdot
.5134 .49353 Mdot
.43175 .52794 Mdot
.38086 .45511 Mdot
.45707 .60849 Mdot
.48893 .55537 Mdot
.53911 .50283 Mdot
.37471 .52769 Mdot
.44144 .48406 Mdot
.61335 .47428 Mdot
.46315 .49302 Mdot
.38001 .47237 Mdot
.39023 .53835 Mdot
.54297 .5088 Mdot
.53229 .47589 Mdot
.55151 .47862 Mdot
.4822 .54062 Mdot
.47282 .47753 Mdot
.53981 .43272 Mdot
.50752 .46984 Mdot
.52861 .52033 Mdot
.53291 .55102 Mdot
.45318 .49783 Mdot
.5454 .53882 Mdot
.46683 .48003 Mdot
.5188 .52561 Mdot
.46326 .48806 Mdot
.44106 .43202 Mdot
.48444 .53589 Mdot
.48833 .54868 Mdot
.51225 .54122 Mdot
.48502 .55072 Mdot
.40552 .44425 Mdot
.50673 .52481 Mdot
.47573 .54291 Mdot
.47022 .47888 Mdot
.45389 .62781 Mdot
.50171 .50461 Mdot
.53125 .50026 Mdot
.48215 .48556 Mdot
.52754 .46948 Mdot
.49007 .51916 Mdot
.45037 .53438 Mdot
.50957 .47477 Mdot
.48672 .56368 Mdot
.56813 .57982 Mdot
.51554 .51889 Mdot
.50536 .47364 Mdot
.50352 .56186 Mdot
.53942 .45956 Mdot
.5612 .42744 Mdot
.49543 .513 Mdot
.51396 .5638 Mdot
.5468 .46106 Mdot
.43778 .51809 Mdot
.57615 .51893 Mdot
.54567 .46646 Mdot
.4631 .48056 Mdot
.45469 .43996 Mdot
.53725 .43057 Mdot
.48888 .49076 Mdot
.53046 .43737 Mdot
.48643 .54431 Mdot
.48424 .49445 Mdot
.45085 .48567 Mdot
.47431 .52123 Mdot
.48742 .4036 Mdot
.48774 .42105 Mdot
.40702 .4933 Mdot
.51477 .53726 Mdot
.52015 .43435 Mdot
.53125 .49261 Mdot
.47624 .52206 Mdot
.52435 .4993 Mdot
.426 .42774 Mdot
.55331 .58917 Mdot
.50889 .52066 Mdot
.52762 .52892 Mdot
.53873 .45379 Mdot
.50395 .538 Mdot
.52578 .50628 Mdot
.42625 .44457 Mdot
.50419 .5259 Mdot
.50382 .47683 Mdot
.5172 .47828 Mdot
.50582 .47122 Mdot
.51132 .47622 Mdot
.51841 .51377 Mdot
.50013 .51106 Mdot
.47287 .46175 Mdot
.47404 .54313 Mdot
.50739 .48784 Mdot
.47554 .52823 Mdot
.50365 .47292 Mdot
.54199 .50179 Mdot
.41837 .51281 Mdot
.58127 .47086 Mdot
.54088 .47331 Mdot
.45658 .51936 Mdot
.52882 .44967 Mdot
.44654 .44899 Mdot
.46055 .43752 Mdot
.62655 .51338 Mdot
.49872 .55078 Mdot
.48893 .40325 Mdot
.48333 .49884 Mdot
.40499 .50279 Mdot
.49023 .48369 Mdot
.49654 .50815 Mdot
.47977 .54667 Mdot
.49307 .43165 Mdot
.45544 .51932 Mdot
.43155 .45587 Mdot
.49362 .49198 Mdot
.4861 .55318 Mdot
.56245 .52761 Mdot
.61063 .48732 Mdot
.48821 .4771 Mdot
.48831 .5002 Mdot
.49486 .54086 Mdot
.5256 .47215 Mdot
.44602 .4951 Mdot
.43964 .44915 Mdot
.44154 .41092 Mdot
.37663 .47713 Mdot
.57148 .55209 Mdot
.46878 .50589 Mdot
.5334 .48388 Mdot
.53575 .43739 Mdot
.50266 .54535 Mdot
.47412 .49541 Mdot
.5175 .41833 Mdot
.48443 .49015 Mdot
.55638 .50331 Mdot
.44928 .49962 Mdot
.53647 .50246 Mdot
.44958 .50485 Mdot
.44315 .62063 Mdot
.53895 .47706 Mdot
.4699 .59494 Mdot
.52647 .48237 Mdot
.46815 .5207 Mdot
.53902 .56299 Mdot
.62049 .47876 Mdot
.46631 .47732 Mdot
.53741 .48082 Mdot
.47855 .52604 Mdot
.50096 .47487 Mdot
.47194 .47494 Mdot
.53765 .42257 Mdot
.48947 .48397 Mdot
.57857 .52843 Mdot
.48654 .48784 Mdot
.47888 .45398 Mdot
.53956 .47656 Mdot
.45817 .51659 Mdot
.52194 .52992 Mdot
.47184 .52175 Mdot
.47422 .47885 Mdot
.46011 .52514 Mdot
.5217 .49854 Mdot
.47976 .50085 Mdot
.57476 .55092 Mdot
.5393 .45594 Mdot
.47231 .48019 Mdot
.547 .45442 Mdot
.51119 .47386 Mdot
.45633 .49314 Mdot
.44989 .49905 Mdot
.50444 .52637 Mdot
.45144 .60528 Mdot
.44406 .50298 Mdot
.48106 .55755 Mdot
.52212 .51161 Mdot
.50505 .51302 Mdot
.53189 .47592 Mdot
.49946 .55506 Mdot
.53142 .43182 Mdot
.47817 .49848 Mdot
.56397 .48937 Mdot
.45952 .47823 Mdot
.52638 .50566 Mdot
.52547 .53044 Mdot
.58869 .55469 Mdot
.56086 .57548 Mdot
.51383 .56066 Mdot
.61265 .47118 Mdot
.49874 .55716 Mdot
.52591 .5091 Mdot
.47966 .53552 Mdot
.46003 .48816 Mdot
.48629 .41572 Mdot
.43997 .56073 Mdot
.38796 .53727 Mdot
.59824 .55941 Mdot
.48389 .5138 Mdot
.51839 .49443 Mdot
.46417 .42492 Mdot
.49156 .49957 Mdot
.50488 .47741 Mdot
.51092 .563 Mdot
.48343 .51407 Mdot
.50883 .49419 Mdot
.54883 .53554 Mdot
.53447 .43149 Mdot
.50547 .56297 Mdot
.464 .50162 Mdot
.54103 .42807 Mdot
.47012 .49526 Mdot
.39826 .43526 Mdot
.52298 .42172 Mdot
.56367 .48767 Mdot
.46653 .53681 Mdot
.44849 .47133 Mdot
.46352 .48121 Mdot
.49251 .4925 Mdot
.51346 .46827 Mdot
.5287 .50135 Mdot
.48447 .52968 Mdot
.41767 .43348 Mdot
.45831 .60498 Mdot
.392 .47505 Mdot
.44335 .49714 Mdot
.49668 .48637 Mdot
.47733 .40069 Mdot
.47955 .47628 Mdot
.48619 .53577 Mdot
.5354 .48764 Mdot
.54931 .56009 Mdot
.39629 .47498 Mdot
.5096 .54376 Mdot
.50789 .50774 Mdot
.5306 .5635 Mdot
.52915 .44533 Mdot
.51336 .47902 Mdot
.56173 .40829 Mdot
.49622 .47959 Mdot
.451 .50157 Mdot
.47897 .50688 Mdot
.47435 .50615 Mdot
.50681 .43479 Mdot
.4662 .51215 Mdot
.45586 .48271 Mdot
.47077 .4965 Mdot
.55159 .44342 Mdot
.48935 .48988 Mdot
.54569 .56091 Mdot
.48404 .53885 Mdot
.50715 .46998 Mdot
.44208 .49932 Mdot
.50287 .56099 Mdot
.52237 .52547 Mdot
.48045 .51241 Mdot
.51845 .4667 Mdot
.46704 .48661 Mdot
.49004 .52317 Mdot
.52162 .56004 Mdot
.49955 .60744 Mdot
.43393 .48693 Mdot
.565 .50884 Mdot
.52701 .49986 Mdot
.50018 .50715 Mdot
.43279 .53985 Mdot
.51655 .55791 Mdot
.58944 .50372 Mdot
.48433 .49346 Mdot
.50599 .47027 Mdot
.48365 .5241 Mdot
.60155 .45092 Mdot
.4912 .48657 Mdot
.46856 .50773 Mdot
.50359 .54796 Mdot
.57978 .43956 Mdot
.45748 .48866 Mdot
.49297 .50111 Mdot
.55888 .3875 Mdot
.52121 .50653 Mdot
.44702 .5995 Mdot
.57815 .50657 Mdot
.57725 .54577 Mdot
.40977 .4616 Mdot
.4887 .47278 Mdot
.46602 .53394 Mdot
.4857 .49201 Mdot
.51774 .52845 Mdot
.44897 .47894 Mdot
.44698 .51112 Mdot
.45329 .52533 Mdot
.46518 .5289 Mdot
.41178 .50175 Mdot
.54337 .44006 Mdot
.48325 .50604 Mdot
.50596 .40905 Mdot
.45423 .49385 Mdot
.4812 .48996 Mdot
.53412 .42754 Mdot
.53298 .55893 Mdot
.53603 .4956 Mdot
.43653 .59099 Mdot
.60395 .54212 Mdot
.52411 .53671 Mdot
.49392 .49472 Mdot
.53076 .52424 Mdot
.50779 .51228 Mdot
.52076 .4989 Mdot
.45794 .51984 Mdot
.50743 .56077 Mdot
.46592 .50975 Mdot
.53218 .49153 Mdot
.55777 .52614 Mdot
.49716 .55845 Mdot
.44357 .48925 Mdot
.42308 .43359 Mdot
.53357 .51134 Mdot
.41269 .5698 Mdot
.53981 .48974 Mdot
.4665 .62981 Mdot
.49407 .49637 Mdot
.49897 .52508 Mdot
.5225 .41769 Mdot
.46616 .40475 Mdot
.50654 .48213 Mdot
.48888 .47251 Mdot
.51608 .4746 Mdot
.43856 .50877 Mdot
.47835 .54926 Mdot
.45576 .48451 Mdot
.47389 .50292 Mdot
.53925 .49712 Mdot
.52616 .45754 Mdot
.46465 .47629 Mdot
.51711 .46783 Mdot
.44169 .49492 Mdot
.53424 .45966 Mdot
.53944 .47244 Mdot
.51961 .52517 Mdot
.56035 .54107 Mdot
.5217 .56789 Mdot
.58193 .56189 Mdot
.49671 .40535 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0/_ooool2o`0009?ooooo000Nooooo`03
o`000?oooooooooo0;7ooooo0ol0002Cooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`2aooooo`Co
0000T_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0;?ooooo0ol0002Aooooo`000oooool01Ol@413ooooo
oooooooooooo410@00_ooooo1Ol00006ooooo`?o0000Uoooool2o`0001_ooooo0ol0002@ooooo`00
0oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool00ol0
003oooooooooo`2Gooooo`;o000000Coooooo`000?l0003o00003oooool2o`0000Oooooo0_l0002@
ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001ooo
ool00ol0003oooooooooo`2@ooooo`;o000000?oooooo`000?l000001Oooool6o`0000cooooo0_l0
0007ooooo`;o0000T?ooool000?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<
c<co000000Oooooo00?o0000ooooooooool0T?ooool2o`000003ooooool0003o000000;ooooo0_l0
0003ooooo`So00003oooool4o`00093ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo08_ooooo0_l0000:ooooo`;o00001ooo
ool4o`0000oooooo1?l0002@ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?o
MgMgo`000?ooool01_ooool00ol0003oooooooooo`2;ooooo`;o000000?oooooo`000?l000002_oo
ool2o`0000Gooooo0ol000000ooooooo0000o`00002Pooooo`007_ooool00ol0003oooooooooo`29
ooooo`?o00000_ooool2o`0000[ooooo0_l00006ooooo`Ko0000Woooool001kooooo00?o0000oooo
ooooool0ROooool3o`0000Cooooo2?l00002ooooo`?o00001oooool4o`0000?ooooo0_l0000;oooo
o`;o0000SOooool001kooooo00?o0000ooooooooool0Roooool2o`0000?ooooo2?l00002ooooo`?o
00001?ooool3o`0000;ooooo0ol00002ooooo`;o00002oooool2o`0008gooooo000Nooooo`03o`00
0?oooooooooo08Kooooo0_l00003ooooo`;o00001?ooool4o`0000cooooo0ol00003ooooo`Oo0000
1?ooool2o`000003ooooool0003o0000093ooooo000Nooooo`03o`000?oooooooooo08Kooooo1?l0
00000ooooooo0000o`000004ooooo`;o00002Oooool2o`0000[ooooo1_l00004ooooo`;o000000?o
ooooo`000?l000001?ooool2o`0008[ooooo000Nooooo`03o`000?oooooooooo08?ooooo1?l00000
1?oooooo0000o`000?ooool2o`0000oooooo0_l00003ooooo`;o00000_ooool8o`0000kooooo0_l0
002:ooooo`007_ooool00ol0003oooooooooo`1mooooo`;o00001?ooool4o`0000?ooooo0_l00003
ooooo`;o000000?oooooo`000?l000003Oooool2o`0000;ooooo2Ol0002Iooooo`007_ooool00ol0
003oooooooooo`1mooooo`;o00000_ooool3o`000003ooooool0003o000000?ooooo0_l00003oooo
o`Go00005?ooool7o`0000Wooooo0_l0002=ooooo`007_ooool00ol0003oooooooooo`20ooooo`Co
000000?oooooo`000?l000000oooool2o`0000Cooooo0_l0000Fooooo`Co000000?oooooo`000?l0
00000_l00002ooooo`;o00000oooool2o`0008gooooo000Nooooo`03o`000?oooooooooo083ooooo
0_l00004ooooo`;o00000_ooool2o`0001cooooo1?l000000ooooooo0000o`000002o`0000;ooooo
0_l00002ooooo`;o0000S_ooool001kooooo00?o0000ooooooooool0N_ooool2o`0000[ooooo0_l0
00000ooooooo0000o`000004o`0001Wooooo1?l00009ooooo`Co0000S_ooool001kooooo0_l0001k
ooooo`;o00003Oooool6o`0001Wooooo1Ol00008ooooo`Co000000?oooooo`000?l000000oooool2
o`0008Kooooo000Nooooo`03o`000?oooooooooo07Sooooo0_l0000>ooooo`;o00003_ooool2o`00
00Cooooo0_l00003ooooo`;o00000oooool8o`0000[ooooo0_l00003ooooo`;o0000Q_ooool001ko
oooo00?o0000ooooooooool0N?ooool2o`0000kooooo0ol0000=ooooo`;o00001?ooool4o`000003
ooooool0003o000000;ooooo2Ol0000:ooooo`;o0000Roooool001kooooo00?o0000ooooooooool0
Noooool2o`0000Cooooo0_l00006ooooo`;o00002oooool2o`0000Sooooo0_l00005ooooo`Wo0000
0_ooool2o`0000Kooooo0_l0002;ooooo`007_ooool00ol0003oooooooooo`1kooooo`;o00001?oo
ool2o`0001?ooooo0_l000000ooooooo0000o`00000;ooooo`Oo000000?oooooo`000?l000000_oo
ool2o`0009?ooooo000Nooooo`03o`000?oooooooooo09Wooooo0_l00008ooooo`Oo000000?ooooo
o`000?l000001_l00002ooooo`;o0000T?ooool001kooooo00?o0000ooooooooool0S_ooool2o`00
00Oooooo0_l000000ooooooo0000o`00000Go`0000;ooooo0_l000000ooooooo0000o`000003o`00
00Kooooo0_l00022ooooo`007_ooool00ol0003oooooooooo`1fooooo`?o00000_ooool6o`0000Go
oooo0_l00006ooooo`Co00000ooooolLo`0000Oooooo1Ol00006ooooo`;o0000P_ooool001kooooo
00?o0000ooooooooool0M_ooool3o`0000;ooooo1_l00005ooooo`;o00001Oooool2o`000003oooo
ool0003o000001go00002?ooool2o`0000[ooooo0_l00022ooooo`007_ooool00ol0003ooooooooo
o`1fooooo`;o00005OoooolIo`000003ooooool0003o000000So00001_ooool2o`0000gooooo0_l0
001oooooo`007_ooool00ol0003oooooooooo`2;ooooo`;o000000?oooooo`000?l000005_l00000
0ooooooo0000o`00000:o`0001?ooooo0_l0001oooooo`007_ooool00ol0003oooooooooo`1koooo
o`;o00002_oooolMo`0000?ooooo3?l00002ooooo`;o00002oooool2o`0008?ooooo000Nooooo`03
o`000?oooooooooo07_ooooo0_l0000:ooooo`Co000000?oooooo`000?l000002?l00002ooooo`Oo
000000?oooooo`000?l000000ol000000ooooooo0000o`00000?o`0000_ooooo0_l00023ooooo`00
7_ooool00ol0003oooooooooo`1jooooo`;o00001?ooool2o`0000?ooooo0_l00002ooooo`;o0000
00?oooooo`000?l000001_l00003ooooo`ko000000?oooooo`000?l000001_l00003ooooo`Co0000
1Oooool2o`0000?ooooo0_l00026ooooo`007_ooool00ol0003oooooooooo`1jooooo`;o00001?oo
ool4o`000004ooooool0003o0000o`0000?ooooo1?l000000ooooooo0000o`00000Jo`0000Gooooo
0_l00005ooooo`Co00000oooool2o`0008Kooooo000Nooooo`03o`000?oooooooooo087ooooo0ol0
00001?oooooo0000o`000?l00002ooooobGo00000_ooool3o`0000;ooooo1?l0002=ooooo`007_oo
ool2o`00087ooooo2?l00002ooooo`Oo000000?oooooo`000?l000000_l000000ooooooo0000o`00
0005o`000003ooooool0003o000000ko000000?oooooo`000?l000000_l00002ooooo`;o0000Sooo
ool001kooooo00?o0000ooooooooool0Noooool2o`0000?ooooo2?l00003ooooo`Ko000000Gooooo
o`000?l0003o0000ooooo`04o`000005ooooool0003o0000o`000?ooool04?l000001?oooooo0000
o`000?l00009ooooo`?o0000R?ooool001kooooo00?o0000ooooooooool0Noooool2o`0000Cooooo
0_l00007ooooo`Ko00001?oooolKo`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o0000
0_ooool3o`0008Sooooo000Nooooo`03o`000?oooooooooo07Cooooo0_l00005ooooo`;o00003Ooo
ool5o`0000?ooooo4Ol000000ooooooo0000o`000005o`000003ooooool0003o000000Kooooo0_l0
0002ooooo`;o00000_ooool2o`0008Wooooo000Nooooo`03o`000?oooooooooo07Cooooo0_l00005
ooooo`;o00001oooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool5o`000003ooooool0
003o000000_o000000?oooooo`000?l000001Ol0000Aooooo`;o00000_ooool2o`0000Kooooo0_l0
001mooooo`007_ooool00ol0003oooooooooo`1hooooo`;o00002_ooool2o`0000Cooooo0_l00003
oooooaco00003?ooool2o`0000Oooooo0_l00006ooooo`;o0000OOooool001kooooo00?o0000oooo
ooooool0N?ooool2o`00013ooooo0_l00003ooooo`ko000000?oooooo`000?l000002ol0000<oooo
o`;o00001_ooool2o`0008Kooooo000Nooooo`03o`000?oooooooooo07[ooooo0_l0000>ooooo`;o
00001?oooolJo`0000?ooooo0_l00005ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Go
oooo0_l0001oooooo`007_ooool00ol0003oooooooooo`1jooooo`;o00001oooool2o`0000Cooooo
0ol00003oooooa_o00000oooool2o`0000;ooooo0_l000000ooooooo0000o`00000@ooooo`;o0000
Ooooool001kooooo00?o0000ooooooooool0M_ooool2o`0000_ooooo0_l00003ooooo`?o00001?oo
oolKo`0000Oooooo1?l00003ooooo`;o0000SOooool001kooooo00?o0000ooooooooool0M_ooool2
o`0000Sooooo0_l00006ooooo`;o00002?ooool<o`0000?ooooo2Ol00009ooooo`;o00000oooool2
o`0008gooooo000Nooooo`03o`000?oooooooooo083ooooo0_l0000<ooooo`;o00000_ooool4o`00
0003ooooool0003o000000Go00001?ooool2o`0000;ooooo0ol00005ooooo`;o0000Uoooool001ko
oooo00?o0000ooooooooool0N?ooool6o`0000[ooooo0_l00004ooooo`;o00000ooooolBo`000003
ooooool0003o000000Gooooo0ol0002Gooooo`007_ooool00ol0003oooooooooo`1hooooo`Ko0000
2_ooool4o`0000?ooooo0_l00003ooooo`Co000000?oooooo`000?l000002_l000000ooooooo0000
o`000005ooooo`;o00000oooool2o`0000cooooo0_l00025ooooo`007_ooool00ol0003ooooooooo
o`29ooooo`?o00000oooool2o`0000Gooooo3ol00009ooooo`;o00000_ooool2o`000004ooooool0
003o0000ooooo`;o000000?oooooo`000?l000000_ooool3o`0008Gooooo000Nooooo`03o`000?oo
oooooooo097ooooo0_l00003ooooo`ko00002Oooool4o`0000Cooooo0_l000001?oooooo0000o`00
0?ooool2o`0000;ooooo0_l00026ooooo`007_ooool2o`0008?ooooo0_l0000=ooooo`;o00001?oo
ool;o`0000Gooooo1?l00002ooooo`Co00000_ooool6o`0008kooooo000Nooooo`03o`000?oooooo
oooo08;ooooo0ol0000Booooo`_o00001Oooool4o`0000Gooooo0_l000000ooooooo0000o`000004
o`0000;ooooo0_l0002:ooooo`007_ooool00ol0003oooooooooo`23ooooo`Co00002_ooool2o`00
00Gooooo2Ol00003ooooo`;o00000oooool3o`0000Cooooo0ol00003ooooo`;o00000oooool4o`00
08Sooooo000Nooooo`03o`000?oooooooooo08Gooooo0_l00004ooooo`;o00001?ooool2o`0000Go
oooo0_l000000ooooooo0000o`00000:o`0000;ooooo0ol000000ooooooo0000o`000004o`0000[o
oooo0ol00027ooooo`007_ooool00ol0003oooooooooo`28ooooo`;o000000?oooooo`000?l00000
1Oooool2o`0000Kooooo0_l000000ooooooo0000o`000008o`000003ooooool0003o000000Ko0000
1Oooool2o`0000;ooooo0_l00003ooooo`;o0000Qoooool001kooooo00?o0000ooooooooool0R?oo
ool2o`000004ooooool0003o0000o`0000Cooooo0_l00004ooooo`Co00001?ooool5o`0000;ooooo
1ol00007ooooo`;o00000_ooool2o`0008cooooo000Nooooo`03o`000?oooooooooo08;ooooo0_l0
0004ooooo`;o000000Coooooo`000?l0003o00002_ooool2o`0000_ooooo1?l0002Nooooo`007_oo
ool00ol0003oooooooooo`22ooooo`?o00001_ooool4o`0001Kooooo0_l0000;ooooo`;o0000Tooo
ool001kooooo00?o0000ooooooooool0Poooool2o`0000Kooooo1?l0000:ooooo`;o00003?ooool2
o`0000Wooooo0_l0002Cooooo`007_ooool00ol0003oooooooooo`2:ooooo`;o00003Oooool2o`00
0003ooooool0003o000000Oooooo1?l00002ooooo`;o00001Oooool2o`0009?ooooo000Nooooo`03
o`000?oooooooooo08[ooooo0_l0000@ooooo`;o00001Oooool4o`0000Cooooo0_l00008ooooo`;o
0000T?ooool001kooooo00?o0000ooooooooool0Woooool2o`0000;ooooo0_l0000;ooooo`;o0000
0oooool2o`00093ooooo000Nooooo`03o`000?oooooooooo09oooooo0_l0000?ooooo`;o0000UOoo
ool001kooooo00?o0000ooooooooool0R_ooool2o`0002Cooooo0_l0002Eooooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_oo
ool00ol0003oooooooooo`2:ooooo`;o00002Oooool2o`0001Cooooo0_l000000ooooooo0000o`00
0002o`0009Gooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
EEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo09Gooooo0_l0000Dooooo`Go0000
Uoooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
00001_ooool3o`0008gooooo0_l0000Nooooo`;o0000V?ooool000?ooooo00Go0000oooooooooooo
ooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2=oooo
o`;o0000^?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000
oa0@4?o<c<`01_ooool00ol0003oooooooooo`2?ooooo`Co00007?ooool2o`0009Kooooo0003oooo
o`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooo
oooo08oooooo1?l0000;ooooo`;o00003oooool2o`0009Kooooo0003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo093ooooo0_l0000<
ooooo`;o0000Yoooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co
0000oa0@40Kooooo00?o0000ooooooooool0SOooool2o`0000Wooooo0_l0000;ooooo`;o0000X?oo
ool001kooooo00?o0000ooooooooool0SOooool2o`0000Wooooo0_l0000;ooooo`;o0000X?ooool0
01kooooo00?o0000ooooooooool0S?ooool2o`0000?ooooo0_l00005ooooo`;o0000[Oooool001ko
oooo00?o0000ooooooooool0S?ooool2o`0000?ooooo0_l00005ooooo`;o0000[Oooool001kooooo
00?o0000ooooooooool0Soooool2o`0001Cooooo0_l0002Pooooo`007_ooool00ol0003ooooooooo
o`2?ooooo`;o00000oooool2o`0000oooooo0_l0002Pooooo`007_ooool00ol0003oooooooooo`2@
ooooo`;o00000_ooool2o`000;7ooooo000Nooooo`03o`000?oooooooooo093ooooo0_l0002eoooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<
c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_oo
ool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41002ooo
ool01Ol0003ooooooooooooooooo000000Kooooo0ol0003oooooodSooooo0003ooooo`05o`000?oo
ooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000oooooooo
ool0oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0
003o0000olc<c006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`3o
ooooodSooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj
^[[o000000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01Cooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB?ooool001Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodSooooo000Fooooo`03o`00
0?oooooooooo00Gooooo0ol0003oooooodSooooo000Fooooo`03o`000?oooooooooo0?ooooooD?oo
ool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooo
oe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Cooooo00?oEEEEofIVI_l00000
oooooomBooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.49953 .47106 Mdot
.48012 .47728 Mdot
.46225 .53315 Mdot
.49356 .47649 Mdot
.51241 .47798 Mdot
.48226 .43691 Mdot
.5171 .58788 Mdot
.52012 .46776 Mdot
.57025 .47537 Mdot
.54909 .5003 Mdot
.54312 .46717 Mdot
.47807 .51142 Mdot
.46542 .43888 Mdot
.43661 .50621 Mdot
.58452 .53546 Mdot
.53796 .5138 Mdot
.48394 .46517 Mdot
.55607 .44284 Mdot
.5554 .48728 Mdot
.47159 .54388 Mdot
.48843 .46118 Mdot
.5167 .54669 Mdot
.53036 .47223 Mdot
.44812 .47256 Mdot
.51262 .46547 Mdot
.49252 .51943 Mdot
.55125 .53745 Mdot
.56081 .46724 Mdot
.50391 .48343 Mdot
.46647 .45384 Mdot
.44899 .48988 Mdot
.48879 .47051 Mdot
.50872 .51116 Mdot
.4647 .54747 Mdot
.46361 .44542 Mdot
.45227 .52991 Mdot
.50377 .52112 Mdot
.53518 .52375 Mdot
.52223 .4749 Mdot
.47774 .51989 Mdot
.53291 .51105 Mdot
.47785 .55212 Mdot
.45223 .48975 Mdot
.49338 .50375 Mdot
.49134 .4678 Mdot
.51568 .52472 Mdot
.43324 .53408 Mdot
.44989 .49111 Mdot
.44554 .50864 Mdot
.57131 .41129 Mdot
.51666 .47876 Mdot
.43828 .43138 Mdot
.50083 .48387 Mdot
.52213 .47259 Mdot
.54423 .51269 Mdot
.49767 .53093 Mdot
.4632 .50417 Mdot
.40747 .43709 Mdot
.49965 .47127 Mdot
.46026 .50551 Mdot
.51185 .53343 Mdot
.5137 .52156 Mdot
.46548 .54791 Mdot
.53755 .51259 Mdot
.51378 .48464 Mdot
.58079 .44904 Mdot
.45285 .47282 Mdot
.50739 .52916 Mdot
.47896 .54033 Mdot
.53906 .5155 Mdot
.53778 .56854 Mdot
.50542 .47511 Mdot
.46456 .51509 Mdot
.4901 .48675 Mdot
.45672 .4617 Mdot
.5318 .56159 Mdot
.49178 .54165 Mdot
.55243 .43392 Mdot
.52719 .57069 Mdot
.54927 .45222 Mdot
.51355 .54091 Mdot
.52199 .46872 Mdot
.5003 .46082 Mdot
.52662 .51556 Mdot
.4648 .54834 Mdot
.49452 .48587 Mdot
.48994 .56326 Mdot
.50757 .52594 Mdot
.47339 .51894 Mdot
.51014 .41322 Mdot
.50574 .48802 Mdot
.52158 .52477 Mdot
.51195 .55957 Mdot
.57927 .42447 Mdot
.49248 .56007 Mdot
.50939 .54554 Mdot
.50372 .52842 Mdot
.44941 .48479 Mdot
.4348 .53883 Mdot
.46342 .4959 Mdot
.49713 .56542 Mdot
.49888 .56262 Mdot
.51039 .47146 Mdot
.55732 .43264 Mdot
.57348 .48755 Mdot
.51158 .51408 Mdot
.43688 .61801 Mdot
.51112 .48552 Mdot
.45488 .47468 Mdot
.52259 .525 Mdot
.46496 .47135 Mdot
.50398 .475 Mdot
.47816 .48943 Mdot
.55163 .49425 Mdot
.46037 .46561 Mdot
.45944 .42643 Mdot
.54796 .52299 Mdot
.56509 .47255 Mdot
.45702 .51557 Mdot
.51782 .5565 Mdot
.54133 .42894 Mdot
.49052 .51589 Mdot
.54851 .50458 Mdot
.44631 .49815 Mdot
.47878 .46979 Mdot
.54263 .50221 Mdot
.45901 .47021 Mdot
.49226 .51729 Mdot
.49413 .51044 Mdot
.54003 .50699 Mdot
.55134 .43969 Mdot
.47788 .46314 Mdot
.40598 .4748 Mdot
.45481 .529 Mdot
.53985 .47454 Mdot
.40532 .48643 Mdot
.54171 .51381 Mdot
.49973 .49497 Mdot
.47026 .52725 Mdot
.48253 .49556 Mdot
.50874 .48628 Mdot
.5659 .49778 Mdot
.50049 .51332 Mdot
.49798 .47787 Mdot
.51196 .50373 Mdot
.52234 .52683 Mdot
.49204 .4677 Mdot
.50144 .55243 Mdot
.45898 .46597 Mdot
.44546 .50337 Mdot
.46025 .53901 Mdot
.56264 .46499 Mdot
.50901 .48238 Mdot
.44383 .48468 Mdot
.5485 .44655 Mdot
.53833 .51413 Mdot
.51689 .51915 Mdot
.42828 .45937 Mdot
.49085 .54167 Mdot
.50852 .49598 Mdot
.55997 .55883 Mdot
.48195 .54686 Mdot
.53802 .42455 Mdot
.54934 .51431 Mdot
.46847 .51159 Mdot
.47116 .49693 Mdot
.574 .49784 Mdot
.50542 .53677 Mdot
.49322 .55252 Mdot
.53955 .51252 Mdot
.55324 .46064 Mdot
.44673 .50136 Mdot
.47186 .47926 Mdot
.46881 .51479 Mdot
.568 .56622 Mdot
.50263 .52484 Mdot
.51592 .54694 Mdot
.51024 .49261 Mdot
.4229 .52627 Mdot
.45265 .51933 Mdot
.49411 .47809 Mdot
.51684 .54181 Mdot
.49324 .4919 Mdot
.50139 .48286 Mdot
.46525 .43355 Mdot
.47776 .50655 Mdot
.47097 .55131 Mdot
.512 .53535 Mdot
.57638 .43183 Mdot
.51913 .5599 Mdot
.48699 .50109 Mdot
.52765 .49957 Mdot
.4505 .47397 Mdot
.50973 .48345 Mdot
.53759 .51725 Mdot
.53015 .50907 Mdot
.57512 .40946 Mdot
.50157 .50942 Mdot
.51544 .4853 Mdot
.48669 .47913 Mdot
.46509 .4911 Mdot
.50543 .53309 Mdot
.54564 .43267 Mdot
.49145 .54629 Mdot
.54305 .50918 Mdot
.46806 .48089 Mdot
.48636 .45911 Mdot
.45973 .49727 Mdot
.46156 .54439 Mdot
.51141 .48176 Mdot
.49071 .46676 Mdot
.50213 .5187 Mdot
.47647 .52868 Mdot
.52117 .43007 Mdot
.49001 .51584 Mdot
.43271 .53256 Mdot
.51799 .52675 Mdot
.48915 .54002 Mdot
.56488 .49745 Mdot
.50868 .48896 Mdot
.52509 .48771 Mdot
.4099 .449 Mdot
.52086 .52701 Mdot
.4289 .49444 Mdot
.54414 .47866 Mdot
.53134 .47312 Mdot
.49307 .47281 Mdot
.5514 .5042 Mdot
.46532 .54592 Mdot
.55145 .4622 Mdot
.54871 .52597 Mdot
.50072 .51763 Mdot
.55429 .49809 Mdot
.51504 .51851 Mdot
.49672 .5247 Mdot
.46929 .52663 Mdot
.5456 .50065 Mdot
.52461 .56577 Mdot
.47004 .47046 Mdot
.47768 .5067 Mdot
.55129 .50339 Mdot
.57776 .54009 Mdot
.48013 .46748 Mdot
.54162 .50458 Mdot
.48429 .55979 Mdot
.5435 .51414 Mdot
.53901 .55934 Mdot
.52755 .47107 Mdot
.55299 .51407 Mdot
.55455 .52019 Mdot
.45345 .49166 Mdot
.46838 .42946 Mdot
.56737 .5335 Mdot
.48772 .55906 Mdot
.48151 .4885 Mdot
.4726 .50595 Mdot
.53518 .4745 Mdot
.48654 .533 Mdot
.46667 .54993 Mdot
.56484 .51711 Mdot
.50181 .53901 Mdot
.53055 .50537 Mdot
.50861 .49659 Mdot
.5385 .43462 Mdot
.46675 .5417 Mdot
.46852 .54946 Mdot
.55023 .46642 Mdot
.55727 .44958 Mdot
.52505 .51077 Mdot
.41815 .52187 Mdot
.45267 .47453 Mdot
.47785 .48977 Mdot
.57761 .43327 Mdot
.47967 .49261 Mdot
.46898 .54495 Mdot
.53825 .563 Mdot
.49701 .53603 Mdot
.55247 .48973 Mdot
.47222 .54145 Mdot
.54626 .48677 Mdot
.4735 .53321 Mdot
.49017 .52377 Mdot
.44481 .50557 Mdot
.50481 .50157 Mdot
.54776 .51432 Mdot
.57852 .42085 Mdot
.42918 .53172 Mdot
.53059 .47628 Mdot
.47127 .47261 Mdot
.44755 .48066 Mdot
.47059 .50982 Mdot
.45063 .47331 Mdot
.47057 .42216 Mdot
.45027 .49595 Mdot
.47122 .49649 Mdot
.52141 .47159 Mdot
.55814 .46127 Mdot
.45548 .5245 Mdot
.47893 .55297 Mdot
.49483 .47583 Mdot
.49773 .5029 Mdot
.53247 .47372 Mdot
.57714 .47977 Mdot
.53555 .52197 Mdot
.47371 .51038 Mdot
.49542 .47635 Mdot
.38783 .51373 Mdot
.46062 .47025 Mdot
.51296 .46712 Mdot
.46467 .53758 Mdot
.48998 .48138 Mdot
.50552 .5041 Mdot
.54082 .47233 Mdot
.51772 .47434 Mdot
.48153 .48148 Mdot
.46396 .46228 Mdot
.47909 .52118 Mdot
.50738 .52799 Mdot
.4665 .51776 Mdot
.53305 .52128 Mdot
.44958 .51323 Mdot
.53616 .46962 Mdot
.52886 .46494 Mdot
.50102 .52673 Mdot
.55553 .4687 Mdot
.53039 .51802 Mdot
.48946 .50256 Mdot
.49299 .51121 Mdot
.56155 .47684 Mdot
.49541 .55733 Mdot
.48466 .46504 Mdot
.44787 .4335 Mdot
.47676 .49021 Mdot
.54963 .49756 Mdot
.45805 .54123 Mdot
.53446 .48803 Mdot
.45914 .53605 Mdot
.50026 .47567 Mdot
.53164 .47844 Mdot
.5114 .52272 Mdot
.45025 .47397 Mdot
.46766 .46387 Mdot
.46007 .59699 Mdot
.50267 .51262 Mdot
.51187 .54094 Mdot
.46157 .46703 Mdot
.50404 .5004 Mdot
.51876 .46996 Mdot
.50493 .53771 Mdot
.52678 .51565 Mdot
.46671 .50579 Mdot
.40865 .46802 Mdot
.48854 .4646 Mdot
.51013 .52033 Mdot
.49444 .42229 Mdot
.46938 .50123 Mdot
.43815 .50222 Mdot
.47021 .46684 Mdot
.4816 .4156 Mdot
.5127 .51339 Mdot
.51514 .48376 Mdot
.46266 .46441 Mdot
.47352 .49435 Mdot
.44399 .49107 Mdot
.46688 .46714 Mdot
.44716 .50924 Mdot
.46709 .54987 Mdot
.50719 .53633 Mdot
.41284 .54374 Mdot
.49528 .487 Mdot
.50846 .49519 Mdot
.50211 .49307 Mdot
.41238 .45842 Mdot
.55236 .47267 Mdot
.4578 .52182 Mdot
.54593 .50579 Mdot
.55268 .46668 Mdot
.50618 .56671 Mdot
.47602 .55094 Mdot
.49966 .52018 Mdot
.45941 .53363 Mdot
.50541 .56837 Mdot
.50379 .47766 Mdot
.42966 .47953 Mdot
.49468 .47226 Mdot
.4934 .44172 Mdot
.56167 .46643 Mdot
.53295 .4841 Mdot
.49538 .52871 Mdot
.45842 .53075 Mdot
.3935 .49475 Mdot
.47561 .54622 Mdot
.45194 .51654 Mdot
.48959 .47026 Mdot
.52665 .47528 Mdot
.51252 .46637 Mdot
.54206 .52357 Mdot
.5074 .50761 Mdot
.55619 .46887 Mdot
.39749 .4994 Mdot
.39866 .51213 Mdot
.45662 .52986 Mdot
.37867 .49172 Mdot
.48867 .52321 Mdot
.45394 .51765 Mdot
.45044 .52469 Mdot
.50103 .48142 Mdot
.50801 .49163 Mdot
.46104 .49117 Mdot
.54864 .45735 Mdot
.482 .49948 Mdot
.55248 .48187 Mdot
.49168 .48747 Mdot
.44945 .49258 Mdot
.49552 .48927 Mdot
.5016 .56332 Mdot
.5267 .5238 Mdot
.44913 .47476 Mdot
.45228 .50248 Mdot
.54949 .50622 Mdot
.54497 .47912 Mdot
.51353 .52633 Mdot
.49245 .49241 Mdot
.55146 .4912 Mdot
.38891 .45847 Mdot
.45587 .53322 Mdot
.58249 .51474 Mdot
.52778 .51142 Mdot
.47135 .53342 Mdot
.47878 .52815 Mdot
.45535 .47432 Mdot
.5387 .51581 Mdot
.48482 .45964 Mdot
.54501 .47416 Mdot
.49387 .54815 Mdot
.44532 .47497 Mdot
.49459 .55103 Mdot
.46306 .50544 Mdot
.45599 .47447 Mdot
.46817 .5131 Mdot
.44857 .49502 Mdot
.48856 .40809 Mdot
.44781 .47779 Mdot
.53964 .43771 Mdot
.51254 .51396 Mdot
.55211 .44522 Mdot
.50878 .4775 Mdot
.54212 .50869 Mdot
.46189 .54457 Mdot
.50536 .48628 Mdot
.44825 .52758 Mdot
.47832 .50257 Mdot
.53088 .51341 Mdot
.47038 .51776 Mdot
.48268 .56335 Mdot
.56312 .48142 Mdot
.46009 .538 Mdot
.52904 .52666 Mdot
.50563 .49408 Mdot
.48271 .53079 Mdot
.48607 .55011 Mdot
.48728 .48497 Mdot
.45012 .49704 Mdot
.51474 .51784 Mdot
.45005 .51009 Mdot
.41725 .504 Mdot
.5227 .51478 Mdot
.48993 .49407 Mdot
.44861 .47589 Mdot
.48468 .5353 Mdot
.51741 .47092 Mdot
.53998 .49103 Mdot
.49883 .61703 Mdot
.60381 .54178 Mdot
.55462 .47383 Mdot
.56688 .47998 Mdot
.4474 .50571 Mdot
.6074 .54067 Mdot
.49958 .5658 Mdot
.40873 .48206 Mdot
.50496 .50613 Mdot
.48916 .46481 Mdot
.52521 .47038 Mdot
.50326 .46864 Mdot
.51275 .52759 Mdot
.4861 .54991 Mdot
.55032 .49427 Mdot
.4954 .47012 Mdot
.44749 .50623 Mdot
.50821 .56708 Mdot
.46141 .41472 Mdot
.46452 .54639 Mdot
.5719 .45646 Mdot
.51329 .48772 Mdot
.45615 .49493 Mdot
.48826 .42267 Mdot
.55679 .50591 Mdot
.513 .49072 Mdot
.48075 .55192 Mdot
.52803 .47337 Mdot
.43973 .60285 Mdot
.57201 .52769 Mdot
.49716 .60099 Mdot
.53103 .49241 Mdot
.47692 .5052 Mdot
.55908 .49955 Mdot
.49017 .46832 Mdot
.54605 .49823 Mdot
.50337 .56267 Mdot
.57575 .41656 Mdot
.47558 .54576 Mdot
.46247 .54483 Mdot
.45408 .48939 Mdot
.4886 .42941 Mdot
.53149 .47425 Mdot
.53626 .51672 Mdot
.45424 .49106 Mdot
.46609 .4442 Mdot
.44615 .52274 Mdot
.5219 .4762 Mdot
.55434 .51273 Mdot
.45307 .47284 Mdot
.52251 .47377 Mdot
.49544 .52134 Mdot
.47174 .50177 Mdot
.50241 .52901 Mdot
.45265 .52292 Mdot
.44296 .42732 Mdot
.55145 .44959 Mdot
.55284 .47586 Mdot
.47858 .55903 Mdot
.52253 .52693 Mdot
.49627 .53523 Mdot
.48626 .48548 Mdot
.57446 .43641 Mdot
.48202 .51031 Mdot
.43078 .47425 Mdot
.50922 .52907 Mdot
.46043 .5006 Mdot
.55697 .49206 Mdot
.48033 .4895 Mdot
.5382 .42177 Mdot
.5271 .52499 Mdot
.43614 .47561 Mdot
.55268 .44419 Mdot
.55265 .5471 Mdot
.50159 .47852 Mdot
.53317 .41831 Mdot
.50756 .47426 Mdot
.54362 .46664 Mdot
.47365 .51785 Mdot
.53192 .47163 Mdot
.51003 .50691 Mdot
.43186 .59566 Mdot
.49911 .4741 Mdot
.5234 .49263 Mdot
.50586 .49079 Mdot
.45544 .51512 Mdot
.46751 .4155 Mdot
.53819 .54103 Mdot
.49908 .5602 Mdot
.47214 .5542 Mdot
.544 .50719 Mdot
.49857 .48631 Mdot
.47393 .55182 Mdot
.53592 .4744 Mdot
.52411 .59822 Mdot
.5436 .48511 Mdot
.43096 .47763 Mdot
.44611 .5046 Mdot
.41826 .52058 Mdot
.49653 .51825 Mdot
.45276 .50892 Mdot
.51282 .47189 Mdot
.47924 .50416 Mdot
.53334 .51436 Mdot
.52597 .41569 Mdot
.47471 .51854 Mdot
.51898 .56664 Mdot
.4838 .51616 Mdot
.4745 .55126 Mdot
.50619 .47579 Mdot
.46002 .60573 Mdot
.46265 .48874 Mdot
.48398 .54539 Mdot
.43102 .54636 Mdot
.53646 .47311 Mdot
.45822 .47028 Mdot
.47076 .45952 Mdot
.46939 .55166 Mdot
.47599 .50689 Mdot
.52032 .5203 Mdot
.51646 .48515 Mdot
.48724 .50627 Mdot
.54197 .50714 Mdot
.48399 .46569 Mdot
.44075 .47706 Mdot
.52101 .54411 Mdot
.53923 .42518 Mdot
.47617 .47965 Mdot
.49882 .54137 Mdot
.54215 .52852 Mdot
.51307 .47399 Mdot
.50728 .42429 Mdot
.52128 .52017 Mdot
.45352 .47742 Mdot
.53783 .49921 Mdot
.45887 .53204 Mdot
.51309 .52148 Mdot
.49108 .51077 Mdot
.56652 .46802 Mdot
.47848 .47068 Mdot
.53722 .47205 Mdot
.43222 .54139 Mdot
.49149 .46952 Mdot
.50796 .48107 Mdot
.52097 .47681 Mdot
.54684 .5112 Mdot
.51331 .48511 Mdot
.57347 .55763 Mdot
.51871 .58556 Mdot
.43218 .43115 Mdot
.48151 .48608 Mdot
.51627 .51945 Mdot
.47465 .55879 Mdot
.46046 .53386 Mdot
.50744 .48422 Mdot
.50422 .49317 Mdot
.40634 .48723 Mdot
.47154 .47398 Mdot
.51038 .53152 Mdot
.54083 .51203 Mdot
.44522 .50313 Mdot
.54218 .4218 Mdot
.53602 .42015 Mdot
.53624 .4772 Mdot
.52307 .56357 Mdot
.48758 .49568 Mdot
.50519 .47188 Mdot
.42925 .53089 Mdot
.52486 .46971 Mdot
.49394 .53983 Mdot
.46025 .54272 Mdot
.52554 .51232 Mdot
.54128 .50512 Mdot
.51697 .42619 Mdot
.49932 .42359 Mdot
.51573 .51539 Mdot
.50769 .57889 Mdot
.52259 .57742 Mdot
.52563 .47531 Mdot
.50976 .50451 Mdot
.50574 .51618 Mdot
.45507 .47479 Mdot
.47157 .49051 Mdot
.45243 .4931 Mdot
.58734 .45776 Mdot
.48762 .49828 Mdot
.47385 .55549 Mdot
.48664 .50795 Mdot
.5074 .47376 Mdot
.51306 .50858 Mdot
.44287 .49228 Mdot
.39795 .44181 Mdot
.43982 .5864 Mdot
.46072 .54035 Mdot
.51753 .53052 Mdot
.38084 .5052 Mdot
.47414 .47 Mdot
.60306 .4969 Mdot
.4752 .47519 Mdot
.39663 .4565 Mdot
.39544 .51267 Mdot
.54164 .5332 Mdot
.53833 .50271 Mdot
.55904 .50965 Mdot
.4655 .52298 Mdot
.49266 .46841 Mdot
.56097 .46052 Mdot
.5231 .47099 Mdot
.51645 .53584 Mdot
.50047 .55931 Mdot
.46143 .47587 Mdot
.51434 .55281 Mdot
.48599 .46695 Mdot
.5044 .53559 Mdot
.47811 .47095 Mdot
.47027 .4306 Mdot
.47124 .52163 Mdot
.46878 .53384 Mdot
.49823 .54762 Mdot
.45321 .52907 Mdot
.42919 .4351 Mdot
.49626 .52634 Mdot
.45557 .52173 Mdot
.4987 .46513 Mdot
.43677 .61126 Mdot
.49754 .50589 Mdot
.52463 .52329 Mdot
.49671 .47572 Mdot
.53816 .47288 Mdot
.48225 .51162 Mdot
.44498 .49777 Mdot
.5138 .48445 Mdot
.46238 .53109 Mdot
.53722 .57868 Mdot
.50409 .52685 Mdot
.51429 .47954 Mdot
.47211 .55451 Mdot
.55164 .49064 Mdot
.56564 .45892 Mdot
.48961 .50901 Mdot
.47993 .55978 Mdot
.56461 .4934 Mdot
.44818 .48124 Mdot
.55 .53945 Mdot
.5619 .50001 Mdot
.4869 .46063 Mdot
.48513 .44186 Mdot
.55941 .45764 Mdot
.49451 .48387 Mdot
.54929 .46255 Mdot
.46887 .52969 Mdot
.48895 .48401 Mdot
.48294 .47009 Mdot
.46703 .5021 Mdot
.52111 .41492 Mdot
.51889 .42856 Mdot
.43067 .47443 Mdot
.50073 .54488 Mdot
.54703 .44789 Mdot
.52914 .51525 Mdot
.46821 .50419 Mdot
.52138 .51618 Mdot
.45352 .42383 Mdot
.5229 .58232 Mdot
.50009 .52457 Mdot
.51798 .54768 Mdot
.55346 .48561 Mdot
.48972 .53653 Mdot
.51696 .52489 Mdot
.45431 .43883 Mdot
.49344 .52548 Mdot
.53174 .47633 Mdot
.51769 .49763 Mdot
.51737 .47539 Mdot
.51264 .48779 Mdot
.50805 .52479 Mdot
.49543 .51111 Mdot
.507 .46636 Mdot
.45028 .52042 Mdot
.50619 .49656 Mdot
.46485 .50889 Mdot
.51512 .47685 Mdot
.54513 .53121 Mdot
.43588 .48433 Mdot
.56633 .49863 Mdot
.54696 .50553 Mdot
.44932 .48833 Mdot
.54211 .476 Mdot
.47724 .44822 Mdot
.49112 .44084 Mdot
.6138 .53321 Mdot
.47985 .54902 Mdot
.52225 .41414 Mdot
.48505 .48725 Mdot
.42468 .48006 Mdot
.50122 .47909 Mdot
.49154 .50485 Mdot
.45102 .52375 Mdot
.52352 .44102 Mdot
.44987 .48616 Mdot
.46147 .45001 Mdot
.49665 .48798 Mdot
.45379 .53504 Mdot
.5334 .54553 Mdot
.59684 .50973 Mdot
.51805 .47197 Mdot
.48802 .49152 Mdot
.48042 .53445 Mdot
.53287 .49872 Mdot
.45959 .46811 Mdot
.46962 .44652 Mdot
.47149 .41012 Mdot
.39201 .46034 Mdot
.53959 .56334 Mdot
.47158 .48684 Mdot
.53591 .5089 Mdot
.55681 .46544 Mdot
.48369 .55291 Mdot
.48352 .48086 Mdot
.54598 .43477 Mdot
.493 .48091 Mdot
.53042 .52764 Mdot
.45616 .47494 Mdot
.51961 .53245 Mdot
.45231 .47769 Mdot
.42905 .60175 Mdot
.54302 .50694 Mdot
.45126 .56863 Mdot
.53114 .50649 Mdot
.46122 .4994 Mdot
.50141 .56269 Mdot
.61153 .50029 Mdot
.50141 .47155 Mdot
.5399 .50892 Mdot
.46852 .50945 Mdot
.52716 .4729 Mdot
.49319 .4643 Mdot
.56373 .4459 Mdot
.50076 .47868 Mdot
.55186 .54676 Mdot
.49566 .48063 Mdot
.51156 .46144 Mdot
.54385 .50716 Mdot
.45225 .49173 Mdot
.50786 .54041 Mdot
.46454 .50156 Mdot
.50531 .4693 Mdot
.44661 .4963 Mdot
.52098 .51491 Mdot
.48183 .48706 Mdot
.54338 .5627 Mdot
.55286 .48829 Mdot
.50497 .47109 Mdot
.56518 .48603 Mdot
.51437 .4845 Mdot
.46821 .47226 Mdot
.45726 .47507 Mdot
.49344 .526 Mdot
.43564 .58205 Mdot
.44948 .474 Mdot
.45895 .52291 Mdot
.51161 .52622 Mdot
.50097 .51679 Mdot
.53793 .50269 Mdot
.47607 .55278 Mdot
.54981 .45073 Mdot
.48288 .48439 Mdot
.5429 .51702 Mdot
.49444 .47042 Mdot
.51778 .52486 Mdot
.51264 .54218 Mdot
.55974 .5649 Mdot
.5277 .57302 Mdot
.4832 .56203 Mdot
.60297 .49388 Mdot
.47467 .55346 Mdot
.51576 .52732 Mdot
.4654 .51695 Mdot
.47498 .47001 Mdot
.51838 .42246 Mdot
.43328 .52708 Mdot
.39317 .51197 Mdot
.57171 .56898 Mdot
.47836 .50223 Mdot
.52 .51209 Mdot
.49528 .42774 Mdot
.49084 .49292 Mdot
.51064 .48437 Mdot
.47851 .55953 Mdot
.47783 .50221 Mdot
.50636 .50366 Mdot
.51796 .55075 Mdot
.55786 .45717 Mdot
.47077 .5531 Mdot
.46986 .48278 Mdot
.56459 .45379 Mdot
.48054 .47942 Mdot
.42016 .42627 Mdot
.54983 .44088 Mdot
.5432 .5158 Mdot
.45062 .502 Mdot
.48311 .46512 Mdot
.49165 .46481 Mdot
.4956 .48762 Mdot
.52487 .47241 Mdot
.52184 .52274 Mdot
.47326 .51715 Mdot
.444 .42743 Mdot
.44105 .58176 Mdot
.41218 .45975 Mdot
.45709 .46811 Mdot
.50172 .48648 Mdot
.51036 .40915 Mdot
.49902 .46988 Mdot
.47297 .52336 Mdot
.53467 .51383 Mdot
.51358 .56589 Mdot
.41777 .46007 Mdot
.49513 .54874 Mdot
.5058 .51488 Mdot
.49239 .56088 Mdot
.54363 .47076 Mdot
.51275 .49266 Mdot
.57166 .43499 Mdot
.50709 .48006 Mdot
.45577 .47712 Mdot
.47755 .49224 Mdot
.47546 .48915 Mdot
.53639 .44626 Mdot
.46504 .49133 Mdot
.47489 .46083 Mdot
.47992 .48083 Mdot
.55367 .48013 Mdot
.49544 .48356 Mdot
.50995 .56603 Mdot
.46858 .52314 Mdot
.52223 .4714 Mdot
.45586 .46836 Mdot
.47485 .55715 Mdot
.49445 .54253 Mdot
.47599 .49865 Mdot
.52307 .47528 Mdot
.48287 .47137 Mdot
.48056 .5152 Mdot
.48864 .56359 Mdot
.47599 .58749 Mdot
.46465 .4707 Mdot
.53862 .53143 Mdot
.52146 .51855 Mdot
.49551 .50678 Mdot
.43766 .50357 Mdot
.4856 .561 Mdot
.56805 .52666 Mdot
.49007 .48325 Mdot
.52018 .47238 Mdot
.4743 .51178 Mdot
.59479 .47538 Mdot
.49857 .48266 Mdot
.46998 .48836 Mdot
.4791 .55226 Mdot
.57602 .46814 Mdot
.47223 .4695 Mdot
.49119 .49533 Mdot
.57432 .40803 Mdot
.51483 .52054 Mdot
.43326 .57421 Mdot
.55387 .52942 Mdot
.54721 .55957 Mdot
.43519 .45063 Mdot
.51459 .46672 Mdot
.44748 .50934 Mdot
.4919 .48288 Mdot
.50318 .53764 Mdot
.48373 .46886 Mdot
.44746 .47941 Mdot
.44835 .48863 Mdot
.45267 .50582 Mdot
.43314 .47844 Mdot
.56235 .46994 Mdot
.48103 .49413 Mdot
.53952 .42514 Mdot
.46638 .47181 Mdot
.49187 .47909 Mdot
.55896 .45189 Mdot
.49925 .56465 Mdot
.53134 .52098 Mdot
.42812 .56331 Mdot
.57966 .55696 Mdot
.49357 .54916 Mdot
.49517 .49035 Mdot
.5232 .54543 Mdot
.50368 .51777 Mdot
.52017 .51484 Mdot
.44916 .49365 Mdot
.46934 .54858 Mdot
.4666 .48931 Mdot
.53047 .51496 Mdot
.52825 .54426 Mdot
.47102 .55087 Mdot
.47295 .46985 Mdot
.45028 .4285 Mdot
.50924 .53547 Mdot
.41151 .54165 Mdot
.53763 .51705 Mdot
.44676 .61543 Mdot
.49429 .4918 Mdot
.48878 .52171 Mdot
.55424 .43907 Mdot
.49881 .40992 Mdot
.50778 .49094 Mdot
.50831 .46901 Mdot
.53749 .47608 Mdot
.44771 .47635 Mdot
.45686 .5142 Mdot
.48679 .46897 Mdot
.47747 .48632 Mdot
.53349 .5222 Mdot
.53439 .48253 Mdot
.49999 .47114 Mdot
.52104 .47734 Mdot
.4653 .46771 Mdot
.54673 .4889 Mdot
.54598 .50292 Mdot
.50519 .53559 Mdot
.52979 .55563 Mdot
.48412 .55389 Mdot
.55133 .56884 Mdot
.52994 .41714 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go
00001_ooool3o`000?ooooooB?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04
odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol0003o
oooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`3o
ooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007
ooooo`03o`000?oooooooooo09Gooooo0_l00004ooooo`;o000000?oooooo`000?l000000_ooool2
o`0001?ooooo0_l0002>ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000001oooool00ol0003oooooooooo`2Eooooo`;o00001?ooool2o`000003ooooool0003o
000000;ooooo0_l0000Booooo`?o0000S_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=
ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0T_ooool4o`0000;ooooo0_l00008
ooooo`;o000000?oooooo`000?l000000_l0000=ooooo`?o0000S_ooool001kooooo00?o0000oooo
ooooool0T_ooool4o`0000;ooooo0_l0000;ooooo`Ko00003?ooool2o`0008kooooo000Nooooo`03
o`000?oooooooooo09Gooooo0_l00004ooooo`Co00001Oooool2o`0000;ooooo1_l0000:ooooo`;o
0000SOooool001kooooo00?o0000ooooooooool0Soooool2o`0000Cooooo0_l00004ooooo`Go0000
00Coooooo`000?l0003ooooo0_l00004ooooo`Co00002_ooool2o`0008gooooo000Nooooo`03o`00
0?oooooooooo08Cooooo0_l00006ooooo`Oo00002_ooool3o`000004ooooool0003o0000ooooo`?o
00001?ooool3o`0000[ooooo0_l0002=ooooo`007_ooool00ol0003oooooooooo`24ooooo`;o0000
0_ooool8o`000004ooooool0003o0000ooooo`?o00001?ooool4o`0000Gooooo0ol00005ooooo`;o
00002Oooool2o`0008kooooo000Nooooo`03o`000?oooooooooo08Oooooo1Ol000000ooooooo0000
o`000004ooooo`Co00001?ooool2o`0000Sooooo0_l00004ooooo`So00000oooool4o`0008gooooo
000Nooooo`03o`000?oooooooooo083ooooo0_l00005ooooo`;o00001?ooool2o`0000Cooooo0_l0
0004ooooo`;o00004?ooool8o`0000?ooooo1?l0002=ooooo`007_ooool00ol0003oooooooooo`20
ooooo`;o00003_ooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000008
ooooo`;o00000oooool2o`0000;ooooo0ol00005ooooo`;o0000S_ooool001kooooo00?o0000oooo
ooooool0OOooool2o`00017ooooo0_l000000ooooooo0000o`000005ooooo`Co00002?ooool2o`00
00Oooooo1?l0002Dooooo`007_ooool00ol0003oooooooooo`1mooooo`;o00005?ooool4o`0000?o
oooo1?l0000<ooooo`;o00000_ooool7o`0009;ooooo000Nooooo`03o`000?oooooooooo087ooooo
0_l0000?ooooo`Oo00004Oooool2o`0000;ooooo1ol00004ooooo`;o0000S?ooool001kooooo0_l0
0022ooooo`;o00001_ooool2o`0000Oooooo0_l00003ooooo`;o00005Oooool6o`0000Gooooo0_l0
002<ooooo`007_ooool00ol0003oooooooooo`1mooooo`;o00002_ooool2o`0000Wooooo0_l0000H
ooooo`?o000000Goooooo`000?l0003o0000ooooo`02o`0008oooooo000Nooooo`03o`000?oooooo
oooo07[ooooo0_l000000ooooooo0000o`000003ooooo`;o00000oooool2o`0000_ooooo0ol00003
ooooo`;o00004_ooool2o`000003ooooool0003o000000Go00000oooool2o`0008[ooooo000Noooo
o`03o`000?oooooooooo07[ooooo0ol00005ooooo`Co000000?oooooo`000?l000001oooool2o`00
0003ooooool0003o000000?o00000_ooool3o`0000;ooooo0_l000000ooooooo0000o`00000:oooo
o`So00001Oooool2o`0008[ooooo000Nooooo`03o`000?oooooooooo07_ooooo0_l00005ooooo`Co
00002_oooolAo`000004ooooool0003o0000o`0000?ooooo0_l00004ooooo`Oo0000T_ooool001ko
oooo00?o0000ooooooooool0POooool2o`0000gooooo6_l00002ooooo`[o000000?oooooo`000?l0
0000S_ooool001kooooo00?o0000ooooooooool0POooool2o`0000gooooo9_l000000ooooooo0000
o`00002>ooooo`007_ooool00ol0003oooooooooo`20ooooo`;o00001_ooool2o`0000?ooooo9Ol0
00001?oooooo0000o`000?l0002Aooooo`007_ooool00ol0003oooooooooo`20ooooo`;o00001_oo
oolBo`0000;ooooo6ol00006ooooo`;o0000R?ooool001kooooo00?o0000ooooooooool0Q_oooolY
o`000003ooooool0003o000000Go000000?oooooo`000?l000000oooool2o`0008Sooooo000Noooo
o`03o`000?oooooooooo087ooooo0_l00003ooooo`Ko000000Coooooo`000?l0003o00001?oooolB
o`0000?ooooo0ol000001?oooooo0000o`000?ooool2o`000004ooooool0003o0000o`0000;ooooo
0_l0002=ooooo`007_ooool00ol0003oooooooooo`20ooooo`?o00001oooool6o`0000Gooooo4Ol0
0003ooooo`?o000000Coooooo`000?l0003ooooo0_l000001?oooooo0000o`000?l0002Aooooo`00
7_ooool00ol0003oooooooooo`20ooooo`;o00002_oooolJo`000004ooooool0003o0000ooooo`;o
000000?oooooo`000?l000000ol00002ooooo`Co0000Soooool001kooooo00?o0000ooooooooool0
Moooool2o`0001?ooooo3_l000000ooooooo0000o`000008o`000003ooooool0003o000000Go0000
00?oooooo`000?l000001Ol000000ooooooo0000o`00002?ooooo`007_ooool00ol0003ooooooooo
o`1gooooo`;o00000oooool2o`0000Wooooo0_l00003oooooaWo000000Coooooo`000?l0003ooooo
1?l00002ooooo`Ko00002oooool2o`0008Gooooo000Nooooo`03o`000?oooooooooo07cooooo0ol0
0008ooooo`;o00001?oooolFo`000004ooooool0003o0000oooooa7o00002?ooool2o`0008Gooooo
000Nooooo`;o0000O_ooool2o`0000_ooooo0_l000000ooooooo0000o`00000>o`0000?ooooo0_l0
0002ooooo`;o000000?oooooo`000?l000003ol00008ooooo`;o000000?oooooo`000?l00000P_oo
ool001kooooo00?o0000ooooooooool0N?ooool2o`0000[ooooo0_l00004ooooo`Oo000000?ooooo
o`000?l000004?l00004ooooo`;o000000?oooooo`000?l000001?l00002ooooo`;o00003_ooool2
o`0008;ooooo000Nooooo`03o`000?oooooooooo07Sooooo0_l0000:ooooo`;o00001?ooool7o`00
0003ooooool0003o0000017o00000oooool;o`0009Cooooo000Nooooo`03o`000?oooooooooo07co
oooo0_l0000<ooooo`;o000000?oooooo`000?l000000_l00002oooooa;o00000_ooool=o`0000[o
oooo0_l00027ooooo`007_ooool00ol0003oooooooooo`1jooooo`Go00003_ooool5o`000003oooo
ool0003o000001oo00001Oooool2o`0000?ooooo0_l00027ooooo`007_ooool00ol0003ooooooooo
o`1jooooo`Go00003oooool4o`000003ooooool0003o000000Wo000000?oooooo`000?l000004Ol0
0002ooooo`;o00000oooool2o`0008cooooo000Nooooo`03o`000?oooooooooo08Cooooo0_l00008
ooooo`Co000000?oooooo`000?l000006Ol00002ooooo`;o00000_ooool2o`00097ooooo000Noooo
o`03o`000?oooooooooo08Cooooo0_l00007ooooo`go000000?oooooo`000?l000005Ol0002Eoooo
o`007_ooool00ol0003oooooooooo`24ooooo`?o00000_ooool2o`0000;ooooo2ol00003oooooaGo
00001Oooool2o`00093ooooo000Nooooo`03o`000?oooooooooo08Gooooo0_l00002ooooo`;o0000
0oooool4o`0000;ooooo1_l00002ooooo`ko00000_ooool6o`0000?ooooo0ol0002?ooooo`007_oo
ool00ol0003oooooooooo`27ooooo`Co00000oooool>o`000003ooooool0003o000000So000000Co
ooooo`000?l0003ooooo1?l000000ooooooo0000o`000002ooooo`Co00002oooool2o`0008;ooooo
000Nooooo`03o`000?oooooooooo08Oooooo1?l00004oooooaSo00001?ooool4o`0000Gooooo0_l0
0004ooooo`;o00001oooool2o`0008;ooooo000Nooooo`03o`000?oooooooooo08Wooooo0_l00004
ooooo`Oo00000_ooool>o`0000Wooooo0_l00009ooooo`;o0000Roooool001kooooo00?o0000oooo
ooooool0P_ooool2o`0000Cooooo0ol00006ooooo`Ko000000Coooooo`000?l0003ooooo2ol00005
ooooo`;o00000_ooool2o`0000Oooooo0_l00006ooooo`?o0000Q?ooool001kooooo00?o0000oooo
ooooool0P_ooool2o`0000Cooooo0_l00007oooooaco00002oooool2o`0000Kooooo0ol00024oooo
o`007_ooool00ol0003oooooooooo`22ooooo`;o00001?ooool2o`0000Sooooo2Ol000000ooooooo
0000o`000005o`000003ooooool0003o000000Go00001?ooool3o`0009Gooooo000Nooooo`;o0000
ROooool2o`0000Wooooo3Ol00004ooooo`;o00002Oooool3o`0009Gooooo000Nooooo`03o`000?oo
oooooooo09Cooooo3Ol00002ooooo`?o0000XOooool001kooooo00?o0000ooooooooool0UOooool6
o`000003ooooool0003o000000?o00000_ooool3o`0000;ooooo0_l0000<ooooo`Co0000SOooool0
01kooooo00?o0000ooooooooool0U_ooool;o`000003ooooool0003o000000?o000000Coooooo`00
0?l0003ooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool4o`0008gooooo000Noooo
o`03o`000?oooooooooo08Oooooo0_l0000=ooooo`ko000000Goooooo`000?l0003o0000ooooo`07
o`0000;ooooo0_l0002Cooooo`007_ooool00ol0003oooooooooo`27ooooo`;o00004?ooool4o`00
0003ooooool0003o000000So000000?oooooo`000?l000001?l00003ooooo`;o000000?oooooo`00
0?l00000T?ooool001kooooo00?o0000ooooooooool0Soooool2o`0000gooooo2_l00003ooooo`;o
00000_ooool2o`000004ooooool0003o0000ooooo`?o0000Soooool001kooooo00?o0000oooooooo
ool0Soooool2o`0000oooooo0_l00005ooooo`;o00000_ooool2o`0000;ooooo0_l00005ooooo`;o
0000Soooool001kooooo00?o0000ooooooooool0ROooool2o`0001cooooo0_l0002Nooooo`007_oo
ool00ol0003oooooooooo`29ooooo`;o00005_ooool2o`0000?ooooo0_l00003ooooo`;o0000V_oo
ool001kooooo00?o0000ooooooooool0R_ooool3o`0001Cooooo0_l00003ooooo`;o00000oooool2
o`0009[ooooo000Nooooo`03o`000?oooooooooo08[ooooo0ol0000Hooooo`?o0000Woooool001ko
oooo00?o0000ooooooooool0Roooool2o`0000[ooooo0_l0000;ooooo`?o0000X?ooool001kooooo
00?o0000ooooooooool0Roooool2o`0000[ooooo0_l0000;ooooo`;o0000XOooool000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Ko
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`28oooo
o`;o00001oooool2o`000;Cooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0
003ooooooooooooooooo000000Kooooo0ol00028ooooo`;o00001oooool2o`0000_ooooo0_l00006
ooooo`;o0000Woooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9So
oooooiRHV?lQ8B401_ooool00ol0003oooooooooo`27ooooo`;o00000_ooool2o`00017ooooo0_l0
0006ooooo`;o0000Woooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mE
EEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`27ooooo`;o00000_ooool2o`0000Cooooo
0_l0002dooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
2?ooool00ol0003oooooooooo`2Aooooo`;o0000]?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0R_ooool2o`000;_ooooo
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03
o`000?oooooooooo08[ooooo0_l000000ooooooo0000o`00002hooooo`007_ooool00ol0003ooooo
ooooo`2:ooooo`;o000000?oooooo`000?l000003oooool2o`000:Oooooo000Nooooo`03o`000?oo
oooooooo08[ooooo0_l0000Booooo`;o0000Yoooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodSooooo
0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?oooooo
V9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooo
oooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool000?o
oooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool0
0ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`000?ooooooooooooooool000002oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool0
1Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2
o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`005?ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooo
oom8ooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB?ooool0
01Kooooo00?o0000ooooooooool01Oooool3o`000?ooooooB?ooool001Kooooo00?o0000oooooooo
ool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oo
oooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005?ooool00omE
EEGoIVIVo`00003ooooooe;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.53438 .47681 Mdot
.49777 .46966 Mdot
.43844 .50071 Mdot
.50826 .47455 Mdot
.51972 .48929 Mdot
.51559 .4529 Mdot
.48617 .56407 Mdot
.53486 .47674 Mdot
.54981 .50949 Mdot
.54357 .53187 Mdot
.55988 .48749 Mdot
.47598 .49772 Mdot
.50053 .44968 Mdot
.45067 .4687 Mdot
.55225 .55069 Mdot
.52594 .5371 Mdot
.50785 .46218 Mdot
.57827 .47618 Mdot
.55506 .52266 Mdot
.45677 .52197 Mdot
.51242 .46006 Mdot
.50054 .55666 Mdot
.52566 .4884 Mdot
.48868 .4621 Mdot
.534 .47063 Mdot
.48635 .51159 Mdot
.51302 .54948 Mdot
.5673 .50333 Mdot
.50928 .49079 Mdot
.50473 .46161 Mdot
.45457 .4613 Mdot
.50956 .46964 Mdot
.50368 .51771 Mdot
.44085 .52264 Mdot
.49996 .45486 Mdot
.43425 .50107 Mdot
.49569 .51939 Mdot
.49983 .54175 Mdot
.52197 .4908 Mdot
.47272 .50405 Mdot
.52335 .53081 Mdot
.46052 .53821 Mdot
.461 .46793 Mdot
.48984 .49988 Mdot
.51326 .46964 Mdot
.50071 .53391 Mdot
.43755 .49469 Mdot
.45526 .45852 Mdot
.43967 .4805 Mdot
.57927 .44232 Mdot
.51916 .49323 Mdot
.47195 .4346 Mdot
.50654 .48862 Mdot
.52735 .48542 Mdot
.53248 .53819 Mdot
.48506 .52411 Mdot
.46522 .48208 Mdot
.43635 .43241 Mdot
.51785 .47594 Mdot
.46154 .4821 Mdot
.49377 .53807 Mdot
.5011 .52801 Mdot
.44498 .52436 Mdot
.52621 .53598 Mdot
.51249 .50023 Mdot
.57093 .48257 Mdot
.47376 .45257 Mdot
.49142 .53162 Mdot
.46886 .52293 Mdot
.52603 .53831 Mdot
.49741 .56063 Mdot
.51921 .48068 Mdot
.46105 .49119 Mdot
.49509 .48318 Mdot
.49749 .46134 Mdot
.49293 .56113 Mdot
.47806 .53145 Mdot
.57594 .46474 Mdot
.4872 .55602 Mdot
.55737 .48199 Mdot
.47841 .54762 Mdot
.53776 .47718 Mdot
.52235 .4642 Mdot
.51462 .53124 Mdot
.443 .52448 Mdot
.49964 .48516 Mdot
.45472 .54681 Mdot
.49338 .52829 Mdot
.46972 .50085 Mdot
.54201 .43188 Mdot
.50689 .49721 Mdot
.50622 .53807 Mdot
.47572 .55619 Mdot
.57985 .45639 Mdot
.45896 .52914 Mdot
.49254 .54332 Mdot
.48947 .52737 Mdot
.45937 .45619 Mdot
.43658 .49924 Mdot
.46931 .47608 Mdot
.46147 .55237 Mdot
.46472 .55445 Mdot
.52486 .47977 Mdot
.56371 .47239 Mdot
.54731 .51701 Mdot
.50621 .52013 Mdot
.42393 .59426 Mdot
.51151 .49874 Mdot
.47439 .45743 Mdot
.50681 .53883 Mdot
.50465 .46361 Mdot
.51834 .47984 Mdot
.48545 .47791 Mdot
.52788 .52813 Mdot
.48567 .44743 Mdot
.49346 .43605 Mdot
.5102 .54056 Mdot
.5718 .5081 Mdot
.44669 .47665 Mdot
.48072 .55559 Mdot
.56501 .4542 Mdot
.48591 .50814 Mdot
.54147 .53516 Mdot
.44591 .46961 Mdot
.50077 .46424 Mdot
.52244 .53706 Mdot
.50015 .46371 Mdot
.487 .50995 Mdot
.49016 .50577 Mdot
.53151 .53122 Mdot
.56827 .4668 Mdot
.50325 .45614 Mdot
.43744 .46002 Mdot
.44043 .50062 Mdot
.54364 .48425 Mdot
.43405 .46605 Mdot
.53949 .55126 Mdot
.49774 .49709 Mdot
.46285 .5051 Mdot
.48492 .48619 Mdot
.5096 .49799 Mdot
.53627 .52543 Mdot
.4962 .51238 Mdot
.51018 .47902 Mdot
.50605 .51664 Mdot
.50574 .53964 Mdot
.52901 .475 Mdot
.48653 .5487 Mdot
.48424 .44683 Mdot
.44309 .47577 Mdot
.4426 .51326 Mdot
.57003 .50049 Mdot
.51312 .49379 Mdot
.46482 .45234 Mdot
.56623 .47201 Mdot
.52611 .5374 Mdot
.50519 .52752 Mdot
.46463 .453 Mdot
.47738 .5309 Mdot
.50397 .50865 Mdot
.52152 .56283 Mdot
.46908 .53254 Mdot
.56409 .44995 Mdot
.53585 .53747 Mdot
.46684 .49163 Mdot
.47563 .48021 Mdot
.54385 .52393 Mdot
.47558 .54724 Mdot
.47681 .55379 Mdot
.50936 .53895 Mdot
.56331 .49501 Mdot
.44685 .47443 Mdot
.48922 .46839 Mdot
.46591 .49437 Mdot
.5312 .56737 Mdot
.49152 .5228 Mdot
.49951 .54803 Mdot
.50592 .50696 Mdot
.43954 .48993 Mdot
.44397 .4909 Mdot
.50716 .47679 Mdot
.49932 .54285 Mdot
.49456 .48954 Mdot
.50776 .48806 Mdot
.49976 .44436 Mdot
.47739 .49331 Mdot
.4402 .52792 Mdot
.49363 .53836 Mdot
.57516 .46537 Mdot
.48141 .55803 Mdot
.4861 .49337 Mdot
.52326 .52457 Mdot
.48974 .46047 Mdot
.51245 .49561 Mdot
.5053 .54045 Mdot
.52331 .52858 Mdot
.58282 .43926 Mdot
.49697 .51079 Mdot
.5111 .50269 Mdot
.50126 .47378 Mdot
.47435 .47321 Mdot
.48877 .53348 Mdot
.56632 .45984 Mdot
.46785 .54916 Mdot
.5336 .53648 Mdot
.48443 .46842 Mdot
.51136 .45476 Mdot
.46541 .47599 Mdot
.43602 .519 Mdot
.51487 .49461 Mdot
.51311 .46817 Mdot
.49577 .51667 Mdot
.46975 .51088 Mdot
.54891 .45202 Mdot
.48543 .50783 Mdot
.44023 .49286 Mdot
.50224 .53764 Mdot
.47658 .52777 Mdot
.53552 .52545 Mdot
.50732 .50161 Mdot
.51824 .51244 Mdot
.44038 .44228 Mdot
.50459 .53934 Mdot
.45782 .46497 Mdot
.5544 .49099 Mdot
.54327 .48134 Mdot
.51189 .47299 Mdot
.54359 .53472 Mdot
.43688 .52049 Mdot
.55545 .48632 Mdot
.5378 .54666 Mdot
.49513 .51505 Mdot
.52613 .52867 Mdot
.50552 .52467 Mdot
.48788 .51774 Mdot
.46192 .50387 Mdot
.5213 .53344 Mdot
.48539 .56163 Mdot
.49213 .46038 Mdot
.47728 .4934 Mdot
.54401 .53436 Mdot
.54354 .55362 Mdot
.52003 .46937 Mdot
.51841 .53731 Mdot
.4581 .52246 Mdot
.53055 .5383 Mdot
.50004 .56103 Mdot
.53917 .48004 Mdot
.54116 .53796 Mdot
.51758 .53922 Mdot
.46177 .46986 Mdot
.50235 .4414 Mdot
.5317 .54843 Mdot
.45802 .52447 Mdot
.48778 .4793 Mdot
.47342 .48944 Mdot
.52845 .49693 Mdot
.47606 .51905 Mdot
.44344 .52615 Mdot
.52994 .53758 Mdot
.47164 .54683 Mdot
.52554 .52767 Mdot
.50386 .50915 Mdot
.56199 .45886 Mdot
.45172 .51748 Mdot
.44851 .52679 Mdot
.55048 .48786 Mdot
.57286 .4831 Mdot
.51848 .5275 Mdot
.43627 .48747 Mdot
.47107 .45584 Mdot
.48501 .47803 Mdot
.57503 .46658 Mdot
.48401 .48219 Mdot
.43926 .51744 Mdot
.49837 .56218 Mdot
.48291 .5286 Mdot
.55131 .52426 Mdot
.45892 .51972 Mdot
.54629 .51927 Mdot
.4649 .51283 Mdot
.48202 .51343 Mdot
.45148 .46701 Mdot
.49943 .50831 Mdot
.51392 .5373 Mdot
.58124 .4523 Mdot
.44066 .4927 Mdot
.52296 .49778 Mdot
.492 .46292 Mdot
.47079 .44977 Mdot
.47001 .49134 Mdot
.47497 .44915 Mdot
.5041 .4344 Mdot
.45515 .47135 Mdot
.47589 .47985 Mdot
.52937 .48281 Mdot
.56812 .49677 Mdot
.44537 .49634 Mdot
.45844 .54166 Mdot
.50987 .47471 Mdot
.49309 .50263 Mdot
.54412 .48198 Mdot
.55423 .51066 Mdot
.51888 .54007 Mdot
.47277 .49419 Mdot
.50985 .47537 Mdot
.40433 .48777 Mdot
.49435 .45225 Mdot
.53569 .47163 Mdot
.45115 .51221 Mdot
.50061 .47747 Mdot
.50007 .51093 Mdot
.53845 .50094 Mdot
.54453 .48074 Mdot
.49569 .47349 Mdot
.48912 .44327 Mdot
.47339 .5057 Mdot
.49218 .53043 Mdot
.46187 .49462 Mdot
.49964 .54182 Mdot
.44364 .48534 Mdot
.55666 .48926 Mdot
.55247 .48648 Mdot
.48913 .52302 Mdot
.56284 .50412 Mdot
.50369 .54443 Mdot
.48737 .49625 Mdot
.48913 .50562 Mdot
.54586 .51471 Mdot
.46293 .55034 Mdot
.52334 .47164 Mdot
.48288 .43915 Mdot
.48405 .47775 Mdot
.54511 .52976 Mdot
.43451 .51528 Mdot
.53247 .51781 Mdot
.44279 .50964 Mdot
.51472 .47776 Mdot
.55352 .4929 Mdot
.49854 .5276 Mdot
.46987 .45302 Mdot
.49616 .44563 Mdot
.44311 .56649 Mdot
.4982 .51375 Mdot
.49048 .55621 Mdot
.48637 .45067 Mdot
.49888 .50641 Mdot
.53111 .47969 Mdot
.47405 .54692 Mdot
.51469 .53146 Mdot
.46748 .48517 Mdot
.44058 .45557 Mdot
.51213 .46397 Mdot
.50062 .52314 Mdot
.52708 .43852 Mdot
.47196 .48284 Mdot
.45994 .46558 Mdot
.49472 .45633 Mdot
.51535 .42937 Mdot
.50736 .52087 Mdot
.51252 .50056 Mdot
.48823 .44389 Mdot
.47889 .4796 Mdot
.46918 .45717 Mdot
.49145 .4546 Mdot
.45062 .46934 Mdot
.45089 .50726 Mdot
.47882 .54837 Mdot
.4232 .50949 Mdot
.49946 .48672 Mdot
.50416 .50802 Mdot
.50076 .49774 Mdot
.44451 .44929 Mdot
.56114 .48917 Mdot
.4421 .4856 Mdot
.53816 .53526 Mdot
.55823 .48659 Mdot
.46882 .55617 Mdot
.46072 .53369 Mdot
.49295 .51609 Mdot
.44558 .50713 Mdot
.46958 .54249 Mdot
.51494 .48214 Mdot
.46484 .46046 Mdot
.51362 .47381 Mdot
.52508 .461 Mdot
.56848 .50226 Mdot
.52959 .51352 Mdot
.48409 .52036 Mdot
.44601 .5038 Mdot
.41692 .47252 Mdot
.46272 .52723 Mdot
.44478 .48843 Mdot
.51044 .46996 Mdot
.52029 .49397 Mdot
.52954 .4741 Mdot
.52615 .54107 Mdot
.50199 .51523 Mdot
.56338 .50461 Mdot
.4203 .47466 Mdot
.41722 .48427 Mdot
.44293 .50191 Mdot
.39944 .47254 Mdot
.48091 .5122 Mdot
.44742 .4899 Mdot
.43634 .49551 Mdot
.50871 .48599 Mdot
.50523 .50428 Mdot
.47118 .47217 Mdot
.5567 .49013 Mdot
.48305 .48912 Mdot
.55468 .51654 Mdot
.4959 .48472 Mdot
.45349 .46059 Mdot
.49812 .48888 Mdot
.46677 .55541 Mdot
.51072 .53973 Mdot
.486 .45681 Mdot
.4552 .47788 Mdot
.5411 .53618 Mdot
.54691 .51315 Mdot
.49809 .53397 Mdot
.49371 .48937 Mdot
.54934 .52397 Mdot
.41427 .44613 Mdot
.43907 .50549 Mdot
.55109 .53531 Mdot
.51997 .52857 Mdot
.46165 .51133 Mdot
.47151 .51133 Mdot
.48199 .44836 Mdot
.52551 .53837 Mdot
.51091 .45283 Mdot
.54774 .50824 Mdot
.47413 .55255 Mdot
.48387 .46038 Mdot
.47716 .55423 Mdot
.46449 .48308 Mdot
.4855 .45047 Mdot
.46576 .49266 Mdot
.45305 .46983 Mdot
.52199 .42454 Mdot
.47092 .4494 Mdot
.56217 .46224 Mdot
.50705 .52067 Mdot
.56783 .47656 Mdot
.51895 .48525 Mdot
.53264 .53529 Mdot
.43852 .51892 Mdot
.50801 .49514 Mdot
.44694 .48533 Mdot
.47913 .48994 Mdot
.51993 .53177 Mdot
.46691 .49753 Mdot
.45442 .54911 Mdot
.54234 .51677 Mdot
.44318 .51212 Mdot
.49362 .54309 Mdot
.50257 .50357 Mdot
.4738 .51527 Mdot
.46289 .54765 Mdot
.49432 .47976 Mdot
.45214 .46201 Mdot
.50604 .5239 Mdot
.44624 .483 Mdot
.44194 .47409 Mdot
.51353 .52713 Mdot
.49106 .48919 Mdot
.47087 .45206 Mdot
.47434 .52052 Mdot
.54544 .48752 Mdot
.53866 .52126 Mdot
.47604 .59588 Mdot
.57658 .55607 Mdot
.55968 .50963 Mdot
.54499 .5141 Mdot
.4412 .47479 Mdot
.58135 .5554 Mdot
.46336 .55323 Mdot
.44001 .46398 Mdot
.49962 .51196 Mdot
.51259 .4646 Mdot
.53909 .4791 Mdot
.52143 .47514 Mdot
.49666 .53465 Mdot
.46427 .54827 Mdot
.54684 .52626 Mdot
.53152 .47512 Mdot
.44514 .47914 Mdot
.47075 .55751 Mdot
.49451 .42503 Mdot
.43674 .52145 Mdot
.56138 .49269 Mdot
.50925 .50415 Mdot
.46357 .47327 Mdot
.52135 .4381 Mdot
.52485 .53188 Mdot
.50777 .507 Mdot
.46099 .54575 Mdot
.54512 .48053 Mdot
.42702 .57489 Mdot
.53707 .54456 Mdot
.47261 .57453 Mdot
.52779 .52051 Mdot
.47714 .49162 Mdot
.55419 .53082 Mdot
.52327 .465 Mdot
.5413 .5268 Mdot
.46365 .54636 Mdot
.58116 .4479 Mdot
.46287 .52668 Mdot
.44207 .52022 Mdot
.46447 .46886 Mdot
.52106 .44604 Mdot
.54528 .48211 Mdot
.52289 .53826 Mdot
.46356 .47001 Mdot
.50202 .45474 Mdot
.44709 .48106 Mdot
.54728 .48526 Mdot
.54337 .53755 Mdot
.47293 .45412 Mdot
.54491 .47952 Mdot
.4884 .51449 Mdot
.47425 .48487 Mdot
.48842 .52671 Mdot
.44152 .49421 Mdot
.47672 .43227 Mdot
.56444 .48172 Mdot
.55695 .51139 Mdot
.45494 .54479 Mdot
.50583 .53972 Mdot
.48255 .5271 Mdot
.49323 .47958 Mdot
.57242 .47102 Mdot
.47978 .49889 Mdot
.46903 .46125 Mdot
.49289 .53298 Mdot
.46426 .47849 Mdot
.55448 .52599 Mdot
.48639 .47946 Mdot
.56521 .44661 Mdot
.51023 .54008 Mdot
.47398 .46077 Mdot
.56697 .47178 Mdot
.51469 .55519 Mdot
.51202 .48224 Mdot
.56209 .44332 Mdot
.52135 .48116 Mdot
.54583 .49854 Mdot
.47027 .50008 Mdot
.53456 .4832 Mdot
.5044 .51709 Mdot
.42404 .56591 Mdot
.51552 .47703 Mdot
.51724 .51678 Mdot
.5049 .49997 Mdot
.45124 .48856 Mdot
.50094 .42692 Mdot
.49986 .55 Mdot
.46534 .55289 Mdot
.44497 .53184 Mdot
.53539 .53514 Mdot
.5027 .48868 Mdot
.45655 .53293 Mdot
.52943 .49717 Mdot
.49507 .57745 Mdot
.54411 .51785 Mdot
.46747 .46078 Mdot
.44071 .47482 Mdot
.43685 .48636 Mdot
.49099 .51308 Mdot
.45171 .48304 Mdot
.52589 .4809 Mdot
.47937 .49193 Mdot
.52157 .5349 Mdot
.55581 .43844 Mdot
.47095 .50131 Mdot
.48053 .56129 Mdot
.47936 .50476 Mdot
.44183 .52632 Mdot
.51911 .48153 Mdot
.44243 .57823 Mdot
.47446 .4713 Mdot
.47135 .53161 Mdot
.4358 .50708 Mdot
.54236 .48227 Mdot
.48019 .45339 Mdot
.49595 .44556 Mdot
.44778 .52968 Mdot
.47582 .49265 Mdot
.50617 .53253 Mdot
.51096 .50325 Mdot
.48498 .49806 Mdot
.53315 .53348 Mdot
.52296 .47122 Mdot
.47758 .45919 Mdot
.50458 .54702 Mdot
.56486 .45102 Mdot
.49302 .47018 Mdot
.47302 .54883 Mdot
.52766 .54473 Mdot
.54381 .48439 Mdot
.53843 .44298 Mdot
.50709 .53317 Mdot
.46986 .45865 Mdot
.53388 .52617 Mdot
.44836 .48942 Mdot
.50084 .52746 Mdot
.48747 .50414 Mdot
.57616 .5031 Mdot
.51734 .46639 Mdot
.53182 .49099 Mdot
.43592 .50198 Mdot
.52864 .4732 Mdot
.51416 .49076 Mdot
.51825 .49418 Mdot
.53528 .5375 Mdot
.51216 .50038 Mdot
.53722 .56416 Mdot
.48629 .56284 Mdot
.46509 .43276 Mdot
.49021 .47695 Mdot
.50464 .52734 Mdot
.45462 .51776 Mdot
.44749 .50758 Mdot
.51065 .49473 Mdot
.50211 .50051 Mdot
.43463 .46608 Mdot
.4917 .46435 Mdot
.49301 .53596 Mdot
.52974 .5371 Mdot
.44194 .47491 Mdot
.56868 .44814 Mdot
.56384 .44435 Mdot
.55577 .4925 Mdot
.48463 .56071 Mdot
.48863 .48918 Mdot
.52155 .47854 Mdot
.44104 .49186 Mdot
.53546 .4795 Mdot
.48002 .53064 Mdot
.44848 .49956 Mdot
.51779 .52804 Mdot
.53374 .53042 Mdot
.54605 .44691 Mdot
.5314 .4408 Mdot
.50861 .523 Mdot
.47626 .55087 Mdot
.48584 .55781 Mdot
.54727 .48228 Mdot
.504 .51516 Mdot
.50022 .51736 Mdot
.47448 .45767 Mdot
.47972 .47542 Mdot
.45958 .47042 Mdot
.574 .48909 Mdot
.48761 .49135 Mdot
.45358 .5377 Mdot
.4842 .49916 Mdot
.52168 .48065 Mdot
.50759 .52046 Mdot
.46856 .45854 Mdot
.42488 .43446 Mdot
.42951 .55398 Mdot
.44245 .51488 Mdot
.48953 .54859 Mdot
.39853 .4821 Mdot
.51427 .46651 Mdot
.57989 .51953 Mdot
.49489 .46685 Mdot
.42424 .44547 Mdot
.41324 .48531 Mdot
.52872 .54846 Mdot
.53262 .52813 Mdot
.55201 .53758 Mdot
.45866 .49839 Mdot
.51417 .47085 Mdot
.57015 .49601 Mdot
.53111 .48199 Mdot
.49829 .54053 Mdot
.46655 .55258 Mdot
.48056 .46229 Mdot
.4782 .55265 Mdot
.5088 .46553 Mdot
.48756 .53454 Mdot
.4993 .46436 Mdot
.50425 .44301 Mdot
.46656 .50072 Mdot
.45779 .50947 Mdot
.48308 .54006 Mdot
.43379 .49939 Mdot
.46214 .4353 Mdot
.48635 .51914 Mdot
.44765 .49408 Mdot
.52699 .46392 Mdot
.42465 .58544 Mdot
.49318 .50477 Mdot
.5091 .53853 Mdot
.51174 .47572 Mdot
.53785 .48431 Mdot
.47957 .50018 Mdot
.45425 .46144 Mdot
.51281 .49986 Mdot
.4482 .4898 Mdot
.50004 .56504 Mdot
.49059 .52587 Mdot
.51791 .49311 Mdot
.44726 .53349 Mdot
.54977 .52352 Mdot
.55792 .49775 Mdot
.48639 .50177 Mdot
.45012 .5413 Mdot
.56752 .52642 Mdot
.47243 .45009 Mdot
.51158 .5505 Mdot
.56317 .53268 Mdot
.51377 .45382 Mdot
.51833 .4588 Mdot
.57016 .49307 Mdot
.50119 .48331 Mdot
.55681 .49653 Mdot
.46009 .50645 Mdot
.49659 .47976 Mdot
.51978 .46537 Mdot
.46952 .482 Mdot
.55218 .43941 Mdot
.54722 .44996 Mdot
.46886 .46126 Mdot
.48493 .53915 Mdot
.56532 .47286 Mdot
.5172 .53272 Mdot
.4696 .48476 Mdot
.51062 .52752 Mdot
.48741 .43209 Mdot
.48808 .56179 Mdot
.49064 .52008 Mdot
.50211 .55303 Mdot
.55414 .52059 Mdot
.4777 .5241 Mdot
.50182 .53513 Mdot
.49022 .44563 Mdot
.48421 .51661 Mdot
.54962 .4836 Mdot
.51159 .51752 Mdot
.52267 .4887 Mdot
.50908 .50381 Mdot
.49435 .52739 Mdot
.49136 .50715 Mdot
.53862 .48283 Mdot
.44008 .49167 Mdot
.50199 .5062 Mdot
.4644 .48663 Mdot
.52105 .48946 Mdot
.53583 .55199 Mdot
.46808 .45964 Mdot
.53623 .52584 Mdot
.53944 .53543 Mdot
.45611 .46073 Mdot
.54335 .50925 Mdot
.51267 .4624 Mdot
.52321 .4594 Mdot
.59038 .54982 Mdot
.4658 .53366 Mdot
.55284 .43814 Mdot
.49099 .48046 Mdot
.4595 .4612 Mdot
.51111 .48291 Mdot
.4884 .49955 Mdot
.43551 .49387 Mdot
.54969 .46443 Mdot
.45824 .4572 Mdot
.49915 .45761 Mdot
.49992 .48858 Mdot
.43331 .5078 Mdot
.49512 .55157 Mdot
.56992 .53052 Mdot
.54175 .47675 Mdot
.49088 .4859 Mdot
.47134 .5179 Mdot
.52959 .52525 Mdot
.48356 .45099 Mdot
.50565 .45811 Mdot
.50495 .42213 Mdot
.41843 .44775 Mdot
.49953 .56236 Mdot
.48291 .47256 Mdot
.52718 .53072 Mdot
.56546 .50089 Mdot
.46814 .54632 Mdot
.49774 .47371 Mdot
.56728 .46316 Mdot
.50319 .47922 Mdot
.49448 .54329 Mdot
.47512 .45862 Mdot
.49572 .55244 Mdot
.46812 .45772 Mdot
.42103 .57391 Mdot
.53434 .53413 Mdot
.44103 .53035 Mdot
.52559 .52815 Mdot
.46566 .47792 Mdot
.46229 .54728 Mdot
.59046 .5215 Mdot
.53548 .47674 Mdot
.53032 .5338 Mdot
.46778 .48977 Mdot
.54453 .48004 Mdot
.51585 .46619 Mdot
.57953 .47846 Mdot
.51112 .48199 Mdot
.51379 .55489 Mdot
.50551 .48113 Mdot
.54082 .48158 Mdot
.53521 .535 Mdot
.45989 .46925 Mdot
.49023 .53883 Mdot
.46768 .48055 Mdot
.53425 .47103 Mdot
.44762 .46821 Mdot
.5126 .52615 Mdot
.48924 .47814 Mdot
.50334 .56267 Mdot
.55233 .52306 Mdot
.53553 .47287 Mdot
.56868 .52 Mdot
.51215 .50084 Mdot
.48909 .46106 Mdot
.47647 .45949 Mdot
.48394 .51707 Mdot
.42743 .54885 Mdot
.4683 .4531 Mdot
.44825 .48143 Mdot
.49658 .5321 Mdot
.49579 .51465 Mdot
.53231 .52806 Mdot
.45849 .53662 Mdot
.55881 .48051 Mdot
.49258 .47626 Mdot
.50913 .53913 Mdot
.53052 .47376 Mdot
.50258 .53571 Mdot
.49493 .54158 Mdot
.52138 .56514 Mdot
.48875 .55692 Mdot
.45579 .54871 Mdot
.58043 .51694 Mdot
.45674 .5359 Mdot
.49971 .53662 Mdot
.46111 .49314 Mdot
.49719 .46249 Mdot
.54799 .44285 Mdot
.44066 .48754 Mdot
.4108 .48513 Mdot
.5359 .56988 Mdot
.47928 .48964 Mdot
.51428 .52551 Mdot
.52716 .44518 Mdot
.49227 .48876 Mdot
.51219 .49719 Mdot
.45073 .54167 Mdot
.47887 .48934 Mdot
.50081 .51146 Mdot
.48099 .55202 Mdot
.57003 .4915 Mdot
.44302 .52978 Mdot
.48467 .47019 Mdot
.5768 .48782 Mdot
.49678 .4715 Mdot
.45062 .42594 Mdot
.56833 .4714 Mdot
.50997 .53875 Mdot
.44892 .46618 Mdot
.52213 .47086 Mdot
.52166 .46076 Mdot
.4993 .48749 Mdot
.52797 .48599 Mdot
.50701 .5365 Mdot
.47009 .49927 Mdot
.47787 .43264 Mdot
.43112 .54793 Mdot
.44439 .45027 Mdot
.48178 .44876 Mdot
.50534 .49182 Mdot
.54224 .43079 Mdot
.5182 .4749 Mdot
.46784 .50378 Mdot
.52296 .53534 Mdot
.47398 .55717 Mdot
.45157 .45144 Mdot
.4805 .53959 Mdot
.50099 .51676 Mdot
.45495 .54337 Mdot
.54648 .50408 Mdot
.50715 .50879 Mdot
.57181 .47047 Mdot
.51496 .48828 Mdot
.47278 .46027 Mdot
.48289 .48034 Mdot
.48408 .47613 Mdot
.55925 .47047 Mdot
.47411 .47336 Mdot
.50031 .45152 Mdot
.49509 .47251 Mdot
.54186 .52151 Mdot
.50227 .48371 Mdot
.47111 .55641 Mdot
.46224 .50038 Mdot
.52995 .48262 Mdot
.48089 .44693 Mdot
.45264 .53919 Mdot
.46689 .54699 Mdot
.47881 .48511 Mdot
.5196 .49273 Mdot
.50355 .4667 Mdot
.47682 .50229 Mdot
.45742 .55221 Mdot
.45575 .55344 Mdot
.50498 .46421 Mdot
.50103 .54501 Mdot
.50809 .53095 Mdot
.49137 .50376 Mdot
.45753 .46613 Mdot
.45727 .54938 Mdot
.53259 .54372 Mdot
.49838 .47957 Mdot
.52752 .4842 Mdot
.47274 .49566 Mdot
.57473 .50273 Mdot
.50563 .48565 Mdot
.48034 .47311 Mdot
.45949 .54261 Mdot
.55831 .50151 Mdot
.49478 .46087 Mdot
.49141 .49103 Mdot
.58268 .43764 Mdot
.50281 .52755 Mdot
.428 .53913 Mdot
.516 .54454 Mdot
.50771 .56203 Mdot
.47129 .44946 Mdot
.53585 .47195 Mdot
.44314 .48184 Mdot
.50005 .48045 Mdot
.48649 .5353 Mdot
.52292 .46994 Mdot
.46178 .45392 Mdot
.45753 .45521 Mdot
.45367 .48068 Mdot
.46912 .46019 Mdot
.56787 .50583 Mdot
.48435 .48422 Mdot
.56766 .45386 Mdot
.48789 .45943 Mdot
.50458 .47652 Mdot
.57329 .48562 Mdot
.4646 .55512 Mdot
.51634 .53945 Mdot
.42987 .52688 Mdot
.54488 .56442 Mdot
.46336 .54744 Mdot
.49712 .48957 Mdot
.508 .55388 Mdot
.49759 .51705 Mdot
.51217 .52567 Mdot
.45464 .46911 Mdot
.43886 .52356 Mdot
.47708 .47252 Mdot
.51865 .53333 Mdot
.49012 .55025 Mdot
.45198 .52996 Mdot
.51001 .46097 Mdot
.48477 .43541 Mdot
.48105 .54872 Mdot
.42241 .50779 Mdot
.52384 .53876 Mdot
.4312 .59124 Mdot
.4955 .4902 Mdot
.48163 .51119 Mdot
.57738 .47132 Mdot
.5317 .42855 Mdot
.50561 .50299 Mdot
.52473 .47667 Mdot
.54775 .48488 Mdot
.47056 .45118 Mdot
.44753 .47476 Mdot
.52132 .46467 Mdot
.48787 .47483 Mdot
.51697 .54005 Mdot
.53197 .51294 Mdot
.53474 .47714 Mdot
.51752 .49506 Mdot
.49803 .45087 Mdot
.54594 .52071 Mdot
.53912 .5318 Mdot
.48812 .535 Mdot
.49136 .55698 Mdot
.44979 .52566 Mdot
.51201 .56473 Mdot
.55939 .44179 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go
00001_ooool3o`000?ooooooB?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04
odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol0003o
oooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`3o
ooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007
ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<
ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0X?ooool2o`000:Gooooo000Nooooo`03o`000?oooooooooo09gooooo0_l000000ooooooo0000
o`000004ooooo`;o0000Woooool001kooooo00?o0000ooooooooool0S_ooool2o`0000gooooo1?l0
0005ooooo`;o000000?oooooo`000?l00000W?ooool001kooooo00?o0000ooooooooool0S_ooool2
o`0000oooooo0_l00002ooooo`;o00001?ooool2o`000003ooooool0003o000009Wooooo000Noooo
o`03o`000?oooooooooo08Kooooo0_l00002ooooo`;o00001oooool6o`000003ooooool0003o0000
00Cooooo0_l000000ooooooo0000o`000007ooooo`;o0000VOooool001kooooo00?o0000oooooooo
ool0Q_ooool2o`0000;ooooo0_l00006ooooo`co00000_ooool2o`0000?ooooo0_l00009ooooo`;o
00001oooool2o`0008cooooo000Nooooo`03o`000?oooooooooo09;ooooo0_l00005ooooo`;o0000
00?oooooo`000?l000001oooool6o`0000Cooooo1?l00006ooooo`;o0000S?ooool001kooooo00?o
0000ooooooooool0Roooool2o`0000cooooo1?l00002ooooo`?o00001Oooool6o`000003ooooool0
003o000000Go00000oooool3o`0008cooooo000Nooooo`03o`000?oooooooooo08?ooooo0_l00000
0ooooooo0000o`000003ooooo`;o00002oooool:o`0000?ooooo1?l00002ooooo`Go00000_ooool4
o`0000;ooooo0_l0002=ooooo`007_ooool00ol0003oooooooooo`23ooooo`Go00001?ooool2o`00
00Oooooo3?l00004ooooo`Co00001?ooool3o`0000?ooooo1?l00002ooooo`;o0000S?ooool001ko
oooo0_l00025ooooo`;o00001_ooool2o`000003ooooool0003o000000;ooooo2Ol000000ooooooo
0000o`000002o`000003ooooool0003o000000;o00002?ooool2o`0000?ooooo1?l00002ooooo`;o
0000S?ooool001kooooo00?o0000ooooooooool0Roooool2o`0000;ooooo4_l000000ooooooo0000
o`000002o`0000Sooooo0_l00004ooooo`;o00000_ooool3o`0008cooooo000Nooooo`03o`000?oo
oooooooo08_ooooo0_l00003ooooo`Wo000000?oooooo`000?l000003?l0000;ooooo`?o00000_oo
ool2o`0008gooooo000Nooooo`03o`000?oooooooooo08[ooooo0_l00003oooooa[o00002_ooool3
o`00097ooooo000Nooooo`03o`000?oooooooooo08[ooooo0ol00002oooooa[o00001_ooool2o`00
00;ooooo0ol000000ooooooo0000o`00002>ooooo`007_ooool00ol0003oooooooooo`29ooooo`co
00001?ooool@o`0000Kooooo0_l00003ooooo`Go0000S_ooool001kooooo00?o0000ooooooooool0
ROooool2o`0000;ooooo2?l000001?oooooo0000o`000?ooool?o`000004ooooool0003o0000o`00
00Kooooo2?l0002=ooooo`007_ooool00ol0003oooooooooo`1nooooo`;o00000oooool4o`0000Co
oooo8Ol00006ooooo`So0000SOooool001kooooo00?o0000ooooooooool0O_ooool2o`0000?ooooo
1?l00004ooooo`Co000000Coooooo`000?l0003ooooo6ol00005ooooo`?o00000_ooool2o`0008go
oooo000Nooooo`03o`000?oooooooooo08_ooooo1ol000001Ooooooo0000o`000?l0003ooooo01So
00000oooool4o`0000;ooooo0_l0002=ooooo`007_ooool00ol0003oooooooooo`1mooooo`;o0000
1Oooool2o`0000Gooooo1_l000000ooooooo0000o`00000Qo`000003ooooool0003o000000;o0000
SOooool001kooooo00?o0000ooooooooool0OOooool2o`0000;ooooo1Ol00004ooooo`Oo000000?o
ooooo`000?l000008Ol000000ooooooo0000o`00002?ooooo`007_ooool00ol0003oooooooooo`1o
ooooo`Go00001_ooool7o`0000;ooooo5ol00003ooooo`Oo00000_ooool3o`0008kooooo000Noooo
o`03o`000?oooooooooo07oooooo0_l00009ooooo`Oo000000?oooooo`000?l000005ol00002oooo
o`Oo000000?oooooo`000?l000000_l0002>ooooo`007_ooool00ol0003oooooooooo`29ooooo`Ko
00000oooool<o`0000;ooooo2?l000000ooooooo0000o`000005ooooo`Oo0000T?ooool001kooooo
00?o0000ooooooooool0ROooool7o`000003ooooool0003o000000[o000000?oooooo`000?l00000
2_l00003ooooo`;o00000_ooool6o`00093ooooo000Nooooo`;o0000R_ooool7o`000003ooooool0
003o000001;o000000?oooooo`000?l000000_l000000ooooooo0000o`000002o`0000;ooooo0_l0
00000ooooooo0000o`000003o`0008kooooo000Nooooo`03o`000?oooooooooo08Wooooo1_l00003
ooooo`co000000?oooooo`000?l000001?l00006ooooo`;o000000Coooooo`000?l0003ooooo2?l0
002>ooooo`007_ooool00ol0003oooooooooo`25ooooo`;o00000_ooool7o`000003ooooool0003o
0000017o00002_ooool2o`0000?ooooo1_l0002>ooooo`007_ooool00ol0003oooooooooo`25oooo
o`;o00000_ooool7o`000005ooooool0003o0000o`000?ooool00_l000000ooooooo0000o`000009
o`0000[ooooo1ol00002ooooo`;o0000Soooool001kooooo00?o0000ooooooooool0QOooool2o`00
00Gooooo0_l000000ooooooo0000o`000006o`000003ooooool0003o000000So00000_ooool2o`00
00;ooooo0ol00002ooooo`Oo0000Toooool001kooooo00?o0000ooooooooool0ROooool5o`000005
ooooool0003o0000o`000?ooool04ol00002ooooo`?o000000?oooooo`000?l000001?l00007oooo
o`;o0000S?ooool001kooooo00?o0000ooooooooool0ROooool5o`000003ooooool0003o000000;o
00000_oooolAo`000003ooooool0003o000000;o000000?oooooo`000?l000001?l00003ooooo`;o
000000Coooooo`000?l0003o0000S?ooool001kooooo00?o0000ooooooooool0R_ooool4o`0000;o
oooo0ol000000ooooooo0000o`00000=o`0000Cooooo0_l00002ooooo`Oo00000oooool2o`000003
ooooool0003o000000;ooooo0_l00029ooooo`007_ooool00ol0003oooooooooo`28ooooo`ko0000
00?oooooo`000?l000003?l000000ooooooo0000o`00000:o`0000;ooooo0_l00006ooooo`;o0000
ROooool001kooooo00?o0000ooooooooool0R?ooool2o`000003ooooool0003o000000Oo00000ooo
oolKo`0000;ooooo0_l0002Aooooo`007_ooool00ol0003oooooooooo`2;ooooo`So000000?ooooo
o`000?l000006Ol000001?oooooo0000o`000?ooool4o`00093ooooo000Nooooo`03o`000?oooooo
oooo08gooooo0_l000000ooooooo0000o`00000Po`000003ooooool0003o000000;o0000T?ooool0
01kooooo00?o0000ooooooooool0Qoooool2o`0000Kooooo1_l00003oooooaWo0000U_ooool001ko
oooo00?o0000ooooooooool0Qoooool2o`0000Gooooo1_l000001?oooooo0000o`000?oooolIo`00
09Kooooo000Nooooo`03o`000?oooooooooo08kooooo1_l000000ooooooo0000o`000002ooooo`;o
000000?oooooo`000?l000003_l0002Kooooo`007_ooool00ol0003oooooooooo`27ooooo`?o0000
1_oooolBo`0000;ooooo0_l000000ooooooo0000o`000004o`0009[ooooo000Nooooo`;o0000R?oo
ool3o`0000Kooooo5Ol00003ooooo`Go00000_ooool2o`0000_ooooo0_l00029ooooo`007_ooool0
0ol0003oooooooooo`28ooooo`;o00001_ooool:o`000003ooooool0003o000000So00001Oooool7
o`0000_ooooo0_l00029ooooo`007_ooool00ol0003oooooooooo`28ooooo`;o00001_oooolEo`00
00Sooooo0_l00008ooooo`Co0000S?ooool001kooooo00?o0000ooooooooool0Toooool>o`0000;o
oooo0_l0000Booooo`Co0000S?ooool001kooooo00?o0000ooooooooool0V?ooool;o`0000;ooooo
0_l00004ooooo`;o0000V_ooool001kooooo00?o0000ooooooooool0Q_ooool2o`0000Cooooo0_l0
000:ooooo`Go000000?oooooo`000?l000001?l000000ooooooo0000o`000002ooooo`Ko0000V?oo
ool001kooooo00?o0000ooooooooool0Q_ooool2o`0000Cooooo0_l0000@ooooo`;o00000_ooool2
o`000003ooooool0003o000000;ooooo0ol000000ooooooo0000o`00002Hooooo`007_ooool00ol0
003oooooooooo`2Zooooo`;o0000Voooool001kooooo00?o0000ooooooooool0QOooool4o`0000go
oooo0_l0002_ooooo`007_ooool00ol0003oooooooooo`25ooooo`Co00000oooool2o`0000Sooooo
0_l00005ooooo`;o0000Z?ooool001kooooo00?o0000ooooooooool0S?ooool2o`0000oooooo0_l0
002Xooooo`007_ooool00ol0003oooooooooo`26ooooo`;o0000_oooool001kooooo00?o0000oooo
ooooool0Q_ooool2o`000;oooooo000Nooooo`03o`000?oooooooooo08Sooooo0_l0002mooooo`00
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@
4?o<c<`01_ooool00ol0003oooooooooo`26ooooo`Co0000_Oooool000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000
ooooooooool0Q_ooool2o`0000oooooo0_l0002^ooooo`000oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000Uoooool2o`000:kooooo0003
ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo
00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo
00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo
00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000oooooooo
ool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nH
V9P02?ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000
oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Ko
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`3ooooo
odSooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo
000000Kooooo0ol0003oooooodSooooo0003ooooo`05o`000?ooooooooooooooool000002oooool0
1Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@
4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000oooo
ooooool0oooooom8ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@
4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001Cooooo1?l000000ol@413ooooo
ooooo`03ooooo`03o`000?oooooooooo0?ooooooB?ooool001Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Fooooo`03o`000?oooooooooo00Gooooo0ol0003o
ooooodSooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000oooooooo
ool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oo
oooooooo0?ooooooD?ooool001Cooooo00?oEEEEofIVI_l00000oooooomBooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.55839 .48977 Mdot
.51512 .47262 Mdot
.42973 .46761 Mdot
.51936 .48167 Mdot
.51932 .50428 Mdot
.54364 .48344 Mdot
.45782 .52465 Mdot
.53867 .49292 Mdot
.51528 .54096 Mdot
.52557 .55497 Mdot
.56234 .51054 Mdot
.48178 .48404 Mdot
.53384 .47659 Mdot
.47779 .43948 Mdot
.50822 .55455 Mdot
.50499 .54958 Mdot
.52831 .47163 Mdot
.58586 .51355 Mdot
.54023 .55212 Mdot
.45404 .49379 Mdot
.53174 .47175 Mdot
.48331 .55064 Mdot
.51137 .50845 Mdot
.53159 .46388 Mdot
.54507 .48463 Mdot
.48444 .49983 Mdot
.47006 .54659 Mdot
.55878 .53812 Mdot
.51046 .50145 Mdot
.54038 .4821 Mdot
.47159 .44299 Mdot
.52634 .47913 Mdot
.49693 .51845 Mdot
.43109 .4922 Mdot
.53478 .47908 Mdot
.43163 .47156 Mdot
.4888 .51124 Mdot
.46386 .54651 Mdot
.51321 .50982 Mdot
.47655 .48631 Mdot
.50532 .54139 Mdot
.45356 .51432 Mdot
.48029 .45517 Mdot
.489 .49576 Mdot
.53005 .4817 Mdot
.48511 .53216 Mdot
.45696 .45617 Mdot
.47164 .43692 Mdot
.44846 .45696 Mdot
.57658 .48166 Mdot
.51405 .51004 Mdot
.51087 .45314 Mdot
.50902 .49749 Mdot
.52277 .50305 Mdot
.51072 .55303 Mdot
.47742 .50962 Mdot
.47748 .46511 Mdot
.47453 .43868 Mdot
.52925 .48893 Mdot
.47396 .4637 Mdot
.47716 .53085 Mdot
.48794 .52525 Mdot
.43821 .49452 Mdot
.50585 .54887 Mdot
.50576 .51578 Mdot
.5463 .51928 Mdot
.50104 .44649 Mdot
.47798 .52413 Mdot
.46838 .49864 Mdot
.5041 .54996 Mdot
.45684 .53665 Mdot
.52565 .4929 Mdot
.46899 .46937 Mdot
.50086 .4856 Mdot
.53775 .47386 Mdot
.45501 .54485 Mdot
.47129 .51189 Mdot
.58602 .50161 Mdot
.4499 .52623 Mdot
.55142 .51605 Mdot
.44911 .54088 Mdot
.54209 .49253 Mdot
.53682 .47888 Mdot
.49723 .53729 Mdot
.43505 .49444 Mdot
.50392 .48993 Mdot
.43043 .51902 Mdot
.48123 .52153 Mdot
.47561 .48174 Mdot
.56675 .46342 Mdot
.50456 .50744 Mdot
.48829 .53945 Mdot
.44543 .53846 Mdot
.56811 .49525 Mdot
.43673 .49023 Mdot
.47732 .52786 Mdot
.47862 .5176 Mdot
.47919 .4395 Mdot
.45362 .45936 Mdot
.48428 .46352 Mdot
.43487 .52658 Mdot
.43876 .53309 Mdot
.53011 .49488 Mdot
.55624 .5181 Mdot
.50742 .54177 Mdot
.49831 .51963 Mdot
.41791 .56152 Mdot
.5068 .51245 Mdot
.50046 .45303 Mdot
.48826 .54055 Mdot
.54178 .46805 Mdot
.52567 .49163 Mdot
.49686 .47378 Mdot
.49439 .55377 Mdot
.51356 .44483 Mdot
.52791 .4618 Mdot
.46856 .54564 Mdot
.56331 .54135 Mdot
.45047 .44382 Mdot
.44818 .54002 Mdot
.57714 .48847 Mdot
.48566 .4975 Mdot
.52262 .55643 Mdot
.45909 .44874 Mdot
.52132 .47086 Mdot
.49432 .56092 Mdot
.54001 .46953 Mdot
.48574 .49919 Mdot
.48892 .49902 Mdot
.51273 .54653 Mdot
.57182 .50041 Mdot
.52632 .46343 Mdot
.48193 .4539 Mdot
.44101 .47156 Mdot
.53482 .49845 Mdot
.47669 .45287 Mdot
.52715 .5758 Mdot
.49548 .50026 Mdot
.46656 .48087 Mdot
.49171 .48125 Mdot
.50603 .51044 Mdot
.49507 .54581 Mdot
.49266 .50732 Mdot
.51808 .48764 Mdot
.49754 .52414 Mdot
.4867 .54005 Mdot
.55612 .49045 Mdot
.47487 .53066 Mdot
.51249 .44322 Mdot
.45507 .45426 Mdot
.43926 .48391 Mdot
.56222 .53519 Mdot
.51168 .50741 Mdot
.49414 .43338 Mdot
.57001 .50327 Mdot
.50495 .54976 Mdot
.49147 .52699 Mdot
.5094 .45983 Mdot
.47113 .51092 Mdot
.49725 .51851 Mdot
.47715 .55165 Mdot
.46526 .50901 Mdot
.57924 .4852 Mdot
.51172 .5504 Mdot
.47527 .47368 Mdot
.48766 .46957 Mdot
.50057 .54336 Mdot
.4525 .54455 Mdot
.46623 .54083 Mdot
.47558 .55334 Mdot
.55872 .5301 Mdot
.46098 .45421 Mdot
.50906 .46799 Mdot
.47336 .47504 Mdot
.48746 .55416 Mdot
.48315 .51333 Mdot
.48235 .53407 Mdot
.49868 .51908 Mdot
.47102 .45571 Mdot
.44983 .4644 Mdot
.51696 .48382 Mdot
.4813 .53036 Mdot
.49682 .49083 Mdot
.5105 .49757 Mdot
.53287 .47136 Mdot
.48428 .48168 Mdot
.42323 .49795 Mdot
.47676 .52943 Mdot
.5604 .50493 Mdot
.44788 .54129 Mdot
.48926 .48759 Mdot
.51019 .54217 Mdot
.53092 .45971 Mdot
.50982 .50934 Mdot
.47069 .55099 Mdot
.50793 .53954 Mdot
.58025 .47709 Mdot
.49278 .50855 Mdot
.50187 .51925 Mdot
.51452 .47794 Mdot
.49128 .46367 Mdot
.47543 .52352 Mdot
.57464 .49491 Mdot
.45245 .53907 Mdot
.51383 .55364 Mdot
.50486 .46618 Mdot
.53204 .46468 Mdot
.48113 .46184 Mdot
.42504 .48909 Mdot
.51217 .50936 Mdot
.53046 .48019 Mdot
.49047 .50912 Mdot
.47254 .48937 Mdot
.56646 .48535 Mdot
.48538 .49702 Mdot
.46261 .45451 Mdot
.48523 .53655 Mdot
.47169 .50712 Mdot
.49475 .54615 Mdot
.50234 .51377 Mdot
.50428 .53333 Mdot
.48146 .44679 Mdot
.48626 .53932 Mdot
.49776 .44512 Mdot
.5506 .50546 Mdot
.54271 .4949 Mdot
.52595 .48253 Mdot
.52354 .55615 Mdot
.42288 .49016 Mdot
.54543 .51375 Mdot
.5166 .55507 Mdot
.49077 .50747 Mdot
.4886 .55078 Mdot
.49389 .52277 Mdot
.4829 .50499 Mdot
.4659 .47936 Mdot
.48933 .55624 Mdot
.44907 .54211 Mdot
.51537 .46317 Mdot
.48417 .48168 Mdot
.52439 .55634 Mdot
.49895 .55464 Mdot
.55272 .4813 Mdot
.48863 .55882 Mdot
.44372 .4787 Mdot
.50794 .55163 Mdot
.46017 .54648 Mdot
.53904 .49497 Mdot
.5178 .55189 Mdot
.47434 .54647 Mdot
.48059 .45667 Mdot
.5345 .46944 Mdot
.48678 .55 Mdot
.44008 .48294 Mdot
.49737 .47711 Mdot
.48265 .47575 Mdot
.51146 .52035 Mdot
.47358 .49905 Mdot
.43393 .49583 Mdot
.48543 .54738 Mdot
.44908 .54192 Mdot
.51122 .54176 Mdot
.49699 .51873 Mdot
.57349 .49165 Mdot
.44996 .48825 Mdot
.44183 .49711 Mdot
.53695 .51248 Mdot
.57356 .51953 Mdot
.50507 .53581 Mdot
.46943 .45574 Mdot
.49668 .45016 Mdot
.49643 .47361 Mdot
.55876 .50572 Mdot
.49302 .47757 Mdot
.42393 .48556 Mdot
.45803 .54514 Mdot
.47433 .51234 Mdot
.53575 .55226 Mdot
.45732 .49223 Mdot
.53277 .54644 Mdot
.46686 .48833 Mdot
.47972 .49861 Mdot
.47086 .43716 Mdot
.49346 .5123 Mdot
.47498 .54888 Mdot
.57216 .49114 Mdot
.46696 .45508 Mdot
.50634 .52003 Mdot
.51405 .46539 Mdot
.50084 .43349 Mdot
.47872 .475 Mdot
.50517 .44005 Mdot
.53581 .46271 Mdot
.47227 .45465 Mdot
.48801 .46943 Mdot
.52722 .4996 Mdot
.56308 .53238 Mdot
.4498 .4686 Mdot
.44849 .51978 Mdot
.52078 .48256 Mdot
.49 .50134 Mdot
.54313 .49536 Mdot
.51699 .53863 Mdot
.49554 .54619 Mdot
.48052 .47919 Mdot
.52015 .48316 Mdot
.43494 .46338 Mdot
.5282 .4495 Mdot
.54774 .48461 Mdot
.4512 .48315 Mdot
.51015 .48186 Mdot
.49393 .51414 Mdot
.52407 .52922 Mdot
.55865 .4926 Mdot
.5104 .4749 Mdot
.51583 .44008 Mdot
.4764 .48788 Mdot
.47932 .52322 Mdot
.46856 .47247 Mdot
.46568 .54911 Mdot
.45218 .46092 Mdot
.563 .51136 Mdot
.5622 .51147 Mdot
.48081 .51187 Mdot
.55539 .53814 Mdot
.47509 .55695 Mdot
.48888 .4909 Mdot
.48837 .49798 Mdot
.51675 .54848 Mdot
.43951 .53061 Mdot
.55366 .48757 Mdot
.52097 .46052 Mdot
.49594 .47266 Mdot
.52764 .55404 Mdot
.4258 .48567 Mdot
.5196 .54239 Mdot
.44087 .48045 Mdot
.52338 .48763 Mdot
.56135 .50903 Mdot
.48602 .52341 Mdot
.49674 .44574 Mdot
.52422 .44342 Mdot
.43543 .52457 Mdot
.49382 .5103 Mdot
.47085 .55613 Mdot
.51366 .44964 Mdot
.49325 .51031 Mdot
.53312 .49591 Mdot
.4503 .54318 Mdot
.49719 .53757 Mdot
.478 .46871 Mdot
.4849 .45306 Mdot
.53105 .4751 Mdot
.49075 .51824 Mdot
.55343 .46928 Mdot
.48313 .4695 Mdot
.49228 .43854 Mdot
.51939 .45995 Mdot
.54562 .45849 Mdot
.49908 .5216 Mdot
.50447 .5172 Mdot
.5156 .43913 Mdot
.49068 .47131 Mdot
.50209 .43576 Mdot
.51712 .45653 Mdot
.46722 .43757 Mdot
.44848 .46218 Mdot
.45611 .54674 Mdot
.44916 .47319 Mdot
.50284 .49134 Mdot
.49758 .51826 Mdot
.49803 .5033 Mdot
.48813 .45181 Mdot
.5555 .50791 Mdot
.44098 .45272 Mdot
.51917 .55519 Mdot
.5496 .50956 Mdot
.43872 .53193 Mdot
.45606 .50741 Mdot
.48828 .50668 Mdot
.44607 .47833 Mdot
.44204 .50507 Mdot
.52014 .49286 Mdot
.509 .45265 Mdot
.52722 .48444 Mdot
.54865 .49229 Mdot
.5602 .53699 Mdot
.51586 .53895 Mdot
.47803 .50548 Mdot
.44802 .47533 Mdot
.45491 .45499 Mdot
.4605 .50052 Mdot
.45206 .46296 Mdot
.52703 .4799 Mdot
.50594 .51473 Mdot
.5367 .49016 Mdot
.50147 .54665 Mdot
.49539 .51782 Mdot
.55579 .53884 Mdot
.4582 .45457 Mdot
.45087 .45907 Mdot
.44395 .47294 Mdot
.43333 .45676 Mdot
.47938 .49706 Mdot
.45518 .46442 Mdot
.43744 .46697 Mdot
.51247 .49559 Mdot
.49966 .51558 Mdot
.4897 .46165 Mdot
.55058 .52515 Mdot
.4892 .48207 Mdot
.54246 .54682 Mdot
.50061 .48743 Mdot
.46914 .43896 Mdot
.50038 .49254 Mdot
.43965 .53405 Mdot
.49069 .54345 Mdot
.52579 .45246 Mdot
.47073 .45941 Mdot
.52106 .55659 Mdot
.53524 .54352 Mdot
.48289 .5307 Mdot
.49622 .49 Mdot
.53299 .55021 Mdot
.45111 .44131 Mdot
.43714 .47604 Mdot
.50634 .54719 Mdot
.50482 .53705 Mdot
.46323 .48557 Mdot
.47336 .49066 Mdot
.51235 .43779 Mdot
.50352 .54972 Mdot
.53282 .46083 Mdot
.53677 .54 Mdot
.46105 .54304 Mdot
.52622 .45826 Mdot
.46543 .54314 Mdot
.47636 .46549 Mdot
.51775 .44183 Mdot
.47371 .47387 Mdot
.47013 .4528 Mdot
.55127 .45582 Mdot
.50078 .43565 Mdot
.57226 .4947 Mdot
.49873 .52068 Mdot
.56909 .51269 Mdot
.52176 .49809 Mdot
.51293 .55199 Mdot
.42955 .48862 Mdot
.50682 .50577 Mdot
.45986 .44668 Mdot
.48649 .48017 Mdot
.50173 .54054 Mdot
.47363 .47735 Mdot
.43699 .5231 Mdot
.50878 .5474 Mdot
.44058 .48287 Mdot
.45951 .54626 Mdot
.49761 .51194 Mdot
.47351 .49479 Mdot
.44898 .53299 Mdot
.50243 .48173 Mdot
.46622 .43691 Mdot
.49501 .52217 Mdot
.45668 .46016 Mdot
.48094 .45058 Mdot
.49931 .53098 Mdot
.4944 .48795 Mdot
.50009 .44226 Mdot
.47251 .49932 Mdot
.5605 .5076 Mdot
.52526 .54545 Mdot
.45599 .56106 Mdot
.53818 .56222 Mdot
.55016 .54278 Mdot
.50985 .54427 Mdot
.44943 .45007 Mdot
.54425 .56253 Mdot
.43573 .52769 Mdot
.48462 .45412 Mdot
.49379 .51382 Mdot
.5312 .47597 Mdot
.54127 .49405 Mdot
.53163 .49012 Mdot
.48126 .53068 Mdot
.45139 .53417 Mdot
.52975 .55112 Mdot
.55734 .48806 Mdot
.45706 .45733 Mdot
.44005 .53394 Mdot
.52795 .45171 Mdot
.42338 .49142 Mdot
.53634 .53027 Mdot
.50102 .51928 Mdot
.48132 .45944 Mdot
.54911 .46851 Mdot
.48395 .54843 Mdot
.49897 .52103 Mdot
.451 .52795 Mdot
.54941 .49317 Mdot
.42316 .53743 Mdot
.49179 .54957 Mdot
.4527 .53251 Mdot
.51461 .54253 Mdot
.48467 .48022 Mdot
.53543 .55448 Mdot
.54846 .47274 Mdot
.52408 .54793 Mdot
.43313 .51808 Mdot
.57527 .48707 Mdot
.46085 .49999 Mdot
.43575 .49046 Mdot
.48462 .45736 Mdot
.54749 .4777 Mdot
.54623 .49499 Mdot
.5015 .5485 Mdot
.48294 .45763 Mdot
.53591 .48001 Mdot
.46218 .44422 Mdot
.55941 .49836 Mdot
.52045 .55265 Mdot
.49945 .44905 Mdot
.55457 .49107 Mdot
.48496 .50283 Mdot
.48484 .47239 Mdot
.4782 .51591 Mdot
.44518 .4665 Mdot
.51466 .453 Mdot
.56301 .51769 Mdot
.5466 .54384 Mdot
.44231 .5196 Mdot
.48665 .54009 Mdot
.47454 .51055 Mdot
.50164 .48087 Mdot
.55625 .51101 Mdot
.48402 .48721 Mdot
.51536 .45961 Mdot
.47855 .5265 Mdot
.47848 .46264 Mdot
.53761 .55321 Mdot
.49625 .47632 Mdot
.58163 .48129 Mdot
.48947 .54283 Mdot
.51871 .45778 Mdot
.56731 .50513 Mdot
.47188 .54806 Mdot
.51749 .49224 Mdot
.581 .47865 Mdot
.52705 .49448 Mdot
.5348 .53077 Mdot
.47632 .48151 Mdot
.52619 .49998 Mdot
.49677 .52168 Mdot
.42649 .52748 Mdot
.52589 .48796 Mdot
.50443 .53572 Mdot
.5011 .50921 Mdot
.46082 .46476 Mdot
.53346 .45471 Mdot
.46059 .54333 Mdot
.43987 .53246 Mdot
.43099 .50184 Mdot
.51606 .55341 Mdot
.50489 .49521 Mdot
.45068 .5054 Mdot
.51251 .52084 Mdot
.46623 .54021 Mdot
.5315 .5456 Mdot
.51236 .45529 Mdot
.44977 .4512 Mdot
.47042 .4551 Mdot
.4881 .50355 Mdot
.46424 .46161 Mdot
.52952 .49629 Mdot
.48599 .48187 Mdot
.5021 .54503 Mdot
.57658 .4724 Mdot
.47647 .48293 Mdot
.44627 .54087 Mdot
.48164 .49134 Mdot
.42297 .49495 Mdot
.5247 .49362 Mdot
.43248 .53912 Mdot
.49377 .46275 Mdot
.4674 .50872 Mdot
.45563 .46584 Mdot
.53592 .49655 Mdot
.50671 .45079 Mdot
.52077 .44763 Mdot
.43934 .50019 Mdot
.48346 .48018 Mdot
.48955 .53444 Mdot
.50065 .52034 Mdot
.48723 .49008 Mdot
.5139 .55043 Mdot
.55371 .48621 Mdot
.52013 .45384 Mdot
.48592 .53534 Mdot
.57938 .48644 Mdot
.51117 .47089 Mdot
.45442 .54295 Mdot
.50434 .54814 Mdot
.56191 .49921 Mdot
.56157 .47484 Mdot
.4901 .53569 Mdot
.49389 .45201 Mdot
.51888 .5456 Mdot
.45206 .44924 Mdot
.48815 .52438 Mdot
.48755 .49587 Mdot
.57042 .53683 Mdot
.54994 .47302 Mdot
.51571 .51278 Mdot
.45486 .46168 Mdot
.55616 .48549 Mdot
.51451 .5037 Mdot
.50822 .51357 Mdot
.51319 .55352 Mdot
.50568 .51555 Mdot
.49291 .55717 Mdot
.45648 .52459 Mdot
.50419 .44899 Mdot
.50139 .4758 Mdot
.49119 .52635 Mdot
.44723 .47158 Mdot
.44868 .47883 Mdot
.50912 .50714 Mdot
.49814 .50774 Mdot
.4768 .45218 Mdot
.51333 .46646 Mdot
.47746 .52918 Mdot
.50905 .5516 Mdot
.45306 .45291 Mdot
.58419 .48383 Mdot
.58141 .47863 Mdot
.56112 .50947 Mdot
.44935 .54256 Mdot
.49278 .48622 Mdot
.52982 .49251 Mdot
.46761 .45445 Mdot
.53499 .49561 Mdot
.47245 .51222 Mdot
.45107 .45586 Mdot
.50346 .53516 Mdot
.51547 .54713 Mdot
.56588 .47982 Mdot
.55649 .47204 Mdot
.49819 .52321 Mdot
.4511 .50888 Mdot
.45208 .52304 Mdot
.55571 .49413 Mdot
.49631 .52084 Mdot
.49424 .51277 Mdot
.50045 .45333 Mdot
.49391 .46829 Mdot
.4778 .4561 Mdot
.54553 .52196 Mdot
.49108 .48713 Mdot
.44508 .51048 Mdot
.48658 .49019 Mdot
.52778 .49414 Mdot
.4991 .52572 Mdot
.50222 .43686 Mdot
.46199 .4363 Mdot
.43103 .51272 Mdot
.43844 .48545 Mdot
.46386 .55217 Mdot
.42967 .46116 Mdot
.54904 .47402 Mdot
.542 .53812 Mdot
.51513 .46972 Mdot
.46364 .44311 Mdot
.44583 .46025 Mdot
.50699 .55004 Mdot
.51625 .54548 Mdot
.53184 .55646 Mdot
.46398 .47357 Mdot
.53024 .48315 Mdot
.56422 .5317 Mdot
.52874 .49875 Mdot
.48006 .53242 Mdot
.44071 .53263 Mdot
.50466 .46048 Mdot
.44759 .53825 Mdot
.52788 .4756 Mdot
.47439 .52292 Mdot
.51951 .4699 Mdot
.53594 .47141 Mdot
.47219 .47885 Mdot
.45898 .48197 Mdot
.47275 .52069 Mdot
.42983 .46942 Mdot
.50205 .44971 Mdot
.48087 .50573 Mdot
.45406 .4675 Mdot
.54667 .47378 Mdot
.42038 .55051 Mdot
.49041 .50195 Mdot
.49006 .54183 Mdot
.52201 .4843 Mdot
.52594 .50046 Mdot
.48348 .48805 Mdot
.47504 .43532 Mdot
.50627 .51535 Mdot
.44824 .45083 Mdot
.46198 .53494 Mdot
.48018 .51654 Mdot
.51436 .50907 Mdot
.43533 .50433 Mdot
.53359 .55001 Mdot
.5358 .53682 Mdot
.48721 .49359 Mdot
.43251 .51291 Mdot
.55578 .55346 Mdot
.50317 .43368 Mdot
.46889 .5464 Mdot
.55058 .55817 Mdot
.53577 .46141 Mdot
.54533 .48862 Mdot
.56587 .52937 Mdot
.50652 .48889 Mdot
.55002 .53109 Mdot
.46304 .48081 Mdot
.50451 .48281 Mdot
.54971 .47175 Mdot
.48118 .46718 Mdot
.57428 .47551 Mdot
.56582 .48336 Mdot
.51517 .45942 Mdot
.4734 .52175 Mdot
.5696 .50356 Mdot
.49899 .54024 Mdot
.48021 .46968 Mdot
.49587 .53015 Mdot
.52312 .45641 Mdot
.45547 .52569 Mdot
.48416 .50903 Mdot
.48471 .54266 Mdot
.54039 .55013 Mdot
.47315 .50418 Mdot
.48564 .53412 Mdot
.52738 .46822 Mdot
.48011 .50232 Mdot
.55388 .49527 Mdot
.5009 .53184 Mdot
.51928 .50585 Mdot
.50137 .51863 Mdot
.48242 .52112 Mdot
.48963 .50069 Mdot
.55854 .50443 Mdot
.44472 .46459 Mdot
.4962 .51383 Mdot
.47449 .46799 Mdot
.51882 .50568 Mdot
.51704 .55943 Mdot
.50845 .44667 Mdot
.4946 .54568 Mdot
.52049 .55582 Mdot
.47393 .44366 Mdot
.53167 .53986 Mdot
.54331 .48874 Mdot
.54778 .49046 Mdot
.55569 .55998 Mdot
.46139 .50901 Mdot
.57456 .47369 Mdot
.49915 .48044 Mdot
.50459 .45299 Mdot
.51633 .49279 Mdot
.48851 .49408 Mdot
.43523 .46505 Mdot
.56383 .49668 Mdot
.47682 .43979 Mdot
.53565 .47919 Mdot
.50221 .49342 Mdot
.42803 .47852 Mdot
.45735 .54221 Mdot
.52877 .54496 Mdot
.55331 .48832 Mdot
.49601 .48509 Mdot
.47139 .49573 Mdot
.51607 .54436 Mdot
.5109 .44899 Mdot
.53879 .48334 Mdot
.53701 .44991 Mdot
.45672 .44309 Mdot
.45872 .54509 Mdot
.49904 .46725 Mdot
.50898 .54355 Mdot
.55918 .53559 Mdot
.46091 .5274 Mdot
.51182 .47602 Mdot
.57574 .49876 Mdot
.51141 .48511 Mdot
.45957 .54557 Mdot
.50055 .45486 Mdot
.47215 .55694 Mdot
.49194 .44999 Mdot
.42211 .53733 Mdot
.51506 .55182 Mdot
.44435 .48503 Mdot
.51075 .54148 Mdot
.48012 .46294 Mdot
.43258 .51981 Mdot
.55562 .53911 Mdot
.55852 .48911 Mdot
.51084 .54902 Mdot
.47682 .47272 Mdot
.54922 .49285 Mdot
.5327 .47911 Mdot
.58072 .51452 Mdot
.51681 .4917 Mdot
.4711 .54777 Mdot
.51259 .48847 Mdot
.55801 .50712 Mdot
.51587 .55318 Mdot
.47842 .45544 Mdot
.47519 .52537 Mdot
.48042 .46524 Mdot
.55281 .48148 Mdot
.46195 .44825 Mdot
.49951 .52914 Mdot
.49946 .47672 Mdot
.46164 .54648 Mdot
.53739 .55168 Mdot
.55531 .48285 Mdot
.55727 .54926 Mdot
.50463 .51694 Mdot
.51212 .46241 Mdot
.50177 .45628 Mdot
.47967 .50259 Mdot
.43185 .50744 Mdot
.49473 .44571 Mdot
.45163 .44473 Mdot
.48236 .52769 Mdot
.49159 .50764 Mdot
.51607 .54537 Mdot
.45178 .51094 Mdot
.55371 .51485 Mdot
.50396 .47649 Mdot
.47183 .54913 Mdot
.55659 .48545 Mdot
.48607 .53517 Mdot
.47817 .52807 Mdot
.47738 .55013 Mdot
.45202 .52553 Mdot
.43897 .52357 Mdot
.54315 .53643 Mdot
.45009 .50908 Mdot
.48328 .53417 Mdot
.46829 .4708 Mdot
.51901 .4675 Mdot
.56859 .47527 Mdot
.46276 .45077 Mdot
.44302 .46052 Mdot
.49294 .55692 Mdot
.48668 .48002 Mdot
.50322 .53092 Mdot
.55202 .47718 Mdot
.49547 .48844 Mdot
.50844 .51103 Mdot
.43501 .51378 Mdot
.48653 .47952 Mdot
.49433 .51548 Mdot
.44876 .5389 Mdot
.56723 .52706 Mdot
.42873 .49934 Mdot
.50356 .46735 Mdot
.57397 .52356 Mdot
.51314 .4736 Mdot
.48855 .4388 Mdot
.57286 .50763 Mdot
.47294 .54973 Mdot
.46026 .43906 Mdot
.55321 .48618 Mdot
.54448 .46893 Mdot
.50225 .49197 Mdot
.52115 .50416 Mdot
.48938 .53882 Mdot
.47638 .48085 Mdot
.51569 .45366 Mdot
.43375 .5055 Mdot
.48823 .45235 Mdot
.51027 .44477 Mdot
.50609 .50016 Mdot
.56707 .4653 Mdot
.53049 .48857 Mdot
.4727 .48242 Mdot
.50309 .54637 Mdot
.44061 .53415 Mdot
.49653 .45514 Mdot
.47153 .51891 Mdot
.49541 .51307 Mdot
.42861 .5152 Mdot
.53591 .5362 Mdot
.49826 .5221 Mdot
.55793 .51146 Mdot
.51675 .50061 Mdot
.49692 .45532 Mdot
.49327 .47485 Mdot
.49726 .47105 Mdot
.56873 .50142 Mdot
.49092 .46367 Mdot
.524 .45791 Mdot
.51098 .47383 Mdot
.51735 .55684 Mdot
.50738 .48984 Mdot
.43907 .53285 Mdot
.46724 .47677 Mdot
.52748 .49945 Mdot
.5099 .44089 Mdot
.44229 .51156 Mdot
.44786 .53907 Mdot
.48818 .4761 Mdot
.50838 .51269 Mdot
.52206 .47341 Mdot
.48072 .488 Mdot
.43605 .52848 Mdot
.4455 .50711 Mdot
.54268 .46972 Mdot
.46233 .54443 Mdot
.4916 .53355 Mdot
.48946 .49932 Mdot
.48858 .438 Mdot
.43918 .52568 Mdot
.48745 .54873 Mdot
.50635 .48334 Mdot
.52505 .50122 Mdot
.47992 .48024 Mdot
.53921 .52877 Mdot
.50982 .49384 Mdot
.49639 .46654 Mdot
.45015 .52212 Mdot
.52612 .53418 Mdot
.51767 .46511 Mdot
.49372 .48972 Mdot
.58097 .47536 Mdot
.48964 .52556 Mdot
.43627 .49701 Mdot
.47247 .54628 Mdot
.4655 .54861 Mdot
.51406 .46296 Mdot
.54637 .48557 Mdot
.45325 .45875 Mdot
.50727 .48524 Mdot
.47376 .52223 Mdot
.55399 .4808 Mdot
.48522 .44113 Mdot
.4769 .43378 Mdot
.46772 .46077 Mdot
.51307 .45358 Mdot
.55837 .5399 Mdot
.49225 .47941 Mdot
.58415 .49133 Mdot
.51186 .45998 Mdot
.51488 .48246 Mdot
.57263 .52169 Mdot
.43808 .53236 Mdot
.49548 .54601 Mdot
.44621 .48484 Mdot
.50112 .55928 Mdot
.44233 .53354 Mdot
.49908 .49254 Mdot
.48969 .54684 Mdot
.49195 .51067 Mdot
.49962 .52837 Mdot
.47227 .45298 Mdot
.42257 .49286 Mdot
.49432 .46441 Mdot
.50007 .54162 Mdot
.45406 .5413 Mdot
.44556 .50122 Mdot
.54303 .46475 Mdot
.52175 .45822 Mdot
.45781 .54804 Mdot
.44893 .47222 Mdot
.50174 .54906 Mdot
.42254 .55726 Mdot
.4973 .49206 Mdot
.48044 .49684 Mdot
.58634 .50847 Mdot
.55887 .46118 Mdot
.50047 .51411 Mdot
.53205 .49218 Mdot
.54468 .49781 Mdot
.50038 .44025 Mdot
.4522 .44201 Mdot
.54852 .47158 Mdot
.50153 .47194 Mdot
.4944 .54585 Mdot
.51873 .53956 Mdot
.55858 .49023 Mdot
.50692 .51451 Mdot
.52969 .44984 Mdot
.53164 .54679 Mdot
.52061 .552 Mdot
.47449 .52368 Mdot
.45443 .54288 Mdot
.42877 .49052 Mdot
.46912 .54485 Mdot
.57916 .47714 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go
00001_ooool3o`000?ooooooB?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04
odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol0003o
oooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`3o
ooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007
ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<
ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`2Gooooo`;o00001?ooool4o`000:Kooooo000Nooooo`03o`000?oooooooooo09;o
oooo1ol00002ooooo`Ko000000?oooooo`000?l00000Xoooool001kooooo00?o0000ooooooooool0
T_ooool<o`000003ooooool0003o000000Go0000XOooool001kooooo00?o0000ooooooooool0S_oo
oolJo`0009oooooo000Nooooo`03o`000?oooooooooo08kooooo3?l00003ooooo`_o0000Woooool0
01kooooo00?o0000ooooooooool0S_ooool6o`0000Cooooo0_l00002ooooo`_o000000?oooooo`00
0?l000000_l0002Kooooo`007_ooool2o`0008cooooo0_l000000ooooooo0000o`000004o`000003
ooooool0003o000001Go0000Voooool001kooooo00?o0000ooooooooool0Roooool2o`000003oooo
ool0003o000001_o00001?ooool2o`0009Kooooo000Nooooo`03o`000?oooooooooo08Wooooo0_l0
0003ooooo`go00000_ooool4o`000003ooooool0003o000000Oo00000_ooool4o`0009Kooooo000N
ooooo`03o`000?oooooooooo08Sooooo0ol000000ooooooo0000o`000004o`000003ooooool0003o
000000Wo00000_ooool<o`000003ooooool0003o000000?ooooo0_l0002Cooooo`007_ooool00ol0
003oooooooooo`28ooooo`?o000000?oooooo`000?l000004Ol000000ooooooo0000o`00000<o`00
00Cooooo1?l0002Aooooo`007_ooool00ol0003oooooooooo`28ooooo`co00000_oooolEo`000003
ooooool0003o000000;o00001?ooool2o`00097ooooo000Nooooo`03o`000?oooooooooo08Sooooo
2_l00002oooooako0000UOooool001kooooo00?o0000ooooooooool0R?ooool2o`000003ooooool0
003o000000?o00000oooool>o`000003ooooool0003o0000013o00000oooool2o`0008kooooo000N
ooooo`03o`000?oooooooooo08[ooooo1_l00003oooooa;o000000?oooooo`000?l000001Ol00000
0ooooooo0000o`000004o`000003ooooool0003o000000Co0000S?ooool001kooooo00?o0000oooo
ooooool0Qoooool2o`000003ooooool0003o000000Co00000_oooolCo`0000;ooooo1Ol00002oooo
o`Co00000_ooool7o`0008cooooo000Nooooo`03o`000?oooooooooo08Oooooo0_l00002ooooobCo
000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000?o0000Roooool001kooooo
00?o0000ooooooooool0Q_ooool2o`0000;ooooo2_l00002oooooaCo000000?oooooo`000?l00000
1_l000001?oooooo0000o`000?ooool5o`0008_ooooo000Nooooo`03o`000?oooooooooo08Gooooo
2ol00002oooooa[o000000?oooooo`000?l000001?l000001?oooooo0000o`000?ooool3o`0008go
oooo000Nooooo`03o`000?oooooooooo08Gooooo1ol00002ooooo`;o000000Coooooo`000?l0003o
oooo8?l00002ooooo`Ko0000Roooool001kooooo00?o0000ooooooooool0QOooool7o`0000?ooooo
1?l00002oooooaoo000000?oooooo`000?l000000_l000000ooooooo0000o`00002;ooooo`007_oo
ool00ol0003oooooooooo`25ooooo`Wo000000?oooooo`000?l000000oooool9o`0000?ooooo1?l0
0002ooooo`Wo000000?oooooo`000?l000001ol0002>ooooo`007_ooool2o`0008Kooooo2_l00003
ooooo`go000000?oooooo`000?l000002_l000000ooooooo0000o`000003ooooo`Oo000000?ooooo
o`000?l00000Roooool001kooooo00?o0000ooooooooool0R?ooool8o`0000;ooooo0_l00002oooo
oa?o00001_ooool9o`0000;ooooo0_l0002;ooooo`007_ooool00ol0003oooooooooo`28ooooo`?o
000000?oooooo`000?l000001?l00002oooooaCo00001oooool9o`0000?ooooo0_l0002:ooooo`00
7_ooool00ol0003oooooooooo`28ooooo`;o00000_oooolIo`0000[ooooo1_l000000ooooooo0000
o`000003ooooo`;o0000R_ooool001kooooo00?o0000ooooooooool0R?ooool3o`000003ooooool0
003o000000?o000000?oooooo`000?l000004_l00004ooooo`;o000000?oooooo`000?l000002?l0
0002ooooo`?o0000Roooool001kooooo00?o0000ooooooooool0Qoooool4o`0000Cooooo0_l00004
ooooo`Ko000000?oooooo`000?l000001Ol000000ooooooo0000o`000004ooooo`;o000000?ooooo
o`000?l000002?l00002ooooo`?o0000Roooool001kooooo00?o0000ooooooooool0Qoooool4o`00
0003ooooool0003o000000;o00001Oooool@o`0000Sooooo2?l000000ooooooo0000o`00002?oooo
o`007_ooool00ol0003oooooooooo`28ooooo`Wo00001?ooool@o`0000Sooooo0_l00007ooooo`;o
0000Soooool001kooooo00?o0000ooooooooool0ROooool4o`000003ooooool0003o000000?o0000
0oooool:o`0000gooooo1?l00003ooooo`Co0000Soooool001kooooo00?o0000ooooooooool0Qooo
ool6o`000003ooooool0003o000000Co00000_ooool:o`0000Kooooo0_l00002ooooo`?o00000_oo
ool2o`000003ooooool0003o000000;o0000TOooool001kooooo00?o0000ooooooooool0Qoooool2
o`000003ooooool0003o000000Go000000?oooooo`000?l000000_ooool6o`000003ooooool0003o
000000?o00001?ooool2o`0000;ooooo0ol00002ooooo`;o000000?oooooo`000?l000000_l0002A
ooooo`007_ooool00ol0003oooooooooo`2:ooooo`Oo000000?oooooo`000?l000000_ooool<o`00
00Gooooo0_l000000ooooooo0000o`000002o`000004ooooool0003o0000ooooo`?o0000T_ooool0
01kooooo00?o0000ooooooooool0QOooool2o`000004ooooool0003o0000ooooo`Wo00001Oooool:
o`000003ooooool0003o000000?o000000?oooooo`000?l000000_l00002ooooo`Oo0000T?ooool0
01kooooo00?o0000ooooooooool0QOooool2o`000003ooooool0003o000000?ooooo2?l00004oooo
o`Co000000?oooooo`000?l000001ol00002ooooo`Go00000_ooool7o`00093ooooo000Nooooo`03
o`000?oooooooooo08gooooo2Ol00003oooooa?o00000_ooool7o`0009;ooooo000Nooooo`03o`00
0?oooooooooo08kooooo2_l000000ooooooo0000o`00000Fo`0009Kooooo000Nooooo`;o0000Q_oo
ool2o`0000Wooooo7_l00003ooooo`;o0000U?ooool001kooooo00?o0000ooooooooool0QOooool2
o`0000cooooo6ol00003ooooo`;o0000U?ooool001kooooo00?o0000ooooooooool0QOooool2o`00
00cooooo1_l000000ooooooo0000o`000004o`000003ooooool0003o000000_o00000oooool2o`00
09Cooooo000Nooooo`03o`000?oooooooooo08Gooooo0_l00009ooooo`;o00000oooool3o`0000?o
oooo1_l00003ooooo`Co000000?oooooo`000?l000001?ooool4o`0009Cooooo000Nooooo`03o`00
0?oooooooooo08Cooooo0_l0000:ooooo`;o00002Oooool6o`0000?ooooo0_l00005ooooo`So0000
U?ooool001kooooo00?o0000ooooooooool0Q?ooool2o`0002Gooooo1?l0002Hooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0Yoooool2o`0009kooooo000Nooooo`03o`000?oooooooooo0:Oooooo
0_l0002Nooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So
8B4Q00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000oooooom8ooooo`000oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05oa0@
4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00So
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?oooooo
BOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03
o`000?oooooooooo0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0oooooom8oooo
o`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006
ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8b
oiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003ooooo
ooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zj
oooooonj^[[o410@00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo
0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000
oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Dooooo`Co000000?o410@ooooooooool0
0oooool00ol0003oooooooooo`3oooooodSooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0oooooom8ooooo`005_ooool00ol0003oooooooooo`05ooooo`?o0000oooooom8
ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?oo
ooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003ooooooooo
o`3ooooooe3ooooo000Dooooo`03oeEEEOmVIVKo00000?ooooooD_ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.5683 .50495 Mdot
.52706 .48433 Mdot
.43533 .4408 Mdot
.52357 .49439 Mdot
.51146 .5172 Mdot
.55948 .51855 Mdot
.44127 .47909 Mdot
.53104 .51035 Mdot
.4747 .56082 Mdot
.49967 .5647 Mdot
.55075 .5304 Mdot
.49332 .47528 Mdot
.55692 .51061 Mdot
.50936 .42548 Mdot
.46106 .5432 Mdot
.4816 .547 Mdot
.53973 .48973 Mdot
.57915 .54816 Mdot
.51514 .5698 Mdot
.46433 .46721 Mdot
.54137 .49198 Mdot
.47032 .52953 Mdot
.49206 .52567 Mdot
.56508 .47619 Mdot
.54365 .50276 Mdot
.48767 .48829 Mdot
.43508 .53051 Mdot
.53773 .5646 Mdot
.50721 .51133 Mdot
.56446 .50765 Mdot
.49474 .43917 Mdot
.53428 .49491 Mdot
.48958 .51363 Mdot
.43641 .46347 Mdot
.55914 .50951 Mdot
.44353 .44779 Mdot
.48488 .49984 Mdot
.43707 .53871 Mdot
.49876 .52558 Mdot
.48808 .47265 Mdot
.48431 .53942 Mdot
.45955 .48708 Mdot
.50432 .45555 Mdot
.49147 .49317 Mdot
.53723 .49907 Mdot
.47335 .52078 Mdot
.4869 .4285 Mdot
.4936 .43027 Mdot
.46954 .44325 Mdot
.55876 .52495 Mdot
.50299 .52349 Mdot
.54549 .48591 Mdot
.50764 .50694 Mdot
.50962 .51873 Mdot
.48501 .55308 Mdot
.47731 .49237 Mdot
.49602 .45836 Mdot
.51789 .46007 Mdot
.531 .5046 Mdot
.4936 .45571 Mdot
.46745 .51461 Mdot
.47751 .51495 Mdot
.44609 .46598 Mdot
.48273 .54702 Mdot
.49549 .52652 Mdot
.50932 .55028 Mdot
.5267 .45602 Mdot
.47135 .50961 Mdot
.47802 .4748 Mdot
.48003 .54635 Mdot
.42748 .50342 Mdot
.52298 .50636 Mdot
.48573 .45601 Mdot
.50554 .49301 Mdot
.5671 .49425 Mdot
.42811 .51732 Mdot
.47373 .48903 Mdot
.58111 .53776 Mdot
.42604 .49037 Mdot
.53246 .54526 Mdot
.43216 .52446 Mdot
.53437 .50927 Mdot
.54044 .4998 Mdot
.47928 .53176 Mdot
.44197 .46569 Mdot
.5061 .49812 Mdot
.42116 .48743 Mdot
.47467 .50847 Mdot
.48938 .46801 Mdot
.57831 .50303 Mdot
.49947 .51543 Mdot
.47304 .52885 Mdot
.42791 .51198 Mdot
.54139 .53467 Mdot
.42919 .4535 Mdot
.46904 .50426 Mdot
.47454 .50272 Mdot
.5031 .43808 Mdot
.48221 .42923 Mdot
.50325 .46193 Mdot
.42277 .49528 Mdot
.42645 .5047 Mdot
.52541 .51052 Mdot
.5355 .5587 Mdot
.46394 .55405 Mdot
.48919 .51319 Mdot
.42273 .52048 Mdot
.49837 .52232 Mdot
.52509 .46321 Mdot
.4724 .52995 Mdot
.56756 .48159 Mdot
.52391 .50514 Mdot
.50856 .47833 Mdot
.46172 .56361 Mdot
.53674 .45745 Mdot
.55361 .49882 Mdot
.43523 .53796 Mdot
.54231 .56624 Mdot
.46483 .42315 Mdot
.42812 .51508 Mdot
.57401 .52499 Mdot
.49002 .48781 Mdot
.4968 .56386 Mdot
.48168 .44059 Mdot
.53458 .48653 Mdot
.467 .56846 Mdot
.56876 .48418 Mdot
.48909 .48885 Mdot
.49107 .49278 Mdot
.48898 .54851 Mdot
.56001 .53325 Mdot
.54086 .48163 Mdot
.5306 .46134 Mdot
.4555 .44862 Mdot
.51514 .5119 Mdot
.52502 .4533 Mdot
.50956 .58503 Mdot
.49407 .50363 Mdot
.48023 .46184 Mdot
.50065 .48245 Mdot
.49908 .51969 Mdot
.45437 .55197 Mdot
.49075 .50023 Mdot
.51937 .49976 Mdot
.4879 .52427 Mdot
.47088 .52835 Mdot
.5693 .50793 Mdot
.47097 .50372 Mdot
.53641 .45494 Mdot
.47787 .44389 Mdot
.45036 .45808 Mdot
.54159 .56224 Mdot
.50516 .51849 Mdot
.52366 .43064 Mdot
.55874 .53313 Mdot
.48136 .54702 Mdot
.47908 .51829 Mdot
.55035 .47909 Mdot
.47414 .48792 Mdot
.48979 .5228 Mdot
.43884 .52559 Mdot
.47202 .48315 Mdot
.57932 .52342 Mdot
.48314 .54889 Mdot
.49133 .46344 Mdot
.5029 .46836 Mdot
.45588 .54923 Mdot
.44094 .53093 Mdot
.4647 .51668 Mdot
.44814 .55279 Mdot
.54123 .55796 Mdot
.48459 .44574 Mdot
.52528 .47779 Mdot
.48901 .46291 Mdot
.44655 .52543 Mdot
.47991 .49999 Mdot
.47003 .50997 Mdot
.4901 .52542 Mdot
.50982 .43384 Mdot
.46849 .44609 Mdot
.52058 .49578 Mdot
.4686 .50889 Mdot
.49942 .49537 Mdot
.5089 .50753 Mdot
.55609 .50697 Mdot
.49596 .47577 Mdot
.42172 .4685 Mdot
.467 .51191 Mdot
.53147 .54247 Mdot
.42674 .51489 Mdot
.49552 .48588 Mdot
.49269 .5474 Mdot
.56291 .47058 Mdot
.50262 .52006 Mdot
.44366 .54724 Mdot
.48867 .53871 Mdot
.56289 .5197 Mdot
.49011 .5039 Mdot
.49017 .52997 Mdot
.5225 .48918 Mdot
.50997 .46537 Mdot
.46994 .50675 Mdot
.56744 .53066 Mdot
.44899 .51946 Mdot
.48926 .55629 Mdot
.52288 .47474 Mdot
.54321 .48492 Mdot
.50175 .45899 Mdot
.42949 .46143 Mdot
.50414 .521 Mdot
.53815 .49806 Mdot
.48757 .49897 Mdot
.48424 .47094 Mdot
.56933 .52205 Mdot
.49004 .48729 Mdot
.49412 .428 Mdot
.47199 .52449 Mdot
.47606 .48452 Mdot
.45459 .55255 Mdot
.49501 .5218 Mdot
.48724 .54406 Mdot
.52644 .46616 Mdot
.47131 .52743 Mdot
.53698 .4409 Mdot
.53345 .51751 Mdot
.52998 .50902 Mdot
.53114 .49713 Mdot
.49623 .56388 Mdot
.42421 .46181 Mdot
.52302 .53676 Mdot
.48994 .54914 Mdot
.48876 .49781 Mdot
.45368 .55757 Mdot
.48268 .514 Mdot
.48347 .49088 Mdot
.47995 .46042 Mdot
.45958 .56329 Mdot
.42502 .5126 Mdot
.53311 .4773 Mdot
.4959 .47568 Mdot
.4973 .56469 Mdot
.45387 .5396 Mdot
.57183 .49835 Mdot
.46116 .56444 Mdot
.44342 .43965 Mdot
.4821 .54999 Mdot
.4302 .51975 Mdot
.52738 .51041 Mdot
.48831 .55193 Mdot
.43826 .54014 Mdot
.50415 .45621 Mdot
.55654 .50651 Mdot
.44506 .53638 Mdot
.43653 .44514 Mdot
.50712 .48261 Mdot
.49711 .46952 Mdot
.48891 .5376 Mdot
.48015 .47938 Mdot
.43938 .46652 Mdot
.44457 .54285 Mdot
.43879 .52707 Mdot
.49214 .54369 Mdot
.48949 .52267 Mdot
.56965 .52597 Mdot
.462 .46179 Mdot
.44961 .4682 Mdot
.51218 .53291 Mdot
.5599 .55134 Mdot
.48847 .53324 Mdot
.51026 .4362 Mdot
.52187 .45974 Mdot
.50829 .4779 Mdot
.52849 .54262 Mdot
.5037 .4803 Mdot
.42391 .45657 Mdot
.42809 .5165 Mdot
.47429 .49256 Mdot
.51054 .56808 Mdot
.46801 .46675 Mdot
.5095 .5621 Mdot
.47893 .46704 Mdot
.48434 .48431 Mdot
.49599 .42215 Mdot
.48857 .5127 Mdot
.44296 .54612 Mdot
.54784 .53165 Mdot
.50145 .42958 Mdot
.48579 .5362 Mdot
.53097 .47862 Mdot
.52955 .43357 Mdot
.49397 .46615 Mdot
.53292 .44674 Mdot
.55746 .50163 Mdot
.49633 .45072 Mdot
.50322 .4685 Mdot
.51551 .51518 Mdot
.54506 .56075 Mdot
.46736 .44804 Mdot
.45226 .49342 Mdot
.52434 .49563 Mdot
.48983 .49986 Mdot
.52987 .50914 Mdot
.47303 .55572 Mdot
.47256 .53795 Mdot
.49433 .47052 Mdot
.52329 .49597 Mdot
.47919 .44634 Mdot
.55357 .46113 Mdot
.5468 .50171 Mdot
.46471 .45802 Mdot
.51571 .49211 Mdot
.48859 .51319 Mdot
.50024 .54928 Mdot
.55861 .50578 Mdot
.52116 .48455 Mdot
.53761 .45221 Mdot
.48722 .47367 Mdot
.47275 .50923 Mdot
.48438 .45791 Mdot
.4404 .54294 Mdot
.47272 .44573 Mdot
.55528 .53012 Mdot
.55794 .53306 Mdot
.4786 .4973 Mdot
.53552 .56358 Mdot
.45262 .55433 Mdot
.49368 .48859 Mdot
.4912 .49117 Mdot
.48156 .56883 Mdot
.4299 .50432 Mdot
.57025 .50651 Mdot
.55195 .4938 Mdot
.5084 .47652 Mdot
.50186 .56523 Mdot
.43242 .459 Mdot
.49943 .55536 Mdot
.45324 .45554 Mdot
.52373 .50076 Mdot
.55513 .52227 Mdot
.47708 .51226 Mdot
.52318 .45402 Mdot
.54507 .45607 Mdot
.44236 .47751 Mdot
.49047 .50389 Mdot
.45818 .5414 Mdot
.5359 .46364 Mdot
.48888 .51124 Mdot
.52463 .5123 Mdot
.43861 .52906 Mdot
.47916 .53202 Mdot
.49489 .46148 Mdot
.53245 .46447 Mdot
.54032 .49393 Mdot
.48277 .50791 Mdot
.56668 .50829 Mdot
.49901 .46541 Mdot
.52534 .42732 Mdot
.53741 .47567 Mdot
.56449 .49859 Mdot
.48919 .51574 Mdot
.49321 .52862 Mdot
.53817 .44974 Mdot
.50475 .47211 Mdot
.53335 .43052 Mdot
.53679 .47156 Mdot
.4903 .42022 Mdot
.45877 .42571 Mdot
.44407 .53326 Mdot
.48865 .44297 Mdot
.50445 .49897 Mdot
.49016 .523 Mdot
.495 .50812 Mdot
.53394 .46876 Mdot
.53622 .52381 Mdot
.45225 .42982 Mdot
.49402 .56104 Mdot
.52786 .52912 Mdot
.42236 .5009 Mdot
.46396 .47943 Mdot
.48697 .49543 Mdot
.46049 .45437 Mdot
.42892 .46667 Mdot
.51793 .50511 Mdot
.54938 .45926 Mdot
.53166 .49942 Mdot
.55901 .52504 Mdot
.53927 .56366 Mdot
.49578 .55333 Mdot
.4794 .48905 Mdot
.46378 .4524 Mdot
.50381 .4484 Mdot
.47006 .4738 Mdot
.47154 .44623 Mdot
.53462 .49584 Mdot
.48803 .53099 Mdot
.53282 .50844 Mdot
.47527 .53771 Mdot
.48882 .51507 Mdot
.5358 .56442 Mdot
.50623 .44587 Mdot
.49668 .44343 Mdot
.45882 .44992 Mdot
.48041 .44936 Mdot
.48486 .48289 Mdot
.47454 .44758 Mdot
.45231 .44529 Mdot
.51127 .5062 Mdot
.49254 .52221 Mdot
.51039 .46287 Mdot
.53185 .55318 Mdot
.49841 .48081 Mdot
.51924 .56621 Mdot
.5043 .49455 Mdot
.49104 .43185 Mdot
.50166 .49895 Mdot
.42605 .5054 Mdot
.47255 .53385 Mdot
.55733 .46202 Mdot
.49392 .45226 Mdot
.49449 .56297 Mdot
.51337 .56313 Mdot
.47239 .51832 Mdot
.4993 .49414 Mdot
.50708 .56422 Mdot
.49801 .4489 Mdot
.44967 .45168 Mdot
.45862 .54487 Mdot
.48662 .53425 Mdot
.47566 .46363 Mdot
.48399 .47272 Mdot
.53873 .44279 Mdot
.47954 .5458 Mdot
.54521 .48008 Mdot
.51524 .56176 Mdot
.45791 .52219 Mdot
.56015 .46847 Mdot
.46277 .52028 Mdot
.4949 .45795 Mdot
.5445 .44836 Mdot
.48969 .46263 Mdot
.49451 .44882 Mdot
.56865 .49818 Mdot
.52928 .43815 Mdot
.56704 .52789 Mdot
.48898 .5144 Mdot
.55591 .54541 Mdot
.5165 .51046 Mdot
.48855 .55424 Mdot
.43571 .46072 Mdot
.50221 .51456 Mdot
.48178 .421 Mdot
.49782 .47667 Mdot
.48162 .53675 Mdot
.48857 .46373 Mdot
.43406 .49221 Mdot
.47151 .56404 Mdot
.45232 .45738 Mdot
.43543 .53739 Mdot
.4921 .51681 Mdot
.48212 .47585 Mdot
.44805 .51063 Mdot
.50898 .48991 Mdot
.4869 .42616 Mdot
.48397 .51374 Mdot
.47804 .44714 Mdot
.5242 .44151 Mdot
.48349 .52523 Mdot
.49897 .49081 Mdot
.528 .44837 Mdot
.47997 .47838 Mdot
.56151 .52507 Mdot
.50305 .55781 Mdot
.44475 .51289 Mdot
.49127 .55555 Mdot
.52853 .56623 Mdot
.4705 .56145 Mdot
.46933 .43692 Mdot
.49792 .55745 Mdot
.42245 .49638 Mdot
.5326 .45787 Mdot
.48884 .51161 Mdot
.54012 .49472 Mdot
.53152 .50985 Mdot
.53171 .50734 Mdot
.47118 .51764 Mdot
.45103 .5119 Mdot
.50365 .56338 Mdot
.56915 .50377 Mdot
.47958 .4461 Mdot
.42283 .50307 Mdot
.55286 .49232 Mdot
.42539 .46314 Mdot
.50038 .55972 Mdot
.49058 .52855 Mdot
.50377 .45759 Mdot
.56417 .50764 Mdot
.44716 .5504 Mdot
.48862 .52867 Mdot
.45409 .50358 Mdot
.54035 .50698 Mdot
.43333 .49342 Mdot
.44815 .53932 Mdot
.44516 .48263 Mdot
.49566 .55247 Mdot
.49682 .475 Mdot
.50738 .56573 Mdot
.56077 .48836 Mdot
.49851 .55657 Mdot
.41746 .48612 Mdot
.55403 .52891 Mdot
.47055 .47344 Mdot
.44419 .46282 Mdot
.50832 .45857 Mdot
.56104 .51587 Mdot
.53437 .50841 Mdot
.47867 .54363 Mdot
.50641 .45781 Mdot
.5591 .51114 Mdot
.48548 .42077 Mdot
.55725 .51102 Mdot
.49071 .55408 Mdot
.52474 .45946 Mdot
.55042 .50446 Mdot
.48634 .49048 Mdot
.49974 .46842 Mdot
.47498 .5005 Mdot
.46209 .4462 Mdot
.54726 .48789 Mdot
.54784 .54894 Mdot
.52459 .56619 Mdot
.44385 .49014 Mdot
.47072 .52834 Mdot
.47509 .49099 Mdot
.50875 .48868 Mdot
.52651 .54749 Mdot
.49326 .47958 Mdot
.55618 .47028 Mdot
.4707 .51227 Mdot
.49849 .45775 Mdot
.51098 .56832 Mdot
.50666 .48106 Mdot
.58323 .51969 Mdot
.47101 .53252 Mdot
.55699 .46751 Mdot
.55292 .53662 Mdot
.43663 .52715 Mdot
.51642 .50414 Mdot
.58512 .51835 Mdot
.52336 .50847 Mdot
.51304 .55471 Mdot
.48999 .46841 Mdot
.50841 .5154 Mdot
.48846 .51969 Mdot
.44394 .48377 Mdot
.52725 .50195 Mdot
.48863 .54378 Mdot
.49558 .5158 Mdot
.48072 .44997 Mdot
.55658 .49522 Mdot
.43134 .52528 Mdot
.42803 .50505 Mdot
.43219 .47161 Mdot
.49126 .55745 Mdot
.50462 .50335 Mdot
.45855 .47676 Mdot
.48968 .5382 Mdot
.44646 .49197 Mdot
.50927 .56192 Mdot
.55257 .4634 Mdot
.47057 .43892 Mdot
.51138 .4363 Mdot
.48878 .49313 Mdot
.48606 .45032 Mdot
.52326 .51169 Mdot
.4968 .47753 Mdot
.48083 .54121 Mdot
.58273 .51231 Mdot
.48959 .46963 Mdot
.42454 .51105 Mdot
.48991 .48065 Mdot
.41952 .46467 Mdot
.52137 .5067 Mdot
.43606 .49233 Mdot
.51401 .46582 Mdot
.47357 .48352 Mdot
.48706 .43291 Mdot
.51846 .51077 Mdot
.53003 .46321 Mdot
.53883 .46457 Mdot
.44556 .47083 Mdot
.49616 .47386 Mdot
.47511 .52589 Mdot
.4882 .53124 Mdot
.49336 .48535 Mdot
.48956 .55318 Mdot
.57076 .50465 Mdot
.55585 .46224 Mdot
.47078 .51304 Mdot
.5788 .52453 Mdot
.52509 .48093 Mdot
.44708 .52637 Mdot
.4787 .53687 Mdot
.56549 .51338 Mdot
.57059 .51337 Mdot
.47511 .52736 Mdot
.5184 .45999 Mdot
.49699 .55255 Mdot
.46682 .421 Mdot
.47813 .51401 Mdot
.49149 .48907 Mdot
.55166 .5633 Mdot
.56936 .48744 Mdot
.49299 .53042 Mdot
.48525 .43066 Mdot
.56979 .5014 Mdot
.509 .51498 Mdot
.49396 .52877 Mdot
.48647 .55497 Mdot
.4957 .52599 Mdot
.4498 .5342 Mdot
.43877 .4803 Mdot
.54079 .48059 Mdot
.51139 .48283 Mdot
.47917 .51741 Mdot
.45337 .43178 Mdot
.46364 .45489 Mdot
.50336 .51719 Mdot
.49361 .51282 Mdot
.52457 .4521 Mdot
.53006 .47907 Mdot
.46875 .51387 Mdot
.4848 .55125 Mdot
.47535 .44219 Mdot
.58496 .52253 Mdot
.58421 .51725 Mdot
.55247 .52345 Mdot
.42628 .51428 Mdot
.49873 .48786 Mdot
.52825 .50787 Mdot
.50217 .42941 Mdot
.52368 .512 Mdot
.47383 .49036 Mdot
.46552 .42251 Mdot
.48641 .53151 Mdot
.49142 .55061 Mdot
.57117 .51771 Mdot
.56805 .51078 Mdot
.48642 .51632 Mdot
.43953 .46495 Mdot
.43142 .48287 Mdot
.55022 .50683 Mdot
.48816 .52022 Mdot
.48899 .50443 Mdot
.52498 .4635 Mdot
.50919 .47124 Mdot
.50159 .45453 Mdot
.50486 .5485 Mdot
.49698 .48718 Mdot
.45071 .48102 Mdot
.49309 .48441 Mdot
.52436 .50841 Mdot
.48884 .52307 Mdot
.53418 .43128 Mdot
.50642 .45209 Mdot
.44761 .46896 Mdot
.44895 .4592 Mdot
.44687 .54209 Mdot
.47458 .44753 Mdot
.57073 .48915 Mdot
.49284 .54733 Mdot
.52994 .48213 Mdot
.51082 .45437 Mdot
.49113 .44404 Mdot
.48224 .53666 Mdot
.49378 .55012 Mdot
.50316 .56241 Mdot
.47958 .45572 Mdot
.53662 .50024 Mdot
.54521 .56032 Mdot
.51656 .51461 Mdot
.46756 .51473 Mdot
.42844 .50562 Mdot
.5263 .47107 Mdot
.42964 .51496 Mdot
.53791 .49323 Mdot
.4694 .5047 Mdot
.53297 .48481 Mdot
.55718 .50831 Mdot
.48643 .46303 Mdot
.47187 .45902 Mdot
.47102 .49545 Mdot
.44033 .44545 Mdot
.54002 .47952 Mdot
.4817 .49073 Mdot
.47257 .4487 Mdot
.55373 .49135 Mdot
.4287 .50749 Mdot
.49037 .49876 Mdot
.4731 .53236 Mdot
.52448 .49741 Mdot
.50465 .51513 Mdot
.49261 .47967 Mdot
.50065 .42462 Mdot
.49604 .52616 Mdot
.4601 .42311 Mdot
.43419 .49565 Mdot
.47596 .50241 Mdot
.50478 .52192 Mdot
.43827 .47438 Mdot
.50773 .56434 Mdot
.5031 .56646 Mdot
.49198 .48757 Mdot
.42984 .48195 Mdot
.53259 .57008 Mdot
.53208 .43351 Mdot
.43441 .52928 Mdot
.52735 .5724 Mdot
.54775 .47993 Mdot
.55975 .52118 Mdot
.54828 .55899 Mdot
.50892 .49811 Mdot
.5308 .55773 Mdot
.47674 .46022 Mdot
.51021 .49162 Mdot
.56659 .48618 Mdot
.49806 .46216 Mdot
.58136 .51727 Mdot
.56984 .52071 Mdot
.55602 .46996 Mdot
.47031 .49815 Mdot
.55889 .5328 Mdot
.47973 .53518 Mdot
.49652 .46365 Mdot
.48081 .52353 Mdot
.55114 .49369 Mdot
.43512 .48333 Mdot
.48257 .4954 Mdot
.47122 .51945 Mdot
.51605 .56805 Mdot
.47765 .48312 Mdot
.47309 .52287 Mdot
.55575 .50041 Mdot
.48274 .48745 Mdot
.54433 .50742 Mdot
.48812 .5363 Mdot
.50838 .52052 Mdot
.49138 .5278 Mdot
.4756 .50864 Mdot
.49099 .49425 Mdot
.56442 .52406 Mdot
.46249 .4453 Mdot
.49033 .51738 Mdot
.492 .4586 Mdot
.50924 .51949 Mdot
.49311 .55212 Mdot
.54529 .44904 Mdot
.45361 .55137 Mdot
.49509 .56222 Mdot
.49745 .44127 Mdot
.51007 .56025 Mdot
.56173 .5178 Mdot
.55931 .52363 Mdot
.51055 .55936 Mdot
.46837 .48212 Mdot
.58143 .5152 Mdot
.50683 .4871 Mdot
.5471 .45926 Mdot
.51537 .50444 Mdot
.49208 .49064 Mdot
.4487 .44329 Mdot
.56333 .52906 Mdot
.50012 .43754 Mdot
.56153 .50692 Mdot
.50292 .50062 Mdot
.43784 .4536 Mdot
.43032 .52208 Mdot
.47831 .54792 Mdot
.55118 .50265 Mdot
.50177 .48935 Mdot
.48084 .47483 Mdot
.49645 .55103 Mdot
.53397 .46214 Mdot
.56063 .5132 Mdot
.55937 .49127 Mdot
.5042 .45132 Mdot
.42817 .51616 Mdot
.51454 .47254 Mdot
.4868 .54351 Mdot
.54024 .56235 Mdot
.46464 .50141 Mdot
.52149 .48614 Mdot
.5686 .53408 Mdot
.51519 .4957 Mdot
.43473 .53599 Mdot
.52455 .46518 Mdot
.45523 .5466 Mdot
.51673 .45736 Mdot
.43716 .49431 Mdot
.49046 .55532 Mdot
.4618 .44308 Mdot
.49128 .54268 Mdot
.49988 .45891 Mdot
.41774 .48831 Mdot
.50838 .54802 Mdot
.56745 .5039 Mdot
.48711 .55002 Mdot
.4929 .46373 Mdot
.54058 .50692 Mdot
.53949 .49824 Mdot
.56742 .54737 Mdot
.5162 .50353 Mdot
.43612 .52703 Mdot
.51479 .49928 Mdot
.56133 .53008 Mdot
.4911 .55713 Mdot
.50229 .4546 Mdot
.46803 .50457 Mdot
.4985 .46024 Mdot
.55777 .49698 Mdot
.48501 .44136 Mdot
.48465 .52311 Mdot
.50911 .4832 Mdot
.42956 .51797 Mdot
.5125 .56831 Mdot
.56129 .49733 Mdot
.53384 .56855 Mdot
.49387 .5279 Mdot
.53059 .47539 Mdot
.52535 .46672 Mdot
.4823 .48743 Mdot
.45133 .46461 Mdot
.5213 .4538 Mdot
.46549 .42026 Mdot
.47309 .51509 Mdot
.48942 .4985 Mdot
.49379 .54999 Mdot
.45847 .4828 Mdot
.5354 .54471 Mdot
.51335 .4846 Mdot
.44204 .54504 Mdot
.56874 .50076 Mdot
.47302 .52405 Mdot
.46801 .50634 Mdot
.43949 .52032 Mdot
.42834 .48812 Mdot
.4365 .49339 Mdot
.49441 .54689 Mdot
.45723 .48028 Mdot
.47135 .52153 Mdot
.48454 .45646 Mdot
.53426 .48256 Mdot
.57457 .51378 Mdot
.49367 .42683 Mdot
.48814 .44446 Mdot
.45118 .52801 Mdot
.49799 .47673 Mdot
.48929 .52687 Mdot
.56338 .5157 Mdot
.49952 .49211 Mdot
.50051 .52141 Mdot
.43405 .48309 Mdot
.49814 .47618 Mdot
.48843 .5149 Mdot
.42906 .51662 Mdot
.55091 .5563 Mdot
.42979 .46919 Mdot
.52045 .47502 Mdot
.55699 .55388 Mdot
.52468 .48422 Mdot
.52815 .46732 Mdot
.56236 .54164 Mdot
.44318 .54632 Mdot
.47957 .42552 Mdot
.57062 .50498 Mdot
.55542 .4859 Mdot
.50362 .49928 Mdot
.50626 .52019 Mdot
.47403 .52932 Mdot
.49024 .4681 Mdot
.5479 .48862 Mdot
.45134 .46206 Mdot
.53426 .4687 Mdot
.53488 .45614 Mdot
.50392 .50837 Mdot
.5785 .50756 Mdot
.53292 .50506 Mdot
.48619 .46612 Mdot
.48119 .54313 Mdot
.42067 .50375 Mdot
.54128 .4727 Mdot
.47151 .49292 Mdot
.49009 .50555 Mdot
.41747 .48406 Mdot
.51473 .55901 Mdot
.48805 .52868 Mdot
.53037 .54891 Mdot
.51206 .51197 Mdot
.52074 .4642 Mdot
.5052 .47757 Mdot
.51051 .47544 Mdot
.56317 .53133 Mdot
.50961 .46522 Mdot
.53975 .47683 Mdot
.52272 .48367 Mdot
.48735 .57774 Mdot
.50927 .49924 Mdot
.42069 .50228 Mdot
.48193 .45949 Mdot
.51539 .51513 Mdot
.53531 .45041 Mdot
.44624 .48149 Mdot
.4414 .52204 Mdot
.50087 .47468 Mdot
.49293 .5287 Mdot
.53301 .48846 Mdot
.49086 .47741 Mdot
.42893 .49881 Mdot
.4494 .45932 Mdot
.56876 .48392 Mdot
.43323 .53202 Mdot
.47652 .52593 Mdot
.49073 .49531 Mdot
.52127 .42559 Mdot
.43535 .49648 Mdot
.4453 .53891 Mdot
.51151 .49263 Mdot
.51333 .51658 Mdot
.4934 .4708 Mdot
.49239 .547 Mdot
.50994 .50381 Mdot
.51266 .47065 Mdot
.45437 .49654 Mdot
.48434 .55758 Mdot
.53438 .48009 Mdot
.49751 .49193 Mdot
.56455 .5182 Mdot
.47851 .51589 Mdot
.45936 .45565 Mdot
.43646 .5347 Mdot
.43203 .52189 Mdot
.5517 .48789 Mdot
.54415 .50299 Mdot
.47495 .44553 Mdot
.51136 .49487 Mdot
.46938 .5028 Mdot
.57137 .49689 Mdot
.51127 .44372 Mdot
.50054 .42793 Mdot
.49021 .45152 Mdot
.55212 .46103 Mdot
.53642 .56538 Mdot
.50209 .48133 Mdot
.5857 .5302 Mdot
.53132 .47285 Mdot
.5197 .49388 Mdot
.55779 .55266 Mdot
.42533 .50277 Mdot
.47499 .53828 Mdot
.47656 .44624 Mdot
.45638 .5378 Mdot
.43469 .51226 Mdot
.50054 .49827 Mdot
.47364 .52548 Mdot
.48805 .50121 Mdot
.48522 .5223 Mdot
.49672 .45008 Mdot
.42163 .46362 Mdot
.51238 .46747 Mdot
.48014 .53687 Mdot
.42945 .52211 Mdot
.45338 .47238 Mdot
.56467 .4783 Mdot
.55141 .49354 Mdot
.44482 .53501 Mdot
.48891 .44295 Mdot
.47816 .54409 Mdot
.42554 .51462 Mdot
.49927 .49679 Mdot
.48585 .48355 Mdot
.58072 .54375 Mdot
.57342 .50305 Mdot
.49357 .52102 Mdot
.52914 .5092 Mdot
.52904 .51029 Mdot
.52885 .44533 Mdot
.46683 .42173 Mdot
.56291 .48662 Mdot
.5139 .47835 Mdot
.47255 .53744 Mdot
.49829 .55519 Mdot
.56829 .50539 Mdot
.49246 .5295 Mdot
.55264 .46304 Mdot
.50776 .56121 Mdot
.49516 .55863 Mdot
.469 .50555 Mdot
.42876 .5181 Mdot
.42297 .45741 Mdot
.43447 .51239 Mdot
.58408 .51736 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go
00001_ooool3o`000?ooooooB?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04
odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol0003o
oooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`3o
ooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007
ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<
ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0Toooool3o`0000?ooooo1_l0002Xooooo`007_ooool00ol0003oooooooooo`2Aooooo`Go0000
0_ooool;o`0000;ooooo0_l0002Pooooo`007_ooool00ol0003oooooooooo`2Aooooo`Co00000ooo
ool;o`0000;ooooo1?l0002Nooooo`007_ooool00ol0003oooooooooo`2?ooooo`;o00002?ooool8
o`0000Gooooo1_l0002Kooooo`007_ooool00ol0003oooooooooo`2?ooooo`;o00002?ooool5o`00
0004ooooool0003o0000ooooo`;o00000_ooool6o`0009_ooooo000Nooooo`03o`000?oooooooooo
09Cooooo0_l00004ooooo`;o00000_ooool3o`000003ooooool0003o000000Cooooo0ol0002Loooo
o`007_ooool00ol0003oooooooooo`29ooooo`;o000000?oooooo`000?l000001_ooool3o`000003
ooooool0003o000000?ooooo1?l000000ooooooo0000o`000004ooooo`Co0000Voooool001kooooo
00?o0000ooooooooool0ROooool2o`000003ooooool0003o000000;o00000_ooool2o`000003oooo
ool0003o000000Wo00000_ooool2o`0000;ooooo0_l00002ooooo`?o0000V_ooool001kooooo00?o
0000ooooooooool0R_ooool3o`000005ooooool0003o0000o`000?ooool03Ol000000ooooooo0000
o`000002o`0000;ooooo1ol0002Jooooo`007_ooool00ol0003oooooooooo`2:ooooo`Co000000?o
ooooo`000?l000004Ol00006ooooo`Oo0000V?ooool001kooooo0_l00028ooooo`;o00000ooooolG
o`0000?ooooo2Ol0002Hooooo`007_ooool00ol0003oooooooooo`26ooooo`?o000000?oooooo`00
0?l000000_ooool7o`0000?ooooo3?l000000ooooooo0000o`000002o`000003ooooool0003o0000
00?o0000V?ooool001kooooo00?o0000ooooooooool0QOooool7o`0000;ooooo2Ol000000ooooooo
0000o`00000Bo`000004ooooool0003o0000o`0009Oooooo000Nooooo`03o`000?oooooooooo08Go
oooo1ol00002ooooo`?o000000?oooooo`000?l000003ol000000ooooooo0000o`000006o`0000;o
oooo1Ol0002Dooooo`007_ooool00ol0003oooooooooo`24ooooo`[o000000Coooooo`000?l0003o
oooo0_l00003ooooo`[o000000?oooooo`000?l000002Ol00002ooooo`Co0000U?ooool001kooooo
00?o0000ooooooooool0Q?ooool5o`000003ooooool0003o000000Go00000_ooool3o`000003oooo
ool0003o000000So000000?oooooo`000?l000002Ol00003ooooo`Co0000Toooool001kooooo00?o
0000ooooooooool0QOooool5o`000003ooooool0003o000000?o00000oooool3o`0000;ooooo3Ol0
0002ooooo`Go00001Oooool4o`0009;ooooo000Nooooo`03o`000?oooooooooo08Sooooo1?l00000
0ooooooo0000o`000002o`0000Cooooo6Ol00003ooooo`Co0000T_ooool001kooooo00?o0000oooo
ooooool0R_ooool4o`000003ooooool0003o000000;o00000_oooolIo`0000Kooooo0_l0002Aoooo
o`007_ooool00ol0003oooooooooo`2;ooooo`Go000000?oooooo`000?l000000_l00003ooooo`go
00000_ooool:o`0000;ooooo0ol0002Aooooo`007_ooool00ol0003oooooooooo`24ooooo`;o0000
0_ooool8o`000003ooooool0003o000001;o000000?oooooo`000?l000002Ol00002ooooo`Co0000
T?ooool001kooooo00?o0000ooooooooool0Q?ooool2o`0000;ooooo0ol000001?oooooo0000o`00
0?l00002ooooo`;o000000?oooooo`000?l000006Ol000001?oooooo0000o`000?ooool4o`00093o
oooo000Nooooo`03o`000?oooooooooo08Cooooo1Ol00003ooooo`;o00000oooool2o`0000?ooooo
4_l000000ooooooo0000o`00000<o`00093ooooo000Nooooo`03o`000?oooooooooo08Cooooo3Ol0
0004oooooa?o000000?oooooo`000?l000002Ol000000ooooooo0000o`00002@ooooo`007_ooool0
0ol0003oooooooooo`25ooooo`;o00000_ooool3o`000003ooooool0003o000000?o00000ooooolC
o`0000;ooooo1?l000000ooooooo0000o`000005o`00097ooooo000Nooooo`03o`000?oooooooooo
08Gooooo1ol00004ooooo`;o00000ooooolCo`000003ooooool0003o000000?o000000?oooooo`00
0?l000001ol0002?ooooo`007_ooool2o`0008Kooooo1?l0000:ooooo`[o000000?oooooo`000?l0
00006?l0002?ooooo`007_ooool00ol0003oooooooooo`25ooooo`Go00001_ooool2o`000003oooo
ool0003o000001ko000000?oooooo`000?l000001?l0002=ooooo`007_ooool00ol0003ooooooooo
o`25ooooo`Go00001_ooool2o`0000;ooooo2ol000000ooooooo0000o`00000Ho`0008gooooo000N
ooooo`03o`000?oooooooooo08Kooooo0ol00005ooooo`?o00000oooool;o`000003ooooool0003o
000001Go000000?oooooo`000?l00000SOooool001kooooo00?o0000ooooooooool0Q_ooool5o`00
0003ooooool0003o000000?o00000oooool:o`000003ooooool0003o000000_o00001Oooool:o`00
08cooooo000Nooooo`03o`000?oooooooooo08Kooooo1Ol000000ooooooo0000o`000005oooooaGo
000000?oooooo`000?l000001oooool:o`0008_ooooo000Nooooo`03o`000?oooooooooo08Gooooo
1Ol000001?oooooo0000o`000?ooool2o`0000;ooooo4ol00004ooooo`;o00001oooool6o`000004
ooooool0003o0000o`0008_ooooo000Nooooo`03o`000?oooooooooo08Gooooo0_l000001?oooooo
0000o`000?ooool2o`000004ooooool0003o0000ooooo`?o000000?oooooo`000?l000003Ol00006
ooooo`;o00000oooool8o`000003ooooool0003o000000;o0000Roooool001kooooo00?o0000oooo
ooooool0R?ooool7o`0000;ooooo0_l00002ooooo`go00002?ooool2o`0000?ooooo3Ol0002;oooo
o`007_ooool00ol0003oooooooooo`28ooooo`Wo00001?ooool;o`0000Oooooo0_l00006ooooo`go
0000Roooool001kooooo00?o0000ooooooooool0ROooool5o`000003ooooool0003o000000Cooooo
2Ol00004ooooo`;o00000oooool2o`0000Gooooo2?l00004ooooo`;o0000Roooool001kooooo00?o
0000ooooooooool0ROooool7o`0000Gooooo2?l00005ooooo`;o00002?ooool;o`00093ooooo000N
ooooo`03o`000?oooooooooo08Wooooo0ol000000ooooooo0000o`000003o`0000Cooooo1ol00009
ooooo`;o00001?ooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0008cooooo000Noooo
o`03o`000?oooooooooo08Wooooo0ol000000ooooooo0000o`000004o`0000?ooooo2?l00008oooo
o`Go00002?ooool2o`0000Cooooo0_l0002<ooooo`007_ooool00ol0003oooooooooo`2:ooooo`Go
00000_ooool3o`0000?ooooo1ol0000:ooooo`Co00001Oooool4o`0000Cooooo0_l0002<ooooo`00
7_ooool00ol0003oooooooooo`2;ooooo`?o00000_ooool4o`0000?ooooo2?l000001?oooooo0000
o`000?l00004ooooo`Go00001Oooool2o`000003ooooool0003o000000;ooooo0ol0002<ooooo`00
7_ooool2o`0008gooooo1_l00005ooooo`co00001?ooool3o`0000Cooooo0_l00002ooooo`Co0000
0_ooool2o`0008gooooo000Nooooo`03o`000?oooooooooo08gooooo1Ol000000ooooooo0000o`00
0004ooooo`co00001?ooool2o`0000?ooooo0_l000001?oooooo0000o`000?l0002Cooooo`007_oo
ool00ol0003oooooooooo`2>ooooo`Co000000Coooooo`000?l0003ooooo0_l000000ooooooo0000
o`000006o`0000;ooooo0_l00003ooooo`?o000000Coooooo`000?l0003ooooo1?l0002Dooooo`00
7_ooool00ol0003oooooooooo`2?ooooo`;o00001Oooool2o`000003ooooool0003o000000[o0000
0oooool9o`0009Kooooo000Nooooo`03o`000?oooooooooo097ooooo0ol000001?oooooo0000o`00
0?l00004ooooo`Wo00001Oooool7o`0009Kooooo000Nooooo`03o`000?oooooooooo097ooooo0ol0
00000ooooooo0000o`000006oooooa7o000000?oooooo`000?l00000U_ooool001kooooo00?o0000
ooooooooool0T_ooool4o`0000;ooooo0_l00004oooooa3o0000VOooool001kooooo00?o0000oooo
ooooool0U?ooool2o`0000;ooooo0_l00008ooooo`Co000000?oooooo`000?l000000_l0002Loooo
o`007_ooool00ol0003oooooooooo`2Wooooo`;o0000W_ooool001kooooo00?o0000ooooooooool0
V_ooool2o`000:_ooooo000Nooooo`03o`000?oooooooooo09[ooooo0_l0002[ooooo`007_ooool0
0ol0003oooooooooo`2Rooooo`;o0000Xoooool001kooooo00?o0000ooooooooool0X_ooool2o`00
0:?ooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000oooo
ooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`3oooooodSooooo0003oooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodSooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooo
oonHV9So8B4Q00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00So
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003o
ooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Q
o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0
003oooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0
003ooooooooooooooooo000000Kooooo0ol0003oooooodSooooo0003ooooo`05o`000?oooooooooo
ooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000ooooooooool0oooo
oom8ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000
olc<c006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooo
oa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`3oooooodSo
oooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o0000
00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o
0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001Cooooo
1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB?ooool001Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodSooooo000Fooooo`03o`000?oooooo
oooo00Gooooo0ol0003oooooodSooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Ko
oooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo
000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Cooooo00?oEEEEofIVI_l00000oooooomB
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.56377 .51964 Mdot
.53002 .50053 Mdot
.45137 .42375 Mdot
.51979 .50802 Mdot
.49866 .52422 Mdot
.56285 .54892 Mdot
.43766 .43827 Mdot
.51414 .52388 Mdot
.43974 .56589 Mdot
.47281 .55915 Mdot
.52842 .54233 Mdot
.5068 .47434 Mdot
.5672 .54196 Mdot
.53814 .42697 Mdot
.42326 .5209 Mdot
.46237 .53105 Mdot
.53999 .51068 Mdot
.5609 .57464 Mdot
.48633 .57312 Mdot
.48401 .44892 Mdot
.53958 .51436 Mdot
.46548 .50027 Mdot
.4733 .53495 Mdot
.58463 .49492 Mdot
.53065 .51979 Mdot
.49478 .48058 Mdot
.41346 .50797 Mdot
.50928 .57886 Mdot
.50044 .51719 Mdot
.5747 .53177 Mdot
.51822 .45014 Mdot
.5321 .51168 Mdot
.48452 .50473 Mdot
.4541 .44195 Mdot
.57039 .5377 Mdot
.46623 .43407 Mdot
.48591 .48902 Mdot
.42288 .52286 Mdot
.48222 .53319 Mdot
.50323 .46731 Mdot
.46669 .52611 Mdot
.47654 .46353 Mdot
.52624 .4687 Mdot
.49645 .49284 Mdot
.53381 .51616 Mdot
.46948 .50368 Mdot
.51878 .41607 Mdot
.51602 .43902 Mdot
.49731 .44234 Mdot
.52904 .56168 Mdot
.48873 .52931 Mdot
.56787 .52283 Mdot
.50286 .5137 Mdot
.49194 .52809 Mdot
.46223 .53877 Mdot
.48486 .4781 Mdot
.515 .46361 Mdot
.5552 .49276 Mdot
.52339 .51806 Mdot
.51432 .46024 Mdot
.46712 .49482 Mdot
.47395 .50067 Mdot
.4659 .44471 Mdot
.46341 .5318 Mdot
.48443 .52899 Mdot
.46832 .56797 Mdot
.54411 .47745 Mdot
.47354 .49304 Mdot
.49483 .45854 Mdot
.46066 .52953 Mdot
.41252 .46985 Mdot
.51252 .51687 Mdot
.50595 .45464 Mdot
.5079 .50228 Mdot
.58193 .51677 Mdot
.41548 .48621 Mdot
.48483 .47002 Mdot
.56369 .56739 Mdot
.41645 .4568 Mdot
.5051 .56348 Mdot
.4292 .50274 Mdot
.51686 .52258 Mdot
.5329 .52034 Mdot
.46675 .51703 Mdot
.46105 .44407 Mdot
.50574 .50642 Mdot
.42607 .4585 Mdot
.47634 .4937 Mdot
.5061 .46372 Mdot
.57472 .54299 Mdot
.49272 .51835 Mdot
.46536 .51009 Mdot
.42471 .48317 Mdot
.50502 .56506 Mdot
.43376 .42497 Mdot
.47024 .48031 Mdot
.47901 .48804 Mdot
.52526 .45166 Mdot
.51384 .41408 Mdot
.52054 .47158 Mdot
.4251 .46526 Mdot
.4286 .47568 Mdot
.51227 .52194 Mdot
.50706 .58728 Mdot
.42846 .55313 Mdot
.48254 .50282 Mdot
.44194 .47529 Mdot
.48819 .52503 Mdot
.54143 .48381 Mdot
.46421 .51093 Mdot
.57912 .50019 Mdot
.51411 .51603 Mdot
.51703 .48971 Mdot
.43649 .55997 Mdot
.55009 .48103 Mdot
.56604 .53633 Mdot
.41466 .52246 Mdot
.51361 .57915 Mdot
.48484 .41637 Mdot
.42234 .48709 Mdot
.55724 .55605 Mdot
.49744 .48205 Mdot
.47072 .5561 Mdot
.50809 .44637 Mdot
.53755 .50602 Mdot
.44589 .56167 Mdot
.58313 .50328 Mdot
.49583 .48215 Mdot
.49588 .48893 Mdot
.46691 .53675 Mdot
.53668 .55844 Mdot
.54393 .50531 Mdot
.57018 .47932 Mdot
.47958 .43672 Mdot
.48976 .52097 Mdot
.56545 .46633 Mdot
.4901 .5797 Mdot
.49392 .50587 Mdot
.49946 .45325 Mdot
.50894 .48919 Mdot
.4903 .52257 Mdot
.42367 .54613 Mdot
.49158 .49326 Mdot
.51402 .51101 Mdot
.4805 .51699 Mdot
.46315 .50878 Mdot
.56815 .52417 Mdot
.47623 .4766 Mdot
.55068 .47812 Mdot
.50571 .44693 Mdot
.47258 .4412 Mdot
.513 .57746 Mdot
.49524 .52342 Mdot
.54729 .44229 Mdot
.53608 .55526 Mdot
.46203 .53089 Mdot
.47276 .50445 Mdot
.57815 .50457 Mdot
.48572 .46907 Mdot
.48393 .52008 Mdot
.41405 .49389 Mdot
.48761 .46252 Mdot
.56557 .557 Mdot
.45818 .53351 Mdot
.50951 .46376 Mdot
.51669 .47682 Mdot
.42119 .54321 Mdot
.44236 .51057 Mdot
.47305 .48844 Mdot
.43151 .54088 Mdot
.51543 .57419 Mdot
.51149 .45091 Mdot
.53275 .49441 Mdot
.50749 .46138 Mdot
.41871 .49097 Mdot
.48346 .48748 Mdot
.46678 .48372 Mdot
.48285 .52394 Mdot
.54546 .42691 Mdot
.49426 .44022 Mdot
.51715 .50823 Mdot
.46528 .48562 Mdot
.50162 .50115 Mdot
.5035 .51459 Mdot
.56633 .54088 Mdot
.50867 .47758 Mdot
.43357 .44477 Mdot
.46681 .49168 Mdot
.49413 .56936 Mdot
.41998 .48548 Mdot
.50288 .48862 Mdot
.47563 .5392 Mdot
.58149 .48879 Mdot
.49256 .52421 Mdot
.42822 .53326 Mdot
.47124 .52667 Mdot
.53277 .55748 Mdot
.49018 .49824 Mdot
.47977 .53169 Mdot
.52275 .50322 Mdot
.52496 .47733 Mdot
.47367 .48885 Mdot
.5478 .55967 Mdot
.45851 .49556 Mdot
.46633 .54437 Mdot
.53289 .49121 Mdot
.54253 .50959 Mdot
.52108 .46814 Mdot
.4466 .44092 Mdot
.49281 .52576 Mdot
.53507 .51603 Mdot
.48862 .48951 Mdot
.50076 .46111 Mdot
.55889 .55373 Mdot
.49774 .48166 Mdot
.52592 .4171 Mdot
.46675 .50556 Mdot
.48843 .46696 Mdot
.42432 .54688 Mdot
.4873 .52296 Mdot
.4725 .54221 Mdot
.56279 .49524 Mdot
.46439 .50789 Mdot
.5677 .44936 Mdot
.50686 .52368 Mdot
.50811 .51958 Mdot
.52682 .51185 Mdot
.46881 .55642 Mdot
.43847 .44023 Mdot
.49306 .54955 Mdot
.46464 .52932 Mdot
.49026 .48912 Mdot
.42819 .55212 Mdot
.47639 .50133 Mdot
.48945 .47996 Mdot
.49955 .45221 Mdot
.43763 .55712 Mdot
.41546 .48062 Mdot
.5407 .49836 Mdot
.50868 .47742 Mdot
.46986 .55777 Mdot
.41983 .51519 Mdot
.57583 .51676 Mdot
.44114 .5566 Mdot
.453 .41122 Mdot
.46019 .53416 Mdot
.41436 .48885 Mdot
.50699 .52176 Mdot
.46073 .53771 Mdot
.41459 .52542 Mdot
.52567 .46836 Mdot
.56551 .54204 Mdot
.41569 .51473 Mdot
.44385 .41695 Mdot
.5141 .49349 Mdot
.51202 .47262 Mdot
.46811 .54392 Mdot
.49322 .46612 Mdot
.45721 .44409 Mdot
.41558 .52895 Mdot
.44192 .5063 Mdot
.47366 .53312 Mdot
.48371 .51965 Mdot
.55275 .55436 Mdot
.48345 .4445 Mdot
.46922 .44631 Mdot
.48222 .54356 Mdot
.53592 .57309 Mdot
.4738 .52088 Mdot
.54776 .43142 Mdot
.53984 .48059 Mdot
.51701 .48918 Mdot
.49009 .56869 Mdot
.51274 .48925 Mdot
.43645 .43498 Mdot
.41243 .48446 Mdot
.48286 .47576 Mdot
.4824 .56927 Mdot
.48745 .44993 Mdot
.48305 .56352 Mdot
.49733 .45502 Mdot
.49403 .47505 Mdot
.52097 .42282 Mdot
.48642 .50936 Mdot
.42266 .53343 Mdot
.51314 .56389 Mdot
.53461 .41976 Mdot
.46813 .54185 Mdot
.53815 .49835 Mdot
.55135 .44736 Mdot
.5106 .46734 Mdot
.55211 .46624 Mdot
.56556 .54043 Mdot
.52046 .46067 Mdot
.51689 .47719 Mdot
.49788 .52538 Mdot
.5186 .57759 Mdot
.49239 .43964 Mdot
.46844 .46906 Mdot
.51968 .50914 Mdot
.49276 .49867 Mdot
.5075 .51932 Mdot
.43532 .55849 Mdot
.45686 .51907 Mdot
.50956 .47085 Mdot
.51853 .50914 Mdot
.52828 .44255 Mdot
.56668 .48201 Mdot
.53367 .51815 Mdot
.48691 .44303 Mdot
.51572 .50429 Mdot
.48595 .50834 Mdot
.47439 .5555 Mdot
.54523 .51775 Mdot
.52456 .49868 Mdot
.54973 .47621 Mdot
.502 .46752 Mdot
.47475 .49329 Mdot
.50422 .45484 Mdot
.4272 .52767 Mdot
.49962 .4434 Mdot
.53634 .54132 Mdot
.54236 .54687 Mdot
.48363 .48435 Mdot
.50839 .5767 Mdot
.44017 .53977 Mdot
.50022 .48989 Mdot
.49665 .48724 Mdot
.4499 .57382 Mdot
.43454 .47749 Mdot
.57232 .52464 Mdot
.56979 .52895 Mdot
.51768 .48784 Mdot
.47469 .56126 Mdot
.45134 .43998 Mdot
.47781 .55385 Mdot
.47608 .44029 Mdot
.5161 .51257 Mdot
.53722 .52943 Mdot
.47532 .49805 Mdot
.54222 .4748 Mdot
.55491 .47938 Mdot
.46209 .43552 Mdot
.48972 .49646 Mdot
.45556 .51646 Mdot
.5481 .48747 Mdot
.48722 .50889 Mdot
.50785 .52394 Mdot
.44019 .50864 Mdot
.46658 .51719 Mdot
.51268 .46545 Mdot
.57046 .4857 Mdot
.53837 .51426 Mdot
.48004 .49567 Mdot
.5659 .54582 Mdot
.51461 .47174 Mdot
.55248 .43055 Mdot
.54448 .49882 Mdot
.56898 .5397 Mdot
.48159 .50515 Mdot
.48208 .53132 Mdot
.55115 .4726 Mdot
.51684 .48162 Mdot
.55757 .43874 Mdot
.54582 .4949 Mdot
.51437 .41819 Mdot
.4758 .40254 Mdot
.44466 .51245 Mdot
.53019 .42688 Mdot
.50403 .50646 Mdot
.48417 .52065 Mdot
.49257 .51035 Mdot
.56975 .49462 Mdot
.50738 .53214 Mdot
.47164 .41919 Mdot
.46924 .55195 Mdot
.49759 .53976 Mdot
.42056 .47008 Mdot
.48194 .45713 Mdot
.48982 .48593 Mdot
.48405 .44093 Mdot
.42887 .43467 Mdot
.50941 .51493 Mdot
.57786 .47576 Mdot
.52653 .51375 Mdot
.55744 .55122 Mdot
.51073 .57828 Mdot
.47527 .55339 Mdot
.48764 .47643 Mdot
.48799 .44065 Mdot
.55067 .45608 Mdot
.48855 .45446 Mdot
.49762 .44218 Mdot
.53205 .51247 Mdot
.47223 .53806 Mdot
.51936 .52347 Mdot
.45574 .51797 Mdot
.48475 .50782 Mdot
.50859 .57766 Mdot
.55164 .4515 Mdot
.54237 .44237 Mdot
.48283 .43812 Mdot
.53217 .45502 Mdot
.49521 .47417 Mdot
.5001 .44358 Mdot
.47695 .43463 Mdot
.50566 .51424 Mdot
.48598 .52193 Mdot
.52725 .47493 Mdot
.50525 .56931 Mdot
.50775 .48565 Mdot
.49119 .57188 Mdot
.50604 .50305 Mdot
.51403 .4399 Mdot
.50177 .50532 Mdot
.42692 .47595 Mdot
.46187 .51475 Mdot
.57642 .48038 Mdot
.51795 .45846 Mdot
.46823 .55425 Mdot
.4876 .56874 Mdot
.4701 .50105 Mdot
.50203 .49993 Mdot
.47864 .5636 Mdot
.54446 .47074 Mdot
.47302 .43743 Mdot
.42063 .53144 Mdot
.47103 .52144 Mdot
.49522 .45155 Mdot
.49963 .46297 Mdot
.55618 .46024 Mdot
.46045 .52883 Mdot
.54534 .50527 Mdot
.48933 .5698 Mdot
.46595 .49595 Mdot
.58097 .48643 Mdot
.47029 .49234 Mdot
.51421 .46247 Mdot
.56093 .46665 Mdot
.50827 .46208 Mdot
.51944 .45888 Mdot
.57125 .54181 Mdot
.55048 .45417 Mdot
.54921 .55469 Mdot
.4817 .50383 Mdot
.53229 .56846 Mdot
.50519 .51884 Mdot
.466 .54207 Mdot
.4541 .44043 Mdot
.49523 .51847 Mdot
.50642 .41035 Mdot
.50954 .48063 Mdot
.46592 .52235 Mdot
.50653 .46049 Mdot
.44491 .46335 Mdot
.44015 .56608 Mdot
.47481 .44113 Mdot
.42414 .52078 Mdot
.48769 .5165 Mdot
.49652 .46432 Mdot
.46018 .48617 Mdot
.51213 .50093 Mdot
.50942 .43086 Mdot
.47737 .50144 Mdot
.50462 .44724 Mdot
.56059 .44624 Mdot
.47161 .51192 Mdot
.50335 .49645 Mdot
.54788 .46763 Mdot
.49398 .46411 Mdot
.55031 .53615 Mdot
.47872 .55574 Mdot
.44678 .46208 Mdot
.44539 .53436 Mdot
.50055 .57672 Mdot
.43741 .56429 Mdot
.49542 .43713 Mdot
.45071 .53772 Mdot
.42362 .46615 Mdot
.57136 .47276 Mdot
.48659 .506 Mdot
.53786 .51471 Mdot
.51243 .52193 Mdot
.52237 .52158 Mdot
.4696 .49998 Mdot
.46342 .48719 Mdot
.47568 .5608 Mdot
.56635 .51935 Mdot
.50683 .44817 Mdot
.42016 .47194 Mdot
.56453 .53526 Mdot
.44043 .44156 Mdot
.46299 .57433 Mdot
.48129 .52919 Mdot
.5243 .46803 Mdot
.56544 .54533 Mdot
.42154 .54121 Mdot
.48016 .52769 Mdot
.46941 .47891 Mdot
.52049 .51831 Mdot
.45736 .45117 Mdot
.41647 .52022 Mdot
.45041 .43684 Mdot
.47629 .54814 Mdot
.50971 .47777 Mdot
.47687 .56226 Mdot
.55921 .50747 Mdot
.47184 .55063 Mdot
.41587 .45686 Mdot
.52165 .56326 Mdot
.48907 .45437 Mdot
.46447 .4429 Mdot
.52879 .4717 Mdot
.56175 .55014 Mdot
.5127 .51865 Mdot
.4611 .5263 Mdot
.5272 .47016 Mdot
.5693 .53956 Mdot
.51074 .41249 Mdot
.54228 .5209 Mdot
.46214 .54111 Mdot
.54198 .48113 Mdot
.5337 .51657 Mdot
.4921 .48136 Mdot
.5142 .47415 Mdot
.48036 .48604 Mdot
.48721 .43774 Mdot
.56733 .52634 Mdot
.52301 .56946 Mdot
.49667 .57529 Mdot
.45849 .46323 Mdot
.4629 .50873 Mdot
.48408 .47483 Mdot
.51254 .49976 Mdot
.489 .57235 Mdot
.50445 .4784 Mdot
.5839 .48873 Mdot
.47169 .49515 Mdot
.51815 .46514 Mdot
.48134 .56882 Mdot
.51445 .49173 Mdot
.5708 .55462 Mdot
.4604 .51318 Mdot
.58237 .48534 Mdot
.52789 .55946 Mdot
.41491 .50034 Mdot
.50951 .51394 Mdot
.57517 .555 Mdot
.51175 .51887 Mdot
.48679 .56529 Mdot
.50642 .46467 Mdot
.48658 .52554 Mdot
.48247 .51174 Mdot
.47429 .44389 Mdot
.51984 .51433 Mdot
.47464 .53932 Mdot
.48989 .51736 Mdot
.50525 .44822 Mdot
.56614 .53733 Mdot
.4161 .50177 Mdot
.43055 .47693 Mdot
.44659 .44721 Mdot
.46753 .54682 Mdot
.50204 .50998 Mdot
.47731 .45407 Mdot
.46832 .54447 Mdot
.43967 .44591 Mdot
.4839 .564 Mdot
.58039 .48051 Mdot
.49753 .43993 Mdot
.54876 .43221 Mdot
.49295 .48507 Mdot
.51097 .45232 Mdot
.50909 .52256 Mdot
.50834 .48036 Mdot
.46414 .52558 Mdot
.57442 .5504 Mdot
.50568 .46538 Mdot
.41731 .47915 Mdot
.50127 .47607 Mdot
.42909 .44037 Mdot
.51071 .51678 Mdot
.45329 .44755 Mdot
.52929 .47895 Mdot
.48833 .46356 Mdot
.52057 .41486 Mdot
.49441 .52086 Mdot
.54427 .48581 Mdot
.54631 .49102 Mdot
.46404 .44786 Mdot
.50978 .47579 Mdot
.46791 .50988 Mdot
.4778 .53287 Mdot
.50137 .48527 Mdot
.46672 .54159 Mdot
.57308 .52281 Mdot
.57915 .47954 Mdot
.46442 .48759 Mdot
.56446 .55766 Mdot
.53034 .49667 Mdot
.45272 .50385 Mdot
.45852 .515 Mdot
.55556 .52461 Mdot
.56553 .54927 Mdot
.46729 .51115 Mdot
.53671 .47928 Mdot
.47425 .54524 Mdot
.48677 .40672 Mdot
.47479 .49996 Mdot
.49796 .48579 Mdot
.52411 .57861 Mdot
.57426 .50558 Mdot
.47049 .53889 Mdot
.51805 .41464 Mdot
.56856 .51785 Mdot
.4993 .5211 Mdot
.47954 .53518 Mdot
.46222 .54194 Mdot
.48484 .52828 Mdot
.41894 .50345 Mdot
.4342 .44045 Mdot
.56592 .51799 Mdot
.51722 .49511 Mdot
.47324 .50361 Mdot
.46766 .40421 Mdot
.48725 .44162 Mdot
.49474 .52153 Mdot
.48988 .51389 Mdot
.56462 .46489 Mdot
.53721 .49801 Mdot
.46919 .4952 Mdot
.46358 .53666 Mdot
.50324 .44489 Mdot
.57189 .55727 Mdot
.57288 .55301 Mdot
.53252 .53082 Mdot
.41762 .48315 Mdot
.50462 .49326 Mdot
.51779 .51994 Mdot
.53526 .42 Mdot
.50434 .52375 Mdot
.48387 .47203 Mdot
.48547 .40309 Mdot
.47208 .51856 Mdot
.46826 .53996 Mdot
.56264 .55186 Mdot
.56561 .54745 Mdot
.47799 .50464 Mdot
.44023 .42815 Mdot
.42446 .44649 Mdot
.53236 .51756 Mdot
.48241 .51348 Mdot
.48688 .49498 Mdot
.54123 .48403 Mdot
.52103 .48306 Mdot
.52402 .46608 Mdot
.46111 .56173 Mdot
.50345 .49124 Mdot
.46862 .45611 Mdot
.50157 .48358 Mdot
.51275 .51909 Mdot
.48053 .51337 Mdot
.55893 .43903 Mdot
.54811 .48143 Mdot
.4762 .43199 Mdot
.47077 .4416 Mdot
.44171 .52264 Mdot
.52568 .44675 Mdot
.57774 .50761 Mdot
.44407 .54312 Mdot
.53524 .49982 Mdot
.55404 .47849 Mdot
.53784 .44201 Mdot
.46167 .51269 Mdot
.4714 .54068 Mdot
.47264 .55353 Mdot
.50053 .44959 Mdot
.53253 .51663 Mdot
.51772 .57744 Mdot
.49821 .52524 Mdot
.46442 .49345 Mdot
.4305 .47776 Mdot
.53914 .49032 Mdot
.42588 .48864 Mdot
.53715 .51252 Mdot
.47381 .486 Mdot
.53642 .5041 Mdot
.56542 .5432 Mdot
.50433 .45766 Mdot
.49229 .4466 Mdot
.47853 .47237 Mdot
.46154 .43141 Mdot
.56664 .51548 Mdot
.48858 .47901 Mdot
.49771 .44246 Mdot
.54748 .51154 Mdot
.45131 .46317 Mdot
.49325 .49616 Mdot
.46355 .51374 Mdot
.51872 .51033 Mdot
.48031 .52469 Mdot
.50391 .47773 Mdot
.52512 .42993 Mdot
.4848 .52877 Mdot
.47825 .40878 Mdot
.42026 .4577 Mdot
.47987 .48853 Mdot
.49169 .52759 Mdot
.45419 .45003 Mdot
.47923 .56408 Mdot
.46884 .58094 Mdot
.4991 .48553 Mdot
.44096 .45494 Mdot
.50302 .57378 Mdot
.5538 .44678 Mdot
.41342 .50593 Mdot
.49847 .57317 Mdot
.54701 .50443 Mdot
.56188 .5483 Mdot
.52181 .57736 Mdot
.50791 .50735 Mdot
.50424 .57211 Mdot
.49699 .45024 Mdot
.5121 .50266 Mdot
.5692 .50462 Mdot
.51486 .46831 Mdot
.57425 .55602 Mdot
.56038 .55344 Mdot
.5838 .48834 Mdot
.47662 .47601 Mdot
.53674 .55436 Mdot
.46561 .51997 Mdot
.51329 .46837 Mdot
.47084 .50997 Mdot
.5661 .53287 Mdot
.42824 .44474 Mdot
.48675 .48373 Mdot
.46613 .49103 Mdot
.48767 .57184 Mdot
.48956 .46746 Mdot
.46837 .50522 Mdot
.57066 .53274 Mdot
.49102 .47675 Mdot
.52338 .51715 Mdot
.47737 .53018 Mdot
.49316 .52836 Mdot
.48222 .52851 Mdot
.47672 .49437 Mdot
.49504 .48974 Mdot
.55768 .53778 Mdot
.48831 .43798 Mdot
.48621 .51563 Mdot
.5112 .46095 Mdot
.49518 .52676 Mdot
.46956 .53057 Mdot
.57164 .46308 Mdot
.42285 .54516 Mdot
.4698 .55357 Mdot
.52062 .45367 Mdot
.48503 .56658 Mdot
.56737 .54247 Mdot
.55878 .55063 Mdot
.4618 .5448 Mdot
.48477 .46053 Mdot
.57399 .55418 Mdot
.5118 .49761 Mdot
.57808 .47554 Mdot
.50888 .51393 Mdot
.49796 .49023 Mdot
.47219 .43239 Mdot
.5507 .5546 Mdot
.52235 .45048 Mdot
.57383 .53327 Mdot
.50201 .50719 Mdot
.45927 .43753 Mdot
.41739 .49724 Mdot
.4331 .53724 Mdot
.53626 .51627 Mdot
.50643 .4968 Mdot
.49649 .46157 Mdot
.47609 .54357 Mdot
.54737 .4855 Mdot
.56947 .53989 Mdot
.56795 .53534 Mdot
.54954 .47336 Mdot
.41191 .48391 Mdot
.52484 .48633 Mdot
.46707 .53103 Mdot
.51347 .57719 Mdot
.47876 .47589 Mdot
.52372 .50017 Mdot
.54917 .56227 Mdot
.51361 .50697 Mdot
.42283 .51896 Mdot
.54034 .4855 Mdot
.44861 .52508 Mdot
.53587 .47668 Mdot
.46585 .45292 Mdot
.46712 .54432 Mdot
.48722 .41321 Mdot
.4727 .53164 Mdot
.51889 .46695 Mdot
.41704 .45915 Mdot
.45727 .54398 Mdot
.56196 .51844 Mdot
.46567 .53688 Mdot
.51061 .4653 Mdot
.52111 .51855 Mdot
.53528 .51747 Mdot
.54297 .57113 Mdot
.50983 .51345 Mdot
.41472 .50043 Mdot
.51177 .50954 Mdot
.5528 .54593 Mdot
.46743 .54644 Mdot
.52461 .46683 Mdot
.47053 .48331 Mdot
.5163 .46691 Mdot
.54905 .51365 Mdot
.51104 .44852 Mdot
.4734 .51017 Mdot
.51533 .49483 Mdot
.41165 .48572 Mdot
.4843 .57045 Mdot
.55324 .51301 Mdot
.50376 .5751 Mdot
.48298 .53029 Mdot
.53933 .49599 Mdot
.54046 .4868 Mdot
.49073 .47647 Mdot
.48217 .4296 Mdot
.54099 .4745 Mdot
.48466 .40958 Mdot
.47204 .49863 Mdot
.4905 .49008 Mdot
.47159 .54053 Mdot
.47623 .45925 Mdot
.5084 .5638 Mdot
.51793 .4973 Mdot
.4241 .5313 Mdot
.5661 .51673 Mdot
.46777 .50615 Mdot
.46744 .48361 Mdot
.41516 .48611 Mdot
.4187 .45346 Mdot
.44769 .46502 Mdot
.44552 .54404 Mdot
.47557 .45657 Mdot
.4677 .50301 Mdot
.50468 .45396 Mdot
.53922 .50277 Mdot
.56605 .54982 Mdot
.52495 .41857 Mdot
.5355 .44237 Mdot
.42184 .49264 Mdot
.50962 .48087 Mdot
.477 .51465 Mdot
.56162 .55053 Mdot
.50316 .49809 Mdot
.49013 .52485 Mdot
.44663 .45621 Mdot
.51003 .48046 Mdot
.48517 .50989 Mdot
.42359 .49092 Mdot
.52526 .57458 Mdot
.44403 .44512 Mdot
.53012 .49056 Mdot
.53011 .57383 Mdot
.52773 .49938 Mdot
.55878 .50526 Mdot
.54069 .56699 Mdot
.42511 .53292 Mdot
.50229 .42716 Mdot
.57335 .52341 Mdot
.5529 .50703 Mdot
.50321 .50638 Mdot
.4876 .52953 Mdot
.46602 .51147 Mdot
.50677 .46479 Mdot
.56746 .52693 Mdot
.48013 .4269 Mdot
.57024 .49397 Mdot
.55 .47883 Mdot
.49932 .51355 Mdot
.57508 .54905 Mdot
.52567 .51929 Mdot
.50358 .45956 Mdot
.46369 .52756 Mdot
.41523 .47293 Mdot
.57455 .49825 Mdot
.48058 .46973 Mdot
.48741 .49649 Mdot
.42035 .45598 Mdot
.48903 .56827 Mdot
.47996 .52666 Mdot
.49475 .57473 Mdot
.5025 .519 Mdot
.53755 .48338 Mdot
.51502 .48743 Mdot
.51988 .48763 Mdot
.54564 .55408 Mdot
.5247 .47706 Mdot
.54417 .50276 Mdot
.52659 .49827 Mdot
.45943 .58302 Mdot
.50764 .50826 Mdot
.41683 .47161 Mdot
.50148 .45325 Mdot
.49743 .52545 Mdot
.55149 .47231 Mdot
.46286 .45576 Mdot
.44837 .50016 Mdot
.51292 .48139 Mdot
.47771 .53598 Mdot
.534 .50665 Mdot
.50377 .47393 Mdot
.43611 .46983 Mdot
.4646 .42018 Mdot
.58048 .50263 Mdot
.41748 .51295 Mdot
.46812 .51078 Mdot
.49478 .49293 Mdot
.54891 .42798 Mdot
.44534 .46846 Mdot
.4153 .52051 Mdot
.51245 .50376 Mdot
.49623 .52619 Mdot
.50862 .47027 Mdot
.4461 .5519 Mdot
.50615 .51197 Mdot
.52436 .48373 Mdot
.4707 .47237 Mdot
.44564 .56632 Mdot
.54075 .50105 Mdot
.50163 .4966 Mdot
.53507 .55673 Mdot
.47381 .5019 Mdot
.49189 .42447 Mdot
.41339 .51583 Mdot
.41257 .49047 Mdot
.57618 .51643 Mdot
.53028 .51926 Mdot
.50262 .44538 Mdot
.51129 .50557 Mdot
.47448 .48347 Mdot
.57375 .51464 Mdot
.53348 .46056 Mdot
.52304 .43793 Mdot
.51461 .45557 Mdot
.57899 .47786 Mdot
.50729 .57851 Mdot
.51082 .48915 Mdot
.57405 .56398 Mdot
.54102 .4939 Mdot
.51773 .5065 Mdot
.53289 .57335 Mdot
.42711 .47299 Mdot
.46125 .5196 Mdot
.51249 .42075 Mdot
.42228 .50715 Mdot
.44094 .48855 Mdot
.50118 .50422 Mdot
.46519 .49685 Mdot
.48784 .49172 Mdot
.47425 .50955 Mdot
.5211 .46125 Mdot
.43368 .44069 Mdot
.52597 .48025 Mdot
.46516 .52149 Mdot
.41901 .49821 Mdot
.47272 .45002 Mdot
.57234 .49779 Mdot
.56798 .5308 Mdot
.44429 .51424 Mdot
.53088 .42782 Mdot
.46 .52655 Mdot
.44299 .46905 Mdot
.50087 .50228 Mdot
.49578 .4755 Mdot
.56317 .57167 Mdot
.57285 .54519 Mdot
.4869 .52136 Mdot
.51722 .52257 Mdot
.50443 .5188 Mdot
.54944 .46363 Mdot
.48672 .41546 Mdot
.5633 .50557 Mdot
.52126 .49152 Mdot
.45799 .51854 Mdot
.47674 .55636 Mdot
.56359 .51995 Mdot
.47843 .53557 Mdot
.56321 .4853 Mdot
.481 .5613 Mdot
.46968 .5505 Mdot
.47296 .48665 Mdot
.41732 .48955 Mdot
.42975 .43149 Mdot
.41373 .47746 Mdot
.57486 .55469 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go
00001_ooool3o`000?ooooooB?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04
odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0U?ooool2o`000004ooooool0003o0000
ooooo`;o0000Zoooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0000Oooooo00?o0000ooooooooool0U?ooool2o`000004ooooool0003o0000ooooo`;o0000
Zoooool000?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo
00?o0000ooooooooool0Uoooool5o`0000Gooooo0_l0002Tooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2?ooooo`;o0000
1_ooool5o`0000Gooooo0ol0002Sooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo
00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`2?ooooo`;o00002Oooool2o`0000Kooooo
1Ol0002Pooooo`007_ooool00ol0003oooooooooo`2<ooooo`;o00001oooool2o`0000?ooooo0_l0
0007ooooo`Ko0000W_ooool001kooooo00?o0000ooooooooool0S?ooool2o`0000Gooooo1?l0000<
ooooo`Ko000000?oooooo`000?l00000Voooool001kooooo00?o0000ooooooooool0ROooool2o`00
00Cooooo0_l00002ooooo`;o00001oooool2o`0000Gooooo1?l00003ooooo`;o0000Voooool001ko
oooo00?o0000ooooooooool0ROooool4o`0000;ooooo0_l00007ooooo`;o00000_ooool2o`000003
ooooool0003o000000Oooooo0_l000000ooooooo0000o`000003o`0009Oooooo000Nooooo`03o`00
0?oooooooooo08Sooooo0_l000000ooooooo0000o`000005ooooo`;o00000oooool4o`0000Cooooo
0_l000000ooooooo0000o`000003ooooo`?o000000?oooooo`000?l000001Ol0002Eooooo`007_oo
ool00ol0003oooooooooo`27ooooo`Go00001_ooool9o`0000Oooooo0_l00003ooooo`;o00001Ooo
ool4o`0009Gooooo000Nooooo`03o`000?oooooooooo08Oooooo0_l000000ooooooo0000o`000002
ooooo`;o000000?oooooo`000?l000003?l00007ooooo`;o00001_ooool2o`0009Oooooo000Noooo
o`03o`000?oooooooooo08Oooooo1Ol000000ooooooo0000o`000005o`0000;ooooo2_l00003oooo
o`Go00002Oooool3o`0009?ooooo000Nooooo`03o`000?oooooooooo08Oooooo6Ol00003ooooo`?o
00000_ooool8o`000004ooooool0003o0000o`0009?ooooo000Nooooo`03o`000?oooooooooo08Ko
oooo2Ol000000ooooooo0000o`000006o`000003ooooool0003o000000So00001?ooool=o`0009?o
oooo000Nooooo`03o`000?oooooooooo08Kooooo3?l000000ooooooo0000o`000003o`000003oooo
ool0003o000000ko00001_ooool7o`00097ooooo000Nooooo`;o0000QOooool2o`0000Wooooo1_l0
00001?oooooo0000o`000?ooool3o`000003ooooool0003o000000[o00001_ooool2o`0000?ooooo
0_l0002Aooooo`007_ooool00ol0003oooooooooo`24ooooo`?o00001?ooool4o`0000;ooooo2?l0
0002oooooa3o00001?ooool2o`0009Kooooo000Nooooo`03o`000?oooooooooo08?ooooo1Ol00003
ooooo`Co00000oooool@o`000003ooooool0003o000000;o00000_ooool2o`0000Cooooo0_l0002F
ooooo`007_ooool00ol0003oooooooooo`23ooooo`Go00001Oooool2o`0000Sooooo1Ol000000ooo
oooo0000o`000008o`0000;ooooo0_l00006ooooo`;o0000U?ooool001kooooo00?o0000oooooooo
ool0Q_ooool2o`0000Gooooo1_l00004oooooa3o00000_ooool2o`0000Cooooo1_l000000ooooooo
0000o`00002?ooooo`007_ooool00ol0003oooooooooo`26ooooo`;o00001Oooool6o`0000Cooooo
0_l00002ooooo`ko00001Oooool3o`000003ooooool0003o000000Co0000Soooool001kooooo00?o
0000ooooooooool0P_ooool6o`0000;ooooo1Ol00005ooooo`;o00000_ooool6o`000003ooooool0
003o000000Wo00000oooool4o`000003ooooool0003o000000;o0000TOooool001kooooo00?o0000
ooooooooool0P_ooool7o`000003ooooool0003o000000;o00001_ooool;o`000003ooooool0003o
000000So00000_ooool5o`0000Gooooo0_l0002?ooooo`007_ooool00ol0003oooooooooo`22oooo
o`?o00000_ooool4o`000003ooooool0003o000000Oooooo5?l000000ooooooo0000o`000005o`00
00Gooooo1?l0002=ooooo`007_ooool00ol0003oooooooooo`22ooooo`Co000000?oooooo`000?l0
00000_l000000ooooooo0000o`000006oooooako00000oooool6o`0008cooooo000Nooooo`03o`00
0?oooooooooo08;ooooo1_l0000<ooooo`Co00000_oooolHo`0000;ooooo1ol0002<ooooo`007_oo
ool00ol0003oooooooooo`22ooooo`Ko00002OoooolHo`0000;ooooo1Ol00003ooooo`Co00000_oo
ool2o`0008cooooo000Nooooo`03o`000?oooooooooo08;ooooo1_l00003ooooo`;o00001?ooool4
o`000003ooooool0003o0000017o00000_ooool5o`0000?ooooo1?l00002ooooo`?o0000Roooool0
01kooooo00?o0000ooooooooool0P_ooool6o`0000?ooooo0_l00006oooooaCo000000?oooooo`00
0?l000002?l00007ooooo`?o0000Roooool001kooooo00?o0000ooooooooool0P_ooool6o`0000Wo
oooo4Ol000000ooooooo0000o`000002o`000003ooooool0003o000000Go000000Coooooo`000?l0
003ooooo1?l00003ooooo`;o0000Roooool001kooooo00?o0000ooooooooool0P_ooool4o`0000_o
oooo3Ol000000ooooooo0000o`00000>o`0000Cooooo1_l000000ooooooo0000o`00002;ooooo`00
7_ooool2o`0008Cooooo0ol000000ooooooo0000o`000005ooooo`;o00000oooool6o`0000;ooooo
0ol000000ooooooo0000o`00000>o`0000Oooooo1Ol0002<ooooo`007_ooool00ol0003ooooooooo
o`23ooooo`?o000000?oooooo`000?l000001Oooool3o`0000;ooooo2?l00004oooooa7o00000_oo
ool9o`0008cooooo000Nooooo`03o`000?oooooooooo08;ooooo1Ol00004ooooo`?o000000Cooooo
o`000?l0003ooooo3?l000000ooooooo0000o`000007o`000003ooooool0003o0000013o0000S?oo
ool001kooooo00?o0000ooooooooool0P_ooool2o`000003ooooool0003o000000Cooooo0ol00004
ooooo`Ko000000?oooooo`000?l000000ol000000ooooooo0000o`00000Co`0000Cooooo0_l0002=
ooooo`007_ooool00ol0003oooooooooo`23ooooo`?o00001_ooool2o`0000?ooooo8Ol00004oooo
o`;o0000Soooool001kooooo00?o0000ooooooooool0P_ooool4o`0000Kooooo0_l00002ooooo`Ko
000000?oooooo`000?l000001?l000000ooooooo0000o`00000Bo`0000;ooooo1ol0002<ooooo`00
7_ooool00ol0003oooooooooo`22ooooo`Ko00002?oooolOo`0000Cooooo2?l0002<ooooo`007_oo
ool00ol0003oooooooooo`23ooooo`Go00000oooool2o`0000?ooooo2?l000000ooooooo0000o`00
000@o`000003ooooool0003o000000Gooooo1Ol0002?ooooo`007_ooool00ol0003oooooooooo`23
ooooo`Co00001?ooool2o`000004ooooool0003o0000ooooo`Ko000000?oooooo`000?l000003_l0
0009ooooo`;o000000?oooooo`000?l000000_l0002?ooooo`007_ooool00ol0003oooooooooo`23
ooooo`;o00000_ooool2o`0000Gooooo0_l000000ooooooo0000o`00000=o`0000_ooooo0_l00004
ooooo`;o000000?oooooo`000?l000000_l0002?ooooo`007_ooool00ol0003oooooooooo`23oooo
o`Ko00002?ooool=o`0000?ooooo0_l00006ooooo`Co00001oooool5o`0008kooooo000Nooooo`03
o`000?oooooooooo08Gooooo1?l00004ooooo`;o00000_ooool:o`0000Kooooo0_l00006ooooo`;o
00001?ooool2o`0000;ooooo1_l0002>ooooo`007_ooool00ol0003oooooooooo`29ooooo`;o0000
0_ooool3o`000003ooooool0003o000000Oo00005Oooool8o`00093ooooo000Nooooo`03o`000?oo
oooooooo08Gooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000;ooooo1ol0
0005ooooo`;o00002?ooool4o`0000Gooooo0_l000000ooooooo0000o`000002o`0008oooooo000N
ooooo`03o`000?oooooooooo08Gooooo0_l000001?oooooo0000o`000?ooool4o`0000;ooooo2_l0
0003ooooo`;o00002?ooool4o`0000Sooooo1Ol0002>ooooo`007_ooool00ol0003oooooooooo`25
ooooo`?o00001?ooool3o`0000;ooooo2_l0000Aooooo`;o00000_ooool2o`000003ooooool0003o
000000Co0000S_ooool001kooooo0_l00027ooooo`;o00001Oooool2o`0000Gooooo1Ol00003oooo
o`;o00003_ooool2o`0000;ooooo1_l000000ooooooo0000o`00002>ooooo`007_ooool00ol0003o
ooooooooo`27ooooo`;o00001?ooool2o`0000Gooooo1Ol00003ooooo`;o00003?ooool2o`000003
ooooool0003o000000[o0000S_ooool001kooooo00?o0000ooooooooool0Qoooool2o`000004oooo
ool0003o0000o`0000Oooooo1_l0000?ooooo`?o000000?oooooo`000?l000002_l0002>ooooo`00
7_ooool00ol0003oooooooooo`29ooooo`Co00001oooool6o`0000kooooo1?l00002ooooo`;o0000
00?oooooo`000?l000001_l0002>ooooo`007_ooool00ol0003oooooooooo`29ooooo`?o000000?o
ooooo`000?l000000oooool2o`0000;ooooo1Ol00005ooooo`Oo000000?oooooo`000?l000000_l0
0002ooooo`;o00001oooool2o`0008kooooo000Nooooo`03o`000?oooooooooo08[ooooo1Ol00003
ooooo`;o00000_ooool6o`0000Cooooo1ol000000ooooooo0000o`000002ooooo`Co00001oooool2
o`0008kooooo000Nooooo`03o`000?oooooooooo08_ooooo1?l00005ooooo`;o00000_ooool7o`00
0003ooooool0003o000000Cooooo0_l000001?oooooo0000o`000?ooool2o`0000Gooooo0_l0002B
ooooo`007_ooool00ol0003oooooooooo`2Dooooo`;o00000_ooool:o`0000Cooooo0_l000000ooo
oooo0000o`000003o`0000Gooooo0_l0002Booooo`007_ooool00ol0003oooooooooo`2>ooooo`;o
00000_ooool2o`0000Kooooo2?l000000ooooooo0000o`000002ooooo`Oo00001?ooool3o`0009;o
oooo000Nooooo`03o`000?oooooooooo08kooooo0_l00002ooooo`;o00002Oooool=o`0000Sooooo
0_l0002Cooooo`007_ooool00ol0003oooooooooo`2Dooooo`;o00001Oooool2o`0000;ooooo2Ol0
002Oooooo`007_ooool00ol0003oooooooooo`2Aooooo`;o000000?oooooo`000?l000001Oooool2
o`000:[ooooo000Nooooo`03o`000?oooooooooo097ooooo0_l0000>ooooo`;o0000Y?ooool001ko
oooo00?o0000ooooooooool0XOooool2o`000:Cooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo
0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmE
EEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol@
413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000oooo
oom8ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RH
ob4Q8@06ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`3oooooodSo
oooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03
o`000?oooooooooo0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03
omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o
8B4Qolc<c006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000oooo
ooooool0oooooom8ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooo
ooooooooooooo`000006ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooooooo0?ooooooB?oo
ool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0
1_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@4100
2oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0oooooom8ooooo`00
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006oooo
o`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?oo
ooooBOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Dooooo`Co0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`3oooooodSooooo000Fooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooom8ooooo`005_ooool00ol0003oooooooooo`05
ooooo`?o0000oooooom8ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03
o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_oo
ool00ol0003oooooooooo`3ooooooe3ooooo000Dooooo`03oeEEEOmVIVKo00000?ooooooD_ooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.54693 .5311 Mdot
.52363 .51604 Mdot
.47438 .4183 Mdot
.50915 .51848 Mdot
.48428 .52245 Mdot
.55667 .57075 Mdot
.44328 .40679 Mdot
.49193 .52908 Mdot
.41385 .56059 Mdot
.45074 .54026 Mdot
.49994 .54401 Mdot
.51797 .48105 Mdot
.56668 .56632 Mdot
.56013 .44068 Mdot
.39885 .49495 Mdot
.45232 .50758 Mdot
.52991 .52867 Mdot
.535 .59022 Mdot
.45952 .56238 Mdot
.50738 .44296 Mdot
.52772 .53281 Mdot
.47073 .47208 Mdot
.46084 .53489 Mdot
.59041 .51529 Mdot
.50902 .53062 Mdot
.5034 .47877 Mdot
.40514 .48409 Mdot
.47893 .57989 Mdot
.49182 .51662 Mdot
.57237 .55133 Mdot
.53621 .47359 Mdot
.52074 .52468 Mdot
.48402 .49488 Mdot
.48001 .4307 Mdot
.57005 .55991 Mdot
.49486 .43245 Mdot
.49135 .48189 Mdot
.42207 .50302 Mdot
.4694 .53134 Mdot
.51714 .47124 Mdot
.45774 .50601 Mdot
.50034 .44953 Mdot
.53995 .49035 Mdot
.50201 .49458 Mdot
.52119 .52836 Mdot
.4748 .48663 Mdot
.54714 .41712 Mdot
.53417 .46102 Mdot
.52512 .45509 Mdot
.49421 .5866 Mdot
.47623 .52604 Mdot
.57774 .55622 Mdot
.49575 .51529 Mdot
.47496 .52837 Mdot
.44793 .51527 Mdot
.4973 .47061 Mdot
.52915 .47868 Mdot
.57967 .52744 Mdot
.50817 .52528 Mdot
.53046 .4753 Mdot
.47646 .47741 Mdot
.4789 .48746 Mdot
.49263 .43461 Mdot
.45295 .5088 Mdot
.47663 .52273 Mdot
.43269 .57224 Mdot
.5501 .50478 Mdot
.48428 .47951 Mdot
.51273 .45343 Mdot
.45102 .50566 Mdot
.40982 .44058 Mdot
.49717 .52129 Mdot
.52402 .46531 Mdot
.50684 .5103 Mdot
.58332 .53753 Mdot
.41575 .45715 Mdot
.50058 .45958 Mdot
.53792 .58692 Mdot
.41835 .42936 Mdot
.47575 .56859 Mdot
.43959 .48061 Mdot
.49341 .52806 Mdot
.51647 .53474 Mdot
.46333 .49822 Mdot
.48764 .43321 Mdot
.50249 .51206 Mdot
.44247 .43615 Mdot
.48584 .48178 Mdot
.52067 .46943 Mdot
.55941 .57636 Mdot
.48682 .51499 Mdot
.46738 .48943 Mdot
.4342 .45718 Mdot
.46675 .58231 Mdot
.44661 .40649 Mdot
.48031 .46235 Mdot
.49035 .47758 Mdot
.54002 .47711 Mdot
.54278 .41253 Mdot
.53111 .4893 Mdot
.43929 .44084 Mdot
.44294 .45094 Mdot
.49426 .52561 Mdot
.47727 .60261 Mdot
.404 .54367 Mdot
.48129 .4923 Mdot
.47273 .4351 Mdot
.48016 .51952 Mdot
.54671 .50867 Mdot
.46592 .48978 Mdot
.5766 .51976 Mdot
.49901 .52113 Mdot
.51956 .50379 Mdot
.42112 .54665 Mdot
.55101 .50941 Mdot
.5673 .56775 Mdot
.40729 .50336 Mdot
.48237 .579 Mdot
.50675 .42335 Mdot
.42945 .46118 Mdot
.53213 .57746 Mdot
.5054 .48168 Mdot
.4499 .53542 Mdot
.53183 .46534 Mdot
.53027 .52362 Mdot
.43399 .54417 Mdot
.58363 .52278 Mdot
.50366 .48085 Mdot
.50158 .48839 Mdot
.45243 .51581 Mdot
.50739 .57246 Mdot
.53574 .52759 Mdot
.59632 .50199 Mdot
.50765 .43779 Mdot
.46616 .52308 Mdot
.59349 .48609 Mdot
.47189 .56051 Mdot
.4948 .50609 Mdot
.51831 .4572 Mdot
.51383 .49888 Mdot
.48304 .5179 Mdot
.40479 .53292 Mdot
.49473 .48848 Mdot
.50341 .51811 Mdot
.47847 .50484 Mdot
.46561 .48774 Mdot
.55453 .53666 Mdot
.48928 .45677 Mdot
.55252 .50681 Mdot
.53149 .46324 Mdot
.50054 .43643 Mdot
.48188 .57959 Mdot
.485 .52011 Mdot
.56151 .46461 Mdot
.50745 .56637 Mdot
.45196 .50731 Mdot
.47497 .49042 Mdot
.592 .5303 Mdot
.50163 .45899 Mdot
.48202 .51117 Mdot
.40243 .46302 Mdot
.50661 .45196 Mdot
.5425 .58148 Mdot
.44311 .51043 Mdot
.5245 .47401 Mdot
.5249 .49211 Mdot
.39849 .53043 Mdot
.45678 .48845 Mdot
.48997 .46436 Mdot
.42681 .52178 Mdot
.48661 .57744 Mdot
.5347 .46871 Mdot
.53046 .51225 Mdot
.5234 .47033 Mdot
.40392 .45789 Mdot
.49231 .47918 Mdot
.47294 .46241 Mdot
.47973 .51503 Mdot
.57345 .43151 Mdot
.52078 .44797 Mdot
.50761 .51745 Mdot
.47165 .46676 Mdot
.50233 .50612 Mdot
.49557 .51618 Mdot
.56579 .56793 Mdot
.51839 .48606 Mdot
.45551 .42962 Mdot
.47625 .47455 Mdot
.45707 .58258 Mdot
.42606 .45837 Mdot
.50877 .49457 Mdot
.46387 .52049 Mdot
.58638 .50967 Mdot
.48312 .52005 Mdot
.42546 .51349 Mdot
.4614 .50737 Mdot
.49706 .58391 Mdot
.49298 .49338 Mdot
.47401 .52441 Mdot
.51519 .51558 Mdot
.53167 .49588 Mdot
.48589 .47504 Mdot
.52107 .57809 Mdot
.47919 .47362 Mdot
.45037 .52163 Mdot
.53315 .50985 Mdot
.53109 .53173 Mdot
.53362 .48604 Mdot
.4726 .43014 Mdot
.48194 .52178 Mdot
.52262 .52924 Mdot
.49312 .48347 Mdot
.51669 .46202 Mdot
.53978 .57608 Mdot
.50591 .48153 Mdot
.55306 .41931 Mdot
.47114 .4861 Mdot
.50416 .45861 Mdot
.40582 .53367 Mdot
.48216 .51667 Mdot
.46353 .52941 Mdot
.58579 .52592 Mdot
.46745 .48712 Mdot
.58736 .46635 Mdot
.47664 .52135 Mdot
.4824 .52306 Mdot
.51404 .52238 Mdot
.44704 .53622 Mdot
.46209 .42789 Mdot
.46281 .54942 Mdot
.44817 .50216 Mdot
.49463 .4839 Mdot
.41384 .53821 Mdot
.47786 .48943 Mdot
.49875 .47521 Mdot
.51873 .45677 Mdot
.42579 .54132 Mdot
.4186 .45158 Mdot
.5372 .51967 Mdot
.51847 .48588 Mdot
.44782 .53792 Mdot
.39913 .48817 Mdot
.56635 .53333 Mdot
.4311 .53883 Mdot
.46833 .39431 Mdot
.44766 .51033 Mdot
.41151 .45957 Mdot
.48298 .52527 Mdot
.44206 .51466 Mdot
.40408 .50664 Mdot
.53907 .48912 Mdot
.56391 .57044 Mdot
.39959 .49066 Mdot
.45811 .39961 Mdot
.51596 .50589 Mdot
.52294 .48369 Mdot
.45393 .53934 Mdot
.50813 .46233 Mdot
.48304 .43202 Mdot
.39952 .51051 Mdot
.45808 .48472 Mdot
.46158 .5136 Mdot
.48198 .51061 Mdot
.52803 .57293 Mdot
.50847 .43985 Mdot
.49546 .43579 Mdot
.45525 .54256 Mdot
.50637 .58274 Mdot
.46653 .50283 Mdot
.57689 .43776 Mdot
.54705 .50661 Mdot
.5198 .50332 Mdot
.45278 .58102 Mdot
.51719 .5011 Mdot
.45799 .4229 Mdot
.40963 .45467 Mdot
.49702 .46641 Mdot
.45698 .55647 Mdot
.5097 .4456 Mdot
.45912 .55125 Mdot
.516 .45503 Mdot
.50561 .47337 Mdot
.54172 .43716 Mdot
.48788 .50334 Mdot
.4151 .51522 Mdot
.47538 .58341 Mdot
.56198 .42238 Mdot
.45729 .53706 Mdot
.53465 .51826 Mdot
.56282 .47125 Mdot
.52371 .47766 Mdot
.55947 .49326 Mdot
.56293 .57238 Mdot
.53821 .48089 Mdot
.5249 .4926 Mdot
.47892 .52651 Mdot
.48879 .58157 Mdot
.51861 .44478 Mdot
.49314 .45273 Mdot
.5082 .51914 Mdot
.49747 .49799 Mdot
.48145 .52249 Mdot
.40769 .55176 Mdot
.45233 .49603 Mdot
.52159 .47956 Mdot
.50728 .51878 Mdot
.57032 .4511 Mdot
.56649 .50714 Mdot
.51145 .52914 Mdot
.51173 .441 Mdot
.51 .51449 Mdot
.48715 .50119 Mdot
.45305 .54845 Mdot
.52128 .5254 Mdot
.51955 .51253 Mdot
.54952 .50623 Mdot
.51592 .47062 Mdot
.48511 .48038 Mdot
.52237 .46382 Mdot
.42716 .5075 Mdot
.52602 .4548 Mdot
.51027 .54309 Mdot
.51964 .55093 Mdot
.49393 .47646 Mdot
.4794 .57654 Mdot
.43936 .51762 Mdot
.50608 .49403 Mdot
.50277 .48711 Mdot
.42598 .5669 Mdot
.4512 .45491 Mdot
.56151 .5393 Mdot
.57538 .55965 Mdot
.52086 .50245 Mdot
.45192 .54362 Mdot
.47868 .43114 Mdot
.45989 .53911 Mdot
.504 .43753 Mdot
.50266 .51974 Mdot
.51069 .52899 Mdot
.48177 .48563 Mdot
.55018 .50226 Mdot
.5521 .50778 Mdot
.48844 .40514 Mdot
.49191 .49037 Mdot
.46445 .48812 Mdot
.54811 .51452 Mdot
.4889 .50395 Mdot
.48721 .52703 Mdot
.45483 .48686 Mdot
.46314 .49825 Mdot
.52632 .4789 Mdot
.59487 .51045 Mdot
.52653 .53058 Mdot
.4838 .48556 Mdot
.55484 .57559 Mdot
.52539 .48618 Mdot
.57097 .44448 Mdot
.53986 .5222 Mdot
.56225 .57436 Mdot
.47961 .49366 Mdot
.47485 .52495 Mdot
.55188 .50208 Mdot
.52321 .49643 Mdot
.57214 .45681 Mdot
.54296 .51952 Mdot
.53552 .42995 Mdot
.49553 .39228 Mdot
.45815 .48946 Mdot
.5659 .42373 Mdot
.50121 .51129 Mdot
.48201 .5119 Mdot
.49144 .5091 Mdot
.5918 .52236 Mdot
.475 .5305 Mdot
.49512 .42172 Mdot
.45017 .53035 Mdot
.46592 .53904 Mdot
.43092 .44395 Mdot
.50469 .44567 Mdot
.49577 .48085 Mdot
.51084 .44041 Mdot
.43828 .41163 Mdot
.49683 .51925 Mdot
.59288 .4972 Mdot
.51305 .52331 Mdot
.54728 .56818 Mdot
.48003 .57972 Mdot
.4591 .54024 Mdot
.49986 .47103 Mdot
.51445 .4421 Mdot
.58652 .47288 Mdot
.50977 .4468 Mdot
.52368 .45184 Mdot
.52034 .52511 Mdot
.46268 .53517 Mdot
.49938 .53045 Mdot
.44766 .49442 Mdot
.48498 .49853 Mdot
.47952 .57762 Mdot
.58634 .46686 Mdot
.57924 .4524 Mdot
.51018 .43938 Mdot
.57546 .47138 Mdot
.50704 .47322 Mdot
.52503 .45333 Mdot
.50601 .43694 Mdot
.49697 .51696 Mdot
.48252 .51466 Mdot
.53548 .49425 Mdot
.47694 .57217 Mdot
.51417 .49458 Mdot
.46411 .56371 Mdot
.5049 .51004 Mdot
.53316 .46125 Mdot
.50017 .50943 Mdot
.44007 .45066 Mdot
.46143 .49247 Mdot
.58186 .50302 Mdot
.53637 .47546 Mdot
.44782 .53299 Mdot
.46346 .56053 Mdot
.47701 .48468 Mdot
.50319 .50533 Mdot
.45371 .54922 Mdot
.57973 .49981 Mdot
.5017 .43562 Mdot
.3955 .51289 Mdot
.46342 .50293 Mdot
.51554 .45214 Mdot
.51505 .46354 Mdot
.5621 .48581 Mdot
.4512 .50498 Mdot
.53399 .52914 Mdot
.46471 .56402 Mdot
.48389 .47181 Mdot
.58816 .50746 Mdot
.48688 .46749 Mdot
.52895 .47706 Mdot
.56512 .49189 Mdot
.52404 .47185 Mdot
.53833 .47959 Mdot
.5625 .5788 Mdot
.56081 .47962 Mdot
.524 .57139 Mdot
.48007 .49281 Mdot
.50336 .57953 Mdot
.49079 .52033 Mdot
.45074 .51962 Mdot
.48057 .43054 Mdot
.48817 .51586 Mdot
.52957 .41345 Mdot
.51791 .49027 Mdot
.45928 .50229 Mdot
.52219 .46797 Mdot
.46644 .44135 Mdot
.41781 .55769 Mdot
.50274 .43722 Mdot
.42627 .50051 Mdot
.48605 .51093 Mdot
.51169 .46273 Mdot
.48278 .46571 Mdot
.51062 .5111 Mdot
.52944 .44965 Mdot
.47817 .48981 Mdot
.52941 .46063 Mdot
.58647 .46026 Mdot
.46808 .49598 Mdot
.50587 .50278 Mdot
.55625 .49443 Mdot
.50952 .45976 Mdot
.52984 .53988 Mdot
.45786 .54034 Mdot
.45929 .41843 Mdot
.41139 .50627 Mdot
.47191 .57359 Mdot
.41366 .55709 Mdot
.52192 .45124 Mdot
.41471 .51008 Mdot
.43671 .4413 Mdot
.59691 .49331 Mdot
.48807 .49885 Mdot
.5258 .53053 Mdot
.48843 .52625 Mdot
.50576 .52846 Mdot
.47736 .48355 Mdot
.48582 .46644 Mdot
.45189 .54455 Mdot
.55098 .53195 Mdot
.53168 .46338 Mdot
.42975 .44522 Mdot
.56512 .57218 Mdot
.46482 .42925 Mdot
.43149 .57567 Mdot
.47631 .52127 Mdot
.53705 .48719 Mdot
.55645 .57531 Mdot
.40806 .52551 Mdot
.47653 .51855 Mdot
.49368 .46051 Mdot
.49375 .52326 Mdot
.48999 .4186 Mdot
.39804 .4978 Mdot
.4639 .40144 Mdot
.46119 .53124 Mdot
.51927 .48714 Mdot
.45025 .54506 Mdot
.54495 .52549 Mdot
.45032 .53197 Mdot
.42579 .43369 Mdot
.48505 .58536 Mdot
.51016 .44702 Mdot
.4917 .43417 Mdot
.54051 .49264 Mdot
.55317 .5756 Mdot
.48608 .52223 Mdot
.45346 .50258 Mdot
.53956 .49068 Mdot
.56822 .5616 Mdot
.53384 .41788 Mdot
.51734 .52542 Mdot
.44183 .51844 Mdot
.54811 .50777 Mdot
.5078 .52367 Mdot
.50025 .47795 Mdot
.52394 .48749 Mdot
.49213 .47628 Mdot
.51464 .44264 Mdot
.57518 .56057 Mdot
.49391 .57753 Mdot
.46879 .57062 Mdot
.48244 .44428 Mdot
.46533 .48767 Mdot
.49824 .46636 Mdot
.51155 .51037 Mdot
.45293 .58327 Mdot
.51399 .48367 Mdot
.59802 .50977 Mdot
.48156 .48048 Mdot
.53201 .48196 Mdot
.45465 .55532 Mdot
.51706 .50447 Mdot
.5482 .58104 Mdot
.46038 .49116 Mdot
.59419 .50634 Mdot
.49781 .57054 Mdot
.40657 .47336 Mdot
.49852 .51857 Mdot
.55453 .58343 Mdot
.49542 .52251 Mdot
.46224 .56218 Mdot
.52062 .47072 Mdot
.46745 .52748 Mdot
.48141 .50057 Mdot
.51038 .41607 Mdot
.50566 .52156 Mdot
.46622 .52439 Mdot
.48611 .51321 Mdot
.52781 .45967 Mdot
.5646 .57318 Mdot
.41423 .47788 Mdot
.44524 .45297 Mdot
.47044 .43198 Mdot
.45026 .52471 Mdot
.49749 .51272 Mdot
.50196 .44252 Mdot
.45347 .5397 Mdot
.44267 .40871 Mdot
.46086 .55238 Mdot
.59472 .50165 Mdot
.52446 .45479 Mdot
.57756 .43911 Mdot
.49914 .4816 Mdot
.53232 .46667 Mdot
.49079 .52538 Mdot
.51691 .48897 Mdot
.45675 .50349 Mdot
.55502 .58058 Mdot
.51976 .47079 Mdot
.4227 .45047 Mdot
.51211 .4787 Mdot
.44864 .42466 Mdot
.49562 .52077 Mdot
.47935 .41242 Mdot
.53555 .49803 Mdot
.50632 .45347 Mdot
.55033 .41014 Mdot
.47048 .52367 Mdot
.54698 .51209 Mdot
.54187 .51978 Mdot
.48997 .43561 Mdot
.5201 .48494 Mdot
.4699 .49198 Mdot
.47259 .52534 Mdot
.5085 .48947 Mdot
.45105 .51976 Mdot
.56237 .53789 Mdot
.58894 .50109 Mdot
.46794 .46606 Mdot
.54099 .58156 Mdot
.5262 .5129 Mdot
.47072 .4813 Mdot
.44928 .49 Mdot
.53445 .53091 Mdot
.55056 .57678 Mdot
.46873 .49266 Mdot
.54478 .5042 Mdot
.45659 .52612 Mdot
.50806 .40583 Mdot
.47984 .48723 Mdot
.50468 .48671 Mdot
.49245 .58131 Mdot
.56524 .52379 Mdot
.45456 .53737 Mdot
.5475 .41204 Mdot
.55449 .53178 Mdot
.48792 .51947 Mdot
.46955 .53183 Mdot
.44613 .51903 Mdot
.47714 .52196 Mdot
.40145 .47205 Mdot
.43928 .40953 Mdot
.57846 .55264 Mdot
.51694 .50835 Mdot
.47579 .4899 Mdot
.48562 .38907 Mdot
.51333 .44143 Mdot
.48608 .51833 Mdot
.48826 .51046 Mdot
.59242 .48464 Mdot
.53384 .51722 Mdot
.47894 .4789 Mdot
.45072 .51322 Mdot
.52972 .4611 Mdot
.54875 .58333 Mdot
.55093 .58054 Mdot
.50462 .5299 Mdot
.42172 .45462 Mdot
.50836 .50037 Mdot
.50115 .52503 Mdot
.56248 .423 Mdot
.48196 .52691 Mdot
.499 .46189 Mdot
.50684 .39683 Mdot
.46565 .50078 Mdot
.45206 .51928 Mdot
.5448 .57711 Mdot
.5531 .57605 Mdot
.47654 .49249 Mdot
.44908 .40172 Mdot
.42832 .418 Mdot
.50555 .52287 Mdot
.48152 .50293 Mdot
.48876 .48747 Mdot
.54645 .50875 Mdot
.52577 .49967 Mdot
.53883 .48673 Mdot
.4243 .56268 Mdot
.50819 .49767 Mdot
.49404 .44125 Mdot
.50918 .48757 Mdot
.49617 .52296 Mdot
.47777 .50003 Mdot
.57396 .4565 Mdot
.57767 .51552 Mdot
.50913 .40815 Mdot
.49861 .43591 Mdot
.44944 .49873 Mdot
.56968 .4583 Mdot
.57091 .52581 Mdot
.40645 .53042 Mdot
.53031 .51719 Mdot
.58466 .50792 Mdot
.57634 .4515 Mdot
.45145 .48614 Mdot
.4552 .52075 Mdot
.44704 .53169 Mdot
.52074 .45678 Mdot
.51944 .5279 Mdot
.48699 .58167 Mdot
.4784 .5268 Mdot
.47136 .47478 Mdot
.44477 .45391 Mdot
.54122 .51203 Mdot
.43503 .46424 Mdot
.52655 .52817 Mdot
.48666 .47212 Mdot
.52966 .52195 Mdot
.5632 .57075 Mdot
.52056 .4637 Mdot
.51411 .44723 Mdot
.49288 .4574 Mdot
.48906 .42929 Mdot
.58046 .54922 Mdot
.4991 .47376 Mdot
.5228 .4499 Mdot
.52992 .52906 Mdot
.48415 .42614 Mdot
.49777 .49479 Mdot
.46393 .49218 Mdot
.50643 .51935 Mdot
.46096 .52677 Mdot
.51376 .48245 Mdot
.54407 .4485 Mdot
.4767 .52266 Mdot
.49905 .40765 Mdot
.41787 .42604 Mdot
.49034 .47871 Mdot
.4794 .52428 Mdot
.47904 .43519 Mdot
.45409 .55004 Mdot
.43923 .58184 Mdot
.50609 .48773 Mdot
.46246 .43581 Mdot
.4723 .564 Mdot
.56518 .46996 Mdot
.40576 .48156 Mdot
.46918 .56028 Mdot
.53448 .5279 Mdot
.55452 .56691 Mdot
.49148 .58301 Mdot
.50338 .51363 Mdot
.47625 .5731 Mdot
.51747 .45332 Mdot
.50934 .51228 Mdot
.55821 .52306 Mdot
.52681 .4833 Mdot
.55665 .58638 Mdot
.54204 .57697 Mdot
.598 .50936 Mdot
.49059 .4613 Mdot
.50853 .565 Mdot
.46074 .49984 Mdot
.52569 .48193 Mdot
.46948 .49444 Mdot
.56956 .56658 Mdot
.4318 .41439 Mdot
.49512 .47722 Mdot
.47076 .46584 Mdot
.46099 .56166 Mdot
.5045 .46093 Mdot
.47298 .48714 Mdot
.57353 .56 Mdot
.50216 .47315 Mdot
.49481 .52091 Mdot
.4722 .51554 Mdot
.47821 .52699 Mdot
.47711 .52073 Mdot
.48553 .48276 Mdot
.50026 .48833 Mdot
.54095 .54448 Mdot
.51621 .44406 Mdot
.48544 .50904 Mdot
.52673 .47378 Mdot
.48072 .52495 Mdot
.45359 .501 Mdot
.58559 .48384 Mdot
.40395 .5318 Mdot
.45005 .53225 Mdot
.53755 .47773 Mdot
.46212 .55913 Mdot
.56224 .56008 Mdot
.54942 .56855 Mdot
.42104 .51978 Mdot
.50531 .44928 Mdot
.5559 .5849 Mdot
.51229 .50835 Mdot
.5956 .49678 Mdot
.49847 .51825 Mdot
.50396 .49263 Mdot
.50067 .43427 Mdot
.53053 .57016 Mdot
.53797 .47565 Mdot
.57378 .55472 Mdot
.49925 .51085 Mdot
.48785 .43262 Mdot
.41776 .47274 Mdot
.40004 .51986 Mdot
.51182 .52516 Mdot
.50828 .50481 Mdot
.51283 .45886 Mdot
.46048 .52458 Mdot
.54874 .51259 Mdot
.56703 .56014 Mdot
.56504 .57365 Mdot
.5827 .50198 Mdot
.40849 .45398 Mdot
.52679 .50381 Mdot
.45545 .51065 Mdot
.48409 .57895 Mdot
.49982 .45782 Mdot
.51778 .51346 Mdot
.52259 .57974 Mdot
.5069 .5154 Mdot
.42431 .49862 Mdot
.54523 .50962 Mdot
.45461 .49833 Mdot
.54493 .50241 Mdot
.50216 .4218 Mdot
.45058 .52243 Mdot
.51406 .39707 Mdot
.46089 .51208 Mdot
.53183 .48402 Mdot
.42798 .43588 Mdot
.41526 .5301 Mdot
.54426 .52985 Mdot
.45208 .51464 Mdot
.5248 .47643 Mdot
.49461 .52373 Mdot
.52174 .53156 Mdot
.51223 .5832 Mdot
.49931 .51838 Mdot
.4067 .47364 Mdot
.50412 .51611 Mdot
.53581 .55299 Mdot
.45029 .52436 Mdot
.53909 .48801 Mdot
.48191 .46733 Mdot
.52883 .48268 Mdot
.52896 .52728 Mdot
.53356 .4686 Mdot
.47022 .49512 Mdot
.51604 .50754 Mdot
.40666 .45549 Mdot
.45845 .55861 Mdot
.53337 .52608 Mdot
.4725 .56816 Mdot
.47575 .52378 Mdot
.53722 .51746 Mdot
.54463 .51032 Mdot
.50213 .47268 Mdot
.51596 .40824 Mdot
.54982 .50198 Mdot
.50557 .41234 Mdot
.47986 .48378 Mdot
.49436 .48485 Mdot
.45555 .5206 Mdot
.50057 .44594 Mdot
.47897 .56996 Mdot
.51614 .51026 Mdot
.41909 .51227 Mdot
.55078 .5302 Mdot
.47192 .48753 Mdot
.47619 .46589 Mdot
.40373 .45396 Mdot
.42039 .42552 Mdot
.46951 .44342 Mdot
.40763 .53243 Mdot
.50048 .4435 Mdot
.47361 .48475 Mdot
.52299 .46369 Mdot
.53348 .522 Mdot
.5476 .57739 Mdot
.55158 .42357 Mdot
.57493 .45198 Mdot
.4056 .45843 Mdot
.51787 .49062 Mdot
.47149 .49862 Mdot
.55063 .5765 Mdot
.50495 .50426 Mdot
.48121 .51996 Mdot
.46931 .43732 Mdot
.51842 .49048 Mdot
.48596 .5021 Mdot
.43115 .46669 Mdot
.49511 .5803 Mdot
.46771 .43024 Mdot
.53051 .50845 Mdot
.49824 .58142 Mdot
.52177 .51411 Mdot
.5766 .54255 Mdot
.51285 .58084 Mdot
.41987 .51393 Mdot
.52394 .44354 Mdot
.56305 .53866 Mdot
.53813 .52683 Mdot
.50064 .51084 Mdot
.47108 .52982 Mdot
.46752 .49127 Mdot
.52096 .47124 Mdot
.57484 .56093 Mdot
.51209 .4055 Mdot
.59244 .52125 Mdot
.55272 .50688 Mdot
.49339 .51364 Mdot
.56036 .58289 Mdot
.51037 .52699 Mdot
.51953 .46401 Mdot
.45541 .50513 Mdot
.4222 .44617 Mdot
.59367 .52518 Mdot
.49565 .45512 Mdot
.48851 .48891 Mdot
.43468 .43443 Mdot
.46464 .56376 Mdot
.47684 .51671 Mdot
.45951 .58672 Mdot
.49049 .51902 Mdot
.54395 .507 Mdot
.51958 .50073 Mdot
.52246 .50316 Mdot
.52111 .56653 Mdot
.5316 .49559 Mdot
.53711 .52792 Mdot
.52166 .51277 Mdot
.43716 .57572 Mdot
.50255 .51401 Mdot
.42527 .44523 Mdot
.5201 .45951 Mdot
.47829 .52672 Mdot
.55543 .50087 Mdot
.4877 .43956 Mdot
.46831 .4791 Mdot
.52051 .49351 Mdot
.46744 .53341 Mdot
.52529 .52259 Mdot
.51536 .47822 Mdot
.45482 .44636 Mdot
.48483 .39365 Mdot
.57824 .52188 Mdot
.41506 .49169 Mdot
.46882 .49346 Mdot
.50001 .49267 Mdot
.56839 .44152 Mdot
.46632 .4466 Mdot
.39853 .49878 Mdot
.50862 .51311 Mdot
.47836 .52673 Mdot
.52094 .47827 Mdot
.41004 .54671 Mdot
.49921 .51559 Mdot
.52789 .50134 Mdot
.49555 .45591 Mdot
.41567 .56407 Mdot
.53607 .52154 Mdot
.50442 .50193 Mdot
.49976 .5841 Mdot
.47757 .48856 Mdot
.52526 .40781 Mdot
.40356 .49442 Mdot
.40617 .46039 Mdot
.58717 .54318 Mdot
.50779 .52945 Mdot
.52903 .45874 Mdot
.50676 .51389 Mdot
.4879 .46965 Mdot
.56266 .53082 Mdot
.54677 .48701 Mdot
.53976 .46089 Mdot
.53441 .47113 Mdot
.59237 .49922 Mdot
.47652 .57832 Mdot
.51557 .49992 Mdot
.55274 .58869 Mdot
.53962 .51642 Mdot
.50946 .51643 Mdot
.50272 .58182 Mdot
.44103 .44783 Mdot
.45772 .49636 Mdot
.54571 .4093 Mdot
.40158 .47521 Mdot
.45961 .46744 Mdot
.50033 .50829 Mdot
.46679 .47009 Mdot
.49132 .48505 Mdot
.47123 .49489 Mdot
.53889 .48255 Mdot
.45545 .42664 Mdot
.53107 .49865 Mdot
.45944 .50076 Mdot
.42191 .47451 Mdot
.49856 .43909 Mdot
.56602 .51866 Mdot
.57266 .56311 Mdot
.45665 .49088 Mdot
.56683 .42552 Mdot
.452 .50265 Mdot
.47158 .42943 Mdot
.50115 .50658 Mdot
.50701 .47489 Mdot
.53761 .5891 Mdot
.561 .58022 Mdot
.48303 .51484 Mdot
.49927 .52812 Mdot
.47691 .52041 Mdot
.55856 .49001 Mdot
.50817 .423 Mdot
.55056 .52405 Mdot
.52132 .50676 Mdot
.45438 .49555 Mdot
.45915 .54414 Mdot
.54663 .53119 Mdot
.46915 .53185 Mdot
.5606 .51119 Mdot
.4572 .54779 Mdot
.44984 .5299 Mdot
.48548 .47237 Mdot
.41889 .46257 Mdot
.44565 .41482 Mdot
.40561 .44589 Mdot
.55493 .58378 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`2Jooooo`;o0000Zoooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0U?ooool2o`0000Co
oooo0_l000000ooooooo0000o`00002Xooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0U?ooool2o`0000Co
oooo0_l000000ooooooo0000o`000002ooooo`Co0000X_ooool000?ooooo00Go410@oooooooooooo
oooooa0@400;ooooo`Go00001_ooool3o`00097ooooo0_l0000>ooooo`Co0000X_ooool000?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000oooo
ooooool0S_ooool2o`000003ooooool0003o000000;o0000/_ooool000?ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0S?ooool4
o`0000?ooooo0_l00006ooooo`;o00001?ooool3o`000:?ooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo08_ooooo1?l0000<
ooooo`;o000000Coooooo`000?l0003ooooo1Ol000000ooooooo0000o`000004ooooo`Co0000U_oo
ool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o
0000ooooooooool0R_ooool4o`0000[ooooo0_l00004ooooo`Go000000Coooooo`000?l0003ooooo
0ol00002ooooo`Go0000U_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMg
Mol0003ooooo00Kooooo00?o0000ooooooooool0R?ooool4o`000003ooooool0003o000000Wooooo
0_l00006ooooo`Co00001?ooool2o`0000;ooooo1?l0002Gooooo`007_ooool00ol0003ooooooooo
o`27ooooo`?o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000oooool2o`0000Gooooo0_l0
0005ooooo`;o00000oooool4o`0009Gooooo000Nooooo`03o`000?oooooooooo08Oooooo0_l00008
ooooo`;o00000oooool2o`0000?ooooo1_l00008ooooo`;o00000oooool4o`000003ooooool0003o
000009;ooooo000Nooooo`03o`000?oooooooooo08Gooooo0_l00007ooooo`;o000000?oooooo`00
0?l000002_ooool6o`0000cooooo0_l00002ooooo`?o0000TOooool001kooooo00?o0000oooooooo
ool0Q?ooool3o`0000Oooooo1_l00005ooooo`;o00001_ooool2o`0000cooooo0_l00002ooooo`?o
0000TOooool001kooooo00?o0000ooooooooool0Q?ooool2o`0000[ooooo3Ol0000=ooooo`;o0000
2_ooool2o`0008oooooo000Nooooo`03o`000?oooooooooo08Cooooo1?l000000ooooooo0000o`00
0005ooooo`;o000000?oooooo`000?l000003?l00009ooooo`;o00002_ooool2o`0008oooooo000N
ooooo`03o`000?oooooooooo08Kooooo1Ol000000ooooooo0000o`000004oooooa7o00002Oooool2
o`0000Wooooo0_l0002>ooooo`007_ooool00ol0003oooooooooo`21ooooo`;o00001?ooool2o`00
00;ooooo0ol00004ooooo`Co00000_ooool<o`0000Sooooo0_l00004ooooo`;o00000oooool3o`00
08gooooo000Nooooo`03o`000?oooooooooo087ooooo0_l00005ooooo`Go00001oooool3o`0000;o
oooo0ol000000ooooooo0000o`000009o`0000[ooooo0_l000001?oooooo0000o`000?ooool2o`00
08gooooo000Nooooo`03o`000?oooooooooo083ooooo0_l00003ooooo`Oo00001?ooool2o`000003
ooooool0003o000000;o00000_ooool2o`0000Cooooo2Ol0000=ooooo`?o0000Soooool001kooooo
00?o0000ooooooooool0P?ooool2o`0000?ooooo1Ol000000ooooooo0000o`000003ooooo`;o0000
00?oooooo`000?l000002_ooool;o`0000?ooooo0_l00007ooooo`;o0000Soooool001kooooo0_l0
0025ooooo`?o00001?ooool4o`0000gooooo0_l000000ooooooo0000o`000009o`0000?ooooo0_l0
0006ooooo`Go0000SOooool001kooooo00?o0000ooooooooool0Ooooool4o`000004ooooool0003o
0000o`0000Cooooo1_l0000;ooooo`?o000000?oooooo`000?l000001ol0000<ooooo`Go0000SOoo
ool001kooooo00?o0000ooooooooool0Ooooool9o`000004ooooool0003o0000ooooo`;o000000?o
ooooo`000?l000002_ooool7o`000003ooooool0003o000000Go00002oooool3o`0008oooooo000N
ooooo`03o`000?oooooooooo07oooooo3?l0000;ooooo`Co000000?oooooo`000?l000004?l00008
ooooo`?o00000oooool2o`0008[ooooo000Nooooo`03o`000?oooooooooo07oooooo0ol00002oooo
o`;o00000_ooool3o`0000[ooooo6?l00005ooooo`;o00001oooool2o`0008[ooooo000Nooooo`03
o`000?oooooooooo07oooooo0_l00007ooooo`?o00001_ooool2o`000003ooooool0003o000000[o
00000oooool5o`000004ooooool0003o0000o`0000Kooooo0_l00007ooooo`;o0000R_ooool001ko
oooo00?o0000ooooooooool0R?ooool2o`0000Oooooo0_l000000ooooooo0000o`00000:o`0000Co
oooo1?l000001?oooooo0000o`000?l00007ooooo`?o000000?oooooo`000?l000000_ooool2o`00
08[ooooo000Nooooo`03o`000?oooooooooo07kooooo1?l00002ooooo`?o00003Oooool9o`000003
ooooool0003o000000?o000000?oooooo`000?l000000ol000000ooooooo0000o`000007ooooo`?o
000000?oooooo`000?l000000_ooool2o`0008[ooooo000Nooooo`03o`000?oooooooooo07kooooo
1?l000000ooooooo0000o`000002o`0000kooooo3_l00003ooooo`Oo00003_ooool2o`0008[ooooo
000Nooooo`03o`000?oooooooooo07kooooo0_l00003ooooo`;o00001_ooool2o`0000Oooooo0_l0
00000ooooooo0000o`00000Do`0000Gooooo0_l0002Cooooo`007_ooool00ol0003oooooooooo`20
ooooo`;o00002Oooool2o`0000Oooooo6Ol00005ooooo`;o00001_ooool2o`0008_ooooo000Noooo
o`03o`000?oooooooooo083ooooo0_l0000=ooooo`Co000000?oooooo`000?l000003?l000000ooo
oooo0000o`000008o`000003ooooool0003o000000?ooooo0_l00005ooooo`Go0000R?ooool001ko
oooo00?o0000ooooooooool0O_ooool2o`0000kooooo5Ol000000ooooooo0000o`000007o`000004
ooooool0003o0000ooooo`Co00001oooool3o`0008Sooooo000Nooooo`03o`000?oooooooooo07ko
oooo0_l00003ooooo`;o00002Oooool<o`000003ooooool0003o000000Ko000000?oooooo`000?l0
00002?l00003ooooo`Go00002?ooool2o`0008Oooooo000Nooooo`03o`000?oooooooooo07kooooo
0ol00002ooooo`;o00002?ooool>o`000003ooooool0003o0000013o00000oooool5o`0000Sooooo
0_l00027ooooo`007_ooool00ol0003oooooooooo`1mooooo`Co00001Oooool2o`0000Gooooo2_l0
00000ooooooo0000o`000003o`000003ooooool0003o000000Go000000?oooooo`000?l000001?l0
0005ooooo`;o00002Oooool4o`0008Oooooo000Nooooo`;o0000O_ooool2o`0000Oooooo0_l00006
ooooo`oo000000?oooooo`000?l000003?l000000ooooooo0000o`000003o`0000Kooooo2?l00027
ooooo`007_ooool00ol0003oooooooooo`20ooooo`;o00000oooool3o`0000Kooooo2?l000000ooo
oooo0000o`000004o`0000;ooooo1?l000000ooooooo0000o`000004o`0000?ooooo1Ol00006oooo
o`So0000Qoooool001kooooo00?o0000ooooooooool0Ooooool5o`000003ooooool0003o000000;o
00001_ooool7o`000003ooooool0003o0000017o00000oooool5o`0000;ooooo0_l00003ooooo`Ko
0000R?ooool001kooooo00?o0000ooooooooool0O_ooool3o`000004ooooool0003o0000o`0000;o
oooo0_l00003ooooo`So00001Oooool>o`000004ooooool0003o0000o`0000;ooooo2Ol00004oooo
o`Ko0000Qoooool001kooooo00?o0000ooooooooool0O?ooool4o`0000?ooooo1Ol00004ooooo`So
00001?oooolCo`000003ooooool0003o000000?o000000?oooooo`000?l000001oooool5o`0008Oo
oooo000Nooooo`03o`000?oooooooooo07cooooo0_l00005ooooo`Go00000oooool6o`000004oooo
ool0003o0000oooooa_o00002?ooool2o`0000;ooooo0_l00029ooooo`007_ooool00ol0003ooooo
ooooo`1nooooo`;o00000oooool4o`0000Cooooo1ol000000ooooooo0000o`00000@o`000003oooo
ool0003o000000Ko00001_ooool2o`000004ooooool0003o0000o`0000;ooooo0_l00029ooooo`00
7_ooool00ol0003oooooooooo`1nooooo`;o00001Oooool4o`0000?ooooo1_l000000ooooooo0000
o`00000@o`0000;ooooo1ol000000ooooooo0000o`000002o`000004ooooool0003o0000ooooo`Oo
0000ROooool001kooooo00?o0000ooooooooool0POooool2o`0000Cooooo0_l00005ooooobGo0000
00Goooooo`000?l0003o0000ooooo`07o`0008Sooooo000Nooooo`03o`000?oooooooooo07gooooo
0_l000000ooooooo0000o`000003o`0000Wooooo8ol00004ooooo`;o000000?oooooo`000?l00000
1Ol00028ooooo`007_ooool00ol0003oooooooooo`1mooooo`Go000000?oooooo`000?l000002?oo
ool3o`0000;ooooo1_l00004ooooo`So000000?oooooo`000?l000002ol000001?oooooo0000o`00
0?l00002ooooo`;o00000_ooool2o`0008Wooooo000Nooooo`03o`000?oooooooooo07oooooo0ol0
000;ooooo`?o00000_ooool6o`0000Wooooo0_l000000ooooooo0000o`000006o`0000;ooooo1?l0
00001?oooooo0000o`000?l0002Aooooo`007_ooool00ol0003oooooooooo`20ooooo`Co00001?oo
ool2o`0000?ooooo2?l0000?ooooo`;o00002_ooool5o`0000Gooooo0_l0002;ooooo`007_ooool0
0ol0003oooooooooo`22ooooo`;o00000_ooool4o`0000?ooooo2?l0000Cooooo`;o00001_ooool5
o`0000;ooooo0_l000000ooooooo0000o`00002;ooooo`007_ooool00ol0003oooooooooo`1ooooo
o`;o00001Oooool2o`000003ooooool0003o000000?ooooo1Ol0000;ooooo`;o00000_ooool2o`00
00Cooooo0_l00002ooooo`;o00002Oooool2o`0000;ooooo0_l0002:ooooo`007_ooool00ol0003o
ooooooooo`1oooooo`Co00000_ooool2o`0000;ooooo0_l00003ooooo`Go00002oooool2o`0000;o
oooo0_l00008ooooo`;o00003Oooool2o`0008[ooooo000Nooooo`;o0000POooool3o`0000;ooooo
0_l00008ooooo`Go00004Oooool2o`0000oooooo0_l000000ooooooo0000o`00002<ooooo`007_oo
ool00ol0003oooooooooo`20ooooo`;o00003Oooool5o`00017ooooo0_l00003ooooo`;o00002_oo
ool5o`0008cooooo000Nooooo`03o`000?oooooooooo08;ooooo1?l0000:ooooo`Co00005_ooool2
o`0000[ooooo1?l0002=ooooo`007_ooool00ol0003oooooooooo`22ooooo`Co00002_ooool7o`00
01cooooo1ol0002=ooooo`007_ooool00ol0003oooooooooo`22ooooo`?o000000?oooooo`000?l0
00002Oooool6o`0001cooooo1_l0002>ooooo`007_ooool00ol0003oooooooooo`23ooooo`;o0000
00?oooooo`000?l000002Oooool6o`0000[ooooo0_l00002ooooo`;o00002Oooool2o`0000;ooooo
1?l0002?ooooo`007_ooool00ol0003oooooooooo`26ooooo`;o00003Oooool5o`0000Oooooo0_l0
0002ooooo`;o000000?oooooo`000?l000001?ooool4o`000003ooooool0003o000000;o0000T?oo
ool001kooooo00?o0000ooooooooool0ROooool2o`0000Wooooo1_l00004ooooo`;o000000?ooooo
o`000?l000000oooool4o`0000Cooooo2?l0002Aooooo`007_ooool00ol0003oooooooooo`28oooo
o`Co00002?ooool6o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`Co000000?oooooo`00
0?l000000_ooool7o`00097ooooo000Nooooo`03o`000?oooooooooo08Sooooo1?l00009ooooo`Wo
00000_ooool2o`0000?ooooo0_l00002ooooo`go0000TOooool001kooooo00?o0000ooooooooool0
Roooool2o`0000;ooooo0ol00002ooooo`;o000000?oooooo`000?l000003ol000001?oooooo0000
o`000?ooool9o`0009;ooooo000Nooooo`03o`000?oooooooooo08_ooooo0_l00002ooooo`?o0000
0_oooolAo`000003ooooool0003o000000Cooooo2?l0002Cooooo`007_ooool00ol0003ooooooooo
o`2?ooooo`Co00000oooool2o`0000;ooooo1_l00002ooooo`;o00001oooool2o`000003ooooool0
003o000000Co0000Toooool001kooooo00?o0000ooooooooool0TOooool2o`0000[ooooo0_l0000;
ooooo`?o00000oooool3o`0009Cooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0:[ooooo0ol0
002Jooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0003oooooodSo
oooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q
00Kooooo00?o0000ooooooooool0Uoooool2o`000:kooooo0003ooooo`05o`000?oooooooooooooo
ool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0Uoooool2
o`000:kooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08
ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000
oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q
8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o
0000ooooooooool0oooooom8ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`00
0?o<c<`01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0oooooom8
ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00
0006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2
o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Doooo
o`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3oooooodSooooo000Fooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom8ooooo`005_ooool00ol0003ooooo
ooooo`05ooooo`?o0000oooooom8ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000F
ooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@oooo
o`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Dooooo`03oeEEEOmVIVKo00000?oooooo
D_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.51994 .53591 Mdot
.50963 .52603 Mdot
.50125 .42503 Mdot
.49495 .5223 Mdot
.47361 .51309 Mdot
.54339 .58324 Mdot
.45473 .38535 Mdot
.4709 .52468 Mdot
.39776 .54813 Mdot
.43851 .51281 Mdot
.47051 .53337 Mdot
.52317 .49301 Mdot
.55758 .58238 Mdot
.57259 .46302 Mdot
.38664 .46954 Mdot
.45429 .48338 Mdot
.51182 .53838 Mdot
.50554 .5944 Mdot
.43895 .54014 Mdot
.529 .44962 Mdot
.5087 .54218 Mdot
.48423 .45197 Mdot
.45679 .52635 Mdot
.58372 .53412 Mdot
.48414 .53163 Mdot
.51104 .48327 Mdot
.4088 .46218 Mdot
.45131 .5684 Mdot
.48474 .51027 Mdot
.56 .56432 Mdot
.54401 .50377 Mdot
.50277 .5293 Mdot
.48816 .4872 Mdot
.50962 .43176 Mdot
.56038 .57462 Mdot
.52433 .44392 Mdot
.49951 .48044 Mdot
.43453 .48302 Mdot
.46356 .52086 Mdot
.5256 .48298 Mdot
.45968 .48545 Mdot
.52456 .44783 Mdot
.54262 .51463 Mdot
.5065 .49801 Mdot
.5022 .53161 Mdot
.4878 .47432 Mdot
.5689 .42873 Mdot
.54331 .49204 Mdot
.54562 .47882 Mdot
.45986 .59906 Mdot
.46969 .51449 Mdot
.57749 .58299 Mdot
.48901 .5114 Mdot
.46406 .52003 Mdot
.44602 .48898 Mdot
.51089 .4715 Mdot
.53424 .49942 Mdot
.59182 .55864 Mdot
.48966 .52343 Mdot
.53733 .49693 Mdot
.49316 .46729 Mdot
.49027 .47867 Mdot
.52076 .43734 Mdot
.45434 .48469 Mdot
.47486 .50918 Mdot
.40534 .56698 Mdot
.54347 .53161 Mdot
.49996 .4725 Mdot
.5272 .45979 Mdot
.45371 .48168 Mdot
.41677 .41775 Mdot
.48161 .51791 Mdot
.53459 .48484 Mdot
.50294 .51457 Mdot
.57321 .55383 Mdot
.42656 .43346 Mdot
.5166 .45959 Mdot
.50815 .59524 Mdot
.42895 .40972 Mdot
.44982 .56119 Mdot
.4618 .46286 Mdot
.47073 .52404 Mdot
.49536 .53908 Mdot
.46978 .48112 Mdot
.51656 .43497 Mdot
.49764 .51329 Mdot
.46686 .42275 Mdot
.49975 .47572 Mdot
.52868 .48323 Mdot
.53705 .6002 Mdot
.48408 .50668 Mdot
.4784 .47264 Mdot
.45368 .4378 Mdot
.4328 .58745 Mdot
.46506 .39829 Mdot
.49605 .45406 Mdot
.50484 .47408 Mdot
.54379 .50844 Mdot
.56588 .42192 Mdot
.53222 .50977 Mdot
.46197 .42481 Mdot
.46629 .43417 Mdot
.47682 .52013 Mdot
.44985 .60576 Mdot
.39058 .52898 Mdot
.4856 .48475 Mdot
.50881 .40653 Mdot
.47719 .5077 Mdot
.54015 .53182 Mdot
.47689 .47239 Mdot
.56138 .53692 Mdot
.48314 .5184 Mdot
.5154 .51631 Mdot
.41689 .52665 Mdot
.53955 .53617 Mdot
.55999 .59081 Mdot
.41258 .48389 Mdot
.45338 .56634 Mdot
.52694 .44394 Mdot
.44704 .44103 Mdot
.50335 .58757 Mdot
.51162 .48671 Mdot
.43975 .50715 Mdot
.54666 .49272 Mdot
.51441 .53388 Mdot
.43281 .51913 Mdot
.57166 .5395 Mdot
.51036 .48524 Mdot
.50658 .49138 Mdot
.44972 .49172 Mdot
.4768 .57413 Mdot
.51854 .54238 Mdot
.60995 .52503 Mdot
.53386 .45178 Mdot
.45107 .51865 Mdot
.60932 .5082 Mdot
.45784 .52905 Mdot
.49657 .50434 Mdot
.53186 .47179 Mdot
.51379 .50872 Mdot
.48001 .50738 Mdot
.39767 .51557 Mdot
.49934 .48739 Mdot
.49085 .51855 Mdot
.48256 .49184 Mdot
.47737 .47095 Mdot
.53079 .54264 Mdot
.5055 .44765 Mdot
.5418 .53456 Mdot
.54854 .48836 Mdot
.52834 .44478 Mdot
.45308 .5692 Mdot
.47833 .51004 Mdot
.56399 .49336 Mdot
.47731 .56502 Mdot
.454 .48309 Mdot
.48476 .48009 Mdot
.59391 .55259 Mdot
.51748 .45944 Mdot
.48488 .49894 Mdot
.4019 .43629 Mdot
.5241 .45323 Mdot
.51469 .59515 Mdot
.44073 .48591 Mdot
.53142 .49128 Mdot
.52474 .50925 Mdot
.38747 .51406 Mdot
.48209 .47026 Mdot
.51004 .44976 Mdot
.43524 .49915 Mdot
.4594 .56817 Mdot
.54831 .49414 Mdot
.51918 .52621 Mdot
.53178 .48712 Mdot
.39996 .42953 Mdot
.50366 .47733 Mdot
.48643 .45054 Mdot
.48197 .50148 Mdot
.5924 .44415 Mdot
.54165 .46791 Mdot
.49494 .52035 Mdot
.48579 .4567 Mdot
.50157 .50889 Mdot
.48805 .51197 Mdot
.55686 .58649 Mdot
.52193 .49831 Mdot
.48403 .42484 Mdot
.49314 .46544 Mdot
.42554 .58417 Mdot
.44252 .43702 Mdot
.51144 .50205 Mdot
.46121 .4963 Mdot
.57858 .52982 Mdot
.47781 .50925 Mdot
.43597 .49173 Mdot
.46161 .48702 Mdot
.46141 .59786 Mdot
.49763 .49084 Mdot
.47494 .5094 Mdot
.5024 .52243 Mdot
.52877 .51541 Mdot
.50267 .46901 Mdot
.49191 .58463 Mdot
.50639 .45978 Mdot
.44649 .49419 Mdot
.52388 .52553 Mdot
.51185 .54533 Mdot
.53627 .5076 Mdot
.50348 .43119 Mdot
.47552 .51058 Mdot
.50353 .53345 Mdot
.49973 .48263 Mdot
.52765 .47261 Mdot
.51601 .58764 Mdot
.51216 .48683 Mdot
.57305 .43156 Mdot
.48386 .47144 Mdot
.51903 .46083 Mdot
.39908 .5162 Mdot
.48157 .50503 Mdot
.46305 .50888 Mdot
.59647 .55344 Mdot
.47949 .47081 Mdot
.59549 .48796 Mdot
.4525 .51223 Mdot
.46096 .51883 Mdot
.4964 .52504 Mdot
.43602 .50854 Mdot
.49149 .42659 Mdot
.43876 .53802 Mdot
.4444 .47588 Mdot
.50065 .48371 Mdot
.41117 .51912 Mdot
.48604 .48143 Mdot
.50874 .47796 Mdot
.53249 .47207 Mdot
.4256 .51924 Mdot
.43188 .42864 Mdot
.52391 .5355 Mdot
.52205 .49816 Mdot
.43625 .51021 Mdot
.39044 .46248 Mdot
.54556 .54484 Mdot
.43256 .51461 Mdot
.4867 .38885 Mdot
.44766 .48508 Mdot
.41943 .43519 Mdot
.46297 .52028 Mdot
.43602 .48911 Mdot
.40605 .48703 Mdot
.54159 .51279 Mdot
.5543 .59001 Mdot
.39559 .46762 Mdot
.47654 .39337 Mdot
.51227 .51607 Mdot
.52619 .4991 Mdot
.44904 .5261 Mdot
.52083 .46832 Mdot
.51206 .43239 Mdot
.3957 .49076 Mdot
.4848 .46791 Mdot
.45933 .49102 Mdot
.48506 .49845 Mdot
.4999 .57996 Mdot
.53144 .44797 Mdot
.52258 .43819 Mdot
.43688 .53218 Mdot
.47585 .58009 Mdot
.46837 .48504 Mdot
.59641 .4515 Mdot
.54226 .53149 Mdot
.51583 .51606 Mdot
.42168 .58188 Mdot
.51565 .51232 Mdot
.48536 .42169 Mdot
.41738 .4302 Mdot
.51241 .46621 Mdot
.43854 .53253 Mdot
.52957 .4537 Mdot
.44199 .52787 Mdot
.53017 .46615 Mdot
.51561 .47937 Mdot
.55453 .46218 Mdot
.49251 .49665 Mdot
.4204 .49487 Mdot
.44079 .59045 Mdot
.58157 .43434 Mdot
.45534 .52372 Mdot
.5217 .53286 Mdot
.562 .50074 Mdot
.52894 .49404 Mdot
.55392 .5223 Mdot
.55254 .59529 Mdot
.54527 .50608 Mdot
.52453 .50971 Mdot
.46507 .51915 Mdot
.46022 .57306 Mdot
.53996 .4623 Mdot
.52 .4479 Mdot
.49343 .52223 Mdot
.50244 .49813 Mdot
.45997 .51821 Mdot
.39058 .5388 Mdot
.45983 .4753 Mdot
.52644 .49386 Mdot
.49299 .52162 Mdot
.60169 .46675 Mdot
.55343 .53166 Mdot
.48531 .53064 Mdot
.53366 .45164 Mdot
.50051 .51948 Mdot
.49182 .4942 Mdot
.43999 .53111 Mdot
.49062 .52452 Mdot
.50801 .52195 Mdot
.53685 .53536 Mdot
.52483 .48168 Mdot
.50013 .47373 Mdot
.53365 .48201 Mdot
.44039 .48643 Mdot
.54498 .47715 Mdot
.48134 .53325 Mdot
.49309 .54291 Mdot
.50633 .47578 Mdot
.45317 .56384 Mdot
.45122 .4923 Mdot
.5096 .49992 Mdot
.50783 .49085 Mdot
.41125 .55146 Mdot
.47686 .44064 Mdot
.54041 .54777 Mdot
.57107 .58326 Mdot
.51692 .51592 Mdot
.4383 .51669 Mdot
.51 .43452 Mdot
.45004 .51521 Mdot
.53096 .44776 Mdot
.48744 .51963 Mdot
.48041 .51905 Mdot
.4938 .47807 Mdot
.54538 .52986 Mdot
.53678 .53499 Mdot
.51593 .38749 Mdot
.49637 .48751 Mdot
.48286 .46392 Mdot
.53636 .53845 Mdot
.49341 .49808 Mdot
.46919 .5211 Mdot
.48065 .46931 Mdot
.46962 .48101 Mdot
.5314 .498 Mdot
.60685 .53439 Mdot
.5074 .538 Mdot
.4925 .48028 Mdot
.53725 .59557 Mdot
.52773 .50419 Mdot
.57937 .46589 Mdot
.52514 .53964 Mdot
.54796 .59978 Mdot
.48371 .48483 Mdot
.47409 .51058 Mdot
.53983 .53177 Mdot
.52171 .51187 Mdot
.5756 .48124 Mdot
.52941 .53925 Mdot
.5501 .45345 Mdot
.51538 .39428 Mdot
.48233 .47021 Mdot
.59354 .42961 Mdot
.49717 .51199 Mdot
.48461 .49956 Mdot
.49219 .50489 Mdot
.60153 .54755 Mdot
.44846 .51987 Mdot
.51897 .4377 Mdot
.4424 .50209 Mdot
.44107 .52864 Mdot
.45042 .42536 Mdot
.52647 .44671 Mdot
.5031 .48167 Mdot
.53497 .45261 Mdot
.45418 .39824 Mdot
.48418 .51655 Mdot
.59533 .51966 Mdot
.49497 .52463 Mdot
.53096 .57528 Mdot
.45192 .56864 Mdot
.45102 .51779 Mdot
.51248 .47391 Mdot
.53729 .45612 Mdot
.6104 .4938 Mdot
.52858 .4515 Mdot
.543 .47318 Mdot
.50213 .52922 Mdot
.46109 .52358 Mdot
.47847 .52726 Mdot
.45206 .47338 Mdot
.48946 .49034 Mdot
.45317 .56506 Mdot
.60945 .48685 Mdot
.60538 .46873 Mdot
.53504 .45343 Mdot
.60653 .49239 Mdot
.5168 .47994 Mdot
.54274 .47444 Mdot
.5336 .45225 Mdot
.48822 .51353 Mdot
.48356 .50276 Mdot
.53344 .5151 Mdot
.45183 .56249 Mdot
.51564 .50491 Mdot
.44246 .54371 Mdot
.50149 .51337 Mdot
.54343 .49166 Mdot
.49769 .51009 Mdot
.46235 .43313 Mdot
.47114 .47326 Mdot
.57434 .52596 Mdot
.54448 .49883 Mdot
.43852 .50478 Mdot
.44495 .54062 Mdot
.49098 .47355 Mdot
.50265 .50882 Mdot
.43682 .52435 Mdot
.60191 .52968 Mdot
.52992 .44696 Mdot
.38237 .4928 Mdot
.46558 .48473 Mdot
.53161 .46443 Mdot
.52599 .47353 Mdot
.55521 .51468 Mdot
.45427 .4812 Mdot
.51409 .54514 Mdot
.44539 .54637 Mdot
.50688 .45596 Mdot
.58266 .5281 Mdot
.50754 .45159 Mdot
.53467 .49777 Mdot
.55639 .51929 Mdot
.532 .48911 Mdot
.54653 .50559 Mdot
.54651 .60636 Mdot
.55843 .50957 Mdot
.49575 .5763 Mdot
.48438 .48466 Mdot
.47368 .5782 Mdot
.47816 .51469 Mdot
.44751 .49302 Mdot
.51062 .43301 Mdot
.48382 .50793 Mdot
.54796 .42876 Mdot
.52019 .50247 Mdot
.46332 .48287 Mdot
.53084 .48379 Mdot
.49437 .4301 Mdot
.40556 .542 Mdot
.53 .44634 Mdot
.44177 .48061 Mdot
.48793 .50196 Mdot
.52348 .47077 Mdot
.51052 .45446 Mdot
.50516 .51726 Mdot
.54185 .47999 Mdot
.48556 .48195 Mdot
.54595 .4835 Mdot
.6012 .47945 Mdot
.47343 .48224 Mdot
.5059 .50811 Mdot
.55171 .52307 Mdot
.52247 .46567 Mdot
.50277 .53385 Mdot
.44535 .51573 Mdot
.47718 .3858 Mdot
.39018 .47742 Mdot
.44723 .55805 Mdot
.40003 .54292 Mdot
.54226 .47719 Mdot
.3916 .48111 Mdot
.45847 .42463 Mdot
.61015 .5153 Mdot
.49279 .4926 Mdot
.50655 .53737 Mdot
.46673 .52162 Mdot
.4866 .5257 Mdot
.4921 .47267 Mdot
.51255 .4548 Mdot
.43713 .51884 Mdot
.52508 .53825 Mdot
.54777 .48736 Mdot
.44862 .42586 Mdot
.55767 .60022 Mdot
.49481 .42813 Mdot
.40802 .56744 Mdot
.47752 .5066 Mdot
.5393 .50971 Mdot
.5407 .59561 Mdot
.40698 .50634 Mdot
.47913 .50364 Mdot
.52004 .45227 Mdot
.46779 .51983 Mdot
.52386 .39911 Mdot
.39186 .47561 Mdot
.48117 .37753 Mdot
.45486 .50649 Mdot
.52234 .49994 Mdot
.43293 .51844 Mdot
.52004 .5373 Mdot
.43985 .50634 Mdot
.44449 .41849 Mdot
.4502 .59497 Mdot
.52874 .45202 Mdot
.52049 .43825 Mdot
.54109 .51565 Mdot
.53827 .59116 Mdot
.46261 .51822 Mdot
.45772 .47958 Mdot
.54095 .51373 Mdot
.55811 .57584 Mdot
.55149 .43521 Mdot
.48671 .52125 Mdot
.43409 .49232 Mdot
.54211 .53304 Mdot
.4787 .52221 Mdot
.50853 .48118 Mdot
.52565 .50404 Mdot
.50655 .47382 Mdot
.53838 .46008 Mdot
.57318 .58764 Mdot
.46528 .5731 Mdot
.44539 .55373 Mdot
.51059 .43713 Mdot
.47711 .47088 Mdot
.51329 .46705 Mdot
.50634 .51723 Mdot
.42286 .58279 Mdot
.51885 .49353 Mdot
.59978 .53011 Mdot
.49719 .47213 Mdot
.53628 .50351 Mdot
.43542 .53091 Mdot
.51377 .51546 Mdot
.52017 .59698 Mdot
.47069 .47252 Mdot
.59349 .52711 Mdot
.46752 .56898 Mdot
.40977 .44967 Mdot
.48696 .51637 Mdot
.52789 .60168 Mdot
.47939 .51798 Mdot
.44348 .54741 Mdot
.52821 .48459 Mdot
.45616 .52166 Mdot
.48569 .49 Mdot
.54432 .40148 Mdot
.48887 .52093 Mdot
.46624 .50246 Mdot
.48577 .5048 Mdot
.54241 .48091 Mdot
.55515 .60004 Mdot
.42413 .45702 Mdot
.46904 .43697 Mdot
.49955 .4283 Mdot
.44502 .49701 Mdot
.49282 .51088 Mdot
.5263 .44368 Mdot
.44797 .52623 Mdot
.45168 .38149 Mdot
.44424 .52948 Mdot
.59647 .52322 Mdot
.54427 .48071 Mdot
.59666 .45327 Mdot
.50566 .48372 Mdot
.5446 .48914 Mdot
.47412 .51926 Mdot
.51975 .50054 Mdot
.46054 .48174 Mdot
.52939 .60076 Mdot
.52752 .48402 Mdot
.43803 .42823 Mdot
.519 .48743 Mdot
.47505 .41907 Mdot
.4808 .51723 Mdot
.50816 .38974 Mdot
.5315 .51767 Mdot
.52287 .45492 Mdot
.57379 .41566 Mdot
.45406 .51933 Mdot
.53797 .5358 Mdot
.52692 .54348 Mdot
.51791 .43599 Mdot
.52368 .49815 Mdot
.48042 .47731 Mdot
.47433 .50996 Mdot
.51263 .49671 Mdot
.44735 .49371 Mdot
.54114 .54702 Mdot
.58597 .52319 Mdot
.47965 .45313 Mdot
.51296 .59456 Mdot
.51379 .52472 Mdot
.49715 .4648 Mdot
.45225 .46846 Mdot
.50496 .52916 Mdot
.52966 .59416 Mdot
.47892 .47723 Mdot
.54112 .52847 Mdot
.44938 .50051 Mdot
.52782 .41784 Mdot
.49102 .47895 Mdot
.50973 .49158 Mdot
.46149 .5715 Mdot
.54401 .53803 Mdot
.44805 .52749 Mdot
.57073 .41995 Mdot
.52964 .53974 Mdot
.47923 .51117 Mdot
.46644 .51976 Mdot
.44242 .49235 Mdot
.47534 .50859 Mdot
.39547 .44385 Mdot
.45064 .38835 Mdot
.58068 .58101 Mdot
.51083 .51853 Mdot
.48568 .48001 Mdot
.50474 .38569 Mdot
.5361 .45386 Mdot
.4807 .50898 Mdot
.48947 .5037 Mdot
.60802 .50694 Mdot
.52111 .53134 Mdot
.49529 .46941 Mdot
.45008 .48749 Mdot
.54788 .48666 Mdot
.52024 .59885 Mdot
.52321 .59778 Mdot
.4745 .51906 Mdot
.43607 .43201 Mdot
.50885 .50729 Mdot
.48303 .52081 Mdot
.58184 .4353 Mdot
.46375 .52133 Mdot
.51482 .46175 Mdot
.52702 .40307 Mdot
.46859 .48398 Mdot
.44763 .49445 Mdot
.52175 .59185 Mdot
.53429 .59472 Mdot
.48215 .48341 Mdot
.46304 .38581 Mdot
.43974 .39842 Mdot
.47614 .51985 Mdot
.48585 .49211 Mdot
.49399 .4841 Mdot
.53989 .53173 Mdot
.52193 .51597 Mdot
.54282 .51089 Mdot
.39714 .55554 Mdot
.50981 .50473 Mdot
.52093 .43892 Mdot
.5136 .49514 Mdot
.47964 .51845 Mdot
.48155 .48763 Mdot
.57789 .48021 Mdot
.59446 .5479 Mdot
.54032 .39727 Mdot
.52667 .4433 Mdot
.46982 .47659 Mdot
.60245 .47627 Mdot
.55176 .54023 Mdot
.38082 .51378 Mdot
.51659 .52918 Mdot
.60251 .53688 Mdot
.60413 .46755 Mdot
.45298 .46389 Mdot
.45002 .49598 Mdot
.43276 .50319 Mdot
.53491 .47467 Mdot
.50035 .53021 Mdot
.45778 .5734 Mdot
.46383 .51984 Mdot
.48666 .46389 Mdot
.46827 .4379 Mdot
.53254 .53074 Mdot
.45475 .4458 Mdot
.50838 .53525 Mdot
.50377 .46646 Mdot
.51438 .53292 Mdot
.55309 .5894 Mdot
.53049 .47901 Mdot
.53227 .46015 Mdot
.50949 .45313 Mdot
.51839 .44008 Mdot
.58372 .57709 Mdot
.51021 .47629 Mdot
.54152 .46943 Mdot
.50439 .53827 Mdot
.51954 .4019 Mdot
.50257 .49517 Mdot
.47397 .47377 Mdot
.49132 .52134 Mdot
.451 .52184 Mdot
.51903 .49212 Mdot
.5536 .47692 Mdot
.47462 .50929 Mdot
.51956 .41976 Mdot
.42396 .4024 Mdot
.50393 .47552 Mdot
.47224 .51297 Mdot
.50813 .43241 Mdot
.43682 .52534 Mdot
.4167 .57248 Mdot
.51091 .49354 Mdot
.4903 .42734 Mdot
.44562 .54188 Mdot
.56438 .49869 Mdot
.40999 .45948 Mdot
.44453 .53531 Mdot
.51317 .54371 Mdot
.54005 .5763 Mdot
.46201 .57617 Mdot
.49696 .51491 Mdot
.45158 .56154 Mdot
.53306 .46785 Mdot
.50299 .51746 Mdot
.53528 .53708 Mdot
.53009 .50268 Mdot
.53302 .60659 Mdot
.51881 .58983 Mdot
.59983 .52973 Mdot
.50748 .45658 Mdot
.47865 .56319 Mdot
.46629 .48109 Mdot
.52963 .50029 Mdot
.47672 .4815 Mdot
.56412 .59217 Mdot
.44244 .39323 Mdot
.50521 .47766 Mdot
.48321 .44948 Mdot
.44032 .53992 Mdot
.51844 .46451 Mdot
.4856 .47362 Mdot
.5667 .58002 Mdot
.5129 .47736 Mdot
.46675 .51713 Mdot
.47446 .49649 Mdot
.46854 .51707 Mdot
.47796 .50637 Mdot
.49882 .47673 Mdot
.5052 .49049 Mdot
.51674 .54223 Mdot
.53993 .46259 Mdot
.48845 .49977 Mdot
.53372 .49361 Mdot
.47097 .51482 Mdot
.44954 .47262 Mdot
.58715 .50741 Mdot
.39687 .51445 Mdot
.44138 .50393 Mdot
.54394 .50757 Mdot
.44513 .5401 Mdot
.54865 .56956 Mdot
.53368 .57678 Mdot
.39334 .49178 Mdot
.52477 .45029 Mdot
.53176 .60549 Mdot
.50832 .51604 Mdot
.60066 .51907 Mdot
.48752 .51586 Mdot
.50832 .49724 Mdot
.52887 .4494 Mdot
.50643 .5744 Mdot
.54298 .50711 Mdot
.56371 .5694 Mdot
.49587 .51056 Mdot
.51868 .44038 Mdot
.42958 .45202 Mdot
.37914 .49999 Mdot
.48312 .52517 Mdot
.50688 .51104 Mdot
.52556 .46653 Mdot
.4546 .49908 Mdot
.53813 .5371 Mdot
.55561 .57262 Mdot
.55419 .60297 Mdot
.60291 .53105 Mdot
.41561 .42938 Mdot
.52008 .51976 Mdot
.45508 .48846 Mdot
.4567 .5682 Mdot
.5214 .45052 Mdot
.50583 .52199 Mdot
.49346 .58536 Mdot
.49729 .51824 Mdot
.43909 .47886 Mdot
.53858 .53169 Mdot
.47228 .47339 Mdot
.54214 .52799 Mdot
.53759 .40436 Mdot
.44606 .49559 Mdot
.53886 .39315 Mdot
.45911 .48998 Mdot
.5352 .50528 Mdot
.44771 .42056 Mdot
.3856 .51195 Mdot
.51661 .53444 Mdot
.45038 .48962 Mdot
.53075 .49396 Mdot
.46862 .52031 Mdot
.50202 .53629 Mdot
.47998 .58314 Mdot
.48798 .51649 Mdot
.41023 .45011 Mdot
.49434 .51678 Mdot
.51296 .54966 Mdot
.44517 .49679 Mdot
.5427 .51237 Mdot
.49874 .46033 Mdot
.53233 .50301 Mdot
.50083 .53271 Mdot
.54668 .4964 Mdot
.4755 .48249 Mdot
.51118 .51746 Mdot
.41232 .43037 Mdot
.4392 .53546 Mdot
.50465 .5316 Mdot
.44518 .54884 Mdot
.47478 .50964 Mdot
.52523 .53408 Mdot
.5374 .53155 Mdot
.51314 .47681 Mdot
.54702 .3996 Mdot
.54592 .52966 Mdot
.52516 .42834 Mdot
.49389 .47435 Mdot
.49991 .48437 Mdot
.45045 .49584 Mdot
.52511 .44515 Mdot
.45243 .56356 Mdot
.50879 .51952 Mdot
.42714 .49153 Mdot
.52467 .53756 Mdot
.48425 .47334 Mdot
.49192 .45733 Mdot
.40295 .42693 Mdot
.43048 .40583 Mdot
.49762 .43276 Mdot
.38164 .5166 Mdot
.52552 .44311 Mdot
.48744 .47172 Mdot
.53423 .48264 Mdot
.51862 .53473 Mdot
.52361 .59462 Mdot
.57079 .43873 Mdot
.60358 .4682 Mdot
.40019 .42896 Mdot
.52004 .50283 Mdot
.47414 .48408 Mdot
.53367 .59236 Mdot
.50451 .50889 Mdot
.47701 .50855 Mdot
.4978 .42965 Mdot
.52055 .50298 Mdot
.49057 .49418 Mdot
.44958 .4478 Mdot
.46527 .57351 Mdot
.49677 .42677 Mdot
.52177 .52361 Mdot
.46622 .57652 Mdot
.50868 .52392 Mdot
.58336 .57454 Mdot
.48339 .58257 Mdot
.4277 .49295 Mdot
.53934 .47229 Mdot
.54226 .54794 Mdot
.51391 .53951 Mdot
.49702 .51133 Mdot
.46133 .5216 Mdot
.478 .47448 Mdot
.52841 .48539 Mdot
.57242 .5877 Mdot
.54197 .39683 Mdot
.60231 .54616 Mdot
.54288 .53398 Mdot
.48861 .50898 Mdot
.53896 .60699 Mdot
.4913 .52547 Mdot
.52951 .47769 Mdot
.45855 .48258 Mdot
.43884 .42615 Mdot
.60055 .5492 Mdot
.51228 .45168 Mdot
.493 .48507 Mdot
.45733 .42141 Mdot
.44558 .54739 Mdot
.47992 .50165 Mdot
.42924 .58704 Mdot
.48039 .51241 Mdot
.53888 .52917 Mdot
.5174 .51348 Mdot
.51745 .51729 Mdot
.49352 .56707 Mdot
.52891 .51517 Mdot
.52088 .54572 Mdot
.5096 .52277 Mdot
.42261 .55827 Mdot
.4958 .51462 Mdot
.44324 .42586 Mdot
.53276 .47592 Mdot
.46443 .51949 Mdot
.54645 .52996 Mdot
.51527 .43566 Mdot
.49707 .46455 Mdot
.52113 .50718 Mdot
.46433 .52202 Mdot
.50873 .53101 Mdot
.52191 .48866 Mdot
.48138 .43222 Mdot
.50639 .3792 Mdot
.56339 .5384 Mdot
.42517 .47173 Mdot
.47826 .47898 Mdot
.50488 .49473 Mdot
.57808 .46296 Mdot
.49412 .43521 Mdot
.39405 .47716 Mdot
.50141 .51772 Mdot
.46575 .51876 Mdot
.52632 .49223 Mdot
.38491 .53557 Mdot
.49156 .51347 Mdot
.5225 .51823 Mdot
.52199 .45047 Mdot
.39519 .55433 Mdot
.52186 .53591 Mdot
.50517 .5066 Mdot
.46411 .59899 Mdot
.48815 .47937 Mdot
.55462 .4035 Mdot
.40608 .4737 Mdot
.41067 .43488 Mdot
.58706 .56504 Mdot
.4823 .52994 Mdot
.54736 .48197 Mdot
.49938 .51717 Mdot
.50516 .46444 Mdot
.5402 .54189 Mdot
.54782 .51694 Mdot
.54664 .49244 Mdot
.54451 .49392 Mdot
.59312 .52136 Mdot
.44891 .5656 Mdot
.51482 .51049 Mdot
.52594 .60286 Mdot
.52792 .53461 Mdot
.49756 .52045 Mdot
.4719 .57787 Mdot
.46382 .43071 Mdot
.46516 .47532 Mdot
.57307 .40848 Mdot
.39252 .44616 Mdot
.48763 .45413 Mdot
.49857 .50935 Mdot
.47704 .45137 Mdot
.49744 .48315 Mdot
.47646 .48271 Mdot
.54587 .50839 Mdot
.48358 .42314 Mdot
.52666 .51726 Mdot
.46442 .48116 Mdot
.43636 .45456 Mdot
.52478 .44104 Mdot
.54727 .53663 Mdot
.56788 .58784 Mdot
.48001 .47092 Mdot
.59453 .43215 Mdot
.4562 .47948 Mdot
.5051 .40158 Mdot
.50032 .50852 Mdot
.51615 .48163 Mdot
.50817 .59525 Mdot
.54219 .60566 Mdot
.4835 .50359 Mdot
.4804 .52386 Mdot
.45543 .51555 Mdot
.55483 .51903 Mdot
.52765 .4441 Mdot
.52626 .5372 Mdot
.51423 .51945 Mdot
.46237 .47496 Mdot
.44915 .52191 Mdot
.51957 .53574 Mdot
.46684 .51944 Mdot
.54543 .53544 Mdot
.44092 .52377 Mdot
.44142 .50276 Mdot
.50262 .46628 Mdot
.43128 .44052 Mdot
.46785 .40823 Mdot
.40762 .42019 Mdot
.52898 .60272 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
V?ooool2o`0000Oooooo0_l0002Tooooo`007_ooool00ol0003oooooooooo`2?ooooo`;o00001ooo
ool2o`0000Oooooo0_l0002Tooooo`007_ooool00ol0003oooooooooo`2?ooooo`Go00000oooool2
o`0000Oooooo0_l0002Uooooo`007_ooool00ol0003oooooooooo`2>ooooo`Ko00000oooool2o`00
0003ooooool0003o000000Cooooo0_l00002ooooo`;o0000XOooool001kooooo00?o0000oooooooo
ool0S_ooool2o`0000[ooooo0_l00005ooooo`;o000000?oooooo`000?l00000XOooool000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Co
oooo00?o0000ooooooooool0S?ooool2o`0000Wooooo0_l00008ooooo`Co00001_ooool2o`0009[o
oooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2<ooooo`;o00002Oooool2o`0000[ooooo0_l00006ooooo`?o
0000VOooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool3o`0008_o
oooo0_l00003ooooo`;o000000?oooooo`000?l000004Oooool2o`0000Cooooo1?l0002Gooooo`00
0oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool00ol0
003oooooooooo`26ooooo`;o00000oooool2o`0000?ooooo0_l000000ooooooo0000o`00000;oooo
o`;o00000oooool4o`0000;ooooo1ol0002Eooooo`000oooool01Ol0003ooooooooooooooooo0000
00_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`26ooooo`Co00005_ooool3
o`0000;ooooo1?l00002ooooo`Co000000?oooooo`000?l00000UOooool000?ooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0Qoooool3
o`0000[ooooo0_l0000;ooooo`;o00004oooool2o`0008oooooo0003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo08Oooooo0_l0000;
ooooo`;o00008?ooool2o`0008oooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool0
0omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0;Kooooo0_l0002?ooooo`007_ooool00ol0
003oooooooooo`23ooooo`;o00001oooool2o`0000Sooooo0_l0000?ooooo`;o00003Oooool2o`00
08oooooo000Nooooo`03o`000?oooooooooo083ooooo0_l000000ooooooo0000o`000007ooooo`?o
00000_ooool2o`000003ooooool0003o000000;o00000_ooool2o`0000Wooooo1?l0000;ooooo`?o
0000T?ooool001kooooo00?o0000ooooooooool0P?ooool2o`0000[ooooo1?l000000ooooooo0000
o`000003o`0000?ooooo0ol00003ooooo`;o00001?ooool2o`0000gooooo0ol0002@ooooo`007_oo
ool00ol0003oooooooooo`1nooooo`?o00001oooool8o`000004ooooool0003o0000o`0000Gooooo
2?l00006ooooo`;o00001Oooool2o`0000Gooooo0_l0002@ooooo`007_ooool00ol0003ooooooooo
o`1nooooo`?o000000?oooooo`000?l000000_l00002ooooo`Go00001_ooool2o`0000Kooooo2Ol0
0003ooooo`;o00001Oooool2o`0000Gooooo0ol00005ooooo`;o0000R?ooool001kooooo00?o0000
ooooooooool0O_ooool2o`000003ooooool0003o000000?o000000Coooooo`000?l0003ooooo0_l0
0006ooooo`?o00000oooool2o`0000?ooooo2Ol0000@ooooo`;o000000?oooooo`000?l000000_oo
ool2o`0008Sooooo000Nooooo`03o`000?oooooooooo07oooooo1?l000001?oooooo0000o`000?oo
ool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool4o`0000;ooooo0_l00003ooooo`?o0000
00?oooooo`000?l000001Ol00007ooooo`;o00002?ooool2o`0000;ooooo0_l00028ooooo`007_oo
ool00ol0003oooooooooo`1oooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`Go00000ooo
ool2o`000003ooooool0003o000000Cooooo0_l00003ooooo`Ko00001oooool2o`0000Cooooo0_l0
0002ooooo`;o0000S?ooool001kooooo00?o0000ooooooooool0O?ooool2o`0000[ooooo0_l00003
ooooo`;o00002?ooool2o`0000_ooooo1Ol0000<ooooo`;o00001Oooool2o`0008Wooooo000Noooo
o`03o`000?oooooooooo07_ooooo0ol0000Booooo`;o00005?ooool4o`0001;ooooo0_l00029oooo
o`007_ooool00ol0003oooooooooo`1kooooo`;o00001?ooool2o`0000_ooooo1?l00007ooooo`;o
00001Oooool4o`000003ooooool0003o000000Co0000W?ooool001kooooo0_l00022ooooo`;o0000
1Oooool2o`0000Cooooo0_l00007ooooo`Go00001?ooool4o`000003ooooool0003o000000Go0000
0oooool2o`0000gooooo0_l00027ooooo`007_ooool00ol0003oooooooooo`28ooooo`Co00002ooo
ool5o`000003ooooool0003o000000;ooooo3?l00002ooooo`;o00003Oooool2o`0008Oooooo000N
ooooo`03o`000?oooooooooo087ooooo0_l00003ooooo`;o00000_ooool2o`0000kooooo1Ol00002
ooooo`co0000V_ooool001kooooo00?o0000ooooooooool0Noooool2o`0000Cooooo0_l00003oooo
o`;o00004_ooool6o`000003ooooool0003o000000[o00000oooool2o`0009Gooooo000Nooooo`03
o`000?oooooooooo07_ooooo0_l00004ooooo`;o00003?ooool2o`000003ooooool0003o000000Go
oooo5?l00003ooooo`;o00001?ooool4o`0008gooooo000Nooooo`03o`000?oooooooooo07cooooo
0_l0000Aooooo`;o000000?oooooo`000?l000001OoooolBo`000003ooooool0003o000000Sooooo
1?l00006ooooo`?o0000Q?ooool001kooooo00?o0000ooooooooool0N_ooool4o`0000Sooooo0_l0
0007ooooo`;o00001_oooolDo`000003ooooool0003o000000[ooooo0_l00006ooooo`?o0000Q?oo
ool001kooooo00?o0000ooooooooool0N_ooool2o`0000Cooooo0_l00004ooooo`;o00001_ooool3
o`000004ooooool0003o0000ooooo`oo00000_ooool8o`0009Wooooo000Nooooo`03o`000?oooooo
oooo07_ooooo0ol00002ooooo`;o00002_oooolIo`0000;ooooo2?l000000ooooooo0000o`00000>
ooooo`;o0000QOooool001kooooo00?o0000ooooooooool0Noooool3o`0000gooooo0ol00002oooo
oaKo00000_ooool3o`000005ooooool0003o0000o`000?ooool00_l00005ooooo`?o00001Oooool3
o`0008Gooooo000Nooooo`03o`000?oooooooooo07_ooooo0_l00005ooooo`;o00001Oooool5o`00
0003ooooool0003o000001Go000000?oooooo`000?l000001ol00007ooooo`?o00001Oooool2o`00
08Kooooo000Nooooo`03o`000?oooooooooo083ooooo1?l00005oooooago000000?oooooo`000?l0
00000ol000001?oooooo0000o`000?l0000Booooo`;o0000Poooool001kooooo00?o0000oooooooo
ool0P?ooool2o`0000Sooooo3?l00002ooooo`So00000_ooool2o`000003ooooool0003o000000Go
000000Coooooo`000?l0003o00003Oooool2o`0000?ooooo0_l00023ooooo`007_ooool00ol0003o
ooooooooo`1hooooo`;o00000_ooool3o`0000Sooooo3?l00005ooooo`co000000?oooooo`000?l0
00001?l00002ooooo`?o00000oooool2o`0000Sooooo0_l00002ooooo`;o0000Q?ooool001kooooo
00?o0000ooooooooool0N?ooool2o`0000;ooooo0ol00006ooooo`oo00000_ooool2o`000003oooo
ool0003o0000013o00000_ooool3o`0000?ooooo0_l0000<ooooo`?o0000Poooool001kooooo00?o
0000ooooooooool0QOooool2o`0000;ooooo0_l00002ooooo`Oo00000_ooool2o`000003ooooool0
003o000000?o000000?oooooo`000?l000001?l000000ooooooo0000o`000008o`0000?ooooo0_l0
000=ooooo`;o0000Poooool001kooooo0_l0001hooooo`;o00004?ooool9o`000003ooooool0003o
000000?ooooo1_l000000ooooooo0000o`00000>o`0000Cooooo0_l0002Booooo`007_ooool00ol0
003oooooooooo`1gooooo`;o00004?ooool7o`0000?ooooo0_l00003ooooo`Oo00000oooool:o`00
0004ooooool0003o0000o`0000?ooooo0_l0002Booooo`007_ooool00ol0003oooooooooo`20oooo
o`;o00001oooool4o`0000?ooooo1?l00002oooooa[o00002oooool2o`0000Gooooo0_l00023oooo
o`007_ooool00ol0003oooooooooo`1iooooo`;o00001Oooool2o`0000Sooooo0ol00003ooooo`Co
00000_oooolBo`000003ooooool0003o000000Co00000_ooool2o`0000Sooooo0_l00005ooooo`;o
0000Poooool001kooooo00?o0000ooooooooool0N?ooool4o`000003ooooool0003o000000[ooooo
0ol00003ooooo`;o00001?oooolCo`000003ooooool0003o000000?o00000_ooool3o`0009Cooooo
000Nooooo`03o`000?oooooooooo07Sooooo1?l000001?oooooo0000o`000?l00009ooooo`?o0000
00?oooooo`000?l000000ol00002oooooaOo000000?oooooo`000?l000001?l0000@ooooo`;o0000
Poooool001kooooo00?o0000ooooooooool0N?ooool2o`0000?ooooo0ol00002ooooo`;o00000_oo
ool2o`000005ooooool0003o0000o`000?ooool07_l000000ooooooo0000o`000005o`0000[ooooo
1?l000000ooooooo0000o`000023ooooo`007_ooool00ol0003oooooooooo`22ooooo`;o00000_oo
ool2o`000003ooooool0003o000000;o000000?oooooo`000?l000006?l00007ooooo`Co00001ooo
ool2o`000003ooooool0003o000000;o0000Q_ooool001kooooo00?o0000ooooooooool0Poooool2
o`0000Gooooo0ol000000ooooooo0000o`00000Ho`0000Oooooo0ol00005ooooo`;o000000Cooooo
o`000?l0003ooooo0ol00002ooooo`;o0000Poooool001kooooo00?o0000ooooooooool0Noooool2
o`0000Kooooo0_l00005ooooo`Wo00000_oooolCo`0000?ooooo1Ol00007ooooo`Co00000_ooool7
o`0008?ooooo000Nooooo`03o`000?oooooooooo07_ooooo0_l0000<ooooo`Oo000000?oooooo`00
0?l000000_ooool2o`000003ooooool0003o000000;o00000oooool8o`0000;ooooo2Ol00006oooo
o`?o00001?ooool3o`0008Gooooo000Nooooo`03o`000?oooooooooo07Wooooo0_l0000>ooooo`Go
00001oooool2o`000003ooooool0003o000000;o00000oooool@o`000003ooooool0003o000000So
oooo0_l00004ooooo`?o0000Q?ooool001kooooo00?o0000ooooooooool0NOooool4o`0000kooooo
0ol0000?oooooa?o00000_ooool3o`000003ooooool0003o000000;ooooo0_l00004ooooo`?o0000
Q?ooool001kooooo00?o0000ooooooooool0Noooool2o`0000?ooooo0_l00009ooooo`Co00003_oo
ool2o`000003ooooool0003o000000oo000000Goooooo`000?l0003o0000ooooo`02o`0000Sooooo
0_l00025ooooo`007_ooool00ol0003oooooooooo`1nooooo`Co00002Oooool4o`0000gooooo0_l0
0003ooooo`Wo00000_ooool5o`0009Kooooo000Nooooo`03o`000?oooooooooo07gooooo0ol0000<
ooooo`?o00003Oooool2o`0000Cooooo1ol00003ooooo`?o00003_ooool5o`0008Gooooo000Noooo
o`;o0000O_ooool2o`0000?ooooo0_l00008ooooo`?o00005?ooool2o`0000Oooooo0_l0000?oooo
o`Go0000QOooool001kooooo00?o0000ooooooooool0O?ooool2o`0000Cooooo0_l00009ooooo`;o
00005?ooool2o`00017ooooo0_l00005ooooo`Co0000Q_ooool001kooooo00?o0000ooooooooool0
O?ooool3o`0000kooooo0_l0000Wooooo`;o00001Oooool3o`0008Oooooo000Nooooo`03o`000?oo
oooooooo07gooooo0_l00006ooooo`;o00001_ooool3o`0002cooooo0_l00029ooooo`007_ooool0
0ol0003oooooooooo`25ooooo`;o00001oooool3o`0000Kooooo0_l0000Sooooo`;o0000ROooool0
01kooooo00?o0000ooooooooool0P?ooool2o`0000cooooo0ol00006ooooo`;o00000oooool2o`00
01Cooooo0_l00007ooooo`;o0000R_ooool001kooooo00?o0000ooooooooool0P?ooool3o`0000_o
oooo1Ol000001?oooooo0000o`000?ooool2o`0000?ooooo0_l0000@ooooo`;o00000_ooool3o`00
00Kooooo0_l0002:ooooo`007_ooool00ol0003oooooooooo`21ooooo`Co00002_ooool7o`0001So
oooo0_l000000ooooooo0000o`000002o`0009;ooooo000Nooooo`03o`000?oooooooooo08?ooooo
0_l0000<ooooo`Co00000_ooool2o`0000Cooooo0_l00002ooooo`;o00001_ooool4o`0000Cooooo
0ol00006ooooo`;o0000Roooool001kooooo00?o0000ooooooooool0T_ooool7o`0000Cooooo0_l0
0002ooooo`;o00001_ooool4o`0000Cooooo0ol00006ooooo`;o0000Roooool001kooooo00?o0000
ooooooooool0QOooool2o`0000kooooo1_l00003ooooo`;o00002Oooool2o`0000Kooooo0_l00000
0ooooooo0000o`000003ooooo`?o0000Roooool001kooooo00?o0000ooooooooool0QOooool3o`00
00oooooo1?l000000ooooooo0000o`000002o`0000gooooo0_l00002ooooo`;o000000?oooooo`00
0?l000001Ol0002<ooooo`007_ooool00ol0003oooooooooo`25ooooo`Ko00003Oooool2o`0000;o
oooo0_l00002ooooo`;o00000_ooool2o`0000Oooooo0_l00002ooooo`;o00000_ooool5o`0008go
oooo000Nooooo`03o`000?oooooooooo08Oooooo1_l0000Cooooo`;o00000_ooool4o`0000?ooooo
0_l00003ooooo`Co000000Coooooo`000?l0003o0000Soooool000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000oooo
ooooool0Roooool2o`000003ooooool0003o0000013ooooo0_l000000ooooooo0000o`000008o`00
00?ooooo1Ol0002Booooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2>ooooo`;o00000_ooool2
o`0000cooooo3_l00002ooooo`;o000000?oooooo`000?l00000T_ooool000?ooooo00Go410@oooo
oooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`00097ooooo1?l0
000<oooooa;o0000U?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2Aooooo`Co00004?ooool7o`0000;ooooo
1Ol0002Dooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o
410@olc<c006ooooo`03o`000?oooooooooo08kooooo0_l0000Gooooo`_o0000UOooool000?ooooo
00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000oooooooo
ool0S_ooool2o`0001Wooooo1ol0002Gooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003o
ooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Q
o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0
003oooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0
003ooooooooooooooooo000000Kooooo0ol0003oooooodSooooo0003ooooo`05o`000?oooooooooo
ooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000ooooooooool0oooo
oom8ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000
olc<c006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooo
oa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`3oooooodSo
oooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o0000
00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o
0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001Cooooo
1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB?ooool001Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodSooooo000Fooooo`03o`000?oooooo
oooo00Gooooo0ol0003oooooodSooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Ko
oooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo
000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Cooooo00?oEEEEofIVI_l00000oooooomB
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.48777 .53078 Mdot
.49242 .52719 Mdot
.52809 .44496 Mdot
.48171 .51801 Mdot
.47006 .4994 Mdot
.52509 .58569 Mdot
.46977 .37379 Mdot
.45722 .51207 Mdot
.3918 .53064 Mdot
.4388 .48287 Mdot
.44768 .51317 Mdot
.52053 .50682 Mdot
.54201 .58942 Mdot
.57346 .49058 Mdot
.38497 .44695 Mdot
.46729 .46405 Mdot
.49082 .53728 Mdot
.47611 .58695 Mdot
.42859 .51041 Mdot
.54383 .46737 Mdot
.48778 .5399 Mdot
.50189 .44365 Mdot
.4627 .51063 Mdot
.56578 .5491 Mdot
.46294 .52269 Mdot
.51489 .49275 Mdot
.42316 .4447 Mdot
.43026 .54635 Mdot
.48172 .5004 Mdot
.53958 .56905 Mdot
.53963 .53331 Mdot
.4837 .52413 Mdot
.49555 .48379 Mdot
.53762 .44571 Mdot
.54362 .58073 Mdot
.54828 .46727 Mdot
.5076 .48536 Mdot
.45931 .46675 Mdot
.46663 .50411 Mdot
.5257 .49914 Mdot
.4717 .46937 Mdot
.54299 .45774 Mdot
.53391 .53544 Mdot
.50846 .5021 Mdot
.48237 .52465 Mdot
.50423 .47029 Mdot
.58218 .44847 Mdot
.54048 .52512 Mdot
.55412 .50748 Mdot
.42942 .60062 Mdot
.47104 .49836 Mdot
.56942 .60213 Mdot
.48504 .50352 Mdot
.46201 .50564 Mdot
.45628 .46585 Mdot
.5211 .48046 Mdot
.52894 .52044 Mdot
.59447 .58415 Mdot
.47358 .51316 Mdot
.53325 .51948 Mdot
.51192 .46662 Mdot
.50432 .47687 Mdot
.54461 .45248 Mdot
.46679 .46511 Mdot
.48007 .49264 Mdot
.38686 .55512 Mdot
.52665 .55144 Mdot
.51565 .47407 Mdot
.53442 .4755 Mdot
.4675 .46297 Mdot
.43126 .40254 Mdot
.47086 .50827 Mdot
.53506 .50816 Mdot
.49767 .5136 Mdot
.55343 .56368 Mdot
.44574 .41739 Mdot
.52833 .4696 Mdot
.47815 .59202 Mdot
.44611 .3987 Mdot
.43114 .54349 Mdot
.49242 .45401 Mdot
.45545 .51204 Mdot
.47527 .53192 Mdot
.48437 .47009 Mdot
.54228 .44936 Mdot
.49301 .50969 Mdot
.49575 .42056 Mdot
.51357 .47754 Mdot
.52773 .50133 Mdot
.51126 .61347 Mdot
.48564 .49617 Mdot
.49552 .46439 Mdot
.48021 .4283 Mdot
.40549 .58343 Mdot
.48679 .40094 Mdot
.5136 .45755 Mdot
.5177 .47855 Mdot
.53566 .53793 Mdot
.58119 .43997 Mdot
.52369 .52752 Mdot
.48973 .41962 Mdot
.49508 .42847 Mdot
.46553 .50766 Mdot
.4268 .59869 Mdot
.38816 .51129 Mdot
.49394 .48228 Mdot
.54371 .39035 Mdot
.48057 .4934 Mdot
.524 .54759 Mdot
.49438 .46359 Mdot
.53525 .54815 Mdot
.47163 .5092 Mdot
.50611 .52339 Mdot
.42504 .5026 Mdot
.51915 .55483 Mdot
.54644 .60477 Mdot
.43003 .46679 Mdot
.4308 .54303 Mdot
.5411 .4762 Mdot
.47251 .43006 Mdot
.47461 .58582 Mdot
.51381 .49568 Mdot
.44224 .47773 Mdot
.54884 .522 Mdot
.49463 .53425 Mdot
.44427 .49042 Mdot
.54878 .55104 Mdot
.51346 .49404 Mdot
.50911 .49705 Mdot
.45913 .47032 Mdot
.44909 .56399 Mdot
.49716 .54608 Mdot
.61266 .54612 Mdot
.55219 .47605 Mdot
.44746 .50959 Mdot
.61408 .53 Mdot
.45322 .48991 Mdot
.49892 .50109 Mdot
.53632 .49323 Mdot
.50897 .51563 Mdot
.48248 .49445 Mdot
.40234 .49643 Mdot
.50385 .49043 Mdot
.48044 .51234 Mdot
.49157 .48168 Mdot
.49545 .46297 Mdot
.5004 .53853 Mdot
.52131 .45095 Mdot
.52155 .55469 Mdot
.55271 .51631 Mdot
.54981 .46459 Mdot
.43053 .54814 Mdot
.4776 .49663 Mdot
.55326 .52366 Mdot
.45043 .55154 Mdot
.46711 .4638 Mdot
.49886 .47632 Mdot
.58594 .56963 Mdot
.52877 .46988 Mdot
.49193 .48727 Mdot
.41046 .41539 Mdot
.53554 .46535 Mdot
.4859 .59743 Mdot
.45059 .46495 Mdot
.52869 .51081 Mdot
.51639 .52349 Mdot
.3877 .49622 Mdot
.51239 .46099 Mdot
.52842 .4473 Mdot
.45671 .47721 Mdot
.43768 .54787 Mdot
.5489 .52118 Mdot
.50195 .53182 Mdot
.53054 .50718 Mdot
.40473 .40727 Mdot
.51367 .48263 Mdot
.50365 .45075 Mdot
.48924 .48765 Mdot
.60164 .46238 Mdot
.55192 .49488 Mdot
.48324 .51586 Mdot
.50382 .45772 Mdot
.49986 .50845 Mdot
.48356 .50357 Mdot
.54171 .59586 Mdot
.51793 .51101 Mdot
.51505 .43241 Mdot
.51214 .46609 Mdot
.4014 .57723 Mdot
.46675 .42455 Mdot
.50997 .50885 Mdot
.46855 .47367 Mdot
.55905 .54636 Mdot
.47862 .4954 Mdot
.45916 .47212 Mdot
.47157 .47078 Mdot
.4296 .60084 Mdot
.50265 .49133 Mdot
.48283 .49132 Mdot
.48841 .52116 Mdot
.5171 .53037 Mdot
.51881 .47201 Mdot
.46392 .57927 Mdot
.53237 .45645 Mdot
.45496 .46875 Mdot
.50725 .53324 Mdot
.49022 .54693 Mdot
.52842 .52722 Mdot
.53409 .44524 Mdot
.47586 .49588 Mdot
.48334 .5272 Mdot
.50619 .48744 Mdot
.53023 .49009 Mdot
.49081 .58771 Mdot
.51421 .49601 Mdot
.58418 .45138 Mdot
.50111 .46551 Mdot
.52878 .47269 Mdot
.40419 .49684 Mdot
.48607 .49182 Mdot
.47198 .48598 Mdot
.59731 .57578 Mdot
.49724 .46332 Mdot
.59198 .51132 Mdot
.4398 .50024 Mdot
.44902 .50918 Mdot
.47928 .51857 Mdot
.43778 .47944 Mdot
.52241 .43801 Mdot
.42519 .51942 Mdot
.45236 .4556 Mdot
.5062 .4888 Mdot
.42088 .49735 Mdot
.49813 .47955 Mdot
.51576 .48737 Mdot
.53702 .49413 Mdot
.43842 .49389 Mdot
.45285 .41401 Mdot
.50439 .5417 Mdot
.51806 .51094 Mdot
.4374 .48068 Mdot
.39207 .44027 Mdot
.51589 .54765 Mdot
.4468 .48772 Mdot
.50617 .39455 Mdot
.45962 .46399 Mdot
.43604 .41784 Mdot
.45202 .50924 Mdot
.44253 .46621 Mdot
.42004 .46911 Mdot
.53284 .5334 Mdot
.53884 .60012 Mdot
.40236 .44786 Mdot
.49711 .39827 Mdot
.50438 .52078 Mdot
.52065 .51475 Mdot
.45554 .50643 Mdot
.52729 .4824 Mdot
.53894 .44558 Mdot
.40353 .47198 Mdot
.51575 .4604 Mdot
.46734 .47141 Mdot
.49227 .48701 Mdot
.47198 .57483 Mdot
.54729 .46705 Mdot
.54495 .45289 Mdot
.42985 .51556 Mdot
.4482 .56573 Mdot
.47865 .4721 Mdot
.60585 .47018 Mdot
.52747 .54926 Mdot
.50659 .52345 Mdot
.39823 .57451 Mdot
.50882 .51944 Mdot
.51494 .43282 Mdot
.43351 .41291 Mdot
.5243 .47498 Mdot
.43128 .50217 Mdot
.54221 .47213 Mdot
.43642 .4984 Mdot
.53601 .48524 Mdot
.52042 .49126 Mdot
.55564 .49415 Mdot
.49901 .49118 Mdot
.43874 .47562 Mdot
.41208 .58767 Mdot
.59207 .45309 Mdot
.46385 .50392 Mdot
.50281 .53815 Mdot
.54776 .53053 Mdot
.52494 .51199 Mdot
.53602 .54685 Mdot
.53667 .60847 Mdot
.54003 .53008 Mdot
.51606 .52377 Mdot
.45989 .50594 Mdot
.43674 .55346 Mdot
.55146 .48784 Mdot
.54235 .45488 Mdot
.48005 .51726 Mdot
.50618 .49892 Mdot
.44821 .50878 Mdot
.3839 .52199 Mdot
.47718 .4618 Mdot
.52256 .50975 Mdot
.48022 .51664 Mdot
.62243 .48585 Mdot
.52899 .55017 Mdot
.46261 .52232 Mdot
.54776 .4726 Mdot
.49038 .51734 Mdot
.49858 .48922 Mdot
.4382 .50741 Mdot
.46211 .51481 Mdot
.49363 .52369 Mdot
.51561 .55622 Mdot
.52557 .49752 Mdot
.51503 .47541 Mdot
.53507 .5047 Mdot
.46589 .46879 Mdot
.55211 .50482 Mdot
.4567 .51327 Mdot
.46804 .52283 Mdot
.51655 .48258 Mdot
.43355 .54055 Mdot
.47497 .46956 Mdot
.50954 .50587 Mdot
.51003 .4974 Mdot
.40654 .52973 Mdot
.50727 .43827 Mdot
.51166 .54651 Mdot
.5593 .59881 Mdot
.50738 .52413 Mdot
.43708 .48635 Mdot
.53965 .45068 Mdot
.45202 .48773 Mdot
.5509 .469 Mdot
.47534 .51253 Mdot
.45528 .50245 Mdot
.50747 .47766 Mdot
.52984 .5509 Mdot
.51286 .55398 Mdot
.54171 .38105 Mdot
.50163 .48876 Mdot
.50593 .44962 Mdot
.5165 .55358 Mdot
.49951 .49296 Mdot
.45897 .50834 Mdot
.51184 .46082 Mdot
.48426 .46987 Mdot
.52668 .51769 Mdot
.60824 .55541 Mdot
.48644 .5344 Mdot
.50321 .48145 Mdot
.51599 .605 Mdot
.5211 .52096 Mdot
.57616 .49181 Mdot
.50437 .54685 Mdot
.52883 .61511 Mdot
.49239 .48106 Mdot
.48044 .49275 Mdot
.51823 .55405 Mdot
.51304 .52352 Mdot
.56638 .50863 Mdot
.50904 .54929 Mdot
.55361 .48553 Mdot
.53347 .40794 Mdot
.51143 .45987 Mdot
.6125 .44176 Mdot
.49349 .50834 Mdot
.49147 .48759 Mdot
.49483 .49903 Mdot
.60116 .56826 Mdot
.43366 .50444 Mdot
.53896 .4661 Mdot
.44731 .47392 Mdot
.42774 .51213 Mdot
.47619 .41666 Mdot
.54213 .45927 Mdot
.50922 .48831 Mdot
.55094 .47485 Mdot
.47427 .39516 Mdot
.47563 .50805 Mdot
.58621 .5404 Mdot
.47782 .517 Mdot
.51082 .57148 Mdot
.43027 .54696 Mdot
.45449 .49096 Mdot
.52106 .48432 Mdot
.55125 .47937 Mdot
.62332 .5157 Mdot
.54053 .46703 Mdot
.55106 .50066 Mdot
.48301 .52352 Mdot
.46884 .50505 Mdot
.46295 .51494 Mdot
.46746 .45936 Mdot
.49677 .48541 Mdot
.43335 .54188 Mdot
.62168 .50842 Mdot
.62094 .48822 Mdot
.55167 .47736 Mdot
.62647 .51458 Mdot
.52099 .49232 Mdot
.54914 .5015 Mdot
.55332 .47778 Mdot
.48245 .50532 Mdot
.48914 .49009 Mdot
.52175 .53178 Mdot
.4336 .54234 Mdot
.51167 .51362 Mdot
.43028 .51537 Mdot
.49715 .51186 Mdot
.54171 .52421 Mdot
.49543 .50712 Mdot
.49038 .42633 Mdot
.48859 .46227 Mdot
.55463 .5455 Mdot
.54017 .52277 Mdot
.442 .47598 Mdot
.43613 .51255 Mdot
.50748 .47082 Mdot
.50081 .50914 Mdot
.43217 .49436 Mdot
.61311 .55696 Mdot
.55137 .46947 Mdot
.38025 .47335 Mdot
.4767 .47139 Mdot
.53922 .48491 Mdot
.52877 .49028 Mdot
.53558 .54081 Mdot
.46831 .46284 Mdot
.49128 .54931 Mdot
.43496 .5197 Mdot
.52874 .4513 Mdot
.56543 .54549 Mdot
.52714 .44765 Mdot
.52995 .51917 Mdot
.53514 .54302 Mdot
.53025 .50915 Mdot
.54216 .53057 Mdot
.52623 .62383 Mdot
.54306 .53798 Mdot
.46809 .56904 Mdot
.49309 .48163 Mdot
.44716 .56521 Mdot
.47142 .50401 Mdot
.45655 .46873 Mdot
.53884 .4483 Mdot
.48383 .49733 Mdot
.55859 .45428 Mdot
.51552 .51388 Mdot
.47671 .46877 Mdot
.53012 .50374 Mdot
.52358 .43166 Mdot
.40403 .52135 Mdot
.55053 .46666 Mdot
.46926 .46545 Mdot
.49303 .49246 Mdot
.52801 .48626 Mdot
.53614 .4545 Mdot
.49766 .51728 Mdot
.54292 .5151 Mdot
.49701 .48006 Mdot
.55027 .51026 Mdot
.60478 .50106 Mdot
.48626 .47438 Mdot
.50361 .51059 Mdot
.53489 .54688 Mdot
.52888 .48008 Mdot
.47483 .51725 Mdot
.4449 .48762 Mdot
.49695 .36393 Mdot
.37998 .45084 Mdot
.43023 .53256 Mdot
.39695 .5241 Mdot
.55127 .50853 Mdot
.37966 .45407 Mdot
.48564 .4185 Mdot
.6124 .53629 Mdot
.49933 .48886 Mdot
.48565 .53325 Mdot
.4533 .5102 Mdot
.47069 .51388 Mdot
.50905 .47033 Mdot
.53654 .45428 Mdot
.43478 .48928 Mdot
.49298 .53453 Mdot
.55117 .5144 Mdot
.47394 .41624 Mdot
.54461 .61874 Mdot
.52592 .43988 Mdot
.3934 .55241 Mdot
.485 .48983 Mdot
.53056 .52987 Mdot
.52084 .60554 Mdot
.41835 .48641 Mdot
.48758 .4877 Mdot
.54163 .45526 Mdot
.44995 .51012 Mdot
.55487 .39143 Mdot
.3967 .45592 Mdot
.49975 .36404 Mdot
.45969 .48045 Mdot
.51771 .51275 Mdot
.42826 .4883 Mdot
.49006 .53896 Mdot
.44205 .47975 Mdot
.46938 .41284 Mdot
.42031 .59405 Mdot
.54038 .46773 Mdot
.54504 .45468 Mdot
.53062 .53483 Mdot
.51936 .59626 Mdot
.44835 .50885 Mdot
.47229 .46256 Mdot
.53123 .53344 Mdot
.54116 .58128 Mdot
.56024 .46209 Mdot
.45938 .50951 Mdot
.43912 .46816 Mdot
.52633 .55094 Mdot
.45516 .51298 Mdot
.51385 .49013 Mdot
.5188 .51935 Mdot
.51881 .47927 Mdot
.55273 .48602 Mdot
.5638 .60662 Mdot
.44107 .55732 Mdot
.43012 .5272 Mdot
.53692 .44264 Mdot
.49527 .4629 Mdot
.52452 .47651 Mdot
.49874 .518 Mdot
.40036 .57398 Mdot
.51725 .50519 Mdot
.59051 .54774 Mdot
.51361 .4724 Mdot
.52988 .52427 Mdot
.42778 .50056 Mdot
.50582 .52124 Mdot
.49063 .60169 Mdot
.48876 .46217 Mdot
.58139 .54522 Mdot
.44158 .55592 Mdot
.42276 .43152 Mdot
.47871 .50837 Mdot
.49901 .609 Mdot
.46881 .50719 Mdot
.43363 .52366 Mdot
.52692 .50242 Mdot
.45525 .50993 Mdot
.49395 .48283 Mdot
.57325 .39729 Mdot
.47476 .5128 Mdot
.47521 .48018 Mdot
.48926 .49485 Mdot
.54555 .5067 Mdot
.54026 .61722 Mdot
.44439 .44203 Mdot
.49823 .43227 Mdot
.52907 .4377 Mdot
.45228 .47063 Mdot
.48981 .50518 Mdot
.54475 .45659 Mdot
.4539 .50641 Mdot
.46434 .36389 Mdot
.43882 .50007 Mdot
.58677 .54269 Mdot
.55227 .51118 Mdot
.60559 .47222 Mdot
.51012 .49091 Mdot
.54474 .51431 Mdot
.46431 .50657 Mdot
.51573 .51194 Mdot
.47417 .46551 Mdot
.50131 .61005 Mdot
.52653 .50137 Mdot
.46066 .4148 Mdot
.51949 .49964 Mdot
.50496 .42525 Mdot
.47105 .50769 Mdot
.53603 .37851 Mdot
.51827 .53225 Mdot
.5336 .46695 Mdot
.58967 .42919 Mdot
.44851 .50995 Mdot
.52025 .55129 Mdot
.50607 .5565 Mdot
.5423 .44891 Mdot
.51916 .51184 Mdot
.49653 .47011 Mdot
.48314 .49133 Mdot
.51225 .50493 Mdot
.45594 .4698 Mdot
.51204 .54662 Mdot
.57109 .54277 Mdot
.49642 .45168 Mdot
.48412 .59613 Mdot
.49687 .5282 Mdot
.52471 .45822 Mdot
.46562 .45446 Mdot
.47376 .51777 Mdot
.50598 .60062 Mdot
.49515 .4693 Mdot
.52728 .54596 Mdot
.45456 .47547 Mdot
.54315 .44232 Mdot
.50467 .47757 Mdot
.5113 .49899 Mdot
.43555 .55054 Mdot
.51331 .54439 Mdot
.45278 .51107 Mdot
.58616 .43608 Mdot
.49799 .53795 Mdot
.47619 .4991 Mdot
.47172 .50154 Mdot
.45116 .46794 Mdot
.48041 .49244 Mdot
.39896 .42067 Mdot
.46603 .37698 Mdot
.57491 .60199 Mdot
.50101 .52235 Mdot
.49961 .4767 Mdot
.52326 .39355 Mdot
.55039 .47602 Mdot
.48059 .49663 Mdot
.49342 .49575 Mdot
.61249 .52906 Mdot
.50243 .53637 Mdot
.51306 .46902 Mdot
.46139 .46547 Mdot
.55335 .51542 Mdot
.4903 .60317 Mdot
.49369 .60386 Mdot
.45117 .5017 Mdot
.45813 .41791 Mdot
.50609 .5117 Mdot
.46928 .50925 Mdot
.59202 .45431 Mdot
.45442 .50931 Mdot
.52673 .4713 Mdot
.5438 .42116 Mdot
.47991 .47235 Mdot
.4555 .47159 Mdot
.49677 .59533 Mdot
.51214 .6027 Mdot
.49282 .47986 Mdot
.47997 .38013 Mdot
.45632 .38833 Mdot
.45308 .50994 Mdot
.4941 .48401 Mdot
.50075 .48596 Mdot
.52377 .54732 Mdot
.51096 .52716 Mdot
.53521 .53254 Mdot
.3796 .54296 Mdot
.50784 .51018 Mdot
.54343 .44888 Mdot
.51323 .50413 Mdot
.46849 .50751 Mdot
.49055 .47941 Mdot
.56932 .50694 Mdot
.60111 .57541 Mdot
.56715 .39696 Mdot
.5488 .46242 Mdot
.4983 .46189 Mdot
.62421 .49691 Mdot
.52233 .54731 Mdot
.36607 .49582 Mdot
.49794 .53218 Mdot
.60977 .56252 Mdot
.62135 .4869 Mdot
.46429 .44971 Mdot
.4571 .47288 Mdot
.4316 .47449 Mdot
.53918 .49877 Mdot
.48088 .52244 Mdot
.43394 .55416 Mdot
.45817 .5069 Mdot
.50569 .46295 Mdot
.49731 .43311 Mdot
.51546 .54145 Mdot
.48211 .43717 Mdot
.48795 .53183 Mdot
.52004 .47023 Mdot
.49509 .53414 Mdot
.53718 .59851 Mdot
.53124 .49964 Mdot
.54218 .48199 Mdot
.52438 .46044 Mdot
.54393 .46318 Mdot
.57872 .59788 Mdot
.51791 .48589 Mdot
.54955 .49575 Mdot
.47779 .53623 Mdot
.55249 .38968 Mdot
.50615 .49713 Mdot
.4913 .46369 Mdot
.47821 .51564 Mdot
.45243 .51138 Mdot
.51781 .50397 Mdot
.5504 .5103 Mdot
.47956 .49289 Mdot
.53679 .44475 Mdot
.43638 .38724 Mdot
.51611 .48003 Mdot
.47249 .49745 Mdot
.53595 .44251 Mdot
.43173 .49533 Mdot
.4026 .55542 Mdot
.51184 .50129 Mdot
.51989 .43151 Mdot
.42841 .51136 Mdot
.5502 .52809 Mdot
.42472 .44214 Mdot
.43031 .50298 Mdot
.48905 .54787 Mdot
.52067 .5755 Mdot
.43722 .55817 Mdot
.49096 .51078 Mdot
.43389 .53955 Mdot
.53965 .48988 Mdot
.49526 .51635 Mdot
.50425 .54239 Mdot
.52388 .52135 Mdot
.50666 .61614 Mdot
.4939 .59131 Mdot
.59061 .54745 Mdot
.52302 .46289 Mdot
.45192 .54916 Mdot
.48063 .46827 Mdot
.52409 .51863 Mdot
.49064 .47472 Mdot
.55221 .6089 Mdot
.45782 .38156 Mdot
.51345 .48507 Mdot
.49994 .4452 Mdot
.42979 .51057 Mdot
.52716 .47706 Mdot
.50227 .46849 Mdot
.55256 .59175 Mdot
.51935 .48819 Mdot
.4471 .50805 Mdot
.48403 .47888 Mdot
.46691 .50175 Mdot
.48495 .48999 Mdot
.51229 .47826 Mdot
.50814 .49565 Mdot
.48876 .5288 Mdot
.55378 .4891 Mdot
.49454 .49076 Mdot
.53056 .51513 Mdot
.46883 .49991 Mdot
.45676 .45116 Mdot
.57642 .53057 Mdot
.40155 .49545 Mdot
.44537 .47523 Mdot
.53835 .53579 Mdot
.43788 .51297 Mdot
.52842 .56964 Mdot
.51385 .57432 Mdot
.37719 .46462 Mdot
.53822 .4627 Mdot
.50501 .61535 Mdot
.50136 .51814 Mdot
.5944 .53987 Mdot
.47971 .50785 Mdot
.50958 .50273 Mdot
.55033 .47564 Mdot
.48156 .56656 Mdot
.53618 .53704 Mdot
.54582 .57598 Mdot
.49324 .50648 Mdot
.54564 .46043 Mdot
.45106 .43815 Mdot
.36921 .48008 Mdot
.45867 .51629 Mdot
.50288 .5134 Mdot
.53078 .48236 Mdot
.46013 .47446 Mdot
.51894 .55323 Mdot
.53727 .57621 Mdot
.53815 .62256 Mdot
.61224 .55741 Mdot
.43111 .4119 Mdot
.50691 .52931 Mdot
.46574 .46987 Mdot
.43516 .54658 Mdot
.53794 .45473 Mdot
.49169 .52271 Mdot
.46537 .57908 Mdot
.48798 .51443 Mdot
.46586 .464 Mdot
.5226 .54623 Mdot
.4975 .45674 Mdot
.52894 .54695 Mdot
.56846 .39796 Mdot
.45394 .47042 Mdot
.55963 .39973 Mdot
.4676 .47113 Mdot
.52818 .52522 Mdot
.47357 .41499 Mdot
.36711 .49258 Mdot
.4845 .52917 Mdot
.46064 .46781 Mdot
.52712 .51308 Mdot
.45056 .51039 Mdot
.48173 .52998 Mdot
.45013 .57133 Mdot
.47965 .50876 Mdot
.42357 .43214 Mdot
.48572 .51139 Mdot
.48782 .53366 Mdot
.45256 .4706 Mdot
.53481 .53385 Mdot
.51653 .46406 Mdot
.52591 .52258 Mdot
.47228 .52767 Mdot
.54703 .52531 Mdot
.48782 .47571 Mdot
.50248 .52141 Mdot
.4265 .41208 Mdot
.43072 .50542 Mdot
.47444 .52704 Mdot
.42644 .52017 Mdot
.4808 .49235 Mdot
.50652 .5414 Mdot
.52102 .54516 Mdot
.51979 .48769 Mdot
.57296 .40112 Mdot
.53115 .55086 Mdot
.53998 .45724 Mdot
.50958 .47317 Mdot
.50522 .48899 Mdot
.45751 .47279 Mdot
.54388 .45613 Mdot
.43262 .54663 Mdot
.49834 .52198 Mdot
.44819 .47261 Mdot
.49238 .53498 Mdot
.50103 .4676 Mdot
.51022 .45989 Mdot
.41068 .40633 Mdot
.44677 .39495 Mdot
.52663 .43501 Mdot
.36652 .49917 Mdot
.54484 .45457 Mdot
.5048 .46739 Mdot
.53549 .50592 Mdot
.49881 .53764 Mdot
.49761 .60067 Mdot
.58047 .46128 Mdot
.62161 .48769 Mdot
.40347 .40565 Mdot
.51532 .51413 Mdot
.48415 .47486 Mdot
.51335 .5975 Mdot
.5022 .51037 Mdot
.47919 .49435 Mdot
.52702 .43495 Mdot
.51563 .51452 Mdot
.49766 .48828 Mdot
.47637 .43814 Mdot
.43982 .55539 Mdot
.5266 .43628 Mdot
.50617 .53123 Mdot
.43834 .56028 Mdot
.49258 .52539 Mdot
.58171 .59952 Mdot
.45598 .57249 Mdot
.44859 .47358 Mdot
.54422 .50747 Mdot
.51354 .54769 Mdot
.48634 .5413 Mdot
.49381 .50773 Mdot
.46092 .50704 Mdot
.49476 .46597 Mdot
.52691 .5033 Mdot
.56266 .60634 Mdot
.56736 .3986 Mdot
.60204 .56677 Mdot
.52325 .55367 Mdot
.48675 .50121 Mdot
.51418 .62069 Mdot
.47418 .51485 Mdot
.53052 .49705 Mdot
.47191 .46525 Mdot
.46256 .41512 Mdot
.59739 .56851 Mdot
.52646 .45996 Mdot
.49931 .48615 Mdot
.48531 .41886 Mdot
.43526 .52184 Mdot
.48866 .48627 Mdot
.40587 .57851 Mdot
.47557 .50157 Mdot
.52412 .54423 Mdot
.50941 .5218 Mdot
.5067 .52573 Mdot
.46696 .5551 Mdot
.51741 .53026 Mdot
.50027 .55199 Mdot
.49424 .52488 Mdot
.41757 .53333 Mdot
.4898 .50994 Mdot
.46798 .41582 Mdot
.53588 .49833 Mdot
.45936 .50635 Mdot
.52655 .55259 Mdot
.53992 .44438 Mdot
.52699 .45997 Mdot
.51462 .51854 Mdot
.46995 .50391 Mdot
.48954 .52968 Mdot
.5211 .50214 Mdot
.51134 .43023 Mdot
.5272 .37553 Mdot
.53774 .54902 Mdot
.44714 .45642 Mdot
.49393 .47145 Mdot
.50779 .49846 Mdot
.57633 .48923 Mdot
.5235 .43652 Mdot
.40073 .45795 Mdot
.4933 .51588 Mdot
.46169 .50503 Mdot
.52302 .50822 Mdot
.37016 .5211 Mdot
.4859 .50655 Mdot
.50988 .52933 Mdot
.54321 .45653 Mdot
.38435 .53932 Mdot
.50199 .54046 Mdot
.50383 .50895 Mdot
.43204 .60282 Mdot
.50203 .47695 Mdot
.57806 .40882 Mdot
.42003 .45628 Mdot
.42401 .41584 Mdot
.57787 .5806 Mdot
.46103 .52079 Mdot
.55325 .5094 Mdot
.4917 .51416 Mdot
.52127 .46894 Mdot
.5094 .54408 Mdot
.53664 .54318 Mdot
.54088 .52596 Mdot
.54233 .51835 Mdot
.58222 .5415 Mdot
.42832 .54257 Mdot
.509 .51756 Mdot
.49718 .60602 Mdot
.50909 .54369 Mdot
.48588 .517 Mdot
.44447 .56234 Mdot
.492 .42449 Mdot
.4815 .46182 Mdot
.5934 .41586 Mdot
.393 .42185 Mdot
.51915 .45236 Mdot
.49677 .50703 Mdot
.49278 .44432 Mdot
.50406 .48676 Mdot
.48844 .47629 Mdot
.54055 .5325 Mdot
.51421 .43192 Mdot
.51393 .53059 Mdot
.47852 .46739 Mdot
.46045 .44194 Mdot
.54555 .45505 Mdot
.51831 .54728 Mdot
.55613 .60411 Mdot
.50896 .45977 Mdot
.61338 .44485 Mdot
.47099 .46226 Mdot
.53798 .38596 Mdot
.49893 .50736 Mdot
.5199 .49358 Mdot
.47849 .58987 Mdot
.51956 .62081 Mdot
.48851 .49128 Mdot
.46657 .5112 Mdot
.44467 .50668 Mdot
.53857 .54435 Mdot
.54097 .47677 Mdot
.49543 .54064 Mdot
.50241 .52561 Mdot
.47975 .46185 Mdot
.45078 .49428 Mdot
.48741 .53037 Mdot
.47285 .50095 Mdot
.52021 .55232 Mdot
.43668 .49445 Mdot
.44571 .47553 Mdot
.51929 .46972 Mdot
.4523 .42614 Mdot
.49361 .41278 Mdot
.41756 .40145 Mdot
.50069 .61078 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`2Cooooo`;o00002?ooool3o`000:Oooooo000Nooooo`03o`000?oo
oooooooo09?ooooo0_l00008ooooo`?o0000Yoooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo09Go
oooo0_l0000@ooooo`;o0000W_ooool001kooooo00?o0000ooooooooool0Toooool4o`00013ooooo
0_l000000ooooooo0000o`00002Kooooo`007_ooool00ol0003oooooooooo`2Aooooo`Co00000ooo
ool2o`00013ooooo1?l0002Iooooo`007_ooool00ol0003oooooooooo`2Aooooo`;o00001Oooool2
o`0001;ooooo0_l0002Iooooo`007_ooool00ol0003oooooooooo`2:ooooo`;o00001?ooool2o`00
01Wooooo0_l0002Jooooo`007_ooool00ol0003oooooooooo`2:ooooo`;o00001?ooool2o`0001Wo
oooo1?l000000ooooooo0000o`00002Eooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`2=ooooo`;o
00004Oooool2o`0000Cooooo0_l00005ooooo`;o000000?oooooo`000?l00000UOooool000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo08gooooo0_l00007ooooo`;o00002?ooool2o`0000Cooooo0_l0000<ooooo`Co
0000Soooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool3o`0008go
oooo0_l00007ooooo`;o00000_ooool2o`0000;ooooo0_l0000Booooo`Ko0000Soooool000?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000oooo
ooooool0Q?ooool2o`0000;ooooo0_l00003ooooo`;o00002oooool2o`0000;ooooo0_l0000Boooo
o`Ko0000Soooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0000Oooooo00?o0000ooooooooool0Ooooool4o`000003ooooool0003o000000;ooooo0_l0002m
ooooo`000oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool0
0ol0003oooooooooo`1oooooo`Co00009_ooool2o`0000gooooo0_l0002=ooooo`000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`27
ooooo`Co00002Oooool2o`0000Kooooo0_l0000;ooooo`;o00003Oooool2o`0008gooooo0003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooo
oooo087ooooo0_l00003ooooo`Go00001?ooool2o`000003ooooool0003o000000Go00000oooool2
o`0001oooooo0_l00028ooooo`007_ooool00ol0003oooooooooo`21ooooo`;o00000oooool2o`00
00;ooooo0_l000000ooooooo0000o`00000:o`000004ooooool0003o0000o`00023ooooo0_l00028
ooooo`007_ooool00ol0003oooooooooo`1looooo`Co00002_ooool2o`000003ooooool0003o0000
00;ooooo0_l00007ooooo`Go00003_ooool2o`0009Sooooo000Nooooo`03o`000?oooooooooo07co
oooo1?l0000Dooooo`;o00001_ooool3o`000003ooooool0003o000000_ooooo0_l0002Hooooo`00
7_ooool00ol0003oooooooooo`2?ooooo`;o00000oooool2o`0000;ooooo0_l000000ooooooo0000
o`000002o`000003ooooool0003o00000:Gooooo000Nooooo`03o`000?oooooooooo08Gooooo0_l0
0008ooooo`;o00001Oooool4o`000003ooooool0003o000000;o00000oooool6o`0001Cooooo0_l0
0029ooooo`007_ooool00ol0003oooooooooo`25ooooo`?o00003_ooool2o`0000Kooooo0_l00002
ooooo`Oo00004oooool2o`0008Wooooo000Nooooo`03o`000?oooooooooo08Kooooo0_l00007oooo
o`;o00001_ooool4o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l0000@oooo
o`;o0000Roooool001kooooo00?o0000ooooooooool0Noooool2o`0001;ooooo0_l00006ooooo`Co
00001_ooool2o`0000?ooooo1?l0000?ooooo`?o0000Roooool001kooooo00?o0000ooooooooool0
Noooool2o`0000Wooooo0_l00004ooooo`;o00001?ooool2o`0000Sooooo0_l000000ooooooo0000
o`000002o`0000Cooooo0_l000000ooooooo0000o`000002o`0000_ooooo0_l00008ooooo`;o0000
P_ooool001kooooo00?o0000ooooooooool0NOooool2o`0000[ooooo0ol00004ooooo`;o00001?oo
ool2o`0000Sooooo1Ol00007ooooo`Ko00005Oooool2o`0008;ooooo000Nooooo`03o`000?oooooo
oooo07Wooooo0_l00004ooooo`;o00001?ooool2o`0000cooooo0_l00009ooooo`Co00001Oooool8
o`0000[ooooo0_l00008ooooo`;o0000P_ooool001kooooo0_l0001hooooo`;o00001_ooool2o`00
00oooooo0_l000000ooooooo0000o`000008ooooo`;o000000?oooooo`000?l000000oooool5o`00
0003ooooool0003o000000;o00002_ooool5o`0008Wooooo000Nooooo`03o`000?oooooooooo07Oo
oooo0_l00004ooooo`;o00001Oooool2o`0000Oooooo1Ol000000ooooooo0000o`000007ooooo`?o
000000?oooooo`000?l000000oooool2o`000003ooooool0003o000000Go00000_ooool2o`0000Oo
oooo1?l00029ooooo`007_ooool00ol0003oooooooooo`1gooooo`;o00001?ooool3o`0000Cooooo
0_l00007ooooo`Co00000_ooool3o`0000Kooooo1_l000001?oooooo0000o`000?ooool2o`000003
ooooool0003o000000Co00000_ooool2o`0000Wooooo0_l00029ooooo`007_ooool00ol0003ooooo
ooooo`1nooooo`;o00005?ooool6o`000004ooooool0003o0000ooooo`_o00000_ooool5o`0000;o
oooo0_l00005ooooo`;o00001?ooool2o`0008Kooooo000Nooooo`03o`000?oooooooooo07Oooooo
0_l0000Eooooo`co000000?oooooo`000?l000003?l000000ooooooo0000o`000005o`000003oooo
ool0003o000000Gooooo0_l00004ooooo`;o0000Q_ooool001kooooo00?o0000ooooooooool0Mooo
ool2o`0000oooooo0_l000000ooooooo0000o`00000=o`0000;ooooo3?l000000ooooooo0000o`00
0006o`0009Kooooo000Nooooo`03o`000?oooooooooo07oooooo0_l00003ooooo`;o00000_ooool2
o`000005ooooool0003o0000o`000?ooool03?l000000ooooooo0000o`00000Co`00013ooooo0_l0
0024ooooo`007_ooool00ol0003oooooooooo`1hooooo`;o00001Oooool2o`0000?ooooo0_l00002
ooooo`;o00000ooooolBo`000003ooooool0003o000000So00000_ooool5o`00013ooooo0_l00024
ooooo`007_ooool00ol0003oooooooooo`1hooooo`;o00003_ooool2o`000003ooooool0003o0000
00Ko000000Coooooo`000?l0003ooooo1_l000000ooooooo0000o`00000Bo`0000oooooo0_l00024
ooooo`007_ooool00ol0003oooooooooo`1dooooo`;o00005?ooool5o`000004ooooool0003o0000
o`0000?ooooo0_l000000ooooooo0000o`00000Co`000004ooooool0003o0000o`0009Gooooo000N
ooooo`03o`000?oooooooooo07Cooooo0_l0000Dooooo`Co00000oooool2o`0000?ooooo0_l00000
0ooooooo0000o`000006o`000003ooooool0003o000000Ko00000_ooool2o`000003ooooool0003o
000009Kooooo000Nooooo`03o`000?oooooooooo08Cooooo0_l00004ooooo`?o00002?ooool2o`00
00Cooooo4ol00002ooooo`;o00005?ooool2o`0007oooooo000Nooooo`03o`000?oooooooooo08Co
oooo0_l000000ooooooo0000o`000008o`0000Cooooo0_l00003ooooo`go000000?oooooo`000?l0
00000ol00002ooooo`?o00001Oooool2o`0000gooooo0_l0001oooooo`007_ooool00ol0003ooooo
ooooo`1cooooo`;o00004_ooool4o`000003ooooool0003o000000Co00001_ooool?o`000003oooo
ool0003o000000?o00000_ooool3o`0000Cooooo0ol0000=ooooo`;o0000Ooooool001kooooo00?o
0000ooooooooool0Loooool2o`0000Gooooo0_l00002ooooo`?o00001oooool4o`0000;ooooo1?l0
0005oooooa3o00000oooool2o`0000?ooooo1?l00003ooooo`?o0000S_ooool001kooooo00?o0000
ooooooooool0Loooool2o`0000Gooooo0_l00002ooooo`?o00001?ooool2o`000003ooooool0003o
000000;o00000_ooool2o`0000Gooooo2_l000000ooooooo0000o`00000;o`0000;ooooo1?l0000D
ooooo`;o0000O_ooool001kooooo0_l0001dooooo`;o00002_ooool2o`0000Cooooo2?l00002oooo
o`?o00000_ooool8o`000003ooooool0003o000000Go000000?oooooo`000?l000001_l000001?oo
oooo0000o`000?l0000@ooooo`;o00001?ooool2o`0007kooooo000Nooooo`03o`000?oooooooooo
08Kooooo1ol00002ooooo`ko000000Coooooo`000?l0003ooooo2ol00002ooooo`?o00004?ooool2
o`0008Cooooo000Nooooo`03o`000?oooooooooo08Sooooo6?l00002ooooo`[o000000?oooooo`00
0?l000000ol00002ooooo`?o00003oooool2o`0007oooooo000Nooooo`03o`000?oooooooooo07[o
oooo0_l0000;ooooobGo000000?oooooo`000?l000000ol00002ooooo`?o00001Oooool2o`0000So
oooo0_l0001oooooo`007_ooool00ol0003oooooooooo`1jooooo`;o00002oooool5o`000003oooo
ool0003o000001_o00000oooool5o`0000[ooooo0_l0000:ooooo`;o0000OOooool001kooooo00?o
0000ooooooooool0Qoooool5o`000004ooooool0003o0000ooooo`Co000000?oooooo`000?l00000
4ol00002ooooo`Ko00005Oooool3o`0007gooooo000Nooooo`03o`000?oooooooooo07Cooooo0_l0
000@ooooo`Go00001_ooool3o`0000;ooooo5Ol000000ooooooo0000o`000004o`0001Gooooo0_l0
001nooooo`007_ooool00ol0003oooooooooo`1dooooo`;o00000oooool2o`0000;ooooo1?l00005
ooooo`Go00001oooool4o`0000;ooooo4ol000000ooooooo0000o`000004o`0009Gooooo000Noooo
o`03o`000?oooooooooo07Wooooo0_l00002ooooo`Co00001oooool3o`0000Oooooo2Ol000000ooo
oooo0000o`00000<o`0000;ooooo1_l0002Eooooo`007_ooool00ol0003oooooooooo`20ooooo`;o
00001_ooool2o`0000_ooooo0ol000000ooooooo0000o`00000?o`000003ooooool0003o000000Co
00004_ooool3o`00087ooooo000Nooooo`03o`000?oooooooooo07_ooooo0_l00003ooooo`;o0000
0_ooool2o`0000;ooooo0_l0000;ooooo`?o000000?oooooo`000?l000005_l00006ooooo`;o0000
2_ooool3o`00087ooooo000Nooooo`03o`000?oooooooooo07_ooooo0_l00007ooooo`;o00000_oo
ool2o`0000cooooo0ol000000ooooooo0000o`00000Do`0000Oooooo0_l0000:ooooo`;o0000P_oo
ool001kooooo00?o0000ooooooooool0NOooool2o`0000kooooo0_l0000<ooooo`;o000000?ooooo
o`000?l000001Ol00007ooooo`Ko00005Oooool2o`0008;ooooo000Nooooo`03o`000?oooooooooo
07Wooooo0_l0000<ooooo`Co00003oooool;o`0000Gooooo1?l00008ooooo`;o000000?oooooo`00
0?l000001?l00028ooooo`007_ooool00ol0003oooooooooo`1gooooo`;o00003_ooool4o`0000oo
oooo0_l000000ooooooo0000o`000009o`0000;ooooo0ol00003ooooo`;o00000_ooool4o`000003
ooooool0003o000000Co0000R?ooool001kooooo00?o0000ooooooooool0Moooool2o`0000oooooo
1?l0000?ooooo`;o000000?oooooo`000?l000003Ol00003ooooo`Ko00000oooool2o`000003oooo
ool0003o000000Gooooo0_l00022ooooo`007_ooool2o`0008Wooooo1?l00002ooooo`?o00002_oo
oolBo`000003ooooool0003o000000;ooooo1?l00006ooooo`;o00001Oooool2o`0008;ooooo000N
ooooo`03o`000?oooooooooo07cooooo0_l0000;ooooo`?o00000_ooool3o`0000_ooooo0_l00000
0ooooooo0000o`00000<o`000003ooooool0003o000000Cooooo0_l0002Aooooo`007_ooool00ol0
003oooooooooo`1jooooo`Co000000?oooooo`000?l000002?ooool4o`0000Oooooo0_l0000:oooo
o`;o000000?oooooo`000?l000001?l0000Iooooo`?o0000P_ooool001kooooo00?o0000oooooooo
ool0N_ooool2o`0000?ooooo0_l00009ooooo`?o00001oooool2o`0000[ooooo0_l00002ooooo`;o
00007?ooool3o`0008;ooooo000Nooooo`03o`000?oooooooooo08[ooooo1_l0000Pooooo`;o0000
4?ooool2o`0008?ooooo000Nooooo`03o`000?oooooooooo08cooooo1?l00008ooooo`;o00005_oo
ool2o`0000kooooo1?l00023ooooo`007_ooool00ol0003oooooooooo`2=ooooo`?o00001?ooool2
o`0000;ooooo0_l0000>ooooo`;o000000?oooooo`000?l000003Oooool2o`0000;ooooo1?l00025
ooooo`007_ooool00ol0003oooooooooo`2>ooooo`Co00000_ooool2o`0000cooooo0_l00004oooo
o`;o000000?oooooo`000?l000003Oooool2o`0000;ooooo0ol00026ooooo`007_ooool00ol0003o
ooooooooo`1mooooo`?o00003_ooool4o`0000?ooooo0_l0000;ooooo`Go00001?ooool4o`0000oo
oooo0ol00026ooooo`007_ooool00ol0003oooooooooo`1mooooo`Go00004Oooool4o`0000cooooo
1?l00004ooooo`Co00003oooool3o`0008Kooooo000Nooooo`03o`000?oooooooooo07kooooo1?l0
000Aooooo`;o00005oooool3o`0000Wooooo0_l0002=ooooo`007_ooool00ol0003oooooooooo`20
ooooo`;o00005?ooool2o`0000oooooo0_l00003ooooo`?o00002Oooool2o`0000?ooooo0_l00028
ooooo`007_ooool00ol0003oooooooooo`20ooooo`Co00004_ooool3o`0000;ooooo0_l0000:oooo
o`;o00005?ooool2o`0008Sooooo000Nooooo`03o`000?oooooooooo08;ooooo0_l0000Cooooo`;o
00000_ooool3o`0000kooooo0_l00002ooooo`;o0000UOooool000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000oooo
ooooool0QOooool2o`00013ooooo0_l00003ooooo`;o00003_ooool2o`0000;ooooo0_l0002Eoooo
o`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B401_ooool00ol0003oooooooooo`25ooooo`;o00004?ooool5o`000003ooooool0003o
000000Cooooo1?l00005ooooo`;o00002_ooool2o`0008gooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol00027ooooo`?o00003ooo
ool3o`000003ooooool0003o000000?o000000?oooooo`000?l000000_l00004ooooo`?o00001?oo
ool2o`0000Cooooo0ol0002<ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go
0000oiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo08Oooooo0ol0000Aooooo`Wo0000
1oooool2o`0000Cooooo0ol000000ooooooo0000o`000004o`0008cooooo0003ooooo`05o`000?oo
ooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000oooooooo
ool0R?ooool2o`00017ooooo1Ol00002ooooo`Go00001oooool2o`000003ooooool0003o000000Ko
0000S_ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00So
oooo00?o0000ooooooooool0W_ooool3o`0000?ooooo0ol00003ooooo`;o00000_ooool3o`0000;o
oooo0_l0002Booooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nH
V9P02?ooool00ol0003oooooooooo`2Nooooo`?o000000?oooooo`000?l000001_ooool2o`0000?o
oooo0_l0002Fooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0
003o410@1_ooool00ol0003oooooooooo`2Oooooo`Go00001?ooool2o`0009gooooo000Nooooo`03
o`000?oooooooooo0:3ooooo0ol00005ooooo`;o00000_ooool3o`0009Sooooo000Nooooo`03o`00
0?oooooooooo0:?ooooo1?l00004ooooo`Co0000V?ooool001kooooo00?o0000ooooooooool0Xooo
ool6o`0000;ooooo0_l0002Jooooo`007_ooool00ol0003oooooooooo`2Wooooo`;o0000W_ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?oooooo
BOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03
o`000?oooooooooo0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0oooooom8oooo
o`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006
ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8b
oiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003ooooo
ooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zj
oooooonj^[[o410@00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo
0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000
oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Dooooo`Co000000?o410@ooooooooool0
0oooool00ol0003oooooooooo`3oooooodSooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0oooooom8ooooo`005_ooool00ol0003oooooooooo`05ooooo`?o0000oooooom8
ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?oo
ooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003ooooooooo
o`3ooooooe3ooooo000Dooooo`03oeEEEOmVIVKo00000?ooooooD_ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.45927 .51584 Mdot
.4776 .51913 Mdot
.54932 .47671 Mdot
.47387 .50715 Mdot
.47486 .48539 Mdot
.50361 .57633 Mdot
.48681 .37204 Mdot
.45404 .49542 Mdot
.39668 .50999 Mdot
.45152 .4567 Mdot
.43667 .48904 Mdot
.51055 .51866 Mdot
.52154 .58621 Mdot
.56096 .51947 Mdot
.39255 .42865 Mdot
.48773 .45409 Mdot
.47271 .52526 Mdot
.45011 .56819 Mdot
.43117 .47855 Mdot
.54792 .4919 Mdot
.47044 .52634 Mdot
.51948 .4485 Mdot
.47819 .49112 Mdot
.53754 .55707 Mdot
.451 .50634 Mdot
.51326 .50439 Mdot
.44713 .43427 Mdot
.41894 .51682 Mdot
.48384 .49001 Mdot
.51304 .56309 Mdot
.52533 .55551 Mdot
.46954 .51031 Mdot
.50377 .48585 Mdot
.55824 .47056 Mdot
.52122 .57654 Mdot
.56065 .49703 Mdot
.51276 .49498 Mdot
.49309 .45889 Mdot
.4787 .4855 Mdot
.51664 .51552 Mdot
.49079 .4622 Mdot
.55182 .47634 Mdot
.51653 .54806 Mdot
.50685 .50543 Mdot
.46785 .50884 Mdot
.51927 .47547 Mdot
.58479 .47415 Mdot
.52673 .5523 Mdot
.54927 .53449 Mdot
.40453 .59359 Mdot
.4805 .48227 Mdot
.55536 .61301 Mdot
.48518 .4941 Mdot
.46981 .48896 Mdot
.47597 .45103 Mdot
.52435 .49504 Mdot
.51464 .53606 Mdot
.58951 .60321 Mdot
.46516 .49795 Mdot
.51936 .53708 Mdot
.52731 .47536 Mdot
.51669 .48274 Mdot
.55911 .47716 Mdot
.48684 .45471 Mdot
.49088 .47828 Mdot
.37764 .53862 Mdot
.50404 .55956 Mdot
.52634 .48336 Mdot
.53189 .49722 Mdot
.48862 .45382 Mdot
.45157 .39605 Mdot
.46826 .49539 Mdot
.52494 .52938 Mdot
.4928 .50779 Mdot
.52525 .56452 Mdot
.47098 .41109 Mdot
.53207 .48731 Mdot
.45125 .57759 Mdot
.46798 .39733 Mdot
.42244 .51854 Mdot
.52497 .45735 Mdot
.45099 .49607 Mdot
.46209 .5148 Mdot
.50298 .46828 Mdot
.55941 .47402 Mdot
.49011 .50254 Mdot
.52507 .43122 Mdot
.52287 .48626 Mdot
.51727 .51904 Mdot
.48477 .61598 Mdot
.49104 .48667 Mdot
.51376 .4666 Mdot
.50978 .43116 Mdot
.38555 .57249 Mdot
.5096 .4152 Mdot
.52796 .4721 Mdot
.52473 .48938 Mdot
.5188 .55894 Mdot
.58668 .46447 Mdot
.50776 .53782 Mdot
.51877 .42697 Mdot
.52459 .43581 Mdot
.46337 .49224 Mdot
.40953 .58319 Mdot
.39703 .49241 Mdot
.50361 .48579 Mdot
.57469 .38398 Mdot
.48938 .48102 Mdot
.50228 .55191 Mdot
.51328 .46536 Mdot
.50149 .54903 Mdot
.46813 .49644 Mdot
.4949 .52273 Mdot
.44683 .47805 Mdot
.49502 .56119 Mdot
.52845 .60904 Mdot
.45921 .45558 Mdot
.41827 .51255 Mdot
.5442 .51374 Mdot
.50224 .43103 Mdot
.44949 .57277 Mdot
.51076 .50593 Mdot
.45676 .45356 Mdot
.53843 .54655 Mdot
.47677 .52417 Mdot
.46813 .46369 Mdot
.51619 .55343 Mdot
.51149 .50464 Mdot
.50787 .50359 Mdot
.4779 .45679 Mdot
.42836 .54382 Mdot
.47749 .53716 Mdot
.60579 .56378 Mdot
.55773 .5048 Mdot
.45589 .4975 Mdot
.60876 .5496 Mdot
.46002 .45308 Mdot
.50079 .49733 Mdot
.52992 .51619 Mdot
.50097 .51748 Mdot
.4898 .4831 Mdot
.41948 .47771 Mdot
.50647 .4966 Mdot
.47575 .50149 Mdot
.50262 .47768 Mdot
.51469 .46569 Mdot
.47068 .52315 Mdot
.5326 .46617 Mdot
.49695 .56266 Mdot
.54388 .54087 Mdot
.55966 .49118 Mdot
.41753 .51936 Mdot
.48331 .48396 Mdot
.5298 .5492 Mdot
.43133 .5282 Mdot
.48767 .45392 Mdot
.51293 .48067 Mdot
.56954 .58026 Mdot
.53198 .48793 Mdot
.50087 .47982 Mdot
.42643 .40155 Mdot
.53805 .48537 Mdot
.45925 .58854 Mdot
.47075 .45199 Mdot
.51664 .52745 Mdot
.50273 .53068 Mdot
.39935 .47873 Mdot
.53958 .46218 Mdot
.541 .45654 Mdot
.48849 .46162 Mdot
.42503 .5192 Mdot
.53686 .54365 Mdot
.48459 .52756 Mdot
.5195 .52533 Mdot
.41652 .39186 Mdot
.51895 .49326 Mdot
.52048 .46387 Mdot
.49923 .47786 Mdot
.60046 .48411 Mdot
.54873 .5226 Mdot
.47645 .50557 Mdot
.52113 .47033 Mdot
.49767 .50498 Mdot
.48367 .49359 Mdot
.5221 .59511 Mdot
.50761 .52045 Mdot
.54339 .45288 Mdot
.52774 .47625 Mdot
.38514 .56377 Mdot
.49549 .42358 Mdot
.50472 .51278 Mdot
.48382 .45908 Mdot
.52899 .55548 Mdot
.48552 .48274 Mdot
.49186 .46012 Mdot
.48872 .46322 Mdot
.40332 .59524 Mdot
.50615 .49466 Mdot
.49543 .47592 Mdot
.47788 .51232 Mdot
.50039 .53682 Mdot
.52919 .48293 Mdot
.44061 .56295 Mdot
.55095 .46305 Mdot
.47337 .4511 Mdot
.4889 .53118 Mdot
.47163 .53603 Mdot
.51209 .53979 Mdot
.55798 .47054 Mdot
.48318 .48216 Mdot
.46812 .51167 Mdot
.5101 .49632 Mdot
.52323 .51009 Mdot
.46725 .57606 Mdot
.51087 .50637 Mdot
.58449 .47676 Mdot
.51804 .46988 Mdot
.53014 .4916 Mdot
.42188 .47787 Mdot
.49426 .48115 Mdot
.48854 .4674 Mdot
.59008 .59205 Mdot
.51573 .46653 Mdot
.57668 .53364 Mdot
.4401 .48773 Mdot
.44906 .4965 Mdot
.46831 .5053 Mdot
.45189 .45489 Mdot
.5491 .46194 Mdot
.42415 .49725 Mdot
.46935 .44476 Mdot
.50916 .49751 Mdot
.4441 .47602 Mdot
.51035 .48466 Mdot
.51722 .50057 Mdot
.53052 .51747 Mdot
.4641 .4696 Mdot
.4791 .40967 Mdot
.48452 .5363 Mdot
.5077 .52048 Mdot
.45097 .45539 Mdot
.40273 .42303 Mdot
.48296 .53848 Mdot
.47319 .46359 Mdot
.52474 .41168 Mdot
.48029 .45172 Mdot
.4593 .40945 Mdot
.45263 .49507 Mdot
.45999 .45041 Mdot
.44607 .45602 Mdot
.51541 .54611 Mdot
.51943 .60006 Mdot
.41881 .43329 Mdot
.51765 .41488 Mdot
.49503 .5185 Mdot
.50805 .52617 Mdot
.47307 .48431 Mdot
.52506 .5012 Mdot
.5582 .46955 Mdot
.42291 .45658 Mdot
.54274 .46328 Mdot
.48334 .4601 Mdot
.50126 .47988 Mdot
.44815 .55823 Mdot
.55176 .49267 Mdot
.55785 .47703 Mdot
.43537 .49574 Mdot
.42747 .54138 Mdot
.49458 .46796 Mdot
.60475 .4916 Mdot
.50655 .55558 Mdot
.49526 .52311 Mdot
.38284 .56092 Mdot
.49901 .52027 Mdot
.54185 .45684 Mdot
.45608 .40441 Mdot
.52851 .49073 Mdot
.43735 .47117 Mdot
.54394 .49657 Mdot
.44399 .46895 Mdot
.53139 .50781 Mdot
.51804 .50565 Mdot
.54332 .527 Mdot
.50515 .48865 Mdot
.46924 .46192 Mdot
.39031 .57744 Mdot
.59204 .4767 Mdot
.48189 .48234 Mdot
.48384 .53241 Mdot
.52183 .55406 Mdot
.51237 .52665 Mdot
.51023 .56136 Mdot
.5174 .61153 Mdot
.52446 .54731 Mdot
.5024 .53068 Mdot
.46495 .49037 Mdot
.42187 .52523 Mdot
.54975 .51555 Mdot
.55554 .47115 Mdot
.47256 .50596 Mdot
.50706 .49997 Mdot
.4485 .49646 Mdot
.38799 .50302 Mdot
.50003 .45867 Mdot
.51079 .52289 Mdot
.47328 .50554 Mdot
.63322 .50621 Mdot
.49824 .55726 Mdot
.44921 .50672 Mdot
.54982 .49902 Mdot
.48302 .50897 Mdot
.50516 .48785 Mdot
.44905 .48167 Mdot
.44318 .50009 Mdot
.48122 .51706 Mdot
.49162 .56459 Mdot
.51725 .51404 Mdot
.52504 .48457 Mdot
.52576 .52613 Mdot
.49944 .45973 Mdot
.54578 .53128 Mdot
.44262 .48894 Mdot
.45148 .49493 Mdot
.52115 .49458 Mdot
.42407 .51011 Mdot
.50523 .45593 Mdot
.50573 .50988 Mdot
.50815 .50472 Mdot
.41326 .50417 Mdot
.53643 .44891 Mdot
.48077 .5332 Mdot
.5419 .60542 Mdot
.49553 .52444 Mdot
.44852 .45888 Mdot
.56108 .47719 Mdot
.46557 .46317 Mdot
.55872 .49611 Mdot
.47054 .50065 Mdot
.4414 .48448 Mdot
.51848 .48449 Mdot
.5079 .5606 Mdot
.48681 .56033 Mdot
.56409 .38416 Mdot
.50574 .49376 Mdot
.52812 .44825 Mdot
.49354 .55628 Mdot
.50504 .49017 Mdot
.45907 .49255 Mdot
.54006 .46286 Mdot
.50295 .46797 Mdot
.51329 .53261 Mdot
.60038 .57222 Mdot
.46944 .52041 Mdot
.51246 .48882 Mdot
.49333 .60351 Mdot
.50751 .53175 Mdot
.55966 .51887 Mdot
.48357 .54147 Mdot
.50723 .62008 Mdot
.50288 .48368 Mdot
.49226 .47707 Mdot
.49311 .56399 Mdot
.50017 .52787 Mdot
.54391 .53459 Mdot
.48745 .54657 Mdot
.54397 .52017 Mdot
.54752 .43289 Mdot
.53774 .46028 Mdot
.62251 .45834 Mdot
.49135 .50161 Mdot
.50035 .47971 Mdot
.49831 .49331 Mdot
.59221 .58362 Mdot
.43193 .48782 Mdot
.54929 .50196 Mdot
.46374 .45226 Mdot
.42729 .49321 Mdot
.50499 .41986 Mdot
.54822 .4803 Mdot
.5118 .49864 Mdot
.55419 .50187 Mdot
.49659 .4031 Mdot
.47427 .49632 Mdot
.56634 .55689 Mdot
.46724 .50308 Mdot
.48939 .55505 Mdot
.41829 .51773 Mdot
.46916 .46617 Mdot
.52253 .49923 Mdot
.55232 .5065 Mdot
.62633 .5366 Mdot
.54242 .48969 Mdot
.54551 .52773 Mdot
.46898 .50938 Mdot
.48513 .48436 Mdot
.45687 .49753 Mdot
.48991 .45542 Mdot
.50452 .48541 Mdot
.42353 .51142 Mdot
.62384 .52952 Mdot
.62643 .50881 Mdot
.55547 .50555 Mdot
.63665 .53587 Mdot
.51775 .50689 Mdot
.54211 .52797 Mdot
.56017 .50739 Mdot
.48166 .49492 Mdot
.49745 .48061 Mdot
.50367 .54001 Mdot
.42532 .51483 Mdot
.50355 .51802 Mdot
.43064 .48383 Mdot
.49331 .5061 Mdot
.5288 .55114 Mdot
.49405 .5015 Mdot
.51978 .43237 Mdot
.50885 .46191 Mdot
.52434 .55725 Mdot
.52489 .54132 Mdot
.45746 .45289 Mdot
.43974 .48146 Mdot
.52161 .47698 Mdot
.49821 .50622 Mdot
.44075 .46536 Mdot
.61526 .58014 Mdot
.56064 .49773 Mdot
.38849 .45618 Mdot
.49397 .46692 Mdot
.53577 .50879 Mdot
.52223 .50958 Mdot
.50752 .55794 Mdot
.48954 .45412 Mdot
.47133 .54054 Mdot
.43658 .48858 Mdot
.54445 .45793 Mdot
.53755 .5563 Mdot
.54116 .45551 Mdot
.516 .53554 Mdot
.50577 .55732 Mdot
.51883 .52678 Mdot
.52711 .54887 Mdot
.50397 .63106 Mdot
.51762 .55858 Mdot
.44531 .55042 Mdot
.50339 .48479 Mdot
.42766 .54233 Mdot
.47273 .4915 Mdot
.47525 .45235 Mdot
.55922 .47424 Mdot
.48827 .48732 Mdot
.55832 .48752 Mdot
.50545 .52107 Mdot
.4961 .46394 Mdot
.51954 .52265 Mdot
.54859 .44594 Mdot
.41435 .49792 Mdot
.55918 .49331 Mdot
.50397 .45961 Mdot
.49962 .48538 Mdot
.52354 .5054 Mdot
.55384 .46449 Mdot
.49072 .51119 Mdot
.53223 .54667 Mdot
.50891 .48497 Mdot
.54134 .5347 Mdot
.5973 .52274 Mdot
.50269 .47505 Mdot
.4997 .50943 Mdot
.51037 .56053 Mdot
.5264 .49974 Mdot
.45435 .49426 Mdot
.4567 .46226 Mdot
.5167 .35167 Mdot
.3791 .42811 Mdot
.42438 .50113 Mdot
.40535 .50249 Mdot
.54696 .53791 Mdot
.37718 .43064 Mdot
.51463 .42472 Mdot
.60472 .55457 Mdot
.50546 .48887 Mdot
.46892 .51893 Mdot
.45115 .49535 Mdot
.46293 .49699 Mdot
.52322 .47688 Mdot
.55255 .46372 Mdot
.44531 .46185 Mdot
.46322 .52034 Mdot
.54148 .53832 Mdot
.50253 .41839 Mdot
.5279 .62768 Mdot
.55205 .46388 Mdot
.38842 .53249 Mdot
.4965 .4763 Mdot
.5132 .54261 Mdot
.49903 .60463 Mdot
.4427 .46873 Mdot
.49925 .47576 Mdot
.55415 .46755 Mdot
.44397 .4971 Mdot
.58117 .39296 Mdot
.41166 .44049 Mdot
.51812 .36017 Mdot
.47438 .45993 Mdot
.5069 .52178 Mdot
.43681 .46038 Mdot
.46316 .52944 Mdot
.45636 .45788 Mdot
.49782 .41855 Mdot
.39672 .58508 Mdot
.54191 .49046 Mdot
.55992 .4802 Mdot
.51201 .54566 Mdot
.49843 .59012 Mdot
.44611 .49658 Mdot
.49338 .45552 Mdot
.51313 .54512 Mdot
.51891 .57619 Mdot
.55731 .49526 Mdot
.44227 .49439 Mdot
.45551 .45054 Mdot
.50478 .55711 Mdot
.44244 .49953 Mdot
.51412 .50207 Mdot
.50568 .52898 Mdot
.52488 .49081 Mdot
.55393 .51445 Mdot
.54898 .617 Mdot
.42486 .5324 Mdot
.42657 .49534 Mdot
.55623 .45926 Mdot
.51465 .46563 Mdot
.52792 .4925 Mdot
.49139 .51244 Mdot
.38599 .55883 Mdot
.50933 .51527 Mdot
.57113 .56072 Mdot
.52578 .48087 Mdot
.51447 .53868 Mdot
.43377 .47001 Mdot
.49595 .51996 Mdot
.46264 .59531 Mdot
.50961 .46247 Mdot
.55872 .55828 Mdot
.42372 .53371 Mdot
.44417 .42087 Mdot
.47666 .49708 Mdot
.47076 .6053 Mdot
.46677 .49356 Mdot
.43564 .49476 Mdot
.51629 .51959 Mdot
.46528 .49481 Mdot
.50352 .48145 Mdot
.59613 .40115 Mdot
.46811 .49981 Mdot
.49105 .46438 Mdot
.49542 .48643 Mdot
.53611 .53082 Mdot
.52202 .62461 Mdot
.47297 .43651 Mdot
.52775 .44074 Mdot
.55322 .45918 Mdot
.47015 .4516 Mdot
.48941 .49743 Mdot
.55338 .47824 Mdot
.47117 .48417 Mdot
.47913 .35542 Mdot
.44646 .47021 Mdot
.56651 .55774 Mdot
.54706 .53922 Mdot
.60388 .49376 Mdot
.51068 .50093 Mdot
.53275 .53617 Mdot
.46389 .49128 Mdot
.50616 .51972 Mdot
.4942 .45896 Mdot
.47362 .60835 Mdot
.51625 .51834 Mdot
.48784 .41221 Mdot
.51273 .51192 Mdot
.53393 .44464 Mdot
.46941 .4951 Mdot
.561 .37695 Mdot
.49979 .53804 Mdot
.5356 .48675 Mdot
.59694 .44916 Mdot
.45491 .49738 Mdot
.49831 .55458 Mdot
.48486 .55655 Mdot
.55815 .47213 Mdot
.50795 .52207 Mdot
.51341 .47235 Mdot
.49656 .47538 Mdot
.50719 .51156 Mdot
.47441 .45361 Mdot
.48069 .53417 Mdot
.54526 .55671 Mdot
.51435 .46301 Mdot
.45762 .5865 Mdot
.48113 .52232 Mdot
.5462 .46193 Mdot
.48595 .45113 Mdot
.4502 .49986 Mdot
.48208 .5959 Mdot
.51252 .47092 Mdot
.50701 .55263 Mdot
.4704 .45717 Mdot
.55042 .47732 Mdot
.5165 .48361 Mdot
.50832 .50666 Mdot
.41854 .52116 Mdot
.47983 .53923 Mdot
.46884 .49102 Mdot
.5923 .45853 Mdot
.46758 .525 Mdot
.48009 .48689 Mdot
.485 .4823 Mdot
.47041 .45116 Mdot
.49097 .47855 Mdot
.41039 .40365 Mdot
.48377 .37545 Mdot
.56283 .61508 Mdot
.49089 .51842 Mdot
.51329 .48139 Mdot
.53934 .41246 Mdot
.55192 .50276 Mdot
.48595 .48507 Mdot
.4987 .48908 Mdot
.60678 .54901 Mdot
.4837 .53069 Mdot
.52697 .47751 Mdot
.48124 .4522 Mdot
.54577 .54099 Mdot
.46192 .59645 Mdot
.46536 .59888 Mdot
.43995 .48314 Mdot
.48521 .41453 Mdot
.50094 .51218 Mdot
.46395 .49416 Mdot
.59162 .47807 Mdot
.45621 .49407 Mdot
.53079 .48836 Mdot
.55448 .45039 Mdot
.49655 .46949 Mdot
.47349 .45617 Mdot
.47271 .58733 Mdot
.48903 .59965 Mdot
.50518 .48312 Mdot
.49828 .38482 Mdot
.47642 .38812 Mdot
.44134 .4967 Mdot
.50361 .48129 Mdot
.50672 .49257 Mdot
.50211 .55149 Mdot
.49669 .53003 Mdot
.5184 .54664 Mdot
.37169 .52682 Mdot
.50285 .51226 Mdot
.55717 .46904 Mdot
.50782 .5118 Mdot
.46592 .49362 Mdot
.50191 .47813 Mdot
.54744 .5326 Mdot
.59962 .59709 Mdot
.58829 .40512 Mdot
.55973 .48881 Mdot
.52729 .45817 Mdot
.63599 .51795 Mdot
.48777 .54289 Mdot
.36128 .4781 Mdot
.48031 .5251 Mdot
.60822 .58358 Mdot
.62854 .50743 Mdot
.48237 .44675 Mdot
.47413 .45715 Mdot
.44293 .45099 Mdot
.53185 .52299 Mdot
.46712 .50656 Mdot
.41886 .52653 Mdot
.46303 .49135 Mdot
.52326 .47251 Mdot
.52687 .44145 Mdot
.49475 .54136 Mdot
.51271 .44098 Mdot
.47113 .51843 Mdot
.53034 .48219 Mdot
.47762 .52494 Mdot
.51741 .59731 Mdot
.52179 .52029 Mdot
.54059 .50773 Mdot
.53305 .47761 Mdot
.55913 .49385 Mdot
.56709 .61101 Mdot
.51942 .49966 Mdot
.54416 .52265 Mdot
.45718 .52365 Mdot
.58093 .38677 Mdot
.50692 .49995 Mdot
.51081 .46407 Mdot
.47154 .50413 Mdot
.46523 .49721 Mdot
.51003 .51462 Mdot
.53396 .54134 Mdot
.49026 .47858 Mdot
.54687 .48076 Mdot
.45349 .38089 Mdot
.5229 .49054 Mdot
.48054 .48231 Mdot
.55692 .46382 Mdot
.43992 .46609 Mdot
.39808 .53276 Mdot
.50806 .50858 Mdot
.54594 .4485 Mdot
.42409 .47855 Mdot
.52366 .55177 Mdot
.44884 .43207 Mdot
.42942 .46988 Mdot
.46817 .53942 Mdot
.49844 .56223 Mdot
.42062 .53134 Mdot
.48735 .5027 Mdot
.42642 .51048 Mdot
.5349 .5141 Mdot
.48878 .50942 Mdot
.47296 .53596 Mdot
.50981 .53409 Mdot
.48013 .61495 Mdot
.47025 .58117 Mdot
.57126 .56054 Mdot
.53245 .47867 Mdot
.43306 .52523 Mdot
.49992 .46488 Mdot
.51051 .53181 Mdot
.50691 .47647 Mdot
.53561 .61633 Mdot
.47633 .3796 Mdot
.51694 .49706 Mdot
.51705 .45416 Mdot
.43213 .479 Mdot
.52747 .49578 Mdot
.5182 .47303 Mdot
.53268 .59407 Mdot
.51907 .50245 Mdot
.43958 .49634 Mdot
.49787 .46831 Mdot
.47425 .48532 Mdot
.49599 .47678 Mdot
.5216 .48654 Mdot
.50766 .50214 Mdot
.46419 .50586 Mdot
.55438 .51747 Mdot
.50168 .48478 Mdot
.5179 .5327 Mdot
.47529 .48448 Mdot
.47194 .44014 Mdot
.55363 .54992 Mdot
.41863 .47699 Mdot
.46112 .45269 Mdot
.52333 .55615 Mdot
.44295 .48261 Mdot
.5037 .55776 Mdot
.49226 .55928 Mdot
.37086 .44024 Mdot
.5425 .4833 Mdot
.47825 .61442 Mdot
.49382 .51395 Mdot
.57767 .557 Mdot
.47779 .49674 Mdot
.50693 .50728 Mdot
.55904 .50655 Mdot
.46018 .54657 Mdot
.52046 .55869 Mdot
.5217 .57238 Mdot
.49216 .49995 Mdot
.56222 .48841 Mdot
.48006 .4345 Mdot
.36918 .46164 Mdot
.44432 .50211 Mdot
.49761 .51115 Mdot
.52666 .50271 Mdot
.47521 .45718 Mdot
.496 .55705 Mdot
.51382 .56872 Mdot
.51915 .63237 Mdot
.61253 .5796 Mdot
.45311 .40303 Mdot
.49189 .52983 Mdot
.48454 .45968 Mdot
.42299 .51697 Mdot
.54619 .46869 Mdot
.48006 .51539 Mdot
.44184 .56177 Mdot
.48209 .50537 Mdot
.5003 .45842 Mdot
.50131 .5495 Mdot
.52355 .45198 Mdot
.50911 .55508 Mdot
.59352 .39994 Mdot
.47211 .45273 Mdot
.57499 .41536 Mdot
.48402 .46065 Mdot
.51252 .53846 Mdot
.50267 .42113 Mdot
.35859 .4737 Mdot
.45698 .51432 Mdot
.47977 .45434 Mdot
.51455 .52868 Mdot
.44426 .49706 Mdot
.46674 .51398 Mdot
.42667 .54925 Mdot
.47724 .49761 Mdot
.44538 .4217 Mdot
.48115 .50176 Mdot
.46631 .50738 Mdot
.47049 .45177 Mdot
.51793 .5475 Mdot
.52986 .47741 Mdot
.51115 .53602 Mdot
.45139 .51343 Mdot
.53526 .54872 Mdot
.50331 .47714 Mdot
.49296 .51802 Mdot
.44745 .40204 Mdot
.4354 .47412 Mdot
.45163 .5132 Mdot
.42011 .48768 Mdot
.49217 .47735 Mdot
.48682 .53733 Mdot
.4997 .54761 Mdot
.5196 .50214 Mdot
.59261 .41072 Mdot
.50975 .56088 Mdot
.54585 .4952 Mdot
.52215 .48031 Mdot
.50825 .49719 Mdot
.47445 .45715 Mdot
.55305 .47602 Mdot
.42237 .52195 Mdot
.4884 .51673 Mdot
.48058 .46045 Mdot
.46259 .52186 Mdot
.51744 .47176 Mdot
.52603 .47325 Mdot
.42521 .39301 Mdot
.46756 .39366 Mdot
.55079 .44966 Mdot
.36144 .48173 Mdot
.55453 .47516 Mdot
.52075 .47277 Mdot
.52599 .52765 Mdot
.48004 .52945 Mdot
.47241 .59549 Mdot
.57846 .48856 Mdot
.62962 .5083 Mdot
.4137 .38914 Mdot
.50527 .52112 Mdot
.49837 .47407 Mdot
.49182 .5914 Mdot
.49872 .50823 Mdot
.48727 .48172 Mdot
.55134 .45262 Mdot
.5053 .52166 Mdot
.50486 .48632 Mdot
.50744 .44067 Mdot
.42262 .5283 Mdot
.55151 .45814 Mdot
.48906 .52937 Mdot
.4184 .53504 Mdot
.4788 .51796 Mdot
.57348 .61696 Mdot
.43433 .55178 Mdot
.48089 .46087 Mdot
.5368 .54081 Mdot
.48222 .53528 Mdot
.46265 .53163 Mdot
.49201 .50126 Mdot
.47053 .4898 Mdot
.51282 .46761 Mdot
.51612 .5203 Mdot
.54752 .6163 Mdot
.58695 .40885 Mdot
.59311 .58216 Mdot
.49876 .5613 Mdot
.4884 .49272 Mdot
.4885 .62387 Mdot
.46462 .49868 Mdot
.52158 .51711 Mdot
.49203 .45747 Mdot
.49065 .41504 Mdot
.58567 .58222 Mdot
.53403 .47803 Mdot
.50526 .49193 Mdot
.51516 .42866 Mdot
.43683 .49136 Mdot
.50029 .47541 Mdot
.3902 .56308 Mdot
.47792 .48972 Mdot
.50343 .54852 Mdot
.49834 .52311 Mdot
.49395 .5258 Mdot
.44641 .5317 Mdot
.50077 .53689 Mdot
.48088 .54487 Mdot
.48071 .51823 Mdot
.42382 .50342 Mdot
.48654 .50157 Mdot
.49659 .41712 Mdot
.52801 .52103 Mdot
.46461 .49074 Mdot
.50098 .56346 Mdot
.55689 .46384 Mdot
.55019 .46512 Mdot
.5032 .52424 Mdot
.48392 .484 Mdot
.47356 .51872 Mdot
.51258 .515 Mdot
.53931 .44127 Mdot
.54581 .38172 Mdot
.50411 .54941 Mdot
.47874 .44995 Mdot
.51104 .47308 Mdot
.50732 .50262 Mdot
.56133 .51699 Mdot
.54849 .45036 Mdot
.4178 .44304 Mdot
.48702 .50836 Mdot
.46755 .48918 Mdot
.51162 .5219 Mdot
.36538 .50489 Mdot
.48414 .49705 Mdot
.49446 .53159 Mdot
.55494 .47149 Mdot
.38353 .5208 Mdot
.48241 .53348 Mdot
.50072 .5082 Mdot
.4053 .59796 Mdot
.51493 .48233 Mdot
.59447 .42178 Mdot
.4447 .44486 Mdot
.4445 .4048 Mdot
.56109 .58883 Mdot
.44935 .50492 Mdot
.54587 .53479 Mdot
.48629 .50604 Mdot
.53118 .48181 Mdot
.47693 .53454 Mdot
.51709 .5601 Mdot
.52421 .55347 Mdot
.52862 .53849 Mdot
.5605 .55702 Mdot
.41797 .51266 Mdot
.50007 .51894 Mdot
.46923 .59812 Mdot
.48866 .5411 Mdot
.47832 .50738 Mdot
.42443 .53723 Mdot
.52124 .43116 Mdot
.50233 .45881 Mdot
.6061 .42977 Mdot
.40142 .40334 Mdot
.54653 .46235 Mdot
.49542 .50212 Mdot
.5102 .45019 Mdot
.50883 .49474 Mdot
.50341 .47789 Mdot
.52505 .54948 Mdot
.54232 .45363 Mdot
.49719 .53514 Mdot
.49808 .46315 Mdot
.4912 .44027 Mdot
.55651 .47802 Mdot
.48536 .54617 Mdot
.53923 .61127 Mdot
.53575 .45952 Mdot
.62313 .4618 Mdot
.49248 .45496 Mdot
.56755 .38027 Mdot
.49731 .50354 Mdot
.51651 .50737 Mdot
.45191 .57319 Mdot
.49549 .62552 Mdot
.49644 .48173 Mdot
.46163 .49446 Mdot
.44626 .49561 Mdot
.51371 .56034 Mdot
.54324 .51461 Mdot
.4665 .53249 Mdot
.48998 .52309 Mdot
.50204 .45917 Mdot
.46448 .46758 Mdot
.45902 .51524 Mdot
.48663 .48165 Mdot
.49085 .557 Mdot
.44541 .46608 Mdot
.46174 .4544 Mdot
.53025 .48151 Mdot
.47956 .42217 Mdot
.51996 .4297 Mdot
.4338 .39055 Mdot
.47284 .60786 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000YOooool2o`000:7ooooo000Nooooo`03o`000?oooooooooo0:Cooooo0_l0002Q
ooooo`007_ooool00ol0003oooooooooo`2Hooooo`;o0000[Oooool001kooooo00?o0000oooooooo
ool0V?ooool2o`0000[ooooo0_l0002Qooooo`007_ooool00ol0003oooooooooo`2Tooooo`;o0000
XOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo09[ooooo0_l0002[ooooo`007_ooool00ol0003o
ooooooooo`2Iooooo`?o0000Zoooool001kooooo00?o0000ooooooooool0Uoooool4o`0001Oooooo
0_l0002Cooooo`007_ooool00ol0003oooooooooo`2?ooooo`;o00001_ooool2o`0001Cooooo0_l0
0003ooooo`Co0000TOooool001kooooo00?o0000ooooooooool0Soooool2o`0000gooooo0_l0000=
ooooo`;o00001?ooool3o`000003ooooool0003o000008kooooo000Nooooo`03o`000?oooooooooo
09Oooooo0_l00005ooooo`;o00004oooool2o`0000;ooooo1?l0002<ooooo`007_ooool00ol0003o
ooooooooo`22ooooo`?o00001?ooool2o`0000cooooo0_l0000Pooooo`;o0000S?ooool000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Co
oooo00?o0000ooooooooool0P_ooool3o`000004ooooool0003o0000ooooo`;o00002Oooool2o`00
02?ooooo0_l0002<ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Q_ooool2o`0000Oooooo0_l00003oooo
o`;o00008oooool2o`0008cooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`00
00Kooooo0ol0002?ooooo`;o00000oooool2o`0002Oooooo0ol00027ooooo`000oooool01Ol0003o
oooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool00ol0003oooooooooo`1n
ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Cooooo1?l0000<ooooo`;o00007_ooool3
o`0008Oooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0
0007ooooo`03o`000?oooooooooo07kooooo0_l000000ooooooo0000o`000004ooooo`;o00000ooo
ool6o`0000_ooooo0_l0000Looooo`;o0000R_ooool000?ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0S?ooool2o`0000;ooooo0ol0
0005ooooo`;o00008Oooool2o`0008[ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo097ooooo0_l00002ooooo`;o000000?o
ooooo`000?l000000_l0000:ooooo`;o00000oooool2o`0000kooooo1?l00028ooooo`000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooooooo
o`2Eooooo`;o00000oooool3o`0000Gooooo1_l00003ooooo`;o00002_ooool2o`0000Cooooo0_l0
0028ooooo`007_ooool00ol0003oooooooooo`2Jooooo`Oo000000?oooooo`000?l000000_l0000A
ooooo`;o0000S_ooool001kooooo00?o0000ooooooooool0S?ooool3o`0000Wooooo0_l00003oooo
o`Go00006oooool2o`0008Sooooo000Nooooo`03o`000?oooooooooo07oooooo0_l0000;ooooo`?o
00002Oooool2o`0000?ooooo1Ol000000ooooooo0000o`00000Hooooo`;o0000R?ooool001kooooo
00?o0000ooooooooool0Moooool2o`0000?ooooo0_l000000ooooooo0000o`00000Looooo`;o0000
1?ooool4o`000:3ooooo000Nooooo`03o`000?oooooooooo07Oooooo0_l00003ooooo`;o00008Ooo
ool2o`000003ooooool0003o000000Go00006?ooool2o`0008Cooooo000Nooooo`03o`000?oooooo
oooo07Oooooo0_l0000;ooooo`;o00001oooool3o`0000Sooooo0_l00005ooooo`;o000000Cooooo
o`000?l0003ooooo1?l00005ooooo`;o00004Oooool2o`0008Cooooo000Nooooo`03o`000?oooooo
oooo08Cooooo0_l00007ooooo`?o00001_ooool4o`0000_ooooo0ol00006ooooo`;o0000Uoooool0
01kooooo00?o0000ooooooooool0M?ooool2o`0000cooooo0_l0000Aooooo`?o00001?ooool2o`00
00?ooooo1?l000001?oooooo0000o`000?l00002ooooo`;o0000V_ooool001kooooo00?o0000oooo
ooooool0M?ooool2o`0000cooooo1?l0000?ooooo`;o00001Oooool2o`0000?ooooo1?l00002oooo
o`;o00000_ooool2o`0009[ooooo000Nooooo`03o`000?oooooooooo08Cooooo0_l00006ooooo`;o
00001_ooool2o`0000?ooooo0_l0000<ooooo`Co00000oooool2o`0009Oooooo000Nooooo`03o`00
0?oooooooooo08cooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool3o`0000Oooooo
0_l000001?oooooo0000o`000?ooool4o`000003ooooool0003o000000?o00003?ooool2o`0008Oo
oooo000Nooooo`;o0000SOooool2o`0000;ooooo3?l00006ooooo`;o000000?oooooo`000?l00000
1Ol000000ooooooo0000o`000003o`0000cooooo0_l00027ooooo`007_ooool00ol0003ooooooooo
o`1jooooo`;o00002Oooool2o`0000Gooooo4_l00002ooooo`;o00000_ooool4o`0000Cooooo1Ol0
002Fooooo`007_ooool00ol0003oooooooooo`1jooooo`;o00002Oooool2o`0000Kooooo1ol00000
0ooooooo0000o`00000;o`0000;ooooo0_l000001?oooooo0000o`000?ooool9o`0000Wooooo0_l0
0008ooooo`;o0000Ooooool001kooooo00?o0000ooooooooool0M?ooool2o`0001Cooooo0_l00000
0ooooooo0000o`000003o`0000;ooooo4?l00003ooooo`;o000000?oooooo`000?l000001ol00009
ooooo`;o00002?ooool2o`0007oooooo000Nooooo`03o`000?oooooooooo07Cooooo0_l0000Doooo
o`Go000000Coooooo`000?l0003ooooo3Ol000000ooooooo0000o`000004o`0000Cooooo2?l00008
ooooo`;o00002Oooool2o`0007oooooo000Nooooo`03o`000?oooooooooo08_ooooo1?l00004oooo
o`Go00000oooool6o`000003ooooool0003o000000?o00000_ooool:o`0000Sooooo0_l0002:oooo
o`007_ooool00ol0003oooooooooo`27ooooo`So00001?ooool3o`0000Gooooo1_l00002ooooo`Co
00000_ooool2o`0000;ooooo0_l000001?oooooo0000o`000?l0002Dooooo`007_ooool00ol0003o
ooooooooo`1`ooooo`;o00005Oooool5o`000003ooooool0003o000000Cooooo0_l00008ooooo`Co
000000?oooooo`000?l000001_l00006ooooo`Co00001_ooool2o`0008_ooooo000Nooooo`03o`00
0?oooooooooo073ooooo0ol0000Aooooo`?o00000_ooool2o`000004ooooool0003o0000o`0000go
oooo4?l00002ooooo`Ko00001_ooool4o`0008Wooooo000Nooooo`03o`000?oooooooooo077ooooo
0_l0000;ooooo`;o00001?ooool6o`0000;ooooo0ol0000<oooooa7o00000_ooool6o`0000Kooooo
1?l00029ooooo`007_ooool00ol0003oooooooooo`1aooooo`;o00002oooool2o`0000Kooooo1?l0
00000ooooooo0000o`000003o`0000Gooooo3Ol000000ooooooo0000o`000006o`000003ooooool0
003o000000Ko00002oooool2o`0008Kooooo000Nooooo`03o`000?oooooooooo077ooooo0_l0000E
ooooo`;o000000?oooooo`000?l000000ol00005oooooaWo00004Oooool2o`0008Kooooo000Noooo
o`03o`000?oooooooooo08Cooooo0_l00002ooooo`Ko00001OoooolKo`0000?ooooo1?l00003oooo
o`;o0000SOooool001kooooo00?o0000ooooooooool0OOooool2o`0000Gooooo0_l000000ooooooo
0000o`000005o`0000?ooooo3?l000000ooooooo0000o`000004o`000003ooooool0003o000000Co
000000?oooooo`000?l000001ol00003ooooo`;o00001_ooool2o`0008Gooooo000Nooooo`03o`00
0?oooooooooo07gooooo0_l00008oooooaKo000000?oooooo`000?l000002_l00003ooooo`Oo0000
3?ooool2o`0008Gooooo000Nooooo`03o`000?oooooooooo08?ooooo0_l000000ooooooo0000o`00
000Eo`0000;ooooo3?l00002ooooo`Oo00003?ooool2o`0008Gooooo000Nooooo`;o0000POooool2
o`000004ooooool0003o0000ooooo`;o00000ooooolPo`0000?ooooo1_l0002Cooooo`007_ooool0
0ol0003oooooooooo`1cooooo`;o00001Oooool2o`0000Cooooo1?l00002ooooo`;o00001?ooool4
o`0000?ooooo3Ol000000ooooooo0000o`000006o`0000Gooooo1Ol0002Dooooo`007_ooool00ol0
003oooooooooo`1cooooo`;o00001Oooool2o`0000Kooooo0_l00002ooooo`;o00001_ooool3o`00
00;ooooo5Ol000000ooooooo0000o`000003o`000003ooooool0003o000000?o00005?ooool4o`00
07_ooooo000Nooooo`03o`000?oooooooooo07gooooo0_l00007ooooo`?o00001Oooool3o`0000;o
oooo5Ol000000ooooooo0000o`000003o`000004ooooool0003o0000ooooo`;o00005?ooool4o`00
07_ooooo000Nooooo`03o`000?oooooooooo07gooooo0_l00005ooooo`Go00001_oooolIo`0000;o
oooo1Ol000000ooooooo0000o`00002Eooooo`007_ooool00ol0003oooooooooo`24ooooo`Co0000
1oooool7o`000005ooooool0003o0000o`000?ooool00ol000000ooooooo0000o`000006o`000003
ooooool0003o000000[o00005oooool2o`0007[ooooo000Nooooo`03o`000?oooooooooo07Wooooo
0_l00009ooooo`Co00002Oooool9o`000003ooooool0003o000000go00000oooool7o`0001Oooooo
0_l0001jooooo`007_ooool00ol0003oooooooooo`1iooooo`;o00002Oooool4o`0000Wooooo2Ol0
00000ooooooo0000o`00000>o`0000;ooooo0ol00002ooooo`;o00002_ooool2o`0008Oooooo000N
ooooo`03o`000?oooooooooo07Gooooo0_l0000=ooooo`?o00000_ooool2o`0000Kooooo2Ol00000
0ooooooo0000o`000007o`000003ooooool0003o000000Co00000_ooool3o`0000kooooo0_l00027
ooooo`007_ooool00ol0003oooooooooo`1eooooo`;o00003Oooool3o`000004ooooool0003o0000
o`0000Oooooo5ol00003ooooo`?o00006?ooool2o`0007kooooo000Nooooo`03o`000?oooooooooo
07[ooooo0_l000000ooooooo0000o`000006ooooo`Go00000oooool2o`0000?ooooo1?l00002oooo
o`ko000000Coooooo`000?l0003ooooo1_l0000Gooooo`;o0000O_ooool001kooooo00?o0000oooo
ooooool0N_ooool2o`000003ooooool0003o000000Gooooo1?l00005ooooo`;o00000ooooolDo`00
00?ooooo1ol00007ooooo`;o00003oooool2o`000003ooooool0003o000007[ooooo000Nooooo`03
o`000?oooooooooo07Oooooo0_l0000;ooooo`Co00003?ooool8o`0000;ooooo2Ol000001Ooooooo
0000o`000?l0003ooooo00Co00001oooool2o`0000oooooo0_l000000ooooooo0000o`00001joooo
o`007_ooool00ol0003oooooooooo`1gooooo`;o00003Oooool3o`0000_ooooo7?l0002Gooooo`00
7_ooool00ol0003oooooooooo`27ooooo`;o00003?ooool2o`000003ooooool0003o000000Go0000
00?oooooo`000?l000000ol00002ooooo`Go000000?oooooo`000?l00000V?ooool001kooooo00?o
0000ooooooooool0Qoooool2o`0000Sooooo0_l00005ooooo`Co00000_ooool?o`0009[ooooo000N
ooooo`;o0000R?ooool4o`0000;ooooo0_l00002ooooo`;o00001oooool2o`0000;ooooo1?l00000
0ooooooo0000o`000008o`0000?ooooo0_l0000?ooooo`?o0000Poooool001kooooo00?o0000oooo
ooooool0Qoooool4o`0000;ooooo0_l0000<ooooo`;o000000?oooooo`000?l000000ol000000ooo
oooo0000o`000004o`0000Kooooo0_l0000>ooooo`Co0000Poooool001kooooo00?o0000oooooooo
ool0V_ooool9o`000003ooooool0003o000000Co000000?oooooo`000?l000000_l00003ooooo`Co
00000_ooool2o`0000Kooooo0_l00025ooooo`007_ooool00ol0003oooooooooo`1hooooo`?o0000
4oooool2o`0000[ooooo4?l000000ooooooo0000o`000002o`0000?ooooo2?l0002=ooooo`007_oo
ool00ol0003oooooooooo`1hooooo`Go00003_ooool5o`0000[ooooo3Ol0000;ooooo`;o00000_oo
ool2o`0000Wooooo0_l00024ooooo`007_ooool00ol0003oooooooooo`1iooooo`Co00003_ooool3
o`0000kooooo1Ol000001?oooooo0000o`000?l00002ooooo`;o00006?ooool2o`0008Cooooo000N
ooooo`03o`000?oooooooooo08kooooo0_l0000<ooooo`;o00001Oooool2o`0000;ooooo0_l0002N
ooooo`007_ooool00ol0003oooooooooo`1iooooo`;o00004oooool3o`0001;ooooo1?l0000Hoooo
o`;o0000Q_ooool001kooooo00?o0000ooooooooool0NOooool2o`0001?ooooo0ol00003ooooo`;o
00002_ooool2o`0000?ooooo0_l0000Hooooo`;o0000Q_ooool001kooooo00?o0000ooooooooool0
Noooool2o`0001;ooooo0_l00003ooooo`;o00002_ooool2o`0000?ooooo0_l0000Looooo`;o0000
P_ooool001kooooo00?o0000ooooooooool0Noooool2o`0001;ooooo0_l00004ooooo`;o00007_oo
ool2o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`?o0000POooool001kooooo00?o0000
ooooooooool0OOooool2o`0000;ooooo0_l0000Booooo`;o00007_ooool2o`0000?ooooo1Ol00003
ooooo`Co0000POooool001kooooo00?o0000ooooooooool0OOooool2o`0000;ooooo0_l0000>oooo
o`;o00000oooool2o`0000gooooo0_l0000;ooooo`;o00002?ooool2o`0000Cooooo0_l00023oooo
o`007_ooool00ol0003oooooooooo`2Aooooo`;o00000oooool2o`0000Cooooo1?l00005ooooo`;o
00002oooool2o`0009?ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo07oooooo0_l0000Koooo
o`Co00002Oooool2o`00017ooooo0_l00029ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1o
ooooo`?o00004?ooool5o`0000;ooooo0_l00009ooooo`Co000000?oooooo`000?l000004Oooool2
o`000003ooooool0003o000008Kooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool0
1Ol0003ooooooooooooooooo000000Kooooo0ol0001oooooo`?o00004?ooool5o`0000;ooooo1?l0
0007ooooo`Co00005oooool2o`0008Kooooo0003ooooo`05o`000?ooooooooooooooool000002ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0Toooool2o`0000Kooooo
0ol00007ooooo`;o00005Oooool2o`0008Wooooo0003ooooo`05o`000?ooooooooooooooool00000
2oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0UOooool2o`0000Go
oooo1?l0000<ooooo`;o00003_ooool2o`0008Wooooo0003ooooo`05oa0@4?ooooooooooooooool@
41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo09Gooooo0ol00006ooooo`;o
00002?ooool2o`0000;ooooo0_l0002Iooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`2Fooooo`;o00003?ooool2o`0000;o
oooo0_l000000ooooooo0000o`000003ooooo`;o00000_ooool2o`00097ooooo0003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo
09Oooooo1?l00009ooooo`;o00001?ooool3o`000003ooooool0003o000000;o000000Coooooo`00
0?l0003o0000TOooool001kooooo00?o0000ooooooooool0Uoooool4o`0000oooooo0_l00002oooo
o`;o00000oooool2o`000003ooooool0003o000008oooooo000Nooooo`03o`000?oooooooooo0:7o
oooo0_l0000;ooooo`;o00001_ooool2o`0008oooooo000Nooooo`03o`000?oooooooooo09_ooooo
1?l00002ooooo`;o00000oooool2o`0009oooooo000Nooooo`03o`000?oooooooooo09_ooooo1?l0
0007ooooo`Co0000WOooool001kooooo00?o0000ooooooooool0X?ooool2o`0000Kooooo0_l0002M
ooooo`007_ooool00ol0003oooooooooo`2Pooooo`;o00000oooool2o`000:3ooooo000Nooooo`03
o`000?oooooooooo0:Gooooo0_l0002Pooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000oooo
ooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`3oooooodSooooo0003oooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
003oooooodSooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooo
oonHV9So<S8b00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol0003ooooooooo
oooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj
^_l@41001_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0oooooom8
ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVY
Z@06ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?oo
ooooBOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001Cooooo1?l000000ol@413oooooooooo`03ooooo`03
o`000?oooooooooo0?ooooooB?ooool001Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3oooooodSooooo000Fooooo`03o`000?oooooooooo00Gooooo0ol0003oooooodSooooo000F
ooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@oooo
o`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?oooooo
D?ooool001Cooooo00?oEEEEofIVI_l00000oooooomBooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.44114 .49562 Mdot
.47005 .50435 Mdot
.55796 .51326 Mdot
.47421 .49341 Mdot
.48748 .4754 Mdot
.48187 .55345 Mdot
.50453 .38034 Mdot
.46246 .47915 Mdot
.41361 .48808 Mdot
.47426 .43945 Mdot
.43842 .46688 Mdot
.49666 .52461 Mdot
.49778 .57076 Mdot
.53552 .54439 Mdot
.40839 .41586 Mdot
.5106 .45632 Mdot
.46309 .50467 Mdot
.43146 .53965 Mdot
.44638 .45088 Mdot
.53902 .51746 Mdot
.46179 .50418 Mdot
.53227 .46612 Mdot
.50046 .4739 Mdot
.50142 .55451 Mdot
.45106 .48738 Mdot
.50643 .51425 Mdot
.4791 .43397 Mdot
.42001 .48409 Mdot
.49084 .48237 Mdot
.48392 .54436 Mdot
.50472 .56598 Mdot
.46427 .49265 Mdot
.51035 .49241 Mdot
.56638 .50086 Mdot
.4951 .55951 Mdot
.55937 .52652 Mdot
.51297 .50576 Mdot
.52813 .46254 Mdot
.49736 .47098 Mdot
.50151 .52712 Mdot
.51195 .46573 Mdot
.5479 .49967 Mdot
.49489 .54903 Mdot
.50227 .50662 Mdot
.4625 .48965 Mdot
.52802 .48819 Mdot
.57467 .50313 Mdot
.50618 .56808 Mdot
.53263 .55454 Mdot
.38626 .57977 Mdot
.49598 .47138 Mdot
.53661 .61499 Mdot
.48973 .4861 Mdot
.48631 .47501 Mdot
.5009 .44827 Mdot
.51873 .51063 Mdot
.49592 .54214 Mdot
.57832 .61529 Mdot
.46641 .48263 Mdot
.49956 .54522 Mdot
.53415 .49123 Mdot
.52329 .49383 Mdot
.56057 .50597 Mdot
.5096 .45632 Mdot
.50439 .47085 Mdot
.37805 .51898 Mdot
.48113 .55456 Mdot
.52827 .49733 Mdot
.51895 .51905 Mdot
.51191 .45696 Mdot
.47623 .39957 Mdot
.47473 .48323 Mdot
.5065 .54287 Mdot
.48983 .49901 Mdot
.49156 .55314 Mdot
.49961 .41676 Mdot
.52585 .50812 Mdot
.43084 .55318 Mdot
.49274 .4069 Mdot
.42605 .48989 Mdot
.55092 .47168 Mdot
.4587 .48022 Mdot
.45888 .49263 Mdot
.5204 .47626 Mdot
.56366 .50345 Mdot
.48992 .49405 Mdot
.5495 .45464 Mdot
.52421 .49887 Mdot
.50061 .53103 Mdot
.45993 .6078 Mdot
.49897 .48123 Mdot
.52776 .47847 Mdot
.53713 .44745 Mdot
.3735 .55629 Mdot
.53061 .44233 Mdot
.53393 .49441 Mdot
.52303 .50304 Mdot
.49765 .56767 Mdot
.5804 .49327 Mdot
.48974 .53786 Mdot
.54422 .44742 Mdot
.54903 .45586 Mdot
.47109 .47837 Mdot
.39948 .56067 Mdot
.41813 .47439 Mdot
.5117 .49382 Mdot
.60063 .38533 Mdot
.50135 .47457 Mdot
.48081 .54324 Mdot
.52811 .47705 Mdot
.46821 .53712 Mdot
.47374 .48409 Mdot
.48518 .51444 Mdot
.48042 .4585 Mdot
.47268 .55445 Mdot
.50751 .60267 Mdot
.49701 .45411 Mdot
.41839 .47967 Mdot
.53512 .54758 Mdot
.53106 .44575 Mdot
.43134 .54991 Mdot
.5034 .51393 Mdot
.48018 .43928 Mdot
.51894 .56151 Mdot
.46654 .50573 Mdot
.49978 .44598 Mdot
.47975 .54364 Mdot
.50493 .51337 Mdot
.50326 .50854 Mdot
.50192 .4543 Mdot
.41774 .51638 Mdot
.46473 .51788 Mdot
.59024 .57675 Mdot
.54974 .53181 Mdot
.47566 .48524 Mdot
.59404 .56536 Mdot
.47511 .42649 Mdot
.50171 .494 Mdot
.51379 .53458 Mdot
.4923 .51343 Mdot
.50011 .47699 Mdot
.44933 .46278 Mdot
.50622 .50342 Mdot
.47871 .4896 Mdot
.51263 .48112 Mdot
.52946 .47821 Mdot
.44971 .49991 Mdot
.53523 .48992 Mdot
.47369 .55739 Mdot
.52465 .55718 Mdot
.55605 .51879 Mdot
.41671 .48703 Mdot
.49411 .47603 Mdot
.49881 .5639 Mdot
.42363 .49887 Mdot
.51067 .45625 Mdot
.52254 .49106 Mdot
.54574 .58287 Mdot
.52519 .50889 Mdot
.50928 .4791 Mdot
.44855 .39604 Mdot
.52962 .50871 Mdot
.43775 .56925 Mdot
.49723 .45046 Mdot
.49892 .53627 Mdot
.48826 .52868 Mdot
.423 .46378 Mdot
.55729 .47207 Mdot
.54443 .47549 Mdot
.52296 .45672 Mdot
.42467 .48654 Mdot
.51575 .55684 Mdot
.47221 .51438 Mdot
.50168 .5362 Mdot
.4341 .38407 Mdot
.51725 .50554 Mdot
.53136 .48688 Mdot
.50927 .47551 Mdot
.58765 .50735 Mdot
.53293 .54505 Mdot
.47712 .49291 Mdot
.53188 .4915 Mdot
.49564 .49944 Mdot
.48871 .48518 Mdot
.49957 .58269 Mdot
.49443 .52336 Mdot
.56258 .48358 Mdot
.53468 .49321 Mdot
.37729 .54543 Mdot
.52458 .43626 Mdot
.4974 .51236 Mdot
.50291 .45542 Mdot
.49211 .55326 Mdot
.49681 .47529 Mdot
.52622 .45931 Mdot
.50858 .46604 Mdot
.38357 .58288 Mdot
.50694 .49934 Mdot
.50933 .46847 Mdot
.47443 .49895 Mdot
.48394 .53276 Mdot
.53031 .49847 Mdot
.42542 .53762 Mdot
.55817 .47714 Mdot
.49755 .44529 Mdot
.47413 .51964 Mdot
.46107 .51521 Mdot
.49238 .54197 Mdot
.56941 .50132 Mdot
.49565 .47377 Mdot
.462 .4919 Mdot
.50991 .50592 Mdot
.50776 .52691 Mdot
.44889 .5532 Mdot
.50321 .51436 Mdot
.57198 .50509 Mdot
.52936 .48304 Mdot
.52167 .5124 Mdot
.45238 .46279 Mdot
.50403 .47656 Mdot
.50814 .45833 Mdot
.57591 .60158 Mdot
.52943 .47931 Mdot
.54952 .5515 Mdot
.45291 .47753 Mdot
.46151 .48382 Mdot
.46645 .48973 Mdot
.47584 .43957 Mdot
.56473 .49375 Mdot
.43676 .47536 Mdot
.49233 .44581 Mdot
.50831 .50653 Mdot
.47917 .4601 Mdot
.51881 .49451 Mdot
.51202 .51305 Mdot
.51424 .53596 Mdot
.49872 .453 Mdot
.50768 .4176 Mdot
.46954 .5206 Mdot
.49446 .52349 Mdot
.47457 .43918 Mdot
.42136 .41212 Mdot
.45532 .51868 Mdot
.50655 .44886 Mdot
.53957 .44096 Mdot
.50515 .45164 Mdot
.48704 .41206 Mdot
.46507 .48134 Mdot
.48555 .44531 Mdot
.48251 .45149 Mdot
.49395 .54746 Mdot
.49771 .58855 Mdot
.44416 .42607 Mdot
.53526 .44406 Mdot
.48705 .50991 Mdot
.49262 .52953 Mdot
.49872 .46649 Mdot
.51352 .5191 Mdot
.5651 .49916 Mdot
.45356 .44765 Mdot
.55961 .47434 Mdot
.50336 .45949 Mdot
.50961 .47944 Mdot
.4326 .53218 Mdot
.54283 .51902 Mdot
.55776 .50539 Mdot
.45399 .47634 Mdot
.41709 .51006 Mdot
.51177 .47352 Mdot
.5923 .51372 Mdot
.48463 .54906 Mdot
.48533 .51504 Mdot
.37601 .54268 Mdot
.48926 .5143 Mdot
.55945 .49043 Mdot
.4831 .40647 Mdot
.52321 .5087 Mdot
.45531 .44597 Mdot
.53317 .52096 Mdot
.46295 .44602 Mdot
.51656 .52782 Mdot
.50885 .51796 Mdot
.51953 .55357 Mdot
.50911 .48959 Mdot
.50721 .45764 Mdot
.37614 .56154 Mdot
.57976 .50297 Mdot
.50549 .46597 Mdot
.47003 .51699 Mdot
.49044 .56572 Mdot
.49553 .53341 Mdot
.48253 .56304 Mdot
.49637 .60367 Mdot
.50212 .55354 Mdot
.48804 .52838 Mdot
.47957 .47696 Mdot
.4188 .49212 Mdot
.53499 .53931 Mdot
.55629 .49297 Mdot
.47346 .49216 Mdot
.50476 .50049 Mdot
.46122 .48416 Mdot
.40371 .48369 Mdot
.52223 .46751 Mdot
.49514 .52896 Mdot
.47461 .49208 Mdot
.63454 .52626 Mdot
.46871 .55117 Mdot
.44801 .48846 Mdot
.53825 .5246 Mdot
.48092 .49719 Mdot
.50958 .49024 Mdot
.47172 .46003 Mdot
.43711 .48454 Mdot
.47483 .50441 Mdot
.46994 .56001 Mdot
.50262 .52619 Mdot
.52647 .49809 Mdot
.50774 .54046 Mdot
.53252 .46238 Mdot
.52795 .55099 Mdot
.44097 .46664 Mdot
.44697 .46749 Mdot
.51797 .50778 Mdot
.42756 .47747 Mdot
.53355 .45458 Mdot
.49943 .51042 Mdot
.50283 .51011 Mdot
.433 .47777 Mdot
.55792 .47101 Mdot
.45594 .51009 Mdot
.52029 .60213 Mdot
.48501 .51661 Mdot
.47045 .43975 Mdot
.56941 .50773 Mdot
.4873 .44754 Mdot
.55294 .52315 Mdot
.47446 .48794 Mdot
.43986 .46965 Mdot
.52305 .49589 Mdot
.48464 .55737 Mdot
.46429 .55405 Mdot
.5819 .39559 Mdot
.50732 .50042 Mdot
.54394 .45909 Mdot
.47287 .54606 Mdot
.50839 .49031 Mdot
.4698 .4781 Mdot
.55865 .47342 Mdot
.52045 .47594 Mdot
.49568 .53856 Mdot
.58427 .58363 Mdot
.46133 .49947 Mdot
.5171 .49945 Mdot
.47153 .59049 Mdot
.49158 .5334 Mdot
.5302 .54197 Mdot
.46784 .52499 Mdot
.48507 .61438 Mdot
.51208 .49158 Mdot
.50637 .4688 Mdot
.47005 .56089 Mdot
.48722 .52343 Mdot
.51051 .55322 Mdot
.46988 .53183 Mdot
.52242 .54981 Mdot
.55387 .46878 Mdot
.55506 .46993 Mdot
.62314 .47796 Mdot
.49147 .49384 Mdot
.50889 .47862 Mdot
.50178 .48946 Mdot
.57577 .59259 Mdot
.44316 .4734 Mdot
.54611 .53638 Mdot
.48775 .44133 Mdot
.44025 .47535 Mdot
.53262 .43638 Mdot
.54175 .50531 Mdot
.50963 .50888 Mdot
.5438 .52756 Mdot
.51881 .4233 Mdot
.48092 .48516 Mdot
.53669 .56599 Mdot
.46597 .48754 Mdot
.47122 .52591 Mdot
.41862 .48518 Mdot
.49168 .45001 Mdot
.51555 .5138 Mdot
.53993 .53142 Mdot
.62019 .55507 Mdot
.53238 .51422 Mdot
.52819 .54853 Mdot
.46394 .49168 Mdot
.50593 .46833 Mdot
.46195 .47996 Mdot
.5143 .46354 Mdot
.5104 .49003 Mdot
.42658 .47854 Mdot
.61654 .54855 Mdot
.62217 .52885 Mdot
.54578 .53179 Mdot
.6381 .55504 Mdot
.50784 .51904 Mdot
.52389 .54794 Mdot
.5536 .53492 Mdot
.48647 .48563 Mdot
.50632 .47751 Mdot
.48494 .53731 Mdot
.42966 .48416 Mdot
.4939 .51646 Mdot
.44387 .45533 Mdot
.49115 .4979 Mdot
.50868 .56693 Mdot
.49399 .49489 Mdot
.54516 .45139 Mdot
.52629 .47241 Mdot
.48812 .55711 Mdot
.50224 .54997 Mdot
.48165 .43985 Mdot
.45565 .45421 Mdot
.52863 .49009 Mdot
.49562 .50085 Mdot
.46062 .44317 Mdot
.60977 .59835 Mdot
.55624 .52557 Mdot
.40668 .44291 Mdot
.51264 .47235 Mdot
.52139 .5299 Mdot
.50756 .5258 Mdot
.47821 .5622 Mdot
.51272 .45769 Mdot
.45919 .52128 Mdot
.45094 .45953 Mdot
.5503 .47368 Mdot
.50169 .5566 Mdot
.54612 .47328 Mdot
.49715 .54255 Mdot
.47563 .55867 Mdot
.50096 .53681 Mdot
.50492 .55611 Mdot
.48153 .62818 Mdot
.48819 .56685 Mdot
.43157 .5227 Mdot
.5122 .49283 Mdot
.41842 .51238 Mdot
.48229 .48103 Mdot
.49949 .44772 Mdot
.56672 .50492 Mdot
.49615 .48107 Mdot
.54471 .52261 Mdot
.49327 .52146 Mdot
.51614 .46975 Mdot
.50209 .53498 Mdot
.56436 .47069 Mdot
.43792 .47467 Mdot
.55431 .5205 Mdot
.53707 .46535 Mdot
.50596 .48304 Mdot
.51038 .52256 Mdot
.5599 .48143 Mdot
.48645 .50105 Mdot
.51343 .56806 Mdot
.51751 .49454 Mdot
.5219 .5516 Mdot
.57868 .54202 Mdot
.51814 .4841 Mdot
.49536 .50482 Mdot
.48388 .56137 Mdot
.51435 .51886 Mdot
.44537 .47198 Mdot
.47805 .44533 Mdot
.5353 .34804 Mdot
.38623 .41016 Mdot
.43221 .46923 Mdot
.42657 .48045 Mdot
.53153 .55971 Mdot
.38281 .41176 Mdot
.54082 .4442 Mdot
.5878 .5686 Mdot
.50929 .49227 Mdot
.46117 .49813 Mdot
.46111 .48084 Mdot
.46523 .48023 Mdot
.52976 .49034 Mdot
.55705 .48038 Mdot
.46669 .44206 Mdot
.44317 .49946 Mdot
.52156 .55418 Mdot
.53033 .43384 Mdot
.509 .62677 Mdot
.56667 .49511 Mdot
.39395 .50933 Mdot
.50896 .47063 Mdot
.49229 .54451 Mdot
.47739 .59205 Mdot
.4785 .45753 Mdot
.51102 .47201 Mdot
.55468 .48617 Mdot
.4507 .48402 Mdot
.60177 .40188 Mdot
.43614 .43153 Mdot
.53512 .36539 Mdot
.49549 .44961 Mdot
.49351 .52387 Mdot
.45648 .43964 Mdot
.44559 .51137 Mdot
.47997 .44515 Mdot
.52617 .43762 Mdot
.38031 .56994 Mdot
.53158 .51487 Mdot
.56165 .50913 Mdot
.49042 .545 Mdot
.47793 .57139 Mdot
.45644 .48434 Mdot
.51548 .46072 Mdot
.49165 .54547 Mdot
.49338 .55816 Mdot
.54081 .52855 Mdot
.43784 .47993 Mdot
.4808 .44318 Mdot
.48273 .55029 Mdot
.4426 .48542 Mdot
.50883 .51288 Mdot
.49068 .52991 Mdot
.5221 .50471 Mdot
.54199 .53935 Mdot
.52999 .61819 Mdot
.41986 .50164 Mdot
.43654 .46411 Mdot
.56436 .48357 Mdot
.52956 .47818 Mdot
.52184 .51019 Mdot
.48651 .50243 Mdot
.38034 .53895 Mdot
.49783 .5204 Mdot
.54235 .56664 Mdot
.52941 .49485 Mdot
.49485 .54305 Mdot
.45173 .44517 Mdot
.48717 .51193 Mdot
.43913 .57846 Mdot
.52743 .47347 Mdot
.52651 .56302 Mdot
.41695 .50561 Mdot
.47225 .4203 Mdot
.48193 .48616 Mdot
.44582 .59099 Mdot
.47403 .48117 Mdot
.45069 .46651 Mdot
.49982 .53084 Mdot
.48489 .48051 Mdot
.51167 .48614 Mdot
.61245 .41151 Mdot
.47062 .4862 Mdot
.50901 .45883 Mdot
.50268 .48227 Mdot
.51667 .54766 Mdot
.50196 .62181 Mdot
.50635 .44358 Mdot
.55145 .4616 Mdot
.56633 .48867 Mdot
.49442 .444 Mdot
.49195 .49002 Mdot
.54913 .50408 Mdot
.49687 .46618 Mdot
.49502 .35599 Mdot
.46547 .44685 Mdot
.53655 .56536 Mdot
.53082 .5595 Mdot
.59076 .51575 Mdot
.50684 .51014 Mdot
.51173 .54964 Mdot
.47323 .47784 Mdot
.49421 .52113 Mdot
.51518 .46397 Mdot
.44891 .596 Mdot
.5001 .52973 Mdot
.51624 .42228 Mdot
.50114 .5203 Mdot
.55594 .4758 Mdot
.47663 .48335 Mdot
.58191 .38371 Mdot
.4818 .53307 Mdot
.52703 .50961 Mdot
.59416 .47418 Mdot
.47283 .48466 Mdot
.47764 .54476 Mdot
.46784 .54409 Mdot
.56136 .50053 Mdot
.4938 .52532 Mdot
.52597 .48308 Mdot
.51094 .46763 Mdot
.49918 .51426 Mdot
.4987 .44886 Mdot
.45542 .51178 Mdot
.51041 .56091 Mdot
.52799 .4847 Mdot
.43655 .56655 Mdot
.47151 .50874 Mdot
.55712 .47378 Mdot
.50899 .46048 Mdot
.43911 .48101 Mdot
.46064 .57973 Mdot
.52589 .48137 Mdot
.48559 .54659 Mdot
.49308 .44928 Mdot
.54494 .51689 Mdot
.5226 .49458 Mdot
.50189 .51184 Mdot
.4136 .48784 Mdot
.45252 .52338 Mdot
.4938 .47304 Mdot
.58745 .48553 Mdot
.44627 .50378 Mdot
.49013 .47837 Mdot
.50284 .46841 Mdot
.49597 .44593 Mdot
.50419 .47149 Mdot
.42849 .39387 Mdot
.50247 .38413 Mdot
.54589 .61974 Mdot
.48353 .50815 Mdot
.52236 .49186 Mdot
.55036 .44251 Mdot
.53986 .52795 Mdot
.49553 .47796 Mdot
.50394 .4858 Mdot
.59158 .56509 Mdot
.47019 .51559 Mdot
.53229 .49248 Mdot
.50507 .45109 Mdot
.52752 .55845 Mdot
.43801 .57933 Mdot
.44106 .58337 Mdot
.44109 .46803 Mdot
.51397 .42391 Mdot
.495 .50841 Mdot
.46844 .48007 Mdot
.57892 .50432 Mdot
.46917 .47966 Mdot
.52506 .50826 Mdot
.55501 .48919 Mdot
.51393 .47613 Mdot
.49772 .4516 Mdot
.45271 .56805 Mdot
.46734 .58503 Mdot
.51552 .4918 Mdot
.51629 .40051 Mdot
.49838 .39875 Mdot
.44243 .48353 Mdot
.51167 .4847 Mdot
.50986 .50124 Mdot
.48077 .54268 Mdot
.48354 .52366 Mdot
.49666 .54946 Mdot
.37369 .50854 Mdot
.49641 .51011 Mdot
.55864 .495 Mdot
.49926 .51548 Mdot
.47282 .48094 Mdot
.51245 .48416 Mdot
.51391 .55144 Mdot
.59137 .61247 Mdot
.60279 .42022 Mdot
.55726 .51674 Mdot
.54923 .46507 Mdot
.63862 .53792 Mdot
.45715 .52705 Mdot
.36588 .46183 Mdot
.46913 .50942 Mdot
.59915 .59922 Mdot
.62605 .52755 Mdot
.50385 .45657 Mdot
.49738 .45214 Mdot
.46444 .43648 Mdot
.51467 .5411 Mdot
.46267 .48801 Mdot
.41546 .4941 Mdot
.4778 .47761 Mdot
.53348 .49009 Mdot
.55068 .46224 Mdot
.47606 .52997 Mdot
.54018 .45799 Mdot
.46298 .49863 Mdot
.53123 .49892 Mdot
.46749 .50714 Mdot
.49545 .58443 Mdot
.50463 .53507 Mdot
.52722 .53094 Mdot
.53203 .50072 Mdot
.5608 .52495 Mdot
.55021 .61592 Mdot
.51353 .51296 Mdot
.52692 .54407 Mdot
.44698 .50369 Mdot
.60401 .39124 Mdot
.50456 .50225 Mdot
.52694 .47477 Mdot
.47342 .49071 Mdot
.48767 .48316 Mdot
.49842 .52053 Mdot
.50871 .56324 Mdot
.50386 .47108 Mdot
.54461 .52073 Mdot
.47408 .38414 Mdot
.52152 .50354 Mdot
.49459 .47236 Mdot
.5662 .49191 Mdot
.4595 .44351 Mdot
.40455 .50634 Mdot
.50097 .51282 Mdot
.56289 .47612 Mdot
.4327 .44961 Mdot
.49094 .56382 Mdot
.4806 .43238 Mdot
.44071 .44225 Mdot
.45547 .52091 Mdot
.47726 .53565 Mdot
.41531 .49912 Mdot
.48742 .49321 Mdot
.43187 .47904 Mdot
.51953 .53436 Mdot
.4856 .49898 Mdot
.44957 .51952 Mdot
.49278 .53738 Mdot
.45574 .60313 Mdot
.45125 .55973 Mdot
.5425 .56661 Mdot
.53225 .50012 Mdot
.42582 .49546 Mdot
.51878 .47215 Mdot
.4936 .53602 Mdot
.52081 .48592 Mdot
.51582 .61381 Mdot
.49652 .38801 Mdot
.51398 .50945 Mdot
.52959 .47516 Mdot
.44707 .45156 Mdot
.51821 .5152 Mdot
.52829 .48572 Mdot
.50871 .58536 Mdot
.51155 .51547 Mdot
.44496 .48483 Mdot
.512 .46755 Mdot
.48952 .47291 Mdot
.50813 .47125 Mdot
.52336 .49865 Mdot
.50385 .50746 Mdot
.44943 .48046 Mdot
.54195 .54182 Mdot
.50789 .48372 Mdot
.49952 .54153 Mdot
.48947 .47338 Mdot
.49233 .44143 Mdot
.52028 .56075 Mdot
.44836 .46239 Mdot
.48494 .44055 Mdot
.50257 .56462 Mdot
.46019 .45591 Mdot
.47878 .53281 Mdot
.47311 .53133 Mdot
.37293 .41969 Mdot
.53512 .50748 Mdot
.45385 .60289 Mdot
.48796 .50486 Mdot
.55117 .56791 Mdot
.4828 .48612 Mdot
.50132 .50914 Mdot
.55429 .53546 Mdot
.4472 .51643 Mdot
.5 .56816 Mdot
.4935 .556 Mdot
.49304 .49291 Mdot
.56537 .51796 Mdot
.51243 .44391 Mdot
.37839 .44586 Mdot
.44265 .4866 Mdot
.49267 .50491 Mdot
.51298 .52176 Mdot
.4963 .4507 Mdot
.47477 .54782 Mdot
.48782 .54828 Mdot
.49874 .63236 Mdot
.60512 .59671 Mdot
.47973 .40448 Mdot
.4795 .52111 Mdot
.50702 .46035 Mdot
.42327 .48392 Mdot
.54315 .48943 Mdot
.47481 .50256 Mdot
.42648 .53538 Mdot
.48173 .49404 Mdot
.53402 .46486 Mdot
.48058 .53988 Mdot
.54375 .45936 Mdot
.48754 .55054 Mdot
.61216 .4086 Mdot
.49644 .44645 Mdot
.58313 .43881 Mdot
.50431 .46079 Mdot
.49327 .5416 Mdot
.53095 .44075 Mdot
.35922 .45649 Mdot
.44019 .49467 Mdot
.50345 .45252 Mdot
.4971 .5361 Mdot
.45064 .48368 Mdot
.46106 .49305 Mdot
.4129 .51948 Mdot
.48195 .48666 Mdot
.47387 .42147 Mdot
.48238 .49102 Mdot
.45423 .47817 Mdot
.49477 .44438 Mdot
.49632 .54969 Mdot
.53409 .49703 Mdot
.4931 .53972 Mdot
.44209 .49475 Mdot
.51509 .56189 Mdot
.51755 .48616 Mdot
.48551 .50845 Mdot
.4734 .40192 Mdot
.45229 .44812 Mdot
.4404 .49497 Mdot
.42691 .45721 Mdot
.50586 .46965 Mdot
.47133 .52276 Mdot
.47932 .53745 Mdot
.51197 .51544 Mdot
.60514 .4269 Mdot
.48655 .55806 Mdot
.53895 .53341 Mdot
.52728 .49328 Mdot
.50779 .50582 Mdot
.49755 .45225 Mdot
.54943 .50064 Mdot
.42417 .49294 Mdot
.48204 .50565 Mdot
.51778 .45876 Mdot
.44256 .50163 Mdot
.52832 .48436 Mdot
.53371 .49432 Mdot
.44542 .38786 Mdot
.49117 .40312 Mdot
.56506 .47443 Mdot
.36582 .46549 Mdot
.55141 .50059 Mdot
.53009 .48623 Mdot
.50786 .54202 Mdot
.46767 .51202 Mdot
.45083 .57932 Mdot
.56305 .5171 Mdot
.62801 .52843 Mdot
.4296 .38006 Mdot
.49318 .5213 Mdot
.51295 .48189 Mdot
.47161 .57315 Mdot
.49512 .50302 Mdot
.49916 .47471 Mdot
.56542 .47982 Mdot
.49292 .52182 Mdot
.51005 .48865 Mdot
.53638 .45666 Mdot
.41696 .49595 Mdot
.56557 .48841 Mdot
.47549 .51835 Mdot
.40943 .50423 Mdot
.47187 .50419 Mdot
.56006 .62661 Mdot
.42192 .52273 Mdot
.51796 .45856 Mdot
.52009 .56532 Mdot
.45648 .51275 Mdot
.44819 .5132 Mdot
.49225 .49386 Mdot
.48873 .47505 Mdot
.52687 .47874 Mdot
.49956 .53119 Mdot
.52829 .61698 Mdot
.59966 .42608 Mdot
.57658 .59128 Mdot
.47527 .55562 Mdot
.49338 .48616 Mdot
.464 .61663 Mdot
.46485 .48217 Mdot
.50492 .53212 Mdot
.51362 .46144 Mdot
.51965 .4279 Mdot
.56643 .58914 Mdot
.53172 .50183 Mdot
.5089 .50002 Mdot
.54196 .45167 Mdot
.45124 .4623 Mdot
.5117 .47289 Mdot
.38306 .54251 Mdot
.48713 .4806 Mdot
.48259 .54024 Mdot
.48763 .51673 Mdot
.48309 .51738 Mdot
.43657 .5007 Mdot
.48426 .53302 Mdot
.46722 .5262 Mdot
.47339 .50517 Mdot
.44356 .47261 Mdot
.48722 .49217 Mdot
.52527 .43165 Mdot
.51086 .53792 Mdot
.47949 .47717 Mdot
.47586 .56094 Mdot
.56215 .49008 Mdot
.56182 .47742 Mdot
.49051 .52208 Mdot
.50278 .46883 Mdot
.46592 .50117 Mdot
.49937 .52308 Mdot
.55982 .46371 Mdot
.56085 .39714 Mdot
.47016 .5371 Mdot
.51478 .45592 Mdot
.52455 .48314 Mdot
.50364 .50546 Mdot
.5333 .5412 Mdot
.5638 .47448 Mdot
.44476 .43508 Mdot
.48462 .49765 Mdot
.48251 .47594 Mdot
.49603 .52882 Mdot
.37053 .48827 Mdot
.48713 .48799 Mdot
.48089 .52433 Mdot
.55422 .49197 Mdot
.39352 .5002 Mdot
.4684 .51666 Mdot
.49681 .50441 Mdot
.38489 .58618 Mdot
.52265 .49311 Mdot
.60298 .44101 Mdot
.47878 .44294 Mdot
.47038 .40351 Mdot
.53782 .58826 Mdot
.44995 .48684 Mdot
.52726 .55294 Mdot
.48497 .49546 Mdot
.53154 .4995 Mdot
.45165 .51503 Mdot
.49378 .5646 Mdot
.50134 .56928 Mdot
.50672 .54954 Mdot
.52906 .56448 Mdot
.42027 .48035 Mdot
.49081 .51395 Mdot
.44503 .57947 Mdot
.47192 .52737 Mdot
.47761 .49483 Mdot
.41518 .50582 Mdot
.54626 .45076 Mdot
.52195 .46763 Mdot
.61044 .44891 Mdot
.41665 .39149 Mdot
.56324 .48038 Mdot
.49494 .49603 Mdot
.52463 .46928 Mdot
.50999 .50399 Mdot
.51709 .48682 Mdot
.50277 .5551 Mdot
.56138 .48552 Mdot
.48159 .52951 Mdot
.51768 .46983 Mdot
.52316 .452 Mdot
.55449 .50507 Mdot
.45696 .53317 Mdot
.51863 .60854 Mdot
.55397 .46886 Mdot
.62338 .48156 Mdot
.5152 .45996 Mdot
.59259 .38265 Mdot
.49594 .49808 Mdot
.50689 .51859 Mdot
.43208 .5465 Mdot
.47198 .6198 Mdot
.50523 .47813 Mdot
.46691 .47857 Mdot
.46037 .48483 Mdot
.486 .56372 Mdot
.53351 .54855 Mdot
.44633 .51524 Mdot
.48072 .51276 Mdot
.52319 .46825 Mdot
.4869 .44895 Mdot
.44104 .49501 Mdot
.50445 .46797 Mdot
.46433 .54887 Mdot
.46527 .44474 Mdot
.48587 .44344 Mdot
.53184 .49827 Mdot
.50969 .43138 Mdot
.54239 .45964 Mdot
.45512 .38834 Mdot
.44806 .59431 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`2Zooooo`;o0000
Voooool001kooooo0_l0002[ooooo`;o0000Voooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`2Mooooo`;o0000Z?ooool001kooooo00?o0000oooooooo
ool0WOooool2o`000:Sooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0Z_ooool2o`0009_ooooo000Nooooo`03o`000?oooooooooo0:[ooooo0_l0002K
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`28ooooo`;o00005_ooool2o`0001_ooooo0_l00028ooooo`007_ooool00ol0003oooooooooo`28
ooooo`?o00002oooool2o`0000Oooooo0ol0000Gooooo`;o00000_ooool4o`0008Kooooo000Noooo
o`03o`000?oooooooooo08Wooooo0_l00002ooooo`;o000000?oooooo`000?l000001?ooool2o`00
00Gooooo1?l0000Hooooo`;o00001?ooool2o`0008Kooooo000Nooooo`03o`000?oooooooooo08?o
oooo0_l00008ooooo`;o000000?oooooo`000?l000002oooool2o`00027ooooo0_l00025ooooo`00
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@oooooooo
ool01?ooool00ol0003oooooooooo`23ooooo`;o00000_ooool2o`0003Oooooo0_l00025ooooo`00
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0Qoooool2o`0000Gooooo0_l0000Rooooo`;o00001Oooool2o`0008co
oooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol0002>ooooo`;o
00001oooool2o`0000Gooooo0_l00004ooooo`;o00003?ooool2o`0000Gooooo0_l0002<ooooo`00
0oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool00ol0
003oooooooooo`2Eooooo`Co00000oooool4o`0000Cooooo0_l0000Jooooo`;o0000QOooool000?o
oooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000
ooooooooool0UOooool6o`000003ooooool0003o000002;ooooo0_l00025ooooo`000oooool01Ol@
413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`1i
ooooo`;o00007Oooool3o`000003ooooool0003o000002Gooooo0_l00022ooooo`000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`1h
ooooo`?o00002_ooool2o`0001?ooooo0_l0000Wooooo`;o0000P_ooool000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0N?ooool2
o`0000Oooooo0_l00002ooooo`;o00004oooool2o`0002Oooooo0_l00022ooooo`007_ooool00ol0
003oooooooooo`1eooooo`;o00002_ooool2o`0001_ooooo0_l000000ooooooo0000o`00002Toooo
o`007_ooool00ol0003oooooooooo`1eooooo`;o00007_ooool3o`0000Kooooo0_l000001?oooooo
0000o`000?ooool2o`0001[ooooo0_l00025ooooo`007_ooool00ol0003oooooooooo`2Eooooo`?o
00002oooool4o`0001Wooooo0_l00025ooooo`007_ooool00ol0003oooooooooo`2<ooooo`;o0000
2?ooool2o`0000_ooooo1?l0000Hooooo`Co0000Q?ooool001kooooo00?o0000ooooooooool0R_oo
ool4o`0000Sooooo0_l0000:ooooo`;o000000?oooooo`000?l000000_l0000Fooooo`Co0000Q?oo
ool001kooooo00?o0000ooooooooool0R_ooool4o`0000[ooooo0_l00008ooooo`;o00000oooool3
o`0009gooooo000Nooooo`03o`000?oooooooooo08cooooo0_l00005ooooo`;o00000oooool2o`00
00cooooo1Ol0002Looooo`007_ooool00ol0003oooooooooo`2@ooooo`;o000000?oooooo`000?l0
00001ol0000:ooooo`Oo00003?ooool2o`0000Gooooo0_l00025ooooo`007_ooool00ol0003ooooo
ooooo`20ooooo`;o00002Oooool2o`0000?ooooo3ol00002ooooo`?o00001?ooool6o`000003oooo
ool0003o000000Sooooo0_l00005ooooo`;o0000QOooool001kooooo00?o0000ooooooooool0Mooo
ool2o`0000Oooooo0_l00009ooooo`;o00000_ooool7o`000003ooooool0003o000000Oo000000Co
ooooo`000?l0003o00001?ooool9o`0009Kooooo000Nooooo`03o`000?oooooooooo07Oooooo0_l0
000@ooooo`;o00001?ooool6o`0000;ooooo3?l00006ooooo`Ko00004oooool2o`0008?ooooo000N
ooooo`;o0000R_ooool2o`0000;ooooo1?l00008ooooo`[o00000oooool2o`0000?ooooo1?l0000C
ooooo`;o0000Poooool001kooooo00?o0000ooooooooool0LOooool2o`0001Wooooo0ol000001?oo
oooo0000o`000?l00006ooooo`;o00000_ooool8o`000004ooooool0003o0000ooooo`;o000000?o
ooooo`000?l000000ol0002Fooooo`007_ooool00ol0003oooooooooo`1aooooo`;o00005?ooool2
o`0000?ooooo1ol00004ooooo`?o00000ooooolDo`0009Kooooo000Nooooo`03o`000?oooooooooo
07?ooooo0_l0000Booooo`;o00001Oooool3o`0000Cooooo1Ol00006oooooa7o0000U_ooool001ko
oooo00?o0000ooooooooool0Loooool2o`00013ooooo0_l00003ooooo`;o00000_ooool3o`0000Co
oooo0_l000000ooooooo0000o`000006ooooo`Go00000oooool4o`0000;ooooo0ol000000ooooooo
0000o`00002Cooooo`007_ooool00ol0003oooooooooo`1cooooo`;o00004?ooool2o`0000?ooooo
1_l0000=ooooo`So000000Coooooo`000?l0003ooooo0ol00002ooooo`Ko0000Toooool001kooooo
00?o0000ooooooooool0R?ooool8o`0000gooooo2ol000000ooooooo0000o`000004ooooo`Ko0000
T_ooool001kooooo00?o0000ooooooooool0Q?ooool2o`0000;ooooo1ol0000;ooooo`oo00001?oo
ool9o`0000Oooooo0_l00028ooooo`007_ooool00ol0003oooooooooo`24ooooo`;o000000?ooooo
o`000?l000001Ol000001?oooooo0000o`000?l00003oooooaGo00000oooool9o`0000Oooooo0_l0
0007ooooo`;o0000Ooooool001kooooo00?o0000ooooooooool0Q?ooool9o`000003ooooool0003o
000001[o00000oooool2o`0000;ooooo1Ol0000@ooooo`;o0000Ooooool001kooooo00?o0000oooo
ooooool0Ooooool2o`0000?ooooo3?l000000ooooooo0000o`00000Go`0000Oooooo1Ol0000Aoooo
o`;o0000O_ooool001kooooo00?o0000ooooooooool0Ooooool2o`0000;ooooo6ol000000ooooooo
0000o`00000:o`0000Gooooo1Ol00006ooooo`;o00002_ooool2o`0007kooooo000Nooooo`03o`00
0?oooooooooo07Cooooo0_l0000<ooooo`Ko00000_oooolDo`000003ooooool0003o000000Ko0000
00?oooooo`000?l000001?l00002ooooo`Ko00001Oooool2o`0008[ooooo000Nooooo`03o`000?oo
oooooooo07Cooooo0_l0000<ooooo`Ko00001_ooool2o`000003ooooool0003o000000_o000000?o
ooooo`000?l000001?l000000ooooooo0000o`000006o`0000;ooooo1_l00003ooooo`;o0000S?oo
ool001kooooo00?o0000ooooooooool0Poooool5o`0000?ooooo0ol00003ooooo`Co000000?ooooo
o`000?l000005?l00004ooooo`Ko00000oooool2o`0008cooooo000Nooooo`03o`000?oooooooooo
08?ooooo0_l000000ooooooo0000o`000003ooooo`?o00001?ooool2o`0000;ooooo5_l00002oooo
o`;o00000_ooool4o`00097ooooo000Nooooo`;o0000OOooool2o`0000Gooooo1Ol00002ooooo`Ko
00000_ooool3o`000003ooooool0003o000000Oo000000?oooooo`000?l000002_l00002ooooo`?o
000000?oooooo`000?l000000ol0002@ooooo`007_ooool00ol0003oooooooooo`1looooo`;o0000
0oooool5o`0000Cooooo1_l00002ooooo`Ko000000?oooooo`000?l000001?l000000ooooooo0000
o`000006o`000004ooooool0003o0000ooooo`ko0000SOooool001kooooo00?o0000ooooooooool0
MOooool2o`0000Sooooo1_l00008ooooo`;o00000oooool6o`000003ooooool0003o000001oo0000
00?oooooo`000?l00000R_ooool001kooooo00?o0000ooooooooool0MOooool2o`0000Gooooo0_l0
00000ooooooo0000o`000002ooooo`;o00002?ooool2o`000003ooooool0003o000000;ooooo0ol0
0002ooooo`?o000000?oooooo`000?l000003Ol00006ooooo`;o000000?oooooo`000?l000001?oo
ool2o`0008[ooooo000Nooooo`03o`000?oooooooooo07cooooo0_l00005ooooo`?o00001oooool5
o`0000;ooooo0ol000000ooooooo0000o`00000Ao`0000Kooooo0ol00008ooooo`;o0000ROooool0
01kooooo00?o0000ooooooooool0Q?ooool2o`0000Oooooo2_l000000ooooooo0000o`00000=o`00
00;ooooo1_l00002ooooo`Go00001_ooool2o`0008Wooooo000Nooooo`03o`000?oooooooooo07Oo
oooo0_l00009ooooo`Co00001ooooolJo`0000;ooooo1_l000000ooooooo0000o`000004o`0000Ko
oooo0_l00029ooooo`007_ooool00ol0003oooooooooo`1gooooo`;o00002Oooool2o`000004oooo
ool0003o0000ooooo`;o00001?ooool5o`0000;ooooo4_l00002ooooo`;o000000Goooooo`000?l0
003o0000ooooo`03o`0009Cooooo000Nooooo`03o`000?oooooooooo08Gooooo0_l000000ooooooo
0000o`000005ooooo`Co000000Goooooo`000?l0003o0000ooooo`0=o`0000Kooooo1?l000000ooo
oooo0000o`000002o`0001Kooooo0_l0001kooooo`007_ooool00ol0003oooooooooo`2Aooooo`;o
000000?oooooo`000?l000001?l000000ooooooo0000o`000006o`000004ooooool0003o0000o`00
00Cooooo1?l00002ooooo`?o00004_ooool6o`0007_ooooo000Nooooo`03o`000?oooooooooo08Wo
oooo0_l00005ooooo`;o00000oooool=o`0000;ooooo1Ol00002ooooo`Ko00005Oooool4o`0007go
oooo000Nooooo`03o`000?oooooooooo08Oooooo1?l00005ooooo`;o00000oooool6o`000003oooo
ool0003o000000Co000000?oooooo`000?l000001?l00002ooooo`Oo0000UOooool001kooooo00?o
0000ooooooooool0N?ooool2o`0000cooooo1?l0000:oooooa?o00000oooool5o`000003ooooool0
003o000001[ooooo0_l0001iooooo`007_ooool00ol0003oooooooooo`1fooooo`Co00003?ooool4
o`0000[ooooo0ol000000ooooooo0000o`00000;o`0000?ooooo1_l0000:ooooo`;o00004_ooool2
o`0007Wooooo000Nooooo`03o`000?oooooooooo07Kooooo1?l0000Jooooo`;o000000?oooooo`00
0?l000001ol000000ooooooo0000o`000002o`0000;ooooo1ol0000:ooooo`;o0000SOooool001ko
oooo00?o0000ooooooooool0Moooool2o`0000oooooo0_l00009ooooo`go000000Coooooo`000?l0
003ooooo2?l0000Hooooo`;o0000POooool001kooooo0_l00029ooooo`;o00002Oooool5o`000003
ooooool0003o0000017o00000oooool2o`0001?ooooo0_l00021ooooo`007_ooool00ol0003ooooo
ooooo`28ooooo`;o00001?ooool2o`0000?ooooo6?l00004ooooo`;o00005Oooool2o`0000?ooooo
0_l0001jooooo`007_ooool00ol0003oooooooooo`1eooooo`;o00004Oooool2o`0000Cooooo0_l0
0003ooooo`;o000000?oooooo`000?l000001_l000000ooooooo0000o`00000:o`0001_ooooo0_l0
0003ooooo`;o0000N_ooool001kooooo00?o0000ooooooooool0MOooool2o`0000Oooooo0_l0000?
ooooo`;o00001?oooolFo`0009cooooo000Nooooo`03o`000?oooooooooo07Kooooo0_l00006oooo
o`;o00003oooool2o`0000Cooooo2ol000000ooooooo0000o`000008o`0009cooooo000Nooooo`03
o`000?oooooooooo07Kooooo0_l0000Booooo`;o00002ooooolGo`0000kooooo0ol00028ooooo`00
7_ooool00ol0003oooooooooo`1hooooo`;o00004?ooool2o`0000?ooooo0_l0000:ooooo`co0000
00?oooooo`000?l000001?l000000ooooooo0000o`00000:ooooo`Co0000R?ooool001kooooo00?o
0000ooooooooool0N?ooool2o`00013ooooo0_l00003ooooo`;o00001?ooool4o`0000Gooooo1?l0
00000ooooooo0000o`00000:ooooo`;o00002_ooool2o`0008[ooooo000Nooooo`03o`000?oooooo
oooo09Gooooo1?l00005ooooo`;o0000Yoooool001kooooo00?o0000ooooooooool0R_ooool6o`00
02cooooo0_l00029ooooo`007_ooool00ol0003oooooooooo`1iooooo`;o00003oooool6o`0000;o
oooo0_l0000:ooooo`;o00007?ooool2o`0008Wooooo000Nooooo`03o`000?oooooooooo07Wooooo
0_l0000@ooooo`;o00001Oooool4o`0000Oooooo0ol000000ooooooo0000o`00000:ooooo`;o0000
2oooool2o`0008_ooooo000Nooooo`03o`000?oooooooooo07Wooooo0_l0000@ooooo`;o00001ooo
ool2o`0000Oooooo0ol000000ooooooo0000o`000008ooooo`Co00002oooool2o`0008_ooooo000N
ooooo`03o`000?oooooooooo07Wooooo0_l0000Booooo`;o00001_ooool2o`0000Oooooo0_l0000;
ooooo`;o00001oooool2o`000003ooooool0003o000008kooooo0003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oo
oooooooo08gooooo0ol00005ooooo`Co00006oooool2o`000003ooooool0003o000008kooooo0003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RH
ob4Q8@06ooooo`03o`000?oooooooooo08kooooo0_l00007ooooo`;o00007_ooool2o`0000Sooooo
0_l00024ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooooooo
ooooo`000006ooooo`?o0000S_ooool2o`0002oooooo1Ol00023ooooo`000oooool01Ol0003ooooo
oooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo
08oooooo0ol0000;ooooo`;o00000_ooool2o`0000;ooooo0_l0000@ooooo`;o00001_ooool2o`00
0003ooooool0003o000008?ooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0
003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0Soooool3o`0000_ooooo0_l00002
ooooo`;o00000_ooool2o`00013ooooo0_l0002>ooooo`000oooool01Ol@413ooooooooooooooooo
410@00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`2Aooooo`;o00004Oooool2
o`000:7ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008
ooooo`03o`000?oooooooooo097ooooo0_l0000Aooooo`;o00005_ooool2o`0008Wooooo0003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oo
oooooooo09[ooooo0_l00008ooooo`;o00001?ooool2o`0000?ooooo0_l00007ooooo`;o00000_oo
ool2o`0008Wooooo000Nooooo`03o`000?oooooooooo09?ooooo0_l00005ooooo`;o00002?ooool2
o`0000;ooooo1?l00003ooooo`;o00001oooool2o`0008gooooo000Nooooo`03o`000?oooooooooo
09?ooooo1?l00008ooooo`;o00001oooool2o`0000?ooooo0_l0002Hooooo`007_ooool00ol0003o
ooooooooo`2Eooooo`;o00002?ooool2o`0000cooooo0_l0002Hooooo`007_ooool00ol0003ooooo
ooooo`2Hooooo`;o00001oooool2o`0000oooooo0_l0002Cooooo`007_ooool00ol0003ooooooooo
o`2Hooooo`;o00001oooool2o`0000oooooo0_l0002Cooooo`007_ooool00ol0003oooooooooo`2N
ooooo`;o0000Yoooool001kooooo00?o0000ooooooooool0W_ooool2o`000:Oooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?oooooo
BOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000
ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oo
ooooooooooooool000001_ooool3o`000?ooooooB?ooool000?ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool00ol0003oooooooooo`3oooooodSo
oooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<
00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool0
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_oo
ool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003o
ooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`005?ooool4o`00
0003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom8ooooo`005_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB?ooool001Kooooo00?o0000ooooooooool0
1Oooool3o`000?ooooooB?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool0
0ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Ko
oooo00?o0000ooooooooool0oooooom@ooooo`005?ooool00omEEEGoIVIVo`00003ooooooe;ooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.43586 .47531 Mdot
.47184 .48787 Mdot
.55344 .5463 Mdot
.48299 .48134 Mdot
.50417 .47288 Mdot
.46501 .51818 Mdot
.52149 .39951 Mdot
.48073 .4682 Mdot
.44358 .46757 Mdot
.50249 .43479 Mdot
.45185 .45113 Mdot
.48322 .52299 Mdot
.47407 .54109 Mdot
.50077 .55954 Mdot
.43177 .41012 Mdot
.5303 .47069 Mdot
.46394 .48212 Mdot
.42403 .50442 Mdot
.47152 .433 Mdot
.51894 .53774 Mdot
.46383 .48016 Mdot
.53577 .4926 Mdot
.52285 .46471 Mdot
.46435 .53863 Mdot
.46308 .4707 Mdot
.49688 .51936 Mdot
.51509 .44678 Mdot
.43428 .45364 Mdot
.50091 .48001 Mdot
.45947 .51441 Mdot
.48257 .56271 Mdot
.46905 .47642 Mdot
.51324 .50068 Mdot
.56056 .53027 Mdot
.46979 .52904 Mdot
.54568 .55012 Mdot
.50831 .51397 Mdot
.55481 .47619 Mdot
.51704 .46519 Mdot
.48508 .53051 Mdot
.52935 .4791 Mdot
.5306 .52203 Mdot
.47429 .53731 Mdot
.49663 .50535 Mdot
.46737 .4727 Mdot
.52731 .50359 Mdot
.55059 .53099 Mdot
.48383 .57009 Mdot
.50785 .5636 Mdot
.37549 .56045 Mdot
.51288 .46908 Mdot
.51445 .60699 Mdot
.49771 .48215 Mdot
.50723 .46865 Mdot
.52547 .4596 Mdot
.50616 .52218 Mdot
.47789 .53693 Mdot
.56179 .61984 Mdot
.47701 .47184 Mdot
.47926 .54126 Mdot
.53034 .50865 Mdot
.52147 .50571 Mdot
.54844 .53279 Mdot
.52948 .4701 Mdot
.51664 .47216 Mdot
.38883 .49764 Mdot
.46325 .53713 Mdot
.52048 .5108 Mdot
.49894 .53461 Mdot
.53162 .47204 Mdot
.50338 .41505 Mdot
.48928 .47594 Mdot
.48545 .54506 Mdot
.49029 .49013 Mdot
.45986 .52887 Mdot
.52778 .43647 Mdot
.51031 .52541 Mdot
.42055 .52115 Mdot
.518 .42936 Mdot
.44307 .46237 Mdot
.56396 .49227 Mdot
.47687 .46914 Mdot
.46659 .47164 Mdot
.53086 .49133 Mdot
.55413 .53144 Mdot
.49311 .48706 Mdot
.56286 .4876 Mdot
.51668 .51043 Mdot
.48299 .53397 Mdot
.43902 .58916 Mdot
.50744 .48149 Mdot
.53259 .49641 Mdot
.55591 .47556 Mdot
.36996 .53625 Mdot
.54446 .48209 Mdot
.52921 .51724 Mdot
.51287 .51451 Mdot
.4766 .56235 Mdot
.56044 .52279 Mdot
.47457 .52772 Mdot
.56013 .47892 Mdot
.56234 .48527 Mdot
.4873 .47063 Mdot
.39834 .53266 Mdot
.45221 .46047 Mdot
.51558 .50303 Mdot
.62097 .39301 Mdot
.51313 .47598 Mdot
.46508 .5237 Mdot
.53375 .4953 Mdot
.44384 .51615 Mdot
.4876 .47627 Mdot
.48035 .50165 Mdot
.51939 .44987 Mdot
.45747 .53587 Mdot
.48549 .58417 Mdot
.53558 .4655 Mdot
.43161 .4499 Mdot
.51696 .57118 Mdot
.55233 .47298 Mdot
.42361 .51951 Mdot
.49439 .51734 Mdot
.50781 .438 Mdot
.49434 .56396 Mdot
.46621 .48515 Mdot
.53134 .44244 Mdot
.44938 .52295 Mdot
.4962 .51763 Mdot
.49719 .51045 Mdot
.52536 .46473 Mdot
.41965 .48562 Mdot
.46214 .49337 Mdot
.5667 .58338 Mdot
.52992 .55165 Mdot
.5033 .47722 Mdot
.57055 .57547 Mdot
.49436 .413 Mdot
.50205 .49213 Mdot
.49258 .54347 Mdot
.48595 .5051 Mdot
.51066 .47799 Mdot
.48987 .45573 Mdot
.50358 .50857 Mdot
.48868 .4806 Mdot
.51835 .49008 Mdot
.53476 .4968 Mdot
.44144 .47542 Mdot
.52702 .51563 Mdot
.45713 .54 Mdot
.49847 .56161 Mdot
.53963 .54169 Mdot
.42902 .45632 Mdot
.50698 .47546 Mdot
.46762 .5647 Mdot
.42947 .46871 Mdot
.53048 .47073 Mdot
.52408 .50324 Mdot
.51554 .57511 Mdot
.50922 .52611 Mdot
.51463 .48464 Mdot
.47548 .4005 Mdot
.51125 .52849 Mdot
.4247 .54109 Mdot
.52435 .46268 Mdot
.48086 .53494 Mdot
.47734 .5184 Mdot
.45884 .45462 Mdot
.56193 .48778 Mdot
.53566 .5004 Mdot
.55052 .46346 Mdot
.43773 .45574 Mdot
.48998 .55758 Mdot
.46883 .49685 Mdot
.48261 .53694 Mdot
.4564 .38489 Mdot
.50916 .51518 Mdot
.5322 .51294 Mdot
.51632 .48065 Mdot
.56188 .52922 Mdot
.50815 .55742 Mdot
.4854 .48211 Mdot
.53238 .51416 Mdot
.49506 .49364 Mdot
.49749 .48112 Mdot
.47677 .55629 Mdot
.48257 .5191 Mdot
.56813 .51732 Mdot
.53081 .51108 Mdot
.37861 .52363 Mdot
.54789 .46234 Mdot
.49059 .5079 Mdot
.52113 .46437 Mdot
.45703 .53812 Mdot
.50935 .47548 Mdot
.55272 .46939 Mdot
.52579 .4787 Mdot
.37111 .56512 Mdot
.50517 .50349 Mdot
.5203 .47026 Mdot
.47953 .48553 Mdot
.4725 .51974 Mdot
.52131 .51314 Mdot
.4216 .50621 Mdot
.55196 .49599 Mdot
.52218 .45351 Mdot
.4681 .5023 Mdot
.46125 .48985 Mdot
.47456 .53304 Mdot
.56686 .53118 Mdot
.5097 .47339 Mdot
.46626 .47367 Mdot
.50595 .51302 Mdot
.48893 .53557 Mdot
.44061 .52113 Mdot
.49394 .51764 Mdot
.54564 .53192 Mdot
.5311 .50062 Mdot
.5052 .52863 Mdot
.49319 .45581 Mdot
.51265 .47916 Mdot
.52529 .46097 Mdot
.55571 .60338 Mdot
.53362 .49779 Mdot
.512 .56002 Mdot
.47697 .47249 Mdot
.48412 .47503 Mdot
.47417 .47658 Mdot
.505 .43696 Mdot
.5665 .52622 Mdot
.46185 .45838 Mdot
.51703 .46052 Mdot
.50424 .51293 Mdot
.52005 .45471 Mdot
.52046 .50506 Mdot
.50219 .52099 Mdot
.49278 .54471 Mdot
.53364 .44963 Mdot
.53455 .43933 Mdot
.46399 .49892 Mdot
.48252 .51928 Mdot
.50359 .43559 Mdot
.44716 .40931 Mdot
.43929 .49358 Mdot
.53799 .44797 Mdot
.54624 .48196 Mdot
.52847 .46503 Mdot
.51626 .42773 Mdot
.48703 .47245 Mdot
.51447 .4534 Mdot
.52346 .45946 Mdot
.47382 .5365 Mdot
.47604 .56359 Mdot
.47698 .4293 Mdot
.54493 .48535 Mdot
.48332 .49809 Mdot
.47911 .52435 Mdot
.52491 .45853 Mdot
.49674 .5308 Mdot
.55802 .5282 Mdot
.49318 .44939 Mdot
.56314 .49071 Mdot
.5224 .47046 Mdot
.51476 .48515 Mdot
.42886 .49999 Mdot
.52222 .53993 Mdot
.54408 .5318 Mdot
.48362 .4625 Mdot
.41952 .47639 Mdot
.52512 .48707 Mdot
.56752 .53385 Mdot
.46701 .53037 Mdot
.48022 .5023 Mdot
.37842 .52124 Mdot
.48292 .50383 Mdot
.56333 .52549 Mdot
.51198 .42107 Mdot
.50938 .52303 Mdot
.48183 .43163 Mdot
.51215 .53895 Mdot
.48948 .43456 Mdot
.49551 .53954 Mdot
.49604 .52443 Mdot
.48982 .56812 Mdot
.50988 .49323 Mdot
.54301 .46528 Mdot
.3703 .54142 Mdot
.5538 .52827 Mdot
.52745 .45953 Mdot
.46556 .49653 Mdot
.46091 .56383 Mdot
.47953 .53073 Mdot
.45882 .55174 Mdot
.47557 .58355 Mdot
.47862 .54655 Mdot
.47731 .51786 Mdot
.50066 .47043 Mdot
.42901 .45964 Mdot
.51068 .55393 Mdot
.54332 .51565 Mdot
.48289 .48038 Mdot
.50067 .50022 Mdot
.48416 .47564 Mdot
.43204 .46632 Mdot
.53722 .48557 Mdot
.48049 .52653 Mdot
.48427 .48071 Mdot
.62666 .54467 Mdot
.44716 .53384 Mdot
.45908 .47207 Mdot
.51584 .5432 Mdot
.48525 .48592 Mdot
.51062 .4951 Mdot
.5018 .44849 Mdot
.44375 .47164 Mdot
.47698 .49018 Mdot
.45514 .54358 Mdot
.4863 .53032 Mdot
.51848 .51084 Mdot
.48668 .54401 Mdot
.55653 .47466 Mdot
.5021 .55947 Mdot
.45083 .45096 Mdot
.45364 .44691 Mdot
.50813 .51772 Mdot
.4442 .44881 Mdot
.55319 .46442 Mdot
.49297 .50747 Mdot
.49616 .51202 Mdot
.46554 .45551 Mdot
.56643 .49905 Mdot
.44271 .48363 Mdot
.49606 .58723 Mdot
.4794 .50367 Mdot
.49839 .43289 Mdot
.5641 .53622 Mdot
.51209 .44516 Mdot
.53464 .54441 Mdot
.48663 .4786 Mdot
.45013 .46087 Mdot
.51925 .50735 Mdot
.46519 .54137 Mdot
.44998 .53687 Mdot
.59396 .41447 Mdot
.50617 .50621 Mdot
.54912 .47917 Mdot
.46 .52489 Mdot
.50879 .49293 Mdot
.48922 .46977 Mdot
.56402 .48949 Mdot
.53097 .49111 Mdot
.47886 .53398 Mdot
.56066 .58814 Mdot
.464 .47782 Mdot
.51544 .50911 Mdot
.45364 .56539 Mdot
.47791 .52573 Mdot
.49191 .5552 Mdot
.46179 .50142 Mdot
.46433 .59751 Mdot
.51698 .50143 Mdot
.51854 .46974 Mdot
.45374 .5459 Mdot
.47829 .51192 Mdot
.47364 .55922 Mdot
.46129 .50881 Mdot
.4938 .56787 Mdot
.54755 .51126 Mdot
.55958 .4859 Mdot
.61362 .4993 Mdot
.49446 .48764 Mdot
.5145 .48397 Mdot
.50471 .48857 Mdot
.55261 .59393 Mdot
.46629 .46457 Mdot
.53186 .56285 Mdot
.51437 .44387 Mdot
.46545 .46256 Mdot
.55343 .46547 Mdot
.52323 .52795 Mdot
.50373 .5158 Mdot
.52204 .5462 Mdot
.53733 .45728 Mdot
.49377 .47832 Mdot
.49973 .56395 Mdot
.47429 .47504 Mdot
.46219 .48942 Mdot
.43213 .45466 Mdot
.51627 .44732 Mdot
.50269 .52356 Mdot
.51691 .54856 Mdot
.60539 .5697 Mdot
.51207 .53395 Mdot
.50264 .55838 Mdot
.46896 .47569 Mdot
.52493 .46163 Mdot
.47698 .46743 Mdot
.53422 .48196 Mdot
.51261 .49718 Mdot
.44285 .44935 Mdot
.60014 .56387 Mdot
.60818 .54675 Mdot
.52474 .55061 Mdot
.63149 .57108 Mdot
.49462 .52506 Mdot
.49808 .55671 Mdot
.53533 .55524 Mdot
.49574 .48053 Mdot
.51321 .48126 Mdot
.47074 .52472 Mdot
.44714 .45601 Mdot
.48591 .50972 Mdot
.46751 .43559 Mdot
.49198 .48995 Mdot
.48615 .56919 Mdot
.49597 .4895 Mdot
.56041 .48101 Mdot
.53508 .49088 Mdot
.45474 .54403 Mdot
.47835 .54563 Mdot
.50976 .4399 Mdot
.48078 .43693 Mdot
.52604 .50521 Mdot
.49446 .49479 Mdot
.48809 .43236 Mdot
.59762 .61087 Mdot
.53942 .54741 Mdot
.4347 .43583 Mdot
.52718 .48603 Mdot
.49932 .5424 Mdot
.48957 .53408 Mdot
.45408 .55376 Mdot
.53207 .47299 Mdot
.45804 .49606 Mdot
.47556 .43909 Mdot
.54306 .49537 Mdot
.46485 .54349 Mdot
.53873 .49736 Mdot
.47858 .53814 Mdot
.45171 .54765 Mdot
.48207 .53658 Mdot
.48088 .55019 Mdot
.46059 .61512 Mdot
.46113 .56162 Mdot
.4303 .48991 Mdot
.51665 .50238 Mdot
.42192 .47967 Mdot
.49755 .47618 Mdot
.52374 .45719 Mdot
.56045 .53398 Mdot
.50544 .48055 Mdot
.51932 .55156 Mdot
.48289 .51525 Mdot
.53092 .48437 Mdot
.48325 .53744 Mdot
.56709 .50102 Mdot
.47386 .45652 Mdot
.53675 .54255 Mdot
.56012 .4797 Mdot
.51035 .4857 Mdot
.49299 .5326 Mdot
.55241 .502 Mdot
.48675 .49021 Mdot
.49124 .57619 Mdot
.51977 .50485 Mdot
.4957 .55675 Mdot
.54893 .55561 Mdot
.52725 .49751 Mdot
.49244 .49839 Mdot
.46115 .54926 Mdot
.49679 .53183 Mdot
.44804 .45567 Mdot
.50461 .44108 Mdot
.55193 .35248 Mdot
.40042 .39788 Mdot
.45233 .44297 Mdot
.46103 .46166 Mdot
.50863 .57015 Mdot
.39556 .39832 Mdot
.55831 .47518 Mdot
.56226 .57639 Mdot
.50982 .49746 Mdot
.46416 .477 Mdot
.48118 .47107 Mdot
.47698 .46864 Mdot
.52647 .50572 Mdot
.54808 .50103 Mdot
.49477 .43417 Mdot
.43605 .47749 Mdot
.49521 .55813 Mdot
.55184 .46217 Mdot
.4893 .6155 Mdot
.56737 .52669 Mdot
.41126 .48482 Mdot
.51859 .47369 Mdot
.47328 .53478 Mdot
.45884 .56706 Mdot
.52016 .45735 Mdot
.51923 .47662 Mdot
.54166 .5074 Mdot
.4693 .47413 Mdot
.61586 .41699 Mdot
.46904 .43201 Mdot
.54961 .37956 Mdot
.51768 .45304 Mdot
.48177 .51864 Mdot
.48392 .43006 Mdot
.44064 .48976 Mdot
.50829 .44522 Mdot
.54837 .46991 Mdot
.37186 .54996 Mdot
.5111 .53428 Mdot
.54994 .53551 Mdot
.47133 .5327 Mdot
.46182 .53946 Mdot
.47775 .47554 Mdot
.53281 .47686 Mdot
.47227 .53404 Mdot
.46916 .52685 Mdot
.51337 .55447 Mdot
.44594 .46927 Mdot
.51045 .44875 Mdot
.46554 .53119 Mdot
.4552 .47389 Mdot
.50002 .51927 Mdot
.47831 .52226 Mdot
.51119 .51603 Mdot
.51967 .55563 Mdot
.50819 .60918 Mdot
.42819 .46966 Mdot
.45809 .4396 Mdot
.55883 .51087 Mdot
.53498 .4968 Mdot
.50771 .52388 Mdot
.48617 .49133 Mdot
.3843 .51584 Mdot
.48645 .51915 Mdot
.5058 .56197 Mdot
.52317 .50919 Mdot
.47629 .53599 Mdot
.47864 .43094 Mdot
.48258 .5001 Mdot
.42314 .55238 Mdot
.53632 .49213 Mdot
.48769 .55573 Mdot
.42321 .47582 Mdot
.50444 .43242 Mdot
.4931 .47923 Mdot
.4271 .56687 Mdot
.48942 .47423 Mdot
.47656 .44554 Mdot
.48265 .53308 Mdot
.50941 .47203 Mdot
.51577 .49464 Mdot
.62167 .42722 Mdot
.48193 .47629 Mdot
.52425 .46487 Mdot
.50919 .48342 Mdot
.49175 .55287 Mdot
.48165 .60815 Mdot
.53793 .46464 Mdot
.56327 .49052 Mdot
.56565 .51996 Mdot
.51984 .45026 Mdot
.4972 .48541 Mdot
.53149 .528 Mdot
.52363 .45808 Mdot
.51104 .3658 Mdot
.4918 .43514 Mdot
.49924 .56185 Mdot
.50716 .56837 Mdot
.56532 .53543 Mdot
.50023 .51574 Mdot
.48672 .55082 Mdot
.49072 .47084 Mdot
.4837 .51601 Mdot
.5314 .47917 Mdot
.42984 .57361 Mdot
.48314 .53235 Mdot
.54143 .44618 Mdot
.4885 .52228 Mdot
.56459 .51215 Mdot
.49138 .47645 Mdot
.59775 .39779 Mdot
.46959 .51913 Mdot
.50897 .5286 Mdot
.57908 .50238 Mdot
.49916 .47623 Mdot
.4637 .52391 Mdot
.45938 .52149 Mdot
.55066 .528 Mdot
.48117 .52086 Mdot
.52958 .49835 Mdot
.52186 .46929 Mdot
.49099 .51235 Mdot
.52322 .45812 Mdot
.4418 .48564 Mdot
.47249 .55206 Mdot
.53227 .51028 Mdot
.42423 .53793 Mdot
.471 .49232 Mdot
.55481 .49118 Mdot
.52929 .481 Mdot
.44051 .46574 Mdot
.44508 .55221 Mdot
.53036 .49697 Mdot
.46822 .52881 Mdot
.51744 .45499 Mdot
.52738 .5516 Mdot
.52051 .50609 Mdot
.4944 .51307 Mdot
.4217 .45596 Mdot
.43718 .50122 Mdot
.52088 .46321 Mdot
.56956 .51443 Mdot
.43773 .48054 Mdot
.50344 .4764 Mdot
.51993 .46389 Mdot
.52237 .4546 Mdot
.51622 .47302 Mdot
.45217 .39254 Mdot
.52054 .40403 Mdot
.52515 .61511 Mdot
.4817 .49519 Mdot
.5234 .50385 Mdot
.55167 .48308 Mdot
.51694 .5458 Mdot
.50674 .47759 Mdot
.50791 .48663 Mdot
.56754 .57535 Mdot
.46601 .49582 Mdot
.52728 .50861 Mdot
.52739 .46357 Mdot
.50208 .56424 Mdot
.42159 .55306 Mdot
.42381 .55844 Mdot
.45383 .4593 Mdot
.53984 .44736 Mdot
.49053 .50176 Mdot
.48187 .47141 Mdot
.55256 .52938 Mdot
.49095 .47085 Mdot
.51015 .52458 Mdot
.54192 .52981 Mdot
.52665 .48998 Mdot
.52248 .46055 Mdot
.4407 .53856 Mdot
.4504 .5585 Mdot
.52031 .50223 Mdot
.53189 .42828 Mdot
.51999 .42175 Mdot
.4559 .47343 Mdot
.5157 .49241 Mdot
.50933 .50871 Mdot
.4652 .5231 Mdot
.47579 .51022 Mdot
.47538 .53942 Mdot
.38613 .48951 Mdot
.4909 .50458 Mdot
.54632 .52132 Mdot
.49044 .51419 Mdot
.48801 .4737 Mdot
.51871 .49466 Mdot
.47586 .558 Mdot
.57737 .62105 Mdot
.6096 .44103 Mdot
.54185 .54044 Mdot
.55907 .47958 Mdot
.63263 .55566 Mdot
.43766 .50416 Mdot
.37967 .44813 Mdot
.46743 .4907 Mdot
.58346 .60858 Mdot
.61401 .54575 Mdot
.52419 .47867 Mdot
.52126 .46048 Mdot
.4924 .43387 Mdot
.49236 .5486 Mdot
.46834 .47217 Mdot
.42523 .46195 Mdot
.49959 .47052 Mdot
.53318 .50961 Mdot
.56255 .49104 Mdot
.46535 .51034 Mdot
.55768 .48483 Mdot
.46529 .47843 Mdot
.52181 .51465 Mdot
.46711 .48686 Mdot
.47394 .5579 Mdot
.48529 .54003 Mdot
.50476 .54559 Mdot
.52055 .52231 Mdot
.5499 .55042 Mdot
.52905 .61166 Mdot
.50248 .52173 Mdot
.50134 .55506 Mdot
.44951 .48173 Mdot
.62117 .40184 Mdot
.50043 .50325 Mdot
.53416 .49286 Mdot
.48379 .47974 Mdot
.51417 .47409 Mdot
.48671 .52001 Mdot
.4809 .57183 Mdot
.51637 .47226 Mdot
.53051 .55497 Mdot
.49685 .39827 Mdot
.51221 .51428 Mdot
.5105 .47073 Mdot
.56162 .52108 Mdot
.48685 .4322 Mdot
.42353 .4786 Mdot
.4931 .51284 Mdot
.56636 .5085 Mdot
.45185 .42927 Mdot
.46002 .5624 Mdot
.51595 .44596 Mdot
.46134 .42423 Mdot
.45433 .49657 Mdot
.46335 .49975 Mdot
.42322 .46623 Mdot
.49169 .4855 Mdot
.45021 .4514 Mdot
.49726 .54529 Mdot
.48729 .48846 Mdot
.43859 .49768 Mdot
.47754 .53051 Mdot
.43589 .5809 Mdot
.44138 .52859 Mdot
.50594 .5621 Mdot
.52153 .52019 Mdot
.43208 .46557 Mdot
.5314 .48762 Mdot
.47821 .53031 Mdot
.52738 .49904 Mdot
.49429 .60026 Mdot
.51664 .40796 Mdot
.50574 .51825 Mdot
.53269 .50326 Mdot
.47195 .43385 Mdot
.50215 .52937 Mdot
.52894 .50193 Mdot
.483 .56339 Mdot
.49952 .52332 Mdot
.46263 .47611 Mdot
.52233 .4762 Mdot
.50817 .4686 Mdot
.51772 .47431 Mdot
.51656 .50983 Mdot
.4984 .51003 Mdot
.44651 .45918 Mdot
.5193 .55724 Mdot
.51146 .4874 Mdot
.48062 .53906 Mdot
.50705 .47027 Mdot
.51429 .45652 Mdot
.48141 .55921 Mdot
.4888 .45567 Mdot
.51198 .44172 Mdot
.48074 .55927 Mdot
.48617 .43921 Mdot
.46072 .49902 Mdot
.46252 .49502 Mdot
.38241 .40386 Mdot
.51689 .5286 Mdot
.43417 .58107 Mdot
.4861 .49397 Mdot
.51627 .5691 Mdot
.49343 .47951 Mdot
.49492 .50784 Mdot
.53787 .55716 Mdot
.44671 .48164 Mdot
.47907 .56344 Mdot
.46662 .52646 Mdot
.49627 .48773 Mdot
.5555 .54347 Mdot
.54143 .46706 Mdot
.39662 .43411 Mdot
.45346 .47335 Mdot
.49009 .49683 Mdot
.49422 .53388 Mdot
.51828 .45786 Mdot
.46101 .52715 Mdot
.46511 .51565 Mdot
.47838 .62218 Mdot
.59094 .60793 Mdot
.50861 .41825 Mdot
.47404 .5061 Mdot
.52737 .47228 Mdot
.43687 .45327 Mdot
.52784 .51214 Mdot
.4781 .48867 Mdot
.42268 .50301 Mdot
.48747 .48421 Mdot
.55823 .48026 Mdot
.46579 .52003 Mdot
.5533 .47594 Mdot
.4693 .53346 Mdot
.62388 .42271 Mdot
.5215 .45409 Mdot
.58171 .46908 Mdot
.52334 .47216 Mdot
.47561 .53368 Mdot
.55219 .47302 Mdot
.3685 .44194 Mdot
.43628 .47517 Mdot
.52608 .464 Mdot
.47994 .53347 Mdot
.46887 .47358 Mdot
.46595 .4733 Mdot
.41129 .48623 Mdot
.49256 .47955 Mdot
.50634 .43412 Mdot
.48945 .48273 Mdot
.4532 .45403 Mdot
.52013 .45086 Mdot
.47527 .53899 Mdot
.52754 .5163 Mdot
.47671 .53276 Mdot
.4456 .47621 Mdot
.49076 .56227 Mdot
.52563 .49885 Mdot
.48287 .49608 Mdot
.50227 .41373 Mdot
.47835 .43267 Mdot
.44205 .47681 Mdot
.44524 .43373 Mdot
.51778 .47097 Mdot
.465 .5016 Mdot
.46542 .51757 Mdot
.4997 .52356 Mdot
.60955 .44846 Mdot
.46658 .54233 Mdot
.52166 .56353 Mdot
.52297 .50718 Mdot
.50431 .51205 Mdot
.52124 .46069 Mdot
.53218 .5241 Mdot
.43945 .46437 Mdot
.48174 .4926 Mdot
.54957 .4684 Mdot
.43546 .47986 Mdot
.52978 .50096 Mdot
.53074 .51594 Mdot
.47007 .39215 Mdot
.51541 .42513 Mdot
.56589 .50421 Mdot
.37955 .45159 Mdot
.53454 .52492 Mdot
.52964 .503 Mdot
.48669 .54531 Mdot
.46502 .49085 Mdot
.43625 .55289 Mdot
.53462 .54163 Mdot
.61698 .54664 Mdot
.45019 .37921 Mdot
.48291 .51491 Mdot
.5231 .49497 Mdot
.45663 .54217 Mdot
.49307 .49649 Mdot
.51161 .47552 Mdot
.56589 .51082 Mdot
.48246 .51527 Mdot
.51172 .49399 Mdot
.55606 .48312 Mdot
.42456 .46351 Mdot
.56586 .52055 Mdot
.47032 .50187 Mdot
.41325 .47219 Mdot
.47397 .48883 Mdot
.54255 .62791 Mdot
.42189 .48916 Mdot
.54956 .46763 Mdot
.4983 .57718 Mdot
.44223 .48626 Mdot
.44627 .49076 Mdot
.49509 .48802 Mdot
.51062 .46791 Mdot
.53191 .4959 Mdot
.4824 .53299 Mdot
.5063 .6073 Mdot
.60425 .44906 Mdot
.55322 .59283 Mdot
.45843 .53776 Mdot
.50063 .48366 Mdot
.44271 .59913 Mdot
.47465 .47024 Mdot
.48593 .53792 Mdot
.53101 .47623 Mdot
.54455 .45457 Mdot
.54049 .58767 Mdot
.51901 .52382 Mdot
.50924 .50728 Mdot
.55908 .48558 Mdot
.47608 .44136 Mdot
.5193 .47851 Mdot
.38544 .51833 Mdot
.50055 .47729 Mdot
.46699 .52159 Mdot
.48088 .50517 Mdot
.47784 .50366 Mdot
.43988 .46837 Mdot
.47264 .52012 Mdot
.46325 .50026 Mdot
.47485 .49029 Mdot
.47511 .44755 Mdot
.49215 .48486 Mdot
.54848 .45963 Mdot
.48965 .54463 Mdot
.50087 .47041 Mdot
.45667 .54592 Mdot
.55366 .51785 Mdot
.55997 .49423 Mdot
.48063 .51318 Mdot
.52092 .46294 Mdot
.46829 .48264 Mdot
.48563 .52398 Mdot
.56808 .49312 Mdot
.57064 .42154 Mdot
.44487 .51561 Mdot
.54641 .47398 Mdot
.52945 .49778 Mdot
.49845 .50613 Mdot
.49603 .55587 Mdot
.56568 .50367 Mdot
.4801 .43735 Mdot
.48741 .48729 Mdot
.50303 .46993 Mdot
.48112 .52726 Mdot
.38596 .47247 Mdot
.49438 .48237 Mdot
.47373 .50984 Mdot
.53983 .51358 Mdot
.41568 .47926 Mdot
.464 .4949 Mdot
.49383 .4989 Mdot
.3716 .56887 Mdot
.5222 .50496 Mdot
.60228 .46515 Mdot
.51768 .45382 Mdot
.49956 .41402 Mdot
.50931 .57673 Mdot
.46266 .47112 Mdot
.50092 .55969 Mdot
.4887 .48593 Mdot
.52152 .516 Mdot
.43858 .49104 Mdot
.47154 .55543 Mdot
.47773 .57093 Mdot
.48227 .54799 Mdot
.49091 .56009 Mdot
.43574 .45108 Mdot
.4844 .50454 Mdot
.42807 .55108 Mdot
.46413 .50603 Mdot
.48439 .48353 Mdot
.41887 .47274 Mdot
.56107 .48096 Mdot
.53444 .48564 Mdot
.60528 .47223 Mdot
.43762 .38726 Mdot
.56638 .50217 Mdot
.49617 .49078 Mdot
.53094 .49714 Mdot
.50738 .51127 Mdot
.52476 .49919 Mdot
.47918 .54746 Mdot
.56678 .52002 Mdot
.47196 .51558 Mdot
.5315 .48527 Mdot
.5484 .47644 Mdot
.53892 .53014 Mdot
.43929 .51237 Mdot
.49582 .59452 Mdot
.55952 .48477 Mdot
.61345 .50276 Mdot
.53326 .47609 Mdot
.61236 .39177 Mdot
.49593 .49281 Mdot
.4943 .52383 Mdot
.42294 .51249 Mdot
.45097 .60362 Mdot
.51242 .48118 Mdot
.48134 .46846 Mdot
.48486 .47758 Mdot
.46134 .5539 Mdot
.51495 .57199 Mdot
.4387 .49361 Mdot
.47795 .49847 Mdot
.53677 .48636 Mdot
.51256 .44348 Mdot
.43592 .47485 Mdot
.52097 .46374 Mdot
.44655 .53019 Mdot
.49227 .4351 Mdot
.51318 .44576 Mdot
.52303 .51426 Mdot
.53748 .45477 Mdot
.55436 .49885 Mdot
.48028 .3962 Mdot
.42911 .57079 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`2_ooooo`;o0000U_ooool0
01kooooo00?o0000ooooooooool0[oooool2o`0009Kooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`2Rooooo`;o0000Xoooool001kooooo00?o0000ooooooooool0X_ooool2o`000:?ooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`2>ooooo`;o00007oooool2o`0009Kooooo000Nooooo`03o`000?oo
oooooooo08kooooo0_l0000Oooooo`;o0000U_ooool001kooooo00?o0000ooooooooool0T?ooool2
o`000;Gooooo000Nooooo`03o`000?oooooooooo08[ooooo0_l00004ooooo`;o0000]Oooool001ko
oooo00?o0000ooooooooool0R_ooool2o`0003Oooooo0_l00022ooooo`000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003o
ooooooooo`2?ooooo`;o00001?ooool2o`0002cooooo0_l000000ooooooo0000o`00001oooooo`00
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0O_ooool2o`0000oooooo0_l00004ooooo`;o000000?oooooo`000?l0
00009?ooool2o`0000Kooooo0_l0001oooooo`000oooool01Ol@413ooooooooooooooooo410@00_o
oooo1Ol00006ooooo`?o0000O?ooool4o`0001Kooooo1?l00003ooooo`;o00001_ooool2o`0001Oo
oooo0_l00027ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoo
oooo00001oooool00ol0003oooooooooo`1hooooo`;o00000_ooool2o`0001Sooooo0_l00005oooo
o`;o00001_ooool2o`0001oooooo0_l0001oooooo`000oooool01Ol0003ooooooooooooooooo0000
00_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`1hooooo`;o0000:oooool2
o`0001oooooo0_l0001oooooo`000oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMg
olc<c?l000001oooool00ol0003oooooooooo`28ooooo`;o00000oooool2o`0001Gooooo0_l0002Q
ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool0
0ol0003oooooooooo`28ooooo`;o00000oooool2o`0000kooooo0_l00005ooooo`;o0000XOooool0
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000
ooooooooool0WOooool5o`0001_ooooo0_l00028ooooo`007_ooool00ol0003oooooooooo`2Noooo
o`Go00006_ooool2o`0000Gooooo0_l00021ooooo`007_ooool00ol0003oooooooooo`2Qooooo`?o
000000?oooooo`000?l000003_ooool2o`0000gooooo0_l000000ooooooo0000o`00001nooooo`00
7_ooool00ol0003oooooooooo`2Booooo`;o00003_ooool5o`0000kooooo0_l0000@ooooo`;o0000
O_ooool001kooooo00?o0000ooooooooool0T_ooool2o`0000oooooo0ol00003ooooo`;o00006ooo
ool2o`0007oooooo000Nooooo`03o`000?oooooooooo08oooooo0_l00003ooooo`;o000000?ooooo
o`000?l000000_l00009ooooo`;o00000oooool2o`0001_ooooo0_l0001oooooo`007_ooool00ol0
003oooooooooo`1mooooo`;o00003_ooool4o`0000?ooooo3ol000000ooooooo0000o`00002Qoooo
o`007_ooool00ol0003oooooooooo`1mooooo`;o00002_ooool2o`0000;ooooo0_l00005ooooo`oo
00001?ooool2o`0009kooooo000Nooooo`03o`000?oooooooooo08Wooooo0_l00006ooooo`;o0000
00?oooooo`000?l000002?l00002ooooo`Co00000oooool2o`000003ooooool0003o000001Kooooo
0_l00023ooooo`007_ooool00ol0003oooooooooo`1dooooo`;o00006Oooool4o`0000?ooooo0ol0
00000ooooooo0000o`000004ooooo`Go00001?ooool3o`0001Kooooo0_l00023ooooo`007_ooool0
0ol0003oooooooooo`1dooooo`;o00006Oooool2o`0000Kooooo0_l00008ooooo`Go00000oooool5
o`0009Wooooo000Nooooo`03o`000?oooooooooo07Oooooo0_l0000?ooooo`;o00000_ooool2o`00
0003ooooool0003o000000Gooooo0ol00003ooooo`;o000000?oooooo`000?l000001_l00002oooo
o`Go00004_ooool4o`0008?ooooo000Nooooo`;o0000N?ooool2o`0000oooooo2Ol00005ooooo`;o
00001?ooool2o`000004ooooool0003o0000ooooo`Ko000000?oooooo`000?l000000_l0000Coooo
o`Co0000Poooool001kooooo00?o0000ooooooooool0Moooool2o`0000cooooo1ol000000ooooooo
0000o`000006o`000003ooooool0003o000000?ooooo0ol00005ooooo`Go00000oooool4o`0009So
oooo000Nooooo`03o`000?oooooooooo08Gooooo1ol000000ooooooo0000o`000006o`000003oooo
ool0003o000000?ooooo0ol00005ooooo`Ko00000_ooool5o`0009Oooooo000Nooooo`03o`000?oo
oooooooo08Kooooo0ol00003ooooo`Go000000Coooooo`000?l0003o00001?ooool2o`0000Wooooo
1Ol00002ooooo`;o000000Coooooo`000?l0003o0000U_ooool001kooooo00?o0000ooooooooool0
Q_ooool4o`000003ooooool0003o000000Co000000Coooooo`000?l0003o00001?ooool2o`0000Wo
oooo3_l0000>ooooo`;o0000QOooool001kooooo00?o0000ooooooooool0QOooool5o`000004oooo
ool0003o0000o`0000Gooooo0_l00002ooooo`?o00001oooool=o`000004ooooool0003o0000o`00
00kooooo0_l00025ooooo`007_ooool00ol0003oooooooooo`25ooooo`Go000000?oooooo`000?l0
00000_l00003ooooo`_o000000?oooooo`000?l000002_l00002ooooo`Ko00001oooool2o`0008co
oooo000Nooooo`03o`000?oooooooooo07Wooooo0_l00007ooooo`Co000000Coooooo`000?l0003o
oooo4ol000000ooooooo0000o`00000;o`0000?ooooo1Ol00006ooooo`;o00001_ooool2o`0008Co
oooo000Nooooo`03o`000?oooooooooo07Wooooo0_l00007ooooo`Go00000ooooolQo`0000?ooooo
1Ol0000>ooooo`;o0000Q?ooool001kooooo00?o0000ooooooooool0Poooool5o`000003ooooool0
003o000000Co00000ooooolIo`0000?ooooo1_l0002Cooooo`007_ooool00ol0003oooooooooo`23
ooooo`Go000000?oooooo`000?l000001Ol00003ooooo`?o00000ooooolCo`000003ooooool0003o
000000Go0000Toooool001kooooo00?o0000ooooooooool0P_ooool4o`0000Kooooo1?l00003oooo
o`?o00000_ooool=o`0000;ooooo3_l0002Booooo`007_ooool00ol0003oooooooooo`1iooooo`;o
00001oooool5o`000004ooooool0003o0000ooooo`?o00001?oooolDo`000003ooooool0003o0000
00Ko00000_ooool4o`0009;ooooo000Nooooo`03o`000?oooooooooo07Wooooo0_l0000:ooooo`;o
000000?oooooo`000?l000001Ol00003oooooaCo000000?oooooo`000?l000000ol00004ooooo`;o
000000?oooooo`000?l000000_l0002@ooooo`007_ooool00ol0003oooooooooo`2:ooooo`Go0000
00?oooooo`000?l000001Ol000000ooooooo0000o`00000Do`000003ooooool0003o000000Ko0000
T?ooool001kooooo00?o0000ooooooooool0N_ooool2o`0000kooooo0ol00003ooooo`Ko000000?o
ooooo`000?l000001_l00003ooooo`co000000?oooooo`000?l000001Ol0000=ooooo`;o0000P_oo
ool001kooooo0_l0001kooooo`;o00002oooool2o`000003ooooool0003o000000Kooooo3?l00000
1?oooooo0000o`000?ooool;o`000003ooooool0003o000000;o00000_ooool2o`0000;ooooo0_l0
0009ooooo`;o0000P_ooool001kooooo00?o0000ooooooooool0QOooool4o`000003ooooool0003o
000000Kooooo4?l000000ooooooo0000o`000007o`0000;ooooo0ol00003ooooo`;o00000_ooool2
o`0000Wooooo0_l00022ooooo`007_ooool00ol0003oooooooooo`25ooooo`?o00000_ooool2o`00
00Kooooo0ol000000ooooooo0000o`00000;o`000003ooooool0003o000000Go000000?oooooo`00
0?l000001_ooool2o`00097ooooo000Nooooo`03o`000?oooooooooo08Gooooo0_l0000;ooooo`?o
000000Goooooo`000?l0003o0000ooooo`0Ao`000003ooooool0003o000000;o00000_ooool4o`00
097ooooo000Nooooo`03o`000?oooooooooo08Gooooo0_l00004ooooo`;o00001?ooool4o`000003
ooooool0003o000001Go000000?oooooo`000?l000000_ooool5o`00093ooooo000Nooooo`03o`00
0?oooooooooo07Wooooo0_l0000:ooooo`;o00001?ooool4o`0000;ooooo7_l000001?oooooo0000
o`000?ooool4o`00093ooooo000Nooooo`03o`000?oooooooooo07Oooooo1?l0000:ooooo`?o0000
0oooool4o`0000Cooooo4Ol000000ooooooo0000o`000003o`0000?ooooo0_l000000ooooooo0000
o`000005o`00093ooooo000Nooooo`03o`000?oooooooooo07Oooooo1?l0000:ooooo`?o00000ooo
ool2o`000004ooooool0003o0000oooooa;o00000_ooool2o`000004ooooool0003o0000o`0000;o
oooo0_l00003ooooo`Co0000TOooool001kooooo00?o0000ooooooooool0Moooool2o`0001Gooooo
0_l000000ooooooo0000o`00000Ao`000004ooooool0003o0000ooooo`Co000000?oooooo`000?l0
00000oooool4o`00097ooooo000Nooooo`03o`000?oooooooooo08_ooooo1?l00002ooooo`_o0000
00?oooooo`000?l000002Ol000000ooooooo0000o`000003o`000003ooooool0003o000000Go0000
TOooool001kooooo00?o0000ooooooooool0OOooool2o`0000cooooo1?l00002oooooaOo000000?o
ooooo`000?l000002ol0002Aooooo`007_ooool00ol0003oooooooooo`1dooooo`;o00001oooool2
o`0000kooooo0_l00002ooooo`oo00000_ooool2o`0000Wooooo2Ol0002Aooooo`007_ooool00ol0
003oooooooooo`1dooooo`;o00004?ooool2o`0000?ooooo5Ol00002ooooo`;o000000?oooooo`00
0?l000002?ooool2o`000003ooooool0003o000000;o0000TOooool001kooooo00?o0000oooooooo
ool0M?ooool2o`00013ooooo0_l00003ooooo`;o000000?oooooo`000?l000003?l000001?oooooo
0000o`000?l00002ooooo`;o000000Coooooo`000?l0003o00000_ooool4o`0009Wooooo000Noooo
o`03o`000?oooooooooo07Cooooo0_l0000@ooooo`;o00002?oooolBo`0000;ooooo1?l00002oooo
o`Co00000_ooool2o`0001;ooooo0_l00002ooooo`;o0000OOooool001kooooo00?o0000oooooooo
ool0Soooool3o`000003ooooool0003o000000;ooooo2ol00002ooooo`Co00000_ooool3o`0000?o
oooo0_l0000@ooooo`Co00000_ooool2o`0007gooooo000Nooooo`;o0000M_ooool2o`00013ooooo
0_l00006ooooo`Go00000oooool7o`0000Kooooo1_l000000ooooooo0000o`000005o`00013ooooo
1?l00021ooooo`007_ooool00ol0003oooooooooo`1eooooo`;o00003_ooool4o`000004ooooool0
003o0000ooooo`;o000000?oooooo`000?l000000_l000001?oooooo0000o`000?ooool6o`000004
ooooool0003o0000ooooo`So00000oooool4o`0009Kooooo000Nooooo`03o`000?oooooooooo08Go
oooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo1?l000000ooooooo0000o`000002o`00
0003ooooool0003o000000_o000000?oooooo`000?l000000ol000000ooooooo0000o`00000Joooo
o`;o0000Noooool001kooooo00?o0000ooooooooool0M_ooool2o`0000kooooo0_l00006ooooo`;o
00001Oooool?o`000003ooooool0003o000000?ooooo0ol000000ooooooo0000o`00000Jooooo`;o
0000Noooool001kooooo00?o0000ooooooooool0M_ooool2o`0000kooooo0_l00006ooooo`;o0000
00Coooooo`000?l0003o00000_ooool>o`000003ooooool0003o000000;ooooo0_l0000Dooooo`;o
0000Q_ooool001kooooo00?o0000ooooooooool0MOooool2o`00013ooooo0_l00006ooooo`Oo0000
00?oooooo`000?l000002_l00002ooooo`;o00000_ooool2o`0001Cooooo0_l00026ooooo`007_oo
ool00ol0003oooooooooo`1eooooo`;o00004?ooool2o`0000Kooooo1?l000000ooooooo0000o`00
0003ooooo`Go00000oooool2o`000003ooooool0003o000001_ooooo0_l00024ooooo`007_ooool0
0ol0003oooooooooo`1eooooo`;o00004?ooool2o`0000kooooo1ol00003ooooo`Go00006oooool2
o`0000Kooooo0_l0001looooo`007_ooool00ol0003oooooooooo`27ooooo`?o00003Oooool3o`00
00;ooooo0_l00005ooooo`?o00003Oooool4o`0001;ooooo0_l0001looooo`007_ooool00ol0003o
ooooooooo`28ooooo`;o00004_ooool4o`000003ooooool0003o000000;o00003_ooool4o`00093o
oooo000Nooooo`03o`000?oooooooooo08Wooooo0ol0000Booooo`;o000000?oooooo`000?l00000
Y?ooool001kooooo00?o0000ooooooooool0ROooool3o`0000[ooooo0_l00002ooooo`;o00006?oo
ool2o`00097ooooo000Nooooo`03o`000?oooooooooo09Kooooo0_l00002ooooo`;o000000?ooooo
o`000?l000003Oooool2o`0000Cooooo1?l0002Aooooo`007_ooool00ol0003oooooooooo`2;oooo
o`;o00004?ooool2o`0000gooooo0_l00004ooooo`;o0000Toooool000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000
ooooooooool0Roooool2o`00013ooooo0_l0000Aooooo`;o0000UOooool000?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o
0000ooooooooool0Toooool2o`0000Sooooo0_l0000Aooooo`;o0000UOooool000?ooooo00Go410@
oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`0008cooooo
0_l00005ooooo`;o00002?ooool2o`000:Sooooo0003ooooo`05o`000?ooooooooooooooool00000
2oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0S?ooool4o`0000go
oooo0_l0000Booooo`;o0000U?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05
o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2>ooooo`;o00004?ooool2o`00
0003ooooool0003o000000cooooo0_l0002Dooooo`000oooool01Ol@413ooooooooooooooooo410@
00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`2Hooooo`;o00001_ooool5o`00
01Gooooo1?l00029ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@
4?nHV9P02?ooool00ol0003oooooooooo`2Hooooo`;o00001oooool2o`0000Gooooo0_l0000@oooo
o`Ko0000Qoooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000
oa0@40Kooooo00?o0000ooooooooool0T_ooool2o`0000Oooooo0_l0000:ooooo`?o00005?ooool2
o`0008Oooooo000Nooooo`03o`000?oooooooooo09;ooooo0_l00007ooooo`;o00002_ooool2o`00
09kooooo000Nooooo`03o`000?oooooooooo09Oooooo0_l0000Jooooo`;o00000oooool2o`0008go
oooo000Nooooo`03o`000?oooooooooo09Oooooo0_l0000Jooooo`;o00000oooool2o`0008gooooo
000Nooooo`03o`000?oooooooooo0:cooooo0_l0002Iooooo`007_ooool00ol0003oooooooooo`2/
ooooo`;o0000VOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000
oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooo
odSooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRH
V?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooo
oooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?oo
ool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80
1_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`000?ooooooooooooooool00000
2oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom8ooooo`00
0oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006oooo
o`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`3oooooodSooooo0003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`005?ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooooooo
ool0oooooom8ooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
B?ooool001Kooooo00?o0000ooooooooool01Oooool3o`000?ooooooB?ooool001Kooooo00?o0000
ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03
o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005?oo
ool00omEEEGoIVIVo`00003ooooooe;ooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.44361 .45944 Mdot
.48256 .47527 Mdot
.5383 .57023 Mdot
.49748 .47539 Mdot
.52002 .47919 Mdot
.45845 .47837 Mdot
.5356 .431 Mdot
.50479 .46681 Mdot
.48531 .45351 Mdot
.53037 .44447 Mdot
.47446 .44583 Mdot
.47461 .51471 Mdot
.45721 .50083 Mdot
.46428 .56101 Mdot
.46184 .41369 Mdot
.54092 .4933 Mdot
.47494 .46449 Mdot
.43038 .46769 Mdot
.50181 .42809 Mdot
.49238 .54738 Mdot
.47597 .46159 Mdot
.52819 .52003 Mdot
.5385 .46568 Mdot
.4364 .51366 Mdot
.48466 .46168 Mdot
.48725 .51815 Mdot
.54758 .47361 Mdot
.45945 .43142 Mdot
.51117 .48427 Mdot
.44657 .48095 Mdot
.46357 .54576 Mdot
.48285 .4672 Mdot
.51159 .50744 Mdot
.54234 .55318 Mdot
.45322 .49116 Mdot
.5223 .56337 Mdot
.50022 .51701 Mdot
.56727 .49536 Mdot
.53184 .46961 Mdot
.4724 .52531 Mdot
.53748 .49826 Mdot
.50374 .53675 Mdot
.46077 .5159 Mdot
.49201 .50197 Mdot
.48127 .46345 Mdot
.51736 .51618 Mdot
.51453 .55136 Mdot
.46407 .55799 Mdot
.48009 .55915 Mdot
.37324 .53694 Mdot
.5261 .47618 Mdot
.49038 .58722 Mdot
.50687 .48409 Mdot
.52636 .47199 Mdot
.54286 .48225 Mdot
.49035 .5262 Mdot
.46582 .52195 Mdot
.54078 .61589 Mdot
.49471 .46977 Mdot
.46416 .52646 Mdot
.51673 .52201 Mdot
.51213 .51425 Mdot
.52475 .5517 Mdot
.54052 .49231 Mdot
.52379 .482 Mdot
.41134 .47636 Mdot
.45485 .51103 Mdot
.50546 .51954 Mdot
.47753 .5401 Mdot
.54184 .49497 Mdot
.52979 .44435 Mdot
.50757 .47662 Mdot
.46732 .53536 Mdot
.49426 .48438 Mdot
.43912 .49788 Mdot
.54988 .46996 Mdot
.49024 .53412 Mdot
.4234 .48558 Mdot
.53949 .46615 Mdot
.47132 .44226 Mdot
.56243 .51405 Mdot
.50195 .46733 Mdot
.48336 .4585 Mdot
.53141 .50778 Mdot
.53255 .55221 Mdot
.49891 .48422 Mdot
.56174 .52285 Mdot
.50315 .51751 Mdot
.4697 .52763 Mdot
.42489 .56061 Mdot
.51379 .48756 Mdot
.52701 .51395 Mdot
.56046 .5093 Mdot
.37581 .51363 Mdot
.5454 .52612 Mdot
.51507 .53361 Mdot
.49781 .52048 Mdot
.4603 .54345 Mdot
.52743 .54686 Mdot
.46716 .51018 Mdot
.56172 .51493 Mdot
.5612 .51754 Mdot
.50765 .47209 Mdot
.40835 .50113 Mdot
.49648 .45516 Mdot
.51402 .50994 Mdot
.63532 .406 Mdot
.52089 .485 Mdot
.45951 .49825 Mdot
.52872 .51355 Mdot
.43304 .49164 Mdot
.50571 .47629 Mdot
.48238 .48854 Mdot
.55356 .45513 Mdot
.45311 .50936 Mdot
.46531 .55186 Mdot
.56428 .48598 Mdot
.45554 .42875 Mdot
.49456 .5815 Mdot
.55964 .50661 Mdot
.42926 .48565 Mdot
.48636 .51517 Mdot
.53389 .45098 Mdot
.46977 .55253 Mdot
.47575 .46882 Mdot
.5558 .45216 Mdot
.43258 .49726 Mdot
.48776 .51612 Mdot
.49157 .50869 Mdot
.54127 .48522 Mdot
.43504 .45658 Mdot
.47049 .47056 Mdot
.53588 .58131 Mdot
.50232 .55967 Mdot
.53034 .47676 Mdot
.539 .57725 Mdot
.51427 .41305 Mdot
.50201 .4924 Mdot
.472 .54065 Mdot
.48435 .4952 Mdot
.518 .48596 Mdot
.53336 .46117 Mdot
.49933 .51032 Mdot
.5026 .478 Mdot
.51792 .50118 Mdot
.52913 .51489 Mdot
.4459 .4557 Mdot
.50978 .53518 Mdot
.45109 .51393 Mdot
.47117 .55225 Mdot
.51357 .55476 Mdot
.45287 .43287 Mdot
.51798 .48293 Mdot
.44266 .5527 Mdot
.44804 .44372 Mdot
.54116 .49344 Mdot
.51719 .51267 Mdot
.48161 .55386 Mdot
.48901 .53468 Mdot
.51526 .49452 Mdot
.50511 .41721 Mdot
.48815 .53916 Mdot
.4238 .50698 Mdot
.54438 .48552 Mdot
.46784 .52418 Mdot
.47365 .50311 Mdot
.5032 .45593 Mdot
.5521 .50575 Mdot
.51572 .52364 Mdot
.56518 .47857 Mdot
.46166 .43311 Mdot
.46541 .54483 Mdot
.47527 .48038 Mdot
.46785 .52774 Mdot
.48225 .3958 Mdot
.4973 .51926 Mdot
.52298 .53389 Mdot
.51813 .49153 Mdot
.52357 .54484 Mdot
.48005 .55657 Mdot
.49865 .47719 Mdot
.52282 .5314 Mdot
.49644 .48964 Mdot
.50753 .48331 Mdot
.45904 .51665 Mdot
.47598 .50935 Mdot
.56002 .54728 Mdot
.51711 .52425 Mdot
.39029 .49986 Mdot
.55888 .49722 Mdot
.48674 .50084 Mdot
.53319 .48361 Mdot
.43268 .51465 Mdot
.5192 .48361 Mdot
.56565 .4865 Mdot
.53458 .49743 Mdot
.36678 .54315 Mdot
.50157 .5057 Mdot
.52504 .48091 Mdot
.4915 .47689 Mdot
.46967 .50153 Mdot
.50479 .52238 Mdot
.43139 .47315 Mdot
.53132 .5149 Mdot
.54097 .4747 Mdot
.47208 .48447 Mdot
.47239 .46708 Mdot
.46411 .51543 Mdot
.55178 .55502 Mdot
.52099 .4815 Mdot
.47985 .46284 Mdot
.49935 .5153 Mdot
.47225 .53435 Mdot
.44585 .48475 Mdot
.4858 .51526 Mdot
.50806 .55069 Mdot
.52271 .51632 Mdot
.48562 .53584 Mdot
.53622 .46143 Mdot
.51735 .48822 Mdot
.53519 .47462 Mdot
.5303 .59583 Mdot
.52714 .5154 Mdot
.47052 .55541 Mdot
.50819 .47604 Mdot
.51199 .47445 Mdot
.49004 .4709 Mdot
.53328 .44864 Mdot
.55527 .55318 Mdot
.49541 .45142 Mdot
.53709 .48657 Mdot
.49808 .51461 Mdot
.55567 .46202 Mdot
.51494 .51251 Mdot
.49035 .52189 Mdot
.47184 .54149 Mdot
.56042 .4591 Mdot
.55405 .47401 Mdot
.46927 .47749 Mdot
.47585 .50954 Mdot
.53203 .44632 Mdot
.47885 .41711 Mdot
.43675 .46915 Mdot
.5606 .45948 Mdot
.53956 .52721 Mdot
.54356 .48816 Mdot
.54211 .45776 Mdot
.51329 .47237 Mdot
.53986 .47463 Mdot
.5578 .47889 Mdot
.46095 .51608 Mdot
.45921 .52498 Mdot
.51395 .44593 Mdot
.54152 .52987 Mdot
.48549 .48693 Mdot
.47193 .51234 Mdot
.54411 .46222 Mdot
.47942 .53329 Mdot
.53845 .55075 Mdot
.53489 .46502 Mdot
.55214 .50863 Mdot
.53449 .49016 Mdot
.51515 .495 Mdot
.439 .46691 Mdot
.49441 .54991 Mdot
.51939 .55005 Mdot
.51796 .45948 Mdot
.43533 .44605 Mdot
.53 .50359 Mdot
.53047 .54773 Mdot
.45863 .50416 Mdot
.48198 .48905 Mdot
.39124 .49803 Mdot
.48245 .49229 Mdot
.55425 .55484 Mdot
.53851 .44982 Mdot
.49136 .52946 Mdot
.51175 .43087 Mdot
.48635 .54606 Mdot
.51816 .43699 Mdot
.47419 .54029 Mdot
.4831 .52311 Mdot
.46129 .56862 Mdot
.50746 .49824 Mdot
.56729 .48151 Mdot
.37366 .51837 Mdot
.5155 .54671 Mdot
.5418 .46427 Mdot
.47153 .47706 Mdot
.43876 .54999 Mdot
.46932 .51967 Mdot
.44416 .52951 Mdot
.45851 .5497 Mdot
.46019 .52749 Mdot
.47385 .50249 Mdot
.52215 .47341 Mdot
.45109 .43385 Mdot
.48234 .5556 Mdot
.51835 .53322 Mdot
.49804 .47503 Mdot
.49656 .4992 Mdot
.51236 .47512 Mdot
.47271 .45473 Mdot
.54093 .50694 Mdot
.47152 .51666 Mdot
.49924 .47568 Mdot
.60971 .56011 Mdot
.43828 .50977 Mdot
.48053 .46266 Mdot
.48787 .55028 Mdot
.49465 .47926 Mdot
.50818 .5006 Mdot
.53211 .45113 Mdot
.46261 .46441 Mdot
.48693 .4793 Mdot
.45094 .518 Mdot
.4733 .52585 Mdot
.5039 .51892 Mdot
.46818 .53588 Mdot
.56636 .49274 Mdot
.47424 .55435 Mdot
.46999 .44567 Mdot
.46884 .43731 Mdot
.49471 .52138 Mdot
.47048 .43011 Mdot
.5598 .48217 Mdot
.48866 .50194 Mdot
.49019 .50984 Mdot
.50569 .44424 Mdot
.56025 .52676 Mdot
.44248 .46017 Mdot
.47174 .55858 Mdot
.4809 .48986 Mdot
.52676 .44034 Mdot
.54686 .55787 Mdot
.53423 .45685 Mdot
.50752 .55504 Mdot
.50336 .47631 Mdot
.47098 .46039 Mdot
.50865 .51511 Mdot
.45444 .51561 Mdot
.44804 .51223 Mdot
.59872 .44001 Mdot
.50269 .5092 Mdot
.54031 .50424 Mdot
.45843 .49779 Mdot
.5064 .49708 Mdot
.51221 .47087 Mdot
.55487 .50739 Mdot
.53157 .50774 Mdot
.46785 .52029 Mdot
.53041 .58344 Mdot
.47663 .46228 Mdot
.50824 .51473 Mdot
.44411 .52912 Mdot
.47095 .51095 Mdot
.45428 .55505 Mdot
.46702 .47739 Mdot
.44762 .56875 Mdot
.51599 .50937 Mdot
.5251 .47973 Mdot
.4481 .52148 Mdot
.47651 .49721 Mdot
.4424 .55201 Mdot
.46396 .48356 Mdot
.4654 .57185 Mdot
.52814 .54992 Mdot
.54969 .50464 Mdot
.5926 .52064 Mdot
.49963 .48537 Mdot
.51546 .49391 Mdot
.50636 .491 Mdot
.52364 .58545 Mdot
.49783 .46497 Mdot
.51061 .5774 Mdot
.53774 .46049 Mdot
.49899 .45932 Mdot
.56111 .50226 Mdot
.49672 .54131 Mdot
.49571 .51717 Mdot
.49339 .55302 Mdot
.54631 .50207 Mdot
.50903 .47869 Mdot
.46141 .54796 Mdot
.49069 .4705 Mdot
.46393 .4557 Mdot
.45678 .43197 Mdot
.53702 .45862 Mdot
.48751 .52549 Mdot
.48824 .55338 Mdot
.58217 .57896 Mdot
.4869 .54363 Mdot
.47493 .5547 Mdot
.483 .46691 Mdot
.53673 .4658 Mdot
.49876 .46453 Mdot
.54364 .50499 Mdot
.51058 .5041 Mdot
.46892 .42996 Mdot
.57479 .5738 Mdot
.58436 .56059 Mdot
.49644 .55717 Mdot
.61723 .58305 Mdot
.48178 .52319 Mdot
.47115 .55193 Mdot
.50902 .56414 Mdot
.50681 .48188 Mdot
.51594 .49066 Mdot
.46538 .50567 Mdot
.47484 .43688 Mdot
.48245 .50006 Mdot
.49698 .42845 Mdot
.49577 .48517 Mdot
.4657 .55737 Mdot
.49963 .48737 Mdot
.56131 .51461 Mdot
.53299 .51087 Mdot
.43201 .52176 Mdot
.45967 .52944 Mdot
.53584 .45415 Mdot
.50978 .43312 Mdot
.5145 .51703 Mdot
.49545 .49014 Mdot
.51786 .43539 Mdot
.57953 .61695 Mdot
.51342 .55866 Mdot
.47172 .43826 Mdot
.5328 .50303 Mdot
.47563 .54324 Mdot
.47356 .53278 Mdot
.43969 .53485 Mdot
.54173 .4959 Mdot
.46872 .4716 Mdot
.50514 .43187 Mdot
.52301 .51717 Mdot
.4366 .5202 Mdot
.5195 .52083 Mdot
.46565 .52364 Mdot
.43871 .52712 Mdot
.4677 .52649 Mdot
.46095 .53132 Mdot
.44309 .59156 Mdot
.44164 .54456 Mdot
.44266 .45828 Mdot
.51529 .50977 Mdot
.43894 .44979 Mdot
.5141 .47937 Mdot
.54146 .47868 Mdot
.54217 .5561 Mdot
.51332 .48628 Mdot
.48793 .56799 Mdot
.47783 .50464 Mdot
.53593 .50284 Mdot
.46846 .52982 Mdot
.55515 .53063 Mdot
.51624 .45001 Mdot
.50999 .5544 Mdot
.56883 .49837 Mdot
.51152 .49248 Mdot
.47639 .53323 Mdot
.53058 .52108 Mdot
.49171 .48253 Mdot
.46987 .56994 Mdot
.5151 .51215 Mdot
.46907 .54839 Mdot
.50973 .55902 Mdot
.52716 .51003 Mdot
.49235 .49217 Mdot
.44726 .52619 Mdot
.47866 .53538 Mdot
.46083 .44852 Mdot
.53045 .45105 Mdot
.56573 .36476 Mdot
.42098 .39231 Mdot
.48082 .42772 Mdot
.50444 .45215 Mdot
.48293 .56684 Mdot
.4147 .39132 Mdot
.56155 .51173 Mdot
.52902 .57498 Mdot
.50711 .50245 Mdot
.47705 .46223 Mdot
.50712 .47027 Mdot
.49557 .46643 Mdot
.51415 .51766 Mdot
.52517 .52024 Mdot
.524 .44042 Mdot
.44199 .45951 Mdot
.46859 .5485 Mdot
.56058 .49897 Mdot
.4704 .59271 Mdot
.55508 .55278 Mdot
.44167 .46202 Mdot
.52238 .48482 Mdot
.46177 .51605 Mdot
.44766 .53018 Mdot
.55637 .46922 Mdot
.52128 .48836 Mdot
.51649 .52542 Mdot
.49674 .47186 Mdot
.62264 .43725 Mdot
.50733 .44528 Mdot
.56015 .4029 Mdot
.53539 .46964 Mdot
.47561 .50811 Mdot
.5143 .43417 Mdot
.449 .46969 Mdot
.53498 .45942 Mdot
.55736 .50947 Mdot
.37235 .52642 Mdot
.48602 .5436 Mdot
.52671 .55376 Mdot
.46034 .51203 Mdot
.45529 .49851 Mdot
.50621 .47467 Mdot
.54009 .49943 Mdot
.46067 .51385 Mdot
.454 .48866 Mdot
.48137 .56754 Mdot
.46587 .46491 Mdot
.53788 .46836 Mdot
.45784 .50449 Mdot
.47904 .46854 Mdot
.48997 .5192 Mdot
.47266 .50843 Mdot
.49584 .52145 Mdot
.49154 .55928 Mdot
.48518 .58828 Mdot
.4494 .44259 Mdot
.48696 .42675 Mdot
.53946 .53508 Mdot
.52943 .51492 Mdot
.48981 .52949 Mdot
.49068 .48303 Mdot
.39919 .49123 Mdot
.47889 .5122 Mdot
.46659 .54377 Mdot
.50882 .51914 Mdot
.46431 .51944 Mdot
.50949 .43015 Mdot
.48416 .4883 Mdot
.41829 .51937 Mdot
.53403 .51189 Mdot
.45077 .53509 Mdot
.44297 .4496 Mdot
.53577 .4589 Mdot
.50688 .4792 Mdot
.4179 .53453 Mdot
.50848 .47577 Mdot
.50755 .43775 Mdot
.46998 .52625 Mdot
.53131 .47237 Mdot
.51454 .5037 Mdot
.62305 .44742 Mdot
.49918 .47413 Mdot
.53229 .48097 Mdot
.51291 .4896 Mdot
.46752 .54484 Mdot
.4631 .58246 Mdot
.55919 .49481 Mdot
.56056 .52103 Mdot
.55154 .54678 Mdot
.54031 .47033 Mdot
.50377 .48551 Mdot
.50441 .54317 Mdot
.54383 .46177 Mdot
.52614 .38546 Mdot
.51987 .43742 Mdot
.46063 .54453 Mdot
.48089 .56348 Mdot
.52783 .54847 Mdot
.49259 .51595 Mdot
.46398 .53894 Mdot
.51141 .47307 Mdot
.4782 .50624 Mdot
.53785 .50006 Mdot
.41942 .54223 Mdot
.47055 .52605 Mdot
.55734 .48211 Mdot
.47872 .51753 Mdot
.55935 .54549 Mdot
.50925 .47739 Mdot
.60746 .41844 Mdot
.46663 .50027 Mdot
.48678 .53851 Mdot
.54961 .52995 Mdot
.52629 .47584 Mdot
.46022 .49718 Mdot
.4624 .49376 Mdot
.52771 .54836 Mdot
.47425 .51048 Mdot
.52343 .51247 Mdot
.52608 .47999 Mdot
.48534 .50651 Mdot
.54131 .47916 Mdot
.44129 .46202 Mdot
.44091 .53055 Mdot
.52641 .53147 Mdot
.42426 .50373 Mdot
.47974 .4784 Mdot
.53808 .51001 Mdot
.54028 .50663 Mdot
.45366 .45703 Mdot
.44035 .51538 Mdot
.52492 .51193 Mdot
.45996 .50378 Mdot
.5373 .47339 Mdot
.50233 .57425 Mdot
.51122 .51421 Mdot
.48817 .50998 Mdot
.44149 .43072 Mdot
.43558 .47811 Mdot
.54194 .46397 Mdot
.53779 .54019 Mdot
.44227 .46073 Mdot
.51611 .48228 Mdot
.53127 .46981 Mdot
.54281 .47596 Mdot
.52327 .48289 Mdot
.48017 .40146 Mdot
.53564 .43664 Mdot
.50176 .59973 Mdot
.48625 .48388 Mdot
.51626 .51294 Mdot
.53872 .5274 Mdot
.48829 .55175 Mdot
.51613 .4845 Mdot
.50951 .49136 Mdot
.53553 .57696 Mdot
.47214 .47727 Mdot
.51308 .52054 Mdot
.54182 .48624 Mdot
.47481 .55617 Mdot
.41618 .51994 Mdot
.41706 .52616 Mdot
.47639 .45958 Mdot
.5566 .48299 Mdot
.48942 .49433 Mdot
.50101 .47167 Mdot
.51402 .54733 Mdot
.51587 .47129 Mdot
.49075 .53253 Mdot
.51797 .56234 Mdot
.53047 .5057 Mdot
.54088 .4807 Mdot
.44093 .5021 Mdot
.44326 .52165 Mdot
.518 .51038 Mdot
.54146 .46953 Mdot
.53776 .4589 Mdot
.48044 .46968 Mdot
.51448 .50152 Mdot
.50528 .5125 Mdot
.45978 .49776 Mdot
.47616 .49418 Mdot
.46075 .5191 Mdot
.41003 .47134 Mdot
.48845 .49741 Mdot
.52182 .5414 Mdot
.48426 .50846 Mdot
.50727 .47503 Mdot
.51858 .50558 Mdot
.44303 .55123 Mdot
.5584 .62206 Mdot
.60735 .46649 Mdot
.51643 .55467 Mdot
.5546 .49849 Mdot
.61829 .57006 Mdot
.43186 .47983 Mdot
.40291 .43847 Mdot
.47559 .47473 Mdot
.56191 .61059 Mdot
.59234 .56027 Mdot
.53658 .50693 Mdot
.53917 .48008 Mdot
.52194 .44529 Mdot
.47059 .54331 Mdot
.48284 .46426 Mdot
.44733 .43578 Mdot
.52212 .47294 Mdot
.52254 .52495 Mdot
.5599 .52131 Mdot
.46503 .48814 Mdot
.56082 .51476 Mdot
.47737 .46429 Mdot
.5047 .52448 Mdot
.4765 .47041 Mdot
.4581 .5182 Mdot
.46916 .53425 Mdot
.47935 .54804 Mdot
.5017 .53586 Mdot
.52889 .56591 Mdot
.50482 .59667 Mdot
.48928 .52321 Mdot
.47375 .55263 Mdot
.46467 .46354 Mdot
.63188 .41767 Mdot
.49615 .50261 Mdot
.53067 .5118 Mdot
.4996 .47543 Mdot
.53635 .47318 Mdot
.47868 .51352 Mdot
.45631 .56623 Mdot
.52389 .48196 Mdot
.50886 .57735 Mdot
.51974 .42515 Mdot
.49823 .5196 Mdot
.52347 .4782 Mdot
.54384 .54524 Mdot
.51672 .43469 Mdot
.45608 .45393 Mdot
.48699 .50868 Mdot
.55565 .53869 Mdot
.47827 .42042 Mdot
.43679 .54922 Mdot
.54758 .47356 Mdot
.48775 .41853 Mdot
.46575 .4727 Mdot
.46043 .46385 Mdot
.44383 .43847 Mdot
.49901 .4825 Mdot
.478 .43399 Mdot
.47403 .54402 Mdot
.49344 .48169 Mdot
.44126 .4756 Mdot
.46882 .5154 Mdot
.42373 .54899 Mdot
.44468 .49191 Mdot
.46671 .54405 Mdot
.50318 .53281 Mdot
.4506 .44161 Mdot
.53407 .50579 Mdot
.46911 .51638 Mdot
.52467 .5107 Mdot
.47303 .57377 Mdot
.53413 .44101 Mdot
.49463 .5207 Mdot
.52538 .52885 Mdot
.50198 .42913 Mdot
.48379 .53445 Mdot
.51997 .51586 Mdot
.4603 .52769 Mdot
.48613 .52351 Mdot
.49043 .47383 Mdot
.52542 .49201 Mdot
.52473 .47397 Mdot
.52174 .48532 Mdot
.50382 .5167 Mdot
.49299 .509 Mdot
.45423 .44622 Mdot
.49104 .55997 Mdot
.51138 .49452 Mdot
.46659 .52622 Mdot
.52288 .47649 Mdot
.53263 .484 Mdot
.44614 .5442 Mdot
.53242 .46141 Mdot
.53642 .45704 Mdot
.46268 .54047 Mdot
.51512 .4362 Mdot
.45412 .46533 Mdot
.46287 .45997 Mdot
.3986 .39364 Mdot
.49239 .54047 Mdot
.42223 .54975 Mdot
.48915 .48502 Mdot
.47713 .55705 Mdot
.50657 .4797 Mdot
.48996 .50376 Mdot
.51333 .56763 Mdot
.45897 .45051 Mdot
.46219 .54504 Mdot
.44941 .49029 Mdot
.5011 .48644 Mdot
.53467 .56043 Mdot
.5591 .49854 Mdot
.42394 .42812 Mdot
.47575 .46623 Mdot
.49112 .48959 Mdot
.47577 .53627 Mdot
.53536 .47699 Mdot
.45811 .50003 Mdot
.45273 .47913 Mdot
.45976 .60119 Mdot
.57075 .61227 Mdot
.53582 .446 Mdot
.47731 .4897 Mdot
.53921 .49225 Mdot
.46114 .43116 Mdot
.50328 .5297 Mdot
.48879 .47857 Mdot
.43262 .46937 Mdot
.49757 .47955 Mdot
.56812 .49993 Mdot
.46108 .49516 Mdot
.54866 .49822 Mdot
.45954 .50801 Mdot
.62804 .44131 Mdot
.5409 .47456 Mdot
.56711 .50401 Mdot
.53498 .4918 Mdot
.46495 .51684 Mdot
.55947 .51169 Mdot
.38634 .43112 Mdot
.44536 .46017 Mdot
.54108 .48566 Mdot
.46824 .52181 Mdot
.49598 .47117 Mdot
.48019 .46098 Mdot
.4228 .45447 Mdot
.50594 .47922 Mdot
.53756 .46109 Mdot
.50025 .48012 Mdot
.46149 .43989 Mdot
.54043 .47099 Mdot
.46095 .51811 Mdot
.51186 .52927 Mdot
.46699 .51706 Mdot
.46165 .46253 Mdot
.46741 .5489 Mdot
.52484 .5101 Mdot
.48624 .48504 Mdot
.53059 .43931 Mdot
.50849 .43063 Mdot
.45645 .46316 Mdot
.47175 .42094 Mdot
.52428 .48107 Mdot
.46931 .48004 Mdot
.46173 .4933 Mdot
.48597 .52394 Mdot
.60436 .47435 Mdot
.45494 .51648 Mdot
.49873 .58088 Mdot
.51062 .51725 Mdot
.49877 .51382 Mdot
.53895 .48033 Mdot
.50517 .53949 Mdot
.46639 .44253 Mdot
.48776 .48202 Mdot
.56803 .48553 Mdot
.44153 .46154 Mdot
.52142 .51556 Mdot
.51805 .53155 Mdot
.49754 .40776 Mdot
.53653 .46155 Mdot
.55228 .5326 Mdot
.40291 .44152 Mdot
.50756 .54115 Mdot
.51944 .5172 Mdot
.46802 .53664 Mdot
.47267 .47224 Mdot
.43259 .51811 Mdot
.49718 .5559 Mdot
.59651 .56127 Mdot
.47447 .38787 Mdot
.47799 .50423 Mdot
.5253 .50814 Mdot
.45208 .50214 Mdot
.49363 .49083 Mdot
.52057 .48418 Mdot
.55236 .53915 Mdot
.47749 .50435 Mdot
.50953 .50032 Mdot
.56141 .51317 Mdot
.44464 .43673 Mdot
.55276 .54811 Mdot
.47476 .48508 Mdot
.42996 .44382 Mdot
.48466 .47719 Mdot
.52191 .61999 Mdot
.4355 .4567 Mdot
.56792 .48433 Mdot
.47584 .57467 Mdot
.4411 .46217 Mdot
.45753 .46984 Mdot
.49991 .48597 Mdot
.52962 .47053 Mdot
.5267 .51283 Mdot
.46983 .52577 Mdot
.48325 .58548 Mdot
.59896 .47668 Mdot
.52392 .58461 Mdot
.45205 .51152 Mdot
.50811 .48646 Mdot
.42708 .57157 Mdot
.49203 .46727 Mdot
.47004 .53343 Mdot
.5388 .49776 Mdot
.55863 .49193 Mdot
.509 .57522 Mdot
.49936 .53741 Mdot
.50616 .51129 Mdot
.5618 .52236 Mdot
.5059 .43363 Mdot
.52067 .49054 Mdot
.39877 .49239 Mdot
.51432 .48161 Mdot
.46117 .49747 Mdot
.48065 .49225 Mdot
.48024 .48914 Mdot
.45526 .44206 Mdot
.46959 .50193 Mdot
.4703 .47418 Mdot
.48478 .47874 Mdot
.51218 .43558 Mdot
.49999 .48249 Mdot
.55952 .49691 Mdot
.47 .53945 Mdot
.52257 .47316 Mdot
.44755 .52113 Mdot
.532 .5407 Mdot
.54358 .51171 Mdot
.47701 .5006 Mdot
.53304 .46769 Mdot
.48006 .46924 Mdot
.47575 .5178 Mdot
.5617 .52354 Mdot
.57255 .45467 Mdot
.43314 .49065 Mdot
.56486 .49862 Mdot
.52462 .51147 Mdot
.49357 .50437 Mdot
.45821 .55708 Mdot
.55309 .53156 Mdot
.51946 .45306 Mdot
.49461 .48107 Mdot
.52316 .47347 Mdot
.4716 .51805 Mdot
.41263 .45915 Mdot
.50385 .48254 Mdot
.47523 .49291 Mdot
.51397 .53037 Mdot
.4511 .46102 Mdot
.47025 .47451 Mdot
.4932 .49337 Mdot
.36627 .54717 Mdot
.51399 .51365 Mdot
.59035 .49274 Mdot
.55208 .47766 Mdot
.52862 .43833 Mdot
.4782 .55137 Mdot
.48504 .46294 Mdot
.47282 .55277 Mdot
.49641 .48098 Mdot
.5039 .52624 Mdot
.43893 .46825 Mdot
.45557 .53353 Mdot
.45812 .55847 Mdot
.46162 .53395 Mdot
.45371 .54207 Mdot
.46173 .43065 Mdot
.48332 .49379 Mdot
.42242 .51536 Mdot
.46706 .48316 Mdot
.49647 .47764 Mdot
.4357 .44354 Mdot
.56151 .51513 Mdot
.53632 .50699 Mdot
.58857 .4983 Mdot
.46334 .39208 Mdot
.55494 .52299 Mdot
.49901 .48834 Mdot
.5272 .52431 Mdot
.50177 .5142 Mdot
.52377 .50999 Mdot
.46042 .52752 Mdot
.55873 .55012 Mdot
.47119 .49764 Mdot
.5354 .50423 Mdot
.55987 .50671 Mdot
.51295 .54681 Mdot
.43523 .48876 Mdot
.47303 .56719 Mdot
.55067 .50373 Mdot
.59207 .52365 Mdot
.54117 .4989 Mdot
.62624 .40667 Mdot
.4976 .48962 Mdot
.48229 .52155 Mdot
.42732 .47597 Mdot
.43487 .5769 Mdot
.51574 .48995 Mdot
.50142 .46788 Mdot
.51443 .4777 Mdot
.44503 .5327 Mdot
.49256 .582 Mdot
.44457 .47264 Mdot
.4829 .4849 Mdot
.53917 .50753 Mdot
.53546 .45213 Mdot
.44378 .45922 Mdot
.53142 .46996 Mdot
.4418 .50542 Mdot
.52093 .43946 Mdot
.53753 .46213 Mdot
.50615 .52442 Mdot
.55592 .48951 Mdot
.55183 .53739 Mdot
.50743 .41613 Mdot
.41916 .53855 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0;Cooooo0_l0
002Aooooo`007_ooool00ol0003oooooooooo`2dooooo`;o0000TOooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`2Wooooo`;o0000W_ooool001kooooo00?o0000ooooooooool0U_ooool2o`00
00oooooo0_l0002Nooooo`007_ooool00ol0003oooooooooo`23ooooo`;o00004Oooool2o`000:oo
oooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413o
ooooooooo`04ooooo`03o`000?oooooooooo07gooooo0_l00004ooooo`Co00003?ooool2o`000;;o
oooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`1mooooo`;o00001_ooool2o`0000cooooo0_l00004ooooo`;o
0000[?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool3o`0009Wo
oooo0_l0002/ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoo
oooo00001oooool00ol0003oooooooooo`2Hooooo`;o00006?ooool2o`0009?ooooo0003ooooo`05
o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooo
oooo09Sooooo0_l0000Hooooo`;o00004oooool2o`000003ooooool0003o000007_ooooo0003oooo
o`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooo
oooo09kooooo0_l0000Wooooo`;o000000?oooooo`000?l00000Noooool000?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0W_ooool2
o`0000?ooooo0_l0002Rooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMg
o`000?ooool01_ooool00ol0003oooooooooo`2Booooo`;o00003Oooool4o`000:;ooooo000Noooo
o`03o`000?oooooooooo09;ooooo0_l00004ooooo`Co00001?ooool3o`0001kooooo0_l00006oooo
o`;o0000O?ooool001kooooo00?o0000ooooooooool0UOooool7o`0000Cooooo0_l0000Oooooo`;o
00001_ooool2o`0007cooooo000Nooooo`03o`000?oooooooooo09Gooooo1?l0000<ooooo`;o0000
X?ooool001kooooo00?o0000ooooooooool0Q_ooool2o`0000Sooooo0_l00006ooooo`Co000000?o
ooooo`000?l000000_l00004ooooo`;o0000X?ooool001kooooo00?o0000ooooooooool0NOooool2
o`0000_ooooo0_l00003ooooo`;o00000oooool7o`000003ooooool0003o000000;o000000?ooooo
o`000?l000001Ol00006ooooo`;o0000Voooool001kooooo00?o0000ooooooooool0NOooool2o`00
013ooooo0_l00002ooooo`[o00001_ooool7o`0000Cooooo0_l0002Kooooo`007_ooool00ol0003o
ooooooooo`2<ooooo`Go000000?oooooo`000?l000001Ol00007ooooo`Oo00000oooool2o`0001[o
oooo0_l0001oooooo`007_ooool00ol0003oooooooooo`1oooooo`;o00002oooool3o`0000?ooooo
1_l00009ooooo`_o00004oooool2o`0000Gooooo0_l0001oooooo`007_ooool00ol0003ooooooooo
o`1oooooo`;o00001oooool?o`0000Wooooo0_l00003ooooo`Oo00004oooool2o`0000Oooooo0_l0
001mooooo`007_ooool00ol0003oooooooooo`1oooooo`;o00001oooool4o`0000;ooooo1?l00002
ooooo`Co00002?ooool5o`000003ooooool0003o000000Co00006_ooool4o`0007gooooo000Noooo
o`03o`000?oooooooooo08Wooooo1Ol00002ooooo`Co000000Coooooo`000?l0003o00002Oooool<
o`0001Wooooo0_l0001oooooo`007_ooool2o`0008cooooo0ol00003ooooo`?o00001_ooool2o`00
0004ooooool0003o0000ooooo`;o00000_ooool3o`000003ooooool0003o000000?o00001?ooool2
o`0009Cooooo000Nooooo`03o`000?oooooooooo08Gooooo0_l00002ooooo`;o00000_ooool2o`00
0003ooooool0003o000000?o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o0000
00?o00000oooool2o`000003ooooool0003o000000;o00001?ooool3o`0000?ooooo0_l0002?oooo
o`007_ooool00ol0003oooooooooo`22ooooo`;o000000?oooooo`000?l000000_ooool2o`000003
ooooool0003o000000Co000000Coooooo`000?l0003ooooo1Ol00002ooooo`Co00000oooool2o`00
00Cooooo1?l00002ooooo`Co00000_ooool2o`0008oooooo000Nooooo`03o`000?oooooooooo08;o
oooo0_l00005ooooo`So000000Coooooo`000?l0003ooooo1_l00003ooooo`;o00001?ooool2o`00
00?ooooo1_l00002ooooo`?o0000Toooool001kooooo00?o0000ooooooooool0RooooolAo`0000;o
oooo0_l00009ooooo`Ko00000_ooool2o`0009Cooooo000Nooooo`03o`000?oooooooooo08Sooooo
0_l000000ooooooo0000o`000003oooooa;o00001oooool5o`0001?ooooo0_l00024ooooo`007_oo
ool00ol0003oooooooooo`21ooooo`;o00001Oooool5o`000004ooooool0003o0000ooooo`;o0000
00?oooooo`000?l000004?l000000ooooooo0000o`000005o`000003ooooool0003o000000;o0000
3_ooool2o`0008Cooooo000Nooooo`03o`000?oooooooooo087ooooo0_l00005ooooo`So000000?o
ooooo`000?l000001ol000000ooooooo0000o`00000Fo`0000gooooo0_l00025ooooo`007_ooool0
0ol0003oooooooooo`22ooooo`;o00000oooool7o`0000Gooooo4_l000000ooooooo0000o`00000:
o`0000gooooo0ol00025ooooo`007_ooool00ol0003oooooooooo`22ooooo`;o00000oooool<o`00
0003ooooool0003o000001So000000?oooooo`000?l000000_l000000ooooooo0000o`000009oooo
o`;o0000Q_ooool001kooooo00?o0000ooooooooool0R?ooool2o`0000?ooooo8Ol00003ooooo`Ko
0000T?ooool001kooooo00?o0000ooooooooool0Q_ooool3o`0000Cooooo0_l00004ooooo`Go0000
00?oooooo`000?l000003Ol000000ooooooo0000o`000004o`0000;ooooo1_l0002@ooooo`007_oo
ool00ol0003oooooooooo`26ooooo`Go00000_ooool4o`0000;ooooo5Ol00002ooooo`Go00000_oo
ool6o`00093ooooo000Nooooo`03o`000?oooooooooo07kooooo0_l00009ooooo`;o000000?ooooo
o`000?l000000ol000001Ooooooo0000o`000?l0003ooooo00Go000000?oooooo`000?l000002ol0
00000ooooooo0000o`000003o`0000;ooooo1Ol00006ooooo`;o0000ROooool001kooooo00?o0000
ooooooooool0O_ooool2o`0000Wooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0
003o000000;ooooo2?l000000ooooooo0000o`000008o`000003ooooool0003o000000;o00001?oo
ool4o`0000Kooooo0_l00029ooooo`007_ooool00ol0003oooooooooo`1kooooo`;o00003?ooool4
o`0000?ooooo1?l000000ooooooo0000o`000008o`0000;ooooo1?l00005ooooo`go00001?ooool2
o`0008[ooooo000Nooooo`;o0000O?ooool2o`0000Cooooo0_l00006ooooo`Co00000_ooool@o`00
00;ooooo1Ol00004ooooo`go00001?ooool2o`0008[ooooo000Nooooo`03o`000?oooooooooo07_o
oooo0_l00004ooooo`;o00000oooool2o`0000?ooooo0ol000000ooooooo0000o`00000Eo`0000;o
oooo2Ol000000ooooooo0000o`000003o`00093ooooo000Nooooo`03o`000?oooooooooo08Kooooo
0_l00004ooooo`;o00000oooool4o`000003ooooool0003o000000Ko000000Coooooo`000?l0003o
oooo1?l000000ooooooo0000o`00000=o`00097ooooo000Nooooo`03o`000?oooooooooo08Kooooo
0_l00002ooooo`;o00000oooool4o`000003ooooool0003o000001ko0000Toooool001kooooo00?o
0000ooooooooool0M_ooool2o`00017ooooo0ol00002ooooo`co000000?oooooo`000?l000004_l0
0002ooooo`Co0000T_ooool001kooooo00?o0000ooooooooool0M_ooool2o`0000gooooo0_l00002
ooooo`Co000000?oooooo`000?l000006ol00007ooooo`?o0000T_ooool001kooooo00?o0000oooo
ooooool0MOooool2o`0000cooooo1?l00002ooooob7o00002?ooool2o`0000Wooooo0_l00028oooo
o`007_ooool00ol0003oooooooooo`1eooooo`;o00003?ooool3o`0000;ooooo2?l000000ooooooo
0000o`000003o`0000?ooooo4Ol00006ooooo`Go00001oooool3o`0008Sooooo000Nooooo`03o`00
0?oooooooooo07Gooooo0_l0000<ooooo`;o00000oooool2o`000003ooooool0003o000000?o0000
00?oooooo`000?l000001Ol000000ooooooo0000o`000004o`000003ooooool0003o000000;ooooo
1Ol00002ooooo`Co000000?oooooo`000?l000000ol00007ooooo`;o0000ROooool001kooooo00?o
0000ooooooooool0MOooool2o`0000cooooo0_l00006ooooo`Co00000_ooool7o`0000;ooooo1?l0
0002ooooo`Wo00000_ooool6o`000003ooooool0003o000009?ooooo000Nooooo`03o`000?oooooo
oooo08_ooooo1?l000000ooooooo0000o`000008o`000005ooooool0003o0000o`000?ooool02_l0
0002ooooo`?o000000Coooooo`000?l0003o0000UOooool001kooooo00?o0000ooooooooool0Q?oo
ool2o`0000Gooooo4_l00002ooooo`;o000000?oooooo`000?l000001Ol00002ooooo`;o00000_oo
ool3o`0009Gooooo000Nooooo`03o`000?oooooooooo07Gooooo0_l0000=ooooo`;o00001Oooool2
o`000003ooooool0003o000000;ooooo2ol000000ooooooo0000o`000005o`000003ooooool0003o
000000?ooooo0_l00002ooooo`Co0000U?ooool001kooooo00?o0000ooooooooool0MOooool2o`00
00gooooo0_l00009ooooo`;o000000?oooooo`000?l000001Ol000000ooooooo0000o`000007o`00
00?ooooo0_l000000ooooooo0000o`000002o`0000;ooooo1?l0002Dooooo`007_ooool00ol0003o
ooooooooo`1cooooo`;o00003oooool2o`0000Gooooo1_l000000ooooooo0000o`000005o`000003
ooooool0003o000000?o000000Coooooo`000?l0003o00000oooool2o`000003ooooool0003o0000
00Co00000oooool2o`0009?ooooo000Nooooo`03o`000?oooooooooo07?ooooo0_l0000Fooooo`Co
00000oooool<o`0000;ooooo0_l000001?oooooo0000o`000?ooool4o`0000?ooooo1ol0002Coooo
o`007_ooool2o`0007Cooooo0_l0000@ooooo`?o00000_ooool4o`0000?ooooo3_l00002ooooo`Wo
000000?oooooo`000?l000000_ooool5o`0009?ooooo000Nooooo`03o`000?oooooooooo08Gooooo
0ol00002ooooo`Co00000_ooool?o`0000;ooooo3Ol000000ooooooo0000o`000003o`0009?ooooo
000Nooooo`03o`000?oooooooooo08cooooo0_l00002oooooa3o000000?oooooo`000?l000000ol0
00000ooooooo0000o`000002o`000003ooooool0003o000000Co0000UOooool001kooooo00?o0000
ooooooooool0Q_ooool2o`0000Wooooo2_l000000ooooooo0000o`000003o`000004ooooool0003o
0000o`0000Gooooo1_l0000:ooooo`Co00001?ooool2o`0008?ooooo000Nooooo`03o`000?oooooo
oooo08Kooooo0_l00009ooooo`Ko000000?oooooo`000?l000000_ooool2o`000003ooooool0003o
000000Oo00000_ooool2o`0000kooooo1_l00002ooooo`;o0000Poooool001kooooo00?o0000oooo
ooooool0T?ooool2o`0000Cooooo1Ol00006ooooo`;o000000?oooooo`000?l000001?l0000Doooo
o`;o0000Qoooool001kooooo00?o0000ooooooooool0SOooool2o`000003ooooool0003o000000;o
000000?oooooo`000?l000001_l00006ooooo`;o00000oooool2o`000003ooooool0003o000001So
oooo0_l00020ooooo`007_ooool00ol0003oooooooooo`27ooooo`;o00001?ooool2o`0000?ooooo
1Ol000001?oooooo0000o`000?ooool2o`0000Kooooo0_l00006ooooo`;o00006?ooool2o`00083o
oooo000Nooooo`03o`000?oooooooooo08Oooooo0_l0000:ooooo`;o000000Coooooo`000?l0003o
00001_ooool4o`0000Gooooo0_l0000=ooooo`;o0000S_ooool001kooooo00?o0000ooooooooool0
ROooool2o`0000_ooooo0ol00006ooooo`Go00001?ooool5o`0000[ooooo1?l0002<ooooo`007_oo
ool00ol0003oooooooooo`29ooooo`;o00001oooool2o`0000Sooooo1?l000001?oooooo0000o`00
0?l00006ooooo`?o00003?ooool2o`0008cooooo000Nooooo`03o`000?oooooooooo09;ooooo0_l0
0005ooooo`;o000000?oooooo`000?l000000_l00006ooooo`Ko00006Oooool2o`00083ooooo000N
ooooo`03o`000?oooooooooo09Wooooo1?l00009ooooo`Co00006oooool2o`00083ooooo000Noooo
o`03o`000?oooooooooo08cooooo0_l0000<ooooo`?o0000Z_ooool000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000
ooooooooool0S?ooool2o`0000Oooooo0_l0002`ooooo`000oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooooooo
o`2Eooooo`;o00002Oooool2o`0000Kooooo0_l0002Mooooo`000oooool01Ol@413ooooooooooooo
oooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000TOooool2o`0000cooooo
0ol00006ooooo`;o0000WOooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?nHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2Aooooo`;o00003?ooool2o`000:Ko
oooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<
00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol@413ooooooooooooooooo410@
00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo
0;?ooooo1?l0002@ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4
A?l0003o410@1_ooool00ol0003oooooooooo`2/ooooo`;o00001Oooool4o`00093ooooo000Noooo
o`03o`000?oooooooooo0:cooooo0_l0000:ooooo`;o0000SOooool001kooooo00?o0000oooooooo
ool0Y_ooool2o`0000Wooooo0_l00005ooooo`;o0000SOooool001kooooo00?o0000ooooooooool0
Y_ooool2o`0000Wooooo0_l0002Dooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0
003oooooooooo`3oooooodSooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooB?ooool0
00?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_oo
ool3o`000?ooooooB?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nH
V9SooooooiRHV?lb<S801_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`000?oo
ooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000oooooooo
ool0oooooom8ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oo
oooo^[Zjoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`3o
ooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00Kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o
0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`005?ooool4o`000003oa0@4?oooooooooo00?o
oooo00?o0000ooooooooool0oooooom8ooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0?ooooooB?ooool001Kooooo00?o0000ooooooooool01Oooool3o`000?ooooooB?oo
ool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooo
oe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0
oooooom@ooooo`005?ooool00omEEEGoIVIVo`00003ooooooe;ooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.46267 .45157 Mdot
.49937 .47116 Mdot
.51635 .58205 Mdot
.51338 .47834 Mdot
.52938 .49226 Mdot
.46332 .44453 Mdot
.54319 .47568 Mdot
.52779 .47628 Mdot
.53041 .45261 Mdot
.55158 .4678 Mdot
.50208 .45378 Mdot
.47351 .50263 Mdot
.45263 .46112 Mdot
.43449 .54953 Mdot
.49665 .4296 Mdot
.53935 .51701 Mdot
.49302 .45723 Mdot
.44962 .43656 Mdot
.53146 .43778 Mdot
.46616 .54392 Mdot
.49454 .45401 Mdot
.51159 .54032 Mdot
.54374 .47603 Mdot
.42261 .48628 Mdot
.51048 .46409 Mdot
.48077 .51122 Mdot
.56659 .50756 Mdot
.49103 .42152 Mdot
.51794 .49361 Mdot
.44688 .45203 Mdot
.45272 .51758 Mdot
.50189 .46817 Mdot
.50579 .51082 Mdot
.51511 .56488 Mdot
.44952 .45601 Mdot
.49362 .56332 Mdot
.49104 .5138 Mdot
.56463 .5151 Mdot
.53732 .48304 Mdot
.46718 .51319 Mdot
.53422 .51682 Mdot
.47434 .54039 Mdot
.45816 .49083 Mdot
.48988 .49762 Mdot
.50047 .4651 Mdot
.50129 .52266 Mdot
.47385 .55843 Mdot
.45132 .53313 Mdot
.45574 .54072 Mdot
.38078 .51059 Mdot
.53084 .49098 Mdot
.46716 .55352 Mdot
.51404 .49131 Mdot
.53724 .48416 Mdot
.54767 .50965 Mdot
.47623 .52186 Mdot
.46311 .50138 Mdot
.51618 .60189 Mdot
.51446 .47784 Mdot
.45861 .50493 Mdot
.49708 .5275 Mdot
.49828 .51731 Mdot
.49446 .5577 Mdot
.53948 .51596 Mdot
.52312 .4974 Mdot
.44694 .4584 Mdot
.45896 .48278 Mdot
.4877 .5212 Mdot
.46115 .53464 Mdot
.53965 .51843 Mdot
.54965 .48738 Mdot
.52378 .48552 Mdot
.45723 .5166 Mdot
.50044 .48404 Mdot
.43258 .4678 Mdot
.55843 .51114 Mdot
.4716 .53274 Mdot
.44033 .45244 Mdot
.55029 .51214 Mdot
.5049 .43514 Mdot
.54674 .53216 Mdot
.52687 .47635 Mdot
.50441 .45737 Mdot
.52213 .52073 Mdot
.50327 .56083 Mdot
.50543 .48684 Mdot
.54698 .55249 Mdot
.48766 .51817 Mdot
.46441 .51394 Mdot
.42151 .5238 Mdot
.51569 .49735 Mdot
.51262 .52607 Mdot
.55065 .54028 Mdot
.39237 .49 Mdot
.53417 .56254 Mdot
.49558 .53967 Mdot
.48227 .51925 Mdot
.45314 .51414 Mdot
.48708 .55882 Mdot
.46932 .49042 Mdot
.54922 .54704 Mdot
.54615 .54531 Mdot
.52597 .48308 Mdot
.43187 .46954 Mdot
.54175 .46336 Mdot
.50748 .51267 Mdot
.64325 .42353 Mdot
.5218 .49852 Mdot
.46568 .47399 Mdot
.51452 .52656 Mdot
.43638 .46896 Mdot
.5224 .48472 Mdot
.49038 .4795 Mdot
.576 .47039 Mdot
.46173 .48119 Mdot
.45239 .50704 Mdot
.5782 .50931 Mdot
.48622 .41974 Mdot
.47232 .57753 Mdot
.55246 .53804 Mdot
.44894 .45448 Mdot
.48195 .50826 Mdot
.55213 .47696 Mdot
.45138 .5281 Mdot
.4927 .46206 Mdot
.56886 .47208 Mdot
.43016 .47241 Mdot
.48242 .50949 Mdot
.4882 .50388 Mdot
.54498 .5095 Mdot
.462 .43516 Mdot
.4875 .45651 Mdot
.49947 .56706 Mdot
.47279 .55364 Mdot
.54787 .48353 Mdot
.5012 .56695 Mdot
.53172 .42668 Mdot
.50144 .49479 Mdot
.4579 .5271 Mdot
.488 .48706 Mdot
.51948 .49813 Mdot
.56806 .4774 Mdot
.49467 .508 Mdot
.51617 .48324 Mdot
.51145 .5107 Mdot
.51425 .52738 Mdot
.46109 .44481 Mdot
.48852 .54406 Mdot
.45842 .48506 Mdot
.44976 .52975 Mdot
.48326 .5544 Mdot
.48426 .42109 Mdot
.52316 .4958 Mdot
.42868 .5306 Mdot
.47585 .42916 Mdot
.5396 .51719 Mdot
.5043 .51705 Mdot
.45084 .5189 Mdot
.4706 .53307 Mdot
.51084 .50536 Mdot
.53356 .44795 Mdot
.46692 .53869 Mdot
.43746 .47185 Mdot
.55145 .51197 Mdot
.46354 .50708 Mdot
.47838 .4876 Mdot
.54692 .47069 Mdot
.52806 .52136 Mdot
.48999 .53852 Mdot
.5652 .4983 Mdot
.4918 .42292 Mdot
.44863 .5209 Mdot
.49004 .47061 Mdot
.46157 .51128 Mdot
.50971 .41902 Mdot
.4852 .51656 Mdot
.50645 .54458 Mdot
.51396 .50446 Mdot
.47847 .5484 Mdot
.45545 .54189 Mdot
.5129 .48049 Mdot
.50585 .53879 Mdot
.4992 .48901 Mdot
.51536 .49107 Mdot
.45261 .47321 Mdot
.47679 .49737 Mdot
.54079 .56842 Mdot
.49722 .52888 Mdot
.4141 .47623 Mdot
.55509 .53208 Mdot
.48722 .4935 Mdot
.535 .50746 Mdot
.42263 .48868 Mdot
.52279 .49683 Mdot
.56376 .5063 Mdot
.53269 .51583 Mdot
.37165 .51815 Mdot
.49709 .50522 Mdot
.52152 .49749 Mdot
.50673 .47642 Mdot
.47626 .4836 Mdot
.4856 .52366 Mdot
.45453 .44499 Mdot
.50096 .52831 Mdot
.54773 .5032 Mdot
.48503 .47194 Mdot
.4914 .45393 Mdot
.46374 .49416 Mdot
.52672 .56856 Mdot
.52543 .49545 Mdot
.49903 .46296 Mdot
.49204 .51193 Mdot
.46243 .52396 Mdot
.46449 .45211 Mdot
.48146 .50817 Mdot
.46708 .55594 Mdot
.50661 .52584 Mdot
.46884 .53278 Mdot
.56982 .47754 Mdot
.51638 .50063 Mdot
.53446 .49595 Mdot
.5009 .57633 Mdot
.51182 .52718 Mdot
.43485 .53754 Mdot
.53713 .48801 Mdot
.53628 .48267 Mdot
.50939 .47492 Mdot
.55404 .47362 Mdot
.53373 .57032 Mdot
.53004 .45874 Mdot
.54594 .51608 Mdot
.49168 .51094 Mdot
.5786 .47786 Mdot
.5041 .51498 Mdot
.48041 .51567 Mdot
.45736 .52734 Mdot
.57478 .477 Mdot
.55935 .51526 Mdot
.48401 .46317 Mdot
.47662 .49752 Mdot
.55336 .4705 Mdot
.5133 .43842 Mdot
.44694 .45062 Mdot
.57073 .47933 Mdot
.52192 .5643 Mdot
.54586 .51405 Mdot
.55768 .49852 Mdot
.53558 .48155 Mdot
.55349 .50325 Mdot
.57769 .50333 Mdot
.45892 .49194 Mdot
.45335 .48027 Mdot
.54771 .47706 Mdot
.52702 .56601 Mdot
.49264 .48033 Mdot
.47306 .49735 Mdot
.55205 .47554 Mdot
.46696 .52645 Mdot
.51017 .56178 Mdot
.56708 .49046 Mdot
.52707 .52351 Mdot
.53598 .51211 Mdot
.5105 .50562 Mdot
.46153 .44027 Mdot
.46631 .54619 Mdot
.48903 .55522 Mdot
.54749 .46862 Mdot
.46159 .42457 Mdot
.52533 .51777 Mdot
.48566 .54965 Mdot
.46209 .47758 Mdot
.48984 .47971 Mdot
.41624 .47513 Mdot
.48788 .48357 Mdot
.53509 .5742 Mdot
.55641 .49129 Mdot
.47457 .52676 Mdot
.53917 .44459 Mdot
.46267 .54051 Mdot
.54293 .45381 Mdot
.45884 .53021 Mdot
.47439 .51481 Mdot
.43933 .55601 Mdot
.50253 .50294 Mdot
.57681 .50155 Mdot
.38749 .49393 Mdot
.47219 .55251 Mdot
.54516 .47841 Mdot
.48654 .46501 Mdot
.42813 .52673 Mdot
.46767 .50352 Mdot
.44273 .50116 Mdot
.45049 .50419 Mdot
.45225 .5017 Mdot
.4788 .48708 Mdot
.53656 .48508 Mdot
.48107 .4195 Mdot
.45693 .54345 Mdot
.48718 .54059 Mdot
.51444 .47874 Mdot
.49357 .49785 Mdot
.53683 .48322 Mdot
.51957 .45515 Mdot
.53264 .52532 Mdot
.47072 .50251 Mdot
.51507 .47949 Mdot
.58359 .57075 Mdot
.44355 .4841 Mdot
.50738 .46426 Mdot
.46143 .54376 Mdot
.50626 .47995 Mdot
.50293 .50488 Mdot
.55493 .46693 Mdot
.49074 .46628 Mdot
.50153 .47563 Mdot
.46004 .48858 Mdot
.46748 .51427 Mdot
.48707 .52012 Mdot
.45747 .5185 Mdot
.56118 .512 Mdot
.45144 .53566 Mdot
.49495 .45312 Mdot
.48945 .44064 Mdot
.48178 .51778 Mdot
.50143 .42471 Mdot
.55185 .50393 Mdot
.48797 .49566 Mdot
.48687 .50434 Mdot
.54453 .44767 Mdot
.54079 .54805 Mdot
.45371 .44449 Mdot
.45278 .51634 Mdot
.48884 .47972 Mdot
.54935 .46184 Mdot
.52047 .56862 Mdot
.54784 .48022 Mdot
.47731 .55199 Mdot
.5195 .48251 Mdot
.49908 .47065 Mdot
.49456 .51716 Mdot
.45618 .4865 Mdot
.45983 .48529 Mdot
.594 .47125 Mdot
.4978 .50838 Mdot
.51955 .52702 Mdot
.46882 .472 Mdot
.50188 .5014 Mdot
.53165 .48163 Mdot
.53146 .52268 Mdot
.52231 .52088 Mdot
.46576 .50139 Mdot
.49527 .56617 Mdot
.49561 .45763 Mdot
.49767 .51475 Mdot
.44785 .48682 Mdot
.47261 .49362 Mdot
.42605 .54331 Mdot
.48211 .46029 Mdot
.43954 .52838 Mdot
.50942 .51328 Mdot
.52339 .4961 Mdot
.45602 .49246 Mdot
.48255 .48399 Mdot
.42225 .53478 Mdot
.47715 .46338 Mdot
.44259 .56209 Mdot
.50149 .57605 Mdot
.52569 .5212 Mdot
.55864 .53904 Mdot
.50526 .4881 Mdot
.5113 .50504 Mdot
.50604 .496 Mdot
.49062 .564 Mdot
.53036 .47672 Mdot
.48682 .57791 Mdot
.55144 .48766 Mdot
.53306 .46879 Mdot
.55398 .53785 Mdot
.46946 .54272 Mdot
.48809 .51255 Mdot
.46478 .54603 Mdot
.54184 .54524 Mdot
.52166 .48641 Mdot
.43158 .52044 Mdot
.51034 .47577 Mdot
.47359 .43281 Mdot
.4883 .42135 Mdot
.54847 .48093 Mdot
.47497 .51942 Mdot
.46098 .54443 Mdot
.55083 .58057 Mdot
.4638 .5412 Mdot
.45211 .53737 Mdot
.5022 .46839 Mdot
.5385 .47946 Mdot
.52126 .47312 Mdot
.54036 .52561 Mdot
.50484 .50868 Mdot
.49989 .42375 Mdot
.54082 .57549 Mdot
.55064 .56757 Mdot
.46745 .5497 Mdot
.5955 .58988 Mdot
.47361 .51441 Mdot
.45012 .53405 Mdot
.47979 .55913 Mdot
.51595 .48939 Mdot
.51345 .5025 Mdot
.47024 .48573 Mdot
.50697 .43125 Mdot
.48479 .49064 Mdot
.52665 .43583 Mdot
.50127 .48549 Mdot
.45195 .53266 Mdot
.5037 .48943 Mdot
.54812 .54435 Mdot
.52076 .52656 Mdot
.4235 .4956 Mdot
.45146 .5061 Mdot
.55335 .48051 Mdot
.53664 .44384 Mdot
.49766 .52249 Mdot
.49814 .4887 Mdot
.54382 .45283 Mdot
.55612 .61544 Mdot
.48341 .55636 Mdot
.51375 .45386 Mdot
.5282 .51791 Mdot
.45733 .53242 Mdot
.46418 .52261 Mdot
.43821 .50916 Mdot
.539 .51902 Mdot
.48851 .45553 Mdot
.53348 .43924 Mdot
.49517 .53252 Mdot
.4224 .49313 Mdot
.49346 .53678 Mdot
.46205 .50307 Mdot
.43939 .5013 Mdot
.46194 .50947 Mdot
.45101 .5048 Mdot
.43195 .55722 Mdot
.43405 .51873 Mdot
.46626 .43475 Mdot
.50857 .51301 Mdot
.46655 .42893 Mdot
.52624 .48945 Mdot
.54696 .50615 Mdot
.51519 .56691 Mdot
.51694 .49622 Mdot
.45794 .56997 Mdot
.47985 .49315 Mdot
.52998 .51931 Mdot
.46183 .5144 Mdot
.5305 .55287 Mdot
.55478 .45795 Mdot
.47963 .55269 Mdot
.56231 .51693 Mdot
.50893 .50112 Mdot
.46559 .5247 Mdot
.49926 .53285 Mdot
.49974 .48095 Mdot
.4535 .5496 Mdot
.50507 .51458 Mdot
.44907 .52765 Mdot
.46722 .54871 Mdot
.5182 .51827 Mdot
.49491 .48848 Mdot
.44678 .49745 Mdot
.46549 .52911 Mdot
.48127 .45294 Mdot
.54914 .4744 Mdot
.57576 .38481 Mdot
.44729 .39501 Mdot
.51221 .42641 Mdot
.54686 .45693 Mdot
.45976 .54911 Mdot
.43965 .39209 Mdot
.55053 .54506 Mdot
.49041 .56046 Mdot
.50187 .50567 Mdot
.49619 .45838 Mdot
.53123 .47944 Mdot
.51583 .47514 Mdot
.49662 .52306 Mdot
.49384 .5321 Mdot
.54796 .46092 Mdot
.45937 .44937 Mdot
.44871 .5265 Mdot
.55444 .53532 Mdot
.45507 .55676 Mdot
.53244 .56904 Mdot
.4838 .44664 Mdot
.5188 .50047 Mdot
.46091 .49357 Mdot
.44948 .48678 Mdot
.57895 .48829 Mdot
.5163 .50328 Mdot
.4853 .5346 Mdot
.52572 .47933 Mdot
.62099 .46167 Mdot
.54394 .47323 Mdot
.56482 .4359 Mdot
.54297 .495 Mdot
.47706 .49575 Mdot
.54163 .45274 Mdot
.46959 .45644 Mdot
.55272 .48466 Mdot
.55212 .54607 Mdot
.38304 .50084 Mdot
.46327 .54083 Mdot
.49675 .55923 Mdot
.4605 .4888 Mdot
.46145 .45867 Mdot
.53312 .48277 Mdot
.53535 .52102 Mdot
.46008 .49058 Mdot
.45145 .4538 Mdot
.45222 .56614 Mdot
.49456 .4699 Mdot
.55474 .49683 Mdot
.46216 .47735 Mdot
.50933 .47296 Mdot
.48211 .51289 Mdot
.47536 .49278 Mdot
.48062 .51952 Mdot
.46398 .54887 Mdot
.46383 .5535 Mdot
.47965 .42618 Mdot
.51767 .42806 Mdot
.50985 .55001 Mdot
.51456 .52745 Mdot
.47365 .52605 Mdot
.49858 .48065 Mdot
.42679 .46769 Mdot
.4776 .50194 Mdot
.43497 .51453 Mdot
.49078 .52212 Mdot
.4622 .49809 Mdot
.53828 .44388 Mdot
.49114 .48062 Mdot
.42745 .48346 Mdot
.52139 .5271 Mdot
.42609 .50667 Mdot
.473 .43284 Mdot
.55804 .49645 Mdot
.51877 .48638 Mdot
.42179 .49719 Mdot
.52516 .48582 Mdot
.53683 .44457 Mdot
.46533 .51241 Mdot
.54375 .48113 Mdot
.50833 .51048 Mdot
.6154 .47128 Mdot
.5173 .48128 Mdot
.53032 .50268 Mdot
.51246 .49871 Mdot
.45057 .52544 Mdot
.4497 .54358 Mdot
.56568 .52562 Mdot
.54415 .54622 Mdot
.52655 .56384 Mdot
.54941 .49866 Mdot
.50938 .49043 Mdot
.47462 .54602 Mdot
.55288 .47521 Mdot
.53858 .41618 Mdot
.54367 .45405 Mdot
.43098 .51652 Mdot
.45769 .54435 Mdot
.48305 .54919 Mdot
.48645 .51075 Mdot
.44984 .5174 Mdot
.52875 .48446 Mdot
.47955 .49506 Mdot
.53281 .51972 Mdot
.42151 .50475 Mdot
.46585 .51275 Mdot
.55874 .5222 Mdot
.47495 .50783 Mdot
.54282 .57015 Mdot
.52443 .48618 Mdot
.60965 .44494 Mdot
.47385 .48208 Mdot
.46691 .53748 Mdot
.50759 .54971 Mdot
.54491 .48325 Mdot
.46831 .4719 Mdot
.47644 .46839 Mdot
.49749 .5564 Mdot
.47517 .49761 Mdot
.50937 .52154 Mdot
.5218 .49694 Mdot
.48416 .4987 Mdot
.54722 .50604 Mdot
.45253 .44578 Mdot
.4226 .50297 Mdot
.51232 .54293 Mdot
.43892 .46906 Mdot
.49541 .47187 Mdot
.51008 .52495 Mdot
.53941 .52933 Mdot
.47677 .45774 Mdot
.4496 .47568 Mdot
.51112 .52198 Mdot
.46324 .47847 Mdot
.54617 .49961 Mdot
.47593 .58237 Mdot
.49769 .51686 Mdot
.48525 .50366 Mdot
.46961 .41605 Mdot
.44748 .45938 Mdot
.55201 .47419 Mdot
.49649 .55579 Mdot
.45836 .44859 Mdot
.52361 .49386 Mdot
.53341 .48474 Mdot
.55074 .50414 Mdot
.52265 .49798 Mdot
.51015 .42308 Mdot
.54375 .4824 Mdot
.47778 .57131 Mdot
.49559 .47818 Mdot
.50339 .51691 Mdot
.51497 .56348 Mdot
.46104 .54401 Mdot
.52032 .49625 Mdot
.50805 .49843 Mdot
.49763 .56615 Mdot
.48722 .46612 Mdot
.49392 .52506 Mdot
.5439 .51236 Mdot
.45239 .53437 Mdot
.42459 .4839 Mdot
.42405 .48999 Mdot
.50503 .47127 Mdot
.55885 .52257 Mdot
.49189 .48875 Mdot
.52037 .48179 Mdot
.47078 .55248 Mdot
.536 .48114 Mdot
.47269 .5307 Mdot
.48941 .5814 Mdot
.52466 .5185 Mdot
.5472 .50618 Mdot
.45535 .46572 Mdot
.44987 .4804 Mdot
.50948 .51416 Mdot
.5395 .51913 Mdot
.54604 .50694 Mdot
.51115 .47552 Mdot
.50835 .50901 Mdot
.49886 .51143 Mdot
.46602 .47373 Mdot
.48447 .4806 Mdot
.4569 .49422 Mdot
.44667 .45702 Mdot
.48985 .49105 Mdot
.49071 .54994 Mdot
.48278 .50022 Mdot
.5246 .4852 Mdot
.51214 .51358 Mdot
.42137 .53441 Mdot
.53522 .61433 Mdot
.59394 .49521 Mdot
.4862 .55559 Mdot
.53551 .51694 Mdot
.59572 .57976 Mdot
.43976 .45935 Mdot
.43606 .43486 Mdot
.49197 .46717 Mdot
.53527 .6037 Mdot
.56093 .56869 Mdot
.53795 .53208 Mdot
.54541 .50529 Mdot
.54645 .47101 Mdot
.45547 .52674 Mdot
.50229 .46714 Mdot
.4779 .4205 Mdot
.53761 .48416 Mdot
.5042 .53152 Mdot
.54358 .54615 Mdot
.47508 .46984 Mdot
.54989 .54076 Mdot
.49585 .46069 Mdot
.48485 .52571 Mdot
.49329 .46325 Mdot
.45374 .4743 Mdot
.46069 .51954 Mdot
.45795 .53752 Mdot
.4808 .53849 Mdot
.5018 .56852 Mdot
.47955 .56857 Mdot
.47827 .51724 Mdot
.45142 .53679 Mdot
.48862 .45483 Mdot
.63551 .43791 Mdot
.49295 .50053 Mdot
.51757 .52609 Mdot
.51616 .48006 Mdot
.54777 .48018 Mdot
.4769 .50333 Mdot
.43942 .54819 Mdot
.52353 .49723 Mdot
.48494 .58563 Mdot
.53881 .46639 Mdot
.48367 .51798 Mdot
.52875 .4927 Mdot
.51602 .55908 Mdot
.54304 .4516 Mdot
.49775 .43949 Mdot
.48466 .50177 Mdot
.53306 .56058 Mdot
.50768 .42524 Mdot
.42523 .52701 Mdot
.56574 .50829 Mdot
.51563 .42667 Mdot
.48693 .45672 Mdot
.4671 .43692 Mdot
.47343 .42102 Mdot
.50707 .48562 Mdot
.50949 .43032 Mdot
.45655 .53099 Mdot
.50212 .48133 Mdot
.45711 .45877 Mdot
.46902 .49648 Mdot
.4237 .50968 Mdot
.46174 .45748 Mdot
.43501 .51489 Mdot
.48245 .53511 Mdot
.4779 .42849 Mdot
.52627 .52109 Mdot
.4688 .49834 Mdot
.51368 .51781 Mdot
.45601 .53262 Mdot
.54454 .48734 Mdot
.48407 .51611 Mdot
.50985 .54505 Mdot
.53135 .43903 Mdot
.46886 .52967 Mdot
.50411 .52374 Mdot
.44806 .48521 Mdot
.47594 .51638 Mdot
.52178 .48064 Mdot
.52008 .5095 Mdot
.53327 .4878 Mdot
.51861 .50068 Mdot
.48895 .5174 Mdot
.48935 .50473 Mdot
.47056 .44421 Mdot
.46347 .5486 Mdot
.50755 .5027 Mdot
.46149 .50657 Mdot
.53123 .49042 Mdot
.54085 .51598 Mdot
.42261 .51997 Mdot
.56744 .47797 Mdot
.55185 .48377 Mdot
.45343 .51174 Mdot
.54081 .44763 Mdot
.45842 .43969 Mdot
.47189 .43485 Mdot
.42102 .39008 Mdot
.46846 .54073 Mdot
.42228 .51106 Mdot
.49604 .48126 Mdot
.4422 .53116 Mdot
.51792 .48692 Mdot
.48808 .49828 Mdot
.4853 .56429 Mdot
.4794 .43056 Mdot
.45386 .5157 Mdot
.44571 .4569 Mdot
.50586 .48968 Mdot
.50657 .56522 Mdot
.56195 .52964 Mdot
.46038 .43083 Mdot
.50512 .46918 Mdot
.49526 .48586 Mdot
.46312 .52876 Mdot
.54171 .503 Mdot
.46732 .47367 Mdot
.45286 .44795 Mdot
.44529 .56847 Mdot
.54521 .60837 Mdot
.55524 .48679 Mdot
.48819 .47711 Mdot
.53929 .51369 Mdot
.49154 .42153 Mdot
.47633 .53756 Mdot
.50356 .47598 Mdot
.45551 .44127 Mdot
.50895 .48218 Mdot
.56277 .51912 Mdot
.4677 .47227 Mdot
.52993 .52 Mdot
.46126 .48111 Mdot
.62374 .4636 Mdot
.5483 .50238 Mdot
.53755 .53761 Mdot
.53589 .51311 Mdot
.4641 .49593 Mdot
.55256 .54702 Mdot
.41289 .42553 Mdot
.46572 .45322 Mdot
.54392 .51098 Mdot
.46528 .50447 Mdot
.52483 .47863 Mdot
.49972 .45999 Mdot
.44631 .42945 Mdot
.51777 .48613 Mdot
.55908 .4985 Mdot
.51146 .48458 Mdot
.47659 .43784 Mdot
.54926 .49925 Mdot
.4574 .49294 Mdot
.49152 .53268 Mdot
.46656 .49714 Mdot
.48691 .45818 Mdot
.45104 .52318 Mdot
.51571 .51699 Mdot
.49439 .47921 Mdot
.55254 .47855 Mdot
.53676 .44313 Mdot
.48107 .45817 Mdot
.5022 .42151 Mdot
.52278 .49706 Mdot
.48309 .46486 Mdot
.46919 .47149 Mdot
.47547 .51688 Mdot
.58719 .50297 Mdot
.45564 .48704 Mdot
.4752 .58393 Mdot
.49411 .52093 Mdot
.4928 .51044 Mdot
.54505 .50552 Mdot
.47528 .5433 Mdot
.49954 .43316 Mdot
.49811 .47772 Mdot
.5716 .5055 Mdot
.45927 .4507 Mdot
.50573 .5242 Mdot
.49918 .53725 Mdot
.52494 .43683 Mdot
.54812 .5084 Mdot
.52626 .55309 Mdot
.43649 .43736 Mdot
.47717 .54554 Mdot
.50248 .52497 Mdot
.45712 .51854 Mdot
.48881 .46228 Mdot
.44318 .48013 Mdot
.45883 .55618 Mdot
.5665 .57013 Mdot
.50094 .40802 Mdot
.48011 .49278 Mdot
.51905 .51753 Mdot
.46094 .46234 Mdot
.49646 .48815 Mdot
.5228 .49766 Mdot
.52709 .55877 Mdot
.47972 .49265 Mdot
.5041 .5055 Mdot
.55258 .53968 Mdot
.47348 .42048 Mdot
.52887 .56589 Mdot
.48762 .47354 Mdot
.45728 .42388 Mdot
.50074 .47345 Mdot
.49922 .60131 Mdot
.46066 .43188 Mdot
.57142 .50416 Mdot
.45711 .55723 Mdot
.45174 .44541 Mdot
.47966 .45653 Mdot
.50508 .48868 Mdot
.53974 .4821 Mdot
.51275 .52465 Mdot
.46536 .51166 Mdot
.46223 .54958 Mdot
.58112 .50704 Mdot
.49049 .56336 Mdot
.45886 .48309 Mdot
.51312 .49357 Mdot
.42071 .53485 Mdot
.5121 .47488 Mdot
.46164 .52015 Mdot
.53488 .51887 Mdot
.55802 .5307 Mdot
.47515 .54854 Mdot
.47824 .53975 Mdot
.50049 .51081 Mdot
.55085 .55363 Mdot
.53434 .4405 Mdot
.5152 .50494 Mdot
.42479 .46739 Mdot
.52356 .49196 Mdot
.46671 .47475 Mdot
.48691 .48223 Mdot
.4893 .47854 Mdot
.47869 .42705 Mdot
.47595 .4839 Mdot
.48651 .45617 Mdot
.50005 .47457 Mdot
.54659 .43812 Mdot
.50826 .48626 Mdot
.55576 .53426 Mdot
.45741 .52401 Mdot
.53707 .48464 Mdot
.452 .49185 Mdot
.50182 .55282 Mdot
.51476 .52505 Mdot
.48097 .48844 Mdot
.53577 .4818 Mdot
.49806 .4655 Mdot
.47286 .5068 Mdot
.54174 .5482 Mdot
.56225 .49529 Mdot
.4355 .4677 Mdot
.56824 .523 Mdot
.51153 .52038 Mdot
.49054 .50079 Mdot
.42872 .54618 Mdot
.52795 .55176 Mdot
.554 .4824 Mdot
.50398 .48151 Mdot
.53585 .48564 Mdot
.47016 .50414 Mdot
.45129 .45118 Mdot
.5124 .48871 Mdot
.485 .47886 Mdot
.48293 .53741 Mdot
.49743 .45124 Mdot
.48571 .46211 Mdot
.49493 .4899 Mdot
.36995 .52218 Mdot
.50071 .51703 Mdot
.56451 .52122 Mdot
.57216 .50726 Mdot
.5517 .47651 Mdot
.45126 .51251 Mdot
.51167 .46594 Mdot
.45018 .53252 Mdot
.50573 .48275 Mdot
.48373 .52746 Mdot
.45181 .45169 Mdot
.45078 .50384 Mdot
.44671 .53383 Mdot
.45057 .5116 Mdot
.42737 .51453 Mdot
.49372 .42277 Mdot
.48783 .48533 Mdot
.43115 .47726 Mdot
.47991 .46565 Mdot
.51023 .47975 Mdot
.46267 .42341 Mdot
.54788 .54533 Mdot
.52723 .52521 Mdot
.5576 .52441 Mdot
.49235 .40814 Mdot
.53009 .53757 Mdot
.50243 .48971 Mdot
.51465 .54304 Mdot
.49476 .51177 Mdot
.51478 .51648 Mdot
.4521 .50082 Mdot
.53989 .57093 Mdot
.47957 .48112 Mdot
.5285 .52079 Mdot
.55684 .53476 Mdot
.4825 .55074 Mdot
.4451 .4676 Mdot
.45485 .52561 Mdot
.52755 .52077 Mdot
.55785 .54116 Mdot
.5368 .52092 Mdot
.63352 .42651 Mdot
.50027 .48978 Mdot
.47486 .51284 Mdot
.44541 .44362 Mdot
.42701 .53988 Mdot
.5139 .50144 Mdot
.52152 .47802 Mdot
.53949 .48536 Mdot
.44159 .50469 Mdot
.47067 .57773 Mdot
.46321 .45764 Mdot
.4937 .47662 Mdot
.52998 .5255 Mdot
.55008 .47336 Mdot
.46292 .45165 Mdot
.53262 .48515 Mdot
.45114 .47999 Mdot
.54502 .45817 Mdot
.55207 .48872 Mdot
.48614 .52599 Mdot
.55979 .52637 Mdot
.5374 .56739 Mdot
.53306 .44998 Mdot
.42203 .50071 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0;Oooooo0_l0002>ooooo`007_ooool00ol0003oooooooooo`2gooooo`;o0000S_ooool001ko
oooo00?o0000ooooooooool0QOooool2o`000<3ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo08Go
oooo0_l00004ooooo`Co0000^?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08_ooooo1?l0002hooooo`00
0oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`?o0000oooooom8ooooo`00
0oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool00ol0
003oooooooooo`3oooooodSooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01?oM
gMgoEEEEooooool00007ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0W?ooool2
o`000003ooooool0003o00000:Kooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo09cooooo0_l000000ooooooo0000o`00002V
ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool0
0ol0003oooooooooo`2Eooooo`;o00005?ooool2o`0009[ooooo000Nooooo`03o`000?oooooooooo
09Gooooo0_l000000ooooooo0000o`000002o`0000Kooooo0_l00007ooooo`;o0000V_ooool001ko
oooo00?o0000ooooooooool0U_ooool8o`000004ooooool0003o0000ooooo`;o0000Xoooool001ko
oooo00?o0000ooooooooool0P_ooool2o`0000gooooo0ol00002ooooo`ko0000:Oooool2o`0007So
oooo000Nooooo`03o`000?oooooooooo08;ooooo0_l0000=ooooo`Go000000Coooooo`000?l0003o
00000_ooool:o`0000?ooooo0_l0000Oooooo`;o000000?oooooo`000?l00000N?ooool001kooooo
00?o0000ooooooooool0SOooool2o`0000?ooooo1?l000001?oooooo0000o`000?l00003ooooo`;o
00000_ooool5o`0000?ooooo0_l0000Oooooo`;o0000Noooool001kooooo00?o0000ooooooooool0
R_ooool2o`000003ooooool0003o000000?ooooo2?l00003ooooo`?o000000Coooooo`000?l0003o
0000Xoooool001kooooo00?o0000ooooooooool0R_ooool2o`0000;ooooo0_l00002ooooo`Oo0000
1Oooool4o`0000Gooooo1?l00003ooooo`;o00001?ooool2o`0001Cooooo0_l0001kooooo`007_oo
ool00ol0003oooooooooo`2:ooooo`;o00000_ooool8o`000003ooooool0003o000000;ooooo0_l0
00000ooooooo0000o`000002o`000003ooooool0003o000000;ooooo1Ol00002ooooo`;o00001?oo
ool2o`0001Cooooo0_l0001kooooo`007_ooool00ol0003oooooooooo`2=ooooo`;o000000?ooooo
o`000?l000000_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000000oooool2
o`0000Cooooo1?l0002Jooooo`007_ooool00ol0003oooooooooo`2=ooooo`[o00000_ooool2o`00
00oooooo0ol0000Eooooo`;o0000Poooool001kooooo00?o0000ooooooooool0Soooool6o`0000Co
oooo0_l0000>ooooo`Ko00004oooool2o`0008?ooooo000Nooooo`;o0000S?ooool:o`0000?ooooo
0_l00003ooooo`?o00002?ooool3o`000004ooooool0003o0000o`0009Sooooo000Nooooo`03o`00
0?oooooooooo08_ooooo3?l000000ooooooo0000o`000007o`0000;ooooo1?l000000ooooooo0000
o`000002ooooo`?o0000V?ooool001kooooo00?o0000ooooooooool0Roooool9o`000003ooooool0
003o000000_o000000?oooooo`000?l000000_l000000ooooooo0000o`000002ooooo`Ko0000UOoo
ool001kooooo00?o0000ooooooooool0Roooool9o`0000?ooooo2ol00006ooooo`;o00000oooool5
o`0001Cooooo0_l0001oooooo`007_ooool00ol0003oooooooooo`2?ooooo`Go00000oooool=o`00
00Sooooo1?l0000Fooooo`?o0000O_ooool001kooooo00?o0000ooooooooool0Q_ooool5o`0000;o
oooo0_l000000ooooooo0000o`000005ooooo`go00001Oooool9o`0001Gooooo0_l0001nooooo`00
7_ooool00ol0003oooooooooo`26ooooo`Wo00001Oooool5o`000003ooooool0003o000000So0000
1Oooool4o`000003ooooool0003o000000;o00001Oooool2o`0000Cooooo0_l00005ooooo`;o0000
POooool001kooooo00?o0000ooooooooool0R?ooool5o`0000;ooooo0_l00002ooooo`Go00000_oo
ool:o`000003ooooool0003o000000Kooooo1Ol00003ooooo`Co00001?ooool2o`0000Gooooo0_l0
0021ooooo`007_ooool00ol0003oooooooooo`23ooooo`;o00000oooool2o`0000Cooooo0ol00000
0ooooooo0000o`000002o`0000Cooooo4?l00002ooooo`Ko00000_ooool6o`0008gooooo000Noooo
o`03o`000?oooooooooo08?ooooo0_l00003ooooo`;o00000_ooool5o`000003ooooool0003o0000
00Cooooo6_l00002ooooo`Ko0000SOooool001kooooo00?o0000ooooooooool0Q_ooool3o`0000?o
oooo2?l00002oooooaco00000oooool2o`00093ooooo000Nooooo`03o`000?oooooooooo08Gooooo
1?l00003ooooo`Oo00000_oooolMo`0009Gooooo000Nooooo`03o`000?oooooooooo07_ooooo0_l0
0008ooooo`?o00001OoooolUo`0000;ooooo0_l00002ooooo`;o0000SOooool001kooooo00?o0000
ooooooooool0Noooool2o`0000Sooooo0ol00007oooooako00000_ooool4o`000003ooooool0003o
000000;ooooo0_l0002=ooooo`007_ooool00ol0003oooooooooo`1jooooo`;o00002Oooool3o`00
00Oooooo3_l00002ooooo`?o000000?oooooo`000?l000002Ol00003ooooo`Co00002?ooool2o`00
08Sooooo000Nooooo`03o`000?oooooooooo07[ooooo0_l00009ooooo`?o00001Oooool2o`000003
ooooool0003o000000co000000?oooooo`000?l000002?l000000ooooooo0000o`00000:o`0000Oo
oooo0_l00028ooooo`007_ooool2o`0007Wooooo0_l0000;ooooo`;o00001?ooool6o`000003oooo
ool0003o000000[o000000?oooooo`000?l000002Ol00003ooooo`Wo000000?oooooo`000?l00000
S_ooool001kooooo00?o0000ooooooooool0N?ooool2o`0000_ooooo0_l00004oooooaco000000?o
ooooo`000?l000000_ooool6o`0000Cooooo1?l000000ooooooo0000o`00002:ooooo`007_ooool0
0ol0003oooooooooo`25ooooo`?o00000oooool2o`000003ooooool0003o000001Ko00001?ooool8
o`000003ooooool0003o000000So0000R_ooool001kooooo00?o0000ooooooooool0N?ooool2o`00
00_ooooo0ol00002ooooo`;o00000_ooool3o`000005ooooool0003o0000o`000?ooool03_l00000
0ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000003?l0002<ooooo`007_ooool00ol0
003oooooooooo`1hooooo`;o00002oooool7o`0000;ooooo0ol000000ooooooo0000o`00000@o`00
0003ooooool0003o000000?ooooo2_l00004ooooo`;o0000SOooool001kooooo00?o0000oooooooo
ool0MOooool2o`00013ooooo1?l00003ooooob?o000000Coooooo`000?l0003o0000T_ooool001ko
oooo00?o0000ooooooooool0MOooool2o`0000kooooo0_l000001?oooooo0000o`000?l00003oooo
o`Ko00000_oooolIo`0000?ooooo0ol0002Booooo`007_ooool00ol0003oooooooooo`1dooooo`;o
00003oooool2o`000004ooooool0003o0000o`0000?ooooo1ol000000ooooooo0000o`00000Eo`00
00Gooooo1Ol0002@ooooo`007_ooool00ol0003oooooooooo`1dooooo`;o00003oooool4o`0000Go
oooo2ol000000ooooooo0000o`00000?o`000003ooooool0003o000000?ooooo1_l0002@ooooo`00
7_ooool00ol0003oooooooooo`26ooooo`?o00000_ooool2o`000003ooooool0003o000000So0000
00?oooooo`000?l000004ol00003ooooo`Go0000TOooool001kooooo00?o0000ooooooooool0Qooo
ool2o`0000;ooooo3Ol000001?oooooo0000o`000?ooool6o`000003ooooool0003o000000Kooooo
0_l000000ooooooo0000o`000005o`0009;ooooo000Nooooo`03o`000?oooooooooo08Gooooo1?l0
0003ooooo`co000000?oooooo`000?l000001ol00009ooooo`;o000000?oooooo`000?l000000ol0
002Dooooo`007_ooool00ol0003oooooooooo`25ooooo`;o00000_ooool2o`0000;ooooo2Ol00000
0ooooooo0000o`000009o`0000Kooooo0_l000000ooooooo0000o`000002ooooo`Go0000Toooool0
01kooooo00?o0000ooooooooool0Qoooool4o`0000Cooooo5Ol00004ooooo`;o000000?oooooo`00
0?l000000_ooool5o`0009?ooooo000Nooooo`03o`000?oooooooooo08Kooooo0ol00005ooooo`_o
000000Coooooo`000?l0003o00001?ooool4o`0000Oooooo1ol0002Dooooo`007_ooool00ol0003o
ooooooooo`26ooooo`?o00000_ooool2o`000003ooooool0003o000000Wo00000_ooool2o`0000Co
oooo1?l00007ooooo`Ko0000UOooool001kooooo0_l00028ooooo`Ko00000_ooool>o`0000Cooooo
0ol00004ooooo`;o00000_ooool6o`0009Gooooo000Nooooo`03o`000?oooooooooo08Wooooo0_l0
0004ooooo`ko00000_ooool5o`0000?ooooo0ol00004ooooo`?o0000U_ooool001kooooo00?o0000
ooooooooool0R?ooool2o`000003ooooool0003o000000?ooooo4Ol00006ooooo`?o00001?ooool3
o`0009Kooooo000Nooooo`03o`000?oooooooooo08Sooooo0_l000000ooooooo0000o`000003oooo
o`?o000000?oooooo`000?l000003?l00002ooooo`;o000000?oooooo`000?l000000_l0002Loooo
o`007_ooool00ol0003oooooooooo`2<ooooo`;o00002?ooool9o`000003ooooool0003o000000[o
0000Voooool001kooooo00?o0000ooooooooool0S?ooool2o`000003ooooool0003o000000Wooooo
2ol000000ooooooo0000o`000004o`0009_ooooo000Nooooo`03o`000?oooooooooo08gooooo1_l0
0005ooooo`;o00000ooooolAo`000004ooooool0003o0000ooooo`Co0000TOooool001kooooo00?o
0000ooooooooool0SOooool2o`0000;ooooo0_l00004ooooo`?o00001Oooool2o`0000Cooooo2Ol0
00001?oooooo0000o`000?ooool4o`0000Cooooo0_l0002;ooooo`007_ooool00ol0003ooooooooo
o`2Gooooo`;o00001_ooool2o`0000Wooooo1?l0000<ooooo`;o0000Roooool001kooooo00?o0000
ooooooooool0UOooool2o`0000?ooooo0_l00003ooooo`;o00002Oooool4o`0009Wooooo000Noooo
o`03o`000?oooooooooo09Gooooo1?l000001?oooooo0000o`000?l00007ooooo`;o00002Oooool2
o`0000gooooo0_l00027ooooo`007_ooool00ol0003oooooooooo`2Fooooo`?o000000Coooooo`00
0?l0003o00001oooool2o`0000Wooooo0_l0000=ooooo`;o0000Qoooool001kooooo00?o0000oooo
ooooool0U_ooool2o`0000;ooooo0_l0002[ooooo`007_ooool00ol0003oooooooooo`2mooooo`;o
0000R?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko
<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0_Oooool2o`0008Sooooo0003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06
ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400;
ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool000?ooooo00Go0000
ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`2Nooooo`;o00001?ooool2o`0000Cooooo0_l0002Kooooo`000oooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo09ko
oooo0_l00004ooooo`;o00001?ooool2o`0009_ooooo0003ooooo`05oa0@4?ooooooooooooooool@
41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo0:gooooo0_l0002Hooooo`00
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003o
ooooooooo`2]ooooo`;o0000V?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04
olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0Z_ooool2o`0000Gooooo0_l0002Doooo
o`007_ooool00ol0003oooooooooo`2Zooooo`;o00001Oooool2o`0009Cooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2
o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<
c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06oooo
o`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool000?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool00ol0003ooooooooo
o`3oooooodSooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`00
0?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol@413ooooooooo
oooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj
^_l000001_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
5?ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom8ooooo`005_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB?ooool001Kooooo00?o0000
ooooooooool01Oooool3o`000?ooooooB?ooool001Kooooo00?o0000ooooooooool0oooooom@oooo
o`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?oooooo
D?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005?ooool00omEEEGoIVIVo`00003o
oooooe;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.48939 .45514 Mdot
.5161 .47728 Mdot
.4915 .58022 Mdot
.52502 .48944 Mdot
.52953 .50793 Mdot
.47518 .4228 Mdot
.53896 .52817 Mdot
.54237 .49446 Mdot
.56813 .46469 Mdot
.56026 .49973 Mdot
.52825 .4754 Mdot
.48049 .49037 Mdot
.45877 .43041 Mdot
.41653 .52845 Mdot
.53095 .46008 Mdot
.52661 .53514 Mdot
.51206 .46258 Mdot
.47778 .41693 Mdot
.5545 .46075 Mdot
.44726 .52887 Mdot
.5135 .45975 Mdot
.49103 .54866 Mdot
.537 .49402 Mdot
.42352 .46168 Mdot
.53297 .47804 Mdot
.47968 .5009 Mdot
.57055 .53964 Mdot
.52315 .42598 Mdot
.51877 .50514 Mdot
.45786 .43308 Mdot
.45433 .48519 Mdot
.52001 .47998 Mdot
.49764 .51002 Mdot
.48427 .56272 Mdot
.45663 .43045 Mdot
.46524 .54877 Mdot
.48393 .50579 Mdot
.54744 .53119 Mdot
.53203 .50211 Mdot
.47099 .49759 Mdot
.52091 .52958 Mdot
.4505 .5327 Mdot
.46709 .46891 Mdot
.49078 .49421 Mdot
.51902 .4782 Mdot
.48386 .52071 Mdot
.43794 .55147 Mdot
.45038 .50016 Mdot
.44147 .51217 Mdot
.39983 .4833 Mdot
.52607 .5088 Mdot
.45038 .50657 Mdot
.51654 .50162 Mdot
.53732 .50158 Mdot
.53909 .53396 Mdot
.46828 .51076 Mdot
.47105 .48117 Mdot
.48958 .57531 Mdot
.52963 .49425 Mdot
.46461 .48275 Mdot
.47715 .52339 Mdot
.48413 .51395 Mdot
.46414 .54941 Mdot
.52719 .53436 Mdot
.51477 .51351 Mdot
.49379 .4494 Mdot
.47415 .45976 Mdot
.47269 .51566 Mdot
.45399 .52009 Mdot
.52626 .53589 Mdot
.55571 .53401 Mdot
.53237 .49974 Mdot
.4585 .49372 Mdot
.50633 .48965 Mdot
.43922 .44407 Mdot
.55261 .54928 Mdot
.45969 .522 Mdot
.46849 .42852 Mdot
.54728 .55446 Mdot
.53641 .44248 Mdot
.51939 .54175 Mdot
.54358 .49413 Mdot
.52356 .46916 Mdot
.50572 .52601 Mdot
.47221 .55514 Mdot
.51007 .4943 Mdot
.52271 .57088 Mdot
.47507 .51269 Mdot
.4688 .49665 Mdot
.43302 .48283 Mdot
.5123 .50786 Mdot
.49375 .52876 Mdot
.52943 .56188 Mdot
.42149 .46764 Mdot
.51622 .58637 Mdot
.47587 .53376 Mdot
.47123 .51181 Mdot
.45848 .48162 Mdot
.44844 .55653 Mdot
.48053 .47419 Mdot
.52625 .56861 Mdot
.52096 .56253 Mdot
.53611 .50029 Mdot
.46879 .444 Mdot
.57671 .48175 Mdot
.49806 .51057 Mdot
.64414 .44494 Mdot
.51543 .51231 Mdot
.4812 .45767 Mdot
.49535 .53008 Mdot
.45272 .45275 Mdot
.53192 .49879 Mdot
.50124 .47795 Mdot
.5842 .4913 Mdot
.48079 .45882 Mdot
.45244 .46109 Mdot
.57692 .53082 Mdot
.51832 .42491 Mdot
.45434 .55896 Mdot
.5335 .56061 Mdot
.47934 .43308 Mdot
.48271 .49892 Mdot
.55682 .50966 Mdot
.44522 .49669 Mdot
.511 .46697 Mdot
.56775 .49816 Mdot
.44149 .45312 Mdot
.48204 .49999 Mdot
.48824 .49788 Mdot
.53591 .53068 Mdot
.49553 .42631 Mdot
.50686 .45487 Mdot
.46223 .53818 Mdot
.44844 .53393 Mdot
.55218 .49523 Mdot
.46226 .54208 Mdot
.54323 .45352 Mdot
.50018 .49892 Mdot
.45443 .50639 Mdot
.49526 .48368 Mdot
.51444 .51074 Mdot
.58816 .49889 Mdot
.49117 .50274 Mdot
.52453 .49471 Mdot
.50092 .51609 Mdot
.49449 .53022 Mdot
.48375 .44581 Mdot
.4688 .54029 Mdot
.47702 .46081 Mdot
.44081 .50002 Mdot
.45557 .54003 Mdot
.51746 .42349 Mdot
.52068 .51 Mdot
.42892 .50277 Mdot
.50743 .42854 Mdot
.52681 .53532 Mdot
.48935 .51502 Mdot
.43295 .47945 Mdot
.45915 .5221 Mdot
.5026 .51398 Mdot
.55447 .49185 Mdot
.45319 .52779 Mdot
.4643 .44287 Mdot
.54462 .53485 Mdot
.4695 .48855 Mdot
.48978 .47665 Mdot
.5785 .49396 Mdot
.49543 .52929 Mdot
.46562 .54188 Mdot
.54993 .51825 Mdot
.52235 .42716 Mdot
.44499 .49202 Mdot
.50748 .47077 Mdot
.46581 .49214 Mdot
.53464 .45624 Mdot
.47683 .50841 Mdot
.48706 .54239 Mdot
.505 .51549 Mdot
.43736 .53862 Mdot
.4409 .51684 Mdot
.52302 .4911 Mdot
.48616 .53436 Mdot
.50203 .49239 Mdot
.51812 .50201 Mdot
.45806 .43677 Mdot
.48487 .48685 Mdot
.51443 .57736 Mdot
.47696 .52362 Mdot
.45166 .45659 Mdot
.53867 .55922 Mdot
.49158 .48864 Mdot
.52629 .52859 Mdot
.42738 .46505 Mdot
.51883 .51098 Mdot
.54691 .52442 Mdot
.52106 .52868 Mdot
.38708 .49165 Mdot
.49311 .50269 Mdot
.51084 .51475 Mdot
.51977 .48487 Mdot
.49014 .47152 Mdot
.46968 .517 Mdot
.48647 .42817 Mdot
.46919 .5318 Mdot
.54077 .53042 Mdot
.50223 .46887 Mdot
.51159 .45391 Mdot
.47376 .47528 Mdot
.4964 .56878 Mdot
.52153 .51087 Mdot
.51787 .47491 Mdot
.48656 .50437 Mdot
.46229 .50691 Mdot
.49047 .43097 Mdot
.48245 .49869 Mdot
.4324 .54783 Mdot
.48764 .52594 Mdot
.45948 .52054 Mdot
.58869 .49874 Mdot
.50985 .51252 Mdot
.52322 .51841 Mdot
.47079 .5421 Mdot
.49226 .52933 Mdot
.41219 .51218 Mdot
.55517 .50386 Mdot
.55004 .49673 Mdot
.52576 .48843 Mdot
.5614 .50597 Mdot
.50613 .57466 Mdot
.55693 .47798 Mdot
.54211 .54064 Mdot
.48726 .50345 Mdot
.5868 .49802 Mdot
.49132 .51178 Mdot
.47574 .50457 Mdot
.45364 .506 Mdot
.57411 .4997 Mdot
.55044 .55251 Mdot
.50256 .45984 Mdot
.48473 .48691 Mdot
.56172 .50264 Mdot
.54411 .47389 Mdot
.46766 .4423 Mdot
.566 .50379 Mdot
.49949 .58787 Mdot
.5354 .53557 Mdot
.5584 .5394 Mdot
.54754 .49699 Mdot
.55265 .53068 Mdot
.58203 .52706 Mdot
.46832 .4707 Mdot
.45963 .44108 Mdot
.56857 .51521 Mdot
.50704 .58889 Mdot
.50195 .48098 Mdot
.48249 .48386 Mdot
.54652 .49603 Mdot
.46284 .51201 Mdot
.47898 .55879 Mdot
.58418 .51804 Mdot
.49368 .52988 Mdot
.52686 .52986 Mdot
.50215 .51393 Mdot
.4911 .42584 Mdot
.44532 .53035 Mdot
.45989 .54626 Mdot
.565 .48658 Mdot
.49372 .41627 Mdot
.51259 .52535 Mdot
.4429 .5378 Mdot
.4758 .45778 Mdot
.50073 .47778 Mdot
.45507 .45654 Mdot
.49696 .48084 Mdot
.51002 .58077 Mdot
.55986 .53496 Mdot
.46415 .51592 Mdot
.55847 .47103 Mdot
.4474 .52441 Mdot
.55816 .4824 Mdot
.45364 .5122 Mdot
.47282 .50222 Mdot
.42802 .5328 Mdot
.49645 .50627 Mdot
.57061 .5212 Mdot
.41352 .47027 Mdot
.43423 .54473 Mdot
.53613 .49932 Mdot
.50483 .46376 Mdot
.43217 .49839 Mdot
.47546 .48699 Mdot
.45559 .47329 Mdot
.45602 .45842 Mdot
.45756 .47632 Mdot
.49028 .47641 Mdot
.5403 .50171 Mdot
.51342 .4192 Mdot
.4411 .52048 Mdot
.45806 .5361 Mdot
.52624 .49044 Mdot
.49241 .49724 Mdot
.55062 .49693 Mdot
.56103 .46863 Mdot
.51491 .53507 Mdot
.47868 .48825 Mdot
.5261 .49099 Mdot
.54823 .5738 Mdot
.4623 .46258 Mdot
.53172 .4774 Mdot
.44345 .52602 Mdot
.5158 .48818 Mdot
.49634 .50711 Mdot
.56512 .49111 Mdot
.52104 .47891 Mdot
.51556 .48121 Mdot
.4802 .46294 Mdot
.47056 .49886 Mdot
.47324 .51454 Mdot
.45796 .49642 Mdot
.54151 .52815 Mdot
.44022 .50828 Mdot
.52014 .47409 Mdot
.51126 .45797 Mdot
.47358 .50849 Mdot
.53094 .43397 Mdot
.52955 .52428 Mdot
.49093 .49109 Mdot
.48736 .49754 Mdot
.5742 .4634 Mdot
.51236 .55791 Mdot
.47387 .44013 Mdot
.44632 .47026 Mdot
.50012 .47696 Mdot
.56037 .49321 Mdot
.48979 .56569 Mdot
.54839 .50958 Mdot
.45125 .53514 Mdot
.52942 .49521 Mdot
.52717 .49124 Mdot
.48132 .51303 Mdot
.46974 .46156 Mdot
.48261 .46299 Mdot
.57648 .50648 Mdot
.49306 .50435 Mdot
.49251 .54025 Mdot
.48773 .45472 Mdot
.49645 .5049 Mdot
.54166 .49884 Mdot
.49878 .53008 Mdot
.50586 .5263 Mdot
.47367 .48282 Mdot
.46014 .53431 Mdot
.51491 .46567 Mdot
.48709 .5093 Mdot
.46491 .44828 Mdot
.48263 .47894 Mdot
.41092 .52409 Mdot
.50129 .4546 Mdot
.44496 .48183 Mdot
.49937 .51214 Mdot
.51396 .51369 Mdot
.47603 .46615 Mdot
.49391 .47656 Mdot
.416 .5117 Mdot
.49607 .4538 Mdot
.42942 .54103 Mdot
.47402 .58747 Mdot
.4936 .52996 Mdot
.51261 .54911 Mdot
.50905 .49518 Mdot
.50319 .51406 Mdot
.50355 .50226 Mdot
.45858 .52804 Mdot
.55389 .49684 Mdot
.46482 .56369 Mdot
.55117 .51828 Mdot
.55806 .48816 Mdot
.53495 .56478 Mdot
.44879 .5326 Mdot
.48351 .50371 Mdot
.44365 .52705 Mdot
.52796 .5775 Mdot
.52731 .49911 Mdot
.41639 .4889 Mdot
.52672 .4902 Mdot
.48761 .42353 Mdot
.52088 .42501 Mdot
.54667 .50898 Mdot
.46913 .50748 Mdot
.44225 .52415 Mdot
.51233 .57082 Mdot
.44878 .52797 Mdot
.44055 .51092 Mdot
.52041 .48066 Mdot
.52935 .49995 Mdot
.53722 .49148 Mdot
.52606 .53819 Mdot
.49707 .50984 Mdot
.52967 .4322 Mdot
.50035 .56484 Mdot
.50846 .56319 Mdot
.44506 .52921 Mdot
.56633 .58992 Mdot
.47278 .5015 Mdot
.44113 .50794 Mdot
.45396 .53993 Mdot
.51986 .50074 Mdot
.50634 .51315 Mdot
.48384 .47075 Mdot
.5367 .44002 Mdot
.49178 .48473 Mdot
.55043 .45685 Mdot
.50621 .49119 Mdot
.4499 .49991 Mdot
.50641 .49533 Mdot
.52435 .56386 Mdot
.50191 .53279 Mdot
.43018 .4706 Mdot
.4565 .48192 Mdot
.55708 .5124 Mdot
.55579 .46747 Mdot
.48053 .51972 Mdot
.50123 .49138 Mdot
.56021 .48213 Mdot
.52816 .60454 Mdot
.45598 .53996 Mdot
.55172 .48286 Mdot
.5149 .52631 Mdot
.44939 .51326 Mdot
.46409 .50611 Mdot
.45111 .48192 Mdot
.52524 .53593 Mdot
.51032 .45211 Mdot
.55487 .45974 Mdot
.46744 .53737 Mdot
.42319 .46762 Mdot
.46788 .54144 Mdot
.46926 .48235 Mdot
.45458 .47586 Mdot
.4667 .49032 Mdot
.45447 .47782 Mdot
.43178 .51324 Mdot
.44093 .48916 Mdot
.49564 .42415 Mdot
.49863 .5113 Mdot
.49952 .42137 Mdot
.52998 .50329 Mdot
.53907 .53151 Mdot
.4847 .56382 Mdot
.51489 .50734 Mdot
.43489 .55862 Mdot
.48812 .4844 Mdot
.51499 .52891 Mdot
.46551 .49533 Mdot
.49894 .56239 Mdot
.58183 .47576 Mdot
.45282 .5371 Mdot
.54148 .53129 Mdot
.50318 .50905 Mdot
.46362 .50909 Mdot
.46688 .53386 Mdot
.50771 .48653 Mdot
.44701 .51728 Mdot
.49282 .51148 Mdot
.44178 .50019 Mdot
.43143 .52563 Mdot
.5032 .5197 Mdot
.49891 .48902 Mdot
.46022 .47013 Mdot
.46086 .51473 Mdot
.50533 .47002 Mdot
.55478 .50542 Mdot
.58057 .41271 Mdot
.47847 .40842 Mdot
.54041 .43933 Mdot
.57874 .47262 Mdot
.44504 .51906 Mdot
.46969 .40273 Mdot
.52865 .56828 Mdot
.45277 .53159 Mdot
.4956 .50656 Mdot
.51553 .46711 Mdot
.54605 .49591 Mdot
.53112 .49323 Mdot
.47909 .52009 Mdot
.46302 .5336 Mdot
.56072 .49156 Mdot
.4849 .45069 Mdot
.44167 .49807 Mdot
.53608 .56341 Mdot
.44851 .50833 Mdot
.50382 .57243 Mdot
.52858 .44474 Mdot
.50889 .51566 Mdot
.47107 .47361 Mdot
.46451 .44723 Mdot
.58641 .50959 Mdot
.5058 .51673 Mdot
.45695 .53329 Mdot
.54668 .49449 Mdot
.60937 .48918 Mdot
.56877 .50946 Mdot
.56009 .47872 Mdot
.53801 .52167 Mdot
.48568 .48536 Mdot
.55975 .48337 Mdot
.49689 .45438 Mdot
.55653 .51421 Mdot
.53603 .57261 Mdot
.40562 .47531 Mdot
.44875 .5274 Mdot
.46625 .55033 Mdot
.47162 .46931 Mdot
.47625 .42898 Mdot
.55022 .49684 Mdot
.52044 .53554 Mdot
.47059 .47058 Mdot
.45917 .42905 Mdot
.43136 .55208 Mdot
.52452 .48515 Mdot
.557 .5259 Mdot
.4767 .45705 Mdot
.53664 .48724 Mdot
.47912 .50256 Mdot
.48574 .48006 Mdot
.47037 .51137 Mdot
.4439 .52588 Mdot
.44966 .50573 Mdot
.51277 .42398 Mdot
.54425 .44339 Mdot
.47676 .55119 Mdot
.49473 .53032 Mdot
.46413 .51469 Mdot
.50678 .48552 Mdot
.468 .45007 Mdot
.48323 .4916 Mdot
.41783 .4825 Mdot
.47453 .5174 Mdot
.47096 .47806 Mdot
.55913 .47039 Mdot
.50075 .48004 Mdot
.45118 .45103 Mdot
.50198 .53276 Mdot
.41674 .47731 Mdot
.50749 .42965 Mdot
.56553 .53471 Mdot
.52459 .49857 Mdot
.4408 .46069 Mdot
.53379 .50107 Mdot
.55832 .46428 Mdot
.47022 .49541 Mdot
.54401 .49584 Mdot
.499 .51321 Mdot
.59675 .49782 Mdot
.5299 .49542 Mdot
.51878 .52317 Mdot
.50774 .50803 Mdot
.44629 .49971 Mdot
.44755 .49437 Mdot
.55815 .55054 Mdot
.51803 .56056 Mdot
.496 .56764 Mdot
.54428 .52703 Mdot
.51182 .49878 Mdot
.44996 .53619 Mdot
.54842 .49584 Mdot
.54527 .45908 Mdot
.55778 .48235 Mdot
.4161 .4854 Mdot
.44381 .51414 Mdot
.44102 .53628 Mdot
.48395 .50205 Mdot
.44887 .49185 Mdot
.53725 .50141 Mdot
.48726 .48601 Mdot
.51812 .53256 Mdot
.43876 .46673 Mdot
.47053 .49616 Mdot
.54633 .55655 Mdot
.4786 .49618 Mdot
.51906 .58272 Mdot
.53177 .50004 Mdot
.60239 .47637 Mdot
.48899 .47012 Mdot
.45462 .5263 Mdot
.4625 .55568 Mdot
.551 .49584 Mdot
.485 .45512 Mdot
.49694 .45272 Mdot
.46645 .55015 Mdot
.48389 .48616 Mdot
.49174 .5226 Mdot
.51028 .51477 Mdot
.48786 .49166 Mdot
.53966 .53084 Mdot
.47305 .44067 Mdot
.41956 .47518 Mdot
.49417 .54198 Mdot
.46641 .44104 Mdot
.51222 .47527 Mdot
.47826 .53066 Mdot
.52806 .54334 Mdot
.50513 .46999 Mdot
.47148 .44228 Mdot
.49326 .52387 Mdot
.47656 .45978 Mdot
.54154 .52557 Mdot
.45304 .57606 Mdot
.48407 .51329 Mdot
.4867 .49635 Mdot
.50179 .41478 Mdot
.47067 .44949 Mdot
.54874 .49188 Mdot
.45461 .55715 Mdot
.48276 .44788 Mdot
.52336 .50752 Mdot
.52562 .5049 Mdot
.5444 .53082 Mdot
.5145 .51356 Mdot
.53739 .4589 Mdot
.53963 .53368 Mdot
.45741 .52806 Mdot
.50618 .4806 Mdot
.48873 .51452 Mdot
.48757 .58573 Mdot
.44233 .52503 Mdot
.51775 .50915 Mdot
.50375 .50581 Mdot
.45924 .54075 Mdot
.50545 .4656 Mdot
.47549 .52066 Mdot
.53359 .5345 Mdot
.44141 .50411 Mdot
.44774 .45113 Mdot
.44602 .45599 Mdot
.53194 .49317 Mdot
.54732 .55634 Mdot
.49675 .48731 Mdot
.53324 .4987 Mdot
.43322 .54416 Mdot
.54571 .49738 Mdot
.46122 .51992 Mdot
.46214 .58597 Mdot
.51096 .52441 Mdot
.54006 .52955 Mdot
.48037 .43781 Mdot
.46934 .44442 Mdot
.49745 .51257 Mdot
.52641 .56251 Mdot
.54117 .55263 Mdot
.53834 .49062 Mdot
.49912 .51297 Mdot
.49217 .506 Mdot
.48152 .45771 Mdot
.4975 .47398 Mdot
.46501 .47164 Mdot
.49446 .45185 Mdot
.49428 .488 Mdot
.46032 .54455 Mdot
.48664 .49229 Mdot
.53404 .50083 Mdot
.50141 .51642 Mdot
.41358 .51186 Mdot
.5088 .59591 Mdot
.56655 .52453 Mdot
.45788 .5424 Mdot
.50609 .52963 Mdot
.56489 .58282 Mdot
.45957 .447 Mdot
.47886 .4412 Mdot
.51023 .47027 Mdot
.50486 .58535 Mdot
.52064 .56699 Mdot
.52939 .54799 Mdot
.53858 .52862 Mdot
.55889 .50521 Mdot
.45163 .50324 Mdot
.52068 .48106 Mdot
.51146 .41926 Mdot
.54223 .50061 Mdot
.48357 .52761 Mdot
.51766 .56009 Mdot
.49215 .46093 Mdot
.52766 .55723 Mdot
.51475 .46919 Mdot
.4684 .51842 Mdot
.51134 .46756 Mdot
.46115 .43731 Mdot
.46256 .49965 Mdot
.44635 .51747 Mdot
.46382 .52996 Mdot
.47353 .55654 Mdot
.45758 .52579 Mdot
.47308 .50596 Mdot
.44057 .51201 Mdot
.51451 .4589 Mdot
.63116 .46186 Mdot
.49176 .49823 Mdot
.49867 .53097 Mdot
.52757 .49216 Mdot
.54615 .4932 Mdot
.4822 .49262 Mdot
.43415 .52015 Mdot
.51537 .51327 Mdot
.46296 .57973 Mdot
.54785 .51752 Mdot
.47325 .5105 Mdot
.52497 .50964 Mdot
.48412 .55922 Mdot
.56004 .48065 Mdot
.53875 .43952 Mdot
.48698 .49455 Mdot
.50376 .56982 Mdot
.53465 .44447 Mdot
.42857 .49988 Mdot
.56892 .54097 Mdot
.53976 .44889 Mdot
.51063 .45308 Mdot
.47952 .42286 Mdot
.50683 .41746 Mdot
.51275 .49407 Mdot
.53817 .44096 Mdot
.44974 .51 Mdot
.51001 .48799 Mdot
.48252 .4517 Mdot
.47845 .47933 Mdot
.43893 .46886 Mdot
.48725 .43342 Mdot
.41778 .48286 Mdot
.46534 .52696 Mdot
.50853 .42942 Mdot
.51027 .52868 Mdot
.47782 .48153 Mdot
.49793 .51826 Mdot
.44967 .48317 Mdot
.54235 .5375 Mdot
.47762 .50629 Mdot
.49079 .54839 Mdot
.55405 .46223 Mdot
.46157 .51644 Mdot
.48609 .52282 Mdot
.44903 .44686 Mdot
.47234 .50435 Mdot
.54623 .49467 Mdot
.50808 .5233 Mdot
.53182 .50575 Mdot
.50921 .5155 Mdot
.47664 .51215 Mdot
.48871 .49892 Mdot
.4924 .4549 Mdot
.44351 .52475 Mdot
.50098 .50961 Mdot
.46716 .4857 Mdot
.52999 .50757 Mdot
.53753 .54277 Mdot
.41411 .49225 Mdot
.58787 .49971 Mdot
.55346 .51514 Mdot
.4567 .48049 Mdot
.55789 .47166 Mdot
.47031 .42606 Mdot
.48566 .42309 Mdot
.44923 .39475 Mdot
.4515 .53 Mdot
.43745 .47062 Mdot
.50402 .48446 Mdot
.42027 .49833 Mdot
.52346 .49893 Mdot
.48981 .49357 Mdot
.4594 .54645 Mdot
.50292 .4246 Mdot
.45777 .48265 Mdot
.45322 .43258 Mdot
.50858 .49665 Mdot
.47634 .55573 Mdot
.55147 .55401 Mdot
.50335 .44627 Mdot
.5327 .48274 Mdot
.50073 .48735 Mdot
.45963 .51337 Mdot
.53578 .52775 Mdot
.48551 .45543 Mdot
.46241 .42778 Mdot
.43947 .5238 Mdot
.51532 .59395 Mdot
.56048 .53115 Mdot
.50261 .47281 Mdot
.52808 .53056 Mdot
.5224 .42627 Mdot
.45458 .53466 Mdot
.51712 .48249 Mdot
.48668 .42484 Mdot
.5174 .49146 Mdot
.5432 .53362 Mdot
.48308 .45776 Mdot
.50217 .53468 Mdot
.47352 .46 Mdot
.60955 .48868 Mdot
.5418 .52915 Mdot
.49863 .56109 Mdot
.52625 .52989 Mdot
.47361 .47691 Mdot
.53488 .57221 Mdot
.44845 .42771 Mdot
.49328 .45768 Mdot
.53429 .53273 Mdot
.47228 .48649 Mdot
.54588 .49409 Mdot
.5186 .47148 Mdot
.47822 .41598 Mdot
.52384 .49814 Mdot
.56568 .53604 Mdot
.51892 .49476 Mdot
.49566 .44929 Mdot
.54385 .52735 Mdot
.46565 .4704 Mdot
.47234 .52573 Mdot
.47595 .47879 Mdot
.5148 .46589 Mdot
.44733 .49173 Mdot
.50125 .51751 Mdot
.50415 .48108 Mdot
.56085 .52399 Mdot
.55736 .46851 Mdot
.50985 .4649 Mdot
.53116 .43653 Mdot
.51373 .5139 Mdot
.50109 .46032 Mdot
.48504 .45832 Mdot
.47168 .50478 Mdot
.55535 .53102 Mdot
.46829 .46162 Mdot
.45524 .57268 Mdot
.47844 .51714 Mdot
.48849 .50336 Mdot
.53817 .52874 Mdot
.45053 .53503 Mdot
.53157 .43841 Mdot
.50893 .48178 Mdot
.5597 .52421 Mdot
.48532 .45116 Mdot
.48743 .52387 Mdot
.47915 .53133 Mdot
.54661 .47967 Mdot
.54616 .55254 Mdot
.494 .56048 Mdot
.47996 .44305 Mdot
.45127 .53728 Mdot
.48378 .52349 Mdot
.45751 .49574 Mdot
.50739 .46374 Mdot
.46708 .44712 Mdot
.42852 .54372 Mdot
.52747 .56952 Mdot
.52644 .44196 Mdot
.48839 .48419 Mdot
.5065 .52037 Mdot
.47892 .43203 Mdot
.50024 .48982 Mdot
.51745 .51175 Mdot
.49585 .56527 Mdot
.48824 .48386 Mdot
.49695 .5084 Mdot
.53215 .55711 Mdot
.50607 .41809 Mdot
.49924 .57058 Mdot
.50409 .47129 Mdot
.49108 .41676 Mdot
.51643 .47952 Mdot
.47642 .56945 Mdot
.49239 .41974 Mdot
.5594 .52299 Mdot
.44668 .52712 Mdot
.47179 .43974 Mdot
.50616 .45514 Mdot
.50846 .49551 Mdot
.53856 .49951 Mdot
.49426 .52737 Mdot
.47046 .49462 Mdot
.44905 .50107 Mdot
.54824 .53604 Mdot
.45804 .52765 Mdot
.47677 .4598 Mdot
.51373 .50289 Mdot
.42812 .49238 Mdot
.52836 .49197 Mdot
.46331 .50145 Mdot
.52083 .53357 Mdot
.54444 .56222 Mdot
.44614 .50856 Mdot
.46167 .53074 Mdot
.49406 .50613 Mdot
.52998 .574 Mdot
.55564 .46043 Mdot
.50455 .51728 Mdot
.46451 .44818 Mdot
.5251 .50513 Mdot
.48147 .45992 Mdot
.49713 .47865 Mdot
.50155 .47575 Mdot
.50522 .42619 Mdot
.48971 .47161 Mdot
.50529 .45056 Mdot
.51518 .47998 Mdot
.57246 .45275 Mdot
.51376 .49509 Mdot
.53957 .56364 Mdot
.45579 .5022 Mdot
.54079 .50121 Mdot
.46943 .46536 Mdot
.46974 .5508 Mdot
.48086 .52915 Mdot
.49079 .48056 Mdot
.52812 .50207 Mdot
.51611 .47305 Mdot
.47795 .49424 Mdot
.51267 .56149 Mdot
.53696 .53691 Mdot
.45083 .45133 Mdot
.55725 .54223 Mdot
.49428 .52172 Mdot
.49029 .49699 Mdot
.41182 .52701 Mdot
.49622 .55904 Mdot
.57463 .51667 Mdot
.51198 .48888 Mdot
.53802 .50261 Mdot
.47752 .4896 Mdot
.49999 .45375 Mdot
.51685 .49898 Mdot
.4993 .47239 Mdot
.45527 .53346 Mdot
.54329 .4555 Mdot
.50444 .46099 Mdot
.49807 .49011 Mdot
.38399 .49537 Mdot
.48642 .514 Mdot
.52445 .54464 Mdot
.57683 .53524 Mdot
.56128 .52159 Mdot
.43735 .47098 Mdot
.53466 .48011 Mdot
.4397 .50438 Mdot
.51312 .49096 Mdot
.4672 .51985 Mdot
.47469 .44562 Mdot
.45948 .47398 Mdot
.44767 .50132 Mdot
.45276 .48685 Mdot
.41613 .48442 Mdot
.52575 .42937 Mdot
.49601 .48223 Mdot
.45389 .44401 Mdot
.49795 .45849 Mdot
.52069 .48947 Mdot
.49525 .41649 Mdot
.52382 .56514 Mdot
.50984 .53438 Mdot
.51302 .54415 Mdot
.52166 .43793 Mdot
.49726 .54141 Mdot
.50489 .49481 Mdot
.49755 .54942 Mdot
.48875 .50506 Mdot
.50073 .51678 Mdot
.45708 .4748 Mdot
.51428 .57941 Mdot
.49419 .47128 Mdot
.5129 .5299 Mdot
.54137 .55488 Mdot
.45489 .54085 Mdot
.46722 .45377 Mdot
.44821 .4774 Mdot
.49595 .5303 Mdot
.51185 .54998 Mdot
.52196 .536 Mdot
.63339 .45063 Mdot
.50267 .49363 Mdot
.47457 .50047 Mdot
.47343 .42182 Mdot
.43253 .4958 Mdot
.50731 .51212 Mdot
.53486 .49641 Mdot
.55319 .49775 Mdot
.45241 .47623 Mdot
.45326 .55902 Mdot
.49002 .45311 Mdot
.50633 .47698 Mdot
.51192 .5346 Mdot
.55159 .50238 Mdot
.48968 .45552 Mdot
.52406 .50544 Mdot
.47307 .46002 Mdot
.55874 .48771 Mdot
.55255 .51842 Mdot
.46912 .51891 Mdot
.55009 .55672 Mdot
.51621 .58495 Mdot
.55108 .49705 Mdot
.44016 .46309 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo08kooooo0_l0002gooooo`00
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0S_ooool2o`000;Oooooo0003ooooo`05oa0@4?ooooooooooooooool@
41002oooool5o`0000Kooooo0ol0003oooooodSooooo0003ooooo`05o`000?ooooooooooooooool0
00002oooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo09Gooooo0_l0002`oooo
o`000oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool0
0ol0003oooooooooo`2Eooooo`;o0000/?ooool000?ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0Uoooool2o`000:kooooo0003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooo
oooo09Oooooo0_l0000Pooooo`;o0000S?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=
ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0Uoooool2o`0000?ooooo1Ol0000H
ooooo`;o0000S?ooool001kooooo00?o0000ooooooooool0Uoooool2o`0000?ooooo2Ol0002Roooo
o`007_ooool00ol0003oooooooooo`2Fooooo`?o00000oooool9o`000:;ooooo000Nooooo`03o`00
0?oooooooooo09Kooooo2ol00002ooooo`Co0000X?ooool001kooooo00?o0000ooooooooool0S_oo
ool2o`0000;ooooo1Ol000000ooooooo0000o`00000>o`0009oooooo000Nooooo`03o`000?oooooo
oooo08kooooo4Ol000001?oooooo0000o`000?l00003ooooo`?o0000W_ooool001kooooo00?o0000
ooooooooool0Soooool4o`0000Cooooo1_l00004ooooo`;o00001?ooool3o`0009gooooo000Noooo
o`03o`000?oooooooooo08oooooo1Ol00004ooooo`Co00002Oooool2o`000004ooooool0003o0000
o`0009cooooo000Nooooo`03o`000?oooooooooo097ooooo2Ol0000;ooooo`;o00000_ooool5o`00
09Wooooo000Nooooo`03o`000?oooooooooo08_ooooo0_l00002ooooo`_o00003Oooool8o`0009So
oooo000Nooooo`03o`000?oooooooooo08_ooooo0_l000000ooooooo0000o`00000;o`0000Gooooo
0_l00005ooooo`Go000000?oooooo`000?l000007_ooool2o`0007Sooooo000Nooooo`03o`000?oo
oooooooo08kooooo0_l000000ooooooo0000o`000005o`000004ooooool0003o0000ooooo`?o0000
00?oooooo`000?l000001_ooool5o`00023ooooo0_l0001hooooo`007_ooool2o`0008cooooo1_l0
0002ooooo`Co00000_ooool6o`000003ooooool0003o000000;o00001oooool3o`0000Sooooo0_l0
000Booooo`;o0000Noooool001kooooo00?o0000ooooooooool0Roooool7o`0000;ooooo0_l00003
ooooo`_o00001_ooool5o`0000Oooooo0_l0000Booooo`;o0000Noooool001kooooo00?o0000oooo
ooooool0SOooool5o`0000;ooooo0_l000000ooooooo0000o`00000<o`0000Gooooo1ol0002Foooo
o`007_ooool00ol0003oooooooooo`26ooooo`;o00000oooool2o`0000;ooooo5_l00004ooooo`[o
00005_ooool2o`0007cooooo000Nooooo`03o`000?oooooooooo08Kooooo0ol00002ooooo`;o0000
0_ooool2o`000003ooooool0003o000000Oo000000Coooooo`000?l0003ooooo1_l00004ooooo`;o
00001Oooool3o`0000;ooooo1?l0000@ooooo`;o0000O?ooool001kooooo00?o0000ooooooooool0
QOooool4o`0000;ooooo0_l00007ooooo`Oo00001?ooool6o`0000cooooo0ol000000ooooooo0000
o`000002o`0008kooooo000Nooooo`03o`000?oooooooooo08;ooooo0_l000001?oooooo0000o`00
0?ooool7o`0000?ooooo5_l00009ooooo`?o0000Toooool001kooooo00?o0000ooooooooool0P_oo
ool2o`0000Cooooo1?l000001?oooooo0000o`000?ooool7o`000003ooooool0003o000000ko0000
1Oooool2o`0000;ooooo0ol00004ooooo`;o0000SOooool001kooooo00?o0000ooooooooool0P?oo
ool2o`000004ooooool0003o0000o`0000Sooooo1Ol00002ooooo`Go000000?oooooo`000?l00000
2_l000001?oooooo0000o`000?l00002ooooo`;o00000_ooool2o`0000Gooooo0ol00005ooooo`;o
0000QOooool001kooooo00?o0000ooooooooool0P?ooool2o`000004ooooool0003o0000o`0000?o
oooo0_l00003ooooo`Go00000_oooolBo`000003ooooool0003o000000;o00000_ooool2o`000004
ooooool0003o0000o`0000Gooooo0_l00005ooooo`;o0000QOooool001kooooo00?o0000oooooooo
ool0O_ooool2o`0000Cooooo0_l00003ooooo`;o00000_oooolJo`0000;ooooo0ol00002ooooo`Ko
00000oooool2o`0008kooooo000Nooooo`03o`000?oooooooooo07kooooo0_l00003ooooo`?o0000
0oooool2o`0000;ooooo5_l000000ooooooo0000o`000002o`000004ooooool0003o0000o`0000?o
oooo1ol000000ooooooo0000o`00002>ooooo`007_ooool00ol0003oooooooooo`23ooooo`;o0000
1_ooool2o`0000;ooooo0ol00002oooooaGo000000?oooooo`000?l000001Oooool5o`0000cooooo
0_l00023ooooo`007_ooool00ol0003oooooooooo`1jooooo`;o00001oooool2o`0000;ooooo0_l0
0002ooooo`Go00000ooooolSo`0000Cooooo0_l00006ooooo`;o0000Poooool001kooooo00?o0000
ooooooooool0NOooool3o`0000Oooooo0_l00002ooooo`Co00000_ooool3o`000003ooooool0003o
000000[o00000_oooolGo`0000;ooooo1?l0002;ooooo`007_ooool00ol0003oooooooooo`1ioooo
o`;o00002_ooool2o`000003ooooool0003o000000Go00000_oooolQo`0000;ooooo0_l000001Ooo
oooo0000o`000?l0003ooooo00;o000000?oooooo`000?l00000Qoooool001kooooo0_l00026oooo
o`Go000000?oooooo`000?l00000:Ol000000ooooooo0000o`000002ooooo`;o000000?oooooo`00
0?l00000Qoooool001kooooo00?o0000ooooooooool0Qoooool2o`0000;ooooo1ol000000ooooooo
0000o`00000:o`000004ooooool0003o0000ooooo`_o000000?oooooo`000?l000001Ol0002Aoooo
o`007_ooool00ol0003oooooooooo`2;oooooaCo000000?oooooo`000?l000002Ol00005ooooo`Ko
000000?oooooo`000?l00000S_ooool001kooooo00?o0000ooooooooool0P_ooool3o`0000Kooooo
3_l000000ooooooo0000o`00000>o`0000Cooooo0_l000001Ooooooo0000o`000?l0003ooooo00Co
00000_ooool2o`0008[ooooo000Nooooo`03o`000?oooooooooo08;ooooo0ol00003ooooo`;o0000
00?oooooo`000?l000007?l00005ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Cooooo
0_l0002:ooooo`007_ooool00ol0003oooooooooo`22ooooo`;o00001?ooool2o`000003ooooool0
003o0000013o000000?oooooo`000?l000001Ol00009ooooo`Go00000_ooool4o`000003ooooool0
003o000008_ooooo000Nooooo`03o`000?oooooooooo08Wooooo4_l00003ooooo`Go00000oooool2
o`0000Kooooo1?l00003ooooo`Co000000?oooooo`000?l00000Roooool001kooooo00?o0000oooo
ooooool0POooool2o`0000Kooooo6_l00002ooooo`Go000000?oooooo`000?l000000_ooool5o`00
0003ooooool0003o0000093ooooo000Nooooo`03o`000?oooooooooo087ooooo0ol00004ooooo`;o
000000?oooooo`000?l000000_l000000ooooooo0000o`00000=o`000003ooooool0003o000000Go
000000Coooooo`000?l0003ooooo1Ol000000ooooooo0000o`000003o`0000?ooooo0_l0002<oooo
o`007_ooool00ol0003oooooooooo`22ooooo`?o00000oooool2o`0000;ooooo2ol000000ooooooo
0000o`00000?o`000003ooooool0003o000000Co000000Coooooo`000?l0003ooooo0_l00003oooo
o`;o0000S?ooool001kooooo00?o0000ooooooooool0Poooool2o`0000;ooooo0_l00004ooooo`Wo
000000?oooooo`000?l000000_l000000ooooooo0000o`00000Fo`0000?ooooo0_l0002>ooooo`00
7_ooool00ol0003oooooooooo`27ooooo`;o00000_ooool2o`000003ooooool0003o000000Ko0000
00?oooooo`000?l000000ol00002ooooo`?o000000?oooooo`000?l000004_l000000ooooooo0000
o`00002>ooooo`007_ooool00ol0003oooooooooo`2:ooooo`co000000Coooooo`000?l0003ooooo
0_l00003ooooo`;o000000?oooooo`000?l000003?l000000ooooooo0000o`000006o`0008kooooo
000Nooooo`03o`000?oooooooooo08Oooooo0_l000000ooooooo0000o`000002o`000003ooooool0
003o000000Ko00000oooool6o`0000Gooooo1?l000000ooooooo0000o`000002o`0000?ooooo0_l0
0002ooooo`;o0000T?ooool001kooooo00?o0000ooooooooool0Qoooool4o`0000Cooooo2?l00003
ooooo`Ko00000oooool7o`000004ooooool0003o0000o`0000?ooooo0_l00002ooooo`;o0000T?oo
ool001kooooo00?o0000ooooooooool0Qoooool4o`0000Kooooo1?l00006ooooo`?o00001Oooool2
o`000003ooooool0003o000000;o0000WOooool001kooooo0_l00029ooooo`Co00001Oooool8o`00
00;ooooo1Ol00002ooooo`?o00000oooool2o`0000Kooooo0ol0002Dooooo`007_ooool00ol0003o
ooooooooo`28ooooo`Co00001oooool6o`0000Gooooo0_l00002ooooo`?o00001oooool7o`0009Co
oooo000Nooooo`03o`000?oooooooooo08Sooooo0_l00004ooooo`Ko000000?oooooo`000?l00000
0_l00009ooooo`;o00000oooool4o`000003ooooool0003o000000?o0000U_ooool001kooooo00?o
0000ooooooooool0ROooool2o`0000?ooooo1_l000000ooooooo0000o`000004o`000003ooooool0
003o000000;o00000_ooool4o`000003ooooool0003o000000Co000000Coooooo`000?l0003o0000
U_ooool001kooooo00?o0000ooooooooool0ROooool2o`0000Cooooo0ol000000ooooooo0000o`00
0003ooooo`?o000000?oooooo`000?l000000_l000000ooooooo0000o`00000<o`0009Sooooo000N
ooooo`03o`000?oooooooooo09?ooooo0_l00004oooooaKo0000V?ooool001kooooo00?o0000oooo
ooooool0Uoooool2o`0000;ooooo1ol00003ooooo`Oo0000Voooool001kooooo00?o0000oooooooo
ool0T?ooool2o`0000Gooooo0_l00004ooooo`Oo00000_ooool6o`0009_ooooo000Nooooo`03o`00
0?oooooooooo08oooooo0ol00009ooooo`;o000000?oooooo`000?l000001?l00002ooooo`Ko0000
0_ooool2o`0009Oooooo000Nooooo`03o`000?oooooooooo08oooooo0_l0000:ooooo`;o00000ooo
ool2o`000003ooooool0003o000000?ooooo0_l00004ooooo`;o0000Uoooool001kooooo00?o0000
ooooooooool0T_ooool2o`0000Sooooo0_l00004ooooo`Go000000?oooooo`000?l00000WOooool0
01kooooo00?o0000ooooooooool0T_ooool2o`0000Kooooo1?l00002ooooo`Oo00003Oooool2o`00
097ooooo000Nooooo`03o`000?oooooooooo09;ooooo0_l00002ooooo`;o00000_ooool2o`0000;o
oooo1Ol000000ooooooo0000o`00000>ooooo`;o0000TOooool001kooooo00?o0000ooooooooool0
T_ooool2o`0000;ooooo0_l00006ooooo`;o000000Coooooo`000?l0003ooooo0_l0000>ooooo`;o
0000TOooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko
<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0Xoooool2o`0000oooooo0_l0002Aoooo
o`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B401_ooool00ol0003oooooooooo`2Qooooo`Co0000X_ooool000?ooooo00Go410@oooo
oooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`000:7ooooo0_l0
002Tooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RH
ob4Q8@06ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2Xooooo`;o
0000WOooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00So
oooo00?o0000ooooooooool0Z?ooool2o`0009gooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2
o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<
c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06oooo
o`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool000?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool00ol0003ooooooooo
o`3oooooodSooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`00
0?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol@413ooooooooo
oooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj
^_l000001_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
5?ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom8ooooo`005_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB?ooool001Kooooo00?o0000
ooooooooool01Oooool3o`000?ooooooB?ooool001Kooooo00?o0000ooooooooool0oooooom@oooo
o`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?oooooo
D?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005?ooool00omEEEGoIVIVo`00003o
oooooe;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.51748 .47115 Mdot
.52663 .492 Mdot
.46826 .56425 Mdot
.52788 .50499 Mdot
.52028 .52151 Mdot
.49105 .41569 Mdot
.52432 .57255 Mdot
.54452 .51529 Mdot
.59339 .48402 Mdot
.55403 .53259 Mdot
.545 .50621 Mdot
.49317 .48132 Mdot
.47221 .41246 Mdot
.41283 .5025 Mdot
.55638 .50158 Mdot
.50661 .54307 Mdot
.52624 .47926 Mdot
.5091 .41166 Mdot
.56596 .49284 Mdot
.44084 .50626 Mdot
.52727 .47723 Mdot
.47212 .54315 Mdot
.51899 .51481 Mdot
.43752 .44366 Mdot
.54528 .50004 Mdot
.48471 .49026 Mdot
.56161 .56467 Mdot
.54974 .44396 Mdot
.51305 .51527 Mdot
.47654 .42663 Mdot
.46825 .4574 Mdot
.53079 .49949 Mdot
.48957 .5053 Mdot
.45639 .54638 Mdot
.47143 .41743 Mdot
.44378 .52119 Mdot
.48134 .49562 Mdot
.51841 .5393 Mdot
.51653 .52126 Mdot
.48349 .48292 Mdot
.50131 .53275 Mdot
.43831 .51634 Mdot
.48462 .4558 Mdot
.49398 .49284 Mdot
.5305 .49963 Mdot
.47038 .51101 Mdot
.41285 .53396 Mdot
.46334 .46815 Mdot
.44129 .48094 Mdot
.43213 .45822 Mdot
.51268 .52411 Mdot
.44714 .45852 Mdot
.51312 .51179 Mdot
.52597 .51936 Mdot
.52062 .54921 Mdot
.46912 .49616 Mdot
.48729 .46696 Mdot
.46502 .53434 Mdot
.53508 .5134 Mdot
.48043 .46596 Mdot
.46294 .51071 Mdot
.47411 .50537 Mdot
.44091 .52801 Mdot
.50746 .54273 Mdot
.50129 .52489 Mdot
.54043 .45402 Mdot
.49571 .44762 Mdot
.46507 .50459 Mdot
.45871 .49982 Mdot
.50575 .543 Mdot
.54929 .57293 Mdot
.53058 .51489 Mdot
.47141 .47319 Mdot
.50928 .49921 Mdot
.45669 .43026 Mdot
.53603 .57697 Mdot
.4581 .50447 Mdot
.50213 .41843 Mdot
.53468 .5855 Mdot
.5597 .46182 Mdot
.48704 .53962 Mdot
.54761 .51464 Mdot
.53454 .49123 Mdot
.48702 .52157 Mdot
.44645 .53565 Mdot
.5107 .50411 Mdot
.4942 .57548 Mdot
.46944 .50259 Mdot
.4824 .48064 Mdot
.45878 .44592 Mdot
.50444 .51572 Mdot
.47592 .52115 Mdot
.50235 .57049 Mdot
.46411 .45098 Mdot
.49587 .59654 Mdot
.4617 .51705 Mdot
.46816 .5003 Mdot
.47501 .45468 Mdot
.41913 .54204 Mdot
.49704 .46645 Mdot
.4983 .57665 Mdot
.49154 .56623 Mdot
.53504 .51829 Mdot
.51215 .43118 Mdot
.59747 .50421 Mdot
.48857 .50432 Mdot
.63713 .46949 Mdot
.50371 .52186 Mdot
.50079 .45295 Mdot
.4768 .52301 Mdot
.47967 .44709 Mdot
.53118 .5141 Mdot
.5104 .48457 Mdot
.57805 .51416 Mdot
.50412 .44782 Mdot
.46377 .42437 Mdot
.56169 .54698 Mdot
.54581 .44394 Mdot
.44458 .52767 Mdot
.50791 .57056 Mdot
.51326 .42588 Mdot
.4886 .48995 Mdot
.54727 .54053 Mdot
.45324 .46692 Mdot
.52467 .48253 Mdot
.55145 .52537 Mdot
.46447 .44326 Mdot
.48704 .49049 Mdot
.49153 .4926 Mdot
.5173 .54309 Mdot
.52867 .43235 Mdot
.52267 .46595 Mdot
.43339 .49861 Mdot
.43588 .5055 Mdot
.54229 .50926 Mdot
.4314 .50572 Mdot
.54484 .49125 Mdot
.4982 .50343 Mdot
.46349 .48442 Mdot
.503 .48618 Mdot
.50432 .51966 Mdot
.59374 .52094 Mdot
.48993 .49643 Mdot
.52431 .50876 Mdot
.48944 .51519 Mdot
.47558 .52248 Mdot
.50913 .46025 Mdot
.45586 .52494 Mdot
.50123 .4474 Mdot
.44652 .47102 Mdot
.43762 .51507 Mdot
.5463 .43976 Mdot
.5112 .52103 Mdot
.44461 .47468 Mdot
.53619 .44233 Mdot
.50674 .54324 Mdot
.47693 .50727 Mdot
.42914 .44476 Mdot
.45815 .50435 Mdot
.49291 .5172 Mdot
.56128 .53889 Mdot
.45098 .50906 Mdot
.49844 .42629 Mdot
.52687 .54894 Mdot
.48429 .47374 Mdot
.50336 .47389 Mdot
.59511 .51889 Mdot
.4634 .52677 Mdot
.44862 .53356 Mdot
.5213 .53355 Mdot
.54742 .44495 Mdot
.45531 .46583 Mdot
.52124 .48096 Mdot
.47987 .47569 Mdot
.55051 .50468 Mdot
.47512 .4972 Mdot
.47026 .52756 Mdot
.49387 .52064 Mdot
.40863 .52043 Mdot
.4403 .48783 Mdot
.52498 .50553 Mdot
.46943 .51879 Mdot
.50334 .49861 Mdot
.51445 .51272 Mdot
.47152 .4126 Mdot
.49708 .4808 Mdot
.48571 .57224 Mdot
.46248 .50972 Mdot
.50034 .44683 Mdot
.51462 .5742 Mdot
.49782 .4878 Mdot
.50982 .54058 Mdot
.44545 .44793 Mdot
.50845 .52153 Mdot
.5177 .53573 Mdot
.50303 .5321 Mdot
.41483 .46605 Mdot
.49075 .49911 Mdot
.49624 .52665 Mdot
.52561 .49928 Mdot
.50589 .46886 Mdot
.46182 .50454 Mdot
.52009 .42601 Mdot
.44469 .52535 Mdot
.52324 .54929 Mdot
.51722 .47616 Mdot
.52712 .46659 Mdot
.49135 .46433 Mdot
.46694 .5546 Mdot
.51039 .52282 Mdot
.52995 .49632 Mdot
.48481 .49515 Mdot
.47267 .48804 Mdot
.51721 .42438 Mdot
.48866 .48967 Mdot
.4095 .53037 Mdot
.47139 .51641 Mdot
.46057 .50202 Mdot
.5931 .5205 Mdot
.49968 .51986 Mdot
.50446 .53463 Mdot
.44691 .49578 Mdot
.47414 .52111 Mdot
.40407 .48486 Mdot
.55875 .51956 Mdot
.54961 .51276 Mdot
.53319 .50672 Mdot
.55406 .53757 Mdot
.47772 .56464 Mdot
.57052 .50381 Mdot
.52841 .55525 Mdot
.48636 .49465 Mdot
.58042 .5189 Mdot
.48054 .50406 Mdot
.47828 .49181 Mdot
.46267 .48358 Mdot
.55781 .52305 Mdot
.53122 .57883 Mdot
.51865 .46849 Mdot
.497 .48076 Mdot
.55521 .53492 Mdot
.56312 .51789 Mdot
.49495 .44671 Mdot
.54621 .52805 Mdot
.4774 .59751 Mdot
.51595 .54747 Mdot
.547 .572 Mdot
.54584 .51434 Mdot
.5392 .55063 Mdot
.57239 .54623 Mdot
.48617 .458 Mdot
.474 .41402 Mdot
.57476 .55043 Mdot
.48621 .59803 Mdot
.50944 .48868 Mdot
.49679 .47581 Mdot
.52759 .51869 Mdot
.46881 .49396 Mdot
.45174 .54173 Mdot
.587 .54274 Mdot
.46135 .52575 Mdot
.50998 .53832 Mdot
.49247 .51685 Mdot
.52127 .42628 Mdot
.43686 .50684 Mdot
.43898 .52512 Mdot
.56829 .5084 Mdot
.52589 .42246 Mdot
.4956 .52366 Mdot
.41206 .51706 Mdot
.4953 .44933 Mdot
.51007 .48406 Mdot
.50427 .44808 Mdot
.50586 .48508 Mdot
.48348 .57332 Mdot
.55065 .57117 Mdot
.46325 .50003 Mdot
.56502 .50507 Mdot
.44506 .50172 Mdot
.55976 .51635 Mdot
.46084 .49109 Mdot
.47939 .48894 Mdot
.43076 .50319 Mdot
.49085 .50715 Mdot
.54987 .53662 Mdot
.45286 .45141 Mdot
.40825 .52789 Mdot
.51589 .52133 Mdot
.52012 .47375 Mdot
.4514 .47085 Mdot
.49059 .47468 Mdot
.47992 .45292 Mdot
.47184 .42254 Mdot
.47407 .45791 Mdot
.50376 .47403 Mdot
.53194 .5187 Mdot
.54234 .43283 Mdot
.43904 .49252 Mdot
.43848 .52166 Mdot
.52903 .50622 Mdot
.49308 .49761 Mdot
.55019 .51254 Mdot
.58988 .48971 Mdot
.49285 .53401 Mdot
.4929 .47788 Mdot
.52813 .50639 Mdot
.50493 .56483 Mdot
.49026 .45068 Mdot
.54608 .49887 Mdot
.43868 .50163 Mdot
.51941 .5011 Mdot
.49027 .50656 Mdot
.56077 .51811 Mdot
.54367 .49964 Mdot
.52361 .49397 Mdot
.50507 .44788 Mdot
.48246 .48399 Mdot
.46671 .50379 Mdot
.47033 .47599 Mdot
.51092 .53638 Mdot
.44335 .47934 Mdot
.53793 .50465 Mdot
.52846 .48739 Mdot
.47296 .49621 Mdot
.55344 .4559 Mdot
.49848 .5366 Mdot
.49605 .48965 Mdot
.49139 .49159 Mdot
.59132 .48587 Mdot
.48133 .55403 Mdot
.49921 .44921 Mdot
.45256 .43158 Mdot
.51 .48271 Mdot
.55692 .52711 Mdot
.46108 .54847 Mdot
.53544 .53695 Mdot
.4364 .50906 Mdot
.52966 .51034 Mdot
.54605 .51561 Mdot
.4731 .50408 Mdot
.49077 .44689 Mdot
.50932 .45136 Mdot
.54364 .54091 Mdot
.48994 .49864 Mdot
.46683 .54114 Mdot
.50849 .44989 Mdot
.49153 .50648 Mdot
.53922 .51737 Mdot
.46583 .5268 Mdot
.4871 .52195 Mdot
.48932 .46978 Mdot
.43424 .49271 Mdot
.52854 .48453 Mdot
.47989 .50033 Mdot
.48955 .42182 Mdot
.49736 .47136 Mdot
.40999 .50094 Mdot
.5182 .46188 Mdot
.46384 .44031 Mdot
.48885 .50622 Mdot
.49964 .52645 Mdot
.50234 .44962 Mdot
.50601 .47752 Mdot
.42461 .48663 Mdot
.51422 .4572 Mdot
.42914 .51213 Mdot
.45036 .58554 Mdot
.4626 .52821 Mdot
.46359 .54585 Mdot
.50917 .50426 Mdot
.49345 .51769 Mdot
.49929 .50771 Mdot
.43668 .48376 Mdot
.56302 .5188 Mdot
.449 .53602 Mdot
.53746 .5443 Mdot
.56904 .51144 Mdot
.50933 .57903 Mdot
.44003 .514 Mdot
.48366 .49349 Mdot
.4356 .50122 Mdot
.50933 .59618 Mdot
.52373 .51289 Mdot
.41575 .45944 Mdot
.53397 .5088 Mdot
.50298 .42905 Mdot
.54838 .44239 Mdot
.53173 .53516 Mdot
.47206 .49315 Mdot
.43701 .49775 Mdot
.47167 .54697 Mdot
.44618 .50724 Mdot
.44322 .48217 Mdot
.53116 .5004 Mdot
.51051 .52126 Mdot
.54193 .51343 Mdot
.50488 .54001 Mdot
.48956 .50717 Mdot
.5527 .45348 Mdot
.45997 .53981 Mdot
.46466 .54478 Mdot
.43535 .50131 Mdot
.52996 .58035 Mdot
.48015 .48816 Mdot
.44644 .48035 Mdot
.43823 .51027 Mdot
.51675 .51239 Mdot
.49665 .51887 Mdot
.50141 .46505 Mdot
.55836 .46085 Mdot
.50048 .48423 Mdot
.56314 .48785 Mdot
.50828 .50027 Mdot
.46186 .4682 Mdot
.50629 .5031 Mdot
.4957 .56992 Mdot
.48202 .52793 Mdot
.45048 .45164 Mdot
.4732 .46321 Mdot
.54669 .54169 Mdot
.56264 .49936 Mdot
.46836 .50965 Mdot
.50303 .49726 Mdot
.5629 .5167 Mdot
.49702 .58137 Mdot
.4382 .51295 Mdot
.57631 .5176 Mdot
.49676 .52537 Mdot
.45477 .49089 Mdot
.47412 .48796 Mdot
.47691 .46003 Mdot
.50458 .5424 Mdot
.52778 .46174 Mdot
.56475 .48943 Mdot
.44701 .5313 Mdot
.43756 .44797 Mdot
.44921 .53434 Mdot
.48521 .46723 Mdot
.48163 .45738 Mdot
.48101 .47437 Mdot
.4699 .45731 Mdot
.44655 .46655 Mdot
.4619 .46274 Mdot
.52463 .42847 Mdot
.48845 .50515 Mdot
.5313 .42864 Mdot
.52402 .51675 Mdot
.52106 .54821 Mdot
.45709 .54653 Mdot
.50755 .51609 Mdot
.42204 .53698 Mdot
.49934 .48106 Mdot
.49527 .52876 Mdot
.47917 .47802 Mdot
.46769 .55758 Mdot
.59543 .4984 Mdot
.43666 .51175 Mdot
.51003 .5372 Mdot
.49579 .51353 Mdot
.4717 .49084 Mdot
.44217 .5247 Mdot
.51223 .49723 Mdot
.45386 .48059 Mdot
.48212 .50396 Mdot
.44907 .47344 Mdot
.41021 .49696 Mdot
.48658 .51353 Mdot
.50229 .49358 Mdot
.48388 .45105 Mdot
.46666 .49594 Mdot
.52633 .49725 Mdot
.54606 .53583 Mdot
.578 .44857 Mdot
.51227 .43575 Mdot
.56021 .46401 Mdot
.59729 .49376 Mdot
.44376 .4842 Mdot
.50319 .42651 Mdot
.50139 .57818 Mdot
.42635 .49411 Mdot
.49009 .50488 Mdot
.52899 .48643 Mdot
.54759 .51458 Mdot
.53639 .51441 Mdot
.46691 .50971 Mdot
.4408 .52528 Mdot
.5591 .52512 Mdot
.51295 .46508 Mdot
.44913 .47082 Mdot
.51083 .57898 Mdot
.45562 .45826 Mdot
.47477 .56144 Mdot
.56582 .45542 Mdot
.49566 .52505 Mdot
.48929 .46179 Mdot
.48712 .41981 Mdot
.57946 .52959 Mdot
.4929 .52385 Mdot
.43867 .5227 Mdot
.55429 .51226 Mdot
.58557 .51808 Mdot
.57865 .54414 Mdot
.5419 .52766 Mdot
.5224 .54182 Mdot
.49811 .47998 Mdot
.5641 .51899 Mdot
.52318 .46524 Mdot
.54636 .54062 Mdot
.5137 .58621 Mdot
.4415 .45347 Mdot
.44672 .50658 Mdot
.44238 .52807 Mdot
.49035 .45878 Mdot
.49515 .41374 Mdot
.55312 .51285 Mdot
.49981 .53943 Mdot
.48905 .45926 Mdot
.474 .41719 Mdot
.42184 .52842 Mdot
.54582 .50635 Mdot
.5459 .54862 Mdot
.49669 .44828 Mdot
.55293 .50646 Mdot
.48236 .49129 Mdot
.49979 .47418 Mdot
.46835 .49937 Mdot
.43699 .49624 Mdot
.44919 .45714 Mdot
.54231 .43595 Mdot
.56168 .47007 Mdot
.44818 .53843 Mdot
.47569 .52258 Mdot
.46422 .49871 Mdot
.5118 .49586 Mdot
.51624 .44464 Mdot
.49365 .48411 Mdot
.415 .45374 Mdot
.46509 .50639 Mdot
.48797 .46497 Mdot
.56727 .5045 Mdot
.50886 .48684 Mdot
.48573 .42931 Mdot
.48152 .52735 Mdot
.42137 .45206 Mdot
.53909 .44081 Mdot
.55996 .56608 Mdot
.52183 .51199 Mdot
.47209 .4325 Mdot
.53176 .5168 Mdot
.56774 .49234 Mdot
.48394 .48003 Mdot
.53144 .51277 Mdot
.48931 .51075 Mdot
.56436 .5249 Mdot
.53271 .51191 Mdot
.50116 .53543 Mdot
.49997 .51446 Mdot
.45626 .47495 Mdot
.45932 .44741 Mdot
.53962 .56553 Mdot
.48821 .56132 Mdot
.46636 .55707 Mdot
.52754 .54787 Mdot
.50979 .50791 Mdot
.43669 .517 Mdot
.53017 .5187 Mdot
.54131 .51211 Mdot
.55828 .51605 Mdot
.41557 .45695 Mdot
.44373 .48063 Mdot
.41127 .51499 Mdot
.4861 .49258 Mdot
.4616 .4692 Mdot
.53432 .51877 Mdot
.49825 .48178 Mdot
.4981 .53517 Mdot
.46886 .43598 Mdot
.48398 .48096 Mdot
.52471 .57947 Mdot
.4887 .48579 Mdot
.49229 .58155 Mdot
.52887 .51471 Mdot
.58289 .51103 Mdot
.50631 .4678 Mdot
.45365 .50749 Mdot
.42443 .54847 Mdot
.54291 .51063 Mdot
.50441 .4506 Mdot
.51636 .45028 Mdot
.44201 .53053 Mdot
.49705 .47941 Mdot
.47576 .515 Mdot
.495 .52722 Mdot
.49479 .4875 Mdot
.52181 .54714 Mdot
.49895 .44889 Mdot
.43054 .45206 Mdot
.477 .52835 Mdot
.50063 .42574 Mdot
.52396 .48794 Mdot
.45153 .52611 Mdot
.50987 .54589 Mdot
.53049 .49241 Mdot
.49915 .42197 Mdot
.47659 .51658 Mdot
.49557 .45209 Mdot
.52574 .54404 Mdot
.43701 .55698 Mdot
.47462 .50474 Mdot
.49188 .49029 Mdot
.53256 .4279 Mdot
.50027 .45207 Mdot
.53183 .51292 Mdot
.42105 .54579 Mdot
.51023 .46043 Mdot
.51519 .51905 Mdot
.50917 .52398 Mdot
.5268 .54936 Mdot
.50131 .52439 Mdot
.55501 .50542 Mdot
.5255 .57597 Mdot
.44747 .47657 Mdot
.51364 .49028 Mdot
.4768 .50661 Mdot
.4622 .5942 Mdot
.43707 .49968 Mdot
.50906 .5191 Mdot
.49763 .51102 Mdot
.42971 .50434 Mdot
.52055 .47601 Mdot
.46341 .50873 Mdot
.51455 .54707 Mdot
.44487 .47345 Mdot
.48208 .42872 Mdot
.47962 .43146 Mdot
.54865 .51817 Mdot
.52637 .57876 Mdot
.50169 .49047 Mdot
.53556 .51689 Mdot
.4078 .527 Mdot
.54214 .5154 Mdot
.45979 .50295 Mdot
.43996 .57785 Mdot
.49344 .52126 Mdot
.52243 .54465 Mdot
.50882 .42378 Mdot
.49517 .42118 Mdot
.48554 .50608 Mdot
.508 .59265 Mdot
.52771 .58664 Mdot
.55406 .50957 Mdot
.48949 .51184 Mdot
.48733 .49826 Mdot
.50099 .4533 Mdot
.50993 .47668 Mdot
.48239 .45727 Mdot
.5419 .45995 Mdot
.49965 .48925 Mdot
.43822 .5273 Mdot
.49414 .487 Mdot
.53277 .51702 Mdot
.48958 .51287 Mdot
.42047 .48736 Mdot
.48135 .56408 Mdot
.52504 .54853 Mdot
.43856 .51796 Mdot
.47441 .53199 Mdot
.52619 .57596 Mdot
.488 .44638 Mdot
.52562 .46113 Mdot
.52403 .4835 Mdot
.47393 .55305 Mdot
.47636 .55159 Mdot
.51414 .55177 Mdot
.52147 .54372 Mdot
.55673 .53887 Mdot
.46121 .47965 Mdot
.53153 .50231 Mdot
.54191 .43206 Mdot
.53425 .51783 Mdot
.46673 .51387 Mdot
.48808 .56046 Mdot
.50995 .46352 Mdot
.49964 .56077 Mdot
.52794 .48799 Mdot
.46025 .50492 Mdot
.52466 .48243 Mdot
.47602 .41284 Mdot
.47527 .48037 Mdot
.44815 .49301 Mdot
.45553 .51228 Mdot
.45028 .53067 Mdot
.44622 .47522 Mdot
.47576 .49263 Mdot
.4439 .48463 Mdot
.53498 .47482 Mdot
.61755 .48861 Mdot
.49265 .49655 Mdot
.47955 .52503 Mdot
.5297 .50774 Mdot
.53137 .50921 Mdot
.49265 .48439 Mdot
.44337 .48762 Mdot
.50191 .52471 Mdot
.44643 .56067 Mdot
.54395 .5641 Mdot
.47037 .49931 Mdot
.51284 .52371 Mdot
.45522 .54524 Mdot
.56344 .51535 Mdot
.5715 .45144 Mdot
.49288 .4892 Mdot
.47398 .56473 Mdot
.55343 .4758 Mdot
.44745 .47313 Mdot
.55947 .56623 Mdot
.55478 .4827 Mdot
.52991 .46231 Mdot
.49502 .42347 Mdot
.53794 .42813 Mdot
.51356 .50502 Mdot
.55855 .4635 Mdot
.4564 .48683 Mdot
.51376 .49928 Mdot
.51123 .45742 Mdot
.49405 .46899 Mdot
.46716 .43502 Mdot
.51433 .42371 Mdot
.41488 .45402 Mdot
.45678 .51013 Mdot
.53608 .44466 Mdot
.49083 .52632 Mdot
.49326 .47078 Mdot
.48211 .51158 Mdot
.45657 .43873 Mdot
.52994 .57825 Mdot
.47769 .49416 Mdot
.47344 .53795 Mdot
.56504 .49443 Mdot
.46443 .49816 Mdot
.4713 .5133 Mdot
.46072 .41934 Mdot
.47689 .49089 Mdot
.55743 .51128 Mdot
.49308 .52833 Mdot
.52035 .52247 Mdot
.49639 .5246 Mdot
.47083 .50247 Mdot
.49118 .49347 Mdot
.51464 .47821 Mdot
.4369 .49453 Mdot
.49345 .51276 Mdot
.48215 .4694 Mdot
.51923 .52279 Mdot
.52544 .55891 Mdot
.42018 .46596 Mdot
.59371 .52187 Mdot
.54131 .54297 Mdot
.47153 .45508 Mdot
.56218 .5033 Mdot
.4872 .42661 Mdot
.50121 .42609 Mdot
.48248 .41032 Mdot
.44625 .51109 Mdot
.46585 .4368 Mdot
.50964 .49348 Mdot
.41367 .466 Mdot
.52078 .51202 Mdot
.49416 .49111 Mdot
.44181 .51643 Mdot
.52457 .43346 Mdot
.47309 .4549 Mdot
.46923 .42036 Mdot
.50781 .50507 Mdot
.45063 .53225 Mdot
.53075 .56751 Mdot
.54364 .47558 Mdot
.55006 .50283 Mdot
.50494 .49351 Mdot
.46697 .49411 Mdot
.52006 .54422 Mdot
.50628 .4494 Mdot
.4784 .4209 Mdot
.44747 .47334 Mdot
.48342 .56617 Mdot
.55265 .56866 Mdot
.51479 .47817 Mdot
.50891 .53811 Mdot
.54782 .44459 Mdot
.44332 .52236 Mdot
.52426 .49576 Mdot
.51943 .42326 Mdot
.51947 .5043 Mdot
.51287 .53942 Mdot
.50194 .45492 Mdot
.47337 .53796 Mdot
.49231 .44969 Mdot
.58321 .5152 Mdot
.5244 .54785 Mdot
.46004 .57025 Mdot
.50898 .53733 Mdot
.49076 .4653 Mdot
.51111 .58439 Mdot
.4926 .44177 Mdot
.52108 .47429 Mdot
.51564 .54526 Mdot
.48741 .47287 Mdot
.55377 .51229 Mdot
.53061 .49291 Mdot
.51316 .41682 Mdot
.52157 .51151 Mdot
.55934 .56653 Mdot
.51957 .50736 Mdot
.51397 .47445 Mdot
.52696 .54784 Mdot
.48292 .45631 Mdot
.46003 .50977 Mdot
.49237 .46733 Mdot
.53704 .48439 Mdot
.45742 .46315 Mdot
.48574 .5112 Mdot
.51142 .49 Mdot
.55539 .5638 Mdot
.5655 .5019 Mdot
.53432 .48262 Mdot
.5529 .46415 Mdot
.49987 .52582 Mdot
.517 .46772 Mdot
.50377 .4568 Mdot
.47617 .49112 Mdot
.51076 .55178 Mdot
.48874 .44636 Mdot
.44216 .54848 Mdot
.46846 .50705 Mdot
.4873 .49499 Mdot
.52111 .54369 Mdot
.43717 .51761 Mdot
.55621 .45616 Mdot
.51582 .49272 Mdot
.53412 .53714 Mdot
.51378 .46462 Mdot
.47196 .51452 Mdot
.46395 .51499 Mdot
.55574 .52943 Mdot
.53465 .58539 Mdot
.46292 .55361 Mdot
.52715 .46223 Mdot
.43635 .51932 Mdot
.46894 .51322 Mdot
.46986 .47478 Mdot
.5223 .47641 Mdot
.498 .42646 Mdot
.41085 .52311 Mdot
.48331 .55545 Mdot
.54481 .48873 Mdot
.49953 .48109 Mdot
.49138 .5155 Mdot
.50048 .41599 Mdot
.50298 .49524 Mdot
.50612 .52189 Mdot
.46552 .55743 Mdot
.49965 .48068 Mdot
.4901 .50802 Mdot
.5051 .56197 Mdot
.53648 .43001 Mdot
.47003 .5608 Mdot
.51786 .47898 Mdot
.52544 .42413 Mdot
.52587 .49339 Mdot
.45786 .52342 Mdot
.52442 .42227 Mdot
.53365 .53636 Mdot
.44899 .48987 Mdot
.49741 .44737 Mdot
.52927 .46645 Mdot
.50838 .50421 Mdot
.52561 .518 Mdot
.47667 .52001 Mdot
.48431 .47944 Mdot
.44988 .45321 Mdot
.50381 .55633 Mdot
.43592 .48372 Mdot
.5003 .44752 Mdot
.50933 .5115 Mdot
.45066 .45176 Mdot
.53516 .51259 Mdot
.47556 .48274 Mdot
.50081 .53799 Mdot
.52248 .58192 Mdot
.43099 .46689 Mdot
.45426 .5126 Mdot
.48889 .49908 Mdot
.50384 .5809 Mdot
.56533 .4894 Mdot
.49188 .52301 Mdot
.5119 .44103 Mdot
.51811 .51713 Mdot
.50035 .45628 Mdot
.50702 .48284 Mdot
.51195 .48194 Mdot
.52941 .43997 Mdot
.50548 .46871 Mdot
.52085 .45847 Mdot
.52444 .49302 Mdot
.58693 .47538 Mdot
.5141 .50609 Mdot
.51593 .58075 Mdot
.4666 .48046 Mdot
.53228 .51833 Mdot
.49469 .44842 Mdot
.44357 .5352 Mdot
.45143 .5232 Mdot
.50254 .47953 Mdot
.51115 .52237 Mdot
.52797 .49031 Mdot
.48968 .48358 Mdot
.48105 .56095 Mdot
.50248 .56882 Mdot
.47708 .44558 Mdot
.53451 .55263 Mdot
.47796 .51466 Mdot
.49257 .49424 Mdot
.40897 .50348 Mdot
.46523 .55206 Mdot
.58027 .54795 Mdot
.51525 .50061 Mdot
.52865 .51959 Mdot
.49156 .47847 Mdot
.54671 .46948 Mdot
.51521 .51011 Mdot
.51235 .4756 Mdot
.43804 .52031 Mdot
.57906 .47043 Mdot
.52025 .47161 Mdot
.50093 .49393 Mdot
.41016 .46902 Mdot
.47557 .50569 Mdot
.4784 .55612 Mdot
.56799 .55732 Mdot
.55695 .56171 Mdot
.4367 .43601 Mdot
.54713 .50159 Mdot
.44378 .47574 Mdot
.51547 .5028 Mdot
.4592 .50561 Mdot
.50287 .45265 Mdot
.47884 .45168 Mdot
.46272 .46934 Mdot
.46769 .46627 Mdot
.41921 .45714 Mdot
.5516 .44922 Mdot
.50437 .48556 Mdot
.48617 .42221 Mdot
.51478 .46353 Mdot
.52371 .50353 Mdot
.52757 .42409 Mdot
.49506 .57143 Mdot
.48939 .53259 Mdot
.46509 .55142 Mdot
.54493 .48097 Mdot
.46471 .5326 Mdot
.505 .50193 Mdot
.48078 .54173 Mdot
.48572 .49643 Mdot
.48578 .51051 Mdot
.47332 .45611 Mdot
.48639 .5739 Mdot
.50927 .47111 Mdot
.49321 .52896 Mdot
.51745 .56325 Mdot
.43708 .52024 Mdot
.4968 .45142 Mdot
.45464 .43546 Mdot
.46482 .52918 Mdot
.46308 .54526 Mdot
.50103 .54045 Mdot
.62464 .47815 Mdot
.50338 .49989 Mdot
.48209 .48798 Mdot
.50569 .41444 Mdot
.45308 .45307 Mdot
.49784 .51831 Mdot
.53732 .51684 Mdot
.55248 .51175 Mdot
.47559 .45455 Mdot
.44425 .52766 Mdot
.5179 .46143 Mdot
.5157 .48593 Mdot
.49028 .53281 Mdot
.53874 .53172 Mdot
.51773 .47177 Mdot
.50729 .52441 Mdot
.50163 .45081 Mdot
.55845 .52123 Mdot
.53952 .54354 Mdot
.46019 .50539 Mdot
.53052 .57592 Mdot
.49258 .58879 Mdot
.55485 .54599 Mdot
.47077 .43338 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go
00001_ooool3o`000?ooooooB?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04
odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol0003o
oooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`3o
ooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007
ooooo`03o`000?oooooooooo09Wooooo0_l0002/ooooo`000oooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2Eooooo`Ko00001_ooool2
o`000:Cooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06
ooooo`03o`000?oooooooooo09Gooooo1?l00003ooooo`Oo0000Y?ooool001kooooo00?o0000oooo
ooooool0T_ooool2o`000004ooooool0003o0000o`0000Cooooo1_l000000ooooooo0000o`00002R
ooooo`007_ooool00ol0003oooooooooo`2Booooo`Oo000000?oooooo`000?l000001Ol00002oooo
o`;o000000Coooooo`000?l0003o0000W_ooool001kooooo00?o0000ooooooooool0Toooool6o`00
0003ooooool0003o000000go0000W_ooool001kooooo00?o0000ooooooooool0Toooool2o`0000;o
oooo1Ol000000ooooooo0000o`00000>o`0009[ooooo000Nooooo`03o`000?oooooooooo08oooooo
0ol00005ooooo`Go00000_ooool3o`000004ooooool0003o0000ooooo`?o000000?oooooo`000?l0
00000_l0002Jooooo`007_ooool00ol0003oooooooooo`2?ooooo`?o00000_ooool3o`000003oooo
ool0003o000000;o00000oooool2o`000003ooooool0003o000000;ooooo2?l0002Iooooo`007_oo
ool00ol0003oooooooooo`2:ooooo`;o00001?ooool2o`000003ooooool0003o000000;o00002ooo
ool2o`0000;ooooo1?l00002ooooo`;o0000VOooool001kooooo00?o0000ooooooooool0R_ooool2
o`0000Cooooo0_l000001?oooooo0000o`000?l0000<ooooo`;o00001?ooool2o`000003ooooool0
003o000000;o0000V?ooool001kooooo00?o0000ooooooooool0R_ooool2o`0000Cooooo0_l00000
0ooooooo0000o`000007ooooo`;o00001?ooool2o`0000Cooooo2Ol0002Fooooo`007_ooool00ol0
003oooooooooo`27ooooo`;o000000?oooooo`000?l000001Oooool4o`0000;ooooo0ol000000ooo
oooo0000o`000004o`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l000000_l0002Foooo
o`007_ooool00ol0003oooooooooo`27ooooo`;o000000Coooooo`000?l0003ooooo0_l00002oooo
o`;o00001?ooool3o`000003ooooool0003o000000Ko000000?oooooo`000?l000001?ooool2o`00
00;ooooo0ol00007ooooo`;o0000SOooool001kooooo0_l00026ooooo`;o000000?oooooo`000?l0
00001ol00002ooooo`;o00000oooool;o`000003ooooool0003o000000Wooooo0ol00004ooooo`Co
0000SOooool001kooooo00?o0000ooooooooool0Poooool4o`000004ooooool0003o0000ooooo`;o
000000Coooooo`000?l0003o00000_ooool@o`0000Wooooo0_l00002ooooo`?o000000?oooooo`00
0?l000000_l0002?ooooo`007_ooool00ol0003oooooooooo`23ooooo`?o00000_ooool2o`0000?o
oooo1Ol00002ooooo`Wo00000_ooool8o`0000Gooooo0_l00002ooooo`?o000000?oooooo`000?l0
0000TOooool001kooooo00?o0000ooooooooool0Poooool3o`0000;ooooo0_l00003oooooa3o0000
0oooool:o`0000;ooooo0_l00003ooooo`?o0000Toooool001kooooo00?o0000ooooooooool0T?oo
ool4o`0000;ooooo0ol00002ooooo`?o000000?oooooo`000?l000002Ol00002ooooo`;o00000_oo
ool4o`0009?ooooo000Nooooo`03o`000?oooooooooo08;ooooo1?l00002ooooo`;o00000ooooolM
o`0000Kooooo1?l0002Cooooo`007_ooool00ol0003oooooooooo`21ooooo`Go00000_ooool2o`00
00?ooooo1?l000000ooooooo0000o`000002o`0000;ooooo2ol000000ooooooo0000o`000004o`00
00Cooooo0_l00002ooooo`;o00001?ooool2o`00017ooooo0_l0001jooooo`007_ooool00ol0003o
ooooooooo`21ooooo`;o00002Oooool8o`000004ooooool0003o0000ooooo`oo00000oooool2o`00
00;ooooo0_l00002ooooo`;o00001?ooool2o`00017ooooo0_l0001jooooo`007_ooool00ol0003o
ooooooooo`2<ooooo`Ko00000oooool2o`000003ooooool0003o000000oo000000Coooooo`000?l0
003ooooo0_l000000ooooooo0000o`000009ooooo`;o00002_ooool2o`0007kooooo000Nooooo`03
o`000?oooooooooo08_ooooo1_l000000ooooooo0000o`000007o`000003ooooool0003o000000_o
00001?ooool2o`000003ooooool0003o000000Wooooo0_l0000:ooooo`;o0000O_ooool001kooooo
00?o0000ooooooooool0R_ooool7o`000003ooooool0003o000000Co000000?oooooo`000?l00000
3_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000_ooooo0_l00028ooooo`00
7_ooool00ol0003oooooooooo`1oooooo`;o00001?ooool3o`0000;ooooo1?l00002ooooo`Go0000
00Coooooo`000?l0003ooooo4ol00004ooooo`;o00002_ooool3o`0008Sooooo000Nooooo`03o`00
0?oooooooooo07oooooo0_l00004ooooo`?o00000oooool7o`000004ooooool0003o0000oooooaKo
000000?oooooo`000?l000001?ooool3o`0000Kooooo0_l00007ooooo`;o0000P?ooool001kooooo
00?o0000ooooooooool0ROooool;o`000003ooooool0003o000001Go000000?oooooo`000?l00000
1?ooool3o`0000Kooooo0_l00007ooooo`;o0000P?ooool001kooooo00?o0000ooooooooool0Q_oo
ool2o`000003ooooool0003o0000027o000000?oooooo`000?l000001Oooool2o`0000Sooooo0_l0
0027ooooo`007_ooool00ol0003oooooooooo`21ooooo`;o00000oooool2o`000005ooooool0003o
0000o`000?ooool00_l00004ooooo`_o000000?oooooo`000?l000001?l000000ooooooo0000o`00
0002o`0000?ooooo0_l00004ooooo`?o00001oooool3o`0008Oooooo000Nooooo`;o0000P_ooool3
o`0000Gooooo1_l00002ooooo`go000000?oooooo`000?l000002_l00002ooooo`?o000000?ooooo
o`000?l000000ol00007ooooo`;o0000R?ooool001kooooo00?o0000ooooooooool0POooool3o`00
00Cooooo1ol00002ooooo`co000000?oooooo`000?l000005ol00007ooooo`;o0000Qoooool001ko
oooo00?o0000ooooooooool0POooool2o`0000Gooooo:_l000000ooooooo0000o`000002o`0000Oo
oooo0_l00027ooooo`007_ooool00ol0003oooooooooo`2:oooooaKo000000?oooooo`000?l00000
2?l000001Ooooooo0000o`000?l0003ooooo00?o00000_ooool2o`0000;ooooo0_l0002<ooooo`00
7_ooool00ol0003oooooooooo`22ooooo`;o00000oooool2o`000003ooooool0003o000001Co0000
00?oooooo`000?l000004?l00002ooooo`;o000000Coooooo`000?l0003o0000S?ooool001kooooo
00?o0000ooooooooool0P_ooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`0000;ooooo
2Ol000000ooooooo0000o`00000Io`0000;ooooo1Ol0002;ooooo`007_ooool00ol0003ooooooooo
o`21ooooo`?o00001_ooool4o`0000Cooooo0_l000000ooooooo0000o`000002o`0000;ooooo5Ol0
00000ooooooo0000o`000002o`0000;ooooo1Ol000000ooooooo0000o`000028ooooo`007_ooool0
0ol0003oooooooooo`21ooooo`;o00001oooool4o`000003ooooool0003o000000;o00000_ooool4
o`000003ooooool0003o0000013o00001Oooool4o`0000Cooooo0_l00002ooooo`;o0000R?ooool0
01kooooo00?o0000ooooooooool0P?ooool3o`0000Oooooo1?l000000ooooooo0000o`000004o`00
00;ooooo4?l00008ooooo`Ko00002?ooool2o`0008Sooooo000Nooooo`03o`000?oooooooooo083o
oooo0ol00002ooooo`;o00000oooool4o`000003ooooool0003o000001;o00002Oooool9o`0000?o
oooo0_l0002=ooooo`007_ooool00ol0003oooooooooo`21ooooo`;o00000_ooool2o`0000Cooooo
1Ol00002ooooo`oo00002_ooool4o`000004ooooool0003o0000o`0000Gooooo0_l0002=ooooo`00
7_ooool00ol0003oooooooooo`22ooooo`;o00002?ooool4o`0000?ooooo0_l000000ooooooo0000
o`000003ooooo`co00000_ooool9o`0009Gooooo000Nooooo`03o`000?oooooooooo08;ooooo0_l0
00000ooooooo0000o`000005ooooo`Co00000oooool2o`000003ooooool0003o000000;ooooo3Ol0
0002ooooo`?o000000?oooooo`000?l000001Ol0002Cooooo`007_ooool00ol0003oooooooooo`24
ooooo`?o00001oooool5o`000003ooooool0003o000000Ko00000_ooool:o`0000;ooooo0_l00000
0ooooooo0000o`000005o`0000Oooooo0_l0002:ooooo`007_ooool00ol0003oooooooooo`24oooo
o`?o00002?ooool8o`000003ooooool0003o000000Gooooo2_l00002ooooo`Go00002?ooool2o`00
0003ooooool0003o000008[ooooo000Nooooo`03o`000?oooooooooo08Gooooo0ol00004ooooo`;o
00000_ooool7o`0000Wooooo2Ol00002ooooo`Co000000?oooooo`000?l000000_l00002ooooo`Go
0000S?ooool001kooooo0_l00027ooooo`;o00001?ooool2o`0000;ooooo2Ol00009ooooo`Oo0000
0_ooool4o`000003ooooool0003o000000;o00000_ooool5o`0008cooooo000Nooooo`03o`000?oo
oooooooo09;ooooo2?l00008ooooo`Oo000000Coooooo`000?l0003o00002_ooool2o`0008kooooo
000Nooooo`03o`000?oooooooooo08[ooooo0_l00006ooooo`Wo00001Oooool2o`0000Kooooo1?l0
0009ooooo`;o0000T?ooool001kooooo00?o0000ooooooooool0R_ooool2o`000003ooooool0003o
000000Cooooo2_l000000ooooooo0000o`000002o`0000Gooooo0ol0000;ooooo`;o0000T?ooool0
01kooooo00?o0000ooooooooool0SOooool2o`0000Gooooo1_l000001?oooooo0000o`000?ooool4
o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`;o000000Coooooo`000?l0003o0000U?oo
ool001kooooo00?o0000ooooooooool0U?ooool:o`0000;ooooo0_l00002ooooo`;o00001Oooool4
o`000003ooooool0003o000000;o0000Toooool001kooooo00?o0000ooooooooool0TOooool2o`00
00?ooooo1Ol000000ooooooo0000o`000004o`0000Kooooo0_l000000ooooooo0000o`000003oooo
o`Co0000Toooool001kooooo00?o0000ooooooooool0TOooool2o`0000Kooooo0ol000000ooooooo
0000o`000004o`0000?ooooo1?l00004ooooo`Co0000UOooool001kooooo00?o0000ooooooooool0
VOooool3o`000003ooooool0003o000000Ko000000?oooooo`000?l000000_l00004ooooo`?o0000
U_ooool001kooooo00?o0000ooooooooool0Roooool2o`0000gooooo0_l000000ooooooo0000o`00
0006o`000003ooooool0003o000000Co0000Voooool001kooooo00?o0000ooooooooool0Roooool2
o`0000oooooo4?l0002Kooooo`007_ooool00ol0003oooooooooo`2>ooooo`;o00003?ooool3o`00
0003ooooool0003o000000[o0000Voooool001kooooo00?o0000ooooooooool0S_ooool2o`0000co
oooo0_l00004ooooo`?o00000_ooool2o`000003ooooool0003o000009_ooooo000Nooooo`03o`00
0?oooooooooo09cooooo0_l00005ooooo`;o00000_ooool2o`0009kooooo0003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03
o`000?oooooooooo09;ooooo0_l0000=ooooo`;o0000Y?ooool000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000oooo
ooooool0T_ooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l0002T
ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00
0006ooooo`?o0000Uoooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`000:Cooooo
0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Ko
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000_o
oooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000oooo
ooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@
4?nHV9P02?ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o
0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<
00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`3o
ooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooo
oooo000000Kooooo0ol0003oooooodSooooo0003ooooo`05o`000?ooooooooooooooool000002ooo
ool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000ooooooooool0oooooom8ooooo`000ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03
o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05
oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000
ooooooooool0oooooom8ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVY
oa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001Cooooo1?l000000ol@413o
ooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB?ooool001Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`3oooooodSooooo000Fooooo`03o`000?oooooooooo00Gooooo0ol0
003oooooodSooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000oooo
ooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`00
0?oooooooooo0?ooooooD?ooool001Cooooo00?oEEEEofIVI_l00000oooooomBooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.53855 .49616 Mdot
.52737 .51004 Mdot
.45122 .53516 Mdot
.52106 .51985 Mdot
.5043 .52838 Mdot
.50792 .42306 Mdot
.50522 .60309 Mdot
.53428 .53293 Mdot
.60597 .50613 Mdot
.53533 .55862 Mdot
.54881 .53667 Mdot
.50701 .47839 Mdot
.48982 .408 Mdot
.42371 .47624 Mdot
.56749 .54423 Mdot
.48504 .53875 Mdot
.53054 .50305 Mdot
.53823 .42046 Mdot
.56321 .52757 Mdot
.4484 .48214 Mdot
.531 .50237 Mdot
.45997 .5257 Mdot
.49433 .53113 Mdot
.462 .43533 Mdot
.54425 .5236 Mdot
.49395 .48276 Mdot
.54302 .57986 Mdot
.56602 .47188 Mdot
.5026 .52046 Mdot
.4997 .43432 Mdot
.48996 .44033 Mdot
.53105 .52022 Mdot
.48416 .49859 Mdot
.43772 .5186 Mdot
.49086 .41802 Mdot
.43528 .48783 Mdot
.48421 .4868 Mdot
.48437 .53658 Mdot
.49548 .53356 Mdot
.50053 .47382 Mdot
.48128 .52533 Mdot
.43977 .49587 Mdot
.50566 .45441 Mdot
.49817 .4938 Mdot
.53152 .52222 Mdot
.46543 .49742 Mdot
.40059 .511 Mdot
.48565 .44477 Mdot
.45452 .45441 Mdot
.47664 .44081 Mdot
.49508 .53132 Mdot
.45521 .41954 Mdot
.50478 .51826 Mdot
.50611 .5315 Mdot
.49725 .55183 Mdot
.47903 .48271 Mdot
.50647 .46245 Mdot
.44903 .4834 Mdot
.52989 .52944 Mdot
.50144 .45897 Mdot
.45893 .49452 Mdot
.47193 .49476 Mdot
.43038 .49953 Mdot
.48591 .53896 Mdot
.48718 .52719 Mdot
.57691 .46864 Mdot
.51725 .44886 Mdot
.46739 .49197 Mdot
.47504 .47968 Mdot
.4839 .53782 Mdot
.53473 .60024 Mdot
.51913 .52618 Mdot
.49233 .46094 Mdot
.50805 .50935 Mdot
.4818 .42878 Mdot
.51355 .59179 Mdot
.46806 .4856 Mdot
.53463 .42317 Mdot
.51699 .60383 Mdot
.57087 .48868 Mdot
.45807 .52573 Mdot
.53862 .53236 Mdot
.53433 .51684 Mdot
.47192 .50923 Mdot
.4322 .50734 Mdot
.50687 .51283 Mdot
.46722 .56575 Mdot
.4728 .49155 Mdot
.50089 .47095 Mdot
.49317 .42057 Mdot
.49462 .51801 Mdot
.46509 .50584 Mdot
.47528 .56477 Mdot
.51486 .44586 Mdot
.47635 .59324 Mdot
.45773 .4948 Mdot
.47447 .48866 Mdot
.49802 .43937 Mdot
.40202 .52055 Mdot
.51326 .46864 Mdot
.47115 .57031 Mdot
.46419 .55585 Mdot
.5236 .53159 Mdot
.55189 .43236 Mdot
.60503 .52673 Mdot
.48208 .49644 Mdot
.62098 .49626 Mdot
.49049 .52358 Mdot
.51881 .46094 Mdot
.46494 .50757 Mdot
.51134 .45425 Mdot
.5206 .52584 Mdot
.51487 .49645 Mdot
.55756 .53533 Mdot
.52505 .45011 Mdot
.48129 .40086 Mdot
.53498 .55455 Mdot
.56343 .47328 Mdot
.44724 .48904 Mdot
.48117 .56634 Mdot
.54362 .43297 Mdot
.49734 .48424 Mdot
.52674 .56254 Mdot
.4725 .44536 Mdot
.52881 .50426 Mdot
.52213 .54685 Mdot
.49497 .44553 Mdot
.49544 .48407 Mdot
.49666 .48972 Mdot
.49424 .54388 Mdot
.55484 .45107 Mdot
.53005 .48678 Mdot
.4193 .45953 Mdot
.43769 .47586 Mdot
.52014 .52187 Mdot
.41521 .46818 Mdot
.53344 .53252 Mdot
.49588 .50666 Mdot
.48259 .46714 Mdot
.50857 .49328 Mdot
.49242 .52159 Mdot
.58608 .54051 Mdot
.49114 .49124 Mdot
.51539 .52069 Mdot
.48077 .50871 Mdot
.46374 .50656 Mdot
.53047 .48568 Mdot
.45396 .50186 Mdot
.52382 .44747 Mdot
.46466 .4491 Mdot
.43343 .48635 Mdot
.56559 .46654 Mdot
.49782 .52498 Mdot
.47318 .45297 Mdot
.55627 .46746 Mdot
.48507 .53888 Mdot
.47145 .4968 Mdot
.43637 .41877 Mdot
.4687 .4853 Mdot
.48495 .5141 Mdot
.55585 .57866 Mdot
.4617 .48775 Mdot
.53212 .42488 Mdot
.50273 .55085 Mdot
.50321 .46735 Mdot
.51457 .47959 Mdot
.59854 .5417 Mdot
.44076 .51568 Mdot
.44316 .51656 Mdot
.48645 .53931 Mdot
.56236 .47283 Mdot
.47638 .44816 Mdot
.52662 .49774 Mdot
.49962 .46719 Mdot
.55235 .55344 Mdot
.48108 .48679 Mdot
.46144 .50355 Mdot
.48424 .51821 Mdot
.39363 .49892 Mdot
.45349 .46184 Mdot
.51786 .51897 Mdot
.46119 .49667 Mdot
.50245 .50539 Mdot
.50549 .51946 Mdot
.48925 .40186 Mdot
.5091 .48107 Mdot
.46006 .55306 Mdot
.45832 .49265 Mdot
.54766 .45065 Mdot
.48815 .57504 Mdot
.50366 .49096 Mdot
.49079 .54099 Mdot
.47401 .44114 Mdot
.49507 .52464 Mdot
.48344 .53686 Mdot
.48404 .52515 Mdot
.45552 .44565 Mdot
.49057 .49577 Mdot
.48254 .52905 Mdot
.52192 .5148 Mdot
.51846 .47564 Mdot
.46466 .49063 Mdot
.54872 .43762 Mdot
.43282 .51193 Mdot
.50015 .55565 Mdot
.52513 .49148 Mdot
.53318 .48876 Mdot
.51049 .46363 Mdot
.44441 .52759 Mdot
.49569 .527 Mdot
.53165 .51982 Mdot
.48729 .48747 Mdot
.49114 .47296 Mdot
.53966 .43182 Mdot
.49768 .48399 Mdot
.39965 .50815 Mdot
.46328 .50107 Mdot
.47276 .4829 Mdot
.58422 .53983 Mdot
.48919 .51989 Mdot
.48442 .54009 Mdot
.43673 .45071 Mdot
.46347 .50526 Mdot
.4095 .45967 Mdot
.54866 .53157 Mdot
.53566 .52668 Mdot
.52999 .52398 Mdot
.53472 .56145 Mdot
.45408 .54094 Mdot
.5695 .53007 Mdot
.50846 .55731 Mdot
.48915 .48754 Mdot
.55993 .53723 Mdot
.47553 .49479 Mdot
.48731 .48166 Mdot
.48189 .46607 Mdot
.52803 .54173 Mdot
.50691 .59191 Mdot
.52747 .48656 Mdot
.50911 .48093 Mdot
.53638 .56005 Mdot
.5682 .55884 Mdot
.52244 .46455 Mdot
.51449 .54571 Mdot
.45845 .5944 Mdot
.49268 .54681 Mdot
.5277 .59283 Mdot
.53143 .52888 Mdot
.5172 .55923 Mdot
.55065 .55807 Mdot
.5071 .45666 Mdot
.49245 .40067 Mdot
.56914 .578 Mdot
.46738 .59413 Mdot
.5126 .50032 Mdot
.51097 .47571 Mdot
.4998 .53604 Mdot
.48387 .47777 Mdot
.43491 .51435 Mdot
.57775 .56183 Mdot
.43889 .51336 Mdot
.49039 .53563 Mdot
.48466 .51357 Mdot
.54618 .44037 Mdot
.44263 .48175 Mdot
.4312 .49751 Mdot
.55715 .52961 Mdot
.55225 .44196 Mdot
.47964 .51327 Mdot
.39525 .49338 Mdot
.51488 .4541 Mdot
.51482 .49578 Mdot
.55102 .45288 Mdot
.5116 .49433 Mdot
.46038 .55185 Mdot
.53297 .59599 Mdot
.4729 .48416 Mdot
.55714 .53929 Mdot
.45664 .47873 Mdot
.54753 .5475 Mdot
.47887 .47262 Mdot
.49201 .47922 Mdot
.44834 .47301 Mdot
.48751 .50537 Mdot
.51728 .54411 Mdot
.50225 .44324 Mdot
.39552 .50665 Mdot
.49029 .53642 Mdot
.5274 .49234 Mdot
.48255 .45078 Mdot
.50772 .47064 Mdot
.50912 .44464 Mdot
.49264 .40049 Mdot
.49737 .45052 Mdot
.51473 .48009 Mdot
.51385 .53066 Mdot
.56277 .45777 Mdot
.45107 .46646 Mdot
.43227 .50168 Mdot
.52197 .52094 Mdot
.4951 .49872 Mdot
.53613 .52613 Mdot
.60552 .51299 Mdot
.4727 .52212 Mdot
.50836 .47476 Mdot
.52051 .52063 Mdot
.46101 .54176 Mdot
.51984 .45164 Mdot
.54699 .52219 Mdot
.44829 .477 Mdot
.51554 .51433 Mdot
.48663 .50357 Mdot
.54259 .5419 Mdot
.55329 .52196 Mdot
.52265 .50941 Mdot
.52729 .44605 Mdot
.49927 .47434 Mdot
.46978 .49173 Mdot
.49105 .46314 Mdot
.47726 .53389 Mdot
.45968 .45558 Mdot
.54405 .53505 Mdot
.5355 .52146 Mdot
.48052 .48506 Mdot
.56443 .48647 Mdot
.46785 .53754 Mdot
.50141 .4916 Mdot
.4973 .48836 Mdot
.59554 .51098 Mdot
.45468 .5366 Mdot
.52346 .47168 Mdot
.46713 .4048 Mdot
.51531 .49431 Mdot
.54032 .55537 Mdot
.44064 .51915 Mdot
.51346 .55518 Mdot
.43571 .48083 Mdot
.52015 .52307 Mdot
.55226 .53681 Mdot
.47299 .49358 Mdot
.51324 .44546 Mdot
.53212 .45232 Mdot
.50054 .56612 Mdot
.48928 .49332 Mdot
.44894 .53078 Mdot
.52561 .45795 Mdot
.48861 .50566 Mdot
.52554 .53175 Mdot
.44178 .51478 Mdot
.47191 .50957 Mdot
.50729 .46594 Mdot
.42275 .45287 Mdot
.53198 .50886 Mdot
.47872 .49114 Mdot
.51563 .41007 Mdot
.51173 .47272 Mdot
.42353 .47776 Mdot
.52828 .47962 Mdot
.49012 .41107 Mdot
.48125 .49799 Mdot
.48524 .52973 Mdot
.52668 .44635 Mdot
.51485 .48594 Mdot
.44796 .46428 Mdot
.52692 .47195 Mdot
.44342 .48057 Mdot
.43326 .57218 Mdot
.44105 .51769 Mdot
.42261 .53075 Mdot
.50535 .51214 Mdot
.48527 .51481 Mdot
.49445 .51033 Mdot
.42863 .44328 Mdot
.55826 .53747 Mdot
.44447 .49922 Mdot
.51497 .55994 Mdot
.56565 .53341 Mdot
.48242 .57915 Mdot
.44491 .49181 Mdot
.48844 .48534 Mdot
.44215 .47526 Mdot
.48964 .60143 Mdot
.51188 .52311 Mdot
.42752 .436 Mdot
.53056 .52571 Mdot
.51683 .44937 Mdot
.56588 .46991 Mdot
.50831 .55225 Mdot
.48331 .48095 Mdot
.44623 .47205 Mdot
.43762 .51055 Mdot
.45712 .48461 Mdot
.45921 .45791 Mdot
.53134 .52109 Mdot
.48801 .53536 Mdot
.53465 .53264 Mdot
.48248 .53007 Mdot
.48474 .50182 Mdot
.56446 .48371 Mdot
.4287 .50423 Mdot
.42879 .51465 Mdot
.44024 .47326 Mdot
.48877 .55748 Mdot
.4933 .47865 Mdot
.46478 .45788 Mdot
.43646 .4781 Mdot
.50759 .5203 Mdot
.48755 .51765 Mdot
.51726 .46958 Mdot
.56802 .48938 Mdot
.50783 .48891 Mdot
.56194 .52249 Mdot
.50653 .50954 Mdot
.48346 .44502 Mdot
.50313 .50997 Mdot
.46834 .56171 Mdot
.46714 .51345 Mdot
.48127 .44317 Mdot
.49709 .45456 Mdot
.52554 .56186 Mdot
.55499 .53283 Mdot
.4652 .49623 Mdot
.50272 .50414 Mdot
.55163 .54851 Mdot
.46681 .54405 Mdot
.43424 .48272 Mdot
.5865 .54992 Mdot
.47935 .51518 Mdot
.47234 .47115 Mdot
.49192 .47366 Mdot
.50881 .4489 Mdot
.48286 .53663 Mdot
.53601 .48146 Mdot
.56063 .52241 Mdot
.43845 .51709 Mdot
.46285 .43777 Mdot
.44197 .51837 Mdot
.5048 .46174 Mdot
.51317 .45026 Mdot
.5006 .46672 Mdot
.49283 .44764 Mdot
.47337 .42765 Mdot
.49215 .44576 Mdot
.54746 .44607 Mdot
.48131 .49707 Mdot
.55616 .44853 Mdot
.5099 .52534 Mdot
.49797 .55249 Mdot
.43856 .51773 Mdot
.49727 .51931 Mdot
.42206 .50869 Mdot
.50959 .48395 Mdot
.47676 .51872 Mdot
.4988 .46789 Mdot
.44308 .53982 Mdot
.59572 .52194 Mdot
.4345 .48354 Mdot
.4758 .53218 Mdot
.48914 .51302 Mdot
.48815 .47545 Mdot
.43035 .5089 Mdot
.51158 .50924 Mdot
.47269 .44933 Mdot
.47664 .49492 Mdot
.46883 .45359 Mdot
.40338 .46888 Mdot
.47366 .50238 Mdot
.50379 .50031 Mdot
.51113 .44453 Mdot
.48209 .47838 Mdot
.53765 .52623 Mdot
.52616 .55816 Mdot
.56431 .49153 Mdot
.54218 .47676 Mdot
.56771 .49594 Mdot
.60289 .51631 Mdot
.45587 .45337 Mdot
.53521 .46526 Mdot
.47436 .57374 Mdot
.41494 .45797 Mdot
.48706 .50138 Mdot
.53221 .51068 Mdot
.5361 .53048 Mdot
.53082 .53222 Mdot
.46407 .49601 Mdot
.43155 .51031 Mdot
.54403 .55354 Mdot
.53567 .48952 Mdot
.46883 .45091 Mdot
.48402 .58044 Mdot
.47285 .41796 Mdot
.45118 .53692 Mdot
.59141 .4737 Mdot
.48348 .52525 Mdot
.50968 .46069 Mdot
.51162 .40689 Mdot
.5589 .54518 Mdot
.48186 .52222 Mdot
.43368 .50628 Mdot
.54811 .52819 Mdot
.54797 .54471 Mdot
.57623 .57235 Mdot
.51259 .56973 Mdot
.50088 .55089 Mdot
.50998 .48118 Mdot
.55452 .55134 Mdot
.54093 .48595 Mdot
.52538 .55808 Mdot
.48945 .58607 Mdot
.4886 .44091 Mdot
.45823 .48404 Mdot
.43106 .49859 Mdot
.51086 .45957 Mdot
.51424 .41304 Mdot
.54229 .52682 Mdot
.47934 .53138 Mdot
.5097 .45912 Mdot
.49313 .41915 Mdot
.42612 .49921 Mdot
.55401 .52719 Mdot
.52482 .56086 Mdot
.51636 .45287 Mdot
.5552 .52549 Mdot
.49065 .48282 Mdot
.51267 .47669 Mdot
.47565 .48752 Mdot
.44448 .46763 Mdot
.45981 .41805 Mdot
.56309 .45905 Mdot
.56629 .5033 Mdot
.43074 .51621 Mdot
.46369 .50663 Mdot
.47459 .48313 Mdot
.51177 .50793 Mdot
.55908 .45203 Mdot
.5051 .48181 Mdot
.42406 .43155 Mdot
.46552 .49323 Mdot
.50764 .46198 Mdot
.56089 .53892 Mdot
.51283 .49816 Mdot
.52276 .42194 Mdot
.46623 .51242 Mdot
.43793 .43418 Mdot
.56184 .46313 Mdot
.54497 .58736 Mdot
.51136 .52206 Mdot
.50898 .41773 Mdot
.51994 .52811 Mdot
.56294 .52305 Mdot
.502 .47117 Mdot
.50891 .52659 Mdot
.48242 .50433 Mdot
.51821 .54726 Mdot
.52527 .52564 Mdot
.48323 .53658 Mdot
.49161 .51555 Mdot
.47747 .45728 Mdot
.47975 .41197 Mdot
.51374 .56842 Mdot
.46119 .5482 Mdot
.44359 .53365 Mdot
.5042 .5568 Mdot
.50376 .51455 Mdot
.43717 .4936 Mdot
.50254 .53641 Mdot
.52541 .56276 Mdot
.545 .54698 Mdot
.42723 .43477 Mdot
.45686 .45201 Mdot
.39558 .49117 Mdot
.49201 .4855 Mdot
.48408 .4549 Mdot
.52119 .53123 Mdot
.50866 .48354 Mdot
.4786 .52667 Mdot
.50527 .41816 Mdot
.50178 .47197 Mdot
.49892 .5886 Mdot
.50157 .48004 Mdot
.4672 .56638 Mdot
.51663 .52549 Mdot
.54932 .54466 Mdot
.52034 .47512 Mdot
.46509 .48649 Mdot
.39801 .53288 Mdot
.5225 .5236 Mdot
.52128 .45906 Mdot
.52999 .46024 Mdot
.42991 .50334 Mdot
.51003 .47942 Mdot
.46694 .50191 Mdot
.481 .53007 Mdot
.50238 .48744 Mdot
.4986 .55127 Mdot
.52384 .47052 Mdot
.45324 .43726 Mdot
.46626 .50506 Mdot
.53392 .42567 Mdot
.52649 .50513 Mdot
.43661 .51393 Mdot
.48936 .53583 Mdot
.54536 .51803 Mdot
.52624 .41679 Mdot
.46679 .50322 Mdot
.5146 .45718 Mdot
.50335 .5512 Mdot
.43098 .52771 Mdot
.47291 .49438 Mdot
.49876 .48739 Mdot
.55633 .45358 Mdot
.52845 .46756 Mdot
.50491 .53082 Mdot
.39935 .52676 Mdot
.53333 .4839 Mdot
.50178 .52443 Mdot
.48959 .5348 Mdot
.50285 .55563 Mdot
.48745 .52631 Mdot
.55851 .55204 Mdot
.50689 .6044 Mdot
.45032 .43123 Mdot
.51538 .5035 Mdot
.47186 .49622 Mdot
.44159 .59077 Mdot
.44636 .4746 Mdot
.49706 .52253 Mdot
.49158 .51216 Mdot
.41503 .46711 Mdot
.52744 .49451 Mdot
.4615 .49393 Mdot
.49203 .54707 Mdot
.46109 .44937 Mdot
.51974 .42055 Mdot
.51724 .42086 Mdot
.5523 .53936 Mdot
.50098 .58749 Mdot
.50492 .4968 Mdot
.52733 .53085 Mdot
.39571 .50559 Mdot
.52665 .53007 Mdot
.46959 .48508 Mdot
.42549 .55903 Mdot
.47756 .51031 Mdot
.49909 .54812 Mdot
.53471 .42437 Mdot
.52125 .41286 Mdot
.47766 .4973 Mdot
.4887 .60917 Mdot
.51008 .60739 Mdot
.55589 .52744 Mdot
.48262 .50635 Mdot
.48588 .49103 Mdot
.51884 .46152 Mdot
.51777 .48715 Mdot
.50402 .4543 Mdot
.57849 .47723 Mdot
.504 .49402 Mdot
.4291 .50329 Mdot
.50253 .48597 Mdot
.52151 .52878 Mdot
.48049 .50457 Mdot
.4419 .46527 Mdot
.45799 .51849 Mdot
.47744 .56028 Mdot
.43279 .48896 Mdot
.44966 .52414 Mdot
.48292 .5553 Mdot
.51867 .45894 Mdot
.56346 .49141 Mdot
.52854 .50258 Mdot
.44894 .50746 Mdot
.43762 .52283 Mdot
.49574 .54231 Mdot
.49884 .54731 Mdot
.54256 .56481 Mdot
.48116 .46207 Mdot
.53185 .5239 Mdot
.56399 .45625 Mdot
.51604 .53045 Mdot
.45913 .4954 Mdot
.46134 .54696 Mdot
.52339 .47647 Mdot
.47213 .55014 Mdot
.53107 .51126 Mdot
.46314 .48988 Mdot
.52845 .50349 Mdot
.49459 .40215 Mdot
.49534 .46749 Mdot
.46343 .47053 Mdot
.45899 .49086 Mdot
.43868 .49646 Mdot
.44767 .43105 Mdot
.48581 .48162 Mdot
.46063 .46118 Mdot
.5443 .49861 Mdot
.5928 .51674 Mdot
.49502 .49596 Mdot
.46625 .50999 Mdot
.52194 .52178 Mdot
.50645 .52329 Mdot
.50449 .48128 Mdot
.46616 .45827 Mdot
.4876 .52716 Mdot
.43902 .53028 Mdot
.53186 .59903 Mdot
.47634 .48828 Mdot
.49643 .52984 Mdot
.43582 .52009 Mdot
.55282 .54765 Mdot
.59284 .47082 Mdot
.50013 .48738 Mdot
.44962 .54609 Mdot
.5589 .51365 Mdot
.47888 .45322 Mdot
.54062 .58135 Mdot
.5562 .52157 Mdot
.53965 .4814 Mdot
.51083 .43912 Mdot
.56147 .45082 Mdot
.50901 .51467 Mdot
.56669 .49348 Mdot
.47473 .46745 Mdot
.51185 .51129 Mdot
.53535 .47456 Mdot
.51038 .46804 Mdot
.5019 .41406 Mdot
.53774 .42821 Mdot
.42389 .43172 Mdot
.4598 .4902 Mdot
.55477 .4711 Mdot
.47387 .51455 Mdot
.50973 .46906 Mdot
.47145 .50063 Mdot
.47184 .40611 Mdot
.51257 .60562 Mdot
.48448 .48387 Mdot
.46289 .51635 Mdot
.56174 .52903 Mdot
.4775 .48045 Mdot
.46477 .49906 Mdot
.47854 .4046 Mdot
.48839 .48033 Mdot
.55467 .52638 Mdot
.4799 .52358 Mdot
.50219 .53214 Mdot
.48439 .52466 Mdot
.47369 .49185 Mdot
.49563 .49014 Mdot
.53071 .50886 Mdot
.4446 .46572 Mdot
.48739 .51122 Mdot
.50186 .46229 Mdot
.50214 .53078 Mdot
.50785 .56205 Mdot
.4394 .44531 Mdot
.58631 .54141 Mdot
.51954 .561 Mdot
.49347 .441 Mdot
.55206 .53556 Mdot
.50617 .44179 Mdot
.51569 .44425 Mdot
.51812 .43981 Mdot
.4543 .48917 Mdot
.50108 .41564 Mdot
.51092 .50491 Mdot
.41996 .43879 Mdot
.51074 .52169 Mdot
.49941 .49154 Mdot
.43759 .48208 Mdot
.53964 .45529 Mdot
.49523 .43862 Mdot
.49037 .42166 Mdot
.50358 .51194 Mdot
.43635 .50014 Mdot
.50424 .56799 Mdot
.57153 .51207 Mdot
.55332 .52379 Mdot
.50638 .50195 Mdot
.48382 .47664 Mdot
.49923 .54899 Mdot
.52403 .45643 Mdot
.49812 .4282 Mdot
.46805 .42967 Mdot
.45515 .52453 Mdot
.53599 .59514 Mdot
.52073 .49088 Mdot
.48733 .5345 Mdot
.5631 .47298 Mdot
.44498 .504 Mdot
.52218 .51117 Mdot
.54752 .43551 Mdot
.5142 .51634 Mdot
.47909 .53404 Mdot
.51892 .46435 Mdot
.45137 .53009 Mdot
.51209 .45247 Mdot
.54288 .53992 Mdot
.50103 .5544 Mdot
.42829 .56681 Mdot
.48924 .53376 Mdot
.50966 .46376 Mdot
.48582 .58269 Mdot
.53764 .46955 Mdot
.5405 .49942 Mdot
.49312 .54564 Mdot
.50559 .46784 Mdot
.5479 .52862 Mdot
.53212 .51741 Mdot
.54499 .4317 Mdot
.51165 .52168 Mdot
.54365 .58683 Mdot
.513 .5181 Mdot
.52631 .50805 Mdot
.50358 .55637 Mdot
.50425 .45381 Mdot
.4586 .4907 Mdot
.51004 .46556 Mdot
.54773 .50819 Mdot
.47766 .44366 Mdot
.4742 .50076 Mdot
.51371 .50249 Mdot
.54048 .59312 Mdot
.5591 .53621 Mdot
.54769 .50619 Mdot
.56238 .4996 Mdot
.48584 .52838 Mdot
.52621 .48467 Mdot
.52009 .46709 Mdot
.48788 .48028 Mdot
.46386 .55913 Mdot
.51123 .44431 Mdot
.43966 .51382 Mdot
.46756 .49449 Mdot
.48947 .48822 Mdot
.49861 .54711 Mdot
.43748 .49579 Mdot
.56928 .48228 Mdot
.51628 .50649 Mdot
.49977 .54078 Mdot
.53667 .48819 Mdot
.46456 .49998 Mdot
.45855 .49367 Mdot
.55201 .57304 Mdot
.51804 .60552 Mdot
.43945 .5342 Mdot
.56516 .49149 Mdot
.43509 .49658 Mdot
.46287 .49835 Mdot
.49063 .46174 Mdot
.52841 .49708 Mdot
.52856 .42092 Mdot
.40693 .49856 Mdot
.44306 .52774 Mdot
.55026 .53963 Mdot
.50963 .48421 Mdot
.47845 .50493 Mdot
.52123 .41476 Mdot
.50362 .50231 Mdot
.49254 .52433 Mdot
.44216 .53679 Mdot
.50998 .48384 Mdot
.48577 .50466 Mdot
.47734 .55282 Mdot
.55928 .45398 Mdot
.44696 .53786 Mdot
.52437 .49381 Mdot
.55389 .4449 Mdot
.52565 .51016 Mdot
.45001 .47001 Mdot
.55087 .43822 Mdot
.49916 .54056 Mdot
.4646 .45543 Mdot
.52251 .46846 Mdot
.54264 .48711 Mdot
.5046 .51169 Mdot
.50414 .53128 Mdot
.46587 .50536 Mdot
.50237 .47098 Mdot
.46141 .41555 Mdot
.45888 .56271 Mdot
.42769 .44358 Mdot
.52245 .44877 Mdot
.50122 .51631 Mdot
.48366 .42164 Mdot
.53127 .53036 Mdot
.4951 .46964 Mdot
.48064 .53079 Mdot
.49689 .58787 Mdot
.42891 .43163 Mdot
.45886 .49067 Mdot
.48656 .49227 Mdot
.47746 .57362 Mdot
.56101 .52163 Mdot
.48135 .52031 Mdot
.55519 .44721 Mdot
.50486 .5238 Mdot
.5178 .4647 Mdot
.51336 .4928 Mdot
.5171 .49426 Mdot
.54589 .46589 Mdot
.51821 .47529 Mdot
.52896 .4773 Mdot
.52439 .50903 Mdot
.58885 .50227 Mdot
.50895 .51543 Mdot
.48982 .58395 Mdot
.48666 .46472 Mdot
.51395 .53055 Mdot
.52022 .44477 Mdot
.42918 .51113 Mdot
.43402 .51037 Mdot
.51222 .48526 Mdot
.49035 .5351 Mdot
.52978 .51138 Mdot
.50381 .47829 Mdot
.45366 .54672 Mdot
.46796 .58644 Mdot
.50873 .45266 Mdot
.50424 .55116 Mdot
.46812 .50223 Mdot
.49636 .49335 Mdot
.42045 .47948 Mdot
.4416 .53239 Mdot
.57403 .57238 Mdot
.5124 .51267 Mdot
.51024 .53103 Mdot
.50731 .47441 Mdot
.58111 .49296 Mdot
.50791 .51822 Mdot
.51997 .48696 Mdot
.43429 .50201 Mdot
.60218 .49058 Mdot
.52811 .49115 Mdot
.50236 .49977 Mdot
.44929 .44718 Mdot
.47215 .49522 Mdot
.43728 .55409 Mdot
.54841 .57065 Mdot
.54288 .59163 Mdot
.44577 .41103 Mdot
.546 .52421 Mdot
.46087 .45319 Mdot
.51172 .51421 Mdot
.46245 .48964 Mdot
.52892 .47235 Mdot
.50337 .44165 Mdot
.48733 .44576 Mdot
.49101 .4549 Mdot
.4346 .43645 Mdot
.5666 .47852 Mdot
.51009 .49372 Mdot
.52062 .41499 Mdot
.52576 .47884 Mdot
.51796 .51722 Mdot
.55377 .44487 Mdot
.46769 .56343 Mdot
.47179 .52028 Mdot
.42458 .54603 Mdot
.55548 .5299 Mdot
.4409 .51415 Mdot
.50244 .50853 Mdot
.46891 .52204 Mdot
.48663 .4889 Mdot
.47479 .50036 Mdot
.49639 .44869 Mdot
.46141 .55428 Mdot
.52004 .47995 Mdot
.47531 .51813 Mdot
.49007 .55804 Mdot
.43282 .49457 Mdot
.52603 .46202 Mdot
.46944 .40539 Mdot
.44264 .51899 Mdot
.42248 .52885 Mdot
.47996 .53282 Mdot
.60564 .5077 Mdot
.50189 .50629 Mdot
.49471 .47937 Mdot
.53625 .42147 Mdot
.48378 .42077 Mdot
.48858 .51776 Mdot
.52889 .53317 Mdot
.53803 .52401 Mdot
.50506 .44455 Mdot
.44769 .48898 Mdot
.53906 .48029 Mdot
.51861 .49983 Mdot
.47125 .52045 Mdot
.51576 .55317 Mdot
.53865 .49693 Mdot
.488 .53485 Mdot
.5284 .4547 Mdot
.54458 .5506 Mdot
.51724 .5586 Mdot
.4623 .49018 Mdot
.50576 .58171 Mdot
.4704 .57895 Mdot
.54738 .58578 Mdot
.50725 .41693 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go
00001_ooool3o`0009Sooooo0_l00002ooooo`;o0000ZOooool000?ooooo00Go0000oooooooooooo
ooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0V?ooool2o`00
0003ooooool0003o000000;o0000Z?ooool000?ooooo00Go0000ooooooooooooooooo`00000;oooo
o`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0U?ooool5o`0000;ooooo1?l00003
ooooo`;o0000Xoooool000?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co
000000Oooooo00?o0000ooooooooool0U?ooool5o`0000;ooooo0_l00005ooooo`Co0000XOooool0
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000
ooooooooool0SOooool2o`0000Wooooo0_l000000ooooooo0000o`000006ooooo`Co0000X?ooool0
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000
ooooooooool0SOooool2o`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l000000_ooool2
o`0000;ooooo1?l0002Pooooo`007_ooool00ol0003oooooooooo`2:ooooo`;o00001?ooool4o`00
00;ooooo0_l00003ooooo`?o000000?oooooo`000?l000000_l00002ooooo`Co0000W_ooool001ko
oooo00?o0000ooooooooool0R_ooool2o`0000Cooooo0ol00003ooooo`;o000000?oooooo`000?l0
00000ol00002ooooo`?o000000?oooooo`000?l000001ol0002Jooooo`007_ooool00ol0003ooooo
ooooo`2Iooooo`Go00000oooool2o`000003ooooool0003o000000Oo0000V_ooool001kooooo00?o
0000ooooooooool0U_ooool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`00
0006ooooo`Co0000V_ooool001kooooo00?o0000ooooooooool0Q_ooool3o`0000Cooooo0ol00004
ooooo`Co000000?oooooo`000?l000000oooool2o`0000_ooooo1?l0002Hooooo`007_ooool00ol0
003oooooooooo`26ooooo`?o000000Coooooo`000?l0003ooooo0ol00004ooooo`;o00002?ooool2
o`0000_ooooo1_l0002Fooooo`007_ooool00ol0003oooooooooo`27ooooo`Go00000oooool2o`00
0003ooooool0003o000000[ooooo0_l0000=ooooo`Co0000U_ooool001kooooo00?o0000oooooooo
ool0Q?ooool2o`000003ooooool0003o000000;o00001?ooool2o`000003ooooool0003o000000;o
oooo0ol00002ooooo`Go00000_ooool4o`0000Oooooo1?l0002Fooooo`007_ooool00ol0003ooooo
ooooo`24ooooo`;o000000?oooooo`000?l000003Oooool4o`000003ooooool0003o000000Wo0000
1oooool4o`0009Kooooo000Nooooo`03o`000?oooooooooo08Oooooo0_l00002ooooo`;o000000?o
ooooo`000?l000000_l00003oooooaCo00001Oooool4o`0009Gooooo000Nooooo`03o`000?oooooo
oooo08_ooooo0_l000000ooooooo0000o`00000?o`000003ooooool0003o000000Oo00001Oooool5
o`0009Cooooo000Nooooo`;o0000Q_ooool2o`0000?ooooo0_l00004ooooo`_o000000?oooooo`00
0?l000000_l000000ooooooo0000o`000008o`0000?ooooo1_l0002Cooooo`007_ooool00ol0003o
ooooooooo`25ooooo`;o00000oooool2o`0000Cooooo2ol000000ooooooo0000o`00000?o`000003
ooooool0003o000000Go0000T_ooool001kooooo00?o0000ooooooooool0POooool5o`0000[ooooo
1_l000000ooooooo0000o`000002o`000003ooooool0003o000000co000000?oooooo`000?l00000
1?ooool4o`0009;ooooo000Nooooo`03o`000?oooooooooo087ooooo1Ol00009ooooo`Ko00000_oo
ool3o`000005ooooool0003o0000o`000?ooool02ol00009ooooo`;o0000T_ooool001kooooo00?o
0000ooooooooool0S?ooool5o`000003ooooool0003o000000Cooooo1_l000000ooooooo0000o`00
000;o`0000Oooooo0_l0002Booooo`007_ooool00ol0003oooooooooo`1oooooo`;o00000_ooool2
o`0000Oooooo1Ol00005ooooo`;o000000?oooooo`000?l000004Ol000000ooooooo0000o`000002
ooooo`Go000000?oooooo`000?l00000S_ooool001kooooo00?o0000ooooooooool0Ooooool2o`00
00;ooooo0_l00007ooooo`Go00000_ooool5o`000003ooooool0003o000000;ooooo3Ol000000ooo
oooo0000o`000002o`000005ooooool0003o0000o`000?ooool00_l000000ooooooo0000o`000004
ooooo`;o0000R?ooool001kooooo00?o0000ooooooooool0Roooool5o`0000?ooooo1?l000000ooo
oooo0000o`000002oooooa7o00000oooool2o`000004ooooool0003o0000o`0000Kooooo0ol00028
ooooo`007_ooool00ol0003oooooooooo`26ooooo`;o00000_ooool6o`0000Sooooo5_l00005oooo
o`;o00000oooool2o`0000;ooooo0_l00029ooooo`007_ooool00ol0003oooooooooo`25ooooo`?o
00000_ooool8o`0000Cooooo5?l000001?oooooo0000o`000?l00006ooooo`;o00000_ooool2o`00
08gooooo000Nooooo`03o`000?oooooooooo08Gooooo0_l00002ooooo`[o00000ooooolGo`0000Ko
oooo1?l0002@ooooo`007_ooool00ol0003oooooooooo`29ooooobGo00001Oooool4o`00093ooooo
000Nooooo`03o`000?oooooooooo08Wooooo0_l00002ooooo`;o000000?oooooo`000?l000007?l0
0005ooooo`Co0000T?ooool001kooooo00?o0000ooooooooool0O?ooool2o`0000_ooooo0_l00002
ooooo`;o000000?oooooo`000?l000006_l00007ooooo`Co00000_ooool2o`0000Gooooo0_l00025
ooooo`007_ooool00ol0003oooooooooo`1looooo`;o00002oooool6o`0000;ooooo6Ol000000ooo
oooo0000o`000006ooooo`?o00000oooool2o`0000Gooooo0_l00004ooooo`;o0000Ooooool001ko
oooo00?o0000ooooooooool0O?ooool2o`0000;ooooo0_l00004ooooo`So00000ooooolIo`000003
ooooool0003o000000;o00001?ooool3o`00013ooooo0_l0001oooooo`007_ooool2o`0007gooooo
0_l00002ooooo`;o00001?ooool8o`000004ooooool0003o0000ooooo`[o000000?oooooo`000?l0
00001ol000000ooooooo0000o`000006o`0000Cooooo0_l00006ooooo`;o0000R_ooool001kooooo
00?o0000ooooooooool0OOooool2o`0000Sooooo1Ol000000ooooooo0000o`000002o`000003oooo
ool0003o000000Wo00000_ooool7o`000003ooooool0003o000000;o00002Oooool2o`0000Gooooo
0_l0002:ooooo`007_ooool00ol0003oooooooooo`1looooo`Co00001Oooool6o`0000;ooooo0ol0
0002ooooo`Co000000?oooooo`000?l000002?l000000ooooooo0000o`000002o`000003ooooool0
003o000000;o00000oooool2o`0000Cooooo0_l0000;ooooo`;o0000Q?ooool001kooooo00?o0000
ooooooooool0O?ooool4o`0000Gooooo1ol00002ooooo`;o00000oooool9o`000003ooooool0003o
000000co00000oooool2o`0000kooooo0_l000000ooooooo0000o`000024ooooo`007_ooool00ol0
003oooooooooo`1nooooo`;o00001oooool7o`0000Gooooo4_l000000ooooooo0000o`000003o`00
00Oooooo0_l00002ooooo`;o00001_ooool2o`000003ooooool0003o000008Cooooo000Nooooo`03
o`000?oooooooooo08Oooooo1ol00004oooooaKo000000Goooooo`000?l0003o0000ooooo`02o`00
00?ooooo0_l00002ooooo`;o00001Oooool2o`000004ooooool0003o0000o`0008Cooooo000Noooo
o`03o`000?oooooooooo07oooooo0_l00007ooooo`Ko00000oooool3o`000003ooooool0003o0000
017o000000Goooooo`000?l0003o0000ooooo`02o`0000kooooo0_l000000ooooooo0000o`000025
ooooo`007_ooool00ol0003oooooooooo`1oooooo`;o00002Oooool6o`000004ooooool0003o0000
ooooob7o00002Oooool2o`0008Oooooo000Nooooo`03o`000?oooooooooo07kooooo0_l0000:oooo
o`;o00000_ooool5o`000003ooooool0003o000001oo00002Oooool2o`000003ooooool0003o0000
08Cooooo000Nooooo`03o`000?oooooooooo07kooooo0_l00005ooooo`;o000000Coooooo`000?l0
003ooooo0ol000000ooooooo0000o`000002o`0000Cooooo8?l0000:ooooo`;o0000Q?ooool001ko
oooo00?o0000ooooooooool0OOooool2o`0000Kooooo0_l000001?oooooo0000o`000?ooool6o`00
00Kooooo1Ol000000ooooooo0000o`00000>o`000003ooooool0003o000000Oo0000T?ooool001ko
oooo00?o0000ooooooooool0OOooool2o`0000Kooooo0_l00004ooooo`Oo00001OoooolOo`00097o
oooo000Nooooo`03o`000?oooooooooo08_ooooo1ol00002ooooo`;o000000?oooooo`000?l00000
2?l0000<ooooo`Oo0000Toooool001kooooo00?o0000ooooooooool0S?ooool:o`0000?ooooo1ol0
0008ooooo`;o00000_ooool8o`0000Kooooo0ol000000ooooooo0000o`000027ooooo`007_ooool0
0ol0003oooooooooo`2<ooooo`;o00000_ooool6o`0000?ooooo1ol00003ooooo`?o00000_ooool2
o`0000;ooooo1?l00002ooooo`Co00001?ooool3o`000003ooooool0003o000008Oooooo000Noooo
o`03o`000?oooooooooo08Kooooo0_l00006ooooo`?o000000?oooooo`000?l000000_l00006oooo
o`Co00000oooool5o`0000Gooooo2Ol0002Aooooo`007_ooool2o`0008Oooooo0_l00006ooooo`?o
000000Coooooo`000?l0003ooooo0_l00005ooooo`Ko00000_ooool4o`0000Gooooo1Ol00009oooo
o`;o0000R_ooool001kooooo00?o0000ooooooooool0R_ooool2o`0000Gooooo0ol000000ooooooo
0000o`000002o`0000Gooooo1Ol000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l0
00001?l00008ooooo`;o0000R_ooool001kooooo00?o0000ooooooooool0R_ooool2o`0000Gooooo
1?l00002ooooo`Ko000000?oooooo`000?l000001_l000001?oooooo0000o`000?ooool9o`0009Co
oooo000Nooooo`03o`000?oooooooooo08Kooooo0_l0000;ooooo`;o00000_ooool6o`000003oooo
ool0003o000000Wo000000?oooooo`000?l000000_l000000ooooooo0000o`000004ooooo`;o0000
T?ooool001kooooo00?o0000ooooooooool0Q_ooool2o`0000Wooooo1Ol000000ooooooo0000o`00
0008ooooo`So000000?oooooo`000?l000002Oooool2o`000003ooooool0003o000008gooooo000N
ooooo`03o`000?oooooooooo08Oooooo0_l00008ooooo`;o000000?oooooo`000?l000001?l00005
ooooo`Co00001?ooool2o`000003ooooool0003o000000;o00002_ooool2o`0008gooooo000Noooo
o`03o`000?oooooooooo08Oooooo0_l0000;ooooo`Ko00001Oooool3o`000003ooooool0003o0000
00Oooooo0_l0002Iooooo`007_ooool00ol0003oooooooooo`29ooooo`;o00002_ooool2o`0000Wo
oooo0_l000000ooooooo0000o`000009ooooo`?o00001_ooool2o`0008kooooo000Nooooo`03o`00
0?oooooooooo08Wooooo0_l0000;ooooo`?o00000_ooool2o`00017ooooo0ol00006ooooo`;o0000
S_ooool001kooooo00?o0000ooooooooool0UOooool8o`0001Cooooo0_l00002ooooo`;o0000T?oo
ool001kooooo00?o0000ooooooooool0UOooool2o`0000;ooooo0ol00004ooooo`;o00002_ooool2
o`0000?ooooo0_l00002ooooo`;o0000T?ooool001kooooo00?o0000ooooooooool0VOooool4o`00
00?ooooo0_l0000:ooooo`Co0000Uoooool001kooooo00?o0000ooooooooool0U?ooool2o`0000Go
oooo1_l0000<ooooo`?o0000Uoooool001kooooo00?o0000ooooooooool0Roooool2o`0000Oooooo
0_l00005ooooo`[o00001oooool3o`0009Sooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo08_o
oooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l00008ooooo`Co00000_ooool2o`00
00?ooooo0_l0002Iooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2Aooooo`;o000000Cooooo
o`000?l0003ooooo0_l0000>ooooo`Oo0000VOooool000?ooooo00Go410@oooooooooooooooooa0@
400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`000:Wooooo0ol0002Kooooo`000ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`03
o`000?oooooooooo09_ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0ol0002Kooooo`00
0oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c006oooo
o`03o`000?oooooooooo09_ooooo0_l00003ooooo`Ko0000XOooool000?ooooo00Go410@oooooooo
oooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0Voooool2o`00
00Cooooo1Ol0002Qooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@
4?nHV9P02?ooool00ol0003oooooooooo`2Kooooo`;o00001Oooool2o`000:?ooooo0003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0
003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co
8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool0
0ol0003oooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool0
1Ol0003ooooooooooooooooo000000Kooooo0ol0003oooooodSooooo0003ooooo`05o`000?oooooo
ooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000ooooooooool0
oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o
0000olc<c006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooo
oooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`3ooooo
odSooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o
000000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001Co
oooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB?ooool001Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodSooooo000Fooooo`03o`000?oo
oooooooo00Gooooo0ol0003oooooodSooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool0
01Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3o
oooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Cooooo00?oEEEEofIVI_l00000oooo
oomBooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.5476 .52303 Mdot
.51836 .52588 Mdot
.44542 .49727 Mdot
.50683 .52917 Mdot
.48681 .52659 Mdot
.52302 .44457 Mdot
.48574 .621 Mdot
.51461 .54279 Mdot
.60659 .52802 Mdot
.5095 .5728 Mdot
.54092 .56008 Mdot
.5176 .48215 Mdot
.50866 .41692 Mdot
.44828 .45461 Mdot
.56664 .58004 Mdot
.46774 .52331 Mdot
.52418 .52686 Mdot
.56082 .44137 Mdot
.54704 .55804 Mdot
.46839 .46276 Mdot
.52394 .52775 Mdot
.45831 .50033 Mdot
.47128 .53791 Mdot
.49334 .43887 Mdot
.531 .54255 Mdot
.50427 .48089 Mdot
.51814 .58329 Mdot
.56938 .50473 Mdot
.49086 .51922 Mdot
.52271 .45607 Mdot
.51377 .4366 Mdot
.52147 .536 Mdot
.48288 .49261 Mdot
.4323 .48602 Mdot
.51162 .43243 Mdot
.44037 .45721 Mdot
.49137 .48245 Mdot
.45486 .52318 Mdot
.47568 .53578 Mdot
.51672 .47288 Mdot
.46708 .50938 Mdot
.45491 .47632 Mdot
.52473 .46504 Mdot
.50164 .49694 Mdot
.52272 .53933 Mdot
.47006 .48475 Mdot
.40169 .48636 Mdot
.51124 .43432 Mdot
.47729 .43788 Mdot
.52636 .43613 Mdot
.47886 .52897 Mdot
.46966 .39225 Mdot
.49431 .5191 Mdot
.48424 .53433 Mdot
.47463 .54055 Mdot
.49503 .47507 Mdot
.52315 .46824 Mdot
.44549 .43689 Mdot
.51576 .538 Mdot
.52161 .46326 Mdot
.46588 .47997 Mdot
.47785 .48605 Mdot
.43432 .47107 Mdot
.46838 .52403 Mdot
.47697 .5207 Mdot
.60073 .48803 Mdot
.53378 .46243 Mdot
.47878 .482 Mdot
.49882 .46637 Mdot
.46668 .52172 Mdot
.51613 .61584 Mdot
.5013 .52996 Mdot
.51505 .4595 Mdot
.50309 .51689 Mdot
.5103 .44079 Mdot
.48931 .59358 Mdot
.48687 .47136 Mdot
.56083 .44045 Mdot
.49742 .60988 Mdot
.56857 .51789 Mdot
.43994 .50404 Mdot
.51932 .54288 Mdot
.52349 .53874 Mdot
.46505 .49393 Mdot
.43201 .4772 Mdot
.4999 .51778 Mdot
.44666 .54338 Mdot
.48407 .48344 Mdot
.51847 .47001 Mdot
.52854 .40924 Mdot
.48602 .51451 Mdot
.46394 .48874 Mdot
.45367 .54575 Mdot
.56141 .45338 Mdot
.46043 .57723 Mdot
.465 .47407 Mdot
.48832 .48093 Mdot
.52126 .43779 Mdot
.39793 .49592 Mdot
.52449 .47954 Mdot
.44956 .55089 Mdot
.4445 .5333 Mdot
.50477 .53633 Mdot
.58238 .4438 Mdot
.60074 .54674 Mdot
.48049 .48998 Mdot
.59398 .52366 Mdot
.48009 .51753 Mdot
.53055 .47893 Mdot
.4628 .48978 Mdot
.53938 .47315 Mdot
.50315 .53022 Mdot
.51288 .50988 Mdot
.52469 .55043 Mdot
.53872 .46417 Mdot
.50107 .39017 Mdot
.50081 .55038 Mdot
.56804 .50749 Mdot
.46276 .45324 Mdot
.45851 .54854 Mdot
.56558 .45112 Mdot
.50596 .48366 Mdot
.50068 .57174 Mdot
.49802 .43606 Mdot
.52263 .52559 Mdot
.48704 .55622 Mdot
.52648 .4611 Mdot
.50437 .48286 Mdot
.50173 .4903 Mdot
.47276 .53229 Mdot
.56972 .47826 Mdot
.52697 .51155 Mdot
.41731 .42662 Mdot
.45236 .45189 Mdot
.491 .52827 Mdot
.41176 .43561 Mdot
.51272 .56601 Mdot
.49379 .50793 Mdot
.50646 .45944 Mdot
.50988 .50276 Mdot
.48263 .51646 Mdot
.56628 .55521 Mdot
.49416 .48907 Mdot
.50099 .5266 Mdot
.47766 .49946 Mdot
.46188 .48862 Mdot
.5413 .51527 Mdot
.46431 .47819 Mdot
.53969 .45959 Mdot
.49047 .43867 Mdot
.44289 .46064 Mdot
.57233 .49896 Mdot
.48497 .52084 Mdot
.50842 .44292 Mdot
.56378 .49863 Mdot
.46766 .52338 Mdot
.47419 .48756 Mdot
.45121 .40277 Mdot
.48796 .47099 Mdot
.48129 .5064 Mdot
.54281 .60778 Mdot
.48261 .47016 Mdot
.55969 .4363 Mdot
.47794 .53891 Mdot
.52053 .47039 Mdot
.51984 .49142 Mdot
.59054 .56026 Mdot
.43132 .5004 Mdot
.45074 .49502 Mdot
.45545 .53382 Mdot
.56431 .50569 Mdot
.50322 .44289 Mdot
.52183 .5159 Mdot
.51896 .46829 Mdot
.54413 .5924 Mdot
.49241 .48087 Mdot
.46315 .47849 Mdot
.47929 .50974 Mdot
.39176 .47745 Mdot
.47698 .44473 Mdot
.50434 .52703 Mdot
.46348 .47562 Mdot
.49947 .51073 Mdot
.49422 .52021 Mdot
.50813 .40425 Mdot
.51705 .48718 Mdot
.44286 .52211 Mdot
.46521 .47774 Mdot
.58418 .46365 Mdot
.46398 .56182 Mdot
.507 .49716 Mdot
.47434 .52973 Mdot
.50831 .44692 Mdot
.48308 .51973 Mdot
.45398 .52726 Mdot
.47001 .50977 Mdot
.50485 .43616 Mdot
.4923 .49404 Mdot
.47415 .52223 Mdot
.51023 .52642 Mdot
.52385 .48948 Mdot
.47713 .47968 Mdot
.56775 .45939 Mdot
.43476 .49556 Mdot
.47707 .54793 Mdot
.52323 .50969 Mdot
.52825 .51435 Mdot
.5258 .47281 Mdot
.43429 .49334 Mdot
.4822 .52259 Mdot
.52339 .53854 Mdot
.49299 .484 Mdot
.51181 .46635 Mdot
.55436 .45082 Mdot
.50649 .48352 Mdot
.40323 .48469 Mdot
.4653 .48548 Mdot
.49284 .46946 Mdot
.56306 .55426 Mdot
.4818 .51339 Mdot
.46879 .53418 Mdot
.43726 .41444 Mdot
.46285 .48781 Mdot
.42681 .43985 Mdot
.52631 .53764 Mdot
.51139 .53437 Mdot
.51738 .53509 Mdot
.5086 .57331 Mdot
.44075 .50738 Mdot
.5551 .55197 Mdot
.48662 .54568 Mdot
.49452 .48462 Mdot
.52716 .54929 Mdot
.47774 .48747 Mdot
.49967 .47756 Mdot
.50605 .45832 Mdot
.49076 .54994 Mdot
.48181 .59173 Mdot
.52621 .50868 Mdot
.51716 .48699 Mdot
.5104 .57338 Mdot
.56281 .59151 Mdot
.54221 .4915 Mdot
.47893 .55113 Mdot
.44469 .57993 Mdot
.4714 .53319 Mdot
.5047 .60126 Mdot
.50774 .53623 Mdot
.49142 .55453 Mdot
.51947 .55963 Mdot
.52555 .4668 Mdot
.51156 .40049 Mdot
.55505 .59636 Mdot
.45298 .57817 Mdot
.50997 .5124 Mdot
.52058 .48292 Mdot
.47198 .54273 Mdot
.50347 .46889 Mdot
.43167 .48335 Mdot
.55801 .57347 Mdot
.42984 .49746 Mdot
.47357 .52243 Mdot
.48123 .50587 Mdot
.56158 .46468 Mdot
.4612 .46119 Mdot
.43775 .47035 Mdot
.53301 .54586 Mdot
.56832 .47094 Mdot
.46976 .49851 Mdot
.3915 .47045 Mdot
.52981 .47046 Mdot
.51314 .50922 Mdot
.58642 .46619 Mdot
.51203 .50569 Mdot
.4458 .51862 Mdot
.5112 .60887 Mdot
.49042 .47357 Mdot
.53733 .56661 Mdot
.47914 .46186 Mdot
.52511 .56906 Mdot
.50302 .46283 Mdot
.50646 .47625 Mdot
.47784 .44977 Mdot
.48727 .50203 Mdot
.48002 .53988 Mdot
.55084 .44857 Mdot
.39589 .48444 Mdot
.46748 .54083 Mdot
.52449 .51361 Mdot
.51801 .44315 Mdot
.52162 .47513 Mdot
.5357 .44941 Mdot
.51407 .39161 Mdot
.52112 .4562 Mdot
.5197 .49214 Mdot
.49133 .53385 Mdot
.57128 .48968 Mdot
.47417 .44846 Mdot
.44036 .48121 Mdot
.50728 .52983 Mdot
.49734 .50052 Mdot
.51161 .53366 Mdot
.60921 .53528 Mdot
.46079 .50275 Mdot
.5202 .4793 Mdot
.50572 .52908 Mdot
.42627 .50821 Mdot
.54351 .46438 Mdot
.5351 .54152 Mdot
.47008 .45849 Mdot
.50575 .52358 Mdot
.48635 .49963 Mdot
.51443 .55679 Mdot
.54944 .54075 Mdot
.51311 .52264 Mdot
.54225 .45604 Mdot
.51565 .47276 Mdot
.4814 .48246 Mdot
.51394 .46067 Mdot
.45034 .52126 Mdot
.48486 .44206 Mdot
.53916 .55823 Mdot
.53193 .55063 Mdot
.49365 .47896 Mdot
.56197 .51996 Mdot
.44562 .52819 Mdot
.50501 .4964 Mdot
.50297 .489 Mdot
.58712 .53523 Mdot
.43859 .50992 Mdot
.53906 .50183 Mdot
.48585 .3902 Mdot
.51406 .50805 Mdot
.51552 .57243 Mdot
.43327 .48474 Mdot
.48834 .56001 Mdot
.44824 .45699 Mdot
.50374 .52921 Mdot
.54648 .55122 Mdot
.48074 .48537 Mdot
.53196 .45681 Mdot
.54638 .46386 Mdot
.4574 .577 Mdot
.49103 .49038 Mdot
.44294 .5124 Mdot
.53467 .47622 Mdot
.48843 .50317 Mdot
.50395 .53767 Mdot
.43091 .49877 Mdot
.46496 .49411 Mdot
.52237 .47162 Mdot
.42283 .42018 Mdot
.52482 .5316 Mdot
.48368 .48507 Mdot
.53885 .41164 Mdot
.52141 .48204 Mdot
.45082 .4589 Mdot
.52832 .50303 Mdot
.51766 .39534 Mdot
.47882 .49067 Mdot
.47528 .52369 Mdot
.54381 .45494 Mdot
.5175 .49876 Mdot
.48251 .45003 Mdot
.53013 .49413 Mdot
.4704 .4539 Mdot
.42472 .54923 Mdot
.4326 .50245 Mdot
.39466 .50968 Mdot
.49885 .51643 Mdot
.48131 .50708 Mdot
.49051 .50973 Mdot
.43103 .41118 Mdot
.54132 .54971 Mdot
.45349 .46253 Mdot
.48922 .56215 Mdot
.54935 .55024 Mdot
.45874 .56566 Mdot
.46293 .47167 Mdot
.49608 .48207 Mdot
.46122 .45545 Mdot
.47153 .59405 Mdot
.49584 .52639 Mdot
.44905 .42117 Mdot
.51774 .53606 Mdot
.52577 .48201 Mdot
.57058 .50263 Mdot
.48289 .55575 Mdot
.49925 .47506 Mdot
.46743 .45326 Mdot
.41716 .47138 Mdot
.47908 .46643 Mdot
.4843 .44351 Mdot
.52168 .53661 Mdot
.46899 .539 Mdot
.51785 .54416 Mdot
.46538 .51071 Mdot
.48387 .49613 Mdot
.56284 .51726 Mdot
.41184 .46759 Mdot
.40685 .48108 Mdot
.45762 .45151 Mdot
.45033 .52093 Mdot
.50786 .47604 Mdot
.49135 .44568 Mdot
.44773 .45099 Mdot
.49548 .52202 Mdot
.48201 .51064 Mdot
.52671 .48247 Mdot
.56416 .52028 Mdot
.51132 .49723 Mdot
.54709 .55377 Mdot
.50157 .51612 Mdot
.50888 .43467 Mdot
.49791 .5139 Mdot
.44758 .54086 Mdot
.46151 .49464 Mdot
.51632 .44753 Mdot
.52146 .45814 Mdot
.49898 .56911 Mdot
.53478 .56055 Mdot
.47166 .48408 Mdot
.50015 .50999 Mdot
.52979 .57096 Mdot
.44476 .49544 Mdot
.4437 .45636 Mdot
.58526 .57622 Mdot
.46815 .49993 Mdot
.49767 .46019 Mdot
.51167 .46769 Mdot
.53804 .4506 Mdot
.46611 .52018 Mdot
.533 .50607 Mdot
.54287 .55199 Mdot
.44317 .49842 Mdot
.4951 .43941 Mdot
.44775 .49745 Mdot
.52244 .46678 Mdot
.54078 .45558 Mdot
.51946 .46875 Mdot
.51734 .45109 Mdot
.50504 .40185 Mdot
.52412 .44195 Mdot
.55999 .47329 Mdot
.47934 .49021 Mdot
.56994 .47707 Mdot
.49238 .52622 Mdot
.47543 .54284 Mdot
.43327 .48431 Mdot
.4874 .51634 Mdot
.4364 .4785 Mdot
.51551 .49186 Mdot
.46542 .50233 Mdot
.51825 .46721 Mdot
.42984 .51328 Mdot
.5834 .54325 Mdot
.44577 .45903 Mdot
.44883 .51732 Mdot
.48533 .50833 Mdot
.50777 .46805 Mdot
.43264 .49095 Mdot
.50602 .51878 Mdot
.49805 .43017 Mdot
.47799 .4878 Mdot
.49594 .44497 Mdot
.40898 .44485 Mdot
.4685 .49066 Mdot
.50245 .50731 Mdot
.53523 .45096 Mdot
.50265 .46797 Mdot
.53821 .54929 Mdot
.50046 .56773 Mdot
.53702 .53667 Mdot
.56003 .52322 Mdot
.56152 .5293 Mdot
.59636 .53747 Mdot
.47724 .43281 Mdot
.55708 .51199 Mdot
.45225 .55587 Mdot
.41539 .42779 Mdot
.48714 .49768 Mdot
.52488 .53281 Mdot
.51459 .53933 Mdot
.51639 .54202 Mdot
.4711 .48363 Mdot
.43627 .49282 Mdot
.52 .57124 Mdot
.54699 .51718 Mdot
.49573 .44262 Mdot
.46012 .56829 Mdot
.4944 .39062 Mdot
.4387 .50335 Mdot
.60472 .49558 Mdot
.47643 .51698 Mdot
.52663 .4701 Mdot
.53399 .40731 Mdot
.52695 .55289 Mdot
.47638 .5131 Mdot
.4427 .48825 Mdot
.52937 .53887 Mdot
.49978 .56241 Mdot
.56444 .5923 Mdot
.48094 .59802 Mdot
.47917 .54602 Mdot
.51748 .48818 Mdot
.5345 .57427 Mdot
.54657 .51047 Mdot
.49872 .5627 Mdot
.46706 .57242 Mdot
.53813 .44159 Mdot
.48052 .46616 Mdot
.43414 .46934 Mdot
.52761 .47103 Mdot
.53061 .42583 Mdot
.51988 .53523 Mdot
.46509 .51365 Mdot
.52698 .46982 Mdot
.51322 .43507 Mdot
.44515 .47007 Mdot
.54903 .5434 Mdot
.49839 .56015 Mdot
.53102 .4692 Mdot
.54408 .54028 Mdot
.50112 .47999 Mdot
.52036 .48618 Mdot
.49017 .47998 Mdot
.46368 .44637 Mdot
.47618 .39095 Mdot
.57185 .48892 Mdot
.55709 .53681 Mdot
.42705 .49011 Mdot
.46167 .48864 Mdot
.49249 .47325 Mdot
.50669 .51796 Mdot
.59047 .46744 Mdot
.51385 .48525 Mdot
.44258 .41787 Mdot
.47544 .48227 Mdot
.52447 .46933 Mdot
.54237 .56682 Mdot
.51097 .51053 Mdot
.55519 .4281 Mdot
.46038 .49352 Mdot
.46347 .42606 Mdot
.5723 .49175 Mdot
.52397 .59723 Mdot
.49682 .52551 Mdot
.54398 .41683 Mdot
.50161 .53151 Mdot
.54447 .55032 Mdot
.51877 .47098 Mdot
.48334 .53237 Mdot
.4804 .49668 Mdot
.46735 .55722 Mdot
.50946 .53227 Mdot
.47017 .52705 Mdot
.48537 .51164 Mdot
.50461 .4508 Mdot
.50316 .38967 Mdot
.48525 .55762 Mdot
.44286 .52357 Mdot
.43273 .50225 Mdot
.47994 .55181 Mdot
.49572 .51676 Mdot
.45139 .47163 Mdot
.47409 .5435 Mdot
.50421 .60048 Mdot
.52189 .56815 Mdot
.44855 .42125 Mdot
.47901 .43393 Mdot
.39291 .46838 Mdot
.49957 .48321 Mdot
.51059 .45237 Mdot
.50139 .53511 Mdot
.51508 .49046 Mdot
.46573 .50934 Mdot
.54046 .41437 Mdot
.51834 .47149 Mdot
.47351 .58406 Mdot
.51302 .48064 Mdot
.44848 .53856 Mdot
.49878 .52881 Mdot
.50492 .56952 Mdot
.52653 .48956 Mdot
.486 .46973 Mdot
.38352 .51309 Mdot
.49444 .52991 Mdot
.53123 .47777 Mdot
.5347 .47955 Mdot
.43219 .47528 Mdot
.51866 .48573 Mdot
.46741 .48834 Mdot
.47274 .52349 Mdot
.50802 .49148 Mdot
.47579 .54147 Mdot
.54004 .50003 Mdot
.4841 .43355 Mdot
.46497 .48024 Mdot
.5608 .43821 Mdot
.51914 .52157 Mdot
.43519 .49817 Mdot
.47193 .51522 Mdot
.54761 .54053 Mdot
.54845 .42474 Mdot
.46631 .48894 Mdot
.52887 .47323 Mdot
.48017 .54454 Mdot
.43805 .49217 Mdot
.47908 .48606 Mdot
.50493 .48865 Mdot
.56859 .48726 Mdot
.5473 .49118 Mdot
.47634 .53952 Mdot
.3902 .50397 Mdot
.54553 .51184 Mdot
.48759 .52202 Mdot
.47303 .53528 Mdot
.47828 .54795 Mdot
.47743 .51964 Mdot
.5514 .58967 Mdot
.48768 .62034 Mdot
.46111 .39701 Mdot
.5106 .5162 Mdot
.47505 .48725 Mdot
.42755 .57726 Mdot
.46783 .45609 Mdot
.48571 .51868 Mdot
.4875 .50944 Mdot
.413 .43495 Mdot
.52409 .51517 Mdot
.46997 .48101 Mdot
.47168 .53408 Mdot
.4855 .43649 Mdot
.55343 .42597 Mdot
.55136 .42395 Mdot
.54427 .55323 Mdot
.47563 .58248 Mdot
.50502 .50446 Mdot
.51079 .53675 Mdot
.39677 .48334 Mdot
.5029 .53678 Mdot
.48793 .47206 Mdot
.42127 .53171 Mdot
.4684 .49599 Mdot
.47601 .5381 Mdot
.5542 .43752 Mdot
.54345 .41777 Mdot
.47625 .48967 Mdot
.4709 .61366 Mdot
.4915 .61592 Mdot
.54451 .54071 Mdot
.4806 .49893 Mdot
.48808 .48691 Mdot
.53035 .47962 Mdot
.51838 .50166 Mdot
.52417 .46346 Mdot
.60207 .49819 Mdot
.50562 .50094 Mdot
.43441 .47845 Mdot
.50897 .48948 Mdot
.5033 .53254 Mdot
.47695 .49496 Mdot
.475 .45064 Mdot
.44565 .46721 Mdot
.43513 .55874 Mdot
.44082 .46235 Mdot
.4373 .50929 Mdot
.44392 .52125 Mdot
.54324 .4819 Mdot
.5877 .52393 Mdot
.52268 .52177 Mdot
.43697 .45966 Mdot
.41196 .4882 Mdot
.47851 .52081 Mdot
.47653 .53762 Mdot
.5208 .57934 Mdot
.50616 .45494 Mdot
.52237 .53954 Mdot
.57423 .48754 Mdot
.4927 .53444 Mdot
.46248 .47832 Mdot
.44336 .52214 Mdot
.5279 .4961 Mdot
.45163 .52679 Mdot
.52389 .5322 Mdot
.47597 .47798 Mdot
.52193 .52438 Mdot
.51353 .40477 Mdot
.51629 .46414 Mdot
.48798 .45634 Mdot
.4733 .47216 Mdot
.44087 .46303 Mdot
.45722 .39777 Mdot
.4997 .47668 Mdot
.48646 .44721 Mdot
.54062 .52389 Mdot
.55526 .54323 Mdot
.49772 .49691 Mdot
.46239 .49178 Mdot
.5066 .52971 Mdot
.47914 .53015 Mdot
.51385 .48406 Mdot
.49699 .43924 Mdot
.47706 .52085 Mdot
.44404 .4927 Mdot
.51597 .62205 Mdot
.48929 .48129 Mdot
.481 .52675 Mdot
.42971 .48987 Mdot
.53145 .57091 Mdot
.60212 .49398 Mdot
.50621 .48971 Mdot
.43577 .5172 Mdot
.55067 .54984 Mdot
.51568 .44519 Mdot
.51588 .58457 Mdot
.54407 .55708 Mdot
.5376 .50521 Mdot
.52375 .46804 Mdot
.57359 .48151 Mdot
.50072 .52003 Mdot
.56119 .52528 Mdot
.50021 .45758 Mdot
.50506 .52018 Mdot
.54851 .49803 Mdot
.5227 .47605 Mdot
.536 .40706 Mdot
.55402 .44474 Mdot
.44237 .4179 Mdot
.47348 .4732 Mdot
.56061 .50314 Mdot
.46481 .49792 Mdot
.52236 .47613 Mdot
.46903 .48969 Mdot
.49087 .38603 Mdot
.49391 .62072 Mdot
.49552 .47895 Mdot
.46243 .48958 Mdot
.54523 .55902 Mdot
.49721 .46929 Mdot
.46801 .48522 Mdot
.49919 .40269 Mdot
.50289 .47622 Mdot
.53864 .53705 Mdot
.47297 .51083 Mdot
.48325 .53219 Mdot
.47723 .51644 Mdot
.48427 .4841 Mdot
.50037 .49013 Mdot
.53638 .53786 Mdot
.46384 .44453 Mdot
.4847 .50609 Mdot
.52053 .46575 Mdot
.48426 .52946 Mdot
.48864 .55135 Mdot
.46864 .43404 Mdot
.56686 .55598 Mdot
.49357 .5658 Mdot
.5167 .44038 Mdot
.52982 .56129 Mdot
.52335 .47035 Mdot
.52584 .47512 Mdot
.54905 .48216 Mdot
.47414 .47028 Mdot
.53582 .40854 Mdot
.50724 .51526 Mdot
.4364 .41933 Mdot
.4968 .52485 Mdot
.50359 .49485 Mdot
.44653 .45192 Mdot
.54476 .48641 Mdot
.51822 .43598 Mdot
.51302 .4369 Mdot
.49724 .51524 Mdot
.43618 .46791 Mdot
.47696 .5543 Mdot
.58558 .54727 Mdot
.54315 .54082 Mdot
.50421 .51016 Mdot
.50525 .46685 Mdot
.47863 .54007 Mdot
.53424 .47407 Mdot
.518 .44979 Mdot
.49427 .3986 Mdot
.43831 .47549 Mdot
.51487 .60983 Mdot
.51835 .50665 Mdot
.46945 .52061 Mdot
.56539 .50629 Mdot
.46004 .48445 Mdot
.5118 .52381 Mdot
.56641 .45822 Mdot
.50358 .52371 Mdot
.45149 .51848 Mdot
.52933 .48309 Mdot
.44104 .51414 Mdot
.52812 .46732 Mdot
.49229 .55621 Mdot
.47746 .54694 Mdot
.40583 .5544 Mdot
.47263 .52006 Mdot
.525 .47209 Mdot
.46307 .56743 Mdot
.57181 .50435 Mdot
.54751 .52581 Mdot
.47248 .53329 Mdot
.52136 .47203 Mdot
.52956 .53959 Mdot
.52345 .53787 Mdot
.56838 .4576 Mdot
.49753 .52537 Mdot
.52208 .59561 Mdot
.50158 .52357 Mdot
.52897 .54 Mdot
.47941 .55098 Mdot
.52405 .46354 Mdot
.46809 .47438 Mdot
.52395 .47329 Mdot
.54506 .53139 Mdot
.50305 .43681 Mdot
.47027 .49032 Mdot
.50998 .51475 Mdot
.52049 .61088 Mdot
.54034 .5644 Mdot
.54765 .52962 Mdot
.55802 .53612 Mdot
.4761 .5219 Mdot
.52556 .50616 Mdot
.52925 .48611 Mdot
.50275 .47592 Mdot
.42438 .55427 Mdot
.53054 .45521 Mdot
.45051 .4755 Mdot
.47572 .4838 Mdot
.4941 .48542 Mdot
.47651 .5373 Mdot
.45163 .47489 Mdot
.56902 .51174 Mdot
.5101 .51881 Mdot
.46545 .53265 Mdot
.54803 .51524 Mdot
.467 .48557 Mdot
.46417 .47424 Mdot
.54041 .60565 Mdot
.49946 .61351 Mdot
.42804 .50706 Mdot
.58958 .52291 Mdot
.44785 .47454 Mdot
.46699 .48408 Mdot
.51369 .45934 Mdot
.52408 .5193 Mdot
.55372 .42844 Mdot
.41702 .47415 Mdot
.41528 .49288 Mdot
.54415 .58296 Mdot
.51539 .49228 Mdot
.47179 .49291 Mdot
.53802 .42685 Mdot
.50159 .50898 Mdot
.48115 .51879 Mdot
.43048 .50786 Mdot
.51586 .49206 Mdot
.48513 .49998 Mdot
.4554 .53056 Mdot
.57049 .48567 Mdot
.43525 .50607 Mdot
.52125 .51097 Mdot
.5717 .47477 Mdot
.51601 .52459 Mdot
.45371 .42407 Mdot
.56747 .46407 Mdot
.46487 .53305 Mdot
.4883 .43161 Mdot
.53954 .4979 Mdot
.54359 .51131 Mdot
.49837 .5157 Mdot
.48127 .53522 Mdot
.46459 .48908 Mdot
.51902 .47121 Mdot
.47836 .38993 Mdot
.42169 .55721 Mdot
.42999 .4117 Mdot
.53816 .46205 Mdot
.49205 .51603 Mdot
.51938 .40514 Mdot
.51827 .54059 Mdot
.51559 .46564 Mdot
.46631 .51403 Mdot
.47198 .58018 Mdot
.43607 .40536 Mdot
.47433 .47151 Mdot
.48761 .48818 Mdot
.45547 .55276 Mdot
.54304 .55064 Mdot
.47651 .51078 Mdot
.58756 .4622 Mdot
.48977 .52303 Mdot
.52902 .48241 Mdot
.51384 .50529 Mdot
.51509 .50874 Mdot
.55057 .49876 Mdot
.52385 .48902 Mdot
.52696 .5023 Mdot
.51516 .52301 Mdot
.57775 .52942 Mdot
.50012 .52023 Mdot
.46555 .5735 Mdot
.5102 .45902 Mdot
.49115 .53403 Mdot
.54019 .45354 Mdot
.42886 .48441 Mdot
.43042 .49493 Mdot
.51664 .49562 Mdot
.47235 .53743 Mdot
.52151 .53 Mdot
.5158 .4798 Mdot
.43618 .52182 Mdot
.4383 .59164 Mdot
.53758 .47195 Mdot
.47295 .53592 Mdot
.46729 .48923 Mdot
.50007 .4948 Mdot
.44564 .45928 Mdot
.43009 .50507 Mdot
.55847 .58832 Mdot
.50457 .52118 Mdot
.48854 .53345 Mdot
.51983 .47812 Mdot
.60226 .51795 Mdot
.49744 .52084 Mdot
.51961 .50239 Mdot
.44469 .48313 Mdot
.61321 .51219 Mdot
.5257 .51364 Mdot
.50142 .50601 Mdot
.49804 .43568 Mdot
.47678 .4865 Mdot
.40645 .54243 Mdot
.52103 .57274 Mdot
.52335 .6101 Mdot
.46135 .39678 Mdot
.53232 .54226 Mdot
.48645 .44132 Mdot
.50331 .52155 Mdot
.47578 .47685 Mdot
.54515 .49924 Mdot
.52682 .44515 Mdot
.51484 .43514 Mdot
.51647 .4555 Mdot
.4594 .42507 Mdot
.56838 .51181 Mdot
.51103 .50415 Mdot
.5512 .4211 Mdot
.52708 .50014 Mdot
.50566 .5261 Mdot
.56933 .47477 Mdot
.44687 .5428 Mdot
.46258 .50117 Mdot
.39567 .53286 Mdot
.55311 .5737 Mdot
.43034 .49189 Mdot
.49797 .51264 Mdot
.46597 .49507 Mdot
.49096 .48515 Mdot
.47127 .49036 Mdot
.52016 .45448 Mdot
.4446 .52276 Mdot
.52297 .49467 Mdot
.46505 .50113 Mdot
.4651 .53908 Mdot
.44264 .47002 Mdot
.54678 .48201 Mdot
.4882 .38767 Mdot
.43342 .50364 Mdot
.39508 .50667 Mdot
.46486 .51525 Mdot
.57466 .53686 Mdot
.49854 .51094 Mdot
.50824 .47743 Mdot
.56044 .44083 Mdot
.51714 .40209 Mdot
.48253 .51139 Mdot
.51205 .54107 Mdot
.51258 .53093 Mdot
.53297 .44783 Mdot
.46395 .45317 Mdot
.54855 .50412 Mdot
.51371 .51444 Mdot
.46071 .50125 Mdot
.48901 .56139 Mdot
.54751 .5238 Mdot
.4722 .53493 Mdot
.54698 .46912 Mdot
.52135 .56946 Mdot
.49114 .56037 Mdot
.47453 .47799 Mdot
.4802 .57362 Mdot
.45327 .55616 Mdot
.53351 .61428 Mdot
.54215 .41438 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0Voooool2o`000:[ooooo000Nooooo`03
o`000?oooooooooo09Oooooo0_l000000ooooooo0000o`000005o`0000;ooooo0_l0002Rooooo`00
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@oooooooo
ool01?ooool00ol0003oooooooooo`2Eooooo`Co000000Coooooo`000?l0003ooooo1?l00002oooo
o`;o0000X_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo097ooooo0ol000000ooooooo0000o`00000=oooo
o`;o0000XOooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool3o`00
097ooooo0ol00009ooooo`;o00000oooool4o`000:7ooooo0003ooooo`05o`000?oooooooooooooo
ool000002oooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo08oooooo0_l0000<
ooooo`Wo0000XOooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0000Oooooo00?o0000ooooooooool0R_ooool2o`0000?ooooo0_l0000=ooooo`Wo00000_oo
ool3o`0009_ooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00
0007ooooo`03o`000?oooooooooo08[ooooo0_l0000Gooooo`Co000000?oooooo`000?l000000_l0
002Kooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001ooo
ool00ol0003oooooooooo`28ooooo`;o00007_ooool5o`0009[ooooo0003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo08Sooooo1?l0
000Oooooo`?o0000VOooool001kooooo00?o0000ooooooooool0R_ooool4o`0001?ooooo0_l00009
ooooo`?o0000V?ooool001kooooo00?o0000ooooooooool0QOooool2o`0000?ooooo1_l0000Aoooo
o`;o00002_ooool4o`0009Kooooo000Nooooo`03o`000?oooooooooo08Gooooo0_l00007ooooo`Go
00005Oooool2o`0000Cooooo0ol0002Fooooo`007_ooool00ol0003oooooooooo`23ooooo`?o0000
2Oooool6o`0001?ooooo0_l000001?oooooo0000o`000?ooool4o`0009Gooooo000Nooooo`03o`00
0?oooooooooo08?ooooo0ol0000=ooooo`;o00001_ooool2o`000003ooooool0003o000000_ooooo
0_l00003ooooo`;o0000UOooool001kooooo00?o0000ooooooooool0P_ooool2o`00013ooooo0_l0
00000ooooooo0000o`000004o`000004ooooool0003o0000ooooo`Co0000X_ooool001kooooo00?o
0000ooooooooool0P_ooool2o`0000Wooooo0_l00005ooooo`;o000000?oooooo`000?l000000ol0
0002ooooo`_o00001oooool4o`0009?ooooo000Nooooo`03o`000?oooooooooo08;ooooo0_l00003
ooooo`;o00001?ooool2o`0000Sooooo0_l000000ooooooo0000o`00000=o`0000Oooooo1?l0002C
ooooo`007_ooool00ol0003oooooooooo`27ooooo`;o00004?ooool?o`0000?ooooo0_l00005oooo
o`;o00001Oooool2o`0008cooooo000Nooooo`03o`000?oooooooooo087ooooo0_l0000@ooooo`;o
00000_ooool<o`000003ooooool0003o000000?o00000_ooool2o`0000?ooooo1?l00005ooooo`;o
0000S?ooool001kooooo00?o0000ooooooooool0POooool2o`00013ooooo0_l000000ooooooo0000
o`000007o`0000;ooooo0_l000000ooooooo0000o`000006o`0000?ooooo0ol0002Eooooo`007_oo
ool2o`0008kooooo3_l00005ooooo`Ko00000oooool5o`000003ooooool0003o000000Go0000TOoo
ool001kooooo00?o0000ooooooooool0S?ooool<o`0000?ooooo0_l00003ooooo`oo000000?ooooo
o`000?l000001?l0002Aooooo`007_ooool00ol0003oooooooooo`2:ooooo`Ko00000_ooool5o`00
00Cooooo0_l00002oooooa3o00001Oooool3o`00093ooooo000Nooooo`03o`000?oooooooooo08[o
oooo1ol000000ooooooo0000o`000003o`000003ooooool0003o000000Cooooo3ol00007ooooo`?o
00001?ooool2o`0008[ooooo000Nooooo`03o`000?oooooooooo08_ooooo0ol000001?oooooo0000
o`000?ooool4o`0000;ooooo0_l00004ooooo`?o00000_ooool=o`0000;ooooo1?l00004ooooo`?o
0000R_ooool001kooooo00?o0000ooooooooool0O?ooool2o`0000Cooooo0_l00006ooooo`Go0000
2Oooool2o`0000Cooooo3?l000000ooooooo0000o`000003o`0000;ooooo1?l00004ooooo`Co0000
ROooool001kooooo00?o0000ooooooooool0Noooool3o`0000Cooooo1?l00003ooooo`So000000?o
ooooo`000?l000000_oooolGo`000003ooooool0003o000000Gooooo0_l00004ooooo`?o0000ROoo
ool001kooooo00?o0000ooooooooool0Noooool2o`0000Kooooo0ol00003ooooo`So000000?ooooo
o`000?l000001?l000000ooooooo0000o`000005o`0000Cooooo2Ol000000ooooooo0000o`000002
ooooo`;o000000Coooooo`000?l0003o0000Soooool001kooooo00?o0000ooooooooool0Noooool2
o`0000Kooooo0_l00003ooooo`Co000000?oooooo`000?l000000ol000000ooooooo0000o`000004
o`0000;ooooo2?l000000ooooooo0000o`000007o`0000Gooooo0_l000001?oooooo0000o`000?l0
002?ooooo`007_ooool00ol0003oooooooooo`1kooooo`;o00000oooool2o`0000Kooooo1Ol00000
0ooooooo0000o`000009o`0000;ooooo4Ol00009ooooo`;o0000T?ooool001kooooo00?o0000oooo
ooooool0OOooool2o`000003ooooool0003o000000Kooooo1_l00004oooooako00001Oooool3o`00
08oooooo000Nooooo`03o`000?oooooooooo07gooooo1?l00006ooooo`Co000000?oooooo`000?l0
00000ooooolIo`0000;ooooo1?l00005ooooo`?o0000Soooool001kooooo00?o0000ooooooooool0
OOooool4o`000003ooooool0003o000000?ooooo1?l000000ooooooo0000o`000003oooooaWo0000
0oooool2o`0000Kooooo1?l00006ooooo`;o0000Q_ooool001kooooo00?o0000ooooooooool0P_oo
ool3o`0000;ooooo1ol00004oooooaOo00000oooool4o`0000Kooooo0ol00006ooooo`;o0000Q_oo
ool001kooooo00?o0000ooooooooool0OOooool2o`0000Cooooo0_l00003ooooo`So00000_ooool9
o`000003ooooool0003o000000co00000_ooool4o`0000Kooooo0_l00008ooooo`;o0000QOooool0
01kooooo00?o0000ooooooooool0OOooool2o`0000Wooooo0ol000000ooooooo0000o`000002o`00
00;ooooo6?l000000ooooooo0000o`000004o`0000;ooooo0_l000000ooooooo0000o`000008oooo
o`;o0000QOooool001kooooo0_l00029ooooo`?o000000Coooooo`000?l0003o00000_ooool;o`00
00;ooooo2ol00002ooooo`Ko00000_ooool5o`0000Sooooo0_l00025ooooo`007_ooool00ol0003o
ooooooooo`1kooooo`;o00002oooool5o`0000Cooooo1Ol00004ooooo`?o000000?oooooo`000?l0
00002_l000001?oooooo0000o`000?ooool2o`0000;ooooo1_l0002?ooooo`007_ooool00ol0003o
ooooooooo`1kooooo`?o00002?ooool7o`0000_ooooo1_l000000ooooooo0000o`000005o`000003
ooooool0003o000000Co000000?oooooo`000?l000000_ooool6o`0008oooooo000Nooooo`03o`00
0?oooooooooo07cooooo0_l00008ooooo`Oo00001_oooolHo`0000;ooooo0ol000001?oooooo0000
o`000?ooool3o`00093ooooo000Nooooo`03o`000?oooooooooo07Wooooo0_l000000ooooooo0000
o`00000:ooooo`Ko00001Oooool:o`000003ooooool0003o000000[o00000oooool3o`000003oooo
ool0003o000000;ooooo0_l0000<ooooo`;o0000P_ooool001kooooo00?o0000ooooooooool0NOoo
ool2o`0000gooooo2?l00003oooooa;o000000?oooooo`000?l000000_l00002ooooo`Co00000ooo
ool4o`0000Wooooo0_l000000ooooooo0000o`000022ooooo`007_ooool00ol0003oooooooooo`2:
ooooo`;o000000?oooooo`000?l000000_l00002oooooa7o00000_ooool2o`0000Cooooo1?l00003
ooooo`Co00002Oooool2o`0008Gooooo000Nooooo`03o`000?oooooooooo08[ooooo2?l000000ooo
oooo0000o`00000Co`0000Cooooo1?l00002ooooo`?o00001_ooool4o`0008Sooooo000Nooooo`03
o`000?oooooooooo08[ooooo2?l00002oooooaCo00001?ooool4o`0000;ooooo0_l00007ooooo`Co
0000R?ooool001kooooo00?o0000ooooooooool0SOooool4o`0000Cooooo4ol00006ooooo`;o0000
0_ooool2o`0000Cooooo0_l00007ooooo`;o0000Q?ooool001kooooo00?o0000ooooooooool0OOoo
ool2o`0000Kooooo0_l00005ooooo`?o000000Coooooo`000?l0003ooooo5_l00004ooooo`?o0000
0_ooool2o`0000Cooooo0_l00007ooooo`;o0000Q?ooool001kooooo00?o0000ooooooooool0OOoo
ool2o`0000Kooooo0_l00005ooooo`;o00000_ooool2o`000003ooooool0003o000000Wo000000?o
ooooo`000?l000002?l00004ooooo`;o00000_ooool2o`0000Sooooo0_l00005ooooo`;o0000Pooo
ool001kooooo00?o0000ooooooooool0S_ooool4o`000003ooooool0003o000000Ko000000Cooooo
o`000?l0003ooooo3_l00004ooooo`;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`00
0002ooooo`;o0000Poooool001kooooo00?o0000ooooooooool0P?ooool2o`0000_ooooo0ol00003
ooooo`Oo00001OoooolDo`0000Cooooo0_l00005ooooo`;o0000Qoooool001kooooo00?o0000oooo
ooooool0P?ooool2o`0000_ooooo1?l00003ooooo`So00001_ooool5o`000003ooooool0003o0000
00So00002?ooool2o`0008_ooooo000Nooooo`03o`000?oooooooooo08gooooo1_l00003ooooo`Ko
00001oooool4o`0000;ooooo0_l00003ooooo`Co00002?ooool2o`0000?ooooo0_l00026ooooo`00
7_ooool2o`0008Oooooo0_l00006ooooo`;o000000?oooooo`000?l000001?ooool3o`000003oooo
ool0003o000000;ooooo0_l00005ooooo`co00002?ooool2o`0000?ooooo0_l00026ooooo`007_oo
ool00ol0003oooooooooo`20ooooo`;o00001?ooool2o`0000Kooooo1?l00005ooooo`?o000000Go
ooooo`000?l0003o0000ooooo`02o`0000Gooooo3?l000000ooooooo0000o`00002Booooo`007_oo
ool00ol0003oooooooooo`20ooooo`;o00000oooool3o`0000Oooooo0ol00002ooooo`;o000000?o
ooooo`000?l000001Ol00005ooooo`;o00000_ooool2o`0000Cooooo0ol00003ooooo`?o0000TOoo
ool001kooooo00?o0000ooooooooool0QOooool2o`0000;ooooo0_l00004ooooo`;o00000oooool2
o`0000?ooooo1ol00003ooooo`Co00000oooool6o`0000Cooooo0_l00006ooooo`;o0000ROooool0
01kooooo00?o0000ooooooooool0ROooool2o`0000Sooooo0_l00006ooooo`Go00001Oooool2o`00
0003ooooool0003o000000Go00003Oooool2o`0008Wooooo000Nooooo`03o`000?oooooooooo097o
oooo1?l00006ooooo`Go00000oooool2o`0000?ooooo0_l000001?oooooo0000o`000?l0002Ioooo
o`007_ooool00ol0003oooooooooo`2Aooooo`?o00002?ooool6o`000003ooooool0003o000000Co
00000_ooool3o`0009Wooooo000Nooooo`03o`000?oooooooooo097ooooo1Ol00008ooooo`go0000
1_ooool2o`0009Cooooo000Nooooo`03o`000?oooooooooo09?ooooo0ol00002ooooo`;o00001Ooo
ool8o`000003ooooool0003o000000;o00001?ooool3o`0000Oooooo0_l0002;ooooo`007_ooool0
0ol0003oooooooooo`27ooooo`;o00001_ooool5o`0000Cooooo0_l0000;ooooo`;o00000oooool2
o`0000Cooooo0_l00008ooooo`;o0000Roooool001kooooo00?o0000ooooooooool0Qoooool2o`00
00?ooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000;o00003?ooool2o`00
00gooooo0_l0002Aooooo`007_ooool00ol0003oooooooooo`2<ooooo`;o00001oooool4o`0000_o
oooo0_l00007ooooo`;o00001Oooool2o`00097ooooo000Nooooo`03o`000?oooooooooo09Kooooo
0_l0000<ooooo`;o00001oooool2o`0000;ooooo0_l0002Dooooo`007_ooool00ol0003ooooooooo
o`2:ooooo`;o00003Oooool2o`0001Cooooo1_l0002Booooo`000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003ooooo
ooooo`2:ooooo`;o00002Oooool2o`0000;ooooo1?l0000@ooooo`Co00000_ooool2o`0009;ooooo
0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMooooooo
V9RHob4Q8@06ooooo`03o`000?oooooooooo09Gooooo0_l000001?oooooo0000o`000?ooool2o`00
00Wooooo0_l00005ooooo`;o000000Coooooo`000?l0003ooooo0_l0002Booooo`000oooool01Ol@
413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000V?oo
ool2o`0000Kooooo0_l00004ooooo`;o00002?ooool2o`0009Gooooo0003ooooo`05o`000?oooooo
ooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0
X?ooool2o`000:Gooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<00Kooooo00?o0000ooooooooool0X?ooool2o`0000[ooooo0_l0002Iooooo`00
0oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003o
ooooooooo`2Nooooo`;o00000_ooool3o`000003ooooool0003o000000Cooooo0_l0002Iooooo`00
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003o
ooooooooo`2Nooooo`;o00000_ooool6o`0000Cooooo0_l0002Iooooo`000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`2Eoooo
o`;o00001Oooool4o`0000Cooooo0ol00002ooooo`;o0000W?ooool001kooooo00?o0000oooooooo
ool0UOooool2o`0000Gooooo0_l00006ooooo`;o00000oooool2o`0009cooooo000Nooooo`03o`00
0?oooooooooo09[ooooo1?l00006ooooo`;o0000XOooool001kooooo00?o0000ooooooooool0V_oo
ool4o`0000Kooooo0_l0002Qooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3
o`000?ooooooB?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9So
oooooiRHV?lb<S801_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`000?oooooo
ooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0
oooooom8ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo
^[Zjoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`3ooooo
odSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413o
ZJVY00Kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000
oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`005?ooool4o`000003oa0@4?oooooooooo00?ooooo
00?o0000ooooooooool0oooooom8ooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?ooooooB?ooool001Kooooo00?o0000ooooooooool01Oooool3o`000?ooooooB?ooool0
01Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3o
oooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooo
oom@ooooo`005?ooool00omEEEGoIVIVo`00003ooooooe;ooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.54415 .54565 Mdot
.50224 .53472 Mdot
.45277 .45967 Mdot
.48926 .53012 Mdot
.47274 .51673 Mdot
.53269 .47871 Mdot
.46781 .62798 Mdot
.4905 .54182 Mdot
.59594 .54735 Mdot
.48202 .57354 Mdot
.52506 .57305 Mdot
.5217 .49076 Mdot
.52616 .43902 Mdot
.48283 .44243 Mdot
.55761 .60688 Mdot
.45982 .50108 Mdot
.50901 .5438 Mdot
.57326 .47082 Mdot
.5217 .57886 Mdot
.49578 .45329 Mdot
.50827 .54606 Mdot
.46777 .47485 Mdot
.45591 .53454 Mdot
.52614 .45566 Mdot
.50967 .55214 Mdot
.51257 .48508 Mdot
.49046 .57386 Mdot
.5594 .53691 Mdot
.481 .51218 Mdot
.53946 .48883 Mdot
.53476 .44598 Mdot
.50496 .54287 Mdot
.48612 .4895 Mdot
.44029 .45608 Mdot
.53017 .46013 Mdot
.45621 .43487 Mdot
.50049 .484 Mdot
.4375 .50345 Mdot
.46275 .52802 Mdot
.52715 .47937 Mdot
.46215 .49088 Mdot
.48103 .46312 Mdot
.53613 .48447 Mdot
.50315 .50159 Mdot
.50704 .54693 Mdot
.48276 .47706 Mdot
.41579 .46319 Mdot
.53464 .43712 Mdot
.50447 .43426 Mdot
.57062 .44416 Mdot
.46885 .5181 Mdot
.48717 .37609 Mdot
.48445 .51416 Mdot
.46651 .52738 Mdot
.45883 .51828 Mdot
.51217 .47552 Mdot
.53235 .48216 Mdot
.45029 .40063 Mdot
.49647 .53684 Mdot
.53522 .47693 Mdot
.48166 .47154 Mdot
.4899 .48221 Mdot
.45074 .44845 Mdot
.4601 .50206 Mdot
.47379 .50802 Mdot
.61243 .50892 Mdot
.54118 .48451 Mdot
.49598 .47814 Mdot
.52283 .46289 Mdot
.45903 .49934 Mdot
.49596 .62016 Mdot
.48183 .52485 Mdot
.53344 .46862 Mdot
.49566 .51943 Mdot
.53663 .46588 Mdot
.46676 .58266 Mdot
.50908 .466 Mdot
.57696 .46633 Mdot
.47835 .60406 Mdot
.55322 .5444 Mdot
.43533 .48095 Mdot
.49442 .54291 Mdot
.5055 .55131 Mdot
.46757 .48062 Mdot
.4449 .45172 Mdot
.49147 .51737 Mdot
.4375 .51201 Mdot
.49952 .48098 Mdot
.52992 .47706 Mdot
.55977 .41019 Mdot
.48101 .5068 Mdot
.47228 .47509 Mdot
.44245 .5167 Mdot
.59657 .46833 Mdot
.45071 .54913 Mdot
.48108 .46102 Mdot
.5051 .47959 Mdot
.53996 .44911 Mdot
.40688 .47133 Mdot
.52703 .49561 Mdot
.43852 .5212 Mdot
.43727 .50331 Mdot
.48363 .53096 Mdot
.60223 .46181 Mdot
.5858 .5623 Mdot
.48421 .48718 Mdot
.55486 .54845 Mdot
.47551 .5063 Mdot
.53243 .50195 Mdot
.47042 .47507 Mdot
.55618 .49792 Mdot
.48352 .52576 Mdot
.50526 .52052 Mdot
.48577 .55398 Mdot
.54217 .48589 Mdot
.52062 .39141 Mdot
.46603 .53267 Mdot
.55937 .5406 Mdot
.48598 .42849 Mdot
.44508 .51975 Mdot
.57624 .47668 Mdot
.51188 .48823 Mdot
.47457 .56715 Mdot
.5241 .44017 Mdot
.50797 .54022 Mdot
.45476 .55214 Mdot
.55033 .48624 Mdot
.51116 .48712 Mdot
.50516 .49432 Mdot
.45908 .51164 Mdot
.5714 .50898 Mdot
.51416 .53313 Mdot
.42401 .40155 Mdot
.47626 .43822 Mdot
.46376 .52618 Mdot
.41786 .41007 Mdot
.48944 .58641 Mdot
.49239 .5072 Mdot
.52851 .46269 Mdot
.50648 .5116 Mdot
.47771 .5065 Mdot
.53584 .56227 Mdot
.49805 .49082 Mdot
.48489 .52438 Mdot
.48089 .49098 Mdot
.46995 .47405 Mdot
.54038 .54168 Mdot
.48376 .46105 Mdot
.54563 .48015 Mdot
.51827 .44143 Mdot
.46328 .44295 Mdot
.56562 .53161 Mdot
.4762 .5104 Mdot
.54187 .44595 Mdot
.55788 .5301 Mdot
.45965 .50106 Mdot
.48416 .4827 Mdot
.47119 .39742 Mdot
.51032 .46563 Mdot
.4828 .49719 Mdot
.52531 .62633 Mdot
.50804 .4617 Mdot
.57769 .4567 Mdot
.45911 .51627 Mdot
.53103 .4812 Mdot
.51754 .50535 Mdot
.57247 .57282 Mdot
.43588 .48444 Mdot
.47093 .47451 Mdot
.43565 .52007 Mdot
.55297 .53771 Mdot
.52953 .45084 Mdot
.50866 .52968 Mdot
.53214 .47774 Mdot
.53028 .62038 Mdot
.50543 .48132 Mdot
.4742 .45979 Mdot
.48029 .49866 Mdot
.40195 .45838 Mdot
.50531 .44047 Mdot
.48811 .52704 Mdot
.47496 .46178 Mdot
.49513 .5131 Mdot
.48361 .5148 Mdot
.52585 .41924 Mdot
.51849 .49677 Mdot
.43901 .48561 Mdot
.481 .46956 Mdot
.60872 .48131 Mdot
.44687 .53641 Mdot
.50664 .50452 Mdot
.46555 .50987 Mdot
.54077 .46568 Mdot
.47585 .50889 Mdot
.43666 .51053 Mdot
.4646 .49174 Mdot
.55333 .44001 Mdot
.49535 .49474 Mdot
.47373 .50875 Mdot
.49398 .53045 Mdot
.52042 .50574 Mdot
.49588 .47557 Mdot
.5748 .48733 Mdot
.45036 .47968 Mdot
.45966 .52751 Mdot
.51245 .52506 Mdot
.51344 .53618 Mdot
.53246 .48885 Mdot
.43775 .46009 Mdot
.47384 .51131 Mdot
.50797 .54797 Mdot
.50011 .48597 Mdot
.52871 .46893 Mdot
.55807 .47817 Mdot
.51242 .48821 Mdot
.41982 .46301 Mdot
.47642 .47436 Mdot
.51469 .46525 Mdot
.5313 .56084 Mdot
.47953 .50307 Mdot
.46163 .51906 Mdot
.44464 .38787 Mdot
.47192 .47402 Mdot
.454 .42823 Mdot
.49605 .53484 Mdot
.48284 .53281 Mdot
.49886 .53719 Mdot
.48102 .57168 Mdot
.44088 .47169 Mdot
.53018 .5655 Mdot
.46791 .52168 Mdot
.50081 .48695 Mdot
.48778 .55025 Mdot
.48614 .4846 Mdot
.51171 .48077 Mdot
.52858 .46178 Mdot
.45547 .54474 Mdot
.4595 .57886 Mdot
.51532 .52823 Mdot
.51867 .49656 Mdot
.48262 .57328 Mdot
.55043 .61482 Mdot
.54987 .52018 Mdot
.44837 .54335 Mdot
.4384 .55498 Mdot
.45813 .51038 Mdot
.48132 .59731 Mdot
.48092 .5337 Mdot
.46741 .53634 Mdot
.48399 .54877 Mdot
.53598 .48525 Mdot
.52909 .41269 Mdot
.53478 .60466 Mdot
.44561 .55087 Mdot
.50267 .52096 Mdot
.52269 .49459 Mdot
.45133 .5382 Mdot
.52182 .46912 Mdot
.44177 .45558 Mdot
.52989 .57533 Mdot
.43477 .4815 Mdot
.46486 .50251 Mdot
.48298 .49684 Mdot
.56459 .49482 Mdot
.48834 .45018 Mdot
.4565 .44939 Mdot
.50085 .55231 Mdot
.57152 .50454 Mdot
.46833 .48458 Mdot
.39943 .4506 Mdot
.53556 .49393 Mdot
.50576 .52005 Mdot
.60978 .48377 Mdot
.50709 .51547 Mdot
.4445 .48052 Mdot
.48831 .60994 Mdot
.51037 .47142 Mdot
.51071 .58265 Mdot
.50678 .45566 Mdot
.4979 .57803 Mdot
.52626 .46343 Mdot
.51839 .48055 Mdot
.51229 .43935 Mdot
.48999 .49865 Mdot
.44802 .5247 Mdot
.58877 .46276 Mdot
.40883 .46384 Mdot
.45287 .5348 Mdot
.51235 .53109 Mdot
.54936 .44833 Mdot
.52796 .48621 Mdot
.55409 .46507 Mdot
.53374 .39454 Mdot
.53904 .47294 Mdot
.51711 .50609 Mdot
.47059 .52728 Mdot
.56647 .52327 Mdot
.50287 .44317 Mdot
.4612 .46492 Mdot
.48916 .53021 Mdot
.49892 .50281 Mdot
.48269 .53212 Mdot
.60213 .5545 Mdot
.45945 .48266 Mdot
.5248 .48935 Mdot
.48792 .5291 Mdot
.40559 .47246 Mdot
.55605 .48429 Mdot
.51434 .5521 Mdot
.49871 .45079 Mdot
.49268 .52577 Mdot
.48932 .49644 Mdot
.48289 .55904 Mdot
.53433 .55238 Mdot
.49798 .52944 Mdot
.54716 .47485 Mdot
.52663 .47872 Mdot
.49803 .47915 Mdot
.53276 .46854 Mdot
.43653 .50294 Mdot
.51321 .44157 Mdot
.52641 .57093 Mdot
.52104 .56905 Mdot
.50816 .4798 Mdot
.54656 .55024 Mdot
.43634 .51202 Mdot
.50559 .50269 Mdot
.50666 .4934 Mdot
.56687 .55535 Mdot
.43604 .48057 Mdot
.54299 .53141 Mdot
.50597 .38718 Mdot
.50681 .5195 Mdot
.48794 .57629 Mdot
.43921 .4533 Mdot
.46567 .55131 Mdot
.471 .44221 Mdot
.48493 .52678 Mdot
.53091 .55648 Mdot
.49371 .48225 Mdot
.54244 .47807 Mdot
.54904 .48239 Mdot
.42085 .57608 Mdot
.49464 .49097 Mdot
.45029 .49072 Mdot
.53318 .49999 Mdot
.4908 .50027 Mdot
.48035 .5331 Mdot
.43402 .48242 Mdot
.46743 .48057 Mdot
.52993 .48468 Mdot
.43101 .3959 Mdot
.50925 .54655 Mdot
.49295 .48415 Mdot
.55663 .42476 Mdot
.52334 .496 Mdot
.48828 .44905 Mdot
.51834 .52525 Mdot
.54293 .39158 Mdot
.48226 .48682 Mdot
.47304 .51048 Mdot
.55074 .47236 Mdot
.51304 .51173 Mdot
.52104 .44867 Mdot
.52316 .51739 Mdot
.50388 .43888 Mdot
.42749 .51882 Mdot
.43805 .48612 Mdot
.37915 .48705 Mdot
.49126 .51581 Mdot
.48253 .49763 Mdot
.48847 .50652 Mdot
.44041 .38823 Mdot
.51534 .55235 Mdot
.47256 .43449 Mdot
.46569 .55079 Mdot
.52265 .5583 Mdot
.44255 .54042 Mdot
.49 .45944 Mdot
.50427 .4848 Mdot
.4884 .44617 Mdot
.4574 .57447 Mdot
.47992 .52157 Mdot
.47716 .41723 Mdot
.49901 .53724 Mdot
.52562 .51906 Mdot
.5619 .53501 Mdot
.4613 .54588 Mdot
.51511 .47723 Mdot
.49558 .44595 Mdot
.40954 .4368 Mdot
.50638 .45807 Mdot
.51273 .44211 Mdot
.5051 .5431 Mdot
.45801 .53244 Mdot
.49594 .54481 Mdot
.45794 .48839 Mdot
.48717 .49224 Mdot
.54821 .54807 Mdot
.40733 .43557 Mdot
.39793 .45001 Mdot
.48338 .44061 Mdot
.42499 .47877 Mdot
.51944 .48067 Mdot
.51992 .44658 Mdot
.46867 .43385 Mdot
.48358 .51697 Mdot
.48145 .50072 Mdot
.52691 .49961 Mdot
.54734 .54798 Mdot
.50973 .50646 Mdot
.5226 .57576 Mdot
.4946 .51791 Mdot
.53261 .43761 Mdot
.49192 .51379 Mdot
.43846 .51127 Mdot
.46609 .47745 Mdot
.54745 .46461 Mdot
.53975 .4723 Mdot
.47264 .56259 Mdot
.50762 .57716 Mdot
.48582 .47722 Mdot
.49599 .51312 Mdot
.50261 .58114 Mdot
.43579 .44758 Mdot
.46362 .43872 Mdot
.57521 .59528 Mdot
.46582 .48504 Mdot
.52361 .46029 Mdot
.52762 .47062 Mdot
.55854 .46271 Mdot
.45904 .49793 Mdot
.5193 .52898 Mdot
.51603 .57195 Mdot
.46119 .47971 Mdot
.52849 .45432 Mdot
.46654 .47682 Mdot
.53296 .48032 Mdot
.55866 .46998 Mdot
.53198 .47899 Mdot
.53746 .4669 Mdot
.53601 .38859 Mdot
.55059 .45082 Mdot
.55938 .50519 Mdot
.48306 .48695 Mdot
.57054 .50931 Mdot
.47624 .51907 Mdot
.45936 .52165 Mdot
.44127 .45397 Mdot
.48064 .50855 Mdot
.46361 .45292 Mdot
.51525 .502 Mdot
.46359 .48549 Mdot
.53186 .47517 Mdot
.4304 .48352 Mdot
.55952 .55935 Mdot
.46765 .44304 Mdot
.43505 .49781 Mdot
.48527 .5015 Mdot
.52481 .46969 Mdot
.4485 .4745 Mdot
.49707 .52279 Mdot
.52389 .42455 Mdot
.48545 .48501 Mdot
.52412 .44954 Mdot
.42492 .42724 Mdot
.47188 .48206 Mdot
.49878 .51245 Mdot
.55107 .46811 Mdot
.52225 .4669 Mdot
.53024 .56248 Mdot
.47466 .56354 Mdot
.50003 .57416 Mdot
.56502 .56587 Mdot
.5428 .55798 Mdot
.57849 .55477 Mdot
.50274 .42519 Mdot
.56584 .55675 Mdot
.4397 .52726 Mdot
.42467 .40526 Mdot
.49024 .49533 Mdot
.50927 .54691 Mdot
.48835 .5381 Mdot
.49701 .54129 Mdot
.48594 .47664 Mdot
.45443 .47651 Mdot
.49228 .57598 Mdot
.54577 .54163 Mdot
.5237 .44757 Mdot
.44325 .54419 Mdot
.51646 .37511 Mdot
.43979 .46854 Mdot
.60608 .51814 Mdot
.47653 .50374 Mdot
.53504 .48695 Mdot
.55171 .41953 Mdot
.48873 .54915 Mdot
.47799 .50028 Mdot
.46463 .47274 Mdot
.50239 .54074 Mdot
.4515 .56639 Mdot
.54564 .60303 Mdot
.452 .614 Mdot
.46266 .52884 Mdot
.51829 .49834 Mdot
.50876 .58513 Mdot
.53958 .53302 Mdot
.4722 .55361 Mdot
.45041 .54599 Mdot
.57981 .45326 Mdot
.50777 .45816 Mdot
.44954 .44615 Mdot
.53555 .48965 Mdot
.54177 .45127 Mdot
.49089 .53478 Mdot
.46062 .49208 Mdot
.53567 .488 Mdot
.53066 .46416 Mdot
.4759 .44772 Mdot
.53308 .55196 Mdot
.47211 .54577 Mdot
.5364 .49283 Mdot
.5225 .54747 Mdot
.51067 .48368 Mdot
.5205 .49922 Mdot
.50708 .47909 Mdot
.4899 .43687 Mdot
.49502 .3752 Mdot
.5673 .52059 Mdot
.53601 .56431 Mdot
.43722 .46553 Mdot
.46964 .474 Mdot
.51225 .47185 Mdot
.49801 .52274 Mdot
.60991 .48679 Mdot
.51722 .4929 Mdot
.46786 .41441 Mdot
.49219 .47736 Mdot
.5333 .48446 Mdot
.5163 .58393 Mdot
.5041 .51994 Mdot
.57915 .44423 Mdot
.46494 .47651 Mdot
.4944 .43 Mdot
.56942 .52172 Mdot
.49993 .5949 Mdot
.48201 .52106 Mdot
.57255 .42714 Mdot
.48162 .52568 Mdot
.51646 .56828 Mdot
.52925 .47853 Mdot
.46227 .52883 Mdot
.48373 .49065 Mdot
.42339 .55475 Mdot
.48974 .53 Mdot
.46583 .50969 Mdot
.48291 .50448 Mdot
.53078 .45716 Mdot
.52612 .37923 Mdot
.45996 .53338 Mdot
.43787 .49304 Mdot
.43575 .4698 Mdot
.46039 .5336 Mdot
.48774 .51397 Mdot
.47692 .45666 Mdot
.45235 .539 Mdot
.48269 .62576 Mdot
.49454 .57661 Mdot
.47648 .41856 Mdot
.50504 .42883 Mdot
.40186 .44892 Mdot
.50656 .48656 Mdot
.53445 .46215 Mdot
.48016 .52893 Mdot
.5155 .50003 Mdot
.46244 .48946 Mdot
.56982 .42205 Mdot
.52871 .47866 Mdot
.45237 .56658 Mdot
.51957 .48681 Mdot
.44162 .50226 Mdot
.48006 .52344 Mdot
.45961 .58081 Mdot
.52327 .50632 Mdot
.51051 .46217 Mdot
.38045 .49169 Mdot
.46707 .52733 Mdot
.53123 .50178 Mdot
.52879 .50355 Mdot
.44748 .45234 Mdot
.52032 .49582 Mdot
.47659 .47852 Mdot
.47279 .50988 Mdot
.50991 .49827 Mdot
.45943 .52042 Mdot
.5444 .52936 Mdot
.51793 .44296 Mdot
.47269 .4614 Mdot
.57786 .4595 Mdot
.5043 .53213 Mdot
.4475 .48229 Mdot
.4628 .49024 Mdot
.53886 .55572 Mdot
.56304 .44357 Mdot
.4748 .47819 Mdot
.53388 .49585 Mdot
.46199 .52589 Mdot
.45844 .45802 Mdot
.491 .48261 Mdot
.50849 .49365 Mdot
.56755 .52306 Mdot
.5532 .51658 Mdot
.45418 .5374 Mdot
.39336 .48032 Mdot
.54528 .53749 Mdot
.47651 .5129 Mdot
.464 .52603 Mdot
.45905 .52755 Mdot
.47425 .50711 Mdot
.53769 .61684 Mdot
.46986 .62526 Mdot
.47587 .37376 Mdot
.50098 .52425 Mdot
.48527 .4828 Mdot
.42192 .55498 Mdot
.49637 .4486 Mdot
.47813 .50924 Mdot
.4864 .50421 Mdot
.42045 .40995 Mdot
.51164 .53167 Mdot
.48644 .47418 Mdot
.45921 .5117 Mdot
.51275 .43671 Mdot
.57899 .44169 Mdot
.57763 .43762 Mdot
.52704 .55754 Mdot
.45437 .5643 Mdot
.50196 .51113 Mdot
.49031 .53285 Mdot
.41043 .46286 Mdot
.47737 .53314 Mdot
.50939 .46779 Mdot
.42984 .4988 Mdot
.46793 .48321 Mdot
.45954 .51758 Mdot
.5642 .46007 Mdot
.55923 .43395 Mdot
.48153 .48582 Mdot
.45626 .60719 Mdot
.47399 .61309 Mdot
.52266 .54634 Mdot
.48388 .49244 Mdot
.49316 .48738 Mdot
.53203 .50258 Mdot
.51157 .51549 Mdot
.53695 .48183 Mdot
.61347 .5196 Mdot
.50387 .50796 Mdot
.45271 .45811 Mdot
.51144 .49627 Mdot
.48298 .52695 Mdot
.47994 .48749 Mdot
.5137 .44868 Mdot
.44472 .42319 Mdot
.40288 .54823 Mdot
.46009 .44332 Mdot
.43853 .49191 Mdot
.41823 .4818 Mdot
.5556 .50866 Mdot
.59955 .55354 Mdot
.50823 .53517 Mdot
.43621 .41947 Mdot
.39973 .45506 Mdot
.46775 .49305 Mdot
.46069 .51752 Mdot
.49563 .58092 Mdot
.52961 .45973 Mdot
.50612 .54562 Mdot
.57119 .52078 Mdot
.4707 .52851 Mdot
.47531 .4676 Mdot
.43872 .49174 Mdot
.52253 .51627 Mdot
.44382 .4965 Mdot
.50864 .54516 Mdot
.49539 .47344 Mdot
.50709 .5388 Mdot
.53055 .41993 Mdot
.53223 .47024 Mdot
.51544 .4539 Mdot
.49463 .46212 Mdot
.45435 .43707 Mdot
.47109 .37528 Mdot
.51331 .47932 Mdot
.51533 .44623 Mdot
.52545 .5442 Mdot
.50642 .56257 Mdot
.49978 .49945 Mdot
.46844 .47606 Mdot
.48803 .52914 Mdot
.45787 .52824 Mdot
.51789 .4914 Mdot
.5286 .43353 Mdot
.47352 .50828 Mdot
.46209 .45656 Mdot
.49864 .63414 Mdot
.50486 .48058 Mdot
.4711 .51561 Mdot
.43731 .46131 Mdot
.5045 .58205 Mdot
.59929 .51802 Mdot
.5092 .4954 Mdot
.43547 .48413 Mdot
.53186 .57745 Mdot
.54884 .44997 Mdot
.48876 .57491 Mdot
.52316 .5827 Mdot
.52415 .52769 Mdot
.52903 .50509 Mdot
.57251 .51508 Mdot
.49072 .51927 Mdot
.54287 .55298 Mdot
.52575 .45931 Mdot
.4952 .52306 Mdot
.54853 .52195 Mdot
.52706 .49032 Mdot
.56526 .4117 Mdot
.55998 .47016 Mdot
.46763 .41428 Mdot
.4942 .46469 Mdot
.55312 .53473 Mdot
.46531 .48211 Mdot
.52714 .48945 Mdot
.47501 .48219 Mdot
.5107 .37743 Mdot
.47602 .62472 Mdot
.5074 .48097 Mdot
.47182 .46592 Mdot
.51994 .57909 Mdot
.51751 .46736 Mdot
.47976 .4761 Mdot
.51993 .41344 Mdot
.51607 .47963 Mdot
.51268 .54015 Mdot
.47403 .49512 Mdot
.46884 .52294 Mdot
.47691 .50342 Mdot
.49896 .4818 Mdot
.5039 .4937 Mdot
.53259 .55891 Mdot
.48992 .43513 Mdot
.48595 .49957 Mdot
.53276 .47806 Mdot
.47065 .51945 Mdot
.47193 .52725 Mdot
.50327 .43513 Mdot
.53682 .56292 Mdot
.46886 .55693 Mdot
.53629 .45269 Mdot
.50148 .57537 Mdot
.5328 .50651 Mdot
.52712 .5123 Mdot
.56673 .52804 Mdot
.50073 .46047 Mdot
.56565 .41314 Mdot
.49977 .5212 Mdot
.46012 .40954 Mdot
.48259 .52026 Mdot
.50529 .50017 Mdot
.46531 .43145 Mdot
.53737 .52031 Mdot
.53746 .44637 Mdot
.53301 .46526 Mdot
.49041 .51404 Mdot
.44807 .44209 Mdot
.45502 .52739 Mdot
.58838 .57697 Mdot
.52273 .55004 Mdot
.49917 .51557 Mdot
.52494 .4665 Mdot
.46371 .52018 Mdot
.5341 .49773 Mdot
.53341 .48398 Mdot
.52111 .37983 Mdot
.4341 .43191 Mdot
.4922 .61284 Mdot
.5086 .52043 Mdot
.46052 .5007 Mdot
.55438 .53867 Mdot
.48529 .46935 Mdot
.49625 .52962 Mdot
.57341 .48733 Mdot
.49037 .52388 Mdot
.43673 .49791 Mdot
.52999 .50583 Mdot
.44411 .49453 Mdot
.53559 .49013 Mdot
.44326 .55897 Mdot
.45951 .52699 Mdot
.39364 .53593 Mdot
.46429 .50044 Mdot
.5319 .48752 Mdot
.44701 .53993 Mdot
.59262 .53857 Mdot
.54216 .54744 Mdot
.45961 .51167 Mdot
.5299 .48356 Mdot
.50303 .54162 Mdot
.50753 .54917 Mdot
.5799 .48986 Mdot
.48289 .52118 Mdot
.49764 .59209 Mdot
.4882 .52178 Mdot
.5236 .56288 Mdot
.46012 .53237 Mdot
.53651 .48245 Mdot
.48577 .46591 Mdot
.52966 .48789 Mdot
.53091 .54863 Mdot
.52798 .44333 Mdot
.47448 .4832 Mdot
.50158 .52278 Mdot
.49831 .61712 Mdot
.51411 .58176 Mdot
.53559 .54764 Mdot
.54171 .56677 Mdot
.47374 .50882 Mdot
.51536 .52564 Mdot
.52861 .50833 Mdot
.51637 .47917 Mdot
.3957 .54175 Mdot
.54202 .47656 Mdot
.47319 .44343 Mdot
.49065 .47869 Mdot
.49975 .48763 Mdot
.4609 .51716 Mdot
.47736 .46047 Mdot
.55559 .53945 Mdot
.49925 .5257 Mdot
.44039 .51583 Mdot
.54667 .5395 Mdot
.47817 .47571 Mdot
.47878 .46237 Mdot
.52445 .62744 Mdot
.48114 .60983 Mdot
.43064 .47792 Mdot
.60167 .55164 Mdot
.47262 .45877 Mdot
.47981 .47479 Mdot
.53282 .46758 Mdot
.5107 .53638 Mdot
.57044 .44606 Mdot
.4402 .45401 Mdot
.40121 .45872 Mdot
.53166 .61517 Mdot
.51497 .50246 Mdot
.47301 .4835 Mdot
.54843 .45076 Mdot
.49751 .51326 Mdot
.47521 .50765 Mdot
.4327 .47677 Mdot
.51542 .50242 Mdot
.48818 .49593 Mdot
.44498 .50058 Mdot
.56843 .5197 Mdot
.43725 .47245 Mdot
.50989 .52498 Mdot
.57639 .50863 Mdot
.49989 .53219 Mdot
.46372 .38944 Mdot
.57172 .4955 Mdot
.43992 .5168 Mdot
.51416 .42104 Mdot
.54483 .52763 Mdot
.53238 .53323 Mdot
.49122 .51506 Mdot
.46348 .52922 Mdot
.47266 .47618 Mdot
.52927 .47912 Mdot
.49751 .37567 Mdot
.39493 .54418 Mdot
.43938 .38888 Mdot
.54397 .48347 Mdot
.48429 .51101 Mdot
.55233 .40111 Mdot
.49968 .54073 Mdot
.53118 .47077 Mdot
.46151 .49331 Mdot
.45172 .55945 Mdot
.44947 .38863 Mdot
.49658 .46121 Mdot
.49168 .48829 Mdot
.44283 .52091 Mdot
.51583 .57015 Mdot
.47866 .49831 Mdot
.60819 .4818 Mdot
.47701 .51519 Mdot
.53057 .50431 Mdot
.50836 .51627 Mdot
.50676 .52072 Mdot
.54187 .53197 Mdot
.52069 .5053 Mdot
.51514 .52623 Mdot
.49971 .53055 Mdot
.55411 .55259 Mdot
.48977 .51883 Mdot
.44712 .5504 Mdot
.53087 .46419 Mdot
.4702 .52771 Mdot
.55075 .47186 Mdot
.44208 .46055 Mdot
.44069 .48002 Mdot
.51434 .50705 Mdot
.46184 .52962 Mdot
.50561 .54094 Mdot
.522 .48696 Mdot
.43218 .49173 Mdot
.41533 .58719 Mdot
.55566 .49747 Mdot
.44916 .51082 Mdot
.47523 .47971 Mdot
.50244 .49846 Mdot
.48145 .44756 Mdot
.43253 .47612 Mdot
.53585 .59448 Mdot
.49382 .52334 Mdot
.46956 .52624 Mdot
.52527 .48769 Mdot
.61157 .54128 Mdot
.48644 .51706 Mdot
.51144 .51689 Mdot
.46768 .46816 Mdot
.61305 .53288 Mdot
.51379 .53239 Mdot
.49847 .51086 Mdot
.54734 .4376 Mdot
.48789 .48253 Mdot
.38683 .52542 Mdot
.48987 .56186 Mdot
.50129 .61706 Mdot
.48085 .3935 Mdot
.51031 .55113 Mdot
.51488 .44251 Mdot
.49238 .52238 Mdot
.49574 .47178 Mdot
.54875 .52626 Mdot
.544 .46096 Mdot
.53935 .43766 Mdot
.53746 .4675 Mdot
.48995 .42545 Mdot
.55699 .54332 Mdot
.50689 .51348 Mdot
.57418 .43779 Mdot
.51854 .52088 Mdot
.49019 .52722 Mdot
.57175 .50876 Mdot
.4375 .51323 Mdot
.46351 .48185 Mdot
.37812 .51581 Mdot
.54264 .6072 Mdot
.43352 .47086 Mdot
.4927 .51314 Mdot
.47226 .4698 Mdot
.4973 .48651 Mdot
.47567 .48373 Mdot
.53851 .47176 Mdot
.44108 .48545 Mdot
.51719 .5104 Mdot
.46437 .48402 Mdot
.44894 .51023 Mdot
.46433 .45208 Mdot
.55468 .50564 Mdot
.50806 .38144 Mdot
.43803 .48697 Mdot
.38028 .48326 Mdot
.45963 .49336 Mdot
.53144 .561 Mdot
.49418 .51255 Mdot
.51861 .4823 Mdot
.57454 .46879 Mdot
.54814 .39576 Mdot
.4813 .50187 Mdot
.49129 .53832 Mdot
.48223 .52943 Mdot
.55331 .46246 Mdot
.48771 .42854 Mdot
.54497 .52724 Mdot
.50297 .52495 Mdot
.46073 .48175 Mdot
.46452 .55605 Mdot
.54392 .54626 Mdot
.46412 .52543 Mdot
.55331 .48958 Mdot
.49407 .57552 Mdot
.46684 .54857 Mdot
.49374 .47314 Mdot
.45832 .55188 Mdot
.44549 .52251 Mdot
.51632 .632 Mdot
.57102 .42316 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo09Gooooo1?l000001?oooooo0000o`000?ooool3o`00
00Cooooo0_l0002Qooooo`007_ooool00ol0003oooooooooo`2Eooooo`Co000000Coooooo`000?l0
003ooooo0ol00002ooooo`Co000000?oooooo`000?l00000W_ooool001kooooo00?o0000oooooooo
ool0XOooool3o`000003ooooool0003o000000;o0000W_ooool001kooooo00?o0000ooooooooool0
XOooool2o`0000;ooooo0_l0002Pooooo`007_ooool00ol0003oooooooooo`2;ooooo`Go00004?oo
ool2o`0000Sooooo0_l0002Kooooo`007_ooool00ol0003oooooooooo`2;ooooo`Go00000oooool2
o`0000_ooooo0_l00003ooooo`;o00000oooool4o`0009Wooooo0003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooo
oooo09?ooooo0_l00003ooooo`;o00002oooool2o`0000;ooooo0_l000000ooooooo0000o`00002I
ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0R?ooool2o`0000_ooooo0_l000000ooooooo0000o`00000?
ooooo`;o00000oooool2o`0009Oooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool5
o`0000Kooooo0ol00028ooooo`;o00001?ooool2o`0000Gooooo0_l0000Gooooo`?o0000U_ooool0
00?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o
0000ooooooooool0Q_ooool2o`0000Kooooo0_l0000Oooooo`;o0000U_ooool000?ooooo00Go0000
ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0
Q_ooool2o`000;oooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`000007ooooo`03o`000?oooooooooo08Cooooo1?l00009ooooo`;o00007oooool2o`0009?ooooo
0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007ooooo`03o`00
0?oooooooooo08Cooooo0ol0000:ooooo`;o00004_ooool2o`000003ooooool0003o000000Sooooo
1?l0002Aooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool0
1_ooool00ol0003oooooooooo`2Dooooo`;o00003oooool2o`000003ooooool0003o000000[ooooo
0_l0002Aooooo`007_ooool00ol0003oooooooooo`2:ooooo`;o00002?ooool2o`000003ooooool0
003o000000kooooo0_l00006ooooo`;o0000U_ooool001kooooo00?o0000ooooooooool0R_ooool2
o`0000_ooooo0_l0000:ooooo`;o00000_ooool3o`0000Gooooo0_l00004ooooo`;o0000T?ooool0
01kooooo00?o0000ooooooooool0S?ooool2o`0000gooooo0_l00002ooooo`;o00000_ooool2o`00
0003ooooool0003o000000;o00001oooool2o`0000;ooooo0ol0002?ooooo`007_ooool00ol0003o
ooooooooo`26ooooo`;o00001?ooool2o`000003ooooool0003o000000Wooooo0ol00002ooooo`?o
00001?ooool2o`0000Wooooo0_l00003ooooo`;o0000Soooool001kooooo00?o0000ooooooooool0
Q_ooool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o00001Oooool2o`000004oooo
ool0003o0000ooooo`;o00005?ooool2o`0008oooooo000Nooooo`03o`000?oooooooooo08Wooooo
0_l00005ooooo`;o000000?oooooo`000?l000000ol00005ooooo`;o000000?oooooo`000?l00000
1_ooool2o`0000Sooooo0_l0002Cooooo`007_ooool00ol0003oooooooooo`20ooooo`?o00003Ooo
ool2o`0000;ooooo1?l00003ooooo`;o00000oooool2o`000003ooooool0003o000000?ooooo1Ol0
00000ooooooo0000o`000002ooooo`;o00000oooool3o`0008gooooo000Nooooo`03o`000?oooooo
oooo083ooooo0ol0000=ooooo`;o000000?oooooo`000?l000000_ooool6o`0000?ooooo1Ol00000
0ooooooo0000o`000005o`000003ooooool0003o000000;o00001Oooool3o`0008gooooo000Noooo
o`03o`000?oooooooooo08kooooo0_l000000ooooooo0000o`000008o`0000Cooooo2ol00006oooo
o`;o000000?oooooo`000?l000000_l000000ooooooo0000o`00002=ooooo`007_ooool00ol0003o
ooooooooo`2>ooooo`;o000000?oooooo`000?l000001Ol000000ooooooo0000o`000006o`0000;o
oooo1?l000000ooooooo0000o`000004o`0000Gooooo1?l000000ooooooo0000o`00002=ooooo`00
7_ooool00ol0003oooooooooo`1mooooo`Co00002Oooool2o`0000;ooooo1?l00005ooooo`?o0000
00?oooooo`000?l000000_l00004ooooo`Go00000_ooool6o`0000Gooooo0_l0002@ooooo`007_oo
ool2o`0007kooooo1?l00009ooooo`So000000?oooooo`000?l000000_ooool3o`000003ooooool0
003o000000?o00000oooool>o`0000Oooooo0_l0002=ooooo`007_ooool00ol0003oooooooooo`1n
ooooo`;o00002oooool4o`0000?ooooo0ol00008ooooo`?o000000?oooooo`000?l000000_l00002
ooooo`[o00001oooool2o`0008gooooo000Nooooo`03o`000?oooooooooo07kooooo0ol0000:oooo
o`?o000000?oooooo`000?l000000ol00002ooooo`?o00000_ooool2o`0000Cooooo1?l00002oooo
o`?o00003_ooool2o`0008gooooo000Nooooo`03o`000?oooooooooo07kooooo0ol00009ooooo`Co
000000?oooooo`000?l000000_l00003ooooo`ko00000_ooool6o`000004ooooool0003o0000oooo
o`Go00000oooool2o`000003ooooool0003o000000?ooooo0_l00025ooooo`007_ooool00ol0003o
ooooooooo`21ooooo`Go00001?ooool4o`0000Cooooo0_l00002ooooo`Go00000_ooool8o`000003
ooooool0003o000000go00001_ooool2o`0000?ooooo0_l00025ooooo`007_ooool00ol0003ooooo
ooooo`21ooooo`Go00001?ooool3o`0000Gooooo2_l000000ooooooo0000o`000002oooooa7o0000
1Oooool2o`0000Gooooo0_l00027ooooo`007_ooool00ol0003oooooooooo`20ooooo`;o00001ooo
ool4o`0000Oooooo2?l000000ooooooo0000o`000002ooooo`co00000_ooool2o`000003ooooool0
003o000000;ooooo0ol00005ooooo`;o0000Qoooool001kooooo00?o0000ooooooooool0P?ooool2
o`0000Oooooo1?l000000ooooooo0000o`000003ooooo`co00000oooool2o`0000;ooooo1ol00000
1Ooooooo0000o`000?l0003ooooo00;o00000_ooool2o`0008oooooo000Nooooo`03o`000?oooooo
oooo083ooooo0_l00006ooooo`Co00000_ooool4o`000003ooooool0003o000000[o00000oooool3
o`0000?ooooo2ol00004ooooo`;o0000S_ooool001kooooo00?o0000ooooooooool0O?ooool2o`00
00Sooooo:Ol00002ooooo`;o00001?ooool2o`0008kooooo000Nooooo`03o`000?oooooooooo07So
oooo0_l00002ooooo`;o00001_ooool<o`000003ooooool0003o000001Wo000000Goooooo`000?l0
003o0000ooooo`02o`0000oooooo0_l00023ooooo`007_ooool00ol0003oooooooooo`1gooooo`?o
00002_ooool2o`0000;ooooo1ol00002ooooob;o00000oooool3o`0000Wooooo0_l00023ooooo`00
7_ooool00ol0003oooooooooo`1gooooo`;o00004Oooool3o`0000Cooooo1Ol00002oooooaKo0000
00Coooooo`000?l0003o00001?ooool4o`0000Sooooo0_l00023ooooo`007_ooool00ol0003ooooo
ooooo`1hooooo`;o00003_ooool5o`000004ooooool0003o0000ooooo`Go00000_ooool8o`000003
ooooool0003o000000[o00000oooool2o`0000Kooooo0_l0002=ooooo`007_ooool00ol0003ooooo
ooooo`1hooooo`;o00003_ooool8o`000003ooooool0003o000001Wo00001oooool2o`000003oooo
ool0003o000008oooooo000Nooooo`03o`000?oooooooooo08Sooooo1_l00003ooooo`;o00000ooo
oolFo`0000Gooooo1?l000000ooooooo0000o`00002?ooooo`007_ooool2o`0008Wooooo1ol00002
ooooo`Co00000_ooool6o`000003ooooool0003o000000co00001Oooool2o`0009Cooooo000Noooo
o`03o`000?oooooooooo08[ooooo1Ol00002ooooo`Co00000_ooool6o`000003ooooool0003o0000
00Oo000000Coooooo`000?l0003o00001Oooool4o`0000;ooooo0_l0002?ooooo`007_ooool00ol0
003oooooooooo`2:ooooo`;o00002_oooolEo`0000Gooooo1?l00002ooooo`?o00002_ooool2o`00
08;ooooo000Nooooo`03o`000?oooooooooo08[ooooo0_l00002ooooo`;o000000?oooooo`000?l0
00000_l000000ooooooo0000o`00000Co`0000Kooooo0_l00002ooooo`Co00002_ooool2o`0008;o
oooo000Nooooo`03o`000?oooooooooo08[ooooo0_l00002ooooo`;o000000?oooooo`000?l00000
0_l000000ooooooo0000o`00000>o`000003ooooool0003o000000cooooo0ol0002?ooooo`007_oo
ool00ol0003oooooooooo`1gooooo`;o00004Oooool4o`0000?ooooo3ol000001?oooooo0000o`00
0?l00002ooooo`?o00001oooool2o`0000Cooooo0_l00007ooooo`Co0000Q?ooool001kooooo00?o
0000ooooooooool0Moooool2o`0000kooooo0_l000000ooooooo0000o`000003o`0000;ooooo6?l0
0002ooooo`;o00000_ooool3o`0000;ooooo1?l00007ooooo`Ko0000P_ooool001kooooo00?o0000
ooooooooool0Qoooool2o`000003ooooool0003o000000?o00000_oooolBo`000004ooooool0003o
0000ooooo`;o00000_ooool2o`000004ooooool0003o0000o`0000?ooooo1?l0000;ooooo`;o0000
P_ooool001kooooo00?o0000ooooooooool0N_ooool2o`0000oooooo3?l000000ooooooo0000o`00
0007o`000003ooooool0003o000000;o00001oooool3o`0000Cooooo0ol0002@ooooo`007_ooool0
0ol0003oooooooooo`1jooooo`;o00003oooool2o`000003ooooool0003o000000Oo000000?ooooo
o`000?l000003_l00005ooooo`?o000000Coooooo`000?l0003ooooo0_l0002Aooooo`007_ooool0
0ol0003oooooooooo`2AoooooaOo000000?oooooo`000?l000001?l00002ooooo`;o000000?ooooo
o`000?l000003Oooool2o`0008;ooooo000Nooooo`03o`000?oooooooooo07cooooo0_l0000?oooo
o`Wo000000?oooooo`000?l000003?l00004ooooo`Go00000_ooool2o`000004ooooool0003o0000
o`0000gooooo0_l00022ooooo`007_ooool00ol0003oooooooooo`1looooo`;o00003oooool9o`00
00;ooooo0_l000000ooooooo0000o`000008o`0000Sooooo2?l00008ooooo`;o0000R?ooool001ko
oooo00?o0000ooooooooool0OOooool2o`0000gooooo1_l00009ooooo`[o00001oooool8o`0000Wo
oooo0_l00004ooooo`;o0000P_ooool001kooooo00?o0000ooooooooool0O?ooool3o`0000gooooo
1_l00003ooooo`;o00001?ooool:o`0000;ooooo0_l00003ooooo`?o000000?oooooo`000?l00000
0_l0000?ooooo`;o0000P_ooool001kooooo00?o0000ooooooooool0O?ooool2o`000003ooooool0
003o000000_ooooo2ol00002ooooo`;o00000_ooool2o`000004ooooool0003o0000o`0000?ooooo
3Ol0000;ooooo`;o0000Qoooool001kooooo0_l00020ooooo`;o00003?ooool3o`000003ooooool0
003o000000?o00000oooool4o`0000?ooooo1?l00002ooooo`co00003?ooool3o`0008Kooooo000N
ooooo`03o`000?oooooooooo08Gooooo0ol00002ooooo`;o000000?oooooo`000?l000002?l00003
ooooo`?o00000_ooool6o`000004ooooool0003o0000ooooo`Wo00001_ooool2o`0000Gooooo0ol0
0025ooooo`007_ooool00ol0003oooooooooo`25ooooo`?o00000_ooool2o`0000Cooooo0_l00000
0ooooooo0000o`000002o`0000?ooooo0_l00003ooooo`;o000000Coooooo`000?l0003o00000_oo
ool7o`0000;ooooo0_l00002ooooo`;o00000_ooool2o`0000Gooooo0ol00025ooooo`007_ooool0
0ol0003oooooooooo`2<ooooo`;o000000?oooooo`000?l000000_ooool3o`0000?ooooo0_l0000;
ooooo`So00001?ooool4o`00097ooooo000Nooooo`03o`000?oooooooooo08cooooo0_l000001?oo
oooo0000o`000?l00004ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o00000oooool6
o`0000Kooooo0_l00006ooooo`;o0000Roooool001kooooo00?o0000ooooooooool0Soooool3o`00
00Cooooo0_l00003ooooo`;o00001?ooool2o`0000?ooooo2?l00006ooooo`;o00001?ooool2o`00
08_ooooo000Nooooo`03o`000?oooooooooo08oooooo0_l00005ooooo`;o00003?ooool3o`000003
ooooool0003o000000Co00001_ooool2o`00097ooooo000Nooooo`03o`000?oooooooooo09Sooooo
0ol00009ooooo`Go00003Oooool2o`0008oooooo000Nooooo`03o`000?oooooooooo08Gooooo0_l0
000:ooooo`;o00001Oooool9o`0000?ooooo1_l0000<ooooo`;o0000Soooool001kooooo00?o0000
ooooooooool0QOooool2o`0000[ooooo0_l00006ooooo`[o00000_ooool6o`00013ooooo0_l0002:
ooooo`007_ooool00ol0003oooooooooo`2Aooooo`;o000000?oooooo`000?l000001oooool;o`00
0003ooooool0003o0000013ooooo0_l0002:ooooo`007_ooool00ol0003oooooooooo`2Aooooo`;o
000000?oooooo`000?l000001oooool;o`0009oooooo000Nooooo`03o`000?oooooooooo08?ooooo
0_l0000Fooooo`;o00001?ooool2o`000003ooooool0003o00000:7ooooo000Nooooo`03o`000?oo
oooooooo08?ooooo0_l0000Fooooo`;o0000Z_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0
W_ooool2o`0000[ooooo0_l0002Kooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2Hooooo`;o
00001?ooool2o`0000[ooooo0_l0000;ooooo`;o0000S_ooool000?ooooo00Go410@oooooooooooo
oooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`0009Sooooo0_l0000Moooo
o`;o0000S_ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9Sooooo
oiRHV?lQ8B401_ooool00ol0003oooooooooo`2Gooooo`;o00005?ooool2o`0009Sooooo0003oooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o
0000ooooooooool0T?ooool2o`0000Gooooo0_l0000Aooooo`Go00000_ooool2o`0009Cooooo0003
ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo093ooooo0_l00006ooooo`;o000000?oooooo`000?l000003Oooool4o`0000?ooooo0_l0
002Dooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`2Fooooo`Co000000Coooooo`000?l0003o0000ZOooool000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000oooooooo
ool0Soooool2o`0000Gooooo0_l00004ooooo`;o00002oooool2o`0000Cooooo0_l0002Fooooo`00
7_ooool00ol0003oooooooooo`2?ooooo`;o00003Oooool3o`0000Sooooo1?l00002ooooo`;o0000
U_ooool001kooooo00?o0000ooooooooool0WOooool4o`0000Oooooo0_l000000ooooooo0000o`00
002Jooooo`007_ooool00ol0003oooooooooo`2Eooooo`Ko00000_ooool2o`0000Wooooo0_l0002M
ooooo`007_ooool00ol0003oooooooooo`2Dooooo`Oo00002oooool3o`0009kooooo000Nooooo`03
o`000?oooooooooo09Cooooo0_l0000@ooooo`?o0000W_ooool001kooooo00?o0000ooooooooool0
W_ooool2o`0000Cooooo0_l0002Qooooo`007_ooool00ol0003oooooooooo`2Nooooo`;o00001?oo
ool2o`000:7ooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodSooooo
0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?oooooo
V9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooo
oooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool000?o
oooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool0
0ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`000?ooooooooooooooool000002oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool0
1Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2
o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`005?ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooo
oom8ooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB?ooool0
01Kooooo00?o0000ooooooooool01Oooool3o`000?ooooooB?ooool001Kooooo00?o0000oooooooo
ool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oo
oooooooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005?ooool00omE
EEGoIVIVo`00003ooooooe;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.53101 .55987 Mdot
.4838 .53392 Mdot
.46991 .431 Mdot
.47345 .52217 Mdot
.46642 .50185 Mdot
.53284 .51788 Mdot
.45265 .62513 Mdot
.46802 .5295 Mdot
.57475 .56199 Mdot
.45789 .5611 Mdot
.50412 .57371 Mdot
.51798 .50136 Mdot
.53852 .47367 Mdot
.52055 .44321 Mdot
.54304 .62454 Mdot
.46297 .47899 Mdot
.49055 .54977 Mdot
.5727 .50428 Mdot
.49229 .58717 Mdot
.52402 .45625 Mdot
.48969 .55291 Mdot
.48535 .45716 Mdot
.45133 .52287 Mdot
.55263 .4834 Mdot
.48554 .54955 Mdot
.51615 .49375 Mdot
.46458 .55103 Mdot
.53802 .56311 Mdot
.47613 .50165 Mdot
.54487 .52352 Mdot
.54871 .46675 Mdot
.4861 .53862 Mdot
.49271 .49039 Mdot
.45876 .43435 Mdot
.54126 .49737 Mdot
.47888 .42372 Mdot
.50852 .49129 Mdot
.43416 .48289 Mdot
.45971 .51261 Mdot
.52914 .49107 Mdot
.46732 .47535 Mdot
.51149 .46047 Mdot
.53701 .50712 Mdot
.50198 .50634 Mdot
.48883 .54278 Mdot
.4998 .47718 Mdot
.44178 .44496 Mdot
.55175 .45165 Mdot
.53075 .44393 Mdot
.60441 .45962 Mdot
.46754 .50193 Mdot
.5056 .37028 Mdot
.47826 .50509 Mdot
.45781 .51261 Mdot
.45422 .49117 Mdot
.52524 .48346 Mdot
.53191 .50013 Mdot
.45983 .37463 Mdot
.47673 .52543 Mdot
.53888 .49596 Mdot
.50196 .47216 Mdot
.50416 .48464 Mdot
.4761 .43613 Mdot
.46282 .47994 Mdot
.47815 .49324 Mdot
.61307 .52905 Mdot
.53709 .50957 Mdot
.51364 .48182 Mdot
.5407 .46897 Mdot
.46264 .47759 Mdot
.47615 .61342 Mdot
.46686 .51187 Mdot
.54294 .48514 Mdot
.48757 .51615 Mdot
.55368 .49866 Mdot
.44932 .5597 Mdot
.52854 .47028 Mdot
.58055 .49659 Mdot
.462 .58666 Mdot
.52719 .56341 Mdot
.44384 .46162 Mdot
.47003 .53139 Mdot
.48566 .55133 Mdot
.4785 .47345 Mdot
.46751 .43559 Mdot
.48402 .51179 Mdot
.44223 .47801 Mdot
.51429 .48521 Mdot
.53252 .48983 Mdot
.58442 .42074 Mdot
.48106 .49748 Mdot
.48778 .46958 Mdot
.44488 .4839 Mdot
.62005 .48655 Mdot
.45109 .51057 Mdot
.50141 .45888 Mdot
.51963 .48498 Mdot
.55042 .4711 Mdot
.42817 .45003 Mdot
.52006 .51184 Mdot
.44122 .48691 Mdot
.44406 .47251 Mdot
.46625 .51646 Mdot
.61105 .48343 Mdot
.56119 .57148 Mdot
.4919 .4891 Mdot
.50528 .56529 Mdot
.478 .49357 Mdot
.52368 .52347 Mdot
.48561 .46835 Mdot
.55954 .52243 Mdot
.46773 .51324 Mdot
.49382 .52507 Mdot
.44981 .54444 Mdot
.53391 .5102 Mdot
.53797 .40381 Mdot
.43996 .50616 Mdot
.53955 .56721 Mdot
.5113 .4169 Mdot
.44517 .4864 Mdot
.5736 .50534 Mdot
.51309 .49635 Mdot
.45348 .54959 Mdot
.54533 .45695 Mdot
.48997 .54448 Mdot
.43156 .53701 Mdot
.56097 .51357 Mdot
.51353 .49533 Mdot
.5056 .50055 Mdot
.45657 .48806 Mdot
.55997 .53814 Mdot
.49574 .54603 Mdot
.43717 .38489 Mdot
.50432 .43742 Mdot
.44633 .51672 Mdot
.43119 .39247 Mdot
.46785 .59399 Mdot
.49188 .50481 Mdot
.54321 .4751 Mdot
.49912 .51716 Mdot
.47905 .49499 Mdot
.49819 .55873 Mdot
.50134 .49625 Mdot
.47212 .51449 Mdot
.4892 .48601 Mdot
.48562 .46761 Mdot
.52993 .55998 Mdot
.50683 .45484 Mdot
.53936 .50452 Mdot
.54233 .45696 Mdot
.49012 .43694 Mdot
.54697 .55935 Mdot
.47421 .49704 Mdot
.56706 .45956 Mdot
.54015 .55643 Mdot
.46276 .47889 Mdot
.49809 .48392 Mdot
.49386 .40331 Mdot
.52962 .46992 Mdot
.4888 .4896 Mdot
.50542 .63465 Mdot
.53119 .46379 Mdot
.58394 .48263 Mdot
.45141 .48936 Mdot
.5322 .49642 Mdot
.50805 .51729 Mdot
.54562 .57735 Mdot
.45373 .47153 Mdot
.49854 .46214 Mdot
.42969 .50207 Mdot
.53047 .5632 Mdot
.54932 .47043 Mdot
.49102 .53516 Mdot
.53597 .49255 Mdot
.51347 .63805 Mdot
.51602 .48796 Mdot
.49102 .45209 Mdot
.48668 .48873 Mdot
.42336 .44368 Mdot
.53255 .44934 Mdot
.47399 .51879 Mdot
.49219 .45866 Mdot
.49053 .51182 Mdot
.47697 .50502 Mdot
.53968 .44692 Mdot
.5127 .50669 Mdot
.44835 .45213 Mdot
.50141 .47078 Mdot
.62199 .50067 Mdot
.44175 .50316 Mdot
.50246 .5108 Mdot
.46634 .48746 Mdot
.56316 .49176 Mdot
.47554 .49565 Mdot
.43328 .49148 Mdot
.46874 .47655 Mdot
.59269 .45348 Mdot
.49858 .49791 Mdot
.48087 .49293 Mdot
.47781 .52558 Mdot
.50892 .51973 Mdot
.51521 .47977 Mdot
.56845 .51686 Mdot
.47821 .46895 Mdot
.45292 .49979 Mdot
.49573 .53312 Mdot
.4935 .54875 Mdot
.52908 .507 Mdot
.45226 .4342 Mdot
.47298 .49682 Mdot
.48989 .54553 Mdot
.50616 .49311 Mdot
.53767 .47927 Mdot
.54862 .50915 Mdot
.51348 .49641 Mdot
.44837 .44661 Mdot
.49364 .47178 Mdot
.53235 .47052 Mdot
.49281 .55655 Mdot
.4829 .49241 Mdot
.46495 .49872 Mdot
.45649 .37077 Mdot
.48816 .46853 Mdot
.4877 .42778 Mdot
.46538 .52221 Mdot
.45829 .52174 Mdot
.47917 .52899 Mdot
.45703 .55691 Mdot
.45317 .44194 Mdot
.49902 .56771 Mdot
.45811 .49128 Mdot
.50578 .49409 Mdot
.45092 .53813 Mdot
.49789 .48723 Mdot
.51952 .48986 Mdot
.5438 .47459 Mdot
.42991 .52942 Mdot
.44336 .55425 Mdot
.49801 .54001 Mdot
.51291 .50653 Mdot
.4581 .56 Mdot
.53326 .62868 Mdot
.54528 .54483 Mdot
.42885 .52639 Mdot
.44232 .52082 Mdot
.45628 .48504 Mdot
.4605 .58132 Mdot
.45874 .52144 Mdot
.45152 .5085 Mdot
.452 .5251 Mdot
.53588 .50671 Mdot
.5427 .43694 Mdot
.51047 .60212 Mdot
.4485 .51358 Mdot
.49227 .52326 Mdot
.51641 .50694 Mdot
.44204 .5251 Mdot
.53383 .4776 Mdot
.4622 .43625 Mdot
.49627 .56514 Mdot
.45289 .46913 Mdot
.46595 .48235 Mdot
.48916 .48954 Mdot
.5542 .52539 Mdot
.51784 .45209 Mdot
.48333 .4393 Mdot
.46799 .54573 Mdot
.56144 .53721 Mdot
.47529 .47571 Mdot
.41794 .43579 Mdot
.53044 .51802 Mdot
.49442 .52495 Mdot
.62191 .5028 Mdot
.49792 .52074 Mdot
.45585 .44695 Mdot
.46676 .5995 Mdot
.52697 .47776 Mdot
.48219 .58584 Mdot
.53269 .46124 Mdot
.4711 .57352 Mdot
.54251 .47324 Mdot
.52415 .49031 Mdot
.54428 .44192 Mdot
.49467 .49649 Mdot
.4294 .5036 Mdot
.61497 .48116 Mdot
.43353 .44754 Mdot
.44968 .52068 Mdot
.49487 .54017 Mdot
.5709 .46314 Mdot
.52524 .50035 Mdot
.56051 .48698 Mdot
.54991 .40829 Mdot
.5465 .49567 Mdot
.50746 .51787 Mdot
.45792 .51258 Mdot
.54919 .55309 Mdot
.53096 .45101 Mdot
.49072 .45751 Mdot
.47283 .52168 Mdot
.49916 .50503 Mdot
.45784 .5212 Mdot
.58519 .56894 Mdot
.46847 .46761 Mdot
.52074 .50158 Mdot
.47233 .52042 Mdot
.39729 .43976 Mdot
.55537 .50668 Mdot
.48966 .55096 Mdot
.52762 .45601 Mdot
.47998 .52003 Mdot
.49452 .49514 Mdot
.45488 .54818 Mdot
.51145 .55402 Mdot
.48144 .52758 Mdot
.53971 .49859 Mdot
.52932 .49012 Mdot
.51449 .48308 Mdot
.54284 .48389 Mdot
.43678 .48386 Mdot
.53885 .45398 Mdot
.50827 .5716 Mdot
.50565 .57524 Mdot
.51953 .48708 Mdot
.52147 .57164 Mdot
.441 .49323 Mdot
.50271 .50854 Mdot
.50695 .50017 Mdot
.53635 .56797 Mdot
.44655 .45509 Mdot
.53619 .55463 Mdot
.52538 .39524 Mdot
.49532 .52519 Mdot
.46257 .56688 Mdot
.45537 .43037 Mdot
.45027 .53049 Mdot
.49898 .43989 Mdot
.46941 .51611 Mdot
.50836 .55116 Mdot
.50772 .48539 Mdot
.54142 .50386 Mdot
.53875 .504 Mdot
.39286 .56711 Mdot
.49877 .49517 Mdot
.47057 .47156 Mdot
.5209 .52267 Mdot
.49482 .49809 Mdot
.4616 .51894 Mdot
.4504 .46942 Mdot
.47833 .47319 Mdot
.52815 .50118 Mdot
.44489 .38042 Mdot
.49058 .55002 Mdot
.50344 .48892 Mdot
.56685 .44796 Mdot
.51659 .51015 Mdot
.52809 .45215 Mdot
.50081 .5403 Mdot
.564 .39802 Mdot
.49028 .48777 Mdot
.47852 .49435 Mdot
.54497 .4949 Mdot
.50268 .52116 Mdot
.55491 .45982 Mdot
.5073 .53547 Mdot
.53657 .43705 Mdot
.4444 .48472 Mdot
.45677 .47263 Mdot
.37457 .46527 Mdot
.48478 .51057 Mdot
.48834 .48966 Mdot
.48877 .50186 Mdot
.45451 .37449 Mdot
.48521 .54335 Mdot
.49614 .41911 Mdot
.44947 .5273 Mdot
.49044 .555 Mdot
.43805 .50711 Mdot
.51918 .45848 Mdot
.5102 .49273 Mdot
.51782 .44988 Mdot
.45 .54315 Mdot
.46928 .50999 Mdot
.50825 .42583 Mdot
.47907 .5281 Mdot
.51598 .55059 Mdot
.54161 .56182 Mdot
.44823 .52512 Mdot
.52597 .48614 Mdot
.52459 .45174 Mdot
.41141 .40888 Mdot
.53196 .46105 Mdot
.53853 .45362 Mdot
.48615 .53844 Mdot
.45758 .51779 Mdot
.47421 .53351 Mdot
.46149 .46952 Mdot
.49346 .49152 Mdot
.5235 .57044 Mdot
.41221 .41009 Mdot
.3995 .42396 Mdot
.51212 .44269 Mdot
.41317 .44001 Mdot
.52454 .49065 Mdot
.54417 .46007 Mdot
.49462 .42903 Mdot
.47563 .5068 Mdot
.48588 .49129 Mdot
.51735 .51567 Mdot
.52056 .56719 Mdot
.50333 .51383 Mdot
.4937 .58518 Mdot
.48742 .5144 Mdot
.55031 .45247 Mdot
.48684 .50975 Mdot
.44321 .4792 Mdot
.47928 .4672 Mdot
.56729 .4886 Mdot
.54749 .49253 Mdot
.4518 .54325 Mdot
.47902 .58056 Mdot
.50345 .47813 Mdot
.49124 .51261 Mdot
.47499 .57805 Mdot
.43667 .40843 Mdot
.48962 .43288 Mdot
.55812 .6063 Mdot
.47247 .47492 Mdot
.54343 .4705 Mdot
.5357 .48103 Mdot
.5672 .48113 Mdot
.46315 .47667 Mdot
.49818 .54416 Mdot
.48588 .5792 Mdot
.48903 .46695 Mdot
.55525 .48023 Mdot
.49383 .46335 Mdot
.53381 .49842 Mdot
.56394 .48946 Mdot
.53509 .49423 Mdot
.54805 .49011 Mdot
.56347 .38573 Mdot
.56682 .46894 Mdot
.54556 .53572 Mdot
.49111 .48845 Mdot
.55804 .53992 Mdot
.4668 .50599 Mdot
.45432 .49461 Mdot
.45945 .43225 Mdot
.47905 .49853 Mdot
.498 .43845 Mdot
.50853 .51119 Mdot
.47129 .47317 Mdot
.53631 .48925 Mdot
.44445 .45664 Mdot
.526 .56704 Mdot
.4953 .43916 Mdot
.43531 .47854 Mdot
.48881 .49492 Mdot
.53465 .47927 Mdot
.47646 .46424 Mdot
.48682 .51984 Mdot
.54584 .43202 Mdot
.49648 .48761 Mdot
.5469 .4665 Mdot
.44935 .41795 Mdot
.48274 .47949 Mdot
.4935 .51421 Mdot
.55468 .49118 Mdot
.53555 .47455 Mdot
.5158 .56459 Mdot
.45402 .54636 Mdot
.46306 .59799 Mdot
.56078 .6002 Mdot
.5156 .57692 Mdot
.55011 .5656 Mdot
.52767 .43108 Mdot
.56449 .59385 Mdot
.44053 .49283 Mdot
.44068 .39116 Mdot
.49525 .49521 Mdot
.49059 .54948 Mdot
.4643 .52629 Mdot
.4773 .52937 Mdot
.50421 .47759 Mdot
.48377 .46644 Mdot
.466 .56732 Mdot
.53432 .55842 Mdot
.54648 .46498 Mdot
.43757 .51134 Mdot
.53695 .36983 Mdot
.45276 .44004 Mdot
.59613 .53906 Mdot
.48335 .48989 Mdot
.53302 .50638 Mdot
.56257 .44221 Mdot
.45278 .53253 Mdot
.48583 .48808 Mdot
.49521 .46512 Mdot
.47353 .53172 Mdot
.41145 .55926 Mdot
.52178 .60361 Mdot
.42764 .62024 Mdot
.45599 .50386 Mdot
.51183 .50836 Mdot
.48152 .58314 Mdot
.5224 .54869 Mdot
.45172 .53174 Mdot
.4443 .5097 Mdot
.61008 .47074 Mdot
.53294 .46142 Mdot
.47379 .4332 Mdot
.53284 .51008 Mdot
.54415 .48687 Mdot
.4632 .52447 Mdot
.46667 .4731 Mdot
.53377 .50845 Mdot
.54019 .50188 Mdot
.51137 .43819 Mdot
.50952 .55047 Mdot
.45235 .51945 Mdot
.53082 .51738 Mdot
.49465 .54425 Mdot
.51614 .49244 Mdot
.51262 .51166 Mdot
.52119 .48495 Mdot
.51782 .4405 Mdot
.51413 .36982 Mdot
.55015 .54891 Mdot
.50786 .58104 Mdot
.45906 .44745 Mdot
.48526 .46747 Mdot
.52811 .47873 Mdot
.48767 .52058 Mdot
.61811 .50732 Mdot
.51399 .50221 Mdot
.49705 .4228 Mdot
.51055 .48021 Mdot
.53217 .50294 Mdot
.48737 .58845 Mdot
.49375 .52343 Mdot
.59251 .46699 Mdot
.47834 .46661 Mdot
.52613 .44727 Mdot
.55393 .54827 Mdot
.47587 .57984 Mdot
.47169 .51005 Mdot
.59237 .44578 Mdot
.4662 .51178 Mdot
.48487 .57376 Mdot
.53091 .4914 Mdot
.45112 .51752 Mdot
.4912 .48826 Mdot
.39032 .54491 Mdot
.4716 .51886 Mdot
.47101 .48983 Mdot
.48485 .49652 Mdot
.54964 .47365 Mdot
.5466 .37913 Mdot
.44469 .50071 Mdot
.44655 .46389 Mdot
.451 .44311 Mdot
.45074 .50687 Mdot
.48222 .50715 Mdot
.50746 .45333 Mdot
.44165 .5257 Mdot
.46277 .6406 Mdot
.46821 .57163 Mdot
.50754 .42847 Mdot
.53011 .43712 Mdot
.4213 .43483 Mdot
.51052 .4944 Mdot
.54983 .48061 Mdot
.46395 .51399 Mdot
.50942 .50916 Mdot
.46911 .47295 Mdot
.59107 .43848 Mdot
.53036 .49115 Mdot
.43933 .53791 Mdot
.5192 .49639 Mdot
.44861 .46547 Mdot
.46654 .51067 Mdot
.42031 .58045 Mdot
.51107 .5205 Mdot
.53208 .46493 Mdot
.38845 .47075 Mdot
.44861 .51689 Mdot
.52078 .52429 Mdot
.51282 .52561 Mdot
.47239 .43894 Mdot
.51424 .5064 Mdot
.49197 .47604 Mdot
.48063 .49357 Mdot
.50714 .50565 Mdot
.45409 .49389 Mdot
.5377 .55277 Mdot
.54803 .46511 Mdot
.48657 .45314 Mdot
.58296 .48597 Mdot
.48638 .53369 Mdot
.47243 .47075 Mdot
.46358 .46844 Mdot
.52199 .56103 Mdot
.56762 .47072 Mdot
.48999 .47484 Mdot
.52821 .51856 Mdot
.45407 .50004 Mdot
.48741 .43361 Mdot
.50478 .4853 Mdot
.50809 .5008 Mdot
.55401 .55517 Mdot
.54656 .53866 Mdot
.44286 .52661 Mdot
.40849 .45834 Mdot
.53453 .55607 Mdot
.47209 .49999 Mdot
.46472 .50941 Mdot
.45064 .49989 Mdot
.4785 .4928 Mdot
.52028 .63392 Mdot
.45476 .62012 Mdot
.49244 .36062 Mdot
.48862 .52491 Mdot
.49912 .48441 Mdot
.4271 .52544 Mdot
.52564 .45418 Mdot
.47663 .4973 Mdot
.48845 .49831 Mdot
.43508 .39306 Mdot
.49411 .53963 Mdot
.50617 .47596 Mdot
.45788 .48638 Mdot
.53752 .44997 Mdot
.59419 .46421 Mdot
.59395 .45847 Mdot
.50342 .5509 Mdot
.44114 .53481 Mdot
.49629 .51481 Mdot
.47127 .51949 Mdot
.43583 .44693 Mdot
.45771 .51986 Mdot
.52792 .47279 Mdot
.45273 .46574 Mdot
.47589 .47586 Mdot
.45408 .49239 Mdot
.56244 .48886 Mdot
.56626 .45945 Mdot
.49162 .48707 Mdot
.44623 .59045 Mdot
.45936 .59933 Mdot
.49437 .54175 Mdot
.49125 .48905 Mdot
.49933 .49254 Mdot
.52314 .5239 Mdot
.49922 .52474 Mdot
.5392 .50409 Mdot
.61405 .53938 Mdot
.49903 .51296 Mdot
.48066 .44695 Mdot
.50889 .50414 Mdot
.4667 .51304 Mdot
.48827 .48461 Mdot
.54937 .45943 Mdot
.45068 .38953 Mdot
.38129 .53249 Mdot
.48634 .43566 Mdot
.45333 .47618 Mdot
.40589 .44484 Mdot
.55495 .5334 Mdot
.60137 .57827 Mdot
.48991 .53918 Mdot
.44258 .38877 Mdot
.39842 .42648 Mdot
.46582 .46788 Mdot
.45559 .49271 Mdot
.47124 .56923 Mdot
.54575 .47421 Mdot
.48747 .54012 Mdot
.55549 .55081 Mdot
.45665 .51421 Mdot
.49416 .46659 Mdot
.44762 .46302 Mdot
.50844 .53153 Mdot
.44961 .46709 Mdot
.49031 .54686 Mdot
.51557 .47768 Mdot
.489 .54306 Mdot
.54308 .44741 Mdot
.53938 .4835 Mdot
.53919 .46328 Mdot
.51699 .4629 Mdot
.47512 .42208 Mdot
.48714 .36285 Mdot
.5223 .48818 Mdot
.5409 .45798 Mdot
.50296 .55486 Mdot
.45591 .56902 Mdot
.50029 .50305 Mdot
.48254 .46787 Mdot
.47164 .51986 Mdot
.44763 .51901 Mdot
.51522 .50081 Mdot
.55508 .4403 Mdot
.47759 .49354 Mdot
.4879 .43077 Mdot
.48138 .63599 Mdot
.5182 .48631 Mdot
.46937 .49989 Mdot
.45613 .43989 Mdot
.47677 .58004 Mdot
.58472 .54028 Mdot
.50792 .50263 Mdot
.44846 .45415 Mdot
.50747 .59321 Mdot
.57209 .46436 Mdot
.46374 .55189 Mdot
.49813 .59599 Mdot
.50183 .54283 Mdot
.52424 .53988 Mdot
.55852 .5463 Mdot
.48193 .51269 Mdot
.51565 .57131 Mdot
.54475 .47122 Mdot
.48474 .51886 Mdot
.53654 .54144 Mdot
.52226 .5064 Mdot
.58751 .4255 Mdot
.55329 .50053 Mdot
.49682 .4225 Mdot
.51604 .46653 Mdot
.53425 .56024 Mdot
.47479 .47186 Mdot
.5228 .50485 Mdot
.48776 .48088 Mdot
.52944 .37926 Mdot
.4604 .61834 Mdot
.51629 .48913 Mdot
.48783 .45198 Mdot
.49092 .58659 Mdot
.53275 .47433 Mdot
.49672 .47507 Mdot
.53785 .43667 Mdot
.52382 .48895 Mdot
.48217 .53324 Mdot
.48248 .48157 Mdot
.4631 .50683 Mdot
.48317 .48991 Mdot
.51311 .48593 Mdot
.50487 .49977 Mdot
.52176 .56936 Mdot
.51766 .4389 Mdot
.49059 .49396 Mdot
.53549 .49558 Mdot
.46529 .50361 Mdot
.46296 .49492 Mdot
.53723 .44951 Mdot
.49949 .55927 Mdot
.45055 .53558 Mdot
.54795 .47548 Mdot
.47288 .57586 Mdot
.53165 .54023 Mdot
.51868 .54556 Mdot
.57221 .56953 Mdot
.52692 .46178 Mdot
.58833 .42686 Mdot
.49003 .52076 Mdot
.48826 .41089 Mdot
.47266 .5094 Mdot
.50368 .50588 Mdot
.48938 .42303 Mdot
.51916 .54926 Mdot
.54915 .46783 Mdot
.54451 .50179 Mdot
.48503 .50881 Mdot
.4685 .42648 Mdot
.44488 .49355 Mdot
.58276 .59975 Mdot
.49626 .5485 Mdot
.49227 .51652 Mdot
.53765 .47479 Mdot
.45875 .49461 Mdot
.52313 .52095 Mdot
.53886 .52165 Mdot
.54591 .37152 Mdot
.43829 .39741 Mdot
.47038 .60442 Mdot
.49408 .52817 Mdot
.4625 .48106 Mdot
.53225 .56448 Mdot
.51401 .46371 Mdot
.47992 .52672 Mdot
.56702 .51807 Mdot
.4784 .51662 Mdot
.43594 .47763 Mdot
.52046 .52617 Mdot
.46066 .47625 Mdot
.53237 .51461 Mdot
.40377 .55178 Mdot
.45232 .49985 Mdot
.39237 .51381 Mdot
.46591 .48121 Mdot
.52894 .50547 Mdot
.4425 .50399 Mdot
.60231 .56871 Mdot
.52754 .56024 Mdot
.4578 .48711 Mdot
.52919 .49886 Mdot
.47453 .53263 Mdot
.48915 .54833 Mdot
.57828 .5233 Mdot
.4724 .5104 Mdot
.47354 .57578 Mdot
.47693 .51326 Mdot
.51278 .57412 Mdot
.45092 .5055 Mdot
.53849 .50512 Mdot
.50672 .46753 Mdot
.5259 .50497 Mdot
.50918 .556 Mdot
.5472 .46207 Mdot
.48561 .48193 Mdot
.49033 .52393 Mdot
.47626 .61206 Mdot
.48534 .58637 Mdot
.51518 .55629 Mdot
.51779 .58694 Mdot
.47893 .49339 Mdot
.49847 .5378 Mdot
.51799 .52756 Mdot
.5245 .48846 Mdot
.37773 .52501 Mdot
.54214 .50284 Mdot
.50082 .42401 Mdot
.50761 .48093 Mdot
.50437 .4945 Mdot
.45598 .49241 Mdot
.50819 .45703 Mdot
.53105 .56055 Mdot
.48625 .52475 Mdot
.42907 .4955 Mdot
.53478 .5565 Mdot
.495 .47405 Mdot
.49824 .46117 Mdot
.50621 .63903 Mdot
.46502 .59481 Mdot
.44642 .45278 Mdot
.60368 .57572 Mdot
.50339 .45403 Mdot
.4978 .47397 Mdot
.5433 .48351 Mdot
.49291 .54401 Mdot
.5765 .47101 Mdot
.47363 .44237 Mdot
.39835 .42884 Mdot
.51588 .63685 Mdot
.50819 .51158 Mdot
.48149 .47975 Mdot
.54892 .48418 Mdot
.49227 .51386 Mdot
.47644 .49454 Mdot
.44794 .45007 Mdot
.50848 .51171 Mdot
.49385 .49393 Mdot
.44829 .47059 Mdot
.55371 .55056 Mdot
.45168 .44434 Mdot
.4933 .53161 Mdot
.568 .54113 Mdot
.48188 .53057 Mdot
.47686 .36528 Mdot
.56253 .52731 Mdot
.42872 .49685 Mdot
.53777 .42352 Mdot
.53888 .55172 Mdot
.51182 .54765 Mdot
.48521 .51006 Mdot
.45529 .51528 Mdot
.48783 .47113 Mdot
.53067 .49216 Mdot
.51672 .37182 Mdot
.37869 .52677 Mdot
.45359 .37524 Mdot
.5378 .50799 Mdot
.48031 .50294 Mdot
.57982 .40712 Mdot
.47993 .52981 Mdot
.53815 .48305 Mdot
.46706 .47488 Mdot
.44034 .52777 Mdot
.46711 .3817 Mdot
.5194 .46191 Mdot
.4973 .49281 Mdot
.44378 .48432 Mdot
.48525 .57704 Mdot
.48676 .48708 Mdot
.61749 .50308 Mdot
.47069 .50277 Mdot
.52181 .52416 Mdot
.49826 .52248 Mdot
.49417 .52656 Mdot
.52262 .55865 Mdot
.50938 .5194 Mdot
.49677 .54274 Mdot
.4823 .52921 Mdot
.52037 .56733 Mdot
.48101 .51174 Mdot
.43892 .51713 Mdot
.54357 .47795 Mdot
.45737 .51322 Mdot
.54867 .4954 Mdot
.46617 .44441 Mdot
.46376 .46945 Mdot
.50582 .51621 Mdot
.46128 .51392 Mdot
.48703 .54119 Mdot
.52055 .49728 Mdot
.44202 .463 Mdot
.39996 .57517 Mdot
.5603 .52282 Mdot
.43884 .48326 Mdot
.48979 .47715 Mdot
.50247 .50328 Mdot
.5209 .44872 Mdot
.44798 .45169 Mdot
.50846 .58951 Mdot
.48301 .51832 Mdot
.45897 .51119 Mdot
.52205 .49994 Mdot
.61074 .56122 Mdot
.47831 .50817 Mdot
.49775 .52641 Mdot
.4983 .46213 Mdot
.60246 .55089 Mdot
.49628 .54258 Mdot
.49407 .51286 Mdot
.58837 .4499 Mdot
.50182 .48471 Mdot
.37828 .50583 Mdot
.46065 .53776 Mdot
.47903 .6127 Mdot
.50207 .4015 Mdot
.4853 .54793 Mdot
.54022 .45654 Mdot
.48196 .51633 Mdot
.51637 .47579 Mdot
.54059 .54818 Mdot
.55097 .48474 Mdot
.55682 .4514 Mdot
.54886 .48676 Mdot
.52191 .43912 Mdot
.5347 .56779 Mdot
.49863 .51892 Mdot
.5872 .46194 Mdot
.50241 .53556 Mdot
.47607 .52006 Mdot
.56103 .54123 Mdot
.44201 .48078 Mdot
.47383 .46805 Mdot
.37119 .49722 Mdot
.52758 .63049 Mdot
.44916 .45524 Mdot
.48807 .50994 Mdot
.48535 .4536 Mdot
.50344 .49285 Mdot
.48667 .4828 Mdot
.54663 .49533 Mdot
.45067 .45132 Mdot
.50429 .52283 Mdot
.47297 .47189 Mdot
.44626 .47906 Mdot
.49301 .44547 Mdot
.54942 .52768 Mdot
.52704 .38593 Mdot
.45597 .47296 Mdot
.37649 .46105 Mdot
.46521 .47369 Mdot
.48149 .57428 Mdot
.48992 .51069 Mdot
.52263 .49206 Mdot
.57579 .50095 Mdot
.57427 .39954 Mdot
.48509 .49244 Mdot
.4718 .52497 Mdot
.45614 .51911 Mdot
.56201 .48388 Mdot
.51332 .4171 Mdot
.53011 .54481 Mdot
.48892 .5279 Mdot
.47078 .46762 Mdot
.44719 .53865 Mdot
.5307 .56022 Mdot
.46582 .50865 Mdot
.54634 .51148 Mdot
.46791 .56809 Mdot
.44981 .52481 Mdot
.51416 .47711 Mdot
.44494 .51873 Mdot
.45121 .48363 Mdot
.49769 .63962 Mdot
.59162 .44057 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0W?ooool2o`000:Wo
oooo000Nooooo`03o`000?oooooooooo09[ooooo1?l0002Yooooo`007_ooool00ol0003ooooooooo
o`2Gooooo`;o000000?oooooo`000?l00000Zoooool001kooooo00?o0000ooooooooool0Uoooool2
o`0000Oooooo0_l000000ooooooo0000o`000005ooooo`;o0000Voooool001kooooo00?o0000oooo
ooooool0T?ooool2o`0000kooooo0_l000001?oooooo0000o`000?l00004ooooo`;o000000?ooooo
o`000?l00000V?ooool001kooooo00?o0000ooooooooool0Soooool4o`00017ooooo0_l00007oooo
o`;o0000V?ooool001kooooo00?o0000ooooooooool0Soooool4o`0001Gooooo0_l00004ooooo`;o
0000Uoooool001kooooo00?o0000ooooooooool0SOooool2o`0000Gooooo0_l0000Booooo`;o0000
1?ooool2o`0009Oooooo000Nooooo`03o`000?oooooooooo08[ooooo0_l000000ooooooo0000o`00
0005ooooo`;o00007Oooool2o`0009;ooooo000Nooooo`03o`000?oooooooooo08[ooooo1?l0000I
ooooo`;o00002_ooool2o`0009;ooooo000Nooooo`03o`000?oooooooooo08_ooooo1Ol0000Goooo
o`;o0000W_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`00
0003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0R?ooool5o`000003ooooool0003o0000
0;Oooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`28ooooo`Co00006oooool2o`0000[ooooo0_l0002Boooo
o`000oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`?o0000R_ooool2o`00
01_ooooo0_l0000:ooooo`;o00000_ooool2o`0008kooooo0003ooooo`05o`000?oooooooooooooo
ool000002oooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo09cooooo0_l00000
0ooooooo0000o`00000:ooooo`;o00002_ooool2o`0008kooooo0003ooooo`05o`000?oooooooooo
ooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo09cooooo0_l0
00000ooooooo0000o`00000:ooooo`;o00002oooool2o`0008gooooo0003ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo08;ooooo0_l0
0006ooooo`;o00008oooool2o`0000Oooooo0_l0002=ooooo`000oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`22ooooo`;o00001_oo
ool2o`0000oooooo0_l0000Booooo`;o0000U_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0Voooool2o`000:[ooooo000N
ooooo`03o`000?oooooooooo08kooooo0_l0000=ooooo`;o00000oooool3o`000:;ooooo000Noooo
o`03o`000?oooooooooo08kooooo0_l00006ooooo`;o00001Oooool2o`0000?ooooo0ol0000Eoooo
o`;o0000Roooool001kooooo00?o0000ooooooooool0O_ooool2o`0001Kooooo1?l000000ooooooo
0000o`000006o`0000Sooooo0_l0000=ooooo`?o0000R_ooool001kooooo00?o0000ooooooooool0
OOooool3o`0001Cooooo0_l00002ooooo`Go00000_ooool4o`0000Sooooo0_l0000>ooooo`;o0000
R_ooool001kooooo00?o0000ooooooooool0OOooool2o`00017ooooo0_l00002ooooo`?o00000ooo
ool5o`0000;ooooo0_l00004ooooo`;o00001?ooool2o`0000cooooo0_l0002:ooooo`007_ooool0
0ol0003oooooooooo`25ooooo`;o00002?ooool4o`0000;ooooo0ol00002ooooo`Go00002?ooool2
o`0000Cooooo0_l0002Hooooo`007_ooool00ol0003oooooooooo`24ooooo`?o00002?ooool:o`00
0004ooooool0003o0000o`0000?ooooo1?l00004ooooo`Ko0000VOooool001kooooo00?o0000oooo
ooooool0OOooool2o`0000?ooooo1?l00009oooooaoo00000_ooool2o`0000[ooooo0_l00029oooo
o`007_ooool00ol0003oooooooooo`1mooooo`;o00000oooool2o`0000;ooooo0_l00007ooooo`?o
00000oooool3o`000003ooooool0003o000000;ooooo0ol00002ooooo`So00000oooool2o`000004
ooooool0003o0000ooooo`;o00001oooool2o`0008Wooooo000Nooooo`03o`000?oooooooooo083o
oooo0_l00004ooooo`;o00000_ooool8o`000004ooooool0003o0000ooooo`Co00000_ooool2o`00
00Cooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000;o00001?ooool2o`00
00Oooooo0_l00029ooooo`007_ooool00ol0003oooooooooo`20ooooo`;o00001Oooool>o`0000?o
oooo0_l00002ooooo`;o00001_ooool:o`0000Kooooo0_l00005ooooo`?o0000ROooool001kooooo
0_l00028ooooo`Co00000_ooool3o`000003ooooool0003o000000Oooooo1?l00003ooooo`;o0000
00?oooooo`000?l000001ol00002ooooo`Co000000?oooooo`000?l000001Oooool4o`0008Sooooo
000Nooooo`03o`000?oooooooooo08cooooo1?l0000:ooooo`Co00000_ooool3o`000003ooooool0
003o000000So000000?oooooo`000?l000000_l0000:ooooo`;o0000R?ooool001kooooo00?o0000
ooooooooool0POooool2o`0000Wooooo1?l0000:ooooo`Co000000?oooooo`000?l000000_l00002
ooooo`Co00000_ooool5o`0000Cooooo0_l00007ooooo`;o000000?oooooo`000?l00000QOooool0
01kooooo00?o0000ooooooooool0M_ooool2o`0000Wooooo0_l00009ooooo`;o00003?ooool:o`00
0003ooooool0003o000000Co000000?oooooo`000?l000001?l00002ooooo`;o00001Oooool4o`00
0003ooooool0003o000008Gooooo000Nooooo`03o`000?oooooooooo07Kooooo0_l0000Dooooo`Go
00001_ooool2o`0000?ooooo1?l00002oooooa3o00000oooool3o`0000?ooooo1?l00028ooooo`00
7_ooool00ol0003oooooooooo`1fooooo`;o00005?ooool5o`0000;ooooo3?l00002ooooo`Go0000
0oooool4o`000003ooooool0003o000000Cooooo1?l00005ooooo`;o0000R?ooool001kooooo00?o
0000ooooooooool0N_ooool2o`0001;ooooo0ol000000ooooooo0000o`00000?o`000003ooooool0
003o000000;ooooo0ol000000ooooooo0000o`000003o`0000?ooooo0_l000000ooooooo0000o`00
0004ooooo`;o00000oooool2o`0008?ooooo000Nooooo`03o`000?oooooooooo07[ooooo0_l0000@
ooooo`go000000?oooooo`000?l000001Ol00007ooooo`Wo00000oooool2o`000003ooooool0003o
000000Wooooo0_l00023ooooo`007_ooool00ol0003oooooooooo`2:ooooo`Co000000?oooooo`00
0?l000002?l00002ooooo`Oo000000Goooooo`000?l0003o0000ooooo`0:o`0009Kooooo000Noooo
o`03o`000?oooooooooo08Wooooo2?l000000ooooooo0000o`00000Bo`000003ooooool0003o0000
00Wo00000_ooool2o`0000kooooo0_l00021ooooo`007_ooool00ol0003oooooooooo`29ooooo`So
000000Coooooo`000?l0003o00000oooool4o`0000;ooooo0_l000000ooooooo0000o`000002o`00
00;ooooo2ol000001?oooooo0000o`000?l00004ooooo`;o00001oooool3o`00087ooooo000Noooo
o`03o`000?oooooooooo08Wooooo3?l00004oooooa3o00000_ooool:o`0000Cooooo0ol00007oooo
o`Co0000P?ooool001kooooo00?o0000ooooooooool0Roooool<o`0000;ooooo6?l000000ooooooo
0000o`000002o`0000?ooooo0_l0000:ooooo`;o0000P?ooool001kooooo00?o0000ooooooooool0
ROoooolSo`0000;ooooo1?l000001?oooooo0000o`000?l0002Aooooo`007_ooool00ol0003ooooo
ooooo`27ooooo`So000000?oooooo`000?l000000_l00002oooooaco000000?oooooo`000?l00000
1?ooool2o`0008cooooo000Nooooo`03o`000?oooooooooo07Gooooo0_l0000@ooooo`;o00001ooo
ool5o`000003ooooool0003o000000oo000000?oooooo`000?l000002?l00007ooooo`;o0000S?oo
ool001kooooo0_l0001fooooo`;o00004?ooool3o`0000;ooooo1_l000000ooooooo0000o`000005
o`000003ooooool0003o000001;o000000?oooooo`000?l000001Oooool2o`0000gooooo0_l0001o
ooooo`007_ooool00ol0003oooooooooo`1gooooo`;o00003_ooool3o`0000;ooooo1_l000000ooo
oooo0000o`000005o`000003ooooool0003o000001;o000000?oooooo`000?l000001?ooool3o`00
00cooooo0ol0001oooooo`007_ooool00ol0003oooooooooo`1gooooo`;o00003_ooool2o`000003
ooooool0003o000000[o000000?oooooo`000?l000005Ol00002ooooo`;o00001?ooool2o`0000go
oooo0ol0001oooooo`007_ooool00ol0003oooooooooo`2:oooooa?o00000_ooool>o`000003oooo
ool0003o000000;o00004oooool2o`00083ooooo000Nooooo`03o`000?oooooooooo07_ooooo0_l0
000=oooooago00000_ooool3o`0000;ooooo0_l00002ooooo`;o0000Toooool001kooooo00?o0000
ooooooooool0Noooool2o`0000kooooo6?l000000ooooooo0000o`000002ooooo`?o00001oooool5
o`00093ooooo000Nooooo`03o`000?oooooooooo08_ooooo8?l00009ooooo`?o0000T?ooool001ko
oooo00?o0000ooooooooool0S?oooolHo`000003ooooool0003o000000?o000000?oooooo`000?l0
00000_l00003ooooo`;o00001?ooool2o`0008gooooo000Nooooo`03o`000?oooooooooo07Oooooo
0_l0000>ooooo`;o00000_oooolGo`000003ooooool0003o000000?o00000oooool4o`000003oooo
ool0003o000000?o00000oooool2o`0008gooooo000Nooooo`03o`000?oooooooooo07Oooooo0_l0
000>ooooo`?o000000?oooooo`000?l000001?l000000ooooooo0000o`00000<o`0000?ooooo1?l0
0008ooooo`?o000000?oooooo`000?l000003_ooool2o`0008;ooooo000Nooooo`03o`000?oooooo
oooo07Sooooo0_l0000>ooooo`;o000000Coooooo`000?l0003ooooo0ol00003ooooo`_o00000_oo
ool2o`000003ooooool0003o000000Wooooo0ol0000Aooooo`;o0000P_ooool001kooooo00?o0000
ooooooooool0N?ooool2o`00017ooooo0_l000001?oooooo0000o`000?l00004ooooo`?o000000?o
ooooo`000?l000002?l0000:ooooo`;o000000?oooooo`000?l00000UOooool001kooooo00?o0000
ooooooooool0R?ooool2o`000003ooooool0003o000000?o00000_ooool2o`0000Gooooo2_l0000:
ooooo`?o00000_ooool2o`0000[ooooo0_l00004ooooo`;o0000POooool001kooooo00?o0000oooo
ooooool0R?ooool2o`000003ooooool0003o000000?o00000_ooool2o`0000Kooooo1ol00005oooo
o`;o000000Coooooo`000?l0003o00000_ooool2o`000005ooooool0003o0000o`000?ooool00_l0
0003ooooo`;o00000_ooool2o`0000Cooooo0_l00021ooooo`007_ooool00ol0003oooooooooo`1k
ooooo`;o00004Oooool3o`0000?ooooo0_l00004ooooo`Oo00001?ooool7o`000003ooooool0003o
000000;ooooo0ol000000ooooooo0000o`000003ooooo`;o0000Roooool001kooooo00?o0000oooo
ooooool0Noooool2o`00017ooooo1?l00002ooooo`;o00001?ooool7o`000004ooooool0003o0000
ooooo`Go00000_ooool7o`0009Cooooo000Nooooo`;o0000P?ooool2o`0000kooooo0ol000000ooo
oooo0000o`000005ooooo`Go000000?oooooo`000?l000001_l00003ooooo`?o000000?oooooo`00
0?l000000_l0000=ooooo`;o0000QOooool001kooooo00?o0000ooooooooool0Ooooool2o`0000_o
oooo0_l000000ooooooo0000o`000002ooooo`;o00001Oooool3o`0000;ooooo2?l00003ooooo`?o
000000?oooooo`000?l000000_l0000>ooooo`;o0000QOooool001kooooo00?o0000ooooooooool0
S?ooool2o`0000;ooooo0_l00009ooooo`?o000000?oooooo`000?l000001?l00005ooooo`?o0000
00?oooooo`000?l000000_l0002Eooooo`007_ooool00ol0003oooooooooo`22ooooo`;o00002_oo
ool5o`0000Wooooo1?l000000ooooooo0000o`000002o`000003ooooool0003o000000Go000000?o
ooooo`000?l000000_l0000@ooooo`;o0000Poooool001kooooo00?o0000ooooooooool0P_ooool2
o`0000[ooooo0_l000000ooooooo0000o`00000;ooooo`;o00001_ooool:o`0000Oooooo0_l00009
ooooo`;o0000Poooool001kooooo00?o0000ooooooooool0O?ooool2o`0001Cooooo0ol00008oooo
o`;o000000?oooooo`000?l000000_ooool:o`000003ooooool0003o000000Kooooo0_l0002>oooo
o`007_ooool00ol0003oooooooooo`1looooo`;o00004_ooool7o`0000Kooooo1Ol00002ooooo`Wo
00000_ooool2o`0000Gooooo0_l00002ooooo`;o00001?ooool2o`0008Gooooo000Nooooo`03o`00
0?oooooooooo093ooooo0_l00002ooooo`?o00001oooool2o`000004ooooool0003o0000ooooo`Co
00000_ooool2o`0000Kooooo0_l00002ooooo`;o00000_ooool2o`0000Cooooo0_l00025ooooo`00
7_ooool00ol0003oooooooooo`1nooooo`;o00005?ooool8o`0000Cooooo1ol0000;ooooo`;o0000
3?ooool2o`0008Gooooo000Nooooo`03o`000?oooooooooo07kooooo0_l0000Fooooo`Ko00001?oo
ool2o`000004ooooool0003o0000o`0000Oooooo0_l0000@ooooo`?o0000QOooool001kooooo00?o
0000ooooooooool0QOooool2o`0000_ooooo0_l00002ooooo`Ko00001Oooool2o`000003ooooool0
003o000000Oooooo0_l0000@ooooo`;o0000Q_ooool001kooooo00?o0000ooooooooool0QOooool2
o`0000_ooooo0_l00003ooooo`?o00000_ooool2o`0000?ooooo0_l0002Tooooo`007_ooool00ol0
003oooooooooo`2Booooo`;o00001?ooool6o`0000Kooooo0_l0002Qooooo`007_ooool00ol0003o
ooooooooo`2=ooooo`;o00000oooool2o`0000Gooooo1Ol00003ooooo`;o000000?oooooo`000?l0
0000XOooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko
<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0SOooool2o`0000Cooooo0ol0000;oooo
o`;o00004?ooool2o`0009;ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo09;ooooo1?l00008
ooooo`;o000000?oooooo`000?l000004?ooool2o`0009;ooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0002Aooooo`Go00002?oo
ool2o`0001;ooooo0_l00005ooooo`;o0000S?ooool000?ooooo00Go0000ooooooooooooooooo`00
000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2Aooooo`;o0000
00?oooooo`000?l000003?ooool2o`0000;ooooo0_l0000:ooooo`;o00001Oooool2o`0008cooooo
0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Ko
oooo00?o0000ooooooooool0UOooool2o`0000_ooooo0_l00002ooooo`;o00002Oooool2o`0009Co
oooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03
o`000?oooooooooo09Gooooo0_l0000Jooooo`;o0000U?ooool000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0Uoooool3o`000:go
oooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106oooo
o`03o`000?oooooooooo09Oooooo0ol0002]ooooo`007_ooool00ol0003oooooooooo`2Booooo`;o
0000/oooool001kooooo00?o0000ooooooooool0Qoooool2o`0000Oooooo1?l0002cooooo`007_oo
ool00ol0003oooooooooo`27ooooo`;o00001_ooool3o`0001[ooooo0_l0002Iooooo`007_ooool0
0ol0003oooooooooo`2?ooooo`;o00006?ooool2o`000003ooooool0003o000009Wooooo000Noooo
o`03o`000?oooooooooo0:Oooooo1?l0002Looooo`007_ooool00ol0003oooooooooo`2Pooooo`;o
00000oooool4o`0009kooooo000Nooooo`03o`000?oooooooooo09Sooooo0_l00006ooooo`;o0000
00?oooooo`000?l000000_l0002Pooooo`007_ooool00ol0003oooooooooo`2Booooo`;o00001?oo
ool2o`0000Cooooo1?l000001?oooooo0000o`000?l0002Qooooo`007_ooool00ol0003ooooooooo
o`2Booooo`;o00002_ooool4o`000:Gooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo
0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ
8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol@
413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000oooo
oom8ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RH
oc8b<P06ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`3oooooodSo
oooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@
00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0?ooooooB?ooool0
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Dooooo`Co000000?o410@ooooooooool00oooool00ol0003o
ooooooooo`3oooooodSooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
oooooom8ooooo`005_ooool00ol0003oooooooooo`05ooooo`?o0000oooooom8ooooo`005_ooool0
0ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Ko
oooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo
000Dooooo`03oeEEEOmVIVKo00000?ooooooD_ooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001
\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.51102 .56337 Mdot
.46858 .52337 Mdot
.49159 .41474 Mdot
.46437 .50701 Mdot
.46949 .48672 Mdot
.52287 .55166 Mdot
.44125 .6129 Mdot
.45343 .5086 Mdot
.54384 .56964 Mdot
.44161 .53742 Mdot
.48185 .56107 Mdot
.50721 .51095 Mdot
.54099 .51489 Mdot
.554 .45647 Mdot
.52479 .63295 Mdot
.47556 .46347 Mdot
.47364 .5433 Mdot
.5584 .53641 Mdot
.46358 .58269 Mdot
.54657 .47024 Mdot
.47285 .5472 Mdot
.5057 .45123 Mdot
.45945 .50494 Mdot
.56628 .5141 Mdot
.4643 .53457 Mdot
.51358 .50403 Mdot
.44617 .51653 Mdot
.50919 .57892 Mdot
.47791 .49098 Mdot
.53881 .55227 Mdot
.55148 .49449 Mdot
.4698 .52383 Mdot
.50027 .49492 Mdot
.48361 .42415 Mdot
.54039 .53414 Mdot
.50442 .42542 Mdot
.51269 .50144 Mdot
.44474 .46577 Mdot
.46748 .49363 Mdot
.52184 .50467 Mdot
.48065 .46787 Mdot
.53878 .46866 Mdot
.52681 .527 Mdot
.49842 .50913 Mdot
.47246 .5274 Mdot
.51576 .48559 Mdot
.47714 .4362 Mdot
.55889 .47571 Mdot
.551 .46544 Mdot
.62756 .47874 Mdot
.4753 .4855 Mdot
.5234 .37438 Mdot
.47786 .49466 Mdot
.46045 .49432 Mdot
.46193 .46667 Mdot
.53029 .49603 Mdot
.52105 .51701 Mdot
.47208 .35811 Mdot
.46261 .50567 Mdot
.5311 .515 Mdot
.52076 .48218 Mdot
.516 .49249 Mdot
.50529 .4366 Mdot
.47505 .46411 Mdot
.48832 .48117 Mdot
.60342 .54658 Mdot
.522 .53131 Mdot
.52647 .49136 Mdot
.54869 .48231 Mdot
.47569 .46279 Mdot
.45864 .59549 Mdot
.46078 .49538 Mdot
.54094 .50467 Mdot
.48163 .50767 Mdot
.55706 .53049 Mdot
.44114 .52617 Mdot
.54033 .48264 Mdot
.57061 .52675 Mdot
.45093 .55791 Mdot
.49504 .57114 Mdot
.46355 .45017 Mdot
.45295 .51084 Mdot
.46866 .53886 Mdot
.49453 .47542 Mdot
.49526 .43165 Mdot
.48011 .50252 Mdot
.46013 .44913 Mdot
.52387 .49409 Mdot
.52527 .50473 Mdot
.6011 .43873 Mdot
.48604 .4894 Mdot
.50566 .47389 Mdot
.46065 .45506 Mdot
.63305 .50571 Mdot
.46471 .46925 Mdot
.52088 .46832 Mdot
.52754 .49481 Mdot
.549 .4991 Mdot
.46048 .43614 Mdot
.50541 .52403 Mdot
.45763 .45566 Mdot
.46343 .44805 Mdot
.45775 .49697 Mdot
.60879 .50635 Mdot
.52814 .5718 Mdot
.50082 .4951 Mdot
.45393 .5693 Mdot
.48635 .48343 Mdot
.50628 .53771 Mdot
.50375 .47162 Mdot
.55053 .54219 Mdot
.46055 .49675 Mdot
.48205 .52141 Mdot
.42464 .52517 Mdot
.51515 .53099 Mdot
.55103 .42695 Mdot
.42816 .47829 Mdot
.51245 .58328 Mdot
.53462 .418 Mdot
.45873 .45643 Mdot
.55727 .53255 Mdot
.50892 .50534 Mdot
.44195 .52125 Mdot
.55698 .48286 Mdot
.47352 .53721 Mdot
.42092 .51532 Mdot
.55863 .53766 Mdot
.51043 .50475 Mdot
.50274 .50656 Mdot
.4656 .46804 Mdot
.53728 .56085 Mdot
.4773 .54712 Mdot
.45503 .377 Mdot
.53122 .44972 Mdot
.44239 .503 Mdot
.44997 .38343 Mdot
.45033 .58999 Mdot
.49244 .50109 Mdot
.54696 .49337 Mdot
.48986 .51718 Mdot
.48595 .48558 Mdot
.46015 .54233 Mdot
.50271 .50316 Mdot
.46673 .50007 Mdot
.49961 .4862 Mdot
.50422 .47128 Mdot
.51276 .56747 Mdot
.52802 .46064 Mdot
.52151 .52671 Mdot
.55735 .48188 Mdot
.51832 .44398 Mdot
.51947 .5777 Mdot
.47942 .4851 Mdot
.58068 .47959 Mdot
.51415 .57302 Mdot
.47534 .46331 Mdot
.51135 .49105 Mdot
.5169 .42131 Mdot
.54107 .48225 Mdot
.49705 .48593 Mdot
.48487 .63303 Mdot
.5467 .47493 Mdot
.57718 .51052 Mdot
.45669 .46542 Mdot
.52314 .5117 Mdot
.49415 .52364 Mdot
.51166 .57132 Mdot
.48272 .46606 Mdot
.52584 .46088 Mdot
.43871 .4837 Mdot
.50144 .5777 Mdot
.55744 .49626 Mdot
.47434 .5307 Mdot
.52913 .5085 Mdot
.49541 .64613 Mdot
.52081 .49822 Mdot
.50934 .457 Mdot
.49599 .48302 Mdot
.45525 .43614 Mdot
.55313 .46974 Mdot
.46658 .50447 Mdot
.51067 .46714 Mdot
.4872 .50682 Mdot
.47657 .49393 Mdot
.54583 .48562 Mdot
.50138 .51423 Mdot
.46733 .42852 Mdot
.52052 .48166 Mdot
.62485 .51977 Mdot
.45091 .46927 Mdot
.49559 .51364 Mdot
.47606 .46927 Mdot
.57198 .51861 Mdot
.48199 .48432 Mdot
.44433 .47415 Mdot
.48073 .46915 Mdot
.62126 .47195 Mdot
.50074 .50205 Mdot
.49291 .47991 Mdot
.46687 .51233 Mdot
.49273 .52738 Mdot
.52938 .49046 Mdot
.54919 .54307 Mdot
.51102 .46805 Mdot
.45933 .47235 Mdot
.4784 .53159 Mdot
.47428 .54905 Mdot
.51591 .52237 Mdot
.47412 .41935 Mdot
.47966 .4838 Mdot
.47342 .53138 Mdot
.50897 .50259 Mdot
.5365 .49471 Mdot
.5263 .53707 Mdot
.50905 .50544 Mdot
.48593 .4405 Mdot
.51165 .47871 Mdot
.54159 .48349 Mdot
.45525 .53956 Mdot
.49048 .48472 Mdot
.47807 .47912 Mdot
.47118 .36288 Mdot
.50667 .47304 Mdot
.52296 .44042 Mdot
.44362 .50277 Mdot
.4446 .50437 Mdot
.46422 .51186 Mdot
.44137 .53098 Mdot
.47336 .42311 Mdot
.46739 .55668 Mdot
.4596 .46361 Mdot
.50759 .50325 Mdot
.42534 .51718 Mdot
.50897 .49461 Mdot
.52044 .50173 Mdot
.54801 .49332 Mdot
.41792 .50864 Mdot
.43726 .51987 Mdot
.47973 .54103 Mdot
.50155 .51415 Mdot
.44148 .53546 Mdot
.5132 .63307 Mdot
.53081 .56114 Mdot
.42331 .50444 Mdot
.4598 .48163 Mdot
.46588 .46408 Mdot
.44555 .55395 Mdot
.4473 .50296 Mdot
.44884 .47848 Mdot
.43242 .49452 Mdot
.52488 .52549 Mdot
.54903 .4723 Mdot
.48439 .58762 Mdot
.46489 .47276 Mdot
.48213 .51795 Mdot
.50352 .51673 Mdot
.44614 .50595 Mdot
.53657 .492 Mdot
.48863 .42868 Mdot
.46277 .54189 Mdot
.48206 .4645 Mdot
.47585 .46796 Mdot
.49746 .48618 Mdot
.53174 .55036 Mdot
.54328 .46603 Mdot
.5128 .44211 Mdot
.44228 .52792 Mdot
.54 .56363 Mdot
.48839 .47547 Mdot
.44598 .42805 Mdot
.51555 .53659 Mdot
.48254 .52167 Mdot
.62367 .52142 Mdot
.48713 .51928 Mdot
.47507 .4244 Mdot
.44904 .57771 Mdot
.53563 .49051 Mdot
.45614 .57649 Mdot
.55092 .47622 Mdot
.44924 .5567 Mdot
.54813 .48935 Mdot
.52169 .50245 Mdot
.56831 .45529 Mdot
.49963 .49583 Mdot
.42572 .48182 Mdot
.63038 .50103 Mdot
.46855 .4395 Mdot
.45965 .50101 Mdot
.47736 .53845 Mdot
.58031 .48345 Mdot
.51333 .51344 Mdot
.55364 .51074 Mdot
.56043 .43227 Mdot
.54115 .51828 Mdot
.49354 .5239 Mdot
.45656 .49437 Mdot
.52222 .57412 Mdot
.55254 .47031 Mdot
.52182 .46184 Mdot
.46342 .50614 Mdot
.49792 .50579 Mdot
.44398 .50417 Mdot
.55934 .57679 Mdot
.48473 .46196 Mdot
.5088 .51262 Mdot
.46384 .50519 Mdot
.39855 .41214 Mdot
.54135 .5267 Mdot
.46676 .53731 Mdot
.55018 .47203 Mdot
.47193 .50774 Mdot
.50006 .49582 Mdot
.43633 .52665 Mdot
.48507 .54385 Mdot
.46887 .51704 Mdot
.52051 .52153 Mdot
.52275 .50372 Mdot
.52581 .49238 Mdot
.5415 .50261 Mdot
.45085 .46821 Mdot
.55634 .47662 Mdot
.48798 .5593 Mdot
.48869 .56815 Mdot
.52418 .49809 Mdot
.4918 .58082 Mdot
.45974 .47607 Mdot
.49715 .51169 Mdot
.50354 .50678 Mdot
.49898 .56975 Mdot
.46722 .4388 Mdot
.52147 .56791 Mdot
.54194 .4143 Mdot
.48297 .52266 Mdot
.44386 .54583 Mdot
.47809 .41879 Mdot
.44716 .50203 Mdot
.52678 .45075 Mdot
.46195 .50045 Mdot
.48291 .53396 Mdot
.51832 .49349 Mdot
.52843 .5276 Mdot
.51697 .52355 Mdot
.37365 .55284 Mdot
.50181 .50131 Mdot
.4979 .46138 Mdot
.5007 .53826 Mdot
.49906 .49685 Mdot
.45291 .49919 Mdot
.47845 .46388 Mdot
.49437 .47498 Mdot
.51666 .51637 Mdot
.46278 .37405 Mdot
.47346 .54101 Mdot
.5116 .49764 Mdot
.56669 .47915 Mdot
.50315 .5208 Mdot
.56179 .46674 Mdot
.48154 .54458 Mdot
.57946 .4133 Mdot
.50006 .49327 Mdot
.48971 .48055 Mdot
.52672 .51757 Mdot
.48925 .52375 Mdot
.57781 .47863 Mdot
.48775 .5439 Mdot
.56281 .44682 Mdot
.47472 .45437 Mdot
.48603 .4667 Mdot
.37978 .44596 Mdot
.48161 .50206 Mdot
.49654 .48559 Mdot
.49132 .49688 Mdot
.47172 .37007 Mdot
.45798 .52301 Mdot
.51982 .41673 Mdot
.44598 .49673 Mdot
.45976 .53907 Mdot
.44787 .47226 Mdot
.54359 .46836 Mdot
.51175 .50293 Mdot
.54333 .46601 Mdot
.45352 .50228 Mdot
.46694 .49547 Mdot
.53754 .44763 Mdot
.4639 .51018 Mdot
.50163 .57085 Mdot
.51333 .57863 Mdot
.44822 .49772 Mdot
.52848 .49874 Mdot
.54813 .46936 Mdot
.42048 .38824 Mdot
.54999 .47352 Mdot
.55627 .47545 Mdot
.46975 .52327 Mdot
.46836 .49807 Mdot
.45871 .51256 Mdot
.4741 .45912 Mdot
.50047 .49404 Mdot
.49375 .58077 Mdot
.42438 .39193 Mdot
.40948 .404 Mdot
.53823 .45755 Mdot
.41124 .40765 Mdot
.52128 .50287 Mdot
.55875 .4822 Mdot
.521 .43742 Mdot
.47432 .4947 Mdot
.49352 .48521 Mdot
.50085 .52662 Mdot
.48908 .57441 Mdot
.4939 .51675 Mdot
.4653 .5817 Mdot
.48251 .50629 Mdot
.55804 .47688 Mdot
.48439 .50272 Mdot
.46113 .45206 Mdot
.49705 .46706 Mdot
.57357 .51395 Mdot
.54242 .51347 Mdot
.44151 .51421 Mdot
.45368 .57135 Mdot
.51902 .48679 Mdot
.48749 .5081 Mdot
.4515 .56243 Mdot
.44375 .37853 Mdot
.51697 .44012 Mdot
.53559 .60825 Mdot
.48595 .47345 Mdot
.5527 .48744 Mdot
.53392 .49616 Mdot
.56254 .50239 Mdot
.47653 .46269 Mdot
.47626 .54785 Mdot
.45778 .57356 Mdot
.5189 .46443 Mdot
.56922 .50978 Mdot
.52193 .46074 Mdot
.524 .51591 Mdot
.55573 .51017 Mdot
.5276 .51014 Mdot
.54587 .51466 Mdot
.586 .3914 Mdot
.57055 .49207 Mdot
.52111 .55891 Mdot
.50065 .49428 Mdot
.53447 .56374 Mdot
.46649 .49131 Mdot
.46176 .46927 Mdot
.48375 .42216 Mdot
.48311 .48941 Mdot
.53238 .43717 Mdot
.49741 .51671 Mdot
.48599 .46965 Mdot
.53025 .50548 Mdot
.46903 .43846 Mdot
.48678 .5631 Mdot
.52343 .44841 Mdot
.44921 .46368 Mdot
.49462 .49042 Mdot
.53495 .49418 Mdot
.50956 .46452 Mdot
.47887 .51043 Mdot
.56057 .45051 Mdot
.50728 .49481 Mdot
.55886 .49064 Mdot
.48 .41941 Mdot
.49762 .4843 Mdot
.48837 .51143 Mdot
.54498 .51518 Mdot
.53947 .48886 Mdot
.49745 .55459 Mdot
.44318 .51886 Mdot
.43044 .6107 Mdot
.55067 .62547 Mdot
.48515 .58317 Mdot
.51307 .56685 Mdot
.54769 .44945 Mdot
.55657 .62217 Mdot
.45545 .46011 Mdot
.46149 .38622 Mdot
.50037 .49704 Mdot
.47344 .53965 Mdot
.44928 .50663 Mdot
.46295 .50844 Mdot
.52025 .48644 Mdot
.5165 .46664 Mdot
.44582 .54676 Mdot
.51548 .56486 Mdot
.55867 .48989 Mdot
.44609 .47599 Mdot
.55466 .37373 Mdot
.47352 .42246 Mdot
.57548 .55603 Mdot
.49419 .47988 Mdot
.52056 .52319 Mdot
.56392 .47369 Mdot
.42828 .50781 Mdot
.49686 .48032 Mdot
.52624 .46809 Mdot
.45111 .51339 Mdot
.38132 .54575 Mdot
.49491 .59267 Mdot
.40851 .61854 Mdot
.46148 .478 Mdot
.50007 .51551 Mdot
.45697 .56855 Mdot
.49885 .55381 Mdot
.44303 .50195 Mdot
.45208 .47108 Mdot
.62947 .49072 Mdot
.55037 .47401 Mdot
.50212 .43295 Mdot
.5198 .527 Mdot
.53468 .52492 Mdot
.44493 .50676 Mdot
.48087 .46251 Mdot
.52136 .52578 Mdot
.53788 .53798 Mdot
.54441 .44154 Mdot
.48276 .53721 Mdot
.44514 .4878 Mdot
.51539 .53658 Mdot
.46702 .52953 Mdot
.51553 .50326 Mdot
.49916 .52022 Mdot
.52826 .49517 Mdot
.54208 .45678 Mdot
.53199 .3742 Mdot
.52284 .56884 Mdot
.47786 .58486 Mdot
.48825 .44069 Mdot
.50391 .47106 Mdot
.53574 .49161 Mdot
.47929 .51172 Mdot
.61577 .52703 Mdot
.50491 .51043 Mdot
.52619 .44441 Mdot
.52494 .48965 Mdot
.52064 .51964 Mdot
.45995 .58037 Mdot
.48314 .51926 Mdot
.59414 .4933 Mdot
.49654 .4669 Mdot
.55239 .47666 Mdot
.52812 .56684 Mdot
.4557 .55227 Mdot
.46902 .49604 Mdot
.60201 .47008 Mdot
.45985 .49442 Mdot
.4557 .56628 Mdot
.52293 .50599 Mdot
.45294 .50148 Mdot
.50014 .49026 Mdot
.36737 .53104 Mdot
.46082 .50173 Mdot
.48398 .47367 Mdot
.49042 .49011 Mdot
.55644 .49573 Mdot
.56331 .38823 Mdot
.44364 .46801 Mdot
.46651 .44261 Mdot
.47461 .42712 Mdot
.45458 .47842 Mdot
.48103 .49824 Mdot
.53606 .46224 Mdot
.44429 .5063 Mdot
.44533 .64637 Mdot
.44736 .55456 Mdot
.53691 .45155 Mdot
.54963 .45752 Mdot
.45019 .42815 Mdot
.50993 .50391 Mdot
.55266 .50288 Mdot
.45736 .49494 Mdot
.49872 .51524 Mdot
.4833 .46508 Mdot
.60277 .46107 Mdot
.52249 .50546 Mdot
.43835 .50169 Mdot
.51164 .50652 Mdot
.46696 .43656 Mdot
.46205 .49479 Mdot
.38922 .57234 Mdot
.49359 .52812 Mdot
.54576 .47646 Mdot
.40739 .45234 Mdot
.44352 .50202 Mdot
.50245 .53925 Mdot
.49109 .53968 Mdot
.50186 .43808 Mdot
.50218 .51464 Mdot
.50858 .48219 Mdot
.49345 .47984 Mdot
.50049 .51113 Mdot
.46125 .46923 Mdot
.52274 .56648 Mdot
.56724 .49461 Mdot
.50287 .45727 Mdot
.57492 .51393 Mdot
.47086 .52555 Mdot
.50391 .46849 Mdot
.47283 .45546 Mdot
.4997 .55485 Mdot
.55948 .50256 Mdot
.50699 .4805 Mdot
.51308 .5355 Mdot
.45899 .47443 Mdot
.51813 .42224 Mdot
.51595 .49315 Mdot
.50362 .50754 Mdot
.53073 .57878 Mdot
.5294 .55316 Mdot
.44472 .50947 Mdot
.43503 .44101 Mdot
.51619 .56448 Mdot
.47556 .4875 Mdot
.47502 .49012 Mdot
.456 .47246 Mdot
.48843 .48134 Mdot
.50102 .64133 Mdot
.44356 .60529 Mdot
.50927 .35688 Mdot
.47774 .51738 Mdot
.51195 .49175 Mdot
.44647 .49119 Mdot
.54908 .47107 Mdot
.48158 .4867 Mdot
.4929 .49331 Mdot
.45496 .38502 Mdot
.47675 .53688 Mdot
.52323 .48608 Mdot
.46766 .46515 Mdot
.55473 .47433 Mdot
.59795 .49047 Mdot
.59919 .48368 Mdot
.47805 .53198 Mdot
.44023 .49801 Mdot
.4898 .51375 Mdot
.45966 .49994 Mdot
.47127 .43961 Mdot
.44913 .50089 Mdot
.53871 .48545 Mdot
.4863 .44092 Mdot
.48982 .47709 Mdot
.46105 .46948 Mdot
.54725 .51904 Mdot
.56177 .49146 Mdot
.50304 .49311 Mdot
.44281 .56367 Mdot
.44941 .57474 Mdot
.46626 .52609 Mdot
.50008 .48976 Mdot
.50428 .50057 Mdot
.50576 .53782 Mdot
.48467 .52592 Mdot
.52987 .52427 Mdot
.60481 .55596 Mdot
.49247 .51384 Mdot
.512 .4486 Mdot
.50197 .51053 Mdot
.45931 .49525 Mdot
.49899 .48737 Mdot
.57449 .47849 Mdot
.46072 .36561 Mdot
.36993 .51403 Mdot
.51458 .44099 Mdot
.47986 .467 Mdot
.40376 .41335 Mdot
.54283 .55177 Mdot
.59513 .59721 Mdot
.47302 .53257 Mdot
.45352 .36728 Mdot
.40569 .40381 Mdot
.47179 .45182 Mdot
.46253 .47015 Mdot
.45204 .54525 Mdot
.55053 .49451 Mdot
.47099 .52383 Mdot
.52961 .57276 Mdot
.45419 .49595 Mdot
.51371 .47593 Mdot
.46763 .44243 Mdot
.49013 .53779 Mdot
.46689 .44542 Mdot
.47351 .53662 Mdot
.53061 .48909 Mdot
.4727 .53604 Mdot
.54733 .48561 Mdot
.53581 .50047 Mdot
.55388 .48112 Mdot
.53477 .47383 Mdot
.49928 .41977 Mdot
.50381 .35989 Mdot
.52374 .50024 Mdot
.55758 .47904 Mdot
.47892 .55302 Mdot
.41288 .56432 Mdot
.49902 .50584 Mdot
.50038 .46971 Mdot
.46255 .50424 Mdot
.45073 .50485 Mdot
.50634 .50951 Mdot
.57265 .45686 Mdot
.48766 .48141 Mdot
.51531 .41805 Mdot
.4654 .62798 Mdot
.52523 .49611 Mdot
.47627 .4846 Mdot
.48218 .42967 Mdot
.45273 .56549 Mdot
.55903 .55776 Mdot
.50258 .50889 Mdot
.47133 .43376 Mdot
.48149 .59652 Mdot
.58304 .48396 Mdot
.44628 .51725 Mdot
.47277 .59671 Mdot
.47766 .54683 Mdot
.51192 .56528 Mdot
.53392 .57012 Mdot
.47738 .50211 Mdot
.48489 .57711 Mdot
.55288 .48962 Mdot
.47733 .50854 Mdot
.5155 .55228 Mdot
.50915 .5199 Mdot
.60141 .44644 Mdot
.5329 .5295 Mdot
.526 .4439 Mdot
.53329 .47794 Mdot
.50816 .57527 Mdot
.49033 .47095 Mdot
.50999 .51808 Mdot
.50302 .4865 Mdot
.5456 .391 Mdot
.44831 .6019 Mdot
.51924 .50049 Mdot
.506 .45062 Mdot
.46285 .58131 Mdot
.53916 .48824 Mdot
.51353 .48305 Mdot
.54918 .4714 Mdot
.52354 .50113 Mdot
.45541 .5167 Mdot
.49507 .4747 Mdot
.46747 .48889 Mdot
.49352 .48022 Mdot
.52236 .49453 Mdot
.50278 .50592 Mdot
.50615 .56774 Mdot
.54182 .45535 Mdot
.49689 .49075 Mdot
.52744 .51334 Mdot
.46955 .48695 Mdot
.46416 .46443 Mdot
.56372 .47502 Mdot
.46147 .54273 Mdot
.44389 .5058 Mdot
.54772 .50363 Mdot
.44885 .56391 Mdot
.52198 .56506 Mdot
.50451 .56837 Mdot
.56876 .60337 Mdot
.54642 .47288 Mdot
.60253 .44759 Mdot
.48142 .51356 Mdot
.51754 .42464 Mdot
.47014 .49575 Mdot
.49919 .50973 Mdot
.51464 .42766 Mdot
.4954 .56732 Mdot
.54947 .49602 Mdot
.5434 .53667 Mdot
.48295 .50092 Mdot
.49341 .42323 Mdot
.44861 .46139 Mdot
.5706 .61506 Mdot
.46975 .53473 Mdot
.48588 .51215 Mdot
.54054 .48952 Mdot
.46507 .47086 Mdot
.50366 .53759 Mdot
.53351 .55339 Mdot
.5673 .37212 Mdot
.44773 .37207 Mdot
.45178 .58463 Mdot
.47926 .52718 Mdot
.47413 .46734 Mdot
.50348 .57935 Mdot
.53879 .46822 Mdot
.46809 .51527 Mdot
.54784 .54522 Mdot
.47176 .50401 Mdot
.4487 .462 Mdot
.50322 .53862 Mdot
.48709 .46516 Mdot
.51903 .53449 Mdot
.37456 .53924 Mdot
.45845 .47297 Mdot
.40283 .49026 Mdot
.4763 .46811 Mdot
.51619 .52101 Mdot
.45219 .46719 Mdot
.60333 .5935 Mdot
.50651 .56203 Mdot
.46714 .46644 Mdot
.51864 .51351 Mdot
.45221 .51412 Mdot
.47267 .53531 Mdot
.56422 .55311 Mdot
.46934 .49648 Mdot
.45391 .54699 Mdot
.47163 .50056 Mdot
.4991 .57252 Mdot
.45521 .4773 Mdot
.52906 .52547 Mdot
.52522 .47903 Mdot
.51286 .51978 Mdot
.48454 .55128 Mdot
.55599 .48882 Mdot
.49993 .48722 Mdot
.47999 .51724 Mdot
.45654 .59573 Mdot
.45848 .57837 Mdot
.49055 .55328 Mdot
.49066 .59483 Mdot
.48967 .48061 Mdot
.48035 .53957 Mdot
.50042 .53866 Mdot
.52444 .50074 Mdot
.37008 .50618 Mdot
.53013 .52728 Mdot
.52781 .41791 Mdot
.52135 .48968 Mdot
.50623 .50332 Mdot
.46297 .47 Mdot
.53675 .46518 Mdot
.49969 .5709 Mdot
.47556 .51565 Mdot
.43262 .47601 Mdot
.51531 .56331 Mdot
.51221 .48157 Mdot
.51751 .47122 Mdot
.4873 .64096 Mdot
.45324 .56844 Mdot
.47207 .43716 Mdot
.59752 .59418 Mdot
.53306 .46157 Mdot
.51535 .48236 Mdot
.5423 .50289 Mdot
.47583 .54017 Mdot
.56954 .49992 Mdot
.51157 .44337 Mdot
.40426 .40473 Mdot
.49865 .64894 Mdot
.49709 .51692 Mdot
.49437 .4833 Mdot
.53683 .52051 Mdot
.48763 .51004 Mdot
.48409 .4837 Mdot
.47257 .4335 Mdot
.49713 .51716 Mdot
.5001 .49432 Mdot
.46366 .44767 Mdot
.52884 .57318 Mdot
.47448 .42696 Mdot
.47681 .52892 Mdot
.54835 .56754 Mdot
.4677 .51975 Mdot
.49131 .35061 Mdot
.54125 .55394 Mdot
.43247 .47748 Mdot
.55579 .43781 Mdot
.52442 .56629 Mdot
.48734 .55085 Mdot
.48239 .50195 Mdot
.45902 .49711 Mdot
.50541 .47566 Mdot
.52241 .50669 Mdot
.53447 .3778 Mdot
.37276 .50713 Mdot
.471 .37091 Mdot
.52045 .52956 Mdot
.48148 .49425 Mdot
.60043 .42093 Mdot
.46465 .50982 Mdot
.53466 .49926 Mdot
.48081 .4646 Mdot
.44214 .48983 Mdot
.48715 .38485 Mdot
.53716 .47282 Mdot
.50236 .50011 Mdot
.45816 .45153 Mdot
.45692 .57098 Mdot
.49775 .48064 Mdot
.61612 .52385 Mdot
.47256 .48982 Mdot
.50491 .53652 Mdot
.48638 .52137 Mdot
.48119 .52394 Mdot
.49767 .57404 Mdot
.49326 .52727 Mdot
.47792 .548 Mdot
.46858 .51891 Mdot
.48198 .57006 Mdot
.47684 .50098 Mdot
.44461 .47995 Mdot
.54509 .49675 Mdot
.45597 .49503 Mdot
.53339 .51882 Mdot
.49615 .44024 Mdot
.49535 .46757 Mdot
.49352 .52014 Mdot
.47107 .49422 Mdot
.47078 .53048 Mdot
.51145 .50779 Mdot
.46337 .44175 Mdot
.39299 .55705 Mdot
.55258 .54341 Mdot
.44219 .4594 Mdot
.50624 .48282 Mdot
.50006 .50713 Mdot
.55583 .46222 Mdot
.47302 .43715 Mdot
.47929 .57197 Mdot
.47586 .50735 Mdot
.45944 .49302 Mdot
.51058 .51142 Mdot
.60103 .57663 Mdot
.47584 .49686 Mdot
.48244 .52752 Mdot
.52868 .46721 Mdot
.58207 .56449 Mdot
.47844 .54155 Mdot
.48968 .51078 Mdot
.61875 .46796 Mdot
.51396 .49242 Mdot
.3804 .48573 Mdot
.4406 .50422 Mdot
.45876 .59707 Mdot
.52275 .4216 Mdot
.46323 .53262 Mdot
.55693 .48021 Mdot
.47564 .50502 Mdot
.53176 .48757 Mdot
.52342 .56104 Mdot
.54507 .51118 Mdot
.56408 .47407 Mdot
.54753 .50824 Mdot
.54949 .46535 Mdot
.50576 .58128 Mdot
.48858 .51825 Mdot
.58858 .49054 Mdot
.48382 .54035 Mdot
.46796 .50634 Mdot
.53926 .56703 Mdot
.45986 .4528 Mdot
.49018 .46407 Mdot
.37445 .47881 Mdot
.51004 .64415 Mdot
.47476 .44912 Mdot
.48563 .50368 Mdot
.50112 .44971 Mdot
.50714 .50177 Mdot
.50055 .48815 Mdot
.54194 .51886 Mdot
.46951 .42748 Mdot
.48785 .52788 Mdot
.48807 .46891 Mdot
.45657 .45311 Mdot
.52272 .45187 Mdot
.53244 .54354 Mdot
.54337 .4008 Mdot
.48468 .46638 Mdot
.38244 .44165 Mdot
.47935 .46219 Mdot
.43461 .57471 Mdot
.48718 .5055 Mdot
.51874 .50369 Mdot
.56313 .53231 Mdot
.5942 .4115 Mdot
.49237 .48596 Mdot
.4594 .50354 Mdot
.4416 .50338 Mdot
.55748 .5078 Mdot
.53663 .41831 Mdot
.5073 .55285 Mdot
.47631 .52214 Mdot
.48753 .46309 Mdot
.44142 .51272 Mdot
.51069 .56341 Mdot
.47682 .48944 Mdot
.52701 .52985 Mdot
.44752 .54862 Mdot
.44577 .49435 Mdot
.52983 .48853 Mdot
.44506 .48089 Mdot
.46962 .44918 Mdot
.47903 .63751 Mdot
.60248 .46397 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000WOooool2o`000:Wooooo000Nooooo`03o`000?oooooooooo09cooooo0_l0002Y
ooooo`007_ooool00ol0003oooooooooo`2Eooooo`;o00002_ooool2o`000:Cooooo000Nooooo`03
o`000?oooooooooo09Gooooo0_l00009ooooo`?o0000Y?ooool001kooooo00?o0000ooooooooool0
UOooool2o`0000Wooooo0_l0002Uooooo`007_ooool00ol0003oooooooooo`2?ooooo`;o000000Co
ooooo`000?l0003ooooo0_l0002`ooooo`007_ooool00ol0003oooooooooo`2?ooooo`;o000000Co
ooooo`000?l0003ooooo0_l0002`ooooo`007_ooool00ol0003oooooooooo`2=ooooo`;o00001_oo
ool2o`0001gooooo0_l0002Aooooo`007_ooool00ol0003oooooooooo`2=ooooo`;o00000oooool2
o`000003ooooool0003o000000oooooo0_l000000ooooooo0000o`000005ooooo`;o00000_ooool2
o`00097ooooo000Nooooo`03o`000?oooooooooo08cooooo0_l00002ooooo`Co00004_ooool2o`00
0004ooooool0003o0000o`0000Cooooo0_l0002Eooooo`007_ooool00ol0003oooooooooo`2<oooo
o`;o00000_ooool2o`0001Sooooo0_l0002Kooooo`007_ooool00ol0003oooooooooo`2>ooooo`Co
00002?ooool2o`000:_ooooo000Nooooo`03o`000?oooooooooo08Gooooo0_l00007ooooo`Ko0000
1_ooool2o`0001Oooooo0_l0002Booooo`007_ooool00ol0003oooooooooo`25ooooo`?o00002_oo
ool2o`0001Wooooo0_l00004ooooo`;o00001Oooool2o`0008_ooooo0003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oo
oooooooo08Kooooo0_l0000Uooooo`;o00002oooool2o`0008_ooooo0003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol0
002]ooooo`;o0000V?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oM
gMgoooooo`0000Oooooo00?o0000ooooooooool0P?ooool3o`0002[ooooo0_l0002Hooooo`000ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003o
ooooooooo`1oooooo`Co0000a?ooool000?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03
ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0Ooooool2o`000003ooooool0003o00000<?o
oooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007ooooo`03
o`000?oooooooooo07gooooo1?l000000ooooooo0000o`00000dooooo`;o00000oooool2o`0008So
oooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03
o`000?oooooooooo07gooooo1?l0000Kooooo`;o00003_ooool2o`0000[ooooo0_l00003ooooo`;o
0000R?ooool001kooooo00?o0000ooooooooool0U_ooool4o`0000;ooooo0_l00005ooooo`Ko0000
00?oooooo`000?l000000_l0002Iooooo`007_ooool00ol0003oooooooooo`2Fooooo`Go00000ooo
ool2o`0000?ooooo1_l000000ooooooo0000o`00000Cooooo`;o0000Q_ooool001kooooo00?o0000
ooooooooool0U_ooool2o`000004ooooool0003o0000ooooo`Ko00000_ooool4o`0001Oooooo0_l0
0026ooooo`007_ooool00ol0003oooooooooo`2=ooooo`?o00001?ooool4o`000003ooooool0003o
000000?o00000_ooool2o`000004ooooool0003o0000o`0000Wooooo0_l0002Fooooo`007_ooool0
0ol0003oooooooooo`2=ooooo`?o00001?ooool4o`000003ooooool0003o000000Co00001?ooool2
o`0000[ooooo0_l0002Fooooo`007_ooool00ol0003oooooooooo`2Eooooo`?o000000?oooooo`00
0?l000000_ooool4o`00017ooooo0_l0002Cooooo`007_ooool00ol0003oooooooooo`2@ooooo`Wo
00001_ooool3o`0000?ooooo0_l00002ooooo`;o00001_ooool3o`0009?ooooo000Nooooo`03o`00
0?oooooooooo08Wooooo0_l00005ooooo`Wo000000?oooooo`000?l000001_l000000ooooooo0000
o`000003o`000003ooooool0003o000000Kooooo0_l0000<ooooo`;o0000Q_ooool001kooooo00?o
0000ooooooooool0N?ooool2o`0000oooooo0_l00008ooooo`Co00000oooool5o`0000?ooooo1ol0
0004ooooo`;o00004?ooool2o`0008Kooooo000Nooooo`03o`000?oooooooooo07Oooooo0ol0000I
ooooo`?o00003?ooool4o`000003ooooool0003o000000Cooooo0_l00004ooooo`;o00002_ooool2
o`0008Kooooo000Nooooo`03o`000?oooooooooo07Oooooo0_l0000Hooooo`Oo00001oooool2o`00
0003ooooool0003o000000;ooooo1ol000000ooooooo0000o`000003ooooo`;o00002_ooool3o`00
08Gooooo000Nooooo`;o0000POooool2o`0000kooooo2?l00007ooooo`Go00000_ooool7o`000003
ooooool0003o000000;ooooo0_l0000<ooooo`;o0000QOooool001kooooo00?o0000ooooooooool0
P?ooool2o`0000kooooo1?l000001?oooooo0000o`000?l00008ooooo`;o00001?ooool3o`000003
ooooool0003o000000;o00000_ooool4o`000003ooooool0003o0000093ooooo000Nooooo`03o`00
0?oooooooooo08cooooo0_l00003ooooo`?o00000_ooool2o`0000Oooooo1?l00008ooooo`?o0000
00Coooooo`000?l0003o00000oooool3o`0008oooooo000Nooooo`03o`000?oooooooooo08cooooo
1_l00004ooooo`Go00000oooool5o`0000?ooooo2?l000000ooooooo0000o`000002o`0000?ooooo
0_l00008ooooo`;o0000QOooool001kooooo00?o0000ooooooooool0S?oooolAo`000003ooooool0
003o000000;ooooo0_l000000ooooooo0000o`000005o`0000?ooooo1?l0000=ooooo`;o0000QOoo
ool001kooooo00?o0000ooooooooool0S?oooolCo`000003ooooool0003o000000oo00000_ooool2
o`0000_ooooo0_l00003ooooo`;o0000P?ooool001kooooo00?o0000ooooooooool0S?ooool5o`00
0003ooooool0003o000001Ko000000?oooooo`000?l000001Ol000000ooooooo0000o`00000;oooo
o`;o00000oooool3o`0007oooooo000Nooooo`03o`000?oooooooooo08cooooo2Ol00002ooooo`co
000000?oooooo`000?l000001?ooool3o`000003ooooool0003o000000;o000000?oooooo`000?l0
00002oooool2o`0000Cooooo0_l0001oooooo`007_ooool00ol0003oooooooooo`28ooooo`?o0000
00Goooooo`000?l0003o0000ooooo`05o`0000Cooooo1_l000000ooooooo0000o`000003o`0000Co
oooo3?l0002Booooo`007_ooool00ol0003oooooooooo`1fooooo`;o00003oooool4o`000003oooo
ool0003o000000Ko00000oooool2o`0000;ooooo2_l00002ooooo`Co00000_ooool9o`000003oooo
ool0003o000000;o00003Oooool2o`0007gooooo000Nooooo`03o`000?oooooooooo07Kooooo0_l0
000>ooooo`?o00000_ooool8o`0000Cooooo4_l00003ooooo`[o000000?oooooo`000?l000000_l0
0004ooooo`;o00001oooool2o`0007gooooo000Nooooo`03o`000?oooooooooo07Sooooo0_l0000<
ooooo`;o00000oooool2o`0000Cooooo0_l00002oooooa?o00000oooool5o`000004ooooool0003o
0000o`0000Gooooo0_l00004ooooo`;o0000Q_ooool001kooooo00?o0000ooooooooool0N?ooool2
o`0000Gooooo0_l0000;ooooo`?o00001Oooool=o`0000?ooooo4?l0000:ooooo`;o0000Qoooool0
01kooooo00?o0000ooooooooool0Ooooool2o`0000_ooooo0ol00002ooooo`;o000000?oooooo`00
0?l000002ol000000ooooooo0000o`00000Co`0000Cooooo1Ol00009ooooo`;o0000O?ooool001ko
oooo00?o0000ooooooooool0R?ooool2o`0000?ooooo0_l000000ooooooo0000o`000008o`0000;o
oooo4?l00002ooooo`Wo00001?ooool4o`0000[ooooo0_l0001looooo`007_ooool00ol0003ooooo
ooooo`28ooooo`;o000000?oooooo`000?l000003Ol00002ooooo`So000000?oooooo`000?l00000
1Ol000000ooooooo0000o`000004o`000003ooooool0003o0000097ooooo000Nooooo`;o0000Rooo
oolAo`000003ooooool0003o000001;o00000_ooool5o`0001;ooooo0_l0001looooo`007_ooool0
0ol0003oooooooooo`26ooooo`;o00000_ooool]o`0001;ooooo0ol0001kooooo`007_ooool00ol0
003oooooooooo`1dooooo`?o00003Oooool5o`0000;ooooo4Ol00002ooooo`co00000_ooool7o`00
00oooooo0_l00006ooooo`;o0000Noooool001kooooo00?o0000ooooooooool0M?ooool3o`0000go
oooo0_l000000ooooooo0000o`000003ooooo`Go000000?oooooo`000?l000002Ol000000ooooooo
0000o`000004o`0000;ooooo1?l00003ooooo`Ko00000_ooool2o`000003ooooool0003o000000So
oooo0_l00023ooooo`007_ooool00ol0003oooooooooo`1dooooo`;o00005Oooool3o`000003oooo
ool0003o000000Go00000_oooolCo`000005ooooool0003o0000o`000?ooool00ol000000ooooooo
0000o`000004o`0008gooooo000Nooooo`03o`000?oooooooooo07Cooooo0_l0000?ooooo`?o0000
0oooool8o`000003ooooool0003o000001Go000000Coooooo`000?l0003o00001Oooool5o`0008ko
oooo000Nooooo`03o`000?oooooooooo08Gooooo0ol00002ooooo`Go000000?oooooo`000?l00000
0_oooolLo`0000Kooooo0_l0000?ooooo`;o0000O_ooool001kooooo00?o0000ooooooooool0R_oo
ool4o`0000?ooooo0_l000000ooooooo0000o`00000Ao`000003ooooool0003o000000Ko00001_oo
ool2o`0000cooooo0_l000000ooooooo0000o`00001nooooo`007_ooool00ol0003oooooooooo`26
ooooo`;o00000_ooool4o`0000?ooooo4Ol00002ooooo`[o00001oooool2o`0000gooooo0_l00000
0ooooooo0000o`00001nooooo`007_ooool00ol0003oooooooooo`26ooooo`;o00000_ooool4o`00
00Gooooo2ol000000ooooooo0000o`000004ooooo`Wo00001oooool2o`0000gooooo0_l00021oooo
o`007_ooool00ol0003oooooooooo`1cooooo`;o00005_ooool3o`0000Cooooo3?l00005ooooo`So
00001_ooool4o`0009;ooooo000Nooooo`03o`000?oooooooooo07?ooooo0_l0000Fooooo`;o0000
1Oooool9o`0000Gooooo0_l000000ooooooo0000o`000003o`0000Cooooo0_l00003ooooo`Co0000
T_ooool001kooooo00?o0000ooooooooool0M_ooool2o`0001?ooooo0_l00003ooooo`ko000000Go
ooooo`000?l0003o0000ooooo`06o`0000;ooooo1?l00002ooooo`?o0000Toooool001kooooo00?o
0000ooooooooool0M_ooool2o`0001?ooooo0_l00003ooooo`ko000000Coooooo`000?l0003o0000
1Oooool2o`0000;ooooo1_l000000ooooooo0000o`00002Cooooo`007_ooool00ol0003ooooooooo
o`1hooooo`;o00004_ooool2o`000003ooooool0003o000000?o00000_ooool6o`0000gooooo0_l0
0003ooooo`Co0000UOooool001kooooo00?o0000ooooooooool0N?ooool2o`0001;ooooo1Ol00005
ooooo`Ko00003Oooool2o`0000?ooooo1?l0000>ooooo`;o0000QOooool001kooooo0_l0002>oooo
o`Co00001Oooool6o`0000[ooooo0_l000001?oooooo0000o`000?ooool2o`0001;ooooo0_l00025
ooooo`007_ooool00ol0003oooooooooo`1eooooo`;o00005_ooool2o`000003ooooool0003o0000
00Cooooo1ol000001?oooooo0000o`000?ooool4o`000003ooooool0003o000000Ko00001Oooool2
o`0009;ooooo000Nooooo`03o`000?oooooooooo07Gooooo0_l00005ooooo`;o00003oooool5o`00
00;ooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000002
o`0000?ooooo1_l00004ooooo`?o00000_ooool2o`0000Sooooo0_l00024ooooo`007_ooool00ol0
003oooooooooo`1looooo`;o00004?ooool2o`0000Cooooo0_l00003ooooo`Co00002?ooool5o`00
0003ooooool0003o000000Gooooo0_l00003ooooo`;o00002?ooool2o`0008Cooooo000Nooooo`03
o`000?oooooooooo08cooooo1Ol00008ooooo`Co00001?ooool<o`0009[ooooo000Nooooo`03o`00
0?oooooooooo08;ooooo0_l00008ooooo`Ko00002?ooool2o`000003ooooool0003o000000;ooooo
3?l0000<ooooo`;o0000S?ooool001kooooo00?o0000ooooooooool0P_ooool2o`0000_ooooo0ol0
0007oooooaOo00002Oooool2o`0008cooooo000Nooooo`03o`000?oooooooooo07[ooooo0_l0000C
ooooo`?o00001_oooolCo`0000;ooooo0ol0002Gooooo`007_ooool00ol0003oooooooooo`1joooo
o`;o00003Oooool2o`0000?ooooo1Ol00005ooooo`;o000000?oooooo`000?l000002?l000000ooo
oooo0000o`000002o`0009gooooo000Nooooo`03o`000?oooooooooo08Wooooo0_l00003ooooo`Go
00001oooool3o`000003ooooool0003o000000[o00002?ooool2o`0000_ooooo0_l00026ooooo`00
7_ooool00ol0003oooooooooo`2>ooooo`;o000000?oooooo`000?l000000_l00005ooooo`Co0000
00?oooooo`000?l000001_l000000ooooooo0000o`000008ooooo`;o00002oooool2o`0008Kooooo
000Nooooo`03o`000?oooooooooo08oooooo1_l00002ooooo`;o000000?oooooo`000?l000000_l0
0002ooooo`Co0000Xoooool001kooooo00?o0000ooooooooool0Soooool2o`0000Kooooo1Ol00006
ooooo`;o0000Xoooool001kooooo00?o0000ooooooooool0S_ooool2o`0000Wooooo0_l0002/oooo
o`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000
oa0@4?o<c<`01_ooool00ol0003oooooooooo`2>ooooo`;o00002oooool4o`0001oooooo1?l00025
ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOo
oooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2@ooooo`?o00000oooool4o`000003ooooool0
003o000000;o00007_ooool5o`0008Gooooo0003ooooo`05oa0@4?ooooooooooooooool@41002ooo
ool01Ol0003ooooooooooooooooo000000Kooooo0ol0002@ooooo`?o00000oooool4o`0002?ooooo
0_l00028ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@06ooooo`03o`000?oooooooooo08kooooo0_l0000Uooooo`;o0000T?ooool000?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0
003oooooooooo`2<ooooo`Co00009Oooool2o`00093ooooo0003ooooo`05oa0@4?oooooooooooooo
ool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo08cooooo0_l0000Loooo
o`;o0000Voooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH
00Sooooo00?o0000ooooooooool0R?ooool2o`000003ooooool0003o000001gooooo0_l0002Koooo
o`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_ooool0
0ol0003oooooooooo`28ooooo`;o000000?oooooo`000?l00000:?ooool2o`00093ooooo000Noooo
o`03o`000?oooooooooo087ooooo0_l0000booooo`;o0000T?ooool001kooooo00?o0000oooooooo
ool0POooool2o`0002kooooo0_l0002Dooooo`007_ooool00ol0003oooooooooo`2_ooooo`Co0000
U?ooool001kooooo00?o0000ooooooooool0Toooool2o`0001[ooooo0_l0002Fooooo`007_ooool0
0ol0003oooooooooo`2Cooooo`;o0000/_ooool001kooooo00?o0000ooooooooool0V_ooool2o`00
00Oooooo0_l000000ooooooo0000o`00002Oooooo`007_ooool00ol0003oooooooooo`2Hooooo`Co
00001oooool2o`000003ooooool0003o000009oooooo000Nooooo`03o`000?oooooooooo09Sooooo
1?l0002[ooooo`007_ooool00ol0003oooooooooo`2Jooooo`;o00000oooool2o`000003ooooool0
003o00000:?ooooo000Nooooo`03o`000?oooooooooo08gooooo0_l0000>ooooo`Co000000?ooooo
o`000?l00000Xoooool001kooooo00?o0000ooooooooool0SOooool2o`0000kooooo0ol0002Woooo
o`007_ooool2o`0009oooooo0_l0002Wooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0
003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co
8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool0
0ol0003oooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool0
1Ol0003ooooooooooooooooo000000Kooooo0ol0003oooooodSooooo0003ooooo`05o`000?oooooo
ooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000ooooooooool0
oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o
0000olc<c006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooo
oooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`3ooooo
odSooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o
000000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001Co
oooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB?ooool001Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodSooooo000Fooooo`03o`000?oo
oooooooo00Gooooo0ol0003oooooodSooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool0
01Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3o
oooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Cooooo00?oEEEEofIVI_l00000oooo
oomBooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.48784 .55456 Mdot
.46177 .50543 Mdot
.51378 .41138 Mdot
.46531 .48957 Mdot
.48101 .47577 Mdot
.50672 .57419 Mdot
.43479 .59135 Mdot
.45163 .48508 Mdot
.50515 .56692 Mdot
.43727 .50643 Mdot
.4626 .53583 Mdot
.49275 .5165 Mdot
.53193 .55138 Mdot
.57712 .47866 Mdot
.5043 .63187 Mdot
.49379 .45819 Mdot
.46254 .52578 Mdot
.53261 .56154 Mdot
.43989 .56647 Mdot
.55834 .49141 Mdot
.46171 .5299 Mdot
.52365 .45817 Mdot
.47894 .48538 Mdot
.56671 .54132 Mdot
.45164 .51064 Mdot
.50533 .51273 Mdot
.44124 .47766 Mdot
.47812 .58196 Mdot
.48585 .48329 Mdot
.52435 .57098 Mdot
.54091 .5224 Mdot
.4616 .50143 Mdot
.50634 .50123 Mdot
.51049 .42735 Mdot
.52933 .56272 Mdot
.52829 .44044 Mdot
.51146 .51088 Mdot
.46761 .45629 Mdot
.48448 .47655 Mdot
.50631 .51651 Mdot
.49839 .47013 Mdot
.55673 .48494 Mdot
.50779 .53851 Mdot
.49389 .50845 Mdot
.46332 .50351 Mdot
.52599 .49893 Mdot
.51622 .44048 Mdot
.55353 .50491 Mdot
.56025 .49462 Mdot
.64069 .49944 Mdot
.48995 .47384 Mdot
.53914 .38826 Mdot
.48374 .48597 Mdot
.47418 .47757 Mdot
.47888 .45101 Mdot
.52539 .50941 Mdot
.50243 .52808 Mdot
.48585 .35068 Mdot
.45902 .48405 Mdot
.5134 .5291 Mdot
.53271 .49817 Mdot
.52172 .5028 Mdot
.53245 .45028 Mdot
.49312 .45838 Mdot
.50089 .47581 Mdot
.58395 .55976 Mdot
.49949 .54395 Mdot
.53036 .5035 Mdot
.54456 .49959 Mdot
.49431 .45835 Mdot
.44579 .56639 Mdot
.46576 .48011 Mdot
.52701 .522 Mdot
.48062 .49651 Mdot
.54842 .55574 Mdot
.44607 .48652 Mdot
.54143 .49948 Mdot
.5482 .5518 Mdot
.44908 .51926 Mdot
.46315 .56585 Mdot
.49065 .45025 Mdot
.44869 .48709 Mdot
.45889 .51647 Mdot
.51081 .48649 Mdot
.52286 .44112 Mdot
.48178 .49232 Mdot
.48611 .43153 Mdot
.52491 .50476 Mdot
.50877 .51788 Mdot
.60861 .46218 Mdot
.49436 .48499 Mdot
.52069 .48762 Mdot
.48491 .43674 Mdot
.63633 .5243 Mdot
.48711 .43653 Mdot
.53427 .48721 Mdot
.52607 .50602 Mdot
.53411 .52592 Mdot
.4997 .43398 Mdot
.48753 .52752 Mdot
.48329 .43462 Mdot
.49006 .43518 Mdot
.46117 .47817 Mdot
.59522 .52827 Mdot
.48916 .56029 Mdot
.50808 .50281 Mdot
.4101 .56257 Mdot
.49781 .47912 Mdot
.4858 .54143 Mdot
.51951 .48476 Mdot
.5307 .55373 Mdot
.46453 .48105 Mdot
.47474 .51042 Mdot
.41325 .50147 Mdot
.49076 .54243 Mdot
.55669 .46067 Mdot
.43056 .45466 Mdot
.48266 .58677 Mdot
.55286 .43064 Mdot
.48135 .43664 Mdot
.52911 .55302 Mdot
.50053 .51227 Mdot
.44383 .48771 Mdot
.55584 .51212 Mdot
.46334 .51985 Mdot
.42441 .4911 Mdot
.54492 .55466 Mdot
.50264 .51232 Mdot
.49756 .51003 Mdot
.48309 .45688 Mdot
.50695 .57301 Mdot
.46349 .53641 Mdot
.47621 .37838 Mdot
.55139 .47366 Mdot
.45282 .48838 Mdot
.47285 .38369 Mdot
.43896 .57533 Mdot
.49426 .49683 Mdot
.53804 .51233 Mdot
.48247 .51107 Mdot
.49613 .48122 Mdot
.43095 .51631 Mdot
.50181 .50875 Mdot
.47097 .48549 Mdot
.50867 .49157 Mdot
.52034 .48484 Mdot
.49223 .56256 Mdot
.54223 .47662 Mdot
.49604 .5403 Mdot
.55961 .51039 Mdot
.54214 .4635 Mdot
.48778 .58363 Mdot
.49012 .47819 Mdot
.58097 .50252 Mdot
.48476 .57704 Mdot
.49362 .45797 Mdot
.51989 .50124 Mdot
.53669 .45201 Mdot
.54174 .49913 Mdot
.50482 .48747 Mdot
.46522 .62151 Mdot
.551 .49242 Mdot
.55703 .53603 Mdot
.47235 .45017 Mdot
.5056 .52296 Mdot
.48054 .52145 Mdot
.47473 .55268 Mdot
.51541 .47073 Mdot
.5465 .46991 Mdot
.46169 .4691 Mdot
.47158 .57909 Mdot
.55193 .52178 Mdot
.46421 .5171 Mdot
.51248 .52144 Mdot
.4774 .64504 Mdot
.51771 .50886 Mdot
.52444 .47372 Mdot
.50516 .4836 Mdot
.49503 .43985 Mdot
.56217 .49685 Mdot
.46871 .48864 Mdot
.52533 .4858 Mdot
.48687 .49935 Mdot
.48289 .48481 Mdot
.5401 .52745 Mdot
.48807 .51645 Mdot
.49142 .41749 Mdot
.53285 .49869 Mdot
.61784 .53708 Mdot
.47226 .44315 Mdot
.48868 .51144 Mdot
.49169 .46037 Mdot
.56778 .54159 Mdot
.49304 .47835 Mdot
.46856 .46332 Mdot
.49718 .47128 Mdot
.63956 .49269 Mdot
.50126 .50526 Mdot
.50579 .47424 Mdot
.46513 .49517 Mdot
.47726 .52575 Mdot
.53419 .50385 Mdot
.51932 .56086 Mdot
.53992 .47718 Mdot
.47614 .45273 Mdot
.46631 .52065 Mdot
.46031 .53733 Mdot
.49654 .52999 Mdot
.4995 .4175 Mdot
.49171 .47625 Mdot
.46366 .50806 Mdot
.50755 .51096 Mdot
.5244 .51104 Mdot
.49605 .55547 Mdot
.50035 .51238 Mdot
.52541 .4475 Mdot
.52526 .49323 Mdot
.53986 .50057 Mdot
.42787 .51375 Mdot
.49979 .48251 Mdot
.49696 .46653 Mdot
.48753 .36427 Mdot
.52212 .48704 Mdot
.55322 .46537 Mdot
.43618 .48245 Mdot
.44507 .48571 Mdot
.45916 .491 Mdot
.43832 .49843 Mdot
.49739 .41743 Mdot
.44196 .53403 Mdot
.47061 .4451 Mdot
.5056 .51106 Mdot
.4141 .49317 Mdot
.51594 .50377 Mdot
.51351 .51281 Mdot
.53937 .51269 Mdot
.42017 .48652 Mdot
.44484 .481 Mdot
.46576 .53114 Mdot
.48816 .51649 Mdot
.437 .50383 Mdot
.49178 .62774 Mdot
.5095 .56635 Mdot
.43284 .48177 Mdot
.48806 .44785 Mdot
.48354 .45262 Mdot
.44065 .51742 Mdot
.44996 .48346 Mdot
.45937 .45427 Mdot
.42768 .46505 Mdot
.50523 .53595 Mdot
.54397 .51427 Mdot
.46006 .56046 Mdot
.49033 .44001 Mdot
.47651 .50647 Mdot
.48799 .52036 Mdot
.46425 .48506 Mdot
.52857 .50815 Mdot
.51622 .43449 Mdot
.43756 .50884 Mdot
.51504 .47023 Mdot
.49164 .46306 Mdot
.50515 .48794 Mdot
.50169 .56479 Mdot
.55885 .48815 Mdot
.53888 .45772 Mdot
.42945 .50371 Mdot
.51078 .57962 Mdot
.50376 .484 Mdot
.48212 .4308 Mdot
.49522 .54517 Mdot
.47495 .51096 Mdot
.61553 .53808 Mdot
.47912 .51104 Mdot
.49794 .41524 Mdot
.43868 .54538 Mdot
.53382 .50556 Mdot
.4366 .55594 Mdot
.55718 .4968 Mdot
.43695 .5302 Mdot
.54119 .5073 Mdot
.51101 .51356 Mdot
.58134 .47612 Mdot
.50332 .4966 Mdot
.43656 .46344 Mdot
.63581 .52066 Mdot
.50916 .44379 Mdot
.48111 .48084 Mdot
.465 .52627 Mdot
.57629 .50596 Mdot
.49588 .52175 Mdot
.53354 .53097 Mdot
.56266 .46575 Mdot
.5244 .53532 Mdot
.48012 .52131 Mdot
.46731 .47761 Mdot
.49033 .58285 Mdot
.56257 .49627 Mdot
.547 .47657 Mdot
.46431 .48859 Mdot
.49595 .50428 Mdot
.44433 .48592 Mdot
.52548 .5755 Mdot
.5039 .4672 Mdot
.49269 .51907 Mdot
.46558 .48823 Mdot
.40728 .39053 Mdot
.51633 .53934 Mdot
.45166 .51413 Mdot
.5612 .49462 Mdot
.47192 .49289 Mdot
.50418 .49793 Mdot
.43101 .49942 Mdot
.46138 .52229 Mdot
.46485 .50106 Mdot
.49379 .53718 Mdot
.50764 .51588 Mdot
.52826 .50399 Mdot
.52806 .51963 Mdot
.47702 .46048 Mdot
.56146 .50436 Mdot
.46936 .53442 Mdot
.47322 .54819 Mdot
.5199 .50952 Mdot
.46291 .57702 Mdot
.48906 .46602 Mdot
.49104 .51047 Mdot
.49756 .51077 Mdot
.46108 .55851 Mdot
.4937 .43474 Mdot
.50167 .56914 Mdot
.55299 .44422 Mdot
.47475 .51234 Mdot
.43612 .5164 Mdot
.50364 .42029 Mdot
.45819 .47279 Mdot
.54845 .47337 Mdot
.46538 .48447 Mdot
.46117 .50684 Mdot
.52207 .50366 Mdot
.50644 .54301 Mdot
.4887 .535 Mdot
.36327 .53499 Mdot
.50288 .50679 Mdot
.52438 .46277 Mdot
.4788 .543 Mdot
.50223 .49664 Mdot
.4575 .47939 Mdot
.51134 .46864 Mdot
.51071 .48603 Mdot
.49868 .52586 Mdot
.48321 .37711 Mdot
.46234 .52133 Mdot
.51476 .50702 Mdot
.55334 .5141 Mdot
.48714 .52382 Mdot
.58366 .48774 Mdot
.46588 .53741 Mdot
.58768 .43629 Mdot
.5084 .5012 Mdot
.50282 .47373 Mdot
.4993 .53443 Mdot
.47778 .51794 Mdot
.58719 .50065 Mdot
.47015 .5409 Mdot
.57921 .46556 Mdot
.51024 .43575 Mdot
.51801 .47094 Mdot
.39401 .43054 Mdot
.48351 .49275 Mdot
.50443 .48684 Mdot
.4955 .49291 Mdot
.49064 .37525 Mdot
.44178 .49594 Mdot
.54012 .42669 Mdot
.45667 .4668 Mdot
.43829 .51398 Mdot
.47052 .4445 Mdot
.55787 .48599 Mdot
.50819 .51192 Mdot
.55895 .49031 Mdot
.47008 .46052 Mdot
.47403 .48226 Mdot
.55932 .48073 Mdot
.45877 .48904 Mdot
.48627 .57812 Mdot
.48204 .58281 Mdot
.46229 .47067 Mdot
.52115 .51135 Mdot
.56071 .49419 Mdot
.43524 .3752 Mdot
.55636 .49231 Mdot
.56172 .50271 Mdot
.46147 .50067 Mdot
.48827 .47885 Mdot
.45448 .48781 Mdot
.4924 .4596 Mdot
.50592 .49868 Mdot
.46445 .57811 Mdot
.44234 .38164 Mdot
.42628 .39095 Mdot
.55596 .48238 Mdot
.41637 .38228 Mdot
.50994 .51392 Mdot
.56048 .50776 Mdot
.54283 .45829 Mdot
.48047 .48429 Mdot
.50187 .48451 Mdot
.48241 .52815 Mdot
.459 .56856 Mdot
.48497 .51358 Mdot
.44174 .56632 Mdot
.48225 .49595 Mdot
.55326 .50619 Mdot
.48602 .49464 Mdot
.48717 .43595 Mdot
.51423 .47755 Mdot
.56653 .53625 Mdot
.52554 .53004 Mdot
.44502 .48167 Mdot
.43571 .55133 Mdot
.52792 .49986 Mdot
.48661 .50068 Mdot
.43666 .53661 Mdot
.45499 .35742 Mdot
.54032 .45997 Mdot
.50912 .59974 Mdot
.50244 .48105 Mdot
.54909 .5066 Mdot
.52155 .51185 Mdot
.54407 .52204 Mdot
.49522 .45912 Mdot
.4592 .53963 Mdot
.43621 .55662 Mdot
.54332 .47206 Mdot
.56969 .53671 Mdot
.54415 .46867 Mdot
.50554 .52803 Mdot
.53422 .52756 Mdot
.51059 .52254 Mdot
.53138 .53463 Mdot
.60268 .40423 Mdot
.56043 .51592 Mdot
.49122 .57043 Mdot
.50858 .50213 Mdot
.50378 .57665 Mdot
.47558 .47926 Mdot
.47871 .45235 Mdot
.51001 .42535 Mdot
.49151 .48391 Mdot
.56066 .44768 Mdot
.48556 .51605 Mdot
.50354 .47583 Mdot
.5141 .51958 Mdot
.49904 .43267 Mdot
.44946 .54647 Mdot
.5461 .46976 Mdot
.47497 .45723 Mdot
.50083 .48937 Mdot
.52462 .51024 Mdot
.53918 .47544 Mdot
.47673 .49746 Mdot
.5652 .47813 Mdot
.51448 .50375 Mdot
.55748 .51598 Mdot
.51319 .43398 Mdot
.51181 .49497 Mdot
.48575 .50456 Mdot
.52312 .53446 Mdot
.53238 .50574 Mdot
.47849 .53211 Mdot
.44581 .48664 Mdot
.4035 .6149 Mdot
.5366 .64203 Mdot
.45649 .57661 Mdot
.47259 .55574 Mdot
.55856 .47851 Mdot
.54431 .64198 Mdot
.48054 .43677 Mdot
.48546 .39135 Mdot
.50397 .49983 Mdot
.4624 .51936 Mdot
.44807 .48496 Mdot
.45893 .48483 Mdot
.52929 .49979 Mdot
.54418 .47679 Mdot
.43643 .51753 Mdot
.49263 .55912 Mdot
.55757 .51621 Mdot
.46784 .44692 Mdot
.56848 .38615 Mdot
.49806 .41803 Mdot
.54477 .56614 Mdot
.50545 .47728 Mdot
.50059 .53215 Mdot
.55258 .5103 Mdot
.41861 .4816 Mdot
.50742 .47991 Mdot
.5501 .48024 Mdot
.44186 .49122 Mdot
.36072 .52872 Mdot
.46812 .56897 Mdot
.39497 .60996 Mdot
.47718 .45874 Mdot
.48669 .51685 Mdot
.43953 .54296 Mdot
.47434 .54647 Mdot
.44872 .47149 Mdot
.47194 .44004 Mdot
.63889 .51128 Mdot
.55605 .4928 Mdot
.52899 .44606 Mdot
.49964 .53522 Mdot
.51505 .55535 Mdot
.44069 .48715 Mdot
.49911 .46256 Mdot
.50131 .53463 Mdot
.52606 .5653 Mdot
.56946 .45585 Mdot
.45961 .51356 Mdot
.45174 .45918 Mdot
.49457 .54578 Mdot
.44775 .50636 Mdot
.50863 .51276 Mdot
.48433 .52128 Mdot
.5258 .5066 Mdot
.55743 .4829 Mdot
.54726 .38806 Mdot
.49022 .57673 Mdot
.45074 .57604 Mdot
.51885 .44707 Mdot
.52015 .48461 Mdot
.53281 .50643 Mdot
.47657 .49886 Mdot
.60325 .5441 Mdot
.49282 .51476 Mdot
.54963 .47805 Mdot
.53081 .50237 Mdot
.50153 .52966 Mdot
.43821 .56081 Mdot
.47668 .50845 Mdot
.58323 .51994 Mdot
.51429 .47783 Mdot
.56656 .51143 Mdot
.49611 .57381 Mdot
.44437 .51452 Mdot
.47525 .48318 Mdot
.60025 .49738 Mdot
.46476 .47856 Mdot
.43405 .54801 Mdot
.5064 .5184 Mdot
.46799 .48475 Mdot
.50759 .49585 Mdot
.35379 .51511 Mdot
.46118 .48389 Mdot
.50061 .46645 Mdot
.49783 .4872 Mdot
.54968 .51765 Mdot
.575 .4058 Mdot
.45516 .44254 Mdot
.49269 .43337 Mdot
.50207 .42444 Mdot
.4704 .45611 Mdot
.48512 .48985 Mdot
.55627 .4805 Mdot
.46103 .48514 Mdot
.43096 .64402 Mdot
.4364 .52811 Mdot
.55856 .48568 Mdot
.55898 .48713 Mdot
.48701 .43249 Mdot
.50482 .51186 Mdot
.54187 .52314 Mdot
.46269 .47718 Mdot
.48686 .51563 Mdot
.50097 .46753 Mdot
.60374 .48749 Mdot
.5062 .51776 Mdot
.45204 .46496 Mdot
.49902 .51421 Mdot
.49103 .41993 Mdot
.46825 .48033 Mdot
.36648 .55898 Mdot
.47654 .52633 Mdot
.54827 .49396 Mdot
.43711 .43919 Mdot
.45278 .48644 Mdot
.482 .54333 Mdot
.47043 .54285 Mdot
.52983 .45058 Mdot
.48789 .51743 Mdot
.52147 .49476 Mdot
.50693 .47351 Mdot
.49215 .5124 Mdot
.47805 .45298 Mdot
.50237 .56826 Mdot
.57263 .52428 Mdot
.5172 .47351 Mdot
.55353 .53892 Mdot
.4631 .5093 Mdot
.53302 .47657 Mdot
.48779 .4539 Mdot
.47628 .53618 Mdot
.53759 .53265 Mdot
.52071 .49328 Mdot
.49307 .54247 Mdot
.47459 .4563 Mdot
.5454 .42355 Mdot
.52099 .50323 Mdot
.49656 .51139 Mdot
.50175 .5907 Mdot
.50512 .5568 Mdot
.46048 .48979 Mdot
.47159 .43239 Mdot
.49367 .56075 Mdot
.4859 .47912 Mdot
.49245 .47406 Mdot
.47261 .45264 Mdot
.50073 .47654 Mdot
.48137 .63928 Mdot
.43767 .58065 Mdot
.52519 .3622 Mdot
.4729 .50401 Mdot
.51988 .50189 Mdot
.47973 .45908 Mdot
.56122 .49478 Mdot
.49131 .48063 Mdot
.49839 .49066 Mdot
.47854 .38662 Mdot
.46481 .52394 Mdot
.53251 .50073 Mdot
.48515 .45337 Mdot
.55986 .50447 Mdot
.58949 .51743 Mdot
.59239 .51044 Mdot
.45801 .50359 Mdot
.45388 .46154 Mdot
.48526 .50776 Mdot
.45956 .48019 Mdot
.51179 .44484 Mdot
.45465 .48139 Mdot
.53888 .50182 Mdot
.52171 .4292 Mdot
.50558 .48657 Mdot
.47773 .45492 Mdot
.51973 .54369 Mdot
.54378 .52443 Mdot
.51214 .5016 Mdot
.44857 .52756 Mdot
.44706 .53959 Mdot
.44699 .50251 Mdot
.50743 .49426 Mdot
.50648 .50819 Mdot
.48542 .54117 Mdot
.47357 .51831 Mdot
.51108 .53671 Mdot
.58637 .5678 Mdot
.48695 .50969 Mdot
.53988 .46298 Mdot
.49293 .51294 Mdot
.46336 .47869 Mdot
.50858 .49484 Mdot
.58592 .50096 Mdot
.47325 .35073 Mdot
.36847 .49463 Mdot
.53918 .45904 Mdot
.511 .46766 Mdot
.40917 .3882 Mdot
.52173 .56045 Mdot
.58221 .60967 Mdot
.46285 .51662 Mdot
.46754 .35466 Mdot
.41981 .38781 Mdot
.48342 .44769 Mdot
.47886 .45593 Mdot
.44315 .51212 Mdot
.54201 .51498 Mdot
.46232 .49987 Mdot
.4977 .58298 Mdot
.46453 .47861 Mdot
.52845 .49377 Mdot
.49361 .43399 Mdot
.4732 .53344 Mdot
.4905 .43573 Mdot
.46303 .51638 Mdot
.53617 .50359 Mdot
.46295 .51917 Mdot
.53943 .52685 Mdot
.52103 .51653 Mdot
.55607 .50294 Mdot
.54351 .49234 Mdot
.52264 .43066 Mdot
.51987 .36621 Mdot
.51625 .51199 Mdot
.56166 .50445 Mdot
.45881 .53884 Mdot
.37955 .55311 Mdot
.49663 .50634 Mdot
.51663 .4819 Mdot
.46406 .48719 Mdot
.46749 .4891 Mdot
.49403 .51465 Mdot
.57881 .48015 Mdot
.50036 .47587 Mdot
.53985 .4179 Mdot
.4519 .61016 Mdot
.52319 .50698 Mdot
.48971 .4744 Mdot
.51069 .43277 Mdot
.4368 .54049 Mdot
.52374 .56675 Mdot
.49496 .51177 Mdot
.49894 .42613 Mdot
.45731 .5875 Mdot
.58073 .50558 Mdot
.44225 .47806 Mdot
.45033 .58542 Mdot
.45804 .53906 Mdot
.49632 .57832 Mdot
.50267 .5827 Mdot
.47939 .49076 Mdot
.4562 .56992 Mdot
.54798 .50959 Mdot
.47633 .49532 Mdot
.48988 .55148 Mdot
.49175 .52628 Mdot
.60556 .47248 Mdot
.50298 .55025 Mdot
.54953 .47737 Mdot
.54146 .49589 Mdot
.47993 .57741 Mdot
.50739 .47973 Mdot
.49264 .52485 Mdot
.51598 .49711 Mdot
.55748 .4124 Mdot
.44147 .57507 Mdot
.5147 .51146 Mdot
.52171 .46223 Mdot
.43999 .56433 Mdot
.53467 .50494 Mdot
.52531 .49695 Mdot
.54917 .5129 Mdot
.51441 .51272 Mdot
.44057 .49529 Mdot
.50773 .47717 Mdot
.4809 .47436 Mdot
.50451 .47779 Mdot
.52349 .50479 Mdot
.49837 .50974 Mdot
.4885 .55343 Mdot
.55721 .48191 Mdot
.50282 .49091 Mdot
.50999 .5266 Mdot
.48227 .4744 Mdot
.47385 .44327 Mdot
.57739 .50548 Mdot
.43195 .5164 Mdot
.45136 .47441 Mdot
.53436 .5296 Mdot
.43362 .54198 Mdot
.50698 .57799 Mdot
.48867 .57841 Mdot
.55946 .62901 Mdot
.55494 .49072 Mdot
.60693 .47331 Mdot
.47768 .50169 Mdot
.54333 .45122 Mdot
.47621 .48336 Mdot
.49347 .50987 Mdot
.5367 .4452 Mdot
.47176 .57249 Mdot
.53648 .52395 Mdot
.53188 .56331 Mdot
.48549 .49261 Mdot
.51853 .43336 Mdot
.46401 .43789 Mdot
.55318 .62252 Mdot
.45056 .51154 Mdot
.48284 .5035 Mdot
.53218 .50654 Mdot
.48023 .45548 Mdot
.48173 .54359 Mdot
.52052 .5746 Mdot
.58435 .38055 Mdot
.46084 .3555 Mdot
.43961 .55406 Mdot
.46966 .51741 Mdot
.49206 .46312 Mdot
.4735 .58122 Mdot
.55427 .48089 Mdot
.46505 .49896 Mdot
.51843 .56364 Mdot
.47332 .49002 Mdot
.47318 .45495 Mdot
.48366 .54029 Mdot
.51587 .46454 Mdot
.49924 .54477 Mdot
.35478 .52393 Mdot
.47525 .45376 Mdot
.42603 .46793 Mdot
.49245 .46448 Mdot
.49715 .52928 Mdot
.47355 .43853 Mdot
.59743 .61239 Mdot
.48316 .55135 Mdot
.48443 .45497 Mdot
.50098 .52346 Mdot
.44274 .49154 Mdot
.46278 .51256 Mdot
.54005 .57512 Mdot
.47512 .48359 Mdot
.44402 .50866 Mdot
.47465 .48758 Mdot
.48495 .55779 Mdot
.47128 .4556 Mdot
.51035 .53778 Mdot
.53597 .49739 Mdot
.49446 .52762 Mdot
.46247 .53425 Mdot
.55166 .5173 Mdot
.5128 .49729 Mdot
.47493 .50468 Mdot
.44171 .56835 Mdot
.43765 .55899 Mdot
.46698 .53786 Mdot
.46415 .59013 Mdot
.50235 .47479 Mdot
.46643 .53066 Mdot
.48121 .53885 Mdot
.51524 .51254 Mdot
.37245 .487 Mdot
.50882 .54354 Mdot
.55039 .42383 Mdot
.52759 .50178 Mdot
.50471 .51077 Mdot
.47924 .45597 Mdot
.55658 .48214 Mdot
.46771 .56818 Mdot
.47171 .50135 Mdot
.45004 .46159 Mdot
.49178 .55801 Mdot
.52477 .4956 Mdot
.53129 .49048 Mdot
.46905 .63345 Mdot
.44919 .53144 Mdot
.50251 .43426 Mdot
.58445 .60638 Mdot
.55487 .47879 Mdot
.52743 .49686 Mdot
.52906 .52046 Mdot
.46423 .52563 Mdot
.54851 .52782 Mdot
.54628 .4572 Mdot
.41711 .38716 Mdot
.48123 .652 Mdot
.48537 .51602 Mdot
.50766 .49298 Mdot
.51408 .55054 Mdot
.48577 .50263 Mdot
.49561 .47851 Mdot
.5017 .42982 Mdot
.48515 .51629 Mdot
.5049 .49674 Mdot
.48621 .43638 Mdot
.49806 .584 Mdot
.50114 .42288 Mdot
.46625 .51727 Mdot
.52024 .58405 Mdot
.46227 .50271 Mdot
.50596 .34477 Mdot
.51136 .57067 Mdot
.45019 .46286 Mdot
.56517 .46206 Mdot
.50422 .56901 Mdot
.46473 .54174 Mdot
.48436 .49308 Mdot
.47433 .47959 Mdot
.52016 .4892 Mdot
.50579 .51881 Mdot
.54934 .39335 Mdot
.37701 .48704 Mdot
.49019 .3762 Mdot
.49596 .54216 Mdot
.48767 .48747 Mdot
.61315 .44088 Mdot
.45923 .48672 Mdot
.52021 .51498 Mdot
.49875 .46461 Mdot
.45802 .45428 Mdot
.50791 .39882 Mdot
.54554 .49126 Mdot
.50529 .50717 Mdot
.48127 .42959 Mdot
.43548 .55382 Mdot
.50797 .48146 Mdot
.60448 .54222 Mdot
.48219 .48013 Mdot
.48521 .53843 Mdot
.47748 .51279 Mdot
.47291 .51317 Mdot
.47255 .57628 Mdot
.47768 .52585 Mdot
.46349 .54131 Mdot
.46341 .50261 Mdot
.44636 .55992 Mdot
.47944 .48983 Mdot
.46378 .44786 Mdot
.534 .51529 Mdot
.46687 .47808 Mdot
.50794 .53626 Mdot
.52575 .44942 Mdot
.52686 .47616 Mdot
.48178 .51679 Mdot
.48915 .47629 Mdot
.46193 .51091 Mdot
.49736 .51541 Mdot
.49151 .43229 Mdot
.39545 .5342 Mdot
.53412 .55584 Mdot
.45727 .44372 Mdot
.51956 .49477 Mdot
.49615 .5082 Mdot
.57977 .48346 Mdot
.50267 .4354 Mdot
.45335 .54153 Mdot
.47566 .49389 Mdot
.47123 .47677 Mdot
.49438 .51874 Mdot
.58332 .58635 Mdot
.48043 .48653 Mdot
.47126 .51968 Mdot
.55153 .4814 Mdot
.55249 .57142 Mdot
.46525 .52956 Mdot
.48735 .50481 Mdot
.6389 .48865 Mdot
.52058 .50265 Mdot
.39318 .46692 Mdot
.43494 .46953 Mdot
.44302 .57028 Mdot
.53938 .45418 Mdot
.45015 .5087 Mdot
.56101 .50795 Mdot
.47641 .492 Mdot
.53759 .50286 Mdot
.50042 .56223 Mdot
.52683 .53381 Mdot
.55859 .50182 Mdot
.53332 .52656 Mdot
.56623 .4994 Mdot
.47522 .5819 Mdot
.48082 .5111 Mdot
.57702 .51995 Mdot
.4684 .53428 Mdot
.46897 .49054 Mdot
.51003 .58218 Mdot
.48617 .43563 Mdot
.50793 .47089 Mdot
.38777 .46212 Mdot
.49151 .64866 Mdot
.50518 .45552 Mdot
.48681 .49604 Mdot
.51533 .45915 Mdot
.50718 .50986 Mdot
.51281 .49791 Mdot
.52574 .53671 Mdot
.49305 .41645 Mdot
.47374 .52376 Mdot
.50534 .47585 Mdot
.47612 .43767 Mdot
.54689 .47011 Mdot
.50719 .54962 Mdot
.55511 .42588 Mdot
.51651 .46997 Mdot
.39729 .42644 Mdot
.49796 .4613 Mdot
.39628 .56616 Mdot
.48748 .49828 Mdot
.50757 .51387 Mdot
.53855 .55745 Mdot
.6069 .43014 Mdot
.50076 .48455 Mdot
.45845 .48088 Mdot
.44144 .48668 Mdot
.53952 .52892 Mdot
.55464 .43094 Mdot
.48166 .54883 Mdot
.47012 .509 Mdot
.50643 .4694 Mdot
.44954 .48363 Mdot
.48758 .55427 Mdot
.49431 .47371 Mdot
.49906 .53954 Mdot
.43764 .52012 Mdot
.45581 .46516 Mdot
.53621 .50328 Mdot
.45868 .44793 Mdot
.494 .42682 Mdot
.46169 .6258 Mdot
.60241 .49095 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0X?ooool2o`000:Gooooo000Nooooo`03o`000?oooooooooo0:3ooooo
0_l0002Uooooo`007_ooool2o`0009Oooooo0_l00002ooooo`;o0000Zoooool001kooooo00?o0000
ooooooooool0U?ooool4o`0000;ooooo0_l0002[ooooo`007_ooool00ol0003oooooooooo`2@oooo
o`Ko0000/Oooool001kooooo00?o0000ooooooooool0T?ooool4o`000;?ooooo000Nooooo`03o`00
0?oooooooooo09[ooooo0_l0000;ooooo`;o0000W_ooool001kooooo00?o0000ooooooooool0V_oo
ool2o`0000Wooooo1?l0002Nooooo`007_ooool00ol0003oooooooooo`2Uooooo`;o0000X?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`29ooooo`;o
00004?ooool2o`000:[ooooo000Nooooo`03o`000?oooooooooo08Wooooo0_l0000<ooooo`Ko0000
Z_ooool001kooooo00?o0000ooooooooool0Poooool2o`0000Oooooo0_l00009ooooo`Co00007ooo
ool2o`0008_ooooo000Nooooo`03o`000?oooooooooo08?ooooo0_l00007ooooo`;o00002?ooool2
o`0002;ooooo0_l0002;ooooo`007_ooool00ol0003oooooooooo`21ooooo`Go00004?ooool3o`00
01;ooooo0_l000000ooooooo0000o`000005ooooo`;o0000T?ooool001kooooo00?o0000oooooooo
ool0P?ooool8o`0000oooooo0_l000000ooooooo0000o`00000?ooooo`;o000000?oooooo`000?l0
00001Oooool2o`00093ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo083ooooo0_l00004ooooo`;o
00004_ooool2o`0001;ooooo0_l0002Gooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0[_ooool2o`0009Oo
oooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol0002Qooooo`;o
0000Y?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`00
00Oooooo00?o0000ooooooooool0XOooool2o`0001gooooo0_l00025ooooo`000oooool01Ol0003o
oooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`2g
ooooo`;o00001oooool2o`0008Gooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo0;Oooooo0_l0002>ooooo`000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2S
ooooo`;o00003?ooool2o`0009Cooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool0
0omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo09cooooo1?l00003ooooo`;o00003?ooool2
o`0009Cooooo000Nooooo`03o`000?oooooooooo09cooooo1?l0000;ooooo`;o0000V_ooool001ko
oooo00?o0000ooooooooool0W?ooool6o`0000Wooooo0_l0002Jooooo`007_ooool00ol0003ooooo
ooooo`2Looooo`;o000000?oooooo`000?l000000ol00009ooooo`Go0000UOooool001kooooo00?o
0000ooooooooool0OOooool2o`0001gooooo1Ol000000ooooooo0000o`000007ooooo`Oo0000UOoo
ool001kooooo00?o0000ooooooooool0O?ooool3o`0001Wooooo2Ol000001?oooooo0000o`000?oo
ool3o`0000?ooooo0_l00003ooooo`;o00003oooool2o`0008Cooooo000Nooooo`03o`000?oooooo
oooo07cooooo0_l0000Gooooo`;o000000?oooooo`000?l000001ol000000ooooooo0000o`000004
o`0000Sooooo0_l0000?ooooo`;o0000Q?ooool001kooooo00?o0000ooooooooool0Toooool>o`00
0003ooooool0003o000000;o00005Oooool2o`0008[ooooo000Nooooo`03o`000?oooooooooo08[o
oooo0_l00007ooooo`ko000000?oooooo`000?l000001_l0000Aooooo`;o00001_ooool2o`0008;o
oooo000Nooooo`03o`000?oooooooooo08[ooooo0_l00004ooooo`?o00000_ooool3o`0000?ooooo
1?l00002ooooo`;o000000?oooooo`000?l000001?l00006ooooo`;o00004Oooool2o`0008;ooooo
000Nooooo`03o`000?oooooooooo093ooooo0ol000000ooooooo0000o`000002o`0000Wooooo0ol0
00001?oooooo0000o`000?ooool4o`0000Cooooo0_l0002Eooooo`007_ooool00ol0003ooooooooo
o`2Aooooo`Ko00000_ooool4o`0000Gooooo0_l000000ooooooo0000o`000005o`0000Kooooo0_l0
002Cooooo`007_ooool2o`0009;ooooo3?l0000:ooooo`Go000000?oooooo`000?l000000oooool2
o`0009?ooooo000Nooooo`03o`000?oooooooooo08Sooooo0_l00007ooooo`;o000000?oooooo`00
0?l000001_l00004ooooo`;o00001_ooool7o`0000Kooooo0_l0002@ooooo`007_ooool00ol0003o
ooooooooo`28ooooo`;o00001Oooool4o`000003ooooool0003o000000Wo000000Coooooo`000?l0
003ooooo0_l000000ooooooo0000o`000003ooooo`Co00001_ooool2o`00093ooooo000Nooooo`03
o`000?oooooooooo07[ooooo0_l0000Booooo`?o00001?ooool6o`000003ooooool0003o000000;o
00000oooool5o`0000?ooooo1?l00002ooooo`;o000000?oooooo`000?l000003?ooool2o`0008?o
oooo000Nooooo`03o`000?oooooooooo07[ooooo0_l0000;ooooo`;o000000?oooooo`000?l00000
0_ooool4o`0000;ooooo1Ol00003ooooo`Co00001?ooool4o`0000?ooooo0ol00002ooooo`Ko0000
0_ooool2o`0000Sooooo0_l00023ooooo`007_ooool00ol0003oooooooooo`1looooo`;o00002?oo
ool3o`000003ooooool0003o000000;ooooo1?l00002ooooo`;o00001Oooool;o`0000Gooooo1?l0
00001?oooooo0000o`000?ooool2o`0000?ooooo0_l0002=ooooo`007_ooool00ol0003ooooooooo
o`1looooo`;o00002?ooool2o`000003ooooool0003o000000?ooooo1_l00007ooooo`_o00001ooo
ool3o`0009Oooooo000Nooooo`03o`000?oooooooooo08Wooooo0_l00003ooooo`Ko00001?ooool@
o`0000Gooooo1?l0000@ooooo`;o0000Q?ooool001kooooo00?o0000ooooooooool0Roooool3o`00
0003ooooool0003o0000023o00000oooool2o`0000?ooooo0_l00006ooooo`;o0000Q?ooool001ko
oooo00?o0000ooooooooool0Roooool4o`0000;ooooo5?l00002ooooo`oo00000_ooool3o`0008co
oooo000Nooooo`03o`000?oooooooooo08Cooooo0_l00003ooooo`?o000000?oooooo`000?l00000
5?l000000ooooooo0000o`000009ooooo`Go00001?ooool2o`0008gooooo000Nooooo`03o`000?oo
oooooooo07Gooooo0ol0000<ooooo`;o00000ooooolPo`000003ooooool0003o000000?ooooo1Ol0
0004ooooo`;o0000SOooool001kooooo00?o0000ooooooooool0MOooool3o`0000cooooo0_l00005
oooooa7o000000?oooooo`000?l000001Ol000000ooooooo0000o`000005o`0000Gooooo0ol00006
ooooo`;o00001?ooool2o`0000[ooooo0_l0001iooooo`007_ooool00ol0003oooooooooo`23oooo
o`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000_o000000?oooooo`00
0?l000001?l00002ooooo`Ko00000_ooool7o`0000Kooooo0_l00004ooooo`;o00002_ooool2o`00
07Wooooo000Nooooo`03o`000?oooooooooo07Cooooo0_l0000=ooooo`;o000000?oooooo`000?l0
00000oooool3o`0000?ooooo2ol000000ooooooo0000o`000005o`000003ooooool0003o000000?o
00000_ooool9o`0000_ooooo0_l0000:ooooo`;o0000NOooool001kooooo00?o0000ooooooooool0
M?ooool2o`0001;ooooo1_l00005ooooo`;o00000_ooool5o`000003ooooool0003o0000017o0000
00?oooooo`000?l000000ol00009ooooo`;o00002oooool2o`0007Wooooo000Nooooo`;o0000Pooo
ool2o`0000Cooooo1?l000000ooooooo0000o`000003ooooo`Oo000000Coooooo`000?l0003ooooo
4_l00002ooooo`Go00000oooool4o`0000;ooooo0_l0000;ooooo`;o0000NOooool001kooooo00?o
0000ooooooooool0P_ooool2o`0000Cooooo1?l000000ooooooo0000o`000002ooooo`_o000000?o
ooooo`000?l000003_l00003ooooo`Go00000oooool5o`0008[ooooo000Nooooo`03o`000?oooooo
oooo08Sooooo2?l000000ooooooo0000o`000002o`000003ooooool0003o000001co00000oooool4
o`0008cooooo000Nooooo`03o`000?oooooooooo08[ooooo1ol000000ooooooo0000o`00000Go`00
0003ooooool0003o000000So000000?oooooo`000?l000000oooool2o`0000kooooo0_l0001ioooo
o`007_ooool00ol0003oooooooooo`27ooooo`;o000000?oooooo`000?l000002?l000000ooooooo
0000o`00000Bo`0000;ooooo2ol00006ooooo`;o00003_ooool2o`0007Wooooo000Nooooo`03o`00
0?oooooooooo06oooooo0_l0000Fooooo`Oo000000?oooooo`000?l000005_l00002ooooo`_o0000
2?ooool2o`0008Wooooo000Nooooo`03o`000?oooooooooo06oooooo0_l0000Gooooo`Go000000Co
ooooo`000?l0003ooooo5_l000001?oooooo0000o`000?l00004ooooo`Go00000oooool4o`000003
ooooool0003o000000gooooo0_l0001jooooo`007_ooool00ol0003oooooooooo`1_ooooo`;o0000
6Oooool2o`0000;ooooo0_l00002oooooa?o00000_ooool:o`0000Gooooo1Ol0000@ooooo`;o0000
N_ooool001kooooo00?o0000ooooooooool0Koooool2o`00027ooooo0ol000000ooooooo0000o`00
000<o`0000?ooooo2_l00005ooooo`;o00004oooool2o`0007[ooooo000Nooooo`03o`000?oooooo
oooo077ooooo0_l0000Gooooo`;o00000_ooool2o`0000;ooooo0ol00002ooooo`ko00000_ooool9
o`0000gooooo0_l00028ooooo`007_ooool00ol0003oooooooooo`1aooooo`;o00005oooool2o`00
00;ooooo0_l00002ooooo`[o000000?oooooo`000?l000000ol000000ooooooo0000o`000002oooo
o`Ko000000?oooooo`000?l000003Oooool2o`0008Sooooo000Nooooo`03o`000?oooooooooo07;o
oooo0_l00008ooooo`;o00003?ooool6o`0000;ooooo1ol00002ooooo`;o000000?oooooo`000?l0
00000ol00003ooooo`Oo00001?ooool2o`000003ooooool0003o0000097ooooo000Nooooo`03o`00
0?oooooooooo07;ooooo0_l00008ooooo`;o00003?ooool5o`0000;ooooo1Ol000000ooooooo0000
o`00000Bo`0000Gooooo0ol000001?oooooo0000o`000?l0000=ooooo`?o0000P?ooool001kooooo
00?o0000ooooooooool0ROooool3o`000003ooooool0003o000000So000000?oooooo`000?l00000
1_l000000ooooooo0000o`000003o`000003ooooool0003o000000Oooooo0_l00002ooooo`?o0000
2Oooool2o`0000;ooooo0ol00020ooooo`007_ooool00ol0003oooooooooo`29ooooo`Co00000_oo
ool2o`0000;ooooo1?l000000ooooooo0000o`000006o`000003ooooool0003o000000;ooooo0_l0
000=ooooo`;o00002_ooool2o`0008Gooooo000Nooooo`03o`000?oooooooooo08Wooooo1?l00000
0ooooooo0000o`000005ooooo`Ko00000_ooool3o`000003ooooool0003o000000;ooooo0_l0000I
ooooo`;o0000QOooool001kooooo0_l0002:ooooo`?o00000_ooool2o`0000Kooooo1ol00002oooo
o`Ko00001?ooool2o`0000?ooooo0_l0002Gooooo`007_ooool00ol0003oooooooooo`1gooooo`;o
00004?ooool4o`0000Wooooo0_l000000ooooooo0000o`000002o`0000;ooooo1_l00003ooooo`?o
00000_ooool3o`0009Oooooo000Nooooo`03o`000?oooooooooo07Oooooo0_l0000@ooooo`Co0000
2Oooool2o`0000;ooooo1Ol000001?oooooo0000o`000?ooool2o`0000?ooooo2?l0002Gooooo`00
7_ooool00ol0003oooooooooo`1cooooo`;o00005Oooool2o`000003ooooool0003o000000;ooooo
0ol00002ooooo`;o00000_ooool5o`000004ooooool0003o0000ooooo`Go00000_ooool3o`000003
ooooool0003o000000[ooooo0_l0002;ooooo`007_ooool00ol0003oooooooooo`1cooooo`;o0000
3?ooool2o`0000Oooooo0_l000000ooooooo0000o`000002ooooo`?o00001oooool3o`000003oooo
ool0003o000000?ooooo1ol0000?ooooo`;o0000Roooool001kooooo00?o0000ooooooooool0OOoo
ool2o`0000;ooooo0_l00008ooooo`Co00000oooool2o`0000Sooooo0_l000000ooooooo0000o`00
000:o`0000;ooooo0_l0002Hooooo`007_ooool00ol0003oooooooooo`1mooooo`;o00003?ooool4
o`000003ooooool0003o000000Co00001_ooool2o`000003ooooool0003o000000?o00000_ooool3
o`0000Cooooo0_l0000<ooooo`;o0000R_ooool001kooooo00?o0000ooooooooool0Roooool3o`00
00;ooooo0ol000001?oooooo0000o`000?l00005ooooo`;o000000?oooooo`000?l000000ol00002
ooooo`;o00002?ooool2o`0000Wooooo0_l0002:ooooo`007_ooool00ol0003oooooooooo`2;oooo
o`;o000000?oooooo`000?l000000_l00003ooooo`?o00001Oooool2o`0000;ooooo0ol000000ooo
oooo0000o`000002o`0000;ooooo0_l00003ooooo`;o0000UOooool001kooooo00?o0000oooooooo
ool0Roooool2o`000003ooooool0003o000000oo000000?oooooo`000?l000000_l000000ooooooo
0000o`000002o`0000;ooooo0_l0002Jooooo`007_ooool00ol0003oooooooooo`2:ooooo`;o0000
1_oooolBo`000:?ooooo000Nooooo`03o`000?oooooooooo08[ooooo0_l00002ooooo`;o00001_oo
ool7o`000005ooooool0003o0000o`000?ooool00_l000000ooooooo0000o`00002Pooooo`007_oo
ool00ol0003oooooooooo`2>ooooo`;o000000?oooooo`000?l000001_ooool4o`000003ooooool0
003o000000Gooooo0_l0000Cooooo`;o0000Roooool001kooooo00?o0000ooooooooool0ROooool2
o`0000Kooooo1?l00004ooooo`;o00001?ooool2o`0001Wooooo0_l0002;ooooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_oo
ool00ol0003oooooooooo`29ooooo`;o00002?ooool2o`0000[ooooo0_l0002Vooooo`000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40
1_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@4100
2oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0002Qooooo`;o0000Y?ooool000?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool00ol0
003oooooooooo`2Qooooo`;o0000Y?ooool000?ooooo00Go0000ooooooooooooooooo`00000;oooo
o`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2jooooo`;o0000Roooool0
00?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000
ooooooooool0O?ooool2o`00017ooooo0_l0000Xooooo`?o0000Roooool000?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0O?ooool2
o`00017ooooo0_l0000Xooooo`;o00000oooool2o`0008Oooooo0003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo07oooooo0_l0
000mooooo`;o0000Qoooool001kooooo00?o0000ooooooooool0Ooooool2o`000<Kooooo000Noooo
o`03o`000?oooooooooo09?ooooo0_l0000Kooooo`;o0000UOooool001kooooo00?o0000oooooooo
ool0T_ooool3o`0001_ooooo0_l0002Eooooo`007_ooool00ol0003oooooooooo`2Booooo`;o0000
2?ooool2o`000:Wooooo000Nooooo`03o`000?oooooooooo09cooooo0_l00002ooooo`;o00004?oo
ool2o`0009?ooooo000Nooooo`03o`000?oooooooooo09Cooooo0_l0000:ooooo`;o00004?ooool2
o`0009?ooooo000Nooooo`03o`000?oooooooooo09Cooooo0_l0002aooooo`007_ooool00ol0003o
ooooooooo`2Hooooo`;o0000[Oooool001kooooo00?o0000ooooooooool0R?ooool2o`0000kooooo
0_l0000@ooooo`;o000000?oooooo`000?l00000V?ooool001kooooo00?o0000ooooooooool0R?oo
ool2o`0000gooooo0_l0000Aooooo`;o000000?oooooo`000?l00000V?ooool001kooooo00?o0000
ooooooooool0Uoooool2o`0000?ooooo0_l0002Yooooo`007_ooool2o`0009Wooooo0_l00002oooo
o`;o0000ZOooool001kooooo00?o0000ooooooooool0V?ooool2o`000:gooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003ooooooooo
o`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000000Kooooo0ol0003oooooodSooooo0003ooooo`05o`000?ooooooooooooooool00000
2oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000ooooooooool0oooooom8ooooo`00
0oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006oooo
o`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`3oooooodSooooo0003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o
0000ooooooooool0oooooom8ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
ZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001Cooooo1?l000000ol@
413oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB?ooool001Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooodSooooo000Fooooo`03o`000?oooooooooo00Gooooo
0ol0003oooooodSooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000
ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03
o`000?oooooooooo0?ooooooD?ooool001Cooooo00?oEEEEofIVI_l00000oooooomBooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.46639 .53308 Mdot
.46596 .48582 Mdot
.53338 .42058 Mdot
.47628 .47513 Mdot
.49767 .47262 Mdot
.48815 .58335 Mdot
.43512 .56043 Mdot
.46296 .46557 Mdot
.46417 .55099 Mdot
.44715 .47415 Mdot
.4523 .50184 Mdot
.47956 .51626 Mdot
.51502 .57653 Mdot
.58692 .50478 Mdot
.48297 .62079 Mdot
.51236 .46447 Mdot
.46137 .50097 Mdot
.49961 .57517 Mdot
.42509 .54089 Mdot
.55677 .51442 Mdot
.46029 .5048 Mdot
.53459 .47593 Mdot
.50461 .47041 Mdot
.55604 .56118 Mdot
.45213 .48394 Mdot
.49432 .51686 Mdot
.44988 .44415 Mdot
.44993 .57207 Mdot
.49743 .48107 Mdot
.5041 .5773 Mdot
.51931 .54326 Mdot
.46461 .47849 Mdot
.50952 .507 Mdot
.5346 .44378 Mdot
.51144 .5795 Mdot
.54559 .46729 Mdot
.50562 .51644 Mdot
.49828 .45777 Mdot
.50539 .46715 Mdot
.48764 .52246 Mdot
.51501 .48199 Mdot
.56181 .50484 Mdot
.48531 .53916 Mdot
.49047 .5047 Mdot
.4649 .47848 Mdot
.52725 .51267 Mdot
.5508 .45731 Mdot
.53476 .53237 Mdot
.55589 .52477 Mdot
.64438 .52018 Mdot
.50649 .47082 Mdot
.55104 .41212 Mdot
.49411 .48179 Mdot
.49544 .46778 Mdot
.50062 .44794 Mdot
.51169 .51954 Mdot
.48167 .52978 Mdot
.50026 .35214 Mdot
.46676 .46692 Mdot
.49051 .5338 Mdot
.53445 .51464 Mdot
.51969 .51215 Mdot
.55189 .4752 Mdot
.51175 .46415 Mdot
.51156 .47899 Mdot
.55511 .56615 Mdot
.47567 .54468 Mdot
.5245 .51441 Mdot
.52793 .51663 Mdot
.51309 .46545 Mdot
.44148 .52728 Mdot
.48034 .4707 Mdot
.50411 .53173 Mdot
.48555 .48633 Mdot
.53055 .57088 Mdot
.46471 .45028 Mdot
.53064 .51618 Mdot
.51624 .56677 Mdot
.46038 .47588 Mdot
.4375 .54894 Mdot
.51895 .46323 Mdot
.45806 .46669 Mdot
.46033 .48949 Mdot
.52265 .50226 Mdot
.54461 .46276 Mdot
.48884 .48448 Mdot
.5145 .4275 Mdot
.51721 .51381 Mdot
.48838 .52467 Mdot
.60569 .48933 Mdot
.50333 .48569 Mdot
.52842 .50564 Mdot
.51194 .43179 Mdot
.63031 .54105 Mdot
.51171 .41721 Mdot
.53757 .51011 Mdot
.51565 .51516 Mdot
.50933 .54441 Mdot
.53792 .4454 Mdot
.47242 .52208 Mdot
.51211 .42701 Mdot
.51811 .43579 Mdot
.4752 .46564 Mdot
.57008 .54633 Mdot
.45147 .53586 Mdot
.51188 .50944 Mdot
.37611 .54961 Mdot
.5085 .48209 Mdot
.46807 .53405 Mdot
.52833 .50317 Mdot
.5033 .55377 Mdot
.47844 .47088 Mdot
.4752 .49593 Mdot
.41573 .47772 Mdot
.46763 .54247 Mdot
.55138 .50243 Mdot
.44467 .4386 Mdot
.45478 .57738 Mdot
.56305 .45334 Mdot
.50766 .43019 Mdot
.4935 .56188 Mdot
.49083 .51474 Mdot
.45955 .4572 Mdot
.54158 .53785 Mdot
.46321 .49671 Mdot
.44254 .46862 Mdot
.52225 .56128 Mdot
.49291 .51544 Mdot
.49215 .50986 Mdot
.50429 .45727 Mdot
.47413 .57185 Mdot
.45839 .51677 Mdot
.49938 .38998 Mdot
.55971 .50451 Mdot
.47621 .47686 Mdot
.49824 .39444 Mdot
.43568 .55088 Mdot
.49717 .49351 Mdot
.51822 .52723 Mdot
.48013 .50116 Mdot
.50621 .48333 Mdot
.41575 .48739 Mdot
.49929 .51112 Mdot
.48376 .47527 Mdot
.514 .49983 Mdot
.52929 .50365 Mdot
.47221 .54456 Mdot
.54558 .49949 Mdot
.47031 .54267 Mdot
.54855 .53597 Mdot
.55608 .49188 Mdot
.45719 .57646 Mdot
.50277 .47861 Mdot
.56737 .52473 Mdot
.45718 .56779 Mdot
.5123 .46423 Mdot
.52126 .51101 Mdot
.54815 .49342 Mdot
.53047 .51598 Mdot
.50991 .49336 Mdot
.4482 .59985 Mdot
.54222 .51163 Mdot
.5255 .55375 Mdot
.49448 .4474 Mdot
.48502 .52607 Mdot
.47233 .5121 Mdot
.44299 .52186 Mdot
.54248 .48469 Mdot
.55618 .48669 Mdot
.49463 .46277 Mdot
.44579 .56783 Mdot
.53395 .54101 Mdot
.46403 .49846 Mdot
.49082 .5268 Mdot
.46059 .63484 Mdot
.50811 .51638 Mdot
.53143 .49919 Mdot
.51146 .48991 Mdot
.53488 .45691 Mdot
.5574 .52435 Mdot
.48002 .47614 Mdot
.53142 .50935 Mdot
.49034 .49192 Mdot
.49395 .48056 Mdot
.52373 .56113 Mdot
.47768 .51298 Mdot
.51656 .41989 Mdot
.53495 .51604 Mdot
.60107 .55112 Mdot
.49972 .42978 Mdot
.48462 .50524 Mdot
.50837 .46257 Mdot
.55249 .5573 Mdot
.50499 .47978 Mdot
.50083 .4622 Mdot
.51293 .48277 Mdot
.64844 .51394 Mdot
.50041 .50647 Mdot
.51545 .47747 Mdot
.47364 .4793 Mdot
.46817 .51577 Mdot
.52855 .51586 Mdot
.4841 .56628 Mdot
.55827 .49318 Mdot
.49866 .44531 Mdot
.46355 .50351 Mdot
.45562 .51685 Mdot
.47686 .52802 Mdot
.52432 .42919 Mdot
.50507 .47677 Mdot
.46435 .48229 Mdot
.50271 .51539 Mdot
.50375 .52353 Mdot
.46542 .5609 Mdot
.4904 .51482 Mdot
.55819 .46635 Mdot
.53015 .5101 Mdot
.52653 .51722 Mdot
.41474 .48566 Mdot
.50774 .48643 Mdot
.51522 .46412 Mdot
.50455 .37528 Mdot
.52984 .50552 Mdot
.57224 .4981 Mdot
.44268 .46606 Mdot
.45928 .47062 Mdot
.46564 .47262 Mdot
.44971 .46624 Mdot
.52128 .42526 Mdot
.42866 .50478 Mdot
.48814 .43913 Mdot
.50078 .51489 Mdot
.41665 .47034 Mdot
.51698 .51159 Mdot
.50134 .51934 Mdot
.51962 .52791 Mdot
.43652 .46682 Mdot
.46597 .4469 Mdot
.46051 .51291 Mdot
.47766 .51312 Mdot
.44688 .47144 Mdot
.47053 .61212 Mdot
.48504 .55857 Mdot
.45641 .46298 Mdot
.51829 .42706 Mdot
.50463 .45352 Mdot
.44932 .47715 Mdot
.46607 .46836 Mdot
.47927 .44078 Mdot
.43584 .44161 Mdot
.48276 .53586 Mdot
.52709 .55171 Mdot
.44291 .52222 Mdot
.5171 .42056 Mdot
.47818 .49274 Mdot
.4753 .51699 Mdot
.49248 .46849 Mdot
.51119 .5215 Mdot
.53962 .45303 Mdot
.42646 .47399 Mdot
.54251 .48533 Mdot
.50853 .4688 Mdot
.51008 .49389 Mdot
.46999 .56591 Mdot
.56125 .51296 Mdot
.55594 .48315 Mdot
.43129 .47894 Mdot
.47863 .58259 Mdot
.51667 .49812 Mdot
.52165 .44711 Mdot
.4748 .54177 Mdot
.47506 .49657 Mdot
.59756 .55128 Mdot
.47734 .49905 Mdot
.52057 .41948 Mdot
.43939 .50537 Mdot
.52167 .51867 Mdot
.42719 .52702 Mdot
.54983 .51781 Mdot
.43745 .49804 Mdot
.52263 .52275 Mdot
.49582 .51985 Mdot
.58142 .50111 Mdot
.50501 .49845 Mdot
.45988 .45221 Mdot
.63185 .53871 Mdot
.54652 .46089 Mdot
.50782 .46681 Mdot
.46199 .50654 Mdot
.55826 .52705 Mdot
.47849 .52239 Mdot
.50398 .54223 Mdot
.55318 .50611 Mdot
.49975 .54232 Mdot
.47225 .51161 Mdot
.48721 .46752 Mdot
.4591 .57838 Mdot
.5588 .52276 Mdot
.56062 .49789 Mdot
.47543 .47431 Mdot
.49445 .50113 Mdot
.45845 .47115 Mdot
.48597 .56182 Mdot
.52044 .48252 Mdot
.47781 .51885 Mdot
.47724 .47468 Mdot
.42201 .37559 Mdot
.48569 .54122 Mdot
.44953 .48732 Mdot
.55858 .51816 Mdot
.48047 .4801 Mdot
.50606 .50065 Mdot
.44045 .47239 Mdot
.44807 .4944 Mdot
.47126 .48462 Mdot
.46754 .54216 Mdot
.48902 .52238 Mdot
.52133 .51422 Mdot
.50547 .52991 Mdot
.509 .46346 Mdot
.55286 .53067 Mdot
.45842 .50039 Mdot
.46352 .51659 Mdot
.50844 .51761 Mdot
.43945 .56123 Mdot
.5204 .46599 Mdot
.48697 .50553 Mdot
.49133 .51087 Mdot
.43036 .53619 Mdot
.52069 .44419 Mdot
.48029 .55691 Mdot
.5547 .48396 Mdot
.47423 .49792 Mdot
.44217 .48373 Mdot
.52788 .43526 Mdot
.48027 .45101 Mdot
.55859 .50317 Mdot
.47865 .47302 Mdot
.45051 .47769 Mdot
.51797 .51258 Mdot
.4814 .54684 Mdot
.46255 .5363 Mdot
.36191 .515 Mdot
.50205 .50974 Mdot
.54343 .47433 Mdot
.46163 .53662 Mdot
.50374 .49749 Mdot
.47362 .46538 Mdot
.53971 .48309 Mdot
.52264 .50193 Mdot
.4797 .52634 Mdot
.50488 .39045 Mdot
.46144 .49552 Mdot
.51234 .5139 Mdot
.52705 .54489 Mdot
.47417 .51871 Mdot
.59221 .51067 Mdot
.45835 .52094 Mdot
.5867 .4659 Mdot
.5132 .50862 Mdot
.51351 .47594 Mdot
.47065 .54089 Mdot
.47279 .50617 Mdot
.58299 .52233 Mdot
.4595 .52769 Mdot
.58351 .48975 Mdot
.54265 .43013 Mdot
.5437 .48442 Mdot
.41672 .42047 Mdot
.4902 .48569 Mdot
.50975 .49267 Mdot
.50019 .49128 Mdot
.51006 .39072 Mdot
.4398 .46981 Mdot
.55371 .44788 Mdot
.47828 .44527 Mdot
.43066 .48601 Mdot
.49966 .4293 Mdot
.55918 .50691 Mdot
.50101 .51663 Mdot
.56129 .51672 Mdot
.49419 .42909 Mdot
.48884 .4745 Mdot
.56837 .51843 Mdot
.4652 .47094 Mdot
.47239 .57212 Mdot
.4529 .574 Mdot
.4863 .45166 Mdot
.50626 .51999 Mdot
.55969 .5201 Mdot
.45435 .37023 Mdot
.54942 .51274 Mdot
.55334 .52892 Mdot
.46447 .47774 Mdot
.51082 .46667 Mdot
.4628 .46636 Mdot
.51151 .47135 Mdot
.5086 .50368 Mdot
.44029 .56334 Mdot
.46474 .37997 Mdot
.44869 .38572 Mdot
.56103 .51156 Mdot
.42686 .36408 Mdot
.49441 .52002 Mdot
.5487 .53106 Mdot
.55509 .48864 Mdot
.49222 .47886 Mdot
.50831 .48922 Mdot
.46845 .5208 Mdot
.43559 .55132 Mdot
.48013 .50574 Mdot
.42698 .54138 Mdot
.48733 .48678 Mdot
.53514 .53341 Mdot
.49159 .48821 Mdot
.51538 .43325 Mdot
.52594 .49585 Mdot
.5479 .55165 Mdot
.50024 .53727 Mdot
.46211 .45374 Mdot
.42836 .52331 Mdot
.52747 .51297 Mdot
.48962 .49285 Mdot
.43393 .5044 Mdot
.46901 .3447 Mdot
.55429 .48926 Mdot
.48075 .57882 Mdot
.51677 .4953 Mdot
.53244 .52347 Mdot
.5015 .52339 Mdot
.51407 .5349 Mdot
.51381 .46697 Mdot
.4514 .52241 Mdot
.42473 .53131 Mdot
.55703 .48738 Mdot
.55854 .557 Mdot
.55582 .48467 Mdot
.48408 .53082 Mdot
.50293 .53643 Mdot
.48911 .52697 Mdot
.50796 .54506 Mdot
.61257 .42316 Mdot
.53727 .53555 Mdot
.46195 .56861 Mdot
.51291 .50915 Mdot
.47126 .57608 Mdot
.49185 .47367 Mdot
.50056 .44776 Mdot
.53368 .44186 Mdot
.50154 .48381 Mdot
.57898 .46713 Mdot
.47753 .50989 Mdot
.51848 .49051 Mdot
.49248 .52676 Mdot
.52826 .44051 Mdot
.42248 .52087 Mdot
.55787 .49892 Mdot
.50704 .46208 Mdot
.50559 .49199 Mdot
.50568 .52274 Mdot
.55843 .49383 Mdot
.48195 .48514 Mdot
.55694 .51061 Mdot
.5162 .51134 Mdot
.54315 .53691 Mdot
.54279 .46145 Mdot
.52136 .50734 Mdot
.48721 .496 Mdot
.49367 .54378 Mdot
.51519 .52063 Mdot
.46508 .50024 Mdot
.46217 .45778 Mdot
.38236 .61242 Mdot
.52 .65011 Mdot
.43421 .55857 Mdot
.43749 .53253 Mdot
.55687 .5128 Mdot
.52914 .65358 Mdot
.50955 .42675 Mdot
.51081 .40801 Mdot
.50545 .50254 Mdot
.46164 .4935 Mdot
.46044 .46719 Mdot
.4663 .46548 Mdot
.52873 .51317 Mdot
.56071 .49366 Mdot
.44077 .48481 Mdot
.47023 .54039 Mdot
.54353 .53806 Mdot
.49673 .43009 Mdot
.57712 .40669 Mdot
.52232 .42713 Mdot
.50607 .56568 Mdot
.51362 .48265 Mdot
.479 .53108 Mdot
.52813 .54373 Mdot
.42273 .45855 Mdot
.51441 .48653 Mdot
.56171 .4977 Mdot
.44666 .47115 Mdot
.34917 .50997 Mdot
.44656 .53306 Mdot
.38756 .59517 Mdot
.49857 .45054 Mdot
.4767 .5124 Mdot
.43339 .50989 Mdot
.45554 .52764 Mdot
.46728 .44819 Mdot
.49782 .42185 Mdot
.63892 .53101 Mdot
.54842 .51311 Mdot
.54884 .4708 Mdot
.47813 .53291 Mdot
.49073 .57337 Mdot
.4504 .47059 Mdot
.51598 .47353 Mdot
.47945 .53305 Mdot
.5079 .5805 Mdot
.58343 .47747 Mdot
.44762 .48609 Mdot
.46971 .43992 Mdot
.47383 .54293 Mdot
.44231 .48159 Mdot
.49796 .51771 Mdot
.47359 .51514 Mdot
.51444 .51577 Mdot
.56 .51316 Mdot
.55816 .41145 Mdot
.45835 .57121 Mdot
.43086 .55622 Mdot
.54406 .46567 Mdot
.52927 .50347 Mdot
.51972 .51903 Mdot
.48129 .48619 Mdot
.58068 .55664 Mdot
.48204 .51388 Mdot
.56104 .51768 Mdot
.52683 .51423 Mdot
.48053 .53005 Mdot
.42601 .53241 Mdot
.47739 .49475 Mdot
.55955 .54295 Mdot
.52657 .49646 Mdot
.56723 .54332 Mdot
.46369 .56719 Mdot
.4466 .47345 Mdot
.4889 .47553 Mdot
.5859 .52487 Mdot
.47946 .46899 Mdot
.42347 .52224 Mdot
.48668 .52426 Mdot
.49227 .47255 Mdot
.5117 .50281 Mdot
.34909 .49845 Mdot
.47236 .47065 Mdot
.51541 .4695 Mdot
.50473 .48869 Mdot
.53033 .53424 Mdot
.57994 .43132 Mdot
.47577 .42833 Mdot
.51965 .43769 Mdot
.5284 .4355 Mdot
.49343 .445 Mdot
.49332 .4847 Mdot
.56391 .50361 Mdot
.48866 .4682 Mdot
.42023 .63413 Mdot
.43848 .4963 Mdot
.56722 .52315 Mdot
.55523 .51969 Mdot
.52604 .45036 Mdot
.4971 .51553 Mdot
.51993 .53618 Mdot
.47826 .46605 Mdot
.47838 .51064 Mdot
.51672 .48007 Mdot
.59272 .51532 Mdot
.48679 .52373 Mdot
.47752 .43667 Mdot
.48555 .51678 Mdot
.51626 .41685 Mdot
.48347 .47175 Mdot
.35206 .54209 Mdot
.46607 .51612 Mdot
.53795 .5128 Mdot
.47662 .43525 Mdot
.47494 .47452 Mdot
.46534 .53613 Mdot
.45652 .53549 Mdot
.55037 .47446 Mdot
.47657 .51421 Mdot
.52675 .50917 Mdot
.51692 .47618 Mdot
.48542 .50928 Mdot
.49998 .44891 Mdot
.48028 .55665 Mdot
.56511 .54877 Mdot
.52533 .49863 Mdot
.52113 .55549 Mdot
.46586 .49026 Mdot
.55261 .49217 Mdot
.50491 .46453 Mdot
.45882 .50754 Mdot
.50581 .55384 Mdot
.52707 .50839 Mdot
.47364 .53796 Mdot
.49652 .44962 Mdot
.56578 .43564 Mdot
.51852 .51219 Mdot
.48958 .51114 Mdot
.47155 .58954 Mdot
.47834 .54753 Mdot
.48743 .47295 Mdot
.51381 .43687 Mdot
.47132 .54395 Mdot
.49972 .47761 Mdot
.51087 .46669 Mdot
.49576 .44484 Mdot
.51119 .48001 Mdot
.4627 .62774 Mdot
.43945 .54636 Mdot
.53903 .37669 Mdot
.47648 .48921 Mdot
.52063 .51138 Mdot
.51788 .43803 Mdot
.55972 .51941 Mdot
.50265 .4811 Mdot
.50329 .49118 Mdot
.50419 .39915 Mdot
.46243 .50395 Mdot
.53158 .51504 Mdot
.5056 .45384 Mdot
.55133 .53311 Mdot
.56849 .54151 Mdot
.57287 .53549 Mdot
.44995 .4741 Mdot
.47864 .43417 Mdot
.48489 .49902 Mdot
.47054 .46607 Mdot
.54848 .46271 Mdot
.47244 .467 Mdot
.52767 .51738 Mdot
.55219 .43007 Mdot
.51842 .50072 Mdot
.49973 .45218 Mdot
.48593 .55711 Mdot
.5144 .54988 Mdot
.51651 .50947 Mdot
.46691 .48506 Mdot
.45597 .49662 Mdot
.44177 .47825 Mdot
.51146 .50071 Mdot
.50564 .51284 Mdot
.46796 .53349 Mdot
.47024 .50476 Mdot
.48794 .53863 Mdot
.55925 .57283 Mdot
.48494 .50213 Mdot
.55821 .48647 Mdot
.4852 .51077 Mdot
.47752 .46833 Mdot
.51451 .50404 Mdot
.5837 .52303 Mdot
.48726 .34461 Mdot
.37691 .47579 Mdot
.55462 .48673 Mdot
.53774 .47817 Mdot
.42042 .36984 Mdot
.49475 .55688 Mdot
.56361 .61494 Mdot
.46296 .49584 Mdot
.4835 .35076 Mdot
.43953 .3792 Mdot
.49839 .4565 Mdot
.50022 .45334 Mdot
.44799 .47626 Mdot
.52201 .53066 Mdot
.46474 .4758 Mdot
.46512 .5798 Mdot
.48472 .46755 Mdot
.53391 .51367 Mdot
.52013 .43909 Mdot
.46323 .51975 Mdot
.51542 .43949 Mdot
.4628 .49136 Mdot
.53091 .51677 Mdot
.46336 .49674 Mdot
.52096 .55995 Mdot
.49874 .5268 Mdot
.54465 .52358 Mdot
.54036 .51284 Mdot
.54082 .45405 Mdot
.53412 .38203 Mdot
.50269 .5195 Mdot
.55202 .52841 Mdot
.44812 .51581 Mdot
.35541 .53809 Mdot
.49442 .50447 Mdot
.52676 .50036 Mdot
.47582 .47382 Mdot
.49374 .47653 Mdot
.4826 .51461 Mdot
.5717 .50698 Mdot
.51129 .47885 Mdot
.55843 .42882 Mdot
.44277 .58207 Mdot
.51295 .51543 Mdot
.50513 .47273 Mdot
.53615 .44893 Mdot
.43257 .5086 Mdot
.48253 .56343 Mdot
.48797 .51044 Mdot
.52598 .43233 Mdot
.43851 .56711 Mdot
.5647 .52595 Mdot
.45178 .4442 Mdot
.43432 .56325 Mdot
.44798 .52249 Mdot
.48027 .57785 Mdot
.4699 .58195 Mdot
.48758 .48225 Mdot
.4345 .55153 Mdot
.53036 .52644 Mdot
.48275 .48343 Mdot
.46552 .53804 Mdot
.47572 .5238 Mdot
.59841 .5016 Mdot
.47094 .55821 Mdot
.56109 .51703 Mdot
.5379 .51482 Mdot
.45444 .56644 Mdot
.52089 .4956 Mdot
.4764 .52298 Mdot
.52301 .50869 Mdot
.56278 .4433 Mdot
.44259 .53818 Mdot
.50456 .51837 Mdot
.53065 .48417 Mdot
.42623 .5381 Mdot
.51966 .5199 Mdot
.5283 .51194 Mdot
.53641 .55037 Mdot
.49977 .5198 Mdot
.43999 .47498 Mdot
.51668 .48764 Mdot
.49944 .46801 Mdot
.51268 .48316 Mdot
.51632 .5134 Mdot
.49344 .51002 Mdot
.47245 .52646 Mdot
.55991 .51288 Mdot
.50675 .49418 Mdot
.48825 .53079 Mdot
.49962 .47007 Mdot
.48939 .43501 Mdot
.5771 .53463 Mdot
.41639 .48708 Mdot
.4716 .44988 Mdot
.51132 .54683 Mdot
.4301 .51331 Mdot
.48964 .57764 Mdot
.47385 .57512 Mdot
.54616 .64664 Mdot
.55032 .51067 Mdot
.60008 .50198 Mdot
.48097 .48911 Mdot
.56004 .48815 Mdot
.48937 .47615 Mdot
.48896 .50647 Mdot
.55093 .47383 Mdot
.45257 .56497 Mdot
.51315 .54411 Mdot
.51335 .57835 Mdot
.4921 .48662 Mdot
.53908 .45611 Mdot
.48657 .42656 Mdot
.53169 .62144 Mdot
.44472 .48542 Mdot
.48494 .49352 Mdot
.51379 .5213 Mdot
.49995 .45185 Mdot
.46366 .53828 Mdot
.50265 .58314 Mdot
.59617 .39607 Mdot
.4763 .34747 Mdot
.43756 .51489 Mdot
.46875 .50221 Mdot
.51097 .46953 Mdot
.44722 .57035 Mdot
.55725 .49843 Mdot
.47241 .4828 Mdot
.48399 .56956 Mdot
.483 .47902 Mdot
.50422 .45953 Mdot
.46756 .53111 Mdot
.53917 .47411 Mdot
.47822 .54301 Mdot
.34384 .5073 Mdot
.4981 .44654 Mdot
.4625 .45114 Mdot
.50946 .47126 Mdot
.4776 .52805 Mdot
.50058 .42294 Mdot
.58577 .62497 Mdot
.46288 .52826 Mdot
.50496 .45544 Mdot
.48161 .52505 Mdot
.4473 .471 Mdot
.46337 .48612 Mdot
.50901 .58599 Mdot
.48838 .47576 Mdot
.44799 .46833 Mdot
.4854 .47839 Mdot
.47317 .53036 Mdot
.49433 .44526 Mdot
.48751 .53938 Mdot
.53594 .5164 Mdot
.47649 .52631 Mdot
.44954 .5087 Mdot
.53463 .54068 Mdot
.52073 .50827 Mdot
.47777 .49045 Mdot
.43549 .53129 Mdot
.42659 .53094 Mdot
.45128 .513 Mdot
.44198 .57361 Mdot
.51271 .47782 Mdot
.46114 .51342 Mdot
.46627 .5285 Mdot
.50028 .51991 Mdot
.38486 .46897 Mdot
.4839 .54822 Mdot
.56565 .44012 Mdot
.52456 .51327 Mdot
.50065 .51432 Mdot
.50041 .45358 Mdot
.56373 .50349 Mdot
.44108 .55331 Mdot
.47665 .48646 Mdot
.4794 .45603 Mdot
.46892 .53978 Mdot
.5287 .51119 Mdot
.53538 .51279 Mdot
.45279 .61638 Mdot
.45725 .48747 Mdot
.53138 .4448 Mdot
.56549 .61147 Mdot
.5643 .50141 Mdot
.53032 .51241 Mdot
.50653 .53106 Mdot
.46221 .5037 Mdot
.51569 .54803 Mdot
.57108 .48041 Mdot
.43557 .37683 Mdot
.46467 .64633 Mdot
.47754 .50962 Mdot
.51754 .50504 Mdot
.48666 .56824 Mdot
.48805 .49417 Mdot
.50713 .48075 Mdot
.52958 .43977 Mdot
.47712 .50984 Mdot
.50722 .50019 Mdot
.51118 .43848 Mdot
.46655 .58144 Mdot
.52686 .43252 Mdot
.46516 .50042 Mdot
.48791 .58817 Mdot
.46783 .48475 Mdot
.52 .3475 Mdot
.47809 .57437 Mdot
.47992 .45691 Mdot
.56307 .49336 Mdot
.48194 .5584 Mdot
.45008 .52281 Mdot
.49082 .48636 Mdot
.4972 .4684 Mdot
.52774 .50648 Mdot
.48615 .52423 Mdot
.5594 .41855 Mdot
.39163 .46817 Mdot
.50994 .39184 Mdot
.47121 .54324 Mdot
.49698 .48477 Mdot
.61701 .46549 Mdot
.46518 .46733 Mdot
.49849 .52544 Mdot
.51543 .47519 Mdot
.48353 .42935 Mdot
.52734 .42508 Mdot
.54174 .51195 Mdot
.50556 .5116 Mdot
.50794 .42127 Mdot
.42444 .52854 Mdot
.5145 .48876 Mdot
.58271 .55627 Mdot
.49666 .47685 Mdot
.46859 .52974 Mdot
.47533 .49991 Mdot
.47272 .4981 Mdot
.45153 .56571 Mdot
.46834 .51606 Mdot
.4573 .52498 Mdot
.46897 .48541 Mdot
.41988 .54011 Mdot
.48819 .48183 Mdot
.49095 .42765 Mdot
.51276 .52875 Mdot
.48705 .46765 Mdot
.47895 .54318 Mdot
.54848 .47038 Mdot
.54976 .49282 Mdot
.47517 .50776 Mdot
.50947 .46632 Mdot
.46382 .48815 Mdot
.48297 .51753 Mdot
.52074 .43641 Mdot
.40901 .50819 Mdot
.50789 .55701 Mdot
.48118 .43946 Mdot
.52586 .50853 Mdot
.49255 .50628 Mdot
.59033 .50756 Mdot
.53068 .44707 Mdot
.43763 .5024 Mdot
.48308 .48223 Mdot
.49121 .46761 Mdot
.47884 .51947 Mdot
.55836 .58881 Mdot
.4907 .48046 Mdot
.46833 .50563 Mdot
.56199 .50048 Mdot
.51487 .56837 Mdot
.46104 .50951 Mdot
.48853 .49706 Mdot
.64964 .51016 Mdot
.51982 .51197 Mdot
.41689 .45146 Mdot
.44244 .44103 Mdot
.4356 .53355 Mdot
.54719 .49702 Mdot
.45067 .48254 Mdot
.55159 .53339 Mdot
.48447 .48138 Mdot
.53232 .51705 Mdot
.47602 .55014 Mdot
.50021 .54672 Mdot
.53934 .52869 Mdot
.50937 .53641 Mdot
.56887 .53321 Mdot
.4481 .56968 Mdot
.47869 .50017 Mdot
.55234 .54534 Mdot
.46088 .51917 Mdot
.47916 .47748 Mdot
.4781 .58436 Mdot
.51492 .43187 Mdot
.52197 .48712 Mdot
.41136 .44888 Mdot
.47315 .6442 Mdot
.53282 .47385 Mdot
.49171 .48957 Mdot
.52439 .47956 Mdot
.50393 .5144 Mdot
.52013 .50835 Mdot
.50147 .54441 Mdot
.5173 .41882 Mdot
.46717 .51196 Mdot
.51953 .49127 Mdot
.50077 .43546 Mdot
.56003 .49605 Mdot
.47883 .54316 Mdot
.55916 .46088 Mdot
.54247 .48295 Mdot
.4204 .41692 Mdot
.51557 .47153 Mdot
.36713 .55227 Mdot
.49133 .49148 Mdot
.49293 .51909 Mdot
.50587 .57164 Mdot
.61125 .45417 Mdot
.50756 .48855 Mdot
.46886 .4636 Mdot
.45519 .47316 Mdot
.51113 .54169 Mdot
.56451 .45343 Mdot
.4596 .53267 Mdot
.47282 .49295 Mdot
.52203 .48538 Mdot
.47114 .45887 Mdot
.46627 .53248 Mdot
.51214 .46681 Mdot
.46994 .53804 Mdot
.44131 .48752 Mdot
.47682 .4446 Mdot
.53174 .51681 Mdot
.48128 .42642 Mdot
.51894 .41825 Mdot
.4471 .60437 Mdot
.59013 .51893 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0U?ooool2o`0000Cooooo0_l0002[ooooo`007_ooool00ol0003ooooo
ooooo`2Dooooo`;o000000Coooooo`000?l0003ooooo0_l00009ooooo`;o0000X?ooool001kooooo
0_l0002Hooooo`Co00002_ooool2o`000:3ooooo000Nooooo`03o`000?oooooooooo09Wooooo0_l0
0004ooooo`;o0000Y_ooool001kooooo00?o0000ooooooooool0Woooool2o`000:Kooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0Qoooool2o`000;ko
oooo000Nooooo`03o`000?oooooooooo08Oooooo0_l0002nooooo`007_ooool00ol0003ooooooooo
o`25ooooo`;o00002Oooool2o`000;Gooooo000Nooooo`03o`000?oooooooooo08Gooooo0_l00009
ooooo`;o0000]Oooool001kooooo00?o0000ooooooooool0QOooool2o`0001Wooooo0_l0002Uoooo
o`007_ooool00ol0003oooooooooo`25ooooo`;o00000_ooool4o`0001?ooooo0_l00009ooooo`;o
0000V_ooool001kooooo00?o0000ooooooooool0ROooool4o`0000Kooooo0_l0000Eooooo`?o0000
V_ooool001kooooo00?o0000ooooooooool0S_ooool2o`0000?ooooo0_l0000Eooooo`;o0000Vooo
ool001kooooo00?o0000ooooooooool0S_ooool2o`000;Oooooo000Nooooo`03o`000?oooooooooo
09kooooo1_l0002Sooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`2Nooooo`Ko0000Xoooool000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo09kooooo0_l0000Nooooo`;o0000Qoooool000?ooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go00001_ooool3o`000:3ooooo0_l0000Looooo`;o0000Qoooool000?o
oooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000
ooooooooool0X?ooool2o`000:Gooooo0003ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo0;Sooooo0_l0002=ooooo`000oooool0
1Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003ooooooooo
o`2Rooooo`;o00005?ooool2o`0008gooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0:;ooooo0_l0000;ooooo`Co0000U?oo
ool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o
0000ooooooooool0[oooool4o`0009Cooooo000Nooooo`03o`000?oooooooooo08Gooooo0_l0000K
ooooo`Go00002oooool2o`0009?ooooo000Nooooo`03o`000?oooooooooo08?ooooo1?l0000Goooo
o`;o000000?oooooo`000?l000001?l00002ooooo`;o00001oooool2o`0009?ooooo000Nooooo`03
o`000?oooooooooo08?ooooo0_l0000Iooooo`Go000000?oooooo`000?l000001Ol0000Hooooo`;o
0000P_ooool001kooooo00?o0000ooooooooool0Uoooool6o`0000;ooooo0_l000000ooooooo0000
o`000005o`0000Sooooo0_l0000@ooooo`;o0000P_ooool001kooooo00?o0000ooooooooool0Uooo
ool9o`000003ooooool0003o000000Go00001?ooool2o`000003ooooool0003o000000;o00001Ooo
ool2o`0008gooooo000Nooooo`03o`000?oooooooooo09Oooooo2Ol000000ooooooo0000o`000002
o`000004ooooool0003o0000o`0000?ooooo0_l000000ooooooo0000o`000007ooooo`;o0000SOoo
ool001kooooo00?o0000ooooooooool0Uoooool2o`0000;ooooo0_l00002ooooo`;o00000_ooool7
o`0000[ooooo0_l0002Aooooo`007_ooool00ol0003oooooooooo`2<ooooo`;o00001oooool5o`00
0003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o0000
00[ooooo0_l0002Aooooo`007_ooool00ol0003oooooooooo`2:ooooo`Oo00001?ooool2o`000004
ooooool0003o0000ooooo`;o00001Oooool5o`000003ooooool0003o000000;o00001oooool3o`00
097ooooo000Nooooo`03o`000?oooooooooo08[ooooo0_l00002ooooo`?o00000_ooool2o`0000;o
oooo0_l00003ooooo`Co00001Oooool2o`000003ooooool0003o000000?o00001_ooool2o`0009;o
oooo000Nooooo`03o`000?oooooooooo08;ooooo0_l0000?ooooo`Ko00000oooool5o`0000Cooooo
2?l00003ooooo`;o0000UOooool001kooooo0_l00023ooooo`?o00003?ooool6o`000003ooooool0
003o000000;o000000?oooooo`000?l000000ol00005ooooo`;o000000Coooooo`000?l0003o0000
0oooool2o`000003ooooool0003o000009;ooooo000Nooooo`03o`000?oooooooooo08?ooooo0_l0
000<ooooo`?o00001?ooool4o`0000;ooooo1?l00009ooooo`?o00001Oooool2o`0000kooooo0_l0
0022ooooo`007_ooool00ol0003oooooooooo`25ooooo`;o00002_ooool3o`000004ooooool0003o
0000ooooo`;o00001?ooool4o`0000Sooooo1?l000000ooooooo0000o`00000Booooo`;o0000P_oo
ool001kooooo00?o0000ooooooooool0QOooool2o`0000[ooooo0ol000001?oooooo0000o`000?oo
ool2o`0000?ooooo1_l00007ooooo`Oo000000?oooooo`000?l00000Toooool001kooooo00?o0000
ooooooooool0T?ooool8o`0000Gooooo2_l00005ooooo`Co00000_ooool2o`00013ooooo0_l00021
ooooo`007_ooool00ol0003oooooooooo`1kooooo`;o00003OoooolMo`0000Kooooo0_l00002oooo
o`;o00001Oooool2o`000003ooooool0003o000000Oooooo0_l00021ooooo`007_ooool00ol0003o
ooooooooo`1iooooo`Co00001_ooool2o`0000Gooooo1_l000000ooooooo0000o`00000Do`0000Ko
oooo0ol000000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l00000R_ooool001kooooo
00?o0000ooooooooool0NOooool2o`0000Sooooo0_l00002ooooo`;o00000_oooolKo`0000?ooooo
2?l0002Fooooo`007_ooool00ol0003oooooooooo`1fooooo`;o00002oooool2o`0000;ooooo0_l0
0002ooooo`[o000000?oooooo`000?l000002_l000001?oooooo0000o`000?l00003ooooo`So0000
2Oooool2o`0008_ooooo000Nooooo`03o`000?oooooooooo07Kooooo0_l0000;ooooo`;o00000ooo
ool2o`0000;ooooo1?l00002ooooo`?o000000?oooooo`000?l000004?l00002ooooo`?o00000_oo
ool2o`0000Gooooo0_l00002ooooo`;o0000Roooool001kooooo00?o0000ooooooooool0R?ooool2
o`0000;ooooo1Ol00002oooooaOo000000Coooooo`000?l0003o00000_ooool3o`0000?ooooo0_l0
002?ooooo`007_ooool00ol0003oooooooooo`23ooooo`;o00000oooool2o`000003ooooool0003o
000000Co00000_oooolGo`000003ooooool0003o000000;o000000Coooooo`000?l0003o0000U?oo
ool001kooooo00?o0000ooooooooool0Poooool2o`0000?ooooo0_l000000ooooooo0000o`000003
o`000003ooooool0003o000000co000000?oooooo`000?l000001_l00004ooooo`?o000000?ooooo
o`000?l000000_l00006ooooo`;o00001Oooool2o`0008Cooooo000Nooooo`03o`000?oooooooooo
08_ooooo0_l00004ooooo`Co000000?oooooo`000?l000003ol00007ooooo`Oo00001Oooool2o`00
00Gooooo0_l00024ooooo`007_ooool00ol0003oooooooooo`2:ooooo`;o00000_ooool6o`0000;o
oooo0ol000000ooooooo0000o`00000=o`0000Gooooo1ol0002Booooo`007_ooool00ol0003ooooo
ooooo`1]ooooo`;o00006oooool2o`0000;ooooo1ol000001Ooooooo0000o`000?l0003ooooo00?o
00000oooool;o`0000;ooooo0ol000000ooooooo0000o`000002o`000003ooooool0003o000008oo
oooo000Nooooo`;o0000K_ooool2o`0001_ooooo0_l00003oooooa3o000000?oooooo`000?l00000
2Ol00002ooooo`So000000Coooooo`000?l0003ooooo0_l00003ooooo`?o0000Q_ooool001kooooo
00?o0000ooooooooool0Qoooool6o`0000;ooooo4?l000000ooooooo0000o`000008o`0000Gooooo
1_l00004ooooo`Co000000Coooooo`000?l0003o0000Q_ooool001kooooo00?o0000ooooooooool0
K?ooool2o`0001?ooooo0_l00004ooooo`Ko000000Coooooo`000?l0003ooooo6Ol00006ooooo`Go
000000?oooooo`000?l000000oooool3o`0008Wooooo000Nooooo`03o`000?oooooooooo06cooooo
0ol0000Booooo`;o00001_ooool2o`0000?ooooo0_l000000ooooooo0000o`000006o`000003oooo
ool0003o000001;o000000?oooooo`000?l000000ol00002ooooo`;o00001?ooool2o`00017ooooo
0_l0001fooooo`007_ooool00ol0003oooooooooo`1]ooooo`;o00000oooool2o`0001Cooooo1?l0
0003ooooo`;o000000?oooooo`000?l000008?l00008ooooo`;o00004Oooool2o`0007Kooooo000N
ooooo`03o`000?oooooooooo07;ooooo0_l0000Dooooo`Co00000_oooolVo`0000Wooooo0_l0000@
ooooo`;o0000M_ooool001kooooo00?o0000ooooooooool0QOooool2o`0000Oooooo7_l00003oooo
o`Go000000?oooooo`000?l000001Oooool3o`0000kooooo0_l0001hooooo`007_ooool00ol0003o
ooooooooo`25ooooo`Co00000ooooolLo`000003ooooool0003o000000;ooooo0_l000000ooooooo
0000o`000005o`0000;ooooo1Ol0000?ooooo`;o0000N?ooool001kooooo00?o0000ooooooooool0
Q_ooool3o`0000;ooooo2?l00002oooooaKo00000_ooool2o`0000;ooooo1Ol00003ooooo`?o0000
Roooool001kooooo00?o0000ooooooooool0Q_ooool3o`0000;ooooo0_l00003oooooa;o000000?o
ooooo`000?l000000_l000001?oooooo0000o`000?ooool2o`0000;ooooo1ol00004ooooo`;o0000
Roooool001kooooo00?o0000ooooooooool0Q_ooool6o`000004ooooool0003o0000ooooo`go0000
0oooool8o`0000;ooooo0ol000000ooooooo0000o`000002o`0000?ooooo0_l0000Eooooo`;o0000
NOooool001kooooo00?o0000ooooooooool0Q_ooool6o`000003ooooool0003o000000Oo000000?o
ooooo`000?l000001?l00002ooooo`ko000000?oooooo`000?l000000_l00003ooooo`Go00004_oo
ool2o`0007Wooooo000Nooooo`03o`000?oooooooooo06oooooo0_l0000Eooooo`So000000?ooooo
o`000?l000001ol000000ooooooo0000o`000002o`0000;ooooo2?l000001?oooooo0000o`000?oo
ool5o`0000Kooooo1?l0000?ooooo`;o0000O?ooool001kooooo00?o0000ooooooooool0K_ooool3
o`0001?ooooo1Ol00003ooooo`;o00001Oooool5o`0000;ooooo0ol000000ooooooo0000o`000004
o`0000Gooooo1_l00006ooooo`;o00004_ooool2o`0007cooooo000Nooooo`03o`000?oooooooooo
06kooooo0_l0000Dooooo`Go00002ooooolHo`0000?ooooo0_l000000ooooooo0000o`000003o`00
01;ooooo0_l0001looooo`007_ooool00ol0003oooooooooo`2;ooooo`;o00002?ooool6o`000004
ooooool0003o0000ooooo`_o00001Oooool2o`000003ooooool0003o000000?o0000T?ooool001ko
oooo0_l0001gooooo`;o00004Oooool4o`0000Kooooo0_l00002ooooo`Co00001?ooool2o`000003
ooooool0003o000000;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00001?ooool3o`00
00Oooooo0ol00026ooooo`007_ooool00ol0003oooooooooo`1cooooo`;o000000?oooooo`000?l0
00004Oooool4o`0000Kooooo0_l00002ooooo`;o00001oooool2o`000003ooooool0003o000000;o
oooo0_l000000ooooooo0000o`000002ooooo`;o00003_ooool3o`0008Kooooo000Nooooo`03o`00
0?oooooooooo07?ooooo0_l0000Cooooo`;o000000?oooooo`000?l000002oooool4o`000004oooo
ool0003o0000ooooo`?o00000_ooool4o`0000Oooooo0ol00006ooooo`;o0000S?ooool001kooooo
00?o0000ooooooooool0R?ooool5o`0000Kooooo1?l000000ooooooo0000o`000002o`000003oooo
ool0003o000000;ooooo0_l00002ooooo`?o00002?ooool3o`0000Kooooo0_l0002<ooooo`007_oo
ool00ol0003oooooooooo`29ooooo`Co00001_ooool4o`0000;ooooo1Ol00007ooooo`?o00002Ooo
ool2o`0009Cooooo000Nooooo`03o`000?oooooooooo08Wooooo1?l00002ooooo`?o000000?ooooo
o`000?l000000_l00002ooooo`Go00000_ooool2o`0000;ooooo1?l00008ooooo`;o0000UOooool0
01kooooo00?o0000ooooooooool0R_ooool2o`000003ooooool0003o000000So00000_ooool3o`00
00Cooooo0_l000001?oooooo0000o`000?l0000:ooooo`;o0000UOooool001kooooo00?o0000oooo
ooooool0SOooool3o`000005ooooool0003o0000o`000?ooool00ol000000ooooooo0000o`000002
o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`;o00002?ooool2o`0009?ooooo000Noooo
o`03o`000?oooooooooo08cooooo1ol00002ooooo`Co00000_ooool2o`000003ooooool0003o0000
00;o000000?oooooo`000?l000000oooool2o`0000Sooooo0_l0002Cooooo`007_ooool00ol0003o
ooooooooo`2<ooooo`;o000000?oooooo`000?l000000_l00002ooooo`Go000000Coooooo`000?l0
003ooooo1ol0002Rooooo`007_ooool00ol0003oooooooooo`2<ooooo`;o00000_ooool:o`000003
ooooool0003o000000?ooooo1Ol0002Rooooo`007_ooool00ol0003oooooooooo`2<ooooo`;o0000
1Oooool6o`0000;ooooo0_l00002ooooo`Co0000Y?ooool001kooooo00?o0000ooooooooool0Uooo
ool2o`0000;ooooo0_l00002ooooo`Co00003_ooool2o`0009Cooooo000Nooooo`03o`000?oooooo
oooo09Gooooo0_l00004ooooo`;o00001?ooool2o`0000kooooo0_l0002Dooooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_oo
ool00ol0003oooooooooo`2Eooooo`;o0000/?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0
N_ooool2o`000<_ooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000000Kooooo0ol0001jooooo`;o00004_ooool2o`000;Oooooo0003ooooo`05o`00
0?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o0000oooo
ooooool0S_ooool2o`000;Oooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0
003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0SOooool2o`000;Sooooo0003oooo
o`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooo
oooo08gooooo0_l0002hooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgM
oa0@4?nHV9P02?ooool00ol0003oooooooooo`1hooooo`;o00006oooool2o`0001gooooo0_l0002A
ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_oo
ool00ol0003oooooooooo`1hooooo`;o00005Oooool2o`0000Cooooo0_l0000Looooo`?o0000TOoo
ool001kooooo00?o0000ooooooooool0Soooool2o`0002;ooooo0_l0002Booooo`007_ooool00ol0
003oooooooooo`2Iooooo`;o00003_ooool2o`0009cooooo000Nooooo`03o`000?oooooooooo09Wo
oooo0_l0000>ooooo`;o00003oooool2o`0008_ooooo000Nooooo`03o`000?oooooooooo09;ooooo
0_l0000Vooooo`;o0000Roooool001kooooo00?o0000ooooooooool0T_ooool2o`000;?ooooo000N
ooooo`03o`000?oooooooooo08Gooooo0_l0000;ooooo`;o0000/oooool001kooooo00?o0000oooo
ooooool0QOooool2o`0000_ooooo0_l0002cooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo09Kooooo0_l0002_ooooo`007_ooool00ol0003ooooooooo
o`2Cooooo`;o000000?oooooo`000?l000005Oooool2o`0009Sooooo000Nooooo`03o`000?oooooo
oooo09?ooooo0_l0000@ooooo`;o00001_ooool2o`0009Sooooo000Nooooo`;o0000Y_ooool2o`00
0:3ooooo000Nooooo`03o`000?oooooooooo0:Sooooo0_l0002Mooooo`007_ooool00ol0003ooooo
ooooo`2Xooooo`;o0000WOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003ooooooooo
o`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000000Kooooo0ol0003oooooodSooooo0003ooooo`05o`000?ooooooooooooooool00000
2oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000ooooooooool0oooooom8ooooo`00
0oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006oooo
o`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`3oooooodSooooo0003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o
0000ooooooooool0oooooom8ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
ZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001Cooooo1?l000000ol@
413oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB?ooool001Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooodSooooo000Fooooo`03o`000?oooooooooo00Gooooo
0ol0003oooooodSooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000
ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03
o`000?oooooooooo0?ooooooD?ooool001Cooooo00?oEEEEofIVI_l00000oooooomBooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.45327 .50305 Mdot
.48009 .47064 Mdot
.54728 .44175 Mdot
.49441 .46899 Mdot
.51367 .4781 Mdot
.47013 .57913 Mdot
.44532 .52075 Mdot
.48391 .45533 Mdot
.43014 .52369 Mdot
.47034 .44835 Mdot
.4555 .46746 Mdot
.47227 .51082 Mdot
.49449 .58844 Mdot
.58321 .53054 Mdot
.4625 .59895 Mdot
.52632 .48059 Mdot
.47155 .47599 Mdot
.46503 .5749 Mdot
.42266 .50947 Mdot
.54212 .53411 Mdot
.47031 .4785 Mdot
.53522 .50081 Mdot
.52755 .46442 Mdot
.53667 .5709 Mdot
.46574 .46158 Mdot
.48406 .51501 Mdot
.46823 .4216 Mdot
.42947 .5512 Mdot
.50852 .48491 Mdot
.48172 .57 Mdot
.49207 .5522 Mdot
.47769 .46211 Mdot
.50884 .51022 Mdot
.5509 .47115 Mdot
.49054 .58307 Mdot
.55167 .50186 Mdot
.49701 .51608 Mdot
.52866 .47104 Mdot
.52351 .46736 Mdot
.4719 .52086 Mdot
.52573 .49963 Mdot
.55319 .52409 Mdot
.46563 .52882 Mdot
.48944 .49918 Mdot
.47648 .46004 Mdot
.51982 .52237 Mdot
.57438 .4827 Mdot
.50693 .55073 Mdot
.53894 .54874 Mdot
.63911 .53972 Mdot
.51973 .47665 Mdot
.55613 .44624 Mdot
.50521 .48347 Mdot
.51699 .46766 Mdot
.5218 .45834 Mdot
.49353 .5228 Mdot
.46545 .52245 Mdot
.5145 .3627 Mdot
.48346 .45911 Mdot
.46911 .52832 Mdot
.52624 .5267 Mdot
.51089 .51743 Mdot
.5588 .50649 Mdot
.52596 .47985 Mdot
.5173 .48889 Mdot
.51808 .56224 Mdot
.45698 .53375 Mdot
.51054 .52056 Mdot
.5026 .52826 Mdot
.527 .4822 Mdot
.4502 .48286 Mdot
.50047 .47048 Mdot
.47878 .53132 Mdot
.49445 .48061 Mdot
.50691 .57354 Mdot
.4915 .42637 Mdot
.51064 .52776 Mdot
.48012 .56849 Mdot
.48265 .43955 Mdot
.42271 .52386 Mdot
.54087 .48598 Mdot
.47814 .45497 Mdot
.47313 .46564 Mdot
.52664 .51756 Mdot
.55565 .49274 Mdot
.49864 .48168 Mdot
.54003 .4368 Mdot
.50347 .51813 Mdot
.47061 .52315 Mdot
.59085 .51789 Mdot
.50999 .49086 Mdot
.52702 .52212 Mdot
.53643 .44013 Mdot
.61516 .55487 Mdot
.53442 .41118 Mdot
.53018 .5302 Mdot
.49964 .51906 Mdot
.48102 .55054 Mdot
.56775 .46742 Mdot
.46517 .50995 Mdot
.53863 .4329 Mdot
.54191 .44904 Mdot
.4964 .46335 Mdot
.53409 .5565 Mdot
.4251 .50392 Mdot
.51114 .51274 Mdot
.35132 .53317 Mdot
.51524 .49076 Mdot
.4582 .5178 Mdot
.52797 .52092 Mdot
.47363 .54025 Mdot
.49858 .46988 Mdot
.48359 .48294 Mdot
.43161 .45759 Mdot
.45159 .53214 Mdot
.53267 .54403 Mdot
.46802 .43289 Mdot
.43328 .55638 Mdot
.56223 .48385 Mdot
.53251 .43737 Mdot
.4577 .55716 Mdot
.48315 .51209 Mdot
.48482 .43723 Mdot
.51771 .5541 Mdot
.47393 .47465 Mdot
.47345 .45314 Mdot
.49423 .55486 Mdot
.48445 .51311 Mdot
.48841 .50613 Mdot
.52353 .46927 Mdot
.44476 .55729 Mdot
.46467 .49286 Mdot
.52276 .41353 Mdot
.5544 .53477 Mdot
.50683 .47308 Mdot
.52401 .41749 Mdot
.44316 .51823 Mdot
.5 .49202 Mdot
.49233 .53306 Mdot
.48399 .4909 Mdot
.51305 .49074 Mdot
.41419 .46069 Mdot
.49591 .50928 Mdot
.50095 .47324 Mdot
.51408 .50818 Mdot
.52888 .52164 Mdot
.4581 .51527 Mdot
.53634 .52302 Mdot
.45108 .53432 Mdot
.52662 .55295 Mdot
.55667 .52264 Mdot
.43265 .55743 Mdot
.51309 .48589 Mdot
.54062 .54173 Mdot
.43643 .54708 Mdot
.52639 .48038 Mdot
.51538 .51715 Mdot
.54674 .53698 Mdot
.51002 .52777 Mdot
.51088 .50129 Mdot
.4363 .56737 Mdot
.52194 .52771 Mdot
.4877 .55855 Mdot
.51772 .45814 Mdot
.46812 .5207 Mdot
.47239 .49915 Mdot
.42463 .48659 Mdot
.5579 .50312 Mdot
.55272 .50699 Mdot
.52828 .46718 Mdot
.42843 .54628 Mdot
.50773 .54961 Mdot
.47456 .48038 Mdot
.47086 .52329 Mdot
.44615 .61535 Mdot
.49505 .51806 Mdot
.52855 .52536 Mdot
.51309 .49942 Mdot
.5658 .48367 Mdot
.53995 .54591 Mdot
.49713 .47158 Mdot
.52793 .53016 Mdot
.49618 .48699 Mdot
.50578 .48259 Mdot
.50178 .58181 Mdot
.47396 .50545 Mdot
.53876 .43545 Mdot
.52705 .52853 Mdot
.57425 .55985 Mdot
.52754 .43057 Mdot
.48503 .49724 Mdot
.52167 .47515 Mdot
.52827 .56251 Mdot
.51399 .48766 Mdot
.53185 .47187 Mdot
.52342 .49978 Mdot
.64857 .53447 Mdot
.4984 .50503 Mdot
.519 .48791 Mdot
.49018 .4703 Mdot
.4682 .50128 Mdot
.51406 .52277 Mdot
.45062 .55822 Mdot
.56313 .51122 Mdot
.52123 .45149 Mdot
.47151 .48549 Mdot
.46296 .49223 Mdot
.46343 .51757 Mdot
.54393 .45349 Mdot
.51538 .48476 Mdot
.47527 .46193 Mdot
.49593 .5142 Mdot
.48078 .52762 Mdot
.44067 .55434 Mdot
.48262 .51213 Mdot
.57898 .49211 Mdot
.52573 .52394 Mdot
.50476 .52818 Mdot
.41512 .46001 Mdot
.51207 .49463 Mdot
.52808 .47151 Mdot
.52114 .39686 Mdot
.52818 .52255 Mdot
.57706 .53177 Mdot
.46167 .45707 Mdot
.48429 .46358 Mdot
.48171 .46238 Mdot
.47339 .44212 Mdot
.54095 .44612 Mdot
.42982 .47512 Mdot
.50846 .44681 Mdot
.49457 .51321 Mdot
.43214 .45209 Mdot
.51201 .51546 Mdot
.48755 .51886 Mdot
.49346 .53396 Mdot
.46564 .4538 Mdot
.4948 .42532 Mdot
.46631 .49133 Mdot
.47382 .50564 Mdot
.46975 .44597 Mdot
.45152 .58523 Mdot
.46243 .5375 Mdot
.49066 .45341 Mdot
.54483 .41938 Mdot
.52384 .46676 Mdot
.47138 .44283 Mdot
.49138 .46225 Mdot
.50414 .44079 Mdot
.45388 .42737 Mdot
.46405 .52554 Mdot
.50364 .57637 Mdot
.43911 .47947 Mdot
.54079 .41426 Mdot
.48666 .48149 Mdot
.46995 .50836 Mdot
.52201 .46147 Mdot
.48951 .52729 Mdot
.55378 .48143 Mdot
.42926 .44398 Mdot
.55832 .50473 Mdot
.52165 .48372 Mdot
.51084 .50171 Mdot
.44293 .55429 Mdot
.55032 .53504 Mdot
.56 .51291 Mdot
.44712 .45852 Mdot
.44864 .57223 Mdot
.52349 .51296 Mdot
.5552 .47517 Mdot
.46001 .52733 Mdot
.48317 .48347 Mdot
.56945 .55886 Mdot
.48278 .48747 Mdot
.53946 .43667 Mdot
.45427 .4645 Mdot
.50231 .52543 Mdot
.43139 .49403 Mdot
.52988 .53417 Mdot
.45232 .46656 Mdot
.49669 .53041 Mdot
.48082 .5191 Mdot
.56752 .52642 Mdot
.50419 .50053 Mdot
.49226 .45247 Mdot
.61876 .55404 Mdot
.57307 .48642 Mdot
.53107 .46237 Mdot
.46993 .48512 Mdot
.52777 .54179 Mdot
.46714 .51591 Mdot
.472 .54142 Mdot
.53038 .5453 Mdot
.47359 .53714 Mdot
.47269 .49847 Mdot
.51024 .46722 Mdot
.43345 .5619 Mdot
.54222 .54384 Mdot
.56047 .52022 Mdot
.494 .46853 Mdot
.494 .49728 Mdot
.48361 .46427 Mdot
.44797 .53475 Mdot
.52948 .50347 Mdot
.46933 .51267 Mdot
.49569 .46953 Mdot
.44162 .36798 Mdot
.45761 .53171 Mdot
.46114 .46385 Mdot
.54295 .53749 Mdot
.49473 .47393 Mdot
.50515 .5029 Mdot
.46319 .45158 Mdot
.44877 .468 Mdot
.48636 .47321 Mdot
.44843 .53684 Mdot
.47285 .52129 Mdot
.5072 .51967 Mdot
.4801 .53041 Mdot
.53738 .47662 Mdot
.53245 .54959 Mdot
.45956 .46633 Mdot
.46401 .48048 Mdot
.49342 .51943 Mdot
.42549 .5362 Mdot
.54476 .47525 Mdot
.48653 .49864 Mdot
.48704 .5071 Mdot
.41219 .50823 Mdot
.54217 .46564 Mdot
.46199 .53159 Mdot
.54343 .52788 Mdot
.48194 .48433 Mdot
.46204 .45498 Mdot
.54589 .46218 Mdot
.50745 .44242 Mdot
.55508 .53271 Mdot
.49815 .4703 Mdot
.45313 .45442 Mdot
.50759 .51722 Mdot
.45975 .53838 Mdot
.44524 .52887 Mdot
.36991 .4942 Mdot
.49953 .50898 Mdot
.55098 .49288 Mdot
.45347 .52155 Mdot
.5031 .49886 Mdot
.49724 .46155 Mdot
.55691 .50251 Mdot
.5267 .51748 Mdot
.46616 .51855 Mdot
.52611 .41571 Mdot
.47179 .47111 Mdot
.50525 .51589 Mdot
.49377 .56378 Mdot
.46877 .50785 Mdot
.58773 .53234 Mdot
.46204 .49913 Mdot
.57387 .50028 Mdot
.51306 .51303 Mdot
.51863 .48584 Mdot
.4486 .53694 Mdot
.47618 .49263 Mdot
.56564 .5404 Mdot
.45933 .50753 Mdot
.5744 .51598 Mdot
.56741 .43548 Mdot
.55755 .50238 Mdot
.44739 .41796 Mdot
.49915 .48323 Mdot
.51097 .50077 Mdot
.50367 .49217 Mdot
.52837 .41802 Mdot
.45083 .45024 Mdot
.55702 .47827 Mdot
.50531 .43717 Mdot
.43722 .46103 Mdot
.5292 .42826 Mdot
.54697 .52659 Mdot
.49234 .51525 Mdot
.55043 .53946 Mdot
.51979 .41169 Mdot
.50616 .47507 Mdot
.56398 .55246 Mdot
.4812 .46127 Mdot
.46226 .55288 Mdot
.43077 .55379 Mdot
.5137 .44571 Mdot
.4884 .52149 Mdot
.54569 .54136 Mdot
.47665 .37404 Mdot
.52972 .52998 Mdot
.53294 .54807 Mdot
.47755 .46159 Mdot
.52906 .464 Mdot
.48084 .45403 Mdot
.52585 .49176 Mdot
.50771 .50725 Mdot
.42537 .53912 Mdot
.49013 .38803 Mdot
.47542 .38965 Mdot
.5527 .53837 Mdot
.44155 .35323 Mdot
.47954 .51908 Mdot
.52551 .54656 Mdot
.55416 .52211 Mdot
.50533 .48031 Mdot
.51102 .4973 Mdot
.46333 .50743 Mdot
.4229 .52587 Mdot
.48134 .49607 Mdot
.42445 .51036 Mdot
.49575 .4819 Mdot
.508 .55139 Mdot
.49898 .4855 Mdot
.54015 .44353 Mdot
.5288 .51581 Mdot
.52017 .55614 Mdot
.47337 .53326 Mdot
.48803 .43723 Mdot
.43482 .4917 Mdot
.51828 .52195 Mdot
.49529 .48723 Mdot
.44554 .47168 Mdot
.48474 .34015 Mdot
.55507 .52156 Mdot
.45427 .54439 Mdot
.52491 .51116 Mdot
.50649 .53284 Mdot
.47974 .52655 Mdot
.4793 .53722 Mdot
.52721 .48419 Mdot
.45638 .49999 Mdot
.42651 .50153 Mdot
.55754 .50605 Mdot
.53816 .56747 Mdot
.55444 .50466 Mdot
.4663 .52427 Mdot
.46946 .53427 Mdot
.46989 .52256 Mdot
.48131 .54298 Mdot
.61455 .44732 Mdot
.50493 .54574 Mdot
.43858 .55479 Mdot
.51238 .51296 Mdot
.44241 .56229 Mdot
.50955 .47655 Mdot
.52189 .45665 Mdot
.54981 .46949 Mdot
.50975 .48881 Mdot
.58496 .49177 Mdot
.47632 .50066 Mdot
.52664 .50834 Mdot
.47201 .525 Mdot
.55076 .45996 Mdot
.40934 .49243 Mdot
.55592 .52887 Mdot
.53613 .47746 Mdot
.5075 .497 Mdot
.48391 .52716 Mdot
.56416 .51412 Mdot
.49244 .47774 Mdot
.53541 .5408 Mdot
.51213 .51504 Mdot
.51887 .54865 Mdot
.56203 .49752 Mdot
.52355 .5174 Mdot
.49227 .48864 Mdot
.46439 .54089 Mdot
.49261 .52833 Mdot
.46215 .46841 Mdot
.48768 .4396 Mdot
.36712 .60437 Mdot
.50204 .64974 Mdot
.42203 .53199 Mdot
.41501 .50357 Mdot
.54201 .54421 Mdot
.51221 .65709 Mdot
.53684 .43041 Mdot
.53468 .43763 Mdot
.50431 .50412 Mdot
.47203 .46962 Mdot
.48307 .45818 Mdot
.48263 .45569 Mdot
.51921 .5224 Mdot
.56364 .51242 Mdot
.459 .45571 Mdot
.45456 .51139 Mdot
.5196 .55057 Mdot
.52659 .42733 Mdot
.57872 .43517 Mdot
.54199 .44909 Mdot
.46476 .55162 Mdot
.51633 .49358 Mdot
.46271 .52085 Mdot
.49646 .56555 Mdot
.43891 .44186 Mdot
.51577 .49748 Mdot
.55952 .51621 Mdot
.46442 .45803 Mdot
.34625 .49086 Mdot
.43716 .49052 Mdot
.38709 .57463 Mdot
.51986 .45567 Mdot
.47374 .5041 Mdot
.44138 .47532 Mdot
.44811 .50222 Mdot
.49345 .43753 Mdot
.52453 .41773 Mdot
.62992 .54871 Mdot
.52822 .53008 Mdot
.55672 .50265 Mdot
.46205 .52113 Mdot
.46655 .57762 Mdot
.47281 .4614 Mdot
.52664 .49272 Mdot
.46259 .52191 Mdot
.48721 .58239 Mdot
.58454 .50298 Mdot
.44938 .4622 Mdot
.49434 .43358 Mdot
.45882 .52893 Mdot
.45062 .46125 Mdot
.48678 .51625 Mdot
.4707 .5044 Mdot
.49784 .51944 Mdot
.5493 .54059 Mdot
.5621 .44446 Mdot
.43279 .55391 Mdot
.42154 .52833 Mdot
.55841 .49228 Mdot
.52905 .52158 Mdot
.49997 .5251 Mdot
.49155 .47811 Mdot
.54821 .56174 Mdot
.47636 .50849 Mdot
.55932 .55338 Mdot
.51426 .52148 Mdot
.46441 .52141 Mdot
.42695 .49928 Mdot
.48522 .48288 Mdot
.52512 .55739 Mdot
.52987 .51658 Mdot
.55685 .56741 Mdot
.43696 .54845 Mdot
.46207 .43893 Mdot
.50506 .47592 Mdot
.55862 .54847 Mdot
.49998 .46895 Mdot
.42677 .49338 Mdot
.47017 .52201 Mdot
.51784 .46903 Mdot
.51129 .50875 Mdot
.35308 .48212 Mdot
.49155 .46644 Mdot
.52442 .48145 Mdot
.50897 .49366 Mdot
.50276 .54107 Mdot
.57569 .46415 Mdot
.50154 .42766 Mdot
.54184 .45444 Mdot
.5484 .45845 Mdot
.5179 .44745 Mdot
.50262 .48443 Mdot
.55771 .52641 Mdot
.51891 .46089 Mdot
.4139 .61685 Mdot
.45486 .46553 Mdot
.56269 .55578 Mdot
.5387 .54741 Mdot
.55781 .47941 Mdot
.4892 .51358 Mdot
.4919 .53857 Mdot
.49997 .46505 Mdot
.47639 .5023 Mdot
.52604 .49899 Mdot
.56885 .54118 Mdot
.47056 .52177 Mdot
.50822 .42188 Mdot
.47588 .51375 Mdot
.53874 .42685 Mdot
.50315 .47212 Mdot
.34593 .52295 Mdot
.4652 .50141 Mdot
.51696 .52798 Mdot
.52149 .4448 Mdot
.50473 .47105 Mdot
.45692 .51995 Mdot
.45287 .52015 Mdot
.55847 .50494 Mdot
.47225 .50656 Mdot
.52332 .52075 Mdot
.52033 .48646 Mdot
.48275 .50302 Mdot
.52149 .45834 Mdot
.46127 .53195 Mdot
.54724 .56447 Mdot
.52475 .52459 Mdot
.4833 .55899 Mdot
.4787 .4743 Mdot
.55896 .51015 Mdot
.51951 .4853 Mdot
.45304 .47702 Mdot
.47131 .56154 Mdot
.52463 .52097 Mdot
.46045 .52327 Mdot
.51898 .4564 Mdot
.5767 .45622 Mdot
.5096 .51703 Mdot
.48515 .507 Mdot
.44434 .57565 Mdot
.45572 .52596 Mdot
.51741 .46476 Mdot
.55274 .45426 Mdot
.45514 .51609 Mdot
.51212 .48331 Mdot
.52498 .46884 Mdot
.51974 .45063 Mdot
.51685 .48988 Mdot
.44644 .60644 Mdot
.45223 .5041 Mdot
.54954 .40085 Mdot
.48741 .47808 Mdot
.51433 .51709 Mdot
.55166 .42953 Mdot
.54521 .53958 Mdot
.51176 .48758 Mdot
.50602 .49433 Mdot
.52949 .42439 Mdot
.47101 .48297 Mdot
.52123 .52467 Mdot
.5239 .46652 Mdot
.53133 .55385 Mdot
.53618 .55818 Mdot
.54115 .55437 Mdot
.45509 .45132 Mdot
.50824 .42036 Mdot
.48902 .49053 Mdot
.48966 .46174 Mdot
.57394 .48868 Mdot
.49804 .46239 Mdot
.50782 .52726 Mdot
.57405 .44105 Mdot
.52467 .51481 Mdot
.52124 .46241 Mdot
.45383 .55726 Mdot
.48062 .56212 Mdot
.51499 .51413 Mdot
.49495 .44726 Mdot
.47748 .45465 Mdot
.45021 .45915 Mdot
.51104 .50685 Mdot
.50204 .5128 Mdot
.45843 .51704 Mdot
.47597 .48991 Mdot
.46685 .52955 Mdot
.52442 .56788 Mdot
.48737 .49379 Mdot
.56335 .51345 Mdot
.48157 .50498 Mdot
.49816 .46766 Mdot
.51508 .51188 Mdot
.56839 .54139 Mdot
.50192 .34699 Mdot
.39558 .45912 Mdot
.55696 .51799 Mdot
.55368 .49504 Mdot
.4363 .35862 Mdot
.46737 .53978 Mdot
.54024 .61186 Mdot
.47398 .47639 Mdot
.50041 .35561 Mdot
.4636 .37897 Mdot
.51309 .47737 Mdot
.52089 .46347 Mdot
.46624 .44649 Mdot
.49515 .53672 Mdot
.47714 .45911 Mdot
.43704 .56412 Mdot
.50888 .46627 Mdot
.52948 .52946 Mdot
.54166 .45651 Mdot
.46337 .5007 Mdot
.53648 .45591 Mdot
.4734 .469 Mdot
.5164 .52464 Mdot
.47459 .47538 Mdot
.49729 .57997 Mdot
.47551 .52782 Mdot
.5218 .53752 Mdot
.52611 .52976 Mdot
.5495 .48709 Mdot
.54511 .40814 Mdot
.48715 .51998 Mdot
.53036 .54526 Mdot
.45091 .48931 Mdot
.33981 .52095 Mdot
.4932 .50079 Mdot
.52794 .51914 Mdot
.49486 .46905 Mdot
.52073 .4716 Mdot
.47606 .50979 Mdot
.55056 .53288 Mdot
.51738 .48861 Mdot
.56836 .44927 Mdot
.44085 .54358 Mdot
.49789 .51848 Mdot
.51755 .47957 Mdot
.55315 .47563 Mdot
.44256 .47548 Mdot
.44353 .54675 Mdot
.48411 .5055 Mdot
.54728 .45083 Mdot
.4287 .5372 Mdot
.53577 .54068 Mdot
.47077 .42149 Mdot
.42796 .53221 Mdot
.45108 .50095 Mdot
.46623 .56382 Mdot
.44074 .56834 Mdot
.49892 .47955 Mdot
.42357 .52502 Mdot
.50397 .53487 Mdot
.49411 .47701 Mdot
.44917 .51527 Mdot
.46663 .51386 Mdot
.57835 .53082 Mdot
.44393 .55366 Mdot
.55948 .55292 Mdot
.52378 .52943 Mdot
.43641 .54437 Mdot
.52695 .5131 Mdot
.46689 .51389 Mdot
.52224 .51753 Mdot
.55797 .48266 Mdot
.45547 .49425 Mdot
.49194 .51868 Mdot
.52984 .51109 Mdot
.42505 .50632 Mdot
.49802 .52802 Mdot
.52237 .52319 Mdot
.51585 .5759 Mdot
.48395 .51969 Mdot
.45301 .46045 Mdot
.51934 .50211 Mdot
.51689 .47125 Mdot
.51567 .49392 Mdot
.50336 .51741 Mdot
.48973 .50665 Mdot
.46399 .49162 Mdot
.54931 .54109 Mdot
.50753 .49915 Mdot
.46886 .52546 Mdot
.51572 .47489 Mdot
.5074 .44051 Mdot
.56449 .55809 Mdot
.41453 .46005 Mdot
.49892 .43841 Mdot
.4844 .55131 Mdot
.4407 .48267 Mdot
.4726 .56364 Mdot
.46231 .55834 Mdot
.53011 .65635 Mdot
.53272 .52806 Mdot
.58043 .53069 Mdot
.48998 .48014 Mdot
.56341 .52816 Mdot
.50488 .47676 Mdot
.48733 .50075 Mdot
.55276 .50908 Mdot
.44134 .54665 Mdot
.48551 .55206 Mdot
.4915 .58019 Mdot
.50031 .48488 Mdot
.55021 .48838 Mdot
.51213 .42911 Mdot
.50735 .61071 Mdot
.45269 .46293 Mdot
.49141 .48562 Mdot
.49038 .52862 Mdot
.51914 .46128 Mdot
.45397 .52379 Mdot
.48301 .57831 Mdot
.60162 .41818 Mdot
.49315 .34791 Mdot
.44934 .47306 Mdot
.47736 .48648 Mdot
.52535 .48494 Mdot
.42901 .54889 Mdot
.54657 .51688 Mdot
.48815 .47232 Mdot
.45116 .56193 Mdot
.49745 .47496 Mdot
.53319 .47527 Mdot
.45971 .51365 Mdot
.55157 .49092 Mdot
.46176 .52982 Mdot
.3413 .49048 Mdot
.52111 .45288 Mdot
.50754 .44629 Mdot
.52229 .48676 Mdot
.46405 .5183 Mdot
.52795 .42151 Mdot
.56929 .63066 Mdot
.45221 .49781 Mdot
.52342 .46784 Mdot
.46714 .51852 Mdot
.46479 .45749 Mdot
.47451 .4639 Mdot
.47553 .58391 Mdot
.50435 .4759 Mdot
.46455 .43555 Mdot
.50002 .47633 Mdot
.46845 .49426 Mdot
.51859 .44848 Mdot
.4668 .52987 Mdot
.52575 .53049 Mdot
.46503 .51687 Mdot
.45035 .48121 Mdot
.50924 .55354 Mdot
.52151 .51658 Mdot
.48752 .47946 Mdot
.4421 .48884 Mdot
.42878 .49831 Mdot
.44882 .48513 Mdot
.42792 .5468 Mdot
.51779 .48795 Mdot
.46673 .49266 Mdot
.46015 .51045 Mdot
.48399 .52006 Mdot
.40781 .45388 Mdot
.4616 .54024 Mdot
.57104 .46472 Mdot
.51338 .52041 Mdot
.49524 .51256 Mdot
.52084 .46385 Mdot
.55705 .52456 Mdot
.42463 .52956 Mdot
.48883 .47614 Mdot
.51425 .46265 Mdot
.45315 .51154 Mdot
.52361 .52331 Mdot
.52928 .53134 Mdot
.44029 .58919 Mdot
.47733 .4471 Mdot
.55277 .46648 Mdot
.54149 .60822 Mdot
.55978 .52428 Mdot
.52394 .52414 Mdot
.48097 .53168 Mdot
.47122 .48085 Mdot
.47816 .55538 Mdot
.58252 .50773 Mdot
.45842 .37458 Mdot
.44991 .63191 Mdot
.47653 .50024 Mdot
.52116 .51549 Mdot
.46036 .57237 Mdot
.49357 .4875 Mdot
.51507 .48913 Mdot
.55063 .46128 Mdot
.47606 .50035 Mdot
.50638 .50338 Mdot
.5334 .4536 Mdot
.43921 .5663 Mdot
.5467 .45436 Mdot
.47453 .48356 Mdot
.45615 .57915 Mdot
.48287 .47163 Mdot
.53266 .35884 Mdot
.44736 .56444 Mdot
.515 .46295 Mdot
.5473 .52658 Mdot
.46227 .5346 Mdot
.44849 .49868 Mdot
.49934 .484 Mdot
.51973 .46674 Mdot
.52635 .52192 Mdot
.46989 .52158 Mdot
.56178 .45329 Mdot
.41722 .45258 Mdot
.52859 .41942 Mdot
.45271 .53341 Mdot
.50606 .48688 Mdot
.61078 .49313 Mdot
.48044 .45706 Mdot
.47593 .52693 Mdot
.52597 .49368 Mdot
.5127 .41815 Mdot
.54147 .46393 Mdot
.52654 .5294 Mdot
.5031 .51177 Mdot
.53341 .42662 Mdot
.42691 .49919 Mdot
.51541 .49968 Mdot
.55103 .56308 Mdot
.51082 .48107 Mdot
.46013 .51292 Mdot
.48115 .48722 Mdot
.48114 .4838 Mdot
.43859 .5444 Mdot
.46805 .50166 Mdot
.46238 .50235 Mdot
.48376 .47289 Mdot
.40564 .51495 Mdot
.49985 .47976 Mdot
.52027 .42141 Mdot
.48689 .53277 Mdot
.5104 .46698 Mdot
.45431 .5386 Mdot
.55935 .49851 Mdot
.55951 .51176 Mdot
.47628 .49642 Mdot
.52588 .46597 Mdot
.47621 .46903 Mdot
.47325 .51391 Mdot
.54503 .45297 Mdot
.43583 .48143 Mdot
.47861 .54471 Mdot
.50956 .44874 Mdot
.52359 .51968 Mdot
.49056 .50199 Mdot
.58766 .53087 Mdot
.5511 .46978 Mdot
.43624 .46306 Mdot
.4953 .47643 Mdot
.51295 .46819 Mdot
.46933 .514 Mdot
.52706 .58166 Mdot
.50292 .48074 Mdot
.47488 .49004 Mdot
.55856 .52001 Mdot
.47335 .55203 Mdot
.4679 .487 Mdot
.49285 .49012 Mdot
.65166 .53119 Mdot
.51223 .51728 Mdot
.45163 .44265 Mdot
.45953 .42257 Mdot
.44078 .49109 Mdot
.54218 .54113 Mdot
.4646 .46101 Mdot
.53072 .55091 Mdot
.4968 .47689 Mdot
.51755 .5259 Mdot
.45616 .52534 Mdot
.47192 .54663 Mdot
.50998 .54743 Mdot
.48176 .53537 Mdot
.55923 .56077 Mdot
.42907 .54681 Mdot
.48331 .48924 Mdot
.51752 .56101 Mdot
.46404 .499 Mdot
.4955 .47193 Mdot
.44836 .57329 Mdot
.54042 .4412 Mdot
.52812 .50758 Mdot
.44552 .44196 Mdot
.45611 .63064 Mdot
.55049 .49981 Mdot
.49841 .48637 Mdot
.52472 .50652 Mdot
.49841 .51367 Mdot
.52048 .51607 Mdot
.4753 .53957 Mdot
.53851 .43427 Mdot
.47011 .49682 Mdot
.52663 .50962 Mdot
.52533 .44716 Mdot
.55949 .52339 Mdot
.45485 .52521 Mdot
.55167 .50328 Mdot
.55682 .50084 Mdot
.45118 .41523 Mdot
.52722 .49031 Mdot
.34664 .53509 Mdot
.49717 .48731 Mdot
.47948 .51765 Mdot
.47069 .5722 Mdot
.60577 .48225 Mdot
.51085 .49611 Mdot
.48759 .45646 Mdot
.48088 .46691 Mdot
.47878 .54263 Mdot
.56332 .4836 Mdot
.44743 .5087 Mdot
.484 .47933 Mdot
.5297 .50613 Mdot
.50037 .44537 Mdot
.45337 .50226 Mdot
.52527 .46937 Mdot
.44786 .52673 Mdot
.45894 .45795 Mdot
.50361 .43747 Mdot
.51789 .52506 Mdot
.50789 .41862 Mdot
.54052 .42266 Mdot
.43741 .57248 Mdot
.56495 .54425 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo09Wooooo0_l0002/oooo
o`007_ooool00ol0003oooooooooo`2Iooooo`;o0000[?ooool001kooooo00?o0000ooooooooool0
W?ooool2o`000003ooooool0003o00000:Kooooo000Nooooo`;o0000WOooool2o`000003ooooool0
003o00000:Kooooo000Nooooo`03o`000?oooooooooo08_ooooo0_l0002jooooo`007_ooool00ol0
003oooooooooo`2;ooooo`;o00004_ooool2o`000:Kooooo000Nooooo`03o`000?oooooooooo08[o
oooo0_l0000Cooooo`;o00002?ooool2o`0009cooooo000Nooooo`03o`000?oooooooooo08[ooooo
0_l0000Gooooo`;o00001?ooool2o`0009cooooo000Nooooo`03o`000?oooooooooo0:?ooooo0_l0
002Rooooo`007_ooool00ol0003oooooooooo`2;ooooo`;o0000^_ooool001kooooo00?o0000oooo
ooooool0Roooool2o`000;[ooooo000Nooooo`03o`000?oooooooooo097ooooo0_l00004ooooo`;o
0000[_ooool001kooooo00?o0000ooooooooool0TOooool4o`0000;ooooo0_l0002^ooooo`007_oo
ool00ol0003oooooooooo`2Cooooo`;o0000/_ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`2Kooooo`;o0000Z_ooool001kooooo00?o0000oooooooo
ool0U_ooool2o`0000?ooooo0_l0002Zooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`2Fooooo`;o
0000[oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0:Gooooo0_l0002Pooooo`000oooool01Ol@413ooooo
oooooooooooo410@00_ooooo1Ol00006ooooo`?o0000YOooool2o`0000Sooooo0_l0002Fooooo`00
0oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool00ol0
003oooooooooo`2_ooooo`;o0000U_ooool000?ooooo00Go0000ooooooooooooooooo`00000;oooo
o`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol@
413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`2]
ooooo`;o0000V?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co
000000Oooooo00?o0000ooooooooool0YOooool3o`0000;ooooo0_l000000ooooooo0000o`00002H
ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool0
0ol0003oooooooooo`2?ooooo`;o00005?ooool4o`000003ooooool0003o000000;o0000VOooool0
01kooooo00?o0000ooooooooool0SOooool4o`00013ooooo1?l000000ooooooo0000o`000002o`00
00;ooooo0ol0000@ooooo`;o0000Q_ooool001kooooo00?o0000ooooooooool0SOooool2o`0000;o
oooo0_l000001?oooooo0000o`000?l0000:ooooo`Wo00000_ooool3o`00013ooooo0_l00026oooo
o`007_ooool00ol0003oooooooooo`2Aooooo`;o000000Coooooo`000?l0003o00001_ooool2o`00
00;ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0009Wooooo000Nooooo`03
o`000?oooooooooo08oooooo0_l0000;ooooo`Go00001_ooool6o`0009[ooooo000Nooooo`03o`00
0?oooooooooo08oooooo0_l0000;ooooo`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`Ko
00000_ooool2o`0009Kooooo000Nooooo`03o`000?oooooooooo09Cooooo0_l00007ooooo`;o0000
0oooool2o`0000?ooooo0_l000001?oooooo0000o`000?l00002ooooo`;o0000U_ooool001kooooo
00?o0000ooooooooool0Toooool3o`0000Cooooo1Ol000000ooooooo0000o`000007ooooo`Co0000
1oooool2o`0000;ooooo0_l0002=ooooo`007_ooool00ol0003oooooooooo`2Booooo`?o00001?oo
ool:o`0000Kooooo1Ol00006ooooo`;o000000Coooooo`000?l0003o0000SOooool001kooooo00?o
0000ooooooooool0Qoooool2o`0000;ooooo1_l000001?oooooo0000o`000?ooool3o`000004oooo
ool0003o0000o`0000;ooooo1Ol00007ooooo`Ko00001oooool2o`0008kooooo000Nooooo`03o`00
0?oooooooooo08Oooooo0_l00002ooooo`Ko00000_ooool6o`0000Cooooo3?l00002ooooo`Go0000
00?oooooo`000?l000000_l0000?ooooo`;o0000POooool001kooooo00?o0000ooooooooool0S_oo
ool2o`0000?ooooo1_l00004ooooo`co00000oooool2o`0000?ooooo1_l0000=ooooo`;o0000POoo
ool001kooooo0_l00025ooooo`;o00000_ooool2o`0000Cooooo1_l000001?oooooo0000o`000?l0
0003ooooo`?o00001?ooool5o`0000Gooooo1?l00003ooooo`Co0000T?ooool001kooooo00?o0000
ooooooooool0P?ooool2o`0000;ooooo0_l00002ooooo`;o00001Oooool6o`000003ooooool0003o
000000Ko00001oooool3o`000003ooooool0003o000000Oo000000?oooooo`000?l000000_ooool2
o`0008kooooo000Nooooo`03o`000?oooooooooo07cooooo0_l00002ooooo`;o00001_ooool2o`00
00?ooooo2?l00002ooooo`Go00002?ooool4o`000003ooooool0003o000000Oo00001Oooool2o`00
08kooooo000Nooooo`03o`000?oooooooooo07cooooo0_l00005ooooo`;o00000oooool4o`000003
ooooool0003o000000Ko000000?oooooo`000?l000002?l00003ooooo`Go000000?oooooo`000?l0
00000_ooool4o`0009Kooooo000Nooooo`03o`000?oooooooooo08?ooooo0_l00005ooooo`;o0000
0_ooool7o`000003ooooool0003o000000So00000oooool8o`000003ooooool0003o000000?o0000
1Oooool3o`0008kooooo000Nooooo`03o`000?oooooooooo08[ooooo0_l00002ooooo`Ko00000_oo
ool5o`000003ooooool0003o000000;o000000?oooooo`000?l000001ol00002ooooo`;o00000_oo
ool2o`0000;ooooo1Ol0002>ooooo`007_ooool00ol0003oooooooooo`2=ooooo`Oo000000?ooooo
o`000?l000005?l00004ooooo`?o00000_ooool2o`00097ooooo000Nooooo`03o`000?oooooooooo
08gooooo0ol00005ooooo`ko000000?oooooo`000?l000001Ol00004ooooo`;o0000U_ooool001ko
oooo00?o0000ooooooooool0R?ooool2o`000003ooooool0003o000000Co00001?oooolBo`0000;o
oooo1_l000000ooooooo0000o`00002Eooooo`007_ooool00ol0003oooooooooo`28ooooo`;o0000
00?oooooo`000?l000001?l00002ooooo`Go000000?oooooo`000?l000005?l000001?oooooo0000
o`000?l0002Dooooo`007_ooool00ol0003oooooooooo`1_ooooo`;o00006Oooool3o`000003oooo
ool0003o000000?ooooo5_l00007ooooo`Ko000000?oooooo`000?l000002?ooool2o`0008Cooooo
000Nooooo`03o`000?oooooooooo06oooooo0_l0000Eooooo`;o00000_ooool3o`000003ooooool0
003o000000Cooooo5Ol00003ooooo`;o000000?oooooo`000?l000002?l00008ooooo`;o0000Q?oo
ool001kooooo00?o0000ooooooooool0Joooool2o`0001Wooooo0_l00004ooooo`Co00001?ooool7
o`000003ooooool0003o000000_o00000oooool2o`000003ooooool0003o000000Gooooo0_l0002?
ooooo`007_ooool00ol0003oooooooooo`1[ooooo`?o00004oooool2o`0000Cooooo2Ol00002oooo
oaOo00001_ooool4o`0000?ooooo1_l00006ooooo`;o0000Poooool001kooooo00?o0000oooooooo
ool0K?ooool2o`0000Kooooo0_l0000;ooooo`;o00001?ooool6o`0000?ooooo1_l000000ooooooo
0000o`000004o`000003ooooool0003o000000Ko000000?oooooo`000?l000001_ooool4o`0000Go
oooo1?l00006ooooo`;o0000Poooool001kooooo00?o0000ooooooooool0M?ooool2o`00017ooooo
0ol00004oooooa3o000000?oooooo`000?l000001Ol000000ooooooo0000o`000007ooooo`Go0000
T_ooool001kooooo0_l00028ooooo`;o00001Oooool;o`000003ooooool0003o000000;o000000?o
ooooo`000?l000002?l000000ooooooo0000o`000003ooooo`Ko000000?oooooo`000?l00000Sooo
ool001kooooo00?o0000ooooooooool0Poooool2o`000004ooooool0003o0000o`0000Gooooo5_l0
00000ooooooo0000o`000005o`0000?ooooo1?l00003ooooo`;o00000_ooool2o`0008_ooooo000N
ooooo`03o`000?oooooooooo08;ooooo0ol000000ooooooo0000o`000005oooooa3o000000?ooooo
o`000?l000001Ol000000ooooooo0000o`000002o`0000Gooooo1Ol00005ooooo`?o0000Roooool0
01kooooo00?o0000ooooooooool0P_ooool2o`000004ooooool0003o0000o`0000Gooooo3?l00000
0ooooooo0000o`000009o`000003ooooool0003o000000;o00001_ooool5o`0000Cooooo0_l0002<
ooooo`007_ooool00ol0003oooooooooo`20ooooo`;o00000oooool3o`0000Oooooo5_l000000ooo
oooo0000o`000002o`0000Kooooo1Ol0002Booooo`007_ooool00ol0003oooooooooo`20ooooo`;o
00003?oooolLo`0000Cooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00003ooooo`;o
0000ROooool001kooooo00?o0000ooooooooool0J_ooool2o`00023ooooo2ol000000ooooooo0000
o`00000@o`0000Cooooo0_l000001?oooooo0000o`000?l00003ooooo`;o00000oooool2o`0008Wo
oooo000Nooooo`03o`000?oooooooooo06[ooooo1?l0000Gooooo`;o000000?oooooo`000?l00000
0_oooolDo`000003ooooool0003o000000Wo00001?ooool4o`0009?ooooo000Nooooo`03o`000?oo
oooooooo06cooooo0_l0000Gooooo`Go00000ooooolOo`0000;ooooo2?l0002Aooooo`007_ooool0
0ol0003oooooooooo`25ooooo`?o00001Oooool2o`000003ooooool0003o000001Wo00000_ooool3
o`000003ooooool0003o000000?o0000TOooool001kooooo00?o0000ooooooooool0K_ooool2o`00
01Gooooo1?l00004oooooako00000_ooool8o`0000;ooooo1_l0000Cooooo`;o0000MOooool001ko
oooo00?o0000ooooooooool0KOooool3o`0001Gooooo1?l00005ooooo`Ko000000?oooooo`000?l0
00001ol00002ooooo`?o00001?ooool3o`0000;ooooo0_l000001?oooooo0000o`000?l00005oooo
o`Ko00004_ooool3o`0007Gooooo000Nooooo`03o`000?oooooooooo06gooooo0_l0000Gooooo`?o
00001Oooool6o`000003ooooool0003o000000Co000000Goooooo`000?l0003o0000ooooo`02o`00
00Cooooo1?l00002ooooo`Ko00007Oooool2o`0007Kooooo000Nooooo`03o`000?oooooooooo08Ko
oooo0ol00005ooooo`co00000_ooool5o`0000Gooooo0ol000000ooooooo0000o`000006o`0000;o
oooo0ol0000Eooooo`;o0000NOooool001kooooo00?o0000ooooooooool0R_ooool3o`0000?ooooo
2_l00005ooooo`?o00001Oooool9o`0000Cooooo0ol0000Eooooo`;o0000NOooool001kooooo00?o
0000ooooooooool0Qoooool2o`000003ooooool0003o000000;o00000_ooool2o`0000?ooooo1Ol0
0006ooooo`Co000000?oooooo`000?l000001ol00003ooooo`;o000000?oooooo`000?l000004ooo
ool2o`0007cooooo000Nooooo`;o0000R?ooool7o`0000Gooooo1?l000001?oooooo0000o`000?l0
0006ooooo`?o000000?oooooo`000?l000001_l00004ooooo`;o00005_ooool2o`0007cooooo000N
ooooo`03o`000?oooooooooo08Sooooo1_l00004ooooo`?o000000?oooooo`000?l000001ol00002
ooooo`;o000000?oooooo`000?l000001Ol000000ooooooo0000o`000004ooooo`?o00003oooool3
o`00083ooooo000Nooooo`03o`000?oooooooooo08Sooooo1_l000000ooooooo0000o`000003o`00
00;ooooo0ol000000ooooooo0000o`000003o`0000;ooooo0_l000000ooooooo0000o`000008o`00
00Cooooo0ol0000?ooooo`?o0000P?ooool001kooooo00?o0000ooooooooool0ROooool2o`000003
ooooool0003o000000Ko00000oooool5o`0000Sooooo1Ol000000ooooooo0000o`000006ooooo`Oo
0000S_ooool001kooooo00?o0000ooooooooool0ROooool8o`000003ooooool0003o000000[o0000
1_ooool2o`0000;ooooo1?l00002ooooo`?o000000Coooooo`000?l0003ooooo1?l0002>ooooo`00
7_ooool00ol0003oooooooooo`29ooooo`So00000_ooool7o`0000;ooooo0ol00005ooooo`;o0000
0_ooool2o`0000Cooooo0ol0002Fooooo`007_ooool00ol0003oooooooooo`2:ooooo`Go00002Ooo
ool2o`0000?ooooo0_l00007ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`;o0000
U?ooool001kooooo00?o0000ooooooooool0R_ooool3o`000003ooooool0003o000000;ooooo0_l0
00001?oooooo0000o`000?ooool2o`0000cooooo0_l00002ooooo`?o00001?ooool2o`0009Cooooo
000Nooooo`03o`000?oooooooooo07[ooooo0_l0000>ooooo`Ko00000_ooool5o`0000Wooooo0ol0
00000ooooooo0000o`000004ooooo`;o0000Voooool001kooooo00?o0000ooooooooool0N_ooool2
o`00013ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00001Oooool3
o`000003ooooool0003o00000:7ooooo000Nooooo`03o`000?oooooooooo093ooooo0_l00002oooo
o`?o00000_ooool8o`0000Kooooo0_l0002Nooooo`007_ooool00ol0003oooooooooo`2?ooooo`;o
00001Oooool2o`0000;ooooo1ol00006ooooo`;o0000W_ooool001kooooo00?o0000ooooooooool0
Soooool2o`0000Gooooo0_l00003ooooo`Co0000Z?ooool001kooooo00?o0000ooooooooool0Rooo
ool2o`00013ooooo0_l0002Xooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2;ooooo`;o0000
^_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMg
oooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol@413ooooo
oooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000T_ooool2o`00
0;?ooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So
8B4Q00Kooooo00?o0000ooooooooool0T_ooool2o`000;?ooooo0003ooooo`05o`000?oooooooooo
ooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0Looo
ool2o`0001Sooooo0_l0002hooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00?o
EEEEohN7Qoooool02?ooool00ol0003oooooooooo`1cooooo`;o00006?ooool2o`0001gooooo0_l0
002Iooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`2Qooooo`;o00002Oooool2o`0009Wooooo0003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo08gooooo
0_l0000Booooo`;o00002Oooool2o`0009Wooooo000Nooooo`03o`000?oooooooooo08;ooooo0_l0
0009ooooo`;o0000^?ooool001kooooo00?o0000ooooooooool0P_ooool2o`000<?ooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`2>ooooo`Co00008oooool2o`00093ooooo000Nooooo`03o`000?oo
oooooooo08kooooo1?l0000Sooooo`;o0000T?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`2Oooooo`;o0000Y_ooool001kooooo0_l0002Pooooo`;o0000Y_ooool001kooooo00?o0000oooo
ooooool0Z?ooool2o`0009gooooo000Nooooo`03o`000?oooooooooo0:;ooooo0_l00004ooooo`;o
0000WOooool001kooooo00?o0000ooooooooool0X_ooool2o`000:?ooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_oo
ool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?oooooo
B?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
00001_ooool3o`000?ooooooB?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05
oc8b<_nHV9SooooooiRHV?lb<S801_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05
o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000
ooooooooool0oooooom8ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@
okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003ooooo
ooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@
o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`005?ooool4o`000003oa0@4?oooooo
oooo00?ooooo00?o0000ooooooooool0oooooom8ooooo`005_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0?ooooooB?ooool001Kooooo00?o0000ooooooooool01Oooool3o`000?oo
ooooB?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003ooooooooo
o`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000oooo
ooooool0oooooom@ooooo`005?ooool00omEEEGoIVIVo`00003ooooooe;ooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.453 .47333 Mdot
.50059 .46454 Mdot
.55179 .4732 Mdot
.51422 .4725 Mdot
.52467 .49027 Mdot
.45554 .56179 Mdot
.46866 .4771 Mdot
.50918 .45748 Mdot
.41015 .4928 Mdot
.50037 .43525 Mdot
.47 .44119 Mdot
.47292 .50235 Mdot
.47399 .58726 Mdot
.56655 .55195 Mdot
.44544 .56539 Mdot
.53114 .50223 Mdot
.49079 .45864 Mdot
.43482 .56166 Mdot
.43464 .47736 Mdot
.51724 .54559 Mdot
.4896 .45904 Mdot
.52506 .52581 Mdot
.54231 .4675 Mdot
.51144 .56792 Mdot
.48821 .44921 Mdot
.47804 .50807 Mdot
.4917 .41198 Mdot
.42018 .52235 Mdot
.51627 .49333 Mdot
.46142 .54898 Mdot
.46574 .54736 Mdot
.49726 .45654 Mdot
.50475 .5096 Mdot
.55427 .50461 Mdot
.47019 .57325 Mdot
.54414 .53655 Mdot
.48866 .50964 Mdot
.54992 .49199 Mdot
.53405 .47633 Mdot
.46356 .51287 Mdot
.52743 .51758 Mdot
.53142 .53816 Mdot
.45426 .51059 Mdot
.49131 .49369 Mdot
.49473 .45279 Mdot
.50619 .52482 Mdot
.58411 .51124 Mdot
.47728 .55522 Mdot
.51402 .56103 Mdot
.62507 .55684 Mdot
.5259 .48938 Mdot
.55062 .48941 Mdot
.51413 .49028 Mdot
.53302 .47662 Mdot
.53685 .47948 Mdot
.47663 .51786 Mdot
.45815 .50885 Mdot
.52765 .38283 Mdot
.5048 .46288 Mdot
.45524 .51466 Mdot
.5104 .53067 Mdot
.49827 .51659 Mdot
.55196 .53688 Mdot
.5311 .5013 Mdot
.51671 .50206 Mdot
.47744 .54458 Mdot
.44808 .51488 Mdot
.49296 .51954 Mdot
.47601 .53018 Mdot
.53165 .504 Mdot
.47218 .4433 Mdot
.52031 .47961 Mdot
.4583 .52132 Mdot
.50494 .4812 Mdot
.48153 .5623 Mdot
.52035 .41671 Mdot
.48723 .53015 Mdot
.4464 .55653 Mdot
.50887 .41694 Mdot
.42213 .49561 Mdot
.55101 .51236 Mdot
.50402 .45552 Mdot
.49384 .45165 Mdot
.52236 .52754 Mdot
.55303 .52464 Mdot
.50853 .48477 Mdot
.55793 .45748 Mdot
.48809 .51571 Mdot
.46042 .5146 Mdot
.56291 .54425 Mdot
.51273 .49864 Mdot
.51751 .53188 Mdot
.5536 .46 Mdot
.5907 .56425 Mdot
.55253 .41739 Mdot
.51465 .54177 Mdot
.48311 .51574 Mdot
.4557 .54314 Mdot
.58467 .49501 Mdot
.4676 .49551 Mdot
.55814 .45056 Mdot
.55654 .47267 Mdot
.51864 .47204 Mdot
.4916 .55402 Mdot
.41338 .47226 Mdot
.50635 .51148 Mdot
.33502 .51491 Mdot
.51632 .50213 Mdot
.45928 .49736 Mdot
.51924 .53239 Mdot
.44926 .51556 Mdot
.51905 .47838 Mdot
.49729 .47557 Mdot
.45933 .44482 Mdot
.44682 .51479 Mdot
.50667 .57428 Mdot
.49737 .44009 Mdot
.42198 .52656 Mdot
.54776 .51775 Mdot
.55097 .45668 Mdot
.42885 .54077 Mdot
.4801 .50539 Mdot
.51354 .4311 Mdot
.49007 .55664 Mdot
.49325 .46072 Mdot
.5111 .45002 Mdot
.46667 .53459 Mdot
.48018 .50633 Mdot
.48778 .50013 Mdot
.53497 .48966 Mdot
.4243 .53247 Mdot
.48131 .47169 Mdot
.54302 .45025 Mdot
.53709 .55781 Mdot
.53494 .47773 Mdot
.54625 .45386 Mdot
.46401 .48235 Mdot
.5022 .49262 Mdot
.46779 .52842 Mdot
.49285 .48367 Mdot
.51497 .50081 Mdot
.42441 .43949 Mdot
.49312 .50371 Mdot
.51764 .47989 Mdot
.50909 .51361 Mdot
.51994 .5332 Mdot
.45511 .48255 Mdot
.51701 .54031 Mdot
.44293 .51858 Mdot
.49928 .5565 Mdot
.54394 .54874 Mdot
.41826 .52959 Mdot
.51852 .49739 Mdot
.50481 .54874 Mdot
.4266 .51812 Mdot
.53134 .5021 Mdot
.50436 .5175 Mdot
.53448 .57219 Mdot
.48632 .53033 Mdot
.50754 .50843 Mdot
.4331 .52497 Mdot
.49522 .5352 Mdot
.45142 .54962 Mdot
.53601 .47994 Mdot
.45958 .50935 Mdot
.48104 .48708 Mdot
.42035 .45435 Mdot
.55953 .52139 Mdot
.53572 .52618 Mdot
.5533 .48005 Mdot
.42291 .51755 Mdot
.47951 .54444 Mdot
.49351 .46879 Mdot
.45842 .51267 Mdot
.43572 .58605 Mdot
.48282 .51308 Mdot
.51741 .54394 Mdot
.50968 .50883 Mdot
.583 .51372 Mdot
.51402 .55651 Mdot
.51504 .4761 Mdot
.51677 .54224 Mdot
.50284 .48609 Mdot
.51524 .49005 Mdot
.47887 .58896 Mdot
.4781 .49663 Mdot
.55368 .4626 Mdot
.51151 .53258 Mdot
.53715 .56035 Mdot
.5504 .4444 Mdot
.48994 .49015 Mdot
.52722 .49497 Mdot
.49883 .5544 Mdot
.51778 .4992 Mdot
.55309 .48884 Mdot
.52553 .51699 Mdot
.6403 .55318 Mdot
.49615 .50117 Mdot
.51567 .5019 Mdot
.50978 .4706 Mdot
.47769 .48711 Mdot
.49502 .52197 Mdot
.4253 .53917 Mdot
.5542 .52741 Mdot
.5385 .46989 Mdot
.48843 .47235 Mdot
.48103 .4705 Mdot
.45969 .50256 Mdot
.55354 .48728 Mdot
.52004 .4973 Mdot
.49336 .45235 Mdot
.48973 .5076 Mdot
.46241 .5228 Mdot
.42557 .5382 Mdot
.47962 .5054 Mdot
.58585 .51947 Mdot
.51358 .53037 Mdot
.48116 .52955 Mdot
.42728 .44 Mdot
.51174 .50424 Mdot
.53188 .48652 Mdot
.53551 .43075 Mdot
.51817 .5328 Mdot
.5687 .56052 Mdot
.48981 .4585 Mdot
.51394 .46718 Mdot
.50311 .46298 Mdot
.50299 .43121 Mdot
.55192 .47764 Mdot
.44451 .4506 Mdot
.52696 .46809 Mdot
.48937 .50654 Mdot
.45892 .44191 Mdot
.50283 .51392 Mdot
.47682 .51181 Mdot
.46836 .52933 Mdot
.5029 .4522 Mdot
.52517 .41809 Mdot
.48212 .47289 Mdot
.47788 .49682 Mdot
.49939 .43319 Mdot
.43812 .54669 Mdot
.44791 .50711 Mdot
.52741 .45688 Mdot
.56466 .42324 Mdot
.53543 .48888 Mdot
.49973 .42148 Mdot
.51919 .46725 Mdot
.52845 .45484 Mdot
.47916 .4248 Mdot
.45441 .50817 Mdot
.47892 .58719 Mdot
.44879 .44167 Mdot
.55878 .41974 Mdot
.4994 .4763 Mdot
.47324 .49766 Mdot
.54503 .46453 Mdot
.47009 .52386 Mdot
.55448 .51396 Mdot
.44258 .42221 Mdot
.56036 .52361 Mdot
.52701 .50342 Mdot
.50733 .5086 Mdot
.42529 .53283 Mdot
.52762 .54952 Mdot
.55042 .54036 Mdot
.47438 .44685 Mdot
.42569 .55027 Mdot
.52258 .52378 Mdot
.57537 .50849 Mdot
.45508 .50593 Mdot
.49671 .47582 Mdot
.53125 .55769 Mdot
.49371 .48007 Mdot
.55084 .46529 Mdot
.48035 .43212 Mdot
.48174 .523 Mdot
.44981 .46309 Mdot
.50223 .54108 Mdot
.47896 .44307 Mdot
.47105 .52795 Mdot
.47085 .51201 Mdot
.54012 .54697 Mdot
.50119 .50179 Mdot
.52672 .46605 Mdot
.59649 .56519 Mdot
.58568 .51457 Mdot
.54572 .46709 Mdot
.48716 .46863 Mdot
.49073 .54513 Mdot
.46468 .50508 Mdot
.44558 .52937 Mdot
.50088 .57259 Mdot
.45304 .52145 Mdot
.48166 .48641 Mdot
.52992 .47648 Mdot
.41737 .53621 Mdot
.51649 .55466 Mdot
.54682 .53865 Mdot
.51437 .47249 Mdot
.4949 .49389 Mdot
.51364 .46787 Mdot
.42141 .50051 Mdot
.52895 .52363 Mdot
.4694 .50304 Mdot
.51541 .47392 Mdot
.46504 .36854 Mdot
.43943 .5146 Mdot
.48266 .44956 Mdot
.51731 .54798 Mdot
.5106 .47628 Mdot
.5018 .50358 Mdot
.49428 .44232 Mdot
.46184 .44909 Mdot
.50588 .47041 Mdot
.44043 .5239 Mdot
.46383 .51358 Mdot
.49038 .51807 Mdot
.45932 .52145 Mdot
.55466 .49574 Mdot
.50536 .55589 Mdot
.47115 .4409 Mdot
.47497 .45037 Mdot
.47972 .51421 Mdot
.4247 .50592 Mdot
.55673 .49034 Mdot
.49002 .49212 Mdot
.48628 .5008 Mdot
.40773 .47978 Mdot
.5527 .49472 Mdot
.45255 .49821 Mdot
.52092 .56503 Mdot
.49549 .47594 Mdot
.49079 .43707 Mdot
.55263 .49698 Mdot
.53323 .44762 Mdot
.53929 .55548 Mdot
.51811 .47698 Mdot
.46612 .44115 Mdot
.49435 .51564 Mdot
.44667 .52072 Mdot
.44039 .51567 Mdot
.38794 .47412 Mdot
.49642 .50441 Mdot
.54497 .51341 Mdot
.45726 .50167 Mdot
.50066 .49994 Mdot
.52165 .46913 Mdot
.56034 .5219 Mdot
.52249 .52775 Mdot
.46158 .50565 Mdot
.54356 .45409 Mdot
.4908 .45538 Mdot
.49597 .51199 Mdot
.46084 .56881 Mdot
.47233 .49515 Mdot
.57071 .54973 Mdot
.47668 .47845 Mdot
.54668 .53512 Mdot
.50832 .51288 Mdot
.517 .49993 Mdot
.43762 .52532 Mdot
.48728 .48184 Mdot
.53634 .55127 Mdot
.47036 .48612 Mdot
.55121 .53976 Mdot
.58228 .4494 Mdot
.55761 .52035 Mdot
.48497 .42624 Mdot
.50798 .4861 Mdot
.50785 .50824 Mdot
.50529 .49515 Mdot
.54247 .45833 Mdot
.47219 .44106 Mdot
.54688 .51326 Mdot
.53163 .44313 Mdot
.45577 .44352 Mdot
.55369 .44023 Mdot
.52261 .54009 Mdot
.48536 .5083 Mdot
.52836 .55372 Mdot
.54282 .40745 Mdot
.52114 .48364 Mdot
.54907 .5774 Mdot
.5026 .46265 Mdot
.45856 .52165 Mdot
.41939 .52524 Mdot
.53806 .45303 Mdot
.47329 .51548 Mdot
.52159 .55325 Mdot
.50085 .38779 Mdot
.50195 .5387 Mdot
.50562 .55499 Mdot
.49712 .45634 Mdot
.53889 .47036 Mdot
.50391 .45426 Mdot
.53113 .51465 Mdot
.50367 .50791 Mdot
.42332 .5092 Mdot
.51666 .40742 Mdot
.50477 .40464 Mdot
.53289 .55713 Mdot
.45941 .35003 Mdot
.47009 .51186 Mdot
.49665 .54931 Mdot
.54001 .55092 Mdot
.51627 .48799 Mdot
.50939 .5059 Mdot
.46847 .49265 Mdot
.42434 .49691 Mdot
.48836 .48787 Mdot
.43643 .4785 Mdot
.50526 .48286 Mdot
.47883 .55551 Mdot
.50626 .4873 Mdot
.55662 .46473 Mdot
.52285 .53114 Mdot
.48828 .54693 Mdot
.45252 .51957 Mdot
.51676 .43466 Mdot
.45531 .46264 Mdot
.50332 .52372 Mdot
.50208 .48557 Mdot
.46999 .44567 Mdot
.50129 .34383 Mdot
.54258 .54938 Mdot
.43679 .50016 Mdot
.52481 .52364 Mdot
.47837 .53178 Mdot
.46292 .52105 Mdot
.4488 .52872 Mdot
.53132 .50591 Mdot
.47363 .47863 Mdot
.44291 .47247 Mdot
.54434 .52389 Mdot
.51147 .56546 Mdot
.53942 .52411 Mdot
.45713 .51079 Mdot
.44282 .52266 Mdot
.45848 .5114 Mdot
.45808 .52882 Mdot
.60701 .47564 Mdot
.47105 .54288 Mdot
.42502 .53161 Mdot
.50745 .5122 Mdot
.4222 .53822 Mdot
.5237 .48678 Mdot
.53722 .47662 Mdot
.55323 .50352 Mdot
.51415 .49709 Mdot
.5774 .51792 Mdot
.48259 .49168 Mdot
.52604 .52377 Mdot
.45866 .51544 Mdot
.56146 .48721 Mdot
.4095 .46561 Mdot
.5412 .55286 Mdot
.55434 .49866 Mdot
.50622 .50252 Mdot
.46592 .52261 Mdot
.55613 .53196 Mdot
.50527 .47765 Mdot
.50574 .56064 Mdot
.50381 .51348 Mdot
.49041 .547 Mdot
.56734 .53457 Mdot
.51823 .522 Mdot
.49948 .48482 Mdot
.44237 .52776 Mdot
.47143 .52649 Mdot
.46939 .44505 Mdot
.51611 .4353 Mdot
.35801 .59144 Mdot
.48379 .64069 Mdot
.42333 .50102 Mdot
.40648 .47485 Mdot
.51809 .56526 Mdot
.49449 .6524 Mdot
.55766 .44618 Mdot
.55176 .47913 Mdot
.50102 .50368 Mdot
.4909 .45474 Mdot
.51041 .46094 Mdot
.50362 .45818 Mdot
.50368 .52433 Mdot
.55279 .52909 Mdot
.4867 .437 Mdot
.45106 .48031 Mdot
.49145 .5494 Mdot
.5519 .43789 Mdot
.57026 .47111 Mdot
.55247 .48141 Mdot
.42949 .52534 Mdot
.51299 .50633 Mdot
.45611 .50511 Mdot
.46468 .57347 Mdot
.46498 .43461 Mdot
.51124 .50903 Mdot
.54378 .53166 Mdot
.49094 .45543 Mdot
.35183 .47252 Mdot
.44167 .4508 Mdot
.39502 .54861 Mdot
.53581 .47223 Mdot
.47879 .49499 Mdot
.46266 .44663 Mdot
.45442 .47744 Mdot
.52137 .441 Mdot
.54761 .42692 Mdot
.61203 .5631 Mdot
.50028 .53836 Mdot
.55085 .53445 Mdot
.45581 .50382 Mdot
.44638 .56891 Mdot
.50282 .46288 Mdot
.5281 .51412 Mdot
.45539 .50496 Mdot
.46753 .5709 Mdot
.5719 .52843 Mdot
.46289 .44672 Mdot
.52055 .44147 Mdot
.45377 .50776 Mdot
.47045 .44959 Mdot
.47896 .50914 Mdot
.47651 .49288 Mdot
.48125 .51586 Mdot
.52767 .55919 Mdot
.55539 .48602 Mdot
.41775 .52802 Mdot
.42601 .49663 Mdot
.55902 .52085 Mdot
.52024 .53329 Mdot
.47967 .52193 Mdot
.50445 .47721 Mdot
.50744 .5555 Mdot
.47768 .50063 Mdot
.54749 .57938 Mdot
.49704 .52146 Mdot
.45754 .50692 Mdot
.44248 .46727 Mdot
.49779 .47664 Mdot
.48573 .5582 Mdot
.52418 .53189 Mdot
.53813 .5809 Mdot
.42092 .52115 Mdot
.48488 .4165 Mdot
.51924 .48407 Mdot
.52071 .56273 Mdot
.52039 .47866 Mdot
.44441 .46657 Mdot
.46142 .51317 Mdot
.53751 .47426 Mdot
.50668 .51145 Mdot
.36582 .46715 Mdot
.51328 .4724 Mdot
.52474 .49875 Mdot
.50958 .5003 Mdot
.47405 .5357 Mdot
.55866 .50238 Mdot
.52768 .44139 Mdot
.55432 .48075 Mdot
.55708 .48965 Mdot
.5382 .4628 Mdot
.51059 .48901 Mdot
.53838 .54383 Mdot
.54362 .46399 Mdot
.41293 .592 Mdot
.48244 .44314 Mdot
.54811 .579 Mdot
.51409 .56371 Mdot
.5761 .51279 Mdot
.48399 .50676 Mdot
.46518 .52944 Mdot
.52164 .47471 Mdot
.48175 .49365 Mdot
.52627 .5184 Mdot
.53294 .56002 Mdot
.46201 .51325 Mdot
.53809 .42111 Mdot
.47303 .50646 Mdot
.55477 .44899 Mdot
.52161 .48132 Mdot
.34822 .50265 Mdot
.47449 .48707 Mdot
.49089 .53425 Mdot
.5615 .46712 Mdot
.5328 .47658 Mdot
.45967 .49908 Mdot
.46138 .50044 Mdot
.55281 .53485 Mdot
.47613 .49733 Mdot
.51262 .5258 Mdot
.51642 .50072 Mdot
.4852 .49585 Mdot
.53695 .47853 Mdot
.45127 .4992 Mdot
.5215 .56864 Mdot
.5167 .54286 Mdot
.44772 .54884 Mdot
.49863 .46664 Mdot
.55164 .5264 Mdot
.52706 .5104 Mdot
.45983 .45276 Mdot
.441 .55607 Mdot
.51457 .52702 Mdot
.45739 .50256 Mdot
.53626 .47452 Mdot
.57548 .48295 Mdot
.49723 .51582 Mdot
.48488 .50046 Mdot
.42422 .55048 Mdot
.4442 .49818 Mdot
.54198 .46625 Mdot
.58037 .48014 Mdot
.45076 .48479 Mdot
.51998 .49407 Mdot
.53087 .47937 Mdot
.53888 .46893 Mdot
.51633 .50271 Mdot
.43467 .57478 Mdot
.47807 .46189 Mdot
.5545 .43576 Mdot
.50241 .47416 Mdot
.50319 .51697 Mdot
.57683 .4317 Mdot
.52048 .5507 Mdot
.51641 .49775 Mdot
.50609 .49885 Mdot
.55001 .46277 Mdot
.48868 .46757 Mdot
.5044 .52638 Mdot
.53458 .48812 Mdot
.50514 .56169 Mdot
.49714 .56239 Mdot
.50157 .56142 Mdot
.46994 .43925 Mdot
.53703 .42047 Mdot
.49639 .48502 Mdot
.51177 .46858 Mdot
.58537 .51689 Mdot
.5242 .469 Mdot
.4853 .5279 Mdot
.58515 .45958 Mdot
.52294 .52434 Mdot
.53638 .48258 Mdot
.4294 .54614 Mdot
.44942 .56072 Mdot
.50833 .51395 Mdot
.5244 .42348 Mdot
.50494 .425 Mdot
.47002 .44902 Mdot
.50644 .51037 Mdot
.49714 .50774 Mdot
.45985 .49661 Mdot
.48951 .47866 Mdot
.4537 .5123 Mdot
.48518 .54924 Mdot
.49355 .48741 Mdot
.55473 .5381 Mdot
.48338 .49767 Mdot
.51929 .477 Mdot
.5104 .51563 Mdot
.54108 .55267 Mdot
.51643 .35805 Mdot
.42495 .44673 Mdot
.54588 .54568 Mdot
.55596 .51342 Mdot
.45579 .35499 Mdot
.44671 .51232 Mdot
.51321 .59863 Mdot
.49359 .4646 Mdot
.51728 .36965 Mdot
.49069 .38844 Mdot
.523 .50518 Mdot
.53519 .48333 Mdot
.49187 .429 Mdot
.46888 .53151 Mdot
.49594 .45382 Mdot
.41793 .53864 Mdot
.53018 .47485 Mdot
.51698 .53683 Mdot
.55329 .48316 Mdot
.47413 .4823 Mdot
.54866 .48218 Mdot
.49217 .45586 Mdot
.49676 .52433 Mdot
.49432 .46202 Mdot
.47325 .58636 Mdot
.45826 .52011 Mdot
.49331 .54064 Mdot
.50454 .53788 Mdot
.54483 .52328 Mdot
.55038 .4455 Mdot
.47475 .51352 Mdot
.50198 .55022 Mdot
.46696 .46631 Mdot
.33238 .50285 Mdot
.49354 .49639 Mdot
.52065 .53219 Mdot
.51543 .47391 Mdot
.54063 .47471 Mdot
.47653 .50208 Mdot
.51738 .55164 Mdot
.51711 .50171 Mdot
.56688 .47736 Mdot
.44984 .49696 Mdot
.48283 .51459 Mdot
.52362 .4925 Mdot
.55679 .50761 Mdot
.46581 .44829 Mdot
.41475 .52105 Mdot
.48482 .49874 Mdot
.55823 .47889 Mdot
.43167 .50156 Mdot
.49861 .54513 Mdot
.49459 .41194 Mdot
.43498 .49633 Mdot
.46764 .48036 Mdot
.45713 .53704 Mdot
.41975 .54424 Mdot
.51031 .4835 Mdot
.4269 .4951 Mdot
.47607 .53236 Mdot
.50726 .47817 Mdot
.44594 .48971 Mdot
.46666 .50028 Mdot
.54509 .55533 Mdot
.42629 .53919 Mdot
.54771 .57916 Mdot
.50286 .53514 Mdot
.42963 .51453 Mdot
.52445 .52671 Mdot
.46644 .50112 Mdot
.51434 .5208 Mdot
.53962 .52577 Mdot
.48074 .45273 Mdot
.48107 .51226 Mdot
.51978 .53489 Mdot
.43848 .4744 Mdot
.47635 .52643 Mdot
.50957 .52706 Mdot
.49238 .58768 Mdot
.47222 .51289 Mdot
.47705 .45495 Mdot
.51503 .51587 Mdot
.52856 .48281 Mdot
.51284 .50638 Mdot
.48878 .51491 Mdot
.48867 .50075 Mdot
.46603 .45984 Mdot
.52786 .56038 Mdot
.50507 .5039 Mdot
.45735 .51258 Mdot
.52616 .48731 Mdot
.52411 .45986 Mdot
.542 .57225 Mdot
.42441 .43861 Mdot
.52689 .44123 Mdot
.45982 .54218 Mdot
.46484 .45648 Mdot
.45942 .53631 Mdot
.45678 .52937 Mdot
.51235 .65811 Mdot
.50621 .53765 Mdot
.54768 .55485 Mdot
.50212 .47768 Mdot
.55362 .56284 Mdot
.51845 .48485 Mdot
.48931 .49465 Mdot
.54111 .54272 Mdot
.44056 .51958 Mdot
.45997 .54638 Mdot
.47009 .56847 Mdot
.50796 .48785 Mdot
.54787 .52352 Mdot
.53588 .44559 Mdot
.48192 .58861 Mdot
.47199 .44905 Mdot
.5004 .48232 Mdot
.46895 .52642 Mdot
.53268 .48101 Mdot
.456 .50381 Mdot
.46501 .55989 Mdot
.59903 .44634 Mdot
.51039 .35703 Mdot
.47403 .438 Mdot
.49336 .47536 Mdot
.53078 .50471 Mdot
.4223 .51976 Mdot
.5234 .53151 Mdot
.50768 .47066 Mdot
.42605 .54303 Mdot
.51257 .47922 Mdot
.55181 .49756 Mdot
.46267 .4931 Mdot
.55044 .51009 Mdot
.45444 .50896 Mdot
.34702 .47439 Mdot
.53871 .47114 Mdot
.551 .45513 Mdot
.52713 .50614 Mdot
.46 .50371 Mdot
.55095 .43327 Mdot
.54866 .62867 Mdot
.45474 .46901 Mdot
.53428 .48893 Mdot
.46139 .5068 Mdot
.49091 .45464 Mdot
.49316 .45202 Mdot
.44457 .56863 Mdot
.51858 .48384 Mdot
.48781 .41523 Mdot
.51439 .48209 Mdot
.47326 .46049 Mdot
.53845 .4645 Mdot
.45401 .51212 Mdot
.50839 .53556 Mdot
.46292 .50295 Mdot
.46435 .45895 Mdot
.4816 .55256 Mdot
.51534 .51959 Mdot
.50127 .47522 Mdot
.4624 .4497 Mdot
.44545 .46698 Mdot
.45974 .46159 Mdot
.42569 .5128 Mdot
.51638 .50164 Mdot
.48223 .47468 Mdot
.4649 .49024 Mdot
.47176 .51338 Mdot
.44172 .44441 Mdot
.44724 .52247 Mdot
.56367 .49497 Mdot
.49776 .52058 Mdot
.49063 .506 Mdot
.53487 .48377 Mdot
.53708 .54056 Mdot
.42205 .50166 Mdot
.50463 .47368 Mdot
.5448 .47958 Mdot
.44987 .48126 Mdot
.51131 .52809 Mdot
.51533 .54103 Mdot
.43404 .5515 Mdot
.50286 .42006 Mdot
.56165 .49482 Mdot
.51356 .59464 Mdot
.54188 .5423 Mdot
.5103 .52827 Mdot
.45968 .52255 Mdot
.48929 .4642 Mdot
.44392 .54922 Mdot
.58015 .53421 Mdot
.48446 .38154 Mdot
.43819 .60842 Mdot
.48295 .49125 Mdot
.51787 .52098 Mdot
.43934 .56395 Mdot
.50082 .48474 Mdot
.51743 .5007 Mdot
.55976 .49039 Mdot
.48258 .49124 Mdot
.50273 .50488 Mdot
.54754 .47932 Mdot
.4204 .54097 Mdot
.55595 .48527 Mdot
.49227 .47222 Mdot
.42981 .55795 Mdot
.50343 .46742 Mdot
.54308 .37918 Mdot
.42455 .54352 Mdot
.54554 .4792 Mdot
.5193 .55365 Mdot
.45104 .50209 Mdot
.46067 .47604 Mdot
.50766 .48669 Mdot
.53594 .47419 Mdot
.51699 .53065 Mdot
.4615 .51249 Mdot
.55263 .49583 Mdot
.45408 .44354 Mdot
.5429 .46003 Mdot
.44504 .51618 Mdot
.5126 .49293 Mdot
.59285 .52162 Mdot
.50105 .45871 Mdot
.45932 .51986 Mdot
.52744 .51413 Mdot
.54028 .42062 Mdot
.54495 .51077 Mdot
.5039 .53816 Mdot
.49901 .50732 Mdot
.5533 .44466 Mdot
.44397 .47097 Mdot
.51053 .51051 Mdot
.51087 .55879 Mdot
.52091 .49111 Mdot
.46241 .4932 Mdot
.49303 .47881 Mdot
.49569 .47487 Mdot
.43667 .51507 Mdot
.47725 .48746 Mdot
.47824 .4799 Mdot
.50383 .46902 Mdot
.40458 .48842 Mdot
.51123 .48427 Mdot
.54654 .42878 Mdot
.46374 .52658 Mdot
.53037 .47591 Mdot
.43942 .52539 Mdot
.55633 .52746 Mdot
.55562 .52862 Mdot
.48499 .48666 Mdot
.53424 .47452 Mdot
.49609 .45926 Mdot
.47104 .50614 Mdot
.55917 .47899 Mdot
.47628 .45909 Mdot
.4532 .52005 Mdot
.53576 .47149 Mdot
.51393 .52465 Mdot
.49103 .49672 Mdot
.57232 .55006 Mdot
.55873 .49878 Mdot
.44706 .43083 Mdot
.5089 .47842 Mdot
.53041 .47796 Mdot
.46828 .50464 Mdot
.49167 .56145 Mdot
.5138 .48716 Mdot
.48961 .47802 Mdot
.54169 .53559 Mdot
.43618 .52246 Mdot
.48444 .46883 Mdot
.49909 .4862 Mdot
.64538 .55066 Mdot
.50043 .51659 Mdot
.49568 .44466 Mdot
.48277 .41629 Mdot
.45977 .45146 Mdot
.52772 .57554 Mdot
.48754 .44947 Mdot
.50359 .5555 Mdot
.50998 .48003 Mdot
.49741 .52633 Mdot
.44737 .49441 Mdot
.44869 .53422 Mdot
.47811 .55288 Mdot
.45799 .52379 Mdot
.54034 .5783 Mdot
.42174 .51661 Mdot
.4932 .48191 Mdot
.47915 .56294 Mdot
.47771 .47996 Mdot
.51317 .47537 Mdot
.42558 .5506 Mdot
.5578 .46158 Mdot
.52518 .52594 Mdot
.48933 .44522 Mdot
.44175 .60776 Mdot
.55454 .52638 Mdot
.50517 .48736 Mdot
.51662 .53158 Mdot
.49269 .50761 Mdot
.51415 .51862 Mdot
.45412 .52354 Mdot
.55259 .46142 Mdot
.48218 .48327 Mdot
.52504 .52516 Mdot
.54394 .47121 Mdot
.54555 .54607 Mdot
.44228 .5013 Mdot
.53059 .54546 Mdot
.55737 .51909 Mdot
.48839 .42456 Mdot
.52957 .51194 Mdot
.33435 .51609 Mdot
.50348 .48703 Mdot
.47154 .51043 Mdot
.43919 .55942 Mdot
.58846 .5123 Mdot
.50986 .50458 Mdot
.50972 .4616 Mdot
.51243 .47054 Mdot
.45042 .53164 Mdot
.54846 .51715 Mdot
.44875 .48371 Mdot
.5004 .4725 Mdot
.52789 .52527 Mdot
.52979 .44609 Mdot
.45334 .47256 Mdot
.53009 .48017 Mdot
.43834 .50985 Mdot
.48628 .43837 Mdot
.53005 .44448 Mdot
.4985 .52508 Mdot
.53376 .42465 Mdot
.55575 .43909 Mdot
.43576 .5302 Mdot
.52829 .56166 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0Woooool2o`000:Kooooo000Nooooo`03o`000?oooooooooo09oooooo
0_l0002Vooooo`007_ooool2o`0009;ooooo0_l0002dooooo`007_ooool00ol0003oooooooooo`2@
ooooo`?o0000]?ooool001kooooo00?o0000ooooooooool0T?ooool2o`00013ooooo1?l0002Qoooo
o`007_ooool00ol0003oooooooooo`2Rooooo`Co0000XOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo09?ooooo0_l0000?ooooo`;o0000XOooool001kooooo00?o0000ooooooooool0Toooool2o`00
00oooooo0_l0002Qooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0:cooooo0_l0002Iooooo`007_ooool00ol0003oooooooooo`2Iooooo`;o00003?oo
ool2o`0000?ooooo0_l0002Iooooo`007_ooool00ol0003oooooooooo`2Iooooo`;o00003?ooool2
o`0009kooooo000Nooooo`03o`000?oooooooooo09_ooooo0_l00002ooooo`;o0000Y_ooool001ko
oooo00?o0000ooooooooool0Voooool2o`0000;ooooo0_l0002Vooooo`000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol0003oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo
0?ooooooB?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0000Oooooo00?o0000ooooooooool0X?ooool2o`0000;ooooo0_l0002Qooooo`000oooool01Ol@
413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`2P
ooooo`;o00000_ooool2o`0000Kooooo0_l0002Iooooo`000oooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2Looooo`?o00003Oooool2
o`0009Wooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06
ooooo`03o`000?oooooooooo09Wooooo1_l0002Xooooo`007_ooool00ol0003oooooooooo`2Ioooo
o`?o00001Oooool2o`0000;ooooo1?l00007ooooo`Co0000Toooool001kooooo00?o0000oooooooo
ool0S?ooool2o`00013ooooo1Ol00002ooooo`Co000000?oooooo`000?l000000_l00002ooooo`Co
0000Toooool001kooooo00?o0000ooooooooool0S?ooool2o`0000[ooooo0_l000001?oooooo0000
o`000?ooool4o`0000Cooooo0_l000000ooooooo0000o`000003o`0000Gooooo0_l0002Booooo`00
7_ooool00ol0003oooooooooo`2Hooooo`Go00000oooool2o`0000Cooooo0_l000000ooooooo0000
o`000003ooooo`;o00000oooool2o`0009;ooooo000Nooooo`03o`000?oooooooooo08gooooo0_l0
000;ooooo`Co000000?oooooo`000?l000000_ooool2o`0000Gooooo0_l00002ooooo`;o00001ooo
ool2o`0008kooooo000Nooooo`03o`000?oooooooooo08gooooo0_l00004ooooo`;o00000oooool2
o`0000;ooooo1Ol00002ooooo`?o00001?ooool2o`0000?ooooo0_l00006ooooo`;o0000S_ooool0
01kooooo00?o0000ooooooooool0Toooool2o`000003ooooool0003o000000Go000000Coooooo`00
0?l0003o00000oooool2o`0000Wooooo0ol0002Eooooo`007_ooool00ol0003oooooooooo`26oooo
o`?o00002_ooool5o`0000;ooooo0ol000001?oooooo0000o`000?l00003ooooo`Go00001_ooool4
o`0009Cooooo000Nooooo`03o`000?oooooooooo08Kooooo0ol00005ooooo`Wo000000?oooooo`00
0?l000000_l000001?oooooo0000o`000?l00005ooooo`Ko00001Oooool3o`0009Cooooo000Noooo
o`03o`000?oooooooooo08Kooooo0_l00003ooooo`;o000000?oooooo`000?l000003ol00006oooo
o`Oo00000oooool4o`0000cooooo0_l00026ooooo`007_ooool00ol0003oooooooooo`26ooooo`;o
00000oooool2o`0000Cooooo1ol000000ooooooo0000o`000004o`0000?ooooo0_l00004ooooo`Ko
000000?oooooo`000?l000000_l00006ooooo`;o00001?ooool2o`0008Kooooo000Nooooo`;o0000
S?ooool3o`0000?ooooo4?l000000ooooooo0000o`000005ooooo`Go00000_ooool3o`0000Kooooo
0_l0002<ooooo`007_ooool00ol0003oooooooooo`25ooooo`;o00001?ooool3o`0000?ooooo1?l0
0002ooooo`?o000000?oooooo`000?l000001Ol00006ooooo`;o000000?oooooo`000?l000001_l0
002Dooooo`007_ooool00ol0003oooooooooo`25ooooo`;o00003?ooool2o`0000;ooooo0_l00002
ooooo`So00001?ooool3o`0000;ooooo1ol00007ooooo`;o0000Roooool001kooooo00?o0000oooo
ooooool0T?ooool5o`000004ooooool0003o0000o`0000;ooooo2Ol00002ooooo`?o00000_ooool3
o`000003ooooool0003o000000;o00001oooool2o`0008_ooooo000Nooooo`03o`000?oooooooooo
087ooooo0_l0000;ooooo`Oo000000Coooooo`000?l0003o00000_ooool9o`0000;ooooo0_l00003
ooooo`So0000U?ooool001kooooo00?o0000ooooooooool0Loooool2o`0000cooooo0_l00009oooo
o`Co00001?ooool2o`0000?ooooo4?l00002ooooo`Wo0000Toooool001kooooo00?o0000oooooooo
ool0Loooool2o`0001Oooooo0ol000000ooooooo0000o`000002ooooo`;o00000_oooolAo`000003
ooooool0003o000000?o00000oooool2o`000003ooooool0003o0000093ooooo000Nooooo`03o`00
0?oooooooooo06gooooo0ol0000:ooooo`;o00001?ooool4o`0000Kooooo1?l000001?oooooo0000
o`000?l00006oooooa_o00000_ooool2o`00093ooooo000Nooooo`03o`000?oooooooooo06gooooo
0ol0000:ooooo`;o00001?ooool4o`0000Gooooo1Ol000000ooooooo0000o`000005o`0000?ooooo
3_l000000ooooooo0000o`000004o`000003ooooool0003o000000;o000000?oooooo`000?l00000
2oooool2o`0008Cooooo000Nooooo`03o`000?oooooooooo083ooooo0_l00007ooooo`?o00000_oo
ool;o`0000;ooooo3?l000000ooooooo0000o`00000<o`0000?ooooo0_l00006ooooo`;o0000Q?oo
ool001kooooo00?o0000ooooooooool0P?ooool2o`0000Sooooo0_l00002ooooo`Co000000?ooooo
o`000?l000002Ol000000ooooooo0000o`000006o`000003ooooool0003o000000;o000000?ooooo
o`000?l000001Ol00003ooooo`Co0000S?ooool001kooooo00?o0000ooooooooool0S_ooool4o`00
0003ooooool0003o000001Oo00000_ooool6o`0000?ooooo0_l0002>ooooo`007_ooool00ol0003o
ooooooooo`1oooooo`;o00003?ooool3o`0000?ooooo6Ol00003ooooo`Go0000Toooool001kooooo
00?o0000ooooooooool0Ooooool4o`0000[ooooo0_l00003ooooo`Co000000?oooooo`000?l00000
1?l00002ooooo`[o000000?oooooo`000?l000000oooool5o`0009?ooooo000Nooooo`03o`000?oo
oooooooo087ooooo0_l00002ooooo`Ko00000_ooool2o`0000;ooooo4Ol000000ooooooo0000o`00
0004o`0000Kooooo1_l00005ooooo`;o0000Roooool001kooooo00?o0000ooooooooool0QOooool6
o`000003ooooool0003o000000Go000000?oooooo`000?l000002Ol000001?oooooo0000o`000?oo
ool6o`0000Kooooo1_l00005ooooo`;o0000Roooool001kooooo0_l0001^ooooo`;o00005_oooolS
o`000003ooooool0003o000000Cooooo1Ol0002Cooooo`007_ooool00ol0003oooooooooo`1Xoooo
o`;o00000oooool2o`0001Kooooo2Ol000000ooooooo0000o`00000Jo`0000Gooooo1?l0002Coooo
o`007_ooool00ol0003oooooooooo`1Xooooo`;o00007?ooool2o`0000Kooooo5ol000000ooooooo
0000o`000003o`0000Gooooo0ol00004ooooo`;o0000S_ooool001kooooo00?o0000ooooooooool0
Q_ooool2o`0000;ooooo0_l00002ooooo`Ko000000?oooooo`000?l000003_l00002ooooo`Co0000
0_ooool6o`0000Cooooo0_l000000ooooooo0000o`00002;ooooo`007_ooool00ol0003ooooooooo
o`1Yooooo`;o00006ooooolNo`0000?ooooo1?l00002ooooo`Ko00001?ooool6o`0008[ooooo000N
ooooo`03o`000?oooooooooo06Wooooo0_l0000Jooooob3o00000_ooool4o`0000;ooooo1_l00004
ooooo`Ko0000R_ooool001kooooo00?o0000ooooooooool0JOooool2o`0001Sooooo1_l00002oooo
o`Wo00000_ooool@o`000003ooooool0003o000000Gooooo0_l000001?oooooo0000o`000?l00004
ooooo`Co0000Roooool001kooooo00?o0000ooooooooool0Poooool4o`0000?ooooo3Ol000001Ooo
oooo0000o`000?l0003ooooo00Ko000000?oooooo`000?l000001Ol000000ooooooo0000o`000003
o`000004ooooool0003o0000o`0000Kooooo0_l000000ooooooo0000o`000028ooooo`007_ooool0
0ol0003oooooooooo`24ooooo`?o000000?oooooo`000?l000004Ol00002oooooaOo00002Oooool2
o`0008Sooooo000Nooooo`03o`000?oooooooooo08Cooooo0ol000000ooooooo0000o`00000Bo`00
0003ooooool0003o000000Ko000000?oooooo`000?l000001Ol00002ooooo`Co00000oooool2o`00
08oooooo000Nooooo`03o`000?oooooooooo08Cooooo1?l00002oooooa;o00001_ooool6o`0000Go
oooo0_l000001?oooooo0000o`000?l00003ooooo`;o0000Soooool001kooooo00?o0000oooooooo
ool0Q?ooool4o`0000Kooooo0_l000001?oooooo0000o`000?ooool5o`0000;ooooo3Ol00004oooo
o`Oo000000?oooooo`000?l000000_ooool2o`0008gooooo000Nooooo`03o`000?oooooooooo08Co
oooo1?l00006ooooo`;o000000Coooooo`000?l0003ooooo1?l00003ooooo`So000000Coooooo`00
0?l0003o00000_ooool2o`000003ooooool0003o000000Co00000_ooool2o`0000;ooooo0_l0002=
ooooo`007_ooool00ol0003oooooooooo`24ooooo`Go00002?ooool2o`0000Wooooo0_l000001Ooo
oooo0000o`000?l0003ooooo00Go000000?oooooo`000?l000001ol0002Eooooo`007_ooool00ol0
003oooooooooo`24ooooo`Go00001oooool3o`0000;ooooo1Ol000000ooooooo0000o`000004o`00
00;ooooo3_l00002ooooo`;o0000T_ooool001kooooo00?o0000ooooooooool0O?ooool2o`0000Ko
oooo1Ol000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000So000000Coooooo`00
0?l0003ooooo1?l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000;o00001?ooool2
o`0009;ooooo000Nooooo`;o0000OOooool2o`0000Sooooo3ol00005ooooo`So00000_ooool5o`00
0003ooooool0003o000000?o00001Oooool4o`0001Kooooo0_l0001gooooo`007_ooool00ol0003o
ooooooooo`26ooooo`;o000000Coooooo`000?l0003ooooo0_l000001?oooooo0000o`000?ooool2
o`0000?ooooo2ol00002ooooo`co00001?ooool4o`0001Cooooo1?l0001gooooo`007_ooool00ol0
003oooooooooo`28ooooo`;o000000?oooooo`000?l000000_l00008ooooo`?o000000?oooooo`00
0?l000002_l000000ooooooo0000o`000006o`0001Oooooo0_l00003ooooo`;o0000NOooool001ko
oooo00?o0000ooooooooool0R?ooool2o`000003ooooool0003o000000?o00000oooool2o`0000;o
oooo1_l000000ooooooo0000o`000005o`0000;ooooo2?l00006ooooo`;o00004?ooool2o`0007ko
oooo000Nooooo`03o`000?oooooooooo08Wooooo1?l000000ooooooo0000o`000002o`000003oooo
ool0003o000000?ooooo5Ol00003ooooo`;o00000oooool2o`0000Gooooo0_l00005ooooo`;o0000
P_ooool001kooooo00?o0000ooooooooool0ROooool6o`000003ooooool0003o000000Kooooo0_l0
0002ooooo`_o000000?oooooo`000?l000001_ooool2o`0000[ooooo1?l00003ooooo`;o0000P_oo
ool001kooooo00?o0000ooooooooool0S?ooool3o`0000?ooooo0_l000000ooooooo0000o`00000;
ooooo`Go00005oooool2o`0008Oooooo000Nooooo`03o`000?oooooooooo08cooooo0ol00003oooo
o`Go00002?ooool2o`000004ooooool0003o0000ooooo`;o00000oooool4o`0009Wooooo000Noooo
o`03o`000?oooooooooo08Wooooo0_l00008ooooo`Co00002?ooool4o`0000Cooooo0_l000000ooo
oooo0000o`000002o`0009Wooooo000Nooooo`03o`000?oooooooooo08Wooooo0_l0000Fooooo`;o
00001?ooool2o`0000?ooooo1?l0002Gooooo`007_ooool00ol0003oooooooooo`2[ooooo`Go0000
Uoooool001kooooo00?o0000ooooooooool0Zoooool2o`0009[ooooo000Nooooo`03o`000?oooooo
oooo08[ooooo0_l0000:ooooo`Go000000?oooooo`000?l00000ZOooool001kooooo00?o0000oooo
ooooool0L?ooool2o`0001Sooooo0_l0000:ooooo`Go000000?oooooo`000?l00000ZOooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413o
c<c<00Kooooo00?o0000ooooooooool0L?ooool2o`00013ooooo0_l0000Dooooo`;o00002Oooool2
o`000:;ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEE
ogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo08;ooooo0_l0000Oooooo`;o0000X_oo
ool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000
1_ooool3o`000:?ooooo0_l0002Rooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo
00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0:?ooooo0_l0002Rooooo`00
0oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c006oooo
o`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400;oooo
o`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0R_ooool4o`000;Wooooo0003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo
08[ooooo1?l0002iooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4
A?l0003o410@1_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0:kooooo0_l0002Gooooo`007_ooool0
0ol0003oooooooooo`2^ooooo`;o0000Uoooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo09Wooooo
0_l0002/ooooo`007_ooool00ol0003oooooooooo`2Iooooo`;o0000[?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o
0000W_ooool2o`000:Sooooo000Nooooo`03o`000?oooooooooo09gooooo0_l0002Xooooo`007_oo
ool00ol0003oooooooooo`2Rooooo`;o0000Xoooool001kooooo00?o0000ooooooooool0X_ooool2
o`000:?ooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06
ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400;
ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool000?ooooo00Go0000
ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool00ol0003ooooo
ooooo`3oooooodSooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol@413ooooo
oooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo
0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooo
okZj^_l000001_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?oooooo
BOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`005?ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom8ooooo`00
5_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB?ooool001Kooooo00?o
0000ooooooooool01Oooool3o`000?ooooooB?ooool001Kooooo00?o0000ooooooooool0oooooom@
ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?oo
ooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005?ooool00omEEEGoIVIVo`00
003ooooooe;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.46452 .45128 Mdot
.5216 .46939 Mdot
.54286 .51062 Mdot
.53024 .48483 Mdot
.52746 .50516 Mdot
.44792 .53251 Mdot
.50162 .44085 Mdot
.5323 .47192 Mdot
.40371 .46395 Mdot
.5304 .43663 Mdot
.49113 .42736 Mdot
.48169 .49371 Mdot
.45673 .57329 Mdot
.53876 .56478 Mdot
.4361 .52066 Mdot
.526 .52263 Mdot
.51298 .45308 Mdot
.41359 .53843 Mdot
.45959 .45105 Mdot
.48828 .54473 Mdot
.51219 .45122 Mdot
.50742 .54286 Mdot
.54615 .47855 Mdot
.48426 .5508 Mdot
.51374 .45024 Mdot
.47843 .49865 Mdot
.5166 .41583 Mdot
.42497 .49034 Mdot
.51857 .50345 Mdot
.44831 .51604 Mdot
.44614 .53058 Mdot
.51786 .46356 Mdot
.49896 .50516 Mdot
.54358 .53659 Mdot
.45424 .55028 Mdot
.52594 .56271 Mdot
.4835 .49972 Mdot
.55726 .51435 Mdot
.53475 .49208 Mdot
.4646 .50149 Mdot
.52071 .52998 Mdot
.50173 .54229 Mdot
.45434 .49033 Mdot
.49608 .49013 Mdot
.51449 .45878 Mdot
.49068 .51863 Mdot
.57993 .53809 Mdot
.45222 .54647 Mdot
.48643 .55952 Mdot
.6023 .57014 Mdot
.52357 .5051 Mdot
.53119 .53464 Mdot
.51849 .49989 Mdot
.53943 .49235 Mdot
.54128 .50619 Mdot
.466 .50696 Mdot
.46163 .49357 Mdot
.53824 .4137 Mdot
.52532 .47785 Mdot
.4523 .49754 Mdot
.49165 .52501 Mdot
.48603 .50958 Mdot
.5332 .55935 Mdot
.52623 .52175 Mdot
.51027 .51393 Mdot
.44186 .51477 Mdot
.45136 .49293 Mdot
.47719 .51151 Mdot
.45528 .52262 Mdot
.52631 .52409 Mdot
.50065 .41626 Mdot
.53395 .49524 Mdot
.44764 .50538 Mdot
.51454 .488 Mdot
.4596 .53753 Mdot
.54618 .42035 Mdot
.46697 .52282 Mdot
.42108 .53351 Mdot
.53387 .40808 Mdot
.43602 .46962 Mdot
.54755 .5355 Mdot
.52909 .46894 Mdot
.51624 .45109 Mdot
.51151 .52908 Mdot
.53726 .55082 Mdot
.51609 .4927 Mdot
.56406 .48649 Mdot
.47592 .50774 Mdot
.46013 .50226 Mdot
.52323 .56258 Mdot
.51097 .50621 Mdot
.5031 .53209 Mdot
.55894 .48823 Mdot
.55663 .56694 Mdot
.56367 .43476 Mdot
.49553 .54168 Mdot
.47119 .50702 Mdot
.43885 .52534 Mdot
.58744 .52332 Mdot
.47952 .48325 Mdot
.56673 .47775 Mdot
.55756 .50205 Mdot
.5356 .48953 Mdot
.45111 .53783 Mdot
.41402 .44543 Mdot
.49939 .50583 Mdot
.32675 .49595 Mdot
.51168 .51216 Mdot
.47154 .47888 Mdot
.50514 .53429 Mdot
.43691 .48749 Mdot
.53382 .49384 Mdot
.51297 .47656 Mdot
.49554 .44334 Mdot
.45436 .49447 Mdot
.47968 .59002 Mdot
.52737 .46155 Mdot
.42456 .49267 Mdot
.52046 .54708 Mdot
.55821 .48527 Mdot
.41183 .51717 Mdot
.48297 .49708 Mdot
.53983 .43899 Mdot
.46462 .54546 Mdot
.51495 .45829 Mdot
.5461 .46078 Mdot
.44646 .50469 Mdot
.48176 .49759 Mdot
.49085 .49399 Mdot
.53589 .51261 Mdot
.41708 .50241 Mdot
.50453 .45942 Mdot
.55419 .49841 Mdot
.51241 .56876 Mdot
.55294 .48865 Mdot
.5584 .50058 Mdot
.49513 .45232 Mdot
.50384 .49523 Mdot
.45076 .5152 Mdot
.50462 .48187 Mdot
.51157 .50995 Mdot
.44465 .42628 Mdot
.49228 .49649 Mdot
.52904 .49299 Mdot
.50108 .51405 Mdot
.50549 .53505 Mdot
.46387 .45554 Mdot
.49338 .54633 Mdot
.44722 .49897 Mdot
.47246 .54601 Mdot
.52169 .56407 Mdot
.4173 .49739 Mdot
.51753 .50914 Mdot
.46824 .54232 Mdot
.43098 .48665 Mdot
.52627 .52262 Mdot
.4919 .51147 Mdot
.51658 .5943 Mdot
.46599 .52315 Mdot
.50158 .51218 Mdot
.4431 .47779 Mdot
.46979 .53182 Mdot
.42359 .52935 Mdot
.54386 .50724 Mdot
.46148 .49608 Mdot
.49611 .47943 Mdot
.42741 .42897 Mdot
.5476 .53503 Mdot
.50895 .53811 Mdot
.56447 .49723 Mdot
.43169 .48662 Mdot
.45593 .52708 Mdot
.51525 .46701 Mdot
.45642 .49906 Mdot
.43194 .54656 Mdot
.47538 .50364 Mdot
.50207 .55054 Mdot
.50295 .51477 Mdot
.58629 .54168 Mdot
.48528 .5535 Mdot
.52877 .48849 Mdot
.50149 .54265 Mdot
.50908 .48962 Mdot
.51977 .50038 Mdot
.45855 .58324 Mdot
.48921 .48928 Mdot
.55644 .4976 Mdot
.49283 .52668 Mdot
.49291 .54863 Mdot
.56357 .46912 Mdot
.49834 .48627 Mdot
.52375 .51584 Mdot
.47003 .53232 Mdot
.51531 .51035 Mdot
.56033 .50798 Mdot
.51961 .52871 Mdot
.62379 .56884 Mdot
.49491 .49637 Mdot
.50683 .51464 Mdot
.52711 .48025 Mdot
.49464 .47741 Mdot
.47724 .51329 Mdot
.41238 .51359 Mdot
.53232 .53747 Mdot
.54544 .49612 Mdot
.50986 .46815 Mdot
.50567 .45789 Mdot
.46686 .48794 Mdot
.54916 .52362 Mdot
.51776 .51012 Mdot
.51331 .45602 Mdot
.48645 .49819 Mdot
.45295 .51122 Mdot
.42296 .51568 Mdot
.48271 .49708 Mdot
.5792 .544 Mdot
.49759 .52738 Mdot
.46219 .52145 Mdot
.44945 .42824 Mdot
.50729 .51183 Mdot
.52596 .50521 Mdot
.54383 .47734 Mdot
.50313 .53336 Mdot
.55013 .58051 Mdot
.52116 .47171 Mdot
.53999 .48078 Mdot
.52419 .47481 Mdot
.53214 .43474 Mdot
.54916 .51413 Mdot
.46985 .43567 Mdot
.53786 .4987 Mdot
.48723 .49743 Mdot
.49396 .44313 Mdot
.49264 .50711 Mdot
.47266 .50097 Mdot
.45061 .51591 Mdot
.53952 .46425 Mdot
.55171 .42407 Mdot
.50436 .46315 Mdot
.48896 .48941 Mdot
.52925 .43493 Mdot
.43488 .49882 Mdot
.44616 .47615 Mdot
.55732 .47205 Mdot
.57624 .43698 Mdot
.53642 .51379 Mdot
.52828 .41454 Mdot
.54174 .48209 Mdot
.54588 .48092 Mdot
.50841 .43621 Mdot
.45638 .48957 Mdot
.45686 .58503 Mdot
.46799 .41435 Mdot
.56922 .43572 Mdot
.51345 .47924 Mdot
.48481 .48832 Mdot
.5569 .4759 Mdot
.45799 .51271 Mdot
.54151 .54307 Mdot
.46347 .41091 Mdot
.5489 .53748 Mdot
.52334 .52151 Mdot
.50126 .51204 Mdot
.42081 .50598 Mdot
.4986 .55144 Mdot
.52931 .55914 Mdot
.50809 .4477 Mdot
.41375 .51978 Mdot
.51481 .52703 Mdot
.5809 .54033 Mdot
.46179 .48401 Mdot
.51241 .47644 Mdot
.4867 .54384 Mdot
.50748 .47937 Mdot
.54987 .50152 Mdot
.51059 .41341 Mdot
.46585 .51264 Mdot
.47968 .44087 Mdot
.47429 .53596 Mdot
.51072 .43263 Mdot
.45233 .51674 Mdot
.46882 .50138 Mdot
.50378 .55668 Mdot
.49758 .50171 Mdot
.5538 .48941 Mdot
.56486 .57018 Mdot
.5846 .5406 Mdot
.54877 .47955 Mdot
.50903 .46179 Mdot
.456 .53583 Mdot
.47189 .49352 Mdot
.43039 .51043 Mdot
.47138 .58531 Mdot
.44336 .50017 Mdot
.49688 .47896 Mdot
.54072 .49282 Mdot
.41397 .50516 Mdot
.4873 .55203 Mdot
.52215 .54839 Mdot
.5309 .48528 Mdot
.49754 .49223 Mdot
.54015 .48133 Mdot
.40957 .46775 Mdot
.51996 .53664 Mdot
.47828 .49316 Mdot
.5309 .48679 Mdot
.49109 .37836 Mdot
.43431 .49503 Mdot
.50871 .44824 Mdot
.4877 .54565 Mdot
.52385 .48653 Mdot
.49765 .50234 Mdot
.52676 .44707 Mdot
.48346 .44148 Mdot
.52443 .47711 Mdot
.44482 .50572 Mdot
.46408 .50222 Mdot
.47609 .51004 Mdot
.44815 .50643 Mdot
.55776 .51535 Mdot
.47744 .54832 Mdot
.48919 .42804 Mdot
.49256 .43258 Mdot
.47163 .50423 Mdot
.43867 .47603 Mdot
.55453 .50719 Mdot
.49689 .48812 Mdot
.48969 .49421 Mdot
.41584 .45489 Mdot
.54913 .52452 Mdot
.4557 .46684 Mdot
.49449 .5884 Mdot
.51156 .47575 Mdot
.52166 .43312 Mdot
.54524 .53196 Mdot
.55188 .46541 Mdot
.51553 .5665 Mdot
.53277 .49113 Mdot
.48629 .43998 Mdot
.48258 .50833 Mdot
.44549 .49822 Mdot
.44844 .49964 Mdot
.41695 .45711 Mdot
.49424 .49779 Mdot
.52655 .53022 Mdot
.47254 .4826 Mdot
.49777 .50029 Mdot
.53991 .48608 Mdot
.55019 .53662 Mdot
.51167 .52953 Mdot
.4673 .49198 Mdot
.5514 .50305 Mdot
.51256 .45212 Mdot
.48771 .50353 Mdot
.43371 .56141 Mdot
.48442 .48459 Mdot
.54211 .55916 Mdot
.49943 .46492 Mdot
.50817 .5619 Mdot
.50079 .50795 Mdot
.50934 .51336 Mdot
.43927 .50839 Mdot
.50309 .47714 Mdot
.49921 .5503 Mdot
.49054 .46952 Mdot
.51639 .55506 Mdot
.58553 .47002 Mdot
.54415 .53378 Mdot
.52551 .44864 Mdot
.51461 .49333 Mdot
.502 .51239 Mdot
.50515 .49919 Mdot
.54667 .50847 Mdot
.49988 .44453 Mdot
.5239 .54464 Mdot
.55145 .46191 Mdot
.4832 .43704 Mdot
.56875 .46283 Mdot
.49243 .54259 Mdot
.48259 .49847 Mdot
.50014 .55521 Mdot
.56066 .41471 Mdot
.52943 .49728 Mdot
.52697 .59058 Mdot
.52383 .47536 Mdot
.46462 .48435 Mdot
.42196 .49299 Mdot
.55393 .47174 Mdot
.46539 .50453 Mdot
.49274 .55193 Mdot
.52511 .41326 Mdot
.47391 .53585 Mdot
.4774 .54808 Mdot
.51775 .46373 Mdot
.53826 .48443 Mdot
.52616 .46764 Mdot
.52704 .53296 Mdot
.49827 .50528 Mdot
.43586 .47892 Mdot
.54106 .43968 Mdot
.53366 .43266 Mdot
.5064 .5634 Mdot
.47958 .35493 Mdot
.46875 .50121 Mdot
.46893 .53844 Mdot
.51729 .56828 Mdot
.52202 .49926 Mdot
.50446 .51193 Mdot
.48298 .48083 Mdot
.44049 .47013 Mdot
.49949 .48369 Mdot
.46138 .45233 Mdot
.51369 .48941 Mdot
.45396 .54634 Mdot
.51186 .49304 Mdot
.56048 .49311 Mdot
.51042 .53732 Mdot
.4592 .52482 Mdot
.44278 .50096 Mdot
.54229 .44595 Mdot
.48641 .44268 Mdot
.48733 .51707 Mdot
.50875 .48854 Mdot
.50145 .43185 Mdot
.51779 .35608 Mdot
.52088 .56616 Mdot
.43341 .4576 Mdot
.51717 .5287 Mdot
.45548 .52089 Mdot
.45504 .50937 Mdot
.42925 .51309 Mdot
.5256 .52541 Mdot
.4997 .46433 Mdot
.47168 .45052 Mdot
.51933 .53557 Mdot
.48276 .54941 Mdot
.51367 .53701 Mdot
.4588 .49502 Mdot
.42838 .50596 Mdot
.45758 .49767 Mdot
.44414 .50677 Mdot
.58756 .50647 Mdot
.44339 .52853 Mdot
.42481 .50328 Mdot
.50001 .50686 Mdot
.4145 .50806 Mdot
.53012 .50095 Mdot
.54194 .50301 Mdot
.54258 .53627 Mdot
.51364 .50572 Mdot
.55567 .54111 Mdot
.49459 .4856 Mdot
.51762 .53181 Mdot
.45551 .50193 Mdot
.55784 .51686 Mdot
.42137 .44385 Mdot
.51788 .56541 Mdot
.55832 .51966 Mdot
.50263 .50651 Mdot
.45615 .51112 Mdot
.5355 .54308 Mdot
.5173 .48508 Mdot
.47517 .56645 Mdot
.49416 .50683 Mdot
.46431 .53237 Mdot
.5598 .56546 Mdot
.5073 .51937 Mdot
.50749 .48595 Mdot
.43214 .50836 Mdot
.45716 .51613 Mdot
.48368 .43387 Mdot
.54144 .44488 Mdot
.35544 .5742 Mdot
.46646 .6224 Mdot
.43947 .4715 Mdot
.41016 .45021 Mdot
.49083 .57245 Mdot
.47696 .63914 Mdot
.5681 .4718 Mdot
.55509 .52524 Mdot
.49719 .50128 Mdot
.51245 .45246 Mdot
.53526 .47518 Mdot
.524 .47296 Mdot
.487 .51766 Mdot
.52922 .53924 Mdot
.51743 .43205 Mdot
.45991 .45543 Mdot
.46546 .53475 Mdot
.56815 .45941 Mdot
.5477 .51206 Mdot
.54912 .51773 Mdot
.40781 .49458 Mdot
.50518 .51645 Mdot
.46099 .48907 Mdot
.43791 .56859 Mdot
.49779 .43969 Mdot
.50288 .51708 Mdot
.517 .53943 Mdot
.52016 .46528 Mdot
.36603 .4561 Mdot
.45693 .42035 Mdot
.41401 .51759 Mdot
.54181 .4964 Mdot
.49064 .48783 Mdot
.49212 .42944 Mdot
.47249 .45959 Mdot
.54479 .45809 Mdot
.56331 .44796 Mdot
.5852 .57253 Mdot
.47252 .53507 Mdot
.53286 .55866 Mdot
.46121 .48666 Mdot
.43355 .54884 Mdot
.53259 .47562 Mdot
.52083 .53096 Mdot
.45984 .48779 Mdot
.45271 .54647 Mdot
.54562 .54893 Mdot
.48455 .44276 Mdot
.54242 .463 Mdot
.46048 .48554 Mdot
.49755 .44995 Mdot
.47722 .49913 Mdot
.48993 .48405 Mdot
.46978 .50689 Mdot
.50043 .56469 Mdot
.53464 .53039 Mdot
.4163 .49806 Mdot
.44515 .46719 Mdot
.54607 .54486 Mdot
.50584 .53529 Mdot
.46462 .51125 Mdot
.51686 .48401 Mdot
.46535 .53547 Mdot
.48592 .49299 Mdot
.52885 .59357 Mdot
.48055 .51368 Mdot
.46171 .49145 Mdot
.47 .44288 Mdot
.51214 .47837 Mdot
.44926 .54542 Mdot
.51168 .53796 Mdot
.51394 .58181 Mdot
.41901 .49093 Mdot
.51032 .40764 Mdot
.52738 .49717 Mdot
.47879 .56331 Mdot
.53461 .4952 Mdot
.47394 .44762 Mdot
.46247 .50096 Mdot
.54662 .48651 Mdot
.49978 .50979 Mdot
.38779 .45478 Mdot
.53154 .48723 Mdot
.51643 .51584 Mdot
.50671 .50613 Mdot
.45139 .51994 Mdot
.52733 .53971 Mdot
.54811 .46836 Mdot
.55289 .51115 Mdot
.55157 .52277 Mdot
.54898 .48749 Mdot
.51529 .49686 Mdot
.51019 .55084 Mdot
.55754 .47565 Mdot
.41896 .5591 Mdot
.5143 .434 Mdot
.52661 .59045 Mdot
.48688 .5661 Mdot
.57995 .54401 Mdot
.48346 .49767 Mdot
.44638 .51174 Mdot
.53686 .49253 Mdot
.49303 .48728 Mdot
.51837 .53197 Mdot
.49058 .56623 Mdot
.46313 .5013 Mdot
.56233 .43279 Mdot
.47802 .49751 Mdot
.5603 .48125 Mdot
.53332 .4964 Mdot
.35929 .48229 Mdot
.49217 .47726 Mdot
.46708 .52993 Mdot
.58833 .49576 Mdot
.5513 .48891 Mdot
.47352 .47971 Mdot
.4806 .48177 Mdot
.53498 .55727 Mdot
.48758 .48945 Mdot
.49815 .5223 Mdot
.5067 .51408 Mdot
.49238 .49011 Mdot
.5418 .50457 Mdot
.45413 .46828 Mdot
.49193 .55888 Mdot
.50458 .54933 Mdot
.4211 .52786 Mdot
.51975 .46944 Mdot
.53139 .53652 Mdot
.52593 .53195 Mdot
.47577 .43921 Mdot
.41965 .54014 Mdot
.50021 .52435 Mdot
.46573 .48236 Mdot
.54327 .49973 Mdot
.55947 .5125 Mdot
.48553 .50872 Mdot
.48924 .49382 Mdot
.41516 .51693 Mdot
.44619 .47249 Mdot
.55585 .476 Mdot
.59366 .5091 Mdot
.45891 .45865 Mdot
.52108 .50625 Mdot
.52755 .49596 Mdot
.5477 .49523 Mdot
.51011 .51405 Mdot
.43057 .53268 Mdot
.51065 .43022 Mdot
.55047 .4814 Mdot
.51774 .47898 Mdot
.49097 .51061 Mdot
.59219 .44197 Mdot
.49113 .54868 Mdot
.51534 .50803 Mdot
.50391 .50307 Mdot
.55856 .50933 Mdot
.51047 .46208 Mdot
.48627 .51903 Mdot
.53488 .51278 Mdot
.47818 .55544 Mdot
.45889 .55245 Mdot
.46197 .5543 Mdot
.49128 .43972 Mdot
.56037 .43307 Mdot
.50551 .48442 Mdot
.53096 .48518 Mdot
.58316 .54263 Mdot
.54339 .48495 Mdot
.46643 .51927 Mdot
.58383 .48345 Mdot
.51427 .52616 Mdot
.5409 .50741 Mdot
.4161 .52677 Mdot
.426 .54786 Mdot
.4989 .50867 Mdot
.54987 .41324 Mdot
.53171 .40983 Mdot
.49711 .45091 Mdot
.4996 .50986 Mdot
.49294 .4995 Mdot
.47231 .47831 Mdot
.50724 .47458 Mdot
.45198 .49248 Mdot
.44933 .51736 Mdot
.50224 .48511 Mdot
.53417 .55489 Mdot
.49042 .49127 Mdot
.53469 .49378 Mdot
.50234 .51381 Mdot
.50518 .5525 Mdot
.52982 .37841 Mdot
.46512 .44207 Mdot
.52461 .56334 Mdot
.54451 .52858 Mdot
.47794 .3596 Mdot
.43856 .48268 Mdot
.48456 .57271 Mdot
.51572 .46349 Mdot
.5328 .39372 Mdot
.51892 .40949 Mdot
.52507 .53083 Mdot
.53913 .50771 Mdot
.51922 .4258 Mdot
.44975 .51706 Mdot
.51598 .46164 Mdot
.41124 .50738 Mdot
.54261 .491 Mdot
.5 .53363 Mdot
.55102 .51335 Mdot
.49351 .46987 Mdot
.5474 .51245 Mdot
.51333 .45516 Mdot
.47792 .51531 Mdot
.51621 .45992 Mdot
.45258 .57996 Mdot
.45094 .50688 Mdot
.46657 .5319 Mdot
.48196 .53469 Mdot
.52821 .55349 Mdot
.54585 .49372 Mdot
.46939 .50273 Mdot
.4736 .54139 Mdot
.4922 .45255 Mdot
.33293 .48471 Mdot
.49592 .49287 Mdot
.50758 .53577 Mdot
.53176 .48726 Mdot
.5492 .48448 Mdot
.48422 .49411 Mdot
.4804 .55711 Mdot
.51084 .51363 Mdot
.55097 .50967 Mdot
.47191 .45273 Mdot
.47248 .50571 Mdot
.52174 .50739 Mdot
.54641 .53758 Mdot
.49692 .43278 Mdot
.39987 .49266 Mdot
.49024 .49245 Mdot
.55514 .51129 Mdot
.44906 .46726 Mdot
.46213 .53671 Mdot
.5194 .41593 Mdot
.45604 .46284 Mdot
.49392 .46622 Mdot
.4568 .5009 Mdot
.41056 .51326 Mdot
.51882 .49274 Mdot
.44471 .46769 Mdot
.45393 .51997 Mdot
.51887 .48661 Mdot
.45577 .46808 Mdot
.47629 .48755 Mdot
.50279 .56867 Mdot
.42094 .51808 Mdot
.52908 .5936 Mdot
.48133 .53001 Mdot
.43688 .48285 Mdot
.5147 .53214 Mdot
.47557 .48892 Mdot
.50198 .51704 Mdot
.51061 .56197 Mdot
.51128 .42353 Mdot
.47553 .50174 Mdot
.50434 .54863 Mdot
.46457 .44906 Mdot
.46057 .51603 Mdot
.49396 .52199 Mdot
.46984 .58602 Mdot
.4681 .50216 Mdot
.50755 .46113 Mdot
.50589 .52413 Mdot
.53141 .49946 Mdot
.50558 .51619 Mdot
.47723 .50712 Mdot
.49102 .49446 Mdot
.47687 .43821 Mdot
.50085 .56652 Mdot
.50072 .50667 Mdot
.4565 .49681 Mdot
.52813 .50343 Mdot
.53448 .49053 Mdot
.51278 .57404 Mdot
.4442 .4252 Mdot
.54928 .45737 Mdot
.44317 .52251 Mdot
.49766 .44085 Mdot
.45469 .49958 Mdot
.46075 .4925 Mdot
.49385 .65167 Mdot
.47824 .53605 Mdot
.50537 .56812 Mdot
.51458 .48278 Mdot
.53462 .58685 Mdot
.52622 .49763 Mdot
.49477 .49021 Mdot
.51995 .56642 Mdot
.45242 .48853 Mdot
.44202 .52936 Mdot
.45341 .54368 Mdot
.51331 .49455 Mdot
.53294 .55284 Mdot
.55222 .47442 Mdot
.45871 .5535 Mdot
.49826 .44735 Mdot
.51004 .48489 Mdot
.45493 .51592 Mdot
.53651 .50614 Mdot
.46963 .48398 Mdot
.45295 .52892 Mdot
.58592 .47979 Mdot
.52695 .37544 Mdot
.50454 .41594 Mdot
.51255 .47262 Mdot
.52644 .52257 Mdot
.4298 .48795 Mdot
.49362 .53694 Mdot
.52564 .4784 Mdot
.41279 .51683 Mdot
.52423 .49026 Mdot
.55631 .51987 Mdot
.47611 .47552 Mdot
.53564 .52647 Mdot
.45866 .4866 Mdot
.36116 .46003 Mdot
.5458 .49697 Mdot
.58345 .47355 Mdot
.52306 .52316 Mdot
.46671 .4891 Mdot
.56549 .45631 Mdot
.52462 .61767 Mdot
.46847 .4485 Mdot
.53479 .51284 Mdot
.4659 .49393 Mdot
.5197 .4644 Mdot
.51371 .45344 Mdot
.42112 .54218 Mdot
.52701 .49682 Mdot
.51318 .40848 Mdot
.52452 .49359 Mdot
.48582 .43724 Mdot
.54855 .48948 Mdot
.4526 .49184 Mdot
.48887 .52995 Mdot
.471 .48913 Mdot
.48732 .44685 Mdot
.45792 .53825 Mdot
.50436 .51599 Mdot
.51577 .47947 Mdot
.49122 .42187 Mdot
.474 .44356 Mdot
.48054 .44756 Mdot
.43795 .47758 Mdot
.50921 .51415 Mdot
.50426 .46508 Mdot
.47971 .47373 Mdot
.46719 .50262 Mdot
.48569 .44454 Mdot
.44459 .49925 Mdot
.54178 .52597 Mdot
.48268 .51327 Mdot
.4887 .49712 Mdot
.5386 .50809 Mdot
.50824 .54666 Mdot
.4342 .47502 Mdot
.51996 .48002 Mdot
.56287 .50148 Mdot
.45915 .45694 Mdot
.49572 .5238 Mdot
.49758 .53923 Mdot
.43784 .50428 Mdot
.5281 .40722 Mdot
.5561 .52392 Mdot
.48389 .56809 Mdot
.51428 .55053 Mdot
.49368 .52325 Mdot
.44785 .50696 Mdot
.51109 .45815 Mdot
.41899 .53259 Mdot
.56486 .55562 Mdot
.51209 .39934 Mdot
.4313 .57541 Mdot
.49501 .48528 Mdot
.50905 .51953 Mdot
.42668 .54501 Mdot
.50843 .48694 Mdot
.51364 .51138 Mdot
.55458 .52123 Mdot
.49487 .48516 Mdot
.49798 .50406 Mdot
.54858 .50986 Mdot
.41376 .50926 Mdot
.55114 .51913 Mdot
.51337 .46995 Mdot
.41326 .52744 Mdot
.52372 .47344 Mdot
.54994 .40931 Mdot
.41365 .51536 Mdot
.56344 .50046 Mdot
.48714 .56741 Mdot
.4526 .47055 Mdot
.48366 .46085 Mdot
.51384 .49353 Mdot
.54198 .48883 Mdot
.50281 .53005 Mdot
.46293 .50028 Mdot
.52936 .53884 Mdot
.50006 .44539 Mdot
.54704 .51009 Mdot
.44977 .49565 Mdot
.51497 .50083 Mdot
.56195 .54732 Mdot
.52175 .4726 Mdot
.45245 .50727 Mdot
.52032 .52999 Mdot
.56199 .43535 Mdot
.53589 .5545 Mdot
.48044 .53554 Mdot
.49505 .49974 Mdot
.56329 .4732 Mdot
.47326 .4501 Mdot
.50209 .51736 Mdot
.46866 .5407 Mdot
.52406 .5036 Mdot
.47522 .47643 Mdot
.50802 .47755 Mdot
.51274 .47452 Mdot
.44806 .48331 Mdot
.49403 .47763 Mdot
.50166 .46416 Mdot
.52357 .47502 Mdot
.41645 .46417 Mdot
.51937 .49377 Mdot
.56539 .44801 Mdot
.44898 .51248 Mdot
.54137 .49206 Mdot
.43693 .50667 Mdot
.54029 .55044 Mdot
.53883 .53927 Mdot
.4989 .48139 Mdot
.53279 .49035 Mdot
.51749 .46144 Mdot
.47711 .49693 Mdot
.55921 .50929 Mdot
.52373 .44768 Mdot
.43873 .49026 Mdot
.5521 .50201 Mdot
.50005 .52139 Mdot
.49433 .49232 Mdot
.54535 .56145 Mdot
.55196 .52763 Mdot
.46622 .40937 Mdot
.52037 .48756 Mdot
.53882 .49428 Mdot
.47618 .49452 Mdot
.45802 .52732 Mdot
.52039 .4975 Mdot
.50853 .47341 Mdot
.51458 .54261 Mdot
.41198 .48849 Mdot
.50643 .4602 Mdot
.50617 .48671 Mdot
.63097 .56738 Mdot
.48841 .50969 Mdot
.5408 .46073 Mdot
.50898 .42351 Mdot
.48782 .42271 Mdot
.50885 .5961 Mdot
.51372 .45127 Mdot
.47604 .54617 Mdot
.52057 .48971 Mdot
.47791 .51755 Mdot
.45173 .46641 Mdot
.43584 .51367 Mdot
.45083 .54511 Mdot
.44392 .50545 Mdot
.5155 .58331 Mdot
.42871 .48443 Mdot
.50598 .48062 Mdot
.4446 .55141 Mdot
.49911 .4676 Mdot
.52736 .48697 Mdot
.41378 .51937 Mdot
.56291 .48957 Mdot
.51474 .53632 Mdot
.5358 .46209 Mdot
.43206 .5751 Mdot
.54553 .54703 Mdot
.51064 .49229 Mdot
.50385 .54712 Mdot
.48901 .4986 Mdot
.50335 .51479 Mdot
.44344 .50114 Mdot
.55473 .49675 Mdot
.50048 .47535 Mdot
.51592 .53288 Mdot
.55084 .50231 Mdot
.52154 .55862 Mdot
.44336 .47872 Mdot
.50232 .57617 Mdot
.54436 .53304 Mdot
.52787 .44815 Mdot
.52276 .52967 Mdot
.33005 .49634 Mdot
.5091 .49082 Mdot
.47149 .5002 Mdot
.4165 .53628 Mdot
.5576 .54065 Mdot
.50539 .5109 Mdot
.52957 .47809 Mdot
.54083 .48346 Mdot
.43249 .51282 Mdot
.5206 .5463 Mdot
.46277 .46407 Mdot
.51776 .47484 Mdot
.51794 .53677 Mdot
.55279 .45978 Mdot
.46498 .45065 Mdot
.52583 .49684 Mdot
.44227 .49192 Mdot
.51679 .43249 Mdot
.55016 .46446 Mdot
.47947 .51612 Mdot
.55433 .44361 Mdot
.56153 .46595 Mdot
.4464 .48189 Mdot
.4861 .56591 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`2Hooooo`;o0000[Oooool0
01kooooo00?o0000ooooooooool0V?ooool2o`0000[ooooo0_l0002Qooooo`007_ooool00ol0003o
ooooooooo`2Gooooo`;o00002oooool2o`000:7ooooo000Nooooo`03o`000?oooooooooo09Oooooo
0_l0002^ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`2Wooooo`;o0000W_ooool001kooooo00?o0000ooooooooool0W?ooool2o`0000Wooooo
0ol0002Mooooo`007_ooool00ol0003oooooooooo`2Looooo`;o00002_ooool2o`0009gooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0:Wo
oooo0_l0002Looooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0ZOooool2o`0009cooooo0003ooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol0002Rooooo`;o0000Xoooool000?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000oooo
ooooool0X_ooool2o`000:?ooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01?oM
gMgoEEEEooooool00007ooooo`03o`000?oooooooooo0:Sooooo0_l0002Mooooo`000oooool01Ol@
413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`2C
ooooo`;o00003Oooool5o`000004ooooool0003o0000o`0000Cooooo0_l0002Fooooo`000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0003ooooooooo
o`2Cooooo`;o00003Oooool9o`0000Cooooo0_l0002Fooooo`000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`2Cooooo`?o00002Ooo
ool;o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`00002Cooooo`007_ooool0
0ol0003oooooooooo`2Dooooo`;o00002Oooool3o`0000;ooooo0ol000001?oooooo0000o`000?oo
ool2o`0000Gooooo0_l0002Cooooo`007_ooool00ol0003oooooooooo`2@ooooo`;o00002?ooool4
o`0000oooooo0_l0002Hooooo`007_ooool00ol0003oooooooooo`2<ooooo`;o00000_ooool2o`00
00Sooooo1?l00003ooooo`?o000000?oooooo`000?l000001_ooool4o`0009Kooooo000Nooooo`03
o`000?oooooooooo08Oooooo0_l00003ooooo`Co00002oooool3o`0000?ooooo0ol000000ooooooo
0000o`000008ooooo`;o0000U_ooool001kooooo00?o0000ooooooooool0Qoooool2o`0000?ooooo
1?l0000;ooooo`?o000000Coooooo`000?l0003ooooo0_l0002Sooooo`007_ooool00ol0003ooooo
ooooo`2Iooooo`;o000000?oooooo`000?l000000ol000000ooooooo0000o`000003o`000004oooo
ool0003o0000o`0000Oooooo0ol0002Booooo`007_ooool00ol0003oooooooooo`2Eooooo`;o0000
0_ooool6o`0000;ooooo1_l000001?oooooo0000o`000?l00007ooooo`Oo0000S_ooool001kooooo
00?o0000ooooooooool0UOooool>o`0000Gooooo0_l000001?oooooo0000o`000?l00005ooooo`Ko
0000S_ooool001kooooo00?o0000ooooooooool0QOooool2o`0000cooooo3_l0000:ooooo`?o0000
0_ooool2o`0000[ooooo0_l00029ooooo`007_ooool00ol0003oooooooooo`22ooooo`;o000000?o
ooooo`000?l000003?ooool5o`000003ooooool0003o000000Go00001oooool2o`0000?ooooo0_l0
0002ooooo`;o00002_ooool2o`0008Wooooo000Nooooo`03o`000?oooooooooo087ooooo0ol0000?
ooooo`Wo00000_ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000000_l00002
ooooo`;o00001Oooool3o`00097ooooo000Nooooo`;o0000P_ooool2o`0000kooooo2Ol00002oooo
o`Co000000?oooooo`000?l000001ol00009ooooo`?o0000TOooool001kooooo00?o0000oooooooo
ool0Loooool2o`0000Gooooo0_l00007ooooo`;o00003?ooool6o`0000Gooooo1?l00002ooooo`Co
00003_ooool2o`00097ooooo000Nooooo`03o`000?oooooooooo07?ooooo0_l00005ooooo`;o0000
1oooool2o`0000Cooooo0_l00006ooooo`Ko00002Oooool5o`0000Sooooo0ol00004ooooo`?o0000
T?ooool001kooooo00?o0000ooooooooool0LOooool2o`00013ooooo0_l00004ooooo`;o00001_oo
ool2o`0000;ooooo0_l00002ooooo`;o00001Oooool6o`000004ooooool0003o0000ooooo`So0000
0oooool2o`00093ooooo000Nooooo`03o`000?oooooooooo077ooooo0_l0000<ooooo`;o00000_oo
ool2o`0000_ooooo1?l00005ooooo`;o00000oooool;o`000003ooooool0003o000000Ko00000ooo
ool2o`00093ooooo000Nooooo`03o`000?oooooooooo07oooooo1_l00007ooooo`So00002?ooool>
o`000003ooooool0003o000000Co000000Coooooo`000?l0003ooooo0_l0002@ooooo`007_ooool0
0ol0003oooooooooo`21ooooo`;o00001oooool8o`0000Wooooo1Ol00002ooooo`Wo00000oooool9
o`0000?ooooo0_l0002;ooooo`007_ooool00ol0003oooooooooo`29ooooo`So00001oooool2o`00
0004ooooool0003o0000o`0000?ooooo1ol000000ooooooo0000o`000004ooooo`So00000oooool2
o`0008_ooooo000Nooooo`03o`000?oooooooooo08Wooooo1_l00007ooooo`Co00000_ooool@o`00
0003ooooool0003o000000Oo00001?ooool2o`0008_ooooo000Nooooo`03o`000?oooooooooo08[o
oooo1Ol00006ooooo`Ko000000?oooooo`000?l000004_l000000ooooooo0000o`000003o`0000Co
oooo0_l0002;ooooo`007_ooool00ol0003oooooooooo`1aooooo`;o00005oooool6o`0000;ooooo
5ol00002ooooo`Ko000000?oooooo`000?l000001_ooool2o`0008_ooooo000Nooooo`03o`000?oo
oooooooo06Sooooo0_l00007ooooo`;o00005?ooool5o`000005ooooool0003o0000o`000?ooool0
9?l00005ooooo`;o0000Roooool001kooooo00?o0000ooooooooool0J?ooool2o`0001Sooooo0_l0
0002ooooo`Oo00000_oooolVo`0009;ooooo000Nooooo`03o`000?oooooooooo07kooooo0_l00002
ooooo`co000000?oooooo`000?l000002?l000000ooooooo0000o`000004o`000003ooooool0003o
000001;o0000T_ooool001kooooo00?o0000ooooooooool0I_ooool3o`0001Gooooo1?l00002oooo
o`Co000000Coooooo`000?l0003ooooo9?l00002ooooo`;o00001oooool2o`0008[ooooo000Noooo
o`03o`000?oooooooooo06Kooooo0ol0000Gooooo`;o000000Coooooo`000?l0003o00000oooool2
o`000003ooooool0003o000000Oo00000_ooool8o`000004ooooool0003o0000oooooa;o00001_oo
ool2o`0008[ooooo000Nooooo`;o0000Q?ooool3o`0000?ooooo0_l000000ooooooo0000o`00000D
o`000003ooooool0003o0000013o0000T_ooool001kooooo00?o0000ooooooooool0P_ooool3o`00
0003ooooool0003o000000;ooooo1Ol000000ooooooo0000o`000006o`000005ooooool0003o0000
o`000?ooool01Ol000000ooooooo0000o`000005o`0000;ooooo2Ol0002Booooo`007_ooool00ol0
003oooooooooo`22ooooo`oo00000_oooolQo`0000Oooooo0_l0002:ooooo`007_ooool00ol0003o
ooooooooo`22oooooa3o000000?oooooo`000?l000004ol00002ooooo`[o00001oooool4o`0008So
oooo000Nooooo`03o`000?oooooooooo087ooooo0ol00003ooooo`ko00000_ooool?o`0000Cooooo
2_l00009ooooo`;o0000R?ooool001kooooo00?o0000ooooooooool0POoooolDo`0000;ooooo1Ol0
0003ooooo`Wo00000_ooool2o`0000;ooooo1_l0002Cooooo`007_ooool00ol0003oooooooooo`22
ooooo`Go00000oooool2o`0000;ooooo2?l000000ooooooo0000o`000004o`0000;ooooo1?l00000
0ooooooo0000o`000002o`0000Kooooo1Ol0002Dooooo`007_ooool00ol0003oooooooooo`22oooo
o`;o00001_ooool4o`000003ooooool0003o000000Go00001?ooool9o`0000?ooooo0ol00005oooo
o`Go00002?ooool2o`0008[ooooo000Nooooo`03o`000?oooooooooo08?ooooo0_l00006ooooo`?o
00000_ooool6o`0000Kooooo1_l000001?oooooo0000o`000?ooool3o`000003ooooool0003o0000
00Oo00002?ooool2o`0008[ooooo000Nooooo`03o`000?oooooooooo08;ooooo1_l00003ooooo`?o
000000?oooooo`000?l000000_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l0
00001?l000000ooooooo0000o`000005o`000003ooooool0003o000000Ko0000UOooool001kooooo
00?o0000ooooooooool0P_ooool8o`0000;ooooo1Ol00002ooooo`Co000000Coooooo`000?l0003o
oooo0_l00002ooooo`;o000000?oooooo`000?l000001Ol000001?oooooo0000o`000?ooool4o`00
09Kooooo000Nooooo`03o`000?oooooooooo08?ooooo1?l000000ooooooo0000o`000003ooooo`Go
000000?oooooo`000?l000001_l00003ooooo`go000000?oooooo`000?l000000ol0002Fooooo`00
7_ooool00ol0003oooooooooo`22ooooo`?o00002_ooool<o`000003ooooool0003o000000Wo0000
00?oooooo`000?l000001ol00007ooooo`;o0000SOooool001kooooo00?o0000ooooooooool0P_oo
ool5o`0000Sooooo2Ol00004oooooa7o000000Coooooo`000?l0003ooooo0_l00005ooooo`Co0000
Roooool001kooooo00?o0000ooooooooool0Q?ooool5o`0000Gooooo0ol00002ooooo`Go00000_oo
ool;o`000005ooooool0003o0000o`000?ooool01Ol00002ooooo`;o00001Oooool4o`0008_ooooo
000Nooooo`03o`000?oooooooooo08Kooooo1Ol00003ooooo`?o00000_ooool6o`000003ooooool0
003o000000;o00000_ooool3o`0000;ooooo0ol00002ooooo`Go00001?ooool2o`0000?ooooo0_l0
002=ooooo`007_ooool2o`0008Oooooo1Ol000001?oooooo0000o`000?ooool3o`0000?ooooo1_l0
00000ooooooo0000o`00000:o`0000?ooooo1?l00004ooooo`;o0000T_ooool001kooooo00?o0000
ooooooooool0S?ooool2o`0000;ooooo1?l00005ooooo`go00000_ooool7o`0009Sooooo000Noooo
o`03o`000?oooooooooo097ooooo0ol00003ooooo`Go00000_ooool4o`0000;ooooo0_l00002oooo
o`Co00002?ooool2o`00097ooooo000Nooooo`03o`000?oooooooooo08Cooooo0_l0000Aooooo`_o
00000oooool2o`000003ooooool0003o000000Co00001_ooool2o`00097ooooo000Nooooo`03o`00
0?oooooooooo08Cooooo0_l00003ooooo`;o00003Oooool6o`0000?ooooo0ol000000ooooooo0000
o`000004o`000004ooooool0003o0000o`0009Sooooo000Nooooo`03o`000?oooooooooo08Wooooo
0_l0000;ooooo`Oo00000_ooool:o`0000;ooooo1?l00002ooooo`?o00005Oooool2o`0007cooooo
000Nooooo`03o`000?oooooooooo08[ooooo0_l0000:ooooo`;o000000?oooooo`000?l000000_l0
0002ooooo`So00001?ooool2o`0000Cooooo1Ol0000:ooooo`;o00001Oooool4o`0007cooooo000N
ooooo`03o`000?oooooooooo08[ooooo0_l00004ooooo`;o00001oooool4o`0000;ooooo1ol0000>
ooooo`;o00001?ooool2o`0000Cooooo0_l00005ooooo`;o0000O_ooool001kooooo00?o0000oooo
ooooool0Koooool2o`0001Oooooo0_l00006ooooo`;o00001oooool4o`0000;ooooo0_l00002oooo
o`;o00005Oooool2o`0008_ooooo000Nooooo`03o`000?oooooooooo06oooooo0_l0000Gooooo`;o
00005Oooool2o`0000;ooooo0_l0002Rooooo`007_ooool00ol0003oooooooooo`2?ooooo`;o0000
4_ooool2o`0000[ooooo0_l0002Fooooo`007_ooool00ol0003oooooooooo`2?ooooo`Co00000_oo
ool2o`0000cooooo0_l0000:ooooo`;o0000U_ooool001kooooo00?o0000ooooooooool0T?ooool3
o`0000;ooooo0_l00006ooooo`;o00001?ooool2o`0000Gooooo0_l0002Kooooo`007_ooool00ol0
003oooooooooo`2Eooooo`;o000000?oooooo`000?l000000oooool2o`0000Sooooo0_l000000ooo
oooo0000o`00002Kooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2Hooooo`;o00002_ooool2
o`000004ooooool0003o0000o`0009gooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0:7ooooo
0_l000000ooooooo0000o`000002ooooo`;o0000WOooool000?ooooo00Go410@oooooooooooooooo
oa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`000:7ooooo0_l0002Tooooo`00
0oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06oooo
o`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go0000ooooooooooooooooo`00000;oooo
o`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`3oooooodSooooo0003oooo
o`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooo
oooo0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413o
V9RH00Sooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0:Kooooo0_l0002Oooooo`007_ooool00ol0003oooooooooo`2Doooo
o`;o00004?ooool2o`0009oooooo000Nooooo`03o`000?oooooooooo09Cooooo0_l0002aooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo09Oooooo0_l0002^ooooo`007_ooool00ol0003ooooo
ooooo`2Gooooo`;o0000[_ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000WOooool2o`000:Wooooo000Nooooo`03
o`000?oooooooooo09cooooo0_l0002Yooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooo
oooo0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool0
1Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000
oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oooooo
V9RHoc8b<P06ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go0000oooooooooooo
ooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`3ooooo
odSooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o
410@00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0?ooooooB?oo
ool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0
1_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003ooooo
odWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Dooooo`Co000000?o410@ooooooooool00oooool00ol0
003oooooooooo`3oooooodSooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0oooooom8ooooo`005_ooool00ol0003oooooooooo`05ooooo`?o0000oooooom8ooooo`005_oo
ool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool0
01Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3o
oooo000Dooooo`03oeEEEOmVIVKo00000?ooooooD_ooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.4839 .44083 Mdot
.53696 .48413 Mdot
.52169 .54474 Mdot
.53754 .50225 Mdot
.52179 .51816 Mdot
.45113 .49487 Mdot
.53487 .41843 Mdot
.54678 .49528 Mdot
.40875 .44013 Mdot
.55456 .4509 Mdot
.51444 .42747 Mdot
.4962 .48779 Mdot
.44592 .54707 Mdot
.50369 .56522 Mdot
.43955 .47093 Mdot
.51319 .53542 Mdot
.53241 .4604 Mdot
.4044 .50923 Mdot
.49301 .43606 Mdot
.46254 .53156 Mdot
.53226 .45662 Mdot
.48821 .5477 Mdot
.53744 .49614 Mdot
.46105 .52054 Mdot
.53634 .46463 Mdot
.48545 .49026 Mdot
.53922 .43302 Mdot
.44412 .46111 Mdot
.51514 .5123 Mdot
.44711 .47872 Mdot
.43767 .5059 Mdot
.53414 .48157 Mdot
.49391 .49913 Mdot
.52213 .55921 Mdot
.44714 .51586 Mdot
.50225 .5754 Mdot
.4835 .4904 Mdot
.55034 .53295 Mdot
.52524 .51032 Mdot
.47532 .49029 Mdot
.50817 .53294 Mdot
.47209 .53417 Mdot
.46581 .47382 Mdot
.50273 .49047 Mdot
.53102 .47665 Mdot
.47821 .50599 Mdot
.56295 .55927 Mdot
.43656 .52694 Mdot
.46199 .5444 Mdot
.5707 .57752 Mdot
.5139 .51893 Mdot
.5035 .57005 Mdot
.51708 .50943 Mdot
.53439 .51042 Mdot
.53369 .5309 Mdot
.46457 .49429 Mdot
.47525 .48107 Mdot
.5436 .45649 Mdot
.53867 .50059 Mdot
.46151 .48196 Mdot
.47568 .51055 Mdot
.47814 .49952 Mdot
.50752 .56914 Mdot
.51362 .53489 Mdot
.50101 .52097 Mdot
.41887 .48132 Mdot
.46671 .47393 Mdot
.46816 .49986 Mdot
.44497 .5082 Mdot
.51326 .53611 Mdot
.52959 .40313 Mdot
.53746 .5123 Mdot
.44962 .48852 Mdot
.52018 .49914 Mdot
.44654 .50294 Mdot
.56528 .43548 Mdot
.45515 .50808 Mdot
.40842 .50446 Mdot
.55456 .41128 Mdot
.4618 .45117 Mdot
.53239 .5497 Mdot
.54646 .49199 Mdot
.53502 .46371 Mdot
.49768 .52114 Mdot
.51313 .56499 Mdot
.51898 .50324 Mdot
.55547 .51857 Mdot
.47092 .49754 Mdot
.4704 .48989 Mdot
.4786 .56731 Mdot
.50604 .51166 Mdot
.48834 .52206 Mdot
.54975 .5194 Mdot
.51358 .55902 Mdot
.56539 .46165 Mdot
.478 .52957 Mdot
.46744 .49641 Mdot
.43423 .50103 Mdot
.5766 .54816 Mdot
.49784 .47735 Mdot
.56092 .50982 Mdot
.54362 .53078 Mdot
.54224 .51037 Mdot
.42074 .51224 Mdot
.42462 .42591 Mdot
.49305 .49834 Mdot
.32619 .47719 Mdot
.50373 .51799 Mdot
.4919 .46816 Mdot
.49007 .52557 Mdot
.43769 .46338 Mdot
.53856 .51121 Mdot
.5257 .48609 Mdot
.53342 .45544 Mdot
.47348 .47664 Mdot
.45559 .59274 Mdot
.55044 .49404 Mdot
.44165 .46107 Mdot
.48805 .56381 Mdot
.55111 .51763 Mdot
.40845 .49081 Mdot
.49119 .4903 Mdot
.55857 .45888 Mdot
.44689 .52294 Mdot
.5333 .4678 Mdot
.57027 .48122 Mdot
.43903 .47412 Mdot
.48902 .49022 Mdot
.49712 .4904 Mdot
.5264 .53148 Mdot
.42441 .47249 Mdot
.52745 .45907 Mdot
.55058 .54689 Mdot
.48547 .56547 Mdot
.55672 .50272 Mdot
.55546 .54703 Mdot
.52821 .43525 Mdot
.50479 .49979 Mdot
.44538 .49777 Mdot
.51602 .48685 Mdot
.50487 .51566 Mdot
.47242 .42372 Mdot
.49416 .49093 Mdot
.53172 .50835 Mdot
.49324 .5096 Mdot
.48996 .52615 Mdot
.4808 .43959 Mdot
.47178 .53954 Mdot
.46446 .48047 Mdot
.45223 .52364 Mdot
.49494 .56569 Mdot
.43084 .46634 Mdot
.51126 .5177 Mdot
.43902 .52486 Mdot
.44894 .45905 Mdot
.51346 .53554 Mdot
.48215 .50162 Mdot
.49654 .6033 Mdot
.45426 .5085 Mdot
.49561 .51172 Mdot
.46511 .43751 Mdot
.45194 .51903 Mdot
.4089 .50338 Mdot
.53906 .53226 Mdot
.47364 .48478 Mdot
.51345 .47954 Mdot
.44291 .41256 Mdot
.52392 .5398 Mdot
.48012 .53879 Mdot
.56031 .51492 Mdot
.454 .45959 Mdot
.4424 .50171 Mdot
.53342 .47566 Mdot
.4658 .48651 Mdot
.43911 .49829 Mdot
.47535 .49348 Mdot
.48665 .54339 Mdot
.49579 .51555 Mdot
.57752 .56411 Mdot
.46017 .53719 Mdot
.53402 .50472 Mdot
.48631 .53074 Mdot
.51313 .49702 Mdot
.51812 .51045 Mdot
.44374 .56548 Mdot
.50407 .48617 Mdot
.54432 .53313 Mdot
.47659 .51164 Mdot
.45077 .52368 Mdot
.56338 .50046 Mdot
.50817 .48768 Mdot
.5131 .53128 Mdot
.44876 .50074 Mdot
.50832 .5179 Mdot
.55279 .52507 Mdot
.50816 .53121 Mdot
.59906 .58009 Mdot
.49566 .49324 Mdot
.49629 .52229 Mdot
.53672 .49672 Mdot
.51431 .47619 Mdot
.46614 .50034 Mdot
.41328 .48593 Mdot
.50212 .53731 Mdot
.53916 .52344 Mdot
.52943 .47429 Mdot
.52966 .45744 Mdot
.48307 .47796 Mdot
.53162 .55307 Mdot
.51014 .51942 Mdot
.53039 .47205 Mdot
.48751 .48989 Mdot
.45497 .49669 Mdot
.43442 .49023 Mdot
.4912 .49029 Mdot
.56034 .56214 Mdot
.48282 .51502 Mdot
.45252 .50661 Mdot
.47916 .42758 Mdot
.50097 .51534 Mdot
.51197 .52197 Mdot
.54024 .53095 Mdot
.48773 .52342 Mdot
.52431 .58903 Mdot
.54693 .49439 Mdot
.55497 .50048 Mdot
.53858 .49551 Mdot
.55529 .45104 Mdot
.53274 .54646 Mdot
.50131 .43325 Mdot
.53744 .52957 Mdot
.48921 .48969 Mdot
.531 .45786 Mdot
.48496 .49808 Mdot
.47656 .49041 Mdot
.44449 .49804 Mdot
.56638 .48596 Mdot
.5706 .44112 Mdot
.52641 .46471 Mdot
.50386 .4862 Mdot
.55353 .44968 Mdot
.44572 .45202 Mdot
.4561 .45281 Mdot
.57384 .49419 Mdot
.57761 .4587 Mdot
.52692 .53426 Mdot
.55278 .42035 Mdot
.55271 .50253 Mdot
.55071 .5128 Mdot
.53641 .46143 Mdot
.46933 .47498 Mdot
.44033 .57104 Mdot
.49198 .39922 Mdot
.56985 .46054 Mdot
.52427 .48972 Mdot
.50134 .48357 Mdot
.55499 .49366 Mdot
.45636 .49798 Mdot
.51877 .56167 Mdot
.48927 .4113 Mdot
.52565 .5422 Mdot
.51275 .53229 Mdot
.49529 .51132 Mdot
.43087 .47848 Mdot
.47037 .53956 Mdot
.50191 .56491 Mdot
.54042 .46208 Mdot
.41538 .48591 Mdot
.50299 .52126 Mdot
.57392 .56634 Mdot
.47832 .46793 Mdot
.52534 .48565 Mdot
.44575 .51789 Mdot
.52002 .4863 Mdot
.53439 .5372 Mdot
.53964 .40811 Mdot
.45896 .49851 Mdot
.51448 .43158 Mdot
.45307 .52052 Mdot
.5408 .43604 Mdot
.44489 .50075 Mdot
.47562 .49092 Mdot
.46694 .55243 Mdot
.49507 .50133 Mdot
.56656 .51567 Mdot
.52431 .56543 Mdot
.57125 .56107 Mdot
.53854 .49811 Mdot
.52928 .46639 Mdot
.43078 .51718 Mdot
.48729 .48479 Mdot
.42916 .48955 Mdot
.44602 .58518 Mdot
.44702 .47964 Mdot
.5142 .47946 Mdot
.53971 .51132 Mdot
.42484 .47369 Mdot
.46137 .53608 Mdot
.49195 .54534 Mdot
.53853 .50297 Mdot
.50158 .4937 Mdot
.55553 .5007 Mdot
.40972 .44024 Mdot
.50563 .53897 Mdot
.49385 .48621 Mdot
.53742 .50405 Mdot
.51817 .39896 Mdot
.44306 .47745 Mdot
.53321 .46043 Mdot
.46143 .53086 Mdot
.53007 .50145 Mdot
.49458 .50057 Mdot
.55318 .46496 Mdot
.50925 .44695 Mdot
.53611 .49188 Mdot
.46208 .48658 Mdot
.47408 .49078 Mdot
.46888 .49893 Mdot
.44949 .49015 Mdot
.54662 .53098 Mdot
.45512 .52823 Mdot
.50976 .429 Mdot
.51221 .42861 Mdot
.47172 .49337 Mdot
.46488 .45314 Mdot
.53782 .52202 Mdot
.50551 .48874 Mdot
.49661 .49009 Mdot
.43485 .43695 Mdot
.53245 .54718 Mdot
.46878 .44487 Mdot
.46905 .59804 Mdot
.52518 .48442 Mdot
.54843 .44271 Mdot
.52632 .55841 Mdot
.55822 .49171 Mdot
.48875 .56349 Mdot
.53779 .50813 Mdot
.50998 .45207 Mdot
.47612 .49849 Mdot
.45736 .47703 Mdot
.46936 .48453 Mdot
.4571 .44695 Mdot
.49418 .49235 Mdot
.50064 .53774 Mdot
.4958 .47005 Mdot
.49591 .50086 Mdot
.54689 .5074 Mdot
.52793 .54241 Mdot
.49784 .52176 Mdot
.48205 .48163 Mdot
.5447 .55105 Mdot
.53168 .4619 Mdot
.48337 .49423 Mdot
.41589 .54424 Mdot
.50164 .47993 Mdot
.50513 .5567 Mdot
.52351 .46246 Mdot
.46817 .5746 Mdot
.49348 .50037 Mdot
.49916 .52216 Mdot
.45415 .48981 Mdot
.51925 .48098 Mdot
.46273 .53555 Mdot
.51432 .46308 Mdot
.47788 .55686 Mdot
.57546 .49504 Mdot
.51957 .53833 Mdot
.5601 .48427 Mdot
.51703 .50297 Mdot
.496 .51226 Mdot
.50372 .50372 Mdot
.53755 .55602 Mdot
.5283 .46175 Mdot
.49475 .56397 Mdot
.55941 .48973 Mdot
.51465 .44379 Mdot
.57092 .49222 Mdot
.46454 .533 Mdot
.48525 .48969 Mdot
.47235 .54267 Mdot
.57124 .43194 Mdot
.52871 .51167 Mdot
.50108 .5908 Mdot
.53846 .49678 Mdot
.48003 .45284 Mdot
.43894 .46287 Mdot
.55662 .49785 Mdot
.4669 .49268 Mdot
.46597 .53705 Mdot
.54578 .45168 Mdot
.45265 .52272 Mdot
.45479 .5287 Mdot
.53409 .48207 Mdot
.52684 .50346 Mdot
.54147 .49108 Mdot
.5155 .5415 Mdot
.49379 .50102 Mdot
.46106 .45467 Mdot
.55765 .4838 Mdot
.55649 .47333 Mdot
.47885 .55548 Mdot
.50113 .36877 Mdot
.47625 .49079 Mdot
.44863 .51713 Mdot
.49125 .5716 Mdot
.52087 .51062 Mdot
.49858 .51384 Mdot
.50303 .47622 Mdot
.46827 .45126 Mdot
.51186 .48574 Mdot
.49465 .43746 Mdot
.51839 .49981 Mdot
.43824 .5263 Mdot
.51419 .50135 Mdot
.54946 .52311 Mdot
.49548 .53243 Mdot
.43977 .49494 Mdot
.4464 .48286 Mdot
.5592 .46891 Mdot
.52112 .4359 Mdot
.47526 .50461 Mdot
.51338 .49578 Mdot
.53324 .43218 Mdot
.53321 .3776 Mdot
.49498 .56912 Mdot
.44097 .42346 Mdot
.50477 .52448 Mdot
.44308 .50372 Mdot
.45835 .49531 Mdot
.42359 .4949 Mdot
.51238 .53643 Mdot
.52702 .46119 Mdot
.50741 .44068 Mdot
.48913 .53675 Mdot
.45841 .52042 Mdot
.48445 .53899 Mdot
.47122 .48157 Mdot
.42834 .48853 Mdot
.46778 .48543 Mdot
.44307 .48343 Mdot
.55369 .53628 Mdot
.42727 .50683 Mdot
.43948 .47493 Mdot
.49302 .49928 Mdot
.42096 .47688 Mdot
.52728 .51461 Mdot
.53432 .52835 Mdot
.52136 .55965 Mdot
.50908 .51237 Mdot
.52204 .55541 Mdot
.50903 .48505 Mdot
.5044 .53001 Mdot
.46385 .48854 Mdot
.54008 .54215 Mdot
.44314 .43016 Mdot
.49099 .56406 Mdot
.54828 .53564 Mdot
.49863 .50837 Mdot
.45728 .49662 Mdot
.50627 .54324 Mdot
.52455 .49785 Mdot
.44956 .55886 Mdot
.48659 .49803 Mdot
.44663 .5085 Mdot
.54297 .58617 Mdot
.49459 .50997 Mdot
.514 .49231 Mdot
.43581 .48752 Mdot
.45334 .50105 Mdot
.50175 .43606 Mdot
.55841 .46622 Mdot
.36006 .55304 Mdot
.45174 .59405 Mdot
.46742 .44966 Mdot
.42417 .43236 Mdot
.46546 .56524 Mdot
.46094 .61654 Mdot
.56461 .50316 Mdot
.54489 .56462 Mdot
.49457 .49875 Mdot
.53139 .46317 Mdot
.55051 .4976 Mdot
.53781 .49694 Mdot
.47434 .50496 Mdot
.49806 .53865 Mdot
.54504 .44076 Mdot
.47744 .44139 Mdot
.4476 .51044 Mdot
.57197 .48821 Mdot
.51173 .5494 Mdot
.53231 .54886 Mdot
.39999 .46521 Mdot
.49624 .52081 Mdot
.47599 .47724 Mdot
.41945 .55333 Mdot
.53174 .45858 Mdot
.49416 .51913 Mdot
.48584 .53592 Mdot
.54431 .48578 Mdot
.3892 .44295 Mdot
.47839 .40149 Mdot
.44668 .48363 Mdot
.53555 .52158 Mdot
.50591 .48542 Mdot
.52363 .42616 Mdot
.4978 .45277 Mdot
.55794 .48536 Mdot
.56818 .47816 Mdot
.54948 .57433 Mdot
.45179 .52169 Mdot
.50796 .57018 Mdot
.47661 .47449 Mdot
.43135 .51951 Mdot
.55342 .49654 Mdot
.50773 .53818 Mdot
.47457 .47523 Mdot
.44721 .51123 Mdot
.50928 .55833 Mdot
.51021 .45189 Mdot
.55402 .49418 Mdot
.47729 .46864 Mdot
.52596 .46375 Mdot
.48245 .49 Mdot
.50706 .48131 Mdot
.46677 .49611 Mdot
.4735 .55573 Mdot
.50459 .56587 Mdot
.42935 .46911 Mdot
.47537 .44639 Mdot
.52261 .55842 Mdot
.49027 .5265 Mdot
.45886 .49732 Mdot
.52469 .49655 Mdot
.43137 .50567 Mdot
.49875 .48829 Mdot
.50642 .59512 Mdot
.46984 .50143 Mdot
.47595 .47944 Mdot
.50415 .43079 Mdot
.52373 .488 Mdot
.42261 .52221 Mdot
.49631 .53288 Mdot
.4876 .56872 Mdot
.43124 .46313 Mdot
.53475 .41189 Mdot
.52706 .51105 Mdot
.44134 .55046 Mdot
.53854 .51318 Mdot
.50995 .44106 Mdot
.47365 .48914 Mdot
.54267 .50281 Mdot
.49343 .5048 Mdot
.41975 .44701 Mdot
.54066 .50628 Mdot
.50333 .52745 Mdot
.50207 .50992 Mdot
.43998 .49837 Mdot
.48882 .56608 Mdot
.55641 .50379 Mdot
.53727 .5384 Mdot
.53258 .54944 Mdot
.54603 .51587 Mdot
.51542 .50582 Mdot
.47977 .54434 Mdot
.55766 .49369 Mdot
.43504 .51803 Mdot
.54365 .43857 Mdot
.50137 .5889 Mdot
.46249 .55456 Mdot
.57162 .5689 Mdot
.48812 .48991 Mdot
.43993 .49114 Mdot
.5413 .51266 Mdot
.50711 .48584 Mdot
.50544 .53568 Mdot
.45034 .55834 Mdot
.47423 .48962 Mdot
.57745 .4542 Mdot
.48975 .48999 Mdot
.5516 .51816 Mdot
.53504 .51251 Mdot
.37986 .4633 Mdot
.51317 .47596 Mdot
.45138 .51664 Mdot
.6007 .52496 Mdot
.55567 .50441 Mdot
.49516 .46787 Mdot
.50596 .46997 Mdot
.50976 .56725 Mdot
.50322 .48574 Mdot
.48477 .51088 Mdot
.49533 .52255 Mdot
.50244 .4883 Mdot
.53442 .5291 Mdot
.46726 .44654 Mdot
.46442 .53528 Mdot
.49171 .54228 Mdot
.4077 .50157 Mdot
.53581 .48214 Mdot
.50295 .53651 Mdot
.51752 .54385 Mdot
.49736 .43847 Mdot
.41028 .51748 Mdot
.48641 .51299 Mdot
.48317 .46861 Mdot
.53747 .52488 Mdot
.52898 .53888 Mdot
.47832 .49891 Mdot
.49725 .4898 Mdot
.41986 .48052 Mdot
.4596 .45501 Mdot
.55599 .49223 Mdot
.59326 .53682 Mdot
.47606 .44294 Mdot
.51568 .51618 Mdot
.51578 .51376 Mdot
.54275 .52288 Mdot
.50111 .52051 Mdot
.43882 .48381 Mdot
.54162 .41247 Mdot
.53272 .53249 Mdot
.52839 .49135 Mdot
.48172 .50075 Mdot
.59721 .45846 Mdot
.46429 .53351 Mdot
.50969 .51553 Mdot
.50086 .50639 Mdot
.5525 .55345 Mdot
.5302 .46796 Mdot
.47234 .50516 Mdot
.52503 .53327 Mdot
.45627 .53612 Mdot
.42869 .53071 Mdot
.42986 .53513 Mdot
.5151 .4537 Mdot
.57465 .45562 Mdot
.51386 .48967 Mdot
.54123 .50672 Mdot
.56881 .56247 Mdot
.55044 .50553 Mdot
.45622 .50453 Mdot
.56814 .50992 Mdot
.50169 .51911 Mdot
.53355 .52986 Mdot
.41601 .50259 Mdot
.41381 .52666 Mdot
.49026 .50049 Mdot
.56875 .414 Mdot
.55431 .40693 Mdot
.52565 .46607 Mdot
.49336 .50601 Mdot
.49117 .49182 Mdot
.49275 .46798 Mdot
.52401 .4798 Mdot
.4622 .47573 Mdot
.42519 .48061 Mdot
.51122 .48847 Mdot
.50616 .55925 Mdot
.50084 .48838 Mdot
.53983 .51248 Mdot
.49405 .50718 Mdot
.4684 .5386 Mdot
.54075 .40931 Mdot
.5124 .4494 Mdot
.49814 .56742 Mdot
.52138 .53567 Mdot
.5017 .3734 Mdot
.44309 .4583 Mdot
.45887 .53269 Mdot
.53419 .47342 Mdot
.54497 .42917 Mdot
.54475 .4435 Mdot
.52001 .54699 Mdot
.53166 .52957 Mdot
.54338 .4363 Mdot
.44232 .49782 Mdot
.53232 .48081 Mdot
.4186 .47527 Mdot
.54281 .50987 Mdot
.48361 .51981 Mdot
.53478 .53968 Mdot
.51579 .46758 Mdot
.53284 .53899 Mdot
.53163 .46698 Mdot
.46554 .50126 Mdot
.53435 .46947 Mdot
.43825 .56182 Mdot
.45575 .49219 Mdot
.44792 .51389 Mdot
.46435 .52117 Mdot
.50505 .57082 Mdot
.52811 .54377 Mdot
.47271 .49163 Mdot
.45183 .52138 Mdot
.52007 .45159 Mdot
.34142 .46741 Mdot
.50012 .49228 Mdot
.49283 .52851 Mdot
.53889 .5048 Mdot
.54413 .49884 Mdot
.49693 .48871 Mdot
.44792 .54935 Mdot
.50156 .52082 Mdot
.52091 .53915 Mdot
.50099 .42035 Mdot
.47011 .4954 Mdot
.51317 .51965 Mdot
.52476 .55822 Mdot
.52925 .43129 Mdot
.39836 .4657 Mdot
.49907 .48927 Mdot
.53773 .54061 Mdot
.47729 .44197 Mdot
.43418 .51848 Mdot
.54144 .43319 Mdot
.48675 .43919 Mdot
.52287 .4628 Mdot
.46777 .46522 Mdot
.41513 .48033 Mdot
.52174 .50451 Mdot
.47369 .44883 Mdot
.44259 .50167 Mdot
.52512 .4998 Mdot
.47561 .4557 Mdot
.49314 .4797 Mdot
.46027 .56746 Mdot
.42947 .49358 Mdot
.50664 .59542 Mdot
.46506 .51538 Mdot
.45697 .45628 Mdot
.50105 .52759 Mdot
.49212 .48113 Mdot
.48954 .5073 Mdot
.47954 .58419 Mdot
.54027 .40827 Mdot
.4774 .49119 Mdot
.48823 .54899 Mdot
.49839 .43548 Mdot
.45463 .50083 Mdot
.48052 .50917 Mdot
.45155 .57166 Mdot
.47292 .49133 Mdot
.53687 .47889 Mdot
.49548 .52387 Mdot
.52464 .51609 Mdot
.49706 .52034 Mdot
.47251 .4973 Mdot
.4965 .49054 Mdot
.49306 .42948 Mdot
.47404 .55813 Mdot
.49658 .50727 Mdot
.46691 .48279 Mdot
.52142 .51821 Mdot
.5348 .52422 Mdot
.48139 .56137 Mdot
.47145 .42242 Mdot
.56057 .48342 Mdot
.43851 .49678 Mdot
.53167 .43898 Mdot
.46171 .46375 Mdot
.47499 .45875 Mdot
.47562 .63652 Mdot
.45609 .52399 Mdot
.46228 .56695 Mdot
.52327 .49412 Mdot
.51074 .59833 Mdot
.52582 .51102 Mdot
.50247 .48966 Mdot
.49482 .57624 Mdot
.47594 .46176 Mdot
.43568 .50498 Mdot
.44614 .50847 Mdot
.51485 .50323 Mdot
.51058 .5697 Mdot
.55514 .5105 Mdot
.44347 .50657 Mdot
.52567 .45921 Mdot
.51735 .49303 Mdot
.45175 .50084 Mdot
.52957 .5292 Mdot
.49174 .47015 Mdot
.45133 .48979 Mdot
.55879 .51634 Mdot
.54138 .40432 Mdot
.53484 .40762 Mdot
.529 .47939 Mdot
.51432 .53286 Mdot
.45108 .45965 Mdot
.46594 .5313 Mdot
.53633 .49369 Mdot
.4132 .48789 Mdot
.52859 .50461 Mdot
.54691 .53694 Mdot
.49682 .46695 Mdot
.51105 .53468 Mdot
.47333 .4692 Mdot
.38418 .44852 Mdot
.53954 .52362 Mdot
.60204 .49615 Mdot
.51219 .53231 Mdot
.48251 .47876 Mdot
.56809 .48735 Mdot
.49827 .59559 Mdot
.4894 .44001 Mdot
.52519 .53256 Mdot
.47974 .48374 Mdot
.54358 .48496 Mdot
.5313 .46766 Mdot
.40948 .50861 Mdot
.52709 .5107 Mdot
.53707 .41481 Mdot
.52712 .50717 Mdot
.50189 .42734 Mdot
.54493 .51756 Mdot
.46299 .47483 Mdot
.47274 .51468 Mdot
.48739 .47961 Mdot
.51385 .44783 Mdot
.44331 .5141 Mdot
.49251 .50679 Mdot
.52624 .49114 Mdot
.52206 .4079 Mdot
.50876 .43268 Mdot
.50645 .44625 Mdot
.46262 .44891 Mdot
.49956 .52175 Mdot
.52617 .46645 Mdot
.50088 .46661 Mdot
.47174 .49161 Mdot
.53349 .45774 Mdot
.45513 .47706 Mdot
.50863 .54918 Mdot
.47281 .50161 Mdot
.49049 .48971 Mdot
.53107 .52977 Mdot
.47763 .53987 Mdot
.45888 .45523 Mdot
.52983 .49347 Mdot
.56564 .5229 Mdot
.47729 .44326 Mdot
.48186 .51107 Mdot
.48096 .5258 Mdot
.45525 .45662 Mdot
.54975 .40683 Mdot
.53689 .54672 Mdot
.4575 .52766 Mdot
.48336 .54539 Mdot
.4793 .51003 Mdot
.44853 .48994 Mdot
.53065 .46413 Mdot
.40677 .51022 Mdot
.53891 .56791 Mdot
.53866 .42974 Mdot
.43237 .53252 Mdot
.50941 .48496 Mdot
.49788 .51126 Mdot
.4255 .51804 Mdot
.51418 .494 Mdot
.50589 .51813 Mdot
.53568 .54632 Mdot
.50953 .48478 Mdot
.49423 .50206 Mdot
.53589 .53745 Mdot
.42119 .47629 Mdot
.53266 .54753 Mdot
.53148 .47764 Mdot
.4098 .49224 Mdot
.53754 .48858 Mdot
.55054 .45033 Mdot
.41652 .48472 Mdot
.56594 .52147 Mdot
.4577 .56717 Mdot
.46479 .44788 Mdot
.51158 .45692 Mdot
.51608 .50271 Mdot
.53606 .50691 Mdot
.48837 .51959 Mdot
.47443 .48869 Mdot
.49846 .57118 Mdot
.54675 .46096 Mdot
.53784 .5571 Mdot
.467 .47725 Mdot
.51276 .50842 Mdot
.51952 .56411 Mdot
.53666 .49581 Mdot
.45739 .49306 Mdot
.50749 .53639 Mdot
.57431 .45978 Mdot
.51905 .58597 Mdot
.46229 .52247 Mdot
.49291 .49262 Mdot
.55943 .50787 Mdot
.50929 .4415 Mdot
.49354 .51811 Mdot
.43381 .51181 Mdot
.51967 .51469 Mdot
.49553 .46836 Mdot
.52168 .48458 Mdot
.52697 .48336 Mdot
.4714 .45726 Mdot
.51366 .4762 Mdot
.52574 .45959 Mdot
.53682 .48986 Mdot
.44016 .44612 Mdot
.5217 .50541 Mdot
.5733 .47612 Mdot
.44627 .49512 Mdot
.54043 .51063 Mdot
.448 .48685 Mdot
.51529 .56169 Mdot
.51249 .53982 Mdot
.5143 .48319 Mdot
.52174 .50928 Mdot
.53472 .47498 Mdot
.49018 .48937 Mdot
.54461 .53718 Mdot
.56573 .44959 Mdot
.43742 .46378 Mdot
.5538 .53186 Mdot
.48676 .51053 Mdot
.49991 .49106 Mdot
.50974 .56115 Mdot
.53208 .54907 Mdot
.48996 .39975 Mdot
.52595 .50107 Mdot
.53586 .51232 Mdot
.49134 .48688 Mdot
.43409 .48506 Mdot
.52068 .50861 Mdot
.52604 .47827 Mdot
.48386 .53768 Mdot
.40144 .45707 Mdot
.52756 .46331 Mdot
.51216 .49221 Mdot
.60854 .5801 Mdot
.48007 .49967 Mdot
.5762 .4869 Mdot
.53406 .44474 Mdot
.51848 .40771 Mdot
.48895 .60348 Mdot
.53697 .46625 Mdot
.45447 .52474 Mdot
.52511 .50298 Mdot
.46485 .50292 Mdot
.46657 .44768 Mdot
.43623 .49009 Mdot
.43322 .52684 Mdot
.44282 .48625 Mdot
.48829 .57447 Mdot
.44929 .4565 Mdot
.518 .48654 Mdot
.41971 .52924 Mdot
.52199 .46586 Mdot
.53351 .50299 Mdot
.41558 .48484 Mdot
.55318 .51997 Mdot
.50049 .53593 Mdot
.5735 .48925 Mdot
.43032 .53246 Mdot
.52631 .55685 Mdot
.51327 .50009 Mdot
.49053 .54953 Mdot
.48893 .49052 Mdot
.492 .50581 Mdot
.44604 .47919 Mdot
.54213 .53287 Mdot
.52009 .47669 Mdot
.50255 .5305 Mdot
.54319 .53266 Mdot
.49273 .55768 Mdot
.45649 .46282 Mdot
.47393 .59211 Mdot
.52011 .53823 Mdot
.56103 .48476 Mdot
.50948 .53806 Mdot
.33366 .47676 Mdot
.51247 .49805 Mdot
.47977 .49054 Mdot
.40611 .50716 Mdot
.5147 .56042 Mdot
.49965 .51348 Mdot
.54115 .50205 Mdot
.55782 .50158 Mdot
.42816 .49135 Mdot
.48755 .563 Mdot
.48557 .45444 Mdot
.53059 .4862 Mdot
.50324 .5375 Mdot
.56411 .48264 Mdot
.4844 .44043 Mdot
.51355 .5144 Mdot
.45916 .47699 Mdot
.54431 .44028 Mdot
.55816 .49328 Mdot
.46648 .50181 Mdot
.56502 .47298 Mdot
.55443 .50007 Mdot
.46904 .4396 Mdot
.44687 .55626 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0Woooool2o`000:Kooooo000Nooooo`03o`000?oooooooooo
09oooooo0_l0002Vooooo`007_ooool00ol0003oooooooooo`2Oooooo`;o0000Y_ooool001kooooo
00?o0000ooooooooool0ZOooool2o`0009cooooo000Nooooo`03o`000?oooooooooo0:Wooooo0_l0
002Looooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol0002Kooooo`?o00001_ooool2o`000:7o
oooo0003ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00007oooo
o`03o`000?oooooooooo09Oooooo0_l00002ooooo`?o00001_ooool2o`0000;ooooo0_l00002oooo
o`;o0000VOooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0000Oooooo00?o0000ooooooooool0Uoooool2o`0000oooooo0_l00002ooooo`;o000000Cooooo
o`000?l0003o0000UOooool000?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<
c<co000000Oooooo00?o0000ooooooooool0Y?ooool4o`0000;ooooo1?l000001?oooooo0000o`00
0?l0002Eooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
1oooool00ol0003oooooooooo`2<ooooo`;o00003Oooool2o`0000Oooooo1?l00002ooooo`Co0000
0_ooool2o`0009Gooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000
ooooo`06ooooo`03o`000?oooooooooo08cooooo0_l0000=ooooo`;o00003Oooool4o`0000;ooooo
0_l00003ooooo`;o0000T?ooool001kooooo00?o0000ooooooooool0Z_ooool2o`0000Wooooo0_l0
002@ooooo`007_ooool00ol0003oooooooooo`2Eooooo`;o00002?ooool2o`0000Wooooo0_l00004
ooooo`;o0000UOooool001kooooo00?o0000ooooooooool0Roooool2o`0000Sooooo0_l00008oooo
o`;o00003oooool2o`0009Gooooo000Nooooo`03o`000?oooooooooo08Kooooo0_l00003ooooo`;o
00002?ooool2o`000003ooooool0003o000000Gooooo0_l000001Ooooooo0000o`000?l0003ooooo
00;o0000Woooool001kooooo00?o0000ooooooooool0Q_ooool2o`0000Cooooo0_l0000:ooooo`;o
00000_ooool2o`000003ooooool0003o000000Co000000?oooooo`000?l000000_l000000ooooooo
0000o`000002o`0000Oooooo0_l0002?ooooo`007_ooool00ol0003oooooooooo`26ooooo`;o0000
1?ooool2o`0000kooooo0_l000000ooooooo0000o`000004o`0000?ooooo1ol00007ooooo`;o0000
Soooool001kooooo00?o0000ooooooooool0Q_ooool2o`000003ooooool0003o000000Sooooo0_l0
0007ooooo`Oo00000_ooool2o`000003ooooool0003o000000Go00001Oooool2o`00097ooooo000N
ooooo`03o`000?oooooooooo087ooooo0_l00006ooooo`;o00002?ooool3o`0000;ooooo3?l00000
1?oooooo0000o`000?ooool3o`000004ooooool0003o0000o`0000Gooooo0ol0002@ooooo`007_oo
ool00ol0003oooooooooo`1jooooo`;o00001Oooool2o`00017ooooo0_l000000ooooooo0000o`00
0004o`000004ooooool0003o0000ooooo`Co00001?ooool2o`0000;ooooo0ol00005ooooo`;o0000
T?ooool001kooooo00?o0000ooooooooool0N_ooool2o`0000Sooooo0_l00005ooooo`;o00000ooo
ool2o`0000;ooooo1Ol00008ooooo`Co00001Oooool2o`000004ooooool0003o0000o`0009Oooooo
000Nooooo`03o`000?oooooooooo07Wooooo0_l00009ooooo`;o00001Oooool2o`0000?ooooo2?l0
0009ooooo`Co00001Oooool2o`0000?ooooo0ol00002ooooo`;o0000TOooool001kooooo0_l0001j
ooooo`;o00004_ooool2o`000003ooooool0003o000000So00001?ooool2o`0000;ooooo1Ol00006
ooooo`Go00000_ooool2o`00097ooooo000Nooooo`03o`000?oooooooooo08gooooo2Ol000000ooo
oooo0000o`000003o`0000;ooooo0_l00002ooooo`Go00000_ooool2o`0000;ooooo0_l000000ooo
oooo0000o`000005ooooo`?o0000SOooool001kooooo00?o0000ooooooooool0O_ooool2o`0000co
oooo2?l000000ooooooo0000o`000002o`000003ooooool0003o000000Kooooo0ol00002ooooo`Co
00000_ooool2o`0000;ooooo0_l00004ooooo`?o00001?ooool2o`0008Oooooo000Nooooo`03o`00
0?oooooooooo07kooooo0_l0000;ooooo`Ko00001?ooool4o`0000Wooooo0_l00002ooooo`[o0000
00Coooooo`000?l0003ooooo1_l00004ooooo`;o0000Qoooool001kooooo00?o0000ooooooooool0
Moooool2o`0000Cooooo0ol00008ooooo`Ko00000_ooool6o`000003ooooool0003o000000[ooooo
0_l000000ooooooo0000o`00000:o`0000;ooooo1Ol0002>ooooo`007_ooool00ol0003ooooooooo
o`1[ooooo`;o00002_ooool2o`0000Cooooo0ol00008ooooo`Go00000oooool6o`000003ooooool0
003o000000;o000000?oooooo`000?l000000ol00002ooooo`Wo00001?ooool4o`0009?ooooo000N
ooooo`03o`000?oooooooooo06_ooooo0_l0000Jooooo`?o000000?oooooo`000?l000002Oooool5
o`000003ooooool0003o000000Co00000_ooool2o`000003ooooool0003o000000?o00001Oooool3
o`0009?ooooo000Nooooo`03o`000?oooooooooo08Kooooo0ol00002ooooo`;o00001Oooool7o`00
00?ooooo0ol000000ooooooo0000o`000006ooooo`Co00001Oooool2o`000003ooooool0003o0000
097ooooo000Nooooo`03o`000?oooooooooo06Kooooo1?l0000Jooooo`Co00000oooool3o`0000;o
oooo2ol00003ooooo`?o00000_ooool4o`000003ooooool0003o000000;o00001Oooool2o`000003
ooooool0003o000000;o0000Soooool001kooooo00?o0000ooooooooool0I_ooool4o`0001Wooooo
1ol00002ooooo`?o000000?oooooo`000?l000003ol00002ooooo`Wo00002Oooool3o`0008oooooo
000Nooooo`03o`000?oooooooooo08?ooooo1ol000000ooooooo0000o`000002o`0000?ooooo3?l0
00000ooooooo0000o`00000;o`0000Gooooo1_l0002@ooooo`007_ooool00ol0003oooooooooo`22
ooooo`Co00000oooool7o`0000;ooooo3?l000000ooooooo0000o`00000;o`000003ooooool0003o
000000;ooooo2?l0002>ooooo`007_ooool00ol0003oooooooooo`22ooooo`?o00000_oooolXo`00
00;ooooo2?l0002>ooooo`007_ooool00ol0003oooooooooo`21ooooo`?o00000oooool6o`000003
ooooool0003o0000023o000000Goooooo`000?l0003o0000ooooo`03o`0008oooooo000Nooooo`03
o`000?oooooooooo087ooooo0_l00003ooooo`Co000000?oooooo`000?l000005?l000000ooooooo
0000o`00000?o`0000;ooooo1?l00007ooooo`;o0000QOooool001kooooo00?o0000ooooooooool0
Q_oooolKo`000003ooooool0003o000000Co00000_ooool9o`0000?ooooo0ol00007ooooo`;o0000
QOooool001kooooo0_l00021ooooo`;o000000?oooooo`000?l000001?oooolFo`000003ooooool0
003o000001?o0000T_ooool001kooooo00?o0000ooooooooool0P?ooool5o`0000?ooooo2_l00000
0ooooooo0000o`00000:o`000004ooooool0003o0000ooooo`_o000000?oooooo`000?l000001?l0
002Booooo`007_ooool00ol0003oooooooooo`20ooooo`?o00001?ooool;o`000003ooooool0003o
000000Co00000_ooool7o`000003ooooool0003o0000013o0000T_ooool001kooooo00?o0000oooo
ooooool0Ooooool4o`0000Cooooo2ol00005ooooo`_o000000?oooooo`000?l000003ol000000ooo
oooo0000o`00002@ooooo`007_ooool00ol0003oooooooooo`1oooooo`?o00000oooool2o`0000;o
oooo0_l000000ooooooo0000o`000002o`0000Kooooo6?l000000ooooooo0000o`000003o`000003
ooooool0003o0000093ooooo000Nooooo`03o`000?oooooooooo087ooooo0_l00002ooooo`Ko0000
00?oooooo`000?l000000ol00002ooooo`;o000000Coooooo`000?l0003ooooo4?l000000ooooooo
0000o`000005o`000003ooooool0003o000000;o0000TOooool001kooooo00?o0000ooooooooool0
POooool2o`0000?ooooo1Ol00002ooooo`So00001?ooool?o`0000Gooooo2Ol0002Aooooo`007_oo
ool00ol0003oooooooooo`25ooooo`;o000000Coooooo`000?l0003o00000_ooool8o`0000Cooooo
2?l000000ooooooo0000o`000003o`0000?ooooo1?l000001?oooooo0000o`000?l00002ooooo`;o
0000TOooool001kooooo00?o0000ooooooooool0P_ooool2o`000003ooooool0003o000000;ooooo
2ol00004ooooo`co00001_ooool4o`000004ooooool0003o0000o`0000;ooooo0_l00009ooooo`;o
0000Q_ooool001kooooo00?o0000ooooooooool0P_ooool4o`0000?ooooo1?l00003ooooo`?o0000
1?ooool3o`000005ooooool0003o0000o`000?ooool00ol00006ooooo`Go00000oooool2o`0000go
oooo0_l00026ooooo`007_ooool00ol0003oooooooooo`24ooooo`;o000000Coooooo`000?l0003o
00001_ooool5o`0000;ooooo0_l000000ooooooo0000o`000009o`0000;ooooo2ol0002Eooooo`00
7_ooool00ol0003oooooooooo`27ooooo`?o00001_ooool7o`0000?ooooo0_l000000ooooooo0000
o`00000Co`0009Gooooo000Nooooo`03o`000?oooooooooo08Sooooo0_l00006ooooo`Oo000000?o
ooooo`000?l000000ol000000ooooooo0000o`00000Bo`0000_ooooo0_l00028ooooo`007_ooool0
0ol0003oooooooooo`2Aoooooaoo00003Oooool2o`0008Sooooo000Nooooo`03o`000?oooooooooo
08?ooooo0_l0000=ooooo`;o000000?oooooo`000?l000001ol00002ooooo`;o000000?oooooo`00
0?l000001Ol000000ooooooo0000o`00002Jooooo`007_ooool00ol0003oooooooooo`23ooooo`;o
00002?ooool2o`0000?ooooo0_l00004ooooo`Ko00000_ooool2o`0000;ooooo0ol000000ooooooo
0000o`000002o`0000?ooooo0ol00005ooooo`;o0000S_ooool001kooooo0_l0002<ooooo`Go0000
2oooool2o`0000Cooooo0ol000000ooooooo0000o`000002ooooo`?o000000?oooooo`000?l00000
0ol00005ooooo`;o0000S_ooool001kooooo00?o0000ooooooooool0LOooool2o`00017ooooo0_l0
0005ooooo`;o000000?oooooo`000?l000000_ooool4o`0000Gooooo0_l00004ooooo`?o00001Ooo
ool2o`0000;ooooo0_l000000ooooooo0000o`00002Eooooo`007_ooool00ol0003oooooooooo`1a
ooooo`;o00004Oooool2o`0000Oooooo0_l00003ooooo`So00000_ooool2o`0000;ooooo0_l00004
ooooo`Oo00000oooool2o`0009Gooooo000Nooooo`03o`000?oooooooooo08gooooo0ol00006oooo
o`Co00000_ooool2o`0000;ooooo2Ol00002ooooo`;o00001_ooool2o`000003ooooool0003o0000
08oooooo000Nooooo`03o`000?oooooooooo08[ooooo0_l00002ooooo`;o00002?ooool7o`000003
ooooool0003o000000Oo00002Oooool8o`0008gooooo000Nooooo`03o`000?oooooooooo08[ooooo
1?l00003ooooo`Co00000_oooolAo`0000Gooooo0_l00003ooooo`;o000000?oooooo`000?l00000
0ol0002=ooooo`007_ooool00ol0003oooooooooo`2<ooooo`;o00000oooool4o`0000;ooooo0_l0
00000ooooooo0000o`000009o`000003ooooool0003o000000?ooooo1?l00007ooooo`;o0000Sooo
ool001kooooo00?o0000ooooooooool0Roooool2o`0000;ooooo0_l000000ooooooo0000o`000006
ooooo`[o00001oooool2o`0000Wooooo0_l0002?ooooo`007_ooool00ol0003oooooooooo`2;oooo
o`;o00000_ooool2o`0000?ooooo0_l00005ooooo`Oo00003Oooool2o`0009Kooooo000Nooooo`03
o`000?oooooooooo09Cooooo0_l00005ooooo`Ko00003_ooool2o`0000Cooooo0_l0002@ooooo`00
7_ooool00ol0003oooooooooo`2eooooo`;o00002?ooool2o`000003ooooool0003o000008?ooooo
000Nooooo`03o`000?oooooooooo08gooooo0_l00009ooooo`;o00009Oooool2o`000003ooooool0
003o000008?ooooo000Nooooo`03o`000?oooooooooo08gooooo0_l00009ooooo`;o00001Oooool2
o`0000Cooooo0_l00005ooooo`;o0000VOooool001kooooo00?o0000ooooooooool0Woooool2o`00
00Cooooo0ol00004ooooo`;o0000VOooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0Soooool3
o`0000Cooooo0_l00007ooooo`;o00001Oooool2o`0009oooooo0003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oo
oooooooo08oooooo0ol00002ooooo`Co00001_ooool2o`000003ooooool0003o00000:Cooooo0003
ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo
0ol0002Dooooo`;o00002?ooool2o`000004ooooool0003o0000o`000:?ooooo0003ooooo`05o`00
0?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o0000oooo
ooooool0Voooool4o`0000?ooooo0_l0002Sooooo`000oooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo09_ooooo1?l0002X
ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool0
0ol0003oooooooooo`3oooooodSooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
0ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0T_oo
ool2o`000;?ooooo000Nooooo`03o`000?oooooooooo09;ooooo0_l0002cooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0Uoooool2o`00
0:kooooo000Nooooo`03o`000?oooooooooo09Oooooo0_l0002^ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?ooooooB?ooool0
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonH
V9So8B4Q00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol@413ooooooooooooo
oooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000oooooom8ooooo`000ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03
o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05
olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000
ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000
okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o
0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Dooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooo
odSooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom8ooooo`00
5_ooool00ol0003oooooooooo`05ooooo`?o0000oooooom8ooooo`005_ooool00ol0003ooooooooo
o`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000oooo
ooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Dooooo`03oeEE
EOmVIVKo00000?ooooooD_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.50643 .44378 Mdot
.54212 .50437 Mdot
.49519 .56665 Mdot
.53372 .51966 Mdot
.50964 .5255 Mdot
.46657 .45877 Mdot
.56343 .40834 Mdot
.54797 .52062 Mdot
.42342 .42352 Mdot
.56832 .47484 Mdot
.53577 .44111 Mdot
.51204 .48731 Mdot
.44533 .51073 Mdot
.46837 .55145 Mdot
.45472 .42849 Mdot
.4973 .53772 Mdot
.54447 .47839 Mdot
.40884 .47825 Mdot
.52799 .43466 Mdot
.44601 .50924 Mdot
.54532 .47324 Mdot
.47271 .53987 Mdot
.51777 .51561 Mdot
.44777 .48353 Mdot
.55033 .48873 Mdot
.49674 .48589 Mdot
.55542 .46215 Mdot
.47374 .44098 Mdot
.50736 .51754 Mdot
.45759 .44767 Mdot
.44276 .47943 Mdot
.54104 .506 Mdot
.49095 .49431 Mdot
.49584 .5681 Mdot
.45228 .47663 Mdot
.4784 .57352 Mdot
.48831 .48496 Mdot
.53055 .54335 Mdot
.50795 .52571 Mdot
.49307 .4826 Mdot
.49412 .52577 Mdot
.45011 .51609 Mdot
.48536 .46607 Mdot
.50884 .4954 Mdot
.53914 .50268 Mdot
.47243 .4913 Mdot
.53559 .57091 Mdot
.4334 .5005 Mdot
.44609 .51843 Mdot
.53069 .57567 Mdot
.50045 .52667 Mdot
.4755 .59108 Mdot
.5106 .51643 Mdot
.51923 .52575 Mdot
.51691 .54684 Mdot
.47258 .4835 Mdot
.49549 .47548 Mdot
.53961 .50941 Mdot
.54057 .52386 Mdot
.48009 .47237 Mdot
.46713 .49234 Mdot
.47689 .48971 Mdot
.48066 .56461 Mdot
.49777 .53766 Mdot
.49243 .52084 Mdot
.4095 .45148 Mdot
.48998 .46373 Mdot
.46813 .48817 Mdot
.44747 .49128 Mdot
.49713 .5375 Mdot
.55539 .4021 Mdot
.53011 .52606 Mdot
.46368 .47513 Mdot
.51953 .51142 Mdot
.44642 .46738 Mdot
.57488 .45984 Mdot
.45472 .49073 Mdot
.40979 .47431 Mdot
.56878 .42504 Mdot
.49483 .4447 Mdot
.50967 .55137 Mdot
.55083 .51794 Mdot
.54557 .4863 Mdot
.4855 .50592 Mdot
.48652 .56506 Mdot
.51602 .51347 Mdot
.53274 .546 Mdot
.47422 .48814 Mdot
.48869 .48104 Mdot
.43866 .55882 Mdot
.4998 .51369 Mdot
.47772 .50433 Mdot
.5268 .54534 Mdot
.46787 .53726 Mdot
.55487 .49577 Mdot
.46716 .50798 Mdot
.47266 .48698 Mdot
.44372 .47618 Mdot
.55358 .56598 Mdot
.51701 .48074 Mdot
.54036 .53975 Mdot
.51813 .55131 Mdot
.53676 .52861 Mdot
.40453 .48377 Mdot
.44333 .41556 Mdot
.48903 .49231 Mdot
.33322 .4594 Mdot
.49545 .51789 Mdot
.51442 .46827 Mdot
.47874 .50795 Mdot
.44965 .44741 Mdot
.53213 .52565 Mdot
.53089 .50099 Mdot
.56415 .47882 Mdot
.49937 .46725 Mdot
.43692 .58427 Mdot
.55945 .52877 Mdot
.4694 .43831 Mdot
.45867 .56696 Mdot
.53007 .54536 Mdot
.41886 .46572 Mdot
.50212 .4878 Mdot
.56578 .48706 Mdot
.44105 .49353 Mdot
.54342 .48686 Mdot
.58007 .50555 Mdot
.44368 .45034 Mdot
.49959 .48706 Mdot
.50449 .49135 Mdot
.50951 .54108 Mdot
.44484 .4483 Mdot
.54416 .47005 Mdot
.53548 .58494 Mdot
.462 .54867 Mdot
.54573 .51651 Mdot
.54086 .5837 Mdot
.55654 .43109 Mdot
.5045 .50556 Mdot
.45304 .48087 Mdot
.52281 .49728 Mdot
.49737 .51637 Mdot
.50452 .43441 Mdot
.49796 .48956 Mdot
.52492 .52163 Mdot
.48794 .5023 Mdot
.47819 .50824 Mdot
.50138 .437 Mdot
.45762 .52204 Mdot
.49041 .46859 Mdot
.44324 .49385 Mdot
.46979 .55331 Mdot
.45639 .4424 Mdot
.50208 .52058 Mdot
.42227 .50056 Mdot
.47684 .4413 Mdot
.4975 .53796 Mdot
.47794 .49147 Mdot
.4769 .59933 Mdot
.45407 .49111 Mdot
.49158 .50766 Mdot
.493 .40985 Mdot
.44559 .50027 Mdot
.40829 .47648 Mdot
.52391 .54855 Mdot
.49293 .47896 Mdot
.52711 .48771 Mdot
.46451 .40669 Mdot
.49397 .53346 Mdot
.45711 .52855 Mdot
.54162 .52917 Mdot
.48551 .44272 Mdot
.44224 .4757 Mdot
.54267 .49262 Mdot
.48395 .47855 Mdot
.4599 .45028 Mdot
.4825 .48565 Mdot
.47541 .52436 Mdot
.49063 .51124 Mdot
.55857 .57867 Mdot
.44428 .5111 Mdot
.52912 .52011 Mdot
.47571 .50908 Mdot
.51324 .50643 Mdot
.51106 .5176 Mdot
.43757 .53721 Mdot
.51801 .48913 Mdot
.52069 .56008 Mdot
.46753 .4925 Mdot
.42009 .49136 Mdot
.54791 .53194 Mdot
.5158 .4945 Mdot
.49929 .53707 Mdot
.44035 .46887 Mdot
.49942 .51965 Mdot
.53146 .53547 Mdot
.49518 .52393 Mdot
.56602 .58494 Mdot
.49793 .49355 Mdot
.48781 .52219 Mdot
.53553 .51491 Mdot
.53012 .48415 Mdot
.46446 .48718 Mdot
.42789 .46063 Mdot
.4724 .52599 Mdot
.52188 .54388 Mdot
.5411 .48934 Mdot
.5471 .46835 Mdot
.5038 .47639 Mdot
.50691 .56972 Mdot
.50005 .52236 Mdot
.53954 .49725 Mdot
.49228 .48584 Mdot
.46854 .48316 Mdot
.45941 .46707 Mdot
.50242 .48779 Mdot
.53157 .57025 Mdot
.47357 .49751 Mdot
.45482 .48966 Mdot
.51247 .44042 Mdot
.49516 .51392 Mdot
.49495 .53146 Mdot
.52592 .57614 Mdot
.47665 .50528 Mdot
.49464 .58406 Mdot
.55943 .51931 Mdot
.55522 .52057 Mdot
.54177 .51826 Mdot
.56798 .4769 Mdot
.50846 .56692 Mdot
.53297 .44451 Mdot
.52685 .55212 Mdot
.49444 .48635 Mdot
.56119 .48377 Mdot
.48192 .49018 Mdot
.48716 .48337 Mdot
.45152 .48061 Mdot
.57876 .51087 Mdot
.57905 .46659 Mdot
.54202 .47685 Mdot
.5179 .48906 Mdot
.56763 .47433 Mdot
.46613 .41576 Mdot
.47435 .4408 Mdot
.57482 .51737 Mdot
.56652 .48674 Mdot
.51004 .54492 Mdot
.57012 .43706 Mdot
.54915 .52284 Mdot
.54148 .5415 Mdot
.55608 .49681 Mdot
.48975 .46918 Mdot
.43208 .54679 Mdot
.51721 .39641 Mdot
.55807 .49224 Mdot
.52781 .50442 Mdot
.51779 .48592 Mdot
.53876 .51353 Mdot
.46606 .48383 Mdot
.49211 .56637 Mdot
.51684 .42462 Mdot
.49579 .53537 Mdot
.49914 .53321 Mdot
.49133 .50715 Mdot
.45401 .45608 Mdot
.44979 .51704 Mdot
.4747 .55647 Mdot
.5635 .48616 Mdot
.43079 .45451 Mdot
.49117 .50826 Mdot
.55704 .58396 Mdot
.50008 .46224 Mdot
.53084 .5004 Mdot
.41705 .4866 Mdot
.52673 .49874 Mdot
.51002 .56294 Mdot
.56404 .41446 Mdot
.46291 .4848 Mdot
.54716 .43576 Mdot
.4431 .49861 Mdot
.56393 .45114 Mdot
.45064 .48442 Mdot
.4894 .48376 Mdot
.43749 .53619 Mdot
.49435 .50139 Mdot
.56448 .53857 Mdot
.47866 .54667 Mdot
.54743 .57307 Mdot
.51696 .51795 Mdot
.54232 .48107 Mdot
.41913 .49413 Mdot
.50633 .48216 Mdot
.44186 .4709 Mdot
.42742 .57441 Mdot
.46244 .4651 Mdot
.52762 .48801 Mdot
.52725 .52689 Mdot
.44895 .44783 Mdot
.44456 .51042 Mdot
.4647 .52986 Mdot
.5348 .52042 Mdot
.50545 .49863 Mdot
.55615 .52038 Mdot
.41952 .42002 Mdot
.49068 .52991 Mdot
.51137 .48517 Mdot
.5329 .52071 Mdot
.54361 .43183 Mdot
.46377 .4662 Mdot
.55017 .48321 Mdot
.44457 .50707 Mdot
.52709 .51661 Mdot
.49343 .49951 Mdot
.56776 .491 Mdot
.53349 .46578 Mdot
.53741 .50983 Mdot
.48886 .47189 Mdot
.49142 .48264 Mdot
.47046 .48812 Mdot
.46303 .47682 Mdot
.52324 .53853 Mdot
.44331 .49977 Mdot
.52912 .44355 Mdot
.53021 .43819 Mdot
.47974 .48482 Mdot
.49796 .44215 Mdot
.51041 .53038 Mdot
.51273 .49448 Mdot
.50477 .49061 Mdot
.46259 .42897 Mdot
.50803 .55782 Mdot
.48762 .43565 Mdot
.44744 .59572 Mdot
.53146 .49905 Mdot
.56629 .46301 Mdot
.50155 .57132 Mdot
.55017 .52043 Mdot
.46488 .54688 Mdot
.53177 .5232 Mdot
.53182 .47717 Mdot
.47685 .48916 Mdot
.47914 .46326 Mdot
.49824 .47483 Mdot
.50494 .44866 Mdot
.49605 .49059 Mdot
.47568 .53398 Mdot
.52035 .46822 Mdot
.4956 .5021 Mdot
.54047 .52712 Mdot
.49857 .53678 Mdot
.48563 .50646 Mdot
.5017 .4783 Mdot
.52805 .58752 Mdot
.54346 .48221 Mdot
.484 .48739 Mdot
.40948 .5202 Mdot
.51868 .48366 Mdot
.46771 .54038 Mdot
.54201 .47109 Mdot
.43379 .57456 Mdot
.48839 .49353 Mdot
.49027 .52328 Mdot
.48032 .47441 Mdot
.52998 .49217 Mdot
.43521 .51111 Mdot
.5348 .46795 Mdot
.44484 .54587 Mdot
.54974 .52089 Mdot
.48999 .53196 Mdot
.58071 .52396 Mdot
.51424 .51242 Mdot
.49185 .50832 Mdot
.5015 .50793 Mdot
.52039 .5912 Mdot
.55012 .48982 Mdot
.46731 .56937 Mdot
.55304 .52037 Mdot
.54353 .46384 Mdot
.55788 .52319 Mdot
.44549 .51398 Mdot
.49223 .48513 Mdot
.45176 .51895 Mdot
.57231 .45793 Mdot
.51935 .5228 Mdot
.47514 .57718 Mdot
.54185 .51988 Mdot
.49961 .4341 Mdot
.46696 .44108 Mdot
.5446 .52497 Mdot
.47729 .4833 Mdot
.44759 .51212 Mdot
.55714 .50061 Mdot
.44261 .50244 Mdot
.44273 .50089 Mdot
.54104 .50669 Mdot
.50709 .52205 Mdot
.54508 .5178 Mdot
.50035 .53837 Mdot
.49147 .49725 Mdot
.49387 .44181 Mdot
.56043 .53229 Mdot
.56637 .52081 Mdot
.45666 .53476 Mdot
.52279 .39279 Mdot
.49055 .48374 Mdot
.44037 .49056 Mdot
.46728 .56088 Mdot
.51338 .51902 Mdot
.49388 .51139 Mdot
.52251 .48127 Mdot
.50222 .44483 Mdot
.52091 .49376 Mdot
.52922 .43617 Mdot
.51736 .51115 Mdot
.43494 .49929 Mdot
.51221 .51012 Mdot
.52487 .54674 Mdot
.48281 .51736 Mdot
.43369 .46626 Mdot
.46203 .46974 Mdot
.56348 .49891 Mdot
.55232 .44239 Mdot
.47072 .49045 Mdot
.51401 .50546 Mdot
.55965 .44502 Mdot
.54606 .40946 Mdot
.47054 .55794 Mdot
.45557 .40013 Mdot
.49187 .51181 Mdot
.44388 .48535 Mdot
.47243 .48272 Mdot
.43252 .47746 Mdot
.49637 .53673 Mdot
.54805 .46911 Mdot
.54209 .44433 Mdot
.46267 .52709 Mdot
.44443 .48481 Mdot
.46003 .52989 Mdot
.49108 .47467 Mdot
.44224 .47354 Mdot
.4863 .47822 Mdot
.45434 .4647 Mdot
.50715 .55773 Mdot
.42556 .48321 Mdot
.46625 .45331 Mdot
.48837 .49281 Mdot
.44083 .45041 Mdot
.51621 .52398 Mdot
.51719 .54545 Mdot
.49551 .56927 Mdot
.50219 .51535 Mdot
.48345 .55615 Mdot
.52104 .49081 Mdot
.49088 .51855 Mdot
.48147 .47898 Mdot
.51255 .55696 Mdot
.47248 .42743 Mdot
.46654 .54898 Mdot
.52605 .54284 Mdot
.49562 .50804 Mdot
.46947 .48316 Mdot
.47629 .53117 Mdot
.52413 .5121 Mdot
.43293 .54029 Mdot
.4832 .49046 Mdot
.4416 .48202 Mdot
.52016 .59484 Mdot
.48405 .49761 Mdot
.51639 .5023 Mdot
.45272 .46974 Mdot
.46156 .48558 Mdot
.51993 .45189 Mdot
.56307 .495 Mdot
.373 .52847 Mdot
.44269 .55482 Mdot
.50159 .44041 Mdot
.447 .42348 Mdot
.4467 .54577 Mdot
.44837 .58363 Mdot
.54587 .534 Mdot
.52631 .59197 Mdot
.49384 .4976 Mdot
.54294 .48424 Mdot
.55146 .52132 Mdot
.54054 .52255 Mdot
.46941 .49044 Mdot
.46851 .52664 Mdot
.56455 .4606 Mdot
.49924 .44066 Mdot
.44219 .48291 Mdot
.56081 .51935 Mdot
.47353 .57339 Mdot
.50789 .56761 Mdot
.40414 .44024 Mdot
.48932 .51801 Mdot
.49725 .47377 Mdot
.41159 .53022 Mdot
.55863 .48847 Mdot
.48796 .51466 Mdot
.45923 .52181 Mdot
.55637 .51096 Mdot
.42185 .43519 Mdot
.50253 .39478 Mdot
.49139 .45443 Mdot
.51913 .54035 Mdot
.51969 .48929 Mdot
.55166 .43628 Mdot
.52388 .45907 Mdot
.55715 .5166 Mdot
.55902 .51307 Mdot
.50598 .56422 Mdot
.44245 .50153 Mdot
.48177 .56734 Mdot
.49799 .4716 Mdot
.44257 .4852 Mdot
.55983 .51892 Mdot
.49336 .53422 Mdot
.49579 .4717 Mdot
.45417 .47255 Mdot
.4714 .55386 Mdot
.53399 .47405 Mdot
.55132 .52739 Mdot
.49961 .46198 Mdot
.54811 .48832 Mdot
.49276 .48484 Mdot
.52238 .48627 Mdot
.47284 .4866 Mdot
.45288 .53427 Mdot
.47408 .58713 Mdot
.4548 .44676 Mdot
.51038 .43879 Mdot
.49415 .5583 Mdot
.47837 .50864 Mdot
.46389 .48421 Mdot
.52485 .511 Mdot
.41151 .47418 Mdot
.51223 .48897 Mdot
.48311 .58316 Mdot
.46778 .48861 Mdot
.49655 .47496 Mdot
.53801 .43236 Mdot
.52828 .50243 Mdot
.40967 .49398 Mdot
.483 .51751 Mdot
.46415 .54189 Mdot
.45511 .44289 Mdot
.55489 .42825 Mdot
.51851 .52186 Mdot
.41408 .52759 Mdot
.53135 .52759 Mdot
.54441 .44793 Mdot
.49216 .48121 Mdot
.52628 .51893 Mdot
.48944 .49883 Mdot
.46209 .44738 Mdot
.53794 .52402 Mdot
.49027 .52988 Mdot
.4974 .51095 Mdot
.44212 .47706 Mdot
.45309 .57875 Mdot
.55 .53867 Mdot
.5122 .55567 Mdot
.50597 .56364 Mdot
.53015 .54 Mdot
.51094 .51357 Mdot
.45505 .52609 Mdot
.54329 .5137 Mdot
.46429 .47215 Mdot
.56534 .45449 Mdot
.47603 .57342 Mdot
.44588 .53127 Mdot
.55382 .58496 Mdot
.49633 .48642 Mdot
.44659 .4728 Mdot
.53392 .52944 Mdot
.51933 .4905 Mdot
.49192 .52864 Mdot
.41908 .5394 Mdot
.49258 .48165 Mdot
.58054 .48245 Mdot
.50459 .4868 Mdot
.52894 .55032 Mdot
.52651 .52521 Mdot
.41091 .44761 Mdot
.53065 .48398 Mdot
.44739 .49814 Mdot
.60054 .55127 Mdot
.54539 .51918 Mdot
.51823 .46703 Mdot
.53 .46883 Mdot
.48287 .563 Mdot
.5182 .48829 Mdot
.4763 .49587 Mdot
.48627 .52317 Mdot
.51207 .49185 Mdot
.51755 .54525 Mdot
.48646 .43741 Mdot
.44564 .50194 Mdot
.48189 .52336 Mdot
.40842 .47464 Mdot
.54206 .50101 Mdot
.47472 .52552 Mdot
.50499 .54364 Mdot
.5198 .45134 Mdot
.41438 .49146 Mdot
.47711 .4973 Mdot
.50479 .46532 Mdot
.52112 .54262 Mdot
.49093 .55462 Mdot
.47768 .48957 Mdot
.50632 .49054 Mdot
.43816 .44795 Mdot
.4809 .44878 Mdot
.54185 .51087 Mdot
.58064 .56009 Mdot
.49777 .4405 Mdot
.50583 .52108 Mdot
.49946 .52741 Mdot
.52589 .54397 Mdot
.49276 .51998 Mdot
.45981 .43918 Mdot
.56739 .40634 Mdot
.50613 .57446 Mdot
.53062 .50727 Mdot
.47811 .49088 Mdot
.59062 .47957 Mdot
.44628 .50884 Mdot
.50161 .51814 Mdot
.49806 .50836 Mdot
.53566 .58679 Mdot
.5424 .48361 Mdot
.46653 .48943 Mdot
.5082 .54405 Mdot
.4442 .50735 Mdot
.41127 .5023 Mdot
.41001 .50871 Mdot
.53587 .48033 Mdot
.5767 .48512 Mdot
.51819 .49945 Mdot
.53954 .52682 Mdot
.54426 .57344 Mdot
.5432 .52511 Mdot
.45732 .48828 Mdot
.53727 .53434 Mdot
.4895 .50565 Mdot
.51698 .54375 Mdot
.43036 .47753 Mdot
.4147 .50039 Mdot
.48478 .49283 Mdot
.58002 .42398 Mdot
.57083 .41456 Mdot
.54782 .49166 Mdot
.48954 .50071 Mdot
.49216 .48788 Mdot
.51516 .46855 Mdot
.53396 .49258 Mdot
.48131 .46711 Mdot
.41477 .44801 Mdot
.51703 .49687 Mdot
.47739 .54968 Mdot
.51132 .49089 Mdot
.53352 .52787 Mdot
.48799 .49867 Mdot
.4396 .5143 Mdot
.5468 .45181 Mdot
.5574 .46999 Mdot
.47258 .55727 Mdot
.49256 .53245 Mdot
.52553 .3977 Mdot
.45793 .44331 Mdot
.44286 .48353 Mdot
.54373 .49203 Mdot
.55013 .47617 Mdot
.56225 .48857 Mdot
.51022 .55045 Mdot
.5154 .54284 Mdot
.56014 .45825 Mdot
.44821 .47904 Mdot
.53974 .50674 Mdot
.43923 .44805 Mdot
.53073 .52632 Mdot
.47258 .4991 Mdot
.50975 .55563 Mdot
.53418 .4759 Mdot
.50987 .55514 Mdot
.54216 .48859 Mdot
.46269 .48671 Mdot
.54388 .48824 Mdot
.43317 .53378 Mdot
.47167 .47994 Mdot
.44154 .49164 Mdot
.45613 .50057 Mdot
.48124 .57374 Mdot
.50332 .58212 Mdot
.48367 .48348 Mdot
.44147 .49467 Mdot
.54391 .46346 Mdot
.35811 .45184 Mdot
.50461 .49568 Mdot
.48105 .51181 Mdot
.5346 .52151 Mdot
.52623 .51423 Mdot
.5108 .48845 Mdot
.42538 .53098 Mdot
.49277 .52091 Mdot
.48547 .55757 Mdot
.53041 .40151 Mdot
.47609 .48664 Mdot
.50109 .52554 Mdot
.49756 .56521 Mdot
.55692 .4427 Mdot
.40875 .44298 Mdot
.50847 .49113 Mdot
.51095 .55957 Mdot
.50984 .42996 Mdot
.41945 .49536 Mdot
.55668 .46218 Mdot
.52009 .429 Mdot
.54639 .47044 Mdot
.48589 .43976 Mdot
.43318 .45098 Mdot
.51791 .51548 Mdot
.50781 .44303 Mdot
.4446 .48273 Mdot
.52344 .51381 Mdot
.50063 .45557 Mdot
.51204 .48007 Mdot
.42477 .55431 Mdot
.45217 .47032 Mdot
.48328 .58376 Mdot
.45816 .49557 Mdot
.48549 .44057 Mdot
.48821 .51376 Mdot
.511 .481 Mdot
.48061 .49546 Mdot
.452 .59324 Mdot
.56452 .40461 Mdot
.48577 .48392 Mdot
.4758 .53644 Mdot
.53289 .43557 Mdot
.46047 .48531 Mdot
.47315 .49326 Mdot
.44087 .54595 Mdot
.48533 .48356 Mdot
.55628 .50374 Mdot
.48739 .51525 Mdot
.51037 .52784 Mdot
.49033 .51752 Mdot
.47575 .48837 Mdot
.50326 .49109 Mdot
.51078 .43441 Mdot
.45333 .53712 Mdot
.49398 .50604 Mdot
.48569 .4747 Mdot
.50836 .52732 Mdot
.52521 .55061 Mdot
.45449 .53555 Mdot
.50306 .43273 Mdot
.5579 .51368 Mdot
.44743 .47171 Mdot
.56011 .44962 Mdot
.47689 .43799 Mdot
.49471 .43674 Mdot
.4591 .61171 Mdot
.44456 .50425 Mdot
.42603 .5537 Mdot
.52484 .50823 Mdot
.48541 .5966 Mdot
.51751 .52133 Mdot
.50971 .49398 Mdot
.4709 .57178 Mdot
.5049 .44628 Mdot
.44311 .47908 Mdot
.45155 .47067 Mdot
.5119 .51167 Mdot
.48636 .57224 Mdot
.54367 .54416 Mdot
.44125 .45763 Mdot
.54723 .48256 Mdot
.51947 .50446 Mdot
.46096 .48544 Mdot
.5143 .54362 Mdot
.51609 .46687 Mdot
.46157 .45378 Mdot
.51726 .54901 Mdot
.55122 .44463 Mdot
.56112 .41126 Mdot
.5374 .49358 Mdot
.49868 .53321 Mdot
.48209 .4413 Mdot
.44698 .51639 Mdot
.53648 .51162 Mdot
.42744 .46093 Mdot
.5242 .51813 Mdot
.52576 .54492 Mdot
.51858 .46957 Mdot
.48404 .5325 Mdot
.49437 .46177 Mdot
.41692 .44178 Mdot
.52219 .54334 Mdot
.60742 .51919 Mdot
.49848 .53158 Mdot
.503 .4765 Mdot
.55601 .52117 Mdot
.47221 .55994 Mdot
.51253 .445 Mdot
.50852 .54272 Mdot
.49916 .47967 Mdot
.5556 .51047 Mdot
.54113 .49162 Mdot
.4117 .47321 Mdot
.51893 .52164 Mdot
.55619 .43317 Mdot
.5214 .51903 Mdot
.51811 .43117 Mdot
.52871 .54083 Mdot
.48206 .46627 Mdot
.46464 .49427 Mdot
.50727 .47808 Mdot
.53784 .46206 Mdot
.44135 .48582 Mdot
.48333 .49581 Mdot
.52884 .50649 Mdot
.55045 .40658 Mdot
.54239 .43536 Mdot
.5314 .45838 Mdot
.49423 .43247 Mdot
.4911 .52183 Mdot
.54156 .47816 Mdot
.52214 .4708 Mdot
.48414 .48354 Mdot
.57392 .48189 Mdot
.47601 .46214 Mdot
.47412 .55902 Mdot
.47098 .4893 Mdot
.49518 .48676 Mdot
.51491 .54278 Mdot
.45339 .52206 Mdot
.49158 .44659 Mdot
.53082 .50977 Mdot
.55391 .53927 Mdot
.49979 .44285 Mdot
.47372 .49461 Mdot
.47042 .50347 Mdot
.48142 .41965 Mdot
.56562 .41737 Mdot
.50896 .55794 Mdot
.4413 .47883 Mdot
.45729 .52819 Mdot
.47135 .49337 Mdot
.46149 .4759 Mdot
.5429 .48041 Mdot
.40822 .48585 Mdot
.50581 .56746 Mdot
.55916 .47223 Mdot
.44577 .48244 Mdot
.52126 .49097 Mdot
.48801 .49963 Mdot
.43829 .48675 Mdot
.51571 .50409 Mdot
.49707 .51892 Mdot
.50828 .55981 Mdot
.52161 .49078 Mdot
.49254 .50018 Mdot
.51398 .55515 Mdot
.44201 .44818 Mdot
.50642 .56384 Mdot
.54103 .49314 Mdot
.42025 .45809 Mdot
.54078 .50786 Mdot
.54109 .50153 Mdot
.43314 .45685 Mdot
.55387 .53778 Mdot
.43559 .5552 Mdot
.48352 .43762 Mdot
.53712 .46528 Mdot
.51341 .51183 Mdot
.51951 .52343 Mdot
.47801 .50237 Mdot
.49309 .48116 Mdot
.46827 .58913 Mdot
.58294 .48579 Mdot
.52065 .59171 Mdot
.49229 .46672 Mdot
.5069 .51384 Mdot
.47308 .56691 Mdot
.54084 .52101 Mdot
.47316 .48104 Mdot
.49344 .53196 Mdot
.57401 .4907 Mdot
.49909 .60365 Mdot
.45383 .50198 Mdot
.49306 .48902 Mdot
.54082 .54088 Mdot
.54389 .44632 Mdot
.48766 .51272 Mdot
.41256 .47971 Mdot
.50944 .52134 Mdot
.51717 .47122 Mdot
.52905 .49764 Mdot
.53347 .49842 Mdot
.50075 .44293 Mdot
.52963 .48397 Mdot
.54394 .46644 Mdot
.5396 .50847 Mdot
.47323 .43839 Mdot
.51731 .51594 Mdot
.56703 .50886 Mdot
.45636 .47911 Mdot
.52783 .52648 Mdot
.47119 .47091 Mdot
.48726 .559 Mdot
.48343 .52897 Mdot
.5257 .49175 Mdot
.50403 .52573 Mdot
.54276 .49694 Mdot
.50622 .48638 Mdot
.5188 .5558 Mdot
.59671 .46006 Mdot
.44735 .44537 Mdot
.54235 .55406 Mdot
.47782 .49626 Mdot
.50584 .49423 Mdot
.47245 .54687 Mdot
.50465 .55807 Mdot
.51515 .40245 Mdot
.52338 .51497 Mdot
.52245 .52702 Mdot
.50912 .48477 Mdot
.42338 .44641 Mdot
.51466 .51747 Mdot
.53626 .49109 Mdot
.45812 .5219 Mdot
.40209 .431 Mdot
.54213 .47712 Mdot
.51461 .50143 Mdot
.57803 .58708 Mdot
.47782 .48995 Mdot
.59662 .51541 Mdot
.55273 .47808 Mdot
.54716 .4054 Mdot
.47039 .59823 Mdot
.55132 .49068 Mdot
.44375 .49547 Mdot
.52176 .51597 Mdot
.46142 .48725 Mdot
.48765 .4415 Mdot
.44997 .4689 Mdot
.4284 .50194 Mdot
.45426 .47082 Mdot
.46355 .55164 Mdot
.47957 .43883 Mdot
.52479 .49796 Mdot
.40786 .50128 Mdot
.53945 .47475 Mdot
.52959 .51875 Mdot
.43111 .45301 Mdot
.52948 .54518 Mdot
.48723 .52462 Mdot
.59605 .51843 Mdot
.44107 .48282 Mdot
.50116 .55321 Mdot
.51186 .50883 Mdot
.48039 .53885 Mdot
.49218 .48654 Mdot
.48344 .49539 Mdot
.46045 .46329 Mdot
.51851 .56033 Mdot
.53415 .4868 Mdot
.4895 .51832 Mdot
.52426 .55444 Mdot
.4663 .54316 Mdot
.47863 .45675 Mdot
.44936 .59551 Mdot
.4907 .53254 Mdot
.58011 .52523 Mdot
.49437 .53534 Mdot
.34525 .45829 Mdot
.51209 .50694 Mdot
.49387 .48451 Mdot
.40951 .47654 Mdot
.46888 .56631 Mdot
.49479 .51185 Mdot
.54067 .52607 Mdot
.55993 .51971 Mdot
.43797 .47162 Mdot
.45768 .56618 Mdot
.51154 .45746 Mdot
.53469 .50269 Mdot
.48867 .52707 Mdot
.56132 .50959 Mdot
.50688 .44362 Mdot
.49749 .52756 Mdot
.4856 .46958 Mdot
.56389 .45929 Mdot
.55166 .52415 Mdot
.46282 .48682 Mdot
.56229 .50831 Mdot
.53262 .53471 Mdot
.49714 .41016 Mdot
.41701 .53595 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo09oooooo0_l00005ooooo`;o
0000Woooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo09oooooo0_l00003ooooo`Go0000W_ooool000?ooooo
00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool3o`00093ooooo0_l0000Booooo`;o
000000?oooooo`000?l00000W_ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04
odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0T?ooool2o`00017ooooo0_l00003oooo
o`;o00001_ooool2o`0009Gooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01?oM
gMgoEEEEooooool00007ooooo`03o`000?oooooooooo09?ooooo0_l0000>ooooo`;o00000oooool2
o`0000Cooooo1?l000001?oooooo0000o`000?l0002Aooooo`000oooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`2Cooooo`;o00001ooo
ool4o`0000gooooo1?l00002ooooo`?o0000TOooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0W?ooool4o`0000gooooo0_l0
0003ooooo`?o0000T_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0
003ooooo00Kooooo00?o0000ooooooooool0S?ooool2o`0000Gooooo0_l0000Mooooo`Go0000T?oo
ool001kooooo00?o0000ooooooooool0S?ooool2o`0000Gooooo0_l00003ooooo`;o00006Oooool4
o`00093ooooo000Nooooo`03o`000?oooooooooo08Cooooo0_l0000Booooo`;o00006_ooool2o`00
097ooooo000Nooooo`03o`000?oooooooooo08Cooooo1?l00005ooooo`;o00005Oooool2o`0000oo
oooo0_l000000ooooooo0000o`00002=ooooo`007_ooool00ol0003oooooooooo`26ooooo`;o0000
1Oooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000003Oooool2o`0000[ooooo
0_l00003ooooo`;o000000?oooooo`000?l00000SOooool001kooooo00?o0000ooooooooool0Oooo
ool2o`0000oooooo1?l000000ooooooo0000o`00000;ooooo`Go00001_ooool2o`000004ooooool0
003o0000o`0009Cooooo000Nooooo`03o`000?oooooooooo07oooooo0_l0000Looooo`[o000000Co
ooooo`000?l0003ooooo1?l00002ooooo`;o0000U?ooool001kooooo00?o0000ooooooooool0QOoo
ool2o`00013ooooo1Ol000000ooooooo0000o`000005o`0000Cooooo2ol00002ooooo`;o0000T?oo
ool001kooooo00?o0000ooooooooool0Ooooool2o`0000Cooooo0_l0000:ooooo`;o000000?ooooo
o`000?l000001_l000000ooooooo0000o`000002o`000003ooooool0003o000000Cooooo2Ol00004
ooooo`;o0000T?ooool001kooooo00?o0000ooooooooool0Ooooool6o`0000_ooooo0ol000000ooo
oooo0000o`00000>o`0000Cooooo1_l000000ooooooo0000o`000002o`0009Cooooo000Nooooo`03
o`000?oooooooooo087ooooo1?l000000ooooooo0000o`000005ooooo`Oo00000oooool>o`0000?o
oooo0ol000000ooooooo0000o`000006o`0009?ooooo000Nooooo`03o`000?oooooooooo087ooooo
1?l000000ooooooo0000o`000002ooooo`[o00001?ooool2o`0000;ooooo1_l000000ooooooo0000
o`000004ooooo`;o00000_ooool4o`000003ooooool0003o000009?ooooo000Nooooo`;o0000LOoo
ool2o`0000oooooo1?l00003ooooo`So000000?oooooo`000?l000000_l00003ooooo`;o00001_oo
ool2o`0000?ooooo0_l00006ooooo`?o00000_ooool3o`0009;ooooo000Nooooo`03o`000?oooooo
oooo073ooooo0_l0000?ooooo`;o00001Oooool3o`0000Cooooo0_l000001?oooooo0000o`000?l0
0007ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Oooooo0_l00003ooooo`?o0000TOoo
ool001kooooo00?o0000ooooooooool0J?ooool2o`0000;ooooo0_l0000Gooooo`;o000000?ooooo
o`000?l000000ol00002ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000003
ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o000000?oooooo`000?l000001ooo
ool6o`0008oooooo000Nooooo`03o`000?oooooooooo06Sooooo0_l00002ooooo`;o00005oooool8
o`0000Oooooo0_l000000ooooooo0000o`000004ooooo`?o00000_ooool2o`0000;ooooo0_l00000
0ooooooo0000o`000002o`0000?ooooo1Ol000001?oooooo0000o`000?l00005ooooo`;o0000Qooo
ool001kooooo00?o0000ooooooooool0Q?ooool2o`000003ooooool0003o000000Oooooo1?l00003
ooooo`?o000000?oooooo`000?l000001Ol00007ooooo`Ko000000?oooooo`000?l000001?l00000
0ooooooo0000o`000005ooooo`;o0000Qoooool001kooooo00?o0000ooooooooool0Q?ooool2o`00
00?ooooo3?l00003ooooo`[o000000?oooooo`000?l000000_l000000ooooooo0000o`000006o`00
00Cooooo0_l00002ooooo`;o0000SOooool001kooooo00?o0000ooooooooool0ROooool>o`000003
ooooool0003o000000Ko00000oooool=o`000003ooooool0003o000000Gooooo0_l0002=ooooo`00
7_ooool00ol0003oooooooooo`21ooooo`?o00001_ooool=o`000003ooooool0003o000000Ko0000
1?ooool4o`000003ooooool0003o000000Go000000?oooooo`000?l000001?l0002@ooooo`007_oo
ool00ol0003oooooooooo`21ooooo`?o00001?ooool3o`000003ooooool0003o000000Oo00000ooo
ool;o`0000Kooooo3_l0002@ooooo`007_ooool00ol0003oooooooooo`21ooooo`?o00001?oooolN
o`0000?ooooo2Ol000000ooooooo0000o`000002o`0000Gooooo0_l00029ooooo`007_ooool00ol0
003oooooooooo`1oooooo`Go00000_ooool2o`0000?ooooo1ol000000ooooooo0000o`00000Lo`00
0005ooooool0003o0000o`000?ooool00_l000001?oooooo0000o`000?ooool2o`0008Wooooo000N
ooooo`03o`000?oooooooooo07oooooo1_l000000ooooooo0000o`000002ooooo`Ko00000_oooolO
o`000003ooooool0003o000000Oo0000S?ooool001kooooo00?o0000ooooooooool0POooool4o`00
00Gooooo7ol000000ooooooo0000o`000005o`000003ooooool0003o000000;o000000?oooooo`00
0?l000000_l0002<ooooo`007_ooool00ol0003oooooooooo`23ooooo`?o00001Oooool4o`000005
ooooool0003o0000o`000?ooool08_l000000ooooooo0000o`00002>ooooo`007_ooool00ol0003o
ooooooooo`21ooooo`Go00001Oooool4o`000003ooooool0003o000002Co000000?oooooo`000?l0
0000S_ooool001kooooo00?o0000ooooooooool0POooool2o`000003ooooool0003o000000?ooooo
1_l00002ooooo`Co000000?oooooo`000?l000001_l00002ooooo`ko00000_ooool5o`0009;ooooo
000Nooooo`;o0000POooool;o`000003ooooool0003o000000Co00001?ooool9o`000004ooooool0
003o0000ooooo`_o00000oooool4o`0009;ooooo000Nooooo`03o`000?oooooooooo083ooooo2ol0
00000ooooooo0000o`000004o`0000?ooooo1?l00002ooooo`Co000000Coooooo`000?l0003ooooo
2ol00003ooooo`;o00001Oooool2o`0008gooooo000Nooooo`03o`000?oooooooooo087ooooo0_l0
0009ooooo`?o00001OoooolFo`000004ooooool0003o0000o`0000?ooooo1Ol00002ooooo`;o0000
SOooool001kooooo00?o0000ooooooooool0POooool2o`0000Kooooo0_l000001?oooooo0000o`00
0?l00005ooooo`;o000000?oooooo`000?l000002?l000000ooooooo0000o`00000:o`0000?ooooo
1Ol00002ooooo`;o0000SOooool001kooooo00?o0000ooooooooool0ROooool6o`0000Sooooo2Ol0
00000ooooooo0000o`00000<o`0000;ooooo0ol00004ooooo`;o0000SOooool001kooooo00?o0000
ooooooooool0Roooool5o`0000Wooooo4?l000000ooooooo0000o`000008o`0000?ooooo0_l00005
ooooo`;o0000Qoooool001kooooo00?o0000ooooooooool0POooool2o`0000[ooooo1?l00008oooo
oago000000?oooooo`000?l000001Oooool2o`000003ooooool0003o000008Cooooo000Nooooo`03
o`000?oooooooooo087ooooo0_l0000:ooooo`Ko00001_oooolMo`0000?ooooo0_l00003ooooo`;o
000000?oooooo`000?l00000Q?ooool001kooooo00?o0000ooooooooool0Soooool9o`000003oooo
ool0003o000001So00001Oooool3o`0008cooooo000Nooooo`03o`000?oooooooooo07Gooooo0_l0
000;ooooo`?o00002oooool8o`000003ooooool0003o000000Wo000000?oooooo`000?l000002_l0
00000ooooooo0000o`000004ooooo`;o0000SOooool001kooooo00?o0000ooooooooool0MOooool2
o`0000_ooooo0ol000000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l000000ol00002
ooooo`Wo00000_ooool2o`0000Gooooo1ol00002ooooo`;o0000Toooool001kooooo00?o0000oooo
ooooool0Poooool2o`000004ooooool0003o0000ooooo`?o000000?oooooo`000?l000000ol00005
ooooo`Wo00002Oooool7o`0000;ooooo0_l0002Cooooo`007_ooool00ol0003oooooooooo`23oooo
o`?o00000oooool3o`0000?ooooo0ol00002ooooo`;o000000Coooooo`000?l0003o00000_ooool5
o`0000Gooooo0_l000000ooooooo0000o`000007o`000003ooooool0003o000009;ooooo000Noooo
o`03o`000?oooooooooo08Cooooo0_l00003ooooo`?o00000oooool2o`0000;ooooo1ol00003oooo
o`Oo000000?oooooo`000?l000000ol00002ooooo`;o000000Goooooo`000?l0003o0000ooooo`02
o`0009;ooooo000Nooooo`03o`000?oooooooooo08Wooooo0_l00002ooooo`;o00001?ooool5o`00
00Sooooo2_l00002ooooo`?o0000V?ooool001kooooo00?o0000ooooooooool0R?ooool2o`000003
ooooool0003o000000;o00000oooool5o`000003ooooool0003o000000Kooooo2ol00002ooooo`;o
0000V?ooool001kooooo0_l00029ooooo`;o000000?oooooo`000?l000000_l00003ooooo`So0000
2?ooool9o`0001Cooooo0_l00026ooooo`007_ooool00ol0003oooooooooo`26ooooo`;o00001?oo
ool2o`0000Gooooo1_l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000Ko00000_oo
ool2o`00017ooooo0_l00026ooooo`007_ooool00ol0003oooooooooo`26ooooo`;o000000Cooooo
o`000?l0003ooooo0_l00007ooooo`?o000000?oooooo`000?l000000_l00002ooooo`[o00000ooo
ool2o`0009Wooooo000Nooooo`03o`000?oooooooooo08Wooooo0ol00008ooooo`Co000000Gooooo
o`000?l0003o0000ooooo`02o`000003ooooool0003o000000Go00004_ooool2o`0008cooooo000N
ooooo`03o`000?oooooooooo08[ooooo0_l00008ooooo`Co000000Goooooo`000?l0003o0000oooo
o`02o`000003ooooool0003o000000Go00004_ooool2o`0008cooooo000Nooooo`03o`000?oooooo
oooo097ooooo0_l000000ooooooo0000o`00000>o`0000cooooo0_l0002Eooooo`007_ooool00ol0
003oooooooooo`2Aooooo`;o000000?oooooo`000?l000003Ol00006ooooo`;o00001Oooool2o`00
09Gooooo000Nooooo`03o`000?oooooooooo09Cooooo1Ol000001?oooooo0000o`000?ooool6o`00
00Kooooo0ol000001?oooooo0000o`000?l0002Gooooo`007_ooool00ol0003oooooooooo`27oooo
o`Co00002_ooool7o`0000?ooooo0ol00005ooooo`Go000000Coooooo`000?l0003o0000Uoooool0
01kooooo00?o0000ooooooooool0Qoooool4o`0000Cooooo0_l00005ooooo`Co00001_ooool2o`00
00Gooooo0ol00007ooooo`;o0000U?ooool001kooooo00?o0000ooooooooool0Soooool2o`0000Go
oooo0_l00008ooooo`;o00003oooool2o`0009Cooooo000Nooooo`03o`000?oooooooooo08[ooooo
0_l00002ooooo`;o00002Oooool2o`0000;ooooo0_l000000ooooooo0000o`000008ooooo`Co0000
0_ooool3o`000003ooooool0003o0000097ooooo000Nooooo`03o`000?oooooooooo08[ooooo0_l0
0002ooooo`;o00001_ooool2o`000003ooooool0003o000000;ooooo0_l00009ooooo`Ko00000_oo
ool3o`000003ooooool0003o000000;ooooo0_l0002=ooooo`007_ooool00ol0003oooooooooo`2D
ooooo`Co00003Oooool7o`0000cooooo0_l0002=ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003ooooooooo
o`2?ooooo`;o00000oooool4o`0000gooooo1?l0002Nooooo`000oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`2=ooooo`Co00002Oooool2o`0000Wooooo0_l0002Pooooo`000oooool01Ol@413ooooooooo
oooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000SOooool3o`0000Go
oooo1?l000000ooooooo0000o`00002[ooooo`000oooool01Ol0003ooooooooooooooooo000000_o
oooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo09Gooooo1?l00005oooo
o`;o0000Yoooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000
oa0@4?o<c<`01_ooool00ol0003oooooooooo`2Nooooo`;o0000Yoooool000?ooooo00Go410@oooo
oooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0oooooom8
ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool0
0ol0003oooooooooo`2Aooooo`;o0000]?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0TOooool2o`000;Cooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`00
0?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006
ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0oooo
oom8ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooooooooooo
o`000006ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo
00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0
003oooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@
413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@
413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Dooooo`Co000000?o410@oooo
ooooool00oooool00ol0003oooooooooo`3oooooodSooooo000Fooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0oooooom8ooooo`005_ooool00ol0003oooooooooo`05ooooo`?o0000
oooooom8ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooo
oooo0?ooooooD?ooool001Kooooo00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003o
ooooooooo`3ooooooe3ooooo000Dooooo`03oeEEEOmVIVKo00000?ooooooD_ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.52712 .4603 Mdot
.53518 .52443 Mdot
.46995 .57445 Mdot
.52016 .53175 Mdot
.49556 .52482 Mdot
.48871 .43357 Mdot
.58554 .40786 Mdot
.53587 .54057 Mdot
.4462 .41623 Mdot
.56857 .50412 Mdot
.5506 .4666 Mdot
.52398 .4924 Mdot
.45772 .47066 Mdot
.4407 .52632 Mdot
.47619 .39832 Mdot
.48332 .52911 Mdot
.54535 .50319 Mdot
.42666 .44998 Mdot
.55798 .44579 Mdot
.44248 .48348 Mdot
.54746 .49771 Mdot
.46515 .52188 Mdot
.49296 .53092 Mdot
.44681 .45001 Mdot
.55117 .51659 Mdot
.50851 .48725 Mdot
.56057 .49958 Mdot
.50782 .43415 Mdot
.49812 .51757 Mdot
.47541 .4286 Mdot
.46037 .45736 Mdot
.53613 .52974 Mdot
.49066 .49196 Mdot
.47062 .56276 Mdot
.46863 .44334 Mdot
.45885 .55825 Mdot
.49605 .4851 Mdot
.50283 .54237 Mdot
.48934 .53298 Mdot
.51222 .48157 Mdot
.48325 .51024 Mdot
.44066 .4929 Mdot
.5078 .46891 Mdot
.51213 .5032 Mdot
.53585 .52917 Mdot
.47453 .47902 Mdot
.50162 .56957 Mdot
.44432 .47263 Mdot
.44285 .48704 Mdot
.48515 .56022 Mdot
.48833 .52583 Mdot
.45109 .59919 Mdot
.50149 .51874 Mdot
.49873 .5333 Mdot
.49593 .55003 Mdot
.48786 .47794 Mdot
.51605 .47914 Mdot
.52421 .56053 Mdot
.53109 .54053 Mdot
.50321 .472 Mdot
.46764 .4759 Mdot
.4823 .48314 Mdot
.45829 .54704 Mdot
.48372 .52951 Mdot
.48736 .51397 Mdot
.41135 .42804 Mdot
.5149 .4647 Mdot
.47666 .47975 Mdot
.46274 .47552 Mdot
.48296 .52803 Mdot
.57578 .41131 Mdot
.51411 .5323 Mdot
.48635 .46916 Mdot
.51297 .52116 Mdot
.45739 .43928 Mdot
.57207 .49057 Mdot
.46586 .47502 Mdot
.42444 .44756 Mdot
.57475 .44793 Mdot
.52823 .452 Mdot
.48497 .5394 Mdot
.54132 .53938 Mdot
.54413 .51356 Mdot
.47826 .48884 Mdot
.46311 .55168 Mdot
.50843 .52028 Mdot
.50175 .56162 Mdot
.4848 .48239 Mdot
.50956 .47919 Mdot
.40853 .54118 Mdot
.49453 .5117 Mdot
.47438 .48483 Mdot
.49676 .55915 Mdot
.43095 .50599 Mdot
.53033 .53168 Mdot
.46599 .48329 Mdot
.4854 .48153 Mdot
.46547 .45672 Mdot
.52122 .57291 Mdot
.53087 .49182 Mdot
.50956 .55973 Mdot
.48818 .55831 Mdot
.52111 .539 Mdot
.40164 .45693 Mdot
.46829 .41622 Mdot
.48816 .48932 Mdot
.34787 .44339 Mdot
.48964 .51213 Mdot
.53261 .47888 Mdot
.47449 .48748 Mdot
.47019 .44282 Mdot
.51652 .53273 Mdot
.52661 .51721 Mdot
.58144 .50714 Mdot
.52449 .46876 Mdot
.42576 .56618 Mdot
.55466 .55697 Mdot
.50211 .4286 Mdot
.43684 .55876 Mdot
.50129 .56122 Mdot
.44201 .44585 Mdot
.51204 .49059 Mdot
.55887 .51833 Mdot
.44854 .4645 Mdot
.54197 .51057 Mdot
.57489 .52901 Mdot
.45773 .43705 Mdot
.50985 .48938 Mdot
.51028 .49643 Mdot
.49069 .53911 Mdot
.47438 .43487 Mdot
.55048 .4894 Mdot
.51499 .61037 Mdot
.44723 .52125 Mdot
.52195 .52618 Mdot
.52015 .60824 Mdot
.57696 .43716 Mdot
.50316 .51049 Mdot
.47202 .46863 Mdot
.52231 .51036 Mdot
.49171 .51201 Mdot
.53538 .45888 Mdot
.50206 .49274 Mdot
.51064 .52873 Mdot
.48669 .49449 Mdot
.47368 .48738 Mdot
.52118 .44833 Mdot
.45467 .49784 Mdot
.51799 .46704 Mdot
.44745 .46439 Mdot
.45194 .52935 Mdot
.48907 .43048 Mdot
.49346 .51695 Mdot
.41997 .47496 Mdot
.50865 .43698 Mdot
.48338 .52941 Mdot
.48018 .48397 Mdot
.46008 .58259 Mdot
.4656 .4752 Mdot
.4907 .50144 Mdot
.52163 .39533 Mdot
.45259 .48001 Mdot
.42101 .45255 Mdot
.50249 .5518 Mdot
.51345 .48107 Mdot
.53264 .50135 Mdot
.48994 .41285 Mdot
.46696 .5172 Mdot
.44505 .51048 Mdot
.51162 .53564 Mdot
.51926 .43944 Mdot
.45445 .45509 Mdot
.54012 .51276 Mdot
.50591 .47823 Mdot
.48785 .41431 Mdot
.49433 .48285 Mdot
.47272 .49739 Mdot
.48907 .50349 Mdot
.53161 .58287 Mdot
.44141 .48123 Mdot
.51564 .52996 Mdot
.47314 .48409 Mdot
.50941 .51496 Mdot
.50126 .51965 Mdot
.44314 .50155 Mdot
.52629 .49716 Mdot
.49228 .57321 Mdot
.46747 .47509 Mdot
.40358 .45962 Mdot
.51986 .55539 Mdot
.5184 .50465 Mdot
.48688 .53201 Mdot
.44375 .44358 Mdot
.49193 .51516 Mdot
.50161 .5363 Mdot
.48505 .50882 Mdot
.5253 .58033 Mdot
.50071 .49702 Mdot
.48423 .51486 Mdot
.52406 .52945 Mdot
.53729 .49843 Mdot
.47206 .47742 Mdot
.45456 .44213 Mdot
.45166 .50649 Mdot
.49881 .55234 Mdot
.54154 .50853 Mdot
.55381 .48759 Mdot
.52264 .48395 Mdot
.48087 .57194 Mdot
.49132 .51807 Mdot
.5373 .52453 Mdot
.49885 .48729 Mdot
.49022 .47468 Mdot
.49321 .45257 Mdot
.51253 .49059 Mdot
.4967 .56496 Mdot
.47242 .48023 Mdot
.46859 .47469 Mdot
.54298 .46658 Mdot
.49172 .50827 Mdot
.48067 .53142 Mdot
.5067 .60722 Mdot
.47321 .48501 Mdot
.46579 .56505 Mdot
.55763 .53978 Mdot
.5414 .53563 Mdot
.53317 .53628 Mdot
.56705 .50774 Mdot
.48251 .57309 Mdot
.55826 .4678 Mdot
.50951 .56139 Mdot
.50086 .48846 Mdot
.57782 .5138 Mdot
.48405 .48565 Mdot
.50093 .48243 Mdot
.47017 .4678 Mdot
.57617 .53392 Mdot
.57451 .49734 Mdot
.54704 .4964 Mdot
.52631 .497 Mdot
.56832 .50445 Mdot
.4907 .3921 Mdot
.49696 .44214 Mdot
.56065 .53732 Mdot
.54127 .51788 Mdot
.49108 .54316 Mdot
.57788 .46232 Mdot
.53204 .53709 Mdot
.52189 .55997 Mdot
.56158 .53369 Mdot
.51199 .47358 Mdot
.43497 .51472 Mdot
.54072 .40551 Mdot
.53232 .52639 Mdot
.52271 .51929 Mdot
.52866 .49433 Mdot
.51141 .53023 Mdot
.48446 .47433 Mdot
.46739 .55719 Mdot
.54163 .45118 Mdot
.46831 .51818 Mdot
.48708 .52412 Mdot
.49058 .50099 Mdot
.4859 .4441 Mdot
.44174 .48921 Mdot
.45389 .53589 Mdot
.57268 .51369 Mdot
.4573 .43126 Mdot
.48267 .49287 Mdot
.53273 .59114 Mdot
.52095 .46831 Mdot
.52688 .51667 Mdot
.40226 .45679 Mdot
.52499 .51338 Mdot
.48361 .57458 Mdot
.58144 .43037 Mdot
.4763 .47519 Mdot
.57234 .45098 Mdot
.44657 .47567 Mdot
.57653 .47492 Mdot
.46843 .47146 Mdot
.50571 .48266 Mdot
.41987 .51267 Mdot
.49565 .50166 Mdot
.54949 .55397 Mdot
.43924 .51636 Mdot
.51565 .57336 Mdot
.4906 .53274 Mdot
.54442 .50202 Mdot
.42167 .4711 Mdot
.52298 .48673 Mdot
.46648 .45859 Mdot
.41757 .55487 Mdot
.48587 .45987 Mdot
.53279 .50191 Mdot
.50687 .53465 Mdot
.48173 .43325 Mdot
.44078 .48113 Mdot
.44723 .50602 Mdot
.52107 .53231 Mdot
.50765 .50528 Mdot
.54265 .53514 Mdot
.43718 .40869 Mdot
.47973 .5117 Mdot
.52514 .49037 Mdot
.51886 .53168 Mdot
.56234 .47609 Mdot
.49232 .46416 Mdot
.55445 .51113 Mdot
.44087 .48034 Mdot
.51595 .52749 Mdot
.49448 .49926 Mdot
.56782 .51921 Mdot
.54959 .49449 Mdot
.52785 .52587 Mdot
.51774 .46687 Mdot
.51063 .48106 Mdot
.48011 .48074 Mdot
.48545 .4703 Mdot
.49348 .53539 Mdot
.445 .46995 Mdot
.5427 .47045 Mdot
.54269 .4601 Mdot
.49321 .48143 Mdot
.53081 .44503 Mdot
.4808 .52963 Mdot
.51588 .50349 Mdot
.51124 .4955 Mdot
.49567 .43377 Mdot
.48207 .55452 Mdot
.5082 .44017 Mdot
.43184 .58295 Mdot
.52815 .5156 Mdot
.57209 .49027 Mdot
.47654 .56962 Mdot
.52832 .54385 Mdot
.44948 .51966 Mdot
.51658 .53168 Mdot
.545 .51048 Mdot
.4842 .48327 Mdot
.50527 .46036 Mdot
.52663 .47471 Mdot
.55108 .46396 Mdot
.49885 .4929 Mdot
.45858 .52075 Mdot
.53917 .47679 Mdot
.49693 .50338 Mdot
.52287 .53944 Mdot
.47082 .52038 Mdot
.47835 .48912 Mdot
.52007 .48346 Mdot
.50703 .61077 Mdot
.54399 .5084 Mdot
.48899 .48503 Mdot
.41587 .49254 Mdot
.52993 .49417 Mdot
.43886 .51414 Mdot
.55041 .48815 Mdot
.40792 .56514 Mdot
.48673 .48926 Mdot
.48562 .5168 Mdot
.51107 .46785 Mdot
.53177 .50734 Mdot
.42118 .48325 Mdot
.54675 .48229 Mdot
.42254 .52594 Mdot
.5103 .54129 Mdot
.4645 .51607 Mdot
.58683 .55954 Mdot
.5074 .51879 Mdot
.4908 .50201 Mdot
.49939 .51033 Mdot
.50012 .61297 Mdot
.55872 .52138 Mdot
.44614 .56254 Mdot
.53272 .5459 Mdot
.56275 .49312 Mdot
.53068 .54858 Mdot
.43928 .49053 Mdot
.50099 .48631 Mdot
.44336 .48943 Mdot
.56138 .4908 Mdot
.50453 .52714 Mdot
.45386 .55033 Mdot
.53347 .53771 Mdot
.51875 .42936 Mdot
.50044 .43211 Mdot
.5202 .54524 Mdot
.49374 .47951 Mdot
.44202 .48306 Mdot
.55402 .55009 Mdot
.44601 .48025 Mdot
.44416 .47148 Mdot
.53618 .53039 Mdot
.4862 .53374 Mdot
.53608 .53997 Mdot
.48627 .52409 Mdot
.49184 .49496 Mdot
.52726 .44274 Mdot
.54975 .57378 Mdot
.56161 .56387 Mdot
.44499 .50549 Mdot
.54226 .42832 Mdot
.50705 .48283 Mdot
.44535 .46518 Mdot
.45029 .53838 Mdot
.5024 .52184 Mdot
.49181 .50556 Mdot
.53518 .49386 Mdot
.53508 .45217 Mdot
.52335 .50546 Mdot
.55854 .44731 Mdot
.51116 .51999 Mdot
.44563 .47111 Mdot
.50678 .5166 Mdot
.49365 .55776 Mdot
.47632 .49659 Mdot
.43976 .44401 Mdot
.48616 .46499 Mdot
.55297 .52965 Mdot
.57482 .4593 Mdot
.47435 .47892 Mdot
.51041 .51465 Mdot
.5765 .46735 Mdot
.55369 .45236 Mdot
.45292 .53488 Mdot
.47438 .38799 Mdot
.48224 .49555 Mdot
.4574 .46975 Mdot
.49376 .47562 Mdot
.45477 .46422 Mdot
.48255 .52637 Mdot
.5581 .48518 Mdot
.56915 .45925 Mdot
.4465 .50954 Mdot
.4431 .45215 Mdot
.44605 .51266 Mdot
.51248 .47704 Mdot
.46832 .46442 Mdot
.50792 .47888 Mdot
.4752 .45468 Mdot
.4593 .56525 Mdot
.43796 .46201 Mdot
.49935 .44363 Mdot
.48711 .48917 Mdot
.47039 .43406 Mdot
.50083 .52601 Mdot
.49575 .55013 Mdot
.47075 .56462 Mdot
.49556 .51376 Mdot
.4493 .54413 Mdot
.52645 .50116 Mdot
.48121 .50113 Mdot
.50363 .47679 Mdot
.48227 .55795 Mdot
.50586 .43815 Mdot
.45018 .52289 Mdot
.4968 .53845 Mdot
.49455 .5056 Mdot
.48958 .47482 Mdot
.4542 .51003 Mdot
.51625 .5237 Mdot
.42796 .51442 Mdot
.48461 .48624 Mdot
.44931 .45914 Mdot
.49446 .59033 Mdot
.47852 .4861 Mdot
.51363 .51305 Mdot
.48008 .45952 Mdot
.47956 .47385 Mdot
.53334 .48033 Mdot
.55325 .52537 Mdot
.396 .50139 Mdot
.44366 .50622 Mdot
.53487 .44501 Mdot
.47647 .42629 Mdot
.43862 .5172 Mdot
.44293 .54005 Mdot
.51521 .55632 Mdot
.50385 .60621 Mdot
.49508 .49796 Mdot
.5432 .5107 Mdot
.53854 .53956 Mdot
.53188 .542 Mdot
.47293 .47848 Mdot
.44846 .50653 Mdot
.57241 .4879 Mdot
.52057 .45383 Mdot
.44953 .45877 Mdot
.53527 .5461 Mdot
.44049 .58435 Mdot
.48194 .57203 Mdot
.41835 .42184 Mdot
.48669 .50941 Mdot
.51829 .48001 Mdot
.416 .50232 Mdot
.57179 .52163 Mdot
.48631 .5055 Mdot
.44359 .501 Mdot
.55416 .53385 Mdot
.46394 .43609 Mdot
.52644 .40028 Mdot
.53724 .43809 Mdot
.49771 .54792 Mdot
.52731 .49821 Mdot
.57164 .45703 Mdot
.54396 .47689 Mdot
.54213 .544 Mdot
.53548 .54516 Mdot
.4614 .53988 Mdot
.44661 .47963 Mdot
.45964 .55124 Mdot
.51896 .47883 Mdot
.4666 .45365 Mdot
.55192 .53698 Mdot
.48207 .52021 Mdot
.5172 .47816 Mdot
.47158 .44099 Mdot
.44057 .53767 Mdot
.54887 .50497 Mdot
.53505 .55358 Mdot
.52115 .46712 Mdot
.55758 .51687 Mdot
.50468 .48555 Mdot
.53082 .49723 Mdot
.48636 .48122 Mdot
.44336 .50451 Mdot
.44762 .59549 Mdot
.48798 .43621 Mdot
.54302 .44463 Mdot
.46759 .54451 Mdot
.47368 .48771 Mdot
.47811 .47546 Mdot
.51727 .52324 Mdot
.40498 .44622 Mdot
.52176 .49469 Mdot
.46265 .55772 Mdot
.47438 .47889 Mdot
.51714 .47997 Mdot
.56582 .44574 Mdot
.52403 .51775 Mdot
.41048 .4658 Mdot
.47582 .4964 Mdot
.44964 .50516 Mdot
.48636 .43457 Mdot
.56753 .45509 Mdot
.50476 .52621 Mdot
.39937 .49997 Mdot
.51528 .53418 Mdot
.57061 .46583 Mdot
.51226 .48037 Mdot
.50199 .5299 Mdot
.48886 .49364 Mdot
.51103 .46007 Mdot
.52452 .53504 Mdot
.4813 .52319 Mdot
.49428 .5089 Mdot
.45672 .46075 Mdot
.42452 .58028 Mdot
.53117 .5644 Mdot
.48447 .55916 Mdot
.47829 .56365 Mdot
.50625 .55347 Mdot
.50359 .5177 Mdot
.44178 .50038 Mdot
.51669 .53047 Mdot
.50177 .43436 Mdot
.576 .47851 Mdot
.45547 .54471 Mdot
.44118 .5005 Mdot
.52882 .59026 Mdot
.50517 .48845 Mdot
.46493 .46085 Mdot
.51712 .5381 Mdot
.52547 .49981 Mdot
.4821 .51269 Mdot
.39966 .5144 Mdot
.51241 .48066 Mdot
.56946 .51373 Mdot
.51766 .48926 Mdot
.49901 .56944 Mdot
.5102 .53048 Mdot
.45278 .43879 Mdot
.5394 .49833 Mdot
.45655 .47873 Mdot
.58985 .57236 Mdot
.52244 .52898 Mdot
.53611 .47678 Mdot
.54628 .47748 Mdot
.4601 .54565 Mdot
.52747 .49618 Mdot
.47512 .48182 Mdot
.48259 .51622 Mdot
.51781 .4995 Mdot
.49626 .54903 Mdot
.50764 .44197 Mdot
.44014 .46674 Mdot
.47872 .4968 Mdot
.42242 .451 Mdot
.53617 .5208 Mdot
.45518 .50633 Mdot
.49195 .5312 Mdot
.53754 .47691 Mdot
.43238 .46595 Mdot
.47495 .48211 Mdot
.52439 .47317 Mdot
.49918 .54866 Mdot
.4557 .55712 Mdot
.48345 .48357 Mdot
.51323 .49572 Mdot
.46614 .42532 Mdot
.50551 .45595 Mdot
.51578 .5272 Mdot
.55753 .57589 Mdot
.5193 .45193 Mdot
.49523 .5194 Mdot
.48476 .53232 Mdot
.50208 .55318 Mdot
.48777 .51303 Mdot
.48718 .40689 Mdot
.58661 .40946 Mdot
.47832 .60178 Mdot
.5236 .52228 Mdot
.48087 .4839 Mdot
.57064 .50365 Mdot
.44127 .48081 Mdot
.49412 .51514 Mdot
.49648 .50822 Mdot
.51356 .6076 Mdot
.54346 .50485 Mdot
.4697 .47643 Mdot
.48985 .54257 Mdot
.44531 .4756 Mdot
.40766 .47257 Mdot
.40358 .48016 Mdot
.54703 .51394 Mdot
.56418 .51735 Mdot
.5167 .51108 Mdot
.52688 .53955 Mdot
.51221 .57233 Mdot
.52395 .53777 Mdot
.46929 .47461 Mdot
.49649 .54975 Mdot
.48102 .49062 Mdot
.49614 .5456 Mdot
.45822 .45649 Mdot
.42968 .47299 Mdot
.48378 .48777 Mdot
.58267 .44201 Mdot
.57986 .43112 Mdot
.5571 .52041 Mdot
.48919 .49553 Mdot
.4951 .48871 Mdot
.53304 .47955 Mdot
.53406 .50901 Mdot
.5044 .46872 Mdot
.41523 .42267 Mdot
.51742 .50789 Mdot
.45497 .52818 Mdot
.51814 .49779 Mdot
.5178 .53545 Mdot
.4858 .49089 Mdot
.42392 .48577 Mdot
.54387 .50485 Mdot
.59034 .49766 Mdot
.45363 .5351 Mdot
.46711 .51955 Mdot
.54678 .43374 Mdot
.47974 .44044 Mdot
.43956 .43761 Mdot
.54127 .51392 Mdot
.5432 .53006 Mdot
.56578 .53665 Mdot
.49828 .5403 Mdot
.49536 .54425 Mdot
.56589 .48845 Mdot
.46611 .46512 Mdot
.53568 .53176 Mdot
.46946 .43089 Mdot
.50984 .53521 Mdot
.46997 .478 Mdot
.48272 .55775 Mdot
.54351 .49259 Mdot
.48487 .55749 Mdot
.54126 .51448 Mdot
.46946 .4756 Mdot
.54164 .51128 Mdot
.44029 .49905 Mdot
.4948 .47412 Mdot
.44836 .4703 Mdot
.45974 .47856 Mdot
.46114 .56308 Mdot
.47787 .60613 Mdot
.49883 .48119 Mdot
.44446 .46803 Mdot
.55805 .48459 Mdot
.38349 .43921 Mdot
.50762 .50177 Mdot
.47579 .49115 Mdot
.5204 .53228 Mdot
.50032 .5262 Mdot
.52112 .49337 Mdot
.41557 .50682 Mdot
.48739 .51424 Mdot
.45393 .563 Mdot
.55663 .39436 Mdot
.48875 .48219 Mdot
.49013 .52311 Mdot
.47119 .558 Mdot
.57548 .46398 Mdot
.42947 .42716 Mdot
.51507 .49727 Mdot
.48188 .56457 Mdot
.54042 .43153 Mdot
.41894 .47202 Mdot
.56078 .49931 Mdot
.54995 .43187 Mdot
.55908 .48621 Mdot
.50613 .42795 Mdot
.4617 .43069 Mdot
.50888 .52235 Mdot
.53987 .45075 Mdot
.45914 .46736 Mdot
.51458 .52451 Mdot
.5247 .46829 Mdot
.52697 .48835 Mdot
.4 .53355 Mdot
.48551 .45445 Mdot
.46271 .55862 Mdot
.46241 .476 Mdot
.51622 .43849 Mdot
.47981 .49555 Mdot
.52619 .48847 Mdot
.47762 .48501 Mdot
.43039 .59142 Mdot
.58256 .41044 Mdot
.49776 .48247 Mdot
.47103 .51406 Mdot
.56172 .4478 Mdot
.47631 .47354 Mdot
.47366 .47909 Mdot
.44107 .51166 Mdot
.50146 .48172 Mdot
.56132 .5283 Mdot
.48403 .50172 Mdot
.49392 .53106 Mdot
.48757 .50909 Mdot
.48589 .48311 Mdot
.50879 .49583 Mdot
.52622 .4528 Mdot
.44342 .50746 Mdot
.49372 .50334 Mdot
.50753 .47565 Mdot
.49382 .52795 Mdot
.50907 .56361 Mdot
.43836 .5012 Mdot
.5337 .45692 Mdot
.54092 .54094 Mdot
.46785 .45332 Mdot
.57848 .46954 Mdot
.49585 .4257 Mdot
.51486 .42859 Mdot
.44647 .5762 Mdot
.4463 .48217 Mdot
.40054 .53276 Mdot
.5186 .52115 Mdot
.46192 .58173 Mdot
.50433 .52535 Mdot
.51383 .50167 Mdot
.4526 .55463 Mdot
.53223 .44442 Mdot
.46302 .45769 Mdot
.46778 .44012 Mdot
.50568 .51723 Mdot
.46493 .56096 Mdot
.5216 .56723 Mdot
.4495 .4175 Mdot
.55675 .51143 Mdot
.51548 .51594 Mdot
.48006 .47379 Mdot
.49561 .54599 Mdot
.53577 .47425 Mdot
.479 .42926 Mdot
.47147 .56843 Mdot
.55222 .49542 Mdot
.58087 .42472 Mdot
.53512 .51096 Mdot
.48471 .52356 Mdot
.51598 .43649 Mdot
.44071 .49645 Mdot
.52604 .52703 Mdot
.4538 .44067 Mdot
.51249 .52675 Mdot
.49773 .5408 Mdot
.53494 .48242 Mdot
.46273 .52085 Mdot
.51593 .46599 Mdot
.45986 .44285 Mdot
.49893 .55122 Mdot
.6006 .54021 Mdot
.48655 .52122 Mdot
.5218 .48334 Mdot
.52984 .54984 Mdot
.45259 .51216 Mdot
.53266 .46327 Mdot
.49024 .54093 Mdot
.51805 .4836 Mdot
.55339 .53382 Mdot
.53956 .5191 Mdot
.42718 .44147 Mdot
.50541 .52621 Mdot
.56721 .46174 Mdot
.50937 .52557 Mdot
.53104 .44813 Mdot
.50483 .55315 Mdot
.50488 .46813 Mdot
.46625 .47483 Mdot
.52441 .48511 Mdot
.55327 .48625 Mdot
.45233 .46006 Mdot
.47927 .48626 Mdot
.5226 .52124 Mdot
.5734 .41598 Mdot
.56915 .44946 Mdot
.54914 .48151 Mdot
.52639 .42995 Mdot
.48657 .51483 Mdot
.54635 .49697 Mdot
.53709 .485 Mdot
.5006 .48134 Mdot
.59993 .50952 Mdot
.50198 .45821 Mdot
.44589 .55662 Mdot
.47718 .48004 Mdot
.50086 .48915 Mdot
.49512 .54394 Mdot
.441 .4977 Mdot
.52532 .45163 Mdot
.52256 .52424 Mdot
.52969 .54683 Mdot
.52167 .45634 Mdot
.47344 .47942 Mdot
.46887 .47935 Mdot
.51006 .39615 Mdot
.57413 .43735 Mdot
.47925 .55524 Mdot
.43772 .43447 Mdot
.44219 .50318 Mdot
.47166 .47832 Mdot
.48359 .46883 Mdot
.54414 .50309 Mdot
.42318 .46288 Mdot
.47164 .55264 Mdot
.56721 .52132 Mdot
.47158 .43607 Mdot
.52645 .50152 Mdot
.48204 .4884 Mdot
.46432 .4576 Mdot
.51238 .51425 Mdot
.4903 .51372 Mdot
.47928 .5593 Mdot
.52693 .5014 Mdot
.49337 .49882 Mdot
.48891 .55912 Mdot
.47217 .43048 Mdot
.479 .56595 Mdot
.5391 .51177 Mdot
.44267 .43043 Mdot
.5323 .52584 Mdot
.51974 .5535 Mdot
.4609 .43699 Mdot
.52916 .54554 Mdot
.42373 .53454 Mdot
.50478 .44099 Mdot
.55394 .48325 Mdot
.50695 .51805 Mdot
.49746 .53293 Mdot
.47478 .484 Mdot
.51306 .4808 Mdot
.44263 .59474 Mdot
.60495 .513 Mdot
.50034 .61295 Mdot
.51867 .46691 Mdot
.49957 .51541 Mdot
.43239 .55709 Mdot
.53352 .54056 Mdot
.4959 .47518 Mdot
.48253 .51794 Mdot
.55877 .52349 Mdot
.4791 .60825 Mdot
.45763 .47967 Mdot
.49495 .48986 Mdot
.51196 .56374 Mdot
.57044 .46225 Mdot
.48633 .50329 Mdot
.40486 .45023 Mdot
.4972 .52143 Mdot
.53369 .48412 Mdot
.52747 .51313 Mdot
.52994 .51551 Mdot
.52931 .44247 Mdot
.53708 .49815 Mdot
.55214 .48215 Mdot
.53097 .52561 Mdot
.51071 .44397 Mdot
.50794 .52218 Mdot
.54587 .53995 Mdot
.47694 .46858 Mdot
.50716 .53465 Mdot
.50106 .46391 Mdot
.46262 .54312 Mdot
.46041 .50928 Mdot
.52912 .50466 Mdot
.4864 .53392 Mdot
.53868 .52093 Mdot
.52002 .4892 Mdot
.48852 .56074 Mdot
.61605 .47507 Mdot
.46588 .43812 Mdot
.52149 .56434 Mdot
.47573 .48292 Mdot
.50985 .5006 Mdot
.44262 .52145 Mdot
.47658 .55308 Mdot
.53868 .41748 Mdot
.51369 .52512 Mdot
.50259 .53373 Mdot
.52379 .48903 Mdot
.42338 .41599 Mdot
.50464 .52137 Mdot
.53619 .50786 Mdot
.44352 .49945 Mdot
.41189 .41177 Mdot
.54605 .49826 Mdot
.51248 .51167 Mdot
.5397 .58583 Mdot
.48197 .48343 Mdot
.60376 .542 Mdot
.55894 .5176 Mdot
.5708 .41398 Mdot
.45543 .58063 Mdot
.55229 .51831 Mdot
.44627 .46606 Mdot
.51189 .52479 Mdot
.46791 .47475 Mdot
.51053 .44898 Mdot
.47465 .4552 Mdot
.4379 .47543 Mdot
.47595 .46286 Mdot
.44708 .51781 Mdot
.51316 .43468 Mdot
.52364 .51187 Mdot
.40971 .4722 Mdot
.54694 .49182 Mdot
.51695 .52946 Mdot
.45753 .42962 Mdot
.49815 .5585 Mdot
.47915 .50525 Mdot
.60534 .54526 Mdot
.46464 .43653 Mdot
.47645 .53572 Mdot
.50708 .51575 Mdot
.47654 .51776 Mdot
.4973 .4878 Mdot
.47993 .48657 Mdot
.48311 .4569 Mdot
.49068 .57393 Mdot
.53861 .50219 Mdot
.48069 .50023 Mdot
.49928 .56267 Mdot
.44842 .51843 Mdot
.50495 .46277 Mdot
.43075 .58829 Mdot
.46515 .5172 Mdot
.5847 .56134 Mdot
.48203 .5223 Mdot
.36502 .44194 Mdot
.50818 .51473 Mdot
.50924 .48454 Mdot
.42628 .44895 Mdot
.42939 .55998 Mdot
.49231 .50672 Mdot
.52888 .5429 Mdot
.54773 .53332 Mdot
.46014 .45776 Mdot
.43555 .55814 Mdot
.53423 .47263 Mdot
.52844 .51978 Mdot
.47878 .50807 Mdot
.54396 .53469 Mdot
.52744 .46037 Mdot
.48361 .53196 Mdot
.51497 .47213 Mdot
.57203 .48598 Mdot
.53133 .5487 Mdot
.46875 .47523 Mdot
.54492 .54211 Mdot
.50198 .56002 Mdot
.52546 .39395 Mdot
.39918 .51001 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0U_ooool2o`000:oooooo000Nooooo`03
o`000?oooooooooo09Kooooo0_l0002_ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`2Kooooo`;o
00002_ooool2o`0000Sooooo0_l0002Dooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Voooool2o`0000Go
oooo0_l000000ooooooo0000o`000002o`0000Sooooo0_l0002Dooooo`000oooool01Ol@413ooooo
oooooooooooo410@00_ooooo1Ol00006ooooo`?o0000Uoooool2o`0000Wooooo0_l000000ooooooo
0000o`000002o`0009kooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4Co
gMgMooooool00007ooooo`03o`000?oooooooooo09Oooooo0_l0000>ooooo`;o0000W_ooool000?o
oooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000
ooooooooool0V_ooool2o`00013ooooo0_l0002Iooooo`000oooool01Ol@413ooooooooooooooooo
410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`2:ooooo`;o00003_ooool2
o`00013ooooo0_l0000;ooooo`Co0000R_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<
ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0P_ooool2o`0000Kooooo0_l0000?
ooooo`;o00006_ooool6o`0008[ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool0
0omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo08;ooooo0_l00002ooooo`;o00001Oooool2
o`0000Gooooo0_l00004ooooo`?o00006?ooool4o`0008kooooo000Nooooo`03o`000?oooooooooo
08Kooooo0_l00005ooooo`?o00001?ooool2o`0000Cooooo0_l0000?ooooo`;o00002?ooool3o`00
08oooooo000Nooooo`03o`000?oooooooooo08?ooooo0ol00008ooooo`;o00006oooool2o`0009[o
oooo000Nooooo`03o`000?oooooooooo08?ooooo0ol0000=ooooo`;o00002?ooool2o`0001[ooooo
0_l0002<ooooo`007_ooool00ol0003oooooooooo`22ooooo`;o00001?ooool2o`0000Wooooo0_l0
00001?oooooo0000o`000?l00004ooooo`Go000000?oooooo`000?l000001oooool2o`0000_ooooo
0_l0002<ooooo`007_ooool00ol0003oooooooooo`22ooooo`;o00001?ooool2o`0000;ooooo0_l0
0003ooooo`?o000000?oooooo`000?l000000ol000000ooooooo0000o`000002ooooo`?o000000?o
ooooo`000?l000001?l00003ooooo`;o000000?oooooo`000?l000001oooool3o`0008cooooo000N
ooooo`03o`000?oooooooooo08[ooooo1?l00003ooooo`?o000000?oooooo`000?l000004_l00003
ooooo`Go00001oooool3o`0008cooooo000Nooooo`03o`000?oooooooooo08[ooooo0ol00004oooo
o`Oo000000?oooooo`000?l000002ol00005ooooo`;o000000?oooooo`000?l000001oooool2o`00
08kooooo000Nooooo`03o`000?oooooooooo07Wooooo0_l0000@ooooo`;o00000_ooool8o`000004
ooooool0003o0000ooooo`;o00000oooool3o`000004ooooool0003o0000o`0000Cooooo0_l0000:
ooooo`;o0000S_ooool001kooooo00?o0000ooooooooool0KOooool2o`0000Cooooo0_l00004oooo
o`;o00003?ooool2o`0000;ooooo0ol000000ooooooo0000o`000002o`000005ooooool0003o0000
o`000?ooool01?l000000ooooooo0000o`00000;o`0000oooooo0_l0002<ooooo`007_ooool00ol0
003oooooooooo`1]ooooo`;o00001?ooool2o`0000_ooooo0_l00005ooooo`;o00000_ooool3o`00
00;ooooo0ol000001?oooooo0000o`000?l00003ooooo`;o000000Goooooo`000?l0003o0000oooo
o`03o`0000?ooooo1ol00003ooooo`;o000000?oooooo`000?l000000oooool2o`0008cooooo000N
ooooo`03o`000?oooooooooo083ooooo0_l00004ooooo`?o00000oooool3o`0001?ooooo0_l00000
1?oooooo0000o`000?ooool6o`0000?ooooo2?l0002>ooooo`007_ooool2o`00087ooooo0_l00003
ooooo`Co00000oooool3o`0000Gooooo0_l00006ooooo`;o00001?ooool2o`000003ooooool0003o
000000Oo00000_ooool2o`000003ooooool0003o000000Co0000S_ooool001kooooo00?o0000oooo
ooooool0QOooool2o`0000Gooooo0_l00002ooooo`?o000000?oooooo`000?l000000_l00002oooo
o`Co00000_ooool2o`0000?ooooo2Ol00002ooooo`;o00000_ooool4o`0008oooooo000Nooooo`03
o`000?oooooooooo07kooooo0ol0000=ooooo`ko00000oooool3o`0000?ooooo0_l00002ooooo`?o
00002?ooool5o`0008kooooo000Nooooo`03o`000?oooooooooo07kooooo0ol00009ooooo`;o0000
0_ooool8o`0000;ooooo1?l00003ooooo`Go00000oooool7o`0000Kooooo1_l0002=ooooo`007_oo
ool00ol0003oooooooooo`21ooooo`;o00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`00
0003o`000005ooooool0003o0000o`000?ooool00_l000000ooooooo0000o`000002o`000003oooo
ool0003o000000Co00000_ooool4o`000004ooooool0003o0000ooooo`;o00000oooool6o`0008go
oooo000Nooooo`03o`000?oooooooooo087ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o
oooo4ol000000ooooooo0000o`000007o`000004ooooool0003o0000ooooo`;o000000?oooooo`00
0?l000000_l00002ooooo`Co0000S_ooool001kooooo00?o0000ooooooooool0Q?ooool3o`000004
ooooool0003o0000ooooo`Go000000Coooooo`000?l0003ooooo2?l00003ooooo`Wo00001?ooool2
o`000003ooooool0003o000000;o00001?ooool3o`0008gooooo000Nooooo`03o`000?oooooooooo
083ooooo0ol000001Ooooooo0000o`000?l0003ooooo00;o00000_ooool4o`000003ooooool0003o
000000?o000000?oooooo`000?l000002?l000001Ooooooo0000o`000?l0003ooooo00?o000000?o
ooooo`000?l000000_l00009ooooo`?o00002_ooool2o`00087ooooo000Nooooo`03o`000?oooooo
oooo083ooooo0ol000000ooooooo0000o`000002ooooo`Oo00000oooool=o`000003ooooool0003o
000000Oo000000?oooooo`000?l000000ol00004ooooo`;o00000_ooool2o`0000_ooooo0_l00021
ooooo`007_ooool00ol0003oooooooooo`1oooooo`;o00002OoooolMo`0000;ooooo1_l00004oooo
o`;o00000_ooool2o`0008kooooo000Nooooo`03o`000?oooooooooo07oooooo0_l00004ooooo`;o
00001?oooolMo`000004ooooool0003o0000o`0000;ooooo1?l00005ooooo`;o0000S_ooool001ko
oooo00?o0000ooooooooool0QOooool3o`0000Cooooo0ol00004ooooo`;o000000?oooooo`000?l0
00004?l000001?oooooo0000o`000?l00002ooooo`Ko00000_ooool2o`0008oooooo000Nooooo`03
o`000?oooooooooo08Kooooo0_l00003ooooo`?o00002?oooolCo`000003ooooool0003o000000?o
oooo2Ol0002?ooooo`007_ooool00ol0003oooooooooo`23ooooo`;o00001_ooool3o`0000Sooooo
5?l00003ooooo`_o0000Soooool001kooooo00?o0000ooooooooool0Poooool2o`0000Kooooo0_l0
000:oooooaGo000000?oooooo`000?l000000_l000001Ooooooo0000o`000?l0003ooooo00;o0000
Soooool001kooooo00?o0000ooooooooool0Roooool3o`0000;ooooo0_l00004oooooa_o000000?o
ooooo`000?l000000oooool2o`0000?ooooo0_l00029ooooo`007_ooool2o`0007kooooo0ol00003
ooooo`;o00001Oooool4o`0000;ooooo0_l00004oooooa3o000000?oooooo`000?l000001ol00002
ooooo`;o00000oooool2o`0000?ooooo0_l00029ooooo`007_ooool00ol0003oooooooooo`1moooo
o`?o00000oooool2o`0000Gooooo1_l00008ooooo`Oo00000_ooool?o`0000Gooooo0_l0002@oooo
o`007_ooool00ol0003oooooooooo`23ooooo`;o00000oooool2o`0000;ooooo1_l00006ooooo`Oo
00000_ooool?o`0000Cooooo0ol00002ooooo`;o0000S?ooool001kooooo00?o0000ooooooooool0
O_ooool2o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000001ol00004ooooo`Wo0000
00?oooooo`000?l000001?l000000ooooooo0000o`000004o`000005ooooool0003o0000o`000?oo
ool00_l00003ooooo`;o00001?ooool2o`0008Kooooo000Nooooo`03o`000?oooooooooo07kooooo
0_l00004ooooo`;o000000?oooooo`000?l000002ol000001?oooooo0000o`000?oooolAo`000003
ooooool0003o000000Oo00000_ooool5o`0000Gooooo1?l00024ooooo`007_ooool00ol0003ooooo
ooooo`1nooooo`;o00001?ooool2o`000003ooooool0003o000000So00000_oooolBo`000003oooo
ool0003o000000;o000000?oooooo`000?l000003Ol00007ooooo`;o0000Q?ooool001kooooo00?o
0000ooooooooool0R_ooool6o`000003ooooool0003o000001_o000000?oooooo`000?l000001Ol0
002Aooooo`007_ooool00ol0003oooooooooo`2<ooooo`Co000000?oooooo`000?l000001?l00000
0ooooooo0000o`00000Co`0000;ooooo2Ol0002?ooooo`007_ooool00ol0003oooooooooo`25oooo
o`;o00001?ooool5o`0000?ooooo0_l00003oooooaGo00000oooool8o`0008oooooo000Nooooo`03
o`000?oooooooooo08Gooooo0_l00004ooooo`;o00000_ooool3o`0000Kooooo5_l00002ooooo`Co
00000oooool2o`0008kooooo000Nooooo`03o`000?oooooooooo07kooooo0_l0000?ooooo`?o0000
1_ooool9o`000003ooooool0003o0000013o00000oooool2o`0008kooooo000Nooooo`03o`000?oo
oooooooo07kooooo0_l00006ooooo`;o00001oooool2o`0000Kooooo7Ol00003ooooo`;o0000S_oo
ool001kooooo00?o0000ooooooooool0O_ooool2o`0000Kooooo0_l00003ooooo`;o000000Cooooo
o`000?l0003o00001_ooool2o`000003ooooool0003o000001[o000000?oooooo`000?l00000S_oo
ool001kooooo00?o0000ooooooooool0POooool2o`0000Sooooo1Ol00002ooooo`;o00001_ooool7
o`000003ooooool0003o000001;o00002Oooool3o`0008Gooooo000Nooooo`03o`000?oooooooooo
087ooooo0_l00009ooooo`[o00001Oooool6o`000004ooooool0003o0000ooooo`;o000000?ooooo
o`000?l000001Ol00002ooooo`;o00003?ooool4o`0008Cooooo000Nooooo`03o`000?oooooooooo
08kooooo2?l00006ooooo`Co00001Oooool2o`000003ooooool0003o000000Co00004oooool2o`00
08Cooooo000Nooooo`;o0000T?ooool5o`0000Wooooo1?l00007ooooo`Co00001?ooool2o`0009Go
oooo000Nooooo`03o`000?oooooooooo08Cooooo0_l00009ooooo`Go000000?oooooo`000?l00000
1?l00002ooooo`Go00000oooool2o`000003ooooool0003o000000;o00000oooool3o`0009Gooooo
000Nooooo`03o`000?oooooooooo08Cooooo0_l00002ooooo`?o00000_oooolEo`000003ooooool0
003o000000;o00000oooool2o`0000?ooooo0ol0002Eooooo`007_ooool00ol0003oooooooooo`27
ooooo`Go000000Coooooo`000?l0003ooooo1ol000000ooooooo0000o`000007o`000003ooooool0
003o000000Co00002?ooool2o`0000Wooooo0_l0002:ooooo`007_ooool00ol0003oooooooooo`27
ooooo`;o000000Coooooo`000?l0003ooooo5ol00002ooooo`;o00002_ooool2o`0000Kooooo0ol0
002:ooooo`007_ooool00ol0003oooooooooo`21ooooo`;o00000oooool2o`0000Gooooo3_l00002
ooooo`Oo000000?oooooo`000?l000000_ooool2o`0000Oooooo0_l00006ooooo`;o0000Roooool0
01kooooo00?o0000ooooooooool0POooool2o`0000?ooooo0_l00009ooooo`[o00000_ooool4o`00
00Cooooo0_l00002ooooo`;o0000W?ooool001kooooo00?o0000ooooooooool0UOooool6o`000003
ooooool0003o000000?o000000?oooooo`000?l000000ol0000Eooooo`;o0000ROooool001kooooo
00?o0000ooooooooool0SOooool2o`0000Kooooo0_l000000ooooooo0000o`000004o`0000Cooooo
1Ol00008ooooo`Co00002Oooool2o`0008Wooooo000Nooooo`03o`000?oooooooooo08gooooo0_l0
0006ooooo`;o00000_ooool4o`0001;ooooo1?l0002Dooooo`007_ooool00ol0003oooooooooo`26
ooooo`;o00002?ooool4o`0001?ooooo0_l0002Nooooo`007_ooool00ol0003oooooooooo`26oooo
o`Co000000?oooooo`000?l000000oooool4o`0001?ooooo1_l0002Jooooo`007_ooool00ol0003o
ooooooooo`28ooooo`;o000000?oooooo`000?l000007?ooool4o`0009[ooooo000Nooooo`03o`00
0?oooooooooo08Sooooo0_l0000Cooooo`;o00002Oooool3o`0009cooooo0003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03
o`000?oooooooooo08Sooooo0_l00002ooooo`;o00003oooool2o`0000Wooooo0ol0002Looooo`00
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRH
V?lQ8B401_ooool00ol0003oooooooooo`2<ooooo`?o0000^?ooool000?ooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`0008gooooo1?l0002f
ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q
8@06ooooo`03o`000?oooooooooo08oooooo0_l00006ooooo`;o0000[_ooool000?ooooo00Go0000
ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003ooooo
ooooo`2Gooooo`;o00001oooool3o`000:Cooooo0003ooooo`05oa0@4?ooooooooooooooool@4100
2oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo09Oooooo0ol00006ooooo`Oo0000
X?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo
00?o0000ooooooooool0V?ooool2o`0000Cooooo2Ol0002Pooooo`000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`2Nooooo`Go
0000Y?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003ooooo
odWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`00
0?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003o
oooooooooooooooo000000Kooooo0ol0003oooooodSooooo0003ooooo`05o`000?oooooooooooooo
ool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000ooooooooool0oooooom8
ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@
400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`3oooooodSooooo
0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Ko
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000
oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001Cooooo1?l0
00000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB?ooool001Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`3oooooodSooooo000Fooooo`03o`000?oooooooooo
00Gooooo0ol0003oooooodSooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo
00?o0000ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000F
ooooo`03o`000?oooooooooo0?ooooooD?ooool001Cooooo00?oEEEEofIVI_l00000oooooomBoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.54066 .48775 Mdot
.51775 .53791 Mdot
.44996 .56934 Mdot
.50051 .53486 Mdot
.48428 .51667 Mdot
.51199 .42207 Mdot
.60061 .41508 Mdot
.51432 .5503 Mdot
.47534 .42019 Mdot
.55412 .53302 Mdot
.55406 .50008 Mdot
.52798 .5014 Mdot
.48043 .4375 Mdot
.42572 .49551 Mdot
.49983 .38057 Mdot
.47561 .51222 Mdot
.53337 .5283 Mdot
.45569 .42926 Mdot
.57847 .46629 Mdot
.45219 .46049 Mdot
.53639 .52396 Mdot
.46804 .49771 Mdot
.47144 .53733 Mdot
.45539 .42648 Mdot
.53814 .54083 Mdot
.5171 .49402 Mdot
.55136 .53788 Mdot
.53968 .44091 Mdot
.49058 .51263 Mdot
.49658 .42313 Mdot
.4861 .44529 Mdot
.52089 .5457 Mdot
.49318 .49266 Mdot
.45175 .54523 Mdot
.49024 .42276 Mdot
.44767 .53221 Mdot
.50432 .49104 Mdot
.47499 .52942 Mdot
.47498 .53098 Mdot
.52686 .48768 Mdot
.47851 .49145 Mdot
.44471 .47023 Mdot
.52694 .482 Mdot
.51162 .51138 Mdot
.52225 .54799 Mdot
.48365 .47288 Mdot
.46719 .55346 Mdot
.46796 .45012 Mdot
.4529 .4576 Mdot
.44326 .53152 Mdot
.48117 .51733 Mdot
.43194 .59644 Mdot
.49298 .51573 Mdot
.47974 .53121 Mdot
.47654 .53961 Mdot
.50581 .4799 Mdot
.53096 .49062 Mdot
.50291 .59785 Mdot
.51307 .54659 Mdot
.52409 .48147 Mdot
.47663 .46606 Mdot
.49257 .48189 Mdot
.44548 .51971 Mdot
.47579 .51299 Mdot
.48723 .50294 Mdot
.4222 .4122 Mdot
.53501 .4764 Mdot
.49162 .47738 Mdot
.48765 .46605 Mdot
.47524 .51051 Mdot
.58904 .42907 Mdot
.4942 .52933 Mdot
.51174 .47279 Mdot
.50277 .52489 Mdot
.47532 .42291 Mdot
.55494 .52331 Mdot
.48585 .46604 Mdot
.45018 .42828 Mdot
.56998 .47821 Mdot
.55505 .47137 Mdot
.46538 .51699 Mdot
.52123 .55132 Mdot
.53015 .53797 Mdot
.47763 .47478 Mdot
.44819 .52754 Mdot
.49888 .52133 Mdot
.47047 .56282 Mdot
.49936 .48242 Mdot
.52659 .48523 Mdot
.38976 .51852 Mdot
.49185 .50659 Mdot
.47854 .46943 Mdot
.46771 .55886 Mdot
.40779 .47276 Mdot
.49682 .55902 Mdot
.47411 .46272 Mdot
.50186 .4822 Mdot
.49421 .44795 Mdot
.48441 .56561 Mdot
.53527 .50675 Mdot
.47652 .56556 Mdot
.46129 .55194 Mdot
.49932 .5386 Mdot
.41023 .43459 Mdot
.49704 .42972 Mdot
.49071 .49005 Mdot
.37035 .43013 Mdot
.48799 .50288 Mdot
.54131 .49674 Mdot
.47791 .47021 Mdot
.49567 .45111 Mdot
.49616 .53051 Mdot
.51374 .52905 Mdot
.58431 .53449 Mdot
.54219 .4801 Mdot
.42433 .5402 Mdot
.53951 .57471 Mdot
.53357 .43272 Mdot
.42503 .54195 Mdot
.47233 .56265 Mdot
.47468 .43565 Mdot
.51781 .49776 Mdot
.53784 .5458 Mdot
.46742 .44276 Mdot
.52845 .53235 Mdot
.55568 .5475 Mdot
.4785 .43562 Mdot
.5166 .49645 Mdot
.51269 .50409 Mdot
.4754 .52646 Mdot
.50772 .43487 Mdot
.54355 .51237 Mdot
.49262 .62389 Mdot
.4452 .48862 Mdot
.4912 .52829 Mdot
.49691 .62084 Mdot
.58777 .451 Mdot
.50148 .51305 Mdot
.49774 .46513 Mdot
.5145 .52144 Mdot
.48954 .5043 Mdot
.55797 .49372 Mdot
.50531 .49957 Mdot
.4937 .52747 Mdot
.48971 .48852 Mdot
.47701 .46971 Mdot
.53588 .47254 Mdot
.46404 .47304 Mdot
.53986 .47576 Mdot
.4631 .44215 Mdot
.446 .49862 Mdot
.52275 .4323 Mdot
.48797 .50843 Mdot
.43131 .45273 Mdot
.53807 .44619 Mdot
.4755 .51251 Mdot
.48804 .48135 Mdot
.44906 .55403 Mdot
.48606 .46595 Mdot
.49325 .49514 Mdot
.54776 .39248 Mdot
.47185 .46392 Mdot
.44527 .43525 Mdot
.4808 .54105 Mdot
.5291 .49044 Mdot
.52813 .51612 Mdot
.51609 .43227 Mdot
.4501 .49578 Mdot
.44613 .48931 Mdot
.47863 .53202 Mdot
.54869 .44928 Mdot
.47574 .44432 Mdot
.52592 .53025 Mdot
.52499 .48616 Mdot
.51682 .39165 Mdot
.5071 .48644 Mdot
.4788 .47014 Mdot
.49155 .49487 Mdot
.49941 .57407 Mdot
.4518 .45462 Mdot
.49767 .53121 Mdot
.4783 .46339 Mdot
.50309 .51963 Mdot
.49219 .51604 Mdot
.46217 .46447 Mdot
.52597 .50773 Mdot
.46517 .57188 Mdot
.47587 .46454 Mdot
.39879 .43223 Mdot
.48673 .56508 Mdot
.51503 .51478 Mdot
.47951 .51797 Mdot
.45632 .42833 Mdot
.48798 .50631 Mdot
.47223 .5267 Mdot
.48043 .49096 Mdot
.47984 .56198 Mdot
.50337 .50276 Mdot
.48661 .50298 Mdot
.50497 .53564 Mdot
.53345 .5146 Mdot
.48715 .47414 Mdot
.48893 .43495 Mdot
.44371 .4845 Mdot
.47648 .54684 Mdot
.52999 .52642 Mdot
.54722 .51064 Mdot
.53398 .49784 Mdot
.45849 .56052 Mdot
.48643 .50847 Mdot
.52411 .5453 Mdot
.50521 .49405 Mdot
.51358 .47495 Mdot
.52754 .4512 Mdot
.51834 .49776 Mdot
.46258 .5453 Mdot
.47888 .4685 Mdot
.49051 .46678 Mdot
.56325 .50139 Mdot
.49164 .50045 Mdot
.47329 .5227 Mdot
.48651 .6259 Mdot
.47755 .46872 Mdot
.44369 .53416 Mdot
.54341 .55215 Mdot
.51665 .54197 Mdot
.51535 .54485 Mdot
.55155 .53743 Mdot
.45981 .56545 Mdot
.57164 .4981 Mdot
.48995 .55646 Mdot
.50651 .4956 Mdot
.57992 .54161 Mdot
.49066 .48573 Mdot
.51349 .48846 Mdot
.49591 .46373 Mdot
.56015 .55149 Mdot
.55509 .52883 Mdot
.53901 .51807 Mdot
.52613 .50753 Mdot
.55433 .53412 Mdot
.51583 .38045 Mdot
.51923 .45722 Mdot
.53373 .54988 Mdot
.50414 .54478 Mdot
.47532 .52976 Mdot
.57351 .49319 Mdot
.50598 .54161 Mdot
.49695 .5646 Mdot
.55389 .56385 Mdot
.52964 .48735 Mdot
.45118 .47917 Mdot
.55963 .42572 Mdot
.49684 .55332 Mdot
.51025 .52895 Mdot
.53049 .506 Mdot
.48113 .53819 Mdot
.50638 .47324 Mdot
.45001 .53648 Mdot
.55803 .48857 Mdot
.45079 .49554 Mdot
.48038 .50781 Mdot
.49328 .49488 Mdot
.51971 .44565 Mdot
.44707 .46278 Mdot
.44418 .50749 Mdot
.5672 .53886 Mdot
.49012 .42012 Mdot
.47964 .47951 Mdot
.50367 .58594 Mdot
.53531 .48436 Mdot
.51425 .52876 Mdot
.39895 .43154 Mdot
.51499 .52497 Mdot
.46012 .57225 Mdot
.58991 .45399 Mdot
.49588 .47318 Mdot
.5866 .47364 Mdot
.46296 .45762 Mdot
.57573 .50301 Mdot
.49408 .46626 Mdot
.51945 .48843 Mdot
.4157 .48654 Mdot
.49876 .50223 Mdot
.52397 .55837 Mdot
.41294 .48212 Mdot
.48055 .55921 Mdot
.46814 .53828 Mdot
.53386 .52366 Mdot
.43756 .45208 Mdot
.53204 .49684 Mdot
.49806 .45668 Mdot
.41837 .52869 Mdot
.51178 .4661 Mdot
.52789 .51675 Mdot
.48517 .53249 Mdot
.51692 .43228 Mdot
.45027 .45509 Mdot
.44295 .47987 Mdot
.50094 .53509 Mdot
.5077 .51148 Mdot
.51792 .54138 Mdot
.46111 .40759 Mdot
.47606 .48965 Mdot
.53064 .50007 Mdot
.4992 .53365 Mdot
.56812 .52585 Mdot
.52175 .47302 Mdot
.5447 .53702 Mdot
.45044 .45705 Mdot
.50016 .53039 Mdot
.49762 .5 Mdot
.55348 .54376 Mdot
.55222 .52567 Mdot
.50951 .5346 Mdot
.541 .47216 Mdot
.52578 .48679 Mdot
.49515 .47933 Mdot
.5109 .47307 Mdot
.46665 .52229 Mdot
.45901 .44605 Mdot
.54568 .5055 Mdot
.54566 .49153 Mdot
.50787 .48482 Mdot
.55724 .46013 Mdot
.45818 .52054 Mdot
.51393 .51284 Mdot
.51398 .50327 Mdot
.52862 .45236 Mdot
.46094 .53856 Mdot
.52639 .45819 Mdot
.42409 .56111 Mdot
.5159 .52837 Mdot
.5636 .5196 Mdot
.4563 .55474 Mdot
.49865 .55562 Mdot
.44679 .48743 Mdot
.49658 .53113 Mdot
.54544 .54189 Mdot
.4958 .48282 Mdot
.52905 .46923 Mdot
.54668 .48336 Mdot
.58611 .48753 Mdot
.50184 .49869 Mdot
.45288 .50189 Mdot
.54742 .4927 Mdot
.49975 .50448 Mdot
.49855 .54088 Mdot
.45266 .49792 Mdot
.47766 .47472 Mdot
.53171 .49511 Mdot
.48506 .62193 Mdot
.53198 .53333 Mdot
.4968 .48791 Mdot
.43589 .46526 Mdot
.53186 .50793 Mdot
.42323 .48436 Mdot
.54564 .50912 Mdot
.39161 .54932 Mdot
.48894 .48861 Mdot
.48655 .50526 Mdot
.53777 .47163 Mdot
.52375 .52162 Mdot
.42094 .45739 Mdot
.54651 .50214 Mdot
.41327 .50147 Mdot
.46833 .55012 Mdot
.44954 .49536 Mdot
.58268 .58825 Mdot
.49894 .51992 Mdot
.49317 .49545 Mdot
.49825 .51032 Mdot
.47967 .62264 Mdot
.55324 .54834 Mdot
.4342 .5459 Mdot
.50392 .55972 Mdot
.5679 .52449 Mdot
.49555 .56142 Mdot
.44658 .46813 Mdot
.50879 .49322 Mdot
.44828 .4613 Mdot
.53661 .5263 Mdot
.48935 .52344 Mdot
.44246 .51368 Mdot
.5159 .54578 Mdot
.53411 .43791 Mdot
.53292 .437 Mdot
.49018 .55312 Mdot
.51107 .48318 Mdot
.44972 .45686 Mdot
.53968 .58927 Mdot
.46245 .46177 Mdot
.45817 .44764 Mdot
.52104 .54616 Mdot
.47044 .53611 Mdot
.51756 .55208 Mdot
.47781 .5026 Mdot
.49484 .49483 Mdot
.55484 .45629 Mdot
.53102 .60368 Mdot
.54716 .59711 Mdot
.44661 .47404 Mdot
.55532 .47542 Mdot
.52059 .48872 Mdot
.46201 .44667 Mdot
.44468 .50799 Mdot
.49181 .51826 Mdot
.49297 .49844 Mdot
.53745 .5096 Mdot
.56036 .47087 Mdot
.51808 .51693 Mdot
.57816 .46769 Mdot
.50197 .5232 Mdot
.46876 .44868 Mdot
.49989 .5186 Mdot
.46422 .555 Mdot
.47766 .47598 Mdot
.45535 .43129 Mdot
.5129 .47066 Mdot
.52908 .55365 Mdot
.58543 .4824 Mdot
.48505 .47354 Mdot
.50394 .5201 Mdot
.58071 .49483 Mdot
.55137 .50466 Mdot
.44661 .50421 Mdot
.49527 .38738 Mdot
.47841 .48036 Mdot
.48121 .46121 Mdot
.51567 .47727 Mdot
.48721 .45895 Mdot
.47541 .50828 Mdot
.5548 .50527 Mdot
.58464 .48101 Mdot
.44344 .48902 Mdot
.4519 .42863 Mdot
.4451 .49189 Mdot
.52916 .48792 Mdot
.50157 .46461 Mdot
.52614 .48756 Mdot
.50082 .45686 Mdot
.41902 .5615 Mdot
.4621 .4476 Mdot
.53165 .44772 Mdot
.48959 .48921 Mdot
.50436 .43081 Mdot
.48654 .52025 Mdot
.47594 .5412 Mdot
.45213 .54765 Mdot
.49126 .50841 Mdot
.42612 .52352 Mdot
.52321 .51284 Mdot
.47805 .48285 Mdot
.52346 .48335 Mdot
.4565 .54607 Mdot
.53729 .46247 Mdot
.4464 .49112 Mdot
.4694 .52321 Mdot
.49583 .50206 Mdot
.51158 .47516 Mdot
.44437 .48565 Mdot
.50352 .52843 Mdot
.43654 .4854 Mdot
.49035 .48648 Mdot
.46762 .4447 Mdot
.46937 .57211 Mdot
.4793 .47859 Mdot
.50678 .52068 Mdot
.51139 .46059 Mdot
.50261 .47028 Mdot
.5371 .51559 Mdot
.52958 .5498 Mdot
.43153 .47365 Mdot
.45793 .45535 Mdot
.5612 .46141 Mdot
.509 .44276 Mdot
.44365 .48457 Mdot
.449 .48897 Mdot
.48077 .56476 Mdot
.48076 .60789 Mdot
.49812 .49979 Mdot
.53112 .53519 Mdot
.51559 .54803 Mdot
.51463 .55056 Mdot
.48382 .47271 Mdot
.44153 .48398 Mdot
.56611 .51764 Mdot
.53656 .4793 Mdot
.4674 .44317 Mdot
.50082 .56134 Mdot
.41473 .58536 Mdot
.45942 .56275 Mdot
.44092 .41192 Mdot
.48906 .49799 Mdot
.53308 .49377 Mdot
.43405 .47331 Mdot
.5705 .55082 Mdot
.48966 .49465 Mdot
.44143 .47887 Mdot
.53899 .54934 Mdot
.51162 .44947 Mdot
.54721 .41759 Mdot
.5764 .43349 Mdot
.47749 .54224 Mdot
.5261 .50933 Mdot
.58014 .48459 Mdot
.55265 .50169 Mdot
.51679 .561 Mdot
.50292 .56598 Mdot
.42655 .50659 Mdot
.46377 .46163 Mdot
.44651 .52473 Mdot
.53347 .49391 Mdot
.49705 .43358 Mdot
.53143 .54686 Mdot
.47756 .50008 Mdot
.53263 .49272 Mdot
.49358 .4225 Mdot
.42152 .51445 Mdot
.55011 .53563 Mdot
.51053 .56725 Mdot
.53621 .48242 Mdot
.55296 .54195 Mdot
.51448 .49221 Mdot
.52969 .51058 Mdot
.50328 .48214 Mdot
.44721 .47279 Mdot
.42701 .59326 Mdot
.52248 .43932 Mdot
.56768 .46147 Mdot
.44953 .52055 Mdot
.47685 .46985 Mdot
.49796 .47435 Mdot
.50444 .52878 Mdot
.40918 .42406 Mdot
.52407 .50364 Mdot
.4501 .52117 Mdot
.48803 .47533 Mdot
.5318 .49252 Mdot
.58366 .46761 Mdot
.5119 .52844 Mdot
.4237 .44169 Mdot
.47661 .47547 Mdot
.44825 .46622 Mdot
.51919 .43991 Mdot
.56911 .48943 Mdot
.49059 .52276 Mdot
.39751 .47182 Mdot
.49492 .53109 Mdot
.58448 .48963 Mdot
.52781 .48704 Mdot
.47823 .53208 Mdot
.49178 .49078 Mdot
.55632 .48439 Mdot
.5036 .53631 Mdot
.47946 .50955 Mdot
.49372 .50463 Mdot
.48063 .45334 Mdot
.40438 .57349 Mdot
.50566 .5769 Mdot
.46063 .54952 Mdot
.45557 .55073 Mdot
.481 .55295 Mdot
.49601 .51691 Mdot
.44206 .47348 Mdot
.48522 .53853 Mdot
.53803 .41035 Mdot
.57302 .50629 Mdot
.44505 .50682 Mdot
.45005 .46852 Mdot
.49937 .58279 Mdot
.51191 .49552 Mdot
.49082 .45864 Mdot
.49548 .53611 Mdot
.52318 .51094 Mdot
.47884 .49273 Mdot
.3926 .48732 Mdot
.52766 .48707 Mdot
.54384 .54258 Mdot
.52478 .49652 Mdot
.46916 .57382 Mdot
.49139 .52693 Mdot
.50237 .4413 Mdot
.53667 .51453 Mdot
.47698 .46415 Mdot
.57026 .5863 Mdot
.49246 .53051 Mdot
.54397 .4941 Mdot
.55073 .49281 Mdot
.44676 .51858 Mdot
.52791 .50683 Mdot
.48102 .47298 Mdot
.48543 .50429 Mdot
.51771 .50893 Mdot
.47651 .53941 Mdot
.52649 .46004 Mdot
.44682 .43766 Mdot
.48261 .47055 Mdot
.44783 .43433 Mdot
.51955 .53525 Mdot
.44781 .48464 Mdot
.48249 .50983 Mdot
.545 .5099 Mdot
.46292 .44604 Mdot
.47995 .472 Mdot
.53622 .49016 Mdot
.47803 .54115 Mdot
.42938 .54921 Mdot
.49373 .48284 Mdot
.51576 .50372 Mdot
.49867 .4157 Mdot
.52787 .47563 Mdot
.48511 .53563 Mdot
.52633 .58101 Mdot
.53589 .476 Mdot
.48731 .51207 Mdot
.4757 .52826 Mdot
.4781 .54834 Mdot
.48756 .50221 Mdot
.51561 .38757 Mdot
.59865 .42019 Mdot
.45299 .61656 Mdot
.5089 .53101 Mdot
.48901 .48187 Mdot
.53588 .52741 Mdot
.44952 .45613 Mdot
.48948 .50786 Mdot
.49673 .50623 Mdot
.48968 .61625 Mdot
.5321 .52592 Mdot
.48088 .47005 Mdot
.47508 .52967 Mdot
.45939 .44867 Mdot
.41689 .44592 Mdot
.41002 .45355 Mdot
.54501 .54463 Mdot
.53735 .54621 Mdot
.50995 .52035 Mdot
.50643 .54155 Mdot
.47749 .5567 Mdot
.49754 .53999 Mdot
.48922 .46807 Mdot
.45715 .55155 Mdot
.47837 .47824 Mdot
.47702 .5349 Mdot
.49456 .4454 Mdot
.45812 .44983 Mdot
.48751 .48658 Mdot
.5752 .467 Mdot
.57989 .4555 Mdot
.55234 .54474 Mdot
.49238 .49208 Mdot
.49915 .49407 Mdot
.54135 .4976 Mdot
.52385 .52398 Mdot
.52506 .48071 Mdot
.42416 .40552 Mdot
.51224 .51771 Mdot
.44414 .49989 Mdot
.51897 .50698 Mdot
.49693 .53307 Mdot
.4879 .4861 Mdot
.4222 .45887 Mdot
.52842 .55772 Mdot
.60947 .52584 Mdot
.44588 .50524 Mdot
.45181 .50093 Mdot
.56063 .48076 Mdot
.50458 .45105 Mdot
.44514 .40161 Mdot
.52691 .5328 Mdot
.52446 .57651 Mdot
.55633 .57793 Mdot
.48769 .51878 Mdot
.47731 .53349 Mdot
.55774 .52144 Mdot
.49176 .46013 Mdot
.52155 .54853 Mdot
.50407 .42685 Mdot
.48659 .53408 Mdot
.4754 .46302 Mdot
.4601 .54698 Mdot
.54076 .51243 Mdot
.46379 .54679 Mdot
.52847 .5372 Mdot
.48423 .47135 Mdot
.52741 .53215 Mdot
.46102 .46343 Mdot
.51813 .47749 Mdot
.46737 .45507 Mdot
.47386 .46167 Mdot
.4486 .54112 Mdot
.45484 .61796 Mdot
.51334 .48621 Mdot
.45956 .44765 Mdot
.5589 .50986 Mdot
.41822 .43124 Mdot
.50837 .50866 Mdot
.4781 .47249 Mdot
.50003 .53393 Mdot
.47569 .53032 Mdot
.52444 .50191 Mdot
.41921 .48098 Mdot
.48695 .50333 Mdot
.4309 .55783 Mdot
.57793 .39684 Mdot
.50409 .48391 Mdot
.48357 .51378 Mdot
.45157 .53885 Mdot
.58169 .49086 Mdot
.45873 .42081 Mdot
.51672 .50579 Mdot
.45687 .55633 Mdot
.5645 .44472 Mdot
.43174 .45241 Mdot
.55051 .53738 Mdot
.57225 .44549 Mdot
.55832 .5057 Mdot
.52452 .42985 Mdot
.4958 .42288 Mdot
.49779 .52273 Mdot
.56382 .46954 Mdot
.48326 .45973 Mdot
.50154 .52803 Mdot
.54133 .4909 Mdot
.53328 .5016 Mdot
.38673 .50893 Mdot
.52118 .45112 Mdot
.44996 .52231 Mdot
.47641 .46255 Mdot
.54321 .44965 Mdot
.47801 .47818 Mdot
.53292 .50092 Mdot
.48114 .47886 Mdot
.4159 .5806 Mdot
.59341 .42422 Mdot
.50953 .48782 Mdot
.47574 .48712 Mdot
.58061 .4689 Mdot
.49821 .46978 Mdot
.48141 .47096 Mdot
.45449 .4742 Mdot
.51618 .48708 Mdot
.55261 .54698 Mdot
.4863 .48743 Mdot
.48048 .52533 Mdot
.48952 .49798 Mdot
.49971 .48347 Mdot
.51143 .50331 Mdot
.53531 .48335 Mdot
.44678 .4753 Mdot
.49599 .50022 Mdot
.52592 .48563 Mdot
.48247 .52036 Mdot
.49084 .56232 Mdot
.43589 .46556 Mdot
.55652 .49192 Mdot
.51357 .55832 Mdot
.4944 .44664 Mdot
.58406 .49425 Mdot
.51458 .42729 Mdot
.53184 .43387 Mdot
.44161 .53011 Mdot
.4611 .46335 Mdot
.38661 .50798 Mdot
.50658 .52814 Mdot
.4441 .55486 Mdot
.49092 .52178 Mdot
.51352 .51031 Mdot
.4439 .52751 Mdot
.553 .45465 Mdot
.49052 .44651 Mdot
.48921 .42229 Mdot
.49843 .51806 Mdot
.45079 .53815 Mdot
.49467 .57624 Mdot
.464 .38897 Mdot
.55216 .53821 Mdot
.50678 .5233 Mdot
.50406 .47034 Mdot
.47877 .53575 Mdot
.54561 .48979 Mdot
.49918 .41836 Mdot
.43134 .5752 Mdot
.5395 .54835 Mdot
.59226 .44622 Mdot
.5223 .52623 Mdot
.47683 .50687 Mdot
.54624 .44496 Mdot
.44798 .47623 Mdot
.50728 .53476 Mdot
.48786 .43172 Mdot
.49742 .52754 Mdot
.47118 .5252 Mdot
.5413 .50144 Mdot
.45221 .50337 Mdot
.53236 .48071 Mdot
.5096 .45574 Mdot
.47643 .54518 Mdot
.58238 .55705 Mdot
.48005 .5045 Mdot
.53336 .49669 Mdot
.49595 .56557 Mdot
.44546 .46073 Mdot
.54451 .49153 Mdot
.47552 .52806 Mdot
.5308 .49399 Mdot
.53823 .5497 Mdot
.52651 .54191 Mdot
.45292 .41795 Mdot
.49123 .52298 Mdot
.56651 .49707 Mdot
.49516 .52454 Mdot
.5373 .47723 Mdot
.47999 .55147 Mdot
.52516 .48045 Mdot
.47661 .46221 Mdot
.53352 .49813 Mdot
.55553 .5146 Mdot
.4735 .44287 Mdot
.48128 .48072 Mdot
.50905 .53008 Mdot
.58893 .43413 Mdot
.58535 .47149 Mdot
.5543 .51019 Mdot
.55363 .44037 Mdot
.48726 .50337 Mdot
.53822 .51778 Mdot
.54154 .50458 Mdot
.51586 .48648 Mdot
.61296 .53619 Mdot
.52639 .46651 Mdot
.42754 .5448 Mdot
.48967 .47676 Mdot
.50582 .49635 Mdot
.4774 .53303 Mdot
.44217 .47275 Mdot
.55293 .46909 Mdot
.50705 .53173 Mdot
.4976 .54216 Mdot
.53779 .48168 Mdot
.48047 .47015 Mdot
.47571 .46082 Mdot
.53729 .38473 Mdot
.57307 .46535 Mdot
.45501 .54008 Mdot
.44283 .4 Mdot
.44054 .47647 Mdot
.47962 .46941 Mdot
.50921 .47126 Mdot
.53278 .52613 Mdot
.45074 .44521 Mdot
.4447 .52621 Mdot
.56092 .56627 Mdot
.50172 .40287 Mdot
.52299 .51327 Mdot
.48141 .48067 Mdot
.49766 .43884 Mdot
.50545 .52085 Mdot
.48754 .50456 Mdot
.45538 .54606 Mdot
.52348 .51324 Mdot
.49661 .49848 Mdot
.46668 .54961 Mdot
.50628 .42612 Mdot
.45617 .55493 Mdot
.52576 .52807 Mdot
.47301 .4135 Mdot
.51405 .53673 Mdot
.49324 .59178 Mdot
.49484 .42931 Mdot
.49659 .54132 Mdot
.42433 .50847 Mdot
.52425 .45798 Mdot
.55774 .50598 Mdot
.49902 .51928 Mdot
.47729 .53293 Mdot
.47889 .47004 Mdot
.52826 .4878 Mdot
.42317 .59021 Mdot
.61453 .53893 Mdot
.47983 .62211 Mdot
.53919 .47737 Mdot
.4934 .5128 Mdot
.40207 .5392 Mdot
.5172 .5497 Mdot
.51849 .47836 Mdot
.4782 .49845 Mdot
.52947 .55114 Mdot
.46133 .6008 Mdot
.47249 .46199 Mdot
.49809 .49484 Mdot
.48033 .57239 Mdot
.58504 .48451 Mdot
.48992 .49283 Mdot
.40825 .42626 Mdot
.48711 .5152 Mdot
.54038 .5028 Mdot
.51708 .52569 Mdot
.51705 .52887 Mdot
.55183 .45442 Mdot
.53356 .51429 Mdot
.54748 .50303 Mdot
.51284 .53564 Mdot
.54527 .46292 Mdot
.49686 .52196 Mdot
.5133 .56179 Mdot
.50298 .4672 Mdot
.48506 .5329 Mdot
.52943 .46821 Mdot
.44729 .51769 Mdot
.44862 .48638 Mdot
.52332 .51761 Mdot
.47383 .53275 Mdot
.52331 .53963 Mdot
.52713 .49683 Mdot
.46107 .55214 Mdot
.62436 .49239 Mdot
.48982 .44346 Mdot
.49563 .56064 Mdot
.48061 .47444 Mdot
.5108 .50823 Mdot
.42565 .49103 Mdot
.45485 .536 Mdot
.55695 .44421 Mdot
.50017 .52787 Mdot
.48293 .53069 Mdot
.53061 .49816 Mdot
.43113 .39453 Mdot
.49414 .51907 Mdot
.52533 .52355 Mdot
.44241 .47599 Mdot
.4292 .40048 Mdot
.53704 .5211 Mdot
.50664 .51927 Mdot
.49551 .5725 Mdot
.4911 .48211 Mdot
.59984 .56441 Mdot
.55103 .5535 Mdot
.58733 .43153 Mdot
.44699 .55161 Mdot
.53935 .54188 Mdot
.46053 .44344 Mdot
.49887 .52629 Mdot
.48273 .46923 Mdot
.53039 .46977 Mdot
.50425 .45354 Mdot
.46071 .45329 Mdot
.50291 .46529 Mdot
.44345 .47943 Mdot
.54365 .44393 Mdot
.51472 .52326 Mdot
.42447 .44636 Mdot
.54167 .5121 Mdot
.49931 .53172 Mdot
.4901 .41844 Mdot
.4675 .55764 Mdot
.47836 .48373 Mdot
.60391 .56772 Mdot
.49373 .40276 Mdot
.45953 .50891 Mdot
.50069 .51849 Mdot
.48114 .49111 Mdot
.50275 .49408 Mdot
.48231 .48171 Mdot
.50879 .46247 Mdot
.46443 .57313 Mdot
.53171 .51832 Mdot
.47854 .48148 Mdot
.47456 .55644 Mdot
.44333 .48897 Mdot
.5289 .48016 Mdot
.41953 .57207 Mdot
.45004 .49676 Mdot
.57915 .5903 Mdot
.47655 .50257 Mdot
.39342 .4291 Mdot
.50223 .51873 Mdot
.52108 .4908 Mdot
.4542 .42894 Mdot
.4001 .54574 Mdot
.49294 .49996 Mdot
.50912 .54837 Mdot
.52308 .53911 Mdot
.49052 .45379 Mdot
.42356 .54165 Mdot
.54749 .49631 Mdot
.5132 .53163 Mdot
.47638 .48613 Mdot
.51506 .55144 Mdot
.5408 .488 Mdot
.47572 .52749 Mdot
.53907 .48421 Mdot
.56615 .51548 Mdot
.50296 .56074 Mdot
.48284 .47057 Mdot
.51653 .56614 Mdot
.47102 .57097 Mdot
.55096 .3892 Mdot
.39384 .48246 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`00007o410@
0Oooool1ooooo`00E?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo02_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Oooooo00?o0000ooooooooool00_ooool005Cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000;?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000003Oooooo00?o0000ooooooooool00_ooool005Cooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02cooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0gooooo`03o`000?oooooooooo00;ooooo001Dooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0[ooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool0000]ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<02cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`0=oooool00ol0003oooooooooo`02ooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool0:_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l00000;Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
;_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400goooo
o`03o`000?oooooooooo00;ooooo001Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@02cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000002gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000=oooool00ol0
003oooooooooo`02ooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`0/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410/ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY03Gooooo00?oEEEE
ofIVI_l000001?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool001koooooool00017o`0000Cooooo000Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOoo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3oooooodSooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`2Nooooo`;o00001?ooool2o`000:7ooooo000N
ooooo`03o`000?oooooooooo09kooooo0_l00004ooooo`;o00001Oooool2o`0009[ooooo000Noooo
o`03o`000?oooooooooo09?ooooo0_l00008ooooo`;o00001Oooool2o`0000Gooooo0_l0002Joooo
o`007_ooool00ol0003oooooooooo`2Cooooo`;o00002?ooool2o`0000Gooooo0_l00009ooooo`;o
0000U_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003
oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0R?ooool2o`0001[ooooo0_l00008ooooo`?o
0000U_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo08Sooooo0_l0000Tooooo`;o00002?ooool2o`0008go
oooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol00027ooooo`;o
00000oooool2o`0002[ooooo0_l0002=ooooo`000oooool01Ol0003ooooooooooooooooo000000_o
oooo00CoA4A4omgMgOoooooo00001oooool00ol0003oooooooooo`27ooooo`;o00000oooool3o`00
00gooooo0_l000000ooooooo0000o`00002Vooooo`000oooool01Ol0003ooooooooooooooooo0000
00_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`26ooooo`;o00001Oooool2
o`0000gooooo0_l000000ooooooo0000o`00002Vooooo`000oooool01Ol@413ooooooooooooooooo
410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`26ooooo`;o00002_ooool2
o`0001Oooooo0_l0002Jooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000001oooool00ol0003oooooooooo`25ooooo`;o00001?ooool2o`0000Gooooo0_l00002
ooooo`;o00004oooool2o`0009[ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool0
0omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo08Gooooo0_l00004ooooo`;o00002Oooool2
o`0000Kooooo0_l0000Oooooo`;o0000Q_ooool001kooooo00?o0000ooooooooool0Soooool2o`00
00[ooooo0_l000000ooooooo0000o`00000>ooooo`;o00003oooool2o`0008Kooooo000Nooooo`03
o`000?oooooooooo08oooooo1?l00003ooooo`;o00000oooool5o`0000;ooooo0_l0000:ooooo`;o
00003oooool2o`0008Kooooo000Nooooo`03o`000?oooooooooo087ooooo0_l0000>ooooo`;o0000
0oooool2o`0000?ooooo1?l00003ooooo`;o00003_ooool2o`0000Wooooo1?l00026ooooo`007_oo
ool00ol0003oooooooooo`21ooooo`;o00002oooool4o`0000Cooooo0_l00005ooooo`;o000000Co
ooooo`000?l0003ooooo0_l0000=ooooo`;o00002Oooool2o`0008Sooooo000Nooooo`03o`000?oo
oooooooo07Cooooo0_l00006ooooo`Co000000Coooooo`000?l0003ooooo0_l00008ooooo`Co0000
2?ooool2o`000004ooooool0003o0000ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Coooo
o`;o0000R_ooool001kooooo00?o0000ooooooooool0M?ooool2o`0000Kooooo1?l000001?oooooo
0000o`000?ooool2o`0000Oooooo0_l000000ooooooo0000o`000008ooooo`Go000000Goooooo`00
0?l0003o0000ooooo`04o`000003ooooool0003o000000cooooo0_l00002ooooo`;o0000R_ooool0
01kooooo00?o0000ooooooooool0O_ooool2o`000003ooooool0003o000000[ooooo0_l00007oooo
o`Co000000?oooooo`000?l000000_l00002ooooo`;o000000?oooooo`000?l000000_l000001?oo
oooo0000o`000?l0000;ooooo`;o00000_ooool2o`0008[ooooo000Nooooo`03o`000?oooooooooo
08gooooo0_l00007ooooo`Co00001?ooool2o`0000Gooooo0ol000000ooooooo0000o`000002o`00
00?ooooo0_l0002Eooooo`007_ooool00ol0003oooooooooo`26ooooo`;o00002_ooool7o`0000;o
oooo0_l000000ooooooo0000o`000003o`0000;ooooo0ol00003ooooo`Co000000Coooooo`000?l0
003o0000U?ooool001kooooo00?o0000ooooooooool0Poooool2o`000003ooooool0003o000000Ko
oooo0_l000000ooooooo0000o`000006o`000003ooooool0003o000000Oo00000_ooool2o`0000Co
oooo1?l00002ooooo`Co000000?oooooo`000?l000001?ooool2o`0008Wooooo000Nooooo`03o`00
0?oooooooooo08?ooooo0_l000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l00000
0ol00004ooooo`Go00000oooool2o`000003ooooool0003o000000;ooooo1ol00003ooooo`;o0000
00?oooooo`000?l000001?ooool2o`0008Wooooo000Nooooo`;o0000P_ooool2o`0000Gooooo1?l0
0005ooooo`Go00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`000003ooooool0
003o000000Co000000?oooooo`000?l000000_l0000;ooooo`;o0000R_ooool001kooooo00?o0000
ooooooooool0POooool2o`0000Gooooo1?l00002ooooo`So00000_ooool2o`000003ooooool0003o
000000;o000000?oooooo`000?l000000_l000000ooooooo0000o`000003o`0000Gooooo0ol00006
ooooo`;o000000Coooooo`000?l0003o0000ROooool001kooooo00?o0000ooooooooool0QOooool2
o`0000Oooooo2?l00003ooooo`Co000000Goooooo`000?l0003o0000ooooo`02o`000003ooooool0
003o000000;o00001_ooool3o`0000Kooooo0_l00002ooooo`;o0000ROooool001kooooo00?o0000
ooooooooool0QOooool2o`0000Kooooo1?l000000ooooooo0000o`00000@o`000003ooooool0003o
000000;o00000_ooool2o`0000Cooooo1Ol0002Aooooo`007_ooool00ol0003oooooooooo`2:oooo
o`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000006o`0000;ooooo2?l00003oooo
o`;o00000_ooool4o`0000;ooooo1ol0002?ooooo`007_ooool00ol0003oooooooooo`2:ooooo`;o
000000Coooooo`000?l0003o00000_ooool2o`000003ooooool0003o000000[o000000?oooooo`00
0?l000000oooool3o`0000?ooooo0_l00007ooooo`Ko0000Roooool001kooooo00?o0000oooooooo
ool0OOooool2o`0000gooooo1?l00007ooooo`ko00000_ooool3o`000003ooooool0003o000000?o
oooo1Ol00002ooooo`Go0000Roooool001kooooo00?o0000ooooooooool0OOooool2o`000003oooo
ool0003o000000Kooooo0ol000001Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`000?l0
00000_ooool5o`000003ooooool0003o000000Ko000000?oooooo`000?l000001_l00002ooooo`Go
00001Oooool3o`0008[ooooo000Nooooo`03o`000?oooooooooo083ooooo0_l00006ooooo`[o0000
00?oooooo`000?l000000_ooool9o`000003ooooool0003o000000_o00000_ooool2o`0000Wooooo
0_l0002:ooooo`007_ooool00ol0003oooooooooo`24ooooo`;o00001Oooool6o`0000Kooooo0ol0
00000ooooooo0000o`000002o`000003ooooool0003o000000Co000000?oooooo`000?l000001Ol0
0002ooooo`Co000000?oooooo`000?l000000oooool2o`0008_ooooo000Nooooo`03o`000?oooooo
oooo07cooooo0_l00004ooooo`Co00001Oooool3o`000003ooooool0003o000000Kooooo6Ol00002
ooooo`;o000000?oooooo`000?l000000oooool2o`0008_ooooo000Nooooo`03o`000?oooooooooo
07cooooo0_l00004ooooo`Go00000oooool6o`0000Oooooo5_l000001?oooooo0000o`000?ooool2
o`0000Gooooo1?l0002;ooooo`007_ooool00ol0003oooooooooo`1looooo`;o00001Oooool4o`00
00?ooooo1_l00007ooooo`;o000000?oooooo`000?l000000ol00002ooooo`ko00000_ooool2o`00
00;ooooo0_l000000ooooooo0000o`000002o`0008_ooooo000Nooooo`03o`000?oooooooooo08Ko
oooo0_l00004ooooo`Co00001oooool8o`000003ooooool0003o0000017o00000_ooool3o`000004
ooooool0003o0000o`0000_ooooo0_l0001nooooo`007_ooool00ol0003oooooooooo`26ooooo`;o
00001Oooool3o`0000Oooooo0ol000000ooooooo0000o`00000>o`000003ooooool0003o000000Go
00000oooool2o`000004ooooool0003o0000o`0000_ooooo0_l0001nooooo`007_ooool00ol0003o
ooooooooo`26ooooo`;o00001Oooool4o`0000?ooooo0_l000000ooooooo0000o`000002oooooa3o
000000?oooooo`000?l000000_l000001?oooooo0000o`000?ooool4o`000004ooooool0003o0000
o`0008_ooooo000Nooooo`;o0000Poooool2o`0000Sooooo1Ol00003ooooo`;o000000Coooooo`00
0?l0003ooooo2?l00002ooooo`Oo000000?oooooo`000?l000001?l000000ooooooo0000o`000003
o`0008oooooo000Nooooo`03o`000?oooooooooo08;ooooo0_l00008ooooo`Go00001_oooolDo`00
0003ooooool0003o000000Oo00000_ooool2o`0008kooooo000Nooooo`03o`000?oooooooooo07[o
oooo0_l0000:ooooo`?o00000oooool7o`0000?ooooo2_l000000ooooooo0000o`00000@o`0000?o
oooo0ol0002>ooooo`007_ooool00ol0003oooooooooo`1jooooo`;o00002_ooool3o`0000?ooooo
0ol00002ooooo`;o00000oooool:o`000003ooooool0003o0000017o00000_ooool2o`0008oooooo
000Nooooo`03o`000?oooooooooo08Gooooo0_l00005ooooo`;o00002?ooool?o`000003ooooool0
003o000000co0000Toooool001kooooo00?o0000ooooooooool0QOooool2o`0000Gooooo0ol00004
ooooo`;o000000?oooooo`000?l000002Ol000000ooooooo0000o`00000;o`000003ooooool0003o
000000;ooooo0_l0002Aooooo`007_ooool00ol0003oooooooooo`1kooooo`;o00004?ooool3o`00
0003ooooool0003o000000;o00000ooooolEo`0000Kooooo0ol0002Aooooo`007_ooool00ol0003o
ooooooooo`1kooooo`;o00002Oooool2o`0000Gooooo0ol000001?oooooo0000o`000?ooool4o`00
0003ooooool0003o000000[o000000?oooooo`000?l000001?l00004ooooo`Go0000T_ooool001ko
oooo00?o0000ooooooooool0Q_ooool2o`0000Cooooo1?l00004ooooo`Ko000000?oooooo`000?l0
00003ol00003ooooo`Co00000_ooool2o`0000_ooooo0_l00023ooooo`007_ooool00ol0003ooooo
ooooo`24ooooo`;o00001Oooool5o`0000Gooooo1Ol00002oooooa3o00000oooool3o`0000?ooooo
0_l0000;ooooo`;o0000Poooool001kooooo00?o0000ooooooooool0Q?ooool2o`0000Gooooo1Ol0
0006oooooa3o000000?oooooo`000?l000000ol00004ooooo`;o0000UOooool001kooooo00?o0000
ooooooooool0S?ooool6o`0000?ooooo5_l00004ooooo`?o00002?ooool2o`0000Oooooo0_l00022
ooooo`007_ooool00ol0003oooooooooo`1oooooo`;o00002oooool@o`000003ooooool0003o0000
00co00000_ooool5o`0000;ooooo0_l00004ooooo`;o00001oooool3o`00087ooooo000Nooooo`03
o`000?oooooooooo07oooooo0_l00005ooooo`;o00001_ooool>o`000003ooooool0003o000000_o
000000?oooooo`000?l000001Ol00002ooooo`;o00000_ooool2o`0000[ooooo0_l00021ooooo`00
7_ooool00ol0003oooooooooo`1nooooo`;o00001_ooool3o`0000Gooooo1_l00003ooooo`?o0000
0oooool<o`0000;ooooo1ol00006ooooo`;o0000SOooool001kooooo00?o0000ooooooooool0O_oo
ool2o`0000Oooooo1?l00004ooooo`Ko00000_ooool2o`0000Oooooo2?l000000ooooooo0000o`00
0008o`0009Cooooo000Nooooo`;o0000O?ooool2o`0000[ooooo1?l00002ooooo`Wo000000Cooooo
o`000?l0003o00001oooool<o`0000?ooooo1?l000000ooooooo0000o`00002@ooooo`007_ooool0
0ol0003oooooooooo`1kooooo`;o00002_ooool2o`0000?ooooo2_l00002ooooo`;o000000?ooooo
o`000?l000000_l00004ooooo`Co000000?oooooo`000?l000001ol000001?oooooo0000o`000?oo
ool2o`00093ooooo000Nooooo`03o`000?oooooooooo08Sooooo0_l00002ooooo`ko000000?ooooo
o`000?l000000ol00004ooooo`;o00000_ooool2o`0000?ooooo1?l00008ooooo`;o0000S?ooool0
01kooooo00?o0000ooooooooool0Q_ooool4o`0000Kooooo0ol000000ooooooo0000o`000004o`00
0003ooooool0003o000000Go000000?oooooo`000?l000001Ol0000?ooooo`;o0000S?ooool001ko
oooo00?o0000ooooooooool0Q?ooool4o`0000Wooooo0_l000001Ooooooo0000o`000?l0003ooooo
00;o000000?oooooo`000?l000001Ol000000ooooooo0000o`000003o`0000Sooooo0_l0002Eoooo
o`007_ooool00ol0003oooooooooo`24ooooo`;o00002oooool2o`0000;ooooo3?l000000ooooooo
0000o`000002o`0000[ooooo1?l0000;ooooo`;o0000Q_ooool001kooooo00?o0000ooooooooool0
S_ooool2o`000003ooooool0003o000000Cooooo1Ol000000ooooooo0000o`000002o`000003oooo
ool0003o000000;o00003?ooool2o`0000_ooooo0ol00025ooooo`007_ooool00ol0003ooooooooo
o`1oooooo`;o00000oooool2o`0000Sooooo0_l000000ooooooo0000o`000004o`000003ooooool0
003o000000?ooooo0_l0000Qooooo`;o0000QOooool001kooooo00?o0000ooooooooool0Ooooool2
o`0000?ooooo0_l00002ooooo`;o00001oooool6o`000003ooooool0003o000000?ooooo0ol00006
ooooo`;o00000oooool2o`0009[ooooo000Nooooo`03o`000?oooooooooo08Sooooo0_l0000:oooo
o`;o00001oooool5o`0000Cooooo0_l00003ooooo`;o00001?ooool2o`0009Cooooo000Nooooo`03
o`000?oooooooooo08?ooooo0_l0000Kooooo`;o00001Oooool2o`0000Sooooo0_l0002Dooooo`00
7_ooool00ol0003oooooooooo`23ooooo`;o00006Oooool2o`0000Oooooo0_l0002Nooooo`007_oo
ool00ol0003oooooooooo`23ooooo`;o00006Oooool4o`0001?ooooo0_l00002ooooo`;o0000S?oo
ool001kooooo00?o0000ooooooooool0QOooool2o`0001Gooooo0_l00002ooooo`;o00002Oooool2
o`0000Sooooo0_l000001?oooooo0000o`000?l0002<ooooo`000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003ooooo
ooooo`25ooooo`Co00004oooool2o`0000gooooo0_l0000;ooooo`;o0000SOooool000?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Ko
oooo00?o0000ooooooooool0Qoooool3o`0001Gooooo0_l0000=ooooo`;o0000Uoooool000?ooooo
00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`00
08Sooooo0_l00008ooooo`;o00002oooool2o`0000gooooo0_l0002Gooooo`000oooool01Ol0003o
oooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooo
oooo09;ooooo0_l0000Eooooo`;o0000W?ooool000?ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2Yooooo`;o0000W?oo
ool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o
0000ooooooooool0V?ooool2o`000:gooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo09Sooooo0_l0002]ooooo`000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003ooooo
ooooo`2?ooooo`;o00002_ooool2o`000:[ooooo000Nooooo`03o`000?oooooooooo08oooooo0ol0
0009ooooo`;o0000Z_ooool001kooooo00?o0000ooooooooool0T?ooool2o`0000Kooooo1?l00000
0ooooooo0000o`00002Xooooo`007_ooool00ol0003oooooooooo`2Hooooo`Oo0000Z?ooool001ko
oooo00?o0000ooooooooool0V_ooool4o`000:Wooooo000Nooooo`03o`000?oooooooooo09[ooooo
0_l0002[ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003ooooo
odWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?ooooooB?oo
ool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooo
oonHV9So8B4Q00Kooooo00?o0000ooooooooool0oooooom8ooooo`000oooool01Ol@413ooooooooo
oooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000oooooom8ooooo`00
0oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06oooo
o`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go0000ooooooooooooooooo`00000;oooo
o`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`3oooooodSooooo0003oooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o
0000ooooooooool0oooooom8ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0?ooooooB?ooool000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Dooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3o
ooooodSooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom8oooo
o`005_ooool00ol0003oooooooooo`05ooooo`?o0000oooooom8ooooo`005_ooool00ol0003ooooo
ooooo`3ooooooe3ooooo000Fooooo`03o`000?oooooooooo0?ooooooD?ooool001Kooooo00?o0000
ooooooooool0oooooom@ooooo`005_ooool00ol0003oooooooooo`3ooooooe3ooooo000Dooooo`03
oeEEEOmVIVKo00000?ooooooD_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0926677, -0.0670041, \
0.00384473, 0.00384473}}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[Table[{n\ \[CapitalDelta]t, kineticenergy[n]}, {n, 0, 50}], 
        PlotJoined \[Rule] True, 
        PlotLabel \[Rule] \ "\<kinetic energy versus time\>", \ 
        AxesLabel \[Rule] {"\<t\>", "\<\>"}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.92"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 15.873 -0.268776 5.2679e-06 [
[.18254 .0348 -12 -9 ]
[.18254 .0348 12 0 ]
[.34127 .0348 -12 -9 ]
[.34127 .0348 12 0 ]
[.5 .0348 -12 -9 ]
[.5 .0348 12 0 ]
[.65873 .0348 -12 -9 ]
[.65873 .0348 12 0 ]
[.81746 .0348 -12 -9 ]
[.81746 .0348 12 0 ]
[.97619 .0348 -12 -9 ]
[.97619 .0348 12 0 ]
[1.025 .0473 0 -6 ]
[1.025 .0473 10 6 ]
[.01131 .15266 -30 -4.5 ]
[.01131 .15266 0 4.5 ]
[.01131 .25801 -36 -4.5 ]
[.01131 .25801 0 4.5 ]
[.01131 .36337 -36 -4.5 ]
[.01131 .36337 0 4.5 ]
[.01131 .46873 -36 -4.5 ]
[.01131 .46873 0 4.5 ]
[.01131 .57409 -36 -4.5 ]
[.01131 .57409 0 4.5 ]
[.5 .63053 -80 0 ]
[.5 .63053 80 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .0473 m
.18254 .05355 L
s
[(0.01)] .18254 .0348 0 1 Mshowa
.34127 .0473 m
.34127 .05355 L
s
[(0.02)] .34127 .0348 0 1 Mshowa
.5 .0473 m
.5 .05355 L
s
[(0.03)] .5 .0348 0 1 Mshowa
.65873 .0473 m
.65873 .05355 L
s
[(0.04)] .65873 .0348 0 1 Mshowa
.81746 .0473 m
.81746 .05355 L
s
[(0.05)] .81746 .0348 0 1 Mshowa
.97619 .0473 m
.97619 .05355 L
s
[(0.06)] .97619 .0348 0 1 Mshowa
.125 Mabswid
.05556 .0473 m
.05556 .05105 L
s
.0873 .0473 m
.0873 .05105 L
s
.11905 .0473 m
.11905 .05105 L
s
.15079 .0473 m
.15079 .05105 L
s
.21429 .0473 m
.21429 .05105 L
s
.24603 .0473 m
.24603 .05105 L
s
.27778 .0473 m
.27778 .05105 L
s
.30952 .0473 m
.30952 .05105 L
s
.37302 .0473 m
.37302 .05105 L
s
.40476 .0473 m
.40476 .05105 L
s
.43651 .0473 m
.43651 .05105 L
s
.46825 .0473 m
.46825 .05105 L
s
.53175 .0473 m
.53175 .05105 L
s
.56349 .0473 m
.56349 .05105 L
s
.59524 .0473 m
.59524 .05105 L
s
.62698 .0473 m
.62698 .05105 L
s
.69048 .0473 m
.69048 .05105 L
s
.72222 .0473 m
.72222 .05105 L
s
.75397 .0473 m
.75397 .05105 L
s
.78571 .0473 m
.78571 .05105 L
s
.84921 .0473 m
.84921 .05105 L
s
.88095 .0473 m
.88095 .05105 L
s
.9127 .0473 m
.9127 .05105 L
s
.94444 .0473 m
.94444 .05105 L
s
.25 Mabswid
0 .0473 m
1 .0473 L
s
gsave
1.025 .0473 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .15266 m
.03006 .15266 L
s
[(80000)] .01131 .15266 1 0 Mshowa
.02381 .25801 m
.03006 .25801 L
s
[(100000)] .01131 .25801 1 0 Mshowa
.02381 .36337 m
.03006 .36337 L
s
[(120000)] .01131 .36337 1 0 Mshowa
.02381 .46873 m
.03006 .46873 L
s
[(140000)] .01131 .46873 1 0 Mshowa
.02381 .57409 m
.03006 .57409 L
s
[(160000)] .01131 .57409 1 0 Mshowa
.125 Mabswid
.02381 .07364 m
.02756 .07364 L
s
.02381 .09998 m
.02756 .09998 L
s
.02381 .12632 m
.02756 .12632 L
s
.02381 .179 m
.02756 .179 L
s
.02381 .20534 m
.02756 .20534 L
s
.02381 .23167 m
.02756 .23167 L
s
.02381 .28435 m
.02756 .28435 L
s
.02381 .31069 m
.02756 .31069 L
s
.02381 .33703 m
.02756 .33703 L
s
.02381 .38971 m
.02756 .38971 L
s
.02381 .41605 m
.02756 .41605 L
s
.02381 .44239 m
.02756 .44239 L
s
.02381 .49507 m
.02756 .49507 L
s
.02381 .52141 m
.02756 .52141 L
s
.02381 .54775 m
.02756 .54775 L
s
.02381 .02096 m
.02756 .02096 L
s
.02381 .60043 m
.02756 .60043 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -141 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(kinetic) show
111.000 13.000 moveto
(energy) show
153.000 13.000 moveto
(versus) show
195.000 13.000 moveto
(time) show
219.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .05146 m
.04286 .14674 L
.0619 .34345 L
.08095 .55589 L
.1 .60332 L
.11905 .44224 L
.1381 .23021 L
.15714 .0821 L
.17619 .01472 L
.19524 .02415 L
.21429 .10778 L
.23333 .25784 L
.25238 .42939 L
.27143 .52827 L
.29048 .48481 L
.30952 .34011 L
.32857 .19525 L
.34762 .10723 L
.36667 .08227 L
.38571 .10981 L
.40476 .1748 L
.42381 .2602 L
.44286 .34489 L
.4619 .40302 L
.48095 .40767 L
.5 .35323 L
.51905 .27161 L
.5381 .203 L
.55714 .16601 L
.57619 .15904 L
.59524 .1766 L
.61429 .21288 L
.63333 .25906 L
.65238 .30363 L
.67143 .33429 L
.69048 .34116 L
.70952 .32255 L
.72857 .28628 L
.74762 .24765 L
.76667 .22043 L
.78571 .20936 L
.80476 .21241 L
.82381 .22527 L
.84286 .24189 L
.8619 .25974 L
.88095 .27886 L
.9 .29352 L
.91905 .29713 L
.9381 .29004 L
.95714 .27729 L
Mistroke
.97619 .26268 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo000dooooo`03o`000?oooooooooo01co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Cooooo1?l000000ol@413oooooooooo`0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`Go00004_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01OnH
V9So410@o`000?lb<S;oc<c<017ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_l000000ol@413oooooooooo`0@ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04oooo
o`05odA4A?l0003o0000oc8b<_oMgMd04Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?l@413oc<c<00ko
oooo000dooooo`03o`000?oooooooooo01cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool04Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A401;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go410@okZj^_ooooooMgMgoc8b<P0A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`06ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo00?oMgMgoc8b<_ooool04?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool01OmEEEGoMgMgoooooonHV9So8B4Q00kooooo000dooooo`03o`000?oooooooooo01cooooo00Go
410@oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003o
ooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo
410@00Cooooo00?oV9RHob4Q8Oo^k^h04oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
410@oooooooooooooooooa0@4007ooooo`03o`000?oooooooooo00oooooo00Go410@oooooooooooo
oooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41000oooool5o`0001;ooooo00Go410@oooo
oooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003ooooooooo
o`0?ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go0000ooooooooooooooooo`00000>ooooo`00=?ooool00ol0003oooooooooo`0Looooo`05
o`000?ooooooooooooooool000002Oooool3o`0000?ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Aooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooo
oooo000000Gooooo00?oV9RHob4Q8Oo^k^h04_ooool01Ol0003ooooooooooooooooo000000_ooooo
00Go0000ooooooooooooooooo`000006ooooo`03ojVYZOl@413ooooo013ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`05o`000?ooooooooooooooool000000oooool01?m4A4CogMgMooooool0
000Cooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000Oo
oooo00?oMgMgoc8b<_ooool04?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?nHV9SooooooiRHV?lQ8B403_ooool003Cooooo00?o0000
ooooooooool07?ooool01Ol0003ooooooooooooooooo000000Wooooo00Co0000ooooool0003o0000
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo017ooooo00Go0000oooooooooooo
ooooo`00000;ooooo`05o`000?ooooooooooooooool000001_ooool00omgMgOoIVIVooooo`0Aoooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000Gooooo00?o
410@o`000?nj^[X04Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oooooooooooo
ooooo`000003ooooo`04omgMgOmEEEGoooooo`0001?ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<017ooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003oEEEEo`000?l@413oc<c<00kooooo000dooooo`;o00007Oooool01Ol@413ooooooooooooooooo
410@00Wooooo00Oo0000ooooool@413oooooo`000?oooooo410@00Kooooo00?o0000ooooooooool0
4Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4007oooo
o`03o`000?oooooooooo013ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?oooooo
ooooooooool@41001_ooool00onj^[[o8B4Qooooo`0@ooooo`05oa0@4?ooooooooooooooool@4100
2oooool01Ol@413ooooooooooooooooo410@00Cooooo00?oMgMgolc<c?l000004oooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4004ooooo`03o`000?oooooo
oooo01?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@4100
0oooool00omEEEGoQhN7ooooo`0@ooooo`00=?ooool00ol0003oooooooooo`0Looooo`05ogMgMonH
V9SooooooiRHV?mgMgL02?ooool02?l0003ooooooooooomgMgOoV9RHooooool0003oMgMg1_ooool0
0ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00Go0000okZj^_ooooooV9RHoa0@400Booooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go410@oiRHV?oooooo^[Zjo`00
000Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Co
oooo00?ok^k^odA4A?l000004oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`04ooooo`03o`000?oooooooooo01?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool00ooMgMgo410@oiRHV00@ooooo`00=?oo
ool00ol0003oooooooooo`0Looooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool01Ol0003ooooo
ooooooo^k^ko<S8b00;o000000?ok^k^ooooooooool00_ooool00omEEEGoIVIVo`00000Cooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c00Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0Aooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?oMgMgo`000?ooool04_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`Co
00004_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04
ooooo`04olc<c?m4A4Co0000oa0@40kooooo000dooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`3oooooo`00=?ooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0o_ooool003Cooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?Gooooo00GoV9RHo`000?l0
003oA4A4okZj^P04ooooo`00=?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0mOooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo000dooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3eooooo`03
o`000?oooooooooo00Kooooo000]oooooooo0000:?l0000;ooooo`03o`000?oooooooooo00Kooooo
000dooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000Gooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Ko
oooo000dooooo`03o`000?oooooooooo02Oooooo00Go0000ooooooooooooooooo`000005ooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0>ooooo`03
oa0@4?l0003o000000?o00001Oooool003Cooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo0?Cooooo00?o0000ooooooooool01_ooool003Cooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0??ooooo00?o
0000ooooooooool01_ooool003Cooooo0_l0000Wooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0o?ooool003Cooooo0_l0000Vooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0o?ooool003Cooooo0_l0000Vooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0o?ooool003Cooooo0_l0000Vooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
o?ooool003Cooooo0_l0000Uooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0nooo
ool003Cooooo00?o0000ooooool000009?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool0c?ooool003Cooooo00?o0000ooooool000009?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0c?ooool003Co
oooo00?o0000ooooool000009?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02_o
oooo00?o0000ooooool00000cOooool003Cooooo00?o0000ooooool000009?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`00003<ooooo`00
=?ooool00ol0003oooooo`00000Tooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0<[ooooo000dooooo`03o`000?oo
oooo000002?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0bOooool003Cooooo0_l000000ooooooo0000ooooo`0Q
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0<Wooooo000dooooo`04o`000?ooooooooooo`0002;ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0b?ooool003Cooooo00Co0000oooooooooooo00008_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`37
ooooo`00=?ooool01?l0003oooooooooool0000Rooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0<Oooooo000doooo
o`04o`000?ooooooooooo`0002;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0aoooool003Cooooo00Co0000oooo
oooooooo00008_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`36ooooo`00=?ooool01Ol0003ooooooooooooooooo
0000023ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0a_ooool003Cooooo0_l00002ooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0a_ooool003Cooooo00Go0000ooooooooooooooooo`00000Poooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo0<Gooooo000dooooo`05o`000?ooooooooooooooool000008?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`35ooooo`00=?ooool01Ol0003ooooooooooooooooo0000023ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool0aOooool003Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo0<Cooooo000dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`34ooooo`002Oooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`34ooooo`002Oooool0
1OlQ8B7oV9RHoooooonHV9So8B4Q00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`34ooooo`002Oooool01Ol0003ooooooooooooooooo000000?ooooo00Go410@
oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`?o00000_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo0<?ooooo0009ooooo`05oc8b<_nHV9SooooooiRH
V?lb<S800oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0<?o
oooo0009ooooo`05olc<c?l0003o0000o`000?o<c<`00oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo033ooooo0ol0002@ooooo`002Oooool01Ol@413o^[Zjoooo
oonj^[[o410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
4006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0/ooooo`?o00000oooool00ol0003oooooooooo`2=ooooo`002Oooool01Ol0003o^[Zjoooooonj
^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Z
ooooo`;o00001oooool00ol0003oooooooooo`2<ooooo`002Oooool01OnYZJWo410@o`000?l@413o
ZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Zoooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Roooool003Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`2:ooooo`00=?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo08Wooooo000dooooo`;o00001?ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`29ooooo`00=?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo08Sooooo000dooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool0R?ooool003Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`27ooooo`00=?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo08Oooooo
000dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Q_ooool003Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`26ooooo`00=?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo08Kooooo000dooooo`;o00001Oooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`25ooooo`00
=?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo033ooooo1Ol0001@ooooo`00=?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02gooooo0_l00005ooooo`?o0000COoo
ool003Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0[ooooo`;o00002_ooool2
o`0004_ooooo000dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0<ooooo`;o0000BOooool003Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0A_ooool003Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0AOooool003Cooooo0_l00006ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`14ooooo`00=?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`13
ooooo`00=?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`12ooooo`00=?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`11ooooo`00
=?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`10ooooo`000_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o
0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0oooooo`001?ooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool0?_ooool000Cooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@
oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03gooooo0004ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001_ooool3o`0000Gooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03cooooo0004ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool08Oooool2o`0001oooooo0_l0000Kooooo`001?ooool00ol0003o
ooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo
410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100
0oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Kooooo`001?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Looooo`000_ooool00omEEEGoIVIVo`00
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0Mooooo`00=?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01kooooo000doooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Yoooo
o`;o00004oooool2o`00027ooooo000dooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00kooooo0_l0000Sooooo`00
=?ooool2o`0000Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo00_ooooo0_l0000Uooooo`00=?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`08ooooo`;o00009ooo
ool003Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo033ooooo1?l00003ooooo`?o0000:Oooool003Cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo03Cooooo0ol0000/ooooo`00=?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0I?ooool003Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo06Cooooo
000dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`1Uooooo`00=?ooool2o`0000Sooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1V
ooooo`00=?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0I_ooool003Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo06Oooooo000dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`1Wooooo`00=?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0J?ooool003Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo06Wooooo000dooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Zooooo`00=?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0^ooooo`?o00001Oooool00ol0003oooooooooo`1[ooooo`00=?ooool2o`0000Wooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo037ooooo
0ol000000ooooooo0000ooooo`1]ooooo`00=?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo06gooooo000dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0:Cooooo000dooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
0:Cooooo000dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo0:Gooooo0002ooooo`Co000000?o410@ooooooooool0
1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`2Uooooo`001?ooool00ol0003oooooooooo`02ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0YOooool000Cooooo00?o0000ooooooooool00oooool00onH
V9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`2Vooooo`001?ooool00ol0003oooooooooo`04ooooo`03oiRH
V?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0006ooooo`?o00002Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0Y_ooool000Cooooo00?o0000ooooooooool01Oooool00omgMgOoIVIVooooo`02
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`2Vooooo`001?ooool00ol0003oooooooooo`06ooooo`05o`000?oooooooooooooo
ool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`04ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo0:Oooooo0004ooooo`03o`000?oooooooooo00;ooooo00Go0000okZj^_ooooooV9RH
oa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`2Wooooo`000_ooool00omEEEGoIVIVo`000004ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0Yoooool003Cooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Z?ooool003Co
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0Z?ooool003Cooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0ZOooool003Cooooo0_l0
000:ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`2Yooooo`00=?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`2Yooooo`00=?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Zoooo
o`00=?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`2Zooooo`00=?ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo02cooooo1?l00003ooooo`03o`000?oooooooooo0:[ooooo000dooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0<?ooool3o`000:gooooo000dooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool0h?ooool003Cooooo0_l0000;ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
0>3ooooo000dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0h?ooool003Cooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`3Pooooo`00=?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo0>3ooooo000dooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0hOooool003Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3Qoooo
o`00=?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0>7ooooo000dooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0hOooool003Cooooo0_l0000<ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo0>7ooooo000dooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0hOooool0
03Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`3Qooooo`00=?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo0>;ooooo000dooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0h_ooool000;ooooo1?l000000ol@413oooooooooo`02ooooo`;o000000Wo
410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0>;ooooo0004ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3R
ooooo`001?ooool00ol0003oooooooooo`02ooooo`Go00000oooool01Ol@413ooooooooooooooooo
410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100
0oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`3Rooooo`001?ooool00ol0003oooooooooo`02ooooo`04odA4A?oMgMgoooooo`0000Co
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000
2oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`3Rooooo`001?ooool00ol0003oooooooooo`02ooooo`04omgMgOmE
EEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0h_ooool000Cooooo00?o0000
ooooooooool00oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0>?ooooo0004ooooo`03o`000?oooooooooo00?ooooo00?ok^k^odA4A?l000001?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`3Sooooo`000_ooool00omEEEGoIVIVo`000006ooooo`03ogMgMol0
003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0hoooool003Cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`3Sooooo`00=?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo0>?ooooo000dooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
i?ooool003Cooooo0_l0000=ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0>Cooooo000dooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0i?ooool003Cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`3Uooooo`00=?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0:oooool01Ol0003ooooooooooooooooo00000>Oooooo000dooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0[ooooo`04
o`000?ooooooooooo`000>Sooooo000dooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0/ooooo`04o`000?ooooooooooo`000>Sooooo000dooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooo00000>Wooooo000dooooo`;o00003_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooool00000jOooool003Cooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02gooooo0_l0003Yooooo`00=?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`3Xooooo`00=?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0oooooolIooooo`00=?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00=?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolJooooo`00=?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooo
oolJooooo`00=?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0oooooolJooooo`00=?ooool2o`0000oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3ooooooa[ooooo000dooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`3ooooooa[ooooo000dooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooooa[ooooo000dooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooooa[ooooo000d
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3o
oooooa[ooooo0002ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o410@olc<c0?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3ooooooa_ooooo0004
ooooo`03o`000?oooooooooo00;ooooo00GoEEEEogMgMoooooooV9RHob4Q8@03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0oooooolKooooo`001?ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooo
oooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo6oooool000Cooooo00?o0000oooooooo
ool00_ooool01Ol0003oV9RHoooooonHV9So8B4Q00?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000006ooooo`?o00004?ooool01Ol0003ooooooooooooooooo0000
0?oooooo7Oooool000Cooooo00?o0000ooooooooool00_ooool01Ol0003oEEEEo`000?l@413oc<c<
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo013ooooo00Go0000ooooooooooooooooo`00003ooooooagooooo0004ooooo`03
o`000?oooooooooo00;ooooo00?oEEEEohN7Qoooool01Oooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool04Oooool01?l0003ooooo
ooooool0003ooooooagooooo0004ooooo`03o`000?oooooooooo00;ooooo00?ogMgMoa0@4?nHV9P0
1Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o
0000ooooooooool04Oooool01?l0003oooooooooool0003ooooooagooooo0002ooooo`03oeEEEOmV
IVKo000000Gooooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool04Oooool01?l0003ooooooooo
ool0003ooooooagooooo000dooooo`03o`000?oooooooooo01;ooooo0_l0003ooooooakooooo000d
ooooo`03o`000?oooooooooo01;ooooo0_l0003ooooooakooooo000dooooo`03o`000?oooooooooo
01;ooooo0_l0003ooooooakooooo000dooooo`;o00005?ooool00ol0003oooooooooo`3ooooooaco
oooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Cooooo00?o0000ooooooooool0oooo
oolbooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo000dooooo`03o`000?oooooooooo
0?oooooo<_ooool003Cooooo00?o0000ooooooooool0oooooolbooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00_?ooool01_lQ8B7o0000o`000?m4A4CogMgM
ooooo`?o000000?o410@ooooooooool0X?ooool00;oooooo00?oMgMgoc8b<_ooool00_ooool00ol@
413o^[Zjooooo`2Qooooo`00`?ooool01_l0003oooooooooooooooooV9RHoc8b<Z;ooooo001Ooooo
o`;o00000_ooool00ol@413o0000o`000002ooooo`Go00000_ooool01?l@413o0000o`000?ooool2
o`000004oa0@4?ooooook^k^oeEEE@;o000000?oA4A4okZj^_ooool00_ooool01OnHV9So0000o`00
0?m4A4Co^[Zj00?ooooo1Ol00003ooooo`05ofIVI_l0003o0000odA4A?o<c<`01_ooool01_o^k^ko
EEEEo`000?l0003oA4A4okZj^P;ooooo00Co410@o`000?l0003ooooo0_l000001?l@413oooooonk^
k_mEEED2o`000004odA4A?nj^[[ooooooa0@40Go00000oooool01_o^k^koEEEEo`000?l@413oc<c<
o`0000?ooooo00?ogMgMo`000?nj^[X02oooool00olQ8B7o<S8booooo`03ooooo`08onk^k_mEEEGo
0000o`000?m4A4Co^[Zjooooool@4105o`0000?ooooo00Ko410@oc8b<_l0003o0000oa0@4?nYZJT3
ooooo`09oiRHV?l0003o0000ogMgMol0003o410@ooooool@413o<S8b00;o000000?o410@ojVYZOoo
ool01_ooool01OnHV9So0000o`000?m4A4Co^[Zj00?ooooo1Ol000000ooooooo0000o`000002oooo
o`07o`000?ooooooooooo`000?l@413ok^k^oeEEE@02o`000003odA4A?nj^[[ooooo04Gooooo001P
ooooo`05o`000?ooooook^k^oc8b<_o<c<`01Oooool00ol0003oooooooooo`03ooooo`05o`000?oo
ooooooooooooool000000_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40?ooooo00Go410@okZj
^_o^k^koMgMgoa0@4005ooooo`03o`000?oooooooooo00;ooooo00KoIVIVogMgMoooooooooooohN7
Qol@4106ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0oooool01Ol0003ooooooooooooooooo
000000;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4103ooooo`03o`000?oooooooooo00Cooooo
00KoEEEEogMgMoooooook^k^oeEEEOl00003ooooo`03oeEEEOmgMgOoA4A400[ooooo00CoV9RHoc8b
<_l@413o^[Zj0oooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40?ooooo00?o0000ooooooooool0
1?ooool01_l0003oZJVYoooooooooooo^[Zjo`0000?ooooo00Go0000ojVYZOooooooQhN7o`000002
ooooo`06o`000?nYZJWooooooooooonj^[[o00001oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Go
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`08o`000?ooooooEEEE
ogMgMoooooook^k^ogMgMol@4116ooooo`00H?ooool01?l0003oV9RHoc8b<_o<c<`6ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`04ooooo`06o`000?ooooooooooooooooo^k^ko00000_oo
ool01OoMgMgo410@oooooolQ8B7ogMgM00Wooooo00Co410@okZj^_nHV9So<S8b0oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00Go^[ZjohN7QomVIVKoIVIVoa0@4003oooo
o`05o`000?ooooooooooooooool000000oooool01Onj^[[oQhN7ofIVI_mVIVKo410@00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooool00000Boooool0063ooooo00?o0000oa0@4?nHV9P01oooool00ol0003ooooooooo
o`03ooooo`05o`000?ooooooooooooooool000000_ooool6o`0000?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo1_l00003ooooo`05o`00
0?ooooooooooooooool000000_ooool6o`0000?ooooo00?o0000ooooooooool01?ooool01_l0003o
ooooooooooooooook^k^o`0000;ooooo00GoIVIVohN7QoooooooV9RHoeEEE@08ooooo`06oiRHV?lb
<S;oooooooooool@413o^[Zj0_ooool6o`0000?ooooo00?o0000ooooooooool01?ooool01_lb<S;o
8B4QogMgMomgMgOoQhN7onk^kP?ooooo00Go0000ooooooooooooooooo`000002ooooo`06oc8b<_lQ
8B7oMgMgogMgMon7QhOok^k^1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000005o`0004Kooooo001Pooooo`04
o`000?o^k^koEEEEohN7Q`Kooooo00?o0000ooooooooool00oooool01Ol0003oQhN7oooooonYZJWo
000000;ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S83ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool00_ooool01_mVIVKoMgMgooooooooooooQhN7o`0000Kooooo00KoEEEEohN7
Qoo^k^koooooohN7Qolb<S83ooooo`05o`000?n7QhOoooooojVYZOl000000_ooool01_mEEEGoQhN7
onk^k_ooooooQhN7oc8b<P?ooooo00?o0000oc8b<_oMgMd01?ooool02_mEEEGoMgMgooooooo^k^ko
EEEEo`000?ooooook^k^o`000?o^k^h2ooooo`03o`000?oMgMgooooo00Gooooo00?ok^k^o`000?oM
gMd00_ooool02_nHV9So<S8booooooooooooEEEEohN7Qoo^k^koooooohN7Qolb<S83ooooo`03o`00
0?lb<S;ogMgM00Cooooo00Ko0000okZj^_ooooook^k^ogMgMol00003ooooo`05o`000?oooooooooo
ooooool000000_ooool01_l0003o^[Zjooooooo^k^koMgMgo`0000Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`02ooooo`0>o`000?o<c<coc<c<o`000?nYZJWogMgMob4Q8Ooooooo
EEEEohN7Qoo^k^koooooohN7Qolb<S96ooooo`00H?ooool01Ol0003oooooodA4A?l0003o410@00?o
oooo00?o410@o`000?l000001?ooool00ol@413o0000ogMgM`02o`000005oiRHV?ooooooooooonk^
k_mEEED00_l000001?m4A4Cok^k^ooooool@4105o`0000Cooooo00?o410@o`000?l000001?ooool0
1_o^k^koIVIVo`000?l0003oA4A4o`0000Kooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h2oooo
o`03oa0@4?l0003oMgMg00;o000000GoV9RHooooooooooook^k^oeEEE@02o`000004odA4A?o^k^ko
ooooooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q0_ooool01_o^k^koEEEEo`000?lQ8B7oZJVYo`00
00;o410@0_l000001?oooooo0000o`000?l@4106ooooo`03oa0@4?l0003o000000;ooooo0ol00000
0oooooook^k^oeEEE@02o`000004odA4A?o^k^koooooooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q
0_ooool01_nYZJWo8B4Qo`000?l0003o<S8bo`0000;ooooo00Co410@o`000?oooooooooo0_l00002
ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o00001Oooool00ol@413o0000o`000003o`0000Cooooo
00?o410@o`000?l000000oooool02ol@413o0000ob4Q8Ol0003oMgMgoa0@4?l0003oZJVYooooooo^
k^koEEEE00;o000000?oA4A4onk^k_ooool0AOooool0063ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`22ooooo`03o`000?oooooooooo063ooooo001Pooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
07Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Fooooo`00Goooool2o`0000Wo
oooo00?o410@ooooooooool07Oooool00ol@413oooooooooo`22ooooo`03oa0@4?oooooooooo05Ko
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {221.375, 0}} -> {-0.0111972, 43891.9, \
0.000267939, 807.341}}]
}, Open  ]],

Cell["\<\
Collapse still occurs to some extent, but is moderated by the \
cloud's rotation. The final state is considerably less dense at the center \
than what one would obtain from the same initial condition without rotation \
(try it). \
\>", "Text"],

Cell[TextData[{
  "\tNote, also, the formation of spiral arms during the evolution. Spiral \
arms can be observed in many galaxies (see Fig. ",
  ButtonBox["7.9",
    ButtonData:>"Fig. 7.9",
    ButtonStyle->"Hyperlink"],
  "). These spiral structures can be understood from conservation of angular \
momentum. During the collapse, filaments of high density are thrown out from \
the core. As these filaments move to larger radius, conservation of angular \
momentum implies that they must slow their rotation. As result, the filaments \
are wound around the core, producing the spiral arms. (The formation of \
spiral arms is still a subject of some debate, and may be influenced by many \
effects beyond the scope of this simple explanation.)"
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises for Sec. 7.3", "Subsubtitle",
  CellTags->"c:40"],

Cell[TextData[{
  StyleBox["(1)",
    FontWeight->"Bold"],
  " Using the linearized Navier-Stokes equations ",
  ButtonBox["(7.3.13)",
    ButtonData:>{"Chapter7.nb", "(7.3.13)"},
    ButtonStyle->"Hyperlink"],
  " , derive the dispersion relation for sound waves in a self-gravitating \
gas, Eq. ",
  ButtonBox["(7.3.14)",
    ButtonData:>{"Chapter7.nb", "(7.3.14)"},
    ButtonStyle->"Hyperlink"],
  " ."
}], "Text"],

Cell[TextData[{
  StyleBox["(2)(a)",
    FontWeight->"Bold"],
  "  Solve Poisson's equation for a uniform cylindrical cloud of density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_o\)]],
  " and radius ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " to find the gravitational potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](r)\)]],
  "  both inside and outside the cloud. Use this result to prove Eq. ",
  ButtonBox["(7.3.17)",
    ButtonData:>{"Chapter7.nb", "(7.3.17)"},
    ButtonStyle->"Hyperlink"],
  "  for the equilibrium of a rotating cylindrical cloud. As a test of the \
FFT code, simulate this uniform cloud with 1000 particles, radius ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(R\)\(\ \)\(=\)\(\ \)\(0.25\)\(\ \)\)\)]],
  "(taking ",
  Cell[BoxData[
      \(TraditionalForm\`L = 1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`M = 40\)]],
  "), and plot the potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " obtained from the FFT vs. radius ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " from the cloud center, along with the analytic result, for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < r < 0.5\)]],
  ". Discuss reasons for any deviations from the analytic result that you \
observe."
}], "Text"],

Cell[TextData[{
  StyleBox["(3)(a)",
    FontWeight->"Bold"],
  "  The Jeans instability can also be understood from the linearized \
versions of the Poisson-Boltzmann equations ",
  ButtonBox["(7.3.1)",
    ButtonData:>{"Chapter7.nb", "(7.3.1)"},
    ButtonStyle->"Hyperlink"],
  " -",
  ButtonBox["(7.3.2)",
    ButtonData:>{"Chapter7.nb", "(7.3.2)"},
    ButtonStyle->"Hyperlink"],
  " . If we assume that ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(f(x, p\_x, \(p\_y\) t)\), "=", 
          RowBox[{\(\(f\_o\)(p\_x, p\_y)\), " ", "+", " ", 
            RowBox[{"\[Delta]", 
              RowBox[{
                StyleBox[
                  OverscriptBox[
                    StyleBox["f",
                      FontSlant->"Italic"], "~"],
                  FontSlant->"Italic"], "(", \(p\_x, p\_y\), ")"}], 
              " ", \(\[ExponentialE]\^\(\[ImaginaryI]\ k\ x\  - \ \
\[ImaginaryI]\ \[Omega]\ t\)\)}]}]}], TraditionalForm]]],
  ", then show that Eqs. ",
  ButtonBox["(7.1.31)",
    ButtonData:>{"Chapter7.nb", "(7.1.31)"},
    ButtonStyle->"Hyperlink"],
  "  and ",
  ButtonBox["(7.1.32)",
    ButtonData:>{"Chapter7.nb", "(7.1.32)"},
    ButtonStyle->"Hyperlink"],
  "  become"
}], "Text",
  CellTags->"i:82"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{\(\(-\[ImaginaryI]\)\ \[Omega]\), " ", "+", " ", 
                  RowBox[{"\[ImaginaryI]", " ", "k", " ", 
                    StyleBox[
                      FractionBox[
                        StyleBox[
                          SubscriptBox[
                            StyleBox["p",
                              FontSlant->"Italic"], "x"],
                          FontSlant->"Plain"], "m"],
                      FontSlant->"Plain"]}]}], ")"}], "\[Delta]", 
              StyleBox[
                OverscriptBox[
                  StyleBox["f",
                    FontSlant->"Italic"], "~"],
                FontSlant->"Italic"]}], "-", 
            RowBox[{"m", " ", "\[ImaginaryI]", " ", "k", " ", "\[Delta]", 
              StyleBox[
                OverscriptBox[
                  StyleBox["\[Phi]",
                    FontSlant->"Plain"], "~"],
                
                FontSlant->
                  "Italic"], \(\[PartialD]f\_o\/\[PartialD]p\_x\)}]}], "=", 
          "0"}], TraditionalForm]]],
  ", \n",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Delta] \( \[Phi]\&~\)\), "=", 
          RowBox[{\(-\(\(4  \[Pi]\ G\ m\)\/k\^2\)\), 
            RowBox[{"\[Integral]", 
              RowBox[{"\[Delta]", 
                StyleBox[
                  OverscriptBox[
                    StyleBox["f",
                      FontSlant->"Italic"], "~"],
                  FontSlant->"Italic"], \(\[DifferentialD]\^2 p\)}]}]}]}], 
        TraditionalForm]]],
  ","
}], "NE3",
  CellTags->"(7.3.18)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Delta]", 
          RowBox[{
            StyleBox[
              OverscriptBox[
                StyleBox["\[Phi]",
                  FontSlant->"Plain"], "~"],
              FontSlant->"Italic"], "(", \(k, \[Omega]\), ")"}]}], 
        TraditionalForm]]],
  " is the Fourier transform of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\[Phi]\)]],
  " in ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Show that Eqs. ",
  ButtonBox["(7.3.18)",
    ButtonData:>{"Chapter7.nb", "(7.3.18)"},
    ButtonStyle->"Hyperlink"],
  "  lead to the following dispersion relation:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`1\  + \ \(\(4  \[Pi]\ G\ m\^3\)\/k\^2\) \
\(\[Integral]\(\(\[PartialD]f\_o/\[PartialD]p\_x\)\/\(p\_x - 
                      m\ \[Omega]/k\)\) \[DifferentialD]\^2 p\) = 0\)]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " We previously simulated a case where the equilibrium velocity \
distribution is given by ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(f\_o\)(p\_x, p\_y) = \ 
        N\/\((m\ V\ L)\)\^2\ \ for | 
          p\_x | \(\(<\)\(\ \)\(m\ V\ \ and\)\)\  | 
          p\_y | \(\(<\)\(m\ V\)\)\)\(,\)\)\)]],
  " and ",
  Cell[BoxData[
      FormBox[Cell[TextData[{
          " ",
          Cell[BoxData[
              \(TraditionalForm\`f\_o = 0\)]],
          " "
        }]], TraditionalForm]]],
  "otherwise.  Show that for this velocity distribution the dispersion \
relation works out to be"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\^2\  = \ 
        V\^2\ k\^2 - \ 4\ \[Pi]\ G\ \[Rho]\_o\)]],
  ", "
}], "UNNEQ"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_o = \ m\ N/L\^2\)]],
  " is the average mass density. What is the minimum value of ",
  Cell[BoxData[
      \(TraditionalForm\`V\)]],
  ",",
  " ",
  Cell[BoxData[
      \(TraditionalForm\`V\_min\)]],
  ", that allows a stable distribution in our simulation? For the simulation \
run in the above examples,  with ",
  Cell[BoxData[
      \(TraditionalForm\`V = 30\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`N = 1000\)]],
  ", should the simulation be stable or unstable? "
}], "Text"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " Repeat the simulation taking ",
  Cell[BoxData[
      \(TraditionalForm\`V\  = \ 0.8\ V\_min\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`V\  = \ 1.2\ V\_min\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(4)(a)",
    FontWeight->"Bold"],
  " Simplify the code so that only motion in one dimension is considered,  \
where ",
  Cell[BoxData[
      \(TraditionalForm\`f = f(x, p, t)\)]],
  ". (This requires determination of the correct equivalent of  area \
weighting for a one-dimensional grid.) Test the code by running cases with ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(N\)\(=\)\(1000\)\(\ \)\)\)]],
  "particles distributed randomly on ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < L\)]],
  ", with ",
  Cell[BoxData[
      \(TraditionalForm\`M = 40\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`L = \(m = \(G = 1\)\)\)]],
  ", and\n (i) ",
  Cell[BoxData[
      \(TraditionalForm\`V\  = \ 0.8\ V\_min\)]],
  " (unstable) \n ",
  Cell[BoxData[
      \(TraditionalForm\`\(\((ii)\)\(\ \)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`V = 1.2\ V\_min\)]],
  " (stable). \nMake animations of the density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](x, t)\)]],
  ", evaluated from your position data. Check energy and momentum \
conservation. "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " In equilibrium, we expect that the distribution function will be a \
function only of the energy: "
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`f = f(p\^2/2  m\  + \ m\ \[Phi])\)]]], "NE3",
  CellTags->"(7.3.19)"],

Cell[TextData[{
  "(in a frame where the center of mass is stationary). This is the same \
equilibrium distribution as we studied for the case of particles in a given \
external field; see Eq. ",
  ButtonBox["(7.1.25)",
    ButtonData:>{"Chapter7.nb", "(7.1.25)"},
    ButtonStyle->"Hyperlink"],
  " . However, now the problem is much more difficult, because the potential \
",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\[Phi]\)\)\)]],
  " is determined in terms of ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " itself. Nevertheless, we can test whether the final state observed from \
the evolution of an unstable initial condition satisfies this result. To do \
so, make a 2-D histogram in phase space ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, p)\)\)]],
  " of the end result of the simulation in Exercise (4)(a)(i) using the ",
  StyleBox["BinCounts ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function, available in the ",
  StyleBox["Statistics",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " add-on package.  The syntax is"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{"BinCounts", "[", 
          
          RowBox[{\({{x\_1, p\_1}, {x\_2, p\_2}, \(\(...\)\(.\)\), {x\_N, 
                p\_N}}\), ",", 
            RowBox[{"{", 
              RowBox[{"0", ",", "L", ",", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{\(-P\), ",", "P", ",", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["p",
                      FontSlant->"Italic"]}]]}], "}"}]}], "]"}], 
        TraditionalForm]]],
  ","
}], "Text"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " and \[CapitalDelta]",
  Cell[BoxData[
      StyleBox["p",
        FontSlant->"Italic"]]],
  " are the sizes of the bins in ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " respectively, and where ",
  Cell[BoxData[
      \(TraditionalForm\`P\)]],
  " is a maximum momentum, chosen from your data to capture all (or at least  \
most) of the distribution function. The result  is a list of the number of \
points in each bin. This number is ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(f\_\(i\ j\)\), "\[Congruent]", 
          RowBox[{\(f(x\_i, \ p\_j)\), " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]], " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["p",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\((x\_i, p\_j)\)\)]],
  " is the center of a bin.  Take ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], " ", "=", " ", \(\(L/10\)\(\ \)\)}], 
        TraditionalForm]]],
  "and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["p",
                FontSlant->"Italic"]}]], " ", "=", " ", \(P/10\)}], 
        TraditionalForm]]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tAccording to Eq. ",
  ButtonBox["(7.3.19)",
    ButtonData:>{"Chapter7.nb", "(7.3.19)"},
    ButtonStyle->"Hyperlink"],
  " , ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " is a function only of ",
  Cell[BoxData[
      \(TraditionalForm\`E = \ p\^2/2  m\  + \ m\ \(\[Phi](x)\)\)]],
  " in equilibrium. Test this for your final state by evaluating ",
  Cell[BoxData[
      \(TraditionalForm\`E\_\(i\ j\) = 
        p\_j\^2/2  m\  + \ m\ \(\[Phi](x\_i)\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " is determined from ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " using the FFT. Make a data table of ",
  Cell[BoxData[
      \(TraditionalForm\`{E\_\(i\ j\), \ f\_\(i\ j\)}\)]],
  " values, and plot them via a ",
  StyleBox["ListPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". If you have achieved an equilibrium, the points should all fall on a \
single curve, which defines the function ",
  Cell[BoxData[
      \(TraditionalForm\`f(E)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(5)",
    FontWeight->"Bold"],
  " ",
  StyleBox["SIMULATION PROJECT: 2D FLUID DYNAMICS",
    FontSlant->"Italic"],
  " . The PIC method is also used in the study of 2-dimensional  \
incompressible fluids.  Two examples of  fluids that are approximately 2D are \
soap films, and planetary atmospheres and oceans (for flows whose horizontal \
scale is large compared to the atmosphere's thickness or the ocean's depth, \
such as the jet stream or large scale ocean currents).  The following project \
allows a student to  study several aspects of 2D fluid flows. "
}], "Text",
  CellTags->"i:65"],

Cell["\<\
\tThe equations of motion for such fluids are the momentum \
equation,\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{\(\[PartialD]\/\[PartialD]t\), 
              StyleBox["u",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], "+", 
            RowBox[{
              StyleBox["u",
                FontWeight->"Bold",
                FontSlant->"Plain"], "\[CenterDot]", 
              RowBox[{"\[Del]", 
                StyleBox["u",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}]}]}], " ", "=", 
          " ", \(\(-\(1\/\[Rho]\)\) \[Del]p\)}], TraditionalForm]]],
  ","
}], "NE3",
  CellTags->"(7.3.20)"],

Cell["\<\
(assuming the flow is unforced) and the constraint equation for \
incompressible flow,\
\>", "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[Del]", 
            RowBox[{"\[CenterDot]", 
              RowBox[{
                StyleBox["u",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox["(",
                  FontWeight->"Plain"], 
                StyleBox[\(x, y, t\),
                  FontWeight->"Plain"], 
                StyleBox[")",
                  FontWeight->"Plain"]}]}]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox["0",
            FontWeight->"Plain"]}], TraditionalForm]]],
  ". "
}], "NE3",
  CellTags->"(7.3.21)"],

Cell[TextData[{
  "  In order to solve these equations,  we note that Eq. ",
  ButtonBox["(7.3.21)",
    ButtonData:>{"Chapter7.nb", "(7.3.21)"},
    ButtonStyle->"Hyperlink"],
  "  implies that ",
  Cell[BoxData[
      FormBox[
        StyleBox["u",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " can be written in terms of a ",
  StyleBox["stream function",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Psi](x, y, t)\)\(:\)\)\)]]
}], "Text",
  CellTags->"i:64"],

Cell[TextData[{
  "  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["u",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox[
            RowBox[{
              OverscriptBox[
                StyleBox["z",
                  FontWeight->"Plain"], "^"], "\[Times]", \(\[Del]\[Psi]\)}],
            FontWeight->"Plain"]}], TraditionalForm]]]
}], "NE3",
  CellTags->"(7.3.22)"],

Cell[TextData[{
  "(The divergence of ",
  Cell[BoxData[
      FormBox[
        StyleBox["u",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " is then guaranteed to equal zero.) At any given instant of time, ",
  Cell[BoxData[
      FormBox[
        StyleBox["u",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " points along contours of constant ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)]],
  ". In order to solve for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)]],
  ", we take the curl of Eq. ",
  ButtonBox["(7.3.20)",
    ButtonData:>{"Chapter7.nb", "(7.3.20)"},
    ButtonStyle->"Hyperlink"],
  " , and then dot the result with ",
  Cell[BoxData[
      FormBox[
        OverscriptBox[
          StyleBox["z",
            FontWeight->"Bold",
            FontSlant->"Plain"], "^"], TraditionalForm]]],
  ". After some work with vector identities, one obtains"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\(\[PartialD]\/\[PartialD]t\) \[Zeta]\), "+", 
            RowBox[{
              StyleBox["u",
                FontWeight->"Bold",
                FontSlant->"Plain"], "\[CenterDot]", \(\[Del]\[Zeta]\)}]}], 
          " ", "=", "0"}], TraditionalForm]]],
  ","
}], "NE3",
  CellTags->"(7.3.23)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["\[Zeta]",
            FontWeight->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            RowBox[{
              StyleBox[
                OverscriptBox[
                  StyleBox["z",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "^"],
                FontWeight->"Plain"], "\[CenterDot]", "\[Del]"}], "\[Times]", 
            
            StyleBox["u",
              FontWeight->"Bold",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  " is the ",
  StyleBox["vorticity ",
    FontSlant->"Italic"],
  " of the flow. The vorticity  ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Zeta]", "(", \(x, y, t\), 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " can be thought of as a measure of the rotation rate of a fluid element at \
",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y)\)\)]],
  " about its own center. According to Eq. ",
  ButtonBox["(7.3.23)",
    ButtonData:>{"Chapter7.nb", "(7.3.23)"},
    ButtonStyle->"Hyperlink"],
  " , vorticity ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\)]],
  " is transported without change along characteristics given by ",
  Cell[BoxData[
      FormBox[
        StyleBox["u",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ":"
}], "Text",
  CellTags->"i:66"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]x\/\[DifferentialD]t = \ \(\(u\_x\)(
            x, y, t) = \(-\(\[PartialD]\[Psi]\/\[PartialD]y\)\)\)\)]],
  ",\n",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]y\/\[DifferentialD]t = \(\(u\_y\)(x, 
            y, t) = \ \ \(\(\[PartialD]\[Psi]\/\[PartialD]x\)\(\ \
\)\(.\)\)\)\)]]
}], "NE3",
  CellTags->"(7.3.24)"],

Cell[TextData[{
  "Equation ",
  ButtonBox["(7.3.23)",
    ButtonData:>{"Chapter7.nb", "(7.3.23)"},
    ButtonStyle->"Hyperlink"],
  "  is analogous to the Boltzmann equation. If we know the flow field ",
  Cell[BoxData[
      FormBox[
        StyleBox["u",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ", then we can take the curl of this field to determine the vorticity, and \
populate a 2D area with a collection of ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " particles (\"point vortices\") that are distributed according to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\)]],
  ".  We can follow the resulting motion of these particles by solving Eqs. \
",
  ButtonBox["(7.3.24)",
    ButtonData:>{"Chapter7.nb", "(7.3.24)"},
    ButtonStyle->"Hyperlink"],
  " .  Since vorticity has dimensions of frequency, we assign a quantity ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\)]],
  " to each particle (analogous to mass), with dimensions of ",
  Cell[BoxData[
      \(TraditionalForm\`area\ per\ unit\ time\)]],
  ". This quantity is called the ",
  StyleBox["circulation",
    FontSlant->"Italic"],
  " of the point vortex.  Then the mean circulation of the particles per unit \
area equals ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\)]],
  " ; i.e.  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Zeta]\)\(\ \)\(=\)\(\ \)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\ \[Times]\((number\ or\ particles\ per\ \
unit\ area)\)\)]],
  ".  The total circulation of the flow is defined to be ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", " ", "=", " ", 
          RowBox[{
            RowBox[{"\[Integral]", 
              RowBox[{"\[Zeta]", 
                RowBox[{\(\[DifferentialD]\^2\), 
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}]}]}], "=", " ", \(N\ \[Gamma]\)}]}], 
        TraditionalForm]]],
  ". Clearly, \[CapitalGamma] is a conserved quantity in this dynamics, \
because ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " is fixed."
}], "Text",
  CellTags->"i:69"],

Cell[TextData[{
  "\tThe stream function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)]],
  " is determined by the vorticity. This can be seen by taking the curl of \
Eq. ",
  ButtonBox["(7.3.22)",
    ButtonData:>{"Chapter7.nb", "(7.3.22)"},
    ButtonStyle->"Hyperlink"],
  " : "
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Zeta]", "=", 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox[
                  OverscriptBox[
                    StyleBox["z",
                      FontWeight->"Plain"], "^"],
                  FontWeight->"Plain"], "\[CenterDot]", "\[Del]"}], 
              "\[Times]", 
              StyleBox["u",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], "=", 
            RowBox[{
              RowBox[{
                RowBox[{
                  StyleBox[
                    OverscriptBox[
                      StyleBox["z",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], "^"],
                    FontWeight->"Plain"], "\[CenterDot]", "\[Del]"}], 
                "\[Times]", 
                RowBox[{"(", 
                  StyleBox[
                    RowBox[{
                      OverscriptBox[
                        StyleBox["z",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], "^"], 
                      "\[Times]", \(\[Del]\[Psi]\)}],
                    FontWeight->"Plain"], 
                  StyleBox[")",
                    FontWeight->"Plain"]}]}], 
              StyleBox[" ",
                FontWeight->"Plain"], 
              StyleBox["=",
                FontWeight->"Plain"], 
              StyleBox[" ",
                FontWeight->"Plain"], 
              StyleBox[\(\[Del]\^2 \[Psi]\),
                FontWeight->"Plain"]}]}]}], TraditionalForm]]]
}], "NE3",
  CellTags->"(7.3.25)"],

Cell[TextData[{
  "Equations ",
  ButtonBox["(7.3.23)",
    ButtonData:>{"Chapter7.nb", "(7.3.23)"},
    ButtonStyle->"Hyperlink"],
  "  and ",
  ButtonBox["(7.3.25)",
    ButtonData:>{"Chapter7.nb", "(7.3.25)"},
    ButtonStyle->"Hyperlink"],
  "  are coupled equations for the vorticity and stream function, called the \
",
  StyleBox["Euler equations",
    FontSlant->"Italic"],
  " for 2D flow. Note Eq. ",
  ButtonBox["(7.3.25)",
    ButtonData:>{"Chapter7.nb", "(7.3.25)"},
    ButtonStyle->"Hyperlink"],
  "  is merely Poisson's equation. Therefore, we can follow the same \
procedure as we used for the PIC method in gravitational systems (see Table \
",
  ButtonBox["7.1",
    ButtonData:>"Table 7.1",
    ButtonStyle->"Hyperlink"],
  "). Starting with a collection of identical point vortices  that model an \
initial vorticity distribution ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta](x, y, t = 0)\)]],
  ", we solve Poissons equation using our FFT and interpolation codes in \
order to determine the stream function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](x, y, t)\)]],
  " and the flow field ",
  Cell[BoxData[
      FormBox[
        StyleBox["u",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ". We then move the point vortices according to Eq. ",
  ButtonBox["(7.3.24)",
    ButtonData:>{"Chapter7.nb", "(7.3.24)"},
    ButtonStyle->"Hyperlink"],
  " , and repeat the procedure. "
}], "Text",
  CellTags->"i:84"],

Cell[TextData[{
  "Table 7.1 Analogous Quantities  in  2D Fluids  and Gravitational Dynamics\n\
",
  Cell[BoxData[GridBox[{
          {"gravity", \(2  D\ fluids\)},
          {"\[Phi]", "\[Psi]"},
          {"\[Rho]", "\[Zeta]"},
          {
            StyleBox["m",
              FontSlant->"Italic"], "\[Gamma]"},
          {
            StyleBox["f",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["u",
              FontWeight->"Bold",
              FontSlant->"Plain"]}
          },
        GridFrame->True,
        RowLines->True,
        ColumnLines->True]]],
  "\n"
}], "Text",
  CellFrame->True,
  TextAlignment->Center,
  Background->GrayLevel[0.900008],
  CellTags->"Table 7.1"],

Cell[TextData[{
  "\t",
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Modify the previous PIC code to solve these 2D fluid equations.  Part of \
the job is done for you below, since the leapfrog technique for moving the \
particles will no longer work. Instead, we use the Adams-Bashforth scheme \
discussed in Chapter 1: see Eq. ",
  ButtonBox["(1.4.29)",
    ButtonData:>{"Chapter1.nb", "(1.4.29)"},
    ButtonStyle->"Hyperlink"],
  "  . The following module implements this method, including a few extra \
tricks in order to save memory. First,  the code keeps  memory  of only one  \
previous velocity field evaluation in the variable ",
  StyleBox["u0",
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  ", by updating ",
  StyleBox["u0",
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  " after each step.  Second,  an ",
  StyleBox["Unset",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command is used to clear previous position evaluations (again, in order \
to save memory space), and for this reason the plots of the flow are created \
inside the routine. [This ",
  StyleBox["Unset",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command can be disabled if you wish by surrounding the command with \
comment marks ",
  StyleBox["(* *)",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ]"
}], "Text",
  CellTags->"i:68"],

Cell[TextData[{
  "\tAlso, for long runs, it is not a bad idea to save data to a file \
periodically. This is implemented using the ",
  StyleBox["Export",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " statement to open a datafile named ",
  StyleBox["r_n",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in the default directory, and to  write positions to the file every 100 \
steps. The module is"
}], "Text",
  CellTags->"i:67"],

Cell[BoxData[
    RowBox[{\(adbash[r0_, \ Nstep_, \[CapitalDelta]t_, \ \[CapitalDelta]N_]\),
       " ", ":=", " ", 
      RowBox[{"Module", "[", 
        RowBox[{\({}\), ",", "\[IndentingNewLine]", 
          StyleBox[
            RowBox[{"(*", " ", 
              RowBox[{
                RowBox[{"second", "-", 
                  RowBox[{
                  "order", " ", "Adams", " ", "Bashforth", " ", "method", " ",
                     "for", " ", "the", " ", "ODE", 
                    RowBox[{
                    Cell["dr/dt =  u"], ".", " ", 
                      "\[IndentingNewLine]", \((Requires\ a\ function\ u[
                            r])\), ".", " ", "r0"}], " ", "is", " ", "the", 
                    " ", "initial", " ", "condition"}]}], ",", 
                " ", \(Nstep\ is\ the\ number\ of\ timsteps\), ",", 
                " ", \(\[CapitalDelta]t\ is\ the\ step\ size\), ",", 
                " ", \(\[CapitalDelta]N\ is\ a\ parameter\ in\ the\ plots\)}],
               " ", "*)"}],
            FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          
          RowBox[{\(md[x_]\  := \ Mod[x, L]\), ";", "\[IndentingNewLine]", 
            "\[IndentingNewLine]", 
            StyleBox[\( (*\ initial\ conditions\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(r[0]\  = \ Map[r0, L]\), ";", 
            "\[IndentingNewLine]", "\[IndentingNewLine]", 
            "\[IndentingNewLine]", 
            RowBox[{\(r[n_]\), " ", ":=", 
              RowBox[{
                RowBox[{"(", " ", 
                  RowBox[{\(r[n]\), " ", "=", 
                    RowBox[{
                      StyleBox["(",
                        FontSize->16,
                        FontColor->RGBColor[0, 0, 1]], "\[IndentingNewLine]", 
                      
                      RowBox[{
                        StyleBox["(*",
                          FontColor->RGBColor[1, 0, 0]], 
                        StyleBox[" ",
                          FontColor->RGBColor[1, 0, 0]], 
                        
                        StyleBox[\(write\ n - 
                            1\ position\ data\ to\ file\ if\ n - 
                            1\ a\ multiple\ of\ 100\),
                          FontColor->RGBColor[1, 0, 0]], " ", 
                        StyleBox["*)",
                          FontColor->RGBColor[1, 0, 0]]}], 
                      "\[IndentingNewLine]", 
                      
                      RowBox[{\(If[Mod[n - 1, 100]\  == 0, 
                          Export["\<r_\>" <> ToString[n - 1], 
                            r[n - 1], "\<Table\>"]]\), ";", 
                        "\[IndentingNewLine]", 
                        
                        StyleBox[\( (*\ 
                            account\ for\ periodic\ boundary\ conditions\ *) \
\),
                          FontColor->RGBColor[1, 0, 0]], 
                        "\[IndentingNewLine]", " ", \(Map[md, \ r1[n]]\)}], 
                      StyleBox[")",
                        FontSize->16,
                        FontColor->RGBColor[0, 0, 1]]}]}], ")"}], " ", "/;", 
                " ", \(n \[GreaterEqual] \ 1\)}]}], ";", 
            "\[IndentingNewLine]", "\[IndentingNewLine]", 
            StyleBox[\( (*\ predictor\ step\ for\ n = 1\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(u0\  = \ \ u[r[0]]\), ";", " ", 
            "\[IndentingNewLine]", \(rp\  = \ 
              Map[md, r[0]\  + \ u0\ \ \[CapitalDelta]t]\), ";", 
            "\[IndentingNewLine]", "\[IndentingNewLine]", 
            StyleBox[\( (*\ corrector\ step\ for\ n = 1*) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(u1\  = \ u[rp]\), ";", 
            "\[IndentingNewLine]", \(r1[1]\  := 
              r[0]\  + \ \[CapitalDelta]t \((u0\  + \ u1)\)/2\), " ", ";", 
            "\[IndentingNewLine]", "\[IndentingNewLine]", 
            RowBox[{
              StyleBox["(*",
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox[" ",
                FontColor->RGBColor[1, 0, 0]], 
              
              StyleBox[\(second - order\ Adams - 
                    Bashforth\ step\ for\ n\  \[GreaterEqual] \ 2\),
                FontColor->RGBColor[1, 0, 0]], " ", 
              StyleBox["*)",
                FontColor->RGBColor[1, 0, 0]]}], "\[IndentingNewLine]", 
            RowBox[{\(r1[n_]\), " ", ":=", 
              RowBox[{
                RowBox[{"(", 
                  
                  RowBox[{\(u1\  = \ u[r[n - 1]]\), ";", 
                    "\[IndentingNewLine]", 
                    "                ", \(rnew = \ 
                      r[n - 1]\  + \ \[CapitalDelta]t\ \((1.5\ u1 - 
                              0.5  u0)\)\), ";", "\[IndentingNewLine]", 
                    "                ", 
                    RowBox[{
                      StyleBox["(*",
                        FontColor->RGBColor[1, 0, 0]], 
                      StyleBox[" ",
                        FontColor->RGBColor[1, 0, 0]], 
                      StyleBox[\(update\ the\ old\ velocity\ field\),
                        FontColor->RGBColor[1, 0, 0]], " ", 
                      StyleBox["*)",
                        FontColor->RGBColor[1, 0, 0]]}], 
                    "\[IndentingNewLine]", "                ", \(u0 = u1\), 
                    ";", "\[IndentingNewLine]", "                ", 
                    RowBox[{
                      StyleBox["(*",
                        FontColor->RGBColor[1, 0, 0]], 
                      StyleBox[" ",
                        FontColor->RGBColor[1, 0, 0]], 
                      
                      StyleBox[\(un - 
                          memorize\ \((Unset)\)\ r[n - 2]\ to\ save\ memory\),
                        
                        FontColor->RGBColor[1, 0, 0]], " ", 
                      StyleBox["*)",
                        FontColor->RGBColor[1, 0, 0]]}], 
                    "\[IndentingNewLine]", 
                    "                ", \(Unset[r[n - 2]]\), ";", 
                    "\[IndentingNewLine]", "                ", 
                    RowBox[{
                      StyleBox["(*",
                        FontColor->RGBColor[1, 0, 0]], 
                      StyleBox[" ",
                        FontColor->RGBColor[1, 0, 0]], 
                      StyleBox[\(return\ new\ position\),
                        FontColor->RGBColor[1, 0, 0]], " ", 
                      StyleBox["*)",
                        FontColor->RGBColor[1, 0, 0]]}], 
                    "\[IndentingNewLine]", "                ", "rnew"}], 
                  ")"}], "  ", "/;", \(n \[GreaterEqual] \ 2\)}]}], ";", 
            "\[IndentingNewLine]", "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ plot\ solution\ up\ to\ time\ step\ Nstep, \ 
                showing\ every\ \[CapitalDelta]N\ th\ step\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(Table[
              ListPlot[r[n], PlotRange \[Rule] {{0, L}, {0, L}}, 
                AspectRatio \[Rule] 1, 
                PlotLabel -> "\<n= \>" <> ToString[n\ ]], {n, 0, 
                Nstep, \ \[CapitalDelta]N}]\), ";"}]}], "]"}]}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.93"],

Cell[TextData[{
  "\t",
  StyleBox["(b)",
    FontWeight->"Bold"],
  " ",
  StyleBox["Code tests.\n\t(",
    FontSlant->"Italic"],
  "i) Show that a circular patch of vorticity with radius ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " and vorticity ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\)]],
  " causes fluid rotation of the form ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["u",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[
            RowBox[{\(\[Omega](r)\), " ", "r", " ", 
              OverscriptBox[
                StyleBox["\[Theta]",
                  FontWeight->"Bold"], "^"]}],
            FontWeight->"Plain"]}], TraditionalForm]]],
  ", where the rotation frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega](r)\)]],
  " is  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega](r)\  = \ \[Zeta]\ /2\)]],
  " inside the patch, and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega](r)\  = \ \[Zeta]\ R\^2/2\ r\^2\)]],
  " outside the patch.  (This sort of flow can be set up by stirring the \
fluid with a rotating disk of radius ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  ", then removing the disk.)"
}], "Text"],

Cell[TextData[{
  "\t(ii) Create such a uniform circular patch with radius ",
  Cell[BoxData[
      \(TraditionalForm\`R = 0.3\)]],
  ", using ",
  Cell[BoxData[
      \(TraditionalForm\`N = 1000\)]],
  " point vortices  each with circulation ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma] = 1/N\)]],
  ". Evaluate the rotation frequency of the patch numerically as a function \
of ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  ", and compare with part (i)"
}], "Text"],

Cell[TextData[{
  "\t(iii) Show analytically that two isolated point vortices, each with \
circulation ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Gamma]\)\(,\)\)\)]],
  " and separated by a distance ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  ", will rotate around one another with rotation rate ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\  = \ \[Gamma]/R\^2\)]],
  ". Test this result in your code, taking ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma] = 1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`R = 0.25\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\t(iv) Show analytically that the total kinetic energy ",
  Cell[BoxData[
      \(TraditionalForm\`K\)]],
  " of the flow is conserved, where  ",
  Cell[BoxData[
      FormBox[
        RowBox[{"K", " ", "=", " ", 
          RowBox[{"\[Rho]", 
            RowBox[{"\[Integral]", 
              RowBox[{\(u\^2\/2\), 
                RowBox[{\(\[DifferentialD]\^2\), 
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}]}]}]}]}], TraditionalForm]]],
  ". Test this result for the simulations done in parts ii) and iii). Comment \
on whether the PIC method does an adequate job of evaluating ",
  Cell[BoxData[
      \(TraditionalForm\`K\)]],
  ". [Hint: First show that ",
  Cell[BoxData[
      FormBox[
        RowBox[{"K", " ", "=", 
          RowBox[{\(-\(\[Rho]\/2\)\), 
            RowBox[{"\[Integral]", 
              RowBox[{"\[Zeta]", "  ", "\[Psi]", 
                RowBox[{\(\[DifferentialD]\^2\), 
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], " "}]}]}]}]}], TraditionalForm]]],
  ". Take a time derivative of this quantity and apply Eqs. ",
  ButtonBox["(7.3.23)",
    ButtonData:>{"Chapter7.nb", "(7.3.23)"},
    ButtonStyle->"Hyperlink"],
  "  and ",
  ButtonBox["(7.3.25)",
    ButtonData:>{"Chapter7.nb", "(7.3.25)"},
    ButtonStyle->"Hyperlink"],
  " . ]"
}], "Text"],

Cell[TextData[{
  "\t(v) Show analytically that, for an unbounded flow where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["u",
            FontWeight->"Bold",
            FontSlant->"Plain"], "\[Rule]", "0"}], TraditionalForm]]],
  " at infinity,  the total angular momentum ",
  Cell[BoxData[
      \(TraditionalForm\`L\_z\)]],
  " of the flow is conserved, where  ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(\(L\)\(\ \)\)\_z\), "=", " ", 
          RowBox[{"\[Rho]", 
            RowBox[{"\[Integral]", 
              RowBox[{\((x\ u\_y - y\ u\_x)\), 
                RowBox[{\(\[DifferentialD]\^2\), 
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}]}]}]}]}], TraditionalForm]]],
  ". Test this result for the simulations done in parts (ii) and (iii). \
Comment. "
}], "Text"],

Cell[TextData[{
  "\t ",
  StyleBox["(c)",
    FontWeight->"Bold"],
  " ",
  StyleBox["Fluid turbulence",
    FontSlant->"Italic"],
  ". \t(i) Run your code for a random collection of ",
  Cell[BoxData[
      \(TraditionalForm\`N = 500\)]],
  " point vortices, taking ",
  Cell[BoxData[
      \(TraditionalForm\`M = 15\)]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], " ", "=", " ", "0.3"}],
            "TraditionalForm"], ","}], TraditionalForm]]],
  "  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma] = 1/N\)]],
  ". These vortices create a complicated flow field, which has been used by \
researchers as a model of fluid turbulence.   Run the code for ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["Nstep",
            FontFamily->"Courier",
            FontWeight->"Bold"], " ", "=", " ", "300"}], TraditionalForm]]],
  " steps.  Does anything like gravitational collapse happen here?  Describe \
the motion of the fluid in a few words."
}], "Text",
  CellTags->"i:72"],

Cell[TextData[{
  "\t \t\t         \t(ii) Higher-kinetic-energy initial conditions do go \
through a process somewhat akin to gravitational collapse: there is an \
instability that results in a final (rotating) equilibrium state. Repeat the \
simulation, now confining the initial random positions of the point vortices \
to the region ",
  Cell[BoxData[
      \(TraditionalForm\`0.4 < y < 0.5\)]],
  ".  Sheets of vorticity such as this create shear flows that are unstable \
and that can be analyzed in much the same way as for the Jeans instability. \
(This instability is called the Kelvin-Helmholtz instability.) Take ",
  Cell[BoxData[
      \(TraditionalForm\`M = 20\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(N = 500\)\(,\)\)\)]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], "=", "0.03"}], TraditionalForm]]],
  ". Now describe the state that develops after 300 steps. "
}], "Text"],

Cell[TextData[{
  "\t ",
  StyleBox["(d)",
    FontWeight->"Bold"],
  " ",
  StyleBox["Vortex merger.\t (",
    FontSlant->"Italic"],
  "i)",
  StyleBox[" ",
    FontSlant->"Italic"],
  " In part (c)(ii), it should have become apparent that merger between \
vortex patches is an important process in the equilibration of initially \
unstable flows.  To study this process, create an initial condition \
consisting of two identical uniform circular vortex patches of radius ",
  Cell[BoxData[
      \(TraditionalForm\`R = 0.1\)]],
  ", with centers separated by distance ",
  Cell[BoxData[
      \(TraditionalForm\`D = 0.25\)]],
  ".  Take ",
  Cell[BoxData[
      \(TraditionalForm\`N = 1000\)]],
  " (500 in each patch),  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma] = 2/N\)]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["Nstep",
            FontFamily->"Courier",
            FontWeight->"Bold"], " ", "=", " ", "300"}], TraditionalForm]]],
  ", and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], " ", "=", " ", "0.01"}], 
        TraditionalForm]]],
  ".  (This run requires fine resolution; take ",
  Cell[BoxData[
      \(TraditionalForm\`M > 30\)]],
  "). How long would you estimate that it takes the two vortices to merge, \
becoming one vortex?"
}], "Text",
  CellTags->"i:70"],

Cell[TextData[{
  "\t \t\t         (ii) Repeat the simulation for ",
  Cell[BoxData[
      \(TraditionalForm\`D = 0.5\)]],
  ". Now what happens? Do the vortices merge? The time required to merge is \
in fact  a sensitive function of the ratio ",
  Cell[BoxData[
      \(TraditionalForm\`D/R\)]],
  ".  [See ",
  ButtonBox["Driscoll and Fine (1990)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  ".] "
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(e)",
    FontWeight->"Bold"],
  " ",
  StyleBox["Vortex crystals",
    FontSlant->"Italic"],
  ". The following code will create an initial condition consisting of a thin \
vortex ring of thickness ",
  Cell[BoxData[
      \(TraditionalForm\`d\)]],
  " surrounding a low vorticity center. Such vortex rings can occur \
naturally, for example, in the eye-walls of hurricanes.  These rings are \
unstable because the flow field is highly sheared.  Follow the dynamics of \
the ring for 1000-1500 time steps.  Often, through chaotic vortex merger \
processes, an equilibrium state will develop  called a v",
  StyleBox["ortex crystal",
    FontSlant->"Italic"],
  ", that consists of several strong vortices in a stable regular pattern \
[\"a phalanx of tornadoes\", in the words of  ",
  ButtonBox["James Glanz (1998)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  "].  (This simulation will take up to several hours. It might be best to \
run the code overnight.) See ",
  ButtonBox["Fine et. al (1995)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text",
  CellTags->"i:71"],

Cell[BoxData[{
    \(M = 50; 
    L = 1; \[CapitalDelta]x\  = \ \(\[CapitalDelta]y\  = \ 
        L/M\); \[Gamma] = \ 1. /6000; \[CapitalDelta]t\  = \ 0.018;\), "\n", 
    \(\(\(Clear[r];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(d\  = \ 0.025; R\  = \ 0.2;\), "\n", 
    \(\(r0\  = \ 
        Table[\((rr = d\ Random[] + R; \[Theta]\  = \ 
              2\ Pi\ Random[]; {rr\ Cos[\[Theta]]\  + \  .5, 
              rr\ Sin[\[Theta]] + \  .5})\), {5000}];\)\), "\n", 
    \(\(rc = 
        Table[\((rr = \((Random[Real, {0, R^3}])\)^\((1/3)\); \[Theta]\  = \ 
              2\ Pi\ Random[]; {rr\ Cos[\[Theta]]\  + \  .5, 
              rr\ Sin[\[Theta]] + \  .5})\), {1000}];\)\), "\n", 
    \(\(r0\  = \ Join[r0, rc];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.94"],

Cell[TextData[{
  "The results of one such simulation are shown in Cell ",
  ButtonBox["7.95",
    ButtonData:>"Cell 7.95",
    ButtonStyle->"Hyperlink"],
  ". Your results may differ substantially because even small differences in \
the initial conditions can lead to large differences in the final state.  \
However,  from this initial condition roughly the same number of vortices in \
the final crystal should appear almost every time. "
}], "Text"],

Cell[TextData[{
  "\t(i) Show, using Eq. ",
  ButtonBox["(7.3.23)",
    ButtonData:>{"Chapter7.nb", "(7.3.23)"},
    ButtonStyle->"Hyperlink"],
  " , that equilibrium vorticity distributions satisfy ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta](x, y)\  = \ \[Zeta](\[Psi])\)]],
  ": contours of vorticity lie along contours of the stream function."
}], "Text"],

Cell[TextData[{
  "\t(ii)   Test whether your final state is an equilibrium by plotting ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](x, y)\)]],
  " vs. ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta](x, y)\)]],
  " for all points ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y)\)\)]],
  " on the grid. (Make a table of data pairs ",
  Cell[BoxData[
      \(TraditionalForm\`\(\({\[Psi]\_\(i\ j\), \ \[Rho]\_\(i\ \
j\)}\)\(,\)\)\)]],
  " and plot them with a list plot.)  Smooth your data by evaluating ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\)]],
  " from the  position data taking ",
  Cell[BoxData[
      \(TraditionalForm\`M = 15\)]],
  ". Does the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)]],
  "-vs.- ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\)]],
  " data fall on one (or more) lines? Comment on the scatter. Repeat this for \
an intermediate value of ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " where the system has not yet achieved equilibrium.  "
}], "Text"],

Cell[TextData[{
  "\t(iii) ",
  StyleBox["Other possible runs:",
    FontSlant->"Italic"],
  " "
}], "Text"],

Cell["\<\
\tRemove the low-vorticity region in the center. How does this \
affect the number of vortices in the final state? \
\>", "Text"],

Cell[TextData[{
  "\tIncrease the thickness ",
  Cell[BoxData[
      \(TraditionalForm\`d\)]],
  " of the ring by a factor of two. How does this affect the number of \
vortices observed in the final state?"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< Utilities`;\)\), "\n", 
    \(Timing[adbash[r0, 1500, \[CapitalDelta]t, 6]]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.95"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -17 0 ]
[.5 1.0125 17 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.65997 .37116 Mdot
.59727 .31797 Mdot
.37533 .3389 Mdot
.46646 .71221 Mdot
.43511 .70589 Mdot
.3822 .33037 Mdot
.55783 .29986 Mdot
.49982 .28502 Mdot
.28413 .43997 Mdot
.45241 .71015 Mdot
.40862 .30653 Mdot
.70211 .57872 Mdot
.54892 .29725 Mdot
.52506 .70901 Mdot
.62809 .65988 Mdot
.71231 .43985 Mdot
.61906 .32219 Mdot
.43042 .70253 Mdot
.69594 .5625 Mdot
.28805 .42699 Mdot
.29354 .49224 Mdot
.47729 .70746 Mdot
.60027 .30683 Mdot
.55623 .70938 Mdot
.70299 .55011 Mdot
.70418 .4706 Mdot
.66216 .37587 Mdot
.70876 .52794 Mdot
.70379 .56922 Mdot
.45647 .28285 Mdot
.70953 .50391 Mdot
.61231 .69185 Mdot
.29708 .50384 Mdot
.6715 .37267 Mdot
.39959 .3152 Mdot
.4185 .29371 Mdot
.36435 .35136 Mdot
.45018 .29032 Mdot
.48084 .27881 Mdot
.42661 .3087 Mdot
.41684 .31067 Mdot
.70547 .46505 Mdot
.40685 .29824 Mdot
.5746 .3025 Mdot
.58813 .70078 Mdot
.68722 .37973 Mdot
.29179 .48245 Mdot
.53884 .69692 Mdot
.65242 .35888 Mdot
.28996 .4919 Mdot
.62927 .66639 Mdot
.58086 .31129 Mdot
.30225 .54979 Mdot
.62035 .3136 Mdot
.5382 .29686 Mdot
.70603 .54438 Mdot
.32461 .38015 Mdot
.65112 .65044 Mdot
.67705 .60028 Mdot
.67625 .38125 Mdot
.56703 .71033 Mdot
.33669 .61943 Mdot
.69717 .57242 Mdot
.30895 .3869 Mdot
.32972 .38384 Mdot
.49224 .30001 Mdot
.59003 .29442 Mdot
.44677 .29233 Mdot
.53935 .70832 Mdot
.32714 .39715 Mdot
.63466 .65921 Mdot
.40878 .30683 Mdot
.69651 .41841 Mdot
.46004 .70749 Mdot
.64894 .36248 Mdot
.42768 .29828 Mdot
.45022 .71593 Mdot
.70424 .4356 Mdot
.28168 .54112 Mdot
.51225 .72444 Mdot
.49989 .71015 Mdot
.37535 .31434 Mdot
.65388 .63028 Mdot
.70764 .4686 Mdot
.59775 .69021 Mdot
.42532 .28913 Mdot
.44351 .70344 Mdot
.70941 .50082 Mdot
.71434 .50949 Mdot
.7098 .56706 Mdot
.28836 .45035 Mdot
.57848 .29395 Mdot
.45277 .70178 Mdot
.62812 .68113 Mdot
.5936 .68307 Mdot
.59511 .68931 Mdot
.71676 .50045 Mdot
.28851 .52662 Mdot
.4454 .30176 Mdot
.29794 .52623 Mdot
.43346 .29442 Mdot
.31123 .58851 Mdot
.61566 .69146 Mdot
.34686 .35196 Mdot
.65488 .3488 Mdot
.28762 .54012 Mdot
.43754 .29863 Mdot
.44378 .69638 Mdot
.43467 .29089 Mdot
.58496 .30129 Mdot
.71334 .49273 Mdot
.39208 .68289 Mdot
.43877 .71379 Mdot
.66835 .38501 Mdot
.65222 .66392 Mdot
.45646 .71144 Mdot
.49483 .70719 Mdot
.5854 .29212 Mdot
.29023 .42915 Mdot
.28089 .47558 Mdot
.61897 .33633 Mdot
.44097 .30436 Mdot
.63157 .33138 Mdot
.35294 .65956 Mdot
.29925 .41896 Mdot
.29234 .54794 Mdot
.30284 .59252 Mdot
.59265 .70202 Mdot
.59417 .68831 Mdot
.34816 .66266 Mdot
.34798 .3492 Mdot
.62067 .33794 Mdot
.53224 .29068 Mdot
.63258 .67893 Mdot
.69457 .39122 Mdot
.53853 .29795 Mdot
.37063 .66085 Mdot
.41221 .69907 Mdot
.69193 .40617 Mdot
.64618 .66483 Mdot
.50183 .29691 Mdot
.52097 .27819 Mdot
.64931 .65326 Mdot
.68868 .38541 Mdot
.37835 .66149 Mdot
.52048 .27788 Mdot
.31311 .58243 Mdot
.71635 .47905 Mdot
.69786 .60251 Mdot
.3899 .30402 Mdot
.62461 .66805 Mdot
.30017 .45665 Mdot
.33555 .62425 Mdot
.52461 .29479 Mdot
.47286 .71544 Mdot
.63018 .33404 Mdot
.68651 .39313 Mdot
.67884 .61544 Mdot
.29046 .52206 Mdot
.67287 .63688 Mdot
.3223 .61717 Mdot
.2958 .58375 Mdot
.48878 .70334 Mdot
.67811 .3774 Mdot
.64373 .33011 Mdot
.63853 .65724 Mdot
.32784 .38797 Mdot
.45921 .71988 Mdot
.40174 .30828 Mdot
.58009 .69495 Mdot
.57379 .69098 Mdot
.68773 .60533 Mdot
.54611 .28807 Mdot
.36361 .32795 Mdot
.28946 .46621 Mdot
.4863 .29714 Mdot
.38854 .31533 Mdot
.32647 .36677 Mdot
.68929 .59164 Mdot
.40004 .69614 Mdot
.32447 .63242 Mdot
.63643 .65883 Mdot
.55896 .70689 Mdot
.70584 .5751 Mdot
.30322 .60544 Mdot
.30863 .6175 Mdot
.66706 .37273 Mdot
.39721 .30409 Mdot
.52364 .71803 Mdot
.6838 .58492 Mdot
.61082 .67721 Mdot
.49202 .29283 Mdot
.5187 .28668 Mdot
.32541 .36135 Mdot
.29076 .42003 Mdot
.3066 .43563 Mdot
.63145 .65174 Mdot
.63141 .65639 Mdot
.51355 .71532 Mdot
.29679 .54452 Mdot
.72121 .51 Mdot
.33617 .62416 Mdot
.62065 .32516 Mdot
.37212 .31702 Mdot
.69415 .61029 Mdot
.69195 .55721 Mdot
.27828 .46614 Mdot
.27865 .50701 Mdot
.32981 .64492 Mdot
.3656 .67062 Mdot
.62451 .66635 Mdot
.66159 .3672 Mdot
.63416 .66331 Mdot
.29656 .50803 Mdot
.43833 .71527 Mdot
.61091 .32717 Mdot
.54722 .695 Mdot
.55685 .30298 Mdot
.42361 .3137 Mdot
.43586 .69849 Mdot
.43692 .69276 Mdot
.70294 .42485 Mdot
.62641 .6801 Mdot
.69584 .5678 Mdot
.70808 .51579 Mdot
.31033 .42584 Mdot
.45765 .29456 Mdot
.45611 .28106 Mdot
.29101 .49283 Mdot
.69371 .39947 Mdot
.58537 .31058 Mdot
.35089 .35264 Mdot
.29623 .47807 Mdot
.40771 .30224 Mdot
.36172 .65792 Mdot
.35314 .34852 Mdot
.37927 .66099 Mdot
.68861 .58608 Mdot
.3566 .33784 Mdot
.37753 .66939 Mdot
.6426 .65053 Mdot
.30723 .59698 Mdot
.41482 .70781 Mdot
.56586 .30465 Mdot
.56108 .28902 Mdot
.65407 .64696 Mdot
.31001 .58884 Mdot
.29822 .50789 Mdot
.68398 .59812 Mdot
.30393 .59892 Mdot
.29663 .57581 Mdot
.68702 .59679 Mdot
.41804 .69301 Mdot
.37102 .32203 Mdot
.71008 .50264 Mdot
.62387 .32594 Mdot
.55731 .7077 Mdot
.47133 .30134 Mdot
.53443 .29717 Mdot
.52328 .72257 Mdot
.42972 .28919 Mdot
.5725 .30913 Mdot
.49282 .70505 Mdot
.47501 .28284 Mdot
.70585 .42098 Mdot
.69505 .60975 Mdot
.69545 .42213 Mdot
.52223 .70898 Mdot
.47588 .28139 Mdot
.29071 .49218 Mdot
.70598 .4412 Mdot
.47028 .70855 Mdot
.49051 .71678 Mdot
.29856 .54535 Mdot
.7118 .50185 Mdot
.47729 .28833 Mdot
.70126 .57928 Mdot
.37572 .32569 Mdot
.65005 .64102 Mdot
.32237 .60016 Mdot
.33952 .63697 Mdot
.68703 .38514 Mdot
.29827 .59215 Mdot
.3667 .33925 Mdot
.59315 .68238 Mdot
.5918 .68033 Mdot
.60084 .69326 Mdot
.29959 .57635 Mdot
.65234 .63216 Mdot
.55062 .30611 Mdot
.72059 .49122 Mdot
.34602 .65918 Mdot
.33516 .37027 Mdot
.30435 .55022 Mdot
.59751 .68936 Mdot
.59313 .30271 Mdot
.70819 .49931 Mdot
.36787 .32936 Mdot
.59892 .30888 Mdot
.55852 .69266 Mdot
.44987 .29244 Mdot
.3287 .60509 Mdot
.45733 .28646 Mdot
.69805 .55093 Mdot
.65817 .63507 Mdot
.32257 .40239 Mdot
.70361 .41667 Mdot
.51295 .29106 Mdot
.69629 .42042 Mdot
.66417 .64422 Mdot
.66834 .64412 Mdot
.68456 .38554 Mdot
.33135 .62187 Mdot
.2838 .50105 Mdot
.41054 .30416 Mdot
.29522 .55373 Mdot
.31204 .41254 Mdot
.6517 .35594 Mdot
.35577 .34419 Mdot
.66463 .65317 Mdot
.42905 .31247 Mdot
.70626 .50589 Mdot
.32116 .40205 Mdot
.67872 .61803 Mdot
.59485 .69942 Mdot
.31455 .37621 Mdot
.2945 .50318 Mdot
.64019 .65804 Mdot
.7009 .40272 Mdot
.49315 .70194 Mdot
.43851 .70173 Mdot
.63262 .65261 Mdot
.33348 .37141 Mdot
.64956 .66249 Mdot
.70396 .53218 Mdot
.70058 .54975 Mdot
.61902 .32619 Mdot
.30364 .57067 Mdot
.3815 .66744 Mdot
.41745 .70655 Mdot
.31881 .59992 Mdot
.7073 .5748 Mdot
.65853 .65401 Mdot
.69053 .39366 Mdot
.29072 .47616 Mdot
.55175 .28375 Mdot
.29604 .50879 Mdot
.49823 .28431 Mdot
.36891 .3252 Mdot
.43151 .69535 Mdot
.43462 .7031 Mdot
.70938 .491 Mdot
.65029 .35847 Mdot
.69817 .41871 Mdot
.50935 .28979 Mdot
.71941 .52642 Mdot
.51549 .72426 Mdot
.52568 .72216 Mdot
.49429 .27943 Mdot
.29324 .52218 Mdot
.66481 .61706 Mdot
.58633 .68145 Mdot
.56444 .29615 Mdot
.58448 .69919 Mdot
.68104 .39892 Mdot
.50239 .70216 Mdot
.6167 .68877 Mdot
.52707 .70439 Mdot
.69654 .39649 Mdot
.70751 .49655 Mdot
.58925 .68065 Mdot
.27632 .47976 Mdot
.69749 .60644 Mdot
.38611 .69248 Mdot
.46062 .70684 Mdot
.62303 .66683 Mdot
.3695 .65576 Mdot
.66652 .38023 Mdot
.56483 .69583 Mdot
.39424 .3026 Mdot
.46564 .7063 Mdot
.40098 .30757 Mdot
.66852 .62131 Mdot
.61618 .68307 Mdot
.70656 .52692 Mdot
.599 .30559 Mdot
.48696 .27763 Mdot
.40555 .31146 Mdot
.34025 .65061 Mdot
.53261 .29684 Mdot
.59012 .6933 Mdot
.66451 .62533 Mdot
.66832 .38452 Mdot
.30553 .59263 Mdot
.57502 .29161 Mdot
.47302 .72195 Mdot
.54568 .29177 Mdot
.30704 .57044 Mdot
.70736 .55839 Mdot
.52505 .2819 Mdot
.38637 .31059 Mdot
.71356 .49043 Mdot
.29352 .52157 Mdot
.65885 .36733 Mdot
.32117 .40294 Mdot
.29023 .55385 Mdot
.53128 .29539 Mdot
.57929 .70306 Mdot
.71836 .48595 Mdot
.49528 .28748 Mdot
.69183 .43241 Mdot
.71601 .47031 Mdot
.45845 .70331 Mdot
.7034 .48127 Mdot
.56769 .28551 Mdot
.68296 .62625 Mdot
.54216 .71739 Mdot
.36504 .34473 Mdot
.29806 .57217 Mdot
.29967 .5716 Mdot
.2879 .56076 Mdot
.43684 .31006 Mdot
.28315 .48703 Mdot
.46202 .29639 Mdot
.52965 .70762 Mdot
.48124 .29801 Mdot
.31085 .5908 Mdot
.3681 .34233 Mdot
.55403 .70642 Mdot
.7248 .50425 Mdot
.51951 .27692 Mdot
.30166 .42486 Mdot
.4272 .68981 Mdot
.63378 .33562 Mdot
.56368 .29878 Mdot
.63245 .65623 Mdot
.31857 .41273 Mdot
.33454 .6158 Mdot
.63528 .66905 Mdot
.51902 .27942 Mdot
.68558 .41737 Mdot
.51486 .27894 Mdot
.59901 .67862 Mdot
.5609 .70041 Mdot
.6292 .34612 Mdot
.37571 .68457 Mdot
.69858 .58207 Mdot
.5591 .70952 Mdot
.2868 .51204 Mdot
.57107 .2963 Mdot
.37128 .68089 Mdot
.71254 .5542 Mdot
.31154 .6113 Mdot
.45955 .71909 Mdot
.50586 .71457 Mdot
.68947 .59805 Mdot
.34013 .64185 Mdot
.47521 .28561 Mdot
.402 .70126 Mdot
.27972 .46449 Mdot
.60259 .3164 Mdot
.46372 .29581 Mdot
.28796 .52318 Mdot
.41205 .30596 Mdot
.69995 .59038 Mdot
.32334 .62297 Mdot
.58942 .31577 Mdot
.40584 .67861 Mdot
.30043 .58278 Mdot
.32581 .38077 Mdot
.66265 .64395 Mdot
.69265 .59079 Mdot
.45587 .70212 Mdot
.38117 .66777 Mdot
.56956 .29278 Mdot
.39022 .31219 Mdot
.47747 .27698 Mdot
.48401 .70167 Mdot
.68673 .38486 Mdot
.68409 .42086 Mdot
.29926 .53227 Mdot
.38535 .68104 Mdot
.36612 .66324 Mdot
.47507 .69977 Mdot
.68191 .59285 Mdot
.69454 .3957 Mdot
.46892 .70834 Mdot
.49252 .70305 Mdot
.29502 .44793 Mdot
.70071 .4915 Mdot
.34894 .34406 Mdot
.68739 .57133 Mdot
.6225 .67522 Mdot
.45786 .29303 Mdot
.55479 .30487 Mdot
.30109 .56702 Mdot
.45601 .28093 Mdot
.28883 .46437 Mdot
.29984 .57222 Mdot
.47258 .70918 Mdot
.66671 .38717 Mdot
.46391 .70696 Mdot
.46368 .70601 Mdot
.53979 .70577 Mdot
.65597 .65572 Mdot
.27664 .49781 Mdot
.39355 .68993 Mdot
.70162 .57014 Mdot
.33357 .35722 Mdot
.27883 .46257 Mdot
.60179 .67966 Mdot
.49205 .7132 Mdot
.4837 .70454 Mdot
.7014 .47256 Mdot
.72001 .47905 Mdot
.51216 .28166 Mdot
.62788 .34544 Mdot
.48991 .72008 Mdot
.29549 .46271 Mdot
.55894 .69826 Mdot
.68443 .39226 Mdot
.4085 .31374 Mdot
.49726 .29291 Mdot
.30701 .6039 Mdot
.29895 .5187 Mdot
.29781 .57576 Mdot
.29409 .49955 Mdot
.41057 .29655 Mdot
.36947 .34153 Mdot
.31906 .58964 Mdot
.66992 .64353 Mdot
.53745 .71688 Mdot
.56978 .69682 Mdot
.29605 .44011 Mdot
.309 .56489 Mdot
.65533 .65351 Mdot
.71864 .44771 Mdot
.41507 .3162 Mdot
.28722 .55138 Mdot
.7052 .49616 Mdot
.59331 .30787 Mdot
.31616 .41317 Mdot
.44667 .29052 Mdot
.38033 .6704 Mdot
.29353 .48107 Mdot
.5708 .29101 Mdot
.68783 .58364 Mdot
.4115 .31812 Mdot
.66338 .62515 Mdot
.72476 .4955 Mdot
.36672 .33526 Mdot
.71957 .49971 Mdot
.59481 .29781 Mdot
.30458 .59261 Mdot
.66006 .6315 Mdot
.68094 .60264 Mdot
.31398 .37375 Mdot
.46003 .70857 Mdot
.28424 .46132 Mdot
.33176 .37416 Mdot
.31035 .59784 Mdot
.33416 .37069 Mdot
.5408 .30268 Mdot
.33005 .36713 Mdot
.69762 .45278 Mdot
.60059 .70067 Mdot
.6335 .32384 Mdot
.67984 .62045 Mdot
.48846 .72092 Mdot
.57962 .31209 Mdot
.47478 .29957 Mdot
.55236 .71263 Mdot
.42653 .70058 Mdot
.33605 .37088 Mdot
.29018 .46889 Mdot
.71796 .50078 Mdot
.30611 .42216 Mdot
.5986 .30503 Mdot
.44389 .29463 Mdot
.47543 .29946 Mdot
.29424 .56793 Mdot
.69319 .3887 Mdot
.45868 .28934 Mdot
.44339 .30404 Mdot
.32805 .6042 Mdot
.67898 .62843 Mdot
.66473 .36349 Mdot
.6648 .61737 Mdot
.40225 .68021 Mdot
.46866 .70648 Mdot
.34319 .34984 Mdot
.30082 .44433 Mdot
.594 .67702 Mdot
.35378 .35088 Mdot
.29831 .56116 Mdot
.68035 .4028 Mdot
.70316 .55195 Mdot
.59192 .31164 Mdot
.62978 .67858 Mdot
.46599 .29555 Mdot
.59293 .3053 Mdot
.28761 .56932 Mdot
.57001 .71239 Mdot
.68022 .37985 Mdot
.72 .53771 Mdot
.46126 .7041 Mdot
.31003 .40489 Mdot
.37213 .6575 Mdot
.30187 .45697 Mdot
.28736 .45068 Mdot
.34555 .63781 Mdot
.58076 .30504 Mdot
.30056 .4164 Mdot
.3617 .66148 Mdot
.35727 .66427 Mdot
.28726 .55992 Mdot
.38614 .68755 Mdot
.59509 .69089 Mdot
.51683 .29373 Mdot
.58709 .30848 Mdot
.52696 .70242 Mdot
.45711 .71283 Mdot
.62476 .31611 Mdot
.29778 .53971 Mdot
.45925 .70189 Mdot
.67142 .63544 Mdot
.68555 .3947 Mdot
.36938 .31993 Mdot
.30882 .39331 Mdot
.29367 .53445 Mdot
.58791 .3071 Mdot
.37508 .31431 Mdot
.32396 .38963 Mdot
.35468 .64697 Mdot
.49241 .28957 Mdot
.66589 .3872 Mdot
.30103 .54769 Mdot
.56219 .30242 Mdot
.29222 .44004 Mdot
.62493 .6684 Mdot
.71656 .44973 Mdot
.40869 .32151 Mdot
.62824 .66671 Mdot
.70027 .52401 Mdot
.31008 .42958 Mdot
.36503 .32625 Mdot
.58273 .2994 Mdot
.48612 .28103 Mdot
.37549 .67207 Mdot
.69804 .42358 Mdot
.57488 .29193 Mdot
.55404 .30475 Mdot
.62145 .31199 Mdot
.64884 .6367 Mdot
.42849 .29884 Mdot
.66268 .61702 Mdot
.63534 .66179 Mdot
.30301 .5581 Mdot
.3983 .69389 Mdot
.45324 .29427 Mdot
.70443 .4705 Mdot
.53228 .27864 Mdot
.5988 .68578 Mdot
.71938 .47238 Mdot
.39699 .68482 Mdot
.64155 .33286 Mdot
.35276 .33239 Mdot
.51728 .28205 Mdot
.2879 .50512 Mdot
.4237 .69914 Mdot
.606 .69074 Mdot
.33184 .38756 Mdot
.57534 .69781 Mdot
.58756 .31621 Mdot
.69969 .52507 Mdot
.61192 .32532 Mdot
.41966 .30094 Mdot
.71156 .47173 Mdot
.70437 .57164 Mdot
.54624 .71489 Mdot
.30879 .42774 Mdot
.67301 .38717 Mdot
.33879 .63642 Mdot
.41979 .68786 Mdot
.57453 .71179 Mdot
.29948 .50823 Mdot
.59977 .69974 Mdot
.37483 .32124 Mdot
.29206 .5166 Mdot
.4058 .31817 Mdot
.30154 .58786 Mdot
.29741 .55521 Mdot
.65145 .35074 Mdot
.30638 .43759 Mdot
.29913 .51526 Mdot
.52054 .72322 Mdot
.44759 .69501 Mdot
.48867 .27681 Mdot
.65234 .63518 Mdot
.67388 .60906 Mdot
.34754 .3413 Mdot
.3273 .6018 Mdot
.56934 .69081 Mdot
.70788 .44324 Mdot
.4103 .69582 Mdot
.32242 .61593 Mdot
.60357 .31281 Mdot
.59956 .68819 Mdot
.29422 .44903 Mdot
.30563 .59054 Mdot
.3155 .59676 Mdot
.3863 .67557 Mdot
.55942 .29518 Mdot
.68668 .40669 Mdot
.33023 .37598 Mdot
.71399 .4573 Mdot
.45603 .71541 Mdot
.30867 .42327 Mdot
.30352 .56164 Mdot
.33347 .64105 Mdot
.68701 .38617 Mdot
.6966 .44626 Mdot
.28983 .51342 Mdot
.33623 .35365 Mdot
.42458 .29086 Mdot
.42215 .30396 Mdot
.67578 .61866 Mdot
.46079 .28583 Mdot
.58307 .29928 Mdot
.61284 .67899 Mdot
.36445 .66211 Mdot
.53052 .28379 Mdot
.29418 .56995 Mdot
.58494 .30299 Mdot
.69963 .44607 Mdot
.56963 .70859 Mdot
.48279 .70875 Mdot
.29136 .48834 Mdot
.60885 .69391 Mdot
.55075 .2898 Mdot
.37312 .6612 Mdot
.35733 .35327 Mdot
.71874 .49353 Mdot
.62942 .33297 Mdot
.30743 .44084 Mdot
.71475 .55532 Mdot
.31411 .38296 Mdot
.60966 .33053 Mdot
.403 .68648 Mdot
.39202 .68925 Mdot
.61657 .67807 Mdot
.30629 .44397 Mdot
.56618 .30314 Mdot
.69289 .39011 Mdot
.57411 .2994 Mdot
.69457 .58084 Mdot
.48815 .71207 Mdot
.71178 .5302 Mdot
.39445 .30956 Mdot
.58892 .69252 Mdot
.38539 .67302 Mdot
.62728 .32157 Mdot
.58679 .70183 Mdot
.42786 .70522 Mdot
.34207 .64146 Mdot
.33347 .64457 Mdot
.30272 .39567 Mdot
.40645 .68783 Mdot
.41201 .69152 Mdot
.43041 .70967 Mdot
.37084 .32434 Mdot
.65237 .64284 Mdot
.42748 .69761 Mdot
.47142 .71277 Mdot
.65674 .64833 Mdot
.71752 .45488 Mdot
.4832 .29691 Mdot
.32408 .4015 Mdot
.61078 .67322 Mdot
.48953 .71653 Mdot
.61885 .31505 Mdot
.71274 .44064 Mdot
.57215 .68847 Mdot
.61001 .31876 Mdot
.66301 .3578 Mdot
.29627 .41096 Mdot
.51915 .3004 Mdot
.33667 .38425 Mdot
.71822 .5393 Mdot
.72231 .52368 Mdot
.64686 .34145 Mdot
.51194 .29356 Mdot
.71786 .53874 Mdot
.56832 .30046 Mdot
.61314 .31195 Mdot
.71871 .45208 Mdot
.69335 .43767 Mdot
.33686 .61838 Mdot
.58031 .68604 Mdot
.5646 .30926 Mdot
.61382 .67159 Mdot
.54435 .30209 Mdot
.44937 .70873 Mdot
.71812 .5358 Mdot
.48647 .71809 Mdot
.53497 .70719 Mdot
.30124 .60339 Mdot
.48977 .71097 Mdot
.28221 .53689 Mdot
.6312 .33648 Mdot
.44817 .71201 Mdot
.69567 .57134 Mdot
.64402 .65604 Mdot
.47354 .70374 Mdot
.62335 .31475 Mdot
.50701 .7093 Mdot
.32347 .39764 Mdot
.7223 .52991 Mdot
.60989 .67307 Mdot
.51815 .28769 Mdot
.41897 .30722 Mdot
.66894 .38667 Mdot
.32655 .62851 Mdot
.62976 .32214 Mdot
.47812 .70234 Mdot
.31169 .39685 Mdot
.31729 .59506 Mdot
.3954 .67664 Mdot
.6082 .32954 Mdot
.41961 .68965 Mdot
.40559 .2992 Mdot
.29287 .43236 Mdot
.71258 .49115 Mdot
.36779 .33114 Mdot
.31637 .37543 Mdot
.55981 .28902 Mdot
.39754 .69285 Mdot
.54563 .69943 Mdot
.675 .37958 Mdot
.66265 .34555 Mdot
.6937 .58247 Mdot
.29981 .41291 Mdot
.34063 .64228 Mdot
.69952 .51895 Mdot
.34472 .62743 Mdot
.35483 .65306 Mdot
.55785 .3044 Mdot
.3081 .39943 Mdot
.29364 .54201 Mdot
.36214 .66116 Mdot
.29462 .41271 Mdot
.28836 .522 Mdot
.28736 .50013 Mdot
.69111 .39211 Mdot
.66719 .64907 Mdot
.67972 .37477 Mdot
.46545 .27957 Mdot
.2962 .458 Mdot
.698 .40606 Mdot
.70803 .4403 Mdot
.29753 .55001 Mdot
.32948 .38739 Mdot
.66825 .37367 Mdot
.66741 .6374 Mdot
.32178 .63364 Mdot
.58024 .70711 Mdot
.45572 .71934 Mdot
.45193 .69729 Mdot
.31185 .43032 Mdot
.50786 .28017 Mdot
.35579 .35221 Mdot
.5631 .30648 Mdot
.61288 .69224 Mdot
.55947 .71617 Mdot
.47601 .71118 Mdot
.66958 .61981 Mdot
.64742 .34381 Mdot
.67539 .38356 Mdot
.31667 .38575 Mdot
.3476 .35924 Mdot
.71097 .54334 Mdot
.63851 .33886 Mdot
.32702 .61709 Mdot
.69287 .58036 Mdot
.51351 .71051 Mdot
.62914 .33473 Mdot
.71991 .46062 Mdot
.50973 .29812 Mdot
.6677 .62411 Mdot
.62835 .32553 Mdot
.28308 .48266 Mdot
.52326 .70783 Mdot
.29929 .52478 Mdot
.34903 .66228 Mdot
.69446 .59932 Mdot
.42616 .69948 Mdot
.60597 .32171 Mdot
.30663 .56167 Mdot
.63678 .34197 Mdot
.42983 .31181 Mdot
.51529 .30021 Mdot
.61461 .32492 Mdot
.50071 .70776 Mdot
.34579 .37245 Mdot
.52448 .29594 Mdot
.51185 .70314 Mdot
.4267 .3009 Mdot
.69765 .41344 Mdot
.62903 .34101 Mdot
.28833 .5221 Mdot
.72064 .493 Mdot
.55303 .29477 Mdot
.52377 .71909 Mdot
.69199 .43493 Mdot
.71146 .47779 Mdot
.3936 .6724 Mdot
.54602 .70192 Mdot
.68353 .62861 Mdot
.28188 .47177 Mdot
.60832 .67795 Mdot
.38697 .31689 Mdot
.40553 .30075 Mdot
.39072 .30972 Mdot
.66009 .36636 Mdot
.29481 .58998 Mdot
.69199 .42579 Mdot
.29856 .56422 Mdot
.33808 .37716 Mdot
.51726 .7036 Mdot
.29601 .49229 Mdot
.45568 .29535 Mdot
.37815 .68414 Mdot
.70668 .57305 Mdot
.39642 .32857 Mdot
.32949 .64647 Mdot
.53284 .28575 Mdot
.69198 .44136 Mdot
.60497 .31705 Mdot
.28571 .49739 Mdot
.52653 .70598 Mdot
.47972 .70899 Mdot
.4664 .29925 Mdot
.30898 .43881 Mdot
.34806 .64167 Mdot
.29373 .50613 Mdot
.45738 .29698 Mdot
.66063 .62989 Mdot
.70194 .42422 Mdot
.61527 .67054 Mdot
.65782 .63048 Mdot
.37656 .32209 Mdot
.66222 .34831 Mdot
.34245 .6336 Mdot
.62086 .68208 Mdot
.60897 .3252 Mdot
.5345 .29204 Mdot
.37555 .687 Mdot
.6895 .57379 Mdot
.52021 .71711 Mdot
.65843 .64187 Mdot
.68606 .60202 Mdot
.70773 .5082 Mdot
.30255 .59849 Mdot
.64818 .64994 Mdot
.70792 .55102 Mdot
.71321 .45823 Mdot
.56483 .69774 Mdot
.57232 .69338 Mdot
.62893 .33618 Mdot
.63532 .65145 Mdot
.34379 .35165 Mdot
.7141 .52393 Mdot
.3035 .44814 Mdot
.707 .5149 Mdot
.65596 .63698 Mdot
.66678 .35388 Mdot
.69379 .60091 Mdot
.67683 .39733 Mdot
.65047 .35295 Mdot
.46268 .28012 Mdot
.70021 .5262 Mdot
.31379 .38299 Mdot
.32904 .62451 Mdot
.31584 .4111 Mdot
.63149 .33849 Mdot
.29371 .41811 Mdot
.49249 .29945 Mdot
.40872 .3218 Mdot
.39749 .31993 Mdot
.51161 .27957 Mdot
.55625 .28544 Mdot
.71731 .54877 Mdot
.52769 .28186 Mdot
.30883 .56768 Mdot
.35708 .65166 Mdot
.65717 .34137 Mdot
.3004 .48552 Mdot
.42106 .68523 Mdot
.5246 .27692 Mdot
.37127 .34546 Mdot
.67587 .62751 Mdot
.65069 .36043 Mdot
.42009 .70543 Mdot
.61777 .32894 Mdot
.30544 .45141 Mdot
.33416 .62031 Mdot
.6062 .68941 Mdot
.29614 .46659 Mdot
.38045 .31888 Mdot
.54887 .69933 Mdot
.66736 .36095 Mdot
.31659 .41048 Mdot
.5496 .30589 Mdot
.41919 .29141 Mdot
.29657 .52469 Mdot
.62167 .3215 Mdot
.69089 .42695 Mdot
.3013 .57139 Mdot
.53078 .29 Mdot
.67879 .40061 Mdot
.66426 .64669 Mdot
.44083 .28362 Mdot
.53 .70041 Mdot
.64538 .66542 Mdot
.31358 .57855 Mdot
.29201 .57625 Mdot
.71383 .43898 Mdot
.33288 .38041 Mdot
.71714 .51905 Mdot
.62472 .68046 Mdot
.51193 .70538 Mdot
.52089 .71379 Mdot
.64908 .64861 Mdot
.2876 .46364 Mdot
.66692 .37614 Mdot
.32876 .63855 Mdot
.30031 .54879 Mdot
.71175 .42774 Mdot
.29195 .49201 Mdot
.37305 .67752 Mdot
.28503 .51057 Mdot
.57576 .71067 Mdot
.49814 .70949 Mdot
.70268 .44872 Mdot
.65672 .66003 Mdot
.30019 .58859 Mdot
.52942 .71412 Mdot
.71563 .55804 Mdot
.52166 .29055 Mdot
.68638 .62527 Mdot
.48692 .70194 Mdot
.494 .29376 Mdot
.52409 .28923 Mdot
.30283 .43551 Mdot
.29847 .47878 Mdot
.31121 .3806 Mdot
.34306 .62978 Mdot
.61387 .67024 Mdot
.61187 .68068 Mdot
.65547 .63591 Mdot
.34015 .6234 Mdot
.70528 .52613 Mdot
.64844 .66853 Mdot
.4689 .69819 Mdot
.35756 .65761 Mdot
.46514 .28463 Mdot
.6236 .33048 Mdot
.64565 .6646 Mdot
.30025 .55098 Mdot
.71303 .47109 Mdot
.43445 .70858 Mdot
.63708 .34293 Mdot
.67775 .37607 Mdot
.61229 .33264 Mdot
.52453 .28428 Mdot
.31781 .41527 Mdot
.33362 .6192 Mdot
.61658 .32804 Mdot
.29123 .43101 Mdot
.44718 .29369 Mdot
.68005 .61516 Mdot
.47425 .27851 Mdot
.55754 .28756 Mdot
.64424 .34123 Mdot
.65591 .36937 Mdot
.71069 .53109 Mdot
.65313 .64558 Mdot
.29674 .56039 Mdot
.46118 .29706 Mdot
.34195 .37056 Mdot
.60302 .68499 Mdot
.67429 .37186 Mdot
.69639 .60567 Mdot
.60815 .68968 Mdot
.45391 .69762 Mdot
.43683 .69379 Mdot
.32048 .63485 Mdot
.46378 .7128 Mdot
.46468 .71029 Mdot
.59001 .31714 Mdot
.30629 .4281 Mdot
.55093 .71867 Mdot
.33286 .64287 Mdot
.41794 .69134 Mdot
.41979 .70687 Mdot
.62959 .67137 Mdot
.71678 .53071 Mdot
.62058 .32682 Mdot
.34478 .34491 Mdot
.30077 .4063 Mdot
.38044 .66799 Mdot
.49615 .28369 Mdot
.55842 .28316 Mdot
.28798 .45459 Mdot
.33111 .61564 Mdot
.54025 .70471 Mdot
.67145 .61744 Mdot
.69668 .59581 Mdot
.69166 .59491 Mdot
.53205 .70526 Mdot
.29206 .5701 Mdot
.38093 .32389 Mdot
.67268 .62513 Mdot
.68546 .37937 Mdot
.42394 .69969 Mdot
.35579 .64487 Mdot
.67171 .38087 Mdot
.62348 .68302 Mdot
.57157 .31199 Mdot
.67491 .60106 Mdot
.47963 .28868 Mdot
.63767 .32935 Mdot
.45053 .71217 Mdot
.56057 .6976 Mdot
.57931 .68862 Mdot
.442 .70228 Mdot
.65623 .35094 Mdot
.68042 .40052 Mdot
.70445 .46797 Mdot
.51882 .2906 Mdot
.60209 .67866 Mdot
.41238 .31109 Mdot
.30079 .58968 Mdot
.59455 .30804 Mdot
.62173 .65944 Mdot
.34904 .35792 Mdot
.71389 .44446 Mdot
.39835 .69722 Mdot
.67918 .59972 Mdot
.32076 .62028 Mdot
.67581 .63737 Mdot
.37061 .34021 Mdot
.70116 .41769 Mdot
.71566 .44577 Mdot
.27625 .49225 Mdot
.63489 .65884 Mdot
.35844 .67268 Mdot
.30017 .47759 Mdot
.33654 .61919 Mdot
.57274 .69081 Mdot
.40677 .70174 Mdot
.54798 .29211 Mdot
.55117 .7182 Mdot
.62791 .66369 Mdot
.46745 .7042 Mdot
.58519 .69235 Mdot
.5256 .2937 Mdot
.69372 .55719 Mdot
.32278 .61191 Mdot
.30218 .46494 Mdot
.70684 .51383 Mdot
.38609 .6902 Mdot
.42479 .30387 Mdot
.30176 .43589 Mdot
.29101 .52856 Mdot
.33384 .6124 Mdot
.55914 .69541 Mdot
.53807 .71184 Mdot
.29771 .58968 Mdot
.59561 .69062 Mdot
.70943 .53078 Mdot
.37314 .32971 Mdot
.70373 .51617 Mdot
.41783 .69938 Mdot
.40553 .69793 Mdot
.51619 .29334 Mdot
.6144 .32583 Mdot
.37118 .66163 Mdot
.3691 .34325 Mdot
.64274 .66271 Mdot
.55716 .69993 Mdot
.69661 .4487 Mdot
.59112 .70164 Mdot
.41892 .70004 Mdot
.60467 .68997 Mdot
.7002 .49883 Mdot
.62966 .31909 Mdot
.51828 .71713 Mdot
.71402 .50872 Mdot
.65355 .35496 Mdot
.35896 .65556 Mdot
.49191 .28038 Mdot
.6066 .67162 Mdot
.54693 .28858 Mdot
.70399 .47304 Mdot
.30206 .5333 Mdot
.57778 .30078 Mdot
.30206 .53211 Mdot
.70959 .44656 Mdot
.51593 .70701 Mdot
.69363 .44214 Mdot
.36076 .67214 Mdot
.31422 .38765 Mdot
.348 .36751 Mdot
.30835 .59761 Mdot
.60044 .3155 Mdot
.30264 .56974 Mdot
.37079 .66472 Mdot
.35599 .33309 Mdot
.65353 .35845 Mdot
.40895 .31727 Mdot
.37537 .34205 Mdot
.46544 .30091 Mdot
.45478 .69974 Mdot
.63778 .65842 Mdot
.40362 .32116 Mdot
.44673 .28668 Mdot
.61915 .31734 Mdot
.48004 .70961 Mdot
.29205 .51817 Mdot
.35119 .34467 Mdot
.32199 .36251 Mdot
.70142 .43732 Mdot
.71703 .44572 Mdot
.52704 .70713 Mdot
.4013 .30459 Mdot
.68657 .62384 Mdot
.71569 .50573 Mdot
.34932 .63761 Mdot
.61667 .68967 Mdot
.66198 .64665 Mdot
.4042 .30871 Mdot
.29711 .51444 Mdot
.69282 .59286 Mdot
.28831 .45029 Mdot
.66551 .6377 Mdot
.42644 .69516 Mdot
.29689 .58807 Mdot
.54688 .70432 Mdot
.31359 .58677 Mdot
.60117 .32105 Mdot
.47598 .70655 Mdot
.45347 .29311 Mdot
.31682 .37996 Mdot
.53122 .70631 Mdot
.29677 .47317 Mdot
.41964 .29928 Mdot
.3184 .61453 Mdot
.34683 .64021 Mdot
.71575 .46661 Mdot
.60999 .69401 Mdot
.29571 .44078 Mdot
.3881 .68646 Mdot
.46609 .70193 Mdot
.35137 .35824 Mdot
.41527 .30703 Mdot
.32468 .63575 Mdot
.60667 .67595 Mdot
.44358 .30237 Mdot
.50382 .28397 Mdot
.40042 .69939 Mdot
.53795 .2805 Mdot
.62545 .6866 Mdot
.52326 .70876 Mdot
.58804 .31222 Mdot
.69745 .44379 Mdot
.56418 .69153 Mdot
.47015 .7175 Mdot
.56759 .30618 Mdot
.66604 .63465 Mdot
.68374 .62941 Mdot
.3628 .67543 Mdot
.53025 .30041 Mdot
.30178 .39363 Mdot
.35113 .36344 Mdot
.37804 .67695 Mdot
.56572 .29044 Mdot
.33833 .63343 Mdot
.3238 .37227 Mdot
.65819 .64572 Mdot
.56107 .29661 Mdot
.7009 .51268 Mdot
.43273 .29831 Mdot
.38493 .33206 Mdot
.68767 .40412 Mdot
.68084 .59359 Mdot
.42722 .69562 Mdot
.47316 .28798 Mdot
.2862 .48881 Mdot
.39088 .67247 Mdot
.68586 .37956 Mdot
.53838 .71055 Mdot
.65938 .63538 Mdot
.55125 .70645 Mdot
.31056 .61478 Mdot
.30407 .42684 Mdot
.2898 .51525 Mdot
.29596 .52464 Mdot
.58396 .68376 Mdot
.50124 .28319 Mdot
.40151 .31121 Mdot
.31959 .6127 Mdot
.52034 .28449 Mdot
.58257 .70791 Mdot
.38121 .33005 Mdot
.70907 .47166 Mdot
.51376 .7104 Mdot
.3221 .59536 Mdot
.50142 .29991 Mdot
.70619 .41958 Mdot
.29778 .40586 Mdot
.5754 .6901 Mdot
.66674 .37213 Mdot
.53897 .28675 Mdot
.64878 .66024 Mdot
.31509 .38438 Mdot
.29071 .52913 Mdot
.34074 .36761 Mdot
.51462 .69992 Mdot
.57712 .69021 Mdot
.30029 .51603 Mdot
.50278 .70891 Mdot
.67598 .40023 Mdot
.69101 .57283 Mdot
.71509 .52998 Mdot
.46119 .70906 Mdot
.67323 .35877 Mdot
.41953 .29573 Mdot
.31862 .61014 Mdot
.68624 .60223 Mdot
.59641 .68853 Mdot
.66064 .36913 Mdot
.41911 .30469 Mdot
.36129 .32504 Mdot
.52568 .29248 Mdot
.31186 .3882 Mdot
.49667 .28309 Mdot
.42878 .69353 Mdot
.63541 .32861 Mdot
.34198 .35918 Mdot
.30674 .57196 Mdot
.28149 .44978 Mdot
.47454 .71799 Mdot
.36674 .32874 Mdot
.31829 .39862 Mdot
.71872 .50199 Mdot
.58428 .29248 Mdot
.30564 .61312 Mdot
.69061 .58084 Mdot
.6685 .63937 Mdot
.55647 .70602 Mdot
.29314 .50763 Mdot
.51842 .29342 Mdot
.70066 .44602 Mdot
.28715 .50583 Mdot
.41627 .69889 Mdot
.67609 .39533 Mdot
.4157 .70544 Mdot
.66406 .62438 Mdot
.67629 .36478 Mdot
.71701 .55485 Mdot
.54549 .30163 Mdot
.60355 .31707 Mdot
.44256 .71394 Mdot
.68467 .58383 Mdot
.39287 .68493 Mdot
.30685 .40585 Mdot
.72115 .52815 Mdot
.38474 .32444 Mdot
.44782 .30603 Mdot
.30762 .4317 Mdot
.57773 .31172 Mdot
.29559 .48081 Mdot
.69742 .5331 Mdot
.40995 .29916 Mdot
.48044 .29728 Mdot
.33708 .3562 Mdot
.32522 .6251 Mdot
.69512 .55392 Mdot
.3409 .64757 Mdot
.33658 .64339 Mdot
.39923 .3088 Mdot
.60401 .31381 Mdot
.63592 .33673 Mdot
.416 .69024 Mdot
.60696 .31665 Mdot
.3575 .34188 Mdot
.66926 .62194 Mdot
.71912 .52512 Mdot
.43012 .29279 Mdot
.71549 .46623 Mdot
.41729 .68394 Mdot
.33045 .39257 Mdot
.37039 .33408 Mdot
.51175 .28788 Mdot
.54725 .28196 Mdot
.30865 .57213 Mdot
.70048 .43474 Mdot
.57895 .29826 Mdot
.61943 .33682 Mdot
.55659 .28628 Mdot
.6201 .67048 Mdot
.5817 .31421 Mdot
.60537 .32199 Mdot
.53032 .69996 Mdot
.58068 .70609 Mdot
.28974 .5439 Mdot
.31409 .62355 Mdot
.7078 .53239 Mdot
.29541 .55703 Mdot
.54737 .71348 Mdot
.33489 .36996 Mdot
.30228 .60223 Mdot
.30678 .55764 Mdot
.32912 .36202 Mdot
.33866 .35077 Mdot
.33961 .64675 Mdot
.29891 .59745 Mdot
.67427 .39668 Mdot
.69841 .52701 Mdot
.66761 .36172 Mdot
.30455 .41571 Mdot
.39844 .30078 Mdot
.69587 .4479 Mdot
.49885 .70102 Mdot
.29905 .49398 Mdot
.37126 .33868 Mdot
.65556 .36454 Mdot
.48558 .71352 Mdot
.29945 .55447 Mdot
.38017 .67417 Mdot
.30885 .58094 Mdot
.28931 .56021 Mdot
.65187 .3412 Mdot
.54232 .2836 Mdot
.6853 .38697 Mdot
.28437 .45912 Mdot
.31904 .61795 Mdot
.66161 .36113 Mdot
.29228 .47098 Mdot
.34284 .34028 Mdot
.68566 .57938 Mdot
.45966 .70881 Mdot
.3479 .34196 Mdot
.59882 .30507 Mdot
.50931 .27558 Mdot
.7146 .5608 Mdot
.61534 .32743 Mdot
.29723 .48196 Mdot
.30087 .58512 Mdot
.34965 .34563 Mdot
.67711 .39318 Mdot
.71641 .50111 Mdot
.61973 .33371 Mdot
.46237 .29976 Mdot
.53781 .70714 Mdot
.6667 .37197 Mdot
.29423 .54644 Mdot
.62665 .32982 Mdot
.35253 .35994 Mdot
.3908 .67769 Mdot
.58389 .6945 Mdot
.44657 .28858 Mdot
.47231 .70311 Mdot
.4496 .30474 Mdot
.32332 .5939 Mdot
.72241 .4851 Mdot
.56503 .70442 Mdot
.67699 .618 Mdot
.48251 .29718 Mdot
.51037 .70032 Mdot
.64982 .63278 Mdot
.67877 .37696 Mdot
.69319 .40943 Mdot
.57791 .70996 Mdot
.38687 .32501 Mdot
.27888 .52278 Mdot
.51777 .70753 Mdot
.27576 .50803 Mdot
.71338 .5483 Mdot
.32821 .62364 Mdot
.43464 .70504 Mdot
.61427 .67747 Mdot
.587 .69663 Mdot
.49327 .71895 Mdot
.4956 .70161 Mdot
.7039 .58287 Mdot
.31932 .37752 Mdot
.30328 .3954 Mdot
.36778 .66313 Mdot
.69339 .61189 Mdot
.4043 .69388 Mdot
.41317 .30685 Mdot
.69876 .53002 Mdot
.30155 .47009 Mdot
.61324 .32197 Mdot
.47549 .70518 Mdot
.32096 .39153 Mdot
.55584 .70403 Mdot
.71577 .48898 Mdot
.3534 .34447 Mdot
.36225 .34674 Mdot
.29371 .43834 Mdot
.42028 .69951 Mdot
.63312 .34603 Mdot
.45121 .7082 Mdot
.39168 .67151 Mdot
.30851 .56694 Mdot
.69972 .59511 Mdot
.63906 .33144 Mdot
.63692 .34121 Mdot
.63664 .3506 Mdot
.52279 .71976 Mdot
.52163 .72034 Mdot
.4211 .31011 Mdot
.6834 .40499 Mdot
.59046 .31928 Mdot
.35839 .33464 Mdot
.27686 .52221 Mdot
.57807 .70017 Mdot
.32624 .60502 Mdot
.39211 .69327 Mdot
.29242 .43223 Mdot
.28696 .55026 Mdot
.40953 .70319 Mdot
.52969 .7205 Mdot
.35095 .34258 Mdot
.42714 .70328 Mdot
.57334 .29821 Mdot
.38938 .3061 Mdot
.4067 .69421 Mdot
.29385 .53044 Mdot
.67777 .38371 Mdot
.62928 .66806 Mdot
.36295 .67089 Mdot
.41024 .30117 Mdot
.71436 .55634 Mdot
.28857 .56314 Mdot
.32598 .60806 Mdot
.62133 .66489 Mdot
.3309 .36699 Mdot
.29491 .52388 Mdot
.45126 .71933 Mdot
.72299 .50685 Mdot
.34804 .64819 Mdot
.63376 .33674 Mdot
.71657 .52656 Mdot
.59681 .69523 Mdot
.71954 .47018 Mdot
.46237 .28096 Mdot
.30218 .4115 Mdot
.30548 .4026 Mdot
.69551 .45095 Mdot
.67653 .61569 Mdot
.40956 .3195 Mdot
.68162 .61121 Mdot
.43486 .70451 Mdot
.52757 .70002 Mdot
.45897 .71761 Mdot
.69816 .56641 Mdot
.42897 .71337 Mdot
.39969 .68648 Mdot
.47936 .29286 Mdot
.50642 .28089 Mdot
.53016 .29562 Mdot
.39106 .32264 Mdot
.66767 .61743 Mdot
.30375 .40018 Mdot
.56409 .29471 Mdot
.3754 .67921 Mdot
.28285 .47464 Mdot
.44132 .70088 Mdot
.54455 .71416 Mdot
.71767 .45376 Mdot
.2906 .52223 Mdot
.54806 .69756 Mdot
.44908 .30248 Mdot
.29046 .43237 Mdot
.32956 .35423 Mdot
.6975 .46846 Mdot
.58242 .30771 Mdot
.3567 .351 Mdot
.43863 .70666 Mdot
.38933 .69298 Mdot
.69534 .60514 Mdot
.35 .66761 Mdot
.32558 .38079 Mdot
.62552 .68263 Mdot
.65598 .36347 Mdot
.34043 .37707 Mdot
.47009 .70586 Mdot
.36182 .35345 Mdot
.28375 .55768 Mdot
.71968 .50217 Mdot
.60871 .6776 Mdot
.39135 .30614 Mdot
.68263 .60645 Mdot
.42798 .71031 Mdot
.30039 .51435 Mdot
.61964 .66113 Mdot
.32622 .36865 Mdot
.2842 .43896 Mdot
.39887 .68383 Mdot
.69123 .3856 Mdot
.64591 .34758 Mdot
.67329 .394 Mdot
.44828 .30393 Mdot
.50785 .70576 Mdot
.34696 .34703 Mdot
.69463 .42493 Mdot
.6416 .66346 Mdot
.55558 .29965 Mdot
.28146 .45349 Mdot
.50106 .70865 Mdot
.56175 .7045 Mdot
.39269 .68146 Mdot
.40039 .67644 Mdot
.31655 .59733 Mdot
.33887 .34318 Mdot
.58769 .68171 Mdot
.70844 .49723 Mdot
.51777 .71743 Mdot
.64002 .33395 Mdot
.30266 .57251 Mdot
.39687 .69294 Mdot
.56857 .68957 Mdot
.64525 .64488 Mdot
.6373 .33355 Mdot
.55406 .30481 Mdot
.30779 .57975 Mdot
.59747 .67772 Mdot
.48838 .70601 Mdot
.60286 .6936 Mdot
.71116 .5293 Mdot
.42471 .68748 Mdot
.32094 .40449 Mdot
.70702 .47734 Mdot
.35046 .63483 Mdot
.62733 .34178 Mdot
.2917 .46908 Mdot
.68414 .57948 Mdot
.6736 .60422 Mdot
.67583 .36307 Mdot
.60296 .30429 Mdot
.46488 .29942 Mdot
.57061 .30439 Mdot
.32868 .60626 Mdot
.52934 .70291 Mdot
.30303 .59422 Mdot
.61333 .33078 Mdot
.3059 .40696 Mdot
.40657 .69706 Mdot
.28548 .49152 Mdot
.52108 .71458 Mdot
.33433 .36012 Mdot
.31669 .62068 Mdot
.66357 .36326 Mdot
.33063 .37332 Mdot
.29051 .52976 Mdot
.35394 .64595 Mdot
.70817 .56555 Mdot
.30106 .46057 Mdot
.29904 .52872 Mdot
.55129 .70335 Mdot
.70981 .4615 Mdot
.71668 .46744 Mdot
.35934 .67108 Mdot
.29609 .40573 Mdot
.29533 .5386 Mdot
.7085 .45575 Mdot
.72146 .48996 Mdot
.32667 .38745 Mdot
.69108 .43018 Mdot
.68929 .57565 Mdot
.3039 .54147 Mdot
.62862 .32259 Mdot
.28795 .50571 Mdot
.64016 .35731 Mdot
.64139 .66283 Mdot
.43253 .68867 Mdot
.39542 .32094 Mdot
.38861 .68064 Mdot
.40209 .31345 Mdot
.49521 .2945 Mdot
.47252 .29458 Mdot
.42079 .3145 Mdot
.48442 .70622 Mdot
.60671 .32195 Mdot
.52244 .28147 Mdot
.70178 .45136 Mdot
.36041 .3512 Mdot
.38646 .32668 Mdot
.71608 .45058 Mdot
.40665 .69918 Mdot
.44607 .70397 Mdot
.30802 .4045 Mdot
.31168 .42227 Mdot
.66192 .36205 Mdot
.43102 .71093 Mdot
.69438 .56554 Mdot
.30236 .4571 Mdot
.68837 .61855 Mdot
.68377 .37331 Mdot
.30415 .58961 Mdot
.68727 .42548 Mdot
.66809 .64256 Mdot
.37175 .32673 Mdot
.30001 .45068 Mdot
.68145 .6093 Mdot
.37258 .32278 Mdot
.54818 .29056 Mdot
.32681 .37577 Mdot
.49737 .71265 Mdot
.28483 .48697 Mdot
.37611 .67504 Mdot
.67667 .59415 Mdot
.32147 .61599 Mdot
.70013 .45655 Mdot
.51356 .27808 Mdot
.29902 .59847 Mdot
.40258 .31339 Mdot
.53433 .29736 Mdot
.66769 .35667 Mdot
.59542 .69533 Mdot
.36295 .34362 Mdot
.40061 .32434 Mdot
.44908 .71247 Mdot
.32984 .39182 Mdot
.6491 .35846 Mdot
.34229 .34397 Mdot
.65232 .642 Mdot
.57337 .71063 Mdot
.28996 .57414 Mdot
.30943 .60485 Mdot
.31138 .4273 Mdot
.50972 .69988 Mdot
.6941 .39813 Mdot
.30055 .39961 Mdot
.36787 .3489 Mdot
.72055 .47787 Mdot
.509 .28004 Mdot
.35677 .67327 Mdot
.36197 .33923 Mdot
.60457 .67255 Mdot
.57746 .69965 Mdot
.49124 .29093 Mdot
.35736 .34315 Mdot
.29087 .49859 Mdot
.44512 .28923 Mdot
.68897 .40648 Mdot
.69414 .59711 Mdot
.7005 .42463 Mdot
.40891 .70237 Mdot
.314 .39339 Mdot
.41084 .30983 Mdot
.31396 .60295 Mdot
.27964 .51508 Mdot
.40906 .31809 Mdot
.62965 .33624 Mdot
.59936 .69543 Mdot
.63015 .67248 Mdot
.50225 .70838 Mdot
.70066 .59955 Mdot
.42509 .706 Mdot
.5076 .29807 Mdot
.46501 .29821 Mdot
.69291 .59946 Mdot
.42885 .7052 Mdot
.3108 .38547 Mdot
.35063 .34702 Mdot
.47346 .28937 Mdot
.29044 .56554 Mdot
.30813 .38987 Mdot
.56086 .70223 Mdot
.27818 .48656 Mdot
.67391 .37023 Mdot
.50505 .2799 Mdot
.59598 .68924 Mdot
.41108 .31738 Mdot
.65278 .3417 Mdot
.67386 .61226 Mdot
.50612 .7061 Mdot
.35872 .66819 Mdot
.55715 .29624 Mdot
.53947 .28009 Mdot
.3308 .39256 Mdot
.47651 .69982 Mdot
.4258 .30521 Mdot
.29487 .48064 Mdot
.27997 .47672 Mdot
.60558 .32671 Mdot
.37624 .34129 Mdot
.49423 .27911 Mdot
.32252 .63011 Mdot
.34929 .63346 Mdot
.33594 .37141 Mdot
.34078 .37426 Mdot
.707 .52056 Mdot
.39434 .67179 Mdot
.3997 .70093 Mdot
.59742 .30203 Mdot
.57116 .30954 Mdot
.71685 .48045 Mdot
.60578 .67216 Mdot
.51414 .72131 Mdot
.51688 .2937 Mdot
.63533 .32598 Mdot
.62309 .6866 Mdot
.50163 .71755 Mdot
.63588 .6673 Mdot
.68303 .38553 Mdot
.58918 .30332 Mdot
.68722 .61597 Mdot
.71214 .51448 Mdot
.66188 .62166 Mdot
.6222 .32851 Mdot
.63385 .34374 Mdot
.67488 .60423 Mdot
.71006 .50995 Mdot
.68461 .41077 Mdot
.51193 .28259 Mdot
.54931 .29122 Mdot
.61625 .33497 Mdot
.71939 .45695 Mdot
.51221 .29372 Mdot
.70375 .44538 Mdot
.38721 .32985 Mdot
.65456 .62751 Mdot
.56111 .28513 Mdot
.71921 .53365 Mdot
.54854 .29251 Mdot
.67856 .62283 Mdot
.71699 .53836 Mdot
.42676 .68848 Mdot
.59281 .6978 Mdot
.39107 .67205 Mdot
.31386 .60116 Mdot
.3399 .6475 Mdot
.51816 .29308 Mdot
.47042 .7153 Mdot
.70557 .46056 Mdot
.50348 .72052 Mdot
.59007 .70206 Mdot
.61815 .66608 Mdot
.61248 .66643 Mdot
.6108 .33156 Mdot
.70488 .46786 Mdot
.27705 .49611 Mdot
.29226 .42599 Mdot
.64853 .64171 Mdot
.55362 .29405 Mdot
.62467 .32734 Mdot
.58745 .31626 Mdot
.32576 .36996 Mdot
.36533 .34245 Mdot
.29667 .56543 Mdot
.29492 .52326 Mdot
.33485 .3671 Mdot
.27619 .49045 Mdot
.66904 .63124 Mdot
.69442 .43995 Mdot
.70763 .4788 Mdot
.61351 .68338 Mdot
.64673 .66492 Mdot
.3851 .67836 Mdot
.30083 .4591 Mdot
.44116 .30372 Mdot
.68699 .60555 Mdot
.53965 .71997 Mdot
.29997 .53304 Mdot
.4508 .28096 Mdot
.35479 .65684 Mdot
.51736 .27966 Mdot
.34615 .63552 Mdot
.33442 .37853 Mdot
.49896 .70928 Mdot
.48679 .71779 Mdot
.45957 .29805 Mdot
.29979 .42649 Mdot
.35881 .33623 Mdot
.39139 .68529 Mdot
.61118 .68225 Mdot
.34266 .35309 Mdot
.56127 .28376 Mdot
.63658 .32849 Mdot
.31532 .61904 Mdot
.49153 .71372 Mdot
.61489 .67632 Mdot
.72065 .49537 Mdot
.31009 .57583 Mdot
.30683 .57556 Mdot
.56943 .29836 Mdot
.6709 .63478 Mdot
.35667 .32685 Mdot
.29832 .51685 Mdot
.61348 .33528 Mdot
.35723 .34855 Mdot
.31051 .57901 Mdot
.34654 .65659 Mdot
.4601 .71621 Mdot
.34022 .65634 Mdot
.61483 .3178 Mdot
.69892 .41551 Mdot
.69675 .54623 Mdot
.60741 .30403 Mdot
.33875 .62222 Mdot
.37796 .68436 Mdot
.3079 .43656 Mdot
.45141 .29266 Mdot
.66778 .64538 Mdot
.38284 .68468 Mdot
.60246 .32574 Mdot
.71431 .4496 Mdot
.71167 .49347 Mdot
.70107 .53466 Mdot
.70253 .44577 Mdot
.56674 .69443 Mdot
.308 .42176 Mdot
.62767 .33393 Mdot
.70454 .51393 Mdot
.64018 .67152 Mdot
.6661 .37478 Mdot
.56385 .3075 Mdot
.69015 .57889 Mdot
.60875 .32311 Mdot
.69968 .59016 Mdot
.57563 .31095 Mdot
.66209 .63262 Mdot
.33102 .3544 Mdot
.30685 .44051 Mdot
.51191 .28675 Mdot
.2838 .44919 Mdot
.33985 .35348 Mdot
.36308 .33544 Mdot
.58751 .30443 Mdot
.31566 .4032 Mdot
.70485 .47311 Mdot
.28626 .48728 Mdot
.59929 .67706 Mdot
.33417 .61998 Mdot
.30738 .43001 Mdot
.6219 .33821 Mdot
.56244 .29284 Mdot
.41717 .68805 Mdot
.59721 .70214 Mdot
.40354 .30627 Mdot
.3644 .6604 Mdot
.66881 .62186 Mdot
.34956 .63694 Mdot
.31506 .38254 Mdot
.54519 .69528 Mdot
.57926 .69922 Mdot
.37991 .31508 Mdot
.38992 .68098 Mdot
.63184 .34415 Mdot
.70456 .52707 Mdot
.4164 .313 Mdot
.37979 .67817 Mdot
.40468 .69805 Mdot
.50656 .70663 Mdot
.70063 .41899 Mdot
.38036 .3242 Mdot
.46638 .28671 Mdot
.28209 .54848 Mdot
.70131 .5898 Mdot
.64646 .65245 Mdot
.5603 .70772 Mdot
.66024 .62796 Mdot
.29054 .47094 Mdot
.51726 .28557 Mdot
.56624 .70629 Mdot
.29292 .4767 Mdot
.48538 .69977 Mdot
.64382 .33254 Mdot
.29611 .45239 Mdot
.32183 .63329 Mdot
.28991 .54044 Mdot
.47408 .7095 Mdot
.47946 .7217 Mdot
.60783 .67557 Mdot
.4904 .28904 Mdot
.32567 .6274 Mdot
.28816 .44247 Mdot
.65281 .35958 Mdot
.45814 .71517 Mdot
.71031 .52494 Mdot
.49218 .29031 Mdot
.34472 .35233 Mdot
.46636 .71831 Mdot
.37911 .66331 Mdot
.72283 .5135 Mdot
.58297 .70607 Mdot
.47756 .71087 Mdot
.55069 .3001 Mdot
.46551 .2852 Mdot
.6872 .37754 Mdot
.2903 .57686 Mdot
.66244 .36392 Mdot
.43404 .29693 Mdot
.47486 .7212 Mdot
.30567 .59796 Mdot
.68999 .39019 Mdot
.31043 .61042 Mdot
.4687 .27992 Mdot
.62272 .6671 Mdot
.69988 .41793 Mdot
.30893 .59808 Mdot
.71348 .54099 Mdot
.7148 .47346 Mdot
.6298 .65928 Mdot
.46145 .69923 Mdot
.64527 .35134 Mdot
.62861 .33362 Mdot
.70552 .44249 Mdot
.29991 .58115 Mdot
.52835 .71425 Mdot
.44876 .70221 Mdot
.44895 .69342 Mdot
.64469 .33584 Mdot
.48581 .70718 Mdot
.65144 .36572 Mdot
.64764 .63813 Mdot
.32188 .36339 Mdot
.50477 .71928 Mdot
.49918 .28583 Mdot
.44883 .69946 Mdot
.41688 .70721 Mdot
.69927 .58021 Mdot
.71276 .52853 Mdot
.5267 .2869 Mdot
.6227 .68361 Mdot
.29323 .48835 Mdot
.47032 .71642 Mdot
.34273 .63136 Mdot
.39159 .30975 Mdot
.63145 .66451 Mdot
.67832 .39928 Mdot
.62312 .33652 Mdot
.33878 .37091 Mdot
.55582 .29253 Mdot
.31419 .38815 Mdot
.69818 .52757 Mdot
.3 .59411 Mdot
.28274 .48216 Mdot
.61037 .6699 Mdot
.65181 .64953 Mdot
.29172 .51212 Mdot
.70108 .476 Mdot
.31699 .41024 Mdot
.65423 .66086 Mdot
.71698 .45167 Mdot
.39241 .67802 Mdot
.35125 .64167 Mdot
.418 .69106 Mdot
.69867 .43389 Mdot
.56831 .29623 Mdot
.55214 .29989 Mdot
.41141 .31864 Mdot
.43128 .71231 Mdot
.42613 .28818 Mdot
.46875 .28291 Mdot
.31676 .41623 Mdot
.5169 .27862 Mdot
.52503 .71704 Mdot
.33911 .64502 Mdot
.68271 .39533 Mdot
.31015 .58305 Mdot
.66485 .64667 Mdot
.37596 .34256 Mdot
.29756 .58305 Mdot
.38738 .66802 Mdot
.4882 .28083 Mdot
.34552 .36079 Mdot
.60116 .69311 Mdot
.62887 .33302 Mdot
.70951 .41929 Mdot
.28422 .53925 Mdot
.71147 .5325 Mdot
.7064 .54886 Mdot
.68325 .38135 Mdot
.33423 .63162 Mdot
.27935 .54135 Mdot
.69946 .56372 Mdot
.47312 .29676 Mdot
.31641 .58292 Mdot
.30093 .42709 Mdot
.30976 .39871 Mdot
.34009 .36009 Mdot
.6735 .63722 Mdot
.31137 .38008 Mdot
.68947 .58844 Mdot
.41446 .31345 Mdot
.40065 .30099 Mdot
.54984 .6996 Mdot
.35136 .3474 Mdot
.30056 .52267 Mdot
.57215 .6989 Mdot
.6911 .40431 Mdot
.33579 .35199 Mdot
.42391 .6863 Mdot
.2756 .48553 Mdot
.464 .30051 Mdot
.29902 .57849 Mdot
.7155 .55535 Mdot
.51978 .28256 Mdot
.60318 .30937 Mdot
.63349 .65598 Mdot
.37637 .67716 Mdot
.70471 .42298 Mdot
.32219 .59651 Mdot
.3977 .69776 Mdot
.65562 .62734 Mdot
.58942 .29594 Mdot
.3301 .645 Mdot
.35362 .6464 Mdot
.38446 .66431 Mdot
.33582 .36322 Mdot
.29232 .47564 Mdot
.29456 .53492 Mdot
.60312 .69215 Mdot
.28926 .45914 Mdot
.50102 .28425 Mdot
.5612 .7082 Mdot
.36483 .33321 Mdot
.33218 .64103 Mdot
.49449 .71625 Mdot
.71139 .51836 Mdot
.67934 .38059 Mdot
.31655 .62766 Mdot
.34273 .63359 Mdot
.69466 .40845 Mdot
.5448 .70852 Mdot
.33816 .61827 Mdot
.28267 .54777 Mdot
.57054 .69615 Mdot
.59314 .3142 Mdot
.57419 .29902 Mdot
.30404 .40793 Mdot
.55331 .30511 Mdot
.39591 .32798 Mdot
.34377 .63048 Mdot
.46499 .71691 Mdot
.29353 .55409 Mdot
.69234 .57497 Mdot
.6982 .57798 Mdot
.32617 .38411 Mdot
.63489 .34624 Mdot
.52473 .30045 Mdot
.70101 .57715 Mdot
.56511 .6992 Mdot
.47883 .71221 Mdot
.2969 .45282 Mdot
.64974 .35318 Mdot
.48542 .7133 Mdot
.3079 .60981 Mdot
.56195 .69788 Mdot
.36958 .6624 Mdot
.32617 .35961 Mdot
.29645 .50885 Mdot
.61737 .31114 Mdot
.30425 .58506 Mdot
.36311 .33709 Mdot
.5976 .67477 Mdot
.6634 .62261 Mdot
.44332 .70787 Mdot
.61728 .31922 Mdot
.655 .34502 Mdot
.36721 .33973 Mdot
.29034 .47709 Mdot
.70554 .54156 Mdot
.70477 .53143 Mdot
.57411 .69899 Mdot
.31494 .38341 Mdot
.28848 .42463 Mdot
.30812 .60464 Mdot
.28967 .56539 Mdot
.64072 .64644 Mdot
.34258 .36904 Mdot
.49585 .70886 Mdot
.71785 .45923 Mdot
.48018 .27789 Mdot
.69646 .4205 Mdot
.44843 .29042 Mdot
.49371 .2755 Mdot
.65986 .65419 Mdot
.5724 .68648 Mdot
.43903 .3058 Mdot
.4859 .29571 Mdot
.3205 .41078 Mdot
.63819 .64459 Mdot
.40748 .6958 Mdot
.61107 .67036 Mdot
.31147 .38943 Mdot
.54156 .71241 Mdot
.64137 .3547 Mdot
.2861 .53566 Mdot
.5009 .29438 Mdot
.45584 .71227 Mdot
.69253 .56137 Mdot
.29587 .44263 Mdot
.30072 .53066 Mdot
.31749 .60793 Mdot
.61759 .67408 Mdot
.49088 .70846 Mdot
.30469 .40655 Mdot
.71115 .55099 Mdot
.43165 .29743 Mdot
.31562 .42157 Mdot
.69694 .43258 Mdot
.45917 .70452 Mdot
.66549 .37719 Mdot
.48298 .27913 Mdot
.31919 .59545 Mdot
.40754 .68798 Mdot
.47627 .7181 Mdot
.68392 .58068 Mdot
.43275 .3086 Mdot
.70538 .53662 Mdot
.71407 .49733 Mdot
.29703 .54661 Mdot
.69564 .56425 Mdot
.59219 .70491 Mdot
.62974 .68364 Mdot
.30886 .56888 Mdot
.47157 .28145 Mdot
.65732 .65188 Mdot
.30465 .54734 Mdot
.7043 .5756 Mdot
.52231 .27799 Mdot
.70592 .53704 Mdot
.5235 .29228 Mdot
.31518 .42106 Mdot
.45872 .30112 Mdot
.35195 .63636 Mdot
.3136 .4189 Mdot
.70563 .41343 Mdot
.60684 .32167 Mdot
.58047 .31206 Mdot
.35487 .64744 Mdot
.5106 .28866 Mdot
.33733 .36917 Mdot
.4742 .29927 Mdot
.62025 .31017 Mdot
.60208 .67362 Mdot
.65918 .65415 Mdot
.54227 .30439 Mdot
.2956 .42331 Mdot
.61594 .33456 Mdot
.46216 .29301 Mdot
.71784 .54569 Mdot
.38299 .66654 Mdot
.4671 .7084 Mdot
.48576 .28068 Mdot
.29978 .44147 Mdot
.6779 .37043 Mdot
.34909 .64196 Mdot
.53825 .2798 Mdot
.32947 .38256 Mdot
.53814 .70161 Mdot
.49832 .29497 Mdot
.28024 .50135 Mdot
.45576 .29731 Mdot
.62539 .67615 Mdot
.29362 .5804 Mdot
.31166 .61645 Mdot
.66871 .37017 Mdot
.29922 .48477 Mdot
.29531 .47967 Mdot
.48051 .29808 Mdot
.69582 .39197 Mdot
.27824 .47983 Mdot
.60403 .69227 Mdot
.70197 .51962 Mdot
.29714 .55856 Mdot
.63886 .34021 Mdot
.71378 .51939 Mdot
.29446 .56394 Mdot
.64814 .637 Mdot
.69885 .42119 Mdot
.32366 .36667 Mdot
.55854 .70276 Mdot
.40945 .29684 Mdot
.42249 .30122 Mdot
.29677 .48439 Mdot
.40495 .31225 Mdot
.7039 .57622 Mdot
.58439 .29278 Mdot
.69581 .55361 Mdot
.36756 .66102 Mdot
.67859 .40723 Mdot
.30784 .60627 Mdot
.41181 .68526 Mdot
.54634 .70334 Mdot
.36503 .34207 Mdot
.2822 .4676 Mdot
.64397 .64442 Mdot
.62124 .32884 Mdot
.69208 .58792 Mdot
.70547 .54802 Mdot
.70549 .53358 Mdot
.41032 .31842 Mdot
.66588 .62378 Mdot
.49036 .70771 Mdot
.53945 .3021 Mdot
.71622 .55995 Mdot
.63548 .67212 Mdot
.29735 .47499 Mdot
.71365 .52511 Mdot
.39604 .30675 Mdot
.69402 .43737 Mdot
.36208 .34373 Mdot
.69631 .39923 Mdot
.69875 .4462 Mdot
.594 .3081 Mdot
.43182 .2877 Mdot
.70484 .5542 Mdot
.37723 .31312 Mdot
.67404 .36898 Mdot
.64202 .66725 Mdot
.64662 .36 Mdot
.27998 .547 Mdot
.70156 .40262 Mdot
.60622 .31128 Mdot
.70313 .50491 Mdot
.64769 .3498 Mdot
.58967 .69486 Mdot
.59878 .68834 Mdot
.62896 .65626 Mdot
.28696 .47902 Mdot
.50937 .70955 Mdot
.34209 .65269 Mdot
.36386 .65597 Mdot
.68634 .38365 Mdot
.3085 .58167 Mdot
.67826 .59738 Mdot
.31343 .58495 Mdot
.55947 .70919 Mdot
.49914 .7155 Mdot
.70048 .5419 Mdot
.66366 .63616 Mdot
.28552 .47677 Mdot
.63677 .3498 Mdot
.64146 .6699 Mdot
.27895 .49536 Mdot
.52734 .69954 Mdot
.69405 .58762 Mdot
.63265 .6796 Mdot
.363 .34361 Mdot
.69267 .42766 Mdot
.33704 .64391 Mdot
.66973 .39235 Mdot
.46874 .70211 Mdot
.3356 .63107 Mdot
.33213 .61123 Mdot
.49545 .71413 Mdot
.6687 .38305 Mdot
.71014 .53335 Mdot
.61185 .31362 Mdot
.65291 .34957 Mdot
.56407 .69941 Mdot
.69072 .41527 Mdot
.58701 .30116 Mdot
.70546 .53045 Mdot
.29456 .44557 Mdot
.34827 .33732 Mdot
.64028 .65782 Mdot
.35073 .64526 Mdot
.52474 .70438 Mdot
.36803 .67666 Mdot
.33145 .63107 Mdot
.29636 .53119 Mdot
.56999 .69169 Mdot
.28551 .44154 Mdot
.34669 .64646 Mdot
.28691 .47454 Mdot
.6172 .30852 Mdot
.66591 .35989 Mdot
.43799 .29586 Mdot
.29165 .48528 Mdot
.29568 .53601 Mdot
.61533 .67951 Mdot
.69355 .60238 Mdot
.41562 .3106 Mdot
.65953 .35603 Mdot
.63291 .66263 Mdot
.29722 .49425 Mdot
.34124 .34708 Mdot
.39879 .32361 Mdot
.47913 .2978 Mdot
.70955 .45182 Mdot
.53784 .71611 Mdot
.29273 .51069 Mdot
.68996 .5798 Mdot
.31659 .60946 Mdot
.33693 .65312 Mdot
.28059 .45641 Mdot
.51468 .71315 Mdot
.71774 .53688 Mdot
.33816 .3536 Mdot
.36179 .66791 Mdot
.6598 .35623 Mdot
.33958 .62351 Mdot
.38298 .31305 Mdot
.68092 .375 Mdot
.32464 .37645 Mdot
.29414 .51372 Mdot
.54352 .71139 Mdot
.7005 .4461 Mdot
.70035 .47294 Mdot
.69246 .41164 Mdot
.36521 .65965 Mdot
.30269 .40427 Mdot
.28306 .52991 Mdot
.59684 .69403 Mdot
.59157 .29619 Mdot
.46867 .71972 Mdot
.53976 .7051 Mdot
.54457 .28903 Mdot
.71808 .50252 Mdot
.59436 .31462 Mdot
.71363 .53137 Mdot
.67347 .36269 Mdot
.39087 .32413 Mdot
.41225 .68187 Mdot
.58654 .69462 Mdot
.62852 .66617 Mdot
.3569 .65987 Mdot
.64849 .34711 Mdot
.62431 .66381 Mdot
.68821 .61869 Mdot
.63043 .66782 Mdot
.48034 .71359 Mdot
.65999 .65337 Mdot
.34942 .658 Mdot
.29209 .55334 Mdot
.7059 .56637 Mdot
.46643 .69884 Mdot
.67015 .38343 Mdot
.67937 .38682 Mdot
.7138 .54319 Mdot
.51779 .29431 Mdot
.70622 .4216 Mdot
.33938 .35127 Mdot
.4094 .31485 Mdot
.27775 .50384 Mdot
.42614 .69965 Mdot
.70199 .54812 Mdot
.49058 .72134 Mdot
.51371 .29447 Mdot
.37088 .67228 Mdot
.62887 .32306 Mdot
.4046 .70065 Mdot
.68186 .6098 Mdot
.35442 .63939 Mdot
.28599 .54423 Mdot
.43305 .28999 Mdot
.71741 .45897 Mdot
.33641 .62774 Mdot
.69501 .41282 Mdot
.63682 .66064 Mdot
.59716 .68349 Mdot
.54863 .28471 Mdot
.4062 .69205 Mdot
.28192 .54915 Mdot
.51786 .7005 Mdot
.69017 .61452 Mdot
.52383 .29361 Mdot
.34848 .63294 Mdot
.56281 .29803 Mdot
.71866 .48748 Mdot
.64729 .3327 Mdot
.6256 .33419 Mdot
.42378 .29867 Mdot
.69331 .58775 Mdot
.36195 .64684 Mdot
.32955 .37101 Mdot
.63315 .64957 Mdot
.28446 .47711 Mdot
.35522 .66229 Mdot
.64587 .6582 Mdot
.31251 .41471 Mdot
.64038 .6709 Mdot
.43951 .3009 Mdot
.4504 .70731 Mdot
.71732 .51457 Mdot
.53819 .6972 Mdot
.36273 .33287 Mdot
.34218 .35828 Mdot
.28414 .49141 Mdot
.67859 .62909 Mdot
.64206 .67259 Mdot
.70108 .45923 Mdot
.3046 .40435 Mdot
.59792 .31536 Mdot
.64281 .34676 Mdot
.28617 .44476 Mdot
.63678 .33197 Mdot
.40549 .69864 Mdot
.5398 .6964 Mdot
.44104 .30067 Mdot
.4503 .29662 Mdot
.33177 .37016 Mdot
.31007 .4085 Mdot
.36431 .34323 Mdot
.71826 .49864 Mdot
.58071 .29176 Mdot
.6433 .65185 Mdot
.47637 .70111 Mdot
.47161 .71527 Mdot
.6965 .43332 Mdot
.70498 .57045 Mdot
.50889 .72446 Mdot
.38796 .67451 Mdot
.36385 .33734 Mdot
.52692 .28008 Mdot
.70476 .50339 Mdot
.52596 .29837 Mdot
.57141 .6937 Mdot
.3609 .3302 Mdot
.68183 .4076 Mdot
.36157 .64761 Mdot
.71919 .46844 Mdot
.41368 .69212 Mdot
.4771 .27937 Mdot
.701 .46993 Mdot
.67384 .61727 Mdot
.55518 .69917 Mdot
.67174 .61177 Mdot
.31254 .57888 Mdot
.67915 .36643 Mdot
.55934 .29973 Mdot
.71632 .46276 Mdot
.31544 .59266 Mdot
.72296 .49387 Mdot
.67131 .63945 Mdot
.48473 .70065 Mdot
.64661 .66087 Mdot
.60713 .68818 Mdot
.68822 .40467 Mdot
.68807 .59704 Mdot
.29291 .51463 Mdot
.59345 .69159 Mdot
.42149 .2905 Mdot
.56113 .70995 Mdot
.47687 .71598 Mdot
.55583 .71344 Mdot
.62065 .68554 Mdot
.70743 .42854 Mdot
.70098 .53295 Mdot
.53747 .30064 Mdot
.67572 .62848 Mdot
.43806 .29284 Mdot
.33958 .36437 Mdot
.29965 .46699 Mdot
.68441 .39676 Mdot
.40957 .68885 Mdot
.3732 .32128 Mdot
.66316 .6381 Mdot
.27737 .50903 Mdot
.61215 .68853 Mdot
.28535 .5442 Mdot
.33757 .64316 Mdot
.36468 .64927 Mdot
.41616 .3181 Mdot
.50747 .28372 Mdot
.62459 .68403 Mdot
.6063 .32464 Mdot
.60743 .31625 Mdot
.58384 .69355 Mdot
.46135 .27927 Mdot
.42329 .30117 Mdot
.30865 .42725 Mdot
.536 .71598 Mdot
.59941 .68861 Mdot
.63493 .32943 Mdot
.28739 .51132 Mdot
.66192 .61923 Mdot
.38876 .68477 Mdot
.48018 .72012 Mdot
.2972 .49739 Mdot
.68451 .60045 Mdot
.53772 .29979 Mdot
.33081 .64368 Mdot
.53947 .72051 Mdot
.60418 .67424 Mdot
.7009 .5639 Mdot
.42531 .69683 Mdot
.29147 .42123 Mdot
.55628 .70175 Mdot
.53726 .70386 Mdot
.69962 .42445 Mdot
.46066 .2994 Mdot
.63262 .34584 Mdot
.68638 .42558 Mdot
.29613 .53214 Mdot
.45939 .30246 Mdot
.42409 .68868 Mdot
.39449 .3117 Mdot
.71781 .50432 Mdot
.66684 .64022 Mdot
.55997 .30041 Mdot
.66236 .3657 Mdot
.63377 .32538 Mdot
.59843 .68129 Mdot
.71627 .48771 Mdot
.52411 .70418 Mdot
.2908 .4791 Mdot
.29681 .48264 Mdot
.55775 .69864 Mdot
.61961 .32366 Mdot
.56381 .70428 Mdot
.47738 .28103 Mdot
.32969 .61518 Mdot
.6162 .32576 Mdot
.30022 .43325 Mdot
.40525 .3203 Mdot
.29655 .41893 Mdot
.29232 .58 Mdot
.70066 .55762 Mdot
.69658 .40433 Mdot
.60769 .32921 Mdot
.67819 .60247 Mdot
.36196 .33792 Mdot
.37692 .67066 Mdot
.52292 .70602 Mdot
.29916 .49264 Mdot
.40694 .29882 Mdot
.61107 .30684 Mdot
.64712 .63936 Mdot
.34444 .62612 Mdot
.69428 .60082 Mdot
.29873 .54677 Mdot
.51817 .71621 Mdot
.35289 .6371 Mdot
.3341 .38116 Mdot
.71156 .54196 Mdot
.3517 .6649 Mdot
.28801 .46598 Mdot
.42113 .31608 Mdot
.42305 .29723 Mdot
.29574 .41186 Mdot
.43216 .70572 Mdot
.29693 .51451 Mdot
.6092 .32064 Mdot
.49735 .7116 Mdot
.29888 .55646 Mdot
.38126 .32978 Mdot
.3054 .59873 Mdot
.4521 .70524 Mdot
.66461 .38033 Mdot
.33034 .37516 Mdot
.55561 .70419 Mdot
.70771 .54797 Mdot
.68349 .37861 Mdot
.29966 .4384 Mdot
.69007 .58936 Mdot
.43714 .71394 Mdot
.34788 .36841 Mdot
.36522 .33193 Mdot
.57869 .69245 Mdot
.3736 .66099 Mdot
.45132 .69853 Mdot
.50684 .28107 Mdot
.69045 .60563 Mdot
.45996 .29807 Mdot
.60286 .6976 Mdot
.60493 .69481 Mdot
.66918 .62898 Mdot
.65876 .34299 Mdot
.2888 .51306 Mdot
.52156 .70673 Mdot
.43469 .69293 Mdot
.64592 .35864 Mdot
.72345 .51924 Mdot
.65012 .64559 Mdot
.68851 .41571 Mdot
.33281 .6156 Mdot
.5124 .29164 Mdot
.52291 .70572 Mdot
.37669 .31661 Mdot
.37057 .66373 Mdot
.60588 .68064 Mdot
.6438 .64024 Mdot
.63474 .34457 Mdot
.50633 .72261 Mdot
.62133 .333 Mdot
.65298 .64903 Mdot
.69497 .38785 Mdot
.45956 .29362 Mdot
.61874 .68067 Mdot
.29738 .51677 Mdot
.2798 .49769 Mdot
.64994 .66046 Mdot
.39149 .68075 Mdot
.71851 .51015 Mdot
.29796 .53542 Mdot
.51653 .27957 Mdot
.33923 .34444 Mdot
.36674 .34097 Mdot
.43818 .28493 Mdot
.69455 .39271 Mdot
.30178 .43834 Mdot
.30028 .58952 Mdot
.70344 .56095 Mdot
.4273 .71214 Mdot
.45022 .30469 Mdot
.44247 .69729 Mdot
.51681 .72079 Mdot
.2951 .45656 Mdot
.33342 .35216 Mdot
.65901 .37547 Mdot
.68913 .38009 Mdot
.70216 .46728 Mdot
.35993 .6649 Mdot
.29621 .44558 Mdot
.41812 .68682 Mdot
.51464 .71117 Mdot
.34041 .37547 Mdot
.69347 .42873 Mdot
.3613 .65231 Mdot
.31237 .61813 Mdot
.50266 .29174 Mdot
.2814 .47751 Mdot
.61434 .32465 Mdot
.29243 .44412 Mdot
.28376 .52747 Mdot
.70403 .50041 Mdot
.60992 .68362 Mdot
.51547 .2832 Mdot
.30265 .42374 Mdot
.58692 .30755 Mdot
.57432 .69167 Mdot
.32118 .61836 Mdot
.29378 .583 Mdot
.66982 .36063 Mdot
.32548 .37795 Mdot
.38094 .66655 Mdot
.66295 .64779 Mdot
.38361 .66351 Mdot
.6971 .44016 Mdot
.32209 .39156 Mdot
.32714 .63513 Mdot
.5273 .2795 Mdot
.56188 .70468 Mdot
.36493 .65783 Mdot
.51926 .28433 Mdot
.29023 .53724 Mdot
.60137 .67654 Mdot
.64891 .64568 Mdot
.69846 .56421 Mdot
.53222 .2949 Mdot
.66634 .61567 Mdot
.58559 .70729 Mdot
.43854 .30108 Mdot
.3241 .59949 Mdot
.28064 .50133 Mdot
.70619 .57484 Mdot
.48074 .29808 Mdot
.32137 .39679 Mdot
.29579 .4073 Mdot
.28398 .55528 Mdot
.28571 .47563 Mdot
.41488 .30217 Mdot
.31244 .60111 Mdot
.28393 .50319 Mdot
.46035 .299 Mdot
.68782 .6026 Mdot
.53949 .70677 Mdot
.71714 .53321 Mdot
.29323 .51941 Mdot
.30124 .57758 Mdot
.6809 .3965 Mdot
.71379 .47387 Mdot
.32444 .6288 Mdot
.44382 .69196 Mdot
.70271 .47174 Mdot
.56163 .30038 Mdot
.48736 .72444 Mdot
.45621 .2845 Mdot
.70789 .55196 Mdot
.43091 .31206 Mdot
.30512 .43139 Mdot
.49579 .71184 Mdot
.35408 .33111 Mdot
.46876 .71929 Mdot
.51634 .7048 Mdot
.71922 .46839 Mdot
.48818 .70043 Mdot
.59106 .69208 Mdot
.70099 .50053 Mdot
.28869 .55221 Mdot
.70552 .4492 Mdot
.52388 .28389 Mdot
.32853 .61254 Mdot
.29529 .48149 Mdot
.52718 .29489 Mdot
.51072 .70878 Mdot
.30303 .45773 Mdot
.48049 .71167 Mdot
.46952 .69835 Mdot
.6936 .61464 Mdot
.46646 .72217 Mdot
.35214 .35466 Mdot
.4186 .69681 Mdot
.6329 .33112 Mdot
.67183 .38299 Mdot
.38587 .67551 Mdot
.63396 .64982 Mdot
.66211 .61766 Mdot
.31856 .36775 Mdot
.60863 .31709 Mdot
.39716 .69882 Mdot
.50028 .28726 Mdot
.71224 .57211 Mdot
.6438 .64668 Mdot
.48636 .28927 Mdot
.47237 .71373 Mdot
.60333 .32493 Mdot
.68581 .4107 Mdot
.43866 .30721 Mdot
.59778 .31886 Mdot
.66352 .61995 Mdot
.71793 .49107 Mdot
.5316 .29851 Mdot
.50868 .70518 Mdot
.46496 .29822 Mdot
.66715 .65055 Mdot
.71737 .47659 Mdot
.61906 .32769 Mdot
.62868 .67266 Mdot
.6766 .39931 Mdot
.29865 .56951 Mdot
.68874 .61772 Mdot
.38036 .67285 Mdot
.6688 .61515 Mdot
.31427 .4103 Mdot
.63392 .32048 Mdot
.61736 .33625 Mdot
.47936 .27694 Mdot
.63846 .34501 Mdot
.66454 .36228 Mdot
.45653 .28689 Mdot
.70792 .46244 Mdot
.47324 .70273 Mdot
.65844 .35638 Mdot
.69507 .39987 Mdot
.54894 .29628 Mdot
.37166 .67 Mdot
.6935 .417 Mdot
.28851 .49475 Mdot
.56512 .70126 Mdot
.36809 .34476 Mdot
.41686 .7058 Mdot
.68504 .39816 Mdot
.38762 .6782 Mdot
.37748 .33349 Mdot
.28631 .55954 Mdot
.46613 .29026 Mdot
.39682 .31444 Mdot
.34472 .66207 Mdot
.47939 .29929 Mdot
.64343 .34267 Mdot
.28952 .455 Mdot
.52655 .70749 Mdot
.53764 .71501 Mdot
.41816 .7074 Mdot
.65387 .36064 Mdot
.38503 .31686 Mdot
.31153 .59436 Mdot
.68765 .42056 Mdot
.50968 .27675 Mdot
.31231 .41925 Mdot
.71934 .53217 Mdot
.42928 .29545 Mdot
.29398 .51342 Mdot
.29712 .54231 Mdot
.47697 .71193 Mdot
.61495 .67489 Mdot
.34634 .63657 Mdot
.282 .50455 Mdot
.71228 .44298 Mdot
.30098 .4206 Mdot
.56662 .71109 Mdot
.70987 .4944 Mdot
.59799 .70217 Mdot
.43413 .70835 Mdot
.41779 .29787 Mdot
.60347 .3158 Mdot
.31954 .59732 Mdot
.40717 .32061 Mdot
.71844 .55162 Mdot
.59214 .68752 Mdot
.68014 .59711 Mdot
.33697 .35278 Mdot
.64945 .3549 Mdot
.34815 .35534 Mdot
.43451 .30191 Mdot
.40499 .69421 Mdot
.71495 .51442 Mdot
.29539 .51164 Mdot
.32191 .38796 Mdot
.58289 .31475 Mdot
.3004 .43174 Mdot
.36002 .33156 Mdot
.2965 .53387 Mdot
.72206 .53196 Mdot
.31668 .37304 Mdot
.3251 .62439 Mdot
.67119 .371 Mdot
.69632 .60665 Mdot
.66941 .35357 Mdot
.31425 .38498 Mdot
.43762 .70421 Mdot
.52873 .2864 Mdot
.49331 .29753 Mdot
.64997 .66302 Mdot
.4709 .71936 Mdot
.67217 .6404 Mdot
.39811 .30131 Mdot
.44495 .29989 Mdot
.53574 .29415 Mdot
.35501 .3493 Mdot
.66249 .36695 Mdot
.70892 .5534 Mdot
.31573 .37711 Mdot
.47673 .69876 Mdot
.62741 .32199 Mdot
.6328 .65433 Mdot
.3035 .39536 Mdot
.70324 .53618 Mdot
.68419 .37192 Mdot
.4037 .70212 Mdot
.65143 .65321 Mdot
.42433 .299 Mdot
.51916 .70451 Mdot
.37155 .31633 Mdot
.36837 .33777 Mdot
.3326 .64886 Mdot
.55693 .29267 Mdot
.50359 .72039 Mdot
.54773 .71207 Mdot
.54093 .71003 Mdot
.41786 .70197 Mdot
.67289 .37205 Mdot
.57983 .68623 Mdot
.55479 .69268 Mdot
.71151 .43188 Mdot
.30988 .43419 Mdot
.42286 .69886 Mdot
.59882 .67637 Mdot
.27787 .47725 Mdot
.68199 .40189 Mdot
.43455 .69524 Mdot
.43523 .29208 Mdot
.71247 .48664 Mdot
.56666 .30859 Mdot
.57056 .30191 Mdot
.33439 .38371 Mdot
.62958 .33087 Mdot
.6934 .55539 Mdot
.28422 .43708 Mdot
.65907 .34228 Mdot
.69816 .53639 Mdot
.70838 .43856 Mdot
.46882 .28166 Mdot
.49657 .72445 Mdot
.48361 .29299 Mdot
.28945 .56974 Mdot
.70295 .40908 Mdot
.63083 .32383 Mdot
.68411 .59959 Mdot
.57685 .29572 Mdot
.29514 .45588 Mdot
.69931 .40863 Mdot
.29202 .49365 Mdot
.69994 .47119 Mdot
.53645 .29062 Mdot
.46806 .30001 Mdot
.69843 .55096 Mdot
.46692 .70306 Mdot
.6623 .62926 Mdot
.31231 .59706 Mdot
.71969 .53924 Mdot
.33806 .354 Mdot
.28652 .50756 Mdot
.41136 .29452 Mdot
.70508 .48646 Mdot
.44209 .28591 Mdot
.55145 .71184 Mdot
.71803 .47685 Mdot
.60024 .68809 Mdot
.44361 .29406 Mdot
.68872 .58171 Mdot
.45784 .69778 Mdot
.70193 .54768 Mdot
.39539 .31885 Mdot
.28889 .4422 Mdot
.70897 .47556 Mdot
.29838 .43023 Mdot
.46855 .71129 Mdot
.38083 .68534 Mdot
.44498 .71235 Mdot
.60111 .68087 Mdot
.32145 .39758 Mdot
.66016 .62237 Mdot
.43773 .69386 Mdot
.69998 .58945 Mdot
.35264 .33741 Mdot
.30215 .46943 Mdot
.37856 .32985 Mdot
.70843 .4621 Mdot
.34139 .65307 Mdot
.35222 .34178 Mdot
.67145 .60503 Mdot
.29678 .55006 Mdot
.27986 .49365 Mdot
.36989 .66194 Mdot
.56027 .70806 Mdot
.44585 .70668 Mdot
.30036 .40249 Mdot
.52193 .28767 Mdot
.6874 .39846 Mdot
.55625 .30639 Mdot
.29024 .4417 Mdot
.60744 .68057 Mdot
.29171 .55957 Mdot
.44157 .30787 Mdot
.71104 .43301 Mdot
.37708 .68015 Mdot
.4948 .29526 Mdot
.69255 .56866 Mdot
.59583 .68419 Mdot
.44874 .70979 Mdot
.49631 .71945 Mdot
.28585 .50925 Mdot
.44925 .30471 Mdot
.40323 .67986 Mdot
.49489 .71007 Mdot
.35665 .35567 Mdot
.43041 .70207 Mdot
.46027 .70654 Mdot
.30426 .42698 Mdot
.53128 .70351 Mdot
.35054 .63483 Mdot
.69862 .41786 Mdot
.64109 .6512 Mdot
.31151 .56859 Mdot
.31973 .59768 Mdot
.66521 .64731 Mdot
.60943 .69074 Mdot
.28247 .5132 Mdot
.63568 .34475 Mdot
.55149 .70112 Mdot
.42146 .70793 Mdot
.70073 .48024 Mdot
.69645 .39881 Mdot
.70268 .56137 Mdot
.55819 .29389 Mdot
.33099 .37337 Mdot
.35415 .64989 Mdot
.28594 .51828 Mdot
.55884 .706 Mdot
.72184 .49454 Mdot
.38697 .67467 Mdot
.54803 .29114 Mdot
.70602 .54459 Mdot
.56771 .29847 Mdot
.66584 .63653 Mdot
.50604 .29925 Mdot
.41936 .68372 Mdot
.62348 .67558 Mdot
.70277 .42411 Mdot
.38679 .30577 Mdot
.48386 .29838 Mdot
.40217 .32223 Mdot
.32605 .6334 Mdot
.6593 .35769 Mdot
.36518 .65895 Mdot
.67468 .59944 Mdot
.4968 .71859 Mdot
.40625 .67685 Mdot
.70086 .41532 Mdot
.59542 .68764 Mdot
.7013 .49177 Mdot
.28965 .48794 Mdot
.49125 .72403 Mdot
.61044 .324 Mdot
.631 .34233 Mdot
.71057 .43916 Mdot
.27846 .50225 Mdot
.65219 .34367 Mdot
.50503 .70288 Mdot
.29075 .4388 Mdot
.42326 .69544 Mdot
.3578 .65112 Mdot
.41593 .6908 Mdot
.64251 .33002 Mdot
.69468 .57685 Mdot
.71202 .5293 Mdot
.56374 .69411 Mdot
.70087 .58937 Mdot
.43719 .30197 Mdot
.56979 .68921 Mdot
.30329 .55706 Mdot
.37574 .33238 Mdot
.63418 .67415 Mdot
.46441 .69798 Mdot
.6012 .31444 Mdot
.32266 .60151 Mdot
.52485 .29947 Mdot
.32955 .63153 Mdot
.29852 .40501 Mdot
.39529 .69399 Mdot
.64619 .34235 Mdot
.64466 .66412 Mdot
.31981 .6082 Mdot
.29063 .51774 Mdot
.47514 .71389 Mdot
.5542 .70182 Mdot
.31085 .57633 Mdot
.55211 .30211 Mdot
.40198 .32348 Mdot
.33016 .63074 Mdot
.66576 .61918 Mdot
.69988 .58921 Mdot
.52656 .71251 Mdot
.68201 .41684 Mdot
.58252 .31345 Mdot
.29761 .57251 Mdot
.29593 .43671 Mdot
.5168 .70532 Mdot
.66247 .63255 Mdot
.3101 .567 Mdot
.30702 .57699 Mdot
.70148 .56608 Mdot
.39049 .67166 Mdot
.71701 .4776 Mdot
.6651 .63686 Mdot
.70659 .56977 Mdot
.4427 .70252 Mdot
.3408 .37394 Mdot
.49445 .27826 Mdot
.34841 .66227 Mdot
.36183 .33905 Mdot
.69572 .39804 Mdot
.56617 .69334 Mdot
.64579 .35074 Mdot
.62516 .34306 Mdot
.6656 .36212 Mdot
.496 .28876 Mdot
.61641 .31046 Mdot
.30784 .55832 Mdot
.52603 .71781 Mdot
.44566 .30337 Mdot
.64329 .33004 Mdot
.69625 .59233 Mdot
.68647 .42333 Mdot
.64788 .34734 Mdot
.70016 .5863 Mdot
.71082 .52036 Mdot
.5916 .68059 Mdot
.47695 .6992 Mdot
.39271 .67475 Mdot
.58955 .2939 Mdot
.6652 .63077 Mdot
.67169 .63869 Mdot
.50659 .71329 Mdot
.698 .5484 Mdot
.42556 .69826 Mdot
.60929 .68665 Mdot
.51048 .71856 Mdot
.61981 .66571 Mdot
.69739 .5885 Mdot
.65045 .36229 Mdot
.4728 .29049 Mdot
.68652 .58323 Mdot
.35631 .36007 Mdot
.70154 .44643 Mdot
.34735 .64736 Mdot
.6797 .40194 Mdot
.68098 .58605 Mdot
.50644 .28667 Mdot
.59754 .31789 Mdot
.33446 .37253 Mdot
.5151 .28526 Mdot
.46464 .2981 Mdot
.69997 .54039 Mdot
.38781 .33355 Mdot
.32903 .61026 Mdot
.42895 .29476 Mdot
.71217 .5419 Mdot
.53517 .29046 Mdot
.70922 .44683 Mdot
.72198 .5304 Mdot
.6412 .65446 Mdot
.31333 .60691 Mdot
.34912 .65874 Mdot
.42859 .30237 Mdot
.38567 .68208 Mdot
.70309 .55106 Mdot
.69165 .41041 Mdot
.38103 .68175 Mdot
.67771 .36981 Mdot
.31249 .41776 Mdot
.68958 .42352 Mdot
.30215 .4437 Mdot
.57697 .29374 Mdot
.65061 .65425 Mdot
.31495 .57886 Mdot
.31297 .58503 Mdot
.67341 .62049 Mdot
.32716 .63779 Mdot
.61281 .69421 Mdot
.69358 .56376 Mdot
.47837 .70316 Mdot
.27696 .52128 Mdot
.39427 .69847 Mdot
.70339 .42056 Mdot
.29706 .47299 Mdot
.57916 .31333 Mdot
.67511 .60382 Mdot
.33628 .65039 Mdot
.71685 .48434 Mdot
.70078 .48593 Mdot
.59555 .30426 Mdot
.70592 .41581 Mdot
.2993 .42717 Mdot
.28611 .56453 Mdot
.5301 .7115 Mdot
.29559 .48374 Mdot
.44354 .29887 Mdot
.43603 .30808 Mdot
.35144 .35825 Mdot
.41618 .68707 Mdot
.35695 .3423 Mdot
.40391 .67962 Mdot
.58162 .29559 Mdot
.34112 .63151 Mdot
.49343 .70649 Mdot
.69156 .41936 Mdot
.7147 .53756 Mdot
.31993 .59325 Mdot
.40966 .68853 Mdot
.46883 .30196 Mdot
.43687 .3063 Mdot
.31525 .62035 Mdot
.69691 .58833 Mdot
.69001 .60435 Mdot
.49078 .72052 Mdot
.42246 .30427 Mdot
.71411 .50213 Mdot
.50431 .29735 Mdot
.71822 .46406 Mdot
.39235 .69748 Mdot
.37848 .32616 Mdot
.32204 .36325 Mdot
.69937 .43941 Mdot
.56767 .69238 Mdot
.66403 .35709 Mdot
.65805 .64154 Mdot
.34741 .33897 Mdot
.31963 .59011 Mdot
.35563 .35065 Mdot
.39569 .30185 Mdot
.37964 .32602 Mdot
.3759 .6865 Mdot
.72445 .5011 Mdot
.48473 .27593 Mdot
.70643 .56383 Mdot
.28736 .4411 Mdot
.61763 .69006 Mdot
.31319 .59258 Mdot
.30251 .45909 Mdot
.70686 .50065 Mdot
.68095 .37671 Mdot
.40256 .68369 Mdot
.49852 .7074 Mdot
.70788 .47927 Mdot
.49953 .70795 Mdot
.50657 .70922 Mdot
.5636 .70734 Mdot
.43653 .29597 Mdot
.71121 .55541 Mdot
.46761 .70261 Mdot
.28362 .48868 Mdot
.46544 .72063 Mdot
.32275 .36515 Mdot
.7036 .42972 Mdot
.37086 .67228 Mdot
.7009 .45234 Mdot
.6662 .624 Mdot
.45552 .28234 Mdot
.67384 .37268 Mdot
.70744 .52082 Mdot
.64003 .32758 Mdot
.48811 .29705 Mdot
.37899 .66603 Mdot
.2997 .54351 Mdot
.49573 .29231 Mdot
.28692 .47464 Mdot
.32874 .63395 Mdot
.30462 .42837 Mdot
.44477 .70268 Mdot
.61079 .32049 Mdot
.32824 .63681 Mdot
.5886 .31795 Mdot
.28271 .4523 Mdot
.69548 .60972 Mdot
.58725 .69871 Mdot
.33599 .35458 Mdot
.30669 .58019 Mdot
.66807 .6167 Mdot
.70897 .55796 Mdot
.28568 .44402 Mdot
.50094 .29321 Mdot
.43828 .29868 Mdot
.36704 .66538 Mdot
.6522 .35808 Mdot
.59554 .30769 Mdot
.56351 .30095 Mdot
.35721 .32908 Mdot
.58688 .69638 Mdot
.56364 .70372 Mdot
.67942 .60936 Mdot
.62019 .68614 Mdot
.29542 .43853 Mdot
.32009 .61733 Mdot
.61286 .33121 Mdot
.69257 .5629 Mdot
.7141 .44965 Mdot
.53083 .71061 Mdot
.60846 .681 Mdot
.31666 .38744 Mdot
.71959 .47277 Mdot
.34802 .63261 Mdot
.6654 .36876 Mdot
.52945 .703 Mdot
.37285 .68263 Mdot
.59052 .3046 Mdot
.28055 .49587 Mdot
.52506 .28872 Mdot
.28242 .44449 Mdot
.28285 .44143 Mdot
.34836 .65035 Mdot
.70118 .44059 Mdot
.32806 .63283 Mdot
.31089 .41321 Mdot
.29389 .49732 Mdot
.38974 .67038 Mdot
.61695 .67273 Mdot
.2895 .47022 Mdot
.37664 .32499 Mdot
.50505 .27522 Mdot
.66314 .63937 Mdot
.55368 .71843 Mdot
.4834 .29966 Mdot
.49006 .71492 Mdot
.38645 .67517 Mdot
.42241 .308 Mdot
.60799 .32855 Mdot
.38266 .66705 Mdot
.41199 .29943 Mdot
.59842 .30711 Mdot
.70081 .54081 Mdot
.6952 .59413 Mdot
.68831 .39553 Mdot
.63804 .33285 Mdot
.58814 .69536 Mdot
.33876 .37892 Mdot
.61125 .32714 Mdot
.68802 .38662 Mdot
.70293 .50197 Mdot
.30294 .41299 Mdot
.4142 .69048 Mdot
.48746 .27648 Mdot
.45494 .69896 Mdot
.39971 .31874 Mdot
.35764 .65932 Mdot
.57891 .29961 Mdot
.591 .70504 Mdot
.5568 .70605 Mdot
.37988 .68284 Mdot
.44077 .71102 Mdot
.38326 .68153 Mdot
.47113 .29829 Mdot
.70464 .53057 Mdot
.70414 .48238 Mdot
.48491 .29765 Mdot
.40933 .70345 Mdot
.3513 .65425 Mdot
.29283 .49085 Mdot
.58091 .69911 Mdot
.43265 .70801 Mdot
.62553 .31792 Mdot
.72429 .50886 Mdot
.29477 .49342 Mdot
.46014 .71707 Mdot
.27808 .52591 Mdot
.44291 .70811 Mdot
.49079 .27968 Mdot
.71556 .46709 Mdot
.35762 .64923 Mdot
.29333 .54096 Mdot
.58878 .69728 Mdot
.60572 .68956 Mdot
.38598 .68836 Mdot
.6134 .6857 Mdot
.60531 .31273 Mdot
.66537 .35206 Mdot
.37276 .67507 Mdot
.32685 .38823 Mdot
.32688 .36277 Mdot
.34051 .35877 Mdot
.51965 .71375 Mdot
.62252 .66103 Mdot
.71118 .57262 Mdot
.70819 .47032 Mdot
.45703 .30146 Mdot
.5861 .30004 Mdot
.65959 .35849 Mdot
.70031 .40707 Mdot
.28333 .45225 Mdot
.38536 .68157 Mdot
.68066 .41198 Mdot
.46755 .30093 Mdot
.42523 .30236 Mdot
.30192 .39464 Mdot
.36395 .33612 Mdot
.32709 .37381 Mdot
.68616 .40314 Mdot
.54914 .28416 Mdot
.71491 .55388 Mdot
.62267 .34136 Mdot
.2754 .49355 Mdot
.29014 .48 Mdot
.30177 .39628 Mdot
.55307 .29774 Mdot
.65871 .35881 Mdot
.54828 .70412 Mdot
.50767 .7243 Mdot
.33237 .35647 Mdot
.40752 .69362 Mdot
.60443 .30147 Mdot
.45669 .71367 Mdot
.72041 .46126 Mdot
.53721 .28487 Mdot
.29468 .5566 Mdot
.56715 .70907 Mdot
.39772 .32365 Mdot
.41623 .68948 Mdot
.29024 .56335 Mdot
.68702 .59044 Mdot
.62046 .31182 Mdot
.50105 .28183 Mdot
.7233 .51906 Mdot
.30364 .53882 Mdot
.69364 .55133 Mdot
.42589 .30689 Mdot
.31658 .39299 Mdot
.28808 .5118 Mdot
.68123 .39693 Mdot
.59323 .68266 Mdot
.29098 .54758 Mdot
.6772 .63428 Mdot
.34612 .34851 Mdot
.37748 .66332 Mdot
.33311 .36157 Mdot
.65175 .36365 Mdot
.30351 .4091 Mdot
.57942 .70749 Mdot
.70323 .48068 Mdot
.43598 .30008 Mdot
.70127 .59044 Mdot
.29784 .46696 Mdot
.3353 .3758 Mdot
.31656 .59701 Mdot
.71349 .47177 Mdot
.68391 .58674 Mdot
.34815 .66403 Mdot
.58697 .70679 Mdot
.56385 .30307 Mdot
.70206 .49342 Mdot
.58056 .31379 Mdot
.44052 .70894 Mdot
.4971 .29279 Mdot
.52444 .28901 Mdot
.62322 .65873 Mdot
.38401 .6689 Mdot
.60622 .68185 Mdot
.46767 .69894 Mdot
.56172 .2971 Mdot
.67141 .60728 Mdot
.70502 .49626 Mdot
.66603 .6116 Mdot
.58365 .68405 Mdot
.56428 .30239 Mdot
.29852 .58819 Mdot
.71605 .5436 Mdot
.44635 .71231 Mdot
.41555 .30172 Mdot
.6487 .64598 Mdot
.31914 .61434 Mdot
.39763 .69621 Mdot
.40831 .69088 Mdot
.39649 .68987 Mdot
.53038 .70952 Mdot
.62873 .67107 Mdot
.31715 .59024 Mdot
.4495 .28674 Mdot
.33498 .62743 Mdot
.32245 .59244 Mdot
.44503 .28906 Mdot
.43292 .70615 Mdot
.43799 .69436 Mdot
.71744 .46351 Mdot
.71516 .46991 Mdot
.37392 .33934 Mdot
.50103 .29445 Mdot
.28491 .50437 Mdot
.40985 .68038 Mdot
.54654 .28398 Mdot
.69646 .40516 Mdot
.35906 .66998 Mdot
.53876 .69638 Mdot
.68965 .57524 Mdot
.69369 .39325 Mdot
.67844 .60793 Mdot
.69049 .42727 Mdot
.30888 .57225 Mdot
.58071 .70826 Mdot
.70184 .42835 Mdot
.6491 .33592 Mdot
.61467 .68564 Mdot
.68877 .42385 Mdot
.57105 .28927 Mdot
.46187 .30023 Mdot
.48854 .28194 Mdot
.56422 .30298 Mdot
.38214 .32641 Mdot
.62782 .34189 Mdot
.54785 .69985 Mdot
.39794 .32225 Mdot
.47709 .7151 Mdot
.56393 .30179 Mdot
.67634 .6367 Mdot
.63117 .34283 Mdot
.43415 .68962 Mdot
.62765 .65569 Mdot
.30795 .42179 Mdot
.38196 .6846 Mdot
.68522 .37663 Mdot
.28553 .52389 Mdot
.42505 .2963 Mdot
.58409 .30666 Mdot
.32002 .58888 Mdot
.70159 .51987 Mdot
.41138 .6822 Mdot
.62532 .68428 Mdot
.70047 .52386 Mdot
.72063 .51981 Mdot
.28833 .55819 Mdot
.40665 .32041 Mdot
.28925 .43032 Mdot
.5762 .6974 Mdot
.62756 .33962 Mdot
.35708 .64101 Mdot
.31527 .58702 Mdot
.35726 .67159 Mdot
.65701 .62642 Mdot
.55531 .69256 Mdot
.69044 .61925 Mdot
.57357 .69009 Mdot
.36119 .3489 Mdot
.29979 .47788 Mdot
.68187 .60136 Mdot
.40109 .6907 Mdot
.53308 .70057 Mdot
.70361 .43395 Mdot
.56123 .28444 Mdot
.31749 .38474 Mdot
.41312 .29516 Mdot
.33909 .64337 Mdot
.3174 .37233 Mdot
.57428 .69822 Mdot
.71249 .45303 Mdot
.40505 .31241 Mdot
.65661 .36098 Mdot
.37125 .67892 Mdot
.39007 .32563 Mdot
.33366 .62214 Mdot
.63831 .34593 Mdot
.57877 .2994 Mdot
.58889 .68975 Mdot
.29928 .60166 Mdot
.31652 .39434 Mdot
.52348 .71202 Mdot
.3382 .35225 Mdot
.30983 .42879 Mdot
.47807 .29146 Mdot
.55448 .70037 Mdot
.68261 .58995 Mdot
.57239 .31219 Mdot
.55991 .71327 Mdot
.71076 .49868 Mdot
.70913 .53466 Mdot
.31138 .40595 Mdot
.31246 .57022 Mdot
.37943 .68694 Mdot
.59382 .31644 Mdot
.54671 .28565 Mdot
.68557 .62086 Mdot
.31219 .40222 Mdot
.71634 .526 Mdot
.52355 .29085 Mdot
.58487 .29554 Mdot
.52655 .27687 Mdot
.54758 .29609 Mdot
.57218 .70139 Mdot
.38409 .67407 Mdot
.63168 .32816 Mdot
.29836 .47671 Mdot
.70102 .59446 Mdot
.31516 .59211 Mdot
.28981 .50857 Mdot
.32153 .61741 Mdot
.46575 .27772 Mdot
.32014 .37815 Mdot
.69288 .44635 Mdot
.57444 .30593 Mdot
.51537 .2893 Mdot
.28173 .54909 Mdot
.68371 .37938 Mdot
.70838 .42717 Mdot
.61648 .31023 Mdot
.28748 .47306 Mdot
.38167 .67626 Mdot
.65239 .63045 Mdot
.34374 .35614 Mdot
.29297 .47661 Mdot
.38811 .3197 Mdot
.44968 .30593 Mdot
.66257 .38191 Mdot
.50655 .70166 Mdot
.70593 .49026 Mdot
.43838 .69659 Mdot
.61734 .67235 Mdot
.53831 .28661 Mdot
.58242 .29472 Mdot
.39064 .31349 Mdot
.57401 .69526 Mdot
.6246 .66636 Mdot
.2825 .45747 Mdot
.30814 .57867 Mdot
.34967 .33844 Mdot
.57178 .69265 Mdot
.36144 .33623 Mdot
.67735 .36225 Mdot
.2951 .52148 Mdot
.65444 .63898 Mdot
.40195 .31451 Mdot
.29361 .5656 Mdot
.30055 .52485 Mdot
.43136 .6971 Mdot
.69419 .43628 Mdot
.63341 .34918 Mdot
.41256 .68949 Mdot
.39612 .3052 Mdot
.40739 .30136 Mdot
.53752 .28201 Mdot
.56944 .70153 Mdot
.38621 .31943 Mdot
.29908 .46872 Mdot
.55587 .71472 Mdot
.69456 .55561 Mdot
.67715 .38146 Mdot
.68459 .62506 Mdot
.70485 .55381 Mdot
.5348 .28857 Mdot
.35325 .65854 Mdot
.68173 .62417 Mdot
.31568 .3802 Mdot
.66605 .37648 Mdot
.68743 .41355 Mdot
.35727 .6452 Mdot
.46299 .29376 Mdot
.40379 .67677 Mdot
.58867 .29715 Mdot
.5197 .70233 Mdot
.5324 .29294 Mdot
.29319 .55505 Mdot
.31858 .62188 Mdot
.3571 .66584 Mdot
.58772 .29419 Mdot
.29315 .54626 Mdot
.66111 .35415 Mdot
.67497 .61313 Mdot
.61005 .67625 Mdot
.51563 .29349 Mdot
.38054 .67442 Mdot
.29921 .465 Mdot
.31786 .41307 Mdot
.695 .59008 Mdot
.60599 .67928 Mdot
.43928 .28762 Mdot
.37588 .66883 Mdot
.51221 .70858 Mdot
.28715 .54339 Mdot
.61857 .66178 Mdot
.4268 .69623 Mdot
.33404 .64208 Mdot
.71645 .44623 Mdot
.63667 .33447 Mdot
.32922 .6406 Mdot
.55725 .28255 Mdot
.53284 .7104 Mdot
.67537 .60415 Mdot
.64334 .35569 Mdot
.62322 .3177 Mdot
.32425 .61708 Mdot
.426 .29339 Mdot
.66348 .61821 Mdot
.42843 .68781 Mdot
.63143 .65564 Mdot
.29981 .5677 Mdot
.49741 .29252 Mdot
.38349 .32353 Mdot
.28267 .46885 Mdot
.31328 .40949 Mdot
.37097 .32658 Mdot
.46972 .28971 Mdot
.51066 .7047 Mdot
.71362 .54351 Mdot
.6275 .65828 Mdot
.46475 .28586 Mdot
.72448 .5052 Mdot
.46663 .70297 Mdot
.49227 .7169 Mdot
.33906 .35113 Mdot
.4763 .27878 Mdot
.70258 .56158 Mdot
.67771 .60483 Mdot
.40485 .70309 Mdot
.61118 .33213 Mdot
.45153 .7005 Mdot
.43242 .28738 Mdot
.30269 .41649 Mdot
.42737 .28856 Mdot
.45095 .70271 Mdot
.30719 .57401 Mdot
.39555 .31285 Mdot
.4463 .29797 Mdot
.35409 .35946 Mdot
.35561 .35771 Mdot
.4344 .69244 Mdot
.53864 .30237 Mdot
.72111 .52025 Mdot
.67831 .5976 Mdot
.30206 .5632 Mdot
.34871 .6379 Mdot
.61653 .69157 Mdot
.70787 .41876 Mdot
.29025 .50786 Mdot
.5241 .71277 Mdot
.64382 .35069 Mdot
.33561 .36707 Mdot
.31527 .41345 Mdot
.59827 .31437 Mdot
.30537 .42965 Mdot
.49712 .29325 Mdot
.67766 .63672 Mdot
.36598 .65122 Mdot
.70986 .41899 Mdot
.3185 .59288 Mdot
.29661 .56988 Mdot
.5757 .70097 Mdot
.31508 .40533 Mdot
.32462 .3971 Mdot
.70362 .50713 Mdot
.50954 .28191 Mdot
.28891 .56805 Mdot
.71118 .51218 Mdot
.37374 .68335 Mdot
.37032 .3355 Mdot
.31615 .62561 Mdot
.53975 .70171 Mdot
.70017 .44494 Mdot
.71288 .53559 Mdot
.33419 .65189 Mdot
.3015 .57584 Mdot
.34229 .65497 Mdot
.4129 .29885 Mdot
.70052 .39945 Mdot
.40664 .3145 Mdot
.32327 .40278 Mdot
.71869 .54462 Mdot
.59213 .68206 Mdot
.58391 .29922 Mdot
.544 .71702 Mdot
.54603 .30355 Mdot
.61422 .31013 Mdot
.37988 .67744 Mdot
.3059 .5501 Mdot
.38179 .31437 Mdot
.30337 .45763 Mdot
.71133 .47863 Mdot
.71502 .43567 Mdot
.70451 .43628 Mdot
.53898 .28308 Mdot
.6424 .66979 Mdot
.29184 .41738 Mdot
.36824 .67596 Mdot
.46701 .30032 Mdot
.70531 .50979 Mdot
.48208 .70112 Mdot
.37863 .67195 Mdot
.47529 .30075 Mdot
.35369 .66837 Mdot
.53354 .30147 Mdot
.32231 .60975 Mdot
.70593 .49785 Mdot
.46942 .71004 Mdot
.30842 .57836 Mdot
.691 .39611 Mdot
.45444 .30053 Mdot
.6811 .39001 Mdot
.30719 .56249 Mdot
.31531 .41965 Mdot
.46186 .30173 Mdot
.56108 .69396 Mdot
.6879 .42984 Mdot
.55393 .28722 Mdot
.70654 .42532 Mdot
.29386 .47856 Mdot
.28754 .49121 Mdot
.32292 .37838 Mdot
.55466 .29928 Mdot
.41666 .31497 Mdot
.38759 .67185 Mdot
.64919 .63548 Mdot
.35385 .35848 Mdot
.69273 .38748 Mdot
.41284 .3168 Mdot
.64275 .64526 Mdot
.4798 .29273 Mdot
.3293 .35898 Mdot
.53045 .7185 Mdot
.70578 .51829 Mdot
.30456 .58363 Mdot
.40025 .67756 Mdot
.67252 .61481 Mdot
.54518 .69702 Mdot
.29958 .53692 Mdot
.43914 .69467 Mdot
.55203 .30594 Mdot
.59446 .67663 Mdot
.70378 .57649 Mdot
.31136 .42263 Mdot
.60598 .30487 Mdot
.28767 .43419 Mdot
.33567 .6299 Mdot
.54586 .71378 Mdot
.4374 .69231 Mdot
.71649 .50306 Mdot
.60652 .30356 Mdot
.43945 .29627 Mdot
.71643 .55181 Mdot
.29209 .45738 Mdot
.7033 .47464 Mdot
.70472 .46127 Mdot
.62103 .66895 Mdot
.31354 .59887 Mdot
.51055 .2769 Mdot
.5593 .70917 Mdot
.28675 .55843 Mdot
.55752 .69249 Mdot
.34591 .33928 Mdot
.28664 .50031 Mdot
.33169 .39176 Mdot
.69697 .45932 Mdot
.33094 .35886 Mdot
.71775 .49637 Mdot
.29439 .55327 Mdot
.31577 .40622 Mdot
.43659 .29556 Mdot
.35437 .65723 Mdot
.50726 .71782 Mdot
.6085 .68377 Mdot
.33599 .35293 Mdot
.39855 .32758 Mdot
.71739 .53497 Mdot
.42782 .28802 Mdot
.3066 .61491 Mdot
.43681 .30377 Mdot
.70413 .44073 Mdot
.65822 .65917 Mdot
.49594 .72348 Mdot
.50867 .29007 Mdot
.7053 .51058 Mdot
.3139 .3795 Mdot
.33643 .63214 Mdot
.69818 .40074 Mdot
.35628 .66003 Mdot
.53023 .72066 Mdot
.70533 .43582 Mdot
.28675 .46221 Mdot
.70253 .49588 Mdot
.3224 .62493 Mdot
.49214 .2961 Mdot
.374 .33573 Mdot
.47991 .27742 Mdot
.69816 .57051 Mdot
.38147 .67721 Mdot
.64792 .6542 Mdot
.72086 .46837 Mdot
.6747 .37304 Mdot
.7053 .53328 Mdot
.34429 .66156 Mdot
.70206 .53698 Mdot
.70349 .4607 Mdot
.45615 .69653 Mdot
.41048 .67909 Mdot
.30676 .4382 Mdot
.47392 .7133 Mdot
.55932 .70632 Mdot
.62722 .65588 Mdot
.52973 .71452 Mdot
.51178 .70992 Mdot
.56133 .69937 Mdot
.64339 .3454 Mdot
.59372 .68027 Mdot
.66426 .37968 Mdot
.65449 .37014 Mdot
.31912 .40697 Mdot
.38062 .68946 Mdot
.42611 .70032 Mdot
.63932 .65614 Mdot
.60786 .68286 Mdot
.68079 .37873 Mdot
.67951 .40726 Mdot
.43972 .29977 Mdot
.70337 .57336 Mdot
.29766 .46171 Mdot
.61869 .67636 Mdot
.3709 .3419 Mdot
.31677 .39909 Mdot
.43473 .69451 Mdot
.46702 .71819 Mdot
.60948 .69187 Mdot
.66164 .63149 Mdot
.48532 .70269 Mdot
.58244 .68913 Mdot
.2953 .42185 Mdot
.64777 .65634 Mdot
.70982 .53768 Mdot
.6998 .46676 Mdot
.34122 .63601 Mdot
.3286 .6353 Mdot
.67502 .60461 Mdot
.66255 .65221 Mdot
.68115 .39782 Mdot
.7138 .51491 Mdot
.38678 .32938 Mdot
.59618 .31556 Mdot
.67142 .62244 Mdot
.4288 .29408 Mdot
.70105 .59527 Mdot
.46399 .28769 Mdot
.41299 .30513 Mdot
.39353 .69478 Mdot
.32853 .37961 Mdot
.55599 .71718 Mdot
.41323 .31811 Mdot
.56643 .69917 Mdot
.71957 .53111 Mdot
.35968 .64524 Mdot
.6873 .40262 Mdot
.40536 .31358 Mdot
.62908 .32978 Mdot
.70885 .435 Mdot
.59635 .67551 Mdot
.34062 .34581 Mdot
.3064 .40489 Mdot
.3103 .61622 Mdot
.668 .36716 Mdot
.54798 .70703 Mdot
.64993 .34256 Mdot
.61449 .32329 Mdot
.69515 .43307 Mdot
.60119 .67424 Mdot
.68068 .62139 Mdot
.54623 .70255 Mdot
.69317 .40013 Mdot
.32323 .38479 Mdot
.38 .66219 Mdot
.59163 .69287 Mdot
.29482 .55563 Mdot
.69635 .45695 Mdot
.31173 .38584 Mdot
.65316 .65153 Mdot
.36298 .33578 Mdot
.70651 .44404 Mdot
.28765 .43805 Mdot
.49171 .29397 Mdot
.35247 .35948 Mdot
.62755 .67949 Mdot
.47501 .70043 Mdot
.70354 .46417 Mdot
.58127 .3016 Mdot
.70548 .50854 Mdot
.53412 .71655 Mdot
.65914 .35513 Mdot
.32377 .39459 Mdot
.67907 .40816 Mdot
.70238 .5528 Mdot
.59246 .69967 Mdot
.32032 .59953 Mdot
.72104 .54117 Mdot
.61983 .66438 Mdot
.70431 .57653 Mdot
.38775 .68222 Mdot
.70194 .56622 Mdot
.66692 .643 Mdot
.60958 .69343 Mdot
.28862 .46386 Mdot
.50918 .72087 Mdot
.29546 .5176 Mdot
.68576 .57682 Mdot
.70534 .5917 Mdot
.69684 .54154 Mdot
.69209 .38978 Mdot
.70565 .46883 Mdot
.31773 .40095 Mdot
.69685 .40068 Mdot
.29205 .54446 Mdot
.51075 .27708 Mdot
.70728 .41722 Mdot
.2987 .48189 Mdot
.29146 .56316 Mdot
.30803 .55989 Mdot
.33525 .64278 Mdot
.30375 .60988 Mdot
.28257 .54253 Mdot
.29699 .57642 Mdot
.66499 .36356 Mdot
.27984 .4763 Mdot
.32134 .59309 Mdot
.51318 .27714 Mdot
.29776 .52037 Mdot
.50678 .72103 Mdot
.70643 .54049 Mdot
.55907 .28804 Mdot
.36623 .3287 Mdot
.34485 .65614 Mdot
.59996 .69688 Mdot
.68483 .41556 Mdot
.45466 .70166 Mdot
.3222 .60557 Mdot
.63246 .34322 Mdot
.38314 .32729 Mdot
.35484 .64045 Mdot
.32052 .61358 Mdot
.37623 .67778 Mdot
.33873 .35427 Mdot
.43381 .28572 Mdot
.51052 .72199 Mdot
.29947 .46553 Mdot
.41852 .70331 Mdot
.51129 .72148 Mdot
.66848 .3709 Mdot
.34193 .64798 Mdot
.51201 .70337 Mdot
.71452 .50353 Mdot
.6047 .3107 Mdot
.37565 .31497 Mdot
.55097 .71809 Mdot
.71418 .43559 Mdot
.69839 .46344 Mdot
.30293 .59821 Mdot
.38907 .3244 Mdot
.58934 .70477 Mdot
.5199 .28045 Mdot
.5692 .30503 Mdot
.28569 .46775 Mdot
.56931 .29402 Mdot
.43018 .31216 Mdot
.63356 .67407 Mdot
.30018 .52536 Mdot
.57824 .70641 Mdot
.27566 .48743 Mdot
.52003 .30045 Mdot
.62597 .32331 Mdot
.32372 .40107 Mdot
.69127 .61181 Mdot
.53735 .28293 Mdot
.30975 .4241 Mdot
.70052 .46883 Mdot
.63716 .34841 Mdot
.60002 .31703 Mdot
.34592 .63218 Mdot
.36159 .33838 Mdot
.64666 .3592 Mdot
.6466 .34655 Mdot
.70765 .53916 Mdot
.44779 .70349 Mdot
.70228 .42785 Mdot
.28588 .48267 Mdot
.34247 .63878 Mdot
.29393 .45068 Mdot
.29581 .4768 Mdot
.44667 .30375 Mdot
.63783 .64836 Mdot
.69478 .59238 Mdot
.49632 .72416 Mdot
.56391 .69305 Mdot
.53601 .70981 Mdot
.68366 .38206 Mdot
.46168 .7198 Mdot
.33824 .62338 Mdot
.6663 .36662 Mdot
.63689 .3322 Mdot
.3537 .64739 Mdot
.62408 .67336 Mdot
.5083 .705 Mdot
.69463 .60804 Mdot
.70565 .48829 Mdot
.66127 .35146 Mdot
.52462 .28329 Mdot
.69797 .4653 Mdot
.28039 .51307 Mdot
.30241 .39761 Mdot
.33126 .38042 Mdot
.45783 .29838 Mdot
.53685 .7211 Mdot
.30069 .41218 Mdot
.71727 .47277 Mdot
.28074 .52017 Mdot
.7125 .48557 Mdot
.34036 .37798 Mdot
.53957 .71629 Mdot
.34755 .3346 Mdot
.47275 .27677 Mdot
.69027 .56903 Mdot
.64672 .66133 Mdot
.38348 .68827 Mdot
.68397 .38134 Mdot
.52825 .29835 Mdot
.70273 .40253 Mdot
.4523 .7029 Mdot
.69681 .42131 Mdot
.41506 .31068 Mdot
.457 .28723 Mdot
.69683 .56588 Mdot
.71653 .48309 Mdot
.7051 .49486 Mdot
.63742 .32296 Mdot
.38573 .32531 Mdot
.69359 .43198 Mdot
.65443 .36498 Mdot
.704 .52259 Mdot
.31975 .37093 Mdot
.69253 .60285 Mdot
.68506 .39215 Mdot
.37192 .65517 Mdot
.63627 .34468 Mdot
.3548 .65035 Mdot
.63662 .35194 Mdot
.29132 .47739 Mdot
.55308 .71115 Mdot
.3153 .41174 Mdot
.40331 .68933 Mdot
.28805 .4261 Mdot
.4679 .28651 Mdot
.2963 .53186 Mdot
.57452 .31257 Mdot
.65334 .63601 Mdot
.70734 .42625 Mdot
.49063 .27925 Mdot
.69351 .60169 Mdot
.5316 .70867 Mdot
.63398 .35033 Mdot
.38416 .32924 Mdot
.29376 .44559 Mdot
.66603 .62342 Mdot
.58808 .29578 Mdot
.35937 .35681 Mdot
.72061 .50635 Mdot
.2798 .48482 Mdot
.68702 .57264 Mdot
.52495 .27662 Mdot
.70571 .47658 Mdot
.29355 .44474 Mdot
.65399 .63706 Mdot
.65684 .36432 Mdot
.3057 .40146 Mdot
.54344 .30426 Mdot
.5137 .27997 Mdot
.62245 .68854 Mdot
.50751 .27537 Mdot
.37733 .33689 Mdot
.42588 .28849 Mdot
.64865 .35983 Mdot
.45184 .28833 Mdot
.38673 .68344 Mdot
.3283 .37748 Mdot
.30137 .56242 Mdot
.71561 .53268 Mdot
.39628 .32005 Mdot
.48038 .72175 Mdot
.2924 .48896 Mdot
.27748 .48778 Mdot
.63098 .34386 Mdot
.58546 .29322 Mdot
.72296 .47385 Mdot
.66872 .61934 Mdot
.37029 .33625 Mdot
.27927 .50091 Mdot
.57172 .68744 Mdot
.29975 .53119 Mdot
.2847 .46583 Mdot
.54929 .69903 Mdot
.70896 .52186 Mdot
.43924 .30192 Mdot
.61542 .67099 Mdot
.66083 .36739 Mdot
.59495 .68372 Mdot
.55297 .30529 Mdot
.28123 .45726 Mdot
.44509 .69861 Mdot
.38227 .68846 Mdot
.58373 .31463 Mdot
.57971 .31198 Mdot
.32452 .36182 Mdot
.56407 .29046 Mdot
.67765 .37685 Mdot
.36613 .33456 Mdot
.70699 .5173 Mdot
.29823 .5416 Mdot
.53732 .70252 Mdot
.69198 .41968 Mdot
.70229 .40179 Mdot
.32789 .37813 Mdot
.67016 .64175 Mdot
.54412 .29809 Mdot
.27696 .49386 Mdot
.71185 .48267 Mdot
.33322 .37746 Mdot
.37334 .68565 Mdot
.30886 .38273 Mdot
.65721 .34793 Mdot
.354 .66231 Mdot
.69618 .42334 Mdot
.29765 .5823 Mdot
.37644 .68772 Mdot
.39555 .69586 Mdot
.29646 .42176 Mdot
.59986 .29965 Mdot
.31483 .41088 Mdot
.53697 .71372 Mdot
.53077 .70345 Mdot
.35622 .33659 Mdot
.37703 .67274 Mdot
.47388 .72281 Mdot
.33148 .61031 Mdot
.59925 .31961 Mdot
.68504 .58022 Mdot
.2911 .49727 Mdot
.29157 .49123 Mdot
.40875 .31079 Mdot
.68656 .41969 Mdot
.29022 .55989 Mdot
.44361 .28492 Mdot
.58604 .31889 Mdot
.3652 .66143 Mdot
.30948 .43542 Mdot
.69985 .43918 Mdot
.46139 .28313 Mdot
.65789 .36579 Mdot
.53975 .70759 Mdot
.33587 .65185 Mdot
.30548 .44822 Mdot
.29214 .57354 Mdot
.6787 .60669 Mdot
.48136 .27764 Mdot
.48036 .70669 Mdot
.34861 .64958 Mdot
.45251 .29909 Mdot
.3195 .59488 Mdot
.71084 .4882 Mdot
.28367 .45151 Mdot
.52988 .27718 Mdot
.62665 .68366 Mdot
.52828 .72172 Mdot
.44719 .3044 Mdot
.63292 .66948 Mdot
.70116 .46339 Mdot
.65063 .35689 Mdot
.32112 .37779 Mdot
.60138 .67394 Mdot
.59963 .68794 Mdot
.59778 .69165 Mdot
.35952 .3359 Mdot
.32289 .62249 Mdot
.28326 .52268 Mdot
.59978 .6925 Mdot
.53418 .28741 Mdot
.69793 .53742 Mdot
.57021 .30118 Mdot
.62779 .67744 Mdot
.55633 .71185 Mdot
.71633 .47907 Mdot
.70117 .54659 Mdot
.57412 .31189 Mdot
.32656 .62786 Mdot
.32402 .61793 Mdot
.69191 .3873 Mdot
.52463 .71864 Mdot
.63198 .65977 Mdot
.5644 .70888 Mdot
.38601 .68978 Mdot
.71314 .57184 Mdot
.64074 .64514 Mdot
.68942 .58494 Mdot
.68541 .61968 Mdot
.49051 .70519 Mdot
.42726 .30812 Mdot
.62993 .32425 Mdot
.53485 .2953 Mdot
.33625 .34782 Mdot
.36911 .34824 Mdot
.32244 .60237 Mdot
.43617 .69379 Mdot
.36439 .65378 Mdot
.59367 .67881 Mdot
.43401 .71244 Mdot
.67943 .60156 Mdot
.71003 .55474 Mdot
.34543 .62846 Mdot
.58323 .7074 Mdot
.33425 .35789 Mdot
.29653 .40411 Mdot
.71546 .46736 Mdot
.62555 .68062 Mdot
.4034 .30916 Mdot
.55123 .29126 Mdot
.28799 .49703 Mdot
.28291 .51315 Mdot
.31945 .59888 Mdot
.30945 .56219 Mdot
.7011 .53917 Mdot
.48664 .70153 Mdot
.31604 .60444 Mdot
.42615 .31195 Mdot
.29586 .57824 Mdot
.29854 .45215 Mdot
.52096 .29634 Mdot
.49837 .28287 Mdot
.48074 .71684 Mdot
.4881 .72433 Mdot
.61779 .32393 Mdot
.58075 .29085 Mdot
.58006 .30915 Mdot
.28784 .43384 Mdot
.3255 .63466 Mdot
.63786 .32829 Mdot
.6933 .44206 Mdot
.40858 .69253 Mdot
.5852 .70507 Mdot
.30108 .40372 Mdot
.68105 .4052 Mdot
.41425 .70407 Mdot
.69102 .60407 Mdot
.27794 .49348 Mdot
.47864 .70948 Mdot
.71659 .43937 Mdot
.64804 .34388 Mdot
.66645 .61918 Mdot
.68507 .39385 Mdot
.53837 .28684 Mdot
.47262 .28545 Mdot
.55941 .71244 Mdot
.57375 .30133 Mdot
.6757 .36067 Mdot
.46865 .28286 Mdot
.34541 .63016 Mdot
.29741 .55066 Mdot
.31598 .58371 Mdot
.31553 .38256 Mdot
.38899 .69276 Mdot
.40461 .31817 Mdot
.30623 .4305 Mdot
.70061 .42536 Mdot
.37833 .67148 Mdot
.632 .65307 Mdot
.29738 .55898 Mdot
.32491 .61178 Mdot
.69108 .58455 Mdot
.71231 .42889 Mdot
.36252 .34554 Mdot
.37085 .65949 Mdot
.43396 .69865 Mdot
.41097 .29348 Mdot
.49523 .29657 Mdot
.48929 .28942 Mdot
.32504 .63041 Mdot
.33521 .37189 Mdot
.69411 .42754 Mdot
.56737 .68938 Mdot
.65966 .34397 Mdot
.50375 .70207 Mdot
.51007 .71623 Mdot
.66981 .35719 Mdot
.69329 .42558 Mdot
.56395 .71257 Mdot
.56869 .6917 Mdot
.29499 .55048 Mdot
.56147 .29876 Mdot
.62546 .34117 Mdot
.6236 .33868 Mdot
.39294 .32942 Mdot
.70289 .47076 Mdot
.30784 .61568 Mdot
.47941 .28747 Mdot
.30009 .46828 Mdot
.55524 .30113 Mdot
.41072 .68501 Mdot
.33439 .38302 Mdot
.63976 .33101 Mdot
.56807 .29359 Mdot
.71684 .50487 Mdot
.70219 .42956 Mdot
.38137 .67991 Mdot
.70528 .46007 Mdot
.69506 .40674 Mdot
.52104 .7196 Mdot
.32394 .6213 Mdot
.30001 .57675 Mdot
.68105 .60316 Mdot
.61753 .32422 Mdot
.53687 .71088 Mdot
.71112 .55862 Mdot
.54318 .71795 Mdot
.66848 .61677 Mdot
.64715 .35486 Mdot
.65417 .65815 Mdot
.70367 .42966 Mdot
.65607 .37453 Mdot
.30567 .44606 Mdot
.29906 .56452 Mdot
.28833 .5534 Mdot
.32406 .36039 Mdot
.51511 .70366 Mdot
.31072 .41999 Mdot
.70551 .5251 Mdot
.30374 .54103 Mdot
.62453 .65694 Mdot
.39017 .67267 Mdot
.56963 .69798 Mdot
.30646 .56567 Mdot
.38091 .32924 Mdot
.7183 .49641 Mdot
.57607 .70097 Mdot
.33091 .63876 Mdot
.702 .44021 Mdot
.59916 .31122 Mdot
.6868 .41896 Mdot
.36462 .66411 Mdot
.55254 .30363 Mdot
.70652 .52558 Mdot
.31969 .37674 Mdot
.31659 .41132 Mdot
.69658 .42551 Mdot
.31212 .40532 Mdot
.49992 .27966 Mdot
.5877 .69811 Mdot
.55944 .29893 Mdot
.37362 .65939 Mdot
.63223 .34198 Mdot
.71564 .49582 Mdot
.68385 .58551 Mdot
.70547 .4705 Mdot
.29346 .53424 Mdot
.33095 .61392 Mdot
.28024 .45593 Mdot
.60684 .30944 Mdot
.54014 .30019 Mdot
.37899 .3385 Mdot
.71826 .48049 Mdot
.44313 .71603 Mdot
.65075 .65059 Mdot
.44324 .69981 Mdot
.6976 .57202 Mdot
.4185 .68279 Mdot
.32499 .40124 Mdot
.68767 .38275 Mdot
.69183 .56269 Mdot
.67786 .59748 Mdot
.47383 .72147 Mdot
.31698 .58314 Mdot
.45814 .69954 Mdot
.62801 .65708 Mdot
.61792 .68074 Mdot
.62603 .31978 Mdot
.66443 .62325 Mdot
.28421 .45831 Mdot
.29717 .4736 Mdot
.33636 .34778 Mdot
.30079 .53757 Mdot
.28608 .44586 Mdot
.56128 .69532 Mdot
.67158 .63713 Mdot
.67519 .40182 Mdot
.71213 .45418 Mdot
.51412 .29045 Mdot
.66284 .65104 Mdot
.38861 .32846 Mdot
.32826 .39305 Mdot
.64586 .6713 Mdot
.70007 .46105 Mdot
.38976 .307 Mdot
.31168 .5887 Mdot
.28745 .5464 Mdot
.40591 .69167 Mdot
.29269 .43681 Mdot
.36262 .67374 Mdot
.54684 .29867 Mdot
.51766 .7237 Mdot
.6402 .64566 Mdot
.36814 .32132 Mdot
.70181 .48769 Mdot
.40636 .30287 Mdot
.40939 .68379 Mdot
.50069 .71008 Mdot
.63236 .33394 Mdot
.69857 .40171 Mdot
.41876 .70513 Mdot
.31917 .41441 Mdot
.28842 .46835 Mdot
.40014 .67406 Mdot
.3322 .62917 Mdot
.41806 .31362 Mdot
.32645 .61749 Mdot
.71027 .50616 Mdot
.67785 .60127 Mdot
.50653 .29983 Mdot
.53362 .71469 Mdot
.59628 .32047 Mdot
.69099 .38748 Mdot
.48979 .7034 Mdot
.33858 .63076 Mdot
.68091 .40794 Mdot
.72091 .49452 Mdot
.51268 .72403 Mdot
.32206 .38586 Mdot
.51835 .71324 Mdot
.29355 .48911 Mdot
.28774 .52525 Mdot
.45572 .70981 Mdot
.37956 .32792 Mdot
.3531 .66075 Mdot
.33706 .62667 Mdot
.70768 .46871 Mdot
.30027 .53843 Mdot
.71238 .47337 Mdot
.52717 .70219 Mdot
.34437 .62977 Mdot
.71473 .48974 Mdot
.66197 .34979 Mdot
.29928 .48579 Mdot
.33137 .38086 Mdot
.63616 .33208 Mdot
.52671 .71203 Mdot
.29566 .54756 Mdot
.49506 .70363 Mdot
.70625 .49204 Mdot
.46814 .71227 Mdot
.5192 .29852 Mdot
.65844 .35913 Mdot
.53022 .28974 Mdot
.71606 .50453 Mdot
.48479 .71064 Mdot
.32629 .61735 Mdot
.31958 .62589 Mdot
.59982 .69709 Mdot
.69516 .42193 Mdot
.69137 .39718 Mdot
.69199 .43166 Mdot
.37868 .33774 Mdot
.58523 .68247 Mdot
.51825 .28518 Mdot
.32099 .61722 Mdot
.51431 .27597 Mdot
.62302 .6612 Mdot
.36862 .67 Mdot
.49114 .29241 Mdot
.59405 .69769 Mdot
.57379 .29001 Mdot
.49013 .70143 Mdot
.63756 .32986 Mdot
.32732 .3572 Mdot
.40468 .30462 Mdot
.61879 .32867 Mdot
.47447 .70181 Mdot
.67899 .60789 Mdot
.64296 .64078 Mdot
.47475 .28232 Mdot
.34066 .64857 Mdot
.31049 .43539 Mdot
.30486 .39781 Mdot
.4383 .71486 Mdot
.46047 .30243 Mdot
.41024 .29426 Mdot
.70226 .55303 Mdot
.61348 .31623 Mdot
.52678 .29607 Mdot
.50222 .29302 Mdot
.37638 .33642 Mdot
.71116 .52679 Mdot
.47812 .71105 Mdot
.29171 .54274 Mdot
.41973 .2985 Mdot
.59924 .6897 Mdot
.71187 .46109 Mdot
.28592 .51514 Mdot
.68684 .41249 Mdot
.36937 .31849 Mdot
.60804 .66907 Mdot
.67447 .37158 Mdot
.28008 .4827 Mdot
.64761 .3595 Mdot
.50517 .70835 Mdot
.31668 .61452 Mdot
.29693 .42488 Mdot
.51542 .70148 Mdot
.32709 .39731 Mdot
.49878 .28756 Mdot
.37647 .31821 Mdot
.67426 .62389 Mdot
.28094 .50618 Mdot
.56952 .71102 Mdot
.72228 .47618 Mdot
.40648 .69736 Mdot
.48239 .28559 Mdot
.67028 .39088 Mdot
.59449 .70268 Mdot
.40517 .32371 Mdot
.31618 .3746 Mdot
.68792 .4003 Mdot
.68862 .42568 Mdot
.6004 .29986 Mdot
.30385 .57095 Mdot
.35704 .35767 Mdot
.29601 .55 Mdot
.43039 .69637 Mdot
.46531 .28286 Mdot
.33721 .6264 Mdot
.28721 .43932 Mdot
.46584 .29693 Mdot
.71234 .42943 Mdot
.56888 .29296 Mdot
.72069 .51203 Mdot
.71702 .46857 Mdot
.30446 .41697 Mdot
.36942 .674 Mdot
.66211 .62119 Mdot
.69967 .56245 Mdot
.35109 .64452 Mdot
.38406 .33323 Mdot
.60543 .31696 Mdot
.70094 .40519 Mdot
.6587 .35872 Mdot
.64083 .64757 Mdot
.6536 .34749 Mdot
.62154 .67089 Mdot
.42293 .6889 Mdot
.566 .29312 Mdot
.55077 .69512 Mdot
.50118 .29206 Mdot
.60809 .30941 Mdot
.66752 .61788 Mdot
.70787 .49861 Mdot
.6026 .68054 Mdot
.6656 .64545 Mdot
.69758 .54945 Mdot
.51391 .70347 Mdot
.66644 .35771 Mdot
.70198 .40103 Mdot
.67156 .60628 Mdot
.4554 .28119 Mdot
.3858 .68672 Mdot
.65392 .36582 Mdot
.51374 .71359 Mdot
.66779 .35568 Mdot
.68561 .59023 Mdot
.52799 .30104 Mdot
.69837 .54171 Mdot
.28281 .45416 Mdot
.62735 .66539 Mdot
.32508 .36322 Mdot
.69366 .57289 Mdot
.67025 .35483 Mdot
.45998 .29075 Mdot
.71953 .5024 Mdot
.27773 .52786 Mdot
.66764 .64741 Mdot
.31762 .61876 Mdot
.37789 .68578 Mdot
.34788 .65183 Mdot
.5731 .31347 Mdot
.52637 .7045 Mdot
.55816 .6948 Mdot
.6052 .69807 Mdot
.41736 .68712 Mdot
.29816 .56228 Mdot
.41726 .69303 Mdot
.70899 .46314 Mdot
.56587 .70128 Mdot
.29798 .41396 Mdot
.63369 .3323 Mdot
.57662 .68977 Mdot
.70459 .56318 Mdot
.71621 .44353 Mdot
.61724 .32478 Mdot
.55172 .28186 Mdot
.29684 .46433 Mdot
.39196 .68353 Mdot
.55069 .71537 Mdot
.36965 .65268 Mdot
.70871 .51781 Mdot
.56172 .30328 Mdot
.62202 .68307 Mdot
.34429 .37208 Mdot
.65965 .63 Mdot
.38076 .33564 Mdot
.47941 .7191 Mdot
.63295 .34545 Mdot
.48289 .28689 Mdot
.28752 .4617 Mdot
.28493 .46726 Mdot
.60845 .68582 Mdot
.29238 .48629 Mdot
.35932 .65453 Mdot
.3704 .66913 Mdot
.51052 .29281 Mdot
.50612 .7071 Mdot
.65914 .62826 Mdot
.71052 .47393 Mdot
.50643 .70042 Mdot
.50963 .72312 Mdot
.45621 .295 Mdot
.46029 .29808 Mdot
.29151 .43141 Mdot
.55729 .71522 Mdot
.58596 .69216 Mdot
.62801 .33397 Mdot
.31909 .59221 Mdot
.34339 .3717 Mdot
.40858 .70412 Mdot
.35147 .34411 Mdot
.70061 .59768 Mdot
.33659 .64277 Mdot
.36849 .6682 Mdot
.39434 .31712 Mdot
.57422 .29394 Mdot
.29389 .55566 Mdot
.34978 .35539 Mdot
.33775 .37659 Mdot
.56717 .69417 Mdot
.70126 .49273 Mdot
.65074 .35842 Mdot
.36001 .65797 Mdot
.57421 .30497 Mdot
.7173 .47213 Mdot
.28967 .56506 Mdot
.41976 .69176 Mdot
.37896 .33936 Mdot
.63452 .3267 Mdot
.71489 .53439 Mdot
.49789 .71552 Mdot
.60017 .31297 Mdot
.49017 .71391 Mdot
.69461 .43442 Mdot
.65799 .37244 Mdot
.64087 .67117 Mdot
.67798 .39047 Mdot
.42364 .3135 Mdot
.33665 .38269 Mdot
.69379 .55096 Mdot
.4923 .29341 Mdot
.70675 .52042 Mdot
.28403 .51017 Mdot
.58453 .70376 Mdot
.51876 .7012 Mdot
.51468 .71474 Mdot
.37607 .6866 Mdot
.67783 .62705 Mdot
.30481 .5902 Mdot
.31634 .61562 Mdot
.60538 .31385 Mdot
.35204 .65825 Mdot
.67636 .60871 Mdot
.37303 .66586 Mdot
.32169 .37815 Mdot
.60675 .68465 Mdot
.36345 .66464 Mdot
.70026 .40179 Mdot
.71368 .52277 Mdot
.59706 .32 Mdot
.30702 .38457 Mdot
.31503 .60454 Mdot
.50505 .2891 Mdot
.71066 .56622 Mdot
.39725 .32402 Mdot
.42756 .30082 Mdot
.69228 .5912 Mdot
.27978 .46098 Mdot
.4447 .28302 Mdot
.33806 .38161 Mdot
.42721 .30406 Mdot
.53015 .28096 Mdot
.66315 .63087 Mdot
.37354 .66594 Mdot
.36454 .6774 Mdot
.4277 .70015 Mdot
.41654 .29708 Mdot
.34578 .37129 Mdot
.34711 .36104 Mdot
.67548 .6005 Mdot
.67332 .38556 Mdot
.29963 .52236 Mdot
.55053 .71789 Mdot
.44957 .30077 Mdot
.66855 .63268 Mdot
.36193 .67368 Mdot
.50319 .28371 Mdot
.69812 .56676 Mdot
.70394 .58742 Mdot
.30593 .57538 Mdot
.29652 .57032 Mdot
.37046 .66013 Mdot
.2989 .44847 Mdot
.64536 .35636 Mdot
.40376 .68544 Mdot
.61346 .69296 Mdot
.54105 .71554 Mdot
.57259 .31152 Mdot
.30106 .54093 Mdot
.50928 .28229 Mdot
.33073 .61778 Mdot
.41581 .69208 Mdot
.7078 .44133 Mdot
.69652 .44623 Mdot
.31983 .6046 Mdot
.69558 .61 Mdot
.6894 .62036 Mdot
.67334 .39915 Mdot
.64037 .35061 Mdot
.67437 .63993 Mdot
.33494 .61624 Mdot
.37823 .66574 Mdot
.72067 .49875 Mdot
.71559 .54834 Mdot
.69735 .55451 Mdot
.69188 .60177 Mdot
.34503 .34187 Mdot
.71774 .49462 Mdot
.28381 .44952 Mdot
.69043 .60458 Mdot
.39125 .3122 Mdot
.71538 .46213 Mdot
.48094 .71429 Mdot
.34605 .35277 Mdot
.47932 .71849 Mdot
.31409 .38792 Mdot
.53741 .71144 Mdot
.27546 .48767 Mdot
.31984 .37669 Mdot
.29358 .48354 Mdot
.70627 .5802 Mdot
.30408 .58811 Mdot
.34052 .62768 Mdot
.28566 .5544 Mdot
.64813 .65467 Mdot
.6104 .32358 Mdot
.64365 .33377 Mdot
.49641 .71601 Mdot
.37063 .34101 Mdot
.49174 .284 Mdot
.70298 .56003 Mdot
.52458 .70763 Mdot
.71461 .48208 Mdot
.5658 .29084 Mdot
.32483 .38226 Mdot
.38274 .68983 Mdot
.28322 .54739 Mdot
.28499 .50125 Mdot
.33817 .37877 Mdot
.50502 .72392 Mdot
.7156 .44614 Mdot
.29221 .49671 Mdot
.68142 .39313 Mdot
.47019 .72174 Mdot
.69837 .40441 Mdot
.29852 .53483 Mdot
.39428 .68045 Mdot
.63676 .65451 Mdot
.64392 .34401 Mdot
.35757 .33718 Mdot
.47856 .70895 Mdot
.33324 .6394 Mdot
.42762 .70013 Mdot
.65862 .36309 Mdot
.34419 .62897 Mdot
.34223 .3602 Mdot
.29899 .5497 Mdot
.62886 .66113 Mdot
.65555 .65968 Mdot
.7247 .51123 Mdot
.48878 .71038 Mdot
.35495 .64999 Mdot
.7004 .49019 Mdot
.71509 .47714 Mdot
.41791 .30365 Mdot
.66993 .61781 Mdot
.4387 .70143 Mdot
.28058 .52621 Mdot
.60424 .32523 Mdot
.38677 .68237 Mdot
.44702 .30137 Mdot
.396 .68781 Mdot
.29086 .56791 Mdot
.69895 .44645 Mdot
.2884 .55743 Mdot
.71208 .46642 Mdot
.52695 .29533 Mdot
.65026 .35625 Mdot
.2821 .53617 Mdot
.33054 .62732 Mdot
.35957 .33405 Mdot
.70719 .58055 Mdot
.6915 .40946 Mdot
.47207 .29427 Mdot
.28484 .52762 Mdot
.52574 .30006 Mdot
.72057 .53049 Mdot
.55958 .29668 Mdot
.49861 .71623 Mdot
.67672 .39823 Mdot
.53748 .28287 Mdot
.28465 .47363 Mdot
.63037 .65555 Mdot
.28711 .55412 Mdot
.55471 .7091 Mdot
.47587 .28934 Mdot
.47132 .27763 Mdot
.70431 .44956 Mdot
.44709 .30553 Mdot
.61247 .69323 Mdot
.29743 .55652 Mdot
.50102 .71965 Mdot
.40785 .30579 Mdot
.47443 .29893 Mdot
.29482 .44662 Mdot
.47458 .70647 Mdot
.39209 .69272 Mdot
.28516 .44822 Mdot
.32204 .36785 Mdot
.31311 .40304 Mdot
.67302 .36392 Mdot
.32099 .61351 Mdot
.30629 .58061 Mdot
.61552 .68407 Mdot
.51069 .28041 Mdot
.30527 .59025 Mdot
.54249 .70345 Mdot
.60913 .67543 Mdot
.65987 .36082 Mdot
.34995 .35221 Mdot
.45391 .71031 Mdot
.69118 .55898 Mdot
.32999 .63992 Mdot
.36166 .3379 Mdot
.70133 .43899 Mdot
.28156 .53212 Mdot
.57246 .70298 Mdot
.69767 .55856 Mdot
.70574 .47164 Mdot
.66789 .35086 Mdot
.6847 .62084 Mdot
.48574 .71348 Mdot
.57306 .30801 Mdot
.53788 .65996 Mdot
.37101 .57361 Mdot
.44407 .47131 Mdot
.30536 .54441 Mdot
.59511 .5679 Mdot
.48296 .64306 Mdot
.68607 .56414 Mdot
.47952 .57838 Mdot
.5971 .67257 Mdot
.53942 .61745 Mdot
.6246 .41851 Mdot
.45732 .53504 Mdot
.43545 .32131 Mdot
.66736 .47148 Mdot
.6373 .62795 Mdot
.33 .49055 Mdot
.66971 .52222 Mdot
.50786 .62458 Mdot
.67178 .46487 Mdot
.60658 .46484 Mdot
.55439 .33067 Mdot
.50101 .30415 Mdot
.60295 .41661 Mdot
.37589 .6496 Mdot
.54964 .64298 Mdot
.39771 .58783 Mdot
.6497 .57918 Mdot
.62746 .37765 Mdot
.68621 .5693 Mdot
.40132 .3833 Mdot
.61441 .57141 Mdot
.45168 .38018 Mdot
.45864 .66387 Mdot
.62798 .44762 Mdot
.39133 .58137 Mdot
.36862 .42996 Mdot
.5582 .68256 Mdot
.53439 .58825 Mdot
.59254 .59076 Mdot
.44273 .63798 Mdot
.62116 .55403 Mdot
.40936 .32395 Mdot
.6971 .47251 Mdot
.67691 .48365 Mdot
.4454 .36558 Mdot
.63739 .54194 Mdot
.47915 .57934 Mdot
.30652 .53791 Mdot
.59702 .56158 Mdot
.46641 .68659 Mdot
.69006 .45946 Mdot
.64804 .46763 Mdot
.63825 .39928 Mdot
.46016 .64967 Mdot
.65202 .41872 Mdot
.43692 .67156 Mdot
.51338 .62672 Mdot
.4918 .64625 Mdot
.60744 .4593 Mdot
.53741 .35316 Mdot
.61994 .33996 Mdot
.33333 .48808 Mdot
.5656 .44275 Mdot
.39848 .47007 Mdot
.65345 .48648 Mdot
.49533 .67614 Mdot
.67195 .57333 Mdot
.68431 .43772 Mdot
.58014 .35617 Mdot
.43978 .35004 Mdot
.60962 .4076 Mdot
.57303 .4466 Mdot
.63969 .53231 Mdot
.37812 .60324 Mdot
.5772 .60677 Mdot
.57822 .38096 Mdot
.59629 .66133 Mdot
.3507 .40746 Mdot
.53745 .52728 Mdot
.38396 .35942 Mdot
.48141 .65264 Mdot
.6167 .46285 Mdot
.43532 .56016 Mdot
.59778 .53275 Mdot
.39974 .64837 Mdot
.41125 .35356 Mdot
.55191 .64198 Mdot
.55534 .38382 Mdot
.66599 .53151 Mdot
.51845 .66662 Mdot
.65166 .42824 Mdot
.34265 .39695 Mdot
.4451 .41305 Mdot
.39343 .36897 Mdot
.48639 .5723 Mdot
.36911 .41705 Mdot
.62711 .44503 Mdot
.66883 .41612 Mdot
.48887 .30721 Mdot
.63057 .60241 Mdot
.46759 .3705 Mdot
.63917 .35803 Mdot
.53482 .32527 Mdot
.47933 .60433 Mdot
.62029 .61429 Mdot
.39551 .37401 Mdot
.58737 .36481 Mdot
.583 .52692 Mdot
.59549 .43622 Mdot
.5895 .58761 Mdot
.56698 .61402 Mdot
.67434 .51918 Mdot
.30865 .55625 Mdot
.60928 .63913 Mdot
.43894 .38346 Mdot
.6062 .37628 Mdot
.33082 .44237 Mdot
.53358 .69673 Mdot
.47195 .38802 Mdot
.58997 .6717 Mdot
.50974 .47277 Mdot
.66607 .55382 Mdot
.38536 .36284 Mdot
.69524 .54035 Mdot
.57158 .66456 Mdot
.60212 .41378 Mdot
.34855 .48903 Mdot
.67991 .52908 Mdot
.67374 .45452 Mdot
.5591 .32707 Mdot
.50172 .66202 Mdot
.36952 .36239 Mdot
.34831 .55607 Mdot
.39947 .44527 Mdot
.56268 .32403 Mdot
.38867 .4662 Mdot
.43399 .4382 Mdot
.39507 .33803 Mdot
.63503 .60922 Mdot
.43004 .42263 Mdot
.61577 .65725 Mdot
.57019 .37344 Mdot
.61949 .41397 Mdot
.54859 .654 Mdot
.31597 .55093 Mdot
.39955 .40327 Mdot
.45615 .43755 Mdot
.59297 .54744 Mdot
.69333 .54043 Mdot
.39185 .56252 Mdot
.62022 .43833 Mdot
.51956 .40869 Mdot
.52312 .35731 Mdot
.67173 .44775 Mdot
.6403 .3595 Mdot
.5012 .38373 Mdot
.41709 .54705 Mdot
.63039 .63822 Mdot
.50719 .42534 Mdot
.66847 .56011 Mdot
.49016 .41104 Mdot
.39923 .38131 Mdot
.56555 .32785 Mdot
.58756 .38621 Mdot
.64478 .52983 Mdot
.64083 .39955 Mdot
.58261 .62567 Mdot
.59032 .6239 Mdot
.49109 .36393 Mdot
.66669 .52117 Mdot
.62666 .47938 Mdot
.68701 .45889 Mdot
.50573 .61162 Mdot
.43064 .63082 Mdot
.36592 .55909 Mdot
.435 .51105 Mdot
.3376 .61552 Mdot
.36864 .43634 Mdot
.50608 .66516 Mdot
.32721 .59208 Mdot
.3745 .49641 Mdot
.38547 .58106 Mdot
.30471 .46244 Mdot
.35698 .56039 Mdot
.45548 .68093 Mdot
.56135 .54999 Mdot
.59107 .38178 Mdot
.46092 .45533 Mdot
.35607 .54392 Mdot
.65848 .56715 Mdot
.54881 .68395 Mdot
.38834 .36202 Mdot
.45172 .33698 Mdot
.50911 .64116 Mdot
.57891 .65233 Mdot
.56318 .31859 Mdot
.64098 .37655 Mdot
.43595 .32377 Mdot
.64541 .52875 Mdot
.67294 .56711 Mdot
.32478 .40624 Mdot
.60866 .49667 Mdot
.43282 .57201 Mdot
.4065 .62307 Mdot
.41919 .36276 Mdot
.57192 .56233 Mdot
.30907 .51036 Mdot
.45521 .61246 Mdot
.4415 .45413 Mdot
.39017 .40219 Mdot
.34598 .4218 Mdot
.342 .44099 Mdot
.67437 .49624 Mdot
.35929 .44247 Mdot
.3861 .38306 Mdot
.55134 .69174 Mdot
.56575 .48391 Mdot
.6581 .60701 Mdot
.39221 .52026 Mdot
.5371 .33094 Mdot
.56386 .42718 Mdot
.56172 .60993 Mdot
.46152 .65058 Mdot
.36764 .38811 Mdot
.45004 .67931 Mdot
.61338 .53678 Mdot
.43563 .38934 Mdot
.56706 .39657 Mdot
.46566 .38358 Mdot
.49718 .35719 Mdot
.50783 .57729 Mdot
.67399 .4582 Mdot
.36624 .64363 Mdot
.54222 .35083 Mdot
.63704 .57481 Mdot
.57719 .67012 Mdot
.53954 .32955 Mdot
.6139 .62484 Mdot
.60799 .60158 Mdot
.46368 .6388 Mdot
.40183 .55741 Mdot
.4675 .49081 Mdot
.54155 .59103 Mdot
.38474 .43531 Mdot
.54324 .39563 Mdot
.54376 .31776 Mdot
.48102 .32306 Mdot
.46853 .47549 Mdot
.56166 .47855 Mdot
.35419 .52496 Mdot
.57924 .34822 Mdot
.52714 .5599 Mdot
.37081 .58108 Mdot
.45959 .45213 Mdot
.51801 .63536 Mdot
.66958 .56348 Mdot
.41055 .55182 Mdot
.47624 .69301 Mdot
.43853 .36166 Mdot
.40045 .3336 Mdot
.48775 .35329 Mdot
.5576 .64867 Mdot
.65497 .40187 Mdot
.65538 .50868 Mdot
.36209 .50056 Mdot
.39551 .61061 Mdot
.49456 .54215 Mdot
.43111 .66351 Mdot
.61611 .3483 Mdot
.67705 .5502 Mdot
.57272 .63332 Mdot
.36112 .63077 Mdot
.43798 .5274 Mdot
.55358 .63195 Mdot
.37255 .48094 Mdot
.5822 .67393 Mdot
.69362 .52975 Mdot
.55574 .35728 Mdot
.50473 .30484 Mdot
.31824 .5048 Mdot
.56278 .45432 Mdot
.31087 .55906 Mdot
.47794 .33083 Mdot
.58477 .54123 Mdot
.45284 .66016 Mdot
.63473 .37884 Mdot
.51869 .36532 Mdot
.44558 .31825 Mdot
.4979 .35584 Mdot
.61651 .40896 Mdot
.65253 .49408 Mdot
.36052 .60317 Mdot
.62099 .58105 Mdot
.66617 .44231 Mdot
.37938 .63755 Mdot
.61747 .38219 Mdot
.60318 .54777 Mdot
.68783 .48977 Mdot
.44438 .68261 Mdot
.45347 .69301 Mdot
.34935 .45171 Mdot
.3698 .60336 Mdot
.43063 .47475 Mdot
.69451 .49336 Mdot
.33055 .54169 Mdot
.61893 .53679 Mdot
.65824 .61051 Mdot
.58124 .65457 Mdot
.67608 .53133 Mdot
.57839 .67113 Mdot
.47744 .31223 Mdot
.64927 .38269 Mdot
.55876 .6282 Mdot
.36899 .49936 Mdot
.40592 .40467 Mdot
.35789 .49445 Mdot
.58808 .64775 Mdot
.40511 .52534 Mdot
.66472 .57426 Mdot
.46604 .64979 Mdot
.55462 .5138 Mdot
.63546 .60351 Mdot
.45972 .60478 Mdot
.54563 .67705 Mdot
.63118 .63421 Mdot
.4601 .34825 Mdot
.33857 .49922 Mdot
.52905 .59521 Mdot
.4007 .66475 Mdot
.49881 .46609 Mdot
.48733 .60607 Mdot
.34137 .54187 Mdot
.51299 .60048 Mdot
.38016 .65435 Mdot
.67314 .40639 Mdot
.56761 .58741 Mdot
.52762 .40334 Mdot
.33764 .56888 Mdot
.45441 .66252 Mdot
.51731 .66418 Mdot
.67212 .45257 Mdot
.33579 .5115 Mdot
.4377 .34748 Mdot
.53488 .50664 Mdot
.3542 .53865 Mdot
.46201 .42559 Mdot
.34821 .46342 Mdot
.30995 .46418 Mdot
.49411 .35933 Mdot
.60025 .56676 Mdot
.32742 .5563 Mdot
.61096 .36627 Mdot
.43381 .50308 Mdot
.43624 .56675 Mdot
.55232 .35271 Mdot
.45082 .576 Mdot
.45883 .56012 Mdot
.47289 .45313 Mdot
.55912 .34481 Mdot
.56357 .57385 Mdot
.61155 .54793 Mdot
.68578 .55192 Mdot
.38272 .39689 Mdot
.55078 .61369 Mdot
.60943 .60561 Mdot
.53959 .4032 Mdot
.41835 .67978 Mdot
.42746 .51366 Mdot
.69115 .46637 Mdot
.52072 .4411 Mdot
.57164 .62002 Mdot
.40323 .33169 Mdot
.57937 .55749 Mdot
.46294 .4636 Mdot
.32826 .51625 Mdot
.32892 .5672 Mdot
.42361 .58909 Mdot
.38138 .3758 Mdot
.61933 .53464 Mdot
.59104 .64009 Mdot
.62353 .56069 Mdot
.39986 .63002 Mdot
.66686 .39163 Mdot
.43412 .34095 Mdot
.56859 .32207 Mdot
.65699 .56668 Mdot
.44573 .6089 Mdot
.36509 .36763 Mdot
.55523 .4861 Mdot
.61897 .49614 Mdot
.65916 .40696 Mdot
.58861 .35344 Mdot
.58511 .37154 Mdot
.41605 .50948 Mdot
.64293 .43794 Mdot
.542 .35408 Mdot
.61874 .62061 Mdot
.47736 .31437 Mdot
.54711 .36289 Mdot
.65493 .62363 Mdot
.57751 .38103 Mdot
.63905 .61855 Mdot
.64866 .42554 Mdot
.48345 .60118 Mdot
.58486 .54873 Mdot
.52115 .42493 Mdot
.60314 .63856 Mdot
.67069 .49904 Mdot
.5667 .50924 Mdot
.47852 .68475 Mdot
.5334 .67065 Mdot
.59952 .65952 Mdot
.40401 .59321 Mdot
.5779 .5247 Mdot
.3287 .55418 Mdot
.52821 .30658 Mdot
.38537 .62474 Mdot
.68963 .47525 Mdot
.53686 .69407 Mdot
.62545 .48434 Mdot
.56231 .68467 Mdot
.46363 .35131 Mdot
.62784 .48301 Mdot
.33822 .44677 Mdot
.3411 .38205 Mdot
.33622 .49822 Mdot
.5732 .60125 Mdot
.47727 .33138 Mdot
.53445 .33149 Mdot
.49924 .31898 Mdot
.3379 .43348 Mdot
.51886 .34357 Mdot
.38105 .63705 Mdot
.56437 .52422 Mdot
.38276 .60363 Mdot
.34998 .4937 Mdot
.53307 .34364 Mdot
.69112 .50595 Mdot
.41356 .40465 Mdot
.47907 .62561 Mdot
.60141 .3617 Mdot
.34182 .47296 Mdot
.45251 .69136 Mdot
.50298 .43963 Mdot
.60607 .44592 Mdot
.43916 .3104 Mdot
.32546 .455 Mdot
.55704 .65506 Mdot
.50532 .37905 Mdot
.56615 .66388 Mdot
.63998 .63858 Mdot
.62897 .42114 Mdot
.47977 .63599 Mdot
.35377 .62776 Mdot
.64251 .48634 Mdot
.36654 .36168 Mdot
.60011 .53951 Mdot
.67333 .41477 Mdot
.35092 .48148 Mdot
.48548 .36159 Mdot
.50934 .38302 Mdot
.33372 .45234 Mdot
.41912 .40412 Mdot
.41893 .41173 Mdot
.37131 .64604 Mdot
.50332 .63384 Mdot
.38006 .61238 Mdot
.39035 .39933 Mdot
.43701 .63311 Mdot
.442 .35093 Mdot
.56209 .31162 Mdot
.60786 .47055 Mdot
.67838 .54342 Mdot
.36185 .58389 Mdot
.36961 .59533 Mdot
.52659 .3669 Mdot
.66518 .53644 Mdot
.45458 .48975 Mdot
.45838 .43926 Mdot
.64635 .41606 Mdot
.41268 .6497 Mdot
.5133 .5882 Mdot
.32838 .46348 Mdot
.47736 .69277 Mdot
.30686 .50562 Mdot
.5896 .38516 Mdot
.61885 .5817 Mdot
.57494 .53764 Mdot
.66989 .56886 Mdot
.42355 .48101 Mdot
.35054 .59899 Mdot
.38848 .3931 Mdot
.57376 .53634 Mdot
.38608 .58784 Mdot
.35784 .46398 Mdot
.60774 .61028 Mdot
.65191 .54323 Mdot
.48886 .58237 Mdot
.59282 .46873 Mdot
.56495 .68902 Mdot
.60662 .40835 Mdot
.39366 .33571 Mdot
.33013 .52136 Mdot
.65199 .53592 Mdot
.36255 .59062 Mdot
.44071 .42696 Mdot
.57372 .41922 Mdot
.32784 .48413 Mdot
.57813 .3433 Mdot
.50707 .66609 Mdot
.61636 .38412 Mdot
.65955 .54735 Mdot
.61783 .49135 Mdot
.3691 .61202 Mdot
.33354 .49136 Mdot
.43555 .58824 Mdot
.54452 .53278 Mdot
.48012 .42471 Mdot
.51992 .68897 Mdot
.55108 .63991 Mdot
.40364 .56143 Mdot
.67977 .4429 Mdot
.33226 .46323 Mdot
.60599 .42811 Mdot
.35566 .45708 Mdot
.33022 .48093 Mdot
.684 .54448 Mdot
.57659 .63408 Mdot
.67308 .42733 Mdot
.35748 .53804 Mdot
.44292 .31048 Mdot
.48226 .69842 Mdot
.44995 .67739 Mdot
.45899 .59788 Mdot
.50628 .394 Mdot
.33907 .60499 Mdot
.54089 .67477 Mdot
.59889 .41839 Mdot
.58613 .6708 Mdot
.46838 .31679 Mdot
.50505 .57255 Mdot
.48674 .64702 Mdot
.41635 .48103 Mdot
.64905 .50011 Mdot
.50693 .63314 Mdot
.45048 .38155 Mdot
.39521 .5117 Mdot
.47382 .64218 Mdot
.48222 .64916 Mdot
.42571 .56243 Mdot
.63645 .59051 Mdot
.43175 .38295 Mdot
.59677 .37407 Mdot
.34208 .61222 Mdot
.43718 .6362 Mdot
.37111 .59174 Mdot
.58865 .54662 Mdot
.47293 .38041 Mdot
.33557 .38863 Mdot
.32566 .57467 Mdot
.42457 .64607 Mdot
.67302 .55241 Mdot
.50407 .53721 Mdot
.38963 .60257 Mdot
.38495 .61026 Mdot
.65932 .47902 Mdot
.58152 .53204 Mdot
.44924 .47308 Mdot
.696 .47841 Mdot
.62071 .35962 Mdot
.34874 .62871 Mdot
.32406 .58628 Mdot
.63902 .55699 Mdot
.41415 .58 Mdot
.5714 .36869 Mdot
.68366 .49976 Mdot
.31524 .5589 Mdot
.62588 .51641 Mdot
.35435 .61851 Mdot
.3849 .54306 Mdot
.33965 .60353 Mdot
.36682 .4268 Mdot
.6907 .52526 Mdot
.59113 .62975 Mdot
.64994 .46054 Mdot
.51832 .36794 Mdot
.55001 .5531 Mdot
.52233 .34054 Mdot
.45546 .40703 Mdot
.50122 .37136 Mdot
.46834 .63151 Mdot
.4767 .56052 Mdot
.61015 .39505 Mdot
.47735 .33328 Mdot
.60279 .37234 Mdot
.41835 .45778 Mdot
.57061 .44791 Mdot
.56184 .32487 Mdot
.50789 .43448 Mdot
.62807 .526 Mdot
.66286 .60361 Mdot
.49112 .54601 Mdot
.5544 .34137 Mdot
.69548 .46508 Mdot
.59416 .45108 Mdot
.50606 .64517 Mdot
.65437 .56778 Mdot
.43462 .38553 Mdot
.57984 .63897 Mdot
.60276 .38104 Mdot
.37463 .59359 Mdot
.55794 .39694 Mdot
.4408 .6559 Mdot
.3902 .46344 Mdot
.30077 .49351 Mdot
.39475 .44276 Mdot
.33542 .40756 Mdot
.40333 .66133 Mdot
.37601 .48781 Mdot
.41995 .35757 Mdot
.39558 .64644 Mdot
.52651 .42652 Mdot
.61975 .46163 Mdot
.68707 .46869 Mdot
.39097 .36324 Mdot
.34619 .5815 Mdot
.61398 .6338 Mdot
.58433 .3728 Mdot
.3231 .43473 Mdot
.3303 .49226 Mdot
.66287 .54254 Mdot
.54312 .43086 Mdot
.43206 .32164 Mdot
.53919 .50841 Mdot
.49082 .32966 Mdot
.59989 .53957 Mdot
.6602 .61417 Mdot
.39725 .37958 Mdot
.62583 .46841 Mdot
.52049 .42847 Mdot
.37489 .5855 Mdot
.46485 .64785 Mdot
.37622 .64232 Mdot
.36377 .54579 Mdot
.40666 .32543 Mdot
.37731 .57281 Mdot
.6276 .44037 Mdot
.42753 .59375 Mdot
.57236 .37197 Mdot
.4634 .32519 Mdot
.56886 .42761 Mdot
.65407 .41873 Mdot
.32721 .53699 Mdot
.42026 .40886 Mdot
.65155 .6138 Mdot
.57285 .67496 Mdot
.32617 .58093 Mdot
.52213 .34412 Mdot
.33794 .49976 Mdot
.38627 .56466 Mdot
.44972 .41074 Mdot
.44939 .34232 Mdot
.51252 .45915 Mdot
.53367 .30935 Mdot
.43342 .61951 Mdot
.61048 .6374 Mdot
.52104 .65397 Mdot
.6808 .44749 Mdot
.54949 .33993 Mdot
.55774 .62803 Mdot
.47752 .57309 Mdot
.50754 .41936 Mdot
.36601 .35885 Mdot
.64584 .56233 Mdot
.59535 .33113 Mdot
.46188 .66352 Mdot
.3321 .49904 Mdot
.61938 .65237 Mdot
.48598 .59835 Mdot
.53107 .57736 Mdot
.3397 .5256 Mdot
.67961 .5075 Mdot
.56901 .64042 Mdot
.50897 .67387 Mdot
.34289 .45095 Mdot
.54785 .59771 Mdot
.46373 .33099 Mdot
.62843 .3952 Mdot
.51628 .57379 Mdot
.49654 .32566 Mdot
.68289 .43144 Mdot
.3431 .44057 Mdot
.35599 .52924 Mdot
.31919 .44002 Mdot
.4507 .68801 Mdot
.45719 .60978 Mdot
.49343 .35781 Mdot
.54762 .55178 Mdot
.6764 .52941 Mdot
.50921 .65569 Mdot
.56499 .33836 Mdot
.3136 .50732 Mdot
.62153 .36715 Mdot
.61133 .45276 Mdot
.38795 .58161 Mdot
.3935 .59372 Mdot
.61555 .59437 Mdot
.59489 .54908 Mdot
.44936 .55647 Mdot
.58971 .46726 Mdot
.42519 .61779 Mdot
.45071 .33534 Mdot
.3272 .46792 Mdot
.54666 .68154 Mdot
.39603 .33321 Mdot
.47481 .66699 Mdot
.48774 .66974 Mdot
.59579 .41941 Mdot
.56737 .59583 Mdot
.53477 .41639 Mdot
.52372 .3973 Mdot
.63472 .35364 Mdot
.3244 .56188 Mdot
.57192 .6211 Mdot
.58738 .44969 Mdot
.65496 .45471 Mdot
.49605 .61267 Mdot
.41807 .32327 Mdot
.66504 .49389 Mdot
.54609 .33039 Mdot
.57762 .38043 Mdot
.66597 .47851 Mdot
.61273 .54099 Mdot
.62938 .60853 Mdot
.38528 .40578 Mdot
.61934 .4582 Mdot
.45375 .37746 Mdot
.67956 .49056 Mdot
.41386 .53601 Mdot
.43079 .67251 Mdot
.34764 .55716 Mdot
.40091 .48843 Mdot
.40975 .43335 Mdot
.34217 .46054 Mdot
.31074 .44407 Mdot
.32408 .58563 Mdot
.65108 .43609 Mdot
.32501 .52041 Mdot
.50509 .62933 Mdot
.30332 .51252 Mdot
.53862 .39632 Mdot
.54617 .59677 Mdot
.38748 .62944 Mdot
.46693 .44741 Mdot
.5122 .34676 Mdot
.61394 .60926 Mdot
.53262 .65463 Mdot
.44311 .34575 Mdot
.46253 .69241 Mdot
.5449 .68572 Mdot
.67038 .54019 Mdot
.46645 .30875 Mdot
.5198 .65763 Mdot
.32409 .45103 Mdot
.62739 .35773 Mdot
.6333 .37879 Mdot
.61882 .59048 Mdot
.50849 .37612 Mdot
.64742 .37276 Mdot
.66076 .57214 Mdot
.34376 .37713 Mdot
.61425 .35249 Mdot
.37709 .44293 Mdot
.62978 .64267 Mdot
.40102 .65798 Mdot
.41297 .4453 Mdot
.30698 .53325 Mdot
.4603 .35749 Mdot
.39024 .61796 Mdot
.60349 .46337 Mdot
.33234 .5184 Mdot
.61342 .39178 Mdot
.62163 .3807 Mdot
.67302 .52612 Mdot
.45242 .62627 Mdot
.64239 .38418 Mdot
.65531 .46862 Mdot
.44475 .66299 Mdot
.33541 .50474 Mdot
.3984 .43071 Mdot
.54598 .54665 Mdot
.45198 .43443 Mdot
.40601 .38108 Mdot
.52165 .33409 Mdot
.51995 .31408 Mdot
.49611 .30582 Mdot
.34531 .54007 Mdot
.56433 .41758 Mdot
.45331 .50253 Mdot
.34957 .44746 Mdot
.65376 .49611 Mdot
.62533 .46632 Mdot
.60238 .39073 Mdot
.45732 .61015 Mdot
.52955 .69674 Mdot
.33429 .45947 Mdot
.39342 .52789 Mdot
.54574 .328 Mdot
.67387 .49956 Mdot
.65183 .4353 Mdot
.32749 .49109 Mdot
.44336 .5516 Mdot
.38546 .49118 Mdot
.33618 .58453 Mdot
.38531 .35701 Mdot
.62465 .61039 Mdot
.34049 .5928 Mdot
.32567 .40815 Mdot
.66418 .45439 Mdot
.52817 .37691 Mdot
.69032 .44765 Mdot
.6038 .35699 Mdot
.37055 .5429 Mdot
.3318 .53481 Mdot
.59285 .46108 Mdot
.68251 .55096 Mdot
.46089 .63648 Mdot
.61675 .44324 Mdot
.6198 .38504 Mdot
.41928 .60992 Mdot
.67335 .40668 Mdot
.42604 .468 Mdot
.69445 .45541 Mdot
.46859 .35915 Mdot
.32531 .48342 Mdot
.50278 .68106 Mdot
.35572 .42276 Mdot
.55461 .6846 Mdot
.47576 .61241 Mdot
.47203 .66807 Mdot
.35879 .59528 Mdot
.61962 .43946 Mdot
.32638 .51737 Mdot
.42097 .59499 Mdot
.32623 .47805 Mdot
.38377 .34944 Mdot
.69965 .5062 Mdot
.42145 .55874 Mdot
.36286 .56802 Mdot
.5423 .61429 Mdot
.57939 .59961 Mdot
.64709 .41591 Mdot
.48634 .32815 Mdot
.6347 .49314 Mdot
.49595 .69837 Mdot
.44389 .43914 Mdot
.48586 .36616 Mdot
.61857 .48961 Mdot
.48164 .36612 Mdot
.42303 .45231 Mdot
.43942 .68029 Mdot
.34956 .61715 Mdot
.59165 .64181 Mdot
.37386 .51807 Mdot
.32626 .59368 Mdot
.30408 .51795 Mdot
.59799 .67319 Mdot
.61656 .34777 Mdot
.33866 .57006 Mdot
.61813 .37084 Mdot
.46118 .36153 Mdot
.46918 .66367 Mdot
.36774 .58999 Mdot
.63384 .3819 Mdot
.50459 .69375 Mdot
.37166 .58423 Mdot
.58914 .32486 Mdot
.64013 .42536 Mdot
.3909 .33531 Mdot
.6551 .57075 Mdot
.52293 .62937 Mdot
.5605 .687 Mdot
.307 .48104 Mdot
.62625 .43119 Mdot
.61315 .59441 Mdot
.66984 .5387 Mdot
.60386 .38135 Mdot
.41778 .41453 Mdot
.65801 .54005 Mdot
.45132 .32851 Mdot
.37671 .61201 Mdot
.44219 .43199 Mdot
.57089 .61256 Mdot
.40405 .53962 Mdot
.41099 .38531 Mdot
.31788 .48036 Mdot
.30577 .4575 Mdot
.40555 .51107 Mdot
.42378 .36168 Mdot
.61672 .34626 Mdot
.36567 .35634 Mdot
.56921 .59202 Mdot
.50207 .64398 Mdot
.40673 .49443 Mdot
.57326 .54469 Mdot
.67767 .58611 Mdot
.33428 .56297 Mdot
.39102 .46097 Mdot
.64967 .40226 Mdot
.5792 .53929 Mdot
.50906 .62069 Mdot
.52149 .61241 Mdot
.39916 .41896 Mdot
.67936 .58796 Mdot
.37701 .64862 Mdot
.32223 .42561 Mdot
.47323 .68515 Mdot
.3049 .51074 Mdot
.54813 .41329 Mdot
.66659 .42978 Mdot
.63118 .43077 Mdot
.61323 .36862 Mdot
.4544 .39527 Mdot
.40372 .37862 Mdot
.67198 .59023 Mdot
.35976 .43325 Mdot
.48912 .44847 Mdot
.666 .50797 Mdot
.39023 .54028 Mdot
.32844 .48227 Mdot
.43535 .44416 Mdot
.33055 .40701 Mdot
.43625 .33702 Mdot
.47378 .37667 Mdot
.65688 .50594 Mdot
.66528 .58211 Mdot
.64948 .42865 Mdot
.36359 .4977 Mdot
.5385 .65925 Mdot
.31889 .50564 Mdot
.51611 .35999 Mdot
.59272 .48749 Mdot
.57294 .60711 Mdot
.40596 .56943 Mdot
.33538 .53768 Mdot
.41868 .32106 Mdot
.40519 .52551 Mdot
.41519 .43098 Mdot
.33883 .47026 Mdot
.6487 .61692 Mdot
.49345 .51468 Mdot
.42829 .43991 Mdot
.3347 .44795 Mdot
.36525 .35221 Mdot
.3864 .58961 Mdot
.51914 .6847 Mdot
.6661 .42122 Mdot
.32028 .43979 Mdot
.32883 .53115 Mdot
.66523 .43783 Mdot
.58905 .46623 Mdot
.59783 .33848 Mdot
.43299 .43254 Mdot
.52753 .67874 Mdot
.63637 .57163 Mdot
.34937 .39992 Mdot
.46517 .42185 Mdot
.37538 .65108 Mdot
.50317 .3659 Mdot
.53186 .41699 Mdot
.46508 .66909 Mdot
.59787 .38982 Mdot
.4129 .63707 Mdot
.66198 .52976 Mdot
.46672 .353 Mdot
.56143 .32325 Mdot
.37146 .34933 Mdot
.52145 .58333 Mdot
.6847 .44547 Mdot
.56119 .41592 Mdot
.55132 .65981 Mdot
.57242 .51948 Mdot
.67103 .40335 Mdot
.57758 .65517 Mdot
.36869 .4299 Mdot
.55475 .57272 Mdot
.63014 .34952 Mdot
.42751 .60804 Mdot
.50714 .54676 Mdot
.57725 .58669 Mdot
.48665 .59786 Mdot
.48386 .57437 Mdot
.64594 .56983 Mdot
.5013 .52659 Mdot
.59566 .63682 Mdot
.62896 .55677 Mdot
.40137 .44987 Mdot
.6107 .43796 Mdot
.4726 .38938 Mdot
.32279 .4102 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0?ooooooB_ooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A006ooooo`03o`000?oooooooooo0?ooooooB_ooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0?ooooooB_oo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06
ooooo`?o0000oooooom:ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<oooo
o`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom:ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001_ooool00ol0003oooooooooo`3ooooood[ooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo09Kooooo2Ol000000ooooooo0000o`000007o`000:3ooooo
000Looooo`03o`000?oooooooooo09;ooooo6ol0002Looooo`007?ooool00ol0003oooooooooo`2=
ooooob3o000000?oooooo`000?l000001?l0002Eooooo`007?ooool00ol0003oooooooooo`29oooo
obko0000T_ooool001cooooo00?o0000ooooooooool0Q_oooolbo`00097ooooo000Looooo`03o`00
0?oooooooooo08Cooooo>?l0002=ooooo`007?ooool00ol0003oooooooooo`22ooooob[o000000?o
ooooo`000?l000003ol0002;ooooo`007?ooool00ol0003oooooooooo`20ooooocoo0000R_ooool0
01cooooo0_l0001oooooodGo0000Q_ooool001cooooo00?o0000ooooooooool0NooooolPo`000004
ooooool0003o0000ooooo`Co000000?oooooo`000?l000007_l00025ooooo`007?ooool00ol0003o
ooooooooo`1joooooaKo000000Goooooo`000?l0003o0000ooooo`02o`0000Cooooo1ol00006oooo
o`;o000000?oooooo`000?l000006?l00024ooooo`007?ooool00ol0003oooooooooo`1joooooaKo
00001?ooool2o`0000Gooooo1?l000000ooooooo0000o`000006ooooo`Co00000ooooolIo`00087o
oooo000Looooo`03o`000?oooooooooo07Oooooo5ol00006ooooo`;o000000?oooooo`000?l00000
4Oooool2o`0000Oooooo5Ol00021ooooo`007?ooool00ol0003oooooooooo`1eoooooaGo00002_oo
ool2o`000003ooooool0003o000000cooooo0_l0000<ooooo`;o000000?oooooo`000?l000004Ol0
0020ooooo`007?ooool00ol0003oooooooooo`1doooooa?o00001_ooool2o`0000Gooooo0_l00000
0ooooooo0000o`000005ooooo`;o00001Oooool2o`0000Kooooo0_l00004ooooo`;o00001?oooolB
o`0007kooooo000Looooo`03o`000?oooooooooo07Cooooo4_l00003ooooo`?o000000?oooooo`00
0?l000002Oooool2o`0000Cooooo0_l0000=ooooo`;o00001?ooool4o`0000Cooooo4_l0001loooo
o`007?ooool00ol0003oooooooooo`1boooooa7o000000?oooooo`000?l000000oooool3o`0000Oo
oooo0_l00003ooooo`;o00001?ooool2o`0000[ooooo0_l00007ooooo`Co00001OoooolAo`0007co
oooo000Looooo`03o`000?oooooooooo073ooooo4ol000000ooooooo0000o`000004ooooo`;o0000
0oooool2o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`0000[ooooo0_l00002ooooo`;o0000
0_ooool4o`0000Kooooo0_l00002ooooo`ko0000Noooool001cooooo00?o0000ooooooooool0Kooo
oolBo`0000kooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000;o00003?oo
ool3o`000003ooooool0003o000000Ko00002?ooool2o`000003ooooool0003o000000co0000N_oo
ool001cooooo00?o0000ooooooooool0KOoooolDo`0000kooooo0_l00002ooooo`;o00000_ooool2
o`0000?ooooo0_l00008ooooo`;o00000_ooool3o`000003ooooool0003o000000;o00003?ooool2
o`0000;ooooo3_l0001iooooo`007?ooool00ol0003oooooooooo`1]oooooa?o00002_ooool2o`00
00?ooooo0_l00006ooooo`;o00003Oooool2o`0000cooooo0_l00008ooooo`;o00000oooool>o`00
07Sooooo000Looooo`03o`000?oooooooooo06cooooo3_l00002ooooo`?o00002_ooool3o`0000?o
oooo0_l0000Eooooo`;o00001oooool3o`0000;ooooo0_l00008ooooo`;o00001Oooool?o`0007Go
oooo000Looooo`03o`000?oooooooooo06[ooooo3ol0000@ooooo`;o00000oooool2o`0001Gooooo
0ol000000ooooooo0000o`000004ooooo`Go00001?ooool2o`0000cooooo3_l0001eooooo`007?oo
ool00ol0003oooooooooo`1Yooooo`oo00004_ooool6o`0001?ooooo1Ol000000ooooooo0000o`00
0007ooooo`;o00001?ooool2o`0000[ooooo4Ol0001dooooo`007?ooool2o`0006[ooooo3_l00002
ooooo`;o00003oooool4o`0000Cooooo0_l0000?ooooo`;o00001oooool2o`0000[ooooo0_l0000:
ooooo`?o000000?oooooo`000?l000003Ol0001booooo`007?ooool00ol0003oooooooooo`1Yoooo
o`ko00000_ooool2o`0000Oooooo0_l00007ooooo`?o00001?ooool4o`0000Gooooo0_l0000>oooo
o`?o00000_ooool2o`0000Kooooo0_l000000ooooooo0000o`000007ooooo`;o00000oooool?o`00
077ooooo000Looooo`03o`000?oooooooooo06Oooooo3_l00004ooooo`;o00001oooool2o`0000oo
oooo0ol00005ooooo`;o000000?oooooo`000?l000002oooool3o`0000;ooooo0_l00007ooooo`Co
00000oooool2o`0000;ooooo0_l00004ooooo`ko0000LOooool001cooooo00?o0000ooooooooool0
I_ooool?o`0000Cooooo0_l0000:ooooo`;o00002oooool4o`0000Oooooo0ol00004ooooo`Co0000
1?ooool2o`0000?ooooo0_l00006ooooo`;o00001Oooool2o`0000Cooooo1?l00002ooooo`go0000
L?ooool001cooooo00?o0000ooooooooool0IOooool=o`000004ooooool0003o0000o`0000?ooooo
1?l00007ooooo`Co00000oooool2o`0000Gooooo1?l00004ooooo`;o000000Coooooo`000?l0003o
00001?ooool4o`0000Kooooo0_l000000ooooooo0000o`00000=ooooo`;o00001?ooool4o`0000;o
oooo3_l0001_ooooo`007?ooool00ol0003oooooooooo`1Uooooo`_o00000oooool3o`0000?ooooo
1?l00007ooooo`Co00000oooool4o`0000?ooooo0_l00005ooooo`Go00000_ooool2o`0000?ooooo
0_l00007ooooo`;o00002oooool2o`0000?ooooo0_l000000ooooooo0000o`00000:ooooo`_o0000
Koooool001cooooo00?o0000ooooooooool0I?ooool<o`0000?ooooo0_l00007ooooo`;o00003ooo
ool2o`0000[ooooo1Ol00002ooooo`;o00000oooool4o`0000gooooo0_l00003ooooo`;o00001_oo
ool2o`000003ooooool0003o000000Sooooo2ol0001^ooooo`007?ooool00ol0003oooooooooo`1S
ooooo`co00001?ooool2o`0000Oooooo0_l0000Fooooo`;o00002Oooool2o`0000Cooooo1?l0000=
ooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`000003o`0000Wooooo2ol0001]
ooooo`007?ooool00ol0003oooooooooo`1Rooooo`go00003_ooool2o`0001Gooooo0_l00009oooo
o`;o00005?ooool3o`0000;ooooo0_l00002ooooo`Co00000oooool2o`0000Sooooo3Ol0001]oooo
o`007?ooool00ol0003oooooooooo`1Rooooo`co00002_ooool2o`0000?ooooo1?l0000?ooooo`;o
00001?ooool2o`0000Wooooo0_l00005ooooo`;o00002oooool2o`0000?ooooo0_l00002ooooo`;o
000000?oooooo`000?l000001Oooool2o`0000;ooooo0_l000000ooooooo0000o`00000<o`0006co
oooo000Looooo`03o`000?oooooooooo067ooooo3Ol0000:ooooo`;o00000oooool5o`0000gooooo
0ol00004ooooo`;o00002?ooool3o`0000Gooooo0_l0000>ooooo`;o00000_ooool2o`0000;ooooo
0ol00003ooooo`So00001Oooool;o`0006_ooooo000Looooo`03o`000?oooooooooo063ooooo3Ol0
000=ooooo`;o000000?oooooo`000?l000000ol00006ooooo`;o000000?oooooo`000?l000000_oo
ool2o`0000?ooooo1?l00007ooooo`Go00003Oooool2o`0000Gooooo0_l00002ooooo`;o00000_oo
ool2o`0000;ooooo1?l00002ooooo`;o000000?oooooo`000?l000000_l00002ooooo`_o0000Jooo
ool001cooooo00?o0000ooooooooool0H?ooool=o`0000gooooo0_l00003ooooo`;o000000?ooooo
o`000?l000001?ooool5o`0000Oooooo0_l00009ooooo`;o000000?oooooo`000?l000003Oooool2
o`0000Sooooo0ol00006ooooo`Co00000_ooool2o`000003ooooool0003o000000;o00000_ooool=
o`0006Wooooo000Looooo`03o`000?oooooooooo063ooooo2ol00009ooooo`;o00003?ooool2o`00
00Gooooo0ol0000:ooooo`;o00008oooool7o`0000Cooooo0_l0000=ooooo`_o0000JOooool00006
ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04
ooooo`03o`000?oooooooooo05kooooo3Ol00009ooooo`;o00001?ooool2o`0000kooooo0_l0000:
ooooo`;o00002Oooool2o`0001_ooooo1?l000000ooooooo0000o`00000@ooooo`_o0000JOooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1Nooooo`co00000_ooool2o`0000_ooooo0ol0000Dooooo`;o00003ooo
ool2o`0000Sooooo1?l00002ooooo`;o000000?oooooo`000?l000003?ooool3o`0000?ooooo0_l0
000;ooooo`_o0000JOooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool5
o`0000Kooooo00?o0000ooooooooool0G_ooool;o`0000?ooooo1?l00009ooooo`Co00004oooool2
o`0001Cooooo0_l00003ooooo`Co00000_ooool2o`000003ooooool0003o000000cooooo0_l00004
ooooo`;o00000_ooool2o`0000Wooooo2ol0001Wooooo`0000?oooooo`000?ooool00_ooool00ol0
003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0001Nooooo`_o00001Oooool2
o`0000_ooooo0_l000000ooooooo0000o`00000Vooooo`Co00000_ooool2o`0001kooooo0_l00000
0ooooooo0000o`000002o`0000?ooooo3?l0001Wooooo`0000?oooooo`000?ooool00_ooool00ol0
003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0G?ooool<
o`00017ooooo1?l000000ooooooo0000o`000002o`000004ooooool0003o0000o`0002;ooooo0_l0
0002ooooo`;o00008Oooool4o`0000?ooooo3?l0001Wooooo`0000?ooooooa0@4?ooool00_ooool0
0ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0G?ooool?
o`0000?ooooo0_l00009ooooo`;o00001Oooool2o`000003ooooool0003o000000;o00002Oooool2
o`0001?ooooo0_l0000Jooooo`Go00003?ooool2o`0000?ooooo3?l0001Vooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0G?oo
ool?o`0000?ooooo0_l0000Dooooo`?o00001oooool4o`0000Wooooo0_l00008ooooo`;o00006_oo
ool5o`0000cooooo0_l00003ooooo`co0000I_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^
3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo05cooooo2ol0000Mooooo`;o0000
1oooool3o`0000_ooooo0_l0000Aooooo`;o00004?ooool2o`0000?ooooo0_l0000@ooooo`co0000
I_ooool001cooooo00?o0000ooooooooool0Foooool;o`0000kooooo0_l0000>ooooo`;o00001ooo
ool2o`0001[ooooo0ol00002ooooo`;o00000oooool3o`0000Wooooo0ol00003ooooo`Co00001Ooo
ool5o`0000;ooooo1?l000000ooooooo0000o`000008o`0006Gooooo000Looooo`03o`000?oooooo
oooo05_ooooo2_l00008ooooo`;o00001Oooool2o`0000Sooooo0_l0000Qooooo`;o00001_ooool3
o`0000Oooooo0ol000000ooooooo0000o`000005ooooo`Co00001Oooool4o`0000?ooooo1Ol00002
ooooo`;o00000oooool;o`0006Cooooo000Looooo`03o`000?oooooooooo05[ooooo2ol00008oooo
o`;o000000?oooooo`000?l000003?ooool2o`0000Sooooo0_l00009ooooo`;o00000oooool2o`00
00Oooooo0_l0000Dooooo`;o00001Oooool2o`0000Wooooo0_l0000:ooooo`;o00000oooool;o`00
06Cooooo000Looooo`03o`000?oooooooooo05[ooooo2_l000000ooooooo0000o`000009ooooo`;o
000000?oooooo`000?l000004oooool2o`000003ooooool0003o000000Gooooo0ol00003ooooo`;o
00001oooool2o`0000?ooooo0ol0000:ooooo`Co00005Oooool2o`000003ooooool0003o000000Ko
oooo0_l00002ooooo`[o0000I?ooool001cooooo00?o0000ooooooooool0F_ooool:o`000003oooo
ool0003o000000cooooo0ol00008ooooo`;o00000oooool2o`0000Kooooo0_l00005ooooo`;o0000
3Oooool2o`0000;ooooo1?l00004ooooo`;o00001?ooool4o`0000[ooooo0_l00006ooooo`;o0000
00Coooooo`000?l0003ooooo0ol00003ooooo`Co00000_ooool;o`0006?ooooo000Looooo`03o`00
0?oooooooooo05[ooooo2_l00006ooooo`;o00001Oooool2o`000003ooooool0003o000000Sooooo
0_l000000ooooooo0000o`000002o`0000Cooooo0_l000000ooooooo0000o`00000Gooooo`;o0000
1_ooool2o`0001;ooooo0_l00005ooooo`?o00001?ooool3o`0000?ooooo0_l00003ooooo`co0000
Hoooool001cooooo00?o0000ooooooooool0FOooool:o`0000;ooooo0_l00003ooooo`;o00001Ooo
ool2o`000003ooooool0003o000000?ooooo0_l00006ooooo`;o00001_ooool2o`000004ooooool0
003o0000ooooo`;o00004?ooool2o`0001_ooooo0_l00008ooooo`;o00001_ooool2o`0000Sooooo
0_l000000ooooooo0000o`000007o`0006?ooooo000Looooo`03o`000?oooooooooo05Wooooo2_l0
00001?oooooo0000o`000?l0000=ooooo`;o00000oooool2o`0000cooooo1?l000001?oooooo0000
o`000?ooool4o`0000gooooo0ol0000Kooooo`;o00000oooool5o`0000Gooooo0_l000000ooooooo
0000o`000002ooooo`;o00001?ooool2o`000003ooooool0003o000000So0000H_ooool001cooooo
00?o0000ooooooooool0F?ooool;o`000003ooooool0003o000000;ooooo0_l000001?oooooo0000
o`000?l00003ooooo`;o00001?ooool2o`0000?ooooo0_l00009ooooo`Co000000?oooooo`000?l0
00000_ooool3o`0000gooooo0_l00003ooooo`;o00003Oooool2o`0000gooooo1ol00003ooooo`;o
00001Oooool3o`0000;ooooo0ol000000ooooooo0000o`000008o`0006;ooooo000Looooo`03o`00
0?oooooooooo05Sooooo2ol00005ooooo`;o000000Coooooo`000?l0003o00000oooool2o`0000Co
oooo0_l00003ooooo`Co00000_ooool2o`0000Kooooo0_l0000Iooooo`;o00003Oooool2o`0000_o
oooo0_l00002ooooo`;o000000?oooooo`000?l000002oooool2o`0000;ooooo3_l0001Rooooo`00
7?ooool00ol0003oooooooooo`1Hooooo`_o00001_ooool3o`0000;ooooo0_l0000>ooooo`;o0000
0_ooool2o`0000Kooooo0_l00008ooooo`;o00001Oooool2o`0001Wooooo0_l00009ooooo`;o0000
1Oooool2o`0000cooooo0_l000000ooooooo0000o`00000=o`00067ooooo000Looooo`;o0000FOoo
ool:o`0000Cooooo0_l000000ooooooo0000o`000005o`0000oooooo0_l00005ooooo`;o00002_oo
ool4o`0000Gooooo0_l0000Iooooo`;o00000oooool4o`0000Wooooo0_l0000<ooooo`Go000000?o
ooooo`000?l000002_l0001Qooooo`007?ooool00ol0003oooooooooo`1Hooooo`Wo00001Oooool2
o`000004ooooool0003o0000ooooo`Co00003oooool2o`0000Gooooo0_l00004ooooo`;o00001?oo
ool2o`0000;ooooo0_l0000Kooooo`;o00001_ooool4o`0000Cooooo0_l0000<ooooo`;o000000Co
ooooo`000?l0003ooooo0_l00005ooooo`Co000000?oooooo`000?l000000ol0001Qooooo`007?oo
ool00ol0003oooooooooo`1Gooooo`_o00001?ooool2o`0000Sooooo0_l0000Booooo`;o00001_oo
ool2o`0000Cooooo0_l00002ooooo`;o00006oooool2o`0000kooooo1?l0000:ooooo`;o000000Co
ooooo`000?l0003ooooo0_l00005ooooo`[o0000HOooool001cooooo00?o0000ooooooooool0Eooo
ool;o`0000Oooooo1?l00003ooooo`;o00002Oooool2o`0000Oooooo0_l0000Mooooo`;o00006?oo
ool2o`0000?ooooo0_l000001?oooooo0000o`000?l00007ooooo`;o00001_ooool2o`0000;ooooo
3Ol0001Qooooo`007?ooool00ol0003oooooooooo`1Gooooo`co00001?ooool8o`0000;ooooo0_l0
0008ooooo`;o00005_ooool2o`0000kooooo0_l0000Hooooo`;o000000?oooooo`000?l000000_l0
00001?oooooo0000o`000?l00007ooooo`;o00001Oooool2o`0000?ooooo0ol000000ooooooo0000
o`000007o`00067ooooo000Looooo`03o`000?oooooooooo05Oooooo3?l00004ooooo`?o00000ooo
ool2o`0000;ooooo0_l00008ooooo`;o00002_ooool2o`0000[ooooo0_l00009ooooo`;o00007?oo
ool2o`0000;ooooo0ol00002ooooo`Co00001_ooool2o`0000Gooooo0_l00005ooooo`[o0000H_oo
ool001cooooo00?o0000ooooooooool0Eoooool9o`0000Oooooo0_l000000ooooooo0000o`00000?
ooooo`;o000000?oooooo`000?l000001oooool2o`0001Gooooo0_l0000Looooo`?o00000oooool2
o`0000?ooooo0ol00005ooooo`Co00002?ooool=o`00067ooooo000Looooo`03o`000?oooooooooo
05Sooooo2?l0000:ooooo`?o00004Oooool2o`0000cooooo1?l0000Booooo`;o00006Oooool2o`00
00?ooooo0_l00004ooooo`;o00001oooool2o`0000;ooooo0_l00004ooooo`;o00000_ooool:o`00
063ooooo000Looooo`03o`000?oooooooooo05Oooooo2?l0000<ooooo`;o00006oooool2o`0000;o
oooo1?l00004ooooo`;o00003?ooool2o`00037ooooo0_l00005ooooo`;o000000?oooooo`000?l0
00002?l0001Pooooo`007?ooool00ol0003oooooooooo`1Fooooo`[o00001?ooool4o`00023ooooo
0_l0000:ooooo`;o00007Oooool2o`0001?ooooo0_l00008ooooo`;o000000?oooooo`000?l00000
1Oooool=o`00063ooooo000Looooo`03o`000?oooooooooo05Kooooo3?l00002ooooo`Ko00001?oo
ool2o`0000Gooooo0_l0000=ooooo`Co0000:oooool2o`0001?ooooo0_l00008ooooo`;o000000?o
ooooo`000?l000001oooool:o`00067ooooo000Looooo`03o`000?oooooooooo05Kooooo3?l00004
ooooo`Co00001?ooool2o`0000Gooooo0_l0000=ooooo`Co0000:Oooool2o`000003ooooool0003o
0000017ooooo0ol00003ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Kooooo2Ol0001P
ooooo`007?ooool00ol0003oooooooooo`1Fooooo`[o00001oooool4o`0000;ooooo0_l00007oooo
o`;o00001_ooool2o`00037ooooo0_l000000ooooooo0000o`000007ooooo`;o00002?ooool2o`00
00Cooooo0_l000000ooooooo0000o`000006ooooo`;o00001_ooool9o`00063ooooo000Looooo`03
o`000?oooooooooo05Kooooo2Ol00008ooooo`Co00000_ooool2o`0000Oooooo0_l000000ooooooo
0000o`000003ooooo`;o00004?ooool2o`0000;ooooo0_l0000Wooooo`;o00001_ooool2o`0001;o
oooo0_l000000ooooooo0000o`000002ooooo`Wo0000H?ooool001cooooo00?o0000ooooooooool0
E_ooool:o`0000Oooooo1?l00003ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Gooooo
0_l0000>ooooo`;o00000_ooool2o`0002oooooo0_l00003ooooo`;o00001?ooool2o`0000;ooooo
0_l00003ooooo`;o000000?oooooo`000?l000003?l0001Oooooo`007?ooool00ol0003ooooooooo
o`1Fooooo`[o00002Oooool2o`0000?ooooo0_l000001?oooooo0000o`000?l00002ooooo`;o0000
2?ooool2o`00043ooooo0_l000000ooooooo0000o`000003ooooo`;o00001?ooool3o`000004oooo
ool0003o0000ooooo`;o00001Oooool<o`0005oooooo000Looooo`;o0000Eoooool9o`0000Wooooo
1?l00006ooooo`Ko0000B_ooool2o`000003ooooool0003o000000Sooooo1?l00003ooooo`?o0000
00?oooooo`000?l000001?ooool:o`0005oooooo000Looooo`03o`000?oooooooooo05Oooooo2?l0
0005ooooo`;o00000_ooool4o`0000Kooooo1?l0000Cooooo`;o00001?ooool2o`0003kooooo0_l0
0005ooooo`?o000000?oooooo`000?l000001?ooool:o`0005oooooo000Looooo`03o`000?oooooo
oooo05Kooooo2Ol000000ooooooo0000o`000004o`0000?ooooo0_l0000Nooooo`;o00001?ooool2
o`0001Wooooo0_l0000Vooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo3Ol0001O
ooooo`007?ooool00ol0003oooooooooo`1Foooooa3o00006_ooool2o`000003ooooool0003o0000
00Gooooo0_l0000Nooooo`?o00001oooool2o`0001_ooooo0ol000000ooooooo0000o`000002oooo
o`;o00000_ooool=o`0005oooooo000Looooo`03o`000?oooooooooo05Kooooo3Ol00006ooooo`;o
00004_ooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`000003ooooool0003o0000
01oooooo0_l00003ooooo`;o00000_ooool2o`0001_ooooo0_l0000=ooooo`[o0000Goooool001co
oooo00?o0000ooooooooool0Eoooool:o`0000Kooooo1?l0000Booooo`;o00002?ooool2o`0001Co
oooo0_l0000Aooooo`;o00005_ooool2o`0001Kooooo2_l0001Oooooo`007?ooool00ol0003ooooo
ooooo`1Gooooo`[o00001Oooool4o`0000cooooo0_l00004ooooo`;o00007oooool2o`0001Oooooo
0_l0000@ooooo`;o00003Oooool2o`0000Kooooo2_l0001Pooooo`007?ooool00ol0003ooooooooo
o`1Fooooo`_o00001Oooool4o`0000cooooo0_l00004ooooo`;o0000>?ooool2o`0001gooooo1?l0
0006ooooo`[o0000H?ooool001cooooo00?o0000ooooooooool0E_ooool:o`0000Sooooo0_l00000
0ooooooo0000o`000002ooooo`;o00003oooool2o`0003;ooooo0_l00002ooooo`;o00003_ooool2
o`0000_ooooo1?l00004ooooo`co0000H?ooool001cooooo00?o0000ooooooooool0Eoooool9o`00
00_ooooo0_l00002ooooo`?o00002_ooool2o`0000;ooooo0_l00009ooooo`;o00004_ooool2o`00
00[ooooo0_l00007ooooo`;o00000_ooool4o`0000cooooo0_l00004ooooo`;o00001oooool4o`00
00;ooooo3?l0001Pooooo`007?ooool00ol0003oooooooooo`1Gooooo`Wo00001oooool2o`0000Oo
oooo0_l0000:ooooo`;o00003Oooool2o`0001;ooooo0_l0000:ooooo`;o00003?ooool3o`00013o
oooo1?l00003ooooo`Co000000Coooooo`000?l0003o00000oooool;o`00063ooooo000Looooo`03
o`000?oooooooooo05Sooooo2_l00005ooooo`?o00009oooool2o`0001[ooooo0_l0000:ooooo`;o
00000oooool2o`0000Gooooo0_l00005ooooo`Co00000oooool4o`000003ooooool0003o000000Co
oooo2ol0001Pooooo`007?ooool00ol0003oooooooooo`1Hooooo`[o00001Oooool4o`0000Cooooo
0ol0000Aooooo`;o00003?ooool2o`0000gooooo0_l0000;ooooo`;o00002?ooool2o`0000Gooooo
0_l00003ooooo`Co00002Oooool2o`0000;ooooo1?l00007ooooo`Wo0000HOooool001cooooo00?o
0000ooooooooool0Eoooool;o`0000Gooooo1ol000001?oooooo0000o`000?l00009ooooo`;o0000
0oooool2o`000003ooooool0003o000001_ooooo0_l0000Eooooo`Go00000oooool2o`0000;ooooo
1?l00004ooooo`;o00000oooool8o`0000Gooooo2ol0001Qooooo`007?ooool00ol0003ooooooooo
o`1Gooooo`[o00001oooool2o`000004ooooool0003o0000o`0000;ooooo0_l00003ooooo`;o0000
0_ooool4o`0000?ooooo0_l0000Kooooo`;o00005oooool6o`0000?ooooo0_l00002ooooo`;o0000
1_ooool2o`0000?ooooo2?l000001Ooooooo0000o`000?l0003ooooo00_o0000HOooool001cooooo
00?o0000ooooooooool0Eoooool:o`0000oooooo1?l000000ooooooo0000o`000002ooooo`;o0000
2Oooool2o`0001Kooooo0ol00002ooooo`;o00002oooool2o`0000Kooooo0_l00003ooooo`Co0000
00Coooooo`000?l0003ooooo0_l0000;ooooo`Ko00000oooool3o`0000?ooooo2Ol0001Qooooo`00
7?ooool2o`0005Sooooo2ol000000ooooooo0000o`00000=ooooo`;o00004?ooool2o`0001Kooooo
0_l00003ooooo`;o00002oooool2o`0000?ooooo0_l00005ooooo`Go000000Coooooo`000?l0003o
oooo0_l0000=ooooo`;o00001?ooool4o`0000;ooooo2Ol0001Rooooo`007?ooool00ol0003ooooo
ooooo`1Hooooo`[o000000?oooooo`000?l000000_ooool2o`0001Wooooo0_l00008ooooo`;o0000
8?ooool3o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l000001oooool2o`0000gooooo
2?l000000ooooooo0000o`000008o`00067ooooo000Looooo`03o`000?oooooooooo05Wooooo2_l0
0004ooooo`;o00001?ooool2o`0001?ooooo0_l00008ooooo`Co00007_ooool3o`0001Gooooo0_l0
00001?oooooo0000o`000?ooool2o`0000Oooooo1?l00002ooooo`go0000HOooool001cooooo00?o
0000ooooooooool0F?ooool=o`0000;ooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo
0_l0000:ooooo`;o00001?ooool2o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l00000
5?ooool2o`0000oooooo0_l0000?ooooo`;o000000?oooooo`000?l000001oooool2o`0000Kooooo
2_l0001Rooooo`007?ooool00ol0003oooooooooo`1Hooooo`go000000Coooooo`000?l0003ooooo
0_l00005ooooo`;o000000?oooooo`000?l000001oooool2o`000003ooooool0003o000000Cooooo
1?l000000ooooooo0000o`000005ooooo`;o00001?ooool2o`0000kooooo0_l0000=ooooo`Co0000
1?ooool2o`0000Oooooo0_l00005ooooo`;o00001Oooool3o`0000Gooooo2_l0001Rooooo`007?oo
ool00ol0003oooooooooo`1Iooooo`[o00000oooool2o`000003ooooool0003o000000oooooo1?l0
00000ooooooo0000o`000006ooooo`;o00003_ooool2o`0001gooooo0_l00006ooooo`;o00001ooo
ool2o`0000Gooooo0_l00006ooooo`;o00000oooool;o`0006?ooooo000Looooo`03o`000?oooooo
oooo05Wooooo2_l00004ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Kooooo0_l00004
ooooo`;o00002?ooool2o`0003;ooooo0ol0000@ooooo`?o00000_ooool3o`0000;ooooo2_l0001T
ooooo`007?ooool00ol0003oooooooooo`1Jooooo`[o00000oooool2o`000003ooooool0003o0000
00Kooooo0_l0000<ooooo`;o00001oooool3o`0000kooooo0_l00004ooooo`;o00003_ooool2o`00
00cooooo0ol00003ooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`Co000000Cooooo
o`000?l0003o00000_ooool;o`0006?ooooo000Looooo`03o`000?oooooooooo05[ooooo2_l00002
ooooo`;o00000_ooool2o`0000Wooooo1?l0000@ooooo`;o00003?ooool5o`0000Cooooo0_l00002
ooooo`;o00002_ooool2o`000003ooooool0003o000000oooooo0_l00005ooooo`;o000000Cooooo
o`000?l0003ooooo1ol00003ooooo`_o0000Hoooool001cooooo00?o0000ooooooooool0F_ooool;
o`000003ooooool0003o000000gooooo1?l0000Fooooo`;o00001_ooool4o`0000Kooooo0_l00000
0ooooooo0000o`000003ooooo`;o00002?ooool2o`0001Kooooo0_l00007ooooo`Co00000oooool9
o`0006Gooooo000Looooo`03o`000?oooooooooo05_ooooo2_l000000ooooooo0000o`000005oooo
o`;o00001_ooool2o`0000;ooooo1?l00006ooooo`;o00002_ooool2o`0000Oooooo0_l00007oooo
o`;o00001_ooool2o`0001[ooooo0ol00007ooooo`;o00002Oooool:o`0006Gooooo000Looooo`03
o`000?oooooooooo05_ooooo2_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00003oooo
o`;o000000?oooooo`000?l000000_ooool4o`0000Kooooo0_l0000Cooooo`;o000000?oooooo`00
0?l000002Oooool2o`0001gooooo0ol00007ooooo`;o00000oooool2o`0000Cooooo2_l0001Uoooo
o`007?ooool00ol0003oooooooooo`1Looooo`Wo000000Coooooo`000?l0003ooooo0_l00007oooo
o`;o000000Coooooo`000?l0003o00000_ooool2o`000003ooooool0003o000001cooooo0_l00009
ooooo`;o00003Oooool2o`000003ooooool0003o000000;ooooo0_l0000Fooooo`;o00000_ooool;
o`0006Kooooo000Looooo`03o`000?oooooooooo05cooooo3?l0000:ooooo`Ko00000_ooool2o`00
0003ooooool0003o000000Oooooo0_l00002ooooo`;o00005oooool2o`0000Gooooo1?l00007oooo
o`;o000000?oooooo`000?l000000_ooool3o`0000Kooooo0_l00004ooooo`;o00002Oooool=o`00
06Kooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o
0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`1Looooo`go00000_ooool2o`0000Gooooo1_l0
0002ooooo`Co000000?oooooo`000?l000001Oooool3o`000003ooooool0003o000001Oooooo0_l0
0005ooooo`Co00001oooool2o`0000Kooooo0_l00006ooooo`;o00001?ooool2o`0000Wooooo3Ol0
001Vooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMg
oooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0GOooool<o`0000;ooooo0_l00004ooooo`;o
000000?oooooo`000?l000000_l00004ooooo`;o000000?oooooo`000?l000001?ooool4o`0001oo
oooo0_l00004ooooo`;o00001Oooool2o`0000cooooo0ol0000Booooo`_o0000I_ooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool0GOooool;o`0000Kooooo0_l000001?oooooo0000o`000?ooool2o`00
00oooooo0_l0000:ooooo`;o00001oooool2o`0000Oooooo0_l00003ooooo`;o00001?ooool2o`00
00Gooooo0_l000000ooooooo0000o`000009ooooo`?o00004Oooool;o`0006Oooooo00000ooooooo
0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@06oooo
o`?o0000GOooool<o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`000004ooooool0003o
0000ooooo`;o00000_ooool2o`0001Cooooo0_l00006ooooo`?o00001oooool2o`0000Wooooo0_l0
0006ooooo`Co00002?ooool2o`0000Gooooo1?l0000:ooooo`_o0000Ioooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o
0000ooooooooool0GOooool<o`000004ooooool0003o0000o`0000Cooooo0_l000001?oooooo0000
o`000?ooool6o`0001Gooooo0_l00004ooooo`Go00006Oooool2o`0000[ooooo0_l00005ooooo`Co
00001oooool=o`0006Sooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo
00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`1Oooooo`[o000000?oooooo`000?l00000
3Oooool2o`0000cooooo0_l00004ooooo`;o00000oooool2o`0000Cooooo0_l000000ooooooo0000
o`00000Iooooo`Co00002?ooool4o`0000?ooooo0ol00006ooooo`oo0000J?ooool00006oooooomg
MgOoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo05oo
oooo3_l00007ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00001Oooool2o`000003
ooooool0003o000000Cooooo0_l000001?oooooo0000o`000?l00004ooooo`;o00001?ooool2o`00
00;ooooo0_l00003ooooo`;o00002oooool2o`000003ooooool0003o000000;o00002?ooool4o`00
0003ooooool0003o000000?o00001_ooool2o`000003ooooool0003o000000Go000000Coooooo`00
0?l0003o0000JOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`00
0?l@4106ooooo`03o`000?oooooooooo05oooooo3_l00007ooooo`;o000000?oooooo`000?l00000
0_l00002ooooo`;o00001Oooool2o`0000[ooooo0ol00004ooooo`;o00001?ooool2o`0000;ooooo
0_l00003ooooo`;o00001?ooool2o`000003ooooool0003o000000;ooooo1Ol0000:ooooo`;o0000
0_ooool3o`0000Oooooo4?l0001Yooooo`007?ooool00ol0003oooooooooo`1Pooooo`co00000_oo
ool3o`0000[ooooo0_l00009ooooo`;o00008oooool3o`000003ooooool0003o000000?ooooo0_l0
000@ooooo`;o00001?ooool2o`000005ooooool0003o0000o`000?ooool03Ol0001Yooooo`007?oo
ool00ol0003oooooooooo`1Qooooo`_o00000_ooool3o`0000[ooooo0_l00009ooooo`;o000000?o
ooooo`000?l000005oooool2o`0000Oooooo0_l00009ooooo`;o00003Oooool2o`0000Gooooo0_l0
00000ooooooo0000o`000002ooooo`_o0000Joooool001cooooo00?o0000ooooooooool0H_ooool;
o`0000cooooo0_l00005ooooo`;o00001oooool2o`0001Kooooo0ol0000Booooo`;o00001?ooool2
o`0000Kooooo0ol0000:ooooo`go0000Joooool001cooooo00?o0000ooooooooool0H_ooool<o`00
0003ooooool0003o000000Sooooo0_l00005ooooo`;o00003Oooool2o`0000Oooooo0_l00007oooo
o`Co00003?ooool3o`0000Gooooo0_l000000ooooooo0000o`000006ooooo`;o00001Oooool2o`00
00Cooooo3?l0001/ooooo`007?ooool00ol0003oooooooooo`1Sooooo`ko000000?oooooo`000?l0
00001_ooool2o`0000;ooooo0_l00008ooooo`;o00001Oooool2o`0000Oooooo0_l00006ooooo`;o
000000Coooooo`000?l0003ooooo0_l00009ooooo`?o00001Oooool2o`000003ooooool0003o0000
00gooooo0_l00003ooooo`go0000K?ooool001cooooo00?o0000ooooooooool0IOooool;o`0000;o
oooo0_l00006ooooo`;o00000_ooool2o`0000Sooooo1?l00008ooooo`;o00002_ooool3o`0000?o
oooo0_l00008ooooo`;o00001?ooool4o`0000;ooooo0_l00006ooooo`;o00000oooool2o`0000Co
oooo3Ol0001]ooooo`007?ooool00ol0003oooooooooo`1Tooooo`go00001oooool2o`0000Sooooo
0_l00006ooooo`;o00001_ooool4o`0000;ooooo0_l00006ooooo`?o00000_ooool2o`0000Wooooo
0_l00004ooooo`Co00001?ooool2o`0000?ooooo0ol00003ooooo`;o00001?ooool;o`0006oooooo
000Looooo`03o`000?oooooooooo06Cooooo3_l00005ooooo`?o00002?ooool2o`0000Kooooo1?l0
0004ooooo`?o00000oooool2o`0000_ooooo0_l00008ooooo`;o00001?ooool2o`0000;ooooo0_l0
00000ooooooo0000o`000007o`0000Cooooo0_l000000ooooooo0000o`00000<o`0006oooooo000L
ooooo`03o`000?oooooooooo06Oooooo2ol000001?oooooo0000o`000?ooool3o`0001?ooooo0_l0
0005ooooo`;o000000Coooooo`000?l0003ooooo0_l00007ooooo`;o00002oooool3o`0000?ooooo
0_l00002ooooo`;o000000?oooooo`000?l000000_ooool4o`0000Gooooo0_l000000ooooooo0000
o`00000;o`00073ooooo000Looooo`03o`000?oooooooooo06Oooooo4Ol00005ooooo`;o00001ooo
ool2o`0000kooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000?o0000
2oooool3o`0000[ooooo0_l0000;ooooo`;o000000?oooooo`000?l000002_l0001aooooo`007?oo
ool00ol0003oooooooooo`1Woooooa;o00001?ooool3o`0000;ooooo0_l00002ooooo`;o00002_oo
ool4o`0000?ooooo1Ol000000ooooooo0000o`000002o`0000kooooo0_l00008ooooo`;o00003Ooo
ool=o`0007;ooooo000Looooo`;o0000JOoooolAo`0000Gooooo0_l00002ooooo`;o00003_ooool4
o`0000?ooooo0ol0000Eooooo`;o00001Oooool2o`000003ooooool0003o000000Sooooo0_l00002
ooooo`ko0000L_ooool001cooooo00?o0000ooooooooool0JOoooolAo`00017ooooo0_l00005oooo
o`;o00001Oooool2o`0000Oooooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool2o`00
0003ooooool0003o000000Gooooo0ol0000:ooooo`;o000000?oooooo`000?l000003Ol0001boooo
o`007?ooool00ol0003oooooooooo`1Zooooo`go000000?oooooo`000?l000001Oooool2o`0000[o
oooo0_l0000Eooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l000000ooooooo
0000o`000005ooooo`?o00002Oooool2o`000003ooooool0003o000000go0000Loooool001cooooo
00?o0000ooooooooool0Joooool>o`0000Kooooo0_l0000>ooooo`;o00003_ooool2o`0000Cooooo
0_l00004ooooo`;o00000_ooool2o`0000gooooo0ol00003oooooa3o0000MOooool001cooooo00?o
0000ooooooooool0K?ooool?o`0000?ooooo0ol00007ooooo`;o00000oooool7o`000003ooooool0
003o000000Sooooo1?l000000ooooooo0000o`000005ooooo`;o00000_ooool2o`0000?ooooo1?l0
0006ooooo`?o00001?ooool?o`0007Gooooo000Looooo`03o`000?oooooooooo06gooooo3ol00002
ooooo`;o00002?ooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`000004ooooool0003o
0000o`0000Wooooo0_l000001?oooooo0000o`000?l0000=ooooo`Co00002oooool?o`0007Oooooo
000Looooo`03o`000?oooooooooo06kooooo3ol0000Fooooo`;o000000?oooooo`000?l000000ooo
ool2o`0000Cooooo0_l00002ooooo`;o00000_ooool2o`0000gooooo0_l000000ooooooo0000o`00
0005ooooo`oo0000N?ooool001cooooo00?o0000ooooooooool0KooooolAo`0000Sooooo1?l00007
ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00003OoooolIo`0007Sooooo000Loooo
o`03o`000?oooooooooo073ooooo4_l00006ooooo`Co00000_ooool2o`0000gooooo0_l00003oooo
o`;o00002?ooool3o`0000Oooooo0_l000001?oooooo0000o`000?oooolCo`0007[ooooo000Loooo
o`03o`000?oooooooooo07;ooooo5?l00005ooooo`;o000000?oooooo`000?l000003Oooool2o`00
00Wooooo0_l00002ooooo`?o00001oooool2o`0000Cooooo4?l0001mooooo`007?ooool00ol0003o
ooooooooo`1eoooooa7o00001Oooool7o`0000kooooo0_l00006ooooo`;o00001?ooool2o`0000;o
oooo0_l00006oooooa;o0000OOooool001cooooo00?o0000ooooooooool0MOoooolCo`0000Gooooo
0_l000000ooooooo0000o`000002ooooo`Ko00001_ooool2o`0000?ooooo0_l00006ooooo`So0000
00Coooooo`000?l0003ooooo4_l0001nooooo`007?ooool00ol0003oooooooooo`1foooooaGo0000
1?ooool2o`0000?ooooo1_l0000;ooooo`;o00001_oooolLo`00083ooooo000Looooo`03o`000?oo
oooooooo07Kooooo6?l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l0000<ooooo`;o0000
2?oooolIo`00087ooooo000Looooo`03o`000?oooooooooo07[ooooo6_l00003ooooo`;o00001ooo
ool2o`0000Wooooo7?l00022ooooo`007?ooool00ol0003oooooooooo`1kooooob3o00000_ooool2
o`000003ooooool0003o000000Kooooo7Ol00024ooooo`007?ooool2o`0007gooooo:ol000000ooo
oooo0000o`00000Io`0008Kooooo000Looooo`03o`000?oooooooooo07kooooo@ol00028ooooo`00
7?ooool00ol0003oooooooooo`20oooood3o0000ROooool001cooooo00?o0000ooooooooool0Pooo
ooljo`0008cooooo000Looooo`03o`000?oooooooooo08Oooooo<ol0002?ooooo`007?ooool00ol0
003oooooooooo`27oooooc;o0000T?ooool001cooooo00?o0000ooooooooool0RooooolYo`0009Go
oooo000Looooo`03o`000?oooooooooo08oooooo8ol0002Gooooo`007?ooool00ol0003ooooooooo
o`2Dooooo`Ko000000?oooooo`000?l000003Ol000000ooooooo0000o`00002Looooo`007?ooool0
0ol0003oooooooooo`2Kooooo`_o0000Xoooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
0006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Q
olc<c006ooooo`03o`000?oooooooooo0?ooooooB_ooool00006oooooomgMgOoV9RHoooooonHV9So
MgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo
0?ooooooB_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooom:ooooo`0000?oooooo`000?oo
ool00_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`00
0?ooooooB_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Oo<c<co
0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom:ooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0
003oooooooooo`3ooooood[ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000
okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0?ooooooB_ooool00006ooooooo^k^ko
<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`00
0?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom:
ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool001Co
oooo00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o0000ooooooooool0
oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooo
oooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`004_ooool00omEEEGo
IVIVo`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002]oooo
o`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05Oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^09Sooooo002^ooooo`05o`000?ooooooooooooooool000002Oooool6o`0000Wooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`2Hooooo`00[_ooool01Ol0003ooooooooooooooooo000001Sooooo
00Go410@oooooooooooooooooa0@402Hooooo`00[_ooool01Ol0003ooooooooooooooooo000000Wo
oooo1_l00009ooooo`05o`000?ooooooooooooooool00000V?ooool00:kooooo00Go0000ohN7Qooo
ooooZJVYo`00000Hooooo`05o`000?ooooooooooooooool00000V?ooool00:gooooo00?o410@o`00
0?mgMgL00_l000000onHV9Soooooooooo`0Fooooo`05oa0@4?ooooooooooooooool@4100V?ooool0
0<_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`2Hooooo`00boooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^09Sooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -17 0 ]
[.5 1.0125 17 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.67331 .39127 Mdot
.6209 .33111 Mdot
.39315 .3273 Mdot
.43217 .69901 Mdot
.40032 .6878 Mdot
.40462 .31686 Mdot
.58503 .31013 Mdot
.53704 .28701 Mdot
.30369 .39681 Mdot
.41778 .69414 Mdot
.44308 .29017 Mdot
.68342 .61539 Mdot
.57653 .30626 Mdot
.49439 .70936 Mdot
.60993 .67702 Mdot
.72097 .48473 Mdot
.65013 .34611 Mdot
.39792 .68509 Mdot
.68586 .58693 Mdot
.30999 .38454 Mdot
.29753 .46544 Mdot
.4503 .69977 Mdot
.63628 .32995 Mdot
.51612 .71617 Mdot
.6925 .57857 Mdot
.70556 .49532 Mdot
.67434 .39491 Mdot
.70217 .55914 Mdot
.68714 .60427 Mdot
.50232 .27672 Mdot
.70672 .53369 Mdot
.56844 .71576 Mdot
.29957 .48143 Mdot
.69204 .40344 Mdot
.42863 .29935 Mdot
.46257 .27868 Mdot
.37834 .33939 Mdot
.48843 .28342 Mdot
.52624 .27801 Mdot
.44957 .29907 Mdot
.44204 .29878 Mdot
.70777 .49286 Mdot
.45025 .28 Mdot
.60347 .31667 Mdot
.54663 .71575 Mdot
.71144 .42163 Mdot
.29791 .45347 Mdot
.52306 .69826 Mdot
.66905 .3812 Mdot
.29486 .46049 Mdot
.60314 .68902 Mdot
.60238 .32164 Mdot
.29981 .52785 Mdot
.65898 .34469 Mdot
.56286 .30284 Mdot
.69581 .57497 Mdot
.34587 .35291 Mdot
.6247 .67692 Mdot
.66575 .62144 Mdot
.6951 .41114 Mdot
.52121 .72016 Mdot
.32613 .60134 Mdot
.6837 .60163 Mdot
.33676 .3489 Mdot
.34453 .36322 Mdot
.50835 .29954 Mdot
.63245 .32008 Mdot
.48317 .28489 Mdot
.50649 .71119 Mdot
.33734 .38026 Mdot
.6122 .68013 Mdot
.44281 .29062 Mdot
.70764 .45121 Mdot
.43059 .69481 Mdot
.66087 .37913 Mdot
.46273 .28666 Mdot
.4086 .69684 Mdot
.71177 .47067 Mdot
.28041 .49325 Mdot
.46269 .71885 Mdot
.46979 .70617 Mdot
.41728 .28939 Mdot
.64151 .64646 Mdot
.70967 .49877 Mdot
.56409 .70742 Mdot
.47198 .27584 Mdot
.41435 .68893 Mdot
.70696 .53028 Mdot
.70927 .5458 Mdot
.69066 .60733 Mdot
.30336 .41319 Mdot
.6176 .31526 Mdot
.42854 .6903 Mdot
.5871 .71032 Mdot
.57275 .69535 Mdot
.56439 .70505 Mdot
.71227 .53963 Mdot
.28961 .49068 Mdot
.46909 .29532 Mdot
.29939 .50374 Mdot
.47126 .28391 Mdot
.3004 .55991 Mdot
.5707 .71673 Mdot
.373 .3281 Mdot
.68083 .38143 Mdot
.28658 .50047 Mdot
.46829 .28978 Mdot
.42304 .68588 Mdot
.47687 .28022 Mdot
.61916 .32062 Mdot
.71099 .52749 Mdot
.36434 .66224 Mdot
.39659 .69284 Mdot
.68013 .40413 Mdot
.61387 .69728 Mdot
.42123 .69584 Mdot
.4691 .70335 Mdot
.6282 .31697 Mdot
.3107 .38891 Mdot
.29261 .4335 Mdot
.63677 .34817 Mdot
.46304 .2973 Mdot
.65939 .35791 Mdot
.32533 .62745 Mdot
.3185 .38414 Mdot
.28971 .51304 Mdot
.28752 .55189 Mdot
.54752 .7188 Mdot
.56549 .70326 Mdot
.3161 .6247 Mdot
.37583 .32472 Mdot
.63791 .34995 Mdot
.56305 .29823 Mdot
.59133 .7095 Mdot
.71569 .43489 Mdot
.56204 .30347 Mdot
.35349 .64268 Mdot
.37699 .67703 Mdot
.70672 .43977 Mdot
.61014 .69586 Mdot
.52224 .29653 Mdot
.56589 .28898 Mdot
.62163 .68019 Mdot
.71103 .42604 Mdot
.36448 .64858 Mdot
.56572 .28865 Mdot
.30548 .55956 Mdot
.71604 .5197 Mdot
.67152 .6436 Mdot
.43442 .28113 Mdot
.60009 .68905 Mdot
.30865 .43372 Mdot
.32165 .60181 Mdot
.54903 .29828 Mdot
.435 .70257 Mdot
.655 .3571 Mdot
.70499 .42739 Mdot
.65752 .6454 Mdot
.29204 .48939 Mdot
.6419 .67169 Mdot
.30539 .58504 Mdot
.28246 .53972 Mdot
.4685 .69991 Mdot
.70009 .41192 Mdot
.67719 .36678 Mdot
.61514 .67933 Mdot
.34162 .36764 Mdot
.41509 .70165 Mdot
.43765 .29004 Mdot
.55047 .70595 Mdot
.55282 .69876 Mdot
.66603 .63887 Mdot
.58326 .30116 Mdot
.40056 .30331 Mdot
.30016 .43326 Mdot
.50696 .29632 Mdot
.42363 .29514 Mdot
.35583 .33494 Mdot
.6737 .62079 Mdot
.36283 .67027 Mdot
.30032 .59253 Mdot
.61301 .68065 Mdot
.52175 .71391 Mdot
.68626 .61412 Mdot
.28392 .55988 Mdot
.28654 .57176 Mdot
.68461 .39887 Mdot
.43927 .28334 Mdot
.47886 .71655 Mdot
.67486 .60517 Mdot
.58589 .69565 Mdot
.51854 .29223 Mdot
.55323 .29258 Mdot
.35878 .32692 Mdot
.31383 .37813 Mdot
.31598 .41401 Mdot
.61876 .66536 Mdot
.61448 .67301 Mdot
.47471 .7123 Mdot
.29516 .517 Mdot
.71331 .55482 Mdot
.3227 .60245 Mdot
.64966 .34783 Mdot
.41355 .29169 Mdot
.66606 .65075 Mdot
.68527 .57585 Mdot
.29302 .42111 Mdot
.28315 .46043 Mdot
.30121 .60313 Mdot
.33687 .6402 Mdot
.60204 .68608 Mdot
.67886 .392 Mdot
.60776 .6868 Mdot
.29894 .48476 Mdot
.39462 .69366 Mdot
.63315 .34084 Mdot
.53131 .69724 Mdot
.58032 .31119 Mdot
.44224 .30528 Mdot
.41001 .68508 Mdot
.41827 .68302 Mdot
.71316 .46253 Mdot
.58701 .70849 Mdot
.68444 .59393 Mdot
.70437 .5447 Mdot
.32008 .40506 Mdot
.4876 .28982 Mdot
.5031 .27494 Mdot
.29549 .46273 Mdot
.71156 .43856 Mdot
.60989 .32336 Mdot
.37324 .33219 Mdot
.30179 .45448 Mdot
.44704 .2847 Mdot
.34111 .63454 Mdot
.37766 .32749 Mdot
.36622 .64911 Mdot
.67604 .61188 Mdot
.38907 .31374 Mdot
.35641 .64975 Mdot
.6227 .67089 Mdot
.2915 .55884 Mdot
.37233 .68198 Mdot
.58975 .31451 Mdot
.60091 .30663 Mdot
.62853 .67346 Mdot
.29835 .55846 Mdot
.30063 .48689 Mdot
.66904 .62485 Mdot
.28673 .5565 Mdot
.28596 .536 Mdot
.67055 .62597 Mdot
.39197 .67785 Mdot
.4092 .29798 Mdot
.70727 .5331 Mdot
.65346 .35051 Mdot
.51947 .71446 Mdot
.48826 .29976 Mdot
.55772 .30194 Mdot
.47435 .72031 Mdot
.47537 .27705 Mdot
.59331 .31815 Mdot
.47021 .70165 Mdot
.51788 .28051 Mdot
.71782 .46384 Mdot
.66681 .65067 Mdot
.70507 .45182 Mdot
.49202 .70887 Mdot
.52007 .27934 Mdot
.29538 .46172 Mdot
.71275 .47673 Mdot
.44116 .69825 Mdot
.45092 .70812 Mdot
.29685 .52008 Mdot
.7086 .53455 Mdot
.51181 .28627 Mdot
.68291 .61529 Mdot
.40756 .30579 Mdot
.63268 .66069 Mdot
.31419 .57971 Mdot
.31956 .60919 Mdot
.70906 .42427 Mdot
.28258 .54751 Mdot
.39035 .32251 Mdot
.57359 .69409 Mdot
.57609 .69028 Mdot
.56139 .71244 Mdot
.28912 .53974 Mdot
.63992 .6481 Mdot
.56901 .31116 Mdot
.71665 .53562 Mdot
.31496 .62165 Mdot
.35517 .34762 Mdot
.302 .53017 Mdot
.56518 .70622 Mdot
.62974 .32505 Mdot
.70618 .52708 Mdot
.40095 .30758 Mdot
.63239 .32981 Mdot
.54151 .69683 Mdot
.48515 .28576 Mdot
.32119 .58787 Mdot
.49914 .28063 Mdot
.68989 .57436 Mdot
.63913 .65752 Mdot
.33366 .38352 Mdot
.71653 .4585 Mdot
.54153 .29365 Mdot
.70669 .45199 Mdot
.6334 .67651 Mdot
.63514 .67903 Mdot
.70564 .42193 Mdot
.3165 .59661 Mdot
.28849 .46114 Mdot
.44668 .28787 Mdot
.29118 .52095 Mdot
.32556 .3882 Mdot
.67005 .37993 Mdot
.3826 .32274 Mdot
.62714 .68949 Mdot
.4469 .30493 Mdot
.70413 .53147 Mdot
.33325 .38174 Mdot
.6558 .64904 Mdot
.55167 .71675 Mdot
.34552 .33889 Mdot
.29713 .47734 Mdot
.6147 .68182 Mdot
.71821 .44722 Mdot
.47528 .6996 Mdot
.40971 .68698 Mdot
.61836 .66751 Mdot
.35394 .34795 Mdot
.61363 .69411 Mdot
.69858 .55822 Mdot
.6915 .57553 Mdot
.64635 .34667 Mdot
.29569 .54165 Mdot
.36412 .65252 Mdot
.3768 .68231 Mdot
.30848 .57495 Mdot
.68712 .61501 Mdot
.6239 .68729 Mdot
.71002 .4322 Mdot
.29864 .44559 Mdot
.59456 .30052 Mdot
.2984 .48477 Mdot
.53653 .28618 Mdot
.40543 .30172 Mdot
.40788 .68282 Mdot
.40289 .68649 Mdot
.70803 .52051 Mdot
.66579 .37915 Mdot
.70953 .45337 Mdot
.53968 .29214 Mdot
.70826 .56983 Mdot
.46596 .71963 Mdot
.4768 .72062 Mdot
.53913 .28178 Mdot
.29492 .49338 Mdot
.65359 .63477 Mdot
.5724 .68953 Mdot
.5975 .31097 Mdot
.54677 .71262 Mdot
.6939 .42276 Mdot
.48443 .70066 Mdot
.57398 .7142 Mdot
.50348 .7051 Mdot
.71591 .43977 Mdot
.70587 .52329 Mdot
.57472 .68957 Mdot
.28841 .43295 Mdot
.66951 .64833 Mdot
.34737 .66127 Mdot
.43213 .69465 Mdot
.60113 .68602 Mdot
.35596 .64071 Mdot
.67956 .40074 Mdot
.54188 .70193 Mdot
.43839 .28085 Mdot
.43886 .69579 Mdot
.43803 .28885 Mdot
.65144 .64468 Mdot
.57983 .70727 Mdot
.70124 .55534 Mdot
.63555 .3289 Mdot
.5329 .27834 Mdot
.43585 .29581 Mdot
.31191 .61387 Mdot
.55583 .30129 Mdot
.55701 .70787 Mdot
.64772 .64735 Mdot
.68031 .40391 Mdot
.29077 .55477 Mdot
.61537 .3128 Mdot
.42723 .7063 Mdot
.57862 .30283 Mdot
.30017 .54568 Mdot
.69188 .59379 Mdot
.56566 .29204 Mdot
.4269 .28795 Mdot
.71154 .52567 Mdot
.29525 .49322 Mdot
.67395 .38923 Mdot
.33287 .38304 Mdot
.28598 .51408 Mdot
.55605 .30023 Mdot
.53899 .71529 Mdot
.7161 .5282 Mdot
.52925 .28791 Mdot
.69755 .45339 Mdot
.71776 .5122 Mdot
.43392 .6924 Mdot
.70356 .50318 Mdot
.61193 .30679 Mdot
.65197 .6643 Mdot
.49436 .72091 Mdot
.38408 .33023 Mdot
.28875 .53569 Mdot
.29075 .53732 Mdot
.28147 .5153 Mdot
.45445 .30348 Mdot
.29121 .44724 Mdot
.48815 .29271 Mdot
.50029 .70875 Mdot
.50119 .29696 Mdot
.29893 .56041 Mdot
.38726 .32854 Mdot
.51949 .71215 Mdot
.7174 .55201 Mdot
.56572 .28772 Mdot
.31716 .3945 Mdot
.40861 .67974 Mdot
.65878 .36054 Mdot
.59361 .31169 Mdot
.61487 .67345 Mdot
.32796 .39493 Mdot
.32467 .59772 Mdot
.60195 .69677 Mdot
.56262 .28908 Mdot
.69373 .43724 Mdot
.55918 .28755 Mdot
.58095 .69118 Mdot
.53303 .70643 Mdot
.643 .3584 Mdot
.34008 .6513 Mdot
.68093 .61645 Mdot
.51766 .71707 Mdot
.28919 .4753 Mdot
.60567 .31339 Mdot
.33695 .64714 Mdot
.69579 .59384 Mdot
.29223 .57059 Mdot
.41631 .70124 Mdot
.46896 .71021 Mdot
.67056 .63021 Mdot
.31712 .61092 Mdot
.51402 .28322 Mdot
.36092 .67321 Mdot
.29432 .42083 Mdot
.63074 .33371 Mdot
.49026 .29233 Mdot
.28938 .48691 Mdot
.44543 .29063 Mdot
.67795 .62935 Mdot
.30376 .58795 Mdot
.61065 .32664 Mdot
.38898 .66815 Mdot
.28798 .54414 Mdot
.34569 .35493 Mdot
.63317 .67504 Mdot
.67511 .623 Mdot
.43212 .69118 Mdot
.36331 .6523 Mdot
.60748 .31139 Mdot
.42764 .29128 Mdot
.52417 .27567 Mdot
.46562 .69798 Mdot
.70879 .42383 Mdot
.69067 .43744 Mdot
.29994 .51083 Mdot
.35631 .65728 Mdot
.34411 .63928 Mdot
.45768 .69474 Mdot
.67085 .61506 Mdot
.71397 .43742 Mdot
.43991 .69774 Mdot
.47293 .70029 Mdot
.3076 .41739 Mdot
.70009 .50885 Mdot
.38094 .31769 Mdot
.68027 .58959 Mdot
.59084 .69974 Mdot
.48998 .28812 Mdot
.57563 .31154 Mdot
.29381 .53664 Mdot
.50306 .27481 Mdot
.30019 .43043 Mdot
.29074 .53784 Mdot
.44283 .69926 Mdot
.67667 .40371 Mdot
.43597 .69561 Mdot
.43693 .6951 Mdot
.51104 .70846 Mdot
.62168 .68812 Mdot
.28381 .45015 Mdot
.35954 .66477 Mdot
.68599 .60326 Mdot
.36503 .3264 Mdot
.29415 .41789 Mdot
.58037 .69424 Mdot
.45749 .70649 Mdot
.4613 .69972 Mdot
.70217 .49284 Mdot
.71908 .52421 Mdot
.55323 .28815 Mdot
.64183 .35737 Mdot
.44581 .70974 Mdot
.30461 .43614 Mdot
.53518 .70327 Mdot
.70239 .42452 Mdot
.43438 .30045 Mdot
.5234 .29267 Mdot
.28885 .56219 Mdot
.3011 .4982 Mdot
.28731 .53736 Mdot
.29707 .47329 Mdot
.45433 .27931 Mdot
.38848 .32813 Mdot
.31301 .57115 Mdot
.63628 .67913 Mdot
.49111 .71914 Mdot
.543 .70467 Mdot
.31021 .40856 Mdot
.3043 .54473 Mdot
.62307 .68471 Mdot
.72573 .49612 Mdot
.4344 .3067 Mdot
.28356 .50814 Mdot
.70395 .51974 Mdot
.62496 .32659 Mdot
.32675 .39331 Mdot
.48569 .28283 Mdot
.35953 .65204 Mdot
.29937 .45426 Mdot
.61076 .31103 Mdot
.67682 .60744 Mdot
.43019 .30864 Mdot
.64758 .64611 Mdot
.7194 .54294 Mdot
.39461 .31611 Mdot
.71428 .54254 Mdot
.6363 .32392 Mdot
.2896 .55376 Mdot
.64219 .65338 Mdot
.66577 .62853 Mdot
.34679 .33516 Mdot
.42918 .69534 Mdot
.29797 .42198 Mdot
.35156 .35059 Mdot
.2955 .56282 Mdot
.35464 .34743 Mdot
.5601 .30687 Mdot
.35648 .33843 Mdot
.69999 .47298 Mdot
.55342 .72028 Mdot
.66826 .35742 Mdot
.65456 .65348 Mdot
.44331 .70982 Mdot
.59973 .32147 Mdot
.49335 .29816 Mdot
.50837 .71885 Mdot
.39496 .68328 Mdot
.35487 .34935 Mdot
.29999 .43708 Mdot
.71303 .54152 Mdot
.31968 .39558 Mdot
.63547 .3285 Mdot
.47795 .28679 Mdot
.49404 .29811 Mdot
.28588 .52843 Mdot
.71505 .43208 Mdot
.49594 .28411 Mdot
.46496 .29748 Mdot
.32067 .58693 Mdot
.64921 .66436 Mdot
.68662 .39416 Mdot
.65336 .63527 Mdot
.38209 .66724 Mdot
.44208 .69677 Mdot
.37401 .32223 Mdot
.31134 .41904 Mdot
.58125 .68631 Mdot
.37552 .33161 Mdot
.29243 .52977 Mdot
.69117 .4235 Mdot
.69198 .58107 Mdot
.61889 .32681 Mdot
.59016 .70797 Mdot
.49236 .2924 Mdot
.62696 .32571 Mdot
.27836 .52071 Mdot
.52071 .72326 Mdot
.70207 .41503 Mdot
.70541 .58229 Mdot
.43643 .69351 Mdot
.32828 .37507 Mdot
.35844 .64294 Mdot
.30965 .4358 Mdot
.30265 .41261 Mdot
.32889 .61571 Mdot
.60918 .31982 Mdot
.32 .38197 Mdot
.33809 .63511 Mdot
.3288 .63216 Mdot
.2811 .51387 Mdot
.35138 .65933 Mdot
.56217 .70708 Mdot
.54193 .29603 Mdot
.61479 .32365 Mdot
.50663 .703 Mdot
.42033 .69673 Mdot
.66297 .34874 Mdot
.29713 .51472 Mdot
.43667 .69189 Mdot
.64225 .66866 Mdot
.70292 .42687 Mdot
.40995 .29451 Mdot
.33351 .35747 Mdot
.29377 .50454 Mdot
.61751 .32371 Mdot
.41714 .28927 Mdot
.33985 .36628 Mdot
.33756 .62622 Mdot
.52354 .28926 Mdot
.67539 .40305 Mdot
.299 .5251 Mdot
.58763 .31253 Mdot
.3084 .40445 Mdot
.59975 .68986 Mdot
.72329 .49652 Mdot
.42452 .31335 Mdot
.60251 .68896 Mdot
.6981 .54436 Mdot
.31892 .40982 Mdot
.4027 .30151 Mdot
.61793 .31904 Mdot
.52989 .28112 Mdot
.35085 .64849 Mdot
.70772 .45579 Mdot
.6149 .31291 Mdot
.57481 .31129 Mdot
.66144 .34456 Mdot
.6359 .6525 Mdot
.46252 .28753 Mdot
.65304 .63287 Mdot
.60966 .68498 Mdot
.29859 .53402 Mdot
.36252 .66867 Mdot
.48485 .2886 Mdot
.70585 .49561 Mdot
.57693 .29245 Mdot
.57066 .70198 Mdot
.7203 .51782 Mdot
.36964 .66568 Mdot
.67225 .36631 Mdot
.39195 .30425 Mdot
.55769 .28985 Mdot
.29103 .47036 Mdot
.39281 .68184 Mdot
.56664 .71175 Mdot
.34272 .37092 Mdot
.5442 .70776 Mdot
.60729 .32594 Mdot
.69745 .5451 Mdot
.63655 .34126 Mdot
.45509 .28716 Mdot
.7132 .50689 Mdot
.68667 .60809 Mdot
.50056 .71959 Mdot
.31893 .40598 Mdot
.6865 .40923 Mdot
.31876 .60829 Mdot
.40042 .67682 Mdot
.52463 .72383 Mdot
.30192 .48874 Mdot
.55393 .71898 Mdot
.41165 .29844 Mdot
.29402 .48661 Mdot
.42755 .30668 Mdot
.28757 .54807 Mdot
.29313 .52493 Mdot
.67371 .37873 Mdot
.31544 .41631 Mdot
.30145 .49513 Mdot
.47141 .72012 Mdot
.42966 .68589 Mdot
.53509 .27803 Mdot
.63781 .65286 Mdot
.66052 .63116 Mdot
.3827 .3131 Mdot
.32056 .58514 Mdot
.55054 .69724 Mdot
.71471 .48078 Mdot
.37764 .67513 Mdot
.30626 .5848 Mdot
.63572 .33352 Mdot
.56751 .70567 Mdot
.30693 .41788 Mdot
.2916 .55383 Mdot
.30422 .56917 Mdot
.36322 .65723 Mdot
.59232 .30882 Mdot
.69933 .43344 Mdot
.34991 .35196 Mdot
.71881 .49949 Mdot
.41615 .69801 Mdot
.32026 .3998 Mdot
.29824 .53673 Mdot
.30801 .60444 Mdot
.70861 .42476 Mdot
.69994 .46743 Mdot
.29199 .48063 Mdot
.36872 .32301 Mdot
.46983 .27742 Mdot
.45296 .29151 Mdot
.65475 .64731 Mdot
.50256 .28068 Mdot
.61853 .31916 Mdot
.58398 .69961 Mdot
.34226 .63763 Mdot
.56927 .29449 Mdot
.28515 .52954 Mdot
.61739 .32112 Mdot
.70364 .47097 Mdot
.52547 .71883 Mdot
.45435 .70191 Mdot
.29651 .45881 Mdot
.56444 .71654 Mdot
.58736 .30355 Mdot
.35704 .6447 Mdot
.37423 .33787 Mdot
.71484 .53548 Mdot
.65489 .35629 Mdot
.31544 .42143 Mdot
.6968 .59728 Mdot
.34117 .34766 Mdot
.62793 .34058 Mdot
.37686 .66936 Mdot
.35797 .66363 Mdot
.58602 .70046 Mdot
.31432 .42416 Mdot
.59187 .31406 Mdot
.7142 .43266 Mdot
.60621 .31554 Mdot
.68006 .61056 Mdot
.45519 .705 Mdot
.70322 .5652 Mdot
.43252 .2892 Mdot
.5576 .70641 Mdot
.36446 .65625 Mdot
.66194 .35223 Mdot
.54462 .71646 Mdot
.39153 .68541 Mdot
.3205 .61282 Mdot
.30611 .60586 Mdot
.32963 .35577 Mdot
.38059 .67133 Mdot
.38484 .67482 Mdot
.39017 .6883 Mdot
.40711 .30126 Mdot
.63173 .66548 Mdot
.39971 .68252 Mdot
.43688 .70075 Mdot
.62801 .67756 Mdot
.723 .5015 Mdot
.50451 .29591 Mdot
.33462 .3836 Mdot
.59095 .68922 Mdot
.4503 .70773 Mdot
.65591 .34428 Mdot
.72129 .48579 Mdot
.55509 .69509 Mdot
.63997 .33896 Mdot
.6875 .39101 Mdot
.3203 .37078 Mdot
.5358 .30085 Mdot
.34598 .37024 Mdot
.70392 .5822 Mdot
.71067 .57007 Mdot
.67358 .37273 Mdot
.53713 .29507 Mdot
.70389 .58123 Mdot
.59761 .31385 Mdot
.65058 .33936 Mdot
.72478 .49986 Mdot
.69808 .4584 Mdot
.32693 .60109 Mdot
.56277 .69433 Mdot
.58295 .31594 Mdot
.59355 .6884 Mdot
.5652 .30739 Mdot
.41563 .69271 Mdot
.70493 .57833 Mdot
.44517 .70777 Mdot
.5051 .70919 Mdot
.28244 .55722 Mdot
.45839 .70471 Mdot
.28174 .49037 Mdot
.65424 .35835 Mdot
.4103 .69407 Mdot
.68344 .59855 Mdot
.6176 .6811 Mdot
.45123 .69682 Mdot
.66216 .34726 Mdot
.47796 .70676 Mdot
.33579 .37758 Mdot
.70901 .57647 Mdot
.59093 .68844 Mdot
.55135 .29295 Mdot
.44733 .29465 Mdot
.68028 .40527 Mdot
.30539 .59322 Mdot
.66479 .35424 Mdot
.45822 .69718 Mdot
.33272 .36514 Mdot
.30792 .57094 Mdot
.37553 .66307 Mdot
.62667 .33958 Mdot
.39813 .6774 Mdot
.44853 .28066 Mdot
.31109 .39533 Mdot
.71064 .52501 Mdot
.39916 .31027 Mdot
.34677 .33917 Mdot
.59937 .30619 Mdot
.36242 .66793 Mdot
.52549 .70185 Mdot
.69395 .40924 Mdot
.69369 .38554 Mdot
.67914 .61198 Mdot
.32114 .37648 Mdot
.3176 .61152 Mdot
.69805 .53782 Mdot
.33486 .61273 Mdot
.33312 .62755 Mdot
.57998 .31211 Mdot
.33021 .36551 Mdot
.29236 .51053 Mdot
.33913 .63544 Mdot
.31866 .3718 Mdot
.28988 .4864 Mdot
.29143 .46495 Mdot
.71135 .43202 Mdot
.63105 .68549 Mdot
.70391 .41264 Mdot
.51185 .27552 Mdot
.30601 .43118 Mdot
.71385 .4464 Mdot
.71553 .47902 Mdot
.29463 .52177 Mdot
.34229 .36838 Mdot
.68603 .40032 Mdot
.6396 .66855 Mdot
.29623 .59083 Mdot
.53386 .72035 Mdot
.41173 .70046 Mdot
.43266 .68786 Mdot
.31946 .41271 Mdot
.55114 .28613 Mdot
.37475 .33515 Mdot
.58419 .3144 Mdot
.56837 .71642 Mdot
.5094 .72435 Mdot
.44385 .70128 Mdot
.6527 .64334 Mdot
.67262 .37373 Mdot
.6924 .41083 Mdot
.34046 .35355 Mdot
.36671 .34013 Mdot
.6986 .57922 Mdot
.66301 .36527 Mdot
.31262 .59042 Mdot
.67969 .60809 Mdot
.48199 .70872 Mdot
.65288 .35629 Mdot
.72378 .50777 Mdot
.5286 .29802 Mdot
.64929 .64825 Mdot
.66003 .35404 Mdot
.29225 .44294 Mdot
.49477 .70799 Mdot
.30094 .50433 Mdot
.31762 .62522 Mdot
.67155 .6366 Mdot
.39574 .68279 Mdot
.63087 .33683 Mdot
.30203 .54011 Mdot
.6576 .36408 Mdot
.4481 .30421 Mdot
.5316 .30014 Mdot
.64107 .34316 Mdot
.47422 .70469 Mdot
.35681 .35913 Mdot
.54736 .29886 Mdot
.49208 .70236 Mdot
.45904 .28934 Mdot
.71077 .45 Mdot
.64713 .3572 Mdot
.28984 .48646 Mdot
.71632 .53732 Mdot
.58472 .30648 Mdot
.47734 .71737 Mdot
.69712 .45517 Mdot
.71197 .51174 Mdot
.37715 .6612 Mdot
.52169 .705 Mdot
.65102 .6678 Mdot
.2941 .43074 Mdot
.58438 .69529 Mdot
.42129 .29684 Mdot
.44708 .28235 Mdot
.43023 .2882 Mdot
.67683 .39029 Mdot
.27939 .54266 Mdot
.6996 .4496 Mdot
.29181 .5319 Mdot
.35114 .36052 Mdot
.49633 .7033 Mdot
.29947 .46871 Mdot
.485 .29035 Mdot
.34367 .65278 Mdot
.68733 .6122 Mdot
.41222 .31988 Mdot
.30009 .60371 Mdot
.5696 .29607 Mdot
.69579 .4596 Mdot
.63382 .33532 Mdot
.29068 .46023 Mdot
.50045 .70666 Mdot
.45076 .70122 Mdot
.48727 .29671 Mdot
.31658 .42048 Mdot
.33024 .61895 Mdot
.29622 .47911 Mdot
.48388 .29254 Mdot
.64349 .65131 Mdot
.71216 .46091 Mdot
.59507 .68756 Mdot
.64239 .64994 Mdot
.41153 .3005 Mdot
.69178 .38675 Mdot
.32678 .61169 Mdot
.58272 .70831 Mdot
.63211 .33928 Mdot
.56406 .2995 Mdot
.33805 .65221 Mdot
.68047 .59529 Mdot
.47754 .71505 Mdot
.63383 .66864 Mdot
.66742 .63258 Mdot
.70499 .53593 Mdot
.28532 .55512 Mdot
.6245 .67394 Mdot
.6944 .58514 Mdot
.71774 .49903 Mdot
.53922 .70422 Mdot
.54905 .70126 Mdot
.65125 .35631 Mdot
.62003 .66748 Mdot
.37253 .3254 Mdot
.70603 .56106 Mdot
.31208 .42651 Mdot
.70377 .54236 Mdot
.63721 .65877 Mdot
.6952 .39259 Mdot
.6705 .63817 Mdot
.68777 .41684 Mdot
.67034 .37823 Mdot
.50914 .27545 Mdot
.69769 .54692 Mdot
.34102 .34744 Mdot
.31142 .59475 Mdot
.32748 .38997 Mdot
.65288 .35889 Mdot
.31627 .37798 Mdot
.50942 .29893 Mdot
.4242 .31384 Mdot
.42182 .3064 Mdot
.55539 .28691 Mdot
.59848 .30303 Mdot
.70047 .5918 Mdot
.56845 .29276 Mdot
.30337 .54621 Mdot
.33809 .62929 Mdot
.68877 .38028 Mdot
.30394 .46674 Mdot
.40523 .67625 Mdot
.57072 .28925 Mdot
.38491 .3356 Mdot
.64887 .66051 Mdot
.66501 .37996 Mdot
.38126 .68278 Mdot
.64191 .34606 Mdot
.31271 .4325 Mdot
.32168 .599 Mdot
.56837 .71026 Mdot
.30416 .44144 Mdot
.41636 .29723 Mdot
.5277 .70233 Mdot
.69222 .39575 Mdot
.328 .3898 Mdot
.56796 .3108 Mdot
.46533 .27646 Mdot
.29814 .5004 Mdot
.65432 .34793 Mdot
.6979 .44904 Mdot
.29266 .53914 Mdot
.56218 .29751 Mdot
.68957 .42058 Mdot
.63154 .68026 Mdot
.48882 .27412 Mdot
.51237 .70108 Mdot
.60927 .69632 Mdot
.30735 .55813 Mdot
.28069 .53064 Mdot
.72287 .48568 Mdot
.34751 .36099 Mdot
.70887 .55944 Mdot
.58592 .70817 Mdot
.48859 .70432 Mdot
.48323 .71267 Mdot
.62593 .67244 Mdot
.29958 .42823 Mdot
.68231 .39964 Mdot
.30302 .59924 Mdot
.29794 .52484 Mdot
.72301 .47532 Mdot
.29635 .46316 Mdot
.34232 .64759 Mdot
.28779 .47157 Mdot
.52661 .72299 Mdot
.46903 .70541 Mdot
.70702 .47702 Mdot
.61915 .69408 Mdot
.28583 .54718 Mdot
.48957 .71477 Mdot
.69659 .60134 Mdot
.55134 .29535 Mdot
.65408 .6653 Mdot
.46848 .6987 Mdot
.51909 .29324 Mdot
.55566 .29532 Mdot
.3144 .40984 Mdot
.3033 .45779 Mdot
.34119 .34241 Mdot
.33051 .61159 Mdot
.59509 .68621 Mdot
.58151 .70161 Mdot
.63793 .65663 Mdot
.32976 .60675 Mdot
.70072 .55288 Mdot
.6082 .70205 Mdot
.45226 .69219 Mdot
.33421 .63085 Mdot
.50749 .28031 Mdot
.64891 .35097 Mdot
.61009 .69528 Mdot
.29734 .52616 Mdot
.71477 .50852 Mdot
.39645 .68887 Mdot
.65723 .36447 Mdot
.70024 .41109 Mdot
.62989 .34251 Mdot
.56229 .29303 Mdot
.3267 .3979 Mdot
.32146 .59807 Mdot
.64103 .34503 Mdot
.31069 .39208 Mdot
.48152 .28652 Mdot
.65798 .64607 Mdot
.5203 .27639 Mdot
.59805 .30466 Mdot
.66971 .37053 Mdot
.66726 .38664 Mdot
.70241 .56491 Mdot
.62953 .67053 Mdot
.29092 .52718 Mdot
.48656 .29333 Mdot
.3566 .35355 Mdot
.57315 .70301 Mdot
.69704 .4061 Mdot
.66924 .64665 Mdot
.56888 .71147 Mdot
.43481 .68842 Mdot
.41694 .68347 Mdot
.29429 .59075 Mdot
.42834 .69858 Mdot
.43253 .69746 Mdot
.61021 .32733 Mdot
.31787 .40376 Mdot
.50081 .72446 Mdot
.30622 .60467 Mdot
.39376 .67732 Mdot
.3795 .68334 Mdot
.59748 .69752 Mdot
.70569 .57145 Mdot
.64802 .34801 Mdot
.3789 .31608 Mdot
.32433 .36833 Mdot
.362 .65175 Mdot
.53545 .28527 Mdot
.60303 .30229 Mdot
.30202 .41796 Mdot
.3196 .59432 Mdot
.51311 .70734 Mdot
.65469 .64147 Mdot
.67413 .63383 Mdot
.67282 .62792 Mdot
.50601 .70669 Mdot
.28279 .52687 Mdot
.41131 .30538 Mdot
.64966 .65423 Mdot
.70938 .41984 Mdot
.39251 .6821 Mdot
.34098 .62662 Mdot
.68775 .406 Mdot
.58303 .71057 Mdot
.58881 .31885 Mdot
.66465 .62059 Mdot
.51333 .28694 Mdot
.66953 .36226 Mdot
.41306 .69472 Mdot
.53706 .70288 Mdot
.55877 .69752 Mdot
.41372 .68808 Mdot
.68144 .38316 Mdot
.69223 .42263 Mdot
.70619 .49362 Mdot
.54822 .29466 Mdot
.5819 .69281 Mdot
.43939 .2978 Mdot
.28616 .5484 Mdot
.62666 .32726 Mdot
.60862 .67247 Mdot
.36816 .33911 Mdot
.72175 .4899 Mdot
.35951 .66982 Mdot
.66675 .62259 Mdot
.30148 .58436 Mdot
.64294 .67421 Mdot
.39026 .32668 Mdot
.71334 .45624 Mdot
.7233 .49258 Mdot
.28501 .44464 Mdot
.61265 .67964 Mdot
.32507 .63618 Mdot
.30486 .45814 Mdot
.32601 .60108 Mdot
.55246 .69823 Mdot
.36682 .67544 Mdot
.58122 .30371 Mdot
.50124 .7241 Mdot
.60582 .68358 Mdot
.4437 .6953 Mdot
.55642 .7046 Mdot
.55159 .29795 Mdot
.68615 .57769 Mdot
.30898 .58404 Mdot
.30853 .44567 Mdot
.70378 .54096 Mdot
.3491 .66024 Mdot
.45444 .29225 Mdot
.31385 .40919 Mdot
.29196 .49584 Mdot
.3253 .59566 Mdot
.53896 .70001 Mdot
.49976 .71456 Mdot
.28272 .54541 Mdot
.56274 .70696 Mdot
.70182 .5631 Mdot
.40238 .311 Mdot
.70144 .5396 Mdot
.38453 .67964 Mdot
.36876 .67356 Mdot
.54177 .29566 Mdot
.63986 .34312 Mdot
.35372 .64329 Mdot
.38651 .33071 Mdot
.61081 .69087 Mdot
.53164 .70491 Mdot
.69954 .46917 Mdot
.54715 .71781 Mdot
.38531 .6803 Mdot
.56706 .71024 Mdot
.69939 .51573 Mdot
.66696 .35306 Mdot
.47592 .71462 Mdot
.70919 .5446 Mdot
.67393 .38151 Mdot
.33824 .63167 Mdot
.53603 .28191 Mdot
.5917 .68426 Mdot
.58376 .30168 Mdot
.70505 .49702 Mdot
.30255 .51456 Mdot
.60964 .31737 Mdot
.30272 .51351 Mdot
.71612 .48543 Mdot
.48965 .70621 Mdot
.69747 .46177 Mdot
.32867 .6374 Mdot
.33853 .35412 Mdot
.3602 .35368 Mdot
.29276 .56038 Mdot
.62828 .33225 Mdot
.29477 .53996 Mdot
.35043 .64353 Mdot
.39296 .30676 Mdot
.67125 .38217 Mdot
.43011 .30634 Mdot
.38948 .33276 Mdot
.48418 .29847 Mdot
.4335 .68972 Mdot
.61375 .68085 Mdot
.42282 .31088 Mdot
.49103 .27855 Mdot
.65452 .34521 Mdot
.45024 .70163 Mdot
.29393 .48805 Mdot
.38101 .32016 Mdot
.35642 .32637 Mdot
.70781 .46791 Mdot
.72467 .49355 Mdot
.499 .70787 Mdot
.44118 .28528 Mdot
.65507 .6634 Mdot
.71073 .54361 Mdot
.33522 .61923 Mdot
.57302 .7152 Mdot
.63087 .67864 Mdot
.43841 .29148 Mdot
.29937 .49164 Mdot
.6742 .62616 Mdot
.30335 .41307 Mdot
.63883 .66756 Mdot
.40118 .68137 Mdot
.2823 .54355 Mdot
.51837 .70806 Mdot
.30483 .56229 Mdot
.62407 .33395 Mdot
.45014 .69894 Mdot
.4867 .28732 Mdot
.34405 .34574 Mdot
.50363 .70767 Mdot
.30317 .44972 Mdot
.45692 .28528 Mdot
.30086 .57964 Mdot
.32926 .61745 Mdot
.71839 .50896 Mdot
.56495 .71712 Mdot
.30985 .40907 Mdot
.35504 .66033 Mdot
.44493 .69375 Mdot
.36845 .3414 Mdot
.44571 .29317 Mdot
.29895 .59428 Mdot
.58668 .69113 Mdot
.46713 .29559 Mdot
.54227 .28724 Mdot
.36044 .67173 Mdot
.58133 .29488 Mdot
.581 .71533 Mdot
.49326 .70884 Mdot
.61221 .32502 Mdot
.70139 .46667 Mdot
.54656 .69678 Mdot
.42961 .70297 Mdot
.59024 .31559 Mdot
.64118 .66335 Mdot
.65076 .66894 Mdot
.32931 .63995 Mdot
.54888 .30278 Mdot
.32998 .35241 Mdot
.3639 .34974 Mdot
.34998 .65123 Mdot
.60513 .30894 Mdot
.32011 .60714 Mdot
.35111 .34083 Mdot
.63058 .67453 Mdot
.59278 .30997 Mdot
.69971 .53191 Mdot
.4657 .28815 Mdot
.40409 .32074 Mdot
.70188 .43356 Mdot
.6701 .61516 Mdot
.4017 .68175 Mdot
.50888 .28529 Mdot
.29279 .45274 Mdot
.37312 .65981 Mdot
.70981 .42031 Mdot
.50212 .71332 Mdot
.63915 .659 Mdot
.51772 .71154 Mdot
.28975 .57161 Mdot
.31742 .3997 Mdot
.29183 .48226 Mdot
.29752 .49949 Mdot
.56794 .69217 Mdot
.54091 .28612 Mdot
.43428 .29396 Mdot
.30362 .58045 Mdot
.55769 .29194 Mdot
.53429 .722 Mdot
.40461 .31586 Mdot
.7107 .50325 Mdot
.48239 .70867 Mdot
.31584 .57752 Mdot
.51763 .29933 Mdot
.71865 .4634 Mdot
.323 .36534 Mdot
.5548 .69816 Mdot
.68444 .39838 Mdot
.57578 .29831 Mdot
.61521 .69049 Mdot
.34074 .35034 Mdot
.29158 .4959 Mdot
.35843 .34804 Mdot
.49956 .69953 Mdot
.55557 .69886 Mdot
.30257 .497 Mdot
.47453 .70582 Mdot
.68531 .41723 Mdot
.68128 .5956 Mdot
.705 .56875 Mdot
.42997 .69589 Mdot
.70191 .39973 Mdot
.46087 .28125 Mdot
.30342 .57839 Mdot
.66735 .63305 Mdot
.56594 .70463 Mdot
.67586 .39148 Mdot
.4505 .29143 Mdot
.40199 .2981 Mdot
.55326 .29736 Mdot
.33737 .3529 Mdot
.53678 .28498 Mdot
.40633 .68145 Mdot
.66707 .36036 Mdot
.36554 .33562 Mdot
.29929 .54615 Mdot
.29896 .40622 Mdot
.43351 .7044 Mdot
.40115 .30601 Mdot
.33373 .37408 Mdot
.71332 .54371 Mdot
.62651 .31679 Mdot
.28442 .56677 Mdot
.67878 .60635 Mdot
.63858 .67222 Mdot
.52162 .71225 Mdot
.29557 .47973 Mdot
.54402 .29613 Mdot
.70496 .47238 Mdot
.29028 .47001 Mdot
.3829 .67883 Mdot
.68748 .41524 Mdot
.37553 .68106 Mdot
.64828 .64549 Mdot
.70359 .40511 Mdot
.6985 .59859 Mdot
.56716 .30743 Mdot
.63158 .33444 Mdot
.4012 .69384 Mdot
.67561 .60444 Mdot
.36345 .66315 Mdot
.32683 .37333 Mdot
.70874 .57355 Mdot
.41197 .30816 Mdot
.466 .30071 Mdot
.31738 .40998 Mdot
.59749 .32071 Mdot
.30082 .45661 Mdot
.69417 .55246 Mdot
.4513 .28202 Mdot
.50153 .2961 Mdot
.36692 .32737 Mdot
.30535 .59066 Mdot
.68763 .57502 Mdot
.31456 .61326 Mdot
.31097 .60805 Mdot
.4358 .28985 Mdot
.63544 .33403 Mdot
.66096 .36264 Mdot
.39219 .67623 Mdot
.63728 .33653 Mdot
.38536 .32041 Mdot
.65115 .64631 Mdot
.70845 .56815 Mdot
.47127 .28112 Mdot
.71824 .50829 Mdot
.40109 .67449 Mdot
.33998 .37696 Mdot
.39689 .31648 Mdot
.5446 .29144 Mdot
.59081 .29817 Mdot
.30189 .5485 Mdot
.7072 .46502 Mdot
.6139 .31711 Mdot
.63703 .34865 Mdot
.59816 .30368 Mdot
.59619 .69042 Mdot
.60047 .32295 Mdot
.62967 .33653 Mdot
.51337 .70059 Mdot
.53555 .7193 Mdot
.28795 .50638 Mdot
.29106 .5796 Mdot
.70054 .563 Mdot
.29046 .52332 Mdot
.50367 .71845 Mdot
.35535 .34692 Mdot
.28389 .55722 Mdot
.30313 .53765 Mdot
.3599 .33024 Mdot
.37189 .32043 Mdot
.31324 .61188 Mdot
.28168 .55152 Mdot
.68403 .4139 Mdot
.69611 .54625 Mdot
.69217 .39624 Mdot
.32174 .38499 Mdot
.44252 .28017 Mdot
.69887 .46793 Mdot
.4825 .69942 Mdot
.3019 .47417 Mdot
.39217 .32451 Mdot
.67016 .38532 Mdot
.45053 .70514 Mdot
.29556 .52725 Mdot
.35568 .65247 Mdot
.2994 .55331 Mdot
.2831 .51691 Mdot
.68145 .3767 Mdot
.58326 .29768 Mdot
.70604 .42336 Mdot
.29857 .41961 Mdot
.30012 .58162 Mdot
.68312 .39063 Mdot
.30081 .44187 Mdot
.38115 .30931 Mdot
.67743 .59906 Mdot
.42842 .69536 Mdot
.38234 .31416 Mdot
.63576 .32863 Mdot
.55697 .2834 Mdot
.69516 .60385 Mdot
.63975 .34402 Mdot
.30184 .45977 Mdot
.2877 .54588 Mdot
.37965 .32053 Mdot
.69014 .41566 Mdot
.71193 .53984 Mdot
.64029 .34831 Mdot
.48351 .29665 Mdot
.50729 .70964 Mdot
.68447 .39831 Mdot
.29205 .51472 Mdot
.65385 .35344 Mdot
.36727 .34502 Mdot
.36769 .66058 Mdot
.55278 .70682 Mdot
.4884 .28062 Mdot
.45066 .69613 Mdot
.46844 .29964 Mdot
.31823 .5782 Mdot
.71973 .53129 Mdot
.52923 .71246 Mdot
.65544 .64744 Mdot
.50349 .29617 Mdot
.49514 .69968 Mdot
.63891 .64698 Mdot
.70133 .41245 Mdot
.70695 .44277 Mdot
.52884 .72285 Mdot
.41202 .31017 Mdot
.28048 .4755 Mdot
.49046 .70692 Mdot
.28027 .45981 Mdot
.69818 .58754 Mdot
.31066 .59357 Mdot
.40066 .68729 Mdot
.58626 .69816 Mdot
.55115 .71066 Mdot
.45058 .70999 Mdot
.47834 .69961 Mdot
.68269 .62272 Mdot
.34634 .34447 Mdot
.33004 .35581 Mdot
.34696 .64071 Mdot
.66484 .6523 Mdot
.37103 .67175 Mdot
.4449 .2922 Mdot
.69581 .55012 Mdot
.30719 .45107 Mdot
.64182 .34173 Mdot
.4515 .69812 Mdot
.3381 .36618 Mdot
.52441 .70968 Mdot
.71351 .52736 Mdot
.38175 .32145 Mdot
.38148 .33133 Mdot
.30965 .40383 Mdot
.38774 .68068 Mdot
.6485 .36132 Mdot
.41863 .69291 Mdot
.37526 .66007 Mdot
.30314 .54542 Mdot
.6757 .6355 Mdot
.66984 .36398 Mdot
.6585 .36412 Mdot
.64974 .36499 Mdot
.47583 .71764 Mdot
.47432 .71781 Mdot
.44493 .29935 Mdot
.69508 .42845 Mdot
.60897 .32835 Mdot
.39256 .31022 Mdot
.2786 .47415 Mdot
.54231 .71149 Mdot
.31784 .58578 Mdot
.35438 .66495 Mdot
.31091 .39473 Mdot
.2836 .50701 Mdot
.36931 .67732 Mdot
.48141 .72024 Mdot
.38292 .31691 Mdot
.39269 .6844 Mdot
.60651 .3149 Mdot
.43245 .28339 Mdot
.37414 .67303 Mdot
.2946 .50148 Mdot
.69619 .41357 Mdot
.60123 .69186 Mdot
.33268 .63837 Mdot
.44952 .28435 Mdot
.69622 .5982 Mdot
.28139 .51776 Mdot
.31599 .58661 Mdot
.60273 .68175 Mdot
.35679 .33894 Mdot
.29652 .4973 Mdot
.40662 .69945 Mdot
.7153 .55327 Mdot
.32543 .62026 Mdot
.65775 .36068 Mdot
.70672 .56677 Mdot
.55725 .71299 Mdot
.72101 .51595 Mdot
.50844 .27615 Mdot
.32269 .37675 Mdot
.32779 .36755 Mdot
.698 .46981 Mdot
.65686 .64362 Mdot
.42751 .31026 Mdot
.66082 .64175 Mdot
.40156 .68713 Mdot
.51107 .70041 Mdot
.41723 .70016 Mdot
.68572 .59454 Mdot
.38501 .6901 Mdot
.37195 .66758 Mdot
.50701 .29123 Mdot
.54885 .28609 Mdot
.55441 .30006 Mdot
.41615 .30815 Mdot
.65394 .63795 Mdot
.32814 .36272 Mdot
.59866 .31027 Mdot
.3442 .64968 Mdot
.29406 .43475 Mdot
.4145 .68734 Mdot
.50058 .71841 Mdot
.72341 .50067 Mdot
.29217 .48974 Mdot
.52944 .70012 Mdot
.47055 .297 Mdot
.30984 .39308 Mdot
.36547 .31969 Mdot
.69821 .48522 Mdot
.60863 .32126 Mdot
.37607 .33394 Mdot
.40408 .68908 Mdot
.35107 .66332 Mdot
.66904 .64511 Mdot
.316 .62825 Mdot
.34563 .35475 Mdot
.58437 .71103 Mdot
.6717 .38554 Mdot
.3522 .36198 Mdot
.44453 .69688 Mdot
.37593 .34077 Mdot
.27826 .50837 Mdot
.71392 .54512 Mdot
.58494 .69497 Mdot
.43375 .28398 Mdot
.66396 .63572 Mdot
.3865 .68795 Mdot
.30272 .49547 Mdot
.6059 .67455 Mdot
.35437 .33755 Mdot
.30407 .39562 Mdot
.37346 .66657 Mdot
.714 .42855 Mdot
.66717 .37314 Mdot
.68364 .41186 Mdot
.46832 .29846 Mdot
.48419 .70414 Mdot
.37758 .32074 Mdot
.70312 .45224 Mdot
.60973 .69138 Mdot
.58245 .30933 Mdot
.298 .41042 Mdot
.47321 .70535 Mdot
.52719 .7117 Mdot
.36667 .66241 Mdot
.38292 .66508 Mdot
.30576 .57084 Mdot
.37731 .31068 Mdot
.57256 .69052 Mdot
.70657 .52526 Mdot
.47505 .71472 Mdot
.66928 .36554 Mdot
.2939 .54135 Mdot
.3614 .66759 Mdot
.55163 .69549 Mdot
.6284 .66341 Mdot
.66571 .36321 Mdot
.57478 .31132 Mdot
.29824 .55138 Mdot
.58163 .68904 Mdot
.46413 .70149 Mdot
.56188 .71369 Mdot
.70312 .56348 Mdot
.40796 .67826 Mdot
.33219 .38507 Mdot
.70773 .50495 Mdot
.33886 .61935 Mdot
.64412 .35604 Mdot
.30089 .43907 Mdot
.67674 .59767 Mdot
.66297 .62382 Mdot
.7037 .40391 Mdot
.64233 .33048 Mdot
.48588 .29667 Mdot
.59616 .31594 Mdot
.32068 .5884 Mdot
.50773 .7038 Mdot
.28718 .55301 Mdot
.63335 .34295 Mdot
.32602 .37396 Mdot
.37106 .67378 Mdot
.2917 .45441 Mdot
.48216 .71333 Mdot
.363 .33123 Mdot
.29544 .58022 Mdot
.68488 .393 Mdot
.35194 .34832 Mdot
.29128 .49615 Mdot
.33706 .62534 Mdot
.6902 .60386 Mdot
.30852 .43937 Mdot
.30022 .50751 Mdot
.52271 .70783 Mdot
.7133 .49649 Mdot
.71908 .51095 Mdot
.32732 .63602 Mdot
.32212 .36392 Mdot
.29476 .51029 Mdot
.7129 .4903 Mdot
.71765 .53523 Mdot
.34167 .3657 Mdot
.69723 .45119 Mdot
.6799 .59766 Mdot
.30315 .52306 Mdot
.66289 .35352 Mdot
.29098 .47097 Mdot
.65032 .36987 Mdot
.61027 .69029 Mdot
.4173 .68054 Mdot
.41975 .30724 Mdot
.36149 .65955 Mdot
.4319 .29749 Mdot
.51919 .294 Mdot
.49883 .29228 Mdot
.43969 .30568 Mdot
.45965 .70085 Mdot
.63178 .33733 Mdot
.56353 .29108 Mdot
.70538 .4775 Mdot
.377 .33672 Mdot
.41002 .31279 Mdot
.72263 .49681 Mdot
.36907 .67446 Mdot
.41709 .68977 Mdot
.32784 .37257 Mdot
.3217 .40166 Mdot
.68299 .39114 Mdot
.38974 .6892 Mdot
.68445 .58931 Mdot
.30994 .43644 Mdot
.65895 .65743 Mdot
.70966 .41522 Mdot
.29006 .55172 Mdot
.69371 .44399 Mdot
.63613 .67664 Mdot
.40503 .30549 Mdot
.30967 .42614 Mdot
.66196 .63879 Mdot
.40923 .29976 Mdot
.58324 .30308 Mdot
.34936 .34855 Mdot
.46358 .70726 Mdot
.29232 .44925 Mdot
.34898 .64944 Mdot
.66809 .6123 Mdot
.30479 .58373 Mdot
.70241 .4787 Mdot
.55886 .28661 Mdot
.2815 .55229 Mdot
.43219 .29759 Mdot
.55737 .302 Mdot
.69503 .39442 Mdot
.55651 .71253 Mdot
.38477 .32699 Mdot
.41796 .31492 Mdot
.41091 .69453 Mdot
.34011 .37528 Mdot
.66383 .37808 Mdot
.37853 .31344 Mdot
.63243 .66406 Mdot
.52495 .72229 Mdot
.27916 .52667 Mdot
.29168 .56512 Mdot
.32006 .40817 Mdot
.49491 .69921 Mdot
.71254 .43828 Mdot
.32685 .35936 Mdot
.38117 .33831 Mdot
.7199 .52345 Mdot
.55236 .28639 Mdot
.32245 .63549 Mdot
.3892 .31932 Mdot
.5901 .68461 Mdot
.54271 .71067 Mdot
.52053 .29038 Mdot
.38402 .32227 Mdot
.29449 .4681 Mdot
.48646 .28101 Mdot
.7027 .43624 Mdot
.67254 .6333 Mdot
.7103 .45936 Mdot
.36922 .67671 Mdot
.33527 .36226 Mdot
.44023 .29542 Mdot
.29911 .56959 Mdot
.2824 .46875 Mdot
.4291 .30774 Mdot
.65222 .35694 Mdot
.55813 .71428 Mdot
.59641 .69957 Mdot
.47482 .70536 Mdot
.6742 .64199 Mdot
.3871 .68483 Mdot
.52646 .2978 Mdot
.48774 .29529 Mdot
.67093 .63539 Mdot
.39284 .68572 Mdot
.3384 .34838 Mdot
.37855 .32335 Mdot
.50711 .28679 Mdot
.28255 .52185 Mdot
.33491 .35221 Mdot
.53021 .70867 Mdot
.28807 .441 Mdot
.69729 .40513 Mdot
.54889 .28514 Mdot
.5648 .70535 Mdot
.43095 .30727 Mdot
.68252 .37761 Mdot
.65858 .63591 Mdot
.482 .70419 Mdot
.3283 .63449 Mdot
.58828 .30846 Mdot
.58352 .29504 Mdot
.34009 .37727 Mdot
.45923 .69506 Mdot
.4533 .29425 Mdot
.30035 .45553 Mdot
.29175 .43358 Mdot
.62545 .33762 Mdot
.39065 .33194 Mdot
.53933 .28151 Mdot
.29891 .58987 Mdot
.33802 .61815 Mdot
.35446 .35007 Mdot
.35391 .35816 Mdot
.70284 .54869 Mdot
.37876 .66126 Mdot
.35817 .67207 Mdot
.63638 .32681 Mdot
.59106 .31788 Mdot
.71614 .52155 Mdot
.59088 .68465 Mdot
.46683 .71662 Mdot
.54202 .29602 Mdot
.66896 .35937 Mdot
.57958 .71442 Mdot
.46053 .71115 Mdot
.60401 .69429 Mdot
.70351 .42027 Mdot
.62333 .32331 Mdot
.6598 .65317 Mdot
.70704 .5484 Mdot
.64949 .63954 Mdot
.64876 .34954 Mdot
.6516 .36163 Mdot
.66332 .62506 Mdot
.70641 .54085 Mdot
.69464 .43268 Mdot
.5518 .28857 Mdot
.58394 .30373 Mdot
.63386 .34573 Mdot
.72421 .50435 Mdot
.53718 .29523 Mdot
.70904 .47632 Mdot
.40698 .31837 Mdot
.64336 .64282 Mdot
.60467 .30452 Mdot
.70616 .5772 Mdot
.58149 .30406 Mdot
.65269 .65586 Mdot
.70353 .57992 Mdot
.40962 .67916 Mdot
.55245 .7142 Mdot
.37383 .65985 Mdot
.2997 .56874 Mdot
.31321 .6124 Mdot
.5442 .29588 Mdot
.4326 .70181 Mdot
.70857 .48958 Mdot
.45802 .71337 Mdot
.54608 .71791 Mdot
.60054 .68197 Mdot
.59824 .67954 Mdot
.62863 .34139 Mdot
.70669 .49417 Mdot
.28461 .44889 Mdot
.31281 .38674 Mdot
.63176 .66065 Mdot
.5863 .30636 Mdot
.65331 .35139 Mdot
.60708 .32591 Mdot
.35328 .33909 Mdot
.38652 .3268 Mdot
.28935 .53015 Mdot
.29659 .49675 Mdot
.35758 .34243 Mdot
.28546 .44291 Mdot
.64444 .66049 Mdot
.69879 .46102 Mdot
.70813 .50711 Mdot
.57856 .70628 Mdot
.61033 .69623 Mdot
.35863 .65671 Mdot
.30863 .43738 Mdot
.4639 .2966 Mdot
.66566 .63851 Mdot
.49051 .72257 Mdot
.30057 .51246 Mdot
.49864 .27374 Mdot
.33024 .62833 Mdot
.56073 .2887 Mdot
.33155 .61587 Mdot
.34915 .35952 Mdot
.47017 .70543 Mdot
.44589 .7077 Mdot
.48392 .29419 Mdot
.31593 .39471 Mdot
.39131 .31273 Mdot
.36093 .66226 Mdot
.57924 .70355 Mdot
.371 .32672 Mdot
.60599 .30369 Mdot
.66871 .36114 Mdot
.29428 .57812 Mdot
.45623 .70668 Mdot
.58784 .69678 Mdot
.71586 .53962 Mdot
.30286 .55226 Mdot
.29827 .54809 Mdot
.60135 .31354 Mdot
.64249 .66733 Mdot
.39809 .29869 Mdot
.30056 .49561 Mdot
.62921 .34375 Mdot
.37853 .33054 Mdot
.30252 .55444 Mdot
.31735 .62116 Mdot
.42007 .69959 Mdot
.3091 .61672 Mdot
.64811 .3422 Mdot
.71148 .45248 Mdot
.69051 .56724 Mdot
.64858 .3326 Mdot
.32808 .60473 Mdot
.34323 .65271 Mdot
.31636 .41658 Mdot
.48591 .28637 Mdot
.63395 .68055 Mdot
.34948 .65619 Mdot
.62169 .33595 Mdot
.72103 .4943 Mdot
.70958 .52592 Mdot
.69632 .55782 Mdot
.7074 .47485 Mdot
.54473 .70083 Mdot
.32051 .39705 Mdot
.65151 .3549 Mdot
.70221 .53812 Mdot
.60147 .70286 Mdot
.68175 .39847 Mdot
.58399 .31502 Mdot
.6793 .60308 Mdot
.6338 .33882 Mdot
.67794 .62881 Mdot
.59545 .31976 Mdot
.64181 .65683 Mdot
.36607 .32076 Mdot
.31519 .42042 Mdot
.54627 .29082 Mdot
.30071 .40756 Mdot
.36993 .32528 Mdot
.39337 .31413 Mdot
.6197 .32279 Mdot
.3308 .37823 Mdot
.70599 .49832 Mdot
.29319 .45134 Mdot
.5831 .68891 Mdot
.32188 .5989 Mdot
.31775 .40747 Mdot
.63946 .35098 Mdot
.59863 .30891 Mdot
.39644 .67605 Mdot
.54994 .72059 Mdot
.44073 .28809 Mdot
.34363 .63731 Mdot
.65111 .64579 Mdot
.33608 .61929 Mdot
.34181 .34783 Mdot
.52956 .69723 Mdot
.54417 .7108 Mdot
.41943 .29173 Mdot
.36306 .6605 Mdot
.64834 .36 Mdot
.70013 .55308 Mdot
.43903 .30213 Mdot
.3513 .65276 Mdot
.36747 .67321 Mdot
.48161 .70466 Mdot
.71229 .45636 Mdot
.41076 .30563 Mdot
.50544 .28274 Mdot
.27917 .49974 Mdot
.67879 .62975 Mdot
.62172 .67685 Mdot
.52125 .71525 Mdot
.64476 .64795 Mdot
.29973 .43975 Mdot
.55319 .29162 Mdot
.52705 .71506 Mdot
.29991 .44887 Mdot
.46923 .69678 Mdot
.67569 .36784 Mdot
.30717 .42413 Mdot
.29646 .5907 Mdot
.28882 .50395 Mdot
.44404 .69987 Mdot
.43377 .70782 Mdot
.58741 .69122 Mdot
.52243 .28856 Mdot
.30473 .59191 Mdot
.30547 .40342 Mdot
.66917 .38171 Mdot
.41893 .69843 Mdot
.70373 .55766 Mdot
.52228 .2899 Mdot
.37216 .32709 Mdot
.42466 .70245 Mdot
.36419 .64973 Mdot
.71363 .55999 Mdot
.5369 .72004 Mdot
.4459 .70156 Mdot
.57563 .3081 Mdot
.50694 .28098 Mdot
.71218 .42029 Mdot
.27863 .52894 Mdot
.68259 .39208 Mdot
.4683 .28693 Mdot
.4299 .70631 Mdot
.28917 .55771 Mdot
.71074 .42985 Mdot
.29106 .56904 Mdot
.5145 .27652 Mdot
.60075 .68629 Mdot
.71177 .4549 Mdot
.29339 .56126 Mdot
.70076 .57916 Mdot
.71593 .51293 Mdot
.611 .67707 Mdot
.44235 .691 Mdot
.66307 .3732 Mdot
.65315 .35568 Mdot
.71189 .47692 Mdot
.28792 .5427 Mdot
.48854 .71464 Mdot
.42277 .6896 Mdot
.43329 .6853 Mdot
.67459 .36963 Mdot
.45974 .70169 Mdot
.66237 .38185 Mdot
.63445 .65398 Mdot
.35592 .32738 Mdot
.46094 .71292 Mdot
.53531 .28744 Mdot
.42609 .68832 Mdot
.37547 .68242 Mdot
.68187 .61455 Mdot
.70417 .5645 Mdot
.5614 .2949 Mdot
.5821 .71091 Mdot
.29788 .46122 Mdot
.43111 .70241 Mdot
.32885 .61156 Mdot
.43071 .28852 Mdot
.60577 .68717 Mdot
.68935 .41941 Mdot
.64265 .35149 Mdot
.35551 .35161 Mdot
.59077 .30646 Mdot
.33823 .3548 Mdot
.69584 .5467 Mdot
.28389 .55032 Mdot
.29216 .44205 Mdot
.59455 .68364 Mdot
.62571 .67592 Mdot
.29394 .48201 Mdot
.70151 .49523 Mdot
.32825 .38985 Mdot
.61727 .69403 Mdot
.72325 .49842 Mdot
.36974 .66165 Mdot
.33556 .62193 Mdot
.39418 .67726 Mdot
.70525 .46217 Mdot
.60228 .31237 Mdot
.57775 .30843 Mdot
.42946 .30949 Mdot
.38876 .69007 Mdot
.47343 .27508 Mdot
.51246 .27932 Mdot
.32588 .39827 Mdot
.56149 .28799 Mdot
.4815 .71613 Mdot
.31356 .61084 Mdot
.69816 .42345 Mdot
.30068 .55603 Mdot
.63174 .68063 Mdot
.38919 .33389 Mdot
.28466 .54123 Mdot
.37246 .657 Mdot
.53208 .28142 Mdot
.36495 .341 Mdot
.56171 .71241 Mdot
.65405 .35582 Mdot
.72259 .46703 Mdot
.28332 .495 Mdot
.70242 .5674 Mdot
.69444 .58082 Mdot
.7057 .41875 Mdot
.31484 .60231 Mdot
.27802 .49248 Mdot
.68696 .59235 Mdot
.49613 .29479 Mdot
.31072 .56431 Mdot
.31616 .39671 Mdot
.33116 .36602 Mdot
.36438 .33558 Mdot
.64197 .67255 Mdot
.34156 .34184 Mdot
.67524 .61627 Mdot
.43753 .30216 Mdot
.44379 .28109 Mdot
.52784 .70287 Mdot
.37836 .32445 Mdot
.30236 .5036 Mdot
.54114 .70798 Mdot
.70642 .43791 Mdot
.36993 .32029 Mdot
.40816 .67757 Mdot
.28631 .43784 Mdot
.48365 .29778 Mdot
.28778 .54026 Mdot
.6973 .59795 Mdot
.55953 .29083 Mdot
.63831 .33239 Mdot
.61534 .67374 Mdot
.3474 .65 Mdot
.71585 .46364 Mdot
.31547 .57807 Mdot
.35815 .66971 Mdot
.6438 .64338 Mdot
.63048 .32071 Mdot
.30153 .60338 Mdot
.33618 .62515 Mdot
.37155 .65425 Mdot
.3609 .33714 Mdot
.29977 .44699 Mdot
.29462 .50622 Mdot
.56367 .71217 Mdot
.3017 .42476 Mdot
.53925 .28675 Mdot
.52104 .71605 Mdot
.39611 .3118 Mdot
.30631 .60334 Mdot
.45555 .70878 Mdot
.70581 .55171 Mdot
.70031 .41432 Mdot
.29246 .58372 Mdot
.32726 .612 Mdot
.70914 .44406 Mdot
.51011 .71249 Mdot
.32907 .60245 Mdot
.27993 .49955 Mdot
.54433 .70409 Mdot
.61815 .32805 Mdot
.60673 .31546 Mdot
.32496 .37352 Mdot
.5735 .31128 Mdot
.41238 .31891 Mdot
.33121 .61248 Mdot
.4248 .70127 Mdot
.2893 .51883 Mdot
.68122 .59998 Mdot
.68232 .61036 Mdot
.34362 .36021 Mdot
.65088 .36284 Mdot
.54222 .30171 Mdot
.68358 .61212 Mdot
.53722 .70606 Mdot
.44541 .7026 Mdot
.30751 .42555 Mdot
.66894 .3776 Mdot
.45068 .70498 Mdot
.28804 .56637 Mdot
.53742 .7036 Mdot
.35053 .64212 Mdot
.36018 .32508 Mdot
.29881 .48539 Mdot
.6567 .34159 Mdot
.29169 .5495 Mdot
.39173 .31668 Mdot
.58505 .68468 Mdot
.64933 .6422 Mdot
.40883 .69082 Mdot
.65031 .34426 Mdot
.6837 .38046 Mdot
.38995 .32363 Mdot
.29818 .4461 Mdot
.69654 .57104 Mdot
.6992 .55832 Mdot
.54197 .70875 Mdot
.34125 .34889 Mdot
.31094 .38206 Mdot
.29005 .56371 Mdot
.28179 .5207 Mdot
.62575 .66295 Mdot
.3578 .35173 Mdot
.46766 .7046 Mdot
.72224 .50538 Mdot
.52617 .27705 Mdot
.70686 .45223 Mdot
.48705 .28315 Mdot
.54097 .27822 Mdot
.62437 .68824 Mdot
.5578 .69257 Mdot
.46019 .29859 Mdot
.50869 .29477 Mdot
.32966 .39376 Mdot
.62599 .65866 Mdot
.37363 .67383 Mdot
.59429 .68476 Mdot
.33655 .35427 Mdot
.50135 .71592 Mdot
.65421 .37036 Mdot
.28588 .4948 Mdot
.52489 .29425 Mdot
.41946 .6961 Mdot
.68465 .58182 Mdot
.30939 .41162 Mdot
.30163 .51105 Mdot
.30269 .57617 Mdot
.59124 .69484 Mdot
.46315 .70343 Mdot
.32577 .37225 Mdot
.69603 .58855 Mdot
.46617 .28684 Mdot
.32355 .40471 Mdot
.70354 .45923 Mdot
.4333 .69316 Mdot
.67937 .39867 Mdot
.52808 .27875 Mdot
.31097 .57371 Mdot
.38206 .67188 Mdot
.43512 .70495 Mdot
.67628 .59918 Mdot
.45331 .30064 Mdot
.69811 .56501 Mdot
.71086 .53297 Mdot
.29493 .51878 Mdot
.68529 .58895 Mdot
.5438 .72186 Mdot
.58605 .71371 Mdot
.30309 .54693 Mdot
.51615 .27852 Mdot
.62515 .68347 Mdot
.30291 .52836 Mdot
.68541 .6133 Mdot
.5674 .28926 Mdot
.69823 .56613 Mdot
.55109 .29671 Mdot
.32354 .40356 Mdot
.47892 .2975 Mdot
.3401 .62082 Mdot
.3236 .39895 Mdot
.71991 .45887 Mdot
.63225 .33735 Mdot
.60097 .32176 Mdot
.33753 .62649 Mdot
.54243 .29168 Mdot
.35646 .34777 Mdot
.49331 .29776 Mdot
.66101 .34282 Mdot
.58811 .68499 Mdot
.6241 .68782 Mdot
.56026 .30829 Mdot
.31539 .38635 Mdot
.63375 .34543 Mdot
.49319 .28887 Mdot
.70172 .58882 Mdot
.36724 .65358 Mdot
.43777 .69722 Mdot
.52985 .28073 Mdot
.31149 .41432 Mdot
.70329 .40905 Mdot
.33176 .62002 Mdot
.58241 .29458 Mdot
.34531 .36106 Mdot
.51665 .70341 Mdot
.52154 .2946 Mdot
.28578 .4568 Mdot
.48221 .29259 Mdot
.5905 .70288 Mdot
.28111 .53518 Mdot
.29052 .57346 Mdot
.68893 .39986 Mdot
.303 .46491 Mdot
.30084 .45506 Mdot
.50045 .29697 Mdot
.71683 .43654 Mdot
.28984 .43472 Mdot
.56391 .71269 Mdot
.69987 .54124 Mdot
.29189 .52661 Mdot
.66237 .36576 Mdot
.70692 .55577 Mdot
.28737 .5263 Mdot
.63551 .65243 Mdot
.70948 .45549 Mdot
.35487 .33276 Mdot
.52802 .70876 Mdot
.4533 .27927 Mdot
.45634 .28839 Mdot
.30112 .46175 Mdot
.43462 .29676 Mdot
.68503 .61374 Mdot
.62643 .31701 Mdot
.68805 .57537 Mdot
.3484 .64016 Mdot
.6866 .42317 Mdot
.28912 .56428 Mdot
.39154 .67305 Mdot
.51961 .70678 Mdot
.38686 .32598 Mdot
.29525 .42675 Mdot
.62838 .66178 Mdot
.64707 .34881 Mdot
.67626 .61822 Mdot
.69431 .57876 Mdot
.69902 .56165 Mdot
.42925 .30873 Mdot
.64912 .64614 Mdot
.46371 .70288 Mdot
.55896 .30618 Mdot
.69648 .60414 Mdot
.59883 .70163 Mdot
.30317 .45245 Mdot
.70549 .56182 Mdot
.4361 .28617 Mdot
.6989 .45887 Mdot
.38446 .32655 Mdot
.71464 .44114 Mdot
.7025 .46985 Mdot
.62578 .32699 Mdot
.47836 .27605 Mdot
.69201 .58573 Mdot
.41933 .2884 Mdot
.69817 .40483 Mdot
.60627 .69737 Mdot
.65903 .37662 Mdot
.27743 .49761 Mdot
.71896 .44779 Mdot
.6411 .33474 Mdot
.70179 .52618 Mdot
.66826 .37512 Mdot
.5547 .70957 Mdot
.56703 .70549 Mdot
.61404 .67117 Mdot
.29559 .44397 Mdot
.47976 .70731 Mdot
.31332 .61623 Mdot
.34652 .63614 Mdot
.70878 .42285 Mdot
.29863 .55322 Mdot
.66743 .61837 Mdot
.30519 .56123 Mdot
.51843 .71677 Mdot
.46114 .70936 Mdot
.69389 .5658 Mdot
.63947 .66376 Mdot
.29521 .43997 Mdot
.65064 .365 Mdot
.60355 .70106 Mdot
.28631 .44988 Mdot
.51146 .69988 Mdot
.67701 .61982 Mdot
.59092 .71025 Mdot
.38479 .327 Mdot
.69986 .45143 Mdot
.31129 .60862 Mdot
.67908 .40837 Mdot
.44781 .69458 Mdot
.3173 .60364 Mdot
.32332 .59355 Mdot
.45953 .70774 Mdot
.68158 .40364 Mdot
.70149 .56682 Mdot
.64738 .33904 Mdot
.677 .3798 Mdot
.53635 .70602 Mdot
.7015 .4424 Mdot
.62226 .32155 Mdot
.69981 .55804 Mdot
.30794 .41393 Mdot
.38608 .30838 Mdot
.61494 .68151 Mdot
.33211 .62225 Mdot
.50158 .70482 Mdot
.33566 .6436 Mdot
.31103 .59921 Mdot
.29707 .50571 Mdot
.54984 .6985 Mdot
.30416 .3998 Mdot
.32447 .61857 Mdot
.29662 .4393 Mdot
.65808 .34003 Mdot
.69062 .39412 Mdot
.47231 .28673 Mdot
.29724 .45618 Mdot
.29558 .50871 Mdot
.5839 .70189 Mdot
.66968 .63992 Mdot
.44151 .29825 Mdot
.68322 .38746 Mdot
.60818 .68487 Mdot
.30026 .47223 Mdot
.37578 .31689 Mdot
.41794 .31307 Mdot
.49964 .29656 Mdot
.71495 .48903 Mdot
.49264 .71856 Mdot
.29501 .48205 Mdot
.67895 .60415 Mdot
.3005 .57555 Mdot
.30639 .61272 Mdot
.2967 .41286 Mdot
.47897 .71094 Mdot
.70439 .57909 Mdot
.36934 .32429 Mdot
.33315 .63665 Mdot
.68353 .38777 Mdot
.32875 .60612 Mdot
.42284 .29005 Mdot
.70539 .41377 Mdot
.34841 .34759 Mdot
.2963 .48682 Mdot
.50443 .71533 Mdot
.70474 .47219 Mdot
.70092 .49161 Mdot
.70517 .44291 Mdot
.34565 .6379 Mdot
.32594 .36732 Mdot
.28365 .48589 Mdot
.55876 .71162 Mdot
.63325 .32181 Mdot
.42546 .70386 Mdot
.51212 .7077 Mdot
.58024 .30115 Mdot
.71281 .54342 Mdot
.61965 .32877 Mdot
.70385 .56862 Mdot
.70043 .40173 Mdot
.41437 .31057 Mdot
.39574 .67199 Mdot
.55372 .70802 Mdot
.6032 .68821 Mdot
.33139 .63077 Mdot
.67172 .37534 Mdot
.60473 .68162 Mdot
.65879 .65749 Mdot
.60182 .69211 Mdot
.44511 .70374 Mdot
.62497 .68723 Mdot
.3209 .62408 Mdot
.28802 .51634 Mdot
.68889 .60264 Mdot
.44873 .692 Mdot
.68375 .40514 Mdot
.69709 .4164 Mdot
.70018 .58202 Mdot
.54217 .29657 Mdot
.71807 .4647 Mdot
.37168 .32167 Mdot
.43339 .30256 Mdot
.28316 .45672 Mdot
.39551 .68284 Mdot
.69269 .57501 Mdot
.44483 .71064 Mdot
.5377 .29597 Mdot
.34371 .64482 Mdot
.66283 .35383 Mdot
.36494 .67409 Mdot
.66174 .63991 Mdot
.34214 .62368 Mdot
.28406 .50129 Mdot
.47697 .27878 Mdot
.72189 .50483 Mdot
.32084 .6037 Mdot
.70787 .4466 Mdot
.61123 .68399 Mdot
.57337 .69775 Mdot
.58983 .30013 Mdot
.37568 .67224 Mdot
.27883 .50019 Mdot
.50181 .70029 Mdot
.66195 .6534 Mdot
.54971 .29748 Mdot
.33715 .61741 Mdot
.59336 .31112 Mdot
.71601 .52995 Mdot
.68047 .37036 Mdot
.64831 .35316 Mdot
.46 .2859 Mdot
.6767 .61927 Mdot
.35071 .63284 Mdot
.35343 .3439 Mdot
.62087 .66316 Mdot
.29447 .43908 Mdot
.32697 .63001 Mdot
.61602 .68576 Mdot
.32479 .39184 Mdot
.60215 .70204 Mdot
.46651 .2929 Mdot
.41868 .6923 Mdot
.71002 .55491 Mdot
.5223 .69848 Mdot
.39574 .31008 Mdot
.36635 .33437 Mdot
.29082 .45263 Mdot
.64867 .665 Mdot
.60138 .70522 Mdot
.70325 .48206 Mdot
.32667 .36915 Mdot
.62448 .33076 Mdot
.66293 .37025 Mdot
.30363 .40429 Mdot
.66627 .36239 Mdot
.368 .67378 Mdot
.5243 .6978 Mdot
.46779 .293 Mdot
.47945 .29059 Mdot
.35456 .34452 Mdot
.32671 .38031 Mdot
.38547 .32732 Mdot
.7136 .53979 Mdot
.62243 .31495 Mdot
.6216 .67358 Mdot
.45774 .69598 Mdot
.4339 .70212 Mdot
.70279 .4591 Mdot
.68728 .60712 Mdot
.45931 .71786 Mdot
.36674 .65826 Mdot
.39167 .31755 Mdot
.5697 .29169 Mdot
.70316 .52673 Mdot
.54583 .30049 Mdot
.54815 .70137 Mdot
.39744 .30523 Mdot
.6916 .42758 Mdot
.34938 .63261 Mdot
.72114 .51422 Mdot
.38663 .67573 Mdot
.52241 .27775 Mdot
.70194 .49013 Mdot
.65528 .64345 Mdot
.53168 .70349 Mdot
.65847 .63312 Mdot
.30566 .55698 Mdot
.70656 .40799 Mdot
.58709 .31058 Mdot
.71991 .50686 Mdot
.30574 .56739 Mdot
.71808 .54019 Mdot
.63966 .67421 Mdot
.46764 .69738 Mdot
.61381 .69024 Mdot
.57026 .70922 Mdot
.70243 .4345 Mdot
.6707 .62738 Mdot
.295 .48597 Mdot
.5606 .70723 Mdot
.46785 .2762 Mdot
.51823 .7181 Mdot
.43842 .704 Mdot
.50938 .72066 Mdot
.57912 .71231 Mdot
.71759 .47061 Mdot
.69672 .55571 Mdot
.55785 .30472 Mdot
.64818 .66182 Mdot
.47651 .2833 Mdot
.36074 .34198 Mdot
.30637 .44569 Mdot
.7002 .42623 Mdot
.38417 .67303 Mdot
.41089 .29779 Mdot
.6379 .66637 Mdot
.28156 .4615 Mdot
.57195 .71197 Mdot
.28343 .50037 Mdot
.31247 .60884 Mdot
.35364 .63573 Mdot
.43252 .31011 Mdot
.54605 .28796 Mdot
.58264 .71222 Mdot
.62853 .33758 Mdot
.63838 .33676 Mdot
.55413 .7056 Mdot
.50843 .27439 Mdot
.45682 .28859 Mdot
.31902 .40515 Mdot
.49152 .71797 Mdot
.56689 .70613 Mdot
.66581 .36029 Mdot
.28981 .47543 Mdot
.65119 .63579 Mdot
.35761 .66038 Mdot
.43642 .70713 Mdot
.29999 .47531 Mdot
.6679 .6288 Mdot
.559 .30424 Mdot
.30309 .60331 Mdot
.49005 .72302 Mdot
.58814 .687 Mdot
.68747 .59412 Mdot
.39767 .68162 Mdot
.3139 .38016 Mdot
.52828 .70697 Mdot
.5123 .7059 Mdot
.70931 .45817 Mdot
.48277 .29592 Mdot
.64794 .36088 Mdot
.69252 .44301 Mdot
.29669 .50618 Mdot
.47785 .29908 Mdot
.40564 .67849 Mdot
.43035 .2921 Mdot
.71233 .54489 Mdot
.63739 .67231 Mdot
.58711 .31105 Mdot
.68121 .39242 Mdot
.66746 .35816 Mdot
.57696 .69503 Mdot
.71414 .5269 Mdot
.50139 .70454 Mdot
.29801 .44877 Mdot
.30142 .45998 Mdot
.53395 .70345 Mdot
.64955 .34676 Mdot
.52875 .71195 Mdot
.5217 .2793 Mdot
.31776 .59281 Mdot
.64268 .34445 Mdot
.31399 .4041 Mdot
.4246 .31004 Mdot
.31744 .38148 Mdot
.27979 .53338 Mdot
.68918 .58559 Mdot
.713 .44415 Mdot
.62621 .33922 Mdot
.66512 .62565 Mdot
.39057 .31723 Mdot
.3543 .64943 Mdot
.4974 .70623 Mdot
.3021 .47293 Mdot
.44975 .28067 Mdot
.65147 .33592 Mdot
.6333 .65566 Mdot
.33523 .61209 Mdot
.67073 .63848 Mdot
.2967 .52128 Mdot
.47723 .71393 Mdot
.34108 .62172 Mdot
.34732 .36323 Mdot
.6994 .57822 Mdot
.31991 .62813 Mdot
.2993 .43135 Mdot
.43798 .30818 Mdot
.46127 .28404 Mdot
.31964 .37155 Mdot
.39659 .68691 Mdot
.29917 .49145 Mdot
.63688 .33871 Mdot
.4651 .7066 Mdot
.29439 .52768 Mdot
.40492 .31543 Mdot
.28858 .55785 Mdot
.4234 .69175 Mdot
.6764 .39905 Mdot
.35054 .35083 Mdot
.52403 .70982 Mdot
.69535 .5812 Mdot
.70724 .41775 Mdot
.31227 .41023 Mdot
.675 .61824 Mdot
.3944 .69253 Mdot
.35961 .35494 Mdot
.39752 .31004 Mdot
.55341 .70228 Mdot
.35792 .645 Mdot
.43044 .68837 Mdot
.549 .28631 Mdot
.66675 .64173 Mdot
.48418 .29428 Mdot
.55765 .71799 Mdot
.56143 .71591 Mdot
.6461 .65711 Mdot
.68996 .38194 Mdot
.29101 .4789 Mdot
.4951 .70672 Mdot
.4151 .68267 Mdot
.65881 .37558 Mdot
.71263 .56651 Mdot
.62888 .66824 Mdot
.69836 .43996 Mdot
.32216 .59595 Mdot
.5402 .29391 Mdot
.49787 .70594 Mdot
.4165 .29263 Mdot
.35098 .64319 Mdot
.58011 .69801 Mdot
.63164 .65472 Mdot
.65218 .36252 Mdot
.45843 .71561 Mdot
.64328 .34944 Mdot
.62644 .67597 Mdot
.71733 .43312 Mdot
.49037 .28911 Mdot
.58351 .70542 Mdot
.29957 .49421 Mdot
.28634 .45293 Mdot
.61551 .6914 Mdot
.36561 .6615 Mdot
.71165 .55175 Mdot
.29807 .51154 Mdot
.56005 .28841 Mdot
.37676 .31234 Mdot
.38846 .32536 Mdot
.48577 .27479 Mdot
.71512 .43578 Mdot
.3132 .4124 Mdot
.28564 .54781 Mdot
.68937 .59295 Mdot
.38408 .68888 Mdot
.46894 .29971 Mdot
.42025 .68604 Mdot
.46971 .7169 Mdot
.3057 .42818 Mdot
.36885 .31903 Mdot
.66882 .39139 Mdot
.71349 .42334 Mdot
.7036 .48976 Mdot
.33248 .63434 Mdot
.30874 .41575 Mdot
.39918 .67591 Mdot
.48197 .70943 Mdot
.35311 .35964 Mdot
.70051 .45293 Mdot
.34509 .63323 Mdot
.29084 .57506 Mdot
.53038 .29236 Mdot
.29245 .43596 Mdot
.64092 .34292 Mdot
.30728 .40981 Mdot
.28468 .48482 Mdot
.70273 .52256 Mdot
.57712 .70472 Mdot
.55444 .2899 Mdot
.31792 .39404 Mdot
.61553 .32334 Mdot
.55224 .6998 Mdot
.30309 .58417 Mdot
.28043 .53699 Mdot
.69608 .39776 Mdot
.34755 .35052 Mdot
.36411 .65191 Mdot
.63024 .68104 Mdot
.37098 .65344 Mdot
.70175 .46394 Mdot
.33835 .36732 Mdot
.30263 .59633 Mdot
.57076 .29151 Mdot
.52698 .71196 Mdot
.34676 .63737 Mdot
.55681 .29155 Mdot
.28977 .5019 Mdot
.5845 .68912 Mdot
.62854 .66748 Mdot
.68643 .59191 Mdot
.55781 .30024 Mdot
.65486 .63398 Mdot
.53698 .72228 Mdot
.46566 .29286 Mdot
.31708 .58136 Mdot
.28607 .45729 Mdot
.68652 .61408 Mdot
.50064 .297 Mdot
.3355 .37434 Mdot
.32136 .36571 Mdot
.2792 .50663 Mdot
.2956 .43903 Mdot
.45115 .287 Mdot
.29741 .56684 Mdot
.28816 .46329 Mdot
.48313 .2954 Mdot
.66759 .63508 Mdot
.50915 .70953 Mdot
.70517 .57453 Mdot
.29509 .49084 Mdot
.29059 .54226 Mdot
.69472 .42158 Mdot
.71491 .51182 Mdot
.30216 .59108 Mdot
.42829 .68375 Mdot
.70375 .49409 Mdot
.58923 .31158 Mdot
.43852 .71194 Mdot
.50071 .27832 Mdot
.69409 .58626 Mdot
.4485 .30483 Mdot
.31647 .40687 Mdot
.4632 .70644 Mdot
.39367 .30316 Mdot
.42607 .70362 Mdot
.49356 .70431 Mdot
.72118 .51419 Mdot
.47174 .69779 Mdot
.55904 .70677 Mdot
.70011 .51855 Mdot
.28484 .51078 Mdot
.71051 .4814 Mdot
.56209 .29266 Mdot
.31745 .59074 Mdot
.30049 .45692 Mdot
.55185 .29894 Mdot
.48218 .70692 Mdot
.31027 .43785 Mdot
.44787 .7028 Mdot
.45281 .69245 Mdot
.66377 .65579 Mdot
.42038 .70482 Mdot
.37167 .3363 Mdot
.38843 .67918 Mdot
.66153 .35902 Mdot
.68677 .40673 Mdot
.36266 .65691 Mdot
.62096 .66404 Mdot
.65241 .63344 Mdot
.35216 .33068 Mdot
.63945 .33774 Mdot
.35654 .66991 Mdot
.53436 .28867 Mdot
.69078 .61573 Mdot
.62648 .66536 Mdot
.51843 .28833 Mdot
.43666 .70153 Mdot
.62372 .33605 Mdot
.69644 .43418 Mdot
.45855 .30023 Mdot
.62087 .33164 Mdot
.65117 .63822 Mdot
.71473 .53213 Mdot
.55254 .30189 Mdot
.48587 .70377 Mdot
.48768 .2953 Mdot
.63017 .68733 Mdot
.71747 .51912 Mdot
.64501 .3469 Mdot
.59573 .69907 Mdot
.68662 .41745 Mdot
.29026 .53496 Mdot
.65957 .65658 Mdot
.35722 .65242 Mdot
.65573 .63545 Mdot
.32726 .38722 Mdot
.67106 .35615 Mdot
.63439 .34679 Mdot
.52597 .27603 Mdot
.65757 .36601 Mdot
.68709 .39366 Mdot
.49794 .28094 Mdot
.711 .49444 Mdot
.45221 .69618 Mdot
.68114 .38651 Mdot
.71297 .44019 Mdot
.57767 .30584 Mdot
.34696 .64506 Mdot
.70444 .44675 Mdot
.29328 .46136 Mdot
.53414 .70857 Mdot
.38473 .33242 Mdot
.37672 .68171 Mdot
.70056 .42764 Mdot
.3625 .65851 Mdot
.39977 .3195 Mdot
.28027 .51229 Mdot
.50016 .28651 Mdot
.42837 .29699 Mdot
.31192 .62232 Mdot
.4977 .29823 Mdot
.6673 .37013 Mdot
.3029 .42004 Mdot
.49803 .70815 Mdot
.49428 .7175 Mdot
.37693 .68302 Mdot
.67016 .38292 Mdot
.42043 .29604 Mdot
.29863 .56281 Mdot
.69564 .44158 Mdot
.55639 .28444 Mdot
.32297 .39811 Mdot
.70666 .57579 Mdot
.46725 .28391 Mdot
.29615 .48632 Mdot
.29595 .5158 Mdot
.44385 .70193 Mdot
.58968 .69451 Mdot
.33112 .61627 Mdot
.28638 .462 Mdot
.72023 .48686 Mdot
.31851 .38808 Mdot
.51982 .72092 Mdot
.70802 .52436 Mdot
.55035 .72091 Mdot
.39629 .68868 Mdot
.45739 .2831 Mdot
.63268 .33413 Mdot
.31079 .57492 Mdot
.42502 .31128 Mdot
.70037 .59602 Mdot
.56586 .70122 Mdot
.66827 .6197 Mdot
.36966 .32225 Mdot
.66709 .37763 Mdot
.37019 .33435 Mdot
.46217 .29278 Mdot
.37169 .6722 Mdot
.7087 .55184 Mdot
.29765 .48659 Mdot
.34036 .36181 Mdot
.60167 .32356 Mdot
.31452 .4023 Mdot
.39588 .30672 Mdot
.29681 .50816 Mdot
.70828 .57839 Mdot
.34838 .33615 Mdot
.30556 .59031 Mdot
.6925 .40262 Mdot
.66882 .64777 Mdot
.69904 .39443 Mdot
.34008 .35046 Mdot
.40559 .68774 Mdot
.56423 .29522 Mdot
.51299 .29694 Mdot
.61336 .69509 Mdot
.42816 .70423 Mdot
.63944 .67609 Mdot
.44189 .28065 Mdot
.47134 .29306 Mdot
.56302 .30084 Mdot
.3773 .33008 Mdot
.68058 .39285 Mdot
.69413 .58915 Mdot
.34554 .34092 Mdot
.46053 .6943 Mdot
.66176 .35244 Mdot
.61684 .67043 Mdot
.33016 .35594 Mdot
.69713 .56202 Mdot
.71063 .41467 Mdot
.36238 .67426 Mdot
.62224 .68157 Mdot
.45994 .28644 Mdot
.49657 .70435 Mdot
.41359 .29071 Mdot
.39239 .32119 Mdot
.30296 .60743 Mdot
.59199 .3069 Mdot
.45829 .71331 Mdot
.50625 .71705 Mdot
.50481 .71333 Mdot
.3818 .68048 Mdot
.69468 .40471 Mdot
.56227 .69444 Mdot
.53896 .69607 Mdot
.72179 .47813 Mdot
.31776 .41564 Mdot
.39198 .68145 Mdot
.58379 .68763 Mdot
.29021 .43189 Mdot
.69417 .42526 Mdot
.41213 .68353 Mdot
.47562 .28172 Mdot
.71129 .52081 Mdot
.58631 .31621 Mdot
.59886 .3151 Mdot
.34567 .36741 Mdot
.65703 .35609 Mdot
.68641 .57507 Mdot
.30464 .39339 Mdot
.69069 .38173 Mdot
.69394 .557 Mdot
.71636 .47837 Mdot
.5136 .27814 Mdot
.44739 .71448 Mdot
.51057 .29176 Mdot
.28011 .52319 Mdot
.71828 .45316 Mdot
.66486 .35556 Mdot
.66827 .62714 Mdot
.61373 .31536 Mdot
.30588 .42739 Mdot
.71436 .44912 Mdot
.29613 .46484 Mdot
.70057 .48959 Mdot
.56817 .29941 Mdot
.48742 .29783 Mdot
.69008 .57478 Mdot
.44452 .69457 Mdot
.64436 .65166 Mdot
.29882 .56498 Mdot
.70478 .5836 Mdot
.36899 .32479 Mdot
.28951 .47079 Mdot
.45688 .27734 Mdot
.7047 .51031 Mdot
.48815 .2767 Mdot
.50907 .71775 Mdot
.71796 .52025 Mdot
.56788 .70586 Mdot
.47856 .28607 Mdot
.67785 .60556 Mdot
.43951 .68934 Mdot
.69281 .57441 Mdot
.4223 .30373 Mdot
.30598 .40379 Mdot
.70996 .50626 Mdot
.31422 .39817 Mdot
.43566 .69913 Mdot
.34627 .65502 Mdot
.40591 .69349 Mdot
.57843 .69576 Mdot
.33516 .37558 Mdot
.64836 .63939 Mdot
.41805 .68365 Mdot
.67838 .6281 Mdot
.38798 .31082 Mdot
.30776 .45088 Mdot
.40394 .31419 Mdot
.71164 .49494 Mdot
.31217 .61586 Mdot
.38406 .31659 Mdot
.66199 .62295 Mdot
.29383 .52077 Mdot
.28741 .44935 Mdot
.35143 .64231 Mdot
.5207 .71564 Mdot
.41353 .69091 Mdot
.32563 .36299 Mdot
.55534 .29396 Mdot
.70392 .43076 Mdot
.5758 .31264 Mdot
.30688 .40451 Mdot
.58059 .6988 Mdot
.28578 .51983 Mdot
.45992 .30162 Mdot
.72097 .4784 Mdot
.34573 .65113 Mdot
.51771 .29472 Mdot
.68294 .59155 Mdot
.57192 .69812 Mdot
.41357 .69306 Mdot
.45277 .71102 Mdot
.28869 .47145 Mdot
.46822 .29953 Mdot
.38389 .66757 Mdot
.46489 .70519 Mdot
.37214 .34104 Mdot
.39844 .68492 Mdot
.43209 .69442 Mdot
.31745 .40009 Mdot
.50829 .70469 Mdot
.33897 .6194 Mdot
.71034 .45342 Mdot
.62169 .67099 Mdot
.30685 .54991 Mdot
.31097 .57533 Mdot
.63136 .68184 Mdot
.56818 .71329 Mdot
.28516 .47051 Mdot
.65344 .36339 Mdot
.52642 .70511 Mdot
.38065 .68453 Mdot
.70081 .49846 Mdot
.71494 .44102 Mdot
.68892 .59268 Mdot
.59223 .30787 Mdot
.35198 .34872 Mdot
.33442 .62633 Mdot
.28779 .47975 Mdot
.52309 .7128 Mdot
.71697 .53995 Mdot
.36513 .6576 Mdot
.58238 .30329 Mdot
.69573 .5752 Mdot
.59905 .31298 Mdot
.63977 .66605 Mdot
.52318 .29871 Mdot
.40436 .67506 Mdot
.59062 .70092 Mdot
.71318 .46188 Mdot
.43092 .28229 Mdot
.50297 .29755 Mdot
.42091 .3121 Mdot
.30202 .59453 Mdot
.68164 .38761 Mdot
.34621 .63777 Mdot
.66518 .6181 Mdot
.45444 .71065 Mdot
.3912 .66754 Mdot
.71377 .45454 Mdot
.56686 .70296 Mdot
.70065 .50996 Mdot
.29535 .45626 Mdot
.44263 .71269 Mdot
.63554 .34007 Mdot
.64876 .35902 Mdot
.71897 .48184 Mdot
.28416 .45578 Mdot
.68022 .37771 Mdot
.48594 .70149 Mdot
.30801 .4014 Mdot
.39648 .68051 Mdot
.33977 .62981 Mdot
.39145 .67636 Mdot
.67561 .36595 Mdot
.68152 .60506 Mdot
.70358 .56448 Mdot
.54333 .69966 Mdot
.67878 .62879 Mdot
.46368 .29356 Mdot
.55279 .69538 Mdot
.29919 .53371 Mdot
.4003 .31684 Mdot
.59608 .70422 Mdot
.44727 .69097 Mdot
.63049 .33246 Mdot
.31406 .58059 Mdot
.54321 .30095 Mdot
.30799 .59737 Mdot
.32372 .36482 Mdot
.35822 .66707 Mdot
.67184 .37239 Mdot
.61012 .69409 Mdot
.30628 .57926 Mdot
.2925 .48569 Mdot
.43935 .70241 Mdot
.52694 .70658 Mdot
.30383 .55347 Mdot
.57526 .30948 Mdot
.41945 .31405 Mdot
.30935 .59775 Mdot
.65228 .63894 Mdot
.67844 .62769 Mdot
.48993 .71276 Mdot
.68864 .43237 Mdot
.60246 .32296 Mdot
.28814 .53534 Mdot
.31117 .40405 Mdot
.49313 .70484 Mdot
.64195 .65704 Mdot
.30527 .54728 Mdot
.29806 .54904 Mdot
.68708 .59765 Mdot
.37338 .65946 Mdot
.71692 .51943 Mdot
.63933 .66598 Mdot
.68825 .60779 Mdot
.41438 .68835 Mdot
.35409 .35772 Mdot
.54009 .28085 Mdot
.31671 .62475 Mdot
.38936 .31894 Mdot
.71443 .4399 Mdot
.54566 .69941 Mdot
.6644 .37356 Mdot
.64019 .35498 Mdot
.68882 .39455 Mdot
.52811 .28904 Mdot
.65589 .34065 Mdot
.30427 .53919 Mdot
.48108 .71697 Mdot
.46722 .29723 Mdot
.67664 .36647 Mdot
.67556 .62873 Mdot
.69325 .44178 Mdot
.67055 .37486 Mdot
.67979 .62394 Mdot
.70505 .55322 Mdot
.57565 .69058 Mdot
.46034 .69468 Mdot
.37349 .66126 Mdot
.63218 .31957 Mdot
.64389 .65651 Mdot
.64031 .67339 Mdot
.47155 .7095 Mdot
.69059 .57116 Mdot
.39633 .68219 Mdot
.57304 .70835 Mdot
.46715 .7138 Mdot
.60144 .68227 Mdot
.67778 .6244 Mdot
.66328 .3802 Mdot
.50494 .28789 Mdot
.67653 .60545 Mdot
.36822 .34789 Mdot
.70601 .47388 Mdot
.3249 .61941 Mdot
.69049 .42231 Mdot
.67319 .60417 Mdot
.54108 .28955 Mdot
.62141 .33122 Mdot
.35332 .3505 Mdot
.55141 .29085 Mdot
.48762 .29511 Mdot
.69405 .56348 Mdot
.40401 .32418 Mdot
.31935 .5904 Mdot
.46793 .28303 Mdot
.69974 .57881 Mdot
.56679 .29895 Mdot
.7156 .48509 Mdot
.70866 .57669 Mdot
.61855 .6765 Mdot
.29647 .57043 Mdot
.31997 .62408 Mdot
.45832 .2916 Mdot
.35575 .65767 Mdot
.69224 .57988 Mdot
.70462 .44133 Mdot
.34968 .65428 Mdot
.70331 .40862 Mdot
.32355 .39622 Mdot
.69727 .44554 Mdot
.31216 .41961 Mdot
.61585 .31459 Mdot
.62103 .68271 Mdot
.30941 .56008 Mdot
.30443 .56065 Mdot
.65301 .64787 Mdot
.3013 .59752 Mdot
.56637 .71848 Mdot
.68456 .58606 Mdot
.45744 .69775 Mdot
.27883 .47331 Mdot
.35292 .6683 Mdot
.71502 .46055 Mdot
.3034 .44986 Mdot
.59773 .32173 Mdot
.66359 .62468 Mdot
.30686 .61085 Mdot
.71529 .52479 Mdot
.70048 .50365 Mdot
.63177 .32669 Mdot
.7195 .4607 Mdot
.31553 .3951 Mdot
.27845 .51569 Mdot
.49436 .71257 Mdot
.30033 .4596 Mdot
.47183 .29154 Mdot
.45593 .30076 Mdot
.36846 .34148 Mdot
.39609 .67535 Mdot
.3848 .32068 Mdot
.38513 .66776 Mdot
.62019 .31723 Mdot
.32604 .6098 Mdot
.46871 .70267 Mdot
.70113 .44553 Mdot
.70253 .57662 Mdot
.31312 .57385 Mdot
.38465 .67299 Mdot
.48572 .30008 Mdot
.45825 .29872 Mdot
.29365 .57869 Mdot
.67769 .6237 Mdot
.6673 .63956 Mdot
.44604 .7102 Mdot
.45275 .29199 Mdot
.7102 .53788 Mdot
.5241 .29701 Mdot
.72137 .50976 Mdot
.35141 .66699 Mdot
.40798 .30794 Mdot
.35608 .3273 Mdot
.70473 .46641 Mdot
.54767 .69869 Mdot
.68946 .39163 Mdot
.63403 .66781 Mdot
.38442 .31003 Mdot
.3138 .57214 Mdot
.37615 .33263 Mdot
.43988 .28049 Mdot
.40851 .30829 Mdot
.33887 .6522 Mdot
.7178 .54855 Mdot
.53172 .27633 Mdot
.68986 .59987 Mdot
.3054 .40099 Mdot
.57314 .71605 Mdot
.30203 .56429 Mdot
.30973 .43899 Mdot
.70501 .52668 Mdot
.70467 .41455 Mdot
.37913 .66844 Mdot
.47256 .7041 Mdot
.70831 .50787 Mdot
.47274 .70463 Mdot
.47767 .70663 Mdot
.52384 .71564 Mdot
.4712 .28648 Mdot
.69472 .59398 Mdot
.44588 .69454 Mdot
.29112 .44938 Mdot
.42103 .70362 Mdot
.35541 .33014 Mdot
.71249 .46625 Mdot
.34368 .6448 Mdot
.70409 .4769 Mdot
.64904 .64675 Mdot
.50191 .27603 Mdot
.69586 .40589 Mdot
.70305 .54953 Mdot
.67384 .36305 Mdot
.50876 .2963 Mdot
.36163 .65024 Mdot
.29846 .52038 Mdot
.5228 .29201 Mdot
.2966 .43942 Mdot
.30544 .59737 Mdot
.31716 .40232 Mdot
.41692 .68892 Mdot
.6395 .33977 Mdot
.30323 .59805 Mdot
.60724 .32701 Mdot
.29914 .4102 Mdot
.66706 .65092 Mdot
.54872 .7131 Mdot
.36792 .3242 Mdot
.29656 .55018 Mdot
.65454 .63718 Mdot
.6928 .59491 Mdot
.30352 .40296 Mdot
.52659 .2933 Mdot
.46869 .29003 Mdot
.34376 .64043 Mdot
.66928 .38084 Mdot
.62849 .3277 Mdot
.59096 .31241 Mdot
.39669 .3019 Mdot
.55144 .7103 Mdot
.5295 .71123 Mdot
.66149 .63694 Mdot
.57832 .71279 Mdot
.3104 .40587 Mdot
.30202 .5826 Mdot
.63217 .34269 Mdot
.68434 .58384 Mdot
.72078 .49407 Mdot
.49636 .71187 Mdot
.58026 .70006 Mdot
.33944 .35599 Mdot
.72037 .51828 Mdot
.33665 .61695 Mdot
.68434 .39618 Mdot
.50767 .70392 Mdot
.33774 .64873 Mdot
.62406 .32435 Mdot
.28731 .45223 Mdot
.55738 .29533 Mdot
.30107 .4009 Mdot
.30228 .39762 Mdot
.32441 .62105 Mdot
.70677 .46962 Mdot
.30511 .59627 Mdot
.3249 .38798 Mdot
.29714 .47086 Mdot
.37359 .65882 Mdot
.59279 .69223 Mdot
.29925 .43774 Mdot
.40862 .30511 Mdot
.55293 .28164 Mdot
.63691 .66833 Mdot
.50323 .72496 Mdot
.50072 .2989 Mdot
.45307 .70701 Mdot
.36386 .65729 Mdot
.4481 .29683 Mdot
.62732 .33928 Mdot
.36626 .6534 Mdot
.45227 .28299 Mdot
.63331 .32905 Mdot
.69442 .56482 Mdot
.67437 .63022 Mdot
.70641 .43057 Mdot
.66732 .36361 Mdot
.55339 .70956 Mdot
.35031 .36364 Mdot
.63371 .34106 Mdot
.70975 .42605 Mdot
.70175 .52273 Mdot
.32233 .37958 Mdot
.38925 .67553 Mdot
.53409 .27745 Mdot
.43459 .68935 Mdot
.42422 .3053 Mdot
.33302 .63127 Mdot
.61243 .31749 Mdot
.54293 .7216 Mdot
.52179 .71236 Mdot
.34716 .6537 Mdot
.40198 .69175 Mdot
.35295 .65585 Mdot
.49232 .29627 Mdot
.69934 .55718 Mdot
.7042 .50523 Mdot
.50496 .29681 Mdot
.36881 .67734 Mdot
.32643 .62467 Mdot
.29719 .46316 Mdot
.54511 .71127 Mdot
.39474 .68813 Mdot
.66255 .34985 Mdot
.71586 .55642 Mdot
.29834 .4682 Mdot
.41916 .70012 Mdot
.27927 .47808 Mdot
.40802 .69083 Mdot
.53549 .28105 Mdot
.7181 .50905 Mdot
.34094 .62926 Mdot
.29225 .50928 Mdot
.55113 .7121 Mdot
.56799 .71022 Mdot
.35047 .65947 Mdot
.57577 .70915 Mdot
.63842 .33457 Mdot
.69416 .39067 Mdot
.34406 .64685 Mdot
.34127 .36704 Mdot
.35856 .32974 Mdot
.36558 .33386 Mdot
.48227 .71239 Mdot
.60711 .67577 Mdot
.68998 .61552 Mdot
.70998 .50091 Mdot
.47724 .29756 Mdot
.62206 .32076 Mdot
.68156 .38807 Mdot
.71603 .44924 Mdot
.29957 .4107 Mdot
.3558 .65736 Mdot
.68815 .42809 Mdot
.48576 .29881 Mdot
.45653 .29056 Mdot
.32965 .35378 Mdot
.39293 .31573 Mdot
.35082 .3459 Mdot
.70008 .43121 Mdot
.59098 .29998 Mdot
.69735 .59565 Mdot
.63815 .3527 Mdot
.28393 .44526 Mdot
.29738 .44888 Mdot
.32885 .35588 Mdot
.58138 .30775 Mdot
.67983 .38729 Mdot
.5196 .70811 Mdot
.45826 .71738 Mdot
.36517 .32449 Mdot
.37595 .67326 Mdot
.64657 .32999 Mdot
.41887 .69711 Mdot
.72406 .5086 Mdot
.57573 .29688 Mdot
.28981 .52204 Mdot
.52326 .71868 Mdot
.41743 .31274 Mdot
.39341 .67611 Mdot
.28305 .5202 Mdot
.6736 .61667 Mdot
.66027 .34385 Mdot
.5426 .28522 Mdot
.71257 .56619 Mdot
.30328 .52063 Mdot
.68749 .57026 Mdot
.45128 .29644 Mdot
.33622 .36412 Mdot
.29042 .47679 Mdot
.69507 .42218 Mdot
.57321 .69455 Mdot
.28839 .51085 Mdot
.64522 .67108 Mdot
.37601 .32234 Mdot
.36173 .64845 Mdot
.36149 .33253 Mdot
.66437 .38161 Mdot
.3243 .37461 Mdot
.53284 .72053 Mdot
.70343 .50241 Mdot
.46538 .29106 Mdot
.67849 .63058 Mdot
.30516 .44379 Mdot
.35115 .35622 Mdot
.30591 .57073 Mdot
.71507 .50972 Mdot
.67421 .60797 Mdot
.31527 .62522 Mdot
.53843 .72218 Mdot
.589 .31329 Mdot
.70128 .51264 Mdot
.59926 .3224 Mdot
.40397 .69063 Mdot
.52342 .29255 Mdot
.55633 .29531 Mdot
.6099 .672 Mdot
.36651 .65471 Mdot
.5785 .70007 Mdot
.45006 .69237 Mdot
.59305 .31038 Mdot
.66094 .62615 Mdot
.70378 .51959 Mdot
.6574 .62734 Mdot
.56737 .69248 Mdot
.5903 .31318 Mdot
.28409 .54528 Mdot
.70131 .58476 Mdot
.40768 .6938 Mdot
.45197 .28671 Mdot
.62823 .66782 Mdot
.3021 .58046 Mdot
.35945 .6691 Mdot
.38007 .67294 Mdot
.36379 .66649 Mdot
.49777 .71074 Mdot
.59756 .69656 Mdot
.30953 .56873 Mdot
.49305 .27925 Mdot
.31873 .60206 Mdot
.31754 .57671 Mdot
.48663 .28081 Mdot
.39713 .68732 Mdot
.4178 .68391 Mdot
.72079 .50865 Mdot
.71706 .51067 Mdot
.39217 .32726 Mdot
.52491 .29433 Mdot
.28869 .46567 Mdot
.39347 .67044 Mdot
.58801 .29911 Mdot
.71253 .44445 Mdot
.32762 .6354 Mdot
.52348 .69769 Mdot
.68014 .59746 Mdot
.71394 .43526 Mdot
.66215 .63389 Mdot
.69731 .44877 Mdot
.30217 .54884 Mdot
.53266 .72181 Mdot
.71074 .46313 Mdot
.681 .37297 Mdot
.57636 .70968 Mdot
.69612 .44478 Mdot
.61266 .31016 Mdot
.48247 .29708 Mdot
.5309 .28235 Mdot
.58956 .31338 Mdot
.4089 .31021 Mdot
.6447 .35643 Mdot
.52624 .70278 Mdot
.41913 .3105 Mdot
.43979 .7036 Mdot
.59054 .31285 Mdot
.64357 .67364 Mdot
.64856 .35924 Mdot
.41832 .6812 Mdot
.61429 .66933 Mdot
.32048 .39703 Mdot
.34837 .65555 Mdot
.71014 .41816 Mdot
.28684 .48415 Mdot
.46359 .28361 Mdot
.61224 .32175 Mdot
.31493 .57217 Mdot
.69959 .54105 Mdot
.3941 .67183 Mdot
.58277 .71282 Mdot
.69828 .54439 Mdot
.7106 .56435 Mdot
.28273 .51424 Mdot
.42506 .31075 Mdot
.30975 .38952 Mdot
.54518 .70758 Mdot
.64627 .35573 Mdot
.34568 .62648 Mdot
.30751 .5647 Mdot
.32399 .63485 Mdot
.64481 .64308 Mdot
.53944 .69605 Mdot
.65976 .65964 Mdot
.55384 .69757 Mdot
.37921 .33384 Mdot
.30449 .45811 Mdot
.66671 .62753 Mdot
.36964 .66929 Mdot
.51451 .70159 Mdot
.71138 .46879 Mdot
.60542 .30415 Mdot
.34126 .35291 Mdot
.45747 .27857 Mdot
.31457 .61033 Mdot
.34907 .33575 Mdot
.54312 .7079 Mdot
.71815 .49419 Mdot
.43447 .29704 Mdot
.67466 .38568 Mdot
.33853 .64658 Mdot
.41241 .31273 Mdot
.31989 .59912 Mdot
.65651 .36598 Mdot
.61246 .31737 Mdot
.56154 .70279 Mdot
.28085 .55464 Mdot
.33546 .36604 Mdot
.4882 .71174 Mdot
.37048 .32232 Mdot
.31904 .4085 Mdot
.50793 .28961 Mdot
.52939 .70484 Mdot
.67238 .61145 Mdot
.58967 .31917 Mdot
.51252 .72155 Mdot
.70822 .52989 Mdot
.7006 .56713 Mdot
.32824 .37796 Mdot
.30783 .55203 Mdot
.34313 .65467 Mdot
.61695 .32896 Mdot
.58655 .30007 Mdot
.65626 .65865 Mdot
.33021 .37338 Mdot
.70674 .56591 Mdot
.553 .296 Mdot
.62467 .31858 Mdot
.57273 .28978 Mdot
.5761 .30533 Mdot
.53761 .71095 Mdot
.36145 .65542 Mdot
.66238 .35733 Mdot
.30356 .45545 Mdot
.67663 .63569 Mdot
.30547 .56678 Mdot
.29233 .47613 Mdot
.30413 .58426 Mdot
.51311 .27389 Mdot
.34614 .34607 Mdot
.69586 .46405 Mdot
.59948 .31772 Mdot
.54633 .29309 Mdot
.27865 .50003 Mdot
.7072 .41832 Mdot
.71913 .47101 Mdot
.65612 .34057 Mdot
.29732 .43843 Mdot
.35578 .6539 Mdot
.641 .64552 Mdot
.36855 .33221 Mdot
.29996 .44883 Mdot
.41851 .30194 Mdot
.46745 .30096 Mdot
.6723 .39781 Mdot
.48934 .70061 Mdot
.7051 .51505 Mdot
.41567 .68493 Mdot
.59333 .69184 Mdot
.57512 .29805 Mdot
.62208 .31716 Mdot
.42656 .29325 Mdot
.54726 .70415 Mdot
.60204 .68617 Mdot
.29773 .41588 Mdot
.29912 .5513 Mdot
.38591 .31054 Mdot
.54966 .70021 Mdot
.3921 .31433 Mdot
.70589 .40441 Mdot
.29693 .49537 Mdot
.6353 .6608 Mdot
.43052 .29915 Mdot
.28594 .52619 Mdot
.30215 .50562 Mdot
.40558 .68341 Mdot
.69933 .4583 Mdot
.64607 .36198 Mdot
.38794 .67456 Mdot
.43757 .28433 Mdot
.44766 .28362 Mdot
.57924 .29554 Mdot
.53599 .71022 Mdot
.41808 .30065 Mdot
.30563 .44716 Mdot
.50789 .72199 Mdot
.68694 .57656 Mdot
.69643 .4122 Mdot
.65326 .66388 Mdot
.69213 .58524 Mdot
.56859 .29796 Mdot
.32653 .62743 Mdot
.65282 .66037 Mdot
.34352 .34513 Mdot
.68065 .39893 Mdot
.69766 .43757 Mdot
.34335 .62802 Mdot
.49271 .28987 Mdot
.3876 .6666 Mdot
.62845 .32093 Mdot
.50051 .70227 Mdot
.56048 .29935 Mdot
.28867 .51898 Mdot
.29747 .58257 Mdot
.32745 .6325 Mdot
.62957 .31902 Mdot
.29096 .51303 Mdot
.68687 .38826 Mdot
.65823 .63829 Mdot
.58698 .69366 Mdot
.54099 .29566 Mdot
.35596 .65279 Mdot
.30646 .44292 Mdot
.32751 .39478 Mdot
.67616 .62438 Mdot
.58204 .69597 Mdot
.4843 .2778 Mdot
.35447 .64833 Mdot
.48384 .70698 Mdot
.28542 .5023 Mdot
.60479 .67516 Mdot
.40041 .68184 Mdot
.30821 .60534 Mdot
.72399 .49358 Mdot
.66407 .36294 Mdot
.30257 .60055 Mdot
.60214 .30149 Mdot
.49822 .71206 Mdot
.6635 .62541 Mdot
.6567 .37245 Mdot
.65964 .34814 Mdot
.30839 .58723 Mdot
.46779 .28063 Mdot
.6524 .63545 Mdot
.41273 .67935 Mdot
.61522 .67175 Mdot
.29215 .53542 Mdot
.5241 .29234 Mdot
.41258 .30602 Mdot
.29526 .42856 Mdot
.32729 .38504 Mdot
.40488 .30486 Mdot
.50368 .28654 Mdot
.48848 .7036 Mdot
.69997 .58219 Mdot
.61157 .67376 Mdot
.50543 .28152 Mdot
.7169 .55276 Mdot
.44429 .69445 Mdot
.45247 .70862 Mdot
.3717 .32124 Mdot
.52202 .27706 Mdot
.68882 .59286 Mdot
.66375 .62864 Mdot
.36311 .67521 Mdot
.62864 .3417 Mdot
.42843 .68939 Mdot
.47914 .27587 Mdot
.32075 .3842 Mdot
.47408 .27579 Mdot
.42502 .69032 Mdot
.29926 .54775 Mdot
.42964 .29411 Mdot
.47489 .29118 Mdot
.36812 .34535 Mdot
.37008 .34357 Mdot
.41529 .68241 Mdot
.55767 .30614 Mdot
.71078 .56534 Mdot
.66736 .61873 Mdot
.29608 .53583 Mdot
.33403 .61876 Mdot
.57113 .71718 Mdot
.72088 .46495 Mdot
.2928 .47607 Mdot
.48751 .71249 Mdot
.66129 .37181 Mdot
.35776 .34303 Mdot
.32629 .39284 Mdot
.62602 .33075 Mdot
.31706 .40483 Mdot
.5228 .29297 Mdot
.64425 .67444 Mdot
.35423 .63715 Mdot
.72305 .46715 Mdot
.31082 .57172 Mdot
.28786 .53261 Mdot
.54 .71162 Mdot
.32968 .38076 Mdot
.3364 .37787 Mdot
.70206 .5293 Mdot
.55042 .28754 Mdot
.2801 .52136 Mdot
.70685 .54468 Mdot
.3384 .64959 Mdot
.39538 .3187 Mdot
.29274 .58225 Mdot
.51766 .70375 Mdot
.70456 .471 Mdot
.70221 .57244 Mdot
.30361 .61029 Mdot
.29144 .54164 Mdot
.31238 .61738 Mdot
.45341 .28263 Mdot
.71897 .44486 Mdot
.43259 .30096 Mdot
.33379 .38471 Mdot
.70255 .58845 Mdot
.57371 .6931 Mdot
.61977 .31951 Mdot
.49623 .72107 Mdot
.56585 .30865 Mdot
.65331 .33922 Mdot
.35212 .65271 Mdot
.30373 .53157 Mdot
.42106 .29141 Mdot
.31051 .43806 Mdot
.7117 .51228 Mdot
.72482 .48407 Mdot
.71196 .47149 Mdot
.57979 .29648 Mdot
.60406 .70133 Mdot
.31536 .37565 Mdot
.33654 .64357 Mdot
.48616 .29805 Mdot
.70312 .53449 Mdot
.46413 .69721 Mdot
.35557 .65096 Mdot
.49213 .29955 Mdot
.32085 .63112 Mdot
.55203 .3043 Mdot
.30944 .58287 Mdot
.70447 .52249 Mdot
.43824 .69874 Mdot
.29962 .55149 Mdot
.70963 .43393 Mdot
.47669 .29598 Mdot
.69821 .41954 Mdot
.30253 .54123 Mdot
.32408 .40169 Mdot
.48052 .29873 Mdot
.54178 .69886 Mdot
.69339 .4474 Mdot
.59402 .30329 Mdot
.71733 .46742 Mdot
.30011 .45204 Mdot
.29323 .45675 Mdot
.34667 .34884 Mdot
.5817 .30889 Mdot
.43676 .30525 Mdot
.36893 .65768 Mdot
.63689 .65077 Mdot
.36891 .34358 Mdot
.71498 .43095 Mdot
.43252 .30694 Mdot
.62737 .6623 Mdot
.50757 .29114 Mdot
.36205 .32614 Mdot
.48347 .71866 Mdot
.70253 .54457 Mdot
.29257 .54916 Mdot
.38166 .66542 Mdot
.65667 .63847 Mdot
.5279 .69909 Mdot
.29953 .51512 Mdot
.41894 .68425 Mdot
.57097 .3114 Mdot
.58184 .68596 Mdot
.68488 .61399 Mdot
.32146 .40181 Mdot
.64615 .33231 Mdot
.3077 .3928 Mdot
.3182 .60343 Mdot
.50212 .71837 Mdot
.41943 .68289 Mdot
.71167 .54192 Mdot
.6478 .33197 Mdot
.47272 .28755 Mdot
.69897 .59451 Mdot
.30381 .42576 Mdot
.70412 .49733 Mdot
.70743 .48886 Mdot
.59821 .68841 Mdot
.3001 .56737 Mdot
.5571 .28482 Mdot
.51835 .7167 Mdot
.28107 .51219 Mdot
.54102 .69643 Mdot
.38342 .30966 Mdot
.29083 .46417 Mdot
.34067 .37699 Mdot
.69851 .47745 Mdot
.36279 .32705 Mdot
.71363 .53691 Mdot
.29043 .5195 Mdot
.32952 .38275 Mdot
.47178 .28603 Mdot
.32925 .62805 Mdot
.46541 .7126 Mdot
.57648 .70418 Mdot
.36923 .3218 Mdot
.41403 .31916 Mdot
.70478 .57668 Mdot
.47491 .27536 Mdot
.28499 .56865 Mdot
.46118 .29561 Mdot
.71051 .47383 Mdot
.6205 .69365 Mdot
.44766 .71354 Mdot
.53863 .29219 Mdot
.70304 .53536 Mdot
.34314 .34287 Mdot
.31791 .60479 Mdot
.71603 .44358 Mdot
.33029 .6303 Mdot
.4818 .72055 Mdot
.71311 .47233 Mdot
.29938 .42565 Mdot
.7016 .51577 Mdot
.30139 .58766 Mdot
.51395 .29544 Mdot
.39624 .32126 Mdot
.52619 .27658 Mdot
.6846 .60008 Mdot
.35458 .65388 Mdot
.62037 .68077 Mdot
.72267 .51509 Mdot
.69706 .40692 Mdot
.699 .56107 Mdot
.31163 .62184 Mdot
.69625 .56163 Mdot
.70603 .48664 Mdot
.43881 .68828 Mdot
.39552 .67002 Mdot
.31552 .41747 Mdot
.43884 .70175 Mdot
.52288 .71331 Mdot
.614 .66938 Mdot
.48918 .71518 Mdot
.48137 .70797 Mdot
.53486 .70524 Mdot
.66497 .37054 Mdot
.57685 .69111 Mdot
.67611 .39846 Mdot
.66429 .38551 Mdot
.33044 .38706 Mdot
.3428 .65659 Mdot
.3947 .68306 Mdot
.61645 .67803 Mdot
.57752 .70255 Mdot
.70353 .41525 Mdot
.68807 .42439 Mdot
.46816 .29164 Mdot
.68571 .60939 Mdot
.30612 .43736 Mdot
.58859 .69919 Mdot
.38839 .32973 Mdot
.33306 .3733 Mdot
.41325 .6833 Mdot
.42551 .70254 Mdot
.56693 .71459 Mdot
.64256 .65467 Mdot
.4657 .6989 Mdot
.55965 .6993 Mdot
.31577 .38418 Mdot
.6183 .68413 Mdot
.69997 .57137 Mdot
.70079 .4859 Mdot
.32303 .61082 Mdot
.30452 .59775 Mdot
.66317 .62574 Mdot
.62683 .68712 Mdot
.69456 .42246 Mdot
.70793 .55095 Mdot
.40727 .31743 Mdot
.62155 .32991 Mdot
.65125 .64902 Mdot
.46873 .28221 Mdot
.67629 .63675 Mdot
.50225 .28333 Mdot
.44686 .28992 Mdot
.35505 .66637 Mdot
.34703 .35578 Mdot
.50586 .72442 Mdot
.43103 .3092 Mdot
.53791 .70645 Mdot
.70707 .57493 Mdot
.34765 .63024 Mdot
.70201 .43245 Mdot
.43317 .29898 Mdot
.6573 .35548 Mdot
.71776 .47668 Mdot
.58378 .6852 Mdot
.37662 .3147 Mdot
.3271 .37156 Mdot
.28896 .57227 Mdot
.68959 .3983 Mdot
.5147 .71148 Mdot
.67751 .37556 Mdot
.64249 .34284 Mdot
.70126 .45735 Mdot
.5871 .68551 Mdot
.65419 .65557 Mdot
.52081 .70581 Mdot
.71067 .43833 Mdot
.34257 .35837 Mdot
.36647 .65014 Mdot
.55819 .70799 Mdot
.29023 .52161 Mdot
.6981 .47506 Mdot
.33864 .34957 Mdot
.62423 .6801 Mdot
.393 .3146 Mdot
.71282 .47937 Mdot
.3065 .39753 Mdot
.51661 .29331 Mdot
.36765 .34423 Mdot
.58819 .70819 Mdot
.45694 .69522 Mdot
.70562 .48936 Mdot
.6136 .31907 Mdot
.70334 .53334 Mdot
.48921 .71799 Mdot
.68322 .38689 Mdot
.3372 .37343 Mdot
.68702 .42421 Mdot
.69137 .58128 Mdot
.55016 .71613 Mdot
.31116 .57684 Mdot
.70499 .58699 Mdot
.6027 .68013 Mdot
.6851 .61455 Mdot
.35865 .65919 Mdot
.68722 .59832 Mdot
.63532 .67654 Mdot
.56536 .71631 Mdot
.30017 .42961 Mdot
.46284 .71503 Mdot
.29751 .49229 Mdot
.67825 .59552 Mdot
.68018 .63533 Mdot
.69177 .56176 Mdot
.71344 .43177 Mdot
.70744 .49607 Mdot
.33245 .37698 Mdot
.71466 .4424 Mdot
.29022 .51013 Mdot
.55713 .28502 Mdot
.72065 .46324 Mdot
.30299 .46134 Mdot
.28439 .52174 Mdot
.30417 .54044 Mdot
.3095 .60668 Mdot
.28319 .56318 Mdot
.28102 .49524 Mdot
.28617 .53677 Mdot
.687 .39443 Mdot
.29178 .43304 Mdot
.31555 .5757 Mdot
.55942 .28586 Mdot
.29976 .49813 Mdot
.46048 .71454 Mdot
.69733 .57079 Mdot
.59944 .30542 Mdot
.40099 .30569 Mdot
.31506 .61959 Mdot
.55686 .71609 Mdot
.69324 .43532 Mdot
.43113 .69067 Mdot
.31145 .58147 Mdot
.65006 .36038 Mdot
.40824 .3122 Mdot
.34221 .62441 Mdot
.30462 .58186 Mdot
.34664 .65 Mdot
.36896 .32566 Mdot
.48155 .27454 Mdot
.46291 .71622 Mdot
.30653 .4438 Mdot
.38126 .6812 Mdot
.46411 .71603 Mdot
.6881 .39983 Mdot
.31574 .61425 Mdot
.49186 .70258 Mdot
.71028 .53986 Mdot
.63936 .33365 Mdot
.41702 .29027 Mdot
.50113 .72395 Mdot
.72395 .48336 Mdot
.69955 .48184 Mdot
.28583 .55526 Mdot
.41345 .31019 Mdot
.5423 .72072 Mdot
.56223 .28984 Mdot
.59361 .3157 Mdot
.29743 .43071 Mdot
.60589 .31185 Mdot
.44793 .30479 Mdot
.59591 .70379 Mdot
.30175 .50578 Mdot
.53369 .71888 Mdot
.28584 .43968 Mdot
.53679 .30102 Mdot
.65866 .35163 Mdot
.33464 .38266 Mdot
.66385 .65067 Mdot
.57804 .29596 Mdot
.32039 .40208 Mdot
.70148 .48857 Mdot
.65248 .36518 Mdot
.62613 .33234 Mdot
.33357 .61497 Mdot
.38999 .31773 Mdot
.65959 .37636 Mdot
.66913 .37357 Mdot
.69838 .57063 Mdot
.41993 .68995 Mdot
.71143 .46342 Mdot
.29402 .44633 Mdot
.32308 .61269 Mdot
.30638 .4196 Mdot
.30176 .4526 Mdot
.46744 .2979 Mdot
.62328 .66421 Mdot
.67505 .6274 Mdot
.44741 .71418 Mdot
.54464 .69848 Mdot
.50157 .71209 Mdot
.70596 .41948 Mdot
.41791 .7022 Mdot
.32656 .60453 Mdot
.68717 .3965 Mdot
.66623 .36253 Mdot
.33556 .62543 Mdot
.59352 .69767 Mdot
.48578 .70358 Mdot
.66736 .64826 Mdot
.70505 .5128 Mdot
.68875 .38743 Mdot
.56357 .29258 Mdot
.69894 .483 Mdot
.28342 .4676 Mdot
.32861 .35817 Mdot
.34713 .35951 Mdot
.48218 .29421 Mdot
.48744 .72282 Mdot
.3218 .3763 Mdot
.71831 .51593 Mdot
.28261 .47438 Mdot
.7115 .51991 Mdot
.35163 .36329 Mdot
.49358 .71918 Mdot
.38757 .30464 Mdot
.51992 .2745 Mdot
.68195 .58956 Mdot
.61346 .69097 Mdot
.34735 .65789 Mdot
.70671 .41948 Mdot
.54859 .30099 Mdot
.72028 .44886 Mdot
.42656 .69072 Mdot
.70702 .45309 Mdot
.44115 .29816 Mdot
.49779 .28141 Mdot
.68534 .59239 Mdot
.7153 .52331 Mdot
.70395 .51832 Mdot
.67356 .35924 Mdot
.41131 .3101 Mdot
.69973 .455 Mdot
.66787 .38431 Mdot
.70071 .54722 Mdot
.35081 .33564 Mdot
.66904 .6397 Mdot
.70337 .42524 Mdot
.35981 .64201 Mdot
.65441 .36392 Mdot
.33517 .627 Mdot
.64859 .36519 Mdot
.29873 .44762 Mdot
.51128 .7174 Mdot
.32701 .39036 Mdot
.37433 .67017 Mdot
.31023 .3835 Mdot
.50688 .28282 Mdot
.2969 .50619 Mdot
.5921 .31994 Mdot
.63741 .65503 Mdot
.71807 .46905 Mdot
.53559 .28064 Mdot
.67001 .63897 Mdot
.50009 .71013 Mdot
.64593 .36264 Mdot
.40647 .31597 Mdot
.30754 .41308 Mdot
.64941 .64571 Mdot
.6288 .32005 Mdot
.37231 .3444 Mdot
.71369 .55044 Mdot
.28963 .44112 Mdot
.67981 .59101 Mdot
.57134 .28914 Mdot
.70648 .50242 Mdot
.30768 .41177 Mdot
.63674 .65727 Mdot
.67257 .38655 Mdot
.3284 .36616 Mdot
.56184 .30846 Mdot
.55685 .28775 Mdot
.57747 .71627 Mdot
.55535 .28263 Mdot
.39611 .32498 Mdot
.47296 .27533 Mdot
.66216 .37807 Mdot
.49247 .28155 Mdot
.35596 .65866 Mdot
.34846 .35241 Mdot
.2955 .53448 Mdot
.70452 .57227 Mdot
.42117 .30612 Mdot
.43461 .70811 Mdot
.29717 .46075 Mdot
.28722 .4415 Mdot
.64739 .35926 Mdot
.62744 .31765 Mdot
.72319 .5212 Mdot
.65283 .64185 Mdot
.39457 .3199 Mdot
.28515 .45529 Mdot
.55616 .69364 Mdot
.30063 .5106 Mdot
.29724 .42753 Mdot
.52839 .70205 Mdot
.70368 .55259 Mdot
.465 .29401 Mdot
.59459 .68839 Mdot
.67739 .39127 Mdot
.57228 .69699 Mdot
.57287 .31129 Mdot
.29694 .41442 Mdot
.42216 .68717 Mdot
.34568 .65722 Mdot
.60301 .32381 Mdot
.59999 .32147 Mdot
.35811 .32697 Mdot
.6031 .30837 Mdot
.69967 .41126 Mdot
.39517 .31465 Mdot
.70344 .545 Mdot
.29726 .51685 Mdot
.51454 .70437 Mdot
.70157 .44621 Mdot
.72004 .44796 Mdot
.34793 .35299 Mdot
.63755 .67681 Mdot
.5692 .30517 Mdot
.28516 .44671 Mdot
.71144 .51647 Mdot
.34952 .35687 Mdot
.33606 .65009 Mdot
.33871 .34365 Mdot
.68503 .38307 Mdot
.32509 .62906 Mdot
.70555 .45335 Mdot
.285 .54089 Mdot
.33868 .65309 Mdot
.3569 .6679 Mdot
.31635 .38513 Mdot
.64169 .32696 Mdot
.3272 .38863 Mdot
.49588 .71614 Mdot
.50798 .70456 Mdot
.39007 .31173 Mdot
.35248 .64981 Mdot
.4272 .70714 Mdot
.32281 .59258 Mdot
.62247 .3326 Mdot
.67692 .59962 Mdot
.29487 .46714 Mdot
.29618 .4619 Mdot
.43812 .29602 Mdot
.69442 .43978 Mdot
.28413 .51796 Mdot
.4902 .27603 Mdot
.60244 .32639 Mdot
.3441 .63818 Mdot
.31733 .41679 Mdot
.7054 .46692 Mdot
.50613 .27802 Mdot
.67333 .3879 Mdot
.508 .71047 Mdot
.30562 .6113 Mdot
.3132 .4286 Mdot
.28172 .52909 Mdot
.66294 .63232 Mdot
.52742 .27707 Mdot
.4547 .7002 Mdot
.32538 .62112 Mdot
.47745 .2939 Mdot
.31172 .5739 Mdot
.70966 .51995 Mdot
.29999 .41015 Mdot
.57583 .29089 Mdot
.58405 .71267 Mdot
.47943 .72097 Mdot
.46709 .29875 Mdot
.60071 .69621 Mdot
.70283 .4853 Mdot
.66751 .3791 Mdot
.34663 .34641 Mdot
.58749 .68515 Mdot
.56787 .70538 Mdot
.5622 .70919 Mdot
.39184 .31267 Mdot
.30338 .58734 Mdot
.28471 .47998 Mdot
.56187 .71111 Mdot
.56922 .29724 Mdot
.69352 .55799 Mdot
.59922 .31474 Mdot
.59021 .70574 Mdot
.51223 .71904 Mdot
.71602 .51969 Mdot
.69279 .57223 Mdot
.59233 .31959 Mdot
.30576 .59301 Mdot
.30755 .5872 Mdot
.71415 .43016 Mdot
.4787 .71724 Mdot
.61098 .67935 Mdot
.52189 .71771 Mdot
.34933 .66002 Mdot
.69142 .61612 Mdot
.62669 .66091 Mdot
.67677 .61104 Mdot
.65689 .65689 Mdot
.46759 .70136 Mdot
.45056 .29849 Mdot
.66329 .35497 Mdot
.56052 .30114 Mdot
.37336 .3147 Mdot
.38204 .3382 Mdot
.31334 .58065 Mdot
.41606 .68332 Mdot
.34932 .63625 Mdot
.57891 .68883 Mdot
.39197 .69086 Mdot
.66594 .6255 Mdot
.69428 .59195 Mdot
.33533 .61365 Mdot
.53527 .72166 Mdot
.36472 .32787 Mdot
.32297 .36217 Mdot
.71794 .50912 Mdot
.58609 .70878 Mdot
.43754 .29178 Mdot
.58636 .30437 Mdot
.29246 .46284 Mdot
.28555 .47106 Mdot
.31 .57541 Mdot
.3055 .54352 Mdot
.69508 .56317 Mdot
.46873 .69837 Mdot
.30193 .57297 Mdot
.44573 .30344 Mdot
.2843 .53649 Mdot
.30855 .42648 Mdot
.54289 .29837 Mdot
.53867 .28523 Mdot
.4412 .70554 Mdot
.43932 .71207 Mdot
.64671 .3454 Mdot
.62323 .31444 Mdot
.60361 .32068 Mdot
.30791 .39253 Mdot
.3006 .59454 Mdot
.67053 .36195 Mdot
.69712 .46139 Mdot
.37868 .67348 Mdot
.53954 .71964 Mdot
.32548 .36519 Mdot
.69132 .42548 Mdot
.37482 .67976 Mdot
.66781 .64006 Mdot
.28605 .4472 Mdot
.44894 .70117 Mdot
.72562 .48806 Mdot
.67352 .37426 Mdot
.65245 .63955 Mdot
.7026 .42593 Mdot
.57493 .29818 Mdot
.51211 .28261 Mdot
.51322 .72053 Mdot
.60364 .316 Mdot
.70455 .40261 Mdot
.51243 .27925 Mdot
.33416 .61405 Mdot
.29434 .52202 Mdot
.30976 .5641 Mdot
.34199 .34822 Mdot
.35082 .66304 Mdot
.42704 .30623 Mdot
.31716 .40689 Mdot
.7102 .4599 Mdot
.35558 .65067 Mdot
.61781 .66781 Mdot
.29203 .52718 Mdot
.31238 .58654 Mdot
.67745 .61223 Mdot
.72337 .47667 Mdot
.38269 .3297 Mdot
.35497 .64257 Mdot
.40726 .68466 Mdot
.45743 .27618 Mdot
.51625 .296 Mdot
.52087 .28879 Mdot
.30216 .59232 Mdot
.35395 .35017 Mdot
.70164 .45299 Mdot
.55113 .69496 Mdot
.69059 .38292 Mdot
.48593 .70071 Mdot
.47028 .71218 Mdot
.69784 .39635 Mdot
.70127 .45095 Mdot
.51617 .72186 Mdot
.54907 .69816 Mdot
.29183 .51854 Mdot
.59086 .31093 Mdot
.64205 .35452 Mdot
.6415 .35242 Mdot
.40988 .31993 Mdot
.70406 .49356 Mdot
.28617 .57001 Mdot
.51488 .28571 Mdot
.30644 .44761 Mdot
.58035 .30989 Mdot
.39015 .67252 Mdot
.34611 .36635 Mdot
.67111 .36432 Mdot
.60479 .31122 Mdot
.71161 .54421 Mdot
.71082 .4643 Mdot
.35188 .65422 Mdot
.7083 .48879 Mdot
.71028 .44368 Mdot
.4745 .71706 Mdot
.30556 .58809 Mdot
.28947 .54044 Mdot
.6655 .62938 Mdot
.64606 .34524 Mdot
.50045 .71335 Mdot
.69373 .5979 Mdot
.49475 .72171 Mdot
.65458 .63767 Mdot
.66334 .37555 Mdot
.61915 .69044 Mdot
.71259 .4663 Mdot
.66423 .38822 Mdot
.31364 .42612 Mdot
.29228 .53272 Mdot
.28415 .51109 Mdot
.3587 .32484 Mdot
.49426 .70314 Mdot
.3221 .39751 Mdot
.70106 .55198 Mdot
.30305 .52256 Mdot
.61221 .66956 Mdot
.37188 .65943 Mdot
.54125 .70603 Mdot
.30078 .54236 Mdot
.40539 .31433 Mdot
.71402 .53768 Mdot
.54019 .71175 Mdot
.30583 .60129 Mdot
.70789 .47051 Mdot
.63052 .33055 Mdot
.69497 .43966 Mdot
.34085 .6381 Mdot
.57414 .31034 Mdot
.70153 .55378 Mdot
.34694 .3437 Mdot
.32767 .39103 Mdot
.70531 .45498 Mdot
.32875 .37778 Mdot
.54436 .28354 Mdot
.54965 .71261 Mdot
.58813 .3103 Mdot
.35911 .64448 Mdot
.65085 .36002 Mdot
.71222 .53356 Mdot
.67466 .60609 Mdot
.707 .49711 Mdot
.29359 .50407 Mdot
.32027 .59355 Mdot
.29658 .41201 Mdot
.64366 .33456 Mdot
.56172 .30516 Mdot
.39506 .32838 Mdot
.71727 .52352 Mdot
.39978 .69521 Mdot
.62448 .67689 Mdot
.41831 .68733 Mdot
.68397 .60153 Mdot
.40404 .67436 Mdot
.33509 .38405 Mdot
.71084 .42369 Mdot
.68406 .58277 Mdot
.66724 .61816 Mdot
.42856 .70621 Mdot
.3116 .56521 Mdot
.43794 .69038 Mdot
.61299 .67195 Mdot
.58315 .70509 Mdot
.66172 .35079 Mdot
.64918 .64404 Mdot
.29866 .41853 Mdot
.30334 .45067 Mdot
.37344 .31471 Mdot
.30066 .51708 Mdot
.30322 .40555 Mdot
.54042 .70043 Mdot
.64122 .67117 Mdot
.68355 .41724 Mdot
.71746 .49448 Mdot
.54352 .29349 Mdot
.6277 .68576 Mdot
.40886 .31677 Mdot
.33915 .37552 Mdot
.60443 .70494 Mdot
.70177 .48196 Mdot
.432 .28455 Mdot
.30105 .56059 Mdot
.28508 .505 Mdot
.37567 .67201 Mdot
.30963 .40082 Mdot
.33018 .63917 Mdot
.57215 .30627 Mdot
.46838 .71974 Mdot
.62611 .66143 Mdot
.40839 .29578 Mdot
.7014 .50676 Mdot
.4457 .28495 Mdot
.38943 .6716 Mdot
.4707 .70626 Mdot
.65824 .35901 Mdot
.71608 .44448 Mdot
.37982 .68214 Mdot
.32769 .39784 Mdot
.29902 .43447 Mdot
.38479 .6641 Mdot
.31333 .59949 Mdot
.4392 .30358 Mdot
.31152 .58989 Mdot
.70699 .53706 Mdot
.66564 .62358 Mdot
.52287 .29922 Mdot
.49186 .71623 Mdot
.61709 .33145 Mdot
.71301 .42939 Mdot
.46949 .70011 Mdot
.32235 .60681 Mdot
.69002 .42652 Mdot
.71623 .53906 Mdot
.46334 .71859 Mdot
.34165 .35884 Mdot
.48196 .71173 Mdot
.298 .46238 Mdot
.28897 .48844 Mdot
.42232 .69483 Mdot
.40639 .31144 Mdot
.32477 .62792 Mdot
.32258 .60414 Mdot
.70969 .49891 Mdot
.29999 .5173 Mdot
.71368 .5094 Mdot
.50716 .70278 Mdot
.3327 .61295 Mdot
.71257 .52663 Mdot
.69064 .38723 Mdot
.30292 .46604 Mdot
.34686 .36028 Mdot
.66534 .36195 Mdot
.49082 .71237 Mdot
.29325 .51749 Mdot
.47473 .70101 Mdot
.70521 .51718 Mdot
.43396 .69952 Mdot
.53807 .29948 Mdot
.67914 .38709 Mdot
.56186 .29723 Mdot
.71115 .54286 Mdot
.45375 .70342 Mdot
.31135 .58965 Mdot
.29693 .58519 Mdot
.55659 .71625 Mdot
.70478 .45134 Mdot
.70965 .43486 Mdot
.69794 .45309 Mdot
.39577 .32697 Mdot
.57042 .69067 Mdot
.5547 .2917 Mdot
.30342 .58358 Mdot
.56154 .28537 Mdot
.60708 .67635 Mdot
.34222 .64257 Mdot
.51831 .29177 Mdot
.55317 .71456 Mdot
.61533 .31154 Mdot
.4727 .69884 Mdot
.669 .36236 Mdot
.3623 .3225 Mdot
.44304 .28644 Mdot
.64368 .34682 Mdot
.45476 .69598 Mdot
.66229 .63436 Mdot
.6309 .65509 Mdot
.51824 .27997 Mdot
.31364 .61342 Mdot
.31783 .4178 Mdot
.32969 .3604 Mdot
.39498 .6934 Mdot
.47872 .29923 Mdot
.45625 .27675 Mdot
.69125 .58144 Mdot
.64756 .34093 Mdot
.54983 .29946 Mdot
.52814 .29328 Mdot
.39628 .32371 Mdot
.70374 .56072 Mdot
.44624 .70181 Mdot
.29022 .50832 Mdot
.45784 .28443 Mdot
.56534 .70745 Mdot
.71566 .49918 Mdot
.28806 .4769 Mdot
.69722 .43631 Mdot
.41089 .29268 Mdot
.59448 .6812 Mdot
.69748 .40619 Mdot
.29035 .43945 Mdot
.66081 .37718 Mdot
.47768 .70578 Mdot
.29818 .57754 Mdot
.31544 .38965 Mdot
.49805 .70111 Mdot
.33727 .38043 Mdot
.53249 .2886 Mdot
.41508 .29473 Mdot
.65088 .65374 Mdot
.28519 .46209 Mdot
.52185 .72165 Mdot
.72195 .52292 Mdot
.37064 .67383 Mdot
.52019 .28436 Mdot
.68045 .40808 Mdot
.54778 .72019 Mdot
.42062 .31557 Mdot
.34721 .3379 Mdot
.70386 .43221 Mdot
.6954 .44569 Mdot
.64225 .32729 Mdot
.29586 .54207 Mdot
.37062 .34441 Mdot
.29302 .51964 Mdot
.40514 .68288 Mdot
.50962 .27856 Mdot
.32299 .60423 Mdot
.30584 .39868 Mdot
.49024 .29395 Mdot
.72327 .4771 Mdot
.60645 .31123 Mdot
.71252 .55635 Mdot
.71911 .51231 Mdot
.32118 .38666 Mdot
.33997 .644 Mdot
.64988 .639 Mdot
.6874 .59087 Mdot
.33327 .62244 Mdot
.40265 .32217 Mdot
.63462 .33559 Mdot
.71738 .44876 Mdot
.67989 .38726 Mdot
.62486 .66485 Mdot
.67969 .37992 Mdot
.596 .692 Mdot
.40373 .67822 Mdot
.60273 .31028 Mdot
.5337 .69796 Mdot
.52847 .2924 Mdot
.64554 .3353 Mdot
.65359 .63851 Mdot
.70599 .52592 Mdot
.57936 .69602 Mdot
.63297 .67928 Mdot
.69007 .57203 Mdot
.49347 .70285 Mdot
.69268 .39384 Mdot
.71997 .44718 Mdot
.66144 .62486 Mdot
.50243 .27492 Mdot
.35165 .65885 Mdot
.66638 .38401 Mdot
.47748 .71109 Mdot
.69569 .3941 Mdot
.67326 .61489 Mdot
.54556 .30277 Mdot
.6927 .56345 Mdot
.29873 .41242 Mdot
.6038 .68616 Mdot
.35758 .32911 Mdot
.68226 .59852 Mdot
.69957 .39558 Mdot
.49487 .28593 Mdot
.71378 .54516 Mdot
.27865 .47975 Mdot
.63239 .68344 Mdot
.29758 .58028 Mdot
.342 .65317 Mdot
.32262 .62099 Mdot
.58916 .31983 Mdot
.50274 .70513 Mdot
.53898 .69912 Mdot
.55848 .71939 Mdot
.39775 .67577 Mdot
.29194 .53023 Mdot
.39082 .67753 Mdot
.71208 .49652 Mdot
.5345 .70881 Mdot
.31997 .37619 Mdot
.66162 .35991 Mdot
.55588 .69813 Mdot
.6892 .59709 Mdot
.72436 .49121 Mdot
.64513 .3451 Mdot
.59622 .29936 Mdot
.30507 .4396 Mdot
.36352 .66228 Mdot
.50323 .72126 Mdot
.35865 .64002 Mdot
.70436 .54775 Mdot
.58606 .31272 Mdot
.5823 .70998 Mdot
.35638 .35757 Mdot
.64318 .65067 Mdot
.39892 .32442 Mdot
.43697 .70637 Mdot
.64878 .3611 Mdot
.51875 .28565 Mdot
.29999 .42589 Mdot
.29706 .42934 Mdot
.57377 .70689 Mdot
.2976 .45809 Mdot
.33972 .63182 Mdot
.34581 .64389 Mdot
.53672 .29435 Mdot
.48048 .70496 Mdot
.64426 .64755 Mdot
.71177 .50716 Mdot
.4911 .69951 Mdot
.46108 .71692 Mdot
.48591 .29005 Mdot
.48441 .29435 Mdot
.31072 .39283 Mdot
.5085 .72286 Mdot
.55699 .70468 Mdot
.65196 .3552 Mdot
.31208 .57226 Mdot
.3563 .35635 Mdot
.36722 .67733 Mdot
.38162 .31952 Mdot
.67496 .63959 Mdot
.31134 .60784 Mdot
.34362 .64213 Mdot
.42403 .30039 Mdot
.61215 .31364 Mdot
.28923 .52034 Mdot
.37049 .33567 Mdot
.35139 .35941 Mdot
.54527 .70066 Mdot
.70057 .51085 Mdot
.66657 .37954 Mdot
.33809 .63303 Mdot
.60024 .31733 Mdot
.71849 .51546 Mdot
.2819 .5205 Mdot
.39589 .67815 Mdot
.39407 .32983 Mdot
.66739 .3591 Mdot
.70363 .57334 Mdot
.45989 .7091 Mdot
.63035 .33153 Mdot
.45462 .70649 Mdot
.70027 .45757 Mdot
.66885 .38944 Mdot
.60212 .70265 Mdot
.69296 .41588 Mdot
.44249 .30499 Mdot
.34697 .36782 Mdot
.68767 .56996 Mdot
.51797 .2928 Mdot
.70272 .54822 Mdot
.28699 .46986 Mdot
.54089 .7179 Mdot
.5015 .70106 Mdot
.47654 .71211 Mdot
.33902 .65236 Mdot
.64973 .66143 Mdot
.29069 .55275 Mdot
.29712 .57755 Mdot
.6375 .3349 Mdot
.32484 .62636 Mdot
.66124 .63304 Mdot
.35289 .64557 Mdot
.34653 .34742 Mdot
.57479 .70445 Mdot
.33842 .63718 Mdot
.71786 .44607 Mdot
.70608 .55931 Mdot
.61871 .33165 Mdot
.3368 .34472 Mdot
.30021 .57166 Mdot
.5364 .29086 Mdot
.69136 .60706 Mdot
.41681 .31318 Mdot
.45961 .28951 Mdot
.67481 .62322 Mdot
.29513 .41711 Mdot
.49245 .27439 Mdot
.34819 .36728 Mdot
.45548 .29324 Mdot
.57209 .29302 Mdot
.64336 .65492 Mdot
.35361 .646 Mdot
.33036 .64175 Mdot
.39703 .68347 Mdot
.45752 .28181 Mdot
.35732 .35754 Mdot
.36506 .34266 Mdot
.66508 .62032 Mdot
.68787 .40909 Mdot
.3015 .50247 Mdot
.50088 .72364 Mdot
.47311 .29516 Mdot
.64326 .66233 Mdot
.32928 .63874 Mdot
.54202 .28693 Mdot
.6856 .59496 Mdot
.68098 .62884 Mdot
.29711 .54687 Mdot
.28762 .53275 Mdot
.35382 .64239 Mdot
.3095 .42225 Mdot
.65942 .37439 Mdot
.37909 .66949 Mdot
.56799 .71741 Mdot
.49585 .71886 Mdot
.5907 .319 Mdot
.30035 .52006 Mdot
.54968 .28767 Mdot
.31788 .59471 Mdot
.3898 .67664 Mdot
.71502 .47938 Mdot
.69986 .46734 Mdot
.30812 .5781 Mdot
.66699 .65134 Mdot
.65856 .66046 Mdot
.68178 .41433 Mdot
.65582 .36861 Mdot
.64079 .67675 Mdot
.32505 .59829 Mdot
.36076 .64959 Mdot
.71521 .54292 Mdot
.69952 .58971 Mdot
.68857 .57811 Mdot
.66936 .63765 Mdot
.38117 .31239 Mdot
.71393 .53519 Mdot
.30062 .40795 Mdot
.66731 .64026 Mdot
.42816 .29166 Mdot
.71912 .50506 Mdot
.44479 .70427 Mdot
.37208 .32874 Mdot
.43765 .70601 Mdot
.33833 .3544 Mdot
.49993 .71402 Mdot
.28561 .43975 Mdot
.34701 .34377 Mdot
.29892 .45686 Mdot
.68482 .62121 Mdot
.29047 .55086 Mdot
.32766 .60829 Mdot
.28115 .508 Mdot
.61996 .68169 Mdot
.63589 .33998 Mdot
.6746 .3682 Mdot
.45775 .70906 Mdot
.38934 .32804 Mdot
.53089 .28457 Mdot
.68944 .59123 Mdot
.49621 .70799 Mdot
.71393 .51982 Mdot
.60483 .30916 Mdot
.34451 .35619 Mdot
.34522 .65809 Mdot
.28058 .49975 Mdot
.28937 .46288 Mdot
.35016 .363 Mdot
.45601 .71633 Mdot
.72315 .49282 Mdot
.29584 .46805 Mdot
.69718 .42103 Mdot
.42464 .70544 Mdot
.71488 .44584 Mdot
.29876 .51187 Mdot
.37005 .66321 Mdot
.61752 .6735 Mdot
.66697 .37079 Mdot
.39 .31337 Mdot
.4496 .70088 Mdot
.30864 .60364 Mdot
.39695 .68344 Mdot
.67656 .38809 Mdot
.33296 .61259 Mdot
.36474 .33745 Mdot
.29629 .5236 Mdot
.60876 .67973 Mdot
.61879 .69308 Mdot
.71564 .55919 Mdot
.45822 .70416 Mdot
.33571 .62707 Mdot
.69985 .50713 Mdot
.71539 .51638 Mdot
.45112 .28974 Mdot
.65414 .64061 Mdot
.41032 .68691 Mdot
.28168 .47952 Mdot
.62482 .33659 Mdot
.35707 .65851 Mdot
.47064 .29525 Mdot
.36514 .66571 Mdot
.28222 .52392 Mdot
.70268 .47026 Mdot
.28303 .51384 Mdot
.71477 .50351 Mdot
.55101 .29912 Mdot
.66737 .37863 Mdot
.28175 .48965 Mdot
.31196 .59718 Mdot
.39351 .31004 Mdot
.68524 .62243 Mdot
.70481 .44072 Mdot
.49893 .29187 Mdot
.28575 .48645 Mdot
.54371 .30156 Mdot
.70779 .57536 Mdot
.59085 .30948 Mdot
.45957 .70968 Mdot
.68723 .4171 Mdot
.57827 .29596 Mdot
.29542 .43576 Mdot
.61508 .67087 Mdot
.2827 .50986 Mdot
.51563 .71546 Mdot
.50914 .28711 Mdot
.51813 .27498 Mdot
.70892 .47991 Mdot
.46593 .3 Mdot
.56717 .71729 Mdot
.29278 .52575 Mdot
.45693 .71225 Mdot
.44351 .28896 Mdot
.49401 .2974 Mdot
.3078 .41553 Mdot
.44873 .6985 Mdot
.35483 .66473 Mdot
.3019 .40761 Mdot
.35352 .3332 Mdot
.33007 .37548 Mdot
.69915 .40185 Mdot
.30537 .58239 Mdot
.29587 .54988 Mdot
.57847 .70817 Mdot
.55346 .28708 Mdot
.29124 .55329 Mdot
.51682 .70622 Mdot
.58786 .69177 Mdot
.68036 .38885 Mdot
.37344 .33081 Mdot
.41945 .69461 Mdot
.68451 .57732 Mdot
.30395 .60092 Mdot
.39052 .31701 Mdot
.70731 .46882 Mdot
.28183 .48564 Mdot
.53547 .71292 Mdot
.68764 .58361 Mdot
.70715 .49841 Mdot
.69812 .39176 Mdot
.65584 .65803 Mdot
.45076 .70516 Mdot
.59531 .31795 Mdot
.54015 .66028 Mdot
.37271 .57318 Mdot
.44392 .47191 Mdot
.3042 .52679 Mdot
.59623 .56769 Mdot
.48543 .64211 Mdot
.68106 .57862 Mdot
.48307 .57789 Mdot
.5867 .68143 Mdot
.5423 .61714 Mdot
.62507 .41845 Mdot
.4598 .53562 Mdot
.44151 .31869 Mdot
.66744 .47302 Mdot
.63402 .63403 Mdot
.33191 .48855 Mdot
.67008 .52455 Mdot
.51104 .62422 Mdot
.67189 .46697 Mdot
.60599 .46309 Mdot
.55715 .33061 Mdot
.51399 .30358 Mdot
.60278 .41516 Mdot
.36874 .64176 Mdot
.552 .64327 Mdot
.39907 .58843 Mdot
.64887 .58144 Mdot
.62837 .37948 Mdot
.68024 .58552 Mdot
.40237 .38174 Mdot
.61521 .57187 Mdot
.4514 .37915 Mdot
.45982 .66165 Mdot
.62785 .44739 Mdot
.39302 .58181 Mdot
.37035 .42899 Mdot
.55311 .68475 Mdot
.53762 .58766 Mdot
.59421 .59133 Mdot
.44456 .63592 Mdot
.62194 .55429 Mdot
.42231 .31737 Mdot
.69753 .48832 Mdot
.67687 .48599 Mdot
.44586 .36399 Mdot
.63815 .54212 Mdot
.4827 .57884 Mdot
.30634 .52245 Mdot
.59793 .56126 Mdot
.46118 .68348 Mdot
.69121 .4718 Mdot
.64797 .46804 Mdot
.63894 .4011 Mdot
.46221 .64771 Mdot
.65344 .42058 Mdot
.43461 .66794 Mdot
.51649 .62648 Mdot
.49412 .64553 Mdot
.60691 .45763 Mdot
.5376 .3525 Mdot
.63529 .35008 Mdot
.33523 .48651 Mdot
.5648 .44057 Mdot
.39919 .4703 Mdot
.65354 .48696 Mdot
.49639 .67522 Mdot
.66929 .58111 Mdot
.6873 .44873 Mdot
.58185 .35568 Mdot
.44094 .34799 Mdot
.60951 .40682 Mdot
.57244 .44426 Mdot
.64046 .5323 Mdot
.37822 .60256 Mdot
.57957 .60755 Mdot
.57814 .37919 Mdot
.59341 .66654 Mdot
.35296 .40473 Mdot
.53967 .52552 Mdot
.3867 .35658 Mdot
.48333 .65165 Mdot
.61613 .46191 Mdot
.43795 .56088 Mdot
.59967 .53203 Mdot
.39825 .64674 Mdot
.41337 .35162 Mdot
.55423 .64229 Mdot
.55495 .38233 Mdot
.6663 .53357 Mdot
.51996 .66617 Mdot
.6526 .42968 Mdot
.34611 .39099 Mdot
.44522 .41289 Mdot
.39509 .36704 Mdot
.48992 .57192 Mdot
.37085 .41557 Mdot
.62705 .44474 Mdot
.67222 .42297 Mdot
.49996 .30665 Mdot
.63076 .6049 Mdot
.46738 .36944 Mdot
.64813 .36907 Mdot
.53699 .32423 Mdot
.48246 .60373 Mdot
.62062 .61658 Mdot
.39695 .37218 Mdot
.58897 .36392 Mdot
.5852 .52555 Mdot
.59525 .43411 Mdot
.59127 .58797 Mdot
.56952 .61443 Mdot
.67465 .52199 Mdot
.30568 .53863 Mdot
.6092 .64275 Mdot
.43904 .3823 Mdot
.60721 .37593 Mdot
.33383 .43812 Mdot
.51899 .69753 Mdot
.47109 .38738 Mdot
.58294 .67801 Mdot
.5095 .47221 Mdot
.66532 .55684 Mdot
.38726 .36046 Mdot
.691 .55884 Mdot
.57137 .66691 Mdot
.60189 .41234 Mdot
.35021 .48897 Mdot
.67997 .533 Mdot
.67414 .45728 Mdot
.56312 .32739 Mdot
.50329 .66129 Mdot
.37409 .35698 Mdot
.34941 .55522 Mdot
.40012 .44485 Mdot
.56828 .32495 Mdot
.38959 .4664 Mdot
.43395 .43811 Mdot
.40375 .33341 Mdot
.63485 .61215 Mdot
.43039 .42229 Mdot
.60802 .66634 Mdot
.57039 .37203 Mdot
.61976 .41371 Mdot
.55076 .65458 Mdot
.31548 .54231 Mdot
.40006 .40188 Mdot
.45591 .4381 Mdot
.5945 .5467 Mdot
.68968 .5571 Mdot
.39407 .56296 Mdot
.62036 .43761 Mdot
.51859 .40751 Mdot
.52328 .35667 Mdot
.67245 .45074 Mdot
.6493 .37092 Mdot
.49999 .38292 Mdot
.41941 .54802 Mdot
.626 .64551 Mdot
.5062 .4244 Mdot
.66719 .56428 Mdot
.48922 .41041 Mdot
.40037 .37968 Mdot
.57052 .32889 Mdot
.58751 .38473 Mdot
.64548 .53008 Mdot
.64167 .40166 Mdot
.58444 .62731 Mdot
.59193 .62577 Mdot
.49113 .36302 Mdot
.66713 .52309 Mdot
.62619 .47863 Mdot
.68796 .46863 Mdot
.50908 .61121 Mdot
.43202 .62926 Mdot
.36771 .55898 Mdot
.43637 .51209 Mdot
.32952 .60069 Mdot
.3703 .43564 Mdot
.50757 .66449 Mdot
.32348 .57966 Mdot
.37594 .49729 Mdot
.38722 .58123 Mdot
.31072 .44511 Mdot
.35834 .55993 Mdot
.45393 .6782 Mdot
.56353 .54822 Mdot
.59134 .38048 Mdot
.46039 .45601 Mdot
.35766 .54391 Mdot
.65748 .56935 Mdot
.54381 .68534 Mdot
.39028 .3598 Mdot
.45358 .33523 Mdot
.51179 .64094 Mdot
.58025 .65467 Mdot
.5712 .32024 Mdot
.64285 .38115 Mdot
.44122 .32132 Mdot
.6461 .52903 Mdot
.67072 .57408 Mdot
.3333 .39096 Mdot
.60877 .49514 Mdot
.43522 .57255 Mdot
.40694 .62238 Mdot
.42053 .36106 Mdot
.57368 .56124 Mdot
.31111 .4988 Mdot
.45802 .61144 Mdot
.44111 .45441 Mdot
.39095 .40048 Mdot
.34855 .41972 Mdot
.34484 .43913 Mdot
.67438 .49851 Mdot
.36122 .44198 Mdot
.38715 .38077 Mdot
.53753 .69437 Mdot
.56608 .48179 Mdot
.65461 .61582 Mdot
.39403 .52099 Mdot
.53884 .32999 Mdot
.56308 .4254 Mdot
.56447 .60993 Mdot
.46353 .64868 Mdot
.36915 .38556 Mdot
.44792 .67623 Mdot
.61478 .53657 Mdot
.43581 .38843 Mdot
.56649 .39509 Mdot
.46495 .38284 Mdot
.4977 .35632 Mdot
.51134 .57683 Mdot
.6742 .46071 Mdot
.35982 .63486 Mdot
.54252 .3502 Mdot
.63697 .57608 Mdot
.57447 .67338 Mdot
.54143 .32863 Mdot
.61424 .62753 Mdot
.60912 .60308 Mdot
.46623 .63716 Mdot
.40406 .55802 Mdot
.4679 .49146 Mdot
.54468 .59045 Mdot
.38584 .43464 Mdot
.54261 .39451 Mdot
.54946 .31769 Mdot
.48257 .32213 Mdot
.46835 .47614 Mdot
.56182 .47635 Mdot
.35569 .52523 Mdot
.58106 .3483 Mdot
.5303 .55889 Mdot
.37228 .58041 Mdot
.45911 .45281 Mdot
.52092 .63532 Mdot
.66797 .56853 Mdot
.41282 .55262 Mdot
.46558 .68971 Mdot
.43926 .35985 Mdot
.41095 .32784 Mdot
.48838 .35233 Mdot
.55963 .64935 Mdot
.6569 .40587 Mdot
.65577 .50929 Mdot
.36354 .50143 Mdot
.39591 .61041 Mdot
.49749 .54168 Mdot
.43095 .66038 Mdot
.62439 .35183 Mdot
.67612 .55535 Mdot
.57468 .63456 Mdot
.35688 .62457 Mdot
.43998 .52848 Mdot
.55605 .63209 Mdot
.37403 .48158 Mdot
.57712 .67814 Mdot
.69184 .54513 Mdot
.55593 .35664 Mdot
.5173 .30419 Mdot
.32002 .50084 Mdot
.56217 .45198 Mdot
.30793 .54293 Mdot
.47931 .32988 Mdot
.58662 .5399 Mdot
.45423 .65769 Mdot
.6355 .38146 Mdot
.51848 .36476 Mdot
.45273 .31523 Mdot
.49851 .35497 Mdot
.61659 .40864 Mdot
.65266 .49445 Mdot
.36023 .60124 Mdot
.6217 .58201 Mdot
.66698 .4447 Mdot
.37801 .63527 Mdot
.61798 .38265 Mdot
.60452 .54747 Mdot
.68765 .49799 Mdot
.43965 .67866 Mdot
.4394 .68582 Mdot
.35153 .45082 Mdot
.36971 .60208 Mdot
.4308 .47533 Mdot
.69404 .50607 Mdot
.3315 .53952 Mdot
.62017 .53673 Mdot
.65389 .62051 Mdot
.58233 .65717 Mdot
.67619 .5348 Mdot
.57512 .67459 Mdot
.48546 .31112 Mdot
.65282 .38989 Mdot
.56122 .62839 Mdot
.37043 .50026 Mdot
.40644 .40353 Mdot
.35941 .49517 Mdot
.5889 .65054 Mdot
.40706 .52625 Mdot
.6629 .57881 Mdot
.4681 .64811 Mdot
.55644 .51189 Mdot
.63542 .60629 Mdot
.46278 .60388 Mdot
.54577 .67755 Mdot
.62796 .64041 Mdot
.46112 .34688 Mdot
.34003 .49843 Mdot
.5323 .59468 Mdot
.39404 .66038 Mdot
.49833 .4659 Mdot
.49058 .60554 Mdot
.3425 .5409 Mdot
.51637 .60006 Mdot
.37172 .64662 Mdot
.6794 .4184 Mdot
.57022 .58716 Mdot
.52677 .40216 Mdot
.33804 .56639 Mdot
.45561 .66008 Mdot
.51895 .66375 Mdot
.67261 .45526 Mdot
.33709 .51051 Mdot
.439 .34535 Mdot
.53646 .50498 Mdot
.35578 .53866 Mdot
.46182 .42592 Mdot
.35018 .46285 Mdot
.31439 .45208 Mdot
.49449 .35843 Mdot
.60117 .56669 Mdot
.32803 .55243 Mdot
.61299 .36623 Mdot
.43489 .50404 Mdot
.43878 .56734 Mdot
.55266 .35219 Mdot
.4537 .57598 Mdot
.46187 .56038 Mdot
.47235 .45367 Mdot
.55988 .34469 Mdot
.56604 .57306 Mdot
.61271 .54788 Mdot
.68282 .56297 Mdot
.38372 .3948 Mdot
.55363 .61348 Mdot
.61045 .6073 Mdot
.53882 .40205 Mdot
.40638 .67258 Mdot
.42899 .51475 Mdot
.69188 .47864 Mdot
.51938 .44026 Mdot
.57395 .6209 Mdot
.41413 .3257 Mdot
.58082 .55636 Mdot
.46245 .46426 Mdot
.32954 .51453 Mdot
.329 .56216 Mdot
.42553 .58939 Mdot
.38266 .37322 Mdot
.62055 .5345 Mdot
.59214 .64268 Mdot
.62406 .56109 Mdot
.39988 .62926 Mdot
.67515 .4059 Mdot
.43581 .33865 Mdot
.57625 .32402 Mdot
.65608 .56875 Mdot
.44825 .60803 Mdot
.36951 .36214 Mdot
.5558 .48409 Mdot
.61886 .49495 Mdot
.66138 .41105 Mdot
.59119 .35313 Mdot
.58602 .37035 Mdot
.41752 .5105 Mdot
.64309 .43868 Mdot
.54211 .35346 Mdot
.61896 .62312 Mdot
.48375 .31326 Mdot
.54692 .36217 Mdot
.64544 .63762 Mdot
.57741 .37926 Mdot
.63827 .62208 Mdot
.64959 .42689 Mdot
.48665 .60067 Mdot
.58646 .5476 Mdot
.51999 .42385 Mdot
.60367 .64176 Mdot
.67075 .50095 Mdot
.56837 .50744 Mdot
.47568 .68306 Mdot
.53467 .67065 Mdot
.59747 .6644 Mdot
.40528 .59372 Mdot
.58021 .52318 Mdot
.32937 .55075 Mdot
.54124 .30724 Mdot
.38494 .6236 Mdot
.68982 .48523 Mdot
.52399 .69508 Mdot
.62505 .48348 Mdot
.55368 .68798 Mdot
.46446 .35 Mdot
.62747 .48227 Mdot
.34104 .44472 Mdot
.34942 .36991 Mdot
.33776 .49712 Mdot
.57577 .60163 Mdot
.47865 .3304 Mdot
.53616 .33051 Mdot
.50207 .31849 Mdot
.34083 .43097 Mdot
.5201 .34243 Mdot
.38001 .63523 Mdot
.56655 .52235 Mdot
.38298 .60319 Mdot
.35154 .49379 Mdot
.53396 .34276 Mdot
.69072 .5169 Mdot
.41408 .40377 Mdot
.48206 .62471 Mdot
.60391 .36112 Mdot
.34387 .4721 Mdot
.44003 .68472 Mdot
.50201 .43902 Mdot
.60586 .44415 Mdot
.45575 .30432 Mdot
.32825 .45076 Mdot
.55896 .65596 Mdot
.50428 .37833 Mdot
.56665 .6657 Mdot
.63146 .6497 Mdot
.62952 .4213 Mdot
.48249 .63499 Mdot
.34738 .6184 Mdot
.64251 .48627 Mdot
.37249 .35501 Mdot
.60188 .53903 Mdot
.67754 .42378 Mdot
.3527 .48154 Mdot
.48566 .36058 Mdot
.50827 .38228 Mdot
.33643 .44957 Mdot
.41966 .40344 Mdot
.41942 .41106 Mdot
.36509 .63806 Mdot
.50621 .63345 Mdot
.37987 .61152 Mdot
.39113 .39756 Mdot
.43868 .63129 Mdot
.44309 .34897 Mdot
.57732 .31651 Mdot
.60724 .46885 Mdot
.67792 .54807 Mdot
.3628 .58257 Mdot
.37002 .59426 Mdot
.52627 .36631 Mdot
.66544 .5385 Mdot
.45493 .49057 Mdot
.4581 .43993 Mdot
.64749 .4177 Mdot
.41233 .64777 Mdot
.51676 .58774 Mdot
.33093 .4606 Mdot
.46703 .68968 Mdot
.30909 .49226 Mdot
.58967 .38377 Mdot
.61965 .58261 Mdot
.57697 .5359 Mdot
.66784 .57493 Mdot
.424 .48165 Mdot
.35016 .59573 Mdot
.3894 .39114 Mdot
.57582 .53458 Mdot
.38737 .5879 Mdot
.35948 .46422 Mdot
.60878 .61209 Mdot
.65224 .54418 Mdot
.4924 .58193 Mdot
.5923 .46639 Mdot
.55007 .69393 Mdot
.60644 .40733 Mdot
.40503 .32946 Mdot
.33128 .51993 Mdot
.65253 .53672 Mdot
.36309 .58918 Mdot
.44089 .42692 Mdot
.57314 .41742 Mdot
.32998 .48177 Mdot
.57996 .34371 Mdot
.50853 .66543 Mdot
.6168 .38445 Mdot
.65943 .54886 Mdot
.61757 .49012 Mdot
.36858 .61038 Mdot
.33534 .48984 Mdot
.43785 .5883 Mdot
.54679 .53091 Mdot
.47949 .42469 Mdot
.51351 .68863 Mdot
.55347 .64014 Mdot
.40585 .56204 Mdot
.68105 .44791 Mdot
.33473 .46091 Mdot
.60594 .42661 Mdot
.35744 .45693 Mdot
.3324 .47887 Mdot
.68245 .55298 Mdot
.57842 .63561 Mdot
.67556 .43338 Mdot
.35917 .5383 Mdot
.45838 .30506 Mdot
.46704 .69512 Mdot
.4482 .67435 Mdot
.46212 .59709 Mdot
.50515 .39303 Mdot
.33638 .5972 Mdot
.54165 .675 Mdot
.59864 .41671 Mdot
.58091 .67585 Mdot
.4737 .31508 Mdot
.50853 .5721 Mdot
.489 .64616 Mdot
.41693 .48163 Mdot
.64922 .50022 Mdot
.50985 .63283 Mdot
.45022 .38053 Mdot
.39689 .51251 Mdot
.47631 .6409 Mdot
.48434 .64818 Mdot
.42812 .56315 Mdot
.63645 .59269 Mdot
.43211 .38181 Mdot
.59793 .37316 Mdot
.33795 .60357 Mdot
.43878 .63423 Mdot
.37181 .59085 Mdot
.59027 .54564 Mdot
.47205 .37961 Mdot
.34325 .37595 Mdot
.32484 .56697 Mdot
.42524 .64396 Mdot
.67209 .55689 Mdot
.50682 .53653 Mdot
.3901 .60246 Mdot
.38501 .60967 Mdot
.65942 .47982 Mdot
.58361 .53057 Mdot
.44908 .47375 Mdot
.69611 .49278 Mdot
.62393 .36085 Mdot
.34003 .61606 Mdot
.32142 .57455 Mdot
.6392 .55755 Mdot
.41605 .5807 Mdot
.57191 .3675 Mdot
.68351 .50521 Mdot
.31377 .54775 Mdot
.62674 .51577 Mdot
.35115 .61279 Mdot
.38703 .54369 Mdot
.33776 .59695 Mdot
.36866 .42567 Mdot
.68974 .53764 Mdot
.59255 .6319 Mdot
.64987 .46108 Mdot
.51799 .36736 Mdot
.55248 .55152 Mdot
.52371 .33936 Mdot
.45516 .40687 Mdot
.50072 .37059 Mdot
.47107 .63024 Mdot
.48025 .5604 Mdot
.61014 .39462 Mdot
.47867 .33233 Mdot
.60421 .37176 Mdot
.41848 .45793 Mdot
.56998 .44558 Mdot
.567 .32563 Mdot
.50684 .43371 Mdot
.62908 .52567 Mdot
.65884 .61351 Mdot
.49417 .54561 Mdot
.55529 .34121 Mdot
.69643 .48094 Mdot
.59375 .44875 Mdot
.50852 .64482 Mdot
.65356 .56975 Mdot
.43486 .38447 Mdot
.58146 .64083 Mdot
.60335 .38037 Mdot
.3753 .5929 Mdot
.55741 .39562 Mdot
.44202 .65301 Mdot
.39103 .46356 Mdot
.30354 .47522 Mdot
.39555 .4423 Mdot
.33906 .40118 Mdot
.4003 .6589 Mdot
.37744 .48855 Mdot
.4214 .3557 Mdot
.3938 .64447 Mdot
.5253 .4254 Mdot
.61919 .46097 Mdot
.68751 .47743 Mdot
.39287 .36116 Mdot
.34672 .57953 Mdot
.61395 .63714 Mdot
.58509 .37154 Mdot
.3267 .42673 Mdot
.33215 .49031 Mdot
.66293 .54444 Mdot
.54188 .42946 Mdot
.43886 .31863 Mdot
.54086 .50661 Mdot
.4924 .32887 Mdot
.60167 .53909 Mdot
.65375 .62669 Mdot
.39846 .37784 Mdot
.62535 .46788 Mdot
.51929 .42745 Mdot
.37618 .585 Mdot
.46701 .64613 Mdot
.3732 .63802 Mdot
.36556 .54602 Mdot
.41984 .31857 Mdot
.3793 .57273 Mdot
.62765 .44012 Mdot
.42953 .5938 Mdot
.57272 .37063 Mdot
.4655 .32363 Mdot
.56818 .42574 Mdot
.65559 .42074 Mdot
.32818 .53466 Mdot
.42076 .40822 Mdot
.64827 .62176 Mdot
.5695 .67794 Mdot
.32471 .57193 Mdot
.52327 .34304 Mdot
.3394 .4989 Mdot
.38849 .56498 Mdot
.44967 .41059 Mdot
.45079 .34053 Mdot
.51171 .45858 Mdot
.54514 .31013 Mdot
.43522 .61841 Mdot
.61054 .64086 Mdot
.52323 .6538 Mdot
.68195 .45297 Mdot
.55047 .33959 Mdot
.56023 .62818 Mdot
.48106 .5727 Mdot
.50657 .41832 Mdot
.3742 .35063 Mdot
.64558 .56347 Mdot
.60675 .33554 Mdot
.46314 .66148 Mdot
.33371 .4974 Mdot
.61303 .6605 Mdot
.48926 .59789 Mdot
.53436 .57668 Mdot
.34084 .52496 Mdot
.67967 .51062 Mdot
.57089 .64156 Mdot
.51011 .67317 Mdot
.34538 .44951 Mdot
.55091 .59722 Mdot
.46554 .32956 Mdot
.6288 .39633 Mdot
.51974 .57318 Mdot
.49832 .32502 Mdot
.68659 .44266 Mdot
.34588 .43879 Mdot
.35756 .52954 Mdot
.32256 .4316 Mdot
.44149 .68253 Mdot
.46011 .6088 Mdot
.49388 .3569 Mdot
.55013 .55019 Mdot
.67653 .53285 Mdot
.51118 .65522 Mdot
.56666 .33871 Mdot
.31552 .49954 Mdot
.6238 .36841 Mdot
.61098 .4514 Mdot
.38965 .58188 Mdot
.39451 .59401 Mdot
.61642 .5958 Mdot
.59632 .54847 Mdot
.45219 .557 Mdot
.58921 .46484 Mdot
.42658 .61694 Mdot
.4528 .33353 Mdot
.32969 .46502 Mdot
.54466 .68234 Mdot
.40847 .32639 Mdot
.47595 .66566 Mdot
.48895 .66876 Mdot
.59551 .41767 Mdot
.57008 .59579 Mdot
.53364 .41519 Mdot
.5229 .39618 Mdot
.64427 .3639 Mdot
.32483 .55676 Mdot
.57419 .62202 Mdot
.58695 .44729 Mdot
.6551 .45548 Mdot
.49939 .61216 Mdot
.42772 .31871 Mdot
.66515 .49518 Mdot
.54836 .32986 Mdot
.57755 .37867 Mdot
.66602 .47986 Mdot
.61411 .54089 Mdot
.62946 .61113 Mdot
.38624 .40406 Mdot
.61886 .45752 Mdot
.45353 .37639 Mdot
.6795 .49326 Mdot
.41606 .53706 Mdot
.42689 .66856 Mdot
.34871 .55625 Mdot
.402 .48908 Mdot
.41021 .43275 Mdot
.3444 .45939 Mdot
.31682 .42876 Mdot
.32157 .57416 Mdot
.65161 .4372 Mdot
.32619 .51846 Mdot
.50812 .62895 Mdot
.30557 .49613 Mdot
.53795 .39523 Mdot
.54923 .59625 Mdot
.38698 .6282 Mdot
.46646 .44802 Mdot
.51326 .34576 Mdot
.6147 .61121 Mdot
.53495 .65474 Mdot
.44441 .34374 Mdot
.45095 .68705 Mdot
.53883 .68682 Mdot
.67039 .54317 Mdot
.47851 .30654 Mdot
.52181 .65738 Mdot
.32697 .44598 Mdot
.63284 .36245 Mdot
.63406 .38124 Mdot
.61959 .59183 Mdot
.50769 .37543 Mdot
.65302 .38247 Mdot
.65947 .57485 Mdot
.35369 .36426 Mdot
.62003 .35425 Mdot
.37838 .44252 Mdot
.62307 .65176 Mdot
.39824 .65582 Mdot
.41328 .44501 Mdot
.30738 .51887 Mdot
.46088 .35608 Mdot
.39022 .61726 Mdot
.6029 .46138 Mdot
.33354 .51716 Mdot
.61357 .39168 Mdot
.62219 .38161 Mdot
.67327 .52899 Mdot
.4549 .62486 Mdot
.64398 .38829 Mdot
.65536 .46926 Mdot
.44558 .66002 Mdot
.33684 .50361 Mdot
.39911 .4299 Mdot
.54845 .54493 Mdot
.45183 .43479 Mdot
.40705 .37962 Mdot
.52334 .33292 Mdot
.52665 .31328 Mdot
.50789 .30535 Mdot
.3466 .53941 Mdot
.56362 .416 Mdot
.4542 .50339 Mdot
.35185 .44644 Mdot
.6539 .49653 Mdot
.62484 .46582 Mdot
.6025 .3898 Mdot
.46025 .60917 Mdot
.51566 .69718 Mdot
.3368 .45727 Mdot
.39536 .52863 Mdot
.54832 .32743 Mdot
.6739 .50183 Mdot
.65242 .43648 Mdot
.32944 .48876 Mdot
.44605 .55232 Mdot
.38681 .49195 Mdot
.33561 .57971 Mdot
.38896 .35386 Mdot
.62488 .61279 Mdot
.34014 .58902 Mdot
.33318 .39438 Mdot
.66449 .45589 Mdot
.52754 .37622 Mdot
.69282 .46257 Mdot
.60717 .3569 Mdot
.3725 .54334 Mdot
.33283 .53306 Mdot
.5923 .45864 Mdot
.68078 .55876 Mdot
.46346 .63482 Mdot
.61673 .44225 Mdot
.62021 .38561 Mdot
.42058 .60955 Mdot
.67957 .41867 Mdot
.42615 .46841 Mdot
.69627 .47226 Mdot
.46899 .35787 Mdot
.32754 .48071 Mdot
.50329 .68022 Mdot
.35806 .42118 Mdot
.54775 .68682 Mdot
.47886 .61164 Mdot
.47306 .66657 Mdot
.35893 .5934 Mdot
.61974 .43868 Mdot
.32764 .51548 Mdot
.42271 .59517 Mdot
.32856 .47536 Mdot
.39048 .34485 Mdot
.69885 .52329 Mdot
.42383 .55952 Mdot
.36432 .56744 Mdot
.5452 .61396 Mdot
.5818 .60022 Mdot
.64827 .41763 Mdot
.48788 .32732 Mdot
.63468 .49261 Mdot
.48197 .69674 Mdot
.44371 .43932 Mdot
.48572 .36521 Mdot
.61824 .48841 Mdot
.48148 .36512 Mdot
.42306 .45234 Mdot
.43476 .67634 Mdot
.34543 .60966 Mdot
.59261 .64453 Mdot
.37549 .5187 Mdot
.32189 .58001 Mdot
.30598 .50205 Mdot
.58666 .68262 Mdot
.62529 .35171 Mdot
.3391 .56786 Mdot
.61965 .37131 Mdot
.46155 .36014 Mdot
.47046 .66205 Mdot
.36848 .58892 Mdot
.63453 .38423 Mdot
.49485 .69291 Mdot
.37293 .58355 Mdot
.60264 .33067 Mdot
.64069 .42618 Mdot
.40392 .32799 Mdot
.65418 .57292 Mdot
.52592 .62925 Mdot
.54944 .69059 Mdot
.31032 .46765 Mdot
.62653 .431 Mdot
.6141 .59577 Mdot
.66996 .54151 Mdot
.60444 .38077 Mdot
.41826 .41384 Mdot
.65835 .54128 Mdot
.4541 .32663 Mdot
.37643 .61091 Mdot
.44221 .43204 Mdot
.57335 .61316 Mdot
.40622 .54049 Mdot
.41185 .38405 Mdot
.32039 .476 Mdot
.31213 .4402 Mdot
.40718 .51197 Mdot
.42501 .35993 Mdot
.62641 .3509 Mdot
.37578 .34688 Mdot
.57183 .59195 Mdot
.50456 .64355 Mdot
.4079 .49523 Mdot
.57518 .543 Mdot
.6712 .6017 Mdot
.3348 .56001 Mdot
.39179 .46102 Mdot
.65118 .40548 Mdot
.58113 .53764 Mdot
.51234 .62031 Mdot
.52472 .61208 Mdot
.39983 .41783 Mdot
.67163 .60565 Mdot
.37079 .64184 Mdot
.32673 .4153 Mdot
.46973 .68294 Mdot
.30713 .49571 Mdot
.5472 .412 Mdot
.66834 .43363 Mdot
.63148 .43091 Mdot
.61501 .36874 Mdot
.45397 .39478 Mdot
.4049 .37709 Mdot
.66685 .60294 Mdot
.36182 .43234 Mdot
.48843 .44852 Mdot
.66627 .50954 Mdot
.39233 .54099 Mdot
.33063 .47997 Mdot
.4352 .44419 Mdot
.3361 .39685 Mdot
.43876 .33467 Mdot
.4731 .3758 Mdot
.65721 .5066 Mdot
.66298 .58827 Mdot
.65031 .42995 Mdot
.36506 .49857 Mdot
.54079 .65959 Mdot
.32061 .5022 Mdot
.5162 .35939 Mdot
.59266 .48546 Mdot
.57542 .60766 Mdot
.408 .57013 Mdot
.33643 .53623 Mdot
.43006 .31568 Mdot
.40714 .52642 Mdot
.41556 .43041 Mdot
.341 .46908 Mdot
.64543 .62435 Mdot
.49537 .51433 Mdot
.4283 .43971 Mdot
.33753 .44513 Mdot
.37821 .34102 Mdot
.38758 .58965 Mdot
.51632 .6842 Mdot
.66856 .42609 Mdot
.32359 .43177 Mdot
.32988 .52922 Mdot
.66623 .44035 Mdot
.58855 .46379 Mdot
.60443 .33972 Mdot
.4331 .43237 Mdot
.52823 .67839 Mdot
.63637 .57275 Mdot
.35176 .39624 Mdot
.46494 .42203 Mdot
.36713 .64218 Mdot
.50307 .36514 Mdot
.53073 .4158 Mdot
.46589 .66718 Mdot
.59797 .38866 Mdot
.41326 .63571 Mdot
.6624 .53124 Mdot
.46743 .35174 Mdot
.56699 .32403 Mdot
.38252 .34081 Mdot
.52487 .58278 Mdot
.68679 .45536 Mdot
.56046 .41442 Mdot
.55328 .66065 Mdot
.57468 .51784 Mdot
.67758 .41545 Mdot
.57889 .65752 Mdot
.37041 .42892 Mdot
.55746 .57179 Mdot
.64143 .35988 Mdot
.42925 .60755 Mdot
.51014 .54607 Mdot
.57956 .58672 Mdot
.48994 .5974 Mdot
.4874 .57396 Mdot
.6455 .57135 Mdot
.50376 .52597 Mdot
.59671 .63952 Mdot
.62944 .55718 Mdot
.40192 .44959 Mdot
.6107 .43658 Mdot
.47172 .38877 Mdot
.33105 .39484 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0?ooooooB_ooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A006ooooo`03o`000?oooooooooo0?ooooooB_ooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0?ooooooB_oo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06
ooooo`?o0000oooooom:ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<oooo
o`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom:ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001_ooool00ol0003oooooooooo`3ooooood[ooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Nooooo`;o
00000oooool2o`000:Cooooo000Looooo`03o`000?oooooooooo093ooooo6ol0002Nooooo`007?oo
ool00ol0003oooooooooo`2?ooooo`oo000000?oooooo`000?l000003Ol0002Kooooo`007?ooool0
0ol0003oooooooooo`28oooooa7o000000?oooooo`000?l000004_l00002ooooo`?o0000U_ooool0
01cooooo00?o0000ooooooooool0R?oooolOo`000003ooooool0003o000000_o0000U?ooool001co
oooo00?o0000ooooooooool0Q?ooool2o`000003ooooool0003o000002oo0000TOooool001cooooo
00?o0000ooooooooool0Pooooolgo`0008oooooo000Looooo`03o`000?oooooooooo087ooooo7ol0
00000ooooooo0000o`00000Io`0008gooooo000Looooo`03o`000?oooooooooo07oooooo:ol00000
0ooooooo0000o`00000Ao`0008_ooooo000Looooo`;o0000Oooooom4o`0008Oooooo000Looooo`03
o`000?oooooooooo07[ooooo9?l000000ooooooo0000o`000007o`000003ooooool0003o000000co
000000?oooooo`000?l000002Ol00026ooooo`007?ooool00ol0003oooooooooo`1joooooaWo0000
1Oooool2o`0000Gooooo1ol00006oooooaWo0000Q?ooool001cooooo00?o0000ooooooooool0Mooo
oolIo`000003ooooool0003o000000Gooooo0_l00005ooooo`Co00002Oooool3o`0000;ooooo5?l0
0024ooooo`007?ooool00ol0003oooooooooo`1goooooaKo00003?ooool3o`0000_ooooo0_l00004
ooooo`;o00000ooooolDo`0008?ooooo000Looooo`03o`000?oooooooooo07Kooooo5?l00005oooo
o`;o00001Oooool2o`000004ooooool0003o0000o`0000_ooooo0_l0000<oooooaGo0000Ooooool0
01cooooo00?o0000ooooooooool0LooooolGo`000005ooooool0003o0000o`000?ooool00_l00005
ooooo`;o00001oooool2o`0000kooooo0_l00007oooooaCo0000OOooool001cooooo00?o0000oooo
ooooool0L_oooolGo`0000;ooooo0ol0000;ooooo`;o00001?ooool2o`0000kooooo0_l00005oooo
o`;o00000ooooolAo`0007gooooo000Looooo`03o`000?oooooooooo077ooooo4Ol000000ooooooo
0000o`000007ooooo`;o00001Oooool2o`0000Cooooo0_l00003ooooo`;o00002oooool2o`0000Oo
oooo1Ol00005ooooo`oo0000O?ooool001cooooo00?o0000ooooooooool0L?oooolEo`0000_ooooo
0_l000000ooooooo0000o`000006ooooo`Go00002oooool5o`0000?ooooo1_l00007ooooo`oo0000
N_ooool001cooooo00?o0000ooooooooool0KooooolEo`0000cooooo0_l000000ooooooo0000o`00
0003ooooo`;o000000Coooooo`000?l0003o00003?ooool6o`000003ooooool0003o000000;o0000
00?oooooo`000?l000002?oooolAo`0007Sooooo000Looooo`03o`000?oooooooooo06gooooo4Ol0
00001?oooooo0000o`000?l00009ooooo`;o00000_ooool3o`000003ooooool0003o000000?ooooo
0_l0000<ooooo`;o00000_ooool3o`000004ooooool0003o0000ooooo`;o00003Oooool3o`0000;o
oooo3?l0001hooooo`007?ooool00ol0003oooooooooo`1]oooooa3o00000_ooool2o`0000Wooooo
0ol00002ooooo`?o00005?ooool2o`0001Wooooo0_l00003ooooo`co0000Moooool001cooooo00?o
0000ooooooooool0KOooool>o`0000oooooo0_l00003ooooo`;o00005Oooool2o`0000Oooooo1?l0
00000ooooooo0000o`00000;ooooo`;o00000oooool>o`0007Gooooo000Looooo`03o`000?oooooo
oooo06[ooooo4Ol0000Booooo`Co00005?ooool3o`0000;ooooo0_l00003ooooo`Oo00000oooool2
o`0000Kooooo0_l00005ooooo`go0000M?ooool001cooooo00?o0000ooooooooool0J_ooool>o`00
00?ooooo0_l0000>ooooo`Co00000oooool2o`0000oooooo1Ol00002ooooo`;o00001_ooool2o`00
00Gooooo0_l0000>ooooo`co0000M?ooool001cooooo0_l0001[ooooo`ko00000oooool2o`0000ko
oooo0ol00004ooooo`?o00003_ooool2o`0000Oooooo0_l0000;ooooo`;o00003Oooool>o`0007?o
oooo000Looooo`03o`000?oooooooooo06Oooooo3Ol00002ooooo`;o00000oooool2o`0000Kooooo
0_l00006ooooo`?o00001Oooool3o`0000Gooooo0_l0000>ooooo`?o00000_ooool2o`0000Oooooo
0_l000000ooooooo0000o`000009ooooo`?o000000?oooooo`000?l000002_l0001booooo`007?oo
ool00ol0003oooooooooo`1Wooooo`co00000_ooool3o`0000;ooooo0ol00006ooooo`Co00002ooo
ool4o`0000Gooooo1Ol00006ooooo`;o00000oooool3o`0000;ooooo0ol00006ooooo`;o000000?o
ooooo`000?l000000oooool2o`0000?ooooo0ol00003ooooo`co0000LOooool001cooooo00?o0000
ooooooooool0I_ooool=o`0000;ooooo0ol00002ooooo`?o00002?ooool3o`0000?ooooo0_l00005
ooooo`;o000000?oooooo`000?l000001_ooool3o`0000Cooooo1?l00009ooooo`;o00001_ooool2
o`0000Kooooo0_l00003ooooo`;o00001?ooool=o`00073ooooo000Looooo`03o`000?oooooooooo
06Gooooo3Ol00002ooooo`;o00001?ooool4o`0000Oooooo0ol00003ooooo`;o00001Oooool2o`00
0003ooooool0003o000000?ooooo1Ol00005ooooo`;o00002?ooool2o`00013ooooo0_l00005oooo
o`;o000000Coooooo`000?l0003ooooo3?l0001`ooooo`007?ooool00ol0003oooooooooo`1Uoooo
o`co00000oooool2o`0000Cooooo1?l00007ooooo`;o00001_ooool2o`0000[ooooo1Ol00002oooo
o`;o00000oooool4o`0000Gooooo0_l0000<ooooo`;o00000_ooool2o`000003ooooool0003o0000
00;ooooo0_l000001?oooooo0000o`000?ooool=o`0006oooooo000Looooo`03o`000?oooooooooo
06Gooooo3?l0000<ooooo`;o00003_ooool2o`0000Gooooo0_l00003ooooo`?o00001?ooool2o`00
00;ooooo1Ol0000=ooooo`;o00001?ooool2o`0000Gooooo0ol000000ooooooo0000o`000004oooo
o`go0000Koooool001cooooo00?o0000ooooooooool0I?ooool5o`000003ooooool0003o000000Co
00003Oooool2o`0001Gooooo0_l00009ooooo`;o00000oooool2o`00013ooooo0_l00002ooooo`?o
00000oooool2o`0000;ooooo1Ol00006ooooo`co0000K_ooool001cooooo00?o0000ooooooooool0
I?ooool<o`0000Wooooo0_l00002ooooo`;o00008?ooool4o`0001?ooooo0_l00002ooooo`?o0000
00?oooooo`000?l000000_l00003ooooo`;o00002?ooool<o`0006kooooo000Looooo`03o`000?oo
oooooooo06;ooooo3?l0000;ooooo`;o00000oooool4o`0000kooooo0_l00004ooooo`;o00002?oo
ool3o`0000Gooooo0_l0000>ooooo`;o00001?ooool2o`000003ooooool0003o000000oooooo2_l0
001]ooooo`007?ooool00ol0003oooooooooo`1Rooooo`co00003?ooool2o`0000;ooooo1?l0000<
ooooo`Co00001?ooool2o`0000Sooooo0_l00006ooooo`;o00003_ooool2o`0000;ooooo0_l00002
ooooo`?o00000oooool9o`0000?ooooo3Ol0001Zooooo`007?ooool00ol0003oooooooooo`1Qoooo
o`_o00003_ooool2o`0000;ooooo1_l00005ooooo`Co000000Coooooo`000?l0003o00000_ooool2
o`000003ooooool0003o000000Oooooo1?l0000=ooooo`;o00001_ooool2o`000004ooooool0003o
0000o`0000;ooooo0ol00002ooooo`[o000000Coooooo`000?l0003ooooo3?l0001Zooooo`007?oo
ool00ol0003oooooooooo`1Qooooo`[o00002Oooool2o`0000cooooo0_l00005ooooo`Co00001_oo
ool4o`0000Sooooo1?l0000=ooooo`;o00002Oooool3o`0000Oooooo0ol00002ooooo`;o00001?oo
ool2o`000003ooooool0003o000000_o0000JOooool001cooooo00?o0000ooooooooool0HOooool:
o`0000;ooooo0_l00005ooooo`;o00005?ooool2o`0000Wooooo0_l0000Wooooo`Co00001?ooool2
o`0000Gooooo0_l000000ooooooo0000o`000002ooooo`co0000JOooool00006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oo
oooooooo05oooooo3?l00002ooooo`;o00003?ooool2o`0000gooooo0_l00009ooooo`;o00002Ooo
ool2o`0001cooooo1?l00002ooooo`;o00001oooool2o`000003ooooool0003o000000;ooooo3Ol0
001Xooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo05oooooo3?l00004ooooo`;o00002?ooool4o`0001?ooooo
0_l0000>ooooo`;o00001?ooool2o`0000?ooooo0ol00003ooooo`;o000000?oooooo`000?l00000
3?ooool4o`0000;ooooo0_l0000;ooooo`co0000J?ooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02Oooool5o`0000Kooooo00?o0000ooooooooool0G_ooool=o`0000Cooooo0_l0
0008ooooo`Co00004oooool2o`0001Cooooo0_l00003ooooo`?o00000oooool2o`000003ooooool0
003o000000cooooo0_l00004ooooo`;o00003Oooool;o`0006Oooooo00000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`0005kooooo2ol0
00000ooooooo0000o`00000?ooooo`;o000000?oooooo`000?l000009oooool2o`0000;ooooo0_l0
000Oooooo`?o00002?ooool<o`0006Kooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`1Mooooo`_o00000_oo
ool2o`0000?ooooo0_l00009ooooo`?o000000?oooooo`000?l000000_l000000ooooooo0000o`00
0002o`00023ooooo0_l00002ooooo`;o00007oooool3o`000003ooooool0003o000000;o00001?oo
ool;o`0006Kooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oMgMg
olc<c?l000001oooool00ol0003oooooooooo`1Mooooo`[o00002?ooool2o`0000Wooooo0_l00004
ooooo`;o000000?oooooo`000?l000000_l00009ooooo`;o00004oooool2o`0001[ooooo0ol00000
0ooooooo0000o`000009ooooo`Co00001?ooool<o`0006Gooooo00001_ooooooMgMgoiRHV?oooooo
V9RHogMgM`cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`1Mooooo`Wo00007_oo
ool3o`0000Oooooo1?l00009ooooo`;o00002?ooool2o`0000Oooooo0_l0000@ooooo`Co000000?o
ooooo`000?l000003?ooool2o`0000Cooooo2ol0001Uooooo`0000Koooooonk^k_lb<S;o0000oc8b
<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0GOooool;o`0000gooooo
0_l0000=ooooo`;o00001oooool3o`0000_ooooo0_l0000=ooooo`;o00000_ooool2o`0000;ooooo
0_l0000<ooooo`;o00001?ooool2o`0000_ooooo0_l00003ooooo`go0000I?ooool001cooooo00?o
0000ooooooooool0G?ooool<o`0000gooooo0_l00007ooooo`;o00001?ooool2o`0000Oooooo0_l0
000Booooo`;o00001_ooool3o`0000Kooooo0ol000000ooooooo0000o`000006ooooo`Co00001?oo
ool3o`0000Kooooo0_l00007ooooo`go0000I?ooool001cooooo00?o0000ooooooooool0Foooool;
o`0000Oooooo0_l00002ooooo`;o00002oooool2o`00027ooooo0_l00006ooooo`;o00002?ooool2
o`000003ooooool0003o000000Kooooo0ol00006ooooo`Co00001?ooool4o`0000Kooooo3Ol0001S
ooooo`007?ooool00ol0003oooooooooo`1Kooooo`[o00002?ooool2o`0000;ooooo0_l0000Eoooo
o`;o00002Oooool2o`0000?ooooo0_l00007ooooo`;o00000_ooool2o`0002;ooooo0_l00005oooo
o`?o00001?ooool3o`000003ooooool0003o000000Wo0000Hoooool001cooooo00?o0000oooooooo
ool0G?ooool8o`0000;ooooo0_l0000<ooooo`;o00004_ooool2o`000003ooooool0003o000000Go
oooo0ol00003ooooo`;o00001oooool2o`0000;ooooo1?l0000:ooooo`Co00002_ooool2o`0000Wo
oooo0_l000000ooooooo0000o`000004ooooo`Go000000?oooooo`000?l000002Ol0001Sooooo`00
7?ooool00ol0003oooooooooo`1Looooo`Wo000000?oooooo`000?l000000oooool2o`0000Oooooo
0ol00007ooooo`;o00000oooool2o`0000Kooooo0_l00005ooooo`;o00004Oooool4o`0000?ooooo
0_l00005ooooo`Co00002_ooool2o`0000Gooooo0ol000001?oooooo0000o`000?ooool3o`0000?o
oooo0_l00005ooooo`[o0000Hoooool001cooooo00?o0000ooooooooool0F_ooool=o`0000Cooooo
0_l00005ooooo`;o000000?oooooo`000?l000001oooool2o`0000;ooooo0ol00004ooooo`;o0000
00?oooooo`000?l000004oooool2o`0000Wooooo0_l0000@ooooo`;o00002?ooool3o`0000Cooooo
0ol00003ooooo`;o000000?oooooo`000?l000000_ooool;o`0006;ooooo000Looooo`03o`000?oo
oooooooo05[ooooo2_l000000ooooooo0000o`00000;ooooo`;o000000?oooooo`000?l000000ooo
ool2o`0000Kooooo0_l00005ooooo`;o000000Coooooo`000?l0003ooooo0_l0000@ooooo`;o0000
6oooool2o`0000?ooooo0_l0000;ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo
2ol0001Rooooo`007?ooool00ol0003oooooooooo`1Iooooo`_o00001Oooool2o`000004ooooool0
003o0000o`0000Kooooo0_l00003ooooo`;o00002oooool4o`000004ooooool0003o0000ooooo`Co
00003?ooool2o`0000Cooooo0_l0000Looooo`;o000000?oooooo`000?l000000_l00003ooooo`;o
000000?oooooo`000?l000002oooool:o`0006;ooooo000Looooo`03o`000?oooooooooo05Wooooo
2ol00005ooooo`;o000000Coooooo`000?l0003o00000oooool2o`0000?ooooo0_l00004ooooo`;o
00002?ooool4o`000003ooooool0003o000000;ooooo0ol0000<ooooo`;o00001?ooool2o`0000go
oooo0_l0000?ooooo`Go00000oooool2o`0000Kooooo0_l00004ooooo`co0000H_ooool001cooooo
00?o0000ooooooooool0FOooool:o`0000?ooooo0_l00002ooooo`?o00000_ooool2o`000003oooo
ool0003o000000?ooooo0_l00004ooooo`?o00000oooool2o`0000Gooooo0_l0000Xooooo`Co0000
2Oooool2o`0000;ooooo0_l000000ooooooo0000o`00000;ooooo`;o00001?ooool=o`00067ooooo
000Looooo`03o`000?oooooooooo05Wooooo2_l00003ooooo`;o00000_ooool4o`000003ooooool0
003o000000gooooo0_l00003ooooo`;o00001Oooool2o`0000Sooooo0_l00005ooooo`;o00006?oo
ool3o`0000?ooooo1?l00002ooooo`;o00001Oooool2o`0000_ooooo0_l00002ooooo`oo0000HOoo
ool001cooooo0_l0001Iooooo`co00000oooool2o`000003ooooool0003o000000Co00003oooool2
o`0000Gooooo0_l0000<ooooo`;o00001Oooool2o`0001Kooooo0_l00006ooooo`Co00001?ooool2
o`0000?ooooo0_l0000=oooooa7o0000HOooool001cooooo00?o0000ooooooooool0F?ooool<o`00
00?ooooo0_l000000ooooooo0000o`000002ooooo`;o00003oooool2o`0000Gooooo0_l00004oooo
o`;o00000oooool2o`0000?ooooo0_l0000Kooooo`;o00003_ooool2o`0000cooooo0_l00004oooo
o`;o000000Coooooo`000?l0003o00000_ooool9o`00067ooooo000Looooo`03o`000?oooooooooo
05Sooooo2Ol00009ooooo`;o00001?ooool2o`0001;ooooo0_l00006ooooo`;o00000oooool3o`00
00;ooooo0_l0000:ooooo`;o00006Oooool2o`0000;ooooo0_l00002ooooo`;o00002_ooool2o`00
0004ooooool0003o0000ooooo`;o000000Coooooo`000?l0003o00000_ooool9o`00067ooooo000L
ooooo`03o`000?oooooooooo05Oooooo2_l00007ooooo`Ko00000_ooool2o`0000[ooooo0_l00006
ooooo`;o00003?ooool2o`0000kooooo0_l0000Iooooo`;o000000Coooooo`000?l0003o00000_oo
ool2o`0000Sooooo0_l00003ooooo`;o000000?oooooo`000?l000001Oooool:o`00067ooooo000L
ooooo`03o`000?oooooooooo05Oooooo2_l00007ooooo`?o000000?oooooo`000?l000000_l00000
0ooooooo0000o`000008ooooo`?o00005?ooool2o`0002Oooooo0ol00002ooooo`?o000000Cooooo
o`000?l0003o00002?ooool2o`0000Kooooo0_l00004ooooo`_o0000HOooool001cooooo00?o0000
ooooooooool0F?ooool;o`0000Cooooo0_l00005ooooo`;o000000?oooooo`000?l000002?ooool2
o`0001Gooooo0_l0000:ooooo`;o00006oooool4o`0000;ooooo0_l000001?oooooo0000o`000?oo
ool2o`0000Kooooo0_l00005ooooo`;o00001Oooool<o`00063ooooo000Looooo`03o`000?oooooo
oooo05Sooooo2ol00004ooooo`;o00000_ooool2o`0000kooooo0_l000000ooooooo0000o`000007
ooooo`;o00005Oooool2o`0001gooooo0_l00002ooooo`;o00001?ooool2o`0000Kooooo1?l00003
ooooo`;o00001?ooool2o`000003ooooool0003o000000So0000H?ooool001cooooo00?o0000oooo
ooooool0Eoooool9o`0000_ooooo0ol0000@ooooo`;o00001oooool2o`0000?ooooo1?l0000Boooo
o`;o00007Oooool2o`0000kooooo0_l00002ooooo`;o00001Oooool<o`00067ooooo000Looooo`03
o`000?oooooooooo05Oooooo2_l00003ooooo`;o000000?oooooo`000?l000000oooool2o`0001[o
oooo0_l00002ooooo`Co00001?ooool2o`0000cooooo0_l0000?ooooo`;o00008?ooool2o`0000Ko
oooo3?l0001Pooooo`007?ooool00ol0003oooooooooo`1Gooooo`[o00000oooool2o`000004oooo
ool0003o0000o`0001kooooo0_l0000:ooooo`;o00007Oooool2o`0001?ooooo0_l00008ooooo`;o
000000?oooooo`000?l000001Oooool=o`00063ooooo000Looooo`03o`000?oooooooooo05Oooooo
2Ol00007ooooo`?o00001Oooool2o`0000Gooooo0_l0000<ooooo`Co0000;?ooool2o`0001;ooooo
0_l00008ooooo`;o000000?oooooo`000?l000001Oooool=o`00063ooooo000Looooo`03o`000?oo
oooooooo05Sooooo2?l00007ooooo`Co00001?ooool2o`0000Gooooo0_l0000<ooooo`Co0000:Ooo
ool2o`000003ooooool0003o000000Oooooo0_l00008ooooo`?o00000oooool2o`0000Wooooo0_l0
0002ooooo`ko0000Goooool001cooooo00?o0000ooooooooool0F?ooool8o`0000Oooooo1?l00003
ooooo`;o00001oooool2o`0000Kooooo0_l0000`ooooo`;o00002_ooool2o`0000Kooooo1?l00004
ooooo`;o000000?oooooo`000?l000001_ooool2o`0000;ooooo0_l000000ooooooo0000o`000009
o`0005oooooo000Looooo`03o`000?oooooooooo05Oooooo2Ol000000ooooooo0000o`000004oooo
o`Co00000oooool2o`0000Oooooo0_l000000ooooooo0000o`000003ooooo`;o00003oooool2o`00
00;ooooo0_l0000_ooooo`;o00000oooool2o`0000Cooooo0_l0000=ooooo`_o0000Goooool001co
oooo00?o0000ooooooooool0Eoooool<o`0000Gooooo0ol00003ooooo`;o000000?oooooo`000?l0
00001oooool2o`0000Gooooo0_l0000=ooooo`;o00000_ooool2o`0002cooooo0_l000000ooooooo
0000o`000003ooooo`;o00001?ooool2o`0000;ooooo0_l00003ooooo`;o00000oooool<o`0005oo
oooo000Looooo`03o`000?oooooooooo05Kooooo3Ol00006ooooo`Co000000Coooooo`000?l0003o
oooo1?l000000ooooooo0000o`000009ooooo`;o0000?oooool2o`000003ooooool0003o000000Wo
oooo0ol000001?oooooo0000o`000?ooool4o`000003ooooool0003o000000co0000Goooool001co
oooo0_l0001Goooooa3o00000oooool4o`0000Gooooo1_l0001Gooooo`Co00000oooool3o`0000?o
oooo0_l00002ooooo`[o0000Goooool001cooooo00?o0000ooooooooool0Eoooool;o`000004oooo
ool0003o0000o`0000Cooooo0ol00005ooooo`;o000000?oooooo`000?l000004oooool2o`0000Co
oooo0_l0000Hooooo`;o00008oooool2o`0000Gooooo0ol00007ooooo`[o0000Goooool001cooooo
00?o0000ooooooooool0Eoooool;o`0000;ooooo0_l00004ooooo`;o00007_ooool2o`0000Cooooo
0_l0000Hooooo`Co00001oooool2o`0001_ooooo0_l00006ooooo`;o00000_ooool;o`00063ooooo
000Looooo`03o`000?oooooooooo05Oooooo2Ol0000:ooooo`;o00006?ooool2o`0002Kooooo0_l0
0007ooooo`;o00006_ooool3o`000003ooooool0003o000000;ooooo0ol00002ooooo`_o0000H?oo
ool001cooooo00?o0000ooooooooool0Eoooool:o`0000Wooooo0_l0000Aooooo`;o00000_ooool2
o`000003ooooool0003o000000Cooooo0_l0000Uooooo`;o00007_ooool2o`0000;ooooo0_l00002
ooooo`;o00001Oooool9o`00063ooooo000Looooo`03o`000?oooooooooo05Oooooo2_l00006oooo
o`Co00004_ooool2o`0000;ooooo0_l00005ooooo`Co00004Oooool2o`0001;ooooo0_l0000Eoooo
o`;o00004oooool<o`00063ooooo000Looooo`03o`000?oooooooooo05Oooooo2ol00004ooooo`Go
00002oooool2o`00013ooooo0_l0000Cooooo`;o00006?ooool2o`0000oooooo0_l0000Cooooo`co
0000H?ooool001cooooo00?o0000ooooooooool0Eoooool;o`0000Cooooo1?l0000<ooooo`;o0000
1?ooool2o`0003Kooooo0_l000000ooooooo0000o`000002o`0001[ooooo1?l00006ooooo`[o0000
H?ooool001cooooo00?o0000ooooooooool0Eoooool;o`0000Wooooo0_l00003ooooo`;o00002_oo
ool2o`0000;ooooo0ol0000Mooooo`;o00002_ooool2o`0000Kooooo0_l00003ooooo`?o00003Ooo
ool2o`0000[ooooo1?l00006ooooo`[o0000H?ooool001cooooo00?o0000ooooooooool0Eoooool:
o`0000Kooooo0_l00002ooooo`;o00000oooool2o`0000_ooooo0_l000001?oooooo0000o`000?l0
0008ooooo`;o00004oooool2o`0000[ooooo0_l0000<ooooo`;o00003Oooool2o`0000?ooooo0_l0
0006ooooo`?o00001oooool8o`00067ooooo000Looooo`03o`000?oooooooooo05Oooooo2_l00006
ooooo`;o00001oooool2o`0000_ooooo0_l0000<ooooo`;o00008Oooool2o`0000[ooooo0_l00003
ooooo`;o00002oooool4o`0000?ooooo0_l00002ooooo`;o00001_ooool9o`00067ooooo000Loooo
o`03o`000?oooooooooo05Oooooo2_l00006ooooo`?o0000:?ooool2o`0001[ooooo0_l00007oooo
o`;o000000?oooooo`000?l000000oooool2o`0000Gooooo0_l00004ooooo`Co00000oooool4o`00
0004ooooool0003o0000o`0000Cooooo2Ol0001Qooooo`007?ooool00ol0003oooooooooo`1Goooo
o`_o00001Oooool5o`0000Cooooo0ol0000@ooooo`;o00003Oooool2o`0000gooooo0_l0000Doooo
o`Co00002Oooool4o`0000Sooooo0_l00002ooooo`?o000000Goooooo`000?l0003o0000ooooo`02
o`000003ooooool0003o000000Ko0000H_ooool001cooooo00?o0000ooooooooool0Eoooool;o`00
00Kooooo1ol000001?oooooo0000o`000?l00009ooooo`;o00000_ooool2o`000003ooooool0003o
000001Wooooo0_l000000ooooooo0000o`00000Eooooo`Go00000oooool2o`0000;ooooo1?l00008
ooooo`So00001?ooool2o`000003ooooool0003o000000Ko0000H_ooool001cooooo00?o0000oooo
ooooool0Eoooool;o`000003ooooool0003o000000?ooooo0_l00002ooooo`?o000000?oooooo`00
0?l000000oooool2o`0000?ooooo1?l00002ooooo`;o00007?ooool2o`0000kooooo0_l00007oooo
o`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00001_ooool2o`0000;ooooo2?l00007oooo
o`Wo0000HOooool001cooooo00?o0000ooooooooool0Eoooool>o`0000_ooooo0_l000000ooooooo
0000o`000002o`0000?ooooo0_l00008ooooo`;o00005oooool2o`0000?ooooo0_l0000:ooooo`;o
00001oooool2o`0000;ooooo1?l00002ooooo`Co00001oooool2o`0000;ooooo0_l00002ooooo`Ko
00000oooool;o`00067ooooo000Looooo`;o0000FOooool<o`0000?ooooo0_l0000:ooooo`;o0000
3oooool2o`0001Oooooo0_l00003ooooo`;o00002oooool2o`0000;ooooo0_l00006ooooo`Go0000
00?oooooo`000?l000000_l0000=ooooo`;o00001?ooool2o`0000?ooooo2_l0001Rooooo`007?oo
ool00ol0003oooooooooo`1Hooooo`[o00001Oooool2o`0001Wooooo0_l00009ooooo`;o00008?oo
ool3o`000003ooooool0003o000000Wooooo0_l00006ooooo`;o00002_ooool2o`0000Kooooo0_l0
0002ooooo`Wo0000H_ooool001cooooo00?o0000ooooooooool0F?ooool:o`0000Cooooo0ol00005
ooooo`;o00004_ooool2o`0000Wooooo1?l0000Oooooo`;o00001oooool2o`0000_ooooo0_l00000
0ooooooo0000o`000009ooooo`;o000000?oooooo`000?l000003_l0001Rooooo`007?ooool00ol0
003oooooooooo`1Hooooo`_o00000oooool2o`000003ooooool0003o000000?ooooo0_l000001?oo
oooo0000o`000?ooool2o`0000[ooooo0_l00004ooooo`;o00001oooool2o`000003ooooool0003o
000000Cooooo0_l0000>ooooo`;o00003oooool2o`0000kooooo0_l000000ooooooo0000o`000006
ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000009o`0006;ooooo000Loooo
o`03o`000?oooooooooo05Sooooo2ol00004ooooo`Co00001_ooool2o`000003ooooool0003o0000
00Kooooo0_l00002ooooo`;o00001?ooool3o`0000;ooooo0_l00005ooooo`;o00001?ooool2o`00
00kooooo0_l0000=ooooo`;o00001Oooool2o`0000Oooooo0_l00003ooooo`Co00002Oooool3o`00
0003ooooool0003o000000So0000H_ooool001cooooo00?o0000ooooooooool0F?ooool;o`0000Co
oooo0_l000000ooooooo0000o`00000>ooooo`Co00000_ooool2o`0000Gooooo0_l00002ooooo`;o
0000:_ooool2o`0000Gooooo0_l00007ooooo`;o00001Oooool2o`0000Gooooo0_l00003ooooo`;o
000000?oooooo`000?l000001ol0001Sooooo`007?ooool00ol0003oooooooooo`1Iooooo`[o0000
0oooool2o`0000;ooooo0_l00007ooooo`;o00001Oooool2o`0000oooooo0_l0000aooooo`?o0000
4?ooool3o`000003ooooool0003o000000Kooooo2Ol0001Sooooo`007?ooool00ol0003ooooooooo
o`1Iooooo`co000000?oooooo`000?l000000_ooool2o`0000Oooooo0_l00002ooooo`;o00002?oo
ool2o`0000Oooooo0ol0000<ooooo`Co00001?ooool2o`0000kooooo0_l0000;ooooo`?o00000ooo
ool2o`0000Gooooo0_l000001?oooooo0000o`000?ooool3o`000003ooooool0003o000000Gooooo
2Ol0001Tooooo`007?ooool00ol0003oooooooooo`1Iooooo`oo00003Oooool4o`0000Sooooo0_l0
0007ooooo`;o00003Oooool4o`0000Cooooo0_l00002ooooo`;o00002_ooool2o`000003ooooool0
003o000000kooooo0_l00005ooooo`;o000000Coooooo`000?l0003ooooo0ol000001?oooooo0000
o`000?l00003ooooo`[o0000I?ooool001cooooo00?o0000ooooooooool0Foooool<o`0000kooooo
0_l0000Iooooo`;o00001oooool4o`0000Gooooo0_l000000ooooooo0000o`000003ooooo`;o0000
2?ooool2o`0001Gooooo0_l00004ooooo`Oo000000?oooooo`000?l000002_l0001Tooooo`007?oo
ool00ol0003oooooooooo`1Kooooo`co00000_ooool2o`0000;ooooo0_l00006ooooo`;o00000ooo
ool4o`0000Gooooo0_l0000;ooooo`;o00001oooool2o`000003ooooool0003o000000Cooooo0_l0
0006ooooo`;o00006_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool4o`000003ooooool0
003o000000[o0000I?ooool001cooooo00?o0000ooooooooool0Foooool<o`0000;ooooo0_l00002
ooooo`;o00000oooool2o`000004ooooool0003o0000o`0000;ooooo1?l00005ooooo`;o00005ooo
ool2o`0000Wooooo0_l0000Looooo`?o00001oooool2o`0000Gooooo0_l00002ooooo`Wo0000I_oo
ool001cooooo00?o0000ooooooooool0Foooool<o`0000_ooooo0_l000001?oooooo0000o`000?l0
0002ooooo`;o0000:?ooool2o`000003ooooool0003o000000;ooooo0_l00008ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0000Oooooo0_l0000Booooo`[o0000I_ooool001cooooo00?o0000
ooooooooool0G?ooool;o`0000Cooooo0_l00005ooooo`Go00000oooool2o`0000;ooooo0_l00006
ooooo`;o00000_ooool2o`0001Sooooo0_l00005ooooo`Co00001_ooool2o`000003ooooool0003o
000000;ooooo0_l0000Fooooo`;o00000oooool:o`0006Kooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003ooooo
ooooo`1Looooo`_o00001?ooool2o`0000Cooooo1ol00002ooooo`So00001?ooool6o`00027ooooo
0_l00007ooooo`;o00001Oooool2o`0000Kooooo0_l00004ooooo`;o00001oooool2o`0000?ooooo
2Ol0001Wooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGo
MgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0GOooool;o`0000;ooooo0_l00002oooo
o`;o000000Coooooo`000?l0003ooooo1?l00004ooooo`;o00000_ooool2o`0000Cooooo1?l00008
ooooo`;o00001oooool2o`0000cooooo0_l00004ooooo`;o00001?ooool3o`0000Gooooo0_l00005
ooooo`?o00001?ooool2o`0000cooooo2Ol0001Wooooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`1N
ooooo`[o00000_ooool2o`0000;ooooo0_l0000Fooooo`;o00002_ooool2o`0000Oooooo0_l00007
ooooo`;o00000oooool2o`0000Cooooo0_l00004ooooo`;o00000_ooool2o`0000Wooooo0_l0000B
ooooo`[o0000Ioooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0
003oV9RHoooooonHV9So8B4Q00Kooooo0ol0001Nooooo`_o000000?oooooo`000?l000001Oooool2
o`000004ooooool0003o0000ooooo`Ko00007Oooool3o`0000Oooooo0_l0000Aooooo`Co00001ooo
ool2o`00017ooooo3?l0001Xooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09
ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`1Nooooo`_o000000?o
ooooo`000?l000001Oooool2o`000004ooooool0003o0000ooooo`Ko00005_ooool2o`0000Cooooo
1Ol0000Iooooo`;o00002Oooool2o`0000Gooooo1?l00008ooooo`_o0000JOooool00003ooooool@
413ooooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo05kooooo2ol00003ooooo`;o00002oooool2o`0000[ooooo0_l000000ooooooo0000o`00
0004ooooo`;o00000_ooool3o`0000Cooooo0_l000000ooooooo0000o`00000Iooooo`?o00002Ooo
ool2o`0000Cooooo1?l00009ooooo`[o0000JOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo05oooooo3?l000000ooooooo0000
o`000002o`0000Cooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00006ooooo`;o0000
00?oooooo`000?l000001?ooool2o`000004ooooool0003o0000o`0000Cooooo0_l00004ooooo`;o
00000_ooool2o`0000?ooooo0_l0000;ooooo`;o000000Coooooo`000?l0003o00002?ooool4o`00
0003ooooool0003o000000?o00002Oooool:o`0006[ooooo00001_ooooook^k^oc8b<_l0003o<S8b
onk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`1Oooooo`co00000ooo
ool2o`0000Cooooo0_l000001?oooooo0000o`000?l00003ooooo`;o00004_ooool2o`0000Gooooo
0_l00004ooooo`;o00000_ooool2o`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l00000
0_ooool4o`0000[ooooo1?l000000ooooooo0000o`000003o`0000Gooooo0ol000000ooooooo0000
o`000008o`0006[ooooo000Looooo`03o`000?oooooooooo067ooooo1?l000000ooooooo0000o`00
0007o`0000cooooo0_l0000:ooooo`;o000000?oooooo`000?l000008?ooool3o`000003ooooool0
003o000000?ooooo0ol0000>ooooo`;o00002Oooool>o`0006[ooooo000Looooo`03o`000?oooooo
oooo067ooooo3_l0000<ooooo`;o00002_ooool2o`000003ooooool0003o000001Oooooo0_l00007
ooooo`;o00002Oooool2o`0000gooooo0_l00007ooooo`Co000000?oooooo`000?l000002Ol0001Z
ooooo`007?ooool00ol0003oooooooooo`1Rooooo`_o00000oooool2o`0000Oooooo0_l00005oooo
o`;o00003_ooool2o`0000Oooooo0_l00007ooooo`?o00004_ooool2o`0000cooooo0_l00005oooo
oa7o0000K?ooool001cooooo00?o0000ooooooooool0H_ooool=o`000003ooooool0003o000000Oo
oooo0ol00004ooooo`;o00003_ooool2o`0000Oooooo0_l00007ooooo`Co00003?ooool2o`0000Ko
oooo1?l00006ooooo`?o00001Oooool4o`000003ooooool0003o000000[o0000K?ooool001cooooo
00?o0000ooooooooool0Hoooool<o`0000_ooooo0_l00002ooooo`;o00002Oooool4o`0000Sooooo
0_l0000:ooooo`;o000000Coooooo`000?l0003ooooo0_l00009ooooo`?o00001Oooool4o`0000Ko
oooo0_l0000;ooooo`[o0000K_ooool001cooooo00?o0000ooooooooool0Hoooool=o`0000kooooo
0_l00009ooooo`Co00002?ooool2o`0000[ooooo0ol00003ooooo`;o00002?ooool4o`0000Sooooo
0_l0000;ooooo`;o00001?ooool;o`0006kooooo000Looooo`03o`000?oooooooooo06Gooooo3_l0
0004ooooo`?o00002?ooool2o`0000Oooooo1?l00004ooooo`?o00000oooool2o`0000Kooooo0ol0
00000ooooooo0000o`00000:ooooo`;o00001?ooool3o`0000?ooooo0_l00005ooooo`;o00001?oo
ool2o`0000Cooooo2ol0001^ooooo`007?ooool00ol0003oooooooooo`1UoooooaGo00002?ooool2
o`0000Wooooo0_l00004ooooo`?o00000oooool2o`0000[ooooo0_l00009ooooo`;o00001Oooool3
o`0000Cooooo0_l00004ooooo`;o00000_ooool2o`0000Cooooo3Ol0001^ooooo`007?ooool00ol0
003oooooooooo`1Woooooa3o00008?ooool2o`000003ooooool0003o000000Cooooo1?l0000<oooo
o`;o00001?ooool2o`000003ooooool0003o000000;ooooo2?l00003ooooo`;o00000oooool<o`00
073ooooo000Looooo`03o`000?oooooooooo06Sooooo2ol000001?oooooo0000o`000?l00005oooo
o`;o00002?ooool2o`0000cooooo0_l000001?oooooo0000o`000?ooool5o`000003ooooool0003o
000000;o00003?ooool2o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o000000?ooooo
o`000?l000000ol00003ooooo`;o00000_ooool=o`00073ooooo000Looooo`03o`000?oooooooooo
06[ooooo3Ol00005ooooo`Co00000_ooool2o`0000;ooooo0_l0000:ooooo`Co00001?ooool5o`00
00;ooooo0_l0000?ooooo`;o00002Oooool2o`0000Wooooo0ol000000ooooooo0000o`000006o`00
0004ooooool0003o0000o`00077ooooo000Looooo`;o0000J_ooool<o`0000Wooooo0_l00002oooo
o`;o00003_ooool4o`0000?ooooo0ol0000Fooooo`;o00002?ooool2o`0000Wooooo3?l000000ooo
oooo0000o`000002o`00077ooooo000Looooo`03o`000?oooooooooo06Wooooo3_l00007ooooo`;o
00003?ooool2o`0000_ooooo0_l00007ooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o
00002?ooool2o`000003ooooool0003o000000Wooooo4?l0001booooo`007?ooool00ol0003ooooo
ooooo`1Zooooo`ko00001_ooool2o`0000cooooo0_l00002ooooo`;o00004?ooool2o`0000;ooooo
0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000000Cooooo0ol0000=ooooo`ko0000
Loooool001cooooo00?o0000ooooooooool0K?ooool=o`0000?ooooo1?l00008ooooo`;o00000ooo
ool2o`000003ooooool0003o000000Go00002Oooool2o`0000Cooooo0_l00004ooooo`;o00000_oo
ool4o`0000Cooooo0ol00008ooooo`;o00000oooool=o`0007Cooooo000Looooo`03o`000?oooooo
oooo06gooooo3_l000000ooooooo0000o`00000:ooooo`;o00000oooool2o`000003ooooool0003o
000000Go00002Oooool3o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`0000cooooo0_l00003
ooooo`;o000000?oooooo`000?l000003Ol0001dooooo`007?ooool00ol0003oooooooooo`1^oooo
o`oo00003?ooool2o`0000Wooooo1Ol00008ooooo`;o00000_ooool2o`0000gooooo1?l00005oooo
o`?o00000_ooool2o`000003ooooool0003o000000co0000M_ooool001cooooo00?o0000oooooooo
ool0K_oooolAo`0000Sooooo1?l00009ooooo`Go00000_ooool2o`0000Cooooo0_l00002ooooo`;o
00000oooool2o`0000Sooooo1?l00005ooooo`;o00000ooooolAo`0007Kooooo000Looooo`03o`00
0?oooooooooo06oooooo4?l000000ooooooo0000o`000005ooooo`;o00001Oooool2o`0000_ooooo
0_l00005ooooo`;o00001_ooool2o`0000_ooooo0_l00009oooooa3o0000Moooool001cooooo00?o
0000ooooooooool0LOoooolAo`0000Oooooo0_l00003ooooo`;o00003Oooool2o`0000?ooooo0_l0
0008ooooo`;o00002Oooool4o`0000Kooooo3_l0001jooooo`007?ooool00ol0003oooooooooo`1b
oooooaCo00000oooool4o`000003ooooool0003o000000;o00002oooool2o`000003ooooool0003o
000000Kooooo0_l00002ooooo`Co00001Oooool7o`0000?ooooo4?l0001jooooo`007?ooool00ol0
003oooooooooo`1eoooooa;o00001?ooool3o`0000;ooooo1?l000000ooooooo0000o`000002o`00
00Oooooo0_l00006ooooo`;o00000oooool3o`0000Gooooo0_l000000ooooooo0000o`00000Co`00
07cooooo000Looooo`03o`000?oooooooooo07Gooooo6Ol00004ooooo`;o000000?oooooo`000?l0
00000_l0000;ooooo`;o00001oooool2o`000003ooooool0003o000000Oooooo4ol0001mooooo`00
7?ooool00ol0003oooooooooo`1hoooooaGo00000_ooool2o`0000;ooooo0ol0000=ooooo`?o0000
1Oooool7o`0000Cooooo5Ol0001nooooo`007?ooool00ol0003oooooooooo`1ioooooaSo00000_oo
ool3o`0000Oooooo0_l00004ooooo`;o00001_ooool2o`000003ooooool0003o000000?o00000_oo
oolFo`0007kooooo000Looooo`03o`000?oooooooooo07Wooooo7Ol00007ooooo`;o00001oooool2
o`0000?ooooo0_l00002oooooaWo0000POooool001cooooo00?o0000ooooooooool0O?oooolLo`00
0003ooooool0003o000000Wooooo4Ol000000ooooooo0000o`00000@o`00087ooooo000Looooo`;o
0000POoooolQo`000003ooooool0003o000002;o0000Poooool001cooooo00?o0000ooooooooool0
P?oooom4o`0008Gooooo000Looooo`03o`000?oooooooooo08Cooooo?ol00026ooooo`007?ooool0
0ol0003oooooooooo`26ooooocSo0000Roooool001cooooo00?o0000ooooooooool0Rooooolco`00
08_ooooo000Looooo`03o`000?oooooooooo08_ooooo<_l0002<ooooo`007?ooool00ol0003ooooo
ooooo`2@ooooob_o0000S_ooool001cooooo00?o0000ooooooooool0TOoooolUo`0009?ooooo000L
ooooo`03o`000?oooooooooo09Sooooo0_l000000ooooooo0000o`00000Do`0009Sooooo000Loooo
o`03o`000?oooooooooo09oooooo1Ol00003ooooo`;o0000X?ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<
ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?ooooooB_ooool00006oooooomgMgOo
V9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03
o`000?oooooooooo0?ooooooB_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool0
2Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooom:ooooo`00
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb
<S801_ooool3o`000?ooooooB_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
2Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom:ooooo`00
00?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@
41001_ooool00ol0003oooooooooo`3ooooood[ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMg
M`_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0?ooooooB_ooool0
0006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooo
ooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB_ooool001Cooooo00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o
0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Doooo
o`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`00
4_ooool00omEEEGoIVIVo`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo002]ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05Oooool01Oo^
k^ko<S8bo`000?l@413oc<c<09Sooooo002^ooooo`05o`000?ooooooooooooooool000002Oooool6
o`0000Wooooo00GoEEEEogMgMoooooooV9RHob4Q8@2Hooooo`00[_ooool01Ol0003ooooooooooooo
oooo000001Sooooo00Go0000ooooooooooooooooo`00002Hooooo`00[_ooool01Ol0003ooooooooo
oooooooo000000Wooooo1_l00009ooooo`05o`000?nHV9SooooooiRHV?lQ8B40V?ooool00:kooooo
00Go0000ohN7QoooooooZJVYo`00000Hooooo`05o`000?mEEEGo0000oa0@4?o<c<`0V?ooool00:go
oooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Fooooo`03oeEEEOn7QhOooooo09[o
oooo003;ooooo`03omgMgOl@413oV9RH09[ooooo003<ooooo`04olc<c?m4A4Co0000oa0@49Sooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -20 0 ]
[.5 1.0125 20 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.68256 .4116 Mdot
.64507 .34785 Mdot
.4096 .31822 Mdot
.40326 .68077 Mdot
.36935 .66493 Mdot
.42685 .30775 Mdot
.60919 .32376 Mdot
.57339 .29591 Mdot
.33096 .35808 Mdot
.38847 .67378 Mdot
.48153 .27991 Mdot
.65925 .64921 Mdot
.60123 .31893 Mdot
.46449 .70488 Mdot
.58923 .69256 Mdot
.71826 .52994 Mdot
.67715 .37629 Mdot
.36855 .66309 Mdot
.67354 .60811 Mdot
.33927 .3469 Mdot
.30572 .438 Mdot
.42522 .68768 Mdot
.66976 .35978 Mdot
.47619 .71301 Mdot
.67926 .60363 Mdot
.70343 .51943 Mdot
.68259 .41397 Mdot
.68963 .58991 Mdot
.6659 .63534 Mdot
.54718 .282 Mdot
.69979 .56307 Mdot
.51947 .72624 Mdot
.30561 .45917 Mdot
.70878 .43805 Mdot
.46042 .28824 Mdot
.50841 .27579 Mdot
.39226 .32883 Mdot
.52636 .28567 Mdot
.57144 .28851 Mdot
.4739 .29189 Mdot
.46929 .29017 Mdot
.70562 .52011 Mdot
.49705 .2728 Mdot
.63 .33483 Mdot
.50269 .71847 Mdot
.72613 .46911 Mdot
.30905 .42482 Mdot
.51007 .69926 Mdot
.68087 .40392 Mdot
.30535 .42915 Mdot
.57195 .70827 Mdot
.6237 .33562 Mdot
.29838 .50655 Mdot
.69016 .38373 Mdot
.58676 .31238 Mdot
.68163 .60259 Mdot
.37122 .32765 Mdot
.594 .70025 Mdot
.65142 .64281 Mdot
.71046 .44504 Mdot
.47501 .71673 Mdot
.31795 .58299 Mdot
.66613 .62797 Mdot
.37174 .31543 Mdot
.36277 .34224 Mdot
.52444 .301 Mdot
.67132 .35353 Mdot
.51963 .28607 Mdot
.47444 .70812 Mdot
.3504 .36379 Mdot
.58627 .69875 Mdot
.48073 .28033 Mdot
.7123 .48444 Mdot
.4062 .67915 Mdot
.66898 .39404 Mdot
.50053 .28262 Mdot
.37216 .67118 Mdot
.71151 .50542 Mdot
.29025 .44921 Mdot
.41694 .70028 Mdot
.44043 .69703 Mdot
.46349 .27276 Mdot
.627 .66102 Mdot
.70685 .52846 Mdot
.52729 .71753 Mdot
.51849 .27571 Mdot
.38922 .67098 Mdot
.70064 .55922 Mdot
.69725 .58111 Mdot
.66581 .64313 Mdot
.32411 .37904 Mdot
.65333 .34215 Mdot
.4089 .67729 Mdot
.53873 .72865 Mdot
.54971 .70725 Mdot
.53115 .71544 Mdot
.70085 .57662 Mdot
.29737 .4577 Mdot
.49344 .29171 Mdot
.3033 .48398 Mdot
.51096 .28285 Mdot
.29447 .53074 Mdot
.52044 .72795 Mdot
.40248 .30791 Mdot
.70028 .41691 Mdot
.29417 .46413 Mdot
.5005 .28679 Mdot
.40597 .67382 Mdot
.52025 .28105 Mdot
.65148 .34472 Mdot
.7034 .56072 Mdot
.33729 .6369 Mdot
.35929 .66524 Mdot
.68867 .42424 Mdot
.56851 .72302 Mdot
.39161 .67555 Mdot
.44333 .69567 Mdot
.66771 .34941 Mdot
.3378 .35329 Mdot
.31242 .39556 Mdot
.65541 .36363 Mdot
.48592 .29228 Mdot
.68188 .38823 Mdot
.30318 .59046 Mdot
.34331 .35292 Mdot
.29415 .47982 Mdot
.28141 .50733 Mdot
.49987 .72136 Mdot
.53457 .71408 Mdot
.29162 .5812 Mdot
.40714 .30471 Mdot
.65565 .36494 Mdot
.59208 .31115 Mdot
.54276 .72923 Mdot
.72515 .48308 Mdot
.58502 .31224 Mdot
.33838 .62396 Mdot
.3437 .64954 Mdot
.71513 .47557 Mdot
.56753 .72017 Mdot
.54415 .29843 Mdot
.60576 .30924 Mdot
.58934 .70373 Mdot
.72422 .47208 Mdot
.35019 .63538 Mdot
.60591 .30903 Mdot
.301 .53651 Mdot
.70789 .55798 Mdot
.63797 .67922 Mdot
.4828 .26884 Mdot
.57063 .70711 Mdot
.31902 .41319 Mdot
.31067 .57827 Mdot
.57478 .30506 Mdot
.40273 .68284 Mdot
.67571 .38325 Mdot
.71754 .46561 Mdot
.63185 .67164 Mdot
.29933 .45931 Mdot
.60539 .70167 Mdot
.29403 .5507 Mdot
.28112 .49102 Mdot
.44695 .69391 Mdot
.71676 .45098 Mdot
.70193 .40786 Mdot
.58816 .69902 Mdot
.35908 .34682 Mdot
.37643 .6752 Mdot
.47799 .27822 Mdot
.52071 .71167 Mdot
.53349 .70586 Mdot
.63906 .66907 Mdot
.61624 .32083 Mdot
.44057 .28641 Mdot
.3159 .40321 Mdot
.52722 .29817 Mdot
.46233 .28128 Mdot
.39001 .30781 Mdot
.65361 .64905 Mdot
.32872 .63763 Mdot
.28526 .54919 Mdot
.58593 .69999 Mdot
.48496 .71226 Mdot
.66096 .64961 Mdot
.27568 .51001 Mdot
.27533 .52188 Mdot
.69853 .42748 Mdot
.48557 .27213 Mdot
.43771 .70456 Mdot
.66202 .62511 Mdot
.55568 .71164 Mdot
.54543 .29516 Mdot
.58644 .30488 Mdot
.39839 .29834 Mdot
.34421 .34063 Mdot
.3279 .39339 Mdot
.60339 .67866 Mdot
.59511 .68845 Mdot
.43836 .70132 Mdot
.29705 .49089 Mdot
.69611 .59634 Mdot
.31205 .57973 Mdot
.67509 .37611 Mdot
.45895 .27465 Mdot
.63038 .68559 Mdot
.67807 .5922 Mdot
.31631 .38017 Mdot
.29826 .41677 Mdot
.28242 .55637 Mdot
.314 .60611 Mdot
.57522 .70336 Mdot
.69156 .41799 Mdot
.57664 .70687 Mdot
.30498 .4624 Mdot
.3559 .6649 Mdot
.65624 .35939 Mdot
.51865 .69946 Mdot
.60112 .32169 Mdot
.46177 .29904 Mdot
.38687 .66818 Mdot
.40179 .67086 Mdot
.71432 .50072 Mdot
.54033 .72694 Mdot
.66981 .617 Mdot
.69545 .57421 Mdot
.33318 .38473 Mdot
.5169 .29082 Mdot
.54912 .28055 Mdot
.3051 .43248 Mdot
.72009 .4816 Mdot
.63392 .33974 Mdot
.39802 .31423 Mdot
.31076 .43034 Mdot
.49077 .27579 Mdot
.32472 .60945 Mdot
.40446 .30986 Mdot
.35237 .63684 Mdot
.6592 .63695 Mdot
.42421 .29653 Mdot
.33693 .62805 Mdot
.59996 .68942 Mdot
.28385 .51805 Mdot
.333 .6483 Mdot
.6116 .32726 Mdot
.63578 .33066 Mdot
.59895 .69695 Mdot
.29213 .52708 Mdot
.30632 .46662 Mdot
.6499 .65108 Mdot
.27931 .50968 Mdot
.28499 .4932 Mdot
.64947 .65416 Mdot
.3667 .6584 Mdot
.45038 .28174 Mdot
.70021 .56298 Mdot
.67865 .38053 Mdot
.48199 .71233 Mdot
.5036 .29928 Mdot
.58136 .31006 Mdot
.42815 .70495 Mdot
.5208 .27767 Mdot
.61329 .33015 Mdot
.44693 .69529 Mdot
.55959 .28776 Mdot
.71817 .50835 Mdot
.63084 .68589 Mdot
.7098 .48123 Mdot
.46263 .70416 Mdot
.56336 .2876 Mdot
.3053 .43118 Mdot
.71163 .51202 Mdot
.41592 .68401 Mdot
.41546 .69061 Mdot
.29755 .49603 Mdot
.70056 .5663 Mdot
.54574 .29034 Mdot
.65915 .64864 Mdot
.44178 .29202 Mdot
.61255 .67842 Mdot
.30806 .5592 Mdot
.30356 .57803 Mdot
.72296 .46879 Mdot
.27842 .49809 Mdot
.4139 .30992 Mdot
.55182 .70582 Mdot
.55762 .70131 Mdot
.51783 .72069 Mdot
.28631 .50054 Mdot
.62526 .66247 Mdot
.58553 .31719 Mdot
.70423 .57654 Mdot
.29135 .57862 Mdot
.37806 .32671 Mdot
.30005 .51101 Mdot
.52981 .71683 Mdot
.66415 .35323 Mdot
.70083 .5544 Mdot
.43649 .29248 Mdot
.66439 .3566 Mdot
.52783 .70115 Mdot
.52024 .28708 Mdot
.31612 .57253 Mdot
.54021 .28474 Mdot
.68007 .59532 Mdot
.61713 .67729 Mdot
.34738 .36604 Mdot
.71816 .50237 Mdot
.571 .30021 Mdot
.71121 .48362 Mdot
.59753 .70437 Mdot
.59623 .70845 Mdot
.72008 .46317 Mdot
.3048 .56971 Mdot
.30152 .42283 Mdot
.48703 .27857 Mdot
.29317 .48872 Mdot
.34278 .36583 Mdot
.68308 .40454 Mdot
.41143 .30581 Mdot
.58376 .71778 Mdot
.4652 .29914 Mdot
.69886 .55726 Mdot
.34833 .36273 Mdot
.62847 .67582 Mdot
.50515 .72077 Mdot
.38242 .30759 Mdot
.30394 .45157 Mdot
.58514 .70268 Mdot
.72302 .49505 Mdot
.45575 .69555 Mdot
.38429 .66858 Mdot
.60162 .68176 Mdot
.37748 .3263 Mdot
.57137 .71905 Mdot
.68861 .58475 Mdot
.68012 .59861 Mdot
.67112 .37258 Mdot
.29178 .51144 Mdot
.346 .6355 Mdot
.33918 .65105 Mdot
.30135 .54926 Mdot
.66086 .65162 Mdot
.58369 .714 Mdot
.72107 .4754 Mdot
.31173 .41675 Mdot
.63274 .32587 Mdot
.30454 .46181 Mdot
.57375 .29539 Mdot
.44475 .28571 Mdot
.38602 .66668 Mdot
.37449 .66565 Mdot
.70308 .54896 Mdot
.67702 .39981 Mdot
.71335 .48863 Mdot
.57055 .2989 Mdot
.68811 .60935 Mdot
.41974 .70184 Mdot
.43044 .70588 Mdot
.5817 .29443 Mdot
.30133 .46744 Mdot
.63935 .65255 Mdot
.55617 .69945 Mdot
.6267 .33041 Mdot
.50772 .71598 Mdot
.70521 .44938 Mdot
.46571 .69819 Mdot
.52512 .7272 Mdot
.48057 .70353 Mdot
.72349 .48723 Mdot
.7013 .54948 Mdot
.5575 .70004 Mdot
.31006 .39098 Mdot
.63369 .68435 Mdot
.31513 .62191 Mdot
.40852 .67973 Mdot
.57492 .7029 Mdot
.34327 .62547 Mdot
.68889 .42201 Mdot
.52093 .7059 Mdot
.48638 .26971 Mdot
.41605 .68255 Mdot
.47965 .27703 Mdot
.63117 .66563 Mdot
.53678 .72334 Mdot
.69064 .58414 Mdot
.6695 .35886 Mdot
.57846 .29074 Mdot
.46916 .28499 Mdot
.29046 .57178 Mdot
.57979 .30908 Mdot
.5221 .71538 Mdot
.62812 .66683 Mdot
.68909 .42438 Mdot
.28391 .51413 Mdot
.65185 .33993 Mdot
.38848 .68162 Mdot
.60788 .31906 Mdot
.296 .52067 Mdot
.67197 .6244 Mdot
.60229 .3104 Mdot
.47205 .27327 Mdot
.70408 .55927 Mdot
.3016 .46767 Mdot
.68458 .41157 Mdot
.34746 .36453 Mdot
.29129 .47571 Mdot
.58118 .30873 Mdot
.49762 .71629 Mdot
.70594 .56748 Mdot
.56323 .29413 Mdot
.70207 .47199 Mdot
.71054 .55224 Mdot
.41378 .67992 Mdot
.70123 .52462 Mdot
.65128 .33553 Mdot
.61579 .696 Mdot
.44837 .71089 Mdot
.40338 .31765 Mdot
.28723 .49693 Mdot
.28837 .50104 Mdot
.28774 .47083 Mdot
.47181 .29813 Mdot
.30768 .41035 Mdot
.5134 .29333 Mdot
.47173 .70559 Mdot
.52025 .29839 Mdot
.29254 .52916 Mdot
.40614 .31696 Mdot
.48561 .71058 Mdot
.69967 .59648 Mdot
.60682 .3086 Mdot
.33726 .36708 Mdot
.39038 .66598 Mdot
.67884 .38795 Mdot
.62029 .32862 Mdot
.59477 .68936 Mdot
.34004 .37823 Mdot
.31724 .58008 Mdot
.56193 .71867 Mdot
.60165 .30788 Mdot
.70137 .45732 Mdot
.59907 .30568 Mdot
.55922 .70385 Mdot
.50674 .7079 Mdot
.65681 .37167 Mdot
.31182 .61245 Mdot
.65791 .64873 Mdot
.47628 .7139 Mdot
.29867 .43979 Mdot
.63646 .3351 Mdot
.31007 .60859 Mdot
.67323 .62831 Mdot
.28206 .52704 Mdot
.37858 .67546 Mdot
.4342 .69844 Mdot
.6465 .66052 Mdot
.29887 .57575 Mdot
.55207 .2886 Mdot
.32443 .63756 Mdot
.31712 .38094 Mdot
.65861 .35605 Mdot
.51589 .29331 Mdot
.29748 .45327 Mdot
.48249 .2811 Mdot
.64912 .66544 Mdot
.29093 .55024 Mdot
.63209 .34084 Mdot
.37172 .65489 Mdot
.28408 .50221 Mdot
.36947 .33053 Mdot
.59886 .70206 Mdot
.65252 .65365 Mdot
.41285 .67895 Mdot
.34496 .63477 Mdot
.64104 .33536 Mdot
.46951 .27708 Mdot
.57127 .28637 Mdot
.44569 .69204 Mdot
.72285 .46819 Mdot
.69734 .45474 Mdot
.30214 .49162 Mdot
.33033 .62897 Mdot
.32643 .61367 Mdot
.44017 .68819 Mdot
.65632 .63721 Mdot
.72266 .48363 Mdot
.41497 .68343 Mdot
.45204 .69537 Mdot
.32371 .38939 Mdot
.69797 .52627 Mdot
.41669 .29783 Mdot
.67019 .60661 Mdot
.55262 .71872 Mdot
.52142 .28976 Mdot
.59416 .31981 Mdot
.29117 .5049 Mdot
.54916 .28042 Mdot
.31672 .39953 Mdot
.28821 .50143 Mdot
.41676 .68487 Mdot
.68302 .4202 Mdot
.41249 .68145 Mdot
.41439 .68168 Mdot
.4831 .70676 Mdot
.58171 .71422 Mdot
.30205 .40637 Mdot
.32849 .63324 Mdot
.66601 .6327 Mdot
.40155 .30093 Mdot
.31798 .377 Mdot
.55502 .70796 Mdot
.42529 .6926 Mdot
.4384 .69159 Mdot
.70036 .51223 Mdot
.70846 .56645 Mdot
.59141 .30326 Mdot
.65577 .37024 Mdot
.40756 .68945 Mdot
.3168 .41182 Mdot
.51356 .70558 Mdot
.71547 .46064 Mdot
.46242 .291 Mdot
.55053 .29593 Mdot
.28005 .51673 Mdot
.30568 .4797 Mdot
.28559 .49613 Mdot
.3043 .44669 Mdot
.50091 .27359 Mdot
.40698 .31703 Mdot
.30859 .55257 Mdot
.5967 .70909 Mdot
.44743 .70916 Mdot
.51748 .70848 Mdot
.32838 .37962 Mdot
.30103 .52471 Mdot
.58561 .71039 Mdot
.7204 .54391 Mdot
.45543 .29987 Mdot
.29073 .46741 Mdot
.70053 .54285 Mdot
.65556 .34998 Mdot
.34037 .37473 Mdot
.52468 .28478 Mdot
.33949 .63127 Mdot
.30954 .42737 Mdot
.64635 .33685 Mdot
.66155 .63058 Mdot
.45099 .30183 Mdot
.62912 .66476 Mdot
.70358 .58784 Mdot
.4234 .30265 Mdot
.70095 .58226 Mdot
.6737 .35751 Mdot
.28292 .51173 Mdot
.62161 .67249 Mdot
.64662 .65379 Mdot
.38551 .30355 Mdot
.4036 .67869 Mdot
.31852 .38587 Mdot
.37454 .32854 Mdot
.28781 .52621 Mdot
.37812 .326 Mdot
.57898 .31288 Mdot
.38715 .31321 Mdot
.70035 .49021 Mdot
.50384 .72453 Mdot
.69434 .39613 Mdot
.62448 .68179 Mdot
.40453 .68863 Mdot
.61988 .33439 Mdot
.51063 .29866 Mdot
.46484 .71314 Mdot
.36593 .66118 Mdot
.37641 .32916 Mdot
.31475 .40794 Mdot
.70063 .57972 Mdot
.33738 .3711 Mdot
.66966 .35866 Mdot
.51249 .28669 Mdot
.51138 .2987 Mdot
.28727 .4873 Mdot
.72565 .48033 Mdot
.53249 .28714 Mdot
.48717 .29283 Mdot
.31566 .57148 Mdot
.61445 .69468 Mdot
.7039 .42794 Mdot
.63895 .65307 Mdot
.36102 .6508 Mdot
.4189 .68392 Mdot
.40931 .30016 Mdot
.32428 .3958 Mdot
.56473 .69699 Mdot
.39926 .31476 Mdot
.29177 .49761 Mdot
.70106 .4467 Mdot
.67803 .60641 Mdot
.6456 .34569 Mdot
.54319 .72744 Mdot
.51777 .29365 Mdot
.65937 .35128 Mdot
.284 .47186 Mdot
.47205 .71932 Mdot
.7181 .4548 Mdot
.68204 .62186 Mdot
.41572 .6811 Mdot
.35098 .34753 Mdot
.34547 .62854 Mdot
.31893 .41702 Mdot
.32411 .37751 Mdot
.31523 .59066 Mdot
.63599 .33857 Mdot
.34499 .35093 Mdot
.31921 .60616 Mdot
.30614 .59569 Mdot
.28775 .46914 Mdot
.32194 .62482 Mdot
.52664 .71652 Mdot
.56864 .3013 Mdot
.64168 .34253 Mdot
.48707 .70223 Mdot
.38929 .67546 Mdot
.69257 .38828 Mdot
.29904 .49165 Mdot
.41806 .68076 Mdot
.60815 .69731 Mdot
.71535 .46265 Mdot
.45413 .2773 Mdot
.36407 .32513 Mdot
.29902 .47757 Mdot
.6461 .34421 Mdot
.46345 .27262 Mdot
.35953 .34325 Mdot
.32408 .60355 Mdot
.55501 .29385 Mdot
.68132 .41873 Mdot
.29823 .50318 Mdot
.6105 .32565 Mdot
.32965 .37217 Mdot
.56945 .70819 Mdot
.71806 .54298 Mdot
.44254 .30749 Mdot
.57177 .70792 Mdot
.69235 .56685 Mdot
.33075 .3903 Mdot
.44339 .28464 Mdot
.65083 .34351 Mdot
.57201 .29111 Mdot
.32983 .62233 Mdot
.71107 .48776 Mdot
.65105 .33971 Mdot
.5933 .31941 Mdot
.69306 .38523 Mdot
.62053 .66683 Mdot
.49913 .28328 Mdot
.64053 .64931 Mdot
.5796 .70502 Mdot
.29607 .50967 Mdot
.32947 .63684 Mdot
.51607 .28939 Mdot
.70368 .52012 Mdot
.61627 .31502 Mdot
.53924 .71445 Mdot
.71066 .5611 Mdot
.34235 .64191 Mdot
.69488 .40304 Mdot
.43475 .285 Mdot
.59485 .30597 Mdot
.3007 .43617 Mdot
.36405 .65975 Mdot
.52235 .72223 Mdot
.35736 .35292 Mdot
.51349 .71135 Mdot
.62734 .33901 Mdot
.69179 .56708 Mdot
.66113 .36247 Mdot
.49409 .28063 Mdot
.70858 .54116 Mdot
.66397 .64079 Mdot
.45628 .71174 Mdot
.33236 .3849 Mdot
.69798 .43436 Mdot
.30277 .5768 Mdot
.38081 .66193 Mdot
.4756 .72077 Mdot
.30734 .47003 Mdot
.50514 .72352 Mdot
.45144 .28297 Mdot
.30102 .45866 Mdot
.45132 .29868 Mdot
.28254 .50457 Mdot
.29354 .49478 Mdot
.68987 .40832 Mdot
.32683 .39614 Mdot
.30643 .47669 Mdot
.42515 .70391 Mdot
.41588 .67665 Mdot
.5812 .29128 Mdot
.62081 .66868 Mdot
.64353 .65316 Mdot
.42196 .29279 Mdot
.31616 .57057 Mdot
.53408 .70372 Mdot
.71306 .5184 Mdot
.34641 .64956 Mdot
.29522 .55163 Mdot
.66633 .36029 Mdot
.53201 .71716 Mdot
.3233 .38938 Mdot
.28501 .51461 Mdot
.29734 .54095 Mdot
.34022 .63522 Mdot
.62136 .32728 Mdot
.70928 .46182 Mdot
.37297 .32934 Mdot
.71392 .54131 Mdot
.38178 .67429 Mdot
.33548 .37762 Mdot
.29521 .51129 Mdot
.28945 .56305 Mdot
.72236 .46863 Mdot
.70133 .48549 Mdot
.29993 .44927 Mdot
.40649 .29828 Mdot
.51558 .27668 Mdot
.48644 .28409 Mdot
.62967 .67235 Mdot
.54354 .28521 Mdot
.65169 .34394 Mdot
.54936 .71619 Mdot
.32452 .61131 Mdot
.60427 .31284 Mdot
.28641 .48714 Mdot
.64818 .34364 Mdot
.70409 .4939 Mdot
.48064 .71655 Mdot
.4274 .68986 Mdot
.30672 .42919 Mdot
.51563 .72523 Mdot
.61963 .32346 Mdot
.342 .62762 Mdot
.39246 .32398 Mdot
.70336 .57443 Mdot
.67621 .38302 Mdot
.32515 .40343 Mdot
.67227 .63404 Mdot
.37438 .31656 Mdot
.64836 .35513 Mdot
.35042 .64789 Mdot
.32738 .6317 Mdot
.54925 .71792 Mdot
.32382 .40621 Mdot
.61524 .32827 Mdot
.72468 .48008 Mdot
.63528 .33595 Mdot
.66084 .6386 Mdot
.42446 .69118 Mdot
.6877 .5985 Mdot
.4752 .27592 Mdot
.52477 .71435 Mdot
.34303 .63621 Mdot
.68927 .389 Mdot
.50008 .71853 Mdot
.35864 .66012 Mdot
.30314 .58026 Mdot
.28672 .56212 Mdot
.36344 .32045 Mdot
.35459 .6507 Mdot
.35814 .65385 Mdot
.35401 .6605 Mdot
.44613 .28557 Mdot
.60789 .68593 Mdot
.37387 .66323 Mdot
.40738 .68304 Mdot
.59442 .70308 Mdot
.71663 .54759 Mdot
.52519 .29772 Mdot
.34761 .36702 Mdot
.56639 .70409 Mdot
.41519 .69022 Mdot
.68662 .38124 Mdot
.71837 .53121 Mdot
.53966 .70244 Mdot
.66822 .3653 Mdot
.70653 .42751 Mdot
.35092 .33445 Mdot
.55583 .30259 Mdot
.35866 .35448 Mdot
.68132 .62038 Mdot
.68934 .61186 Mdot
.69315 .40648 Mdot
.56392 .2994 Mdot
.6817 .6191 Mdot
.62398 .33117 Mdot
.68283 .37515 Mdot
.71859 .5472 Mdot
.70144 .47623 Mdot
.31922 .58358 Mdot
.54556 .70328 Mdot
.60001 .32427 Mdot
.56858 .70376 Mdot
.58473 .3147 Mdot
.38688 .67252 Mdot
.68334 .61643 Mdot
.4091 .6884 Mdot
.47606 .70659 Mdot
.27513 .50673 Mdot
.42862 .69235 Mdot
.29152 .44782 Mdot
.67351 .38257 Mdot
.37745 .67087 Mdot
.66744 .623 Mdot
.58695 .70304 Mdot
.43002 .68705 Mdot
.69244 .38707 Mdot
.44958 .69986 Mdot
.35145 .35814 Mdot
.68618 .61793 Mdot
.56736 .70291 Mdot
.58376 .30415 Mdot
.47833 .28613 Mdot
.68854 .42495 Mdot
.29088 .55465 Mdot
.69166 .39204 Mdot
.43786 .68948 Mdot
.35848 .33554 Mdot
.30168 .54628 Mdot
.35415 .64585 Mdot
.64718 .35391 Mdot
.37674 .66122 Mdot
.49515 .27279 Mdot
.33487 .3625 Mdot
.70373 .55743 Mdot
.43265 .29576 Mdot
.38283 .30859 Mdot
.63402 .32983 Mdot
.3299 .63654 Mdot
.50759 .70281 Mdot
.70949 .44286 Mdot
.71684 .42986 Mdot
.65988 .64003 Mdot
.34815 .34363 Mdot
.29932 .57652 Mdot
.69376 .55869 Mdot
.3263 .5957 Mdot
.31569 .59883 Mdot
.59963 .32177 Mdot
.35744 .33418 Mdot
.29665 .48123 Mdot
.32072 .60737 Mdot
.34962 .33484 Mdot
.29789 .45332 Mdot
.3022 .43032 Mdot
.72236 .47685 Mdot
.58939 .71437 Mdot
.72105 .45535 Mdot
.55813 .283 Mdot
.31867 .40688 Mdot
.71933 .49005 Mdot
.71401 .51797 Mdot
.29548 .49429 Mdot
.35878 .34853 Mdot
.70042 .42981 Mdot
.60729 .69565 Mdot
.28136 .54461 Mdot
.48662 .71945 Mdot
.37287 .67354 Mdot
.4178 .67836 Mdot
.3299 .39488 Mdot
.59095 .30132 Mdot
.39541 .31982 Mdot
.60337 .32435 Mdot
.51886 .72675 Mdot
.45979 .71726 Mdot
.4155 .68579 Mdot
.63255 .66459 Mdot
.69102 .40576 Mdot
.70673 .44184 Mdot
.36935 .32454 Mdot
.38808 .32284 Mdot
.68067 .61109 Mdot
.68182 .39336 Mdot
.30167 .56217 Mdot
.66197 .63431 Mdot
.45164 .70187 Mdot
.67311 .3808 Mdot
.71558 .55443 Mdot
.54997 .2998 Mdot
.6277 .66949 Mdot
.68564 .38803 Mdot
.30957 .40656 Mdot
.4669 .70418 Mdot
.30444 .48605 Mdot
.29321 .58247 Mdot
.64242 .67022 Mdot
.36761 .66144 Mdot
.65613 .35673 Mdot
.29876 .51898 Mdot
.6742 .38711 Mdot
.46667 .29835 Mdot
.5512 .30147 Mdot
.66629 .36693 Mdot
.44786 .69783 Mdot
.36913 .34542 Mdot
.57208 .30462 Mdot
.47226 .70047 Mdot
.49394 .28379 Mdot
.71547 .48809 Mdot
.66366 .37499 Mdot
.29786 .45334 Mdot
.70358 .57817 Mdot
.61268 .32281 Mdot
.435 .70449 Mdot
.70119 .47282 Mdot
.707 .54443 Mdot
.35841 .64638 Mdot
.49898 .7051 Mdot
.61286 .70048 Mdot
.314 .39356 Mdot
.55549 .71064 Mdot
.45889 .28314 Mdot
.49281 .27376 Mdot
.47444 .27431 Mdot
.68894 .41512 Mdot
.27731 .49203 Mdot
.70516 .47207 Mdot
.29072 .49838 Mdot
.36633 .3434 Mdot
.47561 .70159 Mdot
.30652 .44404 Mdot
.51379 .29087 Mdot
.31574 .61591 Mdot
.66229 .64761 Mdot
.42652 .31506 Mdot
.28102 .55583 Mdot
.60296 .31345 Mdot
.69882 .47524 Mdot
.662 .35901 Mdot
.30316 .42408 Mdot
.47505 .70429 Mdot
.42395 .6883 Mdot
.50698 .29656 Mdot
.32596 .40319 Mdot
.31578 .59316 Mdot
.30314 .45259 Mdot
.50974 .2925 Mdot
.62375 .67 Mdot
.71376 .49799 Mdot
.5703 .70304 Mdot
.62462 .667 Mdot
.44942 .2857 Mdot
.71408 .42921 Mdot
.31394 .58718 Mdot
.5375 .72534 Mdot
.65596 .35821 Mdot
.59197 .31195 Mdot
.3088 .61158 Mdot
.66785 .61523 Mdot
.43811 .70346 Mdot
.60542 .6924 Mdot
.64403 .66128 Mdot
.69839 .5638 Mdot
.27839 .50702 Mdot
.59723 .69538 Mdot
.67677 .61467 Mdot
.71323 .53947 Mdot
.51532 .7072 Mdot
.52709 .70718 Mdot
.67059 .37904 Mdot
.60239 .68245 Mdot
.40534 .30374 Mdot
.69038 .59649 Mdot
.32222 .40721 Mdot
.69594 .57054 Mdot
.61548 .67815 Mdot
.71673 .43547 Mdot
.641 .67153 Mdot
.69763 .4395 Mdot
.68454 .4044 Mdot
.55531 .28232 Mdot
.69145 .56963 Mdot
.37452 .31615 Mdot
.2979 .56235 Mdot
.34222 .37048 Mdot
.67097 .38115 Mdot
.34561 .34201 Mdot
.52632 .30047 Mdot
.44179 .30812 Mdot
.44842 .29705 Mdot
.59528 .30372 Mdot
.6357 .32832 Mdot
.6757 .62998 Mdot
.60506 .31186 Mdot
.29979 .52496 Mdot
.32309 .60493 Mdot
.71214 .42314 Mdot
.30999 .44662 Mdot
.38875 .66354 Mdot
.61139 .31117 Mdot
.39914 .3257 Mdot
.6172 .68881 Mdot
.67537 .39922 Mdot
.34531 .65367 Mdot
.66506 .36812 Mdot
.32095 .41615 Mdot
.31204 .57733 Mdot
.52551 .72169 Mdot
.31525 .41795 Mdot
.45547 .2825 Mdot
.50877 .70351 Mdot
.71172 .43451 Mdot
.34243 .37074 Mdot
.58454 .31673 Mdot
.51219 .27452 Mdot
.30299 .47909 Mdot
.68192 .38091 Mdot
.70353 .46948 Mdot
.28953 .50518 Mdot
.59179 .31054 Mdot
.69939 .44339 Mdot
.59338 .70849 Mdot
.53521 .27733 Mdot
.49598 .70106 Mdot
.56655 .72047 Mdot
.30351 .53744 Mdot
.28289 .4819 Mdot
.71987 .53203 Mdot
.3651 .34121 Mdot
.69224 .59749 Mdot
.53988 .72628 Mdot
.46541 .70103 Mdot
.44764 .70403 Mdot
.59925 .69381 Mdot
.31712 .39596 Mdot
.69414 .42494 Mdot
.28579 .55546 Mdot
.2974 .50148 Mdot
.72161 .52221 Mdot
.30547 .43398 Mdot
.31738 .61323 Mdot
.2983 .43394 Mdot
.47807 .72041 Mdot
.4405 .69647 Mdot
.7062 .50411 Mdot
.57473 .72075 Mdot
.28131 .50136 Mdot
.45173 .70666 Mdot
.67064 .63954 Mdot
.58098 .30498 Mdot
.61632 .69831 Mdot
.44835 .69324 Mdot
.54473 .29591 Mdot
.58622 .30689 Mdot
.32913 .38578 Mdot
.31084 .43579 Mdot
.37819 .30966 Mdot
.31994 .59096 Mdot
.57194 .70097 Mdot
.54544 .71771 Mdot
.61761 .675 Mdot
.32098 .58837 Mdot
.69121 .58048 Mdot
.56101 .72662 Mdot
.43698 .68568 Mdot
.31551 .60091 Mdot
.54901 .28566 Mdot
.67143 .37582 Mdot
.56808 .71943 Mdot
.29661 .50169 Mdot
.70942 .54475 Mdot
.36271 .66362 Mdot
.67328 .38673 Mdot
.7172 .45067 Mdot
.6498 .35707 Mdot
.59695 .30924 Mdot
.33854 .38108 Mdot
.31211 .57671 Mdot
.66463 .36713 Mdot
.33631 .35766 Mdot
.51594 .28713 Mdot
.63138 .67303 Mdot
.56648 .28576 Mdot
.6336 .32875 Mdot
.68845 .40178 Mdot
.67575 .40428 Mdot
.68751 .59727 Mdot
.60229 .69285 Mdot
.29129 .49343 Mdot
.51106 .2936 Mdot
.37326 .33683 Mdot
.53908 .7164 Mdot
.71477 .44464 Mdot
.63475 .68188 Mdot
.52427 .7229 Mdot
.41992 .67918 Mdot
.39928 .67046 Mdot
.27916 .54264 Mdot
.39854 .67912 Mdot
.40561 .68056 Mdot
.63073 .34075 Mdot
.33294 .38079 Mdot
.45113 .71502 Mdot
.28731 .56153 Mdot
.37005 .65919 Mdot
.34225 .6529 Mdot
.55874 .71811 Mdot
.68628 .60876 Mdot
.67251 .37447 Mdot
.41738 .29478 Mdot
.35363 .33398 Mdot
.34348 .63352 Mdot
.57354 .29464 Mdot
.64261 .32986 Mdot
.32157 .3844 Mdot
.31078 .57294 Mdot
.48691 .70613 Mdot
.63449 .66345 Mdot
.64512 .66848 Mdot
.64869 .65903 Mdot
.48076 .70492 Mdot
.28555 .48183 Mdot
.44415 .2926 Mdot
.62262 .67939 Mdot
.72474 .46591 Mdot
.36333 .65966 Mdot
.32994 .60783 Mdot
.70123 .43436 Mdot
.5354 .72754 Mdot
.60591 .32816 Mdot
.65161 .64051 Mdot
.54652 .29097 Mdot
.69331 .39912 Mdot
.38083 .67214 Mdot
.5157 .70562 Mdot
.53903 .70606 Mdot
.38923 .6705 Mdot
.70039 .41811 Mdot
.70283 .44736 Mdot
.70411 .51865 Mdot
.57799 .30338 Mdot
.55763 .70643 Mdot
.46883 .2884 Mdot
.28121 .50277 Mdot
.65764 .35142 Mdot
.5936 .68468 Mdot
.38949 .32212 Mdot
.71808 .53548 Mdot
.32479 .63492 Mdot
.65093 .64551 Mdot
.28946 .54589 Mdot
.60376 .7058 Mdot
.40907 .31593 Mdot
.71596 .49619 Mdot
.71894 .53908 Mdot
.30465 .4013 Mdot
.58699 .6982 Mdot
.29867 .59392 Mdot
.31177 .43791 Mdot
.31788 .58278 Mdot
.53401 .70522 Mdot
.33029 .64238 Mdot
.61061 .32045 Mdot
.45187 .71487 Mdot
.57979 .70115 Mdot
.42272 .68403 Mdot
.52679 .71238 Mdot
.57829 .30601 Mdot
.67764 .5956 Mdot
.29915 .55473 Mdot
.31633 .4278 Mdot
.69639 .56877 Mdot
.31818 .62305 Mdot
.48646 .28523 Mdot
.32924 .38429 Mdot
.2988 .46623 Mdot
.31898 .57974 Mdot
.52173 .70357 Mdot
.46263 .70886 Mdot
.27928 .49628 Mdot
.52718 .71663 Mdot
.688 .5944 Mdot
.43331 .29798 Mdot
.69562 .56437 Mdot
.35303 .65458 Mdot
.33424 .64306 Mdot
.56888 .3011 Mdot
.66456 .36578 Mdot
.33826 .62432 Mdot
.40392 .31959 Mdot
.57325 .71383 Mdot
.508 .70636 Mdot
.70063 .48638 Mdot
.50039 .72035 Mdot
.35363 .65515 Mdot
.52469 .72116 Mdot
.69713 .53325 Mdot
.69502 .39314 Mdot
.43681 .70277 Mdot
.69764 .57949 Mdot
.68867 .40933 Mdot
.32178 .60562 Mdot
.57803 .29341 Mdot
.57263 .69682 Mdot
.61641 .3212 Mdot
.70287 .52041 Mdot
.30357 .49757 Mdot
.63897 .33823 Mdot
.30394 .49675 Mdot
.71388 .52462 Mdot
.46385 .70226 Mdot
.70012 .47836 Mdot
.30334 .59767 Mdot
.36831 .32396 Mdot
.37452 .33937 Mdot
.28499 .52086 Mdot
.65598 .35373 Mdot
.29124 .50884 Mdot
.33323 .62118 Mdot
.43317 .28859 Mdot
.68386 .40656 Mdot
.45317 .29867 Mdot
.4036 .3238 Mdot
.50178 .2975 Mdot
.4166 .67912 Mdot
.58594 .70069 Mdot
.44418 .30367 Mdot
.53458 .28192 Mdot
.68424 .38046 Mdot
.42283 .68823 Mdot
.30087 .46018 Mdot
.41398 .30124 Mdot
.39762 .29651 Mdot
.70848 .49743 Mdot
.71999 .54079 Mdot
.47167 .70484 Mdot
.48557 .27446 Mdot
.61789 .69631 Mdot
.69876 .57988 Mdot
.32387 .59863 Mdot
.52355 .72763 Mdot
.59453 .70603 Mdot
.47661 .28012 Mdot
.30502 .4708 Mdot
.65023 .65758 Mdot
.32416 .37887 Mdot
.60795 .69366 Mdot
.37729 .66356 Mdot
.27959 .4943 Mdot
.49095 .70725 Mdot
.29968 .5376 Mdot
.64777 .35073 Mdot
.42605 .68736 Mdot
.51951 .28861 Mdot
.37691 .31572 Mdot
.47685 .70537 Mdot
.31269 .42647 Mdot
.49805 .27962 Mdot
.29022 .54267 Mdot
.31494 .59161 Mdot
.71164 .54982 Mdot
.51553 .72592 Mdot
.32805 .37995 Mdot
.3261 .62833 Mdot
.42619 .68397 Mdot
.38721 .32615 Mdot
.47924 .28402 Mdot
.28316 .54903 Mdot
.56203 .7055 Mdot
.4915 .29152 Mdot
.57928 .29794 Mdot
.32474 .63648 Mdot
.61983 .31784 Mdot
.52981 .73084 Mdot
.46403 .70438 Mdot
.63616 .34134 Mdot
.70284 .48702 Mdot
.53182 .70227 Mdot
.39515 .68091 Mdot
.61122 .3278 Mdot
.61245 .6884 Mdot
.61192 .70196 Mdot
.30302 .59928 Mdot
.56979 .3072 Mdot
.36589 .31617 Mdot
.37865 .33606 Mdot
.3263 .62187 Mdot
.63975 .3334 Mdot
.30549 .57804 Mdot
.3833 .31334 Mdot
.59849 .6998 Mdot
.62084 .32779 Mdot
.69601 .5529 Mdot
.50076 .28472 Mdot
.42147 .31354 Mdot
.71214 .46515 Mdot
.65609 .63667 Mdot
.37769 .66388 Mdot
.54395 .28934 Mdot
.30675 .41816 Mdot
.35321 .64355 Mdot
.72501 .46665 Mdot
.46682 .70864 Mdot
.61579 .67984 Mdot
.48487 .70988 Mdot
.2788 .52455 Mdot
.33465 .3747 Mdot
.29967 .45096 Mdot
.3027 .47739 Mdot
.55102 .70182 Mdot
.57896 .29693 Mdot
.47056 .28218 Mdot
.29337 .54628 Mdot
.59254 .30673 Mdot
.48605 .72111 Mdot
.42817 .30617 Mdot
.70719 .53428 Mdot
.45216 .70195 Mdot
.311 .55999 Mdot
.53507 .30068 Mdot
.71903 .50901 Mdot
.35474 .32895 Mdot
.53562 .70576 Mdot
.69843 .42707 Mdot
.60882 .31674 Mdot
.57591 .71495 Mdot
.37209 .32008 Mdot
.29849 .46581 Mdot
.37845 .32977 Mdot
.48438 .699 Mdot
.5351 .70669 Mdot
.30703 .47978 Mdot
.44668 .6984 Mdot
.69357 .43696 Mdot
.66803 .61645 Mdot
.68701 .60477 Mdot
.40402 .67915 Mdot
.72287 .44549 Mdot
.50533 .27755 Mdot
.29373 .54495 Mdot
.64367 .66192 Mdot
.53272 .71559 Mdot
.68666 .41436 Mdot
.48483 .28334 Mdot
.44583 .28005 Mdot
.58099 .30652 Mdot
.36887 .32143 Mdot
.57541 .29498 Mdot
.38508 .66565 Mdot
.69104 .39627 Mdot
.39237 .31472 Mdot
.29494 .5198 Mdot
.32514 .36576 Mdot
.39865 .68292 Mdot
.43825 .29031 Mdot
.35297 .35068 Mdot
.70006 .5827 Mdot
.66563 .34837 Mdot
.27439 .51629 Mdot
.66256 .6307 Mdot
.60356 .7007 Mdot
.48744 .71096 Mdot
.30261 .45254 Mdot
.57111 .30217 Mdot
.70507 .49705 Mdot
.30026 .43493 Mdot
.35126 .6535 Mdot
.69763 .43836 Mdot
.33825 .6498 Mdot
.6298 .66434 Mdot
.7231 .45028 Mdot
.67245 .63738 Mdot
.58724 .31543 Mdot
.65929 .35691 Mdot
.36479 .66745 Mdot
.66253 .62468 Mdot
.33515 .63627 Mdot
.35158 .34358 Mdot
.68703 .61422 Mdot
.44129 .29693 Mdot
.48353 .29627 Mdot
.33008 .38901 Mdot
.6172 .33309 Mdot
.30967 .43165 Mdot
.68818 .57273 Mdot
.49659 .27489 Mdot
.52179 .29771 Mdot
.4013 .30331 Mdot
.29184 .55334 Mdot
.67915 .59366 Mdot
.2941 .57395 Mdot
.29159 .56783 Mdot
.47689 .27751 Mdot
.66555 .36017 Mdot
.68062 .39068 Mdot
.36868 .65819 Mdot
.66621 .36233 Mdot
.415 .30405 Mdot
.62975 .66791 Mdot
.68879 .60756 Mdot
.51456 .28058 Mdot
.7117 .54897 Mdot
.38427 .66148 Mdot
.35323 .36044 Mdot
.42382 .30424 Mdot
.57731 .3006 Mdot
.62973 .32329 Mdot
.29776 .52494 Mdot
.70849 .49418 Mdot
.64604 .34052 Mdot
.6554 .36393 Mdot
.63465 .32842 Mdot
.56714 .70774 Mdot
.61966 .3352 Mdot
.65451 .35567 Mdot
.49777 .70071 Mdot
.48893 .71881 Mdot
.29436 .47153 Mdot
.27845 .53167 Mdot
.68759 .59286 Mdot
.29202 .48967 Mdot
.46092 .71185 Mdot
.37876 .32575 Mdot
.27644 .50763 Mdot
.30027 .51813 Mdot
.39593 .30339 Mdot
.41044 .29653 Mdot
.29294 .57201 Mdot
.27627 .50117 Mdot
.69232 .4337 Mdot
.69073 .56708 Mdot
.71147 .4347 Mdot
.34378 .35713 Mdot
.49034 .27039 Mdot
.70023 .48462 Mdot
.46471 .69692 Mdot
.30785 .45308 Mdot
.41208 .31384 Mdot
.68059 .4065 Mdot
.41873 .68944 Mdot
.2949 .50004 Mdot
.33353 .6277 Mdot
.29415 .52495 Mdot
.28856 .47429 Mdot
.70356 .41579 Mdot
.61979 .31979 Mdot
.72004 .46455 Mdot
.31963 .38322 Mdot
.2887 .54291 Mdot
.69952 .42251 Mdot
.31371 .41479 Mdot
.4243 .28756 Mdot
.66515 .61819 Mdot
.40251 .67839 Mdot
.42083 .29395 Mdot
.66997 .35893 Mdot
.60047 .30259 Mdot
.66918 .64179 Mdot
.66362 .3658 Mdot
.3095 .43639 Mdot
.28332 .50312 Mdot
.41312 .301 Mdot
.70168 .44145 Mdot
.70061 .57651 Mdot
.66072 .36692 Mdot
.50369 .29586 Mdot
.47757 .70717 Mdot
.69852 .42708 Mdot
.29539 .4845 Mdot
.67691 .38144 Mdot
.38339 .33132 Mdot
.34398 .63954 Mdot
.52089 .71313 Mdot
.53012 .28334 Mdot
.43019 .68663 Mdot
.48691 .29559 Mdot
.31441 .56353 Mdot
.70695 .57497 Mdot
.49394 .71224 Mdot
.62972 .67309 Mdot
.52377 .2979 Mdot
.47928 .69885 Mdot
.62552 .66034 Mdot
.71806 .45254 Mdot
.71436 .47786 Mdot
.48033 .72076 Mdot
.43896 .29993 Mdot
.29272 .43032 Mdot
.46373 .7028 Mdot
.29652 .41334 Mdot
.67673 .62194 Mdot
.29738 .56091 Mdot
.37035 .66492 Mdot
.55247 .7151 Mdot
.51382 .71566 Mdot
.41282 .69125 Mdot
.45946 .69621 Mdot
.65479 .65963 Mdot
.37867 .31543 Mdot
.36363 .32075 Mdot
.33007 .61708 Mdot
.62889 .68689 Mdot
.33914 .64422 Mdot
.48001 .28271 Mdot
.68962 .57159 Mdot
.31449 .43253 Mdot
.66858 .36745 Mdot
.42871 .68758 Mdot
.35918 .34163 Mdot
.49408 .70928 Mdot
.70479 .56354 Mdot
.4127 .30349 Mdot
.40138 .31784 Mdot
.33036 .37255 Mdot
.35718 .65669 Mdot
.66257 .37731 Mdot
.39114 .67376 Mdot
.3564 .64501 Mdot
.29958 .52415 Mdot
.6447 .67178 Mdot
.69272 .39995 Mdot
.67558 .38812 Mdot
.6616 .37936 Mdot
.43298 .70416 Mdot
.43112 .70376 Mdot
.47047 .29142 Mdot
.7053 .4538 Mdot
.62776 .34037 Mdot
.42959 .29314 Mdot
.29171 .42693 Mdot
.50617 .71397 Mdot
.31156 .56713 Mdot
.32185 .62917 Mdot
.33509 .36152 Mdot
.29096 .46647 Mdot
.33228 .6447 Mdot
.43582 .70703 Mdot
.41825 .29782 Mdot
.36138 .66038 Mdot
.63635 .33593 Mdot
.47986 .27028 Mdot
.34284 .64676 Mdot
.30021 .47566 Mdot
.71115 .44747 Mdot
.56754 .71167 Mdot
.30871 .60161 Mdot
.49311 .27631 Mdot
.6717 .63479 Mdot
.28714 .47274 Mdot
.30836 .565 Mdot
.58084 .69687 Mdot
.38678 .31417 Mdot
.30222 .47377 Mdot
.36692 .67154 Mdot
.69792 .5962 Mdot
.3071 .58813 Mdot
.67711 .38681 Mdot
.6885 .60414 Mdot
.51425 .71956 Mdot
.71153 .55999 Mdot
.55405 .28275 Mdot
.34846 .34535 Mdot
.35537 .33538 Mdot
.69904 .48564 Mdot
.63317 .66846 Mdot
.44772 .30363 Mdot
.63549 .66894 Mdot
.37185 .66527 Mdot
.49572 .70043 Mdot
.38099 .6753 Mdot
.6699 .61922 Mdot
.34541 .65909 Mdot
.34426 .64404 Mdot
.53416 .29387 Mdot
.58829 .30025 Mdot
.57938 .30802 Mdot
.4434 .29821 Mdot
.63708 .65753 Mdot
.35842 .32877 Mdot
.62908 .33078 Mdot
.31876 .61563 Mdot
.31284 .39859 Mdot
.39125 .67061 Mdot
.45795 .71113 Mdot
.71719 .54709 Mdot
.29941 .45987 Mdot
.51388 .7018 Mdot
.49228 .29354 Mdot
.33545 .35831 Mdot
.40767 .2927 Mdot
.69716 .50063 Mdot
.63381 .33861 Mdot
.39701 .31871 Mdot
.37355 .66689 Mdot
.31867 .6258 Mdot
.63573 .67967 Mdot
.29035 .58337 Mdot
.36961 .33021 Mdot
.53602 .72838 Mdot
.68283 .40807 Mdot
.36548 .34655 Mdot
.42178 .68478 Mdot
.38987 .32994 Mdot
.28655 .46121 Mdot
.6999 .58503 Mdot
.55617 .71039 Mdot
.48053 .27118 Mdot
.6409 .6629 Mdot
.34901 .65864 Mdot
.3074 .47828 Mdot
.59053 .68666 Mdot
.38724 .31063 Mdot
.3316 .35692 Mdot
.34757 .64499 Mdot
.72602 .47664 Mdot
.68278 .39964 Mdot
.69228 .43222 Mdot
.48847 .29443 Mdot
.46061 .7001 Mdot
.41219 .30013 Mdot
.70786 .47876 Mdot
.57213 .71415 Mdot
.60623 .32226 Mdot
.32292 .37041 Mdot
.44571 .6978 Mdot
.49335 .71131 Mdot
.34075 .63895 Mdot
.36445 .65083 Mdot
.29886 .54372 Mdot
.42087 .28775 Mdot
.55533 .70079 Mdot
.70138 .55272 Mdot
.43569 .70254 Mdot
.69095 .39989 Mdot
.2901 .50865 Mdot
.32882 .63562 Mdot
.53691 .70211 Mdot
.6088 .68041 Mdot
.68727 .39574 Mdot
.59322 .31941 Mdot
.29302 .52204 Mdot
.56202 .701 Mdot
.43962 .69329 Mdot
.51655 .72187 Mdot
.68833 .5963 Mdot
.39085 .66519 Mdot
.34612 .36721 Mdot
.70464 .53205 Mdot
.33005 .60287 Mdot
.66019 .37202 Mdot
.31453 .41146 Mdot
.66541 .61549 Mdot
.64918 .64409 Mdot
.72356 .44953 Mdot
.67748 .36482 Mdot
.50578 .29629 Mdot
.61973 .33097 Mdot
.31509 .5721 Mdot
.48697 .70292 Mdot
.28077 .50768 Mdot
.65473 .35993 Mdot
.35097 .34389 Mdot
.33745 .64476 Mdot
.30565 .41878 Mdot
.44556 .70403 Mdot
.39606 .30656 Mdot
.28361 .53715 Mdot
.70149 .42549 Mdot
.37668 .32537 Mdot
.29824 .46569 Mdot
.32372 .60272 Mdot
.66711 .63754 Mdot
.31768 .42022 Mdot
.30316 .4886 Mdot
.49546 .70754 Mdot
.71015 .53115 Mdot
.71161 .55263 Mdot
.30207 .59592 Mdot
.35502 .32658 Mdot
.29841 .48432 Mdot
.71049 .52472 Mdot
.70486 .57716 Mdot
.36039 .34379 Mdot
.70228 .47011 Mdot
.66665 .61829 Mdot
.30251 .50588 Mdot
.68967 .39022 Mdot
.30056 .43682 Mdot
.65909 .38149 Mdot
.57366 .71282 Mdot
.40279 .66948 Mdot
.44634 .29781 Mdot
.33551 .63398 Mdot
.46455 .2864 Mdot
.54386 .29646 Mdot
.52423 .29429 Mdot
.45969 .29927 Mdot
.43505 .69151 Mdot
.65714 .35759 Mdot
.60064 .30906 Mdot
.70465 .50218 Mdot
.39459 .32368 Mdot
.43476 .30322 Mdot
.71742 .54276 Mdot
.33399 .64356 Mdot
.39244 .6723 Mdot
.35234 .34322 Mdot
.33524 .38151 Mdot
.69907 .42254 Mdot
.35268 .66073 Mdot
.67197 .61013 Mdot
.31894 .41813 Mdot
.6231 .69041 Mdot
.72642 .46262 Mdot
.28392 .51088 Mdot
.69991 .46182 Mdot
.59863 .70582 Mdot
.4408 .29078 Mdot
.32143 .40403 Mdot
.63811 .66563 Mdot
.44882 .28407 Mdot
.61418 .32127 Mdot
.37587 .32375 Mdot
.43152 .69524 Mdot
.30763 .41378 Mdot
.32625 .62053 Mdot
.65715 .63006 Mdot
.29374 .54934 Mdot
.70177 .49896 Mdot
.59967 .30512 Mdot
.27586 .50179 Mdot
.46459 .28661 Mdot
.58087 .30995 Mdot
.71593 .43638 Mdot
.51448 .71895 Mdot
.40705 .31328 Mdot
.43646 .30858 Mdot
.37785 .67124 Mdot
.3541 .35789 Mdot
.67449 .39725 Mdot
.41949 .29143 Mdot
.6094 .68402 Mdot
.47687 .71938 Mdot
.28289 .47747 Mdot
.28267 .52264 Mdot
.33189 .38905 Mdot
.47945 .69841 Mdot
.72107 .48269 Mdot
.35981 .3235 Mdot
.3948 .32822 Mdot
.70906 .5666 Mdot
.59215 .30202 Mdot
.29537 .5915 Mdot
.41749 .30459 Mdot
.57142 .69686 Mdot
.50778 .71338 Mdot
.55011 .29409 Mdot
.4124 .30595 Mdot
.30336 .43752 Mdot
.52782 .2834 Mdot
.71219 .46785 Mdot
.6449 .66659 Mdot
.71249 .49413 Mdot
.3326 .64444 Mdot
.36119 .33326 Mdot
.47252 .28546 Mdot
.29082 .53498 Mdot
.29547 .42502 Mdot
.45119 .30043 Mdot
.67156 .38018 Mdot
.51304 .72089 Mdot
.55567 .72041 Mdot
.44767 .69829 Mdot
.6403 .67885 Mdot
.35243 .65761 Mdot
.54762 .29949 Mdot
.5094 .29544 Mdot
.64302 .66813 Mdot
.36036 .66088 Mdot
.37283 .31574 Mdot
.40954 .30433 Mdot
.54017 .29033 Mdot
.28685 .47758 Mdot
.36851 .31878 Mdot
.50078 .70931 Mdot
.30776 .40007 Mdot
.71541 .44438 Mdot
.58931 .29984 Mdot
.53094 .71588 Mdot
.45276 .3001 Mdot
.70465 .417 Mdot
.63957 .65855 Mdot
.458 .69968 Mdot
.30421 .59614 Mdot
.61579 .32509 Mdot
.62263 .3188 Mdot
.35312 .361 Mdot
.44157 .68877 Mdot
.48292 .28705 Mdot
.30971 .42991 Mdot
.31195 .39482 Mdot
.64684 .35253 Mdot
.40483 .3232 Mdot
.58222 .29438 Mdot
.28464 .54641 Mdot
.32907 .60132 Mdot
.37566 .32995 Mdot
.36895 .34184 Mdot
.69348 .57755 Mdot
.36095 .64733 Mdot
.32178 .63506 Mdot
.67201 .35875 Mdot
.6102 .32893 Mdot
.70752 .56011 Mdot
.57176 .69717 Mdot
.42411 .70064 Mdot
.56876 .30133 Mdot
.69418 .39755 Mdot
.52935 .72956 Mdot
.423 .69556 Mdot
.56592 .71605 Mdot
.71812 .45951 Mdot
.65576 .34808 Mdot
.62613 .68508 Mdot
.69538 .5819 Mdot
.63488 .65617 Mdot
.67237 .37545 Mdot
.66684 .38026 Mdot
.64846 .64632 Mdot
.69763 .57166 Mdot
.70364 .45561 Mdot
.58921 .30274 Mdot
.6145 .32177 Mdot
.65309 .36078 Mdot
.71688 .55133 Mdot
.56381 .29949 Mdot
.70819 .50639 Mdot
.42597 .31093 Mdot
.63039 .65669 Mdot
.64288 .33138 Mdot
.68434 .61624 Mdot
.61062 .32066 Mdot
.62202 .68422 Mdot
.68205 .61708 Mdot
.3925 .66614 Mdot
.50914 .71893 Mdot
.3543 .64402 Mdot
.29175 .53517 Mdot
.29268 .57223 Mdot
.57163 .30215 Mdot
.40048 .6817 Mdot
.70658 .51806 Mdot
.41741 .69552 Mdot
.49939 .72013 Mdot
.57962 .69634 Mdot
.58157 .69163 Mdot
.6488 .35588 Mdot
.70454 .51989 Mdot
.30308 .40564 Mdot
.33976 .35197 Mdot
.61232 .67777 Mdot
.61511 .3236 Mdot
.67773 .38053 Mdot
.62704 .3389 Mdot
.38557 .31216 Mdot
.40776 .31402 Mdot
.28928 .49353 Mdot
.30234 .47326 Mdot
.38362 .32023 Mdot
.30545 .39982 Mdot
.61586 .68591 Mdot
.70157 .47903 Mdot
.70475 .53478 Mdot
.53724 .72191 Mdot
.56729 .72068 Mdot
.334 .63102 Mdot
.31815 .41786 Mdot
.48756 .29176 Mdot
.63923 .66827 Mdot
.44259 .71087 Mdot
.30229 .49376 Mdot
.54518 .2786 Mdot
.3105 .5959 Mdot
.59975 .3069 Mdot
.3195 .59351 Mdot
.36659 .34026 Mdot
.44189 .69685 Mdot
.41004 .68863 Mdot
.50748 .29388 Mdot
.33679 .36619 Mdot
.42632 .29614 Mdot
.3324 .6339 Mdot
.54159 .71912 Mdot
.40339 .30472 Mdot
.64545 .33157 Mdot
.69281 .39799 Mdot
.28274 .53448 Mdot
.42355 .69216 Mdot
.55504 .71384 Mdot
.70268 .58039 Mdot
.29859 .52873 Mdot
.29351 .51977 Mdot
.62981 .33296 Mdot
.60942 .69541 Mdot
.44288 .27977 Mdot
.30563 .47637 Mdot
.64774 .35686 Mdot
.40127 .31495 Mdot
.29789 .52977 Mdot
.29446 .58015 Mdot
.38574 .67619 Mdot
.28615 .57122 Mdot
.67721 .37352 Mdot
.71534 .4908 Mdot
.68269 .58694 Mdot
.68431 .37064 Mdot
.31938 .58611 Mdot
.3152 .61554 Mdot
.32713 .39746 Mdot
.5201 .2877 Mdot
.59445 .70982 Mdot
.32168 .62233 Mdot
.64217 .34949 Mdot
.7166 .53906 Mdot
.70295 .5572 Mdot
.68778 .58174 Mdot
.70688 .50273 Mdot
.52474 .70565 Mdot
.33687 .37399 Mdot
.67216 .37913 Mdot
.69639 .56335 Mdot
.55554 .72571 Mdot
.69364 .42378 Mdot
.60243 .32444 Mdot
.66419 .62603 Mdot
.65899 .35962 Mdot
.64946 .66467 Mdot
.61501 .33178 Mdot
.61843 .67801 Mdot
.40722 .29417 Mdot
.32536 .40173 Mdot
.58003 .30109 Mdot
.32547 .36893 Mdot
.40459 .30207 Mdot
.42548 .29913 Mdot
.65049 .34548 Mdot
.34975 .35481 Mdot
.70365 .52299 Mdot
.3074 .41706 Mdot
.56296 .7012 Mdot
.3124 .57753 Mdot
.33128 .38584 Mdot
.65718 .36655 Mdot
.63037 .33038 Mdot
.37554 .66015 Mdot
.50074 .72375 Mdot
.48246 .27701 Mdot
.32704 .61279 Mdot
.63019 .66706 Mdot
.32528 .59961 Mdot
.37443 .31725 Mdot
.51707 .69913 Mdot
.50867 .71383 Mdot
.46328 .27582 Mdot
.33697 .6355 Mdot
.66329 .37677 Mdot
.69088 .58007 Mdot
.46312 .29424 Mdot
.32699 .62345 Mdot
.33278 .64207 Mdot
.45689 .69985 Mdot
.715 .49476 Mdot
.44358 .29281 Mdot
.54375 .28709 Mdot
.2886 .45427 Mdot
.64915 .66662 Mdot
.59313 .69851 Mdot
.48241 .71319 Mdot
.62691 .66552 Mdot
.31388 .41105 Mdot
.58748 .30452 Mdot
.48794 .71397 Mdot
.31135 .42191 Mdot
.45153 .69235 Mdot
.69918 .40696 Mdot
.32111 .39851 Mdot
.28166 .54474 Mdot
.29542 .47039 Mdot
.41749 .68546 Mdot
.39515 .68444 Mdot
.56225 .70586 Mdot
.55462 .29327 Mdot
.29063 .5533 Mdot
.32906 .368 Mdot
.68083 .40424 Mdot
.38532 .67539 Mdot
.69076 .5898 Mdot
.55275 .29405 Mdot
.40336 .30593 Mdot
.38908 .67897 Mdot
.34869 .63525 Mdot
.6945 .6028 Mdot
.48962 .7198 Mdot
.41764 .68661 Mdot
.59796 .31899 Mdot
.54757 .28602 Mdot
.72725 .4686 Mdot
.28164 .47909 Mdot
.69794 .42241 Mdot
.50445 .28451 Mdot
.39188 .68247 Mdot
.2815 .51401 Mdot
.72259 .4746 Mdot
.281 .52448 Mdot
.56017 .28442 Mdot
.57442 .70317 Mdot
.71491 .49294 Mdot
.28556 .52233 Mdot
.68135 .61329 Mdot
.70929 .5507 Mdot
.58952 .69318 Mdot
.42642 .68229 Mdot
.67623 .395 Mdot
.67402 .38101 Mdot
.71079 .51097 Mdot
.28446 .50105 Mdot
.45081 .70634 Mdot
.40121 .67463 Mdot
.42156 .67765 Mdot
.69652 .40652 Mdot
.43411 .69185 Mdot
.6704 .39714 Mdot
.61894 .66822 Mdot
.39649 .29762 Mdot
.42135 .69646 Mdot
.57086 .29551 Mdot
.40771 .67578 Mdot
.33715 .65033 Mdot
.65924 .6466 Mdot
.68832 .59868 Mdot
.59375 .30941 Mdot
.53439 .72751 Mdot
.30682 .43355 Mdot
.39782 .68131 Mdot
.31736 .58935 Mdot
.47449 .27476 Mdot
.57539 .70656 Mdot
.69937 .44254 Mdot
.66159 .36966 Mdot
.37456 .3331 Mdot
.62156 .32591 Mdot
.36769 .32471 Mdot
.69047 .56735 Mdot
.27862 .5016 Mdot
.30979 .40543 Mdot
.57474 .69682 Mdot
.5954 .69927 Mdot
.30124 .45324 Mdot
.69964 .51367 Mdot
.34246 .37108 Mdot
.57362 .7201 Mdot
.71758 .54479 Mdot
.34621 .64135 Mdot
.32306 .59996 Mdot
.37076 .65938 Mdot
.70731 .48903 Mdot
.63233 .3331 Mdot
.60055 .31995 Mdot
.44971 .30288 Mdot
.35065 .66075 Mdot
.52027 .27531 Mdot
.55535 .28591 Mdot
.3381 .38083 Mdot
.6014 .3069 Mdot
.44116 .70514 Mdot
.29376 .57179 Mdot
.71075 .45496 Mdot
.29535 .52847 Mdot
.59319 .70903 Mdot
.40254 .32524 Mdot
.28229 .49524 Mdot
.35462 .64243 Mdot
.57412 .29189 Mdot
.3868 .32305 Mdot
.51809 .72079 Mdot
.67529 .38202 Mdot
.72242 .51442 Mdot
.29222 .45455 Mdot
.68656 .60033 Mdot
.67882 .60876 Mdot
.7212 .46129 Mdot
.29953 .56975 Mdot
.28849 .44582 Mdot
.67128 .6172 Mdot
.51809 .29611 Mdot
.30687 .54541 Mdot
.33581 .36925 Mdot
.35742 .33568 Mdot
.39211 .31389 Mdot
.60467 .70298 Mdot
.37872 .30916 Mdot
.65665 .6433 Mdot
.46218 .29403 Mdot
.49085 .27158 Mdot
.50802 .70401 Mdot
.4082 .30581 Mdot
.30576 .48664 Mdot
.51085 .71079 Mdot
.71547 .47398 Mdot
.40961 .29541 Mdot
.39186 .66503 Mdot
.30743 .39484 Mdot
.50225 .29682 Mdot
.28505 .499 Mdot
.67221 .63542 Mdot
.59599 .30718 Mdot
.67084 .36222 Mdot
.5946 .69009 Mdot
.32344 .61902 Mdot
.71646 .50544 Mdot
.31034 .55985 Mdot
.32317 .63384 Mdot
.63012 .65784 Mdot
.66834 .35247 Mdot
.28268 .55679 Mdot
.3223 .60164 Mdot
.3557 .64126 Mdot
.38962 .31409 Mdot
.31183 .4196 Mdot
.29925 .48033 Mdot
.51974 .72138 Mdot
.31896 .39352 Mdot
.5763 .29658 Mdot
.48098 .71375 Mdot
.42948 .29683 Mdot
.28792 .56085 Mdot
.4201 .69266 Mdot
.69372 .58468 Mdot
.71624 .45252 Mdot
.27902 .536 Mdot
.31456 .58781 Mdot
.71595 .4818 Mdot
.47604 .70953 Mdot
.32168 .58587 Mdot
.28921 .45497 Mdot
.51935 .70834 Mdot
.64326 .34545 Mdot
.63617 .3362 Mdot
.35089 .34234 Mdot
.59148 .31888 Mdot
.42799 .31351 Mdot
.32059 .59195 Mdot
.39056 .67858 Mdot
.29239 .4843 Mdot
.66615 .62303 Mdot
.66154 .64038 Mdot
.36477 .33676 Mdot
.66485 .37983 Mdot
.5628 .30452 Mdot
.66101 .64432 Mdot
.51078 .70835 Mdot
.41576 .68674 Mdot
.32082 .40084 Mdot
.68271 .4027 Mdot
.41911 .68945 Mdot
.27814 .5188 Mdot
.51486 .7063 Mdot
.33446 .62103 Mdot
.40083 .29653 Mdot
.30485 .46298 Mdot
.68926 .38084 Mdot
.2861 .51159 Mdot
.42162 .30207 Mdot
.56871 .69551 Mdot
.63267 .66015 Mdot
.37876 .66931 Mdot
.67884 .3761 Mdot
.70511 .41925 Mdot
.41245 .31133 Mdot
.31138 .41682 Mdot
.68332 .59843 Mdot
.68881 .58556 Mdot
.51027 .71162 Mdot
.3734 .31838 Mdot
.34086 .34418 Mdot
.28106 .51944 Mdot
.28664 .47565 Mdot
.60835 .67806 Mdot
.37507 .33496 Mdot
.43991 .69569 Mdot
.71504 .55075 Mdot
.57228 .2879 Mdot
.7113 .48404 Mdot
.52548 .28525 Mdot
.58756 .29344 Mdot
.58314 .71532 Mdot
.54386 .70011 Mdot
.48198 .29312 Mdot
.53116 .29689 Mdot
.34102 .37823 Mdot
.61245 .6707 Mdot
.34138 .64661 Mdot
.57328 .69846 Mdot
.36754 .32279 Mdot
.46226 .70995 Mdot
.66379 .38429 Mdot
.29417 .45745 Mdot
.55028 .29709 Mdot
.38875 .67497 Mdot
.67537 .59973 Mdot
.32677 .38307 Mdot
.30354 .49339 Mdot
.29347 .54288 Mdot
.5592 .7123 Mdot
.43598 .69372 Mdot
.35188 .34103 Mdot
.67561 .62115 Mdot
.50293 .28381 Mdot
.33473 .38747 Mdot
.7064 .48425 Mdot
.41197 .67985 Mdot
.68939 .42093 Mdot
.57273 .28947 Mdot
.30511 .55159 Mdot
.35646 .65168 Mdot
.40008 .68372 Mdot
.66467 .61732 Mdot
.4743 .29444 Mdot
.68603 .59264 Mdot
.70208 .56699 Mdot
.29644 .49215 Mdot
.67241 .61046 Mdot
.49479 .7232 Mdot
.53523 .73126 Mdot
.29939 .52522 Mdot
.56009 .2862 Mdot
.58771 .70969 Mdot
.3013 .51028 Mdot
.66105 .64768 Mdot
.60732 .30994 Mdot
.68566 .59417 Mdot
.57912 .30534 Mdot
.33517 .38587 Mdot
.49852 .29571 Mdot
.33163 .60505 Mdot
.33702 .3796 Mdot
.72126 .50591 Mdot
.65785 .35801 Mdot
.62149 .33503 Mdot
.32388 .6036 Mdot
.5744 .29979 Mdot
.37822 .32791 Mdot
.51116 .29831 Mdot
.69351 .3841 Mdot
.56997 .69683 Mdot
.58334 .71471 Mdot
.57768 .31354 Mdot
.34105 .35353 Mdot
.65319 .36065 Mdot
.52341 .29081 Mdot
.67753 .62707 Mdot
.34979 .63821 Mdot
.41285 .68252 Mdot
.57243 .29093 Mdot
.32625 .38914 Mdot
.72147 .45249 Mdot
.31778 .59518 Mdot
.62154 .31813 Mdot
.36454 .3395 Mdot
.49659 .70329 Mdot
.54584 .29704 Mdot
.30123 .41534 Mdot
.50816 .29227 Mdot
.54861 .72233 Mdot
.28165 .48599 Mdot
.27927 .52678 Mdot
.70538 .433 Mdot
.30953 .4435 Mdot
.3101 .42992 Mdot
.51945 .29835 Mdot
.72553 .48525 Mdot
.31053 .39437 Mdot
.51924 .7219 Mdot
.69425 .56477 Mdot
.29217 .49436 Mdot
.68045 .39274 Mdot
.69273 .59094 Mdot
.28896 .48774 Mdot
.62048 .66644 Mdot
.71273 .49008 Mdot
.39149 .30427 Mdot
.49872 .70906 Mdot
.50004 .2732 Mdot
.49327 .28212 Mdot
.3087 .43782 Mdot
.46714 .286 Mdot
.66068 .64804 Mdot
.66534 .3484 Mdot
.67915 .59459 Mdot
.33275 .61854 Mdot
.69435 .44186 Mdot
.27985 .51857 Mdot
.37092 .65722 Mdot
.49419 .70634 Mdot
.40881 .31301 Mdot
.31572 .38956 Mdot
.61029 .67759 Mdot
.67044 .37362 Mdot
.65573 .64734 Mdot
.67968 .60586 Mdot
.68757 .5895 Mdot
.45032 .30181 Mdot
.62946 .66601 Mdot
.43735 .6937 Mdot
.57834 .31222 Mdot
.66964 .64333 Mdot
.55479 .72369 Mdot
.312 .42958 Mdot
.68988 .59684 Mdot
.48077 .27385 Mdot
.70215 .47753 Mdot
.40747 .31245 Mdot
.72184 .48716 Mdot
.70324 .49128 Mdot
.65648 .35068 Mdot
.52415 .27736 Mdot
.67584 .61294 Mdot
.46573 .27212 Mdot
.71664 .44508 Mdot
.56368 .72084 Mdot
.66717 .39088 Mdot
.28742 .45047 Mdot
.72354 .49596 Mdot
.67301 .36533 Mdot
.69836 .54787 Mdot
.68318 .40131 Mdot
.51787 .71601 Mdot
.532 .71682 Mdot
.59683 .68527 Mdot
.31087 .41144 Mdot
.45098 .70063 Mdot
.29134 .57431 Mdot
.33268 .61578 Mdot
.72317 .46749 Mdot
.29322 .52384 Mdot
.65364 .63945 Mdot
.30033 .5373 Mdot
.47744 .71382 Mdot
.42594 .69509 Mdot
.68433 .58892 Mdot
.61159 .68799 Mdot
.31189 .40629 Mdot
.66283 .38008 Mdot
.55837 .72442 Mdot
.30398 .40821 Mdot
.49691 .7 Mdot
.65494 .65053 Mdot
.54186 .72977 Mdot
.40704 .31332 Mdot
.70493 .47362 Mdot
.29177 .56845 Mdot
.68536 .42489 Mdot
.42867 .68517 Mdot
.30281 .57343 Mdot
.31703 .57712 Mdot
.42608 .69385 Mdot
.69147 .42589 Mdot
.68647 .59861 Mdot
.67856 .37213 Mdot
.69478 .41227 Mdot
.51013 .70816 Mdot
.70909 .47006 Mdot
.65555 .34698 Mdot
.68914 .5859 Mdot
.32529 .38482 Mdot
.42793 .28825 Mdot
.58559 .70232 Mdot
.31712 .59624 Mdot
.47899 .70315 Mdot
.31025 .6062 Mdot
.2954 .56375 Mdot
.30111 .4832 Mdot
.53188 .70481 Mdot
.33001 .36221 Mdot
.30643 .58653 Mdot
.31271 .40701 Mdot
.6917 .38093 Mdot
.71 .43211 Mdot
.50791 .28538 Mdot
.30791 .42709 Mdot
.29937 .48401 Mdot
.54631 .71888 Mdot
.63948 .67328 Mdot
.46963 .28938 Mdot
.70121 .42149 Mdot
.57915 .7042 Mdot
.30672 .44905 Mdot
.41521 .29428 Mdot
.4387 .30581 Mdot
.51918 .29794 Mdot
.71245 .52634 Mdot
.44976 .70927 Mdot
.30202 .4546 Mdot
.66361 .62739 Mdot
.29091 .53995 Mdot
.28459 .56673 Mdot
.3213 .37247 Mdot
.44508 .70203 Mdot
.68279 .61687 Mdot
.40546 .30033 Mdot
.31041 .60151 Mdot
.70158 .42195 Mdot
.31976 .58725 Mdot
.46717 .27459 Mdot
.72246 .45776 Mdot
.37648 .32162 Mdot
.30279 .46171 Mdot
.46619 .71026 Mdot
.70489 .49656 Mdot
.69921 .5093 Mdot
.71261 .47547 Mdot
.33 .61516 Mdot
.35484 .33369 Mdot
.2934 .44531 Mdot
.51738 .71905 Mdot
.67125 .35471 Mdot
.38865 .67982 Mdot
.48535 .70631 Mdot
.61199 .31943 Mdot
.69989 .58182 Mdot
.64509 .34655 Mdot
.68663 .60338 Mdot
.7205 .44551 Mdot
.4397 .3012 Mdot
.37868 .65883 Mdot
.51964 .71442 Mdot
.57302 .70706 Mdot
.31097 .59787 Mdot
.68854 .40519 Mdot
.5818 .69754 Mdot
.623 .69041 Mdot
.56749 .71226 Mdot
.41397 .68698 Mdot
.58435 .7143 Mdot
.29804 .5846 Mdot
.29214 .4804 Mdot
.6672 .6345 Mdot
.43301 .68459 Mdot
.69474 .42923 Mdot
.71148 .44997 Mdot
.67991 .61645 Mdot
.56829 .30162 Mdot
.71826 .50939 Mdot
.40902 .2981 Mdot
.4593 .29383 Mdot
.29945 .41283 Mdot
.36721 .66134 Mdot
.68067 .59923 Mdot
.4054 .68956 Mdot
.56354 .29999 Mdot
.32165 .61412 Mdot
.68941 .3903 Mdot
.32881 .64063 Mdot
.63717 .66707 Mdot
.33375 .60842 Mdot
.29214 .46174 Mdot
.52119 .27971 Mdot
.71493 .54987 Mdot
.30843 .57789 Mdot
.71396 .4817 Mdot
.58137 .70427 Mdot
.54668 .71049 Mdot
.62666 .32377 Mdot
.34593 .64763 Mdot
.28827 .45435 Mdot
.48614 .69983 Mdot
.62687 .68669 Mdot
.57654 .30504 Mdot
.32792 .60001 Mdot
.62051 .32835 Mdot
.70543 .56934 Mdot
.70494 .41209 Mdot
.66873 .37551 Mdot
.49948 .28115 Mdot
.65521 .64939 Mdot
.34098 .6185 Mdot
.38117 .31958 Mdot
.60622 .67597 Mdot
.3118 .40439 Mdot
.30445 .59309 Mdot
.58131 .70891 Mdot
.34062 .37061 Mdot
.55666 .72505 Mdot
.49477 .28895 Mdot
.39193 .67361 Mdot
.69443 .59316 Mdot
.50915 .6994 Mdot
.43125 .29419 Mdot
.39388 .31326 Mdot
.30575 .41586 Mdot
.61376 .69531 Mdot
.55384 .72799 Mdot
.70212 .50336 Mdot
.35402 .33696 Mdot
.65121 .35045 Mdot
.67806 .39421 Mdot
.32791 .36748 Mdot
.6886 .39606 Mdot
.33308 .64262 Mdot
.51166 .69894 Mdot
.49563 .28937 Mdot
.50851 .2901 Mdot
.38085 .32138 Mdot
.34757 .35441 Mdot
.40686 .31419 Mdot
.70147 .57823 Mdot
.66088 .34503 Mdot
.59676 .69317 Mdot
.43876 .68879 Mdot
.40183 .68229 Mdot
.70576 .4831 Mdot
.66464 .63984 Mdot
.41417 .6985 Mdot
.34465 .6384 Mdot
.4205 .30332 Mdot
.60775 .31192 Mdot
.69914 .55021 Mdot
.56844 .30488 Mdot
.52629 .70704 Mdot
.43701 .28804 Mdot
.70071 .44946 Mdot
.33944 .61758 Mdot
.71204 .55837 Mdot
.36017 .65503 Mdot
.56752 .28723 Mdot
.70027 .50924 Mdot
.63299 .6669 Mdot
.51031 .70514 Mdot
.64162 .65433 Mdot
.30154 .53488 Mdot
.72538 .45466 Mdot
.61177 .32492 Mdot
.71306 .54968 Mdot
.29971 .54171 Mdot
.70368 .5833 Mdot
.6021 .70432 Mdot
.44887 .69228 Mdot
.57547 .71411 Mdot
.52814 .72155 Mdot
.71244 .46642 Mdot
.64853 .6564 Mdot
.30181 .45914 Mdot
.52544 .71609 Mdot
.51459 .27498 Mdot
.47523 .71472 Mdot
.4054 .68459 Mdot
.46328 .71444 Mdot
.53081 .72763 Mdot
.71695 .51357 Mdot
.68856 .57957 Mdot
.57855 .31123 Mdot
.61599 .69032 Mdot
.51607 .28353 Mdot
.38481 .32175 Mdot
.31525 .4254 Mdot
.71243 .45899 Mdot
.3588 .65312 Mdot
.45158 .28192 Mdot
.60875 .69123 Mdot
.29688 .41642 Mdot
.52582 .72455 Mdot
.29177 .46007 Mdot
.2932 .56976 Mdot
.34297 .62158 Mdot
.45106 .30418 Mdot
.58296 .29983 Mdot
.5336 .72883 Mdot
.6518 .35491 Mdot
.66763 .36338 Mdot
.5237 .71252 Mdot
.55517 .28121 Mdot
.49335 .28245 Mdot
.33275 .38384 Mdot
.44941 .7087 Mdot
.53094 .71738 Mdot
.68929 .39503 Mdot
.29909 .44066 Mdot
.63813 .65194 Mdot
.32951 .63065 Mdot
.39922 .68505 Mdot
.30627 .45242 Mdot
.64689 .65607 Mdot
.58044 .31143 Mdot
.28436 .55798 Mdot
.44169 .71105 Mdot
.56767 .69988 Mdot
.67059 .62037 Mdot
.37171 .66207 Mdot
.34334 .34351 Mdot
.50181 .7076 Mdot
.48834 .70494 Mdot
.71188 .49181 Mdot
.50404 .29512 Mdot
.66208 .37667 Mdot
.69865 .46017 Mdot
.30073 .48315 Mdot
.49543 .29687 Mdot
.38706 .66442 Mdot
.47043 .27875 Mdot
.69914 .58314 Mdot
.60305 .70019 Mdot
.61129 .32504 Mdot
.69544 .42092 Mdot
.69285 .39576 Mdot
.55224 .70805 Mdot
.70522 .56375 Mdot
.47921 .70294 Mdot
.31051 .41965 Mdot
.30919 .43615 Mdot
.51227 .7055 Mdot
.67578 .37582 Mdot
.49433 .71175 Mdot
.56516 .28798 Mdot
.3085 .5699 Mdot
.66755 .36865 Mdot
.33157 .37732 Mdot
.44617 .3028 Mdot
.34433 .34805 Mdot
.28115 .48357 Mdot
.67514 .6097 Mdot
.71931 .48733 Mdot
.64675 .35349 Mdot
.64851 .6488 Mdot
.4205 .30231 Mdot
.33411 .62594 Mdot
.47238 .70359 Mdot
.30809 .45185 Mdot
.49618 .2732 Mdot
.68616 .37449 Mdot
.61724 .67017 Mdot
.32719 .59582 Mdot
.64088 .67209 Mdot
.29717 .49681 Mdot
.43919 .70286 Mdot
.33294 .60655 Mdot
.36338 .34457 Mdot
.68132 .61065 Mdot
.29492 .58563 Mdot
.31611 .3998 Mdot
.45645 .30229 Mdot
.50304 .28005 Mdot
.35022 .33513 Mdot
.36477 .663 Mdot
.30487 .47037 Mdot
.66384 .36237 Mdot
.4342 .69559 Mdot
.29385 .49873 Mdot
.42887 .30562 Mdot
.28083 .51328 Mdot
.39959 .6754 Mdot
.6842 .41773 Mdot
.3741 .32811 Mdot
.4935 .70934 Mdot
.6789 .61025 Mdot
.72321 .46233 Mdot
.32828 .38411 Mdot
.65545 .64623 Mdot
.35654 .66428 Mdot
.37343 .34083 Mdot
.43214 .29481 Mdot
.52841 .70936 Mdot
.34311 .62855 Mdot
.41402 .67763 Mdot
.58823 .30042 Mdot
.6372 .67354 Mdot
.50759 .29401 Mdot
.50893 .72389 Mdot
.51381 .72351 Mdot
.61924 .68154 Mdot
.71315 .42495 Mdot
.29944 .44608 Mdot
.46912 .70351 Mdot
.39733 .66947 Mdot
.66743 .39032 Mdot
.69165 .60952 Mdot
.60441 .68875 Mdot
.70639 .46428 Mdot
.31417 .57675 Mdot
.56908 .29982 Mdot
.47333 .70347 Mdot
.46035 .27634 Mdot
.33431 .62168 Mdot
.54968 .7129 Mdot
.61756 .66749 Mdot
.667 .381 Mdot
.41544 .69685 Mdot
.66424 .36992 Mdot
.59559 .69975 Mdot
.72727 .48278 Mdot
.52044 .29063 Mdot
.54137 .72273 Mdot
.30497 .47388 Mdot
.30297 .4116 Mdot
.57514 .71624 Mdot
.33994 .6379 Mdot
.69633 .59098 Mdot
.30049 .49012 Mdot
.59923 .30646 Mdot
.41936 .28941 Mdot
.40997 .31303 Mdot
.53188 .27747 Mdot
.72431 .48336 Mdot
.3276 .38818 Mdot
.28095 .50157 Mdot
.67166 .62059 Mdot
.34494 .65797 Mdot
.48721 .29574 Mdot
.40152 .67265 Mdot
.42703 .70179 Mdot
.31939 .40248 Mdot
.40996 .29351 Mdot
.67607 .40775 Mdot
.72741 .47206 Mdot
.70188 .51125 Mdot
.31068 .60013 Mdot
.32477 .38826 Mdot
.37989 .6612 Mdot
.45064 .7022 Mdot
.36752 .34356 Mdot
.70518 .47554 Mdot
.33251 .61379 Mdot
.27928 .52827 Mdot
.55917 .29671 Mdot
.31166 .39844 Mdot
.66627 .36675 Mdot
.3269 .37833 Mdot
.29426 .44533 Mdot
.69943 .5446 Mdot
.53874 .71967 Mdot
.59091 .30448 Mdot
.3377 .36715 Mdot
.64319 .34291 Mdot
.53153 .70671 Mdot
.29148 .54757 Mdot
.28036 .48721 Mdot
.71628 .43927 Mdot
.37369 .32538 Mdot
.34654 .63542 Mdot
.59216 .70889 Mdot
.35555 .64074 Mdot
.70374 .48538 Mdot
.35846 .34366 Mdot
.28649 .5535 Mdot
.60926 .31226 Mdot
.49276 .71149 Mdot
.33219 .61627 Mdot
.59191 .3062 Mdot
.29646 .46965 Mdot
.56346 .7019 Mdot
.60507 .68728 Mdot
.67134 .61601 Mdot
.58328 .30944 Mdot
.64019 .6525 Mdot
.48839 .72195 Mdot
.49415 .28871 Mdot
.31187 .56389 Mdot
.30125 .41616 Mdot
.66108 .64977 Mdot
.51961 .29839 Mdot
.35325 .35263 Mdot
.35384 .32836 Mdot
.28762 .46061 Mdot
.31234 .40556 Mdot
.49147 .2792 Mdot
.28936 .53127 Mdot
.30065 .42492 Mdot
.50508 .29475 Mdot
.64223 .6651 Mdot
.4796 .70732 Mdot
.68491 .61198 Mdot
.30162 .4648 Mdot
.28688 .50457 Mdot
.70668 .44974 Mdot
.70888 .54828 Mdot
.28789 .55019 Mdot
.41628 .67536 Mdot
.70181 .5157 Mdot
.6139 .32629 Mdot
.3966 .68818 Mdot
.54427 .2831 Mdot
.67615 .61592 Mdot
.46638 .29918 Mdot
.33111 .38371 Mdot
.43212 .69481 Mdot
.43666 .28414 Mdot
.38973 .67991 Mdot
.47101 .70185 Mdot
.71208 .55838 Mdot
.45345 .69356 Mdot
.52515 .71515 Mdot
.69765 .53703 Mdot
.29117 .47135 Mdot
.70905 .51309 Mdot
.59711 .30902 Mdot
.30892 .56868 Mdot
.3094 .43164 Mdot
.57749 .3065 Mdot
.45438 .70108 Mdot
.31881 .42025 Mdot
.41849 .68771 Mdot
.43731 .68593 Mdot
.62637 .69084 Mdot
.38087 .67867 Mdot
.39333 .31978 Mdot
.35972 .65673 Mdot
.6842 .39065 Mdot
.69932 .43354 Mdot
.33966 .63468 Mdot
.60551 .67745 Mdot
.64 .64959 Mdot
.39183 .30016 Mdot
.66844 .36459 Mdot
.32114 .63283 Mdot
.56828 .29575 Mdot
.66236 .65516 Mdot
.60651 .6825 Mdot
.55036 .29251 Mdot
.40614 .68317 Mdot
.64539 .35092 Mdot
.70557 .45858 Mdot
.47855 .29471 Mdot
.64455 .34792 Mdot
.63628 .65557 Mdot
.70422 .57042 Mdot
.57517 .30807 Mdot
.46308 .70023 Mdot
.50934 .29544 Mdot
.58753 .71617 Mdot
.70881 .55907 Mdot
.66893 .37126 Mdot
.55595 .71953 Mdot
.69564 .43856 Mdot
.28864 .49852 Mdot
.6239 .6896 Mdot
.33578 .62918 Mdot
.6393 .65542 Mdot
.34372 .36596 Mdot
.6987 .3978 Mdot
.65297 .36139 Mdot
.57297 .28717 Mdot
.67256 .38729 Mdot
.70487 .42826 Mdot
.53866 .28483 Mdot
.70842 .52605 Mdot
.43198 .68716 Mdot
.69823 .41888 Mdot
.72075 .48459 Mdot
.60327 .31931 Mdot
.32664 .61772 Mdot
.71071 .47697 Mdot
.30425 .42831 Mdot
.50423 .70991 Mdot
.40177 .32106 Mdot
.33951 .65076 Mdot
.71242 .46019 Mdot
.33796 .63474 Mdot
.421 .31009 Mdot
.28744 .46675 Mdot
.5334 .28954 Mdot
.46302 .28495 Mdot
.28754 .57689 Mdot
.51486 .29918 Mdot
.68499 .39909 Mdot
.32104 .38822 Mdot
.4702 .70485 Mdot
.45292 .70918 Mdot
.33883 .6514 Mdot
.68176 .40567 Mdot
.45927 .28182 Mdot
.29171 .53029 Mdot
.70278 .46204 Mdot
.59884 .30291 Mdot
.33714 .37784 Mdot
.68512 .61498 Mdot
.50783 .28181 Mdot
.30269 .46096 Mdot
.29792 .49094 Mdot
.41468 .68597 Mdot
.55893 .71131 Mdot
.31861 .59322 Mdot
.29991 .42165 Mdot
.71725 .53138 Mdot
.34112 .3589 Mdot
.473 .71706 Mdot
.70238 .55345 Mdot
.50092 .72418 Mdot
.36265 .66348 Mdot
.5008 .27794 Mdot
.66126 .35779 Mdot
.30453 .55208 Mdot
.44511 .30463 Mdot
.67414 .63554 Mdot
.53778 .71209 Mdot
.65309 .64234 Mdot
.40764 .29777 Mdot
.67987 .40074 Mdot
.39491 .3157 Mdot
.49153 .28775 Mdot
.33977 .64481 Mdot
.69491 .588 Mdot
.30388 .46307 Mdot
.36283 .33659 Mdot
.6209 .33592 Mdot
.33257 .37538 Mdot
.4348 .28952 Mdot
.30037 .48521 Mdot
.68505 .6196 Mdot
.38583 .30545 Mdot
.29224 .55341 Mdot
.70971 .43816 Mdot
.63368 .68319 Mdot
.72095 .4397 Mdot
.3718 .31978 Mdot
.3772 .66712 Mdot
.59696 .31082 Mdot
.53295 .29875 Mdot
.57019 .72024 Mdot
.39187 .68093 Mdot
.60059 .70663 Mdot
.4895 .2706 Mdot
.49837 .29029 Mdot
.58916 .31186 Mdot
.40143 .31352 Mdot
.69415 .42031 Mdot
.67479 .62004 Mdot
.38107 .31016 Mdot
.44401 .68875 Mdot
.68894 .38895 Mdot
.59847 .68558 Mdot
.36361 .32098 Mdot
.68676 .58784 Mdot
.72751 .46293 Mdot
.3256 .63908 Mdot
.5882 .70591 Mdot
.49867 .28158 Mdot
.47429 .70229 Mdot
.45964 .27357 Mdot
.41614 .30909 Mdot
.28273 .56055 Mdot
.62287 .32664 Mdot
.4178 .6956 Mdot
.46545 .71164 Mdot
.46953 .70916 Mdot
.34807 .65325 Mdot
.71206 .44147 Mdot
.54511 .70329 Mdot
.52628 .69987 Mdot
.72 .52417 Mdot
.32807 .39747 Mdot
.36316 .65923 Mdot
.5647 .69956 Mdot
.31153 .39126 Mdot
.70491 .45102 Mdot
.39184 .66858 Mdot
.51749 .28207 Mdot
.70495 .5534 Mdot
.60469 .32596 Mdot
.62457 .3321 Mdot
.36022 .34979 Mdot
.67967 .38536 Mdot
.67876 .59237 Mdot
.3328 .35453 Mdot
.71417 .42537 Mdot
.68692 .5781 Mdot
.71486 .51856 Mdot
.55776 .28537 Mdot
.40418 .69242 Mdot
.53724 .29446 Mdot
.28478 .4754 Mdot
.72122 .50003 Mdot
.69095 .39259 Mdot
.64815 .6539 Mdot
.64724 .33991 Mdot
.31968 .40159 Mdot
.7189 .49262 Mdot
.30494 .43566 Mdot
.69898 .50689 Mdot
.59741 .31374 Mdot
.50554 .29753 Mdot
.67997 .59607 Mdot
.42466 .68409 Mdot
.62364 .67123 Mdot
.29152 .53188 Mdot
.68119 .62296 Mdot
.40479 .30084 Mdot
.2996 .43496 Mdot
.50419 .27271 Mdot
.70178 .53356 Mdot
.53302 .27971 Mdot
.46712 .71265 Mdot
.70881 .56086 Mdot
.53194 .71748 Mdot
.51399 .28622 Mdot
.66267 .62859 Mdot
.42487 .68088 Mdot
.68093 .5986 Mdot
.45178 .29313 Mdot
.3291 .36895 Mdot
.70625 .53632 Mdot
.33451 .36937 Mdot
.40775 .68216 Mdot
.31797 .61904 Mdot
.3717 .66904 Mdot
.55197 .70946 Mdot
.35243 .35435 Mdot
.63472 .65502 Mdot
.4008 .67098 Mdot
.65005 .66401 Mdot
.42676 .29213 Mdot
.31484 .43295 Mdot
.43003 .30335 Mdot
.70892 .52741 Mdot
.29002 .57309 Mdot
.41901 .29798 Mdot
.64937 .64193 Mdot
.29514 .49231 Mdot
.30481 .40874 Mdot
.33566 .62195 Mdot
.48131 .71339 Mdot
.38575 .67121 Mdot
.35717 .32753 Mdot
.5874 .30631 Mdot
.71525 .46618 Mdot
.59318 .32015 Mdot
.3291 .37075 Mdot
.54881 .71406 Mdot
.28967 .48033 Mdot
.47781 .29653 Mdot
.71915 .52398 Mdot
.32003 .61753 Mdot
.54124 .29698 Mdot
.67041 .61196 Mdot
.54543 .71049 Mdot
.3834 .67182 Mdot
.41407 .69244 Mdot
.29893 .4348 Mdot
.48689 .29544 Mdot
.36371 .65192 Mdot
.43579 .695 Mdot
.38849 .32805 Mdot
.36949 .66328 Mdot
.40875 .67966 Mdot
.33447 .37527 Mdot
.48617 .70365 Mdot
.33023 .60304 Mdot
.71406 .48983 Mdot
.59956 .68901 Mdot
.30376 .53104 Mdot
.30468 .55255 Mdot
.59216 .71027 Mdot
.52166 .72411 Mdot
.29687 .42987 Mdot
.6682 .38244 Mdot
.50315 .70576 Mdot
.34298 .65393 Mdot
.69888 .5161 Mdot
.72216 .48735 Mdot
.67167 .61974 Mdot
.62221 .32701 Mdot
.37633 .32601 Mdot
.3186 .59995 Mdot
.29705 .44328 Mdot
.48793 .7116 Mdot
.70316 .5819 Mdot
.34278 .63694 Mdot
.61272 .3209 Mdot
.68152 .6028 Mdot
.62697 .33167 Mdot
.6096 .69185 Mdot
.54245 .30007 Mdot
.38865 .66284 Mdot
.55106 .72007 Mdot
.71447 .50024 Mdot
.47916 .26893 Mdot
.52133 .29902 Mdot
.44164 .30503 Mdot
.28649 .55194 Mdot
.6985 .41979 Mdot
.33102 .61575 Mdot
.65324 .63695 Mdot
.41649 .69293 Mdot
.37598 .6558 Mdot
.71678 .49554 Mdot
.53576 .71422 Mdot
.69845 .52799 Mdot
.30691 .42499 Mdot
.40064 .68989 Mdot
.66062 .36137 Mdot
.66464 .37693 Mdot
.71687 .52527 Mdot
.30046 .41273 Mdot
.70118 .41502 Mdot
.46642 .69899 Mdot
.33089 .36774 Mdot
.37104 .66124 Mdot
.32569 .60704 Mdot
.36737 .65783 Mdot
.70005 .40611 Mdot
.66391 .63124 Mdot
.68811 .59802 Mdot
.5256 .70424 Mdot
.64973 .66531 Mdot
.49163 .28884 Mdot
.53783 .70225 Mdot
.29669 .51029 Mdot
.42478 .30622 Mdot
.5508 .72552 Mdot
.43253 .68379 Mdot
.65928 .3556 Mdot
.3076 .5595 Mdot
.56474 .30429 Mdot
.29231 .55947 Mdot
.35533 .32871 Mdot
.32511 .63291 Mdot
.69059 .40453 Mdot
.56941 .71786 Mdot
.29716 .54894 Mdot
.2999 .45573 Mdot
.4085 .68444 Mdot
.50126 .70708 Mdot
.29967 .53062 Mdot
.59593 .31916 Mdot
.43844 .30758 Mdot
.29384 .56116 Mdot
.63595 .65762 Mdot
.65033 .66346 Mdot
.4549 .70578 Mdot
.69554 .44955 Mdot
.62263 .33605 Mdot
.28685 .49579 Mdot
.33074 .37437 Mdot
.46975 .70209 Mdot
.61828 .67845 Mdot
.30201 .52756 Mdot
.29313 .52016 Mdot
.66888 .62525 Mdot
.35392 .64362 Mdot
.70844 .55875 Mdot
.60954 .69146 Mdot
.66468 .64173 Mdot
.38993 .67084 Mdot
.36936 .34128 Mdot
.58383 .29439 Mdot
.2923 .58159 Mdot
.418 .30414 Mdot
.72213 .486 Mdot
.52766 .7046 Mdot
.67815 .39664 Mdot
.65501 .36797 Mdot
.70718 .43048 Mdot
.56055 .29452 Mdot
.68882 .37983 Mdot
.30145 .52037 Mdot
.43963 .70542 Mdot
.4893 .29305 Mdot
.70128 .40725 Mdot
.64888 .66255 Mdot
.6998 .45993 Mdot
.68696 .40377 Mdot
.65309 .65908 Mdot
.69288 .58573 Mdot
.55708 .7016 Mdot
.44333 .68889 Mdot
.3525 .64409 Mdot
.67127 .35311 Mdot
.61924 .67893 Mdot
.60316 .7034 Mdot
.43819 .69903 Mdot
.68143 .592 Mdot
.36911 .66157 Mdot
.53112 .72187 Mdot
.4277 .69938 Mdot
.57962 .69719 Mdot
.65229 .65805 Mdot
.6725 .39738 Mdot
.53647 .29103 Mdot
.66237 .62715 Mdot
.38133 .33634 Mdot
.70578 .49988 Mdot
.30668 .58727 Mdot
.70035 .44533 Mdot
.66187 .622 Mdot
.57525 .29841 Mdot
.64579 .34824 Mdot
.37501 .32976 Mdot
.58623 .30342 Mdot
.50954 .29527 Mdot
.68514 .58619 Mdot
.41779 .31826 Mdot
.3121 .57111 Mdot
.50957 .28127 Mdot
.68117 .61177 Mdot
.59611 .31301 Mdot
.71345 .5236 Mdot
.6859 .61787 Mdot
.59253 .69625 Mdot
.28736 .53231 Mdot
.29661 .58362 Mdot
.49023 .28564 Mdot
.32924 .62852 Mdot
.67863 .60508 Mdot
.71257 .47368 Mdot
.32344 .62214 Mdot
.72164 .45225 Mdot
.33815 .37576 Mdot
.70372 .46645 Mdot
.32438 .39747 Mdot
.65118 .34087 Mdot
.58657 .70692 Mdot
.30583 .54103 Mdot
.29952 .53615 Mdot
.62883 .67183 Mdot
.28457 .55296 Mdot
.51571 .72765 Mdot
.67351 .60555 Mdot
.43625 .68948 Mdot
.29206 .42627 Mdot
.31783 .62951 Mdot
.71636 .50179 Mdot
.31277 .42689 Mdot
.61667 .33359 Mdot
.64878 .64596 Mdot
.28575 .56585 Mdot
.70631 .56271 Mdot
.69844 .52117 Mdot
.66592 .3553 Mdot
.7204 .50724 Mdot
.33647 .36635 Mdot
.28526 .46768 Mdot
.45986 .70662 Mdot
.30862 .43451 Mdot
.50087 .28916 Mdot
.47597 .29497 Mdot
.38713 .3263 Mdot
.37572 .65983 Mdot
.41451 .30411 Mdot
.36561 .65267 Mdot
.65585 .34447 Mdot
.31372 .5858 Mdot
.44373 .69526 Mdot
.70783 .47158 Mdot
.68301 .61189 Mdot
.30808 .55437 Mdot
.35964 .65339 Mdot
.50091 .29913 Mdot
.48038 .29295 Mdot
.28182 .5341 Mdot
.65271 .65694 Mdot
.63893 .67102 Mdot
.4073 .68975 Mdot
.48562 .28451 Mdot
.70037 .57222 Mdot
.54577 .29886 Mdot
.71331 .55418 Mdot
.31674 .62768 Mdot
.43959 .29531 Mdot
.39663 .29758 Mdot
.70596 .49171 Mdot
.53012 .70443 Mdot
.70924 .42977 Mdot
.60627 .6912 Mdot
.42557 .28968 Mdot
.30948 .55419 Mdot
.39834 .31674 Mdot
.48788 .26982 Mdot
.43944 .29601 Mdot
.3098 .61206 Mdot
.70102 .59277 Mdot
.57901 .28913 Mdot
.6687 .63129 Mdot
.33004 .36482 Mdot
.52294 .72837 Mdot
.29575 .53549 Mdot
.31832 .42107 Mdot
.70024 .55247 Mdot
.72135 .45742 Mdot
.35496 .64926 Mdot
.44661 .69708 Mdot
.70481 .53579 Mdot
.44611 .69735 Mdot
.44941 .69972 Mdot
.48414 .7139 Mdot
.50738 .28491 Mdot
.67279 .62748 Mdot
.42638 .68452 Mdot
.30697 .41262 Mdot
.38288 .67825 Mdot
.39401 .30094 Mdot
.71299 .50278 Mdot
.3216 .61408 Mdot
.70356 .49976 Mdot
.62893 .66692 Mdot
.54724 .28131 Mdot
.71327 .44331 Mdot
.6933 .57885 Mdot
.69897 .40328 Mdot
.52918 .29819 Mdot
.34428 .63299 Mdot
.29877 .49853 Mdot
.55067 .29543 Mdot
.31267 .40715 Mdot
.28927 .55679 Mdot
.33336 .37807 Mdot
.39316 .67201 Mdot
.66686 .36499 Mdot
.28648 .55497 Mdot
.62625 .33924 Mdot
.32365 .37102 Mdot
.63086 .68633 Mdot
.50832 .71693 Mdot
.40499 .29943 Mdot
.29123 .5189 Mdot
.63778 .65692 Mdot
.67176 .62693 Mdot
.32841 .36569 Mdot
.55352 .29668 Mdot
.50047 .2871 Mdot
.325 .61346 Mdot
.68139 .40401 Mdot
.66014 .35295 Mdot
.61559 .32739 Mdot
.43947 .28343 Mdot
.51458 .71548 Mdot
.4961 .7113 Mdot
.63943 .66256 Mdot
.52975 .72772 Mdot
.32966 .37607 Mdot
.29068 .54554 Mdot
.65316 .35892 Mdot
.6744 .6022 Mdot
.71644 .53862 Mdot
.46297 .70667 Mdot
.54688 .71549 Mdot
.36711 .32729 Mdot
.71059 .56168 Mdot
.32729 .59927 Mdot
.69915 .42606 Mdot
.48673 .70301 Mdot
.31024 .60983 Mdot
.65604 .34884 Mdot
.30386 .41173 Mdot
.5883 .30769 Mdot
.32817 .36096 Mdot
.33002 .3579 Mdot
.30501 .58723 Mdot
.7072 .49734 Mdot
.28933 .55589 Mdot
.34275 .36485 Mdot
.30466 .44389 Mdot
.35481 .64359 Mdot
.5633 .70916 Mdot
.31426 .40798 Mdot
.44306 .29139 Mdot
.59741 .29985 Mdot
.60664 .69374 Mdot
.45315 .71609 Mdot
.51705 .3 Mdot
.41939 .69103 Mdot
.34112 .6358 Mdot
.47591 .28889 Mdot
.64845 .35434 Mdot
.34846 .63743 Mdot
.49659 .27606 Mdot
.66631 .35714 Mdot
.68484 .58829 Mdot
.64755 .66371 Mdot
.71798 .46943 Mdot
.68934 .39746 Mdot
.51703 .71555 Mdot
.3638 .34767 Mdot
.65691 .35992 Mdot
.72302 .47081 Mdot
.69874 .54361 Mdot
.34685 .34934 Mdot
.36466 .65646 Mdot
.58062 .29062 Mdot
.4185 .67938 Mdot
.45101 .29591 Mdot
.31332 .59976 Mdot
.64334 .33978 Mdot
.49416 .72272 Mdot
.48743 .71107 Mdot
.32025 .6196 Mdot
.36783 .66689 Mdot
.32684 .62559 Mdot
.51231 .29691 Mdot
.68926 .5843 Mdot
.70169 .5276 Mdot
.52444 .29851 Mdot
.33162 .6444 Mdot
.30635 .59063 Mdot
.30594 .43498 Mdot
.50864 .71445 Mdot
.36091 .66257 Mdot
.69143 .38847 Mdot
.69714 .60046 Mdot
.30581 .44216 Mdot
.38383 .67602 Mdot
.29138 .43183 Mdot
.37754 .66898 Mdot
.57837 .29286 Mdot
.71144 .54954 Mdot
.32812 .60832 Mdot
.29687 .47992 Mdot
.51154 .71684 Mdot
.52531 .72151 Mdot
.32058 .62402 Mdot
.5318 .72363 Mdot
.66938 .36292 Mdot
.71593 .43338 Mdot
.32066 .61488 Mdot
.35938 .34558 Mdot
.39582 .30199 Mdot
.39419 .312 Mdot
.44694 .70363 Mdot
.5897 .68914 Mdot
.66201 .65435 Mdot
.70689 .53099 Mdot
.497 .29544 Mdot
.6559 .34668 Mdot
.69815 .41986 Mdot
.72031 .49489 Mdot
.32368 .37202 Mdot
.32956 .62852 Mdot
.69564 .44638 Mdot
.50268 .29807 Mdot
.49037 .28417 Mdot
.36475 .31786 Mdot
.42327 .30126 Mdot
.37864 .3208 Mdot
.71081 .46155 Mdot
.62839 .32422 Mdot
.67308 .6323 Mdot
.65367 .36559 Mdot
.30367 .40106 Mdot
.31018 .41907 Mdot
.36291 .32019 Mdot
.60644 .32141 Mdot
.69566 .41769 Mdot
.49208 .70742 Mdot
.41345 .69781 Mdot
.40354 .29837 Mdot
.34544 .64805 Mdot
.6832 .36782 Mdot
.38673 .67503 Mdot
.71558 .55548 Mdot
.61028 .31632 Mdot
.29189 .4877 Mdot
.47891 .71605 Mdot
.4388 .3052 Mdot
.37074 .65876 Mdot
.28766 .47694 Mdot
.65605 .64241 Mdot
.69213 .38419 Mdot
.58191 .29723 Mdot
.69172 .6091 Mdot
.30311 .50382 Mdot
.68072 .58739 Mdot
.47857 .28907 Mdot
.36014 .3368 Mdot
.29929 .44293 Mdot
.707 .45049 Mdot
.55101 .70633 Mdot
.29377 .47611 Mdot
.6074 .70244 Mdot
.40987 .30145 Mdot
.34604 .63286 Mdot
.39431 .30754 Mdot
.67366 .39925 Mdot
.35008 .34347 Mdot
.48556 .7194 Mdot
.70115 .52365 Mdot
.49643 .28707 Mdot
.6486 .66745 Mdot
.31512 .42184 Mdot
.36962 .33678 Mdot
.29909 .54384 Mdot
.70941 .54634 Mdot
.66065 .62892 Mdot
.29051 .58101 Mdot
.48978 .72218 Mdot
.61173 .32655 Mdot
.6989 .53158 Mdot
.61835 .3345 Mdot
.37178 .6673 Mdot
.55072 .29585 Mdot
.58705 .3072 Mdot
.59455 .68453 Mdot
.34761 .63778 Mdot
.54597 .71491 Mdot
.43414 .68512 Mdot
.6208 .32802 Mdot
.64709 .64595 Mdot
.70042 .54247 Mdot
.64517 .64492 Mdot
.55034 .70209 Mdot
.61381 .32722 Mdot
.2805 .49743 Mdot
.67913 .62123 Mdot
.37391 .66979 Mdot
.49245 .27921 Mdot
.60465 .68765 Mdot
.29146 .54449 Mdot
.32522 .6346 Mdot
.35222 .65065 Mdot
.33292 .6373 Mdot
.4661 .70631 Mdot
.55993 .71688 Mdot
.30437 .54685 Mdot
.53592 .28282 Mdot
.30584 .57469 Mdot
.31372 .5617 Mdot
.52826 .28325 Mdot
.36517 .66337 Mdot
.40013 .67096 Mdot
.71319 .55246 Mdot
.71045 .54984 Mdot
.40923 .31771 Mdot
.55021 .29714 Mdot
.30028 .42818 Mdot
.37675 .65757 Mdot
.62508 .32252 Mdot
.71881 .48686 Mdot
.3028 .59592 Mdot
.51093 .69875 Mdot
.66683 .61821 Mdot
.72347 .48191 Mdot
.64188 .65863 Mdot
.70296 .46859 Mdot
.29808 .52552 Mdot
.48464 .72059 Mdot
.71205 .49775 Mdot
.70455 .41378 Mdot
.5316 .72431 Mdot
.7026 .46462 Mdot
.64982 .33742 Mdot
.50218 .29603 Mdot
.57172 .29196 Mdot
.61248 .32688 Mdot
.43738 .299 Mdot
.66074 .37263 Mdot
.50675 .70372 Mdot
.44239 .30235 Mdot
.40759 .68497 Mdot
.6145 .32727 Mdot
.6045 .70534 Mdot
.66419 .3768 Mdot
.40372 .67019 Mdot
.59853 .68259 Mdot
.33687 .37393 Mdot
.32061 .62118 Mdot
.72601 .46531 Mdot
.29588 .44713 Mdot
.50543 .28048 Mdot
.63921 .34068 Mdot
.31107 .55563 Mdot
.69413 .56424 Mdot
.3763 .65816 Mdot
.53315 .7294 Mdot
.69245 .56707 Mdot
.69127 .60512 Mdot
.2889 .47157 Mdot
.44569 .30389 Mdot
.33706 .35339 Mdot
.51451 .71143 Mdot
.66355 .37388 Mdot
.3379 .61278 Mdot
.30259 .54203 Mdot
.29773 .59236 Mdot
.63069 .65807 Mdot
.52673 .69994 Mdot
.6222 .69378 Mdot
.53584 .70488 Mdot
.39823 .32033 Mdot
.31154 .43748 Mdot
.64754 .65311 Mdot
.33914 .64262 Mdot
.49735 .70161 Mdot
.7115 .50327 Mdot
.64425 .33152 Mdot
.3701 .3242 Mdot
.50402 .27401 Mdot
.29537 .57264 Mdot
.38645 .30528 Mdot
.51247 .71119 Mdot
.71438 .5355 Mdot
.46669 .28634 Mdot
.68767 .41134 Mdot
.3125 .60954 Mdot
.43604 .30387 Mdot
.3091 .57514 Mdot
.6709 .3861 Mdot
.64349 .33977 Mdot
.53293 .71231 Mdot
.27452 .50364 Mdot
.35861 .33923 Mdot
.45445 .70487 Mdot
.40788 .29832 Mdot
.33135 .38854 Mdot
.53729 .2926 Mdot
.5062 .70595 Mdot
.65857 .63276 Mdot
.60691 .32873 Mdot
.46532 .71583 Mdot
.7014 .56025 Mdot
.68605 .59801 Mdot
.34928 .35206 Mdot
.3048 .53357 Mdot
.31389 .61623 Mdot
.64043 .34491 Mdot
.62205 .32215 Mdot
.62126 .69053 Mdot
.35251 .34648 Mdot
.68884 .60311 Mdot
.58224 .30594 Mdot
.66156 .3478 Mdot
.61342 .31222 Mdot
.60165 .31853 Mdot
.50335 .71251 Mdot
.33925 .63343 Mdot
.68654 .39103 Mdot
.31151 .43343 Mdot
.64499 .67263 Mdot
.29952 .54105 Mdot
.30071 .44441 Mdot
.29272 .54881 Mdot
.56057 .28195 Mdot
.37722 .31769 Mdot
.69805 .47904 Mdot
.62293 .33308 Mdot
.57752 .302 Mdot
.28814 .45401 Mdot
.723 .46269 Mdot
.71834 .516 Mdot
.68915 .37996 Mdot
.31327 .40671 Mdot
.33244 .62799 Mdot
.62744 .65933 Mdot
.39674 .31133 Mdot
.31139 .42192 Mdot
.45176 .28957 Mdot
.48437 .29676 Mdot
.67874 .41371 Mdot
.47164 .699 Mdot
.70173 .53915 Mdot
.39576 .6704 Mdot
.56406 .70878 Mdot
.6082 .31639 Mdot
.65881 .34567 Mdot
.46646 .27933 Mdot
.52131 .70921 Mdot
.57512 .70349 Mdot
.32067 .37738 Mdot
.29407 .52317 Mdot
.42595 .29091 Mdot
.52918 .70639 Mdot
.42474 .2988 Mdot
.7257 .4515 Mdot
.30275 .47216 Mdot
.61315 .68036 Mdot
.46174 .28839 Mdot
.28797 .48564 Mdot
.30517 .48851 Mdot
.38185 .66592 Mdot
.70269 .47765 Mdot
.65891 .3757 Mdot
.36349 .65556 Mdot
.48343 .27253 Mdot
.49225 .27505 Mdot
.61639 .31728 Mdot
.50315 .71162 Mdot
.45295 .28761 Mdot
.31454 .4263 Mdot
.46041 .71501 Mdot
.67837 .5949 Mdot
.71193 .44707 Mdot
.61672 .69604 Mdot
.67611 .61238 Mdot
.59956 .31356 Mdot
.30506 .59169 Mdot
.6188 .69094 Mdot
.37721 .31453 Mdot
.69152 .42259 Mdot
.70619 .46203 Mdot
.3332 .6109 Mdot
.5216 .29158 Mdot
.37093 .65381 Mdot
.6655 .35125 Mdot
.48172 .70123 Mdot
.58757 .3103 Mdot
.29191 .48356 Mdot
.28534 .54078 Mdot
.30393 .59452 Mdot
.66822 .3512 Mdot
.29504 .48152 Mdot
.70663 .42563 Mdot
.63769 .66174 Mdot
.55884 .70924 Mdot
.56793 .30083 Mdot
.33366 .62801 Mdot
.31594 .42224 Mdot
.33993 .3776 Mdot
.65191 .65662 Mdot
.55344 .71084 Mdot
.52863 .28016 Mdot
.33529 .62595 Mdot
.45622 .70151 Mdot
.29303 .4644 Mdot
.58946 .68713 Mdot
.37563 .66337 Mdot
.28933 .56373 Mdot
.71935 .54046 Mdot
.68506 .394 Mdot
.28481 .55585 Mdot
.64207 .32916 Mdot
.46466 .70714 Mdot
.64828 .64701 Mdot
.6661 .38721 Mdot
.689 .38579 Mdot
.29706 .5554 Mdot
.51184 .27913 Mdot
.63862 .6525 Mdot
.39707 .66732 Mdot
.59668 .68679 Mdot
.29006 .50158 Mdot
.55179 .29581 Mdot
.44406 .29395 Mdot
.31518 .39193 Mdot
.34499 .36249 Mdot
.44137 .28986 Mdot
.53694 .28986 Mdot
.46633 .70061 Mdot
.67977 .61646 Mdot
.59338 .68813 Mdot
.54532 .28619 Mdot
.69911 .59693 Mdot
.42452 .68397 Mdot
.41667 .69141 Mdot
.40949 .29754 Mdot
.56774 .28668 Mdot
.67156 .61989 Mdot
.6461 .65218 Mdot
.32587 .63995 Mdot
.64857 .35597 Mdot
.40984 .67703 Mdot
.52498 .27734 Mdot
.34399 .35498 Mdot
.52041 .27615 Mdot
.4037 .67577 Mdot
.2947 .5209 Mdot
.46737 .28124 Mdot
.50384 .28961 Mdot
.38332 .33243 Mdot
.38543 .33093 Mdot
.3979 .66946 Mdot
.57682 .31179 Mdot
.691 .60648 Mdot
.65342 .63996 Mdot
.29339 .5075 Mdot
.32213 .59715 Mdot
.52045 .72849 Mdot
.72102 .51168 Mdot
.30105 .44489 Mdot
.45265 .70506 Mdot
.67426 .39257 Mdot
.38307 .32132 Mdot
.34048 .37359 Mdot
.6537 .35164 Mdot
.33222 .38146 Mdot
.54944 .29604 Mdot
.60436 .7066 Mdot
.3429 .62258 Mdot
.72287 .51477 Mdot
.30541 .55022 Mdot
.28745 .49333 Mdot
.5042 .71355 Mdot
.34802 .35785 Mdot
.35148 .35912 Mdot
.69806 .55208 Mdot
.58863 .30162 Mdot
.28529 .47394 Mdot
.69655 .577 Mdot
.31062 .61063 Mdot
.42032 .3069 Mdot
.27977 .53536 Mdot
.49706 .70366 Mdot
.70493 .49528 Mdot
.68456 .60633 Mdot
.28244 .56302 Mdot
.2878 .50533 Mdot
.28971 .5741 Mdot
.49785 .27614 Mdot
.72453 .49353 Mdot
.46076 .29137 Mdot
.34673 .36811 Mdot
.67809 .62731 Mdot
.55312 .70452 Mdot
.65338 .34488 Mdot
.45005 .71148 Mdot
.5842 .31534 Mdot
.68654 .37738 Mdot
.3282 .62424 Mdot
.30165 .51373 Mdot
.46473 .27577 Mdot
.31888 .42078 Mdot
.70674 .54464 Mdot
.72202 .53151 Mdot
.71157 .50638 Mdot
.61622 .31789 Mdot
.55854 .72482 Mdot
.34625 .33806 Mdot
.31149 .60688 Mdot
.5041 .2975 Mdot
.69768 .55984 Mdot
.44481 .69122 Mdot
.33466 .62739 Mdot
.50748 .29969 Mdot
.29502 .58801 Mdot
.57199 .30905 Mdot
.30022 .55474 Mdot
.70055 .54674 Mdot
.41158 .68306 Mdot
.29465 .52399 Mdot
.72004 .47595 Mdot
.49872 .29397 Mdot
.71196 .45291 Mdot
.29924 .52038 Mdot
.33611 .38382 Mdot
.4982 .29707 Mdot
.5256 .70316 Mdot
.69881 .46394 Mdot
.62932 .32653 Mdot
.71719 .51059 Mdot
.31055 .42571 Mdot
.30565 .42308 Mdot
.37494 .32221 Mdot
.60562 .32181 Mdot
.45825 .29827 Mdot
.34855 .64005 Mdot
.62215 .66477 Mdot
.38515 .33012 Mdot
.72601 .47935 Mdot
.45403 .29991 Mdot
.60947 .67791 Mdot
.53488 .29382 Mdot
.40064 .29894 Mdot
.44006 .70688 Mdot
.69465 .57195 Mdot
.28706 .5126 Mdot
.36202 .65015 Mdot
.63722 .66068 Mdot
.51401 .70064 Mdot
.30077 .49531 Mdot
.4015 .67155 Mdot
.58789 .31794 Mdot
.56545 .69663 Mdot
.6605 .6483 Mdot
.33508 .38151 Mdot
.68128 .36856 Mdot
.33467 .35611 Mdot
.30433 .57449 Mdot
.45953 .71146 Mdot
.4037 .67131 Mdot
.69982 .57878 Mdot
.68366 .36974 Mdot
.5071 .28615 Mdot
.67407 .63227 Mdot
.31939 .39714 Mdot
.702 .51943 Mdot
.70557 .5158 Mdot
.57063 .70545 Mdot
.29259 .53486 Mdot
.59934 .30346 Mdot
.47748 .71376 Mdot
.28805 .46768 Mdot
.5278 .70064 Mdot
.42532 .28884 Mdot
.30204 .42875 Mdot
.35353 .36094 Mdot
.6983 .49318 Mdot
.40006 .30058 Mdot
.70234 .57481 Mdot
.29302 .48644 Mdot
.34683 .36094 Mdot
.50847 .28468 Mdot
.30909 .59478 Mdot
.42706 .69814 Mdot
.53917 .71885 Mdot
.40793 .29693 Mdot
.42856 .31435 Mdot
.68392 .61424 Mdot
.52143 .27593 Mdot
.2745 .51822 Mdot
.4868 .29021 Mdot
.70988 .5063 Mdot
.57599 .72064 Mdot
.40545 .69194 Mdot
.56921 .29859 Mdot
.69746 .56084 Mdot
.37871 .31135 Mdot
.3032 .5746 Mdot
.72224 .49038 Mdot
.30949 .59659 Mdot
.43587 .7073 Mdot
.71253 .50872 Mdot
.31785 .39228 Mdot
.69902 .53542 Mdot
.28824 .54758 Mdot
.53604 .29752 Mdot
.41733 .31116 Mdot
.57273 .2876 Mdot
.66709 .62646 Mdot
.33076 .62684 Mdot
.58829 .70392 Mdot
.71283 .56079 Mdot
.71452 .44508 Mdot
.68778 .58876 Mdot
.28737 .57637 Mdot
.68657 .58637 Mdot
.70439 .51169 Mdot
.42528 .68034 Mdot
.38038 .65818 Mdot
.32647 .39787 Mdot
.40866 .68407 Mdot
.48693 .71196 Mdot
.59838 .68251 Mdot
.45075 .70676 Mdot
.45196 .70136 Mdot
.51014 .70722 Mdot
.6811 .39661 Mdot
.55713 .70265 Mdot
.68397 .41718 Mdot
.67181 .40084 Mdot
.34454 .36879 Mdot
.31231 .61672 Mdot
.36575 .661 Mdot
.5901 .6976 Mdot
.54207 .7174 Mdot
.71975 .45652 Mdot
.6963 .44409 Mdot
.49782 .2883 Mdot
.66305 .64195 Mdot
.3171 .41506 Mdot
.55223 .71722 Mdot
.40551 .3192 Mdot
.35328 .34883 Mdot
.39382 .66895 Mdot
.39015 .67931 Mdot
.51936 .72466 Mdot
.62056 .67489 Mdot
.44469 .69254 Mdot
.53708 .70823 Mdot
.3423 .35068 Mdot
.584 .70764 Mdot
.68423 .60258 Mdot
.69946 .50353 Mdot
.30825 .58262 Mdot
.28805 .55606 Mdot
.64799 .64723 Mdot
.58551 .71482 Mdot
.70622 .45001 Mdot
.69488 .58607 Mdot
.42738 .30954 Mdot
.64721 .3481 Mdot
.62747 .67225 Mdot
.51131 .28082 Mdot
.64426 .6737 Mdot
.53975 .28719 Mdot
.48442 .28073 Mdot
.32172 .63027 Mdot
.36906 .33284 Mdot
.45622 .71637 Mdot
.45098 .30273 Mdot
.51073 .70882 Mdot
.68566 .61432 Mdot
.33858 .6156 Mdot
.7126 .46468 Mdot
.4635 .28872 Mdot
.68058 .38556 Mdot
.71636 .51903 Mdot
.56741 .69597 Mdot
.41739 .29211 Mdot
.35271 .34104 Mdot
.27776 .52424 Mdot
.70697 .43302 Mdot
.48203 .70944 Mdot
.6979 .41147 Mdot
.66862 .36824 Mdot
.70476 .47967 Mdot
.56884 .69733 Mdot
.62268 .6848 Mdot
.49688 .70566 Mdot
.71937 .48021 Mdot
.36597 .33316 Mdot
.35181 .63718 Mdot
.52269 .71589 Mdot
.29231 .48793 Mdot
.69825 .49057 Mdot
.37199 .31756 Mdot
.59041 .70487 Mdot
.42474 .29963 Mdot
.71143 .51448 Mdot
.33199 .36134 Mdot
.54184 .29587 Mdot
.38423 .3303 Mdot
.54151 .72703 Mdot
.43875 .68821 Mdot
.70383 .51372 Mdot
.64383 .34084 Mdot
.69804 .55865 Mdot
.447 .70811 Mdot
.70147 .42129 Mdot
.35425 .35258 Mdot
.69475 .4429 Mdot
.67778 .60602 Mdot
.50464 .71975 Mdot
.30452 .55366 Mdot
.67999 .62747 Mdot
.58291 .69421 Mdot
.6603 .64933 Mdot
.33188 .63137 Mdot
.66862 .62639 Mdot
.59835 .70532 Mdot
.51656 .72542 Mdot
.31695 .39843 Mdot
.42127 .69831 Mdot
.30347 .46943 Mdot
.66683 .61362 Mdot
.64679 .67451 Mdot
.68471 .58153 Mdot
.72433 .47871 Mdot
.70511 .52276 Mdot
.35091 .35425 Mdot
.72141 .48815 Mdot
.29523 .47794 Mdot
.5992 .30358 Mdot
.72108 .51006 Mdot
.31002 .43943 Mdot
.28817 .47999 Mdot
.30122 .52127 Mdot
.29034 .56569 Mdot
.27412 .5125 Mdot
.2905 .45204 Mdot
.2849 .49407 Mdot
.70441 .42848 Mdot
.31211 .39416 Mdot
.31107 .55854 Mdot
.60109 .30502 Mdot
.30462 .47838 Mdot
.41901 .6971 Mdot
.68366 .59898 Mdot
.63483 .32959 Mdot
.43848 .28982 Mdot
.2922 .5775 Mdot
.51 .72196 Mdot
.70116 .45565 Mdot
.41211 .67844 Mdot
.30355 .5566 Mdot
.66551 .37848 Mdot
.43462 .30177 Mdot
.33347 .60872 Mdot
.29415 .54819 Mdot
.32229 .61824 Mdot
.40384 .30205 Mdot
.52803 .27651 Mdot
.42005 .69897 Mdot
.31577 .42336 Mdot
.34665 .65317 Mdot
.42165 .69932 Mdot
.70407 .43203 Mdot
.29532 .57562 Mdot
.47168 .70057 Mdot
.69979 .57473 Mdot
.67138 .36348 Mdot
.46261 .2737 Mdot
.45191 .71472 Mdot
.72132 .53035 Mdot
.69875 .4983 Mdot
.27881 .50765 Mdot
.43966 .30038 Mdot
.49409 .72173 Mdot
.60036 .30801 Mdot
.61616 .3296 Mdot
.31554 .39696 Mdot
.63823 .33472 Mdot
.46603 .29907 Mdot
.55107 .72503 Mdot
.30481 .48829 Mdot
.48771 .71809 Mdot
.3066 .39654 Mdot
.55689 .30287 Mdot
.68544 .38609 Mdot
.34816 .36549 Mdot
.62951 .68407 Mdot
.61435 .31693 Mdot
.33456 .38089 Mdot
.69992 .50707 Mdot
.6653 .38175 Mdot
.65249 .35202 Mdot
.32317 .59523 Mdot
.41969 .30273 Mdot
.66827 .39148 Mdot
.68555 .40189 Mdot
.68404 .59992 Mdot
.39653 .6735 Mdot
.7126 .49898 Mdot
.3094 .4124 Mdot
.30732 .5832 Mdot
.3224 .39125 Mdot
.31123 .42817 Mdot
.48855 .29373 Mdot
.60633 .67885 Mdot
.64963 .66015 Mdot
.40451 .69224 Mdot
.52827 .70348 Mdot
.46808 .70782 Mdot
.72127 .46207 Mdot
.37994 .67651 Mdot
.3172 .58465 Mdot
.70386 .42955 Mdot
.68846 .39607 Mdot
.32108 .60101 Mdot
.55661 .71693 Mdot
.46325 .70011 Mdot
.63268 .68296 Mdot
.70186 .53666 Mdot
.70972 .42703 Mdot
.59907 .30966 Mdot
.69807 .49899 Mdot
.29641 .42481 Mdot
.36144 .32295 Mdot
.36611 .33858 Mdot
.50589 .2936 Mdot
.4392 .71019 Mdot
.34845 .34392 Mdot
.71001 .55675 Mdot
.29434 .43141 Mdot
.70525 .55264 Mdot
.36437 .34817 Mdot
.44989 .70982 Mdot
.4317 .28413 Mdot
.56756 .28425 Mdot
.67094 .60808 Mdot
.57448 .71497 Mdot
.31743 .62076 Mdot
.72214 .463 Mdot
.57132 .30615 Mdot
.72447 .49759 Mdot
.40549 .67653 Mdot
.71118 .48484 Mdot
.46951 .28921 Mdot
.53789 .28518 Mdot
.67079 .61562 Mdot
.70666 .56107 Mdot
.70064 .54127 Mdot
.70052 .40141 Mdot
.43867 .29963 Mdot
.70388 .47586 Mdot
.6777 .40394 Mdot
.69298 .57328 Mdot
.38735 .30602 Mdot
.63939 .67252 Mdot
.71637 .46227 Mdot
.34835 .62971 Mdot
.66925 .38353 Mdot
.31948 .60098 Mdot
.66006 .37869 Mdot
.31118 .41916 Mdot
.46976 .71289 Mdot
.34191 .37061 Mdot
.34564 .64626 Mdot
.33984 .34567 Mdot
.5451 .2873 Mdot
.30088 .48345 Mdot
.60984 .33023 Mdot
.61886 .67198 Mdot
.71763 .51297 Mdot
.57897 .29273 Mdot
.64027 .67223 Mdot
.46946 .70639 Mdot
.6583 .37586 Mdot
.42891 .30699 Mdot
.32553 .38321 Mdot
.62989 .66557 Mdot
.66663 .35121 Mdot
.38528 .33377 Mdot
.69795 .59131 Mdot
.30863 .40177 Mdot
.66938 .60829 Mdot
.61227 .31135 Mdot
.70381 .52779 Mdot
.32616 .3815 Mdot
.61671 .67527 Mdot
.68372 .40931 Mdot
.35642 .3338 Mdot
.57943 .31408 Mdot
.59609 .30471 Mdot
.52621 .73028 Mdot
.59925 .30141 Mdot
.41305 .31642 Mdot
.51969 .27545 Mdot
.67174 .39527 Mdot
.53262 .28464 Mdot
.32871 .62886 Mdot
.37224 .32891 Mdot
.29316 .50563 Mdot
.6855 .60854 Mdot
.44839 .29647 Mdot
.39589 .68488 Mdot
.30654 .43218 Mdot
.30705 .39984 Mdot
.66246 .37571 Mdot
.66635 .34931 Mdot
.71162 .56759 Mdot
.63379 .66245 Mdot
.4185 .30828 Mdot
.30133 .4131 Mdot
.54182 .70101 Mdot
.30278 .49202 Mdot
.31641 .39257 Mdot
.50983 .70336 Mdot
.69254 .58342 Mdot
.49203 .28958 Mdot
.56904 .70413 Mdot
.68939 .41605 Mdot
.54721 .70921 Mdot
.59062 .31864 Mdot
.32085 .37468 Mdot
.40313 .67376 Mdot
.31551 .61899 Mdot
.62268 .33654 Mdot
.62027 .3345 Mdot
.39799 .2981 Mdot
.6373 .33228 Mdot
.71645 .45016 Mdot
.42549 .30074 Mdot
.69493 .57353 Mdot
.29863 .49374 Mdot
.49299 .70391 Mdot
.70807 .47262 Mdot
.72452 .49674 Mdot
.37163 .32937 Mdot
.59915 .70669 Mdot
.59244 .31562 Mdot
.30418 .40368 Mdot
.70586 .54879 Mdot
.36871 .33649 Mdot
.30736 .60931 Mdot
.37611 .30993 Mdot
.70598 .42157 Mdot
.302 .59083 Mdot
.70979 .48295 Mdot
.28266 .49548 Mdot
.30912 .61236 Mdot
.32292 .63224 Mdot
.34205 .35254 Mdot
.67864 .36259 Mdot
.34291 .36813 Mdot
.45643 .70884 Mdot
.48605 .70352 Mdot
.42683 .29422 Mdot
.33113 .62417 Mdot
.38758 .68204 Mdot
.31666 .5762 Mdot
.64633 .34928 Mdot
.66476 .61856 Mdot
.30377 .43685 Mdot
.3057 .43233 Mdot
.47034 .28577 Mdot
.70168 .45961 Mdot
.289 .47653 Mdot
.53542 .27939 Mdot
.6195 .33718 Mdot
.32721 .61347 Mdot
.32751 .39867 Mdot
.70646 .4931 Mdot
.55008 .28377 Mdot
.68424 .41051 Mdot
.47703 .70784 Mdot
.28425 .5652 Mdot
.32209 .41138 Mdot
.28413 .48207 Mdot
.64323 .65699 Mdot
.57365 .28829 Mdot
.42997 .68942 Mdot
.30655 .58834 Mdot
.50222 .2924 Mdot
.3061 .55264 Mdot
.70417 .55038 Mdot
.32413 .37164 Mdot
.61627 .31384 Mdot
.53431 .72972 Mdot
.43286 .70685 Mdot
.48709 .29447 Mdot
.5619 .71753 Mdot
.70144 .50585 Mdot
.67967 .40163 Mdot
.37705 .31856 Mdot
.56946 .69689 Mdot
.53266 .71702 Mdot
.52335 .71837 Mdot
.42661 .29628 Mdot
.2907 .54951 Mdot
.29486 .44 Mdot
.52015 .71982 Mdot
.60117 .31363 Mdot
.68646 .57885 Mdot
.62547 .3322 Mdot
.54535 .72526 Mdot
.46819 .71409 Mdot
.70788 .55793 Mdot
.68173 .5958 Mdot
.61051 .3302 Mdot
.2914 .55493 Mdot
.29599 .55436 Mdot
.72556 .47805 Mdot
.43667 .70484 Mdot
.5868 .69688 Mdot
.47917 .71511 Mdot
.31865 .62318 Mdot
.66256 .65609 Mdot
.61056 .67508 Mdot
.6598 .6363 Mdot
.62267 .68841 Mdot
.44403 .69435 Mdot
.47534 .29136 Mdot
.68928 .39108 Mdot
.58566 .31087 Mdot
.41553 .29075 Mdot
.39536 .3284 Mdot
.30652 .5586 Mdot
.3981 .67006 Mdot
.3369 .61857 Mdot
.56069 .70003 Mdot
.35449 .6625 Mdot
.64879 .6493 Mdot
.67352 .62419 Mdot
.32666 .59656 Mdot
.4872 .72099 Mdot
.39999 .30278 Mdot
.35631 .32487 Mdot
.71133 .5494 Mdot
.53938 .72691 Mdot
.47561 .28026 Mdot
.61731 .32316 Mdot
.30336 .42906 Mdot
.29699 .43091 Mdot
.30329 .55138 Mdot
.30256 .52491 Mdot
.68562 .58697 Mdot
.44904 .69312 Mdot
.29339 .54021 Mdot
.4659 .29702 Mdot
.28359 .49121 Mdot
.32093 .40327 Mdot
.56708 .3027 Mdot
.57734 .29574 Mdot
.40698 .68613 Mdot
.39743 .6885 Mdot
.67268 .37273 Mdot
.6624 .34527 Mdot
.62646 .33594 Mdot
.33489 .35592 Mdot
.28489 .5506 Mdot
.69492 .39996 Mdot
.69984 .47777 Mdot
.34951 .64988 Mdot
.49231 .72 Mdot
.35588 .33038 Mdot
.7008 .44797 Mdot
.33818 .64886 Mdot
.63874 .67208 Mdot
.30462 .40506 Mdot
.42183 .68761 Mdot
.72205 .53586 Mdot
.69216 .40688 Mdot
.63551 .65868 Mdot
.71528 .46172 Mdot
.60781 .31634 Mdot
.55084 .28792 Mdot
.46709 .71525 Mdot
.63089 .33475 Mdot
.72479 .44917 Mdot
.55539 .28586 Mdot
.32456 .59548 Mdot
.2952 .49408 Mdot
.30563 .54417 Mdot
.37416 .31795 Mdot
.31853 .6255 Mdot
.4515 .29793 Mdot
.33133 .38443 Mdot
.71226 .4944 Mdot
.33493 .62736 Mdot
.60115 .68198 Mdot
.29212 .49501 Mdot
.30296 .56019 Mdot
.65935 .63884 Mdot
.72177 .52366 Mdot
.40343 .31611 Mdot
.34058 .6252 Mdot
.38308 .66695 Mdot
.5054 .27185 Mdot
.53788 .29798 Mdot
.55255 .29316 Mdot
.28745 .55087 Mdot
.37546 .32972 Mdot
.70625 .47718 Mdot
.53711 .70141 Mdot
.71367 .426 Mdot
.46746 .69852 Mdot
.43332 .69979 Mdot
.7189 .43992 Mdot
.70644 .47529 Mdot
.46857 .71696 Mdot
.53185 .70427 Mdot
.29426 .48756 Mdot
.61702 .327 Mdot
.65827 .36973 Mdot
.6591 .36875 Mdot
.42524 .31442 Mdot
.70213 .51562 Mdot
.27536 .52017 Mdot
.54981 .29035 Mdot
.31485 .42772 Mdot
.60259 .3214 Mdot
.3692 .65639 Mdot
.36098 .34849 Mdot
.69437 .4013 Mdot
.63716 .33399 Mdot
.699 .58155 Mdot
.71189 .49881 Mdot
.32665 .62427 Mdot
.70638 .51694 Mdot
.71711 .48316 Mdot
.43222 .70346 Mdot
.29308 .55235 Mdot
.28641 .50158 Mdot
.64594 .65484 Mdot
.67185 .37206 Mdot
.46509 .70832 Mdot
.67085 .63209 Mdot
.44781 .71148 Mdot
.63742 .65768 Mdot
.67517 .39592 Mdot
.57804 .7163 Mdot
.71307 .50297 Mdot
.67052 .40194 Mdot
.32296 .40832 Mdot
.29088 .49968 Mdot
.29059 .47072 Mdot
.4002 .29556 Mdot
.47354 .70124 Mdot
.33712 .37617 Mdot
.69165 .57973 Mdot
.30251 .50535 Mdot
.59754 .68191 Mdot
.35159 .64257 Mdot
.51403 .70918 Mdot
.29709 .5191 Mdot
.43053 .30408 Mdot
.7023 .57615 Mdot
.50414 .7137 Mdot
.28817 .55926 Mdot
.70805 .49971 Mdot
.66092 .35523 Mdot
.70239 .4601 Mdot
.32178 .60978 Mdot
.59342 .31891 Mdot
.69126 .58251 Mdot
.37947 .31478 Mdot
.34172 .37227 Mdot
.7091 .4837 Mdot
.34951 .35223 Mdot
.58578 .29721 Mdot
.50972 .71681 Mdot
.6136 .32541 Mdot
.34537 .62963 Mdot
.66696 .37918 Mdot
.70259 .56927 Mdot
.66159 .62638 Mdot
.70464 .52318 Mdot
.29899 .47687 Mdot
.31222 .57354 Mdot
.32153 .37132 Mdot
.6766 .36746 Mdot
.58277 .3127 Mdot
.40974 .32041 Mdot
.70767 .56361 Mdot
.36159 .66754 Mdot
.59395 .70009 Mdot
.39709 .67216 Mdot
.66625 .62808 Mdot
.3889 .6625 Mdot
.34749 .36818 Mdot
.72487 .47014 Mdot
.67473 .60046 Mdot
.65372 .63892 Mdot
.39029 .682 Mdot
.30789 .54704 Mdot
.42156 .68071 Mdot
.59571 .68598 Mdot
.54154 .72227 Mdot
.68988 .38827 Mdot
.6312 .6628 Mdot
.32007 .38184 Mdot
.31254 .42775 Mdot
.41557 .2908 Mdot
.30133 .4982 Mdot
.32723 .36871 Mdot
.5222 .70425 Mdot
.60555 .70055 Mdot
.69064 .43491 Mdot
.71379 .53486 Mdot
.57361 .30095 Mdot
.58713 .71351 Mdot
.42904 .30903 Mdot
.35364 .35754 Mdot
.55644 .72845 Mdot
.70078 .50112 Mdot
.47869 .27123 Mdot
.29516 .53198 Mdot
.29239 .46651 Mdot
.34611 .64757 Mdot
.33177 .3685 Mdot
.30466 .59971 Mdot
.5952 .3171 Mdot
.42228 .70272 Mdot
.60988 .67565 Mdot
.45185 .27866 Mdot
.6992 .52545 Mdot
.48945 .27557 Mdot
.36895 .65582 Mdot
.44142 .69736 Mdot
.67921 .38712 Mdot
.72197 .49114 Mdot
.34371 .65266 Mdot
.33893 .38194 Mdot
.3151 .40353 Mdot
.36856 .65168 Mdot
.29854 .56671 Mdot
.46154 .2963 Mdot
.30029 .56053 Mdot
.69907 .56755 Mdot
.65 .64606 Mdot
.54143 .30047 Mdot
.45214 .70795 Mdot
.63842 .34551 Mdot
.72482 .47647 Mdot
.44794 .69431 Mdot
.30928 .58066 Mdot
.69869 .44729 Mdot
.70303 .58011 Mdot
.41797 .70038 Mdot
.3654 .33313 Mdot
.44748 .70325 Mdot
.30659 .43503 Mdot
.29704 .45448 Mdot
.39435 .67569 Mdot
.43466 .30002 Mdot
.30207 .59005 Mdot
.31104 .58015 Mdot
.70685 .52862 Mdot
.30067 .49782 Mdot
.70853 .54425 Mdot
.48797 .70209 Mdot
.32274 .5936 Mdot
.70444 .56161 Mdot
.71237 .4285 Mdot
.30933 .4447 Mdot
.36547 .33956 Mdot
.68756 .39504 Mdot
.45639 .70577 Mdot
.29555 .48864 Mdot
.4534 .69626 Mdot
.70163 .54161 Mdot
.40502 .6816 Mdot
.55994 .30201 Mdot
.69457 .41684 Mdot
.59169 .31032 Mdot
.69924 .5794 Mdot
.42475 .69011 Mdot
.30014 .5602 Mdot
.28392 .5418 Mdot
.5096 .722 Mdot
.70967 .4805 Mdot
.71971 .47657 Mdot
.70255 .47223 Mdot
.4111 .31893 Mdot
.55392 .70048 Mdot
.58921 .30526 Mdot
.29208 .54765 Mdot
.60408 .30567 Mdot
.58902 .69008 Mdot
.32087 .61212 Mdot
.54577 .29482 Mdot
.50906 .71945 Mdot
.65274 .33941 Mdot
.45342 .69445 Mdot
.69249 .39866 Mdot
.40382 .29449 Mdot
.48594 .2761 Mdot
.66704 .36995 Mdot
.43527 .68791 Mdot
.64156 .65945 Mdot
.61705 .66762 Mdot
.56067 .28753 Mdot
.29283 .57316 Mdot
.32745 .40056 Mdot
.36053 .32662 Mdot
.3566 .6649 Mdot
.49596 .29716 Mdot
.50401 .27198 Mdot
.67767 .60611 Mdot
.67741 .37274 Mdot
.57446 .3059 Mdot
.55538 .2969 Mdot
.41445 .31474 Mdot
.68961 .5936 Mdot
.41775 .68681 Mdot
.29566 .4763 Mdot
.49979 .27922 Mdot
.52799 .71803 Mdot
.71163 .53688 Mdot
.29765 .44034 Mdot
.70599 .46074 Mdot
.45624 .27528 Mdot
.57769 .69295 Mdot
.7153 .44511 Mdot
.30953 .40056 Mdot
.66988 .39324 Mdot
.4506 .69935 Mdot
.28761 .53856 Mdot
.33932 .35841 Mdot
.48077 .70021 Mdot
.35028 .36403 Mdot
.56615 .29519 Mdot
.45734 .27875 Mdot
.62334 .67951 Mdot
.29911 .42057 Mdot
.47429 .7181 Mdot
.71037 .56821 Mdot
.3368 .64448 Mdot
.55734 .2904 Mdot
.68786 .42642 Mdot
.49912 .72273 Mdot
.43737 .31006 Mdot
.38392 .3072 Mdot
.71472 .46698 Mdot
.70155 .46446 Mdot
.67913 .36313 Mdot
.29187 .512 Mdot
.38478 .33269 Mdot
.29484 .4902 Mdot
.38173 .66559 Mdot
.55319 .28483 Mdot
.31166 .58066 Mdot
.33121 .36224 Mdot
.51362 .29467 Mdot
.72161 .52402 Mdot
.63963 .33479 Mdot
.69518 .59739 Mdot
.71131 .55402 Mdot
.34265 .35921 Mdot
.31616 .60997 Mdot
.63538 .65568 Mdot
.67211 .61547 Mdot
.31894 .59757 Mdot
.4191 .31506 Mdot
.66302 .35977 Mdot
.72173 .4957 Mdot
.69577 .41775 Mdot
.60638 .68075 Mdot
.6992 .41524 Mdot
.56503 .70996 Mdot
.38441 .66361 Mdot
.63499 .33273 Mdot
.52017 .70063 Mdot
.55686 .29644 Mdot
.67859 .36928 Mdot
.63657 .65808 Mdot
.70093 .55277 Mdot
.55207 .71008 Mdot
.59495 .70783 Mdot
.68096 .59253 Mdot
.47309 .70096 Mdot
.71302 .43397 Mdot
.7247 .49605 Mdot
.64807 .6444 Mdot
.54842 .28039 Mdot
.32269 .62497 Mdot
.67562 .40234 Mdot
.44315 .70166 Mdot
.71692 .43681 Mdot
.65696 .6392 Mdot
.56577 .30614 Mdot
.68464 .58464 Mdot
.32256 .37355 Mdot
.57585 .7042 Mdot
.39588 .30068 Mdot
.6671 .6218 Mdot
.72127 .4409 Mdot
.529 .28854 Mdot
.69982 .58494 Mdot
.29064 .433 Mdot
.59158 .71253 Mdot
.28616 .53955 Mdot
.31332 .61476 Mdot
.30222 .58526 Mdot
.60558 .32876 Mdot
.47974 .70348 Mdot
.52305 .70278 Mdot
.50863 .72544 Mdot
.37785 .66062 Mdot
.29126 .49727 Mdot
.36518 .65772 Mdot
.70912 .52954 Mdot
.50416 .71018 Mdot
.34793 .34226 Mdot
.68368 .39095 Mdot
.53637 .706 Mdot
.66972 .62653 Mdot
.72021 .53829 Mdot
.67058 .37111 Mdot
.63596 .326 Mdot
.31609 .41674 Mdot
.33604 .63619 Mdot
.45668 .71335 Mdot
.34776 .62773 Mdot
.69444 .57808 Mdot
.60793 .32487 Mdot
.5354 .72676 Mdot
.37023 .34269 Mdot
.62423 .66873 Mdot
.41488 .31683 Mdot
.40078 .68491 Mdot
.66312 .37748 Mdot
.55414 .29091 Mdot
.31801 .39325 Mdot
.31577 .39479 Mdot
.53369 .72073 Mdot
.30751 .42965 Mdot
.32426 .60738 Mdot
.32575 .61629 Mdot
.5643 .29894 Mdot
.45512 .69974 Mdot
.6271 .66452 Mdot
.7075 .53958 Mdot
.47484 .69836 Mdot
.41718 .69864 Mdot
.51504 .29076 Mdot
.5077 .2941 Mdot
.33594 .35873 Mdot
.46015 .71581 Mdot
.52705 .71263 Mdot
.67259 .37965 Mdot
.30702 .55211 Mdot
.37112 .34078 Mdot
.32953 .64337 Mdot
.41489 .30069 Mdot
.64198 .67641 Mdot
.29216 .56811 Mdot
.3235 .61357 Mdot
.4566 .28866 Mdot
.64626 .33849 Mdot
.29195 .48549 Mdot
.39362 .318 Mdot
.36725 .34185 Mdot
.52541 .70563 Mdot
.69835 .52886 Mdot
.678 .40078 Mdot
.32063 .60574 Mdot
.62444 .33335 Mdot
.71022 .55648 Mdot
.28677 .47563 Mdot
.37252 .6604 Mdot
.40818 .32185 Mdot
.69221 .39608 Mdot
.68473 .60893 Mdot
.4248 .6945 Mdot
.65985 .35529 Mdot
.42188 .69145 Mdot
.70377 .47843 Mdot
.6769 .40693 Mdot
.55616 .72567 Mdot
.70585 .44479 Mdot
.46219 .2987 Mdot
.36028 .3515 Mdot
.68087 .58721 Mdot
.54403 .29553 Mdot
.69358 .57682 Mdot
.29819 .43112 Mdot
.49505 .71876 Mdot
.48463 .7004 Mdot
.44073 .70182 Mdot
.3099 .61221 Mdot
.61684 .69066 Mdot
.28428 .51256 Mdot
.28635 .53742 Mdot
.66779 .36216 Mdot
.30293 .58951 Mdot
.64232 .65658 Mdot
.33524 .62396 Mdot
.37613 .32 Mdot
.53785 .71853 Mdot
.31835 .60693 Mdot
.72308 .49385 Mdot
.69106 .59441 Mdot
.64097 .34657 Mdot
.37442 .31026 Mdot
.29162 .53745 Mdot
.5681 .29732 Mdot
.6662 .64332 Mdot
.43791 .30571 Mdot
.49412 .28411 Mdot
.65231 .65372 Mdot
.31882 .37679 Mdot
.53861 .27819 Mdot
.36091 .35166 Mdot
.48583 .28649 Mdot
.60944 .31342 Mdot
.62052 .67589 Mdot
.33596 .62475 Mdot
.3037 .60105 Mdot
.36887 .66223 Mdot
.50201 .27687 Mdot
.37061 .34328 Mdot
.38515 .32588 Mdot
.6519 .64045 Mdot
.7003 .43588 Mdot
.30527 .48465 Mdot
.45194 .71443 Mdot
.4969 .2925 Mdot
.61394 .68809 Mdot
.30356 .59874 Mdot
.57934 .29771 Mdot
.66968 .61973 Mdot
.65057 .66696 Mdot
.29237 .51731 Mdot
.28723 .49309 Mdot
.33905 .62415 Mdot
.32255 .3984 Mdot
.66924 .39076 Mdot
.35392 .64941 Mdot
.51775 .72742 Mdot
.45262 .71024 Mdot
.60861 .32916 Mdot
.30043 .5007 Mdot
.5876 .30133 Mdot
.30784 .57078 Mdot
.36443 .65699 Mdot
.71349 .51758 Mdot
.70128 .48531 Mdot
.29997 .5506 Mdot
.63061 .68681 Mdot
.62115 .69424 Mdot
.68834 .43121 Mdot
.66765 .38564 Mdot
.60087 .708 Mdot
.31758 .58069 Mdot
.34354 .6321 Mdot
.70132 .58367 Mdot
.67613 .6263 Mdot
.67826 .59873 Mdot
.64093 .67001 Mdot
.42184 .29126 Mdot
.70299 .5731 Mdot
.32528 .36936 Mdot
.63844 .67197 Mdot
.46947 .27765 Mdot
.713 .54692 Mdot
.41292 .68703 Mdot
.40151 .3083 Mdot
.40204 .68502 Mdot
.36803 .32421 Mdot
.46359 .70859 Mdot
.30642 .39643 Mdot
.37945 .3149 Mdot
.30857 .42981 Mdot
.65658 .65898 Mdot
.28455 .51084 Mdot
.31711 .58707 Mdot
.28891 .46421 Mdot
.5872 .705 Mdot
.66123 .36167 Mdot
.69732 .40602 Mdot
.42232 .69362 Mdot
.40739 .31736 Mdot
.56909 .29295 Mdot
.6725 .61814 Mdot
.46846 .70444 Mdot
.70667 .55555 Mdot
.6391 .33334 Mdot
.36816 .33146 Mdot
.3144 .61898 Mdot
.28968 .45598 Mdot
.30153 .42572 Mdot
.36422 .34653 Mdot
.41187 .6963 Mdot
.71875 .53925 Mdot
.30423 .43906 Mdot
.71018 .45246 Mdot
.38598 .6804 Mdot
.72042 .49102 Mdot
.30093 .49131 Mdot
.34526 .64184 Mdot
.59557 .69083 Mdot
.68401 .39886 Mdot
.42502 .29645 Mdot
.42299 .68777 Mdot
.29053 .56327 Mdot
.36878 .66219 Mdot
.68962 .41417 Mdot
.32331 .59372 Mdot
.39031 .31707 Mdot
.29632 .49814 Mdot
.5856 .69638 Mdot
.57545 .7194 Mdot
.69596 .60365 Mdot
.42913 .6921 Mdot
.32036 .60162 Mdot
.69778 .52428 Mdot
.70823 .55363 Mdot
.48761 .28181 Mdot
.63504 .6617 Mdot
.38531 .66881 Mdot
.29282 .43608 Mdot
.64671 .35184 Mdot
.33033 .62984 Mdot
.49477 .29201 Mdot
.3354 .63822 Mdot
.28603 .47877 Mdot
.70334 .4919 Mdot
.28921 .47162 Mdot
.71025 .53988 Mdot
.57628 .30623 Mdot
.67973 .40134 Mdot
.2916 .44708 Mdot
.29758 .56403 Mdot
.43024 .29326 Mdot
.65614 .66097 Mdot
.71295 .47353 Mdot
.5249 .29395 Mdot
.29485 .4484 Mdot
.56475 .30483 Mdot
.68589 .6155 Mdot
.61851 .32667 Mdot
.42369 .6946 Mdot
.6967 .43904 Mdot
.61465 .31703 Mdot
.3132 .40129 Mdot
.59747 .68534 Mdot
.28975 .4678 Mdot
.47681 .71243 Mdot
.54185 .29073 Mdot
.56527 .28416 Mdot
.70767 .50943 Mdot
.48442 .29553 Mdot
.51716 .72698 Mdot
.29306 .49494 Mdot
.41749 .69462 Mdot
.48345 .27872 Mdot
.51235 .29808 Mdot
.32456 .38695 Mdot
.42489 .68672 Mdot
.32258 .62946 Mdot
.3259 .37012 Mdot
.39048 .30419 Mdot
.35121 .34974 Mdot
.71887 .4444 Mdot
.29494 .54938 Mdot
.2905 .51774 Mdot
.53477 .72372 Mdot
.59278 .30288 Mdot
.28474 .51373 Mdot
.49232 .70561 Mdot
.56173 .70681 Mdot
.69574 .41876 Mdot
.39959 .31224 Mdot
.39042 .67454 Mdot
.67723 .59338 Mdot
.28616 .55723 Mdot
.42075 .30196 Mdot
.70785 .49746 Mdot
.29213 .4429 Mdot
.49847 .71372 Mdot
.67564 .60524 Mdot
.70468 .52466 Mdot
.72056 .4372 Mdot
.62151 .68941 Mdot
.41897 .68953 Mdot
.61648 .3311 Mdot
.54207 .66275 Mdot
.37446 .5731 Mdot
.44403 .47292 Mdot
.30289 .51008 Mdot
.59675 .5676 Mdot
.48829 .64237 Mdot
.67513 .59194 Mdot
.48669 .57797 Mdot
.57346 .69093 Mdot
.54469 .61791 Mdot
.62556 .41813 Mdot
.46245 .53663 Mdot
.44945 .31653 Mdot
.66784 .47389 Mdot
.63004 .64019 Mdot
.33412 .48768 Mdot
.66985 .52672 Mdot
.51418 .62498 Mdot
.67261 .46841 Mdot
.60536 .46122 Mdot
.55993 .33004 Mdot
.52771 .30468 Mdot
.60283 .41352 Mdot
.36136 .63534 Mdot
.55352 .6451 Mdot
.4005 .58933 Mdot
.64727 .58297 Mdot
.63042 .37996 Mdot
.67181 .60089 Mdot
.4037 .38017 Mdot
.61535 .57225 Mdot
.45148 .37836 Mdot
.46213 .66096 Mdot
.62773 .44705 Mdot
.39475 .58258 Mdot
.37268 .42853 Mdot
.54688 .69014 Mdot
.54049 .58778 Mdot
.59507 .59221 Mdot
.44739 .63456 Mdot
.6222 .55444 Mdot
.43636 .31299 Mdot
.69624 .5032 Mdot
.67685 .48738 Mdot
.44668 .36269 Mdot
.63855 .5422 Mdot
.48633 .57891 Mdot
.30577 .50817 Mdot
.59829 .56099 Mdot
.45719 .68264 Mdot
.69211 .48221 Mdot
.64797 .46817 Mdot
.63953 .40186 Mdot
.46511 .64696 Mdot
.65408 .4226 Mdot
.43447 .66476 Mdot
.51953 .62745 Mdot
.49674 .64607 Mdot
.6064 .45584 Mdot
.53828 .35187 Mdot
.65147 .36262 Mdot
.33744 .48603 Mdot
.56409 .43845 Mdot
.40018 .47106 Mdot
.65354 .48692 Mdot
.49778 .67572 Mdot
.66554 .58779 Mdot
.69126 .45992 Mdot
.58355 .35555 Mdot
.4425 .34642 Mdot
.60967 .4057 Mdot
.57193 .44196 Mdot
.64092 .53222 Mdot
.3782 .60206 Mdot
.58098 .60893 Mdot
.57837 .37758 Mdot
.58735 .67301 Mdot
.35615 .40243 Mdot
.54169 .52401 Mdot
.39016 .35313 Mdot
.48566 .65196 Mdot
.61554 .46085 Mdot
.44079 .56203 Mdot
.60121 .53137 Mdot
.3968 .64389 Mdot
.41527 .34984 Mdot
.55564 .64408 Mdot
.55483 .38092 Mdot
.66623 .53567 Mdot
.52188 .66752 Mdot
.65311 .43136 Mdot
.35158 .38441 Mdot
.44565 .41304 Mdot
.39692 .36494 Mdot
.49349 .57208 Mdot
.37328 .41446 Mdot
.627 .44436 Mdot
.67436 .43048 Mdot
.51043 .30704 Mdot
.62992 .60746 Mdot
.46755 .36857 Mdot
.65703 .37993 Mdot
.5403 .32316 Mdot
.48588 .60388 Mdot
.61991 .61907 Mdot
.39861 .37025 Mdot
.59084 .36351 Mdot
.5871 .52431 Mdot
.59516 .43195 Mdot
.59228 .58863 Mdot
.57115 .61565 Mdot
.67424 .52458 Mdot
.30314 .52119 Mdot
.60696 .6466 Mdot
.43944 .38138 Mdot
.60914 .37552 Mdot
.33763 .43531 Mdot
.50654 .69825 Mdot
.47055 .38697 Mdot
.57528 .68473 Mdot
.50938 .47195 Mdot
.66458 .55952 Mdot
.38961 .35767 Mdot
.68506 .57712 Mdot
.56945 .6712 Mdot
.60191 .41069 Mdot
.35201 .48988 Mdot
.67956 .53706 Mdot
.67533 .45955 Mdot
.56725 .32736 Mdot
.5052 .66205 Mdot
.37997 .35088 Mdot
.35041 .55473 Mdot
.40117 .44493 Mdot
.57411 .32567 Mdot
.39081 .46718 Mdot
.43426 .43839 Mdot
.41208 .32894 Mdot
.63379 .61539 Mdot
.4311 .42229 Mdot
.5974 .67585 Mdot
.57082 .37079 Mdot
.6202 .41309 Mdot
.552 .65707 Mdot
.31483 .53358 Mdot
.401 .40064 Mdot
.45596 .439 Mdot
.5956 .54604 Mdot
.6848 .57356 Mdot
.39635 .56379 Mdot
.62053 .43677 Mdot
.51787 .40653 Mdot
.52384 .35622 Mdot
.67372 .4537 Mdot
.65726 .38135 Mdot
.49903 .3823 Mdot
.42184 .54939 Mdot
.61959 .65217 Mdot
.50544 .42369 Mdot
.66579 .56797 Mdot
.48855 .41001 Mdot
.40179 .378 Mdot
.57542 .32968 Mdot
.58788 .38324 Mdot
.64585 .53026 Mdot
.64228 .40281 Mdot
.58494 .62964 Mdot
.59219 .62819 Mdot
.49149 .36228 Mdot
.66701 .52482 Mdot
.62564 .47766 Mdot
.68929 .47698 Mdot
.51237 .61173 Mdot
.43428 .628 Mdot
.36951 .55925 Mdot
.43794 .5136 Mdot
.32291 .58533 Mdot
.37251 .43551 Mdot
.50943 .66538 Mdot
.32135 .56948 Mdot
.3775 .49884 Mdot
.38897 .58171 Mdot
.31757 .42959 Mdot
.35963 .55986 Mdot
.45279 .6774 Mdot
.56534 .54671 Mdot
.59211 .37921 Mdot
.46012 .45704 Mdot
.35917 .54434 Mdot
.65611 .57085 Mdot
.53912 .68965 Mdot
.39265 .35717 Mdot
.45627 .33391 Mdot
.51453 .64209 Mdot
.57964 .65837 Mdot
.5794 .32168 Mdot
.64556 .38417 Mdot
.44697 .31994 Mdot
.64646 .52921 Mdot
.66804 .58019 Mdot
.34335 .37757 Mdot
.60871 .49353 Mdot
.43785 .57348 Mdot
.40772 .62164 Mdot
.42198 .35962 Mdot
.57496 .56037 Mdot
.31386 .48975 Mdot
.46134 .61114 Mdot
.44101 .45507 Mdot
.39229 .39894 Mdot
.35199 .41805 Mdot
.34819 .43831 Mdot
.67394 .50001 Mdot
.36369 .44213 Mdot
.38876 .37841 Mdot
.52634 .69792 Mdot
.56629 .47976 Mdot
.64921 .62619 Mdot
.39594 .5222 Mdot
.54155 .32898 Mdot
.5625 .4237 Mdot
.56643 .61075 Mdot
.46636 .64801 Mdot
.37141 .38295 Mdot
.44649 .6746 Mdot
.61581 .53634 Mdot
.43629 .38776 Mdot
.56621 .39363 Mdot
.46458 .38235 Mdot
.49848 .35566 Mdot
.51478 .57693 Mdot
.67527 .46264 Mdot
.35219 .62625 Mdot
.54334 .34954 Mdot
.63616 .5769 Mdot
.57082 .67842 Mdot
.54434 .32764 Mdot
.61328 .63036 Mdot
.60928 .60483 Mdot
.46942 .63659 Mdot
.40641 .559 Mdot
.4685 .49252 Mdot
.54736 .59057 Mdot
.38743 .43447 Mdot
.54224 .39351 Mdot
.55612 .31729 Mdot
.48434 .32096 Mdot
.46838 .47717 Mdot
.56193 .47424 Mdot
.35708 .52605 Mdot
.58276 .34862 Mdot
.53323 .55832 Mdot
.37382 .58005 Mdot
.4589 .45383 Mdot
.5237 .63659 Mdot
.6661 .57288 Mdot
.4152 .5538 Mdot
.45527 .68728 Mdot
.44032 .35836 Mdot
.42025 .3242 Mdot
.4893 .35155 Mdot
.56042 .65172 Mdot
.6576 .40931 Mdot
.65581 .50951 Mdot
.36505 .503 Mdot
.39634 .6103 Mdot
.50041 .54157 Mdot
.43345 .65765 Mdot
.63525 .35771 Mdot
.67541 .56053 Mdot
.57532 .6368 Mdot
.3532 .61859 Mdot
.44218 .52999 Mdot
.55769 .63343 Mdot
.37575 .48291 Mdot
.57102 .6842 Mdot
.68826 .56132 Mdot
.5564 .35596 Mdot
.53099 .30515 Mdot
.32156 .49935 Mdot
.56159 .44973 Mdot
.30552 .52673 Mdot
.48102 .32877 Mdot
.58809 .53871 Mdot
.45691 .65651 Mdot
.63742 .38228 Mdot
.51863 .3644 Mdot
.46178 .31229 Mdot
.49936 .35432 Mdot
.61692 .40791 Mdot
.6526 .49432 Mdot
.36 .59964 Mdot
.6216 .58283 Mdot
.66805 .44752 Mdot
.37505 .63275 Mdot
.61963 .38249 Mdot
.6054 .54717 Mdot
.68662 .50555 Mdot
.43589 .67553 Mdot
.42913 .67973 Mdot
.35416 .45076 Mdot
.36959 .60106 Mdot
.43123 .47634 Mdot
.69244 .5188 Mdot
.33218 .53731 Mdot
.62104 .53663 Mdot
.64681 .63266 Mdot
.58138 .66109 Mdot
.67589 .53842 Mdot
.5711 .67978 Mdot
.49319 .30985 Mdot
.65523 .39529 Mdot
.56276 .6297 Mdot
.37196 .50184 Mdot
.40738 .4026 Mdot
.36099 .49675 Mdot
.58779 .6542 Mdot
.40913 .5276 Mdot
.66056 .5815 Mdot
.47087 .64768 Mdot
.55804 .51015 Mdot
.63437 .60918 Mdot
.46618 .60374 Mdot
.54615 .68108 Mdot
.62312 .6464 Mdot
.4627 .34577 Mdot
.34142 .49883 Mdot
.53523 .59493 Mdot
.38627 .65353 Mdot
.49802 .46603 Mdot
.49399 .60579 Mdot
.34345 .54015 Mdot
.51963 .6005 Mdot
.36223 .63881 Mdot
.68326 .43055 Mdot
.5722 .5874 Mdot
.52619 .40113 Mdot
.33838 .5643 Mdot
.45821 .65902 Mdot
.52093 .66506 Mdot
.67377 .45764 Mdot
.33807 .51042 Mdot
.44068 .34371 Mdot
.53796 .50353 Mdot
.35727 .5391 Mdot
.46194 .42656 Mdot
.3525 .463 Mdot
.31886 .44156 Mdot
.49515 .35773 Mdot
.60151 .56667 Mdot
.32849 .54857 Mdot
.61646 .36643 Mdot
.43618 .50546 Mdot
.44156 .56835 Mdot
.55334 .35159 Mdot
.45686 .57648 Mdot
.46509 .56113 Mdot
.47205 .45454 Mdot
.56087 .34435 Mdot
.56798 .57268 Mdot
.61341 .54779 Mdot
.6801 .57331 Mdot
.38539 .39281 Mdot
.55584 .61415 Mdot
.61045 .60924 Mdot
.5383 .40104 Mdot
.39428 .66266 Mdot
.43072 .51629 Mdot
.6919 .48923 Mdot
.51822 .43967 Mdot
.57517 .6226 Mdot
.42341 .32265 Mdot
.58187 .55541 Mdot
.46222 .46531 Mdot
.33025 .51352 Mdot
.32927 .5577 Mdot
.42773 .58998 Mdot
.38456 .37047 Mdot
.62143 .53431 Mdot
.59142 .64593 Mdot
.62406 .56135 Mdot
.40017 .62815 Mdot
.68015 .42006 Mdot
.43824 .33697 Mdot
.58436 .32618 Mdot
.6548 .57018 Mdot
.45125 .60772 Mdot
.37451 .35577 Mdot
.55629 .48219 Mdot
.61858 .49362 Mdot
.6626 .41564 Mdot
.59373 .35364 Mdot
.58723 .36947 Mdot
.4192 .51198 Mdot
.64316 .43946 Mdot
.5427 .35283 Mdot
.61801 .62582 Mdot
.49019 .31183 Mdot
.54706 .36151 Mdot
.63537 .64995 Mdot
.57763 .37765 Mdot
.63619 .62688 Mdot
.65008 .42839 Mdot
.49005 .60089 Mdot
.58765 .5466 Mdot
.51902 .42299 Mdot
.60222 .64528 Mdot
.67038 .50219 Mdot
.56984 .50577 Mdot
.47334 .68308 Mdot
.53633 .67314 Mdot
.59142 .67089 Mdot
.40669 .59443 Mdot
.58227 .52179 Mdot
.32988 .54732 Mdot
.55649 .30847 Mdot
.38407 .62251 Mdot
.68939 .49427 Mdot
.51351 .69628 Mdot
.62453 .4824 Mdot
.54461 .69402 Mdot
.46578 .34893 Mdot
.62698 .4813 Mdot
.34441 .44377 Mdot
.35987 .35667 Mdot
.33925 .49727 Mdot
.57752 .6026 Mdot
.48038 .3293 Mdot
.53878 .32955 Mdot
.50466 .31832 Mdot
.34444 .4295 Mdot
.52179 .34156 Mdot
.37761 .63325 Mdot
.56855 .52065 Mdot
.38308 .60291 Mdot
.35316 .49486 Mdot
.53542 .34194 Mdot
.68924 .52777 Mdot
.41499 .40315 Mdot
.48543 .62481 Mdot
.60715 .36133 Mdot
.34629 .47205 Mdot
.43135 .67955 Mdot
.50125 .43869 Mdot
.60576 .44227 Mdot
.47201 .2993 Mdot
.33158 .44697 Mdot
.55952 .65878 Mdot
.50354 .37778 Mdot
.56551 .66963 Mdot
.62066 .66003 Mdot
.62997 .42125 Mdot
.48561 .63511 Mdot
.3429 .6092 Mdot
.6424 .48585 Mdot
.37994 .34768 Mdot
.60322 .53855 Mdot
.68019 .43293 Mdot
.35472 .48253 Mdot
.48615 .35972 Mdot
.50748 .38172 Mdot
.33975 .44797 Mdot
.42054 .40304 Mdot
.42027 .4107 Mdot
.3581 .63161 Mdot
.50918 .63428 Mdot
.37938 .61078 Mdot
.39249 .39593 Mdot
.44132 .62995 Mdot
.44461 .34745 Mdot
.59112 .32178 Mdot
.60657 .46704 Mdot
.67739 .55306 Mdot
.36379 .58154 Mdot
.37044 .59345 Mdot
.52631 .36588 Mdot
.66539 .54067 Mdot
.4555 .49181 Mdot
.45811 .44093 Mdot
.64807 .41922 Mdot
.41297 .64527 Mdot
.5201 .58799 Mdot
.33387 .45794 Mdot
.45699 .68749 Mdot
.31302 .48085 Mdot
.59018 .38237 Mdot
.61964 .58342 Mdot
.57865 .53433 Mdot
.66534 .57975 Mdot
.42471 .48275 Mdot
.34988 .59266 Mdot
.39088 .38924 Mdot
.57755 .533 Mdot
.38866 .58824 Mdot
.36145 .46524 Mdot
.60876 .6142 Mdot
.65226 .54508 Mdot
.496 .58208 Mdot
.59174 .46397 Mdot
.53718 .70007 Mdot
.60655 .40602 Mdot
.41539 .32456 Mdot
.33177 .51895 Mdot
.65274 .53751 Mdot
.36367 .58803 Mdot
.44139 .42722 Mdot
.57278 .41564 Mdot
.33275 .4803 Mdot
.58157 .34426 Mdot
.51037 .66635 Mdot
.61827 .38419 Mdot
.65909 .55025 Mdot
.61716 .48874 Mdot
.36798 .60894 Mdot
.33734 .48949 Mdot
.44048 .58873 Mdot
.54884 .52931 Mdot
.47915 .42493 Mdot
.50804 .68937 Mdot
.555 .64179 Mdot
.40816 .56304 Mdot
.68341 .45393 Mdot
.33761 .45906 Mdot
.60604 .42498 Mdot
.35958 .45757 Mdot
.33513 .47762 Mdot
.68118 .56098 Mdot
.57883 .63808 Mdot
.67755 .43968 Mdot
.36079 .53902 Mdot
.47354 .30041 Mdot
.4508 .69085 Mdot
.44735 .67275 Mdot
.46554 .59703 Mdot
.50428 .39227 Mdot
.33358 .58875 Mdot
.54277 .67816 Mdot
.59861 .41488 Mdot
.57538 .6816 Mdot
.47979 .31288 Mdot
.51195 .57216 Mdot
.49162 .64656 Mdot
.41775 .4827 Mdot
.64913 .49989 Mdot
.51281 .63376 Mdot
.45028 .37976 Mdot
.39871 .51382 Mdot
.47933 .64078 Mdot
.48687 .64848 Mdot
.43071 .56426 Mdot
.63542 .59464 Mdot
.43275 .38089 Mdot
.59962 .37254 Mdot
.33475 .59453 Mdot
.44143 .63276 Mdot
.37253 .59023 Mdot
.59149 .54477 Mdot
.47152 .37903 Mdot
.35511 .36112 Mdot
.32454 .56041 Mdot
.42717 .64193 Mdot
.67132 .56121 Mdot
.50955 .53621 Mdot
.39054 .60252 Mdot
.38488 .60919 Mdot
.65959 .48002 Mdot
.58539 .52926 Mdot
.44918 .47483 Mdot
.69467 .5066 Mdot
.63007 .36299 Mdot
.33349 .60281 Mdot
.31985 .5649 Mdot
.63897 .55791 Mdot
.41811 .5817 Mdot
.57261 .3665 Mdot
.68267 .51 Mdot
.31255 .53632 Mdot
.62733 .51504 Mdot
.34859 .60679 Mdot
.38921 .54472 Mdot
.33566 .58978 Mdot
.37114 .42502 Mdot
.68764 .55055 Mdot
.59248 .63461 Mdot
.64995 .46141 Mdot
.51801 .36699 Mdot
.55462 .55023 Mdot
.52556 .33847 Mdot
.45518 .40698 Mdot
.50052 .37 Mdot
.47433 .62998 Mdot
.48384 .56074 Mdot
.6107 .39378 Mdot
.48036 .33129 Mdot
.60641 .37144 Mdot
.41891 .45854 Mdot
.56943 .4433 Mdot
.57236 .32614 Mdot
.506 .43319 Mdot
.62981 .52525 Mdot
.65277 .62489 Mdot
.49722 .54562 Mdot
.55649 .34084 Mdot
.69596 .49501 Mdot
.59345 .44639 Mdot
.51112 .64584 Mdot
.65232 .57107 Mdot
.43539 .38365 Mdot
.58147 .64367 Mdot
.60468 .37958 Mdot
.37594 .59246 Mdot
.55714 .39437 Mdot
.44488 .65102 Mdot
.39217 .46425 Mdot
.30913 .45604 Mdot
.39677 .44233 Mdot
.34319 .3961 Mdot
.39664 .65433 Mdot
.37907 .48996 Mdot
.42293 .35416 Mdot
.39193 .64175 Mdot
.52428 .42448 Mdot
.61862 .46016 Mdot
.6878 .48465 Mdot
.39493 .35884 Mdot
.34726 .57774 Mdot
.61244 .64037 Mdot
.58617 .37056 Mdot
.33184 .41897 Mdot
.33423 .48955 Mdot
.66272 .54634 Mdot
.54081 .4282 Mdot
.44724 .31643 Mdot
.5424 .50506 Mdot
.4939 .3282 Mdot
.60302 .5386 Mdot
.64412 .64117 Mdot
.39995 .37605 Mdot
.62482 .46718 Mdot
.51828 .42666 Mdot
.3775 .58479 Mdot
.46989 .64562 Mdot
.36836 .6338 Mdot
.3673 .54664 Mdot
.43304 .31455 Mdot
.38136 .573 Mdot
.62771 .43978 Mdot
.43185 .59417 Mdot
.5733 .36947 Mdot
.46855 .32217 Mdot
.5677 .42392 Mdot
.65626 .42297 Mdot
.32873 .53227 Mdot
.42159 .40787 Mdot
.64315 .63095 Mdot
.56538 .68325 Mdot
.32375 .56416 Mdot
.52486 .3422 Mdot
.34077 .49925 Mdot
.39073 .56567 Mdot
.44993 .41074 Mdot
.45278 .33918 Mdot
.51107 .45829 Mdot
.55825 .31121 Mdot
.43766 .61767 Mdot
.60858 .64448 Mdot
.52547 .65532 Mdot
.68424 .45873 Mdot
.55191 .33908 Mdot
.56182 .62944 Mdot
.48467 .57285 Mdot
.50581 .41751 Mdot
.38272 .3431 Mdot
.64494 .56427 Mdot
.61789 .34187 Mdot
.46537 .66098 Mdot
.33527 .49712 Mdot
.60413 .66901 Mdot
.49269 .59813 Mdot
.53735 .5766 Mdot
.34164 .52476 Mdot
.67904 .51319 Mdot
.57142 .64395 Mdot
.51175 .67408 Mdot
.34835 .44893 Mdot
.55344 .59743 Mdot
.46817 .32826 Mdot
.62952 .39653 Mdot
.52305 .57317 Mdot
.49966 .32464 Mdot
.69116 .45483 Mdot
.34919 .43801 Mdot
.35906 .53038 Mdot
.32775 .4227 Mdot
.43586 .67911 Mdot
.46347 .60856 Mdot
.49461 .35618 Mdot
.55232 .5489 Mdot
.6762 .53639 Mdot
.51337 .65629 Mdot
.56826 .33886 Mdot
.31761 .49463 Mdot
.62815 .36967 Mdot
.61069 .44991 Mdot
.39136 .58248 Mdot
.39556 .59455 Mdot
.6164 .59735 Mdot
.59731 .54792 Mdot
.45521 .55798 Mdot
.58868 .46235 Mdot
.42855 .61631 Mdot
.45574 .33218 Mdot
.33261 .46235 Mdot
.54215 .6864 Mdot
.41928 .32204 Mdot
.47754 .66594 Mdot
.49048 .66926 Mdot
.59544 .41581 Mdot
.57209 .59632 Mdot
.53275 .41415 Mdot
.52234 .39527 Mdot
.65527 .3751 Mdot
.32516 .55171 Mdot
.57536 .62377 Mdot
.58664 .44488 Mdot
.65541 .45619 Mdot
.50277 .61253 Mdot
.43864 .31567 Mdot
.665 .49581 Mdot
.55119 .32905 Mdot
.57782 .37709 Mdot
.66622 .48043 Mdot
.61508 .54077 Mdot
.62859 .61397 Mdot
.38782 .40254 Mdot
.61839 .45669 Mdot
.45367 .37558 Mdot
.67915 .49508 Mdot
.4184 .53856 Mdot
.42518 .66433 Mdot
.34966 .55569 Mdot
.4033 .4903 Mdot
.41108 .43255 Mdot
.34703 .45887 Mdot
.32374 .4153 Mdot
.32009 .56468 Mdot
.652 .4386 Mdot
.32663 .51697 Mdot
.51119 .62973 Mdot
.30959 .48168 Mdot
.53753 .39429 Mdot
.5518 .59645 Mdot
.38603 .62692 Mdot
.46625 .44897 Mdot
.51466 .34502 Mdot
.61441 .61338 Mdot
.53711 .65675 Mdot
.44617 .34223 Mdot
.44158 .683 Mdot
.53356 .69049 Mdot
.6701 .54637 Mdot
.4896 .30429 Mdot
.52395 .65885 Mdot
.33049 .44156 Mdot
.6402 .36646 Mdot
.63599 .38199 Mdot
.61949 .5932 Mdot
.5072 .37491 Mdot
.65713 .39001 Mdot
.65767 .57651 Mdot
.36421 .35134 Mdot
.62816 .35749 Mdot
.3801 .44269 Mdot
.61557 .65883 Mdot
.39431 .65126 Mdot
.41395 .44516 Mdot
.30739 .50582 Mdot
.46192 .35492 Mdot
.39005 .61662 Mdot
.60228 .45927 Mdot
.33421 .51651 Mdot
.61442 .3911 Mdot
.624 .38168 Mdot
.67298 .53183 Mdot
.45804 .62421 Mdot
.64595 .39104 Mdot
.65554 .46956 Mdot
.44842 .65813 Mdot
.33805 .50366 Mdot
.40028 .42949 Mdot
.55063 .54349 Mdot
.45198 .43549 Mdot
.40836 .37819 Mdot
.52559 .33215 Mdot
.535 .31318 Mdot
.51987 .30621 Mdot
.34772 .53906 Mdot
.56314 .41447 Mdot
.4553 .50469 Mdot
.35462 .44627 Mdot
.65383 .49644 Mdot
.62432 .46516 Mdot
.60319 .38869 Mdot
.4636 .60892 Mdot
.50341 .6977 Mdot
.3398 .45582 Mdot
.39739 .52981 Mdot
.55149 .32657 Mdot
.67346 .50342 Mdot
.65284 .43795 Mdot
.33173 .48756 Mdot
.44893 .55347 Mdot
.38834 .49333 Mdot
.33513 .57527 Mdot
.39278 .35033 Mdot
.62414 .61542 Mdot
.33991 .58552 Mdot
.34219 .38223 Mdot
.6652 .45727 Mdot
.52725 .37569 Mdot
.69522 .47548 Mdot
.61154 .35782 Mdot
.37446 .5442 Mdot
.33347 .53145 Mdot
.59178 .45617 Mdot
.67957 .56603 Mdot
.46667 .63418 Mdot
.61677 .44114 Mdot
.62169 .3855 Mdot
.42232 .60936 Mdot
.68351 .43092 Mdot
.42653 .46927 Mdot
.69695 .48653 Mdot
.46978 .3568 Mdot
.33047 .47875 Mdot
.50436 .68082 Mdot
.36119 .42013 Mdot
.54102 .69181 Mdot
.48231 .61171 Mdot
.4746 .66672 Mdot
.35912 .5918 Mdot
.6199 .43779 Mdot
.32827 .51424 Mdot
.42474 .59561 Mdot
.33147 .47319 Mdot
.39567 .34066 Mdot
.69629 .54156 Mdot
.42637 .56066 Mdot
.36578 .5672 Mdot
.54758 .61465 Mdot
.58333 .60131 Mdot
.64886 .41924 Mdot
.48946 .32647 Mdot
.63451 .49181 Mdot
.46685 .69478 Mdot
.44385 .43985 Mdot
.48591 .36442 Mdot
.61776 .48705 Mdot
.48166 .36427 Mdot
.42342 .4528 Mdot
.43043 .67212 Mdot
.34285 .60266 Mdot
.59171 .64791 Mdot
.37711 .51986 Mdot
.31951 .56902 Mdot
.30905 .48842 Mdot
.57201 .69277 Mdot
.6365 .35796 Mdot
.33948 .56606 Mdot
.62295 .37165 Mdot
.46234 .35897 Mdot
.47241 .66197 Mdot
.36924 .58812 Mdot
.63623 .38495 Mdot
.48502 .69264 Mdot
.37425 .58316 Mdot
.616 .33881 Mdot
.64101 .42689 Mdot
.41549 .32259 Mdot
.65273 .57432 Mdot
.52868 .63037 Mdot
.53934 .69629 Mdot
.31484 .45446 Mdot
.62679 .43066 Mdot
.61416 .59726 Mdot
.66973 .54454 Mdot
.60577 .38001 Mdot
.41911 .41345 Mdot
.65836 .54254 Mdot
.45784 .32518 Mdot
.37592 .60997 Mdot
.44256 .43244 Mdot
.57484 .61452 Mdot
.4085 .54176 Mdot
.41302 .38291 Mdot
.3236 .47238 Mdot
.31923 .42523 Mdot
.40897 .51337 Mdot
.42638 .35846 Mdot
.63846 .35795 Mdot
.38504 .3392 Mdot
.57376 .5924 Mdot
.50722 .64445 Mdot
.40927 .49656 Mdot
.57672 .54144 Mdot
.66184 .61652 Mdot
.33524 .5574 Mdot
.39288 .46164 Mdot
.65184 .40807 Mdot
.58271 .53619 Mdot
.51556 .62101 Mdot
.52771 .61275 Mdot
.40096 .41704 Mdot
.66089 .6228 Mdot
.36402 .63603 Mdot
.33365 .40425 Mdot
.46704 .68271 Mdot
.31094 .48271 Mdot
.5465 .41082 Mdot
.66975 .4381 Mdot
.63171 .43093 Mdot
.6183 .36891 Mdot
.45387 .39456 Mdot
.40631 .37554 Mdot
.65972 .61447 Mdot
.3645 .43198 Mdot
.48795 .44889 Mdot
.66609 .51065 Mdot
.3945 .54209 Mdot
.33343 .47849 Mdot
.43538 .4446 Mdot
.34276 .38805 Mdot
.442 .3331 Mdot
.47277 .37513 Mdot
.6572 .50683 Mdot
.65982 .59236 Mdot
.65076 .43144 Mdot
.36658 .50017 Mdot
.54269 .66205 Mdot
.32204 .50072 Mdot
.51664 .359 Mdot
.59242 .48339 Mdot
.577 .60888 Mdot
.41017 .57118 Mdot
.33718 .53496 Mdot
.4437 .31163 Mdot
.40921 .52778 Mdot
.41631 .43022 Mdot
.34357 .46864 Mdot
.64077 .63254 Mdot
.49736 .51432 Mdot
.42867 .4399 Mdot
.34102 .44378 Mdot
.39044 .33158 Mdot
.38875 .58996 Mdot
.51439 .68521 Mdot
.67022 .43176 Mdot
.32864 .42344 Mdot
.3304 .52745 Mdot
.66732 .44347 Mdot
.58802 .46126 Mdot
.61171 .34362 Mdot
.43355 .43256 Mdot
.52972 .68047 Mdot
.63569 .57347 Mdot
.35548 .39263 Mdot
.46501 .42249 Mdot
.35904 .63512 Mdot
.50328 .36458 Mdot
.52984 .41478 Mdot
.46738 .66702 Mdot
.59858 .38739 Mdot
.4144 .63412 Mdot
.66243 .53268 Mdot
.46859 .3507 Mdot
.57283 .32461 Mdot
.39293 .33286 Mdot
.52808 .58291 Mdot
.68977 .46457 Mdot
.55996 .413 Mdot
.55404 .66361 Mdot
.57665 .51631 Mdot
.68098 .42705 Mdot
.5782 .66135 Mdot
.37274 .42846 Mdot
.5597 .57129 Mdot
.65349 .37074 Mdot
.43145 .60734 Mdot
.5131 .54579 Mdot
.58121 .58715 Mdot
.49337 .59764 Mdot
.49099 .57411 Mdot
.6445 .57233 Mdot
.50622 .52567 Mdot
.59602 .64269 Mdot
.62943 .55744 Mdot
.40285 .44981 Mdot
.61079 .4351 Mdot
.47117 .38838 Mdot
.34118 .381 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0?ooooooB_ooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A006ooooo`03o`000?oooooooooo0?ooooooB_ooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0?ooooooB_oo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06
ooooo`?o0000oooooom:ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<oooo
o`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom:ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001_ooool00ol0003oooooooooo`3ooooood[ooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0V?ooool6o`000:_ooooo000Looooo`03o`000?oooooooooo09;o
oooo4?l0002Wooooo`007?ooool00ol0003oooooooooo`2@oooooa[o0000Woooool001cooooo00?o
0000ooooooooool0S?oooolSo`0009[ooooo000Looooo`03o`000?oooooooooo08cooooo:?l0002E
ooooo`007?ooool00ol0003oooooooooo`28oooooboo0000T_ooool001cooooo00?o0000oooooooo
ool0QOooooleo`0008oooooo000Looooo`03o`000?oooooooooo08?ooooo2ol000000ooooooo0000
o`00000Zo`0008kooooo000Looooo`03o`000?oooooooooo07oooooo?_l0002<ooooo`007?ooool0
0ol0003oooooooooo`1moooood3o0000S?ooool001cooooo0_l0001mooooodGo0000R?ooool001co
oooo00?o0000ooooooooool0NOoooolOo`0000?ooooo0_l00002ooooob;o0000R?ooool001cooooo
00?o0000ooooooooool0N?oooolKo`0000Sooooo0_l00005ooooo`;o000000Coooooo`000?l0003o
oooo0ol00006oooooa7o0000Qoooool001cooooo00?o0000ooooooooool0M_oooolHo`0000kooooo
0_l00004ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Kooooo0_l000000ooooooo0000
o`00000=o`0008Kooooo000Looooo`03o`000?oooooooooo07Kooooo6?l00004ooooo`;o00001?oo
ool2o`000004ooooool0003o0000o`0000cooooo0_l00005ooooo`?o00000_ooool@o`0008?ooooo
000Looooo`03o`000?oooooooooo07?ooooo7Ol00002ooooo`;o00001?ooool2o`000003ooooool0
003o000000gooooo0_l00006ooooo`;o00001?ooool>o`0008?ooooo000Looooo`03o`000?oooooo
oooo07?ooooo7Ol0000@ooooo`;o00003oooool2o`0000Gooooo4?l00021ooooo`007?ooool00ol0
003oooooooooo`1boooooaKo00001Oooool2o`0000Gooooo0_l00004ooooo`;o00001?ooool2o`00
00[ooooo0_l00003ooooo`;o00001OoooolAo`00083ooooo000Looooo`03o`000?oooooooooo073o
oooo6?l00009ooooo`;o000000?oooooo`000?l000001?ooool2o`0000?ooooo0_l0000;ooooo`;o
00002?ooool8o`000003ooooool0003o000000co0000O?ooool001cooooo00?o0000ooooooooool0
KooooolBo`000003ooooool0003o000000?o00002_ooool2o`000003ooooool0003o000000;ooooo
0_l000000ooooooo0000o`000004o`0000_ooooo1Ol00003ooooo`Go000000?oooooo`000?l00000
0oooool@o`0007[ooooo000Looooo`03o`000?oooooooooo06oooooo1?l000000ooooooo0000o`00
0009o`0000?ooooo0_l0000<ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`00
0002o`0000Sooooo0_l00002ooooo`Ko000000?oooooo`000?l000000_l000000ooooooo0000o`00
0008ooooo`oo0000NOooool001cooooo00?o0000ooooooooool0K_ooool@o`0000kooooo0_l00002
ooooo`;o00001_ooool2o`0000gooooo0_l00002ooooo`;o00001Oooool2o`0000?ooooo0_l00009
oooooa3o0000Moooool001cooooo00?o0000ooooooooool0KOooool>o`000003ooooool0003o0000
00gooooo0ol00002ooooo`;o00005Oooool2o`0001cooooo3Ol0001gooooo`007?ooool00ol0003o
ooooooooo`1/ooooo`oo00000_ooool2o`0000cooooo0_l00002ooooo`;o00005Oooool3o`0000Oo
oooo0ol00002ooooo`;o00003Oooool>o`0007Oooooo000Looooo`03o`000?oooooooooo06_ooooo
3Ol000000ooooooo0000o`000002ooooo`;o00003?ooool6o`0001Gooooo0ol000000ooooooo0000
o`000004ooooo`Co000000?oooooo`000?l000000_ooool2o`0000Sooooo1?l000000ooooooo0000
o`000009o`0007Kooooo000Looooo`03o`000?oooooooooo06[ooooo3Ol000001?oooooo0000o`00
0?l0000@ooooo`Co00001?ooool2o`0000kooooo0_l00002ooooo`;o000000?oooooo`000?l00000
1_ooool2o`0000Gooooo0_l00008ooooo`Co00001Oooool9o`0007Cooooo000Looooo`;o0000Jooo
ool<o`0000;ooooo0_l00002ooooo`;o00001Oooool2o`0000Oooooo0ol00004ooooo`?o00003Ooo
ool2o`0000Sooooo0_l0000;ooooo`;o00004?ooool;o`0007;ooooo000Looooo`03o`000?oooooo
oooo06[ooooo2ol00003ooooo`;o000000Coooooo`000?l0003o00001Oooool2o`0000oooooo0_l0
0005ooooo`;o00003_ooool4o`000003ooooool0003o000000Sooooo0_l000000ooooooo0000o`00
000>ooooo`_o0000LOooool001cooooo00?o0000ooooooooool0J?ooool=o`000003ooooool0003o
000000?ooooo0_l00009ooooo`;o00002_ooool2o`000003ooooool0003o000000Cooooo1Ol00006
ooooo`;o00000oooool4o`000004ooooool0003o0000o`0000Oooooo0_l000000ooooooo0000o`00
000?ooooo`[o0000LOooool001cooooo00?o0000ooooooooool0Ioooool<o`0000?ooooo0_l00003
ooooo`Co00001_ooool4o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l000000oooool2
o`000004ooooool0003o0000o`0000Cooooo1?l00009ooooo`;o00001oooool2o`0000Oooooo0_l0
0003ooooo`;o000000Goooooo`000?l0003o0000ooooo`0:o`00073ooooo000Looooo`03o`000?oo
oooooooo06Oooooo2ol00009ooooo`Co00001_ooool4o`0000;ooooo1?l00003ooooo`;o00001_oo
ool5o`0000Gooooo0_l00008ooooo`;o00004Oooool4o`0000?ooooo1_l00002ooooo`_o0000K_oo
ool001cooooo00?o0000ooooooooool0I_ooool<o`0000_ooooo0_l0000>ooooo`;o00002_ooool5
o`0000;ooooo0_l00003ooooo`Co00001Oooool2o`0000cooooo0_l00003ooooo`;o00001_ooool2
o`0000Gooooo2ol0001^ooooo`007?ooool00ol0003oooooooooo`1Vooooo`[o00003Oooool2o`00
01Gooooo0_l00003ooooo`?o00001?ooool2o`0000?ooooo1?l0000=ooooo`;o00000oooool3o`00
00Kooooo0ol00005ooooo`;o00000oooool;o`0006gooooo000Looooo`03o`000?oooooooooo06Go
oooo2_l0000:ooooo`;o00000oooool2o`0001Cooooo0_l00009ooooo`;o00001?ooool2o`0000oo
oooo0_l00003ooooo`;o00000_ooool4o`000003ooooool0003o000000Co00000_ooool2o`0000;o
oooo3?l0001]ooooo`007?ooool00ol0003oooooooooo`1Tooooo`[o00002oooool2o`0000?ooooo
1?l0000>ooooo`;o00001?ooool2o`0000Oooooo1?l0000Cooooo`;o00000oooool2o`0000;ooooo
1Ol00003ooooo`?o00001_ooool=o`0006cooooo000Looooo`03o`000?oooooooooo06Cooooo2_l0
000=ooooo`;o000000?oooooo`000?l000000ol0000<ooooo`?o00001?ooool2o`0000Sooooo0ol0
0005ooooo`;o00003_ooool2o`0000Sooooo0_l0000=ooooo`co0000K?ooool001cooooo00?o0000
ooooooooool0Hoooool;o`0000gooooo0_l000000ooooooo0000o`000003o`0000Kooooo1?l00002
ooooo`;o00001?ooool2o`0000Wooooo0ol00005ooooo`;o00001_ooool2o`0000Kooooo0_l00003
ooooo`;o00000_ooool2o`0000Cooooo1?l00007ooooo`go0000J_ooool001cooooo00?o0000oooo
ooooool0Hoooool:o`000003ooooool0003o000000Gooooo0_l00008ooooo`;o000000?oooooo`00
0?l000001Oooool4o`0000;ooooo0_l00002ooooo`Co00001oooool2o`000003ooooool0003o0000
00gooooo0_l00009ooooo`Co00000_ooool2o`0000;ooooo2?l000000ooooooo0000o`000002oooo
o`go0000J_ooool001cooooo00?o0000ooooooooool0I?ooool9o`000003ooooool0003o000000Go
oooo0_l0000;ooooo`;o00001_ooool2o`0000Oooooo1?l00007ooooo`;o00006oooool3o`000003
ooooool0003o000000Cooooo0ol00003ooooo`;o000000?oooooo`000?l000001?ooool;o`0006[o
oooo000Looooo`03o`000?oooooooooo067ooooo2_l000000ooooooo0000o`00000=ooooo`;o0000
3Oooool2o`0000Wooooo0_l0000Xooooo`?o00001?ooool2o`0000?ooooo0_l00005ooooo`;o0000
00?oooooo`000?l000002?l0001Zooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o
8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0HOooool9o`0000;o
oooo0_l00002ooooo`;o00001oooool4o`0001Sooooo0_l00009ooooo`;o00002_ooool2o`0000Ko
oooo0_l0000:ooooo`;o000000Coooooo`000?l0003o00002?ooool2o`0000;ooooo0_l000000ooo
oooo0000o`000009o`0006Wooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0H?ooool9o`0000?ooooo0_l00002
ooooo`;o00001oooool2o`000003ooooool0003o000001;ooooo0_l0000>ooooo`;o00001?ooool2
o`0000?ooooo0ol00003ooooo`;o000000?oooooo`000?l000003Oooool3o`0000?ooooo0_l00003
ooooo`;o000000?oooooo`000?l000000_ooool;o`0006Wooooo00000ooooooo410@ooooo`02oooo
o`03oa0@4?oooooooooo00Wooooo1Ol00006ooooo`03o`000?oooooooooo05oooooo2_l00003oooo
o`;o00003_ooool2o`0001;ooooo0_l0000Dooooo`;o00000oooool2o`0000Cooooo0_l0000Foooo
o`;o00001_ooool2o`0000?ooooo2ol0001Xooooo`0000?oooooo`000?ooool00_ooool00ol0003o
ooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0001Oooooo`[o00001oooool2o`00
00Sooooo1?l000000ooooooo0000o`000006o`00023ooooo0_l00002ooooo`;o00007oooool3o`00
00Oooooo3?l0001Wooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04
omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0G_ooool=o`0000Gooooo0_l00008oooo
o`;o00000oooool8o`00023ooooo0_l00002ooooo`;o00005?ooool3o`0000Sooooo0ol00007oooo
o`co0000Ioooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00omgMgOo
c<c<o`000007ooooo`03o`000?oooooooooo05kooooo2_l000000ooooooo0000o`00000Jooooo`;o
00002Oooool2o`0001;ooooo0_l0000Kooooo`?o000000?oooooo`000?l000002Oooool4o`0000Co
oooo2_l0001Wooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co0000
00Oooooo00?o0000ooooooooool0Goooool8o`0001kooooo0_l00007ooooo`Co00002Oooool2o`00
00Oooooo0_l00008ooooo`;o00004?ooool2o`0000?ooooo0_l00009ooooo`Co00001?ooool;o`00
06Kooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool0
0ol0003oooooooooo`1Mooooo`[o00003oooool2o`0000cooooo0ol00006ooooo`?o00002oooool2
o`0000_ooooo0ol00003ooooo`;o00000_ooool3o`000003ooooool0003o000000Oooooo0ol00004
ooooo`;o00002oooool2o`0000Cooooo2_l0001Vooooo`007?ooool00ol0003oooooooooo`1Moooo
o`[o00002?ooool2o`0000Gooooo0_l00007ooooo`;o00000oooool2o`0000Oooooo0_l0000Boooo
o`;o00001Oooool3o`0000Oooooo0ol000000ooooooo0000o`000006ooooo`Co00001?ooool3o`00
00[ooooo0_l00004ooooo`[o0000I_ooool001cooooo00?o0000ooooooooool0GOooool:o`000003
ooooool0003o000000Gooooo0_l000000ooooooo0000o`00000;ooooo`;o00008?ooool2o`0001_o
oooo0_l00007ooooo`Co00001?ooool2o`0000Sooooo2ol0001Uooooo`007?ooool00ol0003ooooo
ooooo`1Mooooo`Wo000000Coooooo`000?l0003o00002?ooool2o`0001Cooooo0_l00009ooooo`;o
00002oooool2o`0000?ooooo1?l0000:ooooo`Co00004_ooool2o`0000Cooooo1?l00006ooooo`go
0000Hoooool001cooooo00?o0000ooooooooool0Foooool;o`000003ooooool0003o000000cooooo
0_l0000Aooooo`;o00000_ooool2o`0000Cooooo0ol00003ooooo`;o00001_ooool2o`0000?ooooo
1?l0000:ooooo`Co00002_ooool2o`0000Wooooo0_l00003ooooo`;o00001_ooool=o`0006?ooooo
000Looooo`03o`000?oooooooooo05_ooooo2ol00006ooooo`;o00001oooool2o`0000Oooooo0_l0
0003ooooo`;o00001oooool2o`0000Cooooo0_l00004ooooo`;o00002oooool2o`0000Gooooo0_l0
000Cooooo`;o00001Oooool3o`000004ooooool0003o0000ooooo`;o00001_ooool@o`0006;ooooo
000Looooo`03o`000?oooooooooo05_ooooo2_l00007ooooo`;o00001Oooool4o`0000Oooooo0_l0
0002ooooo`?o00001?ooool2o`000003ooooool0003o000001?ooooo0_l00009ooooo`;o00004?oo
ool2o`0000Sooooo0ol00004ooooo`?o00001?oooolAo`0006;ooooo000Looooo`03o`000?oooooo
oooo05_ooooo2_l00005ooooo`;o00001oooool4o`0000?ooooo0_l00006ooooo`;o00001Oooool2
o`000004ooooool0003o0000ooooo`;o00004?ooool2o`0001_ooooo0_l00003ooooo`;o000000?o
ooooo`000?l000002?ooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool<o`00067ooooo
000Looooo`03o`000?oooooooooo05_ooooo2Ol00006ooooo`;o000000Coooooo`000?l0003o0000
1Oooool2o`0000?ooooo0_l0000;ooooo`Co000000Coooooo`000?l0003ooooo0ol0000=ooooo`;o
00001?ooool2o`0000cooooo0_l0000>ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o
000000?oooooo`000?l000001?ooool4o`0000?ooooo2ol0001Qooooo`007?ooool00ol0003ooooo
ooooo`1Kooooo`_o00000_ooool2o`0000?ooooo0ol00002ooooo`;o00001?ooool2o`0000?ooooo
0_l00008ooooo`Co000000?oooooo`000?l000000_ooool3o`0000cooooo0_l00004ooooo`;o0000
3?ooool5o`0000Wooooo0_l00002ooooo`Go00000oooool2o`000003ooooool0003o000000Cooooo
1?l00004ooooo`[o0000HOooool001cooooo00?o0000ooooooooool0F_ooool9o`000003ooooool0
003o000000;ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`000?l00000
1?ooool2o`0000?ooooo1?l00002ooooo`;o00001Oooool2o`0000Gooooo0_l0000Rooooo`?o0000
0oooool4o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000002oooool2o`0000Oooooo
2ol0001Pooooo`007?ooool00ol0003oooooooooo`1Jooooo`Wo00001Oooool2o`000003ooooool0
003o000000Co00003_ooool2o`0000;ooooo0_l00005ooooo`;o00002?ooool2o`0000Gooooo0_l0
000Nooooo`Co00002Oooool2o`0000_ooooo0_l00007ooooo`co0000Goooool001cooooo0_l0001K
ooooo`Wo00001Oooool2o`000003ooooool0003o000000Co00003_ooool2o`0001?ooooo0_l00005
ooooo`;o00005_ooool2o`0000kooooo0_l00003ooooo`;o00002oooool2o`0000Oooooo3?l0001O
ooooo`007?ooool00ol0003oooooooooo`1Jooooo`So000000?oooooo`000?l000002_ooool2o`00
00kooooo0_l00005ooooo`;o00001?ooool2o`0000?ooooo0_l00003ooooo`;o00006oooool2o`00
00kooooo0_l0000Booooo`;o000000Coooooo`000?l0003ooooo3Ol0001Oooooo`007?ooool00ol0
003oooooooooo`1Jooooo`_o00001?ooool4o`0000Cooooo0_l0000Aooooo`Co00001?ooool2o`00
00?ooooo0ol00002ooooo`;o00002_ooool2o`0001Sooooo0_l00003ooooo`;o00000_ooool2o`00
00[ooooo0_l000001?oooooo0000o`000?ooool2o`000004ooooool0003o0000ooooo`go0000Gooo
ool001cooooo00?o0000ooooooooool0FOooool:o`0000Kooooo1_l00002ooooo`;o00002Oooool2
o`0000Kooooo0_l0000<ooooo`;o00003_ooool2o`0001Oooooo0ol00002ooooo`?o000000Cooooo
o`000?l0003o00002?ooool4o`000004ooooool0003o0000ooooo`Go000000?oooooo`000?l00000
2_l0001Pooooo`007?ooool00ol0003oooooooooo`1Iooooo`Wo00001_ooool4o`000003ooooool0
003o000000;o00002oooool2o`0003gooooo0ol00002ooooo`?o000000Coooooo`000?l0003o0000
2?ooool2o`0000Oooooo0_l00002ooooo`oo0000G_ooool001cooooo00?o0000ooooooooool0FOoo
ool9o`0000Kooooo0_l00005ooooo`;o000000?oooooo`000?l000001oooool3o`0001Cooooo0_l0
000:ooooo`;o00006oooool3o`0000?ooooo0_l00004ooooo`;o00003oooool2o`0000;ooooo0_l0
00000ooooooo0000o`00000:o`0005kooooo000Looooo`03o`000?oooooooooo05Wooooo2Ol0000:
ooooo`;o00001?ooool2o`0000Oooooo0_l000000ooooooo0000o`000007ooooo`;o00002Oooool2
o`0000[ooooo0_l0000Qooooo`;o00001?ooool2o`0000Kooooo1?l00004ooooo`;o00001oooool:
o`0005oooooo000Looooo`03o`000?oooooooooo05Wooooo2Ol00003ooooo`;o000000?oooooo`00
0?l000000_ooool3o`0000oooooo0_l00007ooooo`;o00000oooool2o`0001Cooooo0_l0000[oooo
o`Co00000_ooool4o`0000Oooooo2_l0001Oooooo`007?ooool00ol0003oooooooooo`1Iooooo`Wo
00000oooool2o`000003ooooool0003o000000?ooooo0_l0000Iooooo`;o00000_ooool4o`0000Co
oooo0_l0000<ooooo`;o00003oooool2o`00023ooooo0_l00005ooooo`ko0000Goooool001cooooo
00?o0000ooooooooool0F?ooool:o`0000Kooooo0ol0000Mooooo`;o00001?ooool2o`0000Cooooo
0_l0000Mooooo`?o00004Oooool2o`0000Wooooo0_l00008ooooo`ko0000Goooool001cooooo00?o
0000ooooooooool0F?ooool<o`0000Cooooo0ol00004ooooo`;o00001Oooool2o`0000cooooo1?l0
000Yooooo`;o000000?oooooo`000?l000001oooool2o`0000Sooooo0ol00008ooooo`;o000000?o
ooooo`000?l000001_ooool=o`0005oooooo000Looooo`03o`000?oooooooooo05Sooooo3?l00006
ooooo`;o00000oooool2o`0000Gooooo0_l0000<ooooo`Co0000:Oooool2o`0000[ooooo0_l00008
ooooo`?o00000oooool2o`0000Kooooo0_l00005ooooo`ko0000Goooool001cooooo00?o0000oooo
ooooool0Eoooool<o`0000Gooooo1?l0001Iooooo`;o00001_ooool2o`000003ooooool0003o0000
00Kooooo0_l00002ooooo`ko0000Goooool001cooooo00?o0000ooooooooool0E_ooool>o`0000Co
oooo1?l00003ooooo`;o00001_ooool2o`0000Kooooo0_l0000?ooooo`;o00000_ooool2o`0002oo
oooo0_l00003ooooo`;o00001?ooool2o`0000Kooooo0_l00003ooooo`co0000H?ooool001cooooo
00?o0000ooooooooool0E_ooool;o`000004ooooool0003o0000o`0000[ooooo0_l00006ooooo`;o
000000?oooooo`000?l000000oooool2o`0000oooooo0_l00002ooooo`;o0000;?ooool2o`000003
ooooool0003o000000?ooooo0_l00004ooooo`;o00001oooool2o`000003ooooool0003o000000co
0000Goooool001cooooo00?o0000ooooooooool0Eoooool:o`0000;ooooo0_l00004ooooo`Co0000
0_ooool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000005ooooo`;o0000
?oooool2o`000003ooooool0003o000000Wooooo0ol000000ooooooo0000o`000003ooooo`;o0000
00?oooooo`000?l000003?l0001Oooooo`007?ooool2o`0005Oooooo2ol00004ooooo`;o00000_oo
ool4o`0000Gooooo1ol00008ooooo`;o0000C?ooool4o`000004ooooool0003o0000ooooo`;o0000
1_ooool;o`0005oooooo000Looooo`03o`000?oooooooooo05Gooooo3?l00004ooooo`;o00000ooo
ool3o`0000Kooooo1?l0000Iooooo`;o00006Oooool2o`0002;ooooo0_l00005ooooo`?o00001Ooo
ool:o`00067ooooo000Looooo`03o`000?oooooooooo05Gooooo3Ol00008ooooo`;o00001oooool2
o`0001Gooooo0_l00004ooooo`;o00006Oooool3o`0000Oooooo0_l0000Kooooo`;o00000_ooool3
o`0000;ooooo0_l000000ooooooo0000o`000008o`00067ooooo000Looooo`03o`000?oooooooooo
05Kooooo3?l00008ooooo`;o00007_ooool2o`00023ooooo0_l00003ooooo`;o00000_ooool2o`00
01[ooooo0ol000000ooooooo0000o`000003ooooo`?o000000?oooooo`000?l000002?l0001Qoooo
o`007?ooool00ol0003oooooooooo`1Eooooo`go00001Oooool5o`0001;ooooo0_l000001?oooooo
0000o`000?ooool2o`0000Gooooo0_l0000Tooooo`;o00007_ooool2o`0000;ooooo0_l00002oooo
o`?o00000oooool9o`00067ooooo000Looooo`03o`000?oooooooooo05Gooooo2ol00006ooooo`Go
00004oooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`000003ooooool0003o0000
017ooooo0_l0000Hooooo`;o00003_ooool2o`0000oooooo0_l00004ooooo`[o0000H?ooool001co
oooo00?o0000ooooooooool0EOooool;o`0000Kooooo1Ol0000<ooooo`;o00003oooool2o`0001Co
oooo0_l0000Hooooo`;o00003_ooool2o`0001?ooooo3?l0001Pooooo`007?ooool00ol0003ooooo
ooooo`1Eooooo`co00001oooool2o`0000gooooo0_l00004ooooo`;o0000=_ooool2o`0000;ooooo
0_l0000Rooooo`co0000H?ooool001cooooo00?o0000ooooooooool0E_ooool;o`0000[ooooo0_l0
0003ooooo`;o00002oooool2o`0002;ooooo0_l00009ooooo`;o00001oooool2o`0000;ooooo1?l0
000<ooooo`;o00002_ooool4o`0000Kooooo2_l0001Pooooo`007?ooool00ol0003oooooooooo`1G
ooooo`_o00001_ooool2o`000003ooooool0003o000000?ooooo0_l0000?ooooo`;o00007_ooool2
o`0000Wooooo0_l000000ooooooo0000o`000009ooooo`?o00003?ooool2o`0000?ooooo0_l00005
ooooo`Co00000oooool2o`000003ooooool0003o000000So0000H?ooool001cooooo00?o0000oooo
ooooool0Eoooool;o`0000Gooooo1?l00006ooooo`;o00002_ooool2o`0000;ooooo0_l00009oooo
o`;o00008Oooool2o`0000Wooooo0_l00004ooooo`;o00002_ooool4o`0000?ooooo0_l000001?oo
oooo0000o`000?l00003ooooo`;o000000?oooooo`000?l000002?l0001Pooooo`007?ooool00ol0
003oooooooooo`1Gooooo`[o00000_ooool2o`0000;ooooo1Ol00005ooooo`;o00002_ooool2o`00
00gooooo0_l0000Zooooo`;o00001_ooool2o`0000Cooooo0_l00004ooooo`Co00000oooool6o`00
00Kooooo2_l0001Pooooo`007?ooool00ol0003oooooooooo`1Gooooo`[o000000Coooooo`000?l0
003o00000oooool4o`0001Sooooo0_l0000<ooooo`;o00003_ooool2o`0001Cooooo1Ol00003oooo
o`;o00000_ooool4o`0000Sooooo0_l00003ooooo`;o000000Coooooo`000?l0003o00001?ooool:
o`00063ooooo000Looooo`03o`000?oooooooooo05Oooooo3Ol00004ooooo`;o00000_ooool3o`00
0004ooooool0003o0000o`0000kooooo0_l000000ooooooo0000o`00000<ooooo`;o00002oooool2
o`000003ooooool0003o000001Cooooo1Ol00003ooooo`;o00000_ooool4o`0000Sooooo0_l00002
ooooo`;o00000_ooool3o`0000?ooooo2ol0001Pooooo`007?ooool00ol0003oooooooooo`1Goooo
o`_o00002_ooool3o`000004ooooool0003o0000o`0000?ooooo0_l00003ooooo`?o00000oooool2
o`0001cooooo0_l0000>ooooo`;o00001oooool2o`0000;ooooo0_l00006ooooo`;o00001_ooool2
o`0000Cooooo1_l00006ooooo`[o0000HOooool001cooooo00?o0000ooooooooool0Eoooool;o`00
00Gooooo0_l00008ooooo`;o000000?oooooo`000?l000000_l00003ooooo`?o00008?ooool2o`00
00?ooooo0_l0000:ooooo`;o00000oooool2o`0000Gooooo1Ol000000ooooooo0000o`000002o`00
00Oooooo0_l00002ooooo`Go000000?oooooo`000?l000001oooool9o`00067ooooo000Looooo`;o
0000FOooool:o`0000Gooooo0_l0000;ooooo`;o00003oooool2o`0001Oooooo0_l00003ooooo`;o
00002oooool2o`0000;ooooo0_l00005ooooo`;o000000Coooooo`000?l0003ooooo1?l0000;oooo
o`Go000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000Oo0000HOooool001co
oooo00?o0000ooooooooool0F?ooool;o`0000?ooooo0ol0000Jooooo`Co00001oooool2o`00023o
oooo0_l0000Pooooo`;o00001?ooool2o`0000;ooooo2ol0001Rooooo`007?ooool00ol0003ooooo
ooooo`1Hooooo`_o00000oooool2o`0000Kooooo0_l0000Cooooo`;o00002Oooool2o`0002Wooooo
0_l0000;ooooo`;o00004?ooool2o`0000Cooooo2Ol0001Rooooo`007?ooool00ol0003ooooooooo
o`1Hooooo`_o00000oooool5o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0000[ooooo
0_l0000>ooooo`;o00005oooool2o`0000cooooo1?l0000;ooooo`;o000000Coooooo`000?l0003o
oooo0_l00006ooooo`;o00002?ooool9o`0006;ooooo000Looooo`03o`000?oooooooooo05Sooooo
3?l00002ooooo`Go00001_ooool2o`000003ooooool0003o000000[ooooo0ol00004ooooo`;o0000
0_ooool2o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`;o00003_ooool2o`0000cooooo
0_l00006ooooo`;o00001_ooool4o`000003ooooool0003o000000Kooooo1ol000000ooooooo0000
o`000008o`0006?ooooo000Looooo`03o`000?oooooooooo05Sooooo3ol00003ooooo`?o00003_oo
ool4o`0000;ooooo0_l00004ooooo`?o000000?oooooo`000?l000001_ooool2o`0000Cooooo0_l0
000Tooooo`;o00001_ooool2o`0000Gooooo0_l00006ooooo`Go000000?oooooo`000?l000002?l0
001Sooooo`007?ooool00ol0003oooooooooo`1Iooooo`Ko000000?oooooo`000?l000001Ol00003
ooooo`?o00001_ooool2o`0000Kooooo1?l00009ooooo`;o00000_ooool2o`00033ooooo1?l0000<
ooooo`;o00001?ooool2o`0000?ooooo0_l000000ooooooo0000o`000007o`0006Cooooo000Loooo
o`03o`000?oooooooooo05Wooooo3_l0000<ooooo`;o00003?ooool2o`0000Wooooo0_l0000?oooo
o`;o00001?ooool2o`0000gooooo0_l000000ooooooo0000o`000007ooooo`Co00000_ooool2o`00
00Sooooo1Ol000000ooooooo0000o`000006ooooo`Wo0000I?ooool001cooooo00?o0000oooooooo
ool0FOooool<o`0000Cooooo0_l0000;ooooo`Co00001oooool2o`0000Oooooo0_l0000>ooooo`Go
00001?ooool2o`000003ooooool0003o000000[ooooo0_l000000ooooooo0000o`00000=ooooo`;o
00001Oooool2o`000003ooooool0003o000000?o00000_ooool2o`0000;ooooo2ol0001Uooooo`00
7?ooool00ol0003oooooooooo`1Jooooo`_o00001?ooool2o`0000;ooooo0_l00007ooooo`Co0000
4?ooool2o`0000Gooooo0_l00007ooooo`Co00001Oooool2o`000003ooooool0003o000000?ooooo
0_l0000Nooooo`;o00000oooool4o`000003ooooool0003o000000;ooooo2ol0001Uooooo`007?oo
ool00ol0003oooooooooo`1Jooooo`co00001oooool2o`0000?ooooo0_l00002ooooo`;o00000ooo
ool2o`0000Oooooo0_l0000;ooooo`;o00001oooool2o`0000Oooooo0_l00006ooooo`;o00007_oo
ool2o`0000Gooooo1Ol00004ooooo`So0000I_ooool001cooooo00?o0000ooooooooool0Foooool;
o`0000cooooo0_l00002ooooo`?o00000_ooool3o`0000Kooooo0_l0000Gooooo`;o00002Oooool2
o`0001_ooooo0ol00006ooooo`;o00000oooool4o`0000Cooooo2?l0001Vooooo`007?ooool00ol0
003oooooooooo`1Kooooo`co00001?ooool2o`0000Gooooo1ol00002ooooo`?o00007oooool2o`00
00Kooooo0_l000000ooooooo0000o`000002ooooo`;o00002?ooool2o`000003ooooool0003o0000
00[ooooo0ol00006ooooo`;o00001?ooool2o`0000?ooooo2_l0001Vooooo`007?ooool00ol0003o
ooooooooo`1Looooo`_o00000_ooool4o`0000Gooooo1Ol00004ooooo`;o000000?oooooo`000?l0
00001oooool2o`0000;ooooo0_l0000Hooooo`;o00001Oooool4o`0000Kooooo0_l000000ooooooo
0000o`000002ooooo`;o00005Oooool2o`0000?ooooo1ol000000ooooooo0000o`00001Vooooo`00
00Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413o
c<c<00Kooooo00?o0000ooooooooool0G?ooool6o`000003ooooool0003o000000;o00000_ooool2
o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`?o00000oooool2o`000003ooooool0003o
000000Oooooo1_l0000Qooooo`;o00001oooool2o`0000Cooooo0ol00005ooooo`;o00003?ooool2
o`0000?ooooo2_l0001Wooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?oo
ool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0G?ooool?o`0000?ooooo
0_l000000ooooooo0000o`000002ooooo`?o00001Oooool2o`000003ooooool0003o000000Cooooo
0_l000000ooooooo0000o`000008ooooo`;o00005Oooool2o`0000?ooooo0_l00005ooooo`?o0000
1Oooool2o`0000Cooooo0ol00004ooooo`;o00001_ooool2o`0000?ooooo2_l0001Wooooo`0000?o
oooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`1Nooooo`go00001_ooool2o`0000[ooooo0_l000000ooooooo0000
o`000004ooooo`;o00002oooool2o`0000Oooooo0ol00006ooooo`;o00000oooool2o`0000?ooooo
0ol00004ooooo`;o00003?ooool2o`0000Gooooo0_l0000:ooooo`[o0000J?ooool00003ooooool0
003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo
0ol0001Oooooo`co000000?oooooo`000?l000000oooool2o`000004ooooool0003o0000ooooo`Ko
00007_ooool4o`0000Kooooo0_l00009ooooo`;o00001_ooool4o`0001[ooooo2ol0001Xooooo`00
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`01_ooool00ol0003oooooooooo`1Oooooo`co000000?oooooo`000?l000001_ooool2o`000003
ooooool0003o000000Co00005oooool2o`0000Cooooo1Ol0000Iooooo`Co00001_ooool2o`0001;o
oooo2_l0001Yooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`03oeEE
EOn7QhOooooo00Sooooo00?o0000ooooooooool0H?ooool;o`000003ooooool0003o000000;o0000
1?ooool2o`0000?ooooo0_l0000:ooooo`;o000000?oooooo`000?l000001Oooool2o`0000;ooooo
0ol00004ooooo`;o000000?oooooo`000?l000006Oooool3o`0000Oooooo0ol00004ooooo`?o0000
2_ooool:o`0006Wooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nH
V9P02?ooool00ol0003oooooooooo`1Poooooa3o00001?ooool7o`0000;ooooo0_l00006ooooo`;o
000000?oooooo`000?l000001Oooool2o`000004ooooool0003o0000o`0000Cooooo0_l00005oooo
o`;o000000?oooooo`000?l000000oooool2o`0000[ooooo0_l00002ooooo`?o00002?ooool2o`00
00Cooooo0ol0000:ooooo`Wo0000J_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool0
1?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo067ooooo2ol0000:ooooo`?o00001?oo
ool2o`0001?ooooo0_l00005ooooo`;o00001Oooool2o`000003ooooool0003o000000?ooooo0_l0
0004ooooo`;o000000Coooooo`000?l0003ooooo1Ol00009ooooo`Co000000?oooooo`000?l00000
0ol00007ooooo`_o0000Joooool001cooooo00?o0000ooooooooool0H_ooool;o`0000;ooooo0_l0
000:ooooo`;o00002_ooool2o`000003ooooool0003o0000027ooooo0ol000000ooooooo0000o`00
0003ooooo`?o00002Oooool4o`000003ooooool0003o000000?o00001oooool:o`0006cooooo000L
ooooo`03o`000?oooooooooo06;ooooo3?l000000ooooooo0000o`00000:ooooo`;o00001?ooool2
o`0000Cooooo0_l000000ooooooo0000o`00000Hooooo`;o00001oooool2o`0001Oooooo0_l0000;
ooooo`[o0000K?ooool001cooooo00?o0000ooooooooool0Hoooool;o`0000_ooooo0_l00006oooo
o`;o00003_ooool2o`0000Oooooo0_l00007ooooo`?o00004Oooool2o`0000gooooo0_l00008oooo
o`;o000000?oooooo`000?l000002?l0001/ooooo`007?ooool00ol0003oooooooooo`1Sooooo`ko
00002?ooool3o`0000;ooooo0_l00009ooooo`;o00001_ooool2o`0000Oooooo0_l00007ooooo`Co
00004?ooool2o`0000Cooooo0_l00006ooooo`;o00001?ooool2o`0000;ooooo0ol000000ooooooo
0000o`000006o`0006kooooo000Looooo`03o`000?oooooooooo06?ooooo3_l00009ooooo`;o0000
0_ooool2o`0000Wooooo0_l000000ooooooo0000o`000008ooooo`;o00002_ooool2o`000004oooo
ool0003o0000ooooo`;o00002Oooool2o`0000Gooooo0_l000000ooooooo0000o`000004ooooo`Co
00001?ooool6o`000003ooooool0003o000000Oo0000K_ooool001cooooo00?o0000ooooooooool0
I?ooool;o`0000;ooooo0_l000000ooooooo0000o`000003o`0000[ooooo0_l00007ooooo`;o0000
1_ooool4o`0000[ooooo0ol00003ooooo`;o00001oooool4o`0000Gooooo0_l00007ooooo`;o0000
1oooool4o`0000;ooooo2?l0001_ooooo`007?ooool00ol0003oooooooooo`1UoooooaCo00002_oo
ool2o`0000Oooooo1?l00004ooooo`?o00000oooool2o`0000Kooooo0ol000000ooooooo0000o`00
0009ooooo`;o00001?ooool2o`0000Cooooo0_l0000=ooooo`go0000L?ooool001cooooo00?o0000
ooooooooool0IOooool@o`0001Wooooo0_l00005ooooo`;o00000oooool2o`0000[ooooo0_l0000?
ooooo`?o00000oooool2o`0000Cooooo0_l00004ooooo`;o00001Oooool9o`00073ooooo000Loooo
o`03o`000?oooooooooo06Kooooo3_l00008ooooo`;o00002Oooool2o`0000oooooo0_l000000ooo
oooo0000o`000006ooooo`;o00003?ooool2o`0000Gooooo0_l00004ooooo`;o00000oooool2o`00
00Cooooo0_l00002ooooo`_o0000LOooool001cooooo00?o0000ooooooooool0Ioooool<o`0000Wo
oooo0ol00003ooooo`;o00000oooool2o`0000cooooo0_l000001?oooooo0000o`000?ooool5o`00
0003ooooool0003o000000;o00002oooool3o`0000?ooooo0_l000001?oooooo0000o`000?ooool8
o`0000?ooooo0_l00004ooooo`_o0000LOooool001cooooo00?o0000ooooooooool0J?ooool<o`00
00Wooooo0_l00003ooooo`;o00003oooool4o`0000?ooooo1_l000001?oooooo0000o`000?l0000<
ooooo`?o00000oooool2o`000004ooooool0003o0000ooooo`;o00000_ooool4o`0000?ooooo0_l0
0003ooooo`Wo0000M?ooool001cooooo0_l0001Yooooo`ko00001_ooool2o`0000oooooo0_l00004
ooooo`Co00000oooool2o`0001Kooooo0_l00008ooooo`;o00001oooool2o`0000Cooooo2_l0001d
ooooo`007?ooool00ol0003oooooooooo`1Zooooo`ko00000_ooool5o`0000kooooo0_l0000;oooo
o`;o00002oooool2o`0000Wooooo0_l00007ooooo`;o00002?ooool2o`0000?ooooo2ol0001doooo
o`007?ooool00ol0003oooooooooo`1[oooooa7o000000?oooooo`000?l000002_ooool2o`0000?o
oooo0_l000000ooooooo0000o`00000@ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`00
00?ooooo1?l00005ooooo`Co00001oooool2o`0000?ooooo3?l0001dooooo`007?ooool00ol0003o
ooooooooo`1/ooooo`oo00003_ooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`000003
ooooool0003o000000Sooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo1?l000000ooo
oooo0000o`000002o`0000Cooooo0ol00009oooooa7o0000M?ooool001cooooo00?o0000oooooooo
ool0K?oooolBo`0000Sooooo0_l000000ooooooo0000o`000007ooooo`?o000000?oooooo`000?l0
00002?ooool2o`0000?ooooo0_l00005ooooo`?o000000?oooooo`000?l000001_ooool3o`0000_o
oooo3Ol0001fooooo`007?ooool00ol0003oooooooooo`1_oooooa3o00001oooool2o`000003oooo
ool0003o000000Wooooo1Ol00009ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`0000;o
oooo0_l0000Cooooo`go0000Moooool001cooooo00?o0000ooooooooool0LOooool@o`0001?ooooo
1Ol00003ooooo`;o00001?ooool2o`0000;ooooo0_l0000<ooooo`?o00001Oooool2o`0000;ooooo
0_l000000ooooooo0000o`00000=o`0007Oooooo000Looooo`03o`000?oooooooooo07?ooooo3ol0
0006ooooo`;o00001?ooool2o`0000cooooo0_l00004ooooo`;o00001_ooool2o`0000Sooooo0ol0
0004ooooo`?o00000_ooool2o`000003ooooool0003o000000_o0000NOooool001cooooo00?o0000
ooooooooool0LooooolBo`0000?ooooo1?l000000ooooooo0000o`000002o`0000gooooo0_l00002
ooooo`;o00001_ooool2o`0000oooooo0_l000001?oooooo0000o`000?ooool?o`0007Wooooo000L
ooooo`03o`000?oooooooooo07Oooooo5Ol000000ooooooo0000o`000002o`0000gooooo0_l00008
ooooo`;o00000oooool2o`0000Oooooo0_l00006ooooo`co000000?oooooo`000?l000000ol0001i
ooooo`007?ooool00ol0003oooooooooo`1hoooooaKo00000oooool2o`000003ooooool0003o0000
00;o00002?ooool2o`0000Kooooo0_l00003ooooo`?o00001?ooool5o`0000Gooooo2ol000000ooo
oooo0000o`000002o`0007_ooooo000Looooo`03o`000?oooooooooo07[ooooo5?l00003ooooo`;o
000000?oooooo`000?l000000_l00008ooooo`;o000000?oooooo`000?l000001oooool4o`0000Co
oooo1Ol00003oooooa3o0000OOooool001cooooo00?o0000ooooooooool0OOoooolAo`0000;ooooo
0ol0000>ooooo`Co00001_ooool3o`0000Sooooo0ol00003oooooa3o0000OOooool001cooooo00?o
0000ooooooooool0OOoooolFo`0000Oooooo0_l00005ooooo`;o00001oooool6o`0000Kooooo1Ol0
00000ooooooo0000o`00000=o`0007kooooo000Looooo`03o`000?oooooooooo07kooooo5?l00002
ooooo`;o00001?ooool2o`0000kooooo1_l00005oooooaGo0000Ooooool001cooooo00?o0000oooo
ooooool0P_oooolJo`0000Cooooo1Ol00002ooooo`;o00000_ooool4o`0000Gooooo5?l00021oooo
o`007?ooool2o`0008?ooooo:?l000000ooooooo0000o`00000Jo`0008;ooooo000Looooo`03o`00
0?oooooooooo08Cooooo7?l000000ooooooo0000o`00000Ro`0008Cooooo000Looooo`03o`000?oo
oooooooo08Gooooo?ol00025ooooo`007?ooool00ol0003oooooooooo`28oooooc_o0000Q_ooool0
01cooooo00?o0000ooooooooool0Roooooleo`0008Wooooo000Looooo`03o`000?oooooooooo08ko
oooo<?l0002;ooooo`007?ooool00ol0003oooooooooo`2?ooooobko0000S?ooool001cooooo00?o
0000ooooooooool0U_oooolSo`000003ooooool0003o000008gooooo000Looooo`03o`000?oooooo
oooo09Oooooo8_l0002@ooooo`007?ooool00ol0003oooooooooo`2OoooooaGo0000UOooool001co
oooo00?o0000ooooooooool0Y?ooool;o`000004ooooool0003o0000o`0009Kooooo000Looooo`03
o`000?oooooooooo0:Oooooo1Ol0002Mooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo00001_oo
ooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0
1_ooool00ol0003oooooooooo`3ooooood[ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Go
oooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`3ooooo
od[ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo0?ooooooB_ooool00003ooooool0003ooooo00;o
oooo00?o0000ooooooooool02Oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0003ooooo
od[ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Goc<c<o`000?l0
003o0000olc<c006ooooo`03o`000?oooooooooo0?ooooooB_ooool00003ooooool@413ooooo00;o
oooo00?o410@ooooooooool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000oooo
ooooool0oooooom:ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooookZj^_l000001_ooool00ol0003oooooooooo`3ooooood[ooooo00001_ooooook^k^oc8b<_l0
003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooo
od_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001;ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB_ooool0
01Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03
o`000?oooooooooo00Gooooo0ol0003ooooood[ooooo000Dooooo`03o`000?oooooooooo0?oooooo
D_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3o
oooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001;ooooo00?oEEEEofIVI_l0
0000oooooomDooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00ZOooool01?l@
413o0000o`000?ooool2o`000003oa0@4?oooooooooo01Kooooo1?l000000ol@413oooooooooo`05
o`0009Cooooo002Zooooo`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo00?o0000
ooooooooool00_ooool01OnHV9So8B4Qonk^k_ooooooA4A409Cooooo002Zooooo`05o`000?oooooo
ooooooooool000006oooool00ol0003oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^09Gooooo002Z
ooooo`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo00?o0000ooooooooool01?oo
ool00onHV9So8B4Qonk^kP2Dooooo`00Z_ooool01Ol0003oQhN7oooooonYZJWo000001_ooooo00?o
0000ooooooooool01Oooool00omgMgOoIVIVooooo`2Cooooo`00ZOooool00ol@413o0000ogMgM`02
o`000003oiRHV?oooooooooo01Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2B
ooooo`00b_ooool00ol0003oooooooooo`02ooooo`05o`000?nj^[[ooooooiRHV?l@4100U?ooool0
0<Sooooo00?oEEEEofIVI_l000001?ooool01OnHV9So410@o`000?lQ8B7oc<c<09Cooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -20 0 ]
[.5 1.0125 20 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(18) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.68747 .42994 Mdot
.67064 .37019 Mdot
.42608 .30986 Mdot
.38052 .65986 Mdot
.34118 .63803 Mdot
.44787 .30169 Mdot
.63026 .34041 Mdot
.60934 .31261 Mdot
.36405 .32459 Mdot
.36411 .65051 Mdot
.52369 .27841 Mdot
.62934 .68088 Mdot
.62308 .33426 Mdot
.43491 .69506 Mdot
.56541 .70677 Mdot
.70671 .57152 Mdot
.69742 .41126 Mdot
.34142 .63705 Mdot
.65939 .62693 Mdot
.37431 .31338 Mdot
.31808 .41142 Mdot
.40404 .67381 Mdot
.69761 .39776 Mdot
.4398 .70205 Mdot
.66299 .62626 Mdot
.69753 .54129 Mdot
.68669 .43113 Mdot
.67284 .61752 Mdot
.64089 .66338 Mdot
.5894 .29557 Mdot
.68796 .59209 Mdot
.4722 .72034 Mdot
.31504 .43965 Mdot
.72051 .47719 Mdot
.49571 .28196 Mdot
.55209 .28564 Mdot
.40694 .31835 Mdot
.55978 .29498 Mdot
.61417 .30878 Mdot
.50216 .28702 Mdot
.50051 .28479 Mdot
.69889 .5449 Mdot
.54358 .27933 Mdot
.65392 .3566 Mdot
.46445 .71033 Mdot
.72657 .51826 Mdot
.32376 .39826 Mdot
.49926 .7029 Mdot
.6878 .42414 Mdot
.32082 .39969 Mdot
.53591 .72234 Mdot
.64252 .35281 Mdot
.29828 .48296 Mdot
.71059 .42722 Mdot
.60857 .32325 Mdot
.6641 .62716 Mdot
.40129 .30455 Mdot
.55869 .7194 Mdot
.63246 .66424 Mdot
.72122 .48431 Mdot
.4337 .70335 Mdot
.31369 .56463 Mdot
.64554 .6511 Mdot
.41265 .28907 Mdot
.38535 .32161 Mdot
.53962 .30454 Mdot
.70268 .39616 Mdot
.55147 .29443 Mdot
.44384 .69955 Mdot
.36579 .34891 Mdot
.55677 .71455 Mdot
.52259 .2784 Mdot
.71096 .51695 Mdot
.3868 .66134 Mdot
.67621 .40751 Mdot
.53719 .28746 Mdot
.34059 .64163 Mdot
.70483 .53559 Mdot
.30836 .40902 Mdot
.37817 .67135 Mdot
.41327 .68334 Mdot
.51161 .26723 Mdot
.61147 .67397 Mdot
.69928 .55676 Mdot
.4882 .71838 Mdot
.56214 .28757 Mdot
.36818 .65041 Mdot
.68978 .58809 Mdot
.67933 .61322 Mdot
.63589 .67594 Mdot
.34982 .34866 Mdot
.68766 .37576 Mdot
.39283 .66258 Mdot
.48743 .7308 Mdot
.52098 .71699 Mdot
.49426 .71891 Mdot
.68236 .61099 Mdot
.311 .42822 Mdot
.51923 .29047 Mdot
.30821 .46624 Mdot
.54653 .29084 Mdot
.2926 .50066 Mdot
.47166 .72212 Mdot
.43544 .29257 Mdot
.71226 .45399 Mdot
.30842 .43291 Mdot
.53177 .28964 Mdot
.39236 .66051 Mdot
.55821 .29146 Mdot
.68339 .375 Mdot
.69011 .59306 Mdot
.3115 .60551 Mdot
.3249 .63196 Mdot
.69355 .4451 Mdot
.51884 .73583 Mdot
.36744 .65254 Mdot
.41878 .68435 Mdot
.70054 .3906 Mdot
.36974 .32206 Mdot
.33738 .36199 Mdot
.67576 .38319 Mdot
.51205 .2891 Mdot
.69717 .42013 Mdot
.28876 .54968 Mdot
.37175 .32534 Mdot
.30457 .45153 Mdot
.28802 .46131 Mdot
.45742 .71091 Mdot
.49886 .71921 Mdot
.2767 .53312 Mdot
.44131 .29053 Mdot
.67509 .38365 Mdot
.61762 .3268 Mdot
.49048 .73282 Mdot
.71987 .53039 Mdot
.60629 .32212 Mdot
.32259 .60416 Mdot
.31179 .61513 Mdot
.71582 .51369 Mdot
.51996 .73317 Mdot
.56781 .30451 Mdot
.63905 .33521 Mdot
.55235 .72213 Mdot
.72377 .51963 Mdot
.33287 .61802 Mdot
.63944 .33523 Mdot
.29841 .51494 Mdot
.69292 .59446 Mdot
.59833 .70795 Mdot
.5329 .27031 Mdot
.53662 .72064 Mdot
.33195 .39377 Mdot
.30337 .55216 Mdot
.60114 .31554 Mdot
.37741 .65986 Mdot
.69107 .41118 Mdot
.7213 .50897 Mdot
.60267 .69331 Mdot
.3118 .43268 Mdot
.56346 .72522 Mdot
.28871 .51611 Mdot
.2937 .44684 Mdot
.4257 .68535 Mdot
.72581 .49569 Mdot
.71699 .45047 Mdot
.55735 .71558 Mdot
.38053 .32673 Mdot
.34388 .64507 Mdot
.52147 .27579 Mdot
.49133 .71304 Mdot
.50993 .71272 Mdot
.60706 .69434 Mdot
.64387 .34505 Mdot
.48291 .27801 Mdot
.33496 .37654 Mdot
.54554 .30299 Mdot
.50486 .27432 Mdot
.4295 .28724 Mdot
.62814 .67621 Mdot
.30061 .59704 Mdot
.28078 .50299 Mdot
.5551 .7161 Mdot
.45184 .70393 Mdot
.62961 .68267 Mdot
.28301 .45837 Mdot
.2782 .47061 Mdot
.70732 .45785 Mdot
.53317 .27403 Mdot
.40049 .68316 Mdot
.64625 .64287 Mdot
.51944 .72263 Mdot
.57321 .3027 Mdot
.61647 .32209 Mdot
.44304 .27982 Mdot
.3801 .30753 Mdot
.34239 .37415 Mdot
.5865 .68898 Mdot
.57245 .70252 Mdot
.40519 .68281 Mdot
.30181 .46636 Mdot
.67118 .63293 Mdot
.30519 .55474 Mdot
.69461 .40875 Mdot
.50606 .26791 Mdot
.59063 .7128 Mdot
.66835 .60892 Mdot
.34659 .34354 Mdot
.32284 .37672 Mdot
.27598 .5063 Mdot
.29914 .56923 Mdot
.54461 .71728 Mdot
.69898 .44482 Mdot
.54076 .72201 Mdot
.31434 .44319 Mdot
.32022 .62989 Mdot
.68033 .38325 Mdot
.50666 .70463 Mdot
.62042 .3349 Mdot
.48228 .29685 Mdot
.36708 .64859 Mdot
.38924 .65781 Mdot
.70741 .53428 Mdot
.49041 .73029 Mdot
.6532 .63687 Mdot
.68217 .60193 Mdot
.34844 .36584 Mdot
.54247 .29673 Mdot
.59326 .29533 Mdot
.31958 .40366 Mdot
.7163 .525 Mdot
.65694 .36031 Mdot
.42577 .29946 Mdot
.32226 .40733 Mdot
.53551 .27915 Mdot
.31273 .58439 Mdot
.43401 .29595 Mdot
.33533 .62001 Mdot
.63818 .66061 Mdot
.45949 .28768 Mdot
.31744 .60345 Mdot
.57366 .70577 Mdot
.28603 .47417 Mdot
.2999 .60624 Mdot
.63046 .34251 Mdot
.66715 .35897 Mdot
.56476 .71676 Mdot
.29091 .49405 Mdot
.31454 .45012 Mdot
.62564 .67654 Mdot
.28602 .46083 Mdot
.29504 .45336 Mdot
.62295 .68093 Mdot
.34231 .6348 Mdot
.4944 .27344 Mdot
.68812 .59244 Mdot
.69704 .41422 Mdot
.44799 .70329 Mdot
.51842 .29823 Mdot
.60389 .31966 Mdot
.38779 .67844 Mdot
.56271 .28933 Mdot
.63035 .34413 Mdot
.42396 .68565 Mdot
.60005 .30285 Mdot
.70844 .54732 Mdot
.59071 .71336 Mdot
.71052 .51089 Mdot
.43338 .69408 Mdot
.60512 .30451 Mdot
.32009 .40222 Mdot
.70374 .54308 Mdot
.39537 .66763 Mdot
.38704 .66832 Mdot
.30021 .47198 Mdot
.68683 .59712 Mdot
.57897 .30001 Mdot
.62977 .67988 Mdot
.47651 .28592 Mdot
.59014 .69281 Mdot
.30355 .53823 Mdot
.29272 .54348 Mdot
.72415 .51578 Mdot
.28969 .44988 Mdot
.43827 .29985 Mdot
.5247 .71573 Mdot
.53567 .71119 Mdot
.47611 .71588 Mdot
.29294 .46155 Mdot
.60945 .67509 Mdot
.60188 .32366 Mdot
.68349 .61433 Mdot
.27711 .53099 Mdot
.40427 .30736 Mdot
.29897 .48951 Mdot
.49118 .71909 Mdot
.6947 .38953 Mdot
.69139 .58218 Mdot
.47227 .28581 Mdot
.69301 .39105 Mdot
.51203 .70767 Mdot
.55088 .29515 Mdot
.31311 .55588 Mdot
.57784 .29588 Mdot
.66755 .61527 Mdot
.59278 .69332 Mdot
.36356 .35004 Mdot
.70938 .541 Mdot
.6017 .31263 Mdot
.7106 .51479 Mdot
.5564 .72564 Mdot
.55187 .72967 Mdot
.72423 .50888 Mdot
.29669 .54068 Mdot
.32188 .38755 Mdot
.52991 .27969 Mdot
.30079 .45933 Mdot
.36275 .3457 Mdot
.69102 .42749 Mdot
.442 .29365 Mdot
.53503 .73516 Mdot
.48509 .29678 Mdot
.68973 .58364 Mdot
.36609 .34541 Mdot
.59768 .6976 Mdot
.46387 .71191 Mdot
.42536 .28407 Mdot
.31497 .42744 Mdot
.55137 .71932 Mdot
.71414 .53967 Mdot
.43515 .68884 Mdot
.36239 .64725 Mdot
.58227 .6938 Mdot
.40455 .30641 Mdot
.52405 .73312 Mdot
.67554 .60898 Mdot
.66586 .61999 Mdot
.69129 .40302 Mdot
.29286 .47876 Mdot
.32577 .61423 Mdot
.3053 .61219 Mdot
.29685 .52476 Mdot
.62807 .68565 Mdot
.53794 .73156 Mdot
.71971 .52047 Mdot
.32799 .39076 Mdot
.66562 .35563 Mdot
.31417 .44192 Mdot
.61035 .31266 Mdot
.48669 .27747 Mdot
.36715 .64782 Mdot
.34911 .64131 Mdot
.69386 .57788 Mdot
.68372 .41734 Mdot
.71015 .52184 Mdot
.60255 .31206 Mdot
.6619 .64313 Mdot
.38013 .67316 Mdot
.38981 .68 Mdot
.62109 .31676 Mdot
.31158 .44545 Mdot
.62204 .6705 Mdot
.53719 .70877 Mdot
.65195 .35346 Mdot
.47322 .71059 Mdot
.71382 .48029 Mdot
.44483 .69284 Mdot
.47664 .7237 Mdot
.45821 .69941 Mdot
.71688 .53303 Mdot
.69283 .57657 Mdot
.53742 .70963 Mdot
.33842 .35351 Mdot
.5932 .71251 Mdot
.29342 .57753 Mdot
.38962 .66275 Mdot
.54504 .71663 Mdot
.3292 .6099 Mdot
.69423 .44397 Mdot
.4997 .70971 Mdot
.53564 .27242 Mdot
.39722 .66749 Mdot
.52394 .27546 Mdot
.60825 .68381 Mdot
.49061 .72633 Mdot
.67629 .61034 Mdot
.69781 .39709 Mdot
.62054 .31343 Mdot
.50724 .27892 Mdot
.27833 .52523 Mdot
.603 .3187 Mdot
.48712 .71533 Mdot
.60632 .68347 Mdot
.69412 .44567 Mdot
.28714 .47067 Mdot
.68694 .37379 Mdot
.35643 .65216 Mdot
.63282 .3388 Mdot
.29486 .49339 Mdot
.64909 .65053 Mdot
.63307 .33344 Mdot
.51944 .26999 Mdot
.69096 .59197 Mdot
.31169 .44606 Mdot
.69066 .43273 Mdot
.36464 .34763 Mdot
.30428 .44335 Mdot
.60514 .31933 Mdot
.46175 .70826 Mdot
.68806 .60443 Mdot
.59835 .30721 Mdot
.70674 .49305 Mdot
.69639 .59012 Mdot
.39696 .66573 Mdot
.69548 .54536 Mdot
.68831 .37125 Mdot
.57434 .72171 Mdot
.40686 .69029 Mdot
.42388 .30669 Mdot
.29474 .45949 Mdot
.29379 .46465 Mdot
.30351 .4335 Mdot
.49213 .29485 Mdot
.32937 .3778 Mdot
.53549 .29718 Mdot
.44357 .69774 Mdot
.53658 .30176 Mdot
.29104 .49653 Mdot
.42603 .30673 Mdot
.45495 .7034 Mdot
.67244 .63638 Mdot
.64111 .33565 Mdot
.36063 .34293 Mdot
.37518 .65007 Mdot
.69286 .41622 Mdot
.64303 .34905 Mdot
.57135 .70383 Mdot
.35445 .36202 Mdot
.31328 .56198 Mdot
.51662 .73056 Mdot
.63459 .33246 Mdot
.70796 .48085 Mdot
.6331 .33037 Mdot
.53329 .71445 Mdot
.48369 .70686 Mdot
.67166 .38607 Mdot
.29339 .56973 Mdot
.62939 .67907 Mdot
.43878 .70245 Mdot
.31488 .40569 Mdot
.66509 .36073 Mdot
.29254 .56604 Mdot
.64716 .65786 Mdot
.28284 .47997 Mdot
.34694 .64611 Mdot
.4032 .68016 Mdot
.61675 .68778 Mdot
.28718 .53723 Mdot
.58915 .3004 Mdot
.29567 .59282 Mdot
.34656 .34523 Mdot
.68625 .38504 Mdot
.53813 .29783 Mdot
.31164 .42231 Mdot
.52365 .2797 Mdot
.61376 .69583 Mdot
.28576 .51155 Mdot
.65284 .35944 Mdot
.35409 .63736 Mdot
.29122 .46021 Mdot
.39785 .30771 Mdot
.55925 .72351 Mdot
.62411 .68251 Mdot
.39668 .665 Mdot
.32464 .61308 Mdot
.67268 .36391 Mdot
.51426 .27231 Mdot
.61573 .30754 Mdot
.42638 .68447 Mdot
.72431 .51517 Mdot
.70281 .47389 Mdot
.30481 .47276 Mdot
.30795 .59604 Mdot
.31256 .58762 Mdot
.42393 .6816 Mdot
.63735 .65867 Mdot
.71745 .52913 Mdot
.39472 .66699 Mdot
.43052 .68754 Mdot
.34378 .36364 Mdot
.69287 .54431 Mdot
.4537 .28655 Mdot
.65941 .62134 Mdot
.50865 .72829 Mdot
.54889 .29695 Mdot
.61186 .32981 Mdot
.29399 .47186 Mdot
.59343 .29527 Mdot
.33682 .37203 Mdot
.29358 .46479 Mdot
.39556 .66824 Mdot
.6859 .43543 Mdot
.39345 .66526 Mdot
.39588 .66638 Mdot
.45703 .70128 Mdot
.53625 .73122 Mdot
.32857 .3671 Mdot
.30293 .59521 Mdot
.64258 .65896 Mdot
.44252 .28387 Mdot
.34874 .34072 Mdot
.52415 .71857 Mdot
.39805 .67419 Mdot
.41746 .68164 Mdot
.69646 .52891 Mdot
.68947 .60574 Mdot
.62515 .32532 Mdot
.67115 .38471 Mdot
.37722 .66383 Mdot
.33172 .3896 Mdot
.49366 .70758 Mdot
.72159 .50258 Mdot
.49364 .28566 Mdot
.57934 .30385 Mdot
.28404 .4679 Mdot
.31108 .46426 Mdot
.29424 .45672 Mdot
.31576 .42125 Mdot
.54679 .2816 Mdot
.42633 .30716 Mdot
.30531 .53434 Mdot
.5517 .73045 Mdot
.40758 .68918 Mdot
.49306 .71031 Mdot
.35054 .35345 Mdot
.29927 .50429 Mdot
.54267 .72849 Mdot
.70487 .58981 Mdot
.47588 .2981 Mdot
.30594 .43293 Mdot
.69373 .56749 Mdot
.68604 .38032 Mdot
.35648 .35722 Mdot
.55886 .29425 Mdot
.31877 .60684 Mdot
.32295 .40209 Mdot
.68033 .36825 Mdot
.64282 .65158 Mdot
.47026 .30039 Mdot
.60849 .68112 Mdot
.67797 .62858 Mdot
.45168 .29457 Mdot
.67965 .61867 Mdot
.70353 .40053 Mdot
.28734 .46717 Mdot
.59904 .68792 Mdot
.62263 .67811 Mdot
.43056 .2806 Mdot
.38333 .65978 Mdot
.34466 .35319 Mdot
.40131 .30794 Mdot
.28742 .48721 Mdot
.40506 .30635 Mdot
.59791 .3194 Mdot
.42248 .29297 Mdot
.70166 .50566 Mdot
.45805 .7137 Mdot
.71092 .43751 Mdot
.59073 .70478 Mdot
.37379 .66207 Mdot
.63727 .34982 Mdot
.52554 .29944 Mdot
.42512 .69814 Mdot
.33855 .63484 Mdot
.40118 .31002 Mdot
.33269 .38206 Mdot
.6808 .61491 Mdot
.35798 .34918 Mdot
.69811 .39717 Mdot
.54319 .29335 Mdot
.52622 .29967 Mdot
.29835 .45067 Mdot
.72138 .52818 Mdot
.56544 .29649 Mdot
.5124 .2898 Mdot
.31259 .55465 Mdot
.57477 .71942 Mdot
.71528 .46436 Mdot
.6215 .671 Mdot
.33909 .62955 Mdot
.39963 .66939 Mdot
.44738 .2862 Mdot
.34046 .37408 Mdot
.54657 .70673 Mdot
.42562 .30078 Mdot
.29673 .46589 Mdot
.70853 .47293 Mdot
.66116 .62904 Mdot
.67315 .37015 Mdot
.4925 .73173 Mdot
.53976 .29848 Mdot
.69024 .3844 Mdot
.30055 .43074 Mdot
.42706 .70353 Mdot
.72569 .5001 Mdot
.65318 .65553 Mdot
.39835 .66702 Mdot
.37785 .32207 Mdot
.33045 .61263 Mdot
.33049 .39875 Mdot
.35063 .34656 Mdot
.30694 .56446 Mdot
.6616 .36135 Mdot
.3736 .32335 Mdot
.30683 .57624 Mdot
.29136 .55541 Mdot
.30379 .43153 Mdot
.29993 .58517 Mdot
.48915 .71765 Mdot
.5975 .31195 Mdot
.66874 .36629 Mdot
.46864 .70015 Mdot
.36377 .65127 Mdot
.71174 .43174 Mdot
.30261 .46953 Mdot
.40195 .66828 Mdot
.56895 .72073 Mdot
.72076 .5041 Mdot
.50008 .26967 Mdot
.40124 .29683 Mdot
.30778 .45481 Mdot
.67505 .37021 Mdot
.51167 .2671 Mdot
.38364 .321 Mdot
.31504 .58181 Mdot
.58769 .30384 Mdot
.68346 .43212 Mdot
.29876 .47957 Mdot
.63038 .34155 Mdot
.35534 .34386 Mdot
.53435 .7216 Mdot
.70384 .58638 Mdot
.45912 .30523 Mdot
.53624 .7219 Mdot
.68417 .58877 Mdot
.34464 .3722 Mdot
.48662 .27606 Mdot
.68319 .37408 Mdot
.61246 .31023 Mdot
.3117 .59393 Mdot
.70914 .51806 Mdot
.68602 .37312 Mdot
.61094 .32912 Mdot
.71348 .43035 Mdot
.60363 .67893 Mdot
.53513 .2873 Mdot
.62492 .66638 Mdot
.54511 .72056 Mdot
.29618 .48286 Mdot
.30193 .59746 Mdot
.54341 .29576 Mdot
.69761 .54248 Mdot
.64898 .34341 Mdot
.50204 .72108 Mdot
.69276 .60125 Mdot
.31482 .61166 Mdot
.70905 .44152 Mdot
.47984 .27555 Mdot
.62706 .32796 Mdot
.31678 .40338 Mdot
.33656 .63328 Mdot
.47853 .7188 Mdot
.37542 .33584 Mdot
.48529 .71046 Mdot
.64594 .35601 Mdot
.68391 .58846 Mdot
.68505 .38914 Mdot
.53427 .28406 Mdot
.69875 .57434 Mdot
.63681 .6709 Mdot
.4157 .69392 Mdot
.34817 .3653 Mdot
.70524 .46105 Mdot
.29196 .54195 Mdot
.36292 .6439 Mdot
.42959 .70531 Mdot
.31456 .45539 Mdot
.46051 .71339 Mdot
.49436 .27484 Mdot
.31274 .43373 Mdot
.47441 .29619 Mdot
.2896 .46034 Mdot
.29864 .46555 Mdot
.69988 .43825 Mdot
.34091 .37723 Mdot
.31237 .46176 Mdot
.38499 .67651 Mdot
.40317 .66589 Mdot
.6233 .3151 Mdot
.60228 .68164 Mdot
.62253 .6747 Mdot
.46275 .28252 Mdot
.31355 .55474 Mdot
.51346 .71098 Mdot
.7041 .55219 Mdot
.31562 .61744 Mdot
.28968 .5183 Mdot
.69311 .3943 Mdot
.49247 .7202 Mdot
.3437 .36319 Mdot
.28764 .47258 Mdot
.29412 .51358 Mdot
.31673 .60825 Mdot
.64594 .34946 Mdot
.7158 .49508 Mdot
.40004 .30814 Mdot
.70185 .58021 Mdot
.35288 .64722 Mdot
.35339 .35719 Mdot
.29532 .48325 Mdot
.28032 .51818 Mdot
.72373 .51522 Mdot
.70346 .50296 Mdot
.31339 .4197 Mdot
.4477 .28303 Mdot
.55825 .28782 Mdot
.52335 .2832 Mdot
.6014 .69293 Mdot
.58155 .29668 Mdot
.68424 .37497 Mdot
.5085 .72541 Mdot
.31135 .5846 Mdot
.63355 .33525 Mdot
.29795 .44949 Mdot
.67885 .37182 Mdot
.70314 .51402 Mdot
.44083 .70475 Mdot
.40443 .67536 Mdot
.32129 .40126 Mdot
.46926 .71793 Mdot
.64666 .34762 Mdot
.32554 .60896 Mdot
.41166 .31139 Mdot
.68411 .61072 Mdot
.69196 .41176 Mdot
.33778 .38614 Mdot
.64361 .66627 Mdot
.4133 .29145 Mdot
.67087 .37462 Mdot
.32346 .62066 Mdot
.30254 .59348 Mdot
.50649 .72677 Mdot
.33635 .38879 Mdot
.63527 .34533 Mdot
.72063 .52729 Mdot
.66236 .36023 Mdot
.63748 .66482 Mdot
.39865 .67356 Mdot
.66769 .62761 Mdot
.52052 .27309 Mdot
.49081 .71586 Mdot
.32033 .61131 Mdot
.70725 .42912 Mdot
.46155 .70972 Mdot
.3275 .6298 Mdot
.29153 .54417 Mdot
.27799 .51435 Mdot
.40455 .29097 Mdot
.32826 .62475 Mdot
.33163 .6281 Mdot
.32015 .62686 Mdot
.48789 .27743 Mdot
.58057 .70341 Mdot
.35026 .64039 Mdot
.38422 .66256 Mdot
.55583 .72315 Mdot
.70148 .59038 Mdot
.54347 .30239 Mdot
.36295 .35181 Mdot
.53802 .71602 Mdot
.38712 .6681 Mdot
.70737 .42292 Mdot
.70661 .5731 Mdot
.51978 .71056 Mdot
.69224 .39776 Mdot
.71932 .4673 Mdot
.38741 .30266 Mdot
.57947 .30839 Mdot
.37485 .33923 Mdot
.65367 .65276 Mdot
.66119 .64762 Mdot
.70535 .44134 Mdot
.59351 .30938 Mdot
.65444 .65124 Mdot
.64674 .35195 Mdot
.70562 .41676 Mdot
.70273 .59179 Mdot
.70539 .49556 Mdot
.31559 .56679 Mdot
.52334 .71216 Mdot
.61651 .33493 Mdot
.53992 .7161 Mdot
.60322 .32242 Mdot
.36277 .64943 Mdot
.65642 .64883 Mdot
.38064 .66444 Mdot
.44802 .69944 Mdot
.28383 .45489 Mdot
.40304 .67627 Mdot
.30939 .40847 Mdot
.68824 .40826 Mdot
.3492 .64422 Mdot
.6489 .64417 Mdot
.5519 .7204 Mdot
.41174 .67687 Mdot
.71206 .43095 Mdot
.42172 .68767 Mdot
.37015 .3402 Mdot
.65687 .65328 Mdot
.54028 .7148 Mdot
.61365 .32019 Mdot
.51372 .28208 Mdot
.69324 .44539 Mdot
.28447 .51453 Mdot
.70905 .43291 Mdot
.41937 .681 Mdot
.38986 .30825 Mdot
.29781 .5232 Mdot
.33138 .62346 Mdot
.66978 .37331 Mdot
.35684 .64158 Mdot
.54176 .27853 Mdot
.36308 .33383 Mdot
.69157 .58922 Mdot
.46549 .28939 Mdot
.42481 .28536 Mdot
.66487 .35768 Mdot
.3026 .59777 Mdot
.49194 .70452 Mdot
.72048 .48148 Mdot
.73104 .47819 Mdot
.63626 .66647 Mdot
.37987 .3139 Mdot
.28752 .53811 Mdot
.68691 .57998 Mdot
.32094 .58024 Mdot
.30476 .56869 Mdot
.61821 .33401 Mdot
.39063 .30567 Mdot
.30533 .45609 Mdot
.30831 .57859 Mdot
.38649 .30253 Mdot
.31185 .42286 Mdot
.31925 .39769 Mdot
.72011 .52271 Mdot
.54203 .73353 Mdot
.72786 .50257 Mdot
.60226 .29963 Mdot
.33434 .38466 Mdot
.71305 .53098 Mdot
.70479 .55285 Mdot
.29978 .46761 Mdot
.3791 .32943 Mdot
.70973 .46135 Mdot
.57011 .71814 Mdot
.27848 .49545 Mdot
.44435 .70733 Mdot
.33984 .64288 Mdot
.40404 .6674 Mdot
.34228 .37842 Mdot
.62655 .32473 Mdot
.41762 .30659 Mdot
.62119 .33687 Mdot
.47117 .7205 Mdot
.41427 .69804 Mdot
.39273 .66763 Mdot
.60956 .68331 Mdot
.70258 .43858 Mdot
.71702 .47705 Mdot
.40386 .299 Mdot
.4116 .30729 Mdot
.65888 .63849 Mdot
.69423 .42153 Mdot
.29436 .53298 Mdot
.64056 .65833 Mdot
.42188 .68894 Mdot
.68877 .40736 Mdot
.69823 .59761 Mdot
.57438 .30593 Mdot
.60367 .68718 Mdot
.70277 .42481 Mdot
.33161 .37462 Mdot
.43899 .69564 Mdot
.30828 .46958 Mdot
.27816 .5354 Mdot
.60714 .69813 Mdot
.34124 .63604 Mdot
.6822 .3826 Mdot
.29736 .4956 Mdot
.68645 .41013 Mdot
.48739 .29556 Mdot
.5744 .30712 Mdot
.68865 .39595 Mdot
.422 .68655 Mdot
.38428 .33157 Mdot
.59823 .31431 Mdot
.45098 .69585 Mdot
.53002 .28569 Mdot
.71149 .5242 Mdot
.67946 .39474 Mdot
.31183 .42284 Mdot
.68248 .61584 Mdot
.63649 .34274 Mdot
.39706 .68171 Mdot
.70577 .49252 Mdot
.69705 .57665 Mdot
.33829 .62681 Mdot
.47926 .70373 Mdot
.56914 .72622 Mdot
.3389 .36056 Mdot
.52064 .72157 Mdot
.50041 .27572 Mdot
.53887 .27835 Mdot
.52097 .27157 Mdot
.69606 .44019 Mdot
.2909 .4436 Mdot
.70955 .4973 Mdot
.29592 .46525 Mdot
.38522 .32615 Mdot
.45413 .69731 Mdot
.31715 .42024 Mdot
.53912 .29595 Mdot
.29697 .57521 Mdot
.63155 .68049 Mdot
.43996 .31036 Mdot
.27486 .50511 Mdot
.63103 .3345 Mdot
.70311 .49132 Mdot
.68863 .38936 Mdot
.32197 .39087 Mdot
.44976 .69827 Mdot
.40149 .67304 Mdot
.52487 .29721 Mdot
.33813 .3866 Mdot
.30695 .56634 Mdot
.31446 .42789 Mdot
.53291 .29569 Mdot
.60209 .68535 Mdot
.70771 .53082 Mdot
.54199 .71563 Mdot
.60509 .68143 Mdot
.4903 .27785 Mdot
.72845 .4759 Mdot
.30603 .56104 Mdot
.48938 .728 Mdot
.68081 .38272 Mdot
.6166 .32682 Mdot
.28981 .56667 Mdot
.654 .63218 Mdot
.4023 .68309 Mdot
.57267 .71263 Mdot
.6154 .68704 Mdot
.68722 .59149 Mdot
.28636 .45759 Mdot
.56575 .71386 Mdot
.65589 .64006 Mdot
.70189 .5773 Mdot
.49295 .70897 Mdot
.50291 .71221 Mdot
.68626 .40384 Mdot
.58189 .69525 Mdot
.44154 .28863 Mdot
.66941 .62754 Mdot
.33544 .3886 Mdot
.68382 .59761 Mdot
.59137 .69389 Mdot
.72982 .48278 Mdot
.60554 .69906 Mdot
.70404 .46375 Mdot
.69339 .42949 Mdot
.59926 .29821 Mdot
.68292 .59145 Mdot
.41369 .29104 Mdot
.28981 .52856 Mdot
.35957 .3524 Mdot
.68547 .40481 Mdot
.3799 .31012 Mdot
.54233 .30453 Mdot
.45795 .30578 Mdot
.47453 .29362 Mdot
.62985 .3277 Mdot
.6686 .35807 Mdot
.647 .66253 Mdot
.63561 .33551 Mdot
.29805 .50287 Mdot
.31297 .58101 Mdot
.72737 .46975 Mdot
.31841 .42764 Mdot
.37477 .64857 Mdot
.64535 .33931 Mdot
.41276 .31684 Mdot
.58148 .71203 Mdot
.68174 .41535 Mdot
.31165 .61808 Mdot
.6862 .39478 Mdot
.33179 .39948 Mdot
.3057 .55337 Mdot
.48199 .71999 Mdot
.32863 .39621 Mdot
.49809 .27474 Mdot
.49211 .70519 Mdot
.72486 .47801 Mdot
.35946 .35297 Mdot
.601 .32303 Mdot
.55681 .28552 Mdot
.30959 .46075 Mdot
.70147 .41819 Mdot
.7086 .49306 Mdot
.293 .46994 Mdot
.61787 .32653 Mdot
.70638 .46849 Mdot
.54986 .72885 Mdot
.57952 .2907 Mdot
.48148 .70124 Mdot
.51893 .7332 Mdot
.30108 .51825 Mdot
.29754 .44028 Mdot
.70738 .57574 Mdot
.38682 .32156 Mdot
.66938 .63077 Mdot
.49062 .72965 Mdot
.44103 .694 Mdot
.41397 .68779 Mdot
.56843 .71233 Mdot
.33867 .36711 Mdot
.70117 .45149 Mdot
.27937 .50826 Mdot
.29856 .47692 Mdot
.70985 .56641 Mdot
.31921 .40598 Mdot
.30053 .57616 Mdot
.31652 .39797 Mdot
.43291 .70582 Mdot
.41407 .6833 Mdot
.70189 .52694 Mdot
.52554 .73547 Mdot
.29015 .45601 Mdot
.41598 .69024 Mdot
.64001 .67355 Mdot
.60907 .31858 Mdot
.57283 .72485 Mdot
.42836 .6857 Mdot
.5714 .30306 Mdot
.61397 .3222 Mdot
.34698 .36347 Mdot
.3206 .41447 Mdot
.42114 .28489 Mdot
.31438 .57137 Mdot
.54585 .7134 Mdot
.5034 .72548 Mdot
.59528 .68969 Mdot
.31694 .57169 Mdot
.67837 .60577 Mdot
.50937 .7369 Mdot
.42291 .67985 Mdot
.30369 .5693 Mdot
.58808 .298 Mdot
.68956 .40415 Mdot
.52102 .73265 Mdot
.298 .47609 Mdot
.69826 .57968 Mdot
.33128 .63342 Mdot
.68534 .40892 Mdot
.72628 .49582 Mdot
.67182 .37635 Mdot
.62667 .32987 Mdot
.35218 .36506 Mdot
.30595 .55311 Mdot
.68633 .39407 Mdot
.36657 .32761 Mdot
.54615 .29443 Mdot
.60123 .6951 Mdot
.61057 .30498 Mdot
.66495 .35708 Mdot
.70042 .43364 Mdot
.68037 .41833 Mdot
.66832 .6257 Mdot
.57083 .71207 Mdot
.29806 .4614 Mdot
.53275 .29669 Mdot
.39295 .31997 Mdot
.49941 .72243 Mdot
.72583 .48866 Mdot
.59523 .70982 Mdot
.47973 .72022 Mdot
.40622 .66894 Mdot
.3855 .65619 Mdot
.2769 .4927 Mdot
.37493 .65691 Mdot
.38436 .6612 Mdot
.6505 .35857 Mdot
.35085 .35953 Mdot
.40597 .6934 Mdot
.27875 .5145 Mdot
.3474 .63718 Mdot
.30811 .61543 Mdot
.51447 .72934 Mdot
.66166 .64057 Mdot
.69197 .4052 Mdot
.45761 .2833 Mdot
.38911 .30337 Mdot
.32323 .6114 Mdot
.61086 .31231 Mdot
.67845 .3627 Mdot
.34626 .35392 Mdot
.30474 .54935 Mdot
.46282 .70178 Mdot
.6111 .68306 Mdot
.60964 .69741 Mdot
.61864 .68731 Mdot
.45652 .70003 Mdot
.29917 .44321 Mdot
.47745 .28696 Mdot
.59235 .69992 Mdot
.72678 .51442 Mdot
.33542 .63279 Mdot
.32046 .58961 Mdot
.71014 .46497 Mdot
.48549 .7286 Mdot
.62124 .33911 Mdot
.63408 .66048 Mdot
.57932 .3005 Mdot
.70839 .43805 Mdot
.35336 .64619 Mdot
.49554 .7082 Mdot
.51413 .71405 Mdot
.3687 .65033 Mdot
.71212 .45476 Mdot
.71092 .47572 Mdot
.69808 .54116 Mdot
.60701 .31667 Mdot
.52838 .71725 Mdot
.50248 .28265 Mdot
.28959 .4571 Mdot
.68788 .38273 Mdot
.57518 .69615 Mdot
.41288 .307 Mdot
.70563 .57772 Mdot
.29751 .59192 Mdot
.63033 .66837 Mdot
.28549 .5064 Mdot
.55937 .72907 Mdot
.4287 .30632 Mdot
.70943 .53203 Mdot
.70536 .58281 Mdot
.33153 .36297 Mdot
.55778 .71406 Mdot
.28206 .54792 Mdot
.32051 .41827 Mdot
.31364 .56442 Mdot
.51127 .7123 Mdot
.29977 .60065 Mdot
.63558 .34093 Mdot
.40701 .69361 Mdot
.55036 .71565 Mdot
.4049 .67186 Mdot
.4953 .71555 Mdot
.60447 .31729 Mdot
.66654 .61331 Mdot
.29315 .52539 Mdot
.32524 .4102 Mdot
.68465 .59577 Mdot
.2963 .58059 Mdot
.52184 .28397 Mdot
.34791 .36126 Mdot
.31045 .44106 Mdot
.31614 .56425 Mdot
.50363 .7083 Mdot
.42737 .69555 Mdot
.29089 .44924 Mdot
.48942 .71791 Mdot
.66998 .62218 Mdot
.46299 .29234 Mdot
.68611 .58916 Mdot
.32277 .62445 Mdot
.30398 .60457 Mdot
.59804 .31198 Mdot
.68719 .3937 Mdot
.32215 .6041 Mdot
.42161 .30979 Mdot
.53023 .72864 Mdot
.4872 .70646 Mdot
.70273 .50275 Mdot
.45934 .71055 Mdot
.32333 .62508 Mdot
.48172 .71922 Mdot
.69199 .55223 Mdot
.71292 .4365 Mdot
.40141 .68223 Mdot
.68023 .61143 Mdot
.69771 .43714 Mdot
.31076 .5795 Mdot
.61756 .31431 Mdot
.5517 .70809 Mdot
.6438 .34522 Mdot
.69703 .54187 Mdot
.3044 .47996 Mdot
.66716 .36328 Mdot
.30491 .47953 Mdot
.70432 .56042 Mdot
.43743 .69394 Mdot
.70381 .49547 Mdot
.28696 .55391 Mdot
.40402 .29762 Mdot
.39101 .32501 Mdot
.28618 .47831 Mdot
.68416 .38175 Mdot
.29301 .47564 Mdot
.31706 .59777 Mdot
.47518 .27993 Mdot
.69144 .42946 Mdot
.47582 .29629 Mdot
.4168 .31572 Mdot
.51906 .29656 Mdot
.40162 .66699 Mdot
.55425 .71701 Mdot
.46363 .30157 Mdot
.57395 .29351 Mdot
.70475 .42038 Mdot
.39999 .67232 Mdot
.31249 .43561 Mdot
.44854 .28933 Mdot
.44408 .27761 Mdot
.70478 .52318 Mdot
.70554 .5859 Mdot
.44449 .69745 Mdot
.5315 .27586 Mdot
.57531 .72283 Mdot
.68027 .61316 Mdot
.31697 .57961 Mdot
.47482 .72329 Mdot
.55297 .72654 Mdot
.51886 .27681 Mdot
.31302 .45369 Mdot
.62031 .68641 Mdot
.34992 .34846 Mdot
.57251 .71548 Mdot
.35563 .64242 Mdot
.29173 .44789 Mdot
.46637 .70305 Mdot
.29694 .51408 Mdot
.67315 .37315 Mdot
.40563 .67434 Mdot
.54814 .29597 Mdot
.41525 .29159 Mdot
.45072 .6992 Mdot
.32435 .40447 Mdot
.53886 .28501 Mdot
.28689 .50493 Mdot
.30615 .56447 Mdot
.69788 .58822 Mdot
.46857 .71847 Mdot
.35027 .3536 Mdot
.30302 .591 Mdot
.40997 .67413 Mdot
.40762 .3118 Mdot
.51737 .28067 Mdot
.27891 .50054 Mdot
.53302 .71685 Mdot
.51784 .2898 Mdot
.61458 .3164 Mdot
.29658 .59256 Mdot
.65185 .34632 Mdot
.47763 .72847 Mdot
.43495 .69472 Mdot
.65978 .36216 Mdot
.70418 .50628 Mdot
.5137 .7093 Mdot
.36767 .65537 Mdot
.62933 .3423 Mdot
.57982 .70942 Mdot
.5676 .7275 Mdot
.28611 .55461 Mdot
.59254 .31421 Mdot
.40857 .28753 Mdot
.39554 .32198 Mdot
.30733 .58947 Mdot
.67185 .36235 Mdot
.29549 .5457 Mdot
.42059 .29143 Mdot
.56138 .72051 Mdot
.64467 .34925 Mdot
.68923 .57522 Mdot
.53469 .28863 Mdot
.43839 .30707 Mdot
.71731 .5016 Mdot
.63765 .65755 Mdot
.35599 .64271 Mdot
.57767 .29914 Mdot
.32575 .38714 Mdot
.33163 .62225 Mdot
.72669 .51527 Mdot
.43313 .69716 Mdot
.58969 .69699 Mdot
.45498 .70295 Mdot
.28066 .47484 Mdot
.35502 .35211 Mdot
.31302 .4217 Mdot
.30994 .45859 Mdot
.5298 .71109 Mdot
.61521 .31596 Mdot
.5115 .27671 Mdot
.28913 .51211 Mdot
.62306 .32659 Mdot
.44156 .70798 Mdot
.45026 .30035 Mdot
.69917 .5643 Mdot
.42246 .68918 Mdot
.30752 .54183 Mdot
.55347 .30554 Mdot
.70896 .54908 Mdot
.39357 .29712 Mdot
.51179 .7131 Mdot
.70725 .45751 Mdot
.63645 .33906 Mdot
.5312 .73039 Mdot
.40926 .29453 Mdot
.31038 .44019 Mdot
.40114 .31218 Mdot
.46898 .69772 Mdot
.51002 .71378 Mdot
.31193 .46578 Mdot
.41974 .68621 Mdot
.69865 .4581 Mdot
.65323 .63429 Mdot
.66409 .63565 Mdot
.38349 .66008 Mdot
.73244 .49484 Mdot
.54754 .28619 Mdot
.28978 .51163 Mdot
.61474 .68765 Mdot
.49524 .71956 Mdot
.69293 .4369 Mdot
.52301 .28214 Mdot
.49166 .2713 Mdot
.60737 .31885 Mdot
.4066 .29462 Mdot
.61282 .31342 Mdot
.36658 .64709 Mdot
.70649 .43438 Mdot
.42294 .29749 Mdot
.29403 .49105 Mdot
.35728 .33121 Mdot
.37108 .65769 Mdot
.47634 .28307 Mdot
.37594 .3288 Mdot
.67914 .61838 Mdot
.69877 .38831 Mdot
.27926 .46439 Mdot
.64299 .65263 Mdot
.5631 .72357 Mdot
.45673 .70392 Mdot
.31421 .42722 Mdot
.59969 .31322 Mdot
.7029 .51826 Mdot
.31702 .40133 Mdot
.32069 .62276 Mdot
.70418 .46304 Mdot
.30491 .61093 Mdot
.60907 .68096 Mdot
.73113 .49925 Mdot
.64194 .67147 Mdot
.60594 .32406 Mdot
.68657 .38597 Mdot
.33174 .63608 Mdot
.64665 .6426 Mdot
.30926 .6032 Mdot
.38113 .31595 Mdot
.65903 .64889 Mdot
.46954 .2927 Mdot
.50471 .29242 Mdot
.34522 .36951 Mdot
.63395 .34753 Mdot
.32143 .40777 Mdot
.68083 .59198 Mdot
.54174 .28094 Mdot
.53926 .30167 Mdot
.44001 .28644 Mdot
.2858 .51493 Mdot
.66807 .61201 Mdot
.28181 .53095 Mdot
.28092 .52402 Mdot
.52095 .27488 Mdot
.69222 .39344 Mdot
.6939 .41918 Mdot
.34593 .63608 Mdot
.69164 .39474 Mdot
.44574 .293 Mdot
.60571 .68623 Mdot
.66314 .64122 Mdot
.55286 .29027 Mdot
.69825 .58723 Mdot
.36909 .64561 Mdot
.36893 .34549 Mdot
.44997 .29658 Mdot
.60921 .31581 Mdot
.66267 .35313 Mdot
.29614 .49995 Mdot
.70569 .52019 Mdot
.6775 .36923 Mdot
.6755 .38323 Mdot
.66688 .35754 Mdot
.53344 .72052 Mdot
.6362 .34983 Mdot
.68044 .38069 Mdot
.48408 .70138 Mdot
.44797 .70755 Mdot
.307 .44224 Mdot
.27869 .48191 Mdot
.67076 .61955 Mdot
.29986 .45879 Mdot
.42149 .6959 Mdot
.40552 .30635 Mdot
.28461 .45655 Mdot
.29875 .49689 Mdot
.43702 .28437 Mdot
.45162 .2827 Mdot
.28108 .52835 Mdot
.28696 .45062 Mdot
.6973 .45483 Mdot
.68356 .58729 Mdot
.72453 .4779 Mdot
.36902 .33242 Mdot
.53885 .27454 Mdot
.70273 .5008 Mdot
.44503 .69196 Mdot
.31674 .43399 Mdot
.43275 .30444 Mdot
.68626 .42481 Mdot
.39289 .66997 Mdot
.2975 .47225 Mdot
.31297 .59949 Mdot
.29288 .49491 Mdot
.30315 .43843 Mdot
.71721 .45662 Mdot
.65016 .3469 Mdot
.72364 .51008 Mdot
.34638 .35045 Mdot
.28544 .50299 Mdot
.70982 .45623 Mdot
.32947 .39032 Mdot
.47013 .27685 Mdot
.65145 .63442 Mdot
.38197 .65911 Mdot
.46063 .28355 Mdot
.69832 .39758 Mdot
.63789 .33033 Mdot
.63808 .67605 Mdot
.68592 .39261 Mdot
.31995 .4137 Mdot
.29052 .46005 Mdot
.44838 .2887 Mdot
.70991 .47011 Mdot
.68235 .6106 Mdot
.68112 .38953 Mdot
.5228 .29588 Mdot
.44923 .70009 Mdot
.70738 .45762 Mdot
.30349 .45794 Mdot
.69395 .41229 Mdot
.40132 .31733 Mdot
.31919 .61284 Mdot
.48939 .71383 Mdot
.56697 .29392 Mdot
.41252 .67694 Mdot
.50857 .29213 Mdot
.31198 .54804 Mdot
.68529 .61494 Mdot
.46299 .70578 Mdot
.6007 .69409 Mdot
.54151 .30222 Mdot
.46225 .69654 Mdot
.61169 .6719 Mdot
.72641 .49811 Mdot
.7145 .51441 Mdot
.43518 .70655 Mdot
.46393 .29634 Mdot
.31464 .38825 Mdot
.43658 .69409 Mdot
.32303 .37108 Mdot
.65163 .65102 Mdot
.2896 .52705 Mdot
.34287 .63866 Mdot
.51246 .7253 Mdot
.47944 .71242 Mdot
.38264 .66703 Mdot
.43909 .69019 Mdot
.6204 .69206 Mdot
.41638 .29202 Mdot
.40442 .2914 Mdot
.31534 .59294 Mdot
.58896 .71394 Mdot
.30904 .60927 Mdot
.51972 .27991 Mdot
.68166 .59205 Mdot
.32291 .41438 Mdot
.6913 .39873 Mdot
.40919 .67608 Mdot
.38495 .31802 Mdot
.46736 .70455 Mdot
.68937 .59818 Mdot
.44532 .29139 Mdot
.42268 .3062 Mdot
.3553 .34504 Mdot
.32784 .62803 Mdot
.67639 .39413 Mdot
.36853 .65196 Mdot
.33594 .62507 Mdot
.29789 .50178 Mdot
.6068 .70159 Mdot
.70724 .43783 Mdot
.68785 .41206 Mdot
.67379 .39371 Mdot
.39475 .68049 Mdot
.39279 .6794 Mdot
.49985 .28634 Mdot
.71328 .48354 Mdot
.64563 .35666 Mdot
.46702 .2852 Mdot
.31497 .38355 Mdot
.47453 .70932 Mdot
.30713 .54696 Mdot
.29732 .58668 Mdot
.36379 .33251 Mdot
.30623 .43206 Mdot
.30082 .60358 Mdot
.39529 .68295 Mdot
.45457 .28712 Mdot
.33166 .63169 Mdot
.66428 .3609 Mdot
.52913 .27032 Mdot
.31228 .61343 Mdot
.30901 .45396 Mdot
.7215 .4869 Mdot
.52851 .72504 Mdot
.29313 .5611 Mdot
.53739 .28058 Mdot
.64301 .66699 Mdot
.30265 .43508 Mdot
.30288 .54208 Mdot
.55635 .71022 Mdot
.4213 .29406 Mdot
.3107 .45402 Mdot
.33217 .63905 Mdot
.67189 .63442 Mdot
.29507 .5526 Mdot
.69095 .41374 Mdot
.66488 .63621 Mdot
.4744 .71403 Mdot
.69368 .60072 Mdot
.59729 .29799 Mdot
.37876 .31673 Mdot
.38885 .30618 Mdot
.7015 .5002 Mdot
.60604 .68944 Mdot
.46634 .302 Mdot
.6062 .69177 Mdot
.34509 .63967 Mdot
.48206 .70088 Mdot
.35072 .64712 Mdot
.65178 .64045 Mdot
.30889 .62049 Mdot
.31609 .61395 Mdot
.55957 .30083 Mdot
.62396 .32269 Mdot
.60364 .31825 Mdot
.46934 .2947 Mdot
.6172 .67627 Mdot
.39554 .29874 Mdot
.65566 .35499 Mdot
.30105 .57856 Mdot
.33612 .36674 Mdot
.37194 .65146 Mdot
.41856 .69439 Mdot
.70198 .59031 Mdot
.31177 .43352 Mdot
.49922 .70535 Mdot
.51588 .29147 Mdot
.36591 .32796 Mdot
.45393 .27743 Mdot
.69631 .51339 Mdot
.65764 .35996 Mdot
.41964 .30567 Mdot
.34646 .64107 Mdot
.29547 .58229 Mdot
.59703 .70745 Mdot
.27482 .53388 Mdot
.3982 .30733 Mdot
.48527 .72946 Mdot
.68921 .42868 Mdot
.38244 .33087 Mdot
.40267 .67132 Mdot
.40507 .31874 Mdot
.30415 .42063 Mdot
.67787 .62143 Mdot
.52153 .72143 Mdot
.52911 .27127 Mdot
.61316 .68698 Mdot
.3138 .62266 Mdot
.31257 .46452 Mdot
.57174 .69833 Mdot
.4252 .28967 Mdot
.36499 .32334 Mdot
.32091 .61744 Mdot
.72328 .52502 Mdot
.69254 .42496 Mdot
.69741 .45386 Mdot
.51144 .29138 Mdot
.43589 .69209 Mdot
.44889 .28733 Mdot
.71 .50623 Mdot
.52907 .72868 Mdot
.62731 .33821 Mdot
.35404 .33575 Mdot
.41922 .68571 Mdot
.46357 .70527 Mdot
.31467 .60943 Mdot
.34508 .63191 Mdot
.29522 .51776 Mdot
.46751 .27632 Mdot
.53467 .71031 Mdot
.69208 .58069 Mdot
.40022 .68158 Mdot
.70482 .43588 Mdot
.29232 .47395 Mdot
.3019 .59639 Mdot
.51803 .70986 Mdot
.58673 .6944 Mdot
.70134 .42971 Mdot
.61083 .32907 Mdot
.29221 .49054 Mdot
.53939 .71141 Mdot
.41692 .68245 Mdot
.4736 .71599 Mdot
.66902 .62519 Mdot
.37674 .65014 Mdot
.3625 .35081 Mdot
.69758 .5586 Mdot
.32285 .58738 Mdot
.67648 .3899 Mdot
.33114 .3867 Mdot
.65331 .63028 Mdot
.63102 .66458 Mdot
.73174 .49886 Mdot
.70434 .40752 Mdot
.52412 .29672 Mdot
.64001 .34904 Mdot
.31159 .55429 Mdot
.4675 .70043 Mdot
.28756 .46079 Mdot
.67756 .38178 Mdot
.38071 .31603 Mdot
.30671 .608 Mdot
.32511 .38674 Mdot
.41128 .68686 Mdot
.43388 .28819 Mdot
.28221 .49119 Mdot
.71216 .46011 Mdot
.40534 .30456 Mdot
.31027 .43974 Mdot
.31494 .58107 Mdot
.63989 .66793 Mdot
.3287 .40169 Mdot
.30654 .47081 Mdot
.47155 .70408 Mdot
.70138 .56387 Mdot
.69674 .59173 Mdot
.28582 .55186 Mdot
.39546 .29426 Mdot
.30507 .46134 Mdot
.70197 .55655 Mdot
.68346 .61575 Mdot
.38339 .32253 Mdot
.70728 .49184 Mdot
.65173 .63594 Mdot
.30177 .48702 Mdot
.70725 .43012 Mdot
.31652 .40403 Mdot
.669 .3917 Mdot
.53167 .72768 Mdot
.3924 .65824 Mdot
.47198 .29449 Mdot
.31126 .60303 Mdot
.50158 .27996 Mdot
.56959 .30328 Mdot
.5465 .3001 Mdot
.48018 .29725 Mdot
.41307 .68005 Mdot
.68306 .38383 Mdot
.63203 .33215 Mdot
.7014 .52277 Mdot
.41272 .31202 Mdot
.45732 .29911 Mdot
.70352 .5855 Mdot
.30342 .60456 Mdot
.37217 .65243 Mdot
.38165 .31588 Mdot
.35093 .3628 Mdot
.70913 .45574 Mdot
.31796 .62603 Mdot
.65798 .62831 Mdot
.33008 .4002 Mdot
.58304 .71666 Mdot
.72945 .51261 Mdot
.28817 .46773 Mdot
.70574 .4822 Mdot
.55579 .72759 Mdot
.47747 .28408 Mdot
.33636 .38332 Mdot
.60994 .68881 Mdot
.49139 .27584 Mdot
.64026 .34362 Mdot
.40689 .30168 Mdot
.40348 .67829 Mdot
.32793 .38233 Mdot
.30812 .58908 Mdot
.64193 .64717 Mdot
.28877 .51478 Mdot
.70042 .51568 Mdot
.63443 .33056 Mdot
.28639 .45086 Mdot
.50135 .28021 Mdot
.60339 .31939 Mdot
.72886 .48295 Mdot
.47545 .7139 Mdot
.43102 .30176 Mdot
.45343 .30531 Mdot
.34949 .64451 Mdot
.37106 .34178 Mdot
.68145 .41363 Mdot
.4629 .28014 Mdot
.58311 .7009 Mdot
.43274 .70503 Mdot
.29866 .4357 Mdot
.28416 .47677 Mdot
.34558 .37137 Mdot
.46294 .69628 Mdot
.71655 .52687 Mdot
.40035 .29283 Mdot
.40864 .31861 Mdot
.68968 .60651 Mdot
.62739 .32554 Mdot
.27862 .54374 Mdot
.44628 .29464 Mdot
.55094 .70786 Mdot
.47695 .70954 Mdot
.58077 .30281 Mdot
.44228 .29422 Mdot
.31736 .40811 Mdot
.56415 .29372 Mdot
.71653 .50371 Mdot
.61115 .69473 Mdot
.70796 .52546 Mdot
.30133 .60373 Mdot
.39278 .30654 Mdot
.50958 .28007 Mdot
.28874 .49929 Mdot
.31808 .38436 Mdot
.4719 .29867 Mdot
.68691 .40528 Mdot
.47148 .71426 Mdot
.50976 .73048 Mdot
.42117 .68657 Mdot
.59971 .70856 Mdot
.31967 .62484 Mdot
.57146 .30549 Mdot
.52865 .29724 Mdot
.60918 .69562 Mdot
.32961 .63114 Mdot
.41306 .28986 Mdot
.44286 .29109 Mdot
.57159 .29921 Mdot
.30118 .44021 Mdot
.40851 .29135 Mdot
.47534 .70599 Mdot
.33354 .36402 Mdot
.7265 .48905 Mdot
.6258 .32333 Mdot
.49346 .71907 Mdot
.4735 .29834 Mdot
.71855 .45854 Mdot
.61685 .67972 Mdot
.43295 .69094 Mdot
.28859 .55385 Mdot
.63918 .34531 Mdot
.65521 .34806 Mdot
.36848 .34638 Mdot
.42504 .68225 Mdot
.51642 .28413 Mdot
.32206 .40557 Mdot
.33755 .36049 Mdot
.67024 .37273 Mdot
.41799 .31532 Mdot
.62178 .31705 Mdot
.28098 .50004 Mdot
.32223 .58567 Mdot
.40015 .31075 Mdot
.38722 .3254 Mdot
.68028 .60424 Mdot
.34193 .6288 Mdot
.29424 .58959 Mdot
.70085 .39948 Mdot
.62668 .34175 Mdot
.69188 .59676 Mdot
.55076 .70835 Mdot
.38698 .67474 Mdot
.59763 .312 Mdot
.71017 .43811 Mdot
.47834 .72734 Mdot
.39143 .67326 Mdot
.52235 .72907 Mdot
.7241 .5042 Mdot
.6874 .37988 Mdot
.58882 .71031 Mdot
.67849 .61233 Mdot
.61794 .67249 Mdot
.69112 .40524 Mdot
.6805 .39989 Mdot
.62919 .66773 Mdot
.68379 .60094 Mdot
.71099 .48262 Mdot
.62264 .32373 Mdot
.64028 .34393 Mdot
.67435 .38029 Mdot
.70026 .59503 Mdot
.59326 .30937 Mdot
.70261 .53214 Mdot
.444 .30515 Mdot
.61647 .66978 Mdot
.67805 .36355 Mdot
.65686 .64943 Mdot
.6354 .34097 Mdot
.58767 .70725 Mdot
.65563 .64863 Mdot
.37858 .65128 Mdot
.47045 .71222 Mdot
.33311 .62324 Mdot
.28955 .50076 Mdot
.28071 .52818 Mdot
.60036 .31343 Mdot
.37521 .65842 Mdot
.69972 .54365 Mdot
.38405 .67035 Mdot
.4585 .71024 Mdot
.55635 .70913 Mdot
.56249 .70309 Mdot
.67106 .37518 Mdot
.69819 .54326 Mdot
.32932 .3671 Mdot
.37136 .32132 Mdot
.59075 .69156 Mdot
.63953 .34462 Mdot
.6957 .41308 Mdot
.6455 .3558 Mdot
.42285 .2909 Mdot
.43045 .30308 Mdot
.29705 .45897 Mdot
.31089 .45357 Mdot
.41331 .30092 Mdot
.33248 .3617 Mdot
.58364 .70703 Mdot
.70495 .49799 Mdot
.69749 .56212 Mdot
.49234 .72556 Mdot
.51941 .73355 Mdot
.31132 .60073 Mdot
.32982 .39909 Mdot
.51415 .28902 Mdot
.60783 .69333 Mdot
.3998 .68781 Mdot
.30425 .47502 Mdot
.59026 .29321 Mdot
.29771 .56034 Mdot
.63287 .33108 Mdot
.31271 .5718 Mdot
.38802 .32104 Mdot
.41543 .684 Mdot
.38172 .665 Mdot
.52889 .2958 Mdot
.36113 .34115 Mdot
.46123 .28788 Mdot
.30733 .59964 Mdot
.49863 .72525 Mdot
.4395 .28899 Mdot
.68186 .36528 Mdot
.70817 .43699 Mdot
.28199 .48763 Mdot
.39618 .67307 Mdot
.51608 .72468 Mdot
.6811 .6179 Mdot
.29669 .50468 Mdot
.29286 .48904 Mdot
.65512 .35601 Mdot
.57143 .7186 Mdot
.48933 .27073 Mdot
.31197 .46058 Mdot
.66855 .37448 Mdot
.42627 .30189 Mdot
.29593 .50463 Mdot
.2804 .53521 Mdot
.35729 .64954 Mdot
.27434 .5212 Mdot
.69916 .41052 Mdot
.71056 .52635 Mdot
.67286 .60584 Mdot
.70927 .4153 Mdot
.31513 .56833 Mdot
.29648 .57451 Mdot
.34054 .37943 Mdot
.54994 .29551 Mdot
.5495 .73052 Mdot
.30105 .58407 Mdot
.66435 .36821 Mdot
.704 .58035 Mdot
.69136 .58806 Mdot
.67698 .60377 Mdot
.70259 .52638 Mdot
.50319 .71051 Mdot
.35599 .35307 Mdot
.68844 .40579 Mdot
.68675 .58868 Mdot
.50524 .73457 Mdot
.70067 .4503 Mdot
.61979 .33638 Mdot
.64627 .64621 Mdot
.68429 .38626 Mdot
.61448 .69508 Mdot
.63159 .34567 Mdot
.59246 .69523 Mdot
.45225 .27884 Mdot
.33846 .3839 Mdot
.61216 .31744 Mdot
.35585 .3357 Mdot
.44293 .28641 Mdot
.45708 .29116 Mdot
.68132 .37433 Mdot
.37209 .3333 Mdot
.69733 .54608 Mdot
.32645 .38641 Mdot
.53976 .71181 Mdot
.30623 .55396 Mdot
.34737 .3657 Mdot
.67617 .38555 Mdot
.6582 .35567 Mdot
.35582 .64067 Mdot
.45553 .71243 Mdot
.52667 .27655 Mdot
.31392 .58817 Mdot
.60663 .68526 Mdot
.31838 .58156 Mdot
.41279 .29226 Mdot
.50565 .70406 Mdot
.47718 .71 Mdot
.50929 .26975 Mdot
.31207 .6049 Mdot
.67777 .39481 Mdot
.67851 .60484 Mdot
.48987 .29004 Mdot
.30721 .59068 Mdot
.30284 .60281 Mdot
.4313 .69056 Mdot
.70924 .52941 Mdot
.47675 .2872 Mdot
.57984 .2978 Mdot
.30647 .41386 Mdot
.61289 .69734 Mdot
.56029 .71672 Mdot
.44739 .70374 Mdot
.60715 .68073 Mdot
.33111 .38543 Mdot
.61832 .32277 Mdot
.45323 .70528 Mdot
.32569 .39709 Mdot
.43361 .68653 Mdot
.71353 .44759 Mdot
.33843 .37495 Mdot
.27873 .49575 Mdot
.30783 .44219 Mdot
.39589 .66876 Mdot
.36413 .65629 Mdot
.53266 .71733 Mdot
.58778 .30344 Mdot
.28463 .5133 Mdot
.35769 .33728 Mdot
.6876 .42421 Mdot
.35741 .64918 Mdot
.67313 .61856 Mdot
.58437 .3033 Mdot
.43816 .29043 Mdot
.35993 .65181 Mdot
.33048 .61675 Mdot
.66771 .63992 Mdot
.44743 .70809 Mdot
.39473 .66899 Mdot
.61825 .33216 Mdot
.58587 .29781 Mdot
.72769 .51857 Mdot
.29745 .43605 Mdot
.70747 .45441 Mdot
.53833 .28974 Mdot
.36092 .65406 Mdot
.28581 .46733 Mdot
.72132 .5208 Mdot
.28258 .47617 Mdot
.6037 .30128 Mdot
.54438 .71682 Mdot
.70969 .52764 Mdot
.28634 .48047 Mdot
.65766 .64242 Mdot
.69639 .58685 Mdot
.56484 .7078 Mdot
.41228 .67399 Mdot
.68492 .41468 Mdot
.68996 .40854 Mdot
.7034 .54079 Mdot
.29183 .45967 Mdot
.41519 .68976 Mdot
.38407 .6579 Mdot
.41008 .66937 Mdot
.71002 .44485 Mdot
.41135 .67955 Mdot
.67671 .4103 Mdot
.60179 .68012 Mdot
.44241 .27834 Mdot
.38821 .67255 Mdot
.60661 .31121 Mdot
.39275 .66171 Mdot
.30342 .61041 Mdot
.63136 .6767 Mdot
.66774 .62849 Mdot
.62193 .32778 Mdot
.48463 .72813 Mdot
.31982 .40695 Mdot
.37148 .65691 Mdot
.31078 .56689 Mdot
.52069 .27195 Mdot
.54038 .72129 Mdot
.70642 .46789 Mdot
.68028 .39106 Mdot
.39671 .31487 Mdot
.64748 .3493 Mdot
.40306 .29829 Mdot
.68339 .58735 Mdot
.28859 .45306 Mdot
.33215 .37331 Mdot
.55294 .70859 Mdot
.56049 .71861 Mdot
.31347 .4266 Mdot
.69564 .53004 Mdot
.35926 .3535 Mdot
.52503 .73463 Mdot
.70301 .58802 Mdot
.32147 .61542 Mdot
.31535 .57924 Mdot
.34846 .63768 Mdot
.70651 .51408 Mdot
.65938 .3576 Mdot
.62113 .33406 Mdot
.46846 .3014 Mdot
.31491 .62465 Mdot
.56439 .28753 Mdot
.59607 .30014 Mdot
.35217 .36432 Mdot
.63515 .33204 Mdot
.40426 .68504 Mdot
.28212 .52921 Mdot
.7191 .49192 Mdot
.29364 .49984 Mdot
.54925 .72935 Mdot
.41503 .3173 Mdot
.29289 .4519 Mdot
.33494 .62315 Mdot
.61426 .31163 Mdot
.41099 .30688 Mdot
.47622 .71603 Mdot
.69121 .41038 Mdot
.71096 .55868 Mdot
.30865 .41807 Mdot
.66643 .62901 Mdot
.65994 .63324 Mdot
.72587 .5079 Mdot
.28966 .53464 Mdot
.3079 .4031 Mdot
.65334 .6386 Mdot
.53688 .29991 Mdot
.30416 .52759 Mdot
.35883 .34499 Mdot
.38937 .30781 Mdot
.42381 .29622 Mdot
.56201 .72641 Mdot
.4219 .28449 Mdot
.63322 .66932 Mdot
.48936 .28977 Mdot
.53851 .27574 Mdot
.49063 .70527 Mdot
.44054 .2923 Mdot
.30902 .47156 Mdot
.48362 .70937 Mdot
.71663 .51293 Mdot
.45234 .28114 Mdot
.37858 .65066 Mdot
.33543 .35668 Mdot
.52032 .2962 Mdot
.29288 .45861 Mdot
.64287 .66833 Mdot
.62743 .32889 Mdot
.69748 .39973 Mdot
.57052 .70491 Mdot
.30529 .58518 Mdot
.70781 .54205 Mdot
.30661 .54102 Mdot
.29625 .58993 Mdot
.61539 .6713 Mdot
.69983 .39295 Mdot
.27608 .50682 Mdot
.3135 .57888 Mdot
.33766 .62363 Mdot
.42256 .29532 Mdot
.32679 .39463 Mdot
.307 .4581 Mdot
.47703 .71705 Mdot
.34041 .36525 Mdot
.61225 .31435 Mdot
.44486 .70363 Mdot
.46218 .28977 Mdot
.27956 .51471 Mdot
.39093 .67118 Mdot
.6766 .61447 Mdot
.7249 .49655 Mdot
.2783 .48639 Mdot
.30682 .56221 Mdot
.71397 .5197 Mdot
.44409 .70059 Mdot
.31876 .57133 Mdot
.30678 .41538 Mdot
.49494 .71082 Mdot
.66931 .36817 Mdot
.66375 .36086 Mdot
.38183 .31362 Mdot
.60872 .32772 Mdot
.44256 .30885 Mdot
.31502 .5727 Mdot
.36268 .65251 Mdot
.30211 .45402 Mdot
.64859 .64306 Mdot
.63642 .66839 Mdot
.39066 .31412 Mdot
.67811 .3976 Mdot
.58648 .31092 Mdot
.63351 .6744 Mdot
.48704 .70821 Mdot
.39197 .66791 Mdot
.33737 .37811 Mdot
.6912 .4262 Mdot
.3934 .6702 Mdot
.28181 .46855 Mdot
.49381 .70835 Mdot
.31885 .59905 Mdot
.44609 .27888 Mdot
.31419 .44381 Mdot
.71075 .42491 Mdot
.28918 .4713 Mdot
.45144 .29325 Mdot
.55089 .70548 Mdot
.6138 .67677 Mdot
.35269 .64449 Mdot
.69992 .41319 Mdot
.71875 .46043 Mdot
.43592 .30116 Mdot
.32785 .39047 Mdot
.66677 .62299 Mdot
.67513 .61037 Mdot
.48189 .70955 Mdot
.41129 .29314 Mdot
.37654 .31053 Mdot
.28383 .47163 Mdot
.30156 .43782 Mdot
.58911 .69005 Mdot
.39515 .31812 Mdot
.41426 .68292 Mdot
.69941 .59265 Mdot
.61568 .30887 Mdot
.71051 .51525 Mdot
.55924 .29462 Mdot
.62911 .31959 Mdot
.53639 .73268 Mdot
.52655 .70848 Mdot
.50751 .28912 Mdot
.55207 .30255 Mdot
.35487 .36274 Mdot
.59715 .68033 Mdot
.31041 .61206 Mdot
.55001 .71044 Mdot
.40484 .2956 Mdot
.42554 .69577 Mdot
.67437 .39832 Mdot
.30934 .42417 Mdot
.57771 .30443 Mdot
.36337 .65089 Mdot
.66384 .61688 Mdot
.34816 .35698 Mdot
.30535 .47592 Mdot
.28994 .50967 Mdot
.52138 .72398 Mdot
.4115 .68072 Mdot
.38317 .31225 Mdot
.65179 .6488 Mdot
.53783 .28888 Mdot
.34718 .37161 Mdot
.70737 .50881 Mdot
.39449 .66471 Mdot
.69514 .44388 Mdot
.61482 .30984 Mdot
.30101 .53035 Mdot
.33059 .62641 Mdot
.37242 .6586 Mdot
.65192 .63258 Mdot
.49917 .29006 Mdot
.67055 .61757 Mdot
.68697 .59968 Mdot
.30103 .46683 Mdot
.65786 .62924 Mdot
.44937 .71085 Mdot
.48198 .73112 Mdot
.29766 .50253 Mdot
.60208 .30223 Mdot
.54481 .72838 Mdot
.30012 .49024 Mdot
.63108 .67973 Mdot
.64062 .33638 Mdot
.66962 .61937 Mdot
.60627 .31762 Mdot
.34823 .36949 Mdot
.51847 .29453 Mdot
.32396 .58995 Mdot
.35261 .36151 Mdot
.71078 .54852 Mdot
.68383 .38468 Mdot
.63936 .35113 Mdot
.31474 .58158 Mdot
.60643 .31409 Mdot
.40301 .30926 Mdot
.52653 .29939 Mdot
.71442 .42997 Mdot
.55012 .70749 Mdot
.53707 .73215 Mdot
.59558 .31906 Mdot
.37073 .32466 Mdot
.67461 .38037 Mdot
.54993 .29785 Mdot
.64909 .65954 Mdot
.32997 .61825 Mdot
.39278 .66564 Mdot
.61315 .31037 Mdot
.34442 .36581 Mdot
.72914 .50029 Mdot
.30934 .57002 Mdot
.65413 .34727 Mdot
.38817 .31831 Mdot
.47903 .70241 Mdot
.57165 .30383 Mdot
.32496 .37762 Mdot
.53167 .2951 Mdot
.50201 .72987 Mdot
.29557 .44283 Mdot
.28058 .47729 Mdot
.7166 .46938 Mdot
.3186 .42296 Mdot
.32219 .40603 Mdot
.53565 .30155 Mdot
.7194 .53269 Mdot
.33712 .35862 Mdot
.47601 .71715 Mdot
.68552 .58815 Mdot
.29814 .46339 Mdot
.69252 .41955 Mdot
.67291 .62228 Mdot
.29908 .45315 Mdot
.60392 .67836 Mdot
.70934 .52225 Mdot
.43369 .28362 Mdot
.47332 .70542 Mdot
.54618 .2809 Mdot
.53164 .28454 Mdot
.31926 .41462 Mdot
.50426 .27972 Mdot
.63069 .68005 Mdot
.69845 .3881 Mdot
.66759 .61334 Mdot
.31811 .59648 Mdot
.69932 .4621 Mdot
.28329 .46947 Mdot
.35063 .63733 Mdot
.47173 .7033 Mdot
.43217 .30206 Mdot
.34164 .35618 Mdot
.59029 .69017 Mdot
.68967 .40244 Mdot
.62997 .67516 Mdot
.66181 .62988 Mdot
.67265 .61469 Mdot
.46975 .30033 Mdot
.60744 .68319 Mdot
.41338 .68143 Mdot
.59782 .31896 Mdot
.63742 .67858 Mdot
.50636 .73276 Mdot
.32296 .40774 Mdot
.66909 .62752 Mdot
.52739 .27344 Mdot
.70575 .49755 Mdot
.43221 .30077 Mdot
.7156 .53146 Mdot
.70331 .51052 Mdot
.68682 .3814 Mdot
.56673 .28951 Mdot
.65684 .63649 Mdot
.51421 .26729 Mdot
.72741 .49064 Mdot
.51627 .73283 Mdot
.67535 .4044 Mdot
.3063 .40794 Mdot
.71432 .54101 Mdot
.69833 .40305 Mdot
.69151 .5715 Mdot
.69249 .42624 Mdot
.48264 .714 Mdot
.49292 .72001 Mdot
.57629 .69808 Mdot
.33 .38269 Mdot
.42258 .68839 Mdot
.27842 .52787 Mdot
.31962 .59538 Mdot
.72486 .51476 Mdot
.2922 .49254 Mdot
.63526 .66032 Mdot
.29764 .51474 Mdot
.44034 .70274 Mdot
.39589 .67479 Mdot
.67226 .61039 Mdot
.57989 .70839 Mdot
.33247 .37669 Mdot
.67516 .39541 Mdot
.50892 .73437 Mdot
.32875 .37127 Mdot
.48408 .70087 Mdot
.62728 .67958 Mdot
.48918 .73284 Mdot
.43097 .30181 Mdot
.70899 .49821 Mdot
.28091 .52465 Mdot
.68867 .44164 Mdot
.41215 .67588 Mdot
.29293 .54024 Mdot
.31355 .55985 Mdot
.39761 .67478 Mdot
.69724 .4492 Mdot
.66736 .62649 Mdot
.70182 .41157 Mdot
.70551 .44579 Mdot
.48669 .70793 Mdot
.71339 .50112 Mdot
.68778 .37932 Mdot
.67501 .61121 Mdot
.34681 .35815 Mdot
.47209 .27841 Mdot
.55206 .719 Mdot
.30792 .56955 Mdot
.45663 .6989 Mdot
.29368 .565 Mdot
.28651 .52628 Mdot
.30708 .46309 Mdot
.51013 .7115 Mdot
.36141 .32973 Mdot
.29454 .55106 Mdot
.33243 .37857 Mdot
.71354 .42681 Mdot
.72329 .47453 Mdot
.54042 .29131 Mdot
.32251 .3999 Mdot
.30573 .46209 Mdot
.50299 .72663 Mdot
.60347 .70062 Mdot
.50184 .28386 Mdot
.71251 .45748 Mdot
.54594 .7194 Mdot
.31659 .42721 Mdot
.45693 .28194 Mdot
.45766 .30279 Mdot
.5358 .30122 Mdot
.70324 .56078 Mdot
.41041 .69026 Mdot
.3137 .42935 Mdot
.6453 .64795 Mdot
.28806 .50374 Mdot
.27444 .5164 Mdot
.35239 .33724 Mdot
.41314 .68623 Mdot
.65599 .64897 Mdot
.4452 .28481 Mdot
.29562 .56287 Mdot
.71296 .45813 Mdot
.31538 .56945 Mdot
.51384 .26969 Mdot
.72813 .50554 Mdot
.4094 .29898 Mdot
.31325 .43978 Mdot
.43026 .6975 Mdot
.70292 .51755 Mdot
.69611 .52443 Mdot
.71427 .51015 Mdot
.31643 .59233 Mdot
.38992 .30357 Mdot
.31096 .40716 Mdot
.47786 .71501 Mdot
.70202 .39673 Mdot
.35842 .65176 Mdot
.46056 .70155 Mdot
.63865 .34174 Mdot
.67954 .61701 Mdot
.67164 .36992 Mdot
.66475 .63332 Mdot
.73054 .49365 Mdot
.46278 .29809 Mdot
.36208 .64188 Mdot
.48645 .71397 Mdot
.53819 .72125 Mdot
.29777 .56183 Mdot
.69916 .4352 Mdot
.55605 .71142 Mdot
.58298 .71662 Mdot
.52774 .72565 Mdot
.3892 .66691 Mdot
.53818 .73204 Mdot
.28371 .54157 Mdot
.30335 .44965 Mdot
.64176 .66303 Mdot
.41901 .67809 Mdot
.70125 .45451 Mdot
.72119 .48924 Mdot
.65536 .64575 Mdot
.59671 .3119 Mdot
.7084 .54854 Mdot
.44926 .28385 Mdot
.48723 .28955 Mdot
.3252 .37267 Mdot
.34063 .63574 Mdot
.66569 .62144 Mdot
.37403 .66276 Mdot
.59237 .30943 Mdot
.30576 .58166 Mdot
.70686 .42987 Mdot
.29901 .59839 Mdot
.60836 .69022 Mdot
.32515 .59358 Mdot
.3076 .42747 Mdot
.56092 .29073 Mdot
.69968 .59148 Mdot
.3 .54916 Mdot
.71288 .51692 Mdot
.54718 .72014 Mdot
.51391 .7198 Mdot
.65737 .3516 Mdot
.31623 .61649 Mdot
.30623 .41362 Mdot
.47055 .69871 Mdot
.58795 .71291 Mdot
.60334 .31628 Mdot
.32134 .58399 Mdot
.64362 .34915 Mdot
.68705 .6063 Mdot
.72005 .4558 Mdot
.68604 .40075 Mdot
.53816 .28633 Mdot
.62825 .678 Mdot
.32994 .60527 Mdot
.41325 .29866 Mdot
.5904 .68549 Mdot
.33322 .37394 Mdot
.28981 .5524 Mdot
.54135 .72563 Mdot
.35907 .35126 Mdot
.50683 .73438 Mdot
.52392 .28899 Mdot
.36998 .65237 Mdot
.67216 .62709 Mdot
.49826 .70284 Mdot
.46668 .28698 Mdot
.42527 .29617 Mdot
.32637 .38307 Mdot
.57379 .72007 Mdot
.50167 .73579 Mdot
.69964 .52063 Mdot
.38706 .30765 Mdot
.67902 .37626 Mdot
.68807 .41676 Mdot
.3576 .33558 Mdot
.70313 .4315 Mdot
.30288 .60333 Mdot
.50104 .70292 Mdot
.52412 .28951 Mdot
.53487 .29401 Mdot
.41108 .30112 Mdot
.37184 .33094 Mdot
.42982 .30298 Mdot
.68178 .61378 Mdot
.69524 .38291 Mdot
.56805 .71043 Mdot
.42137 .68119 Mdot
.37662 .65925 Mdot
.70727 .50696 Mdot
.63764 .66987 Mdot
.3764 .66949 Mdot
.3212 .61332 Mdot
.44931 .29432 Mdot
.63945 .33726 Mdot
.69149 .5752 Mdot
.59335 .31296 Mdot
.50247 .71189 Mdot
.47852 .27973 Mdot
.70778 .47436 Mdot
.32806 .60316 Mdot
.69462 .59921 Mdot
.33402 .62977 Mdot
.61053 .30622 Mdot
.69697 .52522 Mdot
.60749 .687 Mdot
.49125 .70645 Mdot
.62108 .67499 Mdot
.29916 .51425 Mdot
.73155 .5047 Mdot
.63304 .34236 Mdot
.69871 .58946 Mdot
.29644 .51743 Mdot
.68011 .62272 Mdot
.5593 .72705 Mdot
.43024 .68565 Mdot
.53166 .72944 Mdot
.48455 .72118 Mdot
.71717 .50298 Mdot
.62079 .68357 Mdot
.31309 .43527 Mdot
.48882 .71696 Mdot
.55882 .28633 Mdot
.43644 .7025 Mdot
.37951 .66167 Mdot
.42166 .69807 Mdot
.48137 .72661 Mdot
.7071 .55144 Mdot
.67818 .60162 Mdot
.59915 .31878 Mdot
.57954 .71377 Mdot
.55078 .29232 Mdot
.4119 .30384 Mdot
.32568 .40591 Mdot
.71954 .49735 Mdot
.33333 .62844 Mdot
.49529 .27374 Mdot
.57538 .71219 Mdot
.32217 .37508 Mdot
.47966 .72214 Mdot
.30762 .42491 Mdot
.28212 .52726 Mdot
.33137 .60856 Mdot
.46852 .30288 Mdot
.61728 .31903 Mdot
.48274 .7287 Mdot
.67673 .37781 Mdot
.69274 .39658 Mdot
.49259 .71454 Mdot
.60011 .29758 Mdot
.53127 .28475 Mdot
.3489 .36402 Mdot
.41062 .68989 Mdot
.49128 .71984 Mdot
.70458 .43188 Mdot
.31482 .40728 Mdot
.62218 .66868 Mdot
.30581 .59551 Mdot
.36973 .65851 Mdot
.31601 .43126 Mdot
.6207 .6818 Mdot
.60127 .31961 Mdot
.27722 .50898 Mdot
.3985 .6875 Mdot
.54473 .71102 Mdot
.65119 .64291 Mdot
.34767 .63884 Mdot
.37804 .31095 Mdot
.4789 .70549 Mdot
.46636 .70156 Mdot
.70832 .52262 Mdot
.52406 .29551 Mdot
.6761 .39338 Mdot
.70428 .47939 Mdot
.30687 .46264 Mdot
.51433 .29467 Mdot
.37109 .64789 Mdot
.51398 .27388 Mdot
.67869 .61804 Mdot
.5633 .72274 Mdot
.63219 .34203 Mdot
.70394 .45074 Mdot
.70912 .43594 Mdot
.52182 .71824 Mdot
.68943 .59891 Mdot
.45722 .69885 Mdot
.32636 .39323 Mdot
.31989 .41303 Mdot
.49258 .70718 Mdot
.69578 .40952 Mdot
.46414 .70566 Mdot
.60705 .3055 Mdot
.30201 .54499 Mdot
.68914 .39782 Mdot
.35266 .35311 Mdot
.46583 .30095 Mdot
.37543 .3183 Mdot
.29599 .43996 Mdot
.65874 .63092 Mdot
.71388 .52869 Mdot
.66936 .37285 Mdot
.62723 .6718 Mdot
.45055 .29313 Mdot
.315 .59982 Mdot
.44711 .69722 Mdot
.31697 .43258 Mdot
.54247 .27932 Mdot
.70976 .41887 Mdot
.59956 .68198 Mdot
.32188 .58096 Mdot
.60502 .69978 Mdot
.29976 .47221 Mdot
.40441 .6835 Mdot
.32497 .59192 Mdot
.38351 .32602 Mdot
.65929 .63849 Mdot
.27952 .53929 Mdot
.33652 .3718 Mdot
.47426 .30108 Mdot
.54271 .28699 Mdot
.38662 .30318 Mdot
.33499 .63447 Mdot
.31303 .45303 Mdot
.68863 .39213 Mdot
.40672 .67991 Mdot
.29737 .46965 Mdot
.45125 .29995 Mdot
.28567 .46578 Mdot
.38062 .65703 Mdot
.68822 .43546 Mdot
.40164 .30702 Mdot
.46656 .70446 Mdot
.65905 .63551 Mdot
.72702 .51014 Mdot
.34783 .36004 Mdot
.63075 .67318 Mdot
.32151 .62999 Mdot
.38934 .32675 Mdot
.46642 .28801 Mdot
.50086 .71409 Mdot
.3266 .61029 Mdot
.39963 .66526 Mdot
.62372 .32268 Mdot
.60249 .69958 Mdot
.52883 .2959 Mdot
.46403 .71472 Mdot
.4692 .71606 Mdot
.58912 .70162 Mdot
.72819 .47187 Mdot
.31365 .41482 Mdot
.44283 .69615 Mdot
.3833 .65483 Mdot
.67593 .4044 Mdot
.66335 .64643 Mdot
.57623 .70647 Mdot
.71241 .49296 Mdot
.30917 .5558 Mdot
.5997 .31169 Mdot
.44856 .69746 Mdot
.50624 .26963 Mdot
.31821 .59908 Mdot
.51292 .7227 Mdot
.60165 .67855 Mdot
.6803 .40034 Mdot
.37994 .66971 Mdot
.68382 .39418 Mdot
.56003 .71933 Mdot
.72192 .53149 Mdot
.54663 .29733 Mdot
.49523 .72772 Mdot
.31227 .45718 Mdot
.32707 .37461 Mdot
.52938 .73145 Mdot
.3143 .60841 Mdot
.67377 .62604 Mdot
.30414 .46953 Mdot
.63258 .33067 Mdot
.46503 .27775 Mdot
.4327 .30253 Mdot
.57548 .29041 Mdot
.71899 .53011 Mdot
.34523 .36568 Mdot
.28989 .45576 Mdot
.65127 .64426 Mdot
.30883 .61961 Mdot
.50862 .29231 Mdot
.38679 .65785 Mdot
.38959 .67662 Mdot
.3363 .37908 Mdot
.45466 .27914 Mdot
.67955 .4205 Mdot
.7264 .52181 Mdot
.69776 .5293 Mdot
.29653 .56253 Mdot
.34465 .36295 Mdot
.36203 .64322 Mdot
.42016 .68861 Mdot
.38538 .32729 Mdot
.70876 .50005 Mdot
.32057 .59449 Mdot
.28023 .47881 Mdot
.59021 .30645 Mdot
.33576 .3654 Mdot
.68874 .39589 Mdot
.35094 .35021 Mdot
.31141 .40807 Mdot
.69273 .56856 Mdot
.4956 .72458 Mdot
.62316 .32515 Mdot
.36069 .34342 Mdot
.67104 .36754 Mdot
.50712 .71299 Mdot
.28698 .51042 Mdot
.29446 .44246 Mdot
.72856 .48556 Mdot
.40441 .30278 Mdot
.32673 .61475 Mdot
.54864 .7289 Mdot
.3378 .62339 Mdot
.70524 .50613 Mdot
.38301 .32091 Mdot
.28061 .50774 Mdot
.64134 .33834 Mdot
.46259 .70522 Mdot
.31867 .59506 Mdot
.62273 .32608 Mdot
.30855 .44256 Mdot
.53911 .71277 Mdot
.57805 .7044 Mdot
.65413 .63677 Mdot
.60711 .32065 Mdot
.62231 .67106 Mdot
.44333 .70891 Mdot
.52372 .28865 Mdot
.30815 .54532 Mdot
.32464 .37869 Mdot
.62954 .68299 Mdot
.5358 .30161 Mdot
.37455 .33232 Mdot
.39351 .29594 Mdot
.30494 .42103 Mdot
.33291 .37615 Mdot
.53359 .28211 Mdot
.28801 .49401 Mdot
.3207 .38925 Mdot
.5255 .29559 Mdot
.61158 .69093 Mdot
.45167 .7007 Mdot
.6594 .64388 Mdot
.31219 .44246 Mdot
.2918 .46592 Mdot
.71563 .4825 Mdot
.69697 .58345 Mdot
.28289 .50733 Mdot
.40504 .6657 Mdot
.69695 .5347 Mdot
.63504 .34409 Mdot
.36277 .65836 Mdot
.58465 .29555 Mdot
.65499 .64136 Mdot
.48604 .29675 Mdot
.34864 .36222 Mdot
.40486 .67862 Mdot
.48192 .27478 Mdot
.36002 .65233 Mdot
.44755 .69612 Mdot
.69463 .59925 Mdot
.43461 .68749 Mdot
.48996 .7164 Mdot
.69224 .55741 Mdot
.30536 .43818 Mdot
.70199 .54094 Mdot
.62712 .32993 Mdot
.3029 .5448 Mdot
.32135 .40745 Mdot
.60294 .31706 Mdot
.42646 .68988 Mdot
.32919 .40287 Mdot
.39461 .66962 Mdot
.42303 .68003 Mdot
.58465 .71835 Mdot
.34755 .64801 Mdot
.41695 .30549 Mdot
.33187 .62977 Mdot
.69926 .42384 Mdot
.70741 .46218 Mdot
.31633 .60758 Mdot
.58866 .6877 Mdot
.62456 .66642 Mdot
.43743 .27921 Mdot
.69297 .3978 Mdot
.29467 .58792 Mdot
.60311 .31007 Mdot
.62659 .69103 Mdot
.58359 .697 Mdot
.58283 .30204 Mdot
.38223 .66187 Mdot
.66894 .37113 Mdot
.71277 .48744 Mdot
.50245 .29043 Mdot
.66969 .36978 Mdot
.61874 .67271 Mdot
.68618 .60641 Mdot
.59836 .31653 Mdot
.43895 .69293 Mdot
.52859 .29722 Mdot
.53913 .73474 Mdot
.69284 .59681 Mdot
.68921 .40007 Mdot
.51078 .72985 Mdot
.70127 .46101 Mdot
.29483 .4627 Mdot
.58415 .71579 Mdot
.315 .60238 Mdot
.6196 .67482 Mdot
.36286 .34671 Mdot
.71589 .44214 Mdot
.67369 .38031 Mdot
.61708 .30882 Mdot
.68399 .40823 Mdot
.71669 .46573 Mdot
.57579 .29575 Mdot
.70048 .55569 Mdot
.41443 .67805 Mdot
.70871 .45284 Mdot
.71564 .52813 Mdot
.62572 .3357 Mdot
.31034 .58886 Mdot
.71251 .50872 Mdot
.32073 .39741 Mdot
.47825 .7071 Mdot
.41878 .31116 Mdot
.30583 .61229 Mdot
.71917 .49824 Mdot
.31396 .60581 Mdot
.44186 .30259 Mdot
.30399 .42839 Mdot
.56377 .29805 Mdot
.5021 .27812 Mdot
.27383 .52677 Mdot
.52937 .30095 Mdot
.69625 .42783 Mdot
.34395 .35915 Mdot
.44251 .69698 Mdot
.41443 .69155 Mdot
.30473 .61212 Mdot
.68849 .42614 Mdot
.50183 .27442 Mdot
.29017 .4964 Mdot
.70907 .48625 Mdot
.63541 .32952 Mdot
.35371 .35901 Mdot
.65785 .64831 Mdot
.54486 .28943 Mdot
.31331 .43869 Mdot
.30224 .46749 Mdot
.39138 .66718 Mdot
.52244 .72291 Mdot
.3114 .57038 Mdot
.32172 .38439 Mdot
.70588 .57209 Mdot
.3672 .33317 Mdot
.43087 .70285 Mdot
.69236 .58268 Mdot
.45524 .71272 Mdot
.33129 .63335 Mdot
.54306 .28494 Mdot
.6885 .38826 Mdot
.3002 .53014 Mdot
.46353 .30271 Mdot
.64355 .66987 Mdot
.50431 .71884 Mdot
.63317 .66481 Mdot
.44882 .28294 Mdot
.68754 .42135 Mdot
.42267 .30018 Mdot
.52277 .28724 Mdot
.30943 .60999 Mdot
.67503 .62043 Mdot
.31365 .44281 Mdot
.3903 .31254 Mdot
.63767 .35092 Mdot
.3541 .35119 Mdot
.47507 .28145 Mdot
.30589 .4644 Mdot
.65545 .65478 Mdot
.42923 .28285 Mdot
.28617 .51551 Mdot
.72174 .4785 Mdot
.59391 .71102 Mdot
.73256 .48877 Mdot
.40937 .29404 Mdot
.35219 .64315 Mdot
.62506 .33014 Mdot
.55239 .30398 Mdot
.52212 .73389 Mdot
.36243 .65368 Mdot
.55644 .72904 Mdot
.53793 .27439 Mdot
.52528 .29092 Mdot
.61257 .32481 Mdot
.42814 .29986 Mdot
.70211 .44894 Mdot
.65224 .64633 Mdot
.42242 .28658 Mdot
.42826 .68312 Mdot
.70682 .42876 Mdot
.57683 .6991 Mdot
.40423 .29166 Mdot
.67343 .61143 Mdot
.7302 .51364 Mdot
.29614 .59455 Mdot
.54915 .72438 Mdot
.53693 .28626 Mdot
.45142 .69726 Mdot
.50741 .26706 Mdot
.4403 .29965 Mdot
.27489 .51004 Mdot
.64891 .35023 Mdot
.38448 .67055 Mdot
.42764 .69776 Mdot
.43606 .69837 Mdot
.31582 .62009 Mdot
.72381 .48353 Mdot
.52296 .71211 Mdot
.51261 .70633 Mdot
.70856 .56692 Mdot
.34083 .3804 Mdot
.33549 .63259 Mdot
.54324 .71004 Mdot
.33909 .35501 Mdot
.7132 .48104 Mdot
.37503 .65143 Mdot
.55409 .29164 Mdot
.69354 .58545 Mdot
.62156 .33795 Mdot
.64692 .35254 Mdot
.37854 .33257 Mdot
.69563 .41666 Mdot
.66854 .60982 Mdot
.36685 .32071 Mdot
.72921 .4729 Mdot
.67837 .59786 Mdot
.70535 .55455 Mdot
.59972 .3008 Mdot
.36943 .66322 Mdot
.5629 .30143 Mdot
.30042 .4355 Mdot
.71169 .54246 Mdot
.70789 .43251 Mdot
.62287 .67949 Mdot
.67988 .37004 Mdot
.33674 .37807 Mdot
.71204 .5326 Mdot
.3185 .40754 Mdot
.69645 .52153 Mdot
.62269 .33087 Mdot
.52229 .29744 Mdot
.66713 .61624 Mdot
.40761 .67313 Mdot
.60089 .68717 Mdot
.2898 .49756 Mdot
.65234 .65641 Mdot
.44432 .2851 Mdot
.31674 .40065 Mdot
.55053 .2819 Mdot
.69551 .55725 Mdot
.57457 .29201 Mdot
.42864 .69886 Mdot
.6921 .59905 Mdot
.49201 .72035 Mdot
.54527 .2935 Mdot
.64434 .64914 Mdot
.41155 .67262 Mdot
.66609 .6208 Mdot
.48233 .28832 Mdot
.35713 .3387 Mdot
.69832 .56575 Mdot
.35844 .344 Mdot
.38577 .66265 Mdot
.29817 .57874 Mdot
.3416 .64061 Mdot
.51958 .7197 Mdot
.37308 .33458 Mdot
.61887 .67066 Mdot
.38745 .6572 Mdot
.6152 .69463 Mdot
.46655 .28319 Mdot
.32295 .41531 Mdot
.45438 .29777 Mdot
.70076 .55794 Mdot
.27745 .52573 Mdot
.45479 .28759 Mdot
.63256 .6611 Mdot
.30035 .46528 Mdot
.32894 .37274 Mdot
.31993 .60059 Mdot
.44574 .70356 Mdot
.36223 .64856 Mdot
.39595 .29645 Mdot
.61626 .32296 Mdot
.71943 .5067 Mdot
.61013 .32929 Mdot
.35604 .34132 Mdot
.51064 .7235 Mdot
.30205 .44652 Mdot
.49947 .29255 Mdot
.70801 .5657 Mdot
.30166 .58061 Mdot
.56541 .30335 Mdot
.65658 .62955 Mdot
.51287 .71953 Mdot
.35777 .64743 Mdot
.38305 .66798 Mdot
.31651 .39973 Mdot
.50874 .292 Mdot
.34282 .63161 Mdot
.40964 .68074 Mdot
.40609 .31533 Mdot
.34284 .6377 Mdot
.39003 .66287 Mdot
.35462 .35277 Mdot
.46541 .70058 Mdot
.32301 .58763 Mdot
.71015 .5238 Mdot
.57393 .70496 Mdot
.30191 .51285 Mdot
.30029 .53058 Mdot
.54748 .73029 Mdot
.47616 .71981 Mdot
.3172 .39148 Mdot
.681 .4021 Mdot
.48299 .70496 Mdot
.30851 .61648 Mdot
.69467 .53237 Mdot
.71578 .53193 Mdot
.65179 .64293 Mdot
.64754 .34993 Mdot
.40453 .30529 Mdot
.30885 .57325 Mdot
.31326 .40842 Mdot
.45647 .70429 Mdot
.68057 .62037 Mdot
.31936 .61118 Mdot
.63836 .3425 Mdot
.66395 .62735 Mdot
.65133 .35393 Mdot
.57509 .71349 Mdot
.56384 .3055 Mdot
.37524 .64832 Mdot
.506 .72892 Mdot
.70761 .53398 Mdot
.52945 .26901 Mdot
.5373 .30241 Mdot
.46055 .30254 Mdot
.28108 .50664 Mdot
.70888 .4536 Mdot
.31742 .59366 Mdot
.63684 .65563 Mdot
.38576 .66934 Mdot
.36027 .63969 Mdot
.71007 .5325 Mdot
.49959 .71972 Mdot
.69317 .54691 Mdot
.32298 .39609 Mdot
.36696 .66076 Mdot
.68518 .38837 Mdot
.67955 .39639 Mdot
.70635 .56458 Mdot
.32571 .37349 Mdot
.714 .45383 Mdot
.44483 .69343 Mdot
.35848 .33842 Mdot
.34729 .63825 Mdot
.3154 .5849 Mdot
.34398 .63515 Mdot
.71499 .44796 Mdot
.64298 .65469 Mdot
.66805 .62735 Mdot
.50587 .7097 Mdot
.61413 .69603 Mdot
.52142 .288 Mdot
.51857 .71012 Mdot
.29654 .48428 Mdot
.44819 .29924 Mdot
.50113 .73293 Mdot
.41927 .67766 Mdot
.68745 .38565 Mdot
.30288 .53796 Mdot
.58924 .31145 Mdot
.28446 .51964 Mdot
.39407 .29709 Mdot
.29903 .59143 Mdot
.70245 .43752 Mdot
.52346 .73156 Mdot
.29235 .51907 Mdot
.31252 .42847 Mdot
.38428 .66341 Mdot
.47903 .70512 Mdot
.29761 .50797 Mdot
.61509 .33084 Mdot
.45584 .30463 Mdot
.28557 .5227 Mdot
.61689 .6755 Mdot
.61574 .69411 Mdot
.42119 .69131 Mdot
.70054 .46842 Mdot
.64043 .3522 Mdot
.29499 .45799 Mdot
.35429 .34804 Mdot
.44552 .69582 Mdot
.59196 .6959 Mdot
.3002 .508 Mdot
.29251 .48889 Mdot
.64785 .6491 Mdot
.33278 .62286 Mdot
.69283 .59601 Mdot
.57548 .71286 Mdot
.63641 .67291 Mdot
.36951 .65078 Mdot
.38783 .32473 Mdot
.62378 .318 Mdot
.27734 .53397 Mdot
.44709 .2943 Mdot
.7162 .53073 Mdot
.50703 .71043 Mdot
.68689 .41758 Mdot
.67174 .38353 Mdot
.71972 .47006 Mdot
.59442 .30619 Mdot
.71065 .42402 Mdot
.2998 .50048 Mdot
.40196 .68435 Mdot
.51396 .29044 Mdot
.71629 .44958 Mdot
.61591 .69201 Mdot
.70577 .48066 Mdot
.69736 .4325 Mdot
.62009 .69032 Mdot
.67585 .61504 Mdot
.53482 .71149 Mdot
.4272 .68291 Mdot
.32997 .62175 Mdot
.70281 .39586 Mdot
.59177 .69722 Mdot
.56071 .72639 Mdot
.4078 .68242 Mdot
.66974 .61186 Mdot
.34369 .63707 Mdot
.48694 .72278 Mdot
.39315 .67636 Mdot
.55532 .7103 Mdot
.6206 .68844 Mdot
.67907 .4121 Mdot
.56594 .29925 Mdot
.64514 .64649 Mdot
.39655 .32374 Mdot
.70259 .52193 Mdot
.2947 .55171 Mdot
.70764 .47106 Mdot
.64802 .63783 Mdot
.609 .31424 Mdot
.67161 .37089 Mdot
.40017 .31004 Mdot
.61776 .32172 Mdot
.52901 .29719 Mdot
.67397 .6073 Mdot
.43042 .31248 Mdot
.30715 .54993 Mdot
.54716 .28958 Mdot
.65857 .63998 Mdot
.62153 .32987 Mdot
.70408 .55872 Mdot
.65675 .65299 Mdot
.56263 .71336 Mdot
.28615 .49214 Mdot
.28221 .53967 Mdot
.52444 .28547 Mdot
.30686 .59465 Mdot
.66204 .62771 Mdot
.71487 .50869 Mdot
.30341 .58604 Mdot
.72936 .50017 Mdot
.35522 .35684 Mdot
.70934 .49096 Mdot
.33971 .37671 Mdot
.6855 .37361 Mdot
.54699 .72501 Mdot
.30341 .52322 Mdot
.29693 .51261 Mdot
.60168 .69155 Mdot
.27903 .50504 Mdot
.46733 .71999 Mdot
.66073 .62317 Mdot
.41729 .68039 Mdot
.31543 .38305 Mdot
.29282 .58368 Mdot
.70841 .53806 Mdot
.32421 .4051 Mdot
.63262 .34722 Mdot
.62954 .66739 Mdot
.27579 .51648 Mdot
.69029 .59875 Mdot
.69371 .53832 Mdot
.69554 .39202 Mdot
.71005 .54893 Mdot
.36095 .34112 Mdot
.30223 .42724 Mdot
.42657 .69369 Mdot
.32017 .41026 Mdot
.529 .29106 Mdot
.49992 .29068 Mdot
.40744 .31196 Mdot
.3564 .6407 Mdot
.44544 .29288 Mdot
.34549 .63304 Mdot
.68961 .37869 Mdot
.30611 .56009 Mdot
.4198 .68443 Mdot
.71194 .50057 Mdot
.65892 .64196 Mdot
.30436 .53505 Mdot
.33451 .62909 Mdot
.51625 .29752 Mdot
.50634 .2887 Mdot
.28131 .48605 Mdot
.62159 .68724 Mdot
.60526 .69705 Mdot
.37651 .66376 Mdot
.5221 .28321 Mdot
.68425 .60465 Mdot
.56958 .30493 Mdot
.69702 .59528 Mdot
.29253 .58194 Mdot
.47054 .29023 Mdot
.44254 .27836 Mdot
.70489 .51458 Mdot
.50924 .71084 Mdot
.72274 .47207 Mdot
.57436 .71111 Mdot
.4689 .27976 Mdot
.30625 .53631 Mdot
.42273 .3033 Mdot
.53696 .27311 Mdot
.46949 .29117 Mdot
.29091 .56775 Mdot
.67448 .6329 Mdot
.62252 .31288 Mdot
.64414 .65888 Mdot
.35995 .33347 Mdot
.47361 .72357 Mdot
.29326 .50669 Mdot
.32866 .40346 Mdot
.69158 .57915 Mdot
.72738 .50457 Mdot
.33002 .62476 Mdot
.4213 .68591 Mdot
.69745 .56343 Mdot
.4203 .68577 Mdot
.42167 .68757 Mdot
.44862 .70444 Mdot
.54053 .29089 Mdot
.64752 .65616 Mdot
.40959 .67433 Mdot
.32818 .38008 Mdot
.35095 .64871 Mdot
.43812 .2809 Mdot
.7062 .53467 Mdot
.30572 .58159 Mdot
.70131 .51886 Mdot
.60644 .68416 Mdot
.59015 .29523 Mdot
.7247 .48619 Mdot
.67961 .60584 Mdot
.71445 .44545 Mdot
.54806 .30324 Mdot
.32497 .61214 Mdot
.30011 .47595 Mdot
.58007 .30361 Mdot
.33236 .37871 Mdot
.28224 .51382 Mdot
.3526 .3559 Mdot
.37368 .65278 Mdot
.6907 .39615 Mdot
.28016 .50877 Mdot
.64392 .35542 Mdot
.35399 .33718 Mdot
.59045 .71394 Mdot
.47247 .71116 Mdot
.44582 .28364 Mdot
.2912 .48506 Mdot
.61791 .67591 Mdot
.64754 .65438 Mdot
.35879 .33347 Mdot
.58256 .30479 Mdot
.53134 .2898 Mdot
.31074 .58576 Mdot
.6886 .42493 Mdot
.69022 .38573 Mdot
.63667 .34547 Mdot
.48453 .27429 Mdot
.48039 .71261 Mdot
.46695 .70583 Mdot
.61312 .68543 Mdot
.48033 .7262 Mdot
.35298 .34952 Mdot
.28671 .50783 Mdot
.67587 .37998 Mdot
.66241 .61939 Mdot
.704 .57966 Mdot
.43059 .69498 Mdot
.5072 .72422 Mdot
.40027 .30162 Mdot
.69249 .60189 Mdot
.32085 .58304 Mdot
.70855 .45778 Mdot
.46707 .70042 Mdot
.29229 .56686 Mdot
.68733 .38038 Mdot
.32735 .37571 Mdot
.61599 .32375 Mdot
.3611 .32682 Mdot
.36368 .32372 Mdot
.29225 .54983 Mdot
.70408 .52139 Mdot
.28258 .51329 Mdot
.36343 .34412 Mdot
.31633 .41791 Mdot
.33433 .62354 Mdot
.52871 .72138 Mdot
.33252 .38159 Mdot
.47828 .28515 Mdot
.63629 .32779 Mdot
.57182 .71509 Mdot
.40728 .69472 Mdot
.53124 .30216 Mdot
.3919 .67057 Mdot
.31766 .60927 Mdot
.50787 .28401 Mdot
.67162 .37453 Mdot
.32835 .61689 Mdot
.54095 .28192 Mdot
.69495 .39314 Mdot
.67273 .61002 Mdot
.61447 .69266 Mdot
.72 .51274 Mdot
.70359 .43298 Mdot
.48253 .7135 Mdot
.38116 .33151 Mdot
.68096 .38406 Mdot
.72333 .51765 Mdot
.69242 .56663 Mdot
.37533 .32208 Mdot
.34047 .63308 Mdot
.62319 .31447 Mdot
.404 .66815 Mdot
.47797 .29223 Mdot
.30072 .5658 Mdot
.67352 .3669 Mdot
.44917 .71045 Mdot
.45657 .70396 Mdot
.30077 .58149 Mdot
.33703 .63768 Mdot
.30567 .59105 Mdot
.52957 .2989 Mdot
.67592 .60905 Mdot
.69569 .54963 Mdot
.54169 .30275 Mdot
.30021 .60282 Mdot
.29322 .55303 Mdot
.31908 .4078 Mdot
.47628 .71023 Mdot
.32922 .63201 Mdot
.71022 .43083 Mdot
.6697 .63929 Mdot
.31713 .41696 Mdot
.35445 .64859 Mdot
.3133 .38892 Mdot
.35104 .64378 Mdot
.61849 .31428 Mdot
.69789 .58768 Mdot
.3179 .58807 Mdot
.30589 .45494 Mdot
.4757 .7121 Mdot
.48198 .71977 Mdot
.29866 .58335 Mdot
.48591 .72429 Mdot
.69522 .39837 Mdot
.72947 .48051 Mdot
.30398 .58062 Mdot
.38163 .32485 Mdot
.43824 .28277 Mdot
.42691 .29453 Mdot
.41357 .6874 Mdot
.56916 .70179 Mdot
.62689 .68984 Mdot
.69919 .55993 Mdot
.5175 .29396 Mdot
.6884 .37952 Mdot
.70834 .45326 Mdot
.7123 .53652 Mdot
.35346 .33859 Mdot
.30727 .59503 Mdot
.70078 .46629 Mdot
.51914 .29717 Mdot
.52651 .28461 Mdot
.40683 .28883 Mdot
.4533 .2929 Mdot
.41103 .29903 Mdot
.71729 .49701 Mdot
.65979 .35268 Mdot
.64482 .66415 Mdot
.67154 .38181 Mdot
.33114 .36181 Mdot
.3265 .3921 Mdot
.40439 .29047 Mdot
.62842 .3382 Mdot
.70514 .44937 Mdot
.46755 .70335 Mdot
.3762 .66898 Mdot
.446 .28192 Mdot
.31511 .61612 Mdot
.70921 .41288 Mdot
.36005 .64984 Mdot
.69778 .59889 Mdot
.63904 .33999 Mdot
.30057 .45675 Mdot
.43935 .70409 Mdot
.45828 .30217 Mdot
.34896 .63754 Mdot
.30186 .44042 Mdot
.63374 .66736 Mdot
.7128 .42908 Mdot
.61864 .31781 Mdot
.66355 .64595 Mdot
.30267 .48556 Mdot
.67187 .60458 Mdot
.50995 .28469 Mdot
.38935 .31109 Mdot
.31431 .41047 Mdot
.71589 .48346 Mdot
.52333 .71618 Mdot
.30548 .44687 Mdot
.56417 .72669 Mdot
.44624 .28789 Mdot
.32798 .61389 Mdot
.43198 .28867 Mdot
.67973 .414 Mdot
.38071 .31481 Mdot
.44313 .70709 Mdot
.69548 .54405 Mdot
.52783 .28842 Mdot
.61201 .69809 Mdot
.32704 .40112 Mdot
.39191 .31746 Mdot
.29543 .51815 Mdot
.69778 .58163 Mdot
.64361 .64803 Mdot
.27555 .53211 Mdot
.44469 .70931 Mdot
.63137 .34252 Mdot
.69341 .55186 Mdot
.63464 .34871 Mdot
.34321 .64016 Mdot
.57967 .30384 Mdot
.61478 .32282 Mdot
.57582 .69619 Mdot
.32665 .61617 Mdot
.50713 .72351 Mdot
.41989 .67867 Mdot
.6444 .34927 Mdot
.62916 .66603 Mdot
.69372 .56691 Mdot
.62944 .6628 Mdot
.52888 .71133 Mdot
.63399 .34414 Mdot
.29117 .45166 Mdot
.65259 .65209 Mdot
.34453 .64208 Mdot
.53445 .28253 Mdot
.57749 .70481 Mdot
.28769 .50812 Mdot
.29818 .5922 Mdot
.32436 .62283 Mdot
.30579 .60113 Mdot
.43519 .69611 Mdot
.51664 .72853 Mdot
.30091 .52638 Mdot
.5746 .29422 Mdot
.2969 .54442 Mdot
.31119 .546 Mdot
.56485 .29367 Mdot
.33536 .63482 Mdot
.38637 .65679 Mdot
.69769 .59303 Mdot
.69724 .58705 Mdot
.42655 .30896 Mdot
.57756 .30445 Mdot
.31932 .39292 Mdot
.35998 .64053 Mdot
.65591 .35043 Mdot
.71374 .52762 Mdot
.28676 .55245 Mdot
.5006 .70264 Mdot
.65183 .63596 Mdot
.7188 .52818 Mdot
.61728 .68165 Mdot
.70821 .49159 Mdot
.2964 .50095 Mdot
.44052 .70743 Mdot
.70677 .52829 Mdot
.71911 .45645 Mdot
.48509 .72467 Mdot
.70849 .488 Mdot
.68548 .37118 Mdot
.52126 .29564 Mdot
.6113 .31045 Mdot
.63222 .34311 Mdot
.46417 .29476 Mdot
.67686 .39069 Mdot
.48977 .7048 Mdot
.46338 .29995 Mdot
.38233 .66299 Mdot
.63506 .34466 Mdot
.56024 .7288 Mdot
.67901 .39584 Mdot
.39304 .65884 Mdot
.57979 .69426 Mdot
.35602 .35299 Mdot
.30033 .58243 Mdot
.72804 .51475 Mdot
.31184 .41221 Mdot
.54431 .288 Mdot
.66579 .36406 Mdot
.30818 .53888 Mdot
.68566 .58733 Mdot
.35875 .6405 Mdot
.48183 .7289 Mdot
.68413 .58918 Mdot
.66531 .64015 Mdot
.30402 .43572 Mdot
.46459 .30202 Mdot
.36939 .32173 Mdot
.48612 .71083 Mdot
.68006 .39432 Mdot
.32849 .59959 Mdot
.29953 .52116 Mdot
.28132 .54622 Mdot
.61531 .67209 Mdot
.51288 .70646 Mdot
.57995 .72086 Mdot
.51323 .71235 Mdot
.41806 .30866 Mdot
.32047 .41745 Mdot
.62342 .67781 Mdot
.31001 .60874 Mdot
.48229 .70176 Mdot
.70522 .53322 Mdot
.68004 .36447 Mdot
.40447 .29896 Mdot
.54948 .28302 Mdot
.28377 .53164 Mdot
.42973 .2829 Mdot
.48456 .71006 Mdot
.70341 .5738 Mdot
.50343 .28008 Mdot
.69546 .43674 Mdot
.29548 .56892 Mdot
.45752 .30016 Mdot
.30167 .54851 Mdot
.68239 .40606 Mdot
.67379 .36701 Mdot
.50016 .71747 Mdot
.28454 .45161 Mdot
.38682 .31377 Mdot
.42175 .69087 Mdot
.44842 .28363 Mdot
.34576 .37002 Mdot
.56517 .30029 Mdot
.48596 .70579 Mdot
.64072 .65286 Mdot
.62209 .33971 Mdot
.42274 .69956 Mdot
.68966 .59025 Mdot
.6676 .62523 Mdot
.37398 .32834 Mdot
.30287 .51605 Mdot
.29448 .57349 Mdot
.66476 .36588 Mdot
.65155 .34871 Mdot
.58193 .71614 Mdot
.3791 .32142 Mdot
.66551 .63512 Mdot
.60965 .31949 Mdot
.69464 .38482 Mdot
.64726 .34077 Mdot
.62409 .33447 Mdot
.4736 .70798 Mdot
.31671 .60694 Mdot
.70256 .42703 Mdot
.3215 .41219 Mdot
.60623 .7029 Mdot
.29634 .51668 Mdot
.31454 .41405 Mdot
.28789 .51303 Mdot
.60625 .30005 Mdot
.41365 .29412 Mdot
.7017 .49362 Mdot
.64336 .3517 Mdot
.60793 .31616 Mdot
.3062 .41307 Mdot
.72671 .51032 Mdot
.70793 .55583 Mdot
.71098 .42434 Mdot
.33274 .37874 Mdot
.31134 .59828 Mdot
.61327 .67164 Mdot
.42879 .29473 Mdot
.3257 .39715 Mdot
.4871 .2833 Mdot
.50481 .29298 Mdot
.68066 .42567 Mdot
.45182 .69489 Mdot
.69508 .56413 Mdot
.37969 .65402 Mdot
.5298 .7211 Mdot
.63586 .33856 Mdot
.69252 .38155 Mdot
.50994 .27338 Mdot
.49539 .71193 Mdot
.54438 .71742 Mdot
.34972 .34331 Mdot
.29298 .49309 Mdot
.46759 .28143 Mdot
.5057 .71215 Mdot
.45704 .29054 Mdot
.73285 .50203 Mdot
.31139 .45273 Mdot
.58829 .69648 Mdot
.49658 .28222 Mdot
.29932 .44991 Mdot
.30803 .47282 Mdot
.36094 .64539 Mdot
.7062 .49838 Mdot
.6719 .38923 Mdot
.33924 .63212 Mdot
.53086 .27346 Mdot
.53745 .27918 Mdot
.64725 .34424 Mdot
.47467 .70755 Mdot
.49065 .28066 Mdot
.32507 .40628 Mdot
.41732 .69711 Mdot
.66714 .61304 Mdot
.72242 .48757 Mdot
.57483 .72209 Mdot
.65724 .63591 Mdot
.62598 .33227 Mdot
.29106 .55224 Mdot
.58028 .7158 Mdot
.41643 .29029 Mdot
.69789 .44731 Mdot
.71273 .49094 Mdot
.32312 .59407 Mdot
.5468 .29807 Mdot
.35373 .63668 Mdot
.69719 .38971 Mdot
.46289 .69859 Mdot
.61203 .32351 Mdot
.30214 .45266 Mdot
.28294 .49664 Mdot
.28868 .55268 Mdot
.70029 .3921 Mdot
.30442 .45442 Mdot
.71983 .46623 Mdot
.61346 .68298 Mdot
.52527 .72063 Mdot
.59712 .31151 Mdot
.31293 .5997 Mdot
.32719 .40251 Mdot
.35478 .36101 Mdot
.62158 .68628 Mdot
.51875 .72141 Mdot
.5689 .29183 Mdot
.31662 .6012 Mdot
.42833 .69073 Mdot
.30774 .43191 Mdot
.57076 .69873 Mdot
.35307 .64144 Mdot
.27996 .51847 Mdot
.70526 .58484 Mdot
.6988 .42609 Mdot
.27834 .5076 Mdot
.67801 .36203 Mdot
.43221 .69582 Mdot
.6286 .66872 Mdot
.67581 .40184 Mdot
.70832 .42734 Mdot
.29067 .52315 Mdot
.55193 .28886 Mdot
.62187 .66989 Mdot
.38505 .65426 Mdot
.57476 .70047 Mdot
.29446 .46733 Mdot
.58117 .30402 Mdot
.47556 .28885 Mdot
.34016 .35922 Mdot
.36557 .34217 Mdot
.47911 .28286 Mdot
.56793 .29859 Mdot
.44278 .69413 Mdot
.65532 .64562 Mdot
.57191 .70144 Mdot
.58281 .29754 Mdot
.67203 .63646 Mdot
.40755 .67303 Mdot
.38777 .66914 Mdot
.45008 .28342 Mdot
.61127 .30604 Mdot
.65168 .64306 Mdot
.62391 .67523 Mdot
.29597 .5952 Mdot
.6706 .375 Mdot
.39447 .66304 Mdot
.56767 .28958 Mdot
.37052 .32915 Mdot
.56377 .28818 Mdot
.3867 .65947 Mdot
.29373 .49179 Mdot
.5094 .27517 Mdot
.53113 .29228 Mdot
.40045 .3189 Mdot
.40238 .31792 Mdot
.38427 .65518 Mdot
.59639 .31822 Mdot
.66454 .64174 Mdot
.63488 .66102 Mdot
.29471 .47724 Mdot
.31524 .57688 Mdot
.4712 .72256 Mdot
.71007 .5543 Mdot
.31456 .41508 Mdot
.41917 .69017 Mdot
.68338 .41163 Mdot
.41186 .30224 Mdot
.35719 .35561 Mdot
.68212 .37896 Mdot
.35027 .35986 Mdot
.57771 .30375 Mdot
.55919 .73008 Mdot
.33064 .60882 Mdot
.71128 .55952 Mdot
.30164 .52972 Mdot
.29623 .45651 Mdot
.47303 .70864 Mdot
.36951 .33699 Mdot
.36943 .34189 Mdot
.69052 .57637 Mdot
.623 .32315 Mdot
.30113 .43445 Mdot
.6812 .60686 Mdot
.29249 .56764 Mdot
.4449 .29851 Mdot
.27914 .48602 Mdot
.47906 .70268 Mdot
.70328 .51642 Mdot
.6626 .63542 Mdot
.27379 .51197 Mdot
.29201 .4678 Mdot
.27679 .52616 Mdot
.54203 .28251 Mdot
.71577 .53966 Mdot
.49175 .28614 Mdot
.36205 .35276 Mdot
.64911 .66039 Mdot
.52759 .71444 Mdot
.68616 .37675 Mdot
.40829 .69123 Mdot
.6019 .32238 Mdot
.709 .42083 Mdot
.3083 .59236 Mdot
.30024 .49402 Mdot
.51069 .27003 Mdot
.32903 .40362 Mdot
.69685 .57662 Mdot
.70888 .57729 Mdot
.70468 .53672 Mdot
.64647 .34432 Mdot
.50871 .73474 Mdot
.38258 .30521 Mdot
.29518 .56661 Mdot
.52109 .29709 Mdot
.68845 .58561 Mdot
.42624 .68397 Mdot
.31474 .60075 Mdot
.52128 .29933 Mdot
.27904 .54099 Mdot
.59333 .3156 Mdot
.29435 .52673 Mdot
.69303 .57236 Mdot
.39034 .66498 Mdot
.2934 .49469 Mdot
.71862 .52029 Mdot
.52085 .29338 Mdot
.7209 .49211 Mdot
.29772 .49764 Mdot
.34973 .36715 Mdot
.51647 .29542 Mdot
.5074 .70887 Mdot
.70424 .48241 Mdot
.6595 .35394 Mdot
.70755 .54851 Mdot
.32392 .40108 Mdot
.32334 .39226 Mdot
.40824 .29895 Mdot
.62684 .33772 Mdot
.48037 .29584 Mdot
.32644 .61747 Mdot
.6061 .67677 Mdot
.40299 .31656 Mdot
.7221 .52751 Mdot
.47474 .29811 Mdot
.58968 .6903 Mdot
.56055 .30086 Mdot
.44388 .28134 Mdot
.40087 .68503 Mdot
.68289 .59806 Mdot
.28943 .47351 Mdot
.3414 .63011 Mdot
.61433 .68107 Mdot
.50093 .70459 Mdot
.30258 .475 Mdot
.388 .65772 Mdot
.60441 .32518 Mdot
.54751 .70636 Mdot
.63042 .68034 Mdot
.3509 .36265 Mdot
.70688 .41224 Mdot
.36688 .32414 Mdot
.29476 .54254 Mdot
.42018 .69519 Mdot
.39173 .65896 Mdot
.68105 .61279 Mdot
.70893 .41434 Mdot
.53868 .29146 Mdot
.64517 .66489 Mdot
.33865 .37116 Mdot
.69657 .5396 Mdot
.69941 .53953 Mdot
.5389 .71866 Mdot
.29036 .50166 Mdot
.63555 .32994 Mdot
.44046 .70273 Mdot
.30422 .43018 Mdot
.51272 .70723 Mdot
.46969 .27863 Mdot
.31975 .39556 Mdot
.36864 .34658 Mdot
.69916 .50651 Mdot
.44206 .28287 Mdot
.68361 .61017 Mdot
.3016 .45694 Mdot
.36706 .34116 Mdot
.54182 .29112 Mdot
.29594 .55813 Mdot
.39371 .67577 Mdot
.49678 .72418 Mdot
.4498 .28215 Mdot
.44204 .31003 Mdot
.65777 .64623 Mdot
.56508 .28814 Mdot
.27865 .46647 Mdot
.51553 .28764 Mdot
.70367 .53435 Mdot
.52664 .73569 Mdot
.37163 .66358 Mdot
.6012 .31137 Mdot
.68802 .58665 Mdot
.42002 .28708 Mdot
.29316 .5413 Mdot
.71484 .53466 Mdot
.29595 .55946 Mdot
.39509 .6831 Mdot
.70483 .54052 Mdot
.34079 .36229 Mdot
.69335 .55676 Mdot
.28394 .50596 Mdot
.55779 .30334 Mdot
.43863 .30271 Mdot
.61645 .30893 Mdot
.6467 .64947 Mdot
.30992 .59604 Mdot
.55153 .722 Mdot
.69399 .60295 Mdot
.72548 .48878 Mdot
.67312 .61385 Mdot
.27382 .52624 Mdot
.6742 .6091 Mdot
.69932 .53301 Mdot
.41271 .67269 Mdot
.36539 .64252 Mdot
.34019 .37938 Mdot
.38495 .66345 Mdot
.45472 .70424 Mdot
.57979 .69409 Mdot
.41459 .68985 Mdot
.42294 .68895 Mdot
.48806 .70747 Mdot
.69142 .42156 Mdot
.53338 .71275 Mdot
.68798 .43481 Mdot
.67715 .4136 Mdot
.36116 .35185 Mdot
.29231 .57237 Mdot
.33841 .63468 Mdot
.55996 .71434 Mdot
.50082 .72416 Mdot
.72643 .5028 Mdot
.70181 .46538 Mdot
.52742 .28958 Mdot
.63576 .67208 Mdot
.33049 .39431 Mdot
.50983 .72699 Mdot
.42286 .30983 Mdot
.37746 .32591 Mdot
.37796 .65261 Mdot
.36129 .65243 Mdot
.47346 .7191 Mdot
.59634 .69113 Mdot
.42445 .68421 Mdot
.50939 .71555 Mdot
.37301 .32103 Mdot
.54451 .72504 Mdot
.66466 .62979 Mdot
.69763 .51825 Mdot
.29846 .55131 Mdot
.2813 .51168 Mdot
.62837 .66884 Mdot
.53864 .73288 Mdot
.715 .48207 Mdot
.67608 .61767 Mdot
.44635 .30394 Mdot
.67411 .37207 Mdot
.60091 .69131 Mdot
.54936 .28973 Mdot
.60506 .70397 Mdot
.57457 .2973 Mdot
.52582 .28022 Mdot
.29654 .587 Mdot
.39547 .31092 Mdot
.41064 .69603 Mdot
.46958 .30133 Mdot
.48633 .70842 Mdot
.65841 .64785 Mdot
.32788 .6014 Mdot
.71785 .50189 Mdot
.4976 .28273 Mdot
.69684 .41783 Mdot
.70636 .55686 Mdot
.54953 .70585 Mdot
.4608 .28021 Mdot
.38345 .31278 Mdot
.27978 .47407 Mdot
.71892 .47143 Mdot
.45194 .70212 Mdot
.71035 .44872 Mdot
.69083 .39898 Mdot
.70745 .50275 Mdot
.5488 .70793 Mdot
.58747 .7084 Mdot
.476 .70355 Mdot
.71642 .52302 Mdot
.39431 .30941 Mdot
.33414 .61969 Mdot
.48687 .71578 Mdot
.30068 .45749 Mdot
.69976 .50397 Mdot
.41125 .29153 Mdot
.55166 .72387 Mdot
.45606 .29151 Mdot
.70327 .54561 Mdot
.36272 .32991 Mdot
.56748 .30272 Mdot
.40251 .3163 Mdot
.49138 .73081 Mdot
.42207 .68107 Mdot
.69863 .53472 Mdot
.6736 .36755 Mdot
.68899 .58448 Mdot
.40823 .68863 Mdot
.71294 .45764 Mdot
.37483 .33298 Mdot
.69977 .46315 Mdot
.66133 .62822 Mdot
.46474 .71134 Mdot
.29988 .53116 Mdot
.64959 .66218 Mdot
.5605 .70713 Mdot
.62958 .6818 Mdot
.30833 .5984 Mdot
.6471 .65072 Mdot
.55604 .72696 Mdot
.47003 .71847 Mdot
.3374 .37063 Mdot
.38597 .67286 Mdot
.3124 .45032 Mdot
.65483 .62865 Mdot
.60591 .7062 Mdot
.67615 .6003 Mdot
.72094 .52578 Mdot
.69835 .54756 Mdot
.37278 .33325 Mdot
.71495 .53187 Mdot
.3057 .45074 Mdot
.63524 .32988 Mdot
.71025 .55267 Mdot
.31946 .41822 Mdot
.3013 .44438 Mdot
.29955 .50113 Mdot
.28031 .52104 Mdot
.28053 .4603 Mdot
.308 .41291 Mdot
.29468 .45404 Mdot
.71595 .4653 Mdot
.33793 .35969 Mdot
.30779 .54088 Mdot
.63646 .33131 Mdot
.3108 .46169 Mdot
.38437 .67147 Mdot
.66656 .62411 Mdot
.66635 .35805 Mdot
.47716 .28242 Mdot
.27837 .531 Mdot
.4673 .71387 Mdot
.70785 .47935 Mdot
.39618 .6645 Mdot
.29804 .53199 Mdot
.6798 .39787 Mdot
.45891 .29739 Mdot
.32462 .59343 Mdot
.28947 .51456 Mdot
.30424 .58359 Mdot
.44256 .28608 Mdot
.57197 .2893 Mdot
.38361 .67237 Mdot
.32667 .40379 Mdot
.31373 .6189 Mdot
.3853 .67325 Mdot
.71481 .46709 Mdot
.2828 .53339 Mdot
.45006 .69574 Mdot
.68297 .60735 Mdot
.69738 .4007 Mdot
.51012 .26782 Mdot
.40719 .69355 Mdot
.70859 .57531 Mdot
.69825 .51207 Mdot
.28642 .45854 Mdot
.46378 .29709 Mdot
.45026 .70989 Mdot
.63266 .33172 Mdot
.63548 .34619 Mdot
.33771 .36703 Mdot
.66839 .36178 Mdot
.48589 .29662 Mdot
.50183 .73266 Mdot
.30782 .47223 Mdot
.44745 .70699 Mdot
.33432 .35831 Mdot
.58058 .30872 Mdot
.70347 .42381 Mdot
.36411 .3498 Mdot
.59122 .71039 Mdot
.64459 .34296 Mdot
.35116 .36123 Mdot
.69717 .52242 Mdot
.6777 .39887 Mdot
.67993 .37786 Mdot
.31748 .57733 Mdot
.44961 .29332 Mdot
.67645 .4057 Mdot
.69594 .42976 Mdot
.66612 .62585 Mdot
.37767 .65494 Mdot
.70679 .53023 Mdot
.3291 .38241 Mdot
.29685 .55046 Mdot
.34244 .36521 Mdot
.3232 .40503 Mdot
.51243 .2908 Mdot
.58751 .69051 Mdot
.61799 .68948 Mdot
.37005 .66329 Mdot
.5091 .70968 Mdot
.43584 .69733 Mdot
.7256 .50863 Mdot
.34805 .64699 Mdot
.312 .5644 Mdot
.71493 .46529 Mdot
.70293 .43133 Mdot
.31209 .57705 Mdot
.51386 .72784 Mdot
.43932 .69294 Mdot
.59351 .71028 Mdot
.69537 .5612 Mdot
.72387 .47065 Mdot
.62925 .33132 Mdot
.69748 .5123 Mdot
.31873 .38493 Mdot
.40163 .29293 Mdot
.38937 .31793 Mdot
.52777 .29516 Mdot
.39629 .68598 Mdot
.37979 .31449 Mdot
.69433 .59515 Mdot
.31532 .39093 Mdot
.69391 .58484 Mdot
.38094 .33274 Mdot
.40995 .69052 Mdot
.47812 .27412 Mdot
.61307 .30464 Mdot
.65893 .62421 Mdot
.53009 .73004 Mdot
.29661 .57887 Mdot
.7259 .51 Mdot
.59561 .31445 Mdot
.71467 .54341 Mdot
.38859 .66058 Mdot
.71017 .51577 Mdot
.50197 .28364 Mdot
.57443 .29587 Mdot
.65429 .63562 Mdot
.69112 .59706 Mdot
.69405 .56563 Mdot
.71709 .44574 Mdot
.46415 .29588 Mdot
.7076 .49856 Mdot
.683 .41999 Mdot
.68191 .598 Mdot
.4296 .28411 Mdot
.60411 .69947 Mdot
.7217 .50492 Mdot
.33426 .61538 Mdot
.6817 .40353 Mdot
.30973 .57484 Mdot
.67177 .39148 Mdot
.32678 .39333 Mdot
.43176 .69996 Mdot
.35941 .35233 Mdot
.31673 .61586 Mdot
.37526 .31199 Mdot
.58136 .29815 Mdot
.30685 .46311 Mdot
.62488 .34168 Mdot
.59864 .68551 Mdot
.70762 .55161 Mdot
.61936 .31457 Mdot
.60466 .69961 Mdot
.4395 .6973 Mdot
.67085 .38855 Mdot
.44991 .3015 Mdot
.34782 .35598 Mdot
.60798 .68282 Mdot
.69845 .39065 Mdot
.40037 .32182 Mdot
.67408 .62807 Mdot
.33321 .36714 Mdot
.65851 .6229 Mdot
.6464 .33983 Mdot
.69721 .55231 Mdot
.34895 .35407 Mdot
.59471 .68967 Mdot
.69013 .43047 Mdot
.39052 .30457 Mdot
.59718 .31992 Mdot
.63001 .32844 Mdot
.47491 .72646 Mdot
.63732 .3293 Mdot
.43008 .30842 Mdot
.56364 .28755 Mdot
.67901 .41045 Mdot
.5685 .29496 Mdot
.30595 .59409 Mdot
.40028 .30705 Mdot
.29492 .47519 Mdot
.66157 .63951 Mdot
.4753 .29279 Mdot
.36483 .65681 Mdot
.32019 .40489 Mdot
.33329 .36308 Mdot
.67728 .39356 Mdot
.69906 .38938 Mdot
.69061 .61005 Mdot
.61187 .68106 Mdot
.44241 .29951 Mdot
.32588 .37486 Mdot
.52355 .70928 Mdot
.30515 .47381 Mdot
.34024 .36133 Mdot
.49334 .70537 Mdot
.67706 .61139 Mdot
.5208 .28861 Mdot
.53971 .71666 Mdot
.69643 .44121 Mdot
.51618 .71863 Mdot
.60768 .32709 Mdot
.35111 .33986 Mdot
.38807 .65891 Mdot
.29521 .57635 Mdot
.64013 .35237 Mdot
.63782 .35013 Mdot
.44299 .27941 Mdot
.66853 .36041 Mdot
.72579 .49473 Mdot
.45513 .29308 Mdot
.68232 .60046 Mdot
.3016 .47112 Mdot
.47378 .702 Mdot
.71186 .5017 Mdot
.71491 .54264 Mdot
.39964 .30734 Mdot
.55539 .72867 Mdot
.61336 .32764 Mdot
.33047 .36563 Mdot
.69529 .58076 Mdot
.39192 .31636 Mdot
.28871 .56412 Mdot
.41958 .28446 Mdot
.7196 .46289 Mdot
.28711 .54884 Mdot
.70995 .51231 Mdot
.29301 .45257 Mdot
.28993 .56738 Mdot
.29686 .58903 Mdot
.37166 .32382 Mdot
.70664 .40715 Mdot
.36123 .3494 Mdot
.41935 .69292 Mdot
.46544 .70051 Mdot
.46394 .28574 Mdot
.31224 .59595 Mdot
.35463 .65185 Mdot
.31318 .55879 Mdot
.67176 .37157 Mdot
.65111 .63467 Mdot
.31771 .40772 Mdot
.31984 .40414 Mdot
.50724 .27992 Mdot
.70812 .48294 Mdot
.30281 .4415 Mdot
.57777 .2921 Mdot
.63435 .35023 Mdot
.31372 .58854 Mdot
.34023 .3816 Mdot
.7048 .5165 Mdot
.59132 .2973 Mdot
.69051 .43176 Mdot
.44761 .7002 Mdot
.27466 .51491 Mdot
.33389 .39425 Mdot
.29824 .44183 Mdot
.61907 .68028 Mdot
.61689 .3097 Mdot
.40864 .67697 Mdot
.29419 .5521 Mdot
.52597 .29336 Mdot
.30208 .53199 Mdot
.69404 .58085 Mdot
.35382 .33844 Mdot
.64994 .34293 Mdot
.48256 .72963 Mdot
.39182 .68151 Mdot
.51018 .29118 Mdot
.51764 .72955 Mdot
.6986 .52249 Mdot
.68687 .42148 Mdot
.41277 .29512 Mdot
.54974 .70746 Mdot
.49321 .72041 Mdot
.48384 .7171 Mdot
.46122 .28815 Mdot
.28573 .51072 Mdot
.31306 .40184 Mdot
.47918 .71637 Mdot
.62826 .33336 Mdot
.6779 .59841 Mdot
.64836 .35313 Mdot
.49646 .73095 Mdot
.42834 .69989 Mdot
.69294 .59438 Mdot
.66779 .61763 Mdot
.62592 .34214 Mdot
.2849 .51541 Mdot
.28977 .52106 Mdot
.72229 .52601 Mdot
.39883 .6827 Mdot
.55928 .71217 Mdot
.44086 .70376 Mdot
.29676 .58102 Mdot
.62621 .69222 Mdot
.59289 .68603 Mdot
.63875 .65997 Mdot
.58446 .71365 Mdot
.42134 .68436 Mdot
.50407 .28647 Mdot
.70634 .43009 Mdot
.60871 .32233 Mdot
.46112 .27802 Mdot
.40884 .31907 Mdot
.30159 .53632 Mdot
.38396 .65539 Mdot
.32378 .60077 Mdot
.53983 .71 Mdot
.3196 .62797 Mdot
.62688 .67283 Mdot
.6496 .65159 Mdot
.32103 .58098 Mdot
.44307 .70816 Mdot
.43984 .28531 Mdot
.39725 .29293 Mdot
.69788 .58739 Mdot
.4896 .72987 Mdot
.51781 .27658 Mdot
.64338 .34612 Mdot
.32013 .39739 Mdot
.31691 .39286 Mdot
.29878 .52846 Mdot
.30089 .50595 Mdot
.67365 .60894 Mdot
.42942 .68591 Mdot
.29036 .50744 Mdot
.48851 .29375 Mdot
.29498 .44989 Mdot
.33648 .38174 Mdot
.59398 .31173 Mdot
.6144 .3147 Mdot
.38013 .66284 Mdot
.36366 .65883 Mdot
.69333 .40496 Mdot
.69677 .38415 Mdot
.64688 .35465 Mdot
.36708 .32402 Mdot
.28005 .50349 Mdot
.71022 .44004 Mdot
.70367 .49462 Mdot
.32042 .6203 Mdot
.45033 .70871 Mdot
.39307 .29955 Mdot
.70804 .47345 Mdot
.30533 .61043 Mdot
.60428 .69844 Mdot
.33021 .36778 Mdot
.39936 .67164 Mdot
.70806 .58224 Mdot
.70378 .44039 Mdot
.61581 .67675 Mdot
.72104 .50325 Mdot
.63533 .33828 Mdot
.58819 .29969 Mdot
.42561 .69999 Mdot
.65554 .35714 Mdot
.73285 .49932 Mdot
.59618 .30013 Mdot
.31909 .57883 Mdot
.29971 .46705 Mdot
.30282 .52552 Mdot
.41205 .29298 Mdot
.29547 .58204 Mdot
.47558 .29514 Mdot
.34825 .36355 Mdot
.70776 .5254 Mdot
.31512 .60105 Mdot
.5818 .69401 Mdot
.29787 .46394 Mdot
.29651 .53344 Mdot
.63696 .66402 Mdot
.70983 .56819 Mdot
.42585 .30443 Mdot
.32512 .60697 Mdot
.36198 .64627 Mdot
.55222 .28142 Mdot
.55977 .30377 Mdot
.58506 .3028 Mdot
.28229 .5072 Mdot
.40033 .31027 Mdot
.70923 .50278 Mdot
.51917 .70917 Mdot
.72857 .47307 Mdot
.44678 .6935 Mdot
.40034 .67977 Mdot
.73079 .48783 Mdot
.70986 .50156 Mdot
.42554 .70131 Mdot
.51087 .71105 Mdot
.30176 .45958 Mdot
.6393 .34646 Mdot
.67534 .38729 Mdot
.67734 .38805 Mdot
.43983 .30921 Mdot
.69719 .53496 Mdot
.27877 .46885 Mdot
.58434 .30071 Mdot
.32467 .40848 Mdot
.62277 .33569 Mdot
.34842 .63608 Mdot
.37974 .33091 Mdot
.709 .44018 Mdot
.66709 .36085 Mdot
.67947 .61571 Mdot
.70641 .5291 Mdot
.30626 .59049 Mdot
.69975 .54201 Mdot
.71411 .52236 Mdot
.3945 .67983 Mdot
.28732 .51595 Mdot
.29262 .46262 Mdot
.62157 .67919 Mdot
.69263 .40379 Mdot
.43126 .69638 Mdot
.64427 .662 Mdot
.40556 .69031 Mdot
.61715 .67675 Mdot
.68295 .41377 Mdot
.53157 .73225 Mdot
.70621 .53498 Mdot
.6754 .41338 Mdot
.3353 .39088 Mdot
.29553 .46665 Mdot
.30518 .43673 Mdot
.44654 .27762 Mdot
.45176 .69659 Mdot
.35469 .35655 Mdot
.67883 .60522 Mdot
.30186 .4865 Mdot
.57993 .69287 Mdot
.32961 .62068 Mdot
.48891 .7096 Mdot
.29591 .49338 Mdot
.45384 .29877 Mdot
.68299 .61189 Mdot
.47276 .70868 Mdot
.28036 .51399 Mdot
.70396 .52482 Mdot
.68977 .38721 Mdot
.70894 .48423 Mdot
.30849 .58069 Mdot
.61157 .32905 Mdot
.67732 .60869 Mdot
.41737 .29156 Mdot
.35833 .35468 Mdot
.70927 .51202 Mdot
.37392 .3288 Mdot
.62363 .32023 Mdot
.47401 .71151 Mdot
.63541 .34375 Mdot
.32943 .61273 Mdot
.68129 .39966 Mdot
.68615 .60319 Mdot
.64538 .6446 Mdot
.698 .54752 Mdot
.30798 .45397 Mdot
.30682 .55148 Mdot
.35305 .33587 Mdot
.70181 .40778 Mdot
.60279 .32095 Mdot
.42333 .31315 Mdot
.69039 .60133 Mdot
.32683 .63428 Mdot
.55885 .71918 Mdot
.38004 .65509 Mdot
.6455 .65139 Mdot
.37597 .64835 Mdot
.36218 .35353 Mdot
.72511 .51832 Mdot
.66329 .61728 Mdot
.63563 .65947 Mdot
.35889 .65316 Mdot
.30521 .52975 Mdot
.40697 .67046 Mdot
.57504 .69886 Mdot
.49581 .72746 Mdot
.70836 .42936 Mdot
.61088 .67969 Mdot
.34725 .3489 Mdot
.32381 .40595 Mdot
.4611 .27809 Mdot
.30225 .47839 Mdot
.35662 .33681 Mdot
.50307 .7089 Mdot
.56439 .72406 Mdot
.69489 .454 Mdot
.7032 .57239 Mdot
.60416 .31396 Mdot
.54094 .73207 Mdot
.44793 .30385 Mdot
.37117 .34084 Mdot
.50362 .73697 Mdot
.69926 .51669 Mdot
.52732 .27064 Mdot
.29311 .50275 Mdot
.30705 .43381 Mdot
.31656 .61664 Mdot
.35827 .3403 Mdot
.28816 .55627 Mdot
.61598 .32987 Mdot
.38243 .6746 Mdot
.59212 .68663 Mdot
.49739 .27064 Mdot
.69388 .54443 Mdot
.53441 .2784 Mdot
.3485 .63581 Mdot
.41417 .68384 Mdot
.6939 .4165 Mdot
.71442 .53505 Mdot
.31009 .61643 Mdot
.3518 .36668 Mdot
.3346 .37617 Mdot
.35154 .6348 Mdot
.28934 .53184 Mdot
.48577 .29298 Mdot
.29309 .53039 Mdot
.68588 .59711 Mdot
.62971 .66854 Mdot
.56212 .30573 Mdot
.41493 .6908 Mdot
.66065 .36466 Mdot
.72234 .52405 Mdot
.4265 .68581 Mdot
.30059 .55164 Mdot
.70507 .47025 Mdot
.68135 .61789 Mdot
.37939 .67184 Mdot
.39417 .309 Mdot
.41473 .68756 Mdot
.3193 .4086 Mdot
.31126 .42344 Mdot
.37177 .65407 Mdot
.46113 .2953 Mdot
.28741 .54844 Mdot
.3035 .55365 Mdot
.69928 .55696 Mdot
.30177 .47738 Mdot
.69791 .57811 Mdot
.47 .70026 Mdot
.31752 .57612 Mdot
.69009 .59533 Mdot
.72672 .47403 Mdot
.31835 .42433 Mdot
.38835 .31908 Mdot
.70211 .42983 Mdot
.42313 .69194 Mdot
.30195 .46225 Mdot
.4312 .68826 Mdot
.69463 .56712 Mdot
.3823 .661 Mdot
.58547 .3089 Mdot
.70375 .44772 Mdot
.61797 .32643 Mdot
.68061 .61301 Mdot
.40039 .67368 Mdot
.29299 .53002 Mdot
.28151 .49549 Mdot
.46686 .71376 Mdot
.71068 .51011 Mdot
.71811 .52052 Mdot
.70715 .49388 Mdot
.42591 .31141 Mdot
.53403 .70979 Mdot
.61995 .3241 Mdot
.28754 .5113 Mdot
.63989 .33308 Mdot
.5679 .70299 Mdot
.30586 .58013 Mdot
.57406 .30254 Mdot
.46966 .7124 Mdot
.68837 .37423 Mdot
.43348 .68776 Mdot
.70746 .43698 Mdot
.44985 .27788 Mdot
.53066 .27729 Mdot
.68757 .39751 Mdot
.41797 .67971 Mdot
.61646 .68261 Mdot
.6013 .6785 Mdot
.6017 .30323 Mdot
.28057 .52894 Mdot
.33954 .38428 Mdot
.39841 .29692 Mdot
.32122 .63029 Mdot
.51441 .295 Mdot
.55079 .28114 Mdot
.66126 .62824 Mdot
.69988 .41048 Mdot
.59982 .31564 Mdot
.58484 .30524 Mdot
.43288 .30652 Mdot
.67077 .62273 Mdot
.39465 .66908 Mdot
.3064 .44937 Mdot
.54082 .28541 Mdot
.48801 .7189 Mdot
.7015 .57244 Mdot
.3143 .40526 Mdot
.71281 .48967 Mdot
.50318 .26807 Mdot
.55894 .70402 Mdot
.72621 .48957 Mdot
.33404 .36634 Mdot
.67763 .40792 Mdot
.42369 .68795 Mdot
.28533 .49794 Mdot
.36705 .331 Mdot
.46285 .69781 Mdot
.36559 .34921 Mdot
.60097 .30893 Mdot
.5021 .27136 Mdot
.59247 .70051 Mdot
.32177 .38226 Mdot
.43121 .70372 Mdot
.68971 .60968 Mdot
.30608 .60731 Mdot
.59448 .3032 Mdot
.69201 .44553 Mdot
.45487 .71146 Mdot
.45268 .30713 Mdot
.42657 .28417 Mdot
.71876 .50655 Mdot
.70736 .48645 Mdot
.70695 .40783 Mdot
.29283 .47943 Mdot
.4009 .32002 Mdot
.301 .46288 Mdot
.36104 .64525 Mdot
.59429 .29877 Mdot
.30435 .55472 Mdot
.36188 .33066 Mdot
.53393 .29799 Mdot
.70967 .56845 Mdot
.67073 .36275 Mdot
.67037 .63344 Mdot
.69607 .59313 Mdot
.36734 .33489 Mdot
.30058 .57352 Mdot
.61846 .67216 Mdot
.6546 .6367 Mdot
.31028 .5727 Mdot
.43514 .30841 Mdot
.68937 .39063 Mdot
.71303 .53894 Mdot
.70529 .44953 Mdot
.58547 .69387 Mdot
.7111 .45196 Mdot
.52889 .72262 Mdot
.36739 .64625 Mdot
.66434 .35914 Mdot
.50641 .70581 Mdot
.58737 .30556 Mdot
.70343 .41054 Mdot
.6166 .67667 Mdot
.69185 .58027 Mdot
.51876 .72038 Mdot
.55156 .72861 Mdot
.66931 .61215 Mdot
.4515 .69633 Mdot
.72639 .47878 Mdot
.71522 .54216 Mdot
.63054 .66421 Mdot
.59255 .29507 Mdot
.30079 .58606 Mdot
.68091 .41719 Mdot
.41108 .68526 Mdot
.72972 .48402 Mdot
.63618 .66267 Mdot
.58856 .31248 Mdot
.67465 .60455 Mdot
.35224 .33979 Mdot
.54387 .71851 Mdot
.43949 .28134 Mdot
.64956 .64196 Mdot
.73249 .48998 Mdot
.55951 .29703 Mdot
.6779 .62121 Mdot
.31247 .38963 Mdot
.54513 .73239 Mdot
.2839 .49678 Mdot
.29441 .57225 Mdot
.28891 .54589 Mdot
.62026 .33913 Mdot
.45718 .69921 Mdot
.50584 .70803 Mdot
.46211 .71568 Mdot
.35919 .64199 Mdot
.2966 .46493 Mdot
.34027 .63366 Mdot
.70079 .56075 Mdot
.47779 .70719 Mdot
.38072 .31178 Mdot
.69832 .42324 Mdot
.51204 .71346 Mdot
.64727 .65194 Mdot
.70629 .58326 Mdot
.69152 .40201 Mdot
.67052 .35729 Mdot
.32944 .3955 Mdot
.31043 .6041 Mdot
.41436 .69474 Mdot
.33476 .61443 Mdot
.68022 .60603 Mdot
.6273 .33972 Mdot
.48621 .72807 Mdot
.3868 .32774 Mdot
.60342 .68373 Mdot
.43052 .3096 Mdot
.37222 .65925 Mdot
.67707 .39483 Mdot
.58964 .30222 Mdot
.34031 .3639 Mdot
.33887 .36404 Mdot
.49021 .72319 Mdot
.3214 .40274 Mdot
.31327 .58324 Mdot
.31001 .58738 Mdot
.59451 .30938 Mdot
.42912 .68982 Mdot
.6081 .67939 Mdot
.69851 .5712 Mdot
.45685 .69529 Mdot
.38024 .67097 Mdot
.54055 .29622 Mdot
.5288 .29599 Mdot
.36582 .32895 Mdot
.41618 .69742 Mdot
.49514 .71579 Mdot
.68873 .40644 Mdot
.30336 .53251 Mdot
.38873 .32512 Mdot
.29843 .60053 Mdot
.44963 .28907 Mdot
.60221 .70623 Mdot
.28145 .52492 Mdot
.3086 .58385 Mdot
.49206 .28231 Mdot
.67917 .36875 Mdot
.30145 .45467 Mdot
.4193 .30297 Mdot
.38678 .32421 Mdot
.50375 .71066 Mdot
.69307 .54791 Mdot
.68473 .41894 Mdot
.30906 .57799 Mdot
.64564 .35274 Mdot
.69455 .59503 Mdot
.30165 .43795 Mdot
.35054 .63898 Mdot
.42097 .31465 Mdot
.70814 .43546 Mdot
.66113 .63932 Mdot
.39505 .67406 Mdot
.6884 .38616 Mdot
.39478 .67203 Mdot
.70693 .50045 Mdot
.6807 .42056 Mdot
.50584 .73473 Mdot
.71536 .47795 Mdot
.48311 .29636 Mdot
.37734 .33545 Mdot
.67203 .60445 Mdot
.57087 .30276 Mdot
.68061 .60337 Mdot
.31738 .39434 Mdot
.45533 .70874 Mdot
.46789 .69878 Mdot
.40769 .6841 Mdot
.29098 .56792 Mdot
.57961 .71462 Mdot
.28785 .46973 Mdot
.28445 .49522 Mdot
.6937 .3964 Mdot
.28869 .54892 Mdot
.61924 .67896 Mdot
.31797 .6007 Mdot
.41107 .29646 Mdot
.49594 .72344 Mdot
.30521 .57534 Mdot
.71452 .53861 Mdot
.67066 .62539 Mdot
.66444 .36664 Mdot
.41822 .28424 Mdot
.28913 .50261 Mdot
.60118 .3105 Mdot
.63592 .67648 Mdot
.45717 .30252 Mdot
.52975 .28594 Mdot
.62401 .68245 Mdot
.34923 .34108 Mdot
.58278 .29174 Mdot
.37746 .3361 Mdot
.51964 .28464 Mdot
.64053 .33875 Mdot
.59531 .69278 Mdot
.31844 .60165 Mdot
.28647 .55619 Mdot
.34271 .63706 Mdot
.54518 .28463 Mdot
.38641 .32899 Mdot
.40728 .31022 Mdot
.63419 .66062 Mdot
.7085 .46473 Mdot
.3093 .46903 Mdot
.40753 .69341 Mdot
.52118 .29191 Mdot
.58074 .70959 Mdot
.28694 .5547 Mdot
.6149 .31639 Mdot
.65142 .64104 Mdot
.61329 .69859 Mdot
.29231 .48512 Mdot
.29621 .45601 Mdot
.32348 .60498 Mdot
.33884 .37623 Mdot
.67798 .40627 Mdot
.32813 .62395 Mdot
.46953 .7206 Mdot
.41282 .6918 Mdot
.62412 .34077 Mdot
.30085 .47996 Mdot
.6219 .32238 Mdot
.30083 .54471 Mdot
.3396 .63302 Mdot
.70445 .55177 Mdot
.70346 .50275 Mdot
.295 .52383 Mdot
.59001 .71446 Mdot
.5789 .72117 Mdot
.69205 .44917 Mdot
.67855 .40274 Mdot
.55554 .73056 Mdot
.31367 .56281 Mdot
.32447 .61125 Mdot
.67906 .62094 Mdot
.64914 .65716 Mdot
.66521 .61836 Mdot
.60679 .69691 Mdot
.46458 .28066 Mdot
.68458 .6086 Mdot
.35552 .33617 Mdot
.60429 .69809 Mdot
.51382 .27277 Mdot
.6997 .58601 Mdot
.38767 .66632 Mdot
.43454 .29265 Mdot
.374 .65993 Mdot
.40367 .29781 Mdot
.42896 .69586 Mdot
.33426 .35801 Mdot
.41724 .29171 Mdot
.32171 .40414 Mdot
.62153 .69239 Mdot
.28854 .46853 Mdot
.31115 .56548 Mdot
.30529 .42692 Mdot
.54959 .72298 Mdot
.68576 .3891 Mdot
.7113 .44538 Mdot
.39279 .67256 Mdot
.42611 .30779 Mdot
.60708 .30949 Mdot
.65295 .64123 Mdot
.44073 .69626 Mdot
.69343 .59008 Mdot
.67082 .36191 Mdot
.39656 .30826 Mdot
.29386 .57534 Mdot
.30693 .41719 Mdot
.32071 .39119 Mdot
.38213 .32992 Mdot
.37577 .66789 Mdot
.70521 .58279 Mdot
.31722 .41107 Mdot
.71914 .48927 Mdot
.35368 .65062 Mdot
.71337 .53319 Mdot
.30403 .47119 Mdot
.31948 .61454 Mdot
.57014 .70641 Mdot
.69485 .4264 Mdot
.46008 .28784 Mdot
.40079 .67239 Mdot
.28136 .51974 Mdot
.34259 .63699 Mdot
.69738 .44058 Mdot
.31825 .57681 Mdot
.41926 .29993 Mdot
.29888 .47236 Mdot
.5593 .71106 Mdot
.52707 .73445 Mdot
.66799 .64229 Mdot
.40407 .67658 Mdot
.31076 .57629 Mdot
.69288 .54163 Mdot
.69481 .58938 Mdot
.52736 .28219 Mdot
.61287 .68091 Mdot
.36386 .64785 Mdot
.31299 .39511 Mdot
.67051 .37246 Mdot
.30738 .59625 Mdot
.51998 .29102 Mdot
.30829 .60395 Mdot
.30036 .44057 Mdot
.70321 .5112 Mdot
.30418 .43615 Mdot
.70004 .57459 Mdot
.60173 .31647 Mdot
.68709 .42143 Mdot
.30958 .40759 Mdot
.28897 .52916 Mdot
.46726 .28551 Mdot
.62007 .69451 Mdot
.71518 .5091 Mdot
.54777 .29998 Mdot
.31108 .41276 Mdot
.58866 .31165 Mdot
.65791 .64969 Mdot
.64198 .34749 Mdot
.39348 .67348 Mdot
.70273 .46243 Mdot
.64494 .34316 Mdot
.33502 .37097 Mdot
.57655 .69839 Mdot
.30526 .43226 Mdot
.44131 .70199 Mdot
.57336 .29967 Mdot
.61039 .30349 Mdot
.70174 .53488 Mdot
.50646 .29177 Mdot
.46932 .72 Mdot
.29835 .46509 Mdot
.38519 .6702 Mdot
.52636 .27827 Mdot
.52802 .29958 Mdot
.34539 .36072 Mdot
.40475 .67353 Mdot
.29803 .58757 Mdot
.35535 .33772 Mdot
.43316 .28315 Mdot
.37621 .32593 Mdot
.72952 .49167 Mdot
.28996 .51642 Mdot
.29082 .48296 Mdot
.48847 .72571 Mdot
.62735 .32606 Mdot
.28774 .47142 Mdot
.47045 .70262 Mdot
.53093 .71836 Mdot
.70494 .44998 Mdot
.4289 .29725 Mdot
.36654 .65171 Mdot
.66746 .60977 Mdot
.27913 .51002 Mdot
.45112 .29281 Mdot
.70441 .52237 Mdot
.31083 .40282 Mdot
.46636 .70736 Mdot
.66134 .62491 Mdot
.69796 .54943 Mdot
.73283 .48641 Mdot
.58303 .71462 Mdot
.39311 .67013 Mdot
.6346 .34667 Mdot
.54163 .66662 Mdot
.37606 .57332 Mdot
.44427 .47441 Mdot
.30171 .49153 Mdot
.59682 .56734 Mdot
.49091 .64404 Mdot
.66721 .60578 Mdot
.49016 .57862 Mdot
.55807 .70042 Mdot
.5461 .6193 Mdot
.62653 .4174 Mdot
.46513 .53804 Mdot
.45694 .31571 Mdot
.66861 .47543 Mdot
.62432 .64732 Mdot
.33525 .48789 Mdot
.66909 .52811 Mdot
.51666 .62682 Mdot
.67342 .47095 Mdot
.60478 .45927 Mdot
.56466 .3297 Mdot
.54085 .30792 Mdot
.60323 .41189 Mdot
.35084 .62483 Mdot
.55337 .64765 Mdot
.40217 .59031 Mdot
.6458 .58405 Mdot
.63411 .3813 Mdot
.66213 .615 Mdot
.4057 .3788 Mdot
.61507 .57233 Mdot
.45179 .37785 Mdot
.46426 .66218 Mdot
.62765 .4465 Mdot
.39651 .58354 Mdot
.37535 .4289 Mdot
.5379 .69719 Mdot
.54274 .58831 Mdot
.59528 .59295 Mdot
.45073 .63464 Mdot
.62216 .55439 Mdot
.44902 .31025 Mdot
.69498 .51549 Mdot
.6779 .4887 Mdot
.44759 .36153 Mdot
.6387 .54206 Mdot
.4898 .57955 Mdot
.30472 .49228 Mdot
.59825 .56057 Mdot
.45194 .68308 Mdot
.69484 .49238 Mdot
.64794 .46843 Mdot
.64169 .4018 Mdot
.46798 .64784 Mdot
.65468 .42323 Mdot
.43567 .66433 Mdot
.52179 .6295 Mdot
.49902 .64812 Mdot
.60601 .45396 Mdot
.53927 .35165 Mdot
.6704 .3792 Mdot
.33877 .48683 Mdot
.56354 .43647 Mdot
.40122 .47247 Mdot
.6538 .48679 Mdot
.49963 .67838 Mdot
.66241 .5932 Mdot
.69505 .47316 Mdot
.58539 .35521 Mdot
.44374 .34492 Mdot
.61032 .4046 Mdot
.57156 .43977 Mdot
.64117 .53186 Mdot
.37797 .60112 Mdot
.58144 .61033 Mdot
.57887 .37618 Mdot
.57986 .67802 Mdot
.35977 .40119 Mdot
.54348 .52269 Mdot
.39481 .34915 Mdot
.48781 .65382 Mdot
.615 .45968 Mdot
.44373 .56361 Mdot
.6025 .53061 Mdot
.39827 .64045 Mdot
.41721 .34755 Mdot
.55543 .64652 Mdot
.55501 .37973 Mdot
.66547 .53744 Mdot
.52254 .67121 Mdot
.65337 .43214 Mdot
.35735 .37904 Mdot
.44634 .41357 Mdot
.39969 .36277 Mdot
.49687 .57273 Mdot
.37619 .41415 Mdot
.62701 .44374 Mdot
.67449 .43704 Mdot
.51948 .30681 Mdot
.62817 .60909 Mdot
.4679 .36799 Mdot
.66668 .38884 Mdot
.544 .32359 Mdot
.48913 .60483 Mdot
.61814 .62111 Mdot
.40111 .36834 Mdot
.59255 .36331 Mdot
.5888 .52307 Mdot
.59531 .4298 Mdot
.59265 .58918 Mdot
.57172 .61706 Mdot
.67327 .5262 Mdot
.30159 .50282 Mdot
.60377 .65026 Mdot
.44009 .38068 Mdot
.61101 .37602 Mdot
.34168 .43412 Mdot
.497 .70142 Mdot
.47023 .38686 Mdot
.56361 .69263 Mdot
.50932 .47202 Mdot
.66359 .56256 Mdot
.39355 .3544 Mdot
.67826 .59453 Mdot
.56538 .67562 Mdot
.60229 .40907 Mdot
.35325 .4916 Mdot
.67783 .54121 Mdot
.67594 .46332 Mdot
.5735 .32707 Mdot
.5067 .66476 Mdot
.3871 .34462 Mdot
.35134 .55467 Mdot
.40245 .44568 Mdot
.58184 .32548 Mdot
.39207 .46868 Mdot
.4348 .43915 Mdot
.41943 .32417 Mdot
.6314 .61742 Mdot
.4321 .42274 Mdot
.58559 .68293 Mdot
.57157 .3697 Mdot
.62116 .41231 Mdot
.5512 .66046 Mdot
.31437 .52479 Mdot
.40251 .39984 Mdot
.45623 .44035 Mdot
.59638 .54528 Mdot
.67957 .58935 Mdot
.3986 .56496 Mdot
.6209 .43573 Mdot
.51733 .40583 Mdot
.52454 .35612 Mdot
.67403 .45771 Mdot
.66646 .38987 Mdot
.49829 .38197 Mdot
.42431 .55114 Mdot
.61348 .65817 Mdot
.50485 .42329 Mdot
.66447 .5718 Mdot
.4881 .40993 Mdot
.40391 .37648 Mdot
.58168 .32949 Mdot
.58847 .38202 Mdot
.64599 .53008 Mdot
.64443 .40298 Mdot
.58418 .63194 Mdot
.59129 .63052 Mdot
.49211 .36184 Mdot
.66647 .52572 Mdot
.6251 .4766 Mdot
.69236 .48587 Mdot
.51513 .61312 Mdot
.4374 .62781 Mdot
.37123 .55987 Mdot
.43956 .5156 Mdot
.32033 .57194 Mdot
.37497 .43618 Mdot
.51074 .66839 Mdot
.32125 .55993 Mdot
.37887 .50094 Mdot
.39067 .58238 Mdot
.32527 .41381 Mdot
.36073 .5602 Mdot
.45093 .67886 Mdot
.56677 .54526 Mdot
.59307 .3783 Mdot
.45998 .4585 Mdot
.36054 .54515 Mdot
.65498 .5724 Mdot
.53149 .69631 Mdot
.39634 .35411 Mdot
.45866 .33337 Mdot
.51642 .64463 Mdot
.57682 .66183 Mdot
.59033 .32338 Mdot
.65133 .38747 Mdot
.4515 .31931 Mdot
.64661 .52902 Mdot
.66564 .58614 Mdot
.35618 .36358 Mdot
.60859 .49183 Mdot
.44067 .57488 Mdot
.40968 .6209 Mdot
.42365 .35804 Mdot
.57578 .55951 Mdot
.31495 .4825 Mdot
.46478 .61184 Mdot
.44107 .4562 Mdot
.39425 .39791 Mdot
.35585 .41755 Mdot
.35172 .43822 Mdot
.67436 .50028 Mdot
.36635 .44305 Mdot
.39138 .37657 Mdot
.51508 .70454 Mdot
.56646 .4778 Mdot
.64067 .63563 Mdot
.39779 .5238 Mdot
.54472 .32916 Mdot
.56214 .42217 Mdot
.56739 .61183 Mdot
.46915 .64898 Mdot
.37467 .38106 Mdot
.44449 .6755 Mdot
.61658 .53595 Mdot
.43704 .38734 Mdot
.56622 .39235 Mdot
.46442 .38216 Mdot
.49953 .35528 Mdot
.51786 .57756 Mdot
.67598 .4661 Mdot
.34224 .61619 Mdot
.54461 .34927 Mdot
.63516 .57729 Mdot
.56487 .68373 Mdot
.54796 .32778 Mdot
.61147 .63317 Mdot
.60864 .60623 Mdot
.47263 .63743 Mdot
.40879 .56034 Mdot
.46917 .49399 Mdot
.54939 .59105 Mdot
.38933 .43503 Mdot
.54211 .39277 Mdot
.56541 .31788 Mdot
.48771 .32036 Mdot
.46851 .47864 Mdot
.56201 .47222 Mdot
.35828 .52714 Mdot
.58481 .34835 Mdot
.53577 .55805 Mdot
.37515 .57997 Mdot
.45883 .45527 Mdot
.52548 .63904 Mdot
.66461 .57709 Mdot
.4176 .55539 Mdot
.44434 .68526 Mdot
.4414 .35695 Mdot
.427 .32062 Mdot
.4906 .35109 Mdot
.55934 .65465 Mdot
.65932 .41054 Mdot
.65592 .50907 Mdot
.36625 .50495 Mdot
.39742 .60991 Mdot
.5032 .5418 Mdot
.43695 .65744 Mdot
.64602 .36616 Mdot
.67409 .56689 Mdot
.57453 .63915 Mdot
.34687 .61198 Mdot
.44443 .53194 Mdot
.55798 .63523 Mdot
.37733 .48498 Mdot
.56091 .69146 Mdot
.68358 .57743 Mdot
.55751 .3554 Mdot
.54456 .30868 Mdot
.32117 .49687 Mdot
.56107 .44762 Mdot
.30404 .51036 Mdot
.48403 .32832 Mdot
.58926 .53752 Mdot
.45956 .65732 Mdot
.64177 .38371 Mdot
.51895 .36439 Mdot
.47174 .31162 Mdot
.50048 .35393 Mdot
.61781 .40712 Mdot
.65277 .49384 Mdot
.3587 .598 Mdot
.62106 .58322 Mdot
.66809 .45074 Mdot
.37155 .62729 Mdot
.62177 .38327 Mdot
.60596 .54671 Mdot
.68612 .51096 Mdot
.43081 .67394 Mdot
.41874 .67445 Mdot
.35688 .45178 Mdot
.3688 .5998 Mdot
.43176 .47786 Mdot
.68925 .53003 Mdot
.33296 .53507 Mdot
.62169 .53633 Mdot
.63768 .64312 Mdot
.57787 .66473 Mdot
.67442 .54213 Mdot
.56423 .68553 Mdot
.50175 .30752 Mdot
.6591 .39781 Mdot
.563 .6314 Mdot
.37325 .50385 Mdot
.40881 .40211 Mdot
.36217 .49884 Mdot
.58501 .6574 Mdot
.41119 .52938 Mdot
.659 .58352 Mdot
.47356 .64884 Mdot
.55945 .5085 Mdot
.63228 .61092 Mdot
.46962 .60449 Mdot
.54219 .68667 Mdot
.6178 .65234 Mdot
.46422 .34517 Mdot
.34194 .49933 Mdot
.53749 .5957 Mdot
.37868 .64348 Mdot
.49779 .46654 Mdot
.49709 .60687 Mdot
.34439 .53963 Mdot
.52236 .60167 Mdot
.35035 .62696 Mdot
.68486 .44305 Mdot
.57352 .58776 Mdot
.52582 .40038 Mdot
.33876 .56287 Mdot
.46068 .65997 Mdot
.52171 .66858 Mdot
.67423 .46132 Mdot
.33838 .51015 Mdot
.44193 .34209 Mdot
.53932 .50224 Mdot
.35866 .5399 Mdot
.46226 .42758 Mdot
.3548 .46451 Mdot
.32373 .43037 Mdot
.49607 .35733 Mdot
.60143 .56647 Mdot
.32932 .54473 Mdot
.61886 .36843 Mdot
.43754 .50736 Mdot
.44448 .56981 Mdot
.55472 .35116 Mdot
.46009 .57759 Mdot
.46832 .56236 Mdot
.47189 .45583 Mdot
.56299 .344 Mdot
.56936 .57242 Mdot
.6138 .54752 Mdot
.67757 .58443 Mdot
.38784 .39146 Mdot
.55706 .6152 Mdot
.60959 .61083 Mdot
.53801 .40028 Mdot
.38471 .65133 Mdot
.43249 .5183 Mdot
.69363 .49855 Mdot
.51722 .43938 Mdot
.57522 .62442 Mdot
.43005 .31945 Mdot
.58253 .55443 Mdot
.46213 .4668 Mdot
.33033 .51194 Mdot
.32992 .55326 Mdot
.43027 .59098 Mdot
.38768 .36814 Mdot
.6221 .53392 Mdot
.58926 .64889 Mdot
.62374 .56139 Mdot
.40217 .62667 Mdot
.68134 .43133 Mdot
.44015 .33529 Mdot
.5942 .32884 Mdot
.6537 .57163 Mdot
.45456 .6083 Mdot
.38183 .34938 Mdot
.55672 .48041 Mdot
.61828 .49215 Mdot
.66376 .41842 Mdot
.59597 .3538 Mdot
.58851 .3688 Mdot
.42093 .51393 Mdot
.64307 .43983 Mdot
.54371 .35256 Mdot
.61613 .62837 Mdot
.49799 .30994 Mdot
.54759 .36108 Mdot
.62274 .66369 Mdot
.57812 .37625 Mdot
.63198 .63146 Mdot
.65049 .42893 Mdot
.49323 .60185 Mdot
.58851 .54555 Mdot
.5182 .42243 Mdot
.5997 .64842 Mdot
.67064 .50233 Mdot
.57117 .50417 Mdot
.47044 .68426 Mdot
.53555 .67767 Mdot
.58346 .67612 Mdot
.40843 .59526 Mdot
.58412 .52042 Mdot
.33072 .54395 Mdot
.57439 .31199 Mdot
.38375 .62016 Mdot
.69044 .50148 Mdot
.50508 .70084 Mdot
.62399 .48119 Mdot
.53384 .70157 Mdot
.46717 .34831 Mdot
.6265 .48021 Mdot
.34793 .44362 Mdot
.37396 .34352 Mdot
.33981 .49766 Mdot
.57841 .60365 Mdot
.48339 .32887 Mdot
.54163 .32977 Mdot
.50755 .31757 Mdot
.34834 .42903 Mdot
.52333 .34111 Mdot
.37507 .62829 Mdot
.57037 .51902 Mdot
.38318 .60219 Mdot
.35422 .4965 Mdot
.53708 .34167 Mdot
.68603 .53811 Mdot
.41631 .40295 Mdot
.4886 .62604 Mdot
.60941 .36267 Mdot
.34842 .47353 Mdot
.42183 .67519 Mdot
.50063 .43871 Mdot
.60588 .44031 Mdot
.49076 .29641 Mdot
.33551 .44374 Mdot
.55798 .66225 Mdot
.50303 .3775 Mdot
.56217 .67394 Mdot
.60996 .66871 Mdot
.63087 .42066 Mdot
.48854 .63654 Mdot
.33728 .60255 Mdot
.64241 .48531 Mdot
.38798 .34054 Mdot
.60425 .53793 Mdot
.6802 .44123 Mdot
.35626 .48465 Mdot
.48695 .35918 Mdot
.50688 .38145 Mdot
.34334 .4477 Mdot
.42177 .40301 Mdot
.42145 .41075 Mdot
.34774 .62124 Mdot
.51151 .63638 Mdot
.37891 .60915 Mdot
.39451 .39481 Mdot
.44458 .62991 Mdot
.44585 .34607 Mdot
.60585 .32874 Mdot
.60594 .46514 Mdot
.67608 .55895 Mdot
.36436 .5809 Mdot
.37037 .59261 Mdot
.52658 .36577 Mdot
.6646 .54272 Mdot
.45615 .49351 Mdot
.45831 .44235 Mdot
.64895 .41947 Mdot
.41582 .64367 Mdot
.52297 .58885 Mdot
.33741 .45694 Mdot
.44622 .68564 Mdot
.31585 .47323 Mdot
.59091 .38126 Mdot
.61916 .58383 Mdot
.58005 .53278 Mdot
.66342 .58408 Mdot
.4255 .48436 Mdot
.34865 .59052 Mdot
.39313 .38786 Mdot
.57902 .53146 Mdot
.38995 .58862 Mdot
.36333 .46724 Mdot
.6078 .61598 Mdot
.65192 .54585 Mdot
.49938 .58279 Mdot
.59121 .46152 Mdot
.52118 .70778 Mdot
.60708 .40475 Mdot
.42319 .32016 Mdot
.33196 .51745 Mdot
.65258 .53802 Mdot
.36365 .5871 Mdot
.44214 .42797 Mdot
.57267 .41402 Mdot
.33447 .48078 Mdot
.58373 .34401 Mdot
.51164 .66944 Mdot
.6202 .38478 Mdot
.65843 .55171 Mdot
.61671 .48723 Mdot
.36648 .60688 Mdot
.33841 .49006 Mdot
.44341 .58971 Mdot
.55064 .52784 Mdot
.479 .42551 Mdot
.50362 .69302 Mdot
.55498 .64408 Mdot
.4105 .5644 Mdot
.685 .46229 Mdot
.34089 .45916 Mdot
.60648 .42327 Mdot
.36171 .45933 Mdot
.33708 .47834 Mdot
.67946 .56976 Mdot
.57779 .64058 Mdot
.67737 .44586 Mdot
.36229 .54004 Mdot
.49062 .29776 Mdot
.43453 .68587 Mdot
.44616 .67367 Mdot
.46897 .59779 Mdot
.50361 .39179 Mdot
.33113 .58116 Mdot
.54063 .68327 Mdot
.5989 .41307 Mdot
.56611 .68829 Mdot
.48809 .31152 Mdot
.51507 .57271 Mdot
.49396 .64845 Mdot
.41865 .48431 Mdot
.64922 .49908 Mdot
.51505 .63594 Mdot
.45058 .37926 Mdot
.4005 .51557 Mdot
.48223 .6421 Mdot
.48919 .65027 Mdot
.43341 .5658 Mdot
.63395 .5957 Mdot
.4337 .38013 Mdot
.6012 .37234 Mdot
.33114 .58614 Mdot
.44473 .63268 Mdot
.37289 .58963 Mdot
.59238 .54382 Mdot
.47125 .37875 Mdot
.36897 .34807 Mdot
.32519 .55405 Mdot
.43056 .64127 Mdot
.67008 .56638 Mdot
.5121 .53621 Mdot
.39119 .60232 Mdot
.38496 .60808 Mdot
.6601 .48045 Mdot
.58692 .52797 Mdot
.44939 .47638 Mdot
.69295 .51796 Mdot
.63675 .36812 Mdot
.32728 .59054 Mdot
.3202 .55583 Mdot
.63855 .55813 Mdot
.42037 .583 Mdot
.57361 .36558 Mdot
.68206 .51269 Mdot
.31162 .52518 Mdot
.62784 .51406 Mdot
.34474 .60226 Mdot
.39133 .54606 Mdot
.33329 .58345 Mdot
.374 .42523 Mdot
.68427 .56382 Mdot
.59122 .63724 Mdot
.64987 .46197 Mdot
.51823 .36694 Mdot
.55637 .54905 Mdot
.52724 .3381 Mdot
.45544 .40745 Mdot
.50056 .36969 Mdot
.4776 .631 Mdot
.48722 .56154 Mdot
.61175 .39325 Mdot
.48319 .33089 Mdot
.6083 .37198 Mdot
.41948 .45971 Mdot
.569 .44112 Mdot
.57966 .32591 Mdot
.50533 .43299 Mdot
.6304 .52458 Mdot
.64272 .63611 Mdot
.50014 .54597 Mdot
.55882 .34058 Mdot
.69655 .50668 Mdot
.59333 .44403 Mdot
.51295 .64835 Mdot
.65122 .57234 Mdot
.43621 .38303 Mdot
.57985 .64646 Mdot
.6062 .37941 Mdot
.37632 .59193 Mdot
.55715 .3933 Mdot
.44815 .65117 Mdot
.39338 .46566 Mdot
.31718 .43947 Mdot
.39824 .44305 Mdot
.34921 .38962 Mdot
.39345 .64784 Mdot
.38056 .49201 Mdot
.42449 .35233 Mdot
.39287 .63798 Mdot
.52341 .42384 Mdot
.6181 .45924 Mdot
.68988 .49177 Mdot
.39818 .35618 Mdot
.34733 .57671 Mdot
.60995 .64399 Mdot
.58734 .36979 Mdot
.33769 .41278 Mdot
.33521 .48966 Mdot
.662 .54822 Mdot
.53988 .42716 Mdot
.45504 .31541 Mdot
.54377 .50368 Mdot
.49625 .32755 Mdot
.60405 .53798 Mdot
.63156 .65576 Mdot
.4022 .37441 Mdot
.62431 .46639 Mdot
.51744 .42616 Mdot
.37865 .58467 Mdot
.47272 .64667 Mdot
.36199 .62652 Mdot
.36894 .54759 Mdot
.44494 .31137 Mdot
.38327 .57352 Mdot
.62785 .43918 Mdot
.43454 .59502 Mdot
.57417 .36843 Mdot
.47227 .32187 Mdot
.56746 .42226 Mdot
.65682 .42373 Mdot
.32933 .52966 Mdot
.42276 .40792 Mdot
.63648 .63852 Mdot
.55734 .68974 Mdot
.32422 .55685 Mdot
.52639 .34181 Mdot
.34124 .49968 Mdot
.39292 .56668 Mdot
.45044 .41125 Mdot
.4545 .33829 Mdot
.51054 .45834 Mdot
.57391 .31385 Mdot
.44071 .61777 Mdot
.60557 .64818 Mdot
.52635 .65845 Mdot
.68624 .46701 Mdot
.55433 .33886 Mdot
.56212 .63109 Mdot
.48812 .57354 Mdot
.50523 .41701 Mdot
.39182 .33505 Mdot
.64418 .56495 Mdot
.62872 .35117 Mdot
.46741 .66233 Mdot
.33567 .4969 Mdot
.59356 .67545 Mdot
.49583 .59909 Mdot
.53984 .5769 Mdot
.34217 .52451 Mdot
.67845 .51423 Mdot
.57032 .64655 Mdot
.51291 .67757 Mdot
.35145 .4494 Mdot
.55523 .59795 Mdot
.47128 .32793 Mdot
.63151 .39655 Mdot
.52593 .57361 Mdot
.50172 .32389 Mdot
.69492 .46906 Mdot
.35269 .43799 Mdot
.3604 .53155 Mdot
.33412 .41395 Mdot
.42833 .67677 Mdot
.46692 .60929 Mdot
.49563 .35576 Mdot
.55414 .54774 Mdot
.67472 .53987 Mdot
.51467 .65914 Mdot
.571 .3386 Mdot
.31777 .49029 Mdot
.63307 .37296 Mdot
.61054 .44831 Mdot
.39306 .58325 Mdot
.39681 .5951 Mdot
.61574 .59847 Mdot
.59796 .54725 Mdot
.45827 .55946 Mdot
.58817 .45982 Mdot
.4313 .61632 Mdot
.45832 .33166 Mdot
.336 .46149 Mdot
.53584 .69273 Mdot
.42713 .31808 Mdot
.47912 .6678 Mdot
.49216 .67156 Mdot
.59568 .41398 Mdot
.57333 .59699 Mdot
.53206 .41336 Mdot
.52199 .39466 Mdot
.66687 .38536 Mdot
.32596 .54663 Mdot
.57533 .62564 Mdot
.5865 .44251 Mdot
.6554 .45712 Mdot
.50569 .6138 Mdot
.44812 .31373 Mdot
.66537 .49582 Mdot
.55528 .32897 Mdot
.57834 .37572 Mdot
.66705 .48139 Mdot
.61578 .54048 Mdot
.62657 .61588 Mdot
.39 .40161 Mdot
.618 .4557 Mdot
.45401 .37503 Mdot
.67991 .49598 Mdot
.42076 .54051 Mdot
.4261 .66293 Mdot
.35055 .55558 Mdot
.40461 .4921 Mdot
.41225 .43293 Mdot
.34979 .45982 Mdot
.33349 .40093 Mdot
.32054 .55589 Mdot
.65195 .43949 Mdot
.32667 .51473 Mdot
.5136 .6317 Mdot
.31317 .47052 Mdot
.53734 .3936 Mdot
.55364 .59698 Mdot
.38589 .62417 Mdot
.4662 .45033 Mdot
.51605 .34461 Mdot
.61319 .61515 Mdot
.53741 .66016 Mdot
.44755 .3409 Mdot
.43219 .68093 Mdot
.52625 .69694 Mdot
.66901 .5498 Mdot
.50163 .3012 Mdot
.52472 .66209 Mdot
.33458 .43702 Mdot
.65063 .37386 Mdot
.64014 .38335 Mdot
.61882 .59412 Mdot
.50694 .37468 Mdot
.6629 .3947 Mdot
.65636 .57816 Mdot
.37883 .33771 Mdot
.63546 .36371 Mdot
.38201 .44368 Mdot
.60758 .66544 Mdot
.39153 .64492 Mdot
.41484 .44589 Mdot
.30651 .49146 Mdot
.46298 .35414 Mdot
.39048 .61528 Mdot
.60175 .45708 Mdot
.33443 .51546 Mdot
.61578 .39096 Mdot
.62673 .38267 Mdot
.67186 .5342 Mdot
.46144 .62476 Mdot
.65023 .39313 Mdot
.65574 .47014 Mdot
.45145 .65861 Mdot
.33836 .50359 Mdot
.4018 .42974 Mdot
.55247 .54216 Mdot
.45235 .43664 Mdot
.41028 .37691 Mdot
.52732 .33198 Mdot
.54323 .31517 Mdot
.53021 .30786 Mdot
.34878 .53897 Mdot
.56291 .41313 Mdot
.45646 .50644 Mdot
.35752 .44708 Mdot
.65399 .49591 Mdot
.62381 .46441 Mdot
.6042 .38795 Mdot
.46705 .60966 Mdot
.49397 .70026 Mdot
.34307 .45604 Mdot
.39938 .53136 Mdot
.55606 .3265 Mdot
.67366 .50377 Mdot
.65282 .43887 Mdot
.33281 .48743 Mdot
.45186 .55507 Mdot
.38978 .49532 Mdot
.33471 .57127 Mdot
.39734 .3464 Mdot
.6223 .61734 Mdot
.339 .58335 Mdot
.35312 .36955 Mdot
.66541 .45942 Mdot
.52721 .37546 Mdot
.69917 .48842 Mdot
.61429 .36013 Mdot
.37633 .54539 Mdot
.33406 .52972 Mdot
.59137 .45372 Mdot
.67778 .57505 Mdot
.46995 .63492 Mdot
.61699 .43986 Mdot
.62386 .38613 Mdot
.42479 .6096 Mdot
.68518 .4436 Mdot
.42703 .47065 Mdot
.69924 .49942 Mdot
.47075 .35608 Mdot
.33232 .47882 Mdot
.50484 .68401 Mdot
.36471 .42008 Mdot
.53201 .69888 Mdot
.48566 .61271 Mdot
.47611 .66852 Mdot
.35848 .59046 Mdot
.62024 .4367 Mdot
.3283 .51233 Mdot
.42718 .59643 Mdot
.33387 .47294 Mdot
.40122 .33598 Mdot
.69094 .56163 Mdot
.42899 .56223 Mdot
.36702 .56735 Mdot
.54901 .61586 Mdot
.58401 .60238 Mdot
.64972 .41953 Mdot
.49214 .32587 Mdot
.63439 .49081 Mdot
.45034 .69144 Mdot
.44421 .44085 Mdot
.48637 .36391 Mdot
.61725 .48556 Mdot
.48214 .36371 Mdot
.42395 .4538 Mdot
.42635 .66962 Mdot
.33983 .59859 Mdot
.58935 .65093 Mdot
.37853 .52137 Mdot
.31907 .55815 Mdot
.31103 .47668 Mdot
.55572 .70251 Mdot
.64805 .36695 Mdot
.33979 .56505 Mdot
.62634 .37391 Mdot
.4632 .35812 Mdot
.47423 .66363 Mdot
.36957 .58746 Mdot
.64005 .38608 Mdot
.47578 .69288 Mdot
.37533 .58296 Mdot
.62735 .34823 Mdot
.6416 .42688 Mdot
.42418 .31795 Mdot
.65153 .57562 Mdot
.53043 .63249 Mdot
.52749 .70386 Mdot
.3204 .44385 Mdot
.6273 .42996 Mdot
.61359 .59837 Mdot
.66866 .54773 Mdot
.60733 .3799 Mdot
.4203 .41352 Mdot
.65792 .54362 Mdot
.46117 .32496 Mdot
.37513 .60823 Mdot
.44313 .43329 Mdot
.57531 .616 Mdot
.41078 .54342 Mdot
.41471 .38196 Mdot
.3263 .47055 Mdot
.32761 .40976 Mdot
.41075 .51523 Mdot
.42788 .35687 Mdot
.65161 .36818 Mdot
.3961 .32985 Mdot
.57498 .59296 Mdot
.50925 .6468 Mdot
.41065 .49846 Mdot
.5779 .53987 Mdot
.65154 .62895 Mdot
.33586 .55506 Mdot
.39405 .46297 Mdot
.65367 .40892 Mdot
.58401 .53478 Mdot
.51814 .62271 Mdot
.52994 .61416 Mdot
.40253 .41685 Mdot
.64718 .63839 Mdot
.35475 .62653 Mdot
.34057 .39571 Mdot
.46355 .68379 Mdot
.31388 .47299 Mdot
.54603 .40987 Mdot
.66957 .44231 Mdot
.63217 .4305 Mdot
.62074 .37087 Mdot
.454 .39465 Mdot
.40836 .37409 Mdot
.65159 .62443 Mdot
.36748 .43246 Mdot
.48762 .44966 Mdot
.66603 .51077 Mdot
.39663 .54351 Mdot
.3353 .479 Mdot
.43577 .4455 Mdot
.35086 .37844 Mdot
.4445 .3318 Mdot
.47268 .37475 Mdot
.65732 .50638 Mdot
.6576 .59495 Mdot
.65103 .43208 Mdot
.36779 .50221 Mdot
.54225 .66586 Mdot
.32155 .49821 Mdot
.51723 .35896 Mdot
.59208 .48127 Mdot
.57762 .61019 Mdot
.41242 .57256 Mdot
.33788 .53377 Mdot
.45635 .30979 Mdot
.41128 .52956 Mdot
.41736 .43055 Mdot
.34598 .46979 Mdot
.63464 .6397 Mdot
.49929 .51462 Mdot
.42928 .44059 Mdot
.3447 .44335 Mdot
.40429 .32127 Mdot
.38993 .59027 Mdot
.51185 .68953 Mdot
.67032 .43673 Mdot
.33464 .41559 Mdot
.33083 .52537 Mdot
.66727 .44673 Mdot
.58751 .4587 Mdot
.61903 .34917 Mdot
.43426 .43322 Mdot
.52806 .68541 Mdot
.63482 .57381 Mdot
.35962 .39024 Mdot
.46529 .42332 Mdot
.34715 .62332 Mdot
.5037 .36432 Mdot
.52913 .41402 Mdot
.46876 .66864 Mdot
.59945 .38642 Mdot
.41734 .6331 Mdot
.662 .53367 Mdot
.4699 .35008 Mdot
.5808 .32437 Mdot
.40478 .32407 Mdot
.53078 .58354 Mdot
.69317 .47589 Mdot
.55972 .41176 Mdot
.55248 .66748 Mdot
.5784 .51479 Mdot
.68197 .43778 Mdot
.5749 .66501 Mdot
.37541 .42883 Mdot
.56139 .57096 Mdot
.66734 .38268 Mdot
.43422 .60773 Mdot
.51584 .54586 Mdot
.58218 .58757 Mdot
.49652 .59861 Mdot
.49441 .57477 Mdot
.64346 .57302 Mdot
.50853 .52567 Mdot
.59403 .64564 Mdot
.62916 .55751 Mdot
.40398 .45069 Mdot
.61111 .43351 Mdot
.47084 .3883 Mdot
.35334 .36696 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0?ooooooB_ooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A006ooooo`03o`000?oooooooooo0?ooooooB_ooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0?ooooooB_oo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06
ooooo`?o0000oooooom:ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<oooo
o`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom:ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001_ooool00ol0003oooooooooo`3ooooood[ooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0:7ooooo1?l0002T
ooooo`007?ooool00ol0003oooooooooo`2Kooooo`;o000000?oooooo`000?l000001ol000001?oo
oooo0000o`000?l0002Nooooo`007?ooool00ol0003oooooooooo`2Kooooo`co000000?oooooo`00
0?l000000ol0002Looooo`007?ooool00ol0003oooooooooo`2Dooooo`?o000000?oooooo`000?l0
00004ol0002Looooo`007?ooool00ol0003oooooooooo`2:ooooobGo0000V_ooool001cooooo00?o
0000ooooooooool0R?oooolZo`0009Oooooo000Looooo`03o`000?oooooooooo08Cooooo;ol0002F
ooooo`007?ooool00ol0003oooooooooo`20ooooocSo0000TOooool001cooooo00?o0000oooooooo
ool0P?oooolMo`000003ooooool0003o000001co0000SOooool001cooooo00?o0000ooooooooool0
OOoooom2o`0008[ooooo000Looooo`03o`000?oooooooooo07cooooo9_l000000ooooooo0000o`00
000<o`000003ooooool0003o000000go0000R?ooool001cooooo0_l0001mooooob;o000000?ooooo
o`000?l000000oooool=o`000003ooooool0003o000000oo0000Q_ooool001cooooo00?o0000oooo
ooooool0N_oooolNo`0000Oooooo0_l00005oooooaoo0000Q?ooool001cooooo00?o0000oooooooo
ool0N?oooolNo`0000Wooooo0_l00004ooooo`;o000000?oooooo`000?l000007?l00023ooooo`00
7?ooool00ol0003oooooooooo`1goooooaco00002oooool3o`0000Cooooo0_l000000ooooooo0000
o`000002ooooo`?o000000Coooooo`000?l0003ooooo5?l00022ooooo`007?ooool00ol0003ooooo
ooooo`1foooooaco00000oooool2o`0000Cooooo0_l000000ooooooo0000o`00000<ooooo`?o0000
2?oooolAo`00087ooooo000Looooo`03o`000?oooooooooo07Kooooo5?l00003ooooo`Ko00000_oo
ool2o`0000Cooooo0_l0000@ooooo`;o00002?ooool2o`0000;ooooo3_l00020ooooo`007?ooool0
0ol0003oooooooooo`1foooooaCo00001Oooool4o`0000kooooo0_l0000:ooooo`;o00001Oooool2
o`0000Oooooo3_l0001nooooo`007?ooool00ol0003oooooooooo`1coooooa;o000000?oooooo`00
0?l000000_l00005ooooo`;o00001Oooool2o`0000?ooooo0_l00004ooooo`;o00004Oooool2o`00
00Sooooo3Ol0001nooooo`007?ooool00ol0003oooooooooo`1boooooa3o00000oooool4o`0000Wo
oooo0_l00002ooooo`;o00000oooool3o`000003ooooool0003o000000cooooo0_l0000:ooooo`;o
000000Coooooo`000?l0003ooooo2ol0001oooooo`007?ooool00ol0003oooooooooo`1booooo`go
000000?oooooo`000?l000000oooool2o`0000_ooooo0_l000000ooooooo0000o`000002ooooo`;o
000000?oooooo`000?l000000ol0000<ooooo`?o000000?oooooo`000?l000001?ooool4o`000005
ooooool0003o0000o`000?ooool03Ol0001looooo`007?ooool00ol0003oooooooooo`1`ooooo`oo
00003_ooool2o`0000;ooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo0_l00009ooooo`;o
00000_ooool4o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000000_l00002oooo
o`;o00000_ooool<o`0007cooooo000Looooo`03o`000?oooooooooo073ooooo2ol000001?oooooo
0000o`000?l0000<ooooo`Co00000_ooool2o`0000Kooooo0_l0000=ooooo`;o00000_ooool2o`00
00Kooooo0_l00003ooooo`;o00002?ooool;o`0007_ooooo000Looooo`03o`000?oooooooooo06oo
oooo2ol00002ooooo`;o000000?oooooo`000?l000002_ooool2o`0000?ooooo0ol0000Dooooo`;o
00003Oooool2o`0000cooooo2ol0001jooooo`007?ooool00ol0003oooooooooo`1^ooooo`_o0000
00?oooooo`000?l000000oooool2o`0000gooooo1?l0000Dooooo`?o00000_ooool2o`0000?ooooo
1?l00002ooooo`;o00003_ooool:o`0007Wooooo000Looooo`03o`000?oooooooooo06gooooo2ol0
0002ooooo`;o00004?ooool4o`0001Cooooo1Ol00002ooooo`;o00000oooool5o`0000Gooooo0_l0
000:ooooo`_o0000N?ooool001cooooo00?o0000ooooooooool0KOooool;o`0000;ooooo0_l00000
0ooooooo0000o`000005ooooo`;o00001_ooool3o`0000Cooooo0_l0000?ooooo`;o000000?ooooo
o`000?l000002_ooool2o`0000Gooooo0_l0000<ooooo`_o0000M_ooool001cooooo0_l0001^oooo
o`Wo00000_ooool2o`0000?ooooo0_l00005ooooo`;o00001_ooool3o`0000Cooooo1?l0000Foooo
o`;o00002oooool2o`0000Wooooo0_l000000ooooooo0000o`000009o`0007Kooooo000Looooo`03
o`000?oooooooooo06[ooooo3?l00002ooooo`;o00000oooool2o`0000Oooooo0_l0000<ooooo`?o
00001Oooool2o`000003ooooool0003o000000[ooooo1?l000000ooooooo0000o`000008ooooo`;o
00000_ooool2o`0000Gooooo0_l000000ooooooo0000o`00000;o`0007Cooooo000Looooo`03o`00
0?oooooooooo06Wooooo2ol00008ooooo`Co00001_ooool3o`0000?ooooo0_l00005ooooo`Co0000
1Oooool5o`0000Kooooo0_l00002ooooo`Co000000Coooooo`000?l0003o00001oooool2o`0000;o
oooo0_l00008ooooo`;o00000_ooool:o`0007?ooooo000Looooo`03o`000?oooooooooo06Wooooo
2_l00009ooooo`Co00001_ooool3o`0000?ooooo0_l00005ooooo`Co00000oooool2o`000003oooo
ool0003o000000;o00000oooool2o`000003ooooool0003o000000Sooooo0_l00007ooooo`;o0000
2?ooool2o`0000Oooooo2ol0001aooooo`007?ooool00ol0003oooooooooo`1Xooooo`[o00003?oo
ool2o`0000Kooooo0_l00006ooooo`;o00000oooool2o`0000Gooooo1Ol00005ooooo`;o00002?oo
ool2o`0000gooooo0_l00003ooooo`Co00002_ooool;o`0006kooooo000Looooo`03o`000?oooooo
oooo06Sooooo2_l0000<ooooo`;o00003_ooool2o`0000Wooooo1Ol00002ooooo`;o00000oooool4
o`0000Gooooo0_l00007ooooo`;o00001?ooool2o`0000?ooooo0_l00007ooooo`;o000000?ooooo
o`000?l000000_ooool:o`0006gooooo000Looooo`03o`000?oooooooooo06Oooooo2ol00008oooo
o`;o00000oooool2o`0001?ooooo0_l00003ooooo`?o00001?ooool2o`0000?ooooo1?l0000>oooo
o`;o00000_ooool2o`0000Sooooo0_l00004ooooo`;o000000?oooooo`000?l000000_l000000ooo
oooo0000o`000007o`0006gooooo000Looooo`03o`000?oooooooooo06Gooooo3?l00009ooooo`;o
00000oooool2o`0001?ooooo0_l00009ooooo`;o00001?ooool2o`0000oooooo0ol00002ooooo`;o
00000oooool4o`000004ooooool0003o0000o`0000?ooooo0_l00002ooooo`?o00000_ooool:o`00
06_ooooo000Looooo`03o`000?oooooooooo06Gooooo3?l0000>ooooo`Co00003Oooool2o`0000Co
oooo0_l00007ooooo`Co00001?ooool2o`0000gooooo0_l00003ooooo`;o00000oooool4o`0000;o
oooo1_l00004ooooo`;o00000oooool9o`0006_ooooo000Looooo`03o`000?oooooooooo06Gooooo
2?l000000ooooooo0000o`00000;ooooo`;o00000_ooool5o`0000_ooooo0ol00004ooooo`;o0000
2?ooool3o`0000Cooooo0_l0000?ooooo`;o00000oooool2o`0000Cooooo0_l00003ooooo`Co0000
1?ooool2o`0000?ooooo2Ol0001[ooooo`007?ooool00ol0003oooooooooo`1Uooooo`So000000?o
ooooo`000?l000000_l00004ooooo`;o00000oooool2o`0000;ooooo1Ol00005ooooo`Co00000_oo
ool2o`0000Cooooo0_l00009ooooo`?o00003_ooool2o`0000Gooooo0_l00002ooooo`?o00000_oo
ool4o`0000Gooooo0_l0000:ooooo`Wo0000J_ooool001cooooo00?o0000ooooooooool0Hoooool:
o`0000?ooooo0_l00004ooooo`;o00002?ooool2o`000003ooooool0003o000000Cooooo1?l00002
ooooo`;o00000_ooool4o`0000Oooooo0_l000000ooooooo0000o`00000>ooooo`;o00002?ooool3
o`0000?ooooo0_l00003ooooo`Wo00001_ooool<o`0006Sooooo000Looooo`03o`000?oooooooooo
06?ooooo2_l0000?ooooo`;o00001Oooool2o`0000Gooooo0_l00007ooooo`Co00001oooool2o`00
01_ooooo0_l00002ooooo`?o00001?ooool4o`0000;ooooo0ol000000ooooooo0000o`000003oooo
o`co0000J?ooool001cooooo00?o0000ooooooooool0H_ooool:o`0000;ooooo0_l000000ooooooo
0000o`000009ooooo`;o00003?ooool2o`0000Wooooo0_l0000Xooooo`?o00000_ooool2o`000003
ooooool0003o000000?ooooo0_l00002ooooo`;o00000oooool=o`0006Oooooo00001_ooooook^k^
oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0
003oooooooooo`1Rooooo`[o00000_ooool2o`000003ooooool0003o000000Oooooo0_l0000Ioooo
o`;o00002Oooool2o`0000Wooooo0ol00003ooooo`;o000000?oooooo`000?l000003Oooool3o`00
00Wooooo0_l00004ooooo`go0000Ioooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Rooooo`_o00003Oooool4
o`0001;ooooo0_l0000>ooooo`;o00001?ooool2o`0000?ooooo0ol00003ooooo`;o000000?ooooo
o`000?l000003Oooool2o`0000Cooooo0_l00004ooooo`;o00000oooool>o`0006Oooooo00000ooo
oooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006ooooo`03o`000?oooooooooo
06;ooooo2ol0000?ooooo`;o000000?oooooo`000?l000003oooool2o`0001Cooooo0_l0000Qoooo
o`;o00001oooool4o`000003ooooool0003o000000Wo0000Ioooool00003ooooool0003ooooo00;o
oooo00?o0000ooooooooool02Oooool01?m4A4CogMgMooooool00007ooooo`?o0000H?ooool;o`00
00Kooooo0_l00008ooooo`?o000000?oooooo`000?l000001_l0000Pooooo`;o00000_ooool2o`00
023ooooo0ol00002ooooo`;o00000oooool<o`0006Kooooo00000ooooooo0000ooooo`02ooooo`03
o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`1Poooo
o`_o00001_ooool2o`0000Sooooo0_l00004ooooo`Ko00007Oooool2o`000003ooooool0003o0000
00;ooooo0_l0000Dooooo`?o00002Oooool3o`0000Sooooo2ol0001Vooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooooooo
ool0H?ooool9o`0001gooooo0_l00008ooooo`;o00004_ooool2o`0001[ooooo1?l000000ooooooo
0000o`00000:ooooo`;o00001Oooool<o`0006Gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMg
M`cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`1Pooooo`Wo00007?ooool3o`00
00Oooooo0ol00009ooooo`;o00004Oooool2o`0000;ooooo0_l0000<ooooo`;o00000oooool3o`00
00Wooooo0ol00004ooooo`co0000IOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool0
0omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo063ooooo3?l0000:ooooo`;o00003Oooool2
o`0000Kooooo1?l0000:ooooo`;o00002oooool3o`0000?ooooo0_l00002ooooo`?o000000?ooooo
o`000?l000001_ooool4o`0000Cooooo0_l0000:ooooo`;o00001?ooool=o`0006Cooooo000Loooo
o`03o`000?oooooooooo063ooooo2?l000001?oooooo0000o`000?l00004ooooo`;o00001?ooool2
o`0000Oooooo0_l00004ooooo`;o00001_ooool2o`00017ooooo0_l00006ooooo`?o00002?ooool2
o`000003ooooool0003o000000Kooooo0ol00007ooooo`;o00002_ooool2o`0000;ooooo3Ol0001T
ooooo`007?ooool00ol0003oooooooooo`1Oooooo`Oo00002_ooool2o`000003ooooool0003o0000
00[ooooo0_l0000Oooooo`;o00009_ooool3o`0000Cooooo0_l00003ooooo`;o00000oooool<o`00
06Cooooo000Looooo`03o`000?oooooooooo05oooooo1ol0000=ooooo`;o00005?ooool2o`0000So
oooo0_l0000;ooooo`;o00000oooool3o`0000_ooooo1?l0000:ooooo`;o00001_ooool2o`0000Co
oooo1Ol00005ooooo`co0000I?ooool001cooooo00?o0000ooooooooool0G_ooool8o`00013ooooo
0_l0000Aooooo`;o000000?oooooo`000?l000001?ooool3o`0000?ooooo0_l00006ooooo`;o0000
0_ooool4o`0000Cooooo0_l00005ooooo`Co00002_ooool2o`0000[ooooo0_l00002ooooo`?o0000
1Oooool=o`0006?ooooo000Looooo`03o`000?oooooooooo05kooooo2Ol00006ooooo`;o00001ooo
ool2o`0000Oooooo0_l00003ooooo`;o00001_ooool2o`0000Cooooo0_l00004ooooo`;o00002_oo
ool2o`0000Kooooo0_l0000@ooooo`;o00002?ooool4o`000004ooooool0003o0000ooooo`;o0000
1oooool2o`000003ooooool0003o000000So0000Hoooool001cooooo00?o0000ooooooooool0G_oo
ool9o`0000Cooooo1?l00005ooooo`Co00001oooool2o`000003ooooool0003o000000;o00000ooo
ool2o`000003ooooool0003o000001;ooooo0_l0000Looooo`;o00000oooool2o`0000?ooooo1?l0
0004ooooo`;o00002?ooool<o`0006?ooooo000Looooo`03o`000?oooooooooo05gooooo2?l00004
ooooo`Co00001oooool4o`0000?ooooo0_l00005ooooo`;o00001Oooool2o`000004ooooool0003o
0000ooooo`;o00003oooool2o`00017ooooo0_l0000>ooooo`;o000000?oooooo`000?l000002?oo
ool2o`0000Cooooo0ol000000ooooooo0000o`00000:o`0006?ooooo000Looooo`03o`000?oooooo
oooo05cooooo2Ol00004ooooo`;o00001?ooool2o`0000Gooooo0_l00003ooooo`;o00003?ooool2
o`0000Cooooo0_l0000>ooooo`;o00000oooool2o`0000gooooo0_l000000ooooooo0000o`000009
ooooo`;o00000_ooool5o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`?o000000?ooooo
o`000?l000002_l0001Sooooo`007?ooool00ol0003oooooooooo`1Looooo`Wo00001oooool2o`00
0003ooooool0003o000000;ooooo0_l00009ooooo`;o00002?ooool3o`0000;ooooo0_l000001?oo
oooo0000o`000?l0000<ooooo`;o00000oooool2o`0000oooooo0ol00003ooooo`;o00001?ooool2
o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000001?ooool2
o`000003ooooool0003o000000co0000H_ooool001cooooo00?o0000ooooooooool0Foooool;o`00
00?ooooo0_l000001?oooooo0000o`000?l00004ooooo`;o00000oooool2o`0000Cooooo0ol00002
ooooo`;o00000oooool4o`000004ooooool0003o0000ooooo`?o00008_ooool2o`0000Cooooo1?l0
0009ooooo`;o00003?oooolAo`0006;ooooo000Looooo`03o`000?oooooooooo05_ooooo2ol00003
ooooo`;o000000?oooooo`000?l000001?l00006ooooo`;o00001Oooool2o`0000;ooooo0_l00005
ooooo`;o00009_ooool2o`0000Wooooo0_l00004ooooo`;o00000oooool2o`0000_ooooo0_l00000
1?oooooo0000o`000?ooool<o`0006;ooooo000Looooo`;o0000F_ooool;o`0000Sooooo1_l0000=
ooooo`;o00004oooool2o`0000Gooooo0_l0000Eooooo`;o00003oooool2o`0000?ooooo0_l0000;
ooooo`;o00001_ooool:o`0006;ooooo000Looooo`03o`000?oooooooooo05Sooooo3?l0000<oooo
o`;o00003Oooool2o`0000Gooooo0_l00009ooooo`;o000000?oooooo`000?l000001Oooool2o`00
01oooooo0_l00003ooooo`;o00000_ooool2o`0000kooooo0_l00007ooooo`Wo0000H_ooool001co
oooo00?o0000ooooooooool0F?ooool<o`0000Kooooo1?l0000Hooooo`;o00001?ooool2o`0000?o
oooo0ol00002ooooo`;o00002_ooool2o`0001Oooooo0ol00002ooooo`?o00000_ooool2o`0000[o
oooo0_l00004ooooo`;o00001Oooool:o`00067ooooo000Looooo`03o`000?oooooooooo05Oooooo
3Ol00005ooooo`Oo00000_ooool2o`00017ooooo0_l00005ooooo`;o00001?ooool2o`0000;ooooo
0_l0000:ooooo`;o00005oooool3o`0000;ooooo0ol000001?oooooo0000o`000?l0000:ooooo`;o
000000Coooooo`000?l0003ooooo0_l00006ooooo`Wo0000HOooool001cooooo00?o0000oooooooo
ool0Eoooool=o`0000Gooooo1?l000000ooooooo0000o`000004o`0000Sooooo0_l00007ooooo`;o
0000=?ooool3o`0000?ooooo0_l000000ooooooo0000o`000003o`0000Kooooo0_l00003ooooo`;o
000000Goooooo`000?l0003o0000ooooo`02o`0000;ooooo2Ol0001Qooooo`007?ooool00ol0003o
ooooooooo`1Gooooo`go00003?ooool4o`0000Sooooo0_l0000Dooooo`;o00002_ooool2o`00027o
oooo0_l00004ooooo`;o00001_ooool2o`0000Oooooo0_l000000ooooooo0000o`000002ooooo`Wo
0000HOooool001cooooo00?o0000ooooooooool0Eoooool=o`0000;ooooo0_l00005ooooo`;o0000
0oooool2o`0000Sooooo0_l00009ooooo`;o00002Oooool2o`0000[ooooo0_l0000Qooooo`;o0000
1?ooool2o`0000Kooooo1?l00004ooooo`?o000000Coooooo`000?l0003ooooo3?l0001Oooooo`00
7?ooool00ol0003oooooooooo`1Gooooo`ko000000Coooooo`000?l0003ooooo0_l00002ooooo`;o
00003Oooool2o`000003ooooool0003o000000Kooooo0_l0000Iooooo`;o00003oooool2o`0001[o
oooo1?l00004ooooo`;o00001Oooool=o`0005kooooo000Looooo`03o`000?oooooooooo05Oooooo
3_l00004ooooo`;o00000_ooool2o`00013ooooo0_l0000<ooooo`?o00004_ooool2o`0000oooooo
0_l0000Booooo`;o00003?ooool2o`0000Kooooo3_l0001Nooooo`007?ooool00ol0003ooooooooo
o`1Gooooo`co00001Oooool4o`0001gooooo0_l00002ooooo`?o00001?ooool2o`0001kooooo0_l0
000Aooooo`?o00002oooool2o`0000Kooooo0_l00002ooooo`_o0000GOooool001cooooo00?o0000
ooooooooool0Eoooool:o`0000;ooooo0_l00003ooooo`Co00007Oooool2o`0000Wooooo0_l0000K
ooooo`;o000000?oooooo`000?l000001oooool2o`0000Sooooo0ol00009ooooo`Co00002_ooool;
o`0005gooooo000Looooo`03o`000?oooooooooo05Oooooo2_l00002ooooo`;o00001?ooool2o`00
00Gooooo0_l00005ooooo`;o00002oooool4o`0002Wooooo0_l0000:ooooo`;o00001_ooool4o`00
00Cooooo0_l00004ooooo`Co00001_ooool2o`0000;ooooo2ol0001Mooooo`007?ooool00ol0003o
ooooooooo`1Gooooo`[o00001oooool4o`0000Cooooo0_l00005ooooo`;o00002oooool4o`0003go
oooo0_l00006ooooo`;o00000_ooool2o`0000Gooooo0_l00003ooooo`Co000000?oooooo`000?l0
00002?l0001Mooooo`007?ooool00ol0003oooooooooo`1Hooooo`[o000000?oooooo`000?l00000
0oooool4o`0000?ooooo0_l00007ooooo`;o00001_ooool2o`00043ooooo0_l000000ooooooo0000
o`000003ooooo`;o00001Oooool2o`0000Gooooo0_l00002oooooa3o0000GOooool001cooooo00?o
0000ooooooooool0E_ooool<o`000003ooooool0003o000000Cooooo0ol00003ooooo`;o00001ooo
ool2o`000003ooooool0003o000000?ooooo0_l0000>ooooo`;o00000oooool2o`0002_ooooo0_l0
00000ooooooo0000o`000003ooooo`;o00001?ooool2o`0000[ooooo4?l0001Mooooo`007?ooool0
0ol0003oooooooooo`1Fooooo`[o00001Oooool2o`0000;ooooo1?l00002ooooo`;o000000?ooooo
o`000?l000001oooool2o`0000Gooooo0_l0000<ooooo`;o00000oooool2o`0003Wooooo0ol00000
0ooooooo0000o`000003ooooo`;o00000oooool>o`0005gooooo000Looooo`;o0000F?ooool9o`00
00Gooooo0_l00002ooooo`Co00000_ooool2o`000003ooooool0003o000000?ooooo0_l00009oooo
o`;o0000Boooool4o`000004ooooool0003o0000ooooo`Co000000?oooooo`000?l000003_l0001M
ooooo`007?ooool00ol0003oooooooooo`1Gooooo`Wo00002_ooool3o`0000Kooooo1_l0000boooo
o`Co00001oooool2o`0001Oooooo0_l00005ooooo`?o00000oooool2o`000003ooooool0003o0000
00_o0000GOooool001cooooo00?o0000ooooooooool0E_ooool:o`0000[ooooo0_l00007ooooo`Go
00004_ooool2o`0000Gooooo0_l0000Hooooo`Co00001oooool2o`0001[ooooo0_l00002ooooo`?o
00001Oooool>o`0005gooooo000Looooo`03o`000?oooooooooo05Kooooo2ol00009ooooo`;o0000
7_ooool2o`0000Gooooo0_l0000Oooooo`;o00007Oooool3o`000003ooooool0003o000000Cooooo
0_l000000ooooooo0000o`00000;o`0005kooooo000Looooo`03o`000?oooooooooo05Gooooo3?l0
0006ooooo`Go00006Oooool2o`0002_ooooo0_l0000Dooooo`;o00001oooool2o`0000;ooooo0_l0
0002ooooo`Co000000?oooooo`000?l000002ol0001Nooooo`007?ooool00ol0003oooooooooo`1E
ooooo`co00001Oooool5o`0001?ooooo0_l00002ooooo`;o000000?oooooo`000?l000001?ooool2
o`00017ooooo0_l0000Hooooo`;o00003_ooool2o`0000oooooo0ol00002ooooo`go0000G_ooool0
01cooooo00?o0000ooooooooool0EOooool<o`0000Gooooo1Ol0000Cooooo`;o00000_ooool2o`00
00Gooooo1?l0000Aooooo`;o00005_ooool4o`0002?ooooo3_l0001Nooooo`007?ooool00ol0003o
ooooooooo`1Eooooo`co00001oooool2o`0000gooooo0_l0000@ooooo`;o00008_ooool2o`0000Oo
oooo0_l00002ooooo`?o00008?ooool>o`0005kooooo000Looooo`03o`000?oooooooooo05Gooooo
3?l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000002_ooool2o`0000Cooooo
0_l0000Rooooo`;o00002_ooool2o`0000_ooooo0ol0000<ooooo`;o00002_ooool4o`0000Gooooo
3?l0001Oooooo`007?ooool00ol0003oooooooooo`1Eooooo`co000000?oooooo`000?l000001?oo
ool2o`000003ooooool0003o000000Cooooo0_l0000:ooooo`;o00000oooool2o`0001gooooo0_l0
000<ooooo`;o00002_ooool2o`0000cooooo0_l00003ooooo`;o00001Oooool4o`0000Gooooo2ol0
001Pooooo`007?ooool00ol0003oooooooooo`1Eooooo`co00001_ooool4o`0000Kooooo0_l0000;
ooooo`;o00000_ooool2o`0000Wooooo0_l0000Pooooo`;o00001oooool2o`000003ooooool0003o
000000?ooooo0_l0000:ooooo`Co00001_ooool2o`0000Cooooo3Ol0001Pooooo`007?ooool00ol0
003oooooooooo`1Fooooo`_o00001_ooool5o`0000Gooooo0_l0000;ooooo`;o00003Oooool2o`00
02Wooooo1?l00004ooooo`;o00001?ooool2o`0000Cooooo1?l00003ooooo`;o000000?oooooo`00
0?l000001?ooool=o`00063ooooo000Looooo`03o`000?oooooooooo05Kooooo3?l00006ooooo`Co
00009oooool2o`0000kooooo0_l0000Dooooo`Go00000_ooool2o`0000?ooooo0ol00008ooooo`;o
000000?oooooo`000?l000000ol00003ooooo`;o000000?oooooo`000?l000001ol0001Rooooo`00
7?ooool00ol0003oooooooooo`1Gooooo`_o00002_ooool4o`000004ooooool0003o0000o`00017o
oooo0_l0000<ooooo`;o00002oooool2o`000003ooooool0003o000001?ooooo0_l00002ooooo`;o
00000_ooool2o`0000;ooooo1?l00008ooooo`;o00000_ooool2o`000005ooooool0003o0000o`00
0?ooool03?l0001Rooooo`007?ooool00ol0003oooooooooo`1Gooooo`?o000000?oooooo`000?l0
00001Ol00005ooooo`?o00000_ooool4o`000004ooooool0003o0000o`0000Wooooo0_l00003oooo
o`;o000000?oooooo`000?l000006Oooool2o`0000kooooo0_l00006ooooo`;o00000oooool2o`00
00Gooooo0_l00006ooooo`;o00001?ooool4o`000004ooooool0003o0000o`0000?ooooo2_l0001R
ooooo`007?ooool00ol0003oooooooooo`1Gooooo`go00000_ooool4o`0000Oooooo0_l000001?oo
oooo0000o`000?ooool2o`0000;ooooo1?l00003ooooo`;o00006oooool2o`0000?ooooo0_l0000:
ooooo`;o00000_ooool2o`0000Gooooo1Ol000001?oooooo0000o`000?ooool2o`0000Kooooo0_l0
0002ooooo`Wo00001?ooool:o`0006;ooooo000Looooo`;o0000FOooool<o`0000;ooooo0_l00009
ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00002Oooool2o`0001Oooooo0_l0
0003ooooo`;o00002_ooool3o`000003ooooool0003o000000Gooooo0_l000001?oooooo0000o`00
0?ooool2o`000003ooooool0003o000000[ooooo0_l000000ooooooo0000o`000003o`0000Gooooo
2?l0001Tooooo`007?ooool00ol0003oooooooooo`1Iooooo`[o00000oooool3o`0001gooooo0_l0
000Yooooo`;o00007oooool3o`000003ooooool0003o000000Gooooo2?l0001Tooooo`007?ooool0
0ol0003oooooooooo`1Ioooooa;o00000oooool2o`0001Cooooo0_l00009ooooo`;o0000:?ooool2
o`0000_ooooo0_l0000:ooooo`;o00002Oooool8o`0006Cooooo000Looooo`03o`000?oooooooooo
05Wooooo3ol000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000000_ooool2o`00
00[ooooo0_l000000ooooooo0000o`000009ooooo`Co00005oooool2o`0000_ooooo1?l0000;oooo
o`;o000000Coooooo`000?l0003ooooo0_l0000:ooooo`;o00000oooool8o`0006Cooooo000Loooo
o`03o`000?oooooooooo05_ooooo1?l000000ooooooo0000o`000005o`0000?ooooo0_l00005oooo
o`;o00000_ooool2o`0000[ooooo0_l00005ooooo`;o00001oooool2o`000003ooooool0003o0000
00Gooooo0_l0000=ooooo`;o00002oooool2o`0000Kooooo0_l00006ooooo`Co000000?oooooo`00
0?l000001_ooool2o`0000;ooooo0_l00003ooooo`So0000I?ooool001cooooo00?o0000oooooooo
ool0F_ooool;o`0000Gooooo0ol0000Aooooo`;o00000_ooool2o`0000Cooooo0ol000000ooooooo
0000o`000006ooooo`;o00001Oooool2o`0002;ooooo0ol00005ooooo`;o00001?ooool2o`0000Go
oooo1?l00002ooooo`;o000000?oooooo`000?l000001_l0001Tooooo`007?ooool00ol0003ooooo
ooooo`1Jooooo`_o00001_ooool2o`0000Kooooo0_l00007ooooo`Co00000_ooool2o`0000Gooooo
0_l000000ooooooo0000o`00000`ooooo`Co00002oooool2o`0000Oooooo0ol000001?oooooo0000
o`000?ooool8o`0006Cooooo000Looooo`03o`000?oooooooooo05[ooooo3?l00003ooooo`;o0000
2?ooool2o`0000Oooooo0_l00004ooooo`;o00002Oooool2o`0000oooooo0_l00004ooooo`;o0000
3Oooool4o`0000Oooooo0_l00004ooooo`;o00002_ooool3o`000004ooooool0003o0000ooooo`Co
00000_ooool8o`0006Cooooo000Looooo`03o`000?oooooooooo05_ooooo2ol00003ooooo`;o0000
2oooool2o`000003ooooool0003o000000Oooooo0_l00007ooooo`Co00003?ooool5o`0000Cooooo
0_l000000ooooooo0000o`00000:ooooo`Co00003Oooool2o`0000Cooooo0_l000001?oooooo0000
o`000?ooool3o`000003ooooool0003o000000;ooooo0ol000000ooooooo0000o`000006o`0006Go
oooo000Looooo`03o`000?oooooooooo05cooooo2_l00007ooooo`;o00001oooool2o`000003oooo
ool0003o0000013ooooo0_l00005ooooo`;o00001oooool4o`0000Gooooo0_l000000ooooooo0000
o`000003ooooo`;o00007?ooool5o`000005ooooool0003o0000o`000?ooool00_l00002ooooo`co
0000IOooool001cooooo00?o0000ooooooooool0Foooool<o`000003ooooool0003o000000?ooooo
0_l00004ooooo`;o000000?oooooo`000?l000006_ooool2o`0000Oooooo0_l00007ooooo`;o0000
1_ooool2o`0001gooooo0_l00004ooooo`;o000000?oooooo`000?l000001?ooool:o`0006Gooooo
000Looooo`03o`000?oooooooooo05_ooooo3?l000000ooooooo0000o`000002o`0000Oooooo0_l0
00001?oooooo0000o`000?l00002ooooo`Co00001_ooool2o`0001Cooooo0_l000000ooooooo0000
o`000009ooooo`;o00006_ooool3o`0000Kooooo0_l00002ooooo`Co00000_ooool2o`000003oooo
ool0003o000000Oo0000IOooool001cooooo00?o0000ooooooooool0Foooool<o`000003ooooool0
003o000000;o00001_ooool7o`0000;ooooo1?l00006ooooo`;o00005oooool2o`0000Wooooo0_l0
000<ooooo`Co00002_ooool3o`0000Kooooo0_l00002ooooo`Co00000_ooool<o`0006Gooooo000L
ooooo`03o`000?oooooooooo05cooooo3_l00004ooooo`;o000000?oooooo`000?l000001?l00004
ooooo`;o00000_ooool2o`0000Oooooo0_l00002ooooo`;o00006?ooool2o`0000Gooooo1?l00006
ooooo`Co00000_ooool2o`0001Gooooo0_l00003ooooo`[o0000I_ooool00006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`00
0?oooooooooo05cooooo3Ol00005ooooo`;o000000?oooooo`000?l000000_ooool4o`0000;ooooo
0_l00002ooooo`;o00001oooool2o`0000;ooooo0_l0000Hooooo`;o00001Oooool4o`0000Kooooo
0_l00004ooooo`?o00001Oooool2o`0000cooooo0_l00004ooooo`[o0000I_ooool00006oooooomg
MgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06oooo
o`03o`000?oooooooooo05cooooo3?l0000=ooooo`Co00001?ooool2o`0000;ooooo0_l00004oooo
o`Co00008?ooool2o`0000?ooooo0_l00004ooooo`?o00001Oooool2o`0000Gooooo0_l00003oooo
o`;o00001_ooool3o`0000Cooooo2Ol0001Wooooo`0000?ooooooa0@4?ooool00_ooool00ol@413o
ooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`1Loooo
o`[o000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l000000ooooooo0000o`000007oooo
o`;o00000_ooool2o`0000Cooooo1?l0000:ooooo`;o00001_ooool3o`0000_ooooo0_l00003oooo
o`?o00000oooool2o`0000cooooo0_l00004ooooo`;o00001_ooool2o`0000Cooooo2_l0001Woooo
o`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9SooooooiRH
V?lQ8B401_ooool3o`0005gooooo3?l000000ooooooo0000o`000002o`0000?ooooo0_l000001?oo
oooo0000o`000?ooool6o`0001Sooooo0_l00005ooooo`Co00001_ooool2o`0000Wooooo0_l00007
ooooo`;o00002?ooool2o`0001;ooooo2Ol0001Xooooo`0000?oooooo`000?ooool00_ooool00ol0
003oooooooooo`09ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`1M
ooooo`co000000?oooooo`000?l000000_l00009ooooo`Ko00006?ooool2o`0000Cooooo0ol00008
ooooo`;o00004?ooool4o`0000Kooooo0_l0000Aooooo`_o0000JOooool00003ooooool@413ooooo
00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo
05kooooo3?l00009ooooo`;o000000?oooooo`000?l000000ol0000;ooooo`;o000000?oooooo`00
0?l000001Oooool2o`0000;ooooo0ol00004ooooo`;o000000?oooooo`000?l000006?ooool2o`00
00Sooooo0_l00004ooooo`;o00002oooool9o`0006_ooooo00001_ooooooMgMgoiRHV?ooooooV9RH
ogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`1Oooooo`_o00000oooool2
o`0000Cooooo0_l000000ooooooo0000o`000003o`0000;ooooo0_l00007ooooo`;o000000?ooooo
o`000?l000001Oooool2o`000004ooooool0003o0000o`0000Cooooo0_l00002ooooo`;o00005Ooo
ool2o`000004ooooool0003o0000o`0000Oooooo0_l00004ooooo`Co00002Oooool:o`0006[ooooo
00001_ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0
003oooooooooo`1Oooooo`co00000_ooool2o`0000cooooo1?l0000Dooooo`;o00001Oooool2o`00
00Gooooo0_l000000ooooooo0000o`000002ooooo`;o00001Oooool4o`0000;ooooo0_l000001?oo
oooo0000o`000?l00007ooooo`?o00000oooool4o`0000Oooooo3?l0001Zooooo`007?ooool00ol0
003oooooooooo`1Pooooo`go00003_ooool2o`0000_ooooo0_l000000ooooooo0000o`00000Doooo
o`;o000000?oooooo`000?l000000_ooool2o`0000Gooooo1?l00003ooooo`?o00002Oooool3o`00
0003ooooool0003o000000?o00002?ooool:o`0006cooooo000Looooo`03o`000?oooooooooo063o
oooo3ol0000:ooooo`;o00001_ooool2o`0000Gooooo0_l000000ooooooo0000o`00000Qooooo`;o
00001_ooool3o`0000Wooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00001oooool:o`00
06gooooo000Looooo`03o`000?oooooooooo067ooooo2ol000001?oooooo0000o`000?l00009oooo
o`?o00001Oooool2o`0000oooooo0_l0000Aooooo`;o00001oooool2o`0000Oooooo0_l0000<oooo
o`;o00002Oooool;o`0006kooooo000Looooo`03o`000?oooooooooo06;ooooo2_l000000ooooooo
0000o`000005o`000003ooooool0003o000000?ooooo0_l00003ooooo`;o00002Oooool2o`0000Ko
oooo0_l00007ooooo`;o00001oooool3o`00013ooooo0_l0000Gooooo`_o0000K_ooool001cooooo
00?o0000ooooooooool0I?ooool9o`000003ooooool0003o000000Co000000Coooooo`000?l0003o
00001oooool2o`0000Wooooo0_l000000ooooooo0000o`000008ooooo`;o00000_ooool2o`0000Oo
oooo1?l0000;ooooo`;o00000_ooool2o`0000?ooooo0_l00006ooooo`;o00002_ooool:o`0006oo
oooo000Looooo`03o`000?oooooooooo06Cooooo2_l00008ooooo`;o00003?ooool2o`0000Oooooo
0_l00008ooooo`;o00002_ooool2o`000004ooooool0003o0000ooooo`;o00002?ooool2o`0000Go
oooo1?l00005ooooo`?o00001?ooool2o`0000Cooooo2_l0001_ooooo`007?ooool00ol0003ooooo
ooooo`1Vooooo`_o00004oooool2o`0000Oooooo1?l00004ooooo`?o00000oooool2o`0000Gooooo
1?l00003ooooo`;o00001_ooool4o`0000Gooooo1?l00005ooooo`;o00001Oooool5o`000003oooo
ool0003o000000Oo0000L?ooool001cooooo00?o0000ooooooooool0J?ooool;o`0000Wooooo1?l0
000?ooooo`;o00001?ooool3o`0000?ooooo0_l00005ooooo`Co000000?oooooo`000?l000002?oo
ool2o`0000Cooooo0_l00003ooooo`;o00003?ooool?o`00073ooooo000Looooo`03o`000?oooooo
oooo06Sooooo3Ol00002ooooo`;o00000oooool4o`0000Sooooo0_l0000?ooooo`;o00003?ooool2
o`0000kooooo0ol0000@ooooo`?o000000?oooooo`000?l000002?l0001aooooo`007?ooool00ol0
003oooooooooo`1[ooooo`_o000000?oooooo`000?l000000_ooool2o`0000Kooooo0_l00003oooo
o`;o00003?ooool2o`000004ooooool0003o0000ooooo`;o00001_ooool2o`0000_ooooo0_l00002
ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0000?ooooo0_l00007ooooo`;o000000?o
ooooo`000?l000001ol0001booooo`007?ooool00ol0003oooooooooo`1/ooooo`co00000oooool3
o`0000Gooooo0_l0000?ooooo`Co00001?ooool4o`0000;ooooo1?l0000:ooooo`?o00000_ooool2
o`0000;ooooo0_l000000ooooooo0000o`000006o`0000?ooooo0_l00004ooooo`Wo0000Loooool0
01cooooo0_l0001^ooooo`ko000000?oooooo`000?l000004?ooool2o`0000Cooooo1?l00003oooo
o`Go00000_ooool3o`0000_ooooo0_l0000:ooooo`;o000000?oooooo`000?l000000_l00002oooo
o`Co00000oooool9o`0007Cooooo000Looooo`03o`000?oooooooooo06oooooo3?l0000Cooooo`;o
00002oooool2o`0001Gooooo0_l00008ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`_o
0000MOooool001cooooo00?o0000ooooooooool0LOooool=o`0000cooooo0_l00003ooooo`;o0000
00?oooooo`000?l000001oooool2o`0000[ooooo0_l00009ooooo`;o00001_ooool2o`0000Oooooo
0_l00004ooooo`_o0000MOooool001cooooo00?o0000ooooooooool0L_ooool<o`0000cooooo0_l0
0003ooooo`;o000000?oooooo`000?l000003oooool2o`0000;ooooo0_l00002ooooo`;o00000_oo
ool2o`0000Oooooo1?l00007ooooo`;o00001Oooool8o`0007Oooooo000Looooo`03o`000?oooooo
oooo07?ooooo3?l00008ooooo`;o000000?oooooo`000?l000001_ooool6o`0000Wooooo1?l00002
ooooo`;o00000_ooool2o`0000;ooooo1?l00004ooooo`?o00003Oooool:o`0007Sooooo000Loooo
o`03o`000?oooooooooo07Cooooo3_l00005ooooo`;o000000?oooooo`000?l000001oooool7o`00
00Oooooo0_l00009ooooo`;o00000_ooool3o`0000Cooooo0ol00008ooooo`;o00000oooool:o`00
07Sooooo000Looooo`03o`000?oooooooooo07Kooooo3Ol00004ooooo`;o00003?ooool5o`0000So
oooo0_l00002ooooo`;o00001?ooool2o`0000;ooooo0_l0000@ooooo`go0000N_ooool001cooooo
00?o0000ooooooooool0M_ooool>o`0000?ooooo0ol00003ooooo`;o00001_ooool4o`0000?ooooo
0_l00004ooooo`;o00000_ooool2o`0000_ooooo0_l0000=ooooo`go0000N_ooool001cooooo00?o
0000ooooooooool0N?oooolBo`0000?ooooo0_l0000=ooooo`;o00005Oooool3o`0000Cooooo0_l0
00000ooooooo0000o`000002ooooo`ko0000N_ooool001cooooo00?o0000ooooooooool0N?oooolA
o`0000Cooooo1?l0000>ooooo`;o00000_ooool2o`0000Gooooo0_l00008ooooo`;o00000oooool3
o`000003ooooool0003o000000ko0000O?ooool001cooooo00?o0000ooooooooool0N_oooolAo`00
00Cooooo0_l0000>ooooo`;o00000_ooool2o`0000Gooooo1?l0000;ooooo`?o00000_ooool?o`00
07cooooo000Looooo`03o`000?oooooooooo07cooooo3ol00002ooooo`Co00000_ooool4o`0000Wo
oooo0_l00006ooooo`;o00000_ooool2o`0000Kooooo0_l00004oooooa7o0000O_ooool001cooooo
00?o0000ooooooooool0OOooool?o`000003ooooool0003o000000Cooooo1?l00009ooooo`;o0000
00?oooooo`000?l000000oooool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l00000
1Oooool?o`0007oooooo000Looooo`03o`000?oooooooooo07kooooo4ol00006ooooo`;o00002_oo
ool2o`0000Gooooo0_l00005ooooo`Go00000ooooolAo`0007oooooo000Looooo`03o`000?oooooo
oooo083ooooo4ol00004ooooo`;o00001oooool2o`0000Sooooo0_l00006ooooo`?o00001?oooolA
o`0007oooooo000Looooo`03o`000?oooooooooo083ooooo5ol00009ooooo`;o00001Oooool6o`00
00Wooooo4_l00021ooooo`007?ooool2o`0008?ooooo5_l000000ooooooo0000o`000002ooooo`Go
00001Oooool6o`0000Gooooo0_l000000ooooooo0000o`00000?o`0008?ooooo000Looooo`03o`00
0?oooooooooo08Kooooo7Ol000000ooooooo0000o`000002ooooo`Co00001Oooool>o`000004oooo
ool0003o0000o`0008Kooooo000Looooo`03o`000?oooooooooo08Oooooo8ol00004oooooaGo0000
Q_ooool001cooooo00?o0000ooooooooool0R?oooolko`0008Kooooo000Looooo`03o`000?oooooo
oooo08cooooo=Ol00028ooooo`007?ooool00ol0003oooooooooo`2@oooooboo0000R_ooool001co
oooo00?o0000ooooooooool0T_oooolZo`0008gooooo000Looooo`03o`000?oooooooooo09Cooooo
:?l0002=ooooo`007?ooool00ol0003oooooooooo`2EooooobKo0000S_ooool001cooooo00?o0000
ooooooooool0UooooolDo`000003ooooool0003o000000[o0000TOooool001cooooo00?o0000oooo
ooooool0UooooolMo`000003ooooool0003o000009;ooooo000Looooo`03o`000?oooooooooo09Wo
oooo6ol0002Eooooo`007?ooool00ol0003oooooooooo`2Oooooo`Go000000?oooooo`000?l00000
0_l000000ooooooo0000o`000002o`0009_ooooo000Looooo`03o`000?oooooooooo0:3ooooo1?l0
002Uooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Ooo
ool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oooooo
B_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?oo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooB_ooool00003ooooool@413ooooo00;o
oooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool0oooooom:ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05
oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`000?ooooooB_ooool00003ooooool0003ooooo00;o
oooo00?o0000ooooooooool02Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000oooo
ooooool0oooooom:ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05
oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`3ooooood[ooooo00001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oo
oooooooo0?ooooooB_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@
o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`004_ooool4o`000003oa0@4?oooooo
oooo00?ooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool3o`000?oo
ooooB_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003ooooooooo
o`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000oooo
ooooool0oooooomBooooo`004_ooool00omEEEGoIVIVo`00003ooooooeCooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo002Yooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@
ooooooooool05_ooool4o`000008oa0@4?ooooooooooolc<c?lQ8B7o0000ob4Q8Oo<c<bDooooo`00
Z_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l0000<ooooo`03o`000?oooooooooo00;o
oooo00Go8B4QoiRHV?ooooooV9RHob4Q8@2Dooooo`00Z_ooool01Ol0003ooooooooooooooooo0000
01_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000009Cooooo002Zoooo
o`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo00?o0000ooooooooool00_ooool0
1Olb<S;oV9RHoooooonHV9So<S8b09Cooooo002Zooooo`05o`000?n7QhOoooooojVYZOl000006ooo
ool00ol0003oooooooooo`02ooooo`05olc<c?l0003o0000o`000?o<c<`0U?ooool00:Wooooo00?o
410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Iooooo`03o`000?oooooooooo00;ooooo00Go
410@okZj^_oooooo^[Zjoa0@402Dooooo`00b_ooool00ol0003oooooooooo`02ooooo`05o`000?nj
^[[ooooookZj^_l00000U?ooool00<Sooooo00?oEEEEofIVI_l000001?ooool01OnYZJWo410@o`00
0?l@413oZJVY09Cooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -20 0 ]
[.5 1.0125 20 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(24) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.69005 .44552 Mdot
.69817 .39955 Mdot
.44364 .30101 Mdot
.36476 .63797 Mdot
.31413 .60687 Mdot
.46597 .29775 Mdot
.64673 .35825 Mdot
.64313 .3361 Mdot
.40194 .2955 Mdot
.34494 .62508 Mdot
.56626 .28923 Mdot
.59289 .70839 Mdot
.64186 .35053 Mdot
.40691 .68076 Mdot
.53757 .71881 Mdot
.6884 .61096 Mdot
.70768 .44726 Mdot
.31514 .60677 Mdot
.64327 .64305 Mdot
.4148 .28533 Mdot
.33533 .38635 Mdot
.38549 .65828 Mdot
.71404 .44077 Mdot
.40615 .68417 Mdot
.64449 .64519 Mdot
.68885 .55879 Mdot
.68887 .44538 Mdot
.65251 .64125 Mdot
.61187 .68922 Mdot
.63105 .31762 Mdot
.67287 .62058 Mdot
.43204 .70309 Mdot
.32493 .4262 Mdot
.72444 .52096 Mdot
.53435 .28212 Mdot
.58731 .30294 Mdot
.42441 .30689 Mdot
.5881 .30929 Mdot
.6524 .33853 Mdot
.53475 .28682 Mdot
.5359 .28486 Mdot
.68839 .56485 Mdot
.58387 .29715 Mdot
.67417 .38162 Mdot
.43419 .69699 Mdot
.71134 .56578 Mdot
.34236 .3738 Mdot
.48305 .70837 Mdot
.69209 .44226 Mdot
.34095 .37271 Mdot
.49726 .72895 Mdot
.65592 .37195 Mdot
.30169 .45611 Mdot
.71967 .4716 Mdot
.63181 .33694 Mdot
.64398 .64763 Mdot
.43701 .28494 Mdot
.51894 .73234 Mdot
.6089 .6851 Mdot
.72326 .52843 Mdot
.3954 .68112 Mdot
.31161 .54905 Mdot
.62247 .67073 Mdot
.45941 .27302 Mdot
.41256 .30226 Mdot
.55279 .30832 Mdot
.72014 .44445 Mdot
.57692 .30706 Mdot
.41541 .6857 Mdot
.38309 .33606 Mdot
.52284 .72705 Mdot
.56532 .2887 Mdot
.70506 .54672 Mdot
.37305 .64319 Mdot
.68574 .41865 Mdot
.5679 .29888 Mdot
.31099 .6076 Mdot
.6944 .55907 Mdot
.33264 .37297 Mdot
.34988 .63827 Mdot
.38817 .66536 Mdot
.5621 .27508 Mdot
.59466 .68655 Mdot
.6864 .58226 Mdot
.45195 .7105 Mdot
.59897 .30582 Mdot
.35227 .62752 Mdot
.67554 .61706 Mdot
.65644 .64132 Mdot
.59974 .7056 Mdot
.37962 .323 Mdot
.71518 .41874 Mdot
.38056 .64821 Mdot
.43751 .71517 Mdot
.48876 .72178 Mdot
.45729 .71341 Mdot
.65864 .64102 Mdot
.32746 .40412 Mdot
.54772 .29237 Mdot
.31252 .44921 Mdot
.57456 .30385 Mdot
.29477 .47039 Mdot
.42937 .70347 Mdot
.47046 .28444 Mdot
.71755 .49223 Mdot
.32517 .40865 Mdot
.56012 .2974 Mdot
.38175 .64742 Mdot
.58951 .30726 Mdot
.71166 .4145 Mdot
.67279 .62414 Mdot
.29029 .56627 Mdot
.2927 .59179 Mdot
.69401 .46291 Mdot
.46582 .73279 Mdot
.34909 .6275 Mdot
.39495 .6695 Mdot
.72038 .43934 Mdot
.40648 .29462 Mdot
.3672 .3323 Mdot
.69863 .40951 Mdot
.54241 .28967 Mdot
.70387 .45121 Mdot
.28302 .50701 Mdot
.40452 .30076 Mdot
.31693 .42947 Mdot
.30691 .42039 Mdot
.42303 .69393 Mdot
.46149 .71565 Mdot
.27397 .48287 Mdot
.47696 .28437 Mdot
.69741 .40886 Mdot
.64102 .34481 Mdot
.43925 .7183 Mdot
.70286 .57078 Mdot
.62981 .33513 Mdot
.3041 .57932 Mdot
.28578 .57164 Mdot
.70824 .54977 Mdot
.46967 .73164 Mdot
.59063 .3149 Mdot
.6641 .36563 Mdot
.51143 .73301 Mdot
.70889 .56447 Mdot
.31239 .59428 Mdot
.66465 .36591 Mdot
.29714 .49182 Mdot
.67253 .62884 Mdot
.55555 .72846 Mdot
.58116 .28714 Mdot
.4998 .72785 Mdot
.34656 .37577 Mdot
.30214 .52763 Mdot
.62917 .33015 Mdot
.35961 .6354 Mdot
.7005 .43931 Mdot
.71243 .55229 Mdot
.57125 .70901 Mdot
.32636 .41212 Mdot
.51702 .73887 Mdot
.28867 .47988 Mdot
.31554 .41146 Mdot
.40414 .67434 Mdot
.72205 .54327 Mdot
.72383 .49486 Mdot
.52208 .72827 Mdot
.40605 .30821 Mdot
.31411 .61097 Mdot
.56685 .2866 Mdot
.46203 .71057 Mdot
.48202 .71654 Mdot
.57182 .71283 Mdot
.66392 .37142 Mdot
.5244 .27823 Mdot
.35663 .35204 Mdot
.56106 .30955 Mdot
.55073 .2779 Mdot
.47354 .27699 Mdot
.59664 .70145 Mdot
.2847 .55074 Mdot
.28814 .45774 Mdot
.51987 .72825 Mdot
.42273 .68983 Mdot
.59175 .71052 Mdot
.30541 .4124 Mdot
.29689 .42059 Mdot
.71071 .48857 Mdot
.57865 .29027 Mdot
.36979 .65515 Mdot
.6286 .6574 Mdot
.48055 .72509 Mdot
.60056 .31474 Mdot
.64396 .34349 Mdot
.48979 .27459 Mdot
.42273 .28011 Mdot
.35966 .35536 Mdot
.56815 .69627 Mdot
.54681 .71326 Mdot
.37689 .65882 Mdot
.30973 .44171 Mdot
.6412 .66294 Mdot
.30403 .53149 Mdot
.70551 .44271 Mdot
.55594 .27338 Mdot
.54704 .7327 Mdot
.65886 .62319 Mdot
.38199 .31302 Mdot
.35307 .34155 Mdot
.28404 .45624 Mdot
.29433 .53417 Mdot
.51063 .72694 Mdot
.70007 .4677 Mdot
.50203 .72987 Mdot
.3232 .43063 Mdot
.28826 .58731 Mdot
.70432 .41498 Mdot
.48862 .71064 Mdot
.63747 .3481 Mdot
.5008 .29892 Mdot
.35189 .62647 Mdot
.37975 .64442 Mdot
.69593 .56054 Mdot
.44096 .71638 Mdot
.63478 .65317 Mdot
.66555 .62781 Mdot
.36624 .34828 Mdot
.56289 .30499 Mdot
.63645 .31949 Mdot
.33882 .37698 Mdot
.70339 .56116 Mdot
.67811 .3849 Mdot
.45543 .28865 Mdot
.33812 .38505 Mdot
.57589 .29441 Mdot
.30322 .55937 Mdot
.46495 .28751 Mdot
.31558 .59721 Mdot
.61331 .68264 Mdot
.49303 .28709 Mdot
.29775 .5727 Mdot
.54368 .71884 Mdot
.29989 .43171 Mdot
.27937 .55557 Mdot
.64532 .35888 Mdot
.6976 .39196 Mdot
.52595 .73136 Mdot
.29542 .46055 Mdot
.32049 .43966 Mdot
.59557 .7003 Mdot
.30608 .41781 Mdot
.31342 .42028 Mdot
.59042 .70469 Mdot
.31824 .60685 Mdot
.53969 .27468 Mdot
.6727 .62122 Mdot
.70595 .44817 Mdot
.41742 .6881 Mdot
.53736 .2969 Mdot
.62888 .33291 Mdot
.35685 .64549 Mdot
.59812 .30688 Mdot
.64381 .35907 Mdot
.40109 .67315 Mdot
.63974 .32669 Mdot
.69247 .57861 Mdot
.54672 .73337 Mdot
.7073 .54067 Mdot
.40571 .6798 Mdot
.64479 .33065 Mdot
.33959 .37551 Mdot
.69121 .5675 Mdot
.37917 .65076 Mdot
.36616 .64385 Mdot
.30676 .44568 Mdot
.66961 .62611 Mdot
.61195 .31505 Mdot
.59386 .70742 Mdot
.50959 .28716 Mdot
.56673 .70255 Mdot
.30282 .51699 Mdot
.28865 .50753 Mdot
.71083 .5613 Mdot
.31246 .41049 Mdot
.46224 .29301 Mdot
.49426 .72166 Mdot
.51006 .71961 Mdot
.44215 .70416 Mdot
.30887 .42619 Mdot
.59304 .68686 Mdot
.6224 .33271 Mdot
.65627 .64703 Mdot
.27501 .48103 Mdot
.43515 .28974 Mdot
.30051 .46531 Mdot
.454 .71207 Mdot
.71507 .43348 Mdot
.67896 .61058 Mdot
.50592 .28707 Mdot
.71264 .43258 Mdot
.49063 .71349 Mdot
.57535 .30722 Mdot
.31266 .54144 Mdot
.61422 .31315 Mdot
.65399 .63225 Mdot
.56737 .70436 Mdot
.38174 .33609 Mdot
.69438 .57115 Mdot
.63281 .33011 Mdot
.70584 .54425 Mdot
.51094 .73714 Mdot
.50278 .739 Mdot
.71415 .55511 Mdot
.29402 .51073 Mdot
.34766 .35603 Mdot
.57018 .29253 Mdot
.31237 .43334 Mdot
.38502 .32831 Mdot
.69464 .44815 Mdot
.4731 .28772 Mdot
.48196 .73752 Mdot
.50393 .29864 Mdot
.67779 .61088 Mdot
.38595 .33042 Mdot
.56477 .71315 Mdot
.43138 .69706 Mdot
.47298 .27254 Mdot
.32904 .40723 Mdot
.51362 .73037 Mdot
.69711 .57486 Mdot
.41486 .68034 Mdot
.34465 .62335 Mdot
.56185 .70139 Mdot
.43638 .28864 Mdot
.47377 .73291 Mdot
.65957 .63093 Mdot
.64985 .63817 Mdot
.70468 .436 Mdot
.30096 .44449 Mdot
.30297 .58572 Mdot
.28126 .56403 Mdot
.29485 .49821 Mdot
.58879 .7131 Mdot
.48865 .73602 Mdot
.70658 .56078 Mdot
.34724 .36704 Mdot
.69643 .38929 Mdot
.32369 .4286 Mdot
.64446 .33695 Mdot
.52859 .27764 Mdot
.35269 .62636 Mdot
.32565 .61339 Mdot
.6814 .60713 Mdot
.68992 .43273 Mdot
.70261 .55045 Mdot
.63452 .33065 Mdot
.63195 .67065 Mdot
.35109 .63983 Mdot
.35816 .64711 Mdot
.65486 .34659 Mdot
.32137 .43061 Mdot
.60065 .6885 Mdot
.51418 .71735 Mdot
.67233 .37934 Mdot
.44541 .70181 Mdot
.71794 .51703 Mdot
.425 .68477 Mdot
.43332 .70613 Mdot
.43803 .69155 Mdot
.70052 .57017 Mdot
.68143 .60422 Mdot
.51343 .71827 Mdot
.37269 .32157 Mdot
.549 .73292 Mdot
.28504 .53274 Mdot
.37583 .64563 Mdot
.51177 .72645 Mdot
.31093 .58833 Mdot
.69491 .4627 Mdot
.47499 .71244 Mdot
.58217 .28991 Mdot
.38212 .65244 Mdot
.56931 .28751 Mdot
.58327 .69886 Mdot
.44489 .71421 Mdot
.65856 .63376 Mdot
.71457 .44061 Mdot
.65682 .34512 Mdot
.55023 .28231 Mdot
.27802 .47615 Mdot
.6286 .33207 Mdot
.45483 .70942 Mdot
.58302 .6972 Mdot
.69458 .46386 Mdot
.30205 .42908 Mdot
.71541 .41684 Mdot
.33043 .62124 Mdot
.65178 .36041 Mdot
.29756 .46482 Mdot
.62375 .67248 Mdot
.65685 .35986 Mdot
.56876 .28105 Mdot
.67362 .62356 Mdot
.32114 .43153 Mdot
.69295 .45103 Mdot
.38382 .33305 Mdot
.32032 .41918 Mdot
.63091 .3338 Mdot
.43285 .69526 Mdot
.66471 .63725 Mdot
.63342 .32665 Mdot
.71002 .51968 Mdot
.67607 .62663 Mdot
.3836 .65217 Mdot
.68656 .56199 Mdot
.71765 .41613 Mdot
.52852 .73873 Mdot
.37145 .66124 Mdot
.44532 .29649 Mdot
.31046 .42626 Mdot
.30768 .43028 Mdot
.32335 .40402 Mdot
.51408 .29515 Mdot
.3546 .34873 Mdot
.5546 .30199 Mdot
.41718 .68528 Mdot
.55162 .3052 Mdot
.29488 .46364 Mdot
.44652 .29722 Mdot
.42833 .69106 Mdot
.63969 .66883 Mdot
.66678 .36714 Mdot
.38691 .322 Mdot
.36484 .63247 Mdot
.70019 .44398 Mdot
.6595 .37156 Mdot
.54459 .71524 Mdot
.37024 .34765 Mdot
.31178 .54657 Mdot
.46896 .72897 Mdot
.6599 .3611 Mdot
.71213 .50986 Mdot
.65954 .35935 Mdot
.50407 .72222 Mdot
.46218 .70583 Mdot
.69104 .40568 Mdot
.2868 .5277 Mdot
.59442 .70618 Mdot
.40412 .68372 Mdot
.3365 .37484 Mdot
.69342 .39108 Mdot
.2864 .52421 Mdot
.6179 .68394 Mdot
.296 .4348 Mdot
.31855 .61333 Mdot
.3769 .65715 Mdot
.58182 .70957 Mdot
.28249 .49503 Mdot
.62666 .3193 Mdot
.28182 .5442 Mdot
.38107 .3153 Mdot
.7092 .4223 Mdot
.55675 .30353 Mdot
.32947 .39555 Mdot
.5648 .28982 Mdot
.57324 .71829 Mdot
.28796 .47206 Mdot
.67029 .38172 Mdot
.33739 .61574 Mdot
.30883 .42288 Mdot
.43193 .28738 Mdot
.51543 .73612 Mdot
.5894 .70738 Mdot
.38392 .65188 Mdot
.30192 .58413 Mdot
.70415 .3989 Mdot
.56213 .28041 Mdot
.65505 .3389 Mdot
.40627 .67479 Mdot
.71122 .5609 Mdot
.70576 .49668 Mdot
.30869 .45209 Mdot
.29218 .55799 Mdot
.30137 .56048 Mdot
.4058 .67281 Mdot
.61463 .6785 Mdot
.70217 .56672 Mdot
.37887 .65017 Mdot
.40915 .6777 Mdot
.36731 .34042 Mdot
.68557 .55815 Mdot
.49051 .28451 Mdot
.64724 .63474 Mdot
.46272 .72465 Mdot
.57074 .30746 Mdot
.62985 .34011 Mdot
.30442 .43798 Mdot
.63672 .31955 Mdot
.35994 .3469 Mdot
.30754 .43017 Mdot
.37879 .65094 Mdot
.68702 .44744 Mdot
.37883 .64901 Mdot
.38125 .65119 Mdot
.43413 .69151 Mdot
.48749 .73529 Mdot
.36055 .33262 Mdot
.28792 .55209 Mdot
.61575 .68272 Mdot
.48647 .27834 Mdot
.38471 .31027 Mdot
.49018 .72356 Mdot
.37595 .65302 Mdot
.3962 .66841 Mdot
.69299 .54295 Mdot
.66415 .64038 Mdot
.65284 .35138 Mdot
.69108 .40474 Mdot
.35543 .63576 Mdot
.34864 .36912 Mdot
.47152 .7096 Mdot
.71565 .54697 Mdot
.52729 .2853 Mdot
.60864 .31643 Mdot
.30166 .42309 Mdot
.3145 .45054 Mdot
.31159 .42286 Mdot
.33118 .39833 Mdot
.58507 .29928 Mdot
.44625 .29782 Mdot
.30483 .51541 Mdot
.50178 .73955 Mdot
.37347 .66143 Mdot
.46734 .71041 Mdot
.37614 .33102 Mdot
.29882 .48295 Mdot
.49634 .73527 Mdot
.67975 .63334 Mdot
.49234 .3003 Mdot
.32436 .40585 Mdot
.68286 .59216 Mdot
.71158 .41997 Mdot
.3746 .34172 Mdot
.58753 .30877 Mdot
.29739 .57543 Mdot
.3404 .3784 Mdot
.71161 .40791 Mdot
.62146 .66951 Mdot
.48473 .3019 Mdot
.58634 .69515 Mdot
.64602 .66223 Mdot
.47806 .29167 Mdot
.65247 .64966 Mdot
.71921 .44778 Mdot
.30385 .42548 Mdot
.57551 .69944 Mdot
.59314 .70057 Mdot
.47928 .27108 Mdot
.36931 .64025 Mdot
.37489 .32584 Mdot
.43319 .28921 Mdot
.29566 .44824 Mdot
.43667 .28879 Mdot
.62089 .32903 Mdot
.462 .28043 Mdot
.70417 .52467 Mdot
.42069 .69501 Mdot
.71786 .47867 Mdot
.55413 .7216 Mdot
.35145 .63324 Mdot
.64925 .36626 Mdot
.54232 .29914 Mdot
.38835 .6748 Mdot
.31189 .60407 Mdot
.43074 .29196 Mdot
.35298 .3583 Mdot
.65523 .64539 Mdot
.38109 .33038 Mdot
.71486 .44095 Mdot
.56749 .30381 Mdot
.54264 .29941 Mdot
.31567 .42123 Mdot
.70443 .57019 Mdot
.59505 .31089 Mdot
.54187 .2902 Mdot
.31231 .53982 Mdot
.53061 .73664 Mdot
.72097 .50467 Mdot
.60005 .68891 Mdot
.31617 .60308 Mdot
.38375 .65464 Mdot
.48687 .28223 Mdot
.35927 .35346 Mdot
.52423 .71603 Mdot
.45363 .29008 Mdot
.30807 .43505 Mdot
.71282 .50331 Mdot
.64207 .64787 Mdot
.70203 .40208 Mdot
.44217 .7186 Mdot
.55795 .3046 Mdot
.71339 .42631 Mdot
.32315 .39659 Mdot
.38569 .67732 Mdot
.71978 .54774 Mdot
.62144 .68406 Mdot
.38438 .65352 Mdot
.40967 .29884 Mdot
.31141 .59034 Mdot
.34387 .38167 Mdot
.38145 .32032 Mdot
.30441 .5405 Mdot
.68686 .38861 Mdot
.40699 .29858 Mdot
.30069 .54754 Mdot
.28603 .51495 Mdot
.32406 .40131 Mdot
.28967 .54402 Mdot
.45385 .71082 Mdot
.62764 .32702 Mdot
.69691 .39625 Mdot
.45274 .69746 Mdot
.34368 .62504 Mdot
.72017 .47597 Mdot
.3088 .44598 Mdot
.38868 .65689 Mdot
.52523 .73636 Mdot
.71447 .54747 Mdot
.54847 .27263 Mdot
.44488 .2764 Mdot
.31647 .43687 Mdot
.70489 .40415 Mdot
.56223 .275 Mdot
.41263 .30027 Mdot
.30681 .56118 Mdot
.62115 .31962 Mdot
.68502 .44215 Mdot
.30306 .45252 Mdot
.64597 .35859 Mdot
.38494 .3195 Mdot
.49664 .72804 Mdot
.681 .62838 Mdot
.47185 .30405 Mdot
.49805 .7287 Mdot
.67376 .61211 Mdot
.36123 .35453 Mdot
.52951 .2763 Mdot
.71189 .41381 Mdot
.64917 .33783 Mdot
.29696 .56176 Mdot
.70392 .54549 Mdot
.71485 .41558 Mdot
.62926 .33935 Mdot
.72268 .47681 Mdot
.58732 .6889 Mdot
.56604 .29797 Mdot
.60508 .6837 Mdot
.50729 .72984 Mdot
.30079 .45342 Mdot
.28578 .55223 Mdot
.56507 .30493 Mdot
.68849 .56039 Mdot
.67367 .37438 Mdot
.46257 .71779 Mdot
.66807 .63749 Mdot
.29045 .57284 Mdot
.71459 .47887 Mdot
.52305 .27582 Mdot
.65316 .35351 Mdot
.33812 .37363 Mdot
.30967 .6021 Mdot
.4413 .70585 Mdot
.39659 .32044 Mdot
.45923 .70744 Mdot
.65967 .37577 Mdot
.67382 .61142 Mdot
.70574 .42257 Mdot
.56906 .29623 Mdot
.68423 .6072 Mdot
.60437 .69878 Mdot
.37985 .66811 Mdot
.36663 .34716 Mdot
.70789 .48839 Mdot
.28777 .50527 Mdot
.34834 .62288 Mdot
.38772 .67958 Mdot
.31895 .44524 Mdot
.4247 .69593 Mdot
.53867 .27588 Mdot
.32636 .41482 Mdot
.49368 .29814 Mdot
.30809 .42117 Mdot
.30888 .43705 Mdot
.70233 .46454 Mdot
.35763 .35864 Mdot
.31591 .4495 Mdot
.35478 .64333 Mdot
.39339 .65822 Mdot
.65898 .34771 Mdot
.58362 .69226 Mdot
.59664 .69538 Mdot
.50245 .28259 Mdot
.31332 .54103 Mdot
.48807 .71607 Mdot
.68939 .58072 Mdot
.28852 .57637 Mdot
.28887 .48307 Mdot
.71107 .43431 Mdot
.45381 .71292 Mdot
.36764 .33967 Mdot
.3014 .43166 Mdot
.29345 .48488 Mdot
.29426 .57353 Mdot
.66412 .37405 Mdot
.7159 .5333 Mdot
.43239 .28893 Mdot
.68317 .61851 Mdot
.328 .61761 Mdot
.37388 .33918 Mdot
.30031 .45286 Mdot
.28248 .47064 Mdot
.71085 .56037 Mdot
.70595 .5245 Mdot
.33089 .39343 Mdot
.4911 .27925 Mdot
.59329 .30534 Mdot
.56036 .29105 Mdot
.5712 .70777 Mdot
.61897 .31472 Mdot
.71246 .41526 Mdot
.46548 .72304 Mdot
.30175 .55766 Mdot
.65596 .36059 Mdot
.31607 .4194 Mdot
.70859 .40859 Mdot
.70276 .53429 Mdot
.40465 .68525 Mdot
.38428 .65849 Mdot
.34032 .37545 Mdot
.43136 .70121 Mdot
.6667 .37409 Mdot
.30569 .58407 Mdot
.43384 .2983 Mdot
.65914 .64235 Mdot
.70117 .44071 Mdot
.35201 .36963 Mdot
.6106 .69547 Mdot
.45783 .27559 Mdot
.69625 .40132 Mdot
.29578 .58508 Mdot
.28841 .55086 Mdot
.46184 .72288 Mdot
.35024 .37245 Mdot
.64984 .36367 Mdot
.7043 .56851 Mdot
.68887 .38881 Mdot
.60973 .68944 Mdot
.37753 .65354 Mdot
.6442 .65171 Mdot
.56809 .28417 Mdot
.45782 .71113 Mdot
.29681 .57862 Mdot
.71462 .46851 Mdot
.43073 .69548 Mdot
.29715 .59285 Mdot
.28705 .50644 Mdot
.28232 .46539 Mdot
.45183 .27201 Mdot
.30088 .59159 Mdot
.30455 .59611 Mdot
.28914 .58519 Mdot
.52989 .27765 Mdot
.55049 .71632 Mdot
.32838 .61398 Mdot
.36788 .64119 Mdot
.51314 .73484 Mdot
.67765 .63149 Mdot
.55912 .30842 Mdot
.38038 .33831 Mdot
.5065 .72445 Mdot
.36652 .6439 Mdot
.71637 .46487 Mdot
.68796 .61311 Mdot
.49535 .71679 Mdot
.70838 .43488 Mdot
.72492 .51085 Mdot
.43123 .27701 Mdot
.60423 .31802 Mdot
.39347 .32601 Mdot
.62345 .67974 Mdot
.62899 .67698 Mdot
.70951 .47381 Mdot
.62441 .32404 Mdot
.62467 .67778 Mdot
.66372 .37528 Mdot
.71588 .45912 Mdot
.67739 .63429 Mdot
.7086 .52028 Mdot
.31308 .55305 Mdot
.4971 .7186 Mdot
.63152 .34433 Mdot
.50813 .7249 Mdot
.62534 .33312 Mdot
.3435 .62406 Mdot
.62683 .67532 Mdot
.36031 .63842 Mdot
.4221 .68731 Mdot
.30701 .40991 Mdot
.38111 .65723 Mdot
.3333 .37319 Mdot
.69887 .4343 Mdot
.32372 .61423 Mdot
.62824 .66165 Mdot
.51285 .73145 Mdot
.39334 .66412 Mdot
.72078 .47587 Mdot
.39535 .67172 Mdot
.39133 .32446 Mdot
.62408 .68289 Mdot
.51005 .72381 Mdot
.64178 .34084 Mdot
.55307 .28634 Mdot
.69364 .46284 Mdot
.28623 .47298 Mdot
.7162 .47319 Mdot
.39964 .66958 Mdot
.42762 .28462 Mdot
.29601 .4982 Mdot
.30671 .59439 Mdot
.69516 .39976 Mdot
.33921 .61858 Mdot
.58276 .29614 Mdot
.39464 .30898 Mdot
.67536 .62047 Mdot
.49546 .28988 Mdot
.47166 .27355 Mdot
.69438 .38967 Mdot
.28625 .55304 Mdot
.4737 .70782 Mdot
.72346 .52512 Mdot
.73292 .52936 Mdot
.60801 .69139 Mdot
.41755 .28802 Mdot
.28274 .49617 Mdot
.67822 .60288 Mdot
.31408 .56826 Mdot
.30098 .54057 Mdot
.63496 .34585 Mdot
.43047 .28177 Mdot
.31518 .43532 Mdot
.30137 .55076 Mdot
.43075 .27651 Mdot
.32937 .39662 Mdot
.34154 .36824 Mdot
.70577 .56342 Mdot
.49007 .73862 Mdot
.72016 .55161 Mdot
.64528 .32714 Mdot
.35193 .36397 Mdot
.69952 .56357 Mdot
.68961 .58241 Mdot
.30841 .44053 Mdot
.40309 .31197 Mdot
.714 .49477 Mdot
.52838 .73412 Mdot
.28916 .44736 Mdot
.40712 .68755 Mdot
.30916 .60761 Mdot
.393 .65884 Mdot
.35748 .36162 Mdot
.65525 .35246 Mdot
.44205 .29427 Mdot
.63691 .34918 Mdot
.43062 .70271 Mdot
.37355 .66795 Mdot
.37529 .64849 Mdot
.5842 .699 Mdot
.70607 .46828 Mdot
.72139 .51799 Mdot
.44428 .27975 Mdot
.43839 .2928 Mdot
.63435 .66092 Mdot
.69984 .44838 Mdot
.29143 .50143 Mdot
.61574 .6801 Mdot
.39411 .67188 Mdot
.69987 .4346 Mdot
.67207 .63777 Mdot
.59909 .31629 Mdot
.57814 .70079 Mdot
.70971 .46035 Mdot
.35708 .34601 Mdot
.41257 .68297 Mdot
.3115 .45278 Mdot
.27452 .4857 Mdot
.56821 .71826 Mdot
.3155 .60638 Mdot
.70659 .41683 Mdot
.2985 .47084 Mdot
.69605 .43277 Mdot
.50803 .29686 Mdot
.59794 .3168 Mdot
.70561 .42967 Mdot
.39708 .67184 Mdot
.40306 .31843 Mdot
.62632 .32792 Mdot
.43102 .68766 Mdot
.56324 .29509 Mdot
.702 .55451 Mdot
.69623 .41725 Mdot
.32937 .39657 Mdot
.65499 .64825 Mdot
.65394 .36449 Mdot
.36657 .65254 Mdot
.70925 .51795 Mdot
.68291 .60868 Mdot
.31658 .60171 Mdot
.4614 .70324 Mdot
.52064 .74147 Mdot
.36859 .33155 Mdot
.48303 .72471 Mdot
.5448 .27766 Mdot
.57998 .29516 Mdot
.56955 .28319 Mdot
.69741 .46167 Mdot
.31497 .40458 Mdot
.71142 .52717 Mdot
.3081 .43342 Mdot
.40803 .30992 Mdot
.43422 .68923 Mdot
.33197 .39826 Mdot
.55988 .30317 Mdot
.28996 .53535 Mdot
.59417 .70911 Mdot
.45308 .30502 Mdot
.28359 .45431 Mdot
.65298 .35812 Mdot
.7069 .51344 Mdot
.70921 .42697 Mdot
.3459 .36103 Mdot
.42624 .68775 Mdot
.38246 .65609 Mdot
.54446 .29769 Mdot
.35189 .37069 Mdot
.30392 .54174 Mdot
.32872 .4074 Mdot
.55378 .30021 Mdot
.57945 .69745 Mdot
.6976 .5569 Mdot
.51046 .72491 Mdot
.58493 .6935 Mdot
.53216 .27815 Mdot
.73143 .52524 Mdot
.30421 .53706 Mdot
.44203 .71448 Mdot
.70511 .41533 Mdot
.63954 .34388 Mdot
.28266 .52123 Mdot
.63855 .6463 Mdot
.37243 .65656 Mdot
.5355 .72855 Mdot
.58209 .70779 Mdot
.67306 .61899 Mdot
.3077 .41494 Mdot
.52973 .72842 Mdot
.63267 .66083 Mdot
.68435 .61452 Mdot
.46897 .70989 Mdot
.47516 .71462 Mdot
.69894 .42975 Mdot
.56034 .70336 Mdot
.47975 .28258 Mdot
.64458 .65319 Mdot
.35006 .3713 Mdot
.66875 .62364 Mdot
.56618 .70464 Mdot
.73041 .53305 Mdot
.56662 .71884 Mdot
.70645 .48917 Mdot
.69675 .45203 Mdot
.64251 .32458 Mdot
.67198 .61446 Mdot
.45849 .27531 Mdot
.28679 .49176 Mdot
.37894 .33677 Mdot
.69758 .4291 Mdot
.42065 .28315 Mdot
.55603 .30931 Mdot
.47048 .30432 Mdot
.49742 .29542 Mdot
.65729 .35597 Mdot
.70033 .39269 Mdot
.61458 .69152 Mdot
.65878 .3626 Mdot
.298 .47991 Mdot
.30506 .55808 Mdot
.73181 .51845 Mdot
.33034 .41118 Mdot
.36544 .6319 Mdot
.6705 .3709 Mdot
.42888 .30662 Mdot
.54166 .7297 Mdot
.68845 .42891 Mdot
.28432 .57325 Mdot
.7037 .42606 Mdot
.3439 .38413 Mdot
.30474 .53103 Mdot
.44352 .70773 Mdot
.34453 .37598 Mdot
.54287 .27635 Mdot
.473 .70816 Mdot
.72793 .52476 Mdot
.37849 .33757 Mdot
.62182 .33204 Mdot
.59363 .30382 Mdot
.31503 .4452 Mdot
.71005 .45519 Mdot
.71155 .52205 Mdot
.30491 .43474 Mdot
.64164 .34502 Mdot
.70993 .49653 Mdot
.50202 .73773 Mdot
.6211 .31119 Mdot
.46702 .7033 Mdot
.4686 .7313 Mdot
.29982 .49815 Mdot
.31923 .40739 Mdot
.68749 .61732 Mdot
.41307 .30299 Mdot
.64223 .65812 Mdot
.44176 .7161 Mdot
.41773 .68363 Mdot
.38409 .66606 Mdot
.53315 .72721 Mdot
.36386 .34103 Mdot
.70238 .47525 Mdot
.28567 .46104 Mdot
.30403 .44918 Mdot
.69126 .60657 Mdot
.33777 .37985 Mdot
.2938 .53979 Mdot
.34057 .36588 Mdot
.39185 .68153 Mdot
.38937 .66596 Mdot
.69721 .54568 Mdot
.47272 .7348 Mdot
.31029 .41743 Mdot
.38417 .6677 Mdot
.60329 .70462 Mdot
.63702 .33679 Mdot
.52492 .74124 Mdot
.40795 .67619 Mdot
.59749 .31465 Mdot
.6403 .34128 Mdot
.36789 .34317 Mdot
.33505 .39346 Mdot
.46907 .27188 Mdot
.31029 .55441 Mdot
.51628 .72353 Mdot
.45963 .72072 Mdot
.57202 .7003 Mdot
.31288 .55798 Mdot
.66221 .62928 Mdot
.45528 .72986 Mdot
.40615 .67176 Mdot
.29968 .53966 Mdot
.62728 .31796 Mdot
.70229 .43425 Mdot
.47127 .73169 Mdot
.30415 .44756 Mdot
.68217 .61418 Mdot
.30131 .59786 Mdot
.6954 .43072 Mdot
.72234 .54372 Mdot
.69689 .40291 Mdot
.65091 .35341 Mdot
.36741 .3505 Mdot
.30505 .53111 Mdot
.70423 .42596 Mdot
.40062 .30146 Mdot
.56995 .30535 Mdot
.56883 .71093 Mdot
.65085 .33434 Mdot
.69478 .38947 Mdot
.70414 .46249 Mdot
.6857 .42867 Mdot
.64574 .64935 Mdot
.53494 .72743 Mdot
.3106 .43219 Mdot
.55241 .30052 Mdot
.41666 .30363 Mdot
.45816 .71713 Mdot
.72514 .53615 Mdot
.55227 .73003 Mdot
.44083 .70665 Mdot
.39444 .66036 Mdot
.3761 .64154 Mdot
.2889 .44294 Mdot
.35811 .63309 Mdot
.36948 .6412 Mdot
.66626 .37985 Mdot
.37156 .34058 Mdot
.3675 .66178 Mdot
.28285 .46607 Mdot
.32557 .61115 Mdot
.28223 .56857 Mdot
.46795 .7275 Mdot
.63343 .66658 Mdot
.70436 .43784 Mdot
.4976 .28236 Mdot
.4317 .27846 Mdot
.30082 .58205 Mdot
.64546 .33728 Mdot
.71148 .40291 Mdot
.37483 .32818 Mdot
.3039 .52697 Mdot
.4423 .69459 Mdot
.5849 .69966 Mdot
.57001 .71844 Mdot
.58298 .71008 Mdot
.43479 .69097 Mdot
.31891 .41313 Mdot
.50911 .28828 Mdot
.56007 .71455 Mdot
.71323 .5624 Mdot
.30813 .60104 Mdot
.30911 .57177 Mdot
.71463 .49847 Mdot
.43749 .71277 Mdot
.63526 .34983 Mdot
.61238 .67951 Mdot
.61199 .31532 Mdot
.71428 .47566 Mdot
.32959 .61763 Mdot
.47265 .71045 Mdot
.48493 .71828 Mdot
.35327 .62783 Mdot
.71732 .49264 Mdot
.71549 .50899 Mdot
.68916 .55915 Mdot
.63606 .33487 Mdot
.49605 .72351 Mdot
.54079 .28354 Mdot
.30953 .41791 Mdot
.71204 .42301 Mdot
.55559 .70324 Mdot
.43932 .29294 Mdot
.68584 .61857 Mdot
.2841 .54535 Mdot
.60473 .69066 Mdot
.2894 .467 Mdot
.50969 .74095 Mdot
.4486 .29753 Mdot
.69766 .56037 Mdot
.68358 .62504 Mdot
.36434 .32918 Mdot
.52411 .72675 Mdot
.27542 .4987 Mdot
.33386 .3989 Mdot
.31161 .54884 Mdot
.48402 .71654 Mdot
.28208 .55192 Mdot
.65403 .36335 Mdot
.36858 .6624 Mdot
.51699 .72672 Mdot
.38905 .65915 Mdot
.46275 .71295 Mdot
.63199 .33298 Mdot
.65552 .62804 Mdot
.29068 .49375 Mdot
.33794 .39239 Mdot
.67002 .62205 Mdot
.28749 .53786 Mdot
.55813 .29064 Mdot
.36975 .3406 Mdot
.32289 .42322 Mdot
.3144 .55201 Mdot
.48085 .71255 Mdot
.39448 .67595 Mdot
.3133 .41109 Mdot
.45378 .711 Mdot
.64861 .64555 Mdot
.48933 .29242 Mdot
.67406 .61466 Mdot
.29315 .58609 Mdot
.28387 .55804 Mdot
.62837 .32739 Mdot
.70535 .42695 Mdot
.30351 .57877 Mdot
.44089 .29963 Mdot
.48473 .73185 Mdot
.46632 .70701 Mdot
.70546 .52339 Mdot
.42638 .69468 Mdot
.29355 .58687 Mdot
.44423 .70749 Mdot
.6834 .5678 Mdot
.72076 .48062 Mdot
.37207 .65578 Mdot
.65801 .63952 Mdot
.69975 .46123 Mdot
.30349 .55443 Mdot
.65228 .34306 Mdot
.52661 .71841 Mdot
.66367 .37141 Mdot
.68841 .55904 Mdot
.30636 .45958 Mdot
.69571 .39371 Mdot
.30683 .45969 Mdot
.68861 .59284 Mdot
.4122 .68201 Mdot
.70728 .51822 Mdot
.28031 .50791 Mdot
.44578 .27835 Mdot
.41091 .31119 Mdot
.29824 .43652 Mdot
.70898 .4186 Mdot
.30239 .44103 Mdot
.30059 .57019 Mdot
.51585 .28058 Mdot
.69458 .44982 Mdot
.49488 .29834 Mdot
.43229 .30623 Mdot
.54 .29589 Mdot
.38964 .65669 Mdot
.51823 .72895 Mdot
.47817 .30157 Mdot
.61065 .31101 Mdot
.71357 .46015 Mdot
.38098 .6548 Mdot
.32565 .41746 Mdot
.48328 .2856 Mdot
.49168 .27277 Mdot
.70012 .54507 Mdot
.6822 .62906 Mdot
.41895 .68557 Mdot
.57554 .29097 Mdot
.52845 .74004 Mdot
.65658 .64219 Mdot
.30983 .56261 Mdot
.43176 .70523 Mdot
.50716 .73685 Mdot
.5636 .28598 Mdot
.31883 .4417 Mdot
.58447 .70991 Mdot
.37979 .32277 Mdot
.53256 .7319 Mdot
.33643 .61808 Mdot
.31421 .41051 Mdot
.44609 .6969 Mdot
.29584 .48907 Mdot
.70054 .40323 Mdot
.38727 .65956 Mdot
.5708 .30675 Mdot
.45907 .2764 Mdot
.42664 .68833 Mdot
.3398 .38329 Mdot
.5725 .29842 Mdot
.29056 .46736 Mdot
.30358 .53957 Mdot
.67768 .62548 Mdot
.42985 .70102 Mdot
.37597 .33103 Mdot
.29014 .55014 Mdot
.39394 .66287 Mdot
.43152 .29722 Mdot
.55815 .28733 Mdot
.28797 .45315 Mdot
.5009 .72414 Mdot
.54721 .29156 Mdot
.64662 .34117 Mdot
.28286 .54488 Mdot
.67681 .37707 Mdot
.42965 .70913 Mdot
.4074 .68075 Mdot
.68293 .38753 Mdot
.70563 .52847 Mdot
.49042 .71491 Mdot
.34697 .6282 Mdot
.64394 .35784 Mdot
.54322 .7258 Mdot
.51827 .74216 Mdot
.27915 .50742 Mdot
.61813 .32473 Mdot
.45725 .2702 Mdot
.41546 .30833 Mdot
.29528 .55447 Mdot
.70354 .39742 Mdot
.29222 .51302 Mdot
.46282 .27811 Mdot
.51983 .73408 Mdot
.6621 .37303 Mdot
.68001 .59864 Mdot
.56402 .29834 Mdot
.45456 .30099 Mdot
.71406 .54107 Mdot
.61561 .67663 Mdot
.33684 .61838 Mdot
.61086 .31433 Mdot
.34874 .35924 Mdot
.3078 .59428 Mdot
.71277 .5631 Mdot
.40166 .67992 Mdot
.56219 .70875 Mdot
.42891 .69097 Mdot
.29683 .42708 Mdot
.37812 .33266 Mdot
.33012 .39608 Mdot
.31594 .44332 Mdot
.50466 .71863 Mdot
.64783 .34161 Mdot
.55653 .28247 Mdot
.28997 .47698 Mdot
.64884 .3497 Mdot
.40225 .68654 Mdot
.46915 .29704 Mdot
.68569 .59317 Mdot
.39467 .67229 Mdot
.30738 .52383 Mdot
.56893 .31323 Mdot
.69236 .58158 Mdot
.43936 .27377 Mdot
.48358 .71716 Mdot
.71061 .48821 Mdot
.65695 .36392 Mdot
.48368 .73328 Mdot
.45205 .27723 Mdot
.32323 .4219 Mdot
.42828 .29502 Mdot
.45546 .69641 Mdot
.48076 .71721 Mdot
.31448 .45309 Mdot
.39417 .67026 Mdot
.69883 .4774 Mdot
.63686 .64893 Mdot
.63746 .66101 Mdot
.36926 .64041 Mdot
.72743 .54679 Mdot
.58105 .30193 Mdot
.29053 .47742 Mdot
.58126 .70819 Mdot
.45741 .71403 Mdot
.69462 .45629 Mdot
.56133 .29047 Mdot
.5382 .27242 Mdot
.63443 .33545 Mdot
.45022 .27633 Mdot
.64696 .33905 Mdot
.3523 .62586 Mdot
.71236 .47077 Mdot
.45631 .28555 Mdot
.29767 .46091 Mdot
.39419 .30175 Mdot
.35082 .63067 Mdot
.51314 .28399 Mdot
.40273 .30899 Mdot
.65259 .64876 Mdot
.71963 .4364 Mdot
.30014 .41527 Mdot
.62073 .67149 Mdot
.51836 .73727 Mdot
.4305 .69198 Mdot
.32884 .40606 Mdot
.62949 .32873 Mdot
.70117 .53795 Mdot
.33912 .37103 Mdot
.29143 .58339 Mdot
.70656 .48871 Mdot
.2815 .56281 Mdot
.58668 .6953 Mdot
.7244 .55031 Mdot
.60589 .70251 Mdot
.62743 .33519 Mdot
.70902 .42307 Mdot
.30075 .59935 Mdot
.62891 .65725 Mdot
.28945 .56274 Mdot
.41638 .29135 Mdot
.62751 .6774 Mdot
.49424 .29392 Mdot
.53055 .2914 Mdot
.36308 .35097 Mdot
.64595 .36274 Mdot
.33772 .38477 Mdot
.67102 .61313 Mdot
.58017 .29743 Mdot
.5547 .3063 Mdot
.48184 .2799 Mdot
.28696 .47504 Mdot
.65672 .62753 Mdot
.27888 .48339 Mdot
.2806 .47631 Mdot
.56716 .28573 Mdot
.7106 .43291 Mdot
.70025 .44673 Mdot
.32374 .60981 Mdot
.70931 .43281 Mdot
.4764 .28828 Mdot
.57984 .70068 Mdot
.63342 .66878 Mdot
.58338 .30554 Mdot
.67837 .62448 Mdot
.358 .62708 Mdot
.3865 .33275 Mdot
.47416 .29315 Mdot
.63991 .33654 Mdot
.69261 .38624 Mdot
.29701 .47433 Mdot
.70172 .54319 Mdot
.70818 .40595 Mdot
.69825 .40922 Mdot
.69773 .39109 Mdot
.49699 .72704 Mdot
.6475 .36522 Mdot
.70591 .41422 Mdot
.46959 .70426 Mdot
.41236 .68911 Mdot
.32148 .42087 Mdot
.29322 .43259 Mdot
.65072 .6423 Mdot
.31234 .4317 Mdot
.38573 .67224 Mdot
.43688 .28899 Mdot
.30705 .41222 Mdot
.29913 .47425 Mdot
.48186 .27688 Mdot
.4943 .28019 Mdot
.27914 .48046 Mdot
.3105 .40857 Mdot
.69737 .47367 Mdot
.67424 .60947 Mdot
.72769 .52442 Mdot
.39758 .31053 Mdot
.58352 .29261 Mdot
.70575 .52168 Mdot
.42634 .68464 Mdot
.32774 .41941 Mdot
.45315 .29653 Mdot
.69023 .44077 Mdot
.37303 .64869 Mdot
.30556 .44267 Mdot
.29509 .56554 Mdot
.29621 .46409 Mdot
.32173 .41107 Mdot
.72361 .50004 Mdot
.67337 .37619 Mdot
.7132 .55567 Mdot
.3773 .3231 Mdot
.29036 .46351 Mdot
.71416 .49069 Mdot
.34778 .36789 Mdot
.51332 .27716 Mdot
.63648 .64755 Mdot
.3678 .63907 Mdot
.49942 .28329 Mdot
.71488 .44138 Mdot
.66627 .3632 Mdot
.60065 .70684 Mdot
.70464 .42491 Mdot
.33509 .39164 Mdot
.30861 .42191 Mdot
.48405 .28496 Mdot
.71442 .50262 Mdot
.65895 .64043 Mdot
.70132 .41783 Mdot
.54421 .29633 Mdot
.42324 .68793 Mdot
.7108 .48848 Mdot
.31381 .4351 Mdot
.70312 .44351 Mdot
.42285 .3031 Mdot
.29461 .57789 Mdot
.45903 .71 Mdot
.5999 .30988 Mdot
.39439 .66467 Mdot
.53499 .29135 Mdot
.31242 .53376 Mdot
.65647 .64941 Mdot
.43776 .69542 Mdot
.5697 .70914 Mdot
.55692 .30756 Mdot
.44698 .69252 Mdot
.59651 .68368 Mdot
.72132 .54615 Mdot
.70744 .54879 Mdot
.39432 .68294 Mdot
.48449 .2966 Mdot
.34459 .35073 Mdot
.41071 .68158 Mdot
.35586 .33394 Mdot
.62405 .67528 Mdot
.28687 .49023 Mdot
.31653 .60822 Mdot
.47001 .72449 Mdot
.45044 .70528 Mdot
.36079 .64026 Mdot
.4193 .68217 Mdot
.57964 .71687 Mdot
.45936 .27724 Mdot
.4514 .27237 Mdot
.30138 .56618 Mdot
.54508 .73367 Mdot
.28603 .56559 Mdot
.56121 .28806 Mdot
.67128 .61401 Mdot
.33588 .39585 Mdot
.70689 .43417 Mdot
.39052 .66228 Mdot
.41598 .29617 Mdot
.44564 .69772 Mdot
.66932 .63016 Mdot
.47836 .28655 Mdot
.4452 .29552 Mdot
.38393 .32144 Mdot
.29855 .59243 Mdot
.69278 .41327 Mdot
.35152 .62805 Mdot
.31359 .59919 Mdot
.29798 .47856 Mdot
.56494 .72299 Mdot
.71274 .47399 Mdot
.69668 .43553 Mdot
.68963 .41024 Mdot
.36463 .65073 Mdot
.36296 .64915 Mdot
.53318 .28603 Mdot
.71693 .51932 Mdot
.65874 .37571 Mdot
.50232 .28589 Mdot
.34665 .34471 Mdot
.44867 .7023 Mdot
.30681 .52762 Mdot
.28622 .54232 Mdot
.39587 .30737 Mdot
.32471 .40484 Mdot
.28155 .55466 Mdot
.36294 .65158 Mdot
.49031 .28531 Mdot
.30275 .59746 Mdot
.6919 .3905 Mdot
.57768 .28566 Mdot
.28707 .57115 Mdot
.3172 .43743 Mdot
.72253 .53127 Mdot
.48715 .729 Mdot
.28789 .52149 Mdot
.5761 .29581 Mdot
.60982 .69627 Mdot
.32259 .40547 Mdot
.30198 .51943 Mdot
.52757 .72197 Mdot
.45983 .28121 Mdot
.31781 .43942 Mdot
.3 .60099 Mdot
.64048 .66572 Mdot
.29123 .51769 Mdot
.69926 .44037 Mdot
.63721 .66259 Mdot
.44243 .70298 Mdot
.66869 .63765 Mdot
.63999 .3232 Mdot
.41469 .29135 Mdot
.429 .28167 Mdot
.70483 .51964 Mdot
.57656 .70527 Mdot
.48022 .30257 Mdot
.57415 .70863 Mdot
.31971 .61008 Mdot
.46811 .7034 Mdot
.32438 .61621 Mdot
.63168 .65788 Mdot
.28076 .57271 Mdot
.29069 .57519 Mdot
.58198 .31203 Mdot
.65357 .35005 Mdot
.62991 .33249 Mdot
.49125 .29597 Mdot
.59371 .69403 Mdot
.43967 .27601 Mdot
.67865 .38235 Mdot
.29361 .54177 Mdot
.3636 .33813 Mdot
.35795 .63014 Mdot
.38324 .67006 Mdot
.67791 .63181 Mdot
.32609 .41342 Mdot
.48 .70988 Mdot
.54324 .29192 Mdot
.40009 .30162 Mdot
.49957 .27543 Mdot
.69822 .52661 Mdot
.67975 .3853 Mdot
.44412 .2939 Mdot
.32117 .61146 Mdot
.28592 .53794 Mdot
.55515 .72743 Mdot
.27216 .4827 Mdot
.43252 .28703 Mdot
.43647 .71317 Mdot
.69231 .44677 Mdot
.40295 .31628 Mdot
.38628 .6573 Mdot
.42307 .30683 Mdot
.32718 .38533 Mdot
.65036 .65195 Mdot
.48413 .72484 Mdot
.57708 .28651 Mdot
.5814 .70634 Mdot
.2846 .57806 Mdot
.31516 .45254 Mdot
.55136 .70611 Mdot
.46793 .2779 Mdot
.40317 .2943 Mdot
.29422 .58131 Mdot
.70657 .56904 Mdot
.69703 .44841 Mdot
.69752 .47299 Mdot
.53893 .2911 Mdot
.41206 .68104 Mdot
.48629 .28381 Mdot
.70877 .53584 Mdot
.48356 .73156 Mdot
.64442 .35511 Mdot
.3899 .30644 Mdot
.39401 .66987 Mdot
.43923 .69566 Mdot
.29145 .57167 Mdot
.32524 .60821 Mdot
.29378 .49005 Mdot
.51141 .27641 Mdot
.51014 .71859 Mdot
.67982 .60922 Mdot
.37105 .65477 Mdot
.70973 .46953 Mdot
.30287 .43833 Mdot
.2863 .55166 Mdot
.49433 .71597 Mdot
.56361 .70361 Mdot
.70642 .46138 Mdot
.62916 .33927 Mdot
.2969 .45801 Mdot
.51324 .72037 Mdot
.39448 .66806 Mdot
.43902 .7029 Mdot
.64624 .64923 Mdot
.36755 .63379 Mdot
.38093 .33647 Mdot
.68536 .58318 Mdot
.31323 .57381 Mdot
.69545 .41219 Mdot
.35011 .36399 Mdot
.63971 .64281 Mdot
.60824 .68472 Mdot
.72506 .5503 Mdot
.71746 .45241 Mdot
.54438 .2972 Mdot
.65442 .36878 Mdot
.3113 .53835 Mdot
.45081 .69691 Mdot
.30692 .41938 Mdot
.70188 .41124 Mdot
.41613 .29127 Mdot
.28456 .56267 Mdot
.34881 .35799 Mdot
.38127 .66391 Mdot
.47554 .27944 Mdot
.29216 .44681 Mdot
.71719 .497 Mdot
.43886 .28672 Mdot
.32338 .42114 Mdot
.30705 .56069 Mdot
.60788 .696 Mdot
.34206 .38408 Mdot
.31022 .45204 Mdot
.45192 .69998 Mdot
.68682 .59484 Mdot
.67522 .62901 Mdot
.27903 .50487 Mdot
.44244 .27189 Mdot
.31299 .44048 Mdot
.6877 .5848 Mdot
.65531 .64899 Mdot
.41104 .3027 Mdot
.71062 .51924 Mdot
.63531 .65031 Mdot
.3029 .46527 Mdot
.71439 .46913 Mdot
.33775 .37426 Mdot
.68406 .40512 Mdot
.48717 .73161 Mdot
.38362 .64675 Mdot
.49382 .29614 Mdot
.29142 .5649 Mdot
.54318 .28142 Mdot
.59453 .31454 Mdot
.56461 .30825 Mdot
.49795 .29944 Mdot
.39167 .66517 Mdot
.70677 .41826 Mdot
.6565 .35871 Mdot
.69876 .54066 Mdot
.43375 .2996 Mdot
.47562 .29774 Mdot
.6813 .62706 Mdot
.28337 .55756 Mdot
.35747 .63046 Mdot
.41666 .29149 Mdot
.36898 .34579 Mdot
.71324 .48937 Mdot
.28731 .58321 Mdot
.64197 .64395 Mdot
.34309 .38338 Mdot
.53878 .73559 Mdot
.7162 .5627 Mdot
.30397 .42697 Mdot
.70972 .50822 Mdot
.50834 .73858 Mdot
.51289 .28505 Mdot
.35313 .36382 Mdot
.57848 .70678 Mdot
.53471 .27636 Mdot
.65918 .36813 Mdot
.44284 .28404 Mdot
.37947 .65749 Mdot
.35178 .35411 Mdot
.29624 .55531 Mdot
.62428 .66137 Mdot
.28905 .4788 Mdot
.70088 .53243 Mdot
.6613 .36061 Mdot
.31006 .40825 Mdot
.5427 .28156 Mdot
.62846 .3325 Mdot
.72961 .53254 Mdot
.44388 .7035 Mdot
.45542 .29294 Mdot
.46716 .30282 Mdot
.32403 .61451 Mdot
.39017 .32789 Mdot
.68886 .42764 Mdot
.50514 .28021 Mdot
.55477 .71275 Mdot
.39235 .68115 Mdot
.32094 .40203 Mdot
.29788 .43261 Mdot
.3619 .35417 Mdot
.44826 .69274 Mdot
.70267 .56335 Mdot
.44729 .27227 Mdot
.42494 .30792 Mdot
.66365 .64164 Mdot
.65571 .35335 Mdot
.27293 .49361 Mdot
.47447 .29008 Mdot
.5263 .718 Mdot
.45128 .70357 Mdot
.61185 .31654 Mdot
.47249 .28838 Mdot
.33637 .38086 Mdot
.5959 .30936 Mdot
.7128 .5419 Mdot
.57309 .71549 Mdot
.7002 .55143 Mdot
.28194 .55521 Mdot
.43075 .28373 Mdot
.5515 .2839 Mdot
.29304 .46384 Mdot
.34786 .34816 Mdot
.48782 .30051 Mdot
.69891 .43124 Mdot
.43861 .70148 Mdot
.46175 .7263 Mdot
.39583 .67129 Mdot
.55595 .72964 Mdot
.28944 .58366 Mdot
.59515 .31574 Mdot
.54792 .29903 Mdot
.57142 .71574 Mdot
.29972 .59533 Mdot
.4591 .27392 Mdot
.47719 .28544 Mdot
.60159 .31302 Mdot
.32058 .41141 Mdot
.45444 .27379 Mdot
.45403 .70218 Mdot
.36461 .33206 Mdot
.72548 .53701 Mdot
.65546 .35163 Mdot
.45628 .71309 Mdot
.48971 .30037 Mdot
.72493 .50263 Mdot
.58997 .69886 Mdot
.40884 .67933 Mdot
.28246 .51007 Mdot
.65606 .36738 Mdot
.68193 .37977 Mdot
.38567 .33394 Mdot
.40681 .67369 Mdot
.55301 .28837 Mdot
.33875 .38235 Mdot
.36824 .33034 Mdot
.69622 .40003 Mdot
.43341 .30599 Mdot
.65552 .3472 Mdot
.28912 .45505 Mdot
.31327 .57243 Mdot
.42947 .29254 Mdot
.40937 .30975 Mdot
.66359 .62907 Mdot
.32178 .60508 Mdot
.28165 .5409 Mdot
.71675 .44484 Mdot
.6409 .35556 Mdot
.67081 .6308 Mdot
.52562 .7186 Mdot
.35942 .64444 Mdot
.62776 .32711 Mdot
.71672 .47807 Mdot
.43141 .7087 Mdot
.36741 .64768 Mdot
.47646 .72992 Mdot
.71645 .55069 Mdot
.71307 .42107 Mdot
.54783 .72913 Mdot
.65711 .63909 Mdot
.59769 .68878 Mdot
.70341 .43675 Mdot
.69453 .42033 Mdot
.60503 .68882 Mdot
.6665 .62814 Mdot
.71496 .51546 Mdot
.65085 .34902 Mdot
.65896 .36819 Mdot
.6984 .40699 Mdot
.67426 .6364 Mdot
.62406 .32391 Mdot
.69506 .55244 Mdot
.46021 .30033 Mdot
.59961 .6837 Mdot
.71079 .40316 Mdot
.62656 .67663 Mdot
.65373 .36318 Mdot
.54995 .72453 Mdot
.62676 .67439 Mdot
.36977 .63551 Mdot
.43987 .70058 Mdot
.3098 .59604 Mdot
.29308 .46649 Mdot
.27889 .48008 Mdot
.63022 .32923 Mdot
.35719 .63349 Mdot
.68916 .56398 Mdot
.35954 .64169 Mdot
.42549 .69422 Mdot
.52878 .72056 Mdot
.53993 .71271 Mdot
.69627 .40171 Mdot
.68851 .56196 Mdot
.36093 .33313 Mdot
.40776 .29434 Mdot
.56819 .70103 Mdot
.65719 .36761 Mdot
.70479 .44604 Mdot
.65906 .37536 Mdot
.46494 .27834 Mdot
.4534 .29428 Mdot
.31144 .4285 Mdot
.31803 .43917 Mdot
.44682 .28588 Mdot
.36553 .32817 Mdot
.54796 .72312 Mdot
.70793 .52195 Mdot
.68503 .58824 Mdot
.44746 .71477 Mdot
.46872 .73167 Mdot
.29277 .56401 Mdot
.34352 .38147 Mdot
.54461 .29001 Mdot
.57311 .7118 Mdot
.36439 .65581 Mdot
.30767 .45394 Mdot
.63396 .31683 Mdot
.29415 .52675 Mdot
.65861 .35928 Mdot
.30837 .55247 Mdot
.41396 .30279 Mdot
.39054 .667 Mdot
.36145 .63935 Mdot
.54993 .29852 Mdot
.38852 .31935 Mdot
.49408 .28765 Mdot
.28958 .55885 Mdot
.45435 .71807 Mdot
.47796 .28222 Mdot
.71404 .40704 Mdot
.71418 .47468 Mdot
.29309 .44257 Mdot
.37446 .65148 Mdot
.47466 .72538 Mdot
.65331 .6499 Mdot
.29678 .47997 Mdot
.29758 .45701 Mdot
.67693 .38228 Mdot
.52891 .73492 Mdot
.5361 .27161 Mdot
.31612 .4478 Mdot
.69255 .3989 Mdot
.45255 .29157 Mdot
.29622 .47894 Mdot
.27642 .48645 Mdot
.33384 .62092 Mdot
.27624 .47018 Mdot
.7101 .44881 Mdot
.70069 .55561 Mdot
.6614 .62362 Mdot
.7211 .46253 Mdot
.31211 .55348 Mdot
.28959 .53436 Mdot
.35638 .36163 Mdot
.57371 .3071 Mdot
.49984 .73889 Mdot
.29135 .54465 Mdot
.68842 .39302 Mdot
.68404 .62066 Mdot
.67594 .61868 Mdot
.66338 .62503 Mdot
.69781 .54581 Mdot
.47761 .71375 Mdot
.37758 .33498 Mdot
.70028 .43347 Mdot
.67448 .61469 Mdot
.45313 .72675 Mdot
.70179 .47373 Mdot
.63522 .34767 Mdot
.62617 .66292 Mdot
.70661 .42058 Mdot
.57426 .71767 Mdot
.64421 .36039 Mdot
.56521 .70718 Mdot
.49745 .27645 Mdot
.3534 .3667 Mdot
.64237 .33925 Mdot
.39071 .30741 Mdot
.48375 .2809 Mdot
.48649 .28992 Mdot
.71002 .41226 Mdot
.39771 .31399 Mdot
.68731 .56484 Mdot
.34928 .35882 Mdot
.51312 .72084 Mdot
.3053 .53205 Mdot
.36621 .34703 Mdot
.69772 .41065 Mdot
.68335 .38434 Mdot
.33809 .61774 Mdot
.41834 .6936 Mdot
.57064 .28942 Mdot
.30249 .56251 Mdot
.58117 .69991 Mdot
.31056 .56553 Mdot
.4567 .27622 Mdot
.48824 .71012 Mdot
.45096 .70376 Mdot
.55828 .27614 Mdot
.2912 .56668 Mdot
.69412 .41512 Mdot
.66291 .6281 Mdot
.5178 .2902 Mdot
.2945 .55483 Mdot
.28377 .55601 Mdot
.40668 .67831 Mdot
.6988 .55723 Mdot
.50814 .28858 Mdot
.61542 .31456 Mdot
.33017 .37789 Mdot
.57158 .71987 Mdot
.5229 .73016 Mdot
.41592 .68795 Mdot
.58641 .6937 Mdot
.35081 .36197 Mdot
.64585 .34516 Mdot
.42331 .69074 Mdot
.3434 .37415 Mdot
.4153 .67937 Mdot
.71988 .4892 Mdot
.35832 .3529 Mdot
.28923 .44794 Mdot
.32172 .42176 Mdot
.37873 .65123 Mdot
.34006 .62635 Mdot
.49999 .72444 Mdot
.62168 .31954 Mdot
.28673 .4721 Mdot
.39043 .31082 Mdot
.69185 .44206 Mdot
.33431 .62089 Mdot
.6517 .64317 Mdot
.61671 .31804 Mdot
.47512 .28319 Mdot
.33649 .62295 Mdot
.30904 .59151 Mdot
.63574 .67041 Mdot
.41092 .68904 Mdot
.37678 .65023 Mdot
.63677 .34575 Mdot
.62425 .31691 Mdot
.71204 .56698 Mdot
.32033 .40127 Mdot
.71097 .48603 Mdot
.56633 .30033 Mdot
.33639 .62406 Mdot
.30294 .42415 Mdot
.70711 .56297 Mdot
.29731 .43038 Mdot
.64574 .32865 Mdot
.51099 .72648 Mdot
.69979 .5559 Mdot
.29746 .43913 Mdot
.63131 .66611 Mdot
.67802 .62212 Mdot
.53607 .72024 Mdot
.39741 .66434 Mdot
.69234 .43292 Mdot
.70057 .43668 Mdot
.69174 .56403 Mdot
.30934 .42303 Mdot
.38361 .66711 Mdot
.37226 .64062 Mdot
.39939 .66251 Mdot
.71549 .48254 Mdot
.38972 .66387 Mdot
.68501 .4204 Mdot
.58524 .6897 Mdot
.49001 .27295 Mdot
.36345 .64511 Mdot
.64075 .3336 Mdot
.38125 .648 Mdot
.28046 .56132 Mdot
.59725 .70415 Mdot
.64356 .65311 Mdot
.64618 .34879 Mdot
.43709 .71208 Mdot
.33757 .38189 Mdot
.35221 .63079 Mdot
.30787 .54687 Mdot
.56905 .28336 Mdot
.50249 .72922 Mdot
.70994 .49605 Mdot
.69941 .41721 Mdot
.42348 .29713 Mdot
.66693 .37511 Mdot
.44458 .27865 Mdot
.67415 .60938 Mdot
.31071 .41272 Mdot
.35804 .34453 Mdot
.52697 .71924 Mdot
.52108 .73206 Mdot
.32877 .40427 Mdot
.69201 .54349 Mdot
.37807 .33821 Mdot
.47312 .73413 Mdot
.6797 .62974 Mdot
.29597 .58118 Mdot
.30825 .56026 Mdot
.3271 .61202 Mdot
.70431 .53855 Mdot
.68465 .3858 Mdot
.63926 .34868 Mdot
.48244 .30249 Mdot
.28493 .58024 Mdot
.60221 .30613 Mdot
.63667 .32334 Mdot
.36799 .34932 Mdot
.66108 .36155 Mdot
.37316 .65831 Mdot
.2797 .48201 Mdot
.7189 .53464 Mdot
.29554 .47087 Mdot
.50094 .73792 Mdot
.42965 .30801 Mdot
.31327 .41624 Mdot
.313 .59776 Mdot
.65033 .33972 Mdot
.4386 .29203 Mdot
.44209 .70424 Mdot
.701 .43911 Mdot
.69253 .59681 Mdot
.32977 .38608 Mdot
.64295 .6527 Mdot
.63866 .65337 Mdot
.71576 .55558 Mdot
.28571 .49638 Mdot
.33453 .36484 Mdot
.63342 .65614 Mdot
.5534 .30408 Mdot
.30335 .50873 Mdot
.38478 .32412 Mdot
.42777 .28388 Mdot
.4585 .28442 Mdot
.51465 .7395 Mdot
.46994 .27176 Mdot
.60467 .69407 Mdot
.51761 .28998 Mdot
.58216 .29336 Mdot
.47138 .70774 Mdot
.47402 .28588 Mdot
.31137 .45575 Mdot
.4589 .70649 Mdot
.70886 .55011 Mdot
.49616 .27883 Mdot
.37038 .63545 Mdot
.36962 .32371 Mdot
.5416 .29591 Mdot
.31024 .42319 Mdot
.60871 .69829 Mdot
.65284 .35397 Mdot
.71296 .44166 Mdot
.54283 .71683 Mdot
.29539 .55012 Mdot
.69338 .57075 Mdot
.30632 .52224 Mdot
.28369 .54312 Mdot
.59807 .68525 Mdot
.71862 .44022 Mdot
.28391 .45682 Mdot
.30652 .55765 Mdot
.31753 .60029 Mdot
.45893 .28302 Mdot
.34491 .37165 Mdot
.31496 .4394 Mdot
.44177 .70482 Mdot
.36559 .33976 Mdot
.64543 .33882 Mdot
.41212 .68685 Mdot
.49225 .28969 Mdot
.28335 .46695 Mdot
.36887 .64713 Mdot
.65523 .64043 Mdot
.72097 .54354 Mdot
.29159 .43722 Mdot
.30479 .53881 Mdot
.7049 .55306 Mdot
.41455 .68596 Mdot
.31492 .56009 Mdot
.32985 .38035 Mdot
.4686 .71125 Mdot
.69694 .39748 Mdot
.691 .39007 Mdot
.41873 .28845 Mdot
.62763 .33768 Mdot
.4563 .30393 Mdot
.31049 .55605 Mdot
.34074 .62469 Mdot
.31517 .4293 Mdot
.62901 .65956 Mdot
.60643 .69459 Mdot
.42201 .29309 Mdot
.69295 .41644 Mdot
.61223 .32111 Mdot
.60016 .70205 Mdot
.46391 .70749 Mdot
.37388 .64785 Mdot
.35618 .35674 Mdot
.6952 .44759 Mdot
.37354 .64912 Mdot
.30004 .42171 Mdot
.47067 .70994 Mdot
.30202 .57302 Mdot
.49263 .27464 Mdot
.32288 .43135 Mdot
.72042 .47033 Mdot
.30274 .43184 Mdot
.47974 .29031 Mdot
.52893 .71491 Mdot
.59242 .69236 Mdot
.32967 .61671 Mdot
.70991 .45096 Mdot
.725 .50437 Mdot
.45907 .29375 Mdot
.34736 .36645 Mdot
.64757 .6437 Mdot
.65846 .63258 Mdot
.45685 .70586 Mdot
.45479 .27658 Mdot
.41819 .28258 Mdot
.29989 .42685 Mdot
.32141 .40835 Mdot
.56864 .69849 Mdot
.41944 .30165 Mdot
.3901 .66611 Mdot
.67533 .63277 Mdot
.65408 .33953 Mdot
.70563 .54456 Mdot
.5877 .30902 Mdot
.663 .35357 Mdot
.48598 .73631 Mdot
.50449 .71585 Mdot
.5377 .28902 Mdot
.56977 .31127 Mdot
.36975 .34917 Mdot
.58247 .6882 Mdot
.28595 .56857 Mdot
.52276 .72104 Mdot
.44817 .27665 Mdot
.3916 .67484 Mdot
.68791 .41256 Mdot
.32814 .39593 Mdot
.60558 .3162 Mdot
.34332 .62473 Mdot
.65222 .6312 Mdot
.37302 .33435 Mdot
.30803 .45624 Mdot
.2911 .47588 Mdot
.48108 .72645 Mdot
.3886 .66399 Mdot
.42055 .28718 Mdot
.62562 .67167 Mdot
.56685 .29976 Mdot
.36204 .35608 Mdot
.70657 .53484 Mdot
.38091 .64988 Mdot
.69592 .46349 Mdot
.65239 .33943 Mdot
.29978 .50825 Mdot
.30375 .59452 Mdot
.35232 .63169 Mdot
.63796 .645 Mdot
.52768 .28924 Mdot
.6523 .639 Mdot
.66789 .62973 Mdot
.30924 .44124 Mdot
.64128 .64527 Mdot
.41083 .69071 Mdot
.43173 .7127 Mdot
.29774 .47904 Mdot
.64285 .32786 Mdot
.49827 .73583 Mdot
.30102 .46769 Mdot
.59456 .70794 Mdot
.6655 .36701 Mdot
.65075 .64088 Mdot
.63414 .3344 Mdot
.36357 .35379 Mdot
.54191 .29444 Mdot
.31342 .57598 Mdot
.37031 .34524 Mdot
.69339 .58276 Mdot
.70705 .41946 Mdot
.65167 .36852 Mdot
.30661 .56068 Mdot
.63779 .33403 Mdot
.43243 .29169 Mdot
.54327 .29932 Mdot
.72386 .47727 Mdot
.52609 .71742 Mdot
.48719 .73616 Mdot
.61787 .32768 Mdot
.40476 .29907 Mdot
.69873 .40732 Mdot
.57123 .30821 Mdot
.61737 .68796 Mdot
.30735 .59141 Mdot
.37747 .64847 Mdot
.64992 .3384 Mdot
.36574 .3444 Mdot
.72234 .55011 Mdot
.30539 .54703 Mdot
.68038 .3788 Mdot
.4168 .29834 Mdot
.46281 .70276 Mdot
.59709 .31502 Mdot
.35335 .34459 Mdot
.55336 .29944 Mdot
.4539 .72249 Mdot
.31763 .40856 Mdot
.29585 .42953 Mdot
.72202 .51047 Mdot
.33172 .40396 Mdot
.33861 .38313 Mdot
.55078 .30464 Mdot
.7019 .57264 Mdot
.36918 .32751 Mdot
.44046 .70433 Mdot
.67446 .61267 Mdot
.30969 .43426 Mdot
.69863 .44527 Mdot
.64896 .64853 Mdot
.31475 .42481 Mdot
.58806 .68821 Mdot
.70214 .54985 Mdot
.47988 .27498 Mdot
.45234 .70109 Mdot
.58512 .29876 Mdot
.56606 .29534 Mdot
.33455 .39225 Mdot
.54634 .28188 Mdot
.59411 .70813 Mdot
.71942 .436 Mdot
.65562 .62915 Mdot
.30254 .57108 Mdot
.69973 .48131 Mdot
.30052 .42405 Mdot
.33122 .61345 Mdot
.4532 .69997 Mdot
.45569 .29364 Mdot
.37212 .32769 Mdot
.56917 .69903 Mdot
.70327 .43366 Mdot
.59822 .70106 Mdot
.64154 .64978 Mdot
.65481 .63664 Mdot
.48429 .30177 Mdot
.5837 .69747 Mdot
.39053 .66542 Mdot
.62117 .32883 Mdot
.59854 .70963 Mdot
.45595 .72617 Mdot
.33816 .3864 Mdot
.64453 .65287 Mdot
.57394 .28754 Mdot
.70864 .52255 Mdot
.45741 .29219 Mdot
.70045 .56706 Mdot
.70396 .53127 Mdot
.71177 .42131 Mdot
.60376 .30757 Mdot
.63561 .65585 Mdot
.56474 .27627 Mdot
.72549 .53924 Mdot
.46626 .73015 Mdot
.6862 .41638 Mdot
.33196 .36972 Mdot
.69684 .5767 Mdot
.71238 .44422 Mdot
.68148 .59568 Mdot
.69661 .44909 Mdot
.45188 .70707 Mdot
.4545 .71307 Mdot
.55425 .70651 Mdot
.35206 .35664 Mdot
.39576 .67234 Mdot
.27713 .47872 Mdot
.30498 .5727 Mdot
.71174 .56106 Mdot
.29642 .46039 Mdot
.6128 .68006 Mdot
.29642 .4906 Mdot
.40616 .68456 Mdot
.37218 .65127 Mdot
.65827 .62951 Mdot
.54435 .72431 Mdot
.35601 .34992 Mdot
.69046 .41225 Mdot
.45714 .72818 Mdot
.35821 .3386 Mdot
.47024 .70408 Mdot
.59314 .70563 Mdot
.43784 .7176 Mdot
.45533 .29298 Mdot
.71081 .52729 Mdot
.28036 .47689 Mdot
.68923 .45542 Mdot
.39507 .66437 Mdot
.28912 .50525 Mdot
.31249 .54526 Mdot
.37467 .65266 Mdot
.69763 .46926 Mdot
.64499 .64967 Mdot
.71286 .45206 Mdot
.70917 .47715 Mdot
.46391 .70727 Mdot
.71237 .53564 Mdot
.71369 .42111 Mdot
.65779 .63372 Mdot
.37189 .33491 Mdot
.514 .27896 Mdot
.51448 .73026 Mdot
.30405 .54497 Mdot
.43622 .69069 Mdot
.28807 .5249 Mdot
.28419 .48535 Mdot
.31312 .44466 Mdot
.48379 .71581 Mdot
.39707 .30176 Mdot
.29064 .51585 Mdot
.35488 .35271 Mdot
.7235 .47431 Mdot
.72733 .52026 Mdot
.56665 .30186 Mdot
.34126 .3748 Mdot
.31296 .44203 Mdot
.45805 .72115 Mdot
.56422 .72023 Mdot
.53854 .2843 Mdot
.71774 .49535 Mdot
.50926 .72907 Mdot
.3297 .40859 Mdot
.49894 .28087 Mdot
.47227 .3014 Mdot
.5512 .30448 Mdot
.68801 .59225 Mdot
.37626 .66367 Mdot
.32802 .40892 Mdot
.62468 .66512 Mdot
.29151 .46768 Mdot
.27835 .46551 Mdot
.38825 .30762 Mdot
.38468 .66532 Mdot
.62663 .67523 Mdot
.48741 .28017 Mdot
.29098 .52585 Mdot
.7183 .49648 Mdot
.31201 .55453 Mdot
.56309 .27809 Mdot
.71878 .5548 Mdot
.44713 .2821 Mdot
.32426 .42449 Mdot
.39677 .67813 Mdot
.70144 .5373 Mdot
.69429 .53796 Mdot
.70919 .54468 Mdot
.30294 .56739 Mdot
.43202 .27901 Mdot
.33443 .37295 Mdot
.4453 .7049 Mdot
.71919 .44424 Mdot
.33402 .62215 Mdot
.43918 .69331 Mdot
.65815 .36637 Mdot
.65361 .64716 Mdot
.69985 .40045 Mdot
.6394 .65791 Mdot
.72652 .54437 Mdot
.48116 .29807 Mdot
.3484 .62184 Mdot
.4559 .70881 Mdot
.50058 .72867 Mdot
.29402 .52784 Mdot
.70204 .46178 Mdot
.52595 .72338 Mdot
.53876 .73553 Mdot
.4857 .72921 Mdot
.37088 .64552 Mdot
.48832 .73642 Mdot
.27793 .49433 Mdot
.31743 .42586 Mdot
.61241 .68918 Mdot
.40227 .66874 Mdot
.7023 .47762 Mdot
.72143 .53344 Mdot
.6286 .66952 Mdot
.62656 .32648 Mdot
.69218 .58022 Mdot
.49131 .28055 Mdot
.51567 .29004 Mdot
.35598 .33779 Mdot
.31469 .60586 Mdot
.64864 .64027 Mdot
.35121 .63354 Mdot
.62268 .32347 Mdot
.2975 .54906 Mdot
.71391 .46847 Mdot
.28247 .55005 Mdot
.57648 .70777 Mdot
.31325 .57854 Mdot
.32656 .3992 Mdot
.59412 .30734 Mdot
.67619 .63145 Mdot
.29814 .5216 Mdot
.70576 .54909 Mdot
.5094 .73001 Mdot
.47755 .72176 Mdot
.68402 .38238 Mdot
.2896 .57648 Mdot
.33014 .37733 Mdot
.45668 .69773 Mdot
.54512 .73225 Mdot
.63145 .33195 Mdot
.31295 .57066 Mdot
.66041 .3721 Mdot
.66309 .63888 Mdot
.72669 .50127 Mdot
.70025 .42812 Mdot
.5702 .29878 Mdot
.59491 .70414 Mdot
.31466 .5876 Mdot
.44948 .28332 Mdot
.57352 .69279 Mdot
.3579 .34646 Mdot
.28419 .51056 Mdot
.49844 .73278 Mdot
.37967 .3346 Mdot
.45496 .72732 Mdot
.55383 .29363 Mdot
.3537 .62903 Mdot
.64547 .65501 Mdot
.48212 .70815 Mdot
.49969 .28762 Mdot
.45945 .28485 Mdot
.35101 .35373 Mdot
.52932 .73704 Mdot
.44848 .72594 Mdot
.69846 .53674 Mdot
.42667 .28277 Mdot
.7067 .41087 Mdot
.69494 .43819 Mdot
.3915 .30827 Mdot
.70837 .46467 Mdot
.28354 .55636 Mdot
.48483 .70869 Mdot
.55337 .29393 Mdot
.55774 .30047 Mdot
.4455 .28519 Mdot
.39965 .30993 Mdot
.45317 .29397 Mdot
.65627 .64465 Mdot
.71884 .43018 Mdot
.53504 .72467 Mdot
.40237 .67097 Mdot
.35883 .63469 Mdot
.70715 .53303 Mdot
.60553 .69768 Mdot
.34887 .63672 Mdot
.29683 .58024 Mdot
.47687 .2907 Mdot
.66306 .36641 Mdot
.68103 .60094 Mdot
.62058 .32485 Mdot
.47511 .71433 Mdot
.51904 .28024 Mdot
.71197 .50361 Mdot
.31278 .58505 Mdot
.66994 .63657 Mdot
.30753 .59883 Mdot
.64992 .3349 Mdot
.69466 .53949 Mdot
.5796 .70281 Mdot
.47049 .70839 Mdot
.596 .69481 Mdot
.29792 .49219 Mdot
.72205 .5559 Mdot
.64907 .36117 Mdot
.67717 .62789 Mdot
.29498 .49139 Mdot
.65004 .6558 Mdot
.5118 .73923 Mdot
.41102 .67741 Mdot
.48518 .73279 Mdot
.44467 .70924 Mdot
.71339 .54207 Mdot
.58723 .70667 Mdot
.32597 .4176 Mdot
.45441 .71053 Mdot
.59553 .3046 Mdot
.40052 .68249 Mdot
.36129 .63728 Mdot
.38363 .67264 Mdot
.43524 .70964 Mdot
.69098 .58288 Mdot
.66502 .62331 Mdot
.6232 .32948 Mdot
.53877 .73148 Mdot
.57833 .30588 Mdot
.44266 .28867 Mdot
.3396 .38678 Mdot
.71686 .54019 Mdot
.30712 .59778 Mdot
.54046 .27508 Mdot
.53764 .72858 Mdot
.35356 .33878 Mdot
.43841 .70706 Mdot
.32735 .39521 Mdot
.28036 .48024 Mdot
.31523 .58999 Mdot
.48155 .30384 Mdot
.64786 .34389 Mdot
.43463 .71149 Mdot
.70315 .40895 Mdot
.70952 .43496 Mdot
.46134 .71151 Mdot
.64407 .32481 Mdot
.56548 .29528 Mdot
.36773 .34583 Mdot
.37696 .66376 Mdot
.45312 .71226 Mdot
.71028 .46676 Mdot
.33585 .377 Mdot
.60234 .68566 Mdot
.29048 .5553 Mdot
.34779 .63003 Mdot
.32832 .41447 Mdot
.58887 .70438 Mdot
.62534 .33104 Mdot
.28395 .45975 Mdot
.36293 .65487 Mdot
.51812 .7208 Mdot
.62967 .66145 Mdot
.32487 .61174 Mdot
.41882 .28359 Mdot
.45878 .7036 Mdot
.44789 .69659 Mdot
.70163 .54895 Mdot
.54585 .29658 Mdot
.69285 .41271 Mdot
.70806 .50369 Mdot
.3132 .44394 Mdot
.53773 .29382 Mdot
.35957 .62893 Mdot
.56096 .28152 Mdot
.65277 .64782 Mdot
.51926 .73659 Mdot
.64814 .36033 Mdot
.70637 .47852 Mdot
.7157 .47525 Mdot
.48812 .72281 Mdot
.66883 .6312 Mdot
.43718 .69093 Mdot
.34555 .36908 Mdot
.33531 .39062 Mdot
.47092 .70909 Mdot
.70649 .4445 Mdot
.43959 .69604 Mdot
.64643 .33234 Mdot
.3009 .52086 Mdot
.70508 .43103 Mdot
.37685 .33228 Mdot
.48044 .30151 Mdot
.41194 .29201 Mdot
.31868 .40526 Mdot
.64023 .64865 Mdot
.70085 .56209 Mdot
.69472 .39918 Mdot
.60071 .6941 Mdot
.47931 .28992 Mdot
.29702 .56828 Mdot
.42333 .68652 Mdot
.32832 .41752 Mdot
.5827 .29681 Mdot
.72067 .46531 Mdot
.58198 .69149 Mdot
.3149 .5697 Mdot
.56568 .71968 Mdot
.30647 .44538 Mdot
.37497 .65821 Mdot
.31382 .57776 Mdot
.40766 .30869 Mdot
.63442 .66127 Mdot
.27459 .48983 Mdot
.36004 .34627 Mdot
.4881 .30308 Mdot
.5744 .30074 Mdot
.43031 .27729 Mdot
.30652 .60127 Mdot
.31903 .44102 Mdot
.70769 .4281 Mdot
.3825 .66016 Mdot
.30662 .4397 Mdot
.47032 .29692 Mdot
.30362 .42241 Mdot
.36764 .63776 Mdot
.68965 .45015 Mdot
.4344 .28815 Mdot
.44459 .69724 Mdot
.63673 .65621 Mdot
.71551 .55858 Mdot
.37067 .33864 Mdot
.6004 .6985 Mdot
.28958 .58822 Mdot
.40878 .31323 Mdot
.4981 .28862 Mdot
.47044 .71474 Mdot
.30655 .58564 Mdot
.38836 .65483 Mdot
.65325 .34983 Mdot
.56476 .71828 Mdot
.54975 .29854 Mdot
.42821 .69792 Mdot
.43353 .70069 Mdot
.55683 .71597 Mdot
.73211 .52108 Mdot
.33267 .38654 Mdot
.41793 .6847 Mdot
.37412 .63972 Mdot
.68689 .41695 Mdot
.63053 .67669 Mdot
.54436 .72053 Mdot
.71446 .52685 Mdot
.30843 .53674 Mdot
.63101 .32846 Mdot
.42532 .68712 Mdot
.55511 .27481 Mdot
.30123 .57219 Mdot
.47334 .72326 Mdot
.5869 .68732 Mdot
.69407 .42024 Mdot
.35398 .6387 Mdot
.70151 .42275 Mdot
.52001 .73263 Mdot
.70371 .57406 Mdot
.56742 .30687 Mdot
.44833 .71753 Mdot
.3174 .44451 Mdot
.35567 .34207 Mdot
.48076 .73344 Mdot
.29161 .57081 Mdot
.64657 .65489 Mdot
.30948 .44781 Mdot
.65855 .35894 Mdot
.50834 .2779 Mdot
.45541 .29434 Mdot
.61555 .30989 Mdot
.70255 .56949 Mdot
.36595 .34497 Mdot
.31028 .41689 Mdot
.6287 .66373 Mdot
.28104 .572 Mdot
.53481 .2915 Mdot
.37636 .64271 Mdot
.36126 .64657 Mdot
.3554 .3572 Mdot
.49917 .2774 Mdot
.68405 .42902 Mdot
.70983 .5689 Mdot
.69367 .54452 Mdot
.29225 .52676 Mdot
.36796 .34018 Mdot
.34729 .62218 Mdot
.39197 .67064 Mdot
.40703 .31193 Mdot
.71017 .52869 Mdot
.30666 .57362 Mdot
.29512 .43077 Mdot
.62237 .32155 Mdot
.36455 .33571 Mdot
.70573 .42976 Mdot
.37872 .32632 Mdot
.33427 .37461 Mdot
.6823 .59267 Mdot
.45182 .7161 Mdot
.65027 .34962 Mdot
.38651 .32288 Mdot
.70003 .39891 Mdot
.47864 .71607 Mdot
.28902 .47265 Mdot
.3172 .40687 Mdot
.7284 .53494 Mdot
.44045 .28421 Mdot
.30414 .58693 Mdot
.50094 .73738 Mdot
.31794 .60033 Mdot
.70628 .52968 Mdot
.41252 .29977 Mdot
.28651 .46203 Mdot
.66504 .36801 Mdot
.43785 .69511 Mdot
.30401 .57134 Mdot
.64886 .34936 Mdot
.32176 .42311 Mdot
.51145 .72169 Mdot
.54787 .71746 Mdot
.63499 .65385 Mdot
.63232 .33548 Mdot
.60019 .68956 Mdot
.40391 .68761 Mdot
.55406 .2934 Mdot
.30806 .52737 Mdot
.35271 .34586 Mdot
.5915 .71083 Mdot
.5509 .30475 Mdot
.39923 .31395 Mdot
.43997 .27269 Mdot
.32742 .38667 Mdot
.35645 .34951 Mdot
.57065 .2951 Mdot
.29403 .45691 Mdot
.34649 .35739 Mdot
.54707 .29711 Mdot
.57692 .71061 Mdot
.42638 .68906 Mdot
.63076 .66982 Mdot
.32282 .42719 Mdot
.30635 .42921 Mdot
.71915 .52147 Mdot
.68004 .61802 Mdot
.28777 .46453 Mdot
.3965 .65966 Mdot
.69095 .55002 Mdot
.65054 .36328 Mdot
.33601 .62608 Mdot
.62444 .31544 Mdot
.63154 .66216 Mdot
.50499 .29847 Mdot
.36911 .34275 Mdot
.38117 .65865 Mdot
.5256 .27498 Mdot
.33624 .62313 Mdot
.42533 .68645 Mdot
.66992 .63662 Mdot
.41569 .67995 Mdot
.45627 .71089 Mdot
.68292 .57567 Mdot
.32253 .41324 Mdot
.69106 .56271 Mdot
.65149 .35384 Mdot
.30195 .5216 Mdot
.33781 .38423 Mdot
.63013 .33176 Mdot
.39989 .67505 Mdot
.34169 .38631 Mdot
.37592 .65013 Mdot
.40615 .6719 Mdot
.5388 .73773 Mdot
.31837 .61445 Mdot
.44301 .29268 Mdot
.30404 .5969 Mdot
.70538 .45568 Mdot
.71093 .49235 Mdot
.29418 .57281 Mdot
.5705 .69522 Mdot
.60495 .68353 Mdot
.4856 .27213 Mdot
.70913 .43578 Mdot
.28282 .54036 Mdot
.6372 .33068 Mdot
.58395 .71859 Mdot
.55943 .70654 Mdot
.61569 .31704 Mdot
.36545 .63952 Mdot
.69489 .39818 Mdot
.71583 .52226 Mdot
.53069 .28963 Mdot
.6968 .39844 Mdot
.59769 .68968 Mdot
.66285 .63817 Mdot
.62428 .32842 Mdot
.41581 .68263 Mdot
.54788 .299 Mdot
.48613 .73853 Mdot
.67099 .63182 Mdot
.70397 .43204 Mdot
.46347 .72637 Mdot
.70232 .48293 Mdot
.30897 .42958 Mdot
.54023 .73485 Mdot
.2956 .56922 Mdot
.59583 .69351 Mdot
.38419 .33013 Mdot
.72345 .48749 Mdot
.69745 .40623 Mdot
.65577 .34045 Mdot
.69425 .4286 Mdot
.72248 .50724 Mdot
.6113 .31248 Mdot
.68711 .58194 Mdot
.39588 .666 Mdot
.7128 .48654 Mdot
.70178 .56358 Mdot
.64433 .35322 Mdot
.29849 .55808 Mdot
.70901 .54122 Mdot
.34208 .36937 Mdot
.45601 .70376 Mdot
.43793 .30053 Mdot
.28168 .56458 Mdot
.71632 .5405 Mdot
.29262 .56929 Mdot
.46105 .29703 Mdot
.32504 .39669 Mdot
.59095 .31138 Mdot
.54511 .28007 Mdot
.27369 .47531 Mdot
.54472 .30151 Mdot
.70034 .45418 Mdot
.37064 .33386 Mdot
.41643 .68473 Mdot
.38058 .66678 Mdot
.28078 .56349 Mdot
.69223 .44433 Mdot
.54729 .27697 Mdot
.29448 .46237 Mdot
.71278 .51634 Mdot
.66354 .36123 Mdot
.37251 .34228 Mdot
.62756 .67558 Mdot
.57411 .30266 Mdot
.32472 .42291 Mdot
.30944 .44338 Mdot
.37379 .64734 Mdot
.48341 .72603 Mdot
.30747 .54991 Mdot
.34917 .35134 Mdot
.68783 .61103 Mdot
.39642 .31057 Mdot
.39181 .67939 Mdot
.679 .61228 Mdot
.41757 .69357 Mdot
.30137 .59784 Mdot
.57717 .29984 Mdot
.70968 .42633 Mdot
.29877 .50707 Mdot
.47736 .3026 Mdot
.60781 .701 Mdot
.4678 .71791 Mdot
.6086 .68658 Mdot
.49202 .27952 Mdot
.69273 .44019 Mdot
.45273 .28844 Mdot
.55494 .2924 Mdot
.28604 .56641 Mdot
.65057 .64783 Mdot
.32313 .42935 Mdot
.42347 .29065 Mdot
.64901 .36684 Mdot
.37866 .33045 Mdot
.51407 .28224 Mdot
.31215 .44458 Mdot
.62263 .68439 Mdot
.47691 .27272 Mdot
.28704 .47601 Mdot
.72522 .52302 Mdot
.55056 .73123 Mdot
.73012 .54088 Mdot
.45261 .27677 Mdot
.32978 .61601 Mdot
.64839 .35193 Mdot
.56889 .31213 Mdot
.47106 .73277 Mdot
.33933 .62481 Mdot
.50728 .73997 Mdot
.58276 .29219 Mdot
.55268 .29502 Mdot
.63581 .34027 Mdot
.45627 .28987 Mdot
.70399 .47474 Mdot
.62744 .66793 Mdot
.46883 .27392 Mdot
.41092 .67599 Mdot
.71412 .46773 Mdot
.55342 .70831 Mdot
.45105 .27256 Mdot
.65752 .63235 Mdot
.71632 .56421 Mdot
.2815 .54558 Mdot
.50642 .73398 Mdot
.56906 .29826 Mdot
.43005 .68817 Mdot
.55784 .27324 Mdot
.46376 .29341 Mdot
.28156 .45927 Mdot
.66883 .37636 Mdot
.35997 .64203 Mdot
.39246 .6764 Mdot
.40474 .68172 Mdot
.28748 .57788 Mdot
.72552 .5295 Mdot
.49678 .71851 Mdot
.49287 .71257 Mdot
.69041 .60617 Mdot
.35599 .36334 Mdot
.30836 .60103 Mdot
.518 .71947 Mdot
.37208 .32408 Mdot
.71725 .51691 Mdot
.36334 .63254 Mdot
.58353 .30652 Mdot
.67795 .61733 Mdot
.63659 .3498 Mdot
.66361 .37556 Mdot
.40022 .31687 Mdot
.70325 .44763 Mdot
.65836 .62466 Mdot
.40589 .2916 Mdot
.73275 .52282 Mdot
.66705 .61861 Mdot
.68962 .58544 Mdot
.64113 .32596 Mdot
.34318 .63099 Mdot
.58632 .31287 Mdot
.32171 .40364 Mdot
.69514 .57567 Mdot
.71471 .47143 Mdot
.59177 .70274 Mdot
.71045 .40861 Mdot
.35606 .35609 Mdot
.69839 .56414 Mdot
.33694 .3813 Mdot
.69559 .53515 Mdot
.64436 .34975 Mdot
.54186 .29717 Mdot
.65315 .63338 Mdot
.39162 .66119 Mdot
.57708 .69929 Mdot
.294 .46324 Mdot
.62058 .68494 Mdot
.48645 .28015 Mdot
.33935 .3698 Mdot
.58916 .30031 Mdot
.68454 .57895 Mdot
.6129 .31047 Mdot
.39273 .67719 Mdot
.66937 .63398 Mdot
.45317 .71272 Mdot
.56991 .30462 Mdot
.6236 .66641 Mdot
.39792 .66379 Mdot
.64921 .63965 Mdot
.51216 .28936 Mdot
.38928 .31258 Mdot
.68517 .5944 Mdot
.38554 .32212 Mdot
.37018 .64246 Mdot
.29025 .53876 Mdot
.31319 .60792 Mdot
.48398 .72323 Mdot
.39689 .31681 Mdot
.59962 .6866 Mdot
.37791 .64309 Mdot
.57501 .71744 Mdot
.50455 .28383 Mdot
.33561 .39724 Mdot
.47545 .29561 Mdot
.68697 .58555 Mdot
.27709 .47618 Mdot
.48983 .28582 Mdot
.61148 .67957 Mdot
.30961 .43884 Mdot
.35738 .34092 Mdot
.30249 .57497 Mdot
.41355 .68722 Mdot
.34326 .62354 Mdot
.44152 .27403 Mdot
.64281 .34335 Mdot
.71269 .54811 Mdot
.62799 .33884 Mdot
.38716 .31583 Mdot
.46989 .72282 Mdot
.31843 .42062 Mdot
.52484 .29153 Mdot
.69018 .60395 Mdot
.29351 .54356 Mdot
.5882 .31409 Mdot
.64083 .64461 Mdot
.47669 .72132 Mdot
.3363 .62065 Mdot
.36044 .64066 Mdot
.33972 .36829 Mdot
.53533 .29127 Mdot
.3214 .60646 Mdot
.38586 .66252 Mdot
.42716 .30186 Mdot
.31714 .60796 Mdot
.3763 .64598 Mdot
.37752 .33338 Mdot
.44755 .69575 Mdot
.31332 .57408 Mdot
.70172 .55245 Mdot
.54479 .71758 Mdot
.30078 .49393 Mdot
.29889 .50755 Mdot
.4984 .73806 Mdot
.43733 .70481 Mdot
.34423 .35733 Mdot
.694 .42196 Mdot
.46388 .70501 Mdot
.28211 .56959 Mdot
.6905 .54523 Mdot
.70037 .56776 Mdot
.62977 .662 Mdot
.66658 .37532 Mdot
.43765 .28726 Mdot
.30384 .54839 Mdot
.33488 .37698 Mdot
.42963 .69194 Mdot
.65163 .65288 Mdot
.29565 .57748 Mdot
.65708 .36621 Mdot
.64381 .6478 Mdot
.67083 .37905 Mdot
.53614 .73017 Mdot
.58376 .31495 Mdot
.3665 .63225 Mdot
.45919 .72383 Mdot
.69614 .56042 Mdot
.57876 .2846 Mdot
.55188 .30595 Mdot
.47487 .30182 Mdot
.2871 .46159 Mdot
.71299 .48736 Mdot
.30333 .56917 Mdot
.6169 .67253 Mdot
.36317 .64293 Mdot
.34678 .62012 Mdot
.69769 .56167 Mdot
.46154 .71613 Mdot
.685 .56171 Mdot
.3433 .36979 Mdot
.34114 .62894 Mdot
.70632 .42245 Mdot
.69537 .41786 Mdot
.68935 .60079 Mdot
.35576 .33935 Mdot
.71989 .49447 Mdot
.4243 .68489 Mdot
.38991 .31306 Mdot
.32461 .61132 Mdot
.30573 .56309 Mdot
.32093 .60816 Mdot
.72173 .49117 Mdot
.61918 .67519 Mdot
.64446 .65164 Mdot
.48147 .71384 Mdot
.57326 .71873 Mdot
.55281 .29213 Mdot
.4946 .71625 Mdot
.30049 .45562 Mdot
.46935 .29532 Mdot
.45027 .72389 Mdot
.40311 .66882 Mdot
.71007 .42396 Mdot
.30204 .51614 Mdot
.61592 .32245 Mdot
.2846 .4772 Mdot
.43973 .27393 Mdot
.28587 .54643 Mdot
.70608 .46744 Mdot
.47486 .73178 Mdot
.29096 .48735 Mdot
.32788 .40621 Mdot
.36711 .64131 Mdot
.45938 .70355 Mdot
.29712 .48438 Mdot
.63339 .34277 Mdot
.46954 .30273 Mdot
.28448 .48117 Mdot
.59443 .69266 Mdot
.57572 .71705 Mdot
.39036 .67151 Mdot
.70207 .48859 Mdot
.65271 .36981 Mdot
.31127 .42505 Mdot
.38122 .32554 Mdot
.42252 .68563 Mdot
.56428 .70801 Mdot
.29931 .48784 Mdot
.29745 .4564 Mdot
.62446 .66906 Mdot
.30945 .59561 Mdot
.67149 .63077 Mdot
.53703 .72946 Mdot
.60249 .70158 Mdot
.35433 .62844 Mdot
.41021 .30895 Mdot
.65728 .34894 Mdot
.27425 .48399 Mdot
.47547 .28999 Mdot
.701 .56697 Mdot
.48179 .71452 Mdot
.69336 .43711 Mdot
.69266 .40503 Mdot
.72496 .51367 Mdot
.6289 .32386 Mdot
.72051 .46965 Mdot
.29951 .47966 Mdot
.37062 .65641 Mdot
.54263 .2909 Mdot
.72313 .4936 Mdot
.57763 .71447 Mdot
.70976 .50681 Mdot
.70042 .45807 Mdot
.58091 .71461 Mdot
.65472 .64053 Mdot
.50894 .71977 Mdot
.40944 .67523 Mdot
.30535 .59243 Mdot
.72041 .44438 Mdot
.56276 .71003 Mdot
.51362 .7391 Mdot
.38122 .66101 Mdot
.65695 .62908 Mdot
.31906 .60841 Mdot
.44514 .71088 Mdot
.36663 .64922 Mdot
.52674 .72188 Mdot
.58281 .71256 Mdot
.68681 .42364 Mdot
.59303 .31225 Mdot
.62567 .66255 Mdot
.41411 .31175 Mdot
.69971 .54111 Mdot
.2908 .51655 Mdot
.71166 .50048 Mdot
.63314 .65021 Mdot
.64113 .33613 Mdot
.69935 .40079 Mdot
.43028 .29155 Mdot
.64606 .34459 Mdot
.54832 .29915 Mdot
.66064 .62683 Mdot
.44426 .30532 Mdot
.30668 .52998 Mdot
.5768 .30348 Mdot
.63315 .66306 Mdot
.64366 .34858 Mdot
.68861 .59014 Mdot
.62424 .68233 Mdot
.52824 .72709 Mdot
.29367 .45252 Mdot
.27681 .49158 Mdot
.55858 .29245 Mdot
.29194 .55611 Mdot
.64323 .6466 Mdot
.71003 .54415 Mdot
.29305 .5483 Mdot
.72257 .55012 Mdot
.37458 .34013 Mdot
.71247 .52107 Mdot
.35753 .35679 Mdot
.71419 .41551 Mdot
.50394 .73388 Mdot
.30243 .50439 Mdot
.29599 .48774 Mdot
.57278 .70588 Mdot
.28659 .45767 Mdot
.42647 .70088 Mdot
.64627 .63855 Mdot
.39736 .66814 Mdot
.34707 .34439 Mdot
.28235 .53586 Mdot
.69483 .5663 Mdot
.33952 .38403 Mdot
.6443 .36151 Mdot
.60541 .68849 Mdot
.2795 .46628 Mdot
.66913 .63184 Mdot
.68781 .55138 Mdot
.71468 .43573 Mdot
.69294 .58254 Mdot
.38851 .31916 Mdot
.32476 .39307 Mdot
.39549 .67532 Mdot
.3364 .38696 Mdot
.55586 .2967 Mdot
.52769 .28978 Mdot
.43126 .29739 Mdot
.3391 .61808 Mdot
.47638 .28805 Mdot
.32516 .60878 Mdot
.7157 .42252 Mdot
.30451 .5365 Mdot
.39635 .67025 Mdot
.71182 .53327 Mdot
.63189 .66645 Mdot
.30373 .51513 Mdot
.30873 .59905 Mdot
.53614 .29607 Mdot
.53701 .28857 Mdot
.29326 .44004 Mdot
.58427 .71166 Mdot
.56841 .71582 Mdot
.35436 .63527 Mdot
.55928 .29046 Mdot
.66383 .63376 Mdot
.59288 .31528 Mdot
.67314 .63378 Mdot
.2826 .53448 Mdot
.49849 .29152 Mdot
.4901 .27301 Mdot
.70339 .537 Mdot
.48366 .71522 Mdot
.72732 .5175 Mdot
.5381 .72697 Mdot
.51042 .28028 Mdot
.30593 .51793 Mdot
.44875 .29207 Mdot
.58288 .2909 Mdot
.49631 .29234 Mdot
.28395 .52337 Mdot
.64232 .66557 Mdot
.65967 .34623 Mdot
.61624 .68367 Mdot
.39386 .30651 Mdot
.43009 .70489 Mdot
.29399 .47744 Mdot
.34132 .38656 Mdot
.6802 .60655 Mdot
.7187 .55337 Mdot
.30372 .5934 Mdot
.3968 .67134 Mdot
.68492 .59011 Mdot
.3955 .67065 Mdot
.3954 .67168 Mdot
.41701 .6886 Mdot
.56727 .30173 Mdot
.61925 .68115 Mdot
.39314 .6626 Mdot
.35308 .35097 Mdot
.32367 .61689 Mdot
.48524 .27396 Mdot
.69531 .55958 Mdot
.29749 .54897 Mdot
.70022 .53656 Mdot
.5823 .69826 Mdot
.63235 .31782 Mdot
.72523 .53284 Mdot
.66232 .63066 Mdot
.72131 .48871 Mdot
.5639 .31054 Mdot
.30297 .58426 Mdot
.30514 .44997 Mdot
.60999 .31655 Mdot
.35478 .35286 Mdot
.28521 .46941 Mdot
.37469 .33653 Mdot
.35976 .63164 Mdot
.70761 .43232 Mdot
.28593 .46236 Mdot
.65661 .37392 Mdot
.38902 .30844 Mdot
.54614 .73399 Mdot
.44375 .7015 Mdot
.48915 .27924 Mdot
.29797 .45013 Mdot
.59426 .694 Mdot
.62057 .67801 Mdot
.39338 .30585 Mdot
.61252 .31781 Mdot
.55953 .29726 Mdot
.30054 .55735 Mdot
.6927 .44372 Mdot
.71267 .42696 Mdot
.65192 .36504 Mdot
.52856 .27453 Mdot
.45126 .70577 Mdot
.44339 .69766 Mdot
.58298 .70423 Mdot
.43461 .70896 Mdot
.37973 .32687 Mdot
.28964 .46991 Mdot
.70076 .40869 Mdot
.64979 .63401 Mdot
.68434 .61976 Mdot
.40024 .67812 Mdot
.46522 .72185 Mdot
.43968 .28108 Mdot
.66757 .63808 Mdot
.31278 .56962 Mdot
.7124 .4902 Mdot
.45018 .69665 Mdot
.28594 .52448 Mdot
.71276 .42128 Mdot
.3552 .34385 Mdot
.64167 .34316 Mdot
.39899 .29733 Mdot
.40227 .29423 Mdot
.28764 .51185 Mdot
.70057 .54238 Mdot
.28559 .46939 Mdot
.38651 .32612 Mdot
.33246 .39392 Mdot
.31172 .59731 Mdot
.49154 .72655 Mdot
.35319 .35742 Mdot
.51226 .2862 Mdot
.66603 .36119 Mdot
.53247 .73129 Mdot
.36797 .66301 Mdot
.54569 .3032 Mdot
.37095 .64789 Mdot
.29475 .57496 Mdot
.54468 .28551 Mdot
.69753 .40209 Mdot
.30546 .58929 Mdot
.57818 .29766 Mdot
.71353 .43569 Mdot
.65858 .62947 Mdot
.57645 .71452 Mdot
.71015 .55408 Mdot
.70863 .46613 Mdot
.45241 .70693 Mdot
.40198 .31662 Mdot
.70449 .41595 Mdot
.7095 .56221 Mdot
.68228 .58952 Mdot
.40878 .29747 Mdot
.31618 .60504 Mdot
.65931 .34736 Mdot
.39205 .65874 Mdot
.50261 .29413 Mdot
.29719 .53396 Mdot
.70405 .40105 Mdot
.41096 .69049 Mdot
.43019 .69191 Mdot
.29216 .54303 Mdot
.30787 .60387 Mdot
.29279 .55314 Mdot
.54671 .30009 Mdot
.65954 .63145 Mdot
.68571 .56803 Mdot
.55669 .30796 Mdot
.28137 .55362 Mdot
.28871 .51559 Mdot
.33701 .38228 Mdot
.44958 .70334 Mdot
.29878 .59542 Mdot
.7183 .47341 Mdot
.63692 .67097 Mdot
.33305 .39336 Mdot
.32971 .619 Mdot
.34343 .3507 Mdot
.32729 .61539 Mdot
.6535 .34379 Mdot
.67801 .62474 Mdot
.30689 .56774 Mdot
.31583 .43477 Mdot
.44649 .70334 Mdot
.44379 .70769 Mdot
.28905 .54181 Mdot
.44239 .71092 Mdot
.71121 .43858 Mdot
.73094 .53054 Mdot
.29604 .54632 Mdot
.4082 .30564 Mdot
.48409 .27578 Mdot
.46261 .28362 Mdot
.38396 .66573 Mdot
.54569 .71152 Mdot
.58492 .71739 Mdot
.68604 .58682 Mdot
.5417 .29387 Mdot
.71417 .42183 Mdot
.71225 .48635 Mdot
.69708 .56899 Mdot
.38798 .31011 Mdot
.29211 .55676 Mdot
.70214 .48698 Mdot
.53932 .29631 Mdot
.56142 .29307 Mdot
.45498 .27083 Mdot
.48146 .29053 Mdot
.44792 .28283 Mdot
.71591 .53697 Mdot
.68788 .3843 Mdot
.6126 .69283 Mdot
.69336 .40428 Mdot
.36476 .32744 Mdot
.34619 .36753 Mdot
.45202 .2715 Mdot
.64598 .35615 Mdot
.70819 .47915 Mdot
.44744 .69764 Mdot
.34902 .63646 Mdot
.49073 .27761 Mdot
.28864 .57526 Mdot
.72173 .46086 Mdot
.33833 .62255 Mdot
.67111 .63901 Mdot
.66018 .36647 Mdot
.3135 .4304 Mdot
.40312 .68437 Mdot
.4732 .30096 Mdot
.3281 .61234 Mdot
.32071 .41247 Mdot
.60655 .69124 Mdot
.72212 .47532 Mdot
.65079 .34488 Mdot
.63088 .6761 Mdot
.30389 .46441 Mdot
.66175 .62101 Mdot
.54592 .28639 Mdot
.42453 .28821 Mdot
.33448 .38097 Mdot
.71916 .52269 Mdot
.49226 .7217 Mdot
.31918 .42504 Mdot
.51612 .7404 Mdot
.48381 .28346 Mdot
.30662 .58808 Mdot
.47368 .27926 Mdot
.68669 .42538 Mdot
.41715 .28962 Mdot
.40557 .68695 Mdot
.68696 .56033 Mdot
.55802 .29515 Mdot
.57053 .72047 Mdot
.34188 .38145 Mdot
.41896 .29894 Mdot
.29393 .4907 Mdot
.68117 .61636 Mdot
.62419 .66397 Mdot
.27335 .48135 Mdot
.40549 .6883 Mdot
.64655 .35967 Mdot
.68419 .56879 Mdot
.64602 .36357 Mdot
.31609 .60886 Mdot
.60916 .31651 Mdot
.64085 .34203 Mdot
.55592 .70342 Mdot
.30318 .58722 Mdot
.46587 .72146 Mdot
.40291 .66945 Mdot
.66162 .3728 Mdot
.60652 .68595 Mdot
.68289 .5913 Mdot
.60926 .68051 Mdot
.50351 .71872 Mdot
.64892 .3623 Mdot
.31262 .41402 Mdot
.62359 .67781 Mdot
.31707 .61038 Mdot
.57098 .29563 Mdot
.54705 .71805 Mdot
.29011 .47147 Mdot
.28465 .54609 Mdot
.29588 .5868 Mdot
.28736 .55799 Mdot
.40608 .68102 Mdot
.47112 .72783 Mdot
.29965 .50492 Mdot
.61097 .3115 Mdot
.29418 .51393 Mdot
.3116 .53119 Mdot
.59698 .30944 Mdot
.3069 .60167 Mdot
.37676 .64225 Mdot
.67466 .63161 Mdot
.67817 .62323 Mdot
.44473 .30006 Mdot
.60533 .31616 Mdot
.34415 .36142 Mdot
.34563 .6202 Mdot
.68187 .38104 Mdot
.70126 .56079 Mdot
.28017 .50649 Mdot
.48472 .70843 Mdot
.63531 .65043 Mdot
.70312 .56732 Mdot
.58805 .70189 Mdot
.71144 .5202 Mdot
.29701 .47579 Mdot
.40127 .68587 Mdot
.69846 .55294 Mdot
.72566 .50123 Mdot
.44114 .71065 Mdot
.71207 .51723 Mdot
.71511 .41377 Mdot
.54312 .29576 Mdot
.64756 .33702 Mdot
.64728 .36054 Mdot
.4869 .29507 Mdot
.69545 .41285 Mdot
.47109 .70729 Mdot
.47908 .30003 Mdot
.36448 .63969 Mdot
.65008 .36337 Mdot
.51071 .74101 Mdot
.69504 .41701 Mdot
.38406 .64746 Mdot
.56005 .70142 Mdot
.37764 .33488 Mdot
.29127 .54303 Mdot
.71402 .56371 Mdot
.33295 .3809 Mdot
.57513 .30178 Mdot
.69302 .39284 Mdot
.30816 .52199 Mdot
.67488 .61169 Mdot
.34345 .61944 Mdot
.43351 .71117 Mdot
.67354 .61261 Mdot
.63466 .66895 Mdot
.32286 .40799 Mdot
.47871 .3022 Mdot
.40655 .29401 Mdot
.45959 .70787 Mdot
.69719 .41789 Mdot
.31519 .58406 Mdot
.29805 .4988 Mdot
.27495 .49686 Mdot
.59739 .68636 Mdot
.493 .7127 Mdot
.5334 .73935 Mdot
.48611 .71697 Mdot
.43995 .29704 Mdot
.33407 .39767 Mdot
.59365 .70067 Mdot
.28723 .56633 Mdot
.46723 .70376 Mdot
.69561 .55672 Mdot
.71257 .40523 Mdot
.44464 .27996 Mdot
.58674 .30073 Mdot
.28036 .48585 Mdot
.47728 .27293 Mdot
.45899 .70705 Mdot
.68622 .61114 Mdot
.5451 .28195 Mdot
.6974 .45876 Mdot
.28968 .52968 Mdot
.47429 .29884 Mdot
.30037 .52319 Mdot
.69355 .4255 Mdot
.70441 .40137 Mdot
.46516 .71567 Mdot
.30852 .40733 Mdot
.42077 .29086 Mdot
.39168 .67188 Mdot
.49104 .28007 Mdot
.3628 .35229 Mdot
.59084 .31263 Mdot
.4659 .70635 Mdot
.61999 .67024 Mdot
.63609 .35089 Mdot
.38353 .67354 Mdot
.67433 .61988 Mdot
.64598 .64793 Mdot
.40257 .30699 Mdot
.30175 .49757 Mdot
.28736 .53141 Mdot
.6903 .3926 Mdot
.6747 .37766 Mdot
.53835 .7348 Mdot
.41072 .29847 Mdot
.63817 .66144 Mdot
.63693 .33737 Mdot
.71736 .4308 Mdot
.67259 .37253 Mdot
.64307 .35147 Mdot
.4493 .70162 Mdot
.29494 .57302 Mdot
.70881 .46137 Mdot
.33613 .39114 Mdot
.56378 .72445 Mdot
.29498 .49059 Mdot
.33325 .38635 Mdot
.28888 .47615 Mdot
.64958 .32962 Mdot
.45522 .27848 Mdot
.70552 .51383 Mdot
.65815 .37244 Mdot
.63781 .33555 Mdot
.33029 .37651 Mdot
.71518 .55852 Mdot
.69092 .58991 Mdot
.72087 .47026 Mdot
.35485 .35328 Mdot
.29415 .56302 Mdot
.59722 .68432 Mdot
.46347 .28448 Mdot
.34338 .37424 Mdot
.52345 .28335 Mdot
.52995 .29187 Mdot
.68383 .43416 Mdot
.43345 .68773 Mdot
.68371 .58865 Mdot
.36908 .63675 Mdot
.49293 .72661 Mdot
.6565 .36329 Mdot
.71695 .42687 Mdot
.55689 .27925 Mdot
.46761 .71181 Mdot
.51028 .72701 Mdot
.38355 .3146 Mdot
.29668 .46205 Mdot
.50771 .28206 Mdot
.47818 .71526 Mdot
.48733 .28929 Mdot
.72445 .55403 Mdot
.31849 .43887 Mdot
.56214 .70739 Mdot
.53498 .28242 Mdot
.31628 .42149 Mdot
.31046 .45595 Mdot
.34356 .62203 Mdot
.70886 .52385 Mdot
.68958 .40684 Mdot
.31475 .60386 Mdot
.57702 .28897 Mdot
.57771 .29513 Mdot
.67016 .37355 Mdot
.45116 .7021 Mdot
.53052 .28075 Mdot
.33929 .38665 Mdot
.37866 .66969 Mdot
.65581 .62821 Mdot
.72297 .53262 Mdot
.52863 .73922 Mdot
.63613 .65525 Mdot
.64776 .35303 Mdot
.28587 .51212 Mdot
.53749 .73404 Mdot
.46114 .27551 Mdot
.69854 .46844 Mdot
.71518 .5254 Mdot
.31023 .5766 Mdot
.56688 .3073 Mdot
.33723 .61531 Mdot
.71743 .4359 Mdot
.44582 .69362 Mdot
.63632 .33972 Mdot
.31578 .42785 Mdot
.29098 .45374 Mdot
.28267 .50926 Mdot
.71947 .44011 Mdot
.31562 .43246 Mdot
.72554 .51024 Mdot
.58565 .7011 Mdot
.48895 .72522 Mdot
.62753 .32668 Mdot
.29492 .56557 Mdot
.34134 .3836 Mdot
.37112 .34633 Mdot
.58511 .71048 Mdot
.48117 .72412 Mdot
.60477 .30915 Mdot
.2981 .57087 Mdot
.40176 .67635 Mdot
.32526 .40631 Mdot
.55032 .70663 Mdot
.33261 .61618 Mdot
.2821 .47057 Mdot
.68257 .62758 Mdot
.70412 .45635 Mdot
.28527 .45942 Mdot
.71124 .40218 Mdot
.40179 .67922 Mdot
.60397 .69007 Mdot
.68799 .41565 Mdot
.71652 .46877 Mdot
.28863 .4885 Mdot
.58368 .3046 Mdot
.60116 .6874 Mdot
.37732 .64099 Mdot
.55063 .71022 Mdot
.30664 .43378 Mdot
.61123 .31707 Mdot
.50483 .2905 Mdot
.36985 .33069 Mdot
.38862 .32444 Mdot
.51602 .28359 Mdot
.59669 .31221 Mdot
.42027 .68429 Mdot
.62867 .66929 Mdot
.54779 .71137 Mdot
.62003 .31556 Mdot
.63947 .66864 Mdot
.39166 .66116 Mdot
.36638 .64449 Mdot
.49241 .2804 Mdot
.65094 .33533 Mdot
.62965 .66212 Mdot
.59644 .69716 Mdot
.28104 .5458 Mdot
.69562 .40116 Mdot
.3825 .64967 Mdot
.60504 .30776 Mdot
.40078 .30618 Mdot
.60073 .30641 Mdot
.37474 .64291 Mdot
.29735 .46142 Mdot
.55523 .28041 Mdot
.55632 .29811 Mdot
.42074 .30531 Mdot
.42274 .30444 Mdot
.37524 .6405 Mdot
.61985 .32781 Mdot
.63355 .67065 Mdot
.61215 .68106 Mdot
.30235 .44488 Mdot
.30907 .55874 Mdot
.42834 .70344 Mdot
.69228 .5899 Mdot
.33289 .38789 Mdot
.38878 .67003 Mdot
.69196 .42933 Mdot
.44455 .28678 Mdot
.37598 .33983 Mdot
.70854 .41531 Mdot
.37121 .34058 Mdot
.60628 .31596 Mdot
.50865 .74173 Mdot
.31388 .58943 Mdot
.69268 .59826 Mdot
.30051 .50833 Mdot
.31236 .42501 Mdot
.44774 .70142 Mdot
.39394 .31842 Mdot
.3897 .32688 Mdot
.68043 .60158 Mdot
.65186 .34927 Mdot
.32226 .40283 Mdot
.66174 .63378 Mdot
.28607 .52525 Mdot
.46829 .29359 Mdot
.29221 .43761 Mdot
.46251 .70285 Mdot
.70201 .5367 Mdot
.63737 .6593 Mdot
.27969 .46074 Mdot
.30554 .43138 Mdot
.27639 .47625 Mdot
.57871 .29829 Mdot
.69803 .57657 Mdot
.52467 .28585 Mdot
.3795 .33904 Mdot
.61679 .68938 Mdot
.49865 .72118 Mdot
.71337 .41802 Mdot
.37244 .66246 Mdot
.62358 .33225 Mdot
.71911 .46559 Mdot
.29459 .55686 Mdot
.30047 .47271 Mdot
.55959 .27695 Mdot
.34136 .3872 Mdot
.68285 .60843 Mdot
.68781 .62063 Mdot
.69386 .56032 Mdot
.66878 .37304 Mdot
.45658 .72832 Mdot
.42615 .27815 Mdot
.28983 .52787 Mdot
.5412 .29667 Mdot
.67648 .61227 Mdot
.40666 .67467 Mdot
.29622 .56828 Mdot
.53867 .29821 Mdot
.27378 .49125 Mdot
.61791 .32549 Mdot
.29186 .49644 Mdot
.68208 .59848 Mdot
.37459 .64637 Mdot
.29652 .46451 Mdot
.70629 .55926 Mdot
.54556 .29438 Mdot
.72009 .53617 Mdot
.29837 .47374 Mdot
.36544 .35155 Mdot
.53893 .29464 Mdot
.48414 .71362 Mdot
.70808 .50647 Mdot
.68674 .3846 Mdot
.69176 .57926 Mdot
.34109 .37802 Mdot
.34543 .3645 Mdot
.44657 .28159 Mdot
.64416 .35458 Mdot
.50011 .29794 Mdot
.30211 .58737 Mdot
.59043 .68717 Mdot
.42445 .30253 Mdot
.70505 .5703 Mdot
.49123 .30023 Mdot
.56873 .69901 Mdot
.58339 .31225 Mdot
.48951 .27635 Mdot
.36846 .65577 Mdot
.66827 .62329 Mdot
.30181 .43457 Mdot
.31991 .605 Mdot
.58791 .69903 Mdot
.48267 .70973 Mdot
.30676 .4519 Mdot
.37819 .64357 Mdot
.6243 .33452 Mdot
.52537 .71568 Mdot
.59377 .70835 Mdot
.3691 .34552 Mdot
.71897 .45793 Mdot
.40355 .29627 Mdot
.29139 .50956 Mdot
.38463 .67123 Mdot
.38215 .64649 Mdot
.657 .64241 Mdot
.72095 .46155 Mdot
.56461 .3012 Mdot
.61219 .69422 Mdot
.36088 .34729 Mdot
.68893 .55569 Mdot
.6904 .55833 Mdot
.50414 .72682 Mdot
.29328 .46852 Mdot
.66341 .36146 Mdot
.40637 .68461 Mdot
.3246 .3997 Mdot
.4919 .71326 Mdot
.51178 .27909 Mdot
.34281 .36569 Mdot
.38554 .33439 Mdot
.7022 .52236 Mdot
.48699 .27722 Mdot
.65946 .64106 Mdot
.3137 .43182 Mdot
.38982 .32381 Mdot
.56848 .30233 Mdot
.292 .52294 Mdot
.36804 .64961 Mdot
.45347 .71654 Mdot
.49343 .27907 Mdot
.45498 .3051 Mdot
.62884 .67221 Mdot
.60266 .30659 Mdot
.29884 .41683 Mdot
.54774 .28968 Mdot
.69449 .55628 Mdot
.47353 .73528 Mdot
.34652 .63232 Mdot
.63336 .32951 Mdot
.67587 .61324 Mdot
.46659 .2736 Mdot
.28935 .5064 Mdot
.69897 .56972 Mdot
.29189 .52392 Mdot
.36251 .65147 Mdot
.69246 .56529 Mdot
.36788 .3356 Mdot
.68354 .57591 Mdot
.28873 .46456 Mdot
.57705 .31291 Mdot
.45881 .29626 Mdot
.65494 .34007 Mdot
.62393 .66878 Mdot
.29404 .56035 Mdot
.51091 .73268 Mdot
.66742 .64076 Mdot
.72483 .53602 Mdot
.65553 .6358 Mdot
.27387 .4748 Mdot
.65938 .62968 Mdot
.693 .55021 Mdot
.39939 .66429 Mdot
.35388 .624 Mdot
.35629 .36126 Mdot
.36811 .64186 Mdot
.42694 .69114 Mdot
.56018 .7012 Mdot
.38267 .6667 Mdot
.39563 .67262 Mdot
.46589 .70763 Mdot
.6968 .4451 Mdot
.50618 .72073 Mdot
.6895 .44941 Mdot
.68401 .42243 Mdot
.3798 .33708 Mdot
.28482 .52813 Mdot
.31175 .60392 Mdot
.52531 .72757 Mdot
.45794 .71871 Mdot
.71891 .55098 Mdot
.70349 .48757 Mdot
.55624 .29542 Mdot
.603 .69993 Mdot
.34592 .37509 Mdot
.46533 .72443 Mdot
.44164 .30003 Mdot
.40589 .30502 Mdot
.36739 .63513 Mdot
.33838 .62388 Mdot
.43505 .70334 Mdot
.57109 .70274 Mdot
.40355 .67341 Mdot
.47779 .7181 Mdot
.40873 .2947 Mdot
.5018 .73321 Mdot
.64207 .65227 Mdot
.69778 .53259 Mdot
.29591 .52117 Mdot
.28548 .46634 Mdot
.6038 .69012 Mdot
.48779 .73712 Mdot
.71871 .52024 Mdot
.65269 .64476 Mdot
.46283 .29966 Mdot
.70255 .40387 Mdot
.57276 .70512 Mdot
.57938 .30426 Mdot
.56241 .72539 Mdot
.608 .3128 Mdot
.56604 .29105 Mdot
.28526 .54176 Mdot
.42736 .29066 Mdot
.3711 .66553 Mdot
.4835 .30264 Mdot
.4629 .70727 Mdot
.628 .67528 Mdot
.3134 .58423 Mdot
.71417 .54201 Mdot
.53542 .28293 Mdot
.70428 .44968 Mdot
.68998 .58979 Mdot
.52748 .71525 Mdot
.50339 .27994 Mdot
.42025 .28798 Mdot
.29665 .42541 Mdot
.72405 .51434 Mdot
.42509 .68948 Mdot
.71542 .48572 Mdot
.70626 .43368 Mdot
.70858 .52945 Mdot
.52462 .71778 Mdot
.54875 .72614 Mdot
.45797 .70196 Mdot
.7043 .55931 Mdot
.42848 .28809 Mdot
.31367 .59603 Mdot
.45398 .70939 Mdot
.31318 .43131 Mdot
.70295 .5208 Mdot
.45628 .27494 Mdot
.50901 .73427 Mdot
.48527 .29 Mdot
.69035 .57047 Mdot
.39745 .30276 Mdot
.59193 .31403 Mdot
.42449 .30194 Mdot
.44164 .71731 Mdot
.40355 .67144 Mdot
.69188 .55162 Mdot
.70388 .40142 Mdot
.67717 .61128 Mdot
.37488 .66174 Mdot
.7183 .49606 Mdot
.39874 .31526 Mdot
.7004 .48279 Mdot
.64272 .64674 Mdot
.43334 .69736 Mdot
.29836 .50746 Mdot
.61589 .69237 Mdot
.53401 .71847 Mdot
.59234 .70954 Mdot
.29122 .55947 Mdot
.62312 .67125 Mdot
.50921 .73814 Mdot
.43166 .70168 Mdot
.36103 .3453 Mdot
.35984 .64345 Mdot
.31966 .43744 Mdot
.64106 .64175 Mdot
.56156 .72842 Mdot
.6651 .61965 Mdot
.70494 .56736 Mdot
.68748 .56796 Mdot
.39794 .31436 Mdot
.7 .56676 Mdot
.31758 .42991 Mdot
.66301 .36118 Mdot
.69253 .58786 Mdot
.33343 .39771 Mdot
.31915 .4171 Mdot
.29928 .48003 Mdot
.28131 .47315 Mdot
.30285 .41217 Mdot
.33116 .37804 Mdot
.313 .42057 Mdot
.7217 .50617 Mdot
.36884 .32956 Mdot
.3077 .52332 Mdot
.66355 .36253 Mdot
.31522 .44759 Mdot
.35886 .64206 Mdot
.64667 .64522 Mdot
.69666 .39093 Mdot
.51475 .28322 Mdot
.27606 .48164 Mdot
.43372 .69923 Mdot
.71205 .50831 Mdot
.38365 .65139 Mdot
.29601 .50562 Mdot
.69483 .41868 Mdot
.47915 .29647 Mdot
.3126 .57796 Mdot
.28962 .47953 Mdot
.29504 .54808 Mdot
.48397 .28045 Mdot
.61145 .30845 Mdot
.35683 .64163 Mdot
.34068 .38487 Mdot
.28598 .57551 Mdot
.35844 .64298 Mdot
.72031 .50641 Mdot
.27901 .48637 Mdot
.42972 .6873 Mdot
.66158 .6363 Mdot
.71242 .44206 Mdot
.56023 .27494 Mdot
.36887 .6625 Mdot
.6883 .61775 Mdot
.70036 .52676 Mdot
.30731 .41595 Mdot
.48333 .29732 Mdot
.4132 .69072 Mdot
.65775 .3592 Mdot
.64944 .364 Mdot
.36372 .34004 Mdot
.69839 .39416 Mdot
.505 .29834 Mdot
.45122 .72404 Mdot
.3105 .45507 Mdot
.41222 .68876 Mdot
.36825 .32505 Mdot
.60558 .31845 Mdot
.71093 .46063 Mdot
.38204 .33615 Mdot
.54929 .72979 Mdot
.66665 .37143 Mdot
.37028 .34352 Mdot
.69583 .5367 Mdot
.69177 .41642 Mdot
.70692 .41255 Mdot
.31124 .56191 Mdot
.47845 .28981 Mdot
.68688 .41805 Mdot
.69948 .45494 Mdot
.64529 .64749 Mdot
.36465 .63511 Mdot
.69755 .55512 Mdot
.35201 .35532 Mdot
.29379 .51844 Mdot
.36592 .3416 Mdot
.33928 .38282 Mdot
.54065 .29087 Mdot
.56741 .69858 Mdot
.58076 .71241 Mdot
.34414 .63134 Mdot
.48497 .71444 Mdot
.40565 .68151 Mdot
.71519 .55607 Mdot
.31986 .61437 Mdot
.30983 .54671 Mdot
.72052 .50505 Mdot
.70814 .46431 Mdot
.30578 .55476 Mdot
.46886 .72643 Mdot
.41637 .6828 Mdot
.55083 .73021 Mdot
.68405 .58465 Mdot
.72856 .51692 Mdot
.65325 .35599 Mdot
.69958 .52641 Mdot
.34789 .3495 Mdot
.44817 .27284 Mdot
.41759 .29838 Mdot
.5497 .2978 Mdot
.36139 .65298 Mdot
.41699 .2888 Mdot
.67243 .63111 Mdot
.34374 .3549 Mdot
.67839 .61686 Mdot
.40095 .31851 Mdot
.37534 .66337 Mdot
.52239 .27434 Mdot
.65398 .33578 Mdot
.64495 .63871 Mdot
.48302 .73273 Mdot
.28841 .53717 Mdot
.71474 .55759 Mdot
.62243 .32639 Mdot
.69654 .58015 Mdot
.37643 .64454 Mdot
.70529 .54461 Mdot
.53896 .28415 Mdot
.60917 .31218 Mdot
.63594 .6521 Mdot
.67045 .63043 Mdot
.68312 .58976 Mdot
.72442 .49118 Mdot
.48532 .29618 Mdot
.70982 .5258 Mdot
.68816 .43335 Mdot
.66807 .62222 Mdot
.4763 .27403 Mdot
.56558 .71883 Mdot
.71459 .54917 Mdot
.3163 .59474 Mdot
.69407 .42352 Mdot
.30416 .55041 Mdot
.68812 .40747 Mdot
.34559 .36968 Mdot
.39622 .67931 Mdot
.37895 .33654 Mdot
.29042 .57665 Mdot
.41632 .28397 Mdot
.61732 .31521 Mdot
.31302 .44441 Mdot
.63863 .35415 Mdot
.57775 .69602 Mdot
.6912 .58368 Mdot
.65442 .34461 Mdot
.56569 .71927 Mdot
.41135 .68342 Mdot
.68844 .40562 Mdot
.46751 .29812 Mdot
.37369 .33256 Mdot
.58427 .69729 Mdot
.71826 .43758 Mdot
.4176 .31012 Mdot
.64527 .65817 Mdot
.36245 .33622 Mdot
.6457 .63647 Mdot
.67183 .37173 Mdot
.68603 .5735 Mdot
.37533 .33063 Mdot
.57176 .70005 Mdot
.69287 .44896 Mdot
.4315 .28037 Mdot
.61939 .32882 Mdot
.65687 .35624 Mdot
.42865 .70689 Mdot
.66627 .36245 Mdot
.44756 .30039 Mdot
.60112 .30603 Mdot
.68752 .42283 Mdot
.60117 .31062 Mdot
.2914 .5548 Mdot
.43376 .28759 Mdot
.30331 .44279 Mdot
.6341 .66488 Mdot
.49926 .29462 Mdot
.34082 .62685 Mdot
.3385 .37936 Mdot
.36509 .33058 Mdot
.69425 .41415 Mdot
.71945 .43734 Mdot
.66164 .64719 Mdot
.58732 .6973 Mdot
.46531 .29389 Mdot
.35511 .34143 Mdot
.50062 .71622 Mdot
.30853 .45366 Mdot
.36841 .33377 Mdot
.47404 .70857 Mdot
.65778 .63617 Mdot
.5515 .29211 Mdot
.50726 .72534 Mdot
.69764 .46273 Mdot
.48145 .72167 Mdot
.62683 .33688 Mdot
.38631 .31044 Mdot
.37723 .64386 Mdot
.28752 .53404 Mdot
.65206 .36955 Mdot
.6499 .36685 Mdot
.48995 .27418 Mdot
.69925 .39372 Mdot
.72248 .54228 Mdot
.48243 .29126 Mdot
.66661 .62595 Mdot
.30773 .44645 Mdot
.45744 .70071 Mdot
.71136 .53417 Mdot
.69685 .57942 Mdot
.43314 .28769 Mdot
.50682 .73934 Mdot
.63409 .3411 Mdot
.36234 .33195 Mdot
.68078 .61263 Mdot
.42012 .29715 Mdot
.28156 .51802 Mdot
.4681 .27096 Mdot
.72569 .50705 Mdot
.28096 .50409 Mdot
.7065 .54123 Mdot
.31303 .4171 Mdot
.28272 .5219 Mdot
.28473 .54318 Mdot
.40585 .29827 Mdot
.72042 .45465 Mdot
.38165 .33329 Mdot
.38596 .6704 Mdot
.44767 .69574 Mdot
.49913 .28597 Mdot
.29636 .56323 Mdot
.32769 .62018 Mdot
.31225 .54391 Mdot
.69925 .4012 Mdot
.63623 .64765 Mdot
.33663 .38069 Mdot
.3387 .37793 Mdot
.54932 .28296 Mdot
.71214 .51202 Mdot
.32061 .41502 Mdot
.61743 .3114 Mdot
.6443 .36355 Mdot
.30208 .56239 Mdot
.35515 .36468 Mdot
.70268 .53866 Mdot
.63242 .31941 Mdot
.69301 .45024 Mdot
.42055 .6873 Mdot
.2792 .46413 Mdot
.3469 .37846 Mdot
.31904 .41026 Mdot
.58993 .70123 Mdot
.65495 .34077 Mdot
.38869 .66182 Mdot
.2901 .51618 Mdot
.55029 .29632 Mdot
.30105 .51057 Mdot
.68036 .61147 Mdot
.38823 .31011 Mdot
.67564 .37483 Mdot
.43356 .71194 Mdot
.3595 .64881 Mdot
.53788 .29082 Mdot
.47109 .72875 Mdot
.6969 .53793 Mdot
.69197 .43942 Mdot
.45346 .27924 Mdot
.52585 .71733 Mdot
.45427 .71332 Mdot
.44915 .70819 Mdot
.4937 .28791 Mdot
.28821 .47127 Mdot
.33747 .36781 Mdot
.44508 .70578 Mdot
.65002 .35534 Mdot
.66661 .61889 Mdot
.66579 .37676 Mdot
.447 .72026 Mdot
.39116 .67713 Mdot
.67258 .62876 Mdot
.65203 .63628 Mdot
.63967 .35514 Mdot
.28623 .47427 Mdot
.28831 .48554 Mdot
.70564 .569 Mdot
.368 .65394 Mdot
.52735 .72493 Mdot
.40581 .68503 Mdot
.28787 .53862 Mdot
.58292 .71975 Mdot
.57433 .69442 Mdot
.61396 .68188 Mdot
.54218 .73239 Mdot
.39868 .67126 Mdot
.5375 .2866 Mdot
.71313 .46793 Mdot
.6329 .33695 Mdot
.50494 .27767 Mdot
.42453 .30871 Mdot
.30052 .51361 Mdot
.37457 .64028 Mdot
.30766 .57967 Mdot
.51521 .71896 Mdot
.28824 .58559 Mdot
.59963 .69546 Mdot
.62311 .6747 Mdot
.31388 .56878 Mdot
.40433 .68726 Mdot
.48306 .27876 Mdot
.44477 .27126 Mdot
.67817 .62434 Mdot
.44053 .71571 Mdot
.56283 .28533 Mdot
.6623 .37129 Mdot
.34194 .36872 Mdot
.34336 .35907 Mdot
.29701 .5038 Mdot
.30009 .48656 Mdot
.65945 .62887 Mdot
.40938 .67691 Mdot
.29187 .47439 Mdot
.51159 .29459 Mdot
.31493 .4164 Mdot
.35402 .36147 Mdot
.62275 .32487 Mdot
.64789 .34064 Mdot
.36111 .63787 Mdot
.33714 .62667 Mdot
.70596 .43944 Mdot
.71968 .43217 Mdot
.66212 .37613 Mdot
.40374 .29618 Mdot
.28764 .45733 Mdot
.71641 .47939 Mdot
.70722 .51725 Mdot
.29221 .58195 Mdot
.41462 .69038 Mdot
.43748 .27582 Mdot
.71225 .50314 Mdot
.28212 .56288 Mdot
.56667 .71737 Mdot
.36099 .33466 Mdot
.38079 .65427 Mdot
.68543 .62638 Mdot
.70743 .47104 Mdot
.59289 .69377 Mdot
.71502 .54701 Mdot
.65594 .36273 Mdot
.62595 .3186 Mdot
.387 .67532 Mdot
.67712 .38293 Mdot
.72573 .5514 Mdot
.63683 .32341 Mdot
.31245 .56496 Mdot
.30863 .43987 Mdot
.30181 .50585 Mdot
.45546 .27668 Mdot
.286 .53779 Mdot
.49626 .29711 Mdot
.368 .34448 Mdot
.70016 .55112 Mdot
.29646 .56888 Mdot
.56141 .70157 Mdot
.30934 .43448 Mdot
.29404 .50471 Mdot
.61024 .68779 Mdot
.69087 .60901 Mdot
.44911 .29441 Mdot
.3062 .58307 Mdot
.34472 .62287 Mdot
.59165 .3004 Mdot
.57948 .31348 Mdot
.61823 .31818 Mdot
.28751 .46364 Mdot
.43009 .29194 Mdot
.70956 .53176 Mdot
.49635 .71559 Mdot
.73217 .52254 Mdot
.42724 .6856 Mdot
.37317 .65478 Mdot
.72916 .53876 Mdot
.71033 .53147 Mdot
.38566 .67569 Mdot
.48517 .71565 Mdot
.31255 .43476 Mdot
.65533 .36768 Mdot
.69552 .41014 Mdot
.69768 .41273 Mdot
.4539 .30371 Mdot
.69098 .55055 Mdot
.29798 .41926 Mdot
.61924 .31726 Mdot
.33837 .38932 Mdot
.6402 .35049 Mdot
.32817 .61161 Mdot
.40198 .31484 Mdot
.71473 .47788 Mdot
.69669 .39271 Mdot
.65447 .64525 Mdot
.69795 .55339 Mdot
.29368 .55361 Mdot
.68968 .56185 Mdot
.70375 .55585 Mdot
.36494 .65045 Mdot
.28771 .4779 Mdot
.30823 .42689 Mdot
.59174 .70139 Mdot
.70575 .43804 Mdot
.39964 .67868 Mdot
.61395 .68909 Mdot
.3697 .66038 Mdot
.5932 .69472 Mdot
.69052 .42979 Mdot
.48195 .73459 Mdot
.69518 .55995 Mdot
.68222 .42107 Mdot
.34889 .37472 Mdot
.30733 .43437 Mdot
.32293 .41084 Mdot
.49362 .27353 Mdot
.43136 .68813 Mdot
.37467 .33925 Mdot
.66267 .62897 Mdot
.30308 .46471 Mdot
.56115 .69969 Mdot
.30536 .59174 Mdot
.46403 .70861 Mdot
.29811 .4662 Mdot
.47368 .29645 Mdot
.65802 .64299 Mdot
.44733 .70128 Mdot
.28415 .46711 Mdot
.69909 .54573 Mdot
.71145 .42721 Mdot
.71283 .51429 Mdot
.3007 .55211 Mdot
.63021 .33982 Mdot
.65993 .6324 Mdot
.46052 .27712 Mdot
.37699 .33927 Mdot
.70632 .54013 Mdot
.40213 .30772 Mdot
.65526 .34943 Mdot
.44518 .70237 Mdot
.6514 .36359 Mdot
.30966 .58934 Mdot
.69557 .42131 Mdot
.6652 .63367 Mdot
.62707 .65961 Mdot
.68731 .56753 Mdot
.31687 .43621 Mdot
.3062 .53082 Mdot
.38935 .30607 Mdot
.71435 .45007 Mdot
.62616 .33247 Mdot
.43897 .3044 Mdot
.66737 .63537 Mdot
.2943 .59455 Mdot
.5193 .73217 Mdot
.36864 .63714 Mdot
.62225 .67121 Mdot
.36777 .63286 Mdot
.37908 .34022 Mdot
.71031 .56454 Mdot
.65179 .63135 Mdot
.61357 .67876 Mdot
.33372 .62278 Mdot
.30461 .51147 Mdot
.39378 .66084 Mdot
.55267 .70756 Mdot
.44919 .71771 Mdot
.71609 .47008 Mdot
.58859 .69463 Mdot
.37867 .32141 Mdot
.33908 .3848 Mdot
.50489 .27774 Mdot
.3054 .45537 Mdot
.39032 .30948 Mdot
.47952 .71279 Mdot
.51889 .73808 Mdot
.69475 .47101 Mdot
.6865 .60892 Mdot
.63485 .33221 Mdot
.49077 .73727 Mdot
.46406 .29998 Mdot
.39103 .32632 Mdot
.44946 .72754 Mdot
.69973 .53226 Mdot
.57585 .28522 Mdot
.29463 .47331 Mdot
.32445 .40848 Mdot
.28986 .57685 Mdot
.38853 .3158 Mdot
.28169 .5114 Mdot
.63565 .34351 Mdot
.35306 .64151 Mdot
.57336 .69494 Mdot
.54487 .27282 Mdot
.68605 .55926 Mdot
.57567 .29362 Mdot
.32852 .6116 Mdot
.38889 .66605 Mdot
.70124 .4454 Mdot
.69863 .56968 Mdot
.28354 .5708 Mdot
.36616 .3527 Mdot
.35679 .35113 Mdot
.3347 .61344 Mdot
.28569 .49375 Mdot
.50968 .29415 Mdot
.2901 .49766 Mdot
.66946 .62511 Mdot
.60442 .69053 Mdot
.58103 .31482 Mdot
.38208 .66703 Mdot
.68328 .38894 Mdot
.70628 .56718 Mdot
.40484 .67492 Mdot
.29878 .52415 Mdot
.70835 .49636 Mdot
.65338 .65011 Mdot
.3512 .63903 Mdot
.42887 .28748 Mdot
.38545 .66661 Mdot
.33676 .38364 Mdot
.329 .39688 Mdot
.35528 .63046 Mdot
.4837 .29499 Mdot
.28138 .50419 Mdot
.30218 .52887 Mdot
.68637 .58256 Mdot
.30549 .45363 Mdot
.68271 .61163 Mdot
.45456 .69828 Mdot
.31177 .56127 Mdot
.67139 .62711 Mdot
.73037 .52218 Mdot
.33122 .40586 Mdot
.41607 .29971 Mdot
.70742 .4624 Mdot
.39245 .67288 Mdot
.31147 .4377 Mdot
.40935 .67815 Mdot
.68331 .59256 Mdot
.36645 .63951 Mdot
.61275 .32015 Mdot
.70646 .47612 Mdot
.64188 .3451 Mdot
.65675 .64232 Mdot
.38003 .65506 Mdot
.29002 .49724 Mdot
.29064 .45081 Mdot
.43328 .699 Mdot
.70767 .54017 Mdot
.706 .55887 Mdot
.71025 .52096 Mdot
.44216 .30288 Mdot
.51013 .718 Mdot
.64685 .3467 Mdot
.2891 .4742 Mdot
.66696 .36557 Mdot
.5435 .71329 Mdot
.29827 .54846 Mdot
.602 .31479 Mdot
.43862 .70019 Mdot
.71652 .41838 Mdot
.41358 .67942 Mdot
.7132 .47372 Mdot
.49608 .27478 Mdot
.57338 .29156 Mdot
.70363 .42888 Mdot
.39906 .66844 Mdot
.58684 .70265 Mdot
.58678 .68709 Mdot
.64147 .32787 Mdot
.27852 .48071 Mdot
.35354 .36827 Mdot
.44292 .27539 Mdot
.28918 .58824 Mdot
.53741 .29406 Mdot
.59024 .29992 Mdot
.64269 .64671 Mdot
.71099 .44959 Mdot
.62725 .32924 Mdot
.6155 .31881 Mdot
.4511 .29895 Mdot
.6483 .64717 Mdot
.37656 .65016 Mdot
.31835 .42916 Mdot
.5741 .29932 Mdot
.4511 .71051 Mdot
.68578 .60729 Mdot
.33648 .37366 Mdot
.71548 .52434 Mdot
.55279 .27242 Mdot
.53644 .71375 Mdot
.72505 .53733 Mdot
.3633 .33571 Mdot
.68717 .42022 Mdot
.39793 .67307 Mdot
.29173 .45807 Mdot
.39811 .30702 Mdot
.44657 .69331 Mdot
.38281 .3364 Mdot
.63538 .32886 Mdot
.54958 .27463 Mdot
.55949 .71552 Mdot
.35023 .34832 Mdot
.39144 .67985 Mdot
.66144 .64602 Mdot
.28434 .56165 Mdot
.63174 .32312 Mdot
.6923 .4618 Mdot
.41845 .69301 Mdot
.4653 .30446 Mdot
.47387 .27305 Mdot
.71251 .54714 Mdot
.71118 .51431 Mdot
.72056 .45538 Mdot
.30068 .44524 Mdot
.41971 .30734 Mdot
.31087 .4372 Mdot
.34386 .62206 Mdot
.63532 .32168 Mdot
.30306 .53056 Mdot
.39656 .30343 Mdot
.55207 .3016 Mdot
.69072 .60924 Mdot
.70169 .39661 Mdot
.6406 .66305 Mdot
.6742 .63017 Mdot
.39509 .31342 Mdot
.29472 .53833 Mdot
.59814 .68864 Mdot
.63512 .65416 Mdot
.30551 .54987 Mdot
.45111 .30169 Mdot
.70926 .42835 Mdot
.69672 .57274 Mdot
.70838 .47947 Mdot
.5635 .70241 Mdot
.71616 .48914 Mdot
.49029 .72744 Mdot
.35447 .62617 Mdot
.69282 .38987 Mdot
.4869 .71143 Mdot
.61897 .31999 Mdot
.71521 .45313 Mdot
.59314 .69422 Mdot
.6799 .60841 Mdot
.48232 .72346 Mdot
.50371 .73808 Mdot
.65669 .62908 Mdot
.43127 .68797 Mdot
.72901 .52661 Mdot
.69715 .57912 Mdot
.60845 .68374 Mdot
.63571 .31897 Mdot
.29022 .5454 Mdot
.68676 .42878 Mdot
.38279 .6637 Mdot
.72988 .53422 Mdot
.61116 .6849 Mdot
.61383 .3224 Mdot
.66249 .62369 Mdot
.38682 .31103 Mdot
.50858 .72783 Mdot
.48606 .27486 Mdot
.63008 .6585 Mdot
.72957 .54204 Mdot
.5856 .31022 Mdot
.65051 .65167 Mdot
.34261 .35108 Mdot
.49404 .73883 Mdot
.29138 .45504 Mdot
.28753 .53052 Mdot
.28355 .50422 Mdot
.63377 .34881 Mdot
.43672 .69102 Mdot
.48354 .71279 Mdot
.42436 .69736 Mdot
.34311 .62012 Mdot
.30847 .43392 Mdot
.31545 .60504 Mdot
.68677 .5897 Mdot
.45535 .70356 Mdot
.41972 .28559 Mdot
.70434 .45424 Mdot
.48339 .71744 Mdot
.62228 .67351 Mdot
.68387 .6264 Mdot
.70544 .43587 Mdot
.70353 .39376 Mdot
.34507 .37578 Mdot
.29006 .56446 Mdot
.37714 .66738 Mdot
.31771 .59482 Mdot
.66226 .63156 Mdot
.64317 .35541 Mdot
.43874 .71286 Mdot
.40705 .31352 Mdot
.58175 .69587 Mdot
.44685 .3019 Mdot
.35139 .63168 Mdot
.69325 .41429 Mdot
.62563 .32004 Mdot
.36659 .3376 Mdot
.36622 .33649 Mdot
.44793 .71268 Mdot
.33972 .37765 Mdot
.30432 .55954 Mdot
.29897 .55706 Mdot
.62589 .32457 Mdot
.4041 .67685 Mdot
.58818 .69235 Mdot
.68472 .60244 Mdot
.44045 .6897 Mdot
.35324 .63922 Mdot
.56117 .30393 Mdot
.54962 .29857 Mdot
.39931 .30306 Mdot
.37679 .66903 Mdot
.46228 .71295 Mdot
.70027 .43414 Mdot
.30253 .51212 Mdot
.41009 .31013 Mdot
.28089 .5508 Mdot
.48436 .2857 Mdot
.55917 .72736 Mdot
.28069 .47754 Mdot
.29939 .55374 Mdot
.52993 .28226 Mdot
.71027 .40727 Mdot
.3147 .42922 Mdot
.4473 .29052 Mdot
.41041 .30746 Mdot
.478 .71397 Mdot
.68472 .56293 Mdot
.69048 .43505 Mdot
.30236 .5514 Mdot
.66125 .37463 Mdot
.67258 .63115 Mdot
.3214 .40864 Mdot
.32988 .61381 Mdot
.436 .3058 Mdot
.71443 .47364 Mdot
.63412 .66422 Mdot
.37177 .65059 Mdot
.7107 .42522 Mdot
.37354 .6503 Mdot
.7089 .52669 Mdot
.68537 .43062 Mdot
.45361 .7271 Mdot
.71971 .51693 Mdot
.50237 .29837 Mdot
.39754 .32097 Mdot
.66185 .621 Mdot
.59699 .31445 Mdot
.66428 .6282 Mdot
.34271 .36164 Mdot
.4224 .69249 Mdot
.45298 .69638 Mdot
.37915 .66095 Mdot
.28401 .52357 Mdot
.53809 .7325 Mdot
.30286 .42878 Mdot
.29206 .45397 Mdot
.71062 .43596 Mdot
.28299 .50631 Mdot
.59137 .69943 Mdot
.30001 .57246 Mdot
.45088 .28004 Mdot
.45339 .71576 Mdot
.29934 .545 Mdot
.69763 .57399 Mdot
.64636 .65108 Mdot
.68936 .39259 Mdot
.46713 .27032 Mdot
.29238 .46791 Mdot
.63416 .32933 Mdot
.59937 .70628 Mdot
.47204 .30103 Mdot
.56271 .29506 Mdot
.58942 .70723 Mdot
.38472 .31107 Mdot
.62483 .31281 Mdot
.39706 .32214 Mdot
.55536 .28994 Mdot
.6635 .36756 Mdot
.56894 .70472 Mdot
.30002 .57338 Mdot
.27946 .50909 Mdot
.31736 .60771 Mdot
.57997 .30035 Mdot
.40587 .31537 Mdot
.43312 .29486 Mdot
.6123 .67984 Mdot
.7125 .49606 Mdot
.3122 .45339 Mdot
.36943 .66266 Mdot
.54771 .29378 Mdot
.54359 .72625 Mdot
.28021 .50852 Mdot
.64704 .34143 Mdot
.63115 .65855 Mdot
.57073 .72171 Mdot
.29843 .45152 Mdot
.31258 .42446 Mdot
.30489 .58059 Mdot
.35763 .35524 Mdot
.68838 .41989 Mdot
.30112 .59119 Mdot
.42853 .70202 Mdot
.37802 .66565 Mdot
.63822 .35314 Mdot
.30401 .45549 Mdot
.65105 .34824 Mdot
.29947 .51937 Mdot
.31476 .60437 Mdot
.68963 .5805 Mdot
.706 .5243 Mdot
.29282 .49499 Mdot
.54547 .7345 Mdot
.5324 .73941 Mdot
.69193 .46465 Mdot
.69084 .41908 Mdot
.50493 .7409 Mdot
.31204 .54772 Mdot
.30274 .58344 Mdot
.65091 .65234 Mdot
.619 .68406 Mdot
.65113 .63493 Mdot
.56919 .71636 Mdot
.50614 .28103 Mdot
.66087 .63974 Mdot
.39028 .3079 Mdot
.56701 .71686 Mdot
.5614 .28055 Mdot
.67947 .62424 Mdot
.36921 .64424 Mdot
.46978 .28423 Mdot
.35379 .63293 Mdot
.4454 .2784 Mdot
.39665 .67711 Mdot
.36838 .32462 Mdot
.46027 .27723 Mdot
.33922 .37995 Mdot
.58003 .7178 Mdot
.30376 .42821 Mdot
.30863 .54638 Mdot
.32593 .39583 Mdot
.50832 .73296 Mdot
.70649 .42342 Mdot
.71714 .48461 Mdot
.37011 .6487 Mdot
.44547 .29852 Mdot
.643 .33359 Mdot
.63128 .66019 Mdot
.41452 .68386 Mdot
.67533 .62357 Mdot
.70218 .39631 Mdot
.43075 .28754 Mdot
.28616 .53188 Mdot
.32936 .38306 Mdot
.34547 .36024 Mdot
.40363 .31455 Mdot
.34934 .63589 Mdot
.68351 .6249 Mdot
.3352 .38492 Mdot
.7199 .532 Mdot
.32695 .61919 Mdot
.69877 .56636 Mdot
.30883 .44945 Mdot
.29404 .57879 Mdot
.54086 .71916 Mdot
.69914 .45182 Mdot
.49324 .28738 Mdot
.38213 .65551 Mdot
.28253 .47315 Mdot
.31719 .6076 Mdot
.69875 .46318 Mdot
.31228 .56263 Mdot
.45111 .28701 Mdot
.30604 .44447 Mdot
.52867 .7236 Mdot
.47527 .73465 Mdot
.6346 .67397 Mdot
.38231 .6581 Mdot
.30472 .5526 Mdot
.68634 .55476 Mdot
.67607 .62407 Mdot
.56503 .29251 Mdot
.58773 .69777 Mdot
.34677 .62437 Mdot
.34047 .35878 Mdot
.69681 .40023 Mdot
.29153 .55741 Mdot
.54773 .2929 Mdot
.28812 .56201 Mdot
.32021 .41097 Mdot
.70369 .53177 Mdot
.32278 .40882 Mdot
.6846 .60889 Mdot
.62906 .33074 Mdot
.69221 .43966 Mdot
.33369 .3722 Mdot
.28584 .49108 Mdot
.50209 .28625 Mdot
.57746 .71971 Mdot
.70999 .54488 Mdot
.56632 .30861 Mdot
.33248 .38091 Mdot
.61482 .32223 Mdot
.62668 .67785 Mdot
.65895 .37032 Mdot
.37012 .6493 Mdot
.70451 .48619 Mdot
.66707 .37171 Mdot
.36028 .34362 Mdot
.55406 .70708 Mdot
.32433 .40406 Mdot
.40856 .6849 Mdot
.60382 .31348 Mdot
.65171 .33356 Mdot
.69343 .55483 Mdot
.53323 .29093 Mdot
.42895 .70173 Mdot
.30898 .43622 Mdot
.36141 .64255 Mdot
.56866 .29031 Mdot
.54443 .2999 Mdot
.36977 .33744 Mdot
.38688 .65889 Mdot
.28662 .54349 Mdot
.38927 .31002 Mdot
.47982 .27435 Mdot
.40549 .30433 Mdot
.72664 .54172 Mdot
.28953 .48183 Mdot
.29852 .44716 Mdot
.44342 .71284 Mdot
.65521 .35342 Mdot
.302 .4305 Mdot
.45244 .69919 Mdot
.49716 .72487 Mdot
.70785 .47932 Mdot
.46016 .28725 Mdot
.34821 .62678 Mdot
.65819 .6235 Mdot
.28488 .46237 Mdot
.48015 .28978 Mdot
.70034 .54377 Mdot
.33607 .36706 Mdot
.4406 .69754 Mdot
.64517 .64166 Mdot
.6869 .57017 Mdot
.7313 .53875 Mdot
.54042 .73323 Mdot
.37318 .64887 Mdot
.64766 .36321 Mdot
.53848 .67023 Mdot
.37771 .57314 Mdot
.44447 .47639 Mdot
.30207 .471 Mdot
.59663 .56682 Mdot
.49225 .64711 Mdot
.65974 .61815 Mdot
.49324 .57975 Mdot
.53994 .70824 Mdot
.54646 .62066 Mdot
.62801 .41712 Mdot
.4677 .53981 Mdot
.46263 .31399 Mdot
.66842 .47772 Mdot
.61621 .6524 Mdot
.3351 .48716 Mdot
.66936 .52838 Mdot
.51786 .6293 Mdot
.67289 .47397 Mdot
.60435 .45727 Mdot
.56965 .33166 Mdot
.55153 .31105 Mdot
.60385 .41055 Mdot
.34016 .60976 Mdot
.55165 .64994 Mdot
.40463 .59145 Mdot
.64439 .58557 Mdot
.63538 .38533 Mdot
.65335 .62665 Mdot
.40836 .37811 Mdot
.6146 .57211 Mdot
.45236 .37758 Mdot
.46592 .66527 Mdot
.62791 .44569 Mdot
.39889 .58456 Mdot
.37797 .4304 Mdot
.527 .70391 Mdot
.54432 .58892 Mdot
.59513 .59332 Mdot
.45374 .63647 Mdot
.62195 .55402 Mdot
.46021 .30684 Mdot
.69642 .52771 Mdot
.67864 .49211 Mdot
.44881 .36036 Mdot
.6388 .54134 Mdot
.49288 .58068 Mdot
.30448 .47488 Mdot
.59795 .55986 Mdot
.44608 .68359 Mdot
.69827 .50585 Mdot
.64775 .46841 Mdot
.64463 .40381 Mdot
.47014 .65046 Mdot
.65768 .42294 Mdot
.43572 .66619 Mdot
.52263 .63206 Mdot
.49969 .65155 Mdot
.60582 .45206 Mdot
.53997 .35178 Mdot
.69301 .40227 Mdot
.33891 .4869 Mdot
.56312 .43473 Mdot
.40206 .47445 Mdot
.65395 .48706 Mdot
.49842 .68376 Mdot
.66069 .59884 Mdot
.69612 .48812 Mdot
.5886 .35487 Mdot
.44532 .34285 Mdot
.61108 .40397 Mdot
.57131 .43776 Mdot
.64154 .531 Mdot
.3792 .59881 Mdot
.58122 .61131 Mdot
.57993 .37502 Mdot
.57273 .68064 Mdot
.3636 .40181 Mdot
.54504 .52147 Mdot
.40078 .34669 Mdot
.48866 .65736 Mdot
.61462 .45838 Mdot
.44665 .56568 Mdot
.60367 .52968 Mdot
.4028 .64113 Mdot
.42058 .34529 Mdot
.55371 .64867 Mdot
.5554 .37893 Mdot
.66501 .53751 Mdot
.51988 .67585 Mdot
.6551 .43174 Mdot
.36302 .37502 Mdot
.44721 .41458 Mdot
.40345 .3615 Mdot
.49989 .57377 Mdot
.37929 .41491 Mdot
.62739 .44289 Mdot
.6749 .4404 Mdot
.531 .30498 Mdot
.62676 .60996 Mdot
.46827 .36757 Mdot
.68199 .40226 Mdot
.54595 .32434 Mdot
.49172 .60652 Mdot
.61597 .62191 Mdot
.4045 .36725 Mdot
.59525 .36262 Mdot
.59041 .52179 Mdot
.59569 .42785 Mdot
.59266 .58939 Mdot
.57147 .61813 Mdot
.67372 .52676 Mdot
.30097 .4839 Mdot
.6 .65354 Mdot
.44113 .38028 Mdot
.61262 .37623 Mdot
.34554 .43538 Mdot
.48261 .70706 Mdot
.47006 .38706 Mdot
.5501 .69773 Mdot
.50925 .47242 Mdot
.66133 .56497 Mdot
.39891 .35227 Mdot
.66873 .61413 Mdot
.55979 .67834 Mdot
.60286 .40774 Mdot
.35373 .49314 Mdot
.67623 .54303 Mdot
.67484 .46661 Mdot
.58156 .32941 Mdot
.50581 .66911 Mdot
.39607 .33987 Mdot
.35142 .55518 Mdot
.40367 .44722 Mdot
.5935 .32829 Mdot
.39304 .47082 Mdot
.43543 .44049 Mdot
.42656 .31888 Mdot
.62965 .61823 Mdot
.43327 .42378 Mdot
.57306 .68788 Mdot
.57284 .36893 Mdot
.62236 .41206 Mdot
.54839 .66342 Mdot
.31497 .51526 Mdot
.40446 .39984 Mdot
.45658 .44218 Mdot
.59697 .54431 Mdot
.67168 .60846 Mdot
.40106 .56632 Mdot
.6216 .43472 Mdot
.51689 .40549 Mdot
.5254 .35636 Mdot
.67277 .46052 Mdot
.68118 .40262 Mdot
.49766 .38199 Mdot
.42681 .55328 Mdot
.60547 .66492 Mdot
.50435 .42325 Mdot
.66202 .57613 Mdot
.48776 .41022 Mdot
.40675 .37568 Mdot
.59114 .33157 Mdot
.58942 .38088 Mdot
.64636 .52931 Mdot
.64789 .40498 Mdot
.58254 .63365 Mdot
.58952 .63218 Mdot
.49279 .36175 Mdot
.66697 .52575 Mdot
.62462 .4755 Mdot
.69469 .49819 Mdot
.51693 .61507 Mdot
.44051 .62944 Mdot
.37269 .56049 Mdot
.44113 .51803 Mdot
.31641 .56248 Mdot
.37726 .43806 Mdot
.50929 .67297 Mdot
.32077 .55393 Mdot
.37991 .50324 Mdot
.39288 .58287 Mdot
.33685 .39757 Mdot
.3612 .56057 Mdot
.44868 .68134 Mdot
.56788 .54375 Mdot
.59444 .37735 Mdot
.45985 .46041 Mdot
.36149 .5462 Mdot
.65325 .57435 Mdot
.52182 .70328 Mdot
.40134 .35223 Mdot
.46005 .33222 Mdot
.51645 .64794 Mdot
.57296 .66446 Mdot
.60663 .32777 Mdot
.65782 .39426 Mdot
.45539 .31698 Mdot
.64701 .52826 Mdot
.66299 .59336 Mdot
.36941 .35158 Mdot
.60849 .49011 Mdot
.44359 .57686 Mdot
.41306 .62161 Mdot
.4263 .35658 Mdot
.57628 .5585 Mdot
.314 .47343 Mdot
.46786 .61366 Mdot
.44114 .45784 Mdot
.39659 .39775 Mdot
.35984 .41819 Mdot
.35502 .44021 Mdot
.67571 .50248 Mdot
.36866 .44526 Mdot
.39463 .37565 Mdot
.49753 .71138 Mdot
.56662 .47593 Mdot
.63209 .64159 Mdot
.39953 .52569 Mdot
.54656 .32981 Mdot
.56196 .42091 Mdot
.56756 .61266 Mdot
.4712 .6517 Mdot
.37824 .38 Mdot
.44178 .67765 Mdot
.61728 .53529 Mdot
.43815 .3873 Mdot
.5665 .39132 Mdot
.46441 .38225 Mdot
.50078 .35538 Mdot
.52035 .57857 Mdot
.67506 .46946 Mdot
.32987 .60111 Mdot
.54559 .34947 Mdot
.63407 .57766 Mdot
.55578 .68738 Mdot
.55028 .32882 Mdot
.6084 .63454 Mdot
.60771 .60701 Mdot
.47514 .63976 Mdot
.41128 .562 Mdot
.46979 .49586 Mdot
.55076 .59154 Mdot
.39119 .43659 Mdot
.54211 .39237 Mdot
.5744 .32144 Mdot
.49057 .32121 Mdot
.46859 .48056 Mdot
.56206 .47032 Mdot
.35926 .5285 Mdot
.5887 .34831 Mdot
.5379 .55789 Mdot
.37657 .57925 Mdot
.4588 .45717 Mdot
.52559 .64196 Mdot
.66215 .58241 Mdot
.42007 .55737 Mdot
.43317 .68284 Mdot
.44295 .35536 Mdot
.4345 .31518 Mdot
.4919 .3511 Mdot
.55676 .65706 Mdot
.66492 .41249 Mdot
.65655 .5088 Mdot
.36708 .50694 Mdot
.40028 .61008 Mdot
.50571 .5423 Mdot
.43958 .65977 Mdot
.65492 .37998 Mdot
.67034 .57471 Mdot
.57273 .64098 Mdot
.33928 .60155 Mdot
.44662 .53427 Mdot
.55705 .63676 Mdot
.37844 .48742 Mdot
.54857 .6964 Mdot
.67705 .59605 Mdot
.55869 .35549 Mdot
.55528 .31271 Mdot
.32042 .49296 Mdot
.56058 .44571 Mdot
.30306 .49329 Mdot
.48619 .32892 Mdot
.59025 .53622 Mdot
.46171 .65997 Mdot
.6445 .38918 Mdot
.51946 .36474 Mdot
.479 .31234 Mdot
.50181 .35404 Mdot
.61881 .40692 Mdot
.65307 .49382 Mdot
.35739 .59355 Mdot
.62041 .58332 Mdot
.66775 .45237 Mdot
.37125 .61984 Mdot
.623 .38472 Mdot
.60635 .54599 Mdot
.6881 .51714 Mdot
.42338 .67276 Mdot
.40578 .66771 Mdot
.35883 .45432 Mdot
.36891 .59636 Mdot
.4322 .47986 Mdot
.68741 .53821 Mdot
.33389 .53322 Mdot
.62228 .5357 Mdot
.62506 .65253 Mdot
.57342 .66736 Mdot
.67292 .54369 Mdot
.55424 .6895 Mdot
.51293 .30728 Mdot
.66735 .40274 Mdot
.56213 .63276 Mdot
.3742 .50597 Mdot
.41061 .40236 Mdot
.36282 .50092 Mdot
.5817 .6602 Mdot
.41318 .5315 Mdot
.65734 .58692 Mdot
.47542 .65174 Mdot
.56069 .5069 Mdot
.63081 .61183 Mdot
.47268 .60616 Mdot
.53479 .69171 Mdot
.61032 .65782 Mdot
.46522 .34446 Mdot
.34195 .49919 Mdot
.53897 .59657 Mdot
.37677 .63414 Mdot
.49757 .46744 Mdot
.49936 .60866 Mdot
.34508 .53987 Mdot
.5242 .60319 Mdot
.33805 .61038 Mdot
.68484 .45253 Mdot
.57432 .58793 Mdot
.52556 .39996 Mdot
.33736 .5625 Mdot
.46265 .66278 Mdot
.51934 .67308 Mdot
.67309 .46425 Mdot
.33857 .50944 Mdot
.44361 .33973 Mdot
.54053 .50108 Mdot
.35973 .54111 Mdot
.46269 .42905 Mdot
.35597 .46706 Mdot
.33258 .42017 Mdot
.49712 .35735 Mdot
.60109 .56597 Mdot
.33027 .54182 Mdot
.62083 .3689 Mdot
.43885 .5097 Mdot
.44741 .57181 Mdot
.55602 .35145 Mdot
.46314 .57936 Mdot
.47137 .56403 Mdot
.47177 .45757 Mdot
.56528 .34472 Mdot
.5703 .57204 Mdot
.61405 .54696 Mdot
.67185 .60031 Mdot
.39069 .39106 Mdot
.55737 .61609 Mdot
.6084 .61165 Mdot
.53785 .39985 Mdot
.37963 .64034 Mdot
.43419 .52071 Mdot
.69707 .51082 Mdot
.5163 .43945 Mdot
.57438 .62579 Mdot
.43785 .31403 Mdot
.58294 .55328 Mdot
.46206 .46875 Mdot
.33066 .5096 Mdot
.32987 .55033 Mdot
.43314 .59271 Mdot
.39158 .36695 Mdot
.62275 .53323 Mdot
.58638 .65145 Mdot
.6232 .56112 Mdot
.40596 .62716 Mdot
.68293 .43899 Mdot
.44252 .33242 Mdot
.60781 .33208 Mdot
.65203 .57337 Mdot
.4577 .61005 Mdot
.39094 .34441 Mdot
.5571 .47875 Mdot
.61802 .49067 Mdot
.66832 .42037 Mdot
.59992 .35316 Mdot
.59056 .368 Mdot
.42258 .51624 Mdot
.64365 .4394 Mdot
.54451 .35272 Mdot
.61323 .62942 Mdot
.50769 .31042 Mdot
.54818 .36108 Mdot
.60639 .67783 Mdot
.57915 .3751 Mdot
.62668 .63434 Mdot
.65247 .4286 Mdot
.49571 .6035 Mdot
.58916 .54433 Mdot
.51747 .42223 Mdot
.59656 .65126 Mdot
.67178 .50387 Mdot
.57241 .50261 Mdot
.46734 .68749 Mdot
.53136 .68213 Mdot
.57631 .67893 Mdot
.41099 .59647 Mdot
.58584 .51902 Mdot
.33164 .54144 Mdot
.59305 .31897 Mdot
.38695 .61747 Mdot
.69332 .51143 Mdot
.49158 .70774 Mdot
.62346 .47995 Mdot
.51899 .70929 Mdot
.46814 .34772 Mdot
.62602 .47911 Mdot
.35092 .44575 Mdot
.38945 .33296 Mdot
.3398 .49734 Mdot
.57866 .60437 Mdot
.48547 .32945 Mdot
.54306 .3301 Mdot
.51271 .31742 Mdot
.35215 .42996 Mdot
.52518 .3409 Mdot
.37574 .62177 Mdot
.572 .51739 Mdot
.38488 .60053 Mdot
.35466 .49795 Mdot
.53826 .3417 Mdot
.68318 .54406 Mdot
.41796 .40342 Mdot
.49083 .62834 Mdot
.61204 .36234 Mdot
.34922 .47533 Mdot
.40946 .66977 Mdot
.50008 .43913 Mdot
.60625 .43842 Mdot
.51057 .29721 Mdot
.33914 .44456 Mdot
.55462 .66498 Mdot
.50263 .37757 Mdot
.55702 .67673 Mdot
.5976 .67848 Mdot
.6325 .42032 Mdot
.49043 .6392 Mdot
.32771 .5915 Mdot
.6424 .48489 Mdot
.39868 .3343 Mdot
.60512 .53709 Mdot
.67977 .44577 Mdot
.35689 .48678 Mdot
.48772 .35898 Mdot
.50638 .38153 Mdot
.34607 .4498 Mdot
.42327 .40357 Mdot
.42289 .41143 Mdot
.33687 .6067 Mdot
.51238 .6393 Mdot
.38097 .60637 Mdot
.39694 .39453 Mdot
.44765 .63165 Mdot
.44734 .34419 Mdot
.62284 .33624 Mdot
.60543 .4632 Mdot
.67223 .56474 Mdot
.36444 .57931 Mdot
.37087 .59017 Mdot
.52698 .36603 Mdot
.66371 .54304 Mdot
.45675 .49563 Mdot
.4586 .44424 Mdot
.6519 .41941 Mdot
.41914 .64548 Mdot
.52509 .59003 Mdot
.33921 .45849 Mdot
.43559 .68347 Mdot
.3158 .46489 Mdot
.59198 .3802 Mdot
.61856 .58393 Mdot
.58127 .5312 Mdot
.66126 .58953 Mdot
.4262 .48644 Mdot
.34561 .58674 Mdot
.39585 .38733 Mdot
.5803 .52985 Mdot
.39204 .5887 Mdot
.36441 .46996 Mdot
.60639 .61689 Mdot
.65139 .5456 Mdot
.50225 .58396 Mdot
.59074 .4591 Mdot
.49995 .71466 Mdot
.60776 .40388 Mdot
.43209 .31398 Mdot
.33254 .51542 Mdot
.6525 .53743 Mdot
.36347 .58465 Mdot
.443 .42924 Mdot
.57277 .41264 Mdot
.33425 .48021 Mdot
.58799 .34421 Mdot
.51004 .67408 Mdot
.6214 .38584 Mdot
.65722 .5521 Mdot
.6163 .48569 Mdot
.36629 .60211 Mdot
.33846 .48988 Mdot
.44643 .5915 Mdot
.55219 .52641 Mdot
.47895 .42648 Mdot
.49693 .70047 Mdot
.55349 .64613 Mdot
.413 .5661 Mdot
.68411 .47026 Mdot
.34248 .46124 Mdot
.60721 .4218 Mdot
.36298 .46214 Mdot
.33726 .4785 Mdot
.67484 .58159 Mdot
.57578 .64252 Mdot
.67676 .4496 Mdot
.36347 .54135 Mdot
.50865 .29882 Mdot
.41754 .67971 Mdot
.44445 .67599 Mdot
.47207 .59936 Mdot
.50303 .39167 Mdot
.32554 .5749 Mdot
.53445 .68804 Mdot
.59941 .41148 Mdot
.55425 .69272 Mdot
.49614 .31281 Mdot
.51766 .57361 Mdot
.49487 .65181 Mdot
.41944 .48639 Mdot
.64957 .49867 Mdot
.51579 .63887 Mdot
.45117 .37904 Mdot
.40213 .51761 Mdot
.48413 .6449 Mdot
.49021 .65365 Mdot
.43621 .56784 Mdot
.63288 .5967 Mdot
.43511 .3797 Mdot
.60328 .37172 Mdot
.32404 .5783 Mdot
.44778 .63444 Mdot
.37377 .58778 Mdot
.59308 .54269 Mdot
.47109 .37873 Mdot
.38454 .33705 Mdot
.3253 .54961 Mdot
.43382 .64316 Mdot
.66691 .57217 Mdot
.51438 .53644 Mdot
.39332 .60183 Mdot
.38723 .60632 Mdot
.66016 .48136 Mdot
.58833 .52662 Mdot
.44955 .47841 Mdot
.69388 .52865 Mdot
.63986 .37537 Mdot
.31756 .57902 Mdot
.32035 .54972 Mdot
.63788 .55797 Mdot
.42299 .58481 Mdot
.57525 .36496 Mdot
.6837 .51597 Mdot
.31182 .51314 Mdot
.62846 .51296 Mdot
.33962 .59547 Mdot
.3934 .54757 Mdot
.32747 .57748 Mdot
.37687 .42655 Mdot
.6784 .5767 Mdot
.589 .63917 Mdot
.6496 .46193 Mdot
.51862 .36726 Mdot
.55776 .54782 Mdot
.52903 .33791 Mdot
.45588 .40833 Mdot
.50072 .36976 Mdot
.48015 .63333 Mdot
.49029 .56273 Mdot
.61271 .39315 Mdot
.48518 .3314 Mdot
.61026 .37186 Mdot
.41998 .46147 Mdot
.56865 .43913 Mdot
.59031 .32845 Mdot
.50473 .43317 Mdot
.63115 .52364 Mdot
.63295 .64332 Mdot
.50279 .54661 Mdot
.5609 .34153 Mdot
.69957 .52033 Mdot
.59342 .44179 Mdot
.51287 .65181 Mdot
.64965 .57386 Mdot
.43743 .38275 Mdot
.57738 .64865 Mdot
.60761 .37927 Mdot
.37757 .59023 Mdot
.55737 .39254 Mdot
.45078 .65342 Mdot
.39432 .46774 Mdot
.32589 .42803 Mdot
.39965 .44462 Mdot
.35636 .38336 Mdot
.39281 .6435 Mdot
.38167 .49441 Mdot
.42719 .35043 Mdot
.39635 .63668 Mdot
.52262 .42356 Mdot
.61776 .45814 Mdot
.69251 .50211 Mdot
.40271 .35454 Mdot
.34526 .57541 Mdot
.60568 .64669 Mdot
.58926 .36895 Mdot
.34316 .4083 Mdot
.33506 .48884 Mdot
.66083 .54868 Mdot
.53905 .42641 Mdot
.46126 .31336 Mdot
.54497 .50244 Mdot
.49938 .32812 Mdot
.60492 .53713 Mdot
.61547 .66905 Mdot
.4052 .37352 Mdot
.62391 .46545 Mdot
.51667 .42602 Mdot
.38037 .58384 Mdot
.47474 .64942 Mdot
.35871 .61639 Mdot
.37028 .54869 Mdot
.45618 .30719 Mdot
.38536 .57378 Mdot
.62842 .43836 Mdot
.43751 .59672 Mdot
.57564 .36768 Mdot
.47419 .32204 Mdot
.56741 .42086 Mdot
.65991 .42341 Mdot
.33036 .52695 Mdot
.42419 .40856 Mdot
.62754 .64445 Mdot
.54643 .69455 Mdot
.32401 .55198 Mdot
.52806 .34167 Mdot
.34122 .49944 Mdot
.39527 .56775 Mdot
.45113 .41222 Mdot
.45585 .33685 Mdot
.51004 .45875 Mdot
.59047 .31979 Mdot
.44381 .61933 Mdot
.60158 .65137 Mdot
.52477 .66214 Mdot
.68583 .47595 Mdot
.5563 .33972 Mdot
.5613 .63242 Mdot
.49121 .57468 Mdot
.50474 .41687 Mdot
.40439 .3272 Mdot
.64306 .56535 Mdot
.63685 .36027 Mdot
.46892 .66559 Mdot
.33553 .49583 Mdot
.58413 .68064 Mdot
.49827 .6007 Mdot
.54178 .57733 Mdot
.34268 .52442 Mdot
.67984 .51554 Mdot
.5681 .64861 Mdot
.5105 .68279 Mdot
.35377 .45173 Mdot
.55634 .5984 Mdot
.47297 .32789 Mdot
.63324 .39833 Mdot
.52824 .5743 Mdot
.50523 .32429 Mdot
.69547 .48428 Mdot
.35596 .43998 Mdot
.36147 .53296 Mdot
.34079 .4069 Mdot
.41753 .67378 Mdot
.46999 .61107 Mdot
.49677 .35579 Mdot
.5556 .54654 Mdot
.67353 .541 Mdot
.51362 .66307 Mdot
.57475 .33964 Mdot
.31663 .48408 Mdot
.63507 .37807 Mdot
.61063 .44668 Mdot
.39533 .58393 Mdot
.39912 .59571 Mdot
.61503 .59916 Mdot
.59842 .54636 Mdot
.46124 .56145 Mdot
.58775 .45738 Mdot
.43442 .61775 Mdot
.45982 .33046 Mdot
.33724 .46248 Mdot
.52724 .69887 Mdot
.437 .31173 Mdot
.48 .67197 Mdot
.49206 .67623 Mdot
.59614 .41238 Mdot
.57399 .59744 Mdot
.53147 .41289 Mdot
.52175 .39441 Mdot
.684 .40103 Mdot
.32695 .54271 Mdot
.5744 .62705 Mdot
.58654 .44028 Mdot
.65522 .45712 Mdot
.50766 .61575 Mdot
.45687 .31037 Mdot
.66607 .49699 Mdot
.55842 .33066 Mdot
.57942 .37458 Mdot
.66716 .48342 Mdot
.61636 .5399 Mdot
.6248 .61665 Mdot
.3925 .40161 Mdot
.61782 .45457 Mdot
.45456 .37467 Mdot
.68138 .49961 Mdot
.42309 .5428 Mdot
.42574 .6645 Mdot
.35053 .55606 Mdot
.40572 .49435 Mdot
.41351 .43403 Mdot
.3512 .46226 Mdot
.34375 .38806 Mdot
.32066 .54989 Mdot
.65273 .43899 Mdot
.3272 .51162 Mdot
.51463 .63441 Mdot
.3142 .45934 Mdot
.53727 .39327 Mdot
.55479 .59745 Mdot
.38907 .62153 Mdot
.46621 .45213 Mdot
.5179 .3445 Mdot
.61165 .61598 Mdot
.53525 .66361 Mdot
.44903 .33894 Mdot
.4196 .67755 Mdot
.51656 .70432 Mdot
.667 .55176 Mdot
.51659 .30033 Mdot
.52285 .66605 Mdot
.33906 .43667 Mdot
.65904 .38576 Mdot
.6421 .38838 Mdot
.61809 .59465 Mdot
.5068 .37481 Mdot
.6739 .4031 Mdot
.65453 .58082 Mdot
.39627 .32564 Mdot
.63955 .37154 Mdot
.3837 .44571 Mdot
.59799 .67317 Mdot
.39246 .64119 Mdot
.41573 .4473 Mdot
.30611 .47561 Mdot
.4638 .35334 Mdot
.39347 .61405 Mdot
.60139 .45489 Mdot
.33486 .51395 Mdot
.61684 .3913 Mdot
.62798 .38513 Mdot
.67146 .53483 Mdot
.46445 .62669 Mdot
.6558 .39786 Mdot
.65559 .47051 Mdot
.45375 .66115 Mdot
.33837 .50286 Mdot
.40341 .43085 Mdot
.55399 .54081 Mdot
.45282 .4383 Mdot
.41289 .37623 Mdot
.5293 .33172 Mdot
.54855 .3169 Mdot
.54046 .30789 Mdot
.34959 .53951 Mdot
.56288 .41204 Mdot
.45756 .50862 Mdot
.35986 .44948 Mdot
.65435 .4959 Mdot
.62342 .46349 Mdot
.60527 .38737 Mdot
.47011 .61144 Mdot
.48106 .70591 Mdot
.34493 .4582 Mdot
.4013 .53318 Mdot
.55959 .32848 Mdot
.67495 .50557 Mdot
.65369 .43837 Mdot
.33248 .4862 Mdot
.45472 .55714 Mdot
.39094 .49767 Mdot
.33176 .56823 Mdot
.40316 .34403 Mdot
.62037 .61806 Mdot
.33456 .5799 Mdot
.36474 .35822 Mdot
.66472 .46063 Mdot
.5273 .37559 Mdot
.70282 .50568 Mdot
.61692 .35989 Mdot
.37806 .54672 Mdot
.33485 .52813 Mdot
.59113 .45137 Mdot
.67333 .58804 Mdot
.4726 .63713 Mdot
.6175 .43858 Mdot
.62511 .38779 Mdot
.42782 .61103 Mdot
.68513 .45336 Mdot
.42747 .47254 Mdot
.70297 .51614 Mdot
.47153 .35553 Mdot
.33198 .47784 Mdot
.50129 .69016 Mdot
.36828 .4211 Mdot
.52021 .70625 Mdot
.4883 .6146 Mdot
.47708 .67256 Mdot
.35742 .58715 Mdot
.6209 .43565 Mdot
.32867 .50957 Mdot
.43006 .59806 Mdot
.33412 .47264 Mdot
.4099 .3308 Mdot
.68188 .58056 Mdot
.4317 .56427 Mdot
.36786 .56721 Mdot
.54945 .61702 Mdot
.58412 .60308 Mdot
.65274 .41945 Mdot
.49506 .32651 Mdot
.63433 .48988 Mdot
.43516 .68629 Mdot
.44465 .44239 Mdot
.48685 .36373 Mdot
.61678 .48403 Mdot
.48258 .36343 Mdot
.42446 .45539 Mdot
.42098 .66904 Mdot
.333 .59087 Mdot
.58634 .65359 Mdot
.37973 .5231 Mdot
.31883 .5509 Mdot
.31178 .46333 Mdot
.5358 .71127 Mdot
.65776 .38146 Mdot
.33814 .56475 Mdot
.62812 .37696 Mdot
.46395 .35732 Mdot
.47537 .66731 Mdot
.37011 .58551 Mdot
.6421 .39061 Mdot
.46743 .69559 Mdot
.3767 .58199 Mdot
.63724 .35834 Mdot
.64324 .4267 Mdot
.43503 .31101 Mdot
.64989 .57742 Mdot
.53073 .63495 Mdot
.51058 .71155 Mdot
.3262 .43687 Mdot
.62833 .42931 Mdot
.61292 .59904 Mdot
.66692 .54933 Mdot
.60869 .37988 Mdot
.42173 .41422 Mdot
.65733 .54339 Mdot
.46294 .32397 Mdot
.37643 .60481 Mdot
.44381 .43467 Mdot
.57498 .61711 Mdot
.41304 .54542 Mdot
.41698 .38155 Mdot
.32603 .46834 Mdot
.3388 .39434 Mdot
.41241 .51741 Mdot
.43028 .35529 Mdot
.66299 .38381 Mdot
.40963 .32095 Mdot
.57565 .5933 Mdot
.50948 .65018 Mdot
.41187 .50078 Mdot
.57884 .53821 Mdot
.63995 .63954 Mdot
.33536 .55402 Mdot
.39497 .46501 Mdot
.65831 .4104 Mdot
.58512 .53331 Mdot
.51953 .62499 Mdot
.53111 .61582 Mdot
.40434 .41751 Mdot
.63252 .65043 Mdot
.3459 .61241 Mdot
.34937 .38621 Mdot
.46047 .68614 Mdot
.31438 .46259 Mdot
.5457 .40921 Mdot
.66972 .44425 Mdot
.63326 .43001 Mdot
.62263 .37209 Mdot
.45434 .39511 Mdot
.41116 .37329 Mdot
.64225 .63354 Mdot
.37032 .43417 Mdot
.48734 .45085 Mdot
.66697 .51124 Mdot
.39873 .54513 Mdot
.33526 .47871 Mdot
.43622 .44695 Mdot
.36037 .3692 Mdot
.44693 .32921 Mdot
.47266 .37461 Mdot
.65792 .50625 Mdot
.65644 .59889 Mdot
.65266 .43171 Mdot
.36861 .5043 Mdot
.53916 .66941 Mdot
.3209 .49435 Mdot
.51803 .35929 Mdot
.59173 .47914 Mdot
.57754 .61113 Mdot
.41493 .57429 Mdot
.3385 .53314 Mdot
.46635 .30791 Mdot
.41328 .53168 Mdot
.41853 .43155 Mdot
.34694 .47158 Mdot
.62565 .64555 Mdot
.50106 .51519 Mdot
.42998 .44189 Mdot
.34784 .44543 Mdot
.42008 .31057 Mdot
.392 .59025 Mdot
.50598 .69636 Mdot
.67109 .43906 Mdot
.34088 .40964 Mdot
.33172 .52306 Mdot
.66726 .44814 Mdot
.58713 .45627 Mdot
.62631 .35293 Mdot
.43508 .43446 Mdot
.52227 .69117 Mdot
.63382 .57407 Mdot
.36362 .38948 Mdot
.46567 .42457 Mdot
.33474 .60723 Mdot
.50427 .36445 Mdot
.52852 .41359 Mdot
.46995 .67228 Mdot
.60056 .38548 Mdot
.42094 .63471 Mdot
.66194 .53339 Mdot
.47085 .34959 Mdot
.59267 .32728 Mdot
.41788 .3151 Mdot
.53282 .58438 Mdot
.69437 .48938 Mdot
.55967 .4108 Mdot
.54869 .67061 Mdot
.58 .51324 Mdot
.68213 .44455 Mdot
.5705 .66764 Mdot
.37804 .43032 Mdot
.5626 .57059 Mdot
.68615 .40047 Mdot
.43727 .60928 Mdot
.51824 .54616 Mdot
.58269 .58773 Mdot
.49894 .60021 Mdot
.49744 .57585 Mdot
.64218 .57373 Mdot
.51062 .5259 Mdot
.5912 .64812 Mdot
.62868 .55724 Mdot
.405 .45232 Mdot
.61172 .43205 Mdot
.47065 .38853 Mdot
.36629 .35451 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0?ooooooB_ooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A006ooooo`03o`000?oooooooooo0?ooooooB_ooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0?ooooooB_oo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06
ooooo`?o0000oooooom:ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<oooo
o`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom:ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001_ooool00ol0003oooooooooo`3ooooood[ooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0T?ooool3o`000003ooooool0003o00000;?ooooo000Looooo`03
o`000?oooooooooo08_ooooo2?l000000ooooooo0000o`000009o`0000_ooooo2Ol0002Fooooo`00
7?ooool00ol0003oooooooooo`28oooooaWo000000?oooooo`000?l000000_ooool@o`0009?ooooo
000Looooo`03o`000?oooooooooo08Kooooo7ol000000ooooooo0000o`00000>o`0009?ooooo000L
ooooo`03o`000?oooooooooo08Cooooo:?l000000ooooooo0000o`000008o`0009;ooooo000Loooo
o`03o`000?oooooooooo08?ooooo=ol0002?ooooo`007?ooool00ol0003oooooooooo`23ooooocSo
0000S_ooool001cooooo00?o0000ooooooooool0P?oooolEo`000003ooooool0003o000000ko0000
00?oooooo`000?l000004ol0002=ooooo`007?ooool00ol0003oooooooooo`1oooooobOo000000?o
ooooo`000?l000004ol0002=ooooo`007?ooool00ol0003oooooooooo`1nooooobOo00001OoooolB
o`0008gooooo000Looooo`;o0000OooooolXo`0000Cooooo5?l0002;ooooo`007?ooool00ol0003o
ooooooooo`1looooobOo000000?oooooo`000?l000001_oooolDo`0008Wooooo000Looooo`03o`00
0?oooooooooo07[ooooo8ol00006ooooo`;o00001?ooool2o`0000;ooooo5_l00026ooooo`007?oo
ool00ol0003oooooooooo`1ioooooa?o000000?oooooo`000?l000001ol0000;ooooo`Co00001?oo
ool2o`000004ooooool0003o0000oooooaOo0000Poooool001cooooo00?o0000ooooooooool0N?oo
oolDo`0000Gooooo1Ol00002ooooo`;o00000oooool2o`0000;ooooo0_l00009ooooo`;o000000?o
ooooo`000?l000006?l00020ooooo`007?ooool00ol0003oooooooooo`1hooooo`ko00000oooool3
o`0000Cooooo1Ol00003ooooo`;o00000oooool2o`0000oooooo1Ol00002ooooo`;o000000?ooooo
o`000?l000003ol000000ooooooo0000o`00001mooooo`007?ooool00ol0003oooooooooo`1hoooo
o`[o00000_ooool2o`000003ooooool0003o000000?o00001?ooool2o`00017ooooo0_l00009oooo
o`;o00002OoooolDo`0007cooooo000Looooo`03o`000?oooooooooo07Gooooo3_l00004ooooo`;o
00003Oooool2o`0000Cooooo0_l00005ooooo`;o00004_ooool2o`0000?ooooo0ol000000ooooooo
0000o`00000<o`0007_ooooo000Looooo`03o`000?oooooooooo07Cooooo2ol00002ooooo`;o0000
4?ooool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o00003?ooool2o`0000Oooooo
0_l0000:ooooo`co0000N_ooool001cooooo00?o0000ooooooooool0Loooool<o`000003ooooool0
003o000000_ooooo0_l00004ooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0
003o000000?o00003?ooool3o`000003ooooool0003o000000Gooooo0_l000001?oooooo0000o`00
0?l00002ooooo`;o00000_ooool;o`0007Wooooo000Looooo`03o`000?oooooooooo07;ooooo2ol0
0003ooooo`?o00002Oooool3o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`000004ooooool0
003o0000o`0000Sooooo0_l00003ooooo`Co000000Coooooo`000?l0003ooooo0_l00002ooooo`;o
000000Coooooo`000?l0003o00000_ooool3o`000003ooooool0003o000000[o0000N?ooool001co
oooo00?o0000ooooooooool0L?ooool=o`000004ooooool0003o0000ooooo`;o00002Oooool2o`00
00Cooooo0_l00006ooooo`;o00003?ooool2o`0000?ooooo0ol00002ooooo`;o000000?oooooo`00
0?l000001Oooool2o`0000Cooooo0_l00002ooooo`co0000Moooool001cooooo00?o0000oooooooo
ool0L?ooool=o`000003ooooool0003o0000013ooooo0_l0000Fooooo`;o00007?ooool=o`0007Ko
oooo000Looooo`03o`000?oooooooooo06oooooo3?l00002ooooo`;o00003Oooool6o`0001Gooooo
0ol000000ooooooo0000o`000004ooooo`?o00000oooool2o`0000kooooo3?l0001fooooo`007?oo
ool00ol0003oooooooooo`1]ooooo`go000000?oooooo`000?l000001?l0000;ooooo`Co00000ooo
ool2o`0000oooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00001?ooool5o`000003oooo
ool0003o000000;ooooo0_l0000;ooooo`_o0000M_ooool001cooooo00?o0000ooooooooool0KOoo
ool:o`0000Cooooo0_l000001?oooooo0000o`000?l00004ooooo`;o00001_ooool3o`0000?ooooo
0ol0000>ooooo`;o00003_ooool2o`0000Gooooo0_l0000<ooooo`_o0000MOooool001cooooo0_l0
001]ooooo`_o00001oooool2o`0000Gooooo1?l0000;ooooo`?o00005_ooool2o`0000cooooo0_l0
000=ooooo`[o0000MOooool001cooooo00?o0000ooooooooool0K?ooool:o`0000Sooooo0ol00006
ooooo`;o00002_ooool4o`0000Gooooo0_l000000ooooooo0000o`00000;ooooo`?o00000_ooool2
o`0000Sooooo0_l00002ooooo`;o00001oooool>o`0007?ooooo000Looooo`03o`000?oooooooooo
06cooooo2_l00008ooooo`?o00001_ooool3o`0000;ooooo0_l00005ooooo`Co00001Oooool5o`00
00Kooooo0_l00003ooooo`?o00000_ooool3o`0000Oooooo0_l00002ooooo`;o00001oooool2o`00
00;ooooo2_l0001cooooo`007?ooool00ol0003oooooooooo`1[ooooo`[o00002_ooool2o`0000Ko
oooo0ol00002ooooo`;o00001Oooool4o`0000Cooooo0_l000001?oooooo0000o`000?l00004oooo
o`Co00002Oooool2o`0000Oooooo0_l00008ooooo`;o00001?ooool9o`0007Gooooo000Looooo`03
o`000?oooooooooo06_ooooo1ol000000ooooooo0000o`00000:ooooo`;o00003Oooool2o`0000?o
oooo0_l00006ooooo`Go00001Oooool2o`0000Oooooo0_l0000>ooooo`;o00000oooool4o`0000Co
oooo3?l0001booooo`007?ooool00ol0003oooooooooo`1Yooooo`Wo00003Oooool2o`0000gooooo
0_l00009ooooo`Go00000_ooool2o`0000?ooooo1?l00005ooooo`;o00001oooool2o`0000Gooooo
0_l00003ooooo`;o00001_ooool<o`0007;ooooo000Looooo`03o`000?oooooooooo06Wooooo2_l0
0008ooooo`;o00000oooool2o`0001;ooooo0_l00003ooooo`?o00001?ooool2o`0000?ooooo1?l0
000=ooooo`?o00000oooool2o`0000Sooooo0_l00006ooooo`Wo0000L_ooool001cooooo00?o0000
ooooooooool0J?ooool;o`0000Sooooo0_l00003ooooo`;o00004_ooool2o`0000Wooooo0_l00004
ooooo`;o00003oooool3o`0000?ooooo0_l00002ooooo`Co00000_ooool2o`0000Cooooo0_l00000
0ooooooo0000o`000008o`00073ooooo000Looooo`03o`000?oooooooooo06Sooooo2Ol000000ooo
oooo0000o`00000<ooooo`Co00003?ooool2o`0000Cooooo0_l00007ooooo`Co00001Oooool2o`00
00kooooo0ol00005ooooo`Co00000_ooool2o`0000Cooooo0_l00002ooooo`[o0000Koooool001co
oooo00?o0000ooooooooool0J?ooool8o`0000;ooooo0_l00008ooooo`;o00000_ooool4o`0000_o
oooo0ol00004ooooo`;o00002?ooool3o`0000Gooooo0_l0000>ooooo`?o00000_ooool2o`0000Co
oooo0_l00003ooooo`;o000000Coooooo`000?l0003o00000oooool9o`0006oooooo000Looooo`03
o`000?oooooooooo06Oooooo2?l00008ooooo`;o00000oooool2o`0000;ooooo1_l00004ooooo`Co
000000?oooooo`000?l000001?ooool2o`0000Wooooo0ol0000>ooooo`;o00002Oooool3o`0000?o
oooo0ol00003ooooo`;o000000?oooooo`000?l000001?ooool;o`0006gooooo000Looooo`03o`00
0?oooooooooo06Oooooo1ol00002ooooo`;o00001Oooool2o`0000_ooooo0_l00004ooooo`Co0000
00?oooooo`000?l000000_ooool4o`0000Oooooo0_l000000ooooooo0000o`00000>ooooo`;o0000
2Oooool3o`0000?ooooo0_l00003ooooo`;o00002?ooool=o`0006_ooooo000Looooo`03o`000?oo
oooooooo06Oooooo2ol0000;ooooo`;o00002oooool3o`0000Kooooo1?l00007ooooo`;o00007ooo
ool4o`0000?ooooo1?l000000ooooooo0000o`000005ooooo`Co00000_ooool7o`0006[ooooo000L
ooooo`03o`000?oooooooooo06Oooooo2Ol00002ooooo`;o00002Oooool2o`0000cooooo0_l00008
ooooo`;o0000:?ooool4o`0000?ooooo1?l000000ooooooo0000o`000003o`0000;ooooo0_l00004
ooooo`So0000JOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l0
00000ol@413oooooooooo`04ooooo`03o`000?oooooooooo06Kooooo2?l00004ooooo`;o00001ooo
ool2o`0001Sooooo0_l00009ooooo`;o00002Oooool3o`0000?ooooo0_l000000ooooooo0000o`00
000=ooooo`Co00001_ooool3o`0000[ooooo2Ol0001Vooooo`0000KoooooogMgMonHV9SooooooiRH
V?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06Gooooo
1ol0000?ooooo`Co00004Oooool2o`0000kooooo0_l00004ooooo`;o00000oooool3o`0000?ooooo
0_l000000ooooooo0000o`00000=ooooo`Co00002oooool2o`0000Sooooo1ol0001Vooooo`0000?o
oooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`Go00001_ooool00ol0003ooooooooo
o`1Uooooo`Oo00004Oooool2o`000003ooooool0003o000000kooooo0_l0000Dooooo`?o00000_oo
ool2o`0001gooooo0_l00005ooooo`?o00002Oooool6o`0006Kooooo00000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`0006Cooooo2?l0
0006ooooo`;o00002?ooool3o`000003ooooool0003o000000;o00008oooool2o`0000;ooooo0_l0
000Mooooo`;o00001Oooool2o`0000;ooooo4?l0001Tooooo`0000?oooooo`000?ooool00_ooool0
0ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0Hooo
ool7o`0000Sooooo0_l00008ooooo`;o00001?ooool6o`0001cooooo0_l0000Looooo`?o00002Ooo
ool3o`0000Cooooo4Ol0001Sooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:
ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0H?ooool:o`000004ooooool0003o
0000o`0001Kooooo1?l00008ooooo`;o00004_ooool2o`0000Oooooo0_l0000Aooooo`Oo00001ooo
ool3o`0000Wooooo3?l0001Sooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<ooooo`03onk^
k_m4A4Co000000Oooooo00?o0000ooooooooool0Goooool;o`000004ooooool0003o0000o`0001So
oooo0_l00007ooooo`?o00002Oooool2o`00013ooooo0_l00003ooooo`?o00002Oooool4o`0000?o
oooo0ol0000:ooooo`Co00001_ooool:o`0006?ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^
kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`1Nooooo`co000000?oooooo`00
0?l000002_ooool2o`0000cooooo0ol00006ooooo`?o00002_ooool2o`0000_ooooo0ol00007oooo
o`?o000000?oooooo`000?l000001_ooool4o`0000Cooooo0_l0000:ooooo`Co00001_ooool:o`00
06?ooooo000Looooo`03o`000?oooooooooo05gooooo3?l00008ooooo`;o00001?ooool2o`0000Oo
oooo0_l00003ooooo`;o00001oooool2o`00013ooooo0_l00006ooooo`?o00002oooool2o`00013o
oooo0_l0000Aooooo`co0000H_ooool001cooooo00?o0000ooooooooool0GOooool=o`0000Oooooo
0_l000000ooooooo0000o`00000:ooooo`;o00007_ooool2o`00017ooooo1?l0000:ooooo`;o0000
1Oooool4o`0000Cooooo0_l00003ooooo`;o00000oooool=o`0006;ooooo000Looooo`03o`000?oo
oooooooo05gooooo3Ol0000:ooooo`;o00004oooool2o`0000Wooooo0_l0000:ooooo`;o00000_oo
ool4o`0000_ooooo1?l0000:ooooo`;o00001oooool2o`0000Cooooo1ol00003ooooo`go0000H_oo
ool001cooooo00?o0000ooooooooool0GOooool;o`0000oooooo0_l0000@ooooo`;o00002Oooool2
o`0000;ooooo0_l00006ooooo`;o00000_ooool4o`0000?ooooo0_l0000Aooooo`;o00003Oooool2
o`0000?ooooo0ol00005ooooo`go0000H_ooool001cooooo00?o0000ooooooooool0G?ooool<o`00
00Oooooo0_l00006ooooo`;o00001_ooool2o`0000_ooooo0_l00005ooooo`;o00000oooool2o`00
00[ooooo0_l00005ooooo`;o00004Oooool2o`0000Sooooo1?l000001?oooooo0000o`000?ooool2
o`0000Sooooo3_l0001Qooooo`007?ooool00ol0003oooooooooo`1Looooo`co00001oooool2o`00
00Kooooo0_l00006ooooo`;o00000_ooool3o`0000Kooooo0_l00005ooooo`;o00002oooool2o`00
027ooooo0_l00003ooooo`Co00001?ooool3o`0000Oooooo3_l0001Qooooo`007?ooool00ol0003o
ooooooooo`1Kooooo`go00000_ooool2o`000003ooooool0003o000000Kooooo0_l00004ooooo`;o
00001_ooool3o`0000Cooooo1?l0000Booooo`;o00004Oooool2o`0000kooooo0_l000000ooooooo
0000o`000008ooooo`?o00001oooool>o`00067ooooo000Looooo`03o`000?oooooooooo05_ooooo
3Ol00002ooooo`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`Co00000_ooool2o`0000go
oooo1?l000000ooooooo0000o`00000>ooooo`;o00000oooool2o`0000gooooo1Ol00003ooooo`;o
00001?ooool2o`0000;ooooo1Ol00003ooooo`;o000000Coooooo`000?l0003o00000oooool2o`00
00;ooooo3_l0001Qooooo`007?ooool00ol0003oooooooooo`1Jooooo`co00002_ooool2o`0000Go
oooo0_l0000?ooooo`Co000000?oooooo`000?l000001?l0000<ooooo`;o00000oooool2o`0000oo
oooo0ol00003ooooo`Co00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o
000000Coooooo`000?l0003o00000oooool3o`000003ooooool0003o000000co0000HOooool001co
oooo00?o0000ooooooooool0F_ooool3o`000003ooooool0003o000000Ko00001?ooool2o`000004
ooooool0003o0000o`0000Cooooo0_l00003ooooo`;o00000oooool2o`0000Sooooo1?l000000ooo
oooo0000o`000002ooooo`;o00007oooool2o`0000Wooooo0_l00009ooooo`;o00003?oooolBo`00
067ooooo000Looooo`03o`000?oooooooooo05[ooooo3?l00004ooooo`;o000000Goooooo`000?l0
003o0000ooooo`02o`000003ooooool0003o000000?ooooo0_l00003ooooo`?o00000_ooool2o`00
00Gooooo0_l00005ooooo`;o00007oooool2o`0000oooooo0_l00003ooooo`;o00002oooool3o`00
0003ooooool0003o000000go0000HOooool001cooooo0_l0001Kooooo`_o00002?ooool6o`0000co
oooo0ol000000ooooooo0000o`000005ooooo`;o00002?ooool2o`0000Gooooo0_l0000Oooooo`;o
00000oooool4o`00013ooooo0_l000001?oooooo0000o`000?ooool=o`00067ooooo000Looooo`03
o`000?oooooooooo05Sooooo3Ol00008ooooo`Ko00003Oooool2o`0000Cooooo0_l0000<ooooo`;o
00001Oooool2o`0001oooooo0_l00002ooooo`?o00000_ooool2o`0000kooooo0_l000001?oooooo
0000o`000?ooool=o`00067ooooo000Looooo`03o`000?oooooooooo05Sooooo3?l00006ooooo`Co
00000oooool2o`0001?ooooo0_l00004ooooo`;o00000oooool2o`0000;ooooo0_l0000;ooooo`;o
00005oooool2o`0000?ooooo0ol000001?oooooo0000o`000?l0000:ooooo`;o00002?ooool=o`00
067ooooo000Looooo`03o`000?oooooooooo05Oooooo3Ol00006ooooo`Co00005oooool2o`0000Go
oooo0_l00003ooooo`?o000000?oooooo`000?l000002oooool2o`0001Oooooo0ol00003ooooo`;o
000000Coooooo`000?l0003o00002_ooool2o`000004ooooool0003o0000ooooo`;o00001?ooool<
o`00063ooooo000Looooo`03o`000?oooooooooo05Oooooo3_l00005ooooo`Ko00000_ooool2o`00
017ooooo0_l0000;ooooo`;o0000:?ooool2o`0000?ooooo0_l00004ooooo`;o00001_ooool2o`00
00?ooooo0_l000000ooooooo0000o`000004ooooo`co0000H?ooool001cooooo00?o0000oooooooo
ool0Eoooool:o`000004ooooool0003o0000o`0000Gooooo0_l00002ooooo`Ko00002?ooool3o`00
01oooooo0_l0000Qooooo`;o00001?ooool2o`0000Kooooo0_l00006ooooo`;o00001?ooool;o`00
067ooooo000Looooo`03o`000?oooooooooo05Kooooo2ol00005ooooo`;o00002?ooool2o`000003
ooooool0003o000000Oooooo0ol0000Cooooo`;o00002_ooool2o`0001?ooooo0_l0000Booooo`;o
00001_ooool4o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`[o0000HOooool001cooooo
00?o0000ooooooooool0E_ooool:o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l00000
0_ooool2o`0000Cooooo0_l00007ooooo`;o00002Oooool2o`0000Wooooo0_l0000>ooooo`;o0000
3oooool2o`0001[ooooo1?l00004ooooo`;o000000?oooooo`000?l000000_ooool:o`00067ooooo
000Looooo`03o`000?oooooooooo05Gooooo3ol00005ooooo`;o00000_ooool3o`0000oooooo0_l0
0006ooooo`;o00001?ooool2o`0001?ooooo0_l0000@ooooo`;o00004Oooool2o`0000kooooo0_l0
0002ooooo`;o00000_ooool:o`00063ooooo000Looooo`03o`000?oooooooooo05Gooooo3Ol00006
ooooo`Co00000_ooool2o`0000oooooo0_l00008ooooo`;o00000_ooool3o`00027ooooo0_l00000
0ooooooo0000o`000006ooooo`;o00002Oooool3o`0000_ooooo0_l00004ooooo`;o00000_ooool:
o`00063ooooo000Looooo`03o`000?oooooooooo05Gooooo2ol00008ooooo`Co00007Oooool2o`00
00?ooooo0_l00004ooooo`;o00006oooool2o`0000Wooooo0_l00009ooooo`?o00002Oooool4o`00
00Sooooo2Ol0001Qooooo`007?ooool00ol0003oooooooooo`1Eooooo`_o00000oooool2o`0000?o
oooo0_l0000Kooooo`Co00002oooool2o`0002kooooo0ol00006ooooo`;o00001?ooool4o`0000Oo
oooo2_l0001Qooooo`007?ooool00ol0003oooooooooo`1Eooooo`_o00000oooool2o`0000?ooooo
1?l00004ooooo`;o00001Oooool2o`0000cooooo1?l0000kooooo`?o00001_ooool2o`0000;ooooo
0_l0000;ooooo`_o0000H?ooool001cooooo00?o0000ooooooooool0EOooool3o`000003ooooool0
003o000000Go00002Oooool3o`0000Cooooo0_l00005ooooo`;o0000BOooool2o`000003ooooool0
003o000000?ooooo0_l00005ooooo`;o00001_ooool2o`0000?ooooo3?l0001Oooooo`007?ooool0
0ol0003oooooooooo`1Eooooo`co00000oooool3o`0000?ooooo0_l00003ooooo`;o00001oooool2
o`0000Kooooo0_l0000?ooooo`;o0000;oooool2o`000003ooooool0003o000000?ooooo0_l00004
ooooo`;o00001oooool2o`0000Sooooo1ol0001Oooooo`007?ooool00ol0003oooooooooo`1Eoooo
o`co00000oooool3o`0000;ooooo1?l00002ooooo`;o00001oooool2o`000003ooooool0003o0000
00?ooooo0_l0000?ooooo`;o00000_ooool2o`0003Sooooo1?l00002ooooo`;o00001oooool2o`00
0003ooooool0003o000000Ko0000H?ooool001cooooo0_l0001Gooooo`[o00002Oooool4o`0000;o
oooo0_l000000ooooooo0000o`000007ooooo`;o00001Oooool2o`00017ooooo0_l0000Eooooo`;o
00008Oooool4o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o000000Oo
0000Goooool001cooooo00?o0000ooooooooool0Eoooool3o`000003ooooool0003o000000Co0000
2Oooool3o`0000Gooooo1?l00002ooooo`;o00002?ooool2o`0002Sooooo0ol00007ooooo`;o0000
7_ooool6o`000003ooooool0003o000000?ooooo2?l0001Oooooo`007?ooool00ol0003ooooooooo
o`1Gooooo`[o00002Oooool2o`0000Sooooo1_l0000cooooo`;o00000oooool2o`0000;ooooo0_l0
000Jooooo`;o00000_ooool4o`0000?ooooo3Ol0001Oooooo`007?ooool00ol0003oooooooooo`1G
ooooo`[o00001_ooool5o`0000Sooooo1?l0000Cooooo`;o00001?ooool2o`0001oooooo0_l0000M
ooooo`?o00000oooool2o`0000Kooooo2ol0001Oooooo`007?ooool00ol0003oooooooooo`1Goooo
o`[o000000?oooooo`000?l000000oooool5o`0001oooooo0_l00004ooooo`;o00009_ooool2o`00
00gooooo0_l00007ooooo`;o00000_ooool2o`0000Kooooo3Ol0001Oooooo`007?ooool00ol0003o
ooooooooo`1Hooooo`Wo000000Coooooo`000?l0003o00000_ooool4o`0001_ooooo0_l0000Goooo
o`;o00006?ooool2o`0000gooooo0_l0000;ooooo`;o00000_ooool6o`0000;ooooo2_l0001Noooo
o`007?ooool00ol0003oooooooooo`1Hooooo`[o000000?oooooo`000?l000000oooool2o`0001Go
oooo0_l000000ooooooo0000o`000002ooooo`;o00001?ooool2o`00017ooooo0_l0000Eooooo`;o
00000oooool2o`0001cooooo1Ol000000ooooooo0000o`00000;o`0005gooooo000Looooo`03o`00
0?oooooooooo05Sooooo2_l00006ooooo`;o00003_ooool2o`0000Gooooo0_l000000ooooooo0000
o`000005ooooo`;o000000?oooooo`000?l000007oooool2o`0000Oooooo0_l00003ooooo`?o0000
8Oooool=o`0005gooooo000Looooo`03o`000?oooooooooo05Sooooo2_l00006ooooo`;o00000_oo
ool2o`0000[ooooo0_l00004ooooo`;o00002Oooool2o`0001Oooooo0_l00009ooooo`;o000000?o
ooooo`000?l000002_ooool2o`0000_ooooo0_l0000:ooooo`;o00002?ooool=o`0005gooooo000L
ooooo`03o`000?oooooooooo05Wooooo2Ol00006ooooo`?o000000?oooooo`000?l000000oooool2
o`0000_ooooo0_l0000Rooooo`;o00003?ooool2o`0000Wooooo0_l0000<ooooo`;o00000oooool2
o`0000Gooooo1?l00005ooooo`ko0000GOooool001cooooo00?o0000ooooooooool0FOooool:o`00
00Gooooo0ol00006ooooo`;o00003oooool3o`0003Cooooo1?l00003ooooo`;o00002oooool3o`00
00Kooooo0ol00005ooooo`ko0000GOooool001cooooo00?o0000ooooooooool0F?ooool<o`0000Go
oooo0ol00006ooooo`;o00002oooool2o`000004ooooool0003o0000o`0000Sooooo0_l0000Zoooo
o`?o00001?ooool2o`0000?ooooo1?l00004ooooo`;o00001?ooool2o`000003ooooool0003o0000
00Kooooo3_l0001Mooooo`007?ooool00ol0003oooooooooo`1Hooooo`co00001Oooool3o`0000Ko
oooo0_l0000;ooooo`;o00003?ooool2o`0001Cooooo0_l0000Cooooo`Ko00000oooool2o`0000;o
oooo1?l00007ooooo`;o000000?oooooo`000?l000000ol00003ooooo`;o000000?oooooo`000?l0
00003?l0001Mooooo`007?ooool00ol0003oooooooooo`1Hooooo`co00001?ooool2o`0000;ooooo
1?l000001?oooooo0000o`000?l0000Pooooo`;o00003Oooool2o`0000_ooooo0_l00006ooooo`;o
00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`;o00000_ooool2o`0000;o
oooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000003?l0001Mooooo`00
7?ooool00ol0003oooooooooo`1Hooooo`Wo000000?oooooo`000?l000000_ooool4o`0000;ooooo
1?l000001?oooooo0000o`000?l0000Booooo`;o00003?ooool2o`0000_ooooo0_l0000=ooooo`;o
00000oooool2o`0000Gooooo1?l00004ooooo`;o00001_ooool2o`0000Cooooo1?l000000ooooooo
0000o`000003o`000003ooooool0003o000000co0000G_ooool001cooooo00?o0000ooooooooool0
F?ooool<o`0000;ooooo0_l0000:ooooo`;o00000oooool2o`0000?ooooo1?l00002ooooo`;o0000
0_ooool2o`0001Sooooo0ol00002ooooo`;o00002_ooool2o`0000;ooooo0_l00005ooooo`Oo0000
00?oooooo`000?l000002_ooool6o`000003ooooool0003o000001;o0000G_ooool001cooooo0_l0
001Ioooooa7o00002Oooool2o`000003ooooool0003o000000;o00000oooool4o`0000;ooooo0_l0
000Looooo`;o00000oooool2o`0000[ooooo0_l0000<ooooo`Co000000?oooooo`000?l000002_oo
ool2o`000003ooooool0003o000000;o00001Oooool>o`0005oooooo000Looooo`03o`000?oooooo
oooo05Sooooo4ol0000:ooooo`;o00004?ooool2o`00037ooooo0_l0000:ooooo`;o00002_ooool5
o`0000Gooooo3_l0001Oooooo`007?ooool00ol0003oooooooooo`1Goooooa7o000000?oooooo`00
0?l000000oooool2o`0001Gooooo1?l00007ooooo`;o0000:?ooool2o`0000[ooooo1?l00008oooo
o`;o000000?oooooo`000?l000001?ooool?o`0005oooooo000Looooo`03o`000?oooooooooo05Oo
oooo3_l00009ooooo`;o00005Oooool2o`0000Wooooo0_l0000Iooooo`;o00002_ooool2o`0000Go
oooo0_l00008ooooo`;o000000?oooooo`000?l000003_ooool>o`00063ooooo000Looooo`03o`00
0?oooooooooo05Oooooo3_l00005ooooo`;o00001_ooool2o`000003ooooool0003o000000_ooooo
0_l0000>ooooo`;o00002?ooool2o`0000gooooo0_l0000:ooooo`;o00001Oooool2o`0000Oooooo
0_l00002ooooo`;o00003_ooool<o`0006;ooooo000Looooo`03o`000?oooooooooo05Oooooo3_l0
0005ooooo`;o00001_ooool2o`000003ooooool0003o000000Sooooo0_l000000ooooooo0000o`00
0004ooooo`;o00000oooool2o`0000?ooooo0_l000000ooooooo0000o`000005ooooo`;o00008Ooo
ool2o`0000Kooooo0_l00004ooooo`;o00001?ooool2o`0000;ooooo0_l00002ooooo`co0000H_oo
ool001cooooo00?o0000ooooooooool0F?ooool=o`0000?ooooo1?l00008ooooo`;o00001oooool4
o`000003ooooool0003o000000Cooooo1?l000000ooooooo0000o`000006ooooo`;o00009oooool3
o`0000cooooo0_l00004ooooo`;o00000_ooool2o`000003ooooool0003o000000_o0000H_ooool0
01cooooo00?o0000ooooooooool0Eoooool>o`0000?ooooo0_l0000:ooooo`;o00001oooool2o`00
00_ooooo0_l00002ooooo`;o00008oooool4o`0000Oooooo0_l00004ooooo`;o00003oooool2o`00
00?ooooo2ol0001Tooooo`007?ooool00ol0003oooooooooo`1Gooooo`go00000_ooool2o`0000Co
oooo0_l00009ooooo`Co00002?ooool2o`0000Wooooo0_l0000<ooooo`Go00000oooool2o`0000;o
oooo0_l00009ooooo`Co00003Oooool2o`0000Cooooo0_l000000ooooooo0000o`000003o`0000?o
oooo0ol00002ooooo`Wo0000I_ooool001cooooo00?o0000ooooooooool0FOooool;o`0000;ooooo
0ol00003ooooo`;o00002Oooool4o`0000Sooooo0_l00007ooooo`;o00003_ooool5o`0000?ooooo
0ol000000ooooooo0000o`000002ooooo`;o00007?ooool2o`000003ooooool0003o000000?o0000
00Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000008o`0006Kooooo000Looooo`03o`00
0?oooooooooo05Wooooo3?l000000ooooooo0000o`000003o`0000Sooooo0_l00002ooooo`;o0000
4oooool2o`0000Gooooo0_l00007ooooo`;o00001oooool2o`0000Gooooo0_l0000Looooo`;o0000
0oooool6o`0000;ooooo2_l0001Xooooo`007?ooool00ol0003oooooooooo`1Iooooo`co00001?oo
ool2o`0000Oooooo0ol00002ooooo`?o00000_ooool4o`0000Kooooo0_l0000;ooooo`;o00001ooo
ool2o`000003ooooool0003o000000Sooooo0_l0000Jooooo`?o00002Oooool4o`0000;ooooo0_l0
00000ooooooo0000o`000005o`0006Sooooo000Looooo`03o`000?oooooooooo05[ooooo2ol00008
ooooo`;o000000?oooooo`000?l000002?l00002ooooo`Co00001_ooool2o`0001Oooooo0_l00008
ooooo`;o00003?ooool4o`0000[ooooo0ol00006ooooo`;o00000_ooool3o`0000;ooooo0_l00000
0ooooooo0000o`000003o`0006[ooooo000Looooo`03o`000?oooooooooo05[ooooo2ol00003oooo
o`;o00000oooool2o`000003ooooool0003o000000;ooooo1Ol00003ooooo`;o0000:Oooool2o`00
00Cooooo0_l00008ooooo`Co00000_ooool2o`0000oooooo0_l00002ooooo`?o00000_ooool2o`00
0003ooooool0003o000000?o0000J_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2
ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo05[ooooo2ol0
0002ooooo`?o00001_ooool2o`0000?ooooo1?l00003ooooo`;o00000_ooool2o`0000Oooooo0_l0
0002ooooo`;o00006?ooool2o`0000Cooooo1?l00006ooooo`;o00001?ooool3o`0001?ooooo0ol0
0004ooooo`Go0000J_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo
00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo05_ooooo2_l00002ooooo`;o
00000_ooool2o`0000?ooooo0_l00002ooooo`;o00002?ooool6o`0000Gooooo0ol000000ooooooo
0000o`00000Looooo`;o00000_ooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000?o
oooo0_l00008ooooo`;o00000_ooool7o`0006[ooooo00000ooooooo410@ooooo`02ooooo`03oa0@
4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo05co
oooo2_l00005ooooo`;o00001oooool2o`000003ooooool0003o000000Gooooo0_l00002ooooo`;o
00001?ooool4o`0000[ooooo0_l00006ooooo`;o00002oooool2o`0000?ooooo0ol00004ooooo`;o
00002_ooool4o`0000?ooooo0_l00005ooooo`Co000000?oooooo`000?l000001ol0001Zooooo`00
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ
8B401_ooool3o`0005kooooo2?l000001?oooooo0000o`000?ooool2o`0000Oooooo0_l00002oooo
o`Co000000?oooooo`000?l000002_ooool2o`0000cooooo0_l00005ooooo`?o00001oooool2o`00
00Oooooo0ol00004ooooo`;o000000?oooooo`000?l000001oooool3o`0000_ooooo1?l000001?oo
oooo0000o`000?ooool6o`0006[ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo05kooooo2ol00000
0ooooooo0000o`000007ooooo`;o00000_ooool7o`0001Sooooo0_l00004ooooo`Co00001oooool2
o`0000oooooo1?l0000Mooooo`Ko0000J_ooool00003ooooool@413ooooo00;ooooo00?o410@oooo
ooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo063ooooo2?l000001?oo
oooo0000o`000?l0000;ooooo`Go00003_ooool2o`0000[ooooo0_l00004ooooo`Co00006?ooool2
o`0000Sooooo0_l0000Booooo`Wo0000J_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2ooo
ool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo067ooooo3_l0000?ooooo`;o00001ooo
ool2o`000003ooooool0003o000000Gooooo0_l00002ooooo`;o00001oooool2o`0001Gooooo0_l0
00001?oooooo0000o`000?l00007ooooo`;o00001?ooool3o`0000_ooooo2Ol0001Zooooo`0000Ko
ooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000oooo
ooooool0H_ooool=o`0000gooooo1?l00007ooooo`;o00002?ooool2o`000004ooooool0003o0000
o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l000000oooool2o`0000[ooooo0_l00000
1?oooooo0000o`000?l00007ooooo`;o00001?ooool3o`0000[ooooo2Ol0001[ooooo`007?ooool0
0ol0003oooooooooo`1Tooooo`So00001Oooool2o`0000Oooooo1?l0000;ooooo`;o00002Oooool2
o`0000Gooooo0_l00004ooooo`;o000000?oooooo`000?l000000oooool2o`0000Cooooo1?l00003
ooooo`?o00002?ooool4o`000003ooooool0003o000000?o00002?ooool;o`0006_ooooo000Loooo
o`03o`000?oooooooooo06Gooooo2_l00002ooooo`;o00000_ooool3o`0000;ooooo0ol00005oooo
o`;o00001Oooool2o`000003ooooool0003o0000023ooooo1Ol00003ooooo`?o00002?ooool:o`00
00Sooooo2ol0001[ooooo`007?ooool00ol0003oooooooooo`1Vooooo`_o00001?ooool3o`0000?o
oooo0_l00005ooooo`;o00002?ooool2o`0001Oooooo0_l00007ooooo`;o00005?ooool2o`0000co
oooo3?l0001[ooooo`007?ooool00ol0003oooooooooo`1Yooooo`[o00003Oooool2o`00017ooooo
0_l0000@ooooo`;o00004?ooool2o`0001Oooooo3Ol0001/ooooo`007?ooool00ol0003ooooooooo
o`1Yooooo`[o00003Oooool2o`0000Wooooo0_l00006ooooo`;o00001oooool2o`0000Kooooo0_l0
000Aooooo`;o00002_ooool2o`0000_ooooo3Ol0001/ooooo`007?ooool00ol0003oooooooooo`1[
ooooo`_o000000?oooooo`000?l000004_ooool2o`000003ooooool0003o000000Sooooo0_l00002
ooooo`;o00001_ooool4o`0000_ooooo0_l00004ooooo`;o000000?oooooo`000?l000001Oooool2
o`0000?ooooo0_l00003ooooo`oo0000KOooool001cooooo00?o0000ooooooooool0K?ooool=o`00
00Cooooo0_l00006ooooo`;o00001oooool4o`0000Cooooo1?l00009ooooo`;o000000Coooooo`00
0?l0003ooooo0_l00006ooooo`Co00001?ooool2o`000003ooooool0003o000000Cooooo0_l00004
ooooo`;o00000oooool>o`0006kooooo000Looooo`03o`000?oooooooooo06kooooo3?l00003oooo
o`;o00001_ooool2o`0000Oooooo1?l00004ooooo`?o00000oooool2o`0000Gooooo0ol00003oooo
o`;o00001_ooool2o`0000Wooooo0_l00004ooooo`;o00002?ooool=o`00073ooooo000Looooo`03
o`000?oooooooooo06kooooo3?l00002ooooo`;o000000?oooooo`000?l000002?ooool2o`0000co
oooo0_l00003ooooo`;o00001Oooool3o`000003ooooool0003o000000gooooo0ol00003ooooo`;o
00003?ooool?o`00073ooooo000Looooo`03o`000?oooooooooo06oooooo2ol00002ooooo`;o0000
00?oooooo`000?l000000oooool2o`0000?ooooo0_l0000?ooooo`;o00002oooool2o`0000Oooooo
0_l00004ooooo`?o00002?ooool2o`0000Cooooo4?l0001booooo`007?ooool00ol0003ooooooooo
o`1`ooooo`_o00002Oooool2o`00013ooooo0_l00002ooooo`Co00001_ooool2o`0000[ooooo0_l0
0003ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l00004ooooo`?o000000?o
ooooo`000?l000002?l0001dooooo`007?ooool2o`0007;ooooo2_l0000Jooooo`Co00000oooool5
o`000003ooooool0003o000000;o00002Oooool3o`0000?ooooo0_l000001?oooooo0000o`000?oo
ool7o`0000;ooooo0_l000001?oooooo0000o`000?ooool;o`0007Cooooo000Looooo`03o`000?oo
oooooooo07;ooooo2_l0000Cooooo`;o00001?ooool4o`0000;ooooo1_l000001?oooooo0000o`00
0?l0000:ooooo`;o00002_ooool2o`000003ooooool0003o000000;o00000_ooool2o`000004oooo
ool0003o0000ooooo`So0000Moooool001cooooo00?o0000ooooooooool0L_ooool<o`00017ooooo
0_l0000:ooooo`;o00005?ooool2o`0000Sooooo0_l00002ooooo`;o000000?oooooo`000?l00000
1?ooool:o`0007Oooooo000Looooo`03o`000?oooooooooo07Cooooo2ol0000<ooooo`;o00000ooo
ool4o`0000Oooooo0_l0000Dooooo`;o00001_ooool2o`0000Oooooo0_l00003ooooo`Wo0000NOoo
ool001cooooo00?o0000ooooooooool0M?ooool<o`0000Oooooo0_l00002ooooo`;o00000oooool5
o`0000kooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool4o`0000Cooooo0_l00000
0ooooooo0000o`000006ooooo`;o00001?ooool9o`0007Wooooo000Looooo`03o`000?oooooooooo
07Cooooo3_l00005ooooo`;o000000?oooooo`000?l000001oooool6o`0000[ooooo0_l000001Ooo
oooo0000o`000?l0003ooooo00;o00000_ooool4o`0000Cooooo0_l00009ooooo`;o00001?ooool9
o`0007Wooooo000Looooo`03o`000?oooooooooo07Gooooo3_l00002ooooo`;o00000oooool2o`00
00Sooooo1Ol00008ooooo`;o00000oooool2o`0000?ooooo0_l000000ooooooo0000o`000006oooo
o`;o00003?ooool;o`0007[ooooo000Looooo`03o`000?oooooooooo07Oooooo3?l000000ooooooo
0000o`000002o`0000gooooo1Ol00007ooooo`?o000000?oooooo`000?l000001?ooool2o`000003
ooooool0003o000000kooooo0_l00004ooooo`[o0000Noooool001cooooo00?o0000ooooooooool0
NOooool?o`0000Gooooo0_l00006ooooo`Go00000_ooool2o`0000Cooooo0_l000000ooooooo0000
o`00000:ooooo`;o00002oooool2o`0000Cooooo2?l0001mooooo`007?ooool00ol0003ooooooooo
o`1jooooo`go00001Oooool3o`0000gooooo0_l00007ooooo`;o00002_ooool3o`0000?ooooo0_l0
0005ooooo`;o000000?oooooo`000?l000002?l0001nooooo`007?ooool00ol0003oooooooooo`1j
ooooo`go00000_ooool7o`0001;ooooo0_l00005ooooo`;o00001oooool2o`0000;ooooo0ol00000
0ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000001ol0001oooooo`007?ooool00ol0
003oooooooooo`1loooooa3o000000Coooooo`000?l0003o00000_ooool2o`0000[ooooo0_l00002
ooooo`;o00001Oooool2o`0000_ooooo0_l00002ooooo`;o000000?oooooo`000?l000002_l00020
ooooo`007?ooool00ol0003oooooooooo`1oooooo`ko00001Oooool4o`0000Sooooo0_l0000:oooo
o`;o00001?ooool3o`0000?ooooo0_l000000ooooooo0000o`00000=o`00087ooooo000Looooo`03
o`000?oooooooooo07oooooo4Ol00004ooooo`;o00002Oooool2o`0000Gooooo0_l00002ooooo`;o
00001?ooool3o`0000?ooooo4Ol00022ooooo`007?ooool00ol0003oooooooooo`22ooooo`ko0000
1?ooool2o`0000Wooooo0_l00005ooooo`;o00000_ooool2o`0000;ooooo1?l00004oooooa3o0000
Poooool001cooooo00?o0000ooooooooool0Q?ooool?o`000003ooooool0003o000000_ooooo0_l0
0004ooooo`;o00001Oooool3o`0000Cooooo4?l00024ooooo`007?ooool2o`0008Oooooo3Ol0000;
ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Gooooo0ol000000ooooooo0000o`00000@
o`0008Gooooo000Looooo`03o`000?oooooooooo08Oooooo4?l00007ooooo`;o00001?ooool5o`00
00Sooooo4ol00025ooooo`007?ooool00ol0003oooooooooo`27oooooa7o000000Coooooo`000?l0
003ooooo0_l00006ooooo`Go00000oooool2o`000003ooooool0003o000001;o0000Q_ooool001co
oooo00?o0000ooooooooool0QooooolIo`0000Gooooo0_l00003oooooaOo0000R?ooool001cooooo
00?o0000ooooooooool0R?oooolHo`0000;ooooo0_l000000ooooooo0000o`000003ooooo`So0000
00?oooooo`000?l000003?l00028ooooo`007?ooool00ol0003oooooooooo`28oooooago00000_oo
oolFo`0008cooooo000Looooo`03o`000?oooooooooo08[ooooo7?l000000ooooooo0000o`00000C
o`0008gooooo000Looooo`03o`000?oooooooooo08[ooooo:?l00002ooooo`So0000SOooool001co
oooo00?o0000ooooooooool0S_oooolNo`000003ooooool0003o000000?o000000?oooooo`000?l0
00000ol0002Aooooo`007?ooool00ol0003oooooooooo`2>ooooobOo0000U?ooool001cooooo00?o
0000ooooooooool0S_ooool5o`000003ooooool0003o000001oo0000U?ooool001cooooo00?o0000
ooooooooool0U?oooolNo`0009Oooooo000Looooo`03o`000?oooooooooo09Kooooo6_l0002Ioooo
o`007?ooool00ol0003oooooooooo`2IoooooaCo0000W?ooool001cooooo00?o0000ooooooooool0
Woooool<o`0009kooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003o
oooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0
003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?ooooooB_ooool00006oooooomgMgOoV9RHoooo
oonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oo
oooooooo0?ooooooB_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooom:ooooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_oo
ool3o`000?ooooooB_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom:ooooo`0000?ooooo
oa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_oo
ool00ol0003oooooooooo`3ooooood[ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo
00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0?ooooooB_ooool00006oooo
ooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0
oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB_oo
ool001Cooooo00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o0000oooo
ooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`00
0?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`004_ooool0
0omEEEGoIVIVo`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
002Yooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05Oooool5o`0000Gooooo
0_l000000ol@413oooooooooo`2Booooo`00Z_ooool01Ol0003ooooooooooooooooo000000Wooooo
1_l00009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`2Cooooo`00
Z_ooool01Ol0003ooooooooooooooooo000001Wooooo00?oV9RHob4Q8Oo^k^h01?ooool5o`0009Co
oooo002Zooooo`05o`000?ooooooooooooooool000002Oooool6o`0000_ooooo00?oV9RHob4Q8Oo^
k^h00oooool01?m4A4CogMgMooooool0002Eooooo`00Z_ooool01Ol0003oQhN7oooooonYZJWo0000
01_ooooo00?oMgMgofIVI_ooool00_ooool01?oMgMgoEEEEooooool0002Eooooo`00ZOooool00ol@
413o0000ogMgM`02o`000003oiRHV?oooooooooo01[ooooo00?o0000ooooooooool00_ooool00omg
MgOoc<c<o`00002Eooooo`00aoooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?ok^k^odA4
A?l00000UOooool00<Oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03ogMgMol0003ooooo
09Cooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -20 0 ]
[.5 1.0125 20 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.69472 .457 Mdot
.72431 .43977 Mdot
.46389 .29147 Mdot
.35835 .61778 Mdot
.28736 .57017 Mdot
.48432 .29378 Mdot
.65971 .37478 Mdot
.6733 .36703 Mdot
.44528 .2725 Mdot
.33173 .59808 Mdot
.60137 .30926 Mdot
.55055 .72718 Mdot
.66003 .36766 Mdot
.37937 .66109 Mdot
.50674 .72675 Mdot
.66439 .65023 Mdot
.70893 .47833 Mdot
.28881 .571 Mdot
.62771 .65458 Mdot
.46203 .26579 Mdot
.35617 .36449 Mdot
.36767 .64038 Mdot
.71652 .48285 Mdot
.3744 .66071 Mdot
.6256 .65857 Mdot
.68295 .57067 Mdot
.69375 .45596 Mdot
.6309 .6595 Mdot
.57754 .71289 Mdot
.67179 .34979 Mdot
.65335 .65134 Mdot
.40172 .68141 Mdot
.33322 .41661 Mdot
.71617 .5698 Mdot
.57599 .29066 Mdot
.61486 .32286 Mdot
.44578 .29503 Mdot
.61009 .32531 Mdot
.6815 .37691 Mdot
.57114 .29295 Mdot
.57472 .2924 Mdot
.67972 .57714 Mdot
.61512 .31958 Mdot
.68984 .40951 Mdot
.41171 .68273 Mdot
.68622 .60211 Mdot
.36456 .35138 Mdot
.46159 .71248 Mdot
.69792 .45615 Mdot
.36495 .34832 Mdot
.45647 .72683 Mdot
.66076 .38801 Mdot
.31075 .42825 Mdot
.71873 .51433 Mdot
.65858 .35542 Mdot
.62303 .66155 Mdot
.47938 .2733 Mdot
.47482 .73617 Mdot
.58035 .70506 Mdot
.71165 .57651 Mdot
.36013 .65085 Mdot
.30631 .53624 Mdot
.59736 .68683 Mdot
.50682 .27179 Mdot
.44482 .28466 Mdot
.56758 .31054 Mdot
.72182 .49185 Mdot
.59558 .32008 Mdot
.39059 .66807 Mdot
.402 .32553 Mdot
.48468 .73364 Mdot
.60095 .30858 Mdot
.69493 .57512 Mdot
.36494 .62676 Mdot
.70221 .43603 Mdot
.59283 .31342 Mdot
.28304 .56793 Mdot
.6845 .57668 Mdot
.36231 .34149 Mdot
.33138 .60468 Mdot
.36423 .6428 Mdot
.6097 .29849 Mdot
.57361 .69999 Mdot
.67049 .60059 Mdot
.41998 .69677 Mdot
.63099 .32761 Mdot
.3436 .60407 Mdot
.65656 .64879 Mdot
.63105 .66305 Mdot
.55677 .7274 Mdot
.41246 .30271 Mdot
.72704 .46923 Mdot
.37139 .63628 Mdot
.39703 .68777 Mdot
.45422 .72035 Mdot
.42328 .70108 Mdot
.63154 .66457 Mdot
.34541 .38715 Mdot
.57917 .30046 Mdot
.31635 .43204 Mdot
.59577 .31808 Mdot
.3013 .43777 Mdot
.39704 .6795 Mdot
.50552 .2849 Mdot
.71625 .53124 Mdot
.34247 .3924 Mdot
.58609 .30878 Mdot
.374 .63787 Mdot
.61429 .32512 Mdot
.72667 .46316 Mdot
.65016 .65588 Mdot
.28109 .52109 Mdot
.27021 .54205 Mdot
.69287 .47531 Mdot
.4145 .71236 Mdot
.33772 .60146 Mdot
.37032 .65 Mdot
.72318 .48796 Mdot
.44895 .27284 Mdot
.40069 .30882 Mdot
.72016 .44604 Mdot
.57661 .29691 Mdot
.70426 .4756 Mdot
.28629 .46364 Mdot
.44252 .27959 Mdot
.32888 .41243 Mdot
.33259 .38923 Mdot
.39627 .67414 Mdot
.42585 .70412 Mdot
.28524 .42992 Mdot
.51077 .2868 Mdot
.71938 .44422 Mdot
.66396 .36597 Mdot
.39609 .68968 Mdot
.68051 .59969 Mdot
.65723 .35322 Mdot
.28544 .54521 Mdot
.27487 .52002 Mdot
.69371 .5818 Mdot
.41982 .71375 Mdot
.60922 .32825 Mdot
.67777 .39531 Mdot
.4668 .73393 Mdot
.68576 .59812 Mdot
.28926 .56215 Mdot
.67854 .39597 Mdot
.29862 .46474 Mdot
.64564 .66154 Mdot
.51066 .74074 Mdot
.6204 .31355 Mdot
.46062 .72739 Mdot
.36431 .35855 Mdot
.30459 .50913 Mdot
.66051 .3518 Mdot
.35152 .61241 Mdot
.70589 .46281 Mdot
.69341 .58888 Mdot
.53919 .71803 Mdot
.34082 .39897 Mdot
.46573 .73912 Mdot
.29455 .44132 Mdot
.3393 .38643 Mdot
.3811 .65872 Mdot
.70282 .58959 Mdot
.72188 .53955 Mdot
.48253 .73437 Mdot
.43566 .29089 Mdot
.28605 .57244 Mdot
.60475 .30846 Mdot
.43247 .70417 Mdot
.45125 .71541 Mdot
.53518 .72319 Mdot
.67415 .39675 Mdot
.56776 .28639 Mdot
.38191 .32868 Mdot
.57488 .31442 Mdot
.59702 .29565 Mdot
.51622 .27988 Mdot
.55877 .7213 Mdot
.28423 .50511 Mdot
.30655 .41511 Mdot
.48051 .73381 Mdot
.40015 .67375 Mdot
.54822 .72899 Mdot
.33548 .37721 Mdot
.32825 .37927 Mdot
.70933 .51882 Mdot
.61453 .31467 Mdot
.3494 .62379 Mdot
.61072 .666 Mdot
.43942 .71701 Mdot
.62621 .33137 Mdot
.66844 .36915 Mdot
.53249 .28196 Mdot
.47198 .26369 Mdot
.37991 .33659 Mdot
.55254 .70008 Mdot
.51923 .7194 Mdot
.35519 .63065 Mdot
.32008 .41933 Mdot
.60847 .68522 Mdot
.30553 .51464 Mdot
.70852 .47211 Mdot
.60493 .29441 Mdot
.49994 .7441 Mdot
.64829 .64184 Mdot
.42089 .28817 Mdot
.38911 .31076 Mdot
.30554 .4096 Mdot
.29659 .50577 Mdot
.47321 .73057 Mdot
.69712 .48446 Mdot
.46074 .72908 Mdot
.33041 .42013 Mdot
.26862 .53505 Mdot
.72138 .45578 Mdot
.4661 .71506 Mdot
.65656 .36253 Mdot
.51367 .30341 Mdot
.34358 .60348 Mdot
.37405 .63572 Mdot
.68411 .57988 Mdot
.40014 .69003 Mdot
.61589 .66311 Mdot
.64575 .65385 Mdot
.38667 .33092 Mdot
.58132 .31305 Mdot
.67659 .35474 Mdot
.3619 .35307 Mdot
.68561 .58835 Mdot
.6975 .41361 Mdot
.48828 .28322 Mdot
.35751 .3651 Mdot
.60697 .31567 Mdot
.29417 .53462 Mdot
.49709 .28544 Mdot
.29275 .56678 Mdot
.58417 .70329 Mdot
.52072 .2929 Mdot
.2832 .53412 Mdot
.51145 .72694 Mdot
.32516 .39489 Mdot
.27756 .50377 Mdot
.65771 .37348 Mdot
.72625 .43345 Mdot
.48238 .73769 Mdot
.30686 .42664 Mdot
.32367 .42859 Mdot
.55955 .71931 Mdot
.33352 .38502 Mdot
.33412 .39654 Mdot
.55281 .72173 Mdot
.29321 .57363 Mdot
.58878 .28822 Mdot
.65275 .65204 Mdot
.70709 .47648 Mdot
.39196 .66975 Mdot
.56269 .29869 Mdot
.65776 .35199 Mdot
.33792 .61103 Mdot
.62872 .32779 Mdot
.65583 .37188 Mdot
.37672 .65602 Mdot
.67592 .36068 Mdot
.67388 .60046 Mdot
.49918 .7447 Mdot
.69941 .57153 Mdot
.37809 .66004 Mdot
.67876 .36669 Mdot
.36294 .35149 Mdot
.6792 .58303 Mdot
.36661 .63413 Mdot
.35512 .61962 Mdot
.31745 .42078 Mdot
.64782 .6555 Mdot
.64544 .33547 Mdot
.55191 .72657 Mdot
.53857 .29333 Mdot
.54485 .70767 Mdot
.30605 .49852 Mdot
.29165 .47135 Mdot
.68796 .59653 Mdot
.33903 .38166 Mdot
.48768 .28886 Mdot
.4612 .72255 Mdot
.48116 .72573 Mdot
.41507 .68889 Mdot
.32987 .39871 Mdot
.57266 .69964 Mdot
.64798 .34631 Mdot
.62566 .67082 Mdot
.28691 .42866 Mdot
.47287 .27695 Mdot
.30573 .43836 Mdot
.42076 .69849 Mdot
.71996 .47981 Mdot
.66117 .64192 Mdot
.53435 .29352 Mdot
.71825 .47601 Mdot
.46564 .71723 Mdot
.59335 .31944 Mdot
.31004 .53134 Mdot
.65061 .33602 Mdot
.64043 .64874 Mdot
.54288 .71039 Mdot
.40145 .32475 Mdot
.67802 .59125 Mdot
.66569 .3553 Mdot
.69671 .57351 Mdot
.46154 .73567 Mdot
.45143 .73322 Mdot
.69253 .59347 Mdot
.29723 .48171 Mdot
.37681 .32775 Mdot
.60214 .31247 Mdot
.32562 .412 Mdot
.40911 .31526 Mdot
.69746 .46269 Mdot
.50323 .28817 Mdot
.4302 .72362 Mdot
.51762 .30333 Mdot
.66069 .64128 Mdot
.40763 .31914 Mdot
.53103 .7214 Mdot
.40726 .68066 Mdot
.51899 .27573 Mdot
.34387 .39416 Mdot
.4721 .73336 Mdot
.67687 .5994 Mdot
.39505 .66719 Mdot
.33234 .59742 Mdot
.54332 .70463 Mdot
.47501 .27637 Mdot
.42372 .7167 Mdot
.64213 .65223 Mdot
.63423 .65273 Mdot
.71049 .46683 Mdot
.31747 .41238 Mdot
.28137 .54713 Mdot
.2754 .51126 Mdot
.29697 .46901 Mdot
.54441 .73055 Mdot
.43922 .72597 Mdot
.68674 .5914 Mdot
.36965 .34502 Mdot
.72582 .4304 Mdot
.33156 .41829 Mdot
.6741 .36858 Mdot
.57372 .28683 Mdot
.34516 .60415 Mdot
.30288 .58191 Mdot
.66329 .63853 Mdot
.70051 .44762 Mdot
.69192 .57618 Mdot
.66739 .35707 Mdot
.60028 .69251 Mdot
.33238 .60582 Mdot
.33879 .6124 Mdot
.67827 .38157 Mdot
.32957 .41843 Mdot
.57406 .70614 Mdot
.48776 .72442 Mdot
.68656 .40728 Mdot
.42194 .6913 Mdot
.71367 .55933 Mdot
.41002 .67545 Mdot
.4004 .68276 Mdot
.42285 .68482 Mdot
.68008 .59641 Mdot
.66427 .63374 Mdot
.486 .72514 Mdot
.41129 .29615 Mdot
.50151 .74468 Mdot
.28859 .49177 Mdot
.36677 .63029 Mdot
.4749 .73058 Mdot
.28951 .55779 Mdot
.69366 .47583 Mdot
.44678 .71105 Mdot
.61935 .31547 Mdot
.36913 .63746 Mdot
.60643 .30992 Mdot
.55699 .71035 Mdot
.40715 .69192 Mdot
.6392 .65492 Mdot
.71704 .48347 Mdot
.6817 .3831 Mdot
.59229 .29765 Mdot
.29141 .42594 Mdot
.65805 .35158 Mdot
.42492 .69908 Mdot
.55879 .7081 Mdot
.69316 .47667 Mdot
.327 .39425 Mdot
.72822 .46788 Mdot
.30748 .58791 Mdot
.66355 .38064 Mdot
.30483 .43454 Mdot
.59629 .69081 Mdot
.6704 .38625 Mdot
.61197 .30589 Mdot
.65081 .65589 Mdot
.329 .41928 Mdot
.69493 .46361 Mdot
.40483 .32165 Mdot
.33591 .40271 Mdot
.65999 .35407 Mdot
.41158 .6817 Mdot
.63599 .66502 Mdot
.66889 .35503 Mdot
.70882 .55266 Mdot
.64852 .6618 Mdot
.37151 .63914 Mdot
.68056 .57202 Mdot
.73047 .46862 Mdot
.47814 .74404 Mdot
.34598 .626 Mdot
.47094 .28703 Mdot
.33005 .40072 Mdot
.32714 .40244 Mdot
.34484 .38268 Mdot
.53425 .29959 Mdot
.38425 .32181 Mdot
.57585 .30778 Mdot
.39445 .66934 Mdot
.56952 .30818 Mdot
.30486 .42986 Mdot
.47082 .28809 Mdot
.40902 .67824 Mdot
.60425 .69396 Mdot
.68143 .3985 Mdot
.41533 .30552 Mdot
.36248 .61691 Mdot
.7037 .46529 Mdot
.66639 .39179 Mdot
.51582 .72197 Mdot
.38785 .33336 Mdot
.30743 .5346 Mdot
.42102 .71187 Mdot
.67396 .38987 Mdot
.71154 .54404 Mdot
.67464 .38912 Mdot
.47197 .72617 Mdot
.4382 .70375 Mdot
.71415 .43509 Mdot
.2906 .48954 Mdot
.55325 .72548 Mdot
.37136 .65894 Mdot
.36257 .34759 Mdot
.72201 .42909 Mdot
.29026 .48568 Mdot
.58465 .70773 Mdot
.32197 .3947 Mdot
.29138 .57694 Mdot
.35685 .6307 Mdot
.54362 .72333 Mdot
.28671 .45025 Mdot
.66545 .34714 Mdot
.2839 .49692 Mdot
.41888 .29115 Mdot
.72055 .46605 Mdot
.57647 .30955 Mdot
.35037 .3743 Mdot
.59919 .30876 Mdot
.53115 .73089 Mdot
.29771 .43199 Mdot
.68174 .40675 Mdot
.32305 .59017 Mdot
.33181 .3945 Mdot
.47324 .27353 Mdot
.46703 .73695 Mdot
.54956 .72439 Mdot
.37227 .63953 Mdot
.28107 .54504 Mdot
.7292 .44437 Mdot
.60595 .30291 Mdot
.68415 .37947 Mdot
.38462 .66048 Mdot
.68832 .59648 Mdot
.70495 .52114 Mdot
.31421 .43124 Mdot
.28663 .51926 Mdot
.29214 .53284 Mdot
.3859 .66011 Mdot
.58834 .6966 Mdot
.68233 .59373 Mdot
.36678 .63382 Mdot
.38691 .6628 Mdot
.3939 .32012 Mdot
.68214 .56661 Mdot
.52186 .2904 Mdot
.63773 .64557 Mdot
.41738 .70624 Mdot
.5874 .31747 Mdot
.65303 .3541 Mdot
.32179 .40827 Mdot
.67683 .35497 Mdot
.38694 .3234 Mdot
.32719 .40213 Mdot
.36587 .63363 Mdot
.69128 .45606 Mdot
.36791 .63392 Mdot
.3692 .63661 Mdot
.41764 .68243 Mdot
.43855 .7251 Mdot
.39805 .3047 Mdot
.28618 .5102 Mdot
.58493 .70469 Mdot
.52615 .28476 Mdot
.42405 .28545 Mdot
.45404 .72169 Mdot
.35974 .62999 Mdot
.37341 .65133 Mdot
.69168 .55879 Mdot
.63297 .66842 Mdot
.6721 .38037 Mdot
.71456 .43467 Mdot
.34328 .60839 Mdot
.36858 .34978 Mdot
.44559 .70887 Mdot
.69783 .58696 Mdot
.56342 .29099 Mdot
.63867 .3347 Mdot
.32971 .38675 Mdot
.31624 .43598 Mdot
.3323 .39772 Mdot
.34931 .3808 Mdot
.61488 .32081 Mdot
.46985 .28864 Mdot
.30788 .49864 Mdot
.44988 .73306 Mdot
.34842 .62772 Mdot
.43929 .70703 Mdot
.40433 .31358 Mdot
.29975 .4569 Mdot
.44861 .72904 Mdot
.64423 .672 Mdot
.50383 .30327 Mdot
.34395 .38685 Mdot
.66706 .6144 Mdot
.72349 .46723 Mdot
.39395 .32804 Mdot
.60967 .32492 Mdot
.28151 .53504 Mdot
.36147 .35678 Mdot
.73019 .45777 Mdot
.59806 .68398 Mdot
.49578 .3026 Mdot
.56217 .70734 Mdot
.61053 .68718 Mdot
.50191 .29263 Mdot
.62255 .67164 Mdot
.72022 .49396 Mdot
.32926 .39204 Mdot
.55309 .70719 Mdot
.5584 .71821 Mdot
.52559 .27624 Mdot
.36235 .62231 Mdot
.40859 .30439 Mdot
.47214 .27573 Mdot
.31433 .41113 Mdot
.47504 .27662 Mdot
.64871 .34439 Mdot
.50348 .279 Mdot
.70437 .55098 Mdot
.39087 .67266 Mdot
.7166 .51836 Mdot
.51618 .7315 Mdot
.33784 .60445 Mdot
.65717 .38029 Mdot
.56573 .30094 Mdot
.35557 .64327 Mdot
.28524 .56664 Mdot
.46727 .27764 Mdot
.37646 .3357 Mdot
.62703 .66759 Mdot
.40619 .31604 Mdot
.7172 .48409 Mdot
.58743 .31477 Mdot
.56578 .30121 Mdot
.33388 .40038 Mdot
.68133 .60054 Mdot
.62017 .32826 Mdot
.57544 .29691 Mdot
.31021 .5296 Mdot
.48144 .74315 Mdot
.71837 .54867 Mdot
.57341 .70645 Mdot
.2915 .57008 Mdot
.36907 .63892 Mdot
.52171 .28784 Mdot
.38125 .33319 Mdot
.49858 .72347 Mdot
.48509 .28377 Mdot
.32406 .40898 Mdot
.71212 .53746 Mdot
.62238 .66053 Mdot
.72633 .44517 Mdot
.39936 .69141 Mdot
.57661 .31064 Mdot
.7217 .47328 Mdot
.3484 .36979 Mdot
.35031 .64157 Mdot
.69916 .59173 Mdot
.58605 .70949 Mdot
.37118 .63979 Mdot
.44707 .27891 Mdot
.2894 .55926 Mdot
.36061 .3653 Mdot
.41535 .29919 Mdot
.30327 .52306 Mdot
.71319 .4218 Mdot
.44592 .2776 Mdot
.29753 .52476 Mdot
.28955 .47588 Mdot
.34643 .37874 Mdot
.2904 .50735 Mdot
.42204 .69833 Mdot
.66081 .34978 Mdot
.72439 .43619 Mdot
.43585 .6962 Mdot
.32943 .59727 Mdot
.71909 .51864 Mdot
.31753 .42355 Mdot
.37367 .64384 Mdot
.47619 .74092 Mdot
.69702 .58628 Mdot
.59836 .29044 Mdot
.49214 .26924 Mdot
.32404 .42112 Mdot
.7274 .44914 Mdot
.60986 .29846 Mdot
.44706 .2819 Mdot
.29656 .53971 Mdot
.65689 .34266 Mdot
.69149 .45032 Mdot
.31304 .42521 Mdot
.65863 .37409 Mdot
.41705 .29988 Mdot
.45678 .7262 Mdot
.64846 .66772 Mdot
.48265 .30101 Mdot
.45765 .72705 Mdot
.65901 .63945 Mdot
.38087 .33655 Mdot
.57603 .28614 Mdot
.72723 .46283 Mdot
.67852 .37361 Mdot
.28818 .52768 Mdot
.69543 .57257 Mdot
.72847 .46646 Mdot
.65283 .35341 Mdot
.72163 .52089 Mdot
.56839 .69971 Mdot
.59171 .31219 Mdot
.58039 .70061 Mdot
.46637 .73099 Mdot
.3122 .4237 Mdot
.28449 .50743 Mdot
.58365 .314 Mdot
.68201 .5721 Mdot
.69104 .40631 Mdot
.42471 .70498 Mdot
.63658 .66806 Mdot
.27763 .52504 Mdot
.71306 .51424 Mdot
.5681 .28453 Mdot
.67073 .38107 Mdot
.36373 .34717 Mdot
.283 .56342 Mdot
.41203 .68834 Mdot
.41966 .30821 Mdot
.43272 .70221 Mdot
.66433 .3934 Mdot
.65934 .6384 Mdot
.71811 .46149 Mdot
.5969 .31318 Mdot
.6643 .64112 Mdot
.56478 .72224 Mdot
.35037 .63425 Mdot
.3877 .32954 Mdot
.70626 .51493 Mdot
.29065 .46781 Mdot
.33944 .59976 Mdot
.3511 .64381 Mdot
.3194 .43454 Mdot
.39712 .67546 Mdot
.58691 .28872 Mdot
.33954 .40272 Mdot
.50675 .30178 Mdot
.33257 .39151 Mdot
.32282 .41251 Mdot
.69973 .4842 Mdot
.37726 .34025 Mdot
.31702 .43629 Mdot
.33612 .60909 Mdot
.37916 .64808 Mdot
.6824 .38601 Mdot
.56397 .70218 Mdot
.56525 .71366 Mdot
.53595 .28995 Mdot
.31075 .53159 Mdot
.45967 .71768 Mdot
.67206 .60087 Mdot
.27424 .52586 Mdot
.29358 .44503 Mdot
.71627 .47481 Mdot
.41954 .69838 Mdot
.39464 .31932 Mdot
.32541 .39665 Mdot
.29575 .45255 Mdot
.28003 .53005 Mdot
.67322 .39787 Mdot
.70622 .57371 Mdot
.47191 .27517 Mdot
.65721 .65731 Mdot
.30495 .58503 Mdot
.39624 .32372 Mdot
.31246 .4224 Mdot
.29639 .42464 Mdot
.68843 .59553 Mdot
.70536 .55295 Mdot
.35169 .37203 Mdot
.52912 .28634 Mdot
.62216 .32575 Mdot
.5933 .3069 Mdot
.54065 .7164 Mdot
.65697 .33946 Mdot
.72682 .46445 Mdot
.42237 .70753 Mdot
.29376 .53182 Mdot
.66864 .38539 Mdot
.33503 .39839 Mdot
.7277 .45592 Mdot
.70093 .55971 Mdot
.37092 .65965 Mdot
.36572 .63899 Mdot
.36314 .35208 Mdot
.4027 .68077 Mdot
.67776 .40056 Mdot
.28494 .54956 Mdot
.46106 .28594 Mdot
.63032 .66674 Mdot
.70577 .4646 Mdot
.36894 .35378 Mdot
.57107 .72099 Mdot
.50351 .27341 Mdot
.72174 .43879 Mdot
.27541 .53904 Mdot
.28703 .51011 Mdot
.41811 .70517 Mdot
.36695 .35671 Mdot
.65937 .37982 Mdot
.68207 .59822 Mdot
.71624 .42357 Mdot
.57641 .71225 Mdot
.36138 .63179 Mdot
.61906 .6681 Mdot
.60838 .30756 Mdot
.42662 .70137 Mdot
.27932 .53597 Mdot
.7132 .50495 Mdot
.40797 .68013 Mdot
.27327 .54598 Mdot
.29002 .46815 Mdot
.29936 .41878 Mdot
.50117 .26818 Mdot
.27684 .54817 Mdot
.27891 .55477 Mdot
.27022 .5337 Mdot
.57538 .28711 Mdot
.5188 .72386 Mdot
.3074 .58393 Mdot
.35989 .62107 Mdot
.46633 .73544 Mdot
.64481 .66858 Mdot
.57396 .31305 Mdot
.39889 .32713 Mdot
.47191 .72804 Mdot
.35561 .61997 Mdot
.71532 .50421 Mdot
.663 .65316 Mdot
.46812 .72064 Mdot
.71385 .47138 Mdot
.72018 .55841 Mdot
.48069 .26435 Mdot
.62979 .33375 Mdot
.41356 .31652 Mdot
.59007 .70387 Mdot
.59441 .70195 Mdot
.70727 .50261 Mdot
.65837 .34629 Mdot
.59214 .70103 Mdot
.67189 .39786 Mdot
.7151 .49871 Mdot
.64252 .67138 Mdot
.7079 .55159 Mdot
.30618 .54021 Mdot
.46826 .72222 Mdot
.65183 .35647 Mdot
.47308 .72874 Mdot
.65226 .34882 Mdot
.32974 .59688 Mdot
.5949 .69785 Mdot
.35028 .61343 Mdot
.40168 .67317 Mdot
.33721 .37533 Mdot
.36253 .63549 Mdot
.36245 .34235 Mdot
.70718 .45795 Mdot
.29913 .58091 Mdot
.60656 .67381 Mdot
.47004 .73365 Mdot
.37326 .64852 Mdot
.71971 .5189 Mdot
.36876 .65038 Mdot
.41422 .31265 Mdot
.58807 .70896 Mdot
.47628 .72854 Mdot
.66816 .36644 Mdot
.59106 .30096 Mdot
.69256 .47494 Mdot
.29656 .43111 Mdot
.71486 .5112 Mdot
.37798 .65473 Mdot
.47261 .26944 Mdot
.29808 .47048 Mdot
.28206 .55615 Mdot
.7213 .43666 Mdot
.32496 .59234 Mdot
.61446 .31882 Mdot
.42995 .28751 Mdot
.65383 .65342 Mdot
.51927 .29554 Mdot
.51709 .27623 Mdot
.72358 .42902 Mdot
.28453 .50853 Mdot
.4505 .70937 Mdot
.71348 .5734 Mdot
.71899 .58255 Mdot
.57375 .71431 Mdot
.46224 .26917 Mdot
.28662 .45179 Mdot
.66352 .62857 Mdot
.30137 .55079 Mdot
.30046 .52008 Mdot
.6552 .35982 Mdot
.47705 .26802 Mdot
.32471 .41783 Mdot
.29665 .52752 Mdot
.48059 .26375 Mdot
.34984 .37604 Mdot
.36784 .34173 Mdot
.68509 .59357 Mdot
.43844 .72781 Mdot
.6972 .59586 Mdot
.68125 .36526 Mdot
.37249 .34421 Mdot
.68332 .58703 Mdot
.67152 .60386 Mdot
.32059 .41632 Mdot
.43065 .29567 Mdot
.71298 .52945 Mdot
.48131 .74045 Mdot
.31233 .40374 Mdot
.37304 .66199 Mdot
.28075 .56638 Mdot
.37801 .6479 Mdot
.3752 .34513 Mdot
.67412 .38321 Mdot
.47158 .28383 Mdot
.65487 .36209 Mdot
.39988 .68034 Mdot
.34317 .62966 Mdot
.36329 .62952 Mdot
.55716 .71104 Mdot
.70354 .4928 Mdot
.71526 .56426 Mdot
.48935 .27182 Mdot
.47105 .28116 Mdot
.60857 .67679 Mdot
.70169 .46768 Mdot
.29391 .46823 Mdot
.58722 .70017 Mdot
.36667 .64908 Mdot
.70773 .45943 Mdot
.6378 .67136 Mdot
.62243 .33148 Mdot
.55261 .71021 Mdot
.70812 .49109 Mdot
.38716 .31966 Mdot
.3879 .66572 Mdot
.31455 .43531 Mdot
.28441 .43322 Mdot
.52814 .72944 Mdot
.28944 .57111 Mdot
.72187 .45964 Mdot
.30269 .44264 Mdot
.70588 .4537 Mdot
.52426 .30206 Mdot
.62006 .33132 Mdot
.71419 .46483 Mdot
.3713 .65213 Mdot
.42439 .30713 Mdot
.65812 .34876 Mdot
.41726 .68014 Mdot
.59183 .30979 Mdot
.68919 .57969 Mdot
.71423 .44678 Mdot
.34986 .37595 Mdot
.62433 .67155 Mdot
.66309 .38391 Mdot
.34732 .62065 Mdot
.70872 .54976 Mdot
.66326 .64245 Mdot
.29264 .56984 Mdot
.44023 .70294 Mdot
.46887 .74304 Mdot
.40176 .30875 Mdot
.4432 .71829 Mdot
.59161 .2926 Mdot
.61152 .31746 Mdot
.61076 .30747 Mdot
.69594 .47683 Mdot
.34277 .37504 Mdot
.70722 .56232 Mdot
.32513 .40694 Mdot
.43478 .29432 Mdot
.42007 .68218 Mdot
.34951 .38147 Mdot
.58 .31088 Mdot
.29259 .50073 Mdot
.5507 .72857 Mdot
.46646 .29783 Mdot
.30611 .40716 Mdot
.66676 .38158 Mdot
.70749 .54174 Mdot
.71812 .46841 Mdot
.37321 .33403 Mdot
.40904 .67655 Mdot
.36568 .63724 Mdot
.56973 .30101 Mdot
.36831 .35538 Mdot
.30243 .52365 Mdot
.34372 .39412 Mdot
.57683 .3065 Mdot
.55715 .7065 Mdot
.6866 .57764 Mdot
.47541 .72932 Mdot
.56335 .70444 Mdot
.57767 .28802 Mdot
.71977 .57772 Mdot
.30415 .51985 Mdot
.40339 .69019 Mdot
.72173 .45698 Mdot
.66294 .36427 Mdot
.28651 .47797 Mdot
.62279 .65618 Mdot
.35161 .6263 Mdot
.49421 .73765 Mdot
.5457 .72125 Mdot
.65467 .64927 Mdot
.33531 .38293 Mdot
.48929 .73632 Mdot
.60831 .67539 Mdot
.66059 .65262 Mdot
.44196 .70775 Mdot
.44442 .71161 Mdot
.70959 .4559 Mdot
.53978 .70702 Mdot
.51538 .28626 Mdot
.61767 .67087 Mdot
.36755 .35468 Mdot
.65003 .65151 Mdot
.54186 .71037 Mdot
.71468 .58554 Mdot
.52671 .72979 Mdot
.70475 .51384 Mdot
.69781 .46764 Mdot
.6799 .36177 Mdot
.6574 .64152 Mdot
.50428 .27341 Mdot
.29021 .45202 Mdot
.39986 .32393 Mdot
.70896 .45386 Mdot
.46829 .2656 Mdot
.5699 .31228 Mdot
.4813 .30095 Mdot
.51376 .30021 Mdot
.67399 .38607 Mdot
.72851 .43632 Mdot
.57674 .71728 Mdot
.67125 .38893 Mdot
.29957 .45248 Mdot
.29634 .53607 Mdot
.72327 .57052 Mdot
.34213 .4016 Mdot
.36355 .61723 Mdot
.68624 .40275 Mdot
.44855 .29573 Mdot
.4981 .74 Mdot
.70093 .44406 Mdot
.2728 .52041 Mdot
.71484 .46048 Mdot
.35942 .36924 Mdot
.30624 .51486 Mdot
.41272 .69011 Mdot
.36372 .35694 Mdot
.59081 .29084 Mdot
.44921 .70918 Mdot
.71694 .57593 Mdot
.39897 .32478 Mdot
.64763 .34572 Mdot
.62406 .32533 Mdot
.31878 .42989 Mdot
.70919 .48748 Mdot
.70897 .55707 Mdot
.32392 .40476 Mdot
.66449 .36668 Mdot
.70916 .52624 Mdot
.45201 .73239 Mdot
.66228 .33928 Mdot
.44712 .70559 Mdot
.4188 .71295 Mdot
.30184 .47514 Mdot
.34227 .38402 Mdot
.66005 .65855 Mdot
.44425 .28588 Mdot
.61262 .6776 Mdot
.40139 .69041 Mdot
.39723 .6696 Mdot
.35768 .63819 Mdot
.49374 .73593 Mdot
.39279 .31807 Mdot
.69914 .49388 Mdot
.3036 .41669 Mdot
.31509 .42203 Mdot
.66769 .64561 Mdot
.36006 .35648 Mdot
.295 .50994 Mdot
.36916 .33707 Mdot
.35466 .64758 Mdot
.36541 .64412 Mdot
.69292 .56563 Mdot
.42129 .71739 Mdot
.33494 .38911 Mdot
.35619 .63827 Mdot
.55984 .72786 Mdot
.66574 .36072 Mdot
.47349 .74466 Mdot
.38626 .66183 Mdot
.62107 .33038 Mdot
.66609 .36483 Mdot
.39148 .32461 Mdot
.35265 .37619 Mdot
.51606 .27395 Mdot
.3029 .53866 Mdot
.48263 .72961 Mdot
.41775 .70326 Mdot
.55047 .70669 Mdot
.30403 .54326 Mdot
.64401 .65257 Mdot
.40521 .70505 Mdot
.3877 .6604 Mdot
.29977 .51802 Mdot
.66724 .34717 Mdot
.70958 .46256 Mdot
.42165 .71464 Mdot
.31605 .42008 Mdot
.66008 .65039 Mdot
.27496 .55286 Mdot
.70645 .45194 Mdot
.70276 .59024 Mdot
.72167 .44042 Mdot
.66816 .37848 Mdot
.38506 .33538 Mdot
.30649 .51521 Mdot
.71525 .46114 Mdot
.43985 .27912 Mdot
.58863 .31644 Mdot
.53568 .71961 Mdot
.6827 .37384 Mdot
.72412 .42926 Mdot
.70189 .48501 Mdot
.69789 .44173 Mdot
.62163 .6656 Mdot
.495 .73641 Mdot
.3262 .40839 Mdot
.57512 .30596 Mdot
.44523 .28807 Mdot
.42007 .70194 Mdot
.70874 .58541 Mdot
.50655 .74215 Mdot
.41049 .68807 Mdot
.37878 .64941 Mdot
.37069 .63036 Mdot
.31431 .39824 Mdot
.35053 .61061 Mdot
.36182 .62262 Mdot
.67468 .40234 Mdot
.39446 .3239 Mdot
.34027 .62299 Mdot
.29918 .42004 Mdot
.3038 .58101 Mdot
.27374 .51536 Mdot
.42108 .71061 Mdot
.60369 .68635 Mdot
.70946 .46742 Mdot
.53119 .28966 Mdot
.48023 .26572 Mdot
.28104 .54258 Mdot
.6749 .36963 Mdot
.73265 .45333 Mdot
.40655 .30814 Mdot
.30623 .51009 Mdot
.42547 .68815 Mdot
.55662 .71229 Mdot
.52908 .73019 Mdot
.54369 .72448 Mdot
.41909 .68276 Mdot
.33902 .39261 Mdot
.53663 .2943 Mdot
.52681 .72239 Mdot
.68864 .60017 Mdot
.28147 .56133 Mdot
.29417 .54774 Mdot
.71362 .53428 Mdot
.39934 .68695 Mdot
.65212 .36061 Mdot
.58676 .69714 Mdot
.64529 .33558 Mdot
.71269 .51084 Mdot
.30775 .58603 Mdot
.44608 .70957 Mdot
.45314 .71732 Mdot
.34527 .60503 Mdot
.71604 .53138 Mdot
.71402 .54718 Mdot
.68287 .5714 Mdot
.66609 .35942 Mdot
.46123 .72405 Mdot
.5817 .29361 Mdot
.33451 .3889 Mdot
.72225 .46971 Mdot
.5363 .70617 Mdot
.47147 .28161 Mdot
.65836 .6592 Mdot
.28544 .50075 Mdot
.5732 .71161 Mdot
.30116 .42771 Mdot
.45689 .73731 Mdot
.47187 .28895 Mdot
.68465 .58146 Mdot
.65212 .66592 Mdot
.40202 .30255 Mdot
.48621 .73371 Mdot
.2806 .44832 Mdot
.34958 .3844 Mdot
.30639 .53608 Mdot
.45394 .71634 Mdot
.2817 .50242 Mdot
.66405 .38377 Mdot
.34121 .62402 Mdot
.47958 .73201 Mdot
.37191 .64417 Mdot
.43055 .70477 Mdot
.66219 .35501 Mdot
.64407 .64498 Mdot
.2931 .45891 Mdot
.35391 .37712 Mdot
.65167 .65062 Mdot
.29005 .49956 Mdot
.59152 .30554 Mdot
.39415 .32241 Mdot
.33425 .41075 Mdot
.30789 .54067 Mdot
.45434 .71367 Mdot
.3634 .64958 Mdot
.33894 .38343 Mdot
.42173 .69827 Mdot
.62589 .66225 Mdot
.5103 .29625 Mdot
.65786 .6438 Mdot
.2729 .53751 Mdot
.28074 .50833 Mdot
.6616 .35052 Mdot
.71546 .46313 Mdot
.28512 .5442 Mdot
.46374 .28929 Mdot
.43838 .72219 Mdot
.44196 .70597 Mdot
.70537 .55114 Mdot
.40148 .67671 Mdot
.27287 .53847 Mdot
.41389 .69062 Mdot
.67632 .57631 Mdot
.71953 .52326 Mdot
.35189 .62592 Mdot
.63301 .66204 Mdot
.69796 .47827 Mdot
.29668 .53219 Mdot
.67802 .37808 Mdot
.49811 .72615 Mdot
.67373 .39648 Mdot
.68268 .57051 Mdot
.31026 .43781 Mdot
.72405 .43325 Mdot
.31043 .43841 Mdot
.66944 .62068 Mdot
.38817 .66537 Mdot
.70747 .54763 Mdot
.28384 .46118 Mdot
.49148 .27124 Mdot
.4348 .29743 Mdot
.32166 .39921 Mdot
.72245 .46352 Mdot
.31968 .40969 Mdot
.28674 .53647 Mdot
.55404 .28786 Mdot
.69675 .46398 Mdot
.50773 .3022 Mdot
.45095 .29591 Mdot
.56694 .29865 Mdot
.37525 .64478 Mdot
.47814 .73383 Mdot
.48983 .30043 Mdot
.64634 .33341 Mdot
.71242 .49633 Mdot
.36495 .63571 Mdot
.33806 .40568 Mdot
.51427 .28949 Mdot
.53549 .28047 Mdot
.69455 .56796 Mdot
.64865 .66912 Mdot
.39753 .67066 Mdot
.61003 .31402 Mdot
.4775 .74506 Mdot
.63022 .66434 Mdot
.29892 .54353 Mdot
.39898 .6815 Mdot
.45816 .73406 Mdot
.602 .30652 Mdot
.32134 .42982 Mdot
.54462 .72497 Mdot
.41271 .30243 Mdot
.48765 .74002 Mdot
.31998 .59035 Mdot
.33948 .38355 Mdot
.42798 .69125 Mdot
.29735 .46007 Mdot
.7247 .44459 Mdot
.36889 .64223 Mdot
.5882 .31727 Mdot
.50395 .27454 Mdot
.40912 .67688 Mdot
.3588 .36391 Mdot
.59865 .31553 Mdot
.30136 .4294 Mdot
.30289 .52152 Mdot
.64984 .6618 Mdot
.40046 .67963 Mdot
.40427 .31347 Mdot
.28865 .51201 Mdot
.3755 .64915 Mdot
.46106 .28397 Mdot
.59512 .30428 Mdot
.30897 .40949 Mdot
.46615 .72612 Mdot
.57952 .2999 Mdot
.67323 .37176 Mdot
.28457 .49878 Mdot
.6967 .40948 Mdot
.39191 .68122 Mdot
.3803 .66149 Mdot
.70658 .41816 Mdot
.70413 .55687 Mdot
.46389 .71792 Mdot
.33332 .60021 Mdot
.65679 .37157 Mdot
.50374 .73569 Mdot
.46607 .74256 Mdot
.28285 .45963 Mdot
.64781 .34157 Mdot
.50712 .26863 Mdot
.43968 .29459 Mdot
.29044 .52141 Mdot
.72927 .44259 Mdot
.2956 .48183 Mdot
.50591 .27732 Mdot
.47359 .73751 Mdot
.67011 .39526 Mdot
.66509 .6231 Mdot
.58917 .31122 Mdot
.47163 .2938 Mdot
.70113 .57938 Mdot
.5903 .69373 Mdot
.32059 .59072 Mdot
.64415 .33479 Mdot
.37498 .33358 Mdot
.28337 .55724 Mdot
.6881 .60049 Mdot
.37076 .65644 Mdot
.5345 .71474 Mdot
.41009 .67869 Mdot
.32596 .38647 Mdot
.40334 .3175 Mdot
.35026 .37585 Mdot
.31993 .4286 Mdot
.47682 .72423 Mdot
.67421 .37313 Mdot
.59829 .30104 Mdot
.29634 .43966 Mdot
.66885 .37557 Mdot
.36602 .65798 Mdot
.48772 .29411 Mdot
.66816 .61868 Mdot
.36715 .64967 Mdot
.30968 .5101 Mdot
.5796 .31895 Mdot
.67278 .60512 Mdot
.48963 .26482 Mdot
.45262 .71632 Mdot
.7092 .51832 Mdot
.66761 .38715 Mdot
.43576 .72229 Mdot
.49736 .2727 Mdot
.33508 .40936 Mdot
.46195 .28031 Mdot
.4401 .69732 Mdot
.44877 .71501 Mdot
.31554 .43887 Mdot
.36835 .64916 Mdot
.69564 .49268 Mdot
.6199 .6586 Mdot
.6091 .67923 Mdot
.36216 .62229 Mdot
.70522 .5965 Mdot
.60637 .32027 Mdot
.29641 .4408 Mdot
.54487 .72135 Mdot
.42271 .70119 Mdot
.69474 .46958 Mdot
.59491 .30722 Mdot
.58846 .28583 Mdot
.6635 .35785 Mdot
.49655 .27125 Mdot
.67521 .37166 Mdot
.34476 .60369 Mdot
.71056 .50382 Mdot
.49305 .28109 Mdot
.30709 .42974 Mdot
.43597 .27727 Mdot
.3386 .60343 Mdot
.54666 .2905 Mdot
.43347 .29077 Mdot
.62339 .67038 Mdot
.72337 .48535 Mdot
.33202 .37576 Mdot
.59626 .68716 Mdot
.46843 .73866 Mdot
.41158 .6799 Mdot
.34451 .39197 Mdot
.66216 .35183 Mdot
.69881 .5617 Mdot
.3656 .34397 Mdot
.27277 .53381 Mdot
.70483 .51351 Mdot
.27623 .51041 Mdot
.56213 .70773 Mdot
.70094 .59783 Mdot
.56282 .72689 Mdot
.65367 .35098 Mdot
.72 .46619 Mdot
.27397 .55349 Mdot
.61094 .66593 Mdot
.2824 .51816 Mdot
.45852 .27223 Mdot
.59349 .70192 Mdot
.51269 .29848 Mdot
.56054 .29492 Mdot
.38394 .33241 Mdot
.65603 .37581 Mdot
.35754 .36426 Mdot
.6578 .6385 Mdot
.60952 .31844 Mdot
.57158 .31005 Mdot
.52059 .28482 Mdot
.29582 .43415 Mdot
.64472 .64542 Mdot
.28847 .43394 Mdot
.29257 .42859 Mdot
.60596 .30817 Mdot
.71642 .47335 Mdot
.70266 .46717 Mdot
.30116 .57917 Mdot
.71548 .47153 Mdot
.5051 .28959 Mdot
.55352 .71088 Mdot
.60208 .69019 Mdot
.60627 .32229 Mdot
.65089 .66113 Mdot
.355 .60947 Mdot
.40599 .32284 Mdot
.49684 .29258 Mdot
.66946 .36383 Mdot
.72191 .42502 Mdot
.30069 .4449 Mdot
.69623 .56774 Mdot
.7288 .45346 Mdot
.71996 .44542 Mdot
.72657 .43283 Mdot
.45831 .72592 Mdot
.65611 .37833 Mdot
.72287 .45723 Mdot
.44932 .70688 Mdot
.38125 .66622 Mdot
.33522 .40618 Mdot
.32131 .38986 Mdot
.62962 .65941 Mdot
.32671 .40987 Mdot
.35428 .64037 Mdot
.47496 .27688 Mdot
.33626 .37857 Mdot
.30178 .44731 Mdot
.52362 .28229 Mdot
.53079 .28759 Mdot
.28987 .43119 Mdot
.33932 .37676 Mdot
.69432 .48803 Mdot
.66021 .63564 Mdot
.71693 .57545 Mdot
.42976 .2911 Mdot
.61882 .31736 Mdot
.70594 .54964 Mdot
.41268 .67655 Mdot
.33758 .41062 Mdot
.47638 .28923 Mdot
.69692 .4535 Mdot
.35999 .62685 Mdot
.31904 .41558 Mdot
.2849 .52712 Mdot
.30493 .43199 Mdot
.34063 .39251 Mdot
.72126 .54505 Mdot
.68981 .40681 Mdot
.69181 .59307 Mdot
.41168 .30143 Mdot
.30371 .42451 Mdot
.71301 .52536 Mdot
.3692 .34694 Mdot
.55453 .28539 Mdot
.62093 .6566 Mdot
.36136 .62065 Mdot
.53182 .29053 Mdot
.7171 .48441 Mdot
.68268 .3968 Mdot
.55643 .72908 Mdot
.71609 .46118 Mdot
.35354 .37311 Mdot
.33229 .39304 Mdot
.51578 .28919 Mdot
.71346 .53866 Mdot
.63213 .66407 Mdot
.71774 .45343 Mdot
.571 .30039 Mdot
.40317 .6741 Mdot
.70942 .51883 Mdot
.32463 .41597 Mdot
.70625 .4692 Mdot
.44904 .28919 Mdot
.27795 .53286 Mdot
.42944 .7022 Mdot
.62917 .32942 Mdot
.37436 .64959 Mdot
.56619 .29518 Mdot
.31194 .52416 Mdot
.62361 .67445 Mdot
.41854 .68514 Mdot
.53825 .7176 Mdot
.57257 .31168 Mdot
.43357 .69095 Mdot
.57699 .69636 Mdot
.70089 .5916 Mdot
.69415 .57992 Mdot
.3571 .65025 Mdot
.50067 .2982 Mdot
.3792 .3177 Mdot
.38575 .66419 Mdot
.39483 .30358 Mdot
.59401 .69617 Mdot
.29059 .45046 Mdot
.29024 .57288 Mdot
.4264 .71066 Mdot
.42433 .69552 Mdot
.34959 .6141 Mdot
.40161 .67058 Mdot
.53602 .73125 Mdot
.50355 .27536 Mdot
.50054 .26833 Mdot
.28939 .53563 Mdot
.49749 .74467 Mdot
.27851 .51566 Mdot
.59738 .30624 Mdot
.65744 .64014 Mdot
.3517 .38103 Mdot
.71299 .46889 Mdot
.37088 .6456 Mdot
.45342 .27763 Mdot
.42654 .69102 Mdot
.64384 .66029 Mdot
.50897 .28885 Mdot
.47213 .28602 Mdot
.41503 .30268 Mdot
.27455 .54677 Mdot
.71288 .4408 Mdot
.34183 .60353 Mdot
.28919 .56575 Mdot
.29987 .45091 Mdot
.52239 .73491 Mdot
.71093 .50721 Mdot
.70495 .45588 Mdot
.71065 .43573 Mdot
.34613 .61866 Mdot
.34499 .61699 Mdot
.5701 .2922 Mdot
.71252 .56064 Mdot
.66276 .3923 Mdot
.53168 .2927 Mdot
.38374 .31101 Mdot
.42556 .694 Mdot
.30868 .51343 Mdot
.28802 .50143 Mdot
.43201 .28559 Mdot
.34458 .3855 Mdot
.28016 .50406 Mdot
.34271 .61728 Mdot
.52065 .29096 Mdot
.2765 .55383 Mdot
.72027 .42728 Mdot
.61746 .31162 Mdot
.27611 .5207 Mdot
.32387 .42259 Mdot
.70975 .57867 Mdot
.44424 .72226 Mdot
.29172 .485 Mdot
.6058 .3163 Mdot
.56998 .72162 Mdot
.34391 .38436 Mdot
.30522 .50043 Mdot
.49495 .72995 Mdot
.50094 .27889 Mdot
.32266 .42575 Mdot
.27281 .55421 Mdot
.60647 .68933 Mdot
.29491 .48549 Mdot
.70451 .46173 Mdot
.6077 .68188 Mdot
.41679 .68905 Mdot
.63661 .66874 Mdot
.67833 .35947 Mdot
.45737 .27169 Mdot
.47596 .26738 Mdot
.70574 .54625 Mdot
.54627 .71542 Mdot
.49114 .30195 Mdot
.54102 .71878 Mdot
.29422 .57623 Mdot
.4484 .70607 Mdot
.29935 .58213 Mdot
.61088 .66918 Mdot
.27018 .51817 Mdot
.27648 .52692 Mdot
.59797 .32382 Mdot
.67403 .38092 Mdot
.65964 .35289 Mdot
.50716 .2995 Mdot
.56578 .71016 Mdot
.48823 .26685 Mdot
.69921 .41292 Mdot
.2943 .51119 Mdot
.3951 .31396 Mdot
.35263 .61004 Mdot
.35299 .63772 Mdot
.64466 .66912 Mdot
.34015 .40051 Mdot
.45625 .7124 Mdot
.57497 .2982 Mdot
.43943 .27915 Mdot
.54088 .28392 Mdot
.70044 .54609 Mdot
.70088 .41493 Mdot
.47353 .2841 Mdot
.29597 .57793 Mdot
.28869 .4975 Mdot
.51138 .73934 Mdot
.28379 .42892 Mdot
.47401 .27343 Mdot
.3976 .68646 Mdot
.69612 .45976 Mdot
.42645 .30316 Mdot
.36984 .64135 Mdot
.4451 .29461 Mdot
.3544 .35499 Mdot
.61997 .67355 Mdot
.44458 .71899 Mdot
.61605 .31199 Mdot
.54718 .71904 Mdot
.27034 .52456 Mdot
.31596 .43897 Mdot
.52979 .70984 Mdot
.51057 .27885 Mdot
.44693 .27155 Mdot
.27591 .53475 Mdot
.68267 .60126 Mdot
.69934 .46487 Mdot
.69448 .4875 Mdot
.5712 .29612 Mdot
.38892 .6652 Mdot
.51917 .28887 Mdot
.70258 .56825 Mdot
.43717 .72144 Mdot
.65939 .3714 Mdot
.4297 .28206 Mdot
.36849 .64899 Mdot
.42029 .68615 Mdot
.27898 .52542 Mdot
.30458 .57969 Mdot
.29564 .45864 Mdot
.55296 .2848 Mdot
.48241 .72499 Mdot
.66199 .64055 Mdot
.35149 .62488 Mdot
.70762 .49906 Mdot
.32138 .40686 Mdot
.28511 .50778 Mdot
.46771 .71982 Mdot
.54166 .70813 Mdot
.70442 .48729 Mdot
.65275 .3533 Mdot
.30874 .4251 Mdot
.4834 .72675 Mdot
.37102 .64955 Mdot
.41233 .68651 Mdot
.62182 .66582 Mdot
.36474 .61931 Mdot
.40081 .3248 Mdot
.66977 .60117 Mdot
.29823 .55318 Mdot
.716 .44348 Mdot
.37215 .3426 Mdot
.62687 .65192 Mdot
.5805 .70408 Mdot
.7015 .59826 Mdot
.71758 .49569 Mdot
.5702 .30079 Mdot
.66078 .38552 Mdot
.30971 .52733 Mdot
.43396 .6947 Mdot
.33307 .38795 Mdot
.72172 .45081 Mdot
.45843 .27206 Mdot
.27901 .5123 Mdot
.37582 .33167 Mdot
.35581 .63502 Mdot
.51594 .28264 Mdot
.31396 .40579 Mdot
.71586 .53588 Mdot
.47892 .27558 Mdot
.33554 .40849 Mdot
.29701 .53969 Mdot
.56919 .72044 Mdot
.35899 .36736 Mdot
.31455 .43294 Mdot
.43229 .69637 Mdot
.66844 .62256 Mdot
.64613 .66399 Mdot
.28283 .45685 Mdot
.49354 .26446 Mdot
.32118 .42166 Mdot
.67021 .60605 Mdot
.62375 .6729 Mdot
.44363 .28472 Mdot
.70925 .5529 Mdot
.61836 .65933 Mdot
.30679 .44081 Mdot
.71291 .50517 Mdot
.36325 .34782 Mdot
.70449 .42744 Mdot
.44165 .72333 Mdot
.37734 .63986 Mdot
.50924 .30019 Mdot
.2826 .52189 Mdot
.58639 .29375 Mdot
.61615 .32939 Mdot
.5799 .3152 Mdot
.51006 .3036 Mdot
.36963 .64668 Mdot
.72119 .46068 Mdot
.6708 .38567 Mdot
.69627 .56205 Mdot
.45933 .2875 Mdot
.49191 .29653 Mdot
.64951 .66661 Mdot
.28055 .50755 Mdot
.35145 .6096 Mdot
.45859 .27246 Mdot
.38924 .32947 Mdot
.71202 .52286 Mdot
.26978 .5307 Mdot
.62636 .655 Mdot
.35958 .36725 Mdot
.49024 .74496 Mdot
.69003 .60333 Mdot
.32853 .39394 Mdot
.70962 .53922 Mdot
.4574 .73528 Mdot
.54508 .29133 Mdot
.37282 .34504 Mdot
.54534 .71823 Mdot
.58213 .28766 Mdot
.66804 .39054 Mdot
.48461 .27484 Mdot
.35995 .63354 Mdot
.37926 .32799 Mdot
.29074 .52318 Mdot
.60572 .67075 Mdot
.29514 .44059 Mdot
.70073 .55553 Mdot
.67642 .39121 Mdot
.33928 .37585 Mdot
.58575 .29359 Mdot
.65749 .35152 Mdot
.71426 .58464 Mdot
.41806 .69017 Mdot
.48267 .28672 Mdot
.47941 .29863 Mdot
.29952 .58123 Mdot
.41097 .31775 Mdot
.70201 .44362 Mdot
.54189 .28793 Mdot
.5252 .71927 Mdot
.35564 .64792 Mdot
.34557 .3768 Mdot
.32393 .39391 Mdot
.38128 .33652 Mdot
.43492 .69179 Mdot
.68423 .59014 Mdot
.49721 .26669 Mdot
.44508 .29665 Mdot
.63187 .66956 Mdot
.67397 .38389 Mdot
.27999 .44164 Mdot
.50116 .29036 Mdot
.49828 .7257 Mdot
.42744 .69623 Mdot
.64407 .33597 Mdot
.50186 .28847 Mdot
.3592 .35671 Mdot
.62292 .32802 Mdot
.70021 .57886 Mdot
.53335 .72715 Mdot
.69065 .57461 Mdot
.28028 .50474 Mdot
.47575 .26981 Mdot
.59195 .29904 Mdot
.30426 .42795 Mdot
.38232 .31616 Mdot
.49946 .30225 Mdot
.70878 .45653 Mdot
.41333 .68614 Mdot
.41476 .70635 Mdot
.36991 .65087 Mdot
.50991 .74225 Mdot
.27116 .53257 Mdot
.61617 .33004 Mdot
.57194 .30306 Mdot
.53217 .72699 Mdot
.27441 .54975 Mdot
.50587 .27245 Mdot
.50952 .28768 Mdot
.62939 .33109 Mdot
.34026 .39184 Mdot
.50201 .27066 Mdot
.43262 .69842 Mdot
.39998 .30667 Mdot
.70849 .58647 Mdot
.67505 .3833 Mdot
.42241 .70031 Mdot
.5013 .30266 Mdot
.72209 .5488 Mdot
.55922 .71423 Mdot
.38456 .66261 Mdot
.28583 .46619 Mdot
.66382 .38684 Mdot
.70626 .4139 Mdot
.40473 .32405 Mdot
.38682 .66092 Mdot
.5889 .30177 Mdot
.35902 .36139 Mdot
.40262 .30677 Mdot
.72226 .43799 Mdot
.45186 .2958 Mdot
.67858 .3824 Mdot
.30852 .41278 Mdot
.29881 .55244 Mdot
.46578 .27781 Mdot
.43553 .29456 Mdot
.64433 .6536 Mdot
.29985 .57583 Mdot
.28451 .49424 Mdot
.71806 .48931 Mdot
.65469 .36738 Mdot
.64347 .66239 Mdot
.49705 .72635 Mdot
.34336 .61318 Mdot
.66091 .34991 Mdot
.71539 .51633 Mdot
.39486 .68198 Mdot
.35326 .62103 Mdot
.4293 .71654 Mdot
.69591 .59145 Mdot
.72409 .46935 Mdot
.50384 .74037 Mdot
.63343 .66067 Mdot
.57269 .70497 Mdot
.70919 .46547 Mdot
.71121 .44609 Mdot
.57525 .70899 Mdot
.64551 .65515 Mdot
.71254 .55397 Mdot
.6717 .37773 Mdot
.66765 .3903 Mdot
.72112 .44441 Mdot
.63978 .67139 Mdot
.65795 .34596 Mdot
.6884 .57037 Mdot
.47666 .29453 Mdot
.57832 .69781 Mdot
.73204 .45308 Mdot
.59374 .70005 Mdot
.66377 .3834 Mdot
.51034 .73488 Mdot
.59565 .69611 Mdot
.36615 .62159 Mdot
.41609 .68704 Mdot
.28523 .56029 Mdot
.3027 .43122 Mdot
.28991 .43059 Mdot
.66279 .35262 Mdot
.34844 .60976 Mdot
.68039 .57693 Mdot
.34604 .61302 Mdot
.40039 .67601 Mdot
.49755 .72857 Mdot
.5146 .7186 Mdot
.72158 .43902 Mdot
.68121 .57396 Mdot
.39787 .3056 Mdot
.45004 .2729 Mdot
.54762 .70609 Mdot
.66534 .38817 Mdot
.70676 .47332 Mdot
.66351 .39254 Mdot
.5076 .27824 Mdot
.47949 .28727 Mdot
.32872 .40474 Mdot
.3229 .42565 Mdot
.48565 .27792 Mdot
.40322 .3019 Mdot
.51029 .73282 Mdot
.70709 .55258 Mdot
.6685 .6095 Mdot
.40966 .69379 Mdot
.41867 .71325 Mdot
.28401 .52323 Mdot
.36063 .36465 Mdot
.57853 .29805 Mdot
.53689 .72239 Mdot
.34105 .61919 Mdot
.31307 .4324 Mdot
.67535 .35141 Mdot
.29757 .49861 Mdot
.67335 .38809 Mdot
.30191 .53567 Mdot
.44488 .28593 Mdot
.36609 .64536 Mdot
.35155 .61465 Mdot
.57463 .30378 Mdot
.41823 .30173 Mdot
.52094 .29354 Mdot
.28443 .51627 Mdot
.41434 .69921 Mdot
.51443 .28547 Mdot
.73241 .45857 Mdot
.71258 .50981 Mdot
.31654 .40146 Mdot
.35925 .62837 Mdot
.43133 .71367 Mdot
.62251 .67269 Mdot
.29881 .45107 Mdot
.30948 .4246 Mdot
.69561 .41172 Mdot
.48106 .74122 Mdot
.58649 .28438 Mdot
.31772 .43446 Mdot
.71864 .43318 Mdot
.4824 .28467 Mdot
.29873 .44922 Mdot
.28558 .43516 Mdot
.31364 .58975 Mdot
.29345 .41869 Mdot
.71065 .48285 Mdot
.6882 .57945 Mdot
.64895 .64452 Mdot
.72064 .50719 Mdot
.30506 .53965 Mdot
.29244 .49934 Mdot
.37495 .3442 Mdot
.59136 .31868 Mdot
.44861 .732 Mdot
.29159 .51014 Mdot
.71477 .42552 Mdot
.65583 .66086 Mdot
.65541 .65153 Mdot
.64815 .64824 Mdot
.69312 .56637 Mdot
.44868 .71259 Mdot
.40111 .3204 Mdot
.70859 .45943 Mdot
.65797 .64422 Mdot
.40497 .70172 Mdot
.6985 .49171 Mdot
.65394 .36029 Mdot
.60485 .67484 Mdot
.71978 .46164 Mdot
.53223 .73035 Mdot
.65546 .37287 Mdot
.5382 .71344 Mdot
.5379 .28465 Mdot
.37102 .35014 Mdot
.67006 .36683 Mdot
.42939 .28368 Mdot
.52085 .28606 Mdot
.51123 .2936 Mdot
.72675 .46004 Mdot
.42642 .2969 Mdot
.67939 .57604 Mdot
.37536 .33338 Mdot
.48272 .72708 Mdot
.30648 .51632 Mdot
.38775 .32898 Mdot
.7188 .44549 Mdot
.70799 .41698 Mdot
.3233 .59132 Mdot
.388 .67099 Mdot
.60596 .31144 Mdot
.29208 .5353 Mdot
.55499 .71055 Mdot
.29842 .54595 Mdot
.50206 .27354 Mdot
.46617 .71467 Mdot
.42681 .69596 Mdot
.60548 .2979 Mdot
.28151 .5225 Mdot
.71338 .44324 Mdot
.64523 .65172 Mdot
.54523 .29484 Mdot
.28972 .52057 Mdot
.28153 .50702 Mdot
.38158 .66084 Mdot
.68674 .57922 Mdot
.53509 .29463 Mdot
.65151 .33717 Mdot
.35879 .34666 Mdot
.52892 .73248 Mdot
.48104 .73594 Mdot
.38924 .66866 Mdot
.56372 .70551 Mdot
.3736 .33985 Mdot
.66918 .3715 Mdot
.40024 .67423 Mdot
.36454 .35294 Mdot
.39686 .66736 Mdot
.71847 .53104 Mdot
.38153 .33149 Mdot
.31209 .40448 Mdot
.33477 .40763 Mdot
.36547 .63351 Mdot
.32188 .59536 Mdot
.46477 .72594 Mdot
.65778 .34305 Mdot
.29724 .43069 Mdot
.42642 .28852 Mdot
.6978 .45581 Mdot
.31453 .59002 Mdot
.62877 .66147 Mdot
.65099 .33906 Mdot
.51088 .28537 Mdot
.31734 .59202 Mdot
.28591 .5572 Mdot
.60176 .69434 Mdot
.37858 .66513 Mdot
.36368 .63121 Mdot
.65771 .36157 Mdot
.66351 .34427 Mdot
.68604 .60418 Mdot
.34581 .37489 Mdot
.70944 .51656 Mdot
.58963 .31307 Mdot
.31653 .59234 Mdot
.3297 .38941 Mdot
.68577 .59447 Mdot
.32472 .39075 Mdot
.68093 .36655 Mdot
.47411 .73041 Mdot
.68779 .5788 Mdot
.31996 .40157 Mdot
.60346 .6841 Mdot
.65286 .65794 Mdot
.50397 .72849 Mdot
.37967 .6525 Mdot
.7027 .44983 Mdot
.70719 .46146 Mdot
.68111 .57959 Mdot
.33185 .39528 Mdot
.35597 .63765 Mdot
.36586 .62546 Mdot
.3851 .65444 Mdot
.71412 .51896 Mdot
.36804 .64463 Mdot
.70044 .43645 Mdot
.56675 .69977 Mdot
.53384 .28036 Mdot
.34968 .61706 Mdot
.67249 .36397 Mdot
.37264 .63717 Mdot
.27599 .50871 Mdot
.55656 .72466 Mdot
.61758 .6699 Mdot
.66657 .37235 Mdot
.3995 .68649 Mdot
.35897 .3595 Mdot
.34108 .60464 Mdot
.30384 .53126 Mdot
.61009 .30739 Mdot
.46198 .72896 Mdot
.70913 .52571 Mdot
.71671 .45075 Mdot
.45654 .28138 Mdot
.67769 .40113 Mdot
.49033 .27101 Mdot
.66022 .63541 Mdot
.33736 .38304 Mdot
.38866 .31825 Mdot
.49748 .72708 Mdot
.47713 .73669 Mdot
.34553 .3888 Mdot
.69086 .5584 Mdot
.39823 .32543 Mdot
.42216 .71714 Mdot
.64685 .66825 Mdot
.27734 .5365 Mdot
.29837 .54066 Mdot
.30606 .58238 Mdot
.69975 .5659 Mdot
.70991 .41859 Mdot
.65837 .36451 Mdot
.4933 .30249 Mdot
.26944 .52666 Mdot
.63604 .32863 Mdot
.67462 .35666 Mdot
.38607 .33404 Mdot
.67549 .39119 Mdot
.35091 .62708 Mdot
.28949 .43334 Mdot
.70645 .57821 Mdot
.30143 .4392 Mdot
.45073 .73204 Mdot
.44776 .29782 Mdot
.33627 .39082 Mdot
.28887 .56446 Mdot
.67839 .37531 Mdot
.4722 .28044 Mdot
.4149 .68885 Mdot
.70633 .4634 Mdot
.67058 .63063 Mdot
.35483 .35868 Mdot
.61787 .66872 Mdot
.61646 .66638 Mdot
.69306 .59555 Mdot
.28889 .45565 Mdot
.36765 .33081 Mdot
.61287 .66729 Mdot
.57249 .3083 Mdot
.30629 .49002 Mdot
.41283 .3079 Mdot
.47335 .26883 Mdot
.49621 .28096 Mdot
.46281 .73846 Mdot
.5169 .27411 Mdot
.56964 .71634 Mdot
.54524 .29469 Mdot
.61625 .31735 Mdot
.4476 .70843 Mdot
.50642 .28706 Mdot
.31356 .43864 Mdot
.43344 .70195 Mdot
.69364 .58284 Mdot
.53421 .2866 Mdot
.36693 .62213 Mdot
.40841 .29773 Mdot
.56867 .2992 Mdot
.33192 .39654 Mdot
.56756 .72363 Mdot
.66997 .38078 Mdot
.7153 .48194 Mdot
.51291 .72418 Mdot
.29252 .51911 Mdot
.67799 .58961 Mdot
.30887 .50745 Mdot
.28574 .49863 Mdot
.57624 .69964 Mdot
.72104 .48769 Mdot
.30522 .41012 Mdot
.29787 .53737 Mdot
.29462 .57011 Mdot
.49837 .28003 Mdot
.36633 .35037 Mdot
.32212 .42258 Mdot
.41382 .68864 Mdot
.39421 .31773 Mdot
.67373 .37001 Mdot
.38304 .66573 Mdot
.51656 .29476 Mdot
.29887 .42149 Mdot
.35588 .62244 Mdot
.63193 .66076 Mdot
.7021 .58886 Mdot
.31846 .39371 Mdot
.30411 .52192 Mdot
.69079 .58139 Mdot
.38863 .66745 Mdot
.30538 .54652 Mdot
.35751 .34993 Mdot
.43989 .7078 Mdot
.72397 .4371 Mdot
.71919 .42622 Mdot
.46275 .26996 Mdot
.65184 .35164 Mdot
.46986 .29726 Mdot
.3024 .53989 Mdot
.3242 .59528 Mdot
.32867 .41019 Mdot
.60873 .67037 Mdot
.56988 .71791 Mdot
.46048 .27594 Mdot
.7116 .44246 Mdot
.64096 .33763 Mdot
.55973 .72391 Mdot
.43838 .70489 Mdot
.36193 .62785 Mdot
.3782 .33591 Mdot
.69816 .4627 Mdot
.36027 .62741 Mdot
.32967 .38341 Mdot
.44409 .70854 Mdot
.28659 .53961 Mdot
.53499 .28248 Mdot
.32992 .42065 Mdot
.71957 .51371 Mdot
.32546 .39851 Mdot
.50508 .2921 Mdot
.50368 .72199 Mdot
.56719 .70713 Mdot
.30834 .58574 Mdot
.7099 .48415 Mdot
.72181 .55085 Mdot
.48429 .28848 Mdot
.37005 .34417 Mdot
.62772 .65882 Mdot
.64041 .6533 Mdot
.43171 .70055 Mdot
.50016 .27315 Mdot
.46659 .26431 Mdot
.32746 .38925 Mdot
.34209 .3879 Mdot
.55106 .70278 Mdot
.4489 .28615 Mdot
.36634 .64491 Mdot
.64296 .66828 Mdot
.68268 .37898 Mdot
.69645 .57358 Mdot
.6097 .32507 Mdot
.68361 .39102 Mdot
.43584 .72486 Mdot
.47959 .72212 Mdot
.57212 .29482 Mdot
.5824 .31838 Mdot
.38654 .33528 Mdot
.56645 .69664 Mdot
.27673 .51782 Mdot
.4917 .72857 Mdot
.49463 .27073 Mdot
.3602 .64661 Mdot
.70758 .43499 Mdot
.34989 .3736 Mdot
.63359 .33354 Mdot
.32896 .59695 Mdot
.64112 .64581 Mdot
.40053 .31611 Mdot
.31213 .43567 Mdot
.29733 .43975 Mdot
.43872 .71781 Mdot
.36628 .64338 Mdot
.46522 .2693 Mdot
.5975 .69048 Mdot
.59076 .31315 Mdot
.38015 .33964 Mdot
.70235 .56468 Mdot
.37011 .63642 Mdot
.69436 .47738 Mdot
.68085 .37722 Mdot
.30284 .48629 Mdot
.2786 .55304 Mdot
.34061 .6049 Mdot
.62379 .65409 Mdot
.55932 .29355 Mdot
.63337 .65614 Mdot
.64407 .65844 Mdot
.32029 .41816 Mdot
.62475 .65644 Mdot
.37683 .66536 Mdot
.39172 .68382 Mdot
.29961 .45116 Mdot
.6784 .36371 Mdot
.45013 .73008 Mdot
.30502 .44169 Mdot
.55188 .72746 Mdot
.67934 .39716 Mdot
.63119 .65744 Mdot
.66399 .3574 Mdot
.3819 .33732 Mdot
.57069 .29866 Mdot
.29766 .55455 Mdot
.38991 .32978 Mdot
.67293 .60806 Mdot
.7207 .46167 Mdot
.65817 .38321 Mdot
.29659 .53922 Mdot
.66879 .36106 Mdot
.46871 .27794 Mdot
.56657 .30138 Mdot
.72281 .52203 Mdot
.49872 .72504 Mdot
.43739 .72536 Mdot
.64489 .342 Mdot
.44427 .27744 Mdot
.72126 .44499 Mdot
.58721 .31793 Mdot
.58107 .71349 Mdot
.28385 .55525 Mdot
.36646 .63224 Mdot
.6789 .37449 Mdot
.39007 .32458 Mdot
.69943 .5962 Mdot
.30163 .52913 Mdot
.70364 .41254 Mdot
.45136 .28078 Mdot
.44247 .70356 Mdot
.62008 .33039 Mdot
.3873 .31466 Mdot
.5772 .30592 Mdot
.4093 .69997 Mdot
.34131 .3842 Mdot
.32435 .38843 Mdot
.71795 .55626 Mdot
.34623 .39126 Mdot
.35859 .3625 Mdot
.56922 .30754 Mdot
.67931 .6012 Mdot
.40529 .30324 Mdot
.41266 .68764 Mdot
.65894 .64099 Mdot
.32474 .40993 Mdot
.70194 .46406 Mdot
.62295 .667 Mdot
.33153 .40399 Mdot
.56929 .69913 Mdot
.69218 .57506 Mdot
.52331 .28002 Mdot
.43166 .69692 Mdot
.61544 .32062 Mdot
.59454 .31138 Mdot
.35312 .37361 Mdot
.58897 .29547 Mdot
.55146 .72747 Mdot
.72328 .48492 Mdot
.64326 .64642 Mdot
.28799 .53937 Mdot
.69665 .49731 Mdot
.32886 .38668 Mdot
.31278 .58556 Mdot
.43397 .69738 Mdot
.48195 .2874 Mdot
.40618 .30548 Mdot
.55072 .70369 Mdot
.71055 .46362 Mdot
.55975 .72176 Mdot
.62046 .66286 Mdot
.63603 .65521 Mdot
.49546 .30235 Mdot
.55874 .70881 Mdot
.36767 .64543 Mdot
.64935 .34456 Mdot
.55317 .73099 Mdot
.40839 .70289 Mdot
.35684 .36733 Mdot
.61798 .67029 Mdot
.61149 .31169 Mdot
.70729 .55408 Mdot
.48509 .2867 Mdot
.68168 .59231 Mdot
.7025 .55791 Mdot
.7229 .46832 Mdot
.63745 .32968 Mdot
.61352 .66846 Mdot
.61146 .30053 Mdot
.70731 .58855 Mdot
.41689 .71096 Mdot
.70381 .43518 Mdot
.36386 .33606 Mdot
.67594 .60189 Mdot
.71405 .48287 Mdot
.66607 .61932 Mdot
.69873 .46507 Mdot
.424 .6967 Mdot
.42023 .69894 Mdot
.53152 .71061 Mdot
.37746 .33224 Mdot
.36878 .65079 Mdot
.28956 .42776 Mdot
.28948 .54321 Mdot
.68849 .5972 Mdot
.30716 .4276 Mdot
.58637 .69839 Mdot
.29793 .46249 Mdot
.37408 .66077 Mdot
.35641 .62589 Mdot
.64332 .64927 Mdot
.50627 .73399 Mdot
.38356 .32482 Mdot
.71082 .43764 Mdot
.40824 .70482 Mdot
.39321 .31053 Mdot
.45036 .70707 Mdot
.55312 .72422 Mdot
.39505 .68872 Mdot
.48255 .28672 Mdot
.7069 .56173 Mdot
.29219 .42891 Mdot
.69031 .46425 Mdot
.37575 .6503 Mdot
.29195 .46949 Mdot
.30858 .53427 Mdot
.35837 .62854 Mdot
.69481 .48409 Mdot
.62119 .66546 Mdot
.7127 .48908 Mdot
.70689 .50526 Mdot
.43864 .70485 Mdot
.70383 .57211 Mdot
.72457 .46991 Mdot
.6392 .65415 Mdot
.39976 .31604 Mdot
.55356 .28675 Mdot
.47308 .73357 Mdot
.30133 .52634 Mdot
.42128 .68356 Mdot
.29194 .48859 Mdot
.29041 .44198 Mdot
.31882 .42697 Mdot
.45448 .716 Mdot
.43762 .27827 Mdot
.29421 .48276 Mdot
.38102 .32831 Mdot
.72258 .51911 Mdot
.71876 .57062 Mdot
.58847 .31372 Mdot
.36373 .35194 Mdot
.32028 .4235 Mdot
.41539 .70225 Mdot
.52403 .73119 Mdot
.57839 .29307 Mdot
.71638 .53479 Mdot
.46927 .73124 Mdot
.34323 .3971 Mdot
.5344 .28849 Mdot
.48474 .29853 Mdot
.56981 .30759 Mdot
.66926 .61915 Mdot
.34993 .6305 Mdot
.34275 .39589 Mdot
.6025 .678 Mdot
.3015 .43085 Mdot
.29742 .41538 Mdot
.42792 .28305 Mdot
.35923 .63886 Mdot
.5949 .69757 Mdot
.52483 .28643 Mdot
.29475 .4934 Mdot
.71682 .53671 Mdot
.30454 .54024 Mdot
.60872 .30159 Mdot
.69486 .59778 Mdot
.48973 .2749 Mdot
.33392 .41381 Mdot
.36477 .65184 Mdot
.69921 .56133 Mdot
.6945 .55498 Mdot
.69729 .57775 Mdot
.29013 .53818 Mdot
.48017 .26629 Mdot
.36302 .3429 Mdot
.41826 .69133 Mdot
.72081 .49115 Mdot
.3133 .59031 Mdot
.42263 .68583 Mdot
.66769 .38901 Mdot
.62506 .66881 Mdot
.72541 .44208 Mdot
.61227 .67506 Mdot
.70554 .59382 Mdot
.49597 .29837 Mdot
.34017 .5995 Mdot
.42698 .69988 Mdot
.46054 .72803 Mdot
.29732 .49946 Mdot
.69988 .48136 Mdot
.49186 .73112 Mdot
.49027 .74492 Mdot
.44218 .72158 Mdot
.36005 .62445 Mdot
.43848 .726 Mdot
.28391 .44472 Mdot
.33129 .40845 Mdot
.57782 .71306 Mdot
.38373 .65719 Mdot
.69909 .49608 Mdot
.70803 .57972 Mdot
.60006 .68845 Mdot
.65965 .34871 Mdot
.67307 .60272 Mdot
.52768 .28745 Mdot
.54265 .29499 Mdot
.39276 .30811 Mdot
.28847 .57013 Mdot
.63177 .65469 Mdot
.33719 .60435 Mdot
.6562 .34473 Mdot
.29451 .52134 Mdot
.71239 .50394 Mdot
.28267 .50172 Mdot
.5432 .7186 Mdot
.29641 .55578 Mdot
.348 .37767 Mdot
.62175 .32673 Mdot
.64435 .66747 Mdot
.30168 .49889 Mdot
.69355 .57831 Mdot
.4683 .73176 Mdot
.43906 .71426 Mdot
.70944 .41646 Mdot
.27498 .5268 Mdot
.35906 .34582 Mdot
.44044 .69874 Mdot
.49859 .74329 Mdot
.66229 .3543 Mdot
.2991 .55114 Mdot
.66761 .393 Mdot
.63417 .66566 Mdot
.72385 .5483 Mdot
.71138 .45687 Mdot
.59554 .31454 Mdot
.55543 .72344 Mdot
.29502 .56155 Mdot
.49043 .27683 Mdot
.55799 .69844 Mdot
.38693 .32103 Mdot
.2875 .4689 Mdot
.45357 .7289 Mdot
.40205 .32134 Mdot
.40655 .70312 Mdot
.58401 .30412 Mdot
.3452 .60565 Mdot
.61612 .67468 Mdot
.46068 .71213 Mdot
.5265 .29423 Mdot
.49636 .28161 Mdot
.37936 .32677 Mdot
.47988 .743 Mdot
.40056 .69879 Mdot
.69781 .55764 Mdot
.47335 .26746 Mdot
.72519 .45583 Mdot
.70225 .45558 Mdot
.42911 .28516 Mdot
.70633 .49291 Mdot
.28122 .50693 Mdot
.46344 .71306 Mdot
.58322 .30397 Mdot
.58053 .30865 Mdot
.48545 .27684 Mdot
.4312 .29103 Mdot
.47973 .28693 Mdot
.62787 .66744 Mdot
.72497 .48016 Mdot
.49821 .73347 Mdot
.38146 .65722 Mdot
.35059 .61154 Mdot
.70326 .56346 Mdot
.5664 .72147 Mdot
.33072 .60368 Mdot
.27848 .53687 Mdot
.50225 .29155 Mdot
.67559 .39441 Mdot
.66504 .62792 Mdot
.65176 .34332 Mdot
.44469 .71152 Mdot
.55852 .28756 Mdot
.7114 .53674 Mdot
.29328 .55836 Mdot
.63793 .66845 Mdot
.28145 .55944 Mdot
.68135 .37323 Mdot
.69416 .55691 Mdot
.55076 .71355 Mdot
.44568 .70815 Mdot
.56566 .71252 Mdot
.29934 .46613 Mdot
.69645 .6016 Mdot
.66021 .37816 Mdot
.64754 .66433 Mdot
.29671 .4616 Mdot
.61646 .67954 Mdot
.46004 .73697 Mdot
.39076 .66419 Mdot
.43807 .72283 Mdot
.41243 .69109 Mdot
.70028 .57966 Mdot
.54924 .72247 Mdot
.33807 .40619 Mdot
.42309 .69877 Mdot
.62642 .32616 Mdot
.36653 .65562 Mdot
.35301 .61427 Mdot
.35143 .63869 Mdot
.39948 .68477 Mdot
.67194 .60596 Mdot
.64985 .64753 Mdot
.65201 .34634 Mdot
.49367 .74129 Mdot
.59869 .32034 Mdot
.47935 .27873 Mdot
.35702 .36936 Mdot
.70258 .58147 Mdot
.28133 .55843 Mdot
.58933 .28885 Mdot
.49599 .73806 Mdot
.39096 .30781 Mdot
.40674 .6864 Mdot
.35002 .3716 Mdot
.29054 .43225 Mdot
.29496 .56321 Mdot
.49167 .30348 Mdot
.67245 .37355 Mdot
.39676 .68484 Mdot
.72381 .45087 Mdot
.71473 .47301 Mdot
.4305 .7038 Mdot
.68128 .36298 Mdot
.59397 .31106 Mdot
.38904 .32845 Mdot
.35069 .6311 Mdot
.41942 .69779 Mdot
.70838 .49743 Mdot
.36114 .35032 Mdot
.57754 .70252 Mdot
.28672 .5155 Mdot
.33354 .60122 Mdot
.34016 .40424 Mdot
.55256 .72048 Mdot
.65401 .34845 Mdot
.30362 .41359 Mdot
.33972 .61785 Mdot
.48762 .72779 Mdot
.60709 .67442 Mdot
.30227 .58074 Mdot
.46652 .2654 Mdot
.43672 .70166 Mdot
.43059 .69252 Mdot
.69261 .57358 Mdot
.57249 .30116 Mdot
.71321 .44062 Mdot
.70796 .53197 Mdot
.31923 .42616 Mdot
.56664 .29707 Mdot
.35684 .61155 Mdot
.6037 .30292 Mdot
.62427 .66912 Mdot
.47007 .73868 Mdot
.65978 .37692 Mdot
.70373 .50269 Mdot
.71428 .51238 Mdot
.45219 .7204 Mdot
.64274 .66113 Mdot
.42232 .68419 Mdot
.36805 .34681 Mdot
.35409 .37158 Mdot
.44542 .70849 Mdot
.70873 .4747 Mdot
.42039 .68644 Mdot
.67932 .36883 Mdot
.30419 .50097 Mdot
.71313 .4648 Mdot
.40336 .316 Mdot
.49197 .30104 Mdot
.45486 .27156 Mdot
.34337 .37995 Mdot
.62122 .6603 Mdot
.68446 .58668 Mdot
.72102 .43579 Mdot
.56805 .71428 Mdot
.50525 .29168 Mdot
.28493 .53102 Mdot
.4049 .67413 Mdot
.3387 .40851 Mdot
.61374 .31907 Mdot
.72005 .50941 Mdot
.56376 .70046 Mdot
.30187 .55239 Mdot
.5254 .73075 Mdot
.31759 .42005 Mdot
.35333 .62877 Mdot
.2975 .55593 Mdot
.43587 .29224 Mdot
.60828 .67747 Mdot
.28286 .43782 Mdot
.38752 .32253 Mdot
.49826 .30455 Mdot
.59863 .31711 Mdot
.47976 .26422 Mdot
.27948 .55992 Mdot
.32189 .42911 Mdot
.71643 .4669 Mdot
.36142 .63674 Mdot
.32094 .41308 Mdot
.4888 .29435 Mdot
.33063 .3881 Mdot
.36208 .62023 Mdot
.6925 .46024 Mdot
.47416 .27517 Mdot
.42569 .69016 Mdot
.61338 .66998 Mdot
.69138 .59837 Mdot
.39611 .32037 Mdot
.56328 .71982 Mdot
.26924 .53676 Mdot
.43194 .30004 Mdot
.52356 .29497 Mdot
.43813 .70928 Mdot
.28521 .55139 Mdot
.37535 .64362 Mdot
.67382 .38053 Mdot
.52602 .72866 Mdot
.57442 .3037 Mdot
.40108 .67824 Mdot
.40667 .68236 Mdot
.52329 .72401 Mdot
.7224 .57348 Mdot
.35541 .36222 Mdot
.39651 .66985 Mdot
.36906 .62739 Mdot
.70448 .43615 Mdot
.59527 .70223 Mdot
.51022 .7292 Mdot
.70871 .56556 Mdot
.30771 .52329 Mdot
.66453 .35323 Mdot
.40802 .67578 Mdot
.6034 .29538 Mdot
.28631 .53822 Mdot
.43186 .71225 Mdot
.56946 .69739 Mdot
.71085 .44549 Mdot
.33829 .60746 Mdot
.71515 .456 Mdot
.47546 .7367 Mdot
.67932 .60495 Mdot
.58425 .31578 Mdot
.40773 .69487 Mdot
.31949 .43181 Mdot
.38986 .31313 Mdot
.43194 .72082 Mdot
.27957 .52517 Mdot
.61647 .67534 Mdot
.31659 .4267 Mdot
.67353 .38796 Mdot
.548 .28604 Mdot
.48085 .28792 Mdot
.6548 .33535 Mdot
.68102 .59765 Mdot
.38958 .32562 Mdot
.33521 .38837 Mdot
.6048 .678 Mdot
.27081 .51769 Mdot
.5658 .29521 Mdot
.37015 .63088 Mdot
.34463 .61511 Mdot
.37771 .33599 Mdot
.53862 .28563 Mdot
.69574 .44068 Mdot
.68418 .60433 Mdot
.69155 .56097 Mdot
.29589 .49599 Mdot
.39423 .32032 Mdot
.33798 .59883 Mdot
.36464 .64682 Mdot
.43237 .29717 Mdot
.70616 .56247 Mdot
.29074 .54571 Mdot
.3233 .38931 Mdot
.6573 .34409 Mdot
.3972 .31152 Mdot
.71423 .46505 Mdot
.40923 .30778 Mdot
.36199 .3453 Mdot
.66675 .61479 Mdot
.41341 .69706 Mdot
.67054 .37718 Mdot
.41441 .30684 Mdot
.72613 .4411 Mdot
.44729 .71365 Mdot
.29779 .43384 Mdot
.34214 .38104 Mdot
.71189 .58638 Mdot
.48262 .27403 Mdot
.28205 .54915 Mdot
.45129 .73182 Mdot
.29525 .57052 Mdot
.70406 .55893 Mdot
.44755 .28118 Mdot
.30332 .41869 Mdot
.67801 .39696 Mdot
.41898 .68517 Mdot
.28922 .54136 Mdot
.66916 .37555 Mdot
.33401 .40945 Mdot
.48009 .7274 Mdot
.51587 .72527 Mdot
.6153 .66444 Mdot
.66054 .35572 Mdot
.57277 .70751 Mdot
.36772 .65953 Mdot
.58449 .30416 Mdot
.30983 .51434 Mdot
.38611 .31597 Mdot
.54783 .72921 Mdot
.56923 .30765 Mdot
.42705 .29751 Mdot
.49092 .26416 Mdot
.35387 .35738 Mdot
.384 .32453 Mdot
.59994 .31361 Mdot
.30883 .42038 Mdot
.37564 .3289 Mdot
.57321 .30187 Mdot
.54009 .72245 Mdot
.40781 .67667 Mdot
.6005 .69034 Mdot
.33199 .4157 Mdot
.32764 .39948 Mdot
.71281 .56552 Mdot
.65664 .65418 Mdot
.30215 .42302 Mdot
.38272 .65108 Mdot
.68798 .56372 Mdot
.66029 .3803 Mdot
.31476 .5929 Mdot
.66471 .3438 Mdot
.60687 .67704 Mdot
.51902 .30327 Mdot
.39203 .32504 Mdot
.36112 .63537 Mdot
.57203 .28436 Mdot
.31678 .59193 Mdot
.40878 .67577 Mdot
.63787 .6685 Mdot
.39702 .66772 Mdot
.42497 .70022 Mdot
.6721 .58672 Mdot
.33958 .39658 Mdot
.6816 .5774 Mdot
.66848 .3792 Mdot
.30505 .50271 Mdot
.35784 .36348 Mdot
.66059 .35298 Mdot
.37267 .65484 Mdot
.35783 .37058 Mdot
.36257 .63018 Mdot
.38755 .6604 Mdot
.48905 .74675 Mdot
.29073 .57738 Mdot
.47435 .28257 Mdot
.27808 .55475 Mdot
.70441 .48118 Mdot
.70984 .52303 Mdot
.28037 .52958 Mdot
.55467 .69982 Mdot
.5805 .70024 Mdot
.53044 .2787 Mdot
.7141 .47295 Mdot
.28562 .49538 Mdot
.67055 .35973 Mdot
.53769 .73479 Mdot
.53531 .71115 Mdot
.6501 .33816 Mdot
.35805 .61862 Mdot
.7216 .43537 Mdot
.71098 .56241 Mdot
.56275 .29382 Mdot
.72345 .43759 Mdot
.57175 .70631 Mdot
.63479 .66458 Mdot
.65459 .34706 Mdot
.39455 .6681 Mdot
.57194 .30303 Mdot
.43411 .72603 Mdot
.64251 .66379 Mdot
.71186 .46377 Mdot
.41671 .70741 Mdot
.69939 .50162 Mdot
.32773 .40311 Mdot
.49218 .74474 Mdot
.28336 .52962 Mdot
.56702 .71068 Mdot
.40732 .31764 Mdot
.72198 .53168 Mdot
.72061 .44287 Mdot
.6839 .38075 Mdot
.70665 .4496 Mdot
.71903 .55277 Mdot
.64632 .33427 Mdot
.67085 .60071 Mdot
.37538 .65108 Mdot
.71143 .51947 Mdot
.68388 .58946 Mdot
.66078 .3709 Mdot
.29109 .52775 Mdot
.69953 .57402 Mdot
.36723 .34403 Mdot
.4332 .69988 Mdot
.4607 .28968 Mdot
.2755 .5119 Mdot
.70221 .58121 Mdot
.28112 .52572 Mdot
.48154 .29182 Mdot
.34882 .37183 Mdot
.61288 .32705 Mdot
.58971 .29408 Mdot
.28875 .42219 Mdot
.5659 .30335 Mdot
.70018 .47259 Mdot
.40039 .31358 Mdot
.39358 .66875 Mdot
.35239 .63465 Mdot
.27522 .5106 Mdot
.69712 .45784 Mdot
.59447 .29336 Mdot
.30552 .42782 Mdot
.71113 .55228 Mdot
.67951 .39363 Mdot
.39302 .32718 Mdot
.59494 .69874 Mdot
.59641 .31753 Mdot
.33491 .41225 Mdot
.31908 .42103 Mdot
.36229 .62776 Mdot
.44236 .71902 Mdot
.30221 .53309 Mdot
.38055 .32176 Mdot
.66409 .64994 Mdot
.42924 .29067 Mdot
.35634 .64708 Mdot
.66042 .64467 Mdot
.38661 .67049 Mdot
.27502 .5529 Mdot
.60307 .31811 Mdot
.71878 .46872 Mdot
.30171 .48388 Mdot
.48847 .30115 Mdot
.56508 .72615 Mdot
.43103 .70822 Mdot
.5788 .7073 Mdot
.52959 .28672 Mdot
.69939 .45508 Mdot
.48661 .28214 Mdot
.58647 .30432 Mdot
.27804 .51628 Mdot
.6239 .66728 Mdot
.33095 .41864 Mdot
.46401 .27378 Mdot
.65658 .38032 Mdot
.40548 .31448 Mdot
.54984 .28914 Mdot
.31874 .42573 Mdot
.58638 .71045 Mdot
.52232 .27709 Mdot
.29543 .43529 Mdot
.71575 .57248 Mdot
.50414 .74321 Mdot
.71048 .59266 Mdot
.49818 .27252 Mdot
.30887 .58555 Mdot
.66648 .37533 Mdot
.58062 .31844 Mdot
.4206 .71515 Mdot
.3215 .5944 Mdot
.45493 .7355 Mdot
.61815 .31694 Mdot
.58133 .30397 Mdot
.66122 .35993 Mdot
.4873 .28447 Mdot
.70098 .49569 Mdot
.60099 .68484 Mdot
.51435 .27567 Mdot
.39207 .66403 Mdot
.71265 .50357 Mdot
.52893 .71304 Mdot
.50012 .26835 Mdot
.64055 .65216 Mdot
.6895 .60503 Mdot
.28328 .49748 Mdot
.46066 .73253 Mdot
.59477 .31381 Mdot
.4152 .67951 Mdot
.60678 .29511 Mdot
.48832 .28964 Mdot
.30265 .41111 Mdot
.68055 .4034 Mdot
.3465 .61344 Mdot
.36003 .64758 Mdot
.37429 .65931 Mdot
.27264 .52624 Mdot
.71261 .57923 Mdot
.46797 .72206 Mdot
.46934 .71732 Mdot
.66736 .64434 Mdot
.37373 .34675 Mdot
.28174 .56154 Mdot
.48907 .72666 Mdot
.4091 .29976 Mdot
.71335 .55836 Mdot
.36068 .61582 Mdot
.60553 .32266 Mdot
.65681 .65138 Mdot
.65391 .36186 Mdot
.67156 .39784 Mdot
.42459 .30328 Mdot
.70488 .47217 Mdot
.64727 .64326 Mdot
.4508 .26942 Mdot
.72216 .5756 Mdot
.65387 .64301 Mdot
.67091 .60897 Mdot
.67781 .3615 Mdot
.32456 .59874 Mdot
.60394 .32593 Mdot
.34481 .38033 Mdot
.67596 .59861 Mdot
.71322 .50764 Mdot
.55556 .72005 Mdot
.729 .45742 Mdot
.37866 .33475 Mdot
.68274 .58656 Mdot
.35912 .35795 Mdot
.69638 .55321 Mdot
.66366 .37034 Mdot
.56749 .29987 Mdot
.63931 .64937 Mdot
.37363 .6468 Mdot
.55396 .70775 Mdot
.30488 .42834 Mdot
.585 .71041 Mdot
.52405 .28619 Mdot
.36642 .34223 Mdot
.62013 .32261 Mdot
.67126 .59341 Mdot
.65035 .33426 Mdot
.35969 .64788 Mdot
.64002 .66506 Mdot
.41895 .69785 Mdot
.58933 .31618 Mdot
.60114 .67965 Mdot
.38114 .65297 Mdot
.6325 .65431 Mdot
.53904 .29488 Mdot
.42442 .29073 Mdot
.66779 .62035 Mdot
.41485 .30488 Mdot
.36172 .6235 Mdot
.29226 .50416 Mdot
.28577 .56996 Mdot
.4461 .71832 Mdot
.42335 .30166 Mdot
.57565 .70261 Mdot
.37226 .63305 Mdot
.53284 .7303 Mdot
.53682 .29087 Mdot
.3509 .38319 Mdot
.4946 .29484 Mdot
.66977 .60666 Mdot
.29085 .4252 Mdot
.51953 .29125 Mdot
.58643 .69674 Mdot
.32174 .41566 Mdot
.39129 .31286 Mdot
.28604 .54111 Mdot
.38543 .66685 Mdot
.32962 .59657 Mdot
.4912 .2659 Mdot
.66726 .36785 Mdot
.696 .58507 Mdot
.65139 .35221 Mdot
.42084 .29492 Mdot
.42801 .71012 Mdot
.33471 .40267 Mdot
.55294 .2952 Mdot
.66789 .64056 Mdot
.29365 .51233 Mdot
.60585 .32708 Mdot
.62531 .6552 Mdot
.43842 .71367 Mdot
.31832 .59114 Mdot
.34858 .61378 Mdot
.36744 .34018 Mdot
.5667 .29523 Mdot
.29857 .57606 Mdot
.3638 .6404 Mdot
.45282 .28868 Mdot
.29116 .57322 Mdot
.36714 .63088 Mdot
.40253 .3181 Mdot
.43102 .6921 Mdot
.29824 .55341 Mdot
.69042 .57726 Mdot
.51359 .72525 Mdot
.30226 .47132 Mdot
.30188 .48454 Mdot
.44796 .73106 Mdot
.40775 .68541 Mdot
.37502 .32709 Mdot
.70989 .44623 Mdot
.44121 .70447 Mdot
.27306 .51616 Mdot
.68932 .55867 Mdot
.68129 .59311 Mdot
.60661 .67551 Mdot
.67698 .40086 Mdot
.47747 .27559 Mdot
.29973 .52871 Mdot
.36086 .34941 Mdot
.41019 .67924 Mdot
.61948 .67599 Mdot
.27901 .53394 Mdot
.66617 .38776 Mdot
.62284 .66165 Mdot
.68354 .40606 Mdot
.49291 .73941 Mdot
.59818 .32567 Mdot
.36462 .61815 Mdot
.41401 .70374 Mdot
.68423 .57995 Mdot
.61955 .31122 Mdot
.56903 .30874 Mdot
.48667 .29968 Mdot
.30386 .41869 Mdot
.71167 .52052 Mdot
.28962 .53951 Mdot
.59421 .68691 Mdot
.35129 .61663 Mdot
.33835 .5979 Mdot
.68394 .58293 Mdot
.42535 .70418 Mdot
.68017 .5701 Mdot
.36719 .34584 Mdot
.3222 .59688 Mdot
.71856 .4622 Mdot
.71319 .44598 Mdot
.66835 .63473 Mdot
.39173 .30979 Mdot
.71826 .53649 Mdot
.40853 .67487 Mdot
.42427 .29177 Mdot
.30201 .58039 Mdot
.29467 .53951 Mdot
.29699 .57637 Mdot
.72014 .53431 Mdot
.59262 .69313 Mdot
.61917 .6682 Mdot
.45368 .71435 Mdot
.53083 .73146 Mdot
.58466 .30305 Mdot
.46775 .72008 Mdot
.31083 .42621 Mdot
.49016 .29281 Mdot
.40402 .69845 Mdot
.38523 .65795 Mdot
.72024 .46807 Mdot
.30539 .49688 Mdot
.64605 .33965 Mdot
.2938 .43383 Mdot
.48981 .26511 Mdot
.28659 .50389 Mdot
.70359 .49207 Mdot
.42588 .71664 Mdot
.29373 .45228 Mdot
.34428 .3912 Mdot
.35881 .62036 Mdot
.43747 .70196 Mdot
.29837 .45644 Mdot
.65576 .35789 Mdot
.4814 .29909 Mdot
.29204 .43787 Mdot
.5675 .70869 Mdot
.53355 .73006 Mdot
.36143 .64511 Mdot
.69969 .5073 Mdot
.65853 .38459 Mdot
.33091 .40016 Mdot
.4106 .30811 Mdot
.4043 .67344 Mdot
.53667 .71424 Mdot
.30027 .46293 Mdot
.30983 .42366 Mdot
.59928 .68498 Mdot
.28493 .5597 Mdot
.64363 .66296 Mdot
.49447 .73886 Mdot
.56143 .72447 Mdot
.34683 .60612 Mdot
.4367 .29364 Mdot
.67938 .3846 Mdot
.28495 .43121 Mdot
.50208 .2906 Mdot
.68188 .59278 Mdot
.4533 .7147 Mdot
.70143 .45337 Mdot
.71631 .43663 Mdot
.71934 .56176 Mdot
.66519 .35025 Mdot
.71969 .51316 Mdot
.30057 .45402 Mdot
.34934 .62464 Mdot
.57546 .29752 Mdot
.7213 .53776 Mdot
.53676 .72758 Mdot
.70962 .53766 Mdot
.69922 .47598 Mdot
.53855 .72899 Mdot
.6318 .66045 Mdot
.47988 .72568 Mdot
.39012 .66295 Mdot
.28114 .55358 Mdot
.72212 .49191 Mdot
.53337 .71664 Mdot
.46199 .73769 Mdot
.3587 .63515 Mdot
.64351 .64755 Mdot
.29387 .57499 Mdot
.41115 .69159 Mdot
.35061 .62036 Mdot
.49434 .7298 Mdot
.54135 .72736 Mdot
.70138 .43973 Mdot
.61558 .32806 Mdot
.60505 .67382 Mdot
.43586 .29944 Mdot
.69661 .56344 Mdot
.29443 .48373 Mdot
.71104 .53282 Mdot
.61778 .65786 Mdot
.67112 .36498 Mdot
.72485 .44182 Mdot
.46747 .27705 Mdot
.66987 .37165 Mdot
.57225 .30329 Mdot
.64612 .648 Mdot
.45981 .29674 Mdot
.30813 .51562 Mdot
.59903 .31897 Mdot
.60644 .67982 Mdot
.66384 .3694 Mdot
.66978 .61605 Mdot
.58853 .70821 Mdot
.48953 .73485 Mdot
.31142 .41436 Mdot
.28401 .44096 Mdot
.58997 .3064 Mdot
.28734 .51788 Mdot
.62391 .65959 Mdot
.69789 .57814 Mdot
.29164 .51485 Mdot
.69958 .59639 Mdot
.39546 .32567 Mdot
.70973 .55714 Mdot
.37845 .33713 Mdot
.728 .46595 Mdot
.45822 .73153 Mdot
.30502 .48444 Mdot
.29748 .4588 Mdot
.54372 .71459 Mdot
.30602 .41349 Mdot
.39492 .67704 Mdot
.63361 .65008 Mdot
.37558 .65254 Mdot
.38418 .31083 Mdot
.28586 .49103 Mdot
.68071 .58542 Mdot
.35836 .36483 Mdot
.65493 .37354 Mdot
.57573 .70868 Mdot
.29762 .41714 Mdot
.64215 .66218 Mdot
.68591 .56197 Mdot
.71878 .48064 Mdot
.67278 .60726 Mdot
.41839 .30139 Mdot
.35026 .36545 Mdot
.36547 .65053 Mdot
.35614 .36652 Mdot
.58263 .30622 Mdot
.5587 .29391 Mdot
.4607 .28409 Mdot
.32502 .5921 Mdot
.50538 .28941 Mdot
.30418 .57984 Mdot
.72556 .47246 Mdot
.30456 .51962 Mdot
.37175 .65142 Mdot
.70487 .56909 Mdot
.60336 .68508 Mdot
.30694 .49734 Mdot
.28281 .56075 Mdot
.56219 .29806 Mdot
.57183 .2944 Mdot
.31794 .39848 Mdot
.54292 .72696 Mdot
.53038 .72621 Mdot
.34166 .60732 Mdot
.59286 .30612 Mdot
.63953 .65978 Mdot
.61269 .32914 Mdot
.64136 .66775 Mdot
.28617 .49013 Mdot
.52016 .29726 Mdot
.53387 .28044 Mdot
.70015 .56325 Mdot
.455 .71575 Mdot
.71992 .56746 Mdot
.49821 .73639 Mdot
.54779 .28783 Mdot
.30874 .50241 Mdot
.47909 .28388 Mdot
.61943 .31623 Mdot
.51682 .2976 Mdot
.28782 .48168 Mdot
.60726 .69018 Mdot
.68424 .38594 Mdot
.58428 .70647 Mdot
.43178 .2836 Mdot
.39672 .68027 Mdot
.29811 .44487 Mdot
.35761 .37064 Mdot
.66309 .6365 Mdot
.69552 .59629 Mdot
.27896 .55235 Mdot
.37138 .65186 Mdot
.6682 .61267 Mdot
.37003 .65054 Mdot
.36888 .65043 Mdot
.39065 .6695 Mdot
.58929 .31399 Mdot
.58742 .70402 Mdot
.37453 .64834 Mdot
.38198 .32414 Mdot
.29786 .58195 Mdot
.52883 .28043 Mdot
.68447 .57818 Mdot
.29454 .52127 Mdot
.69899 .5592 Mdot
.55734 .70905 Mdot
.67324 .35097 Mdot
.7106 .58233 Mdot
.64263 .65441 Mdot
.71984 .53156 Mdot
.57691 .31601 Mdot
.28202 .54636 Mdot
.31479 .42436 Mdot
.6409 .33523 Mdot
.38088 .32847 Mdot
.29818 .42608 Mdot
.39894 .3205 Mdot
.35497 .61211 Mdot
.7144 .46894 Mdot
.30284 .41856 Mdot
.66057 .3894 Mdot
.42774 .28444 Mdot
.49825 .74517 Mdot
.42014 .68998 Mdot
.52746 .286 Mdot
.31376 .4161 Mdot
.56599 .71043 Mdot
.59057 .69914 Mdot
.4321 .2825 Mdot
.64419 .33668 Mdot
.58564 .30841 Mdot
.29297 .53007 Mdot
.6978 .45776 Mdot
.7208 .47296 Mdot
.6604 .38206 Mdot
.57613 .28464 Mdot
.42479 .6962 Mdot
.42371 .68933 Mdot
.5504 .71712 Mdot
.3993 .6842 Mdot
.409 .30939 Mdot
.29953 .43141 Mdot
.72231 .44817 Mdot
.63857 .64698 Mdot
.65668 .65991 Mdot
.3701 .65509 Mdot
.4233 .70708 Mdot
.48473 .27108 Mdot
.63591 .66836 Mdot
.29929 .55038 Mdot
.7112 .52264 Mdot
.43342 .69418 Mdot
.28981 .48535 Mdot
.72372 .46922 Mdot
.3885 .31501 Mdot
.66608 .36654 Mdot
.44213 .27361 Mdot
.44635 .27123 Mdot
.29095 .47469 Mdot
.6963 .56564 Mdot
.29833 .42645 Mdot
.41143 .31255 Mdot
.35183 .37443 Mdot
.28726 .56292 Mdot
.45238 .72345 Mdot
.37713 .33446 Mdot
.54298 .29229 Mdot
.68344 .39593 Mdot
.48831 .73947 Mdot
.3399 .62374 Mdot
.56527 .30487 Mdot
.35803 .62459 Mdot
.27964 .53143 Mdot
.58351 .29625 Mdot
.72265 .44068 Mdot
.28251 .55201 Mdot
.60662 .31778 Mdot
.71782 .47903 Mdot
.6434 .6495 Mdot
.53605 .72719 Mdot
.69159 .58821 Mdot
.70655 .49456 Mdot
.42484 .69713 Mdot
.42566 .30344 Mdot
.72095 .45649 Mdot
.68703 .59616 Mdot
.66709 .60924 Mdot
.448 .27679 Mdot
.29083 .57102 Mdot
.68305 .38621 Mdot
.37671 .64708 Mdot
.52129 .2997 Mdot
.29913 .50965 Mdot
.72824 .44606 Mdot
.37727 .66541 Mdot
.41115 .67967 Mdot
.29275 .51009 Mdot
.28029 .56284 Mdot
.28931 .51734 Mdot
.56952 .30311 Mdot
.64162 .65286 Mdot
.6772 .57846 Mdot
.57194 .3118 Mdot
.28039 .50315 Mdot
.29226 .47998 Mdot
.35863 .35958 Mdot
.42553 .69479 Mdot
.27361 .54913 Mdot
.71719 .51421 Mdot
.6018 .69596 Mdot
.35223 .37405 Mdot
.30729 .58661 Mdot
.37876 .31689 Mdot
.30478 .58374 Mdot
.67884 .37949 Mdot
.65058 .66115 Mdot
.29364 .54319 Mdot
.32519 .41788 Mdot
.42157 .69224 Mdot
.4131 .6903 Mdot
.29049 .50488 Mdot
.40767 .68969 Mdot
.71477 .47751 Mdot
.71649 .58326 Mdot
.2946 .51767 Mdot
.43924 .28789 Mdot
.5265 .28194 Mdot
.50045 .28173 Mdot
.35782 .63805 Mdot
.52003 .71705 Mdot
.53906 .73381 Mdot
.66916 .60798 Mdot
.5711 .29834 Mdot
.7246 .47085 Mdot
.71084 .51856 Mdot
.67983 .59125 Mdot
.42585 .28648 Mdot
.28716 .51848 Mdot
.69956 .50566 Mdot
.56566 .29866 Mdot
.59215 .30817 Mdot
.50472 .26835 Mdot
.5062 .29274 Mdot
.48966 .27581 Mdot
.70416 .57729 Mdot
.71542 .42017 Mdot
.57456 .7183 Mdot
.71737 .43704 Mdot
.40342 .3004 Mdot
.36914 .34485 Mdot
.50172 .26782 Mdot
.6604 .37338 Mdot
.70583 .50582 Mdot
.42893 .69238 Mdot
.33117 .60369 Mdot
.53059 .28488 Mdot
.27494 .52509 Mdot
.72143 .50609 Mdot
.32099 .59305 Mdot
.63641 .67208 Mdot
.67081 .39131 Mdot
.32772 .40961 Mdot
.36911 .65819 Mdot
.48591 .2984 Mdot
.3077 .58317 Mdot
.3397 .39355 Mdot
.57331 .71336 Mdot
.72112 .5192 Mdot
.67495 .37695 Mdot
.59584 .70141 Mdot
.30754 .44083 Mdot
.65085 .64138 Mdot
.58381 .29722 Mdot
.46712 .27166 Mdot
.35864 .35508 Mdot
.71236 .56678 Mdot
.4587 .72178 Mdot
.33218 .4093 Mdot
.46414 .73996 Mdot
.51755 .28799 Mdot
.28429 .55273 Mdot
.51456 .28191 Mdot
.70047 .44063 Mdot
.46059 .27066 Mdot
.37096 .66068 Mdot
.68154 .57047 Mdot
.58645 .30693 Mdot
.52784 .73296 Mdot
.36025 .36302 Mdot
.45182 .2823 Mdot
.29579 .45955 Mdot
.65827 .65274 Mdot
.60334 .67559 Mdot
.28545 .42807 Mdot
.36967 .66088 Mdot
.65854 .37507 Mdot
.67618 .57816 Mdot
.65559 .37623 Mdot
.28942 .57285 Mdot
.63949 .33491 Mdot
.66609 .36551 Mdot
.53635 .70645 Mdot
.28096 .54822 Mdot
.42453 .70742 Mdot
.38415 .65776 Mdot
.66937 .39463 Mdot
.5787 .7052 Mdot
.66716 .61291 Mdot
.58487 .69717 Mdot
.47553 .7241 Mdot
.65935 .37847 Mdot
.33727 .38696 Mdot
.59174 .70049 Mdot
.29026 .57438 Mdot
.59977 .31393 Mdot
.51471 .72603 Mdot
.29882 .43373 Mdot
.28568 .50201 Mdot
.27469 .54036 Mdot
.28336 .51286 Mdot
.37752 .66041 Mdot
.42457 .71254 Mdot
.30238 .48249 Mdot
.64649 .33374 Mdot
.29764 .48538 Mdot
.31195 .5211 Mdot
.62465 .32839 Mdot
.27981 .56054 Mdot
.37117 .63139 Mdot
.64367 .66654 Mdot
.65194 .65944 Mdot
.46583 .29064 Mdot
.63319 .33344 Mdot
.37257 .33318 Mdot
.3362 .59717 Mdot
.70591 .41446 Mdot
.68529 .58564 Mdot
.28375 .4595 Mdot
.46357 .7129 Mdot
.61827 .65948 Mdot
.6823 .59548 Mdot
.55513 .7169 Mdot
.70944 .55496 Mdot
.30022 .44655 Mdot
.36499 .65698 Mdot
.6892 .57439 Mdot
.72297 .54764 Mdot
.40637 .68878 Mdot
.71054 .5524 Mdot
.72967 .46514 Mdot
.57048 .2997 Mdot
.67734 .37171 Mdot
.65876 .37615 Mdot
.50468 .2977 Mdot
.71569 .44379 Mdot
.44774 .7082 Mdot
.49168 .29929 Mdot
.35644 .6177 Mdot
.65979 .37992 Mdot
.45794 .73783 Mdot
.71334 .44519 Mdot
.37718 .64017 Mdot
.54201 .70428 Mdot
.40122 .32031 Mdot
.29201 .50885 Mdot
.68848 .60236 Mdot
.35825 .35354 Mdot
.59854 .31774 Mdot
.72105 .42989 Mdot
.31053 .50888 Mdot
.65951 .63984 Mdot
.33256 .59548 Mdot
.39552 .68406 Mdot
.65871 .64004 Mdot
.60239 .69122 Mdot
.34251 .38883 Mdot
.48995 .30117 Mdot
.44946 .27219 Mdot
.43265 .70247 Mdot
.71467 .44827 Mdot
.29714 .56046 Mdot
.30014 .47373 Mdot
.28067 .44606 Mdot
.57491 .70109 Mdot
.46938 .71743 Mdot
.4829 .74632 Mdot
.45617 .71735 Mdot
.46649 .28615 Mdot
.3503 .38247 Mdot
.55848 .71863 Mdot
.27895 .51734 Mdot
.44686 .70577 Mdot
.68616 .57538 Mdot
.73227 .45608 Mdot
.48949 .27214 Mdot
.61604 .32191 Mdot
.2883 .43805 Mdot
.52249 .27739 Mdot
.43289 .70204 Mdot
.66335 .64895 Mdot
.58773 .29488 Mdot
.69652 .47412 Mdot
.29323 .49521 Mdot
.4894 .297 Mdot
.30355 .50293 Mdot
.70769 .44733 Mdot
.72835 .4466 Mdot
.43036 .70646 Mdot
.33887 .37313 Mdot
.46198 .27309 Mdot
.36304 .64653 Mdot
.52807 .28701 Mdot
.38284 .33427 Mdot
.61157 .32746 Mdot
.44219 .70565 Mdot
.59706 .68443 Mdot
.65229 .36151 Mdot
.35062 .63885 Mdot
.65417 .65172 Mdot
.62307 .66361 Mdot
.43541 .28767 Mdot
.30367 .47624 Mdot
.2909 .49366 Mdot
.71762 .4271 Mdot
.69212 .4083 Mdot
.4904 .74417 Mdot
.44801 .2788 Mdot
.60887 .68051 Mdot
.66517 .3607 Mdot
.72323 .47977 Mdot
.68959 .40483 Mdot
.66071 .36917 Mdot
.42714 .69447 Mdot
.28083 .53069 Mdot
.70705 .49068 Mdot
.35404 .37327 Mdot
.52037 .73665 Mdot
.29668 .46071 Mdot
.35565 .36247 Mdot
.29621 .43752 Mdot
.68423 .37018 Mdot
.4991 .27493 Mdot
.70641 .54052 Mdot
.66361 .39048 Mdot
.66767 .36137 Mdot
.35953 .34475 Mdot
.69125 .59799 Mdot
.67081 .61772 Mdot
.72004 .51388 Mdot
.38056 .32919 Mdot
.28551 .52457 Mdot
.57671 .69773 Mdot
.49998 .28266 Mdot
.36448 .35305 Mdot
.56065 .28968 Mdot
.55921 .29524 Mdot
.69357 .44361 Mdot
.42055 .68152 Mdot
.66785 .60902 Mdot
.36446 .62126 Mdot
.45401 .7241 Mdot
.66742 .38652 Mdot
.72459 .47658 Mdot
.60172 .29954 Mdot
.43798 .70739 Mdot
.47277 .7305 Mdot
.42041 .29124 Mdot
.30623 .43001 Mdot
.54251 .28931 Mdot
.44764 .71323 Mdot
.51278 .29333 Mdot
.69927 .60138 Mdot
.32324 .42575 Mdot
.53609 .71285 Mdot
.57637 .291 Mdot
.33382 .40142 Mdot
.31311 .43793 Mdot
.33117 .59634 Mdot
.70705 .55575 Mdot
.71194 .43401 Mdot
.28922 .56917 Mdot
.61378 .31347 Mdot
.60856 .31665 Mdot
.68433 .40346 Mdot
.42901 .69608 Mdot
.57288 .28898 Mdot
.35701 .36884 Mdot
.34771 .63376 Mdot
.64402 .64544 Mdot
.70929 .58035 Mdot
.47803 .74447 Mdot
.61418 .66781 Mdot
.66485 .37475 Mdot
.28922 .47271 Mdot
.49013 .74328 Mdot
.50642 .27452 Mdot
.6957 .484 Mdot
.70953 .56488 Mdot
.29338 .55139 Mdot
.58322 .3157 Mdot
.32298 .58992 Mdot
.72127 .4836 Mdot
.43101 .69044 Mdot
.66239 .36039 Mdot
.32973 .40907 Mdot
.30989 .41306 Mdot
.28599 .4656 Mdot
.72199 .48809 Mdot
.32665 .41473 Mdot
.72086 .55804 Mdot
.55519 .71454 Mdot
.45057 .7217 Mdot
.66093 .34962 Mdot
.28476 .5269 Mdot
.35904 .3659 Mdot
.3891 .33211 Mdot
.54442 .72594 Mdot
.44131 .71703 Mdot
.6379 .33065 Mdot
.28441 .53365 Mdot
.3745 .65659 Mdot
.34382 .38859 Mdot
.52843 .71051 Mdot
.31386 .58733 Mdot
.29627 .42421 Mdot
.64985 .66789 Mdot
.70307 .47987 Mdot
.30448 .4143 Mdot
.73283 .45252 Mdot
.37168 .65657 Mdot
.57355 .71033 Mdot
.70642 .43659 Mdot
.71534 .50777 Mdot
.29205 .45072 Mdot
.60767 .3221 Mdot
.57539 .7047 Mdot
.37301 .63192 Mdot
.5249 .7155 Mdot
.32474 .40562 Mdot
.64259 .33591 Mdot
.52867 .29655 Mdot
.40288 .30842 Mdot
.41352 .31094 Mdot
.55072 .29001 Mdot
.62177 .32927 Mdot
.40136 .67156 Mdot
.60026 .68809 Mdot
.52172 .7169 Mdot
.65808 .34052 Mdot
.60428 .69352 Mdot
.37372 .64684 Mdot
.35485 .61987 Mdot
.52883 .2875 Mdot
.68214 .37432 Mdot
.60647 .67565 Mdot
.56324 .71586 Mdot
.28283 .49707 Mdot
.72118 .438 Mdot
.37269 .63836 Mdot
.63943 .33015 Mdot
.43539 .28581 Mdot
.63339 .32834 Mdot
.36756 .62879 Mdot
.30673 .43002 Mdot
.59905 .29935 Mdot
.58155 .30696 Mdot
.44541 .29179 Mdot
.44746 .29106 Mdot
.37016 .62901 Mdot
.64808 .34338 Mdot
.60084 .69347 Mdot
.58525 .69981 Mdot
.31739 .41454 Mdot
.29985 .5404 Mdot
.39539 .67874 Mdot
.67141 .61891 Mdot
.35481 .36462 Mdot
.36056 .6434 Mdot
.70425 .44749 Mdot
.48298 .27781 Mdot
.39606 .32632 Mdot
.72402 .46082 Mdot
.39441 .3236 Mdot
.63498 .33369 Mdot
.4554 .73746 Mdot
.29318 .56154 Mdot
.6704 .63314 Mdot
.30355 .48703 Mdot
.33108 .40139 Mdot
.42537 .69319 Mdot
.42076 .30311 Mdot
.41163 .31585 Mdot
.66467 .62846 Mdot
.67267 .37893 Mdot
.34533 .37951 Mdot
.63937 .65787 Mdot
.28994 .48627 Mdot
.49161 .29115 Mdot
.31862 .39467 Mdot
.442 .70343 Mdot
.6997 .56136 Mdot
.6106 .67607 Mdot
.30087 .41126 Mdot
.32614 .40127 Mdot
.29033 .42477 Mdot
.6067 .3182 Mdot
.6763 .60289 Mdot
.55935 .29134 Mdot
.39786 .32765 Mdot
.57966 .7152 Mdot
.46707 .72398 Mdot
.72595 .46736 Mdot
.34621 .62708 Mdot
.65026 .34716 Mdot
.71837 .50854 Mdot
.28885 .52186 Mdot
.303 .44694 Mdot
.60622 .29922 Mdot
.35732 .37171 Mdot
.66333 .64199 Mdot
.65794 .66301 Mdot
.68366 .57751 Mdot
.68196 .4022 Mdot
.40755 .70462 Mdot
.47584 .26333 Mdot
.29352 .49374 Mdot
.56735 .29942 Mdot
.65969 .64226 Mdot
.38548 .6608 Mdot
.28432 .52997 Mdot
.56274 .29962 Mdot
.28165 .43914 Mdot
.6468 .34158 Mdot
.29411 .46331 Mdot
.66597 .62468 Mdot
.3643 .62873 Mdot
.30476 .4329 Mdot
.68746 .58939 Mdot
.57467 .30017 Mdot
.70596 .58099 Mdot
.30155 .44585 Mdot
.38389 .33536 Mdot
.56712 .29778 Mdot
.45734 .71526 Mdot
.70818 .53519 Mdot
.71365 .41954 Mdot
.67339 .60079 Mdot
.36183 .35684 Mdot
.37094 .33918 Mdot
.4897 .27425 Mdot
.65949 .37098 Mdot
.51372 .30256 Mdot
.27984 .54707 Mdot
.57124 .69882 Mdot
.45057 .28883 Mdot
.68152 .60131 Mdot
.5028 .30293 Mdot
.55053 .70348 Mdot
.59994 .3245 Mdot
.53073 .28353 Mdot
.34696 .62263 Mdot
.6503 .65062 Mdot
.32361 .40084 Mdot
.29656 .57423 Mdot
.55834 .71323 Mdot
.45969 .71305 Mdot
.31394 .42875 Mdot
.3723 .63349 Mdot
.64945 .34817 Mdot
.4999 .72303 Mdot
.55108 .72754 Mdot
.3895 .32916 Mdot
.71868 .50198 Mdot
.44579 .2738 Mdot
.29451 .47705 Mdot
.35375 .63921 Mdot
.37561 .63849 Mdot
.63005 .66499 Mdot
.72055 .50627 Mdot
.58691 .31246 Mdot
.57305 .72004 Mdot
.38676 .32478 Mdot
.68456 .56744 Mdot
.6837 .57176 Mdot
.46659 .72848 Mdot
.3016 .43388 Mdot
.67916 .39355 Mdot
.37438 .66095 Mdot
.34739 .37653 Mdot
.46748 .71749 Mdot
.55077 .28689 Mdot
.36973 .33874 Mdot
.4043 .32464 Mdot
.70364 .54603 Mdot
.52771 .28385 Mdot
.63159 .66533 Mdot
.32679 .41165 Mdot
.41443 .31054 Mdot
.59002 .31478 Mdot
.29581 .49191 Mdot
.3523 .62174 Mdot
.41497 .69838 Mdot
.53136 .28657 Mdot
.46787 .29828 Mdot
.59804 .69345 Mdot
.63642 .32895 Mdot
.33069 .37655 Mdot
.58214 .29943 Mdot
.68608 .57377 Mdot
.42197 .71815 Mdot
.32961 .60107 Mdot
.6668 .35569 Mdot
.65906 .64323 Mdot
.51262 .27467 Mdot
.29225 .47103 Mdot
.6799 .59419 Mdot
.29568 .49273 Mdot
.34213 .61689 Mdot
.68067 .58172 Mdot
.39818 .31389 Mdot
.67226 .58761 Mdot
.30249 .42403 Mdot
.58982 .32197 Mdot
.48088 .29054 Mdot
.68327 .37996 Mdot
.59936 .68413 Mdot
.28678 .52305 Mdot
.46667 .73359 Mdot
.63363 .67143 Mdot
.70859 .58506 Mdot
.63694 .65475 Mdot
.28917 .42178 Mdot
.64334 .65047 Mdot
.68881 .56597 Mdot
.38323 .65448 Mdot
.34894 .60459 Mdot
.37518 .34348 Mdot
.35965 .62137 Mdot
.40645 .67713 Mdot
.54239 .704 Mdot
.35514 .63669 Mdot
.36832 .65066 Mdot
.44069 .70587 Mdot
.70054 .46208 Mdot
.47598 .72584 Mdot
.69266 .45954 Mdot
.69823 .43685 Mdot
.39983 .32498 Mdot
.28867 .48735 Mdot
.2851 .56643 Mdot
.48634 .73465 Mdot
.418 .7019 Mdot
.69689 .59408 Mdot
.70121 .50815 Mdot
.5844 .306 Mdot
.56297 .72297 Mdot
.36451 .35686 Mdot
.42076 .70782 Mdot
.46373 .28992 Mdot
.43886 .28609 Mdot
.36363 .61947 Mdot
.3203 .59351 Mdot
.40606 .68364 Mdot
.54685 .70964 Mdot
.38102 .65822 Mdot
.44374 .71365 Mdot
.45042 .27357 Mdot
.45672 .73042 Mdot
.61814 .66729 Mdot
.69878 .55242 Mdot
.29965 .49544 Mdot
.3001 .42288 Mdot
.57344 .71031 Mdot
.43722 .72609 Mdot
.71307 .56375 Mdot
.62725 .66454 Mdot
.47948 .2946 Mdot
.72589 .44689 Mdot
.54466 .71356 Mdot
.60174 .32032 Mdot
.5186 .73767 Mdot
.64049 .33316 Mdot
.59919 .30988 Mdot
.28738 .49973 Mdot
.46657 .27509 Mdot
.3419 .62676 Mdot
.4942 .30292 Mdot
.43741 .70434 Mdot
.59536 .69843 Mdot
.29447 .55865 Mdot
.70057 .58042 Mdot
.57631 .29138 Mdot
.70512 .47511 Mdot
.67042 .61668 Mdot
.50212 .72247 Mdot
.54029 .28776 Mdot
.46427 .26999 Mdot
.32643 .38446 Mdot
.71837 .56209 Mdot
.40494 .67562 Mdot
.71414 .52201 Mdot
.71273 .46777 Mdot
.70519 .56139 Mdot
.49709 .72544 Mdot
.50775 .7368 Mdot
.43767 .70095 Mdot
.68689 .58728 Mdot
.47007 .27295 Mdot
.29042 .56431 Mdot
.42389 .6984 Mdot
.32706 .4104 Mdot
.70437 .54523 Mdot
.50268 .27231 Mdot
.46294 .73364 Mdot
.51011 .29334 Mdot
.67737 .586 Mdot
.43695 .27975 Mdot
.61215 .32834 Mdot
.45131 .28802 Mdot
.40001 .69068 Mdot
.38317 .65826 Mdot
.68767 .56627 Mdot
.72796 .44622 Mdot
.66034 .64132 Mdot
.34994 .62899 Mdot
.71684 .53626 Mdot
.42559 .29966 Mdot
.69738 .49934 Mdot
.62364 .65944 Mdot
.41002 .68212 Mdot
.30133 .48382 Mdot
.57673 .71891 Mdot
.5042 .7263 Mdot
.54928 .7282 Mdot
.28526 .51881 Mdot
.59713 .68817 Mdot
.45875 .73543 Mdot
.40266 .68103 Mdot
.38855 .32189 Mdot
.34499 .61346 Mdot
.32474 .42504 Mdot
.62859 .65114 Mdot
.51526 .74159 Mdot
.65274 .64262 Mdot
.68289 .59746 Mdot
.67788 .57992 Mdot
.42615 .29765 Mdot
.68171 .59143 Mdot
.32873 .41372 Mdot
.67871 .39308 Mdot
.67179 .61572 Mdot
.35013 .38193 Mdot
.33686 .39857 Mdot
.30033 .45418 Mdot
.29454 .42612 Mdot
.33434 .37445 Mdot
.35912 .34769 Mdot
.33388 .39643 Mdot
.71863 .551 Mdot
.4035 .30605 Mdot
.31001 .50986 Mdot
.67874 .39395 Mdot
.31763 .43314 Mdot
.34448 .61243 Mdot
.62596 .66025 Mdot
.72564 .43188 Mdot
.54956 .28982 Mdot
.28742 .4299 Mdot
.40858 .68245 Mdot
.7115 .54219 Mdot
.37244 .63933 Mdot
.29879 .47872 Mdot
.71232 .44569 Mdot
.49642 .29658 Mdot
.29579 .55475 Mdot
.29515 .44204 Mdot
.29314 .51739 Mdot
.52162 .28578 Mdot
.64942 .33276 Mdot
.34117 .6105 Mdot
.35824 .3673 Mdot
.27282 .52326 Mdot
.34291 .61214 Mdot
.71754 .55015 Mdot
.28737 .43713 Mdot
.41567 .67926 Mdot
.63666 .66099 Mdot
.7147 .48145 Mdot
.60809 .29771 Mdot
.34152 .62427 Mdot
.66017 .65964 Mdot
.70188 .54867 Mdot
.33476 .38387 Mdot
.49877 .29841 Mdot
.38126 .66706 Mdot
.67219 .38714 Mdot
.65878 .37959 Mdot
.39366 .31654 Mdot
.7264 .43591 Mdot
.51915 .30317 Mdot
.40497 .69908 Mdot
.31335 .43699 Mdot
.38134 .66606 Mdot
.40691 .29893 Mdot
.63175 .33433 Mdot
.70945 .49304 Mdot
.40152 .32502 Mdot
.5043 .74142 Mdot
.67893 .39964 Mdot
.39151 .32716 Mdot
.69602 .55509 Mdot
.7104 .44108 Mdot
.72445 .45727 Mdot
.3007 .54437 Mdot
.50469 .29135 Mdot
.704 .43669 Mdot
.69923 .47242 Mdot
.6234 .66238 Mdot
.36055 .61733 Mdot
.68763 .57572 Mdot
.37841 .33012 Mdot
.29751 .4897 Mdot
.39262 .32064 Mdot
.35891 .36266 Mdot
.57338 .29668 Mdot
.5503 .70241 Mdot
.54034 .72627 Mdot
.32604 .59941 Mdot
.4575 .71588 Mdot
.37617 .66007 Mdot
.69254 .59549 Mdot
.29289 .57833 Mdot
.30563 .53292 Mdot
.71795 .54873 Mdot
.70609 .49227 Mdot
.29852 .53487 Mdot
.42312 .71066 Mdot
.39545 .66852 Mdot
.50522 .74212 Mdot
.66875 .60245 Mdot
.72118 .56737 Mdot
.66879 .38154 Mdot
.70147 .54733 Mdot
.38138 .31812 Mdot
.49751 .2675 Mdot
.45174 .2811 Mdot
.57519 .30339 Mdot
.33899 .61618 Mdot
.46116 .26978 Mdot
.64348 .6642 Mdot
.37632 .32315 Mdot
.65725 .65107 Mdot
.42331 .30655 Mdot
.34905 .62965 Mdot
.56834 .2833 Mdot
.68503 .37708 Mdot
.63327 .64923 Mdot
.43541 .72168 Mdot
.29095 .50021 Mdot
.69152 .5966 Mdot
.65339 .34511 Mdot
.67472 .60687 Mdot
.36868 .63109 Mdot
.69633 .57324 Mdot
.57904 .29315 Mdot
.64296 .33332 Mdot
.6171 .66219 Mdot
.64377 .66162 Mdot
.66745 .61043 Mdot
.72269 .53602 Mdot
.5019 .29812 Mdot
.70692 .55899 Mdot
.69846 .44659 Mdot
.65125 .64901 Mdot
.52083 .27809 Mdot
.52607 .72957 Mdot
.69601 .58811 Mdot
.29477 .5664 Mdot
.70914 .44704 Mdot
.2991 .53046 Mdot
.70976 .43272 Mdot
.36768 .34782 Mdot
.36284 .65135 Mdot
.40008 .3236 Mdot
.27549 .52771 Mdot
.46423 .26495 Mdot
.65404 .33857 Mdot
.31895 .42653 Mdot
.65285 .36451 Mdot
.55788 .7039 Mdot
.67187 .60749 Mdot
.67928 .38063 Mdot
.52576 .7302 Mdot
.38508 .66482 Mdot
.71087 .43216 Mdot
.48502 .29451 Mdot
.40231 .31402 Mdot
.55914 .7089 Mdot
.72154 .48546 Mdot
.43903 .29798 Mdot
.61319 .67998 Mdot
.39621 .31063 Mdot
.6359 .64655 Mdot
.68843 .40399 Mdot
.67445 .58608 Mdot
.40448 .31238 Mdot
.55068 .70623 Mdot
.69565 .46187 Mdot
.47889 .26723 Mdot
.64644 .34326 Mdot
.6732 .38567 Mdot
.39251 .67989 Mdot
.68312 .39656 Mdot
.46737 .29162 Mdot
.63434 .32829 Mdot
.70265 .43983 Mdot
.63066 .33008 Mdot
.28758 .51643 Mdot
.47433 .2744 Mdot
.31873 .41304 Mdot
.60516 .68376 Mdot
.51682 .2998 Mdot
.32295 .59601 Mdot
.3605 .35642 Mdot
.40125 .30498 Mdot
.71395 .44295 Mdot
.72285 .48596 Mdot
.62685 .67523 Mdot
.56012 .71069 Mdot
.48889 .29049 Mdot
.39009 .31193 Mdot
.47507 .72184 Mdot
.3134 .43304 Mdot
.39984 .31177 Mdot
.45008 .7097 Mdot
.63661 .65733 Mdot
.58337 .30235 Mdot
.47164 .72871 Mdot
.69594 .47803 Mdot
.44442 .71642 Mdot
.65131 .35079 Mdot
.42473 .28632 Mdot
.37051 .63214 Mdot
.29071 .49626 Mdot
.65799 .38394 Mdot
.65742 .38107 Mdot
.53293 .28158 Mdot
.72729 .4363 Mdot
.70363 .58903 Mdot
.50605 .29356 Mdot
.64763 .65247 Mdot
.31713 .4229 Mdot
.43847 .70045 Mdot
.70428 .5695 Mdot
.67503 .60603 Mdot
.47379 .27426 Mdot
.45508 .73499 Mdot
.65815 .35833 Mdot
.39926 .30498 Mdot
.66071 .64685 Mdot
.45458 .28034 Mdot
.2853 .47339 Mdot
.51588 .27283 Mdot
.72178 .5544 Mdot
.28449 .45795 Mdot
.69884 .5712 Mdot
.33577 .39176 Mdot
.28659 .47871 Mdot
.28657 .50005 Mdot
.44561 .27678 Mdot
.72061 .50022 Mdot
.40386 .32074 Mdot
.35617 .64035 Mdot
.43117 .69218 Mdot
.52806 .2928 Mdot
.28701 .52763 Mdot
.30324 .58586 Mdot
.30885 .53301 Mdot
.72459 .44199 Mdot
.62077 .65657 Mdot
.35935 .35669 Mdot
.36133 .35443 Mdot
.59074 .29747 Mdot
.71144 .54651 Mdot
.33828 .39718 Mdot
.65672 .33711 Mdot
.65373 .3745 Mdot
.2918 .53473 Mdot
.37266 .34833 Mdot
.69915 .56412 Mdot
.67248 .35186 Mdot
.69528 .46301 Mdot
.39875 .67197 Mdot
.29867 .41459 Mdot
.36295 .3632 Mdot
.34063 .38838 Mdot
.55654 .71716 Mdot
.68277 .38018 Mdot
.36864 .64363 Mdot
.29369 .4824 Mdot
.57746 .30316 Mdot
.30425 .48995 Mdot
.6612 .64465 Mdot
.42596 .28659 Mdot
.69494 .40779 Mdot
.39483 .68432 Mdot
.33959 .61378 Mdot
.57027 .29571 Mdot
.4237 .71292 Mdot
.69628 .55742 Mdot
.69908 .4539 Mdot
.49709 .27493 Mdot
.49862 .72494 Mdot
.41966 .69877 Mdot
.41922 .69448 Mdot
.52025 .29367 Mdot
.29824 .43137 Mdot
.36715 .33745 Mdot
.41695 .69119 Mdot
.66554 .37772 Mdot
.65359 .64298 Mdot
.67497 .40061 Mdot
.40333 .69471 Mdot
.35747 .6463 Mdot
.64573 .66148 Mdot
.63636 .65212 Mdot
.65341 .36581 Mdot
.29586 .43251 Mdot
.29249 .44705 Mdot
.68233 .60025 Mdot
.34806 .62205 Mdot
.49129 .73275 Mdot
.37305 .66055 Mdot
.29025 .50074 Mdot
.53625 .73577 Mdot
.55753 .70044 Mdot
.58507 .70231 Mdot
.49586 .74288 Mdot
.37454 .65377 Mdot
.57461 .29372 Mdot
.71153 .50239 Mdot
.66009 .35652 Mdot
.5444 .28591 Mdot
.44413 .2977 Mdot
.30392 .49277 Mdot
.36932 .6281 Mdot
.28905 .54982 Mdot
.48694 .7259 Mdot
.26935 .5334 Mdot
.56617 .7155 Mdot
.59422 .69455 Mdot
.30094 .55092 Mdot
.36865 .65977 Mdot
.52285 .28422 Mdot
.49591 .26485 Mdot
.65097 .6608 Mdot
.40028 .68959 Mdot
.60188 .30583 Mdot
.67141 .39493 Mdot
.36762 .34286 Mdot
.37378 .32899 Mdot
.29963 .47802 Mdot
.3009 .46241 Mdot
.64408 .64951 Mdot
.38818 .66294 Mdot
.29833 .43897 Mdot
.53168 .29952 Mdot
.33651 .39292 Mdot
.37456 .34188 Mdot
.65515 .34508 Mdot
.67502 .373 Mdot
.35218 .61416 Mdot
.31638 .59369 Mdot
.71005 .4706 Mdot
.72497 .48214 Mdot
.66861 .3964 Mdot
.44599 .27375 Mdot
.30662 .41411 Mdot
.71503 .51712 Mdot
.70759 .54645 Mdot
.27407 .53336 Mdot
.38428 .668 Mdot
.48659 .26582 Mdot
.71163 .53656 Mdot
.27677 .51077 Mdot
.52798 .72782 Mdot
.39686 .30759 Mdot
.36523 .63556 Mdot
.65225 .66844 Mdot
.70496 .49717 Mdot
.5658 .70932 Mdot
.69753 .58638 Mdot
.66706 .38578 Mdot
.6649 .34631 Mdot
.35342 .64215 Mdot
.69588 .41212 Mdot
.70154 .59972 Mdot
.67475 .35682 Mdot
.30074 .54734 Mdot
.32101 .41575 Mdot
.30456 .48548 Mdot
.50065 .27349 Mdot
.28879 .49748 Mdot
.5104 .30141 Mdot
.3903 .32666 Mdot
.69083 .57424 Mdot
.28419 .5306 Mdot
.54277 .70479 Mdot
.32456 .40979 Mdot
.29675 .47519 Mdot
.57821 .71002 Mdot
.66652 .649 Mdot
.47629 .28611 Mdot
.28593 .54968 Mdot
.33278 .59733 Mdot
.62392 .3235 Mdot
.59284 .32325 Mdot
.65332 .34012 Mdot
.30264 .42166 Mdot
.46687 .27739 Mdot
.70477 .56493 Mdot
.47061 .72025 Mdot
.72179 .57508 Mdot
.41331 .67733 Mdot
.35432 .62696 Mdot
.71063 .59028 Mdot
.70521 .56551 Mdot
.35148 .64109 Mdot
.45643 .71647 Mdot
.32469 .41402 Mdot
.66261 .38611 Mdot
.71704 .44259 Mdot
.71776 .44645 Mdot
.46822 .29653 Mdot
.68778 .56429 Mdot
.32936 .37869 Mdot
.65563 .34056 Mdot
.35548 .37236 Mdot
.658 .36575 Mdot
.3082 .58296 Mdot
.42739 .30021 Mdot
.7132 .5135 Mdot
.72524 .43332 Mdot
.62704 .66675 Mdot
.68877 .57433 Mdot
.28971 .51879 Mdot
.68163 .57501 Mdot
.68879 .58299 Mdot
.34687 .61892 Mdot
.29491 .43808 Mdot
.32935 .39882 Mdot
.55702 .71839 Mdot
.71045 .4695 Mdot
.36863 .65453 Mdot
.57861 .71358 Mdot
.34441 .62432 Mdot
.56487 .71077 Mdot
.70266 .44628 Mdot
.43246 .72203 Mdot
.68423 .57844 Mdot
.69629 .43465 Mdot
.36542 .35908 Mdot
.32443 .4072 Mdot
.34094 .3934 Mdot
.53678 .28151 Mdot
.41726 .6804 Mdot
.39634 .32445 Mdot
.64435 .65261 Mdot
.30707 .44035 Mdot
.54506 .70207 Mdot
.28141 .55322 Mdot
.43723 .70512 Mdot
.30443 .43679 Mdot
.49208 .29497 Mdot
.62959 .66665 Mdot
.425 .69284 Mdot
.2991 .42245 Mdot
.69373 .5676 Mdot
.71973 .47158 Mdot
.71154 .55001 Mdot
.29553 .52742 Mdot
.65379 .35438 Mdot
.64071 .65441 Mdot
.50465 .27567 Mdot
.39686 .32625 Mdot
.69948 .56986 Mdot
.43448 .2886 Mdot
.67654 .38265 Mdot
.42101 .69115 Mdot
.66088 .38114 Mdot
.2875 .55685 Mdot
.71156 .44783 Mdot
.63977 .66093 Mdot
.60822 .66912 Mdot
.67804 .57925 Mdot
.32456 .42073 Mdot
.30754 .51598 Mdot
.42968 .28136 Mdot
.71464 .48972 Mdot
.65408 .3494 Mdot
.45698 .29473 Mdot
.63831 .66501 Mdot
.27042 .54554 Mdot
.47535 .73619 Mdot
.36366 .62096 Mdot
.59691 .68757 Mdot
.36564 .61927 Mdot
.39656 .32913 Mdot
.68632 .59967 Mdot
.64095 .6456 Mdot
.58779 .69646 Mdot
.31247 .59039 Mdot
.30765 .49415 Mdot
.37731 .64893 Mdot
.52918 .71195 Mdot
.40855 .69547 Mdot
.71482 .50833 Mdot
.56349 .70795 Mdot
.41354 .29941 Mdot
.35787 .36564 Mdot
.54429 .28596 Mdot
.31187 .43161 Mdot
.42749 .28649 Mdot
.45231 .7132 Mdot
.46826 .73942 Mdot
.6921 .48358 Mdot
.6646 .64581 Mdot
.66666 .35772 Mdot
.44045 .72749 Mdot
.47997 .29519 Mdot
.41252 .31567 Mdot
.40058 .70046 Mdot
.70024 .55398 Mdot
.61576 .31081 Mdot
.30002 .44094 Mdot
.34246 .39133 Mdot
.27497 .52733 Mdot
.42138 .29556 Mdot
.28515 .46662 Mdot
.65818 .36021 Mdot
.33454 .60748 Mdot
.55662 .70061 Mdot
.59488 .28897 Mdot
.68176 .56833 Mdot
.60751 .31527 Mdot
.30882 .58318 Mdot
.3646 .64357 Mdot
.704 .46775 Mdot
.67984 .59379 Mdot
.27357 .51793 Mdot
.38322 .33777 Mdot
.38269 .32738 Mdot
.31923 .5877 Mdot
.28907 .45284 Mdot
.52978 .29942 Mdot
.29255 .46244 Mdot
.64874 .65409 Mdot
.57323 .71124 Mdot
.59405 .32445 Mdot
.35411 .63618 Mdot
.70695 .41908 Mdot
.68345 .59864 Mdot
.38179 .6593 Mdot
.30205 .50232 Mdot
.70757 .52405 Mdot
.62234 .67306 Mdot
.33315 .60567 Mdot
.47095 .27251 Mdot
.35907 .63971 Mdot
.35788 .3615 Mdot
.34963 .37611 Mdot
.34716 .60741 Mdot
.50215 .29675 Mdot
.28486 .45858 Mdot
.30443 .5104 Mdot
.67036 .60106 Mdot
.31281 .42949 Mdot
.66185 .64696 Mdot
.43735 .69775 Mdot
.30152 .54444 Mdot
.64712 .65835 Mdot
.7204 .57399 Mdot
.34503 .3941 Mdot
.44943 .28234 Mdot
.70544 .4896 Mdot
.36325 .64739 Mdot
.32265 .41649 Mdot
.3868 .66296 Mdot
.66721 .6155 Mdot
.35946 .61955 Mdot
.64266 .33753 Mdot
.70379 .5005 Mdot
.6647 .36696 Mdot
.63012 .66465 Mdot
.3633 .63454 Mdot
.29248 .46188 Mdot
.31129 .40921 Mdot
.40814 .68211 Mdot
.69983 .57145 Mdot
.68758 .58865 Mdot
.7086 .55434 Mdot
.46074 .29341 Mdot
.48306 .72452 Mdot
.66905 .37285 Mdot
.29716 .43563 Mdot
.6826 .39814 Mdot
.51681 .71933 Mdot
.29533 .52202 Mdot
.62861 .33185 Mdot
.41478 .6861 Mdot
.72836 .46987 Mdot
.39354 .66619 Mdot
.71146 .5076 Mdot
.53811 .28299 Mdot
.60685 .3135 Mdot
.71327 .46173 Mdot
.37819 .65418 Mdot
.55381 .71717 Mdot
.56958 .69703 Mdot
.67704 .36267 Mdot
.28942 .43089 Mdot
.3701 .35289 Mdot
.49132 .26761 Mdot
.26893 .53651 Mdot
.56597 .29709 Mdot
.62214 .32283 Mdot
.62367 .65938 Mdot
.71127 .48467 Mdot
.65841 .34984 Mdot
.64837 .33853 Mdot
.47178 .29098 Mdot
.6242 .66436 Mdot
.36345 .63095 Mdot
.32939 .41363 Mdot
.59968 .31656 Mdot
.41892 .6961 Mdot
.66488 .64257 Mdot
.36327 .34574 Mdot
.71006 .56415 Mdot
.60255 .29216 Mdot
.51091 .72011 Mdot
.70802 .58645 Mdot
.39684 .31059 Mdot
.70342 .43807 Mdot
.37146 .65297 Mdot
.3075 .4193 Mdot
.43336 .28598 Mdot
.43227 .69088 Mdot
.4016 .32584 Mdot
.66969 .35747 Mdot
.59826 .29265 Mdot
.52544 .72372 Mdot
.38322 .31795 Mdot
.35544 .64679 Mdot
.62772 .6735 Mdot
.27936 .51137 Mdot
.66922 .35248 Mdot
.6916 .47285 Mdot
.3888 .67098 Mdot
.47683 .2999 Mdot
.5194 .27646 Mdot
.69657 .58391 Mdot
.71051 .54798 Mdot
.72068 .50089 Mdot
.317 .41298 Mdot
.44275 .29447 Mdot
.32292 .41512 Mdot
.3317 .59654 Mdot
.67419 .35493 Mdot
.30489 .51286 Mdot
.4359 .28031 Mdot
.57366 .30637 Mdot
.66635 .64923 Mdot
.7282 .44058 Mdot
.60822 .68499 Mdot
.64479 .66454 Mdot
.42596 .29477 Mdot
.29609 .50998 Mdot
.573 .705 Mdot
.61504 .66507 Mdot
.30051 .5313 Mdot
.46831 .29377 Mdot
.71751 .46918 Mdot
.67783 .59598 Mdot
.70607 .50639 Mdot
.54314 .70643 Mdot
.71495 .5263 Mdot
.44983 .72319 Mdot
.34871 .60575 Mdot
.72158 .4277 Mdot
.46314 .71504 Mdot
.65312 .34112 Mdot
.71501 .49311 Mdot
.5654 .71007 Mdot
.66232 .63927 Mdot
.44358 .71745 Mdot
.45335 .73321 Mdot
.64347 .64731 Mdot
.4173 .68032 Mdot
.71686 .57838 Mdot
.67521 .60586 Mdot
.58151 .70253 Mdot
.6761 .35391 Mdot
.29046 .50913 Mdot
.69912 .44261 Mdot
.35818 .63678 Mdot
.71357 .58644 Mdot
.58134 .70589 Mdot
.64258 .33867 Mdot
.6491 .64564 Mdot
.42454 .28736 Mdot
.47004 .7304 Mdot
.52892 .28147 Mdot
.60999 .66911 Mdot
.70941 .59342 Mdot
.6052 .3247 Mdot
.62025 .67321 Mdot
.37817 .31689 Mdot
.44257 .72959 Mdot
.30926 .4151 Mdot
.29113 .4931 Mdot
.28676 .46132 Mdot
.65103 .35918 Mdot
.42161 .68392 Mdot
.45749 .7147 Mdot
.39498 .67528 Mdot
.33152 .59547 Mdot
.32484 .40803 Mdot
.28981 .57039 Mdot
.66906 .61363 Mdot
.43263 .69944 Mdot
.46578 .26754 Mdot
.70383 .47856 Mdot
.45203 .71631 Mdot
.59499 .69185 Mdot
.65128 .66758 Mdot
.71114 .46782 Mdot
.7305 .4393 Mdot
.36395 .35714 Mdot
.2819 .51984 Mdot
.34782 .632 Mdot
.29697 .56782 Mdot
.64171 .65551 Mdot
.65767 .37005 Mdot
.4009 .68772 Mdot
.43091 .29985 Mdot
.55974 .70573 Mdot
.46505 .29314 Mdot
.33888 .60409 Mdot
.71289 .44182 Mdot
.66338 .34649 Mdot
.39621 .31561 Mdot
.39703 .31382 Mdot
.41252 .69381 Mdot
.36173 .35495 Mdot
.29503 .53605 Mdot
.29192 .52782 Mdot
.66015 .3477 Mdot
.3783 .65867 Mdot
.56572 .70472 Mdot
.66602 .63366 Mdot
.42806 .68611 Mdot
.33658 .60702 Mdot
.58058 .31183 Mdot
.57426 .30365 Mdot
.43767 .28083 Mdot
.34607 .63218 Mdot
.42996 .70448 Mdot
.70825 .45974 Mdot
.30573 .49298 Mdot
.43547 .29544 Mdot
.28098 .50065 Mdot
.51505 .28983 Mdot
.51447 .7398 Mdot
.29198 .42994 Mdot
.29379 .52656 Mdot
.57036 .28963 Mdot
.72957 .45617 Mdot
.32867 .40953 Mdot
.48012 .28203 Mdot
.43829 .29146 Mdot
.44893 .71283 Mdot
.67947 .57124 Mdot
.69986 .4496 Mdot
.29715 .52913 Mdot
.66778 .39485 Mdot
.64347 .66437 Mdot
.34193 .38835 Mdot
.31015 .58483 Mdot
.45368 .29602 Mdot
.71286 .5092 Mdot
.60566 .68261 Mdot
.35651 .62546 Mdot
.72009 .46954 Mdot
.35916 .62738 Mdot
.70621 .55884 Mdot
.69673 .44263 Mdot
.40524 .70222 Mdot
.71461 .56136 Mdot
.51601 .30302 Mdot
.41951 .30961 Mdot
.65089 .64146 Mdot
.62039 .33015 Mdot
.64526 .65314 Mdot
.37213 .33233 Mdot
.39667 .6736 Mdot
.43719 .69597 Mdot
.35597 .63288 Mdot
.28788 .48196 Mdot
.49206 .7421 Mdot
.32735 .39481 Mdot
.31013 .41446 Mdot
.71527 .47515 Mdot
.28626 .46286 Mdot
.55904 .71577 Mdot
.28513 .53679 Mdot
.49441 .27464 Mdot
.41574 .69825 Mdot
.29755 .52133 Mdot
.67744 .5987 Mdot
.62005 .66886 Mdot
.71627 .42616 Mdot
.51551 .27196 Mdot
.30166 .43212 Mdot
.66792 .35642 Mdot
.55604 .72793 Mdot
.4849 .29814 Mdot
.5913 .30949 Mdot
.54972 .72422 Mdot
.42348 .28659 Mdot
.66672 .34272 Mdot
.41819 .31156 Mdot
.58957 .30372 Mdot
.67566 .3952 Mdot
.54329 .71143 Mdot
.28468 .53724 Mdot
.2831 .46162 Mdot
.29157 .57329 Mdot
.60635 .31938 Mdot
.42863 .30264 Mdot
.46501 .28167 Mdot
.58643 .69769 Mdot
.71161 .52897 Mdot
.31452 .43684 Mdot
.34213 .62474 Mdot
.57762 .30097 Mdot
.50355 .73628 Mdot
.28376 .4617 Mdot
.67349 .37225 Mdot
.61014 .67003 Mdot
.52714 .73456 Mdot
.31299 .41843 Mdot
.33145 .40097 Mdot
.28564 .54684 Mdot
.37959 .3347 Mdot
.70502 .4391 Mdot
.27724 .54819 Mdot
.39718 .67872 Mdot
.35031 .63229 Mdot
.65315 .3639 Mdot
.31154 .43014 Mdot
.67256 .37783 Mdot
.30304 .49804 Mdot
.28907 .56943 Mdot
.67223 .60073 Mdot
.70543 .55279 Mdot
.29494 .4629 Mdot
.4973 .74552 Mdot
.48184 .74599 Mdot
.69077 .47532 Mdot
.70817 .44128 Mdot
.45191 .73512 Mdot
.30723 .53568 Mdot
.28217 .54565 Mdot
.61977 .67459 Mdot
.58499 .70843 Mdot
.63778 .64941 Mdot
.53034 .72718 Mdot
.542 .28854 Mdot
.63302 .66484 Mdot
.42879 .28418 Mdot
.52864 .72721 Mdot
.60507 .30262 Mdot
.65133 .66177 Mdot
.35907 .62267 Mdot
.50528 .28452 Mdot
.34244 .60644 Mdot
.49114 .27112 Mdot
.36557 .65172 Mdot
.40728 .29837 Mdot
.50434 .27568 Mdot
.36037 .35805 Mdot
.53563 .73247 Mdot
.32784 .39518 Mdot
.3047 .53159 Mdot
.3494 .37124 Mdot
.46377 .73279 Mdot
.71814 .46292 Mdot
.71587 .5231 Mdot
.3561 .62374 Mdot
.46839 .28915 Mdot
.675 .36624 Mdot
.60863 .67316 Mdot
.39077 .66726 Mdot
.65111 .65744 Mdot
.72866 .44066 Mdot
.47224 .27325 Mdot
.28971 .49247 Mdot
.35608 .35358 Mdot
.37361 .33244 Mdot
.42841 .30033 Mdot
.33212 .60371 Mdot
.65221 .66569 Mdot
.35684 .36204 Mdot
.7082 .57679 Mdot
.30243 .58501 Mdot
.68162 .58966 Mdot
.31561 .42803 Mdot
.27705 .53284 Mdot
.509 .72726 Mdot
.69989 .46947 Mdot
.52053 .29317 Mdot
.36584 .63696 Mdot
.29503 .42738 Mdot
.29137 .5731 Mdot
.69677 .47931 Mdot
.30151 .54576 Mdot
.48734 .28042 Mdot
.31806 .41839 Mdot
.49405 .73171 Mdot
.42445 .71865 Mdot
.59897 .69966 Mdot
.36333 .63679 Mdot
.29858 .53244 Mdot
.68396 .56388 Mdot
.65082 .65867 Mdot
.59652 .30989 Mdot
.55972 .71153 Mdot
.33561 .59909 Mdot
.37311 .32639 Mdot
.72276 .43876 Mdot
.28645 .51806 Mdot
.5786 .30066 Mdot
.28188 .51601 Mdot
.34044 .39077 Mdot
.70223 .55813 Mdot
.34203 .39007 Mdot
.66384 .64421 Mdot
.65986 .3518 Mdot
.69918 .45427 Mdot
.36319 .34115 Mdot
.28977 .45012 Mdot
.53096 .29302 Mdot
.53269 .73389 Mdot
.69737 .57885 Mdot
.58131 .31601 Mdot
.35812 .35311 Mdot
.64442 .33902 Mdot
.59282 .70226 Mdot
.66628 .39084 Mdot
.35553 .62377 Mdot
.70222 .50807 Mdot
.67954 .40016 Mdot
.38992 .31877 Mdot
.53074 .71139 Mdot
.34496 .38377 Mdot
.37821 .66276 Mdot
.63279 .33198 Mdot
.6841 .37421 Mdot
.68655 .57115 Mdot
.56447 .29474 Mdot
.39821 .67901 Mdot
.32338 .41157 Mdot
.34859 .61488 Mdot
.60281 .31093 Mdot
.56723 .30212 Mdot
.39703 .31794 Mdot
.36903 .64186 Mdot
.28803 .50281 Mdot
.42654 .28686 Mdot
.52371 .27942 Mdot
.4394 .28492 Mdot
.70696 .59152 Mdot
.29434 .44446 Mdot
.31557 .41292 Mdot
.40685 .69072 Mdot
.67329 .38334 Mdot
.32618 .39593 Mdot
.43376 .69656 Mdot
.46099 .72508 Mdot
.70544 .50551 Mdot
.49371 .28368 Mdot
.3366 .60067 Mdot
.64782 .6417 Mdot
.30238 .4176 Mdot
.50611 .29181 Mdot
.69537 .56684 Mdot
.3672 .33508 Mdot
.42017 .6873 Mdot
.62973 .65389 Mdot
.67654 .58217 Mdot
.71265 .59126 Mdot
.49357 .74331 Mdot
.36002 .62702 Mdot
.65751 .37766 Mdot
.53396 .67242 Mdot
.38097 .57229 Mdot
.44448 .47877 Mdot
.30441 .4466 Mdot
.59634 .56595 Mdot
.49128 .6508 Mdot
.6518 .63573 Mdot
.49568 .58119 Mdot
.51855 .71274 Mdot
.54603 .62155 Mdot
.62901 .41764 Mdot
.47002 .54192 Mdot
.46922 .30971 Mdot
.66779 .47839 Mdot
.60733 .65451 Mdot
.33518 .48507 Mdot
.6712 .53068 Mdot
.51761 .63167 Mdot
.67233 .47494 Mdot
.60411 .45541 Mdot
.5727 .33404 Mdot
.56362 .31209 Mdot
.60458 .40937 Mdot
.33166 .58999 Mdot
.54905 .65142 Mdot
.40798 .59385 Mdot
.64178 .58631 Mdot
.63671 .38578 Mdot
.64425 .64147 Mdot
.41135 .37841 Mdot
.61402 .57143 Mdot
.45337 .37774 Mdot
.46503 .67079 Mdot
.62848 .44525 Mdot
.40243 .58655 Mdot
.37971 .43322 Mdot
.51099 .70835 Mdot
.54536 .58932 Mdot
.59493 .59335 Mdot
.45542 .63993 Mdot
.62185 .55319 Mdot
.47116 .30132 Mdot
.6987 .54573 Mdot
.67765 .49532 Mdot
.45082 .35947 Mdot
.63945 .54042 Mdot
.49529 .58216 Mdot
.30505 .45343 Mdot
.59761 .55881 Mdot
.44064 .68688 Mdot
.69879 .52284 Mdot
.64804 .46773 Mdot
.64503 .40742 Mdot
.47014 .65461 Mdot
.66053 .42678 Mdot
.43587 .66971 Mdot
.52204 .63437 Mdot
.49786 .65529 Mdot
.6058 .45034 Mdot
.54118 .35211 Mdot
.71782 .43558 Mdot
.33893 .4858 Mdot
.56273 .43329 Mdot
.40247 .47674 Mdot
.6539 .48686 Mdot
.49204 .68951 Mdot
.6553 .60667 Mdot
.69369 .50198 Mdot
.59204 .35621 Mdot
.44845 .34085 Mdot
.61187 .40326 Mdot
.57111 .43605 Mdot
.64242 .53031 Mdot
.38378 .59751 Mdot
.58073 .6117 Mdot
.58115 .37448 Mdot
.56522 .6845 Mdot
.36735 .40431 Mdot
.5464 .52029 Mdot
.40691 .34601 Mdot
.48674 .66174 Mdot
.61448 .45713 Mdot
.4494 .56838 Mdot
.60489 .52866 Mdot
.40364 .64564 Mdot
.42551 .34445 Mdot
.55117 .65003 Mdot
.55578 .37856 Mdot
.66674 .53855 Mdot
.51422 .67924 Mdot
.65759 .4337 Mdot
.37154 .36959 Mdot
.44816 .41619 Mdot
.40726 .36119 Mdot
.50233 .57505 Mdot
.38199 .41729 Mdot
.62806 .44249 Mdot
.68104 .44251 Mdot
.54708 .30537 Mdot
.6261 .61192 Mdot
.46894 .36725 Mdot
.70156 .42425 Mdot
.5499 .324 Mdot
.49323 .60869 Mdot
.61515 .62284 Mdot
.40805 .36715 Mdot
.59902 .36315 Mdot
.59202 .5205 Mdot
.59617 .4262 Mdot
.59258 .58927 Mdot
.57079 .61856 Mdot
.67577 .52996 Mdot
.30159 .46025 Mdot
.59444 .65377 Mdot
.44263 .38052 Mdot
.61611 .37542 Mdot
.34628 .43802 Mdot
.46242 .71169 Mdot
.47008 .3876 Mdot
.53723 .69868 Mdot
.50909 .47317 Mdot
.65953 .56377 Mdot
.40421 .35166 Mdot
.65672 .63788 Mdot
.55512 .68044 Mdot
.60357 .40652 Mdot
.35384 .4943 Mdot
.67849 .54597 Mdot
.67502 .4673 Mdot
.58745 .33438 Mdot
.50149 .67332 Mdot
.40455 .33815 Mdot
.35047 .55369 Mdot
.40442 .44945 Mdot
.60456 .33608 Mdot
.39345 .47321 Mdot
.43592 .44243 Mdot
.4378 .31272 Mdot
.62952 .62114 Mdot
.43437 .42551 Mdot
.56063 .69303 Mdot
.57405 .36883 Mdot
.62326 .4121 Mdot
.54473 .66531 Mdot
.3169 .50778 Mdot
.40651 .40099 Mdot
.45686 .44449 Mdot
.59753 .54312 Mdot
.65981 .63159 Mdot
.40421 .56805 Mdot
.62237 .43425 Mdot
.51645 .40551 Mdot
.52634 .35705 Mdot
.67369 .46061 Mdot
.69989 .42378 Mdot
.49701 .38229 Mdot
.42941 .55586 Mdot
.59413 .66928 Mdot
.50384 .42359 Mdot
.65817 .57603 Mdot
.48746 .41088 Mdot
.40988 .37589 Mdot
.59929 .33769 Mdot
.59092 .37996 Mdot
.64734 .52893 Mdot
.64847 .40951 Mdot
.58039 .63428 Mdot
.58745 .6326 Mdot
.49329 .36183 Mdot
.66857 .52773 Mdot
.62431 .47431 Mdot
.69369 .51193 Mdot
.51764 .61701 Mdot
.44265 .6329 Mdot
.37478 .56 Mdot
.4426 .52082 Mdot
.30616 .54941 Mdot
.37843 .44098 Mdot
.50434 .67707 Mdot
.31399 .54754 Mdot
.38065 .50546 Mdot
.39651 .58396 Mdot
.35109 .38487 Mdot
.36186 .55905 Mdot
.44495 .68601 Mdot
.56879 .54211 Mdot
.59662 .37672 Mdot
.45965 .46277 Mdot
.36212 .54631 Mdot
.65053 .57382 Mdot
.50674 .70824 Mdot
.40654 .35167 Mdot
.46237 .32965 Mdot
.51448 .65092 Mdot
.56832 .66644 Mdot
.62598 .33801 Mdot
.65776 .4038 Mdot
.46149 .31205 Mdot
.64801 .52795 Mdot
.65685 .59963 Mdot
.38485 .33867 Mdot
.60845 .48842 Mdot
.44636 .57962 Mdot
.41595 .62539 Mdot
.42994 .35594 Mdot
.57663 .55727 Mdot
.3128 .46071 Mdot
.46992 .61648 Mdot
.44104 .45994 Mdot
.39898 .39879 Mdot
.36281 .4218 Mdot
.35593 .44307 Mdot
.67557 .50593 Mdot
.36949 .44814 Mdot
.39812 .37577 Mdot
.47603 .71749 Mdot
.56675 .47421 Mdot
.62448 .64616 Mdot
.40126 .52764 Mdot
.5497 .32975 Mdot
.56183 .41995 Mdot
.56728 .61295 Mdot
.47102 .65593 Mdot
.38237 .38065 Mdot
.44072 .68248 Mdot
.61813 .5345 Mdot
.4396 .38791 Mdot
.56688 .39064 Mdot
.46469 .38267 Mdot
.50157 .35577 Mdot
.5222 .57968 Mdot
.6749 .47037 Mdot
.3162 .58026 Mdot
.54682 .34985 Mdot
.6325 .57716 Mdot
.54672 .68938 Mdot
.55329 .32885 Mdot
.60623 .63454 Mdot
.60707 .60764 Mdot
.47578 .64327 Mdot
.41414 .56412 Mdot
.47027 .49808 Mdot
.55164 .59175 Mdot
.39241 .4391 Mdot
.54215 .39234 Mdot
.58067 .32588 Mdot
.49126 .32151 Mdot
.46856 .48287 Mdot
.56206 .46861 Mdot
.35972 .52971 Mdot
.59241 .35052 Mdot
.53963 .5577 Mdot
.37998 .57781 Mdot
.45864 .45951 Mdot
.52409 .64443 Mdot
.65742 .58386 Mdot
.42274 .55982 Mdot
.42502 .6805 Mdot
.44562 .35414 Mdot
.44617 .3081 Mdot
.49274 .35119 Mdot
.55351 .65859 Mdot
.67052 .42096 Mdot
.65711 .50925 Mdot
.36756 .50884 Mdot
.40375 .61322 Mdot
.50785 .54298 Mdot
.4415 .66398 Mdot
.65705 .39189 Mdot
.66456 .5781 Mdot
.57024 .64174 Mdot
.33346 .58578 Mdot
.44869 .53697 Mdot
.55533 .63758 Mdot
.37903 .48982 Mdot
.53639 .69736 Mdot
.664 .61596 Mdot
.55941 .35589 Mdot
.56574 .31412 Mdot
.32116 .48737 Mdot
.56007 .44407 Mdot
.30441 .47266 Mdot
.48699 .32872 Mdot
.59119 .53483 Mdot
.46168 .66481 Mdot
.64529 .39329 Mdot
.51997 .36553 Mdot
.48422 .31096 Mdot
.50267 .35446 Mdot
.61969 .40665 Mdot
.65309 .49374 Mdot
.36028 .5868 Mdot
.61961 .58303 Mdot
.67008 .45267 Mdot
.37584 .61569 Mdot
.62523 .38419 Mdot
.60677 .54501 Mdot
.69008 .52807 Mdot
.41712 .67064 Mdot
.39141 .66011 Mdot
.35902 .45685 Mdot
.37315 .59245 Mdot
.43241 .48223 Mdot
.68932 .54904 Mdot
.33265 .53268 Mdot
.6231 .53495 Mdot
.61304 .65678 Mdot
.56846 .66965 Mdot
.67479 .54594 Mdot
.5443 .69132 Mdot
.52292 .31083 Mdot
.67399 .41557 Mdot
.56059 .63333 Mdot
.37483 .50801 Mdot
.41248 .40366 Mdot
.36313 .50284 Mdot
.57692 .66175 Mdot
.41519 .53384 Mdot
.65299 .58924 Mdot
.47491 .65599 Mdot
.56182 .50539 Mdot
.63027 .61448 Mdot
.47482 .60865 Mdot
.52495 .69373 Mdot
.60127 .65937 Mdot
.46679 .34322 Mdot
.34207 .49889 Mdot
.53978 .59719 Mdot
.37628 .62832 Mdot
.49728 .46872 Mdot
.5005 .61079 Mdot
.34399 .54026 Mdot
.52513 .60461 Mdot
.32726 .58878 Mdot
.68747 .45831 Mdot
.57486 .58778 Mdot
.52532 .3999 Mdot
.33298 .55842 Mdot
.4623 .668 Mdot
.51409 .67645 Mdot
.67359 .46461 Mdot
.33865 .50917 Mdot
.44713 .33741 Mdot
.54158 .50006 Mdot
.36021 .54173 Mdot
.4631 .43102 Mdot
.35584 .46887 Mdot
.33865 .4167 Mdot
.49782 .3576 Mdot
.60067 .5651 Mdot
.32764 .54049 Mdot
.62632 .36837 Mdot
.44003 .51238 Mdot
.45015 .57452 Mdot
.55688 .35194 Mdot
.46574 .58176 Mdot
.47402 .56612 Mdot
.47156 .45975 Mdot
.56647 .3459 Mdot
.57098 .57143 Mdot
.61438 .54612 Mdot
.6613 .6184 Mdot
.39371 .39197 Mdot
.55708 .61646 Mdot
.60768 .61235 Mdot
.53771 .39977 Mdot
.37732 .63518 Mdot
.4358 .52345 Mdot
.69851 .5276 Mdot
.51538 .4399 Mdot
.57306 .62634 Mdot
.44941 .30689 Mdot
.58325 .55191 Mdot
.4619 .47114 Mdot
.33138 .50771 Mdot
.32559 .54739 Mdot
.43593 .5957 Mdot
.39554 .36644 Mdot
.62362 .53245 Mdot
.58218 .65233 Mdot
.62271 .56023 Mdot
.40875 .63151 Mdot
.69066 .44614 Mdot
.44687 .32925 Mdot
.62446 .33991 Mdot
.64954 .57277 Mdot
.46002 .61303 Mdot
.39953 .34135 Mdot
.55741 .47727 Mdot
.61785 .48921 Mdot
.67554 .42721 Mdot
.60547 .35483 Mdot
.59329 .36807 Mdot
.42411 .51878 Mdot
.64501 .43981 Mdot
.54556 .3531 Mdot
.61166 .62974 Mdot
.51492 .31335 Mdot
.54876 .36144 Mdot
.58652 .69064 Mdot
.58032 .37455 Mdot
.62401 .63603 Mdot
.65475 .43086 Mdot
.49715 .60555 Mdot
.58974 .54293 Mdot
.51674 .42239 Mdot
.59167 .65161 Mdot
.67184 .50666 Mdot
.57361 .50113 Mdot
.46058 .69507 Mdot
.52444 .68466 Mdot
.56931 .68287 Mdot
.41414 .59925 Mdot
.58744 .5176 Mdot
.32918 .54035 Mdot
.61004 .33079 Mdot
.39185 .61917 Mdot
.69469 .5256 Mdot
.47254 .71383 Mdot
.62305 .47863 Mdot
.49939 .71579 Mdot
.46947 .34672 Mdot
.62569 .47789 Mdot
.35125 .44806 Mdot
.40694 .32475 Mdot
.3399 .49671 Mdot
.57861 .60462 Mdot
.48627 .32918 Mdot
.54641 .32993 Mdot
.51662 .31943 Mdot
.35392 .43291 Mdot
.52728 .34132 Mdot
.38136 .62093 Mdot
.57348 .51576 Mdot
.38923 .6003 Mdot
.35483 .49922 Mdot
.54032 .34183 Mdot
.68456 .55098 Mdot
.41967 .40481 Mdot
.49145 .63122 Mdot
.6181 .36191 Mdot
.3491 .47594 Mdot
.39589 .66263 Mdot
.4995 .43996 Mdot
.60672 .43692 Mdot
.52706 .30211 Mdot
.33882 .44603 Mdot
.55081 .66678 Mdot
.50214 .37794 Mdot
.55237 .67877 Mdot
.58231 .68799 Mdot
.63362 .42117 Mdot
.4904 .64248 Mdot
.31571 .57473 Mdot
.64243 .48419 Mdot
.41066 .33039 Mdot
.60601 .53608 Mdot
.68501 .44891 Mdot
.35694 .48842 Mdot
.48834 .35884 Mdot
.50585 .38191 Mdot
.34596 .4514 Mdot
.42483 .40497 Mdot
.42433 .41292 Mdot
.32682 .58662 Mdot
.51149 .64214 Mdot
.38591 .60593 Mdot
.39946 .39543 Mdot
.4496 .63509 Mdot
.45023 .34233 Mdot
.64569 .34746 Mdot
.60504 .46135 Mdot
.66929 .56728 Mdot
.36663 .57561 Mdot
.37463 .58705 Mdot
.52744 .36667 Mdot
.66494 .5435 Mdot
.45721 .4981 Mdot
.45881 .44658 Mdot
.65421 .42303 Mdot
.42118 .64956 Mdot
.52647 .59117 Mdot
.33842 .45815 Mdot
.42768 .6819 Mdot
.31401 .45314 Mdot
.5937 .37933 Mdot
.61781 .58367 Mdot
.58242 .52956 Mdot
.65608 .59343 Mdot
.42669 .48886 Mdot
.34443 .5781 Mdot
.39878 .38797 Mdot
.58151 .5282 Mdot
.39578 .5897 Mdot
.36447 .47235 Mdot
.60555 .61754 Mdot
.6519 .5449 Mdot
.50436 .5854 Mdot
.59039 .4569 Mdot
.47585 .72056 Mdot
.60852 .40298 Mdot
.44527 .30625 Mdot
.33299 .51437 Mdot
.65353 .53714 Mdot
.36608 .58019 Mdot
.44379 .43113 Mdot
.57296 .41155 Mdot
.33403 .47767 Mdot
.59172 .34694 Mdot
.5049 .67817 Mdot
.62363 .38525 Mdot
.65714 .55107 Mdot
.61599 .48414 Mdot
.37101 .59715 Mdot
.33853 .48875 Mdot
.44911 .59437 Mdot
.55355 .52497 Mdot
.47892 .42787 Mdot
.48463 .70773 Mdot
.55116 .64741 Mdot
.41588 .56839 Mdot
.68313 .47468 Mdot
.34191 .46131 Mdot
.60797 .42073 Mdot
.36297 .46464 Mdot
.33704 .47684 Mdot
.6654 .59053 Mdot
.57304 .64334 Mdot
.6805 .45094 Mdot
.36421 .54205 Mdot
.52304 .30372 Mdot
.40062 .66886 Mdot
.44382 .68123 Mdot
.47438 .60167 Mdot
.50243 .39187 Mdot
.31575 .56416 Mdot
.52575 .69018 Mdot
.60007 .41004 Mdot
.54288 .69439 Mdot
.50044 .31475 Mdot
.51963 .57465 Mdot
.49325 .6557 Mdot
.42 .48879 Mdot
.64968 .49845 Mdot
.51484 .64161 Mdot
.45218 .37928 Mdot
.40363 .51973 Mdot
.48379 .64864 Mdot
.48863 .65776 Mdot
.43902 .57062 Mdot
.63123 .59826 Mdot
.43694 .37995 Mdot
.60682 .37137 Mdot
.31291 .56536 Mdot
.44966 .63793 Mdot
.37752 .58544 Mdot
.59372 .54138 Mdot
.47115 .37898 Mdot
.40165 .32788 Mdot
.32047 .54616 Mdot
.43592 .64706 Mdot
.6627 .57368 Mdot
.51631 .5368 Mdot
.39718 .60335 Mdot
.39167 .60707 Mdot
.66001 .48122 Mdot
.58971 .52524 Mdot
.44953 .48085 Mdot
.6963 .54458 Mdot
.6429 .37687 Mdot
.30253 .56008 Mdot
.31479 .54429 Mdot
.63747 .55689 Mdot
.42585 .58771 Mdot
.57679 .36513 Mdot
.68531 .52375 Mdot
.31415 .50254 Mdot
.62923 .51201 Mdot
.33505 .58219 Mdot
.3958 .54898 Mdot
.31829 .56667 Mdot
.37892 .42935 Mdot
.66911 .58524 Mdot
.58634 .63958 Mdot
.65013 .46113 Mdot
.519 .368 Mdot
.55887 .54647 Mdot
.53144 .33823 Mdot
.45644 .40973 Mdot
.50071 .3701 Mdot
.48099 .63657 Mdot
.49291 .56419 Mdot
.61419 .39245 Mdot
.48602 .33114 Mdot
.61436 .37125 Mdot
.42021 .46368 Mdot
.56834 .43743 Mdot
.59985 .3356 Mdot
.50411 .43375 Mdot
.63218 .52286 Mdot
.62329 .64897 Mdot
.50507 .54744 Mdot
.56192 .34251 Mdot
.70187 .54067 Mdot
.59361 .43981 Mdot
.51058 .65505 Mdot
.64727 .57329 Mdot
.43904 .38313 Mdot
.574 .64969 Mdot
.61032 .37843 Mdot
.38169 .58872 Mdot
.55764 .39213 Mdot
.45205 .65758 Mdot
.39471 .47012 Mdot
.33278 .41968 Mdot
.40055 .44692 Mdot
.36349 .37953 Mdot
.3904 .64339 Mdot
.38235 .4968 Mdot
.43124 .34944 Mdot
.39801 .64107 Mdot
.52181 .42364 Mdot
.61768 .45709 Mdot
.69217 .51477 Mdot
.40749 .35404 Mdot
.34357 .56938 Mdot
.60095 .64689 Mdot
.59178 .36893 Mdot
.34979 .40606 Mdot
.33519 .4868 Mdot
.66115 .54809 Mdot
.53822 .426 Mdot
.46841 .30876 Mdot
.54603 .50132 Mdot
.5004 .3292 Mdot
.60581 .53612 Mdot
.59634 .68001 Mdot
.40847 .37364 Mdot
.62376 .46448 Mdot
.51591 .42626 Mdot
.38419 .58291 Mdot
.4745 .65353 Mdot
.36111 .60515 Mdot
.3717 .54899 Mdot
.46759 .30086 Mdot
.38876 .57387 Mdot
.62923 .43815 Mdot
.44025 .59973 Mdot
.57706 .36767 Mdot
.47533 .32023 Mdot
.56745 .41977 Mdot
.66347 .42758 Mdot
.33002 .5259 Mdot
.42566 .41002 Mdot
.61979 .6476 Mdot
.53512 .69561 Mdot
.31838 .54781 Mdot
.53011 .34203 Mdot
.34134 .49905 Mdot
.3985 .56905 Mdot
.45191 .41376 Mdot
.45837 .33457 Mdot
.50949 .45954 Mdot
.60517 .33047 Mdot
.44609 .62255 Mdot
.5963 .65151 Mdot
.52101 .66504 Mdot
.6838 .48178 Mdot
.55748 .3405 Mdot
.55981 .63298 Mdot
.49372 .57615 Mdot
.50426 .41709 Mdot
.41833 .32184 Mdot
.64198 .56436 Mdot
.64614 .36471 Mdot
.46769 .67111 Mdot
.33586 .49416 Mdot
.57371 .68682 Mdot
.49971 .60266 Mdot
.54323 .57765 Mdot
.3423 .52507 Mdot
.68121 .52061 Mdot
.56512 .64966 Mdot
.50375 .68722 Mdot
.35392 .45385 Mdot
.55698 .5985 Mdot
.47425 .32628 Mdot
.63358 .39966 Mdot
.53 .57501 Mdot
.50688 .32564 Mdot
.6929 .49751 Mdot
.35694 .44288 Mdot
.36204 .53405 Mdot
.3485 .40307 Mdot
.40593 .66744 Mdot
.47207 .61377 Mdot
.49751 .35604 Mdot
.55678 .54524 Mdot
.67593 .54346 Mdot
.50992 .6666 Mdot
.57644 .34196 Mdot
.31644 .47449 Mdot
.63739 .37817 Mdot
.61089 .44532 Mdot
.39893 .58543 Mdot
.40264 .59793 Mdot
.61439 .59994 Mdot
.59885 .54522 Mdot
.46391 .56391 Mdot
.58745 .45517 Mdot
.43687 .62105 Mdot
.46224 .32768 Mdot
.33621 .46124 Mdot
.5154 .70186 Mdot
.45025 .30382 Mdot
.47693 .67798 Mdot
.48756 .68178 Mdot
.59675 .41096 Mdot
.57434 .59751 Mdot
.5309 .41276 Mdot
.5215 .39454 Mdot
.70558 .42535 Mdot
.32388 .54081 Mdot
.57299 .62762 Mdot
.58666 .43832 Mdot
.65624 .4564 Mdot
.50845 .61789 Mdot
.46638 .3046 Mdot
.66579 .4985 Mdot
.56061 .3311 Mdot
.58063 .37408 Mdot
.66656 .48428 Mdot
.61709 .53915 Mdot
.62441 .61864 Mdot
.39498 .40293 Mdot
.61788 .45357 Mdot
.45557 .37467 Mdot
.6808 .50462 Mdot
.42544 .54539 Mdot
.42468 .66645 Mdot
.3494 .5544 Mdot
.40655 .49683 Mdot
.4145 .43592 Mdot
.35091 .4635 Mdot
.3576 .37537 Mdot
.31509 .54464 Mdot
.65492 .43965 Mdot
.32816 .50919 Mdot
.51406 .63703 Mdot
.31407 .44545 Mdot
.53722 .39329 Mdot
.55547 .59759 Mdot
.39334 .62365 Mdot
.46613 .45437 Mdot
.51968 .34511 Mdot
.61092 .61685 Mdot
.53147 .66597 Mdot
.4521 .33669 Mdot
.40639 .66981 Mdot
.50095 .71013 Mdot
.66725 .55231 Mdot
.53206 .30384 Mdot
.51852 .66909 Mdot
.33925 .43891 Mdot
.66037 .39853 Mdot
.64294 .391 Mdot
.61739 .59519 Mdot
.50658 .37525 Mdot
.68537 .41897 Mdot
.65092 .58103 Mdot
.41491 .31725 Mdot
.64418 .37411 Mdot
.3845 .44847 Mdot
.58577 .67985 Mdot
.39158 .6423 Mdot
.4163 .44933 Mdot
.30616 .45582 Mdot
.46516 .35231 Mdot
.39753 .61662 Mdot
.6012 .45287 Mdot
.33516 .51324 Mdot
.61858 .39069 Mdot
.62983 .38498 Mdot
.67373 .5372 Mdot
.46616 .62987 Mdot
.65583 .40588 Mdot
.65589 .46987 Mdot
.45431 .66593 Mdot
.33857 .50214 Mdot
.40468 .4329 Mdot
.55525 .53938 Mdot
.45324 .44051 Mdot
.41586 .37651 Mdot
.53245 .33207 Mdot
.55555 .3168 Mdot
.55545 .30801 Mdot
.34899 .54006 Mdot
.56293 .41127 Mdot
.45853 .51118 Mdot
.36042 .45224 Mdot
.65439 .49596 Mdot
.62329 .46255 Mdot
.60711 .38644 Mdot
.47218 .61415 Mdot
.46172 .71075 Mdot
.34445 .45879 Mdot
.40326 .53509 Mdot
.56208 .32899 Mdot
.67515 .50899 Mdot
.65598 .43916 Mdot
.33255 .48337 Mdot
.45739 .55972 Mdot
.39175 .50012 Mdot
.32522 .56143 Mdot
.40954 .34331 Mdot
.61986 .61935 Mdot
.32858 .57022 Mdot
.37968 .34516 Mdot
.66564 .45998 Mdot
.52742 .3761 Mdot
.70331 .52775 Mdot
.62433 .35941 Mdot
.38008 .54756 Mdot
.3342 .52778 Mdot
.59101 .44927 Mdot
.66297 .5994 Mdot
.47355 .64052 Mdot
.61814 .43776 Mdot
.62689 .38758 Mdot
.4305 .61433 Mdot
.68744 .45918 Mdot
.42765 .47482 Mdot
.70448 .54009 Mdot
.47252 .35482 Mdot
.33147 .47471 Mdot
.49347 .69625 Mdot
.37089 .42425 Mdot
.50287 .71206 Mdot
.48971 .61705 Mdot
.47427 .6787 Mdot
.35945 .58112 Mdot
.62165 .43511 Mdot
.32955 .50727 Mdot
.43286 .60113 Mdot
.33335 .47021 Mdot
.42034 .32751 Mdot
.66949 .59382 Mdot
.43449 .56696 Mdot
.36972 .56551 Mdot
.54919 .6177 Mdot
.58402 .60334 Mdot
.65513 .42319 Mdot
.49595 .32723 Mdot
.63435 .48888 Mdot
.42428 .68223 Mdot
.44501 .44446 Mdot
.48724 .36363 Mdot
.6164 .48248 Mdot
.483 .36319 Mdot
.42469 .4575 Mdot
.41581 .66778 Mdot
.32466 .57662 Mdot
.58188 .65455 Mdot
.38078 .52476 Mdot
.31282 .54379 Mdot
.31183 .44755 Mdot
.51246 .71694 Mdot
.65965 .39472 Mdot
.334 .56021 Mdot
.63129 .37673 Mdot
.46518 .35642 Mdot
.4733 .67294 Mdot
.37339 .58242 Mdot
.64273 .39331 Mdot
.45594 .70291 Mdot
.38027 .58043 Mdot
.64769 .36396 Mdot
.6447 .42822 Mdot
.44931 .30264 Mdot
.64708 .57707 Mdot
.52973 .63697 Mdot
.48958 .71854 Mdot
.32908 .42987 Mdot
.62927 .42945 Mdot
.61231 .59974 Mdot
.66751 .55002 Mdot
.61135 .379 Mdot
.42314 .41574 Mdot
.65813 .54298 Mdot
.46529 .32091 Mdot
.3814 .60311 Mdot
.44442 .43665 Mdot
.57429 .61756 Mdot
.41545 .54768 Mdot
.41959 .38206 Mdot
.32393 .46345 Mdot
.3533 .38111 Mdot
.41397 .51975 Mdot
.43378 .35441 Mdot
.66789 .40129 Mdot
.42495 .31402 Mdot
.57606 .59327 Mdot
.50748 .6535 Mdot
.41289 .50329 Mdot
.57968 .53646 Mdot
.63091 .64702 Mdot
.33148 .55124 Mdot
.39535 .46738 Mdot
.66009 .41691 Mdot
.58619 .53178 Mdot
.5196 .62718 Mdot
.53133 .61723 Mdot
.40597 .41924 Mdot
.61741 .6578 Mdot
.3407 .59455 Mdot
.35993 .37778 Mdot
.45396 .69275 Mdot
.31346 .44925 Mdot
.5454 .40888 Mdot
.67393 .44549 Mdot
.63426 .43046 Mdot
.62733 .37166 Mdot
.45488 .39607 Mdot
.41432 .37345 Mdot
.63663 .64064 Mdot
.37186 .43716 Mdot
.48702 .45247 Mdot
.66771 .51333 Mdot
.40112 .54679 Mdot
.33497 .47649 Mdot
.43651 .44895 Mdot
.37206 .35962 Mdot
.45103 .32581 Mdot
.47284 .37466 Mdot
.65833 .50677 Mdot
.65181 .60537 Mdot
.65492 .4335 Mdot
.3691 .50627 Mdot
.53476 .67156 Mdot
.32176 .48899 Mdot
.51879 .3601 Mdot
.5915 .47709 Mdot
.57713 .6115 Mdot
.41786 .57682 Mdot
.33734 .53329 Mdot
.47578 .30382 Mdot
.41529 .53401 Mdot
.4195 .43329 Mdot
.34673 .47196 Mdot
.61802 .6481 Mdot
.50258 .51597 Mdot
.4305 .44381 Mdot
.34801 .44758 Mdot
.44004 .29933 Mdot
.39576 .59126 Mdot
.49643 .70242 Mdot
.67677 .44103 Mdot
.34762 .407 Mdot
.33182 .52224 Mdot
.67032 .44878 Mdot
.58686 .45407 Mdot
.63863 .35688 Mdot
.43579 .43633 Mdot
.51309 .69456 Mdot
.63247 .57345 Mdot
.36864 .38941 Mdot
.46605 .4263 Mdot
.32253 .58552 Mdot
.50464 .36489 Mdot
.52793 .41351 Mdot
.46799 .67857 Mdot
.60242 .3845 Mdot
.42332 .63886 Mdot
.66333 .53406 Mdot
.47201 .34876 Mdot
.60393 .33535 Mdot
.43503 .30584 Mdot
.53424 .58514 Mdot
.69215 .50215 Mdot
.55969 .41015 Mdot
.54436 .67254 Mdot
.58148 .51169 Mdot
.68778 .44985 Mdot
.56579 .66982 Mdot
.37978 .43314 Mdot
.5635 .57003 Mdot
.70929 .42717 Mdot
.43981 .61244 Mdot
.52025 .54657 Mdot
.58299 .58754 Mdot
.50037 .60215 Mdot
.4999 .57718 Mdot
.64041 .57313 Mdot
.51242 .52629 Mdot
.58716 .64866 Mdot
.62836 .55629 Mdot
.40556 .45454 Mdot
.61238 .43103 Mdot
.47064 .38911 Mdot
.38224 .34065 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0?ooooooB_ooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A006ooooo`03o`000?oooooooooo0?ooooooB_ooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0?ooooooB_oo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06
ooooo`?o0000oooooom:ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<oooo
o`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom:ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001_ooool00ol0003oooooooooo`3ooooood[ooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`2Dooooo`Ko00000_ooool3o`000:[ooooo000Looooo`03o`000?oooooo
oooo09;ooooo3_l0002Yooooo`007?ooool00ol0003oooooooooo`2?ooooo`;o000000?oooooo`00
0?l000003ol0002Vooooo`007?ooool00ol0003oooooooooo`2<oooooaOo000000?oooooo`000?l0
0000Xoooool001cooooo00?o0000ooooooooool0S?oooolMo`000:3ooooo000Looooo`03o`000?oo
oooooooo08[ooooo8Ol0002Nooooo`007?ooool00ol0003oooooooooo`27ooooobKo0000W?ooool0
01cooooo00?o0000ooooooooool0Q_ooool/o`0000?ooooo1?l00002ooooo`;o0000S?ooool001co
oooo00?o0000ooooooooool0QOooool_o`000003ooooool0003o000000So0000R_ooool001cooooo
00?o0000ooooooooool0Q?oooolJo`000003ooooool0003o0000027o0000Qoooool001cooooo00?o
0000ooooooooool0Q?ooool<o`000003ooooool0003o0000033o0000Q_ooool001cooooo00?o0000
ooooooooool0POooool3o`000003ooooool0003o000002So000000?oooooo`000?l000004_l00025
ooooo`007?ooool2o`00083ooooo;Ol00007oooooa;o0000Q?ooool001cooooo00?o0000oooooooo
ool0OOooool@o`000004ooooool0003o0000o`0000?ooooo6?l00007oooooa;o0000Q?ooool001co
oooo00?o0000ooooooooool0Noooool>o`000004ooooool0003o0000ooooo`Co00000oooool2o`00
0003ooooool0003o000000?ooooo3ol00003ooooo`;o00001?oooolAo`0008Cooooo000Looooo`03
o`000?oooooooooo07Wooooo3ol00002ooooo`;o000000Coooooo`000?l0003o00001?ooool3o`00
00oooooo0_l00006ooooo`;o000000Coooooo`000?l0003ooooo4_l00023ooooo`007?ooool00ol0
003oooooooooo`1iooooo`oo00000_ooool2o`000003ooooool0003o000000?ooooo1Ol00003oooo
o`;o00001oooool2o`000003ooooool0003o000000Wooooo5ol00021ooooo`007?ooool00ol0003o
ooooooooo`1goooooa7o00000_ooool2o`0000Kooooo0_l00006ooooo`;o00000oooool2o`0000;o
oooo0_l0000<oooooaOo0000POooool001cooooo00?o0000ooooooooool0Moooool>o`0001[ooooo
0_l00003ooooo`;o00002oooool2o`000004ooooool0003o0000oooooa3o0000P_ooool001cooooo
00?o0000ooooooooool0Moooool?o`0000gooooo0_l00002ooooo`;o00000oooool2o`0000Kooooo
0_l0000Boooooa3o0000POooool001cooooo00?o0000ooooooooool0Moooool;o`0000;ooooo0_l0
0009ooooo`;o00000_ooool2o`000004ooooool0003o0000o`0000?ooooo0_l00003ooooo`;o0000
3?ooool2o`0000Sooooo0_l000000ooooooo0000o`00000<o`0007oooooo000Looooo`03o`000?oo
oooooooo07Gooooo3Ol00003ooooo`;o00001_ooool4o`000003ooooool0003o000000;ooooo0_l0
0002ooooo`;o000000?oooooo`000?l000001?l0000<ooooo`?o000000?oooooo`000?l000001?oo
ool2o`0000;ooooo4?l0001looooo`007?ooool00ol0003oooooooooo`1dooooo`go000000Cooooo
o`000?l0003ooooo0_l00006ooooo`;o00000oooool2o`0000Kooooo0_l000000ooooooo0000o`00
0002o`0000Sooooo0_l00003ooooo`Oo00003?ooool=o`0007_ooooo000Looooo`03o`000?oooooo
oooo07Cooooo2Ol00005ooooo`;o00003Oooool3o`0000Kooooo0_l0000=ooooo`;o00000oooool3
o`000003ooooool0003o000000;ooooo0_l00003ooooo`;o00000ooooolCo`0007Kooooo000Loooo
o`03o`000?oooooooooo07;ooooo2_l00004ooooo`;o00002oooool6o`0001Kooooo0_l0000;oooo
o`;o00000oooool2o`0000;ooooo1?l00005ooooo`co0000MOooool001cooooo00?o0000oooooooo
ool0L_ooool9o`0000?ooooo1?l0000;ooooo`Co00005oooool3o`0000Kooooo0_l0000<ooooo`Co
00001?ooool3o`0000;ooooo2Ol0001dooooo`007?ooool00ol0003oooooooooo`1aooooo`[o0000
0oooool2o`000003ooooool0003o000000?ooooo0_l00006ooooo`;o00001?ooool2o`0001;ooooo
0_l00002ooooo`;o00000oooool4o`0000;ooooo0_l0000>ooooo`;o00001?ooool:o`0007;ooooo
000Looooo`03o`000?oooooooooo077ooooo2Ol00006ooooo`?o00000oooool2o`0000Kooooo0_l0
0004ooooo`?o00003_ooool2o`000003ooooool0003o000000;ooooo0_l00005ooooo`?o000000?o
ooooo`000?l000000oooool2o`00013ooooo2Ol0001booooo`007?ooool2o`00077ooooo2_l00006
ooooo`;o00001_ooool2o`0000_ooooo0ol0000=ooooo`;o00001oooool2o`0000Cooooo0_l00006
ooooo`?o00003oooool;o`00073ooooo000Looooo`03o`000?oooooooooo073ooooo1ol00009oooo
o`?o00001Oooool2o`0000Wooooo0_l000000ooooooo0000o`000004ooooo`;o00003_ooool4o`00
0003ooooool0003o000000[ooooo0_l0000@ooooo`_o0000Koooool001cooooo00?o0000oooooooo
ool0Koooool7o`0000[ooooo0ol00005ooooo`?o00000_ooool2o`0000Cooooo0_l000000ooooooo
0000o`000004ooooo`Ko00001Oooool2o`0000?ooooo0ol00002ooooo`?o00002Oooool2o`0000;o
oooo0_l00009ooooo`;o00000_ooool:o`0006oooooo000Looooo`03o`000?oooooooooo06oooooo
2?l0000Aooooo`?o00000_ooool4o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o0000
00?oooooo`000?l000000_l00003ooooo`Co00002Oooool2o`0000Wooooo0_l00002ooooo`;o0000
1?ooool2o`0000?ooooo0_l00002ooooo`_o0000K_ooool001cooooo00?o0000ooooooooool0Kooo
ool8o`0000[ooooo0_l0000<ooooo`;o00002?ooool7o`0000Gooooo0_l00007ooooo`;o00003ooo
ool2o`0000Cooooo1?l00007ooooo`co0000KOooool001cooooo00?o0000ooooooooool0K_ooool6
o`0000gooooo0_l0000Fooooo`Go00000_ooool2o`0000?ooooo0_l00007ooooo`;o00002?ooool2
o`0000Gooooo0_l00004ooooo`;o00001oooool>o`0006gooooo000Looooo`03o`000?oooooooooo
06kooooo1Ol0000:ooooo`;o00000_ooool2o`0001;ooooo0_l00004ooooo`;o00000oooool2o`00
00?ooooo0_l000000ooooooo0000o`00000=ooooo`?o00000_ooool3o`0000Wooooo0_l00004oooo
o`go0000K_ooool001cooooo00?o0000ooooooooool0KOooool6o`0000;ooooo0_l00006ooooo`;o
00000_ooool2o`0001;ooooo0_l00008ooooo`;o00001?ooool2o`000003ooooool0003o000000go
oooo0ol00002ooooo`?o00000_ooool2o`000003ooooool0003o000000;ooooo0_l00007ooooo`_o
0000KOooool001cooooo00?o0000ooooooooool0JOooool:o`0000;ooooo0_l0000:ooooo`Co0000
2oooool2o`0000Cooooo0_l00007ooooo`Co00005_ooool2o`0000Kooooo0_l000000ooooooo0000
o`000002ooooo`;o00000oooool2o`0000;ooooo2ol0001]ooooo`007?ooool00ol0003ooooooooo
o`1Wooooo`co00002oooool2o`000003ooooool0003o000000;o00002oooool2o`0000Cooooo0_l0
0007ooooo`Co00001Oooool2o`0000Oooooo0_l00006ooooo`;o00000oooool2o`0000;ooooo1?l0
0003ooooo`Ko00000_ooool<o`0006cooooo000Looooo`03o`000?oooooooooo06Oooooo3Ol00004
ooooo`;o00001?ooool2o`000003ooooool0003o000000;o00001Oooool4o`000004ooooool0003o
0000o`0000?ooooo0_l00008ooooo`;o00001oooool2o`0000Oooooo0_l00009ooooo`Co00000_oo
ool3o`0000Cooooo1_l00002ooooo`co0000K?ooool001cooooo00?o0000ooooooooool0I_ooool;
o`000003ooooool0003o000000Cooooo0_l0000;ooooo`;o00000oooool4o`000003ooooool0003o
000000;ooooo1?l00007ooooo`;o000000?oooooo`000?l000006Oooool3o`000004ooooool0003o
0000ooooo`;o00000_ooool2o`0000Sooooo2ol0001]ooooo`007?ooool00ol0003oooooooooo`1V
ooooo`[o00005Oooool2o`0000Cooooo0_l00006ooooo`Co00001oooool2o`000003ooooool0003o
000001gooooo0ol00004ooooo`Ko00001Oooool:o`0006gooooo000Looooo`03o`000?oooooooooo
06Gooooo2_l00005ooooo`;o00002?ooool2o`0000_ooooo0_l00008ooooo`;o00007Oooool2o`00
00_ooooo0_l00002ooooo`[o00001?ooool6o`000003ooooool0003o000006gooooo00001_oooooo
k^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool0
0ol0003oooooooooo`1Tooooo`_o00001Oooool2o`0000Kooooo1?l0000Eooooo`;o00002?ooool2
o`0000[ooooo0ol00003ooooo`;o000000?oooooo`000?l000003_ooool3o`0000Kooooo0ol00002
ooooo`[o0000KOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1Tooooo`_o00003Oooool4o`00013ooooo0_l0
000=ooooo`;o00001Oooool2o`0000?ooooo0ol00003ooooo`;o00004Oooool2o`0000Oooooo0ol0
0002ooooo`[o0000KOooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool5
o`0000Kooooo00?o0000ooooooooool0H_ooool<o`00013ooooo0_l0000@ooooo`;o00005?ooool3
o`0000;ooooo0_l0000Mooooo`;o00001_ooool:o`0006gooooo00000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`0006;ooooo3Ol0000>
ooooo`Go00009Oooool2o`0000;ooooo0_l0000Eooooo`?o00001Oooool2o`0000Oooooo2_l0001/
ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGooooo
o`0000Oooooo00?o0000ooooooooool0H_ooool>o`0000Cooooo0_l00007ooooo`;o000000?ooooo
o`000?l000000_l000001?oooooo0000o`000?l0000Looooo`;o00007?ooool3o`0000cooooo0ol0
00000ooooooo0000o`000008o`0006[ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooo
oooo00[ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`1Pooooo`Co000000?ooooo
o`000?l000002Ol00004ooooo`;o00003?ooool2o`000004ooooool0003o0000o`0001cooooo0_l0
0007ooooo`;o00004Oooool3o`0000?ooooo0_l00006ooooo`Ko00001Oooool8o`0006Sooooo0000
1_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l000001oooool00ol0003ooooo
ooooo`1Nooooo`ko000000?oooooo`000?l000006?ooool2o`0000Sooooo0_l00008ooooo`;o0000
4?ooool2o`0000?ooooo0ol000000ooooooo0000o`000006ooooo`Go00000oooool3o`0000Gooooo
0ol00009ooooo`Wo0000I_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo
0000ooooo`06ooooo`03o`000?oooooooooo05gooooo3ol0000Jooooo`?o00001_ooool4o`0000So
oooo0_l0000;ooooo`?o00001oooool3o`000003ooooool0003o000000Kooooo0ol00006ooooo`;o
00003_ooool2o`0000Gooooo1_l0001Uooooo`007?ooool00ol0003oooooooooo`1Loooooa3o0000
3?ooool2o`0000cooooo0_l00006ooooo`?o00003oooool2o`0000Kooooo0ol0000Nooooo`;o0000
2?ooool2o`0000;ooooo0_l00006ooooo`Ko0000I?ooool001cooooo00?o0000ooooooooool0F_oo
oolBo`0000Kooooo0_l00004ooooo`;o00001_ooool2o`0000Cooooo0_l00006ooooo`;o00004?oo
ool2o`00017ooooo1?l0000;ooooo`;o00001Oooool3o`0000Oooooo0_l000000ooooooo0000o`00
0003ooooo`;o00001Oooool5o`0006;ooooo000Looooo`03o`000?oooooooooo05[ooooo4?l00008
ooooo`;o000000?oooooo`000?l000002Oooool2o`0001kooooo0_l00002ooooo`Co00002oooool4
o`0000_ooooo0_l00006ooooo`;o00001Oooool2o`0000?ooooo0_l00003ooooo`;o00000oooool7
o`0006;ooooo000Looooo`03o`000?oooooooooo05[ooooo3_l0000=ooooo`;o00004_ooool2o`00
00Wooooo0_l00002ooooo`;o00001_ooool2o`0000;ooooo1?l00003ooooo`;o00004Oooool2o`00
017ooooo1Ol00002ooooo`;o00001_ooool9o`00063ooooo000Looooo`03o`000?oooooooooo05So
oooo4Ol0000>ooooo`;o00004?ooool2o`0000Sooooo0ol00002ooooo`;o00002_ooool2o`0000Go
oooo0_l0000Aooooo`;o00000oooool2o`0000Cooooo0ol00002ooooo`;o000000?oooooo`000?l0
00000ol00002ooooo`;o00001oooool9o`0005oooooo000Looooo`03o`000?oooooooooo05Sooooo
4Ol00006ooooo`;o00001_ooool3o`0000Kooooo0_l00003ooooo`;o00001Oooool2o`0000Gooooo
0_l0000;ooooo`;o00004Oooool2o`0000kooooo0_l00004ooooo`?o00000_ooool2o`000004oooo
ool0003o0000o`0000oooooo0_l000000ooooooo0000o`000002o`0005oooooo000Looooo`03o`00
0?oooooooooo05Wooooo2?l000000ooooooo0000o`000002o`0000Wooooo0_l00004ooooo`;o0000
00?oooooo`000?l000001_ooool2o`000003ooooool0003o000000;o00000oooool5o`00017ooooo
0_l0000Aooooo`;o000000?oooooo`000?l000002Oooool2o`0000?ooooo0_l00009ooooo`?o0000
2_ooool=o`0005kooooo000Looooo`03o`000?oooooooooo05Sooooo3_l00004ooooo`;o000000?o
ooooo`000?l000001_ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`000003ooooool0
003o000000oooooo0_l00004ooooo`;o00003oooool3o`0000?ooooo1?l00002ooooo`;o00000_oo
ool3o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`00000;ooooo`go0000G_oo
ool001cooooo00?o0000ooooooooool0Eoooool>o`0000Gooooo0_l000001?oooooo0000o`000?oo
ool2o`0000Gooooo0_l00003ooooo`;o00003?ooool2o`0000?ooooo0_l0000=ooooo`;o00001?oo
ool2o`0000oooooo0_l00004ooooo`Co00001_ooool2o`000004ooooool0003o0000o`0000?ooooo
0_l000000ooooooo0000o`000005ooooo`?o00000oooool=o`0005kooooo000Looooo`03o`000?oo
oooooooo05Oooooo3Ol00006ooooo`;o00001?ooool2o`0000Gooooo0_l0000?ooooo`Co000000?o
ooooo`000?l000001?l0000Oooooo`;o00003oooool2o`0000?ooooo0_l0000=ooooo`Co00000_oo
ool>o`0005kooooo000Looooo`03o`000?oooooooooo05Oooooo2_l000000ooooooo0000o`000006
ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`0000?ooooo0_l00003ooooo`Co000000?o
ooooo`000?l000000oooool4o`000003ooooool0003o000000;ooooo0_l0000Oooooo`;o00002?oo
ool2o`0000Gooooo0_l00003ooooo`;o00003?ooool3o`0000;ooooo4?l0001Nooooo`007?ooool2
o`0005Sooooo2_l000000ooooooo0000o`000009ooooo`?o000000Coooooo`000?l0003ooooo0_l0
0003ooooo`;o00000oooool4o`000003ooooool0003o000000Gooooo0_l00005ooooo`;o00001ooo
ool2o`00023ooooo0_l00003ooooo`;o00004oooool2o`000003ooooool0003o0000017o0000GOoo
ool001cooooo00?o0000ooooooooool0FOooool8o`000003ooooool0003o000000Wooooo1_l0000=
ooooo`;o00004_ooool2o`0000Cooooo0_l0000Oooooo`;o00000oooool3o`0000;ooooo0_l0000?
ooooo`;o000000Coooooo`000?l0003ooooo2?l000000ooooooo0000o`000005o`0005gooooo000L
ooooo`03o`000?oooooooooo05Sooooo3?l00006ooooo`Co000000?oooooo`000?l000000_l0000=
ooooo`;o00001?ooool2o`0000cooooo0_l0000Uooooo`?o00000_ooool2o`0000;ooooo0ol0000:
ooooo`;o00000oooool2o`0000Cooooo4?l0001Mooooo`007?ooool00ol0003oooooooooo`1Hoooo
o`co00001Oooool5o`0000?ooooo0_l0000Cooooo`;o00001?ooool2o`0000?ooooo0_l00002oooo
o`;o00002oooool2o`0001Sooooo0_l00003ooooo`;o000000Coooooo`000?l0003o00002?ooool4
o`000004ooooool0003o0000ooooo`;o00000oooool@o`0005gooooo000Looooo`03o`000?oooooo
oooo05Sooooo2?l00002ooooo`;o000000?oooooo`000?l000000_ooool4o`000003ooooool0003o
000000;ooooo0_l0000Aooooo`;o00001Oooool2o`0000?ooooo0ol000000ooooooo0000o`00000;
ooooo`;o00007Oooool2o`0000Cooooo0_l00006ooooo`;o00000oooool2o`000003ooooool0003o
000000?ooooo3_l0001Oooooo`007?ooool00ol0003oooooooooo`1Iooooo`Oo00001Oooool2o`00
00Oooooo0_l00002ooooo`;o00002Oooool2o`0000Kooooo0_l0000;ooooo`;o0000<oooool2o`00
00Kooooo0_l00006ooooo`;o00000oooool?o`0005kooooo000Looooo`03o`000?oooooooooo05Wo
oooo1ol00009ooooo`;o00001Oooool2o`0000[ooooo0ol0000Oooooo`;o00004oooool2o`0001[o
oooo1?l00004ooooo`;o00001Oooool=o`0005kooooo000Looooo`03o`000?oooooooooo05Wooooo
2?l00008ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o00001oooool2o`0001Co
oooo0_l0000:ooooo`;o00000_ooool2o`0000oooooo0_l0000Looooo`;o00001?ooool2o`0000Co
oooo3_l0001Nooooo`007?ooool00ol0003oooooooooo`1Iooooo`So00000_ooool2o`0000?ooooo
1?l000001?oooooo0000o`000?l00003ooooo`;o00001oooool2o`000003ooooool0003o000000Ko
oooo0_l00009ooooo`;o00003_ooool2o`0000gooooo0_l000000ooooooo0000o`000006ooooo`;o
00002Oooool2o`0000kooooo0_l000001?oooooo0000o`000?ooool=o`0005oooooo000Looooo`03
o`000?oooooooooo05Wooooo2?l00002ooooo`;o00000oooool4o`0000;ooooo0_l0000?ooooo`;o
00001_ooool2o`0000Cooooo0_l0000Rooooo`;o000000?oooooo`000?l000001_ooool2o`0000Wo
oooo0_l0000<ooooo`Co000000Coooooo`000?l0003ooooo3Ol0001Oooooo`007?ooool00ol0003o
ooooooooo`1Iooooo`So00001oooool3o`0001kooooo0_l00002ooooo`?o00001?ooool2o`0002ko
oooo0_l000000ooooooo0000o`00000:ooooo`Co00000oooool2o`0000;ooooo3?l0001Oooooo`00
7?ooool00ol0003oooooooooo`1Jooooo`Oo00001oooool4o`0001gooooo0_l00003ooooo`;o0000
1?ooool2o`0002kooooo0_l00007ooooo`;o00001?ooool4o`0000?ooooo0_l000000ooooooo0000
o`00000;o`0005oooooo000Looooo`03o`000?oooooooooo05[ooooo1ol00004ooooo`;o00000_oo
ool3o`0000Cooooo0_l0000Cooooo`Co0000>Oooool5o`0000?ooooo0_l000000ooooooo0000o`00
0002ooooo`;o00000_ooool2o`0000Kooooo3?l0001Pooooo`007?ooool00ol0003oooooooooo`1I
ooooo`Wo00000oooool2o`0000;ooooo0ol00004ooooo`;o00001Oooool2o`0000cooooo1?l0000i
ooooo`;o000000?oooooo`000?l000000oooool2o`0000Gooooo0_l0000;ooooo`_o0000H?ooool0
01cooooo00?o0000ooooooooool0FOooool9o`0000Oooooo0_l00004ooooo`;o00001_ooool2o`00
05Oooooo0_l00006ooooo`;o00001?ooool;o`00063ooooo000Looooo`03o`000?oooooooooo05So
oooo2_l00007ooooo`Co00000_ooool2o`0000Oooooo0_l00006ooooo`;o00003oooool2o`0000;o
oooo0_l0000hooooo`Co000000?oooooo`000?l000000_ooool2o`0000?ooooo2ol0001Qooooo`00
7?ooool2o`0005Wooooo2_l00009ooooo`;o00000oooool2o`0000Kooooo0_l00002ooooo`;o0000
0_ooool2o`0000oooooo0_l00002ooooo`;o00005Oooool4o`0000Oooooo0_l0000Fooooo`Co0000
00?oooooo`000?l000001oooool;o`00067ooooo000Looooo`03o`000?oooooooooo05Kooooo3_l0
0006ooooo`?o00000oooool4o`0000Sooooo0_l00004ooooo`;o0000:?ooool4o`0000Oooooo0_l0
000Pooooo`;o00000_ooool;o`00067ooooo000Looooo`03o`000?oooooooooo05Kooooo3ol00002
ooooo`Go00001_ooool8o`0000Sooooo0_l0000_ooooo`;o00007Oooool2o`0000;ooooo1Ol00002
ooooo`co0000H?ooool001cooooo00?o0000ooooooooool0E_ooool?o`0000;ooooo1Ol00008oooo
o`Ko0000>Oooool2o`0001gooooo0_l00002ooooo`Co00001Oooool:o`00063ooooo000Looooo`03
o`000?oooooooooo05Kooooo3Ol00004ooooo`Go00002?ooool2o`0001Gooooo0_l00004ooooo`;o
00009_ooool2o`0000kooooo0_l00007ooooo`;o000000Coooooo`000?l0003ooooo0_l00004oooo
o`Go000000?oooooo`000?l000000_l0001Qooooo`007?ooool00ol0003oooooooooo`1Eooooo`Wo
000000?oooooo`000?l000000_l00005ooooo`?o00008?ooool2o`0000Cooooo0_l0000<ooooo`;o
00005_ooool4o`0000kooooo0_l0000:ooooo`;o00001_ooool3o`000003ooooool0003o000000Go
0000HOooool001cooooo00?o0000ooooooooool0E?ooool?o`0000Gooooo0_l0000Eooooo`;o0000
0_ooool2o`000003ooooool0003o000001Oooooo0_l0000=ooooo`;o00001oooool2o`0000;ooooo
0_l0000Pooooo`;o00000oooool7o`00063ooooo000Looooo`03o`000?oooooooooo05Cooooo4?l0
0004ooooo`;o00005Oooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`Co00008?oo
ool2o`0000_ooooo1?l0000;ooooo`;o00003Oooool2o`0000Cooooo2_l0001Pooooo`007?ooool0
0ol0003oooooooooo`1Doooooa3o00000oooool3o`000003ooooool0003o000000_ooooo0_l0000@
ooooo`Co00005Oooool2o`0000_ooooo0_l0000:ooooo`?o00002oooool2o`0000gooooo1?l00000
0ooooooo0000o`000009o`00063ooooo000Looooo`03o`000?oooooooooo05Cooooo4?l00003oooo
o`Ko00002oooool2o`0000Gooooo0_l0000Rooooo`;o00002oooool2o`0000Oooooo0_l000000ooo
oooo0000o`000003ooooo`;o00002oooool3o`0000Cooooo0_l00004ooooo`_o0000Hoooool001co
oooo00?o0000ooooooooool0E?ooool?o`0000Gooooo0ol00006ooooo`;o00003?ooool2o`0003So
oooo1?l00004ooooo`;o00001?ooool2o`0000Cooooo1?l00004ooooo`Go00000_ooool2o`000003
ooooool0003o000000So0000H?ooool001cooooo00?o0000ooooooooool0E?ooool?o`0000Gooooo
1?l00005ooooo`?o00002oooool2o`0000;ooooo0_l0000fooooo`?o00001oooool4o`0000Cooooo
0_l00005ooooo`Ko00002?ooool7o`00063ooooo000Looooo`03o`000?oooooooooo05Cooooo3ol0
0007ooooo`;o00001_ooool2o`0000_ooooo0_l00002ooooo`;o00002Oooool2o`0001Cooooo0_l0
000Cooooo`;o000000?oooooo`000?l000000oooool2o`0000;ooooo1?l00007ooooo`;o00000_oo
ool5o`0000Wooooo1ol0001Pooooo`007?ooool00ol0003oooooooooo`1Dooooo`ko00000oooool4
o`0000?ooooo1?l000000ooooooo0000o`00000Kooooo`;o00001Oooool2o`0000gooooo0_l0000;
ooooo`;o00001_ooool2o`0000;ooooo0_l00002ooooo`;o00000_ooool2o`0000Gooooo0_l00002
ooooo`;o00000oooool4o`0000Oooooo2Ol0001Pooooo`007?ooool00ol0003oooooooooo`1Doooo
oaGo00000oooool4o`000003ooooool0003o000000;o00008?ooool2o`0000[ooooo0_l0000>oooo
o`;o00000_ooool2o`0000Gooooo1?l000000ooooooo0000o`000002ooooo`;o00001Oooool2o`00
00;ooooo1_l00002ooooo`;o00001?ooool7o`000004ooooool0003o0000o`00063ooooo000Loooo
o`03o`000?oooooooooo05Cooooo3Ol000000ooooooo0000o`000004o`0000[ooooo0ol00003oooo
o`;o00001Oooool2o`0000;ooooo0_l000000ooooooo0000o`00000Hooooo`?o00000_ooool2o`00
00[ooooo0ol000000ooooooo0000o`000005ooooo`Oo000000?oooooo`000?l000002_ooool6o`00
0003ooooool0003o000000;o00000oooool;o`00063ooooo000Looooo`;o0000EOoooolDo`0000[o
oooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo1?l00002ooooo`;o000000?oooooo`00
0?l000006?ooool2o`0000?ooooo0_l0000:ooooo`?o00002oooool2o`0000?ooooo0_l0000<oooo
o`co000000?oooooo`000?l000002?l0001Pooooo`007?ooool00ol0003oooooooooo`1Eooooo`go
00001_ooool2o`0000Cooooo0_l00005ooooo`;o00001_ooool2o`0003_ooooo0_l0000:ooooo`;o
00002_ooool2o`000003ooooool0003o000000Cooooo3_l0001Pooooo`007?ooool00ol0003ooooo
ooooo`1Eooooo`_o00002?ooool2o`0000Cooooo0_l0000Hooooo`;o0000;_ooool4o`0000[ooooo
1?l000000ooooooo0000o`000008ooooo`;o00001oooool;o`00063ooooo000Looooo`03o`000?oo
oooooooo05Oooooo2_l00007ooooo`?o00000oooool2o`0000;ooooo0_l00002ooooo`;o00003_oo
ool4o`0000Oooooo0_l0000Iooooo`;o00002_ooool2o`0000Cooooo0_l00006ooooo`Co000000?o
ooooo`000?l000003oooool=o`00063ooooo000Looooo`03o`000?oooooooooo05Oooooo2_l00005
ooooo`Go00001oooool2o`0000;ooooo0_l0000>ooooo`;o00002Oooool2o`0001Wooooo0_l0000@
ooooo`;o00001_ooool2o`0001?ooooo3Ol0001Qooooo`007?ooool00ol0003oooooooooo`1Goooo
o`So00000oooool3o`000003ooooool0003o000000cooooo0_l0000=ooooo`;o00003_ooool2o`00
0003ooooool0003o000000Cooooo0_l0000Pooooo`?o00003?ooool2o`0000?ooooo0_l00006oooo
o`ko0000HOooool001cooooo00?o0000ooooooooool0Eoooool8o`0000?ooooo1?l00006ooooo`;o
00001_ooool2o`0000Sooooo1?l000000ooooooo0000o`000004ooooo`;o00000oooool2o`0000?o
oooo0_l000000ooooooo0000o`000004ooooo`;o00008?ooool3o`0000cooooo0_l00003ooooo`;o
00000_ooool2o`0000;ooooo3_l0001Qooooo`007?ooool00ol0003oooooooooo`1Hooooo`Oo0000
1Oooool2o`000003ooooool0003o000000?ooooo0_l0000:ooooo`;o00001?ooool4o`000003oooo
ool0003o000000Cooooo1?l000000ooooooo0000o`00000Sooooo`;o000000?oooooo`000?l00000
3?ooool2o`0000Wooooo0_l00005ooooo`;o000000?oooooo`000?l000002?l000000ooooooo0000
o`000003o`00063ooooo000Looooo`03o`000?oooooooooo05Wooooo1ol00003ooooo`;o00000_oo
ool2o`0000[ooooo0_l00003ooooo`;o000000?oooooo`000?l000003_ooool2o`000003ooooool0
003o000000oooooo0_l00004ooooo`;o000000?oooooo`000?l000002Oooool2o`000003ooooool0
003o000000cooooo0_l00004ooooo`So000000?oooooo`000?l000001?ooool@o`00063ooooo000L
ooooo`03o`000?oooooooooo05[ooooo1_l00003ooooo`;o000000?oooooo`000?l000001?ooool2
o`0000Gooooo0_l00003ooooo`;o000000?oooooo`000?l000001oooool2o`0000Sooooo0_l0000=
ooooo`Co00001?ooool2o`000003ooooool0003o000000?ooooo0_l0000Kooooo`co00000_oooolA
o`00063ooooo000Looooo`03o`000?oooooooooo05_ooooo1_l00002ooooo`;o000000?oooooo`00
0?l000001?ooool2o`0000?ooooo1?l00003ooooo`;o00002_ooool2o`0000Oooooo0_l00005oooo
o`;o00001oooool4o`0000Gooooo0_l00005ooooo`;o00006oooool2o`0000;ooooo2?l00002oooo
oa3o0000HOooool001cooooo00?o0000ooooooooool0GOooool8o`0000Cooooo0_l00006ooooo`Co
000000?oooooo`000?l000000ol00002ooooo`;o00003_ooool2o`0000Gooooo0_l00007ooooo`;o
00001oooool2o`0001gooooo0_l00009ooooo`Co00001?ooool@o`00067ooooo000Looooo`03o`00
0?oooooooooo05kooooo2_l000000ooooooo0000o`000006ooooo`;o00000oooool5o`0000;ooooo
1?l00006ooooo`;o00005?ooool2o`000003ooooool0003o000000Sooooo0_l0000;ooooo`;o0000
00?oooooo`000?l000002Oooool2o`0000Kooooo0_l00003ooooo`;o00000_ooool;o`000003oooo
ool0003o000000Co0000HOooool001cooooo00?o0000ooooooooool0Goooool<o`0000Kooooo0_l0
0003ooooo`Co00000oooool4o`0000Kooooo0_l0000Gooooo`;o00001Oooool2o`000004ooooool0
003o0000ooooo`;o00002?ooool2o`000004ooooool0003o0000ooooo`;o00003_ooool2o`000003
ooooool0003o000000;ooooo4_l0001Sooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5oooo
o`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0H_ooool8
o`0000_ooooo0_l000000ooooooo0000o`000003ooooo`;o00000_ooool2o`0002Cooooo0_l00004
ooooo`Co00001_ooool2o`0000Cooooo0_l0000Aooooo`?o000000?oooooo`000?l000004?l0001S
ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooo
oonHV9So8B4Q00Kooooo00?o0000ooooooooool0Hoooool:o`0000Sooooo0_l0000:ooooo`;o0000
1oooool2o`0000;ooooo0_l0000Looooo`;o000000?oooooo`000?l000001_ooool2o`0000Cooooo
0_l00006ooooo`;o00002_ooool2o`0000?ooooo3ol0001Tooooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`1Uooooo`So00002?ooool2o`0000;ooooo1?l00002ooooo`;o00000_ooool2o`0000Gooooo
0ol000000ooooooo0000o`00000Looooo`;o00000oooool2o`0000Cooooo0_l0000:ooooo`Co0000
0_ooool2o`0000Oooooo1?l000000ooooooo0000o`00000:o`0006Kooooo00000ooooooo0000oooo
o`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000
I_ooool8o`0000[ooooo2Ol00002ooooo`;o00001?ooool4o`0000Wooooo0_l00007ooooo`;o0000
4?ooool2o`0000Cooooo0_l000000ooooooo0000o`000007ooooo`?o00000oooool2o`0000Oooooo
4?l0001Wooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?mE
EEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`1Wooooo`Wo00000_ooool2o`0000Cooooo
1?l000000ooooooo0000o`00000:ooooo`;o00002oooool2o`0000Kooooo0ol00006ooooo`;o0000
3oooool4o`0001Cooooo0_l00003ooooo`co0000J?ooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo06Sooooo3?l0
0006ooooo`?o00006Oooool2o`0000Cooooo1?l00007ooooo`;o00003oooool2o`0000Oooooo0_l0
000=ooooo`?o00000_ooool9o`0006_ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo
00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`1Yooooo`Wo00002Oooool2o`0000kooooo
0_l00009ooooo`;o00001?ooool2o`000003ooooool0003o000001Oooooo0ol00006ooooo`?o0000
1?ooool2o`0000Oooooo0_l00002ooooo`Co0000L?ooool00006ooooooo^k^ko<S8bo`000?lb<S;o
k^k^3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo06[ooooo2Ol00003oooo
o`;o00001oooool2o`0000Oooooo0_l000000ooooooo0000o`000005ooooo`;o00000_ooool2o`00
00Oooooo0_l0000Cooooo`;o00000_ooool3o`0000Oooooo0_l00004ooooo`?o00002_ooool3o`00
077ooooo000Looooo`03o`000?oooooooooo06[ooooo2ol000000ooooooo0000o`000005ooooo`Co
00001oooool2o`0000Sooooo0_l000001?oooooo0000o`000?l00003ooooo`;o00001?ooool2o`00
0003ooooool0003o000000?ooooo0_l00004ooooo`Co000000?oooooo`000?l000000ol00008oooo
o`Co00000_ooool4o`0000Sooooo1Ol0001aooooo`007?ooool00ol0003oooooooooo`1Zooooo`_o
00000oooool2o`0000;ooooo0ol0000;ooooo`;o00002Oooool2o`0000Cooooo0_l00004ooooo`;o
000000?oooooo`000?l000000oooool2o`0000?ooooo1Ol00003ooooo`?o00002?ooool4o`000003
ooooool0003o000000?o00002?ooool5o`00077ooooo000Looooo`03o`000?oooooooooo06_ooooo
2_l00003ooooo`;o00000_ooool2o`0000cooooo0_l000000ooooooo0000o`00000Oooooo`;o0000
5?ooool4o`000003ooooool0003o000000Wooooo1?l0001aooooo`007?ooool00ol0003ooooooooo
o`1[ooooo`_o00001_ooool2o`0000Gooooo0_l00008ooooo`;o00005_ooool2o`0000oooooo0_l0
000<ooooo`;o00003_ooool3o`0007;ooooo000Looooo`03o`000?oooooooooo06_ooooo3Ol0000;
ooooo`;o00003oooool2o`0000Kooooo0_l00007ooooo`;o00003oooool2o`0000_ooooo0_l0000?
ooooo`Co0000LOooool001cooooo00?o0000ooooooooool0K?ooool<o`0000Wooooo0_l00009oooo
o`;o00001_ooool2o`0000Kooooo0_l00006ooooo`Co00002_ooool2o`0000Gooooo1?l00006oooo
o`;o00003_ooool5o`00077ooooo000Looooo`03o`000?oooooooooo06gooooo3?l00008ooooo`;o
00002Oooool4o`0000Sooooo0_l00009ooooo`Oo00002?ooool2o`0000Gooooo1?l00004ooooo`;o
00001?ooool2o`0000Oooooo0_l000000ooooooo0000o`000003o`00077ooooo000Looooo`03o`00
0?oooooooooo06kooooo2ol0000=ooooo`;o00001_ooool4o`0000Cooooo1?l00009ooooo`;o0000
0oooool2o`0000Oooooo0_l00008ooooo`;o00001?ooool2o`0000Cooooo0_l00007ooooo`Oo0000
L_ooool001cooooo00?o0000ooooooooool0K_ooool;o`0000;ooooo0_l000000ooooooo0000o`00
0006ooooo`;o00001_ooool4o`0000Cooooo0ol00003ooooo`;o00001?ooool3o`0000cooooo0_l0
0002ooooo`?o00000oooool2o`0000kooooo3?l0001booooo`007?ooool00ol0003oooooooooo`1^
ooooo`[o00000oooool2o`000004ooooool0003o0000o`0001Kooooo0_l00003ooooo`;o00001?oo
ool3o`000003ooooool0003o000000gooooo0ol0000?ooooo`;o00000_ooool<o`0007;ooooo000L
ooooo`03o`000?oooooooooo06kooooo2ol00006ooooo`;o00001?ooool2o`0000?ooooo0_l0000=
ooooo`;o00002oooool2o`0000Oooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2
o`0000;ooooo0_l00004oooooa;o0000L_ooool001cooooo0_l0001`ooooo`co00002_ooool2o`00
00?ooooo0_l0000=ooooo`;o000000?oooooo`000?l000001Oooool2o`0000[ooooo0_l00003oooo
o`;o000000?oooooo`000?l000002?l00004oooooa;o0000L_ooool001cooooo00?o0000oooooooo
ool0L?ooool;o`0001[ooooo0ol00004ooooo`Co000000?oooooo`000?l000000_l0000:ooooo`;o
00002?ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000001?ooool?o`0007?o
oooo000Looooo`03o`000?oooooooooo07?ooooo2?l0000Dooooo`;o00001?ooool4o`0000;ooooo
1Ol000001?oooooo0000o`000?l0000<ooooo`;o00001oooool2o`0000;ooooo0_l00002oooooaGo
0000Loooool001cooooo00?o0000ooooooooool0Loooool:o`0001;ooooo0_l00006ooooo`;o0000
00Coooooo`000?l0003o00004oooool2o`0000Kooooo0_l00006ooooo`;o000000?oooooo`000?l0
00004?l0001dooooo`007?ooool00ol0003oooooooooo`1dooooo`_o00003Oooool2o`0000Cooooo
0_l00006ooooo`;o00002Oooool2o`00017ooooo0_l00006ooooo`;o00000_oooolAo`0007Cooooo
000Looooo`03o`000?oooooooooo07Oooooo2?l000001?oooooo0000o`000?ooool2o`000003oooo
ool0003o000000Cooooo0_l00002ooooo`Co00003_ooool2o`000003ooooool0003o000000;ooooo
0_l00002ooooo`Co00001?ooool2o`0000cooooo4Ol0001eooooo`007?ooool00ol0003ooooooooo
o`1gooooo`_o000000?oooooo`000?l000000ol00002ooooo`;o00001?ooool6o`0000cooooo0_l0
00000ooooooo0000o`000002ooooo`;o00000_ooool4o`0000?ooooo0ol00006ooooo`;o00000_oo
oolAo`0007Oooooo000Looooo`03o`000?oooooooooo07[ooooo2?l00002ooooo`;o00001?ooool2
o`0000Oooooo1Ol00007ooooo`;o00001?ooool2o`0000?ooooo0_l000000ooooooo0000o`000005
ooooo`?o00001_ooool2o`0000;ooooo4Ol0001gooooo`007?ooool00ol0003oooooooooo`1koooo
o`[o00004Oooool2o`0000Oooooo0ol000000ooooooo0000o`000005ooooo`;o000000?oooooo`00
0?l000004Oooool?o`0007[ooooo000Looooo`03o`000?oooooooooo07cooooo3?l0000<ooooo`Go
00001oooool2o`000003ooooool0003o000000_ooooo0ol00007ooooo`;o00000_ooool<o`0007oo
oooo000Looooo`03o`000?oooooooooo07cooooo3Ol00002ooooo`?o00001_ooool5o`0000;ooooo
0_l00003ooooo`;o000000?oooooo`000?l000002oooool3o`0000;ooooo0_l00003ooooo`;o0000
0_ooool8o`0008?ooooo000Looooo`03o`000?oooooooooo07cooooo3Ol00002ooooo`Co00003?oo
ool2o`0000[ooooo0_l0000;ooooo`?o00001oooool6o`0008Gooooo000Looooo`03o`000?oooooo
oooo07cooooo3Ol00002ooooo`Co00003Oooool2o`0000;ooooo0_l00005ooooo`;o00001Oooool2
o`0000Cooooo0_l000000ooooooo0000o`000002o`0000;ooooo2?l00024ooooo`007?ooool00ol0
003oooooooooo`1moooooa3o00000oooool2o`0000[ooooo0_l00002ooooo`;o00001Oooool2o`00
00Cooooo0ol00007ooooo`ko0000Q?ooool001cooooo00?o0000ooooooooool0O_ooool>o`0000Co
oooo1?l0000?ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o00000oooool2o`00
00Oooooo2?l00026ooooo`007?ooool00ol0003oooooooooo`1nooooo`oo00001Oooool2o`0000Wo
oooo0_l00004ooooo`;o00000_ooool2o`000003ooooool0003o000000?o00000_oooolBo`0008Ko
oooo000Looooo`;o0000Ooooool?o`00013ooooo0_l00005ooooo`;o00001?ooool5o`000003oooo
ool0003o000000oo0000R?ooool001cooooo00?o0000ooooooooool0O_ooool@o`0000;ooooo0_l0
000;ooooo`;o00001Oooool2o`0000Kooooo5Ol00028ooooo`007?ooool00ol0003oooooooooo`20
oooooa;o00002?ooool2o`000003ooooool0003o000000;ooooo0_l00007oooooaKo0000ROooool0
01cooooo00?o0000ooooooooool0Poooool7o`000003ooooool0003o000000Co000000?oooooo`00
0?l000001_ooool2o`0000?ooooo1Ol00004oooooaGo0000S?ooool001cooooo00?o0000oooooooo
ool0PooooolBo`000003ooooool0003o000000Oooooo1Ol000001?oooooo0000o`000?oooolEo`00
08cooooo000Looooo`03o`000?oooooooooo08?ooooo5_l00005ooooo`Co000000?oooooo`000?l0
00005_l0002>ooooo`007?ooool00ol0003oooooooooo`25ooooo`Go000000?oooooo`000?l00000
3?l00002ooooo`;o000000?oooooo`000?l000000_oooolIo`0008kooooo000Looooo`03o`000?oo
oooooooo08Gooooo5Ol000001?oooooo0000o`000?oooolLo`0008oooooo000Looooo`03o`000?oo
oooooooo08Sooooo5Ol000000ooooooo0000o`00000Ho`00097ooooo000Looooo`03o`000?oooooo
oooo08Wooooo;Ol0002Cooooo`007?ooool00ol0003oooooooooo`2;ooooob[o0000U?ooool001co
oooo00?o0000ooooooooool0S_oooolQo`000003ooooool0003o000009Oooooo000Looooo`03o`00
0?oooooooooo08kooooo5_l000000ooooooo0000o`000006o`0009cooooo000Looooo`03o`000?oo
oooooooo093ooooo5ol0002Rooooo`007?ooool00ol0003oooooooooo`2Coooooa?o0000Xoooool0
01cooooo00?o0000ooooooooool0U?ooool@o`000:Gooooo000Looooo`;o0000V_ooool4o`000003
ooooool0003o00000:Wooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Go
c<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?ooooooB_ooool00006oooooomg
MgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06oooo
o`03o`000?oooooooooo0?ooooooB_ooool00003ooooool@413ooooo00;ooooo00?o410@oooooooo
ool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooom:oooo
o`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRH
V?lb<S801_ooool3o`000?ooooooB_ooool00003ooooool0003ooooo00;ooooo00?o0000oooooooo
ool02Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom:oooo
o`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj
^_l@41001_ooool00ol0003oooooooooo`3ooooood[ooooo00001_ooooooMgMgoiRHV?ooooooV9RH
ogMgM`_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0?ooooooB_oo
ool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Ko
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo
00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000D
ooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBoooo
o`004_ooool00omEEEGoIVIVo`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo002Yooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05Oooool0
1OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP2Dooooo`00Z_oo
ool01Ol0003ooooooooooooooooo000000Wooooo1_l00009ooooo`05oa0@4?nj^[[oooooogMgMolb
<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg09Cooooo002Zooooo`05o`000?oooooooooooooo
ool000007?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0T_ooool0
0:[ooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00003?ooool00onYZJWo410@ooooo`02
ooooo`05o`000?ooooooooooooooool00000U?ooool00:[ooooo00Go0000ohN7QoooooooZJVYo`00
000Jooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00002Dooooo`00ZOoo
ool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo01Wooooo00?o^[Zjob4Q8Oooool00_oo
ool01Ol@413ooooooooooooooooo410@09Cooooo0037ooooo`05oa0@4?nHV9SooooookZj^_l00000
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg09Cooooo0037ooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^09Cooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -20 0 ]
[.5 1.0125 20 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(36) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.70709 .47137 Mdot
.73658 .48997 Mdot
.49124 .2826 Mdot
.35947 .60636 Mdot
.26549 .5242 Mdot
.50546 .28958 Mdot
.67483 .38959 Mdot
.69137 .40435 Mdot
.49472 .26044 Mdot
.32527 .57033 Mdot
.62812 .33264 Mdot
.50754 .73427 Mdot
.68048 .38855 Mdot
.35002 .63418 Mdot
.47295 .72934 Mdot
.62981 .69003 Mdot
.70617 .50124 Mdot
.2664 .52605 Mdot
.61667 .66657 Mdot
.51551 .26158 Mdot
.3797 .34733 Mdot
.35048 .61817 Mdot
.70928 .51542 Mdot
.34316 .62827 Mdot
.61199 .66877 Mdot
.68172 .58475 Mdot
.70641 .46994 Mdot
.61116 .67413 Mdot
.53631 .73103 Mdot
.70191 .3946 Mdot
.62372 .68475 Mdot
.38059 .66037 Mdot
.33658 .40861 Mdot
.69188 .61706 Mdot
.61824 .31087 Mdot
.63503 .34412 Mdot
.47339 .28351 Mdot
.62565 .34216 Mdot
.69374 .41573 Mdot
.61097 .30927 Mdot
.61547 .31101 Mdot
.67663 .58859 Mdot
.63795 .34328 Mdot
.70065 .43934 Mdot
.39617 .67093 Mdot
.65926 .62376 Mdot
.38977 .33069 Mdot
.43495 .7144 Mdot
.71072 .47391 Mdot
.39187 .32573 Mdot
.41348 .71422 Mdot
.66713 .39598 Mdot
.32325 .39932 Mdot
.71047 .55291 Mdot
.6881 .38398 Mdot
.60732 .67015 Mdot
.52367 .27435 Mdot
.42859 .7293 Mdot
.54559 .72322 Mdot
.68481 .62 Mdot
.33358 .60953 Mdot
.29422 .51914 Mdot
.57035 .6987 Mdot
.55044 .28477 Mdot
.48399 .27113 Mdot
.58762 .31461 Mdot
.71196 .53125 Mdot
.61054 .33157 Mdot
.3689 .64791 Mdot
.41986 .31732 Mdot
.44247 .73244 Mdot
.62825 .33222 Mdot
.68059 .60253 Mdot
.36003 .61564 Mdot
.72297 .46632 Mdot
.61334 .32777 Mdot
.26303 .51893 Mdot
.67828 .59266 Mdot
.39582 .31261 Mdot
.32188 .57245 Mdot
.34431 .61326 Mdot
.64781 .33154 Mdot
.54808 .71308 Mdot
.65646 .60791 Mdot
.39351 .67909 Mdot
.66024 .35237 Mdot
.34505 .58323 Mdot
.62738 .68422 Mdot
.60659 .67777 Mdot
.51114 .73691 Mdot
.44679 .28787 Mdot
.72124 .51486 Mdot
.35853 .62279 Mdot
.36661 .65686 Mdot
.41673 .71116 Mdot
.39322 .68208 Mdot
.60471 .67963 Mdot
.36203 .37804 Mdot
.61218 .31626 Mdot
.32056 .40997 Mdot
.6125 .331 Mdot
.31485 .39971 Mdot
.37343 .65554 Mdot
.53463 .29222 Mdot
.70892 .57118 Mdot
.35799 .38316 Mdot
.6104 .32225 Mdot
.36046 .6258 Mdot
.63237 .34448 Mdot
.72352 .50965 Mdot
.61797 .68667 Mdot
.28676 .47863 Mdot
.26718 .48675 Mdot
.69645 .48283 Mdot
.37254 .67744 Mdot
.3363 .57703 Mdot
.34548 .62164 Mdot
.71333 .52876 Mdot
.49757 .26197 Mdot
.43669 .29192 Mdot
.73023 .49158 Mdot
.6132 .31379 Mdot
.70501 .49303 Mdot
.29732 .42035 Mdot
.48669 .2657 Mdot
.33858 .40022 Mdot
.35905 .36893 Mdot
.37626 .65436 Mdot
.39336 .68458 Mdot
.31296 .37949 Mdot
.53724 .29499 Mdot
.73105 .48959 Mdot
.68483 .39305 Mdot
.36354 .65666 Mdot
.65949 .61496 Mdot
.68816 .38171 Mdot
.27545 .50077 Mdot
.28345 .4714 Mdot
.67532 .60768 Mdot
.37769 .68169 Mdot
.62202 .34258 Mdot
.67857 .41888 Mdot
.421 .72402 Mdot
.66171 .61778 Mdot
.26979 .51869 Mdot
.67911 .41999 Mdot
.30543 .43401 Mdot
.61076 .68804 Mdot
.4639 .74389 Mdot
.65094 .34317 Mdot
.41872 .71763 Mdot
.38531 .34318 Mdot
.30396 .49629 Mdot
.69202 .38485 Mdot
.35311 .59514 Mdot
.71264 .48665 Mdot
.66989 .61464 Mdot
.50996 .71941 Mdot
.35198 .39204 Mdot
.41516 .72517 Mdot
.31071 .3969 Mdot
.36201 .37103 Mdot
.35483 .63614 Mdot
.67187 .62516 Mdot
.71068 .58747 Mdot
.43928 .732 Mdot
.47121 .27589 Mdot
.2638 .5254 Mdot
.63319 .33417 Mdot
.40218 .69125 Mdot
.41766 .70844 Mdot
.50159 .72496 Mdot
.67482 .4161 Mdot
.61237 .30431 Mdot
.4123 .30674 Mdot
.5919 .31814 Mdot
.63586 .32541 Mdot
.55135 .29281 Mdot
.5179 .73114 Mdot
.29439 .46938 Mdot
.33467 .3808 Mdot
.43754 .73102 Mdot
.38426 .65835 Mdot
.50426 .73557 Mdot
.36769 .35191 Mdot
.36377 .34944 Mdot
.70304 .54783 Mdot
.64115 .34136 Mdot
.34235 .59401 Mdot
.59646 .66839 Mdot
.39937 .6987 Mdot
.64893 .35215 Mdot
.6858 .39931 Mdot
.56745 .29636 Mdot
.52581 .26444 Mdot
.40447 .31712 Mdot
.53745 .70503 Mdot
.4929 .71868 Mdot
.34476 .6023 Mdot
.33172 .39944 Mdot
.57637 .69904 Mdot
.30241 .50194 Mdot
.70883 .49591 Mdot
.64539 .32744 Mdot
.45143 .74466 Mdot
.63218 .66921 Mdot
.46401 .26894 Mdot
.43007 .2884 Mdot
.33866 .37328 Mdot
.29993 .48587 Mdot
.43221 .72663 Mdot
.69655 .49445 Mdot
.41734 .71824 Mdot
.33311 .40999 Mdot
.26976 .47987 Mdot
.72441 .49958 Mdot
.43842 .71722 Mdot
.68106 .38338 Mdot
.52273 .30635 Mdot
.34526 .583 Mdot
.36234 .62549 Mdot
.67563 .59563 Mdot
.37017 .65979 Mdot
.60224 .66784 Mdot
.61917 .68146 Mdot
.41111 .3136 Mdot
.60042 .3204 Mdot
.70291 .4019 Mdot
.38806 .33155 Mdot
.66899 .60592 Mdot
.71621 .44722 Mdot
.52161 .28468 Mdot
.37968 .34953 Mdot
.6294 .33759 Mdot
.28573 .50412 Mdot
.52633 .2894 Mdot
.27101 .52586 Mdot
.54948 .72231 Mdot
.53993 .30114 Mdot
.28077 .48983 Mdot
.47727 .72922 Mdot
.35374 .37052 Mdot
.29081 .46007 Mdot
.67399 .38693 Mdot
.74129 .48582 Mdot
.4357 .73336 Mdot
.32453 .39333 Mdot
.32515 .41324 Mdot
.52004 .72942 Mdot
.36229 .36302 Mdot
.35335 .38202 Mdot
.51423 .7288 Mdot
.26955 .53184 Mdot
.63268 .31613 Mdot
.62277 .68506 Mdot
.70606 .49735 Mdot
.37065 .64953 Mdot
.59458 .30811 Mdot
.68943 .38192 Mdot
.33142 .58019 Mdot
.65589 .35167 Mdot
.67332 .38453 Mdot
.3496 .63051 Mdot
.69841 .4046 Mdot
.65743 .61047 Mdot
.45031 .74486 Mdot
.68379 .60389 Mdot
.34878 .63253 Mdot
.69697 .40954 Mdot
.38932 .3296 Mdot
.6713 .59472 Mdot
.35524 .61755 Mdot
.3537 .60188 Mdot
.33015 .39843 Mdot
.61763 .68473 Mdot
.68227 .36333 Mdot
.50899 .73407 Mdot
.56316 .30382 Mdot
.52401 .71085 Mdot
.30892 .48604 Mdot
.30106 .43615 Mdot
.66327 .61789 Mdot
.36568 .36263 Mdot
.51421 .28761 Mdot
.42436 .71689 Mdot
.44672 .7274 Mdot
.39512 .67452 Mdot
.35122 .3812 Mdot
.54804 .71219 Mdot
.68075 .36968 Mdot
.59582 .68175 Mdot
.31523 .37916 Mdot
.51456 .27403 Mdot
.31507 .40533 Mdot
.39271 .67973 Mdot
.71207 .5169 Mdot
.63551 .67837 Mdot
.55679 .30373 Mdot
.71214 .51143 Mdot
.43592 .71819 Mdot
.60825 .32979 Mdot
.30018 .5186 Mdot
.68964 .36779 Mdot
.62405 .67163 Mdot
.51983 .71296 Mdot
.42031 .31595 Mdot
.66495 .60227 Mdot
.69383 .39183 Mdot
.68199 .60289 Mdot
.41281 .72117 Mdot
.40226 .71309 Mdot
.6664 .61888 Mdot
.30601 .45648 Mdot
.41178 .30185 Mdot
.62597 .3339 Mdot
.33854 .39661 Mdot
.43302 .30634 Mdot
.70704 .47725 Mdot
.52843 .29312 Mdot
.38272 .6934 Mdot
.5271 .30742 Mdot
.63588 .67711 Mdot
.42801 .31178 Mdot
.50054 .72189 Mdot
.39096 .66615 Mdot
.55879 .29074 Mdot
.35693 .38698 Mdot
.42808 .7269 Mdot
.65886 .61147 Mdot
.37932 .65243 Mdot
.32674 .57057 Mdot
.5263 .70713 Mdot
.517 .27454 Mdot
.38015 .68586 Mdot
.62054 .67686 Mdot
.61915 .67045 Mdot
.71257 .49484 Mdot
.33821 .3885 Mdot
.27196 .49879 Mdot
.28719 .46462 Mdot
.30469 .43837 Mdot
.50013 .73632 Mdot
.39168 .70058 Mdot
.66677 .61041 Mdot
.3953 .32368 Mdot
.74262 .48216 Mdot
.3349 .40895 Mdot
.6909 .40571 Mdot
.61878 .30747 Mdot
.34726 .5848 Mdot
.27935 .54481 Mdot
.639 .67422 Mdot
.71674 .47173 Mdot
.67945 .60028 Mdot
.69394 .39439 Mdot
.56678 .7106 Mdot
.32339 .57371 Mdot
.33217 .58125 Mdot
.68657 .41412 Mdot
.3343 .4073 Mdot
.54124 .7218 Mdot
.45573 .72768 Mdot
.69346 .43503 Mdot
.40173 .68126 Mdot
.69712 .60505 Mdot
.39922 .66795 Mdot
.37701 .65907 Mdot
.40968 .68241 Mdot
.66173 .61008 Mdot
.64238 .66644 Mdot
.45301 .72806 Mdot
.452 .27703 Mdot
.45287 .74553 Mdot
.29943 .45972 Mdot
.35888 .61782 Mdot
.43424 .72738 Mdot
.27173 .51524 Mdot
.69695 .48371 Mdot
.41589 .70482 Mdot
.64789 .34378 Mdot
.35487 .62025 Mdot
.63402 .33549 Mdot
.52799 .7187 Mdot
.3799 .66631 Mdot
.61716 .67697 Mdot
.70951 .51675 Mdot
.69053 .41816 Mdot
.62898 .32404 Mdot
.32063 .37925 Mdot
.68997 .38212 Mdot
.39737 .68372 Mdot
.53154 .71703 Mdot
.6961 .48419 Mdot
.35451 .37132 Mdot
.72279 .51469 Mdot
.28522 .55151 Mdot
.67398 .39634 Mdot
.31775 .39993 Mdot
.56646 .70626 Mdot
.67597 .40682 Mdot
.64489 .33647 Mdot
.61819 .68712 Mdot
.33346 .40774 Mdot
.70407 .47563 Mdot
.42433 .3139 Mdot
.34724 .39397 Mdot
.69026 .38519 Mdot
.39689 .67071 Mdot
.60488 .68352 Mdot
.69649 .39515 Mdot
.6992 .59272 Mdot
.61165 .69032 Mdot
.35613 .62313 Mdot
.68043 .58346 Mdot
.72455 .51706 Mdot
.42593 .73463 Mdot
.33545 .59048 Mdot
.50231 .2806 Mdot
.34931 .38461 Mdot
.34772 .38428 Mdot
.36549 .36988 Mdot
.55046 .30775 Mdot
.41939 .2991 Mdot
.60035 .31629 Mdot
.37639 .65207 Mdot
.59257 .31412 Mdot
.32154 .39469 Mdot
.50094 .28139 Mdot
.39571 .66765 Mdot
.56757 .71426 Mdot
.68312 .42448 Mdot
.44521 .29381 Mdot
.36375 .60947 Mdot
.71005 .48555 Mdot
.66957 .40439 Mdot
.48685 .72244 Mdot
.4092 .31815 Mdot
.29601 .51906 Mdot
.38051 .68182 Mdot
.6773 .4124 Mdot
.70396 .58371 Mdot
.67825 .41282 Mdot
.43515 .72447 Mdot
.41106 .69728 Mdot
.73329 .47769 Mdot
.30096 .45933 Mdot
.51087 .73331 Mdot
.34041 .62418 Mdot
.39179 .32266 Mdot
.74101 .47848 Mdot
.30109 .45396 Mdot
.54549 .72805 Mdot
.35329 .3671 Mdot
.26712 .53324 Mdot
.34688 .60469 Mdot
.50725 .72716 Mdot
.30158 .4023 Mdot
.69849 .38721 Mdot
.29585 .46026 Mdot
.46043 .27213 Mdot
.71744 .5067 Mdot
.59907 .31711 Mdot
.3726 .35995 Mdot
.62592 .33123 Mdot
.49013 .73425 Mdot
.31884 .38989 Mdot
.68323 .42981 Mdot
.31129 .56138 Mdot
.35496 .37653 Mdot
.51807 .27182 Mdot
.41859 .72518 Mdot
.50975 .73058 Mdot
.35673 .62409 Mdot
.27297 .4968 Mdot
.73631 .49754 Mdot
.63977 .33255 Mdot
.69585 .41912 Mdot
.36121 .64046 Mdot
.66338 .61818 Mdot
.69963 .54582 Mdot
.3209 .4066 Mdot
.28979 .48436 Mdot
.28554 .50045 Mdot
.36445 .64193 Mdot
.55802 .71364 Mdot
.66417 .60881 Mdot
.35571 .61778 Mdot
.36463 .64332 Mdot
.42323 .30404 Mdot
.68265 .57991 Mdot
.54439 .30005 Mdot
.62621 .66557 Mdot
.38071 .67717 Mdot
.60266 .32511 Mdot
.683 .37729 Mdot
.34224 .38745 Mdot
.70296 .4022 Mdot
.41846 .30326 Mdot
.34803 .38382 Mdot
.35492 .61672 Mdot
.7033 .46812 Mdot
.35681 .61903 Mdot
.35573 .62038 Mdot
.40498 .67706 Mdot
.39143 .69971 Mdot
.43891 .2847 Mdot
.29361 .47642 Mdot
.5485 .72447 Mdot
.55657 .29743 Mdot
.4682 .26661 Mdot
.41512 .71122 Mdot
.35132 .60898 Mdot
.34833 .6258 Mdot
.68973 .58197 Mdot
.60038 .6846 Mdot
.68057 .40664 Mdot
.73376 .47771 Mdot
.34259 .58418 Mdot
.39174 .33109 Mdot
.41646 .70376 Mdot
.67216 .61729 Mdot
.60309 .30487 Mdot
.67086 .35838 Mdot
.36025 .36218 Mdot
.31832 .41447 Mdot
.35218 .3821 Mdot
.36747 .37077 Mdot
.63661 .34352 Mdot
.4995 .28157 Mdot
.31022 .48761 Mdot
.40053 .71194 Mdot
.33788 .59317 Mdot
.40922 .69835 Mdot
.43327 .30099 Mdot
.30645 .42374 Mdot
.40164 .70909 Mdot
.60129 .69669 Mdot
.51302 .30293 Mdot
.36212 .37615 Mdot
.64771 .62973 Mdot
.71917 .51031 Mdot
.41529 .31508 Mdot
.62536 .34182 Mdot
.27928 .4889 Mdot
.38568 .33773 Mdot
.72879 .50844 Mdot
.57329 .6929 Mdot
.50542 .29938 Mdot
.53415 .71771 Mdot
.57546 .70383 Mdot
.52177 .29504 Mdot
.59411 .68086 Mdot
.71059 .53166 Mdot
.35648 .37009 Mdot
.52948 .71352 Mdot
.52044 .72771 Mdot
.5654 .29211 Mdot
.36085 .61224 Mdot
.44365 .28896 Mdot
.51506 .27289 Mdot
.33935 .38351 Mdot
.5168 .27473 Mdot
.68302 .36972 Mdot
.54005 .28848 Mdot
.69832 .58626 Mdot
.36591 .6487 Mdot
.709 .55539 Mdot
.47676 .73457 Mdot
.33508 .57817 Mdot
.66871 .38848 Mdot
.59603 .31006 Mdot
.33446 .60334 Mdot
.26508 .51927 Mdot
.50897 .27233 Mdot
.40446 .31316 Mdot
.60005 .67932 Mdot
.43116 .30592 Mdot
.7095 .51759 Mdot
.60536 .32425 Mdot
.59578 .31018 Mdot
.34963 .38803 Mdot
.65907 .61695 Mdot
.64 .34855 Mdot
.61199 .31309 Mdot
.30091 .5175 Mdot
.43015 .73571 Mdot
.70536 .59593 Mdot
.54058 .72189 Mdot
.26896 .52746 Mdot
.35343 .6201 Mdot
.54744 .29857 Mdot
.40788 .31281 Mdot
.4682 .72637 Mdot
.51825 .28366 Mdot
.3414 .39095 Mdot
.70574 .57532 Mdot
.60863 .66856 Mdot
.73421 .49579 Mdot
.36776 .65958 Mdot
.59801 .31752 Mdot
.7152 .51343 Mdot
.37487 .35028 Mdot
.32975 .59859 Mdot
.66913 .62382 Mdot
.54489 .73048 Mdot
.35512 .62274 Mdot
.49082 .2665 Mdot
.27101 .51637 Mdot
.38033 .3524 Mdot
.45133 .28319 Mdot
.29659 .50755 Mdot
.73691 .46496 Mdot
.4909 .26503 Mdot
.29219 .50209 Mdot
.29989 .44019 Mdot
.36873 .36436 Mdot
.29656 .4793 Mdot
.39451 .68099 Mdot
.69341 .38429 Mdot
.73872 .48694 Mdot
.41529 .69414 Mdot
.32086 .56809 Mdot
.71098 .5584 Mdot
.32758 .40161 Mdot
.35477 .62598 Mdot
.42571 .73169 Mdot
.67251 .61574 Mdot
.64081 .32189 Mdot
.53847 .27713 Mdot
.33084 .40519 Mdot
.73227 .49961 Mdot
.64802 .33156 Mdot
.48823 .26911 Mdot
.28468 .51034 Mdot
.69346 .3769 Mdot
.70518 .46476 Mdot
.32598 .39855 Mdot
.67439 .38814 Mdot
.45149 .28485 Mdot
.41452 .71431 Mdot
.60684 .69521 Mdot
.49583 .29485 Mdot
.41493 .71523 Mdot
.6369 .67318 Mdot
.40477 .3178 Mdot
.6217 .30827 Mdot
.72412 .50985 Mdot
.692 .41178 Mdot
.2863 .49217 Mdot
.68251 .60058 Mdot
.72359 .51374 Mdot
.68319 .37686 Mdot
.71296 .56364 Mdot
.54608 .71048 Mdot
.61327 .32675 Mdot
.55047 .71688 Mdot
.42319 .72283 Mdot
.32731 .396 Mdot
.29381 .47188 Mdot
.60189 .32184 Mdot
.68084 .58515 Mdot
.70292 .43855 Mdot
.39111 .68357 Mdot
.60167 .68702 Mdot
.28278 .4778 Mdot
.7057 .54641 Mdot
.61396 .30332 Mdot
.67911 .40527 Mdot
.39236 .32282 Mdot
.26473 .51456 Mdot
.3912 .67133 Mdot
.44449 .29982 Mdot
.40458 .69154 Mdot
.66691 .40262 Mdot
.6378 .67168 Mdot
.71883 .50086 Mdot
.61865 .33064 Mdot
.63746 .67881 Mdot
.52073 .73484 Mdot
.3354 .59643 Mdot
.4126 .31239 Mdot
.70003 .53928 Mdot
.30016 .43021 Mdot
.34054 .57795 Mdot
.32916 .6002 Mdot
.31973 .41637 Mdot
.37689 .65532 Mdot
.63057 .31565 Mdot
.34785 .39723 Mdot
.51678 .30265 Mdot
.35737 .37254 Mdot
.33805 .39432 Mdot
.69876 .4957 Mdot
.40073 .32132 Mdot
.31832 .41573 Mdot
.32907 .57807 Mdot
.36017 .63331 Mdot
.69014 .41994 Mdot
.5411 .71203 Mdot
.52857 .72629 Mdot
.56315 .30165 Mdot
.30098 .51919 Mdot
.42719 .7148 Mdot
.65668 .60965 Mdot
.27958 .476 Mdot
.30796 .40073 Mdot
.7114 .50787 Mdot
.39124 .67854 Mdot
.42423 .30347 Mdot
.35262 .37342 Mdot
.30508 .41309 Mdot
.2815 .48366 Mdot
.67364 .41585 Mdot
.68391 .61284 Mdot
.51538 .2724 Mdot
.61964 .6924 Mdot
.28187 .54817 Mdot
.41992 .31084 Mdot
.32851 .39491 Mdot
.32456 .38151 Mdot
.66406 .61706 Mdot
.69768 .58988 Mdot
.37434 .35709 Mdot
.55828 .29881 Mdot
.64528 .34863 Mdot
.62081 .32704 Mdot
.51247 .71817 Mdot
.69501 .37525 Mdot
.72306 .51079 Mdot
.38582 .68178 Mdot
.28689 .50185 Mdot
.67498 .4044 Mdot
.35166 .3859 Mdot
.72819 .50497 Mdot
.69234 .5935 Mdot
.33936 .62375 Mdot
.34955 .6157 Mdot
.38899 .3308 Mdot
.38294 .66137 Mdot
.67713 .4219 Mdot
.27278 .50389 Mdot
.49529 .27683 Mdot
.60176 .6808 Mdot
.71156 .48761 Mdot
.38934 .33836 Mdot
.52569 .73634 Mdot
.54588 .28498 Mdot
.73574 .48722 Mdot
.27259 .48788 Mdot
.294 .47742 Mdot
.3826 .67755 Mdot
.3871 .34199 Mdot
.67101 .39059 Mdot
.66086 .61438 Mdot
.73927 .46889 Mdot
.53623 .72987 Mdot
.35162 .61105 Mdot
.59726 .67485 Mdot
.63873 .33559 Mdot
.39716 .6853 Mdot
.27724 .48804 Mdot
.70515 .53548 Mdot
.3926 .66687 Mdot
.26722 .49223 Mdot
.29971 .43008 Mdot
.33024 .37818 Mdot
.54773 .27994 Mdot
.26842 .49665 Mdot
.26621 .50376 Mdot
.27175 .47986 Mdot
.62036 .30855 Mdot
.48759 .72462 Mdot
.28574 .54913 Mdot
.35948 .6098 Mdot
.41905 .72422 Mdot
.60425 .6936 Mdot
.59238 .31735 Mdot
.41745 .3174 Mdot
.4332 .72517 Mdot
.35416 .60271 Mdot
.70689 .53719 Mdot
.6263 .69226 Mdot
.43593 .72071 Mdot
.71167 .50219 Mdot
.7011 .60865 Mdot
.53248 .26863 Mdot
.6543 .35428 Mdot
.43329 .31067 Mdot
.55227 .7251 Mdot
.55629 .72388 Mdot
.70024 .52527 Mdot
.69304 .3801 Mdot
.55581 .72187 Mdot
.6724 .41444 Mdot
.70646 .53054 Mdot
.60089 .6949 Mdot
.69939 .59045 Mdot
.29268 .52153 Mdot
.43452 .72141 Mdot
.67986 .37666 Mdot
.43392 .72593 Mdot
.6854 .3748 Mdot
.3216 .56818 Mdot
.55993 .71782 Mdot
.35048 .59364 Mdot
.3876 .65991 Mdot
.36908 .3503 Mdot
.34934 .61194 Mdot
.39529 .31398 Mdot
.71619 .48521 Mdot
.27456 .54152 Mdot
.58643 .67688 Mdot
.42527 .72587 Mdot
.35036 .6255 Mdot
.71148 .55939 Mdot
.34326 .61953 Mdot
.43785 .30461 Mdot
.54673 .73049 Mdot
.43795 .72707 Mdot
.68765 .39831 Mdot
.6245 .32448 Mdot
.69633 .48235 Mdot
.31923 .38802 Mdot
.70697 .54485 Mdot
.35258 .63207 Mdot
.52125 .26871 Mdot
.30564 .44163 Mdot
.26752 .50718 Mdot
.73671 .48509 Mdot
.31401 .56328 Mdot
.63757 .34269 Mdot
.47079 .27034 Mdot
.62174 .68703 Mdot
.53519 .30225 Mdot
.55634 .29068 Mdot
.74197 .47941 Mdot
.29346 .47289 Mdot
.42277 .7071 Mdot
.68796 .61847 Mdot
.68763 .62999 Mdot
.53272 .73091 Mdot
.51255 .26412 Mdot
.30081 .40433 Mdot
.64354 .6558 Mdot
.28442 .52339 Mdot
.29583 .50252 Mdot
.68158 .38123 Mdot
.5263 .26968 Mdot
.33381 .40213 Mdot
.29045 .50276 Mdot
.53289 .26815 Mdot
.37124 .3626 Mdot
.39728 .3167 Mdot
.66484 .6113 Mdot
.38981 .70117 Mdot
.66639 .62641 Mdot
.7006 .4111 Mdot
.39655 .3245 Mdot
.66962 .60231 Mdot
.65444 .61417 Mdot
.33447 .3966 Mdot
.46285 .28172 Mdot
.70695 .56544 Mdot
.43182 .73403 Mdot
.34528 .37126 Mdot
.34064 .62703 Mdot
.26203 .51587 Mdot
.35816 .6318 Mdot
.39647 .32818 Mdot
.68072 .40997 Mdot
.5066 .2784 Mdot
.67948 .38141 Mdot
.37819 .65841 Mdot
.32839 .58936 Mdot
.3561 .61409 Mdot
.52732 .71952 Mdot
.69862 .50856 Mdot
.6947 .61141 Mdot
.53386 .27784 Mdot
.50898 .27633 Mdot
.58458 .68178 Mdot
.70763 .48459 Mdot
.30247 .43408 Mdot
.55413 .71895 Mdot
.34183 .61665 Mdot
.71558 .48675 Mdot
.59888 .6916 Mdot
.64184 .35071 Mdot
.52583 .71657 Mdot
.7021 .51283 Mdot
.42218 .29837 Mdot
.3646 .64471 Mdot
.31832 .41175 Mdot
.31023 .38194 Mdot
.48937 .73207 Mdot
.26691 .52667 Mdot
.72217 .50285 Mdot
.31181 .40713 Mdot
.71783 .48133 Mdot
.53596 .3079 Mdot
.63763 .34948 Mdot
.71534 .49816 Mdot
.34508 .62313 Mdot
.44788 .29919 Mdot
.69153 .38099 Mdot
.40627 .67621 Mdot
.61598 .32645 Mdot
.67646 .60074 Mdot
.72681 .48655 Mdot
.37131 .36247 Mdot
.59468 .68187 Mdot
.67158 .39714 Mdot
.3415 .59102 Mdot
.70065 .58876 Mdot
.63588 .68025 Mdot
.27005 .52824 Mdot
.41495 .69923 Mdot
.41591 .72889 Mdot
.43716 .29235 Mdot
.40357 .70221 Mdot
.63246 .3208 Mdot
.63426 .34068 Mdot
.64197 .33663 Mdot
.69857 .48593 Mdot
.37073 .35454 Mdot
.69233 .60277 Mdot
.34337 .38917 Mdot
.46675 .28059 Mdot
.40881 .67988 Mdot
.36695 .37216 Mdot
.60141 .31909 Mdot
.29993 .47559 Mdot
.50624 .73596 Mdot
.48609 .28929 Mdot
.34043 .37079 Mdot
.67583 .40068 Mdot
.70241 .57655 Mdot
.71501 .50553 Mdot
.40501 .30843 Mdot
.39706 .6674 Mdot
.3512 .61589 Mdot
.60096 .31154 Mdot
.38826 .34068 Mdot
.29565 .50718 Mdot
.35693 .38679 Mdot
.60287 .31631 Mdot
.53249 .71449 Mdot
.67777 .59593 Mdot
.43613 .72706 Mdot
.53815 .71469 Mdot
.62209 .31036 Mdot
.69025 .62642 Mdot
.29881 .50576 Mdot
.37542 .66256 Mdot
.72381 .50073 Mdot
.68535 .39142 Mdot
.29775 .4399 Mdot
.61374 .66438 Mdot
.34359 .5972 Mdot
.44866 .73776 Mdot
.51067 .72533 Mdot
.62633 .68343 Mdot
.3642 .36124 Mdot
.44479 .73541 Mdot
.58577 .67942 Mdot
.62534 .69048 Mdot
.41244 .70081 Mdot
.41199 .70301 Mdot
.71872 .48691 Mdot
.52107 .70865 Mdot
.54251 .29615 Mdot
.59354 .67747 Mdot
.38846 .33886 Mdot
.62269 .68246 Mdot
.51914 .71261 Mdot
.68264 .63 Mdot
.48787 .73239 Mdot
.69867 .53606 Mdot
.7049 .48042 Mdot
.70137 .40868 Mdot
.63471 .67526 Mdot
.54662 .28527 Mdot
.3028 .40723 Mdot
.42057 .31378 Mdot
.71967 .48496 Mdot
.521 .26418 Mdot
.5885 .31591 Mdot
.49481 .29449 Mdot
.52477 .30379 Mdot
.6791 .41085 Mdot
.74095 .49031 Mdot
.53219 .73514 Mdot
.67531 .40891 Mdot
.30701 .41712 Mdot
.28629 .50775 Mdot
.69715 .62159 Mdot
.34986 .39734 Mdot
.36447 .61041 Mdot
.69251 .43204 Mdot
.47458 .28483 Mdot
.4511 .74076 Mdot
.71861 .47005 Mdot
.28137 .47027 Mdot
.71815 .49611 Mdot
.3778 .35845 Mdot
.30294 .5026 Mdot
.39042 .67201 Mdot
.38616 .3398 Mdot
.63291 .31914 Mdot
.42117 .70626 Mdot
.68887 .62312 Mdot
.41954 .3143 Mdot
.68054 .36916 Mdot
.64896 .34915 Mdot
.32242 .41015 Mdot
.70354 .5104 Mdot
.69653 .59848 Mdot
.34561 .38445 Mdot
.6847 .39388 Mdot
.70382 .55729 Mdot
.40347 .71303 Mdot
.69968 .37944 Mdot
.4219 .70439 Mdot
.37712 .68066 Mdot
.30896 .45198 Mdot
.36419 .36977 Mdot
.62026 .69502 Mdot
.48239 .27221 Mdot
.58506 .68542 Mdot
.37193 .66091 Mdot
.38189 .65493 Mdot
.34104 .60511 Mdot
.45003 .73658 Mdot
.42514 .30034 Mdot
.69505 .50595 Mdot
.33276 .37982 Mdot
.3289 .39733 Mdot
.63565 .68645 Mdot
.3855 .33609 Mdot
.29752 .48759 Mdot
.40116 .31042 Mdot
.33049 .60431 Mdot
.34446 .61478 Mdot
.68676 .59072 Mdot
.37693 .68451 Mdot
.35947 .37108 Mdot
.33921 .60321 Mdot
.51262 .73867 Mdot
.6901 .39391 Mdot
.42034 .73259 Mdot
.36389 .64248 Mdot
.64012 .34968 Mdot
.68728 .3954 Mdot
.4181 .30842 Mdot
.37162 .36531 Mdot
.55753 .28883 Mdot
.28989 .51725 Mdot
.44435 .7298 Mdot
.38392 .6769 Mdot
.52857 .71189 Mdot
.28939 .52133 Mdot
.62039 .67877 Mdot
.36617 .66815 Mdot
.3683 .64399 Mdot
.29631 .5001 Mdot
.69986 .38889 Mdot
.71461 .49097 Mdot
.37919 .68341 Mdot
.33068 .39624 Mdot
.6271 .68812 Mdot
.26465 .49959 Mdot
.71922 .48099 Mdot
.67154 .62574 Mdot
.73474 .48852 Mdot
.67883 .40133 Mdot
.40683 .31915 Mdot
.30302 .50308 Mdot
.7179 .49705 Mdot
.48496 .26452 Mdot
.60511 .32551 Mdot
.50589 .72046 Mdot
.69708 .41565 Mdot
.74217 .47994 Mdot
.69993 .49829 Mdot
.71603 .46544 Mdot
.6013 .6737 Mdot
.45086 .73728 Mdot
.34186 .3925 Mdot
.60158 .31541 Mdot
.48084 .27478 Mdot
.38826 .67902 Mdot
.67755 .62611 Mdot
.45922 .74443 Mdot
.3891 .6697 Mdot
.35829 .63288 Mdot
.36265 .62123 Mdot
.34905 .36534 Mdot
.35256 .59334 Mdot
.36023 .61195 Mdot
.674 .42042 Mdot
.4194 .30973 Mdot
.32808 .58518 Mdot
.32924 .37931 Mdot
.28078 .54488 Mdot
.2844 .46665 Mdot
.38158 .68142 Mdot
.57342 .69969 Mdot
.71176 .49393 Mdot
.557 .30107 Mdot
.53096 .26943 Mdot
.27438 .49471 Mdot
.69092 .40687 Mdot
.73289 .50711 Mdot
.43948 .2938 Mdot
.30489 .49833 Mdot
.4096 .68468 Mdot
.52566 .72058 Mdot
.48928 .73314 Mdot
.50607 .72862 Mdot
.40684 .67878 Mdot
.35722 .38055 Mdot
.5592 .30434 Mdot
.49618 .72261 Mdot
.66101 .62331 Mdot
.26458 .51149 Mdot
.27939 .51282 Mdot
.70708 .57254 Mdot
.37139 .65858 Mdot
.67728 .3781 Mdot
.55683 .71397 Mdot
.68198 .36327 Mdot
.70511 .5419 Mdot
.28596 .55057 Mdot
.41642 .70417 Mdot
.41834 .71 Mdot
.34704 .58521 Mdot
.70878 .57116 Mdot
.70406 .59024 Mdot
.68138 .58539 Mdot
.69132 .39393 Mdot
.42287 .71725 Mdot
.62163 .31571 Mdot
.35956 .37032 Mdot
.71705 .51118 Mdot
.51906 .70701 Mdot
.50891 .27681 Mdot
.61866 .69462 Mdot
.2961 .46648 Mdot
.53497 .7278 Mdot
.32317 .38877 Mdot
.40617 .71892 Mdot
.50081 .28237 Mdot
.67437 .59784 Mdot
.61029 .69601 Mdot
.44241 .28329 Mdot
.44413 .73304 Mdot
.29873 .39605 Mdot
.36456 .37745 Mdot
.29436 .51912 Mdot
.42046 .71044 Mdot
.29361 .46359 Mdot
.67242 .39827 Mdot
.329 .58619 Mdot
.43832 .72989 Mdot
.35216 .62363 Mdot
.39885 .68926 Mdot
.69138 .38792 Mdot
.62839 .67021 Mdot
.3024 .41967 Mdot
.37115 .36809 Mdot
.62404 .68279 Mdot
.29894 .47102 Mdot
.62019 .32556 Mdot
.42087 .30742 Mdot
.34071 .40328 Mdot
.29452 .52334 Mdot
.42374 .71032 Mdot
.3377 .61239 Mdot
.36431 .36562 Mdot
.39418 .6807 Mdot
.60691 .67298 Mdot
.52486 .29992 Mdot
.63277 .67879 Mdot
.27167 .48483 Mdot
.29164 .46806 Mdot
.69366 .38544 Mdot
.71683 .49862 Mdot
.27584 .49965 Mdot
.49366 .28055 Mdot
.39321 .6984 Mdot
.4143 .70078 Mdot
.69865 .58748 Mdot
.38414 .65988 Mdot
.27109 .4856 Mdot
.39161 .67323 Mdot
.67507 .58511 Mdot
.71144 .56444 Mdot
.34428 .59759 Mdot
.6081 .67835 Mdot
.6997 .4885 Mdot
.28829 .50574 Mdot
.6885 .41273 Mdot
.46487 .72913 Mdot
.6745 .41549 Mdot
.68171 .58427 Mdot
.31608 .40978 Mdot
.74011 .48394 Mdot
.31578 .41069 Mdot
.64715 .6438 Mdot
.36552 .64499 Mdot
.70089 .58466 Mdot
.29595 .41491 Mdot
.53628 .27835 Mdot
.46323 .28541 Mdot
.3505 .37347 Mdot
.72014 .50641 Mdot
.34089 .38718 Mdot
.28101 .49585 Mdot
.59213 .30049 Mdot
.70572 .47735 Mdot
.51751 .30336 Mdot
.47613 .28537 Mdot
.60014 .30962 Mdot
.3562 .62811 Mdot
.43479 .73003 Mdot
.50217 .29583 Mdot
.68456 .36298 Mdot
.70437 .52449 Mdot
.35188 .61518 Mdot
.3451 .40021 Mdot
.53735 .2975 Mdot
.57284 .29546 Mdot
.6856 .59499 Mdot
.60577 .69661 Mdot
.38166 .65535 Mdot
.63517 .33878 Mdot
.42467 .73503 Mdot
.6048 .67839 Mdot
.28467 .51573 Mdot
.37549 .65761 Mdot
.40982 .71817 Mdot
.63156 .3321 Mdot
.32338 .41251 Mdot
.50615 .7295 Mdot
.44715 .28751 Mdot
.43918 .73655 Mdot
.30574 .55983 Mdot
.36428 .36635 Mdot
.40965 .68689 Mdot
.30478 .42573 Mdot
.7337 .49402 Mdot
.35019 .61966 Mdot
.60379 .32552 Mdot
.54522 .28591 Mdot
.39693 .66753 Mdot
.38068 .34843 Mdot
.61856 .33235 Mdot
.32164 .39073 Mdot
.29697 .50605 Mdot
.61218 .69125 Mdot
.37987 .65898 Mdot
.43337 .30078 Mdot
.29388 .48111 Mdot
.35296 .62851 Mdot
.49744 .27515 Mdot
.62563 .3277 Mdot
.34006 .37601 Mdot
.42766 .72133 Mdot
.61316 .31637 Mdot
.68771 .40572 Mdot
.29601 .46324 Mdot
.7143 .44412 Mdot
.36166 .65094 Mdot
.35135 .63536 Mdot
.73004 .45695 Mdot
.69502 .59362 Mdot
.43288 .71757 Mdot
.3278 .57258 Mdot
.67453 .38551 Mdot
.46042 .7384 Mdot
.41302 .72705 Mdot
.29554 .41203 Mdot
.68319 .36788 Mdot
.55315 .2822 Mdot
.46958 .28196 Mdot
.29036 .49083 Mdot
.73749 .49624 Mdot
.30485 .45484 Mdot
.54422 .28839 Mdot
.42588 .72909 Mdot
.67156 .4108 Mdot
.64512 .64584 Mdot
.61125 .32475 Mdot
.49496 .28635 Mdot
.6783 .61316 Mdot
.56146 .70948 Mdot
.30672 .56032 Mdot
.68037 .36202 Mdot
.40598 .30888 Mdot
.26781 .50914 Mdot
.66068 .62325 Mdot
.34136 .62299 Mdot
.50943 .71527 Mdot
.397 .66875 Mdot
.35931 .35837 Mdot
.42858 .30654 Mdot
.37145 .36264 Mdot
.32369 .40977 Mdot
.44308 .72533 Mdot
.68768 .40717 Mdot
.63241 .32847 Mdot
.31247 .39666 Mdot
.68128 .40134 Mdot
.33478 .61759 Mdot
.5079 .29086 Mdot
.64713 .639 Mdot
.34192 .61734 Mdot
.30782 .50061 Mdot
.59229 .32158 Mdot
.65393 .61714 Mdot
.53967 .27269 Mdot
.41863 .7095 Mdot
.70287 .54705 Mdot
.67312 .40385 Mdot
.38988 .69645 Mdot
.54068 .28203 Mdot
.34181 .40237 Mdot
.50189 .27247 Mdot
.42009 .69792 Mdot
.41464 .70664 Mdot
.31697 .41701 Mdot
.34368 .61886 Mdot
.69256 .50222 Mdot
.6102 .66496 Mdot
.58235 .6869 Mdot
.36072 .61209 Mdot
.67072 .63407 Mdot
.62454 .33855 Mdot
.31169 .39802 Mdot
.51008 .72515 Mdot
.39238 .68153 Mdot
.70097 .47946 Mdot
.62236 .3282 Mdot
.63374 .31392 Mdot
.69046 .39039 Mdot
.54103 .28055 Mdot
.68979 .40781 Mdot
.34688 .58424 Mdot
.70292 .53091 Mdot
.52821 .28555 Mdot
.3218 .39696 Mdot
.48309 .26181 Mdot
.33708 .57851 Mdot
.57857 .30172 Mdot
.46997 .27518 Mdot
.59576 .67977 Mdot
.71358 .52629 Mdot
.3669 .3469 Mdot
.56956 .69906 Mdot
.41877 .72661 Mdot
.39832 .67043 Mdot
.35868 .38426 Mdot
.69337 .38661 Mdot
.69052 .59326 Mdot
.39507 .31879 Mdot
.27369 .48172 Mdot
.6987 .53572 Mdot
.2881 .4647 Mdot
.53367 .71815 Mdot
.66746 .63208 Mdot
.5155 .73886 Mdot
.6858 .37701 Mdot
.71698 .50627 Mdot
.26365 .49947 Mdot
.59663 .66841 Mdot
.28862 .4781 Mdot
.50644 .26492 Mdot
.55579 .72358 Mdot
.52488 .30212 Mdot
.59548 .30574 Mdot
.40919 .31367 Mdot
.67066 .3857 Mdot
.38017 .34804 Mdot
.6373 .67076 Mdot
.63053 .33984 Mdot
.59293 .31549 Mdot
.5499 .29659 Mdot
.31651 .39032 Mdot
.62809 .67129 Mdot
.31283 .38478 Mdot
.31941 .38247 Mdot
.63503 .33463 Mdot
.71203 .50691 Mdot
.70845 .48544 Mdot
.27737 .54176 Mdot
.7123 .50438 Mdot
.52839 .29454 Mdot
.5256 .71766 Mdot
.56944 .70693 Mdot
.62282 .33913 Mdot
.61315 .69146 Mdot
.36052 .59938 Mdot
.42345 .31642 Mdot
.51744 .29318 Mdot
.69064 .39908 Mdot
.74274 .47416 Mdot
.31014 .40778 Mdot
.68601 .59664 Mdot
.73038 .50403 Mdot
.73055 .49099 Mdot
.74182 .48535 Mdot
.41692 .71544 Mdot
.66897 .38663 Mdot
.72433 .50188 Mdot
.42365 .70597 Mdot
.35018 .63727 Mdot
.34388 .39874 Mdot
.3559 .35932 Mdot
.61122 .67295 Mdot
.34043 .39508 Mdot
.33525 .60137 Mdot
.51648 .27488 Mdot
.36727 .35479 Mdot
.30928 .41235 Mdot
.55647 .2956 Mdot
.55896 .29975 Mdot
.31574 .38313 Mdot
.36903 .35446 Mdot
.69302 .49652 Mdot
.63992 .66743 Mdot
.68911 .62269 Mdot
.46727 .2747 Mdot
.64563 .34436 Mdot
.69954 .58596 Mdot
.40199 .67033 Mdot
.34176 .40574 Mdot
.50424 .28384 Mdot
.71091 .47138 Mdot
.35467 .60985 Mdot
.3351 .39416 Mdot
.28522 .48759 Mdot
.31975 .39715 Mdot
.35755 .3818 Mdot
.70833 .59389 Mdot
.70036 .43781 Mdot
.66653 .61767 Mdot
.44762 .28547 Mdot
.32622 .38804 Mdot
.7067 .56027 Mdot
.39383 .32664 Mdot
.59488 .29919 Mdot
.6125 .66365 Mdot
.36098 .61078 Mdot
.55679 .30167 Mdot
.70938 .51779 Mdot
.68594 .42499 Mdot
.50932 .73871 Mdot
.71821 .49812 Mdot
.37398 .36058 Mdot
.35617 .37471 Mdot
.53926 .2978 Mdot
.70627 .57829 Mdot
.60543 .6796 Mdot
.72402 .49475 Mdot
.60318 .31185 Mdot
.38949 .6615 Mdot
.70312 .54795 Mdot
.3353 .40005 Mdot
.70922 .49107 Mdot
.48233 .2769 Mdot
.27816 .4846 Mdot
.40003 .68814 Mdot
.65573 .35245 Mdot
.35098 .627 Mdot
.60282 .30792 Mdot
.30475 .51448 Mdot
.59145 .68587 Mdot
.40366 .67814 Mdot
.50966 .71881 Mdot
.59229 .31641 Mdot
.41725 .69123 Mdot
.55336 .709 Mdot
.66991 .62536 Mdot
.67683 .60629 Mdot
.33117 .60725 Mdot
.51403 .29775 Mdot
.42056 .29094 Mdot
.36089 .64211 Mdot
.43804 .28175 Mdot
.56093 .71484 Mdot
.30371 .40534 Mdot
.26709 .52888 Mdot
.38791 .68584 Mdot
.40037 .68335 Mdot
.34898 .59285 Mdot
.38975 .65972 Mdot
.49349 .73526 Mdot
.54404 .2863 Mdot
.54702 .27984 Mdot
.28273 .49871 Mdot
.44842 .74425 Mdot
.28793 .47146 Mdot
.62628 .32952 Mdot
.63592 .67325 Mdot
.36757 .37342 Mdot
.71255 .49933 Mdot
.34962 .62221 Mdot
.49705 .26746 Mdot
.408 .68561 Mdot
.61151 .68566 Mdot
.53294 .29547 Mdot
.50451 .28019 Mdot
.44789 .28882 Mdot
.26766 .49383 Mdot
.72963 .48102 Mdot
.34278 .5814 Mdot
.2684 .52173 Mdot
.3074 .4152 Mdot
.47859 .73888 Mdot
.7034 .53543 Mdot
.716 .48151 Mdot
.73065 .47483 Mdot
.34091 .58924 Mdot
.34023 .58765 Mdot
.61043 .30839 Mdot
.69564 .60571 Mdot
.66618 .40021 Mdot
.55399 .30302 Mdot
.42702 .28595 Mdot
.40359 .6846 Mdot
.30571 .50294 Mdot
.29738 .47044 Mdot
.4739 .26873 Mdot
.36323 .37451 Mdot
.29237 .4633 Mdot
.33614 .58563 Mdot
.54225 .30009 Mdot
.26514 .50146 Mdot
.7407 .47553 Mdot
.64796 .34124 Mdot
.28412 .47299 Mdot
.32954 .40668 Mdot
.68237 .62046 Mdot
.40126 .70347 Mdot
.30215 .45474 Mdot
.62722 .33707 Mdot
.52453 .73648 Mdot
.36407 .37191 Mdot
.30775 .48761 Mdot
.4576 .73245 Mdot
.53781 .2875 Mdot
.32673 .40908 Mdot
.26249 .49932 Mdot
.57204 .70665 Mdot
.30417 .45909 Mdot
.71251 .48433 Mdot
.57929 .69175 Mdot
.39737 .6763 Mdot
.60098 .68776 Mdot
.70142 .40615 Mdot
.50593 .26408 Mdot
.52593 .26876 Mdot
.70039 .58104 Mdot
.51688 .71909 Mdot
.5018 .29746 Mdot
.51042 .72071 Mdot
.27007 .53469 Mdot
.4232 .70528 Mdot
.27464 .54253 Mdot
.59288 .67248 Mdot
.27982 .46672 Mdot
.28074 .47848 Mdot
.61069 .33473 Mdot
.68199 .40911 Mdot
.69064 .38435 Mdot
.5185 .30085 Mdot
.53262 .72273 Mdot
.53688 .27367 Mdot
.71912 .44796 Mdot
.29668 .48773 Mdot
.42997 .29607 Mdot
.35632 .59611 Mdot
.33587 .59959 Mdot
.60372 .69401 Mdot
.35021 .3941 Mdot
.42767 .71128 Mdot
.61014 .31322 Mdot
.48461 .26442 Mdot
.57646 .29763 Mdot
.69775 .57533 Mdot
.7221 .45051 Mdot
.50801 .27929 Mdot
.27157 .53723 Mdot
.2986 .46684 Mdot
.46516 .74277 Mdot
.31232 .37792 Mdot
.51883 .27208 Mdot
.36869 .65706 Mdot
.70722 .47426 Mdot
.45263 .29304 Mdot
.3521 .62096 Mdot
.47341 .28283 Mdot
.38469 .32926 Mdot
.59138 .68199 Mdot
.40481 .70343 Mdot
.64561 .34094 Mdot
.5137 .72331 Mdot
.27696 .47225 Mdot
.31712 .41757 Mdot
.51009 .70954 Mdot
.54694 .29075 Mdot
.49697 .2602 Mdot
.2755 .4847 Mdot
.65887 .61922 Mdot
.70753 .48036 Mdot
.69332 .49605 Mdot
.60802 .31051 Mdot
.36736 .6458 Mdot
.54322 .2986 Mdot
.68672 .60413 Mdot
.39217 .69717 Mdot
.67707 .38852 Mdot
.47488 .26455 Mdot
.34396 .61901 Mdot
.40498 .67992 Mdot
.28349 .47932 Mdot
.28216 .54466 Mdot
.30396 .42183 Mdot
.59308 .29855 Mdot
.44899 .7273 Mdot
.63697 .67671 Mdot
.34459 .597 Mdot
.70067 .52141 Mdot
.34369 .3849 Mdot
.294 .47296 Mdot
.43625 .72023 Mdot
.52131 .71031 Mdot
.70053 .5037 Mdot
.68316 .37675 Mdot
.32597 .39375 Mdot
.44827 .72854 Mdot
.34667 .62254 Mdot
.39351 .67168 Mdot
.60107 .67406 Mdot
.36449 .61258 Mdot
.42006 .31559 Mdot
.65584 .60834 Mdot
.28068 .52145 Mdot
.72975 .48601 Mdot
.3977 .32143 Mdot
.61853 .6633 Mdot
.54674 .72194 Mdot
.66767 .63301 Mdot
.70846 .53026 Mdot
.60178 .31165 Mdot
.66869 .39495 Mdot
.30114 .51551 Mdot
.41415 .69229 Mdot
.36007 .36735 Mdot
.72792 .49623 Mdot
.50652 .26476 Mdot
.28938 .46924 Mdot
.40792 .30669 Mdot
.34169 .60296 Mdot
.54761 .2943 Mdot
.34446 .37552 Mdot
.70809 .57694 Mdot
.52121 .27569 Mdot
.34249 .40172 Mdot
.28499 .51088 Mdot
.52481 .73501 Mdot
.37875 .35481 Mdot
.31979 .40897 Mdot
.41014 .69097 Mdot
.6465 .64687 Mdot
.60874 .6904 Mdot
.29642 .4084 Mdot
.54338 .27397 Mdot
.32984 .40307 Mdot
.65257 .61685 Mdot
.59308 .68349 Mdot
.48306 .27087 Mdot
.69925 .59344 Mdot
.60854 .66493 Mdot
.31368 .40947 Mdot
.70493 .5354 Mdot
.3918 .32355 Mdot
.72688 .46249 Mdot
.3968 .70154 Mdot
.36387 .63023 Mdot
.52015 .30218 Mdot
.28696 .48112 Mdot
.62629 .31875 Mdot
.63218 .34681 Mdot
.59656 .32039 Mdot
.519 .30535 Mdot
.34725 .62055 Mdot
.72108 .50309 Mdot
.67663 .40707 Mdot
.68973 .59073 Mdot
.49209 .27773 Mdot
.50852 .29376 Mdot
.60835 .6949 Mdot
.29175 .46712 Mdot
.35462 .59432 Mdot
.50628 .26513 Mdot
.41297 .31349 Mdot
.70573 .556 Mdot
.27307 .47709 Mdot
.616 .66586 Mdot
.37896 .35508 Mdot
.4399 .7415 Mdot
.66023 .6291 Mdot
.35498 .37236 Mdot
.70406 .57523 Mdot
.40808 .71822 Mdot
.57531 .3023 Mdot
.396 .32619 Mdot
.51353 .72162 Mdot
.6268 .31257 Mdot
.67168 .40582 Mdot
.52698 .2778 Mdot
.34817 .60872 Mdot
.41233 .30382 Mdot
.28964 .49245 Mdot
.58888 .67271 Mdot
.31141 .39659 Mdot
.69479 .5883 Mdot
.67891 .4156 Mdot
.3695 .35291 Mdot
.62579 .31831 Mdot
.68943 .38143 Mdot
.68253 .62903 Mdot
.39791 .67754 Mdot
.51261 .2844 Mdot
.4959 .29209 Mdot
.27496 .542 Mdot
.43083 .3114 Mdot
.71984 .47099 Mdot
.57394 .30022 Mdot
.49823 .71854 Mdot
.33124 .60513 Mdot
.37005 .3601 Mdot
.35416 .36782 Mdot
.4049 .31807 Mdot
.41812 .69224 Mdot
.66731 .60652 Mdot
.54508 .27718 Mdot
.47102 .28565 Mdot
.59885 .68499 Mdot
.68023 .41004 Mdot
.30185 .388 Mdot
.52385 .29353 Mdot
.46553 .72867 Mdot
.4037 .68633 Mdot
.67978 .3625 Mdot
.52681 .29279 Mdot
.38514 .33581 Mdot
.64509 .34972 Mdot
.67847 .6117 Mdot
.49594 .72966 Mdot
.68047 .59734 Mdot
.29227 .4641 Mdot
.52362 .27034 Mdot
.62735 .32443 Mdot
.3232 .39204 Mdot
.42305 .29103 Mdot
.50921 .30038 Mdot
.71791 .4863 Mdot
.39536 .67273 Mdot
.37716 .67483 Mdot
.34432 .62116 Mdot
.46261 .74506 Mdot
.27313 .47958 Mdot
.63176 .34704 Mdot
.60123 .31314 Mdot
.49524 .72924 Mdot
.26594 .49639 Mdot
.54897 .285 Mdot
.53494 .29503 Mdot
.65513 .35314 Mdot
.358 .38049 Mdot
.54678 .28234 Mdot
.40845 .69139 Mdot
.43825 .28844 Mdot
.67696 .62686 Mdot
.6816 .41108 Mdot
.39292 .68125 Mdot
.51083 .30145 Mdot
.7072 .59894 Mdot
.52486 .72391 Mdot
.35937 .64055 Mdot
.2968 .42346 Mdot
.67032 .39921 Mdot
.72958 .45324 Mdot
.42198 .31723 Mdot
.36591 .64306 Mdot
.62119 .32306 Mdot
.38223 .34406 Mdot
.43924 .28981 Mdot
.7365 .48693 Mdot
.47693 .28535 Mdot
.68646 .41471 Mdot
.33705 .37986 Mdot
.28145 .5216 Mdot
.5075 .27188 Mdot
.46694 .28112 Mdot
.61924 .68005 Mdot
.2762 .53855 Mdot
.29658 .45786 Mdot
.70919 .52409 Mdot
.67538 .38235 Mdot
.60928 .6871 Mdot
.46357 .72934 Mdot
.33999 .58527 Mdot
.69343 .38445 Mdot
.70786 .55159 Mdot
.36704 .65381 Mdot
.35002 .59927 Mdot
.38661 .68981 Mdot
.66863 .6201 Mdot
.71865 .51257 Mdot
.4571 .74247 Mdot
.60984 .67741 Mdot
.54194 .7196 Mdot
.71273 .49234 Mdot
.72553 .48285 Mdot
.53877 .72577 Mdot
.61758 .68255 Mdot
.70001 .5976 Mdot
.68197 .40542 Mdot
.67145 .40523 Mdot
.73186 .49112 Mdot
.5996 .69301 Mdot
.69284 .37953 Mdot
.68307 .59058 Mdot
.4983 .28806 Mdot
.55248 .71179 Mdot
.73263 .50642 Mdot
.55747 .7209 Mdot
.67245 .39778 Mdot
.46768 .73829 Mdot
.56173 .71529 Mdot
.36456 .61502 Mdot
.3984 .67558 Mdot
.26759 .51343 Mdot
.32019 .39389 Mdot
.31618 .38261 Mdot
.69335 .38761 Mdot
.34967 .59037 Mdot
.67718 .58886 Mdot
.34415 .58821 Mdot
.38274 .65871 Mdot
.46177 .73143 Mdot
.48909 .71836 Mdot
.73552 .4873 Mdot
.67968 .58617 Mdot
.43812 .2859 Mdot
.49845 .26241 Mdot
.52752 .71015 Mdot
.67066 .40152 Mdot
.70737 .49454 Mdot
.66664 .40119 Mdot
.54478 .2895 Mdot
.50924 .28354 Mdot
.34533 .3897 Mdot
.32687 .4092 Mdot
.52522 .2804 Mdot
.44345 .28282 Mdot
.46985 .73608 Mdot
.69854 .59102 Mdot
.6499 .62142 Mdot
.38198 .66886 Mdot
.37677 .68071 Mdot
.28683 .48382 Mdot
.38071 .35124 Mdot
.61406 .31531 Mdot
.50375 .72421 Mdot
.33194 .58472 Mdot
.32001 .40666 Mdot
.70385 .39861 Mdot
.30315 .47913 Mdot
.67759 .41096 Mdot
.29017 .51433 Mdot
.4828 .27242 Mdot
.34422 .61573 Mdot
.35173 .59564 Mdot
.6035 .3145 Mdot
.45019 .28835 Mdot
.53943 .30155 Mdot
.29027 .4792 Mdot
.38333 .67349 Mdot
.54252 .29546 Mdot
.73016 .5108 Mdot
.70494 .54052 Mdot
.34801 .37181 Mdot
.35221 .60848 Mdot
.3914 .6908 Mdot
.59297 .68235 Mdot
.30689 .41422 Mdot
.32646 .39402 Mdot
.71253 .44474 Mdot
.43095 .73432 Mdot
.63275 .31181 Mdot
.3194 .41437 Mdot
.73701 .47992 Mdot
.51489 .28306 Mdot
.30758 .41155 Mdot
.30996 .38425 Mdot
.2948 .5561 Mdot
.3274 .37357 Mdot
.70559 .50764 Mdot
.67653 .59944 Mdot
.62979 .67343 Mdot
.71157 .54684 Mdot
.29168 .52008 Mdot
.30024 .47385 Mdot
.39711 .32638 Mdot
.6064 .32814 Mdot
.39964 .71048 Mdot
.29594 .48333 Mdot
.73748 .46967 Mdot
.61597 .69436 Mdot
.62425 .68626 Mdot
.62587 .67741 Mdot
.68636 .59173 Mdot
.41697 .70631 Mdot
.42459 .30963 Mdot
.71601 .48779 Mdot
.63239 .67942 Mdot
.36805 .66642 Mdot
.69504 .50296 Mdot
.67974 .37996 Mdot
.58478 .67768 Mdot
.71956 .5027 Mdot
.49157 .73365 Mdot
.67223 .38438 Mdot
.51349 .71467 Mdot
.57165 .29817 Mdot
.39208 .33364 Mdot
.68883 .40064 Mdot
.47353 .26605 Mdot
.54866 .29737 Mdot
.5291 .29877 Mdot
.72508 .50731 Mdot
.45924 .28263 Mdot
.67723 .5871 Mdot
.40627 .30884 Mdot
.44715 .72855 Mdot
.30254 .50407 Mdot
.41314 .31163 Mdot
.72992 .49003 Mdot
.73177 .45696 Mdot
.31136 .56199 Mdot
.36085 .64545 Mdot
.63196 .33577 Mdot
.28426 .50191 Mdot
.52673 .71799 Mdot
.28341 .51673 Mdot
.54438 .28451 Mdot
.43884 .71703 Mdot
.40315 .68572 Mdot
.64342 .32992 Mdot
.28624 .48015 Mdot
.72845 .48324 Mdot
.62153 .67893 Mdot
.57186 .30447 Mdot
.29045 .48931 Mdot
.29243 .46785 Mdot
.35421 .63686 Mdot
.67654 .59765 Mdot
.55659 .30448 Mdot
.69024 .36917 Mdot
.39134 .31834 Mdot
.48665 .7361 Mdot
.43598 .7321 Mdot
.36538 .6465 Mdot
.53707 .7162 Mdot
.4002 .31783 Mdot
.68457 .40079 Mdot
.38402 .65848 Mdot
.38878 .33339 Mdot
.38288 .65429 Mdot
.71029 .57318 Mdot
.40954 .31048 Mdot
.34469 .37207 Mdot
.34282 .40013 Mdot
.3546 .61622 Mdot
.30752 .56299 Mdot
.42596 .72035 Mdot
.69411 .37794 Mdot
.31981 .38818 Mdot
.46749 .27064 Mdot
.71078 .4736 Mdot
.29624 .55673 Mdot
.6084 .67436 Mdot
.68884 .3697 Mdot
.53914 .29427 Mdot
.30065 .55925 Mdot
.26948 .51131 Mdot
.56606 .71419 Mdot
.34636 .6341 Mdot
.35489 .61432 Mdot
.68301 .3845 Mdot
.69837 .38371 Mdot
.65827 .62666 Mdot
.37141 .35694 Mdot
.70286 .54511 Mdot
.6098 .32538 Mdot
.29915 .55898 Mdot
.35842 .36638 Mdot
.6643 .6131 Mdot
.35636 .36376 Mdot
.69942 .41134 Mdot
.43347 .727 Mdot
.67699 .59836 Mdot
.34861 .37528 Mdot
.5755 .69479 Mdot
.61698 .69017 Mdot
.46836 .7314 Mdot
.35735 .63415 Mdot
.71759 .47552 Mdot
.71409 .48735 Mdot
.67519 .59247 Mdot
.35434 .37779 Mdot
.33951 .60297 Mdot
.36179 .61611 Mdot
.36736 .64069 Mdot
.70704 .55338 Mdot
.34708 .61838 Mdot
.72069 .46477 Mdot
.54528 .70989 Mdot
.57085 .29539 Mdot
.34733 .59356 Mdot
.69301 .40245 Mdot
.35928 .6242 Mdot
.28843 .46302 Mdot
.51362 .73375 Mdot
.5946 .67628 Mdot
.682 .39773 Mdot
.37207 .65864 Mdot
.38337 .3406 Mdot
.34126 .5811 Mdot
.29355 .51365 Mdot
.64114 .3363 Mdot
.41919 .71915 Mdot
.70374 .55657 Mdot
.72535 .49185 Mdot
.49631 .27157 Mdot
.67696 .42223 Mdot
.5354 .27768 Mdot
.64008 .66702 Mdot
.36442 .3634 Mdot
.42394 .29757 Mdot
.46325 .73003 Mdot
.43076 .73065 Mdot
.36096 .38058 Mdot
.68945 .58064 Mdot
.41874 .31465 Mdot
.37807 .68496 Mdot
.60549 .69465 Mdot
.27548 .48716 Mdot
.28547 .51319 Mdot
.28395 .54733 Mdot
.68784 .59867 Mdot
.7339 .45968 Mdot
.68135 .38592 Mdot
.50323 .29851 Mdot
.27504 .47346 Mdot
.66899 .35471 Mdot
.69999 .40143 Mdot
.40818 .31783 Mdot
.67806 .41461 Mdot
.34199 .59624 Mdot
.31398 .38484 Mdot
.68092 .61722 Mdot
.31383 .4015 Mdot
.40216 .71197 Mdot
.4716 .28758 Mdot
.35831 .37517 Mdot
.26863 .52031 Mdot
.69075 .41221 Mdot
.51071 .27626 Mdot
.39491 .67434 Mdot
.71254 .48755 Mdot
.64609 .66395 Mdot
.38273 .33584 Mdot
.59608 .67501 Mdot
.59834 .6717 Mdot
.66511 .62189 Mdot
.30048 .41136 Mdot
.40532 .30071 Mdot
.59585 .67095 Mdot
.59596 .31515 Mdot
.31138 .47636 Mdot
.44197 .29656 Mdot
.52242 .26861 Mdot
.53108 .28677 Mdot
.4122 .72314 Mdot
.55822 .28913 Mdot
.52845 .73112 Mdot
.57204 .30437 Mdot
.64158 .34317 Mdot
.41969 .70507 Mdot
.53275 .29367 Mdot
.31634 .41456 Mdot
.4059 .69231 Mdot
.67452 .60865 Mdot
.56455 .29948 Mdot
.36495 .61593 Mdot
.4492 .2785 Mdot
.60173 .31047 Mdot
.35324 .37984 Mdot
.52147 .73744 Mdot
.67868 .40425 Mdot
.7087 .51291 Mdot
.48163 .72564 Mdot
.29235 .49183 Mdot
.66605 .60054 Mdot
.3081 .49767 Mdot
.29672 .46451 Mdot
.5496 .7137 Mdot
.71153 .52619 Mdot
.33822 .37363 Mdot
.28661 .51045 Mdot
.27183 .53022 Mdot
.53414 .28713 Mdot
.39084 .33034 Mdot
.32918 .40502 Mdot
.39358 .67322 Mdot
.42583 .3009 Mdot
.68949 .40576 Mdot
.35379 .63919 Mdot
.53302 .30103 Mdot
.32799 .38051 Mdot
.35266 .60338 Mdot
.60962 .67623 Mdot
.67204 .6237 Mdot
.3528 .3625 Mdot
.29783 .50742 Mdot
.67532 .60413 Mdot
.36494 .6457 Mdot
.28989 .5248 Mdot
.38877 .32292 Mdot
.40931 .69894 Mdot
.73796 .48741 Mdot
.74042 .47367 Mdot
.51224 .26491 Mdot
.68304 .37525 Mdot
.48954 .28917 Mdot
.28896 .51747 Mdot
.31167 .5641 Mdot
.34015 .39758 Mdot
.59068 .67319 Mdot
.52728 .7328 Mdot
.50463 .26852 Mdot
.7279 .48084 Mdot
.67355 .3609 Mdot
.51621 .73433 Mdot
.41012 .69746 Mdot
.35615 .61254 Mdot
.40467 .31476 Mdot
.70764 .47794 Mdot
.35447 .61017 Mdot
.36252 .35679 Mdot
.4147 .70266 Mdot
.27919 .49768 Mdot
.57004 .29676 Mdot
.33257 .41013 Mdot
.71111 .55313 Mdot
.35128 .37632 Mdot
.52525 .29587 Mdot
.47502 .72408 Mdot
.53683 .7198 Mdot
.28695 .55078 Mdot
.70481 .50796 Mdot
.70608 .60119 Mdot
.51182 .28611 Mdot
.39602 .32252 Mdot
.61185 .67077 Mdot
.61914 .67644 Mdot
.40491 .6905 Mdot
.54294 .2835 Mdot
.52072 .26253 Mdot
.35799 .36402 Mdot
.36117 .37607 Mdot
.53341 .70772 Mdot
.48545 .27367 Mdot
.34487 .61607 Mdot
.60372 .692 Mdot
.69409 .41755 Mdot
.68191 .60268 Mdot
.62528 .34188 Mdot
.68974 .42332 Mdot
.38843 .69779 Mdot
.44867 .72505 Mdot
.61035 .31053 Mdot
.59613 .3229 Mdot
.40729 .32013 Mdot
.54838 .70535 Mdot
.28586 .47131 Mdot
.45566 .73114 Mdot
.53962 .27932 Mdot
.33661 .60824 Mdot
.72849 .47115 Mdot
.373 .3583 Mdot
.66181 .35558 Mdot
.32002 .56759 Mdot
.62702 .66878 Mdot
.42924 .30275 Mdot
.31774 .4094 Mdot
.31267 .39774 Mdot
.39764 .69811 Mdot
.34613 .61603 Mdot
.515 .26547 Mdot
.56724 .70602 Mdot
.61107 .32621 Mdot
.40193 .32248 Mdot
.68921 .60027 Mdot
.35694 .62142 Mdot
.69689 .48553 Mdot
.69269 .41525 Mdot
.30944 .46833 Mdot
.26695 .50203 Mdot
.34024 .58075 Mdot
.61577 .66304 Mdot
.59503 .30475 Mdot
.6154 .67304 Mdot
.61354 .68434 Mdot
.3328 .39835 Mdot
.61426 .66598 Mdot
.34372 .63225 Mdot
.35943 .65134 Mdot
.30723 .41526 Mdot
.69858 .40812 Mdot
.40278 .71065 Mdot
.31282 .40858 Mdot
.50808 .73511 Mdot
.67983 .42147 Mdot
.61378 .67237 Mdot
.69114 .39078 Mdot
.4044 .31988 Mdot
.60477 .31111 Mdot
.27965 .52174 Mdot
.41282 .31445 Mdot
.65208 .62212 Mdot
.72014 .50348 Mdot
.66784 .3909 Mdot
.28493 .51007 Mdot
.69219 .39747 Mdot
.50995 .27311 Mdot
.59659 .31053 Mdot
.71388 .56597 Mdot
.46669 .72799 Mdot
.38993 .69908 Mdot
.6782 .36548 Mdot
.48969 .26437 Mdot
.73155 .49166 Mdot
.60205 .32524 Mdot
.53815 .73302 Mdot
.26913 .50778 Mdot
.35686 .61755 Mdot
.69189 .41245 Mdot
.41788 .30729 Mdot
.66716 .62893 Mdot
.29266 .50992 Mdot
.72592 .45055 Mdot
.49266 .26943 Mdot
.41747 .70099 Mdot
.63834 .34919 Mdot
.42638 .29228 Mdot
.60391 .3163 Mdot
.3753 .66872 Mdot
.36396 .36918 Mdot
.35765 .35991 Mdot
.70122 .60459 Mdot
.35949 .38471 Mdot
.38146 .3457 Mdot
.59292 .31378 Mdot
.65817 .61615 Mdot
.4433 .28567 Mdot
.39287 .67202 Mdot
.63558 .67556 Mdot
.34043 .39303 Mdot
.70968 .48277 Mdot
.59986 .676 Mdot
.34595 .39153 Mdot
.54712 .71004 Mdot
.68031 .59946 Mdot
.55886 .29422 Mdot
.40869 .69042 Mdot
.63762 .34378 Mdot
.61756 .32865 Mdot
.37356 .36111 Mdot
.6274 .32104 Mdot
.50781 .73496 Mdot
.71356 .52578 Mdot
.62684 .6713 Mdot
.28 .49927 Mdot
.69256 .50839 Mdot
.36006 .3613 Mdot
.29424 .55343 Mdot
.41145 .69263 Mdot
.51117 .28454 Mdot
.44173 .28951 Mdot
.53214 .70864 Mdot
.71444 .49284 Mdot
.51807 .73207 Mdot
.60463 .67001 Mdot
.6166 .6745 Mdot
.50525 .29903 Mdot
.53068 .71781 Mdot
.34596 .61785 Mdot
.6839 .37038 Mdot
.50537 .73973 Mdot
.3717 .66899 Mdot
.37823 .35303 Mdot
.59429 .67693 Mdot
.6393 .33873 Mdot
.69781 .59326 Mdot
.51468 .28534 Mdot
.66512 .60655 Mdot
.69389 .59315 Mdot
.71819 .51071 Mdot
.67103 .35577 Mdot
.59475 .67267 Mdot
.64842 .33332 Mdot
.67521 .62788 Mdot
.37628 .67835 Mdot
.72487 .4674 Mdot
.39984 .30593 Mdot
.65693 .61444 Mdot
.7077 .5122 Mdot
.64622 .6389 Mdot
.70695 .47985 Mdot
.39871 .68297 Mdot
.39154 .67916 Mdot
.51083 .71058 Mdot
.40787 .30862 Mdot
.34298 .61962 Mdot
.31795 .3798 Mdot
.27872 .50375 Mdot
.66292 .61928 Mdot
.32369 .39463 Mdot
.55546 .71584 Mdot
.305 .42995 Mdot
.3427 .6279 Mdot
.35055 .60427 Mdot
.62395 .67469 Mdot
.46474 .7371 Mdot
.41637 .30263 Mdot
.72986 .47649 Mdot
.37005 .66964 Mdot
.43222 .29031 Mdot
.4249 .70664 Mdot
.51202 .73179 Mdot
.36242 .65559 Mdot
.51251 .28436 Mdot
.69264 .60187 Mdot
.31891 .38252 Mdot
.69847 .47331 Mdot
.35246 .6289 Mdot
.30112 .43387 Mdot
.29744 .51975 Mdot
.35088 .60714 Mdot
.69478 .49269 Mdot
.60135 .6733 Mdot
.70557 .51683 Mdot
.69997 .52804 Mdot
.41054 .69772 Mdot
.68428 .60903 Mdot
.71879 .51343 Mdot
.61804 .67623 Mdot
.42909 .30216 Mdot
.59234 .29977 Mdot
.42905 .7275 Mdot
.29365 .5078 Mdot
.40896 .681 Mdot
.30192 .45973 Mdot
.30845 .39422 Mdot
.32472 .40681 Mdot
.42156 .71077 Mdot
.48376 .26314 Mdot
.30388 .45457 Mdot
.41247 .30553 Mdot
.7137 .56235 Mdot
.69318 .61953 Mdot
.60771 .32471 Mdot
.38922 .33101 Mdot
.328 .40431 Mdot
.38174 .67462 Mdot
.48403 .73419 Mdot
.61871 .31344 Mdot
.70857 .57599 Mdot
.42664 .72467 Mdot
.35439 .39095 Mdot
.56267 .30064 Mdot
.50028 .29326 Mdot
.59358 .31399 Mdot
.64742 .64065 Mdot
.33787 .59521 Mdot
.3553 .38866 Mdot
.58113 .68164 Mdot
.32039 .39233 Mdot
.33174 .37315 Mdot
.47284 .26507 Mdot
.34224 .60701 Mdot
.56017 .71738 Mdot
.55292 .29827 Mdot
.30289 .4694 Mdot
.70847 .579 Mdot
.29092 .51994 Mdot
.64433 .33311 Mdot
.66453 .62636 Mdot
.53162 .28022 Mdot
.33868 .40622 Mdot
.33754 .61445 Mdot
.69086 .59332 Mdot
.69229 .58056 Mdot
.6789 .60756 Mdot
.28174 .50126 Mdot
.53043 .26981 Mdot
.39511 .31516 Mdot
.397 .6777 Mdot
.71116 .52944 Mdot
.29411 .5562 Mdot
.40835 .68219 Mdot
.67215 .40471 Mdot
.59811 .67919 Mdot
.73571 .49267 Mdot
.58746 .68053 Mdot
.67173 .63162 Mdot
.50976 .29625 Mdot
.34197 .57848 Mdot
.39921 .68572 Mdot
.41802 .71777 Mdot
.30271 .47988 Mdot
.70003 .4928 Mdot
.4532 .73307 Mdot
.43995 .74147 Mdot
.39898 .70157 Mdot
.35692 .61016 Mdot
.39081 .70013 Mdot
.30285 .39336 Mdot
.34167 .39809 Mdot
.53633 .73133 Mdot
.362 .63924 Mdot
.69464 .50856 Mdot
.6807 .62005 Mdot
.57005 .70288 Mdot
.69296 .38258 Mdot
.65564 .61352 Mdot
.55519 .29928 Mdot
.56762 .30473 Mdot
.43389 .28685 Mdot
.26637 .52499 Mdot
.61696 .67022 Mdot
.33383 .57755 Mdot
.69183 .37726 Mdot
.29223 .49602 Mdot
.70442 .5333 Mdot
.29432 .46407 Mdot
.51189 .72129 Mdot
.27807 .52116 Mdot
.36974 .36387 Mdot
.64387 .34882 Mdot
.605 .69221 Mdot
.30571 .48302 Mdot
.67803 .60408 Mdot
.42492 .72428 Mdot
.40149 .69819 Mdot
.7334 .45746 Mdot
.2796 .47733 Mdot
.39198 .31712 Mdot
.41935 .69873 Mdot
.45026 .74354 Mdot
.69191 .38775 Mdot
.28216 .52105 Mdot
.67012 .40652 Mdot
.60379 .68271 Mdot
.70861 .59936 Mdot
.71897 .48967 Mdot
.61558 .32995 Mdot
.51412 .73189 Mdot
.27475 .52397 Mdot
.5306 .28189 Mdot
.54216 .70482 Mdot
.42078 .30006 Mdot
.29791 .4287 Mdot
.40798 .7127 Mdot
.42384 .31163 Mdot
.36907 .66782 Mdot
.61329 .32006 Mdot
.34667 .58536 Mdot
.58904 .68188 Mdot
.43402 .7138 Mdot
.54543 .30323 Mdot
.53041 .28715 Mdot
.41348 .30224 Mdot
.4285 .73484 Mdot
.364 .66263 Mdot
.6927 .58749 Mdot
.52365 .26766 Mdot
.72666 .5028 Mdot
.71433 .47833 Mdot
.47215 .26755 Mdot
.70056 .51241 Mdot
.29227 .46738 Mdot
.43679 .71534 Mdot
.6126 .3195 Mdot
.60445 .3187 Mdot
.52599 .27957 Mdot
.46827 .27496 Mdot
.50986 .28339 Mdot
.60042 .67974 Mdot
.71584 .52279 Mdot
.45727 .73574 Mdot
.35695 .63653 Mdot
.35211 .59364 Mdot
.6903 .60002 Mdot
.52231 .7348 Mdot
.32098 .57153 Mdot
.27607 .48824 Mdot
.52338 .29457 Mdot
.67694 .41629 Mdot
.64427 .65546 Mdot
.68771 .37224 Mdot
.41247 .70324 Mdot
.599 .30137 Mdot
.70546 .57361 Mdot
.27437 .51962 Mdot
.60165 .68843 Mdot
.26545 .50972 Mdot
.6957 .41426 Mdot
.69156 .58252 Mdot
.52127 .71916 Mdot
.41731 .70374 Mdot
.52995 .72529 Mdot
.30604 .43677 Mdot
.66386 .63259 Mdot
.67285 .39106 Mdot
.60903 .69169 Mdot
.3043 .42733 Mdot
.58442 .6911 Mdot
.41003 .72075 Mdot
.37234 .64771 Mdot
.39227 .6983 Mdot
.38897 .67168 Mdot
.67788 .61256 Mdot
.51149 .72819 Mdot
.3448 .40081 Mdot
.39537 .68197 Mdot
.65268 .35027 Mdot
.33695 .61756 Mdot
.35426 .59761 Mdot
.33318 .59837 Mdot
.37357 .6584 Mdot
.65312 .61794 Mdot
.62694 .67791 Mdot
.68645 .37364 Mdot
.44547 .74005 Mdot
.61435 .33378 Mdot
.51871 .27805 Mdot
.3771 .3568 Mdot
.67718 .61667 Mdot
.26588 .50871 Mdot
.63278 .31687 Mdot
.45012 .73861 Mdot
.43311 .28559 Mdot
.38469 .66575 Mdot
.37425 .35488 Mdot
.31544 .3845 Mdot
.27412 .52518 Mdot
.50116 .2991 Mdot
.68565 .40525 Mdot
.36846 .65598 Mdot
.72908 .49794 Mdot
.71124 .50448 Mdot
.39979 .6892 Mdot
.70206 .41015 Mdot
.61722 .32819 Mdot
.4139 .31187 Mdot
.33841 .59614 Mdot
.3917 .67845 Mdot
.70139 .52047 Mdot
.38963 .32622 Mdot
.54703 .7184 Mdot
.29154 .48148 Mdot
.32782 .57314 Mdot
.3469 .39982 Mdot
.51522 .72733 Mdot
.68762 .37651 Mdot
.3353 .37632 Mdot
.33044 .58334 Mdot
.45202 .73003 Mdot
.58612 .6778 Mdot
.27868 .54361 Mdot
.51968 .26326 Mdot
.41104 .69573 Mdot
.4118 .6892 Mdot
.68144 .59849 Mdot
.60402 .31274 Mdot
.72994 .48124 Mdot
.7035 .56358 Mdot
.32547 .40629 Mdot
.60147 .30888 Mdot
.36154 .60237 Mdot
.63701 .33161 Mdot
.59753 .679 Mdot
.4207 .72755 Mdot
.67335 .39018 Mdot
.69756 .52095 Mdot
.70657 .54558 Mdot
.41385 .70967 Mdot
.61041 .68548 Mdot
.40966 .68196 Mdot
.39366 .32551 Mdot
.37512 .35832 Mdot
.41659 .7036 Mdot
.70768 .49809 Mdot
.4048 .68 Mdot
.69616 .41084 Mdot
.30682 .48742 Mdot
.7149 .49682 Mdot
.43029 .30419 Mdot
.50332 .29685 Mdot
.50388 .26305 Mdot
.36746 .36368 Mdot
.60857 .66757 Mdot
.67013 .60303 Mdot
.73701 .48411 Mdot
.52943 .72829 Mdot
.52592 .29571 Mdot
.28318 .49011 Mdot
.39248 .66325 Mdot
.34364 .40393 Mdot
.63626 .34237 Mdot
.71122 .54874 Mdot
.54306 .70963 Mdot
.28446 .52503 Mdot
.4857 .73362 Mdot
.3308 .39778 Mdot
.34389 .59967 Mdot
.27904 .52252 Mdot
.46988 .27774 Mdot
.58379 .683 Mdot
.30617 .38538 Mdot
.41943 .30253 Mdot
.50675 .30217 Mdot
.61705 .33272 Mdot
.53181 .26815 Mdot
.26393 .50879 Mdot
.32409 .4122 Mdot
.7151 .50233 Mdot
.34682 .61022 Mdot
.33751 .39307 Mdot
.50853 .29137 Mdot
.35953 .3652 Mdot
.3618 .61111 Mdot
.703 .47166 Mdot
.51736 .27335 Mdot
.40779 .68486 Mdot
.59299 .67452 Mdot
.66291 .62369 Mdot
.42341 .30605 Mdot
.5217 .73172 Mdot
.26935 .48167 Mdot
.4587 .28904 Mdot
.541 .303 Mdot
.40513 .69714 Mdot
.272 .50569 Mdot
.35738 .62817 Mdot
.682 .40872 Mdot
.48855 .73087 Mdot
.60335 .31438 Mdot
.38215 .65955 Mdot
.38846 .66561 Mdot
.49143 .72464 Mdot
.69475 .624 Mdot
.38083 .3426 Mdot
.38022 .6542 Mdot
.36329 .61929 Mdot
.72523 .46879 Mdot
.55659 .72444 Mdot
.47371 .73199 Mdot
.69058 .60744 Mdot
.30069 .51106 Mdot
.69427 .38967 Mdot
.39613 .66636 Mdot
.64302 .32762 Mdot
.27984 .49638 Mdot
.39325 .69097 Mdot
.54906 .70758 Mdot
.72566 .48205 Mdot
.33422 .57946 Mdot
.72118 .49377 Mdot
.42882 .72981 Mdot
.65562 .62186 Mdot
.60071 .32278 Mdot
.37794 .66705 Mdot
.3213 .41316 Mdot
.42867 .2918 Mdot
.38645 .69315 Mdot
.28402 .47967 Mdot
.58848 .68322 Mdot
.3247 .40412 Mdot
.6778 .4111 Mdot
.58475 .29884 Mdot
.50961 .28444 Mdot
.69453 .37079 Mdot
.66104 .61263 Mdot
.41676 .30834 Mdot
.36006 .37016 Mdot
.58204 .68252 Mdot
.28067 .46668 Mdot
.60228 .30779 Mdot
.36168 .62084 Mdot
.34082 .58696 Mdot
.40449 .31453 Mdot
.57161 .29881 Mdot
.71333 .46278 Mdot
.65748 .62514 Mdot
.68893 .58419 Mdot
.30298 .47404 Mdot
.42308 .30457 Mdot
.3379 .57621 Mdot
.34129 .61373 Mdot
.46214 .2845 Mdot
.69186 .60192 Mdot
.27812 .50708 Mdot
.35685 .36027 Mdot
.69316 .37798 Mdot
.43296 .29391 Mdot
.71523 .49836 Mdot
.44077 .29463 Mdot
.3932 .31836 Mdot
.6475 .63029 Mdot
.38423 .67264 Mdot
.68137 .40386 Mdot
.44357 .2956 Mdot
.73672 .4925 Mdot
.41396 .70543 Mdot
.31737 .39174 Mdot
.3665 .36445 Mdot
.67986 .62902 Mdot
.5259 .27633 Mdot
.27126 .50105 Mdot
.40298 .71224 Mdot
.27231 .53108 Mdot
.69365 .59596 Mdot
.48928 .26862 Mdot
.33116 .38171 Mdot
.67831 .42002 Mdot
.40425 .67862 Mdot
.27956 .50215 Mdot
.68151 .40171 Mdot
.34148 .40162 Mdot
.44369 .72793 Mdot
.48325 .72674 Mdot
.60029 .66897 Mdot
.68969 .38638 Mdot
.53907 .72291 Mdot
.33568 .61995 Mdot
.61376 .32039 Mdot
.3064 .50451 Mdot
.42488 .29311 Mdot
.50377 .73572 Mdot
.59281 .31382 Mdot
.45892 .28377 Mdot
.5413 .2727 Mdot
.38314 .33292 Mdot
.41675 .30256 Mdot
.62202 .33279 Mdot
.33033 .38896 Mdot
.41037 .30264 Mdot
.60404 .31328 Mdot
.50596 .72498 Mdot
.39509 .66628 Mdot
.56864 .7067 Mdot
.33692 .40652 Mdot
.35051 .3801 Mdot
.69256 .61075 Mdot
.6221 .68947 Mdot
.32731 .38507 Mdot
.36496 .63787 Mdot
.68631 .58315 Mdot
.67151 .39195 Mdot
.29595 .55834 Mdot
.69952 .38441 Mdot
.58372 .68154 Mdot
.52877 .30771 Mdot
.41778 .30944 Mdot
.34779 .61003 Mdot
.61867 .30506 Mdot
.2997 .55892 Mdot
.39728 .66704 Mdot
.60158 .68845 Mdot
.38294 .6545 Mdot
.39623 .68371 Mdot
.66534 .59311 Mdot
.35393 .38718 Mdot
.67725 .59045 Mdot
.67857 .40193 Mdot
.30687 .49002 Mdot
.3807 .34686 Mdot
.69139 .3854 Mdot
.34491 .62524 Mdot
.3766 .35955 Mdot
.35464 .61302 Mdot
.36797 .64383 Mdot
.43783 .74243 Mdot
.26644 .53317 Mdot
.51045 .27855 Mdot
.26568 .50324 Mdot
.70274 .49793 Mdot
.70399 .55384 Mdot
.28199 .48361 Mdot
.5389 .70544 Mdot
.55091 .71638 Mdot
.56852 .29413 Mdot
.711 .50364 Mdot
.2971 .46052 Mdot
.69456 .39895 Mdot
.49089 .74006 Mdot
.51341 .7118 Mdot
.68815 .36846 Mdot
.35852 .60616 Mdot
.73757 .48414 Mdot
.69375 .60623 Mdot
.59961 .30597 Mdot
.73739 .48746 Mdot
.53995 .72093 Mdot
.60517 .68215 Mdot
.68901 .37661 Mdot
.37759 .65204 Mdot
.60126 .31313 Mdot
.38588 .69741 Mdot
.60768 .68753 Mdot
.71492 .49454 Mdot
.37884 .6769 Mdot
.69434 .5156 Mdot
.34703 .386 Mdot
.44227 .74218 Mdot
.2833 .48722 Mdot
.53266 .72391 Mdot
.42969 .30914 Mdot
.71231 .57736 Mdot
.73258 .48958 Mdot
.69488 .41939 Mdot
.72066 .47985 Mdot
.70366 .60136 Mdot
.68422 .36342 Mdot
.65647 .60841 Mdot
.35128 .62843 Mdot
.70489 .55103 Mdot
.66779 .60544 Mdot
.67863 .39014 Mdot
.28757 .49592 Mdot
.68198 .60641 Mdot
.39545 .32012 Mdot
.40772 .69203 Mdot
.49067 .28012 Mdot
.28708 .46526 Mdot
.67723 .61604 Mdot
.28446 .48182 Mdot
.50547 .28732 Mdot
.37385 .35426 Mdot
.62856 .34427 Mdot
.62932 .32066 Mdot
.32103 .37437 Mdot
.59349 .31109 Mdot
.70425 .48578 Mdot
.43199 .29881 Mdot
.37501 .65112 Mdot
.33767 .59854 Mdot
.28725 .46389 Mdot
.70917 .47408 Mdot
.63481 .32259 Mdot
.32342 .39314 Mdot
.70037 .59429 Mdot
.68163 .41998 Mdot
.41587 .31318 Mdot
.55921 .71922 Mdot
.61381 .33128 Mdot
.33992 .40545 Mdot
.33006 .40036 Mdot
.35667 .61306 Mdot
.40164 .70147 Mdot
.29146 .51306 Mdot
.41849 .29632 Mdot
.62986 .68961 Mdot
.46736 .27402 Mdot
.33249 .60523 Mdot
.63271 .68164 Mdot
.35812 .64387 Mdot
.26467 .49967 Mdot
.62198 .33592 Mdot
.71523 .50658 Mdot
.30886 .46397 Mdot
.50035 .29618 Mdot
.51769 .739 Mdot
.39601 .68982 Mdot
.54241 .72536 Mdot
.55842 .2991 Mdot
.71252 .47485 Mdot
.52153 .2834 Mdot
.61577 .32179 Mdot
.28739 .47145 Mdot
.59976 .67688 Mdot
.33448 .40879 Mdot
.50976 .26823 Mdot
.66814 .38797 Mdot
.43266 .30305 Mdot
.58466 .3008 Mdot
.32574 .40532 Mdot
.54436 .7316 Mdot
.56098 .29219 Mdot
.3155 .39109 Mdot
.68998 .61926 Mdot
.45628 .7449 Mdot
.67619 .63385 Mdot
.54162 .28225 Mdot
.28781 .55101 Mdot
.67978 .39835 Mdot
.59398 .32191 Mdot
.37764 .68292 Mdot
.30715 .56239 Mdot
.40494 .71663 Mdot
.6449 .34393 Mdot
.61059 .31827 Mdot
.68729 .38838 Mdot
.51926 .28496 Mdot
.69618 .50943 Mdot
.57376 .69557 Mdot
.55412 .28967 Mdot
.37538 .64906 Mdot
.70462 .53319 Mdot
.50646 .71271 Mdot
.54659 .27969 Mdot
.62043 .67542 Mdot
.65939 .6311 Mdot
.2954 .46017 Mdot
.41424 .71935 Mdot
.61536 .32926 Mdot
.4036 .67369 Mdot
.64691 .32841 Mdot
.5138 .28831 Mdot
.33652 .37269 Mdot
.68082 .42642 Mdot
.34461 .58884 Mdot
.33575 .60837 Mdot
.34387 .62782 Mdot
.27802 .47524 Mdot
.68382 .62319 Mdot
.43431 .72123 Mdot
.44067 .71958 Mdot
.63651 .68456 Mdot
.39497 .32987 Mdot
.26467 .51188 Mdot
.45484 .72948 Mdot
.44793 .28183 Mdot
.69762 .60366 Mdot
.36286 .6077 Mdot
.62155 .33883 Mdot
.62492 .68699 Mdot
.67852 .38031 Mdot
.67209 .41407 Mdot
.45164 .29276 Mdot
.70698 .49135 Mdot
.63066 .67049 Mdot
.50229 .25986 Mdot
.69353 .62577 Mdot
.63241 .67494 Mdot
.65098 .62222 Mdot
.69955 .40665 Mdot
.31118 .56573 Mdot
.61685 .33905 Mdot
.36732 .36572 Mdot
.6592 .60956 Mdot
.70534 .5387 Mdot
.51719 .72832 Mdot
.72816 .5072 Mdot
.40585 .31326 Mdot
.66983 .6013 Mdot
.38437 .33795 Mdot
.69377 .58043 Mdot
.68132 .39365 Mdot
.59948 .31029 Mdot
.62322 .67138 Mdot
.3522 .62594 Mdot
.52932 .71451 Mdot
.3229 .39305 Mdot
.54344 .73109 Mdot
.55227 .298 Mdot
.39654 .31648 Mdot
.64396 .34677 Mdot
.66133 .59914 Mdot
.68997 .36653 Mdot
.33522 .60817 Mdot
.60572 .68673 Mdot
.39101 .678 Mdot
.60621 .32589 Mdot
.57896 .68452 Mdot
.35993 .63599 Mdot
.61742 .67049 Mdot
.56217 .30478 Mdot
.4643 .27291 Mdot
.64662 .64208 Mdot
.44565 .29253 Mdot
.35958 .61216 Mdot
.29861 .47869 Mdot
.26434 .52283 Mdot
.40755 .70468 Mdot
.45271 .28967 Mdot
.54603 .71769 Mdot
.36227 .62318 Mdot
.49211 .73364 Mdot
.56335 .30226 Mdot
.36571 .37657 Mdot
.51282 .29367 Mdot
.65204 .61755 Mdot
.32078 .37822 Mdot
.54065 .29995 Mdot
.55707 .71319 Mdot
.33515 .39699 Mdot
.42949 .29229 Mdot
.27807 .49817 Mdot
.35811 .64202 Mdot
.32148 .56797 Mdot
.54022 .27417 Mdot
.68589 .39756 Mdot
.6732 .6134 Mdot
.6821 .37496 Mdot
.45831 .27795 Mdot
.39039 .68722 Mdot
.34726 .39269 Mdot
.58366 .30444 Mdot
.63967 .67957 Mdot
.2959 .48785 Mdot
.61843 .34047 Mdot
.61553 .66523 Mdot
.40114 .69754 Mdot
.30261 .55933 Mdot
.34758 .59147 Mdot
.39831 .31396 Mdot
.60345 .30813 Mdot
.27472 .53777 Mdot
.34603 .61289 Mdot
.48562 .27722 Mdot
.26778 .52989 Mdot
.35874 .61823 Mdot
.42764 .30698 Mdot
.4128 .68952 Mdot
.2806 .52162 Mdot
.67847 .59968 Mdot
.4811 .72694 Mdot
.3088 .44706 Mdot
.30892 .46504 Mdot
.39946 .70957 Mdot
.38735 .6668 Mdot
.41173 .29979 Mdot
.72467 .48147 Mdot
.41479 .70011 Mdot
.2835 .46677 Mdot
.68859 .5793 Mdot
.66442 .60714 Mdot
.58498 .67904 Mdot
.67636 .42142 Mdot
.5199 .27508 Mdot
.29161 .50737 Mdot
.39017 .32443 Mdot
.39674 .66895 Mdot
.58873 .68603 Mdot
.27827 .48619 Mdot
.67158 .40236 Mdot
.6071 .67015 Mdot
.687 .43127 Mdot
.44546 .7383 Mdot
.60947 .33562 Mdot
.36492 .61174 Mdot
.37843 .67352 Mdot
.67559 .59583 Mdot
.65131 .34169 Mdot
.59135 .3142 Mdot
.5005 .29458 Mdot
.33122 .38224 Mdot
.7052 .55262 Mdot
.28076 .50145 Mdot
.56891 .69793 Mdot
.35005 .59565 Mdot
.33893 .57611 Mdot
.673 .59868 Mdot
.39268 .68412 Mdot
.68085 .58121 Mdot
.39415 .32319 Mdot
.30762 .5638 Mdot
.71859 .5019 Mdot
.72671 .48491 Mdot
.64351 .67032 Mdot
.43207 .28855 Mdot
.7093 .58012 Mdot
.39761 .66666 Mdot
.4633 .27424 Mdot
.27837 .5432 Mdot
.28358 .50785 Mdot
.27293 .53681 Mdot
.71073 .57914 Mdot
.56296 .70922 Mdot
.59719 .67502 Mdot
.42213 .70996 Mdot
.48926 .73497 Mdot
.61516 .3203 Mdot
.43603 .72035 Mdot
.32505 .39719 Mdot
.51152 .29088 Mdot
.36922 .66469 Mdot
.36472 .64101 Mdot
.71635 .5079 Mdot
.30891 .48362 Mdot
.68142 .36563 Mdot
.31599 .38835 Mdot
.53961 .27299 Mdot
.29595 .47113 Mdot
.69881 .50778 Mdot
.38266 .68741 Mdot
.30437 .41071 Mdot
.35917 .38295 Mdot
.35846 .60789 Mdot
.41184 .69651 Mdot
.30576 .42154 Mdot
.68366 .38138 Mdot
.49699 .29294 Mdot
.31212 .39093 Mdot
.53514 .72187 Mdot
.49293 .73337 Mdot
.33917 .60958 Mdot
.69417 .52288 Mdot
.6673 .3919 Mdot
.34985 .38461 Mdot
.44094 .29585 Mdot
.39205 .6626 Mdot
.51156 .71517 Mdot
.30645 .43311 Mdot
.32733 .39343 Mdot
.57291 .69534 Mdot
.26765 .51264 Mdot
.60881 .68768 Mdot
.44767 .73856 Mdot
.51677 .73567 Mdot
.34893 .58732 Mdot
.46876 .27998 Mdot
.68638 .41635 Mdot
.31191 .38048 Mdot
.52439 .29399 Mdot
.6648 .60729 Mdot
.42124 .70975 Mdot
.71489 .47616 Mdot
.73384 .48099 Mdot
.69874 .6115 Mdot
.69656 .38878 Mdot
.71118 .55263 Mdot
.30727 .42048 Mdot
.34164 .59398 Mdot
.61139 .3133 Mdot
.71073 .58469 Mdot
.49799 .7308 Mdot
.70432 .57306 Mdot
.70187 .48719 Mdot
.49779 .73289 Mdot
.61001 .67582 Mdot
.44523 .72701 Mdot
.37184 .6469 Mdot
.2683 .50422 Mdot
.71221 .53164 Mdot
.50688 .71695 Mdot
.41179 .72228 Mdot
.34511 .6068 Mdot
.62578 .67289 Mdot
.26993 .53346 Mdot
.38651 .67036 Mdot
.34668 .5954 Mdot
.45712 .73227 Mdot
.5015 .73148 Mdot
.72081 .46789 Mdot
.63218 .34607 Mdot
.58573 .67646 Mdot
.46154 .2888 Mdot
.6889 .59259 Mdot
.30404 .45613 Mdot
.7056 .56791 Mdot
.60959 .66323 Mdot
.69109 .40131 Mdot
.73557 .49201 Mdot
.50971 .27198 Mdot
.68499 .40168 Mdot
.60132 .31335 Mdot
.62575 .67557 Mdot
.48194 .28738 Mdot
.30434 .50453 Mdot
.61595 .33355 Mdot
.58082 .68696 Mdot
.68217 .39365 Mdot
.64833 .63487 Mdot
.54765 .72979 Mdot
.44661 .73468 Mdot
.33601 .38472 Mdot
.30519 .389 Mdot
.61749 .32462 Mdot
.29073 .48421 Mdot
.61032 .66858 Mdot
.67867 .60857 Mdot
.29389 .48728 Mdot
.66715 .62929 Mdot
.41784 .31294 Mdot
.69678 .59924 Mdot
.40364 .31693 Mdot
.7234 .51295 Mdot
.4117 .71708 Mdot
.31114 .4679 Mdot
.30499 .42401 Mdot
.51618 .71731 Mdot
.33596 .37838 Mdot
.37111 .6533 Mdot
.62153 .66717 Mdot
.35051 .62879 Mdot
.4274 .28597 Mdot
.29779 .45557 Mdot
.67006 .59841 Mdot
.38004 .34973 Mdot
.6712 .38405 Mdot
.53934 .72563 Mdot
.33072 .37507 Mdot
.60917 .68589 Mdot
.6858 .57921 Mdot
.71115 .51615 Mdot
.65249 .62066 Mdot
.4506 .28784 Mdot
.37765 .34417 Mdot
.3393 .61517 Mdot
.37853 .35097 Mdot
.60947 .31951 Mdot
.59379 .30476 Mdot
.49701 .27514 Mdot
.31422 .56322 Mdot
.52886 .29454 Mdot
.28153 .54444 Mdot
.71866 .51643 Mdot
.2993 .50581 Mdot
.34615 .62364 Mdot
.68671 .60724 Mdot
.5745 .69687 Mdot
.30988 .48536 Mdot
.26573 .51191 Mdot
.59458 .30767 Mdot
.61041 .31021 Mdot
.35013 .36886 Mdot
.50295 .73145 Mdot
.49472 .72799 Mdot
.34074 .58233 Mdot
.62112 .32659 Mdot
.61136 .68173 Mdot
.62662 .34481 Mdot
.60352 .69032 Mdot
.29809 .45482 Mdot
.53444 .30356 Mdot
.57082 .29544 Mdot
.68976 .59642 Mdot
.42254 .7111 Mdot
.69574 .61737 Mdot
.4542 .73807 Mdot
.5828 .29998 Mdot
.30978 .49248 Mdot
.51305 .28125 Mdot
.64745 .34414 Mdot
.53021 .30286 Mdot
.29907 .44608 Mdot
.57175 .7085 Mdot
.69304 .42181 Mdot
.54638 .72649 Mdot
.47538 .26658 Mdot
.37217 .65532 Mdot
.30956 .40489 Mdot
.3765 .35949 Mdot
.64032 .67069 Mdot
.66552 .62524 Mdot
.26756 .50163 Mdot
.34537 .6232 Mdot
.64863 .62714 Mdot
.34471 .62129 Mdot
.34335 .61968 Mdot
.36792 .64812 Mdot
.60839 .32532 Mdot
.55058 .72443 Mdot
.35218 .62718 Mdot
.41666 .30053 Mdot
.27299 .54148 Mdot
.56476 .29519 Mdot
.67709 .59421 Mdot
.29227 .496 Mdot
.69218 .59072 Mdot
.52966 .71744 Mdot
.70242 .39676 Mdot
.68072 .62453 Mdot
.61807 .67943 Mdot
.71103 .57526 Mdot
.59242 .3194 Mdot
.2728 .49865 Mdot
.32676 .39956 Mdot
.67458 .35995 Mdot
.41228 .30566 Mdot
.32396 .38442 Mdot
.4239 .30831 Mdot
.35862 .59994 Mdot
.71315 .50116 Mdot
.33119 .38112 Mdot
.66613 .39635 Mdot
.4717 .26644 Mdot
.44906 .74492 Mdot
.40081 .6796 Mdot
.55666 .29837 Mdot
.33453 .38926 Mdot
.53242 .72313 Mdot
.55669 .71848 Mdot
.47644 .26558 Mdot
.67967 .36289 Mdot
.61031 .32188 Mdot
.28733 .49976 Mdot
.70983 .47472 Mdot
.71464 .51213 Mdot
.67054 .39297 Mdot
.62277 .30728 Mdot
.40025 .68375 Mdot
.40608 .68304 Mdot
.51736 .72265 Mdot
.37374 .65817 Mdot
.43914 .29706 Mdot
.3197 .391 Mdot
.72999 .49474 Mdot
.62531 .66803 Mdot
.61715 .69416 Mdot
.34144 .6219 Mdot
.38738 .68253 Mdot
.53032 .27522 Mdot
.60119 .68682 Mdot
.28259 .52075 Mdot
.70504 .55482 Mdot
.41394 .69177 Mdot
.30075 .45301 Mdot
.71841 .51216 Mdot
.42667 .29339 Mdot
.68601 .39583 Mdot
.49105 .26036 Mdot
.49675 .25974 Mdot
.30085 .43999 Mdot
.68743 .59457 Mdot
.3237 .38491 Mdot
.4368 .30323 Mdot
.37276 .36144 Mdot
.26799 .51752 Mdot
.41117 .71027 Mdot
.40574 .31171 Mdot
.57104 .303 Mdot
.6876 .42539 Mdot
.44039 .73654 Mdot
.32697 .58515 Mdot
.59097 .31157 Mdot
.35393 .60685 Mdot
.28034 .48453 Mdot
.621 .3179 Mdot
.7351 .48943 Mdot
.27 .50387 Mdot
.62704 .33798 Mdot
.71099 .51346 Mdot
.62371 .67501 Mdot
.49789 .73018 Mdot
.67006 .61199 Mdot
.70047 .51463 Mdot
.39933 .68376 Mdot
.45198 .29332 Mdot
.72366 .49976 Mdot
.66334 .61647 Mdot
.64959 .62008 Mdot
.49327 .26502 Mdot
.26813 .52773 Mdot
.69105 .42067 Mdot
.35654 .63009 Mdot
.53383 .3055 Mdot
.29955 .49275 Mdot
.7347 .49802 Mdot
.34433 .63276 Mdot
.39786 .66996 Mdot
.29646 .48478 Mdot
.26314 .51208 Mdot
.29178 .4863 Mdot
.59826 .31223 Mdot
.61977 .67703 Mdot
.67409 .58817 Mdot
.59143 .31626 Mdot
.29271 .4627 Mdot
.30235 .44862 Mdot
.38324 .34046 Mdot
.4027 .68453 Mdot
.26574 .49526 Mdot
.70918 .55106 Mdot
.56483 .71691 Mdot
.37309 .36112 Mdot
.28516 .55063 Mdot
.42071 .28987 Mdot
.2818 .54726 Mdot
.68861 .41404 Mdot
.61301 .69126 Mdot
.28118 .50901 Mdot
.33385 .40264 Mdot
.40029 .68087 Mdot
.39078 .67241 Mdot
.29757 .47714 Mdot
.38295 .66676 Mdot
.70961 .50815 Mdot
.68512 .6291 Mdot
.29394 .49336 Mdot
.4768 .27311 Mdot
.56025 .29578 Mdot
.53389 .28878 Mdot
.34134 .60531 Mdot
.4954 .71621 Mdot
.49297 .73902 Mdot
.65102 .61929 Mdot
.60561 .31118 Mdot
.71843 .51426 Mdot
.70429 .54923 Mdot
.6655 .60372 Mdot
.46879 .26814 Mdot
.29037 .48443 Mdot
.69417 .52075 Mdot
.59849 .30914 Mdot
.61811 .32644 Mdot
.551 .28122 Mdot
.52546 .29662 Mdot
.53079 .28083 Mdot
.68071 .61418 Mdot
.73929 .46502 Mdot
.52997 .73523 Mdot
.73425 .48223 Mdot
.44474 .28065 Mdot
.39531 .32301 Mdot
.54849 .2798 Mdot
.67646 .39017 Mdot
.69913 .52738 Mdot
.40974 .68776 Mdot
.32189 .57192 Mdot
.56187 .29806 Mdot
.28064 .47581 Mdot
.71218 .54641 Mdot
.30669 .56155 Mdot
.59777 .69147 Mdot
.67382 .40948 Mdot
.34064 .39583 Mdot
.33821 .62131 Mdot
.50137 .29341 Mdot
.28635 .5489 Mdot
.35656 .38258 Mdot
.53331 .72974 Mdot
.71256 .56117 Mdot
.68566 .40905 Mdot
.55748 .72355 Mdot
.31383 .41035 Mdot
.63319 .67051 Mdot
.62038 .31846 Mdot
.51447 .26796 Mdot
.38596 .33253 Mdot
.69146 .61158 Mdot
.42161 .71486 Mdot
.3412 .39991 Mdot
.41255 .72451 Mdot
.54261 .29768 Mdot
.27074 .50601 Mdot
.54709 .29355 Mdot
.71948 .46745 Mdot
.50972 .26454 Mdot
.33878 .62411 Mdot
.68138 .58298 Mdot
.61288 .3222 Mdot
.48528 .73663 Mdot
.38156 .348 Mdot
.49162 .27089 Mdot
.30394 .4233 Mdot
.62416 .68918 Mdot
.58351 .67819 Mdot
.31433 .37794 Mdot
.33718 .62275 Mdot
.67359 .38824 Mdot
.67371 .58706 Mdot
.66993 .38542 Mdot
.26639 .52821 Mdot
.67224 .35894 Mdot
.68678 .39558 Mdot
.51881 .70731 Mdot
.27109 .4994 Mdot
.38856 .68366 Mdot
.36246 .63976 Mdot
.67109 .40955 Mdot
.54459 .72269 Mdot
.64816 .62688 Mdot
.55599 .71335 Mdot
.44163 .72483 Mdot
.67189 .39009 Mdot
.3614 .36988 Mdot
.55606 .72095 Mdot
.26671 .53022 Mdot
.62149 .33275 Mdot
.48131 .72783 Mdot
.31766 .39259 Mdot
.29594 .46806 Mdot
.27133 .48847 Mdot
.29134 .4751 Mdot
.34773 .63193 Mdot
.38423 .68492 Mdot
.30942 .46272 Mdot
.6847 .36327 Mdot
.30593 .46199 Mdot
.3059 .51199 Mdot
.64797 .35049 Mdot
.26385 .50957 Mdot
.36236 .62185 Mdot
.60552 .69085 Mdot
.61516 .69079 Mdot
.49381 .28227 Mdot
.66109 .35539 Mdot
.40554 .30675 Mdot
.3347 .57383 Mdot
.72917 .45347 Mdot
.67114 .60273 Mdot
.29617 .41257 Mdot
.4371 .7153 Mdot
.60833 .66503 Mdot
.66287 .61096 Mdot
.52001 .72473 Mdot
.69811 .59625 Mdot
.30922 .40948 Mdot
.33443 .61634 Mdot
.68046 .59553 Mdot
.70828 .59811 Mdot
.38174 .66542 Mdot
.70005 .59392 Mdot
.72513 .51364 Mdot
.60335 .31139 Mdot
.69202 .40999 Mdot
.67299 .38873 Mdot
.51813 .29884 Mdot
.72938 .48592 Mdot
.42012 .70514 Mdot
.50505 .29549 Mdot
.3568 .60337 Mdot
.67131 .39113 Mdot
.40706 .71987 Mdot
.72725 .48453 Mdot
.36334 .63009 Mdot
.52571 .70639 Mdot
.42472 .30957 Mdot
.29666 .48274 Mdot
.65994 .62626 Mdot
.38678 .32959 Mdot
.61637 .33284 Mdot
.74005 .47864 Mdot
.30899 .50008 Mdot
.63671 .67415 Mdot
.32776 .56992 Mdot
.3667 .65472 Mdot
.63633 .67395 Mdot
.56875 .70894 Mdot
.36053 .37793 Mdot
.50152 .2965 Mdot
.49859 .26162 Mdot
.40421 .69147 Mdot
.72607 .48804 Mdot
.27705 .52541 Mdot
.30753 .44833 Mdot
.29994 .39327 Mdot
.54741 .71521 Mdot
.44061 .71966 Mdot
.43053 .73898 Mdot
.42258 .71222 Mdot
.49964 .27861 Mdot
.36622 .37472 Mdot
.52009 .7282 Mdot
.28757 .47324 Mdot
.42135 .70424 Mdot
.67943 .59315 Mdot
.73118 .50886 Mdot
.53372 .27813 Mdot
.63765 .34448 Mdot
.30987 .38859 Mdot
.56085 .29242 Mdot
.40502 .69173 Mdot
.63022 .68832 Mdot
.62664 .32005 Mdot
.70047 .48386 Mdot
.3016 .46983 Mdot
.50585 .29328 Mdot
.30568 .48913 Mdot
.72266 .47968 Mdot
.73442 .4985 Mdot
.39687 .68909 Mdot
.37069 .34799 Mdot
.50864 .26691 Mdot
.33978 .61171 Mdot
.5562 .29907 Mdot
.40725 .31568 Mdot
.62616 .34366 Mdot
.41497 .70098 Mdot
.57242 .69359 Mdot
.67682 .37852 Mdot
.33208 .59782 Mdot
.62357 .68569 Mdot
.60442 .67245 Mdot
.47437 .2719 Mdot
.31042 .45532 Mdot
.30052 .46491 Mdot
.73898 .47336 Mdot
.70534 .44042 Mdot
.4404 .74093 Mdot
.49167 .26671 Mdot
.58101 .68942 Mdot
.68968 .39322 Mdot
.71449 .52069 Mdot
.6997 .43649 Mdot
.67988 .3897 Mdot
.40517 .68611 Mdot
.28162 .48486 Mdot
.70146 .51092 Mdot
.37398 .36126 Mdot
.47517 .74087 Mdot
.30434 .42596 Mdot
.38075 .34325 Mdot
.31403 .39415 Mdot
.70102 .41544 Mdot
.54031 .28434 Mdot
.70206 .57377 Mdot
.66793 .40042 Mdot
.69109 .39632 Mdot
.39286 .31567 Mdot
.66305 .62309 Mdot
.64831 .63887 Mdot
.7115 .55388 Mdot
.41152 .30645 Mdot
.28676 .48667 Mdot
.55185 .71102 Mdot
.53231 .28907 Mdot
.38869 .33355 Mdot
.60051 .3032 Mdot
.59326 .30549 Mdot
.70949 .46253 Mdot
.41012 .68038 Mdot
.64997 .62018 Mdot
.36325 .61343 Mdot
.41271 .71167 Mdot
.67333 .40338 Mdot
.71647 .51919 Mdot
.63773 .32944 Mdot
.40689 .69701 Mdot
.43175 .72637 Mdot
.46133 .27262 Mdot
.32151 .39631 Mdot
.57344 .3011 Mdot
.41488 .70565 Mdot
.53095 .29911 Mdot
.66541 .63478 Mdot
.3269 .40962 Mdot
.51242 .71366 Mdot
.61837 .31128 Mdot
.34857 .38968 Mdot
.31663 .41321 Mdot
.32466 .56912 Mdot
.69669 .59513 Mdot
.73237 .47475 Mdot
.26728 .52477 Mdot
.64106 .34052 Mdot
.63072 .33878 Mdot
.68861 .43052 Mdot
.40596 .68785 Mdot
.61636 .30829 Mdot
.3774 .35587 Mdot
.33221 .59397 Mdot
.62794 .67073 Mdot
.68106 .62166 Mdot
.42557 .73488 Mdot
.59575 .6722 Mdot
.67899 .39617 Mdot
.29932 .43559 Mdot
.44043 .74008 Mdot
.54757 .28671 Mdot
.69555 .49312 Mdot
.69138 .60752 Mdot
.27723 .51445 Mdot
.59965 .32222 Mdot
.31124 .56124 Mdot
.71228 .5223 Mdot
.41445 .68933 Mdot
.68786 .38991 Mdot
.34109 .39732 Mdot
.33701 .38156 Mdot
.29696 .42279 Mdot
.71229 .52766 Mdot
.33657 .4006 Mdot
.70177 .60864 Mdot
.52249 .72225 Mdot
.4104 .70855 Mdot
.69359 .38433 Mdot
.28528 .48728 Mdot
.37959 .35222 Mdot
.41054 .31723 Mdot
.50499 .73064 Mdot
.40208 .70045 Mdot
.6714 .35639 Mdot
.28153 .49109 Mdot
.34609 .62776 Mdot
.36085 .37877 Mdot
.50828 .71009 Mdot
.29571 .55498 Mdot
.32488 .38098 Mdot
.60751 .69624 Mdot
.70253 .49499 Mdot
.33487 .37794 Mdot
.73347 .50664 Mdot
.34247 .62422 Mdot
.53645 .72654 Mdot
.72689 .47114 Mdot
.70713 .54135 Mdot
.3043 .40698 Mdot
.62487 .33987 Mdot
.54353 .72049 Mdot
.36406 .62371 Mdot
.50095 .71481 Mdot
.34471 .38668 Mdot
.67728 .36138 Mdot
.54573 .30508 Mdot
.43788 .29242 Mdot
.43929 .30161 Mdot
.58519 .30136 Mdot
.64215 .34966 Mdot
.38843 .6595 Mdot
.57044 .70221 Mdot
.49702 .71607 Mdot
.69559 .37689 Mdot
.5679 .71354 Mdot
.35229 .62607 Mdot
.35314 .60152 Mdot
.55655 .29947 Mdot
.69608 .41534 Mdot
.5848 .67918 Mdot
.52529 .72762 Mdot
.29518 .45917 Mdot
.73589 .48615 Mdot
.35829 .62442 Mdot
.67427 .35698 Mdot
.47613 .26983 Mdot
.66434 .35351 Mdot
.36081 .61827 Mdot
.32154 .39688 Mdot
.63483 .32817 Mdot
.60748 .31898 Mdot
.47686 .27918 Mdot
.47914 .27871 Mdot
.36315 .62052 Mdot
.68257 .36876 Mdot
.56626 .71247 Mdot
.55354 .71766 Mdot
.33609 .39118 Mdot
.28659 .51487 Mdot
.3707 .65391 Mdot
.64825 .6416 Mdot
.3793 .34643 Mdot
.33969 .60847 Mdot
.72003 .47586 Mdot
.52286 .27908 Mdot
.41735 .31429 Mdot
.72282 .50562 Mdot
.41969 .30927 Mdot
.66445 .35615 Mdot
.40436 .71806 Mdot
.27315 .52204 Mdot
.64518 .66846 Mdot
.30986 .46998 Mdot
.34861 .38681 Mdot
.40419 .68445 Mdot
.44993 .29153 Mdot
.43329 .30861 Mdot
.64401 .65629 Mdot
.68199 .4069 Mdot
.36801 .36473 Mdot
.61366 .67988 Mdot
.30087 .45435 Mdot
.51475 .29043 Mdot
.35237 .36401 Mdot
.41697 .70064 Mdot
.69094 .59392 Mdot
.58593 .68149 Mdot
.33561 .37147 Mdot
.34888 .38135 Mdot
.32068 .37752 Mdot
.62678 .33815 Mdot
.65632 .61634 Mdot
.5971 .30367 Mdot
.41669 .31739 Mdot
.53578 .73423 Mdot
.43108 .72125 Mdot
.72111 .51244 Mdot
.33497 .59094 Mdot
.68363 .37217 Mdot
.70974 .54578 Mdot
.28947 .4891 Mdot
.30975 .41325 Mdot
.64328 .33102 Mdot
.37576 .36112 Mdot
.6363 .67964 Mdot
.61588 .69725 Mdot
.67754 .59266 Mdot
.68368 .42719 Mdot
.36931 .66909 Mdot
.52932 .26588 Mdot
.30208 .46833 Mdot
.59981 .31006 Mdot
.63467 .678 Mdot
.36294 .6415 Mdot
.28349 .48867 Mdot
.59362 .30853 Mdot
.3045 .38609 Mdot
.68155 .36698 Mdot
.30261 .42713 Mdot
.64521 .64956 Mdot
.35787 .61532 Mdot
.31901 .398 Mdot
.66845 .60891 Mdot
.60766 .31355 Mdot
.67888 .61941 Mdot
.30988 .41005 Mdot
.40656 .31821 Mdot
.60131 .30934 Mdot
.42633 .71263 Mdot
.70369 .56819 Mdot
.73772 .46316 Mdot
.65707 .6106 Mdot
.38573 .33813 Mdot
.40007 .31477 Mdot
.53215 .27974 Mdot
.67747 .38855 Mdot
.52331 .30568 Mdot
.27103 .49758 Mdot
.54833 .71039 Mdot
.48383 .27686 Mdot
.65858 .61826 Mdot
.51218 .30226 Mdot
.53227 .70834 Mdot
.6127 .33621 Mdot
.56357 .29725 Mdot
.33954 .59076 Mdot
.62373 .68175 Mdot
.34935 .37798 Mdot
.27285 .53494 Mdot
.52549 .72242 Mdot
.4318 .71358 Mdot
.3229 .40347 Mdot
.36197 .6233 Mdot
.68185 .37169 Mdot
.47005 .72579 Mdot
.50751 .7349 Mdot
.41331 .31325 Mdot
.70958 .53861 Mdot
.49402 .26172 Mdot
.30375 .44702 Mdot
.33556 .60059 Mdot
.36222 .62777 Mdot
.60394 .6789 Mdot
.71143 .54569 Mdot
.60722 .32338 Mdot
.52765 .73627 Mdot
.41706 .30502 Mdot
.68362 .58322 Mdot
.68137 .5867 Mdot
.42589 .72228 Mdot
.31791 .39569 Mdot
.68113 .41956 Mdot
.343 .62832 Mdot
.3705 .36128 Mdot
.43807 .71899 Mdot
.58806 .29953 Mdot
.40006 .31329 Mdot
.42137 .31769 Mdot
.69939 .5786 Mdot
.55949 .2971 Mdot
.60374 .6804 Mdot
.33888 .3974 Mdot
.44004 .3014 Mdot
.60847 .32602 Mdot
.30382 .46869 Mdot
.34813 .59793 Mdot
.38505 .6741 Mdot
.56089 .29918 Mdot
.48674 .28991 Mdot
.565 .71158 Mdot
.66951 .355 Mdot
.36602 .34711 Mdot
.61639 .31794 Mdot
.68054 .59144 Mdot
.37716 .68532 Mdot
.31986 .56968 Mdot
.69442 .39319 Mdot
.63363 .67889 Mdot
.55339 .28858 Mdot
.30149 .4363 Mdot
.66331 .60714 Mdot
.3036 .46962 Mdot
.33538 .58504 Mdot
.67308 .59447 Mdot
.43102 .2979 Mdot
.66488 .59414 Mdot
.32648 .3864 Mdot
.60209 .32896 Mdot
.50645 .28622 Mdot
.69433 .41847 Mdot
.57375 .69355 Mdot
.28803 .48726 Mdot
.42115 .72383 Mdot
.59747 .68862 Mdot
.67764 .62567 Mdot
.61718 .67485 Mdot
.32168 .3742 Mdot
.62264 .67603 Mdot
.68558 .58644 Mdot
.36318 .63856 Mdot
.35284 .58921 Mdot
.39769 .32532 Mdot
.3589 .60941 Mdot
.39252 .66501 Mdot
.52633 .70618 Mdot
.33935 .60192 Mdot
.34255 .61901 Mdot
.41253 .69966 Mdot
.70978 .48012 Mdot
.44037 .72578 Mdot
.70353 .47132 Mdot
.71761 .46283 Mdot
.41957 .31519 Mdot
.29994 .45426 Mdot
.26507 .51897 Mdot
.44328 .73354 Mdot
.38559 .67702 Mdot
.66706 .62409 Mdot
.69537 .52514 Mdot
.61163 .32065 Mdot
.51903 .73477 Mdot
.3864 .34031 Mdot
.38354 .68037 Mdot
.49292 .28112 Mdot
.47832 .27104 Mdot
.36347 .61184 Mdot
.30534 .5614 Mdot
.38622 .66499 Mdot
.52315 .71361 Mdot
.35507 .63602 Mdot
.40892 .7025 Mdot
.49817 .26309 Mdot
.41071 .71558 Mdot
.59791 .67353 Mdot
.69523 .58208 Mdot
.30544 .47728 Mdot
.32718 .38299 Mdot
.53642 .72647 Mdot
.38932 .69936 Mdot
.69385 .60926 Mdot
.60406 .67636 Mdot
.50055 .28882 Mdot
.73283 .4967 Mdot
.51779 .71666 Mdot
.61837 .33575 Mdot
.47294 .74187 Mdot
.67482 .35887 Mdot
.62479 .33151 Mdot
.29742 .4678 Mdot
.51077 .27021 Mdot
.32836 .5875 Mdot
.50375 .29919 Mdot
.40924 .69645 Mdot
.55968 .71887 Mdot
.27529 .52115 Mdot
.67737 .61359 Mdot
.61801 .31145 Mdot
.70568 .49376 Mdot
.64841 .63655 Mdot
.47292 .72486 Mdot
.57174 .30017 Mdot
.51354 .26556 Mdot
.3607 .35567 Mdot
.69798 .61118 Mdot
.39125 .66338 Mdot
.70733 .55721 Mdot
.71306 .49828 Mdot
.69232 .59988 Mdot
.46456 .72845 Mdot
.46317 .73998 Mdot
.41319 .69665 Mdot
.67005 .60608 Mdot
.51583 .27008 Mdot
.2699 .5216 Mdot
.39677 .68276 Mdot
.33994 .39615 Mdot
.69997 .57822 Mdot
.54608 .28386 Mdot
.41631 .72137 Mdot
.52834 .29827 Mdot
.66821 .59642 Mdot
.48225 .26427 Mdot
.62638 .34427 Mdot
.48524 .27617 Mdot
.3694 .65985 Mdot
.35984 .63863 Mdot
.6851 .58547 Mdot
.73443 .4979 Mdot
.63571 .67697 Mdot
.3391 .59501 Mdot
.70856 .57841 Mdot
.45587 .28692 Mdot
.69294 .51136 Mdot
.61047 .66823 Mdot
.39414 .66914 Mdot
.30861 .46354 Mdot
.531 .73671 Mdot
.47093 .729 Mdot
.50573 .73499 Mdot
.28946 .48227 Mdot
.56904 .7014 Mdot
.40958 .7192 Mdot
.38263 .66133 Mdot
.42028 .30245 Mdot
.34232 .58708 Mdot
.32786 .41024 Mdot
.61955 .66396 Mdot
.46819 .74519 Mdot
.63249 .67361 Mdot
.66156 .61411 Mdot
.67327 .59032 Mdot
.45829 .28378 Mdot
.6658 .60558 Mdot
.33766 .40143 Mdot
.68067 .41886 Mdot
.64914 .63564 Mdot
.36664 .3736 Mdot
.35162 .38796 Mdot
.30713 .42045 Mdot
.32237 .38157 Mdot
.36842 .34659 Mdot
.39077 .32027 Mdot
.35344 .38161 Mdot
.70438 .59893 Mdot
.4402 .28913 Mdot
.3082 .50061 Mdot
.68026 .41926 Mdot
.32005 .41272 Mdot
.34213 .5863 Mdot
.60977 .67082 Mdot
.74178 .48372 Mdot
.58361 .30123 Mdot
.31479 .38057 Mdot
.39156 .66765 Mdot
.70446 .58115 Mdot
.35712 .62429 Mdot
.30701 .45396 Mdot
.72639 .4838 Mdot
.51229 .29533 Mdot
.2779 .5197 Mdot
.31045 .39838 Mdot
.29341 .49127 Mdot
.5499 .29734 Mdot
.68921 .36486 Mdot
.33784 .58273 Mdot
.37859 .3541 Mdot
.27988 .47276 Mdot
.3399 .58463 Mdot
.70428 .59703 Mdot
.30991 .38709 Mdot
.40442 .67407 Mdot
.60969 .68042 Mdot
.70845 .51164 Mdot
.64655 .33059 Mdot
.32936 .5865 Mdot
.61944 .69598 Mdot
.69783 .58045 Mdot
.36339 .3623 Mdot
.51212 .29722 Mdot
.3497 .63745 Mdot
.67703 .40924 Mdot
.67063 .38981 Mdot
.42695 .29878 Mdot
.74001 .48832 Mdot
.52898 .30767 Mdot
.37004 .66548 Mdot
.3172 .41235 Mdot
.35042 .63733 Mdot
.44751 .2798 Mdot
.65777 .35519 Mdot
.70272 .51684 Mdot
.42011 .31635 Mdot
.4572 .74342 Mdot
.6784 .42235 Mdot
.4156 .31198 Mdot
.69303 .58238 Mdot
.72789 .47863 Mdot
.7253 .50325 Mdot
.28586 .51837 Mdot
.52582 .29534 Mdot
.72457 .46866 Mdot
.70371 .48461 Mdot
.60622 .67133 Mdot
.36198 .60841 Mdot
.67933 .59512 Mdot
.41007 .30626 Mdot
.30529 .46769 Mdot
.42242 .30379 Mdot
.38144 .34626 Mdot
.60996 .31187 Mdot
.53338 .70702 Mdot
.50201 .72983 Mdot
.31364 .56677 Mdot
.42593 .71287 Mdot
.34598 .63023 Mdot
.66502 .62128 Mdot
.2683 .53538 Mdot
.2946 .51648 Mdot
.70513 .59565 Mdot
.7005 .51136 Mdot
.28816 .50969 Mdot
.38406 .68322 Mdot
.37909 .65298 Mdot
.45786 .74417 Mdot
.6546 .60979 Mdot
.69688 .61783 Mdot
.6773 .40311 Mdot
.69798 .57816 Mdot
.42148 .2926 Mdot
.54476 .27796 Mdot
.49267 .26982 Mdot
.60458 .3146 Mdot
.33017 .58238 Mdot
.51104 .26413 Mdot
.6076 .68861 Mdot
.41556 .29547 Mdot
.62537 .68699 Mdot
.44782 .29803 Mdot
.3373 .59416 Mdot
.61495 .30261 Mdot
.69842 .41902 Mdot
.62214 .66596 Mdot
.38988 .69597 Mdot
.29926 .47292 Mdot
.66404 .62161 Mdot
.68865 .37457 Mdot
.65324 .62145 Mdot
.36002 .61958 Mdot
.68215 .60221 Mdot
.61935 .31388 Mdot
.67901 .36052 Mdot
.60399 .66749 Mdot
.61014 .68669 Mdot
.64911 .62237 Mdot
.71199 .58352 Mdot
.5152 .29813 Mdot
.69453 .59886 Mdot
.71508 .46891 Mdot
.62568 .6807 Mdot
.55829 .29265 Mdot
.48758 .73207 Mdot
.67098 .61657 Mdot
.27297 .52744 Mdot
.72376 .48116 Mdot
.29047 .50768 Mdot
.73107 .47152 Mdot
.39287 .32697 Mdot
.33578 .61206 Mdot
.42094 .31349 Mdot
.27945 .47848 Mdot
.51816 .26194 Mdot
.69267 .37229 Mdot
.32511 .40644 Mdot
.6753 .37984 Mdot
.53594 .71173 Mdot
.65209 .62041 Mdot
.68845 .41487 Mdot
.48662 .73289 Mdot
.35885 .64139 Mdot
.73215 .47214 Mdot
.50517 .2903 Mdot
.43214 .30054 Mdot
.5308 .71809 Mdot
.71214 .52445 Mdot
.46519 .28697 Mdot
.58295 .69042 Mdot
.43339 .29208 Mdot
.62489 .66519 Mdot
.69715 .43491 Mdot
.66686 .59425 Mdot
.43459 .29925 Mdot
.52922 .71146 Mdot
.70569 .47514 Mdot
.52856 .26994 Mdot
.67999 .36724 Mdot
.67866 .40983 Mdot
.36387 .65126 Mdot
.68685 .42535 Mdot
.49393 .2835 Mdot
.66611 .35385 Mdot
.72211 .46935 Mdot
.65817 .35321 Mdot
.29148 .48335 Mdot
.51822 .27289 Mdot
.33756 .3907 Mdot
.57651 .69467 Mdot
.52841 .30443 Mdot
.30922 .56379 Mdot
.38565 .33633 Mdot
.44014 .28656 Mdot
.72895 .48364 Mdot
.71312 .52638 Mdot
.59167 .68926 Mdot
.52924 .72054 Mdot
.51325 .28903 Mdot
.42974 .29038 Mdot
.44343 .72364 Mdot
.31961 .40778 Mdot
.43366 .29579 Mdot
.42184 .70688 Mdot
.61411 .67703 Mdot
.61454 .31931 Mdot
.43216 .72522 Mdot
.69802 .48707 Mdot
.4071 .70319 Mdot
.68289 .37443 Mdot
.46808 .2677 Mdot
.36104 .62136 Mdot
.29998 .46791 Mdot
.66721 .39109 Mdot
.66847 .38913 Mdot
.5684 .29614 Mdot
.74028 .4894 Mdot
.67254 .62537 Mdot
.52432 .297 Mdot
.62107 .68163 Mdot
.32818 .40045 Mdot
.4149 .69742 Mdot
.68626 .60704 Mdot
.65387 .62035 Mdot
.51787 .27256 Mdot
.40544 .71645 Mdot
.6858 .38428 Mdot
.43926 .28567 Mdot
.63072 .68465 Mdot
.49568 .27006 Mdot
.2964 .4327 Mdot
.55834 .28793 Mdot
.70431 .60524 Mdot
.29706 .41109 Mdot
.68396 .60294 Mdot
.35754 .37615 Mdot
.29788 .44095 Mdot
.2969 .46714 Mdot
.4913 .26424 Mdot
.7111 .53892 Mdot
.42506 .31186 Mdot
.33738 .60323 Mdot
.41293 .68966 Mdot
.54909 .30262 Mdot
.28582 .49062 Mdot
.27926 .54759 Mdot
.29819 .51906 Mdot
.73532 .49194 Mdot
.61242 .66353 Mdot
.38519 .3359 Mdot
.38707 .33347 Mdot
.62749 .32303 Mdot
.70322 .58698 Mdot
.35316 .38698 Mdot
.69574 .37349 Mdot
.66925 .38321 Mdot
.28441 .5012 Mdot
.39364 .33176 Mdot
.68897 .5962 Mdot
.70128 .39664 Mdot
.70472 .47554 Mdot
.38304 .65675 Mdot
.33289 .37324 Mdot
.38215 .35046 Mdot
.36064 .3755 Mdot
.52048 .7257 Mdot
.6935 .41808 Mdot
.34864 .61923 Mdot
.3035 .45349 Mdot
.60732 .3158 Mdot
.30993 .47444 Mdot
.63305 .68209 Mdot
.46879 .26828 Mdot
.71081 .442 Mdot
.36518 .65419 Mdot
.33276 .58223 Mdot
.60735 .30987 Mdot
.3829 .68435 Mdot
.69235 .58548 Mdot
.71278 .47384 Mdot
.53844 .2835 Mdot
.46669 .72789 Mdot
.39098 .67862 Mdot
.39493 .67847 Mdot
.53845 .30144 Mdot
.31946 .38977 Mdot
.40014 .30977 Mdot
.39536 .67638 Mdot
.67743 .39785 Mdot
.63236 .67471 Mdot
.67457 .4194 Mdot
.37136 .66335 Mdot
.33413 .6057 Mdot
.61084 .68807 Mdot
.61998 .67171 Mdot
.67502 .3807 Mdot
.31783 .3888 Mdot
.3063 .40232 Mdot
.65948 .61744 Mdot
.34158 .59208 Mdot
.45079 .73394 Mdot
.3415 .62661 Mdot
.29874 .47258 Mdot
.48901 .74105 Mdot
.53974 .70727 Mdot
.55095 .72125 Mdot
.44735 .74224 Mdot
.34817 .62753 Mdot
.61417 .31147 Mdot
.70365 .5304 Mdot
.68881 .38613 Mdot
.57964 .29883 Mdot
.46912 .28705 Mdot
.3091 .47765 Mdot
.363 .61964 Mdot
.27512 .50829 Mdot
.45328 .7287 Mdot
.27123 .47903 Mdot
.52722 .72867 Mdot
.56242 .7122 Mdot
.28397 .52301 Mdot
.33664 .62115 Mdot
.55325 .29664 Mdot
.54522 .27519 Mdot
.61346 .69125 Mdot
.37077 .65981 Mdot
.63206 .3318 Mdot
.6729 .41209 Mdot
.3964 .31843 Mdot
.4096 .3016 Mdot
.30758 .45383 Mdot
.30684 .43303 Mdot
.6238 .67558 Mdot
.36743 .64477 Mdot
.3135 .39788 Mdot
.54699 .3075 Mdot
.35668 .37872 Mdot
.3988 .32206 Mdot
.6906 .37636 Mdot
.6886 .408 Mdot
.35303 .59641 Mdot
.29853 .55958 Mdot
.71031 .49678 Mdot
.71546 .52472 Mdot
.66973 .40975 Mdot
.49423 .26175 Mdot
.33555 .37967 Mdot
.70764 .55216 Mdot
.70126 .58315 Mdot
.27495 .48225 Mdot
.35467 .64087 Mdot
.53627 .27222 Mdot
.70562 .57359 Mdot
.28841 .46556 Mdot
.49104 .72991 Mdot
.43615 .28817 Mdot
.35234 .61558 Mdot
.60853 .6982 Mdot
.699 .51554 Mdot
.53359 .72178 Mdot
.67253 .61638 Mdot
.67345 .40265 Mdot
.69845 .38616 Mdot
.33293 .60122 Mdot
.71309 .44516 Mdot
.66723 .63465 Mdot
.7 .40162 Mdot
.28489 .52037 Mdot
.33503 .39636 Mdot
.31073 .46887 Mdot
.54309 .28393 Mdot
.29866 .46694 Mdot
.52062 .30362 Mdot
.41587 .31034 Mdot
.68075 .59718 Mdot
.28311 .4889 Mdot
.52573 .70714 Mdot
.34057 .39264 Mdot
.3052 .44685 Mdot
.53936 .72826 Mdot
.63229 .68974 Mdot
.50793 .28164 Mdot
.27331 .50491 Mdot
.32765 .57091 Mdot
.64994 .34844 Mdot
.60471 .33132 Mdot
.69122 .37248 Mdot
.32857 .38417 Mdot
.50886 .27199 Mdot
.68965 .60304 Mdot
.43951 .72148 Mdot
.6934 .62516 Mdot
.40233 .67113 Mdot
.34676 .60111 Mdot
.67717 .63175 Mdot
.68936 .60408 Mdot
.33145 .59923 Mdot
.42383 .71225 Mdot
.33679 .39804 Mdot
.66981 .39745 Mdot
.73086 .48634 Mdot
.72873 .48981 Mdot
.48901 .28822 Mdot
.68604 .58351 Mdot
.36454 .34938 Mdot
.69329 .37473 Mdot
.37491 .36081 Mdot
.68005 .38573 Mdot
.28718 .54912 Mdot
.4562 .28827 Mdot
.70575 .54568 Mdot
.74077 .48492 Mdot
.60113 .67847 Mdot
.68046 .59501 Mdot
.29128 .48794 Mdot
.6791 .58778 Mdot
.67381 .60361 Mdot
.34189 .59021 Mdot
.31317 .39355 Mdot
.35112 .38084 Mdot
.51953 .72724 Mdot
.71109 .49655 Mdot
.34014 .62001 Mdot
.53642 .73216 Mdot
.33414 .58874 Mdot
.53148 .72297 Mdot
.7192 .47335 Mdot
.38619 .69401 Mdot
.67684 .59424 Mdot
.71495 .45964 Mdot
.38526 .34502 Mdot
.34315 .3888 Mdot
.35691 .3834 Mdot
.5734 .29612 Mdot
.40609 .67628 Mdot
.41921 .31192 Mdot
.62039 .67909 Mdot
.31398 .4092 Mdot
.53045 .70484 Mdot
.26866 .50409 Mdot
.40815 .69625 Mdot
.31596 .40202 Mdot
.51054 .29286 Mdot
.60176 .68016 Mdot
.40407 .68411 Mdot
.32728 .38166 Mdot
.68571 .59372 Mdot
.71454 .50982 Mdot
.70167 .59166 Mdot
.28991 .5013 Mdot
.68375 .37821 Mdot
.61788 .67778 Mdot
.54477 .28692 Mdot
.41761 .31479 Mdot
.68501 .60236 Mdot
.47283 .27274 Mdot
.68373 .41258 Mdot
.40071 .68038 Mdot
.67151 .39316 Mdot
.27072 .51248 Mdot
.72475 .48437 Mdot
.61003 .68293 Mdot
.59176 .67141 Mdot
.67391 .58971 Mdot
.33127 .40525 Mdot
.30364 .50447 Mdot
.47535 .26386 Mdot
.70679 .52008 Mdot
.68714 .37691 Mdot
.48199 .28472 Mdot
.60533 .68536 Mdot
.2655 .48984 Mdot
.4292 .72958 Mdot
.36273 .61265 Mdot
.56949 .70009 Mdot
.36528 .61326 Mdot
.41507 .31849 Mdot
.66075 .62039 Mdot
.62716 .66837 Mdot
.55792 .71321 Mdot
.29271 .55579 Mdot
.31128 .48228 Mdot
.356 .63096 Mdot
.50764 .71163 Mdot
.37861 .66788 Mdot
.70673 .5414 Mdot
.53408 .71905 Mdot
.45029 .28291 Mdot
.37946 .35079 Mdot
.57941 .29886 Mdot
.32052 .40439 Mdot
.46996 .26856 Mdot
.42139 .70886 Mdot
.4179 .72677 Mdot
.69265 .49056 Mdot
.6335 .6856 Mdot
.69293 .39387 Mdot
.39223 .70221 Mdot
.50026 .28941 Mdot
.43382 .30878 Mdot
.36292 .66335 Mdot
.69543 .58575 Mdot
.64612 .34028 Mdot
.31246 .40203 Mdot
.35877 .38158 Mdot
.27928 .47778 Mdot
.45793 .27914 Mdot
.29631 .42342 Mdot
.68455 .38477 Mdot
.32685 .57616 Mdot
.53904 .70716 Mdot
.63811 .3192 Mdot
.68205 .58116 Mdot
.63051 .33779 Mdot
.28813 .54966 Mdot
.34403 .6137 Mdot
.70886 .4874 Mdot
.66359 .60662 Mdot
.28325 .46863 Mdot
.40437 .32162 Mdot
.41371 .3055 Mdot
.30519 .55823 Mdot
.30178 .40755 Mdot
.54456 .30717 Mdot
.30168 .42431 Mdot
.61942 .68412 Mdot
.53535 .72741 Mdot
.60525 .33262 Mdot
.33851 .60058 Mdot
.7305 .45799 Mdot
.66085 .61624 Mdot
.35585 .63701 Mdot
.3048 .48728 Mdot
.70228 .55268 Mdot
.59253 .68279 Mdot
.32503 .57435 Mdot
.51701 .27014 Mdot
.34127 .60671 Mdot
.38188 .34332 Mdot
.37115 .36257 Mdot
.34887 .58815 Mdot
.51705 .29743 Mdot
.29709 .4122 Mdot
.30329 .49738 Mdot
.6561 .60858 Mdot
.32226 .40302 Mdot
.63113 .68547 Mdot
.41591 .69581 Mdot
.28657 .51936 Mdot
.61442 .68656 Mdot
.69261 .62353 Mdot
.35723 .38786 Mdot
.4897 .27022 Mdot
.70058 .5075 Mdot
.33931 .61203 Mdot
.33459 .39874 Mdot
.36424 .6432 Mdot
.64751 .63202 Mdot
.35995 .60877 Mdot
.67663 .36208 Mdot
.69779 .51823 Mdot
.68465 .3942 Mdot
.60439 .67862 Mdot
.35118 .61318 Mdot
.30168 .42343 Mdot
.34082 .37781 Mdot
.39112 .66716 Mdot
.6839 .60427 Mdot
.66905 .60825 Mdot
.69818 .59475 Mdot
.48642 .28387 Mdot
.45024 .72714 Mdot
.68345 .40095 Mdot
.31577 .39298 Mdot
.68549 .42558 Mdot
.49068 .71885 Mdot
.29231 .4975 Mdot
.65318 .35316 Mdot
.39753 .67426 Mdot
.72219 .51644 Mdot
.37692 .65081 Mdot
.70386 .53654 Mdot
.57363 .29708 Mdot
.63123 .3369 Mdot
.71674 .49497 Mdot
.35334 .63231 Mdot
.51907 .72436 Mdot
.54948 .7071 Mdot
.698 .40645 Mdot
.31564 .38257 Mdot
.39015 .33772 Mdot
.539 .27554 Mdot
.26924 .48125 Mdot
.60058 .30864 Mdot
.64728 .34759 Mdot
.61056 .66818 Mdot
.70555 .51033 Mdot
.69123 .38177 Mdot
.68573 .36716 Mdot
.49835 .28398 Mdot
.60368 .67402 Mdot
.35488 .61406 Mdot
.33785 .40194 Mdot
.61891 .3333 Mdot
.39282 .67807 Mdot
.63657 .68113 Mdot
.39322 .32007 Mdot
.69208 .60729 Mdot
.64416 .32477 Mdot
.4842 .72064 Mdot
.67662 .62649 Mdot
.43366 .29237 Mdot
.72354 .46902 Mdot
.34465 .62341 Mdot
.33119 .38645 Mdot
.47454 .26948 Mdot
.41564 .69029 Mdot
.41946 .31747 Mdot
.69545 .39707 Mdot
.63932 .32371 Mdot
.4936 .72426 Mdot
.4223 .29358 Mdot
.33179 .6045 Mdot
.59355 .68711 Mdot
.2899 .46888 Mdot
.69834 .39405 Mdot
.69626 .48025 Mdot
.36259 .64628 Mdot
.4923 .29265 Mdot
.55846 .29132 Mdot
.67414 .61283 Mdot
.70223 .58807 Mdot
.7112 .53975 Mdot
.33763 .3888 Mdot
.47189 .28227 Mdot
.33571 .39754 Mdot
.32569 .56966 Mdot
.70076 .4001 Mdot
.30262 .49992 Mdot
.48102 .26451 Mdot
.59946 .31495 Mdot
.63199 .68989 Mdot
.73818 .49376 Mdot
.57649 .69847 Mdot
.60772 .68988 Mdot
.46129 .27907 Mdot
.298 .48905 Mdot
.54206 .71979 Mdot
.59939 .66951 Mdot
.29097 .50994 Mdot
.49223 .28564 Mdot
.71435 .50529 Mdot
.6615 .60763 Mdot
.69934 .52839 Mdot
.52419 .70899 Mdot
.7082 .56347 Mdot
.40799 .70821 Mdot
.35202 .58941 Mdot
.74135 .47678 Mdot
.43463 .71616 Mdot
.69046 .37271 Mdot
.70653 .52422 Mdot
.53253 .72245 Mdot
.6381 .67487 Mdot
.40492 .70251 Mdot
.40453 .71437 Mdot
.626 .67257 Mdot
.40619 .6763 Mdot
.68755 .62521 Mdot
.65403 .62022 Mdot
.54895 .72013 Mdot
.70301 .40101 Mdot
.29587 .48096 Mdot
.71716 .46723 Mdot
.34296 .60591 Mdot
.68132 .63011 Mdot
.54529 .72463 Mdot
.67593 .36245 Mdot
.62874 .67504 Mdot
.46716 .26882 Mdot
.42844 .72484 Mdot
.56367 .29582 Mdot
.59258 .67204 Mdot
.675 .6339 Mdot
.61948 .33931 Mdot
.59181 .68166 Mdot
.42033 .2896 Mdot
.39367 .70489 Mdot
.33509 .38343 Mdot
.30075 .4645 Mdot
.29784 .41755 Mdot
.67687 .3766 Mdot
.40902 .68131 Mdot
.4271 .71262 Mdot
.37266 .65318 Mdot
.32566 .56906 Mdot
.3423 .39046 Mdot
.26744 .52634 Mdot
.64867 .62961 Mdot
.40738 .69144 Mdot
.51711 .26446 Mdot
.70349 .49488 Mdot
.41782 .70909 Mdot
.56503 .70775 Mdot
.60861 .69686 Mdot
.71232 .49631 Mdot
.74023 .49452 Mdot
.38609 .34035 Mdot
.28766 .47876 Mdot
.33369 .59358 Mdot
.27476 .53064 Mdot
.61667 .67972 Mdot
.67651 .38618 Mdot
.37347 .66008 Mdot
.45836 .28852 Mdot
.53482 .71469 Mdot
.49026 .28442 Mdot
.33734 .57899 Mdot
.72904 .48174 Mdot
.69716 .38494 Mdot
.42862 .29916 Mdot
.43074 .29707 Mdot
.38627 .67175 Mdot
.38685 .33471 Mdot
.28552 .5061 Mdot
.28792 .49702 Mdot
.69393 .38261 Mdot
.35004 .63264 Mdot
.53896 .71609 Mdot
.64307 .66724 Mdot
.41497 .6866 Mdot
.33113 .57783 Mdot
.60099 .31966 Mdot
.60322 .3143 Mdot
.48199 .26547 Mdot
.33099 .59226 Mdot
.39835 .68865 Mdot
.71565 .48756 Mdot
.31028 .47939 Mdot
.46586 .28245 Mdot
.29357 .46096 Mdot
.53769 .29792 Mdot
.46797 .74353 Mdot
.31798 .38337 Mdot
.28944 .49856 Mdot
.61297 .30736 Mdot
.72927 .50671 Mdot
.34069 .39677 Mdot
.5162 .28057 Mdot
.4723 .27725 Mdot
.41706 .70651 Mdot
.67994 .58186 Mdot
.71534 .47218 Mdot
.28998 .50441 Mdot
.66949 .40775 Mdot
.60744 .68875 Mdot
.36081 .37664 Mdot
.28997 .55142 Mdot
.47804 .28585 Mdot
.70514 .54012 Mdot
.57782 .69245 Mdot
.35107 .60445 Mdot
.7156 .50881 Mdot
.35303 .60848 Mdot
.69437 .59801 Mdot
.71426 .46481 Mdot
.36805 .66676 Mdot
.69617 .60808 Mdot
.52549 .30674 Mdot
.4432 .30188 Mdot
.63313 .67067 Mdot
.63906 .34927 Mdot
.61991 .68036 Mdot
.4061 .30527 Mdot
.37752 .65471 Mdot
.41732 .69515 Mdot
.34379 .6033 Mdot
.29914 .4465 Mdot
.44322 .74002 Mdot
.35416 .37254 Mdot
.33577 .38352 Mdot
.71073 .50685 Mdot
.29736 .41925 Mdot
.52316 .72545 Mdot
.28011 .49398 Mdot
.53626 .28217 Mdot
.38627 .67483 Mdot
.29374 .4998 Mdot
.65948 .61096 Mdot
.59669 .67618 Mdot
.7384 .47146 Mdot
.55873 .28717 Mdot
.31934 .39377 Mdot
.69478 .39468 Mdot
.51017 .73724 Mdot
.50086 .29297 Mdot
.61567 .32603 Mdot
.51001 .73045 Mdot
.46699 .2677 Mdot
.70163 .38539 Mdot
.44077 .30439 Mdot
.61991 .32391 Mdot
.67671 .41676 Mdot
.51904 .71413 Mdot
.27964 .49377 Mdot
.29539 .41489 Mdot
.26813 .53026 Mdot
.62525 .33827 Mdot
.45424 .29266 Mdot
.50322 .27459 Mdot
.55617 .71473 Mdot
.70594 .56342 Mdot
.31753 .41351 Mdot
.33005 .58707 Mdot
.60994 .31542 Mdot
.45961 .7389 Mdot
.29581 .41554 Mdot
.6876 .40614 Mdot
.59167 .67324 Mdot
.48295 .73866 Mdot
.33227 .39116 Mdot
.34904 .3865 Mdot
.27465 .50229 Mdot
.40611 .31388 Mdot
.72468 .47141 Mdot
.26868 .49693 Mdot
.37435 .65563 Mdot
.33692 .59594 Mdot
.67612 .37998 Mdot
.32168 .40233 Mdot
.68267 .40648 Mdot
.30691 .4831 Mdot
.26708 .52487 Mdot
.65682 .60956 Mdot
.69779 .58975 Mdot
.30315 .42738 Mdot
.44784 .74487 Mdot
.42936 .73812 Mdot
.69443 .4817 Mdot
.72621 .47632 Mdot
.40165 .71444 Mdot
.29542 .51959 Mdot
.2733 .49816 Mdot
.59023 .68368 Mdot
.54508 .72896 Mdot
.62287 .67009 Mdot
.49362 .72925 Mdot
.57348 .30061 Mdot
.60458 .68103 Mdot
.47268 .26643 Mdot
.49223 .72917 Mdot
.63895 .33206 Mdot
.61282 .69225 Mdot
.35705 .60856 Mdot
.53487 .29194 Mdot
.34231 .58282 Mdot
.53606 .27812 Mdot
.33856 .61551 Mdot
.44813 .27909 Mdot
.54448 .28681 Mdot
.38462 .33914 Mdot
.49187 .73677 Mdot
.35399 .37359 Mdot
.29422 .51472 Mdot
.37431 .35371 Mdot
.41813 .72165 Mdot
.71802 .50185 Mdot
.70872 .56042 Mdot
.35198 .60384 Mdot
.49767 .28162 Mdot
.69346 .40588 Mdot
.58789 .67673 Mdot
.36997 .64803 Mdot
.6167 .68861 Mdot
.73838 .4942 Mdot
.51745 .2712 Mdot
.3 .46196 Mdot
.38611 .32803 Mdot
.40654 .30633 Mdot
.45658 .28871 Mdot
.32382 .57276 Mdot
.61049 .69589 Mdot
.3813 .34345 Mdot
.68276 .61741 Mdot
.27824 .54651 Mdot
.66716 .60355 Mdot
.32355 .40453 Mdot
.27751 .48393 Mdot
.4746 .72978 Mdot
.70566 .48352 Mdot
.53937 .30123 Mdot
.35166 .61616 Mdot
.32165 .38313 Mdot
.268 .52994 Mdot
.69821 .48885 Mdot
.28612 .5202 Mdot
.52425 .28279 Mdot
.33235 .39643 Mdot
.45485 .73377 Mdot
.37954 .68713 Mdot
.56048 .72195 Mdot
.34899 .6128 Mdot
.28929 .50825 Mdot
.68428 .5791 Mdot
.61534 .68945 Mdot
.62153 .32977 Mdot
.52807 .72127 Mdot
.33291 .57416 Mdot
.41149 .29774 Mdot
.73633 .48796 Mdot
.29028 .4832 Mdot
.61135 .31595 Mdot
.2894 .47579 Mdot
.35882 .37907 Mdot
.69367 .59311 Mdot
.35957 .37939 Mdot
.63458 .683 Mdot
.69147 .38417 Mdot
.7127 .47417 Mdot
.39634 .31265 Mdot
.30343 .40418 Mdot
.55267 .30312 Mdot
.48804 .73833 Mdot
.67806 .6087 Mdot
.59723 .32135 Mdot
.387 .32874 Mdot
.67896 .364 Mdot
.55514 .72387 Mdot
.66996 .4038 Mdot
.35115 .60296 Mdot
.6962 .52603 Mdot
.67908 .42326 Mdot
.42374 .2992 Mdot
.50947 .71125 Mdot
.36464 .37189 Mdot
.34727 .63318 Mdot
.66114 .35469 Mdot
.69869 .41699 Mdot
.68227 .5893 Mdot
.601 .30706 Mdot
.37614 .65665 Mdot
.33893 .3937 Mdot
.34693 .59169 Mdot
.62834 .33387 Mdot
.59657 .31104 Mdot
.42629 .30316 Mdot
.35069 .61987 Mdot
.29701 .47187 Mdot
.469 .26872 Mdot
.56001 .2939 Mdot
.47978 .26996 Mdot
.67358 .63046 Mdot
.30863 .40066 Mdot
.33765 .38719 Mdot
.38059 .66596 Mdot
.67995 .40907 Mdot
.35322 .37309 Mdot
.41201 .69237 Mdot
.4215 .71731 Mdot
.6988 .52651 Mdot
.52558 .28715 Mdot
.3344 .57573 Mdot
.63219 .66864 Mdot
.33186 .37965 Mdot
.52655 .29608 Mdot
.68649 .59478 Mdot
.40186 .30645 Mdot
.40364 .67976 Mdot
.61762 .66765 Mdot
.67068 .59176 Mdot
.67879 .63375 Mdot
.44449 .74164 Mdot
.35454 .60987 Mdot
.67077 .38776 Mdot
.52934 .67355 Mdot
.38637 .57328 Mdot
.44424 .48141 Mdot
.31032 .41439 Mdot
.59614 .56472 Mdot
.48799 .6538 Mdot
.63716 .66167 Mdot
.49732 .58275 Mdot
.49725 .71197 Mdot
.54517 .62172 Mdot
.62983 .4172 Mdot
.47197 .54437 Mdot
.47915 .30334 Mdot
.66943 .47805 Mdot
.60309 .65547 Mdot
.33573 .48388 Mdot
.67162 .53505 Mdot
.51628 .63328 Mdot
.6747 .47521 Mdot
.60386 .4538 Mdot
.57711 .3345 Mdot
.58109 .31501 Mdot
.60559 .40818 Mdot
.32771 .56689 Mdot
.54586 .65168 Mdot
.41077 .59896 Mdot
.63971 .58404 Mdot
.64377 .38477 Mdot
.63154 .66551 Mdot
.41457 .38037 Mdot
.61366 .57011 Mdot
.45478 .37866 Mdot
.45884 .67691 Mdot
.62865 .44538 Mdot
.40598 .59107 Mdot
.3796 .43612 Mdot
.49294 .70816 Mdot
.54607 .58934 Mdot
.59469 .59296 Mdot
.45436 .64443 Mdot
.62226 .55232 Mdot
.48607 .29331 Mdot
.69675 .57296 Mdot
.6772 .49579 Mdot
.45362 .35932 Mdot
.64066 .54031 Mdot
.49688 .58375 Mdot
.30957 .42464 Mdot
.59746 .5575 Mdot
.42889 .69317 Mdot
.69467 .54197 Mdot
.64879 .46792 Mdot
.64611 .40723 Mdot
.46675 .65895 Mdot
.6593 .43152 Mdot
.43216 .67753 Mdot
.52047 .63583 Mdot
.49404 .65801 Mdot
.60574 .44889 Mdot
.54217 .35302 Mdot
.73527 .48135 Mdot
.33904 .48528 Mdot
.56232 .43213 Mdot
.40245 .47896 Mdot
.65451 .48619 Mdot
.48156 .69238 Mdot
.64517 .61061 Mdot
.68988 .51207 Mdot
.59384 .35827 Mdot
.45294 .3399 Mdot
.61333 .40223 Mdot
.57088 .43461 Mdot
.64351 .53032 Mdot
.38838 .60193 Mdot
.58038 .61169 Mdot
.58212 .37442 Mdot
.55432 .68836 Mdot
.36809 .40912 Mdot
.54758 .51913 Mdot
.41271 .34472 Mdot
.48174 .66521 Mdot
.6143 .45622 Mdot
.45165 .57186 Mdot
.60621 .52771 Mdot
.40308 .64896 Mdot
.43011 .3443 Mdot
.54804 .65016 Mdot
.55615 .37854 Mdot
.66803 .5427 Mdot
.50765 .68052 Mdot
.65723 .43792 Mdot
.3819 .36702 Mdot
.44897 .41849 Mdot
.41194 .36214 Mdot
.50409 .57637 Mdot
.38269 .42083 Mdot
.62826 .44265 Mdot
.6884 .45384 Mdot
.56463 .31137 Mdot
.62314 .61364 Mdot
.47025 .36724 Mdot
.72334 .45763 Mdot
.55536 .32539 Mdot
.49353 .61086 Mdot
.61405 .62561 Mdot
.41225 .36848 Mdot
.60104 .36528 Mdot
.59369 .5193 Mdot
.5967 .42469 Mdot
.59248 .58871 Mdot
.57017 .61845 Mdot
.67592 .53535 Mdot
.30723 .43061 Mdot
.59088 .65249 Mdot
.44441 .38175 Mdot
.6205 .37711 Mdot
.34352 .43638 Mdot
.43669 .71431 Mdot
.47037 .3886 Mdot
.52684 .69948 Mdot
.50881 .47421 Mdot
.66153 .56455 Mdot
.40992 .35104 Mdot
.63744 .66896 Mdot
.54822 .68224 Mdot
.60461 .40533 Mdot
.35344 .49542 Mdot
.6813 .55451 Mdot
.67879 .469 Mdot
.59174 .33712 Mdot
.49486 .6755 Mdot
.41319 .33446 Mdot
.35235 .54866 Mdot
.40438 .45186 Mdot
.61043 .34378 Mdot
.39337 .4754 Mdot
.43605 .44483 Mdot
.45231 .30852 Mdot
.62582 .62584 Mdot
.43511 .42793 Mdot
.5472 .69882 Mdot
.57503 .369 Mdot
.62458 .41127 Mdot
.54063 .66611 Mdot
.31497 .50324 Mdot
.40807 .40377 Mdot
.45692 .44721 Mdot
.59818 .54184 Mdot
.64137 .65942 Mdot
.40801 .5712 Mdot
.62285 .43389 Mdot
.51593 .40585 Mdot
.5268 .358 Mdot
.67827 .46338 Mdot
.72083 .45586 Mdot
.49647 .3828 Mdot
.43208 .55923 Mdot
.58247 .66893 Mdot
.50329 .42428 Mdot
.65899 .57473 Mdot
.48718 .41194 Mdot
.41336 .37774 Mdot
.60199 .34211 Mdot
.59232 .37989 Mdot
.64836 .52934 Mdot
.64882 .41038 Mdot
.57878 .6341 Mdot
.58643 .63286 Mdot
.49402 .36184 Mdot
.66887 .53108 Mdot
.62411 .47344 Mdot
.68942 .52421 Mdot
.51745 .61849 Mdot
.44247 .63779 Mdot
.37947 .55944 Mdot
.44399 .5239 Mdot
.29009 .52746 Mdot
.37796 .44349 Mdot
.49725 .67891 Mdot
.30141 .53207 Mdot
.38132 .50721 Mdot
.40067 .58798 Mdot
.36447 .37955 Mdot
.36587 .5561 Mdot
.43465 .69424 Mdot
.5696 .54037 Mdot
.59841 .37717 Mdot
.45928 .4655 Mdot
.36455 .54446 Mdot
.65091 .57248 Mdot
.48859 .70867 Mdot
.41199 .35123 Mdot
.4673 .32723 Mdot
.51131 .65279 Mdot
.56205 .66617 Mdot
.64446 .35462 Mdot
.65776 .40622 Mdot
.47177 .30643 Mdot
.64899 .52838 Mdot
.64969 .59967 Mdot
.404 .32435 Mdot
.60846 .48689 Mdot
.4485 .58339 Mdot
.41691 .63116 Mdot
.4339 .35624 Mdot
.57698 .55582 Mdot
.31494 .44294 Mdot
.47034 .61977 Mdot
.44064 .46237 Mdot
.40072 .40172 Mdot
.36181 .4253 Mdot
.35454 .44334 Mdot
.67457 .50746 Mdot
.36874 .44997 Mdot
.4022 .37797 Mdot
.44904 .72147 Mdot
.5668 .47267 Mdot
.61982 .65596 Mdot
.40333 .52957 Mdot
.55393 .33101 Mdot
.56168 .41926 Mdot
.56694 .61271 Mdot
.46742 .66027 Mdot
.38663 .3846 Mdot
.43187 .69045 Mdot
.61922 .53391 Mdot
.44119 .38952 Mdot
.56724 .39031 Mdot
.46534 .38362 Mdot
.50227 .35591 Mdot
.52348 .58062 Mdot
.67817 .47152 Mdot
.30143 .5528 Mdot
.54818 .35068 Mdot
.63181 .57529 Mdot
.53823 .69178 Mdot
.55832 .32986 Mdot
.60634 .63702 Mdot
.60612 .60812 Mdot
.4737 .6469 Mdot
.4173 .56746 Mdot
.4706 .50059 Mdot
.55225 .59157 Mdot
.39239 .44176 Mdot
.54211 .39261 Mdot
.58938 .32778 Mdot
.49257 .31923 Mdot
.46839 .48547 Mdot
.56195 .46712 Mdot
.36056 .52909 Mdot
.59427 .35285 Mdot
.54108 .55737 Mdot
.38575 .57895 Mdot
.45826 .46221 Mdot
.52163 .64586 Mdot
.65655 .58216 Mdot
.42559 .56318 Mdot
.41674 .68385 Mdot
.44915 .3539 Mdot
.46135 .30203 Mdot
.49386 .35088 Mdot
.54945 .65868 Mdot
.66966 .43211 Mdot
.65738 .50929 Mdot
.36783 .51004 Mdot
.4051 .61962 Mdot
.50961 .54374 Mdot
.43863 .67169 Mdot
.66159 .39495 Mdot
.66503 .57905 Mdot
.56785 .64126 Mdot
.3323 .56626 Mdot
.45062 .54007 Mdot
.55329 .63739 Mdot
.3793 .49184 Mdot
.52639 .69809 Mdot
.64614 .63082 Mdot
.56067 .3564 Mdot
.58155 .31628 Mdot
.32287 .48401 Mdot
.55946 .44271 Mdot
.31059 .45107 Mdot
.48885 .32675 Mdot
.5922 .53342 Mdot
.45687 .67065 Mdot
.65003 .39326 Mdot
.52013 .36649 Mdot
.49119 .30613 Mdot
.50337 .35462 Mdot
.62131 .40575 Mdot
.65345 .49305 Mdot
.36853 .58351 Mdot
.61882 .5816 Mdot
.67358 .45707 Mdot
.3766 .61969 Mdot
.63049 .38408 Mdot
.60739 .54399 Mdot
.68811 .54204 Mdot
.41171 .67164 Mdot
.37672 .6478 Mdot
.35821 .45782 Mdot
.37934 .59405 Mdot
.43239 .48478 Mdot
.6903 .56781 Mdot
.32877 .5282 Mdot
.62419 .53446 Mdot
.60688 .65991 Mdot
.5615 .66972 Mdot
.67741 .55294 Mdot
.53561 .69336 Mdot
.52854 .31432 Mdot
.67275 .42977 Mdot
.55883 .6329 Mdot
.37537 .50948 Mdot
.4139 .40632 Mdot
.36308 .50424 Mdot
.57137 .66012 Mdot
.41745 .53645 Mdot
.64996 .58788 Mdot
.47113 .66009 Mdot
.56287 .50397 Mdot
.62628 .61696 Mdot
.47556 .61153 Mdot
.51596 .69334 Mdot
.59673 .65748 Mdot
.46989 .34212 Mdot
.34121 .49925 Mdot
.54014 .59736 Mdot
.37072 .62608 Mdot
.49686 .47033 Mdot
.5005 .61275 Mdot
.34289 .53618 Mdot
.52535 .6056 Mdot
.31951 .56317 Mdot
.69742 .46747 Mdot
.57533 .58725 Mdot
.52498 .40014 Mdot
.33045 .54749 Mdot
.45682 .67415 Mdot
.50788 .67785 Mdot
.67755 .46666 Mdot
.33701 .50867 Mdot
.45224 .33636 Mdot
.54246 .49916 Mdot
.36195 .54005 Mdot
.46337 .43349 Mdot
.35539 .46964 Mdot
.33808 .4135 Mdot
.49858 .35765 Mdot
.60037 .56386 Mdot
.32189 .53328 Mdot
.63461 .37174 Mdot
.44113 .51535 Mdot
.4523 .57808 Mdot
.55844 .35257 Mdot
.4675 .58474 Mdot
.47606 .56855 Mdot
.47116 .46232 Mdot
.56851 .34656 Mdot
.57156 .57052 Mdot
.61501 .54529 Mdot
.64454 .63407 Mdot
.39624 .39517 Mdot
.55658 .6162 Mdot
.60664 .61324 Mdot
.5375 .39998 Mdot
.36747 .6291 Mdot
.43737 .52649 Mdot
.69528 .54809 Mdot
.5144 .4407 Mdot
.57192 .62619 Mdot
.46434 .30041 Mdot
.5836 .55036 Mdot
.46154 .47388 Mdot
.32957 .50658 Mdot
.31926 .5376 Mdot
.43773 .60025 Mdot
.40077 .36773 Mdot
.62475 .53195 Mdot
.57822 .65082 Mdot
.62282 .55915 Mdot
.40945 .63712 Mdot
.70462 .46171 Mdot
.45337 .32782 Mdot
.64073 .35489 Mdot
.64994 .5715 Mdot
.46072 .61679 Mdot
.40707 .33794 Mdot
.55761 .47597 Mdot
.61776 .48792 Mdot
.67669 .44008 Mdot
.6089 .35913 Mdot
.59501 .36923 Mdot
.42568 .52147 Mdot
.64513 .44181 Mdot
.54662 .35392 Mdot
.61139 .63292 Mdot
.51816 .31502 Mdot
.54936 .36208 Mdot
.56257 .70267 Mdot
.58124 .37445 Mdot
.623 .64434 Mdot
.65417 .43448 Mdot
.4975 .60754 Mdot
.59038 .54142 Mdot
.51594 .4229 Mdot
.58841 .65051 Mdot
.67112 .50788 Mdot
.57477 .49977 Mdot
.44756 .70333 Mdot
.51756 .68514 Mdot
.55804 .68624 Mdot
.41633 .60462 Mdot
.58899 .51624 Mdot
.3239 .53347 Mdot
.62133 .34392 Mdot
.39246 .62566 Mdot
.69164 .54242 Mdot
.44764 .71819 Mdot
.62277 .47755 Mdot
.47605 .71785 Mdot
.47213 .34577 Mdot
.62551 .47693 Mdot
.3498 .44734 Mdot
.42226 .31955 Mdot
.33914 .49681 Mdot
.57859 .60445 Mdot
.48821 .32721 Mdot
.55009 .3314 Mdot
.5166 .32063 Mdot
.35201 .43357 Mdot
.52829 .34213 Mdot
.38089 .6266 Mdot
.57487 .51419 Mdot
.39291 .60537 Mdot
.35438 .50042 Mdot
.54199 .34285 Mdot
.68696 .56561 Mdot
.42101 .40734 Mdot
.49033 .63382 Mdot
.62375 .36659 Mdot
.34905 .47612 Mdot
.3843 .65255 Mdot
.49884 .44118 Mdot
.60709 .43561 Mdot
.53932 .30854 Mdot
.33636 .44189 Mdot
.54613 .66744 Mdot
.50166 .37844 Mdot
.54642 .68014 Mdot
.56256 .69662 Mdot
.63407 .42115 Mdot
.48821 .64535 Mdot
.30131 .54947 Mdot
.64284 .48349 Mdot
.42159 .32741 Mdot
.60704 .53513 Mdot
.69513 .46014 Mdot
.35664 .48979 Mdot
.48937 .3586 Mdot
.50531 .38248 Mdot
.34455 .44956 Mdot
.4261 .40741 Mdot
.4254 .41535 Mdot
.31931 .56196 Mdot
.50924 .64406 Mdot
.38885 .61155 Mdot
.40152 .39827 Mdot
.44911 .63971 Mdot
.45449 .34139 Mdot
.67647 .36794 Mdot
.60462 .45976 Mdot
.67123 .57214 Mdot
.37316 .57367 Mdot
.38075 .58835 Mdot
.52764 .36755 Mdot
.66668 .54717 Mdot
.45751 .50083 Mdot
.4588 .44933 Mdot
.65298 .42634 Mdot
.42213 .65565 Mdot
.52723 .592 Mdot
.33783 .45451 Mdot
.41842 .68542 Mdot
.31473 .43391 Mdot
.59529 .37941 Mdot
.61703 .58233 Mdot
.58359 .52794 Mdot
.65131 .59275 Mdot
.427 .49142 Mdot
.34935 .56765 Mdot
.40163 .39064 Mdot
.58274 .52657 Mdot
.39963 .59418 Mdot
.36403 .47408 Mdot
.6046 .61869 Mdot
.65335 .54595 Mdot
.50566 .58683 Mdot
.59004 .45496 Mdot
.44573 .72319 Mdot
.60984 .4019 Mdot
.46161 .29964 Mdot
.33042 .51301 Mdot
.6548 .53847 Mdot
.37325 .57819 Mdot
.4443 .4336 Mdot
.57317 .41074 Mdot
.33496 .47546 Mdot
.59361 .34931 Mdot
.49768 .67993 Mdot
.62839 .38518 Mdot
.65896 .55246 Mdot
.61573 .48278 Mdot
.37747 .59852 Mdot
.33846 .4883 Mdot
.45073 .59837 Mdot
.55476 .5235 Mdot
.47882 .4297 Mdot
.46565 .71234 Mdot
.54827 .64751 Mdot
.41894 .57206 Mdot
.68669 .47735 Mdot
.34165 .45881 Mdot
.60879 .41957 Mdot
.36231 .46615 Mdot
.33763 .47518 Mdot
.66003 .59199 Mdot
.57045 .64277 Mdot
.68767 .45893 Mdot
.36624 .54081 Mdot
.53338 .30887 Mdot
.38943 .6586 Mdot
.436 .69025 Mdot
.47546 .60442 Mdot
.50184 .39232 Mdot
.30276 .54355 Mdot
.51764 .69018 Mdot
.60094 .40874 Mdot
.53343 .6962 Mdot
.50334 .31303 Mdot
.52104 .57558 Mdot
.48933 .65869 Mdot
.42037 .4913 Mdot
.64992 .49767 Mdot
.51264 .64341 Mdot
.45355 .38031 Mdot
.40529 .52177 Mdot
.48078 .652 Mdot
.48437 .66106 Mdot
.44145 .57441 Mdot
.62832 .59703 Mdot
.439 .38126 Mdot
.60996 .37317 Mdot
.29758 .54261 Mdot
.44897 .64263 Mdot
.38335 .5872 Mdot
.59445 .53999 Mdot
.47159 .37966 Mdot
.41813 .31998 Mdot
.31157 .53482 Mdot
.43539 .65292 Mdot
.66379 .57426 Mdot
.51791 .53721 Mdot
.39974 .60912 Mdot
.39409 .61301 Mdot
.66106 .48053 Mdot
.59115 .5239 Mdot
.44932 .48355 Mdot
.69536 .56893 Mdot
.65494 .37939 Mdot
.28311 .53091 Mdot
.30306 .53034 Mdot
.63827 .55615 Mdot
.42815 .5923 Mdot
.57797 .3655 Mdot
.68362 .53283 Mdot
.31405 .49657 Mdot
.63005 .5112 Mdot
.33584 .56539 Mdot
.39918 .55073 Mdot
.30705 .54652 Mdot
.37895 .43242 Mdot
.66468 .58937 Mdot
.58499 .63968 Mdot
.65108 .46186 Mdot
.51909 .36892 Mdot
.55981 .54498 Mdot
.53279 .33923 Mdot
.457 .41178 Mdot
.50071 .37046 Mdot
.47962 .63978 Mdot
.49498 .56579 Mdot
.61673 .39211 Mdot
.48797 .32934 Mdot
.61865 .37366 Mdot
.42003 .46605 Mdot
.568 .43601 Mdot
.60384 .34106 Mdot
.50342 .43469 Mdot
.63332 .52239 Mdot
.61796 .65787 Mdot
.50692 .54837 Mdot
.56436 .34322 Mdot
.69943 .56929 Mdot
.59377 .43806 Mdot
.50694 .65713 Mdot
.64744 .57184 Mdot
.44087 .38454 Mdot
.57048 .64874 Mdot
.61381 .37926 Mdot
.38697 .59161 Mdot
.5579 .39204 Mdot
.44939 .66334 Mdot
.39456 .47233 Mdot
.33412 .41162 Mdot
.40057 .4494 Mdot
.37316 .37853 Mdot
.38423 .64208 Mdot
.3828 .49884 Mdot
.43559 .34941 Mdot
.39659 .64414 Mdot
.52093 .42408 Mdot
.61753 .4564 Mdot
.68833 .52659 Mdot
.41267 .35403 Mdot
.34698 .56001 Mdot
.59946 .647 Mdot
.59342 .36991 Mdot
.35213 .40676 Mdot
.33558 .48572 Mdot
.66305 .55047 Mdot
.53734 .42588 Mdot
.47889 .30217 Mdot
.54694 .50031 Mdot
.50081 .32825 Mdot
.60684 .53516 Mdot
.57638 .68393 Mdot
.41218 .37538 Mdot
.62361 .46394 Mdot
.51508 .42683 Mdot
.38953 .58523 Mdot
.47107 .65757 Mdot
.36823 .60162 Mdot
.37501 .54832 Mdot
.48358 .2926 Mdot
.39371 .57599 Mdot
.62948 .4384 Mdot
.4418 .6042 Mdot
.57815 .3679 Mdot
.47966 .31643 Mdot
.56746 .41894 Mdot
.66274 .43406 Mdot
.3259 .52266 Mdot
.4268 .41245 Mdot
.61602 .65463 Mdot
.52562 .69624 Mdot
.3082 .53471 Mdot
.53123 .3429 Mdot
.34044 .49937 Mdot
.40267 .57202 Mdot
.45262 .41596 Mdot
.46315 .33269 Mdot
.50883 .46067 Mdot
.61484 .34136 Mdot
.44642 .62705 Mdot
.59336 .65064 Mdot
.51651 .66648 Mdot
.68558 .48381 Mdot
.56016 .34131 Mdot
.55809 .63259 Mdot
.49554 .57773 Mdot
.50373 .41766 Mdot
.43054 .32057 Mdot
.64258 .56344 Mdot
.66616 .37426 Mdot
.46133 .67694 Mdot
.3355 .4936 Mdot
.55849 .69296 Mdot
.50013 .60453 Mdot
.54435 .57772 Mdot
.34046 .5233 Mdot
.67986 .52583 Mdot
.56164 .64907 Mdot
.49444 .68849 Mdot
.35297 .45375 Mdot
.55741 .59815 Mdot
.47788 .32342 Mdot
.63619 .39783 Mdot
.53131 .57552 Mdot
.50708 .32536 Mdot
.68955 .50608 Mdot
.35564 .44337 Mdot
.3633 .53324 Mdot
.35226 .40308 Mdot
.3995 .66322 Mdot
.47258 .61691 Mdot
.49832 .35603 Mdot
.55778 .54381 Mdot
.6782 .55069 Mdot
.50479 .6685 Mdot
.57836 .34261 Mdot
.31947 .4653 Mdot
.64728 .37867 Mdot
.61104 .44424 Mdot
.4028 .58978 Mdot
.40545 .60334 Mdot
.61308 .59971 Mdot
.5994 .54397 Mdot
.46604 .56684 Mdot
.58714 .45324 Mdot
.43745 .62593 Mdot
.46742 .32505 Mdot
.33619 .45702 Mdot
.50268 .70122 Mdot
.46696 .29625 Mdot
.46885 .68307 Mdot
.4786 .68538 Mdot
.59751 .40967 Mdot
.57462 .59717 Mdot
.53026 .41294 Mdot
.52116 .39494 Mdot
.72835 .46186 Mdot
.31684 .53267 Mdot
.57176 .62744 Mdot
.58674 .43661 Mdot
.65743 .45794 Mdot
.50816 .61968 Mdot
.47932 .29701 Mdot
.66557 .49836 Mdot
.56594 .33162 Mdot
.58159 .37402 Mdot
.66761 .48377 Mdot
.61806 .53856 Mdot
.62168 .62171 Mdot
.39651 .40613 Mdot
.61784 .45291 Mdot
.45708 .37535 Mdot
.67941 .5066 Mdot
.42791 .54852 Mdot
.42246 .67246 Mdot
.35121 .54902 Mdot
.4072 .49925 Mdot
.4148 .4383 Mdot
.35048 .46306 Mdot
.37337 .36781 Mdot
.30345 .53074 Mdot
.65519 .44324 Mdot
.32601 .50766 Mdot
.51229 .63881 Mdot
.31492 .42351 Mdot
.5371 .39362 Mdot
.55591 .59728 Mdot
.39334 .62934 Mdot
.46585 .45699 Mdot
.52024 .34585 Mdot
.60964 .61837 Mdot
.52724 .66712 Mdot
.45702 .33534 Mdot
.3984 .66406 Mdot
.48129 .71166 Mdot
.67002 .55682 Mdot
.54432 .3106 Mdot
.51349 .67051 Mdot
.33596 .43489 Mdot
.66096 .40106 Mdot
.6487 .39068 Mdot
.61611 .59461 Mdot
.5063 .37583 Mdot
.69249 .44122 Mdot
.65063 .57888 Mdot
.43308 .31244 Mdot
.65793 .37821 Mdot
.38408 .45097 Mdot
.57124 .68136 Mdot
.38648 .64209 Mdot
.41628 .45167 Mdot
.3101 .42926 Mdot
.46771 .35157 Mdot
.39858 .6234 Mdot
.601 .45109 Mdot
.33291 .51215 Mdot
.62173 .39055 Mdot
.63576 .38445 Mdot
.67484 .54326 Mdot
.46564 .63362 Mdot
.65574 .40806 Mdot
.65703 .47007 Mdot
.44992 .67268 Mdot
.33745 .50208 Mdot
.40505 .43551 Mdot
.55632 .53787 Mdot
.45342 .44319 Mdot
.419 .37821 Mdot
.53412 .33361 Mdot
.56646 .31839 Mdot
.57458 .31238 Mdot
.34873 .53678 Mdot
.56297 .41077 Mdot
.45932 .51405 Mdot
.35953 .45348 Mdot
.65466 .49529 Mdot
.62315 .46207 Mdot
.60958 .38641 Mdot
.47268 .61729 Mdot
.43664 .71362 Mdot
.34386 .45674 Mdot
.4057 .53712 Mdot
.56815 .32942 Mdot
.67416 .51091 Mdot
.65623 .44297 Mdot
.33355 .48162 Mdot
.45966 .56288 Mdot
.39241 .50228 Mdot
.31916 .54693 Mdot
.41513 .34204 Mdot
.61811 .62208 Mdot
.3244 .55398 Mdot
.39756 .33159 Mdot
.66861 .46194 Mdot
.52737 .37687 Mdot
.69937 .55292 Mdot
.63329 .36521 Mdot
.38358 .54805 Mdot
.33082 .52459 Mdot
.59086 .44741 Mdot
.65441 .60081 Mdot
.4719 .64417 Mdot
.61858 .43716 Mdot
.63171 .38708 Mdot
.43152 .61942 Mdot
.69707 .46806 Mdot
.42751 .47728 Mdot
.70108 .57119 Mdot
.47444 .35418 Mdot
.33256 .47136 Mdot
.48153 .69876 Mdot
.37053 .42753 Mdot
.48201 .71332 Mdot
.48969 .6195 Mdot
.46612 .68421 Mdot
.36735 .57745 Mdot
.62213 .43471 Mdot
.32775 .50598 Mdot
.43448 .60591 Mdot
.33409 .46655 Mdot
.43009 .32659 Mdot
.66042 .59822 Mdot
.43705 .57068 Mdot
.37488 .56403 Mdot
.54858 .61773 Mdot
.58393 .60322 Mdot
.65383 .4267 Mdot
.49674 .32581 Mdot
.63457 .48796 Mdot
.41417 .68359 Mdot
.44507 .44698 Mdot
.48802 .36352 Mdot
.61608 .48111 Mdot
.48393 .36294 Mdot
.42445 .45987 Mdot
.41152 .66908 Mdot
.31735 .55583 Mdot
.57755 .65284 Mdot
.38231 .52582 Mdot
.30027 .52887 Mdot
.31358 .42388 Mdot
.48823 .71688 Mdot
.66225 .39796 Mdot
.33214 .54919 Mdot
.63951 .37758 Mdot
.46743 .35585 Mdot
.46637 .67823 Mdot
.37983 .58261 Mdot
.64758 .39264 Mdot
.43637 .70814 Mdot
.38608 .58181 Mdot
.6689 .37509 Mdot
.64451 .4298 Mdot
.46734 .29457 Mdot
.64687 .57521 Mdot
.52793 .63808 Mdot
.4637 .72249 Mdot
.32787 .41926 Mdot
.6297 .42945 Mdot
.61113 .59953 Mdot
.67006 .55458 Mdot
.61497 .37977 Mdot
.42413 .41816 Mdot
.6597 .54479 Mdot
.47103 .31739 Mdot
.38525 .60814 Mdot
.44474 .43916 Mdot
.57371 .61751 Mdot
.4182 .55055 Mdot
.42221 .38391 Mdot
.32488 .45528 Mdot
.36777 .37498 Mdot
.41564 .52215 Mdot
.43777 .35454 Mdot
.66782 .41274 Mdot
.4425 .30965 Mdot
.5764 .59285 Mdot
.50397 .6557 Mdot
.41383 .50577 Mdot
.58052 .53468 Mdot
.62267 .6616 Mdot
.32759 .54178 Mdot
.39515 .46961 Mdot
.65772 .42122 Mdot
.5873 .53025 Mdot
.51865 .62868 Mdot
.5309 .61803 Mdot
.40671 .42192 Mdot
.60942 .66297 Mdot
.34403 .57654 Mdot
.37248 .37367 Mdot
.44135 .70096 Mdot
.31429 .42797 Mdot
.54506 .40885 Mdot
.67775 .45276 Mdot
.63454 .43082 Mdot
.63538 .3741 Mdot
.45552 .39774 Mdot
.41774 .37502 Mdot
.6287 .65828 Mdot
.37124 .43937 Mdot
.48656 .45449 Mdot
.66734 .51485 Mdot
.40425 .54887 Mdot
.33576 .47429 Mdot
.43644 .45136 Mdot
.38672 .35118 Mdot
.45772 .32374 Mdot
.47348 .37505 Mdot
.65852 .50668 Mdot
.64345 .60756 Mdot
.65459 .43721 Mdot
.36936 .50765 Mdot
.53023 .67268 Mdot
.32314 .4859 Mdot
.51914 .36106 Mdot
.59131 .47522 Mdot
.57681 .61142 Mdot
.42076 .58104 Mdot
.3346 .52939 Mdot
.48767 .2964 Mdot
.41755 .53664 Mdot
.41989 .43559 Mdot
.34665 .47145 Mdot
.61426 .65439 Mdot
.50382 .51691 Mdot
.43059 .44618 Mdot
.34631 .44613 Mdot
.46424 .28921 Mdot
.39952 .59589 Mdot
.48156 .70447 Mdot
.68101 .45052 Mdot
.35029 .40669 Mdot
.3282 .52002 Mdot
.67359 .45427 Mdot
.58657 .45215 Mdot
.6584 .36654 Mdot
.43613 .43874 Mdot
.50292 .69453 Mdot
.63204 .57179 Mdot
.37309 .39262 Mdot
.46631 .42853 Mdot
.31176 .55909 Mdot
.50494 .36531 Mdot
.52726 .41374 Mdot
.46005 .68502 Mdot
.60452 .38448 Mdot
.42394 .64449 Mdot
.66433 .53684 Mdot
.47436 .3479 Mdot
.6099 .34304 Mdot
.45481 .29886 Mdot
.53519 .5856 Mdot
.68866 .5112 Mdot
.55969 .40978 Mdot
.53982 .67366 Mdot
.58288 .51022 Mdot
.69958 .46219 Mdot
.5592 .67012 Mdot
.37967 .43605 Mdot
.56424 .56921 Mdot
.73226 .4665 Mdot
.44075 .61704 Mdot
.52187 .54695 Mdot
.58327 .58696 Mdot
.50082 .60399 Mdot
.50166 .57856 Mdot
.64004 .57135 Mdot
.51392 .52679 Mdot
.58418 .64773 Mdot
.62885 .55543 Mdot
.40541 .45687 Mdot
.61296 .43005 Mdot
.47088 .39015 Mdot
.40169 .32573 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0?ooooooB_ooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A006ooooo`03o`000?oooooooooo0?ooooooB_ooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0?ooooooB_oo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06
ooooo`?o0000oooooom:ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<oooo
o`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom:ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001_ooool00ol0003oooooooooo`3ooooood[ooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0W?ooool5o`0000?ooooo
0_l0002Sooooo`007?ooool00ol0003oooooooooo`2Goooooa;o0000X?ooool001cooooo00?o0000
ooooooooool0U?oooolFo`0009oooooo000Looooo`03o`000?oooooooooo09?ooooo6?l0002Noooo
o`007?ooool00ol0003oooooooooo`2Boooooago0000V_ooool001cooooo00?o0000ooooooooool0
Soooool2o`000003ooooool0003o000000So000000?oooooo`000?l000004?l0002Jooooo`007?oo
ool00ol0003oooooooooo`2>ooooob;o0000VOooool001cooooo00?o0000ooooooooool0RooooolW
o`0009Oooooo000Looooo`03o`000?oooooooooo08Oooooo:ol0002Gooooo`007?ooool00ol0003o
ooooooooo`27ooooobgo0000UOooool001cooooo00?o0000ooooooooool0QOoooolBo`0000;ooooo
3?l00002ooooo`oo0000Toooool001cooooo00?o0000ooooooooool0Poooool?o`0000;ooooo0_l0
0003oooooaoo0000TOooool001cooooo00?o0000ooooooooool0P_ooool@o`0000;ooooo0_l00002
ooooob7o00001?ooool2o`0008[ooooo000Looooo`;o0000POoooolFo`0000;ooooo0_l000000ooo
oooo0000o`000002ooooob;o0000R?ooool001cooooo00?o0000ooooooooool0P?oooolEo`0000?o
oooo0_l00005ooooob;o00000_ooool3o`0008?ooooo000Looooo`03o`000?oooooooooo07kooooo
4?l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00000ooooolKo`000003
ooooool0003o000000?o000000?oooooo`000?l000001?l00020ooooo`007?ooool00ol0003ooooo
ooooo`1nooooo`go000000Coooooo`000?l0003ooooo0_l00004ooooo`;o00001Oooool2o`0000Oo
oooo3?l0000<ooooo`co0000P?ooool001cooooo00?o0000ooooooooool0OOooool>o`000004oooo
ool0003o0000ooooo`;o00003oooool2o`0000Oooooo1_l00005ooooo`;o000000?oooooo`000?l0
00000oooool@o`0007gooooo000Looooo`03o`000?oooooooooo07cooooo3ol0000=ooooo`;o0000
1_ooool2o`0000?ooooo0_l000000ooooooo0000o`00000:ooooo`;o000000?oooooo`000?l00000
4ol0001mooooo`007?ooool00ol0003oooooooooo`1kooooo`go00003Oooool2o`000003ooooool0
003o000000;ooooo0_l00007ooooo`;o000000?oooooo`000?l000002_ooool2o`0000?ooooo5?l0
001looooo`007?ooool00ol0003oooooooooo`1kooooo`co000000?oooooo`000?l000002oooool2
o`0000Gooooo0_l00006ooooo`;o00003_ooool2o`0000Kooooo4_l0001kooooo`007?ooool00ol0
003oooooooooo`1kooooo`Oo00001_ooool2o`0000Oooooo0_l000001?oooooo0000o`000?ooool2
o`0000Gooooo0_l000001?oooooo0000o`000?ooool2o`0000_ooooo0_l0000:oooooa;o0000N_oo
ool001cooooo00?o0000ooooooooool0NOooool8o`0000Cooooo0_l000000ooooooo0000o`000006
ooooo`?o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o000000?oooooo`000?l000000ol0
000>ooooo`;o00000_ooool2o`0000Gooooo0_l00002oooooa3o0000NOooool001cooooo00?o0000
ooooooooool0NOooool6o`0000Kooooo0_l000000ooooooo0000o`000006ooooo`;o00000_ooool2
o`0000Gooooo0_l00002ooooo`;o00003_ooool8o`0000Gooooo0_l00002oooooa7o0000N?ooool0
01cooooo00?o0000ooooooooool0NOooool6o`0000?ooooo0_l0000=ooooo`Co00005Oooool2o`00
00?ooooo1ol00002ooooo`;o00001oooool@o`0007Sooooo000Looooo`03o`000?oooooooooo07Wo
oooo1Ol00002ooooo`Co00002oooool6o`0001Gooooo0_l0000<ooooo`;o00000_ooool2o`0000?o
oooo4?l0001hooooo`007?ooool00ol0003oooooooooo`1iooooo`Co00000oooool2o`0000gooooo
0ol0000Gooooo`;o00001oooool2o`0000Sooooo0_l00002oooooa;o0000Moooool001cooooo00?o
0000ooooooooool0Moooool5o`0000Kooooo0ol00003ooooo`;o00001Oooool3o`0000?ooooo0_l0
000Aooooo`?o000000?oooooo`000?l000001?ooool4o`0000;ooooo0_l00006oooooa;o0000Mooo
ool001cooooo00?o0000ooooooooool0Loooool3o`000003ooooool0003o000000?o00001_ooool3
o`0000?ooooo0_l0000;ooooo`?o00003Oooool2o`000005ooooool0003o0000o`000?ooool00_l0
0006ooooo`?o000000?oooooo`000?l000001_ooool5o`000003ooooool0003o000000[o0000Mooo
ool001cooooo0_l0001cooooo`Wo00003oooool2o`0000[ooooo0_l00005ooooo`;o00001_ooool2
o`0000Oooooo0_l00005ooooo`;o00001_ooool2o`0000[ooooo2Ol0001gooooo`007?ooool00ol0
003oooooooooo`1booooo`[o00001Oooool3o`0000Kooooo0_l00002ooooo`;o00001?ooool2o`00
00Oooooo0_l0000=ooooo`Co00000_ooool2o`0000Wooooo0_l0000<ooooo`co0000L_ooool001co
oooo00?o0000ooooooooool0LOooool;o`0000Gooooo0ol00005ooooo`?o00000_ooool2o`0000Co
oooo1?l00006ooooo`Co00002_ooool4o`0000;ooooo0_l00009ooooo`;o00003Oooool=o`00073o
oooo000Looooo`03o`000?oooooooooo073ooooo2Ol0000@ooooo`?o00001?ooool2o`0000;ooooo
1?l00003ooooo`;o000000?oooooo`000?l000000_l00005ooooo`;o00002Oooool2o`0000Wooooo
0_l00003ooooo`;o00002?ooool4o`000003ooooool0003o000000Ko0000L?ooool001cooooo00?o
0000ooooooooool0Koooool:o`0000Wooooo0_l0000<ooooo`;o00001oooool7o`0000Gooooo1?l0
0006ooooo`;o00003?ooool2o`0000?ooooo0_l0000Booooo`Oo0000K?ooool001cooooo00?o0000
ooooooooool0K_ooool:o`0000[ooooo0_l0000Eooooo`Ko000000?oooooo`000?l000000oooool2
o`0000Sooooo0_l00007ooooo`;o00001Oooool2o`0000Wooooo0_l0000;ooooo`Oo0000Joooool0
01cooooo00?o0000ooooooooool0K_ooool<o`0000Cooooo0_l00002ooooo`;o00004Oooool2o`00
00Cooooo0_l00003ooooo`;o00000oooool2o`000003ooooool0003o000000gooooo0ol00003oooo
o`Co00001_ooool2o`000003ooooool0003o000000Kooooo0_l00004ooooo`Ko0000Joooool001co
oooo00?o0000ooooooooool0JOoooolAo`0000Cooooo0_l00002ooooo`;o00004Oooool2o`0000So
oooo0_l00004ooooo`;o000000?oooooo`000?l000003Oooool3o`0000?ooooo0_l00008ooooo`;o
000000?oooooo`000?l000001_ooool2o`0000Cooooo2?l0001Yooooo`007?ooool00ol0003ooooo
ooooo`1Uoooooa;o00002oooool4o`0000_ooooo0_l00003ooooo`;o00001oooool2o`0001Sooooo
0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000000?ooooo0ol00008ooooo`;o0000
0_ooool7o`0006Wooooo000Looooo`03o`000?oooooooooo06;ooooo5Ol00008ooooo`;o000000?o
ooooo`000?l000000_l0000:ooooo`?o00000oooool2o`0000Oooooo1?l00005ooooo`;o00001ooo
ool2o`0000Kooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0ol00003ooooo`Go0000
0_ooool2o`000004ooooool0003o0000ooooo`So0000JOooool001cooooo00?o0000ooooooooool0
H_ooool;o`000003ooooool0003o000000Oo00002?ooool2o`0000;ooooo0ol00005ooooo`Co0000
00?oooooo`000?l000000oooool2o`0000Sooooo1?l00005ooooo`;o00001oooool2o`0000[ooooo
1?l00003ooooo`Co00001?ooool4o`000004ooooool0003o0000o`0000?ooooo2_l0001Xooooo`00
7?ooool00ol0003oooooooooo`1QoooooaCo00001Oooool2o`0000Oooooo1?l00004ooooo`Co0000
00Coooooo`000?l0003ooooo1?l00007ooooo`Co00006oooool3o`000004ooooool0003o0000oooo
o`;o00000oooool6o`0000;ooooo0_l00003ooooo`_o0000J?ooool001cooooo00?o0000oooooooo
ool0GooooolDo`0000Oooooo0_l00009ooooo`;o00001?ooool2o`0000Kooooo0_l00009ooooo`Co
00007oooool3o`0000Cooooo1ol00007ooooo`co0000Ioooool001cooooo00?o0000ooooooooool0
G_oooolDo`0000gooooo0_l0000;ooooo`;o00001oooool2o`0001gooooo0_l0000<ooooo`;o0000
0_ooool5o`0000Cooooo0_l00004ooooo`go0000Ioooool00006ooooooo^k^ko<S8bo`000?lb<S;o
k^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo05ko
oooo5?l00003ooooo`;o00002?ooool2o`0000_ooooo0_l00007ooooo`;o00002?ooool2o`0000[o
oooo0ol00003ooooo`;o000000?oooooo`000?l000003oooool3o`0000Oooooo0_l00004ooooo`go
0000Ioooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`1MoooooaCo00001?ooool2o`0000Kooooo0_l0000Poooo
o`;o00001Oooool2o`0000?ooooo0ol00003ooooo`;o00004_ooool2o`0000Sooooo0_l00002oooo
o`oo0000Ioooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool5o`0000Ko
oooo00?o0000ooooooooool0GOooool2o`000003ooooool0003o000000ko00003Oooool4o`0000oo
oooo0_l0000Dooooo`?o00000_ooool2o`0001kooooo0_l00006oooooa3o0000I_ooool00003oooo
ool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?m4A4CogMgMooooool00007ooooo`?o
0000G_oooolCo`0000gooooo0ol0000?ooooo`;o00005Oooool2o`0000;ooooo0_l0000Eooooo`?o
00001_ooool2o`0000Kooooo4?l0001Vooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooo
ooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0G_ooool@o`000003
ooooool0003o000000cooooo0ol000000ooooooo0000o`000002o`0001oooooo0_l0000Kooooo`Co
000000?oooooo`000?l000002_oooolAo`0006Kooooo00000ooooooo410@ooooo`02ooooo`03oa0@
4?oooooooooo00[ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`1MoooooaCo0000
0oooool2o`0000Oooooo0_l00002ooooo`So00006oooool2o`0000Oooooo0_l0000@ooooo`Co0000
0oooool2o`0000Kooooo0_l000001?oooooo0000o`000?l00002ooooo`co0000Ioooool00006oooo
oomgMgOoV9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo
05cooooo4?l00002ooooo`?o00000oooool2o`0000oooooo1?l00008ooooo`;o00001oooool2o`00
017ooooo0_l00003ooooo`?o000000?oooooo`000?l000001_ooool5o`0000Cooooo0_l00005oooo
o`Go00000oooool<o`0006Oooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPgooooo00?oMgMg
o`000?ooool01_ooool00ol0003oooooooooo`1Loooooa3o00006_ooool3o`0000Sooooo0_l00007
ooooo`;o00003?ooool2o`0000Sooooo0ol000000ooooooo0000o`000006ooooo`;o00001oooool2
o`0000Kooooo0_l00004ooooo`go0000Ioooool001cooooo00?o0000ooooooooool0G?ooool<o`00
00;ooooo0_l0000Jooooo`;o00001_ooool3o`0000oooooo0_l00006ooooo`;o00007oooool2o`00
00[ooooo3Ol0001Wooooo`007?ooool00ol0003oooooooooo`1Mooooo`Go000000Goooooo`000?l0
003o0000ooooo`02o`00013ooooo0_l0000;ooooo`;o00001_ooool3o`0000oooooo0_l0000Aoooo
o`Co00002oooool2o`0000Gooooo0ol00006ooooo`;o00000oooool:o`0006Sooooo000Looooo`03
o`000?oooooooooo05gooooo2?l00002ooooo`;o00004?ooool2o`0000Gooooo0_l0000Nooooo`;o
00000_ooool3o`0000cooooo1?l00007ooooo`;o00000_ooool2o`0000Kooooo0_l00006ooooo`;o
00000oooool:o`0006Sooooo000Looooo`03o`000?oooooooooo05gooooo2?l0000=ooooo`;o0000
00?oooooo`000?l000002Oooool2o`0000Sooooo0_l0000Dooooo`;o00000_ooool3o`0000Cooooo
0_l0000Aooooo`;o00004?ooool3o`0000Gooooo1_l0001[ooooo`007?ooool00ol0003ooooooooo
o`1Mooooo`Oo00003_ooool2o`000003ooooool0003o000001?ooooo0_l00008ooooo`;o00000_oo
ool2o`0000[ooooo0_l00005ooooo`;o00005_ooool2o`0000Cooooo0ol00002ooooo`Go00001?oo
ool7o`0006_ooooo000Looooo`03o`000?oooooooooo05gooooo2?l0000:ooooo`;o00001_ooool2
o`0001Cooooo0_l00004ooooo`?o00000_ooool2o`0001Wooooo0_l0000>ooooo`;o00000_ooool5
o`0000;ooooo0_l00002ooooo`?o000000Goooooo`000?l0003o0000ooooo`05o`0006[ooooo000L
ooooo`03o`000?oooooooooo05gooooo1Ol000000ooooooo0000o`000004ooooo`;o000000Cooooo
o`000?l0003ooooo0_l00006ooooo`?o00001_ooool2o`0000?ooooo0_l00006ooooo`;o00001?oo
ool2o`0000_ooooo0_l0000Aooooo`Go00000oooool2o`0000Cooooo0_l00002ooooo`Co00002?oo
ool4o`000003ooooool0003o000000?ooooo1_l0001Xooooo`007?ooool00ol0003oooooooooo`1M
ooooo`Go00001oooool2o`000003ooooool0003o000000Oooooo0_l000000ooooooo0000o`000006
ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o000000?oooooo`000?l000004Oooool2
o`0001?ooooo0ol00003ooooo`Co00000_ooool2o`0000;ooooo0ol000000ooooooo0000o`000006
ooooo`?o00001?ooool2o`0000?ooooo1_l0001Vooooo`007?ooool00ol0003oooooooooo`1Moooo
o`Go000000?oooooo`000?l000001Oooool2o`0000?ooooo0ol00003ooooo`;o00001Oooool2o`00
00Gooooo0_l00005ooooo`;o000000Coooooo`000?l0003ooooo0_l0000<ooooo`;o00000oooool2
o`0000gooooo0_l00009ooooo`;o00002Oooool3o`0000?ooooo0_l000001?oooooo0000o`000?l0
0004ooooo`;o00000oooool2o`000003ooooool0003o000000?o0000I?ooool001cooooo00?o0000
ooooooooool0GOooool2o`000004ooooool0003o0000ooooo`;o00001Oooool2o`000003ooooool0
003o000000?o00001Oooool2o`0000?ooooo0_l0000:ooooo`Co00001?ooool2o`0000cooooo0_l0
0003ooooo`;o00003Oooool2o`0000oooooo0_l00003ooooo`;o00001?ooool2o`000003ooooool0
003o000000[ooooo0_l00002ooooo`Go0000Hoooool001cooooo00?o0000ooooooooool0GOooool6
o`0000Wooooo1?l00007ooooo`;o00001Oooool2o`0000Sooooo1?l000000ooooooo0000o`000002
ooooo`;o0000:Oooool2o`0000?ooooo1?l00003ooooo`;o00006_ooool4o`00067ooooo000Loooo
o`;o0000G_ooool6o`0000Wooooo1?l00004ooooo`;o00000oooool2o`0000?ooooo1?l000000ooo
oooo0000o`000005ooooo`;o000000?oooooo`000?l000000_ooool2o`0002Sooooo0ol000000ooo
oooo0000o`000002o`0001Kooooo0_l0000:ooooo`Go0000Goooool001cooooo00?o0000oooooooo
ool0GOooool6o`0000?ooooo0_l00002ooooo`;o00000oooool4o`000003ooooool0003o000000?o
oooo0_l00005ooooo`;o000000?oooooo`000?l000001Oooool2o`0000kooooo0_l0000Oooooo`?o
000000Coooooo`000?l0003o00000oooool2o`00013ooooo1?l000000ooooooo0000o`000009oooo
o`Co0000G_ooool001cooooo00?o0000ooooooooool0GOooool6o`0000?ooooo0_l000000ooooooo
0000o`000003o`000003ooooool0003o000000;o00003Oooool2o`0001;ooooo0_l00004ooooo`;o
00007oooool3o`0000;ooooo0_l00002ooooo`?o00002oooool2o`0000?ooooo0ol00002ooooo`;o
00002?ooool6o`0005gooooo000Looooo`03o`000?oooooooooo05_ooooo1ol00007ooooo`Go0000
0oooool2o`0000gooooo0_l00004ooooo`;o00003?ooool2o`0000cooooo0_l0000Mooooo`;o0000
00Coooooo`000?l0003o00002Oooool4o`0000?ooooo0_l00003ooooo`Co000000Coooooo`000?l0
003ooooo2Ol0001Looooo`007?ooool00ol0003oooooooooo`1Jooooo`Wo00002?ooool2o`000003
ooooool0003o000001Kooooo0_l00003ooooo`;o00001?ooool2o`0000;ooooo0_l0000;ooooo`;o
00007Oooool2o`0000Cooooo0_l00007ooooo`;o00000oooool2o`0000;ooooo0_l000000ooooooo
0000o`00000@o`0005_ooooo000Looooo`03o`000?oooooooooo05Oooooo3?l000000ooooooo0000
o`000003ooooo`;o00000oooool2o`0000;ooooo0_l0000Aooooo`;o00001?ooool2o`0000Cooooo
0_l00002ooooo`;o00007?ooool2o`0001;ooooo0_l00006ooooo`;o00001?ooool2o`000004oooo
ool0003o0000o`0000Cooooo3ol0001Kooooo`007?ooool00ol0003oooooooooo`1Gooooo`co0000
00?oooooo`000?l000000oooool2o`0000Gooooo1?l00009ooooo`;o00001_ooool2o`0000[ooooo
0_l0000;ooooo`;o00004oooool2o`0001[ooooo0_l000000ooooooo0000o`000004ooooo`?o0000
1?ooool?o`0005_ooooo000Looooo`03o`000?oooooooooo05Kooooo3Ol00005ooooo`;o00000ooo
ool2o`000004ooooool0003o0000ooooo`;o00001oooool3o`0001?ooooo0_l0000:ooooo`;o0000
5?ooool2o`00017ooooo0_l00009ooooo`;o00001?ooool3o`0000Cooooo4?l0001Jooooo`007?oo
ool00ol0003oooooooooo`1Eooooo`ko00001Oooool4o`000004ooooool0003o0000o`0000?ooooo
0_l00007ooooo`;o00002Oooool2o`0000Wooooo0_l0000>ooooo`;o00003Oooool2o`000003oooo
ool0003o000000Kooooo0_l00009ooooo`;o00003_ooool3o`0000Gooooo4?l0001Jooooo`007?oo
ool00ol0003oooooooooo`1Dooooo`oo00001_ooool3o`0000;ooooo0_l0000<ooooo`;o000000?o
ooooo`000?l000001_ooool2o`0001Wooooo0_l0000=ooooo`;o00002Oooool2o`0000Wooooo0_l0
000=ooooo`?o00000_ooool2o`000003ooooool0003o000000oo0000F_ooool001cooooo00?o0000
ooooooooool0E?ooool?o`0000Kooooo0_l0000Dooooo`;o00003?ooool2o`0003Gooooo0_l00000
0ooooooo0000o`00000:ooooo`;o000000?oooooo`000?l000000oooool2o`000003ooooool0003o
000000oo0000F_ooool001cooooo00?o0000ooooooooool0E?ooool?o`0000;ooooo0_l00002oooo
o`?o00007Oooool2o`0000;ooooo0ol00004ooooo`;o0000;_ooool2o`0000Oooooo0_l00002oooo
o`Ko00001?ooool2o`000003ooooool0003o000000oo0000F_ooool001cooooo00?o0000oooooooo
ool0Doooool@o`0000;ooooo0_l00002ooooo`?o00007Oooool2o`0000?ooooo0_l00004ooooo`;o
0000;?ooool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000002ooooo`;o
00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`00000?o`0005[ooooo000Looooo`03o`00
0?oooooooooo05?ooooo4?l00007ooooo`;o00001?ooool2o`0000Gooooo0_l0000<ooooo`Co0000
>Oooool2o`000003ooooool0003o000000?ooooo0_l0000Aoooooa;o0000F_ooool001cooooo00?o
0000ooooooooool0Doooool@o`0000Kooooo0_l00004ooooo`?o00001Oooool2o`0000cooooo1?l0
0017ooooo`?o00002_oooolBo`0005[ooooo000Looooo`03o`000?oooooooooo05?ooooo4Ol00005
ooooo`?o00000oooool2o`0000Sooooo0_l0001Dooooo`Co000000?oooooo`000?l000000_ooool2
o`0000?ooooo4_l0001Jooooo`007?ooool2o`0005?ooooo4_l00006ooooo`?o00000_ooool2o`00
00Sooooo0_l00006ooooo`;o00003_ooool2o`0000;ooooo0_l0000Eooooo`Co00001oooool2o`00
01Kooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`00000<o`00
05_ooooo000Looooo`03o`000?oooooooooo05;ooooo4ol00005ooooo`?o00000_ooool2o`000003
ooooool0003o000000Sooooo0_l00003ooooo`;o00003_ooool2o`0000;ooooo0_l0000Eooooo`Co
00000oooool2o`0000;ooooo0_l0000Tooooo`oo0000GOooool001cooooo00?o0000ooooooooool0
Doooool?o`000004ooooool0003o0000ooooo`?o000000?oooooo`000?l000001_ooool4o`0000;o
oooo0_l00002ooooo`;o00001Oooool2o`0002kooooo0_l0000Mooooo`;o00000_ooool5o`000003
ooooool0003o000000ko0000GOooool001cooooo00?o0000ooooooooool0D_ooool>o`0000Kooooo
0ol000000ooooooo0000o`000008ooooo`Ko00002Oooool2o`0003Gooooo0_l0000Fooooo`;o0000
0_ooool5o`000003ooooool0003o000000ko0000GOooool001cooooo00?o0000ooooooooool0D_oo
ool@o`0000Kooooo1?l00008ooooo`Co00006Oooool2o`0002Cooooo0_l000000ooooooo0000o`00
000=ooooo`;o00001oooool2o`0000?ooooo0_l00003oooooa3o0000GOooool001cooooo00?o0000
ooooooooool0DOoooolAo`0000Kooooo0_l0000Rooooo`;o00000oooool2o`0000gooooo0_l0000E
ooooo`;o00000oooool2o`0000_ooooo0_l0000:ooooo`;o00001Oooool>o`0005oooooo000Loooo
o`03o`000?oooooooooo057ooooo4?l00006ooooo`;o00008oooool2o`0001;ooooo0_l0000<oooo
o`;o00003?ooool3o`0001Kooooo0_l00007ooooo`co0000Goooool001cooooo00?o0000oooooooo
ool0D_ooool>o`0000Kooooo0ol00002ooooo`;o00004oooool2o`000003ooooool0003o000000;o
oooo0_l0000Uooooo`;o00003Oooool2o`0000_ooooo0_l0000Booooo`Wo0000H_ooool001cooooo
00?o0000ooooooooool0D_ooool<o`0000Sooooo1?l000000ooooooo0000o`00000;ooooo`;o0000
1_ooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000002o`0002;ooooo
0_l00008ooooo`Co00003?ooool2o`0000gooooo0_l000000ooooooo0000o`000009o`0006;ooooo
000Looooo`03o`000?oooooooooo05;ooooo1_l000000ooooooo0000o`000002o`000003ooooool0
003o000000Oooooo1?l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00009ooooo`Co00005Ooo
ool2o`0000_ooooo0_l00008ooooo`Co00000oooool2o`0000cooooo0_l00008ooooo`;o000000?o
ooooo`000?l000002Ol0001Rooooo`007?ooool00ol0003oooooooooo`1Cooooo`Oo000000Cooooo
o`000?l0003ooooo0ol00002ooooo`;o00000_ooool4o`0000Kooooo0_l0000<ooooo`;o00008_oo
ool2o`0001Gooooo0ol00004ooooo`;o00001?ooool2o`0000Cooooo1?l00004ooooo`;o00001Ooo
ool2o`000003ooooool0003o000000Go0000Hoooool001cooooo00?o0000ooooooooool0Doooool7
o`0000Cooooo2Ol0000;ooooo`;o0000AOooool6o`0000;ooooo0_l00002ooooo`Co00001?ooool2
o`0000Kooooo1ol00003ooooo`Oo0000Hoooool001cooooo00?o0000ooooooooool0Doooool5o`00
00Sooooo0ol000001?oooooo0000o`000?l00005ooooo`Co00000_ooool2o`0000cooooo0_l00002
ooooo`;o00007_ooool2o`0000_ooooo0_l00006ooooo`;o00000_ooool2o`0000;ooooo0_l00002
ooooo`Co00002?ooool2o`000003ooooool0003o000000Ko00000oooool6o`0006Cooooo000Loooo
o`03o`000?oooooooooo05Gooooo0ol0000<ooooo`;o000000?oooooo`000?l000000oooool4o`00
00;ooooo0ol0000;ooooo`;o00000_ooool2o`0000Wooooo0_l0000Cooooo`;o00002oooool2o`00
00;ooooo0_l00005ooooo`Go00001?ooool2o`0000Gooooo0_l00003ooooo`;o000000?oooooo`00
0?l000002?ooool7o`0006Cooooo000Looooo`03o`000?oooooooooo05Gooooo1Ol00003ooooo`Co
00001_ooool2o`0000Wooooo0ol0000Jooooo`;o00001Oooool2o`0000[ooooo0_l0000=ooooo`?o
000000?oooooo`000?l000001Oooool5o`000003ooooool0003o000000Sooooo0_l00004ooooo`;o
000000?oooooo`000?l000000_l00003ooooo`Wo0000I?ooool001cooooo00?o0000ooooooooool0
EOooool6o`0000;ooooo1Ol00002ooooo`;o00000_ooool2o`0000Wooooo0_l00004ooooo`;o0000
6oooool2o`0000[ooooo0_l00002ooooo`;o00002Oooool3o`0000_ooooo0_l000000ooooooo0000
o`000002o`0000[ooooo1?l000000ooooooo0000o`000002o`0000?ooooo2_l0001Sooooo`007?oo
ool2o`0005Sooooo1Ol00002ooooo`Co00000_ooool2o`0000;ooooo0_l00004ooooo`?o00001Ooo
ool2o`000003ooooool0003o000000?ooooo1?l00002ooooo`;o000000?oooooo`000?l000006?oo
ool2o`0000?ooooo0_l0000Booooo`;o00002?ooool2o`0000[ooooo0_l00002ooooo`?o00000_oo
ool2o`0000?ooooo2?l0001Sooooo`007?ooool00ol0003oooooooooo`1Hooooo`So00001_ooool4
o`0000Cooooo0ol00005ooooo`;o00001_ooool4o`0000;ooooo0_l000000ooooooo0000o`00000H
ooooo`;o00005oooool2o`0000[ooooo0_l0000:ooooo`Co00000_ooool3o`0000Cooooo1_l0001T
ooooo`007?ooool00ol0003oooooooooo`1Iooooo`Oo00000oooool2o`000003ooooool0003o0000
00_ooooo0_l0000gooooo`;o00002_ooool2o`0000cooooo1?l00002ooooo`;o00001?ooool2o`00
00;ooooo1_l00003ooooo`Ko0000I?ooool001cooooo00?o0000ooooooooool0Foooool:o`0000So
oooo0_l00004ooooo`;o00000oooool2o`0000oooooo0_l0000Qooooo`;o00002_ooool2o`0000Co
oooo0_l00007ooooo`?o00000_ooool2o`0000Sooooo0_l00002ooooo`;o00001Oooool4o`0006Co
oooo000Looooo`03o`000?oooooooooo05cooooo2_l00007ooooo`;o00002Oooool2o`0000gooooo
1?l00007ooooo`;o0000:_ooool2o`0000Oooooo0_l00004ooooo`;o00004oooool4o`0006?ooooo
000Looooo`03o`000?oooooooooo05oooooo1ol00002ooooo`?o00002oooool2o`0000oooooo0_l0
0009ooooo`;o00002Oooool2o`0001oooooo0ol0000<ooooo`;o00001?ooool2o`0000Kooooo0_l0
0004ooooo`Go0000Hoooool001cooooo00?o0000ooooooooool0H?ooool;o`0000?ooooo0_l00006
ooooo`;o00003?ooool2o`0000kooooo0_l000000ooooooo0000o`000004ooooo`;o00005Oooool2
o`0000Sooooo0ol0000Booooo`;o00001_ooool;o`0006?ooooo000Looooo`03o`000?oooooooooo
06;ooooo1ol00005ooooo`;o00003oooool4o`000003ooooool0003o000000Cooooo0_l00003oooo
o`;o00000oooool2o`000003ooooool0003o000001_ooooo1?l0000<ooooo`;o00001?ooool4o`00
0004ooooool0003o0000o`0000Cooooo0_l00004ooooo`So0000IOooool001cooooo00?o0000oooo
ooooool0IOooool6o`0000[ooooo0_l00003ooooo`;o00000oooool4o`000003ooooool0003o0000
00Cooooo1?l000000ooooooo0000o`00000Dooooo`;o00000_ooool2o`0000_ooooo0_l0000<oooo
o`;o00000oooool?o`0000Oooooo1_l0001Tooooo`007?ooool00ol0003oooooooooo`1Uooooo`Wo
00001_ooool4o`0000;ooooo1?l0000>ooooo`;o000000?oooooo`000?l000003?ooool5o`0000?o
oooo0_l00002ooooo`;o00000_ooool2o`0001[ooooo0_l00003ooooo`So00002Oooool7o`0006?o
oooo000Looooo`03o`000?oooooooooo06Kooooo2?l00006ooooo`Co00000_ooool4o`0000Oooooo
0_l00008ooooo`;o00003?ooool5o`0000Cooooo0_l00005ooooo`;o00005_ooool2o`0000Wooooo
0_l00002ooooo`;o00000oooool=o`0006?ooooo000Looooo`03o`000?oooooooooo06Sooooo1ol0
0005ooooo`;o00000_ooool4o`0000Wooooo0_l00007ooooo`;o00001?ooool2o`0000Sooooo0_l0
0006ooooo`;o00007Oooool2o`0000Gooooo0_l00003ooooo`;o000000?oooooo`000?l000000ooo
ool<o`0006Cooooo000Looooo`03o`000?oooooooooo06Kooooo2_l00004ooooo`;o00000_ooool5
o`000003ooooool0003o000000kooooo0_l00004ooooo`;o00002?ooool4o`0000Sooooo0_l0000;
ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Gooooo0_l000000ooooooo0000o`000002
o`0000Cooooo3_l0001Tooooo`007?ooool00ol0003oooooooooo`1Vooooo`_o00001oooool5o`00
0003ooooool0003o000000;o00007_ooool2o`0000Sooooo0_l00002ooooo`;o00001oooool2o`00
0004ooooool0003o0000ooooo`;o00004?ooool2o`0000?ooooo0_l000000ooooooo0000o`00000<
o`0006Cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`1Wooooo`[o00001_ooool5o`0000;ooooo
1?l00005ooooo`;o00007_ooool2o`0000Gooooo1?l00005ooooo`;o00001?ooool2o`00017ooooo
0_l000000ooooooo0000o`00000?o`0006Gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1Xoooo
o`[o00001Oooool2o`000003ooooool0003o000000;ooooo0_l00007ooooo`;o00007_ooool2o`00
00?ooooo0_l00002ooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`;o00000_ooool2o`00
00Kooooo0_l000000ooooooo0000o`00000?o`0006Gooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
06Oooooo3?l00004ooooo`;o00001Oooool2o`0000;ooooo0_l00006ooooo`;o00000oooool2o`00
01_ooooo0_l00003ooooo`;o00001?ooool2o`0000[ooooo0ol00002ooooo`;o00001Oooool2o`00
00;ooooo4Ol0001Uooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05
o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0006Oooooo3ol000001?oooooo0000o`000?ooool2
o`0000Cooooo1?l00006ooooo`;o00000oooool2o`00023ooooo0_l00007ooooo`;o00001oooool2
o`0000[ooooo5Ol0001Uooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09oooo
o`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`1Xooooo`ko00001?ooool4
o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000002Oooool2
o`0000Kooooo0_l00006ooooo`;o00003oooool4o`0001Gooooo0_l000000ooooooo0000o`00000>
o`0006Gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEEohN7
Qoooool02?ooool00ol0003oooooooooo`1Xooooo`co00001Oooool2o`000003ooooool0003o0000
00;o00000oooool2o`0000Cooooo0_l000000ooooooo0000o`000009ooooo`;o00001Oooool3o`00
00Kooooo0_l0000?ooooo`;o00001oooool2o`0000[ooooo0_l00002oooooa;o0000I_ooool00006
oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooo
oooo06Sooooo3Ol00004ooooo`Co000000?oooooo`000?l000005oooool2o`0000Cooooo1?l0000C
ooooo`;o00000_ooool3o`0000Kooooo0_l0000:ooooo`?o000000?oooooo`000?l000003ol0001W
ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo
00?o0000ooooooooool0JOooool<o`0000Kooooo0ol0000Iooooo`;o00001?ooool4o`0001?ooooo
0_l00002ooooo`?o00001_ooool2o`0000Cooooo0_l00005ooooo`;o000000?oooooo`000?l00000
2Ol000000ooooooo0000o`000002o`0006Sooooo000Looooo`03o`000?oooooooooo06Wooooo3?l0
0007ooooo`;o00003Oooool2o`0000Gooooo0_l00002ooooo`;o00003?ooool2o`0000?ooooo0_l0
0003ooooo`;o000000?oooooo`000?l000000_ooool4o`0000Sooooo0ol00003ooooo`?o00001_oo
oolAo`0006Sooooo000Looooo`03o`000?oooooooooo06Wooooo3?l00002ooooo`;o00001oooool2
o`0000Kooooo0_l000000ooooooo0000o`000005ooooo`;o000000Coooooo`000?l0003o00000ooo
ool2o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`;o00000_ooool3o`000003ooooool0
003o000000;ooooo1?l00008ooooo`?o00000_ooool4o`0000Gooooo4_l0001Xooooo`007?ooool0
0ol0003oooooooooo`1Yooooo`co00000_ooool2o`0000Gooooo1?l00006ooooo`;o00002oooool2
o`0000Cooooo0_l00004ooooo`;o00002_ooool2o`0001Kooooo0ol00007oooooa;o0000J?ooool0
01cooooo00?o0000ooooooooool0J_ooool=o`000003ooooool0003o000000;ooooo1?l0000:oooo
o`;o000000?oooooo`000?l000009oooool2o`0000cooooo0ol000000ooooooo0000o`000005oooo
oa7o0000JOooool001cooooo00?o0000ooooooooool0Joooool<o`000003ooooool0003o000000;o
oooo0_l00006ooooo`;o00001?ooool2o`000003ooooool0003o000001Kooooo0_l0000?ooooo`;o
00003?ooool2o`0000;ooooo0_l00004ooooo`?o000000?oooooo`000?l000002ol0001Zooooo`00
7?ooool00ol0003oooooooooo`1/ooooo`[o00001_ooool2o`0000Kooooo0_l0000>ooooo`;o0000
1_ooool2o`0000Kooooo0ol0000;ooooo`;o00001?ooool2o`000003ooooool0003o000000Kooooo
0_l00009ooooo`?o000000?oooooo`000?l000002_l0001[ooooo`007?ooool00ol0003ooooooooo
o`1/ooooo`Oo00003_ooool2o`00017ooooo0_l00006ooooo`;o00001_ooool3o`0000Wooooo1?l0
0004ooooo`;o000000?oooooo`000?l000001?ooool4o`0000Wooooo0ol00003ooooo`Oo0000K_oo
ool001cooooo00?o0000ooooooooool0K_ooool7o`0000cooooo0_l00009ooooo`Co00002?ooool2
o`0000Wooooo1?l000000ooooooo0000o`000006ooooo`;o00002?ooool2o`0000Gooooo0_l0000;
ooooo`?o00000oooool3o`0007;ooooo000Looooo`03o`000?oooooooooo06oooooo1ol00003oooo
o`?o00004?ooool4o`0000Sooooo0_l00009ooooo`;o00000oooool2o`0000_ooooo0ol00002oooo
o`;o00004_ooool3o`0007Sooooo000Looooo`03o`000?oooooooooo06oooooo1ol00003ooooo`?o
000000?oooooo`000?l000001oooool2o`0000Kooooo1?l00004ooooo`;o00000oooool2o`0000Go
oooo0ol000000ooooooo0000o`00000=ooooo`?o00003oooool2o`0000Gooooo0ol0001hooooo`00
7?ooool00ol0003oooooooooo`1aooooo`So00001?ooool4o`0000Gooooo0_l00008ooooo`;o0000
1?ooool2o`0000?ooooo0_l00005ooooo`;o00000_ooool2o`0000Kooooo0_l00003ooooo`;o0000
00?oooooo`000?l000000_ooool2o`0000?ooooo0_l00006ooooo`;o00001Oooool2o`0007Wooooo
000Looooo`;o0000L_ooool:o`0000Cooooo0_l0000Eooooo`Co00002?ooool2o`0000[ooooo0_l0
0003ooooo`;o000000?oooooo`000?l000002Ol0000=ooooo`;o0000NOooool001cooooo00?o0000
ooooooooool0LOooool:o`0000[ooooo0_l00003ooooo`;o00003?ooool2o`000003ooooool0003o
000000?ooooo1?l0000:ooooo`;o00002?ooool2o`000003ooooool0003o000000;o000000?ooooo
o`000?l000000_ooool2o`0000Oooooo0_l0001jooooo`007?ooool00ol0003oooooooooo`1boooo
o`_o00002?ooool2o`0000?ooooo0_l00008ooooo`?o00001?ooool4o`000004ooooool0003o0000
o`0000cooooo0_l0000=ooooo`Co00000_ooool6o`0000?ooooo0_l0001jooooo`007?ooool00ol0
003oooooooooo`1booooo`_o00005oooool3o`0000?ooooo1Ol00002ooooo`;o00003?ooool2o`00
00Gooooo0_l00006ooooo`;o000000?oooooo`000?l000000_ooool5o`000003ooooool0003o0000
00;o0000N_ooool001cooooo00?o0000ooooooooool0L_ooool>o`0000kooooo0_l00004ooooo`?o
00000oooool2o`0001[ooooo0_l00009ooooo`So00000_ooool5o`0007Wooooo000Looooo`03o`00
0?oooooooooo07;ooooo3_l0000>ooooo`;o00002Oooool2o`0000Wooooo0_l000000ooooooo0000
o`000003ooooo`Co00000oooool2o`0000_ooooo2ol000000ooooooo0000o`000002o`0007Wooooo
000Looooo`03o`000?oooooooooo07?ooooo3_l000000ooooooo0000o`00000=ooooo`;o00001_oo
ool2o`0000Gooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00000oooool4o`0000;ooooo
0ol00004ooooo`;o00000ooooolBo`0007Wooooo000Looooo`03o`000?oooooooooo07Cooooo4?l0
00000ooooooo0000o`000004ooooo`;o000000Coooooo`000?l0003ooooo0_l0000=ooooo`;o0000
00?oooooo`000?l000000oooool2o`0000;ooooo0_l00004ooooo`?o00001?ooool2o`000003oooo
ool0003o000001;o0000NOooool001cooooo00?o0000ooooooooool0MOooool?o`000003ooooool0
003o000000Cooooo0_l000001?oooooo0000o`000?ooool3o`0000Wooooo0_l00009ooooo`;o0000
0_ooool2o`0000cooooo5?l0001kooooo`007?ooool00ol0003oooooooooo`1eooooo`ko00001_oo
ool2o`0000Kooooo1Ol00007ooooo`?o000000?oooooo`000?l000002oooool2o`0000[ooooo5?l0
001kooooo`007?ooool00ol0003oooooooooo`1fooooo`oo00001?ooool2o`0000Wooooo0ol00007
ooooo`;o000000?oooooo`000?l000002oooool2o`0000Kooooo0_l000000ooooooo0000o`00000C
o`0007_ooooo000Looooo`03o`000?oooooooooo07Oooooo3ol0000<ooooo`Go000000?oooooo`00
0?l000002_ooool2o`0000Sooooo0_l000000ooooooo0000o`000003oooooaOo0000O?ooool001co
oooo00?o0000ooooooooool0Moooool?o`0000cooooo1?l00002ooooo`;o00000oooool2o`0000Go
oooo0_l0000:ooooo`?o00001?oooolFo`0007cooooo000Looooo`03o`000?oooooooooo07Sooooo
3_l00003ooooo`?o00003Oooool2o`0000;ooooo0_l00005ooooo`;o00001Oooool2o`0000?ooooo
0_l00004oooooaKo0000OOooool001cooooo00?o0000ooooooooool0NOooool5o`000003ooooool0
003o000000Go00000_ooool4o`0000gooooo0_l00005ooooo`;o00000_ooool2o`0000Cooooo0ol0
0005ooooo`;o00000_ooool6o`0000;ooooo3_l0001mooooo`007?ooool00ol0003oooooooooo`1i
ooooo`ko000000Coooooo`000?l0003o00003_ooool2o`0000Gooooo0_l00002ooooo`;o000000Co
ooooo`000?l0003ooooo0_l00002ooooo`;o00000_ooool7o`0000Kooooo2Ol00021ooooo`007?oo
ool2o`0007_ooooo3Ol00005ooooo`;o00002oooool2o`0000Gooooo0_l00005ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0000?ooooo1_l00007ooooo`Ko0000Poooool001cooooo00?o0000
ooooooooool0Noooool<o`0000Gooooo1?l00009ooooo`;o00001Oooool2o`0000Gooooo1ol00005
ooooo`Ko0000T?ooool001cooooo00?o0000ooooooooool0O?ooool2o`000003ooooool0003o0000
00Oo00000_ooool2o`0000;ooooo0_l00009ooooo`;o000000?oooooo`000?l000001oooool<o`00
00;ooooo1_l0002@ooooo`007?ooool00ol0003oooooooooo`1nooooo`_o000000?oooooo`000?l0
00003oooool3o`0000?ooooo0ol000000ooooooo0000o`00000;o`000003ooooool0003o000000?o
0000TOooool001cooooo00?o0000ooooooooool0O_ooool>o`0000Sooooo0_l00003ooooo`Co0000
00Coooooo`000?l0003ooooo5ol0002Aooooo`007?ooool00ol0003oooooooooo`1nooooo`oo0000
1oooool2o`0000?ooooo7_l0002Booooo`007?ooool00ol0003oooooooooo`20ooooo`go000000?o
ooooo`000?l000001oooool2o`000003ooooool0003o000001[o0000Toooool001cooooo00?o0000
ooooooooool0P?ooool@o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000006?l0002E
ooooo`007?ooool00ol0003oooooooooo`21ooooo`oo00000ooooolQo`0009Gooooo000Looooo`03
o`000?oooooooooo08;ooooo4?l000000ooooooo0000o`00000No`0009Kooooo000Looooo`03o`00
0?oooooooooo08;ooooo;_l0002Iooooo`007?ooool00ol0003oooooooooo`25ooooob_o0000VOoo
ool001cooooo00?o0000ooooooooool0Q_oooolWo`0009cooooo000Looooo`03o`000?oooooooooo
08Sooooo0_l000000ooooooo0000o`00000Ao`000003ooooool0003o000000[o0000W_ooool001co
oooo00?o0000ooooooooool0R_ooool?o`0000;ooooo0ol00002ooooo`;o0000Yoooool001cooooo
00?o0000ooooooooool0R_ooool2o`0000;ooooo2?l0002cooooo`007?ooool2o`00093ooooo0_l0
002hooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000
ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooood[ooooo00001_ooooooMgMgoiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`3ooooood[ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?ooooooB_ooool00003ooooool0
003ooooo00;ooooo00?o0000ooooooooool02Oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo
0ol0003ooooood[ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go
c<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo0?ooooooB_ooool00003ooooool@
413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo
00?o0000ooooooooool0oooooom:ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05
o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`3ooooood[ooooo00001_oooooo
k^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001;ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oo
ooooB_ooool001Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood[ooooo
000Dooooo`03o`000?oooooooooo00Gooooo0ol0003ooooood[ooooo000Dooooo`03o`000?oooooo
oooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003o
ooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001;ooooo00?o
EEEEofIVI_l00000oooooomDooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
ZOooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo01Gooooo00GoV9RHoa0@4?l0
003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0U?ooool00:[ooooo00Go0000oooo
ooooooooooooo`000009ooooo`Ko00002Oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00Go
EEEEogMgMoooooooV9RHob4Q8@2Dooooo`00Z_ooool01Ol0003ooooooooooooooooo000001cooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo09;ooooo002Zooooo`05o`00
0?ooooooooooooooool000002Oooool6o`0000cooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003o
V9RHoooooonHV9So8B4Q09Cooooo002Zooooo`05o`000?n7QhOoooooojVYZOl000006_ooool00ol@
413o0000okZj^P03ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0U?ooool00:Wooooo00?o410@o`00
0?mgMgL00_l000000onHV9Soooooooooo`0Iooooo`03okZj^_lQ8B7ooooo00;ooooo00?oEEEEohN7
Qoooool0U_ooool00<Oooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`03omgMgOl@413oV9RH
09Kooooo0037ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01?ooool01?o<c<coA4A4o`000?l@412D
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -20 0 ]
[.5 1.0125 20 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(42) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.72228 .50067 Mdot
.7282 .54115 Mdot
.52516 .27744 Mdot
.35521 .60245 Mdot
.25986 .46848 Mdot
.5313 .28691 Mdot
.69725 .41208 Mdot
.69482 .4363 Mdot
.54935 .26599 Mdot
.32639 .5435 Mdot
.64692 .35561 Mdot
.46701 .73066 Mdot
.70112 .41834 Mdot
.32653 .59359 Mdot
.43761 .72556 Mdot
.58233 .71564 Mdot
.70738 .51939 Mdot
.25909 .47109 Mdot
.59929 .69043 Mdot
.56708 .27637 Mdot
.40491 .33592 Mdot
.33734 .58966 Mdot
.70069 .53554 Mdot
.32405 .58366 Mdot
.59616 .68921 Mdot
.6773 .61068 Mdot
.72161 .49886 Mdot
.59031 .69243 Mdot
.49042 .73757 Mdot
.71033 .44139 Mdot
.58215 .70784 Mdot
.36656 .64272 Mdot
.33689 .39028 Mdot
.65377 .65121 Mdot
.65437 .34278 Mdot
.64834 .3642 Mdot
.50734 .27463 Mdot
.63671 .35672 Mdot
.69125 .44475 Mdot
.64815 .3371 Mdot
.6514 .34108 Mdot
.67293 .61001 Mdot
.65366 .36613 Mdot
.70438 .46885 Mdot
.38362 .66317 Mdot
.63835 .63166 Mdot
.41796 .3106 Mdot
.4005 .71037 Mdot
.72548 .50627 Mdot
.42242 .30307 Mdot
.37148 .68957 Mdot
.68592 .40664 Mdot
.34408 .3666 Mdot
.69723 .58957 Mdot
.70767 .42486 Mdot
.59364 .68653 Mdot
.56522 .28924 Mdot
.38046 .70978 Mdot
.50498 .73462 Mdot
.64818 .64848 Mdot
.32703 .56876 Mdot
.27919 .48881 Mdot
.54359 .70284 Mdot
.58291 .30525 Mdot
.52954 .26729 Mdot
.61335 .32427 Mdot
.6974 .55982 Mdot
.62565 .34074 Mdot
.3472 .62346 Mdot
.43892 .30786 Mdot
.39715 .72216 Mdot
.64744 .35562 Mdot
.66188 .62766 Mdot
.34944 .60414 Mdot
.7371 .51125 Mdot
.63282 .34242 Mdot
.26225 .46146 Mdot
.6704 .61613 Mdot
.43486 .28704 Mdot
.31976 .54151 Mdot
.33617 .58115 Mdot
.67646 .36696 Mdot
.51631 .72575 Mdot
.6503 .61227 Mdot
.37438 .66109 Mdot
.69047 .38219 Mdot
.35391 .57296 Mdot
.5847 .71038 Mdot
.58554 .69059 Mdot
.46677 .73426 Mdot
.48352 .27763 Mdot
.7053 .54845 Mdot
.34242 .60246 Mdot
.33968 .62352 Mdot
.37749 .69271 Mdot
.37156 .66087 Mdot
.58299 .69001 Mdot
.3717 .37763 Mdot
.64325 .34029 Mdot
.3333 .37487 Mdot
.62844 .34202 Mdot
.34274 .35966 Mdot
.35382 .63193 Mdot
.55552 .30105 Mdot
.69318 .61611 Mdot
.36474 .38203 Mdot
.6353 .33962 Mdot
.34303 .60592 Mdot
.64394 .36226 Mdot
.70842 .54552 Mdot
.57754 .70416 Mdot
.2992 .4472 Mdot
.28549 .4355 Mdot
.70718 .49791 Mdot
.34253 .63822 Mdot
.34621 .55939 Mdot
.33066 .58392 Mdot
.69849 .5577 Mdot
.55061 .26818 Mdot
.47289 .28158 Mdot
.72373 .53679 Mdot
.64664 .34046 Mdot
.71148 .51267 Mdot
.31775 .37223 Mdot
.53734 .26522 Mdot
.34329 .38293 Mdot
.38237 .36203 Mdot
.36037 .63528 Mdot
.36971 .66117 Mdot
.35712 .34279 Mdot
.55529 .30331 Mdot
.72565 .53613 Mdot
.69932 .42484 Mdot
.33426 .61969 Mdot
.64654 .6207 Mdot
.70954 .42363 Mdot
.28108 .45442 Mdot
.30264 .4358 Mdot
.65652 .62706 Mdot
.34805 .64372 Mdot
.63176 .35408 Mdot
.6778 .42843 Mdot
.37393 .70028 Mdot
.64463 .62552 Mdot
.26546 .46664 Mdot
.67768 .42983 Mdot
.31748 .40096 Mdot
.5737 .69922 Mdot
.41585 .73721 Mdot
.67618 .37373 Mdot
.37528 .69615 Mdot
.40907 .33131 Mdot
.29523 .48024 Mdot
.70897 .42903 Mdot
.35549 .58915 Mdot
.71968 .51683 Mdot
.64926 .62895 Mdot
.4853 .71665 Mdot
.35577 .38619 Mdot
.36718 .69572 Mdot
.34398 .35442 Mdot
.38056 .36696 Mdot
.33038 .6003 Mdot
.64052 .6433 Mdot
.68529 .63684 Mdot
.39306 .71987 Mdot
.51293 .26698 Mdot
.25788 .46923 Mdot
.65279 .3599 Mdot
.37561 .67252 Mdot
.38071 .69348 Mdot
.47255 .71985 Mdot
.67656 .42343 Mdot
.65316 .3354 Mdot
.44751 .2895 Mdot
.6169 .32698 Mdot
.66379 .3591 Mdot
.57534 .3089 Mdot
.47815 .73039 Mdot
.30701 .44577 Mdot
.36573 .3607 Mdot
.3913 .71812 Mdot
.37445 .64694 Mdot
.46289 .73147 Mdot
.39842 .33701 Mdot
.3983 .33022 Mdot
.69199 .57557 Mdot
.66013 .36779 Mdot
.34724 .57499 Mdot
.58874 .67613 Mdot
.36612 .66954 Mdot
.6685 .37647 Mdot
.69502 .42769 Mdot
.59567 .3142 Mdot
.57499 .28324 Mdot
.43436 .29758 Mdot
.51772 .71167 Mdot
.46949 .71336 Mdot
.34449 .58034 Mdot
.34359 .37506 Mdot
.54671 .70307 Mdot
.29169 .4832 Mdot
.7118 .51842 Mdot
.6752 .36376 Mdot
.40043 .73313 Mdot
.60208 .70304 Mdot
.51319 .25878 Mdot
.47304 .27415 Mdot
.3739 .35404 Mdot
.29744 .46835 Mdot
.38694 .71189 Mdot
.70441 .50532 Mdot
.37308 .69469 Mdot
.33537 .38838 Mdot
.2909 .43126 Mdot
.71481 .53735 Mdot
.40327 .71352 Mdot
.70518 .41703 Mdot
.53107 .30442 Mdot
.35418 .57305 Mdot
.34591 .60878 Mdot
.66743 .61642 Mdot
.34563 .62908 Mdot
.5932 .68014 Mdot
.58322 .70263 Mdot
.43991 .29731 Mdot
.62611 .33192 Mdot
.70737 .446 Mdot
.41679 .31123 Mdot
.65739 .61928 Mdot
.73304 .48721 Mdot
.55179 .29212 Mdot
.4035 .34004 Mdot
.64458 .35782 Mdot
.28193 .46756 Mdot
.55064 .29607 Mdot
.26163 .47445 Mdot
.50859 .73527 Mdot
.55293 .30765 Mdot
.29084 .45031 Mdot
.44267 .72481 Mdot
.37972 .36086 Mdot
.30995 .43001 Mdot
.69846 .41021 Mdot
.7344 .54173 Mdot
.3874 .71773 Mdot
.3507 .36309 Mdot
.33167 .38421 Mdot
.48166 .72944 Mdot
.38865 .35405 Mdot
.36408 .3782 Mdot
.47817 .72696 Mdot
.25756 .4798 Mdot
.6667 .35337 Mdot
.58139 .70723 Mdot
.70958 .51651 Mdot
.35024 .6264 Mdot
.6302 .32511 Mdot
.71 .42496 Mdot
.33748 .55539 Mdot
.68241 .37974 Mdot
.69941 .40856 Mdot
.32819 .59153 Mdot
.69991 .44445 Mdot
.64881 .61533 Mdot
.39898 .73276 Mdot
.66089 .63196 Mdot
.32622 .59131 Mdot
.69642 .44539 Mdot
.41857 .30844 Mdot
.6672 .61119 Mdot
.34235 .59684 Mdot
.35219 .593 Mdot
.34482 .37259 Mdot
.57943 .70288 Mdot
.71692 .40436 Mdot
.4683 .73082 Mdot
.58193 .31703 Mdot
.50334 .71373 Mdot
.30435 .47498 Mdot
.31537 .40104 Mdot
.64494 .62687 Mdot
.38964 .35578 Mdot
.54163 .28967 Mdot
.38338 .70218 Mdot
.40688 .72225 Mdot
.37985 .66255 Mdot
.36515 .37532 Mdot
.51719 .72464 Mdot
.71353 .40833 Mdot
.57743 .68471 Mdot
.35901 .34396 Mdot
.55698 .28413 Mdot
.33698 .36494 Mdot
.37275 .66009 Mdot
.70092 .54046 Mdot
.59554 .71208 Mdot
.57245 .31543 Mdot
.7037 .53459 Mdot
.39883 .71224 Mdot
.62502 .33905 Mdot
.28512 .49381 Mdot
.71974 .41395 Mdot
.59582 .70069 Mdot
.49847 .7142 Mdot
.44055 .30626 Mdot
.65982 .61214 Mdot
.7045 .43415 Mdot
.66166 .62935 Mdot
.36684 .69148 Mdot
.36041 .67792 Mdot
.64465 .63076 Mdot
.31751 .4394 Mdot
.45202 .2832 Mdot
.64292 .35413 Mdot
.34727 .37941 Mdot
.4553 .30106 Mdot
.72085 .50484 Mdot
.54823 .29837 Mdot
.34889 .65259 Mdot
.53477 .30701 Mdot
.5969 .7114 Mdot
.44815 .30499 Mdot
.47489 .71662 Mdot
.38055 .65664 Mdot
.58785 .31037 Mdot
.36145 .38527 Mdot
.3812 .70827 Mdot
.64888 .61707 Mdot
.36779 .63886 Mdot
.32917 .54502 Mdot
.50834 .71078 Mdot
.5588 .28576 Mdot
.3493 .64705 Mdot
.58872 .70154 Mdot
.59583 .69619 Mdot
.71414 .52161 Mdot
.3563 .37185 Mdot
.2808 .44988 Mdot
.307 .43208 Mdot
.31747 .40793 Mdot
.45869 .73161 Mdot
.35557 .66259 Mdot
.65296 .62159 Mdot
.42545 .30135 Mdot
.73865 .53904 Mdot
.33633 .38896 Mdot
.69378 .43629 Mdot
.65735 .34107 Mdot
.35568 .57668 Mdot
.26005 .49996 Mdot
.60165 .71067 Mdot
.73073 .5105 Mdot
.66395 .62458 Mdot
.70267 .43547 Mdot
.5306 .72613 Mdot
.32241 .54337 Mdot
.33869 .55685 Mdot
.68604 .43446 Mdot
.3372 .38633 Mdot
.50344 .73155 Mdot
.41829 .72464 Mdot
.69145 .45908 Mdot
.38326 .67194 Mdot
.66378 .64463 Mdot
.38943 .66621 Mdot
.35992 .63761 Mdot
.39223 .68158 Mdot
.65154 .61744 Mdot
.61061 .70367 Mdot
.4146 .7246 Mdot
.49598 .265 Mdot
.40185 .7345 Mdot
.31386 .43818 Mdot
.34641 .60248 Mdot
.38922 .71394 Mdot
.26863 .46511 Mdot
.70761 .49887 Mdot
.38129 .69082 Mdot
.6705 .37256 Mdot
.3399 .59644 Mdot
.6529 .36085 Mdot
.49878 .72276 Mdot
.36153 .64276 Mdot
.58794 .69885 Mdot
.70013 .53736 Mdot
.68738 .44225 Mdot
.65572 .35424 Mdot
.36267 .34776 Mdot
.7101 .42559 Mdot
.37582 .66631 Mdot
.50255 .72288 Mdot
.70643 .49846 Mdot
.37885 .3626 Mdot
.70612 .54992 Mdot
.26514 .5096 Mdot
.69174 .4133 Mdot
.34323 .36209 Mdot
.53437 .71846 Mdot
.68447 .41868 Mdot
.66921 .36809 Mdot
.57721 .70461 Mdot
.33679 .38597 Mdot
.7179 .50064 Mdot
.44443 .30571 Mdot
.3525 .3842 Mdot
.70774 .42759 Mdot
.38465 .66396 Mdot
.5781 .69224 Mdot
.70414 .43802 Mdot
.67428 .63573 Mdot
.57148 .70164 Mdot
.33928 .5987 Mdot
.67767 .60776 Mdot
.70662 .55439 Mdot
.37451 .71044 Mdot
.34087 .56523 Mdot
.53879 .28094 Mdot
.36091 .37796 Mdot
.36129 .37619 Mdot
.38261 .36738 Mdot
.56048 .3155 Mdot
.45767 .28407 Mdot
.63025 .33093 Mdot
.36165 .63479 Mdot
.62173 .32589 Mdot
.3491 .36141 Mdot
.53654 .28069 Mdot
.38534 .66201 Mdot
.52828 .73121 Mdot
.67889 .43764 Mdot
.47559 .28656 Mdot
.35831 .60725 Mdot
.71883 .51341 Mdot
.68139 .41282 Mdot
.46006 .71672 Mdot
.43466 .30229 Mdot
.28091 .4904 Mdot
.35207 .64586 Mdot
.68081 .42224 Mdot
.68348 .62961 Mdot
.68113 .42315 Mdot
.3926 .71373 Mdot
.38138 .68401 Mdot
.73577 .5302 Mdot
.31456 .439 Mdot
.47056 .7305 Mdot
.32437 .57945 Mdot
.4249 .29788 Mdot
.74017 .53517 Mdot
.31587 .43093 Mdot
.50009 .73885 Mdot
.38313 .35491 Mdot
.25525 .48026 Mdot
.34453 .58359 Mdot
.47482 .72322 Mdot
.33379 .35368 Mdot
.7119 .43516 Mdot
.31226 .43543 Mdot
.50701 .26094 Mdot
.70808 .53606 Mdot
.62782 .33023 Mdot
.39338 .35566 Mdot
.64521 .35356 Mdot
.45139 .72904 Mdot
.35391 .3552 Mdot
.67726 .44281 Mdot
.30186 .52991 Mdot
.37207 .37091 Mdot
.56226 .28483 Mdot
.37061 .6986 Mdot
.47281 .7274 Mdot
.33937 .59978 Mdot
.2829 .44866 Mdot
.72277 .54642 Mdot
.66387 .36403 Mdot
.69307 .44931 Mdot
.33572 .60981 Mdot
.64469 .62732 Mdot
.68954 .56952 Mdot
.33643 .37137 Mdot
.29608 .45598 Mdot
.28447 .46431 Mdot
.34061 .61516 Mdot
.52201 .72906 Mdot
.65363 .61792 Mdot
.34271 .59758 Mdot
.34037 .61582 Mdot
.45384 .2929 Mdot
.68035 .60531 Mdot
.55925 .30906 Mdot
.60317 .69582 Mdot
.35542 .64503 Mdot
.62373 .33465 Mdot
.71037 .41581 Mdot
.3576 .3744 Mdot
.70729 .44622 Mdot
.45316 .28896 Mdot
.36182 .37595 Mdot
.34262 .59632 Mdot
.7177 .49436 Mdot
.34303 .59938 Mdot
.34078 .59781 Mdot
.39043 .6753 Mdot
.3558 .66201 Mdot
.48133 .27181 Mdot
.30201 .45291 Mdot
.50588 .73685 Mdot
.57788 .31262 Mdot
.51898 .25816 Mdot
.37541 .69073 Mdot
.34502 .59038 Mdot
.33006 .5883 Mdot
.68083 .61483 Mdot
.57543 .68974 Mdot
.68722 .42345 Mdot
.73598 .53063 Mdot
.35128 .57077 Mdot
.41833 .31241 Mdot
.38287 .69145 Mdot
.64705 .63405 Mdot
.64347 .32975 Mdot
.70683 .39213 Mdot
.38894 .35101 Mdot
.32943 .37871 Mdot
.36394 .37737 Mdot
.3821 .36988 Mdot
.6513 .36522 Mdot
.53485 .28009 Mdot
.3049 .47716 Mdot
.35915 .67577 Mdot
.34313 .56939 Mdot
.3782 .68165 Mdot
.4605 .29444 Mdot
.31973 .38395 Mdot
.3618 .67513 Mdot
.56139 .70287 Mdot
.5237 .29753 Mdot
.37429 .37475 Mdot
.62909 .63483 Mdot
.70649 .54142 Mdot
.43965 .30208 Mdot
.63654 .35634 Mdot
.29116 .44785 Mdot
.41227 .32129 Mdot
.71207 .54955 Mdot
.55017 .69278 Mdot
.5205 .29328 Mdot
.50333 .72471 Mdot
.54218 .71293 Mdot
.53989 .29618 Mdot
.57801 .68282 Mdot
.69657 .55898 Mdot
.38062 .36207 Mdot
.50462 .71857 Mdot
.48389 .72797 Mdot
.59642 .3119 Mdot
.35292 .60501 Mdot
.48043 .27862 Mdot
.55848 .28377 Mdot
.36244 .36799 Mdot
.55843 .28574 Mdot
.71484 .41032 Mdot
.56579 .30242 Mdot
.67954 .62819 Mdot
.34091 .61949 Mdot
.69628 .59204 Mdot
.4372 .73018 Mdot
.3444 .55875 Mdot
.69231 .4051 Mdot
.63051 .32658 Mdot
.33218 .56809 Mdot
.26298 .46333 Mdot
.5529 .28002 Mdot
.43826 .29242 Mdot
.58223 .68621 Mdot
.45475 .29978 Mdot
.69973 .53835 Mdot
.62763 .33612 Mdot
.63007 .32646 Mdot
.35819 .38104 Mdot
.6446 .62259 Mdot
.65401 .36942 Mdot
.646 .33933 Mdot
.28619 .4936 Mdot
.37915 .71453 Mdot
.67519 .64258 Mdot
.50293 .73135 Mdot
.25966 .47436 Mdot
.33851 .59418 Mdot
.5643 .3097 Mdot
.43976 .29416 Mdot
.43472 .72344 Mdot
.54992 .29007 Mdot
.35365 .37685 Mdot
.68958 .61993 Mdot
.59546 .6863 Mdot
.72267 .54335 Mdot
.34103 .626 Mdot
.62607 .32962 Mdot
.70363 .54015 Mdot
.40163 .33854 Mdot
.32741 .56083 Mdot
.64081 .6393 Mdot
.49712 .74075 Mdot
.3384 .59707 Mdot
.54043 .26759 Mdot
.26754 .46553 Mdot
.40168 .3458 Mdot
.49087 .27204 Mdot
.28544 .48186 Mdot
.74676 .51899 Mdot
.54185 .2668 Mdot
.28552 .4731 Mdot
.31515 .40701 Mdot
.38875 .36102 Mdot
.30071 .45905 Mdot
.37424 .66249 Mdot
.71033 .42983 Mdot
.73157 .54094 Mdot
.38937 .68893 Mdot
.31847 .53887 Mdot
.69739 .59812 Mdot
.34144 .37294 Mdot
.33592 .59709 Mdot
.3756 .70848 Mdot
.64853 .6326 Mdot
.67267 .35935 Mdot
.57701 .29728 Mdot
.33836 .38017 Mdot
.71882 .54475 Mdot
.67676 .36704 Mdot
.53556 .26792 Mdot
.27733 .47182 Mdot
.71614 .42499 Mdot
.72028 .49359 Mdot
.34485 .36857 Mdot
.69792 .41108 Mdot
.48951 .27423 Mdot
.3725 .69066 Mdot
.56513 .70364 Mdot
.51666 .28802 Mdot
.37238 .69139 Mdot
.60107 .70888 Mdot
.43378 .29874 Mdot
.65983 .34313 Mdot
.70865 .54635 Mdot
.69134 .44043 Mdot
.29035 .45844 Mdot
.66391 .62786 Mdot
.70686 .54969 Mdot
.71076 .41573 Mdot
.6981 .60727 Mdot
.51776 .72185 Mdot
.63382 .34231 Mdot
.5141 .73068 Mdot
.37737 .70203 Mdot
.34771 .3678 Mdot
.30521 .44808 Mdot
.62627 .33332 Mdot
.6768 .61027 Mdot
.70832 .47 Mdot
.3673 .65822 Mdot
.57267 .69254 Mdot
.29874 .44182 Mdot
.69361 .57591 Mdot
.65533 .33558 Mdot
.68758 .42137 Mdot
.42501 .29843 Mdot
.26598 .45896 Mdot
.3774 .65777 Mdot
.46764 .29644 Mdot
.37829 .67561 Mdot
.68031 .41008 Mdot
.60308 .70788 Mdot
.71214 .53247 Mdot
.63639 .34728 Mdot
.59672 .71339 Mdot
.47589 .73491 Mdot
.33766 .56722 Mdot
.44163 .29677 Mdot
.68961 .56003 Mdot
.31512 .39008 Mdot
.3505 .56428 Mdot
.32573 .56069 Mdot
.32842 .38291 Mdot
.3613 .63639 Mdot
.66463 .35224 Mdot
.34966 .38769 Mdot
.52735 .29844 Mdot
.37777 .36635 Mdot
.34952 .37691 Mdot
.70603 .50798 Mdot
.4293 .30109 Mdot
.3285 .3805 Mdot
.33307 .55145 Mdot
.33821 .60673 Mdot
.68637 .44292 Mdot
.51326 .72206 Mdot
.49076 .72989 Mdot
.5839 .31609 Mdot
.28585 .49494 Mdot
.38898 .70471 Mdot
.64902 .61411 Mdot
.29892 .43639 Mdot
.3389 .35586 Mdot
.70549 .5303 Mdot
.37161 .65812 Mdot
.45475 .29276 Mdot
.37595 .36448 Mdot
.32644 .36687 Mdot
.29489 .44588 Mdot
.67588 .42243 Mdot
.65264 .64044 Mdot
.55921 .28368 Mdot
.57347 .70956 Mdot
.2619 .5047 Mdot
.44561 .29955 Mdot
.34894 .36809 Mdot
.36286 .35289 Mdot
.64595 .62651 Mdot
.67633 .63156 Mdot
.39622 .35123 Mdot
.57908 .31372 Mdot
.6634 .37307 Mdot
.6426 .34876 Mdot
.48833 .71634 Mdot
.71828 .42486 Mdot
.70772 .54615 Mdot
.3605 .65141 Mdot
.28384 .467 Mdot
.68581 .41698 Mdot
.36035 .38091 Mdot
.71302 .54577 Mdot
.67186 .63071 Mdot
.32369 .57835 Mdot
.33849 .58817 Mdot
.41761 .31039 Mdot
.37057 .64609 Mdot
.67564 .43055 Mdot
.27736 .45541 Mdot
.53511 .27549 Mdot
.58079 .68838 Mdot
.71846 .51625 Mdot
.41312 .32456 Mdot
.47752 .73816 Mdot
.57694 .3036 Mdot
.7298 .53863 Mdot
.28867 .44054 Mdot
.3014 .4544 Mdot
.35833 .6472 Mdot
.4103 .33013 Mdot
.69353 .40822 Mdot
.64759 .62103 Mdot
.74588 .52426 Mdot
.49165 .73647 Mdot
.34376 .59098 Mdot
.58512 .68146 Mdot
.65997 .36431 Mdot
.37426 .6661 Mdot
.29098 .44497 Mdot
.69298 .55911 Mdot
.38219 .65853 Mdot
.28211 .44062 Mdot
.31496 .38953 Mdot
.36747 .35392 Mdot
.58474 .30209 Mdot
.28014 .44548 Mdot
.27408 .45042 Mdot
.29263 .43267 Mdot
.65827 .34269 Mdot
.45871 .71888 Mdot
.26575 .50772 Mdot
.35289 .60277 Mdot
.37152 .69848 Mdot
.56537 .7002 Mdot
.61839 .32685 Mdot
.43792 .3066 Mdot
.38935 .71227 Mdot
.35206 .59392 Mdot
.69384 .56343 Mdot
.57814 .71474 Mdot
.39677 .71303 Mdot
.70907 .52579 Mdot
.66448 .65034 Mdot
.57846 .28931 Mdot
.67835 .38008 Mdot
.4518 .30604 Mdot
.50819 .73875 Mdot
.51243 .73901 Mdot
.69233 .53947 Mdot
.71346 .42703 Mdot
.51362 .73702 Mdot
.67594 .42058 Mdot
.69439 .55301 Mdot
.56269 .70003 Mdot
.67625 .63357 Mdot
.277 .48935 Mdot
.39412 .71224 Mdot
.70921 .41237 Mdot
.3898 .71317 Mdot
.71323 .41639 Mdot
.31982 .53934 Mdot
.5198 .73421 Mdot
.35406 .58485 Mdot
.37922 .65129 Mdot
.39982 .33493 Mdot
.34118 .5877 Mdot
.43353 .2883 Mdot
.72242 .51965 Mdot
.25676 .49385 Mdot
.57616 .67538 Mdot
.37821 .70522 Mdot
.33199 .59077 Mdot
.69767 .59992 Mdot
.33032 .58091 Mdot
.45922 .30101 Mdot
.49868 .74149 Mdot
.39469 .71676 Mdot
.69656 .42964 Mdot
.64962 .35116 Mdot
.70713 .49752 Mdot
.35565 .35412 Mdot
.69431 .57478 Mdot
.33013 .5958 Mdot
.56788 .28459 Mdot
.31832 .41439 Mdot
.27243 .45448 Mdot
.73184 .5381 Mdot
.30663 .5326 Mdot
.65339 .36566 Mdot
.51806 .26206 Mdot
.579 .70745 Mdot
.54651 .30615 Mdot
.58447 .3098 Mdot
.74036 .53617 Mdot
.30444 .44884 Mdot
.38899 .69941 Mdot
.65071 .64952 Mdot
.64706 .66162 Mdot
.48824 .73592 Mdot
.56261 .27674 Mdot
.33166 .35517 Mdot
.61809 .68684 Mdot
.27021 .4833 Mdot
.2871 .47724 Mdot
.70698 .41665 Mdot
.57181 .28757 Mdot
.34113 .37992 Mdot
.28444 .47173 Mdot
.57921 .28908 Mdot
.39083 .35973 Mdot
.43227 .2925 Mdot
.65164 .62089 Mdot
.3531 .66157 Mdot
.63788 .64045 Mdot
.70064 .44954 Mdot
.42512 .30351 Mdot
.66063 .61668 Mdot
.64446 .61708 Mdot
.34679 .37541 Mdot
.50064 .27161 Mdot
.69402 .60598 Mdot
.38199 .71488 Mdot
.37734 .3559 Mdot
.32263 .58074 Mdot
.2638 .45805 Mdot
.33634 .60338 Mdot
.42198 .30992 Mdot
.68478 .42459 Mdot
.54522 .28204 Mdot
.70587 .41443 Mdot
.36262 .63898 Mdot
.32884 .55569 Mdot
.34587 .59798 Mdot
.49752 .72318 Mdot
.69918 .51834 Mdot
.65859 .64811 Mdot
.57143 .29572 Mdot
.54952 .28226 Mdot
.57131 .67865 Mdot
.7178 .51022 Mdot
.31596 .39863 Mdot
.51474 .73378 Mdot
.33123 .57892 Mdot
.72103 .51998 Mdot
.56582 .6956 Mdot
.65618 .37154 Mdot
.49955 .71988 Mdot
.69936 .52464 Mdot
.45941 .28465 Mdot
.33977 .61622 Mdot
.33149 .37487 Mdot
.35362 .34312 Mdot
.45283 .72673 Mdot
.25898 .47212 Mdot
.71182 .53782 Mdot
.3343 .36437 Mdot
.72599 .51876 Mdot
.54328 .31042 Mdot
.64934 .36801 Mdot
.71293 .52668 Mdot
.32925 .58387 Mdot
.47059 .29591 Mdot
.71185 .42634 Mdot
.39257 .67644 Mdot
.63732 .3446 Mdot
.66312 .62202 Mdot
.72611 .53028 Mdot
.39096 .35954 Mdot
.57683 .68404 Mdot
.6893 .41113 Mdot
.34789 .57293 Mdot
.67813 .63269 Mdot
.59422 .71357 Mdot
.2598 .47604 Mdot
.38468 .68909 Mdot
.36646 .69888 Mdot
.47261 .28244 Mdot
.36843 .67488 Mdot
.66298 .35553 Mdot
.64932 .36248 Mdot
.66444 .36673 Mdot
.70904 .50166 Mdot
.39731 .34396 Mdot
.66375 .63881 Mdot
.35579 .37692 Mdot
.50474 .27076 Mdot
.39323 .68035 Mdot
.38045 .37162 Mdot
.62861 .33229 Mdot
.30464 .45827 Mdot
.46409 .73221 Mdot
.51308 .28192 Mdot
.3765 .35164 Mdot
.68942 .41656 Mdot
.68747 .61921 Mdot
.70806 .53226 Mdot
.443 .28712 Mdot
.38712 .66347 Mdot
.3397 .59058 Mdot
.63541 .33036 Mdot
.41141 .32833 Mdot
.28496 .48063 Mdot
.36159 .38509 Mdot
.63302 .33285 Mdot
.50563 .72091 Mdot
.66756 .61888 Mdot
.39206 .71541 Mdot
.50877 .72368 Mdot
.65887 .34477 Mdot
.64988 .65939 Mdot
.28765 .48266 Mdot
.35498 .63645 Mdot
.71378 .53768 Mdot
.70079 .42501 Mdot
.31394 .40477 Mdot
.60046 .68572 Mdot
.34665 .57753 Mdot
.40128 .72788 Mdot
.47959 .72241 Mdot
.58468 .70921 Mdot
.39049 .3521 Mdot
.39808 .72479 Mdot
.57405 .67699 Mdot
.57857 .71265 Mdot
.38014 .68593 Mdot
.37773 .68549 Mdot
.72231 .52318 Mdot
.50313 .71057 Mdot
.56043 .30637 Mdot
.581 .68022 Mdot
.41254 .325 Mdot
.5836 .70588 Mdot
.49822 .71366 Mdot
.64363 .65826 Mdot
.451 .72712 Mdot
.68902 .55403 Mdot
.71755 .50468 Mdot
.70273 .44871 Mdot
.59764 .70952 Mdot
.57754 .304 Mdot
.33027 .35911 Mdot
.44288 .3036 Mdot
.72417 .52282 Mdot
.57055 .2809 Mdot
.61361 .32498 Mdot
.51606 .28758 Mdot
.53469 .30295 Mdot
.6832 .42283 Mdot
.73057 .5448 Mdot
.48317 .7396 Mdot
.68227 .41898 Mdot
.32401 .37335 Mdot
.27968 .47125 Mdot
.65666 .659 Mdot
.35032 .38937 Mdot
.35862 .6081 Mdot
.68956 .45557 Mdot
.50701 .27614 Mdot
.40206 .73043 Mdot
.73269 .51082 Mdot
.30216 .43236 Mdot
.71524 .52831 Mdot
.39615 .35601 Mdot
.29191 .48417 Mdot
.37573 .65687 Mdot
.41126 .32544 Mdot
.66487 .35513 Mdot
.38736 .69759 Mdot
.64966 .65499 Mdot
.44194 .30367 Mdot
.71368 .40776 Mdot
.66993 .37528 Mdot
.33343 .37712 Mdot
.7013 .52374 Mdot
.66865 .63864 Mdot
.36113 .37446 Mdot
.69863 .42493 Mdot
.69309 .59056 Mdot
.36171 .67902 Mdot
.71865 .43121 Mdot
.38999 .6982 Mdot
.34774 .64287 Mdot
.31988 .43526 Mdot
.38244 .36645 Mdot
.57203 .71236 Mdot
.52694 .26738 Mdot
.56678 .6832 Mdot
.34864 .63161 Mdot
.3717 .64295 Mdot
.3397 .57624 Mdot
.4039 .72798 Mdot
.45843 .28897 Mdot
.69732 .51414 Mdot
.36673 .35787 Mdot
.34611 .3704 Mdot
.58985 .71715 Mdot
.41312 .31812 Mdot
.2958 .46714 Mdot
.43952 .28718 Mdot
.32565 .5636 Mdot
.33509 .58153 Mdot
.67349 .62271 Mdot
.34556 .64439 Mdot
.37995 .36548 Mdot
.33882 .57376 Mdot
.46593 .73643 Mdot
.70082 .43131 Mdot
.3694 .70488 Mdot
.33932 .6145 Mdot
.65356 .3699 Mdot
.69855 .4284 Mdot
.44754 .29538 Mdot
.38861 .36399 Mdot
.58805 .30914 Mdot
.27656 .48304 Mdot
.40172 .72205 Mdot
.36107 .64874 Mdot
.50551 .71656 Mdot
.2744 .48607 Mdot
.58646 .70238 Mdot
.33548 .62799 Mdot
.34744 .62142 Mdot
.28844 .4759 Mdot
.71196 .43703 Mdot
.71765 .52142 Mdot
.34928 .64545 Mdot
.3473 .37126 Mdot
.58158 .71246 Mdot
.27574 .44574 Mdot
.72692 .51983 Mdot
.64001 .64376 Mdot
.72832 .53862 Mdot
.69053 .42 Mdot
.43301 .30211 Mdot
.29182 .4846 Mdot
.7145 .52866 Mdot
.53684 .26371 Mdot
.62604 .33625 Mdot
.48102 .71645 Mdot
.69497 .44864 Mdot
.74011 .53675 Mdot
.70567 .51083 Mdot
.73219 .50443 Mdot
.58825 .68386 Mdot
.40441 .72868 Mdot
.35225 .37854 Mdot
.63247 .33168 Mdot
.52288 .26867 Mdot
.36663 .65428 Mdot
.64216 .64936 Mdot
.41004 .73637 Mdot
.37551 .65509 Mdot
.33591 .60383 Mdot
.34894 .60858 Mdot
.3834 .34881 Mdot
.356 .58753 Mdot
.35232 .6041 Mdot
.67394 .42695 Mdot
.44656 .29786 Mdot
.32963 .55362 Mdot
.36631 .35443 Mdot
.26128 .50085 Mdot
.305 .43159 Mdot
.354 .64676 Mdot
.54447 .70465 Mdot
.71439 .52022 Mdot
.57514 .3143 Mdot
.57639 .28932 Mdot
.28515 .44797 Mdot
.69312 .43678 Mdot
.71548 .55187 Mdot
.47204 .2855 Mdot
.29534 .48249 Mdot
.39028 .68176 Mdot
.4954 .72338 Mdot
.45167 .72787 Mdot
.47221 .72448 Mdot
.39159 .67793 Mdot
.36648 .37891 Mdot
.57544 .31633 Mdot
.46976 .71699 Mdot
.6393 .63227 Mdot
.268 .45617 Mdot
.27357 .46918 Mdot
.69165 .61685 Mdot
.34847 .63021 Mdot
.70668 .41031 Mdot
.52094 .72917 Mdot
.71674 .40411 Mdot
.69282 .56869 Mdot
.26594 .50913 Mdot
.38248 .69145 Mdot
.3804 .6945 Mdot
.35533 .57666 Mdot
.69312 .61598 Mdot
.67859 .63646 Mdot
.67676 .61111 Mdot
.70136 .43267 Mdot
.38107 .70065 Mdot
.65414 .34712 Mdot
.38086 .36441 Mdot
.70541 .53992 Mdot
.50296 .70837 Mdot
.54899 .28246 Mdot
.57143 .71087 Mdot
.30927 .44397 Mdot
.49311 .73404 Mdot
.35568 .35811 Mdot
.3615 .6846 Mdot
.53526 .28111 Mdot
.66536 .61728 Mdot
.56625 .70676 Mdot
.48471 .27071 Mdot
.39896 .72336 Mdot
.33521 .34759 Mdot
.37335 .37813 Mdot
.27933 .48893 Mdot
.38297 .69711 Mdot
.31008 .43761 Mdot
.68906 .41234 Mdot
.33116 .55516 Mdot
.39316 .71821 Mdot
.33483 .59279 Mdot
.37314 .66831 Mdot
.70618 .42999 Mdot
.59915 .70206 Mdot
.32037 .37436 Mdot
.38588 .36783 Mdot
.58396 .70711 Mdot
.3074 .45235 Mdot
.64325 .34809 Mdot
.44946 .2959 Mdot
.34095 .38821 Mdot
.2782 .49255 Mdot
.38772 .70077 Mdot
.33028 .57392 Mdot
.38673 .36028 Mdot
.37402 .66205 Mdot
.59077 .68817 Mdot
.53722 .29969 Mdot
.59299 .71103 Mdot
.28993 .43706 Mdot
.30702 .44112 Mdot
.70956 .43067 Mdot
.71307 .5286 Mdot
.28221 .45357 Mdot
.52978 .27698 Mdot
.35892 .66329 Mdot
.38254 .68837 Mdot
.67862 .62974 Mdot
.37363 .64733 Mdot
.28909 .43729 Mdot
.37649 .6584 Mdot
.6742 .60442 Mdot
.69688 .60763 Mdot
.34696 .57849 Mdot
.58509 .69211 Mdot
.70956 .50431 Mdot
.28173 .4718 Mdot
.6882 .43635 Mdot
.4283 .72614 Mdot
.67671 .42272 Mdot
.67762 .61008 Mdot
.33282 .37053 Mdot
.73471 .53994 Mdot
.3319 .37132 Mdot
.62282 .6621 Mdot
.34149 .61769 Mdot
.68149 .62853 Mdot
.32035 .36473 Mdot
.57338 .29693 Mdot
.4974 .27613 Mdot
.37563 .36304 Mdot
.70899 .53882 Mdot
.35788 .373 Mdot
.28684 .45541 Mdot
.63283 .32122 Mdot
.71939 .50354 Mdot
.52756 .29938 Mdot
.50784 .27688 Mdot
.63616 .32924 Mdot
.33619 .59966 Mdot
.38821 .71547 Mdot
.52136 .28996 Mdot
.71864 .40561 Mdot
.69472 .54195 Mdot
.34084 .59157 Mdot
.34553 .38845 Mdot
.55282 .30438 Mdot
.60522 .31421 Mdot
.66953 .6259 Mdot
.56359 .70505 Mdot
.37103 .64276 Mdot
.65209 .36262 Mdot
.37293 .70975 Mdot
.5845 .68946 Mdot
.27419 .47658 Mdot
.35735 .63521 Mdot
.36543 .6873 Mdot
.65219 .35816 Mdot
.33184 .38134 Mdot
.47126 .72542 Mdot
.4841 .2772 Mdot
.39002 .72188 Mdot
.29255 .52601 Mdot
.38601 .36134 Mdot
.3885 .68198 Mdot
.31817 .38603 Mdot
.72367 .54159 Mdot
.33597 .58938 Mdot
.62456 .33545 Mdot
.57507 .30371 Mdot
.38687 .66335 Mdot
.40456 .33854 Mdot
.63459 .34736 Mdot
.35345 .35835 Mdot
.28631 .48107 Mdot
.57083 .70284 Mdot
.36579 .6414 Mdot
.46077 .29419 Mdot
.29896 .45775 Mdot
.33251 .59515 Mdot
.53888 .27556 Mdot
.64805 .35266 Mdot
.37161 .35895 Mdot
.38438 .70616 Mdot
.64423 .34116 Mdot
.6917 .43223 Mdot
.31101 .43963 Mdot
.7299 .48328 Mdot
.33281 .61491 Mdot
.32724 .59575 Mdot
.74541 .50633 Mdot
.67235 .63313 Mdot
.39487 .71002 Mdot
.33108 .54715 Mdot
.69983 .41031 Mdot
.41522 .73257 Mdot
.36444 .69537 Mdot
.32202 .36131 Mdot
.71588 .40894 Mdot
.58898 .30477 Mdot
.50569 .27254 Mdot
.29207 .46189 Mdot
.72438 .54637 Mdot
.3175 .43587 Mdot
.571 .30424 Mdot
.37711 .70719 Mdot
.67796 .41789 Mdot
.62151 .66586 Mdot
.63363 .34053 Mdot
.5248 .28114 Mdot
.65153 .63539 Mdot
.52808 .72396 Mdot
.29408 .52678 Mdot
.71598 .40193 Mdot
.44295 .28824 Mdot
.27116 .4565 Mdot
.63926 .63193 Mdot
.32608 .58001 Mdot
.4881 .71301 Mdot
.38613 .6637 Mdot
.39165 .34333 Mdot
.45312 .29921 Mdot
.39085 .35994 Mdot
.3339 .37802 Mdot
.40346 .71941 Mdot
.69081 .43276 Mdot
.65649 .3578 Mdot
.34502 .35545 Mdot
.69158 .42286 Mdot
.32325 .57213 Mdot
.53211 .28852 Mdot
.62417 .65186 Mdot
.33077 .57913 Mdot
.29758 .48633 Mdot
.61414 .32875 Mdot
.6423 .61943 Mdot
.58241 .29491 Mdot
.38119 .69481 Mdot
.6918 .57426 Mdot
.68489 .41512 Mdot
.35602 .65945 Mdot
.57401 .3003 Mdot
.34219 .3881 Mdot
.54579 .27629 Mdot
.39278 .69521 Mdot
.37825 .68938 Mdot
.32724 .38118 Mdot
.33121 .58124 Mdot
.69665 .50949 Mdot
.59893 .68382 Mdot
.56294 .68439 Mdot
.35285 .60481 Mdot
.63576 .65517 Mdot
.63746 .35425 Mdot
.34332 .35601 Mdot
.47935 .72206 Mdot
.37082 .65974 Mdot
.71351 .50009 Mdot
.64341 .35017 Mdot
.6693 .35229 Mdot
.70373 .43027 Mdot
.57612 .29988 Mdot
.69181 .43573 Mdot
.35547 .57585 Mdot
.6923 .55002 Mdot
.55698 .29572 Mdot
.34668 .36335 Mdot
.53727 .26104 Mdot
.34693 .56126 Mdot
.60944 .31751 Mdot
.51253 .26606 Mdot
.58002 .68335 Mdot
.69902 .5545 Mdot
.40067 .3276 Mdot
.54282 .70366 Mdot
.37013 .69955 Mdot
.3866 .66562 Mdot
.36433 .38341 Mdot
.70842 .43105 Mdot
.67177 .62884 Mdot
.42955 .29397 Mdot
.29294 .436 Mdot
.68908 .55357 Mdot
.30742 .43315 Mdot
.5026 .72489 Mdot
.63495 .64961 Mdot
.46778 .73733 Mdot
.71187 .41832 Mdot
.70821 .53516 Mdot
.27516 .44501 Mdot
.58885 .67627 Mdot
.29992 .44883 Mdot
.55633 .27422 Mdot
.51227 .7386 Mdot
.53585 .30156 Mdot
.6335 .32495 Mdot
.43926 .29613 Mdot
.6961 .40606 Mdot
.40463 .33752 Mdot
.60357 .70682 Mdot
.64445 .35933 Mdot
.62097 .32648 Mdot
.56943 .30986 Mdot
.35253 .35372 Mdot
.5978 .7029 Mdot
.35425 .34694 Mdot
.35991 .34976 Mdot
.65511 .36137 Mdot
.70627 .53014 Mdot
.71786 .51162 Mdot
.25889 .49575 Mdot
.70792 .52829 Mdot
.5465 .29885 Mdot
.49842 .72076 Mdot
.53563 .71968 Mdot
.63479 .353 Mdot
.57105 .70372 Mdot
.36032 .60084 Mdot
.44153 .30846 Mdot
.53812 .29351 Mdot
.69757 .43348 Mdot
.74516 .53061 Mdot
.3331 .36396 Mdot
.66802 .62776 Mdot
.71487 .54697 Mdot
.72434 .53666 Mdot
.73527 .54159 Mdot
.3746 .6937 Mdot
.69374 .40463 Mdot
.71325 .53923 Mdot
.39125 .70019 Mdot
.32502 .59519 Mdot
.34668 .38595 Mdot
.39002 .34276 Mdot
.59162 .69176 Mdot
.34931 .37966 Mdot
.33457 .56853 Mdot
.55799 .28564 Mdot
.39622 .34212 Mdot
.32868 .36855 Mdot
.57957 .31185 Mdot
.57918 .3143 Mdot
.35722 .34763 Mdot
.39693 .34268 Mdot
.69972 .50474 Mdot
.6081 .70438 Mdot
.64994 .65471 Mdot
.51061 .26499 Mdot
.66626 .37163 Mdot
.68007 .62889 Mdot
.3913 .67014 Mdot
.33985 .39194 Mdot
.53683 .28343 Mdot
.72629 .50453 Mdot
.34742 .59552 Mdot
.34961 .37392 Mdot
.29315 .4535 Mdot
.34641 .36163 Mdot
.36545 .38051 Mdot
.67908 .64204 Mdot
.70319 .46744 Mdot
.64581 .6294 Mdot
.48632 .2745 Mdot
.35675 .36025 Mdot
.69458 .59767 Mdot
.42238 .30569 Mdot
.63759 .32218 Mdot
.60062 .68391 Mdot
.3541 .60498 Mdot
.5743 .31451 Mdot
.6996 .53845 Mdot
.6811 .44175 Mdot
.46347 .73569 Mdot
.71383 .52972 Mdot
.39321 .35781 Mdot
.37474 .3689 Mdot
.55485 .30549 Mdot
.68822 .62447 Mdot
.58314 .69058 Mdot
.71831 .53341 Mdot
.63766 .33211 Mdot
.38107 .65374 Mdot
.69205 .57582 Mdot
.34319 .37936 Mdot
.71499 .51585 Mdot
.52218 .27074 Mdot
.29347 .44295 Mdot
.37556 .66979 Mdot
.68185 .38001 Mdot
.33157 .59201 Mdot
.64066 .33066 Mdot
.29106 .49449 Mdot
.56979 .68624 Mdot
.388 .67396 Mdot
.48552 .71606 Mdot
.61916 .3265 Mdot
.3942 .69038 Mdot
.52355 .72164 Mdot
.6397 .6419 Mdot
.65796 .62729 Mdot
.3251 .56533 Mdot
.52988 .29438 Mdot
.46562 .27401 Mdot
.33462 .61001 Mdot
.48277 .26803 Mdot
.52296 .73107 Mdot
.3324 .35771 Mdot
.25774 .47485 Mdot
.36073 .65445 Mdot
.37988 .6702 Mdot
.35327 .58258 Mdot
.38206 .65317 Mdot
.45364 .73007 Mdot
.57314 .3034 Mdot
.58398 .30178 Mdot
.28509 .45968 Mdot
.39693 .73141 Mdot
.30399 .44092 Mdot
.64727 .35353 Mdot
.60034 .70852 Mdot
.3792 .37383 Mdot
.71122 .52451 Mdot
.33365 .58903 Mdot
.54548 .27109 Mdot
.3876 .68002 Mdot
.57684 .69847 Mdot
.54994 .30133 Mdot
.54138 .28189 Mdot
.48316 .27926 Mdot
.28146 .44236 Mdot
.73165 .52924 Mdot
.35209 .56913 Mdot
.26286 .4683 Mdot
.32558 .37088 Mdot
.43537 .73418 Mdot
.69196 .55731 Mdot
.72492 .5171 Mdot
.73657 .52565 Mdot
.34803 .5715 Mdot
.34801 .57006 Mdot
.6483 .33635 Mdot
.66265 .644 Mdot
.68157 .40809 Mdot
.56912 .31428 Mdot
.47282 .27022 Mdot
.38298 .67452 Mdot
.29451 .48665 Mdot
.30723 .45017 Mdot
.52254 .26183 Mdot
.37672 .37287 Mdot
.3098 .43592 Mdot
.34396 .56417 Mdot
.55659 .3081 Mdot
.27486 .44772 Mdot
.74227 .53203 Mdot
.67178 .37156 Mdot
.30196 .43829 Mdot
.33703 .38051 Mdot
.6468 .6469 Mdot
.36488 .67263 Mdot
.31626 .43315 Mdot
.64196 .35591 Mdot
.47659 .73785 Mdot
.38004 .36949 Mdot
.30251 .47564 Mdot
.41669 .72812 Mdot
.56444 .30103 Mdot
.33487 .38043 Mdot
.27447 .44416 Mdot
.53754 .71897 Mdot
.31582 .44156 Mdot
.7211 .51532 Mdot
.55519 .69067 Mdot
.38129 .6655 Mdot
.5715 .69273 Mdot
.70354 .44736 Mdot
.55652 .27344 Mdot
.57216 .28671 Mdot
.68398 .62367 Mdot
.49106 .71857 Mdot
.51937 .29117 Mdot
.48459 .71789 Mdot
.25636 .48348 Mdot
.39116 .69966 Mdot
.25659 .49501 Mdot
.58357 .6765 Mdot
.30239 .42696 Mdot
.29784 .44018 Mdot
.62268 .34159 Mdot
.6861 .42599 Mdot
.70861 .4275 Mdot
.53049 .29767 Mdot
.49718 .72847 Mdot
.5787 .29461 Mdot
.73617 .48973 Mdot
.29549 .46634 Mdot
.46485 .28546 Mdot
.35798 .59448 Mdot
.33659 .56881 Mdot
.56475 .70042 Mdot
.3534 .38664 Mdot
.39261 .70465 Mdot
.64394 .33794 Mdot
.53661 .26349 Mdot
.6094 .31558 Mdot
.68678 .61326 Mdot
.73917 .49414 Mdot
.5457 .28321 Mdot
.25617 .48729 Mdot
.3099 .44695 Mdot
.41777 .73651 Mdot
.35705 .3411 Mdot
.56276 .2854 Mdot
.34355 .6262 Mdot
.72182 .50293 Mdot
.48136 .28636 Mdot
.33668 .5923 Mdot
.50805 .27393 Mdot
.41704 .3055 Mdot
.57529 .68205 Mdot
.36894 .67652 Mdot
.66787 .37028 Mdot
.48417 .72144 Mdot
.2989 .43002 Mdot
.32691 .3822 Mdot
.49335 .70818 Mdot
.57179 .3063 Mdot
.5515 .26683 Mdot
.29228 .44032 Mdot
.64239 .62525 Mdot
.71995 .50745 Mdot
.70024 .50453 Mdot
.64411 .33547 Mdot
.34483 .62061 Mdot
.55903 .30778 Mdot
.66114 .63495 Mdot
.3585 .66194 Mdot
.69945 .41432 Mdot
.52717 .25909 Mdot
.33133 .58158 Mdot
.38849 .67609 Mdot
.29806 .44415 Mdot
.26257 .50148 Mdot
.31977 .37892 Mdot
.63557 .32087 Mdot
.41 .72302 Mdot
.59805 .71168 Mdot
.34752 .57866 Mdot
.6942 .5345 Mdot
.36062 .3732 Mdot
.30454 .44953 Mdot
.39764 .71311 Mdot
.50184 .71226 Mdot
.7032 .51554 Mdot
.71082 .41563 Mdot
.35028 .36474 Mdot
.40803 .72338 Mdot
.33099 .58549 Mdot
.37998 .66034 Mdot
.58784 .68391 Mdot
.35735 .60892 Mdot
.4408 .30565 Mdot
.64955 .61235 Mdot
.26898 .47818 Mdot
.72785 .53258 Mdot
.42823 .29931 Mdot
.60273 .68797 Mdot
.50695 .73397 Mdot
.63467 .65127 Mdot
.69555 .55466 Mdot
.63627 .33101 Mdot
.68836 .40755 Mdot
.28684 .49231 Mdot
.38947 .68741 Mdot
.38428 .36031 Mdot
.71896 .53819 Mdot
.55653 .27416 Mdot
.3057 .44 Mdot
.44593 .28676 Mdot
.34188 .57666 Mdot
.56878 .30797 Mdot
.37242 .36161 Mdot
.68997 .62373 Mdot
.56159 .28859 Mdot
.34305 .38794 Mdot
.27707 .47263 Mdot
.47843 .73657 Mdot
.39937 .34949 Mdot
.33407 .37287 Mdot
.38562 .68269 Mdot
.62187 .66851 Mdot
.57047 .69972 Mdot
.32538 .35736 Mdot
.58532 .29703 Mdot
.34005 .37673 Mdot
.6418 .61837 Mdot
.5739 .68455 Mdot
.52891 .26675 Mdot
.67373 .63639 Mdot
.59827 .68253 Mdot
.33258 .36832 Mdot
.69286 .55877 Mdot
.42418 .29934 Mdot
.74139 .51084 Mdot
.36107 .66769 Mdot
.3457 .61187 Mdot
.53094 .29942 Mdot
.29765 .44982 Mdot
.65692 .35101 Mdot
.64213 .36292 Mdot
.62133 .32984 Mdot
.52788 .30193 Mdot
.33293 .58572 Mdot
.7113 .53685 Mdot
.68471 .41935 Mdot
.67394 .62561 Mdot
.53097 .27466 Mdot
.52937 .29032 Mdot
.56608 .70413 Mdot
.3076 .44011 Mdot
.35732 .59095 Mdot
.55603 .27427 Mdot
.44059 .29843 Mdot
.69423 .59024 Mdot
.2946 .4313 Mdot
.59982 .68917 Mdot
.39923 .35013 Mdot
.38802 .72479 Mdot
.63394 .63993 Mdot
.37762 .36448 Mdot
.68887 .61861 Mdot
.36368 .68577 Mdot
.60335 .31739 Mdot
.42348 .30612 Mdot
.48604 .71973 Mdot
.66245 .34856 Mdot
.68204 .41495 Mdot
.56475 .29253 Mdot
.34266 .58582 Mdot
.45043 .28592 Mdot
.29087 .4624 Mdot
.5806 .67388 Mdot
.34467 .35462 Mdot
.677 .62756 Mdot
.67972 .42574 Mdot
.39826 .34004 Mdot
.6567 .35053 Mdot
.71039 .42468 Mdot
.6438 .65698 Mdot
.38108 .66637 Mdot
.54392 .28759 Mdot
.51957 .28577 Mdot
.25695 .49459 Mdot
.44985 .30587 Mdot
.73304 .51275 Mdot
.60288 .31644 Mdot
.47517 .71354 Mdot
.32635 .56475 Mdot
.39268 .35415 Mdot
.38267 .35683 Mdot
.43355 .29922 Mdot
.39453 .69156 Mdot
.65652 .61832 Mdot
.58433 .29967 Mdot
.50326 .27681 Mdot
.57433 .68915 Mdot
.68445 .42394 Mdot
.3424 .34315 Mdot
.54345 .29641 Mdot
.42949 .72573 Mdot
.38164 .67461 Mdot
.71533 .40188 Mdot
.54708 .29749 Mdot
.41316 .31738 Mdot
.66252 .37338 Mdot
.65288 .63409 Mdot
.46183 .72437 Mdot
.66676 .62292 Mdot
.30942 .43686 Mdot
.56876 .2868 Mdot
.65327 .35319 Mdot
.35212 .36083 Mdot
.46699 .27508 Mdot
.52267 .29459 Mdot
.7224 .52202 Mdot
.3814 .66255 Mdot
.35111 .64124 Mdot
.33003 .58247 Mdot
.41386 .73786 Mdot
.29376 .43356 Mdot
.64139 .36271 Mdot
.63422 .33094 Mdot
.46159 .7239 Mdot
.27863 .44368 Mdot
.58077 .30481 Mdot
.55261 .30216 Mdot
.68042 .38001 Mdot
.36672 .37932 Mdot
.58095 .30283 Mdot
.38319 .68065 Mdot
.47773 .27663 Mdot
.64161 .64984 Mdot
.68446 .42611 Mdot
.37181 .66043 Mdot
.52302 .29576 Mdot
.67468 .64609 Mdot
.49114 .72612 Mdot
.33319 .60739 Mdot
.31592 .37676 Mdot
.68654 .41072 Mdot
.74553 .50157 Mdot
.44004 .30877 Mdot
.343 .61767 Mdot
.64688 .34855 Mdot
.40762 .33119 Mdot
.4768 .27897 Mdot
.7304 .53908 Mdot
.50858 .27695 Mdot
.68564 .43463 Mdot
.36691 .36159 Mdot
.26933 .479 Mdot
.5518 .27895 Mdot
.5044 .27136 Mdot
.58475 .70205 Mdot
.2588 .4917 Mdot
.31317 .43266 Mdot
.69716 .54649 Mdot
.70263 .41012 Mdot
.57451 .69755 Mdot
.42655 .72633 Mdot
.34853 .56859 Mdot
.71021 .42994 Mdot
.69552 .58541 Mdot
.34145 .62293 Mdot
.3505 .58658 Mdot
.35587 .65374 Mdot
.64393 .63417 Mdot
.70513 .54309 Mdot
.40835 .73411 Mdot
.58641 .69309 Mdot
.50601 .72995 Mdot
.71588 .52027 Mdot
.72841 .52671 Mdot
.49776 .73397 Mdot
.58168 .70182 Mdot
.67058 .64066 Mdot
.68882 .42486 Mdot
.68234 .41447 Mdot
.72489 .5379 Mdot
.5644 .69738 Mdot
.71378 .42645 Mdot
.67306 .61883 Mdot
.52616 .28335 Mdot
.52027 .72533 Mdot
.71554 .55103 Mdot
.51559 .73659 Mdot
.68949 .41219 Mdot
.42377 .73347 Mdot
.52318 .73171 Mdot
.3559 .60974 Mdot
.38308 .66668 Mdot
.26807 .46018 Mdot
.34992 .35956 Mdot
.35781 .34752 Mdot
.70759 .43158 Mdot
.3552 .58241 Mdot
.67294 .61086 Mdot
.35148 .57478 Mdot
.37152 .64514 Mdot
.42259 .72787 Mdot
.4656 .71306 Mdot
.72962 .53849 Mdot
.67569 .61032 Mdot
.47989 .27315 Mdot
.55105 .26884 Mdot
.50641 .71437 Mdot
.68483 .41209 Mdot
.71192 .51605 Mdot
.68123 .40902 Mdot
.57043 .3049 Mdot
.54187 .28563 Mdot
.35565 .37902 Mdot
.33481 .38074 Mdot
.56016 .29257 Mdot
.48577 .27032 Mdot
.42814 .73179 Mdot
.67552 .63351 Mdot
.63715 .62225 Mdot
.36369 .64574 Mdot
.34719 .64261 Mdot
.29588 .4521 Mdot
.40263 .34382 Mdot
.64618 .34159 Mdot
.47534 .71942 Mdot
.33716 .55824 Mdot
.33634 .37054 Mdot
.71038 .44481 Mdot
.30419 .46429 Mdot
.68214 .42157 Mdot
.27812 .48086 Mdot
.52712 .26767 Mdot
.33411 .58138 Mdot
.35399 .58741 Mdot
.63551 .33296 Mdot
.48514 .27897 Mdot
.55203 .30767 Mdot
.29952 .45187 Mdot
.36268 .64781 Mdot
.56113 .30609 Mdot
.71205 .55298 Mdot
.69263 .56647 Mdot
.37737 .35879 Mdot
.34616 .59168 Mdot
.36205 .65955 Mdot
.57549 .68334 Mdot
.32619 .36932 Mdot
.34999 .3654 Mdot
.72768 .4827 Mdot
.38079 .71436 Mdot
.66938 .35031 Mdot
.32973 .37964 Mdot
.73585 .53506 Mdot
.54758 .28817 Mdot
.32878 .36653 Mdot
.35213 .34472 Mdot
.27661 .51821 Mdot
.369 .34652 Mdot
.70359 .52366 Mdot
.66429 .62092 Mdot
.59626 .70573 Mdot
.69767 .58172 Mdot
.27662 .48718 Mdot
.30601 .45668 Mdot
.42365 .30711 Mdot
.62473 .33762 Mdot
.3589 .6741 Mdot
.29802 .4619 Mdot
.74406 .52486 Mdot
.5702 .70868 Mdot
.58113 .70907 Mdot
.59008 .70582 Mdot
.67254 .62337 Mdot
.38148 .69237 Mdot
.44869 .30066 Mdot
.72048 .52105 Mdot
.59212 .71124 Mdot
.3393 .62913 Mdot
.69878 .51138 Mdot
.70706 .41407 Mdot
.57426 .67535 Mdot
.7111 .5348 Mdot
.45341 .72837 Mdot
.69854 .40726 Mdot
.49198 .71366 Mdot
.60087 .31538 Mdot
.41672 .31726 Mdot
.69558 .4318 Mdot
.52481 .2597 Mdot
.56703 .30969 Mdot
.54241 .30087 Mdot
.71028 .54489 Mdot
.49705 .27233 Mdot
.67415 .60892 Mdot
.4431 .28837 Mdot
.40653 .72297 Mdot
.29107 .48493 Mdot
.4426 .29616 Mdot
.72477 .53542 Mdot
.74669 .50716 Mdot
.30195 .53031 Mdot
.33328 .61132 Mdot
.64966 .35935 Mdot
.28314 .46405 Mdot
.49877 .72156 Mdot
.27297 .47629 Mdot
.57561 .3028 Mdot
.40404 .7137 Mdot
.38147 .67389 Mdot
.67097 .36447 Mdot
.29813 .44809 Mdot
.72942 .52961 Mdot
.58659 .70338 Mdot
.59556 .31814 Mdot
.29306 .46076 Mdot
.30736 .44174 Mdot
.3293 .59974 Mdot
.66587 .61928 Mdot
.57148 .31572 Mdot
.71934 .41572 Mdot
.42803 .29167 Mdot
.44618 .73103 Mdot
.38851 .71734 Mdot
.34068 .61799 Mdot
.50658 .72465 Mdot
.43241 .2956 Mdot
.69341 .42665 Mdot
.37398 .6467 Mdot
.41583 .31495 Mdot
.37385 .644 Mdot
.69314 .6197 Mdot
.4427 .29234 Mdot
.37646 .35674 Mdot
.34473 .3865 Mdot
.34266 .5958 Mdot
.29526 .52879 Mdot
.38286 .70431 Mdot
.71575 .42632 Mdot
.35575 .3547 Mdot
.51478 .26133 Mdot
.72561 .50609 Mdot
.27865 .5194 Mdot
.58962 .69029 Mdot
.71821 .41517 Mdot
.55827 .30399 Mdot
.28492 .52324 Mdot
.2704 .45977 Mdot
.52719 .73105 Mdot
.32326 .58958 Mdot
.34437 .59614 Mdot
.70517 .41969 Mdot
.7145 .43308 Mdot
.63541 .63525 Mdot
.39556 .34903 Mdot
.69161 .57136 Mdot
.63135 .33946 Mdot
.28278 .52237 Mdot
.38491 .35743 Mdot
.64986 .62228 Mdot
.38675 .35111 Mdot
.69873 .44883 Mdot
.38844 .71314 Mdot
.66531 .62039 Mdot
.37309 .36437 Mdot
.54986 .6956 Mdot
.57384 .70557 Mdot
.43048 .72788 Mdot
.33417 .60289 Mdot
.72953 .5144 Mdot
.71991 .51878 Mdot
.66981 .61277 Mdot
.37019 .37247 Mdot
.33939 .57406 Mdot
.35142 .60671 Mdot
.34687 .61916 Mdot
.69504 .58739 Mdot
.33444 .58517 Mdot
.73622 .50788 Mdot
.51785 .72077 Mdot
.60205 .31402 Mdot
.35156 .5808 Mdot
.69689 .43754 Mdot
.34244 .60384 Mdot
.30807 .43139 Mdot
.47212 .73162 Mdot
.58243 .68029 Mdot
.69463 .42273 Mdot
.34983 .6311 Mdot
.40994 .32532 Mdot
.3507 .56733 Mdot
.2808 .48371 Mdot
.66333 .36618 Mdot
.37478 .69689 Mdot
.69304 .58937 Mdot
.72124 .53253 Mdot
.54107 .27303 Mdot
.67541 .43079 Mdot
.5732 .29627 Mdot
.60856 .70387 Mdot
.38873 .35629 Mdot
.46086 .28449 Mdot
.42557 .72686 Mdot
.38243 .71224 Mdot
.36804 .3808 Mdot
.68167 .61283 Mdot
.44129 .30364 Mdot
.34692 .64534 Mdot
.56498 .7022 Mdot
.29072 .44248 Mdot
.27598 .47514 Mdot
.26393 .50504 Mdot
.66635 .63129 Mdot
.74734 .51145 Mdot
.70349 .41845 Mdot
.51953 .29225 Mdot
.29715 .42954 Mdot
.7047 .38844 Mdot
.70372 .44394 Mdot
.43471 .30114 Mdot
.67976 .42438 Mdot
.34582 .57531 Mdot
.35515 .34773 Mdot
.64834 .64214 Mdot
.34063 .36046 Mdot
.36086 .67718 Mdot
.50184 .27909 Mdot
.37453 .37099 Mdot
.26387 .46716 Mdot
.69017 .43904 Mdot
.55125 .28318 Mdot
.37974 .66229 Mdot
.719 .51725 Mdot
.61493 .70089 Mdot
.41234 .3161 Mdot
.58421 .68063 Mdot
.58792 .68006 Mdot
.64164 .63349 Mdot
.32586 .36217 Mdot
.44994 .27837 Mdot
.58662 .67762 Mdot
.62573 .32774 Mdot
.31144 .46738 Mdot
.47013 .29055 Mdot
.56902 .28505 Mdot
.55836 .29754 Mdot
.36525 .69197 Mdot
.58869 .30944 Mdot
.48523 .73432 Mdot
.59595 .3181 Mdot
.65982 .36868 Mdot
.38625 .69573 Mdot
.55185 .30061 Mdot
.32891 .377 Mdot
.37925 .67729 Mdot
.65554 .62719 Mdot
.58809 .31532 Mdot
.35583 .61037 Mdot
.49285 .2662 Mdot
.63725 .33064 Mdot
.36713 .37488 Mdot
.47346 .73767 Mdot
.68818 .42064 Mdot
.70178 .53215 Mdot
.45109 .72044 Mdot
.2919 .46491 Mdot
.66154 .61164 Mdot
.29905 .48409 Mdot
.31058 .44208 Mdot
.51663 .72693 Mdot
.69792 .55207 Mdot
.37347 .3542 Mdot
.27803 .47396 Mdot
.25974 .47958 Mdot
.56101 .29916 Mdot
.41858 .31053 Mdot
.33835 .37821 Mdot
.37897 .66065 Mdot
.45806 .29013 Mdot
.69283 .43452 Mdot
.32766 .60019 Mdot
.54496 .30429 Mdot
.3649 .35471 Mdot
.35022 .59171 Mdot
.58773 .69231 Mdot
.64152 .64162 Mdot
.38677 .34637 Mdot
.28636 .48297 Mdot
.6599 .62385 Mdot
.34009 .61707 Mdot
.27357 .48958 Mdot
.42335 .29685 Mdot
.37781 .68177 Mdot
.73082 .54061 Mdot
.74347 .53006 Mdot
.56176 .27712 Mdot
.71177 .41455 Mdot
.51653 .2823 Mdot
.27582 .4823 Mdot
.30238 .53171 Mdot
.34662 .38175 Mdot
.58159 .67542 Mdot
.48256 .73543 Mdot
.55179 .27546 Mdot
.731 .52756 Mdot
.70961 .39586 Mdot
.47334 .73291 Mdot
.38006 .68282 Mdot
.34704 .59796 Mdot
.43677 .29456 Mdot
.72121 .50594 Mdot
.347 .59524 Mdot
.39355 .34263 Mdot
.3815 .68903 Mdot
.2851 .45488 Mdot
.59949 .31462 Mdot
.33517 .38798 Mdot
.69769 .59039 Mdot
.37194 .36794 Mdot
.54203 .29798 Mdot
.44489 .71993 Mdot
.50271 .72784 Mdot
.26698 .50984 Mdot
.70311 .52309 Mdot
.6722 .64752 Mdot
.54121 .28795 Mdot
.42669 .29997 Mdot
.59407 .69075 Mdot
.58889 .7002 Mdot
.37959 .67606 Mdot
.57498 .3018 Mdot
.57125 .27941 Mdot
.3869 .35277 Mdot
.37407 .3741 Mdot
.51258 .71388 Mdot
.52841 .2695 Mdot
.33441 .58217 Mdot
.56707 .6983 Mdot
.69126 .44628 Mdot
.66185 .62908 Mdot
.63641 .35631 Mdot
.68556 .44513 Mdot
.35338 .65878 Mdot
.41144 .72179 Mdot
.64652 .3372 Mdot
.61819 .3308 Mdot
.43215 .30385 Mdot
.52412 .71472 Mdot
.3035 .43839 Mdot
.41539 .72694 Mdot
.5759 .29878 Mdot
.33186 .57188 Mdot
.73783 .52058 Mdot
.39486 .35271 Mdot
.69264 .38462 Mdot
.31701 .53819 Mdot
.60012 .6998 Mdot
.45713 .29474 Mdot
.33344 .37149 Mdot
.34399 .35648 Mdot
.36452 .66768 Mdot
.33549 .58369 Mdot
.56401 .27894 Mdot
.53509 .71796 Mdot
.6319 .34052 Mdot
.42853 .30376 Mdot
.66514 .63392 Mdot
.34144 .59979 Mdot
.70711 .49993 Mdot
.6903 .44316 Mdot
.31395 .45826 Mdot
.27561 .44941 Mdot
.34985 .56611 Mdot
.60215 .68558 Mdot
.63373 .32436 Mdot
.5922 .69519 Mdot
.57887 .69943 Mdot
.3448 .37522 Mdot
.59924 .68798 Mdot
.32209 .5861 Mdot
.32963 .61273 Mdot
.32547 .37085 Mdot
.69867 .44647 Mdot
.36223 .6771 Mdot
.33322 .36666 Mdot
.46649 .73166 Mdot
.67762 .43177 Mdot
.59268 .69343 Mdot
.70374 .43114 Mdot
.43166 .30146 Mdot
.64001 .33312 Mdot
.26829 .47759 Mdot
.43954 .2996 Mdot
.63732 .62472 Mdot
.71078 .53616 Mdot
.68991 .40519 Mdot
.2776 .47183 Mdot
.69946 .43483 Mdot
.55325 .28102 Mdot
.63085 .32706 Mdot
.69808 .61117 Mdot
.43147 .72505 Mdot
.35438 .66048 Mdot
.71291 .40285 Mdot
.54133 .26586 Mdot
.72433 .53801 Mdot
.62293 .33442 Mdot
.48948 .74017 Mdot
.27275 .45625 Mdot
.34419 .59933 Mdot
.69094 .44063 Mdot
.44869 .2938 Mdot
.63642 .64457 Mdot
.28184 .4798 Mdot
.74265 .4965 Mdot
.53949 .2701 Mdot
.3866 .6925 Mdot
.65074 .36843 Mdot
.46764 .27804 Mdot
.6342 .33365 Mdot
.35142 .63784 Mdot
.38304 .36541 Mdot
.3901 .34499 Mdot
.66643 .6473 Mdot
.36449 .38419 Mdot
.40644 .33384 Mdot
.62258 .32593 Mdot
.64495 .62112 Mdot
.48338 .27394 Mdot
.37901 .65972 Mdot
.59796 .71017 Mdot
.35133 .37786 Mdot
.72032 .51133 Mdot
.58558 .68417 Mdot
.35427 .38104 Mdot
.5188 .72155 Mdot
.66481 .6247 Mdot
.58442 .31201 Mdot
.38432 .68093 Mdot
.65282 .36606 Mdot
.637 .34612 Mdot
.39264 .35855 Mdot
.65633 .35242 Mdot
.46645 .73144 Mdot
.69909 .55376 Mdot
.59728 .70213 Mdot
.28416 .45701 Mdot
.69394 .51514 Mdot
.38961 .34924 Mdot
.27581 .51594 Mdot
.38583 .68435 Mdot
.54246 .28697 Mdot
.47859 .27912 Mdot
.51087 .71449 Mdot
.71626 .52234 Mdot
.4772 .73135 Mdot
.59288 .68404 Mdot
.59072 .69703 Mdot
.52073 .29298 Mdot
.50125 .7232 Mdot
.33393 .58369 Mdot
.71496 .41157 Mdot
.45936 .73596 Mdot
.3448 .63405 Mdot
.40055 .3458 Mdot
.58183 .68046 Mdot
.65871 .36567 Mdot
.67347 .63505 Mdot
.5447 .28892 Mdot
.65597 .61643 Mdot
.67252 .6317 Mdot
.706 .54072 Mdot
.70736 .39044 Mdot
.58476 .67802 Mdot
.67648 .36812 Mdot
.64041 .64973 Mdot
.34771 .64139 Mdot
.73776 .51389 Mdot
.44266 .28147 Mdot
.64557 .61879 Mdot
.70182 .53024 Mdot
.62381 .65132 Mdot
.71971 .50649 Mdot
.37811 .66802 Mdot
.37154 .65854 Mdot
.49314 .7093 Mdot
.44398 .28905 Mdot
.33001 .58065 Mdot
.36072 .34637 Mdot
.28007 .46003 Mdot
.64352 .62835 Mdot
.34923 .36334 Mdot
.51836 .73091 Mdot
.31707 .39353 Mdot
.32388 .58306 Mdot
.34777 .5887 Mdot
.59218 .70298 Mdot
.42136 .73227 Mdot
.45309 .28688 Mdot
.73505 .52622 Mdot
.34155 .63253 Mdot
.47251 .2775 Mdot
.39251 .70153 Mdot
.47315 .72921 Mdot
.33289 .61808 Mdot
.54388 .28752 Mdot
.66458 .63832 Mdot
.35957 .34943 Mdot
.71114 .49344 Mdot
.33177 .59457 Mdot
.31525 .39715 Mdot
.2821 .49222 Mdot
.34602 .58957 Mdot
.703 .50287 Mdot
.58863 .68361 Mdot
.69871 .53292 Mdot
.69118 .54312 Mdot
.38036 .68336 Mdot
.65608 .63708 Mdot
.70472 .54412 Mdot
.58893 .69921 Mdot
.45772 .29384 Mdot
.63373 .32105 Mdot
.3821 .70939 Mdot
.28342 .47912 Mdot
.39256 .68072 Mdot
.31474 .44044 Mdot
.34463 .3511 Mdot
.33644 .37553 Mdot
.38428 .69841 Mdot
.53704 .26232 Mdot
.31712 .43454 Mdot
.44877 .28812 Mdot
.69883 .60574 Mdot
.65372 .65446 Mdot
.62974 .33785 Mdot
.41755 .31089 Mdot
.33884 .37612 Mdot
.35904 .64595 Mdot
.44532 .72921 Mdot
.65281 .34428 Mdot
.69075 .62265 Mdot
.38073 .70608 Mdot
.35748 .38706 Mdot
.58403 .31558 Mdot
.52239 .28756 Mdot
.62335 .32628 Mdot
.6238 .65548 Mdot
.34206 .57002 Mdot
.35951 .38584 Mdot
.56855 .6776 Mdot
.35168 .3585 Mdot
.37139 .34891 Mdot
.52474 .25865 Mdot
.33933 .5779 Mdot
.52032 .73379 Mdot
.57189 .31174 Mdot
.31017 .45393 Mdot
.68906 .62669 Mdot
.27609 .48633 Mdot
.67031 .36638 Mdot
.63748 .63892 Mdot
.56652 .29567 Mdot
.33857 .38962 Mdot
.32856 .57416 Mdot
.67177 .62921 Mdot
.68234 .61543 Mdot
.65686 .63048 Mdot
.28305 .46061 Mdot
.57557 .28939 Mdot
.43245 .28963 Mdot
.37984 .66524 Mdot
.69717 .55633 Mdot
.27571 .51795 Mdot
.39092 .68029 Mdot
.68337 .41473 Mdot
.58161 .68473 Mdot
.72575 .54231 Mdot
.57468 .67854 Mdot
.63712 .65213 Mdot
.52772 .29214 Mdot
.35174 .56603 Mdot
.37656 .66875 Mdot
.37429 .69538 Mdot
.30338 .46476 Mdot
.70827 .50736 Mdot
.41072 .72747 Mdot
.38809 .72481 Mdot
.36354 .66972 Mdot
.3496 .59897 Mdot
.35476 .66161 Mdot
.34056 .34752 Mdot
.34661 .38347 Mdot
.49011 .73785 Mdot
.3377 .61075 Mdot
.69573 .51634 Mdot
.64633 .64499 Mdot
.53972 .71142 Mdot
.71142 .4285 Mdot
.64555 .61718 Mdot
.57415 .31295 Mdot
.58822 .31799 Mdot
.47653 .2733 Mdot
.2598 .46985 Mdot
.59565 .69433 Mdot
.34257 .55686 Mdot
.71492 .42392 Mdot
.28926 .46817 Mdot
.69283 .55509 Mdot
.31005 .439 Mdot
.48517 .71888 Mdot
.26777 .47579 Mdot
.38939 .3609 Mdot
.66078 .37222 Mdot
.56725 .69912 Mdot
.3034 .47004 Mdot
.66017 .6265 Mdot
.37875 .70429 Mdot
.36907 .67193 Mdot
.74777 .50847 Mdot
.29817 .43776 Mdot
.42923 .29054 Mdot
.39108 .69453 Mdot
.3995 .73178 Mdot
.70661 .43038 Mdot
.26998 .47909 Mdot
.68012 .41445 Mdot
.57886 .69098 Mdot
.6757 .64704 Mdot
.72032 .52515 Mdot
.63323 .34449 Mdot
.4746 .72989 Mdot
.26459 .47574 Mdot
.56355 .29572 Mdot
.52085 .71257 Mdot
.45726 .28611 Mdot
.31447 .38588 Mdot
.36654 .6831 Mdot
.44648 .30264 Mdot
.34056 .6308 Mdot
.64072 .34179 Mdot
.35492 .57629 Mdot
.57433 .6806 Mdot
.39965 .7096 Mdot
.55807 .31125 Mdot
.55724 .29733 Mdot
.4524 .28465 Mdot
.37753 .71269 Mdot
.33362 .62316 Mdot
.67724 .6247 Mdot
.57087 .28492 Mdot
.71369 .54239 Mdot
.72602 .51327 Mdot
.52212 .2603 Mdot
.6987 .523 Mdot
.3076 .44099 Mdot
.40241 .71186 Mdot
.6405 .34113 Mdot
.63238 .3345 Mdot
.56185 .29269 Mdot
.51124 .26547 Mdot
.54261 .28586 Mdot
.58181 .68673 Mdot
.70076 .55215 Mdot
.41362 .73021 Mdot
.33246 .60303 Mdot
.35545 .58705 Mdot
.66556 .63471 Mdot
.47701 .73543 Mdot
.31825 .54059 Mdot
.29035 .44398 Mdot
.54185 .29665 Mdot
.67796 .42502 Mdot
.6186 .68632 Mdot
.71608 .41643 Mdot
.37817 .68615 Mdot
.64162 .32568 Mdot
.69034 .61731 Mdot
.26685 .4713 Mdot
.57086 .69371 Mdot
.26965 .45523 Mdot
.6937 .44624 Mdot
.68085 .6173 Mdot
.49424 .72024 Mdot
.38405 .69255 Mdot
.49274 .72957 Mdot
.31801 .40629 Mdot
.63325 .64798 Mdot
.69478 .41037 Mdot
.56917 .70102 Mdot
.31751 .38844 Mdot
.55912 .6904 Mdot
.36432 .68878 Mdot
.35459 .6282 Mdot
.35782 .66237 Mdot
.37376 .65504 Mdot
.65205 .63437 Mdot
.47689 .72547 Mdot
.3448 .38885 Mdot
.3746 .66365 Mdot
.67657 .37757 Mdot
.32563 .57427 Mdot
.35515 .59202 Mdot
.33313 .56504 Mdot
.35302 .63297 Mdot
.64143 .61964 Mdot
.59014 .70681 Mdot
.71453 .41643 Mdot
.39556 .72726 Mdot
.62782 .34382 Mdot
.55684 .28834 Mdot
.39726 .35241 Mdot
.64825 .63807 Mdot
.27056 .45464 Mdot
.66631 .35383 Mdot
.40247 .72895 Mdot
.47702 .27148 Mdot
.371 .64908 Mdot
.39798 .34689 Mdot
.35625 .3485 Mdot
.26362 .47641 Mdot
.51715 .29238 Mdot
.69085 .42946 Mdot
.34344 .62552 Mdot
.71819 .5406 Mdot
.70751 .52721 Mdot
.37436 .66948 Mdot
.70331 .44997 Mdot
.63703 .34578 Mdot
.44257 .29698 Mdot
.34227 .57101 Mdot
.37234 .65872 Mdot
.69503 .53374 Mdot
.42118 .30274 Mdot
.51042 .73091 Mdot
.29826 .45544 Mdot
.33107 .54747 Mdot
.34666 .3895 Mdot
.4806 .72584 Mdot
.71316 .41963 Mdot
.37044 .35563 Mdot
.33478 .55568 Mdot
.41173 .72549 Mdot
.57532 .67594 Mdot
.25967 .49839 Mdot
.56987 .27957 Mdot
.38269 .68395 Mdot
.38914 .6845 Mdot
.66583 .62495 Mdot
.63773 .33296 Mdot
.73162 .52965 Mdot
.69241 .60021 Mdot
.33695 .37572 Mdot
.63836 .32998 Mdot
.35984 .60283 Mdot
.6605 .3619 Mdot
.5816 .6842 Mdot
.37168 .70169 Mdot
.6958 .41061 Mdot
.69241 .53176 Mdot
.69411 .57547 Mdot
.37496 .68885 Mdot
.57682 .69754 Mdot
.39257 .6815 Mdot
.42326 .30366 Mdot
.39543 .35412 Mdot
.38319 .69161 Mdot
.70993 .51868 Mdot
.3882 .67588 Mdot
.69518 .44507 Mdot
.30175 .47488 Mdot
.71372 .52528 Mdot
.45596 .29728 Mdot
.52131 .29097 Mdot
.55544 .27179 Mdot
.38908 .35905 Mdot
.59633 .68533 Mdot
.66009 .6178 Mdot
.7327 .53774 Mdot
.48904 .73211 Mdot
.54281 .29819 Mdot
.29113 .45325 Mdot
.38422 .65749 Mdot
.34188 .39137 Mdot
.65142 .36456 Mdot
.69759 .58413 Mdot
.51678 .7197 Mdot
.26948 .48486 Mdot
.44761 .72849 Mdot
.34554 .3727 Mdot
.3455 .57868 Mdot
.26758 .47785 Mdot
.50996 .26843 Mdot
.5694 .67972 Mdot
.34813 .34338 Mdot
.45424 .28859 Mdot
.51891 .29584 Mdot
.63229 .34603 Mdot
.57819 .28871 Mdot
.26955 .45326 Mdot
.33219 .38167 Mdot
.71009 .52961 Mdot
.34053 .58407 Mdot
.35089 .37532 Mdot
.5321 .28902 Mdot
.38621 .35609 Mdot
.35491 .60598 Mdot
.71712 .4967 Mdot
.56026 .28533 Mdot
.38799 .67977 Mdot
.5824 .67794 Mdot
.63946 .63419 Mdot
.45176 .29564 Mdot
.48011 .73226 Mdot
.28987 .43248 Mdot
.4902 .28082 Mdot
.55285 .30926 Mdot
.37424 .67629 Mdot
.27562 .45653 Mdot
.33756 .60147 Mdot
.68639 .42589 Mdot
.45323 .72547 Mdot
.63545 .33283 Mdot
.37005 .64463 Mdot
.37748 .65386 Mdot
.46276 .71888 Mdot
.65408 .65979 Mdot
.40801 .32762 Mdot
.36877 .64056 Mdot
.35119 .60916 Mdot
.73731 .51549 Mdot
.5122 .73963 Mdot
.4361 .72801 Mdot
.65924 .64133 Mdot
.28744 .48855 Mdot
.70652 .43342 Mdot
.38672 .6622 Mdot
.67185 .36311 Mdot
.28625 .4545 Mdot
.36451 .66186 Mdot
.52236 .71838 Mdot
.72907 .5263 Mdot
.34291 .55852 Mdot
.71795 .52993 Mdot
.38047 .71023 Mdot
.6388 .62671 Mdot
.62395 .33279 Mdot
.35727 .64041 Mdot
.33099 .37999 Mdot
.46924 .27828 Mdot
.35366 .65502 Mdot
.29795 .44509 Mdot
.57201 .68185 Mdot
.33891 .37254 Mdot
.68217 .42181 Mdot
.6224 .31764 Mdot
.54114 .28619 Mdot
.72094 .4205 Mdot
.64907 .61947 Mdot
.44723 .2944 Mdot
.38114 .36449 Mdot
.56852 .67872 Mdot
.30296 .42775 Mdot
.64019 .33023 Mdot
.34784 .60713 Mdot
.34879 .57037 Mdot
.43694 .29414 Mdot
.60023 .31566 Mdot
.73023 .49971 Mdot
.63648 .63255 Mdot
.6791 .61695 Mdot
.30735 .459 Mdot
.45323 .29351 Mdot
.34818 .56051 Mdot
.33301 .57787 Mdot
.49746 .27491 Mdot
.66429 .6377 Mdot
.27716 .46276 Mdot
.38961 .3451 Mdot
.71515 .42556 Mdot
.46869 .2834 Mdot
.71276 .52671 Mdot
.47176 .28716 Mdot
.42897 .29255 Mdot
.62858 .63568 Mdot
.36493 .64889 Mdot
.68973 .4237 Mdot
.47236 .28919 Mdot
.72643 .54303 Mdot
.37833 .68835 Mdot
.35161 .35545 Mdot
.38822 .35976 Mdot
.64216 .65494 Mdot
.56531 .29136 Mdot
.27879 .45149 Mdot
.3616 .67812 Mdot
.25956 .48086 Mdot
.66998 .63406 Mdot
.53702 .2681 Mdot
.36439 .35858 Mdot
.67712 .42935 Mdot
.38843 .67482 Mdot
.28174 .45915 Mdot
.6914 .42324 Mdot
.34274 .38699 Mdot
.40226 .72086 Mdot
.45179 .72142 Mdot
.59117 .67947 Mdot
.70648 .42768 Mdot
.50094 .73158 Mdot
.32262 .57371 Mdot
.64092 .34223 Mdot
.29481 .48835 Mdot
.46608 .27855 Mdot
.46234 .73154 Mdot
.62236 .32589 Mdot
.49575 .27371 Mdot
.58413 .29544 Mdot
.41418 .31108 Mdot
.45329 .28701 Mdot
.63875 .35056 Mdot
.35594 .36486 Mdot
.45069 .28336 Mdot
.63725 .3331 Mdot
.47632 .7207 Mdot
.38553 .66104 Mdot
.53533 .71926 Mdot
.33809 .38815 Mdot
.36665 .37316 Mdot
.65765 .64593 Mdot
.57719 .70932 Mdot
.36021 .35856 Mdot
.34362 .61502 Mdot
.6793 .61309 Mdot
.69308 .40924 Mdot
.27828 .52043 Mdot
.71495 .43425 Mdot
.57085 .67811 Mdot
.53623 .30785 Mdot
.44636 .29646 Mdot
.3414 .58539 Mdot
.65882 .3394 Mdot
.28355 .52257 Mdot
.38764 .66365 Mdot
.57083 .69368 Mdot
.37386 .64414 Mdot
.37433 .66484 Mdot
.66594 .60379 Mdot
.36012 .38361 Mdot
.67188 .61272 Mdot
.68994 .41988 Mdot
.30054 .47722 Mdot
.40552 .3356 Mdot
.70818 .42873 Mdot
.32759 .58428 Mdot
.39481 .3575 Mdot
.34508 .59567 Mdot
.34681 .6209 Mdot
.3852 .72409 Mdot
.25484 .47988 Mdot
.54874 .28417 Mdot
.27409 .44962 Mdot
.70749 .51347 Mdot
.69318 .58538 Mdot
.29503 .4464 Mdot
.51824 .71264 Mdot
.51486 .73029 Mdot
.59942 .31324 Mdot
.70794 .52624 Mdot
.31272 .43706 Mdot
.69976 .43808 Mdot
.44646 .73511 Mdot
.49431 .7111 Mdot
.71848 .41345 Mdot
.35421 .60104 Mdot
.73297 .53824 Mdot
.66143 .64294 Mdot
.63863 .32774 Mdot
.73049 .54017 Mdot
.50347 .73024 Mdot
.5799 .69174 Mdot
.71382 .42101 Mdot
.36426 .63638 Mdot
.63427 .33096 Mdot
.35055 .65679 Mdot
.57363 .69679 Mdot
.71529 .52384 Mdot
.35255 .64316 Mdot
.69243 .52286 Mdot
.35936 .37725 Mdot
.39046 .72666 Mdot
.29303 .45101 Mdot
.49592 .72953 Mdot
.45134 .30271 Mdot
.69246 .6264 Mdot
.72642 .53747 Mdot
.69183 .44833 Mdot
.7284 .52035 Mdot
.67007 .6463 Mdot
.71825 .40577 Mdot
.6499 .61277 Mdot
.33094 .59285 Mdot
.6935 .58199 Mdot
.65758 .61773 Mdot
.69905 .41666 Mdot
.28808 .4629 Mdot
.65828 .63245 Mdot
.42864 .29584 Mdot
.38175 .6797 Mdot
.52714 .27558 Mdot
.30675 .43275 Mdot
.6488 .63744 Mdot
.29669 .44759 Mdot
.53392 .28572 Mdot
.39836 .34544 Mdot
.63907 .35963 Mdot
.65907 .35357 Mdot
.3651 .34319 Mdot
.62596 .32529 Mdot
.71454 .50737 Mdot
.46252 .29055 Mdot
.35905 .63272 Mdot
.33988 .5708 Mdot
.30726 .43124 Mdot
.72392 .5048 Mdot
.66462 .35755 Mdot
.35087 .36193 Mdot
.67345 .638 Mdot
.67942 .43163 Mdot
.44181 .29996 Mdot
.51816 .73546 Mdot
.62971 .3431 Mdot
.33922 .39003 Mdot
.34266 .3742 Mdot
.34726 .59879 Mdot
.36675 .6726 Mdot
.2796 .48112 Mdot
.45994 .27992 Mdot
.58261 .71538 Mdot
.51136 .26438 Mdot
.32815 .56625 Mdot
.59058 .71266 Mdot
.3304 .60738 Mdot
.27571 .44583 Mdot
.63602 .35118 Mdot
.70749 .53348 Mdot
.31574 .45266 Mdot
.51942 .28986 Mdot
.46927 .73807 Mdot
.36904 .66491 Mdot
.50065 .73518 Mdot
.57901 .31388 Mdot
.72649 .50887 Mdot
.55323 .29165 Mdot
.64181 .3441 Mdot
.30385 .4403 Mdot
.5847 .68463 Mdot
.33632 .38832 Mdot
.55693 .27798 Mdot
.69193 .40435 Mdot
.45802 .29703 Mdot
.62061 .31843 Mdot
.33779 .37486 Mdot
.49574 .74149 Mdot
.5896 .31144 Mdot
.35145 .3535 Mdot
.65162 .65188 Mdot
.40625 .73556 Mdot
.63873 .65876 Mdot
.57484 .30077 Mdot
.26794 .51051 Mdot
.69327 .42027 Mdot
.61625 .32949 Mdot
.34734 .64418 Mdot
.29469 .52825 Mdot
.36144 .68234 Mdot
.66519 .37106 Mdot
.63954 .33929 Mdot
.70385 .42619 Mdot
.5493 .29103 Mdot
.69668 .51791 Mdot
.54815 .69694 Mdot
.58247 .30866 Mdot
.36071 .63258 Mdot
.69296 .55512 Mdot
.48753 .71007 Mdot
.58361 .30156 Mdot
.59035 .70068 Mdot
.63227 .64258 Mdot
.31208 .43486 Mdot
.3692 .69199 Mdot
.63368 .34425 Mdot
.39101 .67285 Mdot
.67677 .36486 Mdot
.54045 .28979 Mdot
.3737 .35163 Mdot
.67639 .43741 Mdot
.35166 .57563 Mdot
.33066 .57093 Mdot
.32495 .58411 Mdot
.29867 .43397 Mdot
.64642 .65116 Mdot
.39395 .71203 Mdot
.40469 .71578 Mdot
.59182 .71655 Mdot
.42023 .31206 Mdot
.26777 .45658 Mdot
.41572 .72573 Mdot
.4896 .26985 Mdot
.66507 .64385 Mdot
.35832 .60597 Mdot
.63326 .35173 Mdot
.58099 .71006 Mdot
.70614 .41286 Mdot
.67598 .42018 Mdot
.48102 .28581 Mdot
.71358 .51368 Mdot
.59997 .7035 Mdot
.55646 .26904 Mdot
.6526 .66079 Mdot
.59639 .70816 Mdot
.63682 .62418 Mdot
.70057 .4464 Mdot
.30142 .53238 Mdot
.62672 .34752 Mdot
.38722 .36218 Mdot
.65066 .61539 Mdot
.69282 .56417 Mdot
.48089 .72743 Mdot
.71214 .54779 Mdot
.43863 .29343 Mdot
.66156 .61599 Mdot
.41172 .32094 Mdot
.68277 .61667 Mdot
.69754 .42084 Mdot
.63476 .32896 Mdot
.59584 .69993 Mdot
.33334 .59339 Mdot
.50362 .71948 Mdot
.35097 .36137 Mdot
.49538 .74069 Mdot
.57126 .31138 Mdot
.43213 .29182 Mdot
.66205 .37155 Mdot
.6617 .60583 Mdot
.72063 .41295 Mdot
.3301 .57027 Mdot
.57419 .69485 Mdot
.37173 .65782 Mdot
.62685 .337 Mdot
.56342 .68064 Mdot
.33632 .60689 Mdot
.59544 .69492 Mdot
.57954 .3172 Mdot
.50969 .26258 Mdot
.62308 .65824 Mdot
.47743 .28455 Mdot
.35135 .60312 Mdot
.30182 .46039 Mdot
.26014 .4664 Mdot
.37123 .68013 Mdot
.48527 .2813 Mdot
.51044 .72989 Mdot
.34716 .60833 Mdot
.45395 .72835 Mdot
.58367 .31639 Mdot
.37486 .37744 Mdot
.53341 .29185 Mdot
.64113 .61867 Mdot
.36331 .34687 Mdot
.55469 .30727 Mdot
.52181 .72828 Mdot
.3464 .37643 Mdot
.46905 .27938 Mdot
.28432 .45421 Mdot
.33106 .60647 Mdot
.31961 .53916 Mdot
.58172 .29613 Mdot
.69637 .42733 Mdot
.65082 .63074 Mdot
.71145 .41344 Mdot
.50024 .26689 Mdot
.36333 .65768 Mdot
.35365 .38307 Mdot
.61575 .31953 Mdot
.59797 .71497 Mdot
.29522 .46558 Mdot
.62798 .34964 Mdot
.60023 .68806 Mdot
.36918 .67147 Mdot
.28776 .52419 Mdot
.35295 .58032 Mdot
.43504 .28981 Mdot
.64116 .33118 Mdot
.25805 .48982 Mdot
.33788 .58323 Mdot
.52507 .272 Mdot
.25758 .47647 Mdot
.34593 .60229 Mdot
.45233 .29925 Mdot
.39008 .6856 Mdot
.26885 .47828 Mdot
.66437 .62308 Mdot
.44921 .72188 Mdot
.32005 .42672 Mdot
.31529 .45408 Mdot
.35919 .67345 Mdot
.37488 .65266 Mdot
.4539 .28066 Mdot
.72906 .52503 Mdot
.38373 .68897 Mdot
.30451 .43081 Mdot
.68222 .61016 Mdot
.65523 .61645 Mdot
.57361 .67644 Mdot
.67527 .42955 Mdot
.56099 .2876 Mdot
.28241 .47669 Mdot
.42281 .29996 Mdot
.38568 .66344 Mdot
.56816 .68523 Mdot
.29252 .44446 Mdot
.68491 .41323 Mdot
.59357 .68634 Mdot
.68193 .4486 Mdot
.39685 .72647 Mdot
.62067 .34155 Mdot
.35838 .60896 Mdot
.35404 .64216 Mdot
.66726 .61657 Mdot
.67742 .37326 Mdot
.61979 .3254 Mdot
.52121 .28863 Mdot
.36377 .35921 Mdot
.69385 .58463 Mdot
.28271 .45965 Mdot
.54344 .7014 Mdot
.35255 .5851 Mdot
.34926 .56144 Mdot
.6644 .61671 Mdot
.36913 .66028 Mdot
.67914 .60529 Mdot
.42543 .29994 Mdot
.29537 .52932 Mdot
.71138 .53306 Mdot
.72736 .52912 Mdot
.60847 .70848 Mdot
.47404 .27503 Mdot
.68895 .62853 Mdot
.38829 .66395 Mdot
.50755 .26366 Mdot
.25948 .4978 Mdot
.27866 .46839 Mdot
.25725 .48762 Mdot
.69043 .62802 Mdot
.5293 .72368 Mdot
.58496 .6815 Mdot
.38573 .69898 Mdot
.44983 .72981 Mdot
.64258 .34344 Mdot
.39723 .713 Mdot
.34639 .36661 Mdot
.53541 .28998 Mdot
.34194 .62964 Mdot
.34154 .61533 Mdot
.70703 .53594 Mdot
.3056 .47277 Mdot
.71552 .40567 Mdot
.35393 .35187 Mdot
.58211 .29511 Mdot
.30631 .44952 Mdot
.69975 .51771 Mdot
.35193 .64965 Mdot
.32815 .36363 Mdot
.36551 .38234 Mdot
.35297 .60109 Mdot
.38303 .68498 Mdot
.32062 .37973 Mdot
.70777 .41887 Mdot
.51971 .28665 Mdot
.34958 .35103 Mdot
.49961 .72886 Mdot
.45502 .7281 Mdot
.33406 .57486 Mdot
.68949 .53205 Mdot
.68873 .40506 Mdot
.36093 .37841 Mdot
.47035 .28921 Mdot
.38399 .65682 Mdot
.49 .7135 Mdot
.31794 .40024 Mdot
.35067 .36575 Mdot
.54784 .69663 Mdot
.26864 .45954 Mdot
.57371 .69766 Mdot
.39944 .72776 Mdot
.47222 .73442 Mdot
.35628 .58018 Mdot
.5069 .27036 Mdot
.68476 .43549 Mdot
.35583 .34297 Mdot
.54341 .29684 Mdot
.65519 .61691 Mdot
.38464 .69795 Mdot
.7275 .51225 Mdot
.73358 .53297 Mdot
.66117 .65114 Mdot
.70897 .43475 Mdot
.69774 .58971 Mdot
.32177 .37901 Mdot
.34661 .57415 Mdot
.64521 .33896 Mdot
.68713 .63408 Mdot
.46262 .72565 Mdot
.69012 .61569 Mdot
.71194 .50576 Mdot
.46016 .72786 Mdot
.58826 .69242 Mdot
.40516 .72136 Mdot
.35382 .62728 Mdot
.27493 .45231 Mdot
.6975 .56065 Mdot
.48457 .71378 Mdot
.36528 .69116 Mdot
.34172 .58148 Mdot
.59503 .70284 Mdot
.25689 .48192 Mdot
.37073 .65178 Mdot
.34999 .58065 Mdot
.41625 .72793 Mdot
.46507 .72675 Mdot
.73506 .51087 Mdot
.6426 .36265 Mdot
.57582 .67479 Mdot
.49263 .28055 Mdot
.67214 .62672 Mdot
.31685 .43709 Mdot
.69268 .60879 Mdot
.59967 .68121 Mdot
.69637 .43477 Mdot
.72615 .54172 Mdot
.55393 .28023 Mdot
.69295 .42744 Mdot
.63413 .33105 Mdot
.59188 .70482 Mdot
.51111 .27957 Mdot
.29261 .4868 Mdot
.63006 .34514 Mdot
.56178 .68416 Mdot
.69786 .42184 Mdot
.62607 .6439 Mdot
.50003 .74125 Mdot
.40099 .72544 Mdot
.361 .36621 Mdot
.3452 .34559 Mdot
.64098 .34574 Mdot
.29636 .45689 Mdot
.59593 .68772 Mdot
.65587 .6312 Mdot
.2951 .46291 Mdot
.63621 .64508 Mdot
.44273 .30091 Mdot
.6681 .6395 Mdot
.43432 .29671 Mdot
.70703 .54865 Mdot
.36799 .68877 Mdot
.31508 .45916 Mdot
.31906 .38332 Mdot
.49196 .71682 Mdot
.36857 .35876 Mdot
.34979 .62817 Mdot
.59996 .69469 Mdot
.33005 .59204 Mdot
.47306 .27034 Mdot
.31408 .43034 Mdot
.66413 .61356 Mdot
.40347 .34063 Mdot
.69768 .406 Mdot
.49827 .7341 Mdot
.36975 .35059 Mdot
.57602 .69683 Mdot
.68152 .60734 Mdot
.70096 .53854 Mdot
.63883 .62273 Mdot
.48594 .2783 Mdot
.40611 .32873 Mdot
.32989 .57603 Mdot
.40215 .34207 Mdot
.63706 .33854 Mdot
.63193 .32361 Mdot
.53845 .27535 Mdot
.307 .53268 Mdot
.54696 .29907 Mdot
.26203 .50089 Mdot
.70366 .54734 Mdot
.28795 .48319 Mdot
.32977 .5852 Mdot
.65833 .6377 Mdot
.54749 .69894 Mdot
.30555 .47498 Mdot
.26825 .45742 Mdot
.63058 .32499 Mdot
.64683 .33711 Mdot
.38078 .35559 Mdot
.46635 .72693 Mdot
.46242 .72256 Mdot
.34998 .56764 Mdot
.64342 .34896 Mdot
.58155 .69641 Mdot
.63634 .35859 Mdot
.56908 .69652 Mdot
.31433 .42946 Mdot
.54471 .30671 Mdot
.60194 .31405 Mdot
.66872 .63108 Mdot
.3854 .69955 Mdot
.65668 .65419 Mdot
.40794 .73043 Mdot
.61819 .31763 Mdot
.30281 .48084 Mdot
.54804 .28659 Mdot
.66957 .37247 Mdot
.54075 .30441 Mdot
.31525 .41622 Mdot
.53568 .7227 Mdot
.68954 .44793 Mdot
.50232 .73784 Mdot
.52606 .26079 Mdot
.35125 .63021 Mdot
.33565 .36072 Mdot
.39484 .35731 Mdot
.60566 .708 Mdot
.63873 .63822 Mdot
.27624 .44947 Mdot
.32944 .58422 Mdot
.63152 .63094 Mdot
.33027 .58296 Mdot
.33029 .58103 Mdot
.34508 .62211 Mdot
.62985 .33842 Mdot
.50749 .73755 Mdot
.33254 .59369 Mdot
.45526 .28434 Mdot
.25558 .49296 Mdot
.59249 .31338 Mdot
.66889 .6165 Mdot
.28928 .46821 Mdot
.67438 .62781 Mdot
.50106 .72239 Mdot
.7096 .44288 Mdot
.64429 .65015 Mdot
.58526 .70079 Mdot
.69262 .62297 Mdot
.61645 .32769 Mdot
.2814 .45034 Mdot
.3437 .37014 Mdot
.711 .39599 Mdot
.44858 .28816 Mdot
.36021 .35504 Mdot
.44966 .29873 Mdot
.3583 .60027 Mdot
.71023 .52654 Mdot
.36509 .35798 Mdot
.68453 .40596 Mdot
.52267 .25928 Mdot
.39743 .73219 Mdot
.38329 .67051 Mdot
.57711 .31304 Mdot
.35548 .3691 Mdot
.49662 .72873 Mdot
.51694 .73402 Mdot
.52803 .26053 Mdot
.71509 .40209 Mdot
.63557 .33951 Mdot
.2854 .46577 Mdot
.72443 .50597 Mdot
.70414 .53818 Mdot
.69153 .4086 Mdot
.66153 .3429 Mdot
.37941 .67005 Mdot
.38747 .67776 Mdot
.48759 .72205 Mdot
.35344 .63311 Mdot
.46783 .29074 Mdot
.35295 .35683 Mdot
.72118 .53891 Mdot
.6003 .69795 Mdot
.57094 .70934 Mdot
.32694 .57973 Mdot
.36243 .65343 Mdot
.57066 .29284 Mdot
.57278 .69208 Mdot
.27035 .47918 Mdot
.69382 .58783 Mdot
.38964 .68712 Mdot
.31583 .42912 Mdot
.70529 .54241 Mdot
.46652 .27985 Mdot
.6977 .427 Mdot
.54593 .26411 Mdot
.55154 .26637 Mdot
.31562 .40747 Mdot
.67013 .62725 Mdot
.35973 .35525 Mdot
.45965 .29917 Mdot
.39216 .35863 Mdot
.26545 .4641 Mdot
.37151 .68585 Mdot
.44011 .29148 Mdot
.59552 .31744 Mdot
.68288 .44418 Mdot
.39151 .72269 Mdot
.32746 .5523 Mdot
.62161 .32439 Mdot
.3489 .59414 Mdot
.29412 .44531 Mdot
.65145 .34735 Mdot
.72783 .53954 Mdot
.27604 .45326 Mdot
.64109 .35606 Mdot
.70227 .53541 Mdot
.59173 .703 Mdot
.46321 .72498 Mdot
.65193 .62619 Mdot
.69738 .52546 Mdot
.37826 .66886 Mdot
.48059 .28672 Mdot
.71438 .53674 Mdot
.64636 .62521 Mdot
.63827 .61991 Mdot
.54407 .26791 Mdot
.25904 .4741 Mdot
.68729 .44463 Mdot
.33548 .60067 Mdot
.54267 .30785 Mdot
.29363 .47349 Mdot
.72143 .54548 Mdot
.3223 .5869 Mdot
.38634 .66496 Mdot
.29724 .46367 Mdot
.26689 .45561 Mdot
.29527 .45977 Mdot
.6315 .32858 Mdot
.58832 .70103 Mdot
.67219 .60699 Mdot
.61796 .32613 Mdot
.31013 .43549 Mdot
.31683 .42337 Mdot
.40997 .32498 Mdot
.38189 .67332 Mdot
.27916 .44253 Mdot
.69637 .58575 Mdot
.52424 .73404 Mdot
.3925 .35827 Mdot
.26509 .50876 Mdot
.46646 .27281 Mdot
.26192 .50377 Mdot
.68761 .43718 Mdot
.57115 .70343 Mdot
.27698 .46714 Mdot
.34067 .3805 Mdot
.3817 .66997 Mdot
.37595 .65734 Mdot
.30253 .45785 Mdot
.36705 .64684 Mdot
.70473 .52855 Mdot
.64547 .65893 Mdot
.29138 .46791 Mdot
.52079 .26617 Mdot
.58491 .313 Mdot
.55882 .29956 Mdot
.33986 .57662 Mdot
.47387 .71141 Mdot
.44937 .73407 Mdot
.63954 .61974 Mdot
.64085 .33378 Mdot
.70428 .5446 Mdot
.69295 .57879 Mdot
.65865 .61399 Mdot
.51843 .25959 Mdot
.29615 .45669 Mdot
.69023 .52921 Mdot
.63454 .32797 Mdot
.63988 .34642 Mdot
.58735 .30371 Mdot
.54138 .2984 Mdot
.56497 .29549 Mdot
.65087 .63874 Mdot
.74841 .51949 Mdot
.4816 .73879 Mdot
.73282 .53413 Mdot
.48817 .26796 Mdot
.42604 .30028 Mdot
.58579 .30224 Mdot
.69794 .41416 Mdot
.69084 .54156 Mdot
.38786 .68211 Mdot
.31986 .54127 Mdot
.58518 .31431 Mdot
.29935 .43736 Mdot
.69807 .58161 Mdot
.29397 .52751 Mdot
.56549 .69502 Mdot
.6807 .4184 Mdot
.34863 .38051 Mdot
.32426 .57647 Mdot
.52319 .28792 Mdot
.26639 .50785 Mdot
.3645 .38077 Mdot
.4899 .7351 Mdot
.69821 .6033 Mdot
.68834 .43085 Mdot
.51364 .73903 Mdot
.33179 .36943 Mdot
.60128 .70484 Mdot
.65023 .34709 Mdot
.56172 .28035 Mdot
.41543 .31185 Mdot
.65646 .64581 Mdot
.38115 .69893 Mdot
.34438 .38491 Mdot
.36495 .69311 Mdot
.5591 .30707 Mdot
.27481 .45584 Mdot
.56891 .30745 Mdot
.73443 .50936 Mdot
.55965 .2756 Mdot
.32289 .57799 Mdot
.67825 .60809 Mdot
.63811 .34165 Mdot
.44428 .73166 Mdot
.40512 .3382 Mdot
.53712 .27045 Mdot
.31902 .38137 Mdot
.57876 .71083 Mdot
.57284 .67535 Mdot
.35874 .34232 Mdot
.32226 .57607 Mdot
.69728 .41021 Mdot
.67255 .60536 Mdot
.69549 .40517 Mdot
.25769 .4737 Mdot
.70846 .39349 Mdot
.69821 .42785 Mdot
.50249 .70859 Mdot
.27986 .44985 Mdot
.36341 .65496 Mdot
.33818 .61156 Mdot
.67854 .41686 Mdot
.5048 .73374 Mdot
.63153 .63032 Mdot
.52097 .72819 Mdot
.40177 .71833 Mdot
.69462 .40899 Mdot
.38173 .3649 Mdot
.51451 .73624 Mdot
.25672 .47633 Mdot
.63809 .35009 Mdot
.44855 .72281 Mdot
.35083 .35636 Mdot
.30828 .44581 Mdot
.28753 .44 Mdot
.30246 .44887 Mdot
.32571 .58999 Mdot
.35567 .65008 Mdot
.31654 .45153 Mdot
.71863 .40598 Mdot
.31532 .44728 Mdot
.2928 .49354 Mdot
.66747 .3753 Mdot
.26897 .4539 Mdot
.34813 .60826 Mdot
.56907 .69805 Mdot
.57246 .70458 Mdot
.52815 .2781 Mdot
.6914 .38413 Mdot
.44478 .28549 Mdot
.34434 .55561 Mdot
.74517 .50165 Mdot
.66051 .61853 Mdot
.32216 .36205 Mdot
.40289 .71202 Mdot
.59813 .6825 Mdot
.65126 .61909 Mdot
.48705 .72496 Mdot
.67108 .63792 Mdot
.33122 .3652 Mdot
.32365 .57144 Mdot
.66837 .62121 Mdot
.67623 .6458 Mdot
.36567 .64508 Mdot
.6736 .63746 Mdot
.70777 .55118 Mdot
.63826 .33212 Mdot
.69221 .43955 Mdot
.69649 .40971 Mdot
.53233 .29644 Mdot
.72775 .5322 Mdot
.38679 .69627 Mdot
.52426 .2903 Mdot
.35415 .59825 Mdot
.69344 .40874 Mdot
.36188 .6858 Mdot
.72789 .52936 Mdot
.34491 .61104 Mdot
.50861 .70979 Mdot
.44881 .30065 Mdot
.29855 .46217 Mdot
.63631 .63554 Mdot
.41763 .30712 Mdot
.63131 .34544 Mdot
.73908 .53536 Mdot
.29917 .48654 Mdot
.60004 .70964 Mdot
.33119 .54567 Mdot
.3405 .62282 Mdot
.59994 .70932 Mdot
.53336 .72353 Mdot
.37128 .37667 Mdot
.52012 .29035 Mdot
.55181 .26843 Mdot
.3779 .67513 Mdot
.72461 .5306 Mdot
.26507 .47905 Mdot
.3194 .42771 Mdot
.33794 .3461 Mdot
.51379 .72796 Mdot
.40455 .71578 Mdot
.37824 .71686 Mdot
.38456 .6997 Mdot
.53788 .27852 Mdot
.37731 .37495 Mdot
.48309 .72829 Mdot
.30278 .44247 Mdot
.38931 .69759 Mdot
.67025 .61781 Mdot
.71355 .55204 Mdot
.57096 .2958 Mdot
.6524 .3663 Mdot
.34976 .34784 Mdot
.58917 .31154 Mdot
.37866 .67617 Mdot
.58382 .71479 Mdot
.65625 .35167 Mdot
.71169 .50227 Mdot
.30933 .4533 Mdot
.52745 .28914 Mdot
.29981 .47569 Mdot
.72947 .522 Mdot
.72093 .54564 Mdot
.37076 .66591 Mdot
.40163 .33169 Mdot
.55687 .27657 Mdot
.33307 .57588 Mdot
.57577 .31319 Mdot
.43662 .29747 Mdot
.63647 .35776 Mdot
.38324 .68926 Mdot
.54903 .6939 Mdot
.70614 .41003 Mdot
.33163 .56346 Mdot
.58126 .70822 Mdot
.59063 .68568 Mdot
.51977 .26446 Mdot
.31964 .44171 Mdot
.31171 .44626 Mdot
.74254 .52955 Mdot
.71367 .47346 Mdot
.3889 .72477 Mdot
.54105 .2681 Mdot
.5589 .68751 Mdot
.70117 .43061 Mdot
.70051 .54781 Mdot
.7014 .46592 Mdot
.69998 .418 Mdot
.38368 .67651 Mdot
.29417 .44708 Mdot
.70012 .52211 Mdot
.39263 .35911 Mdot
.4301 .73598 Mdot
.31791 .3861 Mdot
.40762 .3288 Mdot
.34824 .35458 Mdot
.70048 .45237 Mdot
.57093 .30103 Mdot
.68887 .61497 Mdot
.68323 .40934 Mdot
.69965 .43319 Mdot
.43076 .28928 Mdot
.64006 .63349 Mdot
.6247 .65205 Mdot
.69799 .59176 Mdot
.44754 .28865 Mdot
.29404 .45448 Mdot
.52064 .72418 Mdot
.55688 .29889 Mdot
.4157 .31519 Mdot
.64188 .32727 Mdot
.63053 .32357 Mdot
.726 .49597 Mdot
.39432 .68163 Mdot
.63833 .62032 Mdot
.35521 .60802 Mdot
.37228 .68799 Mdot
.68546 .41512 Mdot
.70183 .54813 Mdot
.66323 .36169 Mdot
.37648 .67858 Mdot
.38647 .71138 Mdot
.50734 .26162 Mdot
.34736 .36261 Mdot
.60127 .31678 Mdot
.37933 .68957 Mdot
.54408 .30196 Mdot
.63301 .65272 Mdot
.33451 .38132 Mdot
.49193 .71245 Mdot
.65419 .34306 Mdot
.35657 .38156 Mdot
.33 .37531 Mdot
.32538 .54236 Mdot
.6716 .63578 Mdot
.73747 .52721 Mdot
.26043 .4702 Mdot
.66046 .36746 Mdot
.64552 .35919 Mdot
.68405 .44986 Mdot
.38317 .67748 Mdot
.65432 .34009 Mdot
.39811 .35076 Mdot
.33358 .56222 Mdot
.59835 .70231 Mdot
.64568 .64712 Mdot
.37399 .71031 Mdot
.58576 .67845 Mdot
.69463 .41879 Mdot
.31443 .39865 Mdot
.38937 .72431 Mdot
.57713 .30497 Mdot
.70377 .50368 Mdot
.65949 .64208 Mdot
.27151 .46894 Mdot
.6233 .33205 Mdot
.30178 .5298 Mdot
.69909 .54747 Mdot
.39224 .68729 Mdot
.70294 .42739 Mdot
.34724 .38225 Mdot
.36487 .36363 Mdot
.31631 .37578 Mdot
.69809 .55502 Mdot
.34274 .38124 Mdot
.66503 .65075 Mdot
.49153 .7236 Mdot
.37181 .68451 Mdot
.71042 .43 Mdot
.29336 .45331 Mdot
.40157 .34505 Mdot
.43599 .3019 Mdot
.469 .72639 Mdot
.36801 .67287 Mdot
.70775 .39111 Mdot
.29016 .45218 Mdot
.32691 .58648 Mdot
.3702 .37818 Mdot
.49129 .70821 Mdot
.27786 .51786 Mdot
.36342 .35265 Mdot
.5647 .7054 Mdot
.70894 .51134 Mdot
.36889 .35733 Mdot
.71607 .55193 Mdot
.3262 .58151 Mdot
.49544 .7336 Mdot
.73699 .51912 Mdot
.69412 .56979 Mdot
.3313 .35962 Mdot
.63701 .35501 Mdot
.50615 .73141 Mdot
.34953 .61098 Mdot
.48063 .71083 Mdot
.35854 .37583 Mdot
.71327 .39901 Mdot
.55698 .3124 Mdot
.47289 .28276 Mdot
.46243 .29805 Mdot
.62099 .31879 Mdot
.65727 .37135 Mdot
.38039 .65182 Mdot
.54056 .71001 Mdot
.47568 .7114 Mdot
.71748 .4266 Mdot
.52905 .73032 Mdot
.33334 .59355 Mdot
.35189 .59201 Mdot
.57591 .31347 Mdot
.69391 .44731 Mdot
.57337 .67649 Mdot
.48717 .72975 Mdot
.31225 .4332 Mdot
.73066 .53806 Mdot
.34106 .6023 Mdot
.71121 .39347 Mdot
.52348 .26345 Mdot
.69734 .38492 Mdot
.34854 .60552 Mdot
.34677 .36305 Mdot
.66011 .35937 Mdot
.63541 .33687 Mdot
.51478 .27113 Mdot
.51734 .27128 Mdot
.35013 .60917 Mdot
.7151 .4092 Mdot
.5287 .72879 Mdot
.51544 .73233 Mdot
.35311 .37229 Mdot
.2757 .47771 Mdot
.34872 .62782 Mdot
.62388 .65779 Mdot
.40533 .33397 Mdot
.33551 .57522 Mdot
.73059 .51688 Mdot
.5595 .29091 Mdot
.44116 .30234 Mdot
.71034 .54098 Mdot
.44713 .29747 Mdot
.69719 .38648 Mdot
.36014 .6826 Mdot
.26485 .47255 Mdot
.61109 .70698 Mdot
.31344 .46018 Mdot
.35883 .37929 Mdot
.38387 .6753 Mdot
.4813 .28373 Mdot
.45357 .3037 Mdot
.61808 .68783 Mdot
.68771 .4253 Mdot
.38828 .36114 Mdot
.58404 .69738 Mdot
.31571 .43135 Mdot
.53886 .29114 Mdot
.38551 .34876 Mdot
.3862 .69181 Mdot
.67124 .62986 Mdot
.57265 .67879 Mdot
.37419 .3493 Mdot
.36499 .37352 Mdot
.36355 .34611 Mdot
.64065 .35592 Mdot
.64398 .62015 Mdot
.63725 .32528 Mdot
.43766 .30614 Mdot
.48662 .74027 Mdot
.3893 .70933 Mdot
.7061 .54571 Mdot
.3398 .56474 Mdot
.71384 .4128 Mdot
.69628 .57862 Mdot
.29299 .4595 Mdot
.32805 .36992 Mdot
.67006 .36496 Mdot
.39325 .35999 Mdot
.59507 .71338 Mdot
.5684 .7119 Mdot
.67023 .61536 Mdot
.67825 .44079 Mdot
.34051 .63159 Mdot
.57738 .28583 Mdot
.31045 .45195 Mdot
.63537 .32913 Mdot
.59521 .7114 Mdot
.33815 .61279 Mdot
.29212 .45242 Mdot
.62844 .32468 Mdot
.34599 .34309 Mdot
.71518 .40689 Mdot
.31687 .38678 Mdot
.62071 .67395 Mdot
.34703 .60074 Mdot
.34543 .36162 Mdot
.65466 .6216 Mdot
.64095 .33605 Mdot
.64613 .64266 Mdot
.33092 .36631 Mdot
.43388 .30056 Mdot
.63777 .33001 Mdot
.38954 .70361 Mdot
.69175 .6077 Mdot
.74838 .51688 Mdot
.6485 .61526 Mdot
.41206 .32207 Mdot
.43514 .29171 Mdot
.56758 .29574 Mdot
.69965 .4148 Mdot
.53206 .30403 Mdot
.28115 .44809 Mdot
.51917 .7224 Mdot
.52367 .27119 Mdot
.64318 .62383 Mdot
.5235 .29674 Mdot
.51124 .71418 Mdot
.62369 .34331 Mdot
.58863 .3142 Mdot
.34613 .57058 Mdot
.5847 .70636 Mdot
.36955 .369 Mdot
.25801 .48547 Mdot
.49323 .72499 Mdot
.39663 .70818 Mdot
.33961 .37013 Mdot
.34666 .60789 Mdot
.71309 .41082 Mdot
.43742 .72259 Mdot
.46628 .73132 Mdot
.44095 .29834 Mdot
.6956 .56812 Mdot
.54765 .26641 Mdot
.31753 .42195 Mdot
.33552 .56871 Mdot
.34442 .60894 Mdot
.58375 .68902 Mdot
.69745 .57998 Mdot
.63059 .3373 Mdot
.47888 .73886 Mdot
.45085 .29037 Mdot
.67873 .61061 Mdot
.67581 .61267 Mdot
.38136 .70464 Mdot
.34765 .35895 Mdot
.67925 .43081 Mdot
.32388 .58354 Mdot
.39179 .35672 Mdot
.40136 .71399 Mdot
.62735 .31892 Mdot
.43647 .28993 Mdot
.43926 .3091 Mdot
.6853 .61949 Mdot
.58246 .3134 Mdot
.58183 .68966 Mdot
.3465 .38045 Mdot
.46303 .29806 Mdot
.62921 .33857 Mdot
.31101 .45394 Mdot
.34969 .58346 Mdot
.3652 .65002 Mdot
.58261 .31462 Mdot
.51307 .28256 Mdot
.52853 .7275 Mdot
.70544 .38898 Mdot
.40019 .32749 Mdot
.64625 .34403 Mdot
.6719 .61714 Mdot
.3455 .64491 Mdot
.3165 .53914 Mdot
.70389 .43534 Mdot
.59359 .71151 Mdot
.58268 .30795 Mdot
.31559 .40167 Mdot
.65487 .61557 Mdot
.31036 .45479 Mdot
.34308 .56292 Mdot
.66782 .61271 Mdot
.46316 .28872 Mdot
.66535 .60438 Mdot
.35862 .35904 Mdot
.6193 .336 Mdot
.53613 .28559 Mdot
.69134 .44711 Mdot
.54989 .69376 Mdot
.2939 .45639 Mdot
.37423 .70036 Mdot
.56895 .69192 Mdot
.64241 .64888 Mdot
.5904 .69771 Mdot
.36557 .34344 Mdot
.59027 .70273 Mdot
.67686 .6166 Mdot
.34008 .61242 Mdot
.35849 .58591 Mdot
.42474 .30564 Mdot
.35245 .60187 Mdot
.38325 .65802 Mdot
.50924 .70976 Mdot
.33996 .57368 Mdot
.33008 .58009 Mdot
.38123 .68599 Mdot
.72194 .50976 Mdot
.3992 .71799 Mdot
.71782 .49698 Mdot
.73417 .50348 Mdot
.44104 .30484 Mdot
.31528 .43034 Mdot
.26318 .46305 Mdot
.39745 .72311 Mdot
.36382 .65082 Mdot
.64012 .63797 Mdot
.68945 .53588 Mdot
.63828 .34045 Mdot
.47481 .73427 Mdot
.41105 .32653 Mdot
.35783 .64854 Mdot
.52844 .27705 Mdot
.52428 .26507 Mdot
.35653 .60783 Mdot
.29186 .52678 Mdot
.37426 .65102 Mdot
.5003 .71604 Mdot
.33071 .60056 Mdot
.3744 .68144 Mdot
.55024 .26912 Mdot
.36784 .68721 Mdot
.58642 .68104 Mdot
.68201 .62022 Mdot
.30686 .46405 Mdot
.36239 .35642 Mdot
.4955 .73352 Mdot
.3535 .66018 Mdot
.65933 .64563 Mdot
.58661 .68778 Mdot
.52751 .28461 Mdot
.72122 .54289 Mdot
.49376 .7168 Mdot
.63121 .34771 Mdot
.42704 .73669 Mdot
.71146 .39532 Mdot
.64348 .35268 Mdot
.30893 .447 Mdot
.55638 .27975 Mdot
.32946 .5549 Mdot
.51928 .29287 Mdot
.37984 .68166 Mdot
.51879 .73523 Mdot
.2664 .4735 Mdot
.65104 .63495 Mdot
.65367 .3429 Mdot
.71147 .51382 Mdot
.62549 .64729 Mdot
.44164 .72115 Mdot
.59923 .31628 Mdot
.56253 .27824 Mdot
.39395 .33934 Mdot
.66081 .65035 Mdot
.38252 .65622 Mdot
.69515 .59346 Mdot
.71209 .52431 Mdot
.66618 .63635 Mdot
.42851 .72559 Mdot
.41715 .73412 Mdot
.3846 .6867 Mdot
.65744 .62043 Mdot
.56154 .28253 Mdot
.26362 .46942 Mdot
.37582 .6655 Mdot
.34807 .38023 Mdot
.68567 .61952 Mdot
.57841 .30321 Mdot
.37007 .69464 Mdot
.54211 .30026 Mdot
.66526 .60984 Mdot
.5346 .26228 Mdot
.63638 .35819 Mdot
.52573 .27113 Mdot
.34409 .62812 Mdot
.33475 .60741 Mdot
.67746 .61491 Mdot
.72135 .54517 Mdot
.59688 .71122 Mdot
.34369 .57152 Mdot
.68945 .62595 Mdot
.49047 .27761 Mdot
.69306 .51804 Mdot
.5963 .6875 Mdot
.38247 .66058 Mdot
.31581 .45186 Mdot
.48117 .7406 Mdot
.43559 .72551 Mdot
.46473 .73111 Mdot
.29737 .45375 Mdot
.54044 .70849 Mdot
.36463 .68754 Mdot
.37001 .64567 Mdot
.45461 .289 Mdot
.35015 .57209 Mdot
.33422 .38313 Mdot
.60249 .68962 Mdot
.42042 .73907 Mdot
.59775 .70718 Mdot
.64808 .62126 Mdot
.67064 .60855 Mdot
.49529 .27366 Mdot
.65703 .61606 Mdot
.34198 .38323 Mdot
.67925 .42981 Mdot
.62611 .64581 Mdot
.37874 .37354 Mdot
.35883 .38251 Mdot
.32173 .37885 Mdot
.36195 .35123 Mdot
.40147 .32786 Mdot
.42637 .29376 Mdot
.36464 .37769 Mdot
.67224 .64475 Mdot
.4781 .2782 Mdot
.29803 .48656 Mdot
.67878 .42988 Mdot
.3311 .37801 Mdot
.35023 .57147 Mdot
.59358 .68911 Mdot
.73655 .54026 Mdot
.61846 .31831 Mdot
.35811 .34487 Mdot
.38039 .6576 Mdot
.68549 .627 Mdot
.33972 .60043 Mdot
.31865 .43656 Mdot
.72807 .52811 Mdot
.53104 .29249 Mdot
.26851 .4743 Mdot
.34234 .35549 Mdot
.29251 .46563 Mdot
.56869 .31019 Mdot
.72099 .41077 Mdot
.34697 .56477 Mdot
.39986 .34805 Mdot
.30054 .43337 Mdot
.34863 .56815 Mdot
.6735 .64308 Mdot
.35064 .34679 Mdot
.39175 .67382 Mdot
.58284 .69441 Mdot
.70237 .53055 Mdot
.67507 .366 Mdot
.33174 .55573 Mdot
.57103 .71282 Mdot
.68377 .62056 Mdot
.38946 .35351 Mdot
.52877 .29344 Mdot
.32445 .59473 Mdot
.68319 .42041 Mdot
.69365 .40754 Mdot
.4607 .2878 Mdot
.73129 .54287 Mdot
.53647 .30788 Mdot
.34318 .63088 Mdot
.33079 .37462 Mdot
.32523 .59552 Mdot
.49078 .26738 Mdot
.68519 .38226 Mdot
.69747 .53003 Mdot
.44005 .30668 Mdot
.40801 .73483 Mdot
.67636 .43181 Mdot
.44297 .29825 Mdot
.68129 .61851 Mdot
.73261 .52599 Mdot
.71279 .54142 Mdot
.2734 .48006 Mdot
.54316 .298 Mdot
.73696 .51479 Mdot
.71459 .50607 Mdot
.59224 .68648 Mdot
.35688 .60554 Mdot
.66853 .61966 Mdot
.44718 .28753 Mdot
.31225 .45406 Mdot
.45386 .29207 Mdot
.40611 .33488 Mdot
.64497 .33741 Mdot
.51322 .71304 Mdot
.46736 .72507 Mdot
.30572 .53436 Mdot
.38876 .70327 Mdot
.32527 .58742 Mdot
.64217 .63262 Mdot
.25485 .48342 Mdot
.28059 .487 Mdot
.6752 .64223 Mdot
.69926 .52188 Mdot
.27926 .47495 Mdot
.3566 .64955 Mdot
.36703 .63869 Mdot
.40848 .73564 Mdot
.64766 .61307 Mdot
.6574 .6554 Mdot
.68835 .41886 Mdot
.68521 .6175 Mdot
.46489 .27639 Mdot
.58319 .29997 Mdot
.53913 .27032 Mdot
.6366 .33384 Mdot
.33447 .5549 Mdot
.56119 .27599 Mdot
.57232 .69757 Mdot
.45939 .2773 Mdot
.58127 .71042 Mdot
.472 .29396 Mdot
.34185 .56895 Mdot
.65672 .33559 Mdot
.69631 .45217 Mdot
.60135 .69376 Mdot
.35636 .65932 Mdot
.30621 .45483 Mdot
.64165 .63226 Mdot
.71508 .41915 Mdot
.63837 .62442 Mdot
.34652 .60448 Mdot
.66232 .62891 Mdot
.65314 .34492 Mdot
.71513 .39964 Mdot
.59442 .68135 Mdot
.57523 .69797 Mdot
.63591 .62336 Mdot
.68884 .63333 Mdot
.53051 .29498 Mdot
.66772 .63731 Mdot
.7307 .50658 Mdot
.58658 .70735 Mdot
.58521 .31115 Mdot
.45104 .72679 Mdot
.64753 .63214 Mdot
.26178 .47768 Mdot
.72889 .52399 Mdot
.28161 .47576 Mdot
.73896 .52331 Mdot
.4218 .30573 Mdot
.32817 .57189 Mdot
.44334 .30343 Mdot
.29747 .43873 Mdot
.56927 .27783 Mdot
.7189 .42045 Mdot
.33679 .3755 Mdot
.70432 .40902 Mdot
.51036 .7195 Mdot
.63891 .62207 Mdot
.68707 .43741 Mdot
.44927 .72768 Mdot
.33221 .60708 Mdot
.73914 .52489 Mdot
.5302 .28719 Mdot
.46059 .29319 Mdot
.50103 .7235 Mdot
.69856 .5503 Mdot
.49739 .27818 Mdot
.559 .68921 Mdot
.47106 .28069 Mdot
.60305 .69454 Mdot
.6967 .4625 Mdot
.66612 .60637 Mdot
.463 .29255 Mdot
.50632 .71639 Mdot
.71988 .50197 Mdot
.5737 .28873 Mdot
.71392 .40579 Mdot
.68374 .42205 Mdot
.33621 .61764 Mdot
.68204 .4432 Mdot
.52695 .2789 Mdot
.7002 .38612 Mdot
.73515 .51326 Mdot
.68643 .38156 Mdot
.29706 .45699 Mdot
.56147 .28555 Mdot
.35367 .37324 Mdot
.55058 .69534 Mdot
.53794 .30497 Mdot
.29804 .53011 Mdot
.41304 .31865 Mdot
.48058 .27453 Mdot
.72934 .53032 Mdot
.69876 .55412 Mdot
.56536 .69029 Mdot
.49753 .72497 Mdot
.53912 .28986 Mdot
.47115 .27668 Mdot
.40535 .71891 Mdot
.33521 .3714 Mdot
.46674 .28671 Mdot
.3878 .69841 Mdot
.58742 .69638 Mdot
.64288 .34277 Mdot
.38785 .71136 Mdot
.70813 .50185 Mdot
.37177 .67925 Mdot
.71217 .41383 Mdot
.51809 .25899 Mdot
.34661 .60622 Mdot
.30979 .4496 Mdot
.68908 .40467 Mdot
.69165 .40512 Mdot
.59739 .31418 Mdot
.7307 .54375 Mdot
.64062 .64414 Mdot
.53994 .29811 Mdot
.58374 .70422 Mdot
.34266 .37239 Mdot
.38615 .68886 Mdot
.65842 .63709 Mdot
.63959 .62329 Mdot
.56143 .28516 Mdot
.36202 .68269 Mdot
.70646 .42256 Mdot
.48078 .27315 Mdot
.58691 .71297 Mdot
.54183 .27188 Mdot
.31286 .39156 Mdot
.59007 .30884 Mdot
.66878 .6496 Mdot
.32387 .36063 Mdot
.66182 .6313 Mdot
.37302 .37206 Mdot
.31413 .40662 Mdot
.30914 .44563 Mdot
.54293 .26653 Mdot
.69663 .57002 Mdot
.44676 .30359 Mdot
.3364 .57163 Mdot
.39012 .68575 Mdot
.563 .31237 Mdot
.29129 .45665 Mdot
.25959 .50271 Mdot
.28304 .49237 Mdot
.72607 .54146 Mdot
.60066 .6837 Mdot
.41312 .31757 Mdot
.41521 .31415 Mdot
.6547 .35297 Mdot
.68064 .63259 Mdot
.36002 .38289 Mdot
.71999 .42379 Mdot
.69587 .40366 Mdot
.28368 .46363 Mdot
.41846 .31472 Mdot
.6688 .63016 Mdot
.70826 .44214 Mdot
.71868 .50125 Mdot
.37295 .64491 Mdot
.37188 .34983 Mdot
.40366 .3431 Mdot
.37467 .37292 Mdot
.48624 .72607 Mdot
.6905 .44589 Mdot
.33504 .58726 Mdot
.31707 .43244 Mdot
.6384 .33622 Mdot
.31139 .46449 Mdot
.5905 .7131 Mdot
.5183 .25971 Mdot
.72424 .47919 Mdot
.33773 .62057 Mdot
.33947 .55809 Mdot
.64395 .33476 Mdot
.35413 .64878 Mdot
.67877 .62179 Mdot
.72709 .50833 Mdot
.56981 .2999 Mdot
.43156 .72496 Mdot
.37116 .65779 Mdot
.37674 .66283 Mdot
.55094 .30716 Mdot
.35417 .35564 Mdot
.43962 .28589 Mdot
.37882 .6631 Mdot
.69258 .41747 Mdot
.59657 .70798 Mdot
.67475 .4263 Mdot
.34654 .63171 Mdot
.33029 .56834 Mdot
.57369 .69929 Mdot
.59459 .69796 Mdot
.70348 .40905 Mdot
.3544 .35361 Mdot
.33651 .35634 Mdot
.6443 .62344 Mdot
.34747 .57342 Mdot
.40694 .72699 Mdot
.32368 .58141 Mdot
.30623 .45398 Mdot
.44399 .73608 Mdot
.51703 .71542 Mdot
.51053 .7349 Mdot
.39657 .72948 Mdot
.32881 .58869 Mdot
.64967 .34039 Mdot
.69282 .54996 Mdot
.70625 .4267 Mdot
.61376 .31653 Mdot
.50038 .27839 Mdot
.30913 .46704 Mdot
.35053 .60882 Mdot
.27502 .46147 Mdot
.41442 .72504 Mdot
.29248 .43154 Mdot
.48722 .73152 Mdot
.52625 .72801 Mdot
.27011 .48252 Mdot
.32279 .57502 Mdot
.57397 .31116 Mdot
.58628 .2984 Mdot
.57135 .70374 Mdot
.34682 .62985 Mdot
.65316 .35847 Mdot
.67799 .41944 Mdot
.43039 .29423 Mdot
.45125 .2817 Mdot
.31893 .43689 Mdot
.31813 .40041 Mdot
.59111 .7034 Mdot
.34534 .62039 Mdot
.34414 .3572 Mdot
.55659 .31422 Mdot
.36916 .37558 Mdot
.42802 .301 Mdot
.71487 .42219 Mdot
.69091 .43429 Mdot
.3547 .58962 Mdot
.28194 .52251 Mdot
.71193 .52051 Mdot
.70026 .55438 Mdot
.67729 .41619 Mdot
.54782 .26652 Mdot
.36707 .36007 Mdot
.69539 .58607 Mdot
.68275 .62707 Mdot
.29339 .43761 Mdot
.32787 .60205 Mdot
.57934 .29339 Mdot
.69043 .61739 Mdot
.30729 .43454 Mdot
.45672 .72444 Mdot
.47676 .27568 Mdot
.34097 .59229 Mdot
.56398 .70872 Mdot
.69584 .52566 Mdot
.49877 .72807 Mdot
.64792 .63335 Mdot
.68616 .41497 Mdot
.7127 .43454 Mdot
.33116 .56562 Mdot
.72856 .48343 Mdot
.63386 .65372 Mdot
.70362 .44404 Mdot
.27185 .48092 Mdot
.34706 .37576 Mdot
.31444 .45978 Mdot
.57469 .30204 Mdot
.30987 .44714 Mdot
.53056 .30098 Mdot
.4448 .29639 Mdot
.66694 .62307 Mdot
.2919 .45217 Mdot
.50794 .71059 Mdot
.35174 .37764 Mdot
.31825 .42298 Mdot
.49548 .73643 Mdot
.58467 .71709 Mdot
.5429 .2842 Mdot
.27681 .45681 Mdot
.33091 .5461 Mdot
.6721 .37546 Mdot
.61982 .33802 Mdot
.71793 .41949 Mdot
.36135 .35881 Mdot
.55306 .27976 Mdot
.66279 .63668 Mdot
.40144 .7158 Mdot
.65261 .66011 Mdot
.39118 .67072 Mdot
.34676 .5827 Mdot
.63991 .65653 Mdot
.66183 .6373 Mdot
.32996 .56318 Mdot
.38628 .70107 Mdot
.34549 .37903 Mdot
.68754 .40956 Mdot
.72809 .53378 Mdot
.72438 .5342 Mdot
.51701 .28141 Mdot
.67899 .6133 Mdot
.39861 .33058 Mdot
.7176 .42305 Mdot
.39327 .35886 Mdot
.70307 .41691 Mdot
.26726 .5085 Mdot
.48926 .27956 Mdot
.69357 .57488 Mdot
.73459 .54088 Mdot
.58349 .68659 Mdot
.66882 .62069 Mdot
.29412 .46056 Mdot
.67433 .6116 Mdot
.66018 .6219 Mdot
.34857 .57303 Mdot
.34832 .35353 Mdot
.36565 .37471 Mdot
.4838 .72719 Mdot
.71241 .52116 Mdot
.32709 .5778 Mdot
.48925 .73865 Mdot
.33941 .56279 Mdot
.49623 .72816 Mdot
.73157 .51416 Mdot
.35287 .65528 Mdot
.66881 .61627 Mdot
.73225 .4983 Mdot
.408 .33476 Mdot
.35614 .3764 Mdot
.36408 .38174 Mdot
.60557 .31457 Mdot
.39232 .6763 Mdot
.44425 .30048 Mdot
.58609 .70254 Mdot
.33291 .36825 Mdot
.51335 .70952 Mdot
.2752 .45247 Mdot
.37867 .68023 Mdot
.34058 .36261 Mdot
.53225 .29057 Mdot
.58163 .688 Mdot
.38401 .67515 Mdot
.36361 .35525 Mdot
.67069 .62478 Mdot
.70535 .5357 Mdot
.67617 .63645 Mdot
.28514 .46993 Mdot
.71008 .41712 Mdot
.58714 .69984 Mdot
.57336 .30392 Mdot
.44074 .30315 Mdot
.66251 .6318 Mdot
.51751 .26464 Mdot
.68484 .42968 Mdot
.3826 .67048 Mdot
.6923 .40965 Mdot
.27013 .46181 Mdot
.7269 .52699 Mdot
.5799 .69594 Mdot
.58343 .67498 Mdot
.67125 .60851 Mdot
.33834 .3807 Mdot
.29194 .48619 Mdot
.52803 .25876 Mdot
.69762 .5384 Mdot
.71263 .41948 Mdot
.51391 .27709 Mdot
.57583 .6936 Mdot
.2822 .43744 Mdot
.38108 .71044 Mdot
.35506 .60731 Mdot
.54187 .70578 Mdot
.35793 .60979 Mdot
.43598 .30668 Mdot
.64191 .6281 Mdot
.60062 .69944 Mdot
.52235 .72848 Mdot
.27386 .51693 Mdot
.30829 .47311 Mdot
.3344 .60013 Mdot
.48945 .70942 Mdot
.35802 .64136 Mdot
.69385 .56948 Mdot
.50189 .72589 Mdot
.4904 .27153 Mdot
.40255 .34228 Mdot
.61336 .31651 Mdot
.33866 .36869 Mdot
.51909 .26033 Mdot
.38557 .69805 Mdot
.36919 .69893 Mdot
.70073 .5003 Mdot
.58854 .71535 Mdot
.70235 .4343 Mdot
.35528 .66384 Mdot
.52657 .28487 Mdot
.45372 .30409 Mdot
.332 .6227 Mdot
.67922 .62498 Mdot
.66904 .37028 Mdot
.3396 .35999 Mdot
.36619 .38085 Mdot
.2978 .43785 Mdot
.49902 .26813 Mdot
.31566 .37645 Mdot
.70556 .4215 Mdot
.32882 .54799 Mdot
.51671 .71505 Mdot
.67105 .35695 Mdot
.67949 .60639 Mdot
.64599 .35875 Mdot
.26832 .50952 Mdot
.33557 .58089 Mdot
.71701 .51326 Mdot
.65546 .61525 Mdot
.30373 .4326 Mdot
.42998 .3041 Mdot
.44925 .28885 Mdot
.29168 .52473 Mdot
.32949 .35888 Mdot
.55395 .31317 Mdot
.31769 .3814 Mdot
.58065 .70404 Mdot
.49378 .73387 Mdot
.61915 .33876 Mdot
.33984 .57244 Mdot
.74553 .50787 Mdot
.64589 .62303 Mdot
.33104 .60188 Mdot
.30004 .47344 Mdot
.69198 .58211 Mdot
.57465 .68353 Mdot
.3255 .54525 Mdot
.56269 .28326 Mdot
.33862 .57672 Mdot
.40793 .32958 Mdot
.39084 .3596 Mdot
.35578 .58048 Mdot
.53296 .29534 Mdot
.3231 .3619 Mdot
.29421 .48051 Mdot
.64952 .61273 Mdot
.34008 .36907 Mdot
.58668 .71371 Mdot
.3888 .68987 Mdot
.27337 .48161 Mdot
.57642 .70122 Mdot
.6523 .65802 Mdot
.36089 .38631 Mdot
.5359 .26921 Mdot
.70135 .51848 Mdot
.33232 .57546 Mdot
.34451 .37742 Mdot
.33965 .6152 Mdot
.62733 .63852 Mdot
.35416 .60337 Mdot
.71248 .39906 Mdot
.6937 .52828 Mdot
.69837 .42495 Mdot
.58416 .68924 Mdot
.34176 .59043 Mdot
.3181 .37995 Mdot
.36949 .36204 Mdot
.38015 .65704 Mdot
.66054 .63241 Mdot
.65536 .62152 Mdot
.67236 .63665 Mdot
.51908 .27725 Mdot
.4118 .72339 Mdot
.6928 .42534 Mdot
.34997 .35507 Mdot
.68048 .44165 Mdot
.46699 .71347 Mdot
.28833 .46949 Mdot
.67648 .37905 Mdot
.38294 .66537 Mdot
.70536 .55128 Mdot
.36336 .63513 Mdot
.69213 .55943 Mdot
.60511 .31504 Mdot
.64771 .35908 Mdot
.71564 .52602 Mdot
.33081 .59693 Mdot
.48681 .72428 Mdot
.52308 .71772 Mdot
.69848 .4451 Mdot
.35749 .34711 Mdot
.41376 .32382 Mdot
.57914 .29654 Mdot
.28993 .43207 Mdot
.63754 .32928 Mdot
.66754 .37377 Mdot
.59637 .68753 Mdot
.70208 .52594 Mdot
.71103 .42659 Mdot
.71772 .41028 Mdot
.53092 .28089 Mdot
.58888 .68607 Mdot
.34456 .59611 Mdot
.34151 .38395 Mdot
.63418 .34782 Mdot
.37422 .66014 Mdot
.59413 .71448 Mdot
.4277 .29464 Mdot
.65996 .64246 Mdot
.67515 .36183 Mdot
.45865 .71515 Mdot
.6416 .64908 Mdot
.47083 .28127 Mdot
.73616 .51418 Mdot
.32868 .58346 Mdot
.35887 .3634 Mdot
.52237 .26263 Mdot
.39292 .68861 Mdot
.43861 .30784 Mdot
.70177 .43812 Mdot
.66957 .35986 Mdot
.46542 .71853 Mdot
.46446 .27799 Mdot
.32752 .5652 Mdot
.56914 .68856 Mdot
.30605 .44016 Mdot
.70674 .43883 Mdot
.70757 .49615 Mdot
.33551 .61392 Mdot
.51558 .28568 Mdot
.58681 .31057 Mdot
.65145 .63105 Mdot
.67931 .6331 Mdot
.69675 .57129 Mdot
.35594 .37159 Mdot
.50732 .27316 Mdot
.3459 .37748 Mdot
.32726 .54356 Mdot
.70547 .4437 Mdot
.29262 .48187 Mdot
.53325 .26186 Mdot
.63045 .33002 Mdot
.5843 .717 Mdot
.72641 .54512 Mdot
.54725 .7019 Mdot
.57083 .69865 Mdot
.5017 .26849 Mdot
.29506 .46886 Mdot
.50589 .73016 Mdot
.59015 .6792 Mdot
.28075 .47808 Mdot
.5229 .27997 Mdot
.70801 .53134 Mdot
.65366 .61479 Mdot
.69069 .54315 Mdot
.50514 .71196 Mdot
.69505 .60385 Mdot
.36931 .68153 Mdot
.35768 .58495 Mdot
.74189 .53336 Mdot
.3986 .71072 Mdot
.71734 .41909 Mdot
.69585 .54379 Mdot
.49742 .72818 Mdot
.6004 .71081 Mdot
.36975 .67647 Mdot
.36213 .68073 Mdot
.59549 .70271 Mdot
.39243 .67641 Mdot
.64819 .65626 Mdot
.63975 .62323 Mdot
.51008 .7332 Mdot
.70797 .44558 Mdot
.29948 .4598 Mdot
.73283 .50707 Mdot
.34082 .57864 Mdot
.64274 .65743 Mdot
.50339 .73574 Mdot
.71173 .39881 Mdot
.59397 .70638 Mdot
.51628 .25964 Mdot
.383 .70787 Mdot
.59019 .31354 Mdot
.58362 .67598 Mdot
.63808 .65797 Mdot
.63008 .34997 Mdot
.57597 .68198 Mdot
.46639 .27236 Mdot
.35534 .6662 Mdot
.36257 .36404 Mdot
.31203 .44593 Mdot
.31977 .3687 Mdot
.70731 .40906 Mdot
.39238 .68082 Mdot
.39068 .70432 Mdot
.35313 .63023 Mdot
.32726 .54323 Mdot
.3543 .37716 Mdot
.2595 .47204 Mdot
.62956 .63505 Mdot
.38183 .67926 Mdot
.56671 .27929 Mdot
.70959 .51225 Mdot
.38043 .69377 Mdot
.53201 .72132 Mdot
.56481 .70688 Mdot
.71308 .52227 Mdot
.72725 .54727 Mdot
.41093 .32644 Mdot
.2993 .44836 Mdot
.33626 .56399 Mdot
.26119 .48239 Mdot
.5847 .69977 Mdot
.70076 .41286 Mdot
.35217 .63335 Mdot
.49052 .28006 Mdot
.50681 .72217 Mdot
.52228 .27854 Mdot
.34716 .56188 Mdot
.73083 .52917 Mdot
.71257 .43298 Mdot
.46086 .2893 Mdot
.464 .28734 Mdot
.36919 .65151 Mdot
.41438 .3163 Mdot
.28051 .46897 Mdot
.28743 .4642 Mdot
.71203 .42928 Mdot
.32734 .59291 Mdot
.50779 .72541 Mdot
.61043 .70499 Mdot
.39497 .68709 Mdot
.33719 .55373 Mdot
.62753 .33213 Mdot
.63539 .33271 Mdot
.5332 .2629 Mdot
.3323 .56006 Mdot
.37302 .66769 Mdot
.72049 .52053 Mdot
.30905 .46962 Mdot
.50233 .27274 Mdot
.31104 .43406 Mdot
.55284 .30476 Mdot
.42071 .7376 Mdot
.35847 .34945 Mdot
.28679 .46716 Mdot
.65169 .33761 Mdot
.71303 .54839 Mdot
.34768 .38141 Mdot
.5517 .28796 Mdot
.51256 .26844 Mdot
.38145 .69251 Mdot
.67847 .60521 Mdot
.7296 .50952 Mdot
.28322 .47258 Mdot
.6786 .41482 Mdot
.57212 .69757 Mdot
.37318 .37479 Mdot
.27039 .51203 Mdot
.50906 .27758 Mdot
.69273 .56606 Mdot
.55352 .69178 Mdot
.34809 .58949 Mdot
.70627 .53595 Mdot
.3469 .59291 Mdot
.66842 .63643 Mdot
.73071 .50229 Mdot
.33918 .62929 Mdot
.66141 .6464 Mdot
.53359 .30583 Mdot
.46453 .2994 Mdot
.60108 .70497 Mdot
.65196 .36899 Mdot
.58454 .70274 Mdot
.44641 .28407 Mdot
.36292 .63705 Mdot
.39119 .69142 Mdot
.34315 .57931 Mdot
.31528 .41697 Mdot
.39278 .72597 Mdot
.37727 .36421 Mdot
.36247 .36475 Mdot
.70588 .52866 Mdot
.31843 .37068 Mdot
.48829 .72686 Mdot
.28798 .4529 Mdot
.56897 .29844 Mdot
.3667 .65161 Mdot
.28747 .47291 Mdot
.64965 .61692 Mdot
.5838 .68188 Mdot
.74354 .52724 Mdot
.59136 .30849 Mdot
.34993 .35873 Mdot
.70306 .43638 Mdot
.46571 .73435 Mdot
.5232 .28748 Mdot
.63739 .34431 Mdot
.47316 .72732 Mdot
.51702 .25863 Mdot
.71621 .436 Mdot
.46117 .30164 Mdot
.64453 .34767 Mdot
.67754 .42527 Mdot
.49688 .71498 Mdot
.28801 .45221 Mdot
.31995 .36455 Mdot
.25758 .47712 Mdot
.63859 .35474 Mdot
.4829 .28593 Mdot
.54522 .27815 Mdot
.5198 .72988 Mdot
.69376 .60201 Mdot
.32998 .37658 Mdot
.33277 .55682 Mdot
.64163 .33826 Mdot
.41386 .73272 Mdot
.31983 .36545 Mdot
.69137 .43225 Mdot
.58226 .67614 Mdot
.44005 .73381 Mdot
.35326 .3686 Mdot
.35919 .37937 Mdot
.27948 .45531 Mdot
.4381 .29438 Mdot
.73565 .51736 Mdot
.28013 .4459 Mdot
.35575 .63317 Mdot
.34028 .56902 Mdot
.70484 .41003 Mdot
.34081 .36784 Mdot
.68837 .42605 Mdot
.30428 .47094 Mdot
.26026 .47014 Mdot
.64918 .6141 Mdot
.67649 .63149 Mdot
.31702 .38763 Mdot
.39598 .73156 Mdot
.37715 .7154 Mdot
.70477 .49562 Mdot
.73337 .52271 Mdot
.35915 .67826 Mdot
.28017 .49029 Mdot
.28205 .45023 Mdot
.57229 .68319 Mdot
.49885 .73948 Mdot
.59719 .69852 Mdot
.45997 .72386 Mdot
.60176 .31657 Mdot
.58122 .69066 Mdot
.52365 .25965 Mdot
.4587 .72369 Mdot
.66303 .36336 Mdot
.57026 .70427 Mdot
.35086 .59906 Mdot
.5561 .30107 Mdot
.35137 .56963 Mdot
.5734 .29674 Mdot
.32886 .57538 Mdot
.49168 .26668 Mdot
.57312 .30376 Mdot
.41114 .3233 Mdot
.45055 .7317 Mdot
.37591 .36568 Mdot
.28093 .48522 Mdot
.3989 .34469 Mdot
.37187 .69648 Mdot
.71126 .5324 Mdot
.6958 .59948 Mdot
.3493 .59075 Mdot
.53289 .27927 Mdot
.69539 .4395 Mdot
.57744 .67596 Mdot
.34938 .625 Mdot
.57515 .70428 Mdot
.72626 .54559 Mdot
.56221 .28413 Mdot
.313 .44181 Mdot
.41842 .3041 Mdot
.44563 .28556 Mdot
.48904 .28022 Mdot
.32335 .54333 Mdot
.56644 .70671 Mdot
.40768 .3295 Mdot
.64876 .64399 Mdot
.25887 .5011 Mdot
.65912 .61539 Mdot
.33851 .37181 Mdot
.29363 .44168 Mdot
.43909 .72576 Mdot
.71673 .50745 Mdot
.5522 .30746 Mdot
.3399 .59128 Mdot
.36057 .35205 Mdot
.25768 .47666 Mdot
.70795 .50309 Mdot
.27268 .48193 Mdot
.55645 .29283 Mdot
.34705 .37312 Mdot
.41225 .72844 Mdot
.34783 .64724 Mdot
.5172 .73835 Mdot
.34025 .58724 Mdot
.28067 .47499 Mdot
.68117 .60573 Mdot
.57375 .70366 Mdot
.64087 .34967 Mdot
.49605 .7251 Mdot
.34111 .55372 Mdot
.45549 .27807 Mdot
.72956 .5396 Mdot
.29691 .45553 Mdot
.64265 .33953 Mdot
.3016 .44737 Mdot
.3691 .37751 Mdot
.67251 .63147 Mdot
.3688 .3785 Mdot
.59114 .71454 Mdot
.70921 .42817 Mdot
.7269 .50851 Mdot
.43512 .28732 Mdot
.33326 .35644 Mdot
.56725 .31391 Mdot
.44542 .73331 Mdot
.65571 .63074 Mdot
.6212 .33058 Mdot
.41829 .30576 Mdot
.71407 .40237 Mdot
.51153 .73864 Mdot
.68225 .4127 Mdot
.34918 .58936 Mdot
.68964 .53766 Mdot
.67649 .43315 Mdot
.45913 .28662 Mdot
.49141 .70952 Mdot
.38019 .36982 Mdot
.32456 .59006 Mdot
.69161 .3838 Mdot
.69681 .45127 Mdot
.674 .61659 Mdot
.63943 .3291 Mdot
.35912 .63578 Mdot
.35032 .37716 Mdot
.35232 .57962 Mdot
.64616 .35606 Mdot
.63034 .32718 Mdot
.45575 .29355 Mdot
.33623 .59009 Mdot
.30613 .45148 Mdot
.51805 .26014 Mdot
.58641 .3121 Mdot
.52673 .26483 Mdot
.63856 .65193 Mdot
.33929 .35623 Mdot
.35792 .37012 Mdot
.3631 .64363 Mdot
.68504 .42331 Mdot
.37645 .36439 Mdot
.38674 .68502 Mdot
.37911 .69914 Mdot
.69099 .54016 Mdot
.55258 .29494 Mdot
.34364 .55639 Mdot
.60268 .70239 Mdot
.36671 .35692 Mdot
.54296 .29861 Mdot
.66982 .62655 Mdot
.44328 .2831 Mdot
.38685 .67429 Mdot
.59844 .69229 Mdot
.66886 .60752 Mdot
.64016 .66041 Mdot
.39338 .72757 Mdot
.34729 .59533 Mdot
.69498 .40694 Mdot
.52336 .67319 Mdot
.3912 .57954 Mdot
.44386 .48417 Mdot
.32727 .37178 Mdot
.59627 .56339 Mdot
.48332 .65523 Mdot
.61153 .69515 Mdot
.4982 .58416 Mdot
.47888 .70805 Mdot
.54427 .62113 Mdot
.63192 .41616 Mdot
.47344 .54712 Mdot
.49318 .29797 Mdot
.67146 .4824 Mdot
.60056 .66666 Mdot
.33371 .48201 Mdot
.66997 .53753 Mdot
.51425 .63387 Mdot
.67699 .48124 Mdot
.60347 .45225 Mdot
.58342 .33722 Mdot
.60194 .32324 Mdot
.60671 .4075 Mdot
.33124 .54393 Mdot
.54263 .65042 Mdot
.41085 .60631 Mdot
.6418 .58359 Mdot
.65238 .39133 Mdot
.60549 .69834 Mdot
.41695 .38507 Mdot
.61411 .56895 Mdot
.45643 .38075 Mdot
.44794 .68037 Mdot
.62845 .44493 Mdot
.40712 .59837 Mdot
.37807 .43739 Mdot
.47706 .70448 Mdot
.54664 .58891 Mdot
.59465 .5918 Mdot
.44978 .64853 Mdot
.62312 .55198 Mdot
.50898 .28575 Mdot
.68749 .6087 Mdot
.68025 .4976 Mdot
.45704 .36031 Mdot
.64168 .54065 Mdot
.4977 .58519 Mdot
.32046 .38788 Mdot
.59764 .5562 Mdot
.40812 .69874 Mdot
.68623 .55946 Mdot
.64837 .46949 Mdot
.65198 .40695 Mdot
.46047 .66152 Mdot
.65908 .43071 Mdot
.41936 .68673 Mdot
.5183 .63624 Mdot
.4892 .65916 Mdot
.60556 .44742 Mdot
.54213 .35372 Mdot
.73397 .53446 Mdot
.33736 .48361 Mdot
.56182 .4312 Mdot
.4023 .48078 Mdot
.65529 .48728 Mdot
.47042 .69116 Mdot
.641 .60883 Mdot
.69015 .51715 Mdot
.59645 .35899 Mdot
.458 .33984 Mdot
.61493 .40223 Mdot
.57057 .43339 Mdot
.64445 .53038 Mdot
.38813 .60999 Mdot
.58007 .61118 Mdot
.58321 .37449 Mdot
.54008 .68815 Mdot
.36339 .40983 Mdot
.5486 .51801 Mdot
.42175 .34458 Mdot
.47515 .66644 Mdot
.61386 .45532 Mdot
.45294 .57604 Mdot
.60763 .52697 Mdot
.40078 .65608 Mdot
.43603 .34477 Mdot
.54505 .64886 Mdot
.55628 .37872 Mdot
.66681 .54636 Mdot
.50133 .68038 Mdot
.65548 .43852 Mdot
.39203 .37025 Mdot
.44938 .42143 Mdot
.41786 .36648 Mdot
.50523 .57753 Mdot
.38058 .42262 Mdot
.62815 .44207 Mdot
.69085 .47145 Mdot
.57739 .32051 Mdot
.61933 .6105 Mdot
.47224 .36798 Mdot
.73987 .50274 Mdot
.55767 .32892 Mdot
.49278 .61255 Mdot
.60912 .62539 Mdot
.41685 .37308 Mdot
.60309 .36623 Mdot
.59534 .51825 Mdot
.5973 .42331 Mdot
.59263 .58753 Mdot
.56965 .61782 Mdot
.67353 .53844 Mdot
.31818 .3965 Mdot
.59058 .6569 Mdot
.44621 .38444 Mdot
.62272 .38057 Mdot
.34264 .43082 Mdot
.4031 .71141 Mdot
.47091 .39034 Mdot
.51588 .70216 Mdot
.50837 .47549 Mdot
.66327 .57068 Mdot
.41866 .35251 Mdot
.60529 .70508 Mdot
.53839 .68047 Mdot
.6057 .40474 Mdot
.35275 .49429 Mdot
.67833 .56635 Mdot
.68036 .47725 Mdot
.60009 .33807 Mdot
.48805 .6757 Mdot
.42533 .32951 Mdot
.36006 .54448 Mdot
.40366 .45385 Mdot
.61745 .34801 Mdot
.39313 .47701 Mdot
.43567 .44745 Mdot
.46718 .30755 Mdot
.61806 .62499 Mdot
.43518 .43078 Mdot
.52974 .70375 Mdot
.57616 .36929 Mdot
.62672 .41089 Mdot
.53522 .66489 Mdot
.30599 .49212 Mdot
.40775 .40755 Mdot
.45663 .45022 Mdot
.59898 .54065 Mdot
.6151 .69306 Mdot
.41102 .577 Mdot
.62345 .43299 Mdot
.5154 .40643 Mdot
.52714 .35856 Mdot
.67855 .47248 Mdot
.73793 .49906 Mdot
.49632 .38358 Mdot
.43426 .56379 Mdot
.57762 .66793 Mdot
.50268 .42531 Mdot
.6627 .581 Mdot
.48692 .41344 Mdot
.41606 .38261 Mdot
.60895 .34344 Mdot
.59343 .38008 Mdot
.64913 .5295 Mdot
.65436 .4095 Mdot
.57821 .63443 Mdot
.58545 .63384 Mdot
.49561 .36196 Mdot
.66802 .53257 Mdot
.6236 .47302 Mdot
.68586 .5306 Mdot
.51663 .61923 Mdot
.43857 .64301 Mdot
.38578 .56305 Mdot
.44527 .52738 Mdot
.27297 .49208 Mdot
.37667 .44459 Mdot
.4903 .67886 Mdot
.28571 .50477 Mdot
.38291 .50813 Mdot
.40249 .5953 Mdot
.37071 .38118 Mdot
.37376 .55694 Mdot
.41498 .70069 Mdot
.57039 .53861 Mdot
.5999 .37763 Mdot
.4587 .46849 Mdot
.37094 .54351 Mdot
.65372 .57589 Mdot
.4718 .70482 Mdot
.42013 .35296 Mdot
.47385 .32636 Mdot
.5075 .65336 Mdot
.5568 .66291 Mdot
.65916 .3749 Mdot
.66754 .4069 Mdot
.4852 .30314 Mdot
.64976 .52849 Mdot
.65147 .60058 Mdot
.42734 .30821 Mdot
.60834 .48568 Mdot
.44929 .58795 Mdot
.41465 .63814 Mdot
.43864 .35812 Mdot
.57747 .55425 Mdot
.32312 .42508 Mdot
.46888 .62276 Mdot
.43997 .46495 Mdot
.40004 .40573 Mdot
.35834 .42369 Mdot
.3541 .44158 Mdot
.67622 .50776 Mdot
.36769 .45048 Mdot
.40464 .38411 Mdot
.41493 .71994 Mdot
.56671 .47131 Mdot
.60807 .67747 Mdot
.40613 .53216 Mdot
.55544 .33362 Mdot
.56144 .41877 Mdot
.56671 .61192 Mdot
.46091 .66275 Mdot
.38676 .3908 Mdot
.41334 .69747 Mdot
.62045 .53363 Mdot
.44257 .39249 Mdot
.56748 .3902 Mdot
.46629 .38541 Mdot
.50395 .35583 Mdot
.52434 .58123 Mdot
.68016 .47907 Mdot
.28604 .51934 Mdot
.5484 .35161 Mdot
.63328 .57486 Mdot
.52662 .69379 Mdot
.56049 .33322 Mdot
.60229 .64073 Mdot
.60465 .60668 Mdot
.46937 .6493 Mdot
.41969 .57279 Mdot
.47077 .50335 Mdot
.5528 .59092 Mdot
.39136 .44358 Mdot
.54193 .39303 Mdot
.60436 .33167 Mdot
.49853 .31567 Mdot
.46808 .48831 Mdot
.56168 .46581 Mdot
.36455 .52698 Mdot
.59802 .35336 Mdot
.54232 .55686 Mdot
.39005 .58597 Mdot
.45767 .46517 Mdot
.51856 .6461 Mdot
.66054 .58744 Mdot
.42782 .56805 Mdot
.39885 .68717 Mdot
.4532 .35478 Mdot
.47804 .2999 Mdot
.49634 .35049 Mdot
.54562 .65695 Mdot
.66674 .43687 Mdot
.65829 .50907 Mdot
.36934 .50957 Mdot
.40351 .62671 Mdot
.51098 .5445 Mdot
.42791 .67933 Mdot
.67914 .40241 Mdot
.66817 .58961 Mdot
.56661 .64068 Mdot
.34013 .5481 Mdot
.45222 .54374 Mdot
.55164 .63642 Mdot
.3799 .49291 Mdot
.51628 .70041 Mdot
.62764 .63601 Mdot
.56128 .35739 Mdot
.6016 .32388 Mdot
.31929 .48061 Mdot
.55873 .44156 Mdot
.32077 .43534 Mdot
.49387 .3245 Mdot
.59331 .53214 Mdot
.44735 .67443 Mdot
.66069 .39716 Mdot
.52043 .36719 Mdot
.50255 .29936 Mdot
.50506 .35448 Mdot
.6234 .40583 Mdot
.65431 .4935 Mdot
.37385 .58886 Mdot
.61937 .58003 Mdot
.67228 .46547 Mdot
.37038 .62076 Mdot
.63428 .3884 Mdot
.60822 .54318 Mdot
.68217 .55392 Mdot
.40073 .67718 Mdot
.36418 .63395 Mdot
.35758 .45815 Mdot
.38027 .60307 Mdot
.43229 .4874 Mdot
.68557 .59458 Mdot
.32653 .51606 Mdot
.62537 .53428 Mdot
.60048 .67521 Mdot
.55498 .66605 Mdot
.67491 .5623 Mdot
.52419 .69562 Mdot
.53199 .3136 Mdot
.66968 .43613 Mdot
.55758 .63184 Mdot
.37704 .50983 Mdot
.41383 .40989 Mdot
.36382 .50364 Mdot
.56993 .65892 Mdot
.41998 .53996 Mdot
.65275 .59031 Mdot
.46483 .66232 Mdot
.56382 .50268 Mdot
.62127 .61371 Mdot
.47477 .61416 Mdot
.50766 .69375 Mdot
.59585 .66596 Mdot
.47429 .34187 Mdot
.33918 .49602 Mdot
.5403 .59699 Mdot
.35924 .61916 Mdot
.49628 .47221 Mdot
.49961 .61414 Mdot
.34706 .52838 Mdot
.52513 .60599 Mdot
.31652 .53569 Mdot
.70922 .48831 Mdot
.57591 .58627 Mdot
.52461 .40058 Mdot
.3333 .53221 Mdot
.44644 .67797 Mdot
.50183 .67782 Mdot
.67844 .47494 Mdot
.33469 .50301 Mdot
.4578 .33624 Mdot
.54315 .49838 Mdot
.36777 .53812 Mdot
.46336 .43641 Mdot
.35479 .47 Mdot
.33582 .39771 Mdot
.50035 .35759 Mdot
.60042 .56257 Mdot
.31811 .51724 Mdot
.63931 .38004 Mdot
.4422 .51864 Mdot
.45334 .58234 Mdot
.55903 .35378 Mdot
.46814 .58799 Mdot
.47731 .57112 Mdot
.47059 .46516 Mdot
.57059 .3481 Mdot
.57222 .56934 Mdot
.61592 .54479 Mdot
.62481 .64091 Mdot
.39547 .39981 Mdot
.55617 .61536 Mdot
.6045 .61186 Mdot
.53719 .40037 Mdot
.35247 .6167 Mdot
.43888 .53007 Mdot
.68691 .56908 Mdot
.51334 .4418 Mdot
.57122 .62578 Mdot
.48215 .29718 Mdot
.58411 .54876 Mdot
.46097 .47686 Mdot
.32522 .49966 Mdot
.31454 .51901 Mdot
.43744 .6058 Mdot
.40604 .37351 Mdot
.62597 .53173 Mdot
.578 .651 Mdot
.62356 .55871 Mdot
.40754 .64407 Mdot
.71955 .4907 Mdot
.4601 .32763 Mdot
.65216 .37249 Mdot
.65255 .5746 Mdot
.45934 .62048 Mdot
.42075 .33253 Mdot
.55766 .47485 Mdot
.61756 .48703 Mdot
.67183 .4493 Mdot
.61073 .36137 Mdot
.59683 .36977 Mdot
.42742 .52458 Mdot
.64424 .44197 Mdot
.54675 .35475 Mdot
.6061 .63544 Mdot
.5217 .31163 Mdot
.54948 .36278 Mdot
.53538 .71141 Mdot
.58229 .37449 Mdot
.61227 .65609 Mdot
.65352 .43419 Mdot
.49692 .60906 Mdot
.59112 .53997 Mdot
.5151 .42369 Mdot
.58809 .65371 Mdot
.67257 .50807 Mdot
.57584 .49854 Mdot
.42525 .70687 Mdot
.51063 .68544 Mdot
.5444 .68439 Mdot
.41578 .61163 Mdot
.59048 .51504 Mdot
.32099 .5182 Mdot
.63007 .35421 Mdot
.39047 .63088 Mdot
.68436 .55749 Mdot
.41558 .71769 Mdot
.62226 .47698 Mdot
.45098 .71381 Mdot
.47609 .34558 Mdot
.62506 .47654 Mdot
.34983 .44534 Mdot
.43779 .31205 Mdot
.33684 .49356 Mdot
.57861 .60371 Mdot
.49325 .32505 Mdot
.55114 .33345 Mdot
.51774 .31792 Mdot
.35017 .42983 Mdot
.52872 .34195 Mdot
.3772 .62861 Mdot
.57616 .51272 Mdot
.39231 .61301 Mdot
.35387 .49898 Mdot
.54198 .34349 Mdot
.68382 .58806 Mdot
.42127 .4108 Mdot
.4879 .63548 Mdot
.62644 .37206 Mdot
.34826 .47601 Mdot
.37716 .64508 Mdot
.49807 .44275 Mdot
.60748 .43423 Mdot
.54662 .31213 Mdot
.33799 .43541 Mdot
.54031 .66563 Mdot
.50154 .3791 Mdot
.5377 .6781 Mdot
.54073 .69957 Mdot
.636 .41961 Mdot
.48457 .64693 Mdot
.28586 .51707 Mdot
.64309 .48397 Mdot
.4329 .32236 Mdot
.60819 .53437 Mdot
.70399 .48117 Mdot
.35612 .48952 Mdot
.49141 .35857 Mdot
.50506 .3832 Mdot
.34505 .44714 Mdot
.42647 .41078 Mdot
.42555 .41842 Mdot
.31621 .53491 Mdot
.5062 .64477 Mdot
.38722 .61851 Mdot
.40102 .40255 Mdot
.44509 .64431 Mdot
.4594 .34139 Mdot
.71065 .40318 Mdot
.604 .45827 Mdot
.67323 .58526 Mdot
.37954 .57925 Mdot
.38311 .59665 Mdot
.52777 .36825 Mdot
.66586 .55159 Mdot
.4577 .50383 Mdot
.45846 .45236 Mdot
.6543 .42444 Mdot
.4164 .66513 Mdot
.5276 .59235 Mdot
.33903 .45197 Mdot
.39967 .68891 Mdot
.32225 .40873 Mdot
.59653 .37971 Mdot
.61749 .58075 Mdot
.58481 .52643 Mdot
.65375 .59511 Mdot
.42728 .49403 Mdot
.3598 .56323 Mdot
.40217 .39566 Mdot
.584 .52504 Mdot
.40058 .60196 Mdot
.36341 .47498 Mdot
.60207 .61772 Mdot
.65394 .54778 Mdot
.50628 .58798 Mdot
.5896 .45318 Mdot
.40897 .71984 Mdot
.61126 .40173 Mdot
.48058 .29646 Mdot
.32678 .50481 Mdot
.6551 .53958 Mdot
.37918 .58452 Mdot
.44432 .43648 Mdot
.57332 .41016 Mdot
.33397 .47403 Mdot
.59806 .34971 Mdot
.49066 .67981 Mdot
.63185 .38893 Mdot
.65962 .5559 Mdot
.61531 .4818 Mdot
.37748 .60654 Mdot
.33654 .48613 Mdot
.4506 .60299 Mdot
.55587 .52205 Mdot
.47858 .43195 Mdot
.44181 .71111 Mdot
.54557 .64632 Mdot
.42103 .5777 Mdot
.69407 .48829 Mdot
.34229 .45773 Mdot
.6099 .41846 Mdot
.36158 .46695 Mdot
.33679 .47405 Mdot
.66268 .5982 Mdot
.56935 .64238 Mdot
.6916 .47516 Mdot
.37196 .53976 Mdot
.53999 .31028 Mdot
.38191 .65222 Mdot
.41833 .69727 Mdot
.47515 .60706 Mdot
.50145 .39302 Mdot
.28794 .51395 Mdot
.50984 .69071 Mdot
.60183 .40785 Mdot
.52185 .6989 Mdot
.51025 .30797 Mdot
.52203 .57624 Mdot
.48414 .65997 Mdot
.42075 .49379 Mdot
.65076 .4976 Mdot
.5097 .644 Mdot
.45513 .38252 Mdot
.4076 .52413 Mdot
.47601 .65379 Mdot
.47857 .66238 Mdot
.44282 .57919 Mdot
.6287 .59458 Mdot
.44101 .38421 Mdot
.6117 .37515 Mdot
.28045 .50991 Mdot
.44451 .64729 Mdot
.38593 .59523 Mdot
.59529 .53868 Mdot
.47244 .38108 Mdot
.43534 .31072 Mdot
.30134 .51294 Mdot
.42951 .65987 Mdot
.66694 .58329 Mdot
.51919 .53761 Mdot
.39896 .61654 Mdot
.39253 .62002 Mdot
.66215 .48283 Mdot
.59266 .52272 Mdot
.44899 .4864 Mdot
.68787 .60112 Mdot
.673 .3916 Mdot
.2664 .48918 Mdot
.28797 .50467 Mdot
.63956 .55669 Mdot
.42853 .59843 Mdot
.57949 .36592 Mdot
.67998 .5375 Mdot
.3065 .4864 Mdot
.63097 .51064 Mdot
.34614 .55107 Mdot
.40317 .55451 Mdot
.29466 .51836 Mdot
.37722 .43366 Mdot
.66626 .59961 Mdot
.58421 .64115 Mdot
.65022 .46387 Mdot
.51932 .36963 Mdot
.56068 .54338 Mdot
.53302 .33922 Mdot
.45735 .41452 Mdot
.50131 .37088 Mdot
.47644 .64193 Mdot
.49646 .56734 Mdot
.61864 .39329 Mdot
.49281 .32742 Mdot
.62048 .37678 Mdot
.41952 .46832 Mdot
.56758 .43481 Mdot
.61134 .34318 Mdot
.50264 .43596 Mdot
.63453 .52203 Mdot
.60632 .67955 Mdot
.50838 .54928 Mdot
.56606 .34501 Mdot
.68967 .60561 Mdot
.59387 .43639 Mdot
.50268 .65784 Mdot
.64989 .57426 Mdot
.4426 .38744 Mdot
.56921 .64803 Mdot
.6157 .38149 Mdot
.38844 .59996 Mdot
.55801 .39215 Mdot
.44123 .66826 Mdot
.39422 .47397 Mdot
.33474 .39148 Mdot
.39981 .45137 Mdot
.37627 .38369 Mdot
.38098 .6405 Mdot
.38375 .49998 Mdot
.44055 .3504 Mdot
.39428 .64828 Mdot
.51998 .4248 Mdot
.61711 .45571 Mdot
.68447 .53291 Mdot
.42011 .35671 Mdot
.35714 .55381 Mdot
.59833 .65345 Mdot
.59515 .3704 Mdot
.34736 .4006 Mdot
.33341 .48355 Mdot
.66298 .55465 Mdot
.53637 .42601 Mdot
.49383 .29654 Mdot
.54769 .4994 Mdot
.50423 .32576 Mdot
.60798 .5344 Mdot
.56187 .67956 Mdot
.41529 .38033 Mdot
.62303 .46366 Mdot
.51419 .42771 Mdot
.3923 .59279 Mdot
.46518 .65988 Mdot
.36689 .60492 Mdot
.3809 .55006 Mdot
.50738 .28494 Mdot
.39773 .58258 Mdot
.62958 .43771 Mdot
.44119 .60939 Mdot
.57952 .36821 Mdot
.48831 .31341 Mdot
.56741 .41831 Mdot
.66121 .43507 Mdot
.32179 .51081 Mdot
.42705 .41562 Mdot
.60688 .67256 Mdot
.51603 .69825 Mdot
.29587 .51105 Mdot
.53152 .34292 Mdot
.33827 .49599 Mdot
.4061 .57802 Mdot
.45301 .41884 Mdot
.46904 .33228 Mdot
.50807 .46207 Mdot
.62314 .34768 Mdot
.44378 .63183 Mdot
.59282 .65573 Mdot
.51156 .6667 Mdot
.69201 .49227 Mdot
.5613 .34328 Mdot
.55683 .63155 Mdot
.49666 .57921 Mdot
.50319 .41854 Mdot
.44081 .31716 Mdot
.64413 .56466 Mdot
.69574 .39699 Mdot
.45061 .67994 Mdot
.33275 .49023 Mdot
.54036 .69443 Mdot
.49971 .60593 Mdot
.54531 .57743 Mdot
.34086 .5163 Mdot
.67847 .52703 Mdot
.55929 .64731 Mdot
.4858 .68751 Mdot
.35272 .45306 Mdot
.55782 .59727 Mdot
.48455 .32146 Mdot
.64072 .39933 Mdot
.53231 .57573 Mdot
.50962 .32277 Mdot
.69202 .51155 Mdot
.35509 .4418 Mdot
.36795 .53158 Mdot
.34759 .39698 Mdot
.39294 .66531 Mdot
.47139 .61975 Mdot
.50022 .35589 Mdot
.55868 .54226 Mdot
.67543 .55948 Mdot
.4995 .66888 Mdot
.58234 .34414 Mdot
.32134 .46201 Mdot
.65889 .38851 Mdot
.61108 .443 Mdot
.40426 .59714 Mdot
.40522 .61079 Mdot
.61253 .59764 Mdot
.60012 .5428 Mdot
.46737 .5701 Mdot
.58675 .45147 Mdot
.4349 .63144 Mdot
.47427 .32406 Mdot
.33755 .45474 Mdot
.49301 .69927 Mdot
.48909 .29063 Mdot
.45756 .68437 Mdot
.46828 .68539 Mdot
.59827 .40872 Mdot
.57494 .59627 Mdot
.52954 .41334 Mdot
.52083 .39549 Mdot
.74263 .51121 Mdot
.30976 .51418 Mdot
.57103 .62705 Mdot
.58677 .43503 Mdot
.65612 .46077 Mdot
.50705 .62077 Mdot
.49924 .29003 Mdot
.66735 .49894 Mdot
.57 .33494 Mdot
.58268 .37409 Mdot
.66955 .4868 Mdot
.61918 .53829 Mdot
.61621 .61898 Mdot
.39525 .40973 Mdot
.61756 .45217 Mdot
.45893 .37712 Mdot
.68146 .50721 Mdot
.43019 .55271 Mdot
.41112 .68254 Mdot
.35898 .54429 Mdot
.40806 .50146 Mdot
.41418 .44059 Mdot
.35031 .463 Mdot
.38685 .36853 Mdot
.28851 .50523 Mdot
.65349 .44435 Mdot
.32086 .4997 Mdot
.50976 .63946 Mdot
.32287 .39025 Mdot
.53686 .39409 Mdot
.55633 .59646 Mdot
.39149 .63419 Mdot
.4653 .45992 Mdot
.52099 .34547 Mdot
.60646 .61675 Mdot
.52209 .66688 Mdot
.46268 .33521 Mdot
.39102 .66423 Mdot
.46117 .70777 Mdot
.66924 .56478 Mdot
.55106 .3152 Mdot
.50816 .67071 Mdot
.33622 .42528 Mdot
.67491 .40529 Mdot
.65915 .39557 Mdot
.61583 .59254 Mdot
.50638 .37648 Mdot
.69177 .46361 Mdot
.65418 .58246 Mdot
.45011 .30802 Mdot
.67949 .3926 Mdot
.38294 .4525 Mdot
.55961 .6759 Mdot
.38336 .64142 Mdot
.41563 .45387 Mdot
.31962 .3965 Mdot
.47127 .35168 Mdot
.39707 .63009 Mdot
.60071 .44937 Mdot
.32986 .50478 Mdot
.62416 .39243 Mdot
.64034 .38953 Mdot
.67245 .54853 Mdot
.46271 .63683 Mdot
.66384 .40765 Mdot
.65688 .47239 Mdot
.43941 .67774 Mdot
.33462 .49771 Mdot
.40427 .4378 Mdot
.55729 .53632 Mdot
.45322 .44616 Mdot
.42169 .38245 Mdot
.53423 .33364 Mdot
.57477 .3244 Mdot
.59295 .32174 Mdot
.35354 .5309 Mdot
.56292 .41048 Mdot
.45996 .51725 Mdot
.35874 .45352 Mdot
.65559 .4956 Mdot
.62255 .46178 Mdot
.61121 .38751 Mdot
.47146 .62012 Mdot
.40357 .71111 Mdot
.34435 .4555 Mdot
.40882 .5401 Mdot
.57354 .33321 Mdot
.67531 .51102 Mdot
.65444 .44414 Mdot
.33145 .47984 Mdot
.46114 .56653 Mdot
.39357 .50389 Mdot
.31549 .52547 Mdot
.42377 .34161 Mdot
.61312 .61999 Mdot
.3246 .53317 Mdot
.41982 .31668 Mdot
.668 .46802 Mdot
.52729 .37764 Mdot
.69016 .57989 Mdot
.63833 .37476 Mdot
.38874 .55062 Mdot
.32852 .51395 Mdot
.59064 .44566 Mdot
.65513 .60375 Mdot
.46789 .64676 Mdot
.619 .43621 Mdot
.63566 .3909 Mdot
.42965 .62533 Mdot
.70875 .48844 Mdot
.42718 .47972 Mdot
.68958 .61014 Mdot
.47748 .35416 Mdot
.33226 .46965 Mdot
.46921 .69668 Mdot
.36799 .42749 Mdot
.46092 .70912 Mdot
.48842 .62136 Mdot
.45415 .68578 Mdot
.3746 .58238 Mdot
.62268 .43382 Mdot
.32291 .49881 Mdot
.43373 .61165 Mdot
.33456 .46501 Mdot
.43888 .32396 Mdot
.66186 .60412 Mdot
.43865 .57556 Mdot
.38151 .56803 Mdot
.54794 .61708 Mdot
.58385 .6024 Mdot
.65506 .42484 Mdot
.50094 .32305 Mdot
.6347 .48777 Mdot
.39631 .68561 Mdot
.44471 .44975 Mdot
.48967 .36371 Mdot
.61557 .48014 Mdot
.48577 .36309 Mdot
.4238 .46219 Mdot
.40176 .67517 Mdot
.3126 .53004 Mdot
.57728 .65286 Mdot
.3855 .52685 Mdot
.28423 .50155 Mdot
.32226 .38973 Mdot
.46566 .71182 Mdot
.67855 .4043 Mdot
.33641 .53462 Mdot
.64597 .38565 Mdot
.47057 .35612 Mdot
.45589 .68038 Mdot
.38369 .59022 Mdot
.65718 .3966 Mdot
.40747 .7087 Mdot
.38975 .58913 Mdot
.69937 .39991 Mdot
.64531 .42864 Mdot
.49121 .28823 Mdot
.6496 .57754 Mdot
.52569 .63809 Mdot
.43263 .72054 Mdot
.3295 .39567 Mdot
.63065 .42842 Mdot
.6106 .59759 Mdot
.66894 .56192 Mdot
.61691 .38209 Mdot
.42416 .42112 Mdot
.65998 .54716 Mdot
.47996 .31553 Mdot
.38395 .61546 Mdot
.44458 .442 Mdot
.57321 .61697 Mdot
.42085 .5548 Mdot
.42423 .38791 Mdot
.32849 .44991 Mdot
.37746 .37625 Mdot
.4177 .52497 Mdot
.44228 .35599 Mdot
.67362 .41695 Mdot
.45885 .30742 Mdot
.57682 .59191 Mdot
.49982 .65654 Mdot
.41504 .50825 Mdot
.58143 .53296 Mdot
.60564 .68859 Mdot
.32775 .52615 Mdot
.39471 .47127 Mdot
.66043 .41813 Mdot
.58847 .52884 Mdot
.51705 .62925 Mdot
.53012 .61809 Mdot
.40591 .42455 Mdot
.59974 .68077 Mdot
.35388 .5664 Mdot
.38041 .37704 Mdot
.41917 .70569 Mdot
.3217 .39769 Mdot
.5446 .409 Mdot
.67537 .46303 Mdot
.63535 .42982 Mdot
.64003 .38197 Mdot
.45603 .40034 Mdot
.42095 .37929 Mdot
.61051 .68632 Mdot
.36996 .4396 Mdot
.48594 .45685 Mdot
.66804 .51465 Mdot
.40782 .55263 Mdot
.33498 .47295 Mdot
.4359 .45392 Mdot
.40481 .34679 Mdot
.46502 .32343 Mdot
.47463 .37613 Mdot
.6595 .50654 Mdot
.64143 .60528 Mdot
.65327 .43749 Mdot
.37068 .50746 Mdot
.52429 .67225 Mdot
.31933 .48217 Mdot
.51968 .36167 Mdot
.59101 .47355 Mdot
.57655 .61083 Mdot
.42223 .58716 Mdot
.33465 .51929 Mdot
.50741 .28887 Mdot
.42009 .54015 Mdot
.41941 .43799 Mdot
.34617 .47113 Mdot
.60612 .67104 Mdot
.50479 .51797 Mdot
.43011 .44867 Mdot
.34667 .4434 Mdot
.49435 .28109 Mdot
.40023 .60374 Mdot
.46635 .70161 Mdot
.67823 .46239 Mdot
.34572 .39931 Mdot
.32446 .50955 Mdot
.67158 .4628 Mdot
.58621 .45039 Mdot
.68373 .38769 Mdot
.43588 .44142 Mdot
.49443 .69319 Mdot
.63344 .57151 Mdot
.37064 .39599 Mdot
.46632 .43125 Mdot
.30275 .52881 Mdot
.50583 .36567 Mdot
.52652 .41421 Mdot
.44709 .68765 Mdot
.60598 .38522 Mdot
.4198 .65232 Mdot
.66371 .53867 Mdot
.47803 .34771 Mdot
.61718 .3472 Mdot
.4759 .29578 Mdot
.53587 .58563 Mdot
.68936 .51576 Mdot
.5596 .40961 Mdot
.53305 .67251 Mdot
.5842 .50891 Mdot
.71178 .48634 Mdot
.55255 .66665 Mdot
.37815 .43733 Mdot
.56498 .56813 Mdot
.74276 .51895 Mdot
.43908 .62219 Mdot
.52317 .54724 Mdot
.58372 .58588 Mdot
.50044 .60537 Mdot
.50276 .57979 Mdot
.64191 .57182 Mdot
.51513 .52734 Mdot
.58391 .64935 Mdot
.62985 .5554 Mdot
.40471 .45879 Mdot
.6137 .42892 Mdot
.47134 .39191 Mdot
.42551 .30892 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0?ooooooB_ooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A006ooooo`03o`000?oooooooooo0?ooooooB_ooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0?ooooooB_oo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06
ooooo`?o0000oooooom:ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<oooo
o`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom:ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001_ooool00ol0003oooooooooo`3ooooood[ooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0:Gooooo0_l0002Rooooo`007?ooool00ol0003oooooooooo`2Qooooo`Wo0000
00?oooooo`000?l00000W?ooool001cooooo00?o0000ooooooooool0XOooool<o`000003ooooool0
003o000009Wooooo000Looooo`03o`000?oooooooooo09cooooo5Ol0002Hooooo`007?ooool00ol0
003oooooooooo`2Fooooo`;o000000?oooooo`000?l000006?l0002Fooooo`007?ooool00ol0003o
ooooooooo`2Doooooaoo0000U_ooool001cooooo00?o0000ooooooooool0TooooolSo`0009?ooooo
000Looooo`03o`000?oooooooooo08kooooo:_l0002Aooooo`007?ooool00ol0003oooooooooo`2<
oooooaGo000000?oooooo`000?l000005?l0002Aooooo`007?ooool00ol0003oooooooooo`2;oooo
oaCo00000_oooolIo`0008oooooo000Looooo`03o`000?oooooooooo08Sooooo4ol000000ooooooo
0000o`000003oooooaWo0000Soooool001cooooo00?o0000ooooooooool0QooooolIo`000004oooo
ool0003o0000oooooaKo0000Soooool001cooooo00?o0000ooooooooool0QooooolAo`0000?ooooo
0_l000000ooooooo0000o`000004ooooo`[o000000?oooooo`000?l000002ol0002=ooooo`007?oo
ool00ol0003oooooooooo`26oooooaGo000000Coooooo`000?l0003o00001_oooolHo`0008cooooo
000Looooo`;o0000QooooolEo`000003ooooool0003o000000?o00001?oooolHo`0008cooooo000L
ooooo`03o`000?oooooooooo08Cooooo4Ol00003ooooo`Co00000oooool2o`0000Oooooo5_l0002;
ooooo`007?ooool00ol0003oooooooooo`24ooooo`oo000000?oooooo`000?l000001?ooool2o`00
00cooooo5_l0002;ooooo`007?ooool00ol0003oooooooooo`24ooooo`Go000000?oooooo`000?l0
00001ol000000ooooooo0000o`00000<ooooo`;o00001_oooolDo`0008_ooooo000Looooo`03o`00
0?oooooooooo08?ooooo1_l000000ooooooo0000o`000004o`0000_ooooo0_l00005ooooo`;o0000
0_ooool2o`000003ooooool0003o000001Oo0000Qoooool001cooooo00?o0000ooooooooool0P_oo
ool5o`0000?ooooo0_l0000<ooooo`;o000000Coooooo`000?l0003ooooo0_l00006ooooo`;o0000
00?oooooo`000?l000000ooooolHo`0008?ooooo000Looooo`03o`000?oooooooooo08;ooooo1Ol0
0004ooooo`;o00002oooool2o`0000Cooooo0_l00004ooooo`;o00002Oooool5o`000003ooooool0
003o000000Ko000000?oooooo`000?l000002_l0001oooooo`007?ooool00ol0003oooooooooo`22
ooooo`Co00000oooool4o`0000gooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l0000B
ooooo`;o000000?oooooo`000?l000004?l0001looooo`007?ooool00ol0003oooooooooo`21oooo
o`Co00001?ooool4o`0000Kooooo0_l000000ooooooo0000o`000002ooooo`[o00004oooool3o`00
00?ooooo0_l000001?oooooo0000o`000?ooool<o`0007[ooooo000Looooo`03o`000?oooooooooo
07kooooo1ol00006ooooo`;o00001Oooool3o`000003ooooool0003o000000Cooooo0ol000000ooo
oooo0000o`00000?ooooo`;o00001?ooool2o`0000Oooooo0_l000000ooooooo0000o`00000:o`00
07[ooooo000Looooo`03o`000?oooooooooo07kooooo1_l00002ooooo`;o00002_ooool2o`000004
ooooool0003o0000o`0000Cooooo0_l0000Cooooo`;o00003_ooool2o`000003ooooool0003o0000
00Wo0000N_ooool001cooooo00?o0000ooooooooool0O_ooool6o`000004ooooool0003o0000o`00
00_ooooo1?l0000Cooooo`;o00000oooool5o`000003ooooool0003o000000;o00002?ooool2o`00
0003ooooool0003o000000Wo000000Coooooo`000?l0003o0000M_ooool001cooooo00?o0000oooo
ooooool0O_ooool5o`0000;ooooo0_l0000:ooooo`Co00005Oooool2o`0000?ooooo1Ol000000ooo
oooo0000o`000002o`000003ooooool0003o000000?ooooo0_l00004ooooo`oo0000MOooool001co
oooo00?o0000ooooooooool0L?ooool2o`0000[ooooo1_l00004ooooo`;o00002Oooool2o`0001Ko
oooo0_l0000?ooooo`;o00000oooool2o`0000Cooooo3ol0001eooooo`007?ooool00ol0003ooooo
ooooo`1[ooooo`[o00001_ooool6o`0000Cooooo0ol00002ooooo`;o00001Oooool2o`0000?ooooo
0_l0000@ooooo`?o000000?oooooo`000?l000001Oooool2o`0000Cooooo0_l00007oooooa?o0000
M?ooool001cooooo00?o0000ooooooooool0JOooool=o`0000Cooooo2?l00003ooooo`;o00000ooo
ool2o`0000[ooooo1?l0000;ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000Gooooo
0ol00003ooooo`;o00001ooooolCo`0007Cooooo000Looooo`;o0000J_ooool?o`000003ooooool0
003o000000Oo00002Oooool2o`0000[ooooo0ol00003ooooo`;o00001_ooool2o`0000gooooo1?l0
0006ooooo`;o00001Oooool@o`000003ooooool0003o0000077ooooo000Looooo`03o`000?oooooo
oooo06Wooooo0_l000000ooooooo0000o`00000Bo`0000Cooooo0ol00004ooooo`;o00002?ooool2
o`0000Kooooo0_l0000=ooooo`Co00000_ooool2o`0000;ooooo0_l00006ooooo`;o00001Oooool2
o`000003ooooool0003o000000ko0000LOooool001cooooo00?o0000ooooooooool0J?oooolGo`00
00Gooooo0ol00005ooooo`;o000000?oooooo`000?l000001?ooool4o`0000Kooooo0ol0000:oooo
o`Co00000_ooool2o`0000[ooooo0_l00009ooooo`oo0000LOooool001cooooo00?o0000oooooooo
ool0I_oooolIo`0000Kooooo0_l00004ooooo`?o000000?oooooo`000?l000001?ooool4o`0000?o
oooo0_l000001?oooooo0000o`000?l00005ooooo`;o00001Oooool2o`0000?ooooo0_l00009oooo
o`;o00002Oooool@o`00073ooooo000Looooo`03o`000?oooooooooo06Gooooo6_l0000<ooooo`;o
00001?ooool2o`0000Oooooo1ol00004ooooo`Co00001_ooool2o`0000;ooooo0_l00009ooooo`;o
00000oooool2o`0000Kooooo3ol0001_ooooo`007?ooool00ol0003oooooooooo`1ToooooaWo0000
5?ooool2o`0000Oooooo1Ol00002ooooo`;o00000_ooool2o`0000Sooooo0_l00007ooooo`;o0000
1_ooool2o`000003ooooool0003o000000Sooooo3Ol0001_ooooo`007?ooool00ol0003ooooooooo
o`1ToooooaSo00002?ooool2o`00013ooooo0_l00003ooooo`;o00001?ooool2o`0000;ooooo0_l0
00000ooooooo0000o`00000=ooooo`?o00001_ooool2o`0000gooooo2ol0001_ooooo`007?ooool0
0ol0003oooooooooo`1Soooooa_o00001_ooool2o`00013ooooo0_l00007ooooo`;o00001?ooool2
o`000003ooooool0003o000000gooooo0ol00004ooooo`;o00002?ooool2o`0000Gooooo2ol0001_
ooooo`007?ooool00ol0003oooooooooo`1SoooooaOo00000_ooool2o`0000;ooooo0_l00002oooo
o`;o00006Oooool2o`0000Cooooo0_l0000Booooo`?o00000_ooool2o`0000?ooooo0_l00003oooo
o`;o00000_ooool2o`0000;ooooo2_l0001_ooooo`007?ooool00ol0003oooooooooo`1SoooooaOo
00001_ooool2o`0000;ooooo0_l0000;ooooo`;o00000oooool2o`0000Wooooo0_l00005ooooo`;o
00003oooool3o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Co
oooo2?l0001_ooooo`007?ooool00ol0003oooooooooo`1SoooooaOo00002Oooool4o`0000[ooooo
0_l00003ooooo`;o00001oooool4o`0000Gooooo0_l00007ooooo`;o00002_ooool4o`0000?ooooo
1?l00004ooooo`;o00001oooool2o`000003ooooool0003o000000?o0000K?ooool001cooooo00?o
0000ooooooooool0HooooolEo`0000Sooooo0_l000000ooooooo0000o`000002o`0000Gooooo0ol0
00001?oooooo0000o`000?l00003ooooo`;o00001Oooool5o`0000oooooo0_l0000:ooooo`?o0000
1?ooool4o`0000Cooooo0_l0000:ooooo`Oo0000J_ooool001cooooo00?o0000ooooooooool0H_oo
oolCo`000003ooooool0003o000000Sooooo0_l000000ooooooo0000o`000003o`0000Cooooo0ol0
00000ooooooo0000o`000002ooooo`;o00001oooool2o`000003ooooool0003o000001oooooo1_l0
0005ooooo`Co00002_ooool8o`0006Oooooo000Looooo`03o`000?oooooooooo06;ooooo1Ol00002
ooooo`_o00001_ooool2o`0000Sooooo1?l00004ooooo`;o00001_ooool3o`0001kooooo0_l0000:
ooooo`Co00001?ooool7o`0000;ooooo0_l00006ooooo`;o00000oooool5o`0006Gooooo00001_oo
ooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?oo
ool00ol0003oooooooooo`1Rooooo`Go00000_ooool7o`0000[ooooo0_l0000@ooooo`;o00001ooo
ool2o`0000Sooooo0_l0000:ooooo`?o00000oooool2o`0000;ooooo0_l0000>ooooo`Wo00000_oo
ool4o`0000?ooooo1?l00006ooooo`Co0000I?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Rooooo`Co0000
00?oooooo`000?l000001_l00006ooooo`;o00002?ooool2o`0000_ooooo0_l00007ooooo`;o0000
2?ooool2o`0000Cooooo0_l00004ooooo`?o00000oooool2o`0001;ooooo1?l00007ooooo`Go0000
0_ooool4o`0000?ooooo0_l00002ooooo`?o0000I?ooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02Oooool5o`0000Kooooo00?o0000ooooooooool0H_ooool9o`0000;ooooo0_l0
0006ooooo`;o00001_ooool4o`0002Cooooo0_l0000Uooooo`;o00001?ooool3o`0000Wooooo0ol0
0002ooooo`?o0000Hoooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool0
1?m4A4CogMgMooooool00007ooooo`?o0000H_ooool5o`0000;ooooo0_l00002ooooo`;o00003_oo
ool4o`0000oooooo0_l0000Eooooo`;o00000_ooool2o`0001Kooooo0ol00006ooooo`;o00002ooo
ool2o`0000Cooooo0_l00002ooooo`Co0000H_ooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool02Oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo06;ooooo1?l0
0007ooooo`;o00003oooool3o`0000oooooo0_l0000Booooo`;o000000?oooooo`000?l000000_oo
ool2o`0001Cooooo1Ol000000ooooooo0000o`00000>ooooo`[o00000_ooool5o`00067ooooo0000
0ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oMgMgolc<c?l000001oooool0
0ol0003oooooooooo`1Rooooo`Go00005oooool2o`000003ooooool0003o0000027ooooo0_l00007
ooooo`;o00004?ooool4o`0000Cooooo0_l00007ooooo`?o000000?oooooo`000?l000004_l0001Q
ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o
0000ooooooooool0H_ooool5o`0000_ooooo0_l00009ooooo`;o00000_ooool8o`0002Cooooo0_l0
0003ooooo`?o000000?oooooo`000?l000001oooool4o`0000Gooooo0_l00006ooooo`?o000000Co
ooooo`000?l0003o00000_ooool?o`00067ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPgo
oooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`1Tooooo`;o00003?ooool2o`0000Wo
oooo0_l00004ooooo`Ko00002?ooool2o`0000Oooooo0_l0000;ooooo`?o00002?ooool3o`000003
ooooool0003o0000013ooooo0_l0000?ooooo`oo0000HOooool001cooooo00?o0000ooooooooool0
Hoooool3o`00023ooooo0ol00008ooooo`;o00001oooool2o`0000Cooooo0_l00005ooooo`?o0000
2oooool2o`0000_ooooo0_l00005ooooo`;o00002?ooool2o`0000;ooooo4Ol0001Qooooo`007?oo
ool00ol0003oooooooooo`1Sooooo`;o00008Oooool2o`0000Kooooo0ol0000?ooooo`;o00004Ooo
ool4o`0000_ooooo0_l00005ooooo`Co00001_ooool2o`0000;ooooo4Ol0001Qooooo`007?ooool0
0ol0003oooooooooo`1Sooooo`?o00002oooool2o`0000Gooooo0_l00006ooooo`;o00001?ooool2
o`0000Kooooo0ol0000Cooooo`?o00003?ooool2o`0000Wooooo0_l0000;ooooo`;o00001?ooool2
o`0000Gooooo4?l0001Qooooo`007?ooool00ol0003oooooooooo`1Oooooo`;o00000_ooool4o`00
00;ooooo0_l00006ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Kooooo0_l0000Noooo
o`;o000000?oooooo`000?l000000_l00003ooooo`;o00004_ooool2o`00017ooooo0_l00004oooo
oa7o0000HOooool001cooooo00?o0000ooooooooool0GOooool:o`0000;ooooo0_l000000ooooooo
0000o`000002o`0000Cooooo0_l0000Dooooo`;o00005?ooool2o`000003ooooool0003o000000Go
oooo0_l0000Hooooo`;o00000oooool4o`000003ooooool0003o000000;ooooo0_l00003oooooa3o
0000H_ooool001cooooo00?o0000ooooooooool0F_ooool;o`0000Oooooo1?l00007ooooo`;o0000
4Oooool2o`0000Sooooo0_l00002ooooo`;o00006Oooool2o`000003ooooool0003o000000cooooo
2Ol000000ooooooo0000o`000002ooooo`;o00001?ooool@o`00067ooooo000Looooo`03o`000?oo
oooooooo05Wooooo3Ol00004ooooo`;o00002oooool2o`0001Cooooo0_l00004ooooo`?o00000_oo
ool2o`0000Kooooo0_l0000Aooooo`Go00000oooool4o`0000?ooooo0_l000000ooooooo0000o`00
0002o`0000Oooooo0_l000000ooooooo0000o`00000Co`00067ooooo000Looooo`03o`000?oooooo
oooo05Sooooo3_l00004ooooo`;o00002?ooool2o`000003ooooool0003o000000Oooooo0_l00002
ooooo`;o00001oooool2o`0000Cooooo0_l0000;ooooo`;o00004oooool2o`0000Cooooo1?l00003
ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Gooooo5ol0001Rooooo`007?ooool00ol0
003oooooooooo`1Gooooo`oo00001oooool5o`0000;ooooo0_l000000ooooooo0000o`000007oooo
o`;o000000Coooooo`000?l0003o00001?ooool2o`000003ooooool0003o000000oooooo0_l00003
ooooo`;o00003Oooool2o`0000oooooo0_l00003ooooo`?o00000_ooool2o`000004ooooool0003o
0000o`0000Gooooo3Ol0001Tooooo`007?ooool00ol0003oooooooooo`1Eoooooa7o00001oooool5
o`0000Gooooo0_l00002ooooo`;o00001_ooool2o`0000Gooooo0_l000000ooooooo0000o`000002
o`0000gooooo0_l00003ooooo`;o00003Oooool2o`0000Sooooo0_l00005ooooo`;o00000oooool2
o`0000?ooooo0_l000001?oooooo0000o`000?l00005ooooo`go0000I?ooool001cooooo00?o0000
ooooooooool0EOooool@o`0000Oooooo1?l00007ooooo`;o00000_ooool2o`0000_ooooo1?l00003
ooooo`;o0000:oooool2o`000003ooooool0003o000000;o00001Oooool2o`0000Kooooo0ol00003
ooooo`;o00000_ooool;o`0006Cooooo000Looooo`;o0000E_ooool@o`0000;ooooo0_l000000ooo
oooo0000o`000002o`0000Kooooo0_l00003ooooo`;o00000oooool2o`0000Sooooo1?l000000ooo
oooo0000o`000002ooooo`;o0000:?ooool2o`0000;ooooo1?l00002ooooo`;o00003oooool2o`00
00;ooooo2Ol0001Vooooo`007?ooool00ol0003oooooooooo`1Coooooa;o00000_ooool2o`000003
ooooool0003o000000;o000000?oooooo`000?l000000_l000000ooooooo0000o`000003ooooo`;o
00000oooool3o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l000000_ooool2o`0002So
oooo0ol00002ooooo`;o00000_ooool3o`0001?ooooo2Ol0001Vooooo`007?ooool00ol0003ooooo
ooooo`1Boooooa?o00001Oooool4o`000003ooooool0003o000000;o00003?ooool3o`000003oooo
ool0003o000000Gooooo0_l0000>ooooo`;o00008?ooool2o`0000;ooooo0_l00002ooooo`?o0000
5Oooool2o`0006_ooooo000Looooo`03o`000?oooooooooo057ooooo5?l00006ooooo`;o00000ooo
ool2o`0000kooooo0_l0000Aooooo`;o00001Oooool2o`0002Cooooo0_l00004ooooo`;o00002Ooo
ool2o`0000[ooooo0_l0001Zooooo`007?ooool00ol0003oooooooooo`1AoooooaKo00001oooool2
o`0001Kooooo0_l00003ooooo`;o00001_ooool2o`0000cooooo0_l0000Sooooo`?o00001_ooool4
o`0000?ooooo1Ol00002ooooo`Co0000J?ooool001cooooo00?o0000ooooooooool0DOoooolBo`00
00;ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l0000Booooo`;o00000oooool2o`00
00Cooooo0_l00002ooooo`;o00002_ooool2o`00013ooooo0_l0000Booooo`;o00001_ooool2o`00
00Cooooo1_l00002ooooo`Ko0000I_ooool001cooooo00?o0000ooooooooool0D?oooolCo`0000Go
oooo0ol00005ooooo`Co00004Oooool2o`0000[ooooo0_l00002ooooo`;o00007?ooool2o`0001[o
oooo0_l00004ooooo`Co00001oooool4o`0006Gooooo000Looooo`03o`000?oooooooooo053ooooo
4ol00005ooooo`Co000000Coooooo`000?l0003ooooo0_l0000:ooooo`;o00001oooool2o`0000[o
oooo0_l0000:ooooo`;o00005Oooool2o`0000Kooooo0_l00009ooooo`;o00001_ooool2o`000003
ooooool0003o000000Gooooo0_l00002ooooo`;o00000_ooool5o`0006?ooooo000Looooo`03o`00
0?oooooooooo053ooooo4_l00007ooooo`?o000000?oooooo`000?l000000oooool2o`0000Sooooo
0_l0000Dooooo`;o00002Oooool2o`0000;ooooo0_l0000>ooooo`;o000000?oooooo`000?l00000
1_ooool2o`0000Sooooo0ol00009ooooo`;o00001Oooool2o`0000;ooooo0_l00005ooooo`;o0000
Hoooool001cooooo00?o0000ooooooooool0CooooolCo`0000Kooooo0_l00003ooooo`;o00000ooo
ool2o`0000Sooooo0_l00009ooooo`;o00002Oooool2o`0000gooooo0_l0000>ooooo`;o00004Ooo
ool5o`00013ooooo0_l00002ooooo`;o00002?ooool2o`00063ooooo000Looooo`03o`000?oooooo
oooo04oooooo3ol000000ooooooo0000o`000003ooooo`;o00000_ooool3o`0001Cooooo0_l00006
ooooo`;o0000>oooool2o`0000gooooo0_l000000ooooooo0000o`000003o`0000Kooooo0_l00004
ooooo`Co0000G_ooool001cooooo00?o0000ooooooooool0Coooool4o`000003ooooool0003o0000
00co00000_ooool2o`0000?ooooo0ol0000Cooooo`;o00002oooool4o`0003;ooooo1?l00007oooo
o`;o00001?ooool2o`000003ooooool0003o000000;o00001oooool4o`0000Cooooo0_l0001Noooo
o`007?ooool00ol0003oooooooooo`1@ooooo`;o000000?oooooo`000?l000002_l000000ooooooo
0000o`000007ooooo`?o00001?ooool2o`0001Oooooo0_l000000ooooooo0000o`000002o`0000Co
oooo0_l0000/ooooo`;o000000?oooooo`000?l000000oooool2o`000003ooooool0003o000000;o
oooo0_l00003ooooo`;o00001_ooool2o`0000;ooooo0ol00005ooooo`;o0000GOooool001cooooo
00?o0000ooooooooool0D?ooool2o`000003ooooool0003o000000[o000000?oooooo`000?l00000
1_ooool2o`0000Kooooo0_l0000Gooooo`;o00002Oooool2o`0002oooooo0_l00003ooooo`;o0000
1Oooool2o`0000?ooooo0_l00005ooooo`?o00000_ooool3o`000003ooooool0003o000000;ooooo
0ol0001Looooo`007?ooool00ol0003oooooooooo`1?ooooo`?o00000oooool8o`0000?ooooo0_l0
0006ooooo`Co00000oooool2o`0000Oooooo0_l0000;ooooo`Co0000B?ooool2o`0000[ooooo0_l0
0002ooooo`Oo00000oooool3o`0005_ooooo000Looooo`03o`000?oooooooooo04oooooo1?l00006
ooooo`Co00002?ooool2o`0000;ooooo0ol00003ooooo`;o00001oooool2o`0000_ooooo1?l0000T
ooooo`;o00002?ooool2o`0001Oooooo0ol00006ooooo`;o00001_ooool>o`0005[ooooo000Loooo
o`;o0000DOooool4o`0000Gooooo0_l0000:ooooo`?o000000Coooooo`000?l0003o00000oooool2
o`0000Sooooo0_l00006ooooo`;o0000:_ooool3o`0000Oooooo0_l0000Gooooo`;o00000oooool2
o`0000;ooooo0_l00005oooooa3o0000FOooool001cooooo00?o0000ooooooooool0D?ooool4o`00
00Gooooo0ol00009ooooo`Ko00001?ooool2o`000003ooooool0003o000000Gooooo0_l000000ooo
oooo0000o`000003ooooo`;o00003_ooool2o`0000;ooooo0_l0000Gooooo`;o00000oooool2o`00
023ooooo0_l00008oooooa7o0000FOooool001cooooo00?o0000ooooooooool0DOooool4o`0000Co
oooo0ol0000:ooooo`Go00001oooool2o`000003ooooool0003o000000Gooooo0_l0000Cooooo`;o
00000_ooool2o`0001cooooo0_l0000Mooooo`;o00000oooool5o`0000?ooooo4_l0001Hooooo`00
7?ooool00ol0003oooooooooo`1Booooo`?o00000_ooool2o`000003ooooool0003o000000;o0000
1oooool3o`0000cooooo1ol00008ooooo`;o0000=Oooool2o`0000gooooo0_l00007ooooo`;o0000
0oooool5o`0000;ooooo0_l000000ooooooo0000o`00000>o`0005Sooooo000Looooo`03o`000?oo
oooooooo05;ooooo1?l000001?oooooo0000o`000?ooool6o`000003ooooool0003o000000;ooooo
1?l0000;ooooo`;o000000?oooooo`000?l000000_l00008ooooo`;o0000<_ooool2o`000003oooo
ool0003o000000gooooo0_l00007ooooo`;o00001?ooool2o`0000?ooooo5?l0001Hooooo`007?oo
ool00ol0003oooooooooo`1Dooooo`Co000000Coooooo`000?l0003o00000_ooool2o`000004oooo
ool0003o0000ooooo`Go00000_ooool2o`0002Gooooo0_l0000Sooooo`;o00000oooool2o`0001Oo
oooo0_l00005oooooaGo0000F?ooool001cooooo00?o0000ooooooooool0EOooool6o`000003oooo
ool0003o000000Cooooo1_l000000ooooooo0000o`000002o`0001oooooo0_l00004ooooo`;o0000
3?ooool2o`0000cooooo0_l0000<ooooo`Co00005Oooool2o`0000Gooooo5Ol0001Hooooo`007?oo
ool00ol0003oooooooooo`1Fooooo`Go000000?oooooo`000?l000001?ooool2o`000003ooooool0
003o000000;ooooo0_l0000Qooooo`;o00004_ooool2o`0000cooooo0_l000000ooooooo0000o`00
000:ooooo`?o00002_ooool2o`00017ooooo5?l0001Hooooo`007?ooool00ol0003oooooooooo`1G
ooooo`Ko00001_ooool2o`0000;ooooo0_l0000Hooooo`;o000000Coooooo`000?l0003ooooo0_l0
000Xooooo`;o00001oooool2o`000003ooooool0003o000000_ooooo0_l0000Aoooooa?o0000FOoo
ool001cooooo00?o0000ooooooooool0F_ooool4o`000003ooooool0003o000000;ooooo0_l00002
ooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00001_ooool2o`000004ooooool0003o
0000ooooo`;o00001?ooool2o`0001Gooooo0_l0000Dooooo`?o00001Oooool2o`0000_ooooo0_l0
0008ooooo`;o000000?oooooo`000?l000004_l0001Iooooo`007?ooool00ol0003oooooooooo`1K
ooooo`Wo00001Oooool2o`0000;ooooo1?l00002ooooo`?o00000oooool2o`0000Gooooo0_l00009
ooooo`Co00005Oooool2o`0001Gooooo1?l00003ooooo`;o00001?ooool2o`0000Cooooo0ol00004
ooooo`;o00000_oooolGo`0005Wooooo000Looooo`03o`000?oooooooooo05gooooo2?l000001?oo
oooo0000o`000?ooool3o`0000?ooooo0_l00003ooooo`;o00002_ooool2o`0000Wooooo0_l0000/
ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`Co00001?ooool2o`0000Gooooo0_l00004
oooooaGo0000FOooool001cooooo00?o0000ooooooooool0H?ooool2o`000003ooooool0003o0000
00?o00000_ooool2o`0000Sooooo0_l0000_ooooo`;o00002_ooool2o`0000?ooooo0_l000000ooo
oooo0000o`000003ooooo`;o00000_ooool2o`000003ooooool0003o000000;o00002ooooolKo`00
05[ooooo000Looooo`03o`000?oooooooooo06?ooooo0ol0000>ooooo`?o00002_ooool2o`0000;o
oooo0_l0000Nooooo`;o00002_ooool2o`0000?ooooo0_l00004ooooo`Go00001?ooool2o`0000Ko
oooo0_l00002ooooo`;o000000?oooooo`000?l000001Ol000000ooooooo0000o`00000Ao`0005[o
oooo000Looooo`03o`000?oooooooooo06?ooooo1ol00007ooooo`;o00000_ooool2o`0000[ooooo
0_l00002ooooo`;o00002?ooool2o`00017ooooo0_l0000>ooooo`;o00002?ooool2o`000004oooo
ool0003o0000ooooo`Co00001oooool2o`0000;ooooo0_l0000:oooooa7o0000Foooool001cooooo
00?o0000ooooooooool0IOooool5o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o0000
6?ooool2o`0000Gooooo0_l0000:ooooo`;o00000_ooool2o`0000[ooooo0_l0000;ooooo`;o0000
00?oooooo`000?l000000_l0000;ooooo`Ko00001_ooool?o`0005gooooo000Looooo`;o0000Iooo
ool4o`000003ooooool0003o000000;o00002Oooool2o`000003ooooool0003o000001Wooooo0_l0
0009ooooo`;o00000oooool2o`0001;ooooo0_l0000Eooooo`So00001?ooool=o`0005oooooo000L
ooooo`03o`000?oooooooooo06Oooooo2?l000000ooooooo0000o`000006ooooo`;o000000?ooooo
o`000?l000001?ooool2o`0000Gooooo0_l0000Gooooo`;o00005Oooool4o`0000_ooooo0_l0000;
ooooo`;o000000Coooooo`000?l0003ooooo3Ol0001Rooooo`007?ooool00ol0003oooooooooo`1W
ooooo`Oo00000_ooool2o`0000Cooooo0_l00007ooooo`Co00000_ooool2o`000003ooooool0003o
000002;ooooo0_l0000:ooooo`;o00001?ooool2o`0000Oooooo1?l000000ooooooo0000o`000004
ooooo`Co00001?ooool=o`0006;ooooo000Looooo`03o`000?oooooooooo06Oooooo2?l00007oooo
o`;o00001oooool2o`0000Cooooo0_l0000Uooooo`;o00004?ooool2o`0000Oooooo1?l000000ooo
oooo0000o`000004ooooo`Co00000_ooool2o`000003ooooool0003o000000Oo0000IOooool001co
oooo00?o0000ooooooooool0I_ooool:o`000003ooooool0003o000000Oooooo0_l00012ooooo`?o
00001_ooool2o`0000cooooo1Ol000000ooooooo0000o`000004o`0006Sooooo000Looooo`03o`00
0?oooooooooo06Kooooo3Ol00007ooooo`;o00003Oooool2o`0000Oooooo0_l0000Zooooo`?o0000
3?ooool2o`0000Kooooo1_l00002ooooo`Co0000J?ooool001cooooo00?o0000ooooooooool0I_oo
ool;o`0000Oooooo0_l0000=ooooo`Co00001oooool2o`0000[ooooo0_l0000Dooooo`Co00003?oo
ool2o`0000Oooooo0_l00007ooooo`;o000000?oooooo`000?l000001Ol0001Yooooo`007?ooool0
0ol0003oooooooooo`1Uooooo`co00001oooool2o`0000gooooo0_l0000;ooooo`;o000000?ooooo
o`000?l000001Oooool2o`0001Cooooo1?l0000<ooooo`;o00001?ooool2o`000003ooooool0003o
000000Gooooo0_l00005ooooo`Ko0000J?ooool001cooooo00?o0000ooooooooool0IOooool=o`00
01?ooooo0_l00004ooooo`;o00001oooool2o`000003ooooool0003o0000013ooooo0_l0000Ooooo
o`;o000000?oooooo`000?l000000ol00002ooooo`;o00001oooool4o`0006Sooooo000Looooo`03
o`000?oooooooooo06Gooooo3Ol0000>ooooo`Co000000?oooooo`000?l000001?ooool2o`0000;o
oooo0_l0000?ooooo`;o00001?ooool2o`000003ooooool0003o000000;ooooo0_l0000Kooooo`;o
00000oooool4o`0000[ooooo0ol0001Yooooo`007?ooool00ol0003oooooooooo`1Uooooo`go0000
1_ooool2o`000003ooooool0003o000000?ooooo1?l000000ooooooo0000o`000005ooooo`;o0000
00?oooooo`000?l000003Oooool4o`0000Cooooo0ol00004ooooo`;o00005_ooool2o`0000Sooooo
1_l00007ooooo`Go0000J?ooool001cooooo00?o0000ooooooooool0IOooool=o`0000Cooooo1?l0
00000ooooooo0000o`000002o`0000gooooo0_l00002ooooo`;o00003?ooool4o`0000Gooooo0_l0
000Looooo`;o00001_ooool2o`0000;ooooo1_l00005ooooo`Go0000J?ooool001cooooo00?o0000
ooooooooool0IOooool>o`0000?ooooo0ol00002ooooo`Co00001_ooool2o`0000Oooooo1?l00002
ooooo`;o00002?ooool2o`000003ooooool0003o000000Oooooo0_l0000;ooooo`;o000000Cooooo
o`000?l0003ooooo0_l0000>ooooo`;o00000_ooool8o`000004ooooool0003o0000ooooo`Co0000
J?ooool001cooooo00?o0000ooooooooool0IOooool>o`0000?ooooo0_l000000ooooooo0000o`00
0002o`0000Sooooo0_l00007ooooo`;o00001?ooool2o`0000Sooooo0_l000000ooooooo0000o`00
0007ooooo`;o00000_ooool4o`0000Gooooo0_l000001?oooooo0000o`000?ooool2o`00017ooooo
0_l000000ooooooo0000o`000004o`000004ooooool0003o0000ooooo`Co0000J?ooool00006oooo
ooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006
ooooo`03o`000?oooooooooo06Gooooo3Ol00004ooooo`;o000000?oooooo`000?l000000ol0000Z
ooooo`;o00001?ooool4o`0000Kooooo0_l00003ooooo`;o00001Oooool2o`0000[ooooo0_l00003
ooooo`;o00001_ooool4o`0006Sooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ
8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1Vooooo`go0000
1_ooool5o`000004ooooool0003o0000o`0002Kooooo0_l00002ooooo`;o00000oooool2o`0000Co
oooo0ol00003ooooo`;o00001Oooool2o`0000;ooooo0_l00007ooooo`;o00002?ooool2o`000004
ooooool0003o0000o`0006Sooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wo
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo06Kooooo3Ol00006oooo
o`?o00000oooool4o`0000Cooooo0_l0000Sooooo`;o00000oooool2o`0000Cooooo0_l0000:oooo
o`;o00000oooool2o`0000Oooooo1_l00004ooooo`Ko0000J?ooool00003ooooool0003ooooo00;o
oooo00?o0000ooooooooool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0001Woooo
o`co00001Oooool4o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`;o00001_ooool2o`00
02Wooooo0_l00007ooooo`;o00002oooool2o`000003ooooool0003o000000;o00001Oooool5o`00
06Sooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oeEEEOl0
003o410@olc<c006ooooo`03o`000?oooooooooo06Oooooo3_l00002ooooo`?o00001?ooool2o`00
00;ooooo0_l00006ooooo`;o00000oooool2o`0000kooooo0_l00006ooooo`;o00003oooool4o`00
017ooooo0_l000000ooooooo0000o`000009o`000003ooooool0003o000000?o0000J?ooool00003
ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03
o`000?oooooooooo06Sooooo3Ol00002ooooo`;o00001Oooool2o`0000;ooooo0_l00006ooooo`Co
00002Oooool2o`0000Gooooo0ol00006ooooo`;o00003oooool2o`0000Oooooo0_l00009ooooo`?o
00000_ooool@o`0006Sooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@
4?nHV9P02?ooool00ol0003oooooooooo`1Wooooo`co00001oooool2o`0000Cooooo0_l000000ooo
oooo0000o`000004ooooo`;o000000?oooooo`000?l000002Oooool2o`0000?ooooo1?l0000Doooo
o`;o00000_ooool3o`0000Kooooo0_l00002ooooo`;o00001Oooool2o`000003ooooool0003o0000
00;ooooo3_l0001Xooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co
0000oa0@40Kooooo00?o0000ooooooooool0Ioooool<o`0000Kooooo1Ol00002ooooo`;o000000?o
ooooo`000?l000001?ooool2o`0000_ooooo0_l00004ooooo`;o000000?oooooo`000?l000004?oo
ool2o`000003ooooool0003o000000;ooooo0ol00006ooooo`;o00000_ooool3o`0000Oooooo3ol0
00000ooooooo0000o`00001Xooooo`007?ooool00ol0003oooooooooo`1Xooooo`Ko000000?ooooo
o`000?l000002?ooool7o`0001Kooooo0_l00007ooooo`;o00001oooool2o`0000Cooooo0_l00000
0ooooooo0000o`000002ooooo`?o00002?ooool3o`000003ooooool0003o000000;o00001?oooolC
o`0006[ooooo000Looooo`03o`000?oooooooooo06Sooooo2ol00002ooooo`;o00000oooool6o`00
017ooooo0_l00002ooooo`;o00001?ooool2o`0000Cooooo0_l000000ooooooo0000o`000002oooo
o`;o00000oooool3o`0000Gooooo0ol00008ooooo`Ko00001_oooolCo`0006[ooooo000Looooo`03
o`000?oooooooooo06Sooooo2?l000000ooooooo0000o`000002ooooo`;o00001Oooool2o`0000go
oooo0_l00004ooooo`;o00000_ooool2o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l0
00001oooool2o`0001Cooooo1?l00004oooooaCo0000J_ooool001cooooo00?o0000ooooooooool0
J?ooool9o`0000kooooo0_l00007ooooo`;o000000?oooooo`000?l000002?ooool2o`0001oooooo
0_l0000:ooooo`;o000000?oooooo`000?l000001?oooolDo`0006[ooooo000Looooo`03o`000?oo
oooooooo06Wooooo2?l00006ooooo`;o00000_ooool6o`0000Oooooo0_l0000Jooooo`;o00004?oo
ool2o`0000[ooooo0_l00005ooooo`;o000000?oooooo`000?l000004Ol0001Zooooo`007?ooool0
0ol0003oooooooooo`1Zooooo`_o00000_ooool2o`0000;ooooo1?l0000;ooooo`Co00005Oooool3
o`0000_ooooo0_l00007ooooo`;o00003OoooolEo`0006_ooooo000Looooo`03o`000?oooooooooo
06_ooooo2_l00006ooooo`;o00003Oooool4o`0000Gooooo0_l00006ooooo`;o00001_ooool4o`00
00Sooooo1?l00005ooooo`Co00001Oooool2o`0000Gooooo5_l0001[ooooo`007?ooool00ol0003o
ooooooooo`1/ooooo`[o00000_ooool2o`0000Wooooo0_l0000>ooooo`;o00001_ooool2o`0000Go
oooo0_l000000ooooooo0000o`000002o`0000Kooooo0_l00007ooooo`;o00001oooool2o`0000Go
oooo1_l000000ooooooo0000o`00000<o`0006cooooo000Looooo`03o`000?oooooooooo06cooooo
2ol000001?oooooo0000o`000?l00008ooooo`;o00001_ooool2o`0000[ooooo0_l00009ooooo`;o
00000oooool2o`0000_ooooo0ol00003ooooo`;o00001?ooool2o`0000Gooooo5?l0001^ooooo`00
7?ooool00ol0003oooooooooo`1]ooooo`ko00001_ooool2o`0000Sooooo1?l00008ooooo`;o0000
2?ooool3o`000003ooooool0003o000000Kooooo0_l00005ooooo`?o00000oooool2o`0000Cooooo
0_l00005oooooaCo0000K_ooool001cooooo00?o0000ooooooooool0KOooool<o`0000?ooooo0_l0
0003ooooo`;o00002_ooool3o`0000Cooooo0ol00003ooooo`;o00001Oooool3o`000003ooooool0
003o000000Kooooo0_l00003ooooo`;o000000?oooooo`000?l000000oooool2o`0000_ooooo4ol0
001_ooooo`007?ooool2o`0006kooooo3Ol00002ooooo`;o00001oooool2o`0000Kooooo0ol00004
ooooo`?o00000oooool2o`00013ooooo0ol00003ooooo`;o000000Coooooo`000?l0003ooooo1?l0
000;ooooo`;o000000?oooooo`000?l000003_l0001_ooooo`007?ooool00ol0003oooooooooo`1^
ooooo`co00002oooool2o`00013ooooo1?l00006ooooo`;o00002Oooool2o`0000[ooooo0_l00000
0ooooooo0000o`000004o`0000Kooooo0_l000000ooooooo0000o`00000:o`0007?ooooo000Loooo
o`03o`000?oooooooooo06kooooo3Ol00003ooooo`;o00005oooool4o`0000Cooooo1?l0000:oooo
o`;o00001_ooool2o`0000Cooooo1_l00002ooooo`;o00000_ooool2o`000003ooooool0003o0000
00So0000MOooool001cooooo00?o0000ooooooooool0K_ooool=o`0000?ooooo0_l00008ooooo`;o
00002?ooool3o`0000Gooooo0ol00002ooooo`?o00002oooool2o`0000Kooooo0_l00005ooooo`;o
00001Oooool2o`0000;ooooo0_l00002ooooo`Wo0000MOooool001cooooo00?o0000ooooooooool0
Koooool>o`0000Oooooo0_l00002ooooo`;o00002?ooool3o`0000?ooooo1Ol0000=ooooo`;o0000
1Oooool2o`0001Cooooo0_l00003ooooo`Oo0000M_ooool001cooooo00?o0000ooooooooool0L?oo
ool>o`0000Kooooo0_l00006ooooo`;o00001?ooool3o`0000;ooooo0ol00008ooooo`;o00000_oo
ool2o`0000;ooooo1?l00002ooooo`?o00001Oooool2o`0000Cooooo0ol00005ooooo`;o0000POoo
ool001cooooo00?o0000ooooooooool0L?ooool>o`0000kooooo0_l00009ooooo`;o00001Oooool2
o`000004ooooool0003o0000o`0000;ooooo0_l00004ooooo`;o00000_ooool3o`0000Gooooo0_l0
0004ooooo`Go00000oooool2o`00087ooooo000Looooo`03o`000?oooooooooo077ooooo3Ol0000@
ooooo`;o00003_ooool2o`000003ooooool0003o000000?ooooo1Ol0000>ooooo`;o00001_ooool2
o`0000?ooooo0_l00021ooooo`007?ooool00ol0003oooooooooo`1aoooooa3o00003Oooool2o`00
00_ooooo0_l00009ooooo`Go00001oooool2o`0000;ooooo1ol00002ooooo`Go00000_ooool2o`00
087ooooo000Looooo`03o`000?oooooooooo077ooooo4?l00006ooooo`;o00000_ooool7o`0000Wo
oooo0ol000000ooooooo0000o`00000:ooooo`;o00001OoooolBo`0008Gooooo000Looooo`03o`00
0?oooooooooo077ooooo3Ol00004ooooo`;o00000oooool2o`0000;ooooo1ol0000:ooooo`;o0000
00?oooooo`000?l000002_ooool2o`0000Kooooo4?l00026ooooo`007?ooool00ol0003ooooooooo
o`1aooooo`ko00000oooool4o`0000[ooooo0ol000000ooooooo0000o`00000<ooooo`;o00002Ooo
ool2o`0000Cooooo3ol000000ooooooo0000o`000002o`0008;ooooo000Looooo`03o`000?oooooo
oooo07;ooooo3_l00004ooooo`;o00001oooool2o`000005ooooool0003o0000o`000?ooool00_l0
0004ooooo`;o00001_ooool2o`0000Sooooo0ol00003oooooaGo0000P_ooool001cooooo00?o0000
ooooooooool0Loooool=o`0000gooooo0_l00006ooooo`;o00000oooool2o`0000Kooooo0_l00008
ooooo`;o000000?oooooo`000?l000004_l00002ooooo`;o0000P_ooool001cooooo00?o0000oooo
ooooool0Loooool;o`0001Oooooo0_l00006ooooo`;o00000_ooool3o`0000?ooooo0_l00003oooo
o`;o000000?oooooo`000?l000004Ol000001?oooooo0000o`000?l00023ooooo`007?ooool00ol0
003oooooooooo`1cooooo`_o00000oooool5o`0000oooooo0_l00006ooooo`;o00000_ooool2o`00
0003ooooool0003o000000?o00000oooool5o`0000?ooooo4_l00023ooooo`007?ooool2o`0007Co
oooo2ol00003ooooo`Go00003_ooool3o`0000Gooooo0_l00006ooooo`Co00001?ooool4o`0000?o
oooo4?l000000ooooooo0000o`000023ooooo`007?ooool00ol0003oooooooooo`1dooooo`[o0000
1Oooool2o`0000oooooo1Ol00003ooooo`;o00001_ooool2o`0000;ooooo0_l00002ooooo`Co0000
0ooooolCo`0008?ooooo000Looooo`03o`000?oooooooooo07Cooooo0_l000000ooooooo0000o`00
0006o`0000Gooooo1?l0000:ooooo`;o00000_ooool4o`0000;ooooo0_l00006ooooo`;o00000_oo
ool2o`0000;ooooo1?l00003oooooa;o0000Q?ooool001cooooo00?o0000ooooooooool0MOooool>
o`000003ooooool0003o000000;o00001?ooool2o`0000Cooooo0_l00004ooooo`;o000000?ooooo
o`000?l000002?l00007ooooo`;o00001OoooolBo`0008Cooooo000Looooo`03o`000?oooooooooo
07Gooooo3_l00009ooooo`;o000000Coooooo`000?l0003ooooo5Ol00003ooooo`Co00001OoooolA
o`0008Gooooo000Looooo`03o`000?oooooooooo07Oooooo2ol0000=oooooaWo00000_ooool4o`00
00Oooooo2ol00029ooooo`007?ooool00ol0003oooooooooo`1gooooo`ko00001?ooool2o`0000;o
oooo6ol00002ooooo`?o00002oooool8o`0008Wooooo000Looooo`03o`000?oooooooooo07[ooooo
2ol00004ooooo`co000000?oooooo`000?l000005Ol0002Looooo`007?ooool00ol0003ooooooooo
o`1iooooo`go000000?oooooo`000?l000008ol0002Mooooo`007?ooool00ol0003oooooooooo`1i
oooooc;o0000W_ooool001cooooo00?o0000ooooooooool0O?ooool@o`000003ooooool0003o0000
01_o0000Woooool001cooooo00?o0000ooooooooool0OOooool]o`0009oooooo000Looooo`03o`00
0?oooooooooo07kooooo4_l000000ooooooo0000o`00000Fo`000:3ooooo000Looooo`03o`000?oo
oooooooo087ooooo2?l00003ooooo`;o00001_oooolBo`000:?ooooo000Looooo`03o`000?oooooo
oooo09Wooooo2?l00002ooooo`;o0000Y?ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom:ooooo`0000Ko
ooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q
00Kooooo00?o0000ooooooooool0oooooom:ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413o
ooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooo
od[ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P06ooooo`?o0000oooooom:ooooo`0000?oooooo`000?ooool00_ooool00ol0003o
ooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`3ooooo
od[ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go410@okZj^_oo
oooo^[Zjoa0@4006ooooo`03o`000?oooooooooo0?ooooooB_ooool00006oooooomgMgOoV9RHoooo
oonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0oooo
oom:ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT01_ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003o
oooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Booooo`Co000000?o410@ooooooooool00oooool0
0ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`?o0000oooooom:ooooo`00
5?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_oo
ool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooo
oe;ooooo000Booooo`03oeEEEOmVIVKo00000?ooooooE?ooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00:Wooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0G
ooooo`;o000000Co410@oooooooooooooooo1Ol0002Dooooo`00Z_ooool01Ol0003ooooooooooooo
oooo000000Wooooo1_l0000<ooooo`03o`000?oooooooooo00;ooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A02Dooooo`00Z_ooool01Ol0003ooooooooooooooooo000001Sooooo1Ol00004ooooo`03oiRH
V?lQ8B7ok^k^09Gooooo002Zooooo`05o`000?ooooooooooooooool000002Oooool6o`0000Wooooo
00CoA4A4omgMgOoooooo00001_ooool00onHV9So8B4Qonk^kP2Dooooo`00Z_ooool01Ol0003oQhN7
oooooonYZJWo000001Sooooo00CogMgMoeEEEOoooooo00001oooool00omgMgOoIVIVooooo`2Coooo
o`00ZOooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo01Oooooo00?oMgMgolc<c?l0
00002?ooool00ol0003oooooooooo`2Booooo`00b?ooool00oo^k^koA4A4o`000004ooooo`05o`00
0?nj^[[ooooooiRHV?l@4100U?ooool00<Wooooo00?oMgMgo`000?ooool00oooool01OnHV9So410@
o`000?lQ8B7oc<c<09Cooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -20 0 ]
[.5 1.0125 20 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(48) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.73045 .54444 Mdot
.70421 .58078 Mdot
.56641 .28196 Mdot
.34154 .58986 Mdot
.27667 .41328 Mdot
.56275 .28906 Mdot
.71638 .4495 Mdot
.6945 .45478 Mdot
.59841 .28968 Mdot
.33669 .5214 Mdot
.65967 .37573 Mdot
.43201 .71866 Mdot
.71304 .45536 Mdot
.32428 .54777 Mdot
.40163 .71433 Mdot
.5341 .71947 Mdot
.71252 .54578 Mdot
.27385 .41523 Mdot
.56451 .71717 Mdot
.60978 .30605 Mdot
.42916 .33338 Mdot
.33476 .5616 Mdot
.69896 .54914 Mdot
.32732 .54165 Mdot
.56461 .71378 Mdot
.65965 .64831 Mdot
.73058 .54202 Mdot
.55956 .71129 Mdot
.44641 .73021 Mdot
.70339 .47445 Mdot
.54206 .71322 Mdot
.35859 .62981 Mdot
.34927 .35353 Mdot
.61686 .66636 Mdot
.67926 .37962 Mdot
.65634 .38062 Mdot
.54915 .27253 Mdot
.64697 .36527 Mdot
.68746 .4576 Mdot
.67615 .37283 Mdot
.67679 .37671 Mdot
.65911 .64417 Mdot
.66179 .38564 Mdot
.70128 .49521 Mdot
.36835 .66151 Mdot
.6285 .63309 Mdot
.45035 .28962 Mdot
.3576 .69663 Mdot
.72951 .55241 Mdot
.45902 .28097 Mdot
.34177 .65237 Mdot
.71032 .43508 Mdot
.37701 .34095 Mdot
.67972 .62745 Mdot
.71065 .46369 Mdot
.56645 .70988 Mdot
.59604 .31121 Mdot
.3368 .67353 Mdot
.46026 .73456 Mdot
.61696 .65838 Mdot
.33719 .53969 Mdot
.27084 .44492 Mdot
.52164 .69738 Mdot
.60324 .32646 Mdot
.57837 .27888 Mdot
.64337 .34157 Mdot
.68154 .57676 Mdot
.64931 .35359 Mdot
.32581 .58987 Mdot
.46143 .2953 Mdot
.34838 .69906 Mdot
.66025 .37624 Mdot
.63982 .64817 Mdot
.33452 .58247 Mdot
.73236 .56596 Mdot
.65591 .35977 Mdot
.28376 .40851 Mdot
.65293 .64847 Mdot
.48057 .27082 Mdot
.32517 .51369 Mdot
.33989 .55796 Mdot
.70169 .40378 Mdot
.47825 .73297 Mdot
.64992 .6263 Mdot
.36137 .64791 Mdot
.72106 .42178 Mdot
.35507 .57509 Mdot
.54023 .71692 Mdot
.56037 .70612 Mdot
.42843 .7217 Mdot
.52172 .27367 Mdot
.69039 .56597 Mdot
.32964 .57161 Mdot
.31837 .57965 Mdot
.3443 .66106 Mdot
.35879 .64402 Mdot
.5604 .70349 Mdot
.3713 .37 Mdot
.66831 .36942 Mdot
.36501 .33709 Mdot
.65144 .35603 Mdot
.3841 .33562 Mdot
.33488 .60495 Mdot
.573 .30802 Mdot
.66312 .66264 Mdot
.36384 .36794 Mdot
.66109 .36172 Mdot
.32814 .57381 Mdot
.6524 .3757 Mdot
.69346 .56538 Mdot
.54444 .7073 Mdot
.31139 .4251 Mdot
.31483 .40071 Mdot
.71838 .52797 Mdot
.31821 .59459 Mdot
.35716 .55715 Mdot
.33374 .55083 Mdot
.68281 .57413 Mdot
.59836 .29206 Mdot
.50941 .27801 Mdot
.70463 .57331 Mdot
.67176 .3725 Mdot
.71842 .54558 Mdot
.35647 .32696 Mdot
.58752 .28263 Mdot
.35785 .3506 Mdot
.39249 .36432 Mdot
.3478 .6168 Mdot
.35664 .64156 Mdot
.40243 .32876 Mdot
.57078 .30873 Mdot
.70599 .57476 Mdot
.70646 .45514 Mdot
.31543 .57123 Mdot
.64285 .62996 Mdot
.71263 .4653 Mdot
.30113 .41483 Mdot
.32193 .41631 Mdot
.63961 .64276 Mdot
.32493 .60458 Mdot
.64389 .36094 Mdot
.68773 .4357 Mdot
.3371 .66036 Mdot
.63789 .63151 Mdot
.28212 .41436 Mdot
.68659 .43615 Mdot
.33577 .36242 Mdot
.54861 .70101 Mdot
.36777 .72148 Mdot
.70017 .40742 Mdot
.3406 .6599 Mdot
.43378 .32551 Mdot
.28452 .44953 Mdot
.7083 .46643 Mdot
.34827 .58486 Mdot
.71941 .55746 Mdot
.6361 .63764 Mdot
.46327 .7135 Mdot
.35769 .36493 Mdot
.33444 .65098 Mdot
.38844 .33244 Mdot
.38668 .36756 Mdot
.32318 .55461 Mdot
.61952 .64626 Mdot
.64247 .67469 Mdot
.34445 .69372 Mdot
.56186 .26942 Mdot
.27437 .41316 Mdot
.66389 .38255 Mdot
.35621 .65312 Mdot
.34599 .66539 Mdot
.44802 .7118 Mdot
.68991 .43288 Mdot
.68315 .37601 Mdot
.48574 .2795 Mdot
.6478 .34398 Mdot
.68281 .39223 Mdot
.58898 .32254 Mdot
.44339 .72105 Mdot
.31441 .43061 Mdot
.38699 .35368 Mdot
.34327 .69095 Mdot
.36729 .64093 Mdot
.42693 .71885 Mdot
.42552 .33397 Mdot
.42974 .32046 Mdot
.67698 .6002 Mdot
.67235 .39233 Mdot
.3498 .56839 Mdot
.57437 .69516 Mdot
.34753 .63883 Mdot
.6853 .40323 Mdot
.70177 .45138 Mdot
.61722 .3342 Mdot
.61273 .31323 Mdot
.47028 .28062 Mdot
.49231 .71803 Mdot
.44992 .70624 Mdot
.34493 .56792 Mdot
.36697 .34521 Mdot
.52425 .69714 Mdot
.28097 .44914 Mdot
.71519 .5501 Mdot
.70024 .4013 Mdot
.34953 .70973 Mdot
.55512 .72686 Mdot
.56799 .26408 Mdot
.51583 .26912 Mdot
.39822 .35199 Mdot
.29221 .44129 Mdot
.34133 .68229 Mdot
.71474 .53164 Mdot
.33993 .65668 Mdot
.35061 .3502 Mdot
.31949 .39988 Mdot
.70137 .56457 Mdot
.36029 .70027 Mdot
.71609 .4589 Mdot
.54454 .29803 Mdot
.35519 .57547 Mdot
.32927 .57935 Mdot
.65212 .64622 Mdot
.32291 .59159 Mdot
.57245 .70361 Mdot
.54785 .71063 Mdot
.47299 .2835 Mdot
.6576 .35193 Mdot
.69956 .47492 Mdot
.44926 .29027 Mdot
.64711 .63903 Mdot
.74105 .53632 Mdot
.57774 .30305 Mdot
.4259 .34121 Mdot
.65553 .3741 Mdot
.28871 .4266 Mdot
.57219 .30317 Mdot
.2727 .41939 Mdot
.46222 .73673 Mdot
.56451 .30932 Mdot
.30697 .42014 Mdot
.40871 .71314 Mdot
.39182 .3623 Mdot
.32793 .41417 Mdot
.71852 .44992 Mdot
.70833 .58626 Mdot
.33967 .68668 Mdot
.38181 .34429 Mdot
.3537 .34336 Mdot
.44765 .72145 Mdot
.4046 .3589 Mdot
.3674 .36438 Mdot
.44702 .71858 Mdot
.26527 .42249 Mdot
.69022 .39147 Mdot
.54246 .71221 Mdot
.7154 .5463 Mdot
.32933 .59629 Mdot
.6676 .35326 Mdot
.71177 .46615 Mdot
.35179 .54399 Mdot
.71017 .41501 Mdot
.72037 .45016 Mdot
.32696 .54945 Mdot
.69287 .46539 Mdot
.64757 .62783 Mdot
.34808 .70847 Mdot
.63528 .6501 Mdot
.32539 .54679 Mdot
.69017 .46288 Mdot
.4524 .2866 Mdot
.6567 .64099 Mdot
.33301 .56996 Mdot
.34306 .58212 Mdot
.37002 .34484 Mdot
.54654 .70774 Mdot
.73391 .45839 Mdot
.43317 .71902 Mdot
.59195 .32943 Mdot
.48035 .71764 Mdot
.29302 .45281 Mdot
.33477 .36176 Mdot
.63667 .63278 Mdot
.40285 .36169 Mdot
.56987 .2957 Mdot
.34274 .67236 Mdot
.36133 .70686 Mdot
.36581 .6566 Mdot
.37089 .36323 Mdot
.48002 .73231 Mdot
.72811 .46052 Mdot
.56303 .69494 Mdot
.40288 .3315 Mdot
.59188 .30446 Mdot
.37704 .33417 Mdot
.36026 .64529 Mdot
.69493 .55399 Mdot
.54456 .72686 Mdot
.57962 .32271 Mdot
.70083 .55114 Mdot
.35433 .69582 Mdot
.65007 .35267 Mdot
.27259 .45454 Mdot
.72803 .46783 Mdot
.55299 .72047 Mdot
.47638 .71656 Mdot
.46349 .29408 Mdot
.65393 .63549 Mdot
.70128 .46326 Mdot
.63806 .64901 Mdot
.33629 .64796 Mdot
.33568 .63504 Mdot
.63282 .63567 Mdot
.32306 .43241 Mdot
.49442 .27448 Mdot
.65619 .37122 Mdot
.36211 .35099 Mdot
.47468 .29638 Mdot
.72777 .54752 Mdot
.56715 .30223 Mdot
.32545 .61131 Mdot
.54649 .30138 Mdot
.54593 .72758 Mdot
.46778 .29688 Mdot
.45306 .71005 Mdot
.36917 .65469 Mdot
.60654 .33038 Mdot
.35987 .36848 Mdot
.33804 .6733 Mdot
.64649 .6294 Mdot
.36044 .62861 Mdot
.34176 .52568 Mdot
.48632 .71536 Mdot
.59222 .3061 Mdot
.32659 .60823 Mdot
.55022 .71468 Mdot
.55741 .71799 Mdot
.71374 .55469 Mdot
.37177 .35391 Mdot
.3047 .41069 Mdot
.32569 .41497 Mdot
.33449 .37629 Mdot
.42227 .71863 Mdot
.33404 .6234 Mdot
.64378 .63633 Mdot
.46211 .28035 Mdot
.71341 .58732 Mdot
.35032 .35151 Mdot
.69393 .45375 Mdot
.68441 .38121 Mdot
.35403 .57959 Mdot
.25317 .44766 Mdot
.55025 .73101 Mdot
.7295 .56039 Mdot
.64329 .64829 Mdot
.6992 .46181 Mdot
.49026 .73611 Mdot
.32998 .51739 Mdot
.35241 .54663 Mdot
.69061 .44516 Mdot
.3532 .34897 Mdot
.46246 .73188 Mdot
.37614 .71346 Mdot
.68411 .47258 Mdot
.36203 .6633 Mdot
.62481 .66549 Mdot
.37072 .66781 Mdot
.34683 .61748 Mdot
.36225 .67655 Mdot
.64708 .63218 Mdot
.5636 .73236 Mdot
.37105 .7123 Mdot
.54584 .26233 Mdot
.35083 .71178 Mdot
.32275 .42827 Mdot
.33255 .57733 Mdot
.34269 .68616 Mdot
.28561 .41466 Mdot
.71884 .52938 Mdot
.34805 .66529 Mdot
.69001 .40287 Mdot
.33182 .56654 Mdot
.66345 .38299 Mdot
.46858 .72401 Mdot
.34956 .6227 Mdot
.55261 .71254 Mdot
.69715 .55038 Mdot
.68646 .45177 Mdot
.67236 .38383 Mdot
.40216 .33877 Mdot
.71141 .46645 Mdot
.36006 .65175 Mdot
.47118 .72569 Mdot
.71754 .52771 Mdot
.38973 .36325 Mdot
.68975 .56855 Mdot
.25399 .46087 Mdot
.71193 .44424 Mdot
.38197 .33756 Mdot
.49925 .72659 Mdot
.70202 .43867 Mdot
.68891 .39987 Mdot
.5438 .70743 Mdot
.35345 .34827 Mdot
.72755 .54112 Mdot
.46559 .29561 Mdot
.35834 .35989 Mdot
.70848 .46458 Mdot
.36855 .66274 Mdot
.55698 .70043 Mdot
.69864 .4648 Mdot
.63517 .66552 Mdot
.5449 .70121 Mdot
.32996 .56621 Mdot
.66214 .64505 Mdot
.68751 .57529 Mdot
.33243 .66891 Mdot
.35178 .55633 Mdot
.57647 .29157 Mdot
.36637 .36162 Mdot
.36842 .36071 Mdot
.38781 .36871 Mdot
.56628 .31675 Mdot
.49704 .27748 Mdot
.66337 .35528 Mdot
.35032 .61841 Mdot
.65624 .34678 Mdot
.38354 .34195 Mdot
.57454 .29008 Mdot
.37039 .66277 Mdot
.48349 .74117 Mdot
.68265 .44017 Mdot
.50623 .28427 Mdot
.34479 .59707 Mdot
.72169 .55388 Mdot
.70244 .4333 Mdot
.43645 .70702 Mdot
.46537 .28589 Mdot
.27107 .44786 Mdot
.33115 .61082 Mdot
.69563 .43634 Mdot
.64502 .66832 Mdot
.6952 .43694 Mdot
.34618 .68979 Mdot
.35252 .66356 Mdot
.71693 .57919 Mdot
.32222 .42991 Mdot
.43577 .71921 Mdot
.32968 .54067 Mdot
.46497 .27624 Mdot
.71717 .58553 Mdot
.32955 .41977 Mdot
.45217 .73486 Mdot
.40089 .3577 Mdot
.26263 .42275 Mdot
.34286 .56924 Mdot
.44738 .71491 Mdot
.38244 .32386 Mdot
.70726 .47237 Mdot
.3247 .42346 Mdot
.56076 .26303 Mdot
.70076 .55672 Mdot
.66109 .35298 Mdot
.40509 .36274 Mdot
.65924 .3735 Mdot
.41605 .7162 Mdot
.39113 .34076 Mdot
.67827 .44455 Mdot
.29393 .49574 Mdot
.37809 .36563 Mdot
.59704 .30794 Mdot
.33558 .65596 Mdot
.44116 .71742 Mdot
.32931 .56657 Mdot
.30633 .41153 Mdot
.69813 .58049 Mdot
.68082 .39415 Mdot
.68633 .46315 Mdot
.32129 .56613 Mdot
.63613 .63295 Mdot
.67583 .58777 Mdot
.37018 .33729 Mdot
.30198 .42989 Mdot
.29216 .42624 Mdot
.32226 .57532 Mdot
.47963 .73766 Mdot
.64733 .63452 Mdot
.33275 .57061 Mdot
.32178 .57537 Mdot
.48437 .28643 Mdot
.66471 .64378 Mdot
.5703 .31336 Mdot
.56145 .72355 Mdot
.33733 .61485 Mdot
.65221 .35066 Mdot
.7196 .46374 Mdot
.36903 .35655 Mdot
.69944 .47502 Mdot
.48902 .28154 Mdot
.3689 .36098 Mdot
.33352 .57022 Mdot
.72879 .53426 Mdot
.33184 .57149 Mdot
.33145 .56802 Mdot
.36513 .67235 Mdot
.33457 .62335 Mdot
.52498 .26712 Mdot
.30655 .43249 Mdot
.45852 .7364 Mdot
.58914 .3252 Mdot
.57392 .26662 Mdot
.34411 .65778 Mdot
.33871 .57205 Mdot
.33053 .55114 Mdot
.65674 .65534 Mdot
.55804 .69662 Mdot
.70052 .44276 Mdot
.71674 .57964 Mdot
.3547 .57069 Mdot
.44915 .29264 Mdot
.34872 .66763 Mdot
.6308 .63982 Mdot
.67703 .36618 Mdot
.73418 .44032 Mdot
.40855 .35465 Mdot
.35887 .33727 Mdot
.36823 .36368 Mdot
.38499 .3706 Mdot
.65917 .38341 Mdot
.57355 .28885 Mdot
.2928 .45506 Mdot
.33502 .63295 Mdot
.35098 .56108 Mdot
.35206 .65866 Mdot
.48601 .2909 Mdot
.34844 .33705 Mdot
.33881 .63529 Mdot
.53737 .69666 Mdot
.54386 .29171 Mdot
.37534 .36991 Mdot
.62005 .63155 Mdot
.69604 .55951 Mdot
.46749 .28851 Mdot
.64707 .36498 Mdot
.30942 .41827 Mdot
.44045 .30742 Mdot
.69214 .57361 Mdot
.53586 .68628 Mdot
.54504 .28819 Mdot
.46978 .7273 Mdot
.51015 .71535 Mdot
.56118 .29683 Mdot
.56488 .69402 Mdot
.68153 .5748 Mdot
.3913 .36364 Mdot
.4771 .72319 Mdot
.45119 .72118 Mdot
.62039 .33348 Mdot
.33785 .588 Mdot
.518 .27489 Mdot
.59387 .30526 Mdot
.37747 .35638 Mdot
.59183 .30587 Mdot
.72724 .46287 Mdot
.58358 .31497 Mdot
.64357 .66443 Mdot
.32073 .57836 Mdot
.67867 .63111 Mdot
.39806 .71827 Mdot
.35599 .55441 Mdot
.71734 .44094 Mdot
.66695 .35411 Mdot
.34361 .54692 Mdot
.28302 .41035 Mdot
.59161 .30055 Mdot
.47793 .27746 Mdot
.56356 .70027 Mdot
.47593 .29467 Mdot
.69609 .55107 Mdot
.6559 .35414 Mdot
.66659 .3537 Mdot
.36217 .36161 Mdot
.64062 .62946 Mdot
.66087 .38734 Mdot
.672 .37168 Mdot
.27348 .4551 Mdot
.33407 .67612 Mdot
.63175 .6724 Mdot
.46231 .73151 Mdot
.27155 .41829 Mdot
.33246 .5642 Mdot
.57542 .31645 Mdot
.47664 .28008 Mdot
.39919 .71302 Mdot
.57793 .30129 Mdot
.36567 .35472 Mdot
.65712 .66477 Mdot
.56725 .71103 Mdot
.69988 .57749 Mdot
.3188 .58325 Mdot
.65936 .3513 Mdot
.69626 .5557 Mdot
.42599 .3378 Mdot
.34007 .53575 Mdot
.62368 .64086 Mdot
.4484 .73508 Mdot
.33049 .5647 Mdot
.58916 .28619 Mdot
.28457 .41436 Mdot
.42056 .34978 Mdot
.53398 .26799 Mdot
.27828 .44229 Mdot
.73517 .57599 Mdot
.59096 .28642 Mdot
.28475 .43444 Mdot
.33344 .37328 Mdot
.39744 .36625 Mdot
.30016 .4366 Mdot
.3606 .64828 Mdot
.70884 .4682 Mdot
.70657 .58348 Mdot
.35521 .67569 Mdot
.32243 .51084 Mdot
.67725 .64152 Mdot
.36928 .34224 Mdot
.32891 .56134 Mdot
.33399 .66777 Mdot
.63255 .63976 Mdot
.69719 .39756 Mdot
.60251 .32102 Mdot
.36028 .34423 Mdot
.69742 .57496 Mdot
.70217 .40399 Mdot
.58419 .28332 Mdot
.28345 .42631 Mdot
.71641 .47252 Mdot
.73085 .53529 Mdot
.37478 .34268 Mdot
.71754 .44975 Mdot
.53056 .27009 Mdot
.34198 .65406 Mdot
.53917 .69903 Mdot
.54645 .28395 Mdot
.34144 .65423 Mdot
.55066 .72946 Mdot
.46878 .28152 Mdot
.68624 .38341 Mdot
.69296 .56651 Mdot
.68986 .45412 Mdot
.29869 .42669 Mdot
.6399 .65022 Mdot
.69015 .56894 Mdot
.71986 .4641 Mdot
.67288 .65458 Mdot
.48312 .72993 Mdot
.65706 .36068 Mdot
.47141 .73618 Mdot
.33852 .66516 Mdot
.37595 .34462 Mdot
.31191 .43108 Mdot
.65666 .35239 Mdot
.65989 .6475 Mdot
.70812 .50005 Mdot
.35495 .63707 Mdot
.55438 .69604 Mdot
.31631 .41957 Mdot
.67784 .60191 Mdot
.68549 .37728 Mdot
.70261 .44249 Mdot
.46459 .27683 Mdot
.28863 .40824 Mdot
.36562 .65056 Mdot
.4885 .29512 Mdot
.35623 .65753 Mdot
.70231 .43096 Mdot
.55315 .73037 Mdot
.70461 .55875 Mdot
.65507 .36353 Mdot
.54482 .72887 Mdot
.43664 .72392 Mdot
.34876 .55393 Mdot
.47435 .28392 Mdot
.67825 .57134 Mdot
.34044 .34344 Mdot
.35793 .56592 Mdot
.3375 .53345 Mdot
.35378 .34033 Mdot
.34955 .6188 Mdot
.68767 .38984 Mdot
.35501 .36149 Mdot
.54658 .29303 Mdot
.38542 .3658 Mdot
.36522 .35124 Mdot
.7158 .53569 Mdot
.46432 .28175 Mdot
.35652 .33806 Mdot
.34816 .53561 Mdot
.32453 .5677 Mdot
.68545 .45134 Mdot
.47962 .7288 Mdot
.45476 .72511 Mdot
.59573 .33027 Mdot
.27296 .45623 Mdot
.34625 .68069 Mdot
.64834 .62688 Mdot
.32044 .4137 Mdot
.38494 .32953 Mdot
.70449 .55042 Mdot
.35994 .64288 Mdot
.48496 .28674 Mdot
.38625 .36331 Mdot
.36868 .32776 Mdot
.31192 .41999 Mdot
.68979 .43196 Mdot
.62572 .65113 Mdot
.59476 .30568 Mdot
.53662 .70923 Mdot
.25272 .45405 Mdot
.47261 .28923 Mdot
.37572 .34579 Mdot
.39617 .34437 Mdot
.63738 .63327 Mdot
.63929 .66414 Mdot
.41203 .35698 Mdot
.59 .32636 Mdot
.67653 .39747 Mdot
.66029 .36996 Mdot
.46624 .71445 Mdot
.71832 .47438 Mdot
.69279 .56541 Mdot
.34558 .62482 Mdot
.28957 .42788 Mdot
.70452 .43941 Mdot
.36287 .36331 Mdot
.69479 .57014 Mdot
.63872 .65955 Mdot
.32932 .53931 Mdot
.33646 .56288 Mdot
.45034 .28919 Mdot
.3632 .63598 Mdot
.68369 .43517 Mdot
.29896 .41254 Mdot
.57811 .28723 Mdot
.56121 .70043 Mdot
.71938 .55597 Mdot
.43905 .31395 Mdot
.435 .72681 Mdot
.59628 .32244 Mdot
.70669 .58027 Mdot
.31416 .40898 Mdot
.30493 .43323 Mdot
.34253 .62 Mdot
.43498 .3236 Mdot
.71653 .44386 Mdot
.64284 .63111 Mdot
.73053 .58014 Mdot
.44847 .72993 Mdot
.33758 .57055 Mdot
.56862 .69897 Mdot
.67374 .39092 Mdot
.35882 .64953 Mdot
.31197 .41552 Mdot
.68002 .57233 Mdot
.36982 .65789 Mdot
.31098 .40336 Mdot
.34072 .34267 Mdot
.39624 .3481 Mdot
.60895 .32617 Mdot
.30729 .40626 Mdot
.30039 .40611 Mdot
.31975 .40316 Mdot
.68451 .38238 Mdot
.43315 .70852 Mdot
.25482 .45876 Mdot
.3387 .5868 Mdot
.33638 .65688 Mdot
.54293 .69631 Mdot
.65041 .34481 Mdot
.4622 .29306 Mdot
.34342 .68527 Mdot
.34246 .58229 Mdot
.67892 .58014 Mdot
.53314 .71633 Mdot
.3512 .69407 Mdot
.70887 .55159 Mdot
.62221 .67306 Mdot
.61179 .31804 Mdot
.70375 .4126 Mdot
.46912 .29997 Mdot
.45853 .73886 Mdot
.46265 .74137 Mdot
.69071 .54758 Mdot
.71311 .47051 Mdot
.4647 .74045 Mdot
.6913 .43131 Mdot
.68321 .56389 Mdot
.54109 .69499 Mdot
.63769 .66551 Mdot
.26937 .44399 Mdot
.34839 .69073 Mdot
.72208 .46096 Mdot
.34353 .68633 Mdot
.72059 .46646 Mdot
.32477 .5122 Mdot
.47257 .74135 Mdot
.34878 .5814 Mdot
.37016 .64964 Mdot
.42749 .33016 Mdot
.33834 .56647 Mdot
.47865 .27135 Mdot
.71832 .56195 Mdot
.25411 .43954 Mdot
.56977 .68499 Mdot
.33738 .66801 Mdot
.33056 .55437 Mdot
.67665 .6445 Mdot
.33518 .54948 Mdot
.47701 .29801 Mdot
.44917 .73641 Mdot
.34735 .69376 Mdot
.70082 .45345 Mdot
.66626 .37734 Mdot
.71834 .52754 Mdot
.39281 .34097 Mdot
.6782 .60039 Mdot
.32595 .55303 Mdot
.60367 .31107 Mdot
.33519 .39006 Mdot
.29654 .40836 Mdot
.70849 .5816 Mdot
.30144 .4999 Mdot
.66163 .38523 Mdot
.57084 .26889 Mdot
.54136 .71072 Mdot
.55911 .30569 Mdot
.6016 .32864 Mdot
.71675 .58634 Mdot
.31102 .4311 Mdot
.34901 .67857 Mdot
.61681 .66157 Mdot
.60886 .67986 Mdot
.44642 .72825 Mdot
.60495 .30454 Mdot
.37998 .32352 Mdot
.58142 .71963 Mdot
.26984 .43278 Mdot
.28219 .43945 Mdot
.71727 .46059 Mdot
.60544 .31451 Mdot
.36099 .34625 Mdot
.28548 .4323 Mdot
.61291 .31816 Mdot
.39974 .36617 Mdot
.47438 .2745 Mdot
.64409 .63469 Mdot
.33053 .62057 Mdot
.6212 .64089 Mdot
.69227 .47086 Mdot
.45996 .28275 Mdot
.6504 .64032 Mdot
.64475 .62534 Mdot
.36681 .34807 Mdot
.5446 .26876 Mdot
.67105 .65177 Mdot
.33611 .67917 Mdot
.39698 .35596 Mdot
.32709 .5388 Mdot
.28741 .40649 Mdot
.32524 .56392 Mdot
.45284 .29005 Mdot
.69744 .44079 Mdot
.58161 .29607 Mdot
.71871 .45875 Mdot
.35203 .62231 Mdot
.34245 .53387 Mdot
.33458 .57522 Mdot
.46718 .72374 Mdot
.70737 .53639 Mdot
.62057 .66564 Mdot
.59695 .31706 Mdot
.58577 .299 Mdot
.56548 .68479 Mdot
.72319 .5501 Mdot
.33588 .35746 Mdot
.46856 .73872 Mdot
.33715 .55012 Mdot
.71741 .56104 Mdot
.54748 .69343 Mdot
.66356 .39018 Mdot
.47226 .72234 Mdot
.7046 .54049 Mdot
.49746 .27879 Mdot
.32113 .57481 Mdot
.36431 .33584 Mdot
.40028 .32707 Mdot
.41965 .71432 Mdot
.27287 .4161 Mdot
.70024 .56182 Mdot
.37632 .33173 Mdot
.72075 .56392 Mdot
.55282 .30749 Mdot
.65562 .38323 Mdot
.70941 .55628 Mdot
.33247 .54883 Mdot
.49139 .29499 Mdot
.71228 .46857 Mdot
.36622 .67493 Mdot
.65855 .36421 Mdot
.64576 .64607 Mdot
.71063 .5716 Mdot
.39997 .36607 Mdot
.56336 .69391 Mdot
.71131 .44077 Mdot
.35143 .56804 Mdot
.63927 .66645 Mdot
.54287 .72683 Mdot
.2703 .41975 Mdot
.35142 .66941 Mdot
.33216 .65277 Mdot
.5084 .27905 Mdot
.34744 .6436 Mdot
.68336 .39032 Mdot
.6583 .38062 Mdot
.68079 .39572 Mdot
.71994 .53355 Mdot
.41998 .34615 Mdot
.62918 .65896 Mdot
.36595 .35661 Mdot
.54984 .269 Mdot
.36396 .6772 Mdot
.38185 .37148 Mdot
.66033 .35417 Mdot
.3031 .43899 Mdot
.42753 .71962 Mdot
.54888 .27926 Mdot
.4024 .35062 Mdot
.7079 .44298 Mdot
.65614 .6632 Mdot
.70376 .55433 Mdot
.48582 .27476 Mdot
.37075 .66479 Mdot
.33556 .56504 Mdot
.66905 .35972 Mdot
.43641 .32055 Mdot
.27885 .44064 Mdot
.36005 .36839 Mdot
.66481 .35835 Mdot
.47544 .72546 Mdot
.64965 .64813 Mdot
.34497 .69014 Mdot
.4748 .72874 Mdot
.68393 .3836 Mdot
.61114 .67732 Mdot
.27886 .44499 Mdot
.33689 .60935 Mdot
.70083 .56372 Mdot
.70704 .45665 Mdot
.3332 .36833 Mdot
.56972 .71406 Mdot
.34787 .569 Mdot
.35162 .70626 Mdot
.45309 .71577 Mdot
.54142 .71611 Mdot
.40797 .35672 Mdot
.34874 .70159 Mdot
.5678 .68518 Mdot
.53553 .71471 Mdot
.35043 .66232 Mdot
.34915 .659 Mdot
.71505 .56413 Mdot
.4827 .7139 Mdot
.57396 .31303 Mdot
.56843 .69459 Mdot
.43857 .3146 Mdot
.54453 .71304 Mdot
.47661 .71589 Mdot
.6088 .67236 Mdot
.41717 .71459 Mdot
.68034 .56142 Mdot
.7257 .54472 Mdot
.69428 .47219 Mdot
.54756 .72701 Mdot
.5967 .32292 Mdot
.37705 .32541 Mdot
.46706 .29217 Mdot
.7162 .56555 Mdot
.60989 .31038 Mdot
.64335 .34191 Mdot
.54626 .28352 Mdot
.54932 .29785 Mdot
.69742 .43879 Mdot
.70387 .58578 Mdot
.43853 .72935 Mdot
.69965 .43667 Mdot
.36095 .3306 Mdot
.28489 .4276 Mdot
.61461 .68016 Mdot
.35408 .36426 Mdot
.34524 .59803 Mdot
.68241 .46639 Mdot
.54739 .27353 Mdot
.35194 .70867 Mdot
.7303 .56218 Mdot
.32388 .41121 Mdot
.70872 .55963 Mdot
.40651 .36384 Mdot
.28065 .45027 Mdot
.36439 .64773 Mdot
.43781 .31506 Mdot
.68656 .39131 Mdot
.34843 .67574 Mdot
.61306 .66969 Mdot
.46662 .2917 Mdot
.7287 .4601 Mdot
.68824 .40373 Mdot
.36239 .33867 Mdot
.70637 .54194 Mdot
.63054 .66322 Mdot
.37018 .35944 Mdot
.70606 .45445 Mdot
.67732 .62707 Mdot
.33681 .63674 Mdot
.71548 .47756 Mdot
.35066 .6795 Mdot
.32456 .60369 Mdot
.3281 .42768 Mdot
.38856 .36787 Mdot
.53273 .71171 Mdot
.5757 .27727 Mdot
.56004 .68508 Mdot
.32654 .59736 Mdot
.36527 .63549 Mdot
.34505 .56069 Mdot
.355 .70818 Mdot
.49174 .28362 Mdot
.70678 .53146 Mdot
.39082 .35166 Mdot
.37273 .34473 Mdot
.53828 .72648 Mdot
.44272 .30157 Mdot
.29243 .43883 Mdot
.48366 .27314 Mdot
.3369 .53504 Mdot
.33888 .55649 Mdot
.64697 .65567 Mdot
.32148 .60234 Mdot
.38767 .3661 Mdot
.34618 .55865 Mdot
.42563 .72354 Mdot
.70158 .45832 Mdot
.33145 .66019 Mdot
.32151 .57323 Mdot
.66011 .38724 Mdot
.70293 .45514 Mdot
.47848 .2858 Mdot
.39505 .36847 Mdot
.60793 .33001 Mdot
.27314 .43695 Mdot
.35416 .70294 Mdot
.34742 .62463 Mdot
.47959 .72152 Mdot
.27001 .43863 Mdot
.54888 .71316 Mdot
.31375 .57992 Mdot
.32653 .58885 Mdot
.28375 .43954 Mdot
.70658 .4735 Mdot
.71502 .55843 Mdot
.32669 .60721 Mdot
.37178 .34618 Mdot
.53697 .71631 Mdot
.3044 .40315 Mdot
.72029 .5655 Mdot
.61887 .64659 Mdot
.70577 .57894 Mdot
.7061 .44508 Mdot
.4649 .28482 Mdot
.2804 .4506 Mdot
.70824 .55904 Mdot
.58781 .28121 Mdot
.65386 .35284 Mdot
.45943 .71179 Mdot
.68797 .46441 Mdot
.71612 .58663 Mdot
.71474 .53763 Mdot
.73433 .55584 Mdot
.56747 .70369 Mdot
.35546 .70901 Mdot
.36353 .35459 Mdot
.66518 .35752 Mdot
.57073 .27551 Mdot
.35549 .63479 Mdot
.61426 .65615 Mdot
.36062 .71804 Mdot
.36493 .64654 Mdot
.3247 .56352 Mdot
.33224 .58386 Mdot
.40872 .34963 Mdot
.34952 .58485 Mdot
.33749 .58668 Mdot
.68401 .43253 Mdot
.47503 .28794 Mdot
.34359 .53326 Mdot
.39522 .34792 Mdot
.25368 .44898 Mdot
.32527 .4125 Mdot
.33441 .61378 Mdot
.52054 .70007 Mdot
.71493 .55417 Mdot
.58379 .32383 Mdot
.60924 .31734 Mdot
.30772 .41288 Mdot
.69322 .45342 Mdot
.69223 .57973 Mdot
.50473 .28267 Mdot
.28368 .45171 Mdot
.36039 .67436 Mdot
.46538 .72294 Mdot
.41736 .71521 Mdot
.44346 .71511 Mdot
.36423 .67454 Mdot
.36767 .36682 Mdot
.58267 .32484 Mdot
.44727 .70901 Mdot
.62863 .63401 Mdot
.29206 .40711 Mdot
.28432 .42138 Mdot
.66131 .6628 Mdot
.32638 .5962 Mdot
.7226 .45759 Mdot
.47854 .7375 Mdot
.73398 .45808 Mdot
.67755 .58858 Mdot
.2547 .46054 Mdot
.34846 .66711 Mdot
.34514 .66532 Mdot
.35381 .57912 Mdot
.66317 .66249 Mdot
.63712 .66973 Mdot
.65913 .6484 Mdot
.70072 .45934 Mdot
.34186 .66854 Mdot
.67558 .38055 Mdot
.38932 .3656 Mdot
.69698 .55703 Mdot
.48433 .71121 Mdot
.58501 .29871 Mdot
.53407 .70968 Mdot
.31654 .43087 Mdot
.45214 .72883 Mdot
.38823 .34447 Mdot
.33405 .63968 Mdot
.57285 .28938 Mdot
.65091 .6451 Mdot
.53608 .70269 Mdot
.52914 .26617 Mdot
.35015 .70143 Mdot
.38637 .31971 Mdot
.37155 .37163 Mdot
.27086 .44515 Mdot
.34536 .66971 Mdot
.32223 .42462 Mdot
.71043 .44107 Mdot
.34571 .53639 Mdot
.34517 .69293 Mdot
.33109 .55885 Mdot
.35652 .64859 Mdot
.70567 .46371 Mdot
.55344 .7241 Mdot
.3573 .32945 Mdot
.38983 .37042 Mdot
.54337 .71414 Mdot
.30905 .4365 Mdot
.66156 .37051 Mdot
.47862 .28745 Mdot
.35222 .35418 Mdot
.26849 .44833 Mdot
.347 .67732 Mdot
.33871 .54673 Mdot
.39671 .36483 Mdot
.3606 .6478 Mdot
.56396 .70897 Mdot
.55494 .29698 Mdot
.5434 .72387 Mdot
.31653 .40624 Mdot
.31854 .426 Mdot
.70766 .46767 Mdot
.70793 .5575 Mdot
.30211 .41512 Mdot
.57154 .28453 Mdot
.33922 .62726 Mdot
.35044 .66627 Mdot
.64185 .66477 Mdot
.36632 .64015 Mdot
.31601 .40576 Mdot
.36449 .64958 Mdot
.66342 .63762 Mdot
.67188 .65461 Mdot
.34745 .56986 Mdot
.55879 .70659 Mdot
.71973 .53644 Mdot
.28485 .42988 Mdot
.69058 .44826 Mdot
.38893 .71555 Mdot
.69064 .43275 Mdot
.66026 .64788 Mdot
.36966 .33409 Mdot
.70948 .58516 Mdot
.36844 .33386 Mdot
.59741 .67528 Mdot
.32193 .57803 Mdot
.64444 .66617 Mdot
.36432 .32306 Mdot
.59817 .31863 Mdot
.53686 .27243 Mdot
.38749 .362 Mdot
.69874 .55961 Mdot
.37065 .35592 Mdot
.30118 .42088 Mdot
.67296 .35372 Mdot
.7274 .54513 Mdot
.54579 .29363 Mdot
.54762 .27428 Mdot
.67059 .35998 Mdot
.32741 .56236 Mdot
.34118 .68601 Mdot
.54944 .28644 Mdot
.73418 .46011 Mdot
.69037 .55178 Mdot
.33555 .56678 Mdot
.3533 .35873 Mdot
.56709 .3077 Mdot
.63508 .33588 Mdot
.64292 .65419 Mdot
.5364 .69982 Mdot
.36443 .6346 Mdot
.66133 .38293 Mdot
.33172 .66731 Mdot
.56125 .70452 Mdot
.27731 .42884 Mdot
.34169 .6122 Mdot
.33709 .6444 Mdot
.66432 .3815 Mdot
.35695 .34083 Mdot
.44155 .71554 Mdot
.52266 .27317 Mdot
.34087 .69221 Mdot
.28097 .48888 Mdot
.39542 .36533 Mdot
.35876 .67233 Mdot
.34556 .33882 Mdot
.70137 .57689 Mdot
.33409 .55962 Mdot
.65266 .3515 Mdot
.59371 .32126 Mdot
.37064 .66455 Mdot
.42734 .33847 Mdot
.65309 .36186 Mdot
.38759 .34306 Mdot
.2792 .44223 Mdot
.54319 .70174 Mdot
.35751 .6281 Mdot
.48651 .29068 Mdot
.30076 .43403 Mdot
.328 .55621 Mdot
.58177 .28973 Mdot
.66313 .37611 Mdot
.39073 .35592 Mdot
.34156 .67577 Mdot
.66858 .37044 Mdot
.69595 .44983 Mdot
.3207 .42789 Mdot
.73882 .52935 Mdot
.31664 .56604 Mdot
.32358 .5492 Mdot
.74266 .56236 Mdot
.63649 .66179 Mdot
.35018 .69052 Mdot
.34515 .5297 Mdot
.71917 .45132 Mdot
.36853 .71775 Mdot
.3321 .64887 Mdot
.36814 .32167 Mdot
.72919 .46217 Mdot
.61331 .32862 Mdot
.54926 .27056 Mdot
.29565 .43117 Mdot
.69904 .58196 Mdot
.32627 .42742 Mdot
.58805 .31873 Mdot
.33565 .66827 Mdot
.6957 .43206 Mdot
.59484 .68368 Mdot
.65851 .36027 Mdot
.56245 .28361 Mdot
.63059 .64444 Mdot
.48979 .73367 Mdot
.28311 .49019 Mdot
.73513 .45556 Mdot
.48475 .27584 Mdot
.29432 .40916 Mdot
.6289 .63371 Mdot
.3314 .54324 Mdot
.46875 .71149 Mdot
.36983 .66408 Mdot
.41809 .34388 Mdot
.47595 .29315 Mdot
.39959 .36634 Mdot
.36152 .33959 Mdot
.35776 .70302 Mdot
.69498 .44917 Mdot
.67117 .38553 Mdot
.38815 .33417 Mdot
.70422 .44684 Mdot
.3311 .53612 Mdot
.56181 .29009 Mdot
.60408 .65506 Mdot
.3366 .54954 Mdot
.28458 .45704 Mdot
.64152 .3434 Mdot
.64262 .62532 Mdot
.61206 .32239 Mdot
.34551 .66651 Mdot
.67688 .59775 Mdot
.70487 .43781 Mdot
.3356 .62237 Mdot
.59564 .31984 Mdot
.35265 .35519 Mdot
.58787 .29452 Mdot
.35531 .68196 Mdot
.34694 .66083 Mdot
.35515 .33801 Mdot
.33584 .55086 Mdot
.70641 .52714 Mdot
.57093 .71117 Mdot
.55668 .6834 Mdot
.33783 .58779 Mdot
.60709 .66361 Mdot
.64979 .36531 Mdot
.38704 .3333 Mdot
.45317 .71544 Mdot
.35856 .64261 Mdot
.72435 .53674 Mdot
.65997 .371 Mdot
.69453 .39207 Mdot
.70405 .46114 Mdot
.59878 .32112 Mdot
.69323 .45155 Mdot
.35439 .5788 Mdot
.68392 .55895 Mdot
.57972 .30741 Mdot
.38101 .34118 Mdot
.58954 .27941 Mdot
.35725 .55996 Mdot
.64089 .33801 Mdot
.56221 .26866 Mdot
.56528 .69619 Mdot
.68445 .56947 Mdot
.4322 .31603 Mdot
.52009 .69883 Mdot
.33469 .65623 Mdot
.36887 .66516 Mdot
.36263 .36894 Mdot
.70649 .46655 Mdot
.64049 .65813 Mdot
.47123 .27462 Mdot
.31841 .40767 Mdot
.68059 .56085 Mdot
.32518 .41688 Mdot
.46907 .7271 Mdot
.61109 .65394 Mdot
.42666 .72452 Mdot
.71821 .46609 Mdot
.7015 .55629 Mdot
.30433 .40213 Mdot
.57429 .69544 Mdot
.30995 .4272 Mdot
.60012 .29952 Mdot
.46262 .74094 Mdot
.55172 .29734 Mdot
.67109 .35593 Mdot
.47409 .28188 Mdot
.71985 .44542 Mdot
.42803 .33647 Mdot
.55426 .73006 Mdot
.65445 .37459 Mdot
.6547 .34641 Mdot
.58085 .31913 Mdot
.39247 .33847 Mdot
.55199 .7234 Mdot
.39857 .33228 Mdot
.39912 .33953 Mdot
.66671 .38531 Mdot
.70486 .55116 Mdot
.72234 .55142 Mdot
.25457 .44204 Mdot
.7067 .55183 Mdot
.5648 .30134 Mdot
.47049 .72249 Mdot
.49938 .72799 Mdot
.64803 .3627 Mdot
.54224 .70264 Mdot
.34865 .59613 Mdot
.46205 .29749 Mdot
.56232 .29494 Mdot
.69809 .45597 Mdot
.72531 .58461 Mdot
.37587 .33058 Mdot
.64071 .65402 Mdot
.69474 .57335 Mdot
.705 .57383 Mdot
.70916 .5868 Mdot
.34165 .65805 Mdot
.7188 .44215 Mdot
.69949 .56427 Mdot
.35084 .68182 Mdot
.32198 .54621 Mdot
.35556 .35671 Mdot
.41796 .34263 Mdot
.56059 .71196 Mdot
.36199 .35288 Mdot
.34572 .55062 Mdot
.59145 .30556 Mdot
.4211 .34313 Mdot
.36905 .33015 Mdot
.59235 .32613 Mdot
.58968 .32662 Mdot
.39964 .33518 Mdot
.42093 .34413 Mdot
.70985 .52615 Mdot
.56042 .73149 Mdot
.61333 .66938 Mdot
.56112 .26719 Mdot
.68234 .39927 Mdot
.64325 .66534 Mdot
.36958 .67108 Mdot
.34911 .35852 Mdot
.5719 .29101 Mdot
.731 .55135 Mdot
.3372 .57676 Mdot
.36875 .34956 Mdot
.30409 .42505 Mdot
.38291 .33989 Mdot
.3655 .3672 Mdot
.63477 .67485 Mdot
.69859 .49257 Mdot
.63456 .63538 Mdot
.52714 .2702 Mdot
.38596 .34704 Mdot
.67581 .63977 Mdot
.45666 .28431 Mdot
.67658 .3575 Mdot
.57157 .71236 Mdot
.33931 .58966 Mdot
.58252 .32334 Mdot
.69593 .55109 Mdot
.68234 .44478 Mdot
.4238 .72267 Mdot
.70724 .55893 Mdot
.40286 .3652 Mdot
.38114 .36619 Mdot
.56841 .30936 Mdot
.65223 .66786 Mdot
.55989 .70398 Mdot
.70536 .56563 Mdot
.66984 .36237 Mdot
.37091 .65369 Mdot
.67702 .60068 Mdot
.36183 .34756 Mdot
.71832 .55198 Mdot
.56847 .27629 Mdot
.31425 .4159 Mdot
.35786 .65239 Mdot
.70939 .41486 Mdot
.32946 .55409 Mdot
.67375 .36441 Mdot
.27755 .45957 Mdot
.55879 .68956 Mdot
.36413 .66931 Mdot
.46395 .71311 Mdot
.65197 .34516 Mdot
.3597 .68183 Mdot
.48788 .73092 Mdot
.62061 .64382 Mdot
.63962 .64424 Mdot
.33577 .5353 Mdot
.55338 .29166 Mdot
.51023 .26781 Mdot
.32042 .56473 Mdot
.5298 .26323 Mdot
.47846 .73973 Mdot
.37942 .32591 Mdot
.26948 .41807 Mdot
.34512 .62632 Mdot
.36091 .65849 Mdot
.34904 .57957 Mdot
.372 .65443 Mdot
.41781 .71712 Mdot
.59155 .31994 Mdot
.60808 .32578 Mdot
.29671 .42296 Mdot
.34609 .70582 Mdot
.3181 .42317 Mdot
.66155 .37553 Mdot
.55021 .72867 Mdot
.37849 .37285 Mdot
.71053 .55318 Mdot
.33283 .55627 Mdot
.59164 .29141 Mdot
.35946 .67065 Mdot
.55049 .70292 Mdot
.56647 .3046 Mdot
.57801 .29349 Mdot
.51994 .27555 Mdot
.30973 .40447 Mdot
.71474 .5756 Mdot
.35615 .57062 Mdot
.27886 .4146 Mdot
.36438 .3299 Mdot
.39351 .72199 Mdot
.68025 .56861 Mdot
.72162 .56171 Mdot
.72104 .57653 Mdot
.35237 .56743 Mdot
.35321 .56662 Mdot
.67691 .37272 Mdot
.62475 .6638 Mdot
.70475 .43132 Mdot
.57668 .3205 Mdot
.5191 .26449 Mdot
.36005 .66354 Mdot
.2818 .45488 Mdot
.31069 .43458 Mdot
.57523 .27121 Mdot
.37823 .37041 Mdot
.3236 .42226 Mdot
.35422 .55897 Mdot
.56814 .31145 Mdot
.30262 .40432 Mdot
.72116 .58445 Mdot
.69257 .40327 Mdot
.31995 .41865 Mdot
.35956 .34355 Mdot
.61806 .65525 Mdot
.34425 .63814 Mdot
.32799 .423 Mdot
.65376 .37065 Mdot
.43444 .72635 Mdot
.38373 .36949 Mdot
.2913 .45188 Mdot
.37229 .71533 Mdot
.58327 .31373 Mdot
.35908 .34196 Mdot
.30423 .40096 Mdot
.50142 .7267 Mdot
.32025 .4342 Mdot
.72128 .55727 Mdot
.54267 .68577 Mdot
.36509 .6593 Mdot
.55364 .69522 Mdot
.69528 .47179 Mdot
.60089 .29911 Mdot
.60661 .31423 Mdot
.64983 .66469 Mdot
.46676 .71751 Mdot
.54606 .28659 Mdot
.46163 .71423 Mdot
.26107 .42646 Mdot
.35104 .68152 Mdot
.25323 .44106 Mdot
.57239 .69243 Mdot
.32636 .40292 Mdot
.31758 .41715 Mdot
.6447 .35186 Mdot
.69747 .44243 Mdot
.70905 .46549 Mdot
.5505 .29348 Mdot
.46119 .72703 Mdot
.60729 .32085 Mdot
.74299 .5409 Mdot
.29289 .4379 Mdot
.49997 .28112 Mdot
.3485 .59016 Mdot
.34726 .55349 Mdot
.54229 .69616 Mdot
.35676 .36345 Mdot
.35002 .68532 Mdot
.67103 .3695 Mdot
.5877 .2809 Mdot
.64206 .33719 Mdot
.66104 .65722 Mdot
.74416 .54729 Mdot
.58087 .2967 Mdot
.25795 .43093 Mdot
.31418 .43413 Mdot
.37045 .7217 Mdot
.40319 .32637 Mdot
.59706 .30844 Mdot
.32119 .58664 Mdot
.72919 .54635 Mdot
.51136 .28394 Mdot
.33258 .56129 Mdot
.55058 .27226 Mdot
.45385 .28212 Mdot
.56446 .69104 Mdot
.34711 .64474 Mdot
.68575 .39991 Mdot
.45832 .71679 Mdot
.32385 .40493 Mdot
.35387 .33881 Mdot
.47711 .70865 Mdot
.587 .31968 Mdot
.59995 .29143 Mdot
.31579 .41212 Mdot
.63722 .6297 Mdot
.72596 .54935 Mdot
.71043 .52651 Mdot
.67326 .36902 Mdot
.32399 .58452 Mdot
.57115 .31273 Mdot
.63236 .65284 Mdot
.33896 .62622 Mdot
.71574 .45259 Mdot
.58116 .27208 Mdot
.33576 .55114 Mdot
.36298 .67051 Mdot
.31408 .42126 Mdot
.25434 .44996 Mdot
.35319 .33227 Mdot
.67556 .3553 Mdot
.36534 .70913 Mdot
.54669 .72876 Mdot
.34766 .57061 Mdot
.69529 .54424 Mdot
.37128 .35823 Mdot
.31042 .43177 Mdot
.35226 .69502 Mdot
.48041 .71548 Mdot
.71136 .53861 Mdot
.71998 .46411 Mdot
.37982 .34498 Mdot
.36243 .70818 Mdot
.33306 .55171 Mdot
.36708 .65599 Mdot
.5673 .70339 Mdot
.34307 .59668 Mdot
.46415 .29344 Mdot
.64948 .62567 Mdot
.2734 .42703 Mdot
.70975 .57451 Mdot
.46556 .27921 Mdot
.56882 .71732 Mdot
.46241 .73511 Mdot
.60954 .65655 Mdot
.68291 .56716 Mdot
.66938 .36075 Mdot
.71244 .4381 Mdot
.27424 .45425 Mdot
.35619 .6753 Mdot
.39516 .36379 Mdot
.70185 .5694 Mdot
.60038 .29959 Mdot
.31924 .42369 Mdot
.48784 .27579 Mdot
.34585 .56321 Mdot
.58184 .31821 Mdot
.38735 .35905 Mdot
.6544 .66803 Mdot
.59247 .30872 Mdot
.35301 .35578 Mdot
.28253 .42686 Mdot
.43738 .72581 Mdot
.41577 .35496 Mdot
.36774 .33633 Mdot
.35618 .66893 Mdot
.59378 .68949 Mdot
.54655 .69897 Mdot
.37326 .32102 Mdot
.61436 .32437 Mdot
.36463 .34322 Mdot
.64294 .62403 Mdot
.5618 .69175 Mdot
.57809 .27814 Mdot
.63441 .6656 Mdot
.57193 .7095 Mdot
.37163 .33275 Mdot
.68009 .57168 Mdot
.46332 .27743 Mdot
.73571 .56773 Mdot
.34104 .63157 Mdot
.32793 .58072 Mdot
.54909 .29452 Mdot
.30852 .42605 Mdot
.67663 .38403 Mdot
.64994 .37426 Mdot
.65276 .34761 Mdot
.54351 .29537 Mdot
.3345 .55448 Mdot
.7009 .56062 Mdot
.70172 .43912 Mdot
.64427 .65789 Mdot
.5747 .28413 Mdot
.55719 .28963 Mdot
.53914 .70002 Mdot
.31954 .42545 Mdot
.34939 .58789 Mdot
.59977 .29938 Mdot
.47197 .28508 Mdot
.67799 .62709 Mdot
.32135 .40302 Mdot
.56598 .71665 Mdot
.41502 .3559 Mdot
.33823 .69277 Mdot
.61972 .63825 Mdot
.3872 .36419 Mdot
.65772 .66327 Mdot
.33592 .64206 Mdot
.62935 .33688 Mdot
.45681 .28534 Mdot
.46145 .71628 Mdot
.68648 .38713 Mdot
.70204 .43488 Mdot
.59212 .31187 Mdot
.34039 .5678 Mdot
.49112 .27684 Mdot
.29498 .43049 Mdot
.57299 .68676 Mdot
.38859 .33316 Mdot
.64328 .6618 Mdot
.69182 .43643 Mdot
.42351 .33999 Mdot
.67666 .38371 Mdot
.71225 .46648 Mdot
.6095 .67005 Mdot
.36435 .65922 Mdot
.57442 .29664 Mdot
.55206 .28343 Mdot
.25378 .44051 Mdot
.46802 .2988 Mdot
.7291 .56418 Mdot
.62913 .33644 Mdot
.45585 .70779 Mdot
.33777 .53666 Mdot
.4065 .36045 Mdot
.39806 .35972 Mdot
.46817 .2819 Mdot
.35946 .68262 Mdot
.64777 .63755 Mdot
.61052 .32518 Mdot
.5426 .2736 Mdot
.55812 .69528 Mdot
.69767 .4403 Mdot
.39341 .31995 Mdot
.5643 .29879 Mdot
.39076 .71523 Mdot
.3591 .66182 Mdot
.73471 .45529 Mdot
.56678 .30121 Mdot
.44319 .30015 Mdot
.67475 .39683 Mdot
.63213 .64443 Mdot
.43231 .7129 Mdot
.64542 .64992 Mdot
.32271 .42315 Mdot
.60259 .3125 Mdot
.6696 .38131 Mdot
.38462 .34398 Mdot
.51042 .26928 Mdot
.54587 .28962 Mdot
.71613 .56353 Mdot
.36713 .65877 Mdot
.32986 .60684 Mdot
.33401 .54952 Mdot
.36505 .72109 Mdot
.31985 .40529 Mdot
.64915 .37337 Mdot
.66749 .35887 Mdot
.43245 .71251 Mdot
.3074 .40342 Mdot
.60051 .32515 Mdot
.56875 .30661 Mdot
.70718 .41395 Mdot
.36733 .36732 Mdot
.60258 .32481 Mdot
.35595 .66528 Mdot
.51753 .27242 Mdot
.61363 .65663 Mdot
.69594 .44095 Mdot
.35922 .64418 Mdot
.54501 .29042 Mdot
.63025 .67555 Mdot
.45915 .72285 Mdot
.32083 .5614 Mdot
.35142 .32938 Mdot
.70894 .43767 Mdot
.74576 .55661 Mdot
.46114 .29713 Mdot
.32327 .58011 Mdot
.66515 .37419 Mdot
.4332 .3249 Mdot
.51473 .27514 Mdot
.70681 .58112 Mdot
.54838 .27454 Mdot
.69021 .44484 Mdot
.38608 .35529 Mdot
.27285 .42802 Mdot
.59147 .29941 Mdot
.54892 .26934 Mdot
.54881 .71151 Mdot
.2572 .43666 Mdot
.32729 .42044 Mdot
.68841 .55816 Mdot
.72077 .45387 Mdot
.55062 .7006 Mdot
.38648 .71573 Mdot
.35436 .56636 Mdot
.70867 .46811 Mdot
.67897 .61949 Mdot
.32013 .58155 Mdot
.34472 .57766 Mdot
.33659 .61964 Mdot
.62946 .63799 Mdot
.69432 .56002 Mdot
.359 .71536 Mdot
.55806 .70828 Mdot
.46607 .73204 Mdot
.71539 .55584 Mdot
.71493 .57145 Mdot
.45568 .73077 Mdot
.54829 .70885 Mdot
.63007 .66681 Mdot
.70056 .44468 Mdot
.70264 .43498 Mdot
.70437 .57521 Mdot
.54483 .69389 Mdot
.71372 .47063 Mdot
.65073 .65275 Mdot
.56145 .2852 Mdot
.48176 .73384 Mdot
.69269 .57875 Mdot
.46687 .74118 Mdot
.71088 .44145 Mdot
.37935 .72081 Mdot
.47802 .74036 Mdot
.34069 .59506 Mdot
.36555 .66179 Mdot
.28943 .41026 Mdot
.38576 .34138 Mdot
.40001 .33546 Mdot
.70548 .46582 Mdot
.35095 .58183 Mdot
.65841 .64521 Mdot
.35244 .57323 Mdot
.3646 .63655 Mdot
.38036 .71641 Mdot
.4458 .70526 Mdot
.70666 .58002 Mdot
.6596 .64673 Mdot
.52245 .26856 Mdot
.5984 .29282 Mdot
.48204 .71931 Mdot
.70653 .43651 Mdot
.7168 .54863 Mdot
.70398 .4314 Mdot
.58671 .31851 Mdot
.57449 .29479 Mdot
.3637 .35789 Mdot
.3587 .34217 Mdot
.58665 .30883 Mdot
.53056 .26586 Mdot
.38574 .72 Mdot
.63738 .66483 Mdot
.63652 .62438 Mdot
.35307 .62729 Mdot
.32383 .60291 Mdot
.30592 .4264 Mdot
.42268 .34699 Mdot
.67031 .37232 Mdot
.45127 .71228 Mdot
.35101 .5463 Mdot
.37109 .33675 Mdot
.70314 .47738 Mdot
.29803 .44369 Mdot
.69744 .43742 Mdot
.27541 .43576 Mdot
.57569 .27757 Mdot
.33821 .55505 Mdot
.34755 .58231 Mdot
.66712 .36063 Mdot
.52202 .27514 Mdot
.56352 .3089 Mdot
.30684 .42949 Mdot
.35071 .62666 Mdot
.575 .31335 Mdot
.69031 .57809 Mdot
.67768 .5845 Mdot
.39293 .35918 Mdot
.33858 .57391 Mdot
.34586 .63 Mdot
.56344 .69221 Mdot
.36637 .32919 Mdot
.379 .34514 Mdot
.73689 .52725 Mdot
.33536 .67754 Mdot
.69546 .39094 Mdot
.35801 .3381 Mdot
.71345 .58259 Mdot
.57752 .29922 Mdot
.37081 .32906 Mdot
.39868 .32817 Mdot
.26289 .4752 Mdot
.40609 .34073 Mdot
.70793 .54429 Mdot
.64707 .64653 Mdot
.54905 .72357 Mdot
.68018 .61447 Mdot
.27041 .44137 Mdot
.30517 .43877 Mdot
.45602 .28673 Mdot
.65098 .35211 Mdot
.33532 .63194 Mdot
.29692 .43656 Mdot
.72812 .58008 Mdot
.53592 .70675 Mdot
.54042 .71333 Mdot
.54652 .71826 Mdot
.64609 .65528 Mdot
.34721 .66606 Mdot
.47238 .29231 Mdot
.71622 .56123 Mdot
.54273 .7233 Mdot
.31649 .58386 Mdot
.70856 .53068 Mdot
.71959 .45982 Mdot
.56873 .6834 Mdot
.7025 .55907 Mdot
.41896 .71569 Mdot
.72086 .44863 Mdot
.47155 .71355 Mdot
.62607 .33571 Mdot
.44501 .3009 Mdot
.69842 .45333 Mdot
.57868 .27116 Mdot
.57842 .31787 Mdot
.55883 .30016 Mdot
.6945 .56651 Mdot
.54011 .2689 Mdot
.66027 .64374 Mdot
.48471 .27604 Mdot
.36052 .70699 Mdot
.27977 .45025 Mdot
.47547 .28383 Mdot
.70607 .57343 Mdot
.74327 .56327 Mdot
.29411 .49607 Mdot
.31882 .56384 Mdot
.66031 .37951 Mdot
.2922 .42483 Mdot
.46988 .72319 Mdot
.27701 .42777 Mdot
.59529 .32142 Mdot
.36136 .70095 Mdot
.35947 .66143 Mdot
.69306 .39927 Mdot
.31032 .42496 Mdot
.71298 .57407 Mdot
.54795 .71384 Mdot
.61405 .3357 Mdot
.29684 .43114 Mdot
.31807 .42696 Mdot
.32278 .55293 Mdot
.64898 .64691 Mdot
.5783 .32235 Mdot
.72619 .46898 Mdot
.472 .27192 Mdot
.40845 .7182 Mdot
.34079 .68754 Mdot
.32111 .57709 Mdot
.47219 .72861 Mdot
.47146 .2775 Mdot
.70185 .44955 Mdot
.36693 .64024 Mdot
.44611 .29621 Mdot
.36775 .63863 Mdot
.66031 .66594 Mdot
.48013 .27984 Mdot
.39546 .35643 Mdot
.35462 .35558 Mdot
.33387 .57016 Mdot
.28492 .49229 Mdot
.34119 .67274 Mdot
.71534 .4726 Mdot
.39213 .34157 Mdot
.56826 .26676 Mdot
.7297 .55234 Mdot
.2648 .47719 Mdot
.56156 .70946 Mdot
.72554 .46818 Mdot
.57357 .31085 Mdot
.27134 .48322 Mdot
.2914 .41131 Mdot
.4825 .74082 Mdot
.32341 .5424 Mdot
.33472 .57264 Mdot
.71375 .4597 Mdot
.71066 .47414 Mdot
.62377 .63484 Mdot
.41412 .35347 Mdot
.67682 .59249 Mdot
.6571 .35801 Mdot
.269 .48159 Mdot
.39838 .36147 Mdot
.64232 .63393 Mdot
.40741 .35404 Mdot
.69086 .46829 Mdot
.34223 .68476 Mdot
.64777 .64713 Mdot
.38489 .3616 Mdot
.53324 .68885 Mdot
.54127 .70608 Mdot
.39081 .71683 Mdot
.32413 .5608 Mdot
.72604 .56293 Mdot
.71789 .5592 Mdot
.65601 .64486 Mdot
.37581 .36524 Mdot
.34627 .55941 Mdot
.33555 .58667 Mdot
.32655 .58661 Mdot
.67866 .62262 Mdot
.33599 .55648 Mdot
.73417 .56212 Mdot
.48419 .72897 Mdot
.62926 .33534 Mdot
.34878 .57669 Mdot
.69477 .4575 Mdot
.32887 .57213 Mdot
.32647 .41479 Mdot
.43623 .72046 Mdot
.56884 .69583 Mdot
.7061 .44991 Mdot
.32833 .59869 Mdot
.4373 .31443 Mdot
.35634 .56799 Mdot
.27476 .44064 Mdot
.67895 .39453 Mdot
.33977 .65963 Mdot
.67745 .62498 Mdot
.70684 .56811 Mdot
.58601 .28993 Mdot
.68326 .43518 Mdot
.5986 .31835 Mdot
.56118 .73144 Mdot
.40176 .36198 Mdot
.49851 .27905 Mdot
.38488 .71602 Mdot
.33744 .67758 Mdot
.36646 .36954 Mdot
.65891 .65396 Mdot
.46641 .29129 Mdot
.32327 .60448 Mdot
.54069 .69767 Mdot
.31373 .41288 Mdot
.27949 .42859 Mdot
.25412 .4549 Mdot
.63682 .65483 Mdot
.74103 .56833 Mdot
.71406 .45766 Mdot
.5451 .2873 Mdot
.32326 .40267 Mdot
.73367 .43514 Mdot
.6961 .46887 Mdot
.46663 .28461 Mdot
.6929 .43602 Mdot
.3488 .56694 Mdot
.39853 .33385 Mdot
.62314 .64992 Mdot
.38272 .33442 Mdot
.33657 .63508 Mdot
.53885 .27546 Mdot
.37904 .36752 Mdot
.28057 .41406 Mdot
.69 .45196 Mdot
.58663 .3004 Mdot
.36585 .65635 Mdot
.71878 .55727 Mdot
.57001 .73231 Mdot
.44357 .29748 Mdot
.5691 .69753 Mdot
.57078 .69976 Mdot
.62893 .63618 Mdot
.37134 .32453 Mdot
.49618 .26851 Mdot
.57249 .69593 Mdot
.66034 .35048 Mdot
.30243 .45141 Mdot
.4976 .28829 Mdot
.60455 .3119 Mdot
.57948 .30879 Mdot
.33453 .64713 Mdot
.60874 .33036 Mdot
.4456 .72612 Mdot
.61479 .33578 Mdot
.67141 .39241 Mdot
.34857 .67358 Mdot
.56919 .30545 Mdot
.36051 .33575 Mdot
.3557 .65923 Mdot
.63929 .64192 Mdot
.60287 .33232 Mdot
.34048 .59534 Mdot
.54152 .26282 Mdot
.67058 .36149 Mdot
.37215 .3645 Mdot
.43171 .72565 Mdot
.70372 .44287 Mdot
.70198 .54757 Mdot
.4226 .70942 Mdot
.2929 .43351 Mdot
.65487 .63666 Mdot
.2861 .45624 Mdot
.31849 .43016 Mdot
.4773 .73409 Mdot
.68522 .56513 Mdot
.39785 .35192 Mdot
.2816 .42875 Mdot
.26742 .42276 Mdot
.58099 .31098 Mdot
.45073 .28969 Mdot
.36257 .34286 Mdot
.36595 .65449 Mdot
.49008 .28489 Mdot
.69474 .45194 Mdot
.32124 .5509 Mdot
.55892 .30376 Mdot
.39445 .34738 Mdot
.34182 .57915 Mdot
.5591 .70902 Mdot
.62158 .64452 Mdot
.41291 .34714 Mdot
.27801 .44419 Mdot
.64338 .64408 Mdot
.32101 .57571 Mdot
.26741 .44183 Mdot
.46472 .27467 Mdot
.35171 .65815 Mdot
.70619 .58262 Mdot
.72381 .58357 Mdot
.60371 .30431 Mdot
.72142 .46427 Mdot
.55247 .28052 Mdot
.27327 .43565 Mdot
.29486 .49724 Mdot
.35948 .35238 Mdot
.57245 .68961 Mdot
.44218 .72609 Mdot
.59452 .2977 Mdot
.7157 .57404 Mdot
.7347 .44616 Mdot
.43615 .72176 Mdot
.35246 .66145 Mdot
.33551 .57688 Mdot
.4748 .2788 Mdot
.72742 .54884 Mdot
.33703 .5761 Mdot
.41953 .34328 Mdot
.34932 .66505 Mdot
.3014 .41884 Mdot
.62403 .3352 Mdot
.35094 .3496 Mdot
.67978 .62904 Mdot
.38084 .36358 Mdot
.5613 .29863 Mdot
.41513 .70915 Mdot
.46595 .72913 Mdot
.25536 .46172 Mdot
.70789 .54345 Mdot
.62814 .67525 Mdot
.57134 .29498 Mdot
.46411 .27927 Mdot
.56231 .71334 Mdot
.5515 .71409 Mdot
.35676 .65944 Mdot
.59545 .3208 Mdot
.6118 .3097 Mdot
.40541 .35645 Mdot
.37587 .36929 Mdot
.48681 .72033 Mdot
.57577 .27951 Mdot
.33794 .55568 Mdot
.54577 .69599 Mdot
.68659 .45884 Mdot
.63835 .64903 Mdot
.64695 .36486 Mdot
.68368 .45243 Mdot
.3315 .61933 Mdot
.36798 .70921 Mdot
.6743 .37149 Mdot
.64707 .34578 Mdot
.46276 .28649 Mdot
.49437 .72296 Mdot
.32016 .42002 Mdot
.37105 .71404 Mdot
.59957 .3207 Mdot
.34151 .54827 Mdot
.72584 .57384 Mdot
.40951 .35889 Mdot
.72363 .42524 Mdot
.31978 .50946 Mdot
.55574 .72373 Mdot
.48367 .29002 Mdot
.36902 .33506 Mdot
.387 .33424 Mdot
.34632 .63601 Mdot
.33768 .55762 Mdot
.60467 .30654 Mdot
.50019 .72576 Mdot
.65671 .35866 Mdot
.46132 .28459 Mdot
.63396 .65572 Mdot
.33056 .56935 Mdot
.71827 .52988 Mdot
.68779 .45541 Mdot
.30937 .4457 Mdot
.30216 .40628 Mdot
.35653 .56634 Mdot
.57077 .71482 Mdot
.6717 .35584 Mdot
.55728 .71437 Mdot
.55007 .70504 Mdot
.36688 .34631 Mdot
.56694 .71526 Mdot
.32397 .53984 Mdot
.31536 .56169 Mdot
.36432 .32982 Mdot
.69142 .46601 Mdot
.3384 .63655 Mdot
.37365 .33229 Mdot
.43054 .71942 Mdot
.68517 .43686 Mdot
.55919 .71381 Mdot
.70334 .46143 Mdot
.46499 .28338 Mdot
.67125 .36479 Mdot
.27357 .42605 Mdot
.47022 .28571 Mdot
.63412 .62665 Mdot
.70133 .55961 Mdot
.71509 .43848 Mdot
.28355 .42652 Mdot
.69795 .45831 Mdot
.59096 .30108 Mdot
.66696 .35457 Mdot
.67047 .65904 Mdot
.39384 .71467 Mdot
.33274 .6212 Mdot
.73237 .45522 Mdot
.59103 .28546 Mdot
.70403 .57473 Mdot
.65133 .34996 Mdot
.44304 .73177 Mdot
.29559 .40998 Mdot
.33263 .57313 Mdot
.68951 .45389 Mdot
.48091 .28473 Mdot
.61643 .64629 Mdot
.27794 .43729 Mdot
.74592 .5503 Mdot
.58665 .28727 Mdot
.35077 .67306 Mdot
.65711 .38448 Mdot
.50851 .27295 Mdot
.66532 .35962 Mdot
.33053 .60517 Mdot
.38995 .36727 Mdot
.41579 .34601 Mdot
.62466 .67078 Mdot
.36216 .36984 Mdot
.43113 .32969 Mdot
.65746 .34742 Mdot
.64203 .62882 Mdot
.52493 .26953 Mdot
.3664 .65409 Mdot
.54745 .72771 Mdot
.36427 .35338 Mdot
.72374 .55317 Mdot
.56638 .70171 Mdot
.36139 .35827 Mdot
.48419 .72992 Mdot
.64329 .64916 Mdot
.5997 .32924 Mdot
.35648 .66682 Mdot
.66062 .38491 Mdot
.65678 .36402 Mdot
.40185 .36578 Mdot
.67469 .38393 Mdot
.43071 .71924 Mdot
.68483 .56837 Mdot
.55227 .72256 Mdot
.29913 .41985 Mdot
.70297 .5294 Mdot
.41096 .35222 Mdot
.26211 .47256 Mdot
.35521 .66968 Mdot
.57362 .29553 Mdot
.51605 .27541 Mdot
.4851 .72069 Mdot
.71385 .55743 Mdot
.44147 .72154 Mdot
.56862 .70724 Mdot
.555 .71409 Mdot
.54559 .28808 Mdot
.46992 .72537 Mdot
.33658 .55537 Mdot
.72621 .46399 Mdot
.41936 .72262 Mdot
.32122 .59405 Mdot
.41994 .34959 Mdot
.56848 .69547 Mdot
.67081 .39026 Mdot
.63522 .66429 Mdot
.57375 .29749 Mdot
.64924 .63558 Mdot
.63796 .66087 Mdot
.69648 .55837 Mdot
.73508 .43855 Mdot
.57157 .69517 Mdot
.70148 .40446 Mdot
.61332 .65586 Mdot
.32462 .60268 Mdot
.73078 .56868 Mdot
.48969 .26898 Mdot
.64418 .62776 Mdot
.70324 .54642 Mdot
.60429 .6541 Mdot
.72634 .54824 Mdot
.36099 .65547 Mdot
.35971 .64299 Mdot
.47604 .70972 Mdot
.48451 .27716 Mdot
.33503 .54895 Mdot
.4023 .3358 Mdot
.29559 .41875 Mdot
.63462 .63299 Mdot
.38134 .34327 Mdot
.47458 .73809 Mdot
.33922 .34895 Mdot
.32745 .54124 Mdot
.34151 .57495 Mdot
.54981 .71852 Mdot
.37675 .71952 Mdot
.49152 .27912 Mdot
.71951 .57593 Mdot
.3179 .58906 Mdot
.51254 .27305 Mdot
.35144 .68394 Mdot
.43966 .71887 Mdot
.31517 .56877 Mdot
.57444 .29659 Mdot
.62979 .65924 Mdot
.39931 .33895 Mdot
.72267 .52753 Mdot
.3279 .55503 Mdot
.33619 .35452 Mdot
.27091 .45068 Mdot
.33984 .57304 Mdot
.71347 .52804 Mdot
.5678 .70379 Mdot
.69964 .54571 Mdot
.6875 .55083 Mdot
.35229 .66199 Mdot
.62956 .65028 Mdot
.69339 .56074 Mdot
.55247 .71361 Mdot
.48516 .2892 Mdot
.67384 .3542 Mdot
.33827 .67509 Mdot
.27921 .43784 Mdot
.36307 .67662 Mdot
.32094 .43196 Mdot
.39088 .32981 Mdot
.36529 .33972 Mdot
.34555 .67194 Mdot
.58871 .28029 Mdot
.32723 .42537 Mdot
.48795 .27857 Mdot
.67424 .65301 Mdot
.61512 .67126 Mdot
.65679 .35632 Mdot
.44991 .28996 Mdot
.36512 .34191 Mdot
.34415 .62046 Mdot
.40873 .71661 Mdot
.67606 .37869 Mdot
.65594 .66746 Mdot
.33872 .6713 Mdot
.35758 .36736 Mdot
.59631 .33016 Mdot
.55308 .28551 Mdot
.65833 .34811 Mdot
.60149 .66109 Mdot
.35005 .5603 Mdot
.35889 .36759 Mdot
.56443 .68148 Mdot
.38717 .34185 Mdot
.40402 .3448 Mdot
.57913 .27031 Mdot
.34385 .56104 Mdot
.4734 .74121 Mdot
.58187 .32095 Mdot
.30954 .43977 Mdot
.65166 .6697 Mdot
.27068 .4401 Mdot
.6914 .39978 Mdot
.62238 .63884 Mdot
.59099 .31383 Mdot
.35035 .35389 Mdot
.33668 .54433 Mdot
.64014 .65838 Mdot
.65675 .65689 Mdot
.63628 .64523 Mdot
.29549 .42191 Mdot
.60819 .31704 Mdot
.47689 .27203 Mdot
.36414 .65729 Mdot
.68283 .57096 Mdot
.26204 .47456 Mdot
.36195 .67459 Mdot
.70364 .43613 Mdot
.56464 .69864 Mdot
.70209 .57952 Mdot
.56713 .68745 Mdot
.60985 .65864 Mdot
.5536 .28978 Mdot
.35768 .56833 Mdot
.35928 .65347 Mdot
.34037 .65842 Mdot
.29719 .44345 Mdot
.71789 .53765 Mdot
.3644 .7121 Mdot
.33829 .69284 Mdot
.34389 .63542 Mdot
.33725 .58075 Mdot
.33308 .62217 Mdot
.3904 .32328 Mdot
.35765 .35388 Mdot
.44588 .73029 Mdot
.32212 .56911 Mdot
.70474 .53174 Mdot
.61978 .65232 Mdot
.50957 .71348 Mdot
.71058 .46889 Mdot
.64517 .62643 Mdot
.58363 .32274 Mdot
.60113 .3334 Mdot
.51948 .26844 Mdot
.27547 .41446 Mdot
.55922 .71676 Mdot
.35505 .55046 Mdot
.7161 .47091 Mdot
.28961 .43379 Mdot
.68155 .56577 Mdot
.32103 .42632 Mdot
.46136 .71524 Mdot
.27493 .42406 Mdot
.39795 .36643 Mdot
.67175 .39472 Mdot
.54513 .69664 Mdot
.29422 .4479 Mdot
.64078 .64586 Mdot
.33823 .66798 Mdot
.34993 .64365 Mdot
.74341 .56476 Mdot
.31936 .41469 Mdot
.47379 .27143 Mdot
.35372 .67972 Mdot
.34879 .708 Mdot
.7056 .4643 Mdot
.27308 .42852 Mdot
.70012 .43272 Mdot
.55832 .70034 Mdot
.63064 .67723 Mdot
.7126 .56325 Mdot
.65439 .36038 Mdot
.4404 .71977 Mdot
.27331 .42213 Mdot
.58738 .31184 Mdot
.49381 .71968 Mdot
.49464 .27977 Mdot
.34306 .33792 Mdot
.34055 .64391 Mdot
.46937 .29321 Mdot
.31727 .58645 Mdot
.66451 .36725 Mdot
.35375 .57837 Mdot
.56532 .68908 Mdot
.35675 .6955 Mdot
.56713 .31362 Mdot
.57838 .30797 Mdot
.49339 .27629 Mdot
.33354 .67306 Mdot
.31368 .57395 Mdot
.64611 .66009 Mdot
.60672 .31267 Mdot
.69724 .56738 Mdot
.7252 .5593 Mdot
.57589 .27003 Mdot
.70482 .53887 Mdot
.31878 .42638 Mdot
.35982 .69887 Mdot
.66488 .36696 Mdot
.66267 .3581 Mdot
.5885 .30998 Mdot
.56138 .26774 Mdot
.57496 .29533 Mdot
.56297 .70025 Mdot
.68639 .56726 Mdot
.36726 .71531 Mdot
.32291 .55853 Mdot
.34917 .58397 Mdot
.63327 .65677 Mdot
.43718 .72459 Mdot
.32246 .51189 Mdot
.3125 .41398 Mdot
.56252 .29802 Mdot
.69041 .43462 Mdot
.58217 .71901 Mdot
.72257 .46817 Mdot
.349 .65976 Mdot
.67798 .36241 Mdot
.65995 .66268 Mdot
.27857 .41945 Mdot
.55241 .69534 Mdot
.294 .40727 Mdot
.68799 .46101 Mdot
.65431 .65769 Mdot
.46793 .72035 Mdot
.34886 .66957 Mdot
.45665 .72576 Mdot
.33477 .37322 Mdot
.61177 .65069 Mdot
.71621 .44627 Mdot
.54451 .69913 Mdot
.34318 .3417 Mdot
.5469 .68672 Mdot
.33519 .64436 Mdot
.33646 .60389 Mdot
.33768 .62557 Mdot
.36325 .64419 Mdot
.63173 .64391 Mdot
.44728 .71713 Mdot
.35281 .35861 Mdot
.36037 .6492 Mdot
.70058 .40984 Mdot
.33326 .54028 Mdot
.34657 .58555 Mdot
.34573 .54653 Mdot
.3334 .6044 Mdot
.64216 .62472 Mdot
.54556 .71886 Mdot
.7214 .46733 Mdot
.34538 .70127 Mdot
.64901 .35595 Mdot
.58737 .30558 Mdot
.41127 .35901 Mdot
.62721 .64456 Mdot
.29507 .40734 Mdot
.68939 .39149 Mdot
.35284 .70784 Mdot
.52151 .26641 Mdot
.36287 .63796 Mdot
.41758 .35074 Mdot
.39852 .33553 Mdot
.27222 .42215 Mdot
.54249 .28715 Mdot
.69783 .44802 Mdot
.32123 .586 Mdot
.69991 .57045 Mdot
.70732 .55074 Mdot
.357 .65063 Mdot
.69461 .47397 Mdot
.65714 .36403 Mdot
.4745 .28468 Mdot
.34957 .561 Mdot
.3604 .6441 Mdot
.69637 .54412 Mdot
.45863 .28007 Mdot
.46835 .73467 Mdot
.3029 .43143 Mdot
.34518 .52996 Mdot
.35292 .36121 Mdot
.45057 .71853 Mdot
.7178 .46784 Mdot
.39489 .35172 Mdot
.34946 .5412 Mdot
.36664 .71139 Mdot
.56902 .68499 Mdot
.25369 .44557 Mdot
.61022 .30927 Mdot
.3534 .66534 Mdot
.35766 .67393 Mdot
.64319 .65025 Mdot
.66921 .36268 Mdot
.71439 .57584 Mdot
.67358 .64294 Mdot
.3652 .34022 Mdot
.67208 .36214 Mdot
.34768 .59667 Mdot
.67574 .39048 Mdot
.56509 .69823 Mdot
.3347 .65925 Mdot
.71675 .44746 Mdot
.69505 .54101 Mdot
.67809 .60148 Mdot
.34499 .65648 Mdot
.55149 .70237 Mdot
.36261 .67691 Mdot
.45894 .28203 Mdot
.4081 .36117 Mdot
.34884 .66812 Mdot
.71417 .54817 Mdot
.3629 .67013 Mdot
.68947 .46142 Mdot
.29098 .45061 Mdot
.71074 .55634 Mdot
.47974 .2924 Mdot
.54831 .28702 Mdot
.60088 .29734 Mdot
.39918 .36487 Mdot
.56848 .71085 Mdot
.64923 .64061 Mdot
.70933 .58205 Mdot
.45103 .72595 Mdot
.56181 .2991 Mdot
.30406 .42294 Mdot
.37196 .65938 Mdot
.35016 .35954 Mdot
.65959 .38321 Mdot
.68016 .61848 Mdot
.4844 .72769 Mdot
.26835 .43389 Mdot
.41202 .71584 Mdot
.36995 .34549 Mdot
.34651 .56827 Mdot
.273 .42585 Mdot
.55753 .26913 Mdot
.56393 .68436 Mdot
.39686 .32394 Mdot
.48999 .28159 Mdot
.54086 .28994 Mdot
.65191 .35978 Mdot
.61198 .31759 Mdot
.29515 .40565 Mdot
.3567 .34135 Mdot
.70633 .55493 Mdot
.34047 .56478 Mdot
.36718 .35142 Mdot
.56127 .29029 Mdot
.40075 .36062 Mdot
.34004 .59138 Mdot
.72788 .53631 Mdot
.59427 .30689 Mdot
.35992 .67106 Mdot
.57086 .69337 Mdot
.62713 .6357 Mdot
.47993 .28841 Mdot
.44331 .72299 Mdot
.31843 .40064 Mdot
.52501 .27705 Mdot
.56312 .31012 Mdot
.35262 .65204 Mdot
.29718 .41215 Mdot
.32716 .5648 Mdot
.6978 .44267 Mdot
.42119 .71332 Mdot
.66718 .36055 Mdot
.36285 .63461 Mdot
.36736 .64861 Mdot
.43793 .70899 Mdot
.61296 .67995 Mdot
.43534 .31823 Mdot
.3617 .63076 Mdot
.33443 .58763 Mdot
.72935 .5696 Mdot
.46224 .74176 Mdot
.39802 .71652 Mdot
.62606 .65777 Mdot
.27591 .45084 Mdot
.70334 .46529 Mdot
.3713 .66395 Mdot
.6949 .39913 Mdot
.30199 .41955 Mdot
.34901 .63418 Mdot
.48976 .72739 Mdot
.71566 .57173 Mdot
.35498 .55255 Mdot
.70808 .56333 Mdot
.33664 .67389 Mdot
.63334 .62907 Mdot
.65406 .3504 Mdot
.3415 .61517 Mdot
.35817 .33912 Mdot
.50949 .27348 Mdot
.33257 .61768 Mdot
.31319 .42206 Mdot
.5633 .68816 Mdot
.36939 .33994 Mdot
.69727 .43751 Mdot
.66284 .34429 Mdot
.57317 .29447 Mdot
.72433 .47272 Mdot
.64469 .63142 Mdot
.47956 .28455 Mdot
.38945 .36578 Mdot
.56401 .68266 Mdot
.32626 .40467 Mdot
.67364 .36386 Mdot
.33171 .58145 Mdot
.35347 .56765 Mdot
.47536 .27846 Mdot
.62466 .33572 Mdot
.73591 .54952 Mdot
.62651 .63303 Mdot
.6541 .65606 Mdot
.30421 .4416 Mdot
.48332 .28679 Mdot
.35833 .5607 Mdot
.33942 .55236 Mdot
.5381 .27129 Mdot
.6303 .65838 Mdot
.29219 .41854 Mdot
.41547 .34604 Mdot
.71531 .47172 Mdot
.5047 .27964 Mdot
.70934 .55612 Mdot
.50271 .28452 Mdot
.47199 .2731 Mdot
.61918 .63211 Mdot
.35446 .63039 Mdot
.70225 .44521 Mdot
.50087 .28697 Mdot
.70207 .58078 Mdot
.34767 .66061 Mdot
.39044 .33926 Mdot
.39806 .36507 Mdot
.60993 .66552 Mdot
.59398 .3119 Mdot
.30252 .41044 Mdot
.33707 .6362 Mdot
.26621 .42396 Mdot
.63489 .66035 Mdot
.58557 .28442 Mdot
.38938 .35083 Mdot
.68627 .43556 Mdot
.36385 .67004 Mdot
.29666 .41952 Mdot
.70375 .44674 Mdot
.35371 .35432 Mdot
.35539 .70278 Mdot
.42273 .71016 Mdot
.57236 .70135 Mdot
.70769 .46326 Mdot
.4606 .73072 Mdot
.32979 .53601 Mdot
.66432 .3675 Mdot
.28179 .45667 Mdot
.50697 .27333 Mdot
.42629 .71886 Mdot
.65717 .34725 Mdot
.53742 .27003 Mdot
.61401 .32324 Mdot
.44797 .28929 Mdot
.49147 .27936 Mdot
.65453 .36618 Mdot
.38024 .34956 Mdot
.49347 .27414 Mdot
.66864 .36227 Mdot
.45125 .7135 Mdot
.37119 .66256 Mdot
.49944 .72749 Mdot
.35158 .35171 Mdot
.3737 .36296 Mdot
.62174 .66203 Mdot
.53853 .71117 Mdot
.38848 .34812 Mdot
.32484 .57939 Mdot
.65789 .65256 Mdot
.71558 .4439 Mdot
.26449 .47807 Mdot
.71067 .47526 Mdot
.56553 .68384 Mdot
.54741 .30259 Mdot
.47666 .2863 Mdot
.34003 .56619 Mdot
.68726 .38113 Mdot
.26983 .48208 Mdot
.37103 .66528 Mdot
.55242 .69529 Mdot
.36772 .63872 Mdot
.35952 .64922 Mdot
.66124 .6302 Mdot
.36048 .36566 Mdot
.65658 .64656 Mdot
.70578 .44445 Mdot
.28929 .45155 Mdot
.42964 .33289 Mdot
.70789 .46546 Mdot
.33062 .54663 Mdot
.40419 .36527 Mdot
.33546 .57353 Mdot
.32595 .58761 Mdot
.33597 .68978 Mdot
.26254 .42234 Mdot
.58298 .299 Mdot
.30088 .40544 Mdot
.7153 .54173 Mdot
.67768 .61811 Mdot
.31145 .42058 Mdot
.49187 .71953 Mdot
.47242 .73623 Mdot
.6249 .33464 Mdot
.70815 .55063 Mdot
.3234 .42593 Mdot
.69585 .46044 Mdot
.40593 .72204 Mdot
.47554 .71192 Mdot
.7273 .46699 Mdot
.34096 .58779 Mdot
.70922 .5826 Mdot
.62509 .66152 Mdot
.67391 .3613 Mdot
.70621 .58199 Mdot
.4639 .73105 Mdot
.55808 .7017 Mdot
.71727 .4689 Mdot
.35508 .62301 Mdot
.66752 .35892 Mdot
.32747 .61552 Mdot
.55092 .69944 Mdot
.71236 .55723 Mdot
.33219 .60989 Mdot
.69863 .53429 Mdot
.36652 .35989 Mdot
.34038 .69667 Mdot
.30662 .4228 Mdot
.45909 .72715 Mdot
.47121 .29611 Mdot
.65534 .67077 Mdot
.70544 .57639 Mdot
.6858 .46103 Mdot
.72056 .56703 Mdot
.62727 .67237 Mdot
.73375 .46013 Mdot
.64947 .62642 Mdot
.32844 .55344 Mdot
.67789 .6124 Mdot
.64859 .63815 Mdot
.71355 .45292 Mdot
.29405 .42836 Mdot
.63447 .64802 Mdot
.46899 .27592 Mdot
.35568 .66314 Mdot
.57006 .28217 Mdot
.3252 .41574 Mdot
.628 .64425 Mdot
.31057 .42318 Mdot
.56659 .28996 Mdot
.41914 .34862 Mdot
.64776 .3688 Mdot
.67815 .3866 Mdot
.40653 .33376 Mdot
.66249 .34992 Mdot
.72268 .5445 Mdot
.49233 .28667 Mdot
.34522 .61334 Mdot
.34849 .55847 Mdot
.32627 .4139 Mdot
.72952 .54978 Mdot
.68496 .39216 Mdot
.38318 .34368 Mdot
.63306 .66672 Mdot
.68726 .43812 Mdot
.47069 .28743 Mdot
.4701 .74157 Mdot
.65187 .35722 Mdot
.35024 .355 Mdot
.36789 .34396 Mdot
.33524 .5774 Mdot
.34668 .64066 Mdot
.27593 .43706 Mdot
.5019 .27335 Mdot
.53442 .7194 Mdot
.5624 .26709 Mdot
.33962 .54003 Mdot
.54093 .72311 Mdot
.3189 .55806 Mdot
.30432 .4032 Mdot
.651 .36353 Mdot
.70266 .55447 Mdot
.31382 .4428 Mdot
.5475 .2858 Mdot
.4274 .72538 Mdot
.35392 .6417 Mdot
.4565 .73285 Mdot
.58977 .32636 Mdot
.72844 .55565 Mdot
.57984 .30393 Mdot
.66356 .36858 Mdot
.31861 .4224 Mdot
.5657 .70132 Mdot
.35094 .35074 Mdot
.59775 .30206 Mdot
.71744 .44014 Mdot
.48121 .29299 Mdot
.65981 .34345 Mdot
.36642 .34033 Mdot
.44686 .73517 Mdot
.60861 .33142 Mdot
.39229 .33743 Mdot
.61559 .66581 Mdot
.35595 .71528 Mdot
.6064 .67151 Mdot
.59625 .32049 Mdot
.25599 .46288 Mdot
.7075 .44797 Mdot
.64478 .34435 Mdot
.32392 .60414 Mdot
.28409 .49162 Mdot
.33501 .63831 Mdot
.6805 .39811 Mdot
.66558 .36581 Mdot
.70759 .46008 Mdot
.57623 .30109 Mdot
.70524 .53371 Mdot
.53054 .69024 Mdot
.59957 .32713 Mdot
.34857 .61576 Mdot
.68159 .56592 Mdot
.47064 .70868 Mdot
.60772 .32556 Mdot
.55141 .71564 Mdot
.61642 .64143 Mdot
.32513 .42259 Mdot
.33828 .65087 Mdot
.65509 .36076 Mdot
.36741 .67198 Mdot
.70258 .40274 Mdot
.56859 .29501 Mdot
.40134 .34917 Mdot
.68024 .43928 Mdot
.35204 .57393 Mdot
.34067 .54606 Mdot
.32802 .54299 Mdot
.32175 .41034 Mdot
.61408 .66116 Mdot
.3483 .69044 Mdot
.3613 .70236 Mdot
.53995 .72749 Mdot
.45034 .29267 Mdot
.29163 .40731 Mdot
.37207 .71345 Mdot
.53477 .26575 Mdot
.62577 .66563 Mdot
.34496 .5963 Mdot
.64759 .36131 Mdot
.5393 .71401 Mdot
.72022 .45848 Mdot
.69167 .43119 Mdot
.5116 .28334 Mdot
.71904 .54878 Mdot
.55298 .72554 Mdot
.60355 .29566 Mdot
.6119 .68093 Mdot
.54746 .72507 Mdot
.63425 .62593 Mdot
.69282 .4678 Mdot
.29355 .49733 Mdot
.64428 .35625 Mdot
.39554 .36649 Mdot
.64826 .62962 Mdot
.67827 .58065 Mdot
.44911 .71976 Mdot
.69323 .57159 Mdot
.47699 .27867 Mdot
.65124 .64066 Mdot
.44041 .30658 Mdot
.65573 .65834 Mdot
.70918 .4525 Mdot
.66948 .35864 Mdot
.5537 .72006 Mdot
.32973 .55693 Mdot
.47554 .72365 Mdot
.38384 .34341 Mdot
.44712 .73433 Mdot
.58147 .32051 Mdot
.47486 .27383 Mdot
.67442 .39558 Mdot
.65885 .62978 Mdot
.72974 .46731 Mdot
.34037 .54494 Mdot
.55295 .69872 Mdot
.36016 .64289 Mdot
.65421 .35365 Mdot
.56022 .68065 Mdot
.32319 .56533 Mdot
.55856 .71692 Mdot
.58803 .32798 Mdot
.56217 .26526 Mdot
.59959 .66673 Mdot
.50986 .28193 Mdot
.33688 .5848 Mdot
.29958 .43859 Mdot
.27852 .41164 Mdot
.34733 .64881 Mdot
.52003 .27782 Mdot
.46945 .73397 Mdot
.33061 .58103 Mdot
.4196 .71569 Mdot
.59516 .33024 Mdot
.37294 .37226 Mdot
.55954 .29204 Mdot
.64249 .62368 Mdot
.40319 .338 Mdot
.56674 .31005 Mdot
.48022 .7369 Mdot
.36554 .34833 Mdot
.50852 .27475 Mdot
.30192 .41756 Mdot
.31991 .55815 Mdot
.32439 .5119 Mdot
.60999 .32272 Mdot
.70281 .45264 Mdot
.6349 .64012 Mdot
.72227 .46332 Mdot
.54856 .26478 Mdot
.34868 .63113 Mdot
.35949 .35969 Mdot
.65111 .34103 Mdot
.5452 .73115 Mdot
.29334 .43704 Mdot
.64382 .35761 Mdot
.56729 .71602 Mdot
.35033 .64368 Mdot
.27466 .48522 Mdot
.34996 .57821 Mdot
.47852 .2734 Mdot
.67382 .36503 Mdot
.25781 .43422 Mdot
.33951 .56093 Mdot
.57052 .27878 Mdot
.26803 .41942 Mdot
.33225 .57657 Mdot
.47555 .29279 Mdot
.35783 .67545 Mdot
.27325 .42705 Mdot
.64489 .64783 Mdot
.41918 .71049 Mdot
.33374 .41542 Mdot
.31277 .4435 Mdot
.33595 .63186 Mdot
.36533 .64447 Mdot
.49748 .27228 Mdot
.71675 .57096 Mdot
.35084 .66807 Mdot
.32547 .41085 Mdot
.66152 .65129 Mdot
.649 .63488 Mdot
.56785 .68417 Mdot
.68392 .4345 Mdot
.5928 .30806 Mdot
.28089 .4346 Mdot
.46204 .27745 Mdot
.36967 .66356 Mdot
.55897 .68758 Mdot
.31283 .41648 Mdot
.706 .43708 Mdot
.56661 .70969 Mdot
.67938 .45226 Mdot
.34691 .7017 Mdot
.64204 .3508 Mdot
.34479 .5982 Mdot
.33496 .61136 Mdot
.65194 .64619 Mdot
.70243 .40797 Mdot
.65374 .34527 Mdot
.55071 .2856 Mdot
.38846 .35102 Mdot
.67807 .61719 Mdot
.29636 .4208 Mdot
.52279 .69547 Mdot
.34723 .57966 Mdot
.35874 .56284 Mdot
.65124 .64383 Mdot
.35639 .64044 Mdot
.66433 .64277 Mdot
.46346 .27866 Mdot
.28512 .49275 Mdot
.70395 .55832 Mdot
.71228 .57202 Mdot
.55893 .73416 Mdot
.51589 .27025 Mdot
.65047 .67081 Mdot
.37134 .66592 Mdot
.5591 .26507 Mdot
.25385 .44478 Mdot
.28724 .4244 Mdot
.25866 .43133 Mdot
.65212 .67128 Mdot
.49112 .7334 Mdot
.56853 .69889 Mdot
.34628 .67403 Mdot
.41361 .71686 Mdot
.66492 .36924 Mdot
.35175 .69454 Mdot
.37724 .34286 Mdot
.56348 .29224 Mdot
.31889 .58725 Mdot
.32297 .57672 Mdot
.7006 .55555 Mdot
.29482 .45193 Mdot
.73177 .45912 Mdot
.39475 .33765 Mdot
.61147 .32239 Mdot
.31095 .43327 Mdot
.70804 .53653 Mdot
.33046 .61279 Mdot
.3723 .32689 Mdot
.36401 .36888 Mdot
.33956 .58613 Mdot
.35293 .66605 Mdot
.35308 .33327 Mdot
.7157 .46209 Mdot
.55126 .28397 Mdot
.3934 .33356 Mdot
.46257 .72838 Mdot
.42106 .71551 Mdot
.34205 .55275 Mdot
.69218 .53958 Mdot
.71397 .43716 Mdot
.36588 .36196 Mdot
.49933 .28672 Mdot
.37206 .6587 Mdot
.47002 .71265 Mdot
.3362 .36122 Mdot
.37864 .34589 Mdot
.53048 .68996 Mdot
.2903 .41009 Mdot
.55016 .70001 Mdot
.34955 .70481 Mdot
.43359 .72271 Mdot
.3529 .58221 Mdot
.55257 .26939 Mdot
.68894 .44432 Mdot
.40162 .32826 Mdot
.56379 .29889 Mdot
.64861 .63522 Mdot
.34609 .67224 Mdot
.72667 .55953 Mdot
.71322 .5795 Mdot
.62009 .67167 Mdot
.70462 .46875 Mdot
.67995 .62794 Mdot
.35443 .33328 Mdot
.34997 .56724 Mdot
.67146 .37089 Mdot
.64553 .67374 Mdot
.43202 .71399 Mdot
.66115 .66104 Mdot
.72136 .54039 Mdot
.42725 .71551 Mdot
.5591 .70954 Mdot
.3593 .70519 Mdot
.33511 .60218 Mdot
.29972 .40826 Mdot
.68128 .57819 Mdot
.46494 .71087 Mdot
.33496 .64661 Mdot
.34275 .56521 Mdot
.55077 .72095 Mdot
.26285 .42468 Mdot
.36164 .63891 Mdot
.34789 .57465 Mdot
.37178 .71502 Mdot
.4337 .71517 Mdot
.73152 .56405 Mdot
.65064 .37459 Mdot
.56989 .68398 Mdot
.52767 .27669 Mdot
.64272 .65704 Mdot
.32488 .42875 Mdot
.66825 .6547 Mdot
.57369 .70913 Mdot
.69647 .45545 Mdot
.70264 .5794 Mdot
.59249 .30124 Mdot
.70087 .44935 Mdot
.66731 .35882 Mdot
.54805 .71927 Mdot
.5488 .2771 Mdot
.28014 .45346 Mdot
.65032 .35787 Mdot
.55594 .68265 Mdot
.70844 .45303 Mdot
.61169 .64189 Mdot
.45039 .73678 Mdot
.35196 .70437 Mdot
.37924 .35424 Mdot
.39418 .32452 Mdot
.66124 .36795 Mdot
.30108 .43093 Mdot
.566 .71254 Mdot
.63543 .64483 Mdot
.29527 .43479 Mdot
.61584 .64702 Mdot
.46996 .28901 Mdot
.62971 .66355 Mdot
.4712 .27969 Mdot
.69085 .56774 Mdot
.33893 .64803 Mdot
.30966 .44717 Mdot
.34857 .33613 Mdot
.46896 .71639 Mdot
.39017 .35374 Mdot
.32851 .59677 Mdot
.5605 .72058 Mdot
.32821 .55206 Mdot
.51919 .26466 Mdot
.32929 .4178 Mdot
.65396 .64085 Mdot
.42546 .34226 Mdot
.72106 .44701 Mdot
.45591 .73109 Mdot
.4013 .34583 Mdot
.55196 .70134 Mdot
.66369 .64757 Mdot
.69657 .55208 Mdot
.63743 .62563 Mdot
.52336 .27436 Mdot
.43395 .31978 Mdot
.33732 .54708 Mdot
.4238 .34426 Mdot
.66385 .36329 Mdot
.67036 .35402 Mdot
.58153 .28936 Mdot
.30205 .50016 Mdot
.56508 .3017 Mdot
.2542 .44913 Mdot
.69057 .56334 Mdot
.27867 .44578 Mdot
.33219 .54994 Mdot
.62929 .65296 Mdot
.52841 .69223 Mdot
.29409 .45374 Mdot
.29151 .40821 Mdot
.66807 .35351 Mdot
.6747 .37173 Mdot
.39885 .3574 Mdot
.43491 .7155 Mdot
.43458 .71159 Mdot
.35574 .56738 Mdot
.66097 .3708 Mdot
.55384 .70568 Mdot
.64538 .36592 Mdot
.54872 .69597 Mdot
.32989 .41658 Mdot
.55689 .30532 Mdot
.62904 .33533 Mdot
.63753 .65694 Mdot
.34571 .67382 Mdot
.61661 .67291 Mdot
.35959 .71247 Mdot
.65631 .34163 Mdot
.28999 .45644 Mdot
.5797 .29915 Mdot
.6883 .40216 Mdot
.55447 .30176 Mdot
.33388 .392 Mdot
.49743 .73171 Mdot
.68466 .45862 Mdot
.45487 .73528 Mdot
.57914 .27261 Mdot
.33059 .60013 Mdot
.37979 .33053 Mdot
.40438 .36507 Mdot
.55591 .73219 Mdot
.62359 .63876 Mdot
.30259 .40675 Mdot
.33246 .5492 Mdot
.62437 .6293 Mdot
.33396 .55001 Mdot
.33508 .54946 Mdot
.3238 .58589 Mdot
.65639 .35652 Mdot
.45894 .73764 Mdot
.329 .55589 Mdot
.49536 .27695 Mdot
.25374 .43834 Mdot
.61206 .33307 Mdot
.65229 .6475 Mdot
.28959 .43384 Mdot
.64222 .65973 Mdot
.47064 .72472 Mdot
.70242 .47484 Mdot
.61425 .65843 Mdot
.55015 .71121 Mdot
.65757 .66833 Mdot
.6465 .34392 Mdot
.30455 .4116 Mdot
.37285 .34258 Mdot
.73559 .44688 Mdot
.48781 .27853 Mdot
.39275 .34484 Mdot
.47516 .29069 Mdot
.3461 .59295 Mdot
.70872 .55329 Mdot
.39028 .35071 Mdot
.7091 .43334 Mdot
.57697 .26962 Mdot
.34652 .7069 Mdot
.36305 .66299 Mdot
.58765 .3248 Mdot
.37498 .35166 Mdot
.46047 .72695 Mdot
.47009 .73993 Mdot
.58111 .2736 Mdot
.73438 .45544 Mdot
.66148 .36197 Mdot
.29095 .42828 Mdot
.72914 .55131 Mdot
.69805 .55431 Mdot
.71467 .44194 Mdot
.68858 .384 Mdot
.36068 .6578 Mdot
.36097 .66987 Mdot
.46071 .71868 Mdot
.33415 .6051 Mdot
.49575 .28807 Mdot
.38918 .34142 Mdot
.70208 .5722 Mdot
.55751 .72282 Mdot
.53555 .70777 Mdot
.33245 .54433 Mdot
.34855 .62839 Mdot
.5989 .31578 Mdot
.55487 .69582 Mdot
.27317 .42885 Mdot
.67797 .62271 Mdot
.35652 .67542 Mdot
.3307 .41703 Mdot
.69491 .55945 Mdot
.50635 .27491 Mdot
.70377 .45394 Mdot
.59621 .28649 Mdot
.60024 .29106 Mdot
.3336 .37443 Mdot
.6417 .65559 Mdot
.39237 .34473 Mdot
.47934 .29615 Mdot
.40146 .36572 Mdot
.2844 .41203 Mdot
.34405 .65097 Mdot
.47993 .27754 Mdot
.61447 .33542 Mdot
.68235 .44886 Mdot
.34208 .69421 Mdot
.33998 .52953 Mdot
.65717 .34623 Mdot
.33929 .57829 Mdot
.31234 .41877 Mdot
.67182 .37827 Mdot
.70489 .57916 Mdot
.29973 .40982 Mdot
.6526 .3697 Mdot
.69979 .55022 Mdot
.54967 .71813 Mdot
.4333 .71354 Mdot
.63933 .63812 Mdot
.70251 .53931 Mdot
.3606 .6559 Mdot
.51025 .28445 Mdot
.70173 .56371 Mdot
.63875 .63268 Mdot
.63975 .62289 Mdot
.5924 .28848 Mdot
.27126 .41782 Mdot
.68509 .45371 Mdot
.32633 .56174 Mdot
.55401 .30527 Mdot
.28747 .44221 Mdot
.69806 .5783 Mdot
.3238 .54036 Mdot
.36913 .6647 Mdot
.29532 .43728 Mdot
.29149 .4061 Mdot
.29813 .43234 Mdot
.66657 .35569 Mdot
.55061 .71404 Mdot
.66111 .63957 Mdot
.65023 .34434 Mdot
.32404 .422 Mdot
.33333 .40724 Mdot
.43749 .3138 Mdot
.36015 .66185 Mdot
.30837 .40277 Mdot
.67944 .62055 Mdot
.47727 .74264 Mdot
.40199 .36546 Mdot
.25412 .45983 Mdot
.51186 .26651 Mdot
.25303 .45285 Mdot
.6896 .44812 Mdot
.54264 .70245 Mdot
.28783 .42204 Mdot
.36027 .34632 Mdot
.36231 .66083 Mdot
.36441 .64828 Mdot
.30224 .43704 Mdot
.3585 .63244 Mdot
.70543 .54853 Mdot
.60929 .67437 Mdot
.29045 .4355 Mdot
.57049 .27281 Mdot
.59967 .32984 Mdot
.57808 .30966 Mdot
.34489 .56105 Mdot
.45621 .7058 Mdot
.40992 .72092 Mdot
.64101 .62338 Mdot
.67151 .36574 Mdot
.69286 .56087 Mdot
.67754 .60649 Mdot
.65209 .63614 Mdot
.57283 .26751 Mdot
.30125 .43056 Mdot
.69385 .53784 Mdot
.67 .35809 Mdot
.65949 .36692 Mdot
.61158 .3277 Mdot
.56026 .29846 Mdot
.58933 .31275 Mdot
.62706 .64757 Mdot
.73661 .5766 Mdot
.438 .72832 Mdot
.71181 .5797 Mdot
.53515 .26377 Mdot
.46345 .27934 Mdot
.61043 .32663 Mdot
.7151 .45101 Mdot
.68834 .54893 Mdot
.3582 .67158 Mdot
.32528 .51361 Mdot
.59906 .33041 Mdot
.31997 .4153 Mdot
.6804 .61453 Mdot
.28304 .49072 Mdot
.54781 .69284 Mdot
.69852 .43491 Mdot
.361 .35299 Mdot
.33073 .53932 Mdot
.5535 .28602 Mdot
.25529 .45913 Mdot
.36482 .36663 Mdot
.44856 .72832 Mdot
.67521 .64973 Mdot
.69507 .44608 Mdot
.46387 .74204 Mdot
.37011 .3328 Mdot
.55326 .72727 Mdot
.67047 .3771 Mdot
.60087 .30598 Mdot
.44809 .29087 Mdot
.62149 .66096 Mdot
.34293 .6679 Mdot
.35591 .35341 Mdot
.33368 .64768 Mdot
.57184 .3125 Mdot
.29723 .41101 Mdot
.58247 .31816 Mdot
.7322 .56215 Mdot
.60257 .30221 Mdot
.32851 .53811 Mdot
.66208 .646 Mdot
.66207 .36472 Mdot
.40574 .71896 Mdot
.42781 .33794 Mdot
.58403 .2859 Mdot
.35034 .3342 Mdot
.53757 .7133 Mdot
.56786 .68227 Mdot
.40356 .32904 Mdot
.3285 .53653 Mdot
.71789 .44876 Mdot
.66234 .63766 Mdot
.71992 .4443 Mdot
.2704 .41705 Mdot
.73487 .44272 Mdot
.70325 .45466 Mdot
.48381 .71137 Mdot
.30437 .40986 Mdot
.34973 .63032 Mdot
.32202 .57012 Mdot
.69694 .43219 Mdot
.46108 .73392 Mdot
.62485 .62876 Mdot
.47956 .73662 Mdot
.35583 .70123 Mdot
.71695 .44543 Mdot
.38948 .36634 Mdot
.46603 .74034 Mdot
.2673 .41914 Mdot
.65424 .36544 Mdot
.41765 .7112 Mdot
.38932 .33945 Mdot
.31469 .43174 Mdot
.314 .4074 Mdot
.31051 .4294 Mdot
.32565 .54573 Mdot
.33696 .61764 Mdot
.31492 .44254 Mdot
.73388 .46045 Mdot
.31614 .43872 Mdot
.27934 .45998 Mdot
.68357 .40186 Mdot
.2943 .40584 Mdot
.33156 .58247 Mdot
.54729 .69695 Mdot
.54183 .70435 Mdot
.56889 .28403 Mdot
.72216 .42398 Mdot
.48829 .27393 Mdot
.35658 .55099 Mdot
.74541 .55672 Mdot
.64866 .6415 Mdot
.36791 .32224 Mdot
.36047 .69932 Mdot
.57191 .70936 Mdot
.64564 .63315 Mdot
.45714 .72038 Mdot
.63204 .66467 Mdot
.37355 .32998 Mdot
.33187 .53635 Mdot
.64743 .65035 Mdot
.63142 .67636 Mdot
.35673 .62984 Mdot
.63355 .66637 Mdot
.68961 .57171 Mdot
.67038 .3629 Mdot
.69088 .45432 Mdot
.71786 .44778 Mdot
.55362 .29356 Mdot
.70998 .57418 Mdot
.3487 .67451 Mdot
.55205 .28765 Mdot
.34237 .58661 Mdot
.71616 .44403 Mdot
.33393 .64069 Mdot
.71234 .57263 Mdot
.32753 .57911 Mdot
.48733 .71414 Mdot
.47244 .29237 Mdot
.29687 .43724 Mdot
.62411 .6355 Mdot
.45293 .28445 Mdot
.65141 .3589 Mdot
.71604 .58499 Mdot
.28598 .45848 Mdot
.54936 .72913 Mdot
.34502 .5285 Mdot
.3193 .58018 Mdot
.54945 .72885 Mdot
.49482 .73308 Mdot
.3721 .36898 Mdot
.54773 .28629 Mdot
.59936 .29289 Mdot
.35628 .6569 Mdot
.70968 .57037 Mdot
.27072 .42541 Mdot
.333 .41679 Mdot
.38923 .32018 Mdot
.47406 .73393 Mdot
.3611 .70225 Mdot
.3326 .6775 Mdot
.345 .67279 Mdot
.57809 .29028 Mdot
.37651 .37229 Mdot
.45015 .72112 Mdot
.31649 .42368 Mdot
.35032 .67839 Mdot
.65122 .64964 Mdot
.69139 .57822 Mdot
.59628 .31678 Mdot
.66001 .38471 Mdot
.39558 .33023 Mdot
.60779 .33132 Mdot
.35609 .65818 Mdot
.53548 .71963 Mdot
.67514 .38365 Mdot
.72217 .53697 Mdot
.30943 .43868 Mdot
.55654 .28828 Mdot
.28938 .44962 Mdot
.71967 .56903 Mdot
.69773 .57796 Mdot
.35538 .6445 Mdot
.43031 .32424 Mdot
.5989 .30131 Mdot
.34058 .55169 Mdot
.58561 .32392 Mdot
.47141 .28179 Mdot
.64602 .36556 Mdot
.35033 .66747 Mdot
.53378 .68727 Mdot
.72257 .45697 Mdot
.34472 .54338 Mdot
.54139 .71278 Mdot
.56636 .70705 Mdot
.57075 .27122 Mdot
.32227 .43646 Mdot
.31529 .43505 Mdot
.7232 .58279 Mdot
.71846 .50847 Mdot
.33904 .69351 Mdot
.58942 .28688 Mdot
.54951 .68442 Mdot
.70236 .45847 Mdot
.68903 .56158 Mdot
.69532 .48933 Mdot
.7128 .4542 Mdot
.35914 .66493 Mdot
.31066 .4204 Mdot
.70633 .53975 Mdot
.40136 .36632 Mdot
.3861 .72341 Mdot
.34534 .33884 Mdot
.43455 .32034 Mdot
.39006 .33592 Mdot
.69182 .47354 Mdot
.59107 .31799 Mdot
.66091 .6598 Mdot
.70616 .43364 Mdot
.69935 .45775 Mdot
.47586 .27099 Mdot
.62809 .63536 Mdot
.60422 .65547 Mdot
.67964 .63144 Mdot
.48675 .27861 Mdot
.30321 .42672 Mdot
.48317 .73284 Mdot
.57645 .30815 Mdot
.44588 .29658 Mdot
.6772 .36358 Mdot
.66895 .35288 Mdot
.7343 .54201 Mdot
.36442 .67877 Mdot
.63955 .62327 Mdot
.33998 .59303 Mdot
.34343 .65274 Mdot
.7054 .43838 Mdot
.68934 .56286 Mdot
.68068 .39272 Mdot
.35295 .65562 Mdot
.34113 .68146 Mdot
.5606 .26365 Mdot
.38193 .34128 Mdot
.62582 .33632 Mdot
.34753 .66229 Mdot
.55975 .30178 Mdot
.60763 .65841 Mdot
.35792 .34249 Mdot
.4725 .7124 Mdot
.6788 .37953 Mdot
.36134 .36069 Mdot
.36302 .33523 Mdot
.33471 .51946 Mdot
.63374 .66326 Mdot
.72056 .57818 Mdot
.27557 .4151 Mdot
.67311 .3925 Mdot
.65579 .37561 Mdot
.68022 .45514 Mdot
.35813 .66448 Mdot
.68119 .37882 Mdot
.41367 .35665 Mdot
.34702 .5452 Mdot
.55277 .72356 Mdot
.61754 .65476 Mdot
.33215 .66848 Mdot
.57151 .69636 Mdot
.7095 .44901 Mdot
.33512 .35698 Mdot
.33959 .69352 Mdot
.5952 .32287 Mdot
.71426 .52954 Mdot
.62544 .65886 Mdot
.28352 .4198 Mdot
.65377 .34969 Mdot
.29382 .49564 Mdot
.68864 .56036 Mdot
.3591 .67855 Mdot
.70606 .45943 Mdot
.35901 .35333 Mdot
.38308 .35546 Mdot
.35245 .32884 Mdot
.68382 .5696 Mdot
.35964 .34863 Mdot
.62237 .67398 Mdot
.46218 .72139 Mdot
.34515 .65091 Mdot
.7088 .46836 Mdot
.30432 .42508 Mdot
.42112 .34865 Mdot
.46631 .28618 Mdot
.43823 .7157 Mdot
.3481 .64243 Mdot
.73515 .43952 Mdot
.305 .42113 Mdot
.32876 .54635 Mdot
.37007 .36922 Mdot
.47539 .70809 Mdot
.26403 .47536 Mdot
.39665 .34444 Mdot
.53672 .7006 Mdot
.71717 .5417 Mdot
.39215 .35249 Mdot
.69244 .58035 Mdot
.33072 .54388 Mdot
.45436 .7295 Mdot
.72645 .57215 Mdot
.67815 .59148 Mdot
.37766 .3265 Mdot
.64863 .36501 Mdot
.46459 .73307 Mdot
.332 .58606 Mdot
.46355 .70716 Mdot
.36778 .35826 Mdot
.73536 .45131 Mdot
.56498 .31357 Mdot
.50828 .2795 Mdot
.4827 .29577 Mdot
.6602 .34387 Mdot
.66558 .39111 Mdot
.3711 .65165 Mdot
.51162 .71066 Mdot
.45809 .70627 Mdot
.71656 .47444 Mdot
.48503 .74042 Mdot
.32963 .55698 Mdot
.34327 .58139 Mdot
.58556 .3241 Mdot
.68765 .46213 Mdot
.56769 .68404 Mdot
.45205 .72361 Mdot
.32656 .42055 Mdot
.70765 .5806 Mdot
.32886 .56968 Mdot
.73676 .44382 Mdot
.57502 .27275 Mdot
.72846 .42813 Mdot
.33305 .58175 Mdot
.38136 .34106 Mdot
.67629 .38926 Mdot
.66374 .36145 Mdot
.56034 .27284 Mdot
.56296 .27408 Mdot
.33329 .58601 Mdot
.72842 .46202 Mdot
.48611 .7388 Mdot
.47069 .738 Mdot
.37093 .35155 Mdot
.27695 .43091 Mdot
.327 .59502 Mdot
.60022 .66586 Mdot
.43055 .32967 Mdot
.3431 .55501 Mdot
.72461 .56582 Mdot
.58764 .30799 Mdot
.46777 .2897 Mdot
.69736 .56272 Mdot
.47573 .28785 Mdot
.72814 .4296 Mdot
.33337 .63737 Mdot
.27624 .41949 Mdot
.5628 .73458 Mdot
.30769 .44687 Mdot
.36414 .36083 Mdot
.36012 .66486 Mdot
.51401 .2809 Mdot
.47154 .29835 Mdot
.58075 .72085 Mdot
.69937 .44374 Mdot
.39705 .36614 Mdot
.55329 .70835 Mdot
.32918 .42024 Mdot
.56556 .29448 Mdot
.40967 .35025 Mdot
.35085 .67229 Mdot
.63936 .65837 Mdot
.56603 .68604 Mdot
.40452 .34669 Mdot
.37267 .36189 Mdot
.40387 .33712 Mdot
.65215 .36914 Mdot
.64262 .62733 Mdot
.6743 .35897 Mdot
.46255 .29232 Mdot
.44068 .73092 Mdot
.34453 .6835 Mdot
.6926 .56354 Mdot
.35126 .55482 Mdot
.72426 .4644 Mdot
.67934 .60835 Mdot
.29799 .43002 Mdot
.36726 .33061 Mdot
.69137 .39895 Mdot
.40112 .36728 Mdot
.54357 .72741 Mdot
.53135 .70994 Mdot
.65368 .6477 Mdot
.68019 .44263 Mdot
.31705 .58703 Mdot
.61339 .31562 Mdot
.3109 .43852 Mdot
.66992 .35924 Mdot
.5447 .72611 Mdot
.3214 .57074 Mdot
.30505 .42316 Mdot
.66609 .35172 Mdot
.3957 .32223 Mdot
.73048 .46004 Mdot
.34412 .33939 Mdot
.59054 .70065 Mdot
.33396 .57763 Mdot
.38277 .33909 Mdot
.64422 .63791 Mdot
.66973 .36648 Mdot
.62205 .64901 Mdot
.37251 .33043 Mdot
.4669 .28351 Mdot
.67151 .36165 Mdot
.34736 .68094 Mdot
.66845 .65303 Mdot
.73842 .57392 Mdot
.64748 .62746 Mdot
.43993 .30886 Mdot
.4769 .27517 Mdot
.59221 .31455 Mdot
.71542 .45295 Mdot
.54581 .29789 Mdot
.30621 .40947 Mdot
.48368 .73081 Mdot
.56967 .27745 Mdot
.63905 .62911 Mdot
.54447 .29114 Mdot
.48562 .7204 Mdot
.64442 .35308 Mdot
.60463 .33211 Mdot
.35186 .56486 Mdot
.54435 .71422 Mdot
.37889 .36248 Mdot
.26101 .42872 Mdot
.46196 .72305 Mdot
.35319 .69167 Mdot
.37238 .33915 Mdot
.33031 .58005 Mdot
.72561 .46241 Mdot
.40341 .71202 Mdot
.43065 .7191 Mdot
.47222 .28519 Mdot
.67895 .58961 Mdot
.59661 .28921 Mdot
.33398 .40488 Mdot
.34643 .552 Mdot
.32793 .57726 Mdot
.56151 .70357 Mdot
.68003 .61139 Mdot
.65826 .35698 Mdot
.43556 .72767 Mdot
.48618 .28213 Mdot
.66006 .64931 Mdot
.65746 .64942 Mdot
.3399 .67111 Mdot
.38607 .33916 Mdot
.68765 .4377 Mdot
.32721 .54139 Mdot
.40303 .36356 Mdot
.3572 .69895 Mdot
.66854 .34841 Mdot
.47932 .27421 Mdot
.46056 .29718 Mdot
.65446 .66235 Mdot
.59554 .32846 Mdot
.56045 .70222 Mdot
.36089 .35115 Mdot
.48312 .29596 Mdot
.65552 .35598 Mdot
.31005 .44038 Mdot
.34596 .57545 Mdot
.35459 .63121 Mdot
.59482 .32895 Mdot
.54824 .27968 Mdot
.48712 .73744 Mdot
.73409 .43603 Mdot
.43204 .31568 Mdot
.66831 .3728 Mdot
.6522 .65051 Mdot
.32137 .60265 Mdot
.31912 .50985 Mdot
.70004 .46312 Mdot
.54352 .72473 Mdot
.60049 .32707 Mdot
.3347 .36306 Mdot
.64961 .63383 Mdot
.30911 .44054 Mdot
.35406 .55697 Mdot
.65558 .64313 Mdot
.495 .28463 Mdot
.66075 .63059 Mdot
.38765 .34739 Mdot
.64474 .34779 Mdot
.5689 .29121 Mdot
.68617 .45958 Mdot
.53476 .68716 Mdot
.30124 .42822 Mdot
.33727 .6607 Mdot
.55307 .69278 Mdot
.61479 .65553 Mdot
.55427 .71415 Mdot
.40661 .33435 Mdot
.54952 .7167 Mdot
.65389 .65398 Mdot
.32292 .57294 Mdot
.35281 .58726 Mdot
.45782 .28526 Mdot
.33859 .58575 Mdot
.37094 .65874 Mdot
.4878 .71422 Mdot
.34679 .55987 Mdot
.33542 .54889 Mdot
.3511 .66382 Mdot
.72553 .55295 Mdot
.35237 .69885 Mdot
.72835 .53717 Mdot
.73603 .55647 Mdot
.46507 .29258 Mdot
.32975 .41861 Mdot
.2834 .41019 Mdot
.34846 .69992 Mdot
.35186 .62946 Mdot
.62455 .63914 Mdot
.69083 .54253 Mdot
.66333 .36476 Mdot
.43624 .72316 Mdot
.43717 .31708 Mdot
.34132 .61991 Mdot
.57013 .28373 Mdot
.57467 .27421 Mdot
.34195 .59483 Mdot
.28013 .4892 Mdot
.3654 .64283 Mdot
.47633 .71915 Mdot
.32324 .55515 Mdot
.3494 .65341 Mdot
.59746 .29261 Mdot
.33968 .64715 Mdot
.56941 .69965 Mdot
.65198 .66086 Mdot
.30013 .44547 Mdot
.39158 .34751 Mdot
.45449 .72947 Mdot
.33146 .62019 Mdot
.62248 .66299 Mdot
.56332 .70531 Mdot
.56145 .28635 Mdot
.6995 .57561 Mdot
.47047 .71715 Mdot
.64916 .35918 Mdot
.38201 .72372 Mdot
.73618 .44624 Mdot
.658 .37153 Mdot
.31384 .43335 Mdot
.59558 .30256 Mdot
.34338 .53405 Mdot
.5442 .28771 Mdot
.3531 .66091 Mdot
.47085 .74169 Mdot
.27628 .4212 Mdot
.63095 .64361 Mdot
.67825 .37906 Mdot
.7179 .54644 Mdot
.60833 .64761 Mdot
.41003 .71039 Mdot
.62233 .33577 Mdot
.60369 .3054 Mdot
.42206 .33742 Mdot
.62031 .67033 Mdot
.3711 .65686 Mdot
.67771 .63299 Mdot
.71096 .55402 Mdot
.63189 .65884 Mdot
.38953 .71515 Mdot
.37052 .71969 Mdot
.35286 .66866 Mdot
.64606 .63982 Mdot
.59849 .30667 Mdot
.27835 .41599 Mdot
.36052 .65151 Mdot
.36126 .35228 Mdot
.65467 .66257 Mdot
.59865 .32331 Mdot
.33753 .65322 Mdot
.55901 .29961 Mdot
.65723 .63778 Mdot
.58637 .27878 Mdot
.64565 .36571 Mdot
.57184 .27871 Mdot
.32136 .58875 Mdot
.32187 .5635 Mdot
.65568 .65303 Mdot
.69821 .57793 Mdot
.54603 .72745 Mdot
.34999 .56274 Mdot
.65243 .66944 Mdot
.5283 .27361 Mdot
.70136 .53097 Mdot
.56634 .71264 Mdot
.36919 .65946 Mdot
.31428 .44227 Mdot
.43586 .7296 Mdot
.39898 .71454 Mdot
.42922 .71872 Mdot
.30449 .42918 Mdot
.51301 .70796 Mdot
.3361 .64381 Mdot
.36258 .63512 Mdot
.48967 .28222 Mdot
.35325 .57015 Mdot
.35575 .34393 Mdot
.56701 .71867 Mdot
.37277 .72443 Mdot
.54905 .72569 Mdot
.64277 .63169 Mdot
.65957 .64041 Mdot
.53699 .26994 Mdot
.64986 .6363 Mdot
.35737 .34976 Mdot
.68836 .43735 Mdot
.60998 .64517 Mdot
.37851 .37235 Mdot
.36101 .36349 Mdot
.35456 .33314 Mdot
.39799 .34217 Mdot
.43242 .31676 Mdot
.46918 .27306 Mdot
.36819 .36447 Mdot
.62917 .67235 Mdot
.51644 .2743 Mdot
.28495 .45759 Mdot
.6878 .437 Mdot
.3604 .3378 Mdot
.35367 .5699 Mdot
.56382 .71187 Mdot
.71087 .5867 Mdot
.65637 .34207 Mdot
.40185 .33218 Mdot
.36862 .65501 Mdot
.64841 .66784 Mdot
.32911 .56721 Mdot
.32628 .42895 Mdot
.71351 .57204 Mdot
.55653 .29127 Mdot
.2767 .42312 Mdot
.38699 .33207 Mdot
.29247 .43466 Mdot
.57977 .31887 Mdot
.73192 .46558 Mdot
.35568 .56255 Mdot
.41747 .35288 Mdot
.32279 .41125 Mdot
.35468 .56621 Mdot
.6305 .67159 Mdot
.39666 .32963 Mdot
.36737 .67305 Mdot
.55612 .70582 Mdot
.70324 .54721 Mdot
.69959 .40244 Mdot
.34641 .53756 Mdot
.53172 .71196 Mdot
.6525 .66236 Mdot
.40569 .35844 Mdot
.55327 .29078 Mdot
.3217 .54548 Mdot
.69941 .43803 Mdot
.71702 .44363 Mdot
.49451 .28291 Mdot
.70532 .58479 Mdot
.54763 .3027 Mdot
.3199 .58974 Mdot
.36427 .33523 Mdot
.32197 .54655 Mdot
.53829 .26357 Mdot
.7142 .41848 Mdot
.70049 .54261 Mdot
.46291 .29435 Mdot
.35837 .71571 Mdot
.68369 .43614 Mdot
.47315 .28627 Mdot
.65327 .65902 Mdot
.71808 .57412 Mdot
.69767 .56556 Mdot
.27382 .43166 Mdot
.56233 .2992 Mdot
.72966 .56883 Mdot
.72318 .54335 Mdot
.56606 .70884 Mdot
.34288 .59396 Mdot
.64902 .64953 Mdot
.48774 .2772 Mdot
.31076 .44135 Mdot
.48543 .28551 Mdot
.43035 .33163 Mdot
.67252 .37028 Mdot
.48797 .71929 Mdot
.43776 .71435 Mdot
.30018 .50063 Mdot
.34673 .67974 Mdot
.32662 .54441 Mdot
.62997 .63574 Mdot
.2597 .42645 Mdot
.27252 .44395 Mdot
.63188 .67207 Mdot
.7058 .53873 Mdot
.28116 .43054 Mdot
.3388 .61866 Mdot
.35946 .62779 Mdot
.35878 .71663 Mdot
.64815 .62461 Mdot
.61638 .67518 Mdot
.70529 .44255 Mdot
.65623 .6605 Mdot
.50778 .27053 Mdot
.60853 .32487 Mdot
.58613 .28716 Mdot
.66743 .36187 Mdot
.34935 .54016 Mdot
.60395 .3033 Mdot
.54953 .69893 Mdot
.50322 .27029 Mdot
.53902 .71448 Mdot
.4949 .29275 Mdot
.35058 .55956 Mdot
.68704 .37786 Mdot
.68832 .46929 Mdot
.56228 .72093 Mdot
.33618 .62267 Mdot
.30662 .4375 Mdot
.63001 .63516 Mdot
.71952 .46938 Mdot
.63526 .6269 Mdot
.3317 .57829 Mdot
.63859 .64937 Mdot
.67599 .37912 Mdot
.73617 .45277 Mdot
.57173 .70573 Mdot
.55052 .7014 Mdot
.63432 .62476 Mdot
.64767 .67408 Mdot
.55336 .29218 Mdot
.63139 .66115 Mdot
.73211 .55673 Mdot
.5439 .71632 Mdot
.60159 .32947 Mdot
.41749 .71432 Mdot
.63264 .6387 Mdot
.27016 .42219 Mdot
.71757 .57008 Mdot
.28138 .43306 Mdot
.72449 .57651 Mdot
.45633 .28412 Mdot
.33734 .54284 Mdot
.4674 .29224 Mdot
.31849 .41518 Mdot
.61086 .30781 Mdot
.72203 .47204 Mdot
.36542 .33996 Mdot
.7225 .45481 Mdot
.48007 .72579 Mdot
.63822 .6251 Mdot
.68908 .44768 Mdot
.41465 .71505 Mdot
.32033 .5599 Mdot
.72351 .57768 Mdot
.56137 .28864 Mdot
.48767 .28942 Mdot
.46943 .72549 Mdot
.68654 .56324 Mdot
.53488 .27437 Mdot
.54793 .68578 Mdot
.5089 .27663 Mdot
.56251 .72267 Mdot
.68911 .48163 Mdot
.6598 .63393 Mdot
.49017 .28922 Mdot
.4803 .7216 Mdot
.72838 .54399 Mdot
.60656 .31593 Mdot
.73059 .4585 Mdot
.69856 .43907 Mdot
.31778 .57143 Mdot
.68226 .44708 Mdot
.56695 .28368 Mdot
.73075 .43074 Mdot
.72983 .56622 Mdot
.71583 .41874 Mdot
.3011 .43166 Mdot
.59545 .30774 Mdot
.36984 .35255 Mdot
.53415 .68864 Mdot
.55112 .30079 Mdot
.2888 .49443 Mdot
.44235 .30257 Mdot
.52182 .27015 Mdot
.71237 .57444 Mdot
.68452 .56869 Mdot
.55239 .68931 Mdot
.46524 .72493 Mdot
.5672 .29424 Mdot
.51223 .27186 Mdot
.36073 .70421 Mdot
.36979 .33635 Mdot
.49977 .28301 Mdot
.3484 .67661 Mdot
.55494 .71084 Mdot
.66579 .36944 Mdot
.34233 .68296 Mdot
.71901 .5327 Mdot
.34841 .64931 Mdot
.7223 .46409 Mdot
.57274 .26684 Mdot
.331 .5792 Mdot
.31212 .43622 Mdot
.7145 .43731 Mdot
.71678 .44029 Mdot
.62044 .33458 Mdot
.70445 .58502 Mdot
.61871 .6475 Mdot
.5592 .29762 Mdot
.54631 .71207 Mdot
.37007 .34295 Mdot
.35261 .67137 Mdot
.62989 .6524 Mdot
.6375 .62646 Mdot
.59578 .30757 Mdot
.33552 .63899 Mdot
.71196 .46181 Mdot
.52327 .26859 Mdot
.53847 .72034 Mdot
.58761 .28977 Mdot
.33802 .34512 Mdot
.61161 .33057 Mdot
.62502 .67518 Mdot
.37037 .3223 Mdot
.63607 .65048 Mdot
.37739 .3671 Mdot
.33304 .37204 Mdot
.31507 .43231 Mdot
.59212 .28683 Mdot
.67941 .59368 Mdot
.46849 .29447 Mdot
.34574 .55467 Mdot
.35777 .67555 Mdot
.57169 .31677 Mdot
.30061 .42603 Mdot
.25166 .45121 Mdot
.27143 .45152 Mdot
.70274 .5791 Mdot
.57179 .71218 Mdot
.44305 .30053 Mdot
.44637 .2946 Mdot
.67185 .38257 Mdot
.64085 .66834 Mdot
.36096 .36483 Mdot
.72097 .47451 Mdot
.72118 .44382 Mdot
.29268 .42498 Mdot
.4475 .29666 Mdot
.63844 .65633 Mdot
.70101 .47261 Mdot
.7279 .54234 Mdot
.36641 .63808 Mdot
.40302 .34612 Mdot
.42376 .34606 Mdot
.37727 .36892 Mdot
.45529 .72075 Mdot
.68636 .45782 Mdot
.33494 .55783 Mdot
.32889 .42247 Mdot
.66716 .36418 Mdot
.30359 .44898 Mdot
.54062 .72339 Mdot
.57265 .26753 Mdot
.73303 .52118 Mdot
.31772 .57518 Mdot
.35276 .54867 Mdot
.67368 .36866 Mdot
.33437 .61501 Mdot
.64926 .65947 Mdot
.72909 .55559 Mdot
.59076 .317 Mdot
.39402 .71459 Mdot
.35963 .64216 Mdot
.36277 .65196 Mdot
.56278 .30812 Mdot
.3907 .34132 Mdot
.48477 .27196 Mdot
.36455 .65518 Mdot
.70945 .44652 Mdot
.54772 .72513 Mdot
.6855 .43273 Mdot
.32365 .59465 Mdot
.34139 .54423 Mdot
.54852 .70106 Mdot
.55528 .71786 Mdot
.72208 .45416 Mdot
.39313 .33969 Mdot
.38309 .32801 Mdot
.63979 .62974 Mdot
.35089 .56783 Mdot
.35947 .70958 Mdot
.32801 .54042 Mdot
.30723 .43688 Mdot
.40247 .72312 Mdot
.48857 .72314 Mdot
.46411 .73743 Mdot
.34604 .70392 Mdot
.32923 .54954 Mdot
.67527 .37512 Mdot
.68419 .5592 Mdot
.70837 .46271 Mdot
.64949 .33895 Mdot
.53791 .27472 Mdot
.30033 .44961 Mdot
.33384 .58645 Mdot
.29251 .41582 Mdot
.37058 .71247 Mdot
.32019 .40155 Mdot
.4502 .72484 Mdot
.48448 .73772 Mdot
.27037 .43192 Mdot
.32956 .5368 Mdot
.58502 .32215 Mdot
.61459 .32527 Mdot
.54237 .70284 Mdot
.3242 .59374 Mdot
.66546 .38252 Mdot
.6948 .4327 Mdot
.47153 .27525 Mdot
.49506 .27253 Mdot
.32616 .42954 Mdot
.33623 .36165 Mdot
.54913 .71781 Mdot
.32458 .58513 Mdot
.38654 .33495 Mdot
.5631 .31429 Mdot
.37228 .36656 Mdot
.46377 .28107 Mdot
.71719 .47029 Mdot
.6938 .44993 Mdot
.34724 .58405 Mdot
.26815 .4814 Mdot
.71386 .55161 Mdot
.68502 .57018 Mdot
.69563 .43072 Mdot
.59671 .28939 Mdot
.38808 .35405 Mdot
.67889 .62054 Mdot
.6463 .66612 Mdot
.31774 .41004 Mdot
.3203 .55215 Mdot
.60928 .32053 Mdot
.65995 .66279 Mdot
.32416 .41864 Mdot
.42626 .7126 Mdot
.51757 .27123 Mdot
.33514 .56709 Mdot
.53228 .70467 Mdot
.70094 .5384 Mdot
.4628 .72749 Mdot
.6317 .6399 Mdot
.70616 .43905 Mdot
.7083 .47293 Mdot
.34351 .54407 Mdot
.7377 .52867 Mdot
.60721 .66029 Mdot
.69599 .46885 Mdot
.27242 .43148 Mdot
.36641 .3485 Mdot
.30874 .44722 Mdot
.59484 .32066 Mdot
.31402 .43425 Mdot
.54708 .29526 Mdot
.47612 .28532 Mdot
.64531 .65016 Mdot
.30527 .42274 Mdot
.48619 .71504 Mdot
.36456 .35358 Mdot
.33405 .40734 Mdot
.45139 .73137 Mdot
.53483 .72263 Mdot
.57704 .29509 Mdot
.29759 .41327 Mdot
.3447 .52857 Mdot
.6923 .40543 Mdot
.64388 .34875 Mdot
.72178 .47105 Mdot
.38843 .34908 Mdot
.59203 .30055 Mdot
.63097 .656 Mdot
.35648 .69982 Mdot
.61215 .67981 Mdot
.36907 .67122 Mdot
.34468 .57157 Mdot
.60809 .66754 Mdot
.63023 .65569 Mdot
.34297 .54082 Mdot
.34557 .67558 Mdot
.3624 .3492 Mdot
.71055 .4382 Mdot
.70901 .5755 Mdot
.70676 .57226 Mdot
.5539 .28016 Mdot
.65762 .65255 Mdot
.42966 .32125 Mdot
.71879 .47307 Mdot
.402 .36626 Mdot
.71521 .45679 Mdot
.25583 .46019 Mdot
.52528 .27569 Mdot
.67781 .60007 Mdot
.7089 .58576 Mdot
.56362 .7017 Mdot
.64803 .65045 Mdot
.29721 .43194 Mdot
.65813 .64716 Mdot
.64538 .64324 Mdot
.35176 .56887 Mdot
.39091 .33501 Mdot
.37172 .36321 Mdot
.45197 .72062 Mdot
.71351 .55252 Mdot
.33344 .54377 Mdot
.44439 .73058 Mdot
.35164 .55289 Mdot
.46081 .72641 Mdot
.72726 .56428 Mdot
.33123 .61695 Mdot
.6525 .64727 Mdot
.73776 .54951 Mdot
.43128 .33187 Mdot
.36656 .35659 Mdot
.36378 .36714 Mdot
.6355 .33609 Mdot
.36609 .67462 Mdot
.47103 .28944 Mdot
.54864 .71293 Mdot
.37189 .33294 Mdot
.49097 .71444 Mdot
.29978 .40858 Mdot
.35333 .65899 Mdot
.38067 .3357 Mdot
.55977 .29098 Mdot
.56181 .70095 Mdot
.36032 .66499 Mdot
.39338 .34716 Mdot
.64428 .65453 Mdot
.70037 .55362 Mdot
.63565 .66771 Mdot
.28722 .43148 Mdot
.71832 .46388 Mdot
.55146 .71233 Mdot
.5913 .3202 Mdot
.46674 .29039 Mdot
.63564 .6515 Mdot
.56841 .27015 Mdot
.69353 .44236 Mdot
.36258 .66212 Mdot
.71473 .44329 Mdot
.28959 .41274 Mdot
.71385 .5704 Mdot
.55404 .70399 Mdot
.57343 .69025 Mdot
.65976 .64085 Mdot
.35966 .34465 Mdot
.27989 .45227 Mdot
.58209 .27232 Mdot
.69478 .54983 Mdot
.71761 .46725 Mdot
.55425 .27618 Mdot
.55482 .69934 Mdot
.31223 .40016 Mdot
.33705 .67475 Mdot
.33994 .59239 Mdot
.51695 .70269 Mdot
.34397 .59805 Mdot
.46142 .2921 Mdot
.63408 .63179 Mdot
.55646 .72388 Mdot
.4805 .73722 Mdot
.26031 .47271 Mdot
.29733 .45415 Mdot
.32596 .56004 Mdot
.47285 .7087 Mdot
.34287 .61676 Mdot
.67803 .59074 Mdot
.46746 .72747 Mdot
.53399 .26746 Mdot
.42382 .34465 Mdot
.64877 .33877 Mdot
.37383 .33758 Mdot
.57304 .26838 Mdot
.34671 .67348 Mdot
.33431 .655 Mdot
.71088 .52351 Mdot
.5381 .72364 Mdot
.6999 .46094 Mdot
.3333 .62378 Mdot
.56022 .28603 Mdot
.47137 .29884 Mdot
.31254 .57218 Mdot
.64638 .66199 Mdot
.68789 .40074 Mdot
.38266 .33326 Mdot
.36554 .36809 Mdot
.31919 .41446 Mdot
.54612 .26555 Mdot
.35137 .32909 Mdot
.71241 .4606 Mdot
.34178 .52778 Mdot
.48868 .72261 Mdot
.69549 .39548 Mdot
.66368 .64464 Mdot
.65659 .3759 Mdot
.25647 .46185 Mdot
.33967 .55703 Mdot
.72091 .55213 Mdot
.65006 .63413 Mdot
.32427 .4129 Mdot
.46162 .2857 Mdot
.48734 .27963 Mdot
.27967 .48742 Mdot
.37648 .32471 Mdot
.56121 .31277 Mdot
.3493 .33374 Mdot
.54565 .70946 Mdot
.45283 .72897 Mdot
.64222 .34877 Mdot
.3475 .55919 Mdot
.74173 .56418 Mdot
.64059 .63087 Mdot
.32265 .5561 Mdot
.29056 .4479 Mdot
.67706 .61167 Mdot
.56294 .69163 Mdot
.33556 .52185 Mdot
.59905 .30758 Mdot
.34421 .55968 Mdot
.43425 .32192 Mdot
.39984 .36607 Mdot
.3523 .58174 Mdot
.5554 .2933 Mdot
.36898 .32264 Mdot
.28376 .44888 Mdot
.6493 .62603 Mdot
.37369 .33896 Mdot
.53781 .72073 Mdot
.35413 .67527 Mdot
.27262 .43324 Mdot
.54735 .70439 Mdot
.61287 .6762 Mdot
.3591 .36926 Mdot
.58372 .28438 Mdot
.70891 .53875 Mdot
.34008 .55042 Mdot
.36421 .34733 Mdot
.32147 .57406 Mdot
.6166 .63464 Mdot
.33993 .58887 Mdot
.73483 .45102 Mdot
.69765 .53913 Mdot
.70591 .45418 Mdot
.56139 .70407 Mdot
.33682 .56779 Mdot
.35098 .33247 Mdot
.38601 .35748 Mdot
.36863 .65435 Mdot
.63478 .6501 Mdot
.64447 .6385 Mdot
.63346 .66465 Mdot
.55986 .27852 Mdot
.3677 .71023 Mdot
.70272 .44863 Mdot
.39031 .33769 Mdot
.68184 .44425 Mdot
.44706 .70581 Mdot
.28833 .43403 Mdot
.70032 .4106 Mdot
.36635 .66129 Mdot
.68866 .56974 Mdot
.35352 .62104 Mdot
.67954 .57222 Mdot
.63432 .33621 Mdot
.65833 .37767 Mdot
.71067 .55879 Mdot
.32567 .55427 Mdot
.45769 .71983 Mdot
.49091 .72668 Mdot
.6917 .46458 Mdot
.40015 .33473 Mdot
.43971 .31273 Mdot
.60604 .32184 Mdot
.31863 .40016 Mdot
.67182 .36113 Mdot
.68414 .40123 Mdot
.56634 .71271 Mdot
.70584 .54405 Mdot
.71149 .46779 Mdot
.72946 .46409 Mdot
.56883 .28673 Mdot
.56553 .70593 Mdot
.33486 .5729 Mdot
.35654 .35001 Mdot
.65222 .36155 Mdot
.36164 .6473 Mdot
.54244 .72753 Mdot
.46943 .2744 Mdot
.62519 .6597 Mdot
.70051 .40021 Mdot
.43591 .70579 Mdot
.61433 .65543 Mdot
.50824 .27731 Mdot
.72968 .56775 Mdot
.33214 .5479 Mdot
.3824 .35093 Mdot
.57453 .2716 Mdot
.35916 .67977 Mdot
.46134 .2951 Mdot
.69684 .46231 Mdot
.69208 .39619 Mdot
.44123 .70922 Mdot
.50624 .27233 Mdot
.33919 .53857 Mdot
.55641 .69062 Mdot
.31917 .42417 Mdot
.70054 .46838 Mdot
.71885 .52666 Mdot
.31907 .56815 Mdot
.54776 .28222 Mdot
.60463 .33005 Mdot
.6348 .64084 Mdot
.63964 .66769 Mdot
.67945 .596 Mdot
.37202 .35346 Mdot
.55048 .27149 Mdot
.36424 .34852 Mdot
.33818 .52235 Mdot
.69776 .47059 Mdot
.28216 .44873 Mdot
.58531 .27766 Mdot
.66434 .35522 Mdot
.53464 .72229 Mdot
.70088 .5826 Mdot
.52584 .69548 Mdot
.54772 .69855 Mdot
.54864 .26642 Mdot
.29099 .4396 Mdot
.46575 .73213 Mdot
.57225 .70033 Mdot
.27895 .43473 Mdot
.56176 .28209 Mdot
.70444 .55373 Mdot
.64976 .63194 Mdot
.68719 .55056 Mdot
.48306 .71607 Mdot
.67303 .64935 Mdot
.34449 .64676 Mdot
.35236 .58587 Mdot
.71999 .58518 Mdot
.35473 .69491 Mdot
.72154 .47053 Mdot
.68966 .55447 Mdot
.46168 .72696 Mdot
.54907 .73015 Mdot
.34803 .64582 Mdot
.33655 .63798 Mdot
.55103 .7213 Mdot
.36611 .67477 Mdot
.61176 .67104 Mdot
.63771 .62648 Mdot
.46561 .73608 Mdot
.70029 .47526 Mdot
.29895 .4362 Mdot
.73292 .55882 Mdot
.3441 .563 Mdot
.60881 .67047 Mdot
.4579 .73449 Mdot
.73451 .45044 Mdot
.54731 .72195 Mdot
.57076 .26641 Mdot
.33962 .67505 Mdot
.60786 .33243 Mdot
.5728 .69178 Mdot
.60652 .66978 Mdot
.64584 .35888 Mdot
.5648 .69157 Mdot
.51217 .26597 Mdot
.33283 .62508 Mdot
.38217 .3541 Mdot
.31564 .43504 Mdot
.36114 .32543 Mdot
.72395 .45726 Mdot
.36285 .67645 Mdot
.34818 .68274 Mdot
.33373 .6029 Mdot
.33809 .52208 Mdot
.36536 .35547 Mdot
.27334 .41625 Mdot
.62022 .63196 Mdot
.35603 .66316 Mdot
.60721 .30792 Mdot
.71729 .54313 Mdot
.34561 .6651 Mdot
.49527 .73065 Mdot
.535 .70247 Mdot
.71287 .55391 Mdot
.70043 .58535 Mdot
.43717 .31685 Mdot
.31027 .42625 Mdot
.34888 .55001 Mdot
.26609 .42614 Mdot
.55102 .71014 Mdot
.71758 .45329 Mdot
.33194 .60342 Mdot
.52602 .27619 Mdot
.47497 .72686 Mdot
.56234 .28094 Mdot
.35724 .56083 Mdot
.71425 .57491 Mdot
.70878 .47193 Mdot
.49278 .28475 Mdot
.49721 .28317 Mdot
.36001 .63702 Mdot
.4445 .29835 Mdot
.28717 .42647 Mdot
.29275 .42883 Mdot
.71055 .46982 Mdot
.3254 .54868 Mdot
.47227 .72966 Mdot
.56284 .73309 Mdot
.36235 .68149 Mdot
.35191 .54214 Mdot
.65916 .35319 Mdot
.66721 .36046 Mdot
.58467 .27835 Mdot
.34636 .54191 Mdot
.35678 .64825 Mdot
.71669 .56093 Mdot
.2992 .45173 Mdot
.54539 .27001 Mdot
.32551 .42081 Mdot
.5668 .30788 Mdot
.37375 .7234 Mdot
.39882 .33821 Mdot
.28999 .4307 Mdot
.6798 .37576 Mdot
.69319 .57314 Mdot
.35994 .35297 Mdot
.58213 .30202 Mdot
.56026 .27017 Mdot
.3471 .66606 Mdot
.66418 .64211 Mdot
.72959 .55863 Mdot
.28447 .43187 Mdot
.69799 .43139 Mdot
.54941 .69879 Mdot
.37481 .3691 Mdot
.25776 .46563 Mdot
.54833 .27513 Mdot
.6778 .58386 Mdot
.54004 .68605 Mdot
.34127 .57564 Mdot
.7004 .55475 Mdot
.33835 .57527 Mdot
.63233 .66098 Mdot
.73475 .55253 Mdot
.31636 .5839 Mdot
.62278 .66569 Mdot
.54607 .29994 Mdot
.48244 .29799 Mdot
.55301 .72718 Mdot
.65844 .38567 Mdot
.54807 .71176 Mdot
.49035 .27314 Mdot
.35261 .62155 Mdot
.3556 .67877 Mdot
.34487 .5659 Mdot
.3339 .39354 Mdot
.34276 .69797 Mdot
.38725 .3638 Mdot
.3813 .35445 Mdot
.70575 .54985 Mdot
.35829 .32622 Mdot
.45608 .72212 Mdot
.30391 .41972 Mdot
.59118 .31611 Mdot
.35656 .63394 Mdot
.28555 .4361 Mdot
.64687 .63 Mdot
.56783 .6983 Mdot
.72589 .58161 Mdot
.61411 .33084 Mdot
.38666 .34072 Mdot
.69876 .46266 Mdot
.42726 .72167 Mdot
.55399 .2858 Mdot
.65889 .36426 Mdot
.44159 .71746 Mdot
.57185 .26597 Mdot
.7113 .47757 Mdot
.47795 .29928 Mdot
.66325 .37171 Mdot
.68973 .43436 Mdot
.47447 .71672 Mdot
.30462 .41915 Mdot
.364 .32276 Mdot
.2675 .42 Mdot
.65065 .36656 Mdot
.51324 .2833 Mdot
.58564 .29499 Mdot
.47681 .73779 Mdot
.67332 .64623 Mdot
.36152 .33611 Mdot
.34738 .53976 Mdot
.66848 .36755 Mdot
.36665 .71718 Mdot
.36327 .32331 Mdot
.69574 .44952 Mdot
.5722 .69106 Mdot
.39936 .72132 Mdot
.3754 .34961 Mdot
.36413 .36119 Mdot
.29994 .41418 Mdot
.47563 .27936 Mdot
.72698 .56988 Mdot
.30705 .40663 Mdot
.33853 .60858 Mdot
.34968 .55801 Mdot
.72195 .45585 Mdot
.37518 .3389 Mdot
.69918 .4446 Mdot
.29445 .44938 Mdot
.27552 .41496 Mdot
.64841 .62702 Mdot
.6394 .66422 Mdot
.34354 .34048 Mdot
.34511 .70528 Mdot
.33238 .67543 Mdot
.71517 .52327 Mdot
.72134 .57229 Mdot
.33396 .63422 Mdot
.27069 .44721 Mdot
.30484 .41208 Mdot
.56229 .6894 Mdot
.45063 .73478 Mdot
.5556 .72048 Mdot
.43065 .71229 Mdot
.62691 .33632 Mdot
.5594 .70227 Mdot
.57768 .27048 Mdot
.42928 .7121 Mdot
.67961 .39318 Mdot
.54116 .70268 Mdot
.33844 .5825 Mdot
.57364 .3084 Mdot
.35542 .5701 Mdot
.5984 .3186 Mdot
.33647 .54529 Mdot
.53986 .26306 Mdot
.59115 .32001 Mdot
.43887 .31094 Mdot
.41299 .71861 Mdot
.38504 .36426 Mdot
.27381 .44231 Mdot
.42008 .34761 Mdot
.33787 .65623 Mdot
.70445 .55779 Mdot
.67576 .6432 Mdot
.34145 .57765 Mdot
.57248 .28737 Mdot
.69268 .45731 Mdot
.57014 .68682 Mdot
.3282 .59417 Mdot
.5433 .70588 Mdot
.70053 .58288 Mdot
.59767 .30764 Mdot
.31929 .43202 Mdot
.45586 .28073 Mdot
.48872 .27438 Mdot
.52448 .27643 Mdot
.33155 .51825 Mdot
.53623 .70275 Mdot
.43418 .3217 Mdot
.62143 .65272 Mdot
.25181 .44912 Mdot
.65106 .6378 Mdot
.37019 .3392 Mdot
.31524 .41478 Mdot
.40342 .71432 Mdot
.72413 .54664 Mdot
.56388 .30886 Mdot
.33521 .56545 Mdot
.39656 .34221 Mdot
.26797 .41961 Mdot
.71851 .53357 Mdot
.27205 .43309 Mdot
.58215 .30639 Mdot
.36956 .34697 Mdot
.36611 .71345 Mdot
.32438 .60671 Mdot
.46772 .74333 Mdot
.33814 .56513 Mdot
.2817 .43158 Mdot
.66472 .64501 Mdot
.54341 .70449 Mdot
.65763 .36829 Mdot
.464 .72435 Mdot
.35475 .54595 Mdot
.5001 .26997 Mdot
.70595 .58076 Mdot
.30257 .43028 Mdot
.66837 .36872 Mdot
.31173 .42735 Mdot
.37028 .36788 Mdot
.63818 .66069 Mdot
.36912 .36837 Mdot
.54031 .72511 Mdot
.70907 .46639 Mdot
.72888 .55562 Mdot
.48054 .2712 Mdot
.3807 .3256 Mdot
.57499 .31948 Mdot
.40595 .72042 Mdot
.63587 .64433 Mdot
.65199 .34769 Mdot
.4544 .28287 Mdot
.7335 .45526 Mdot
.46186 .74057 Mdot
.70349 .43412 Mdot
.34216 .577 Mdot
.69007 .54416 Mdot
.68296 .43687 Mdot
.49503 .28102 Mdot
.47445 .70942 Mdot
.38351 .36983 Mdot
.32448 .54425 Mdot
.72241 .42384 Mdot
.68888 .46886 Mdot
.65321 .65174 Mdot
.67371 .36265 Mdot
.34527 .61521 Mdot
.36501 .35207 Mdot
.34998 .57702 Mdot
.65851 .37512 Mdot
.66638 .3542 Mdot
.48446 .28808 Mdot
.33377 .56015 Mdot
.30923 .43476 Mdot
.5722 .26772 Mdot
.60272 .3304 Mdot
.5772 .27558 Mdot
.61062 .65872 Mdot
.385 .33015 Mdot
.37402 .35418 Mdot
.35244 .62549 Mdot
.69872 .44066 Mdot
.38661 .36352 Mdot
.35545 .67105 Mdot
.34138 .66556 Mdot
.68938 .54746 Mdot
.57556 .30422 Mdot
.35591 .55108 Mdot
.55609 .72691 Mdot
.39207 .3507 Mdot
.56151 .29934 Mdot
.64233 .65487 Mdot
.48915 .27085 Mdot
.36297 .66817 Mdot
.56233 .71776 Mdot
.65984 .63767 Mdot
.6062 .67515 Mdot
.34306 .69976 Mdot
.33718 .57652 Mdot
.71845 .44473 Mdot
.51649 .67034 Mdot
.39103 .58907 Mdot
.44351 .48713 Mdot
.36483 .3314 Mdot
.59674 .56223 Mdot
.47817 .65507 Mdot
.56954 .72722 Mdot
.49847 .58521 Mdot
.46402 .70439 Mdot
.54357 .61991 Mdot
.63394 .41702 Mdot
.4743 .55009 Mdot
.51123 .29561 Mdot
.66939 .48867 Mdot
.58479 .68374 Mdot
.33016 .4727 Mdot
.67144 .53797 Mdot
.51201 .63342 Mdot
.67442 .48938 Mdot
.60312 .45069 Mdot
.58419 .34209 Mdot
.62249 .33889 Mdot
.60769 .40723 Mdot
.34476 .52701 Mdot
.54084 .64856 Mdot
.40709 .6138 Mdot
.644 .58772 Mdot
.65651 .40118 Mdot
.56138 .72652 Mdot
.41559 .39096 Mdot
.61511 .56849 Mdot
.45798 .38437 Mdot
.43576 .67898 Mdot
.62873 .44403 Mdot
.40434 .60632 Mdot
.37683 .43711 Mdot
.46499 .70096 Mdot
.54725 .58805 Mdot
.5955 .59039 Mdot
.44268 .65048 Mdot
.624 .55192 Mdot
.54034 .28156 Mdot
.66523 .65246 Mdot
.68225 .50692 Mdot
.4613 .36323 Mdot
.64275 .54068 Mdot
.4979 .58625 Mdot
.34527 .34179 Mdot
.59811 .55508 Mdot
.37552 .69661 Mdot
.67687 .56811 Mdot
.64711 .46974 Mdot
.65673 .41225 Mdot
.45299 .66158 Mdot
.66351 .43019 Mdot
.39669 .68892 Mdot
.51602 .63558 Mdot
.48387 .65872 Mdot
.60545 .44597 Mdot
.54249 .35306 Mdot
.71241 .58079 Mdot
.33512 .47535 Mdot
.56125 .43045 Mdot
.40274 .48214 Mdot
.6545 .48933 Mdot
.46105 .68823 Mdot
.64448 .61504 Mdot
.69805 .52856 Mdot
.59969 .36111 Mdot
.46484 .34078 Mdot
.6162 .40267 Mdot
.57022 .43235 Mdot
.64569 .53064 Mdot
.38416 .61644 Mdot
.57964 .60963 Mdot
.58379 .37493 Mdot
.52885 .68252 Mdot
.3594 .40211 Mdot
.5495 .51693 Mdot
.43396 .34951 Mdot
.46846 .66581 Mdot
.61347 .45423 Mdot
.45282 .58053 Mdot
.60906 .52652 Mdot
.38661 .66612 Mdot
.44507 .34865 Mdot
.54347 .64722 Mdot
.55613 .37875 Mdot
.66635 .54706 Mdot
.49383 .67904 Mdot
.65753 .43633 Mdot
.39261 .37478 Mdot
.44909 .42476 Mdot
.42088 .3752 Mdot
.50589 .57839 Mdot
.37817 .42146 Mdot
.62863 .44113 Mdot
.68594 .48736 Mdot
.58295 .32846 Mdot
.62084 .60758 Mdot
.47484 .36998 Mdot
.74027 .55839 Mdot
.55828 .32764 Mdot
.49133 .61347 Mdot
.60656 .62122 Mdot
.41739 .38076 Mdot
.6067 .36745 Mdot
.59693 .51743 Mdot
.59792 .42225 Mdot
.59354 .58621 Mdot
.56901 .6163 Mdot
.67503 .53893 Mdot
.33796 .35434 Mdot
.58334 .66225 Mdot
.44737 .38886 Mdot
.62509 .38205 Mdot
.3459 .42825 Mdot
.36108 .69922 Mdot
.4715 .39308 Mdot
.49904 .70314 Mdot
.50781 .47701 Mdot
.66012 .57682 Mdot
.42703 .36099 Mdot
.557 .73017 Mdot
.53151 .6753 Mdot
.60665 .40449 Mdot
.35461 .48955 Mdot
.67031 .576 Mdot
.67664 .48643 Mdot
.60915 .34519 Mdot
.48123 .67457 Mdot
.44253 .32591 Mdot
.37018 .54868 Mdot
.40281 .455 Mdot
.63237 .35308 Mdot
.39357 .47776 Mdot
.43488 .44999 Mdot
.48029 .30641 Mdot
.61648 .61985 Mdot
.43448 .43364 Mdot
.50857 .70304 Mdot
.57633 .36991 Mdot
.6284 .41186 Mdot
.5313 .66207 Mdot
.29364 .468 Mdot
.40461 .40987 Mdot
.45605 .45339 Mdot
.59986 .5396 Mdot
.5745 .7262 Mdot
.41106 .58469 Mdot
.62437 .43242 Mdot
.51502 .40731 Mdot
.52848 .35853 Mdot
.67396 .48016 Mdot
.74095 .55354 Mdot
.49673 .38491 Mdot
.43491 .56946 Mdot
.57303 .67627 Mdot
.50206 .4267 Mdot
.66042 .59177 Mdot
.48665 .41546 Mdot
.41469 .38883 Mdot
.62194 .34907 Mdot
.59464 .38032 Mdot
.65044 .52987 Mdot
.6597 .41441 Mdot
.57608 .63385 Mdot
.58248 .63281 Mdot
.49831 .36268 Mdot
.66987 .53349 Mdot
.62282 .47241 Mdot
.68904 .53642 Mdot
.51552 .61916 Mdot
.4311 .64664 Mdot
.38848 .57281 Mdot
.44626 .53156 Mdot
.26572 .44418 Mdot
.37573 .44448 Mdot
.48317 .67758 Mdot
.27139 .46626 Mdot
.38662 .50937 Mdot
.40015 .60356 Mdot
.36757 .37201 Mdot
.37883 .56686 Mdot
.38495 .69859 Mdot
.57121 .53692 Mdot
.60183 .37818 Mdot
.45798 .47166 Mdot
.37845 .54942 Mdot
.65265 .58133 Mdot
.45933 .70013 Mdot
.42813 .36138 Mdot
.48064 .32588 Mdot
.50327 .65252 Mdot
.55608 .66217 Mdot
.66783 .39449 Mdot
.68173 .41886 Mdot
.49911 .30282 Mdot
.6511 .52892 Mdot
.65388 .61411 Mdot
.45663 .28992 Mdot
.60803 .48457 Mdot
.44826 .5926 Mdot
.40656 .64569 Mdot
.44415 .36378 Mdot
.57815 .55267 Mdot
.33582 .41392 Mdot
.46594 .62476 Mdot
.43919 .46756 Mdot
.39588 .40724 Mdot
.35864 .4201 Mdot
.35452 .44084 Mdot
.67899 .51366 Mdot
.36709 .44994 Mdot
.40071 .38941 Mdot
.3739 .70979 Mdot
.56648 .47009 Mdot
.58122 .70639 Mdot
.40924 .5369 Mdot
.55557 .3325 Mdot
.56112 .41843 Mdot
.56651 .61042 Mdot
.45334 .66268 Mdot
.38025 .39041 Mdot
.38398 .69654 Mdot
.62171 .53365 Mdot
.44299 .39684 Mdot
.56747 .39016 Mdot
.46731 .38837 Mdot
.507 .35607 Mdot
.52495 .58143 Mdot
.67694 .4883 Mdot
.27226 .48022 Mdot
.54838 .35114 Mdot
.63466 .57634 Mdot
.51207 .69084 Mdot
.56029 .3328 Mdot
.59517 .63849 Mdot
.60516 .60452 Mdot
.46395 .64993 Mdot
.41979 .5796 Mdot
.47079 .50641 Mdot
.55343 .58984 Mdot
.39018 .44421 Mdot
.5418 .39342 Mdot
.62095 .34242 Mdot
.50807 .31364 Mdot
.46767 .49141 Mdot
.56128 .46466 Mdot
.37271 .52755 Mdot
.6024 .35667 Mdot
.54345 .5562 Mdot
.3887 .595 Mdot
.45696 .46831 Mdot
.5154 .64505 Mdot
.66012 .60039 Mdot
.42825 .57419 Mdot
.36729 .68541 Mdot
.45848 .35779 Mdot
.49313 .30041 Mdot
.50032 .35071 Mdot
.54389 .65508 Mdot
.67038 .43671 Mdot
.65928 .51109 Mdot
.37417 .50882 Mdot
.39712 .63505 Mdot
.51204 .54521 Mdot
.41049 .68132 Mdot
.70342 .42615 Mdot
.66466 .60882 Mdot
.56503 .64 Mdot
.35525 .5396 Mdot
.45315 .54805 Mdot
.55051 .63518 Mdot
.38222 .49308 Mdot
.50084 .70024 Mdot
.61834 .63215 Mdot
.56067 .35773 Mdot
.62138 .33908 Mdot
.31081 .46609 Mdot
.55792 .44062 Mdot
.32864 .42807 Mdot
.50106 .32343 Mdot
.59447 .53103 Mdot
.43607 .67385 Mdot
.66958 .40943 Mdot
.52168 .36769 Mdot
.51999 .29484 Mdot
.5082 .35461 Mdot
.62492 .40685 Mdot
.65404 .49558 Mdot
.37 .59601 Mdot
.621 .57986 Mdot
.66832 .46911 Mdot
.36383 .61779 Mdot
.63577 .39172 Mdot
.60914 .54259 Mdot
.67677 .5578 Mdot
.37462 .68225 Mdot
.35505 .62144 Mdot
.35678 .45698 Mdot
.37616 .60937 Mdot
.43236 .49018 Mdot
.67273 .62992 Mdot
.32843 .49841 Mdot
.6266 .53432 Mdot
.57918 .70046 Mdot
.55344 .66474 Mdot
.66893 .56833 Mdot
.50919 .69338 Mdot
.53996 .30786 Mdot
.67388 .43691 Mdot
.55669 .63061 Mdot
.38137 .51059 Mdot
.41151 .41263 Mdot
.3678 .50144 Mdot
.56872 .66116 Mdot
.42207 .54516 Mdot
.65458 .60059 Mdot
.45773 .66211 Mdot
.56467 .50151 Mdot
.62253 .61049 Mdot
.47276 .61602 Mdot
.49632 .69348 Mdot
.58302 .68049 Mdot
.47987 .34252 Mdot
.33985 .48702 Mdot
.54047 .59612 Mdot
.34593 .60562 Mdot
.49559 .47435 Mdot
.49819 .61475 Mdot
.3575 .52228 Mdot
.52472 .60574 Mdot
.31834 .50744 Mdot
.71878 .52019 Mdot
.57681 .58495 Mdot
.52439 .40121 Mdot
.34419 .51769 Mdot
.43433 .67703 Mdot
.49462 .67653 Mdot
.67427 .48313 Mdot
.33549 .49108 Mdot
.4648 .33663 Mdot
.5437 .49771 Mdot
.37663 .54187 Mdot
.46304 .43964 Mdot
.35414 .46762 Mdot
.34427 .36571 Mdot
.50341 .35802 Mdot
.60083 .56152 Mdot
.31677 .49476 Mdot
.6403 .38436 Mdot
.44317 .52253 Mdot
.45279 .58674 Mdot
.55833 .35394 Mdot
.46754 .59103 Mdot
.47772 .57359 Mdot
.46988 .46824 Mdot
.56993 .34967 Mdot
.57308 .568 Mdot
.61691 .54457 Mdot
.61337 .63698 Mdot
.3899 .40042 Mdot
.55588 .61396 Mdot
.60427 .60907 Mdot
.53693 .40082 Mdot
.3342 .59395 Mdot
.44006 .53455 Mdot
.6745 .58519 Mdot
.51226 .44319 Mdot
.57006 .62452 Mdot
.50045 .29671 Mdot
.58478 .54723 Mdot
.46024 .48007 Mdot
.32237 .4837 Mdot
.31166 .49426 Mdot
.43445 .6111 Mdot
.40433 .38061 Mdot
.62723 .53178 Mdot
.57565 .6534 Mdot
.6243 .55863 Mdot
.39757 .65354 Mdot
.73033 .53146 Mdot
.46724 .32674 Mdot
.65759 .38767 Mdot
.65165 .57941 Mdot
.45613 .62327 Mdot
.43885 .33037 Mdot
.55757 .47387 Mdot
.6171 .48631 Mdot
.67067 .45016 Mdot
.61641 .36216 Mdot
.59916 .37093 Mdot
.42911 .52875 Mdot
.64507 .44047 Mdot
.5468 .35439 Mdot
.59984 .63216 Mdot
.53178 .30562 Mdot
.54936 .36286 Mdot
.50608 .71479 Mdot
.58279 .37491 Mdot
.59525 .66173 Mdot
.65625 .43289 Mdot
.49573 .60987 Mdot
.59196 .53864 Mdot
.51428 .42479 Mdot
.58236 .65754 Mdot
.67494 .51315 Mdot
.57678 .49741 Mdot
.39632 .70246 Mdot
.50119 .68391 Mdot
.5365 .67844 Mdot
.41142 .6187 Mdot
.59188 .51404 Mdot
.32137 .4971 Mdot
.64205 .36026 Mdot
.38542 .63751 Mdot
.67659 .56368 Mdot
.37606 .70867 Mdot
.62145 .47634 Mdot
.42725 .70458 Mdot
.48114 .34631 Mdot
.62425 .47603 Mdot
.35014 .4445 Mdot
.45791 .30072 Mdot
.33631 .48378 Mdot
.57879 .6022 Mdot
.50037 .32403 Mdot
.55167 .33175 Mdot
.52541 .31326 Mdot
.35207 .42713 Mdot
.53102 .34019 Mdot
.3725 .62942 Mdot
.57735 .51136 Mdot
.38806 .61959 Mdot
.35661 .4943 Mdot
.54265 .34192 Mdot
.67282 .61699 Mdot
.41972 .41412 Mdot
.48471 .63591 Mdot
.63052 .37446 Mdot
.34731 .47178 Mdot
.37076 .64325 Mdot
.49723 .44467 Mdot
.60796 .4331 Mdot
.55492 .30996 Mdot
.34104 .43393 Mdot
.53681 .66248 Mdot
.50205 .38023 Mdot
.53125 .67333 Mdot
.52165 .69392 Mdot
.63833 .42028 Mdot
.48026 .64707 Mdot
.27189 .47808 Mdot
.6424 .48464 Mdot
.44876 .31612 Mdot
.60938 .53387 Mdot
.70814 .50798 Mdot
.35751 .48604 Mdot
.49459 .35928 Mdot
.50538 .3843 Mdot
.34532 .44614 Mdot
.42528 .41421 Mdot
.42433 .4213 Mdot
.31765 .50673 Mdot
.50277 .64423 Mdot
.38289 .62406 Mdot
.39663 .40439 Mdot
.43807 .64699 Mdot
.46593 .34242 Mdot
.73066 .45444 Mdot
.60339 .45671 Mdot
.66714 .60484 Mdot
.37901 .58987 Mdot
.37957 .60448 Mdot
.52857 .36861 Mdot
.6643 .55272 Mdot
.45779 .50723 Mdot
.45786 .45557 Mdot
.65914 .42493 Mdot
.40065 .67216 Mdot
.52778 .59219 Mdot
.33854 .45001 Mdot
.36753 .68695 Mdot
.33666 .38058 Mdot
.598 .38004 Mdot
.61912 .58046 Mdot
.58606 .52508 Mdot
.65607 .60807 Mdot
.42782 .4969 Mdot
.3648 .57147 Mdot
.39756 .39846 Mdot
.58528 .52368 Mdot
.39733 .61004 Mdot
.36355 .47355 Mdot
.60075 .61442 Mdot
.65408 .54801 Mdot
.50641 .5887 Mdot
.58914 .45153 Mdot
.36543 .707 Mdot
.61239 .40195 Mdot
.49963 .29601 Mdot
.32561 .48877 Mdot
.6561 .53943 Mdot
.37745 .59401 Mdot
.44381 .43947 Mdot
.57336 .40974 Mdot
.33016 .46648 Mdot
.60304 .35383 Mdot
.48344 .67849 Mdot
.63344 .39184 Mdot
.65833 .55665 Mdot
.61463 .48087 Mdot
.37259 .6109 Mdot
.33444 .47718 Mdot
.4484 .60722 Mdot
.55689 .52062 Mdot
.47816 .4346 Mdot
.41701 .70302 Mdot
.54407 .64479 Mdot
.42068 .58457 Mdot
.69753 .50708 Mdot
.34102 .45524 Mdot
.61099 .41797 Mdot
.36119 .46578 Mdot
.33388 .46738 Mdot
.66166 .61922 Mdot
.56762 .64208 Mdot
.68835 .49209 Mdot
.37966 .54473 Mdot
.54959 .30607 Mdot
.37228 .65368 Mdot
.39144 .6964 Mdot
.47362 .60907 Mdot
.50144 .39418 Mdot
.27392 .47627 Mdot
.49893 .68987 Mdot
.60265 .40728 Mdot
.506 .69747 Mdot
.52253 .30257 Mdot
.52275 .57656 Mdot
.47856 .65961 Mdot
.42149 .4965 Mdot
.65081 .49932 Mdot
.50646 .64335 Mdot
.45652 .38625 Mdot
.41043 .52812 Mdot
.47055 .6539 Mdot
.47246 .66196 Mdot
.44241 .58443 Mdot
.63261 .59642 Mdot
.44215 .38904 Mdot
.61489 .37585 Mdot
.26643 .46849 Mdot
.43703 .64979 Mdot
.38272 .60327 Mdot
.59621 .53753 Mdot
.47357 .3836 Mdot
.45764 .29748 Mdot
.2908 .48249 Mdot
.41781 .66404 Mdot
.66331 .59772 Mdot
.52022 .53797 Mdot
.39404 .6238 Mdot
.38776 .62641 Mdot
.66074 .48591 Mdot
.59418 .52176 Mdot
.44866 .48949 Mdot
.67075 .64225 Mdot
.69359 .41498 Mdot
.2639 .43636 Mdot
.27361 .46754 Mdot
.64019 .55713 Mdot
.42598 .60489 Mdot
.57982 .36689 Mdot
.68184 .53856 Mdot
.29375 .46359 Mdot
.63178 .51074 Mdot
.35882 .54795 Mdot
.40576 .56171 Mdot
.28284 .48357 Mdot
.3758 .43302 Mdot
.6632 .62418 Mdot
.58072 .64113 Mdot
.6488 .46361 Mdot
.52045 .37024 Mdot
.56151 .54177 Mdot
.53499 .33705 Mdot
.45724 .41788 Mdot
.50279 .37176 Mdot
.47221 .64267 Mdot
.49742 .56868 Mdot
.62046 .39411 Mdot
.49962 .32656 Mdot
.62372 .37783 Mdot
.41909 .47033 Mdot
.5671 .4338 Mdot
.62608 .34904 Mdot
.50179 .43759 Mdot
.63586 .52225 Mdot
.57857 .70927 Mdot
.50949 .55012 Mdot
.56512 .34603 Mdot
.66876 .64962 Mdot
.59399 .43494 Mdot
.49789 .65712 Mdot
.64944 .57844 Mdot
.44347 .39201 Mdot
.56772 .64849 Mdot
.61819 .38225 Mdot
.38493 .60762 Mdot
.55793 .39227 Mdot
.4298 .66922 Mdot
.39444 .47477 Mdot
.34765 .35406 Mdot
.39888 .45237 Mdot
.37053 .37872 Mdot
.37641 .6448 Mdot
.38656 .50066 Mdot
.44767 .35465 Mdot
.38404 .6562 Mdot
.51904 .42581 Mdot
.61672 .45476 Mdot
.68707 .53742 Mdot
.42635 .36597 Mdot
.36626 .56025 Mdot
.58848 .65755 Mdot
.59723 .37147 Mdot
.34851 .37936 Mdot
.32996 .47383 Mdot
.66131 .55565 Mdot
.5354 .42633 Mdot
.51338 .2938 Mdot
.5483 .4986 Mdot
.51083 .32378 Mdot
.60917 .53388 Mdot
.55901 .67869 Mdot
.41391 .38687 Mdot
.62234 .46294 Mdot
.51331 .42888 Mdot
.38986 .60113 Mdot
.45834 .65986 Mdot
.35867 .60515 Mdot
.38584 .5586 Mdot
.53939 .28086 Mdot
.39727 .59134 Mdot
.63036 .43691 Mdot
.43802 .61418 Mdot
.57983 .36901 Mdot
.49854 .31253 Mdot
.56728 .41785 Mdot
.66483 .43398 Mdot
.32059 .49142 Mdot
.42592 .41874 Mdot
.58406 .69722 Mdot
.50169 .69754 Mdot
.28337 .47803 Mdot
.53342 .34122 Mdot
.33866 .48657 Mdot
.40619 .58614 Mdot
.45279 .42219 Mdot
.47562 .33219 Mdot
.50723 .46373 Mdot
.63994 .35492 Mdot
.43825 .63539 Mdot
.58483 .66053 Mdot
.50576 .66515 Mdot
.69652 .50947 Mdot
.5602 .34352 Mdot
.55594 .63031 Mdot
.49719 .58038 Mdot
.50271 .41979 Mdot
.45626 .30976 Mdot
.64434 .56612 Mdot
.72446 .43875 Mdot
.43911 .67851 Mdot
.33029 .47913 Mdot
.5247 .68876 Mdot
.49873 .60667 Mdot
.54626 .5768 Mdot
.34759 .50669 Mdot
.68186 .52973 Mdot
.55853 .64652 Mdot
.47787 .68618 Mdot
.35222 .45176 Mdot
.55836 .59591 Mdot
.49195 .32055 Mdot
.64285 .40357 Mdot
.53317 .5756 Mdot
.51623 .31993 Mdot
.70075 .52527 Mdot
.35544 .44102 Mdot
.37606 .5339 Mdot
.34935 .37344 Mdot
.37435 .66987 Mdot
.46883 .62169 Mdot
.50347 .35623 Mdot
.55953 .54068 Mdot
.66987 .56399 Mdot
.49338 .66792 Mdot
.58253 .3477 Mdot
.31384 .45331 Mdot
.66594 .40259 Mdot
.61127 .44179 Mdot
.40164 .60527 Mdot
.40086 .61841 Mdot
.61459 .59664 Mdot
.60094 .54179 Mdot
.46769 .57343 Mdot
.58633 .44983 Mdot
.4288 .63612 Mdot
.48121 .32344 Mdot
.33619 .45192 Mdot
.48299 .69873 Mdot
.51442 .28796 Mdot
.44684 .68199 Mdot
.45934 .68308 Mdot
.59898 .40801 Mdot
.57552 .59483 Mdot
.52887 .41394 Mdot
.52077 .39621 Mdot
.73662 .56826 Mdot
.30321 .48782 Mdot
.5698 .62585 Mdot
.58679 .43367 Mdot
.65433 .46011 Mdot
.5055 .62099 Mdot
.52541 .28572 Mdot
.66814 .50403 Mdot
.56985 .33729 Mdot
.58322 .37454 Mdot
.66833 .49253 Mdot
.62035 .53829 Mdot
.61619 .61446 Mdot
.39113 .41021 Mdot
.61737 .45124 Mdot
.46085 .38045 Mdot
.6855 .5155 Mdot
.43149 .55831 Mdot
.38674 .68698 Mdot
.36942 .54816 Mdot
.40971 .50398 Mdot
.41297 .44227 Mdot
.34906 .46064 Mdot
.38994 .37138 Mdot
.27416 .46842 Mdot
.6544 .44213 Mdot
.31652 .48175 Mdot
.50695 .63896 Mdot
.34429 .34618 Mdot
.53673 .39456 Mdot
.55685 .59516 Mdot
.38614 .6412 Mdot
.46459 .46308 Mdot
.52394 .34419 Mdot
.60575 .61325 Mdot
.5164 .66459 Mdot
.46941 .33543 Mdot
.37339 .66803 Mdot
.44477 .70071 Mdot
.66463 .57039 Mdot
.55702 .31343 Mdot
.50173 .66925 Mdot
.34263 .42045 Mdot
.69539 .42358 Mdot
.66657 .40739 Mdot
.61795 .59182 Mdot
.50714 .37747 Mdot
.68492 .47865 Mdot
.65418 .59036 Mdot
.467 .30135 Mdot
.70579 .4211 Mdot
.38201 .45274 Mdot
.55702 .67459 Mdot
.37793 .64664 Mdot
.41475 .45556 Mdot
.33862 .35493 Mdot
.47587 .35292 Mdot
.39109 .63793 Mdot
.60045 .44771 Mdot
.32964 .49027 Mdot
.62591 .39407 Mdot
.64188 .39418 Mdot
.67084 .55005 Mdot
.45817 .63863 Mdot
.67513 .4174 Mdot
.65524 .47344 Mdot
.42558 .67778 Mdot
.33425 .48638 Mdot
.40285 .43908 Mdot
.5582 .53479 Mdot
.45267 .44926 Mdot
.42134 .38878 Mdot
.53648 .33059 Mdot
.57831 .33008 Mdot
.60678 .33663 Mdot
.36409 .52918 Mdot
.56277 .41031 Mdot
.46039 .52088 Mdot
.35824 .45251 Mdot
.65549 .49789 Mdot
.62189 .46105 Mdot
.61309 .38803 Mdot
.46888 .62205 Mdot
.36194 .69948 Mdot
.34347 .45347 Mdot
.41171 .54554 Mdot
.57399 .33673 Mdot
.6784 .51613 Mdot
.65542 .44182 Mdot
.32702 .47021 Mdot
.46156 .57038 Mdot
.39612 .50574 Mdot
.31454 .49966 Mdot
.43675 .34547 Mdot
.61264 .6155 Mdot
.33072 .51131 Mdot
.44681 .30088 Mdot
.66488 .47084 Mdot
.52766 .37831 Mdot
.67609 .60659 Mdot
.64024 .37931 Mdot
.39284 .55853 Mdot
.33053 .49771 Mdot
.59042 .44405 Mdot
.65589 .62101 Mdot
.46264 .64763 Mdot
.61965 .43546 Mdot
.63714 .39439 Mdot
.42403 .63084 Mdot
.71818 .51986 Mdot
.427 .48214 Mdot
.66526 .65513 Mdot
.48148 .35514 Mdot
.32774 .46253 Mdot
.45913 .69287 Mdot
.36706 .42539 Mdot
.4434 .70168 Mdot
.48633 .62226 Mdot
.44247 .68312 Mdot
.37262 .59132 Mdot
.62353 .43321 Mdot
.3192 .48198 Mdot
.43 .61714 Mdot
.33067 .4595 Mdot
.45149 .32005 Mdot
.65969 .62745 Mdot
.43848 .58111 Mdot
.38331 .5787 Mdot
.54745 .61583 Mdot
.58419 .60084 Mdot
.65995 .42526 Mdot
.50812 .3212 Mdot
.63426 .48787 Mdot
.36479 .68219 Mdot
.444 .45258 Mdot
.49228 .36467 Mdot
.61481 .4792 Mdot
.48853 .36414 Mdot
.42309 .46425 Mdot
.37703 .68125 Mdot
.31074 .50137 Mdot
.57504 .65557 Mdot
.39048 .53044 Mdot
.2704 .462 Mdot
.34445 .34516 Mdot
.44686 .70435 Mdot
.70182 .4265 Mdot
.34883 .52255 Mdot
.64872 .39366 Mdot
.47468 .35765 Mdot
.44538 .67878 Mdot
.38122 .5989 Mdot
.66313 .40686 Mdot
.3691 .70109 Mdot
.38782 .59785 Mdot
.72608 .44432 Mdot
.64794 .42848 Mdot
.51891 .28497 Mdot
.64938 .58249 Mdot
.52359 .63714 Mdot
.39826 .71115 Mdot
.34304 .35826 Mdot
.6321 .42822 Mdot
.61248 .59651 Mdot
.66478 .56604 Mdot
.61942 .38288 Mdot
.42289 .42384 Mdot
.65989 .54735 Mdot
.48921 .31502 Mdot
.37994 .62075 Mdot
.444 .44492 Mdot
.57252 .61543 Mdot
.42234 .56092 Mdot
.42364 .39341 Mdot
.32726 .44576 Mdot
.37534 .37333 Mdot
.41988 .52913 Mdot
.44803 .36088 Mdot
.69006 .4279 Mdot
.47339 .30423 Mdot
.57753 .59053 Mdot
.49508 .65594 Mdot
.41677 .51137 Mdot
.5824 .53137 Mdot
.57009 .71935 Mdot
.33338 .50788 Mdot
.39476 .47207 Mdot
.66896 .42188 Mdot
.58969 .5276 Mdot
.51524 .62885 Mdot
.52934 .61745 Mdot
.40375 .42593 Mdot
.57413 .70871 Mdot
.35877 .57092 Mdot
.3761 .37601 Mdot
.38817 .70196 Mdot
.33884 .3582 Mdot
.54412 .40925 Mdot
.67073 .46705 Mdot
.63686 .42961 Mdot
.64114 .38654 Mdot
.4561 .40389 Mdot
.4208 .38608 Mdot
.57572 .71836 Mdot
.36938 .43905 Mdot
.48516 .45953 Mdot
.67062 .51788 Mdot
.4102 .55935 Mdot
.33147 .46594 Mdot
.43507 .45639 Mdot
.42147 .3518 Mdot
.47221 .32222 Mdot
.47616 .37834 Mdot
.66031 .50887 Mdot
.64543 .61208 Mdot
.65534 .43564 Mdot
.37509 .50681 Mdot
.51764 .66936 Mdot
.31098 .46729 Mdot
.52136 .362 Mdot
.59063 .47197 Mdot
.57622 .60929 Mdot
.4208 .59412 Mdot
.34114 .50634 Mdot
.53543 .28411 Mdot
.42216 .54537 Mdot
.41819 .43993 Mdot
.34489 .46714 Mdot
.58467 .69408 Mdot
.50552 .51914 Mdot
.42924 .45098 Mdot
.34735 .44277 Mdot
.5289 .27722 Mdot
.39676 .61172 Mdot
.4551 .69659 Mdot
.67302 .46715 Mdot
.34771 .37593 Mdot
.3238 .49171 Mdot
.66761 .46558 Mdot
.58581 .44876 Mdot
.71219 .42128 Mdot
.43514 .44403 Mdot
.48509 .6925 Mdot
.63464 .57273 Mdot
.3645 .38749 Mdot
.46601 .43435 Mdot
.29509 .49533 Mdot
.50776 .36632 Mdot
.52583 .4149 Mdot
.43334 .68472 Mdot
.60773 .38559 Mdot
.40851 .65942 Mdot
.66486 .53871 Mdot
.48276 .34846 Mdot
.63257 .35255 Mdot
.49597 .29529 Mdot
.53645 .58524 Mdot
.69722 .52701 Mdot
.55941 .40954 Mdot
.52727 .66886 Mdot
.58541 .50777 Mdot
.72156 .5206 Mdot
.55057 .66487 Mdot
.3769 .43705 Mdot
.56585 .56687 Mdot
.73098 .57523 Mdot
.43444 .62669 Mdot
.52423 .54741 Mdot
.58465 .58456 Mdot
.4995 .60608 Mdot
.50334 .5807 Mdot
.6427 .57411 Mdot
.5161 .52792 Mdot
.58008 .65177 Mdot
.6306 .55552 Mdot
.40401 .45995 Mdot
.61454 .42822 Mdot
.47182 .39465 Mdot
.45523 .29009 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0?ooooooB_ooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A006ooooo`03o`000?oooooooooo0?ooooooB_ooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0?ooooooB_oo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06
ooooo`?o0000oooooom:ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<oooo
o`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom:ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001_ooool00ol0003oooooooooo`3ooooood[ooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`2Uooooo`;o000000?oooooo`000?l000001_l00002ooooo`;o000000?o
ooooo`000?l00000T_ooool001cooooo00?o0000ooooooooool0X_ooool>o`0000;ooooo1ol0002@
ooooo`007?ooool00ol0003oooooooooo`2Hooooo`;o000000?oooooo`000?l000007Ol0002?oooo
o`007?ooool00ol0003oooooooooo`2EooooobKo0000S_ooool001cooooo00?o0000ooooooooool0
TooooolXo`0008kooooo000Looooo`03o`000?oooooooooo097ooooo7?l000000ooooooo0000o`00
000>o`0008_ooooo000Looooo`03o`000?oooooooooo093ooooo5ol000001?oooooo0000o`000?oo
oolCo`0008_ooooo000Looooo`03o`000?oooooooooo08oooooo6_l000000ooooooo0000o`00000=
o`000003ooooool0003o000000;o0000Roooool001cooooo00?o0000ooooooooool0S_oooolKo`00
0003ooooool0003o000001Co0000ROooool001cooooo00?o0000ooooooooool0S_oooolCo`0000;o
oooo0_l00007oooooaGo0000R?ooool001cooooo00?o0000ooooooooool0SOoooolBo`0000Cooooo
1?l00005oooooaGo0000R?ooool001cooooo00?o0000ooooooooool0S?oooolEo`000003ooooool0
003o000000?o00001_oooolEo`0008Oooooo000Looooo`;o0000SOooool4o`000003ooooool0003o
000000So000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000009oooooaGo0000Qooo
ool001cooooo00?o0000ooooooooool0S?ooool3o`0000;ooooo0_l000000ooooooo0000o`000003
o`0000?ooooo1?l00006ooooo`;o00001_oooolEo`0008Kooooo000Looooo`03o`000?oooooooooo
08_ooooo0ol00008ooooo`Co00001?ooool2o`0000Kooooo0_l000001?oooooo0000o`000?oooolI
o`0008Cooooo000Looooo`03o`000?oooooooooo08_ooooo0_l00003ooooo`;o00001_ooool2o`00
00oooooo0_l000001?oooooo0000o`000?oooolFo`0008Cooooo000Looooo`03o`000?oooooooooo
08[ooooo0ol00003ooooo`;o00003?ooool2o`000003ooooool0003o000000Cooooo0_l00007oooo
oaGo0000Q?ooool001cooooo00?o0000ooooooooool0ROooool4o`000003ooooool0003o000000_o
oooo0_l000001?oooooo0000o`000?ooool2o`0000Cooooo0_l00008oooooaCo0000Q?ooool001co
oooo00?o0000ooooooooool0N_ooool4o`0000_ooooo1?l000001?oooooo0000o`000?l0000:oooo
o`;o00001oooool2o`0000gooooo4_l00024ooooo`007?ooool00ol0003oooooooooo`1cooooo`Go
00000_ooool5o`0000Wooooo1?l00003ooooo`;o00001Oooool2o`0000Cooooo0_l00003ooooo`;o
000000?oooooo`000?l000004Oooool?o`0008?ooooo000Looooo`03o`000?oooooooooo077ooooo
2Ol000000ooooooo0000o`000002o`0000Wooooo1_l00008ooooo`Go000000Coooooo`000?l0003o
oooo1Ol0000Dooooo`ko0000Poooool001cooooo00?o0000ooooooooool0K_oooolCo`0000Oooooo
1_l00006ooooo`;o00000_ooool3o`0000Cooooo0_l000000ooooooo0000o`00000>ooooo`;o0000
1Oooool=o`0008?ooooo000Looooo`03o`000?oooooooooo06kooooo4ol00006ooooo`?o000000?o
ooooo`000?l000001oooool2o`000003ooooool0003o000000Kooooo0_l00009ooooo`;o00000ooo
ool5o`0000Cooooo3_l00023ooooo`007?ooool00ol0003oooooooooo`1^oooooaCo00001?ooool4
o`000003ooooool0003o000000Sooooo1?l0000Aooooo`;o00000oooool5o`0000Cooooo0_l00003
ooooo`ko0000O_ooool001cooooo00?o0000ooooooooool0K?oooolFo`0000?ooooo1Ol00009oooo
o`Co00004oooool2o`0000Kooooo0_l000000ooooooo0000o`000002o`0000Kooooo4?l0001joooo
o`007?ooool00ol0003oooooooooo`1/oooooaKo00000oooool4o`0000[ooooo0_l0000Dooooo`?o
00002Oooool4o`0000Sooooo0_l000000ooooooo0000o`00000=o`0007Kooooo000Looooo`03o`00
0?oooooooooo06_ooooo5ol00002ooooo`Go00002_ooool3o`0000;ooooo0_l0000<ooooo`;o0000
00Goooooo`000?l0003o0000ooooo`02o`0000?ooooo0_l00006ooooo`;o00002_ooool2o`0000Go
oooo2Ol0001cooooo`007?ooool00ol0003oooooooooo`1Zooooo`Co000000?oooooo`000?l00000
5ol00002ooooo`;o00002?ooool2o`0000;ooooo0ol0000;ooooo`;o00001Oooool2o`0000?ooooo
1?l00003ooooo`?o00001_ooool2o`0000;ooooo0_l00005ooooo`Wo0000Loooool001cooooo0_l0
001[oooooako000000Goooooo`000?l0003o0000ooooo`02o`0000[ooooo0_l00004ooooo`;o0000
4oooool3o`0000;ooooo0_l00007ooooo`;o00000_ooool4o`0000?ooooo2_l0001booooo`007?oo
ool00ol0003oooooooooo`1Zooooo`;o000000?oooooo`000?l000006?l00002ooooo`;o00000_oo
ool2o`0000Sooooo1?l00004ooooo`;o00002oooool4o`0000;ooooo0_l000000ooooooo0000o`00
0009ooooo`;o00001?ooool6o`000003ooooool0003o000000[o0000L?ooool001cooooo00?o0000
ooooooooool0JOooool3o`000003ooooool0003o000001So00001oooool2o`0000Oooooo1?l00005
ooooo`?o00002Oooool4o`0000;ooooo0_l0000<ooooo`;o00002?ooool@o`0006oooooo000Loooo
o`03o`000?oooooooooo06Wooooo7?l00009ooooo`;o000000?oooooo`000?l000000oooool2o`00
0003ooooool0003o000000;ooooo0_l000001?oooooo0000o`000?l00005ooooo`;o00001?ooool2
o`0000;ooooo0_l0000<ooooo`;o00002_ooool>o`0006oooooo000Looooo`03o`000?oooooooooo
06Wooooo6ol00003ooooo`;o00001Oooool2o`000004ooooool0003o0000o`0000;ooooo0_l00005
ooooo`Go00001?ooool4o`0000Gooooo0_l000000ooooooo0000o`00000;ooooo`;o00000oooool2
o`0000Oooooo3Ol0001_ooooo`007?ooool00ol0003oooooooooo`1Yooooo`;o000000Coooooo`00
0?l0003ooooo5?l00004ooooo`;o00001?ooool3o`0000;ooooo0_l00007ooooo`Go000000?ooooo
o`000?l000000oooool2o`0000Oooooo0_l0000>ooooo`;o00000oooool2o`0000Oooooo3Ol0001_
ooooo`007?ooool00ol0003oooooooooo`1Yooooo`;o000000Coooooo`000?l0003ooooo4ol00005
ooooo`;o00001?ooool2o`0000cooooo0ol00003ooooo`;o00000oooool4o`0000oooooo0_l00006
ooooo`;o00002oooool<o`0006oooooo000Looooo`03o`000?oooooooooo06Sooooo0ol00005oooo
oa7o00005Oooool2o`0000Sooooo0_l00003ooooo`Go00003Oooool4o`0000?ooooo1Ol0000<oooo
o`[o0000L?ooool001cooooo00?o0000ooooooooool0J?ooool3o`0000?ooooo0_l00002ooooo`co
00001oooool2o`0000oooooo0_l00008ooooo`;o00000oooool2o`00013ooooo0_l000000ooooooo
0000o`000002ooooo`?o00002?ooool2o`0000Cooooo2ol0001_ooooo`007?ooool00ol0003ooooo
ooooo`1Yooooo`;o00000_ooool3o`0000Kooooo0ol00003ooooo`;o00001oooool2o`00013ooooo
0_l00008ooooo`;o00001Oooool2o`00013ooooo0_l00004ooooo`;o00000_ooool2o`000003oooo
ool0003o000000;o00001?ooool>o`0006cooooo000Looooo`03o`000?oooooooooo06Wooooo0ol0
00000ooooooo0000o`000006ooooo`?o00002?ooool2o`0000;ooooo0_l0000<ooooo`;o00000ooo
ool2o`0000Kooooo1?l00005ooooo`;o00001oooool2o`0000[ooooo1Ol00002ooooo`;o000000?o
ooooo`000?l000000oooool2o`0000;ooooo3Ol0001/ooooo`007?ooool00ol0003oooooooooo`1Z
ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Wooooo0_l00002ooooo`;o00002oooool3
o`0000;ooooo0_l00007ooooo`?o00003oooool2o`0000[ooooo0ol00005ooooo`Co00000oooool2
o`0000?ooooo3Ol0001[ooooo`007?ooool00ol0003oooooooooo`1cooooo`;o00003_ooool4o`00
00[ooooo0_l00003ooooo`;o00001_ooool4o`00023ooooo0_l000000ooooooo0000o`000002o`00
00?ooooo0_l00003ooooo`go0000Joooool001cooooo00?o0000ooooooooool0JOooool2o`0000So
oooo0_l00003ooooo`;o00001?ooool2o`0000?ooooo1?l00005ooooo`Co000000Coooooo`000?l0
003ooooo0_l00008ooooo`;o00005Oooool2o`0000_ooooo0ol00007ooooo`;o00001?ooool>o`00
06Wooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool01?ooool00ol0003oooooooooo`1Yooooo`;o00003Oooool2o`0000Cooooo0_l00003
ooooo`Go00001?ooool4o`0000Cooooo0ol0000Eooooo`;o00000oooool2o`0000;ooooo0_l0000<
ooooo`;o000000?oooooo`000?l000001Ol00002ooooo`;o00000oooool<o`0006Wooooo00001_oo
ooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0JOooool2o`0001_ooooo0_l00004ooooo`;o00001oooool3o`0000Oooooo0_l0
0004ooooo`;o00001?ooool3o`0000?ooooo0_l0000Cooooo`_o00000oooool<o`0006Wooooo0000
0ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006ooooo`03o`000?oooooo
oooo06;ooooo1?l0000Gooooo`;o00003Oooool2o`0000Sooooo0_l00007ooooo`;o00001?ooool2
o`0000Cooooo0_l0000Nooooo`Co00001_ooool=o`0006Oooooo00000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`0005oooooo2Ol00009
ooooo`;o00002?ooool4o`0002Sooooo0_l00002ooooo`;o00005_ooool3o`0000_ooooo0_l00002
ooooo`;o000000?oooooo`000?l000002?l0001Wooooo`0000?oooooo`000?ooool00_ooool00ol0
003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0Foooool=
o`000003ooooool0003o000000Kooooo0_l00008ooooo`Co00004Oooool2o`0001Gooooo0_l00002
ooooo`;o00005?ooool5o`0000Oooooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo2?l0001W
ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co0000
00Oooooo00?o0000ooooooooool0F?ooool@o`000003ooooool0003o000001;ooooo0_l0000Aoooo
o`;o00004_ooool2o`0000Oooooo0_l0000@ooooo`Go00000oooool2o`0000Cooooo0_l00005oooo
o`Co00001?ooool3o`000003ooooool0003o000006Oooooo00001_ooooooMgMgoiRHV?ooooooV9RH
ogMgM`cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`1Goooooa7o000000?ooooo
o`000?l000004?ooool4o`000003ooooool0003o000002;ooooo0_l00007ooooo`;o00000oooool3
o`000003ooooool0003o000000Oooooo1Ol00003ooooo`?o00002?ooool6o`0000Sooooo0_l0001W
ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o
0000ooooooooool0EOoooolFo`00013ooooo0_l00003ooooo`Co000000Coooooo`000?l0003o0000
4_ooool2o`0000_ooooo0ol00008ooooo`?o000000?oooooo`000?l000004?ooool2o`0000Sooooo
0_l0000:ooooo`Oo0000I?ooool001cooooo00?o0000ooooooooool0E?oooolGo`0001Oooooo0_l0
00000ooooooo0000o`000002o`0000Sooooo0_l00007ooooo`;o00002oooool3o`0000Sooooo1?l0
000=ooooo`;o00001Oooool2o`0000Kooooo0_l00004ooooo`;o00001?ooool2o`000003ooooool0
003o000000Co0000H_ooool001cooooo00?o0000ooooooooool0DooooolGo`0000;ooooo0_l00003
ooooo`;o00001?ooool2o`0000gooooo0ol00008ooooo`;o00003Oooool2o`00013ooooo1?l0000=
ooooo`;o00001Oooool4o`0000[ooooo1?l00005ooooo`;o000000?oooooo`000?l000000_l0001Q
ooooo`007?ooool00ol0003oooooooooo`1BoooooaOo00000oooool2o`0000?ooooo0_l00004oooo
o`;o00003Oooool2o`0000Kooooo0ol0000?ooooo`;o000000?oooooo`000?l000006Oooool2o`00
00cooooo0_l00008ooooo`;o00000_ooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool5
o`00063ooooo000Looooo`03o`000?oooooooooo057ooooo6?l00006ooooo`;o00000_ooool2o`00
00[ooooo0_l00005ooooo`;o00001_ooool3o`0000kooooo0_l00002ooooo`Co00000oooool2o`00
01;ooooo0_l0000Booooo`?o000000?oooooo`000?l000001?ooool7o`0000Cooooo0_l0001Poooo
o`007?ooool00ol0003oooooooooo`1@oooooaWo00001?ooool4o`0000;ooooo0_l0000:ooooo`;o
00007_ooool2o`0000;ooooo1?l00003ooooo`;o00001oooool2o`0000oooooo0_l00004ooooo`?o
00000_ooool2o`000003ooooool0003o000000;o00001_ooool7o`0000Cooooo1Ol0001Mooooo`00
7?ooool00ol0003oooooooooo`1@oooooaWo00000_ooool4o`0000Oooooo0_l0000Aooooo`;o0000
6?ooool2o`0000kooooo1?l00004ooooo`;o00001Oooool4o`000004ooooool0003o0000ooooo`?o
00000_ooool4o`000003ooooool0003o000000Cooooo2ol00004ooooo`?o0000GOooool001cooooo
00?o0000ooooooooool0D?oooolGo`0000Cooooo0_l00009ooooo`?o00004?ooool2o`0000Wooooo
0_l00002ooooo`;o00006_ooool3o`0000Cooooo1?l00003ooooo`;o000000?oooooo`000?l00000
1?l00006ooooo`So000000?oooooo`000?l000002_l00005ooooo`;o0000G?ooool001cooooo00?o
0000ooooooooool0CooooolHo`0000gooooo0_l000000ooooooo0000o`000006ooooo`;o00000ooo
ool2o`0000Kooooo0_l00005ooooo`?o00000_ooool2o`0000Gooooo0_l0000Looooo`;o00001_oo
ool2o`0000;ooooo0_l00006ooooo`?o00000_oooolAo`000004ooooool0003o0000ooooo`;o0000
G?ooool001cooooo00?o0000ooooooooool0Coooool2o`0000;ooooo4_l00008ooooo`Go00000_oo
ool2o`0000Wooooo0_l000000ooooooo0000o`000002o`0000Kooooo0_l00005ooooo`;o00002_oo
ool2o`0000;ooooo0_l0000<ooooo`;o00004?ooool2o`0000?ooooo0_l00004ooooo`;o000000?o
ooooo`000?l000001_oooolAo`000003ooooool0003o000005cooooo000Looooo`03o`000?oooooo
oooo04oooooo0_l00002ooooo`Ko000000?oooooo`000?l000002Ol00002ooooo`;o00000oooool6
o`0000Cooooo0_l00003ooooo`;o00001Oooool2o`0000Kooooo1?l0000@ooooo`;o00000oooool2
o`0000cooooo0_l00009ooooo`;o00000oooool4o`0000?ooooo0_l00004ooooo`;o000000?ooooo
o`000?l000001_oooolAo`000004ooooool0003o0000o`0005_ooooo000Looooo`03o`000?oooooo
oooo04kooooo0ol00002oooooa7o00000oooool2o`0000?ooooo1?l00006ooooo`;o00000oooool2
o`0000gooooo1?l000000ooooooo0000o`00000=ooooo`;o00006oooool3o`000003ooooool0003o
000000;o00001Oooool2o`0000oooooo4Ol000001?oooooo0000o`000?l0001Kooooo`007?ooool2
o`0004oooooo0ol00003ooooo`oo00001_ooool3o`0000?ooooo1?l000000ooooooo0000o`000008
ooooo`;o00002?ooool6o`000003ooooool0003o000002[ooooo0ol000001?oooooo0000o`000?l0
0003ooooo`;o00003oooool2o`000003ooooool0003o000000go00000oooool2o`0005cooooo000L
ooooo`03o`000?oooooooooo04kooooo0ol00003ooooo`go000000?oooooo`000?l000001Oooool5
o`000003ooooool0003o000000;o000000?oooooo`000?l000000_ooool2o`0000Cooooo0ol00002
ooooo`;o00000oooool6o`0000;ooooo0ol0000Xooooo`?o00000_ooool2o`000003ooooool0003o
000000;o00003oooool2o`000003ooooool0003o000000ko000000Coooooo`000?l0003o0000G?oo
ool001cooooo00?o0000ooooooooool0C_ooool3o`0000Cooooo2_l00003ooooo`;o00001oooool3
o`0000;ooooo0_l00006ooooo`;o00001Oooool2o`0000;ooooo0_l00005ooooo`;o00001?ooool3
o`0002gooooo0_l000000ooooooo0000o`000002o`0001;ooooo4?l000001?oooooo0000o`000?l0
001Looooo`007?ooool00ol0003oooooooooo`1?ooooo`?o00000oooool7o`0000cooooo0_l00004
ooooo`Co00003Oooool2o`0000Wooooo0_l0000>ooooo`;o00009?ooool2o`0000Cooooo0_l00009
ooooo`;o00002?oooolBo`0005cooooo000Looooo`03o`000?oooooooooo04oooooo0ol00002oooo
o`Go00000oooool2o`0000Wooooo0ol00004ooooo`;o00003oooool2o`0000Gooooo0_l0000;oooo
o`;o00001Oooool2o`0000Gooooo0_l0000@ooooo`;o00004Oooool2o`0000Oooooo1?l00008oooo
oa;o0000G?ooool001cooooo00?o0000ooooooooool0Coooool3o`0000;ooooo0ol00005ooooo`;o
00000oooool2o`0000Cooooo1?l000001?oooooo0000o`000?ooool2o`000003ooooool0003o0000
01;ooooo0_l00003ooooo`;o00001_ooool2o`0000cooooo0_l0000@ooooo`;o00004Oooool2o`00
00Oooooo0_l00004ooooo`Co000000?oooooo`000?l000004?l0001Mooooo`007?ooool00ol0003o
ooooooooo`1@ooooo`;o000000?oooooo`000?l000000_l00005ooooo`;o00000oooool2o`0000Co
oooo1?l000001?oooooo0000o`000?ooool2o`000003ooooool0003o0000013ooooo0_l00005oooo
o`;o00001?ooool2o`0000;ooooo0_l0000Mooooo`;o00006?ooool2o`0000Cooooo1Ol000000ooo
oooo0000o`00000@o`0005gooooo000Looooo`03o`000?oooooooooo057ooooo1_l0000@ooooo`?o
00000oooool2o`0000?ooooo0_l00008ooooo`;o00001_ooool2o`0000_ooooo0_l00002ooooo`;o
00006_ooool2o`000003ooooool0003o000000Kooooo0_l00009ooooo`;o00001Oooool2o`000004
ooooool0003o0000ooooo`?o00000oooool@o`0005oooooo000Looooo`03o`000?oooooooooo057o
oooo0ol000000ooooooo0000o`00000@ooooo`Co00000_ooool2o`0000?ooooo0_l00008ooooo`;o
00004oooool2o`0000[ooooo0_l00002ooooo`;o00003_ooool2o`0000Wooooo0_l00008ooooo`?o
00002?ooool2o`0000Oooooo0_l000000ooooooo0000o`00000:o`00063ooooo000Looooo`03o`00
0?oooooooooo057ooooo0ol000001?oooooo0000o`000?ooool2o`0000kooooo0ol0000Aooooo`;o
00005?ooool2o`0000Wooooo0_l00002ooooo`;o00008Oooool5o`0000kooooo0_l00002ooooo`;o
00000_ooool9o`00067ooooo000Looooo`03o`000?oooooooooo05;ooooo1Ol000001?oooooo0000
o`000?ooool2o`0000Kooooo0ol00002ooooo`;o00004_ooool2o`000003ooooool0003o000000Ko
oooo0_l00009ooooo`;o0000<?ooool2o`00017ooooo0_l00002ooooo`?o00000oooool6o`0006;o
oooo000Looooo`03o`000?oooooooooo05?ooooo1ol000000ooooooo0000o`000006ooooo`Co0000
0_ooool3o`0000Cooooo0_l0000=ooooo`;o00001_ooool2o`0003Wooooo1Ol00006ooooo`;o0000
1?ooool2o`0000;ooooo0ol00002ooooo`;o0000Joooool001cooooo00?o0000ooooooooool0E_oo
ool4o`0000Gooooo0_l00004ooooo`?o000000?oooooo`000?l000000_l00002ooooo`?o00006_oo
ool4o`0003;ooooo0_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000000_oo
ool4o`000003ooooool0003o000000;o000000Coooooo`000?l0003ooooo0_l0001Yooooo`007?oo
ool00ol0003oooooooooo`1Gooooo`Co00001?ooool2o`0000?ooooo2Ol00002ooooo`;o00006?oo
ool2o`000003ooooool0003o000000;o00001?ooool2o`0003Cooooo0_l00005ooooo`;o00000_oo
ool5o`000003ooooool0003o000000Co0000J?ooool001cooooo00?o0000ooooooooool0F?ooool6
o`0000Cooooo2Ol00005ooooo`;o00001_ooool2o`0000oooooo0_l00009ooooo`;o0000>oooool2
o`0000;ooooo0_l00005ooooo`;o000000Coooooo`000?l0003o0000Ioooool001cooooo00?o0000
ooooooooool0FOooool5o`0000Cooooo2?l00006ooooo`;o00001_ooool2o`0000_ooooo1?l0000T
ooooo`?o00002?ooool2o`0001Oooooo0_l0000=ooooo`;o0000Ioooool001cooooo0_l0001Moooo
o`Co000000Goooooo`000?l0003o0000ooooo`05o`0000[ooooo0_l00004ooooo`;o00002Oooool4
o`0002Cooooo0ol00004ooooo`;o00000_ooool2o`0001Kooooo0ol0000?ooooo`;o0000IOooool0
01cooooo00?o0000ooooooooool0G_ooool2o`000004ooooool0003o0000o`00013ooooo0_l00004
ooooo`;o00001Oooool2o`00037ooooo0_l0000Jooooo`;o00000oooool2o`0000_ooooo0_l0001U
ooooo`007?ooool00ol0003oooooooooo`1Sooooo`?o00000oooool6o`0000Oooooo0_l00005oooo
o`;o00000_ooool2o`0000kooooo0_l00002ooooo`;o00008oooool2o`0001Wooooo0_l00003oooo
o`;o00000oooool2o`000003ooooool0003o000006Gooooo000Looooo`03o`000?oooooooooo06?o
oooo1?l00002ooooo`Ko00001oooool6o`000003ooooool0003o000001;ooooo0_l00002ooooo`;o
00008oooool2o`0000gooooo0_l00007ooooo`?o00001Oooool2o`0000;ooooo0ol000000ooooooo
0000o`000002ooooo`;o0000HOooool001cooooo00?o0000ooooooooool0I?ooool6o`0000cooooo
1_l00008ooooo`;o0000<_ooool2o`0000;ooooo0_l0000;ooooo`;o00001oooool3o`0000;ooooo
1?l00003ooooo`;o00001_ooool2o`00067ooooo000Looooo`03o`000?oooooooooo06Gooooo1Ol0
000Jooooo`;o0000:Oooool2o`0000Oooooo0_l00002ooooo`;o00006Oooool6o`0006cooooo000L
ooooo`03o`000?oooooooooo06Oooooo1?l000000ooooooo0000o`00000booooo`;o00003Oooool2
o`0000gooooo0_l0000Fooooo`;o000000?oooooo`000?l000000_l00008ooooo`?o0000HOooool0
01cooooo00?o0000ooooooooool0Ioooool;o`0001[ooooo0_l00004ooooo`;o00003?ooool2o`00
00oooooo0_l0000:ooooo`?o00002oooool2o`0000Wooooo0_l0000=ooooo`Co000000?oooooo`00
0?l00000GOooool001cooooo00?o0000ooooooooool0JOooool4o`000003ooooool0003o000000;o
00006_ooool2o`0000Cooooo0_l0000Mooooo`;o00001oooool5o`0000?ooooo0_l00007ooooo`;o
00004oooool2o`000003ooooool0003o000000Co000000?oooooo`000?l00000GOooool001cooooo
00?o0000ooooooooool0Joooool3o`0000Gooooo1?l0000;ooooo`;o000000Coooooo`000?l0003o
oooo0_l0000Jooooo`;o00005?ooool4o`0000Cooooo0_l0000<ooooo`;o00003Oooool:o`0000?o
oooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`1[ooooo`?o00001Oooool4o`0000Cooooo
0_l00005ooooo`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00005Oooool2o`0001?o
oooo0_l000001?oooooo0000o`000?l00009ooooo`;o00001?ooool4o`0000Sooooo0_l00003oooo
o`co000000?oooooo`000?l00000Foooool001cooooo00?o0000ooooooooool0JOooool6o`0000Oo
oooo0_l00003ooooo`;o00003_ooool4o`0002?ooooo0_l00005ooooo`;o00000_ooool2o`0000?o
oooo0_l00002ooooo`Co00001?ooool3o`0000Gooooo0_l00002ooooo`;o00000oooool9o`000004
ooooool0003o0000o`0005gooooo000Looooo`03o`000?oooooooooo06Oooooo2?l00007ooooo`;o
00002Oooool2o`0000Sooooo0_l0000Hooooo`;o00002oooool2o`0000;ooooo0_l00005ooooo`?o
00000_ooool2o`0000;ooooo1?l0000:ooooo`Co00000_oooolBo`000003ooooool0003o000005[o
oooo000Looooo`03o`000?oooooooooo06Gooooo3Ol00005ooooo`;o00002?ooool2o`0002;ooooo
0_l0000;ooooo`?o000000?oooooo`000?l000001Oooool4o`0000Gooooo0_l00005ooooo`;o0000
0_ooool2o`000003ooooool0003o000000?o000000?oooooo`000?l000003ol00002ooooo`?o0000
FOooool001cooooo00?o0000ooooooooool0IOooool=o`0000Gooooo0ol0000hooooo`?o00002_oo
ool2o`000004ooooool0003o0000ooooo`;o00001_ooool2o`0000;ooooo0_l00004ooooo`;o0000
0oooool8o`000003ooooool0003o000000Ko000000?oooooo`000?l00000FOooool001cooooo00?o
0000ooooooooool0IOooool>o`0000Gooooo0_l00008ooooo`;o000000?oooooo`000?l000002?oo
ool2o`0001;ooooo0_l00002ooooo`;o00004Oooool2o`0000Kooooo0_l000000ooooooo0000o`00
000:ooooo`Ko00001OoooolAo`000003ooooool0003o000005Wooooo000Looooo`;o0000I_ooool>
o`000003ooooool0003o000000?o00002Oooool2o`000003ooooool0003o000000Sooooo0_l00005
ooooo`;o00002_ooool3o`0000;ooooo0_l0000Aooooo`;o00005Oooool7o`0000?ooooo5Ol0001I
ooooo`007?ooool00ol0003oooooooooo`1Tooooo`ko00000_ooool5o`0001gooooo0_l0000:oooo
o`;o00005?ooool2o`0000gooooo0_l0000;ooooo`Co00000ooooolEo`0005Wooooo000Looooo`03
o`000?oooooooooo06Cooooo3_l0000kooooo`;o00002Oooool2o`0000Gooooo0_l00006ooooo`Co
000000?oooooo`000?l000001?ooool4o`0000Kooooo5?l0001Iooooo`007?ooool00ol0003ooooo
ooooo`1Tooooo`ko000000?oooooo`000?l000001Oooool4o`0000Cooooo0_l00004ooooo`;o0000
8oooool2o`00013ooooo0_l00006ooooo`Co000000?oooooo`000?l000001?ooool3o`0000?ooooo
6?l0001Iooooo`007?ooool00ol0003oooooooooo`1Soooooa;o00001Oooool4o`0000;ooooo1?l0
00001?oooooo0000o`000?ooool2o`0003Cooooo0ol00006ooooo`;o00003ooooolHo`0005Wooooo
000Looooo`03o`000?oooooooooo06?ooooo4?l0000=ooooo`;o00000oooool2o`0003Oooooo0ol0
000=ooooo`;o00001?oooolLo`0005Wooooo000Looooo`03o`000?oooooooooo06?ooooo4?l00004
ooooo`;o00004Oooool2o`0001;ooooo0_l0000Dooooo`Co00003?ooool2o`0000Sooooo0_l00004
oooooaco0000FOooool001cooooo00?o0000ooooooooool0H_oooolCo`0000;ooooo0_l0000Aoooo
o`;o00001_ooool2o`0000[ooooo0_l0000Dooooo`Co00003?ooool2o`0000Cooooo0_l00008oooo
o`?o000000?oooooo`000?l000005Ol0001Jooooo`007?ooool00ol0003oooooooooo`1Roooooa?o
00001Oooool2o`0000_ooooo0_l00009ooooo`Co000000?oooooo`000?l000004?ooool2o`0001oo
oooo0_l000000ooooooo0000o`000005ooooo`;o00000ooooolEo`0005_ooooo000Looooo`03o`00
0?oooooooooo06;ooooo4?l00007ooooo`?o00002oooool2o`0000_ooooo0_l000000ooooooo0000
o`000008ooooo`;o00000oooool2o`000003ooooool0003o000000?ooooo0_l0000Jooooo`;o0000
00?oooooo`000?l000000_l00002ooooo`;o000000?oooooo`000?l000000_oooolDo`0005_ooooo
000Looooo`03o`000?oooooooooo06;ooooo3ol00008ooooo`;o00002_ooool2o`0000Cooooo0_l0
0002ooooo`;o00003Oooool5o`0000?ooooo0ol00005ooooo`;o00005Oooool3o`0000;ooooo0_l0
0003ooooo`?o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00000Bo`0005cooooo
000Looooo`03o`000?oooooooooo06;ooooo3ol0000Aooooo`;o000000?oooooo`000?l000001?oo
ool3o`000003ooooool0003o000000gooooo1?l00005ooooo`;o00003oooool4o`0000Wooooo0ol0
0007ooooo`?o00001_ooool3o`0000;ooooo3_l0001Nooooo`007?ooool00ol0003oooooooooo`1S
ooooo`ko00003oooool4o`000003ooooool0003o000000Gooooo0_l000000ooooooo0000o`00000=
ooooo`;o00002_ooool2o`0000;ooooo0_l00008ooooo`Co000000?oooooo`000?l000003_ooool4
o`0000Kooooo0ol00006ooooo`[o0000Goooool001cooooo00?o0000ooooooooool0Hoooool>o`00
00Kooooo0_l00002ooooo`;o00000oooool2o`0000gooooo0_l00003ooooo`;o00002?ooool2o`00
0003ooooool0003o000000Oooooo0_l00002ooooo`Co00001_ooool2o`0000?ooooo0ol0000=oooo
o`;o00000_ooool2o`0000Cooooo1?l00005ooooo`So0000HOooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oo
oooooooo06Cooooo2ol00006ooooo`Co00000_ooool4o`0000Kooooo0_l00007ooooo`;o00001?oo
ool2o`0000_ooooo0_l00005ooooo`;o00001_ooool2o`0000Kooooo0_l00004ooooo`;o00001Ooo
ool2o`0000[ooooo1?l00003ooooo`?o0000K_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
1Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo06Co
oooo3?l00004ooooo`Go00000_ooool4o`0000Kooooo0_l00007ooooo`;o00006?ooool2o`0000;o
oooo0_l00003ooooo`?o00000oooool2o`0000[ooooo1?l00003ooooo`;o00001oooool2o`0000?o
oooo0ol0001^ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`1Tooooo`Ko000000?oooooo`000?l0
00000ol00004ooooo`;o00000_ooool5o`0002oooooo0_l00003ooooo`?o00000oooool2o`0000[o
oooo0ol00004ooooo`;o00001oooool3o`0000;ooooo0ol0001^ooooo`0000?oooooo`000?ooool0
0_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0006Go
oooo1_l000000ooooooo0000o`00000:ooooo`Go000000?oooooo`000?l00000>?ooool4o`0001Go
oooo1Ol00002ooooo`?o0000K_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
2Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0IOooool7o`000003
ooooool0003o000000;ooooo0_l00005ooooo`Go000000?oooooo`000?l000000_l00005ooooo`;o
00005Oooool2o`0000Oooooo0_l0000?ooooo`Co00001Oooool2o`0000kooooo0_l00002ooooo`;o
000000?oooooo`000?l00000Koooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool0
2Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo06Gooooo1ol000000ooooooo0000
o`000002ooooo`;o00000oooool5o`0000Cooooo0ol00005ooooo`;o00001Oooool2o`0000Kooooo
0_l00006ooooo`;o00001oooool2o`0000kooooo1?l00006ooooo`;o00000oooool2o`0000Wooooo
0_l000001Ooooooo0000o`000?l0003ooooo00?o0000K_ooool00006oooooomgMgOoV9RHoooooonH
V9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo06Kooooo1ol00008oooo
o`?o000000?oooooo`000?l000000_ooool2o`0000[ooooo0_l00003ooooo`;o00001_ooool2o`00
00Gooooo0ol0000Dooooo`;o000000?oooooo`000?l000000_l00006ooooo`;o00000oooool2o`00
00Kooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0ol0001^ooooo`0000Koooooonk^
k_lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0
I_ooool9o`0000Kooooo0_l00006ooooo`;o000000?oooooo`000?l000001oooool4o`0000oooooo
1?l0000>ooooo`;o000000Coooooo`000?l0003ooooo1?l00007ooooo`Wo00001_ooool2o`000003
ooooool0003o000000Gooooo0ol0001^ooooo`007?ooool00ol0003oooooooooo`1Wooooo`Wo0000
0_ooool2o`0000Gooooo0_l00003ooooo`Ko00001?ooool2o`000003ooooool0003o000000Wooooo
0_l00004ooooo`Co00002?ooool2o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`?o0000
1oooool7o`0000Sooooo0_l000000ooooooo0000o`000004ooooo`Co0000K_ooool001cooooo00?o
0000ooooooooool0J?ooool<o`0000Cooooo1?l00002ooooo`;o00000_ooool2o`0000Cooooo0_l0
000;ooooo`?o00002?ooool2o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0000Kooooo0_l0
000:ooooo`;o000000?oooooo`000?l000002oooool4o`0000;ooooo1?l0001^ooooo`007?ooool0
0ol0003oooooooooo`1Xooooo`[o00001_ooool6o`0001;ooooo0_l00002ooooo`?o00000oooool2
o`0000Cooooo0_l00002ooooo`;o00001oooool2o`0000Kooooo0_l0000:ooooo`;o000000?ooooo
o`000?l000001?ooool<o`0000;ooooo0ol0001^ooooo`007?ooool00ol0003oooooooooo`1Xoooo
o`_o00001_ooool5o`0000_ooooo0_l00005ooooo`;o00000_ooool2o`0000Cooooo0_l0000Ioooo
o`;o00004oooool7o`000003ooooool0003o000000;o00000_ooool3o`0006kooooo000Looooo`03
o`000?oooooooooo06[ooooo2_l000000ooooooo0000o`000003ooooo`;o00002_ooool2o`000003
ooooool0003o000001Wooooo0_l0000;ooooo`;o00000_ooool2o`00013ooooo0_l000000ooooooo
0000o`000005o`000004ooooool0003o0000o`0000;ooooo1?l0001^ooooo`007?ooool00ol0003o
ooooooooo`1Yooooo`_o000000?oooooo`000?l000003oooool2o`0001_ooooo0ol0000;ooooo`;o
00001?ooool4o`0000Cooooo0_l00004ooooo`co000000Coooooo`000?l0003o00000_ooool4o`00
06kooooo000Looooo`03o`000?oooooooooo06Wooooo3?l00008ooooo`;o00002Oooool2o`000003
ooooool0003o000000gooooo0_l00007ooooo`Go00001oooool2o`0000Kooooo1?l00004ooooo`;o
00000_oooolBo`0000?ooooo0ol0001^ooooo`007?ooool00ol0003oooooooooo`1Yooooo`Ko0000
00?oooooo`000?l000001?l00003ooooo`Ko00002Oooool2o`000003ooooool0003o000000Cooooo
0_l00007ooooo`;o00001Oooool2o`000003ooooool0003o000000;o00001oooool2o`0000?ooooo
0_l00008ooooo`;o00000ooooolCo`0000;ooooo0_l0001_ooooo`007?ooool00ol0003ooooooooo
o`1Yooooo`ko00000_ooool4o`0001Cooooo0_l00003ooooo`;o00002Oooool2o`00017ooooo0ol0
0002ooooo`;o00000oooool2o`0000?ooooo5ol0001_ooooo`007?ooool00ol0003oooooooooo`1Y
oooooa3o000000?oooooo`000?l000001?ooool2o`0000Kooooo0_l0000<ooooo`;o00002?ooool3
o`000003ooooool0003o000000Oooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2
o`0000Oooooo6?l0001_ooooo`007?ooool00ol0003oooooooooo`1Xoooooa7o00001oooool2o`00
00Kooooo1Ol00006ooooo`;o00000oooool2o`0000Kooooo0_l00002ooooo`;o00001_ooool3o`00
00?ooooo0_l000000ooooooo0000o`00000;oooooaSo0000Koooool001cooooo0_l0001Yooooo`oo
00004oooool4o`0000Gooooo0_l00003ooooo`;o00001_ooool2o`0000[ooooo0ol00006ooooo`;o
00000_ooool2o`0000Oooooo6?l0001_ooooo`007?ooool00ol0003oooooooooo`1Xooooo`oo0000
1_ooool2o`0000gooooo0_l00005ooooo`Co000000?oooooo`000?l000000oooool2o`000003oooo
ool0003o000000_ooooo0_l00008ooooo`Co00001OoooolIo`00073ooooo000Looooo`03o`000?oo
oooooooo06Wooooo3_l00002ooooo`;o00000_ooool2o`0001Kooooo0_l000001?oooooo0000o`00
0?l00002ooooo`?o00003Oooool2o`0000Sooooo1_l00003oooooaWo0000L?ooool001cooooo00?o
0000ooooooooool0J?ooool?o`0000;ooooo0_l00006ooooo`;o00003?ooool4o`0000?ooooo1Ol0
0003ooooo`;o00002Oooool2o`0000[ooooo0_l00002ooooo`Co000000?oooooo`000?l000005Ol0
00000ooooooo0000o`00001aooooo`007?ooool00ol0003oooooooooo`1Xooooo`oo00002_ooool2
o`000003ooooool0003o000000Wooooo1?l00003ooooo`Co00001oooool2o`000003ooooool0003o
000000?ooooo1?l00002ooooo`Co00000_ooool2o`0000?ooooo0_l00002ooooo`Go000000?ooooo
o`000?l000004_l0001aooooo`007?ooool00ol0003oooooooooo`1Xoooooa3o00000_ooool2o`00
00Sooooo0_l0000:ooooo`;o00000_ooool2o`0000Oooooo0_l00002ooooo`;o000000?oooooo`00
0?l000001Oooool2o`0000;ooooo1?l00007ooooo`;o00000ooooolGo`0007?ooooo000Looooo`03
o`000?oooooooooo06Sooooo4?l00002ooooo`;o00003?ooool2o`0000[ooooo0_l00007ooooo`Co
00000oooool2o`0000;ooooo0_l0000EoooooaKo0000M?ooool001cooooo00?o0000ooooooooool0
J?ooool@o`0000Kooooo0_l00008ooooo`Co00004oooool2o`0000?ooooo0_l00002ooooo`?o0000
5_oooolCo`0007Gooooo000Looooo`03o`000?oooooooooo06Sooooo3_l00008ooooo`;o00002Ooo
ool3o`0000gooooo0_l00002ooooo`;o00002_ooool2o`0000Kooooo0_l00003ooooo`;o00001_oo
ool2o`000003ooooool0003o000000Wo000000?oooooo`000?l000000_l0001hooooo`007?ooool0
0ol0003oooooooooo`1Xooooo`go00004Oooool2o`000003ooooool0003o000000Co00002_ooool2
o`0000;ooooo0_l0000:ooooo`Co00001?ooool3o`0000;ooooo0_l00002ooooo`;o00000_ooool2
o`000003ooooool0003o000000?o000000?oooooo`000?l000000ol000000ooooooo0000o`00001j
ooooo`007?ooool00ol0003oooooooooo`1Yooooo`co000000Coooooo`000?l0003o00002Oooool2
o`0000;ooooo0_l00002ooooo`Go00000_ooool2o`0000Kooooo0_l00002ooooo`;o00002Oooool2
o`000003ooooool0003o000000Cooooo1_l00003ooooo`;o00001_ooool4o`0008?ooooo000Loooo
o`03o`000?oooooooooo06_ooooo3_l00009ooooo`;o00001Oooool2o`000004ooooool0003o0000
o`0000;ooooo0_l00004ooooo`;o00001_ooool2o`0000Oooooo3ol00003ooooo`;o000000?ooooo
o`000?l000001?ooool2o`0008Cooooo000Looooo`03o`000?oooooooooo06Wooooo1ol00004oooo
o`;o00001?ooool2o`000003ooooool0003o000000[ooooo0_l00007ooooo`;o00000oooool2o`00
00Kooooo0_l00006oooooa7o00000_ooool2o`000003ooooool0003o000008[ooooo000Looooo`03
o`000?oooooooooo06Wooooo2?l00003ooooo`;o00001?ooool2o`000003ooooool0003o000001;o
oooo0ol00006ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`Go00000_ooool:o`0000Go
oooo0_l0002:ooooo`007?ooool00ol0003oooooooooo`1Zooooo`So00007oooool2o`0000Oooooo
0_l000001?oooooo0000o`000?l00002ooooo`?o000000?oooooo`000?l000000ol000000ooooooo
0000o`00000;o`000003ooooool0003o000008gooooo000Looooo`03o`000?oooooooooo06[ooooo
2Ol00003ooooo`;o000000?oooooo`000?l000000_l0000Cooooo`;o00001oooool2o`0000;ooooo
1ol000000ooooooo0000o`000002o`0000;ooooo3_l000000ooooooo0000o`00002=ooooo`007?oo
ool2o`0006cooooo3Ol000000ooooooo0000o`000002o`0000oooooo0ol000000ooooooo0000o`00
0003o`0000Cooooo0_l00004ooooo`Co00000_ooool4o`000003ooooool0003o000001;o0000Rooo
ool001cooooo00?o0000ooooooooool0K?ooool:o`0000Cooooo0_l000000ooooooo0000o`000005
ooooo`;o000000?oooooo`000?l000000oooool3o`0000;ooooo1?l00009ooooo`Go000000Cooooo
o`000?l0003o00000_oooolAo`0000;ooooo0_l0002;ooooo`007?ooool00ol0003oooooooooo`1/
ooooo`Wo00002?ooool2o`0000Gooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0
003o000000Ko00000_ooool2o`0000Gooooo0_l000000ooooooo0000o`000003o`0000?ooooo3ol0
00000ooooooo0000o`00002>ooooo`007?ooool00ol0003oooooooooo`1/ooooo`co00001_ooool2
o`000003ooooool0003o000000Go000000?oooooo`000?l000004Ol00006ooooo`?o00001?oooolB
o`0008kooooo000Looooo`03o`000?oooooooooo06gooooo2ol00006ooooob3o00001?ooool2o`00
00Gooooo4Ol0002?ooooo`007?ooool00ol0003oooooooooo`1^oooooc3o00000oooool3o`0000Go
oooo3ol0002Aooooo`007?ooool00ol0003oooooooooo`1`oooooboo00000_ooool3o`0000Gooooo
4_l0002>ooooo`007?ooool00ol0003oooooooooo`1aooooobko00002ooooolAo`0008kooooo000L
ooooo`03o`000?oooooooooo07?ooooo4?l000000ooooooo0000o`00000Ko`0000Wooooo2ol00002
ooooo`Co0000S_ooool001cooooo00?o0000ooooooooool0MOooool2o`00013ooooo6_l0000:oooo
o`ko0000T?ooool001cooooo00?o0000ooooooooool0R_oooolFo`0000cooooo2ol0002Booooo`00
7?ooool00ol0003oooooooooo`2;oooooaGo00003Oooool:o`0009;ooooo000Looooo`03o`000?oo
oooooooo08gooooo4_l0000Cooooo`?o0000U?ooool001cooooo00?o0000ooooooooool0S_ooool?
o`000:cooooo000Looooo`03o`000?oooooooooo09;ooooo2_l0002]ooooo`007?ooool00ol0003o
ooooooooo`2Dooooo`;o000000?oooooo`000?l00000/?ooool001cooooo0_l0003ooooood_ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool00006
ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<
c006ooooo`03o`000?oooooooooo0?ooooooB_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?oo
ooooB_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool0oooooom:ooooo`0000?oooooo`000?ooool0
0_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`000?oo
ooooB_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Oo<c<co0000
o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom:ooooo`0000?ooooooa0@4?ooool0
0_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003o
ooooooooo`3ooooood[ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj
^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0?ooooooB_ooool00006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?oo
ooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom:oooo
o`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo
00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o0000ooooooooool0oooo
oomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo
0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`004_ooool00omEEEGoIVIV
o`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Yooooo`04
oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05oooool2o`000009oa0@4?oooooooooo
ooooooo<c<co8B4Qo`000?lQ8B7oc<c<09Cooooo002Zooooo`05o`000?ooooooooooooooool00000
2Oooool6o`0000cooooo00?o0000ooooooooool00_ooool01OlQ8B7oV9RHoooooonHV9So8B4Q09Co
oooo002Zooooo`05o`000?ooooooooooooooool000006?ooool5o`0000?ooooo00Go0000oooooooo
ooooooooo`00002Dooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l00009oooo
o`04odA4A?oMgMgoooooo`0000Cooooo00Go<S8boiRHV?ooooooV9RHoc8b<P2Dooooo`00Z_ooool0
1Ol0003oQhN7oooooonYZJWo000001Sooooo00CogMgMoeEEEOoooooo00001?ooool01Oo<c<co0000
o`000?l0003oc<c<09Cooooo002Yooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool0
5oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?nj^[[ooooookZj^_l@4100U?ooool00<Sooooo
00?ok^k^odA4A?l000001?ooool01Ol0003o^[Zjoooooonj^[[o000009Cooooo0039ooooo`03ogMg
Mol0003ooooo00?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2Dooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -20 0 ]
[.5 1.0125 20 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(54) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.72045 .59705 Mdot
.67855 .60216 Mdot
.60891 .3005 Mdot
.32711 .56383 Mdot
.3116 .37166 Mdot
.59899 .29994 Mdot
.71907 .49415 Mdot
.7008 .47035 Mdot
.63452 .32582 Mdot
.35471 .50974 Mdot
.67287 .3909 Mdot
.40324 .70178 Mdot
.71244 .49141 Mdot
.3413 .5193 Mdot
.3656 .69695 Mdot
.50131 .7107 Mdot
.70952 .58535 Mdot
.30799 .37134 Mdot
.51681 .72925 Mdot
.63636 .33998 Mdot
.44782 .34252 Mdot
.3398 .5407 Mdot
.70183 .57418 Mdot
.34603 .51913 Mdot
.51935 .72723 Mdot
.62281 .68292 Mdot
.7224 .59463 Mdot
.51929 .7216 Mdot
.40931 .71268 Mdot
.69377 .48931 Mdot
.51368 .70857 Mdot
.35024 .62497 Mdot
.3862 .31413 Mdot
.59198 .66746 Mdot
.69257 .41349 Mdot
.6664 .3899 Mdot
.59843 .28412 Mdot
.66752 .37766 Mdot
.69284 .46576 Mdot
.69176 .40811 Mdot
.69021 .40997 Mdot
.62638 .67967 Mdot
.669 .39829 Mdot
.692 .51402 Mdot
.33652 .6551 Mdot
.62718 .64269 Mdot
.48872 .27048 Mdot
.31284 .66505 Mdot
.71304 .60384 Mdot
.50268 .2658 Mdot
.32895 .6185 Mdot
.72597 .48127 Mdot
.40977 .33112 Mdot
.65276 .6698 Mdot
.70501 .49108 Mdot
.52348 .72652 Mdot
.61439 .33281 Mdot
.31394 .62461 Mdot
.41849 .72213 Mdot
.60046 .65716 Mdot
.35323 .53075 Mdot
.27958 .3924 Mdot
.51005 .68892 Mdot
.61188 .3428 Mdot
.62224 .3077 Mdot
.67774 .36701 Mdot
.67277 .58129 Mdot
.67982 .37625 Mdot
.31846 .54176 Mdot
.49126 .28057 Mdot
.30617 .65863 Mdot
.67304 .39172 Mdot
.6179 .66525 Mdot
.32614 .54829 Mdot
.70542 .61452 Mdot
.68296 .38425 Mdot
.32002 .37269 Mdot
.62012 .67724 Mdot
.52651 .26819 Mdot
.33651 .4904 Mdot
.34384 .54556 Mdot
.72501 .44623 Mdot
.43494 .7308 Mdot
.63946 .65412 Mdot
.3435 .64171 Mdot
.74018 .4742 Mdot
.34368 .57171 Mdot
.50853 .71037 Mdot
.52519 .71946 Mdot
.3962 .70269 Mdot
.56255 .27637 Mdot
.68505 .57818 Mdot
.33151 .53727 Mdot
.31964 .52865 Mdot
.32668 .62581 Mdot
.34504 .63689 Mdot
.52818 .71785 Mdot
.37876 .34288 Mdot
.68555 .39907 Mdot
.41036 .31859 Mdot
.68081 .37891 Mdot
.41769 .333 Mdot
.31938 .56783 Mdot
.5919 .31268 Mdot
.61612 .69508 Mdot
.37783 .33532 Mdot
.68587 .38995 Mdot
.32961 .53609 Mdot
.66558 .38439 Mdot
.68709 .58041 Mdot
.52157 .70651 Mdot
.31776 .40555 Mdot
.34137 .38417 Mdot
.72142 .57246 Mdot
.31007 .54173 Mdot
.35356 .56459 Mdot
.3465 .53473 Mdot
.67527 .57919 Mdot
.63293 .32744 Mdot
.54467 .28098 Mdot
.68458 .59573 Mdot
.6865 .4035 Mdot
.7119 .5912 Mdot
.41054 .30421 Mdot
.62816 .31545 Mdot
.39451 .3181 Mdot
.39181 .35466 Mdot
.33731 .5991 Mdot
.34479 .63241 Mdot
.43393 .33432 Mdot
.58887 .31133 Mdot
.68379 .59814 Mdot
.70853 .48344 Mdot
.32197 .52167 Mdot
.63484 .65374 Mdot
.70549 .49429 Mdot
.32509 .39115 Mdot
.33172 .40639 Mdot
.62291 .66163 Mdot
.31112 .55593 Mdot
.66674 .37432 Mdot
.70424 .45618 Mdot
.3213 .61716 Mdot
.63208 .65059 Mdot
.31549 .3761 Mdot
.70254 .4552 Mdot
.36706 .31848 Mdot
.52977 .7061 Mdot
.32003 .69505 Mdot
.72359 .44847 Mdot
.32461 .62085 Mdot
.45674 .32879 Mdot
.28394 .40355 Mdot
.70153 .48931 Mdot
.33354 .56957 Mdot
.7026 .59975 Mdot
.62675 .65457 Mdot
.44059 .71083 Mdot
.37854 .32788 Mdot
.32151 .60882 Mdot
.42295 .33329 Mdot
.38676 .35198 Mdot
.33759 .5218 Mdot
.61301 .64728 Mdot
.59591 .69197 Mdot
.30614 .64944 Mdot
.61289 .28967 Mdot
.30943 .37023 Mdot
.6727 .39887 Mdot
.33764 .63797 Mdot
.32504 .62968 Mdot
.42793 .70345 Mdot
.70789 .457 Mdot
.70053 .41568 Mdot
.52209 .27784 Mdot
.68336 .37121 Mdot
.69479 .42281 Mdot
.59766 .33023 Mdot
.41461 .70645 Mdot
.31392 .41106 Mdot
.39948 .34443 Mdot
.30699 .6454 Mdot
.35234 .6431 Mdot
.39663 .70072 Mdot
.44467 .34386 Mdot
.45751 .32081 Mdot
.65944 .61931 Mdot
.67785 .41233 Mdot
.34227 .56209 Mdot
.54299 .71825 Mdot
.33888 .61828 Mdot
.69969 .43221 Mdot
.70852 .47717 Mdot
.63006 .35485 Mdot
.63553 .34491 Mdot
.51087 .27104 Mdot
.46138 .7206 Mdot
.43495 .70074 Mdot
.33877 .55604 Mdot
.40307 .32394 Mdot
.51341 .68893 Mdot
.28247 .40074 Mdot
.70733 .5911 Mdot
.72321 .44341 Mdot
.30421 .67212 Mdot
.50599 .7297 Mdot
.62013 .28832 Mdot
.55964 .27207 Mdot
.40595 .3525 Mdot
.29434 .40082 Mdot
.31127 .63483 Mdot
.7181 .57399 Mdot
.32547 .61841 Mdot
.39036 .31286 Mdot
.34383 .38519 Mdot
.69126 .58679 Mdot
.31401 .67111 Mdot
.71181 .49587 Mdot
.5692 .29417 Mdot
.3436 .57205 Mdot
.32627 .53952 Mdot
.62203 .67511 Mdot
.31557 .54109 Mdot
.53303 .72623 Mdot
.51841 .71114 Mdot
.50995 .27459 Mdot
.69023 .38355 Mdot
.69096 .4867 Mdot
.48735 .27089 Mdot
.62784 .66614 Mdot
.73351 .59202 Mdot
.60145 .31531 Mdot
.43927 .35251 Mdot
.67012 .38624 Mdot
.30832 .38836 Mdot
.59545 .31091 Mdot
.30457 .37345 Mdot
.41825 .72448 Mdot
.58178 .30808 Mdot
.32169 .39937 Mdot
.37602 .69595 Mdot
.39281 .35245 Mdot
.33736 .40765 Mdot
.72024 .496 Mdot
.67793 .61273 Mdot
.30757 .63792 Mdot
.40752 .33674 Mdot
.39889 .31174 Mdot
.41871 .70847 Mdot
.40348 .36038 Mdot
.38228 .33366 Mdot
.42066 .70673 Mdot
.29433 .37214 Mdot
.70846 .42942 Mdot
.51504 .70811 Mdot
.7103 .5887 Mdot
.31706 .55139 Mdot
.69742 .39308 Mdot
.70438 .49366 Mdot
.35851 .55053 Mdot
.73292 .46183 Mdot
.72156 .49721 Mdot
.34291 .52416 Mdot
.69205 .47513 Mdot
.63772 .65463 Mdot
.30345 .66955 Mdot
.61536 .66244 Mdot
.34272 .52023 Mdot
.69168 .47141 Mdot
.49279 .26803 Mdot
.62843 .6755 Mdot
.33356 .54116 Mdot
.33042 .56018 Mdot
.4042 .32653 Mdot
.5215 .70845 Mdot
.72933 .51011 Mdot
.40438 .70227 Mdot
.59637 .33563 Mdot
.45086 .72052 Mdot
.28661 .41315 Mdot
.36663 .31767 Mdot
.63077 .65066 Mdot
.40052 .36131 Mdot
.59995 .30742 Mdot
.3186 .62905 Mdot
.31404 .67795 Mdot
.33889 .65014 Mdot
.38447 .33498 Mdot
.43705 .7312 Mdot
.7213 .50738 Mdot
.53845 .71247 Mdot
.43131 .33828 Mdot
.61559 .32786 Mdot
.41671 .32678 Mdot
.34498 .63941 Mdot
.69632 .57411 Mdot
.50095 .72261 Mdot
.58688 .32257 Mdot
.70148 .57757 Mdot
.31095 .66098 Mdot
.68148 .3766 Mdot
.27341 .40449 Mdot
.71813 .51164 Mdot
.50949 .72183 Mdot
.44855 .71818 Mdot
.49365 .27995 Mdot
.63287 .66864 Mdot
.6992 .47982 Mdot
.61684 .66419 Mdot
.32442 .60932 Mdot
.32397 .59875 Mdot
.62743 .64951 Mdot
.31882 .41874 Mdot
.53362 .27596 Mdot
.67322 .38633 Mdot
.39563 .32182 Mdot
.4976 .28764 Mdot
.71584 .59899 Mdot
.59091 .30686 Mdot
.31035 .56371 Mdot
.56824 .29631 Mdot
.5011 .72427 Mdot
.49329 .28531 Mdot
.43454 .70441 Mdot
.34284 .65221 Mdot
.61423 .34684 Mdot
.37593 .33323 Mdot
.31501 .62523 Mdot
.63622 .65587 Mdot
.35214 .62639 Mdot
.35964 .51969 Mdot
.45818 .71812 Mdot
.61449 .32846 Mdot
.31175 .56125 Mdot
.51426 .7153 Mdot
.51285 .72349 Mdot
.70325 .59278 Mdot
.39487 .33097 Mdot
.33001 .3903 Mdot
.33528 .40719 Mdot
.35794 .3399 Mdot
.39079 .70002 Mdot
.32039 .58592 Mdot
.62967 .661 Mdot
.50553 .26674 Mdot
.68058 .6182 Mdot
.38898 .3133 Mdot
.70109 .46947 Mdot
.70046 .41906 Mdot
.34047 .57304 Mdot
.26349 .3923 Mdot
.50073 .73084 Mdot
.70653 .60936 Mdot
.61821 .6685 Mdot
.69895 .47745 Mdot
.44355 .73734 Mdot
.34573 .49849 Mdot
.35715 .55284 Mdot
.70342 .46315 Mdot
.39345 .31397 Mdot
.42283 .72183 Mdot
.33092 .6928 Mdot
.68147 .4741 Mdot
.33179 .64891 Mdot
.59651 .66931 Mdot
.33554 .66032 Mdot
.33618 .59847 Mdot
.32387 .65523 Mdot
.6341 .65971 Mdot
.50733 .74084 Mdot
.32455 .68924 Mdot
.59894 .2749 Mdot
.30494 .67539 Mdot
.32102 .41593 Mdot
.32862 .54325 Mdot
.30945 .63982 Mdot
.3174 .37885 Mdot
.72133 .5746 Mdot
.3261 .63212 Mdot
.70841 .43651 Mdot
.33556 .53843 Mdot
.67207 .39865 Mdot
.43546 .72076 Mdot
.3411 .60717 Mdot
.51703 .71611 Mdot
.70004 .57345 Mdot
.69505 .46215 Mdot
.68054 .408 Mdot
.42297 .34677 Mdot
.70392 .49333 Mdot
.33997 .64193 Mdot
.43599 .72298 Mdot
.72095 .57158 Mdot
.3912 .35122 Mdot
.68292 .57931 Mdot
.25634 .40884 Mdot
.72064 .48801 Mdot
.41472 .33297 Mdot
.46141 .7288 Mdot
.7178 .4744 Mdot
.70605 .43344 Mdot
.52116 .70612 Mdot
.39431 .31381 Mdot
.72095 .59255 Mdot
.49333 .28281 Mdot
.3843 .32356 Mdot
.70293 .48879 Mdot
.3359 .6559 Mdot
.5312 .71281 Mdot
.69641 .47884 Mdot
.59958 .67627 Mdot
.529 .70317 Mdot
.33525 .53584 Mdot
.62716 .68255 Mdot
.6771 .58273 Mdot
.31287 .61834 Mdot
.35032 .55798 Mdot
.61044 .3118 Mdot
.38493 .33048 Mdot
.38651 .33136 Mdot
.3867 .3542 Mdot
.57757 .3131 Mdot
.53294 .27959 Mdot
.69269 .39032 Mdot
.34114 .60388 Mdot
.69182 .37969 Mdot
.41063 .33708 Mdot
.60982 .30977 Mdot
.33766 .65754 Mdot
.43313 .7388 Mdot
.69544 .45354 Mdot
.53537 .28624 Mdot
.32917 .57537 Mdot
.70653 .59962 Mdot
.72104 .4721 Mdot
.41898 .69669 Mdot
.50295 .27258 Mdot
.27728 .39587 Mdot
.31565 .56892 Mdot
.71363 .46566 Mdot
.60064 .68642 Mdot
.71288 .4654 Mdot
.3091 .64651 Mdot
.32893 .63709 Mdot
.68571 .61231 Mdot
.31935 .41669 Mdot
.40741 .70304 Mdot
.34813 .52162 Mdot
.51058 .26518 Mdot
.6835 .61912 Mdot
.33316 .41394 Mdot
.41084 .71826 Mdot
.40095 .35723 Mdot
.29113 .37135 Mdot
.33683 .55398 Mdot
.4244 .70494 Mdot
.42917 .32158 Mdot
.69738 .49145 Mdot
.32626 .41389 Mdot
.61412 .28336 Mdot
.69768 .58139 Mdot
.69253 .38725 Mdot
.40242 .36351 Mdot
.67424 .38991 Mdot
.38423 .69817 Mdot
.41484 .34206 Mdot
.68724 .45158 Mdot
.2884 .45874 Mdot
.38453 .34225 Mdot
.6185 .33303 Mdot
.32168 .61317 Mdot
.41543 .70377 Mdot
.33475 .5351 Mdot
.32997 .39242 Mdot
.67682 .59687 Mdot
.69072 .42173 Mdot
.68836 .46849 Mdot
.3308 .52452 Mdot
.63047 .65028 Mdot
.66261 .59583 Mdot
.41159 .32314 Mdot
.3099 .40028 Mdot
.31023 .39071 Mdot
.32616 .52898 Mdot
.43158 .73447 Mdot
.63207 .66237 Mdot
.33306 .54105 Mdot
.3259 .52839 Mdot
.51414 .2827 Mdot
.63 .68329 Mdot
.5842 .31267 Mdot
.51122 .73153 Mdot
.32296 .58201 Mdot
.68544 .37783 Mdot
.71126 .50173 Mdot
.39134 .32972 Mdot
.69086 .48672 Mdot
.52244 .281 Mdot
.38634 .3319 Mdot
.33353 .54193 Mdot
.72592 .58511 Mdot
.33223 .54016 Mdot
.33444 .53844 Mdot
.32795 .65667 Mdot
.32106 .58664 Mdot
.57163 .27129 Mdot
.30892 .40551 Mdot
.41535 .72231 Mdot
.59613 .33171 Mdot
.62437 .29425 Mdot
.32833 .62412 Mdot
.33373 .54954 Mdot
.34451 .53033 Mdot
.61537 .68517 Mdot
.53564 .71054 Mdot
.71387 .47382 Mdot
.68537 .61253 Mdot
.34544 .56892 Mdot
.48543 .27362 Mdot
.32481 .63387 Mdot
.62361 .65104 Mdot
.6973 .40674 Mdot
.74128 .49814 Mdot
.41057 .36013 Mdot
.40702 .3132 Mdot
.38322 .33351 Mdot
.38398 .3534 Mdot
.66767 .39412 Mdot
.60993 .3086 Mdot
.28576 .41557 Mdot
.32291 .59608 Mdot
.34671 .55971 Mdot
.33216 .63479 Mdot
.51065 .28713 Mdot
.39799 .30457 Mdot
.32811 .6031 Mdot
.52673 .69457 Mdot
.57469 .2909 Mdot
.3802 .3452 Mdot
.62191 .63417 Mdot
.69301 .57893 Mdot
.50162 .27584 Mdot
.66788 .37763 Mdot
.32435 .40005 Mdot
.4704 .29651 Mdot
.68025 .58491 Mdot
.5312 .68528 Mdot
.57975 .28963 Mdot
.43334 .72329 Mdot
.4818 .71015 Mdot
.58965 .30076 Mdot
.54003 .71252 Mdot
.67399 .57935 Mdot
.39166 .35301 Mdot
.44313 .72378 Mdot
.42253 .71005 Mdot
.63671 .35576 Mdot
.32518 .55678 Mdot
.55711 .27753 Mdot
.61716 .32975 Mdot
.39357 .33675 Mdot
.61426 .32807 Mdot
.71909 .5081 Mdot
.59699 .3226 Mdot
.60285 .6814 Mdot
.32301 .52878 Mdot
.65005 .67439 Mdot
.35905 .69999 Mdot
.35404 .5617 Mdot
.72692 .49048 Mdot
.69632 .39297 Mdot
.35304 .54378 Mdot
.31844 .37366 Mdot
.61882 .32693 Mdot
.51851 .27256 Mdot
.53258 .71813 Mdot
.50004 .28632 Mdot
.69891 .57299 Mdot
.68714 .38267 Mdot
.69629 .3924 Mdot
.38372 .32759 Mdot
.63452 .65117 Mdot
.66718 .39825 Mdot
.68741 .40354 Mdot
.27359 .4055 Mdot
.31028 .62495 Mdot
.5918 .68244 Mdot
.42304 .72153 Mdot
.30402 .37214 Mdot
.33735 .5385 Mdot
.58683 .31656 Mdot
.51542 .27395 Mdot
.36281 .69609 Mdot
.60324 .31513 Mdot
.39251 .32625 Mdot
.61007 .69249 Mdot
.52304 .72776 Mdot
.67972 .5951 Mdot
.31773 .53156 Mdot
.69218 .38491 Mdot
.69597 .57657 Mdot
.44197 .34898 Mdot
.35596 .52971 Mdot
.62095 .64491 Mdot
.40708 .71674 Mdot
.33643 .53603 Mdot
.6274 .31872 Mdot
.31702 .37789 Mdot
.42641 .36097 Mdot
.58207 .27414 Mdot
.28698 .39231 Mdot
.70331 .62275 Mdot
.62901 .31989 Mdot
.29805 .39047 Mdot
.35868 .33433 Mdot
.39426 .3608 Mdot
.30234 .40244 Mdot
.34288 .64104 Mdot
.70085 .49088 Mdot
.67816 .60757 Mdot
.32135 .64586 Mdot
.33093 .4855 Mdot
.64256 .68544 Mdot
.40666 .32489 Mdot
.3379 .53278 Mdot
.31486 .61862 Mdot
.62408 .65272 Mdot
.71896 .43841 Mdot
.61467 .34063 Mdot
.40223 .31757 Mdot
.68095 .59075 Mdot
.72553 .44665 Mdot
.62456 .31404 Mdot
.30589 .38451 Mdot
.70452 .50276 Mdot
.72683 .58726 Mdot
.40748 .32996 Mdot
.71964 .49522 Mdot
.57635 .27467 Mdot
.32838 .61964 Mdot
.52711 .69738 Mdot
.58594 .28828 Mdot
.32785 .61905 Mdot
.50207 .72937 Mdot
.50912 .27091 Mdot
.70309 .42187 Mdot
.68601 .5807 Mdot
.69724 .46618 Mdot
.31222 .39601 Mdot
.6159 .6666 Mdot
.68286 .5799 Mdot
.71123 .50216 Mdot
.63055 .69474 Mdot
.44222 .73063 Mdot
.6833 .38561 Mdot
.4263 .72918 Mdot
.32005 .62104 Mdot
.40574 .33178 Mdot
.31243 .40924 Mdot
.68902 .38278 Mdot
.62364 .68256 Mdot
.7014 .52658 Mdot
.34499 .62638 Mdot
.53576 .70693 Mdot
.32517 .40593 Mdot
.6595 .6231 Mdot
.70371 .4182 Mdot
.71555 .47626 Mdot
.50985 .26542 Mdot
.32401 .37591 Mdot
.34372 .64708 Mdot
.50802 .29186 Mdot
.33431 .63966 Mdot
.72199 .47041 Mdot
.50259 .73196 Mdot
.69733 .5864 Mdot
.67877 .38406 Mdot
.49954 .72514 Mdot
.40428 .70588 Mdot
.35052 .55318 Mdot
.51034 .27563 Mdot
.67349 .57521 Mdot
.38546 .30372 Mdot
.35048 .56997 Mdot
.35518 .52425 Mdot
.40118 .31042 Mdot
.34022 .60335 Mdot
.70416 .42641 Mdot
.38092 .32327 Mdot
.57672 .29228 Mdot
.38738 .34918 Mdot
.39619 .32452 Mdot
.71705 .57978 Mdot
.50595 .26884 Mdot
.40479 .31155 Mdot
.36058 .53867 Mdot
.33192 .52928 Mdot
.69402 .46108 Mdot
.44004 .72868 Mdot
.42221 .7139 Mdot
.59951 .33801 Mdot
.27254 .40675 Mdot
.31463 .63803 Mdot
.63859 .65383 Mdot
.33349 .40339 Mdot
.42457 .32869 Mdot
.70337 .58071 Mdot
.34644 .63789 Mdot
.51423 .28322 Mdot
.38972 .34802 Mdot
.4188 .31535 Mdot
.32326 .4031 Mdot
.70791 .45629 Mdot
.61157 .65537 Mdot
.61782 .33062 Mdot
.5154 .70265 Mdot
.25897 .40033 Mdot
.50376 .27914 Mdot
.40445 .33201 Mdot
.41341 .34713 Mdot
.63061 .65186 Mdot
.60206 .67768 Mdot
.41214 .36367 Mdot
.59631 .33288 Mdot
.68258 .41908 Mdot
.67816 .39044 Mdot
.4422 .71272 Mdot
.70569 .50628 Mdot
.68672 .57986 Mdot
.33614 .60387 Mdot
.30732 .38965 Mdot
.71916 .47771 Mdot
.38208 .32964 Mdot
.68405 .58468 Mdot
.6064 .67271 Mdot
.34825 .5199 Mdot
.33932 .54338 Mdot
.48902 .27006 Mdot
.35156 .63584 Mdot
.69837 .4518 Mdot
.32622 .38752 Mdot
.61566 .31152 Mdot
.53188 .71637 Mdot
.70386 .59881 Mdot
.46631 .30835 Mdot
.39985 .70731 Mdot
.60564 .33566 Mdot
.6799 .60386 Mdot
.33521 .39541 Mdot
.30757 .40455 Mdot
.33095 .59479 Mdot
.4587 .32559 Mdot
.72397 .49165 Mdot
.6339 .65501 Mdot
.69635 .62348 Mdot
.41158 .71334 Mdot
.33435 .54744 Mdot
.5359 .72012 Mdot
.67987 .41277 Mdot
.34123 .63949 Mdot
.32803 .39982 Mdot
.67439 .57654 Mdot
.34061 .6545 Mdot
.33809 .38585 Mdot
.3863 .30334 Mdot
.40928 .34919 Mdot
.62036 .34748 Mdot
.33453 .38723 Mdot
.3318 .38208 Mdot
.34198 .39096 Mdot
.70035 .41973 Mdot
.4136 .69653 Mdot
.25815 .40606 Mdot
.3261 .55714 Mdot
.32209 .61455 Mdot
.53148 .69776 Mdot
.68649 .37366 Mdot
.4939 .27804 Mdot
.31038 .63953 Mdot
.32996 .55942 Mdot
.66872 .58494 Mdot
.50405 .70771 Mdot
.30974 .65604 Mdot
.70424 .58595 Mdot
.58733 .67908 Mdot
.63054 .34641 Mdot
.7272 .45552 Mdot
.49096 .28978 Mdot
.41327 .72385 Mdot
.41463 .72763 Mdot
.69625 .5652 Mdot
.70294 .49761 Mdot
.41704 .72805 Mdot
.71001 .45762 Mdot
.68234 .57069 Mdot
.53093 .6954 Mdot
.60024 .678 Mdot
.27939 .39093 Mdot
.30964 .64958 Mdot
.71485 .50311 Mdot
.30976 .64068 Mdot
.71055 .5041 Mdot
.33516 .48865 Mdot
.42278 .73303 Mdot
.33491 .56771 Mdot
.34778 .65014 Mdot
.44919 .33728 Mdot
.33724 .54701 Mdot
.52463 .26783 Mdot
.69843 .60143 Mdot
.26991 .38373 Mdot
.55061 .7015 Mdot
.31758 .62134 Mdot
.34282 .53207 Mdot
.64017 .68801 Mdot
.34797 .53588 Mdot
.49729 .29042 Mdot
.40681 .71812 Mdot
.30762 .65175 Mdot
.70636 .47641 Mdot
.67788 .399 Mdot
.72151 .57187 Mdot
.4154 .34323 Mdot
.65994 .62019 Mdot
.34042 .52476 Mdot
.62404 .33902 Mdot
.35426 .36923 Mdot
.32837 .38169 Mdot
.68 .60701 Mdot
.29801 .46483 Mdot
.66908 .39789 Mdot
.62088 .29473 Mdot
.5164 .70633 Mdot
.57918 .30339 Mdot
.60797 .342 Mdot
.68294 .61967 Mdot
.31203 .4085 Mdot
.31717 .63969 Mdot
.59745 .66047 Mdot
.57575 .68969 Mdot
.4111 .71152 Mdot
.63114 .33713 Mdot
.42795 .31973 Mdot
.53038 .74202 Mdot
.29007 .38117 Mdot
.29173 .39233 Mdot
.71147 .49777 Mdot
.62357 .34136 Mdot
.40039 .319 Mdot
.30065 .38956 Mdot
.63234 .34699 Mdot
.39595 .36265 Mdot
.51875 .26845 Mdot
.63119 .65978 Mdot
.31562 .57844 Mdot
.62018 .64266 Mdot
.6882 .47844 Mdot
.50207 .2675 Mdot
.62728 .6699 Mdot
.63861 .64913 Mdot
.40001 .32476 Mdot
.59478 .27892 Mdot
.62988 .69211 Mdot
.30995 .62855 Mdot
.40055 .35375 Mdot
.34633 .51642 Mdot
.32396 .37343 Mdot
.33441 .5288 Mdot
.49036 .27147 Mdot
.71278 .46962 Mdot
.61174 .3172 Mdot
.7136 .49885 Mdot
.34424 .60987 Mdot
.35781 .53 Mdot
.33059 .54522 Mdot
.43459 .71995 Mdot
.71219 .57159 Mdot
.59468 .66751 Mdot
.61047 .33478 Mdot
.61363 .32144 Mdot
.5488 .69973 Mdot
.71051 .59828 Mdot
.37093 .31324 Mdot
.42168 .72912 Mdot
.34848 .53871 Mdot
.69892 .60004 Mdot
.5356 .69875 Mdot
.66835 .40266 Mdot
.43996 .72128 Mdot
.70903 .57282 Mdot
.53199 .28103 Mdot
.32585 .52746 Mdot
.41102 .31726 Mdot
.43439 .33161 Mdot
.39051 .69705 Mdot
.30661 .37137 Mdot
.69331 .58406 Mdot
.41901 .32458 Mdot
.69759 .60488 Mdot
.57071 .30209 Mdot
.66434 .39121 Mdot
.70069 .58957 Mdot
.34683 .53175 Mdot
.51039 .29274 Mdot
.70328 .49542 Mdot
.32766 .65918 Mdot
.68155 .38773 Mdot
.62076 .66941 Mdot
.68782 .60017 Mdot
.39615 .36276 Mdot
.53965 .71148 Mdot
.72293 .48591 Mdot
.34382 .5638 Mdot
.59969 .68006 Mdot
.5001 .72156 Mdot
.30178 .37251 Mdot
.32445 .63798 Mdot
.31846 .60714 Mdot
.54257 .28197 Mdot
.33726 .62146 Mdot
.69619 .42239 Mdot
.6683 .39154 Mdot
.69037 .42253 Mdot
.72048 .58054 Mdot
.42939 .35739 Mdot
.60509 .66471 Mdot
.39047 .32726 Mdot
.60079 .282 Mdot
.32479 .65767 Mdot
.38163 .35121 Mdot
.69113 .38707 Mdot
.30117 .40647 Mdot
.39678 .70128 Mdot
.59351 .28778 Mdot
.41044 .35412 Mdot
.71895 .48287 Mdot
.61004 .69045 Mdot
.70047 .58275 Mdot
.52661 .27379 Mdot
.33705 .65883 Mdot
.33759 .54289 Mdot
.69396 .39726 Mdot
.46134 .32059 Mdot
.28891 .39116 Mdot
.37608 .33323 Mdot
.69149 .39277 Mdot
.43966 .72463 Mdot
.61954 .67415 Mdot
.3083 .6459 Mdot
.43608 .72648 Mdot
.69901 .41972 Mdot
.57855 .68467 Mdot
.28479 .39523 Mdot
.3215 .57563 Mdot
.69182 .58578 Mdot
.7077 .48446 Mdot
.36115 .32651 Mdot
.52242 .73135 Mdot
.34035 .56013 Mdot
.30636 .66959 Mdot
.42934 .70799 Mdot
.51002 .71036 Mdot
.40827 .36106 Mdot
.30561 .66186 Mdot
.54955 .70126 Mdot
.50789 .70683 Mdot
.32907 .634 Mdot
.33068 .63116 Mdot
.69545 .59968 Mdot
.45628 .71648 Mdot
.58836 .31466 Mdot
.54077 .71502 Mdot
.46569 .30955 Mdot
.51482 .71004 Mdot
.44933 .7176 Mdot
.58136 .67557 Mdot
.38687 .69712 Mdot
.68212 .56654 Mdot
.71676 .59559 Mdot
.68873 .48068 Mdot
.50238 .72456 Mdot
.6058 .33617 Mdot
.42527 .31995 Mdot
.49761 .27935 Mdot
.69461 .60161 Mdot
.63334 .34225 Mdot
.67751 .36713 Mdot
.58616 .28802 Mdot
.57514 .2953 Mdot
.71396 .46887 Mdot
.67573 .6082 Mdot
.40174 .70973 Mdot
.71706 .47065 Mdot
.41236 .31078 Mdot
.30538 .38623 Mdot
.57869 .69061 Mdot
.37747 .32562 Mdot
.32977 .57689 Mdot
.68316 .46772 Mdot
.59584 .28378 Mdot
.3061 .6726 Mdot
.70594 .61096 Mdot
.33768 .40273 Mdot
.69765 .59098 Mdot
.40347 .36519 Mdot
.28141 .40191 Mdot
.34523 .64459 Mdot
.465 .3104 Mdot
.70194 .42623 Mdot
.31895 .63743 Mdot
.5863 .67189 Mdot
.49784 .2786 Mdot
.72221 .50755 Mdot
.70543 .43549 Mdot
.40804 .31716 Mdot
.70909 .57586 Mdot
.60084 .67044 Mdot
.38841 .33187 Mdot
.70882 .48284 Mdot
.65146 .66885 Mdot
.32563 .60173 Mdot
.70244 .5057 Mdot
.31717 .64229 Mdot
.31102 .55465 Mdot
.32668 .41869 Mdot
.3876 .35411 Mdot
.50929 .70329 Mdot
.62091 .30491 Mdot
.54617 .69754 Mdot
.31482 .54959 Mdot
.35328 .637 Mdot
.34391 .55263 Mdot
.30841 .67433 Mdot
.52244 .28356 Mdot
.71288 .5654 Mdot
.40282 .347 Mdot
.40492 .32895 Mdot
.49758 .71926 Mdot
.4749 .28674 Mdot
.29674 .39882 Mdot
.52658 .27146 Mdot
.35435 .52529 Mdot
.34456 .54373 Mdot
.61166 .6767 Mdot
.30903 .55116 Mdot
.38825 .35163 Mdot
.34592 .55283 Mdot
.39134 .70353 Mdot
.70308 .47827 Mdot
.31583 .61143 Mdot
.32706 .52739 Mdot
.66646 .39734 Mdot
.70636 .47921 Mdot
.51083 .27931 Mdot
.39172 .36066 Mdot
.61654 .34784 Mdot
.28873 .38557 Mdot
.30881 .66811 Mdot
.33859 .6063 Mdot
.44673 .72348 Mdot
.2847 .38579 Mdot
.51574 .71335 Mdot
.31453 .52709 Mdot
.31949 .5415 Mdot
.29233 .39348 Mdot
.69642 .49165 Mdot
.70043 .59623 Mdot
.312 .56024 Mdot
.40318 .32856 Mdot
.5071 .70861 Mdot
.33539 .38117 Mdot
.69602 .60544 Mdot
.61214 .64736 Mdot
.68045 .60169 Mdot
.71605 .48106 Mdot
.50366 .27148 Mdot
.281 .40222 Mdot
.69803 .59016 Mdot
.62934 .31462 Mdot
.68597 .38025 Mdot
.4388 .70803 Mdot
.68895 .47073 Mdot
.68247 .61952 Mdot
.71553 .58066 Mdot
.71433 .60879 Mdot
.53015 .72338 Mdot
.30867 .67551 Mdot
.39207 .32447 Mdot
.69242 .39286 Mdot
.61743 .30019 Mdot
.34615 .62515 Mdot
.60047 .65409 Mdot
.31246 .6879 Mdot
.3465 .64447 Mdot
.33431 .52793 Mdot
.32451 .54586 Mdot
.41616 .35712 Mdot
.33465 .5713 Mdot
.32544 .55529 Mdot
.69928 .45052 Mdot
.50649 .27924 Mdot
.35862 .53049 Mdot
.40895 .34843 Mdot
.26313 .39381 Mdot
.33729 .40465 Mdot
.31928 .57653 Mdot
.50733 .69092 Mdot
.70403 .59358 Mdot
.59116 .32698 Mdot
.62691 .3448 Mdot
.32922 .3947 Mdot
.70075 .46874 Mdot
.67544 .59156 Mdot
.53534 .2849 Mdot
.28204 .40541 Mdot
.32407 .65174 Mdot
.43387 .71859 Mdot
.38669 .69754 Mdot
.42005 .70345 Mdot
.32621 .65666 Mdot
.38012 .33659 Mdot
.58929 .32671 Mdot
.42971 .70152 Mdot
.62682 .64369 Mdot
.327 .37733 Mdot
.31119 .38233 Mdot
.61426 .69402 Mdot
.31528 .54829 Mdot
.71765 .50214 Mdot
.43084 .7338 Mdot
.72959 .50998 Mdot
.66308 .59759 Mdot
.25711 .40836 Mdot
.32505 .63335 Mdot
.32466 .62862 Mdot
.34049 .57252 Mdot
.61624 .69501 Mdot
.596 .68221 Mdot
.62249 .68253 Mdot
.70178 .47749 Mdot
.3206 .62628 Mdot
.68629 .40998 Mdot
.38939 .35277 Mdot
.69543 .57814 Mdot
.46005 .71292 Mdot
.61307 .32072 Mdot
.51291 .70196 Mdot
.31476 .41298 Mdot
.41615 .71438 Mdot
.4096 .34186 Mdot
.32222 .60043 Mdot
.60878 .3082 Mdot
.62274 .67337 Mdot
.52217 .69802 Mdot
.57735 .27151 Mdot
.30656 .66287 Mdot
.43292 .317 Mdot
.37766 .34518 Mdot
.27941 .39265 Mdot
.32184 .63074 Mdot
.32337 .4132 Mdot
.72214 .48521 Mdot
.35891 .53669 Mdot
.30689 .64913 Mdot
.34045 .5348 Mdot
.34089 .63625 Mdot
.70156 .48494 Mdot
.50721 .72573 Mdot
.41015 .30679 Mdot
.38718 .35782 Mdot
.5131 .71006 Mdot
.30652 .41006 Mdot
.67883 .39196 Mdot
.50919 .28076 Mdot
.38752 .31605 Mdot
.27522 .3956 Mdot
.31726 .6365 Mdot
.35121 .53865 Mdot
.39423 .35899 Mdot
.34324 .64083 Mdot
.52318 .72406 Mdot
.5826 .29708 Mdot
.50271 .71839 Mdot
.33842 .3936 Mdot
.3194 .41189 Mdot
.70023 .48903 Mdot
.69926 .58889 Mdot
.32515 .39215 Mdot
.61164 .30548 Mdot
.3278 .59678 Mdot
.32638 .63546 Mdot
.60208 .68033 Mdot
.35223 .64202 Mdot
.33857 .39265 Mdot
.34384 .64555 Mdot
.63459 .6774 Mdot
.62938 .69436 Mdot
.33957 .56009 Mdot
.52443 .71833 Mdot
.71883 .58406 Mdot
.30295 .38758 Mdot
.70158 .46431 Mdot
.34777 .69763 Mdot
.70889 .45776 Mdot
.6235 .68312 Mdot
.41445 .32091 Mdot
.67896 .61226 Mdot
.4143 .31973 Mdot
.57252 .68074 Mdot
.32426 .52958 Mdot
.60182 .68377 Mdot
.41798 .30706 Mdot
.61076 .33624 Mdot
.58298 .27812 Mdot
.39132 .34827 Mdot
.69435 .58142 Mdot
.39244 .33075 Mdot
.31918 .39511 Mdot
.70174 .39777 Mdot
.71763 .59664 Mdot
.57514 .29234 Mdot
.59567 .28438 Mdot
.69515 .39885 Mdot
.33652 .53112 Mdot
.30879 .63843 Mdot
.58702 .29051 Mdot
.72874 .51127 Mdot
.69433 .56824 Mdot
.33638 .54344 Mdot
.38303 .32001 Mdot
.58586 .30865 Mdot
.66515 .36037 Mdot
.61237 .672 Mdot
.52429 .69631 Mdot
.35297 .63554 Mdot
.67009 .39628 Mdot
.31305 .61668 Mdot
.52718 .71924 Mdot
.29988 .38216 Mdot
.32779 .5856 Mdot
.3259 .6079 Mdot
.67364 .39874 Mdot
.4032 .31333 Mdot
.41757 .70295 Mdot
.5641 .27595 Mdot
.30506 .64485 Mdot
.27344 .4478 Mdot
.39311 .35825 Mdot
.32465 .64866 Mdot
.394 .30369 Mdot
.68066 .59583 Mdot
.34103 .53915 Mdot
.68547 .37858 Mdot
.60351 .3331 Mdot
.33703 .65862 Mdot
.44253 .34967 Mdot
.678 .38185 Mdot
.41087 .34073 Mdot
.28759 .39274 Mdot
.52793 .70214 Mdot
.34997 .62205 Mdot
.51123 .28716 Mdot
.30522 .40148 Mdot
.34034 .52933 Mdot
.61727 .31533 Mdot
.67587 .39509 Mdot
.39845 .34848 Mdot
.3157 .62983 Mdot
.68496 .39959 Mdot
.70553 .4702 Mdot
.31943 .41445 Mdot
.73461 .58312 Mdot
.32646 .51956 Mdot
.34008 .51922 Mdot
.71906 .61606 Mdot
.60372 .67325 Mdot
.31057 .65128 Mdot
.36057 .52787 Mdot
.71958 .4971 Mdot
.32112 .69224 Mdot
.31911 .60453 Mdot
.42099 .30855 Mdot
.72178 .50905 Mdot
.62599 .35096 Mdot
.5995 .28283 Mdot
.30629 .39582 Mdot
.67604 .59936 Mdot
.32487 .41749 Mdot
.59909 .32764 Mdot
.31603 .62011 Mdot
.71513 .46328 Mdot
.5652 .69963 Mdot
.68496 .38703 Mdot
.60372 .29807 Mdot
.61941 .65409 Mdot
.44537 .73531 Mdot
.27564 .4497 Mdot
.73226 .5093 Mdot
.52482 .27426 Mdot
.32671 .38087 Mdot
.62708 .64367 Mdot
.34848 .52622 Mdot
.44686 .71098 Mdot
.33634 .65773 Mdot
.42983 .35502 Mdot
.50159 .28476 Mdot
.39579 .36266 Mdot
.40693 .31682 Mdot
.31138 .67132 Mdot
.70518 .46902 Mdot
.67861 .4077 Mdot
.4209 .33463 Mdot
.71348 .47918 Mdot
.35032 .51914 Mdot
.59704 .29951 Mdot
.59392 .65034 Mdot
.3486 .53773 Mdot
.27932 .41241 Mdot
.67364 .36658 Mdot
.63793 .6476 Mdot
.62794 .3481 Mdot
.32407 .62955 Mdot
.65988 .61432 Mdot
.72045 .47744 Mdot
.32224 .58719 Mdot
.60671 .33429 Mdot
.38661 .31703 Mdot
.61982 .32203 Mdot
.31743 .64971 Mdot
.3284 .62903 Mdot
.40376 .31036 Mdot
.34747 .53751 Mdot
.71221 .55986 Mdot
.52544 .73035 Mdot
.54585 .6929 Mdot
.32524 .5566 Mdot
.58942 .66098 Mdot
.67109 .37968 Mdot
.42139 .33319 Mdot
.42972 .70783 Mdot
.34567 .63576 Mdot
.72171 .58635 Mdot
.67699 .39026 Mdot
.7151 .43276 Mdot
.70241 .48203 Mdot
.60966 .33743 Mdot
.70204 .46802 Mdot
.34121 .573 Mdot
.68616 .56781 Mdot
.59961 .31777 Mdot
.41064 .33459 Mdot
.63198 .3141 Mdot
.35242 .56621 Mdot
.67509 .36395 Mdot
.61355 .28928 Mdot
.53781 .7152 Mdot
.67938 .57574 Mdot
.46114 .31248 Mdot
.50737 .68999 Mdot
.32061 .61224 Mdot
.33479 .6574 Mdot
.37652 .33574 Mdot
.70012 .48706 Mdot
.60812 .67292 Mdot
.51643 .26704 Mdot
.33809 .39654 Mdot
.68269 .56631 Mdot
.33313 .40865 Mdot
.43293 .72281 Mdot
.60007 .65076 Mdot
.39185 .70432 Mdot
.709 .5012 Mdot
.69829 .58184 Mdot
.33598 .37974 Mdot
.54264 .71859 Mdot
.31522 .40546 Mdot
.62946 .33263 Mdot
.41494 .72731 Mdot
.57851 .2959 Mdot
.69857 .39738 Mdot
.51217 .27398 Mdot
.7251 .49448 Mdot
.44456 .34714 Mdot
.50333 .73231 Mdot
.66863 .38542 Mdot
.69056 .37819 Mdot
.59048 .32142 Mdot
.41791 .34125 Mdot
.50712 .72388 Mdot
.42793 .33814 Mdot
.42028 .346 Mdot
.67389 .40322 Mdot
.70307 .58165 Mdot
.70892 .59858 Mdot
.26866 .38624 Mdot
.70327 .58395 Mdot
.58917 .30481 Mdot
.4384 .72068 Mdot
.46044 .73032 Mdot
.67103 .37772 Mdot
.52641 .70202 Mdot
.33381 .58009 Mdot
.48953 .28383 Mdot
.59278 .30118 Mdot
.70261 .47393 Mdot
.68987 .62413 Mdot
.42004 .32345 Mdot
.61223 .66987 Mdot
.68137 .58705 Mdot
.68426 .59648 Mdot
.67818 .61413 Mdot
.32627 .6212 Mdot
.72705 .49204 Mdot
.69083 .58493 Mdot
.31571 .64406 Mdot
.33943 .51523 Mdot
.38654 .31969 Mdot
.4309 .35378 Mdot
.51899 .72284 Mdot
.39351 .32249 Mdot
.35144 .54801 Mdot
.6141 .32768 Mdot
.4333 .35439 Mdot
.41759 .31771 Mdot
.59883 .3342 Mdot
.59582 .33281 Mdot
.42526 .34216 Mdot
.43224 .35537 Mdot
.71507 .56202 Mdot
.50551 .73793 Mdot
.58678 .67143 Mdot
.61311 .28731 Mdot
.69322 .42634 Mdot
.60199 .68202 Mdot
.33264 .661 Mdot
.38057 .31808 Mdot
.60644 .30792 Mdot
.71513 .60376 Mdot
.33042 .54938 Mdot
.39889 .32695 Mdot
.31561 .39958 Mdot
.41261 .33538 Mdot
.37906 .33557 Mdot
.59171 .68763 Mdot
.68881 .50851 Mdot
.62817 .65101 Mdot
.57199 .27407 Mdot
.40599 .34117 Mdot
.64244 .68348 Mdot
.49812 .2675 Mdot
.70276 .40269 Mdot
.52501 .73152 Mdot
.32564 .56033 Mdot
.58999 .32563 Mdot
.69879 .57285 Mdot
.69288 .45535 Mdot
.38974 .70279 Mdot
.69786 .5891 Mdot
.39905 .36403 Mdot
.38523 .34536 Mdot
.58577 .31006 Mdot
.60537 .69138 Mdot
.52753 .71775 Mdot
.69148 .59119 Mdot
.69263 .39886 Mdot
.34504 .6531 Mdot
.65937 .62029 Mdot
.39921 .32023 Mdot
.70684 .59538 Mdot
.61496 .29922 Mdot
.32842 .40164 Mdot
.33873 .63959 Mdot
.73224 .46123 Mdot
.34235 .53036 Mdot
.69494 .40314 Mdot
.27357 .41271 Mdot
.54247 .70285 Mdot
.32895 .65401 Mdot
.4415 .71076 Mdot
.6881 .37512 Mdot
.3195 .65507 Mdot
.44592 .73277 Mdot
.61644 .64535 Mdot
.62158 .6626 Mdot
.35358 .52417 Mdot
.58627 .29431 Mdot
.55484 .27055 Mdot
.33097 .52287 Mdot
.5801 .26958 Mdot
.4287 .73512 Mdot
.42614 .32222 Mdot
.30183 .37106 Mdot
.33574 .60454 Mdot
.33496 .64582 Mdot
.33595 .56701 Mdot
.3454 .65432 Mdot
.38597 .69884 Mdot
.602 .33082 Mdot
.6193 .34666 Mdot
.31547 .39258 Mdot
.3027 .66499 Mdot
.32195 .40974 Mdot
.67484 .39309 Mdot
.50243 .72819 Mdot
.37945 .35085 Mdot
.70352 .58866 Mdot
.34279 .53609 Mdot
.62634 .32352 Mdot
.32596 .64878 Mdot
.52775 .70887 Mdot
.58799 .30709 Mdot
.61029 .31357 Mdot
.55878 .27809 Mdot
.33685 .38667 Mdot
.6865 .60711 Mdot
.34678 .5705 Mdot
.31298 .37399 Mdot
.41498 .31335 Mdot
.35178 .70274 Mdot
.67695 .57308 Mdot
.69988 .60433 Mdot
.68953 .61376 Mdot
.34492 .56456 Mdot
.34602 .5651 Mdot
.69288 .4088 Mdot
.59841 .66724 Mdot
.72377 .47322 Mdot
.58462 .31872 Mdot
.56689 .26822 Mdot
.33088 .64661 Mdot
.27885 .40824 Mdot
.30889 .41026 Mdot
.62366 .29954 Mdot
.38089 .34757 Mdot
.32652 .41237 Mdot
.35032 .56231 Mdot
.58362 .31077 Mdot
.33391 .38149 Mdot
.68658 .62109 Mdot
.71266 .43904 Mdot
.32796 .4074 Mdot
.40248 .31669 Mdot
.60363 .65495 Mdot
.33537 .61308 Mdot
.32922 .41556 Mdot
.6712 .38399 Mdot
.39959 .70688 Mdot
.38394 .35097 Mdot
.28597 .41092 Mdot
.32585 .69224 Mdot
.59771 .32203 Mdot
.40363 .31563 Mdot
.33667 .37807 Mdot
.46361 .7284 Mdot
.31512 .41788 Mdot
.70347 .60135 Mdot
.53765 .68809 Mdot
.33618 .65072 Mdot
.53642 .70551 Mdot
.68961 .48105 Mdot
.63066 .33276 Mdot
.62544 .34202 Mdot
.60548 .6866 Mdot
.43992 .71543 Mdot
.58269 .28929 Mdot
.43858 .71075 Mdot
.28692 .37339 Mdot
.31598 .64408 Mdot
.26787 .38534 Mdot
.54484 .71396 Mdot
.34504 .39334 Mdot
.32842 .40475 Mdot
.67426 .37193 Mdot
.71172 .47008 Mdot
.70274 .48989 Mdot
.58102 .29383 Mdot
.42626 .71844 Mdot
.62131 .34469 Mdot
.73294 .59713 Mdot
.29791 .39843 Mdot
.53194 .28343 Mdot
.33318 .5745 Mdot
.35013 .55126 Mdot
.53116 .69716 Mdot
.37966 .326 Mdot
.31327 .64611 Mdot
.68809 .40196 Mdot
.62943 .31435 Mdot
.67742 .36419 Mdot
.61696 .68987 Mdot
.73016 .60349 Mdot
.6104 .31673 Mdot
.28021 .37639 Mdot
.31117 .41295 Mdot
.32314 .69653 Mdot
.43684 .33088 Mdot
.61808 .33315 Mdot
.31744 .53554 Mdot
.71792 .59848 Mdot
.54118 .28592 Mdot
.33942 .5377 Mdot
.60017 .28475 Mdot
.49736 .26479 Mdot
.54294 .70856 Mdot
.33661 .62172 Mdot
.69996 .43033 Mdot
.43337 .71112 Mdot
.34264 .39562 Mdot
.40224 .30971 Mdot
.45623 .70968 Mdot
.59729 .32721 Mdot
.63503 .32773 Mdot
.33292 .39949 Mdot
.63306 .64793 Mdot
.71296 .59952 Mdot
.7156 .56304 Mdot
.69084 .40412 Mdot
.32101 .53546 Mdot
.58563 .31285 Mdot
.61215 .66189 Mdot
.32733 .59553 Mdot
.71625 .49405 Mdot
.62842 .30375 Mdot
.34727 .53754 Mdot
.32758 .65316 Mdot
.32254 .40556 Mdot
.26318 .39493 Mdot
.40514 .30533 Mdot
.70316 .40066 Mdot
.31812 .68303 Mdot
.50059 .72609 Mdot
.33936 .56073 Mdot
.70156 .56662 Mdot
.39003 .33222 Mdot
.3112 .40838 Mdot
.31001 .65813 Mdot
.45288 .71814 Mdot
.71335 .57805 Mdot
.7113 .5023 Mdot
.40621 .33532 Mdot
.31504 .68 Mdot
.34564 .53424 Mdot
.34016 .65111 Mdot
.53037 .72309 Mdot
.32749 .57237 Mdot
.49467 .27946 Mdot
.63976 .65288 Mdot
.2986 .37882 Mdot
.68515 .60146 Mdot
.50883 .2676 Mdot
.51956 .73278 Mdot
.41985 .72363 Mdot
.59707 .65273 Mdot
.67997 .57283 Mdot
.69347 .39793 Mdot
.72558 .48522 Mdot
.27464 .4047 Mdot
.32191 .64689 Mdot
.3936 .35672 Mdot
.68712 .59031 Mdot
.6297 .33278 Mdot
.32205 .41083 Mdot
.52716 .27541 Mdot
.34241 .55478 Mdot
.59234 .32202 Mdot
.39416 .34669 Mdot
.60672 .6932 Mdot
.61241 .32915 Mdot
.38614 .31767 Mdot
.30486 .38419 Mdot
.40348 .70719 Mdot
.41716 .36454 Mdot
.4118 .32051 Mdot
.32613 .64384 Mdot
.56052 .71138 Mdot
.53165 .70289 Mdot
.42468 .31177 Mdot
.63074 .3499 Mdot
.40446 .3211 Mdot
.63878 .64601 Mdot
.5414 .70785 Mdot
.62249 .30704 Mdot
.5993 .67581 Mdot
.52753 .72994 Mdot
.41643 .32163 Mdot
.67484 .57595 Mdot
.5085 .26523 Mdot
.70803 .6174 Mdot
.33076 .60303 Mdot
.32498 .5383 Mdot
.57825 .29379 Mdot
.31592 .40369 Mdot
.68646 .41252 Mdot
.66399 .38232 Mdot
.6878 .37702 Mdot
.57058 .29259 Mdot
.34459 .53752 Mdot
.6946 .58393 Mdot
.71731 .47424 Mdot
.60904 .676 Mdot
.61488 .30767 Mdot
.5926 .29602 Mdot
.52659 .69809 Mdot
.32054 .41219 Mdot
.33416 .57372 Mdot
.62916 .33238 Mdot
.50775 .27525 Mdot
.65186 .66901 Mdot
.34278 .3915 Mdot
.51803 .73013 Mdot
.41581 .36472 Mdot
.30324 .64406 Mdot
.61986 .63967 Mdot
.3894 .34957 Mdot
.61107 .69173 Mdot
.32456 .60471 Mdot
.65313 .3595 Mdot
.4974 .26839 Mdot
.43664 .71223 Mdot
.7026 .42395 Mdot
.72 .47263 Mdot
.60921 .32937 Mdot
.33683 .55018 Mdot
.52866 .27747 Mdot
.30676 .39497 Mdot
.55058 .70557 Mdot
.42222 .33402 Mdot
.60519 .67864 Mdot
.70924 .46115 Mdot
.43813 .3513 Mdot
.68664 .41242 Mdot
.70454 .49441 Mdot
.58401 .67182 Mdot
.33582 .64993 Mdot
.60378 .31133 Mdot
.59308 .29097 Mdot
.26886 .38474 Mdot
.49155 .28786 Mdot
.7035 .61144 Mdot
.6529 .35927 Mdot
.43907 .70373 Mdot
.35437 .52806 Mdot
.40475 .36268 Mdot
.39735 .35629 Mdot
.50841 .27087 Mdot
.31901 .65533 Mdot
.62941 .66553 Mdot
.62348 .34821 Mdot
.5899 .28122 Mdot
.53706 .70918 Mdot
.71331 .46976 Mdot
.43687 .3196 Mdot
.59102 .30368 Mdot
.35034 .69757 Mdot
.33188 .64479 Mdot
.73191 .50887 Mdot
.59144 .30628 Mdot
.47606 .28445 Mdot
.68007 .41707 Mdot
.61976 .65556 Mdot
.40873 .69872 Mdot
.61695 .67144 Mdot
.32505 .41247 Mdot
.62144 .33868 Mdot
.67862 .40411 Mdot
.40876 .33887 Mdot
.55375 .27201 Mdot
.57933 .29055 Mdot
.69632 .60035 Mdot
.33785 .65251 Mdot
.31473 .5631 Mdot
.34732 .5343 Mdot
.31701 .6933 Mdot
.34057 .39428 Mdot
.66379 .38153 Mdot
.69328 .39546 Mdot
.40927 .69854 Mdot
.33649 .38355 Mdot
.60901 .34006 Mdot
.58862 .30932 Mdot
.73036 .45906 Mdot
.37957 .33694 Mdot
.61212 .34175 Mdot
.32862 .64209 Mdot
.5587 .27519 Mdot
.59972 .65421 Mdot
.71134 .46784 Mdot
.3452 .63756 Mdot
.57745 .2906 Mdot
.58917 .68649 Mdot
.42853 .71515 Mdot
.33287 .52201 Mdot
.40459 .30202 Mdot
.72343 .4818 Mdot
.72633 .6118 Mdot
.48935 .28298 Mdot
.32373 .53185 Mdot
.6791 .39681 Mdot
.45677 .32784 Mdot
.55309 .27788 Mdot
.67947 .60493 Mdot
.59643 .28496 Mdot
.70311 .46262 Mdot
.39754 .34418 Mdot
.29721 .37921 Mdot
.61967 .32655 Mdot
.5996 .28173 Mdot
.51758 .7124 Mdot
.27526 .38118 Mdot
.33089 .41316 Mdot
.68957 .57121 Mdot
.71887 .49926 Mdot
.53043 .70753 Mdot
.34444 .69744 Mdot
.34714 .56626 Mdot
.70078 .49061 Mdot
.65604 .65752 Mdot
.3202 .53069 Mdot
.33363 .56031 Mdot
.32303 .58592 Mdot
.62478 .64825 Mdot
.69169 .57772 Mdot
.31118 .68438 Mdot
.52241 .71866 Mdot
.42574 .72395 Mdot
.70276 .59501 Mdot
.68933 .60417 Mdot
.41766 .71735 Mdot
.52055 .71051 Mdot
.59674 .67423 Mdot
.71253 .4743 Mdot
.72044 .47343 Mdot
.68292 .59698 Mdot
.53402 .69714 Mdot
.70335 .49843 Mdot
.61534 .6781 Mdot
.6013 .29781 Mdot
.43719 .73293 Mdot
.67636 .59069 Mdot
.41823 .72974 Mdot
.72213 .48581 Mdot
.33404 .69947 Mdot
.42794 .73535 Mdot
.32554 .56718 Mdot
.33444 .65241 Mdot
.32305 .37821 Mdot
.41202 .33849 Mdot
.42516 .34263 Mdot
.69988 .48547 Mdot
.33666 .57087 Mdot
.62517 .67975 Mdot
.34218 .56772 Mdot
.35239 .63752 Mdot
.33611 .69651 Mdot
.43152 .69868 Mdot
.68003 .60355 Mdot
.6242 .68178 Mdot
.56749 .27197 Mdot
.63246 .32796 Mdot
.45085 .72234 Mdot
.72246 .47865 Mdot
.70899 .59167 Mdot
.72312 .4725 Mdot
.59776 .32644 Mdot
.60557 .31098 Mdot
.38835 .3262 Mdot
.4032 .3154 Mdot
.60576 .32387 Mdot
.57925 .27166 Mdot
.34238 .70033 Mdot
.60086 .67708 Mdot
.63538 .64101 Mdot
.34588 .61571 Mdot
.31067 .55322 Mdot
.31475 .40174 Mdot
.43136 .3582 Mdot
.68517 .4019 Mdot
.43077 .70509 Mdot
.35669 .55114 Mdot
.41234 .32363 Mdot
.69265 .49213 Mdot
.29484 .40697 Mdot
.71474 .4683 Mdot
.2916 .38572 Mdot
.62071 .3051 Mdot
.34539 .54228 Mdot
.33361 .56666 Mdot
.69161 .39572 Mdot
.5617 .27769 Mdot
.58114 .30742 Mdot
.31195 .40411 Mdot
.34303 .61219 Mdot
.58919 .31544 Mdot
.676 .58806 Mdot
.66532 .59136 Mdot
.39592 .35162 Mdot
.33256 .5501 Mdot
.33716 .60884 Mdot
.54143 .70946 Mdot
.41659 .31459 Mdot
.40587 .33465 Mdot
.73396 .57963 Mdot
.3104 .62679 Mdot
.71651 .43258 Mdot
.40588 .31287 Mdot
.68221 .61265 Mdot
.60466 .3144 Mdot
.41935 .31836 Mdot
.43239 .3327 Mdot
.25864 .42718 Mdot
.42353 .3497 Mdot
.70852 .57944 Mdot
.62052 .67087 Mdot
.50572 .72176 Mdot
.65842 .64908 Mdot
.28244 .38853 Mdot
.30241 .40811 Mdot
.49567 .26924 Mdot
.68298 .37723 Mdot
.32322 .59563 Mdot
.30099 .40007 Mdot
.69379 .62201 Mdot
.51794 .70041 Mdot
.51292 .70761 Mdot
.50953 .71488 Mdot
.61184 .67561 Mdot
.32519 .63143 Mdot
.50045 .28216 Mdot
.69836 .59905 Mdot
.5029 .71736 Mdot
.31503 .53125 Mdot
.71434 .56629 Mdot
.7135 .50019 Mdot
.55137 .69829 Mdot
.69647 .58451 Mdot
.38855 .69792 Mdot
.72323 .49666 Mdot
.44732 .71378 Mdot
.64701 .35832 Mdot
.47667 .28583 Mdot
.70487 .47364 Mdot
.6267 .30155 Mdot
.58876 .31897 Mdot
.58365 .30017 Mdot
.6868 .58201 Mdot
.5893 .27684 Mdot
.62728 .68031 Mdot
.5246 .27442 Mdot
.31319 .67739 Mdot
.28091 .40157 Mdot
.5111 .27617 Mdot
.68492 .59719 Mdot
.71935 .61677 Mdot
.28866 .4591 Mdot
.33001 .52061 Mdot
.67088 .39305 Mdot
.31172 .39003 Mdot
.43726 .72085 Mdot
.30072 .38129 Mdot
.60519 .33448 Mdot
.31485 .67278 Mdot
.33227 .64511 Mdot
.71302 .43661 Mdot
.31758 .4046 Mdot
.68659 .60418 Mdot
.5148 .71301 Mdot
.62319 .35409 Mdot
.3068 .39672 Mdot
.31842 .41205 Mdot
.33796 .52035 Mdot
.62054 .67281 Mdot
.58547 .32121 Mdot
.71551 .51086 Mdot
.51934 .26528 Mdot
.37281 .69957 Mdot
.30764 .63967 Mdot
.32427 .5284 Mdot
.43406 .72526 Mdot
.51412 .26937 Mdot
.70991 .47691 Mdot
.3526 .64248 Mdot
.48051 .27855 Mdot
.35398 .64165 Mdot
.61214 .69573 Mdot
.51786 .27558 Mdot
.39953 .35269 Mdot
.38731 .31838 Mdot
.33366 .54239 Mdot
.27771 .45232 Mdot
.31745 .62753 Mdot
.70366 .50158 Mdot
.41444 .34312 Mdot
.61947 .29116 Mdot
.71325 .60388 Mdot
.25971 .43005 Mdot
.52182 .72234 Mdot
.71507 .50987 Mdot
.58993 .31381 Mdot
.2646 .43912 Mdot
.32342 .38058 Mdot
.43211 .73806 Mdot
.34169 .51444 Mdot
.33226 .54441 Mdot
.70973 .49331 Mdot
.69926 .49698 Mdot
.62365 .63993 Mdot
.41666 .36266 Mdot
.6611 .60383 Mdot
.68556 .38507 Mdot
.26262 .43658 Mdot
.39663 .35784 Mdot
.63146 .65752 Mdot
.41034 .35907 Mdot
.68877 .47566 Mdot
.31011 .63805 Mdot
.62006 .67188 Mdot
.39073 .34563 Mdot
.52714 .68624 Mdot
.5218 .70346 Mdot
.34992 .69874 Mdot
.33549 .5261 Mdot
.70175 .6086 Mdot
.70064 .59939 Mdot
.62461 .67748 Mdot
.38414 .34032 Mdot
.3454 .55336 Mdot
.32441 .55243 Mdot
.32089 .5396 Mdot
.6545 .66253 Mdot
.34369 .54029 Mdot
.70969 .61304 Mdot
.44411 .73028 Mdot
.65365 .35883 Mdot
.33718 .56525 Mdot
.69897 .47175 Mdot
.33093 .53644 Mdot
.33592 .40744 Mdot
.40687 .70383 Mdot
.53959 .71669 Mdot
.71241 .48209 Mdot
.31545 .55267 Mdot
.46503 .30926 Mdot
.34814 .56931 Mdot
.28623 .38931 Mdot
.68722 .41993 Mdot
.32404 .61973 Mdot
.65264 .66587 Mdot
.68969 .59416 Mdot
.6215 .31867 Mdot
.6977 .45138 Mdot
.61153 .33656 Mdot
.50603 .73842 Mdot
.39927 .36083 Mdot
.53265 .28145 Mdot
.34223 .6973 Mdot
.31186 .62809 Mdot
.37743 .33916 Mdot
.61758 .68609 Mdot
.49814 .27802 Mdot
.3098 .55454 Mdot
.5291 .69729 Mdot
.33138 .39889 Mdot
.30153 .38332 Mdot
.25978 .40116 Mdot
.61083 .66718 Mdot
.71392 .61997 Mdot
.71142 .49317 Mdot
.58075 .28927 Mdot
.34381 .3916 Mdot
.74392 .49238 Mdot
.69197 .47965 Mdot
.50497 .27214 Mdot
.71065 .4622 Mdot
.34216 .56017 Mdot
.42616 .34009 Mdot
.61159 .65261 Mdot
.41845 .33113 Mdot
.32516 .59999 Mdot
.58374 .28086 Mdot
.38329 .34477 Mdot
.31467 .37478 Mdot
.69875 .46537 Mdot
.61334 .3225 Mdot
.33913 .65006 Mdot
.70258 .59903 Mdot
.514 .74478 Mdot
.47797 .28029 Mdot
.5378 .71875 Mdot
.53605 .722 Mdot
.6258 .64607 Mdot
.42214 .31446 Mdot
.5409 .27001 Mdot
.54119 .71848 Mdot
.69355 .38542 Mdot
.29346 .41793 Mdot
.52268 .28889 Mdot
.62451 .33987 Mdot
.5981 .31785 Mdot
.32243 .60653 Mdot
.61753 .34859 Mdot
.41224 .70999 Mdot
.62454 .35446 Mdot
.67673 .41156 Mdot
.32052 .63646 Mdot
.59016 .30927 Mdot
.40906 .31381 Mdot
.33291 .63963 Mdot
.6236 .66078 Mdot
.6075 .34437 Mdot
.32533 .5671 Mdot
.59396 .27327 Mdot
.694 .39934 Mdot
.38365 .33704 Mdot
.39696 .7058 Mdot
.71607 .4777 Mdot
.70407 .576 Mdot
.39828 .69445 Mdot
.3026 .3952 Mdot
.63203 .67044 Mdot
.28069 .41241 Mdot
.31632 .41418 Mdot
.43307 .73108 Mdot
.68271 .57325 Mdot
.40579 .35224 Mdot
.30248 .38479 Mdot
.29652 .37316 Mdot
.59773 .31954 Mdot
.48897 .27063 Mdot
.40426 .31909 Mdot
.34073 .64927 Mdot
.51984 .28393 Mdot
.70308 .46959 Mdot
.33728 .5171 Mdot
.58059 .30216 Mdot
.40916 .34764 Mdot
.33097 .55685 Mdot
.52169 .72 Mdot
.61633 .64655 Mdot
.42195 .3574 Mdot
.28498 .394 Mdot
.62231 .66602 Mdot
.32513 .52773 Mdot
.27981 .38823 Mdot
.51166 .2639 Mdot
.33236 .63417 Mdot
.67837 .60613 Mdot
.68892 .62215 Mdot
.62977 .33642 Mdot
.71232 .50388 Mdot
.5964 .29026 Mdot
.29013 .38467 Mdot
.28973 .46041 Mdot
.39328 .32019 Mdot
.54769 .70992 Mdot
.40863 .70876 Mdot
.62459 .3285 Mdot
.68793 .60677 Mdot
.73785 .50315 Mdot
.40563 .70451 Mdot
.33043 .63626 Mdot
.32984 .54713 Mdot
.51531 .27202 Mdot
.71446 .59988 Mdot
.33078 .54889 Mdot
.43169 .35452 Mdot
.32683 .63358 Mdot
.32136 .39414 Mdot
.64313 .35765 Mdot
.39115 .31279 Mdot
.65197 .67187 Mdot
.38739 .34307 Mdot
.58792 .30134 Mdot
.38762 .69353 Mdot
.4284 .72228 Mdot
.25712 .40981 Mdot
.70899 .57871 Mdot
.58831 .68491 Mdot
.60216 .30846 Mdot
.50778 .26691 Mdot
.51851 .72504 Mdot
.51514 .71599 Mdot
.33304 .64102 Mdot
.6058 .33442 Mdot
.63666 .34277 Mdot
.40602 .3593 Mdot
.38083 .34476 Mdot
.45432 .72382 Mdot
.61945 .30633 Mdot
.34484 .54227 Mdot
.53328 .6997 Mdot
.69127 .46566 Mdot
.61687 .66446 Mdot
.66783 .37751 Mdot
.69136 .46004 Mdot
.31662 .57835 Mdot
.32112 .68496 Mdot
.69023 .40587 Mdot
.68126 .37142 Mdot
.50073 .27179 Mdot
.45942 .72554 Mdot
.32653 .40869 Mdot
.32439 .69058 Mdot
.61095 .33799 Mdot
.35133 .54239 Mdot
.69452 .61563 Mdot
.40853 .36344 Mdot
.74082 .479 Mdot
.32636 .48223 Mdot
.50842 .72717 Mdot
.50991 .28535 Mdot
.41332 .3209 Mdot
.42033 .33395 Mdot
.33789 .61441 Mdot
.34338 .54288 Mdot
.62913 .33781 Mdot
.46303 .72768 Mdot
.68469 .38483 Mdot
.50148 .26957 Mdot
.6095 .66547 Mdot
.33328 .53771 Mdot
.72083 .5749 Mdot
.69449 .46499 Mdot
.30069 .41732 Mdot
.3324 .38354 Mdot
.34905 .56867 Mdot
.52265 .73257 Mdot
.69917 .39784 Mdot
.51574 .72116 Mdot
.52524 .70979 Mdot
.40188 .32424 Mdot
.51959 .73005 Mdot
.34271 .5133 Mdot
.32696 .51621 Mdot
.41499 .31324 Mdot
.69059 .47449 Mdot
.32771 .60364 Mdot
.41756 .3229 Mdot
.40077 .70182 Mdot
.70025 .45422 Mdot
.51681 .72257 Mdot
.70176 .4813 Mdot
.50502 .2704 Mdot
.69209 .40092 Mdot
.29969 .37826 Mdot
.50607 .27481 Mdot
.63294 .64137 Mdot
.6956 .58372 Mdot
.72714 .48741 Mdot
.30574 .3847 Mdot
.70068 .47459 Mdot
.6176 .32646 Mdot
.69601 .39323 Mdot
.62557 .69668 Mdot
.35473 .69734 Mdot
.31843 .58182 Mdot
.72937 .5073 Mdot
.6297 .31927 Mdot
.68321 .59627 Mdot
.68479 .37675 Mdot
.40448 .71263 Mdot
.32674 .38258 Mdot
.33137 .54182 Mdot
.69706 .46578 Mdot
.51353 .27971 Mdot
.61047 .6461 Mdot
.29173 .38812 Mdot
.7302 .60641 Mdot
.62419 .31788 Mdot
.32169 .63888 Mdot
.66512 .39304 Mdot
.54848 .27567 Mdot
.69092 .39367 Mdot
.31558 .56209 Mdot
.38874 .35488 Mdot
.42564 .35688 Mdot
.59069 .67656 Mdot
.3756 .33659 Mdot
.45206 .33602 Mdot
.69259 .38106 Mdot
.63541 .65167 Mdot
.56974 .27313 Mdot
.34132 .64952 Mdot
.50179 .7253 Mdot
.39359 .32458 Mdot
.70828 .60076 Mdot
.53191 .72121 Mdot
.38722 .32462 Mdot
.44323 .73097 Mdot
.61736 .66903 Mdot
.60482 .34051 Mdot
.32767 .64335 Mdot
.66828 .39659 Mdot
.68007 .38587 Mdot
.39786 .36384 Mdot
.68352 .4104 Mdot
.40113 .70175 Mdot
.68035 .57512 Mdot
.50784 .72328 Mdot
.31961 .3929 Mdot
.7095 .55925 Mdot
.41507 .36006 Mdot
.25874 .4237 Mdot
.32535 .64293 Mdot
.604 .31045 Mdot
.55439 .27809 Mdot
.45239 .724 Mdot
.70095 .59453 Mdot
.41204 .706 Mdot
.52727 .72639 Mdot
.51558 .71898 Mdot
.58056 .28978 Mdot
.43527 .72221 Mdot
.34465 .54051 Mdot
.71728 .50801 Mdot
.38425 .7026 Mdot
.3128 .54248 Mdot
.42592 .36079 Mdot
.53983 .7161 Mdot
.6766 .40981 Mdot
.60089 .67499 Mdot
.60229 .31097 Mdot
.63159 .6651 Mdot
.60496 .67336 Mdot
.69413 .57858 Mdot
.74315 .49625 Mdot
.54156 .71714 Mdot
.72484 .44669 Mdot
.6001 .65342 Mdot
.31136 .55359 Mdot
.70225 .61538 Mdot
.53511 .26917 Mdot
.6368 .652 Mdot
.70523 .57636 Mdot
.59477 .64932 Mdot
.71417 .59884 Mdot
.33742 .64458 Mdot
.34623 .63763 Mdot
.4544 .71077 Mdot
.52341 .27529 Mdot
.34817 .53536 Mdot
.42623 .34371 Mdot
.31924 .38932 Mdot
.62988 .64874 Mdot
.40849 .33592 Mdot
.42707 .73203 Mdot
.38054 .30715 Mdot
.34627 .51899 Mdot
.33299 .55462 Mdot
.50997 .71746 Mdot
.33092 .69753 Mdot
.52672 .27987 Mdot
.68883 .61191 Mdot
.313 .53637 Mdot
.55259 .27582 Mdot
.31466 .64642 Mdot
.41241 .704 Mdot
.32316 .51991 Mdot
.60385 .31134 Mdot
.60494 .66544 Mdot
.42102 .34571 Mdot
.72434 .57386 Mdot
.34085 .52859 Mdot
.37324 .3108 Mdot
.27509 .3992 Mdot
.33343 .55146 Mdot
.71824 .56815 Mdot
.53021 .72366 Mdot
.7039 .57208 Mdot
.6923 .5649 Mdot
.32999 .63623 Mdot
.61375 .65756 Mdot
.69061 .57738 Mdot
.51582 .71654 Mdot
.51183 .28531 Mdot
.70224 .39875 Mdot
.31405 .62666 Mdot
.29193 .38924 Mdot
.32442 .65629 Mdot
.31691 .41711 Mdot
.42682 .33192 Mdot
.40812 .32026 Mdot
.32046 .63192 Mdot
.63072 .3144 Mdot
.32703 .4167 Mdot
.52454 .27804 Mdot
.63288 .69408 Mdot
.58579 .67471 Mdot
.68653 .38431 Mdot
.48811 .27072 Mdot
.40591 .32104 Mdot
.33329 .59762 Mdot
.37406 .69841 Mdot
.68799 .40984 Mdot
.6081 .69386 Mdot
.31675 .62448 Mdot
.37607 .33066 Mdot
.60012 .33824 Mdot
.59218 .29223 Mdot
.69302 .38223 Mdot
.58775 .65683 Mdot
.34655 .55823 Mdot
.3764 .33161 Mdot
.55084 .69371 Mdot
.41198 .33986 Mdot
.41794 .35156 Mdot
.62742 .30093 Mdot
.34313 .55144 Mdot
.42354 .73339 Mdot
.59063 .32353 Mdot
.30406 .41261 Mdot
.60405 .69269 Mdot
.28381 .38731 Mdot
.71034 .43556 Mdot
.62171 .64201 Mdot
.6062 .32869 Mdot
.38661 .31487 Mdot
.35128 .53434 Mdot
.60781 .67283 Mdot
.61422 .68623 Mdot
.61995 .66008 Mdot
.31611 .39109 Mdot
.6255 .34405 Mdot
.52273 .26764 Mdot
.33734 .6488 Mdot
.67733 .57625 Mdot
.25814 .42624 Mdot
.32476 .65385 Mdot
.7206 .47522 Mdot
.53482 .71739 Mdot
.67883 .59904 Mdot
.54735 .70472 Mdot
.59578 .65493 Mdot
.58845 .29387 Mdot
.34921 .57097 Mdot
.33836 .64176 Mdot
.32508 .61983 Mdot
.29461 .40616 Mdot
.7171 .58412 Mdot
.31681 .68489 Mdot
.30324 .64418 Mdot
.33484 .61036 Mdot
.32811 .55118 Mdot
.31898 .58328 Mdot
.43321 .32383 Mdot
.39077 .3196 Mdot
.4087 .71253 Mdot
.32974 .52671 Mdot
.71122 .56369 Mdot
.60735 .65304 Mdot
.48286 .70795 Mdot
.7018 .49346 Mdot
.63801 .65095 Mdot
.59162 .32619 Mdot
.60415 .3432 Mdot
.56419 .27165 Mdot
.30995 .37174 Mdot
.51443 .72432 Mdot
.35605 .55817 Mdot
.70507 .50143 Mdot
.30091 .39319 Mdot
.67997 .57087 Mdot
.32099 .41361 Mdot
.43746 .71141 Mdot
.30254 .37774 Mdot
.39456 .36138 Mdot
.67673 .41329 Mdot
.53257 .69974 Mdot
.29006 .40864 Mdot
.62025 .66469 Mdot
.31829 .62209 Mdot
.33914 .62489 Mdot
.71881 .61784 Mdot
.33193 .40368 Mdot
.52106 .26571 Mdot
.31816 .64614 Mdot
.30403 .66949 Mdot
.70109 .48508 Mdot
.29694 .37965 Mdot
.71936 .46898 Mdot
.53148 .7139 Mdot
.58849 .68935 Mdot
.69549 .59682 Mdot
.68076 .38283 Mdot
.41245 .70471 Mdot
.30281 .37559 Mdot
.60388 .32505 Mdot
.46146 .72219 Mdot
.52854 .28142 Mdot
.39149 .30169 Mdot
.33022 .61187 Mdot
.49784 .28168 Mdot
.31406 .53378 Mdot
.68403 .39454 Mdot
.34082 .57204 Mdot
.54512 .70638 Mdot
.3126 .66312 Mdot
.58085 .31152 Mdot
.59767 .31681 Mdot
.53096 .27762 Mdot
.31162 .62226 Mdot
.31815 .52284 Mdot
.60735 .67939 Mdot
.6269 .3415 Mdot
.68727 .58499 Mdot
.70399 .60577 Mdot
.62473 .29877 Mdot
.7098 .57148 Mdot
.31923 .41228 Mdot
.31391 .66939 Mdot
.68459 .39488 Mdot
.69001 .39062 Mdot
.60679 .32574 Mdot
.61313 .28795 Mdot
.60556 .3115 Mdot
.53247 .71765 Mdot
.68195 .57566 Mdot
.31984 .68949 Mdot
.33569 .52341 Mdot
.33452 .57012 Mdot
.60826 .66586 Mdot
.40433 .7064 Mdot
.33145 .48648 Mdot
.32981 .39899 Mdot
.58988 .30207 Mdot
.70808 .45857 Mdot
.53163 .74179 Mdot
.71185 .50711 Mdot
.33016 .63127 Mdot
.70107 .40613 Mdot
.61304 .69299 Mdot
.30932 .37705 Mdot
.53607 .70459 Mdot
.32792 .37878 Mdot
.69113 .46833 Mdot
.61226 .68469 Mdot
.43835 .71818 Mdot
.32349 .63486 Mdot
.42338 .71524 Mdot
.3595 .3342 Mdot
.60306 .64818 Mdot
.72168 .49261 Mdot
.5308 .70128 Mdot
.3898 .30389 Mdot
.53925 .69142 Mdot
.32346 .6054 Mdot
.3209 .5692 Mdot
.32556 .59323 Mdot
.34732 .64192 Mdot
.62014 .65481 Mdot
.42225 .70609 Mdot
.38287 .3197 Mdot
.34207 .64118 Mdot
.72402 .4509 Mdot
.35067 .5262 Mdot
.33194 .5677 Mdot
.35418 .54574 Mdot
.31809 .56499 Mdot
.63813 .64644 Mdot
.50849 .71479 Mdot
.7109 .50542 Mdot
.30364 .65895 Mdot
.67771 .37669 Mdot
.60949 .32401 Mdot
.4103 .36457 Mdot
.6185 .651 Mdot
.32842 .3796 Mdot
.70704 .42876 Mdot
.30689 .67236 Mdot
.56808 .2701 Mdot
.3506 .63736 Mdot
.42233 .36174 Mdot
.42428 .34203 Mdot
.3018 .37501 Mdot
.57763 .28827 Mdot
.70824 .47185 Mdot
.31792 .53498 Mdot
.68561 .5893 Mdot
.70426 .5838 Mdot
.33972 .63779 Mdot
.688 .48232 Mdot
.6804 .38624 Mdot
.50965 .27629 Mdot
.34581 .55802 Mdot
.34591 .63904 Mdot
.70246 .56754 Mdot
.50306 .26497 Mdot
.42519 .72667 Mdot
.30865 .40188 Mdot
.36051 .52821 Mdot
.38007 .32208 Mdot
.42432 .70834 Mdot
.70788 .50167 Mdot
.40444 .35016 Mdot
.35915 .54639 Mdot
.31941 .68581 Mdot
.55027 .70128 Mdot
.26539 .38992 Mdot
.63465 .34191 Mdot
.3279 .63886 Mdot
.32325 .64802 Mdot
.61628 .66961 Mdot
.69181 .39834 Mdot
.68618 .60698 Mdot
.63819 .68599 Mdot
.40764 .32043 Mdot
.69495 .40088 Mdot
.33263 .5792 Mdot
.68264 .4144 Mdot
.53544 .71725 Mdot
.31956 .6139 Mdot
.72102 .49355 Mdot
.70243 .5637 Mdot
.65969 .62233 Mdot
.32957 .62467 Mdot
.52848 .70938 Mdot
.32396 .65587 Mdot
.50179 .26656 Mdot
.40616 .36417 Mdot
.32453 .63421 Mdot
.7085 .58881 Mdot
.32776 .65288 Mdot
.6921 .46986 Mdot
.28663 .40932 Mdot
.70101 .5909 Mdot
.50464 .28576 Mdot
.58506 .29028 Mdot
.63199 .33182 Mdot
.39601 .36117 Mdot
.52397 .72855 Mdot
.62671 .66914 Mdot
.68021 .60831 Mdot
.41784 .71234 Mdot
.588 .30186 Mdot
.31783 .39849 Mdot
.34113 .65718 Mdot
.3802 .31935 Mdot
.66821 .39445 Mdot
.65706 .65605 Mdot
.44547 .72943 Mdot
.28776 .38142 Mdot
.37898 .69786 Mdot
.4035 .32669 Mdot
.33962 .55814 Mdot
.29937 .37784 Mdot
.609 .28678 Mdot
.54842 .69843 Mdot
.43573 .32634 Mdot
.52312 .28141 Mdot
.57272 .28915 Mdot
.67843 .3803 Mdot
.63117 .34634 Mdot
.32962 .3779 Mdot
.40261 .31335 Mdot
.70097 .58572 Mdot
.33891 .54923 Mdot
.39651 .32621 Mdot
.59628 .29915 Mdot
.39879 .35913 Mdot
.32567 .56285 Mdot
.72429 .58727 Mdot
.61617 .33043 Mdot
.32585 .64956 Mdot
.54314 .71464 Mdot
.62532 .64382 Mdot
.50898 .28226 Mdot
.41272 .70744 Mdot
.34295 .38598 Mdot
.5639 .27936 Mdot
.57972 .30794 Mdot
.33669 .63303 Mdot
.32578 .3858 Mdot
.33492 .53167 Mdot
.71185 .47054 Mdot
.39337 .69657 Mdot
.69172 .39575 Mdot
.3518 .63427 Mdot
.34648 .6475 Mdot
.41929 .6983 Mdot
.57793 .69008 Mdot
.4619 .31635 Mdot
.35233 .62969 Mdot
.32348 .5515 Mdot
.70027 .61508 Mdot
.41402 .72773 Mdot
.35972 .69869 Mdot
.60555 .66133 Mdot
.2781 .40103 Mdot
.69887 .48278 Mdot
.33809 .65886 Mdot
.71575 .43789 Mdot
.32082 .39504 Mdot
.34093 .61639 Mdot
.45107 .73013 Mdot
.68944 .60505 Mdot
.35463 .55941 Mdot
.69423 .59247 Mdot
.31359 .62476 Mdot
.63158 .64328 Mdot
.68763 .37944 Mdot
.32825 .58833 Mdot
.40534 .31355 Mdot
.54901 .27624 Mdot
.31769 .57799 Mdot
.32141 .40538 Mdot
.5452 .70398 Mdot
.40895 .32394 Mdot
.71454 .46814 Mdot
.69883 .38338 Mdot
.60453 .30984 Mdot
.71209 .51144 Mdot
.63411 .65687 Mdot
.51283 .27889 Mdot
.38933 .35303 Mdot
.54975 .6956 Mdot
.34391 .39628 Mdot
.69525 .40286 Mdot
.32578 .54388 Mdot
.34577 .56593 Mdot
.51595 .27204 Mdot
.64415 .35801 Mdot
.72078 .60371 Mdot
.62593 .64078 Mdot
.61338 .6834 Mdot
.29952 .40941 Mdot
.51303 .2825 Mdot
.35303 .56775 Mdot
.34774 .54233 Mdot
.58533 .27774 Mdot
.60599 .66495 Mdot
.31791 .38651 Mdot
.42532 .35687 Mdot
.70407 .50101 Mdot
.53821 .2824 Mdot
.70081 .5894 Mdot
.53145 .28637 Mdot
.5183 .26621 Mdot
.62101 .63422 Mdot
.34678 .62009 Mdot
.71334 .47647 Mdot
.52711 .28833 Mdot
.67787 .60037 Mdot
.32896 .62985 Mdot
.41611 .34052 Mdot
.39512 .36038 Mdot
.58903 .66459 Mdot
.61135 .33107 Mdot
.32941 .38837 Mdot
.32593 .60163 Mdot
.29427 .3735 Mdot
.60484 .67055 Mdot
.62514 .31561 Mdot
.40319 .34548 Mdot
.70225 .45457 Mdot
.32837 .65402 Mdot
.31897 .39067 Mdot
.71324 .47861 Mdot
.38824 .31706 Mdot
.30969 .66897 Mdot
.39791 .6949 Mdot
.53522 .72425 Mdot
.70323 .48723 Mdot
.42228 .72012 Mdot
.34916 .51733 Mdot
.68367 .39438 Mdot
.27774 .41053 Mdot
.54651 .27606 Mdot
.39579 .70059 Mdot
.69242 .38072 Mdot
.58521 .27664 Mdot
.63084 .34934 Mdot
.487 .26964 Mdot
.52643 .2801 Mdot
.67588 .38394 Mdot
.40144 .33714 Mdot
.53314 .27544 Mdot
.69162 .39767 Mdot
.42963 .70582 Mdot
.33861 .6581 Mdot
.46091 .72975 Mdot
.38973 .31421 Mdot
.38563 .33682 Mdot
.59928 .66338 Mdot
.51435 .70505 Mdot
.40577 .34365 Mdot
.32482 .53361 Mdot
.61808 .68435 Mdot
.72327 .49101 Mdot
.25929 .43103 Mdot
.69881 .49788 Mdot
.54954 .69815 Mdot
.56825 .29721 Mdot
.50922 .27873 Mdot
.33781 .54915 Mdot
.70529 .42148 Mdot
.26331 .4374 Mdot
.33714 .65929 Mdot
.53612 .70455 Mdot
.35392 .64172 Mdot
.34171 .64021 Mdot
.64003 .66774 Mdot
.37889 .33036 Mdot
.62321 .67905 Mdot
.71632 .48055 Mdot
.28513 .40918 Mdot
.44855 .34165 Mdot
.70193 .48843 Mdot
.34665 .52762 Mdot
.40042 .36489 Mdot
.33189 .54573 Mdot
.31995 .53984 Mdot
.30348 .63954 Mdot
.29126 .37105 Mdot
.61062 .31901 Mdot
.33247 .38166 Mdot
.71342 .58508 Mdot
.6559 .6549 Mdot
.3225 .40311 Mdot
.45972 .7224 Mdot
.42708 .72975 Mdot
.64517 .35763 Mdot
.70464 .58456 Mdot
.32325 .41478 Mdot
.69762 .47416 Mdot
.36759 .70253 Mdot
.45203 .71314 Mdot
.71752 .51062 Mdot
.32722 .56125 Mdot
.6799 .60887 Mdot
.60115 .66472 Mdot
.6974 .40225 Mdot
.6787 .60537 Mdot
.42483 .72218 Mdot
.52989 .71463 Mdot
.70695 .50164 Mdot
.34817 .6144 Mdot
.69327 .39551 Mdot
.31193 .57005 Mdot
.53179 .70699 Mdot
.7007 .593 Mdot
.31668 .56927 Mdot
.70623 .56056 Mdot
.3869 .32936 Mdot
.30251 .64977 Mdot
.31874 .40047 Mdot
.42426 .7173 Mdot
.49593 .28584 Mdot
.60626 .69639 Mdot
.68233 .59904 Mdot
.68921 .46648 Mdot
.69504 .60665 Mdot
.59 .67993 Mdot
.72821 .51099 Mdot
.63924 .65398 Mdot
.34201 .52854 Mdot
.65783 .64454 Mdot
.629 .66669 Mdot
.71464 .49152 Mdot
.30871 .39319 Mdot
.61708 .66024 Mdot
.51369 .26695 Mdot
.33007 .64095 Mdot
.61212 .30338 Mdot
.33426 .40763 Mdot
.61899 .65149 Mdot
.31947 .40388 Mdot
.60208 .30335 Mdot
.42611 .35978 Mdot
.66569 .37927 Mdot
.68809 .41528 Mdot
.43118 .34214 Mdot
.69568 .38704 Mdot
.71492 .59379 Mdot
.51983 .28609 Mdot
.33279 .59196 Mdot
.34712 .55538 Mdot
.33661 .4065 Mdot
.71527 .60172 Mdot
.69877 .42502 Mdot
.40862 .33759 Mdot
.59776 .67609 Mdot
.70286 .45694 Mdot
.50458 .27648 Mdot
.4206 .73182 Mdot
.68044 .37965 Mdot
.38522 .31572 Mdot
.4046 .32432 Mdot
.32942 .54695 Mdot
.33766 .61845 Mdot
.29064 .38691 Mdot
.54148 .27582 Mdot
.50163 .71072 Mdot
.61431 .28802 Mdot
.35451 .5341 Mdot
.50222 .71615 Mdot
.33258 .51796 Mdot
.33532 .38119 Mdot
.67408 .38031 Mdot
.69998 .58176 Mdot
.30548 .41844 Mdot
.58533 .28946 Mdot
.39208 .705 Mdot
.34275 .62879 Mdot
.41659 .71906 Mdot
.59607 .33273 Mdot
.70943 .60556 Mdot
.60288 .31717 Mdot
.68215 .39377 Mdot
.32304 .40955 Mdot
.5321 .72044 Mdot
.39013 .31334 Mdot
.62455 .33219 Mdot
.72763 .49004 Mdot
.50503 .28695 Mdot
.6969 .38073 Mdot
.40783 .32155 Mdot
.40549 .71625 Mdot
.61674 .34885 Mdot
.41901 .34024 Mdot
.59188 .66636 Mdot
.30862 .68245 Mdot
.58081 .67397 Mdot
.60697 .33502 Mdot
.2571 .41123 Mdot
.71479 .4834 Mdot
.67855 .36913 Mdot
.3104 .55464 Mdot
.27677 .45141 Mdot
.32337 .60058 Mdot
.68964 .42367 Mdot
.68612 .3954 Mdot
.70541 .48591 Mdot
.60161 .3137 Mdot
.71162 .56641 Mdot
.52376 .68607 Mdot
.60625 .33981 Mdot
.33809 .59908 Mdot
.6799 .57103 Mdot
.45089 .70872 Mdot
.61892 .34631 Mdot
.51338 .71685 Mdot
.61542 .64125 Mdot
.32733 .41354 Mdot
.32602 .61337 Mdot
.68121 .38361 Mdot
.33019 .65906 Mdot
.72588 .4458 Mdot
.59928 .30623 Mdot
.41131 .35272 Mdot
.69227 .45074 Mdot
.34147 .56763 Mdot
.35249 .54044 Mdot
.34616 .52118 Mdot
.33734 .40095 Mdot
.59644 .65893 Mdot
.30976 .64919 Mdot
.31451 .67399 Mdot
.49789 .72104 Mdot
.48628 .2738 Mdot
.32663 .37723 Mdot
.32574 .69067 Mdot
.58448 .2728 Mdot
.59671 .67002 Mdot
.32936 .5749 Mdot
.67162 .37701 Mdot
.51142 .70763 Mdot
.71484 .50045 Mdot
.71051 .45797 Mdot
.54201 .28542 Mdot
.7096 .59394 Mdot
.50599 .72678 Mdot
.63616 .33178 Mdot
.57683 .69189 Mdot
.50382 .7223 Mdot
.63329 .64069 Mdot
.69045 .47671 Mdot
.28822 .46006 Mdot
.67079 .37302 Mdot
.39278 .35935 Mdot
.6365 .65752 Mdot
.66797 .58557 Mdot
.42176 .7083 Mdot
.68229 .58434 Mdot
.51684 .27304 Mdot
.62717 .6708 Mdot
.4708 .29503 Mdot
.61252 .68638 Mdot
.7123 .48626 Mdot
.69516 .39725 Mdot
.51001 .72203 Mdot
.3409 .53208 Mdot
.44142 .72348 Mdot
.40913 .338 Mdot
.40644 .71571 Mdot
.5904 .32286 Mdot
.51968 .26814 Mdot
.67982 .41603 Mdot
.63949 .66557 Mdot
.72049 .51249 Mdot
.35298 .53939 Mdot
.53277 .70816 Mdot
.34659 .63818 Mdot
.6858 .38086 Mdot
.54954 .69082 Mdot
.33241 .52665 Mdot
.51406 .72381 Mdot
.59328 .33251 Mdot
.61478 .28624 Mdot
.58086 .66591 Mdot
.54142 .28434 Mdot
.32584 .55304 Mdot
.30005 .40349 Mdot
.31405 .37163 Mdot
.33503 .62423 Mdot
.55693 .28024 Mdot
.42675 .72687 Mdot
.32568 .54216 Mdot
.38943 .69794 Mdot
.59898 .33772 Mdot
.37776 .34691 Mdot
.59274 .29831 Mdot
.63884 .6452 Mdot
.42445 .34639 Mdot
.5834 .30941 Mdot
.43283 .73427 Mdot
.39941 .32375 Mdot
.5468 .27756 Mdot
.32284 .3938 Mdot
.33349 .51928 Mdot
.33443 .48806 Mdot
.62425 .34706 Mdot
.70822 .47863 Mdot
.62428 .6553 Mdot
.71361 .50429 Mdot
.60094 .27813 Mdot
.34072 .61348 Mdot
.38498 .32412 Mdot
.68922 .37239 Mdot
.49799 .72809 Mdot
.29901 .39808 Mdot
.66917 .37309 Mdot
.51925 .7308 Mdot
.33942 .62543 Mdot
.26753 .4423 Mdot
.33741 .56753 Mdot
.52263 .26952 Mdot
.69454 .4034 Mdot
.27762 .37916 Mdot
.34151 .54656 Mdot
.61514 .30217 Mdot
.29944 .37128 Mdot
.32901 .54254 Mdot
.50174 .28419 Mdot
.32233 .64899 Mdot
.29845 .37876 Mdot
.6189 .66968 Mdot
.3926 .69461 Mdot
.34003 .41213 Mdot
.30435 .41819 Mdot
.32405 .59643 Mdot
.34836 .64375 Mdot
.53844 .27417 Mdot
.69048 .60554 Mdot
.32523 .6367 Mdot
.33883 .40318 Mdot
.62152 .6863 Mdot
.63215 .66418 Mdot
.55035 .69947 Mdot
.69884 .45162 Mdot
.61341 .32933 Mdot
.29606 .38811 Mdot
.50753 .26464 Mdot
.33648 .65733 Mdot
.54393 .70031 Mdot
.3273 .40112 Mdot
.72175 .47843 Mdot
.52374 .72653 Mdot
.68595 .45627 Mdot
.30444 .66058 Mdot
.67065 .36962 Mdot
.32924 .57637 Mdot
.31956 .57482 Mdot
.62201 .67493 Mdot
.72591 .45035 Mdot
.69011 .37673 Mdot
.58933 .29094 Mdot
.40268 .34478 Mdot
.65645 .65343 Mdot
.3176 .39117 Mdot
.51249 .6875 Mdot
.33446 .56465 Mdot
.3525 .56926 Mdot
.62407 .67287 Mdot
.34504 .63124 Mdot
.63062 .68231 Mdot
.50774 .26617 Mdot
.27798 .45284 Mdot
.69753 .58549 Mdot
.68798 .60204 Mdot
.50284 .73948 Mdot
.55874 .27313 Mdot
.60274 .69298 Mdot
.33721 .65986 Mdot
.61203 .28431 Mdot
.26607 .38909 Mdot
.30976 .38611 Mdot
.28067 .37683 Mdot
.60373 .69459 Mdot
.44704 .73532 Mdot
.53596 .71997 Mdot
.31934 .63384 Mdot
.38048 .69861 Mdot
.68276 .39538 Mdot
.30989 .65711 Mdot
.40787 .33221 Mdot
.59669 .3014 Mdot
.31504 .53506 Mdot
.32566 .53032 Mdot
.69848 .58045 Mdot
.28809 .41338 Mdot
.7264 .50909 Mdot
.4199 .34208 Mdot
.62693 .34778 Mdot
.31014 .4097 Mdot
.71254 .57244 Mdot
.31489 .57025 Mdot
.42158 .31772 Mdot
.37707 .3366 Mdot
.32683 .55789 Mdot
.32726 .63855 Mdot
.40448 .30585 Mdot
.70951 .49653 Mdot
.59162 .29071 Mdot
.42388 .33744 Mdot
.4262 .71996 Mdot
.39154 .69793 Mdot
.34845 .54525 Mdot
.69968 .55996 Mdot
.72726 .48568 Mdot
.38442 .33041 Mdot
.52584 .28795 Mdot
.34175 .65689 Mdot
.44688 .71245 Mdot
.36833 .31715 Mdot
.40498 .3346 Mdot
.52384 .68584 Mdot
.32371 .37871 Mdot
.53108 .70676 Mdot
.30521 .66627 Mdot
.40169 .70445 Mdot
.33852 .57361 Mdot
.6038 .28393 Mdot
.70182 .4612 Mdot
.43396 .3335 Mdot
.59037 .30331 Mdot
.63176 .66418 Mdot
.32052 .63268 Mdot
.70481 .60698 Mdot
.68348 .60915 Mdot
.58789 .67625 Mdot
.69739 .48601 Mdot
.65265 .67047 Mdot
.40571 .30696 Mdot
.34297 .56169 Mdot
.68746 .40278 Mdot
.59821 .69281 Mdot
.40736 .69923 Mdot
.61481 .69262 Mdot
.71742 .58935 Mdot
.3998 .69892 Mdot
.52109 .72029 Mdot
.31222 .67473 Mdot
.31984 .5653 Mdot
.32995 .38397 Mdot
.67156 .58293 Mdot
.44427 .70922 Mdot
.32302 .60672 Mdot
.33952 .55214 Mdot
.50834 .72042 Mdot
.29011 .37274 Mdot
.34939 .637 Mdot
.33747 .56311 Mdot
.32523 .69173 Mdot
.40845 .70031 Mdot
.70584 .61283 Mdot
.66452 .38286 Mdot
.55146 .69968 Mdot
.56757 .27908 Mdot
.60957 .67393 Mdot
.32275 .41752 Mdot
.62531 .69272 Mdot
.52918 .73074 Mdot
.70182 .47227 Mdot
.6791 .5994 Mdot
.6192 .32782 Mdot
.70944 .47571 Mdot
.69317 .39527 Mdot
.50885 .71659 Mdot
.59518 .28668 Mdot
.27885 .40573 Mdot
.678 .37838 Mdot
.54603 .69138 Mdot
.71141 .48546 Mdot
.61057 .63989 Mdot
.40767 .71894 Mdot
.30699 .66775 Mdot
.3963 .33766 Mdot
.4338 .32652 Mdot
.6807 .39115 Mdot
.30853 .40008 Mdot
.52103 .72766 Mdot
.62012 .659 Mdot
.30224 .39773 Mdot
.60931 .64654 Mdot
.50251 .27752 Mdot
.60022 .67025 Mdot
.51224 .27085 Mdot
.68405 .5797 Mdot
.32751 .61247 Mdot
.30037 .41887 Mdot
.39854 .30416 Mdot
.44269 .71541 Mdot
.40046 .34721 Mdot
.31636 .55091 Mdot
.51241 .72823 Mdot
.34259 .52749 Mdot
.56687 .26837 Mdot
.3349 .41188 Mdot
.62774 .67315 Mdot
.43807 .35354 Mdot
.72475 .49593 Mdot
.41759 .71767 Mdot
.41496 .35079 Mdot
.52969 .70912 Mdot
.62592 .68541 Mdot
.69857 .5742 Mdot
.63548 .6434 Mdot
.564 .27701 Mdot
.4603 .3193 Mdot
.35034 .53718 Mdot
.43489 .3555 Mdot
.68678 .39308 Mdot
.69926 .39585 Mdot
.61733 .31502 Mdot
.29883 .46528 Mdot
.58914 .30514 Mdot
.26356 .39393 Mdot
.68705 .57662 Mdot
.28396 .396 Mdot
.3461 .53201 Mdot
.61115 .65954 Mdot
.5207 .68653 Mdot
.28705 .41492 Mdot
.3259 .37799 Mdot
.69765 .39367 Mdot
.6906 .40634 Mdot
.39983 .35581 Mdot
.40965 .70084 Mdot
.41283 .69867 Mdot
.34788 .56833 Mdot
.67806 .39136 Mdot
.52491 .71342 Mdot
.66485 .37693 Mdot
.5346 .70212 Mdot
.33643 .41106 Mdot
.57703 .30209 Mdot
.65321 .35878 Mdot
.6088 .66945 Mdot
.31926 .633 Mdot
.58491 .67751 Mdot
.31185 .68186 Mdot
.69437 .37667 Mdot
.28329 .4153 Mdot
.607 .31624 Mdot
.70529 .43446 Mdot
.57727 .29887 Mdot
.35322 .37336 Mdot
.45536 .73434 Mdot
.68962 .46385 Mdot
.413 .71969 Mdot
.62648 .30323 Mdot
.31663 .55676 Mdot
.42147 .32619 Mdot
.40071 .36485 Mdot
.50263 .73557 Mdot
.62232 .6431 Mdot
.33222 .38441 Mdot
.34664 .53196 Mdot
.62551 .63558 Mdot
.34705 .53454 Mdot
.34793 .53574 Mdot
.31987 .53653 Mdot
.68601 .38395 Mdot
.41466 .7233 Mdot
.34109 .53058 Mdot
.53197 .27876 Mdot
.27032 .38261 Mdot
.62113 .35195 Mdot
.62087 .67606 Mdot
.30084 .39321 Mdot
.60688 .67579 Mdot
.43645 .72214 Mdot
.69295 .48884 Mdot
.59879 .65603 Mdot
.51816 .71334 Mdot
.60894 .69577 Mdot
.68143 .37022 Mdot
.32918 .39107 Mdot
.40714 .32819 Mdot
.73821 .50418 Mdot
.52448 .27794 Mdot
.41116 .34522 Mdot
.50368 .2819 Mdot
.33063 .57351 Mdot
.70292 .58696 Mdot
.40365 .34617 Mdot
.72613 .47897 Mdot
.62581 .29898 Mdot
.30276 .66662 Mdot
.33241 .65002 Mdot
.59481 .33047 Mdot
.398 .33304 Mdot
.4257 .71798 Mdot
.42183 .73065 Mdot
.62774 .30524 Mdot
.73145 .50874 Mdot
.68597 .3904 Mdot
.30748 .39087 Mdot
.71368 .60279 Mdot
.69801 .57724 Mdot
.72424 .48932 Mdot
.7068 .42393 Mdot
.33541 .64528 Mdot
.32703 .65034 Mdot
.43383 .71354 Mdot
.3187 .56682 Mdot
.52122 .28826 Mdot
.41325 .34111 Mdot
.68475 .59251 Mdot
.50979 .72775 Mdot
.51642 .70102 Mdot
.34879 .52861 Mdot
.34046 .611 Mdot
.61397 .33623 Mdot
.53605 .70714 Mdot
.2967 .37992 Mdot
.65407 .6625 Mdot
.32194 .64736 Mdot
.33657 .41197 Mdot
.69244 .57787 Mdot
.54444 .27766 Mdot
.70781 .48001 Mdot
.63412 .32233 Mdot
.63557 .32757 Mdot
.35827 .33646 Mdot
.61081 .67191 Mdot
.4111 .34492 Mdot
.50059 .28933 Mdot
.39754 .36354 Mdot
.3185 .376 Mdot
.33152 .62073 Mdot
.51976 .27363 Mdot
.62412 .35417 Mdot
.69114 .45723 Mdot
.30466 .64812 Mdot
.35776 .52257 Mdot
.69295 .38014 Mdot
.33025 .55291 Mdot
.32471 .40253 Mdot
.68253 .40517 Mdot
.67999 .60109 Mdot
.32881 .38564 Mdot
.67075 .38278 Mdot
.70162 .57584 Mdot
.51036 .71711 Mdot
.40941 .69933 Mdot
.6271 .65818 Mdot
.70829 .56953 Mdot
.33691 .64434 Mdot
.53946 .28638 Mdot
.69215 .58659 Mdot
.63148 .65269 Mdot
.63805 .64218 Mdot
.62914 .32216 Mdot
.30399 .37169 Mdot
.69254 .46183 Mdot
.33627 .52941 Mdot
.57378 .30087 Mdot
.29143 .39836 Mdot
.67849 .59445 Mdot
.34247 .51348 Mdot
.33528 .65742 Mdot
.29956 .39956 Mdot
.32721 .3759 Mdot
.30603 .39839 Mdot
.69489 .39337 Mdot
.51504 .71523 Mdot
.63155 .67779 Mdot
.6865 .37329 Mdot
.32709 .41244 Mdot
.34573 .40217 Mdot
.46546 .30811 Mdot
.33215 .6461 Mdot
.33733 .38329 Mdot
.65587 .6594 Mdot
.42635 .73685 Mdot
.39811 .36369 Mdot
.25696 .40751 Mdot
.55764 .26941 Mdot
.26002 .39878 Mdot
.70061 .46336 Mdot
.52683 .70219 Mdot
.31239 .38524 Mdot
.40008 .3184 Mdot
.33368 .64833 Mdot
.34482 .64487 Mdot
.3028 .40452 Mdot
.34927 .62716 Mdot
.7049 .58021 Mdot
.57978 .67892 Mdot
.29944 .39501 Mdot
.61874 .29797 Mdot
.60434 .34066 Mdot
.59583 .31691 Mdot
.34358 .55263 Mdot
.44109 .70224 Mdot
.37323 .70149 Mdot
.63842 .64376 Mdot
.6916 .40143 Mdot
.69021 .577 Mdot
.6587 .63238 Mdot
.63175 .66783 Mdot
.62311 .29454 Mdot
.30897 .40003 Mdot
.70172 .55982 Mdot
.69604 .3975 Mdot
.68006 .38913 Mdot
.62357 .34971 Mdot
.58697 .30053 Mdot
.60527 .32697 Mdot
.61556 .65328 Mdot
.70483 .6238 Mdot
.40201 .70892 Mdot
.68262 .60802 Mdot
.58613 .27152 Mdot
.50725 .26665 Mdot
.62235 .34866 Mdot
.71709 .493 Mdot
.69367 .56415 Mdot
.32496 .64759 Mdot
.33665 .49042 Mdot
.6031 .34031 Mdot
.3316 .40455 Mdot
.65851 .64924 Mdot
.27561 .45021 Mdot
.53609 .69842 Mdot
.71697 .46837 Mdot
.39312 .32169 Mdot
.34927 .52185 Mdot
.59216 .29263 Mdot
.25837 .40649 Mdot
.37933 .33442 Mdot
.41316 .71244 Mdot
.63579 .69176 Mdot
.70729 .46824 Mdot
.41517 .7288 Mdot
.41589 .32047 Mdot
.50488 .72872 Mdot
.68175 .40335 Mdot
.62482 .33551 Mdot
.48597 .27139 Mdot
.60042 .66193 Mdot
.32167 .6272 Mdot
.39051 .31806 Mdot
.32129 .60579 Mdot
.58658 .31319 Mdot
.32675 .38484 Mdot
.59313 .32258 Mdot
.70777 .61201 Mdot
.63012 .33496 Mdot
.34785 .51767 Mdot
.62621 .68321 Mdot
.68415 .39147 Mdot
.36886 .70021 Mdot
.4433 .34901 Mdot
.62253 .31528 Mdot
.40126 .30433 Mdot
.51107 .70637 Mdot
.55184 .69601 Mdot
.43434 .33486 Mdot
.34787 .51617 Mdot
.72071 .49499 Mdot
.63394 .67689 Mdot
.72612 .49393 Mdot
.30346 .37079 Mdot
.74032 .50055 Mdot
.70693 .47952 Mdot
.45945 .71318 Mdot
.33058 .38922 Mdot
.34194 .61411 Mdot
.32913 .52695 Mdot
.71646 .46485 Mdot
.41978 .7222 Mdot
.62599 .63546 Mdot
.43252 .73378 Mdot
.31032 .66777 Mdot
.72292 .49273 Mdot
.38899 .35355 Mdot
.41821 .72871 Mdot
.29876 .37078 Mdot
.67621 .38354 Mdot
.38989 .69496 Mdot
.41543 .33989 Mdot
.31314 .41194 Mdot
.33646 .39342 Mdot
.31332 .40712 Mdot
.3434 .51992 Mdot
.32308 .58439 Mdot
.30648 .4191 Mdot
.72822 .51126 Mdot
.30951 .41739 Mdot
.27456 .41391 Mdot
.69597 .42941 Mdot
.32907 .37752 Mdot
.32512 .5442 Mdot
.53342 .70179 Mdot
.52412 .7028 Mdot
.60956 .30323 Mdot
.74023 .47709 Mdot
.52931 .27371 Mdot
.35654 .56024 Mdot
.72584 .61188 Mdot
.62575 .6692 Mdot
.42065 .30899 Mdot
.31438 .67045 Mdot
.52764 .72984 Mdot
.6329 .65957 Mdot
.42901 .71272 Mdot
.59968 .67309 Mdot
.41987 .32128 Mdot
.35078 .52035 Mdot
.61688 .67355 Mdot
.58931 .68835 Mdot
.34876 .62254 Mdot
.59825 .67606 Mdot
.68075 .58123 Mdot
.69273 .39954 Mdot
.69807 .46715 Mdot
.72151 .49449 Mdot
.58459 .29515 Mdot
.68548 .60143 Mdot
.31992 .63711 Mdot
.58882 .29233 Mdot
.32847 .56238 Mdot
.72357 .49148 Mdot
.32208 .60107 Mdot
.6875 .60252 Mdot
.32589 .53712 Mdot
.46015 .71641 Mdot
.50042 .28225 Mdot
.30025 .40057 Mdot
.62371 .6408 Mdot
.4949 .2663 Mdot
.67855 .37962 Mdot
.68296 .6176 Mdot
.27968 .41508 Mdot
.50167 .72813 Mdot
.36084 .52626 Mdot
.32028 .52933 Mdot
.50192 .72787 Mdot
.45134 .73567 Mdot
.37982 .34209 Mdot
.58511 .28975 Mdot
.63345 .32845 Mdot
.3348 .6395 Mdot
.68855 .5984 Mdot
.29764 .37644 Mdot
.33838 .41309 Mdot
.4344 .31877 Mdot
.43054 .72933 Mdot
.31434 .67369 Mdot
.3083 .62538 Mdot
.3196 .6317 Mdot
.61312 .31266 Mdot
.37905 .349 Mdot
.42156 .7095 Mdot
.32073 .40895 Mdot
.3178 .64121 Mdot
.61847 .67648 Mdot
.6763 .58902 Mdot
.60989 .33412 Mdot
.66777 .39576 Mdot
.42858 .33449 Mdot
.61555 .34816 Mdot
.33379 .63973 Mdot
.50216 .71117 Mdot
.68431 .41077 Mdot
.72016 .58572 Mdot
.30493 .41181 Mdot
.59323 .29521 Mdot
.28643 .40712 Mdot
.69319 .6071 Mdot
.67865 .59385 Mdot
.34258 .63261 Mdot
.45539 .32703 Mdot
.62654 .33269 Mdot
.34863 .54321 Mdot
.59314 .32848 Mdot
.51057 .27249 Mdot
.666 .37719 Mdot
.32549 .6358 Mdot
.52855 .6852 Mdot
.71807 .50185 Mdot
.35578 .54291 Mdot
.51394 .70783 Mdot
.52609 .72481 Mdot
.61974 .29677 Mdot
.3158 .42066 Mdot
.31114 .41444 Mdot
.68866 .62098 Mdot
.71844 .54635 Mdot
.30332 .64533 Mdot
.62719 .31932 Mdot
.54184 .69014 Mdot
.70344 .47924 Mdot
.68747 .57412 Mdot
.68564 .50183 Mdot
.71318 .49089 Mdot
.32964 .646 Mdot
.32246 .40239 Mdot
.71029 .57393 Mdot
.39722 .36395 Mdot
.34216 .70304 Mdot
.39374 .30357 Mdot
.46036 .3203 Mdot
.41977 .33739 Mdot
.68636 .48007 Mdot
.60291 .32977 Mdot
.61523 .69155 Mdot
.72388 .47649 Mdot
.70211 .47562 Mdot
.52295 .2663 Mdot
.62594 .64446 Mdot
.59375 .65078 Mdot
.65055 .67496 Mdot
.52364 .27753 Mdot
.31359 .39969 Mdot
.43951 .73271 Mdot
.59546 .31531 Mdot
.48009 .27914 Mdot
.69938 .40593 Mdot
.6988 .39406 Mdot
.72513 .59599 Mdot
.32439 .65904 Mdot
.63781 .64252 Mdot
.32531 .56424 Mdot
.33024 .62082 Mdot
.72048 .47834 Mdot
.6867 .57524 Mdot
.69077 .42085 Mdot
.33455 .63487 Mdot
.31172 .63388 Mdot
.61382 .28385 Mdot
.41082 .3354 Mdot
.64622 .35852 Mdot
.32784 .63035 Mdot
.58321 .3015 Mdot
.59437 .65427 Mdot
.40243 .31487 Mdot
.44911 .7129 Mdot
.69188 .41299 Mdot
.38448 .32623 Mdot
.41076 .31572 Mdot
.35215 .5055 Mdot
.60161 .67283 Mdot
.68835 .6147 Mdot
.30975 .37224 Mdot
.67872 .41308 Mdot
.66916 .38692 Mdot
.68602 .45835 Mdot
.3297 .64455 Mdot
.69609 .41504 Mdot
.41399 .36442 Mdot
.35559 .5463 Mdot
.50732 .72467 Mdot
.60369 .65431 Mdot
.31285 .61783 Mdot
.54025 .71856 Mdot
.71528 .48605 Mdot
.37051 .31274 Mdot
.30364 .64559 Mdot
.60408 .33489 Mdot
.71837 .57086 Mdot
.60421 .66194 Mdot
.31209 .38078 Mdot
.68773 .37886 Mdot
.28825 .45861 Mdot
.68817 .57294 Mdot
.321 .65231 Mdot
.70493 .48389 Mdot
.39198 .32032 Mdot
.39638 .34154 Mdot
.40594 .30241 Mdot
.6789 .57549 Mdot
.39735 .31876 Mdot
.5865 .68056 Mdot
.43262 .716 Mdot
.33246 .62222 Mdot
.70073 .4909 Mdot
.31564 .39978 Mdot
.42815 .35985 Mdot
.50325 .27327 Mdot
.41356 .70191 Mdot
.33818 .62161 Mdot
.74263 .49734 Mdot
.32005 .39831 Mdot
.34551 .52476 Mdot
.37894 .34112 Mdot
.45531 .70883 Mdot
.25949 .42759 Mdot
.41361 .34743 Mdot
.52413 .69705 Mdot
.71427 .58703 Mdot
.40243 .34841 Mdot
.67506 .59254 Mdot
.3478 .52576 Mdot
.41761 .71593 Mdot
.69598 .61484 Mdot
.66207 .60244 Mdot
.42487 .32156 Mdot
.66987 .37876 Mdot
.42355 .7237 Mdot
.32323 .54685 Mdot
.44636 .70552 Mdot
.38909 .32944 Mdot
.73494 .50695 Mdot
.57881 .31072 Mdot
.54201 .28237 Mdot
.50321 .29022 Mdot
.69701 .38129 Mdot
.67024 .40526 Mdot
.34693 .65199 Mdot
.48779 .70337 Mdot
.44236 .70316 Mdot
.70397 .50428 Mdot
.43496 .73884 Mdot
.34082 .53195 Mdot
.33088 .56006 Mdot
.59297 .32854 Mdot
.69012 .46885 Mdot
.55038 .69919 Mdot
.42106 .71171 Mdot
.33027 .41282 Mdot
.68014 .6051 Mdot
.33256 .53556 Mdot
.7414 .50167 Mdot
.6228 .30087 Mdot
.74316 .48352 Mdot
.32604 .54586 Mdot
.41087 .33481 Mdot
.68395 .41443 Mdot
.6882 .39258 Mdot
.60987 .29131 Mdot
.61148 .29391 Mdot
.32379 .5487 Mdot
.72092 .50844 Mdot
.43672 .73797 Mdot
.42405 .72985 Mdot
.39725 .32947 Mdot
.29754 .38332 Mdot
.31626 .54773 Mdot
.58216 .66441 Mdot
.45168 .33606 Mdot
.34727 .54752 Mdot
.69867 .60926 Mdot
.60762 .32464 Mdot
.50056 .2771 Mdot
.69113 .58215 Mdot
.50701 .27955 Mdot
.74228 .48527 Mdot
.32112 .59756 Mdot
.3076 .37554 Mdot
.50621 .74234 Mdot
.29883 .41698 Mdot
.38516 .32822 Mdot
.32996 .6472 Mdot
.54691 .28338 Mdot
.49389 .28865 Mdot
.52917 .74256 Mdot
.71231 .47266 Mdot
.39401 .36037 Mdot
.52181 .71447 Mdot
.33243 .41415 Mdot
.59667 .30365 Mdot
.4162 .35806 Mdot
.32226 .63859 Mdot
.60769 .67219 Mdot
.5481 .70203 Mdot
.41628 .35296 Mdot
.3864 .33528 Mdot
.42584 .34563 Mdot
.67071 .38232 Mdot
.63665 .65028 Mdot
.69943 .40167 Mdot
.49485 .27731 Mdot
.40277 .71135 Mdot
.31206 .63881 Mdot
.68801 .57851 Mdot
.35112 .55651 Mdot
.71492 .50659 Mdot
.65923 .63683 Mdot
.30841 .39707 Mdot
.41626 .31653 Mdot
.71027 .43499 Mdot
.39666 .36454 Mdot
.50002 .72266 Mdot
.51036 .70119 Mdot
.62108 .6774 Mdot
.69081 .45232 Mdot
.31348 .53423 Mdot
.63494 .34622 Mdot
.30594 .41296 Mdot
.69511 .39793 Mdot
.50161 .72182 Mdot
.32842 .52639 Mdot
.31789 .3994 Mdot
.69719 .39083 Mdot
.4368 .32367 Mdot
.72434 .50873 Mdot
.39211 .30315 Mdot
.55051 .7277 Mdot
.32887 .54529 Mdot
.4134 .3347 Mdot
.62833 .66269 Mdot
.68928 .39985 Mdot
.61189 .65115 Mdot
.41906 .3208 Mdot
.50615 .27142 Mdot
.69476 .40022 Mdot
.31493 .63942 Mdot
.6264 .6917 Mdot
.70798 .62279 Mdot
.63794 .65404 Mdot
.46938 .29906 Mdot
.51988 .27021 Mdot
.60698 .32994 Mdot
.71577 .49375 Mdot
.57088 .2944 Mdot
.33165 .39023 Mdot
.44191 .73144 Mdot
.61529 .30081 Mdot
.63418 .64916 Mdot
.57603 .2908 Mdot
.45313 .72381 Mdot
.67305 .37212 Mdot
.61029 .34582 Mdot
.34569 .56265 Mdot
.51336 .71075 Mdot
.38771 .34054 Mdot
.28523 .37503 Mdot
.43084 .71679 Mdot
.31175 .65566 Mdot
.41042 .32612 Mdot
.32617 .54123 Mdot
.71737 .50671 Mdot
.3692 .69528 Mdot
.40117 .70167 Mdot
.50778 .27547 Mdot
.66326 .5996 Mdot
.63296 .32468 Mdot
.34758 .39928 Mdot
.3508 .54954 Mdot
.32723 .537 Mdot
.52835 .71879 Mdot
.65905 .64319 Mdot
.68735 .38599 Mdot
.39978 .70799 Mdot
.51985 .28017 Mdot
.62211 .68395 Mdot
.62083 .6818 Mdot
.31771 .62533 Mdot
.41456 .33714 Mdot
.70353 .45715 Mdot
.34602 .51877 Mdot
.39992 .36286 Mdot
.31187 .66686 Mdot
.70123 .3908 Mdot
.52244 .27056 Mdot
.48896 .28283 Mdot
.60941 .68839 Mdot
.60047 .33707 Mdot
.52966 .717 Mdot
.3951 .32082 Mdot
.5033 .29056 Mdot
.68558 .38293 Mdot
.30389 .41349 Mdot
.33558 .56097 Mdot
.34661 .62094 Mdot
.59946 .33692 Mdot
.59238 .2876 Mdot
.43897 .73737 Mdot
.74375 .4934 Mdot
.46123 .31184 Mdot
.6829 .39986 Mdot
.61795 .67792 Mdot
.30885 .55143 Mdot
.32553 .48209 Mdot
.69856 .47879 Mdot
.50209 .71946 Mdot
.60754 .34058 Mdot
.36566 .31933 Mdot
.63325 .66353 Mdot
.3032 .41282 Mdot
.35119 .561 Mdot
.62606 .67601 Mdot
.524 .28544 Mdot
.6395 .66793 Mdot
.40624 .34268 Mdot
.67668 .37047 Mdot
.60326 .30555 Mdot
.69043 .46573 Mdot
.52959 .68555 Mdot
.3114 .39883 Mdot
.3213 .61753 Mdot
.53828 .70234 Mdot
.60128 .6538 Mdot
.51544 .71837 Mdot
.4306 .34293 Mdot
.51188 .71608 Mdot
.6152 .68173 Mdot
.32794 .52906 Mdot
.33813 .57779 Mdot
.49827 .2687 Mdot
.32641 .55622 Mdot
.34078 .65593 Mdot
.46051 .71646 Mdot
.3453 .55421 Mdot
.34842 .53586 Mdot
.32834 .63538 Mdot
.7096 .60188 Mdot
.30879 .66217 Mdot
.72412 .58849 Mdot
.71557 .60986 Mdot
.49606 .27883 Mdot
.33443 .41292 Mdot
.31883 .3738 Mdot
.30593 .65966 Mdot
.3444 .61605 Mdot
.6225 .64438 Mdot
.69755 .56122 Mdot
.68513 .3928 Mdot
.40449 .70534 Mdot
.46357 .31413 Mdot
.32926 .59293 Mdot
.61098 .30409 Mdot
.6217 .30185 Mdot
.3266 .56891 Mdot
.27265 .4479 Mdot
.34966 .64297 Mdot
.44616 .72061 Mdot
.3374 .52215 Mdot
.33409 .62929 Mdot
.63161 .32739 Mdot
.32863 .61285 Mdot
.53547 .72124 Mdot
.60888 .68512 Mdot
.29459 .41017 Mdot
.40768 .34572 Mdot
.41776 .71599 Mdot
.3167 .57917 Mdot
.59846 .66496 Mdot
.52675 .72147 Mdot
.60024 .29816 Mdot
.6811 .59302 Mdot
.44323 .71664 Mdot
.67544 .3777 Mdot
.33702 .70252 Mdot
.73923 .50394 Mdot
.67471 .3882 Mdot
.31153 .41219 Mdot
.62159 .33071 Mdot
.35826 .5312 Mdot
.57922 .28911 Mdot
.331 .6369 Mdot
.42116 .73234 Mdot
.30622 .37662 Mdot
.62022 .65387 Mdot
.69123 .41225 Mdot
.71103 .59126 Mdot
.60292 .64394 Mdot
.37951 .69415 Mdot
.63941 .35731 Mdot
.62882 .33683 Mdot
.43903 .34854 Mdot
.5894 .67428 Mdot
.34253 .65504 Mdot
.64829 .67653 Mdot
.70299 .58965 Mdot
.60581 .6667 Mdot
.3487 .6974 Mdot
.32328 .69478 Mdot
.3254 .6395 Mdot
.6269 .66579 Mdot
.62135 .334 Mdot
.31184 .37464 Mdot
.34035 .64233 Mdot
.39396 .32161 Mdot
.60943 .68874 Mdot
.60794 .33796 Mdot
.32459 .61387 Mdot
.58441 .30005 Mdot
.63172 .67323 Mdot
.62951 .31213 Mdot
.66538 .37702 Mdot
.6164 .30307 Mdot
.31614 .53754 Mdot
.33256 .52423 Mdot
.61679 .68267 Mdot
.67884 .59419 Mdot
.50125 .72417 Mdot
.34515 .55941 Mdot
.60471 .693 Mdot
.57087 .27685 Mdot
.7083 .55953 Mdot
.52114 .72799 Mdot
.33871 .6548 Mdot
.30609 .41839 Mdot
.39852 .70935 Mdot
.36187 .6972 Mdot
.39967 .70115 Mdot
.31145 .40199 Mdot
.49203 .69946 Mdot
.32468 .60621 Mdot
.35142 .6345 Mdot
.52225 .28175 Mdot
.34439 .567 Mdot
.39979 .31366 Mdot
.51743 .73232 Mdot
.32583 .70004 Mdot
.50411 .72408 Mdot
.63341 .65559 Mdot
.63003 .67737 Mdot
.58471 .27642 Mdot
.63105 .66622 Mdot
.39521 .31733 Mdot
.70459 .45773 Mdot
.60629 .64233 Mdot
.37973 .35017 Mdot
.38132 .32853 Mdot
.4059 .30698 Mdot
.41685 .34691 Mdot
.46091 .31382 Mdot
.51626 .26486 Mdot
.38242 .33428 Mdot
.59075 .68094 Mdot
.55582 .277 Mdot
.27934 .41334 Mdot
.70394 .45694 Mdot
.40767 .31489 Mdot
.34488 .56733 Mdot
.5205 .72549 Mdot
.67921 .61539 Mdot
.69423 .37699 Mdot
.42994 .33896 Mdot
.34215 .65192 Mdot
.60287 .68851 Mdot
.33426 .53506 Mdot
.32414 .41844 Mdot
.68838 .60324 Mdot
.59022 .29608 Mdot
.30484 .37813 Mdot
.42272 .33209 Mdot
.3012 .39574 Mdot
.58934 .32027 Mdot
.72386 .51293 Mdot
.34996 .56577 Mdot
.42037 .36367 Mdot
.33707 .40226 Mdot
.34747 .56654 Mdot
.59189 .68057 Mdot
.42979 .33405 Mdot
.32965 .65953 Mdot
.52499 .71549 Mdot
.70481 .57699 Mdot
.72248 .44389 Mdot
.35897 .53898 Mdot
.50813 .70321 Mdot
.60829 .68679 Mdot
.40484 .36076 Mdot
.58703 .29399 Mdot
.33916 .51438 Mdot
.7161 .47097 Mdot
.7245 .49188 Mdot
.5253 .28398 Mdot
.67691 .60811 Mdot
.56842 .29732 Mdot
.31436 .5377 Mdot
.41143 .31685 Mdot
.33939 .51546 Mdot
.58995 .27249 Mdot
.73585 .46771 Mdot
.70575 .57036 Mdot
.49305 .28002 Mdot
.31063 .68436 Mdot
.69824 .45239 Mdot
.5072 .27681 Mdot
.61074 .68479 Mdot
.689 .60909 Mdot
.68897 .58419 Mdot
.29445 .38217 Mdot
.58847 .30227 Mdot
.70105 .61476 Mdot
.7162 .59302 Mdot
.52422 .72566 Mdot
.32749 .56953 Mdot
.61801 .67447 Mdot
.52571 .27673 Mdot
.30375 .41484 Mdot
.51585 .28243 Mdot
.45005 .3394 Mdot
.68907 .40373 Mdot
.45625 .72269 Mdot
.41423 .70107 Mdot
.29661 .46503 Mdot
.31546 .63772 Mdot
.34462 .52029 Mdot
.62645 .64669 Mdot
.28542 .37296 Mdot
.28159 .3918 Mdot
.5921 .68203 Mdot
.71043 .57236 Mdot
.30044 .38566 Mdot
.32562 .58805 Mdot
.35164 .62436 Mdot
.31092 .68551 Mdot
.64008 .65043 Mdot
.58269 .68125 Mdot
.71746 .47957 Mdot
.61146 .68839 Mdot
.54997 .27316 Mdot
.62054 .34677 Mdot
.62375 .31748 Mdot
.69089 .39638 Mdot
.35967 .54553 Mdot
.63092 .33612 Mdot
.53222 .70543 Mdot
.54563 .27271 Mdot
.51065 .70791 Mdot
.5157 .29182 Mdot
.34735 .55843 Mdot
.7059 .41959 Mdot
.68634 .47456 Mdot
.51319 .73005 Mdot
.32304 .58833 Mdot
.30434 .40857 Mdot
.62681 .64619 Mdot
.70838 .50445 Mdot
.6336 .64276 Mdot
.32774 .54244 Mdot
.61658 .6649 Mdot
.68764 .40991 Mdot
.73492 .50836 Mdot
.53055 .72742 Mdot
.52951 .70794 Mdot
.63377 .63942 Mdot
.59944 .69462 Mdot
.58571 .29449 Mdot
.60327 .66873 Mdot
.71161 .60837 Mdot
.51081 .7119 Mdot
.6074 .34224 Mdot
.38751 .69696 Mdot
.62502 .652 Mdot
.29974 .37405 Mdot
.69149 .60576 Mdot
.2979 .38743 Mdot
.69204 .61663 Mdot
.49802 .26722 Mdot
.35227 .534 Mdot
.49772 .27961 Mdot
.331 .40362 Mdot
.63663 .34138 Mdot
.70986 .50874 Mdot
.40795 .3205 Mdot
.71972 .50071 Mdot
.44325 .72671 Mdot
.63621 .64354 Mdot
.70023 .46271 Mdot
.38307 .69736 Mdot
.33315 .52069 Mdot
.69074 .61674 Mdot
.59799 .29876 Mdot
.51339 .28658 Mdot
.43477 .72205 Mdot
.6848 .57308 Mdot
.57901 .27887 Mdot
.54028 .6909 Mdot
.54543 .27954 Mdot
.51233 .73165 Mdot
.68225 .48728 Mdot
.63615 .67148 Mdot
.51549 .28737 Mdot
.44726 .72377 Mdot
.71931 .59586 Mdot
.62396 .34262 Mdot
.72536 .50795 Mdot
.71479 .47038 Mdot
.32465 .52323 Mdot
.69178 .45634 Mdot
.60801 .30158 Mdot
.74386 .48707 Mdot
.7028 .6132 Mdot
.73714 .46878 Mdot
.30779 .40049 Mdot
.61677 .33164 Mdot
.39592 .32886 Mdot
.52815 .68649 Mdot
.57429 .29717 Mdot
.28231 .45574 Mdot
.47409 .28834 Mdot
.56553 .27328 Mdot
.68608 .60389 Mdot
.67996 .57512 Mdot
.54013 .69782 Mdot
.43182 .71959 Mdot
.59859 .30493 Mdot
.55332 .27462 Mdot
.31371 .67509 Mdot
.41235 .32228 Mdot
.52989 .28499 Mdot
.31831 .63785 Mdot
.51918 .71728 Mdot
.68334 .39636 Mdot
.31134 .63634 Mdot
.7203 .57899 Mdot
.33561 .62606 Mdot
.71318 .50464 Mdot
.62328 .29381 Mdot
.32693 .54185 Mdot
.30846 .41251 Mdot
.72753 .48615 Mdot
.72703 .48977 Mdot
.63622 .3562 Mdot
.67638 .60766 Mdot
.6111 .64817 Mdot
.58668 .29959 Mdot
.51649 .71068 Mdot
.40615 .3259 Mdot
.32345 .64041 Mdot
.61186 .65954 Mdot
.6351 .64446 Mdot
.61731 .33189 Mdot
.32412 .60187 Mdot
.70714 .49192 Mdot
.56845 .27212 Mdot
.50353 .71254 Mdot
.62331 .31983 Mdot
.38139 .30422 Mdot
.62182 .35076 Mdot
.58687 .68358 Mdot
.42233 .31109 Mdot
.61511 .66342 Mdot
.38306 .34323 Mdot
.35901 .33219 Mdot
.31295 .4126 Mdot
.62991 .32085 Mdot
.66199 .60709 Mdot
.49608 .2827 Mdot
.34863 .55023 Mdot
.32225 .64898 Mdot
.58265 .31477 Mdot
.31354 .39724 Mdot
.25971 .39698 Mdot
.27482 .40038 Mdot
.67936 .59919 Mdot
.5253 .73155 Mdot
.47574 .28506 Mdot
.48187 .27611 Mdot
.68038 .40689 Mdot
.59861 .68321 Mdot
.37989 .32982 Mdot
.70819 .50935 Mdot
.72757 .49426 Mdot
.31176 .39047 Mdot
.48113 .27937 Mdot
.60956 .66972 Mdot
.69293 .48563 Mdot
.72027 .59397 Mdot
.35318 .64033 Mdot
.41584 .35184 Mdot
.43329 .35728 Mdot
.38156 .34514 Mdot
.4269 .71195 Mdot
.69169 .46492 Mdot
.34248 .53955 Mdot
.33032 .41574 Mdot
.68879 .39669 Mdot
.29495 .41616 Mdot
.50178 .71633 Mdot
.62295 .29446 Mdot
.73282 .56999 Mdot
.32214 .52524 Mdot
.35602 .55449 Mdot
.6916 .40442 Mdot
.31942 .57776 Mdot
.60878 .68171 Mdot
.70998 .60592 Mdot
.60334 .32921 Mdot
.355 .69728 Mdot
.34665 .63704 Mdot
.34098 .64498 Mdot
.58103 .30665 Mdot
.41404 .34207 Mdot
.52852 .27074 Mdot
.33935 .64822 Mdot
.71718 .48547 Mdot
.5039 .72251 Mdot
.70161 .45211 Mdot
.31426 .54455 Mdot
.35384 .54001 Mdot
.52971 .70605 Mdot
.51215 .7215 Mdot
.71987 .50013 Mdot
.41691 .34267 Mdot
.42543 .32623 Mdot
.63402 .65064 Mdot
.34347 .56307 Mdot
.31196 .67899 Mdot
.34698 .51912 Mdot
.30523 .40872 Mdot
.36274 .70353 Mdot
.45361 .7264 Mdot
.41921 .72593 Mdot
.30323 .66264 Mdot
.3445 .52755 Mdot
.68904 .4079 Mdot
.6862 .56823 Mdot
.70408 .48785 Mdot
.68808 .36996 Mdot
.58291 .28004 Mdot
.29244 .41458 Mdot
.3238 .54981 Mdot
.32035 .38489 Mdot
.32397 .68912 Mdot
.34316 .38848 Mdot
.41808 .71138 Mdot
.43607 .73659 Mdot
.29132 .38079 Mdot
.3489 .51778 Mdot
.59356 .32698 Mdot
.63058 .35033 Mdot
.52622 .70224 Mdot
.31516 .54407 Mdot
.67415 .4005 Mdot
.71391 .46258 Mdot
.51609 .26768 Mdot
.53611 .27401 Mdot
.32372 .41874 Mdot
.36804 .31763 Mdot
.5106 .7165 Mdot
.32092 .53647 Mdot
.41938 .33419 Mdot
.57639 .31047 Mdot
.38183 .3393 Mdot
.50613 .26807 Mdot
.7062 .50233 Mdot
.70365 .46803 Mdot
.33282 .56747 Mdot
.26192 .4361 Mdot
.70574 .59084 Mdot
.67926 .5767 Mdot
.71542 .46234 Mdot
.63295 .32486 Mdot
.39946 .34551 Mdot
.65556 .65928 Mdot
.60275 .68518 Mdot
.33573 .39873 Mdot
.33598 .51653 Mdot
.6246 .3459 Mdot
.613 .69307 Mdot
.33066 .40966 Mdot
.40093 .69706 Mdot
.55976 .27408 Mdot
.33606 .543 Mdot
.5174 .69693 Mdot
.70767 .56703 Mdot
.42725 .71962 Mdot
.62376 .65199 Mdot
.72061 .47958 Mdot
.69793 .49315 Mdot
.35486 .5421 Mdot
.73405 .58179 Mdot
.59275 .6562 Mdot
.69191 .47956 Mdot
.2935 .38136 Mdot
.39946 .32456 Mdot
.29957 .41817 Mdot
.6052 .33384 Mdot
.31098 .41289 Mdot
.57507 .29344 Mdot
.50994 .27766 Mdot
.61668 .67149 Mdot
.3184 .39936 Mdot
.45834 .71772 Mdot
.39344 .3249 Mdot
.34607 .40246 Mdot
.41307 .71548 Mdot
.49862 .71388 Mdot
.60788 .31316 Mdot
.32501 .38705 Mdot
.36064 .52602 Mdot
.71252 .44039 Mdot
.67474 .37021 Mdot
.70996 .50791 Mdot
.40472 .344 Mdot
.6193 .32729 Mdot
.60865 .66333 Mdot
.31112 .667 Mdot
.57758 .68971 Mdot
.33209 .66051 Mdot
.33652 .55746 Mdot
.58575 .66756 Mdot
.60882 .66249 Mdot
.35605 .53872 Mdot
.31792 .63381 Mdot
.39761 .32136 Mdot
.72423 .4837 Mdot
.68415 .60158 Mdot
.6861 .59694 Mdot
.59825 .29105 Mdot
.61794 .68411 Mdot
.45699 .32215 Mdot
.70641 .5058 Mdot
.39782 .36432 Mdot
.7128 .49433 Mdot
.25827 .40781 Mdot
.56533 .27817 Mdot
.65983 .61938 Mdot
.67842 .61255 Mdot
.531 .71918 Mdot
.6169 .67415 Mdot
.30609 .39745 Mdot
.62321 .68081 Mdot
.62343 .66736 Mdot
.34371 .56461 Mdot
.42117 .33716 Mdot
.38475 .33557 Mdot
.42381 .71015 Mdot
.70492 .59112 Mdot
.34961 .52953 Mdot
.40691 .71225 Mdot
.35265 .55581 Mdot
.42652 .71789 Mdot
.70183 .61027 Mdot
.316 .57552 Mdot
.62114 .6761 Mdot
.72238 .6043 Mdot
.45054 .33967 Mdot
.39066 .32775 Mdot
.37851 .3343 Mdot
.66587 .36063 Mdot
.32769 .65888 Mdot
.50266 .27848 Mdot
.51595 .71304 Mdot
.41632 .32196 Mdot
.46327 .71611 Mdot
.32975 .38436 Mdot
.33244 .63653 Mdot
.41626 .33071 Mdot
.59405 .2982 Mdot
.53142 .71721 Mdot
.32995 .6475 Mdot
.40887 .34683 Mdot
.61225 .67346 Mdot
.69977 .57892 Mdot
.5974 .67896 Mdot
.30231 .39014 Mdot
.71031 .50036 Mdot
.51711 .71503 Mdot
.60156 .33072 Mdot
.49925 .27726 Mdot
.61406 .66374 Mdot
.61823 .29439 Mdot
.70815 .46539 Mdot
.33283 .64913 Mdot
.72319 .49006 Mdot
.32125 .38038 Mdot
.68983 .60244 Mdot
.52686 .71257 Mdot
.54753 .71122 Mdot
.62969 .67786 Mdot
.40156 .3172 Mdot
.27951 .40413 Mdot
.62908 .3044 Mdot
.69861 .57077 Mdot
.70801 .50112 Mdot
.60177 .28943 Mdot
.53224 .71018 Mdot
.34059 .38173 Mdot
.31337 .62564 Mdot
.32538 .56359 Mdot
.50132 .69322 Mdot
.32829 .57501 Mdot
.49438 .27657 Mdot
.63045 .64695 Mdot
.50863 .72785 Mdot
.43278 .7346 Mdot
.25726 .42377 Mdot
.28916 .41752 Mdot
.33703 .52824 Mdot
.45268 .70919 Mdot
.33051 .59199 Mdot
.66228 .60111 Mdot
.43124 .72217 Mdot
.58243 .27376 Mdot
.43459 .35588 Mdot
.68728 .36936 Mdot
.41229 .32646 Mdot
.62298 .29556 Mdot
.3199 .63408 Mdot
.32052 .61109 Mdot
.71576 .55973 Mdot
.49991 .71581 Mdot
.70004 .47738 Mdot
.3195 .58521 Mdot
.59932 .29714 Mdot
.49331 .28918 Mdot
.31774 .52122 Mdot
.60574 .68136 Mdot
.7043 .43309 Mdot
.41968 .3302 Mdot
.37829 .33666 Mdot
.33209 .40339 Mdot
.59796 .27741 Mdot
.40466 .30179 Mdot
.70824 .492 Mdot
.35924 .52222 Mdot
.45417 .72591 Mdot
.71651 .43576 Mdot
.62851 .6833 Mdot
.66973 .38771 Mdot
.25801 .40987 Mdot
.34444 .54486 Mdot
.70761 .5979 Mdot
.6331 .66422 Mdot
.33638 .4045 Mdot
.50072 .27057 Mdot
.52308 .27869 Mdot
.27211 .44599 Mdot
.42528 .3187 Mdot
.57569 .30876 Mdot
.40042 .30332 Mdot
.51932 .70872 Mdot
.41668 .71482 Mdot
.67204 .36905 Mdot
.34613 .55464 Mdot
.71691 .6172 Mdot
.6335 .65273 Mdot
.33653 .52185 Mdot
.28817 .40608 Mdot
.65757 .64279 Mdot
.54185 .70846 Mdot
.35369 .50913 Mdot
.62123 .33466 Mdot
.34431 .55117 Mdot
.45929 .32294 Mdot
.39606 .36266 Mdot
.338 .57253 Mdot
.58692 .29595 Mdot
.42124 .31034 Mdot
.28406 .40232 Mdot
.63946 .65328 Mdot
.41093 .32715 Mdot
.50261 .71274 Mdot
.32128 .64426 Mdot
.29198 .38266 Mdot
.52566 .70712 Mdot
.58018 .68271 Mdot
.37491 .33373 Mdot
.62332 .31425 Mdot
.71206 .57561 Mdot
.34933 .54208 Mdot
.40012 .32223 Mdot
.32654 .52759 Mdot
.61763 .63549 Mdot
.32624 .5606 Mdot
.73459 .50643 Mdot
.70516 .56446 Mdot
.70894 .48261 Mdot
.52773 .71905 Mdot
.33599 .54546 Mdot
.40279 .30378 Mdot
.39529 .3449 Mdot
.34271 .65158 Mdot
.61527 .66199 Mdot
.62783 .66339 Mdot
.60006 .67413 Mdot
.60574 .29441 Mdot
.3207 .68558 Mdot
.71116 .47775 Mdot
.41786 .33908 Mdot
.69243 .45465 Mdot
.43245 .69948 Mdot
.30009 .39252 Mdot
.72375 .45141 Mdot
.3353 .65298 Mdot
.68155 .57918 Mdot
.34593 .61051 Mdot
.67405 .57634 Mdot
.66351 .36035 Mdot
.67011 .39003 Mdot
.69889 .59234 Mdot
.33963 .52502 Mdot
.43002 .7127 Mdot
.45286 .72968 Mdot
.69172 .47373 Mdot
.42604 .34186 Mdot
.46732 .30611 Mdot
.61891 .34391 Mdot
.34332 .38525 Mdot
.69545 .40032 Mdot
.69698 .42956 Mdot
.52109 .72803 Mdot
.70766 .57706 Mdot
.70316 .49407 Mdot
.7213 .51036 Mdot
.60728 .30419 Mdot
.52687 .72354 Mdot
.33213 .54469 Mdot
.39453 .31682 Mdot
.67728 .38097 Mdot
.34409 .64175 Mdot
.49929 .72224 Mdot
.51531 .26601 Mdot
.60321 .66265 Mdot
.72343 .44268 Mdot
.41916 .69574 Mdot
.60107 .6535 Mdot
.54409 .28025 Mdot
.7017 .61407 Mdot
.34708 .53071 Mdot
.40074 .33945 Mdot
.62289 .29951 Mdot
.32028 .65306 Mdot
.49139 .28026 Mdot
.69701 .4761 Mdot
.71132 .43374 Mdot
.42293 .69948 Mdot
.5467 .275 Mdot
.35466 .53189 Mdot
.54089 .70235 Mdot
.32155 .4111 Mdot
.69508 .48222 Mdot
.72209 .57102 Mdot
.32798 .52276 Mdot
.5893 .28822 Mdot
.61155 .34511 Mdot
.62359 .65569 Mdot
.59863 .68164 Mdot
.66142 .61177 Mdot
.39541 .33103 Mdot
.60047 .28418 Mdot
.39887 .32268 Mdot
.35632 .51231 Mdot
.69193 .48186 Mdot
.28341 .40103 Mdot
.62919 .31072 Mdot
.69349 .3912 Mdot
.49882 .71348 Mdot
.67613 .60148 Mdot
.51624 .68795 Mdot
.5323 .70356 Mdot
.60041 .27941 Mdot
.29537 .39845 Mdot
.4254 .72382 Mdot
.53619 .72328 Mdot
.29496 .38696 Mdot
.60441 .29705 Mdot
.70114 .58301 Mdot
.63497 .66155 Mdot
.69212 .56441 Mdot
.45465 .71926 Mdot
.63357 .69099 Mdot
.33367 .61905 Mdot
.33755 .57603 Mdot
.68547 .62098 Mdot
.31146 .66046 Mdot
.7099 .50736 Mdot
.69253 .56965 Mdot
.42678 .71868 Mdot
.50077 .72909 Mdot
.33685 .62364 Mdot
.32541 .60242 Mdot
.50821 .72099 Mdot
.32763 .65898 Mdot
.58424 .67381 Mdot
.6352 .6447 Mdot
.42165 .72597 Mdot
.69134 .48756 Mdot
.30224 .40123 Mdot
.71085 .6102 Mdot
.34176 .55266 Mdot
.5832 .67244 Mdot
.41643 .72082 Mdot
.73466 .50585 Mdot
.50619 .7187 Mdot
.62175 .29225 Mdot
.31502 .62758 Mdot
.61508 .34863 Mdot
.54571 .71317 Mdot
.58252 .67112 Mdot
.67117 .37496 Mdot
.54253 .70944 Mdot
.55842 .26893 Mdot
.31908 .58579 Mdot
.39745 .34025 Mdot
.31136 .41472 Mdot
.41495 .30676 Mdot
.71924 .50289 Mdot
.32435 .65594 Mdot
.3141 .64185 Mdot
.31861 .56386 Mdot
.35617 .51189 Mdot
.3916 .32633 Mdot
.30703 .37172 Mdot
.62194 .63462 Mdot
.33015 .64141 Mdot
.63141 .33972 Mdot
.71334 .58828 Mdot
.32505 .62911 Mdot
.45396 .73338 Mdot
.52145 .69717 Mdot
.70363 .59145 Mdot
.67446 .6049 Mdot
.46369 .31372 Mdot
.31625 .40523 Mdot
.35326 .55106 Mdot
.29249 .37493 Mdot
.51953 .71348 Mdot
.71688 .49633 Mdot
.31707 .56197 Mdot
.56586 .27861 Mdot
.43798 .72534 Mdot
.606 .29711 Mdot
.35203 .56661 Mdot
.68668 .60609 Mdot
.69873 .49297 Mdot
.52212 .28477 Mdot
.52744 .28468 Mdot
.34886 .63336 Mdot
.47799 .28175 Mdot
.30769 .38718 Mdot
.30764 .39248 Mdot
.70121 .4939 Mdot
.34192 .52143 Mdot
.43314 .72592 Mdot
.50647 .741 Mdot
.32152 .65812 Mdot
.35969 .54948 Mdot
.69082 .38556 Mdot
.69182 .39576 Mdot
.62827 .31103 Mdot
.35738 .5437 Mdot
.34123 .6364 Mdot
.69877 .59931 Mdot
.29111 .41612 Mdot
.59514 .28022 Mdot
.32928 .4124 Mdot
.58539 .30855 Mdot
.32698 .69948 Mdot
.42153 .34487 Mdot
.3044 .39151 Mdot
.69538 .41261 Mdot
.681 .58548 Mdot
.39279 .32083 Mdot
.60703 .3188 Mdot
.61112 .28926 Mdot
.32513 .63129 Mdot
.6311 .68172 Mdot
.70794 .60827 Mdot
.30063 .38863 Mdot
.71782 .46559 Mdot
.53236 .70521 Mdot
.38062 .3439 Mdot
.25747 .41475 Mdot
.59601 .28531 Mdot
.66575 .59041 Mdot
.53551 .68693 Mdot
.33251 .55457 Mdot
.69898 .57972 Mdot
.33167 .55033 Mdot
.60366 .66927 Mdot
.71737 .60615 Mdot
.31488 .53123 Mdot
.5955 .66859 Mdot
.56914 .29543 Mdot
.50084 .29239 Mdot
.50483 .72845 Mdot
.66573 .39481 Mdot
.51717 .71194 Mdot
.53166 .27353 Mdot
.34485 .60986 Mdot
.31947 .64801 Mdot
.34005 .55495 Mdot
.35281 .37679 Mdot
.30329 .653 Mdot
.38974 .34933 Mdot
.39678 .33958 Mdot
.70423 .58155 Mdot
.41234 .30506 Mdot
.42636 .71309 Mdot
.32123 .39671 Mdot
.60453 .32936 Mdot
.34725 .62585 Mdot
.29667 .39214 Mdot
.63583 .6569 Mdot
.53635 .71895 Mdot
.69129 .62185 Mdot
.62609 .35219 Mdot
.41306 .33875 Mdot
.69806 .47768 Mdot
.39478 .70244 Mdot
.59295 .29284 Mdot
.68183 .38809 Mdot
.41587 .70394 Mdot
.62283 .29243 Mdot
.69859 .50075 Mdot
.49658 .29221 Mdot
.67934 .39409 Mdot
.70728 .45765 Mdot
.44685 .71771 Mdot
.32205 .39696 Mdot
.41786 .30651 Mdot
.29853 .37141 Mdot
.6711 .38061 Mdot
.54385 .28533 Mdot
.61697 .32026 Mdot
.42914 .73307 Mdot
.63581 .68864 Mdot
.40938 .31491 Mdot
.35887 .5429 Mdot
.68725 .39883 Mdot
.31902 .69072 Mdot
.41719 .30649 Mdot
.70557 .4699 Mdot
.54615 .71196 Mdot
.35952 .70224 Mdot
.4003 .33282 Mdot
.38476 .32853 Mdot
.32525 .38969 Mdot
.51537 .27287 Mdot
.69784 .61366 Mdot
.33415 .38751 Mdot
.32325 .57723 Mdot
.34805 .5565 Mdot
.71834 .50089 Mdot
.41137 .32839 Mdot
.71158 .47264 Mdot
.28923 .41037 Mdot
.30976 .37211 Mdot
.63852 .65409 Mdot
.602 .67784 Mdot
.39092 .30341 Mdot
.30226 .66367 Mdot
.30934 .62348 Mdot
.71948 .5637 Mdot
.6919 .61074 Mdot
.32163 .59571 Mdot
.27756 .39498 Mdot
.32889 .39177 Mdot
.54374 .70516 Mdot
.40944 .71752 Mdot
.51045 .72399 Mdot
.40711 .69795 Mdot
.64843 .35875 Mdot
.52942 .71616 Mdot
.62609 .30025 Mdot
.40547 .69749 Mdot
.68871 .41994 Mdot
.5259 .70125 Mdot
.32761 .55383 Mdot
.59223 .31323 Mdot
.34636 .56942 Mdot
.61107 .33643 Mdot
.35075 .5348 Mdot
.59197 .27274 Mdot
.60152 .33052 Mdot
.46773 .30286 Mdot
.37857 .6998 Mdot
.38845 .34759 Mdot
.28399 .39049 Mdot
.42807 .35883 Mdot
.32376 .61587 Mdot
.69811 .58567 Mdot
.64007 .68675 Mdot
.33152 .55571 Mdot
.61016 .30726 Mdot
.69748 .46999 Mdot
.54924 .70477 Mdot
.31744 .54808 Mdot
.52284 .70482 Mdot
.67583 .60157 Mdot
.61952 .33351 Mdot
.31555 .4159 Mdot
.5001 .26447 Mdot
.5292 .27428 Mdot
.56372 .27883 Mdot
.34806 .50098 Mdot
.52226 .69814 Mdot
.45938 .32259 Mdot
.60794 .65424 Mdot
.26112 .39435 Mdot
.62989 .66843 Mdot
.40983 .32422 Mdot
.33001 .40136 Mdot
.36807 .69688 Mdot
.71401 .59636 Mdot
.58153 .30755 Mdot
.33722 .54255 Mdot
.416 .34615 Mdot
.29926 .37137 Mdot
.71961 .57981 Mdot
.29164 .38232 Mdot
.60312 .31954 Mdot
.40185 .32682 Mdot
.31866 .6872 Mdot
.31021 .55787 Mdot
.41758 .73197 Mdot
.33813 .54631 Mdot
.29962 .38669 Mdot
.62887 .68424 Mdot
.52459 .70405 Mdot
.67716 .38735 Mdot
.43131 .7186 Mdot
.35876 .55493 Mdot
.54295 .27213 Mdot
.6793 .60372 Mdot
.3097 .40098 Mdot
.68618 .39898 Mdot
.31568 .40702 Mdot
.38007 .33955 Mdot
.60517 .67336 Mdot
.37929 .33939 Mdot
.50003 .71815 Mdot
.70214 .49027 Mdot
.70979 .60581 Mdot
.52613 .2685 Mdot
.42695 .32267 Mdot
.58365 .31732 Mdot
.36841 .70128 Mdot
.62066 .6591 Mdot
.68691 .37639 Mdot
.49733 .26554 Mdot
.73054 .50806 Mdot
.41461 .72666 Mdot
.72156 .47393 Mdot
.33225 .55644 Mdot
.69643 .56188 Mdot
.69695 .45209 Mdot
.52764 .28254 Mdot
.45336 .71021 Mdot
.38359 .35108 Mdot
.34276 .51716 Mdot
.74047 .47701 Mdot
.68699 .47465 Mdot
.61712 .67963 Mdot
.69622 .40253 Mdot
.33337 .59392 Mdot
.39522 .32467 Mdot
.33804 .56692 Mdot
.67221 .38941 Mdot
.69579 .39249 Mdot
.5125 .28406 Mdot
.34057 .53892 Mdot
.30807 .40913 Mdot
.62249 .29438 Mdot
.60845 .34354 Mdot
.62325 .30461 Mdot
.59625 .65519 Mdot
.42393 .32925 Mdot
.39509 .33297 Mdot
.3451 .61334 Mdot
.71397 .47115 Mdot
.3897 .34852 Mdot
.32448 .64383 Mdot
.32201 .62436 Mdot
.6951 .5639 Mdot
.59807 .31378 Mdot
.35611 .55953 Mdot
.50639 .73046 Mdot
.40435 .34759 Mdot
.58743 .3017 Mdot
.61162 .67196 Mdot
.53292 .27089 Mdot
.329 .65208 Mdot
.51523 .72778 Mdot
.63274 .67519 Mdot
.57749 .67998 Mdot
.30274 .65537 Mdot
.33057 .54927 Mdot
.72462 .4933 Mdot
.51285 .66665 Mdot
.38523 .59694 Mdot
.44336 .49058 Mdot
.41436 .31489 Mdot
.59727 .56135 Mdot
.47267 .65337 Mdot
.51473 .74053 Mdot
.49844 .58578 Mdot
.44916 .70309 Mdot
.5432 .61818 Mdot
.63577 .41829 Mdot
.47453 .55313 Mdot
.52977 .29578 Mdot
.66605 .49006 Mdot
.55911 .70143 Mdot
.32816 .455 Mdot
.67595 .54502 Mdot
.51025 .63219 Mdot
.67013 .49195 Mdot
.60294 .44934 Mdot
.58304 .34092 Mdot
.63823 .35859 Mdot
.60862 .40731 Mdot
.36112 .52417 Mdot
.5397 .6471 Mdot
.3988 .62014 Mdot
.6421 .591 Mdot
.65848 .40653 Mdot
.50931 .7341 Mdot
.40978 .39256 Mdot
.6159 .56833 Mdot
.45831 .38945 Mdot
.42596 .67445 Mdot
.62952 .4439 Mdot
.39703 .6132 Mdot
.37661 .43526 Mdot
.45293 .69989 Mdot
.54809 .58698 Mdot
.5971 .58976 Mdot
.43505 .64983 Mdot
.6248 .55207 Mdot
.58064 .2849 Mdot
.62354 .68962 Mdot
.67927 .51706 Mdot
.46526 .36927 Mdot
.64415 .54195 Mdot
.49779 .58683 Mdot
.39199 .30521 Mdot
.59862 .55421 Mdot
.3322 .68114 Mdot
.67425 .57178 Mdot
.64697 .46838 Mdot
.65875 .41755 Mdot
.44554 .65964 Mdot
.66796 .43579 Mdot
.36792 .68084 Mdot
.51439 .63423 Mdot
.4783 .65668 Mdot
.60552 .44483 Mdot
.54537 .35125 Mdot
.68243 .60975 Mdot
.33548 .46034 Mdot
.56072 .42987 Mdot
.40462 .48381 Mdot
.653 .48912 Mdot
.45175 .68596 Mdot
.6425 .6329 Mdot
.70497 .55374 Mdot
.59795 .36435 Mdot
.47436 .34542 Mdot
.6177 .40333 Mdot
.56987 .43152 Mdot
.64679 .53243 Mdot
.37485 .62322 Mdot
.58031 .60788 Mdot
.58303 .37493 Mdot
.52605 .67945 Mdot
.36401 .39528 Mdot
.55031 .51595 Mdot
.44084 .36082 Mdot
.46143 .66374 Mdot
.61338 .45327 Mdot
.45117 .58459 Mdot
.61031 .5264 Mdot
.35842 .66748 Mdot
.45282 .35778 Mdot
.54209 .64571 Mdot
.55643 .37821 Mdot
.66934 .5508 Mdot
.48547 .67504 Mdot
.66056 .43856 Mdot
.38769 .36468 Mdot
.44812 .42802 Mdot
.41518 .38055 Mdot
.50632 .57889 Mdot
.37778 .41931 Mdot
.62955 .44113 Mdot
.6794 .49292 Mdot
.58758 .32935 Mdot
.62427 .61086 Mdot
.47762 .37398 Mdot
.71864 .61259 Mdot
.56407 .32069 Mdot
.48968 .61351 Mdot
.60998 .62105 Mdot
.41064 .38372 Mdot
.60734 .37142 Mdot
.59836 .51681 Mdot
.59851 .42152 Mdot
.595 .5855 Mdot
.56913 .61427 Mdot
.6803 .54693 Mdot
.37521 .31092 Mdot
.57203 .66054 Mdot
.44629 .394 Mdot
.62984 .38439 Mdot
.34597 .42566 Mdot
.31496 .67098 Mdot
.47157 .39696 Mdot
.48076 .69849 Mdot
.50721 .47881 Mdot
.65654 .57676 Mdot
.42719 .37069 Mdot
.50457 .73428 Mdot
.52964 .67342 Mdot
.6075 .40459 Mdot
.36165 .48391 Mdot
.66481 .57771 Mdot
.67215 .48845 Mdot
.61267 .35615 Mdot
.47314 .67181 Mdot
.46227 .32851 Mdot
.37057 .56152 Mdot
.40284 .45521 Mdot
.65136 .36656 Mdot
.39582 .47824 Mdot
.43413 .45227 Mdot
.4941 .30167 Mdot
.62161 .62247 Mdot
.43339 .436 Mdot
.49104 .6952 Mdot
.57557 .36937 Mdot
.63028 .41285 Mdot
.52976 .66031 Mdot
.28408 .43108 Mdot
.40042 .40887 Mdot
.45537 .45666 Mdot
.60066 .5388 Mdot
.52045 .74292 Mdot
.40703 .59204 Mdot
.62546 .4326 Mdot
.51491 .40866 Mdot
.53161 .3584 Mdot
.67032 .47975 Mdot
.72248 .60888 Mdot
.49764 .38722 Mdot
.43335 .57532 Mdot
.5588 .68477 Mdot
.50145 .42855 Mdot
.65274 .59814 Mdot
.48623 .41803 Mdot
.40844 .39027 Mdot
.63277 .36271 Mdot
.59451 .38116 Mdot
.65158 .53221 Mdot
.66185 .42069 Mdot
.57429 .63087 Mdot
.58093 .62954 Mdot
.50216 .36462 Mdot
.6733 .54041 Mdot
.62229 .47141 Mdot
.6963 .55446 Mdot
.51461 .61842 Mdot
.42189 .64714 Mdot
.3842 .5829 Mdot
.44658 .53662 Mdot
.27663 .39016 Mdot
.37572 .44252 Mdot
.47458 .67457 Mdot
.2672 .41898 Mdot
.39207 .51411 Mdot
.39306 .61066 Mdot
.37592 .34323 Mdot
.37439 .57829 Mdot
.34647 .68603 Mdot
.57204 .53537 Mdot
.60214 .37987 Mdot
.45729 .47508 Mdot
.37849 .56337 Mdot
.64933 .58246 Mdot
.44799 .69799 Mdot
.42838 .37101 Mdot
.49063 .32587 Mdot
.49961 .65033 Mdot
.55205 .66264 Mdot
.672 .40961 Mdot
.69499 .43941 Mdot
.51135 .30184 Mdot
.65219 .53136 Mdot
.64668 .63669 Mdot
.49332 .27239 Mdot
.60769 .48328 Mdot
.44548 .5965 Mdot
.39222 .64945 Mdot
.44635 .37243 Mdot
.57894 .55121 Mdot
.34261 .41117 Mdot
.46226 .62538 Mdot
.43866 .47028 Mdot
.39194 .40464 Mdot
.36063 .419 Mdot
.35342 .43659 Mdot
.6781 .52373 Mdot
.36742 .44693 Mdot
.39309 .38588 Mdot
.32845 .689 Mdot
.56623 .469 Mdot
.53772 .73192 Mdot
.41082 .54477 Mdot
.56048 .32666 Mdot
.56085 .41819 Mdot
.56692 .60856 Mdot
.44587 .66067 Mdot
.37648 .37874 Mdot
.34538 .68451 Mdot
.6228 .53412 Mdot
.44124 .40121 Mdot
.56737 .38984 Mdot
.46766 .39265 Mdot
.51153 .35724 Mdot
.52555 .58129 Mdot
.67227 .49101 Mdot
.26547 .4361 Mdot
.55088 .34879 Mdot
.63443 .57683 Mdot
.50156 .68389 Mdot
.56455 .32698 Mdot
.59411 .63384 Mdot
.60761 .60471 Mdot
.45814 .6489 Mdot
.41665 .58636 Mdot
.47065 .50991 Mdot
.55437 .58857 Mdot
.38989 .44338 Mdot
.54218 .39379 Mdot
.63364 .3596 Mdot
.5183 .31275 Mdot
.46722 .49492 Mdot
.56084 .46368 Mdot
.37969 .53723 Mdot
.6011 .36121 Mdot
.54459 .55548 Mdot
.38215 .60202 Mdot
.45627 .47167 Mdot
.51331 .64328 Mdot
.65142 .61344 Mdot
.42603 .58043 Mdot
.32416 .66652 Mdot
.46356 .36455 Mdot
.5061 .2983 Mdot
.5058 .35204 Mdot
.54232 .65398 Mdot
.67783 .44312 Mdot
.65852 .51408 Mdot
.3818 .51255 Mdot
.38352 .64216 Mdot
.51288 .54587 Mdot
.39202 .6754 Mdot
.72465 .46779 Mdot
.65252 .63214 Mdot
.56272 .63752 Mdot
.36304 .54946 Mdot
.45309 .55279 Mdot
.54922 .63324 Mdot
.38728 .49425 Mdot
.48445 .69455 Mdot
.62016 .63393 Mdot
.56125 .35583 Mdot
.63591 .3583 Mdot
.30111 .43813 Mdot
.55712 .43989 Mdot
.32708 .41923 Mdot
.50937 .32286 Mdot
.59557 .53015 Mdot
.42642 .67014 Mdot
.67384 .42283 Mdot
.52426 .3685 Mdot
.54111 .29403 Mdot
.51287 .3556 Mdot
.62682 .40775 Mdot
.6524 .49625 Mdot
.3613 .59916 Mdot
.62191 .58008 Mdot
.66832 .46771 Mdot
.35734 .61857 Mdot
.64053 .39323 Mdot
.60999 .54232 Mdot
.68034 .56219 Mdot
.33362 .67107 Mdot
.34796 .61285 Mdot
.35708 .45175 Mdot
.36816 .614 Mdot
.43281 .49362 Mdot
.64674 .67164 Mdot
.33441 .47831 Mdot
.62768 .53496 Mdot
.5405 .72619 Mdot
.54963 .66576 Mdot
.66694 .56996 Mdot
.49672 .68611 Mdot
.55607 .30182 Mdot
.68269 .44449 Mdot
.55555 .62857 Mdot
.38773 .51551 Mdot
.4081 .41292 Mdot
.37627 .50108 Mdot
.56175 .66076 Mdot
.42235 .55208 Mdot
.64833 .61207 Mdot
.45055 .66018 Mdot
.56548 .50045 Mdot
.62616 .61476 Mdot
.47008 .61678 Mdot
.48277 .6888 Mdot
.56066 .69428 Mdot
.48766 .34504 Mdot
.34498 .4743 Mdot
.54086 .59493 Mdot
.33174 .58513 Mdot
.49485 .47679 Mdot
.49673 .61452 Mdot
.37008 .52666 Mdot
.52446 .60501 Mdot
.32346 .47947 Mdot
.7224 .56235 Mdot
.5782 .58382 Mdot
.52454 .40218 Mdot
.3601 .51147 Mdot
.4243 .67269 Mdot
.48677 .67268 Mdot
.67041 .48368 Mdot
.3412 .47591 Mdot
.4754 .34064 Mdot
.54415 .49717 Mdot
.37933 .55509 Mdot
.46246 .44302 Mdot
.35565 .461 Mdot
.37041 .32409 Mdot
.5078 .35953 Mdot
.60127 .56075 Mdot
.3172 .46772 Mdot
.64791 .38682 Mdot
.44368 .5274 Mdot
.45071 .59053 Mdot
.5595 .35153 Mdot
.46597 .5934 Mdot
.47741 .57568 Mdot
.46914 .47159 Mdot
.56998 .34722 Mdot
.57415 .56678 Mdot
.61782 .54472 Mdot
.61368 .63636 Mdot
.38581 .39549 Mdot
.55592 .61208 Mdot
.60686 .60891 Mdot
.53704 .40141 Mdot
.3211 .55623 Mdot
.44043 .5401 Mdot
.66316 .59146 Mdot
.51123 .44492 Mdot
.5695 .62222 Mdot
.51688 .29626 Mdot
.5855 .54588 Mdot
.45955 .4836 Mdot
.32138 .46079 Mdot
.31024 .46481 Mdot
.42909 .61504 Mdot
.39499 .37773 Mdot
.6283 .53244 Mdot
.56923 .65092 Mdot
.62494 .55855 Mdot
.37847 .65794 Mdot
.72815 .58224 Mdot
.47986 .32768 Mdot
.66385 .39546 Mdot
.64881 .57979 Mdot
.45178 .62458 Mdot
.45709 .33599 Mdot
.55743 .47305 Mdot
.6166 .48529 Mdot
.6756 .45209 Mdot
.61976 .36931 Mdot
.59836 .37311 Mdot
.43006 .53454 Mdot
.6469 .44121 Mdot
.54907 .35255 Mdot
.60036 .62826 Mdot
.54755 .30098 Mdot
.55056 .36184 Mdot
.47784 .71142 Mdot
.582 .37479 Mdot
.58202 .65807 Mdot
.65904 .43556 Mdot
.4944 .60988 Mdot
.59277 .53754 Mdot
.51356 .42628 Mdot
.57339 .65454 Mdot
.67387 .52169 Mdot
.57763 .49634 Mdot
.36307 .68917 Mdot
.49196 .67888 Mdot
.53519 .67803 Mdot
.4028 .62433 Mdot
.59315 .51319 Mdot
.32413 .47237 Mdot
.66453 .37288 Mdot
.36964 .64593 Mdot
.6768 .56747 Mdot
.33142 .68939 Mdot
.62079 .47529 Mdot
.4083 .6925 Mdot
.48815 .34893 Mdot
.62363 .47499 Mdot
.34824 .43874 Mdot
.48426 .28722 Mdot
.33955 .46914 Mdot
.57987 .60078 Mdot
.50862 .32355 Mdot
.55719 .32616 Mdot
.53721 .31029 Mdot
.35283 .42508 Mdot
.53663 .33779 Mdot
.3612 .63411 Mdot
.57845 .51012 Mdot
.3779 .6267 Mdot
.36505 .48999 Mdot
.54702 .33865 Mdot
.65389 .65165 Mdot
.41682 .41568 Mdot
.48138 .63507 Mdot
.63881 .37834 Mdot
.34901 .46248 Mdot
.35319 .64651 Mdot
.49634 .44696 Mdot
.60854 .43244 Mdot
.5712 .30452 Mdot
.33924 .42939 Mdot
.53555 .66128 Mdot
.50325 .38228 Mdot
.52941 .67141 Mdot
.5119 .68626 Mdot
.64014 .42179 Mdot
.4757 .64576 Mdot
.26528 .43354 Mdot
.64165 .48382 Mdot
.47094 .31238 Mdot
.61044 .5337 Mdot
.7066 .53715 Mdot
.36353 .4812 Mdot
.49902 .36142 Mdot
.50637 .38617 Mdot
.34264 .43904 Mdot
.42272 .41634 Mdot
.42222 .42311 Mdot
.32219 .47844 Mdot
.49977 .64253 Mdot
.37156 .6315 Mdot
.39222 .40162 Mdot
.42995 .64702 Mdot
.47494 .34699 Mdot
.72808 .50574 Mdot
.60298 .45525 Mdot
.65431 .62495 Mdot
.37188 .59667 Mdot
.37167 .61006 Mdot
.53073 .36901 Mdot
.66646 .5548 Mdot
.45772 .51122 Mdot
.45718 .45892 Mdot
.6619 .42956 Mdot
.37863 .67019 Mdot
.52805 .59166 Mdot
.33443 .43979 Mdot
.32395 .66788 Mdot
.35732 .34837 Mdot
.59799 .38119 Mdot
.62022 .58067 Mdot
.58724 .52391 Mdot
.64879 .62643 Mdot
.42878 .50068 Mdot
.35541 .57888 Mdot
.39204 .39508 Mdot
.58649 .5225 Mdot
.38911 .6169 Mdot
.36672 .46964 Mdot
.60312 .61325 Mdot
.65561 .54926 Mdot
.50638 .58895 Mdot
.58877 .45006 Mdot
.31841 .68132 Mdot
.61364 .40242 Mdot
.51676 .29556 Mdot
.32716 .4674 Mdot
.65824 .54203 Mdot
.3699 .59955 Mdot
.44309 .44226 Mdot
.5733 .40941 Mdot
.32617 .44921 Mdot
.60231 .35919 Mdot
.4747 .67542 Mdot
.63784 .39337 Mdot
.65942 .55676 Mdot
.61398 .47962 Mdot
.36479 .61446 Mdot
.33513 .46168 Mdot
.44455 .61022 Mdot
.55787 .51926 Mdot
.47754 .43757 Mdot
.39419 .68975 Mdot
.5427 .64315 Mdot
.41704 .59109 Mdot
.69416 .52763 Mdot
.33869 .44544 Mdot
.61206 .41792 Mdot
.36293 .46143 Mdot
.3315 .45211 Mdot
.64788 .65123 Mdot
.56494 .63948 Mdot
.68065 .5011 Mdot
.38117 .55809 Mdot
.56805 .30022 Mdot
.3463 .65405 Mdot
.35726 .68546 Mdot
.47139 .61013 Mdot
.50181 .39613 Mdot
.26708 .43216 Mdot
.48695 .68479 Mdot
.60327 .40709 Mdot
.4911 .69048 Mdot
.53765 .30017 Mdot
.52343 .57656 Mdot
.47263 .65764 Mdot
.4228 .50021 Mdot
.64935 .50019 Mdot
.5038 .6417 Mdot
.45654 .39128 Mdot
.41247 .53501 Mdot
.46475 .65244 Mdot
.46598 .65996 Mdot
.43996 .58915 Mdot
.63302 .60054 Mdot
.44056 .39431 Mdot
.61763 .37935 Mdot
.26307 .41991 Mdot
.42854 .64952 Mdot
.37494 .60959 Mdot
.59708 .53662 Mdot
.47445 .38757 Mdot
.48695 .28231 Mdot
.2829 .445 Mdot
.40393 .6626 Mdot
.65339 .60931 Mdot
.52108 .53832 Mdot
.38301 .63087 Mdot
.37566 .63428 Mdot
.65898 .48526 Mdot
.59561 .52102 Mdot
.44846 .49308 Mdot
.63615 .68461 Mdot
.71513 .44872 Mdot
.28175 .38213 Mdot
.26839 .42143 Mdot
.64093 .55718 Mdot
.42051 .61005 Mdot
.57874 .36645 Mdot
.68812 .55075 Mdot
.28431 .4261 Mdot
.63206 .51105 Mdot
.36017 .55928 Mdot
.40434 .57067 Mdot
.27486 .44295 Mdot
.37563 .43108 Mdot
.64536 .66011 Mdot
.57778 .63743 Mdot
.64922 .46204 Mdot
.52281 .37122 Mdot
.56233 .54025 Mdot
.54105 .33393 Mdot
.45636 .42141 Mdot
.50517 .37364 Mdot
.46758 .64189 Mdot
.49802 .56971 Mdot
.62285 .39556 Mdot
.50767 .32631 Mdot
.62881 .38083 Mdot
.41934 .47231 Mdot
.56665 .43299 Mdot
.64086 .36364 Mdot
.50091 .43961 Mdot
.63665 .52324 Mdot
.53317 .73336 Mdot
.51035 .55086 Mdot
.56605 .34277 Mdot
.62901 .68951 Mdot
.59414 .4338 Mdot
.49341 .65479 Mdot
.64712 .57884 Mdot
.44191 .39691 Mdot
.56367 .64646 Mdot
.62125 .38489 Mdot
.37667 .61428 Mdot
.55808 .39212 Mdot
.41907 .66604 Mdot
.39635 .47517 Mdot
.38435 .31384 Mdot
.39886 .45226 Mdot
.3731 .35523 Mdot
.35686 .65018 Mdot
.39173 .50334 Mdot
.45282 .36362 Mdot
.35799 .66154 Mdot
.51824 .42718 Mdot
.61668 .45393 Mdot
.69407 .5538 Mdot
.42483 .37439 Mdot
.36166 .57128 Mdot
.5785 .65368 Mdot
.59645 .37334 Mdot
.36321 .3476 Mdot
.32826 .45596 Mdot
.66276 .55638 Mdot
.53457 .42691 Mdot
.53405 .29402 Mdot
.54882 .49791 Mdot
.51913 .32277 Mdot
.61023 .53371 Mdot
.55037 .68697 Mdot
.40724 .38812 Mdot
.62208 .46206 Mdot
.5125 .43045 Mdot
.3826 .60793 Mdot
.45133 .65808 Mdot
.34909 .60002 Mdot
.384 .57105 Mdot
.58008 .28429 Mdot
.39173 .59901 Mdot
.63148 .43716 Mdot
.43273 .61755 Mdot
.57882 .36859 Mdot
.5087 .3116 Mdot
.56715 .41751 Mdot
.67004 .43923 Mdot
.32136 .46676 Mdot
.42375 .42073 Mdot
.54706 .72383 Mdot
.48647 .69167 Mdot
.27504 .43731 Mdot
.53873 .33866 Mdot
.34346 .47327 Mdot
.40179 .59384 Mdot
.45186 .42557 Mdot
.48551 .3336 Mdot
.50638 .46567 Mdot
.66468 .36967 Mdot
.43105 .63679 Mdot
.57424 .65752 Mdot
.50102 .66198 Mdot
.69453 .53003 Mdot
.56208 .33957 Mdot
.55485 .62829 Mdot
.49737 .58113 Mdot
.50227 .42152 Mdot
.47797 .30186 Mdot
.64428 .56615 Mdot
.73413 .49238 Mdot
.42995 .67435 Mdot
.33028 .46111 Mdot
.51852 .68269 Mdot
.49764 .60668 Mdot
.54734 .576 Mdot
.36031 .49951 Mdot
.68643 .54242 Mdot
.55583 .64497 Mdot
.4676 .68369 Mdot
.35141 .44567 Mdot
.55927 .59435 Mdot
.50091 .31974 Mdot
.64544 .40583 Mdot
.53408 .57521 Mdot
.52527 .31847 Mdot
.70673 .55239 Mdot
.3545 .43691 Mdot
.38111 .54597 Mdot
.36712 .33674 Mdot
.33906 .66411 Mdot
.46556 .62236 Mdot
.50809 .35764 Mdot
.56036 .53916 Mdot
.66993 .56602 Mdot
.487 .66489 Mdot
.58122 .34636 Mdot
.30338 .42785 Mdot
.66926 .41443 Mdot
.61167 .44104 Mdot
.39435 .6123 Mdot
.39132 .625 Mdot
.61688 .59799 Mdot
.6017 .54105 Mdot
.46703 .57643 Mdot
.58598 .4484 Mdot
.42017 .63822 Mdot
.49142 .32299 Mdot
.33135 .44008 Mdot
.4686 .69705 Mdot
.54086 .28901 Mdot
.43852 .67828 Mdot
.45096 .6804 Mdot
.59942 .40765 Mdot
.57673 .59352 Mdot
.52843 .41482 Mdot
.52119 .39731 Mdot
.70875 .61816 Mdot
.2977 .45508 Mdot
.56908 .6235 Mdot
.58682 .43258 Mdot
.65534 .45821 Mdot
.50408 .62038 Mdot
.55647 .28599 Mdot
.66564 .50861 Mdot
.57156 .3334 Mdot
.58243 .37448 Mdot
.66498 .49474 Mdot
.62141 .53874 Mdot
.62074 .61678 Mdot
.38817 .40724 Mdot
.6175 .45054 Mdot
.46172 .38555 Mdot
.68565 .52994 Mdot
.43076 .56476 Mdot
.35204 .67935 Mdot
.37009 .56087 Mdot
.41213 .50822 Mdot
.41205 .44304 Mdot
.34863 .45253 Mdot
.38693 .35892 Mdot
.26858 .42275 Mdot
.65703 .44313 Mdot
.31321 .45606 Mdot
.50461 .63753 Mdot
.38795 .30714 Mdot
.5371 .39511 Mdot
.55774 .59365 Mdot
.3688 .64908 Mdot
.46387 .46649 Mdot
.52933 .34292 Mdot
.60872 .61321 Mdot
.51337 .6616 Mdot
.47971 .33836 Mdot
.33871 .66249 Mdot
.43279 .69487 Mdot
.66223 .57086 Mdot
.57087 .30764 Mdot
.49571 .66566 Mdot
.34426 .41971 Mdot
.71659 .45707 Mdot
.67008 .41909 Mdot
.61996 .59309 Mdot
.50867 .37928 Mdot
.67943 .48007 Mdot
.64892 .5954 Mdot
.4886 .29093 Mdot
.72807 .46522 Mdot
.38242 .45134 Mdot
.55095 .67976 Mdot
.35701 .65218 Mdot
.41442 .45663 Mdot
.37546 .31151 Mdot
.4818 .35643 Mdot
.37587 .64583 Mdot
.60032 .44629 Mdot
.33299 .47132 Mdot
.62894 .39551 Mdot
.64621 .39644 Mdot
.67432 .55447 Mdot
.45286 .63868 Mdot
.6825 .43214 Mdot
.65475 .47171 Mdot
.41355 .67269 Mdot
.33774 .47044 Mdot
.40193 .43907 Mdot
.55908 .53334 Mdot
.45199 .4524 Mdot
.41624 .39234 Mdot
.54381 .32658 Mdot
.58162 .32743 Mdot
.6114 .34955 Mdot
.37311 .53801 Mdot
.56267 .41017 Mdot
.46046 .525 Mdot
.35846 .44807 Mdot
.65367 .49904 Mdot
.62167 .46019 Mdot
.61499 .38973 Mdot
.46558 .62269 Mdot
.31571 .67207 Mdot
.34136 .44473 Mdot
.41222 .55357 Mdot
.57525 .33327 Mdot
.67835 .52626 Mdot
.65819 .44291 Mdot
.32314 .45092 Mdot
.46083 .57402 Mdot
.39991 .51006 Mdot
.31555 .47092 Mdot
.44616 .35606 Mdot
.61678 .617 Mdot
.34397 .49281 Mdot
.47776 .28594 Mdot
.66457 .46917 Mdot
.52896 .37916 Mdot
.65802 .63203 Mdot
.64975 .38219 Mdot
.3914 .56972 Mdot
.3371 .47908 Mdot
.59026 .44267 Mdot
.6448 .65035 Mdot
.45695 .6468 Mdot
.62052 .43533 Mdot
.64137 .39583 Mdot
.41532 .63396 Mdot
.72186 .56159 Mdot
.42742 .48499 Mdot
.62201 .69135 Mdot
.48679 .35816 Mdot
.32153 .4443 Mdot
.44902 .69049 Mdot
.36774 .42363 Mdot
.43081 .69522 Mdot
.48401 .62209 Mdot
.43364 .67873 Mdot
.36422 .59621 Mdot
.62457 .43332 Mdot
.31674 .45757 Mdot
.42361 .6211 Mdot
.32492 .44333 Mdot
.47071 .3194 Mdot
.6416 .6629 Mdot
.43612 .58628 Mdot
.37769 .58835 Mdot
.54729 .61409 Mdot
.58556 .59971 Mdot
.66291 .43019 Mdot
.51668 .3202 Mdot
.63365 .48712 Mdot
.32309 .66148 Mdot
.44327 .45534 Mdot
.49586 .36709 Mdot
.61417 .47796 Mdot
.49223 .36685 Mdot
.42291 .46615 Mdot
.33748 .67209 Mdot
.31082 .47053 Mdot
.56812 .65333 Mdot
.39421 .53975 Mdot
.26792 .41314 Mdot
.38883 .30657 Mdot
.43341 .69843 Mdot
.72309 .46656 Mdot
.36467 .52194 Mdot
.65281 .39767 Mdot
.47962 .36162 Mdot
.4371 .67522 Mdot
.3738 .60484 Mdot
.66587 .41599 Mdot
.32329 .67963 Mdot
.38087 .60461 Mdot
.73134 .49706 Mdot
.65004 .43077 Mdot
.54893 .28616 Mdot
.64656 .5841 Mdot
.52224 .63566 Mdot
.36232 .69482 Mdot
.3764 .31574 Mdot
.63351 .42896 Mdot
.6147 .5976 Mdot
.66397 .56667 Mdot
.62272 .38542 Mdot
.42085 .42549 Mdot
.66176 .54916 Mdot
.49962 .31336 Mdot
.37005 .6271 Mdot
.44328 .4477 Mdot
.57274 .61343 Mdot
.42123 .56803 Mdot
.41924 .39675 Mdot
.31801 .43017 Mdot
.37794 .34972 Mdot
.42123 .53537 Mdot
.45139 .36935 Mdot
.709 .45403 Mdot
.48999 .29697 Mdot
.57884 .58931 Mdot
.49053 .65375 Mdot
.41869 .51635 Mdot
.58337 .52998 Mdot
.51934 .73506 Mdot
.34597 .49145 Mdot
.39641 .47236 Mdot
.67452 .43204 Mdot
.59085 .52656 Mdot
.51388 .62777 Mdot
.52884 .61628 Mdot
.40167 .42554 Mdot
.52986 .73069 Mdot
.34908 .57354 Mdot
.37681 .35399 Mdot
.35071 .68859 Mdot
.37311 .31439 Mdot
.54388 .40959 Mdot
.67133 .46583 Mdot
.63837 .43052 Mdot
.64804 .38913 Mdot
.45519 .40793 Mdot
.41536 .38983 Mdot
.52483 .73821 Mdot
.36929 .4367 Mdot
.48432 .46253 Mdot
.6708 .5254 Mdot
.40912 .5679 Mdot
.32779 .44944 Mdot
.4344 .4587 Mdot
.4256 .36289 Mdot
.48444 .32177 Mdot
.47755 .38217 Mdot
.65925 .51178 Mdot
.64343 .62832 Mdot
.65814 .43778 Mdot
.38241 .51009 Mdot
.51432 .6658 Mdot
.30164 .4394 Mdot
.52457 .36263 Mdot
.59028 .47044 Mdot
.57685 .60753 Mdot
.41615 .60033 Mdot
.35401 .49508 Mdot
.57133 .28493 Mdot
.42243 .55229 Mdot
.41706 .44103 Mdot
.34518 .45711 Mdot
.55036 .71964 Mdot
.50607 .52045 Mdot
.42852 .45292 Mdot
.34484 .43674 Mdot
.56881 .27968 Mdot
.38828 .61854 Mdot
.44434 .6935 Mdot
.6736 .46615 Mdot
.36473 .3408 Mdot
.32569 .46901 Mdot
.66858 .46402 Mdot
.58547 .44734 Mdot
.73352 .46974 Mdot
.43433 .44632 Mdot
.47226 .68996 Mdot
.6346 .57309 Mdot
.36801 .36908 Mdot
.46541 .43766 Mdot
.28967 .45877 Mdot
.51085 .36784 Mdot
.52536 .4159 Mdot
.42258 .67886 Mdot
.609 .38711 Mdot
.392 .66041 Mdot
.66819 .54358 Mdot
.48929 .35105 Mdot
.65201 .36639 Mdot
.51398 .29428 Mdot
.53716 .58455 Mdot
.70376 .55128 Mdot
.55931 .40948 Mdot
.52523 .66634 Mdot
.5865 .50674 Mdot
.7245 .56415 Mdot
.54738 .66554 Mdot
.37667 .4352 Mdot
.5669 .56566 Mdot
.69888 .62003 Mdot
.42757 .62928 Mdot
.52516 .54751 Mdot
.58607 .5836 Mdot
.49845 .60608 Mdot
.50365 .58121 Mdot
.64188 .57455 Mdot
.51689 .52856 Mdot
.57348 .64869 Mdot
.63134 .55559 Mdot
.40428 .46032 Mdot
.61547 .42805 Mdot
.47177 .39847 Mdot
.49215 .27212 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0?ooooooB_ooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A006ooooo`03o`000?oooooooooo0?ooooooB_ooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0?ooooooB_oo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06
ooooo`?o0000oooooom:ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<oooo
o`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom:ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001_ooool00ol0003oooooooooo`3ooooood[ooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`2Oooooo`Go0000YOooool001cooooo00?o0000ooooooooool0WOooool;
o`000:7ooooo000Looooo`03o`000?oooooooooo09[ooooo5?l00002ooooo`Oo00000_ooool2o`00
08kooooo000Looooo`03o`000?oooooooooo09[ooooo9Ol0002:ooooo`007?ooool00ol0003ooooo
ooooo`2IooooobSo0000R?ooool001cooooo00?o0000ooooooooool0V?ooool3o`000003ooooool0
003o000002?o0000R?ooool001cooooo00?o0000ooooooooool0V?oooolOo`000003ooooool0003o
000000Oo0000R?ooool001cooooo00?o0000ooooooooool0UooooolLo`0000?ooooo0_l000000ooo
oooo0000o`000007o`000004ooooool0003o0000o`0008?ooooo000Looooo`03o`000?oooooooooo
09Kooooo0ol000000ooooooo0000o`00000Go`0000?ooooo4_l00021ooooo`007?ooool00ol0003o
ooooooooo`2Fooooo`?o000000?oooooo`000?l000004_l00008oooooa?o0000P?ooool001cooooo
00?o0000ooooooooool0UOooool2o`0000Cooooo2ol00004ooooo`Co00001ooooolDo`00083ooooo
000Looooo`03o`000?oooooooooo09Gooooo0_l00004ooooo`;o00001?ooool5o`0000;ooooo1_l0
0007oooooaCo0000P?ooool001cooooo0_l0001looooo`;o00006?ooool2o`0000Cooooo1?l00002
ooooo`;o000000?oooooo`000?l000000_ooool2o`000004ooooool0003o0000ooooo`;o00001Ooo
oolEo`0007oooooo000Looooo`03o`000?oooooooooo07Sooooo3?l0000@ooooo`?o000000?ooooo
o`000?l000000oooool2o`0000?ooooo0_l00007ooooo`;o000000Coooooo`000?l0003ooooo0_l0
0002oooooaKo0000O_ooool001cooooo00?o0000ooooooooool0N?ooool>o`0000kooooo0_l00002
ooooo`;o00002?ooool2o`0000gooooo0_l00003oooooaGo0000O_ooool001cooooo00?o0000oooo
ooooool0M_ooool8o`000003ooooool0003o000000Ko00003?ooool3o`0001Gooooo0_l00009oooo
oaGo0000O_ooool001cooooo00?o0000ooooooooool0MOooool3o`000003ooooool0003o000000go
00002_ooool5o`0000Sooooo1?l00002ooooo`;o00001?ooool2o`0000[ooooo3ol00002ooooo`?o
0000O_ooool001cooooo00?o0000ooooooooool0MOoooolCo`000003ooooool0003o000000Oooooo
1Ol00008ooooo`Co00000_ooool2o`00017ooooo5?l0001mooooo`007?ooool00ol0003ooooooooo
o`1coooooaWo00001_ooool5o`0000Sooooo0_l00006ooooo`;o00004?oooolCo`0007gooooo000L
ooooo`03o`000?oooooooooo07?ooooo0ol00002oooooaCo00001Oooool3o`000003ooooool0003o
000000?ooooo1?l000001?oooooo0000o`000?ooool7o`0000[ooooo0_l00005oooooa;o0000OOoo
ool001cooooo00?o0000ooooooooool0MOoooolGo`0000Gooooo0ol00006ooooo`Co00000oooool6
o`0000[ooooo1?l00005oooooa;o0000OOooool001cooooo00?o0000ooooooooool0L_ooool2o`00
0003ooooool0003o0000017o000000Coooooo`000?l0003o00001?ooool4o`0000Cooooo0_l00002
ooooo`;o00000oooool2o`0000[ooooo0_l00002ooooo`Go00000ooooolDo`0007cooooo000Loooo
o`03o`000?oooooooooo077ooooo0ol00002oooooaKo00001?ooool4o`0000Cooooo0_l0000Coooo
o`;o00000oooool4o`0000?ooooo5?l0001looooo`007?ooool00ol0003oooooooooo`1aooooo`;o
00000ooooolFo`0000kooooo0_l0000@ooooo`;o00002?ooool3o`0000Cooooo4?l0001looooo`00
7?ooool00ol0003oooooooooo`1aooooo`;o000000?oooooo`000?l000005Ol00003ooooo`Go0000
1Oooool4o`0000oooooo1Ol00006ooooo`?o00001?ooool>o`0007kooooo000Looooo`03o`000?oo
oooooooo077ooooo6Ol00004ooooo`Go00001?ooool3o`00017ooooo0_l000000ooooooo0000o`00
0003ooooo`;o00001Oooool2o`0000;ooooo3ol0001looooo`007?ooool00ol0003oooooooooo`1a
ooooo`Co000000?oooooo`000?l000001?l000000ooooooo0000o`00000;o`0000?ooooo1?l00006
ooooo`;o00003oooool2o`0000Wooooo0ol00004ooooo`;o00001?ooool=o`0007cooooo000Loooo
o`03o`000?oooooooooo07;ooooo0_l00002oooooaCo00000oooool3o`0000Kooooo0ol00002oooo
o`;o00002oooool2o`0000[ooooo0ol00002ooooo`;o00001Oooool=o`0007cooooo000Looooo`;o
0000LOooool4o`0000?ooooo4_l00002ooooo`Co00001oooool3o`0000;ooooo0_l0000Booooo`;o
00001?ooool2o`0000;ooooo0_l00007ooooo`_o0000O?ooool001cooooo00?o0000ooooooooool0
L?ooool2o`0000Gooooo4ol000001?oooooo0000o`000?l0000=ooooo`;o00001?ooool2o`0000[o
oooo1?l000000ooooooo0000o`00000?ooooo`So0000O_ooool001cooooo00?o0000ooooooooool0
MOoooolJo`0000[ooooo1?l00004ooooo`Co00002?ooool4o`000004ooooool0003o0000o`0000ko
oooo0_l000000ooooooo0000o`000005o`0007cooooo000Looooo`03o`000?oooooooooo07Gooooo
0_l00003oooooa;o000000?oooooo`000?l000000_l00008ooooo`?o00001Oooool4o`0000Cooooo
0_l00008ooooo`;o00002oooool2o`000003ooooool0003o000000;ooooo3?l0001fooooo`007?oo
ool00ol0003oooooooooo`1joooooa?o00000_ooool2o`0000Oooooo1?l00002ooooo`;o000000Co
ooooo`000?l0003o00000oooool4o`0000Cooooo0_l0000>ooooo`?o00002?ooool9o`000004oooo
ool0003o0000o`0007;ooooo000Looooo`03o`000?oooooooooo07[ooooo3ol00002ooooo`;o0000
0_ooool2o`0000;ooooo0_l00003ooooo`;o00001?ooool3o`0000Kooooo0_l00006ooooo`;o0000
3Oooool3o`0000Wooooo1?l00002ooooo`;o00000_ooool6o`0006oooooo000Looooo`03o`000?oo
oooooooo06oooooo0_l00003ooooo`;o00001?ooool2o`000003ooooool0003o000000So00002?oo
ool2o`0000;ooooo0_l00007ooooo`Go000000?oooooo`000?l000000oooool4o`0000cooooo0ol0
0004ooooo`;o00001_ooool2o`0000Cooooo0_l00002ooooo`;o00001Oooool6o`0006cooooo000L
ooooo`03o`000?oooooooooo05_ooooo2Ol0000;ooooo`;o00000oooool2o`00017ooooo0_l00004
ooooo`Co00000_ooool2o`0000Oooooo0ol00003ooooo`;o00000_ooool5o`0000cooooo0ol00008
ooooo`;o00000_ooool2o`0000Sooooo0_l00002ooooo`[o0000Joooool001cooooo00?o0000oooo
ooooool0FOooool?o`0000Oooooo0_l0000Eooooo`?o00001?ooool2o`0000Sooooo0_l00007oooo
o`;o00001?ooool2o`00017ooooo0ol00002ooooo`?o000000?oooooo`000?l000004?ooool:o`00
06_ooooo000Looooo`03o`000?oooooooooo05Oooooo4_l000000ooooooo0000o`000003ooooo`;o
00003?ooool2o`0000Oooooo0_l0000?ooooo`;o00001oooool2o`0000oooooo0_l00006ooooo`?o
00000_ooool3o`0000_ooooo0_l00006ooooo`co0000JOooool001cooooo00?o0000ooooooooool0
E_ooool3o`000003ooooool0003o0000017o00000_ooool2o`0000Kooooo0_l00004ooooo`;o0000
1?ooool2o`0001cooooo0_l00005ooooo`;o00001oooool2o`0000[ooooo1Ol00003ooooo`;o0000
00?oooooo`000?l000000_ooool2o`0000Kooooo3Ol0001Xooooo`007?ooool00ol0003ooooooooo
o`1DoooooaWo00002_ooool2o`0000Wooooo0ol0000Booooo`;o00001oooool3o`0000Gooooo0_l0
000Cooooo`Go00000oooool2o`000004ooooool0003o0000o`0000Cooooo0_l00003ooooo`go0000
J?ooool001cooooo00?o0000ooooooooool0Doooool3o`0000;ooooo5_l0000>ooooo`;o00001?oo
ool2o`0000kooooo0_l00002ooooo`?o00001Oooool5o`0001oooooo0_l00002ooooo`;o000000?o
ooooo`000?l000001?ooool2o`0000?ooooo3Ol0001Xooooo`007?ooool00ol0003oooooooooo`1B
oooooaco00003_ooool2o`0000?ooooo1?l0000<ooooo`?o00000_ooool2o`0000Kooooo0_l00000
0ooooooo0000o`00000Booooo`;o00002oooool6o`0000Oooooo0_l00004ooooo`go0000Ioooool0
0006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413ooooooooo
o`04ooooo`03o`000?oooooooooo05;ooooo0ol000000ooooooo0000o`00000Fo`0001?ooooo1?l0
0008ooooo`;o00000_ooool2o`000003ooooool0003o000001Kooooo0_l00004ooooo`;o000000?o
ooooo`000?l000003Oooool2o`0000Gooooo0ol000000ooooooo0000o`000003ooooo`ko0000Iooo
ool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1Aooooo`?o00000_oooolHo`0000Gooooo0_l00005ooooo`Co0000
0oooool5o`0000Gooooo1?l00002ooooo`;o000000Coooooo`000?l0003o00002?ooool2o`0000[o
oooo0ol00004ooooo`;o00004oooool9o`0000Cooooo3Ol0001Xooooo`0000?ooooooa0@4?ooool0
0_ooool00ol@413oooooooooo`09ooooo`Go00001_ooool00ol0003oooooooooo`1Aooooo`?o0000
0_ooool2o`000003ooooool0003o000001Co00001?ooool2o`0000Gooooo1?l00006ooooo`;o0000
1Oooool3o`0000Oooooo0_l00008ooooo`;o00001Oooool2o`0000?ooooo0_l0000Jooooo`Co0000
0_ooool5o`0000;ooooo3_l0001Wooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooooooo
o`09ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0001@ooooo`?o00000ooooolFo`000003oooo
ool0003o000000gooooo0_l0000>ooooo`;o00001oooool2o`0000oooooo0ol00002ooooo`;o0000
5oooool3o`0000Wooooo0_l00003ooooo`ko0000I_ooool00003ooooool0003ooooo00;ooooo00?o
0000ooooooooool02Oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo053ooooo
0ol00002oooooaOo000000?oooooo`000?l000003Oooool2o`0000kooooo0_l0000Iooooo`;o0000
0_ooool2o`0001Gooooo1Ol00007ooooo`;o00001Oooool>o`0006Kooooo00000ooooooo410@oooo
o`02ooooo`03oa0@4?oooooooooo00[ooooo00?oMgMgolc<c?l000001oooool00ol0003ooooooooo
o`1@ooooo`;o00000ooooolGo`0000kooooo1_l0000@ooooo`;o00004Oooool2o`0000gooooo0_l0
0002ooooo`;o00001oooool5o`0000Cooooo0_l00004ooooo`;o00000_ooool2o`0000;ooooo0_l0
00000ooooooo0000o`000007o`0006Oooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo
00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`1@ooooo`;o00000ooooolIo`0000cooooo
0_l00002ooooo`;o00004?ooool2o`00017ooooo0_l00008ooooo`;o00000oooool3o`000003oooo
ool0003o000000Oooooo1Ol00004ooooo`;o00002?ooool2o`0000;ooooo2ol0001Xooooo`0000Ko
ooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000oooooooo
ool0D?ooool2o`000003ooooool0003o000000Wo000000?oooooo`000?l000003Ol0000Cooooo`;o
00009Oooool2o`0000?ooooo0_l00004ooooo`;o00005?ooool2o`0000_ooooo2_l0001Yooooo`00
7?ooool00ol0003oooooooooo`1@ooooo`;o000000?oooooo`000?l000005ol0000Eooooo`;o0000
00?oooooo`000?l000000_l0000Booooo`;o00002oooool3o`0000Sooooo1?l0000=ooooo`;o0000
1?ooool4o`0000Gooooo0_l000000ooooooo0000o`00000<o`0006Kooooo000Looooo`03o`000?oo
oooooooo05;ooooo0ol00005oooooa3o00000_ooool2o`0000?ooooo0_l00004ooooo`;o00002ooo
ool4o`0000Sooooo0_l00008ooooo`;o00000oooool2o`0000Kooooo0_l00009ooooo`Co00002Ooo
ool2o`0000;ooooo0_l00006ooooo`?o00001?ooool6o`000003ooooool0003o000000So0000I_oo
ool001cooooo00?o0000ooooooooool0D?ooool6o`0000Sooooo1?l000000ooooooo0000o`000002
ooooo`;o00000oooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0000cooooo0ol0
0008ooooo`;o00003Oooool2o`0001kooooo0_l0000;ooooo`;o00001Oooool2o`000005ooooool0
003o0000o`000?ooool02_l0001Uooooo`007?ooool00ol0003oooooooooo`1@ooooo`?o000000?o
ooooo`000?l000000oooool2o`0000Cooooo0_l0000<ooooo`Co00000oooool2o`0000Wooooo0_l0
0004ooooo`;o00002?ooool2o`0001;ooooo1?l00003ooooo`;o0000:oooool2o`0000?ooooo2?l0
001Uooooo`007?ooool00ol0003oooooooooo`1@ooooo`?o00001_ooool2o`0000Cooooo0_l00003
ooooo`;o00001?ooool2o`000003ooooool0003o000000;o00001Oooool2o`0000Oooooo0_l00004
ooooo`;o00001oooool3o`0000kooooo0_l00002ooooo`Co00000oooool2o`0000Kooooo0_l0000@
ooooo`;o00001?ooool4o`000003ooooool0003o000000;ooooo0ol00007ooooo`Oo0000IOooool0
01cooooo00?o0000ooooooooool0DOooool4o`0000Cooooo0_l00009ooooo`;o00001?ooool2o`00
00[ooooo0_l0000Fooooo`;o00003oooool2o`0000;ooooo0_l0000=ooooo`Go00001?ooool4o`00
00?ooooo1?l000001?oooooo0000o`000?ooool4o`000003ooooool0003o000000;ooooo0ol00000
1?oooooo0000o`000?ooool2o`0000;ooooo2Ol0001Rooooo`007?ooool00ol0003oooooooooo`1A
ooooo`Co00005oooool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`00000@
ooooo`;o0000:Oooool3o`0000Cooooo1?l00003ooooo`;o00000_ooool5o`0000Oooooo0_l00000
0ooooooo0000o`000002o`000003ooooool0003o000000?ooooo2?l0001Rooooo`007?ooool00ol0
003oooooooooo`1Aooooo`Co000000?oooooo`000?l000001_ooool2o`0000Sooooo0ol000000ooo
oooo0000o`000003o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`;o00002?ooool2o`00
00Sooooo0_l00002ooooo`;o00001_ooool2o`00013ooooo0_l0000Cooooo`;o000000?oooooo`00
0?l000001oooool6o`0000Kooooo0_l000000ooooooo0000o`000005o`00067ooooo000Looooo`03
o`000?oooooooooo05;ooooo0ol000000ooooooo0000o`000006ooooo`;o00001_ooool5o`000004
ooooool0003o0000o`0000Oooooo0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o0000
00;o00001_ooool2o`0000Cooooo0ol00002ooooo`;o00001_ooool2o`00013ooooo0_l00009oooo
o`;o00001Oooool2o`0000Cooooo0_l00003ooooo`;o00000_ooool3o`000003ooooool0003o0000
00;o00001?ooool2o`0000Cooooo1Ol0001Pooooo`007?ooool00ol0003oooooooooo`1Cooooo`Oo
00002oooool3o`0000;ooooo0ol000000ooooooo0000o`000006ooooo`;o00000oooool2o`0000Go
oooo1?l00003ooooo`;o000000?oooooo`000?l000001?ooool2o`0000kooooo0_l0000Hooooo`;o
000000?oooooo`000?l000001?l00004ooooo`;o00000oooool2o`0000;ooooo0_l00004ooooo`Co
00002?ooool2o`000004ooooool0003o0000o`0005oooooo000Looooo`03o`000?oooooooooo05Go
oooo0_l000000ooooooo0000o`00000;ooooo`Co000000Goooooo`000?l0003o0000ooooo`02o`00
0004ooooool0003o0000ooooo`;o00004oooool2o`000003ooooool0003o000000oooooo0_l00003
ooooo`;o00005_ooool3o`0000;ooooo1?l00006ooooo`;o00003oooool2o`0000Sooooo0_l00000
1?oooooo0000o`000?l0001Oooooo`007?ooool2o`0005Kooooo0ol0000=ooooo`Go00001?ooool5
o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o00002Oooool2o`000004ooooool0003o
0000ooooo`;o00003?ooool2o`0001_ooooo0ol00003ooooo`;o00000oooool2o`00017ooooo0_l0
00000ooooooo0000o`000005o`0000;ooooo0_l000001?oooooo0000o`000?l0001Oooooo`007?oo
ool00ol0003oooooooooo`1Fooooo`?o00001?ooool2o`0000Kooooo1Ol00004ooooo`Co00001_oo
ool2o`0000Cooooo0ol00006ooooo`Co000000Coooooo`000?l0003ooooo0_l0000Zooooo`;o0000
0oooool2o`000003ooooool0003o000000;o00004Oooool2o`000003ooooool0003o000000Go0000
00?oooooo`000?l000000_ooool3o`0005oooooo000Looooo`03o`000?oooooooooo05Oooooo1Ol0
00000ooooooo0000o`000003ooooo`?o00000_ooool2o`0000?ooooo0_l0000Aooooo`;o00000_oo
ool2o`0000;ooooo1?l000000ooooooo0000o`000002ooooo`;o0000;_ooool2o`000003ooooool0
003o000000;o00002_ooool2o`0000Sooooo3?l000000ooooooo0000o`00001Oooooo`007?ooool0
0ol0003oooooooooo`1Hooooo`Co00001_ooool9o`000003ooooool0003o000000;ooooo1?l0000<
ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Gooooo0ol0000cooooo`;o00002Oooool2
o`0000Sooooo3?l00002ooooo`?o0000GOooool001cooooo00?o0000ooooooooool0F_ooool2o`00
0003ooooool0003o000000;ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00000oooool6
o`0000cooooo0_l0000?ooooo`;o00001oooool2o`0001Kooooo0_l0000Booooo`;o00001oooool2
o`0000Cooooo0_l00005ooooo`_o00000_ooool3o`0005gooooo000Looooo`03o`000?oooooooooo
05gooooo0_l00002ooooo`So00001Oooool2o`0001Kooooo0_l0000;ooooo`;o00001Oooool2o`00
00Gooooo0_l0000?ooooo`;o00004_ooool2o`0000Oooooo0_l00004ooooo`Co000000?oooooo`00
0?l000004Ol0001Looooo`007?ooool00ol0003oooooooooo`1Mooooo`;o00000_ooool8o`000004
ooooool0003o0000o`0000Kooooo0_l0000Aooooo`;o00000oooool2o`0000Kooooo0_l0000<oooo
o`;o00004Oooool2o`0000Kooooo0_l0000@ooooo`;o00001?ooool5o`000003ooooool0003o0000
01;o0000Foooool001cooooo00?o0000ooooooooool0HOooool4o`000003ooooool0003o000000Ko
00001Oooool2o`0000Sooooo0_l00005ooooo`;o00001Oooool2o`0000?ooooo0_l00003ooooo`;o
00006_ooool2o`000003ooooool0003o000000Kooooo0_l00008ooooo`;o00001_ooool2o`000004
ooooool0003o0000ooooo`;o00001?ooool?o`000003ooooool0003o000000?o0000F_ooool001co
oooo00?o0000ooooooooool0I_ooool4o`000004ooooool0003o0000o`0000oooooo0_l00005oooo
o`;o00002_ooool3o`0000;ooooo0_l00006ooooo`;o00004_ooool2o`0001?ooooo0ol00008oooo
o`;o00001oooool?o`0000Cooooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o
00000_ooool5o`0000oooooo0_l0000Booooo`;o00002_ooool2o`0000;ooooo0_l0000Qooooo`Go
00003Oooool2o`000003ooooool0003o000000oo00000oooool2o`0005[ooooo000Looooo`03o`00
0?oooooooooo06Gooooo0ol000001?oooooo0000o`000?l00006ooooo`;o00002Oooool2o`0002;o
oooo0_l0000Oooooo`Co00004?ooool2o`000003ooooool0003o000000oo00000oooool2o`0005[o
oooo000Looooo`03o`000?oooooooooo06Kooooo1?l00008ooooo`;o00003?ooool2o`0000Gooooo
0_l00009ooooo`;o0000;_ooool2o`000003ooooool0003o000000Kooooo0_l00003ooooo`;o0000
0_ooool2o`0000Cooooo3ol00002ooooo`?o0000FOooool001cooooo00?o0000ooooooooool0J?oo
ool3o`0000Oooooo0_l0000<ooooo`;o00001Oooool2o`0000Wooooo0_l0000aooooo`;o00000ooo
ool2o`000004ooooool0003o0000ooooo`Co00000_ooool3o`000004ooooool0003o0000ooooo`ko
00000_ooool3o`0005Wooooo000Looooo`03o`000?oooooooooo06Wooooo0ol000000ooooooo0000
o`000004ooooo`;o00005oooool2o`0003cooooo0_l00004ooooo`;o00000oooool4o`000004oooo
ool0003o0000oooooa3o000000?oooooo`000?l00000FOooool001cooooo00?o0000ooooooooool0
J_ooool7o`0000;ooooo0_l00005ooooo`;o00003Oooool2o`000003ooooool0003o000000;o0000
1?ooool2o`0003kooooo1ol00002oooooa3o000000?oooooo`000?l00000FOooool001cooooo00?o
0000ooooooooool0K?ooool5o`0000Wooooo0_l0000=ooooo`;o00000oooool2o`0000Cooooo0_l0
000Gooooo`Co00001oooool2o`0001Kooooo0_l00002ooooo`;o00000oooool2o`0000Cooooo3Ol0
00001?oooooo0000o`000?l0001Iooooo`007?ooool2o`0006kooooo0_l00002ooooo`;o00000ooo
ool2o`0000kooooo1?l0000Sooooo`Co00000oooool2o`0000;ooooo0_l0000Eooooo`Co00001_oo
ool4o`0000;ooooo3Ol000001?oooooo0000o`000?l0001Iooooo`007?ooool00ol0003ooooooooo
o`1]ooooo`;o00000_ooool2o`0000?ooooo0_l00004ooooo`;o00002?ooool4o`0002[ooooo0_l0
000Iooooo`Co00001_ooool4o`0000;ooooo2Ol00004ooooo`?o0000F_ooool001cooooo00?o0000
ooooooooool0Koooool2o`0000_ooooo0_l0000mooooo`;o00008oooool>o`0005_ooooo000Loooo
o`03o`000?oooooooooo06oooooo0_l00007ooooo`;o00001?ooool2o`0000;ooooo0_l0000Aoooo
o`;o00008Oooool2o`000003ooooool0003o000000gooooo0_l00008ooooo`;o00001_ooool2o`00
00;ooooo3Ol0001Looooo`007?ooool00ol0003oooooooooo`1/ooooo`;o000000?oooooo`000?l0
00000_l00005ooooo`;o00000_ooool4o`0000;ooooo0_l0000=ooooo`;o00000_ooool2o`00027o
oooo0_l00003ooooo`;o00002oooool2o`0000Kooooo1?l00006ooooo`?o00000oooool;o`0005co
oooo000Looooo`03o`000?oooooooooo06Kooooo0_l000000ooooooo0000o`000008o`0000Gooooo
1_l00006ooooo`;o00002oooool2o`0001cooooo0_l0000<ooooo`Co00004Oooool2o`0000Gooooo
0_l00002ooooo`;o00001Oooool7o`0005kooooo000Looooo`03o`000?oooooooooo06Gooooo2ol0
00000ooooooo0000o`000007ooooo`;o00002?ooool2o`0002Wooooo1?l0000<ooooo`;o00006?oo
ool2o`0006kooooo000Looooo`03o`000?oooooooooo06?ooooo4_l0000/ooooo`;o00003_ooool2
o`0000Sooooo0_l000000ooooooo0000o`00000;ooooo`;o00002_ooool2o`00073ooooo000Loooo
o`03o`000?oooooooooo06?ooooo4_l0000Mooooo`;o00003Oooool2o`0001Sooooo1Ol00002oooo
o`;o00001oooool2o`0000Wooooo1Ol0001^ooooo`007?ooool00ol0003oooooooooo`1RoooooaCo
00005_ooool2o`0000Cooooo0_l0000@ooooo`;o00005Oooool3o`0000Cooooo0_l0000Booooo`Go
00000oooool4o`0006Oooooo000Looooo`03o`000?oooooooooo06;ooooo4Ol000000ooooooo0000
o`00000Fooooo`;o00005_ooool2o`0001Cooooo0_l00002ooooo`;o00002?ooool2o`0000Cooooo
1?l00009ooooo`;o000000?oooooo`000?l000000_l0001Wooooo`007?ooool00ol0003ooooooooo
o`1Roooooa7o00003oooool2o`000004ooooool0003o0000ooooo`;o0000:?ooool2o`0000;ooooo
0_l00002ooooo`;o00000_ooool2o`0000;ooooo0ol00002ooooo`?o00001?ooool4o`0000Wooooo
0_l000000ooooooo0000o`00001Yooooo`007?ooool00ol0003oooooooooo`1Roooooa7o00000_oo
ool2o`000003ooooool0003o000000Sooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo
0_l0000Fooooo`;o00002oooool2o`0000;ooooo0_l00005ooooo`Co000000Goooooo`000?l0003o
0000ooooo`04o`0001Sooooo0_l0001Uooooo`007?ooool00ol0003oooooooooo`1Qoooooa;o0000
0_ooool2o`000003ooooool0003o000000;ooooo0_l0000=ooooo`Co00005_ooool2o`0000_ooooo
0ol00008ooooo`Go00001?ooool2o`0000Gooooo0_l00008ooooo`;o00002Oooool2o`0006Gooooo
000Looooo`03o`000?oooooooooo067ooooo4_l00009ooooo`;o00001?ooool2o`0000Oooooo0_l0
000Uooooo`?o00002oooool4o`000003ooooool0003o000000Kooooo0_l00003ooooo`;o000000?o
ooooo`000?l000000ol000000ooooooo0000o`00001/ooooo`007?ooool00ol0003oooooooooo`1R
oooooa7o00001Oooool2o`0000Sooooo0_l0000Oooooo`;o00000_ooool2o`00017ooooo0_l00006
ooooo`;o000000?oooooo`000?l000002oooool2o`000004ooooool0003o0000ooooo`Go00002Ooo
ool2o`00067ooooo000Looooo`;o0000H_oooolCo`0000Cooooo0_l0000Xooooo`?o00000_ooool2
o`0000oooooo1?l0000Eooooo`Co000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00
0008ooooo`;o0000HOooool001cooooo00?o0000ooooooooool0HOoooolCo`0000kooooo0_l00000
0ooooooo0000o`000008ooooo`;o00001Oooool2o`0000[ooooo0_l0000Dooooo`;o00001Oooool2
o`0000Kooooo0_l00008ooooo`Co000000?oooooo`000?l000001?ooool4o`000004ooooool0003o
0000o`0006Gooooo000Looooo`03o`000?oooooooooo067ooooo4_l00004ooooo`;o00002Oooool2
o`000003ooooool0003o000000Sooooo0_l00005ooooo`;o00005Oooool2o`00013ooooo0_l00006
ooooo`Co000000?oooooo`000?l000001?ooool7o`0000Gooooo0_l000001?oooooo0000o`000?l0
001Uooooo`007?ooool00ol0003oooooooooo`1Qoooooa;o00001?ooool3o`0003?ooooo0_l0000H
ooooo`Co000000?oooooo`000?l000001?ooool7o`0000Gooooo2Ol0001Rooooo`007?ooool00ol0
003oooooooooo`1Qooooo`Co000000?oooooo`000?l000002ol000000ooooooo0000o`000004o`00
04Cooooo1?l00005ooooo`;o00004?ooool2o`0000?ooooo2ol0001Pooooo`007?ooool00ol0003o
ooooooooo`1Qoooooa3o00000oooool5o`0000oooooo0_l0000Zooooo`;o00002?ooool4o`0000_o
oooo0_l00007ooooo`;o000000Goooooo`000?l0003o0000ooooo`0=o`0005oooooo000Looooo`03
o`000?oooooooooo067ooooo4?l0000@ooooo`;o00000_ooool2o`000003ooooool0003o000002[o
oooo0_l000000ooooooo0000o`00000;ooooo`;o00001oooool2o`0000Gooooo5_l0001Oooooo`00
7?ooool00ol0003oooooooooo`1Rooooo`oo000000?oooooo`000?l000001Oooool4o`0000?ooooo
0ol00002ooooo`;o00005oooool2o`0001Oooooo0_l0000;ooooo`;o00003OoooolFo`000003oooo
ool0003o000005gooooo000Looooo`03o`000?oooooooooo06;ooooo3_l00002ooooo`;o00001Ooo
ool4o`0000?ooooo0_l00007ooooo`;o00001oooool2o`0000?ooooo0_l00005ooooo`;o00002_oo
ool2o`0001kooooo0_l000000ooooooo0000o`000004oooooaKo000000?oooooo`000?l00000GOoo
ool001cooooo00?o0000ooooooooool0Hoooool:o`000003ooooool0003o000000;o00001?ooool2
o`00017ooooo0_l00007ooooo`Co000000?oooooo`000?l000002?ooool2o`0000?ooooo0_l00002
ooooo`;o00000_ooool2o`0001[ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o000000Co
ooooo`000?l0003ooooo4_l0001Pooooo`007?ooool00ol0003oooooooooo`1Sooooo`Wo00001?oo
ool2o`0000Cooooo0_l0000?ooooo`;o00002oooool2o`0000Sooooo1Ol00003ooooo`?o00001Ooo
ool2o`0001Kooooo0_l00002ooooo`;o00000_ooool5o`000004ooooool0003o0000oooooa7o0000
0oooool2o`0005cooooo000Looooo`03o`000?oooooooooo06?ooooo1?l000001?oooooo0000o`00
0?l0000>ooooo`;o00003?ooool2o`0000Kooooo0_l0000=ooooo`Co00001Oooool2o`0000;ooooo
0_l0000;ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Kooooo0ol00004oooooa?o0000
00?oooooo`000?l000000_l0001Looooo`007?ooool00ol0003oooooooooo`1Tooooo`Ko00003ooo
ool2o`0000Wooooo0_l00004ooooo`;o00000oooool2o`0000gooooo0_l0000;ooooo`;o000000?o
ooooo`000?l000002?ooool2o`000003ooooool0003o000000;o00003oooool3o`0000Cooooo6?l0
001Looooo`007?ooool00ol0003oooooooooo`1Tooooo`Ko00003Oooool2o`0000_ooooo0_l00004
ooooo`?o00000_ooool2o`0000gooooo0_l000000ooooooo0000o`00000;ooooo`Co00001_ooool2
o`0000?ooooo0ol0000=ooooo`;o00001Oooool3o`000003ooooool0003o0000013o0000Goooool0
0006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@
olc<c006ooooo`03o`000?oooooooooo06Gooooo1_l0000<ooooo`;o00001_ooool3o`0000;ooooo
0_l00005ooooo`;o00000_ooool2o`0000?ooooo0_l0000;ooooo`;o00001Oooool2o`0000Kooooo
0ol00005ooooo`;o00001?ooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`000003oooo
ool0003o0000013o000000?oooooo`000?l00000GOooool00006oooooomgMgOoV9RHoooooonHV9So
MgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo
06Gooooo1_l00008ooooo`Co00000_ooool2o`0000Cooooo0ol0000;ooooo`;o00001Oooool2o`00
01;ooooo0_l00002ooooo`;o00000oooool3o`0000Cooooo0_l0000<ooooo`;o00001oooool2o`00
00;ooooo0ol000000ooooooo0000o`00000Co`0005gooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
06Gooooo1ol00002ooooo`;o00000_ooool5o`0000;ooooo0_l000000ooooooo0000o`000005oooo
o`;o00002?ooool2o`0001gooooo0_l00004ooooo`;o00001_ooool2o`0000Sooooo0ol00008oooo
o`?o000000Coooooo`000?l0003o00000_oooolDo`0005gooooo00000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000IOooool8
o`000003ooooool0003o000000;ooooo1?l00002ooooo`;o00000_ooool2o`0000Gooooo0_l0000d
ooooo`?o00002?ooool3o`0000?ooooo0_l00004ooooo`;o000000Coooooo`000?l0003o00000_oo
ool?o`0000;ooooo0_l0001Nooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09
ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`1Tooooo`Wo00002Ooo
ool4o`0002Cooooo0_l00007ooooo`;o00004?ooool2o`0000Oooooo0_l00006ooooo`;o00001ooo
ool2o`0000;ooooo5?l0001Nooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09
ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0I?ooool9o`0000Wooooo1Ol0000S
ooooo`;o00001oooool2o`0000_ooooo0_l00002ooooo`?o00001_ooool3o`0000cooooo0_l00000
0ooooooo0000o`000002oooooaCo0000G_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2ooo
ool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo06?ooooo3?l00006ooooo`?o000000Co
ooooo`000?l0003ooooo0_l00007ooooo`;o00001_ooool2o`0000Kooooo0_l00006ooooo`?o0000
4Oooool2o`000003ooooool0003o000000;ooooo0ol00006ooooo`;o00001?ooool2o`0000Kooooo
0ol000000ooooooo0000o`000003oooooa;o0000Goooool00006ooooooo^k^ko<S8bo`000?lb<S;o
k^k^3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo06?ooooo3?l00004oooo
o`Ko00000oooool3o`0000Kooooo0_l000000ooooooo0000o`000003ooooo`;o00001_ooool2o`00
00Cooooo1Ol0000>ooooo`;o000000?oooooo`000?l000000_ooool3o`0000Sooooo1?l00003oooo
o`?o00001Oooool3o`000003ooooool0003o000000?ooooo4_l0001Oooooo`007?ooool00ol0003o
ooooooooo`1Rooooo`go000000Coooooo`000?l0003ooooo0ol000001?oooooo0000o`000?ooool5
o`0000Wooooo0ol0000:ooooo`;o00001?ooool2o`000003ooooool0003o000000?ooooo0_l00003
ooooo`;o00000oooool3o`0000Gooooo0ol00008ooooo`Co000000?oooooo`000?l000000ol00006
ooooo`;o000000?oooooo`000?l000000oooool@o`00067ooooo000Looooo`03o`000?oooooooooo
06;ooooo4?l00008ooooo`?o000000?oooooo`000?l000001_ooool2o`000003ooooool0003o0000
00[ooooo0_l00009ooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo0_l0000Coooo
o`;o000000Coooooo`000?l0003o00002_ooool3o`0000Cooooo2?l000000ooooooo0000o`000004
o`00067ooooo000Looooo`03o`000?oooooooooo067ooooo2ol000001?oooooo0000o`000?l00006
ooooo`;o00000oooool2o`000004ooooool0003o0000o`0000Gooooo0_l00007ooooo`;o00000_oo
ool2o`0000Cooooo0_l00005ooooo`;o00004oooool2o`0000_ooooo0_l00002ooooo`;o00002Ooo
ool4o`0000Gooooo3?l0001Sooooo`007?ooool00ol0003oooooooooo`1Poooooa7o00000oooool5
o`0000;ooooo0_l00002ooooo`;o00003_ooool2o`000004ooooool0003o0000o`0000Cooooo0_l0
0008ooooo`;o00004?ooool2o`0000oooooo0_l00007ooooo`Go00002?ooool4o`000004ooooool0
003o0000o`0006Gooooo000Looooo`03o`000?oooooooooo063ooooo4Ol00003ooooo`;o000000?o
ooooo`000?l000000_l0000<ooooo`;o00002Oooool2o`0000oooooo0_l0000;ooooo`?o00001?oo
ool4o`0000Cooooo0_l0000<ooooo`Co0000N?ooool001cooooo00?o0000ooooooooool0HOooool@
o`000004ooooool0003o0000ooooo`?o000000?oooooo`000?l000002?ooool2o`0000;ooooo0_l0
000Iooooo`?o00002_ooool4o`0000Cooooo1?l00002ooooo`Co00001Oooool2o`0000Gooooo0_l0
00000ooooooo0000o`000002o`0007Gooooo000Looooo`03o`000?oooooooooo067ooooo4?l00000
1?oooooo0000o`000?ooool3o`0000_ooooo0_l00003ooooo`;o00003oooool2o`0000Oooooo0ol0
00000ooooooo0000o`000007ooooo`;o00001oooool2o`0000?ooooo0_l00005ooooo`Ko00000ooo
ool7o`0007Gooooo000Looooo`03o`000?oooooooooo05oooooo4_l0000Dooooo`;o000000?ooooo
o`000?l000001Oooool2o`0000Sooooo0_l00005ooooo`;o00001?ooool2o`0000_ooooo0ol00002
ooooo`;o00002Oooool9o`0000;ooooo0_l00002ooooo`;o0000MOooool001cooooo00?o0000oooo
ooooool0GooooolBo`0000Sooooo0_l0000:ooooo`;o00002?ooool2o`0000?ooooo0_l00009oooo
o`?o000000?oooooo`000?l000002?ooool2o`0000Cooooo0ol0000;ooooo`co00001Oooool2o`00
07Gooooo000Looooo`03o`000?oooooooooo05oooooo4_l00003ooooo`Co000000?oooooo`000?l0
00006Oooool2o`000003ooooool0003o000000Kooooo0ol000000ooooooo0000o`000007ooooo`?o
00000_ooool4o`0000_ooooo3_l00004ooooo`;o0000MOooool001cooooo00?o0000ooooooooool0
GooooolBo`0000?ooooo1?l00004ooooo`;o00001oooool5o`0000Oooooo0_l00004ooooo`;o0000
4oooool2o`0000?ooooo1?l00002ooooo`;o00001?ooool2o`000003ooooool0003o000000co0000
1?ooool2o`0007Gooooo000Looooo`;o0000H?ooool@o`000003ooooool0003o000000;ooooo0_l0
0006ooooo`;o00001oooool7o`0000Gooooo1?l0000:ooooo`;o00002oooool2o`0000Oooooo1?l0
0004ooooo`Go000000?oooooo`000?l000003ol0001eooooo`007?ooool00ol0003oooooooooo`1O
oooooa3o000000?oooooo`000?l000006?ooool2o`0000Oooooo0_l000000ooooooo0000o`000004
ooooo`Go00002oooool2o`0000Oooooo1Ol00003oooooaKo0000M_ooool001cooooo00?o0000oooo
ooooool0Goooool@o`0000Sooooo0_l0000Fooooo`;o00001Oooool4o`0000;ooooo0ol0000=oooo
o`;o00001ooooolIo`0000?ooooo0ol0001eooooo`007?ooool00ol0003oooooooooo`1Oooooo`Co
00000_ooool8o`0000Cooooo0_l00004ooooo`;o00000oooool2o`0000oooooo1?l00003ooooo`Ko
00001Oooool2o`0000;ooooo0_l00003ooooo`Co00001oooool2o`000003ooooool0003o000001Go
000000Coooooo`000?l0003ooooo0ol0001eooooo`007?ooool00ol0003oooooooooo`1Nooooo`Ko
000000?oooooo`000?l000001Ol00005ooooo`;o00002Oooool2o`000003ooooool0003o000000co
oooo1?l000000ooooooo0000o`000002o`0000Cooooo0_l00003ooooo`;o00000_ooool2o`0000?o
oooo1?l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l000001?oooooo0000o`000?ooool@
o`000005ooooool0003o0000o`000?ooool00_l0001fooooo`007?ooool00ol0003oooooooooo`1N
ooooo`Ko00000_ooool2o`0000;ooooo0_l00005ooooo`;o00003?ooool2o`0000?ooooo0_l0000<
ooooo`;o00001_ooool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o00001Oooool4
o`0000Oooooo5_l000001?oooooo0000o`000?l0001fooooo`007?ooool00ol0003oooooooooo`1O
ooooo`Ko000000Coooooo`000?l0003ooooo0_l00006ooooo`;o00001?ooool2o`0000_ooooo0_l0
00000ooooooo0000o`00000Dooooo`;o00001?ooool2o`0000;ooooo0_l00005ooooo`?o00002?oo
oolEo`0000;ooooo0_l0001gooooo`007?ooool00ol0003oooooooooo`1Oooooo`Ko00001?ooool3
o`0000_ooooo0_l0000:ooooo`;o000000?oooooo`000?l000000_l0000<ooooo`;o00000_ooool2
o`0000cooooo0_l0000?oooooaCo000000?oooooo`000?l000000_l0001gooooo`007?ooool00ol0
003oooooooooo`1Oooooo`Ko00001Oooool2o`00013ooooo0_l00005ooooo`;o000000?oooooo`00
0?l000001?l0000:ooooo`;o00000_ooool2o`0000cooooo0_l0000?oooooaCo000000?oooooo`00
0?l000000_l0001gooooo`007?ooool00ol0003oooooooooo`1Oooooo`So00002?ooool2o`0000_o
oooo0_l00008ooooo`Oo00000_ooool2o`0000Gooooo0_l00002ooooo`Co00002Oooool2o`000003
ooooool0003o000000?ooooo0_l00007oooooaCo00000oooool3o`0007Oooooo000Looooo`03o`00
0?oooooooooo067ooooo1_l000000ooooooo0000o`000005ooooo`;o00000oooool2o`00013ooooo
0_l000000ooooooo0000o`000002o`0000;ooooo0_l0000;ooooo`;o00001oooool4o`000003oooo
ool0003o000000?ooooo0_l00005oooooaGo00000_ooool2o`0007[ooooo000Looooo`03o`000?oo
oooooooo067ooooo1_l000000ooooooo0000o`000002ooooo`?o000000?oooooo`000?l000000_oo
ool2o`0001Wooooo0_l00003ooooo`;o00001?ooool2o`0000;ooooo0ol00002ooooo`So00001ooo
ool2o`0000;ooooo6Ol0001jooooo`007?ooool00ol0003oooooooooo`1Qooooo`Wo00000_ooool8
o`0000Sooooo0_l0000Aooooo`;o00000oooool2o`0000?ooooo0ol00002ooooo`?o000000?ooooo
o`000?l000002Ol00002ooooo`;o000000?oooooo`000?l000000oooool3o`000005ooooool0003o
0000o`000?ooool04?l0001jooooo`007?ooool00ol0003oooooooooo`1Rooooo`So00001?ooool2
o`0000;ooooo0_l00008ooooo`;o00000oooool2o`0000_ooooo0_l00006ooooo`;o000000?ooooo
o`000?l000000ol00003ooooo`Go00001?ooool7o`0000Kooooo0ol000000ooooooo0000o`00000A
o`0007_ooooo000Looooo`03o`000?oooooooooo06?ooooo1ol00008ooooo`ko000000Coooooo`00
0?l0003ooooo0_l00002ooooo`?o00000_ooool3o`0000Kooooo0_l00002ooooo`Co000000?ooooo
o`000?l000000_l00004ooooo`[o000000?oooooo`000?l000001?ooool2o`0000Cooooo3ol0001l
ooooo`007?ooool00ol0003oooooooooo`1Sooooo`Co000000?oooooo`000?l000007?l00002oooo
o`?o00000_ooool3o`0000Cooooo0_l00002ooooo`Ko000000?oooooo`000?l000000oooool=o`00
0003ooooool0003o000000_ooooo1ol000000ooooooo0000o`000003o`0007gooooo000Looooo`;o
0000I_oooolWo`0000;ooooo0ol00003ooooo`;o00000_ooool2o`0000;ooooo0_l00004ooooo`oo
000000?oooooo`000?l000000_l0000;ooooo`;o00001?ooool2o`00083ooooo000Looooo`03o`00
0?oooooooooo06Kooooo0_l000000ooooooo0000o`000002o`0000;ooooo8_l0000:ooooo`?o0000
0oooool@o`000003ooooool0003o000000;o0000Toooool001cooooo00?o0000ooooooooool0J_oo
ool3o`0000;ooooo1ol00003oooooaOo00002Oooool4o`0000?ooooo4Ol0002Hooooo`007?ooool0
0ol0003oooooooooo`1moooooaGo00001oooool2o`0000Cooooo4_l000000ooooooo0000o`00002E
ooooo`007?ooool00ol0003oooooooooo`1noooooaKo00000oooool4o`0000?ooooo4_l00002oooo
o`;o0000UOooool001cooooo00?o0000ooooooooool0P?oooolEo`0000;ooooo0_l00005oooooa;o
0000VOooool001cooooo00?o0000ooooooooool0P?oooolEo`0000Wooooo4ol0002Hooooo`007?oo
ool00ol0003oooooooooo`20oooooaCo00002_oooolCo`0009Sooooo000Looooo`03o`000?oooooo
oooo08?ooooo4Ol0000:oooooa;o0000VOooool001cooooo00?o0000ooooooooool0PooooolBo`00
00Wooooo4ol0002Hooooo`007?ooool00ol0003oooooooooo`23ooooo`ko000000Coooooo`000?l0
003o00002Oooool?o`0000;ooooo0_l0002Hooooo`007?ooool00ol0003oooooooooo`24oooooa3o
00002oooool>o`0009cooooo000Looooo`03o`000?oooooooooo08Kooooo3?l0000>ooooo`Co0000
00?oooooo`000?l000001?l0002Nooooo`007?ooool00ol0003oooooooooo`27ooooo`Oo00004_oo
ool5o`0000;ooooo1?l0002Nooooo`007?ooool00ol0003oooooooooo`2Pooooo`Oo000000Cooooo
o`000?l0003o0000W_ooool001cooooo00?o0000ooooooooool0XOooool6o`000003ooooool0003o
000009oooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooood[o
oooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B401_ooool00ol0003oooooooooo`3ooooood[ooooo00000ooooooo410@ooooo`02oooo
o`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo0?ooooooB_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Olb
<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0003ooooood[ooooo00000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00Wooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooo
oooo0?ooooooB_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol@
413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0oooooom:ooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003ooooo
ooooo`3ooooood[ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@06ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001;ooooo1?l000000ol@413ooooooooo
o`03ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo0ol0003ooooo
od[ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0
oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooo
oooo0?ooooooD_ooool001;ooooo00?oEEEEofIVI_l00000oooooomDooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00ZOooool01?l@413o0000o`000?ooool2o`000003oa0@4?oo
oooooooo01Kooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`;o000000?o410@ooooooooool0
T_ooool00:[ooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00003Oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo09?ooooo002Zooooo`05o`000?ooooooooooooooool00000
7Oooool00ol0003oooooooooo`05o`0009Cooooo002Zooooo`05o`000?ooooooooooooooool00000
2Oooool6o`0000gooooo00SoMgMgoc8b<_ooooooooooodA4A?oMgMgoooooo`0009Gooooo002Zoooo
o`05o`000?n7QhOoooooojVYZOl000006Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Co
gMgMoeEEEOoooooo0000UOooool00:Wooooo00?o410@o`000?mgMgL00_l000000onHV9Sooooooooo
o`0Gooooo`03o`000?oooooooooo00Gooooo00?oMgMgolc<c?l00000UOooool00<Sooooo00?o0000
ooooooooool01Oooool00oo^k^koA4A4o`00002Eooooo`00b?ooool4o`0000Gooooo00?oMgMgo`00
0?ooool0U?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -20 0 ]
[.5 1.0125 20 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.6883 .64417 Mdot
.66437 .61218 Mdot
.64335 .33236 Mdot
.327 .52348 Mdot
.34962 .35053 Mdot
.6348 .32326 Mdot
.70713 .52858 Mdot
.70981 .49559 Mdot
.65224 .36212 Mdot
.36998 .51534 Mdot
.69389 .4098 Mdot
.38187 .6833 Mdot
.70454 .51886 Mdot
.36006 .51571 Mdot
.32901 .67393 Mdot
.48448 .70053 Mdot
.6893 .62878 Mdot
.34754 .34798 Mdot
.47298 .7223 Mdot
.64753 .36981 Mdot
.45362 .35531 Mdot
.34537 .5276 Mdot
.69496 .61462 Mdot
.36226 .52133 Mdot
.47601 .72249 Mdot
.57772 .69963 Mdot
.69177 .64367 Mdot
.48108 .71827 Mdot
.38109 .69112 Mdot
.69334 .49805 Mdot
.49416 .70624 Mdot
.32983 .62402 Mdot
.43962 .29771 Mdot
.58196 .66489 Mdot
.69833 .44131 Mdot
.68644 .40422 Mdot
.64433 .31455 Mdot
.69548 .40078 Mdot
.70388 .48347 Mdot
.69957 .43732 Mdot
.69725 .43646 Mdot
.5817 .69998 Mdot
.68411 .40937 Mdot
.68244 .52093 Mdot
.29915 .62744 Mdot
.61744 .66502 Mdot
.53442 .26034 Mdot
.28343 .61476 Mdot
.67789 .6433 Mdot
.55118 .26436 Mdot
.32037 .59768 Mdot
.72072 .52963 Mdot
.43241 .32879 Mdot
.60973 .70698 Mdot
.70038 .50854 Mdot
.47858 .72507 Mdot
.62329 .34711 Mdot
.30934 .58376 Mdot
.38253 .70032 Mdot
.59757 .66056 Mdot
.35571 .53759 Mdot
.30971 .34433 Mdot
.50471 .68682 Mdot
.61534 .35 Mdot
.65017 .34554 Mdot
.71237 .4034 Mdot
.67411 .59151 Mdot
.71088 .41196 Mdot
.33599 .50177 Mdot
.52854 .2683 Mdot
.28489 .60355 Mdot
.6935 .41018 Mdot
.59378 .68209 Mdot
.33686 .51381 Mdot
.66669 .64603 Mdot
.70798 .41857 Mdot
.35385 .35629 Mdot
.58195 .6928 Mdot
.56863 .27682 Mdot
.35275 .47354 Mdot
.34242 .53467 Mdot
.73746 .49787 Mdot
.38974 .71564 Mdot
.61093 .68794 Mdot
.31143 .62834 Mdot
.73846 .53236 Mdot
.32967 .5545 Mdot
.48985 .70402 Mdot
.48522 .7216 Mdot
.37117 .68092 Mdot
.6082 .28768 Mdot
.68494 .59969 Mdot
.34644 .51566 Mdot
.34245 .4959 Mdot
.31584 .60111 Mdot
.31636 .62747 Mdot
.4879 .72293 Mdot
.4113 .30891 Mdot
.69898 .4258 Mdot
.44519 .32332 Mdot
.71009 .41433 Mdot
.43279 .33641 Mdot
.32127 .51848 Mdot
.61755 .31976 Mdot
.56648 .7067 Mdot
.41763 .3031 Mdot
.70584 .42351 Mdot
.34636 .51268 Mdot
.68858 .40165 Mdot
.68482 .60335 Mdot
.49928 .71013 Mdot
.32271 .37664 Mdot
.35603 .37868 Mdot
.70653 .62518 Mdot
.32635 .49462 Mdot
.33767 .56011 Mdot
.35126 .53215 Mdot
.67771 .59162 Mdot
.64894 .36215 Mdot
.57894 .28863 Mdot
.67262 .61078 Mdot
.69709 .42881 Mdot
.68589 .63418 Mdot
.45815 .30773 Mdot
.65092 .35322 Mdot
.44073 .30797 Mdot
.4056 .32805 Mdot
.32772 .58452 Mdot
.31978 .62483 Mdot
.44327 .3476 Mdot
.61547 .31685 Mdot
.6702 .61207 Mdot
.70744 .51092 Mdot
.34606 .49377 Mdot
.60957 .68466 Mdot
.69865 .51058 Mdot
.33992 .3771 Mdot
.33053 .38994 Mdot
.59837 .68352 Mdot
.32053 .50457 Mdot
.69575 .39868 Mdot
.7182 .49147 Mdot
.31629 .58579 Mdot
.61192 .679 Mdot
.34916 .35806 Mdot
.71682 .48846 Mdot
.41723 .28715 Mdot
.50222 .71527 Mdot
.27824 .65775 Mdot
.73575 .49974 Mdot
.31734 .5944 Mdot
.47221 .34104 Mdot
.3038 .35362 Mdot
.69944 .50361 Mdot
.32613 .53733 Mdot
.67432 .63114 Mdot
.60648 .67984 Mdot
.41293 .70722 Mdot
.42483 .29898 Mdot
.31741 .57588 Mdot
.43531 .34045 Mdot
.40613 .32226 Mdot
.35743 .51376 Mdot
.60844 .66029 Mdot
.55868 .6941 Mdot
.29227 .59452 Mdot
.65359 .32771 Mdot
.349 .34753 Mdot
.68785 .41224 Mdot
.31135 .62038 Mdot
.31304 .60134 Mdot
.40891 .69797 Mdot
.7212 .49698 Mdot
.70849 .45127 Mdot
.55488 .28147 Mdot
.71584 .41127 Mdot
.70042 .45047 Mdot
.60962 .33081 Mdot
.3929 .69196 Mdot
.31625 .37694 Mdot
.41763 .32521 Mdot
.29596 .59128 Mdot
.31942 .63645 Mdot
.3731 .68006 Mdot
.44897 .35621 Mdot
.47864 .33101 Mdot
.64266 .62892 Mdot
.68395 .4226 Mdot
.33192 .54214 Mdot
.49631 .73279 Mdot
.32508 .60953 Mdot
.7105 .46386 Mdot
.71147 .50881 Mdot
.63236 .37182 Mdot
.64412 .37146 Mdot
.55222 .27176 Mdot
.42548 .71714 Mdot
.4175 .69826 Mdot
.33428 .53375 Mdot
.43842 .31973 Mdot
.50737 .68824 Mdot
.30521 .35091 Mdot
.68335 .63032 Mdot
.73673 .49386 Mdot
.27468 .6194 Mdot
.46683 .71686 Mdot
.66019 .32936 Mdot
.60643 .28415 Mdot
.41224 .33774 Mdot
.31502 .35648 Mdot
.304 .58799 Mdot
.70341 .62485 Mdot
.31854 .59312 Mdot
.44309 .30075 Mdot
.35707 .38009 Mdot
.6818 .61164 Mdot
.28026 .62321 Mdot
.70146 .51996 Mdot
.60443 .29773 Mdot
.32958 .55481 Mdot
.34262 .51008 Mdot
.58447 .69285 Mdot
.33331 .49851 Mdot
.4839 .73186 Mdot
.4927 .71137 Mdot
.54806 .27326 Mdot
.71355 .42547 Mdot
.69234 .49438 Mdot
.53268 .26012 Mdot
.59488 .69097 Mdot
.70674 .64426 Mdot
.62487 .32952 Mdot
.4368 .3624 Mdot
.69385 .40595 Mdot
.33537 .36165 Mdot
.62271 .3226 Mdot
.34415 .34773 Mdot
.38021 .70142 Mdot
.61029 .31032 Mdot
.33034 .3776 Mdot
.34414 .67389 Mdot
.40811 .32621 Mdot
.33453 .39597 Mdot
.7071 .531 Mdot
.65556 .62314 Mdot
.30075 .58576 Mdot
.42629 .32903 Mdot
.44761 .3077 Mdot
.39569 .69534 Mdot
.40554 .34254 Mdot
.42213 .30513 Mdot
.39915 .69571 Mdot
.33693 .3392 Mdot
.72266 .47083 Mdot
.49516 .70688 Mdot
.68694 .63138 Mdot
.32949 .5052 Mdot
.71323 .43637 Mdot
.69838 .5089 Mdot
.34702 .55491 Mdot
.7379 .51853 Mdot
.70763 .53327 Mdot
.35861 .52254 Mdot
.69974 .48833 Mdot
.60976 .68739 Mdot
.27576 .61549 Mdot
.5964 .67758 Mdot
.3604 .51861 Mdot
.70084 .48577 Mdot
.54066 .2605 Mdot
.58618 .69848 Mdot
.34417 .52001 Mdot
.33002 .52514 Mdot
.43607 .32176 Mdot
.49693 .71166 Mdot
.71201 .55052 Mdot
.38313 .68411 Mdot
.60447 .33246 Mdot
.41339 .71704 Mdot
.2971 .36314 Mdot
.41685 .28649 Mdot
.61144 .67824 Mdot
.40359 .34089 Mdot
.6299 .3262 Mdot
.31067 .59287 Mdot
.27703 .63244 Mdot
.30331 .62719 Mdot
.42207 .30753 Mdot
.39144 .71726 Mdot
.70439 .54041 Mdot
.49798 .72637 Mdot
.43774 .349 Mdot
.62824 .34705 Mdot
.43903 .33269 Mdot
.31417 .62881 Mdot
.69273 .60875 Mdot
.47108 .70847 Mdot
.60411 .31963 Mdot
.69215 .61687 Mdot
.28552 .60878 Mdot
.71194 .41366 Mdot
.29317 .35214 Mdot
.70107 .54091 Mdot
.47715 .71163 Mdot
.41331 .71471 Mdot
.53106 .26858 Mdot
.59442 .69658 Mdot
.70373 .4975 Mdot
.59474 .68031 Mdot
.31928 .58059 Mdot
.31862 .56501 Mdot
.61164 .67451 Mdot
.31403 .38639 Mdot
.56911 .28454 Mdot
.69765 .40893 Mdot
.43817 .31125 Mdot
.52732 .27655 Mdot
.68313 .64212 Mdot
.62144 .31746 Mdot
.31564 .5107 Mdot
.60122 .29852 Mdot
.46934 .70998 Mdot
.52618 .27285 Mdot
.41393 .70099 Mdot
.30479 .63275 Mdot
.6156 .35428 Mdot
.41805 .30064 Mdot
.30988 .58562 Mdot
.60797 .68773 Mdot
.33065 .62594 Mdot
.36779 .53176 Mdot
.42399 .71509 Mdot
.62666 .34607 Mdot
.3182 .5091 Mdot
.48633 .71101 Mdot
.47681 .71486 Mdot
.68012 .6275 Mdot
.42994 .31441 Mdot
.34332 .38019 Mdot
.33287 .39375 Mdot
.39495 .30234 Mdot
.36466 .6781 Mdot
.31542 .54173 Mdot
.60062 .68814 Mdot
.5524 .26643 Mdot
.65295 .63309 Mdot
.44199 .29977 Mdot
.71044 .49554 Mdot
.7085 .45358 Mdot
.32787 .55141 Mdot
.29022 .34181 Mdot
.46208 .71657 Mdot
.67008 .64228 Mdot
.5904 .68481 Mdot
.70493 .49636 Mdot
.39478 .72537 Mdot
.36518 .49193 Mdot
.34488 .55484 Mdot
.71492 .49509 Mdot
.44359 .30431 Mdot
.38686 .70284 Mdot
.28748 .6601 Mdot
.68704 .47825 Mdot
.30141 .61828 Mdot
.58281 .66896 Mdot
.29553 .62998 Mdot
.32686 .582 Mdot
.29453 .61354 Mdot
.60341 .69003 Mdot
.45757 .73085 Mdot
.28178 .6531 Mdot
.64886 .30704 Mdot
.27325 .6244 Mdot
.31711 .38589 Mdot
.34128 .5146 Mdot
.30083 .58891 Mdot
.34785 .36215 Mdot
.70502 .62729 Mdot
.31185 .60404 Mdot
.72345 .47754 Mdot
.34653 .52135 Mdot
.68732 .41165 Mdot
.39845 .71003 Mdot
.33046 .6003 Mdot
.48635 .71343 Mdot
.69462 .61235 Mdot
.70736 .48384 Mdot
.6891 .42354 Mdot
.4249 .34833 Mdot
.69831 .50821 Mdot
.30919 .62465 Mdot
.3968 .71147 Mdot
.70677 .62405 Mdot
.40869 .32399 Mdot
.68321 .59829 Mdot
.27268 .3571 Mdot
.71167 .52819 Mdot
.4317 .33398 Mdot
.42028 .72404 Mdot
.7187 .52009 Mdot
.71997 .47199 Mdot
.49964 .70952 Mdot
.44408 .30503 Mdot
.69174 .64143 Mdot
.52838 .27067 Mdot
.43204 .30137 Mdot
.70065 .50495 Mdot
.29837 .62727 Mdot
.49423 .72209 Mdot
.702 .4942 Mdot
.57767 .67567 Mdot
.50558 .71199 Mdot
.34842 .51973 Mdot
.57991 .70288 Mdot
.6771 .59558 Mdot
.30998 .5766 Mdot
.33751 .55017 Mdot
.63609 .33779 Mdot
.42643 .3055 Mdot
.42639 .30721 Mdot
.40397 .32481 Mdot
.60098 .31043 Mdot
.56497 .28675 Mdot
.71073 .43079 Mdot
.33109 .59652 Mdot
.71735 .42476 Mdot
.42639 .33214 Mdot
.63711 .33654 Mdot
.29836 .63035 Mdot
.38392 .72095 Mdot
.70878 .47827 Mdot
.56197 .29108 Mdot
.32267 .53777 Mdot
.67625 .63478 Mdot
.72267 .52054 Mdot
.4038 .68839 Mdot
.54487 .26836 Mdot
.30441 .34584 Mdot
.31759 .51808 Mdot
.72144 .51017 Mdot
.56724 .68752 Mdot
.72111 .50919 Mdot
.29638 .59367 Mdot
.3093 .60989 Mdot
.65903 .62758 Mdot
.31567 .38522 Mdot
.38669 .68612 Mdot
.36155 .52638 Mdot
.55768 .26816 Mdot
.65357 .63618 Mdot
.32819 .39592 Mdot
.3779 .69413 Mdot
.40686 .33696 Mdot
.33428 .33656 Mdot
.33527 .53011 Mdot
.40431 .69695 Mdot
.4524 .3348 Mdot
.69506 .50183 Mdot
.32206 .38918 Mdot
.65752 .32203 Mdot
.68791 .6154 Mdot
.71273 .42932 Mdot
.4029 .34526 Mdot
.69612 .41086 Mdot
.35541 .6757 Mdot
.4226 .33876 Mdot
.69687 .46801 Mdot
.28717 .41834 Mdot
.41499 .31206 Mdot
.62751 .35139 Mdot
.31706 .58151 Mdot
.39594 .69126 Mdot
.3489 .51877 Mdot
.34137 .38157 Mdot
.66793 .60611 Mdot
.69512 .44531 Mdot
.6973 .48089 Mdot
.35269 .50723 Mdot
.61173 .67756 Mdot
.65855 .59654 Mdot
.44105 .32698 Mdot
.32415 .36772 Mdot
.33398 .36436 Mdot
.34782 .50424 Mdot
.3845 .71627 Mdot
.60012 .69091 Mdot
.34416 .5193 Mdot
.34787 .50352 Mdot
.54336 .28033 Mdot
.58138 .70557 Mdot
.60918 .31375 Mdot
.46805 .72148 Mdot
.31782 .53836 Mdot
.71393 .41788 Mdot
.69804 .52299 Mdot
.4299 .31066 Mdot
.69223 .49431 Mdot
.55231 .2835 Mdot
.4258 .30736 Mdot
.34357 .52029 Mdot
.70199 .63778 Mdot
.34469 .51785 Mdot
.34636 .51994 Mdot
.29468 .61886 Mdot
.3158 .5433 Mdot
.62268 .28814 Mdot
.31843 .36952 Mdot
.37919 .69858 Mdot
.60704 .33031 Mdot
.66064 .33633 Mdot
.31739 .60205 Mdot
.33786 .52395 Mdot
.35426 .52756 Mdot
.57341 .69555 Mdot
.49872 .7231 Mdot
.71677 .51488 Mdot
.65873 .62757 Mdot
.33106 .55371 Mdot
.52855 .26142 Mdot
.31031 .60325 Mdot
.60921 .67356 Mdot
.70605 .4428 Mdot
.72916 .54996 Mdot
.40887 .34873 Mdot
.44902 .31539 Mdot
.42276 .30578 Mdot
.40357 .32254 Mdot
.68539 .40669 Mdot
.63812 .33624 Mdot
.29441 .36542 Mdot
.31745 .55941 Mdot
.3348 .54651 Mdot
.31188 .61293 Mdot
.53712 .28208 Mdot
.45263 .30041 Mdot
.32183 .57745 Mdot
.51349 .70114 Mdot
.61499 .29925 Mdot
.40994 .3116 Mdot
.61967 .64838 Mdot
.68825 .60876 Mdot
.54084 .26953 Mdot
.69604 .40107 Mdot
.33112 .38016 Mdot
.50174 .2899 Mdot
.67836 .59934 Mdot
.52126 .68969 Mdot
.62268 .30249 Mdot
.3943 .71002 Mdot
.46101 .69863 Mdot
.62526 .31479 Mdot
.49883 .7273 Mdot
.67642 .59086 Mdot
.40712 .32615 Mdot
.40261 .716 Mdot
.39797 .69819 Mdot
.64242 .37701 Mdot
.33085 .51668 Mdot
.59942 .28738 Mdot
.62843 .34913 Mdot
.42397 .31564 Mdot
.62672 .34574 Mdot
.70242 .53854 Mdot
.61473 .32729 Mdot
.5737 .68251 Mdot
.34549 .50011 Mdot
.6045 .70988 Mdot
.31981 .67521 Mdot
.33829 .55774 Mdot
.71581 .53541 Mdot
.71219 .43538 Mdot
.34735 .54479 Mdot
.35236 .35676 Mdot
.63233 .35005 Mdot
.55689 .27655 Mdot
.48973 .7263 Mdot
.53024 .27606 Mdot
.69446 .61068 Mdot
.712 .42212 Mdot
.71251 .4351 Mdot
.42837 .3029 Mdot
.61212 .68129 Mdot
.68199 .40842 Mdot
.69787 .42993 Mdot
.29249 .35308 Mdot
.30678 .57966 Mdot
.56693 .67886 Mdot
.38733 .70284 Mdot
.34447 .34605 Mdot
.34673 .52362 Mdot
.60883 .31689 Mdot
.5529 .27582 Mdot
.32537 .673 Mdot
.62668 .33132 Mdot
.43342 .31029 Mdot
.56462 .70015 Mdot
.47727 .72566 Mdot
.67103 .60651 Mdot
.33932 .49545 Mdot
.71404 .42793 Mdot
.69097 .61032 Mdot
.44227 .36007 Mdot
.35711 .54007 Mdot
.61361 .664 Mdot
.37489 .69153 Mdot
.34847 .52129 Mdot
.6478 .35459 Mdot
.34844 .36089 Mdot
.41921 .36135 Mdot
.6336 .29611 Mdot
.31708 .34781 Mdot
.66309 .65367 Mdot
.64887 .35613 Mdot
.32807 .35406 Mdot
.39904 .29717 Mdot
.40128 .33715 Mdot
.31828 .36286 Mdot
.31152 .6274 Mdot
.69797 .5039 Mdot
.65965 .61733 Mdot
.30113 .60497 Mdot
.34334 .46382 Mdot
.59244 .71521 Mdot
.43815 .3234 Mdot
.3512 .52153 Mdot
.31139 .5793 Mdot
.60772 .67582 Mdot
.73413 .48665 Mdot
.6189 .35081 Mdot
.44364 .31502 Mdot
.67502 .60407 Mdot
.73775 .49859 Mdot
.64801 .35043 Mdot
.33777 .35761 Mdot
.69381 .51664 Mdot
.70158 .63962 Mdot
.43318 .32618 Mdot
.70699 .52982 Mdot
.62728 .29315 Mdot
.31965 .5982 Mdot
.51156 .70474 Mdot
.63043 .30708 Mdot
.31963 .5969 Mdot
.46452 .71533 Mdot
.55104 .27075 Mdot
.71303 .45845 Mdot
.68407 .60239 Mdot
.70848 .48885 Mdot
.32953 .36813 Mdot
.59209 .68136 Mdot
.68288 .59864 Mdot
.69784 .52331 Mdot
.57771 .71549 Mdot
.3972 .71999 Mdot
.70723 .41936 Mdot
.38351 .70911 Mdot
.31459 .58821 Mdot
.43105 .32525 Mdot
.3168 .37452 Mdot
.71323 .42394 Mdot
.57832 .70004 Mdot
.68976 .54613 Mdot
.32439 .62175 Mdot
.50324 .71984 Mdot
.32655 .38356 Mdot
.64082 .6367 Mdot
.71356 .45624 Mdot
.71614 .518 Mdot
.55689 .26794 Mdot
.35332 .36195 Mdot
.30821 .63102 Mdot
.53138 .28552 Mdot
.30894 .61732 Mdot
.72446 .5197 Mdot
.4623 .71847 Mdot
.68373 .61785 Mdot
.7049 .41411 Mdot
.46712 .71046 Mdot
.38033 .68564 Mdot
.34064 .54736 Mdot
.54732 .27406 Mdot
.67737 .58708 Mdot
.44234 .28886 Mdot
.33474 .56195 Mdot
.36152 .53459 Mdot
.44947 .30836 Mdot
.33038 .59467 Mdot
.71585 .46354 Mdot
.43034 .29819 Mdot
.61674 .30115 Mdot
.40921 .31966 Mdot
.43608 .31313 Mdot
.69844 .62975 Mdot
.55069 .26786 Mdot
.4497 .31214 Mdot
.35433 .55007 Mdot
.35128 .5121 Mdot
.70634 .48203 Mdot
.39598 .71741 Mdot
.39395 .6995 Mdot
.60572 .33552 Mdot
.2904 .35416 Mdot
.30421 .59371 Mdot
.61087 .68708 Mdot
.33363 .38993 Mdot
.44111 .33909 Mdot
.69039 .6208 Mdot
.31671 .62919 Mdot
.54301 .28077 Mdot
.41131 .32006 Mdot
.4519 .32563 Mdot
.32778 .38048 Mdot
.72146 .49642 Mdot
.60282 .66783 Mdot
.6285 .35002 Mdot
.50164 .70277 Mdot
.28036 .34843 Mdot
.53939 .27259 Mdot
.43063 .32408 Mdot
.41877 .34079 Mdot
.61022 .67957 Mdot
.57734 .67823 Mdot
.40777 .35406 Mdot
.60637 .33098 Mdot
.68652 .43333 Mdot
.69954 .41509 Mdot
.41253 .709 Mdot
.69288 .52122 Mdot
.68494 .60262 Mdot
.3273 .5897 Mdot
.3337 .36141 Mdot
.71733 .52305 Mdot
.42565 .30269 Mdot
.68073 .60269 Mdot
.58377 .67788 Mdot
.3627 .52481 Mdot
.34322 .52827 Mdot
.5351 .26016 Mdot
.32332 .63177 Mdot
.71239 .48031 Mdot
.34396 .37577 Mdot
.64117 .3427 Mdot
.49091 .72477 Mdot
.67554 .63175 Mdot
.49315 .31001 Mdot
.3732 .6843 Mdot
.613 .34017 Mdot
.66358 .61465 Mdot
.3417 .38709 Mdot
.31872 .36797 Mdot
.32285 .56898 Mdot
.47646 .33658 Mdot
.71231 .53323 Mdot
.608 .68543 Mdot
.65825 .65051 Mdot
.38321 .6927 Mdot
.3395 .52376 Mdot
.48994 .72987 Mdot
.68565 .42494 Mdot
.31176 .62498 Mdot
.33336 .38329 Mdot
.67793 .58883 Mdot
.30184 .63164 Mdot
.35235 .3797 Mdot
.44318 .28923 Mdot
.4158 .33837 Mdot
.62115 .35897 Mdot
.34881 .37985 Mdot
.35205 .37327 Mdot
.3512 .38531 Mdot
.70835 .45393 Mdot
.39821 .68578 Mdot
.27619 .35395 Mdot
.33088 .51803 Mdot
.31716 .58374 Mdot
.51283 .70739 Mdot
.71703 .41583 Mdot
.53281 .26738 Mdot
.30143 .58978 Mdot
.33039 .5241 Mdot
.66842 .59155 Mdot
.49044 .69965 Mdot
.28893 .60286 Mdot
.68623 .62462 Mdot
.56726 .67386 Mdot
.63585 .36831 Mdot
.73625 .50922 Mdot
.52084 .27777 Mdot
.37575 .69821 Mdot
.37419 .7014 Mdot
.69665 .59989 Mdot
.69524 .51024 Mdot
.37619 .70305 Mdot
.72266 .50002 Mdot
.68591 .59058 Mdot
.51482 .7041 Mdot
.5763 .67739 Mdot
.31062 .34333 Mdot
.29411 .59685 Mdot
.7003 .52893 Mdot
.30055 .58974 Mdot
.69673 .52431 Mdot
.35029 .47048 Mdot
.37781 .70996 Mdot
.32728 .5373 Mdot
.31054 .63658 Mdot
.45836 .3512 Mdot
.34022 .52725 Mdot
.56711 .27608 Mdot
.67163 .6283 Mdot
.30359 .336 Mdot
.5185 .7184 Mdot
.31278 .58548 Mdot
.35261 .5266 Mdot
.5891 .71592 Mdot
.35066 .53447 Mdot
.52481 .27985 Mdot
.37343 .6921 Mdot
.29125 .59761 Mdot
.71064 .50561 Mdot
.69283 .41697 Mdot
.70699 .62459 Mdot
.42207 .34003 Mdot
.64248 .63071 Mdot
.35751 .52015 Mdot
.63044 .35907 Mdot
.37499 .35148 Mdot
.3506 .37118 Mdot
.66096 .6178 Mdot
.29728 .42688 Mdot
.68448 .40924 Mdot
.6574 .33562 Mdot
.49773 .70649 Mdot
.61117 .30665 Mdot
.61194 .34617 Mdot
.65301 .6368 Mdot
.31719 .37374 Mdot
.30411 .59742 Mdot
.59333 .66205 Mdot
.54767 .69142 Mdot
.38429 .69173 Mdot
.64058 .36531 Mdot
.45348 .3328 Mdot
.47377 .74335 Mdot
.3288 .34308 Mdot
.32134 .35058 Mdot
.70019 .52057 Mdot
.62859 .35954 Mdot
.44193 .31428 Mdot
.33058 .35575 Mdot
.6382 .3701 Mdot
.40067 .3407 Mdot
.56112 .27413 Mdot
.6023 .68818 Mdot
.31338 .52881 Mdot
.61457 .66044 Mdot
.69414 .48696 Mdot
.54909 .26499 Mdot
.59101 .69339 Mdot
.61549 .68122 Mdot
.43693 .31711 Mdot
.64382 .30836 Mdot
.57779 .71271 Mdot
.30553 .58219 Mdot
.40953 .33337 Mdot
.3633 .51781 Mdot
.35537 .35869 Mdot
.35278 .51515 Mdot
.5352 .26163 Mdot
.71864 .51142 Mdot
.63295 .34059 Mdot
.70096 .524 Mdot
.3315 .60607 Mdot
.35757 .54204 Mdot
.34048 .51793 Mdot
.39853 .70913 Mdot
.7018 .61876 Mdot
.58359 .66648 Mdot
.61819 .34426 Mdot
.63132 .34356 Mdot
.51909 .71579 Mdot
.67964 .63744 Mdot
.42367 .28565 Mdot
.37957 .70627 Mdot
.34853 .53661 Mdot
.67279 .62773 Mdot
.5133 .71057 Mdot
.68066 .41193 Mdot
.40172 .71296 Mdot
.69934 .61818 Mdot
.56262 .28722 Mdot
.34823 .50285 Mdot
.44667 .32264 Mdot
.44619 .34535 Mdot
.36582 .67647 Mdot
.34667 .34721 Mdot
.68448 .61222 Mdot
.44225 .33333 Mdot
.66886 .63035 Mdot
.6003 .3019 Mdot
.68274 .40355 Mdot
.68197 .62315 Mdot
.35363 .53091 Mdot
.5324 .28735 Mdot
.69667 .50889 Mdot
.29289 .62065 Mdot
.70442 .41811 Mdot
.58985 .68767 Mdot
.66972 .61725 Mdot
.40069 .34096 Mdot
.49964 .7263 Mdot
.71486 .52982 Mdot
.33175 .54581 Mdot
.57403 .67885 Mdot
.47158 .70739 Mdot
.34272 .34476 Mdot
.30755 .60481 Mdot
.3149 .57012 Mdot
.57519 .28919 Mdot
.3229 .6108 Mdot
.70236 .45163 Mdot
.68795 .40612 Mdot
.69476 .44562 Mdot
.70018 .63227 Mdot
.42337 .36005 Mdot
.59222 .67068 Mdot
.43175 .30882 Mdot
.6475 .31465 Mdot
.29299 .6164 Mdot
.40466 .31868 Mdot
.71173 .42794 Mdot
.31364 .36401 Mdot
.37295 .68037 Mdot
.63791 .31306 Mdot
.41295 .34337 Mdot
.71373 .5246 Mdot
.56664 .69762 Mdot
.68763 .61914 Mdot
.56354 .28093 Mdot
.29726 .63055 Mdot
.3434 .52591 Mdot
.70729 .43487 Mdot
.48219 .32966 Mdot
.31992 .34828 Mdot
.41817 .30073 Mdot
.70803 .43049 Mdot
.39855 .71468 Mdot
.58481 .69002 Mdot
.29639 .5926 Mdot
.39389 .71352 Mdot
.70623 .45253 Mdot
.55503 .68093 Mdot
.31238 .34837 Mdot
.31887 .5286 Mdot
.68273 .61165 Mdot
.70629 .51012 Mdot
.40625 .29073 Mdot
.47374 .72806 Mdot
.33231 .53812 Mdot
.27744 .6166 Mdot
.40586 .70087 Mdot
.49057 .70496 Mdot
.40719 .34769 Mdot
.28215 .60677 Mdot
.51795 .71807 Mdot
.49394 .70113 Mdot
.3115 .60878 Mdot
.31398 .60947 Mdot
.67217 .62408 Mdot
.42347 .71359 Mdot
.6121 .31741 Mdot
.49706 .72952 Mdot
.49206 .31208 Mdot
.49278 .70807 Mdot
.41474 .7144 Mdot
.5656 .6696 Mdot
.36004 .67568 Mdot
.68638 .58636 Mdot
.68615 .64057 Mdot
.69352 .48881 Mdot
.46998 .71057 Mdot
.61279 .34051 Mdot
.45128 .33233 Mdot
.53468 .26977 Mdot
.67043 .62479 Mdot
.64148 .369 Mdot
.71213 .40333 Mdot
.6308 .30715 Mdot
.61236 .30103 Mdot
.71981 .51267 Mdot
.65801 .61664 Mdot
.37388 .68616 Mdot
.72067 .51691 Mdot
.45318 .3167 Mdot
.33601 .35816 Mdot
.54904 .69212 Mdot
.42586 .2969 Mdot
.3225 .54049 Mdot
.69033 .47571 Mdot
.64225 .3125 Mdot
.2755 .62066 Mdot
.66874 .64317 Mdot
.33689 .39342 Mdot
.67999 .62082 Mdot
.40239 .34848 Mdot
.30321 .35155 Mdot
.31089 .63141 Mdot
.49108 .31362 Mdot
.7124 .46105 Mdot
.30618 .59814 Mdot
.57343 .66646 Mdot
.53549 .26942 Mdot
.70512 .54156 Mdot
.71946 .47324 Mdot
.4458 .32001 Mdot
.69701 .62129 Mdot
.58412 .67229 Mdot
.42682 .30896 Mdot
.70801 .51113 Mdot
.60872 .70594 Mdot
.32009 .57192 Mdot
.69133 .51791 Mdot
.3024 .59881 Mdot
.32116 .50357 Mdot
.31989 .39279 Mdot
.40442 .32511 Mdot
.4985 .69943 Mdot
.65085 .34305 Mdot
.51973 .71228 Mdot
.32818 .50243 Mdot
.32432 .63356 Mdot
.33769 .53872 Mdot
.27577 .62426 Mdot
.55005 .2851 Mdot
.70593 .61214 Mdot
.41585 .33025 Mdot
.43376 .32337 Mdot
.47144 .70533 Mdot
.51062 .27333 Mdot
.31879 .35696 Mdot
.56569 .27936 Mdot
.36028 .53504 Mdot
.34392 .5346 Mdot
.58079 .68509 Mdot
.32068 .50038 Mdot
.40709 .32274 Mdot
.33844 .54144 Mdot
.36342 .68011 Mdot
.70732 .50191 Mdot
.31273 .57228 Mdot
.34909 .50435 Mdot
.68172 .40758 Mdot
.70889 .50661 Mdot
.54412 .27639 Mdot
.4003 .33582 Mdot
.61718 .35639 Mdot
.32434 .34492 Mdot
.27953 .61614 Mdot
.32909 .59619 Mdot
.40654 .71758 Mdot
.32007 .3427 Mdot
.48911 .71088 Mdot
.33583 .48955 Mdot
.33702 .50283 Mdot
.32079 .35154 Mdot
.6942 .50129 Mdot
.67629 .62675 Mdot
.31896 .50831 Mdot
.43387 .32156 Mdot
.4913 .70194 Mdot
.35488 .37344 Mdot
.66796 .62938 Mdot
.60795 .65969 Mdot
.6657 .61288 Mdot
.71329 .52031 Mdot
.54645 .26811 Mdot
.30258 .35168 Mdot
.68078 .62075 Mdot
.6528 .35338 Mdot
.71284 .41988 Mdot
.41412 .70475 Mdot
.69768 .48285 Mdot
.65291 .6363 Mdot
.69675 .62966 Mdot
.67664 .64787 Mdot
.48454 .72788 Mdot
.27528 .6261 Mdot
.4348 .30908 Mdot
.70872 .4315 Mdot
.651 .33814 Mdot
.3262 .62179 Mdot
.59887 .6577 Mdot
.27349 .64544 Mdot
.31209 .63259 Mdot
.35319 .51447 Mdot
.33773 .51079 Mdot
.41343 .35076 Mdot
.32601 .54091 Mdot
.33193 .51628 Mdot
.71338 .48025 Mdot
.5412 .27408 Mdot
.35773 .54297 Mdot
.41618 .33746 Mdot
.28894 .34294 Mdot
.33567 .39415 Mdot
.31688 .52843 Mdot
.5018 .68759 Mdot
.67978 .62871 Mdot
.6055 .3248 Mdot
.63133 .36427 Mdot
.33886 .38207 Mdot
.71052 .49473 Mdot
.6706 .60099 Mdot
.56312 .29031 Mdot
.30044 .35469 Mdot
.29719 .61112 Mdot
.39927 .70811 Mdot
.35956 .67586 Mdot
.40116 .69377 Mdot
.29415 .61699 Mdot
.41814 .3053 Mdot
.60378 .32362 Mdot
.41207 .69743 Mdot
.61651 .66626 Mdot
.35365 .36486 Mdot
.34217 .36063 Mdot
.56583 .70436 Mdot
.3294 .50204 Mdot
.70276 .53163 Mdot
.38422 .71529 Mdot
.7123 .55062 Mdot
.6583 .59824 Mdot
.27376 .35648 Mdot
.31073 .6033 Mdot
.31354 .60018 Mdot
.32796 .55077 Mdot
.56658 .70668 Mdot
.56965 .67998 Mdot
.57794 .69905 Mdot
.70689 .49995 Mdot
.3131 .59337 Mdot
.69346 .43173 Mdot
.40643 .32457 Mdot
.68968 .61087 Mdot
.43108 .70971 Mdot
.63135 .34281 Mdot
.50154 .70058 Mdot
.31535 .37897 Mdot
.38739 .69587 Mdot
.42155 .33344 Mdot
.31748 .56522 Mdot
.63737 .335 Mdot
.58633 .6922 Mdot
.50907 .70265 Mdot
.6294 .29125 Mdot
.28193 .60839 Mdot
.46012 .33084 Mdot
.40839 .31027 Mdot
.30931 .34443 Mdot
.31131 .59781 Mdot
.32032 .38593 Mdot
.7146 .52881 Mdot
.35407 .54747 Mdot
.29302 .59462 Mdot
.35007 .52539 Mdot
.31412 .62327 Mdot
.70224 .50206 Mdot
.47186 .71337 Mdot
.45581 .3106 Mdot
.40084 .32981 Mdot
.49214 .70685 Mdot
.31308 .37041 Mdot
.69895 .41615 Mdot
.54163 .27635 Mdot
.43926 .30015 Mdot
.30232 .34526 Mdot
.30609 .59583 Mdot
.34914 .53981 Mdot
.40265 .33448 Mdot
.3119 .62769 Mdot
.48058 .72309 Mdot
.62065 .30742 Mdot
.47701 .70594 Mdot
.3458 .38694 Mdot
.31868 .38173 Mdot
.69873 .50238 Mdot
.68215 .6213 Mdot
.33897 .37761 Mdot
.64208 .3367 Mdot
.32099 .5675 Mdot
.30975 .60604 Mdot
.57459 .68074 Mdot
.31977 .63582 Mdot
.34682 .38612 Mdot
.30921 .63041 Mdot
.58796 .70459 Mdot
.57667 .71441 Mdot
.3321 .53702 Mdot
.48591 .72032 Mdot
.6963 .63416 Mdot
.33356 .35676 Mdot
.71293 .49334 Mdot
.30582 .67109 Mdot
.72173 .49882 Mdot
.5778 .70038 Mdot
.4442 .32811 Mdot
.65635 .62299 Mdot
.44535 .32724 Mdot
.55384 .67573 Mdot
.34613 .50216 Mdot
.57069 .6847 Mdot
.45921 .31476 Mdot
.61754 .34516 Mdot
.63306 .29967 Mdot
.41164 .32138 Mdot
.6869 .61183 Mdot
.42936 .31209 Mdot
.33331 .37387 Mdot
.71533 .44226 Mdot
.68613 .64191 Mdot
.61457 .30002 Mdot
.64177 .31274 Mdot
.70745 .43674 Mdot
.3522 .51909 Mdot
.30114 .58739 Mdot
.63009 .30898 Mdot
.71122 .55096 Mdot
.69438 .60094 Mdot
.34284 .52461 Mdot
.43419 .29834 Mdot
.61447 .31367 Mdot
.69702 .39026 Mdot
.58584 .68226 Mdot
.51121 .70197 Mdot
.32508 .63242 Mdot
.68681 .40916 Mdot
.31033 .57505 Mdot
.48623 .72302 Mdot
.33604 .35111 Mdot
.32012 .54973 Mdot
.32029 .58081 Mdot
.68893 .4129 Mdot
.44764 .31261 Mdot
.39885 .69206 Mdot
.61064 .28801 Mdot
.2948 .58979 Mdot
.27384 .40364 Mdot
.40287 .33301 Mdot
.29975 .61003 Mdot
.44999 .29629 Mdot
.6709 .60777 Mdot
.34679 .52822 Mdot
.7135 .41839 Mdot
.61299 .3373 Mdot
.29738 .6304 Mdot
.44253 .36064 Mdot
.70585 .41265 Mdot
.42276 .33401 Mdot
.31727 .34836 Mdot
.50649 .71034 Mdot
.33148 .62199 Mdot
.53752 .28239 Mdot
.32071 .36461 Mdot
.35425 .52256 Mdot
.63972 .34548 Mdot
.69388 .41377 Mdot
.41362 .32707 Mdot
.30861 .58997 Mdot
.69814 .42526 Mdot
.71341 .50178 Mdot
.31704 .38358 Mdot
.71298 .637 Mdot
.35097 .4974 Mdot
.35953 .51416 Mdot
.67925 .65655 Mdot
.58237 .67629 Mdot
.29314 .59909 Mdot
.3617 .54083 Mdot
.70612 .53075 Mdot
.27904 .65487 Mdot
.31529 .56736 Mdot
.45957 .31779 Mdot
.70448 .54242 Mdot
.6274 .36615 Mdot
.64598 .31444 Mdot
.3271 .36304 Mdot
.66545 .60782 Mdot
.31899 .39022 Mdot
.61297 .33109 Mdot
.31205 .5824 Mdot
.72378 .50978 Mdot
.5314 .71401 Mdot
.70733 .42154 Mdot
.64044 .32678 Mdot
.60547 .67342 Mdot
.3979 .72477 Mdot
.27564 .40603 Mdot
.7155 .55219 Mdot
.56125 .28046 Mdot
.35049 .36938 Mdot
.61662 .6664 Mdot
.35818 .52964 Mdot
.41884 .7085 Mdot
.29753 .62902 Mdot
.42523 .35858 Mdot
.53275 .27538 Mdot
.40059 .34066 Mdot
.44574 .3188 Mdot
.27889 .62185 Mdot
.7137 .50068 Mdot
.68759 .42125 Mdot
.4326 .33968 Mdot
.71307 .51627 Mdot
.36381 .52572 Mdot
.6333 .32129 Mdot
.59413 .6513 Mdot
.34932 .53622 Mdot
.29212 .36069 Mdot
.70805 .39989 Mdot
.61673 .67853 Mdot
.6314 .36667 Mdot
.31279 .59996 Mdot
.64555 .6199 Mdot
.71853 .52387 Mdot
.31658 .54516 Mdot
.61496 .34061 Mdot
.43816 .2999 Mdot
.6371 .34977 Mdot
.29707 .60327 Mdot
.31459 .60545 Mdot
.45038 .31027 Mdot
.34928 .53477 Mdot
.70788 .60468 Mdot
.47618 .72942 Mdot
.52404 .7049 Mdot
.33099 .51667 Mdot
.58609 .65828 Mdot
.69969 .40481 Mdot
.43447 .33929 Mdot
.40635 .70098 Mdot
.31781 .62737 Mdot
.6969 .63734 Mdot
.69865 .41378 Mdot
.73065 .47884 Mdot
.70461 .50228 Mdot
.61579 .34474 Mdot
.71182 .49604 Mdot
.32824 .55247 Mdot
.68914 .59171 Mdot
.62112 .3283 Mdot
.42896 .33107 Mdot
.65618 .35427 Mdot
.33649 .5604 Mdot
.71032 .39908 Mdot
.65435 .32766 Mdot
.49508 .72788 Mdot
.68268 .59204 Mdot
.48695 .31796 Mdot
.50217 .68676 Mdot
.31644 .579 Mdot
.29691 .62702 Mdot
.41629 .30255 Mdot
.69989 .50126 Mdot
.58402 .67937 Mdot
.56053 .27215 Mdot
.34263 .38945 Mdot
.68684 .58669 Mdot
.33039 .39259 Mdot
.39441 .70955 Mdot
.59996 .65431 Mdot
.36367 .68066 Mdot
.69697 .51982 Mdot
.68773 .61631 Mdot
.3565 .37156 Mdot
.49575 .73288 Mdot
.32145 .37444 Mdot
.64094 .36216 Mdot
.37472 .70134 Mdot
.61651 .30367 Mdot
.71193 .43939 Mdot
.55032 .27413 Mdot
.71197 .53579 Mdot
.44676 .35878 Mdot
.46247 .71915 Mdot
.69244 .40439 Mdot
.71737 .42265 Mdot
.60881 .32133 Mdot
.42482 .34097 Mdot
.47381 .71176 Mdot
.43499 .34654 Mdot
.42311 .34591 Mdot
.68621 .41532 Mdot
.68947 .62107 Mdot
.67837 .63629 Mdot
.30059 .33764 Mdot
.68757 .62256 Mdot
.62134 .31541 Mdot
.40095 .71177 Mdot
.41817 .72535 Mdot
.70066 .40398 Mdot
.50617 .7093 Mdot
.32369 .55061 Mdot
.52454 .27067 Mdot
.628 .31778 Mdot
.70939 .49961 Mdot
.65424 .64771 Mdot
.44392 .33323 Mdot
.58808 .68058 Mdot
.67778 .6017 Mdot
.67183 .61111 Mdot
.65466 .62532 Mdot
.31806 .59698 Mdot
.71505 .53633 Mdot
.6831 .61008 Mdot
.30066 .59823 Mdot
.36036 .50838 Mdot
.43622 .30144 Mdot
.42719 .35837 Mdot
.47982 .71891 Mdot
.43694 .30948 Mdot
.34419 .54534 Mdot
.62686 .34548 Mdot
.42921 .36023 Mdot
.44889 .32743 Mdot
.60784 .33339 Mdot
.60594 .33066 Mdot
.4301 .347 Mdot
.42752 .36028 Mdot
.7088 .60933 Mdot
.45886 .72673 Mdot
.57427 .66614 Mdot
.65493 .32559 Mdot
.69901 .45183 Mdot
.57272 .68265 Mdot
.29372 .62742 Mdot
.43319 .29508 Mdot
.63542 .33261 Mdot
.67958 .64486 Mdot
.33733 .51967 Mdot
.43467 .31682 Mdot
.32733 .37236 Mdot
.42853 .33323 Mdot
.41831 .30402 Mdot
.56095 .68656 Mdot
.68192 .51243 Mdot
.61039 .67684 Mdot
.62216 .29036 Mdot
.42173 .32956 Mdot
.5927 .71376 Mdot
.54593 .26288 Mdot
.71451 .4457 Mdot
.47491 .73003 Mdot
.32867 .51909 Mdot
.60526 .32334 Mdot
.6945 .61042 Mdot
.70543 .47674 Mdot
.36144 .67934 Mdot
.68163 .61996 Mdot
.40109 .34408 Mdot
.41228 .31474 Mdot
.61316 .31404 Mdot
.56391 .69638 Mdot
.48771 .72238 Mdot
.67832 .61447 Mdot
.70503 .43404 Mdot
.30614 .63553 Mdot
.64213 .63089 Mdot
.44058 .31396 Mdot
.67969 .63242 Mdot
.64952 .3361 Mdot
.33195 .38446 Mdot
.3105 .6223 Mdot
.73763 .51756 Mdot
.35383 .5252 Mdot
.70503 .43852 Mdot
.28673 .36038 Mdot
.51138 .71889 Mdot
.2969 .61809 Mdot
.41387 .70747 Mdot
.71738 .41831 Mdot
.29347 .60915 Mdot
.39999 .72327 Mdot
.61117 .6608 Mdot
.59713 .68317 Mdot
.36095 .53339 Mdot
.62683 .30982 Mdot
.60061 .28231 Mdot
.35332 .50601 Mdot
.63266 .29095 Mdot
.3816 .71512 Mdot
.44945 .33449 Mdot
.34349 .3434 Mdot
.32703 .59005 Mdot
.30465 .62047 Mdot
.32791 .53806 Mdot
.30603 .63654 Mdot
.35782 .67641 Mdot
.61332 .33507 Mdot
.62029 .35757 Mdot
.33432 .36969 Mdot
.27824 .60902 Mdot
.32174 .38255 Mdot
.69438 .41223 Mdot
.46602 .71417 Mdot
.40397 .31711 Mdot
.68368 .62546 Mdot
.3495 .52864 Mdot
.64319 .35602 Mdot
.29995 .61157 Mdot
.49813 .71641 Mdot
.61813 .31499 Mdot
.63453 .33814 Mdot
.60145 .28789 Mdot
.3508 .38015 Mdot
.66341 .62253 Mdot
.33172 .55752 Mdot
.34914 .35413 Mdot
.45201 .32124 Mdot
.3106 .6762 Mdot
.68139 .58768 Mdot
.67 .632 Mdot
.65954 .63247 Mdot
.33192 .54813 Mdot
.33223 .55023 Mdot
.70028 .43893 Mdot
.5862 .66838 Mdot
.72414 .52282 Mdot
.60461 .31642 Mdot
.61769 .28368 Mdot
.30281 .61613 Mdot
.2952 .35642 Mdot
.31406 .37237 Mdot
.65695 .3406 Mdot
.40804 .31417 Mdot
.3232 .38851 Mdot
.33535 .55343 Mdot
.61014 .31264 Mdot
.35376 .37331 Mdot
.65369 .64096 Mdot
.72833 .48364 Mdot
.32731 .38697 Mdot
.44448 .31463 Mdot
.60048 .66072 Mdot
.32543 .59973 Mdot
.32382 .39321 Mdot
.69678 .40629 Mdot
.37314 .68401 Mdot
.40594 .31953 Mdot
.29858 .36082 Mdot
.28293 .65713 Mdot
.6159 .32777 Mdot
.44576 .31498 Mdot
.35832 .36914 Mdot
.42324 .72347 Mdot
.31233 .38299 Mdot
.67352 .63312 Mdot
.52306 .69549 Mdot
.30171 .62435 Mdot
.5053 .71874 Mdot
.69419 .48979 Mdot
.64241 .36316 Mdot
.63063 .36169 Mdot
.569 .69028 Mdot
.4076 .70981 Mdot
.62637 .30479 Mdot
.41118 .70643 Mdot
.32934 .33565 Mdot
.30073 .59852 Mdot
.30003 .33693 Mdot
.50124 .73051 Mdot
.35194 .38822 Mdot
.32943 .38597 Mdot
.70745 .40407 Mdot
.7177 .51018 Mdot
.69982 .5051 Mdot
.62128 .30499 Mdot
.39312 .70365 Mdot
.624 .35872 Mdot
.70342 .64813 Mdot
.31999 .35756 Mdot
.56044 .28855 Mdot
.32455 .54255 Mdot
.34159 .54571 Mdot
.51332 .70647 Mdot
.42736 .29867 Mdot
.29842 .59692 Mdot
.69929 .43 Mdot
.65308 .35328 Mdot
.71265 .40087 Mdot
.56957 .70151 Mdot
.69707 .65223 Mdot
.63207 .33909 Mdot
.3205 .33427 Mdot
.31332 .37611 Mdot
.28079 .66075 Mdot
.44938 .34509 Mdot
.62695 .35098 Mdot
.33774 .49745 Mdot
.68518 .64334 Mdot
.56982 .29155 Mdot
.34764 .52566 Mdot
.64554 .31627 Mdot
.5479 .26094 Mdot
.50489 .72539 Mdot
.32244 .61022 Mdot
.7104 .46251 Mdot
.40625 .70434 Mdot
.34775 .38979 Mdot
.45041 .30855 Mdot
.42994 .7069 Mdot
.61151 .32929 Mdot
.65182 .3634 Mdot
.33646 .38745 Mdot
.61482 .67613 Mdot
.68052 .64028 Mdot
.70859 .61094 Mdot
.70052 .43424 Mdot
.34103 .50157 Mdot
.61063 .31482 Mdot
.59657 .67431 Mdot
.32051 .56482 Mdot
.70521 .5249 Mdot
.65872 .34562 Mdot
.34921 .53455 Mdot
.29709 .61598 Mdot
.32534 .38097 Mdot
.28837 .34379 Mdot
.45511 .30607 Mdot
.71578 .44494 Mdot
.27804 .64171 Mdot
.46697 .71155 Mdot
.33172 .53721 Mdot
.69932 .60647 Mdot
.42719 .31048 Mdot
.31687 .37301 Mdot
.28733 .60518 Mdot
.41804 .71508 Mdot
.69755 .62603 Mdot
.69784 .52352 Mdot
.42755 .32715 Mdot
.27689 .63589 Mdot
.35148 .53091 Mdot
.30341 .62917 Mdot
.4849 .72783 Mdot
.32288 .53173 Mdot
.53229 .2686 Mdot
.61221 .68678 Mdot
.33725 .34778 Mdot
.66775 .61618 Mdot
.55403 .26871 Mdot
.47102 .72744 Mdot
.3825 .70182 Mdot
.59623 .65485 Mdot
.68387 .59012 Mdot
.7064 .43459 Mdot
.71774 .53171 Mdot
.29424 .35249 Mdot
.30051 .60611 Mdot
.40444 .33141 Mdot
.67794 .60934 Mdot
.64115 .36241 Mdot
.32099 .38323 Mdot
.56254 .28221 Mdot
.33587 .53792 Mdot
.61035 .323 Mdot
.41417 .32214 Mdot
.56262 .69935 Mdot
.62404 .34411 Mdot
.43748 .29984 Mdot
.33754 .35657 Mdot
.37825 .68578 Mdot
.41079 .35897 Mdot
.44371 .32603 Mdot
.30376 .60937 Mdot
.51819 .73091 Mdot
.5068 .71327 Mdot
.45906 .32309 Mdot
.63485 .36999 Mdot
.44129 .31969 Mdot
.61849 .67669 Mdot
.50468 .72404 Mdot
.65086 .34525 Mdot
.57796 .6752 Mdot
.47764 .73064 Mdot
.44425 .3298 Mdot
.67859 .58866 Mdot
.55604 .26715 Mdot
.66787 .65079 Mdot
.32352 .58107 Mdot
.34258 .5079 Mdot
.61775 .30279 Mdot
.3234 .37419 Mdot
.6925 .43337 Mdot
.68731 .39985 Mdot
.71607 .41941 Mdot
.60775 .29756 Mdot
.34872 .53143 Mdot
.68496 .61353 Mdot
.71848 .51954 Mdot
.581 .68234 Mdot
.64343 .34055 Mdot
.63176 .31609 Mdot
.51071 .7053 Mdot
.31908 .38278 Mdot
.32514 .54303 Mdot
.64072 .36181 Mdot
.5458 .27244 Mdot
.60908 .70617 Mdot
.35145 .38596 Mdot
.47273 .72392 Mdot
.40976 .35818 Mdot
.29376 .58824 Mdot
.61624 .65606 Mdot
.40964 .32127 Mdot
.56573 .69976 Mdot
.31959 .57469 Mdot
.67488 .38492 Mdot
.54447 .26301 Mdot
.40798 .70642 Mdot
.71282 .45975 Mdot
.72148 .52038 Mdot
.62086 .34113 Mdot
.33785 .52819 Mdot
.56213 .28407 Mdot
.32819 .3631 Mdot
.51394 .72431 Mdot
.43408 .34031 Mdot
.57737 .6812 Mdot
.72069 .50193 Mdot
.43614 .36105 Mdot
.69272 .43354 Mdot
.69802 .50953 Mdot
.57151 .66601 Mdot
.30212 .62352 Mdot
.63027 .33094 Mdot
.63561 .31439 Mdot
.30166 .33661 Mdot
.52279 .2754 Mdot
.66712 .64155 Mdot
.67446 .38475 Mdot
.41856 .70149 Mdot
.35803 .53724 Mdot
.40453 .3464 Mdot
.4063 .33313 Mdot
.55055 .27033 Mdot
.29309 .60899 Mdot
.59596 .69167 Mdot
.62493 .3624 Mdot
.63824 .3065 Mdot
.50092 .72285 Mdot
.71888 .51221 Mdot
.46095 .33396 Mdot
.62422 .31678 Mdot
.30895 .6717 Mdot
.30444 .6165 Mdot
.71514 .55159 Mdot
.62247 .31781 Mdot
.51293 .27046 Mdot
.68417 .42819 Mdot
.60412 .67522 Mdot
.39121 .68461 Mdot
.58711 .68584 Mdot
.32203 .38714 Mdot
.62739 .35628 Mdot
.69007 .41985 Mdot
.42433 .33113 Mdot
.59828 .28331 Mdot
.62149 .30249 Mdot
.67187 .62542 Mdot
.30132 .62734 Mdot
.3201 .51181 Mdot
.35175 .53286 Mdot
.27598 .65443 Mdot
.347 .38814 Mdot
.68745 .39942 Mdot
.70778 .43342 Mdot
.392 .6848 Mdot
.35335 .37684 Mdot
.61378 .34568 Mdot
.61691 .31612 Mdot
.73714 .51439 Mdot
.41746 .30515 Mdot
.61604 .34951 Mdot
.3056 .61153 Mdot
.60332 .28614 Mdot
.59814 .65744 Mdot
.71879 .5086 Mdot
.31593 .62797 Mdot
.61891 .30112 Mdot
.56062 .68434 Mdot
.39821 .70365 Mdot
.35478 .50775 Mdot
.45732 .30189 Mdot
.718 .52838 Mdot
.68935 .65676 Mdot
.52507 .26981 Mdot
.34483 .50289 Mdot
.69548 .41758 Mdot
.47296 .33987 Mdot
.59328 .28713 Mdot
.66245 .61545 Mdot
.64212 .31369 Mdot
.7149 .4944 Mdot
.4175 .32325 Mdot
.33599 .34699 Mdot
.63353 .35079 Mdot
.64667 .31376 Mdot
.4909 .7116 Mdot
.31207 .33548 Mdot
.32644 .39326 Mdot
.69042 .59865 Mdot
.70467 .53106 Mdot
.50064 .71701 Mdot
.30197 .66992 Mdot
.33249 .55311 Mdot
.69809 .50369 Mdot
.62048 .6961 Mdot
.34228 .49779 Mdot
.33063 .52933 Mdot
.31725 .5441 Mdot
.61205 .67109 Mdot
.68858 .60645 Mdot
.27347 .64001 Mdot
.48488 .71889 Mdot
.38744 .70563 Mdot
.67812 .62832 Mdot
.66682 .62214 Mdot
.38616 .6979 Mdot
.49416 .7125 Mdot
.57808 .67269 Mdot
.71568 .51324 Mdot
.7213 .52116 Mdot
.67093 .61036 Mdot
.51446 .70775 Mdot
.69509 .51134 Mdot
.58011 .68941 Mdot
.63848 .3246 Mdot
.39067 .71864 Mdot
.67177 .60095 Mdot
.37606 .70494 Mdot
.71422 .52903 Mdot
.29091 .6681 Mdot
.38081 .71488 Mdot
.3247 .52406 Mdot
.29997 .62332 Mdot
.35097 .36439 Mdot
.42515 .33407 Mdot
.4297 .34722 Mdot
.70072 .50027 Mdot
.32689 .54326 Mdot
.58121 .69903 Mdot
.32979 .54757 Mdot
.32291 .63338 Mdot
.29271 .66608 Mdot
.41525 .69538 Mdot
.66391 .61442 Mdot
.57918 .69986 Mdot
.61722 .28683 Mdot
.64795 .36215 Mdot
.41196 .71822 Mdot
.71937 .52581 Mdot
.68374 .63209 Mdot
.72408 .52192 Mdot
.61257 .32941 Mdot
.63221 .33266 Mdot
.43179 .30638 Mdot
.44584 .31439 Mdot
.62203 .33623 Mdot
.63138 .29239 Mdot
.29978 .67178 Mdot
.57746 .67702 Mdot
.62149 .66693 Mdot
.33071 .61361 Mdot
.32153 .50242 Mdot
.32483 .37243 Mdot
.42547 .36188 Mdot
.69688 .42649 Mdot
.40994 .70006 Mdot
.34552 .55327 Mdot
.44076 .32782 Mdot
.69091 .499 Mdot
.30906 .36037 Mdot
.72061 .51316 Mdot
.32699 .34686 Mdot
.65054 .34306 Mdot
.34517 .53485 Mdot
.32724 .53447 Mdot
.70608 .43171 Mdot
.60607 .28824 Mdot
.61009 .30961 Mdot
.32122 .37116 Mdot
.32986 .60756 Mdot
.61232 .31825 Mdot
.67296 .59878 Mdot
.66257 .59423 Mdot
.41 .32755 Mdot
.33725 .52273 Mdot
.32776 .59736 Mdot
.50297 .72545 Mdot
.45158 .32357 Mdot
.42818 .32653 Mdot
.71421 .63389 Mdot
.30635 .58132 Mdot
.73204 .47942 Mdot
.44892 .31421 Mdot
.65737 .62549 Mdot
.62859 .3326 Mdot
.44906 .32898 Mdot
.44316 .34581 Mdot
.26607 .37794 Mdot
.42322 .35073 Mdot
.6938 .62405 Mdot
.58831 .68851 Mdot
.47541 .70942 Mdot
.62754 .68655 Mdot
.31574 .34325 Mdot
.31272 .36594 Mdot
.54213 .26266 Mdot
.71261 .41535 Mdot
.31763 .55908 Mdot
.32004 .3606 Mdot
.65705 .64678 Mdot
.50519 .70248 Mdot
.49504 .70502 Mdot
.48501 .70753 Mdot
.58194 .68443 Mdot
.31203 .60253 Mdot
.53434 .27287 Mdot
.67344 .62652 Mdot
.47824 .70544 Mdot
.33581 .49255 Mdot
.70618 .61407 Mdot
.70027 .5247 Mdot
.52242 .71354 Mdot
.68505 .61588 Mdot
.3623 .67646 Mdot
.70928 .53492 Mdot
.41653 .71095 Mdot
.66251 .38257 Mdot
.51265 .27203 Mdot
.71114 .50247 Mdot
.65846 .34329 Mdot
.6089 .31904 Mdot
.61931 .30928 Mdot
.68369 .60398 Mdot
.6396 .30297 Mdot
.58148 .70124 Mdot
.56087 .28047 Mdot
.27676 .6312 Mdot
.30308 .35112 Mdot
.54735 .27477 Mdot
.67144 .61222 Mdot
.67943 .65726 Mdot
.28744 .41878 Mdot
.35343 .50276 Mdot
.69007 .40865 Mdot
.3353 .36537 Mdot
.39984 .71116 Mdot
.3372 .35126 Mdot
.61347 .33933 Mdot
.27977 .62602 Mdot
.30432 .6171 Mdot
.72863 .48144 Mdot
.32343 .37604 Mdot
.66592 .61988 Mdot
.48919 .71 Mdot
.62211 .36511 Mdot
.32643 .3638 Mdot
.31804 .3811 Mdot
.35812 .51275 Mdot
.58633 .68992 Mdot
.60357 .31808 Mdot
.69902 .53712 Mdot
.56463 .2723 Mdot
.33841 .67605 Mdot
.29991 .587 Mdot
.34662 .50144 Mdot
.39314 .71153 Mdot
.55641 .27245 Mdot
.71247 .51062 Mdot
.32003 .6363 Mdot
.52051 .26466 Mdot
.32213 .6368 Mdot
.56392 .70535 Mdot
.5533 .27802 Mdot
.41012 .33143 Mdot
.43752 .30139 Mdot
.34325 .52065 Mdot
.27735 .40917 Mdot
.31067 .59055 Mdot
.69382 .51465 Mdot
.42173 .33905 Mdot
.65819 .33187 Mdot
.67803 .6435 Mdot
.26601 .38135 Mdot
.48147 .7208 Mdot
.69878 .53551 Mdot
.6145 .31839 Mdot
.26742 .39262 Mdot
.34915 .3674 Mdot
.38337 .71974 Mdot
.36175 .50997 Mdot
.34145 .51972 Mdot
.70176 .51596 Mdot
.6932 .50688 Mdot
.61772 .65869 Mdot
.4108 .3565 Mdot
.65287 .60551 Mdot
.70914 .42144 Mdot
.26641 .38941 Mdot
.40467 .33439 Mdot
.60469 .68626 Mdot
.4095 .34757 Mdot
.69591 .48576 Mdot
.30199 .58863 Mdot
.58719 .68884 Mdot
.41412 .31878 Mdot
.51835 .69032 Mdot
.50303 .70768 Mdot
.30843 .67251 Mdot
.35464 .51476 Mdot
.66799 .63739 Mdot
.67386 .62899 Mdot
.58305 .69683 Mdot
.41671 .31046 Mdot
.3379 .54108 Mdot
.33349 .51362 Mdot
.33902 .50359 Mdot
.61589 .70082 Mdot
.34639 .53187 Mdot
.67056 .6479 Mdot
.39948 .72071 Mdot
.67606 .38477 Mdot
.32903 .53806 Mdot
.70778 .49391 Mdot
.34675 .51455 Mdot
.33333 .3945 Mdot
.38536 .68617 Mdot
.49483 .73001 Mdot
.71056 .51574 Mdot
.32713 .50462 Mdot
.49171 .31179 Mdot
.33278 .55805 Mdot
.31897 .34566 Mdot
.6913 .43976 Mdot
.31743 .59259 Mdot
.61173 .70375 Mdot
.6754 .6145 Mdot
.64141 .35036 Mdot
.71151 .47912 Mdot
.6181 .346 Mdot
.45875 .72749 Mdot
.40341 .33956 Mdot
.56301 .28765 Mdot
.29941 .66909 Mdot
.30694 .58413 Mdot
.41388 .30533 Mdot
.57313 .69816 Mdot
.53622 .26921 Mdot
.31983 .50308 Mdot
.5124 .70566 Mdot
.33615 .3858 Mdot
.33623 .35321 Mdot
.2808 .3491 Mdot
.5907 .67737 Mdot
.67263 .65679 Mdot
.70285 .5182 Mdot
.62414 .30317 Mdot
.35226 .38629 Mdot
.73446 .54683 Mdot
.69733 .49089 Mdot
.54677 .2692 Mdot
.72123 .50438 Mdot
.33284 .5406 Mdot
.4322 .34639 Mdot
.60491 .66496 Mdot
.43516 .3361 Mdot
.31962 .56868 Mdot
.63247 .30176 Mdot
.41191 .31313 Mdot
.34961 .35609 Mdot
.71017 .49029 Mdot
.6302 .34351 Mdot
.30349 .62743 Mdot
.67485 .63064 Mdot
.46027 .73829 Mdot
.51709 .26616 Mdot
.49212 .73029 Mdot
.48878 .73119 Mdot
.61428 .66898 Mdot
.45479 .32583 Mdot
.58284 .28077 Mdot
.49465 .73208 Mdot
.71479 .42937 Mdot
.2981 .36968 Mdot
.54565 .28879 Mdot
.63053 .35986 Mdot
.61956 .32681 Mdot
.31815 .57417 Mdot
.61769 .35743 Mdot
.38703 .69186 Mdot
.62405 .36665 Mdot
.68337 .42135 Mdot
.30735 .59938 Mdot
.6186 .31742 Mdot
.44918 .31759 Mdot
.3085 .61571 Mdot
.59938 .68338 Mdot
.61042 .34747 Mdot
.32468 .52371 Mdot
.64486 .30248 Mdot
.70601 .43571 Mdot
.41962 .30814 Mdot
.37015 .68271 Mdot
.7155 .51923 Mdot
.69447 .61786 Mdot
.3794 .67757 Mdot
.32594 .35978 Mdot
.59227 .69748 Mdot
.29322 .36099 Mdot
.31538 .38101 Mdot
.38795 .71465 Mdot
.68553 .59328 Mdot
.41236 .33736 Mdot
.33567 .35488 Mdot
.33834 .34157 Mdot
.61783 .32692 Mdot
.53454 .26054 Mdot
.44295 .31814 Mdot
.30489 .62884 Mdot
.54714 .28418 Mdot
.71187 .49819 Mdot
.35867 .50804 Mdot
.61399 .3073 Mdot
.41682 .33709 Mdot
.33229 .52408 Mdot
.48337 .71911 Mdot
.61049 .66216 Mdot
.41619 .35538 Mdot
.31366 .34777 Mdot
.59366 .68648 Mdot
.34756 .5021 Mdot
.31322 .34172 Mdot
.55972 .26792 Mdot
.3124 .6129 Mdot
.66092 .61602 Mdot
.65432 .644 Mdot
.63908 .36379 Mdot
.69806 .52628 Mdot
.63902 .31678 Mdot
.32641 .34523 Mdot
.28858 .42043 Mdot
.43872 .30806 Mdot
.50723 .72818 Mdot
.38368 .68921 Mdot
.63778 .35605 Mdot
.66419 .62335 Mdot
.72348 .55123 Mdot
.38317 .68578 Mdot
.31028 .61139 Mdot
.33885 .51786 Mdot
.55475 .27463 Mdot
.68138 .64171 Mdot
.33776 .5199 Mdot
.42745 .35936 Mdot
.31111 .6057 Mdot
.33525 .3753 Mdot
.65476 .38071 Mdot
.44356 .30143 Mdot
.60787 .70841 Mdot
.41546 .31452 Mdot
.62295 .3134 Mdot
.36301 .6739 Mdot
.39122 .70648 Mdot
.27296 .35804 Mdot
.69466 .6238 Mdot
.56186 .68167 Mdot
.63108 .3286 Mdot
.5539 .26775 Mdot
.47762 .72017 Mdot
.48585 .71203 Mdot
.30751 .61637 Mdot
.61406 .33986 Mdot
.64699 .37115 Mdot
.40746 .3439 Mdot
.41068 .31164 Mdot
.41497 .7198 Mdot
.64852 .34311 Mdot
.34507 .5342 Mdot
.5113 .71067 Mdot
.70185 .48179 Mdot
.59445 .68055 Mdot
.69602 .40098 Mdot
.70312 .47848 Mdot
.31416 .52926 Mdot
.2796 .64592 Mdot
.69918 .43441 Mdot
.7142 .40979 Mdot
.54395 .26671 Mdot
.41985 .72152 Mdot
.32546 .38632 Mdot
.28165 .65454 Mdot
.61671 .3462 Mdot
.34719 .54201 Mdot
.66047 .63877 Mdot
.40593 .35073 Mdot
.73686 .53651 Mdot
.33545 .45717 Mdot
.47091 .71534 Mdot
.53804 .28011 Mdot
.44376 .3274 Mdot
.43299 .33893 Mdot
.32612 .60417 Mdot
.34433 .53278 Mdot
.63751 .36367 Mdot
.42295 .72293 Mdot
.70872 .42046 Mdot
.54665 .26585 Mdot
.59232 .67491 Mdot
.3467 .5181 Mdot
.70445 .62733 Mdot
.706 .48484 Mdot
.30371 .37097 Mdot
.351 .3753 Mdot
.33352 .55857 Mdot
.47275 .72924 Mdot
.71232 .44015 Mdot
.48027 .71538 Mdot
.49631 .71539 Mdot
.43787 .31871 Mdot
.47353 .72492 Mdot
.36263 .50965 Mdot
.35123 .49468 Mdot
.45213 .32111 Mdot
.69841 .48666 Mdot
.32158 .57763 Mdot
.4434 .33132 Mdot
.37839 .68213 Mdot
.71458 .48468 Mdot
.4792 .71708 Mdot
.70462 .50121 Mdot
.54849 .26824 Mdot
.70332 .43426 Mdot
.33838 .34821 Mdot
.54502 .27131 Mdot
.62039 .66616 Mdot
.68543 .61449 Mdot
.71785 .53398 Mdot
.33753 .3576 Mdot
.70769 .4974 Mdot
.6314 .34873 Mdot
.71174 .4352 Mdot
.57268 .71418 Mdot
.31441 .67256 Mdot
.31453 .53475 Mdot
.71232 .5483 Mdot
.65012 .35619 Mdot
.67165 .61005 Mdot
.71414 .41664 Mdot
.37514 .68855 Mdot
.34896 .37144 Mdot
.34326 .51742 Mdot
.70842 .48839 Mdot
.54562 .27805 Mdot
.60765 .65698 Mdot
.32529 .34834 Mdot
.69619 .6542 Mdot
.64484 .35211 Mdot
.3062 .60199 Mdot
.68274 .40475 Mdot
.58852 .2855 Mdot
.70691 .43022 Mdot
.32148 .51121 Mdot
.40417 .32663 Mdot
.41964 .35732 Mdot
.572 .67226 Mdot
.41479 .30261 Mdot
.46244 .35 Mdot
.717 .42624 Mdot
.61191 .68247 Mdot
.61961 .28864 Mdot
.30513 .62963 Mdot
.46871 .71112 Mdot
.43526 .31057 Mdot
.67647 .63716 Mdot
.48707 .72771 Mdot
.43265 .30461 Mdot
.39811 .72073 Mdot
.58971 .68446 Mdot
.60937 .34203 Mdot
.30445 .61095 Mdot
.68443 .40811 Mdot
.7047 .41604 Mdot
.40071 .34334 Mdot
.69051 .42843 Mdot
.37895 .68227 Mdot
.68349 .59249 Mdot
.47481 .71163 Mdot
.33568 .37336 Mdot
.70637 .60207 Mdot
.41099 .35239 Mdot
.26749 .37366 Mdot
.30427 .60807 Mdot
.63118 .33093 Mdot
.595 .28738 Mdot
.4126 .71981 Mdot
.67788 .62624 Mdot
.39024 .69016 Mdot
.48052 .72787 Mdot
.48259 .71403 Mdot
.62358 .3032 Mdot
.39692 .71063 Mdot
.34639 .5331 Mdot
.70102 .53636 Mdot
.35341 .67836 Mdot
.32945 .49693 Mdot
.41863 .36089 Mdot
.49545 .72975 Mdot
.68439 .42043 Mdot
.57948 .67562 Mdot
.62919 .32936 Mdot
.59725 .69281 Mdot
.58269 .67724 Mdot
.6889 .60974 Mdot
.73217 .54938 Mdot
.49593 .73139 Mdot
.73721 .49832 Mdot
.59883 .65686 Mdot
.32212 .50292 Mdot
.66435 .64451 Mdot
.57678 .2794 Mdot
.61204 .68377 Mdot
.69472 .61903 Mdot
.59537 .65072 Mdot
.68185 .64081 Mdot
.30639 .62279 Mdot
.31675 .62887 Mdot
.42694 .70819 Mdot
.55878 .28052 Mdot
.3511 .53441 Mdot
.42988 .34867 Mdot
.3391 .37146 Mdot
.61307 .6752 Mdot
.42726 .32961 Mdot
.38208 .71162 Mdot
.43681 .28762 Mdot
.36242 .52139 Mdot
.33419 .52553 Mdot
.48224 .70937 Mdot
.28778 .66498 Mdot
.55782 .28467 Mdot
.66053 .62961 Mdot
.33209 .49369 Mdot
.59411 .28582 Mdot
.29864 .59848 Mdot
.39225 .68951 Mdot
.34749 .49384 Mdot
.63033 .33101 Mdot
.59133 .67117 Mdot
.42397 .34623 Mdot
.70801 .62753 Mdot
.3549 .52272 Mdot
.42744 .28518 Mdot
.29928 .34793 Mdot
.33644 .5245 Mdot
.70722 .6186 Mdot
.48435 .72811 Mdot
.69732 .61415 Mdot
.69401 .59515 Mdot
.31017 .61084 Mdot
.60121 .6719 Mdot
.68833 .60502 Mdot
.48547 .71282 Mdot
.53948 .28111 Mdot
.71547 .44317 Mdot
.30882 .58563 Mdot
.32443 .34908 Mdot
.2939 .61494 Mdot
.31394 .38373 Mdot
.43923 .34244 Mdot
.44302 .32271 Mdot
.3101 .59685 Mdot
.65453 .35391 Mdot
.32129 .39182 Mdot
.55722 .28268 Mdot
.58015 .71636 Mdot
.57018 .66921 Mdot
.71039 .42219 Mdot
.5336 .26028 Mdot
.44171 .32113 Mdot
.32486 .57671 Mdot
.34054 .67534 Mdot
.69518 .43374 Mdot
.56264 .70081 Mdot
.31128 .58718 Mdot
.42031 .29913 Mdot
.60614 .33615 Mdot
.63396 .31421 Mdot
.71652 .42728 Mdot
.58589 .65417 Mdot
.33558 .54543 Mdot
.4198 .29992 Mdot
.52645 .70615 Mdot
.42376 .33464 Mdot
.41782 .34794 Mdot
.65951 .3431 Mdot
.33808 .53701 Mdot
.37821 .71067 Mdot
.60742 .32252 Mdot
.30956 .37011 Mdot
.56201 .69751 Mdot
.31803 .34321 Mdot
.72566 .47834 Mdot
.61562 .6606 Mdot
.61873 .33821 Mdot
.4395 .29856 Mdot
.35252 .53744 Mdot
.58403 .67906 Mdot
.57207 .69581 Mdot
.59954 .67968 Mdot
.33607 .36963 Mdot
.62973 .3626 Mdot
.56551 .27524 Mdot
.30343 .62468 Mdot
.6809 .59069 Mdot
.26597 .37685 Mdot
.29577 .61334 Mdot
.72021 .52246 Mdot
.49147 .72742 Mdot
.66721 .60928 Mdot
.51234 .72278 Mdot
.59413 .65625 Mdot
.62926 .31155 Mdot
.33368 .56139 Mdot
.30874 .62274 Mdot
.31794 .59412 Mdot
.30972 .35976 Mdot
.69502 .63329 Mdot
.27681 .64343 Mdot
.29369 .58834 Mdot
.32598 .59612 Mdot
.33549 .5176 Mdot
.31473 .53708 Mdot
.45337 .33774 Mdot
.43818 .30532 Mdot
.38047 .69073 Mdot
.35116 .50744 Mdot
.70592 .609 Mdot
.60307 .66184 Mdot
.46448 .69648 Mdot
.69693 .50624 Mdot
.6135 .68326 Mdot
.60653 .3246 Mdot
.60756 .34353 Mdot
.61288 .28523 Mdot
.34856 .34959 Mdot
.47658 .71654 Mdot
.34103 .55703 Mdot
.69469 .51581 Mdot
.32717 .35757 Mdot
.68427 .58836 Mdot
.31848 .38416 Mdot
.40952 .70636 Mdot
.3406 .35007 Mdot
.40099 .33818 Mdot
.68238 .42246 Mdot
.511 .71037 Mdot
.30377 .35966 Mdot
.59471 .68372 Mdot
.31304 .58702 Mdot
.32189 .61566 Mdot
.67853 .6578 Mdot
.33241 .38865 Mdot
.56574 .27329 Mdot
.29997 .6018 Mdot
.27615 .6156 Mdot
.70184 .50149 Mdot
.33554 .34711 Mdot
.72331 .51724 Mdot
.49316 .72303 Mdot
.55704 .6888 Mdot
.67454 .62218 Mdot
.70737 .41582 Mdot
.39177 .68987 Mdot
.34194 .3484 Mdot
.61942 .33485 Mdot
.4244 .7185 Mdot
.55839 .28627 Mdot
.4483 .29209 Mdot
.32272 .59177 Mdot
.53284 .27138 Mdot
.334 .49315 Mdot
.70107 .42265 Mdot
.3282 .55067 Mdot
.50881 .72404 Mdot
.28465 .61225 Mdot
.60625 .31107 Mdot
.61999 .32612 Mdot
.56454 .28498 Mdot
.30838 .57893 Mdot
.34099 .49019 Mdot
.57711 .68365 Mdot
.63274 .3629 Mdot
.68187 .60628 Mdot
.6709 .63704 Mdot
.65835 .34035 Mdot
.70066 .61718 Mdot
.31831 .38186 Mdot
.28118 .62092 Mdot
.70121 .42338 Mdot
.70839 .42819 Mdot
.62151 .33778 Mdot
.65466 .32624 Mdot
.63178 .33278 Mdot
.49006 .72593 Mdot
.68431 .59458 Mdot
.27819 .65088 Mdot
.3559 .51286 Mdot
.32633 .53939 Mdot
.59166 .67417 Mdot
.38 .68588 Mdot
.34455 .46528 Mdot
.33517 .38448 Mdot
.6244 .31534 Mdot
.72078 .49848 Mdot
.47502 .74389 Mdot
.69677 .52876 Mdot
.31372 .60887 Mdot
.71103 .44608 Mdot
.56569 .70242 Mdot
.3453 .35497 Mdot
.50632 .71757 Mdot
.35291 .36723 Mdot
.70111 .48333 Mdot
.57305 .69283 Mdot
.40345 .71045 Mdot
.30929 .60208 Mdot
.3937 .70071 Mdot
.40008 .29702 Mdot
.60266 .65385 Mdot
.70979 .53108 Mdot
.50848 .71109 Mdot
.44651 .29298 Mdot
.52171 .7013 Mdot
.31886 .57409 Mdot
.32171 .52074 Mdot
.31905 .55848 Mdot
.31431 .63213 Mdot
.60492 .6748 Mdot
.40125 .69632 Mdot
.43424 .29802 Mdot
.31095 .62659 Mdot
.73539 .50261 Mdot
.35864 .53203 Mdot
.32625 .53316 Mdot
.34693 .54722 Mdot
.3219 .51505 Mdot
.61788 .67694 Mdot
.48457 .70686 Mdot
.69659 .52602 Mdot
.28306 .60275 Mdot
.70878 .41013 Mdot
.62537 .33994 Mdot
.40636 .35364 Mdot
.60802 .66924 Mdot
.35247 .36857 Mdot
.72056 .4687 Mdot
.27607 .62066 Mdot
.61859 .28567 Mdot
.32115 .63203 Mdot
.41506 .35967 Mdot
.42936 .3462 Mdot
.34152 .34708 Mdot
.62076 .30041 Mdot
.71449 .50623 Mdot
.33845 .49764 Mdot
.67828 .60712 Mdot
.68809 .62339 Mdot
.31232 .62263 Mdot
.69189 .48925 Mdot
.70469 .41649 Mdot
.54617 .27405 Mdot
.33538 .54434 Mdot
.31528 .62939 Mdot
.69947 .60818 Mdot
.55226 .2641 Mdot
.38458 .70682 Mdot
.32194 .36745 Mdot
.36133 .5412 Mdot
.43058 .29683 Mdot
.40119 .69847 Mdot
.69615 .51897 Mdot
.41354 .3343 Mdot
.34955 .55314 Mdot
.2783 .64603 Mdot
.51848 .71807 Mdot
.29407 .34011 Mdot
.64379 .36968 Mdot
.30778 .60936 Mdot
.29993 .60818 Mdot
.58894 .68394 Mdot
.70462 .43292 Mdot
.6634 .62214 Mdot
.5876 .71325 Mdot
.44273 .32237 Mdot
.70605 .43742 Mdot
.32324 .54765 Mdot
.68784 .42968 Mdot
.49193 .72776 Mdot
.31546 .5797 Mdot
.70881 .53074 Mdot
.70085 .60338 Mdot
.64128 .63513 Mdot
.31758 .60408 Mdot
.4977 .71736 Mdot
.29408 .61414 Mdot
.54978 .26432 Mdot
.40432 .34957 Mdot
.31001 .60306 Mdot
.68586 .62999 Mdot
.29735 .61601 Mdot
.70183 .48518 Mdot
.3005 .35944 Mdot
.68094 .62423 Mdot
.53396 .27773 Mdot
.62831 .3072 Mdot
.64486 .36367 Mdot
.40175 .33846 Mdot
.47703 .72695 Mdot
.59159 .69238 Mdot
.65999 .61924 Mdot
.39117 .69622 Mdot
.62259 .31361 Mdot
.32936 .37396 Mdot
.3008 .63384 Mdot
.43234 .29551 Mdot
.68583 .40717 Mdot
.62229 .69462 Mdot
.40148 .72082 Mdot
.32638 .34174 Mdot
.34779 .67516 Mdot
.43579 .32117 Mdot
.33318 .53602 Mdot
.33839 .34763 Mdot
.65177 .32304 Mdot
.52023 .71379 Mdot
.45292 .34064 Mdot
.55265 .28406 Mdot
.6135 .29747 Mdot
.70732 .41259 Mdot
.63678 .36884 Mdot
.35453 .36675 Mdot
.44744 .31213 Mdot
.68527 .62126 Mdot
.33878 .5304 Mdot
.43473 .31418 Mdot
.63288 .32049 Mdot
.40452 .33717 Mdot
.32717 .52094 Mdot
.69882 .63895 Mdot
.62688 .34828 Mdot
.29932 .61185 Mdot
.49929 .73027 Mdot
.61591 .66553 Mdot
.5401 .27721 Mdot
.38985 .69117 Mdot
.35584 .38072 Mdot
.60814 .28966 Mdot
.60791 .30884 Mdot
.3148 .61744 Mdot
.34546 .37401 Mdot
.35134 .51742 Mdot
.7175 .51056 Mdot
.37057 .67698 Mdot
.70616 .43185 Mdot
.32476 .63094 Mdot
.31046 .63403 Mdot
.4033 .68979 Mdot
.54898 .69138 Mdot
.48526 .32384 Mdot
.32863 .62821 Mdot
.33365 .51213 Mdot
.66333 .64261 Mdot
.37354 .70124 Mdot
.32082 .6744 Mdot
.5962 .66821 Mdot
.3009 .34995 Mdot
.70163 .49827 Mdot
.29784 .6317 Mdot
.73133 .48448 Mdot
.33411 .37521 Mdot
.32698 .60997 Mdot
.40737 .72347 Mdot
.66612 .62302 Mdot
.33932 .55626 Mdot
.67789 .61813 Mdot
.30906 .58347 Mdot
.61841 .66842 Mdot
.71452 .42092 Mdot
.32031 .5547 Mdot
.44814 .31446 Mdot
.58882 .2859 Mdot
.31508 .52942 Mdot
.32485 .37985 Mdot
.51169 .72128 Mdot
.43957 .32507 Mdot
.72058 .51284 Mdot
.72056 .43246 Mdot
.63216 .3313 Mdot
.69614 .53372 Mdot
.60626 .68735 Mdot
.54593 .27722 Mdot
.40616 .32484 Mdot
.52399 .70929 Mdot
.34838 .39072 Mdot
.70548 .43873 Mdot
.33963 .51144 Mdot
.33189 .55079 Mdot
.55526 .27496 Mdot
.65675 .3813 Mdot
.68511 .64876 Mdot
.61815 .66132 Mdot
.57466 .69234 Mdot
.30998 .36452 Mdot
.5427 .27956 Mdot
.3371 .56277 Mdot
.34566 .53768 Mdot
.63551 .30102 Mdot
.59217 .6716 Mdot
.34131 .36888 Mdot
.41934 .3571 Mdot
.6943 .5144 Mdot
.56897 .28922 Mdot
.68215 .62318 Mdot
.55722 .29015 Mdot
.56288 .27247 Mdot
.61926 .64809 Mdot
.32996 .61895 Mdot
.71475 .51511 Mdot
.55066 .29002 Mdot
.66556 .60995 Mdot
.31424 .60659 Mdot
.42427 .33896 Mdot
.40195 .33687 Mdot
.58297 .66095 Mdot
.62155 .34361 Mdot
.34471 .37844 Mdot
.32029 .57221 Mdot
.33635 .34031 Mdot
.58559 .67511 Mdot
.64749 .35159 Mdot
.4173 .32955 Mdot
.71665 .48751 Mdot
.29671 .61744 Mdot
.33766 .37186 Mdot
.71331 .51574 Mdot
.43886 .30144 Mdot
.27944 .6178 Mdot
.37858 .67765 Mdot
.48667 .73211 Mdot
.70184 .50491 Mdot
.38799 .70177 Mdot
.36434 .5222 Mdot
.70092 .4222 Mdot
.2923 .35851 Mdot
.58551 .28567 Mdot
.37193 .67975 Mdot
.7171 .42589 Mdot
.63581 .30011 Mdot
.63518 .36982 Mdot
.53338 .25911 Mdot
.55731 .28468 Mdot
.70234 .41103 Mdot
.42508 .32321 Mdot
.56905 .28407 Mdot
.70487 .43244 Mdot
.40823 .69997 Mdot
.29859 .63176 Mdot
.41908 .72486 Mdot
.44166 .30102 Mdot
.42085 .30939 Mdot
.5912 .66562 Mdot
.49854 .70406 Mdot
.41938 .33084 Mdot
.34479 .50525 Mdot
.57496 .69702 Mdot
.71203 .53221 Mdot
.26533 .38255 Mdot
.69242 .50733 Mdot
.5213 .71334 Mdot
.60048 .29893 Mdot
.54355 .27521 Mdot
.33871 .52895 Mdot
.71641 .46045 Mdot
.26677 .39044 Mdot
.29704 .63098 Mdot
.50639 .71755 Mdot
.32203 .63679 Mdot
.31148 .62581 Mdot
.59898 .70058 Mdot
.42291 .30073 Mdot
.58119 .69683 Mdot
.71379 .52053 Mdot
.29945 .35894 Mdot
.455 .35467 Mdot
.70027 .50354 Mdot
.35674 .52842 Mdot
.40112 .34595 Mdot
.34036 .51984 Mdot
.33823 .50256 Mdot
.29676 .5843 Mdot
.33454 .33639 Mdot
.63042 .33988 Mdot
.35281 .37298 Mdot
.69183 .63147 Mdot
.62199 .6933 Mdot
.32735 .3798 Mdot
.42212 .71891 Mdot
.38375 .70998 Mdot
.6589 .38154 Mdot
.6876 .62418 Mdot
.31926 .38686 Mdot
.70557 .49342 Mdot
.33049 .67799 Mdot
.42211 .71055 Mdot
.70075 .53921 Mdot
.32856 .52177 Mdot
.65941 .6196 Mdot
.59069 .6679 Mdot
.70818 .44067 Mdot
.66171 .61545 Mdot
.38829 .70422 Mdot
.49176 .72231 Mdot
.69565 .51794 Mdot
.33301 .61366 Mdot
.70773 .43342 Mdot
.31395 .51761 Mdot
.50176 .7174 Mdot
.67906 .62511 Mdot
.31828 .51893 Mdot
.70414 .60179 Mdot
.42846 .30651 Mdot
.28936 .59317 Mdot
.32776 .37548 Mdot
.39248 .702 Mdot
.52771 .27414 Mdot
.56025 .70348 Mdot
.66883 .61172 Mdot
.69884 .48041 Mdot
.66672 .62951 Mdot
.56835 .67529 Mdot
.71067 .5503 Mdot
.61098 .68765 Mdot
.35515 .5239 Mdot
.62993 .67963 Mdot
.59471 .69228 Mdot
.70575 .52182 Mdot
.33085 .36406 Mdot
.59893 .67728 Mdot
.55842 .27077 Mdot
.3068 .61284 Mdot
.64412 .33634 Mdot
.33182 .39305 Mdot
.60773 .67025 Mdot
.32503 .37743 Mdot
.63501 .32711 Mdot
.41891 .36005 Mdot
.69178 .39993 Mdot
.69325 .43721 Mdot
.43524 .35113 Mdot
.71548 .43197 Mdot
.68607 .63807 Mdot
.54525 .28566 Mdot
.32369 .56724 Mdot
.33748 .5445 Mdot
.33431 .39459 Mdot
.68091 .64357 Mdot
.70712 .45669 Mdot
.42558 .33045 Mdot
.57683 .67468 Mdot
.71669 .49025 Mdot
.5424 .27149 Mdot
.37674 .7078 Mdot
.70939 .41439 Mdot
.43812 .2978 Mdot
.43834 .3213 Mdot
.33888 .51724 Mdot
.32437 .60821 Mdot
.32523 .34691 Mdot
.57898 .28532 Mdot
.48472 .70068 Mdot
.65561 .32681 Mdot
.35343 .54106 Mdot
.47904 .7044 Mdot
.35575 .50327 Mdot
.35483 .37344 Mdot
.70299 .40806 Mdot
.68829 .6181 Mdot
.30589 .37575 Mdot
.62909 .30708 Mdot
.36359 .6811 Mdot
.32105 .62125 Mdot
.38344 .69786 Mdot
.60624 .33077 Mdot
.67407 .64166 Mdot
.62467 .33144 Mdot
.70023 .4203 Mdot
.32258 .38348 Mdot
.4877 .72736 Mdot
.44258 .30083 Mdot
.63527 .3572 Mdot
.71676 .53578 Mdot
.5332 .27905 Mdot
.72055 .42946 Mdot
.44171 .32313 Mdot
.37344 .6907 Mdot
.61689 .35712 Mdot
.4263 .34121 Mdot
.58303 .66396 Mdot
.27239 .63615 Mdot
.56654 .66793 Mdot
.61469 .34114 Mdot
.27216 .3596 Mdot
.71105 .51931 Mdot
.71277 .40582 Mdot
.32047 .50336 Mdot
.27656 .40805 Mdot
.31839 .56699 Mdot
.69397 .44584 Mdot
.70196 .4253 Mdot
.70401 .50746 Mdot
.62634 .32932 Mdot
.70466 .61252 Mdot
.51643 .68925 Mdot
.61113 .3429 Mdot
.32828 .58557 Mdot
.68419 .58843 Mdot
.42517 .7065 Mdot
.62005 .35705 Mdot
.48422 .71132 Mdot
.61282 .65487 Mdot
.32311 .39 Mdot
.31979 .58785 Mdot
.70715 .41653 Mdot
.29389 .62321 Mdot
.73823 .49776 Mdot
.63021 .32525 Mdot
.41426 .34303 Mdot
.70413 .47224 Mdot
.32956 .54647 Mdot
.34877 .5423 Mdot
.36138 .52404 Mdot
.33779 .39213 Mdot
.59321 .66012 Mdot
.2945 .59656 Mdot
.27901 .62741 Mdot
.46986 .70677 Mdot
.52925 .26183 Mdot
.35353 .36459 Mdot
.28278 .65532 Mdot
.63628 .2964 Mdot
.58221 .66961 Mdot
.32288 .53749 Mdot
.70185 .40426 Mdot
.49448 .704 Mdot
.70112 .52665 Mdot
.72291 .50085 Mdot
.57143 .29125 Mdot
.68238 .63397 Mdot
.47002 .71379 Mdot
.65127 .36602 Mdot
.54637 .6953 Mdot
.4735 .70916 Mdot
.62104 .66525 Mdot
.69732 .48787 Mdot
.28711 .41969 Mdot
.70242 .40151 Mdot
.40177 .33435 Mdot
.60648 .68949 Mdot
.66744 .59153 Mdot
.39884 .69702 Mdot
.68001 .60069 Mdot
.55501 .27599 Mdot
.59007 .69398 Mdot
.50277 .28731 Mdot
.57145 .69482 Mdot
.70776 .51688 Mdot
.70847 .43608 Mdot
.47717 .71207 Mdot
.35225 .52453 Mdot
.40119 .71494 Mdot
.42524 .33112 Mdot
.37501 .69077 Mdot
.60768 .322 Mdot
.56222 .27434 Mdot
.68422 .42704 Mdot
.6006 .69839 Mdot
.70279 .54423 Mdot
.34956 .54231 Mdot
.50061 .71913 Mdot
.31659 .62947 Mdot
.71232 .42004 Mdot
.5281 .70119 Mdot
.35276 .511 Mdot
.47694 .71591 Mdot
.60373 .32919 Mdot
.65677 .32521 Mdot
.5745 .65962 Mdot
.57155 .29058 Mdot
.3336 .51565 Mdot
.31605 .3616 Mdot
.35115 .35204 Mdot
.32029 .61034 Mdot
.59705 .28882 Mdot
.38574 .70788 Mdot
.34064 .51055 Mdot
.36366 .67667 Mdot
.60543 .335 Mdot
.40684 .31189 Mdot
.6302 .31697 Mdot
.61922 .67551 Mdot
.42647 .34914 Mdot
.61103 .31202 Mdot
.3858 .71693 Mdot
.43766 .31605 Mdot
.5847 .28664 Mdot
.33627 .37637 Mdot
.35598 .50586 Mdot
.3491 .46926 Mdot
.62656 .36265 Mdot
.71037 .50894 Mdot
.6052 .67872 Mdot
.69897 .52836 Mdot
.64931 .31127 Mdot
.32797 .60662 Mdot
.43196 .30229 Mdot
.71959 .4169 Mdot
.46248 .71338 Mdot
.32101 .3582 Mdot
.7 .40012 Mdot
.47268 .72532 Mdot
.32164 .6163 Mdot
.26936 .39665 Mdot
.32822 .54061 Mdot
.56366 .27644 Mdot
.70448 .4382 Mdot
.31607 .33504 Mdot
.34115 .53235 Mdot
.64764 .33792 Mdot
.34162 .34195 Mdot
.34194 .51477 Mdot
.53337 .27501 Mdot
.29895 .60773 Mdot
.33717 .34762 Mdot
.58926 .68626 Mdot
.37043 .67573 Mdot
.33618 .40098 Mdot
.30537 .37462 Mdot
.31836 .56147 Mdot
.31429 .63394 Mdot
.57654 .2839 Mdot
.66606 .6244 Mdot
.30862 .60519 Mdot
.33756 .39473 Mdot
.57433 .70146 Mdot
.59839 .69244 Mdot
.52049 .71536 Mdot
.71294 .48072 Mdot
.62489 .34517 Mdot
.32875 .35142 Mdot
.55588 .26631 Mdot
.29783 .62889 Mdot
.51525 .71612 Mdot
.33179 .38323 Mdot
.71893 .52524 Mdot
.47869 .72528 Mdot
.69565 .47062 Mdot
.28235 .60486 Mdot
.70332 .39945 Mdot
.32239 .53905 Mdot
.31783 .52646 Mdot
.58463 .69271 Mdot
.73698 .50291 Mdot
.71788 .42115 Mdot
.63205 .31114 Mdot
.41785 .32855 Mdot
.62337 .69172 Mdot
.33659 .37092 Mdot
.50726 .68639 Mdot
.32838 .53372 Mdot
.33659 .56372 Mdot
.58715 .69296 Mdot
.32087 .6244 Mdot
.58227 .70528 Mdot
.55457 .2673 Mdot
.27756 .40978 Mdot
.68453 .61754 Mdot
.66819 .61905 Mdot
.4558 .72807 Mdot
.60461 .28477 Mdot
.56116 .69732 Mdot
.29673 .63144 Mdot
.65541 .32219 Mdot
.2955 .3395 Mdot
.33815 .36178 Mdot
.32085 .33478 Mdot
.55997 .69992 Mdot
.39971 .72553 Mdot
.49007 .72982 Mdot
.30855 .59669 Mdot
.34968 .67566 Mdot
.69947 .4214 Mdot
.28812 .60404 Mdot
.43093 .32749 Mdot
.63155 .32152 Mdot
.33511 .49476 Mdot
.34688 .50443 Mdot
.6889 .61573 Mdot
.29801 .36373 Mdot
.70891 .54708 Mdot
.42565 .34307 Mdot
.63006 .36558 Mdot
.31517 .373 Mdot
.70142 .61991 Mdot
.31633 .51916 Mdot
.45104 .32931 Mdot
.41596 .3034 Mdot
.33058 .51932 Mdot
.30784 .60844 Mdot
.45444 .30624 Mdot
.6997 .5172 Mdot
.63441 .31304 Mdot
.43223 .34318 Mdot
.3916 .70416 Mdot
.36694 .67719 Mdot
.34423 .54016 Mdot
.70035 .59682 Mdot
.7191 .53305 Mdot
.42623 .30506 Mdot
.54969 .28931 Mdot
.30147 .63433 Mdot
.4174 .70977 Mdot
.41927 .28687 Mdot
.4281 .32565 Mdot
.51662 .68897 Mdot
.35086 .36533 Mdot
.50181 .71673 Mdot
.27887 .61169 Mdot
.37785 .68373 Mdot
.32695 .54926 Mdot
.64894 .31784 Mdot
.71448 .49194 Mdot
.44401 .34693 Mdot
.62387 .31609 Mdot
.59823 .69217 Mdot
.30968 .59738 Mdot
.67051 .63876 Mdot
.66062 .62228 Mdot
.57035 .67114 Mdot
.69832 .49876 Mdot
.60929 .70749 Mdot
.45395 .30819 Mdot
.33236 .54281 Mdot
.69831 .42962 Mdot
.55909 .69577 Mdot
.38914 .68417 Mdot
.56683 .70308 Mdot
.69122 .63691 Mdot
.37888 .68034 Mdot
.48292 .71882 Mdot
.27753 .62704 Mdot
.32323 .51622 Mdot
.34929 .37459 Mdot
.67207 .59193 Mdot
.418 .7068 Mdot
.31858 .57525 Mdot
.33684 .5326 Mdot
.47816 .71008 Mdot
.33273 .33704 Mdot
.32019 .63096 Mdot
.33002 .53647 Mdot
.28239 .65626 Mdot
.38991 .68536 Mdot
.66764 .64475 Mdot
.68783 .40039 Mdot
.52106 .71568 Mdot
.61358 .2911 Mdot
.58332 .68124 Mdot
.3173 .38839 Mdot
.5736 .71009 Mdot
.4779 .7324 Mdot
.70968 .49787 Mdot
.66704 .60977 Mdot
.63207 .35066 Mdot
.71294 .50954 Mdot
.70779 .43323 Mdot
.48266 .70818 Mdot
.64004 .31376 Mdot
.29744 .35411 Mdot
.70808 .41126 Mdot
.52547 .70234 Mdot
.70778 .51544 Mdot
.61073 .64981 Mdot
.37373 .69284 Mdot
.27884 .61457 Mdot
.42373 .3185 Mdot
.45094 .34049 Mdot
.70113 .41803 Mdot
.32374 .3665 Mdot
.47641 .72409 Mdot
.60069 .67884 Mdot
.32313 .36055 Mdot
.60682 .6566 Mdot
.53995 .27099 Mdot
.58404 .67174 Mdot
.55345 .2724 Mdot
.68361 .59972 Mdot
.32087 .5888 Mdot
.30225 .37231 Mdot
.45312 .3004 Mdot
.41024 .71092 Mdot
.41521 .32806 Mdot
.32905 .50437 Mdot
.47178 .71869 Mdot
.35605 .52396 Mdot
.61761 .2838 Mdot
.33065 .39625 Mdot
.58811 .69617 Mdot
.43498 .36243 Mdot
.71098 .53617 Mdot
.38579 .69796 Mdot
.41705 .34482 Mdot
.49838 .71797 Mdot
.57747 .70415 Mdot
.69356 .61137 Mdot
.61962 .67081 Mdot
.60988 .28858 Mdot
.48208 .32834 Mdot
.35011 .53795 Mdot
.43051 .36193 Mdot
.70414 .42541 Mdot
.71357 .43928 Mdot
.64003 .34545 Mdot
.29818 .42751 Mdot
.62103 .31547 Mdot
.2894 .34303 Mdot
.68678 .60063 Mdot
.31091 .34845 Mdot
.35329 .53023 Mdot
.5989 .67147 Mdot
.51423 .68875 Mdot
.29591 .36505 Mdot
.35254 .36532 Mdot
.71313 .43684 Mdot
.69931 .43507 Mdot
.40759 .33449 Mdot
.3911 .68631 Mdot
.39618 .6868 Mdot
.33259 .55655 Mdot
.69875 .41519 Mdot
.49171 .71777 Mdot
.69163 .39837 Mdot
.50881 .71408 Mdot
.33252 .39716 Mdot
.60945 .30469 Mdot
.67518 .38462 Mdot
.58785 .67739 Mdot
.309 .59612 Mdot
.56686 .67187 Mdot
.27454 .63675 Mdot
.72102 .42459 Mdot
.2928 .36457 Mdot
.62929 .33547 Mdot
.71909 .47209 Mdot
.61255 .30363 Mdot
.37186 .36037 Mdot
.40973 .7277 Mdot
.69989 .47913 Mdot
.37903 .69589 Mdot
.6572 .34442 Mdot
.32571 .50779 Mdot
.44186 .33577 Mdot
.40126 .346 Mdot
.45903 .72303 Mdot
.61526 .66255 Mdot
.35006 .37621 Mdot
.35343 .5308 Mdot
.62063 .65234 Mdot
.35152 .53268 Mdot
.35076 .53434 Mdot
.33965 .50075 Mdot
.71028 .42151 Mdot
.37763 .69867 Mdot
.35343 .52398 Mdot
.56463 .28598 Mdot
.30474 .33526 Mdot
.61978 .36178 Mdot
.58323 .69256 Mdot
.32711 .35753 Mdot
.58077 .6804 Mdot
.39796 .71132 Mdot
.69291 .49718 Mdot
.5965 .65871 Mdot
.48998 .71261 Mdot
.56204 .70378 Mdot
.71484 .40899 Mdot
.34215 .3802 Mdot
.43492 .32514 Mdot
.72381 .55219 Mdot
.55725 .2826 Mdot
.41918 .33731 Mdot
.53683 .27424 Mdot
.3238 .5377 Mdot
.68489 .62391 Mdot
.41675 .33048 Mdot
.72236 .52828 Mdot
.65921 .34094 Mdot
.2772 .6111 Mdot
.30085 .61962 Mdot
.60665 .32886 Mdot
.42862 .31815 Mdot
.39309 .70314 Mdot
.37858 .7075 Mdot
.65712 .34645 Mdot
.71461 .55114 Mdot
.70558 .42376 Mdot
.33262 .3621 Mdot
.67904 .64308 Mdot
.69124 .61307 Mdot
.7139 .53245 Mdot
.7193 .46417 Mdot
.30517 .62075 Mdot
.29899 .61361 Mdot
.40425 .70576 Mdot
.3213 .51719 Mdot
.54474 .28779 Mdot
.4228 .33658 Mdot
.67544 .60851 Mdot
.47096 .71666 Mdot
.50391 .70202 Mdot
.35643 .53133 Mdot
.32875 .60368 Mdot
.62059 .34795 Mdot
.50308 .72022 Mdot
.33521 .34712 Mdot
.61547 .70075 Mdot
.30015 .60639 Mdot
.33244 .39784 Mdot
.68876 .60738 Mdot
.58142 .28664 Mdot
.70926 .50886 Mdot
.65384 .36008 Mdot
.6527 .36359 Mdot
.39729 .29914 Mdot
.58567 .68085 Mdot
.41938 .33703 Mdot
.52806 .27962 Mdot
.40076 .34275 Mdot
.35062 .3596 Mdot
.32045 .60304 Mdot
.5569 .27783 Mdot
.62351 .36607 Mdot
.70309 .4763 Mdot
.29234 .59249 Mdot
.36428 .53421 Mdot
.71787 .42601 Mdot
.3348 .5212 Mdot
.32908 .38153 Mdot
.69267 .42478 Mdot
.66603 .61195 Mdot
.34707 .37573 Mdot
.69704 .4055 Mdot
.69356 .61572 Mdot
.48282 .7094 Mdot
.39174 .68534 Mdot
.60283 .68378 Mdot
.70112 .61406 Mdot
.30638 .62211 Mdot
.56709 .29174 Mdot
.6822 .61248 Mdot
.60963 .68113 Mdot
.62152 .67036 Mdot
.64746 .35735 Mdot
.3447 .34559 Mdot
.70425 .48079 Mdot
.35322 .5179 Mdot
.60592 .30218 Mdot
.31537 .35348 Mdot
.67079 .60524 Mdot
.36246 .50962 Mdot
.29713 .6276 Mdot
.3198 .35926 Mdot
.35496 .36301 Mdot
.32435 .3638 Mdot
.71057 .43416 Mdot
.4867 .71151 Mdot
.5857 .70265 Mdot
.71722 .41553 Mdot
.32359 .3891 Mdot
.34556 .39639 Mdot
.49264 .30985 Mdot
.30357 .61739 Mdot
.35412 .37674 Mdot
.61909 .69807 Mdot
.37863 .71532 Mdot
.40091 .3432 Mdot
.27407 .35562 Mdot
.60494 .28174 Mdot
.28246 .34696 Mdot
.71253 .49155 Mdot
.50609 .70972 Mdot
.34011 .36351 Mdot
.44233 .31357 Mdot
.30247 .6202 Mdot
.31036 .63113 Mdot
.3164 .36427 Mdot
.32744 .62494 Mdot
.69145 .62181 Mdot
.56141 .67291 Mdot
.32451 .35715 Mdot
.65358 .33725 Mdot
.60881 .34167 Mdot
.61804 .32435 Mdot
.33756 .53827 Mdot
.42176 .70048 Mdot
.3384 .6774 Mdot
.62031 .67302 Mdot
.7026 .43391 Mdot
.68832 .60431 Mdot
.63648 .65689 Mdot
.5947 .69514 Mdot
.6594 .33618 Mdot
.32399 .36685 Mdot
.70157 .59792 Mdot
.70919 .43706 Mdot
.70222 .41686 Mdot
.62433 .36316 Mdot
.6226 .31234 Mdot
.61921 .33678 Mdot
.60543 .66916 Mdot
.66417 .65579 Mdot
.37489 .68587 Mdot
.6612 .62055 Mdot
.63806 .2961 Mdot
.55375 .26731 Mdot
.62311 .36146 Mdot
.70637 .52555 Mdot
.69513 .59579 Mdot
.30066 .60978 Mdot
.35292 .47368 Mdot
.60763 .34009 Mdot
.33162 .38882 Mdot
.62751 .68677 Mdot
.27559 .40659 Mdot
.51386 .71039 Mdot
.72201 .51515 Mdot
.43745 .30869 Mdot
.36162 .52763 Mdot
.63367 .31436 Mdot
.27618 .35435 Mdot
.41956 .30351 Mdot
.38588 .69334 Mdot
.58359 .71629 Mdot
.71566 .50314 Mdot
.3739 .70262 Mdot
.44524 .32872 Mdot
.46714 .71545 Mdot
.69317 .42308 Mdot
.63345 .35857 Mdot
.53088 .25993 Mdot
.59368 .66499 Mdot
.31329 .59539 Mdot
.43918 .30414 Mdot
.31722 .57162 Mdot
.61139 .31563 Mdot
.34685 .37373 Mdot
.61076 .3239 Mdot
.6695 .64556 Mdot
.64033 .36362 Mdot
.36358 .52133 Mdot
.57898 .70264 Mdot
.70349 .42199 Mdot
.33275 .67635 Mdot
.44395 .36017 Mdot
.64502 .3498 Mdot
.45452 .30271 Mdot
.49586 .70287 Mdot
.52496 .70992 Mdot
.44322 .34816 Mdot
.36413 .51921 Mdot
.70793 .53108 Mdot
.58781 .70376 Mdot
.71322 .53649 Mdot
.34478 .34431 Mdot
.72721 .55104 Mdot
.70904 .50749 Mdot
.43016 .7101 Mdot
.34463 .37974 Mdot
.32848 .60858 Mdot
.35067 .5068 Mdot
.7238 .51208 Mdot
.38373 .7011 Mdot
.62088 .65236 Mdot
.38574 .71632 Mdot
.28047 .61662 Mdot
.7108 .53259 Mdot
.40552 .32522 Mdot
.37679 .70416 Mdot
.34128 .34101 Mdot
.70297 .41128 Mdot
.36591 .6752 Mdot
.42444 .33792 Mdot
.31518 .37695 Mdot
.34449 .38605 Mdot
.31904 .37392 Mdot
.36081 .51909 Mdot
.31752 .54192 Mdot
.30604 .3771 Mdot
.71065 .55052 Mdot
.30913 .37815 Mdot
.2867 .36171 Mdot
.70383 .45733 Mdot
.35455 .36599 Mdot
.33909 .51079 Mdot
.50878 .71307 Mdot
.50454 .7086 Mdot
.64187 .33394 Mdot
.73711 .53489 Mdot
.56647 .2819 Mdot
.34091 .55933 Mdot
.68867 .65665 Mdot
.59123 .69166 Mdot
.45896 .31834 Mdot
.28077 .62259 Mdot
.47778 .73063 Mdot
.60306 .68916 Mdot
.40097 .70288 Mdot
.58083 .67351 Mdot
.44613 .33163 Mdot
.36318 .52757 Mdot
.58493 .68729 Mdot
.55864 .68731 Mdot
.33013 .62169 Mdot
.57715 .67487 Mdot
.68095 .59731 Mdot
.70469 .43441 Mdot
.70889 .4904 Mdot
.70879 .53181 Mdot
.62433 .30859 Mdot
.66789 .61642 Mdot
.30675 .59901 Mdot
.63065 .31128 Mdot
.32821 .52419 Mdot
.71204 .53273 Mdot
.31744 .56596 Mdot
.66763 .61907 Mdot
.34383 .50845 Mdot
.42792 .71326 Mdot
.53424 .27292 Mdot
.31915 .36027 Mdot
.61721 .66005 Mdot
.54424 .26051 Mdot
.70787 .41245 Mdot
.6543 .63339 Mdot
.29023 .36349 Mdot
.46555 .7139 Mdot
.36337 .53912 Mdot
.34291 .49707 Mdot
.466 .71371 Mdot
.40432 .72739 Mdot
.41276 .30882 Mdot
.62869 .30702 Mdot
.64908 .36294 Mdot
.30922 .61781 Mdot
.67145 .61649 Mdot
.3377 .34511 Mdot
.33414 .40013 Mdot
.45958 .33296 Mdot
.38698 .7118 Mdot
.27907 .6269 Mdot
.30533 .57773 Mdot
.30989 .5957 Mdot
.63789 .34064 Mdot
.40562 .31471 Mdot
.39758 .69742 Mdot
.32158 .38097 Mdot
.30336 .59891 Mdot
.58229 .6908 Mdot
.67266 .59969 Mdot
.61807 .34345 Mdot
.68438 .40744 Mdot
.43829 .34502 Mdot
.61616 .35596 Mdot
.30872 .61676 Mdot
.48464 .70121 Mdot
.69113 .42965 Mdot
.69595 .6362 Mdot
.31071 .37027 Mdot
.63296 .31638 Mdot
.30238 .35737 Mdot
.66574 .62828 Mdot
.67135 .60486 Mdot
.31802 .62308 Mdot
.4722 .33926 Mdot
.63735 .35935 Mdot
.34544 .53924 Mdot
.60642 .32679 Mdot
.55059 .27242 Mdot
.69338 .39935 Mdot
.30928 .60508 Mdot
.51977 .68909 Mdot
.70317 .53192 Mdot
.34928 .54743 Mdot
.49513 .7059 Mdot
.48128 .72587 Mdot
.6552 .33689 Mdot
.31105 .38583 Mdot
.31226 .37722 Mdot
.65463 .64197 Mdot
.71219 .58876 Mdot
.29307 .5894 Mdot
.64714 .35475 Mdot
.52395 .69993 Mdot
.707 .50272 Mdot
.6881 .59903 Mdot
.68135 .50218 Mdot
.7053 .51965 Mdot
.3029 .6144 Mdot
.32799 .37947 Mdot
.69915 .62007 Mdot
.40036 .34328 Mdot
.29968 .67418 Mdot
.44983 .29596 Mdot
.48151 .32958 Mdot
.42903 .34022 Mdot
.69141 .48638 Mdot
.61494 .33554 Mdot
.56766 .70215 Mdot
.72206 .52521 Mdot
.70815 .49967 Mdot
.56692 .27443 Mdot
.61561 .66682 Mdot
.59379 .65162 Mdot
.60489 .71042 Mdot
.55677 .282 Mdot
.32635 .37063 Mdot
.3931 .7199 Mdot
.61901 .32362 Mdot
.51977 .26513 Mdot
.70895 .44443 Mdot
.7141 .43802 Mdot
.69395 .64586 Mdot
.29188 .61717 Mdot
.62114 .67076 Mdot
.32626 .52148 Mdot
.31985 .60156 Mdot
.71791 .52443 Mdot
.68718 .59914 Mdot
.6951 .44459 Mdot
.3126 .61575 Mdot
.30463 .5879 Mdot
.65706 .32241 Mdot
.42815 .3316 Mdot
.66084 .38236 Mdot
.31355 .6054 Mdot
.61765 .30931 Mdot
.59305 .655 Mdot
.44607 .31327 Mdot
.41921 .71036 Mdot
.69782 .44022 Mdot
.42994 .30291 Mdot
.44802 .32092 Mdot
.37006 .50691 Mdot
.58194 .67457 Mdot
.65841 .63278 Mdot
.34818 .35005 Mdot
.68437 .42383 Mdot
.69214 .40531 Mdot
.69579 .47226 Mdot
.304 .61382 Mdot
.70189 .44616 Mdot
.40862 .35644 Mdot
.34744 .54915 Mdot
.47305 .71251 Mdot
.60074 .66017 Mdot
.31003 .57605 Mdot
.49386 .73164 Mdot
.70959 .52075 Mdot
.42324 .28513 Mdot
.29321 .58974 Mdot
.61218 .33848 Mdot
.70565 .62172 Mdot
.59521 .66765 Mdot
.34393 .36029 Mdot
.71493 .42062 Mdot
.28701 .41815 Mdot
.68899 .59876 Mdot
.29604 .6084 Mdot
.70503 .5062 Mdot
.43813 .30688 Mdot
.41984 .32061 Mdot
.45778 .3031 Mdot
.68242 .59138 Mdot
.44117 .3112 Mdot
.5653 .67524 Mdot
.4008 .70626 Mdot
.32014 .60553 Mdot
.69787 .50382 Mdot
.32714 .37246 Mdot
.42133 .36136 Mdot
.54443 .26892 Mdot
.39512 .68918 Mdot
.32333 .61209 Mdot
.73117 .54997 Mdot
.33049 .37584 Mdot
.35867 .52561 Mdot
.41308 .3076 Mdot
.42973 .70617 Mdot
.26665 .37838 Mdot
.41865 .34119 Mdot
.51063 .70273 Mdot
.69076 .63331 Mdot
.41454 .33091 Mdot
.6698 .60146 Mdot
.35838 .52864 Mdot
.38746 .69734 Mdot
.66156 .63894 Mdot
.65466 .60368 Mdot
.4492 .33362 Mdot
.69841 .4033 Mdot
.38577 .70417 Mdot
.33649 .50971 Mdot
.4236 .70367 Mdot
.42932 .30847 Mdot
.71917 .55217 Mdot
.60442 .30957 Mdot
.57409 .2894 Mdot
.52925 .28175 Mdot
.72029 .42987 Mdot
.68109 .41446 Mdot
.30878 .63673 Mdot
.47471 .692 Mdot
.42204 .7014 Mdot
.69283 .51772 Mdot
.38559 .72203 Mdot
.35233 .52438 Mdot
.33019 .52564 Mdot
.60621 .32672 Mdot
.69965 .48273 Mdot
.5208 .71494 Mdot
.39505 .698 Mdot
.32604 .39244 Mdot
.66262 .61601 Mdot
.34793 .51622 Mdot
.72837 .5524 Mdot
.65534 .34128 Mdot
.73749 .54012 Mdot
.33842 .51261 Mdot
.42878 .33138 Mdot
.68923 .43144 Mdot
.70559 .42688 Mdot
.65016 .32736 Mdot
.64996 .33031 Mdot
.33556 .51121 Mdot
.70387 .54094 Mdot
.38763 .7223 Mdot
.38109 .70822 Mdot
.43193 .31614 Mdot
.33353 .34994 Mdot
.33072 .50256 Mdot
.57725 .6582 Mdot
.462 .35009 Mdot
.34235 .54 Mdot
.6662 .63526 Mdot
.62312 .33823 Mdot
.53891 .26975 Mdot
.68527 .60876 Mdot
.54129 .27453 Mdot
.73563 .54142 Mdot
.31622 .55952 Mdot
.3451 .3522 Mdot
.45601 .73242 Mdot
.30269 .36995 Mdot
.42855 .3045 Mdot
.3021 .61532 Mdot
.58005 .29004 Mdot
.52382 .27676 Mdot
.47261 .7432 Mdot
.71654 .5122 Mdot
.40148 .33637 Mdot
.48968 .71603 Mdot
.32739 .39537 Mdot
.62977 .32207 Mdot
.41283 .35157 Mdot
.30655 .60251 Mdot
.58467 .6785 Mdot
.51604 .7191 Mdot
.41621 .34759 Mdot
.42268 .30918 Mdot
.42822 .34962 Mdot
.69734 .40532 Mdot
.61371 .68154 Mdot
.71084 .44232 Mdot
.53419 .26728 Mdot
.37398 .68731 Mdot
.30262 .59123 Mdot
.68634 .60304 Mdot
.33891 .55019 Mdot
.69944 .5322 Mdot
.63478 .66652 Mdot
.32682 .36527 Mdot
.44949 .3255 Mdot
.72553 .47771 Mdot
.39974 .34402 Mdot
.4703 .70829 Mdot
.5004 .6984 Mdot
.58207 .69375 Mdot
.70226 .47201 Mdot
.33313 .4929 Mdot
.64252 .37169 Mdot
.31026 .37184 Mdot
.70799 .43631 Mdot
.47246 .70801 Mdot
.35043 .50545 Mdot
.32847 .37433 Mdot
.71436 .43508 Mdot
.45681 .33803 Mdot
.7068 .54476 Mdot
.44867 .29425 Mdot
.49834 .74219 Mdot
.33999 .51577 Mdot
.42941 .33365 Mdot
.59851 .68857 Mdot
.70147 .43048 Mdot
.60595 .66364 Mdot
.44625 .33085 Mdot
.54834 .26943 Mdot
.7062 .43691 Mdot
.30347 .59481 Mdot
.57479 .7099 Mdot
.66686 .65636 Mdot
.61042 .6869 Mdot
.49976 .29443 Mdot
.56039 .27577 Mdot
.61847 .33934 Mdot
.70504 .52414 Mdot
.60679 .29833 Mdot
.34434 .3811 Mdot
.3964 .72038 Mdot
.64872 .33728 Mdot
.61399 .67846 Mdot
.61686 .30016 Mdot
.41358 .71975 Mdot
.70596 .40312 Mdot
.61245 .35078 Mdot
.33297 .54737 Mdot
.4914 .7075 Mdot
.41817 .313 Mdot
.32687 .33595 Mdot
.39853 .70565 Mdot
.2901 .60391 Mdot
.43772 .32725 Mdot
.3415 .51074 Mdot
.70144 .53535 Mdot
.33444 .67314 Mdot
.37906 .68225 Mdot
.54561 .27259 Mdot
.65771 .60011 Mdot
.65079 .36073 Mdot
.34945 .39451 Mdot
.34297 .54548 Mdot
.34461 .51008 Mdot
.48716 .72361 Mdot
.63143 .67769 Mdot
.70976 .42368 Mdot
.37258 .6846 Mdot
.55041 .28178 Mdot
.57658 .69992 Mdot
.57801 .69706 Mdot
.31167 .58915 Mdot
.42707 .33579 Mdot
.71727 .4913 Mdot
.36237 .52079 Mdot
.40222 .34268 Mdot
.28178 .61639 Mdot
.71846 .43825 Mdot
.56249 .27705 Mdot
.52488 .2696 Mdot
.56849 .69488 Mdot
.6073 .33602 Mdot
.48934 .72352 Mdot
.43881 .31019 Mdot
.52905 .28219 Mdot
.71073 .4207 Mdot
.30874 .3706 Mdot
.33068 .5324 Mdot
.32941 .61958 Mdot
.60646 .33502 Mdot
.637 .31207 Mdot
.39007 .72307 Mdot
.73388 .54752 Mdot
.48739 .3169 Mdot
.69632 .42292 Mdot
.58083 .69149 Mdot
.32032 .50052 Mdot
.33428 .45647 Mdot
.70384 .4964 Mdot
.47537 .70646 Mdot
.6121 .34471 Mdot
.41507 .28713 Mdot
.59944 .69267 Mdot
.30893 .36958 Mdot
.33636 .55338 Mdot
.58477 .69695 Mdot
.55001 .28695 Mdot
.59848 .70043 Mdot
.42033 .33069 Mdot
.71057 .40529 Mdot
.63438 .32888 Mdot
.70066 .48105 Mdot
.52017 .68978 Mdot
.32631 .36844 Mdot
.31625 .58622 Mdot
.50994 .71633 Mdot
.59964 .6579 Mdot
.48323 .7136 Mdot
.43422 .35122 Mdot
.48455 .70983 Mdot
.57665 .69235 Mdot
.34899 .50662 Mdot
.32613 .55405 Mdot
.5449 .26365 Mdot
.33158 .51797 Mdot
.3012 .6327 Mdot
.42829 .71325 Mdot
.33734 .54145 Mdot
.35076 .53497 Mdot
.31032 .60843 Mdot
.67657 .63914 Mdot
.28357 .60886 Mdot
.69779 .63982 Mdot
.67736 .64954 Mdot
.53391 .26876 Mdot
.32987 .39647 Mdot
.35246 .35713 Mdot
.28395 .60452 Mdot
.32947 .61284 Mdot
.61454 .66443 Mdot
.69867 .59677 Mdot
.7032 .42346 Mdot
.38102 .68551 Mdot
.48792 .31993 Mdot
.32147 .56357 Mdot
.64252 .33554 Mdot
.6537 .34153 Mdot
.32418 .52712 Mdot
.27315 .40367 Mdot
.31614 .63456 Mdot
.40826 .71556 Mdot
.35721 .51388 Mdot
.31657 .61266 Mdot
.64717 .36133 Mdot
.32154 .5908 Mdot
.48893 .73031 Mdot
.57165 .69088 Mdot
.30578 .36255 Mdot
.41792 .33418 Mdot
.38756 .69746 Mdot
.31391 .53029 Mdot
.58878 .66654 Mdot
.4843 .72411 Mdot
.63729 .32383 Mdot
.6734 .60589 Mdot
.40949 .71191 Mdot
.70616 .40838 Mdot
.29416 .67215 Mdot
.72518 .55268 Mdot
.69787 .41092 Mdot
.31407 .37584 Mdot
.63272 .3538 Mdot
.35695 .54329 Mdot
.62233 .30188 Mdot
.30998 .61234 Mdot
.37689 .70854 Mdot
.34357 .35207 Mdot
.60585 .67389 Mdot
.69742 .43902 Mdot
.68527 .63355 Mdot
.60423 .64949 Mdot
.34997 .67297 Mdot
.64731 .379 Mdot
.63767 .36302 Mdot
.43885 .35957 Mdot
.57337 .66966 Mdot
.30309 .63403 Mdot
.60167 .71098 Mdot
.68263 .62551 Mdot
.59016 .67285 Mdot
.30694 .67115 Mdot
.28086 .65883 Mdot
.30674 .60662 Mdot
.59497 .68997 Mdot
.63022 .35458 Mdot
.34808 .35408 Mdot
.3091 .62522 Mdot
.43779 .30948 Mdot
.56814 .69529 Mdot
.61379 .34341 Mdot
.31881 .58646 Mdot
.62023 .30994 Mdot
.58967 .69934 Mdot
.6546 .35194 Mdot
.69246 .39881 Mdot
.64811 .33928 Mdot
.33551 .49717 Mdot
.35389 .5094 Mdot
.57617 .6945 Mdot
.6712 .60525 Mdot
.46956 .70993 Mdot
.33435 .54424 Mdot
.56197 .69822 Mdot
.61941 .29156 Mdot
.7056 .60171 Mdot
.47615 .72442 Mdot
.30041 .6297 Mdot
.3063 .37621 Mdot
.3698 .68495 Mdot
.32391 .67364 Mdot
.37729 .68132 Mdot
.32312 .36974 Mdot
.48209 .6898 Mdot
.31966 .57691 Mdot
.32418 .63085 Mdot
.55145 .28387 Mdot
.33096 .54999 Mdot
.44627 .30996 Mdot
.47044 .7257 Mdot
.28329 .6657 Mdot
.47174 .71068 Mdot
.60727 .68568 Mdot
.58531 .70115 Mdot
.6354 .29959 Mdot
.59596 .69335 Mdot
.44156 .30816 Mdot
.7181 .49316 Mdot
.60696 .6499 Mdot
.40481 .31639 Mdot
.42619 .30145 Mdot
.454 .30834 Mdot
.42029 .34375 Mdot
.48598 .3202 Mdot
.56246 .27071 Mdot
.42162 .30561 Mdot
.56786 .67662 Mdot
.59791 .28691 Mdot
.29137 .36162 Mdot
.71771 .49167 Mdot
.44774 .31753 Mdot
.33109 .55108 Mdot
.47811 .72202 Mdot
.65422 .62778 Mdot
.72073 .42475 Mdot
.43614 .34843 Mdot
.30439 .63183 Mdot
.56588 .69143 Mdot
.34881 .51813 Mdot
.31786 .39025 Mdot
.6673 .62047 Mdot
.62941 .31393 Mdot
.34183 .35226 Mdot
.43645 .33965 Mdot
.32471 .35884 Mdot
.60844 .31989 Mdot
.70604 .548 Mdot
.33435 .5566 Mdot
.4133 .36035 Mdot
.33674 .3926 Mdot
.33262 .5539 Mdot
.56894 .67657 Mdot
.43958 .34563 Mdot
.29338 .62304 Mdot
.4892 .71913 Mdot
.69401 .61925 Mdot
.73608 .49414 Mdot
.35299 .54884 Mdot
.49778 .69866 Mdot
.56977 .6923 Mdot
.40587 .34425 Mdot
.62784 .31036 Mdot
.36049 .50703 Mdot
.71986 .51634 Mdot
.71269 .53387 Mdot
.55265 .28655 Mdot
.65864 .61719 Mdot
.60065 .29902 Mdot
.33339 .49562 Mdot
.44718 .32259 Mdot
.36026 .50861 Mdot
.64136 .29927 Mdot
.73739 .52541 Mdot
.69933 .61341 Mdot
.5305 .26845 Mdot
.27313 .63975 Mdot
.71224 .48066 Mdot
.54393 .27305 Mdot
.57252 .69186 Mdot
.6627 .62657 Mdot
.68303 .60763 Mdot
.33193 .34681 Mdot
.62275 .31413 Mdot
.66391 .64289 Mdot
.68756 .63853 Mdot
.47967 .72503 Mdot
.32416 .52892 Mdot
.5842 .68893 Mdot
.55974 .28239 Mdot
.30755 .37148 Mdot
.54491 .28108 Mdot
.45807 .35298 Mdot
.69921 .43199 Mdot
.4179 .71906 Mdot
.39642 .68909 Mdot
.29591 .42677 Mdot
.30468 .59449 Mdot
.36124 .52112 Mdot
.61392 .67024 Mdot
.32781 .33455 Mdot
.31226 .34481 Mdot
.56757 .67841 Mdot
.70037 .61853 Mdot
.33377 .35365 Mdot
.31881 .55038 Mdot
.3315 .62433 Mdot
.27302 .6415 Mdot
.61472 .68397 Mdot
.5618 .67554 Mdot
.71507 .52173 Mdot
.56914 .69628 Mdot
.5924 .28382 Mdot
.62179 .35884 Mdot
.64466 .35162 Mdot
.70502 .43113 Mdot
.35031 .55321 Mdot
.64078 .36474 Mdot
.50384 .71621 Mdot
.58689 .28325 Mdot
.49383 .70369 Mdot
.53716 .28853 Mdot
.33582 .54662 Mdot
.71703 .45953 Mdot
.69338 .4829 Mdot
.47045 .72101 Mdot
.31712 .54768 Mdot
.31331 .36777 Mdot
.61447 .66981 Mdot
.6952 .52216 Mdot
.61951 .66875 Mdot
.34148 .51318 Mdot
.59396 .68064 Mdot
.69482 .43336 Mdot
.71899 .55323 Mdot
.48151 .73094 Mdot
.49982 .7168 Mdot
.62201 .66335 Mdot
.55792 .69865 Mdot
.62606 .30938 Mdot
.58706 .67257 Mdot
.67416 .6456 Mdot
.48904 .7065 Mdot
.61126 .34582 Mdot
.36113 .67572 Mdot
.60864 .67571 Mdot
.34052 .34467 Mdot
.6662 .6255 Mdot
.33063 .35254 Mdot
.65877 .63807 Mdot
.54611 .26267 Mdot
.353 .53839 Mdot
.53456 .26998 Mdot
.33186 .38776 Mdot
.64747 .37055 Mdot
.69492 .52813 Mdot
.44274 .3227 Mdot
.70475 .5331 Mdot
.40066 .71789 Mdot
.61974 .67143 Mdot
.71247 .4907 Mdot
.35402 .67515 Mdot
.35538 .50689 Mdot
.65812 .63731 Mdot
.63474 .32192 Mdot
.53963 .28299 Mdot
.39664 .71025 Mdot
.68687 .59529 Mdot
.62854 .29747 Mdot
.52258 .70082 Mdot
.58119 .28781 Mdot
.4685 .72223 Mdot
.68376 .48793 Mdot
.59356 .70113 Mdot
.54058 .28466 Mdot
.40692 .71795 Mdot
.68799 .64264 Mdot
.62845 .36047 Mdot
.70789 .54511 Mdot
.71942 .51457 Mdot
.3487 .49821 Mdot
.70395 .47629 Mdot
.64172 .33199 Mdot
.73672 .54287 Mdot
.6657 .64267 Mdot
.73799 .52705 Mdot
.32298 .3661 Mdot
.62663 .34923 Mdot
.43219 .31463 Mdot
.51879 .69087 Mdot
.60969 .30114 Mdot
.28137 .4136 Mdot
.50903 .2756 Mdot
.61397 .2869 Mdot
.66599 .61922 Mdot
.68326 .59208 Mdot
.51609 .71147 Mdot
.39659 .70741 Mdot
.63059 .32426 Mdot
.59599 .2851 Mdot
.27811 .62835 Mdot
.44212 .32726 Mdot
.5567 .28884 Mdot
.30567 .59767 Mdot
.48566 .71566 Mdot
.69917 .42234 Mdot
.30342 .58902 Mdot
.70117 .63085 Mdot
.31945 .61234 Mdot
.69852 .52813 Mdot
.65996 .3356 Mdot
.34154 .51194 Mdot
.31203 .37356 Mdot
.71906 .53349 Mdot
.71632 .53514 Mdot
.64141 .37697 Mdot
.65874 .61644 Mdot
.60704 .65977 Mdot
.62309 .31183 Mdot
.49258 .7097 Mdot
.43706 .32331 Mdot
.30562 .6047 Mdot
.59899 .67209 Mdot
.61859 .67222 Mdot
.62702 .34985 Mdot
.31907 .56995 Mdot
.70108 .51179 Mdot
.61837 .28735 Mdot
.48415 .70273 Mdot
.6425 .35227 Mdot
.43827 .28591 Mdot
.62133 .3619 Mdot
.56245 .67929 Mdot
.45815 .32162 Mdot
.59533 .67815 Mdot
.41335 .31177 Mdot
.40072 .29525 Mdot
.3146 .37728 Mdot
.6493 .35715 Mdot
.65125 .61013 Mdot
.53061 .2715 Mdot
.34142 .54325 Mdot
.29894 .60763 Mdot
.60565 .31362 Mdot
.32883 .36972 Mdot
.28309 .34548 Mdot
.29802 .34882 Mdot
.66736 .60974 Mdot
.47504 .73026 Mdot
.51232 .27116 Mdot
.52328 .26282 Mdot
.68967 .42287 Mdot
.56987 .68239 Mdot
.4242 .30103 Mdot
.69358 .52698 Mdot
.71448 .53802 Mdot
.33488 .3656 Mdot
.5206 .26542 Mdot
.58772 .67821 Mdot
.69469 .49522 Mdot
.69011 .64198 Mdot
.32173 .63561 Mdot
.41675 .34637 Mdot
.428 .3623 Mdot
.41068 .31242 Mdot
.39993 .70139 Mdot
.70254 .48176 Mdot
.34674 .53009 Mdot
.32474 .39439 Mdot
.70316 .42885 Mdot
.30061 .36812 Mdot
.47851 .7043 Mdot
.65932 .33605 Mdot
.718 .62374 Mdot
.34593 .49665 Mdot
.3432 .5546 Mdot
.70109 .4353 Mdot
.31648 .53002 Mdot
.57512 .68706 Mdot
.6742 .64239 Mdot
.61575 .33575 Mdot
.31477 .67256 Mdot
.31758 .62889 Mdot
.30768 .62705 Mdot
.61064 .30922 Mdot
.42228 .338 Mdot
.56838 .27933 Mdot
.30472 .62671 Mdot
.71103 .52305 Mdot
.47332 .70936 Mdot
.71614 .48453 Mdot
.33024 .4992 Mdot
.34968 .54365 Mdot
.50225 .71519 Mdot
.47868 .71309 Mdot
.70505 .53284 Mdot
.4232 .34103 Mdot
.44446 .33764 Mdot
.61249 .68032 Mdot
.33194 .54469 Mdot
.2755 .63275 Mdot
.36267 .52239 Mdot
.31363 .36857 Mdot
.32402 .6784 Mdot
.41255 .72172 Mdot
.37989 .70279 Mdot
.28013 .60665 Mdot
.35637 .52605 Mdot
.6971 .43399 Mdot
.68908 .59217 Mdot
.70194 .50623 Mdot
.71977 .41373 Mdot
.63207 .30077 Mdot
.30015 .36593 Mdot
.33485 .51173 Mdot
.34388 .36973 Mdot
.28134 .65263 Mdot
.35416 .38315 Mdot
.39234 .69603 Mdot
.38771 .72082 Mdot
.33017 .34371 Mdot
.364 .52258 Mdot
.60793 .3263 Mdot
.63446 .37004 Mdot
.50584 .7094 Mdot
.33148 .4997 Mdot
.68824 .41411 Mdot
.72336 .50814 Mdot
.55965 .27238 Mdot
.57387 .2835 Mdot
.31737 .39012 Mdot
.41878 .28702 Mdot
.4836 .70921 Mdot
.34049 .50199 Mdot
.43224 .33833 Mdot
.60157 .30853 Mdot
.4165 .30821 Mdot
.55156 .26751 Mdot
.69493 .51782 Mdot
.71302 .49814 Mdot
.32664 .53415 Mdot
.26595 .38877 Mdot
.68281 .62875 Mdot
.6823 .59271 Mdot
.7245 .50925 Mdot
.65067 .36081 Mdot
.41659 .32588 Mdot
.61889 .6979 Mdot
.56947 .68704 Mdot
.33884 .38955 Mdot
.35811 .50582 Mdot
.6276 .3625 Mdot
.56563 .70249 Mdot
.32794 .39085 Mdot
.38158 .67992 Mdot
.60551 .28559 Mdot
.34313 .52402 Mdot
.50677 .69857 Mdot
.70231 .61082 Mdot
.39281 .70468 Mdot
.60835 .67474 Mdot
.71715 .52517 Mdot
.69446 .50328 Mdot
.34917 .54593 Mdot
.7131 .63586 Mdot
.59081 .65594 Mdot
.69731 .49078 Mdot
.3317 .34562 Mdot
.43697 .31646 Mdot
.30218 .37128 Mdot
.61395 .3391 Mdot
.31326 .37592 Mdot
.61365 .30035 Mdot
.54506 .27498 Mdot
.58702 .68565 Mdot
.32872 .37477 Mdot
.42457 .71468 Mdot
.43494 .31058 Mdot
.3458 .3967 Mdot
.38294 .69443 Mdot
.47837 .70154 Mdot
.6326 .33557 Mdot
.34388 .37454 Mdot
.3634 .53883 Mdot
.72816 .48493 Mdot
.70852 .40338 Mdot
.69515 .52732 Mdot
.41889 .33004 Mdot
.63257 .35062 Mdot
.59451 .67247 Mdot
.28134 .61611 Mdot
.54907 .69079 Mdot
.29371 .62639 Mdot
.33301 .53158 Mdot
.57751 .66203 Mdot
.59547 .67192 Mdot
.35149 .54546 Mdot
.30798 .59511 Mdot
.43916 .31301 Mdot
.71745 .52995 Mdot
.6673 .61547 Mdot
.67204 .61304 Mdot
.64022 .31877 Mdot
.57515 .69671 Mdot
.47725 .33283 Mdot
.69348 .5214 Mdot
.40038 .34409 Mdot
.70294 .52051 Mdot
.27531 .35574 Mdot
.61103 .28967 Mdot
.64283 .62907 Mdot
.6559 .62314 Mdot
.48811 .72579 Mdot
.58432 .68773 Mdot
.32535 .3635 Mdot
.57964 .69823 Mdot
.5925 .68841 Mdot
.33142 .54648 Mdot
.4303 .34111 Mdot
.42165 .30805 Mdot
.39901 .69895 Mdot
.68222 .62815 Mdot
.35589 .53278 Mdot
.37852 .68962 Mdot
.34027 .55156 Mdot
.39388 .70361 Mdot
.66701 .63904 Mdot
.31476 .52552 Mdot
.58327 .69283 Mdot
.68674 .65005 Mdot
.45848 .35322 Mdot
.43141 .30921 Mdot
.41906 .30293 Mdot
.69813 .39081 Mdot
.2931 .62041 Mdot
.5392 .27163 Mdot
.48956 .71083 Mdot
.44386 .32994 Mdot
.43202 .71218 Mdot
.34881 .37491 Mdot
.31066 .6139 Mdot
.43467 .33421 Mdot
.63154 .31816 Mdot
.48995 .72492 Mdot
.30188 .61545 Mdot
.41735 .33619 Mdot
.58426 .68322 Mdot
.69048 .61612 Mdot
.57385 .67689 Mdot
.33085 .35741 Mdot
.69807 .52063 Mdot
.48763 .71287 Mdot
.61299 .33462 Mdot
.53775 .26924 Mdot
.59485 .67748 Mdot
.65538 .33427 Mdot
.71767 .50275 Mdot
.30163 .61963 Mdot
.71252 .53173 Mdot
.3483 .36611 Mdot
.66839 .62106 Mdot
.49329 .71869 Mdot
.50592 .72928 Mdot
.58472 .70126 Mdot
.44374 .31411 Mdot
.29949 .35288 Mdot
.65897 .34637 Mdot
.69575 .60836 Mdot
.69646 .51859 Mdot
.64432 .32059 Mdot
.49786 .72061 Mdot
.35762 .37548 Mdot
.30866 .58394 Mdot
.32666 .5211 Mdot
.4956 .68721 Mdot
.32241 .53606 Mdot
.53444 .26659 Mdot
.61491 .67314 Mdot
.4703 .71611 Mdot
.3856 .71717 Mdot
.26614 .37393 Mdot
.29537 .36832 Mdot
.35423 .51824 Mdot
.4266 .70685 Mdot
.32218 .56394 Mdot
.65585 .60189 Mdot
.39364 .70821 Mdot
.63406 .29602 Mdot
.43001 .36202 Mdot
.7194 .41251 Mdot
.43787 .329 Mdot
.65871 .337 Mdot
.30862 .59743 Mdot
.31647 .57746 Mdot
.71002 .60678 Mdot
.47762 .70315 Mdot
.70577 .49767 Mdot
.31486 .54009 Mdot
.63717 .3226 Mdot
.52298 .27734 Mdot
.34036 .48856 Mdot
.57468 .6844 Mdot
.71742 .46966 Mdot
.4367 .33658 Mdot
.41678 .30419 Mdot
.3327 .38864 Mdot
.64719 .30906 Mdot
.45745 .30161 Mdot
.70168 .51333 Mdot
.36553 .53435 Mdot
.41351 .72141 Mdot
.73205 .48272 Mdot
.58031 .70447 Mdot
.69236 .40602 Mdot
.27386 .35798 Mdot
.34307 .53503 Mdot
.67818 .63467 Mdot
.5987 .69314 Mdot
.33504 .39323 Mdot
.54511 .26601 Mdot
.55505 .28245 Mdot
.27286 .40141 Mdot
.45263 .33116 Mdot
.60201 .30733 Mdot
.45463 .30096 Mdot
.49597 .71035 Mdot
.38755 .69636 Mdot
.7055 .40029 Mdot
.33746 .54278 Mdot
.67658 .6562 Mdot
.61018 .68257 Mdot
.35688 .51245 Mdot
.30478 .35696 Mdot
.6308 .67685 Mdot
.50428 .72481 Mdot
.36963 .5137 Mdot
.62963 .35466 Mdot
.33873 .5384 Mdot
.47882 .33315 Mdot
.40072 .34076 Mdot
.32699 .54717 Mdot
.62628 .31094 Mdot
.45813 .32032 Mdot
.30512 .35262 Mdot
.61173 .68703 Mdot
.43678 .32814 Mdot
.48318 .70245 Mdot
.30227 .60411 Mdot
.32945 .34532 Mdot
.49971 .71345 Mdot
.55845 .6773 Mdot
.4168 .30032 Mdot
.64659 .34981 Mdot
.69879 .62284 Mdot
.34638 .53947 Mdot
.43917 .31601 Mdot
.34865 .50381 Mdot
.61697 .64828 Mdot
.32868 .52004 Mdot
.71877 .55156 Mdot
.70215 .60608 Mdot
.70822 .51122 Mdot
.48665 .72331 Mdot
.34125 .52497 Mdot
.45552 .30306 Mdot
.41628 .32176 Mdot
.305 .63225 Mdot
.59686 .67713 Mdot
.59767 .68876 Mdot
.58 .67447 Mdot
.64481 .32682 Mdot
.27922 .64645 Mdot
.71267 .51262 Mdot
.42634 .3396 Mdot
.70481 .47571 Mdot
.41576 .69644 Mdot
.32741 .3566 Mdot
.73504 .50305 Mdot
.29996 .6247 Mdot
.68254 .59681 Mdot
.33251 .60801 Mdot
.67766 .58843 Mdot
.69429 .38936 Mdot
.6913 .40708 Mdot
.67914 .62288 Mdot
.35705 .51936 Mdot
.40185 .7034 Mdot
.40969 .72372 Mdot
.69998 .48721 Mdot
.43097 .34738 Mdot
.49501 .30625 Mdot
.62142 .35599 Mdot
.35664 .38007 Mdot
.70685 .43767 Mdot
.70548 .45857 Mdot
.47609 .72442 Mdot
.69533 .62142 Mdot
.6974 .50787 Mdot
.70383 .54308 Mdot
.63906 .33218 Mdot
.4827 .72559 Mdot
.34121 .51967 Mdot
.44172 .30716 Mdot
.70586 .41162 Mdot
.31177 .62898 Mdot
.47002 .70787 Mdot
.56061 .27097 Mdot
.59406 .66752 Mdot
.73704 .49311 Mdot
.40449 .68774 Mdot
.59961 .65748 Mdot
.57875 .28821 Mdot
.66463 .64267 Mdot
.35448 .53062 Mdot
.42268 .32359 Mdot
.65628 .34028 Mdot
.29529 .60823 Mdot
.5289 .26811 Mdot
.70407 .4936 Mdot
.72667 .47734 Mdot
.40655 .69268 Mdot
.58658 .28494 Mdot
.35515 .53992 Mdot
.51111 .71764 Mdot
.32045 .38289 Mdot
.69867 .49491 Mdot
.70795 .62389 Mdot
.35136 .50202 Mdot
.63374 .3099 Mdot
.61396 .35125 Mdot
.60468 .67856 Mdot
.57172 .68034 Mdot
.6479 .61654 Mdot
.43001 .31495 Mdot
.6461 .31607 Mdot
.43844 .31501 Mdot
.36998 .52044 Mdot
.69597 .4922 Mdot
.3058 .35144 Mdot
.65516 .35085 Mdot
.71078 .4319 Mdot
.479 .70136 Mdot
.6637 .61004 Mdot
.51004 .68843 Mdot
.50621 .71433 Mdot
.64842 .31228 Mdot
.31823 .35589 Mdot
.38726 .70536 Mdot
.48799 .73213 Mdot
.32892 .35002 Mdot
.64179 .32696 Mdot
.68761 .61997 Mdot
.60204 .69214 Mdot
.69399 .5944 Mdot
.4189 .71611 Mdot
.58156 .7142 Mdot
.32217 .604 Mdot
.32611 .55089 Mdot
.6533 .64022 Mdot
.28614 .60853 Mdot
.69527 .5267 Mdot
.69278 .60038 Mdot
.39332 .70405 Mdot
.4639 .71464 Mdot
.32154 .61209 Mdot
.32 .5726 Mdot
.47748 .71033 Mdot
.29302 .62044 Mdot
.56977 .66806 Mdot
.61842 .67264 Mdot
.38206 .7042 Mdot
.6922 .4952 Mdot
.31948 .36217 Mdot
.67264 .64644 Mdot
.3369 .53588 Mdot
.5702 .66651 Mdot
.38165 .69851 Mdot
.71894 .55117 Mdot
.47897 .70786 Mdot
.6595 .33364 Mdot
.30919 .58762 Mdot
.61553 .35596 Mdot
.50257 .73031 Mdot
.57085 .66511 Mdot
.70216 .40285 Mdot
.50373 .72594 Mdot
.60619 .28148 Mdot
.31446 .54063 Mdot
.42135 .32085 Mdot
.31219 .3776 Mdot
.45797 .31306 Mdot
.70376 .53423 Mdot
.29414 .61458 Mdot
.30163 .59524 Mdot
.32307 .51423 Mdot
.37004 .51968 Mdot
.433 .30947 Mdot
.34675 .34785 Mdot
.61951 .64914 Mdot
.30647 .61311 Mdot
.63968 .36646 Mdot
.68911 .63345 Mdot
.31338 .60099 Mdot
.4087 .72661 Mdot
.50932 .70127 Mdot
.68141 .62712 Mdot
.66001 .61244 Mdot
.48824 .31924 Mdot
.32219 .3752 Mdot
.34347 .54931 Mdot
.33412 .34025 Mdot
.49027 .7137 Mdot
.70453 .52688 Mdot
.32296 .51165 Mdot
.61149 .29013 Mdot
.39649 .71403 Mdot
.64316 .32837 Mdot
.33614 .5603 Mdot
.66432 .62169 Mdot
.69516 .50372 Mdot
.54862 .28576 Mdot
.55429 .2878 Mdot
.32254 .62842 Mdot
.51624 .26759 Mdot
.33618 .36055 Mdot
.33108 .36288 Mdot
.69629 .50604 Mdot
.3596 .51893 Mdot
.39182 .71132 Mdot
.45695 .73078 Mdot
.29167 .61366 Mdot
.34835 .55556 Mdot
.71253 .42698 Mdot
.70625 .43196 Mdot
.65399 .35058 Mdot
.3498 .54966 Mdot
.31418 .62369 Mdot
.67334 .6271 Mdot
.29789 .36722 Mdot
.64353 .30964 Mdot
.32536 .39119 Mdot
.61402 .31328 Mdot
.28425 .6655 Mdot
.42502 .34603 Mdot
.33054 .35977 Mdot
.70149 .44393 Mdot
.67853 .6003 Mdot
.43803 .30793 Mdot
.62724 .33613 Mdot
.65237 .32651 Mdot
.3121 .60239 Mdot
.58291 .70519 Mdot
.67159 .64256 Mdot
.33143 .35531 Mdot
.72427 .51365 Mdot
.50415 .71609 Mdot
.41144 .31079 Mdot
.27062 .36337 Mdot
.64156 .31358 Mdot
.66332 .59379 Mdot
.52265 .69314 Mdot
.33413 .52489 Mdot
.68963 .61582 Mdot
.3369 .52171 Mdot
.5866 .67326 Mdot
.68062 .64816 Mdot
.33561 .49238 Mdot
.58295 .66782 Mdot
.60331 .2983 Mdot
.52583 .28355 Mdot
.4674 .71514 Mdot
.68244 .4059 Mdot
.49132 .711 Mdot
.56918 .28235 Mdot
.33192 .60655 Mdot
.29902 .6041 Mdot
.33514 .53483 Mdot
.3693 .36712 Mdot
.28736 .59669 Mdot
.41001 .32125 Mdot
.42189 .31989 Mdot
.69002 .62205 Mdot
.45822 .30968 Mdot
.39837 .70158 Mdot
.33264 .3762 Mdot
.61671 .3369 Mdot
.3266 .62292 Mdot
.32562 .35376 Mdot
.60685 .68846 Mdot
.49111 .72945 Mdot
.65569 .64495 Mdot
.62713 .36689 Mdot
.42504 .33516 Mdot
.70409 .49542 Mdot
.36922 .6804 Mdot
.63428 .31513 Mdot
.70435 .4185 Mdot
.39632 .69162 Mdot
.66032 .33414 Mdot
.69102 .51003 Mdot
.52298 .28223 Mdot
.69775 .4172 Mdot
.72045 .49668 Mdot
.412 .71387 Mdot
.33282 .37697 Mdot
.45963 .31396 Mdot
.34081 .34143 Mdot
.69913 .40515 Mdot
.57408 .29121 Mdot
.63554 .34658 Mdot
.38323 .71371 Mdot
.58438 .7138 Mdot
.44829 .31894 Mdot
.35107 .55084 Mdot
.7005 .42773 Mdot
.2775 .65207 Mdot
.4593 .31368 Mdot
.71358 .50168 Mdot
.50398 .72955 Mdot
.32012 .67708 Mdot
.4292 .32033 Mdot
.42809 .3043 Mdot
.3414 .37654 Mdot
.55395 .27517 Mdot
.66306 .63906 Mdot
.34832 .37997 Mdot
.31927 .53202 Mdot
.33726 .54636 Mdot
.70368 .5315 Mdot
.43561 .32906 Mdot
.7161 .51119 Mdot
.30155 .36108 Mdot
.34825 .34992 Mdot
.6106 .68731 Mdot
.57717 .6783 Mdot
.44766 .29352 Mdot
.27884 .60739 Mdot
.30648 .57731 Mdot
.71046 .61423 Mdot
.66258 .63085 Mdot
.31639 .55728 Mdot
.30544 .34526 Mdot
.34136 .38042 Mdot
.50926 .72225 Mdot
.37696 .69309 Mdot
.47524 .71363 Mdot
.38955 .68332 Mdot
.66533 .3832 Mdot
.49002 .72285 Mdot
.65871 .34209 Mdot
.38762 .68224 Mdot
.69285 .4415 Mdot
.50695 .70825 Mdot
.33355 .51833 Mdot
.61743 .32018 Mdot
.33151 .55563 Mdot
.61773 .34553 Mdot
.35206 .53709 Mdot
.64321 .30078 Mdot
.6131 .3345 Mdot
.49688 .30106 Mdot
.34649 .67633 Mdot
.41128 .31883 Mdot
.3157 .34525 Mdot
.42141 .36042 Mdot
.31807 .58777 Mdot
.68453 .61825 Mdot
.58933 .71493 Mdot
.33318 .52421 Mdot
.63937 .33599 Mdot
.70727 .49121 Mdot
.51369 .7232 Mdot
.3317 .50381 Mdot
.50171 .70957 Mdot
.66346 .60994 Mdot
.62835 .35257 Mdot
.31387 .38175 Mdot
.5505 .2622 Mdot
.5658 .28232 Mdot
.60827 .28936 Mdot
.36792 .49725 Mdot
.50901 .70284 Mdot
.47915 .33268 Mdot
.60266 .66354 Mdot
.28621 .34333 Mdot
.59332 .69434 Mdot
.43951 .32594 Mdot
.33309 .38574 Mdot
.33246 .67409 Mdot
.68348 .63905 Mdot
.61044 .30993 Mdot
.34362 .52531 Mdot
.42043 .34248 Mdot
.34144 .34192 Mdot
.70009 .63121 Mdot
.3294 .34488 Mdot
.62299 .33232 Mdot
.4354 .31965 Mdot
.27764 .64741 Mdot
.31845 .50573 Mdot
.37398 .7064 Mdot
.34084 .52808 Mdot
.33246 .35354 Mdot
.58012 .70547 Mdot
.50316 .71005 Mdot
.70098 .41327 Mdot
.39715 .70669 Mdot
.34479 .55793 Mdot
.58389 .28268 Mdot
.6634 .61416 Mdot
.32335 .36786 Mdot
.69955 .42652 Mdot
.32038 .37573 Mdot
.41534 .30708 Mdot
.58275 .6774 Mdot
.41499 .30649 Mdot
.47519 .70486 Mdot
.6992 .50467 Mdot
.67414 .64215 Mdot
.56797 .27698 Mdot
.44957 .33511 Mdot
.60467 .31527 Mdot
.33187 .67711 Mdot
.60067 .67938 Mdot
.7158 .41818 Mdot
.54715 .26135 Mdot
.71361 .5499 Mdot
.3749 .70074 Mdot
.72187 .52207 Mdot
.33285 .52553 Mdot
.69768 .59628 Mdot
.71062 .47884 Mdot
.55644 .28657 Mdot
.42635 .70776 Mdot
.40567 .31945 Mdot
.36134 .51466 Mdot
.73743 .53481 Mdot
.69416 .48354 Mdot
.57901 .69215 Mdot
.70672 .43958 Mdot
.32438 .57115 Mdot
.43567 .31222 Mdot
.32863 .54084 Mdot
.69423 .40878 Mdot
.71197 .43465 Mdot
.54102 .28047 Mdot
.34689 .52759 Mdot
.31468 .37104 Mdot
.65897 .33584 Mdot
.61171 .34768 Mdot
.65325 .34403 Mdot
.59447 .6567 Mdot
.44015 .339 Mdot
.42809 .31536 Mdot
.33093 .61049 Mdot
.71845 .51379 Mdot
.41081 .32048 Mdot
.30341 .60743 Mdot
.31465 .5937 Mdot
.69619 .5971 Mdot
.6229 .32579 Mdot
.34054 .55817 Mdot
.46632 .71788 Mdot
.41566 .33222 Mdot
.62211 .31306 Mdot
.58576 .68158 Mdot
.57286 .28058 Mdot
.2983 .61692 Mdot
.47363 .71985 Mdot
.58843 .7016 Mdot
.55857 .67406 Mdot
.28513 .59879 Mdot
.33744 .5198 Mdot
.71208 .5347 Mdot
.51081 .66469 Mdot
.37422 .60235 Mdot
.44346 .49501 Mdot
.45023 .32266 Mdot
.59769 .56085 Mdot
.46792 .65022 Mdot
.46192 .7333 Mdot
.4984 .58593 Mdot
.42864 .7013 Mdot
.54355 .61612 Mdot
.6381 .42049 Mdot
.47419 .55607 Mdot
.54689 .29596 Mdot
.66633 .48821 Mdot
.52504 .71799 Mdot
.3277 .43071 Mdot
.67644 .55721 Mdot
.50908 .63054 Mdot
.66997 .49016 Mdot
.60284 .44846 Mdot
.58978 .33351 Mdot
.64468 .37911 Mdot
.60854 .40815 Mdot
.36537 .5369 Mdot
.53745 .64439 Mdot
.38668 .62267 Mdot
.64023 .59099 Mdot
.66746 .41106 Mdot
.4646 .72344 Mdot
.40488 .38849 Mdot
.61641 .56845 Mdot
.45598 .39427 Mdot
.41746 .67011 Mdot
.63053 .44464 Mdot
.38542 .6167 Mdot
.37815 .43075 Mdot
.4349 .69739 Mdot
.54937 .58596 Mdot
.5985 .58998 Mdot
.42742 .64732 Mdot
.62539 .55286 Mdot
.62678 .30132 Mdot
.57354 .70592 Mdot
.67346 .51957 Mdot
.46552 .37666 Mdot
.64452 .54437 Mdot
.49767 .58697 Mdot
.44812 .29624 Mdot
.59903 .55367 Mdot
.2885 .64856 Mdot
.67876 .58456 Mdot
.64829 .46816 Mdot
.66399 .42006 Mdot
.43804 .65638 Mdot
.67056 .44178 Mdot
.33576 .66393 Mdot
.51326 .63251 Mdot
.474 .65325 Mdot
.60563 .44423 Mdot
.55127 .34951 Mdot
.65972 .62219 Mdot
.33859 .44065 Mdot
.56034 .42951 Mdot
.40821 .48741 Mdot
.65328 .48737 Mdot
.43975 .6822 Mdot
.6289 .6553 Mdot
.70406 .59133 Mdot
.59581 .36162 Mdot
.48235 .35409 Mdot
.61779 .40546 Mdot
.56961 .43093 Mdot
.64656 .53447 Mdot
.3575 .62646 Mdot
.58233 .60743 Mdot
.58296 .37246 Mdot
.52153 .68043 Mdot
.36811 .39177 Mdot
.5511 .51512 Mdot
.43633 .36886 Mdot
.4542 .65988 Mdot
.61351 .45289 Mdot
.44832 .58766 Mdot
.61134 .52636 Mdot
.32109 .65321 Mdot
.45237 .3677 Mdot
.54 .64282 Mdot
.55828 .37719 Mdot
.67118 .56091 Mdot
.48046 .66954 Mdot
.6632 .44212 Mdot
.39579 .34074 Mdot
.44696 .43066 Mdot
.40787 .37611 Mdot
.50675 .57907 Mdot
.37842 .41495 Mdot
.63065 .44199 Mdot
.67882 .49124 Mdot
.60039 .32497 Mdot
.6231 .61458 Mdot
.47867 .37975 Mdot
.67958 .65364 Mdot
.57935 .31473 Mdot
.48829 .6128 Mdot
.61165 .62541 Mdot
.40426 .37831 Mdot
.60467 .37258 Mdot
.59973 .51626 Mdot
.59876 .4212 Mdot
.59635 .58549 Mdot
.57078 .61296 Mdot
.68136 .56229 Mdot
.42995 .28647 Mdot
.5677 .65455 Mdot
.44247 .39731 Mdot
.63084 .39178 Mdot
.34159 .41336 Mdot
.28075 .62369 Mdot
.47016 .40119 Mdot
.4673 .68884 Mdot
.50661 .48096 Mdot
.65841 .57867 Mdot
.41935 .37087 Mdot
.46149 .72197 Mdot
.52481 .67354 Mdot
.60725 .40538 Mdot
.37387 .48044 Mdot
.66765 .58328 Mdot
.67293 .48687 Mdot
.61009 .35965 Mdot
.46615 .66681 Mdot
.47793 .33921 Mdot
.35752 .57092 Mdot
.40487 .45489 Mdot
.66958 .38751 Mdot
.40045 .48024 Mdot
.43414 .45436 Mdot
.51469 .29628 Mdot
.62086 .63029 Mdot
.43282 .43757 Mdot
.4823 .68642 Mdot
.57677 .36622 Mdot
.63216 .41537 Mdot
.52681 .65825 Mdot
.2852 .38432 Mdot
.39837 .40533 Mdot
.45498 .46008 Mdot
.6013 .53824 Mdot
.46492 .73884 Mdot
.39916 .59736 Mdot
.62659 .43362 Mdot
.51491 .41069 Mdot
.53673 .35912 Mdot
.67316 .47876 Mdot
.68526 .65314 Mdot
.49847 .39077 Mdot
.42955 .5803 Mdot
.53932 .68765 Mdot
.50074 .43089 Mdot
.64866 .59827 Mdot
.48538 .42096 Mdot
.40332 .3854 Mdot
.63521 .37837 Mdot
.59298 .38055 Mdot
.65106 .53474 Mdot
.66633 .42407 Mdot
.57613 .62895 Mdot
.58341 .62838 Mdot
.50659 .36855 Mdot
.67235 .55032 Mdot
.62227 .47076 Mdot
.69819 .58614 Mdot
.51409 .61722 Mdot
.41297 .64471 Mdot
.37382 .58978 Mdot
.44578 .54244 Mdot
.30808 .34179 Mdot
.37788 .43787 Mdot
.46741 .6692 Mdot
.27687 .36775 Mdot
.39567 .52578 Mdot
.38115 .61458 Mdot
.40897 .30784 Mdot
.36187 .58439 Mdot
.3037 .66126 Mdot
.57288 .53401 Mdot
.59994 .38012 Mdot
.45684 .47891 Mdot
.36812 .57343 Mdot
.64972 .58313 Mdot
.43095 .69607 Mdot
.42071 .3717 Mdot
.50497 .32951 Mdot
.49755 .64788 Mdot
.54617 .65868 Mdot
.68021 .41812 Mdot
.70546 .46518 Mdot
.52634 .29792 Mdot
.65157 .53384 Mdot
.62891 .66423 Mdot
.53718 .26345 Mdot
.60761 .48204 Mdot
.44143 .59904 Mdot
.37646 .6459 Mdot
.44176 .37845 Mdot
.57978 .54999 Mdot
.33946 .40175 Mdot
.45851 .62458 Mdot
.43875 .47345 Mdot
.39086 .40045 Mdot
.36077 .4136 Mdot
.35341 .42628 Mdot
.67322 .52892 Mdot
.37032 .44061 Mdot
.39151 .37783 Mdot
.28502 .65487 Mdot
.56601 .46818 Mdot
.48233 .73911 Mdot
.40838 .55411 Mdot
.57286 .32088 Mdot
.56081 .41808 Mdot
.56852 .60723 Mdot
.43831 .65733 Mdot
.38342 .36504 Mdot
.30228 .65952 Mdot
.62349 .53484 Mdot
.43764 .40359 Mdot
.56798 .38895 Mdot
.46616 .39727 Mdot
.51741 .36029 Mdot
.52635 .58098 Mdot
.67235 .4893 Mdot
.26889 .38904 Mdot
.55712 .34604 Mdot
.63477 .57704 Mdot
.49917 .67937 Mdot
.57718 .32047 Mdot
.59803 .63533 Mdot
.60887 .60627 Mdot
.45231 .64628 Mdot
.41035 .59153 Mdot
.47028 .51393 Mdot
.55582 .58744 Mdot
.39165 .44086 Mdot
.54336 .39446 Mdot
.63678 .37707 Mdot
.53046 .31143 Mdot
.46675 .49906 Mdot
.56045 .46298 Mdot
.37615 .55337 Mdot
.59837 .35832 Mdot
.54581 .55483 Mdot
.37 .60697 Mdot
.45585 .47542 Mdot
.51183 .64131 Mdot
.64078 .61829 Mdot
.42116 .58548 Mdot
.28708 .62506 Mdot
.46441 .37295 Mdot
.52503 .29257 Mdot
.51277 .35554 Mdot
.5388 .65119 Mdot
.6817 .45167 Mdot
.65675 .51424 Mdot
.38721 .52598 Mdot
.36447 .64104 Mdot
.51362 .54654 Mdot
.3756 .66392 Mdot
.72811 .51903 Mdot
.63376 .65558 Mdot
.56266 .63431 Mdot
.35123 .55857 Mdot
.45183 .55757 Mdot
.54877 .63045 Mdot
.39439 .49983 Mdot
.47389 .68525 Mdot
.619 .64727 Mdot
.56562 .35238 Mdot
.64039 .37785 Mdot
.29668 .39755 Mdot
.55643 .43947 Mdot
.31994 .39354 Mdot
.5214 .32352 Mdot
.59657 .52945 Mdot
.41793 .66592 Mdot
.67743 .43055 Mdot
.52814 .37037 Mdot
.56251 .29655 Mdot
.51906 .35841 Mdot
.62826 .41051 Mdot
.65195 .49451 Mdot
.3485 .6023 Mdot
.62243 .58009 Mdot
.672 .46924 Mdot
.34001 .62148 Mdot
.6455 .40008 Mdot
.61059 .54238 Mdot
.68488 .58035 Mdot
.29077 .63875 Mdot
.33333 .61185 Mdot
.36088 .44284 Mdot
.3522 .61847 Mdot
.43361 .49846 Mdot
.60214 .70682 Mdot
.3442 .4585 Mdot
.62824 .53591 Mdot
.48885 .73686 Mdot
.54254 .6629 Mdot
.67032 .57805 Mdot
.49253 .68044 Mdot
.57815 .30065 Mdot
.68855 .45747 Mdot
.55575 .62592 Mdot
.39159 .52841 Mdot
.40599 .41075 Mdot
.3855 .50918 Mdot
.55605 .65515 Mdot
.41973 .55956 Mdot
.63934 .61628 Mdot
.44326 .65679 Mdot
.56631 .49955 Mdot
.62418 .61944 Mdot
.46736 .61642 Mdot
.47393 .68085 Mdot
.53247 .70588 Mdot
.49631 .35128 Mdot
.35451 .46065 Mdot
.5417 .59367 Mdot
.32226 .55498 Mdot
.49413 .4796 Mdot
.49564 .61366 Mdot
.37109 .54164 Mdot
.52457 .60398 Mdot
.33044 .45242 Mdot
.71298 .61376 Mdot
.57997 .58325 Mdot
.52503 .40379 Mdot
.37253 .52096 Mdot
.41581 .6682 Mdot
.48222 .66763 Mdot
.67242 .48228 Mdot
.35105 .46019 Mdot
.48509 .34934 Mdot
.54458 .49684 Mdot
.37018 .56728 Mdot
.46186 .4464 Mdot
.36148 .45187 Mdot
.41909 .29203 Mdot
.51324 .36301 Mdot
.6016 .56037 Mdot
.31874 .43728 Mdot
.65804 .39675 Mdot
.44322 .53331 Mdot
.4475 .5932 Mdot
.56493 .34779 Mdot
.46386 .5949 Mdot
.47664 .57727 Mdot
.46853 .4753 Mdot
.57571 .34108 Mdot
.57539 .56585 Mdot
.61843 .54525 Mdot
.61408 .64705 Mdot
.38618 .38944 Mdot
.55701 .61018 Mdot
.60838 .61088 Mdot
.53767 .4024 Mdot
.32965 .5114 Mdot
.43937 .54635 Mdot
.6607 .59292 Mdot
.51025 .44703 Mdot
.57107 .62067 Mdot
.53454 .29305 Mdot
.58619 .54478 Mdot
.45904 .4877 Mdot
.32137 .43247 Mdot
.31021 .43154 Mdot
.42229 .61663 Mdot
.39397 .36529 Mdot
.62884 .5333 Mdot
.5673 .64638 Mdot
.62553 .55923 Mdot
.3557 .65115 Mdot
.70626 .63597 Mdot
.49488 .3338 Mdot
.67958 .40547 Mdot
.64983 .58059 Mdot
.447 .62423 Mdot
.4678 .349 Mdot
.55732 .47249 Mdot
.61644 .48424 Mdot
.68057 .45855 Mdot
.61664 .37531 Mdot
.59628 .37177 Mdot
.42929 .54179 Mdot
.64883 .44308 Mdot
.55461 .35043 Mdot
.6038 .63107 Mdot
.5658 .301 Mdot
.55434 .36039 Mdot
.45449 .7009 Mdot
.58209 .37221 Mdot
.58001 .65275 Mdot
.66193 .43859 Mdot
.49333 .60925 Mdot
.59349 .53666 Mdot
.51287 .42826 Mdot
.57108 .64956 Mdot
.66949 .52528 Mdot
.5785 .49538 Mdot
.3269 .66837 Mdot
.48795 .67362 Mdot
.52794 .67927 Mdot
.39113 .62591 Mdot
.59438 .51243 Mdot
.32867 .44574 Mdot
.69272 .39637 Mdot
.34392 .64371 Mdot
.6818 .5824 Mdot
.28775 .65683 Mdot
.62062 .47447 Mdot
.39446 .68083 Mdot
.49571 .355 Mdot
.62358 .4742 Mdot
.34737 .42593 Mdot
.51782 .27388 Mdot
.34653 .45205 Mdot
.58177 .60036 Mdot
.52067 .32436 Mdot
.56935 .32104 Mdot
.55001 .30946 Mdot
.35065 .41566 Mdot
.54504 .33632 Mdot
.33569 .63523 Mdot
.57954 .50899 Mdot
.36026 .62918 Mdot
.3776 .49017 Mdot
.55532 .3357 Mdot
.62256 .68927 Mdot
.41461 .41489 Mdot
.47871 .63321 Mdot
.64328 .39004 Mdot
.35465 .45 Mdot
.31916 .63873 Mdot
.49543 .44961 Mdot
.60897 .43242 Mdot
.5991 .30351 Mdot
.33363 .41281 Mdot
.53171 .65911 Mdot
.50471 .38566 Mdot
.52492 .67119 Mdot
.50731 .68489 Mdot
.6427 .42391 Mdot
.47188 .6432 Mdot
.26949 .38585 Mdot
.64211 .48258 Mdot
.49455 .31524 Mdot
.61125 .53374 Mdot
.69919 .56719 Mdot
.37464 .47754 Mdot
.50404 .36572 Mdot
.50761 .38922 Mdot
.34038 .42372 Mdot
.42042 .41636 Mdot
.42066 .42327 Mdot
.3284 .45056 Mdot
.49789 .64041 Mdot
.3507 .63358 Mdot
.39102 .39718 Mdot
.42193 .64475 Mdot
.48242 .35544 Mdot
.71095 .54585 Mdot
.60272 .45422 Mdot
.63751 .64005 Mdot
.35945 .60146 Mdot
.35688 .61453 Mdot
.53443 .3702 Mdot
.669 .5639 Mdot
.45737 .51598 Mdot
.45676 .46248 Mdot
.66536 .43328 Mdot
.35462 .65866 Mdot
.52861 .59092 Mdot
.33016 .41917 Mdot
.28633 .62652 Mdot
.3892 .31238 Mdot
.59615 .38088 Mdot
.62076 .58072 Mdot
.5884 .5229 Mdot
.63438 .64263 Mdot
.42984 .50626 Mdot
.33976 .57632 Mdot
.39082 .38919 Mdot
.58769 .52146 Mdot
.37558 .62039 Mdot
.37434 .46502 Mdot
.60525 .61522 Mdot
.65659 .55357 Mdot
.50644 .58882 Mdot
.58846 .44896 Mdot
.27859 .63966 Mdot
.61352 .40408 Mdot
.53501 .29235 Mdot
.33072 .44267 Mdot
.65838 .54654 Mdot
.35701 .60406 Mdot
.4427 .44471 Mdot
.57334 .409 Mdot
.32307 .42336 Mdot
.59976 .35644 Mdot
.46741 .66995 Mdot
.64152 .40001 Mdot
.6615 .5622 Mdot
.61374 .47849 Mdot
.34844 .61882 Mdot
.33861 .4418 Mdot
.4397 .61153 Mdot
.55881 .51805 Mdot
.47675 .44067 Mdot
.37554 .67361 Mdot
.54107 .64021 Mdot
.41041 .59581 Mdot
.685 .54322 Mdot
.33742 .42756 Mdot
.61263 .41867 Mdot
.36871 .45468 Mdot
.33082 .42982 Mdot
.61844 .68781 Mdot
.56509 .63625 Mdot
.67741 .49903 Mdot
.37219 .56983 Mdot
.5977 .30024 Mdot
.30717 .63724 Mdot
.31868 .66461 Mdot
.46903 .61018 Mdot
.50208 .39907 Mdot
.27137 .38422 Mdot
.48087 .6779 Mdot
.60298 .40731 Mdot
.48405 .68289 Mdot
.55253 .30034 Mdot
.52424 .57639 Mdot
.46751 .65414 Mdot
.42432 .50598 Mdot
.64866 .49853 Mdot
.50209 .63966 Mdot
.45394 .39576 Mdot
.41144 .54447 Mdot
.45912 .6494 Mdot
.45974 .65629 Mdot
.43587 .5926 Mdot
.63086 .60136 Mdot
.43618 .39697 Mdot
.61501 .38378 Mdot
.27285 .36898 Mdot
.42034 .64696 Mdot
.36062 .61404 Mdot
.59782 .53591 Mdot
.47382 .39244 Mdot
.52361 .26889 Mdot
.28218 .40165 Mdot
.39252 .65644 Mdot
.64384 .61279 Mdot
.52188 .53873 Mdot
.36569 .63231 Mdot
.35525 .63565 Mdot
.65986 .48325 Mdot
.59698 .52039 Mdot
.4484 .4976 Mdot
.58594 .71092 Mdot
.72929 .4957 Mdot
.31936 .33883 Mdot
.27653 .37067 Mdot
.64195 .55894 Mdot
.41294 .61262 Mdot
.57992 .36269 Mdot
.68948 .57344 Mdot
.28705 .37782 Mdot
.63216 .51062 Mdot
.34497 .56275 Mdot
.39815 .57838 Mdot
.27554 .39816 Mdot
.37684 .42641 Mdot
.60916 .69663 Mdot
.5801 .63519 Mdot
.65094 .46254 Mdot
.5263 .37327 Mdot
.56316 .53892 Mdot
.55013 .33181 Mdot
.45489 .42448 Mdot
.50793 .37713 Mdot
.46329 .63971 Mdot
.49848 .57044 Mdot
.62305 .39921 Mdot
.51941 .32755 Mdot
.62921 .38869 Mdot
.4208 .47502 Mdot
.56629 .43243 Mdot
.64899 .3827 Mdot
.49997 .44203 Mdot
.63676 .52374 Mdot
.4782 .73712 Mdot
.51112 .55156 Mdot
.57309 .33671 Mdot
.57789 .70985 Mdot
.59418 .43307 Mdot
.49072 .65192 Mdot
.648 .5796 Mdot
.43792 .39953 Mdot
.56208 .64235 Mdot
.61958 .38962 Mdot
.36168 .61854 Mdot
.55913 .39175 Mdot
.41012 .66111 Mdot
.40063 .47676 Mdot
.43831 .29579 Mdot
.40095 .45139 Mdot
.39591 .32167 Mdot
.32313 .64271 Mdot
.39705 .5117 Mdot
.45135 .37221 Mdot
.32101 .64941 Mdot
.51752 .42903 Mdot
.61689 .45372 Mdot
.69588 .58299 Mdot
.41656 .37345 Mdot
.34665 .57426 Mdot
.57731 .64898 Mdot
.59464 .37187 Mdot
.39461 .31108 Mdot
.32816 .43176 Mdot
.66515 .56356 Mdot
.53393 .42786 Mdot
.5534 .29563 Mdot
.54934 .49741 Mdot
.53 .32263 Mdot
.61105 .53373 Mdot
.5316 .694 Mdot
.40193 .38246 Mdot
.62225 .46179 Mdot
.5117 .43248 Mdot
.36949 .61244 Mdot
.44425 .65484 Mdot
.33735 .59827 Mdot
.37446 .57979 Mdot
.62651 .30064 Mdot
.38129 .60412 Mdot
.63278 .43827 Mdot
.42619 .61871 Mdot
.57981 .3651 Mdot
.52266 .3098 Mdot
.56717 .41727 Mdot
.6729 .44573 Mdot
.32334 .43846 Mdot
.42199 .421 Mdot
.4966 .73833 Mdot
.47778 .68302 Mdot
.27656 .3913 Mdot
.54702 .3369 Mdot
.3524 .45861 Mdot
.39313 .59928 Mdot
.45057 .4284 Mdot
.49775 .33971 Mdot
.50556 .46795 Mdot
.69397 .39493 Mdot
.42345 .6357 Mdot
.57117 .65207 Mdot
.49885 .65907 Mdot
.68607 .54728 Mdot
.57021 .33409 Mdot
.55504 .62567 Mdot
.49747 .58148 Mdot
.50171 .42379 Mdot
.50421 .29752 Mdot
.64537 .56784 Mdot
.72267 .54161 Mdot
.42135 .67027 Mdot
.33243 .43825 Mdot
.51455 .68332 Mdot
.49679 .60611 Mdot
.5487 .57524 Mdot
.37615 .50203 Mdot
.68475 .56049 Mdot
.55411 .64127 Mdot
.45706 .67775 Mdot
.35284 .43389 Mdot
.56084 .593 Mdot
.51495 .3209 Mdot
.6508 .40985 Mdot
.53518 .57474 Mdot
.53646 .31763 Mdot
.70509 .59042 Mdot
.3548 .42705 Mdot
.375 .56025 Mdot
.40652 .29993 Mdot
.29639 .63695 Mdot
.46225 .62171 Mdot
.5139 .36106 Mdot
.56121 .53784 Mdot
.67377 .57647 Mdot
.48315 .66089 Mdot
.58624 .33892 Mdot
.29981 .3846 Mdot
.67504 .42075 Mdot
.61211 .44095 Mdot
.38242 .61601 Mdot
.37716 .62699 Mdot
.6172 .59913 Mdot
.60227 .54055 Mdot
.46564 .57884 Mdot
.58567 .4473 Mdot
.41101 .63701 Mdot
.50645 .326 Mdot
.32631 .41732 Mdot
.4526 .69013 Mdot
.56664 .29344 Mdot
.42937 .67464 Mdot
.44094 .67637 Mdot
.59905 .40747 Mdot
.57855 .59292 Mdot
.52822 .41616 Mdot
.52197 .39916 Mdot
.66831 .65203 Mdot
.29544 .4167 Mdot
.57058 .62183 Mdot
.58679 .4318 Mdot
.65766 .45934 Mdot
.50315 .61922 Mdot
.59171 .29166 Mdot
.66325 .50811 Mdot
.58212 .32582 Mdot
.58248 .3719 Mdot
.66434 .49277 Mdot
.62208 .53954 Mdot
.62054 .62186 Mdot
.38776 .40301 Mdot
.61785 .45049 Mdot
.45994 .39094 Mdot
.67974 .54146 Mdot
.42753 .57075 Mdot
.31086 .65859 Mdot
.35689 .57034 Mdot
.41422 .51582 Mdot
.41256 .44287 Mdot
.35148 .43954 Mdot
.39977 .33122 Mdot
.27607 .37231 Mdot
.65957 .44564 Mdot
.31101 .42388 Mdot
.50307 .63567 Mdot
.44396 .29421 Mdot
.5382 .39609 Mdot
.55926 .59233 Mdot
.342 .6455 Mdot
.46332 .47024 Mdot
.53716 .34267 Mdot
.61023 .6159 Mdot
.51146 .65947 Mdot
.49026 .34621 Mdot
.29651 .63514 Mdot
.41818 .69173 Mdot
.66484 .57584 Mdot
.59624 .3054 Mdot
.49289 .66213 Mdot
.33946 .40815 Mdot
.7278 .50536 Mdot
.6743 .42538 Mdot
.62018 .59398 Mdot
.51057 .38242 Mdot
.68348 .48035 Mdot
.64583 .59553 Mdot
.51829 .27933 Mdot
.7323 .51885 Mdot
.38552 .44838 Mdot
.53785 .68018 Mdot
.32265 .64384 Mdot
.41562 .45742 Mdot
.43005 .28703 Mdot
.48674 .3632 Mdot
.35327 .64366 Mdot
.60021 .44532 Mdot
.33944 .45029 Mdot
.63052 .40018 Mdot
.65352 .40231 Mdot
.67784 .56792 Mdot
.44745 .63703 Mdot
.68579 .44589 Mdot
.65643 .47109 Mdot
.40419 .66642 Mdot
.34495 .45235 Mdot
.4027 .43771 Mdot
.55998 .53205 Mdot
.45161 .45555 Mdot
.41066 .3899 Mdot
.55439 .32397 Mdot
.59561 .32138 Mdot
.61181 .35417 Mdot
.36838 .55285 Mdot
.56291 .41004 Mdot
.45996 .5297 Mdot
.36156 .43959 Mdot
.65289 .49725 Mdot
.62187 .45998 Mdot
.61363 .39261 Mdot
.46225 .62202 Mdot
.28053 .62564 Mdot
.34049 .42841 Mdot
.40865 .56224 Mdot
.58604 .32536 Mdot
.67376 .53263 Mdot
.66079 .44554 Mdot
.31992 .4232 Mdot
.45917 .57706 Mdot
.40297 .51938 Mdot
.31783 .43968 Mdot
.44413 .36587 Mdot
.61744 .6216 Mdot
.36141 .48239 Mdot
.51349 .27214 Mdot
.66752 .46978 Mdot
.53128 .38078 Mdot
.63632 .65603 Mdot
.66238 .39447 Mdot
.38329 .57847 Mdot
.34783 .46112 Mdot
.59009 .44167 Mdot
.61723 .68584 Mdot
.45124 .64438 Mdot
.62136 .43602 Mdot
.64658 .40181 Mdot
.40548 .63349 Mdot
.71293 .6126 Mdot
.42856 .48909 Mdot
.57169 .7064 Mdot
.49168 .36416 Mdot
.31576 .41526 Mdot
.43514 .68759 Mdot
.36808 .41816 Mdot
.41619 .69173 Mdot
.48206 .62103 Mdot
.42473 .67481 Mdot
.35134 .6001 Mdot
.62564 .43427 Mdot
.31516 .427 Mdot
.4158 .62226 Mdot
.31923 .41621 Mdot
.49077 .32578 Mdot
.6042 .69735 Mdot
.43184 .5902 Mdot
.36596 .59416 Mdot
.54792 .61216 Mdot
.58738 .59963 Mdot
.66626 .43429 Mdot
.52807 .32003 Mdot
.63377 .48598 Mdot
.28981 .61847 Mdot
.44304 .4581 Mdot
.4996 .37157 Mdot
.61394 .47687 Mdot
.49575 .37173 Mdot
.42391 .46839 Mdot
.29359 .64311 Mdot
.31236 .43741 Mdot
.56529 .64839 Mdot
.39147 .55252 Mdot
.28119 .36094 Mdot
.44491 .29456 Mdot
.41715 .6956 Mdot
.72764 .51722 Mdot
.36985 .53525 Mdot
.66272 .40322 Mdot
.48327 .36832 Mdot
.42824 .67151 Mdot
.36026 .60942 Mdot
.67125 .42093 Mdot
.28207 .64063 Mdot
.36813 .60936 Mdot
.71721 .54275 Mdot
.65287 .43301 Mdot
.58055 .29164 Mdot
.64632 .58451 Mdot
.52124 .63383 Mdot
.32491 .67205 Mdot
.42989 .29039 Mdot
.63521 .43051 Mdot
.61519 .59866 Mdot
.66687 .57337 Mdot
.6216 .39054 Mdot
.41949 .42556 Mdot
.66284 .55523 Mdot
.51537 .31238 Mdot
.35035 .62994 Mdot
.44295 .45028 Mdot
.57456 .61238 Mdot
.41696 .57448 Mdot
.41427 .39541 Mdot
.31039 .39755 Mdot
.40423 .31517 Mdot
.42036 .54343 Mdot
.44861 .37651 Mdot
.7231 .49569 Mdot
.51509 .28886 Mdot
.58065 .58878 Mdot
.48764 .65083 Mdot
.41968 .52421 Mdot
.58432 .52876 Mdot
.46886 .72956 Mdot
.3628 .48213 Mdot
.40045 .47353 Mdot
.67708 .44021 Mdot
.59196 .52569 Mdot
.513 .62627 Mdot
.52879 .61474 Mdot
.40115 .42334 Mdot
.47837 .73284 Mdot
.3336 .56415 Mdot
.39942 .32045 Mdot
.30933 .66487 Mdot
.42623 .28747 Mdot
.54406 .41021 Mdot
.67569 .46831 Mdot
.64028 .43223 Mdot
.65772 .39807 Mdot
.45301 .4113 Mdot
.40942 .38686 Mdot
.46895 .73587 Mdot
.37087 .43083 Mdot
.48354 .46584 Mdot
.66739 .52969 Mdot
.4037 .57551 Mdot
.3252 .42467 Mdot
.43455 .46101 Mdot
.41818 .36271 Mdot
.50109 .32582 Mdot
.47759 .38731 Mdot
.65752 .51159 Mdot
.63123 .64591 Mdot
.66081 .44074 Mdot
.38835 .52249 Mdot
.5123 .66397 Mdot
.29712 .39938 Mdot
.52931 .36436 Mdot
.59006 .46918 Mdot
.57879 .60685 Mdot
.4087 .60422 Mdot
.37083 .49285 Mdot
.61464 .29517 Mdot
.41979 .55975 Mdot
.41714 .44123 Mdot
.34888 .44255 Mdot
.50235 .7366 Mdot
.50647 .52194 Mdot
.42876 .45463 Mdot
.3426 .42263 Mdot
.61491 .29191 Mdot
.37436 .62184 Mdot
.42945 .69133 Mdot
.67831 .46895 Mdot
.40105 .30342 Mdot
.32945 .44337 Mdot
.67264 .46644 Mdot
.58518 .44625 Mdot
.73434 .5258 Mdot
.43417 .44824 Mdot
.46013 .68281 Mdot
.63506 .57351 Mdot
.38307 .34727 Mdot
.46473 .4409 Mdot
.28836 .41867 Mdot
.51483 .37097 Mdot
.52507 .4174 Mdot
.41415 .67393 Mdot
.6073 .38891 Mdot
.37627 .65367 Mdot
.66818 .55187 Mdot
.49631 .35688 Mdot
.67095 .38764 Mdot
.53384 .29019 Mdot
.53818 .58377 Mdot
.70307 .58689 Mdot
.55962 .40945 Mdot
.52229 .66526 Mdot
.58761 .50581 Mdot
.71375 .61649 Mdot
.5406 .66309 Mdot
.37821 .4307 Mdot
.56813 .56469 Mdot
.66049 .64736 Mdot
.41991 .62921 Mdot
.52609 .54763 Mdot
.58763 .58325 Mdot
.49765 .60552 Mdot
.50395 .58138 Mdot
.64242 .57519 Mdot
.51759 .52931 Mdot
.57294 .64467 Mdot
.63206 .55667 Mdot
.40659 .46046 Mdot
.61617 .42867 Mdot
.47034 .4026 Mdot
.53634 .26277 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0?ooooooB_ooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A006ooooo`03o`000?oooooooooo0?ooooooB_ooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0?ooooooB_oo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06
ooooo`?o0000oooooom:ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<oooo
o`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom:ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001_ooool00ol0003oooooooooo`3ooooood[ooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0Z?ooool8o`0009Wooooo
000Looooo`03o`000?oooooooooo0:Gooooo3Ol0002Gooooo`007?ooool00ol0003oooooooooo`2T
ooooo`oo0000U_ooool001cooooo00?o0000ooooooooool0XooooolBo`0009Cooooo000Looooo`03
o`000?oooooooooo0:;ooooo5?l0002Cooooo`007?ooool00ol0003oooooooooo`2RoooooaGo0000
T_ooool001cooooo00?o0000ooooooooool0X_ooool2o`000003ooooool0003o0000013o000000?o
ooooo`000?l00000Soooool001cooooo00?o0000ooooooooool0YOoooolGo`0000?ooooo1?l00026
ooooo`007?ooool00ol0003oooooooooo`26ooooo`?o00000_ooool2o`0001Wooooo8Ol00022oooo
o`007?ooool00ol0003oooooooooo`23ooooo`_o00004_ooool2o`0000;ooooo0_l000000ooooooo
0000o`00000Oo`00087ooooo000Looooo`03o`000?oooooooooo083ooooo0_l000001Ooooooo0000
o`000?l0003ooooo00Wo00003oooool3o`0000;ooooo0_l00003oooooaoo000000Coooooo`000?l0
003o0000OOooool001cooooo00?o0000ooooooooool0O_ooool4o`0000;ooooo0_l00002ooooo`?o
000000?oooooo`000?l000000_l0000?ooooo`;o00001_ooool2o`000003ooooool0003o000000?o
oooo3?l000000ooooooo0000o`000004ooooo`[o0000OOooool001cooooo00?o0000ooooooooool0
O_ooool2o`0000Oooooo2Ol0000?ooooo`?o000000?oooooo`000?l000000_ooool2o`000003oooo
ool0003o000000;ooooo1?l000001?oooooo0000o`000?l0000:ooooo`Ko00000_ooool5o`0007co
oooo000Looooo`;o0000O_ooool5o`0000;ooooo3ol0000;ooooo`Co000000?oooooo`000?l00000
0_ooool2o`0000Gooooo1?l000001?oooooo0000o`000?l00002ooooo`;o00001?oooolAo`0007[o
oooo000Looooo`03o`000?oooooooooo07gooooo1Ol000000ooooooo0000o`000009o`000003oooo
ool0003o000000;o00002oooool2o`00013ooooo0_l00002ooooo`;o00000_ooool2o`0000Cooooo
4_l0001iooooo`007?ooool00ol0003oooooooooo`1moooooaKo00002_ooool2o`0001oooooo4ol0
001hooooo`007?ooool00ol0003oooooooooo`21oooooa;o00002Oooool3o`0000Oooooo0_l00007
ooooo`;o00003OoooolCo`0007Sooooo000Looooo`03o`000?oooooooooo07_ooooo0ol00002oooo
oaCo00002?ooool2o`0000Kooooo1?l000000ooooooo0000o`000004ooooo`;o00003_oooolBo`00
07Sooooo000Looooo`03o`000?oooooooooo07_ooooo0ol00002oooooaCo00001oooool4o`0000Go
oooo0_l00003ooooo`;o00003Oooool2o`0000Oooooo4?l0001hooooo`007?ooool00ol0003ooooo
ooooo`1ooooooaGo00001_ooool5o`0000Wooooo1?l0000<ooooo`;o00001_oooolAo`0007Sooooo
000Looooo`03o`000?oooooooooo07gooooo5ol00006ooooo`?o00001oooool2o`0000;ooooo1?l0
0009ooooo`Go00001?oooolFo`0007Gooooo000Looooo`03o`000?oooooooooo07gooooo5_l00007
ooooo`Co000000?oooooo`000?l000000_l000000ooooooo0000o`000004o`0000Kooooo0_l00003
ooooo`So000000?oooooo`000?l000005?l0001eooooo`007?ooool00ol0003oooooooooo`1ooooo
oa?o00001oooool5o`000003ooooool0003o000000;o00000_ooool3o`0000Sooooo0_l00007oooo
o`Co00000_oooolFo`0007Cooooo000Looooo`03o`000?oooooooooo07kooooo4ol000000ooooooo
0000o`000004ooooo`?o00001Oooool2o`0000?ooooo0_l00008ooooo`;o00003ooooolEo`0007Co
oooo000Looooo`03o`000?oooooooooo05oooooo0_l000000ooooooo0000o`000002o`000003oooo
ool0003o000001Gooooo5_l00003ooooo`Co00000_ooool2o`000003ooooool0003o000000gooooo
0_l00004ooooo`;o00001Oooool2o`0000?ooooo5?l0001dooooo`007?ooool00ol0003ooooooooo
o`1Nooooo`?o000000?oooooo`000?l000001ol0000CoooooaKo00000oooool3o`0000?ooooo0_l0
000>ooooo`?o000000?oooooo`000?l000000_ooool3o`0000Cooooo0_l00003oooooaCo0000M?oo
ool001cooooo00?o0000ooooooooool0G?ooool5o`000003ooooool0003o000000Wo00004?oooolF
o`0000?ooooo0ol00005ooooo`;o00003Oooool3o`000003ooooool0003o000000?ooooo0ol00002
ooooo`;o00001?oooolDo`0007Cooooo000Looooo`03o`000?oooooooooo05Wooooo1Ol00002oooo
o`ko00003ooooolAo`000003ooooool0003o000000Gooooo0ol00005ooooo`;o00002oooool2o`00
00[ooooo0_l00002ooooo`;o00001OoooolBo`0007Gooooo000Looooo`03o`000?oooooooooo05So
oooo1Ol000000ooooooo0000o`00000@o`0000Wooooo0_l00003oooooa;o00002oooool2o`0000ko
oooo0_l00004ooooo`;o000000?oooooo`000?l000003?ooool<o`000003ooooool0003o000000?o
0000MOooool001cooooo0_l0001Hooooo`?o00000ooooolCo`0000Wooooo0_l00004oooooa7o0000
0_ooool4o`0000Cooooo0ol0000Booooo`Co000000?oooooo`000?l000003OoooolAo`0007Gooooo
000Looooo`03o`000?oooooooooo05Kooooo0ol00002oooooaGo00001_ooool2o`0000Oooooo3ol0
0003ooooo`Go00001?ooool2o`000003ooooool0003o0000013ooooo0ol00002ooooo`;o00003Ooo
ool@o`0007Kooooo000Looooo`03o`000?oooooooooo05Gooooo0ol00003ooooo`Oo000000?ooooo
o`000?l000003?l00005ooooo`;o00002?ooool6o`0000?ooooo0ol00002ooooo`Go00001_ooool2
o`0000;ooooo0_l00004ooooo`;o00003oooool2o`0000Wooooo0_l00002oooooa3o0000M_ooool0
01cooooo00?o0000ooooooooool0EOooool3o`0000?ooooo5ol0000?ooooo`Wo000000?oooooo`00
0?l000001Ol00007ooooo`;o00000_ooool2o`0000Cooooo1?l00004ooooo`;o00004_ooool2o`00
0003ooooool0003o000000oo0000M_ooool001cooooo00?o0000ooooooooool0EOooool2o`000003
ooooool0003o000001So00000oooool2o`0000[ooooo3_l0000;ooooo`;o00001oooool4o`0000Co
oooo0_l00003ooooo`;o00001oooool2o`0000?ooooo0ol000001?oooooo0000o`000?ooool>o`00
07Kooooo000Looooo`03o`000?oooooooooo05Cooooo0_l00002oooooa[o00000oooool2o`0000;o
oooo0_l000000ooooooo0000o`000005ooooo`co00002oooool4o`0000;ooooo0_l000001?oooooo
0000o`000?l00002ooooo`;o00001_ooool2o`0000Kooooo0ol00003ooooo`;o00001_ooool<o`00
07Oooooo000Looooo`03o`000?oooooooooo05Cooooo1?l00003ooooo`Go000000?oooooo`000?l0
00004?l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000003?ooool2o`000003
ooooool0003o000000;o00002?ooool2o`000003ooooool0003o000000;ooooo0ol00005ooooo`;o
00003_ooool3o`0000_ooooo3?l0001gooooo`007?ooool00ol0003oooooooooo`1Eooooo`?o0000
1?oooolGo`000003ooooool0003o000000kooooo0ol00003ooooo`;o00000oooool2o`0000Sooooo
0_l00002ooooo`So00000oooool4o`0000gooooo0ol000001?oooooo0000o`000?l00007ooooo`[o
0000N?ooool001cooooo00?o0000ooooooooool0Doooool2o`000003ooooool0003o000000Gooooo
5Ol0000Booooo`?o00002?ooool2o`0000;ooooo0_l00008ooooo`Co00000_ooool2o`0000;ooooo
1Ol0000=ooooo`?o000000Goooooo`000?l0003o0000ooooo`02o`0000;ooooo0_l00003ooooo`Oo
0000N?ooool001cooooo00?o0000ooooooooool0Doooool2o`0000Gooooo0_l00003oooooa?o0000
2Oooool2o`0000?ooooo0ol000000ooooooo0000o`000006ooooo`Co00000oooool2o`0000cooooo
0_l00004ooooo`;o00002Oooool2o`0000gooooo0_l00002ooooo`;o00001?ooool4o`0007[ooooo
000Looooo`03o`000?oooooooooo05?ooooo0_l00005ooooo`;o00001?oooolBo`0000Wooooo0_l0
0003ooooo`?o00002Oooool4o`0000?ooooo0_l00003ooooo`;o00001oooool2o`0000Kooooo0_l0
0007ooooo`;o00002Oooool4o`0000[ooooo1Ol000001?oooooo0000o`000?l0001eooooo`007?oo
ool00ol0003oooooooooo`1Booooo`Co00000oooool2o`0000?ooooo0_l00002oooooa3o00003Ooo
ool2o`0001Oooooo0_l00008ooooo`;o00001Oooool2o`0001;ooooo1?l00003ooooo`;o00002?oo
ool8o`000004ooooool0003o0000o`0006oooooo000Looooo`03o`000?oooooooooo05;ooooo1?l0
0003ooooo`;o00000oooool2o`000003ooooool0003o000000ko00003_ooool4o`0001Cooooo0_l0
0007ooooo`Co00008?ooool2o`0000Wooooo0_l00002ooooo`Oo0000Koooool001cooooo00?o0000
ooooooooool0Doooool3o`0000_ooooo4?l00009ooooo`?o00000_ooool5o`0000kooooo0_l00003
ooooo`;o00001Oooool5o`0001;ooooo0_l0000:ooooo`;o00000_ooool3o`000003ooooool0003o
000000;ooooo0_l00007ooooo`?o00001Oooool3o`0006Sooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003ooooooooo
o`1Cooooo`Go00002oooool>o`0000?ooooo0_l00004ooooo`?o00000oooool4o`0000kooooo0_l0
0002ooooo`;o00001_ooool2o`000003ooooool0003o000000oooooo0_l000000ooooooo0000o`00
000:ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000002ooooo`;o00003ooo
ool3o`0006Sooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0Doooool5o`0000cooooo2?l000001?oooooo0000
o`000?l00004ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001?ooool2o`0000Co
oooo0_l0000Cooooo`Co00000oooool2o`00013ooooo0_l00003ooooo`;o00001oooool3o`0000So
oooo0ol0001Yooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`Go0000
1_ooool00ol0003oooooooooo`1Dooooo`Co00001Oooool2o`0000;ooooo0_l00003ooooo`Ko0000
00Coooooo`000?l0003o00002oooool2o`0000Kooooo0_l00005ooooo`Co00000_ooool2o`0000;o
oooo0_l00009ooooo`;o00001Oooool2o`0000?ooooo1?l0000Hooooo`Co00000_ooool3o`0000;o
oooo0ol00006ooooo`[o0000I?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
2Oooool01?m4A4CogMgMooooool00007ooooo`?o0000EOooool5o`0000?ooooo0_l00002ooooo`;o
00001Oooool5o`0000gooooo0ol0000>ooooo`?o00001_ooool3o`0000Sooooo0_l00005ooooo`;o
00000oooool2o`0001[ooooo1?l00002ooooo`So00001_ooool;o`0006?ooooo00000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003o
ooooooooo`1Eooooo`Go00003oooool4o`0000gooooo0ol000000ooooooo0000o`00000:ooooo`;o
00002Oooool2o`00013ooooo0_l00002ooooo`;o00005?ooool2o`000004ooooool0003o0000o`00
00Oooooo1?l000000ooooooo0000o`000004ooooo`go0000Hoooool00003ooooool@413ooooo00;o
oooo00?o410@ooooooooool02_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo05Go
oooo0ol0000Cooooo`;o00004Oooool2o`0000[ooooo0_l0000Kooooo`;o00002Oooool2o`0000;o
oooo0_l00007ooooo`So00004_ooool=o`0006?ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMg
M`cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`1Fooooo`;o00004oooool2o`00
01?ooooo0_l0000=ooooo`;o00004_ooool2o`0000Sooooo0_l00003ooooo`?o000000?oooooo`00
0?l000001oooool5o`0000Cooooo0_l00006ooooo`;o00000oooool2o`0000;ooooo3ol0001Qoooo
o`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000
ooooooooool0E_ooool4o`0000Wooooo0_l00004ooooo`Co000000Coooooo`000?l0003ooooo0_l0
0004ooooo`;o00001oooool2o`000003ooooool0003o000000[ooooo0_l0000Booooo`;o00002?oo
ool2o`0000Cooooo0_l0000Cooooo`Co00001?ooool2o`0000?ooooo0_l00002ooooo`oo0000HOoo
ool001cooooo00?o0000ooooooooool0F?ooool6o`0000Gooooo1Ol000000ooooooo0000o`000002
o`000004ooooool0003o0000ooooo`;o000000Coooooo`000?l0003ooooo0_l0000:ooooo`Co0000
8?ooool3o`0000Sooooo1?l0000=ooooo`;o00001Oooool2o`0000gooooo3ol0001Qooooo`007?oo
ool00ol0003oooooooooo`1Jooooo`Co00001_ooool6o`0000[ooooo0_l0000?ooooo`;o00004ooo
ool2o`0000_ooooo0ol00008ooooo`Co00002Oooool2o`0000;ooooo0_l00006ooooo`;o00001ooo
oolDo`00067ooooo000Looooo`03o`000?oooooooooo05[ooooo0_l00005ooooo`;o000000?ooooo
o`000?l000001?l000001?oooooo0000o`000?l0000Aooooo`;o00001?ooool2o`0000Wooooo0_l0
0008ooooo`;o00000oooool2o`0001kooooo0_l0000:ooooo`Co00001Oooool5o`000003ooooool0
003o000000co0000HOooool001cooooo00?o0000ooooooooool0G?ooool3o`0000;ooooo1ol00002
ooooo`So00001Oooool2o`0000Kooooo0_l00004ooooo`;o00002Oooool2o`0000gooooo0_l00009
ooooo`;o00008Oooool2o`0000Kooooo1?l000000ooooooo0000o`00000<o`00067ooooo000Loooo
o`03o`000?oooooooooo05cooooo0ol00004ooooo`;o00000_ooool;o`0000?ooooo1?l0000<oooo
o`;o00001_ooool4o`0000kooooo0_l00002ooooo`?o00001?ooool2o`0000Kooooo0_l000000ooo
oooo0000o`00000=ooooo`;o00001Oooool2o`0000[ooooo4Ol0001Qooooo`007?ooool00ol0003o
ooooooooo`1Qooooo`;o00000_ooool5o`000003ooooool0003o000000;ooooo0_l00004ooooo`Co
00005?ooool4o`0000kooooo0_l000000ooooooo0000o`000002o`0000cooooo1Ol00004ooooo`Co
00000oooool4o`0000;ooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00000_ooool2o`00
00;ooooo4?l0001Qooooo`007?ooool00ol0003oooooooooo`1Qooooo`;o00000_ooool4o`0000Ko
oooo0_l0000aooooo`;o00004?ooool2o`0000Gooooo1?l00003ooooo`;o00000_ooool4o`0000;o
oooo0_l00002ooooo`;o00000_ooool3o`0000Cooooo3Ol0001Qooooo`007?ooool00ol0003ooooo
ooooo`1Rooooo`Go000000?oooooo`000?l000001?ooool2o`0000;ooooo0_l00003ooooo`;o0000
1_ooool2o`0000Sooooo0_l0000Vooooo`;o00004oooool3o`000003ooooool0003o000000Oooooo
1?l000000ooooooo0000o`000003ooooo`_o0000HOooool001cooooo00?o0000ooooooooool0H_oo
ool:o`0000;ooooo0_l000001Ooooooo0000o`000?l0003ooooo00Co00000_ooool2o`0000;ooooo
0_l000000ooooooo0000o`000002o`0000?ooooo0_l00008ooooo`;o00000_ooool2o`0000Kooooo
0_l0000@ooooo`;o00002Oooool2o`0000Gooooo0_l00004ooooo`?o00000oooool2o`0000;ooooo
1ol00003ooooo`_o0000HOooool001cooooo00?o0000ooooooooool0Ioooool5o`0000;ooooo0_l0
00000ooooooo0000o`000002ooooo`;o00001?ooool2o`0000Gooooo1?l00006ooooo`;o00001?oo
ool3o`0000;ooooo0_l00006ooooo`;o00006Oooool4o`000003ooooool0003o000000Co00001?oo
ool2o`0000Cooooo0_l000000ooooooo0000o`000005o`0000;ooooo3?l0001Rooooo`007?ooool0
0ol0003oooooooooo`1Wooooo`;o00004?ooool2o`0000kooooo0_l000000ooooooo0000o`000004
ooooo`;o00003_ooool2o`0001Kooooo0ol00002ooooo`Co00001_ooool2o`0000Oooooo0ol00002
ooooo`;o00000_ooool2o`000003ooooool0003o000000Oo0000H_ooool001cooooo0_l0001Xoooo
o`?o000000?oooooo`000?l000001?l000000ooooooo0000o`000005ooooo`;o00001?ooool2o`00
00Sooooo0_l000000ooooooo0000o`00000?ooooo`;o00000oooool2o`0001Kooooo0ol00003oooo
o`;o00000oooool2o`0001?ooooo0_l00003ooooo`Go0000IOooool001cooooo00?o0000oooooooo
ool0Ioooool3o`000003ooooool0003o000000Co000000?oooooo`000?l000000_l00009ooooo`?o
00001_ooool3o`000004ooooool0003o0000ooooo`;o00003?ooool2o`00027ooooo0_l00002oooo
o`?o00004oooool2o`0000?ooooo1Ol0001Uooooo`007?ooool00ol0003oooooooooo`1Yooooo`;o
000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00002_ooool2o`000003ooooool0003o0000
00?ooooo0ol000001?oooooo0000o`000?ooool2o`0002oooooo0_l00002ooooo`?o00004_ooool2
o`000003ooooool0003o000000?ooooo1Ol0001Sooooo`007?ooool00ol0003oooooooooo`1Yoooo
o`;o000000?oooooo`000?l000000ol0000?ooooo`;o000000?oooooo`000?l000001?ooool2o`00
0003ooooool0003o000000;ooooo0_l0000dooooo`;o00002_ooool2o`0000Gooooo0_l000000ooo
oooo0000o`000003ooooo`Ko0000H_ooool001cooooo00?o0000ooooooooool0K?ooool5o`0000oo
oooo0_l00007ooooo`;o00001Oooool3o`0001oooooo0_l0000Booooo`;o00002?ooool4o`0000oo
oooo1Ol0001Qooooo`007?ooool00ol0003oooooooooo`1/ooooo`;o00002?ooool2o`0001Wooooo
0_l00006ooooo`;o00001Oooool2o`00013ooooo0_l0000Looooo`;o00001Oooool2o`0000Kooooo
2Ol0001Qooooo`007?ooool00ol0003oooooooooo`1/ooooo`Co00001_ooool2o`0000kooooo0_l0
000;ooooo`;o00001?ooool2o`0000Gooooo0_l0000Booooo`;o00001_ooool2o`0000Sooooo0_l0
0007ooooo`Co00000_ooool6o`0000?ooooo1Ol00002ooooo`Co0000H?ooool001cooooo00?o0000
ooooooooool0K_ooool3o`0000gooooo0_l00006ooooo`;o00000oooool2o`0000Kooooo0_l0000L
ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Sooooo0ol00006ooooo`Co00000_ooool6
o`0000?ooooo1Ol00002ooooo`Co0000H?ooool001cooooo00?o0000ooooooooool0Koooool2o`00
00gooooo0_l00005ooooo`;o00001?ooool2o`0000?ooooo0_l00002ooooo`;o00006oooool2o`00
017ooooo1Ol0000Cooooo`Oo00000oooool2o`00067ooooo000Looooo`03o`000?oooooooooo07Ko
oooo0_l00006ooooo`;o00001Oooool2o`0000Wooooo0ol000000ooooooo0000o`000007ooooo`;o
00009Oooool4o`0000oooooo0_l000000ooooooo0000o`000002o`0000;ooooo1_l000000ooooooo
0000o`000003o`0005gooooo000Looooo`03o`000?oooooooooo07;ooooo0_l00002ooooo`;o0000
1_ooool2o`00017ooooo0_l0000:ooooo`;o00000_ooool2o`0001oooooo1?l00007ooooo`;o0000
1?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000:o`000003ooooool0003o000000?o0000
GOooool001cooooo00?o0000ooooooooool0L_ooool2o`0000;ooooo0_l0000Yooooo`;o00007ooo
ool4o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`;o00000_ooool2o`0000Cooooo2_l0
0002ooooo`?o0000GOooool001cooooo00?o0000ooooooooool0JOooool4o`0001Cooooo0_l00004
ooooo`;o00002?ooool2o`00037ooooo0_l00004ooooo`;o00001?ooool2o`0000?ooooo1?l00000
1?oooooo0000o`000?ooool:o`0000;ooooo1?l0001Looooo`007?ooool00ol0003oooooooooo`1Y
ooooo`Co00001_ooool2o`0000;ooooo0_l00008ooooo`;o00001?ooool2o`0000Sooooo0_l0000m
ooooo`;o00000oooool7o`000003ooooool0003o000000So00001?ooool2o`0005cooooo000Loooo
o`03o`000?oooooooooo06Kooooo2_l00003ooooo`Ko00004oooool2o`0002[ooooo0_l0000Foooo
o`;o00000_ooool4o`000003ooooool0003o000000;ooooo4Ol0001Kooooo`007?ooool00ol0003o
ooooooooo`1Vooooo`[o00001?ooool3o`0001;ooooo0_l000000ooooooo0000o`000002o`0001go
oooo1?l00007ooooo`;o00005Oooool3o`0000;ooooo0_l00007oooooa7o0000Foooool001cooooo
0_l0001Uooooo`;o000000?oooooo`000?l000001ol00004ooooo`;o00001_ooool2o`0000_ooooo
0_l00003ooooo`;o00001?ooool2o`0001Oooooo1?l00003ooooo`;o00006Oooool3o`0000Kooooo
0_l00003ooooo`co00000_ooool3o`0005_ooooo000Looooo`03o`000?oooooooooo06Cooooo3_l0
0004ooooo`;o00001?ooool2o`0001Kooooo0_l0000Nooooo`;o00008_ooool4o`000003ooooool0
003o000000[o00000_ooool3o`0005_ooooo000Looooo`03o`000?oooooooooo06Cooooo3ol00000
0ooooooo0000o`000002o`0000kooooo1?l0000aooooo`;o00007Oooool2o`000003ooooool0003o
000000Wo000000?oooooo`000?l000000ol0001Kooooo`007?ooool00ol0003oooooooooo`1Soooo
o`Ko000000?oooooo`000?l000002_l00003ooooo`;o00002oooool4o`0002kooooo0_l000000ooo
oooo0000o`00000=ooooo`;o00002?ooool2o`0000Oooooo4?l0001Looooo`007?ooool00ol0003o
ooooooooo`1Soooooa?o00000oooool2o`0000;ooooo0_l0000Fooooo`;o00008Oooool2o`0000?o
oooo0_l0000;ooooo`;o00001_ooool4o`0000Cooooo0_l000000ooooooo0000o`00000;o`000003
ooooool0003o000005cooooo000Looooo`03o`000?oooooooooo06Cooooo4_l00007ooooo`;o0000
1?ooool2o`0000cooooo0_l00002ooooo`;o00006?ooool2o`0000cooooo1?l0000Aooooo`;o0000
1_ooool2o`0000;ooooo3Ol000000ooooooo0000o`00001Kooooo`007?ooool00ol0003ooooooooo
o`1RoooooaCo00002Oooool2o`0000;ooooo0_l0000<ooooo`;o00007?ooool2o`000003ooooool0
003o000000[ooooo0ol0000Fooooo`;o00001?oooolAo`0005_ooooo000Looooo`03o`000?oooooo
oooo06;ooooo5Ol00003ooooo`;o00000oooool2o`00023ooooo0_l0000?ooooo`;o00001oooool2
o`000003ooooool0003o000001Oooooo0_l000001?oooooo0000o`000?oooolAo`0005_ooooo000L
ooooo`03o`000?oooooooooo06?ooooo5?l00003ooooo`;o000000?oooooo`000?l000001_ooool2
o`0001[ooooo0_l0000Hooooo`Co00001?ooool2o`0000Kooooo0_l00009ooooo`;o00000_ooool2
o`000003ooooool0003o000000[o00000_ooool3o`0005_ooooo000Looooo`03o`000?oooooooooo
06;ooooo4_l00006ooooo`Go00001_ooool2o`0001gooooo0_l0000Dooooo`;o000000Coooooo`00
0?l0003o00000oooool2o`0000Kooooo0_l00009ooooo`?o00001?ooool<o`0000;ooooo0ol0001K
ooooo`007?ooool00ol0003oooooooooo`1RoooooaCo00001Oooool2o`0001Gooooo0_l0000@oooo
o`;o00003?ooool2o`0000Kooooo0_l00002ooooo`;o00005Oooool4o`0000Cooooo3?l00003oooo
o`;o0000Foooool001cooooo00?o0000ooooooooool0H_oooolDo`0001Kooooo0_l00004ooooo`;o
00007_ooool2o`0000;ooooo0_l0000;ooooo`;o00000_ooool3o`0000Cooooo1?l00003ooooo`Co
00001Oooool:o`0000Cooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`1RoooooaCo0000
5_ooool2o`0001Sooooo0_l0000;ooooo`;o000000?oooooo`000?l000001Oooool5o`000003oooo
ool0003o000000;ooooo0ol00004ooooo`Co00003?ooool:o`0000Cooooo0_l0001Kooooo`007?oo
ool00ol0003oooooooooo`1RoooooaGo00004Oooool2o`0001cooooo0_l0000;ooooo`;o00002?oo
ool5o`0000Cooooo1?l0000?ooooo`;o00001?ooool7o`000003ooooool0003o000000;ooooo0ol0
001Kooooo`007?ooool00ol0003oooooooooo`1Roooooa;o000000?oooooo`000?l000002oooool2
o`000004ooooool0003o0000ooooo`;o00000oooool2o`0002Cooooo0_l00006ooooo`;o00000ooo
ool2o`000004ooooool0003o0000ooooo`;o00001_ooool2o`0000Wooooo1?l00003ooooo`Co0000
00?oooooo`000?l000000_l00002ooooo`?o0000Foooool001cooooo00?o0000ooooooooool0Hooo
ool?o`00013ooooo0_l000000ooooooo0000o`000004ooooo`Co00005?ooool2o`0000;ooooo0_l0
000Booooo`;o00001_ooool4o`0000Oooooo0_l00002ooooo`;o00001oooool3o`0000;ooooo1ol0
0004ooooo`?o0000Foooool001cooooo0_l0001Tooooo`ko00006_ooool2o`0001Kooooo0_l00002
ooooo`;o00004?ooool2o`0000[ooooo0_l0000;ooooo`;o00000oooool2o`0000;ooooo0ol00004
ooooo`_o0000G?ooool001cooooo00?o0000ooooooooool0I?ooool=o`0000?ooooo1?l00003oooo
o`;o00001?ooool2o`0001oooooo0_l0000Eooooo`;o00001?ooool2o`0000Kooooo0_l00008oooo
o`;o00000_ooool4o`0000[ooooo2Ol0001Mooooo`007?ooool00ol0003oooooooooo`1Sooooo`go
00001?ooool4o`0000?ooooo0_l00004ooooo`;o00004oooool2o`0000[ooooo0_l0000:ooooo`;o
00003oooool2o`0000Kooooo0_l000000ooooooo0000o`000005ooooo`;o000000Goooooo`000?l0
003o0000ooooo`02o`0000[ooooo1ol0001Nooooo`007?ooool00ol0003oooooooooo`1Sooooo`go
00001_ooool2o`0000gooooo0_l00008ooooo`;o00001Oooool2o`0001Kooooo0_l0000@ooooo`;o
00001Oooool2o`000004ooooool0003o0000ooooo`;o00001Oooool2o`0000;ooooo0_l0001_oooo
o`007?ooool00ol0003oooooooooo`1Sooooo`?o00000_ooool8o`0000Kooooo0_l00009ooooo`;o
00000_ooool2o`0000Sooooo0_l0000]ooooo`Co00001Oooool2o`0000Cooooo0_l00004ooooo`;o
000000?oooooo`000?l000000_ooool3o`0006cooooo000Looooo`03o`000?oooooooooo06?ooooo
1?l00002ooooo`Go00004oooool2o`0003;ooooo1?l00005ooooo`;o00004oooool5o`0000;ooooo
0ol0001/ooooo`007?ooool00ol0003oooooooooo`1Sooooo`Co00000_ooool3o`0000Wooooo0_l0
000nooooo`Co00002oooool2o`0000Sooooo0_l00004ooooo`Ko00001Oooool2o`0006Sooooo000L
ooooo`03o`000?oooooooooo06;ooooo1_l00008ooooo`;o00000oooool2o`00013ooooo0_l0000E
ooooo`;o00009?ooool2o`0000Sooooo0_l00008ooooo`;o00001Oooool2o`0006Sooooo000Loooo
o`03o`000?oooooooooo067ooooo1ol00005ooooo`;o000000?oooooo`000?l000000_ooool3o`00
00Sooooo0_l00003ooooo`;o000000?oooooo`000?l000005Oooool2o`0000[ooooo0_l00002oooo
o`;o00006oooool4o`0000Gooooo0ol00005ooooo`;o0000Joooool001cooooo00?o0000oooooooo
ool0Goooool9o`0000?ooooo1?l00005ooooo`;o00000oooool2o`0000?ooooo0ol00003ooooo`;o
00002oooool2o`000004ooooool0003o0000ooooo`;o00003_ooool2o`000003ooooool0003o0000
00;ooooo0_l0000Jooooo`Go00000oooool7o`0000?ooooo0_l0001[ooooo`007?ooool00ol0003o
ooooooooo`1Oooooo`Wo00000oooool2o`0000Wooooo0_l000000ooooooo0000o`000003ooooo`;o
00002?ooool2o`0000Oooooo0_l000001?oooooo0000o`000?ooool2o`0000Gooooo1Ol00004oooo
o`;o00007Oooool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool3o`00
00;ooooo0_l0001/ooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o000000?oooooo`000?l0
00001ol00009ooooo`;o00000_ooool2o`00013ooooo0_l0000Dooooo`Go00001?ooool2o`0000;o
oooo0_l0000<ooooo`Co00002Oooool2o`0000Kooooo0ol00004ooooo`;o00000_ooool4o`000003
ooooool0003o000006Wooooo000Looooo`03o`000?oooooooooo05gooooo2Ol000000ooooooo0000
o`000009ooooo`;o00004Oooool2o`0000Oooooo0_l0000>ooooo`;o00002oooool2o`0000;ooooo
1?l00006ooooo`Co000000?oooooo`000?l000003_ooool3o`0000Cooooo0_l000000ooooooo0000
o`000003o`000003ooooool0003o000000?o0000I_ooool001cooooo00?o0000ooooooooool0Fooo
ool>o`0000gooooo0_l0000=ooooo`;o00000_ooool2o`0000?ooooo0_l0000>ooooo`;o000000?o
ooooo`000?l000001Oooool2o`0000Gooooo1?l00006ooooo`;o00000oooool3o`0000_ooooo0_l0
000:ooooo`Go00000_ooool4o`000003ooooool0003o000006?ooooo00001_ooooook^k^oc8b<_l0
003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003o
ooooooooo`1Jooooo`oo00002_ooool2o`000003ooooool0003o000000[ooooo0_l00005ooooo`?o
00000_ooool2o`00017ooooo0_l00005ooooo`;o00000_ooool2o`0000Cooooo0_l00004ooooo`?o
00001?ooool2o`0000Gooooo0_l00004ooooo`;o00001Oooool;o`0000?ooooo0_l000000ooooooo
0000o`00001Sooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmE
EEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0F_ooool@o`0000Wooooo0_l00009
ooooo`;o00000_ooool2o`0000Kooooo0_l00002ooooo`;o00000oooool2o`0001Oooooo0_l00004
ooooo`;o00001?ooool2o`0000cooooo0_l00006ooooo`;o00000_oooolAo`0006Kooooo00000ooo
oooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo05Wooooo4ol00002ooooo`;o00003?ooool4o`0000;ooooo0_l00008
ooooo`;o00001Oooool2o`0002Cooooo1?l00007ooooo`?o00001oooool3o`000003ooooool0003o
000000?ooooo2ol0001Wooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09oooo
o`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0005Sooooo5?l000001Ooooooo0000o`000?l0
003ooooo00;o00000oooool2o`0000Cooooo0_l0000>ooooo`;o0000:oooool4o`0000Oooooo0ol0
0002ooooo`;o00001?ooool5o`0000;ooooo3_l0001Uooooo`0000?oooooo`000?ooool00_ooool0
0ol0003oooooooooo`09ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003ooooooooo
o`1Goooooa?o00000oooool2o`000004ooooool0003o0000o`0000?ooooo1?l00007ooooo`;o0000
6oooool2o`0000Oooooo0_l0000Iooooo`;o00001Oooool2o`0000Gooooo0ol00002ooooo`oo0000
IOooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7oooo
o`08ooooo`03o`000?oooooooooo05Oooooo4ol00006ooooo`?o000000?oooooo`000?l000000_oo
ool2o`0000Oooooo0_l0000Iooooo`Co00001oooool2o`0000cooooo0_l000001?oooooo0000o`00
0?l00007ooooo`;o00003?ooool3o`000003ooooool0003o000000oo0000I?ooool00006oooooomg
MgOoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo05Ko
oooo5Ol00006ooooo`;o000000?oooooo`000?l000003?ooool2o`0000Oooooo0_l00008ooooo`;o
00001?ooool3o`00013ooooo0_l000000ooooooo0000o`000002ooooo`Ko00001oooool2o`0000Wo
oooo0_l000001?oooooo0000o`000?oooolCo`0006?ooooo00001_ooooook^k^oc8b<_l0003o<S8b
onk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`1FoooooaGo00001Ooo
ool3o`000003ooooool0003o000000;ooooo0_l00008ooooo`;o00001oooool2o`0000Sooooo0_l0
0004ooooo`Co00002Oooool2o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`?o00002?oo
ool3o`0000?ooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo4ol0001Sooooo`007?oo
ool00ol0003oooooooooo`1FoooooaCo00000oooool7o`0000Cooooo0ol0000:ooooo`Co00002ooo
ool2o`0000Oooooo0_l00004ooooo`;o00000oooool2o`0000?ooooo0_l00007ooooo`;o00002Ooo
ool3o`0000?ooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo5?l0001Sooooo`007?oo
ool00ol0003oooooooooo`1FoooooaCo000000?oooooo`000?l000001?l000000ooooooo0000o`00
0002ooooo`Go00002_ooool4o`0000Wooooo1?l00003ooooo`;o00001Oooool2o`000003ooooool0
003o000000Sooooo0_l00007ooooo`;o00003Oooool4o`0000?ooooo1Ol000000ooooooo0000o`00
000Bo`0006?ooooo000Looooo`03o`000?oooooooooo05Gooooo5Ol000000ooooooo0000o`000009
ooooo`;o00000_ooool2o`0000Oooooo0_l00008ooooo`;o00000_ooool3o`0000Gooooo0_l00005
ooooo`;o00005?ooool2o`0000gooooo1?l00005ooooo`;o000000?oooooo`000?l000004Ol00000
0ooooooo0000o`00001Rooooo`007?ooool00ol0003oooooooooo`1EoooooaGo00001_ooool2o`00
00Gooooo0_l000001?oooooo0000o`000?l00006ooooo`;o00002?ooool2o`0000;ooooo0_l0000@
ooooo`;o00003?ooool2o`00013ooooo0_l0000<oooooa?o000000?oooooo`000?l00000H_ooool0
01cooooo00?o0000ooooooooool0E_ooool5o`000003ooooool0003o000000co00001?ooool5o`00
00Cooooo0_l00002ooooo`;o00002?ooool2o`0001_ooooo0ol00009ooooo`;o000000?oooooo`00
0?l000001?ooool2o`000003ooooool0003o000000Cooooo0_l000001?oooooo0000o`000?ooool2
o`0000Gooooo0_l00002ooooo`go000000?oooooo`000?l000000ol0001Uooooo`007?ooool00ol0
003oooooooooo`1Fooooo`?o00000oooool<o`0000Kooooo0_l000000ooooooo0000o`000002o`00
00_ooooo0_l00003ooooo`;o00004Oooool2o`0000Sooooo0ol000000ooooooo0000o`000006oooo
o`;o00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`;o00001?ooool2o`00
00Gooooo0_l000000ooooooo0000o`00000@o`0000;ooooo0_l0001Sooooo`007?ooool00ol0003o
ooooooooo`1Eooooo`?o00001Oooool;o`000003ooooool0003o000000?ooooo1?l000000ooooooo
0000o`00000;ooooo`Co00000_ooool2o`0000Kooooo0_l00008ooooo`;o00001_ooool2o`000004
ooooool0003o0000ooooo`;o00002oooool3o`0000?ooooo0_l00003ooooo`;o00003?ooool3o`00
0003ooooool0003o000000;o000000?oooooo`000?l000003ol0001Sooooo`007?ooool00ol0003o
ooooooooo`1Eooooo`Co00000_ooool4o`000003ooooool0003o000000Go00000_ooool2o`0000Go
oooo0_l0000@ooooo`;o00000_ooool2o`0000Kooooo0_l00003ooooo`;o00002Oooool4o`0000[o
oooo0_l00006ooooo`;o00000oooool2o`0000?ooooo0_l0000;ooooo`Co000000?oooooo`000?l0
00005?l0001Sooooo`007?ooool00ol0003oooooooooo`1Eooooo`Go000000Coooooo`000?l0003o
00001_ooool3o`0000cooooo0_l0000Nooooo`;o000000?oooooo`000?l000001_ooool3o`000003
ooooool0003o000000Sooooo0_l00002ooooo`;o000000?oooooo`000?l000005Oooool3o`0000?o
oooo4_l0001Wooooo`007?ooool00ol0003oooooooooo`1Eooooo`Go00000_ooool2o`0000Oooooo
0_l00004ooooo`?o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00009ooooo`;o0000
00?oooooo`000?l000002?ooool2o`0000Gooooo0_l0000:ooooo`;o00001oooool3o`0000;ooooo
0_l000000ooooooo0000o`000003o`00017ooooo0ol00005ooooo`;o000000?oooooo`000?l00000
2_l00002ooooo`;o0000IOooool001cooooo00?o0000ooooooooool0EOooool4o`000003ooooool0
003o000000Wooooo0_l00004ooooo`?o000000?oooooo`000?l000001_ooool2o`0000Wooooo0_l0
00000ooooooo0000o`000002o`0000Kooooo1?l0000;ooooo`;o00002oooool2o`0000Oooooo1_l0
0006ooooo`;o00000_ooool4o`000003ooooool0003o000000Kooooo3ol000001?oooooo0000o`00
0?l0001Uooooo`007?ooool2o`0005Oooooo1_l00009ooooo`;o00002Oooool2o`0001?ooooo1?l0
0008ooooo`;o000000?oooooo`000?l000001Oooool5o`0000_ooooo0_l00007ooooo`Oo00000_oo
ool;o`0000Wooooo3?l00002ooooo`Co0000I_ooool001cooooo00?o0000ooooooooool0E_ooool5
o`0000[ooooo0_l00009ooooo`;o00001?ooool2o`0001Gooooo0_l00005ooooo`Co00000oooool3
o`0000gooooo0_l00004ooooo`;o00000_ooool3o`000003ooooool0003o000000[o000000Cooooo
o`000?l0003ooooo0ol00006ooooo`Go00000_ooool4o`000004ooooool0003o0000o`0006Sooooo
000Looooo`03o`000?oooooooooo05Kooooo1_l00005ooooo`;o00000_ooool2o`0000Sooooo0_l0
0005ooooo`;o00001?ooool2o`0000gooooo1?l00003ooooo`Ko00003oooool2o`0000Gooooo0_l0
00000ooooooo0000o`000002ooooo`;o000000Coooooo`000?l0003ooooo3?l00002ooooo`Co0000
1oooool<o`0006Wooooo000Looooo`03o`000?oooooooooo05Oooooo1Ol00002ooooo`Go00003?oo
ool2o`0000_ooooo0_l00003ooooo`;o00002?ooool3o`0000;ooooo1?l00005ooooo`;o00000ooo
ool2o`0000;ooooo0_l00003ooooo`Co00000oooool2o`0000Oooooo4?l00004ooooo`;o00002?oo
ool6o`000003ooooool0003o000006_ooooo000Looooo`03o`000?oooooooooo05Oooooo0_l00000
0ooooooo0000o`000002ooooo`Go000000?oooooo`000?l000000oooool2o`0000_ooooo0_l00009
ooooo`;o00003Oooool2o`0000Oooooo0_l000000ooooooo0000o`000002o`0000;ooooo0ol00004
ooooo`;o000000?oooooo`000?l000002?ooool6o`000003ooooool0003o000000Wo000000?ooooo
o`000?l00000O_ooool001cooooo00?o0000ooooooooool0F?ooool5o`0000Cooooo0_l000000ooo
oooo0000o`000003ooooo`;o00002oooool2o`0000Sooooo0_l000001?oooooo0000o`000?l0000>
ooooo`;o00000oooool2o`000003ooooool0003o000000Cooooo0ol000000ooooooo0000o`000004
ooooo`;o00001_oooolDo`000004ooooool0003o0000o`0007gooooo000Looooo`03o`000?oooooo
oooo05Sooooo1Ol000000ooooooo0000o`000002o`0000Cooooo0_l0000Hooooo`;o000000?ooooo
o`000?l000000_l0000=ooooo`;o00000_ooool3o`0000_ooooo0ol0000;oooooaCo00000_ooool2
o`0007gooooo000Looooo`03o`000?oooooooooo05cooooo3ol000000ooooooo0000o`000002o`00
00;ooooo0_l00002ooooo`;o00002oooool6o`0000_ooooo0_l00002ooooo`;o000000?oooooo`00
0?l000002_ooool2o`0000Wooooo5_l00021ooooo`007?ooool00ol0003oooooooooo`1Loooooaco
00002oooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000003_ooool2o`0000[o
oooo0_l00007oooooaSo000000?oooooo`000?l00000O_ooool001cooooo00?o0000ooooooooool0
HOooool2o`000003ooooool0003o000001Co00003?ooool4o`000003ooooool0003o000000Cooooo
0_l00005ooooo`;o00000_ooool4o`0000Kooooo1?l000000ooooooo0000o`000003oooooaOo0000
0_ooool2o`0007kooooo000Looooo`03o`000?oooooooooo06Kooooo1?l00005ooooo`;o000000?o
ooooo`000?l000002_l0000=ooooo`;o00001?ooool3o`0000;ooooo1Ol000000ooooooo0000o`00
0002o`0000?ooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000Cooooo5_l0
0002ooooo`;o0000O_ooool001cooooo00?o0000ooooooooool0L_ooool>o`0000_ooooo0_l00005
ooooo`;o00000_ooool5o`0000Kooooo1?l0000<oooooaKo000000?oooooo`000?l00000Ooooool0
01cooooo00?o0000ooooooooool0M?ooool>o`0000Sooooo0_l00008ooooo`Co000000?oooooo`00
0?l000000_ooool;o`0000?ooooo0_l00004oooooaWo0000Ooooool001cooooo00?o0000oooooooo
ool0M_ooool<o`000004ooooool0003o0000o`0000;ooooo1?l00003ooooo`;o00000oooool4o`00
0003ooooool0003o000000;ooooo2ol00003ooooo`;o000000?oooooo`000?l000006_l0001ooooo
o`007?ooool00ol0003oooooooooo`1fooooo`co000000Coooooo`000?l0003o00000_ooool2o`00
00Gooooo0_l00005ooooo`;o00003Oooool3o`000003ooooool0003o000000?ooooo0ol000000ooo
oooo0000o`00000>o`0000Cooooo0ol00020ooooo`007?ooool00ol0003oooooooooo`1foooooa3o
00000_ooool4o`0000Kooooo0ol00009ooooo`Go00000oooool2o`000003ooooool0003o000000?o
oooo0_l000000ooooooo0000o`00000Ao`000004ooooool0003o0000o`00087ooooo000Looooo`;o
0000MooooolFo`0000Cooooo1Ol00003ooooo`go000000?oooooo`000?l000000_l00007oooooaOo
0000POooool001cooooo00?o0000ooooooooool0M_oooolCo`0000Oooooo0_l00005ooooo`ko0000
00?oooooo`000?l000000_l00008ooooo`oo00000_ooool3o`0008?ooooo000Looooo`03o`000?oo
oooooooo07Kooooo5?l0000;oooooa3o000000?oooooo`000?l000000ol00007ooooo`_o00000ooo
ool5o`0008Cooooo000Looooo`03o`000?oooooooooo07Kooooo5?l0000:oooooa7o000000?ooooo
o`000?l000000ol00008ooooo`[o00000oooool4o`0008Gooooo000Looooo`03o`000?oooooooooo
07Oooooo5?l00007oooooaWo00002oooool9o`000003ooooool0003o000000;o0000QOooool001co
oooo00?o0000ooooooooool0MooooolDo`0000Oooooo5_l000000ooooooo0000o`00000;ooooo`Wo
0000R_ooool001cooooo00?o0000ooooooooool0MooooolAo`0000[ooooo5ol0000?ooooo`Oo0000
R_ooool001cooooo00?o0000ooooooooool0NOooool?o`0000Wooooo6?l0002Pooooo`007?ooool0
0ol0003oooooooooo`1iooooo`oo00002OoooolDo`000:Cooooo000Looooo`03o`000?oooooooooo
07cooooo1ol000001?oooooo0000o`000?l00009ooooo`?o00000_ooool@o`000:Cooooo000Loooo
o`03o`000?oooooooooo083ooooo0ol0000=ooooo`?o00000_ooool>o`0000;ooooo0_l0002Roooo
o`007?ooool00ol0003oooooooooo`2@ooooo`Co000000?oooooo`000?l000002_l00004ooooo`;o
0000X_ooool001cooooo00?o0000ooooooooool0T_ooool5o`000003ooooool0003o000000?o0000
00Coooooo`000?l0003o0000Z?ooool001cooooo00?o0000ooooooooool0T_ooool3o`0000?ooooo
1Ol000001?oooooo0000o`000?l0002Xooooo`007?ooool00ol0003oooooooooo`2Fooooo`?o0000
1Oooool2o`000:Wooooo000Looooo`03o`000?oooooooooo09Kooooo0ol0002`ooooo`007?ooool2
o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co
8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom:ooooo`0000KoooooogMgMonH
V9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o
0000ooooooooool0oooooom:ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooood[ooooo0000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`?o0000oooooom:ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09
ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`3ooooood[ooooo0000
0ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go410@okZj^_oooooo^[Zjoa0@
4006ooooo`03o`000?oooooooooo0?ooooooB_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0oooooom:ooooo`00
00Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Booooo`Co000000?o410@ooooooooool00oooool00ol0003ooooo
ooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooo
oom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`?o0000oooooom:ooooo`005?ooool00ol0
003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo
00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000B
ooooo`03oeEEEOmVIVKo00000?ooooooE?ooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00:Wooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0Eooooo`05onk^
k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^09Cooooo002Zooooo`05
o`000?ooooooooooooooool000002Oooool6o`0000Wooooo00GoEEEEogMgMoooooooV9RHob4Q8@03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0U?ooool00:[ooooo00Go0000ooooooooooooooooo`00
000Hooooo`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@09Co
oooo002Zooooo`05o`000?ooooooooooooooool000002Oooool6o`0000Wooooo00Go0000oiRHV?oo
ooooV9RHob4Q8@03ooooo`05o`000?ooooooooooooooool00000U?ooool00:[ooooo00Go0000ohN7
QoooooooZJVYo`00000Hooooo`05o`000?mEEEGo0000oa0@4?o<c<`00oooool01Ol0003ooooooooo
oooooooo000009Cooooo002Yooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool05_oo
ool00omEEEGoQhN7ooooo`05ooooo`05oa0@4?ooooooooooooooool@4100U?ooool00<Oooooo00?o
gMgMoa0@4?nHV9P01Oooool01OmgMgOoV9RHoooooonHV9SoMgMg09Cooooo0038ooooo`04olc<c?m4
A4Co0000oa0@40?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP2Dooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -20 0 ]
[.5 1.0125 20 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(66) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.64541 .67375 Mdot
.66064 .62508 Mdot
.66007 .36738 Mdot
.348 .49278 Mdot
.37593 .34138 Mdot
.6591 .35604 Mdot
.6931 .54926 Mdot
.71226 .53118 Mdot
.65444 .38892 Mdot
.36895 .53152 Mdot
.71899 .44036 Mdot
.36708 .66768 Mdot
.69728 .53839 Mdot
.3607 .52785 Mdot
.29285 .64485 Mdot
.473 .69967 Mdot
.65477 .66129 Mdot
.37715 .33782 Mdot
.44101 .70485 Mdot
.64639 .38924 Mdot
.44667 .35978 Mdot
.34887 .51745 Mdot
.6689 .65678 Mdot
.3574 .53332 Mdot
.44282 .70639 Mdot
.54003 .69846 Mdot
.64825 .67573 Mdot
.45083 .70689 Mdot
.36087 .67024 Mdot
.70012 .51245 Mdot
.47102 .70907 Mdot
.29522 .60861 Mdot
.4843 .30847 Mdot
.57797 .67154 Mdot
.70418 .45943 Mdot
.71204 .4303 Mdot
.67355 .35815 Mdot
.72475 .43681 Mdot
.71162 .51295 Mdot
.70679 .45792 Mdot
.70546 .45475 Mdot
.54148 .70108 Mdot
.70686 .43094 Mdot
.68203 .51959 Mdot
.27527 .58009 Mdot
.59178 .69274 Mdot
.58547 .2644 Mdot
.28137 .55711 Mdot
.63986 .66518 Mdot
.59645 .27693 Mdot
.30298 .58302 Mdot
.70086 .56696 Mdot
.45052 .32357 Mdot
.55507 .72581 Mdot
.70134 .52666 Mdot
.44153 .70926 Mdot
.63351 .35343 Mdot
.30952 .55359 Mdot
.35515 .67435 Mdot
.58771 .67682 Mdot
.34212 .53565 Mdot
.35563 .31338 Mdot
.49373 .68917 Mdot
.62542 .34795 Mdot
.659 .37907 Mdot
.73599 .452 Mdot
.67371 .61575 Mdot
.72997 .4583 Mdot
.36214 .48907 Mdot
.57279 .26517 Mdot
.28956 .5505 Mdot
.71839 .44013 Mdot
.5648 .6954 Mdot
.35792 .49972 Mdot
.63326 .66145 Mdot
.72381 .45988 Mdot
.37294 .34898 Mdot
.54936 .69464 Mdot
.60541 .29313 Mdot
.37195 .46573 Mdot
.34299 .51697 Mdot
.73104 .55376 Mdot
.34924 .6876 Mdot
.566 .71178 Mdot
.2781 .59346 Mdot
.71941 .58165 Mdot
.32776 .52274 Mdot
.47189 .70516 Mdot
.4487 .71102 Mdot
.35411 .65886 Mdot
.65687 .31159 Mdot
.67613 .6364 Mdot
.35771 .51291 Mdot
.36691 .48952 Mdot
.29949 .58159 Mdot
.28149 .59824 Mdot
.44828 .71357 Mdot
.46298 .29293 Mdot
.71341 .45235 Mdot
.45972 .33093 Mdot
.72794 .45934 Mdot
.44257 .32938 Mdot
.34589 .48322 Mdot
.64948 .33688 Mdot
.52807 .70383 Mdot
.47077 .29422 Mdot
.71923 .45961 Mdot
.35991 .51111 Mdot
.71593 .43079 Mdot
.67344 .63979 Mdot
.46826 .71487 Mdot
.33803 .3404 Mdot
.35677 .36941 Mdot
.67072 .67154 Mdot
.35334 .46952 Mdot
.32606 .54135 Mdot
.34584 .52715 Mdot
.6762 .61977 Mdot
.65005 .38593 Mdot
.6125 .30125 Mdot
.66423 .63283 Mdot
.70999 .45114 Mdot
.64915 .66244 Mdot
.48376 .32641 Mdot
.65579 .38322 Mdot
.47375 .3179 Mdot
.44342 .3027 Mdot
.31354 .57545 Mdot
.28492 .60011 Mdot
.43994 .34742 Mdot
.65002 .33365 Mdot
.66265 .63123 Mdot
.70311 .53735 Mdot
.36928 .49031 Mdot
.56778 .70869 Mdot
.69906 .52628 Mdot
.34486 .3562 Mdot
.33138 .35647 Mdot
.56393 .70009 Mdot
.34775 .47242 Mdot
.72563 .43544 Mdot
.71849 .53897 Mdot
.30952 .56503 Mdot
.57428 .70593 Mdot
.36773 .34965 Mdot
.71902 .53487 Mdot
.47566 .27938 Mdot
.46292 .71993 Mdot
.24795 .6109 Mdot
.72862 .55475 Mdot
.30449 .57686 Mdot
.47453 .35394 Mdot
.3441 .31541 Mdot
.70303 .5226 Mdot
.33847 .50083 Mdot
.64808 .6493 Mdot
.5705 .70347 Mdot
.37863 .69734 Mdot
.47697 .29733 Mdot
.31445 .54908 Mdot
.43894 .33497 Mdot
.44961 .29804 Mdot
.36091 .52454 Mdot
.59242 .68245 Mdot
.53548 .68656 Mdot
.29892 .54916 Mdot
.67414 .37157 Mdot
.37846 .33769 Mdot
.71079 .43551 Mdot
.28347 .58814 Mdot
.29882 .57892 Mdot
.38222 .6905 Mdot
.71764 .54581 Mdot
.71146 .48229 Mdot
.58551 .28791 Mdot
.73356 .46141 Mdot
.70387 .47065 Mdot
.63437 .33382 Mdot
.37224 .67952 Mdot
.33459 .33502 Mdot
.45201 .30822 Mdot
.30289 .54889 Mdot
.28064 .60822 Mdot
.35733 .65961 Mdot
.44142 .35841 Mdot
.48793 .34625 Mdot
.6331 .63034 Mdot
.70032 .43749 Mdot
.33628 .51069 Mdot
.44504 .72695 Mdot
.29745 .59642 Mdot
.71588 .49921 Mdot
.70602 .54143 Mdot
.62884 .37844 Mdot
.64125 .38716 Mdot
.59139 .28177 Mdot
.38658 .70639 Mdot
.39156 .69262 Mdot
.34309 .50691 Mdot
.46056 .32353 Mdot
.49471 .6912 Mdot
.34742 .31473 Mdot
.65127 .65693 Mdot
.73218 .54983 Mdot
.269 .55971 Mdot
.44214 .69921 Mdot
.6808 .37543 Mdot
.65565 .30775 Mdot
.43667 .31483 Mdot
.35226 .32462 Mdot
.3067 .55349 Mdot
.66754 .66972 Mdot
.30556 .57683 Mdot
.48264 .31343 Mdot
.35673 .37106 Mdot
.66612 .64304 Mdot
.27098 .56437 Mdot
.69522 .53581 Mdot
.64925 .31529 Mdot
.32757 .5231 Mdot
.36143 .50489 Mdot
.54993 .69632 Mdot
.36074 .48181 Mdot
.43789 .7177 Mdot
.46391 .71131 Mdot
.58634 .27946 Mdot
.72259 .46937 Mdot
.70012 .50859 Mdot
.58379 .26311 Mdot
.55456 .70257 Mdot
.66365 .68474 Mdot
.64717 .34788 Mdot
.42941 .35862 Mdot
.72074 .43828 Mdot
.35694 .34408 Mdot
.65094 .3433 Mdot
.37534 .33665 Mdot
.35188 .67324 Mdot
.64941 .32585 Mdot
.34011 .34777 Mdot
.3132 .64709 Mdot
.44685 .30231 Mdot
.33171 .36591 Mdot
.69197 .55147 Mdot
.64662 .62909 Mdot
.30689 .54663 Mdot
.44949 .3182 Mdot
.47698 .32184 Mdot
.37167 .68265 Mdot
.42811 .31704 Mdot
.47267 .30006 Mdot
.37452 .68503 Mdot
.37778 .32364 Mdot
.72821 .51853 Mdot
.47066 .71009 Mdot
.65176 .66113 Mdot
.3566 .48364 Mdot
.71745 .47511 Mdot
.69977 .52482 Mdot
.33083 .54434 Mdot
.72245 .57102 Mdot
.69129 .55434 Mdot
.35413 .53126 Mdot
.70782 .51199 Mdot
.56559 .71071 Mdot
.27301 .55644 Mdot
.5705 .69413 Mdot
.35831 .5305 Mdot
.709 .51113 Mdot
.59081 .26831 Mdot
.5445 .70254 Mdot
.35443 .51245 Mdot
.34859 .49712 Mdot
.4581 .32261 Mdot
.46528 .71423 Mdot
.69131 .58013 Mdot
.36811 .66905 Mdot
.62775 .33123 Mdot
.3716 .70313 Mdot
.32896 .31692 Mdot
.47528 .27851 Mdot
.57476 .70506 Mdot
.4289 .31432 Mdot
.65318 .35212 Mdot
.30456 .56751 Mdot
.26059 .57374 Mdot
.27633 .58382 Mdot
.47076 .30159 Mdot
.34948 .68974 Mdot
.68714 .55909 Mdot
.45089 .72351 Mdot
.43565 .34513 Mdot
.63717 .35832 Mdot
.44787 .33191 Mdot
.27955 .59683 Mdot
.67254 .65075 Mdot
.45574 .69638 Mdot
.63691 .32462 Mdot
.66568 .65594 Mdot
.2868 .55484 Mdot
.72948 .46047 Mdot
.33115 .30924 Mdot
.68538 .55679 Mdot
.45647 .70151 Mdot
.37324 .70184 Mdot
.5751 .2665 Mdot
.54944 .70673 Mdot
.70815 .52441 Mdot
.56705 .69487 Mdot
.3127 .56044 Mdot
.31977 .52769 Mdot
.57887 .7016 Mdot
.32439 .34002 Mdot
.60031 .29656 Mdot
.72322 .44393 Mdot
.46939 .31826 Mdot
.56502 .26977 Mdot
.64309 .66781 Mdot
.65392 .34015 Mdot
.34108 .47257 Mdot
.64463 .31343 Mdot
.45256 .69634 Mdot
.56672 .26686 Mdot
.38518 .694 Mdot
.27277 .59044 Mdot
.62254 .35107 Mdot
.47203 .29255 Mdot
.30875 .55712 Mdot
.56403 .70988 Mdot
.29581 .61035 Mdot
.35381 .54353 Mdot
.38621 .70488 Mdot
.63669 .35632 Mdot
.34474 .47351 Mdot
.46181 .70694 Mdot
.45235 .70287 Mdot
.65261 .65166 Mdot
.46471 .31306 Mdot
.34515 .36062 Mdot
.33124 .36222 Mdot
.44791 .27881 Mdot
.34458 .65392 Mdot
.33052 .49436 Mdot
.55955 .70506 Mdot
.59591 .27895 Mdot
.63738 .63748 Mdot
.48323 .31199 Mdot
.71261 .53199 Mdot
.71145 .4847 Mdot
.32948 .51626 Mdot
.33174 .30195 Mdot
.4375 .69748 Mdot
.63756 .65831 Mdot
.56095 .69467 Mdot
.70934 .52521 Mdot
.34796 .69858 Mdot
.38013 .50145 Mdot
.33002 .54176 Mdot
.71502 .53761 Mdot
.47904 .31665 Mdot
.35708 .67854 Mdot
.25366 .61613 Mdot
.69385 .49011 Mdot
.28349 .57612 Mdot
.57512 .67602 Mdot
.27214 .57987 Mdot
.31431 .57072 Mdot
.28603 .5668 Mdot
.55929 .70838 Mdot
.41862 .71067 Mdot
.25173 .60449 Mdot
.68202 .35372 Mdot
.26367 .56437 Mdot
.32696 .34115 Mdot
.35797 .50576 Mdot
.30569 .55108 Mdot
.36256 .35316 Mdot
.66784 .67218 Mdot
.29655 .57981 Mdot
.72803 .52675 Mdot
.35362 .51622 Mdot
.71036 .43476 Mdot
.36096 .69041 Mdot
.30749 .59369 Mdot
.45888 .70811 Mdot
.67054 .65496 Mdot
.71423 .5179 Mdot
.706 .44145 Mdot
.42988 .33472 Mdot
.70008 .52427 Mdot
.27975 .58832 Mdot
.35832 .68987 Mdot
.67157 .67095 Mdot
.44952 .30085 Mdot
.67637 .63346 Mdot
.30102 .31029 Mdot
.69563 .55459 Mdot
.445 .32655 Mdot
.37512 .71006 Mdot
.70351 .5575 Mdot
.72588 .51866 Mdot
.46923 .71464 Mdot
.47845 .31752 Mdot
.6489 .67362 Mdot
.57066 .26643 Mdot
.47874 .30643 Mdot
.70316 .52494 Mdot
.27523 .57927 Mdot
.45178 .71779 Mdot
.70808 .51975 Mdot
.56702 .67827 Mdot
.46924 .71976 Mdot
.35488 .51786 Mdot
.53849 .70348 Mdot
.67483 .62409 Mdot
.31239 .54185 Mdot
.33111 .52607 Mdot
.6496 .36251 Mdot
.47347 .30441 Mdot
.4717 .30542 Mdot
.44569 .29902 Mdot
.63785 .31853 Mdot
.59294 .29568 Mdot
.71777 .46875 Mdot
.31005 .59021 Mdot
.72617 .47213 Mdot
.4462 .32056 Mdot
.65135 .36309 Mdot
.2726 .58237 Mdot
.34123 .68891 Mdot
.71621 .51434 Mdot
.58549 .2963 Mdot
.33701 .49757 Mdot
.64557 .65443 Mdot
.70595 .56262 Mdot
.38521 .68258 Mdot
.58779 .27494 Mdot
.34928 .31116 Mdot
.3423 .47928 Mdot
.71023 .55477 Mdot
.55009 .68164 Mdot
.71051 .55381 Mdot
.302 .55222 Mdot
.29154 .5805 Mdot
.64518 .63499 Mdot
.32656 .33983 Mdot
.37084 .67278 Mdot
.3526 .53584 Mdot
.59964 .28335 Mdot
.63551 .64127 Mdot
.32728 .36 Mdot
.35485 .669 Mdot
.43492 .3115 Mdot
.37787 .31927 Mdot
.3461 .50598 Mdot
.37833 .68821 Mdot
.45348 .34335 Mdot
.70015 .51681 Mdot
.32728 .34766 Mdot
.68201 .36943 Mdot
.66504 .65132 Mdot
.71993 .47052 Mdot
.42371 .31989 Mdot
.72084 .44333 Mdot
.32997 .64969 Mdot
.43849 .3231 Mdot
.703 .48771 Mdot
.29238 .37517 Mdot
.46366 .29791 Mdot
.63362 .35963 Mdot
.31187 .55928 Mdot
.37563 .68108 Mdot
.35559 .51792 Mdot
.34264 .35993 Mdot
.66525 .62401 Mdot
.7002 .46024 Mdot
.70621 .50235 Mdot
.3653 .51381 Mdot
.57561 .70461 Mdot
.66195 .60679 Mdot
.45456 .3298 Mdot
.34711 .33759 Mdot
.35373 .34449 Mdot
.36663 .50623 Mdot
.34459 .68522 Mdot
.55669 .70662 Mdot
.35492 .51204 Mdot
.3672 .50564 Mdot
.57625 .27929 Mdot
.53703 .70758 Mdot
.64638 .32619 Mdot
.4381 .70232 Mdot
.33421 .49329 Mdot
.72782 .46502 Mdot
.69159 .53557 Mdot
.46862 .31075 Mdot
.70002 .50843 Mdot
.58157 .28732 Mdot
.47147 .30497 Mdot
.35419 .51181 Mdot
.65965 .67765 Mdot
.35597 .51189 Mdot
.35462 .51527 Mdot
.28174 .56979 Mdot
.32997 .49604 Mdot
.67052 .32179 Mdot
.34298 .33345 Mdot
.35302 .67146 Mdot
.6321 .33178 Mdot
.67758 .38007 Mdot
.29911 .58396 Mdot
.35112 .50623 Mdot
.34981 .52848 Mdot
.54287 .6926 Mdot
.45383 .72195 Mdot
.70512 .55179 Mdot
.645 .63485 Mdot
.32838 .52328 Mdot
.57855 .26143 Mdot
.29698 .57761 Mdot
.5788 .69935 Mdot
.70992 .47074 Mdot
.7073 .59244 Mdot
.42303 .3266 Mdot
.46922 .32853 Mdot
.47258 .30114 Mdot
.44762 .29684 Mdot
.70966 .43066 Mdot
.65245 .36397 Mdot
.32381 .3175 Mdot
.32235 .51649 Mdot
.3334 .51837 Mdot
.28945 .58491 Mdot
.56945 .27669 Mdot
.48764 .31698 Mdot
.31472 .55763 Mdot
.48857 .70943 Mdot
.66009 .32513 Mdot
.46022 .29365 Mdot
.60658 .66327 Mdot
.67059 .64716 Mdot
.58334 .27277 Mdot
.72514 .43749 Mdot
.33818 .34982 Mdot
.53443 .28785 Mdot
.67369 .62961 Mdot
.50398 .69161 Mdot
.66463 .33416 Mdot
.3573 .68728 Mdot
.45078 .68618 Mdot
.6584 .34301 Mdot
.45076 .72476 Mdot
.67542 .61734 Mdot
.44631 .30177 Mdot
.36035 .69632 Mdot
.37114 .68534 Mdot
.63805 .38971 Mdot
.35354 .49359 Mdot
.64624 .30611 Mdot
.63588 .35945 Mdot
.46269 .30818 Mdot
.63697 .35622 Mdot
.68673 .55485 Mdot
.64158 .33675 Mdot
.5595 .68062 Mdot
.36794 .49908 Mdot
.54916 .72563 Mdot
.28216 .64373 Mdot
.32716 .5383 Mdot
.69524 .5661 Mdot
.71689 .47311 Mdot
.33528 .53157 Mdot
.37131 .34923 Mdot
.63834 .36361 Mdot
.59172 .28706 Mdot
.44585 .71712 Mdot
.56811 .27033 Mdot
.67181 .65356 Mdot
.72362 .46597 Mdot
.71724 .47335 Mdot
.47643 .30441 Mdot
.57221 .7079 Mdot
.704 .42879 Mdot
.70985 .45243 Mdot
.32969 .30952 Mdot
.31051 .54387 Mdot
.55825 .67372 Mdot
.35749 .67891 Mdot
.37706 .33464 Mdot
.35197 .51749 Mdot
.64402 .32723 Mdot
.58845 .28409 Mdot
.28837 .64325 Mdot
.64707 .35041 Mdot
.46951 .3137 Mdot
.5331 .69415 Mdot
.44007 .70905 Mdot
.66638 .62773 Mdot
.36522 .48538 Mdot
.72164 .47126 Mdot
.67045 .65054 Mdot
.43382 .359 Mdot
.34115 .53926 Mdot
.59097 .68998 Mdot
.35297 .66603 Mdot
.35375 .51874 Mdot
.65153 .38086 Mdot
.36423 .3523 Mdot
.41858 .34788 Mdot
.67581 .33661 Mdot
.36 .32074 Mdot
.62675 .67276 Mdot
.65206 .38267 Mdot
.36131 .33345 Mdot
.45389 .27675 Mdot
.43155 .30939 Mdot
.34908 .33045 Mdot
.27865 .59289 Mdot
.70181 .52108 Mdot
.65464 .62581 Mdot
.29482 .56844 Mdot
.3589 .44607 Mdot
.5377 .72466 Mdot
.45706 .32531 Mdot
.35379 .52226 Mdot
.31173 .54856 Mdot
.57558 .70078 Mdot
.73317 .54151 Mdot
.62764 .35087 Mdot
.46697 .32482 Mdot
.66941 .63009 Mdot
.73098 .55454 Mdot
.65394 .37914 Mdot
.36204 .34322 Mdot
.6924 .52635 Mdot
.65852 .6788 Mdot
.45327 .32261 Mdot
.69245 .55024 Mdot
.67254 .32984 Mdot
.30242 .58281 Mdot
.48291 .71395 Mdot
.6673 .34372 Mdot
.30331 .58153 Mdot
.44162 .69746 Mdot
.59117 .28039 Mdot
.71708 .49577 Mdot
.67385 .63822 Mdot
.71392 .52394 Mdot
.34857 .34258 Mdot
.5654 .69353 Mdot
.67601 .63356 Mdot
.6913 .5357 Mdot
.52695 .71937 Mdot
.35218 .69494 Mdot
.72286 .45946 Mdot
.34883 .6794 Mdot
.30792 .56639 Mdot
.45391 .32012 Mdot
.33726 .33434 Mdot
.72326 .4682 Mdot
.53994 .69923 Mdot
.67855 .55546 Mdot
.2901 .6028 Mdot
.45947 .72316 Mdot
.33352 .34769 Mdot
.62707 .64014 Mdot
.71712 .49388 Mdot
.70316 .55292 Mdot
.59902 .28269 Mdot
.36624 .35546 Mdot
.27503 .59213 Mdot
.56198 .27785 Mdot
.28543 .5838 Mdot
.70777 .56391 Mdot
.43572 .69887 Mdot
.66164 .64886 Mdot
.72518 .45428 Mdot
.44975 .69564 Mdot
.36378 .66755 Mdot
.33304 .5262 Mdot
.58502 .27929 Mdot
.67653 .61314 Mdot
.49093 .29755 Mdot
.32464 .54114 Mdot
.34627 .5404 Mdot
.47722 .32342 Mdot
.31043 .58792 Mdot
.72136 .50546 Mdot
.48032 .30166 Mdot
.66065 .32785 Mdot
.45396 .29822 Mdot
.46692 .31775 Mdot
.66012 .66958 Mdot
.59324 .27864 Mdot
.47309 .32657 Mdot
.33629 .54636 Mdot
.36082 .51698 Mdot
.71378 .51489 Mdot
.353 .69258 Mdot
.36636 .68293 Mdot
.62696 .33354 Mdot
.3262 .30947 Mdot
.30348 .56096 Mdot
.56665 .71114 Mdot
.33334 .35942 Mdot
.44209 .33833 Mdot
.66166 .65693 Mdot
.28103 .59988 Mdot
.57558 .27929 Mdot
.4547 .29998 Mdot
.46051 .33744 Mdot
.33656 .34691 Mdot
.71818 .54544 Mdot
.58271 .68944 Mdot
.63531 .35994 Mdot
.47894 .70941 Mdot
.31493 .30415 Mdot
.57942 .27322 Mdot
.45502 .31903 Mdot
.43555 .32185 Mdot
.57267 .7056 Mdot
.56509 .68004 Mdot
.41749 .3346 Mdot
.63091 .33163 Mdot
.69739 .4451 Mdot
.72121 .44906 Mdot
.37671 .69823 Mdot
.68938 .52945 Mdot
.67403 .63924 Mdot
.31087 .58103 Mdot
.35656 .3426 Mdot
.70135 .55786 Mdot
.47588 .30174 Mdot
.67239 .63519 Mdot
.56816 .6844 Mdot
.35473 .53581 Mdot
.34825 .51498 Mdot
.58624 .26472 Mdot
.28581 .60829 Mdot
.71878 .52143 Mdot
.34898 .35857 Mdot
.65117 .36929 Mdot
.44782 .71698 Mdot
.64788 .65095 Mdot
.51724 .31981 Mdot
.35533 .66176 Mdot
.6307 .34032 Mdot
.65895 .62619 Mdot
.33977 .36418 Mdot
.34464 .333 Mdot
.31885 .54068 Mdot
.48219 .35113 Mdot
.69378 .55985 Mdot
.56608 .70827 Mdot
.6261 .6663 Mdot
.36201 .67242 Mdot
.35143 .50825 Mdot
.44321 .72013 Mdot
.70111 .43976 Mdot
.28035 .59144 Mdot
.33668 .35387 Mdot
.6768 .61621 Mdot
.27267 .58657 Mdot
.35293 .36731 Mdot
.49123 .29837 Mdot
.43736 .31747 Mdot
.62343 .35723 Mdot
.34985 .36471 Mdot
.35702 .36324 Mdot
.3491 .37032 Mdot
.71131 .48489 Mdot
.38227 .67885 Mdot
.30678 .30767 Mdot
.35298 .49441 Mdot
.31075 .56304 Mdot
.48056 .71737 Mdot
.7314 .46578 Mdot
.57786 .26684 Mdot
.30543 .55288 Mdot
.3494 .49701 Mdot
.66962 .61016 Mdot
.47721 .70189 Mdot
.29222 .55376 Mdot
.65689 .65553 Mdot
.56136 .67023 Mdot
.63321 .37835 Mdot
.72452 .56291 Mdot
.5581 .26956 Mdot
.34925 .66935 Mdot
.34512 .6701 Mdot
.68132 .64533 Mdot
.69664 .52287 Mdot
.34622 .6719 Mdot
.71703 .54923 Mdot
.68104 .62544 Mdot
.48609 .71343 Mdot
.56502 .67867 Mdot
.357 .31323 Mdot
.2989 .55347 Mdot
.6896 .54249 Mdot
.30527 .55184 Mdot
.69011 .53562 Mdot
.36881 .45949 Mdot
.34291 .67703 Mdot
.33883 .502 Mdot
.27392 .59973 Mdot
.45311 .3587 Mdot
.34889 .51069 Mdot
.60401 .29216 Mdot
.64984 .64445 Mdot
.35083 .3036 Mdot
.47404 .72934 Mdot
.30919 .56032 Mdot
.3503 .52607 Mdot
.53478 .72376 Mdot
.34389 .52766 Mdot
.56039 .2718 Mdot
.35065 .66538 Mdot
.29672 .55141 Mdot
.70744 .5385 Mdot
.71411 .44243 Mdot
.67154 .67139 Mdot
.437 .32381 Mdot
.63181 .63257 Mdot
.35558 .52911 Mdot
.63184 .36686 Mdot
.39569 .33773 Mdot
.35724 .36095 Mdot
.65519 .627 Mdot
.30111 .3858 Mdot
.70746 .43117 Mdot
.67381 .37826 Mdot
.47234 .71118 Mdot
.65238 .32513 Mdot
.62538 .34344 Mdot
.63465 .64199 Mdot
.33828 .3343 Mdot
.30104 .56517 Mdot
.58476 .67576 Mdot
.52763 .68496 Mdot
.36396 .67297 Mdot
.6386 .37979 Mdot
.45551 .34285 Mdot
.42354 .72714 Mdot
.37048 .32447 Mdot
.36084 .32584 Mdot
.69419 .53515 Mdot
.62993 .36537 Mdot
.46705 .32319 Mdot
.36086 .33654 Mdot
.63463 .38131 Mdot
.42753 .31298 Mdot
.59835 .28842 Mdot
.56034 .70629 Mdot
.33409 .48346 Mdot
.59496 .68498 Mdot
.703 .5041 Mdot
.59414 .276 Mdot
.55084 .70149 Mdot
.57467 .70938 Mdot
.46277 .32092 Mdot
.67696 .35301 Mdot
.5293 .71545 Mdot
.3093 .54659 Mdot
.44012 .30938 Mdot
.36149 .53091 Mdot
.37147 .35217 Mdot
.35851 .521 Mdot
.58512 .26553 Mdot
.70791 .55211 Mdot
.64511 .36029 Mdot
.69263 .53884 Mdot
.30552 .59847 Mdot
.34103 .54166 Mdot
.35556 .50657 Mdot
.36179 .69005 Mdot
.67005 .66473 Mdot
.57745 .67422 Mdot
.63183 .34688 Mdot
.64185 .35977 Mdot
.4765 .72745 Mdot
.64451 .66003 Mdot
.48124 .28203 Mdot
.34739 .67538 Mdot
.34182 .52621 Mdot
.65064 .64503 Mdot
.4768 .7212 Mdot
.70067 .42973 Mdot
.36172 .69413 Mdot
.66861 .66263 Mdot
.58948 .29479 Mdot
.36778 .50539 Mdot
.4609 .33173 Mdot
.44358 .34731 Mdot
.34701 .65361 Mdot
.37735 .33662 Mdot
.66646 .64609 Mdot
.44869 .33486 Mdot
.64727 .64389 Mdot
.64159 .31437 Mdot
.70665 .42696 Mdot
.65673 .65043 Mdot
.34716 .52937 Mdot
.56154 .2802 Mdot
.69844 .52322 Mdot
.27993 .56899 Mdot
.72219 .45576 Mdot
.55735 .69629 Mdot
.65873 .63438 Mdot
.42727 .31328 Mdot
.45203 .72466 Mdot
.69667 .55997 Mdot
.33365 .514 Mdot
.56273 .6782 Mdot
.45722 .69608 Mdot
.37709 .33259 Mdot
.29549 .57574 Mdot
.31624 .53437 Mdot
.60596 .30069 Mdot
.29494 .59544 Mdot
.70568 .47457 Mdot
.71345 .4326 Mdot
.69979 .46032 Mdot
.66016 .67259 Mdot
.42168 .34734 Mdot
.57725 .68477 Mdot
.47082 .3113 Mdot
.6764 .35975 Mdot
.28338 .56679 Mdot
.45142 .29473 Mdot
.71993 .46865 Mdot
.345 .32731 Mdot
.35697 .65968 Mdot
.669 .35348 Mdot
.43065 .32116 Mdot
.69849 .55439 Mdot
.53719 .6917 Mdot
.66186 .65338 Mdot
.59571 .29258 Mdot
.27213 .58175 Mdot
.35008 .51419 Mdot
.71327 .46643 Mdot
.49319 .34441 Mdot
.36167 .32315 Mdot
.47208 .29273 Mdot
.71598 .46519 Mdot
.35737 .69282 Mdot
.55346 .69427 Mdot
.3025 .55093 Mdot
.3541 .6888 Mdot
.70939 .48074 Mdot
.54534 .67288 Mdot
.35603 .31785 Mdot
.33979 .48754 Mdot
.66639 .64397 Mdot
.70307 .53538 Mdot
.46323 .27573 Mdot
.43527 .70915 Mdot
.33932 .50787 Mdot
.27392 .55764 Mdot
.37643 .6912 Mdot
.47105 .70617 Mdot
.42328 .32461 Mdot
.28629 .55036 Mdot
.47373 .72896 Mdot
.4773 .70471 Mdot
.29272 .58231 Mdot
.2926 .58537 Mdot
.65361 .64165 Mdot
.38667 .70387 Mdot
.64681 .33045 Mdot
.44797 .72505 Mdot
.515 .32304 Mdot
.46812 .70943 Mdot
.3752 .70214 Mdot
.56267 .66608 Mdot
.33743 .65068 Mdot
.68184 .61948 Mdot
.64546 .66853 Mdot
.7022 .50506 Mdot
.45248 .69696 Mdot
.63027 .34036 Mdot
.45426 .34106 Mdot
.57756 .2691 Mdot
.65252 .64061 Mdot
.63828 .38297 Mdot
.73587 .45178 Mdot
.66752 .34408 Mdot
.65662 .32365 Mdot
.70789 .55433 Mdot
.65376 .62438 Mdot
.35516 .66305 Mdot
.70625 .55799 Mdot
.47057 .33172 Mdot
.36072 .34233 Mdot
.52829 .68555 Mdot
.47825 .29601 Mdot
.33522 .49942 Mdot
.69748 .49033 Mdot
.67304 .3557 Mdot
.26876 .56106 Mdot
.63636 .65858 Mdot
.33412 .36554 Mdot
.65819 .64701 Mdot
.42 .32472 Mdot
.34464 .31385 Mdot
.27636 .59536 Mdot
.51315 .32538 Mdot
.71707 .49808 Mdot
.30061 .5683 Mdot
.57071 .66784 Mdot
.5786 .26942 Mdot
.6872 .56136 Mdot
.72535 .51983 Mdot
.46295 .32949 Mdot
.66486 .66284 Mdot
.57313 .67997 Mdot
.46995 .30691 Mdot
.70323 .53822 Mdot
.55416 .72445 Mdot
.31682 .54394 Mdot
.69002 .52508 Mdot
.30003 .56474 Mdot
.34851 .47232 Mdot
.32362 .34892 Mdot
.44568 .29953 Mdot
.48134 .70458 Mdot
.66114 .3786 Mdot
.48024 .72431 Mdot
.35602 .47942 Mdot
.28639 .61043 Mdot
.33943 .51404 Mdot
.26597 .56474 Mdot
.57827 .2868 Mdot
.67868 .66165 Mdot
.44624 .31031 Mdot
.45615 .32146 Mdot
.45884 .69484 Mdot
.55026 .26549 Mdot
.35432 .32785 Mdot
.59971 .29292 Mdot
.34519 .53936 Mdot
.34313 .51897 Mdot
.55866 .68759 Mdot
.34765 .46912 Mdot
.44976 .29897 Mdot
.33732 .51717 Mdot
.34191 .65441 Mdot
.70795 .53201 Mdot
.31474 .53644 Mdot
.3668 .50763 Mdot
.70388 .42819 Mdot
.70613 .53678 Mdot
.58027 .27808 Mdot
.43235 .30762 Mdot
.62227 .35329 Mdot
.3668 .32373 Mdot
.27661 .55738 Mdot
.30867 .58866 Mdot
.36349 .69978 Mdot
.36555 .31881 Mdot
.4631 .7087 Mdot
.3626 .47401 Mdot
.36258 .49163 Mdot
.35978 .32608 Mdot
.69957 .51562 Mdot
.65233 .64748 Mdot
.34581 .47367 Mdot
.45791 .32055 Mdot
.47512 .70431 Mdot
.3592 .36541 Mdot
.64785 .64229 Mdot
.59275 .68129 Mdot
.66074 .62704 Mdot
.70042 .5507 Mdot
.58933 .27587 Mdot
.34381 .31354 Mdot
.65844 .64775 Mdot
.65793 .38504 Mdot
.72571 .46543 Mdot
.38211 .69634 Mdot
.70662 .50451 Mdot
.63504 .64124 Mdot
.65886 .66823 Mdot
.6368 .67 Mdot
.44173 .71477 Mdot
.26409 .56645 Mdot
.4711 .31404 Mdot
.71594 .46654 Mdot
.66434 .37623 Mdot
.29185 .60444 Mdot
.59067 .67376 Mdot
.24943 .59196 Mdot
.27655 .59763 Mdot
.35905 .52114 Mdot
.36004 .49916 Mdot
.4233 .33076 Mdot
.336 .50343 Mdot
.35435 .49475 Mdot
.71956 .52275 Mdot
.57973 .27503 Mdot
.34089 .54272 Mdot
.4385 .31688 Mdot
.32947 .30223 Mdot
.33306 .36516 Mdot
.33797 .48571 Mdot
.49122 .69003 Mdot
.65152 .65225 Mdot
.63454 .3281 Mdot
.63075 .37172 Mdot
.34045 .35814 Mdot
.71302 .53152 Mdot
.66885 .62252 Mdot
.58754 .29645 Mdot
.33943 .31397 Mdot
.28865 .56816 Mdot
.36335 .69015 Mdot
.33658 .6506 Mdot
.37813 .68499 Mdot
.28315 .56827 Mdot
.4701 .29637 Mdot
.63347 .32631 Mdot
.38613 .69103 Mdot
.59007 .69419 Mdot
.36382 .35831 Mdot
.36112 .34834 Mdot
.52979 .70009 Mdot
.35712 .48058 Mdot
.68951 .54731 Mdot
.345 .68429 Mdot
.69153 .58053 Mdot
.66156 .6083 Mdot
.30264 .30968 Mdot
.29699 .57808 Mdot
.29976 .57848 Mdot
.32989 .51548 Mdot
.52816 .7038 Mdot
.55944 .6761 Mdot
.54067 .69796 Mdot
.70876 .53029 Mdot
.30452 .57095 Mdot
.70507 .44864 Mdot
.44753 .30004 Mdot
.66947 .64983 Mdot
.39983 .70037 Mdot
.64238 .3595 Mdot
.48151 .70697 Mdot
.332 .33539 Mdot
.36364 .67669 Mdot
.44412 .31736 Mdot
.31928 .52713 Mdot
.65265 .36277 Mdot
.55114 .69709 Mdot
.48369 .71101 Mdot
.67473 .32904 Mdot
.28542 .55124 Mdot
.46346 .34464 Mdot
.45964 .29166 Mdot
.35518 .3132 Mdot
.30122 .5738 Mdot
.32885 .34341 Mdot
.69696 .55878 Mdot
.33689 .54321 Mdot
.29937 .54998 Mdot
.35089 .52244 Mdot
.28238 .59299 Mdot
.70534 .52535 Mdot
.45071 .69943 Mdot
.47894 .32819 Mdot
.43864 .30204 Mdot
.46937 .7083 Mdot
.33863 .32981 Mdot
.72004 .44881 Mdot
.57815 .27635 Mdot
.48188 .3107 Mdot
.34696 .30954 Mdot
.30222 .56564 Mdot
.3391 .52901 Mdot
.43509 .30737 Mdot
.2787 .5935 Mdot
.44491 .70904 Mdot
.66009 .33489 Mdot
.46279 .69863 Mdot
.34347 .36736 Mdot
.33158 .33939 Mdot
.70302 .52103 Mdot
.65834 .64944 Mdot
.34382 .35572 Mdot
.65594 .36786 Mdot
.31917 .53512 Mdot
.29471 .57883 Mdot
.56184 .67996 Mdot
.28114 .60805 Mdot
.34476 .36754 Mdot
.27586 .5927 Mdot
.54099 .7103 Mdot
.52726 .71759 Mdot
.34013 .50687 Mdot
.45046 .71086 Mdot
.65586 .67108 Mdot
.3611 .33953 Mdot
.71489 .53371 Mdot
.26786 .63547 Mdot
.71697 .54766 Mdot
.53944 .69937 Mdot
.45486 .33297 Mdot
.6473 .62937 Mdot
.45617 .33336 Mdot
.54682 .66852 Mdot
.36768 .50248 Mdot
.55563 .68052 Mdot
.47767 .33259 Mdot
.63069 .34676 Mdot
.67366 .33985 Mdot
.45353 .30113 Mdot
.6676 .64807 Mdot
.46705 .31115 Mdot
.34454 .3487 Mdot
.71797 .48221 Mdot
.64487 .66988 Mdot
.65933 .3252 Mdot
.67246 .35566 Mdot
.71267 .46783 Mdot
.35558 .5224 Mdot
.30641 .54944 Mdot
.66585 .34477 Mdot
.69076 .58003 Mdot
.67946 .64482 Mdot
.35104 .5129 Mdot
.48183 .30522 Mdot
.65133 .33138 Mdot
.72812 .42879 Mdot
.5633 .68928 Mdot
.48596 .71045 Mdot
.28745 .61029 Mdot
.71077 .43313 Mdot
.31302 .53927 Mdot
.44751 .71249 Mdot
.36777 .33683 Mdot
.32901 .50567 Mdot
.31278 .56204 Mdot
.71189 .43683 Mdot
.47151 .32566 Mdot
.37752 .68297 Mdot
.65942 .31348 Mdot
.30293 .54596 Mdot
.28334 .35812 Mdot
.43668 .30606 Mdot
.29023 .57011 Mdot
.49026 .31093 Mdot
.66561 .62862 Mdot
.34847 .51956 Mdot
.72717 .46505 Mdot
.63271 .33912 Mdot
.2723 .58168 Mdot
.4341 .35971 Mdot
.72663 .45429 Mdot
.44366 .31891 Mdot
.35974 .32126 Mdot
.47215 .71884 Mdot
.29807 .60836 Mdot
.56955 .27709 Mdot
.34871 .33324 Mdot
.35343 .52629 Mdot
.64794 .36899 Mdot
.71695 .44221 Mdot
.44868 .30648 Mdot
.30616 .5615 Mdot
.7132 .45121 Mdot
.71084 .54 Mdot
.32893 .33943 Mdot
.6739 .68156 Mdot
.37136 .50084 Mdot
.36175 .52614 Mdot
.63478 .68266 Mdot
.56925 .68202 Mdot
.29683 .55474 Mdot
.34431 .54513 Mdot
.69159 .5501 Mdot
.24935 .60674 Mdot
.31753 .52939 Mdot
.47511 .33495 Mdot
.68665 .56192 Mdot
.62645 .36975 Mdot
.67512 .35884 Mdot
.35263 .33798 Mdot
.66317 .62277 Mdot
.32484 .34601 Mdot
.63725 .33663 Mdot
.31062 .55467 Mdot
.71222 .55676 Mdot
.49065 .72559 Mdot
.72142 .46061 Mdot
.66126 .36266 Mdot
.57749 .69701 Mdot
.35078 .69959 Mdot
.2844 .36073 Mdot
.69407 .58528 Mdot
.59326 .29122 Mdot
.3583 .35983 Mdot
.58999 .69441 Mdot
.34892 .53402 Mdot
.38473 .69987 Mdot
.27351 .58037 Mdot
.42368 .34684 Mdot
.57103 .27099 Mdot
.42753 .3129 Mdot
.46406 .32871 Mdot
.27098 .56274 Mdot
.7116 .53977 Mdot
.70563 .43923 Mdot
.43914 .33208 Mdot
.70252 .54785 Mdot
.35485 .53711 Mdot
.65942 .35382 Mdot
.592 .6616 Mdot
.34225 .52699 Mdot
.32448 .31391 Mdot
.73482 .44577 Mdot
.57776 .70783 Mdot
.6299 .37364 Mdot
.29981 .57755 Mdot
.64183 .62039 Mdot
.70169 .55995 Mdot
.32953 .49829 Mdot
.63197 .34217 Mdot
.48183 .30973 Mdot
.64266 .36807 Mdot
.29504 .56268 Mdot
.29588 .58363 Mdot
.47559 .32544 Mdot
.34346 .5261 Mdot
.6857 .65553 Mdot
.43547 .71137 Mdot
.49258 .7145 Mdot
.35363 .49376 Mdot
.58462 .66654 Mdot
.72678 .44336 Mdot
.43984 .33323 Mdot
.37684 .69146 Mdot
.28246 .59972 Mdot
.65486 .67398 Mdot
.72137 .44744 Mdot
.73337 .53166 Mdot
.70645 .52862 Mdot
.62962 .3451 Mdot
.71306 .53418 Mdot
.32885 .51819 Mdot
.68219 .62944 Mdot
.6456 .34345 Mdot
.44768 .32203 Mdot
.66214 .38811 Mdot
.3257 .54044 Mdot
.73665 .44639 Mdot
.67502 .37191 Mdot
.44792 .72242 Mdot
.67903 .62504 Mdot
.50635 .33195 Mdot
.49199 .68893 Mdot
.31292 .55412 Mdot
.27508 .57785 Mdot
.47003 .29259 Mdot
.70429 .52182 Mdot
.56657 .68575 Mdot
.59933 .28712 Mdot
.33957 .36685 Mdot
.68204 .62032 Mdot
.33014 .35883 Mdot
.35782 .68715 Mdot
.59361 .66935 Mdot
.34213 .6548 Mdot
.6927 .5318 Mdot
.66424 .65171 Mdot
.3619 .36479 Mdot
.44461 .72662 Mdot
.33962 .33831 Mdot
.64029 .37819 Mdot
.34579 .67031 Mdot
.65897 .32889 Mdot
.7155 .47548 Mdot
.58761 .2815 Mdot
.69263 .562 Mdot
.43826 .35976 Mdot
.4352 .69938 Mdot
.71971 .43594 Mdot
.72736 .47077 Mdot
.64074 .32914 Mdot
.43649 .32698 Mdot
.45413 .69964 Mdot
.43533 .34073 Mdot
.43138 .33062 Mdot
.70723 .43542 Mdot
.66103 .65626 Mdot
.645 .65777 Mdot
.34696 .30335 Mdot
.65904 .65547 Mdot
.65529 .33924 Mdot
.36188 .693 Mdot
.37195 .71039 Mdot
.72794 .44369 Mdot
.47335 .71781 Mdot
.3293 .51053 Mdot
.56676 .26487 Mdot
.65815 .34714 Mdot
.71013 .53339 Mdot
.62601 .6609 Mdot
.44959 .33612 Mdot
.56575 .68979 Mdot
.67201 .63115 Mdot
.66378 .63224 Mdot
.64421 .63068 Mdot
.30291 .57999 Mdot
.69449 .56615 Mdot
.66773 .6433 Mdot
.30038 .56206 Mdot
.36746 .52054 Mdot
.47966 .30966 Mdot
.42491 .34794 Mdot
.44942 .70646 Mdot
.47111 .31603 Mdot
.33457 .52812 Mdot
.63725 .35624 Mdot
.42499 .35147 Mdot
.45752 .33626 Mdot
.63069 .33377 Mdot
.63068 .33119 Mdot
.4327 .33746 Mdot
.42395 .35043 Mdot
.68343 .65994 Mdot
.42364 .70615 Mdot
.57158 .66804 Mdot
.67699 .37089 Mdot
.70245 .47023 Mdot
.55902 .68002 Mdot
.27387 .57576 Mdot
.48319 .30048 Mdot
.65273 .35998 Mdot
.63983 .6682 Mdot
.35404 .50349 Mdot
.46273 .31874 Mdot
.34384 .34251 Mdot
.44533 .32325 Mdot
.47085 .29557 Mdot
.54669 .6787 Mdot
.68369 .51275 Mdot
.57564 .70328 Mdot
.66966 .32384 Mdot
.44832 .31458 Mdot
.53811 .72323 Mdot
.59316 .27281 Mdot
.71698 .48428 Mdot
.43409 .71128 Mdot
.35117 .49229 Mdot
.63539 .32723 Mdot
.67205 .65339 Mdot
.71347 .50828 Mdot
.33881 .65317 Mdot
.65931 .64811 Mdot
.42409 .31759 Mdot
.45985 .29732 Mdot
.64992 .3302 Mdot
.53688 .68965 Mdot
.44879 .71313 Mdot
.66297 .64136 Mdot
.71211 .46307 Mdot
.2719 .59454 Mdot
.63142 .6328 Mdot
.46689 .32206 Mdot
.64846 .65529 Mdot
.66399 .37413 Mdot
.33521 .35336 Mdot
.28183 .58829 Mdot
.7225 .57017 Mdot
.35148 .5269 Mdot
.71011 .46581 Mdot
.31758 .31279 Mdot
.467 .72707 Mdot
.28286 .57153 Mdot
.37952 .69778 Mdot
.73 .46784 Mdot
.28923 .56306 Mdot
.35321 .69938 Mdot
.59312 .68435 Mdot
.56411 .69885 Mdot
.34671 .53913 Mdot
.66291 .34224 Mdot
.64913 .30334 Mdot
.3665 .51317 Mdot
.67714 .33036 Mdot
.3429 .68278 Mdot
.45139 .34113 Mdot
.37866 .33099 Mdot
.31054 .58121 Mdot
.2821 .58069 Mdot
.33848 .50318 Mdot
.27133 .59547 Mdot
.33362 .65052 Mdot
.63461 .33849 Mdot
.62379 .35565 Mdot
.34869 .34758 Mdot
.28125 .55065 Mdot
.33233 .34262 Mdot
.71831 .44207 Mdot
.4445 .69733 Mdot
.45182 .29327 Mdot
.65527 .65362 Mdot
.34839 .52319 Mdot
.64563 .37704 Mdot
.28898 .57117 Mdot
.4595 .71775 Mdot
.65329 .33571 Mdot
.64805 .36104 Mdot
.64887 .30747 Mdot
.3513 .36642 Mdot
.65208 .63298 Mdot
.32625 .52983 Mdot
.37197 .34526 Mdot
.46507 .33439 Mdot
.27277 .64212 Mdot
.67907 .61772 Mdot
.64613 .64637 Mdot
.64163 .63973 Mdot
.33206 .51691 Mdot
.33069 .51995 Mdot
.70653 .45986 Mdot
.57705 .67793 Mdot
.7061 .56573 Mdot
.63949 .3236 Mdot
.66714 .3142 Mdot
.28555 .57651 Mdot
.33153 .31239 Mdot
.33751 .33137 Mdot
.67028 .38101 Mdot
.45704 .29392 Mdot
.32831 .34821 Mdot
.32897 .5281 Mdot
.64797 .32666 Mdot
.35837 .36452 Mdot
.63135 .64901 Mdot
.72989 .53576 Mdot
.33136 .35091 Mdot
.46775 .32513 Mdot
.5887 .6791 Mdot
.30397 .58964 Mdot
.32561 .35297 Mdot
.72363 .44149 Mdot
.35542 .66159 Mdot
.4518 .29606 Mdot
.33264 .31628 Mdot
.2512 .61076 Mdot
.64219 .338 Mdot
.46796 .3262 Mdot
.36536 .36303 Mdot
.37919 .71021 Mdot
.32606 .33632 Mdot
.64615 .6505 Mdot
.50105 .69997 Mdot
.27839 .58001 Mdot
.46191 .72386 Mdot
.70285 .50665 Mdot
.64161 .38025 Mdot
.63105 .36905 Mdot
.54741 .68524 Mdot
.37036 .69636 Mdot
.66588 .3389 Mdot
.37725 .69633 Mdot
.37517 .31637 Mdot
.30018 .56246 Mdot
.34631 .30255 Mdot
.45014 .72858 Mdot
.34898 .37316 Mdot
.33304 .35213 Mdot
.73251 .44913 Mdot
.70813 .55022 Mdot
.70266 .52393 Mdot
.66204 .33421 Mdot
.36191 .68374 Mdot
.62591 .35995 Mdot
.65911 .68628 Mdot
.35453 .32914 Mdot
.58568 .29436 Mdot
.3345 .50336 Mdot
.33419 .52534 Mdot
.48206 .71635 Mdot
.47849 .29935 Mdot
.30073 .55814 Mdot
.71082 .45416 Mdot
.65833 .38526 Mdot
.73748 .44966 Mdot
.53453 .69703 Mdot
.65108 .68675 Mdot
.64547 .35881 Mdot
.36887 .31093 Mdot
.33332 .33253 Mdot
.24901 .6155 Mdot
.44658 .34909 Mdot
.63348 .35889 Mdot
.36399 .48617 Mdot
.6437 .67067 Mdot
.59585 .29985 Mdot
.35048 .51951 Mdot
.67351 .35995 Mdot
.59628 .27288 Mdot
.45689 .72756 Mdot
.29502 .59465 Mdot
.7154 .4974 Mdot
.37364 .69317 Mdot
.34437 .37121 Mdot
.47755 .32405 Mdot
.4004 .69846 Mdot
.63726 .33471 Mdot
.65363 .38926 Mdot
.33617 .35991 Mdot
.57882 .70482 Mdot
.64277 .66369 Mdot
.68215 .66136 Mdot
.70908 .45745 Mdot
.36525 .49556 Mdot
.64712 .328 Mdot
.57429 .69153 Mdot
.3205 .52894 Mdot
.69412 .54394 Mdot
.66999 .3847 Mdot
.34364 .52589 Mdot
.28463 .57066 Mdot
.33518 .34496 Mdot
.32833 .30255 Mdot
.48316 .3241 Mdot
.71809 .4851 Mdot
.25464 .58644 Mdot
.44837 .69621 Mdot
.33991 .5066 Mdot
.67783 .65345 Mdot
.46842 .30819 Mdot
.33879 .33372 Mdot
.28992 .55399 Mdot
.37863 .70368 Mdot
.66174 .66642 Mdot
.69118 .53588 Mdot
.45158 .3181 Mdot
.25785 .57801 Mdot
.34686 .52676 Mdot
.27491 .58574 Mdot
.44196 .71498 Mdot
.34094 .49358 Mdot
.5763 .26716 Mdot
.56786 .71172 Mdot
.37141 .3341 Mdot
.65909 .63161 Mdot
.59563 .28131 Mdot
.43396 .70782 Mdot
.35387 .67494 Mdot
.59149 .66786 Mdot
.68004 .6232 Mdot
.71269 .46508 Mdot
.69779 .56505 Mdot
.33243 .30982 Mdot
.29374 .56857 Mdot
.43929 .30519 Mdot
.66677 .6374 Mdot
.64043 .37855 Mdot
.33143 .34235 Mdot
.59345 .29259 Mdot
.33994 .51149 Mdot
.64098 .33113 Mdot
.45399 .30344 Mdot
.53267 .69295 Mdot
.63616 .35279 Mdot
.48169 .30921 Mdot
.36299 .34233 Mdot
.36106 .66601 Mdot
.41557 .34281 Mdot
.45665 .3313 Mdot
.29143 .57413 Mdot
.46592 .73763 Mdot
.46843 .7213 Mdot
.46951 .33858 Mdot
.63171 .37884 Mdot
.46146 .32588 Mdot
.58064 .70692 Mdot
.4577 .7266 Mdot
.65991 .37961 Mdot
.56752 .67809 Mdot
.43519 .71309 Mdot
.45322 .33409 Mdot
.67729 .61665 Mdot
.5988 .28164 Mdot
.6308 .66948 Mdot
.31351 .56596 Mdot
.36305 .50348 Mdot
.66055 .32968 Mdot
.34064 .3399 Mdot
.70315 .44877 Mdot
.71476 .42866 Mdot
.72823 .46774 Mdot
.65319 .31787 Mdot
.34612 .52358 Mdot
.66555 .6474 Mdot
.70363 .55685 Mdot
.56216 .68571 Mdot
.6548 .37055 Mdot
.66211 .35017 Mdot
.48161 .71448 Mdot
.3309 .34037 Mdot
.33434 .5044 Mdot
.64018 .37777 Mdot
.5851 .27749 Mdot
.55451 .72482 Mdot
.34914 .37102 Mdot
.43903 .70577 Mdot
.41557 .3414 Mdot
.30291 .54311 Mdot
.59952 .67741 Mdot
.45262 .29964 Mdot
.53424 .69384 Mdot
.31544 .54929 Mdot
.69403 .41251 Mdot
.59187 .27197 Mdot
.37365 .69503 Mdot
.71716 .49702 Mdot
.70514 .56119 Mdot
.63599 .34809 Mdot
.34797 .50814 Mdot
.59144 .29317 Mdot
.35296 .33894 Mdot
.46592 .73156 Mdot
.43879 .33384 Mdot
.56234 .68231 Mdot
.71436 .54912 Mdot
.42913 .35669 Mdot
.70326 .44904 Mdot
.69916 .52494 Mdot
.56956 .66637 Mdot
.27916 .57991 Mdot
.64992 .3541 Mdot
.66625 .35266 Mdot
.34845 .3031 Mdot
.56155 .26798 Mdot
.63704 .65527 Mdot
.69321 .41226 Mdot
.3901 .69536 Mdot
.34291 .53811 Mdot
.4233 .32202 Mdot
.43868 .30756 Mdot
.59107 .27982 Mdot
.28924 .56257 Mdot
.55424 .70392 Mdot
.62548 .36413 Mdot
.67355 .34883 Mdot
.45558 .72342 Mdot
.70762 .55288 Mdot
.46239 .34705 Mdot
.65628 .3428 Mdot
.27085 .6371 Mdot
.28546 .57841 Mdot
.69373 .58423 Mdot
.65435 .34138 Mdot
.5544 .26269 Mdot
.69757 .44072 Mdot
.57493 .69796 Mdot
.37648 .67497 Mdot
.5591 .69286 Mdot
.3287 .34591 Mdot
.63033 .36197 Mdot
.70935 .44078 Mdot
.447 .31798 Mdot
.64568 .30303 Mdot
.66375 .33305 Mdot
.6524 .64239 Mdot
.27579 .58202 Mdot
.34656 .47735 Mdot
.34534 .52813 Mdot
.24752 .60577 Mdot
.34418 .36928 Mdot
.71505 .42851 Mdot
.71429 .46627 Mdot
.37716 .67556 Mdot
.35573 .36632 Mdot
.6273 .34422 Mdot
.65162 .33487 Mdot
.72314 .5675 Mdot
.46971 .29564 Mdot
.62634 .34807 Mdot
.28979 .57727 Mdot
.65161 .30738 Mdot
.59055 .6729 Mdot
.70954 .5507 Mdot
.28102 .59814 Mdot
.66252 .32988 Mdot
.54871 .67645 Mdot
.36641 .68761 Mdot
.36547 .51619 Mdot
.48928 .31949 Mdot
.69936 .56269 Mdot
.64304 .6874 Mdot
.56798 .26446 Mdot
.36684 .50179 Mdot
.71635 .44549 Mdot
.47596 .35324 Mdot
.63707 .30358 Mdot
.65784 .62593 Mdot
.67214 .35652 Mdot
.71536 .53711 Mdot
.45399 .30683 Mdot
.37144 .33264 Mdot
.6389 .36508 Mdot
.67619 .35867 Mdot
.46292 .71023 Mdot
.36046 .30759 Mdot
.3273 .35566 Mdot
.67915 .63935 Mdot
.69073 .54876 Mdot
.45992 .71985 Mdot
.26441 .63299 Mdot
.32888 .52415 Mdot
.70199 .52108 Mdot
.56923 .72275 Mdot
.36655 .49202 Mdot
.34568 .50022 Mdot
.33057 .49776 Mdot
.5828 .69824 Mdot
.6725 .64566 Mdot
.25254 .58386 Mdot
.45175 .70957 Mdot
.35513 .68011 Mdot
.65143 .65039 Mdot
.65374 .63535 Mdot
.36074 .67633 Mdot
.46306 .71289 Mdot
.56939 .67612 Mdot
.70545 .54941 Mdot
.70467 .5615 Mdot
.66399 .6307 Mdot
.48132 .71811 Mdot
.69599 .52353 Mdot
.55309 .69053 Mdot
.66117 .36 Mdot
.34792 .69025 Mdot
.6696 .62376 Mdot
.34469 .67287 Mdot
.69663 .55849 Mdot
.25557 .62744 Mdot
.34238 .68217 Mdot
.34625 .49054 Mdot
.27899 .57751 Mdot
.36216 .35683 Mdot
.44394 .32098 Mdot
.4324 .33738 Mdot
.70522 .52234 Mdot
.33461 .5064 Mdot
.54205 .69971 Mdot
.33223 .51375 Mdot
.28497 .60906 Mdot
.25697 .62548 Mdot
.39139 .69003 Mdot
.65922 .62632 Mdot
.54047 .69947 Mdot
.6662 .31704 Mdot
.64878 .385 Mdot
.36913 .70305 Mdot
.7013 .56243 Mdot
.65002 .65874 Mdot
.70645 .56506 Mdot
.63816 .33562 Mdot
.65012 .3567 Mdot
.47343 .30973 Mdot
.46861 .32586 Mdot
.6403 .34724 Mdot
.67573 .3314 Mdot
.26263 .63439 Mdot
.56596 .67919 Mdot
.59206 .69681 Mdot
.30123 .60265 Mdot
.34891 .47177 Mdot
.34287 .34031 Mdot
.42187 .35116 Mdot
.71142 .45018 Mdot
.38151 .69222 Mdot
.33079 .54028 Mdot
.4536 .33009 Mdot
.69726 .5109 Mdot
.34433 .32235 Mdot
.70812 .55563 Mdot
.36681 .32716 Mdot
.66078 .37835 Mdot
.343 .52079 Mdot
.34086 .49998 Mdot
.7141 .46331 Mdot
.65436 .31057 Mdot
.64961 .32536 Mdot
.34269 .33654 Mdot
.30314 .59845 Mdot
.64642 .33099 Mdot
.67117 .62298 Mdot
.66512 .6078 Mdot
.44658 .30442 Mdot
.35188 .50487 Mdot
.30705 .58892 Mdot
.45524 .72641 Mdot
.46239 .3358 Mdot
.45228 .31827 Mdot
.67674 .67958 Mdot
.30981 .54613 Mdot
.73429 .53295 Mdot
.47043 .32762 Mdot
.64585 .63227 Mdot
.64748 .35286 Mdot
.45616 .33733 Mdot
.4407 .34573 Mdot
.28452 .33086 Mdot
.42749 .33608 Mdot
.66087 .66202 Mdot
.55601 .69571 Mdot
.45801 .69942 Mdot
.58226 .71767 Mdot
.36184 .31641 Mdot
.34255 .32752 Mdot
.59025 .27033 Mdot
.72872 .46223 Mdot
.32261 .51612 Mdot
.35205 .33085 Mdot
.62822 .6596 Mdot
.48136 .71009 Mdot
.47298 .70859 Mdot
.46548 .70434 Mdot
.55977 .68794 Mdot
.29776 .57885 Mdot
.57462 .27038 Mdot
.65185 .64468 Mdot
.46427 .69909 Mdot
.36312 .47771 Mdot
.67749 .66336 Mdot
.69188 .53881 Mdot
.48171 .72572 Mdot
.66367 .64894 Mdot
.34105 .65203 Mdot
.69147 .55788 Mdot
.38002 .70071 Mdot
.66995 .40663 Mdot
.55317 .26413 Mdot
.70943 .5374 Mdot
.6709 .38325 Mdot
.64261 .32822 Mdot
.65791 .33447 Mdot
.67252 .63927 Mdot
.6767 .34659 Mdot
.54047 .70243 Mdot
.59279 .29102 Mdot
.26137 .57219 Mdot
.34474 .31352 Mdot
.58443 .27964 Mdot
.66288 .63264 Mdot
.63467 .68366 Mdot
.29258 .37571 Mdot
.36923 .50981 Mdot
.71516 .43592 Mdot
.35321 .34613 Mdot
.36128 .69192 Mdot
.36817 .33764 Mdot
.63168 .34029 Mdot
.26806 .56711 Mdot
.28493 .57858 Mdot
.73094 .53354 Mdot
.33888 .34076 Mdot
.65555 .63265 Mdot
.46422 .70829 Mdot
.62183 .36372 Mdot
.35166 .33777 Mdot
.33176 .33847 Mdot
.3622 .524 Mdot
.55391 .69528 Mdot
.6372 .32355 Mdot
.68547 .55008 Mdot
.60389 .28917 Mdot
.30507 .6479 Mdot
.30629 .54745 Mdot
.36819 .50217 Mdot
.35504 .68716 Mdot
.59483 .28485 Mdot
.70542 .54376 Mdot
.28127 .60867 Mdot
.56705 .25931 Mdot
.28342 .61093 Mdot
.52757 .70157 Mdot
.58688 .28531 Mdot
.44247 .30794 Mdot
.48007 .31051 Mdot
.35391 .51158 Mdot
.28523 .36423 Mdot
.30603 .56469 Mdot
.69342 .52482 Mdot
.43802 .32264 Mdot
.67698 .37627 Mdot
.6398 .66551 Mdot
.28315 .33443 Mdot
.44798 .70834 Mdot
.68592 .54798 Mdot
.64819 .33323 Mdot
.28059 .34637 Mdot
.35861 .3577 Mdot
.34144 .68749 Mdot
.36699 .52287 Mdot
.35443 .50878 Mdot
.69779 .53309 Mdot
.69623 .51866 Mdot
.59794 .68278 Mdot
.41727 .33898 Mdot
.65331 .61212 Mdot
.72248 .4626 Mdot
.28065 .34301 Mdot
.43637 .30812 Mdot
.56338 .70669 Mdot
.42455 .32508 Mdot
.70482 .50501 Mdot
.30603 .55204 Mdot
.5554 .69507 Mdot
.45727 .30123 Mdot
.50133 .69299 Mdot
.47354 .71497 Mdot
.27042 .63778 Mdot
.35899 .52311 Mdot
.64077 .65062 Mdot
.64981 .64703 Mdot
.54481 .69882 Mdot
.46594 .29841 Mdot
.33758 .51621 Mdot
.35646 .4952 Mdot
.36366 .49532 Mdot
.56268 .72406 Mdot
.34555 .5208 Mdot
.63377 .66633 Mdot
.35402 .69704 Mdot
.69626 .41286 Mdot
.33874 .50436 Mdot
.71188 .52717 Mdot
.35856 .51269 Mdot
.33133 .36339 Mdot
.36937 .67179 Mdot
.44617 .72378 Mdot
.70163 .54422 Mdot
.35475 .4801 Mdot
.51483 .32281 Mdot
.32609 .53202 Mdot
.36289 .32053 Mdot
.69885 .45285 Mdot
.30568 .57507 Mdot
.55774 .72416 Mdot
.66221 .63837 Mdot
.64675 .37263 Mdot
.71824 .51892 Mdot
.6305 .34768 Mdot
.42282 .70695 Mdot
.43024 .31276 Mdot
.58963 .29517 Mdot
.26221 .6312 Mdot
.30889 .5513 Mdot
.46698 .29255 Mdot
.53976 .69487 Mdot
.57945 .26975 Mdot
.34679 .47046 Mdot
.48239 .7152 Mdot
.33684 .35834 Mdot
.36582 .3388 Mdot
.31525 .30466 Mdot
.56991 .68945 Mdot
.63065 .68049 Mdot
.69694 .53592 Mdot
.66527 .3359 Mdot
.34984 .3719 Mdot
.71317 .59204 Mdot
.70554 .51117 Mdot
.5887 .27662 Mdot
.71334 .55112 Mdot
.33755 .5103 Mdot
.434 .33846 Mdot
.58638 .68729 Mdot
.4433 .33111 Mdot
.31823 .53627 Mdot
.67207 .34138 Mdot
.46077 .29607 Mdot
.37019 .34761 Mdot
.71461 .52744 Mdot
.64105 .35865 Mdot
.2762 .58421 Mdot
.64864 .64937 Mdot
.41625 .71898 Mdot
.56201 .25962 Mdot
.44426 .72199 Mdot
.44148 .72042 Mdot
.5862 .69668 Mdot
.46237 .33917 Mdot
.62337 .29795 Mdot
.4445 .72523 Mdot
.72141 .47284 Mdot
.32476 .32127 Mdot
.57163 .28684 Mdot
.63159 .36751 Mdot
.64564 .34131 Mdot
.31535 .54645 Mdot
.62192 .35426 Mdot
.36674 .67519 Mdot
.62315 .36707 Mdot
.70026 .43646 Mdot
.29975 .571 Mdot
.65195 .33713 Mdot
.467 .3302 Mdot
.28666 .58251 Mdot
.56429 .70082 Mdot
.62312 .34359 Mdot
.34639 .49031 Mdot
.68116 .34815 Mdot
.71194 .46527 Mdot
.46938 .29967 Mdot
.35168 .65912 Mdot
.70217 .55287 Mdot
.66607 .65851 Mdot
.36635 .66227 Mdot
.35525 .3353 Mdot
.54786 .70593 Mdot
.32569 .31435 Mdot
.33012 .33654 Mdot
.34847 .68576 Mdot
.67993 .62892 Mdot
.43713 .31454 Mdot
.36389 .33988 Mdot
.37695 .32725 Mdot
.6443 .33957 Mdot
.58545 .26459 Mdot
.46354 .32627 Mdot
.27554 .58684 Mdot
.57646 .28438 Mdot
.71201 .5357 Mdot
.36684 .51922 Mdot
.65474 .32816 Mdot
.43911 .31696 Mdot
.34996 .49933 Mdot
.45086 .70869 Mdot
.59145 .68611 Mdot
.42091 .33827 Mdot
.35749 .31831 Mdot
.5595 .69845 Mdot
.36817 .50401 Mdot
.36021 .3136 Mdot
.60186 .28433 Mdot
.28958 .58546 Mdot
.65646 .62538 Mdot
.6291 .65441 Mdot
.63779 .37765 Mdot
.68981 .53846 Mdot
.66729 .35662 Mdot
.36769 .32527 Mdot
.29347 .37772 Mdot
.4731 .31643 Mdot
.45684 .73072 Mdot
.36531 .67165 Mdot
.63978 .3717 Mdot
.65165 .63428 Mdot
.70141 .59032 Mdot
.36717 .6699 Mdot
.29045 .58233 Mdot
.35543 .50446 Mdot
.59126 .28484 Mdot
.64236 .66597 Mdot
.35394 .50416 Mdot
.42447 .34928 Mdot
.29515 .58006 Mdot
.344 .35118 Mdot
.65604 .40181 Mdot
.48211 .31426 Mdot
.55276 .72609 Mdot
.4618 .29977 Mdot
.65779 .34004 Mdot
.34297 .65097 Mdot
.35769 .68334 Mdot
.301 .31098 Mdot
.66151 .66259 Mdot
.55209 .67427 Mdot
.65226 .35416 Mdot
.59627 .28066 Mdot
.44661 .70585 Mdot
.46038 .70712 Mdot
.28595 .58174 Mdot
.6318 .34099 Mdot
.64537 .38962 Mdot
.42753 .31948 Mdot
.46083 .29423 Mdot
.37132 .7054 Mdot
.65856 .37647 Mdot
.34354 .5203 Mdot
.4751 .72088 Mdot
.71025 .50885 Mdot
.56672 .69482 Mdot
.72516 .4374 Mdot
.71151 .50723 Mdot
.33478 .4843 Mdot
.25326 .59295 Mdot
.70806 .45585 Mdot
.7334 .45896 Mdot
.58841 .27353 Mdot
.37596 .70822 Mdot
.33094 .34861 Mdot
.25115 .60666 Mdot
.62929 .34663 Mdot
.33716 .52836 Mdot
.6367 .64744 Mdot
.41955 .32902 Mdot
.71664 .58438 Mdot
.34709 .43346 Mdot
.44753 .70006 Mdot
.57187 .27594 Mdot
.45536 .33217 Mdot
.43998 .33172 Mdot
.30154 .59377 Mdot
.34467 .51855 Mdot
.63648 .37636 Mdot
.37911 .70979 Mdot
.7229 .46165 Mdot
.59137 .27484 Mdot
.57291 .68874 Mdot
.35594 .51464 Mdot
.6672 .67191 Mdot
.71302 .517 Mdot
.32965 .32452 Mdot
.35484 .36365 Mdot
.32591 .53377 Mdot
.43336 .70999 Mdot
.71562 .47652 Mdot
.45387 .70509 Mdot
.46018 .71589 Mdot
.46137 .32254 Mdot
.43847 .70677 Mdot
.36787 .52287 Mdot
.37202 .49686 Mdot
.46526 .33437 Mdot
.70702 .50886 Mdot
.31458 .5577 Mdot
.45131 .33441 Mdot
.36325 .66437 Mdot
.7192 .52856 Mdot
.45123 .70525 Mdot
.70698 .528 Mdot
.59099 .27731 Mdot
.71091 .46102 Mdot
.37164 .33512 Mdot
.5854 .27643 Mdot
.59213 .69549 Mdot
.66491 .64847 Mdot
.69714 .56712 Mdot
.36195 .34304 Mdot
.71033 .5296 Mdot
.63841 .36213 Mdot
.71657 .4724 Mdot
.52519 .71651 Mdot
.2763 .63966 Mdot
.33296 .48842 Mdot
.69147 .57746 Mdot
.65351 .38389 Mdot
.66443 .63124 Mdot
.72882 .4643 Mdot
.35534 .66494 Mdot
.3558 .35988 Mdot
.35614 .50981 Mdot
.71398 .52343 Mdot
.58014 .27987 Mdot
.59501 .67664 Mdot
.36475 .32718 Mdot
.65005 .68806 Mdot
.64954 .37681 Mdot
.29769 .57205 Mdot
.70632 .42758 Mdot
.63014 .3014 Mdot
.71549 .46367 Mdot
.34801 .47853 Mdot
.44396 .30075 Mdot
.42148 .34187 Mdot
.56564 .67184 Mdot
.46891 .29135 Mdot
.45808 .35916 Mdot
.72506 .4728 Mdot
.5711 .7086 Mdot
.66798 .32045 Mdot
.27504 .58778 Mdot
.45066 .69668 Mdot
.46954 .31544 Mdot
.64373 .65712 Mdot
.4432 .71633 Mdot
.47548 .30919 Mdot
.35265 .69613 Mdot
.56127 .69387 Mdot
.62613 .33908 Mdot
.29016 .57571 Mdot
.70779 .43058 Mdot
.72377 .45506 Mdot
.42473 .31637 Mdot
.7044 .44469 Mdot
.36391 .66487 Mdot
.67935 .6263 Mdot
.45498 .70014 Mdot
.34587 .3506 Mdot
.68615 .65255 Mdot
.42056 .33266 Mdot
.2878 .32627 Mdot
.29258 .57397 Mdot
.65061 .35505 Mdot
.63961 .30434 Mdot
.36866 .70422 Mdot
.65312 .64861 Mdot
.37137 .67706 Mdot
.43966 .71228 Mdot
.45658 .70592 Mdot
.66484 .33538 Mdot
.35911 .68956 Mdot
.34456 .52144 Mdot
.68674 .55086 Mdot
.32631 .65093 Mdot
.35732 .47541 Mdot
.41857 .34708 Mdot
.44675 .72405 Mdot
.70212 .43652 Mdot
.56822 .67942 Mdot
.6503 .35244 Mdot
.55373 .70577 Mdot
.5685 .68305 Mdot
.67007 .64838 Mdot
.71062 .59337 Mdot
.44584 .72561 Mdot
.73061 .55407 Mdot
.59129 .6725 Mdot
.34966 .47285 Mdot
.63353 .65808 Mdot
.61494 .29637 Mdot
.57012 .70956 Mdot
.66524 .65949 Mdot
.59293 .66142 Mdot
.6431 .66537 Mdot
.2805 .58401 Mdot
.28118 .59968 Mdot
.39544 .7002 Mdot
.59035 .28988 Mdot
.34399 .52818 Mdot
.43172 .33904 Mdot
.34911 .35244 Mdot
.5788 .70307 Mdot
.449 .31948 Mdot
.34571 .68038 Mdot
.48843 .29301 Mdot
.35746 .53345 Mdot
.34936 .5024 Mdot
.46197 .70352 Mdot
.25341 .62263 Mdot
.58596 .29115 Mdot
.6444 .63762 Mdot
.35952 .47477 Mdot
.63877 .30311 Mdot
.29954 .56008 Mdot
.37388 .67821 Mdot
.37009 .49193 Mdot
.64991 .35418 Mdot
.57656 .68457 Mdot
.43132 .33166 Mdot
.67116 .67371 Mdot
.35341 .52712 Mdot
.48385 .28399 Mdot
.34194 .30955 Mdot
.35052 .50469 Mdot
.67533 .66736 Mdot
.44142 .71483 Mdot
.67064 .6582 Mdot
.68286 .63766 Mdot
.29089 .58194 Mdot
.57791 .69269 Mdot
.67352 .64419 Mdot
.45928 .70724 Mdot
.57228 .27724 Mdot
.718 .48318 Mdot
.30863 .5559 Mdot
.36371 .32708 Mdot
.28476 .56692 Mdot
.32662 .33771 Mdot
.43928 .33994 Mdot
.45942 .32885 Mdot
.30179 .57139 Mdot
.65988 .38684 Mdot
.32505 .34916 Mdot
.58696 .28989 Mdot
.52805 .72115 Mdot
.56635 .66832 Mdot
.72265 .46436 Mdot
.58469 .26384 Mdot
.46032 .32697 Mdot
.31585 .55935 Mdot
.30799 .64766 Mdot
.7053 .45122 Mdot
.53113 .6947 Mdot
.30807 .5609 Mdot
.47417 .29319 Mdot
.62696 .33411 Mdot
.6651 .35127 Mdot
.72407 .47309 Mdot
.58612 .66128 Mdot
.33421 .51803 Mdot
.47358 .29348 Mdot
.4935 .71585 Mdot
.44312 .32032 Mdot
.42797 .32889 Mdot
.67247 .38363 Mdot
.34083 .51323 Mdot
.34282 .67775 Mdot
.63839 .3285 Mdot
.33603 .32731 Mdot
.53428 .69072 Mdot
.36375 .3179 Mdot
.72964 .52875 Mdot
.59527 .6856 Mdot
.63656 .34456 Mdot
.48351 .30932 Mdot
.34168 .53173 Mdot
.56693 .68553 Mdot
.54203 .69215 Mdot
.56857 .69824 Mdot
.34941 .34902 Mdot
.62991 .36896 Mdot
.60268 .29103 Mdot
.2784 .58202 Mdot
.67837 .6217 Mdot
.28484 .32977 Mdot
.28648 .56797 Mdot
.70334 .5611 Mdot
.44602 .71931 Mdot
.6633 .62583 Mdot
.46541 .72987 Mdot
.58962 .6686 Mdot
.66352 .34554 Mdot
.32464 .53883 Mdot
.28103 .58661 Mdot
.30479 .57724 Mdot
.34549 .32246 Mdot
.65528 .66939 Mdot
.25273 .58899 Mdot
.30282 .54317 Mdot
.30663 .58639 Mdot
.35508 .50001 Mdot
.33212 .49018 Mdot
.45282 .34596 Mdot
.47598 .31405 Mdot
.36048 .66963 Mdot
.36475 .51258 Mdot
.68091 .65887 Mdot
.5887 .68218 Mdot
.45645 .68544 Mdot
.69989 .52161 Mdot
.57158 .70998 Mdot
.63586 .32874 Mdot
.62339 .33915 Mdot
.66231 .31262 Mdot
.37619 .34 Mdot
.45017 .70358 Mdot
.32804 .54047 Mdot
.69344 .52651 Mdot
.35775 .33496 Mdot
.68048 .62088 Mdot
.32935 .3408 Mdot
.37541 .69567 Mdot
.37103 .33811 Mdot
.43034 .31034 Mdot
.69836 .43649 Mdot
.47528 .72047 Mdot
.33948 .31862 Mdot
.56301 .69731 Mdot
.30838 .56281 Mdot
.29137 .5971 Mdot
.63395 .68397 Mdot
.33313 .35711 Mdot
.60446 .29018 Mdot
.29728 .56466 Mdot
.27334 .55658 Mdot
.70541 .52448 Mdot
.37109 .33256 Mdot
.70798 .56116 Mdot
.45045 .71755 Mdot
.54007 .68064 Mdot
.6558 .64254 Mdot
.72539 .45772 Mdot
.37311 .67802 Mdot
.37339 .33683 Mdot
.63954 .34399 Mdot
.38411 .70709 Mdot
.58526 .29222 Mdot
.49255 .3044 Mdot
.30756 .57957 Mdot
.57447 .26883 Mdot
.36138 .47632 Mdot
.71697 .45367 Mdot
.32999 .51564 Mdot
.46125 .72897 Mdot
.28398 .55624 Mdot
.64451 .32265 Mdot
.64647 .34154 Mdot
.59379 .29473 Mdot
.31117 .54436 Mdot
.36708 .48017 Mdot
.55921 .68396 Mdot
.63254 .37189 Mdot
.6702 .63924 Mdot
.64207 .65239 Mdot
.67232 .38152 Mdot
.67033 .66287 Mdot
.33125 .33917 Mdot
.27391 .56225 Mdot
.71655 .4541 Mdot
.71758 .4646 Mdot
.63882 .34729 Mdot
.67628 .37117 Mdot
.64971 .35629 Mdot
.44635 .71712 Mdot
.67883 .62976 Mdot
.25024 .60061 Mdot
.36109 .52252 Mdot
.33715 .50249 Mdot
.57361 .6876 Mdot
.36323 .6674 Mdot
.36089 .44869 Mdot
.33699 .35643 Mdot
.65742 .34237 Mdot
.71644 .54676 Mdot
.42417 .72809 Mdot
.68784 .5396 Mdot
.29303 .58476 Mdot
.714 .48039 Mdot
.5315 .69722 Mdot
.36874 .34477 Mdot
.46363 .72384 Mdot
.36158 .35998 Mdot
.70949 .50927 Mdot
.54602 .6898 Mdot
.36543 .6941 Mdot
.29779 .57565 Mdot
.36507 .68315 Mdot
.45524 .27709 Mdot
.59517 .66975 Mdot
.69332 .55478 Mdot
.4725 .7204 Mdot
.49106 .30514 Mdot
.49445 .70951 Mdot
.31555 .54714 Mdot
.34555 .48519 Mdot
.32357 .51622 Mdot
.27822 .59961 Mdot
.57571 .69804 Mdot
.37595 .68653 Mdot
.48209 .30489 Mdot
.27898 .59168 Mdot
.72686 .55709 Mdot
.34719 .53579 Mdot
.34152 .498 Mdot
.33377 .53397 Mdot
.34745 .48172 Mdot
.58001 .70689 Mdot
.46611 .70371 Mdot
.68913 .53702 Mdot
.28878 .54832 Mdot
.72988 .45514 Mdot
.64 .35221 Mdot
.41712 .33365 Mdot
.58308 .69404 Mdot
.36034 .36076 Mdot
.72645 .51504 Mdot
.26931 .56115 Mdot
.66767 .31682 Mdot
.2836 .60647 Mdot
.4174 .34463 Mdot
.43297 .33602 Mdot
.37436 .3352 Mdot
.66445 .33122 Mdot
.70879 .54387 Mdot
.36441 .4873 Mdot
.66849 .63612 Mdot
.65859 .65649 Mdot
.28219 .59057 Mdot
.70027 .50384 Mdot
.72346 .45528 Mdot
.58404 .27848 Mdot
.335 .51656 Mdot
.28002 .59849 Mdot
.67653 .65509 Mdot
.5976 .27742 Mdot
.35164 .67877 Mdot
.34656 .33551 Mdot
.34394 .54507 Mdot
.48098 .30031 Mdot
.37393 .68753 Mdot
.69266 .53035 Mdot
.441 .31236 Mdot
.3326 .54481 Mdot
.25236 .59307 Mdot
.47424 .72909 Mdot
.33774 .30224 Mdot
.64118 .38563 Mdot
.29181 .57855 Mdot
.29185 .56924 Mdot
.56178 .69289 Mdot
.71251 .46204 Mdot
.65244 .63263 Mdot
.5343 .72004 Mdot
.45961 .32844 Mdot
.71133 .46644 Mdot
.33101 .50674 Mdot
.70085 .44362 Mdot
.44605 .71991 Mdot
.31243 .55423 Mdot
.69295 .55324 Mdot
.68112 .65163 Mdot
.62827 .63816 Mdot
.29761 .58574 Mdot
.45811 .71788 Mdot
.28544 .56667 Mdot
.59527 .27604 Mdot
.41988 .32687 Mdot
.29709 .57715 Mdot
.65239 .65903 Mdot
.28467 .57092 Mdot
.70981 .51188 Mdot
.33601 .31653 Mdot
.65554 .65011 Mdot
.57024 .27279 Mdot
.6657 .34206 Mdot
.64439 .38294 Mdot
.43049 .31094 Mdot
.43852 .70984 Mdot
.55204 .70112 Mdot
.65339 .62768 Mdot
.36679 .67971 Mdot
.6574 .33977 Mdot
.34305 .34509 Mdot
.27075 .58801 Mdot
.48253 .30026 Mdot
.71012 .43128 Mdot
.57193 .72235 Mdot
.35598 .69844 Mdot
.36999 .32172 Mdot
.31837 .64833 Mdot
.45859 .32205 Mdot
.34109 .5073 Mdot
.37215 .33448 Mdot
.67517 .36777 Mdot
.47927 .72587 Mdot
.45135 .34777 Mdot
.58144 .28783 Mdot
.65943 .32271 Mdot
.72751 .45566 Mdot
.63382 .3794 Mdot
.36333 .36016 Mdot
.47193 .32519 Mdot
.65931 .65246 Mdot
.34633 .51027 Mdot
.46555 .31725 Mdot
.65971 .35311 Mdot
.4334 .31072 Mdot
.34939 .49154 Mdot
.65581 .6766 Mdot
.63532 .35755 Mdot
.28859 .57069 Mdot
.4489 .72715 Mdot
.59052 .69294 Mdot
.5761 .27577 Mdot
.37013 .67713 Mdot
.35528 .37056 Mdot
.65634 .31304 Mdot
.6478 .32301 Mdot
.28676 .59043 Mdot
.35137 .35872 Mdot
.35672 .52039 Mdot
.70782 .55019 Mdot
.35475 .65639 Mdot
.71407 .46349 Mdot
.28748 .60901 Mdot
.27492 .5972 Mdot
.38356 .68335 Mdot
.52902 .68459 Mdot
.50086 .33831 Mdot
.29267 .61036 Mdot
.35726 .4945 Mdot
.63466 .6547 Mdot
.34448 .6697 Mdot
.28325 .64326 Mdot
.58056 .68507 Mdot
.34279 .31155 Mdot
.70653 .5222 Mdot
.27139 .5834 Mdot
.73189 .53804 Mdot
.34362 .35008 Mdot
.29898 .59808 Mdot
.3607 .70394 Mdot
.6527 .63551 Mdot
.32794 .53719 Mdot
.65995 .64326 Mdot
.30958 .55279 Mdot
.58883 .69776 Mdot
.72608 .46754 Mdot
.32629 .51169 Mdot
.46974 .32733 Mdot
.63044 .30168 Mdot
.33573 .48503 Mdot
.33595 .34386 Mdot
.4657 .72867 Mdot
.45584 .32748 Mdot
.70827 .5554 Mdot
.72571 .47936 Mdot
.65106 .3562 Mdot
.68522 .54381 Mdot
.56319 .70852 Mdot
.58112 .27972 Mdot
.44709 .30014 Mdot
.48751 .7209 Mdot
.34476 .37248 Mdot
.71039 .46654 Mdot
.36007 .50196 Mdot
.33029 .5203 Mdot
.59147 .28533 Mdot
.65898 .40339 Mdot
.64151 .67649 Mdot
.59572 .68753 Mdot
.54733 .69013 Mdot
.34146 .32498 Mdot
.57635 .27851 Mdot
.32488 .5454 Mdot
.34061 .5231 Mdot
.67473 .3425 Mdot
.57637 .68564 Mdot
.35268 .35265 Mdot
.42146 .34148 Mdot
.69389 .52508 Mdot
.59649 .29849 Mdot
.65675 .65062 Mdot
.58102 .29366 Mdot
.60174 .28842 Mdot
.60655 .66265 Mdot
.29754 .60554 Mdot
.70396 .54933 Mdot
.57502 .29033 Mdot
.66226 .62459 Mdot
.29493 .58397 Mdot
.43855 .32465 Mdot
.43225 .30937 Mdot
.58138 .66794 Mdot
.63473 .34999 Mdot
.34761 .36069 Mdot
.31673 .54482 Mdot
.37672 .32484 Mdot
.57135 .68356 Mdot
.65276 .37917 Mdot
.4474 .31093 Mdot
.71932 .53376 Mdot
.28335 .57103 Mdot
.34804 .35151 Mdot
.70292 .54783 Mdot
.48041 .31147 Mdot
.27511 .55889 Mdot
.36525 .66176 Mdot
.43946 .71981 Mdot
.70378 .52649 Mdot
.35903 .67906 Mdot
.35844 .53487 Mdot
.71719 .45334 Mdot
.32626 .31258 Mdot
.62521 .30088 Mdot
.35581 .65871 Mdot
.72534 .47267 Mdot
.67546 .34184 Mdot
.63205 .37896 Mdot
.58481 .26274 Mdot
.58541 .29087 Mdot
.72554 .44984 Mdot
.45535 .31348 Mdot
.6006 .29634 Mdot
.71294 .46213 Mdot
.37973 .69162 Mdot
.27158 .58403 Mdot
.37326 .71033 Mdot
.48181 .31285 Mdot
.46869 .30158 Mdot
.58107 .6785 Mdot
.47583 .70956 Mdot
.44654 .31351 Mdot
.3653 .50399 Mdot
.5418 .69468 Mdot
.69405 .55857 Mdot
.28199 .33582 Mdot
.69534 .51828 Mdot
.48076 .72549 Mdot
.64342 .31315 Mdot
.58079 .27715 Mdot
.34745 .50954 Mdot
.72113 .50223 Mdot
.28066 .34408 Mdot
.27171 .58202 Mdot
.46371 .72386 Mdot
.28331 .61084 Mdot
.27968 .5917 Mdot
.54902 .71371 Mdot
.47522 .29719 Mdot
.54432 .69765 Mdot
.70057 .5515 Mdot
.33518 .31569 Mdot
.44837 .35987 Mdot
.7036 .52362 Mdot
.34957 .53179 Mdot
.42202 .32049 Mdot
.35427 .50746 Mdot
.36342 .49306 Mdot
.30598 .54036 Mdot
.37813 .31914 Mdot
.64369 .35736 Mdot
.35781 .36362 Mdot
.65411 .66552 Mdot
.5723 .72126 Mdot
.33699 .34613 Mdot
.3808 .70701 Mdot
.34838 .68014 Mdot
.66286 .40456 Mdot
.65777 .65654 Mdot
.32752 .34322 Mdot
.71067 .5238 Mdot
.29469 .64832 Mdot
.38727 .70177 Mdot
.6857 .55419 Mdot
.34981 .49366 Mdot
.65263 .62773 Mdot
.57912 .68066 Mdot
.71208 .47162 Mdot
.65738 .62538 Mdot
.35715 .68019 Mdot
.45046 .71603 Mdot
.69292 .52905 Mdot
.30391 .60403 Mdot
.71426 .46622 Mdot
.33805 .47606 Mdot
.46036 .72081 Mdot
.65436 .64893 Mdot
.34281 .48047 Mdot
.68454 .65159 Mdot
.47272 .3069 Mdot
.29749 .54511 Mdot
.34108 .34439 Mdot
.36282 .68265 Mdot
.56722 .26814 Mdot
.52679 .6984 Mdot
.66246 .6295 Mdot
.70778 .50382 Mdot
.64728 .64151 Mdot
.56128 .67193 Mdot
.69031 .5786 Mdot
.56628 .71161 Mdot
.35261 .5279 Mdot
.58851 .71251 Mdot
.55317 .70338 Mdot
.69607 .54209 Mdot
.35293 .34172 Mdot
.57128 .69587 Mdot
.59826 .28522 Mdot
.28883 .57921 Mdot
.65818 .36957 Mdot
.33085 .36059 Mdot
.58187 .69502 Mdot
.33822 .34285 Mdot
.65643 .35763 Mdot
.41924 .34585 Mdot
.72079 .43274 Mdot
.70169 .45188 Mdot
.43329 .34553 Mdot
.72071 .47512 Mdot
.64674 .66606 Mdot
.57367 .28421 Mdot
.31989 .53786 Mdot
.33498 .51919 Mdot
.33198 .36437 Mdot
.64116 .66768 Mdot
.71056 .48646 Mdot
.4479 .31857 Mdot
.56718 .6769 Mdot
.71819 .5363 Mdot
.58299 .2747 Mdot
.34338 .67504 Mdot
.7275 .45878 Mdot
.48371 .3075 Mdot
.45909 .3243 Mdot
.35585 .50416 Mdot
.29771 .59502 Mdot
.3658 .326 Mdot
.61467 .29964 Mdot
.47309 .69996 Mdot
.67698 .37192 Mdot
.339 .5356 Mdot
.46593 .69899 Mdot
.36962 .51209 Mdot
.35915 .36537 Mdot
.72769 .44862 Mdot
.663 .65333 Mdot
.3273 .32827 Mdot
.66633 .34262 Mdot
.34183 .65498 Mdot
.28754 .59926 Mdot
.35805 .6742 Mdot
.63092 .33144 Mdot
.63948 .6604 Mdot
.64561 .3483 Mdot
.71811 .45186 Mdot
.3319 .34396 Mdot
.44385 .71649 Mdot
.48236 .31321 Mdot
.63703 .37014 Mdot
.69584 .56755 Mdot
.56848 .27322 Mdot
.72697 .47723 Mdot
.4585 .32807 Mdot
.35159 .66477 Mdot
.62153 .35376 Mdot
.4365 .32841 Mdot
.57916 .67127 Mdot
.25442 .57822 Mdot
.56441 .66528 Mdot
.63137 .34222 Mdot
.2994 .31229 Mdot
.69983 .54708 Mdot
.73488 .45452 Mdot
.34763 .47137 Mdot
.28476 .363 Mdot
.31869 .53148 Mdot
.69907 .46007 Mdot
.71568 .45566 Mdot
.70353 .53084 Mdot
.64833 .34939 Mdot
.67722 .66148 Mdot
.50069 .69165 Mdot
.62711 .34068 Mdot
.31331 .57736 Mdot
.68043 .62093 Mdot
.39437 .69927 Mdot
.62399 .35515 Mdot
.46057 .70572 Mdot
.59897 .67428 Mdot
.32723 .34936 Mdot
.30896 .57225 Mdot
.72478 .45792 Mdot
.27788 .57188 Mdot
.73179 .55399 Mdot
.65412 .35213 Mdot
.43158 .32137 Mdot
.71159 .50144 Mdot
.33292 .51233 Mdot
.33711 .53072 Mdot
.35442 .53437 Mdot
.33514 .36515 Mdot
.58635 .67331 Mdot
.29931 .55357 Mdot
.26624 .56836 Mdot
.45626 .69477 Mdot
.57905 .26209 Mdot
.36395 .35802 Mdot
.25162 .60808 Mdot
.67758 .33826 Mdot
.57431 .67618 Mdot
.33727 .49759 Mdot
.72865 .44484 Mdot
.47401 .7075 Mdot
.69122 .54123 Mdot
.71674 .55 Mdot
.59852 .30032 Mdot
.64808 .65909 Mdot
.44871 .69876 Mdot
.65235 .39027 Mdot
.52238 .69051 Mdot
.457 .69813 Mdot
.59339 .69441 Mdot
.70596 .50858 Mdot
.29221 .37677 Mdot
.73026 .44319 Mdot
.43473 .3068 Mdot
.56158 .71015 Mdot
.66889 .60921 Mdot
.37302 .6854 Mdot
.67357 .63279 Mdot
.5903 .28561 Mdot
.54995 .70126 Mdot
.53652 .28356 Mdot
.54294 .69088 Mdot
.69977 .54124 Mdot
.7137 .46874 Mdot
.45595 .70173 Mdot
.35177 .52473 Mdot
.35963 .69477 Mdot
.44714 .31877 Mdot
.35366 .66577 Mdot
.63905 .32849 Mdot
.59946 .28904 Mdot
.69824 .44011 Mdot
.5513 .71287 Mdot
.68542 .56288 Mdot
.33723 .53177 Mdot
.45803 .72103 Mdot
.28084 .59996 Mdot
.72527 .46506 Mdot
.50015 .70719 Mdot
.362 .51765 Mdot
.45117 .70347 Mdot
.62928 .32907 Mdot
.67929 .37133 Mdot
.57655 .66194 Mdot
.59923 .30007 Mdot
.35558 .49654 Mdot
.34881 .32807 Mdot
.37545 .34343 Mdot
.29371 .59264 Mdot
.64227 .30594 Mdot
.35179 .68008 Mdot
.36085 .50273 Mdot
.34329 .65271 Mdot
.62701 .33311 Mdot
.45738 .29162 Mdot
.66032 .349 Mdot
.58217 .70616 Mdot
.42986 .33689 Mdot
.64917 .32727 Mdot
.34519 .68635 Mdot
.464 .32095 Mdot
.62336 .30126 Mdot
.34354 .35267 Mdot
.36755 .51507 Mdot
.36725 .45693 Mdot
.62693 .36598 Mdot
.70548 .54007 Mdot
.57129 .70169 Mdot
.68921 .54094 Mdot
.6801 .35772 Mdot
.30169 .59669 Mdot
.47778 .30701 Mdot
.73268 .46815 Mdot
.44127 .69578 Mdot
.35448 .33033 Mdot
.72903 .4403 Mdot
.43742 .7067 Mdot
.29082 .5972 Mdot
.28112 .35061 Mdot
.33672 .50548 Mdot
.59947 .29072 Mdot
.70979 .46485 Mdot
.36462 .30941 Mdot
.34489 .51415 Mdot
.66075 .37354 Mdot
.37862 .32868 Mdot
.35791 .50667 Mdot
.57192 .27104 Mdot
.29198 .56797 Mdot
.37151 .33389 Mdot
.55897 .69482 Mdot
.35491 .65562 Mdot
.33157 .3723 Mdot
.32787 .32739 Mdot
.32159 .52082 Mdot
.27745 .60108 Mdot
.61173 .29851 Mdot
.65145 .6366 Mdot
.29527 .57712 Mdot
.33418 .36735 Mdot
.537 .69887 Mdot
.55456 .70639 Mdot
.47819 .72734 Mdot
.71913 .5226 Mdot
.63604 .35413 Mdot
.36405 .33217 Mdot
.59928 .281 Mdot
.2737 .58047 Mdot
.47274 .72677 Mdot
.33606 .35238 Mdot
.7013 .56145 Mdot
.44136 .70946 Mdot
.7025 .48954 Mdot
.2873 .54923 Mdot
.73166 .44207 Mdot
.33608 .49822 Mdot
.3397 .48515 Mdot
.55014 .69632 Mdot
.72822 .55799 Mdot
.7287 .47011 Mdot
.66582 .34782 Mdot
.44859 .31067 Mdot
.57477 .72051 Mdot
.34845 .35013 Mdot
.49585 .68849 Mdot
.34176 .50065 Mdot
.32438 .54658 Mdot
.55039 .6983 Mdot
.28597 .60095 Mdot
.53769 .70772 Mdot
.59727 .28081 Mdot
.28529 .36492 Mdot
.66214 .64945 Mdot
.65688 .63413 Mdot
.41883 .70822 Mdot
.65346 .30714 Mdot
.5339 .69039 Mdot
.27124 .58227 Mdot
.67961 .36879 Mdot
.33982 .30243 Mdot
.35799 .34624 Mdot
.36904 .31161 Mdot
.5302 .69348 Mdot
.35207 .70127 Mdot
.44333 .72018 Mdot
.30178 .56943 Mdot
.32111 .64885 Mdot
.71681 .45139 Mdot
.29104 .55389 Mdot
.45165 .32139 Mdot
.65793 .35216 Mdot
.36251 .4795 Mdot
.36631 .50543 Mdot
.66517 .65241 Mdot
.3296 .31765 Mdot
.68905 .57262 Mdot
.43455 .32974 Mdot
.6291 .37164 Mdot
.33769 .33245 Mdot
.66885 .6653 Mdot
.34054 .47895 Mdot
.45681 .33902 Mdot
.46947 .29299 Mdot
.35224 .49477 Mdot
.29258 .5781 Mdot
.48248 .32408 Mdot
.6959 .53203 Mdot
.66626 .35089 Mdot
.43605 .3352 Mdot
.3601 .68274 Mdot
.3487 .65453 Mdot
.33842 .52288 Mdot
.68509 .64437 Mdot
.69839 .56777 Mdot
.4739 .30395 Mdot
.5747 .28934 Mdot
.27065 .58913 Mdot
.38199 .70029 Mdot
.47771 .28045 Mdot
.45319 .31764 Mdot
.50104 .6912 Mdot
.36128 .35756 Mdot
.46104 .72047 Mdot
.27979 .55316 Mdot
.36174 .66479 Mdot
.33072 .51253 Mdot
.67572 .36286 Mdot
.7163 .53468 Mdot
.44092 .34729 Mdot
.65652 .34215 Mdot
.55473 .70607 Mdot
.30137 .5715 Mdot
.64052 .65415 Mdot
.65085 .63092 Mdot
.56521 .66996 Mdot
.70418 .51833 Mdot
.55449 .72603 Mdot
.48006 .32554 Mdot
.33584 .51178 Mdot
.71037 .45284 Mdot
.53399 .68849 Mdot
.37467 .6735 Mdot
.5316 .6983 Mdot
.65056 .6693 Mdot
.36472 .66374 Mdot
.45101 .70828 Mdot
.26528 .56775 Mdot
.34822 .48402 Mdot
.35396 .36196 Mdot
.67222 .6142 Mdot
.38504 .69861 Mdot
.31497 .5492 Mdot
.34435 .5091 Mdot
.45892 .70137 Mdot
.37665 .31937 Mdot
.28298 .60475 Mdot
.34014 .50427 Mdot
.25111 .60936 Mdot
.3747 .67466 Mdot
.63467 .66006 Mdot
.71532 .42942 Mdot
.47854 .72764 Mdot
.66167 .31813 Mdot
.56413 .6866 Mdot
.32506 .34334 Mdot
.52918 .71069 Mdot
.43372 .71482 Mdot
.71114 .53259 Mdot
.66298 .62605 Mdot
.63774 .36365 Mdot
.70624 .54375 Mdot
.71439 .46619 Mdot
.46362 .7032 Mdot
.67026 .35539 Mdot
.33585 .3121 Mdot
.72878 .45545 Mdot
.4966 .7101 Mdot
.70063 .54039 Mdot
.60146 .66446 Mdot
.35054 .66588 Mdot
.27718 .55588 Mdot
.45984 .30957 Mdot
.44964 .34639 Mdot
.72026 .452 Mdot
.34813 .33669 Mdot
.44126 .70757 Mdot
.56983 .69846 Mdot
.35341 .33337 Mdot
.59494 .67573 Mdot
.58131 .27282 Mdot
.57351 .67944 Mdot
.59197 .28294 Mdot
.67558 .63534 Mdot
.30866 .57468 Mdot
.32698 .32459 Mdot
.48797 .31707 Mdot
.37249 .69838 Mdot
.44831 .30829 Mdot
.35639 .4823 Mdot
.44425 .70228 Mdot
.3527 .52896 Mdot
.66705 .31426 Mdot
.3289 .36268 Mdot
.54719 .70161 Mdot
.42804 .35765 Mdot
.69196 .56125 Mdot
.36032 .67606 Mdot
.43076 .32491 Mdot
.45759 .7187 Mdot
.53626 .70384 Mdot
.67078 .65341 Mdot
.58699 .70132 Mdot
.65847 .3134 Mdot
.49389 .34323 Mdot
.34087 .52905 Mdot
.42505 .35441 Mdot
.71696 .45834 Mdot
.71686 .47747 Mdot
.64827 .36928 Mdot
.30191 .38663 Mdot
.65503 .33894 Mdot
.3301 .30244 Mdot
.67624 .6389 Mdot
.35468 .31692 Mdot
.34764 .52862 Mdot
.57785 .69057 Mdot
.49941 .69122 Mdot
.32598 .31756 Mdot
.36254 .35833 Mdot
.71723 .47529 Mdot
.70776 .45631 Mdot
.43796 .30943 Mdot
.37526 .67593 Mdot
.37966 .67868 Mdot
.3269 .52941 Mdot
.72055 .4482 Mdot
.45554 .71372 Mdot
.72095 .43149 Mdot
.46909 .72279 Mdot
.32989 .3653 Mdot
.65157 .32268 Mdot
.69458 .41245 Mdot
.56947 .68722 Mdot
.30221 .56931 Mdot
.56225 .66851 Mdot
.25554 .57906 Mdot
.72975 .4742 Mdot
.32242 .31661 Mdot
.64593 .35457 Mdot
.72512 .51825 Mdot
.65549 .32507 Mdot
.3852 .35332 Mdot
.36163 .70857 Mdot
.70871 .50387 Mdot
.35486 .67038 Mdot
.66849 .38329 Mdot
.35275 .48098 Mdot
.44585 .33632 Mdot
.42204 .32062 Mdot
.42731 .70273 Mdot
.59321 .68844 Mdot
.35346 .36349 Mdot
.34722 .52908 Mdot
.60438 .67125 Mdot
.34545 .52774 Mdot
.344 .52771 Mdot
.36467 .49287 Mdot
.72305 .46388 Mdot
.35118 .67058 Mdot
.35231 .52591 Mdot
.59311 .29519 Mdot
.35226 .30359 Mdot
.62087 .35871 Mdot
.54999 .69523 Mdot
.35777 .33488 Mdot
.56454 .6841 Mdot
.35946 .69065 Mdot
.69996 .51136 Mdot
.58886 .6736 Mdot
.4613 .71014 Mdot
.52774 .69894 Mdot
.73431 .45872 Mdot
.34421 .35969 Mdot
.45461 .32354 Mdot
.70184 .59156 Mdot
.58706 .28987 Mdot
.43948 .31892 Mdot
.57572 .27249 Mdot
.33746 .49868 Mdot
.65696 .65377 Mdot
.44628 .31114 Mdot
.7027 .56777 Mdot
.67317 .38225 Mdot
.2783 .55253 Mdot
.28225 .5762 Mdot
.63275 .33083 Mdot
.46073 .3139 Mdot
.36234 .68352 Mdot
.34546 .67564 Mdot
.66725 .3844 Mdot
.69329 .58321 Mdot
.71891 .4594 Mdot
.35548 .34212 Mdot
.64048 .66571 Mdot
.66832 .65272 Mdot
.69502 .5611 Mdot
.72504 .50891 Mdot
.28196 .58143 Mdot
.28704 .57131 Mdot
.37027 .69258 Mdot
.3463 .48242 Mdot
.57161 .28556 Mdot
.44088 .32128 Mdot
.66665 .63413 Mdot
.44599 .70082 Mdot
.48113 .70925 Mdot
.3473 .53289 Mdot
.30402 .59526 Mdot
.63095 .35107 Mdot
.45908 .72328 Mdot
.37091 .33243 Mdot
.56224 .72379 Mdot
.29343 .56837 Mdot
.32958 .36588 Mdot
.67188 .6466 Mdot
.61785 .30072 Mdot
.70504 .53857 Mdot
.65695 .38921 Mdot
.65478 .39014 Mdot
.45155 .27741 Mdot
.56502 .68812 Mdot
.43982 .31883 Mdot
.56346 .27213 Mdot
.42544 .3155 Mdot
.367 .35191 Mdot
.29915 .58794 Mdot
.5906 .28761 Mdot
.62283 .36602 Mdot
.71144 .50487 Mdot
.29998 .54694 Mdot
.34888 .54269 Mdot
.72598 .47327 Mdot
.35254 .50102 Mdot
.33623 .34877 Mdot
.70898 .44512 Mdot
.6614 .62667 Mdot
.35142 .36094 Mdot
.72426 .4413 Mdot
.66733 .65635 Mdot
.46223 .7039 Mdot
.37655 .67574 Mdot
.56497 .70369 Mdot
.67307 .66097 Mdot
.28106 .5836 Mdot
.59168 .29885 Mdot
.66558 .644 Mdot
.57089 .70633 Mdot
.58869 .70131 Mdot
.64989 .38193 Mdot
.3776 .33411 Mdot
.71238 .51106 Mdot
.35654 .52306 Mdot
.64885 .31855 Mdot
.35472 .32317 Mdot
.66695 .62637 Mdot
.36777 .52277 Mdot
.27463 .57862 Mdot
.35302 .32996 Mdot
.36651 .35693 Mdot
.35091 .33595 Mdot
.71603 .47024 Mdot
.46136 .70743 Mdot
.54134 .70674 Mdot
.73174 .46567 Mdot
.32809 .34908 Mdot
.34058 .37523 Mdot
.51685 .31981 Mdot
.28457 .57793 Mdot
.35644 .36683 Mdot
.56699 .72354 Mdot
.34022 .68173 Mdot
.42499 .31622 Mdot
.30336 .30901 Mdot
.65446 .30513 Mdot
.3185 .30347 Mdot
.71539 .53167 Mdot
.47272 .71813 Mdot
.35711 .34875 Mdot
.468 .32299 Mdot
.28198 .57823 Mdot
.27618 .59456 Mdot
.34677 .32953 Mdot
.2921 .60737 Mdot
.66139 .65852 Mdot
.55701 .66697 Mdot
.357 .33256 Mdot
.668 .37731 Mdot
.62584 .33853 Mdot
.64638 .33892 Mdot
.33978 .51358 Mdot
.39481 .69487 Mdot
.30495 .64884 Mdot
.58515 .70414 Mdot
.71065 .45995 Mdot
.67408 .64357 Mdot
.60971 .67975 Mdot
.55069 .7057 Mdot
.67605 .37948 Mdot
.34789 .33706 Mdot
.68518 .64633 Mdot
.71387 .47028 Mdot
.72176 .45274 Mdot
.62463 .3642 Mdot
.65827 .33921 Mdot
.63795 .34449 Mdot
.58218 .69253 Mdot
.62624 .67658 Mdot
.35669 .6636 Mdot
.65286 .62966 Mdot
.679 .33877 Mdot
.59648 .2803 Mdot
.62406 .36139 Mdot
.69428 .54578 Mdot
.68302 .63925 Mdot
.29062 .57093 Mdot
.37214 .46605 Mdot
.62576 .33697 Mdot
.33257 .3565 Mdot
.58211 .71783 Mdot
.28422 .36138 Mdot
.47748 .72111 Mdot
.70805 .55843 Mdot
.47212 .31587 Mdot
.35166 .53659 Mdot
.66476 .35114 Mdot
.30659 .30794 Mdot
.47197 .29632 Mdot
.3643 .67473 Mdot
.53052 .72209 Mdot
.71108 .54368 Mdot
.34391 .67065 Mdot
.45471 .33419 Mdot
.44406 .69851 Mdot
.71059 .44504 Mdot
.6348 .36937 Mdot
.58183 .2618 Mdot
.58249 .67953 Mdot
.30315 .57342 Mdot
.47757 .31385 Mdot
.31624 .53998 Mdot
.64733 .32906 Mdot
.35263 .35962 Mdot
.64068 .33186 Mdot
.63479 .66228 Mdot
.63902 .37851 Mdot
.35856 .53388 Mdot
.53823 .70273 Mdot
.7189 .45622 Mdot
.29761 .64739 Mdot
.43539 .35987 Mdot
.65097 .37592 Mdot
.48644 .32005 Mdot
.47608 .70722 Mdot
.48772 .72169 Mdot
.43963 .3479 Mdot
.36097 .53242 Mdot
.69234 .55249 Mdot
.54153 .70929 Mdot
.69314 .56416 Mdot
.37872 .33245 Mdot
.70526 .59245 Mdot
.70571 .53749 Mdot
.39828 .70094 Mdot
.34653 .36138 Mdot
.3012 .59823 Mdot
.36518 .51149 Mdot
.711 .5583 Mdot
.35569 .67547 Mdot
.60449 .67132 Mdot
.34556 .68586 Mdot
.27714 .55797 Mdot
.69324 .55745 Mdot
.44626 .30017 Mdot
.34606 .67276 Mdot
.3791 .32736 Mdot
.72576 .4506 Mdot
.34759 .653 Mdot
.43969 .32386 Mdot
.33384 .33425 Mdot
.34271 .36563 Mdot
.33908 .33595 Mdot
.35822 .53104 Mdot
.33196 .49602 Mdot
.32618 .32916 Mdot
.69031 .5789 Mdot
.32794 .33124 Mdot
.31663 .31375 Mdot
.7074 .48309 Mdot
.36385 .35954 Mdot
.36046 .50091 Mdot
.47019 .72207 Mdot
.47319 .7165 Mdot
.65756 .36665 Mdot
.7172 .58318 Mdot
.59878 .29429 Mdot
.3271 .54393 Mdot
.64241 .687 Mdot
.55273 .70029 Mdot
.47399 .33515 Mdot
.27195 .56388 Mdot
.43528 .71316 Mdot
.55984 .70752 Mdot
.36966 .68931 Mdot
.57055 .67862 Mdot
.45225 .33677 Mdot
.35278 .53781 Mdot
.5569 .69222 Mdot
.54351 .67919 Mdot
.2964 .60738 Mdot
.56724 .67728 Mdot
.67596 .63025 Mdot
.71169 .46282 Mdot
.71378 .52581 Mdot
.69248 .55424 Mdot
.66196 .33908 Mdot
.65894 .63192 Mdot
.3 .5699 Mdot
.66473 .34675 Mdot
.34828 .49452 Mdot
.69384 .55907 Mdot
.3189 .52856 Mdot
.65673 .6336 Mdot
.36279 .50531 Mdot
.39288 .70375 Mdot
.57449 .27035 Mdot
.35184 .32996 Mdot
.5965 .68516 Mdot
.59366 .27048 Mdot
.72791 .45609 Mdot
.63797 .6383 Mdot
.31993 .31549 Mdot
.4443 .697 Mdot
.34619 .54531 Mdot
.36698 .4917 Mdot
.44497 .69707 Mdot
.35605 .70558 Mdot
.46425 .29401 Mdot
.66608 .34225 Mdot
.65003 .3865 Mdot
.28508 .58437 Mdot
.65972 .63564 Mdot
.3739 .3313 Mdot
.33013 .36966 Mdot
.46122 .34609 Mdot
.34974 .68322 Mdot
.2667 .56787 Mdot
.31074 .53886 Mdot
.30258 .56985 Mdot
.64928 .36535 Mdot
.45472 .29267 Mdot
.37149 .68475 Mdot
.33363 .34151 Mdot
.29997 .56592 Mdot
.5519 .69317 Mdot
.67067 .62358 Mdot
.63232 .34636 Mdot
.70796 .4302 Mdot
.4377 .34168 Mdot
.62179 .35258 Mdot
.28585 .58327 Mdot
.47272 .70039 Mdot
.70422 .44575 Mdot
.65459 .67237 Mdot
.33684 .32816 Mdot
.66278 .35148 Mdot
.33973 .31656 Mdot
.64793 .63975 Mdot
.6674 .62667 Mdot
.28459 .59716 Mdot
.47517 .3527 Mdot
.63793 .37331 Mdot
.33923 .5238 Mdot
.63405 .3297 Mdot
.58934 .28088 Mdot
.72289 .43383 Mdot
.29542 .57775 Mdot
.50327 .69101 Mdot
.68959 .54803 Mdot
.33431 .53733 Mdot
.4719 .70933 Mdot
.44215 .71121 Mdot
.67024 .37797 Mdot
.32268 .33837 Mdot
.33142 .33242 Mdot
.63098 .65101 Mdot
.69637 .6374 Mdot
.30198 .54392 Mdot
.6507 .3803 Mdot
.49772 .70677 Mdot
.70737 .53204 Mdot
.67788 .63811 Mdot
.68594 .5046 Mdot
.69713 .53988 Mdot
.28706 .57575 Mdot
.33753 .34655 Mdot
.66699 .66383 Mdot
.42462 .31616 Mdot
.26271 .63709 Mdot
.49046 .31043 Mdot
.49238 .34447 Mdot
.43799 .32969 Mdot
.69963 .5009 Mdot
.63565 .34 Mdot
.53292 .69729 Mdot
.70342 .5652 Mdot
.70952 .53178 Mdot
.60503 .29128 Mdot
.58905 .69461 Mdot
.59171 .66187 Mdot
.5495 .72632 Mdot
.58704 .28932 Mdot
.34513 .34084 Mdot
.34902 .69258 Mdot
.64763 .33971 Mdot
.5659 .25943 Mdot
.71226 .47612 Mdot
.71766 .4773 Mdot
.64937 .67923 Mdot
.28252 .5661 Mdot
.58804 .70171 Mdot
.34853 .49079 Mdot
.30004 .58617 Mdot
.70107 .55957 Mdot
.67742 .63757 Mdot
.70047 .45957 Mdot
.2874 .58712 Mdot
.30686 .55411 Mdot
.68128 .36953 Mdot
.44702 .32168 Mdot
.66668 .40584 Mdot
.29574 .58248 Mdot
.65655 .33275 Mdot
.58984 .6662 Mdot
.46999 .32518 Mdot
.38372 .70111 Mdot
.70418 .45798 Mdot
.47672 .30575 Mdot
.46307 .33168 Mdot
.37486 .5233 Mdot
.57037 .68029 Mdot
.64076 .63951 Mdot
.37552 .3404 Mdot
.70016 .43841 Mdot
.71902 .43618 Mdot
.7031 .49156 Mdot
.28769 .57664 Mdot
.70574 .4683 Mdot
.41614 .33848 Mdot
.33294 .53711 Mdot
.45266 .6996 Mdot
.58931 .67853 Mdot
.3126 .54084 Mdot
.44434 .72432 Mdot
.69834 .54611 Mdot
.48116 .28118 Mdot
.30193 .54446 Mdot
.63116 .339 Mdot
.67166 .66894 Mdot
.58083 .68372 Mdot
.3624 .34923 Mdot
.72658 .46766 Mdot
.29226 .37495 Mdot
.67844 .63843 Mdot
.29059 .56533 Mdot
.70464 .53147 Mdot
.47427 .31512 Mdot
.45721 .30724 Mdot
.48835 .32108 Mdot
.67905 .62391 Mdot
.47026 .32054 Mdot
.55918 .67013 Mdot
.36642 .69049 Mdot
.29717 .58944 Mdot
.70176 .52092 Mdot
.34369 .34238 Mdot
.41972 .34831 Mdot
.58695 .27492 Mdot
.37677 .67971 Mdot
.29437 .59663 Mdot
.70951 .59346 Mdot
.34177 .34704 Mdot
.35198 .53266 Mdot
.46519 .29346 Mdot
.40067 .69794 Mdot
.28497 .3312 Mdot
.43509 .32216 Mdot
.48466 .71134 Mdot
.65223 .666 Mdot
.44501 .31005 Mdot
.66815 .62206 Mdot
.34971 .53376 Mdot
.36242 .6772 Mdot
.637 .64825 Mdot
.65586 .61137 Mdot
.45186 .3404 Mdot
.72641 .44117 Mdot
.35494 .6782 Mdot
.35996 .49679 Mdot
.39453 .6973 Mdot
.47082 .30889 Mdot
.69729 .58825 Mdot
.64295 .32062 Mdot
.60404 .30048 Mdot
.56295 .27396 Mdot
.72651 .47738 Mdot
.70037 .43131 Mdot
.27277 .59823 Mdot
.46848 .68622 Mdot
.39441 .69558 Mdot
.69116 .52631 Mdot
.34201 .69075 Mdot
.35189 .52476 Mdot
.3483 .4976 Mdot
.63388 .32952 Mdot
.70833 .50686 Mdot
.47884 .72699 Mdot
.36867 .68316 Mdot
.3274 .35443 Mdot
.65755 .62656 Mdot
.35741 .51518 Mdot
.70661 .59444 Mdot
.66777 .38055 Mdot
.71691 .58743 Mdot
.35903 .50106 Mdot
.44733 .32208 Mdot
.70121 .44548 Mdot
.71684 .46065 Mdot
.67057 .36962 Mdot
.66835 .37123 Mdot
.35876 .4965 Mdot
.68674 .55932 Mdot
.34341 .69187 Mdot
.34733 .67747 Mdot
.46315 .31585 Mdot
.36764 .33425 Mdot
.35812 .48276 Mdot
.57948 .66177 Mdot
.4575 .35914 Mdot
.3385 .5204 Mdot
.64201 .64679 Mdot
.6396 .34917 Mdot
.58145 .27161 Mdot
.66947 .64449 Mdot
.57942 .27529 Mdot
.71454 .58782 Mdot
.3217 .51591 Mdot
.37146 .34189 Mdot
.41577 .7126 Mdot
.32949 .32345 Mdot
.47482 .30567 Mdot
.28615 .57537 Mdot
.61344 .30214 Mdot
.56159 .26927 Mdot
.42283 .72673 Mdot
.70644 .5499 Mdot
.43249 .30867 Mdot
.45698 .71154 Mdot
.32701 .3587 Mdot
.65619 .35058 Mdot
.42224 .33179 Mdot
.29728 .57286 Mdot
.56769 .68559 Mdot
.47118 .72915 Mdot
.42766 .32767 Mdot
.46917 .30318 Mdot
.4304 .33879 Mdot
.72461 .44148 Mdot
.57313 .70881 Mdot
.71406 .47654 Mdot
.57924 .26762 Mdot
.35461 .66362 Mdot
.3049 .5561 Mdot
.67428 .64083 Mdot
.33116 .52779 Mdot
.68759 .54488 Mdot
.60182 .69657 Mdot
.35039 .33882 Mdot
.45952 .33558 Mdot
.72966 .52796 Mdot
.42344 .31711 Mdot
.45519 .69585 Mdot
.48334 .70409 Mdot
.54823 .69555 Mdot
.70968 .49889 Mdot
.36045 .47502 Mdot
.63893 .38576 Mdot
.33499 .32859 Mdot
.71325 .46827 Mdot
.4574 .69693 Mdot
.36623 .50994 Mdot
.34238 .34445 Mdot
.71876 .47571 Mdot
.45574 .34832 Mdot
.68774 .56739 Mdot
.49125 .30766 Mdot
.44109 .73664 Mdot
.35699 .50477 Mdot
.44501 .32434 Mdot
.55826 .70376 Mdot
.71194 .45697 Mdot
.58809 .68612 Mdot
.45308 .33636 Mdot
.58987 .27781 Mdot
.71164 .4663 Mdot
.30273 .5614 Mdot
.53001 .71066 Mdot
.62747 .67794 Mdot
.56646 .71075 Mdot
.53076 .29538 Mdot
.59613 .28878 Mdot
.63555 .34476 Mdot
.69447 .54313 Mdot
.65175 .31749 Mdot
.34534 .36201 Mdot
.35129 .69477 Mdot
.66232 .37415 Mdot
.57611 .70643 Mdot
.66134 .32745 Mdot
.36981 .70469 Mdot
.73201 .44722 Mdot
.62248 .34708 Mdot
.33267 .51724 Mdot
.46824 .70828 Mdot
.4643 .30121 Mdot
.37334 .31559 Mdot
.36488 .68862 Mdot
.292 .55577 Mdot
.45313 .32725 Mdot
.36082 .50388 Mdot
.68733 .55007 Mdot
.29997 .64521 Mdot
.36406 .66494 Mdot
.58482 .27743 Mdot
.66056 .60963 Mdot
.6528 .38683 Mdot
.34522 .37649 Mdot
.33441 .52677 Mdot
.36167 .50738 Mdot
.44727 .71345 Mdot
.59112 .71096 Mdot
.72129 .46437 Mdot
.35426 .6615 Mdot
.58121 .28513 Mdot
.53928 .6982 Mdot
.54298 .69615 Mdot
.30699 .56409 Mdot
.44237 .32411 Mdot
.718 .53791 Mdot
.358 .53297 Mdot
.42624 .31597 Mdot
.27852 .55809 Mdot
.72154 .48232 Mdot
.59753 .29044 Mdot
.56795 .26425 Mdot
.54133 .68973 Mdot
.62827 .33469 Mdot
.44827 .71499 Mdot
.47073 .31802 Mdot
.56245 .27431 Mdot
.72387 .46389 Mdot
.33481 .32707 Mdot
.3434 .50211 Mdot
.29652 .60556 Mdot
.6281 .3337 Mdot
.66895 .35218 Mdot
.34488 .69373 Mdot
.71251 .59244 Mdot
.50745 .33062 Mdot
.71344 .44837 Mdot
.55069 .69276 Mdot
.3472 .46885 Mdot
.34542 .432 Mdot
.70862 .52381 Mdot
.46107 .69788 Mdot
.62661 .3425 Mdot
.47347 .27798 Mdot
.55481 .70737 Mdot
.33598 .32666 Mdot
.3291 .52922 Mdot
.54522 .70007 Mdot
.57681 .28794 Mdot
.54884 .71322 Mdot
.44691 .31418 Mdot
.73383 .45261 Mdot
.65462 .35762 Mdot
.70935 .50666 Mdot
.50305 .69199 Mdot
.3472 .33983 Mdot
.30928 .5656 Mdot
.46782 .7248 Mdot
.59083 .67457 Mdot
.45738 .70614 Mdot
.43269 .3449 Mdot
.4625 .70522 Mdot
.54815 .69114 Mdot
.36499 .50958 Mdot
.32762 .51786 Mdot
.59171 .27257 Mdot
.35341 .49527 Mdot
.27168 .58709 Mdot
.3934 .70373 Mdot
.33728 .51592 Mdot
.34348 .52807 Mdot
.29285 .58083 Mdot
.64221 .65935 Mdot
.28594 .55306 Mdot
.65451 .67655 Mdot
.63639 .6726 Mdot
.5777 .26816 Mdot
.32826 .36216 Mdot
.37098 .34969 Mdot
.28849 .55037 Mdot
.30018 .60143 Mdot
.59097 .69091 Mdot
.68425 .64305 Mdot
.7177 .45643 Mdot
.36471 .66804 Mdot
.50622 .33366 Mdot
.32146 .52742 Mdot
.65713 .36783 Mdot
.6655 .37978 Mdot
.3444 .49176 Mdot
.2827 .35822 Mdot
.27864 .60353 Mdot
.36681 .69969 Mdot
.3607 .52449 Mdot
.29078 .58992 Mdot
.648 .38378 Mdot
.30768 .57764 Mdot
.44225 .71978 Mdot
.54788 .68716 Mdot
.33925 .3213 Mdot
.44258 .31515 Mdot
.36241 .67731 Mdot
.33413 .48489 Mdot
.57946 .67784 Mdot
.44546 .71197 Mdot
.66074 .3586 Mdot
.66766 .62982 Mdot
.3709 .69845 Mdot
.72933 .45156 Mdot
.2581 .63333 Mdot
.7033 .59292 Mdot
.72241 .44523 Mdot
.33414 .33291 Mdot
.63647 .36583 Mdot
.34024 .54216 Mdot
.66476 .3335 Mdot
.28963 .58249 Mdot
.343 .67563 Mdot
.37071 .3412 Mdot
.57709 .69772 Mdot
.70441 .45672 Mdot
.64941 .66136 Mdot
.59844 .66296 Mdot
.32203 .64724 Mdot
.6451 .39539 Mdot
.63685 .37604 Mdot
.43134 .35656 Mdot
.56836 .67056 Mdot
.2714 .59018 Mdot
.54632 .72519 Mdot
.65493 .65264 Mdot
.57466 .68524 Mdot
.26889 .63588 Mdot
.24942 .6128 Mdot
.29397 .57591 Mdot
.55565 .70195 Mdot
.63383 .36384 Mdot
.37135 .34487 Mdot
.27932 .58864 Mdot
.47131 .3167 Mdot
.54065 .69 Mdot
.62898 .34283 Mdot
.30958 .56916 Mdot
.6582 .33574 Mdot
.54537 .70581 Mdot
.6609 .38589 Mdot
.72192 .43258 Mdot
.6604 .37454 Mdot
.36252 .48298 Mdot
.36372 .51713 Mdot
.54531 .69289 Mdot
.66712 .62683 Mdot
.45283 .69641 Mdot
.33501 .51523 Mdot
.53346 .69154 Mdot
.66714 .32318 Mdot
.68576 .65195 Mdot
.44072 .70767 Mdot
.27372 .58332 Mdot
.32725 .32874 Mdot
.34993 .66 Mdot
.28672 .64341 Mdot
.36219 .66313 Mdot
.34481 .33755 Mdot
.47632 .6874 Mdot
.31448 .55399 Mdot
.28691 .60843 Mdot
.58049 .28697 Mdot
.33072 .51809 Mdot
.4738 .32285 Mdot
.43537 .70605 Mdot
.25012 .62261 Mdot
.4539 .69792 Mdot
.56538 .70801 Mdot
.54219 .70482 Mdot
.67541 .34109 Mdot
.5527 .70518 Mdot
.47386 .31857 Mdot
.71758 .54036 Mdot
.59958 .66404 Mdot
.45297 .29331 Mdot
.47678 .30111 Mdot
.47993 .32569 Mdot
.43281 .32602 Mdot
.50395 .33458 Mdot
.60264 .28727 Mdot
.47209 .2999 Mdot
.56018 .6726 Mdot
.64421 .30515 Mdot
.32278 .31437 Mdot
.71808 .53871 Mdot
.46626 .32926 Mdot
.33004 .51973 Mdot
.44475 .70708 Mdot
.64199 .6328 Mdot
.72938 .47416 Mdot
.43505 .34344 Mdot
.27325 .58913 Mdot
.5441 .68521 Mdot
.35605 .51743 Mdot
.32408 .34542 Mdot
.65541 .6344 Mdot
.66196 .34687 Mdot
.36952 .34075 Mdot
.43983 .33513 Mdot
.3556 .33374 Mdot
.64149 .32821 Mdot
.6871 .57114 Mdot
.32709 .53168 Mdot
.41598 .34537 Mdot
.33427 .36464 Mdot
.32843 .52548 Mdot
.56092 .67323 Mdot
.43811 .34318 Mdot
.27792 .5713 Mdot
.45304 .71256 Mdot
.66468 .65906 Mdot
.7315 .5498 Mdot
.33584 .54349 Mdot
.48175 .70342 Mdot
.54522 .68763 Mdot
.42635 .31936 Mdot
.6633 .34353 Mdot
.36871 .51906 Mdot
.70605 .55663 Mdot
.69373 .5609 Mdot
.57948 .28922 Mdot
.65393 .62518 Mdot
.64362 .3133 Mdot
.36102 .47847 Mdot
.46114 .33211 Mdot
.36719 .52076 Mdot
.68005 .34364 Mdot
.71972 .57604 Mdot
.67238 .65923 Mdot
.57465 .26617 Mdot
.25248 .58344 Mdot
.7186 .52157 Mdot
.58297 .27646 Mdot
.54702 .68858 Mdot
.64808 .63613 Mdot
.66955 .64143 Mdot
.36947 .3302 Mdot
.65714 .34016 Mdot
.63468 .65539 Mdot
.64732 .66772 Mdot
.44225 .70975 Mdot
.3433 .49294 Mdot
.55467 .69296 Mdot
.58989 .29122 Mdot
.33289 .32685 Mdot
.57698 .2808 Mdot
.45221 .35991 Mdot
.70948 .45477 Mdot
.3754 .70605 Mdot
.37796 .68017 Mdot
.29987 .38557 Mdot
.303 .56242 Mdot
.35676 .53259 Mdot
.58467 .69805 Mdot
.37444 .31441 Mdot
.35798 .31532 Mdot
.55896 .67372 Mdot
.66906 .66363 Mdot
.3643 .33765 Mdot
.32803 .50531 Mdot
.29737 .60982 Mdot
.25132 .58605 Mdot
.57189 .71112 Mdot
.55578 .66922 Mdot
.70064 .554 Mdot
.54 .69139 Mdot
.63682 .30138 Mdot
.62401 .35778 Mdot
.6496 .37641 Mdot
.7138 .46172 Mdot
.33297 .54574 Mdot
.63906 .37961 Mdot
.46301 .7215 Mdot
.62854 .29983 Mdot
.47411 .70692 Mdot
.56458 .28264 Mdot
.33338 .51966 Mdot
.72159 .50172 Mdot
.70197 .49967 Mdot
.44058 .70299 Mdot
.32849 .50117 Mdot
.34133 .32877 Mdot
.58541 .69777 Mdot
.69035 .53238 Mdot
.58906 .69865 Mdot
.35902 .50522 Mdot
.56654 .69449 Mdot
.70522 .45069 Mdot
.69726 .58937 Mdot
.43721 .71542 Mdot
.45962 .71918 Mdot
.59576 .69173 Mdot
.52973 .69224 Mdot
.66267 .34122 Mdot
.57409 .68252 Mdot
.63687 .66542 Mdot
.46847 .70627 Mdot
.62504 .34282 Mdot
.33928 .65116 Mdot
.57606 .70124 Mdot
.37582 .33202 Mdot
.65053 .63765 Mdot
.36393 .33441 Mdot
.63651 .64576 Mdot
.59348 .2728 Mdot
.34094 .53291 Mdot
.57726 .26913 Mdot
.33328 .35587 Mdot
.64617 .38967 Mdot
.68713 .53751 Mdot
.45931 .32864 Mdot
.68987 .55089 Mdot
.35703 .69607 Mdot
.58643 .70208 Mdot
.7157 .53089 Mdot
.32788 .64913 Mdot
.36645 .51572 Mdot
.63686 .64447 Mdot
.66006 .35548 Mdot
.57085 .27851 Mdot
.35919 .68917 Mdot
.6796 .63263 Mdot
.67157 .33489 Mdot
.49566 .70859 Mdot
.61677 .30126 Mdot
.43765 .70295 Mdot
.68993 .49548 Mdot
.54599 .71039 Mdot
.57036 .28044 Mdot
.36365 .70021 Mdot
.64573 .67199 Mdot
.62945 .36598 Mdot
.68844 .56897 Mdot
.70672 .55496 Mdot
.36998 .49978 Mdot
.71222 .50592 Mdot
.65874 .36579 Mdot
.71581 .58951 Mdot
.6356 .65586 Mdot
.72006 .57747 Mdot
.34824 .33584 Mdot
.63448 .35775 Mdot
.46474 .31527 Mdot
.50124 .69379 Mdot
.65365 .3213 Mdot
.28794 .36934 Mdot
.54746 .2678 Mdot
.66308 .31486 Mdot
.65615 .63218 Mdot
.67932 .62554 Mdot
.47799 .72278 Mdot
.36157 .68788 Mdot
.65514 .35218 Mdot
.64185 .30334 Mdot
.26473 .56913 Mdot
.45477 .3308 Mdot
.58151 .29268 Mdot
.30093 .56723 Mdot
.45595 .70864 Mdot
.71595 .45139 Mdot
.30614 .55419 Mdot
.66189 .67223 Mdot
.29201 .59285 Mdot
.68909 .54042 Mdot
.6771 .37936 Mdot
.35994 .5046 Mdot
.33477 .33054 Mdot
.69825 .56813 Mdot
.69567 .56643 Mdot
.63681 .38892 Mdot
.65449 .62456 Mdot
.5923 .68102 Mdot
.65894 .33944 Mdot
.46597 .71032 Mdot
.45686 .32433 Mdot
.29546 .57342 Mdot
.5772 .69126 Mdot
.58502 .70243 Mdot
.63433 .35842 Mdot
.31747 .53846 Mdot
.69997 .52945 Mdot
.66718 .31837 Mdot
.47095 .70117 Mdot
.64686 .37455 Mdot
.48999 .29127 Mdot
.62216 .35984 Mdot
.5542 .67241 Mdot
.47 .33724 Mdot
.56967 .69372 Mdot
.46279 .29636 Mdot
.45614 .27612 Mdot
.33311 .334 Mdot
.65213 .38359 Mdot
.65007 .61527 Mdot
.57219 .2679 Mdot
.33596 .52239 Mdot
.29205 .56791 Mdot
.64232 .32325 Mdot
.34684 .34268 Mdot
.31995 .3026 Mdot
.33971 .30945 Mdot
.66313 .62637 Mdot
.43395 .71154 Mdot
.5533 .26335 Mdot
.57138 .2593 Mdot
.70705 .44166 Mdot
.55784 .67801 Mdot
.47584 .29876 Mdot
.68692 .53534 Mdot
.69369 .56719 Mdot
.35284 .34591 Mdot
.56667 .2599 Mdot
.56851 .68775 Mdot
.70233 .51162 Mdot
.6475 .67293 Mdot
.28323 .60967 Mdot
.42909 .32648 Mdot
.42329 .35334 Mdot
.46032 .29471 Mdot
.37005 .68805 Mdot
.71084 .50972 Mdot
.34701 .52037 Mdot
.3257 .35512 Mdot
.71407 .45844 Mdot
.32891 .32133 Mdot
.46558 .69861 Mdot
.676 .37936 Mdot
.68597 .67304 Mdot
.36867 .49437 Mdot
.32954 .5394 Mdot
.70886 .45868 Mdot
.33693 .48652 Mdot
.55422 .68546 Mdot
.63897 .6614 Mdot
.63615 .3408 Mdot
.27668 .63978 Mdot
.28172 .60058 Mdot
.27763 .58839 Mdot
.65037 .32573 Mdot
.43927 .32214 Mdot
.6032 .29413 Mdot
.27703 .5848 Mdot
.6978 .54969 Mdot
.45664 .69812 Mdot
.72024 .53027 Mdot
.35829 .47882 Mdot
.33639 .53338 Mdot
.46304 .71991 Mdot
.45569 .70309 Mdot
.69012 .55094 Mdot
.43614 .32571 Mdot
.44551 .33972 Mdot
.57332 .70731 Mdot
.33445 .51303 Mdot
.25922 .57381 Mdot
.35681 .53422 Mdot
.3408 .32938 Mdot
.28705 .64748 Mdot
.36734 .70534 Mdot
.35045 .6737 Mdot
.28474 .54901 Mdot
.35125 .53025 Mdot
.70673 .45326 Mdot
.68197 .63003 Mdot
.70321 .5274 Mdot
.73483 .46576 Mdot
.67234 .3403 Mdot
.33029 .31985 Mdot
.35812 .49588 Mdot
.35348 .35502 Mdot
.25161 .60368 Mdot
.35268 .37099 Mdot
.36802 .68054 Mdot
.34424 .69046 Mdot
.37083 .32596 Mdot
.35778 .53505 Mdot
.63606 .33055 Mdot
.63135 .3786 Mdot
.47299 .71775 Mdot
.35923 .4809 Mdot
.71042 .43673 Mdot
.71277 .55531 Mdot
.59818 .28677 Mdot
.60793 .29774 Mdot
.32385 .34506 Mdot
.47721 .28027 Mdot
.46284 .7043 Mdot
.36486 .49539 Mdot
.44049 .33059 Mdot
.63972 .3181 Mdot
.46736 .29686 Mdot
.5943 .27904 Mdot
.69251 .5283 Mdot
.71258 .53719 Mdot
.34091 .49912 Mdot
.2804 .34239 Mdot
.65235 .65519 Mdot
.67867 .62569 Mdot
.71311 .55699 Mdot
.65262 .38677 Mdot
.45101 .30785 Mdot
.56683 .72332 Mdot
.55192 .68219 Mdot
.33675 .36382 Mdot
.36851 .51641 Mdot
.62797 .36687 Mdot
.5314 .6973 Mdot
.32932 .35477 Mdot
.36833 .66548 Mdot
.65433 .30829 Mdot
.35148 .51302 Mdot
.4869 .70564 Mdot
.67648 .65901 Mdot
.3607 .68388 Mdot
.57706 .7001 Mdot
.70027 .55918 Mdot
.69893 .51727 Mdot
.33499 .53536 Mdot
.67441 .68079 Mdot
.58822 .66619 Mdot
.70554 .51107 Mdot
.37025 .32886 Mdot
.46345 .3206 Mdot
.32781 .32399 Mdot
.63225 .34058 Mdot
.33345 .3324 Mdot
.65827 .3245 Mdot
.58229 .27811 Mdot
.55932 .69265 Mdot
.34208 .34491 Mdot
.38727 .70471 Mdot
.46948 .31517 Mdot
.34084 .3757 Mdot
.36035 .67277 Mdot
.46753 .69662 Mdot
.64834 .35811 Mdot
.34979 .3578 Mdot
.34629 .54511 Mdot
.72921 .53702 Mdot
.73355 .44933 Mdot
.68766 .53698 Mdot
.44728 .31254 Mdot
.63819 .3641 Mdot
.57595 .68828 Mdot
.27837 .55772 Mdot
.52976 .6838 Mdot
.27481 .57477 Mdot
.34454 .50422 Mdot
.57739 .66599 Mdot
.57671 .68846 Mdot
.33601 .53787 Mdot
.30283 .56701 Mdot
.46759 .32031 Mdot
.69832 .56327 Mdot
.6595 .63065 Mdot
.66246 .63388 Mdot
.66688 .35865 Mdot
.54225 .69448 Mdot
.48512 .34801 Mdot
.68968 .53016 Mdot
.42372 .31737 Mdot
.69561 .5378 Mdot
.3049 .30896 Mdot
.65948 .3151 Mdot
.63313 .63054 Mdot
.64686 .62927 Mdot
.44553 .7156 Mdot
.55619 .6921 Mdot
.35156 .33667 Mdot
.54222 .69799 Mdot
.55694 .6989 Mdot
.33316 .51435 Mdot
.43733 .33157 Mdot
.47016 .30152 Mdot
.37142 .68637 Mdot
.65267 .65418 Mdot
.34607 .53304 Mdot
.35888 .66774 Mdot
.33041 .53131 Mdot
.3626 .68431 Mdot
.63905 .6519 Mdot
.33681 .48208 Mdot
.54967 .6955 Mdot
.64225 .67892 Mdot
.45256 .36027 Mdot
.47036 .31123 Mdot
.47185 .29537 Mdot
.72915 .43006 Mdot
.28016 .56906 Mdot
.58008 .27266 Mdot
.46334 .70896 Mdot
.4529 .33387 Mdot
.39926 .70205 Mdot
.35336 .36179 Mdot
.28845 .58405 Mdot
.44523 .32929 Mdot
.66043 .35084 Mdot
.44723 .71636 Mdot
.286 .5752 Mdot
.44026 .31649 Mdot
.56184 .68877 Mdot
.6655 .65406 Mdot
.56385 .67662 Mdot
.35941 .33785 Mdot
.69292 .53349 Mdot
.46007 .70869 Mdot
.63465 .33805 Mdot
.58084 .27068 Mdot
.57037 .69284 Mdot
.6721 .37653 Mdot
.71222 .54609 Mdot
.28234 .57703 Mdot
.69453 .55876 Mdot
.35909 .35626 Mdot
.65519 .63587 Mdot
.45494 .71524 Mdot
.45488 .73067 Mdot
.54186 .70455 Mdot
.46799 .32429 Mdot
.33923 .31245 Mdot
.66998 .38524 Mdot
.67435 .65274 Mdot
.69307 .53031 Mdot
.66939 .36226 Mdot
.45509 .71976 Mdot
.36026 .36841 Mdot
.30931 .55305 Mdot
.34899 .49102 Mdot
.48716 .68799 Mdot
.33805 .49604 Mdot
.58006 .26744 Mdot
.58205 .70177 Mdot
.44613 .70019 Mdot
.34487 .68644 Mdot
.2862 .32682 Mdot
.32265 .31968 Mdot
.35644 .52446 Mdot
.39599 .69923 Mdot
.32136 .52905 Mdot
.65783 .61034 Mdot
.35831 .68597 Mdot
.67619 .33674 Mdot
.42469 .35422 Mdot
.73534 .46451 Mdot
.45139 .32848 Mdot
.67466 .37968 Mdot
.30126 .57033 Mdot
.31358 .55115 Mdot
.68629 .6579 Mdot
.46575 .69733 Mdot
.70921 .52722 Mdot
.33086 .49255 Mdot
.66154 .35803 Mdot
.5604 .26954 Mdot
.36651 .47741 Mdot
.55745 .68284 Mdot
.72367 .51425 Mdot
.44304 .33279 Mdot
.46971 .29433 Mdot
.33332 .35738 Mdot
.67945 .35501 Mdot
.48967 .31914 Mdot
.69934 .53117 Mdot
.35001 .54377 Mdot
.36861 .70563 Mdot
.73318 .53653 Mdot
.53739 .70563 Mdot
.71902 .43681 Mdot
.30215 .31082 Mdot
.34271 .51806 Mdot
.64621 .65602 Mdot
.55409 .70715 Mdot
.33291 .3637 Mdot
.58995 .27393 Mdot
.58487 .28847 Mdot
.28301 .35565 Mdot
.45604 .3413 Mdot
.641 .31788 Mdot
.48834 .31804 Mdot
.46657 .7128 Mdot
.36336 .67696 Mdot
.73292 .44443 Mdot
.33626 .51734 Mdot
.63317 .681 Mdot
.56993 .70764 Mdot
.36188 .52285 Mdot
.34263 .31784 Mdot
.59102 .71009 Mdot
.4568 .72683 Mdot
.36984 .52989 Mdot
.63325 .3633 Mdot
.33974 .51493 Mdot
.48695 .34803 Mdot
.42749 .31306 Mdot
.33206 .5103 Mdot
.66178 .34227 Mdot
.47123 .33633 Mdot
.34621 .31568 Mdot
.56732 .7116 Mdot
.45198 .32701 Mdot
.4708 .70043 Mdot
.29572 .56913 Mdot
.36927 .32717 Mdot
.46405 .71722 Mdot
.55109 .67028 Mdot
.47124 .2912 Mdot
.65268 .37746 Mdot
.66475 .66533 Mdot
.33911 .52518 Mdot
.46435 .32218 Mdot
.36713 .50671 Mdot
.60532 .66262 Mdot
.35077 .49286 Mdot
.69682 .5872 Mdot
.67994 .65476 Mdot
.70327 .53855 Mdot
.44737 .71293 Mdot
.35066 .51102 Mdot
.48676 .32068 Mdot
.45509 .30489 Mdot
.27316 .59014 Mdot
.5711 .69413 Mdot
.55778 .70323 Mdot
.56938 .67883 Mdot
.66534 .36599 Mdot
.25276 .59378 Mdot
.70436 .54515 Mdot
.43819 .32694 Mdot
.71295 .50637 Mdot
.39109 .69094 Mdot
.35874 .33455 Mdot
.72631 .55731 Mdot
.27781 .57846 Mdot
.67691 .63113 Mdot
.30583 .60019 Mdot
.67667 .61537 Mdot
.72544 .42629 Mdot
.71737 .43632 Mdot
.65623 .64746 Mdot
.35606 .52827 Mdot
.37004 .69008 Mdot
.36309 .70534 Mdot
.70817 .51131 Mdot
.43291 .33853 Mdot
.52105 .3139 Mdot
.62579 .35594 Mdot
.35637 .37073 Mdot
.71186 .46765 Mdot
.70928 .48661 Mdot
.44069 .70763 Mdot
.66377 .66155 Mdot
.69954 .52317 Mdot
.68616 .56222 Mdot
.65617 .3634 Mdot
.44314 .71192 Mdot
.35445 .50845 Mdot
.47508 .31786 Mdot
.72725 .45359 Mdot
.27794 .59428 Mdot
.45534 .69548 Mdot
.60038 .28654 Mdot
.5806 .68272 Mdot
.73278 .54928 Mdot
.38641 .68235 Mdot
.59114 .67394 Mdot
.61246 .30101 Mdot
.63516 .65537 Mdot
.34752 .53024 Mdot
.45466 .31156 Mdot
.66956 .38051 Mdot
.2905 .5644 Mdot
.57332 .26523 Mdot
.70962 .52197 Mdot
.73066 .52811 Mdot
.38431 .68629 Mdot
.62732 .30067 Mdot
.34022 .53665 Mdot
.46771 .72617 Mdot
.33148 .34164 Mdot
.70567 .51605 Mdot
.67297 .67139 Mdot
.3692 .50737 Mdot
.6679 .34841 Mdot
.62338 .34811 Mdot
.57128 .7012 Mdot
.56046 .67771 Mdot
.6449 .6189 Mdot
.46416 .31343 Mdot
.67417 .36007 Mdot
.46527 .32097 Mdot
.36517 .53573 Mdot
.70418 .51068 Mdot
.3478 .31541 Mdot
.66222 .38569 Mdot
.71725 .46934 Mdot
.46821 .69686 Mdot
.66135 .6227 Mdot
.49651 .69129 Mdot
.46671 .72177 Mdot
.6787 .35825 Mdot
.3548 .32677 Mdot
.35521 .67985 Mdot
.44027 .72069 Mdot
.36533 .33124 Mdot
.66237 .36387 Mdot
.66116 .65388 Mdot
.55666 .70892 Mdot
.68327 .63671 Mdot
.37888 .70458 Mdot
.53012 .71876 Mdot
.2992 .5903 Mdot
.32959 .51344 Mdot
.63178 .64761 Mdot
.28721 .55527 Mdot
.68803 .53652 Mdot
.67912 .64311 Mdot
.36172 .68404 Mdot
.44168 .69687 Mdot
.29326 .59487 Mdot
.31648 .54532 Mdot
.45821 .70109 Mdot
.28012 .56899 Mdot
.56681 .66714 Mdot
.58449 .70282 Mdot
.35149 .67568 Mdot
.69977 .50913 Mdot
.35037 .33112 Mdot
.63566 .66545 Mdot
.34169 .51112 Mdot
.56819 .66608 Mdot
.3557 .67308 Mdot
.69693 .58687 Mdot
.46199 .70077 Mdot
.67761 .37794 Mdot
.30758 .55904 Mdot
.62131 .3524 Mdot
.45129 .72928 Mdot
.56969 .66523 Mdot
.72949 .44402 Mdot
.4555 .72719 Mdot
.65593 .30561 Mdot
.33026 .4928 Mdot
.45722 .30873 Mdot
.33099 .33258 Mdot
.47825 .33088 Mdot
.68892 .55106 Mdot
.2851 .56698 Mdot
.30239 .55981 Mdot
.34871 .48253 Mdot
.36581 .53517 Mdot
.47032 .31283 Mdot
.3768 .33744 Mdot
.60606 .6647 Mdot
.28858 .57899 Mdot
.63725 .37985 Mdot
.65121 .66472 Mdot
.29913 .57898 Mdot
.36089 .70717 Mdot
.48548 .70935 Mdot
.65329 .65263 Mdot
.65772 .62164 Mdot
.50697 .33283 Mdot
.3392 .33929 Mdot
.33204 .53221 Mdot
.37547 .3239 Mdot
.46006 .71086 Mdot
.69271 .5448 Mdot
.34929 .48061 Mdot
.65984 .31579 Mdot
.35598 .69096 Mdot
.66263 .36559 Mdot
.32565 .53985 Mdot
.65327 .63291 Mdot
.69939 .51822 Mdot
.57652 .28635 Mdot
.58002 .29086 Mdot
.28595 .60523 Mdot
.56002 .26065 Mdot
.35838 .34403 Mdot
.35416 .34129 Mdot
.6994 .52088 Mdot
.35744 .5303 Mdot
.35406 .68608 Mdot
.41799 .71072 Mdot
.28526 .56395 Mdot
.33119 .5467 Mdot
.72101 .46913 Mdot
.71406 .46364 Mdot
.66071 .38478 Mdot
.33386 .54071 Mdot
.28212 .59334 Mdot
.65133 .64504 Mdot
.32655 .31956 Mdot
.67595 .35396 Mdot
.32752 .35249 Mdot
.65119 .33075 Mdot
.25083 .62254 Mdot
.43178 .33231 Mdot
.357 .33911 Mdot
.70579 .46562 Mdot
.67321 .63077 Mdot
.47309 .31579 Mdot
.64399 .35262 Mdot
.67356 .37023 Mdot
.29787 .57881 Mdot
.53808 .70796 Mdot
.63792 .65968 Mdot
.36165 .33691 Mdot
.71057 .55976 Mdot
.46334 .72163 Mdot
.46196 .29425 Mdot
.29582 .31583 Mdot
.67172 .35613 Mdot
.66571 .60799 Mdot
.50249 .69648 Mdot
.34982 .50201 Mdot
.66538 .65312 Mdot
.35254 .50394 Mdot
.57333 .68277 Mdot
.63885 .67285 Mdot
.3629 .47727 Mdot
.5761 .67505 Mdot
.64761 .31473 Mdot
.55871 .27517 Mdot
.44468 .69843 Mdot
.70551 .42792 Mdot
.46382 .71019 Mdot
.60206 .29567 Mdot
.30579 .59898 Mdot
.29499 .56544 Mdot
.34233 .50854 Mdot
.37805 .36144 Mdot
.29455 .54695 Mdot
.45283 .29989 Mdot
.45827 .30865 Mdot
.66052 .65739 Mdot
.48182 .32831 Mdot
.36846 .68697 Mdot
.34221 .34918 Mdot
.63605 .3421 Mdot
.29183 .60545 Mdot
.36041 .33126 Mdot
.56267 .70967 Mdot
.44426 .7206 Mdot
.62902 .65628 Mdot
.62594 .37013 Mdot
.44275 .32186 Mdot
.70909 .52341 Mdot
.35137 .65746 Mdot
.66469 .35206 Mdot
.72187 .45584 Mdot
.37565 .68146 Mdot
.67837 .37858 Mdot
.69302 .51894 Mdot
.55714 .27359 Mdot
.71843 .44787 Mdot
.71724 .54511 Mdot
.37234 .7008 Mdot
.34159 .34971 Mdot
.47881 .33214 Mdot
.37851 .32785 Mdot
.72616 .44304 Mdot
.60269 .30124 Mdot
.64324 .36522 Mdot
.34522 .68253 Mdot
.53199 .71925 Mdot
.46513 .33057 Mdot
.33412 .54364 Mdot
.71312 .45479 Mdot
.24932 .60237 Mdot
.47879 .33182 Mdot
.71098 .54016 Mdot
.45303 .72967 Mdot
.28262 .64547 Mdot
.45865 .31561 Mdot
.47495 .30513 Mdot
.34644 .357 Mdot
.59 .28454 Mdot
.63751 .64933 Mdot
.34936 .3644 Mdot
.33847 .49028 Mdot
.33363 .52102 Mdot
.69003 .54815 Mdot
.4508 .32658 Mdot
.70679 .54876 Mdot
.33588 .31802 Mdot
.37569 .34027 Mdot
.56626 .71115 Mdot
.56493 .67997 Mdot
.49129 .30632 Mdot
.28294 .54925 Mdot
.3112 .53933 Mdot
.68187 .66467 Mdot
.64441 .63995 Mdot
.32304 .51239 Mdot
.35069 .31141 Mdot
.34343 .35919 Mdot
.46287 .72813 Mdot
.3545 .66798 Mdot
.45276 .70142 Mdot
.37554 .67317 Mdot
.67547 .40811 Mdot
.44922 .71509 Mdot
.67188 .38268 Mdot
.37412 .67127 Mdot
.69964 .45539 Mdot
.47525 .71698 Mdot
.35411 .49792 Mdot
.64908 .3369 Mdot
.32731 .52672 Mdot
.63056 .34711 Mdot
.3419 .53094 Mdot
.68072 .34584 Mdot
.63483 .33809 Mdot
.52535 .30612 Mdot
.31626 .64892 Mdot
.45585 .29911 Mdot
.36072 .31792 Mdot
.42035 .34691 Mdot
.30871 .56999 Mdot
.66155 .64989 Mdot
.53511 .72278 Mdot
.35009 .50048 Mdot
.65377 .36509 Mdot
.71246 .5243 Mdot
.46642 .73074 Mdot
.35861 .48526 Mdot
.47028 .7158 Mdot
.66124 .62238 Mdot
.63344 .361 Mdot
.32832 .33616 Mdot
.59749 .27518 Mdot
.59759 .29415 Mdot
.65656 .31291 Mdot
.37972 .51068 Mdot
.48342 .71123 Mdot
.4876 .34759 Mdot
.58698 .68419 Mdot
.32536 .30181 Mdot
.55081 .70398 Mdot
.45497 .32794 Mdot
.3351 .35545 Mdot
.29728 .64562 Mdot
.64492 .6649 Mdot
.64978 .32584 Mdot
.35056 .5142 Mdot
.43412 .32483 Mdot
.37853 .32862 Mdot
.6606 .67179 Mdot
.36957 .3267 Mdot
.64382 .34678 Mdot
.45994 .32089 Mdot
.25129 .59523 Mdot
.34521 .47121 Mdot
.34143 .67293 Mdot
.34829 .51184 Mdot
.36384 .33655 Mdot
.53649 .70675 Mdot
.47045 .71694 Mdot
.72339 .44979 Mdot
.36269 .68801 Mdot
.32886 .5462 Mdot
.62404 .29905 Mdot
.65919 .62561 Mdot
.34668 .33694 Mdot
.7133 .45324 Mdot
.33796 .33791 Mdot
.46722 .29508 Mdot
.56837 .68323 Mdot
.46725 .29435 Mdot
.46234 .69687 Mdot
.70243 .52293 Mdot
.63913 .66107 Mdot
.60443 .29294 Mdot
.45107 .34161 Mdot
.64021 .32318 Mdot
.29645 .64784 Mdot
.56919 .69888 Mdot
.7289 .46665 Mdot
.59537 .27271 Mdot
.69246 .58073 Mdot
.34645 .67006 Mdot
.70466 .56279 Mdot
.34906 .50076 Mdot
.684 .64172 Mdot
.71758 .51741 Mdot
.583 .29133 Mdot
.39497 .7 Mdot
.45165 .29586 Mdot
.36265 .52734 Mdot
.71762 .58322 Mdot
.70291 .50106 Mdot
.54928 .69228 Mdot
.71104 .46873 Mdot
.31815 .54741 Mdot
.46783 .31683 Mdot
.33665 .50611 Mdot
.71981 .44018 Mdot
.71693 .47235 Mdot
.57414 .27786 Mdot
.34896 .5194 Mdot
.33918 .33125 Mdot
.67568 .37908 Mdot
.62408 .34439 Mdot
.66347 .38082 Mdot
.5895 .66946 Mdot
.44148 .33753 Mdot
.4635 .31188 Mdot
.30296 .60086 Mdot
.70658 .55328 Mdot
.45401 .29991 Mdot
.29303 .57263 Mdot
.3045 .57312 Mdot
.6828 .64165 Mdot
.64866 .34455 Mdot
.32747 .54168 Mdot
.44054 .69958 Mdot
.44401 .31189 Mdot
.65744 .33904 Mdot
.56413 .68873 Mdot
.60848 .29615 Mdot
.28414 .57229 Mdot
.44422 .70379 Mdot
.54328 .70733 Mdot
.55312 .66761 Mdot
.29213 .54696 Mdot
.35396 .50371 Mdot
.69307 .56099 Mdot
.50666 .66208 Mdot
.35848 .60215 Mdot
.44353 .50092 Mdot
.46253 .33432 Mdot
.59792 .56066 Mdot
.46497 .64654 Mdot
.42105 .71278 Mdot
.49856 .58584 Mdot
.40293 .69417 Mdot
.54509 .61445 Mdot
.63821 .4258 Mdot
.47342 .55882 Mdot
.56738 .2935 Mdot
.66982 .48928 Mdot
.48112 .72981 Mdot
.32919 .4011 Mdot
.6696 .56665 Mdot
.50835 .62857 Mdot
.67384 .4914 Mdot
.60249 .4482 Mdot
.60779 .32807 Mdot
.64123 .39333 Mdot
.60715 .40828 Mdot
.3488 .54534 Mdot
.53739 .64074 Mdot
.37366 .61984 Mdot
.64116 .59351 Mdot
.67889 .42399 Mdot
.43288 .70297 Mdot
.40393 .38163 Mdot
.61662 .56912 Mdot
.45183 .39627 Mdot
.40671 .66546 Mdot
.6312 .44683 Mdot
.37199 .61481 Mdot
.38287 .42357 Mdot
.4138 .68849 Mdot
.55106 .58531 Mdot
.59941 .59073 Mdot
.41976 .64327 Mdot
.62536 .55364 Mdot
.66822 .33675 Mdot
.53275 .70459 Mdot
.67352 .51724 Mdot
.46076 .38112 Mdot
.64378 .54514 Mdot
.49776 .58686 Mdot
.48939 .31019 Mdot
.59928 .55334 Mdot
.25727 .59995 Mdot
.6777 .61091 Mdot
.6504 .46963 Mdot
.67241 .42905 Mdot
.43083 .65146 Mdot
.6767 .44605 Mdot
.30201 .6388 Mdot
.51258 .6304 Mdot
.47155 .64976 Mdot
.60538 .44431 Mdot
.56021 .34925 Mdot
.65038 .63033 Mdot
.34419 .41744 Mdot
.56021 .42951 Mdot
.41223 .49511 Mdot
.65553 .48741 Mdot
.42847 .67451 Mdot
.60652 .6773 Mdot
.68995 .63903 Mdot
.60206 .35315 Mdot
.48343 .36382 Mdot
.61539 .4069 Mdot
.56951 .43061 Mdot
.64603 .53421 Mdot
.33562 .61865 Mdot
.58411 .60822 Mdot
.5868 .36791 Mdot
.51124 .67817 Mdot
.36744 .3832 Mdot
.55192 .51456 Mdot
.42921 .36548 Mdot
.4492 .65469 Mdot
.61342 .4534 Mdot
.44473 .58958 Mdot
.61248 .52623 Mdot
.28162 .62438 Mdot
.4453 .37032 Mdot
.54038 .63924 Mdot
.56221 .37668 Mdot
.66638 .57026 Mdot
.47856 .66612 Mdot
.66814 .44614 Mdot
.424 .31234 Mdot
.44652 .43248 Mdot
.40743 .36678 Mdot
.50736 .57913 Mdot
.38083 .40686 Mdot
.63131 .44435 Mdot
.68382 .49409 Mdot
.62829 .32471 Mdot
.62099 .61522 Mdot
.47611 .38495 Mdot
.636 .67905 Mdot
.60018 .31532 Mdot
.48735 .61168 Mdot
.60914 .6282 Mdot
.40455 .36927 Mdot
.60614 .367 Mdot
.60124 .51586 Mdot
.5985 .42089 Mdot
.59733 .58602 Mdot
.57296 .61304 Mdot
.67427 .5769 Mdot
.48491 .28732 Mdot
.57018 .65405 Mdot
.43819 .39703 Mdot
.62667 .3971 Mdot
.33813 .39002 Mdot
.2709 .56502 Mdot
.46736 .40435 Mdot
.46278 .68072 Mdot
.50604 .48353 Mdot
.65958 .58775 Mdot
.41565 .36132 Mdot
.43122 .70157 Mdot
.51658 .67004 Mdot
.60579 .40515 Mdot
.3873 .48553 Mdot
.66834 .59928 Mdot
.67731 .48908 Mdot
.61482 .35406 Mdot
.46294 .66146 Mdot
.48299 .35299 Mdot
.33743 .57203 Mdot
.40954 .45516 Mdot
.6839 .41202 Mdot
.40639 .4865 Mdot
.43551 .45675 Mdot
.542 .29365 Mdot
.61501 .63374 Mdot
.43373 .43853 Mdot
.4781 .68381 Mdot
.58226 .36193 Mdot
.63137 .4201 Mdot
.52385 .65421 Mdot
.30088 .33399 Mdot
.39853 .39938 Mdot
.45522 .46392 Mdot
.60187 .53772 Mdot
.4197 .71982 Mdot
.38835 .59898 Mdot
.62675 .43613 Mdot
.51454 .41341 Mdot
.54361 .36184 Mdot
.67782 .48245 Mdot
.64017 .68152 Mdot
.49789 .39507 Mdot
.42388 .58376 Mdot
.52264 .68251 Mdot
.49972 .43355 Mdot
.65103 .60389 Mdot
.484 .42385 Mdot
.40272 .37801 Mdot
.6304 .3861 Mdot
.59407 .37631 Mdot
.65015 .53431 Mdot
.675 .43221 Mdot
.57913 .63043 Mdot
.58576 .63071 Mdot
.50954 .3746 Mdot
.66668 .55517 Mdot
.6225 .47109 Mdot
.68831 .62815 Mdot
.51413 .61582 Mdot
.40439 .64046 Mdot
.35781 .59156 Mdot
.44358 .54832 Mdot
.35486 .31057 Mdot
.38377 .43137 Mdot
.46439 .66377 Mdot
.30107 .31872 Mdot
.39136 .54045 Mdot
.36676 .61265 Mdot
.46143 .29048 Mdot
.34334 .58587 Mdot
.26547 .62382 Mdot
.57377 .53286 Mdot
.60047 .37525 Mdot
.45673 .48354 Mdot
.34989 .57702 Mdot
.65095 .5893 Mdot
.40949 .6886 Mdot
.41648 .36261 Mdot
.51924 .33853 Mdot
.49562 .64552 Mdot
.54527 .65345 Mdot
.69756 .43263 Mdot
.71103 .49455 Mdot
.55017 .29425 Mdot
.6507 .5333 Mdot
.59935 .69346 Mdot
.58534 .26762 Mdot
.60779 .48142 Mdot
.43673 .60004 Mdot
.36339 .63668 Mdot
.43445 .37751 Mdot
.58062 .54901 Mdot
.33414 .3757 Mdot
.45533 .62276 Mdot
.43962 .47772 Mdot
.39129 .39354 Mdot
.3611 .40086 Mdot
.35635 .41005 Mdot
.67092 .52764 Mdot
.37724 .43189 Mdot
.39431 .36966 Mdot
.25316 .60802 Mdot
.56582 .46778 Mdot
.43154 .7244 Mdot
.4012 .5622 Mdot
.58874 .31944 Mdot
.56118 .41827 Mdot
.57062 .60701 Mdot
.43106 .65231 Mdot
.39213 .35589 Mdot
.26427 .62116 Mdot
.62404 .53506 Mdot
.43452 .40289 Mdot
.57017 .38784 Mdot
.46285 .40033 Mdot
.52334 .36608 Mdot
.52745 .58071 Mdot
.67655 .49099 Mdot
.28326 .34223 Mdot
.56688 .34472 Mdot
.63521 .57941 Mdot
.49394 .67853 Mdot
.59492 .31895 Mdot
.59837 .64081 Mdot
.60888 .60746 Mdot
.44766 .64244 Mdot
.40152 .59396 Mdot
.46957 .51854 Mdot
.55769 .58679 Mdot
.39657 .4372 Mdot
.54525 .39601 Mdot
.63203 .38596 Mdot
.54878 .31145 Mdot
.46614 .50399 Mdot
.56009 .4627 Mdot
.35903 .5619 Mdot
.60608 .34967 Mdot
.54714 .55441 Mdot
.35311 .60548 Mdot
.45584 .47991 Mdot
.51061 .63882 Mdot
.63769 .61777 Mdot
.41417 .58855 Mdot
.27363 .56891 Mdot
.45935 .37795 Mdot
.55229 .28674 Mdot
.51928 .36222 Mdot
.53779 .6467 Mdot
.68685 .45836 Mdot
.65738 .51237 Mdot
.3811 .5428 Mdot
.3461 .63014 Mdot
.51437 .5473 Mdot
.36455 .65086 Mdot
.7114 .5666 Mdot
.60909 .67739 Mdot
.56567 .63347 Mdot
.33167 .5536 Mdot
.44944 .56198 Mdot
.55061 .62835 Mdot
.3986 .51271 Mdot
.47077 .67976 Mdot
.60684 .66107 Mdot
.57423 .34961 Mdot
.63562 .38896 Mdot
.30521 .34875 Mdot
.55585 .43948 Mdot
.32318 .34972 Mdot
.53739 .32786 Mdot
.59762 .52884 Mdot
.40813 .66109 Mdot
.68829 .43849 Mdot
.53266 .37417 Mdot
.58181 .29941 Mdot
.52548 .36406 Mdot
.62649 .41458 Mdot
.65384 .49387 Mdot
.32673 .60067 Mdot
.62294 .58127 Mdot
.67629 .47299 Mdot
.3102 .61239 Mdot
.64448 .41068 Mdot
.61099 .54234 Mdot
.68129 .60928 Mdot
.26338 .58714 Mdot
.30512 .60304 Mdot
.36896 .43101 Mdot
.32867 .61263 Mdot
.43415 .50532 Mdot
.54772 .7216 Mdot
.35738 .44023 Mdot
.62858 .53613 Mdot
.43729 .72556 Mdot
.53991 .6568 Mdot
.66971 .59468 Mdot
.48848 .67873 Mdot
.60374 .30695 Mdot
.69257 .46889 Mdot
.55815 .62445 Mdot
.38549 .54385 Mdot
.4061 .40621 Mdot
.38681 .52681 Mdot
.55766 .65127 Mdot
.41396 .56605 Mdot
.63672 .61605 Mdot
.43665 .65172 Mdot
.56721 .49897 Mdot
.62125 .61991 Mdot
.46513 .61526 Mdot
.47169 .6758 Mdot
.49963 .71297 Mdot
.50178 .36049 Mdot
.36875 .44907 Mdot
.5431 .59272 Mdot
.32649 .51442 Mdot
.49346 .48288 Mdot
.495 .61247 Mdot
.35424 .5521 Mdot
.52524 .60296 Mdot
.33929 .42565 Mdot
.68495 .66473 Mdot
.5817 .5833 Mdot
.52541 .40632 Mdot
.36721 .53709 Mdot
.40553 .6635 Mdot
.4802 .66441 Mdot
.67692 .48524 Mdot
.36529 .44653 Mdot
.48841 .35993 Mdot
.54503 .49684 Mdot
.35166 .57206 Mdot
.46164 .44979 Mdot
.37214 .44171 Mdot
.47567 .28536 Mdot
.51814 .36907 Mdot
.6017 .5603 Mdot
.32162 .40347 Mdot
.66267 .41325 Mdot
.44138 .53982 Mdot
.44366 .59462 Mdot
.57461 .34508 Mdot
.46167 .59559 Mdot
.47568 .57841 Mdot
.46816 .47958 Mdot
.58786 .33635 Mdot
.57662 .5653 Mdot
.61875 .54563 Mdot
.60442 .66007 Mdot
.38736 .38256 Mdot
.55918 .6091 Mdot
.60805 .6122 Mdot
.53864 .4042 Mdot
.35484 .48866 Mdot
.43657 .55254 Mdot
.6637 .60472 Mdot
.50922 .44952 Mdot
.57341 .62096 Mdot
.55948 .28761 Mdot
.58684 .54386 Mdot
.45867 .49267 Mdot
.32312 .3995 Mdot
.31262 .39469 Mdot
.41494 .6158 Mdot
.40123 .35224 Mdot
.62928 .5334 Mdot
.57037 .64624 Mdot
.62536 .56021 Mdot
.33302 .63484 Mdot
.66524 .67866 Mdot
.50635 .34549 Mdot
.70086 .42581 Mdot
.65081 .5868 Mdot
.44245 .62246 Mdot
.46569 .35908 Mdot
.55725 .47233 Mdot
.61667 .48389 Mdot
.68496 .46477 Mdot
.61441 .37274 Mdot
.59941 .36522 Mdot
.42609 .5493 Mdot
.65141 .4465 Mdot
.56336 .3496 Mdot
.60267 .6356 Mdot
.58384 .30351 Mdot
.56094 .35982 Mdot
.44026 .68685 Mdot
.58604 .36774 Mdot
.5823 .65708 Mdot
.66702 .44288 Mdot
.49266 .60826 Mdot
.5942 .53589 Mdot
.51196 .4307 Mdot
.574 .6505 Mdot
.66839 .5234 Mdot
.57945 .49475 Mdot
.29006 .63984 Mdot
.48511 .67104 Mdot
.51742 .6753 Mdot
.3792 .62287 Mdot
.59578 .51188 Mdot
.33482 .41771 Mdot
.72275 .43098 Mdot
.31432 .62739 Mdot
.67961 .61017 Mdot
.25436 .61171 Mdot
.62075 .47457 Mdot
.3815 .67342 Mdot
.49987 .36369 Mdot
.62391 .47441 Mdot
.34921 .40656 Mdot
.55758 .26604 Mdot
.35717 .43414 Mdot
.58353 .60083 Mdot
.53646 .32893 Mdot
.58422 .31969 Mdot
.56554 .30815 Mdot
.34964 .39766 Mdot
.55671 .33684 Mdot
.30188 .6189 Mdot
.58071 .50814 Mdot
.33956 .62092 Mdot
.38807 .50212 Mdot
.56696 .33468 Mdot
.57521 .71843 Mdot
.41448 .41184 Mdot
.47695 .63102 Mdot
.63962 .40147 Mdot
.36509 .4364 Mdot
.27986 .60983 Mdot
.4945 .45256 Mdot
.60866 .43304 Mdot
.63886 .31441 Mdot
.33036 .3842 Mdot
.52897 .65449 Mdot
.50506 .39018 Mdot
.51756 .66754 Mdot
.49689 .68628 Mdot
.6439 .42947 Mdot
.46937 .64023 Mdot
.28501 .33865 Mdot
.64369 .4828 Mdot
.51564 .32604 Mdot
.61202 .53365 Mdot
.68669 .59696 Mdot
.38794 .48137 Mdot
.50722 .37229 Mdot
.50794 .39335 Mdot
.34016 .40054 Mdot
.42001 .41423 Mdot
.42098 .42178 Mdot
.33625 .42267 Mdot
.49637 .63814 Mdot
.32539 .62235 Mdot
.39154 .39025 Mdot
.41397 .64082 Mdot
.48317 .36489 Mdot
.69049 .57298 Mdot
.60231 .45383 Mdot
.62229 .64604 Mdot
.34039 .60056 Mdot
.33571 .61014 Mdot
.53932 .3732 Mdot
.66528 .57364 Mdot
.45644 .52155 Mdot
.4569 .46648 Mdot
.67198 .43888 Mdot
.33121 .63938 Mdot
.52962 .59027 Mdot
.32851 .38948 Mdot
.27186 .57 Mdot
.43744 .2851 Mdot
.59686 .37647 Mdot
.62126 .58173 Mdot
.58967 .52206 Mdot
.6183 .65127 Mdot
.42997 .51405 Mdot
.32262 .57088 Mdot
.39163 .38218 Mdot
.589 .5206 Mdot
.3597 .61675 Mdot
.38595 .46341 Mdot
.60494 .61683 Mdot
.65447 .55653 Mdot
.50679 .58853 Mdot
.58806 .44832 Mdot
.25629 .58351 Mdot
.61137 .4048 Mdot
.56031 .28678 Mdot
.33606 .41551 Mdot
.65621 .54798 Mdot
.33716 .60239 Mdot
.44331 .447 Mdot
.57403 .40844 Mdot
.32266 .39006 Mdot
.60832 .34805 Mdot
.46442 .66444 Mdot
.63871 .40895 Mdot
.65941 .56831 Mdot
.61382 .47814 Mdot
.32323 .61248 Mdot
.34463 .41865 Mdot
.43454 .61118 Mdot
.55977 .51711 Mdot
.476 .44377 Mdot
.36286 .65735 Mdot
.54184 .63694 Mdot
.40148 .59765 Mdot
.6765 .54778 Mdot
.33839 .40304 Mdot
.61184 .41989 Mdot
.37919 .44802 Mdot
.33217 .40185 Mdot
.5721 .71574 Mdot
.56828 .6359 Mdot
.68192 .49956 Mdot
.35454 .57456 Mdot
.6385 .3122 Mdot
.27157 .59721 Mdot
.2801 .63372 Mdot
.46699 .60949 Mdot
.50129 .40265 Mdot
.28753 .3365 Mdot
.47896 .67454 Mdot
.60201 .40653 Mdot
.48108 .68011 Mdot
.56903 .29895 Mdot
.5253 .57627 Mdot
.46447 .65012 Mdot
.42473 .5144 Mdot
.65025 .49755 Mdot
.50067 .63743 Mdot
.44988 .39738 Mdot
.40596 .55378 Mdot
.45526 .64538 Mdot
.45577 .65158 Mdot
.43066 .59443 Mdot
.63125 .60265 Mdot
.43219 .39564 Mdot
.61181 .38203 Mdot
.29585 .32058 Mdot
.41215 .64286 Mdot
.34066 .6101 Mdot
.59853 .53529 Mdot
.47091 .39633 Mdot
.5672 .26333 Mdot
.29131 .35511 Mdot
.38372 .64974 Mdot
.64197 .61388 Mdot
.52271 .5393 Mdot
.34738 .6241 Mdot
.33222 .62447 Mdot
.66279 .48401 Mdot
.59851 .5199 Mdot
.44822 .50344 Mdot
.53514 .71641 Mdot
.72496 .54829 Mdot
.36685 .31492 Mdot
.29918 .32156 Mdot
.64134 .56099 Mdot
.40422 .61224 Mdot
.58616 .35741 Mdot
.68275 .60112 Mdot
.30628 .32695 Mdot
.63311 .50988 Mdot
.32723 .55401 Mdot
.38747 .58281 Mdot
.28645 .35158 Mdot
.38088 .41842 Mdot
.5585 .7171 Mdot
.5834 .63777 Mdot
.65329 .46451 Mdot
.53016 .3772 Mdot
.56404 .53786 Mdot
.56245 .33148 Mdot
.45366 .42664 Mdot
.5094 .3822 Mdot
.46016 .63672 Mdot
.49899 .571 Mdot
.61962 .40161 Mdot
.53428 .33267 Mdot
.6249 .39302 Mdot
.4235 .47965 Mdot
.5661 .43218 Mdot
.64768 .39942 Mdot
.49893 .44476 Mdot
.63738 .52312 Mdot
.43032 .72036 Mdot
.5119 .55231 Mdot
.58572 .33305 Mdot
.53173 .71147 Mdot
.59393 .43265 Mdot
.48869 .6493 Mdot
.64881 .5852 Mdot
.43424 .3986 Mdot
.56525 .64116 Mdot
.61575 .38963 Mdot
.34163 .61358 Mdot
.5615 .39176 Mdot
.40122 .6561 Mdot
.40676 .48204 Mdot
.48532 .30526 Mdot
.40585 .45081 Mdot
.44117 .29336 Mdot
.28356 .61635 Mdot
.39741 .52638 Mdot
.44441 .37412 Mdot
.28121 .62083 Mdot
.51663 .43138 Mdot
.61689 .45447 Mdot
.68733 .62141 Mdot
.41361 .36437 Mdot
.32747 .57183 Mdot
.5804 .65212 Mdot
.59784 .36557 Mdot
.44481 .28505 Mdot
.32997 .40249 Mdot
.66233 .57154 Mdot
.53334 .42936 Mdot
.5732 .29549 Mdot
.54987 .49724 Mdot
.54547 .32506 Mdot
.61182 .53364 Mdot
.50952 .69429 Mdot
.40204 .37441 Mdot
.62247 .46257 Mdot
.51071 .43494 Mdot
.35223 .60973 Mdot
.43794 .64997 Mdot
.315 .59515 Mdot
.35832 .58308 Mdot
.66845 .33606 Mdot
.3671 .60409 Mdot
.63351 .44106 Mdot
.4193 .61764 Mdot
.58549 .36007 Mdot
.54294 .31074 Mdot
.56758 .4172 Mdot
.6788 .44996 Mdot
.32673 .40715 Mdot
.42202 .41949 Mdot
.44115 .73165 Mdot
.47548 .67879 Mdot
.28988 .3435 Mdot
.55856 .33711 Mdot
.36602 .44543 Mdot
.38127 .60054 Mdot
.44981 .43039 Mdot
.50723 .35035 Mdot
.50477 .47064 Mdot
.72463 .43098 Mdot
.41592 .63268 Mdot
.5739 .65299 Mdot
.49622 .65667 Mdot
.67634 .55476 Mdot
.58291 .33116 Mdot
.55738 .62417 Mdot
.49772 .58159 Mdot
.50073 .42643 Mdot
.53297 .29866 Mdot
.64507 .57138 Mdot
.70023 .57948 Mdot
.4105 .66548 Mdot
.33651 .41172 Mdot
.50359 .6831 Mdot
.49632 .60523 Mdot
.55032 .57476 Mdot
.38198 .51942 Mdot
.67607 .57582 Mdot
.55661 .63906 Mdot
.45206 .67016 Mdot
.3581 .41778 Mdot
.56283 .59233 Mdot
.5323 .32652 Mdot
.65337 .41985 Mdot
.53657 .5744 Mdot
.55235 .31836 Mdot
.69092 .63817 Mdot
.35821 .41156 Mdot
.35722 .56706 Mdot
.46212 .28305 Mdot
.26695 .58838 Mdot
.45957 .62012 Mdot
.51929 .36722 Mdot
.56212 .5368 Mdot
.6723 .59495 Mdot
.48113 .65774 Mdot
.60094 .33247 Mdot
.3148 .33367 Mdot
.68866 .43153 Mdot
.61204 .44173 Mdot
.36831 .61395 Mdot
.36219 .62207 Mdot
.61752 .60011 Mdot
.60272 .54006 Mdot
.46384 .58059 Mdot
.58529 .44663 Mdot
.40219 .63345 Mdot
.52229 .33433 Mdot
.32448 .38472 Mdot
.44286 .67957 Mdot
.58967 .29944 Mdot
.41796 .6689 Mdot
.43112 .66916 Mdot
.59839 .40631 Mdot
.58039 .59311 Mdot
.52794 .41814 Mdot
.52249 .40201 Mdot
.63034 .67162 Mdot
.29981 .37371 Mdot
.573 .6221 Mdot
.58665 .43126 Mdot
.66067 .46176 Mdot
.50272 .61777 Mdot
.63275 .30548 Mdot
.66477 .50658 Mdot
.60018 .32278 Mdot
.58648 .36733 Mdot
.66737 .49295 Mdot
.62248 .53989 Mdot
.61713 .62325 Mdot
.38841 .39582 Mdot
.61789 .45144 Mdot
.45567 .39378 Mdot
.67319 .54323 Mdot
.42209 .57542 Mdot
.27153 .62413 Mdot
.33667 .57117 Mdot
.41362 .52686 Mdot
.41537 .44226 Mdot
.35829 .42308 Mdot
.43652 .30292 Mdot
.29783 .32321 Mdot
.66367 .44925 Mdot
.31234 .38616 Mdot
.50188 .63357 Mdot
.48896 .30612 Mdot
.53978 .39804 Mdot
.56126 .5916 Mdot
.31126 .62797 Mdot
.46312 .47451 Mdot
.54757 .34475 Mdot
.60927 .61727 Mdot
.50833 .65656 Mdot
.49603 .35697 Mdot
.26832 .58627 Mdot
.39749 .68702 Mdot
.66447 .5881 Mdot
.63345 .31367 Mdot
.49037 .65946 Mdot
.33484 .38274 Mdot
.71825 .55623 Mdot
.68586 .43419 Mdot
.62048 .59494 Mdot
.51176 .38696 Mdot
.68963 .48909 Mdot
.64772 .60009 Mdot
.55468 .2707 Mdot
.71587 .56924 Mdot
.3923 .44494 Mdot
.52722 .67367 Mdot
.28298 .61697 Mdot
.41892 .45884 Mdot
.48474 .28809 Mdot
.48721 .37107 Mdot
.32907 .62939 Mdot
.59982 .44489 Mdot
.34871 .42817 Mdot
.62723 .40533 Mdot
.65629 .41536 Mdot
.673 .58428 Mdot
.44261 .63402 Mdot
.69199 .45528 Mdot
.65927 .4726 Mdot
.3947 .66153 Mdot
.35556 .43357 Mdot
.40608 .43538 Mdot
.56092 .53101 Mdot
.45199 .459 Mdot
.4086 .38388 Mdot
.56776 .3233 Mdot
.6238 .32051 Mdot
.61962 .34977 Mdot
.34867 .55941 Mdot
.56377 .41012 Mdot
.45873 .53482 Mdot
.36879 .42772 Mdot
.65473 .49636 Mdot
.62206 .46083 Mdot
.6109 .39204 Mdot
.45957 .6204 Mdot
.26897 .56693 Mdot
.34206 .4056 Mdot
.40088 .56903 Mdot
.60603 .32219 Mdot
.67042 .53192 Mdot
.66507 .44922 Mdot
.31968 .38811 Mdot
.45691 .57936 Mdot
.40141 .53275 Mdot
.3213 .40574 Mdot
.43597 .36565 Mdot
.61461 .62313 Mdot
.37976 .48398 Mdot
.55402 .26419 Mdot
.6714 .4728 Mdot
.53422 .38387 Mdot
.61023 .67804 Mdot
.67056 .41336 Mdot
.36936 .58274 Mdot
.36242 .44568 Mdot
.58976 .44111 Mdot
.57248 .7137 Mdot
.44655 .64072 Mdot
.62137 .43783 Mdot
.64632 .41251 Mdot
.39601 .63019 Mdot
.68563 .66369 Mdot
.42995 .49537 Mdot
.53129 .70482 Mdot
.49305 .37167 Mdot
.31531 .37697 Mdot
.42015 .67993 Mdot
.37027 .40727 Mdot
.39534 .68706 Mdot
.48074 .61952 Mdot
.4129 .66973 Mdot
.33067 .59924 Mdot
.62579 .43663 Mdot
.31627 .39106 Mdot
.40746 .62066 Mdot
.31806 .37923 Mdot
.50601 .33862 Mdot
.55434 .71448 Mdot
.42618 .59241 Mdot
.34834 .59475 Mdot
.54966 .61075 Mdot
.58887 .60028 Mdot
.67293 .43966 Mdot
.54439 .32268 Mdot
.63478 .48585 Mdot
.28102 .56477 Mdot
.44384 .46129 Mdot
.50112 .37771 Mdot
.614 .47659 Mdot
.49662 .37797 Mdot
.42631 .47197 Mdot
.26215 .59471 Mdot
.31563 .40172 Mdot
.56815 .64751 Mdot
.38031 .56234 Mdot
.31006 .31273 Mdot
.48916 .3069 Mdot
.39333 .69036 Mdot
.7118 .56497 Mdot
.35442 .54702 Mdot
.67132 .41856 Mdot
.4824 .37542 Mdot
.41742 .66603 Mdot
.34063 .6066 Mdot
.68285 .43054 Mdot
.25774 .58564 Mdot
.35063 .60718 Mdot
.69523 .57537 Mdot
.65644 .43805 Mdot
.61331 .30301 Mdot
.64743 .58947 Mdot
.52078 .63152 Mdot
.28778 .64233 Mdot
.48323 .29206 Mdot
.63568 .43432 Mdot
.61558 .59964 Mdot
.66553 .58601 Mdot
.61755 .39116 Mdot
.4201 .42413 Mdot
.65967 .55959 Mdot
.53591 .31579 Mdot
.32502 .61995 Mdot
.44364 .45295 Mdot
.57668 .61281 Mdot
.40975 .57909 Mdot
.41204 .39045 Mdot
.31468 .35177 Mdot
.45319 .29214 Mdot
.41628 .5517 Mdot
.44157 .37736 Mdot
.71993 .5455 Mdot
.54627 .28216 Mdot
.58239 .58896 Mdot
.4857 .64814 Mdot
.41793 .53387 Mdot
.58534 .52774 Mdot
.43026 .70931 Mdot
.38056 .48414 Mdot
.40655 .47794 Mdot
.68455 .44508 Mdot
.59316 .52496 Mdot
.51264 .62446 Mdot
.52956 .61321 Mdot
.40299 .41922 Mdot
.43361 .71545 Mdot
.32346 .54393 Mdot
.44579 .29329 Mdot
.27064 .63015 Mdot
.48216 .28582 Mdot
.54461 .41144 Mdot
.68031 .47267 Mdot
.64126 .43643 Mdot
.66222 .41396 Mdot
.45059 .41295 Mdot
.40744 .38035 Mdot
.42477 .71633 Mdot
.37581 .42136 Mdot
.48289 .46952 Mdot
.66554 .52839 Mdot
.39428 .58031 Mdot
.32503 .39293 Mdot
.43596 .46401 Mdot
.41727 .34975 Mdot
.51693 .33562 Mdot
.47496 .39184 Mdot
.6584 .5098 Mdot
.61427 .65793 Mdot
.66548 .44479 Mdot
.38401 .5394 Mdot
.50824 .66119 Mdot
.30482 .35115 Mdot
.535 .36819 Mdot
.58987 .46844 Mdot
.58078 .60746 Mdot
.39938 .60494 Mdot
.383 .50533 Mdot
.66143 .32214 Mdot
.41401 .56622 Mdot
.41933 .44092 Mdot
.35635 .42491 Mdot
.44661 .73368 Mdot
.50677 .52368 Mdot
.4306 .45667 Mdot
.34239 .40056 Mdot
.66278 .31987 Mdot
.35822 .61772 Mdot
.41069 .68466 Mdot
.68309 .47414 Mdot
.45513 .28216 Mdot
.33488 .4156 Mdot
.67694 .47033 Mdot
.58481 .44558 Mdot
.7159 .5753 Mdot
.43539 .45015 Mdot
.45598 .67453 Mdot
.63534 .57572 Mdot
.40642 .32619 Mdot
.46432 .44402 Mdot
.29341 .37564 Mdot
.51829 .37624 Mdot
.52466 .41952 Mdot
.40255 .66966 Mdot
.60565 .38664 Mdot
.36429 .64288 Mdot
.6636 .55641 Mdot
.50011 .36525 Mdot
.68658 .41257 Mdot
.56081 .28395 Mdot
.5396 .58317 Mdot
.69069 .63237 Mdot
.56058 .40972 Mdot
.51719 .66179 Mdot
.58886 .50518 Mdot
.68421 .6671 Mdot
.53763 .65716 Mdot
.38292 .42354 Mdot
.56943 .56408 Mdot
.62949 .66111 Mdot
.41208 .62686 Mdot
.52708 .54791 Mdot
.58901 .58349 Mdot
.49723 .60466 Mdot
.50445 .58139 Mdot
.64273 .57873 Mdot
.51828 .53027 Mdot
.5763 .64625 Mdot
.63181 .55789 Mdot
.4114 .46172 Mdot
.61573 .43012 Mdot
.46763 .40574 Mdot
.58516 .26678 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0?ooooooB_ooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A006ooooo`03o`000?oooooooooo0?ooooooB_ooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0?ooooooB_oo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06
ooooo`?o0000oooooom:ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<oooo
o`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom:ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001_ooool00ol0003oooooooooo`3ooooood[ooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0/_ooool8o`0008oooooo
000Looooo`03o`000?oooooooooo0;3ooooo3Ol0002<ooooo`007?ooool00ol0003oooooooooo`2^
ooooo`Go000000?oooooo`000?l000001ol0002<ooooo`007?ooool00ol0003oooooooooo`2^oooo
oa7o0000R_ooool001cooooo00?o0000ooooooooool0/?ooool@o`0008Wooooo000Looooo`03o`00
0?oooooooooo093ooooo0_l000000ooooooo0000o`00000Looooo`oo0000ROooool001cooooo00?o
0000ooooooooool0S_ooool4o`000004ooooool0003o0000ooooo`?o00006Oooool>o`0008Wooooo
000Looooo`03o`000?oooooooooo08kooooo1_l00002ooooo`Go00004oooool2o`0000?ooooo3_l0
0028ooooo`007?ooool00ol0003oooooooooo`2:ooooo`;o000000Coooooo`000?l0003ooooo1?l0
0003ooooo`Co00004?ooool2o`000003ooooool0003o000000;ooooo4?l00027ooooo`007?ooool0
0ol0003oooooooooo`2:ooooo`;o000000?oooooo`000?l000002?ooool5o`0000kooooo0ol00003
ooooo`Co00000_ooool<o`0008Oooooo000Looooo`03o`000?oooooooooo08oooooo1Ol000000ooo
oooo0000o`000002ooooo`Co00003Oooool2o`0000Cooooo1?l00002ooooo`go0000Q_ooool001co
oooo00?o0000ooooooooool0S?ooool<o`000003ooooool0003o000000;o00003?ooool2o`000004
ooooool0003o0000ooooo`;o00001?ooool>o`0008Kooooo000Looooo`03o`000?oooooooooo08co
oooo3_l000001?oooooo0000o`000?l0000;ooooo`;o000000Coooooo`000?l0003ooooo0_l00004
ooooo`?o000000?oooooo`000?l000002ol000000ooooooo0000o`000020ooooo`007?ooool2o`00
08gooooo3ol000000ooooooo0000o`00000;ooooo`;o00002_ooool2o`0000;ooooo5?l0001loooo
o`007?ooool00ol0003oooooooooo`1Sooooo`ko00006OoooolAo`000003ooooool0003o000000_o
oooo0_l0000:ooooo`;o00000_oooolHo`0007Sooooo000Looooo`03o`000?oooooooooo063ooooo
0_l000000ooooooo0000o`00000>o`0001Kooooo2_l00002ooooo`Wo00002Oooool2o`00017ooooo
0_l00004ooooo`;o000000?oooooo`000?l000001Oooool9o`0007Kooooo000Looooo`03o`000?oo
oooooooo05kooooo1?l00004ooooo`Co000000?oooooo`000?l000000_l000000ooooooo0000o`00
0004o`0001;ooooo5_l00009ooooo`;o00001?ooool2o`0000Gooooo0_l0000:ooooo`;o00002?oo
ool2o`000003ooooool0003o000000Co0000M_ooool001cooooo00?o0000ooooooooool0G_ooool7
o`000003ooooool0003o000000ko00004?oooolHo`0000Oooooo0_l00006ooooo`?o00001?ooool2
o`0001Cooooo1_l000000ooooooo0000o`000002o`0007Cooooo000Looooo`03o`000?oooooooooo
05cooooo1?l000000ooooooo0000o`00000Eo`0000kooooo5ol00008ooooo`;o00000oooool2o`00
00;ooooo0_l0000?ooooo`;o00002Oooool=o`0007;ooooo000Looooo`03o`000?oooooooooo05co
oooo1?l00004oooooa7o000000Coooooo`000?l0003o00003OoooolGo`0000Oooooo0_l00004oooo
o`;o00001?ooool2o`0000Sooooo1ol0000:ooooo`co0000L_ooool001cooooo00?o0000oooooooo
ool0G?ooool4o`0000Gooooo2Ol000000ooooooo0000o`000005o`000003ooooool0003o000000co
oooo6?l00006ooooo`?o00001oooool2o`000003ooooool0003o000000Sooooo2Ol00004ooooo`;o
00000_ooool=o`00077ooooo000Looooo`03o`000?oooooooooo05[ooooo1Ol00007ooooo`?o0000
00?oooooo`000?l000000_l000000ooooooo0000o`000008o`0000Oooooo0_l00003oooooaSo0000
1_ooool3o`0000Oooooo0_l00006ooooo`;o00002?ooool4o`0000Cooooo4Ol0001aooooo`007?oo
ool00ol0003oooooooooo`1Iooooo`?o00001?ooool2o`0000Cooooo4ol00007ooooo`;o00000ooo
oolFo`0000Sooooo0ol00003ooooo`Ko00001_ooool2o`0000_ooooo0_l00004ooooo`go000000Co
ooooo`000?l0003o0000L?ooool001cooooo00?o0000ooooooooool0FOooool2o`0000Gooooo0_l0
0004oooooa?o00003?oooolFo`0000Kooooo0_l00006ooooo`Co00001_ooool2o`0000Gooooo0_l0
0003ooooo`;o000000?oooooo`000?l000001?ooool>o`000004ooooool0003o0000o`0006oooooo
000Looooo`03o`000?oooooooooo05Sooooo0ol00003ooooo`;o00000oooool2o`0000;ooooo4_l0
000;oooooaKo00001_ooool3o`0000?ooooo0_l00002ooooo`;o00001oooool3o`0000Cooooo0_l0
0003ooooo`;o00001ooooolBo`0006oooooo000Looooo`03o`000?oooooooooo05Sooooo1?l00002
ooooo`;o00000ooooolFo`0000Cooooo0_l00004oooooaKo00001_ooool4o`000003ooooool0003o
000000;o00000_ooool2o`0000Gooooo1Ol00004ooooo`?o00002_oooolCo`0006oooooo000Loooo
o`03o`000?oooooooooo05Sooooo1?l00009oooooaCo00001?ooool2o`0000Cooooo4Ol000000ooo
oooo0000o`000008ooooo`Co000000Coooooo`000?l0003o00002_ooool3o`0000Oooooo0_l0000:
oooooaCo0000K_ooool001cooooo00?o0000ooooooooool0Eoooool5o`0000[ooooo4_l0000;oooo
o`Co000000?oooooo`000?l000002ol00007ooooo`?o00003oooool2o`0000Cooooo0_l0000Aoooo
oaCo0000K_ooool001cooooo00?o0000ooooooooool0Eoooool5o`0000Wooooo4ol0000;ooooo`Go
000000?oooooo`000?l000002_l00006ooooo`Co00000_ooool2o`0000_ooooo0_l00004ooooo`;o
000000?oooooo`000?l000003OoooolEo`0006kooooo000Looooo`;o0000F?ooool3o`0000Gooooo
0_l00004oooooa;o00003?ooool5o`000003ooooool0003o000000Wo00001_ooool3o`0000Cooooo
0_l0000?ooooo`?o00000_ooool2o`0000Sooooo0ol000000ooooooo0000o`00000Do`0006kooooo
000Looooo`03o`000?oooooooooo05Sooooo0ol00004ooooo`;o000000Coooooo`000?l0003ooooo
4_l00002ooooo`;o00001?ooool2o`0000?ooooo1?l00005ooooo`;o000000?oooooo`000?l00000
1?ooool6o`0000Gooooo0_l0000?ooooo`?o00000_ooool2o`0000Oooooo7?l0001]ooooo`007?oo
ool00ol0003oooooooooo`1Hooooo`Go00000_ooool2o`000003ooooool0003o000000;ooooo4Ol0
0002ooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`Go00003?ooool5o`0000;ooooo
0_l0000Qooooo`;o00000_oooolHo`0006gooooo000Looooo`03o`000?oooooooooo05Sooooo0_l0
00000ooooooo0000o`000009ooooo`oo00001oooool2o`0000Sooooo3Ol000000ooooooo0000o`00
0005ooooo`Co00004oooool2o`0000Kooooo0ol00009oooooaGo0000K_ooool001cooooo00?o0000
ooooooooool0F?ooool3o`0000_ooooo3ol00002ooooo`;o00002_ooool3o`000003ooooool0003o
000000[o000000?oooooo`000?l000001Oooool2o`0000;ooooo0_l00004ooooo`;o00001_ooool2
o`0000?ooooo0_l00005ooooo`Co00002OoooolEo`0006kooooo000Looooo`03o`000?oooooooooo
05Wooooo0_l0000<ooooo`ko00000_ooool2o`0000[ooooo0ol00002ooooo`Co00000oooool2o`00
00Sooooo0_l00004ooooo`;o00001?ooool4o`0000Cooooo0_l0000:ooooo`;o00000oooool3o`00
00Gooooo5?l0001_ooooo`007?ooool00ol0003oooooooooo`1Iooooo`?o00002oooool=o`0000co
oooo1Ol00003ooooo`Co00003Oooool2o`0000Cooooo0_l00004ooooo`Co000000?oooooo`000?l0
00003oooool2o`000003ooooool0003o000000?o00000oooool@o`0000;ooooo1?l0001]ooooo`00
7?ooool00ol0003oooooooooo`1Jooooo`;o00003?ooool;o`0000Wooooo0_l00002ooooo`?o0000
2_ooool2o`0000cooooo0ol00003ooooo`;o00000_ooool2o`0000?ooooo0_l0000?ooooo`;o0000
1?ooool2o`0000Cooooo5Ol0001]ooooo`007?ooool00ol0003oooooooooo`1Kooooo`;o000000?o
ooooo`000?l000002?ooool2o`000003ooooool0003o000000Go00002_ooool2o`000003ooooool0
003o000000cooooo0_l0000:ooooo`Go00000oooool3o`0000Gooooo1?l0000Booooo`;o00000ooo
ool2o`0000;ooooo2?l000000ooooooo0000o`000009o`0006gooooo000Looooo`03o`000?oooooo
oooo05_ooooo1Ol00003ooooo`;o00001?ooool7o`0000oooooo0_l00008ooooo`;o000000Cooooo
o`000?l0003o00000_ooool2o`0000Kooooo0_l00003ooooo`?o000000Coooooo`000?l0003ooooo
0_l000000ooooooo0000o`000003o`0000Kooooo0_l00008ooooo`Co00000oooool2o`0000;ooooo
4ol0001^ooooo`007?ooool00ol0003oooooooooo`1Kooooo`?o00001Oooool3o`0000?ooooo1Ol0
000Aooooo`Co00001_ooool2o`000003ooooool0003o000000?ooooo0ol0000:ooooo`?o00001?oo
ool2o`000003ooooool0003o000000Wooooo0_l00008ooooo`?o00002?oooolCo`0006kooooo000L
ooooo`03o`000?oooooooooo06Cooooo1ol00009ooooo`;o00001?ooool3o`0000;ooooo1?l0000?
ooooo`;o00003_ooool2o`0000Kooooo0_l0000Gooooo`;o00001?oooolAo`0006oooooo000Loooo
o`03o`000?oooooooooo05kooooo0_l00002ooooo`;o00000_ooool5o`0000Wooooo0_l00004oooo
o`?o00001?ooool2o`0001Cooooo0_l00009ooooo`;o00001_ooool2o`0000Wooooo0_l0000:oooo
o`Co00001?ooool@o`00073ooooo000Looooo`03o`000?oooooooooo05kooooo0_l00002ooooo`Oo
000000?oooooo`000?l000003oooool2o`0000Gooooo0_l0000Cooooo`;o00001oooool4o`00017o
oooo0_l0000:ooooo`;o000000?oooooo`000?l000000oooool<o`000003ooooool0003o0000077o
oooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@oooo
ooooool01?ooool00ol0003oooooooooo`1Sooooo`Ko000000?oooooo`000?l000003oooool2o`00
00Gooooo0_l0000<ooooo`;o00001Oooool2o`0000Oooooo0ol0000@ooooo`;o00003_ooool6o`00
00;ooooo2_l0001dooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo06;ooooo0ol000000ooooooo0000o`00000B
ooooo`?o00003?ooool4o`0000;ooooo0ol00003ooooo`Co00001Oooool2o`000003ooooool0003o
000000[ooooo0_l00004ooooo`;o00003_ooool7o`0000?ooooo0ol0001iooooo`0000?ooooooa0@
4?ooool00_ooool00ol@413oooooooooo`09ooooo`Go00001_ooool00ol0003oooooooooo`1Roooo
o`;o000000?oooooo`000?l000001oooool2o`0000[ooooo0_l00002ooooo`;o00002Oooool4o`00
0004ooooool0003o0000o`0000Cooooo0_l00007ooooo`;o00003?ooool3o`0001Wooooo0_l00004
ooooo`?o0000N?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?m4
A4CogMgMooooool00007ooooo`?o0000Hoooool:o`000003ooooool0003o000000;ooooo0_l0000:
ooooo`;o00002Oooool2o`0000?ooooo0_l00003ooooo`;o00002_ooool2o`0000Gooooo0_l00004
ooooo`;o00005oooool2o`0000Gooooo0_l000000ooooooo0000o`000002o`0007Kooooo00000ooo
oooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo00001oooool0
0ol0003oooooooooo`1Sooooo`[o00001Oooool2o`0000cooooo0_l00007ooooo`;o00002?ooool3
o`0000Wooooo0_l00005ooooo`?o00000_ooool2o`0001;ooooo2?l000000ooooooo0000o`000002
ooooo`;o00000oooool6o`0007;ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo
00[ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`1Uooooo`?o00000oooool2o`00
0003ooooool0003o000000Gooooo0_l000000ooooooo0000o`000006ooooo`;o00004_ooool2o`00
017ooooo0_l00002ooooo`;o00002_ooool2o`0000Kooooo1ol00002ooooo`;o00000_ooool2o`00
00Cooooo2?l0001_ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co
000000Oooooo00?o0000ooooooooool0I_ooool2o`0000;ooooo0_l00002ooooo`Go00000_ooool2
o`000003ooooool0003o000000Wooooo0_l0000Xooooo`;o00000oooool3o`0000;ooooo0_l00007
ooooo`?o000000?oooooo`000?l000001_ooool4o`0000Kooooo2_l0001Yooooo`0000Koooooonk^
k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0JOoo
ool3o`0000Cooooo0ol0000@ooooo`Co00002?ooool2o`0001;ooooo0_l00008ooooo`;o00000ooo
ool3o`0001?ooooo0_l00004ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`00
0002ooooo`Ko0000JOooool001cooooo00?o0000ooooooooool0JOooool2o`000003ooooool0003o
000000?ooooo0_l00005ooooo`;o00002oooool2o`0000Sooooo0_l0000Booooo`;o00000oooool2
o`0000Wooooo1?l0000Aooooo`;o00001oooool4o`000003ooooool0003o000000Kooooo0_l0001Y
ooooo`007?ooool00ol0003oooooooooo`1Yooooo`;o000000?oooooo`000?l000000oooool2o`00
00?ooooo1?l00005ooooo`;o00001?ooool2o`00023ooooo0ol00009ooooo`Co00002?ooool2o`00
00;ooooo0_l00004ooooo`;o00001Oooool2o`0000Cooooo0_l0001aooooo`007?ooool00ol0003o
ooooooooo`1Yooooo`;o00001Oooool3o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`;o
00001?ooool2o`0001;ooooo0_l0000<ooooo`;o00005_ooool2o`0000;ooooo0_l00004ooooo`;o
00001Oooool2o`0000Oooooo0_l0001^ooooo`007?ooool00ol0003oooooooooo`1Yooooo`?o0000
1?ooool3o`000003ooooool0003o000000?ooooo0_l0000:ooooo`;o00002Oooool2o`0000Oooooo
0_l00004ooooo`;o0000:oooool2o`0000_ooooo0_l00005ooooo`Co00001?ooool2o`0005oooooo
000Looooo`03o`000?oooooooooo06[ooooo0_l00002ooooo`;o00001?ooool2o`0001Sooooo1?l0
000=ooooo`;o00000_ooool2o`0000Cooooo0_l00007ooooo`;o000000?oooooo`000?l000003Ooo
ool2o`0000Kooooo0ol00008ooooo`;o000000?oooooo`000?l000001?ooool;o`0005kooooo000L
ooooo`03o`000?oooooooooo06cooooo1_l00002ooooo`;o000000?oooooo`000?l000000_l0000B
ooooo`?o00003oooool2o`0000;ooooo0ol00003ooooo`;o00001oooool5o`0000Cooooo1?l00003
ooooo`Co00001oooool2o`0000Sooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o
000000[o0000G_ooool001cooooo00?o0000ooooooooool0K?ooool3o`000004ooooool0003o0000
ooooo`;o00000_ooool4o`0000;ooooo0_l000000ooooooo0000o`00000;ooooo`;o00004?ooool2
o`000003ooooool0003o000000;o00003_ooool2o`0000Gooooo1?l00003ooooo`;o00000oooool3
o`000003ooooool0003o000000;o00002?ooool2o`0000;ooooo0ol000000ooooooo0000o`000009
o`0005oooooo000Looooo`03o`000?oooooooooo073ooooo0_l000000ooooooo0000o`000008oooo
o`;o000000?oooooo`000?l000001oooool2o`0001Oooooo0_l0000=ooooo`;o00004oooool4o`00
0003ooooool0003o000000;o00000_ooool2o`0000?ooooo0ol00002ooooo`?o000000?oooooo`00
0?l000002_l0001Nooooo`007?ooool00ol0003oooooooooo`1`ooooo`;o00000oooool2o`0000co
oooo0ol00003ooooo`;o00009_ooool2o`0000Wooooo0_l00005ooooo`;o000000?oooooo`000?l0
00000_ooool2o`0000Gooooo0_l00002ooooo`Co00000oooool2o`000003ooooool0003o000000_o
0000GOooool001cooooo00?o0000ooooooooool0LOooool6o`0000Gooooo0_l00005ooooo`?o0000
3Oooool2o`0000;ooooo0_l00005ooooo`;o00006_ooool4o`000003ooooool0003o000000Co0000
1?ooool3o`0000Sooooo0ol000001?oooooo0000o`000?ooool2o`0000;ooooo3_l0001Looooo`00
7?ooool00ol0003oooooooooo`1aooooo`Go000000?oooooo`000?l000000oooool2o`0000kooooo
0_l00005ooooo`;o00000_ooool2o`0000Gooooo0_l00002ooooo`;o00005_ooool3o`0000;ooooo
1?l00006ooooo`;o00001Oooool2o`0000;ooooo0ol000001?oooooo0000o`000?ooool2o`0000;o
oooo3_l0001Looooo`007?ooool2o`0007;ooooo1Ol000000ooooooo0000o`000007ooooo`;o0000
2?ooool4o`0000Cooooo0_l00009ooooo`;o00000oooool2o`0001Kooooo0ol00003ooooo`;o0000
0oooool2o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`0000?ooooo0_l00005ooooo`ko0000
Foooool001cooooo00?o0000ooooooooool0P?ooool3o`0000Oooooo1?l00004ooooo`;o00002Ooo
ool2o`00027ooooo0_l000000ooooooo0000o`000002o`0001;ooooo0_l00002oooooa7o0000Fooo
ool001cooooo00?o0000ooooooooool0M?ooool2o`0000_ooooo0_l00005ooooo`Ko0000<_ooool2
o`000003ooooool0003o000000;o00005?oooolBo`0005cooooo000Looooo`03o`000?oooooooooo
07Cooooo0_l0000<ooooo`Co00000_ooool6o`000003ooooool0003o000003Gooooo0_l0000;oooo
o`;o00001_ooool2o`0000;ooooo3_l0001Looooo`007?ooool00ol0003oooooooooo`1dooooo`;o
00001?ooool2o`0000Kooooo1?l00004ooooo`Co000000Coooooo`000?l0003o00008?ooool2o`00
01;ooooo0_l00008ooooo`;o000000?oooooo`000?l000001_ooool2o`0000;ooooo3_l0001Loooo
o`007?ooool00ol0003oooooooooo`1eooooo`;o00000oooool2o`0000kooooo0_l00004ooooo`?o
00007oooool4o`00013ooooo0_l00008ooooo`;o00002Oooool2o`0000Cooooo3?l0001Looooo`00
7?ooool00ol0003oooooooooo`1]ooooo`Co00001?ooool2o`0001[ooooo0_l00006ooooo`;o0000
1Oooool2o`0001;ooooo0_l00006ooooo`;o00002?ooool2o`0000Oooooo0_l00007ooooo`;o0000
0oooool2o`000003ooooool0003o000000_o0000G?ooool001cooooo00?o0000ooooooooool0Jooo
ool6o`000003ooooool0003o000001?ooooo0_l0000@ooooo`;o00001Oooool2o`0000oooooo0_l0
0009ooooo`;o00002?ooool2o`0000Oooooo0_l000000ooooooo0000o`000002ooooo`Ko000000Co
ooooo`000?l0003ooooo3?l0001Mooooo`007?ooool00ol0003oooooooooo`1Zooooo`[o00004ooo
ool2o`0000[ooooo0_l0000Looooo`;o00004Oooool5o`0000Wooooo0_l00002ooooo`Ko00001Ooo
ool2o`000003ooooool0003o000000Go0000G_ooool001cooooo00?o0000ooooooooool0J_ooool5
o`000003ooooool0003o000000Co00002_ooool2o`0000Cooooo0_l00003ooooo`;o00000oooool2
o`000004ooooool0003o0000o`0002kooooo1Ol0000Hooooo`;o000000?oooooo`000?l000001?l0
001Oooooo`007?ooool00ol0003oooooooooo`1Zooooo`co00001?ooool2o`0000Cooooo0_l00004
ooooo`;o00000oooool2o`0000?ooooo0_l00002ooooo`;o00001oooool2o`0002?ooooo1?l00007
ooooo`;o00002Oooool2o`0000Sooooo2?l0001Oooooo`007?ooool00ol0003oooooooooo`1Yoooo
o`co00000oooool4o`0000Cooooo0_l0000?ooooo`;o00002_ooool2o`0000;ooooo0_l0000Ooooo
o`;o000000?oooooo`000?l000000oooool2o`000003ooooool0003o000000Gooooo0_l00002oooo
o`;o00002?ooool7o`00063ooooo000Looooo`03o`000?oooooooooo06Sooooo1ol000000ooooooo
0000o`000003o`0000?ooooo1?l00004ooooo`;o00003oooool2o`0000kooooo0_l0000Rooooo`;o
00000oooool2o`0000Gooooo0_l000000ooooooo0000o`000004o`0000;ooooo0_l00002ooooo`Oo
0000H_ooool001cooooo00?o0000ooooooooool0J?ooool>o`0001_ooooo0_l0000nooooo`;o0000
0oooool4o`0000;ooooo2Ol0001Tooooo`007?ooool00ol0003oooooooooo`1Xooooo`ko00003?oo
ool2o`0000Cooooo0_l00007ooooo`;o00009Oooool2o`0001Oooooo0_l00002oooooa;o0000H_oo
ool001cooooo00?o0000ooooooooool0Ioooool@o`0000_ooooo0_l00004ooooo`;o00008oooool4
o`0000Oooooo0_l0000Eooooo`Co00000_ooool2o`0000?ooooo1?l00005ooooo`Co0000H_ooool0
01cooooo0_l0001Xoooooa3o000000?oooooo`000?l000004_ooool2o`0001oooooo1?l00003oooo
o`;o00006Oooool4o`0000Oooooo0_l00003ooooo`[o0000H?ooool001cooooo00?o0000oooooooo
ool0Ioooool@o`000003ooooool0003o000000;o00004?ooool4o`0000Cooooo0_l0000Nooooo`;o
00009?ooool3o`0000;ooooo2_l0001Pooooo`007?ooool00ol0003oooooooooo`1Wooooo`oo0000
0oooool3o`0000gooooo0_l00003ooooo`;o00001?ooool2o`0002Kooooo0_l0000Fooooo`;o0000
1Oooool2o`0000?ooooo2Ol0001Pooooo`007?ooool00ol0003oooooooooo`1Wooooo`oo00000_oo
ool3o`0000kooooo0_l0000^ooooo`;o000000?oooooo`000?l000003?ooool2o`0000Kooooo1?l0
0009ooooo`Oo000000Coooooo`000?l0003o0000Goooool001cooooo00?o0000ooooooooool0IOoo
oolAo`0000;ooooo0_l00004ooooo`;o00002?ooool2o`0002oooooo0_l00003ooooo`;o00002_oo
ool2o`0000Kooooo0_l00006ooooo`;o00000oooool7o`000004ooooool0003o0000o`0005oooooo
000Looooo`03o`000?oooooooooo06Gooooo4Ol00008ooooo`;o00001_ooool4o`0002Kooooo1?l0
000:ooooo`Co00004?ooool2o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`_o0000Gooo
ool001cooooo00?o0000ooooooooool0IOoooolAo`0000;ooooo0_l0000<ooooo`;o00003Oooool2
o`0001Wooooo1?l0000;ooooo`?o00005Oooool2o`000004ooooool0003o0000ooooo`ko0000G_oo
ool001cooooo00?o0000ooooooooool0IOoooolEo`0001Oooooo0_l00002ooooo`;o00009Oooool2
o`000003ooooool0003o000000[ooooo0_l00008ooooo`;o00000oooool2o`000003ooooool0003o
000000co0000G_ooool001cooooo00?o0000ooooooooool0IOoooolCo`0000Gooooo0_l0000Boooo
o`;o00003_ooool2o`0001Wooooo0ol00004ooooo`;o00001_ooool2o`0000Sooooo0_l00005oooo
o`co0000HOooool001cooooo00?o0000ooooooooool0HooooolAo`0000Kooooo0_l000000ooooooo
0000o`000004ooooo`;o00007?ooool2o`0001Oooooo0_l000001?oooooo0000o`000?l00003oooo
o`;o00003oooool4o`0000Cooooo3?l000001?oooooo0000o`000?l0001Mooooo`007?ooool00ol0
003oooooooooo`1Soooooa?o00001?ooool2o`0000Oooooo0_l0000Pooooo`;o00002oooool2o`00
00Kooooo0_l00002ooooo`;o00005?ooool4o`0000Cooooo3?l000001?oooooo0000o`000?l0001M
ooooo`007?ooool00ol0003oooooooooo`1Soooooa?o00002Oooool2o`0000?ooooo0_l0000;oooo
o`;o00004_ooool2o`0000_ooooo0_l00003ooooo`;o00001_ooool2o`0000;ooooo0_l00002oooo
o`Co00000oooool4o`0000Cooooo0_l00003ooooo`go000000?oooooo`000?l000000_l0001Loooo
o`007?ooool00ol0003oooooooooo`1QoooooaGo00002Oooool2o`0000?ooooo0_l0000;ooooo`;o
00008?ooool2o`0000;ooooo0_l00004ooooo`Go000000?oooooo`000?l000000_ooool4o`0000?o
oooo1?l00009ooooo`go000000?oooooo`000?l000000_l0001Looooo`007?ooool00ol0003ooooo
ooooo`1Poooooa;o00000_ooool2o`0000?ooooo1?l0000?ooooo`;o00006?ooool2o`0000_ooooo
0_l00008ooooo`;o000000?oooooo`000?l000001?ooool4o`00017ooooo3Ol000001?oooooo0000
o`000?l0001Mooooo`007?ooool00ol0003oooooooooo`1Noooooa?o00001oooool5o`0000oooooo
0_l0000Hooooo`;o00004oooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0000oo
oooo0_l00002ooooo`go00000_ooool2o`0005gooooo000Looooo`03o`000?oooooooooo05_ooooo
5_l00007ooooo`?o0000:?ooool2o`0000;ooooo0_l0000Booooo`;o00001_ooool4o`0000Kooooo
0_l00002ooooo`;o00001?ooool3o`000003ooooool0003o000000_o0000HOooool001cooooo0_l0
001IoooooaWo00005_ooool2o`0000?ooooo0_l0000Eooooo`;o00000_ooool2o`00013ooooo0_l0
000:ooooo`;o00001_ooool2o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l000003ol0
001Mooooo`007?ooool00ol0003oooooooooo`1Gooooo`ko00000_ooool3o`0000Gooooo0_l0000?
ooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000;o00005Oooool2
o`0001Cooooo0_l00004ooooo`;o00001_ooool2o`0001;ooooo3?l000000ooooooo0000o`000002
o`0005gooooo000Looooo`03o`000?oooooooooo05Gooooo3ol00003ooooo`?o00001Oooool2o`00
00oooooo0_l000000ooooooo0000o`000005ooooo`;o00005oooool2o`0000Wooooo0_l0000?oooo
o`;o00001_ooool2o`0000Sooooo0_l000001Ooooooo0000o`000?l0003ooooo01Co0000GOooool0
01cooooo00?o0000ooooooooool0E?oooolAo`0000Wooooo0_l0000Vooooo`;o00005_ooool2o`00
013ooooo0_l00005ooooo`Co00001_ooool6o`000003ooooool0003o000001;o0000GOooool001co
oooo00?o0000ooooooooool0E?ooool5o`000003ooooool0003o000000Wo00002Oooool2o`000003
ooooool0003o000000Gooooo0_l00005ooooo`;o00003Oooool2o`0000Kooooo0_l0000Vooooo`Co
00001Oooool4o`0000;ooooo0_l00003ooooo`;o00001oooool:o`0000?ooooo0ol0001Nooooo`00
7?ooool00ol0003oooooooooo`1Booooo`Go000000?oooooo`000?l000002_l0000=ooooo`;o0000
1Oooool2o`0000Gooooo0_l00002ooooo`;o00002Oooool2o`0002Gooooo0_l000000ooooooo0000
o`000004ooooo`;o00003Oooool2o`0000cooooo2_l00003ooooo`;o0000Goooool001cooooo00?o
0000ooooooooool0D_oooolBo`0000cooooo0_l0000<ooooo`;o00000oooool2o`00033ooooo0_l0
00000ooooooo0000o`00000;ooooo`;o00002oooool2o`0000;ooooo0_l00004ooooo`go0000H?oo
ool001cooooo00?o0000ooooooooool0DOoooolCo`000003ooooool0003o000000;o000000?ooooo
o`000?l000000oooool3o`0000cooooo0_l0000Nooooo`;o00009Oooool2o`0000Oooooo0_l00002
ooooo`Ko00000oooool7o`0000?ooooo1?l0001Pooooo`007?ooool00ol0003oooooooooo`1@oooo
o`?o00000_ooool?o`000003ooooool0003o000000;o000000?oooooo`000?l000000oooool2o`00
01Cooooo0_l0000Gooooo`;o00002oooool2o`0000;ooooo0_l0000Jooooo`;o000000?oooooo`00
0?l000000oooool4o`000004ooooool0003o0000ooooo`Go00001Oooool4o`00063ooooo000Loooo
o`03o`000?oooooooooo04oooooo1?l00002ooooo`oo00002_ooool3o`0001Cooooo0_l0000@oooo
o`;o00003_ooool2o`0000;ooooo0_l00002ooooo`;o00006_ooool4o`0000Gooooo0_l000001?oo
oooo0000o`000?l00002ooooo`Co00001Oooool3o`00067ooooo000Looooo`03o`000?oooooooooo
04oooooo0ol00003ooooo`oo00002_ooool2o`0000cooooo0_l00003ooooo`;o00003_ooool4o`00
00;ooooo0_l00005ooooo`Go00001?ooool3o`0001cooooo0ol00002ooooo`Co00002?ooool2o`00
00?ooooo0ol000000ooooooo0000o`000004ooooo`;o0000HOooool001cooooo00?o0000oooooooo
ool0C_ooool4o`0000;ooooo3ol0000>ooooo`;o000000?oooooo`000?l000001?ooool4o`0000?o
oooo0_l00003ooooo`;o00002Oooool4o`0000Wooooo1Ol00005ooooo`;o00000_ooool2o`0000_o
oooo0_l000000ooooooo0000o`000008ooooo`?o00000_ooool2o`0000[ooooo0_l00004ooooo`Go
00000oooool3o`00067ooooo000Looooo`03o`000?oooooooooo04kooooo5Ol00009ooooo`;o0000
0oooool2o`000003ooooool0003o000000Cooooo0_l0000:ooooo`;o00005_ooool2o`0000cooooo
0_l000000ooooooo0000o`000002o`0000Kooooo0_l000000ooooooo0000o`000002o`0000oooooo
1ol000000ooooooo0000o`000004ooooo`Co00000oooool3o`0006;ooooo000Looooo`03o`000?oo
oooooooo04kooooo5Ol00009ooooo`;o00005Oooool2o`0000Sooooo0_l0000?ooooo`;o000000?o
ooooo`000?l000001Oooool2o`0000Gooooo1?l00006ooooo`;o00000oooool3o`0000kooooo1ol0
0008ooooo`Co00000_ooool3o`0006;ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo
0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`1=ooooo`Co
00000_ooool@o`0000gooooo0_l0000=ooooo`;o00000_ooool2o`0000;ooooo0_l00004ooooo`;o
00004_ooool2o`0000Gooooo0_l00003ooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`;o
00002oooool2o`000004ooooool0003o0000o`0000gooooo2?l0001Rooooo`0000KoooooogMgMonH
V9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o
0000ooooooooool0COooool6o`000003ooooool0003o000000co000000?oooooo`000?l000002?oo
ool2o`000003ooooool0003o000000gooooo0_l00006ooooo`?o00000_ooool2o`0000Cooooo0_l0
000Iooooo`;o00001?ooool2o`0000Cooooo0_l0000;ooooo`;o00001?ooool2o`0000Sooooo0ol0
0002ooooo`;o00000oooool6o`0006?ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooo
oooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo04kooooo1Ol0
00000ooooooo0000o`00000<o`000003ooooool0003o000000?ooooo0_l00003ooooo`;o00002ooo
ool2o`0000?ooooo0_l00007ooooo`Ko00001?ooool2o`0002Sooooo0_l00006ooooo`Co00001ooo
ool2o`0000Cooooo1?l00002ooooo`;o00001Oooool2o`0006Gooooo00000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo00Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000COoo
ool5o`0000?ooooo3Ol00004ooooo`Oo00001?ooool2o`0000Gooooo1?l00003ooooo`;o00002Ooo
ool2o`0001_ooooo0_l0000Aooooo`Co00001_ooool3o`0000;ooooo0_l00004ooooo`;o00001?oo
ool2o`0000?ooooo0_l0001]ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09
ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`1=ooooo`?o00001_oo
ool;o`0000Gooooo0_l00002ooooo`?o00000_ooool4o`000003ooooool0003o000000;ooooo0_l0
0004ooooo`;o00007Oooool3o`0000Oooooo0_l0000Aooooo`;o00003Oooool2o`0000Gooooo0_l0
0002ooooo`;o00001?ooool2o`0006gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooo
oooo00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`1=ooooo`Co00001_ooool:
o`0000[ooooo0_l000001?oooooo0000o`000?l00003ooooo`;o00002?ooool2o`0001Cooooo0_l0
0006ooooo`Co00004_ooool2o`0000;ooooo0_l000001?oooooo0000o`000?l00006ooooo`;o0000
3?ooool2o`000003ooooool0003o000000;o00000oooool2o`0006gooooo00001_ooooooMgMgoiRH
V?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`1=ooooo`Co
00001_ooool8o`0000;ooooo0_l00002ooooo`So000000Coooooo`000?l0003o00000_ooool2o`00
00_ooooo0_l00007ooooo`;o00002Oooool2o`0000Gooooo1?l0000@ooooo`;o000000?oooooo`00
0?l000000_ooool6o`0000Kooooo0_l0000<ooooo`co0000KOooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo04gooooo1?l0
0006ooooo`So00000_ooool2o`0000;ooooo2?l00006ooooo`Co00002Oooool2o`000003ooooool0
003o000000Cooooo0_l00008ooooo`;o00001_ooool4o`0000Cooooo0_l00003ooooo`;o00000ooo
ool4o`0000Gooooo1?l00008ooooo`;o00000_ooool2o`0000Gooooo1ol00002ooooo`Go0000K_oo
ool001cooooo00?o0000ooooooooool0COooool4o`0000Oooooo0_l00004ooooo`;o00002Oooool4
o`0000Cooooo0_l000001?oooooo0000o`000?l0000<ooooo`?o00003Oooool2o`0000_ooooo0_l0
00000ooooooo0000o`000003ooooo`;o00000oooool2o`0000Oooooo0_l00009ooooo`?o00000_oo
ool2o`0000?ooooo1_l00006ooooo`Co0000K_ooool001cooooo00?o0000ooooooooool0Coooool2
o`000003ooooool0003o000000Cooooo0_l00004ooooo`;o00001_ooool2o`000003ooooool0003o
000000;o00001?ooool2o`0000?ooooo0_l00009ooooo`;o000000?oooooo`000?l000003?ooool2
o`0000Cooooo0_l00006ooooo`;o00005?ooool2o`0000Wooooo0ol00002ooooo`;o00000oooool5
o`0000;ooooo0_l000001?oooooo0000o`000?ooool5o`0006cooooo000Looooo`03o`000?oooooo
oooo04kooooo0ol000000ooooooo0000o`000002o`0000;ooooo0_l0000<ooooo`Co000000?ooooo
o`000?l000000_l00003ooooo`;o00000_ooool3o`0000Sooooo0_l00009ooooo`;o00000_ooool4
o`0000Cooooo0_l00009ooooo`;o00003?ooool3o`0000;ooooo0_l0000<ooooo`Co00001Oooool2
o`0000;ooooo3?l0001/ooooo`007?ooool00ol0003oooooooooo`1>ooooo`Co000000Coooooo`00
0?l0003o00000_ooool2o`0000Oooooo0ol00002ooooo`Co00000oooool2o`0000?ooooo0_l00003
ooooo`;o00002Oooool2o`0000Sooooo0_l00002ooooo`;o00004Oooool2o`0000cooooo0ol00002
ooooo`;o00002_ooool5o`0000Wooooo2ol000000ooooooo0000o`00001[ooooo`007?ooool00ol0
003oooooooooo`1?ooooo`Co000000?oooooo`000?l000002oooool3o`0000?ooooo0_l00004oooo
o`;o00003_ooool2o`0000?ooooo0_l0000Cooooo`;o00002?ooool4o`0000[ooooo0_l00007oooo
o`Co00001_ooool2o`0000Kooooo0_l000000ooooooo0000o`00000?o`0006_ooooo000Looooo`03
o`000?oooooooooo053ooooo1_l000000ooooooo0000o`00000>ooooo`;o00001?ooool2o`0000ko
oooo1?l00002ooooo`;o00001oooool2o`0000Wooooo0_l00006ooooo`So00002?ooool2o`0000?o
oooo0_l00002ooooo`Co00002?ooool2o`0000?ooooo0ol000000ooooooo0000o`00000=o`000003
ooooool0003o000006[ooooo000Looooo`03o`000?oooooooooo053ooooo1_l000000ooooooo0000
o`00000?ooooo`;o00002?ooool2o`0000_ooooo0_l00002ooooo`;o00001oooool2o`0000Cooooo
0_l0000;ooooo`;o00001?ooool2o`0000Gooooo0_l00006ooooo`?o00002Oooool2o`0000;ooooo
0_l00003ooooo`;o00000_ooool?o`000004ooooool0003o0000o`0006Wooooo000Looooo`03o`00
0?oooooooooo05;ooooo1_l00003ooooo`;o000000?oooooo`000?l000002?ooool2o`0000Sooooo
0_l0000<ooooo`;o00004?ooool2o`000003ooooool0003o000000Kooooo1?l000000ooooooo0000
o`000008ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00001?ooool2o`0000Kooooo
0_l000000ooooooo0000o`00000Co`0006Wooooo000Looooo`03o`000?oooooooooo05Cooooo2Ol0
00000ooooooo0000o`000008ooooo`;o00002Oooool2o`0000_ooooo1ol00006ooooo`?o00001Ooo
ool2o`0000Kooooo0_l00003ooooo`;o00001oooool3o`0000?ooooo0_l000000ooooooo0000o`00
0004ooooo`;o00000oooool2o`0000Oooooo5ol0001Zooooo`007?ooool00ol0003oooooooooo`1E
ooooo`;o000000?oooooo`000?l000001_l0000Cooooo`;o00003Oooool5o`0000Kooooo1Ol00000
0ooooooo0000o`000008ooooo`;o00003?ooool2o`0000Oooooo1Ol00006ooooo`;o00001Oooool2
o`0000;ooooo0ol000000ooooooo0000o`00000=o`0006cooooo000Looooo`03o`000?oooooooooo
05Sooooo4Ol0000@ooooo`;o00005Oooool2o`000003ooooool0003o000000;o00000oooool5o`00
00cooooo0_l00008ooooo`Co00003Oooool2o`000003ooooool0003o000001;o0000K?ooool001co
oooo0_l0001KoooooaCo00001Oooool2o`0000Cooooo0_l0000=ooooo`Go00000oooool2o`000003
ooooool0003o000000;o00000oooool3o`0001Cooooo0_l00002ooooo`Ko00002_ooool2o`0000;o
oooo5?l0001/ooooo`007?ooool00ol0003oooooooooo`1Vooooo`;o000000?oooooo`000?l00000
1ol000000ooooooo0000o`00000Cooooo`Go000000?oooooo`000?l000000_l000000ooooooo0000
o`00000Aooooo`Co00000oooool2o`0000;ooooo0_l00002ooooo`Ko00002_ooool2o`0000;ooooo
5?l0001/ooooo`007?ooool00ol0003oooooooooo`1Zooooo`[o00002oooool2o`0000gooooo0_l0
0009ooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`Co000000?oooooo`000?l000000_l0
0006ooooo`Ko00002Oooool2o`0000?ooooo5?l0001/ooooo`007?ooool00ol0003oooooooooo`1^
ooooo`Oo00001oooool2o`000003ooooool0003o000000;o00004?ooool2o`0000Cooooo0_l00000
1?oooooo0000o`000?l00002ooooo`;o000000?oooooo`000?l000001Oooool3o`0000[ooooo1ol0
0002ooooo`;o000000?oooooo`000?l000000_oooolEo`0006cooooo000Looooo`03o`000?oooooo
oooo06kooooo1ol00007ooooo`;o00000_ooool3o`00013ooooo0_l00003ooooo`;o00000_ooool2
o`0000?ooooo0_l000000ooooooo0000o`00000Booooo`;o000000?oooooo`000?l000001_l00005
oooooaGo0000K?ooool001cooooo00?o0000ooooooooool0K_ooool8o`0000[ooooo1_l0000=oooo
o`;o00000oooool2o`0000[ooooo0_l0000:ooooo`ko000000?oooooo`000?l000000_l00005oooo
oaGo0000K?ooool001cooooo00?o0000ooooooooool0K?ooool<o`0000Oooooo1ol00002ooooo`;o
00001Oooool2o`0000Oooooo1?l00008ooooo`;o00002?oooolBo`000003ooooool0003o000000Go
oooo5?l0001]ooooo`007?ooool00ol0003oooooooooo`1[ooooo`oo00001Oooool2o`000003oooo
ool0003o000000;o00000_ooool2o`0000Gooooo0_l00009ooooo`;o00002?ooool2o`000003oooo
ool0003o000000Cooooo2_l000001?oooooo0000o`000?ooool8o`0000Gooooo4Ol00002ooooo`;o
0000K?ooool001cooooo00?o0000ooooooooool0Joooool?o`0000gooooo0_l00007ooooo`;o0000
0oooool2o`000003ooooool0003o000000[ooooo0_l000000ooooooo0000o`000004oooooaOo0000
1?oooolAo`0000;ooooo0_l0001/ooooo`007?ooool00ol0003oooooooooo`1/ooooo`ko00002ooo
ool4o`0000?ooooo0_l00002ooooo`;o00000oooool:o`0000?ooooo1?l00007ooooo`?o000000?o
ooooo`000?l000004Ol00004ooooo`ko00000_ooool2o`0006oooooo000Looooo`03o`000?oooooo
oooo06_ooooo4Ol00009ooooo`;o00001Oooool2o`0000Gooooo3?l000000ooooooo0000o`000002
o`0000;ooooo0_l00004oooooaCo00000_ooool2o`0000Cooooo2Ol000000ooooooo0000o`000002
o`000004ooooool0003o0000o`0006oooooo000Looooo`03o`000?oooooooooo06_ooooo4Ol00006
ooooo`;o00002oooool7o`0000;ooooo0_l00004ooooo`Co00001?oooolJo`0000[ooooo1?l00002
ooooo`Ko000000?oooooo`000?l00000L?ooool001cooooo00?o0000ooooooooool0Joooool@o`00
00;ooooo0_l00002ooooo`Co00001_ooool2o`0000;ooooo1?l000001?oooooo0000o`000?ooool9
o`0000Sooooo6?l0000:ooooo`;o000000?oooooo`000?l000001ol0001cooooo`007?ooool00ol0
003oooooooooo`1[oooooaCo00000_ooool4o`0000Kooooo0_l0000:ooooo`;o000000?oooooo`00
0?l000001_l00004oooooa[o00003Oooool4o`0007Sooooo000Looooo`03o`000?oooooooooo06_o
oooo5_l0000;ooooo`Oo00002Oooool8o`0000;ooooo6ol00028ooooo`007?ooool00ol0003ooooo
ooooo`1/oooooaGo00002Oooool<o`0000Wooooo0_l000000ooooooo0000o`000003oooooa_o0000
Qoooool001cooooo0_l0001^oooooa?o00002?oooolAo`0000Kooooo0_l00006oooooaSo000000?o
ooooo`000?l00000Qoooool001cooooo00?o0000ooooooooool0K_oooolBo`0000Oooooo5?l00004
ooooo`;o00001ooooolEo`0008cooooo000Looooo`03o`000?oooooooooo073ooooo3_l00006oooo
oaSo00000_ooool3o`0000Oooooo5?l0002=ooooo`007?ooool00ol0003oooooooooo`1`ooooo`co
00002?oooolMo`0000Oooooo0_l000000ooooooo0000o`00000>o`000003ooooool0003o000008_o
oooo000Looooo`03o`000?oooooooooo07;ooooo0_l000000ooooooo0000o`000002o`0000[ooooo
1?l000000ooooooo0000o`00000Go`0000Oooooo0ol000000ooooooo0000o`00000;o`0000;ooooo
0ol0002;ooooo`007?ooool00ol0003oooooooooo`23ooooo`Go000000?oooooo`000?l000005_l0
0006ooooo`Go00000oooool9o`0000?ooooo0_l0002<ooooo`007?ooool00ol0003oooooooooo`23
oooooaSo000000Coooooo`000?l0003o00002?ooool5o`0000Kooooo0_l00002ooooo`Go0000S_oo
ool001cooooo00?o0000ooooooooool0Poooool4o`000003ooooool0003o000001?o00002_ooool6
o`000003ooooool0003o000000Cooooo1ol0002>ooooo`007?ooool00ol0003oooooooooo`26oooo
oaSo00002_ooool5o`000003ooooool0003o000000So0000TOooool001cooooo00?o0000oooooooo
ool0Q_ooool6o`000003ooooool0003o000000co000000?oooooo`000?l000003?ooool3o`000003
ooooool0003o000000Go0000U?ooool001cooooo00?o0000ooooooooool0Q_ooool2o`0000Cooooo
3ol0002^ooooo`007?ooool00ol0003oooooooooo`2<ooooo`?o000000Goooooo`000?l0003o0000
ooooo`02o`000;?ooooo000Looooo`03o`000?oooooooooo08cooooo0ol00005ooooo`;o0000/ooo
ool001cooooo00?o0000ooooooooool0S?ooool2o`0000Kooooo0_l0002cooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<
ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?ooooooB_ooool00006oooooomgMgOo
V9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03
o`000?oooooooooo0?ooooooB_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool0
2Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooom:ooooo`00
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb
<S801_ooool3o`000?ooooooB_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
2Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom:ooooo`00
00?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@
41001_ooool00ol0003oooooooooo`3ooooood[ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMg
M`_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0?ooooooB_ooool0
0006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooo
ooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB_ooool001Cooooo00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o
0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Doooo
o`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`00
4_ooool00omEEEGoIVIVo`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo002Yooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05Oooool01Oo^
k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b<_l0003o410@olc<c02Dooooo`00Z_ooool0
1Ol0003ooooooooooooooooo000000Wooooo1_l00009ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40
0oooool01OmEEEGoMgMgoooooonHV9So8B4Q09Cooooo002Zooooo`05o`000?ooooooooooooooool0
00006?ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00002D
ooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l00009ooooo`05o`000?nHV9So
oooooiRHV?lQ8B400oooool01Ol0003oV9RHoooooonHV9So8B4Q09Cooooo002Zooooo`05o`000?n7
QhOoooooojVYZOl000006?ooool01Ol0003oEEEEo`000?l@413oc<c<00?ooooo00Go0000oeEEEOl0
003o410@olc<c02Dooooo`00ZOooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo01Ko
oooo00?oEEEEohN7Qoooool01Oooool00omEEEGoQhN7ooooo`2Fooooo`00aoooool00ooMgMgo410@
oiRHV005ooooo`03omgMgOl@413oV9RH09Kooooo0038ooooo`04olc<c?m4A4Co0000oa0@40Cooooo
00Coc<c<odA4A?l0003o410@U?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -20 0 ]
[.5 1.0125 20 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(72) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.60596 .68869 Mdot
.65235 .65294 Mdot
.66224 .39136 Mdot
.37074 .48803 Mdot
.38624 .33357 Mdot
.66855 .38521 Mdot
.68464 .56287 Mdot
.70182 .56971 Mdot
.64841 .40115 Mdot
.34696 .53886 Mdot
.73825 .48357 Mdot
.35125 .6568 Mdot
.69237 .55869 Mdot
.34349 .5299 Mdot
.26136 .60897 Mdot
.44962 .70416 Mdot
.62048 .67957 Mdot
.39179 .33054 Mdot
.42331 .68836 Mdot
.64133 .39468 Mdot
.44204 .35207 Mdot
.35084 .50968 Mdot
.62922 .68735 Mdot
.33823 .53115 Mdot
.42347 .69015 Mdot
.51804 .68966 Mdot
.60615 .69239 Mdot
.42861 .69616 Mdot
.34348 .65295 Mdot
.70499 .53656 Mdot
.4372 .70974 Mdot
.26179 .5725 Mdot
.50495 .32947 Mdot
.56429 .68577 Mdot
.71705 .47943 Mdot
.73704 .46835 Mdot
.68064 .39991 Mdot
.74323 .48516 Mdot
.7103 .55096 Mdot
.72011 .48095 Mdot
.72076 .47787 Mdot
.51609 .6921 Mdot
.73157 .46437 Mdot
.68885 .52602 Mdot
.27606 .5283 Mdot
.5495 .71606 Mdot
.63337 .2832 Mdot
.29929 .51144 Mdot
.61139 .67459 Mdot
.63552 .29943 Mdot
.27737 .55655 Mdot
.67827 .58964 Mdot
.47431 .31625 Mdot
.50241 .72467 Mdot
.70079 .55306 Mdot
.41927 .69032 Mdot
.65433 .35934 Mdot
.30819 .52683 Mdot
.33514 .64969 Mdot
.56342 .69659 Mdot
.33297 .51927 Mdot
.4001 .30193 Mdot
.47664 .68717 Mdot
.65096 .3508 Mdot
.65565 .39726 Mdot
.73912 .50753 Mdot
.6623 .65065 Mdot
.73211 .50566 Mdot
.37686 .49797 Mdot
.6205 .27417 Mdot
.30731 .50862 Mdot
.73805 .48284 Mdot
.53269 .70274 Mdot
.36708 .50716 Mdot
.61152 .66782 Mdot
.72801 .50008 Mdot
.37796 .33823 Mdot
.52809 .69174 Mdot
.63681 .31231 Mdot
.39039 .46802 Mdot
.35258 .5022 Mdot
.70698 .60235 Mdot
.31996 .65117 Mdot
.51659 .71522 Mdot
.26355 .54181 Mdot
.69232 .62222 Mdot
.34662 .49107 Mdot
.44254 .70772 Mdot
.42256 .69571 Mdot
.3426 .64032 Mdot
.6975 .35349 Mdot
.64921 .67747 Mdot
.35344 .51721 Mdot
.3783 .50239 Mdot
.2773 .55209 Mdot
.26027 .54909 Mdot
.41931 .69612 Mdot
.51124 .30335 Mdot
.72811 .48481 Mdot
.4687 .32799 Mdot
.73042 .50418 Mdot
.46493 .31503 Mdot
.37444 .47421 Mdot
.67716 .36791 Mdot
.50153 .69285 Mdot
.51338 .30973 Mdot
.72605 .49509 Mdot
.3549 .51854 Mdot
.74013 .47224 Mdot
.64522 .67831 Mdot
.42824 .71074 Mdot
.36718 .3068 Mdot
.35489 .34437 Mdot
.62252 .70079 Mdot
.37952 .46169 Mdot
.32547 .51484 Mdot
.34172 .51338 Mdot
.66138 .65855 Mdot
.64571 .39496 Mdot
.64634 .32014 Mdot
.64823 .6645 Mdot
.72658 .48055 Mdot
.61779 .67646 Mdot
.48769 .34049 Mdot
.65156 .39767 Mdot
.48742 .33018 Mdot
.49517 .29807 Mdot
.28926 .55851 Mdot
.25997 .55387 Mdot
.44413 .33354 Mdot
.67995 .36685 Mdot
.64898 .66149 Mdot
.69483 .56451 Mdot
.37866 .50525 Mdot
.52053 .71408 Mdot
.70027 .54999 Mdot
.35547 .322 Mdot
.34871 .31207 Mdot
.5274 .70522 Mdot
.37579 .46079 Mdot
.74439 .48432 Mdot
.70034 .58265 Mdot
.29519 .54576 Mdot
.52636 .71652 Mdot
.3733 .33541 Mdot
.70292 .57983 Mdot
.52507 .29098 Mdot
.41924 .70858 Mdot
.23216 .55716 Mdot
.70389 .60217 Mdot
.28289 .55306 Mdot
.46703 .35678 Mdot
.39124 .29754 Mdot
.70335 .55119 Mdot
.36442 .48434 Mdot
.63045 .663 Mdot
.52695 .71215 Mdot
.33932 .67758 Mdot
.51303 .31628 Mdot
.31444 .52125 Mdot
.4569 .31854 Mdot
.50105 .29876 Mdot
.34576 .52774 Mdot
.56006 .70502 Mdot
.52755 .67958 Mdot
.31182 .51202 Mdot
.67521 .40724 Mdot
.39339 .33051 Mdot
.73465 .47175 Mdot
.27008 .54133 Mdot
.27967 .54926 Mdot
.34856 .67648 Mdot
.69606 .58744 Mdot
.71162 .50751 Mdot
.6168 .2954 Mdot
.73272 .51137 Mdot
.71137 .48719 Mdot
.66979 .35131 Mdot
.3464 .66544 Mdot
.36998 .30153 Mdot
.49298 .30838 Mdot
.31294 .51372 Mdot
.25358 .56081 Mdot
.34566 .64357 Mdot
.43899 .34851 Mdot
.48398 .35567 Mdot
.63212 .63647 Mdot
.72218 .46321 Mdot
.35769 .48986 Mdot
.40236 .70277 Mdot
.26756 .56207 Mdot
.71399 .5372 Mdot
.69309 .57109 Mdot
.63246 .37442 Mdot
.63787 .38869 Mdot
.62693 .2978 Mdot
.34424 .68679 Mdot
.36004 .68006 Mdot
.361 .49591 Mdot
.47709 .32384 Mdot
.47595 .68951 Mdot
.39384 .29901 Mdot
.62376 .67255 Mdot
.70942 .59966 Mdot
.28921 .5073 Mdot
.4294 .68636 Mdot
.68372 .41388 Mdot
.69803 .34822 Mdot
.47987 .30161 Mdot
.38864 .31007 Mdot
.30797 .52477 Mdot
.62084 .69703 Mdot
.28332 .55399 Mdot
.49838 .33227 Mdot
.35457 .34606 Mdot
.63995 .67459 Mdot
.2884 .51206 Mdot
.69315 .55421 Mdot
.6909 .35251 Mdot
.34625 .49125 Mdot
.36285 .5142 Mdot
.52635 .69325 Mdot
.38119 .48756 Mdot
.40636 .69295 Mdot
.42999 .70675 Mdot
.62433 .29287 Mdot
.7216 .50562 Mdot
.70532 .53169 Mdot
.63244 .28099 Mdot
.52118 .70059 Mdot
.61338 .70975 Mdot
.6672 .36998 Mdot
.43051 .34689 Mdot
.7403 .48347 Mdot
.37103 .32464 Mdot
.67293 .37201 Mdot
.39143 .3292 Mdot
.33278 .64637 Mdot
.68505 .36158 Mdot
.3612 .31233 Mdot
.28505 .6149 Mdot
.49758 .30053 Mdot
.34121 .32223 Mdot
.68304 .56349 Mdot
.64393 .6435 Mdot
.3162 .51196 Mdot
.48039 .31241 Mdot
.48554 .33445 Mdot
.34324 .66634 Mdot
.47144 .29868 Mdot
.50786 .31723 Mdot
.34407 .66931 Mdot
.40833 .31724 Mdot
.71817 .57134 Mdot
.43566 .71019 Mdot
.61985 .677 Mdot
.37881 .48632 Mdot
.71624 .50532 Mdot
.70127 .54944 Mdot
.32222 .52384 Mdot
.69491 .61306 Mdot
.68119 .56529 Mdot
.33892 .52624 Mdot
.70892 .54514 Mdot
.51748 .71413 Mdot
.29423 .50611 Mdot
.53596 .70579 Mdot
.34079 .52966 Mdot
.70965 .54548 Mdot
.63584 .29003 Mdot
.51634 .69442 Mdot
.35444 .51309 Mdot
.36787 .49382 Mdot
.47729 .3214 Mdot
.42718 .70861 Mdot
.67097 .60071 Mdot
.35117 .65812 Mdot
.66426 .34404 Mdot
.32828 .67612 Mdot
.37713 .28764 Mdot
.52521 .28954 Mdot
.5274 .71624 Mdot
.47473 .29724 Mdot
.6674 .37769 Mdot
.2913 .54505 Mdot
.27177 .51474 Mdot
.27258 .53209 Mdot
.50538 .3174 Mdot
.31868 .65259 Mdot
.67712 .56605 Mdot
.4094 .70262 Mdot
.44358 .32964 Mdot
.65324 .36451 Mdot
.46354 .32063 Mdot
.26093 .54609 Mdot
.63563 .68587 Mdot
.44117 .69308 Mdot
.67687 .34858 Mdot
.62825 .68402 Mdot
.30308 .51251 Mdot
.73054 .50656 Mdot
.38185 .28384 Mdot
.6779 .56154 Mdot
.43748 .69812 Mdot
.33051 .67633 Mdot
.62224 .27666 Mdot
.51418 .7008 Mdot
.70412 .55897 Mdot
.53403 .70396 Mdot
.30092 .54108 Mdot
.33994 .49022 Mdot
.53248 .7166 Mdot
.35772 .29723 Mdot
.62674 .31035 Mdot
.73827 .48975 Mdot
.48525 .32743 Mdot
.60912 .27175 Mdot
.61011 .67945 Mdot
.67715 .37365 Mdot
.37053 .45472 Mdot
.68846 .34717 Mdot
.43926 .69114 Mdot
.61273 .27115 Mdot
.35004 .67951 Mdot
.26465 .53516 Mdot
.64551 .35065 Mdot
.51536 .30834 Mdot
.30373 .53299 Mdot
.51762 .71244 Mdot
.26207 .57482 Mdot
.32971 .53899 Mdot
.3444 .68566 Mdot
.65451 .3632 Mdot
.37371 .45942 Mdot
.43409 .70398 Mdot
.43377 .69584 Mdot
.62924 .66896 Mdot
.48969 .32106 Mdot
.352 .32558 Mdot
.34369 .31759 Mdot
.50521 .27746 Mdot
.33182 .63001 Mdot
.362 .46887 Mdot
.52065 .70578 Mdot
.63353 .30006 Mdot
.63432 .64493 Mdot
.50035 .33166 Mdot
.70149 .57079 Mdot
.71148 .5109 Mdot
.35185 .48704 Mdot
.384 .2784 Mdot
.42546 .68289 Mdot
.61737 .66489 Mdot
.53243 .69948 Mdot
.70409 .56106 Mdot
.31174 .65912 Mdot
.37731 .52238 Mdot
.32522 .51879 Mdot
.69921 .57803 Mdot
.49209 .33244 Mdot
.33381 .65302 Mdot
.23393 .56442 Mdot
.69985 .50083 Mdot
.283 .53148 Mdot
.55878 .69056 Mdot
.27477 .52596 Mdot
.29234 .5549 Mdot
.2917 .5261 Mdot
.51701 .70821 Mdot
.38879 .68723 Mdot
.23861 .54759 Mdot
.69377 .40104 Mdot
.28085 .50905 Mdot
.35912 .29933 Mdot
.36055 .51251 Mdot
.31082 .51953 Mdot
.36678 .33456 Mdot
.61991 .69951 Mdot
.27869 .54759 Mdot
.71421 .57933 Mdot
.35107 .51455 Mdot
.73449 .47073 Mdot
.32763 .66116 Mdot
.27548 .5688 Mdot
.43121 .70242 Mdot
.63134 .68734 Mdot
.70953 .5597 Mdot
.72804 .47105 Mdot
.45207 .31524 Mdot
.70163 .54927 Mdot
.26908 .5384 Mdot
.32594 .65888 Mdot
.62348 .70081 Mdot
.49995 .3014 Mdot
.65174 .67499 Mdot
.33937 .27236 Mdot
.68224 .57041 Mdot
.4692 .31441 Mdot
.32945 .68412 Mdot
.683 .5818 Mdot
.71607 .57081 Mdot
.42915 .71128 Mdot
.4908 .33264 Mdot
.6079 .68984 Mdot
.61744 .2734 Mdot
.50297 .32597 Mdot
.70221 .55357 Mdot
.27693 .52761 Mdot
.41631 .69999 Mdot
.70641 .55443 Mdot
.55369 .68901 Mdot
.42288 .71304 Mdot
.34927 .51713 Mdot
.51114 .69335 Mdot
.65815 .66332 Mdot
.32282 .50633 Mdot
.34408 .49716 Mdot
.65769 .37881 Mdot
.50281 .32156 Mdot
.50102 .32105 Mdot
.49814 .29663 Mdot
.68079 .34554 Mdot
.61781 .30425 Mdot
.71951 .49982 Mdot
.27916 .56791 Mdot
.72293 .51189 Mdot
.47676 .31143 Mdot
.65835 .38077 Mdot
.27243 .52829 Mdot
.31142 .64819 Mdot
.71173 .5581 Mdot
.61009 .2992 Mdot
.36595 .47913 Mdot
.62476 .66577 Mdot
.68233 .5899 Mdot
.35868 .67343 Mdot
.62901 .292 Mdot
.39737 .29687 Mdot
.37224 .46482 Mdot
.68743 .58686 Mdot
.54372 .6819 Mdot
.68794 .58632 Mdot
.30889 .51938 Mdot
.27813 .54294 Mdot
.64079 .64781 Mdot
.35987 .29833 Mdot
.35066 .6614 Mdot
.33448 .5292 Mdot
.63451 .30454 Mdot
.62993 .64782 Mdot
.34292 .31368 Mdot
.33853 .64706 Mdot
.48256 .29843 Mdot
.41253 .31179 Mdot
.3617 .49926 Mdot
.34563 .67318 Mdot
.45335 .33586 Mdot
.70431 .54175 Mdot
.35366 .30359 Mdot
.68722 .41076 Mdot
.63213 .67984 Mdot
.71936 .50359 Mdot
.46455 .29954 Mdot
.73748 .48726 Mdot
.30873 .62007 Mdot
.47123 .30795 Mdot
.70651 .50577 Mdot
.30549 .33115 Mdot
.50749 .3095 Mdot
.64973 .36223 Mdot
.3019 .53873 Mdot
.3486 .66833 Mdot
.34908 .51801 Mdot
.35147 .32268 Mdot
.65462 .65584 Mdot
.71303 .4762 Mdot
.70867 .53039 Mdot
.35517 .52463 Mdot
.52824 .7165 Mdot
.65787 .62773 Mdot
.46823 .32341 Mdot
.37349 .31317 Mdot
.36923 .32233 Mdot
.36407 .51895 Mdot
.31709 .64673 Mdot
.51772 .70516 Mdot
.35473 .51341 Mdot
.36502 .51876 Mdot
.6156 .28422 Mdot
.50529 .69744 Mdot
.68288 .35889 Mdot
.42252 .68559 Mdot
.36534 .47171 Mdot
.72718 .50794 Mdot
.69177 .5499 Mdot
.49346 .32254 Mdot
.70528 .53137 Mdot
.61379 .29209 Mdot
.5015 .32056 Mdot
.35507 .51242 Mdot
.61158 .70011 Mdot
.35469 .51454 Mdot
.35179 .51511 Mdot
.28872 .52481 Mdot
.36135 .46995 Mdot
.7016 .37123 Mdot
.37574 .30776 Mdot
.33513 .64657 Mdot
.6688 .34809 Mdot
.6777 .41487 Mdot
.27519 .55359 Mdot
.36064 .50548 Mdot
.3404 .51934 Mdot
.52688 .68681 Mdot
.41255 .70323 Mdot
.68667 .57838 Mdot
.64079 .6475 Mdot
.3463 .49209 Mdot
.62854 .27611 Mdot
.28095 .54626 Mdot
.53439 .71494 Mdot
.71486 .49346 Mdot
.68289 .62951 Mdot
.45647 .30554 Mdot
.4753 .33339 Mdot
.50648 .31814 Mdot
.50012 .29602 Mdot
.73472 .46657 Mdot
.65843 .38226 Mdot
.37087 .28442 Mdot
.34832 .48099 Mdot
.35158 .49235 Mdot
.27376 .54429 Mdot
.61011 .27811 Mdot
.49962 .33668 Mdot
.3043 .53765 Mdot
.45274 .71459 Mdot
.69218 .36942 Mdot
.50945 .30226 Mdot
.58948 .67288 Mdot
.63774 .68156 Mdot
.62685 .28722 Mdot
.74313 .48619 Mdot
.35848 .31198 Mdot
.56836 .2903 Mdot
.65374 .6691 Mdot
.48555 .68649 Mdot
.68893 .3791 Mdot
.32715 .65683 Mdot
.44582 .68088 Mdot
.67778 .37909 Mdot
.40807 .70347 Mdot
.6623 .65435 Mdot
.49749 .29962 Mdot
.32287 .664 Mdot
.34043 .66699 Mdot
.63468 .39017 Mdot
.37118 .49561 Mdot
.6911 .34086 Mdot
.65149 .36395 Mdot
.49525 .31645 Mdot
.65477 .36341 Mdot
.67964 .5607 Mdot
.67278 .35988 Mdot
.54855 .68681 Mdot
.37159 .51343 Mdot
.49823 .72248 Mdot
.25088 .60529 Mdot
.32921 .51095 Mdot
.67593 .58315 Mdot
.71684 .50279 Mdot
.3374 .50803 Mdot
.37638 .33741 Mdot
.65005 .36842 Mdot
.62303 .30001 Mdot
.41365 .69587 Mdot
.61232 .27391 Mdot
.63295 .68737 Mdot
.72418 .50413 Mdot
.71686 .50336 Mdot
.50417 .32319 Mdot
.5235 .71646 Mdot
.72805 .46032 Mdot
.72574 .48104 Mdot
.38014 .28308 Mdot
.32007 .50897 Mdot
.55327 .67879 Mdot
.33389 .65352 Mdot
.39554 .32766 Mdot
.35017 .51343 Mdot
.68069 .35716 Mdot
.62243 .29629 Mdot
.25668 .60628 Mdot
.66515 .37085 Mdot
.49024 .32492 Mdot
.51664 .68455 Mdot
.41822 .68934 Mdot
.65256 .66111 Mdot
.38041 .49553 Mdot
.72004 .50615 Mdot
.63467 .68406 Mdot
.43339 .34806 Mdot
.32901 .52353 Mdot
.55137 .71332 Mdot
.33842 .64393 Mdot
.34863 .51639 Mdot
.64875 .39196 Mdot
.36871 .33503 Mdot
.42985 .332 Mdot
.69657 .38692 Mdot
.3969 .31099 Mdot
.5957 .68488 Mdot
.6486 .39399 Mdot
.38452 .32148 Mdot
.51039 .27806 Mdot
.48131 .29523 Mdot
.3814 .31131 Mdot
.26429 .54168 Mdot
.70361 .54824 Mdot
.64932 .64777 Mdot
.28998 .53647 Mdot
.37678 .43169 Mdot
.49023 .71948 Mdot
.47408 .32225 Mdot
.34558 .519 Mdot
.31475 .51847 Mdot
.53156 .7138 Mdot
.71322 .59356 Mdot
.651 .3538 Mdot
.47809 .32946 Mdot
.6519 .66635 Mdot
.70671 .60293 Mdot
.6514 .39282 Mdot
.37484 .32751 Mdot
.69625 .54235 Mdot
.61035 .70093 Mdot
.47608 .31767 Mdot
.68389 .56298 Mdot
.6981 .37971 Mdot
.27723 .55587 Mdot
.44108 .71758 Mdot
.68397 .38715 Mdot
.27854 .55573 Mdot
.43013 .68503 Mdot
.62781 .29713 Mdot
.71453 .53337 Mdot
.64674 .67728 Mdot
.70651 .56521 Mdot
.36916 .31686 Mdot
.53508 .70189 Mdot
.65151 .67483 Mdot
.69157 .54969 Mdot
.48482 .71393 Mdot
.31746 .65805 Mdot
.72784 .49879 Mdot
.32541 .64663 Mdot
.29328 .54632 Mdot
.47911 .31674 Mdot
.37213 .30341 Mdot
.72266 .50543 Mdot
.51713 .69013 Mdot
.67398 .5569 Mdot
.26076 .56152 Mdot
.4141 .70766 Mdot
.35802 .30729 Mdot
.62379 .64286 Mdot
.71446 .53054 Mdot
.68538 .5771 Mdot
.6342 .30387 Mdot
.36859 .33863 Mdot
.26379 .53847 Mdot
.6013 .27561 Mdot
.27485 .53944 Mdot
.68308 .59324 Mdot
.42246 .68269 Mdot
.63358 .67485 Mdot
.73236 .49813 Mdot
.43808 .68898 Mdot
.34819 .65425 Mdot
.34397 .49905 Mdot
.62333 .29167 Mdot
.66442 .64849 Mdot
.52245 .31943 Mdot
.32568 .51332 Mdot
.32847 .52935 Mdot
.4842 .33555 Mdot
.28027 .56635 Mdot
.71672 .55252 Mdot
.50966 .32226 Mdot
.69066 .37193 Mdot
.50373 .30244 Mdot
.48495 .32536 Mdot
.61622 .69165 Mdot
.63108 .29808 Mdot
.47889 .33489 Mdot
.3209 .53122 Mdot
.35021 .52294 Mdot
.71055 .55587 Mdot
.31974 .65689 Mdot
.33806 .6624 Mdot
.66222 .34464 Mdot
.37613 .28077 Mdot
.29826 .53642 Mdot
.51754 .71517 Mdot
.34726 .31565 Mdot
.4541 .32399 Mdot
.62621 .68129 Mdot
.25873 .55035 Mdot
.61497 .28366 Mdot
.50294 .30484 Mdot
.46136 .33336 Mdot
.36042 .30901 Mdot
.69663 .58766 Mdot
.54616 .70964 Mdot
.65071 .36375 Mdot
.44291 .71307 Mdot
.36121 .27144 Mdot
.62294 .284 Mdot
.48062 .31698 Mdot
.47124 .30547 Mdot
.52594 .71514 Mdot
.55106 .68979 Mdot
.4428 .31427 Mdot
.6677 .34691 Mdot
.71552 .4652 Mdot
.73396 .49109 Mdot
.33648 .67668 Mdot
.69308 .5419 Mdot
.64594 .6783 Mdot
.28391 .56131 Mdot
.37234 .32349 Mdot
.68211 .57982 Mdot
.50719 .32041 Mdot
.64872 .67358 Mdot
.54662 .69601 Mdot
.33515 .53111 Mdot
.3533 .50733 Mdot
.63392 .28403 Mdot
.25607 .56444 Mdot
.70985 .56846 Mdot
.35521 .32742 Mdot
.6541 .38385 Mdot
.41506 .69695 Mdot
.62886 .6643 Mdot
.53515 .3359 Mdot
.34279 .64338 Mdot
.66231 .35119 Mdot
.65099 .65249 Mdot
.34697 .32402 Mdot
.37689 .30892 Mdot
.32584 .50792 Mdot
.47547 .35754 Mdot
.67875 .57387 Mdot
.52018 .71263 Mdot
.60162 .67442 Mdot
.3429 .65484 Mdot
.35881 .50701 Mdot
.40813 .69632 Mdot
.72286 .46529 Mdot
.26617 .54165 Mdot
.35412 .31336 Mdot
.66339 .65363 Mdot
.2684 .53159 Mdot
.35267 .33901 Mdot
.52191 .32041 Mdot
.47717 .3037 Mdot
.64219 .35487 Mdot
.35155 .33363 Mdot
.35674 .33844 Mdot
.34924 .33909 Mdot
.71139 .51101 Mdot
.35784 .67028 Mdot
.34838 .27131 Mdot
.37047 .49599 Mdot
.29761 .54396 Mdot
.43427 .71914 Mdot
.72942 .51227 Mdot
.625 .27905 Mdot
.30855 .52279 Mdot
.36804 .49474 Mdot
.66164 .6385 Mdot
.45032 .70675 Mdot
.30563 .51503 Mdot
.62635 .67599 Mdot
.55725 .67659 Mdot
.63561 .37613 Mdot
.69765 .60684 Mdot
.60117 .26901 Mdot
.33258 .64238 Mdot
.32713 .63955 Mdot
.64521 .68837 Mdot
.70063 .54378 Mdot
.32737 .64123 Mdot
.6942 .58951 Mdot
.65995 .66941 Mdot
.44512 .7181 Mdot
.55264 .68827 Mdot
.40112 .3024 Mdot
.30701 .51972 Mdot
.68704 .55357 Mdot
.30983 .52071 Mdot
.69106 .54828 Mdot
.38848 .45636 Mdot
.32028 .64145 Mdot
.36377 .4859 Mdot
.25639 .54562 Mdot
.4471 .35321 Mdot
.35711 .50544 Mdot
.63507 .31104 Mdot
.63514 .66037 Mdot
.40131 .28995 Mdot
.42196 .72308 Mdot
.30015 .53884 Mdot
.34242 .51793 Mdot
.48825 .71857 Mdot
.34148 .51135 Mdot
.60269 .27109 Mdot
.33636 .6416 Mdot
.30909 .51441 Mdot
.69536 .57047 Mdot
.73416 .48008 Mdot
.62326 .70117 Mdot
.46965 .3076 Mdot
.63038 .638 Mdot
.34105 .52591 Mdot
.64279 .36594 Mdot
.41436 .32759 Mdot
.35784 .33661 Mdot
.64898 .64963 Mdot
.31112 .34318 Mdot
.73227 .46508 Mdot
.67302 .41061 Mdot
.43555 .71151 Mdot
.68731 .36362 Mdot
.65442 .34851 Mdot
.62861 .64813 Mdot
.37272 .30423 Mdot
.29324 .53971 Mdot
.56292 .69447 Mdot
.52073 .67613 Mdot
.34423 .65667 Mdot
.63849 .37962 Mdot
.45465 .33636 Mdot
.38328 .70074 Mdot
.40111 .31761 Mdot
.39247 .31579 Mdot
.69313 .55247 Mdot
.64238 .36382 Mdot
.47972 .32854 Mdot
.38096 .32307 Mdot
.63502 .37953 Mdot
.47464 .29577 Mdot
.62924 .30564 Mdot
.51969 .70724 Mdot
.36591 .46119 Mdot
.55938 .7084 Mdot
.70692 .52906 Mdot
.63389 .29737 Mdot
.52079 .69728 Mdot
.52324 .71925 Mdot
.48051 .32398 Mdot
.6878 .39865 Mdot
.49059 .70798 Mdot
.31674 .51321 Mdot
.4883 .3003 Mdot
.34167 .53294 Mdot
.37511 .33949 Mdot
.34725 .52303 Mdot
.6326 .28386 Mdot
.68753 .58192 Mdot
.65655 .37328 Mdot
.69036 .55386 Mdot
.27222 .57116 Mdot
.32633 .52705 Mdot
.35958 .51084 Mdot
.32855 .66162 Mdot
.62521 .69448 Mdot
.56148 .68927 Mdot
.65798 .35512 Mdot
.655 .36979 Mdot
.42528 .72341 Mdot
.6187 .6706 Mdot
.52695 .29664 Mdot
.3265 .64374 Mdot
.34353 .50742 Mdot
.63491 .66157 Mdot
.42811 .71933 Mdot
.72335 .45833 Mdot
.32549 .6637 Mdot
.62528 .69166 Mdot
.6148 .30121 Mdot
.3656 .51892 Mdot
.46831 .32942 Mdot
.44595 .33529 Mdot
.33549 .63149 Mdot
.39348 .32946 Mdot
.63731 .67713 Mdot
.46035 .32413 Mdot
.63477 .6576 Mdot
.6856 .34553 Mdot
.73138 .46096 Mdot
.63118 .67163 Mdot
.33937 .51707 Mdot
.59963 .27702 Mdot
.70144 .54626 Mdot
.28926 .52251 Mdot
.73 .49592 Mdot
.5293 .69808 Mdot
.64548 .6606 Mdot
.47416 .29586 Mdot
.40886 .70414 Mdot
.67954 .57713 Mdot
.35473 .48943 Mdot
.55243 .68635 Mdot
.44231 .69372 Mdot
.39795 .32585 Mdot
.28277 .54324 Mdot
.3324 .49665 Mdot
.63442 .31618 Mdot
.26691 .55871 Mdot
.71085 .49258 Mdot
.73766 .47172 Mdot
.71258 .47588 Mdot
.61449 .69481 Mdot
.43244 .33146 Mdot
.54895 .70224 Mdot
.49348 .32441 Mdot
.68319 .40256 Mdot
.29152 .52358 Mdot
.50359 .29677 Mdot
.72052 .50207 Mdot
.38239 .30635 Mdot
.34527 .64332 Mdot
.67897 .3936 Mdot
.46881 .30266 Mdot
.68316 .57332 Mdot
.52311 .68406 Mdot
.62947 .67855 Mdot
.62301 .30517 Mdot
.27282 .52748 Mdot
.35366 .50903 Mdot
.71897 .49339 Mdot
.49151 .35599 Mdot
.39584 .31378 Mdot
.51522 .30859 Mdot
.72102 .49525 Mdot
.32302 .65992 Mdot
.53028 .69409 Mdot
.31053 .51727 Mdot
.32336 .65529 Mdot
.71074 .50324 Mdot
.54424 .67149 Mdot
.39672 .30633 Mdot
.37019 .47209 Mdot
.63918 .67552 Mdot
.69607 .56288 Mdot
.51795 .28102 Mdot
.41279 .68738 Mdot
.36012 .49153 Mdot
.2945 .50763 Mdot
.34117 .67322 Mdot
.44073 .70802 Mdot
.45896 .30365 Mdot
.30583 .50656 Mdot
.4218 .72258 Mdot
.44719 .70903 Mdot
.2763 .5456 Mdot
.27345 .54789 Mdot
.63849 .66169 Mdot
.34552 .68527 Mdot
.68027 .3619 Mdot
.40614 .70227 Mdot
.53064 .33955 Mdot
.43479 .7086 Mdot
.33232 .67784 Mdot
.56031 .67214 Mdot
.32068 .62371 Mdot
.664 .66216 Mdot
.61041 .68143 Mdot
.70649 .52945 Mdot
.43873 .69165 Mdot
.66187 .35086 Mdot
.4554 .33371 Mdot
.62345 .28014 Mdot
.63904 .65983 Mdot
.63716 .38294 Mdot
.7392 .50725 Mdot
.68392 .38752 Mdot
.69096 .3657 Mdot
.6863 .58382 Mdot
.64953 .64532 Mdot
.3421 .64409 Mdot
.684 .58539 Mdot
.47268 .33641 Mdot
.37485 .32619 Mdot
.52097 .67674 Mdot
.51504 .31533 Mdot
.36443 .47879 Mdot
.70307 .50361 Mdot
.68159 .39815 Mdot
.28822 .50834 Mdot
.61642 .66481 Mdot
.34288 .32259 Mdot
.63466 .67025 Mdot
.4561 .30311 Mdot
.39253 .29661 Mdot
.26118 .54234 Mdot
.52693 .34217 Mdot
.71462 .5369 Mdot
.28994 .54238 Mdot
.5636 .67745 Mdot
.62437 .28119 Mdot
.67576 .56924 Mdot
.71513 .57179 Mdot
.47167 .32943 Mdot
.62306 .68895 Mdot
.55354 .69452 Mdot
.49864 .32089 Mdot
.69431 .56532 Mdot
.50198 .72266 Mdot
.32132 .5125 Mdot
.6947 .53863 Mdot
.29361 .53835 Mdot
.3763 .46137 Mdot
.3496 .3027 Mdot
.49798 .29711 Mdot
.45073 .70981 Mdot
.65773 .39878 Mdot
.43062 .72359 Mdot
.38043 .47987 Mdot
.25568 .56765 Mdot
.35574 .49596 Mdot
.28325 .51017 Mdot
.61126 .2894 Mdot
.63352 .69824 Mdot
.48898 .30537 Mdot
.478 .3192 Mdot
.44433 .69353 Mdot
.59364 .26474 Mdot
.38657 .31371 Mdot
.62799 .30837 Mdot
.32942 .52699 Mdot
.35067 .50366 Mdot
.53998 .69246 Mdot
.37538 .45607 Mdot
.50084 .29981 Mdot
.35317 .49554 Mdot
.32758 .62857 Mdot
.69968 .5657 Mdot
.32959 .49888 Mdot
.36262 .52039 Mdot
.72788 .45976 Mdot
.69604 .5676 Mdot
.62024 .28702 Mdot
.48333 .2944 Mdot
.64365 .35185 Mdot
.39904 .31592 Mdot
.29663 .50873 Mdot
.27836 .56566 Mdot
.323 .66829 Mdot
.40257 .31069 Mdot
.43268 .70538 Mdot
.38426 .47646 Mdot
.37525 .50161 Mdot
.39152 .31551 Mdot
.70423 .53968 Mdot
.63316 .66518 Mdot
.37446 .46069 Mdot
.4794 .32003 Mdot
.44597 .70811 Mdot
.35749 .34226 Mdot
.63633 .65674 Mdot
.56149 .70365 Mdot
.65121 .65524 Mdot
.68584 .57207 Mdot
.62964 .29368 Mdot
.39206 .29582 Mdot
.63401 .67107 Mdot
.65275 .40087 Mdot
.72561 .50598 Mdot
.34439 .67913 Mdot
.70882 .53376 Mdot
.62957 .64757 Mdot
.61646 .6894 Mdot
.60457 .68102 Mdot
.41329 .69269 Mdot
.28022 .51077 Mdot
.49042 .32621 Mdot
.72014 .49626 Mdot
.66214 .40044 Mdot
.2608 .56484 Mdot
.56858 .69243 Mdot
.24535 .53221 Mdot
.25924 .54473 Mdot
.3473 .52366 Mdot
.36816 .50829 Mdot
.45199 .30977 Mdot
.36225 .4835 Mdot
.37051 .49794 Mdot
.70957 .57044 Mdot
.62201 .28518 Mdot
.32523 .52859 Mdot
.4784 .30404 Mdot
.38136 .27731 Mdot
.34255 .32177 Mdot
.36904 .46794 Mdot
.47339 .68926 Mdot
.62844 .66854 Mdot
.67309 .34836 Mdot
.63836 .3695 Mdot
.35204 .31936 Mdot
.70193 .57083 Mdot
.65688 .65688 Mdot
.61173 .30055 Mdot
.38842 .29335 Mdot
.29042 .52995 Mdot
.32971 .66287 Mdot
.31933 .62321 Mdot
.34801 .67169 Mdot
.29018 .52478 Mdot
.51106 .31189 Mdot
.67291 .34635 Mdot
.35345 .67845 Mdot
.54683 .7167 Mdot
.36473 .33926 Mdot
.36948 .33018 Mdot
.50712 .68921 Mdot
.38078 .48275 Mdot
.6844 .55743 Mdot
.31812 .64646 Mdot
.67105 .60154 Mdot
.65768 .62992 Mdot
.34186 .27211 Mdot
.28047 .54666 Mdot
.28016 .54989 Mdot
.3525 .48679 Mdot
.50166 .69282 Mdot
.55276 .682 Mdot
.51904 .68962 Mdot
.70103 .56508 Mdot
.28796 .54828 Mdot
.72376 .47411 Mdot
.49903 .29909 Mdot
.63491 .68266 Mdot
.36675 .68484 Mdot
.65551 .37019 Mdot
.44814 .71192 Mdot
.36792 .29967 Mdot
.34088 .65783 Mdot
.47987 .30813 Mdot
.34025 .4892 Mdot
.65936 .38185 Mdot
.52596 .69454 Mdot
.44551 .71563 Mdot
.7004 .37994 Mdot
.30475 .50722 Mdot
.45904 .34231 Mdot
.51005 .29946 Mdot
.39995 .30156 Mdot
.28477 .5476 Mdot
.35863 .30184 Mdot
.68029 .57616 Mdot
.32425 .52649 Mdot
.31115 .51363 Mdot
.34561 .51568 Mdot
.2652 .54477 Mdot
.70271 .55657 Mdot
.43573 .69248 Mdot
.48069 .33958 Mdot
.49178 .29406 Mdot
.43697 .70861 Mdot
.37689 .3024 Mdot
.73359 .48988 Mdot
.61955 .28447 Mdot
.50051 .33029 Mdot
.39631 .29416 Mdot
.29288 .54121 Mdot
.34049 .50778 Mdot
.486 .29576 Mdot
.26372 .54229 Mdot
.42233 .69245 Mdot
.68511 .37659 Mdot
.44373 .69986 Mdot
.3468 .33073 Mdot
.36426 .30135 Mdot
.70407 .54966 Mdot
.6324 .67228 Mdot
.3555 .32075 Mdot
.6585 .3876 Mdot
.33237 .49963 Mdot
.27972 .5449 Mdot
.5502 .68765 Mdot
.2539 .56094 Mdot
.34737 .33209 Mdot
.26353 .53955 Mdot
.50526 .70141 Mdot
.48684 .71128 Mdot
.36088 .49181 Mdot
.4238 .69694 Mdot
.61305 .69034 Mdot
.37797 .32485 Mdot
.70148 .57468 Mdot
.23938 .59268 Mdot
.69479 .58825 Mdot
.51655 .69012 Mdot
.46461 .32604 Mdot
.64416 .64442 Mdot
.4646 .32723 Mdot
.54711 .66806 Mdot
.3684 .5162 Mdot
.54716 .68428 Mdot
.47601 .34166 Mdot
.65705 .35415 Mdot
.69242 .38845 Mdot
.5016 .30489 Mdot
.63583 .67966 Mdot
.49258 .32164 Mdot
.36192 .31672 Mdot
.71508 .51447 Mdot
.60888 .68297 Mdot
.69165 .36895 Mdot
.681 .39771 Mdot
.71784 .4939 Mdot
.34579 .52099 Mdot
.3129 .51685 Mdot
.68203 .3866 Mdot
.67069 .60012 Mdot
.6441 .68684 Mdot
.35467 .50935 Mdot
.50654 .32605 Mdot
.68243 .36691 Mdot
.74871 .47765 Mdot
.53945 .69702 Mdot
.44861 .71546 Mdot
.25635 .56828 Mdot
.73525 .46973 Mdot
.32598 .50231 Mdot
.42009 .69528 Mdot
.38513 .32696 Mdot
.35805 .47758 Mdot
.29927 .54361 Mdot
.73515 .47387 Mdot
.47907 .33323 Mdot
.34902 .67043 Mdot
.69845 .35718 Mdot
.31596 .50873 Mdot
.3017 .31408 Mdot
.48821 .29584 Mdot
.28847 .5333 Mdot
.50808 .33281 Mdot
.6517 .66144 Mdot
.34889 .51061 Mdot
.72673 .50727 Mdot
.66497 .35241 Mdot
.27297 .52754 Mdot
.43318 .34905 Mdot
.73303 .49964 Mdot
.47794 .30873 Mdot
.39625 .31138 Mdot
.42585 .71468 Mdot
.26397 .57444 Mdot
.60998 .27838 Mdot
.37844 .3124 Mdot
.34271 .52151 Mdot
.65206 .38059 Mdot
.736 .48282 Mdot
.49417 .30483 Mdot
.2982 .53887 Mdot
.72865 .48403 Mdot
.69573 .57555 Mdot
.36215 .29963 Mdot
.62376 .71136 Mdot
.37179 .51722 Mdot
.34508 .52964 Mdot
.59369 .7 Mdot
.54981 .69437 Mdot
.30527 .52043 Mdot
.32398 .53465 Mdot
.68371 .56192 Mdot
.23539 .55088 Mdot
.3375 .49087 Mdot
.4726 .34157 Mdot
.67521 .56957 Mdot
.63635 .36589 Mdot
.68211 .40133 Mdot
.37532 .31792 Mdot
.65467 .65257 Mdot
.35308 .30124 Mdot
.67014 .35553 Mdot
.307 .5296 Mdot
.68802 .59082 Mdot
.44287 .7277 Mdot
.7264 .49797 Mdot
.66618 .39026 Mdot
.53591 .71241 Mdot
.31336 .66121 Mdot
.30193 .3166 Mdot
.67284 .6111 Mdot
.62129 .30275 Mdot
.35903 .33658 Mdot
.54656 .71686 Mdot
.33536 .52371 Mdot
.34533 .68216 Mdot
.27492 .52731 Mdot
.4342 .33096 Mdot
.61523 .27608 Mdot
.47471 .29571 Mdot
.47296 .32975 Mdot
.28931 .51073 Mdot
.69618 .57622 Mdot
.72847 .4693 Mdot
.46047 .31565 Mdot
.68813 .57205 Mdot
.33402 .53257 Mdot
.67033 .3846 Mdot
.58062 .67213 Mdot
.34256 .50867 Mdot
.37278 .28259 Mdot
.74304 .50062 Mdot
.52637 .72027 Mdot
.63638 .37076 Mdot
.28102 .5492 Mdot
.64247 .63115 Mdot
.68109 .58232 Mdot
.36064 .47163 Mdot
.66188 .35314 Mdot
.50146 .32968 Mdot
.64945 .37502 Mdot
.29599 .53073 Mdot
.27525 .54989 Mdot
.48112 .3359 Mdot
.34329 .50943 Mdot
.64377 .69784 Mdot
.41071 .68862 Mdot
.45163 .71939 Mdot
.37108 .49592 Mdot
.5718 .6806 Mdot
.74034 .49276 Mdot
.45936 .31715 Mdot
.34142 .67363 Mdot
.25934 .55139 Mdot
.61078 .69326 Mdot
.7351 .49029 Mdot
.71738 .58521 Mdot
.70124 .5609 Mdot
.65737 .35253 Mdot
.70036 .57314 Mdot
.35035 .48801 Mdot
.65767 .67457 Mdot
.66986 .36673 Mdot
.47543 .31332 Mdot
.6563 .40657 Mdot
.32657 .51305 Mdot
.74397 .50184 Mdot
.67617 .40821 Mdot
.40884 .70005 Mdot
.65929 .66763 Mdot
.51388 .34839 Mdot
.47509 .68746 Mdot
.30799 .53008 Mdot
.2784 .52634 Mdot
.51446 .30728 Mdot
.70414 .55195 Mdot
.54454 .69623 Mdot
.63146 .30583 Mdot
.34505 .32671 Mdot
.66365 .66343 Mdot
.3458 .31362 Mdot
.32766 .65718 Mdot
.5749 .68545 Mdot
.32788 .62895 Mdot
.6942 .54778 Mdot
.63157 .67941 Mdot
.35972 .34362 Mdot
.40235 .70227 Mdot
.36985 .30716 Mdot
.64048 .37883 Mdot
.32786 .64015 Mdot
.68883 .37162 Mdot
.7152 .50365 Mdot
.62378 .29466 Mdot
.67722 .57535 Mdot
.43607 .34978 Mdot
.42152 .68267 Mdot
.74079 .48048 Mdot
.72441 .51201 Mdot
.67738 .35505 Mdot
.46559 .30961 Mdot
.43769 .69503 Mdot
.4481 .32385 Mdot
.45803 .31124 Mdot
.73132 .46822 Mdot
.62663 .68018 Mdot
.62122 .66855 Mdot
.39805 .28794 Mdot
.62686 .67778 Mdot
.67868 .37457 Mdot
.32643 .6632 Mdot
.32635 .68271 Mdot
.74067 .49414 Mdot
.42792 .71509 Mdot
.35536 .48211 Mdot
.61393 .27006 Mdot
.67446 .38057 Mdot
.69963 .5693 Mdot
.60741 .66577 Mdot
.45919 .32595 Mdot
.53952 .69916 Mdot
.65191 .66942 Mdot
.64854 .66353 Mdot
.64206 .64282 Mdot
.27947 .55421 Mdot
.67559 .58248 Mdot
.64013 .67623 Mdot
.29653 .53568 Mdot
.35233 .53041 Mdot
.49991 .32861 Mdot
.43403 .33249 Mdot
.42825 .69494 Mdot
.48823 .32737 Mdot
.34164 .50276 Mdot
.65494 .36367 Mdot
.43141 .33703 Mdot
.46165 .33053 Mdot
.66642 .34783 Mdot
.66767 .34647 Mdot
.45056 .31912 Mdot
.43144 .3356 Mdot
.63928 .69971 Mdot
.39989 .68359 Mdot
.56393 .67807 Mdot
.67895 .40941 Mdot
.71061 .48543 Mdot
.54908 .68593 Mdot
.27997 .5238 Mdot
.51326 .32169 Mdot
.66131 .38051 Mdot
.60816 .67889 Mdot
.36294 .50673 Mdot
.48266 .32273 Mdot
.36751 .31273 Mdot
.4733 .31249 Mdot
.51213 .31138 Mdot
.54312 .6774 Mdot
.69057 .52069 Mdot
.52945 .71559 Mdot
.69972 .3729 Mdot
.48443 .30945 Mdot
.49098 .71763 Mdot
.63516 .29481 Mdot
.71445 .51634 Mdot
.40919 .68819 Mdot
.37164 .49129 Mdot
.67425 .34867 Mdot
.63324 .68742 Mdot
.71231 .54722 Mdot
.32277 .626 Mdot
.63383 .67213 Mdot
.46728 .29774 Mdot
.50685 .30619 Mdot
.68241 .36487 Mdot
.52519 .68245 Mdot
.42014 .69636 Mdot
.64074 .67046 Mdot
.72053 .48967 Mdot
.26049 .53822 Mdot
.62994 .63806 Mdot
.48076 .32775 Mdot
.62472 .66875 Mdot
.66268 .39885 Mdot
.35378 .31202 Mdot
.2696 .54008 Mdot
.69501 .6123 Mdot
.34191 .5199 Mdot
.71771 .48971 Mdot
.36375 .27807 Mdot
.41595 .71618 Mdot
.2872 .52731 Mdot
.34008 .67838 Mdot
.72761 .51241 Mdot
.29548 .52523 Mdot
.31533 .662 Mdot
.5586 .70743 Mdot
.52874 .7045 Mdot
.32991 .52795 Mdot
.68164 .38289 Mdot
.69381 .33959 Mdot
.35661 .52502 Mdot
.7017 .38199 Mdot
.31677 .64443 Mdot
.45423 .33224 Mdot
.40132 .3246 Mdot
.28354 .56122 Mdot
.27808 .5338 Mdot
.36297 .48651 Mdot
.25941 .53877 Mdot
.31452 .62178 Mdot
.66696 .35386 Mdot
.64365 .35402 Mdot
.36441 .31969 Mdot
.30273 .5043 Mdot
.36186 .30362 Mdot
.73684 .48403 Mdot
.43288 .68674 Mdot
.50447 .29556 Mdot
.62784 .673 Mdot
.34531 .5132 Mdot
.64533 .38309 Mdot
.28748 .53295 Mdot
.42009 .70549 Mdot
.68025 .37103 Mdot
.65778 .37655 Mdot
.69297 .344 Mdot
.35188 .33671 Mdot
.64437 .65265 Mdot
.33921 .49803 Mdot
.37945 .33514 Mdot
.46717 .33438 Mdot
.24301 .60159 Mdot
.66359 .65759 Mdot
.63222 .65885 Mdot
.6362 .64922 Mdot
.35229 .48995 Mdot
.34969 .49109 Mdot
.71879 .48187 Mdot
.55725 .69415 Mdot
.68167 .5936 Mdot
.67968 .35046 Mdot
.70311 .36119 Mdot
.28253 .53378 Mdot
.38133 .28639 Mdot
.37491 .30223 Mdot
.6679 .40908 Mdot
.50748 .30024 Mdot
.35398 .30451 Mdot
.34146 .49801 Mdot
.68358 .36072 Mdot
.35723 .34077 Mdot
.62069 .65315 Mdot
.71176 .58799 Mdot
.35372 .30804 Mdot
.47808 .33021 Mdot
.5614 .69997 Mdot
.2743 .56258 Mdot
.34776 .30671 Mdot
.74005 .48849 Mdot
.34295 .64334 Mdot
.50327 .29845 Mdot
.38124 .28991 Mdot
.23474 .5566 Mdot
.67222 .36108 Mdot
.4771 .33102 Mdot
.3638 .34405 Mdot
.33368 .68633 Mdot
.36223 .29614 Mdot
.62873 .66254 Mdot
.4751 .69857 Mdot
.2776 .53045 Mdot
.41481 .70991 Mdot
.70678 .5323 Mdot
.64055 .38158 Mdot
.64051 .3674 Mdot
.53866 .68334 Mdot
.33122 .67125 Mdot
.68636 .38314 Mdot
.33835 .67613 Mdot
.41242 .30861 Mdot
.29607 .53599 Mdot
.39764 .2868 Mdot
.40426 .70666 Mdot
.34848 .3423 Mdot
.35364 .30987 Mdot
.73916 .50232 Mdot
.68866 .58057 Mdot
.70256 .55202 Mdot
.687 .37749 Mdot
.33367 .65905 Mdot
.64282 .35767 Mdot
.60933 .70966 Mdot
.38533 .31472 Mdot
.61178 .29838 Mdot
.36177 .48164 Mdot
.34503 .49912 Mdot
.43704 .71902 Mdot
.51147 .31914 Mdot
.30143 .52962 Mdot
.72541 .48292 Mdot
.65301 .40134 Mdot
.74213 .50557 Mdot
.51474 .68722 Mdot
.60312 .70773 Mdot
.65784 .37291 Mdot
.41172 .30214 Mdot
.37127 .29938 Mdot
.23077 .56373 Mdot
.44662 .33899 Mdot
.65022 .36171 Mdot
.37947 .49557 Mdot
.60759 .68372 Mdot
.61925 .30876 Mdot
.34852 .51301 Mdot
.67959 .40088 Mdot
.63802 .29689 Mdot
.409 .70941 Mdot
.26741 .5581 Mdot
.71365 .53389 Mdot
.33671 .67206 Mdot
.3457 .33601 Mdot
.48381 .33614 Mdot
.36892 .68361 Mdot
.67141 .35458 Mdot
.64756 .40078 Mdot
.3484 .31761 Mdot
.52973 .71884 Mdot
.61423 .67396 Mdot
.63728 .70006 Mdot
.72223 .48283 Mdot
.37333 .50814 Mdot
.68213 .36074 Mdot
.54015 .70631 Mdot
.33905 .49231 Mdot
.68795 .55969 Mdot
.6671 .41127 Mdot
.34348 .50947 Mdot
.28802 .52825 Mdot
.36145 .30694 Mdot
.37998 .27693 Mdot
.48925 .33874 Mdot
.71501 .51876 Mdot
.25493 .52571 Mdot
.43668 .68855 Mdot
.36103 .49131 Mdot
.63717 .69178 Mdot
.49657 .32071 Mdot
.3735 .30439 Mdot
.30486 .51359 Mdot
.33553 .6811 Mdot
.61911 .6897 Mdot
.69143 .54972 Mdot
.481 .31388 Mdot
.26568 .5173 Mdot
.34198 .51432 Mdot
.27006 .5326 Mdot
.41322 .6929 Mdot
.36914 .47995 Mdot
.62317 .27798 Mdot
.51754 .7164 Mdot
.391 .32609 Mdot
.64758 .65834 Mdot
.63146 .3009 Mdot
.41262 .68624 Mdot
.33351 .64881 Mdot
.57493 .68302 Mdot
.66092 .66602 Mdot
.71954 .49179 Mdot
.67742 .58424 Mdot
.38313 .28517 Mdot
.28988 .5355 Mdot
.49083 .29693 Mdot
.64509 .6708 Mdot
.64035 .3792 Mdot
.36148 .30287 Mdot
.62048 .3034 Mdot
.3577 .49492 Mdot
.67626 .35641 Mdot
.49911 .30682 Mdot
.51758 .68349 Mdot
.65686 .36129 Mdot
.50191 .32928 Mdot
.37632 .32756 Mdot
.34655 .65115 Mdot
.43187 .32605 Mdot
.46717 .326 Mdot
.28452 .5378 Mdot
.41114 .72463 Mdot
.42093 .71327 Mdot
.4661 .3406 Mdot
.63424 .37594 Mdot
.47496 .32597 Mdot
.52904 .72151 Mdot
.41019 .70908 Mdot
.65619 .3984 Mdot
.55405 .68911 Mdot
.4085 .68954 Mdot
.46273 .32598 Mdot
.66337 .65465 Mdot
.6347 .3033 Mdot
.60147 .67963 Mdot
.29563 .54942 Mdot
.36517 .51395 Mdot
.68928 .37327 Mdot
.36883 .30875 Mdot
.72157 .47239 Mdot
.73975 .46915 Mdot
.72638 .51051 Mdot
.69225 .358 Mdot
.34538 .51069 Mdot
.63585 .6773 Mdot
.68339 .58132 Mdot
.54333 .69318 Mdot
.65613 .38804 Mdot
.67517 .3856 Mdot
.43902 .71757 Mdot
.36292 .3014 Mdot
.3611 .48239 Mdot
.64071 .37844 Mdot
.62484 .29102 Mdot
.50218 .72324 Mdot
.34911 .33994 Mdot
.42043 .68754 Mdot
.43332 .32418 Mdot
.31854 .50414 Mdot
.57037 .6985 Mdot
.50232 .30278 Mdot
.51803 .68459 Mdot
.3143 .52232 Mdot
.71084 .44285 Mdot
.63455 .29339 Mdot
.33535 .67294 Mdot
.71463 .53539 Mdot
.68225 .58742 Mdot
.66037 .35922 Mdot
.35959 .50282 Mdot
.61794 .30203 Mdot
.3745 .31869 Mdot
.41322 .7191 Mdot
.45818 .31723 Mdot
.54747 .69021 Mdot
.69239 .58671 Mdot
.43135 .34436 Mdot
.72156 .47263 Mdot
.70099 .54882 Mdot
.56391 .67504 Mdot
.27808 .53088 Mdot
.66395 .37517 Mdot
.67703 .39059 Mdot
.39934 .28833 Mdot
.60611 .26907 Mdot
.62001 .66157 Mdot
.70935 .44232 Mdot
.35598 .68157 Mdot
.33044 .5233 Mdot
.46186 .30127 Mdot
.48886 .29817 Mdot
.62815 .29683 Mdot
.29598 .52467 Mdot
.51958 .70142 Mdot
.63956 .36062 Mdot
.68648 .39425 Mdot
.41194 .70525 Mdot
.68699 .58224 Mdot
.4575 .34426 Mdot
.67653 .37701 Mdot
.24159 .59528 Mdot
.28067 .53512 Mdot
.6725 .60917 Mdot
.67645 .37457 Mdot
.60017 .26346 Mdot
.71712 .46294 Mdot
.53387 .71138 Mdot
.35451 .66551 Mdot
.53399 .69688 Mdot
.3563 .30324 Mdot
.64535 .36147 Mdot
.73143 .4741 Mdot
.47996 .31053 Mdot
.69102 .33735 Mdot
.68908 .37778 Mdot
.63758 .66108 Mdot
.27425 .53025 Mdot
.37497 .46671 Mdot
.34075 .51365 Mdot
.23447 .54981 Mdot
.34615 .33351 Mdot
.74003 .46925 Mdot
.71956 .49433 Mdot
.35475 .66617 Mdot
.35487 .34034 Mdot
.65585 .35028 Mdot
.67994 .36901 Mdot
.69586 .61021 Mdot
.51163 .31081 Mdot
.65181 .35151 Mdot
.28148 .53863 Mdot
.69514 .34554 Mdot
.5694 .69108 Mdot
.68896 .58261 Mdot
.26022 .54859 Mdot
.69048 .37465 Mdot
.54538 .6764 Mdot
.3342 .66423 Mdot
.35349 .52628 Mdot
.49915 .33888 Mdot
.67899 .58298 Mdot
.59708 .70692 Mdot
.61557 .27057 Mdot
.36862 .51503 Mdot
.73374 .48422 Mdot
.46862 .35677 Mdot
.68288 .33297 Mdot
.65069 .65109 Mdot
.68014 .39794 Mdot
.69969 .57796 Mdot
.49509 .30899 Mdot
.39271 .32487 Mdot
.64933 .36973 Mdot
.68355 .40179 Mdot
.43074 .70575 Mdot
.40777 .29767 Mdot
.34664 .30957 Mdot
.64818 .68234 Mdot
.6841 .55991 Mdot
.41782 .70641 Mdot
.23713 .58873 Mdot
.34566 .49333 Mdot
.70367 .54847 Mdot
.5138 .72781 Mdot
.37645 .50516 Mdot
.36559 .49354 Mdot
.36165 .47215 Mdot
.53782 .71651 Mdot
.63988 .68201 Mdot
.25467 .52337 Mdot
.42601 .69758 Mdot
.33093 .65202 Mdot
.63025 .66681 Mdot
.64333 .65654 Mdot
.33867 .65528 Mdot
.42763 .70667 Mdot
.55676 .68774 Mdot
.6881 .57673 Mdot
.6819 .58725 Mdot
.64975 .66223 Mdot
.43466 .71997 Mdot
.6999 .54369 Mdot
.53462 .6911 Mdot
.66768 .38892 Mdot
.31692 .65193 Mdot
.65638 .65908 Mdot
.32491 .6406 Mdot
.68035 .5755 Mdot
.23169 .58054 Mdot
.31657 .64378 Mdot
.37192 .48333 Mdot
.28073 .5288 Mdot
.36404 .33707 Mdot
.47558 .31018 Mdot
.45047 .31896 Mdot
.70418 .55354 Mdot
.35997 .48446 Mdot
.518 .69136 Mdot
.35444 .48776 Mdot
.25537 .56489 Mdot
.23319 .57782 Mdot
.36162 .67853 Mdot
.65102 .65292 Mdot
.51723 .6905 Mdot
.70116 .36433 Mdot
.64496 .39302 Mdot
.32584 .67434 Mdot
.67995 .58468 Mdot
.62169 .67327 Mdot
.68203 .59318 Mdot
.67146 .35593 Mdot
.66211 .37646 Mdot
.4964 .32511 Mdot
.4777 .33128 Mdot
.66394 .36288 Mdot
.69982 .38247 Mdot
.23562 .59027 Mdot
.55232 .68941 Mdot
.54628 .71961 Mdot
.26742 .57128 Mdot
.37659 .46096 Mdot
.3693 .31083 Mdot
.42955 .33632 Mdot
.72815 .48159 Mdot
.3464 .67689 Mdot
.32701 .517 Mdot
.46759 .32294 Mdot
.70359 .53136 Mdot
.38632 .30298 Mdot
.68592 .58527 Mdot
.39531 .31892 Mdot
.65748 .3983 Mdot
.34894 .50473 Mdot
.36533 .4867 Mdot
.72138 .49189 Mdot
.69619 .3508 Mdot
.68549 .36139 Mdot
.37273 .30895 Mdot
.27019 .56909 Mdot
.67967 .36182 Mdot
.65748 .65923 Mdot
.65952 .63148 Mdot
.49601 .30194 Mdot
.36179 .50543 Mdot
.27688 .56459 Mdot
.40903 .70743 Mdot
.46425 .33349 Mdot
.48096 .3145 Mdot
.62693 .71102 Mdot
.31736 .51266 Mdot
.71781 .58652 Mdot
.47672 .33367 Mdot
.64233 .64588 Mdot
.66348 .37222 Mdot
.46 .33084 Mdot
.44583 .3318 Mdot
.3123 .28874 Mdot
.44883 .31638 Mdot
.62175 .68499 Mdot
.52951 .69679 Mdot
.44011 .69745 Mdot
.52644 .73075 Mdot
.40183 .30716 Mdot
.38098 .30447 Mdot
.63419 .29114 Mdot
.72912 .50695 Mdot
.34867 .48087 Mdot
.38239 .31384 Mdot
.61043 .66395 Mdot
.44429 .71432 Mdot
.43924 .71024 Mdot
.43917 .70466 Mdot
.53997 .69348 Mdot
.27968 .54809 Mdot
.6195 .27843 Mdot
.63555 .66241 Mdot
.44424 .70105 Mdot
.38403 .48294 Mdot
.6317 .69873 Mdot
.69008 .553 Mdot
.43176 .72519 Mdot
.63393 .67677 Mdot
.32644 .62657 Mdot
.67921 .56907 Mdot
.33872 .68016 Mdot
.66817 .42741 Mdot
.59789 .26417 Mdot
.69676 .5719 Mdot
.66847 .41111 Mdot
.67917 .35636 Mdot
.68404 .3746 Mdot
.6453 .67715 Mdot
.69133 .39435 Mdot
.51391 .69284 Mdot
.62094 .3023 Mdot
.27361 .51399 Mdot
.39276 .29639 Mdot
.62255 .2913 Mdot
.64799 .66305 Mdot
.59301 .70144 Mdot
.30553 .33173 Mdot
.36202 .52382 Mdot
.7379 .47631 Mdot
.36743 .32282 Mdot
.32674 .66218 Mdot
.38448 .32777 Mdot
.66316 .35205 Mdot
.28382 .51302 Mdot
.28056 .5347 Mdot
.71392 .58639 Mdot
.36724 .30768 Mdot
.64573 .6558 Mdot
.43377 .70598 Mdot
.63651 .35854 Mdot
.37511 .31705 Mdot
.36514 .30101 Mdot
.34667 .52856 Mdot
.52925 .69508 Mdot
.67767 .34819 Mdot
.6814 .55542 Mdot
.63664 .30965 Mdot
.27489 .61428 Mdot
.31518 .51308 Mdot
.36894 .51627 Mdot
.3254 .65508 Mdot
.62785 .30165 Mdot
.69147 .57219 Mdot
.25365 .56187 Mdot
.61735 .26696 Mdot
.25389 .56636 Mdot
.50342 .69056 Mdot
.62009 .29548 Mdot
.49074 .30111 Mdot
.49923 .32935 Mdot
.35534 .51194 Mdot
.30169 .32017 Mdot
.29465 .54298 Mdot
.6975 .54205 Mdot
.47154 .30738 Mdot
.67759 .41228 Mdot
.611 .67505 Mdot
.30961 .29193 Mdot
.42524 .69443 Mdot
.68262 .55415 Mdot
.67915 .36483 Mdot
.30271 .30308 Mdot
.36041 .33529 Mdot
.31245 .64709 Mdot
.35064 .53157 Mdot
.35778 .51086 Mdot
.69578 .55478 Mdot
.70167 .53912 Mdot
.56371 .70602 Mdot
.43757 .32044 Mdot
.65172 .6296 Mdot
.72568 .5005 Mdot
.30392 .29994 Mdot
.48659 .29705 Mdot
.5206 .70961 Mdot
.45948 .30433 Mdot
.70785 .53236 Mdot
.30968 .52158 Mdot
.53003 .69595 Mdot
.50244 .30781 Mdot
.48139 .6893 Mdot
.43162 .71409 Mdot
.24123 .59599 Mdot
.34611 .52488 Mdot
.62596 .65917 Mdot
.63298 .6625 Mdot
.5208 .69207 Mdot
.50767 .31145 Mdot
.35396 .49521 Mdot
.37063 .50088 Mdot
.37292 .50671 Mdot
.50834 .72583 Mdot
.34832 .50791 Mdot
.60651 .67521 Mdot
.31746 .66059 Mdot
.71471 .44409 Mdot
.3623 .48792 Mdot
.70397 .56583 Mdot
.35351 .51806 Mdot
.34285 .31904 Mdot
.35009 .66009 Mdot
.40621 .70042 Mdot
.69011 .56815 Mdot
.37975 .47971 Mdot
.53056 .33941 Mdot
.33659 .50094 Mdot
.3992 .31165 Mdot
.71475 .47067 Mdot
.28482 .55268 Mdot
.50458 .72363 Mdot
.64322 .66741 Mdot
.64874 .38142 Mdot
.71077 .56546 Mdot
.65616 .35442 Mdot
.398 .68402 Mdot
.47745 .29677 Mdot
.61466 .30148 Mdot
.2358 .58603 Mdot
.31097 .522 Mdot
.51318 .30544 Mdot
.52183 .68716 Mdot
.6251 .28213 Mdot
.37497 .45715 Mdot
.4389 .71832 Mdot
.35015 .31679 Mdot
.38169 .32735 Mdot
.36167 .27191 Mdot
.54106 .70181 Mdot
.59216 .69713 Mdot
.69375 .55625 Mdot
.68812 .38071 Mdot
.34939 .34153 Mdot
.68769 .63146 Mdot
.70786 .54137 Mdot
.62854 .29355 Mdot
.69085 .58721 Mdot
.35823 .49107 Mdot
.4501 .32068 Mdot
.55073 .70919 Mdot
.46302 .31708 Mdot
.33086 .50065 Mdot
.6899 .38869 Mdot
.50815 .30545 Mdot
.37653 .33558 Mdot
.70491 .56905 Mdot
.65537 .36843 Mdot
.27212 .53232 Mdot
.63054 .66354 Mdot
.37947 .69439 Mdot
.61124 .26421 Mdot
.4068 .69818 Mdot
.40648 .69578 Mdot
.5415 .71716 Mdot
.46028 .33611 Mdot
.6655 .32272 Mdot
.40361 .70099 Mdot
.71912 .50728 Mdot
.37056 .2873 Mdot
.60511 .2857 Mdot
.64209 .36637 Mdot
.6716 .36595 Mdot
.31792 .51654 Mdot
.64259 .35232 Mdot
.34485 .65968 Mdot
.63543 .36203 Mdot
.72228 .46251 Mdot
.2873 .54384 Mdot
.67836 .3704 Mdot
.47261 .33288 Mdot
.27624 .53958 Mdot
.52685 .70598 Mdot
.65178 .34696 Mdot
.3721 .48324 Mdot
.69559 .39705 Mdot
.71904 .49117 Mdot
.50727 .31481 Mdot
.34011 .63865 Mdot
.6851 .57593 Mdot
.62648 .6863 Mdot
.35374 .65272 Mdot
.37923 .31858 Mdot
.5143 .69914 Mdot
.37414 .28367 Mdot
.36557 .29886 Mdot
.32054 .64958 Mdot
.65682 .67273 Mdot
.48046 .30171 Mdot
.37939 .32672 Mdot
.4037 .32119 Mdot
.67222 .3639 Mdot
.63328 .28334 Mdot
.47533 .32779 Mdot
.26915 .53405 Mdot
.61159 .28688 Mdot
.69894 .57328 Mdot
.3526 .52916 Mdot
.68679 .36792 Mdot
.47861 .30447 Mdot
.36655 .49821 Mdot
.42656 .69669 Mdot
.55556 .70928 Mdot
.44139 .31907 Mdot
.3973 .30747 Mdot
.52752 .70097 Mdot
.36719 .51791 Mdot
.40303 .30388 Mdot
.63673 .30635 Mdot
.2732 .54487 Mdot
.65041 .64911 Mdot
.61538 .65771 Mdot
.63921 .3774 Mdot
.68943 .55041 Mdot
.67551 .39338 Mdot
.39804 .31763 Mdot
.30586 .33395 Mdot
.48864 .32892 Mdot
.4068 .71234 Mdot
.34652 .65724 Mdot
.64497 .37421 Mdot
.64342 .65349 Mdot
.67826 .62344 Mdot
.34963 .65786 Mdot
.27635 .54327 Mdot
.36187 .50896 Mdot
.62436 .29884 Mdot
.61167 .67672 Mdot
.36225 .50718 Mdot
.43266 .33418 Mdot
.27844 .54634 Mdot
.3595 .31781 Mdot
.64955 .4143 Mdot
.49713 .3325 Mdot
.50072 .72428 Mdot
.50515 .31004 Mdot
.67967 .37725 Mdot
.32958 .62706 Mdot
.3306 .6554 Mdot
.33921 .27283 Mdot
.62159 .68603 Mdot
.5487 .67607 Mdot
.6653 .37757 Mdot
.63263 .30109 Mdot
.42703 .69259 Mdot
.43313 .70311 Mdot
.27708 .53825 Mdot
.66268 .35246 Mdot
.64031 .39413 Mdot
.46832 .30017 Mdot
.50946 .30338 Mdot
.32715 .67778 Mdot
.65631 .39512 Mdot
.34929 .50506 Mdot
.42643 .71795 Mdot
.71057 .54404 Mdot
.53397 .7037 Mdot
.74319 .48612 Mdot
.71133 .54336 Mdot
.36654 .46283 Mdot
.24819 .53311 Mdot
.7224 .48093 Mdot
.73375 .50963 Mdot
.63052 .29169 Mdot
.3308 .68295 Mdot
.35554 .30624 Mdot
.23683 .55059 Mdot
.65587 .35297 Mdot
.34132 .50528 Mdot
.62567 .65433 Mdot
.45096 .30744 Mdot
.68999 .6238 Mdot
.36013 .41076 Mdot
.43313 .69059 Mdot
.61323 .27925 Mdot
.46573 .32575 Mdot
.46124 .31573 Mdot
.27096 .5637 Mdot
.3507 .50529 Mdot
.63922 .37581 Mdot
.33372 .68595 Mdot
.72648 .5003 Mdot
.63217 .29477 Mdot
.54282 .70319 Mdot
.35214 .51625 Mdot
.61955 .69884 Mdot
.70941 .55729 Mdot
.37415 .29256 Mdot
.35516 .33698 Mdot
.3345 .50328 Mdot
.40964 .68726 Mdot
.71493 .50492 Mdot
.43232 .69796 Mdot
.4226 .70544 Mdot
.4784 .32387 Mdot
.4189 .68761 Mdot
.3514 .53216 Mdot
.37528 .51409 Mdot
.46729 .33451 Mdot
.70883 .5401 Mdot
.3042 .53769 Mdot
.46173 .32518 Mdot
.3497 .65211 Mdot
.70638 .57484 Mdot
.43065 .69594 Mdot
.70176 .56093 Mdot
.63002 .29571 Mdot
.72118 .48694 Mdot
.38999 .32701 Mdot
.62593 .29083 Mdot
.54737 .71856 Mdot
.63466 .67754 Mdot
.67642 .58625 Mdot
.37495 .32735 Mdot
.702 .56626 Mdot
.65121 .36767 Mdot
.71708 .50183 Mdot
.48595 .71031 Mdot
.24584 .59951 Mdot
.36475 .46543 Mdot
.67136 .59651 Mdot
.64941 .39628 Mdot
.64948 .66315 Mdot
.72819 .50849 Mdot
.34133 .64536 Mdot
.35743 .33447 Mdot
.35655 .51347 Mdot
.7068 .56482 Mdot
.61868 .28766 Mdot
.56824 .69706 Mdot
.39376 .31829 Mdot
.60207 .70907 Mdot
.64868 .38689 Mdot
.28634 .54253 Mdot
.73096 .4612 Mdot
.67484 .32771 Mdot
.72177 .4936 Mdot
.37591 .47 Mdot
.49637 .29684 Mdot
.43765 .32421 Mdot
.55865 .68047 Mdot
.51489 .30504 Mdot
.45057 .35554 Mdot
.7218 .51128 Mdot
.52226 .71624 Mdot
.7006 .36885 Mdot
.26801 .53448 Mdot
.43784 .69036 Mdot
.48829 .32595 Mdot
.62142 .66708 Mdot
.41262 .69419 Mdot
.49799 .32602 Mdot
.31702 .65916 Mdot
.53347 .69914 Mdot
.65861 .34687 Mdot
.28302 .53778 Mdot
.73268 .46488 Mdot
.73119 .49713 Mdot
.46902 .29696 Mdot
.72484 .47129 Mdot
.35007 .65296 Mdot
.65852 .66934 Mdot
.43779 .69603 Mdot
.36068 .31909 Mdot
.6457 .69595 Mdot
.44771 .3116 Mdot
.31768 .28454 Mdot
.28462 .53885 Mdot
.66364 .37625 Mdot
.68547 .33514 Mdot
.32494 .675 Mdot
.63227 .66687 Mdot
.34759 .66371 Mdot
.41429 .69053 Mdot
.43271 .70017 Mdot
.68818 .38007 Mdot
.32681 .65931 Mdot
.34791 .50713 Mdot
.68154 .55739 Mdot
.30302 .61989 Mdot
.38139 .4746 Mdot
.43054 .33098 Mdot
.40633 .7009 Mdot
.72503 .46417 Mdot
.55271 .69103 Mdot
.66542 .37488 Mdot
.51734 .70254 Mdot
.54835 .69494 Mdot
.6364 .68207 Mdot
.68567 .63214 Mdot
.40416 .70188 Mdot
.70638 .60246 Mdot
.57027 .69051 Mdot
.37705 .46327 Mdot
.61537 .66313 Mdot
.65188 .31882 Mdot
.52082 .7163 Mdot
.62539 .68642 Mdot
.58142 .67172 Mdot
.61261 .67629 Mdot
.27392 .5353 Mdot
.25894 .55028 Mdot
.36034 .68474 Mdot
.6195 .29995 Mdot
.3409 .51197 Mdot
.44796 .3209 Mdot
.36024 .32318 Mdot
.53121 .7176 Mdot
.47875 .3128 Mdot
.32144 .6449 Mdot
.52456 .31351 Mdot
.33814 .53133 Mdot
.36439 .50064 Mdot
.43812 .70252 Mdot
.23132 .5738 Mdot
.61457 .29708 Mdot
.63903 .64946 Mdot
.3826 .47558 Mdot
.68472 .33357 Mdot
.29887 .53228 Mdot
.34914 .6658 Mdot
.37789 .50771 Mdot
.66388 .3752 Mdot
.54897 .70159 Mdot
.45672 .31228 Mdot
.62193 .70301 Mdot
.34208 .52212 Mdot
.52755 .30006 Mdot
.39222 .29125 Mdot
.36218 .50374 Mdot
.62815 .70034 Mdot
.41297 .69256 Mdot
.62924 .6898 Mdot
.65191 .6832 Mdot
.27673 .54341 Mdot
.54033 .70954 Mdot
.64155 .68176 Mdot
.43244 .70241 Mdot
.61291 .28019 Mdot
.71502 .51587 Mdot
.30521 .5306 Mdot
.3931 .31791 Mdot
.29151 .525 Mdot
.36161 .29724 Mdot
.45111 .32417 Mdot
.47093 .32635 Mdot
.28701 .54624 Mdot
.65406 .40377 Mdot
.35064 .30349 Mdot
.61647 .29733 Mdot
.48426 .71613 Mdot
.56103 .67633 Mdot
.72469 .50193 Mdot
.63292 .28219 Mdot
.47334 .3258 Mdot
.30291 .54116 Mdot
.27848 .61454 Mdot
.72259 .47574 Mdot
.51413 .68467 Mdot
.29929 .53906 Mdot
.51582 .31012 Mdot
.66197 .34494 Mdot
.67698 .38886 Mdot
.72094 .51046 Mdot
.57691 .67211 Mdot
.352 .49292 Mdot
.5153 .31021 Mdot
.45125 .72061 Mdot
.47613 .30922 Mdot
.45774 .30865 Mdot
.67052 .41274 Mdot
.35636 .49719 Mdot
.31977 .64174 Mdot
.67599 .35232 Mdot
.37743 .29901 Mdot
.52154 .68236 Mdot
.40199 .30923 Mdot
.71481 .58168 Mdot
.55902 .70917 Mdot
.66357 .35825 Mdot
.50332 .32994 Mdot
.33715 .51366 Mdot
.54491 .69625 Mdot
.5268 .68611 Mdot
.53098 .70724 Mdot
.36332 .32119 Mdot
.63968 .36681 Mdot
.63364 .30968 Mdot
.27539 .53209 Mdot
.66116 .66276 Mdot
.31303 .28778 Mdot
.29063 .52765 Mdot
.68137 .58535 Mdot
.41115 .6971 Mdot
.65285 .65631 Mdot
.41334 .71723 Mdot
.57305 .68427 Mdot
.67967 .38488 Mdot
.32847 .50964 Mdot
.27118 .53797 Mdot
.28268 .55363 Mdot
.38685 .30395 Mdot
.61394 .68807 Mdot
.25095 .52847 Mdot
.31845 .50421 Mdot
.27778 .56224 Mdot
.36643 .50493 Mdot
.36388 .46641 Mdot
.45164 .33846 Mdot
.49271 .32927 Mdot
.34356 .65236 Mdot
.35587 .52342 Mdot
.6369 .69763 Mdot
.55776 .70417 Mdot
.45023 .68234 Mdot
.70272 .54643 Mdot
.52116 .71758 Mdot
.67387 .34999 Mdot
.65533 .34484 Mdot
.70066 .35741 Mdot
.38809 .33241 Mdot
.43173 .69444 Mdot
.32663 .51504 Mdot
.69698 .54366 Mdot
.38088 .32015 Mdot
.66255 .66325 Mdot
.36132 .30065 Mdot
.33678 .67451 Mdot
.38596 .32934 Mdot
.47949 .29526 Mdot
.71922 .46105 Mdot
.42682 .7178 Mdot
.38622 .29682 Mdot
.52999 .70272 Mdot
.29726 .54213 Mdot
.26449 .55682 Mdot
.59229 .70195 Mdot
.34918 .31357 Mdot
.63689 .31044 Mdot
.29372 .53543 Mdot
.29445 .50638 Mdot
.70317 .55581 Mdot
.39252 .32471 Mdot
.68391 .59048 Mdot
.41587 .69897 Mdot
.53726 .67594 Mdot
.63829 .66451 Mdot
.73018 .50043 Mdot
.34852 .66523 Mdot
.38942 .32896 Mdot
.666 .36087 Mdot
.34079 .68622 Mdot
.61312 .29709 Mdot
.51704 .327 Mdot
.28238 .55778 Mdot
.62023 .27748 Mdot
.38339 .47952 Mdot
.72904 .4894 Mdot
.35245 .487 Mdot
.41065 .71349 Mdot
.30094 .51223 Mdot
.68383 .35466 Mdot
.67186 .36687 Mdot
.61939 .30452 Mdot
.31966 .5102 Mdot
.3845 .48942 Mdot
.54444 .68968 Mdot
.63959 .37044 Mdot
.64449 .67524 Mdot
.62529 .66151 Mdot
.67054 .41125 Mdot
.62631 .69317 Mdot
.3642 .301 Mdot
.29202 .51176 Mdot
.72858 .48917 Mdot
.72208 .49654 Mdot
.66294 .3615 Mdot
.67796 .40895 Mdot
.66217 .37586 Mdot
.41401 .69613 Mdot
.65568 .67293 Mdot
.23993 .5425 Mdot
.34706 .52657 Mdot
.36309 .48414 Mdot
.54439 .70264 Mdot
.34778 .65374 Mdot
.37946 .43618 Mdot
.35196 .31544 Mdot
.67762 .3779 Mdot
.69477 .58705 Mdot
.38337 .70168 Mdot
.68793 .54921 Mdot
.27402 .54783 Mdot
.7132 .50769 Mdot
.51175 .68686 Mdot
.37764 .33276 Mdot
.41581 .71118 Mdot
.36151 .33915 Mdot
.71013 .54368 Mdot
.53236 .6862 Mdot
.32847 .66639 Mdot
.28289 .54553 Mdot
.33673 .66145 Mdot
.51165 .27907 Mdot
.5755 .68608 Mdot
.68149 .56799 Mdot
.42455 .71566 Mdot
.5148 .32764 Mdot
.45917 .71329 Mdot
.31706 .51806 Mdot
.37397 .47627 Mdot
.34915 .48174 Mdot
.25808 .548 Mdot
.53415 .71196 Mdot
.34437 .67087 Mdot
.50715 .32581 Mdot
.26554 .54085 Mdot
.70134 .60326 Mdot
.33339 .52409 Mdot
.36655 .48548 Mdot
.33453 .51015 Mdot
.37547 .47394 Mdot
.52855 .72111 Mdot
.44027 .70461 Mdot
.6899 .54841 Mdot
.30853 .50526 Mdot
.734 .50354 Mdot
.65982 .3646 Mdot
.44353 .31306 Mdot
.54186 .71349 Mdot
.35994 .33902 Mdot
.71799 .56703 Mdot
.28871 .50864 Mdot
.70226 .36456 Mdot
.2558 .5605 Mdot
.43178 .32803 Mdot
.4525 .31741 Mdot
.39227 .32772 Mdot
.69091 .37679 Mdot
.69258 .57623 Mdot
.37888 .49737 Mdot
.64664 .67124 Mdot
.62583 .67827 Mdot
.26741 .5424 Mdot
.70549 .52564 Mdot
.7309 .49694 Mdot
.62315 .29051 Mdot
.35324 .49267 Mdot
.25964 .5481 Mdot
.63526 .69197 Mdot
.63636 .30046 Mdot
.32864 .64855 Mdot
.37527 .31171 Mdot
.32389 .5343 Mdot
.51179 .32108 Mdot
.34141 .66987 Mdot
.69488 .5464 Mdot
.48494 .30282 Mdot
.32187 .52601 Mdot
.24724 .53332 Mdot
.42225 .72303 Mdot
.39008 .28214 Mdot
.63835 .38702 Mdot
.28007 .5417 Mdot
.28928 .53418 Mdot
.5348 .6988 Mdot
.72142 .48928 Mdot
.64471 .65267 Mdot
.49011 .71379 Mdot
.47145 .32622 Mdot
.71799 .49141 Mdot
.35841 .48064 Mdot
.72093 .46731 Mdot
.41046 .69744 Mdot
.30778 .52997 Mdot
.68228 .56614 Mdot
.64103 .69265 Mdot
.62577 .64156 Mdot
.27363 .55342 Mdot
.41929 .70455 Mdot
.29179 .52539 Mdot
.63496 .29813 Mdot
.45366 .30518 Mdot
.28141 .54601 Mdot
.622 .67547 Mdot
.28778 .52851 Mdot
.70986 .54741 Mdot
.38428 .29266 Mdot
.63126 .67033 Mdot
.61327 .27655 Mdot
.6839 .38498 Mdot
.64196 .38696 Mdot
.47914 .29573 Mdot
.41577 .6889 Mdot
.52173 .69779 Mdot
.64785 .64858 Mdot
.34116 .66151 Mdot
.67963 .37677 Mdot
.36476 .31331 Mdot
.26629 .53135 Mdot
.513 .32136 Mdot
.73505 .46751 Mdot
.51625 .72904 Mdot
.31808 .66282 Mdot
.40354 .31475 Mdot
.29176 .61657 Mdot
.47803 .32145 Mdot
.36067 .49349 Mdot
.39114 .32663 Mdot
.67778 .40628 Mdot
.42893 .72404 Mdot
.45008 .33979 Mdot
.61326 .29222 Mdot
.69339 .36689 Mdot
.73254 .5014 Mdot
.63533 .37727 Mdot
.36309 .34039 Mdot
.47969 .33324 Mdot
.62975 .67553 Mdot
.35802 .50211 Mdot
.48507 .32406 Mdot
.67107 .38457 Mdot
.48201 .29705 Mdot
.37184 .48824 Mdot
.60984 .69693 Mdot
.6526 .36255 Mdot
.28795 .53214 Mdot
.40474 .70466 Mdot
.54832 .71578 Mdot
.61793 .28245 Mdot
.34634 .66287 Mdot
.35358 .34441 Mdot
.69661 .35488 Mdot
.6858 .35804 Mdot
.26836 .54639 Mdot
.35617 .32968 Mdot
.34724 .52083 Mdot
.68855 .58019 Mdot
.34393 .63891 Mdot
.72125 .49199 Mdot
.25679 .56668 Mdot
.25904 .54315 Mdot
.3559 .67362 Mdot
.52252 .67624 Mdot
.50352 .35329 Mdot
.25959 .57243 Mdot
.37138 .50076 Mdot
.619 .65987 Mdot
.32652 .63888 Mdot
.25185 .60504 Mdot
.54987 .70448 Mdot
.39221 .29353 Mdot
.7047 .55496 Mdot
.27084 .52827 Mdot
.71309 .59042 Mdot
.36034 .31676 Mdot
.26752 .56502 Mdot
.31853 .67005 Mdot
.64292 .65566 Mdot
.33054 .50997 Mdot
.63845 .66901 Mdot
.30919 .52533 Mdot
.54267 .71919 Mdot
.72493 .50805 Mdot
.35315 .48025 Mdot
.47671 .333 Mdot
.67522 .32805 Mdot
.36733 .46469 Mdot
.3629 .30691 Mdot
.41403 .71642 Mdot
.4713 .32273 Mdot
.68608 .58523 Mdot
.72053 .51893 Mdot
.66305 .37718 Mdot
.68445 .54992 Mdot
.51864 .71084 Mdot
.61965 .28844 Mdot
.49871 .29881 Mdot
.44089 .72383 Mdot
.34566 .33794 Mdot
.71742 .49055 Mdot
.36535 .51075 Mdot
.34932 .49101 Mdot
.62417 .29918 Mdot
.6528 .41765 Mdot
.60186 .69148 Mdot
.5575 .7115 Mdot
.53263 .6872 Mdot
.38265 .30225 Mdot
.61628 .28396 Mdot
.32035 .52101 Mdot
.34719 .50339 Mdot
.69179 .39077 Mdot
.54762 .70254 Mdot
.36137 .32646 Mdot
.43806 .32367 Mdot
.69779 .54281 Mdot
.62059 .30844 Mdot
.63099 .67182 Mdot
.60826 .29501 Mdot
.63392 .30798 Mdot
.59003 .67179 Mdot
.26404 .57105 Mdot
.68769 .57495 Mdot
.60552 .2896 Mdot
.65323 .6539 Mdot
.27486 .54918 Mdot
.46935 .30907 Mdot
.48201 .29555 Mdot
.56894 .68208 Mdot
.65792 .3589 Mdot
.35299 .32785 Mdot
.32022 .51411 Mdot
.40607 .31869 Mdot
.54858 .69724 Mdot
.6504 .39175 Mdot
.48857 .30659 Mdot
.70369 .57924 Mdot
.28768 .52735 Mdot
.36066 .32162 Mdot
.68826 .57251 Mdot
.49852 .33007 Mdot
.29485 .50937 Mdot
.35289 .65166 Mdot
.40549 .69462 Mdot
.70162 .5558 Mdot
.33511 .6549 Mdot
.33722 .53352 Mdot
.72936 .48946 Mdot
.37536 .28291 Mdot
.66819 .32523 Mdot
.34434 .64156 Mdot
.72206 .51146 Mdot
.69294 .39068 Mdot
.6344 .37618 Mdot
.63346 .28137 Mdot
.61432 .29656 Mdot
.73541 .49575 Mdot
.48738 .31406 Mdot
.62729 .31046 Mdot
.72159 .48979 Mdot
.34462 .67558 Mdot
.27033 .52888 Mdot
.32763 .68337 Mdot
.49827 .33153 Mdot
.50476 .3161 Mdot
.55801 .69696 Mdot
.44023 .71201 Mdot
.4852 .30754 Mdot
.36572 .51596 Mdot
.52358 .68788 Mdot
.67955 .57275 Mdot
.30783 .29329 Mdot
.70115 .5377 Mdot
.43072 .72462 Mdot
.68754 .34598 Mdot
.6214 .28709 Mdot
.35844 .50303 Mdot
.71711 .54782 Mdot
.30357 .30093 Mdot
.27235 .52741 Mdot
.41584 .71125 Mdot
.25386 .56616 Mdot
.26575 .54136 Mdot
.50638 .70797 Mdot
.51234 .31535 Mdot
.52184 .69106 Mdot
.68541 .57292 Mdot
.38387 .29142 Mdot
.44321 .35284 Mdot
.703 .55284 Mdot
.33749 .52202 Mdot
.46247 .29958 Mdot
.35898 .50989 Mdot
.37454 .50398 Mdot
.32233 .50091 Mdot
.41287 .31159 Mdot
.65786 .37045 Mdot
.35714 .33946 Mdot
.61652 .68322 Mdot
.51661 .72811 Mdot
.36139 .30887 Mdot
.33666 .68465 Mdot
.32443 .64666 Mdot
.65733 .42107 Mdot
.6256 .67762 Mdot
.35778 .30089 Mdot
.70534 .56133 Mdot
.26348 .61269 Mdot
.34752 .68424 Mdot
.67952 .55914 Mdot
.37045 .49126 Mdot
.64748 .64787 Mdot
.55463 .69885 Mdot
.7155 .49645 Mdot
.65082 .65003 Mdot
.33262 .65371 Mdot
.41765 .69846 Mdot
.69557 .54548 Mdot
.26951 .57475 Mdot
.71958 .49425 Mdot
.36858 .45626 Mdot
.41694 .70708 Mdot
.63218 .66827 Mdot
.3726 .46701 Mdot
.64438 .69457 Mdot
.49952 .32283 Mdot
.31503 .50483 Mdot
.36473 .31127 Mdot
.33529 .65943 Mdot
.61256 .27217 Mdot
.50581 .68769 Mdot
.65011 .6595 Mdot
.70946 .53418 Mdot
.63682 .65556 Mdot
.55625 .67848 Mdot
.67063 .59744 Mdot
.5169 .71527 Mdot
.34132 .52189 Mdot
.53434 .72992 Mdot
.51971 .70028 Mdot
.68971 .56035 Mdot
.37167 .32015 Mdot
.53441 .70754 Mdot
.63149 .30433 Mdot
.27958 .53915 Mdot
.65929 .39062 Mdot
.34473 .31566 Mdot
.54014 .7136 Mdot
.36499 .30812 Mdot
.66538 .38323 Mdot
.43213 .3294 Mdot
.74288 .47827 Mdot
.71845 .47276 Mdot
.44171 .32988 Mdot
.71786 .50881 Mdot
.61338 .67896 Mdot
.60912 .28498 Mdot
.32939 .50417 Mdot
.35125 .49451 Mdot
.34251 .32046 Mdot
.60935 .67858 Mdot
.71087 .51235 Mdot
.47952 .3115 Mdot
.55522 .68748 Mdot
.70166 .58016 Mdot
.62516 .28792 Mdot
.32198 .64079 Mdot
.73054 .50334 Mdot
.5055 .32851 Mdot
.4758 .32319 Mdot
.36217 .50915 Mdot
.26833 .56109 Mdot
.39586 .31762 Mdot
.65062 .32033 Mdot
.44937 .70441 Mdot
.67857 .40994 Mdot
.3328 .51668 Mdot
.44538 .70164 Mdot
.36032 .52583 Mdot
.35747 .34219 Mdot
.73721 .49714 Mdot
.62979 .67954 Mdot
.36947 .29273 Mdot
.684 .38578 Mdot
.32737 .62887 Mdot
.26154 .55535 Mdot
.33794 .65216 Mdot
.6678 .34683 Mdot
.61623 .66817 Mdot
.666 .36858 Mdot
.73073 .48963 Mdot
.36031 .30411 Mdot
.41292 .69458 Mdot
.49836 .332 Mdot
.64421 .37131 Mdot
.67569 .58563 Mdot
.61105 .27569 Mdot
.72215 .51791 Mdot
.47148 .32514 Mdot
.33769 .64208 Mdot
.64251 .35181 Mdot
.4638 .31092 Mdot
.56501 .68598 Mdot
.26129 .51768 Mdot
.56175 .67174 Mdot
.66133 .35264 Mdot
.33666 .27363 Mdot
.68785 .56843 Mdot
.73693 .50832 Mdot
.37573 .45916 Mdot
.30159 .31893 Mdot
.33634 .49409 Mdot
.71192 .47505 Mdot
.72716 .48904 Mdot
.69903 .55953 Mdot
.66665 .37172 Mdot
.63225 .69713 Mdot
.48184 .68787 Mdot
.65847 .34845 Mdot
.28806 .55993 Mdot
.6625 .66328 Mdot
.35943 .68411 Mdot
.6442 .35379 Mdot
.43489 .7028 Mdot
.57333 .69352 Mdot
.35218 .30472 Mdot
.28842 .5529 Mdot
.72976 .49991 Mdot
.28597 .52333 Mdot
.70782 .60275 Mdot
.66797 .37864 Mdot
.46921 .30324 Mdot
.71161 .53539 Mdot
.35562 .48736 Mdot
.33842 .50842 Mdot
.33631 .52938 Mdot
.34375 .32258 Mdot
.56647 .69123 Mdot
.30694 .52018 Mdot
.28111 .51325 Mdot
.44277 .69187 Mdot
.62869 .27691 Mdot
.36502 .33913 Mdot
.2364 .55264 Mdot
.69725 .38892 Mdot
.55833 .69036 Mdot
.366 .47948 Mdot
.74023 .49565 Mdot
.44133 .70998 Mdot
.68841 .5543 Mdot
.69368 .58982 Mdot
.62257 .311 Mdot
.62077 .67219 Mdot
.43492 .69058 Mdot
.64609 .40059 Mdot
.50897 .68073 Mdot
.44052 .69553 Mdot
.5494 .71805 Mdot
.70829 .53847 Mdot
.3049 .33297 Mdot
.74219 .49553 Mdot
.48608 .29516 Mdot
.5162 .71108 Mdot
.66134 .6364 Mdot
.34226 .66839 Mdot
.65113 .67227 Mdot
.62289 .29835 Mdot
.52062 .69658 Mdot
.57223 .28395 Mdot
.52906 .68552 Mdot
.69147 .56373 Mdot
.71781 .49569 Mdot
.43698 .69791 Mdot
.34359 .51857 Mdot
.32336 .66253 Mdot
.47908 .31108 Mdot
.33923 .64437 Mdot
.67651 .35297 Mdot
.63027 .30668 Mdot
.71835 .46312 Mdot
.50846 .70808 Mdot
.67411 .56997 Mdot
.33717 .50997 Mdot
.4156 .7055 Mdot
.2586 .55027 Mdot
.7256 .50525 Mdot
.46756 .70859 Mdot
.3503 .52441 Mdot
.43247 .69518 Mdot
.66715 .34409 Mdot
.68226 .41083 Mdot
.57067 .67143 Mdot
.62356 .31133 Mdot
.36944 .50156 Mdot
.38361 .30984 Mdot
.38378 .33524 Mdot
.26812 .55508 Mdot
.68785 .33831 Mdot
.32788 .64925 Mdot
.36491 .5119 Mdot
.32999 .6284 Mdot
.66248 .34446 Mdot
.50873 .29784 Mdot
.6746 .38343 Mdot
.5308 .72191 Mdot
.44945 .3178 Mdot
.68393 .36227 Mdot
.31694 .64774 Mdot
.48088 .32493 Mdot
.66524 .32469 Mdot
.35803 .31841 Mdot
.35597 .52696 Mdot
.38677 .45179 Mdot
.63944 .3629 Mdot
.69377 .5694 Mdot
.52888 .71146 Mdot
.68775 .55185 Mdot
.68918 .40298 Mdot
.26979 .56631 Mdot
.50177 .32591 Mdot
.72949 .51533 Mdot
.43109 .68384 Mdot
.38405 .31548 Mdot
.74354 .49183 Mdot
.41783 .68699 Mdot
.26422 .55638 Mdot
.30189 .30702 Mdot
.3612 .48624 Mdot
.62912 .30734 Mdot
.71812 .48867 Mdot
.4097 .30026 Mdot
.35478 .50273 Mdot
.65957 .39525 Mdot
.40378 .32253 Mdot
.35947 .51328 Mdot
.61618 .27673 Mdot
.29053 .53314 Mdot
.39132 .32594 Mdot
.53163 .69819 Mdot
.34435 .63846 Mdot
.33746 .33046 Mdot
.37064 .29271 Mdot
.34563 .48417 Mdot
.25657 .54936 Mdot
.64565 .31849 Mdot
.64178 .65542 Mdot
.28142 .54413 Mdot
.34167 .32487 Mdot
.51497 .68917 Mdot
.51703 .70358 Mdot
.42716 .72437 Mdot
.70944 .56984 Mdot
.65576 .36172 Mdot
.38777 .32182 Mdot
.6357 .30338 Mdot
.27491 .52752 Mdot
.42164 .72025 Mdot
.35512 .31196 Mdot
.68031 .58357 Mdot
.41892 .69028 Mdot
.70621 .50786 Mdot
.30713 .50567 Mdot
.74377 .49525 Mdot
.36538 .47863 Mdot
.37037 .46926 Mdot
.52645 .69338 Mdot
.70274 .60457 Mdot
.72569 .51286 Mdot
.67992 .38803 Mdot
.48917 .30732 Mdot
.51884 .72887 Mdot
.362 .32106 Mdot
.47947 .68552 Mdot
.36499 .48859 Mdot
.31877 .52295 Mdot
.52425 .69485 Mdot
.25985 .55569 Mdot
.50569 .69763 Mdot
.6336 .30185 Mdot
.30154 .3209 Mdot
.63313 .67576 Mdot
.64512 .65854 Mdot
.39097 .68541 Mdot
.69656 .34628 Mdot
.52156 .68199 Mdot
.27186 .5273 Mdot
.68371 .40947 Mdot
.39202 .28343 Mdot
.36946 .32672 Mdot
.4113 .30295 Mdot
.51457 .68349 Mdot
.31344 .66342 Mdot
.40816 .69641 Mdot
.28894 .5445 Mdot
.29547 .61737 Mdot
.73046 .48801 Mdot
.30524 .51431 Mdot
.47715 .31578 Mdot
.6705 .38244 Mdot
.38316 .48548 Mdot
.36474 .51797 Mdot
.63118 .6808 Mdot
.37756 .28858 Mdot
.67093 .58686 Mdot
.46109 .31139 Mdot
.63715 .3687 Mdot
.37405 .30289 Mdot
.62409 .69407 Mdot
.37101 .46248 Mdot
.45831 .33291 Mdot
.5139 .30745 Mdot
.37008 .49557 Mdot
.28049 .54214 Mdot
.48856 .33843 Mdot
.69561 .55165 Mdot
.67824 .38981 Mdot
.45524 .31748 Mdot
.33303 .65715 Mdot
.33771 .63332 Mdot
.34772 .50078 Mdot
.64919 .68965 Mdot
.67678 .58824 Mdot
.50357 .32144 Mdot
.606 .28878 Mdot
.26516 .53227 Mdot
.34151 .68098 Mdot
.52571 .29326 Mdot
.4819 .31482 Mdot
.48261 .68717 Mdot
.36279 .33708 Mdot
.41767 .70744 Mdot
.30071 .50615 Mdot
.34797 .6511 Mdot
.35471 .48523 Mdot
.68065 .40406 Mdot
.70161 .57691 Mdot
.4447 .33386 Mdot
.6772 .37696 Mdot
.51745 .70344 Mdot
.28686 .54593 Mdot
.62298 .66222 Mdot
.64509 .64941 Mdot
.55949 .67795 Mdot
.70557 .5482 Mdot
.50196 .72476 Mdot
.48449 .33835 Mdot
.35683 .49016 Mdot
.72586 .48181 Mdot
.52381 .68061 Mdot
.35384 .66381 Mdot
.51067 .68783 Mdot
.61191 .68523 Mdot
.35146 .65279 Mdot
.42713 .69669 Mdot
.28062 .5123 Mdot
.37567 .47789 Mdot
.3553 .33467 Mdot
.66229 .64709 Mdot
.34661 .68173 Mdot
.31435 .52184 Mdot
.35941 .49902 Mdot
.43898 .69971 Mdot
.41131 .31212 Mdot
.2565 .55784 Mdot
.36259 .48973 Mdot
.23535 .55457 Mdot
.35291 .66447 Mdot
.61386 .66622 Mdot
.74002 .47039 Mdot
.42742 .72478 Mdot
.6976 .36351 Mdot
.54284 .6953 Mdot
.35555 .29964 Mdot
.49532 .70117 Mdot
.40492 .69034 Mdot
.70052 .56971 Mdot
.6526 .65626 Mdot
.64963 .36792 Mdot
.69173 .57315 Mdot
.71966 .49438 Mdot
.43936 .7032 Mdot
.67902 .39567 Mdot
.38584 .28932 Mdot
.73328 .50259 Mdot
.46091 .71342 Mdot
.69225 .56401 Mdot
.58453 .67617 Mdot
.33597 .64177 Mdot
.29771 .50755 Mdot
.49298 .31517 Mdot
.44963 .33735 Mdot
.73159 .4919 Mdot
.37477 .31358 Mdot
.42081 .68957 Mdot
.53126 .70826 Mdot
.3804 .31617 Mdot
.56919 .69567 Mdot
.62499 .28547 Mdot
.55431 .69411 Mdot
.62653 .2987 Mdot
.64986 .67612 Mdot
.28647 .5547 Mdot
.37145 .29064 Mdot
.49985 .33689 Mdot
.33179 .67378 Mdot
.49192 .30567 Mdot
.37964 .48442 Mdot
.42871 .68937 Mdot
.34049 .52285 Mdot
.70302 .36124 Mdot
.34186 .31738 Mdot
.51887 .69521 Mdot
.43008 .34544 Mdot
.67743 .5737 Mdot
.33853 .65483 Mdot
.46454 .30569 Mdot
.4181 .70442 Mdot
.50885 .69336 Mdot
.63253 .68643 Mdot
.53827 .72104 Mdot
.69787 .3566 Mdot
.49273 .35539 Mdot
.34035 .50936 Mdot
.42978 .34086 Mdot
.72594 .49188 Mdot
.71531 .50731 Mdot
.65205 .38106 Mdot
.31166 .34421 Mdot
.67876 .3742 Mdot
.38205 .27784 Mdot
.64717 .67972 Mdot
.39659 .3048 Mdot
.3401 .51695 Mdot
.54256 .70781 Mdot
.48083 .68782 Mdot
.37352 .28594 Mdot
.36351 .33847 Mdot
.71608 .50528 Mdot
.72187 .48091 Mdot
.48677 .29892 Mdot
.35246 .66545 Mdot
.35491 .66938 Mdot
.33975 .49802 Mdot
.73423 .49 Mdot
.42295 .7015 Mdot
.74344 .47697 Mdot
.42026 .71469 Mdot
.34057 .32089 Mdot
.68842 .36103 Mdot
.71176 .44304 Mdot
.54362 .69951 Mdot
.28912 .54478 Mdot
.55872 .67498 Mdot
.26212 .51821 Mdot
.72524 .51762 Mdot
.3694 .28294 Mdot
.66128 .37141 Mdot
.7156 .57007 Mdot
.6893 .36612 Mdot
.38976 .34394 Mdot
.31757 .67537 Mdot
.70997 .53535 Mdot
.33765 .64772 Mdot
.66528 .40896 Mdot
.37857 .47882 Mdot
.45771 .32402 Mdot
.46233 .29971 Mdot
.4084 .68189 Mdot
.55466 .71213 Mdot
.35431 .33561 Mdot
.33966 .51686 Mdot
.58029 .68765 Mdot
.34115 .51343 Mdot
.3414 .51155 Mdot
.37514 .50471 Mdot
.72519 .50203 Mdot
.33382 .64458 Mdot
.3428 .52003 Mdot
.61831 .30417 Mdot
.40251 .29054 Mdot
.63858 .35469 Mdot
.52766 .69255 Mdot
.38097 .32013 Mdot
.54595 .69334 Mdot
.32626 .66014 Mdot
.70503 .53501 Mdot
.56761 .69208 Mdot
.43 .70466 Mdot
.50625 .68815 Mdot
.73447 .51037 Mdot
.35233 .32395 Mdot
.47533 .31926 Mdot
.67877 .62551 Mdot
.61658 .29741 Mdot
.47654 .3059 Mdot
.61948 .28046 Mdot
.36544 .48087 Mdot
.62804 .67459 Mdot
.488 .30591 Mdot
.67912 .59255 Mdot
.6716 .41247 Mdot
.29999 .50474 Mdot
.28296 .53036 Mdot
.66994 .34819 Mdot
.48787 .31849 Mdot
.33419 .65934 Mdot
.32412 .64248 Mdot
.6635 .40857 Mdot
.67211 .60721 Mdot
.72606 .49463 Mdot
.37235 .32239 Mdot
.61112 .67555 Mdot
.63197 .68388 Mdot
.67844 .57671 Mdot
.71869 .55898 Mdot
.27719 .53431 Mdot
.28739 .53114 Mdot
.33376 .66934 Mdot
.37472 .47358 Mdot
.60605 .28466 Mdot
.47432 .30827 Mdot
.64784 .6679 Mdot
.43136 .68986 Mdot
.44508 .71364 Mdot
.33618 .52082 Mdot
.27206 .5672 Mdot
.65395 .3563 Mdot
.41378 .70744 Mdot
.39253 .32454 Mdot
.50803 .72531 Mdot
.29009 .535 Mdot
.33997 .3215 Mdot
.63879 .68219 Mdot
.65603 .32217 Mdot
.69459 .56772 Mdot
.65076 .40339 Mdot
.64844 .40243 Mdot
.50845 .27773 Mdot
.54129 .69724 Mdot
.47681 .30606 Mdot
.60601 .27244 Mdot
.47041 .29667 Mdot
.37117 .33655 Mdot
.27271 .55665 Mdot
.62156 .29932 Mdot
.63588 .36096 Mdot
.7114 .53997 Mdot
.3143 .50887 Mdot
.32729 .53461 Mdot
.72236 .51274 Mdot
.36546 .50322 Mdot
.3585 .30989 Mdot
.72898 .47625 Mdot
.65167 .65548 Mdot
.35466 .33153 Mdot
.74049 .48892 Mdot
.62872 .68572 Mdot
.43782 .70285 Mdot
.35396 .66597 Mdot
.52431 .70851 Mdot
.62917 .69374 Mdot
.2745 .53541 Mdot
.6147 .30498 Mdot
.63894 .67481 Mdot
.52437 .71444 Mdot
.53972 .72182 Mdot
.64701 .39135 Mdot
.39672 .32723 Mdot
.71114 .54948 Mdot
.34556 .52241 Mdot
.68907 .35524 Mdot
.39141 .31048 Mdot
.65368 .66009 Mdot
.35137 .53203 Mdot
.27734 .52667 Mdot
.38376 .31415 Mdot
.36804 .33988 Mdot
.37662 .31553 Mdot
.71798 .49933 Mdot
.43327 .70384 Mdot
.50951 .69733 Mdot
.72971 .51252 Mdot
.35306 .30498 Mdot
.34202 .33791 Mdot
.53468 .33604 Mdot
.28122 .53387 Mdot
.35522 .34144 Mdot
.51184 .72738 Mdot
.31441 .64264 Mdot
.46938 .29697 Mdot
.34306 .27175 Mdot
.69761 .34435 Mdot
.36673 .27239 Mdot
.70287 .57351 Mdot
.42711 .7148 Mdot
.36663 .32765 Mdot
.48026 .32912 Mdot
.28095 .53164 Mdot
.26187 .54144 Mdot
.38119 .30896 Mdot
.26005 .56844 Mdot
.62471 .68241 Mdot
.556 .67085 Mdot
.38299 .31839 Mdot
.66591 .40468 Mdot
.65861 .34635 Mdot
.67388 .36572 Mdot
.35612 .49607 Mdot
.36318 .68151 Mdot
.27478 .61505 Mdot
.53479 .72211 Mdot
.72172 .4859 Mdot
.64233 .68173 Mdot
.57614 .7006 Mdot
.51595 .70057 Mdot
.67575 .41325 Mdot
.37432 .31356 Mdot
.64814 .69107 Mdot
.717 .49711 Mdot
.73179 .49376 Mdot
.63877 .36027 Mdot
.68063 .37731 Mdot
.66457 .35953 Mdot
.54273 .71186 Mdot
.59204 .69132 Mdot
.34339 .64578 Mdot
.64656 .65011 Mdot
.6984 .38983 Mdot
.63312 .30109 Mdot
.64009 .35782 Mdot
.68697 .56135 Mdot
.65084 .68467 Mdot
.28766 .5344 Mdot
.39045 .46865 Mdot
.65928 .34548 Mdot
.3494 .31274 Mdot
.52626 .73081 Mdot
.30154 .31731 Mdot
.42888 .71974 Mdot
.68479 .58781 Mdot
.48881 .32795 Mdot
.33355 .52918 Mdot
.67679 .38849 Mdot
.34804 .27145 Mdot
.5118 .31291 Mdot
.3431 .65762 Mdot
.48571 .71697 Mdot
.69364 .57872 Mdot
.32529 .63895 Mdot
.46312 .32699 Mdot
.43162 .68718 Mdot
.73032 .47793 Mdot
.64315 .36947 Mdot
.63129 .2786 Mdot
.55739 .69896 Mdot
.28544 .54914 Mdot
.49398 .33001 Mdot
.32607 .50522 Mdot
.68154 .36161 Mdot
.35612 .33149 Mdot
.67559 .35649 Mdot
.61148 .66948 Mdot
.63943 .37859 Mdot
.33812 .53275 Mdot
.51178 .6926 Mdot
.7282 .49283 Mdot
.2665 .61243 Mdot
.43399 .34947 Mdot
.65029 .38768 Mdot
.49588 .33789 Mdot
.44328 .71048 Mdot
.44086 .7244 Mdot
.44358 .33407 Mdot
.34028 .53369 Mdot
.68255 .5648 Mdot
.50672 .70037 Mdot
.67617 .57866 Mdot
.39976 .32588 Mdot
.68134 .62855 Mdot
.69546 .56766 Mdot
.36406 .68525 Mdot
.35201 .32749 Mdot
.26877 .56719 Mdot
.35718 .52294 Mdot
.68671 .59093 Mdot
.33482 .65063 Mdot
.5803 .68775 Mdot
.31765 .64766 Mdot
.29671 .5096 Mdot
.67994 .57061 Mdot
.49815 .29818 Mdot
.32663 .64154 Mdot
.40567 .32113 Mdot
.73502 .49646 Mdot
.33637 .63148 Mdot
.47085 .30916 Mdot
.37015 .30059 Mdot
.34738 .32808 Mdot
.37171 .30564 Mdot
.34034 .53 Mdot
.36309 .47198 Mdot
.36766 .29243 Mdot
.67059 .59794 Mdot
.36807 .29459 Mdot
.36211 .27827 Mdot
.70938 .50425 Mdot
.36397 .34022 Mdot
.3666 .51008 Mdot
.42161 .71503 Mdot
.42944 .7145 Mdot
.66043 .38848 Mdot
.69036 .62273 Mdot
.62586 .30823 Mdot
.32236 .52016 Mdot
.59675 .70634 Mdot
.52292 .69766 Mdot
.47157 .34099 Mdot
.28948 .51215 Mdot
.40853 .6896 Mdot
.51817 .70788 Mdot
.33573 .66745 Mdot
.55437 .69145 Mdot
.45933 .32812 Mdot
.33271 .53157 Mdot
.53398 .69493 Mdot
.54074 .67619 Mdot
.26287 .57211 Mdot
.55486 .68797 Mdot
.65411 .67145 Mdot
.72046 .48904 Mdot
.70546 .56677 Mdot
.68157 .56654 Mdot
.68327 .38044 Mdot
.64733 .6585 Mdot
.28837 .54317 Mdot
.67972 .38653 Mdot
.3696 .49042 Mdot
.67921 .57307 Mdot
.33883 .49069 Mdot
.64546 .65789 Mdot
.36308 .51545 Mdot
.3543 .68687 Mdot
.61938 .27831 Mdot
.3832 .31322 Mdot
.56037 .70882 Mdot
.63706 .29352 Mdot
.73244 .50209 Mdot
.63437 .64601 Mdot
.36639 .28081 Mdot
.43298 .68641 Mdot
.32461 .53616 Mdot
.37684 .50513 Mdot
.43347 .68689 Mdot
.31427 .6694 Mdot
.511 .30545 Mdot
.68407 .38537 Mdot
.64548 .39544 Mdot
.2742 .5396 Mdot
.64486 .66274 Mdot
.39642 .32423 Mdot
.33801 .3265 Mdot
.45691 .3427 Mdot
.32362 .64912 Mdot
.28192 .51305 Mdot
.32562 .50059 Mdot
.28863 .5456 Mdot
.65549 .37997 Mdot
.50661 .29709 Mdot
.34128 .66702 Mdot
.3637 .30395 Mdot
.29239 .53945 Mdot
.53098 .69227 Mdot
.6569 .65966 Mdot
.65884 .35528 Mdot
.7329 .46473 Mdot
.44834 .32566 Mdot
.6436 .35118 Mdot
.27542 .53941 Mdot
.4486 .70464 Mdot
.72419 .4717 Mdot
.61159 .69115 Mdot
.37721 .3001 Mdot
.67485 .38677 Mdot
.38754 .29556 Mdot
.63849 .65469 Mdot
.65362 .66079 Mdot
.26204 .55061 Mdot
.46796 .35597 Mdot
.64246 .37403 Mdot
.34668 .50235 Mdot
.67182 .34879 Mdot
.62577 .29586 Mdot
.74359 .48074 Mdot
.28079 .54478 Mdot
.48525 .68606 Mdot
.68405 .55811 Mdot
.33064 .51545 Mdot
.43754 .71025 Mdot
.41766 .69135 Mdot
.66849 .40718 Mdot
.35736 .29532 Mdot
.36996 .29782 Mdot
.61906 .65478 Mdot
.66532 .68579 Mdot
.3175 .50503 Mdot
.64824 .3907 Mdot
.46537 .70894 Mdot
.69946 .56505 Mdot
.64855 .68032 Mdot
.69247 .51376 Mdot
.69141 .55973 Mdot
.28317 .53469 Mdot
.36123 .30954 Mdot
.62358 .69144 Mdot
.46909 .29678 Mdot
.23537 .59371 Mdot
.50878 .33242 Mdot
.49041 .35578 Mdot
.46291 .31279 Mdot
.70512 .52106 Mdot
.66659 .3555 Mdot
.51299 .68715 Mdot
.68016 .59015 Mdot
.70039 .56724 Mdot
.63719 .31126 Mdot
.5456 .7167 Mdot
.58018 .67265 Mdot
.49835 .72349 Mdot
.61701 .29717 Mdot
.36959 .31303 Mdot
.31634 .65427 Mdot
.67395 .36729 Mdot
.61599 .26632 Mdot
.71359 .501 Mdot
.71574 .50797 Mdot
.60475 .69754 Mdot
.29205 .52212 Mdot
.53886 .72182 Mdot
.37219 .48633 Mdot
.2741 .55617 Mdot
.68109 .58126 Mdot
.64881 .67947 Mdot
.71357 .47601 Mdot
.27148 .5441 Mdot
.30722 .52606 Mdot
.68604 .41055 Mdot
.47567 .31265 Mdot
.66309 .42473 Mdot
.27625 .54885 Mdot
.6845 .3724 Mdot
.57528 .68027 Mdot
.47891 .33186 Mdot
.34326 .68231 Mdot
.71781 .47853 Mdot
.50267 .32449 Mdot
.4693 .33101 Mdot
.35868 .53614 Mdot
.55229 .69328 Mdot
.63584 .64848 Mdot
.38696 .33263 Mdot
.72174 .46364 Mdot
.74025 .48006 Mdot
.70663 .51149 Mdot
.28225 .53602 Mdot
.7137 .4872 Mdot
.43703 .32007 Mdot
.33083 .51401 Mdot
.43684 .69402 Mdot
.56244 .69927 Mdot
.32402 .50474 Mdot
.40439 .70011 Mdot
.68801 .56606 Mdot
.52735 .29527 Mdot
.31702 .50584 Mdot
.66373 .35098 Mdot
.62442 .69913 Mdot
.55154 .70325 Mdot
.36967 .3316 Mdot
.72524 .5087 Mdot
.30544 .33091 Mdot
.64856 .68103 Mdot
.29324 .52909 Mdot
.69896 .5614 Mdot
.49066 .32886 Mdot
.49526 .3117 Mdot
.49699 .33935 Mdot
.66004 .66616 Mdot
.48337 .32934 Mdot
.55586 .6754 Mdot
.33196 .66543 Mdot
.27118 .55587 Mdot
.70366 .54802 Mdot
.36758 .31254 Mdot
.43032 .33252 Mdot
.62833 .29132 Mdot
.35094 .66835 Mdot
.26602 .55923 Mdot
.68477 .63183 Mdot
.36248 .31332 Mdot
.33718 .52535 Mdot
.51177 .3054 Mdot
.36969 .68326 Mdot
.31274 .28897 Mdot
.47061 .30544 Mdot
.44611 .71612 Mdot
.6154 .68232 Mdot
.48896 .3043 Mdot
.65691 .65574 Mdot
.33574 .52419 Mdot
.33945 .65703 Mdot
.62524 .65524 Mdot
.65366 .63045 Mdot
.45512 .33167 Mdot
.74161 .49077 Mdot
.33219 .65109 Mdot
.37028 .50586 Mdot
.36107 .68294 Mdot
.49643 .32288 Mdot
.67523 .61788 Mdot
.68396 .35177 Mdot
.63115 .31484 Mdot
.60444 .27343 Mdot
.72172 .51761 Mdot
.72287 .4592 Mdot
.25731 .54302 Mdot
.45798 .68638 Mdot
.36209 .68192 Mdot
.69529 .54096 Mdot
.31114 .64996 Mdot
.34358 .51872 Mdot
.36753 .494 Mdot
.67175 .34853 Mdot
.70964 .53899 Mdot
.42801 .72452 Mdot
.33992 .66431 Mdot
.34779 .30862 Mdot
.6502 .65149 Mdot
.35137 .51832 Mdot
.68258 .63199 Mdot
.66471 .40643 Mdot
.69058 .62751 Mdot
.366 .50918 Mdot
.47528 .3131 Mdot
.72071 .4687 Mdot
.72434 .49308 Mdot
.67187 .4029 Mdot
.66875 .4016 Mdot
.37021 .50452 Mdot
.67683 .56596 Mdot
.31181 .65131 Mdot
.32511 .64467 Mdot
.48601 .32149 Mdot
.38796 .32491 Mdot
.37981 .48655 Mdot
.57241 .67223 Mdot
.45015 .35531 Mdot
.35031 .49896 Mdot
.62989 .65634 Mdot
.66199 .363 Mdot
.62592 .28493 Mdot
.6397 .67858 Mdot
.62154 .28503 Mdot
.6885 .62686 Mdot
.3483 .47992 Mdot
.38198 .33256 Mdot
.38315 .68951 Mdot
.37466 .29188 Mdot
.50183 .32335 Mdot
.2836 .5335 Mdot
.64788 .321 Mdot
.60544 .26991 Mdot
.38278 .7004 Mdot
.68818 .57831 Mdot
.48273 .29519 Mdot
.42623 .70196 Mdot
.34386 .31216 Mdot
.67048 .38009 Mdot
.44997 .31081 Mdot
.28555 .54279 Mdot
.54506 .69681 Mdot
.41921 .72092 Mdot
.45894 .30742 Mdot
.50299 .31765 Mdot
.44743 .32035 Mdot
.74053 .48935 Mdot
.52305 .71777 Mdot
.71419 .5033 Mdot
.62603 .28066 Mdot
.3413 .64398 Mdot
.30449 .52853 Mdot
.64471 .67978 Mdot
.34195 .49944 Mdot
.6849 .55337 Mdot
.5559 .72166 Mdot
.37356 .31651 Mdot
.46316 .33121 Mdot
.71522 .58098 Mdot
.46713 .29718 Mdot
.44125 .69225 Mdot
.45315 .70956 Mdot
.52647 .6917 Mdot
.71056 .52952 Mdot
.38305 .47678 Mdot
.63667 .38622 Mdot
.3757 .29879 Mdot
.71787 .49485 Mdot
.44174 .69465 Mdot
.35963 .52222 Mdot
.36513 .31243 Mdot
.71672 .50738 Mdot
.45267 .34252 Mdot
.67245 .57816 Mdot
.51243 .33003 Mdot
.39314 .71244 Mdot
.36158 .51074 Mdot
.4719 .31296 Mdot
.52148 .70395 Mdot
.72444 .48554 Mdot
.5531 .70865 Mdot
.46008 .32815 Mdot
.62865 .29505 Mdot
.71823 .49162 Mdot
.29762 .53654 Mdot
.49606 .70113 Mdot
.59181 .69341 Mdot
.51785 .71474 Mdot
.56182 .30173 Mdot
.62626 .30409 Mdot
.66267 .35742 Mdot
.68854 .55942 Mdot
.69154 .35666 Mdot
.35103 .32698 Mdot
.31684 .6574 Mdot
.66091 .39718 Mdot
.52678 .71815 Mdot
.6914 .37204 Mdot
.32588 .67616 Mdot
.7402 .50045 Mdot
.64836 .34842 Mdot
.35221 .4908 Mdot
.43627 .70805 Mdot
.50403 .3129 Mdot
.41142 .30789 Mdot
.33213 .66342 Mdot
.30342 .51807 Mdot
.47074 .32056 Mdot
.36365 .51291 Mdot
.68215 .55736 Mdot
.26892 .61096 Mdot
.35018 .65313 Mdot
.62465 .29074 Mdot
.65714 .63139 Mdot
.64773 .39809 Mdot
.34511 .34336 Mdot
.34329 .50092 Mdot
.3601 .51666 Mdot
.41882 .69539 Mdot
.53788 .72979 Mdot
.72399 .50046 Mdot
.34182 .64231 Mdot
.61526 .29081 Mdot
.5177 .68922 Mdot
.52269 .68942 Mdot
.2955 .54294 Mdot
.47141 .31104 Mdot
.70065 .58129 Mdot
.33871 .53142 Mdot
.47078 .29727 Mdot
.29742 .51055 Mdot
.717 .51853 Mdot
.62677 .30577 Mdot
.61567 .27044 Mdot
.52925 .68397 Mdot
.66332 .34629 Mdot
.41765 .69652 Mdot
.48597 .32825 Mdot
.60369 .27348 Mdot
.7256 .50292 Mdot
.37687 .2979 Mdot
.36418 .49227 Mdot
.26337 .57022 Mdot
.66357 .34563 Mdot
.67972 .39296 Mdot
.31208 .65343 Mdot
.68714 .6317 Mdot
.51617 .34733 Mdot
.73043 .4828 Mdot
.53097 .6912 Mdot
.37494 .45532 Mdot
.35782 .40838 Mdot
.70461 .55897 Mdot
.44325 .69804 Mdot
.65652 .34892 Mdot
.52432 .28821 Mdot
.51608 .70454 Mdot
.37795 .29865 Mdot
.34013 .4996 Mdot
.51962 .69308 Mdot
.60903 .28915 Mdot
.50682 .70733 Mdot
.48449 .30821 Mdot
.73754 .50601 Mdot
.66421 .38139 Mdot
.71019 .53993 Mdot
.48416 .68735 Mdot
.37135 .31431 Mdot
.2945 .54633 Mdot
.41796 .71514 Mdot
.5678 .69367 Mdot
.43283 .70078 Mdot
.44192 .32896 Mdot
.43646 .70365 Mdot
.53178 .68845 Mdot
.35924 .5211 Mdot
.35016 .48662 Mdot
.63402 .29367 Mdot
.36993 .49754 Mdot
.26752 .53128 Mdot
.35509 .68686 Mdot
.35412 .49468 Mdot
.3411 .51122 Mdot
.27776 .54456 Mdot
.61851 .66846 Mdot
.30384 .50978 Mdot
.60913 .6963 Mdot
.60184 .68504 Mdot
.62412 .2797 Mdot
.34184 .31653 Mdot
.37586 .33751 Mdot
.30692 .50782 Mdot
.26693 .56922 Mdot
.55047 .71417 Mdot
.64916 .68835 Mdot
.72754 .49165 Mdot
.34872 .65523 Mdot
.5129 .34967 Mdot
.34068 .4912 Mdot
.65942 .3887 Mdot
.66208 .40374 Mdot
.37079 .48238 Mdot
.30099 .31428 Mdot
.2553 .55324 Mdot
.32578 .67046 Mdot
.34571 .52752 Mdot
.26936 .54988 Mdot
.64475 .39122 Mdot
.28383 .55632 Mdot
.4078 .69566 Mdot
.53656 .68518 Mdot
.3843 .29836 Mdot
.48206 .30569 Mdot
.33935 .65706 Mdot
.36598 .46284 Mdot
.55816 .69532 Mdot
.41942 .6937 Mdot
.6682 .38789 Mdot
.65154 .66456 Mdot
.3303 .67271 Mdot
.73607 .50072 Mdot
.23246 .58842 Mdot
.67994 .62828 Mdot
.73704 .48988 Mdot
.37153 .30021 Mdot
.64709 .36818 Mdot
.32572 .52721 Mdot
.6895 .37874 Mdot
.27621 .54256 Mdot
.32117 .64084 Mdot
.38219 .33168 Mdot
.53508 .71265 Mdot
.7187 .47799 Mdot
.61893 .6755 Mdot
.58379 .67385 Mdot
.29681 .61646 Mdot
.638 .39952 Mdot
.63971 .37569 Mdot
.43295 .34449 Mdot
.56075 .68001 Mdot
.26442 .53385 Mdot
.49632 .72115 Mdot
.62871 .67187 Mdot
.54756 .70103 Mdot
.24014 .59341 Mdot
.23237 .55974 Mdot
.28262 .54183 Mdot
.52231 .70085 Mdot
.64666 .36505 Mdot
.37932 .33449 Mdot
.26862 .53838 Mdot
.4876 .32788 Mdot
.52838 .68391 Mdot
.65858 .35097 Mdot
.29121 .5504 Mdot
.68327 .37556 Mdot
.51308 .69781 Mdot
.65529 .40386 Mdot
.74358 .47877 Mdot
.6587 .3955 Mdot
.38103 .49035 Mdot
.35162 .52554 Mdot
.52808 .68821 Mdot
.65342 .66076 Mdot
.43937 .69136 Mdot
.35425 .49174 Mdot
.51987 .68267 Mdot
.6983 .37118 Mdot
.64552 .69539 Mdot
.42023 .68926 Mdot
.272 .5298 Mdot
.36909 .29292 Mdot
.33807 .63794 Mdot
.25504 .60601 Mdot
.3493 .65044 Mdot
.37261 .3112 Mdot
.46281 .68809 Mdot
.30835 .53087 Mdot
.25664 .56548 Mdot
.61312 .29109 Mdot
.35101 .48965 Mdot
.48273 .33313 Mdot
.41607 .68584 Mdot
.22892 .57382 Mdot
.43884 .69335 Mdot
.52013 .71195 Mdot
.51229 .6956 Mdot
.69336 .39015 Mdot
.51752 .70139 Mdot
.48682 .33063 Mdot
.69902 .58289 Mdot
.58358 .67571 Mdot
.50522 .29648 Mdot
.50842 .32023 Mdot
.48422 .33839 Mdot
.46455 .30738 Mdot
.50921 .35047 Mdot
.63595 .3081 Mdot
.50784 .31674 Mdot
.5552 .67864 Mdot
.68961 .3387 Mdot
.37052 .2818 Mdot
.70025 .58203 Mdot
.47328 .33173 Mdot
.34965 .49032 Mdot
.42432 .69169 Mdot
.64021 .64276 Mdot
.72494 .51722 Mdot
.44492 .32728 Mdot
.26607 .5343 Mdot
.53711 .68143 Mdot
.34947 .51822 Mdot
.35293 .30046 Mdot
.6445 .65732 Mdot
.67746 .38402 Mdot
.38191 .33074 Mdot
.45707 .31919 Mdot
.38102 .31802 Mdot
.67844 .35524 Mdot
.67037 .58305 Mdot
.33706 .50129 Mdot
.42981 .32925 Mdot
.34365 .32163 Mdot
.34443 .49419 Mdot
.55533 .67973 Mdot
.44697 .32764 Mdot
.28653 .52287 Mdot
.4231 .69933 Mdot
.62549 .68561 Mdot
.70863 .59943 Mdot
.3238 .52619 Mdot
.4524 .70881 Mdot
.53466 .68403 Mdot
.4674 .29978 Mdot
.68099 .3838 Mdot
.35435 .53028 Mdot
.68443 .58386 Mdot
.67816 .57508 Mdot
.6104 .29149 Mdot
.64925 .64637 Mdot
.68766 .34628 Mdot
.38291 .48287 Mdot
.46798 .32987 Mdot
.35199 .53037 Mdot
.69675 .39371 Mdot
.69224 .61644 Mdot
.6297 .6919 Mdot
.62194 .27613 Mdot
.25494 .52296 Mdot
.7097 .56838 Mdot
.62381 .28871 Mdot
.53441 .6858 Mdot
.64112 .6517 Mdot
.64238 .67639 Mdot
.39394 .32225 Mdot
.67916 .3767 Mdot
.61855 .66049 Mdot
.61192 .68137 Mdot
.41937 .69094 Mdot
.36987 .48229 Mdot
.53228 .69397 Mdot
.61801 .3001 Mdot
.37572 .29623 Mdot
.61504 .28551 Mdot
.44597 .3543 Mdot
.7241 .48182 Mdot
.33091 .68083 Mdot
.35186 .66931 Mdot
.31012 .34283 Mdot
.29654 .53805 Mdot
.33861 .52994 Mdot
.53927 .71737 Mdot
.4134 .30629 Mdot
.40003 .30483 Mdot
.55375 .67919 Mdot
.62504 .69283 Mdot
.38199 .32573 Mdot
.35753 .4763 Mdot
.26335 .57543 Mdot
.25162 .52573 Mdot
.5202 .71863 Mdot
.55384 .67273 Mdot
.68401 .57526 Mdot
.52616 .68472 Mdot
.68282 .33104 Mdot
.64241 .35547 Mdot
.64893 .38666 Mdot
.72228 .49044 Mdot
.3209 .52788 Mdot
.6389 .37964 Mdot
.41759 .70933 Mdot
.6728 .32595 Mdot
.44209 .70967 Mdot
.60144 .27983 Mdot
.35062 .49332 Mdot
.71744 .54744 Mdot
.70638 .52203 Mdot
.42467 .68731 Mdot
.35917 .47321 Mdot
.37927 .30414 Mdot
.54003 .71756 Mdot
.69268 .54565 Mdot
.54213 .71998 Mdot
.36144 .51287 Mdot
.53429 .70335 Mdot
.72281 .47538 Mdot
.67538 .61959 Mdot
.40822 .69142 Mdot
.41848 .70601 Mdot
.55378 .71605 Mdot
.51548 .68237 Mdot
.6822 .38217 Mdot
.55068 .69789 Mdot
.60936 .67438 Mdot
.43878 .70709 Mdot
.65454 .34795 Mdot
.32363 .625 Mdot
.53139 .71446 Mdot
.39731 .32522 Mdot
.64079 .65545 Mdot
.38522 .32341 Mdot
.62689 .65265 Mdot
.63545 .295 Mdot
.33584 .51458 Mdot
.62311 .2799 Mdot
.3504 .31263 Mdot
.64098 .39488 Mdot
.6887 .54663 Mdot
.47113 .32613 Mdot
.68271 .56072 Mdot
.32046 .66177 Mdot
.53726 .7213 Mdot
.70346 .57316 Mdot
.30547 .61911 Mdot
.35458 .52665 Mdot
.62823 .65159 Mdot
.66971 .38591 Mdot
.61059 .27993 Mdot
.32716 .65917 Mdot
.65379 .67661 Mdot
.69393 .38356 Mdot
.46141 .71186 Mdot
.65407 .32201 Mdot
.42149 .68563 Mdot
.69604 .50578 Mdot
.5083 .70304 Mdot
.6089 .2806 Mdot
.32287 .66871 Mdot
.60751 .68627 Mdot
.64153 .3641 Mdot
.67185 .58089 Mdot
.68549 .58304 Mdot
.37197 .51542 Mdot
.71177 .54239 Mdot
.66194 .38926 Mdot
.6898 .62943 Mdot
.61868 .66144 Mdot
.69264 .61813 Mdot
.37566 .31326 Mdot
.65183 .36196 Mdot
.48707 .32236 Mdot
.4806 .69035 Mdot
.69061 .36159 Mdot
.30285 .32526 Mdot
.58927 .26641 Mdot
.70014 .36038 Mdot
.64623 .65594 Mdot
.65905 .66844 Mdot
.42878 .72117 Mdot
.33005 .66041 Mdot
.66859 .37969 Mdot
.68772 .33558 Mdot
.2791 .51318 Mdot
.46713 .32429 Mdot
.60945 .29473 Mdot
.29106 .54167 Mdot
.42917 .70046 Mdot
.73006 .48708 Mdot
.30703 .52574 Mdot
.61578 .69559 Mdot
.26739 .55364 Mdot
.68801 .55128 Mdot
.67718 .41408 Mdot
.36244 .513 Mdot
.37396 .29957 Mdot
.67661 .58857 Mdot
.67598 .58397 Mdot
.63405 .38883 Mdot
.64981 .64623 Mdot
.56147 .70323 Mdot
.68089 .37806 Mdot
.43236 .70774 Mdot
.47509 .32148 Mdot
.28506 .54136 Mdot
.54156 .70796 Mdot
.53591 .7208 Mdot
.6512 .36215 Mdot
.32819 .50349 Mdot
.69887 .55405 Mdot
.70117 .36621 Mdot
.44642 .70479 Mdot
.64765 .38268 Mdot
.52708 .31111 Mdot
.63917 .35597 Mdot
.55107 .67528 Mdot
.46711 .33988 Mdot
.53613 .70494 Mdot
.50862 .30721 Mdot
.5122 .27833 Mdot
.36987 .2999 Mdot
.64835 .39482 Mdot
.64914 .63143 Mdot
.61829 .27524 Mdot
.34836 .49793 Mdot
.29059 .53316 Mdot
.68196 .35293 Mdot
.36842 .31538 Mdot
.36894 .2724 Mdot
.39037 .28982 Mdot
.65246 .65678 Mdot
.40873 .68832 Mdot
.59844 .26366 Mdot
.62224 .26972 Mdot
.72893 .47224 Mdot
.55049 .68309 Mdot
.51085 .31736 Mdot
.68953 .54449 Mdot
.67482 .5831 Mdot
.36749 .32238 Mdot
.61668 .26711 Mdot
.54269 .69934 Mdot
.70617 .53813 Mdot
.6077 .68822 Mdot
.25423 .56455 Mdot
.4614 .30668 Mdot
.42915 .33925 Mdot
.50892 .30358 Mdot
.33712 .66725 Mdot
.71079 .5459 Mdot
.34842 .50939 Mdot
.34595 .30842 Mdot
.72456 .48871 Mdot
.37517 .29028 Mdot
.44553 .70119 Mdot
.67572 .41315 Mdot
.63925 .70991 Mdot
.37561 .50934 Mdot
.32798 .51461 Mdot
.72131 .48335 Mdot
.36817 .46765 Mdot
.54087 .68778 Mdot
.6149 .66931 Mdot
.66628 .35631 Mdot
.24615 .59973 Mdot
.25848 .55172 Mdot
.2683 .53693 Mdot
.68571 .36232 Mdot
.47273 .30774 Mdot
.63265 .31132 Mdot
.2718 .53344 Mdot
.6857 .56842 Mdot
.44031 .69529 Mdot
.70604 .57733 Mdot
.38161 .48105 Mdot
.33526 .5115 Mdot
.41933 .70866 Mdot
.43549 .6985 Mdot
.68278 .56102 Mdot
.46695 .30845 Mdot
.45365 .32743 Mdot
.52459 .71683 Mdot
.35564 .48951 Mdot
.27029 .51436 Mdot
.33723 .53141 Mdot
.37847 .304 Mdot
.2556 .61026 Mdot
.32337 .67523 Mdot
.33097 .64535 Mdot
.30573 .50419 Mdot
.33913 .5224 Mdot
.72282 .47824 Mdot
.65711 .67513 Mdot
.70095 .55597 Mdot
.73192 .51563 Mdot
.69087 .3881 Mdot
.37738 .29047 Mdot
.37055 .50325 Mdot
.35983 .32884 Mdot
.23903 .54651 Mdot
.35162 .34282 Mdot
.34155 .6628 Mdot
.3134 .65045 Mdot
.39975 .31906 Mdot
.33684 .53307 Mdot
.673 .35119 Mdot
.63414 .37559 Mdot
.42776 .71483 Mdot
.38132 .48517 Mdot
.73391 .4723 Mdot
.68885 .5901 Mdot
.63026 .30489 Mdot
.63899 .31596 Mdot
.35302 .3001 Mdot
.52552 .29282 Mdot
.43768 .70338 Mdot
.37332 .50768 Mdot
.4628 .31492 Mdot
.68272 .3469 Mdot
.50967 .31067 Mdot
.63181 .29901 Mdot
.69564 .5443 Mdot
.69827 .57513 Mdot
.36583 .48585 Mdot
.30385 .29941 Mdot
.62571 .67187 Mdot
.65868 .66814 Mdot
.6886 .59197 Mdot
.6476 .39789 Mdot
.49316 .3074 Mdot
.51173 .72704 Mdot
.54379 .6835 Mdot
.34567 .3219 Mdot
.35587 .52844 Mdot
.63965 .36415 Mdot
.51155 .68693 Mdot
.34885 .30973 Mdot
.35397 .65628 Mdot
.69698 .34814 Mdot
.35447 .50996 Mdot
.45507 .71085 Mdot
.63285 .69478 Mdot
.33258 .65808 Mdot
.53283 .71432 Mdot
.68105 .57998 Mdot
.7036 .5408 Mdot
.33293 .51315 Mdot
.62429 .71093 Mdot
.57425 .6803 Mdot
.70788 .54124 Mdot
.39605 .32137 Mdot
.48104 .32431 Mdot
.37263 .29093 Mdot
.6634 .35267 Mdot
.37147 .29942 Mdot
.69145 .36762 Mdot
.62195 .28882 Mdot
.53432 .69688 Mdot
.36459 .31239 Mdot
.34588 .68598 Mdot
.48857 .32576 Mdot
.34206 .33869 Mdot
.34114 .65357 Mdot
.44866 .69982 Mdot
.66004 .37538 Mdot
.35617 .32758 Mdot
.32475 .53597 Mdot
.71054 .5887 Mdot
.73954 .50347 Mdot
.68921 .54675 Mdot
.48663 .30747 Mdot
.64958 .36857 Mdot
.54441 .70468 Mdot
.29756 .51008 Mdot
.52386 .67584 Mdot
.28157 .52358 Mdot
.36289 .49574 Mdot
.56827 .67761 Mdot
.54448 .70531 Mdot
.33016 .51759 Mdot
.29149 .54316 Mdot
.48263 .32727 Mdot
.67834 .58263 Mdot
.64838 .65777 Mdot
.64695 .66381 Mdot
.67389 .3939 Mdot
.52414 .68792 Mdot
.4798 .3561 Mdot
.69311 .54285 Mdot
.46717 .29746 Mdot
.69213 .55632 Mdot
.34536 .2719 Mdot
.69769 .35906 Mdot
.63212 .63667 Mdot
.64398 .64391 Mdot
.4152 .69497 Mdot
.53387 .69437 Mdot
.37616 .31641 Mdot
.52004 .69034 Mdot
.52612 .69948 Mdot
.35435 .48919 Mdot
.46033 .31425 Mdot
.50528 .31696 Mdot
.33986 .6676 Mdot
.62678 .67123 Mdot
.33589 .51972 Mdot
.34327 .65003 Mdot
.33763 .50358 Mdot
.33377 .65985 Mdot
.62388 .65946 Mdot
.36816 .46242 Mdot
.52721 .69253 Mdot
.6007 .69516 Mdot
.44611 .35486 Mdot
.49338 .32407 Mdot
.51271 .31172 Mdot
.74886 .47969 Mdot
.28923 .52277 Mdot
.62395 .28428 Mdot
.43249 .70562 Mdot
.46288 .32559 Mdot
.36481 .68591 Mdot
.35505 .33399 Mdot
.27464 .5426 Mdot
.46587 .31666 Mdot
.67333 .38431 Mdot
.41545 .69626 Mdot
.28377 .53322 Mdot
.4797 .30491 Mdot
.53963 .69557 Mdot
.62978 .68237 Mdot
.55435 .68524 Mdot
.37872 .32284 Mdot
.69347 .54956 Mdot
.43108 .7034 Mdot
.6673 .35369 Mdot
.62596 .28389 Mdot
.53731 .70478 Mdot
.67121 .40807 Mdot
.69276 .58192 Mdot
.2822 .53104 Mdot
.67958 .5735 Mdot
.36171 .33461 Mdot
.64337 .65845 Mdot
.42087 .70149 Mdot
.40559 .71116 Mdot
.51239 .69522 Mdot
.47899 .32989 Mdot
.38888 .29201 Mdot
.66703 .41162 Mdot
.63525 .68865 Mdot
.69512 .54684 Mdot
.6743 .39805 Mdot
.41566 .70291 Mdot
.3576 .34605 Mdot
.30885 .52564 Mdot
.37212 .48714 Mdot
.47116 .68776 Mdot
.36703 .47886 Mdot
.627 .28125 Mdot
.53426 .71869 Mdot
.432 .68963 Mdot
.31655 .64761 Mdot
.31555 .28517 Mdot
.3688 .28497 Mdot
.34461 .52328 Mdot
.36183 .68418 Mdot
.33921 .49311 Mdot
.65516 .63041 Mdot
.32899 .65702 Mdot
.69685 .38717 Mdot
.42963 .34057 Mdot
.73275 .51523 Mdot
.46877 .32019 Mdot
.67387 .41217 Mdot
.28802 .5448 Mdot
.31173 .52478 Mdot
.64342 .69973 Mdot
.44681 .69992 Mdot
.70296 .5628 Mdot
.36248 .46749 Mdot
.66931 .38841 Mdot
.60391 .26963 Mdot
.38561 .48468 Mdot
.54508 .68757 Mdot
.71598 .565 Mdot
.46093 .31865 Mdot
.51286 .30924 Mdot
.34906 .3139 Mdot
.68975 .40098 Mdot
.4998 .33886 Mdot
.69755 .55487 Mdot
.32722 .53678 Mdot
.32446 .67628 Mdot
.71511 .58954 Mdot
.50779 .69534 Mdot
.73996 .48061 Mdot
.34091 .27281 Mdot
.35162 .50255 Mdot
.62334 .66775 Mdot
.51599 .70388 Mdot
.34357 .31998 Mdot
.63157 .29315 Mdot
.61578 .29512 Mdot
.3022 .31163 Mdot
.45593 .33493 Mdot
.68385 .34788 Mdot
.49942 .33762 Mdot
.4297 .70897 Mdot
.34042 .6577 Mdot
.74279 .49839 Mdot
.35294 .4945 Mdot
.59363 .69765 Mdot
.52262 .71476 Mdot
.34721 .52751 Mdot
.38887 .29854 Mdot
.53807 .7291 Mdot
.4095 .70869 Mdot
.34899 .53819 Mdot
.64664 .36429 Mdot
.35505 .49689 Mdot
.48226 .35667 Mdot
.47454 .29581 Mdot
.35666 .48481 Mdot
.68077 .38188 Mdot
.46863 .34002 Mdot
.39243 .29906 Mdot
.51739 .71596 Mdot
.47067 .31954 Mdot
.44717 .70422 Mdot
.28926 .53801 Mdot
.39713 .31973 Mdot
.42303 .70861 Mdot
.54974 .67163 Mdot
.51608 .3062 Mdot
.65102 .39041 Mdot
.62148 .69105 Mdot
.34512 .50347 Mdot
.47979 .32591 Mdot
.36384 .51972 Mdot
.58909 .67208 Mdot
.37117 .49148 Mdot
.6748 .61595 Mdot
.6382 .69415 Mdot
.69411 .56563 Mdot
.41949 .69531 Mdot
.35647 .50775 Mdot
.49571 .3384 Mdot
.49762 .30859 Mdot
.26507 .53518 Mdot
.53616 .7062 Mdot
.52183 .70324 Mdot
.55376 .69104 Mdot
.6683 .39593 Mdot
.24704 .53416 Mdot
.69029 .57204 Mdot
.4664 .31049 Mdot
.71216 .54391 Mdot
.36055 .67905 Mdot
.38183 .32063 Mdot
.70067 .60315 Mdot
.27903 .52879 Mdot
.6538 .67305 Mdot
.27195 .57285 Mdot
.66369 .65224 Mdot
.74773 .47318 Mdot
.73915 .47866 Mdot
.63389 .66881 Mdot
.34182 .52572 Mdot
.33548 .66807 Mdot
.31975 .67269 Mdot
.70919 .54469 Mdot
.44934 .32052 Mdot
.54285 .32852 Mdot
.64547 .35525 Mdot
.35433 .34542 Mdot
.71754 .4929 Mdot
.71015 .51115 Mdot
.42023 .68923 Mdot
.62331 .68697 Mdot
.70191 .54754 Mdot
.67483 .5696 Mdot
.66135 .38553 Mdot
.41766 .6922 Mdot
.35807 .51068 Mdot
.4882 .33096 Mdot
.73377 .49985 Mdot
.26273 .54246 Mdot
.44164 .69199 Mdot
.63326 .30633 Mdot
.55266 .70201 Mdot
.7103 .59944 Mdot
.36043 .67348 Mdot
.56868 .69273 Mdot
.64632 .32001 Mdot
.61884 .66073 Mdot
.3386 .5183 Mdot
.48955 .3124 Mdot
.66701 .40808 Mdot
.29418 .528 Mdot
.62103 .27459 Mdot
.70592 .55843 Mdot
.71613 .58145 Mdot
.35453 .67551 Mdot
.67109 .32598 Mdot
.33177 .51907 Mdot
.41704 .71605 Mdot
.36219 .3025 Mdot
.70696 .54747 Mdot
.62451 .70209 Mdot
.36438 .52171 Mdot
.68131 .39019 Mdot
.64861 .34956 Mdot
.52931 .71112 Mdot
.55204 .68438 Mdot
.64497 .63186 Mdot
.48914 .32085 Mdot
.68025 .40144 Mdot
.48126 .32591 Mdot
.34079 .53962 Mdot
.70721 .53911 Mdot
.39353 .29978 Mdot
.65683 .4048 Mdot
.71897 .4998 Mdot
.44894 .70031 Mdot
.65406 .65089 Mdot
.47776 .68892 Mdot
.41944 .71227 Mdot
.68704 .40271 Mdot
.38793 .31326 Mdot
.3312 .65199 Mdot
.40524 .69546 Mdot
.38971 .32163 Mdot
.66652 .39192 Mdot
.62883 .67832 Mdot
.51524 .70698 Mdot
.65287 .68263 Mdot
.3354 .68187 Mdot
.48804 .71254 Mdot
.27146 .55859 Mdot
.35369 .48482 Mdot
.622 .65208 Mdot
.30294 .51332 Mdot
.68961 .54676 Mdot
.6452 .68531 Mdot
.33327 .65901 Mdot
.43063 .68473 Mdot
.26664 .55661 Mdot
.31954 .51495 Mdot
.43885 .69904 Mdot
.28929 .52268 Mdot
.56197 .67499 Mdot
.53519 .7208 Mdot
.33067 .64708 Mdot
.70512 .53199 Mdot
.38133 .31267 Mdot
.6086 .6742 Mdot
.35793 .49694 Mdot
.56335 .67414 Mdot
.33659 .64966 Mdot
.67481 .6155 Mdot
.44119 .70113 Mdot
.67811 .41372 Mdot
.30121 .53575 Mdot
.6432 .35082 Mdot
.40446 .70794 Mdot
.56469 .67356 Mdot
.74119 .49575 Mdot
.40849 .70823 Mdot
.6986 .3457 Mdot
.36189 .46712 Mdot
.49346 .31265 Mdot
.36952 .29756 Mdot
.47755 .34097 Mdot
.68228 .55985 Mdot
.29148 .52538 Mdot
.29951 .53377 Mdot
.37617 .47653 Mdot
.34164 .53961 Mdot
.49152 .32497 Mdot
.39188 .33016 Mdot
.58774 .67556 Mdot
.27983 .53872 Mdot
.63747 .37909 Mdot
.61626 .68028 Mdot
.27964 .54964 Mdot
.3173 .67342 Mdot
.44937 .71446 Mdot
.62843 .67038 Mdot
.65287 .64604 Mdot
.51435 .34901 Mdot
.36875 .30726 Mdot
.33659 .50621 Mdot
.40592 .31771 Mdot
.42848 .70402 Mdot
.68696 .55885 Mdot
.37666 .47452 Mdot
.69759 .36003 Mdot
.32328 .65787 Mdot
.66583 .39303 Mdot
.32728 .51207 Mdot
.64481 .65376 Mdot
.70361 .54236 Mdot
.61005 .28804 Mdot
.60957 .29274 Mdot
.25754 .56066 Mdot
.60841 .26384 Mdot
.37183 .32563 Mdot
.37263 .32091 Mdot
.70287 .54512 Mdot
.34068 .52866 Mdot
.3254 .65381 Mdot
.38782 .68744 Mdot
.29431 .52242 Mdot
.31955 .52824 Mdot
.72084 .50366 Mdot
.72114 .49209 Mdot
.65537 .40288 Mdot
.32673 .52017 Mdot
.26482 .54487 Mdot
.63511 .6622 Mdot
.37346 .2876 Mdot
.68603 .39876 Mdot
.34966 .30717 Mdot
.6828 .36641 Mdot
.22946 .5737 Mdot
.45623 .31308 Mdot
.37616 .32187 Mdot
.71515 .48526 Mdot
.65265 .66992 Mdot
.48933 .32853 Mdot
.6617 .36868 Mdot
.67499 .40604 Mdot
.27971 .54818 Mdot
.50574 .69795 Mdot
.61613 .66672 Mdot
.38107 .32374 Mdot
.68599 .59185 Mdot
.41763 .70963 Mdot
.5099 .3042 Mdot
.33086 .27601 Mdot
.67995 .39739 Mdot
.65982 .63219 Mdot
.4797 .69321 Mdot
.3647 .50088 Mdot
.63061 .68154 Mdot
.36261 .50548 Mdot
.55013 .69768 Mdot
.60316 .68552 Mdot
.38406 .48209 Mdot
.56015 .68974 Mdot
.68996 .35065 Mdot
.59903 .27299 Mdot
.43221 .68754 Mdot
.72995 .46083 Mdot
.43128 .70634 Mdot
.62996 .31121 Mdot
.27229 .5718 Mdot
.293 .53381 Mdot
.35983 .49606 Mdot
.3771 .34962 Mdot
.31242 .50616 Mdot
.50226 .3032 Mdot
.49377 .3134 Mdot
.62549 .68068 Mdot
.48368 .34089 Mdot
.33655 .66559 Mdot
.36065 .31497 Mdot
.66519 .35674 Mdot
.26043 .56596 Mdot
.38626 .31961 Mdot
.51721 .7114 Mdot
.40836 .69713 Mdot
.61408 .65972 Mdot
.63567 .36599 Mdot
.47419 .30991 Mdot
.70499 .55915 Mdot
.34027 .63722 Mdot
.67609 .38882 Mdot
.72979 .49565 Mdot
.34831 .66852 Mdot
.67907 .41465 Mdot
.69903 .5359 Mdot
.59801 .27162 Mdot
.73349 .48773 Mdot
.69604 .58652 Mdot
.33011 .67501 Mdot
.35994 .31475 Mdot
.47716 .34208 Mdot
.40457 .32168 Mdot
.74026 .49193 Mdot
.62862 .31439 Mdot
.65188 .37406 Mdot
.31949 .64566 Mdot
.48904 .71304 Mdot
.4714 .33177 Mdot
.3234 .52516 Mdot
.72649 .48569 Mdot
.23807 .54493 Mdot
.47734 .34187 Mdot
.69569 .57583 Mdot
.40523 .70917 Mdot
.25137 .60725 Mdot
.48541 .31785 Mdot
.50256 .32303 Mdot
.35546 .32401 Mdot
.62347 .29771 Mdot
.62478 .65645 Mdot
.35146 .33288 Mdot
.36885 .47353 Mdot
.34944 .49465 Mdot
.68416 .55867 Mdot
.47083 .31837 Mdot
.68896 .57778 Mdot
.38351 .29359 Mdot
.38729 .33255 Mdot
.51736 .71491 Mdot
.55109 .68962 Mdot
.51384 .32877 Mdot
.30447 .50366 Mdot
.3253 .50154 Mdot
.6357 .7023 Mdot
.63723 .65162 Mdot
.35091 .47794 Mdot
.39831 .29783 Mdot
.35241 .32286 Mdot
.41225 .71384 Mdot
.33884 .64627 Mdot
.43538 .69534 Mdot
.35499 .66404 Mdot
.67683 .43167 Mdot
.41807 .69725 Mdot
.66984 .41161 Mdot
.35509 .66231 Mdot
.7146 .47276 Mdot
.43031 .71597 Mdot
.3681 .50162 Mdot
.67692 .36752 Mdot
.34295 .4948 Mdot
.65666 .35421 Mdot
.33803 .51285 Mdot
.69631 .39539 Mdot
.66742 .35388 Mdot
.55152 .31751 Mdot
.28901 .61671 Mdot
.50398 .30488 Mdot
.39977 .30839 Mdot
.43196 .33079 Mdot
.29016 .55062 Mdot
.6326 .67556 Mdot
.48893 .71728 Mdot
.36578 .49967 Mdot
.65861 .38411 Mdot
.70574 .56386 Mdot
.41397 .71875 Mdot
.37829 .4902 Mdot
.4284 .71236 Mdot
.65419 .65039 Mdot
.64855 .36296 Mdot
.36437 .2975 Mdot
.63774 .29912 Mdot
.62429 .30726 Mdot
.6968 .35486 Mdot
.37098 .52973 Mdot
.44498 .71572 Mdot
.48323 .35655 Mdot
.55442 .70618 Mdot
.37628 .27467 Mdot
.51795 .6992 Mdot
.47051 .3224 Mdot
.35184 .31342 Mdot
.26605 .61074 Mdot
.61387 .67653 Mdot
.68528 .36189 Mdot
.35356 .5096 Mdot
.4668 .30686 Mdot
.40377 .32247 Mdot
.61521 .69426 Mdot
.3979 .3194 Mdot
.66623 .36623 Mdot
.47961 .32181 Mdot
.24457 .53598 Mdot
.3738 .45676 Mdot
.32073 .63852 Mdot
.35619 .50541 Mdot
.38286 .32478 Mdot
.50578 .69645 Mdot
.42709 .71288 Mdot
.73447 .49356 Mdot
.33084 .66137 Mdot
.31975 .52563 Mdot
.66649 .32364 Mdot
.65143 .65209 Mdot
.37395 .3125 Mdot
.72752 .48513 Mdot
.3694 .3056 Mdot
.51126 .3086 Mdot
.54809 .69503 Mdot
.51189 .30776 Mdot
.44492 .69777 Mdot
.70299 .5508 Mdot
.61534 .66892 Mdot
.63531 .31163 Mdot
.45366 .3326 Mdot
.68049 .35086 Mdot
.26528 .61261 Mdot
.5306 .70809 Mdot
.72729 .51036 Mdot
.63725 .29617 Mdot
.6715 .60257 Mdot
.32883 .64051 Mdot
.68153 .58868 Mdot
.36551 .49859 Mdot
.64977 .68727 Mdot
.71114 .56313 Mdot
.61185 .29507 Mdot
.35978 .68459 Mdot
.50326 .29812 Mdot
.34478 .53127 Mdot
.69075 .62301 Mdot
.70691 .52494 Mdot
.53092 .68998 Mdot
.71651 .49294 Mdot
.31704 .52029 Mdot
.4862 .32551 Mdot
.36077 .48666 Mdot
.73882 .48426 Mdot
.71725 .50215 Mdot
.61457 .28178 Mdot
.34894 .5111 Mdot
.37598 .30357 Mdot
.67534 .41272 Mdot
.65223 .34806 Mdot
.65934 .40244 Mdot
.57219 .68563 Mdot
.45482 .32277 Mdot
.4909 .3194 Mdot
.26925 .57106 Mdot
.68635 .58137 Mdot
.50275 .30422 Mdot
.28592 .53822 Mdot
.28603 .5501 Mdot
.64887 .68653 Mdot
.67066 .37022 Mdot
.32515 .51656 Mdot
.42752 .68561 Mdot
.48643 .30472 Mdot
.68023 .37647 Mdot
.54033 .69713 Mdot
.64062 .31557 Mdot
.28649 .52914 Mdot
.42726 .69004 Mdot
.51007 .69859 Mdot
.5526 .66982 Mdot
.31122 .50504 Mdot
.36272 .50683 Mdot
.67792 .57446 Mdot
.5044 .65752 Mdot
.34147 .5938 Mdot
.44283 .50853 Mdot
.46606 .33249 Mdot
.59798 .56054 Mdot
.46269 .64326 Mdot
.39071 .6882 Mdot
.49909 .58581 Mdot
.37567 .68053 Mdot
.54729 .614 Mdot
.63454 .4307 Mdot
.47236 .5614 Mdot
.59656 .29072 Mdot
.67465 .49302 Mdot
.42941 .72765 Mdot
.33381 .3674 Mdot
.66256 .56828 Mdot
.50883 .6267 Mdot
.67909 .49552 Mdot
.60172 .44829 Mdot
.63162 .3317 Mdot
.63572 .39527 Mdot
.60688 .40585 Mdot
.32589 .5379 Mdot
.5403 .63922 Mdot
.36193 .61299 Mdot
.63951 .59918 Mdot
.68592 .44389 Mdot
.41598 .68329 Mdot
.40472 .37138 Mdot
.61628 .56962 Mdot
.4488 .39446 Mdot
.39499 .65754 Mdot
.63013 .45044 Mdot
.35944 .60824 Mdot
.39152 .41371 Mdot
.39622 .67393 Mdot
.55288 .58533 Mdot
.59997 .59212 Mdot
.41317 .63768 Mdot
.62523 .55345 Mdot
.68981 .38315 Mdot
.50495 .69384 Mdot
.67959 .51938 Mdot
.4551 .3798 Mdot
.64432 .54396 Mdot
.49823 .58679 Mdot
.50792 .33205 Mdot
.59945 .55307 Mdot
.24597 .54159 Mdot
.66554 .6456 Mdot
.65255 .47352 Mdot
.67676 .44498 Mdot
.42597 .6454 Mdot
.68408 .45781 Mdot
.27067 .60573 Mdot
.51336 .62849 Mdot
.4692 .64654 Mdot
.60457 .44469 Mdot
.57193 .35191 Mdot
.6452 .64835 Mdot
.35191 .39177 Mdot
.56033 .43011 Mdot
.41336 .50796 Mdot
.65877 .48982 Mdot
.42272 .66443 Mdot
.57589 .69743 Mdot
.65745 .68674 Mdot
.61778 .34831 Mdot
.47664 .36844 Mdot
.61398 .40449 Mdot
.56969 .43071 Mdot
.64774 .53317 Mdot
.31446 .59963 Mdot
.58519 .60977 Mdot
.59589 .36415 Mdot
.50383 .67099 Mdot
.36565 .3642 Mdot
.55273 .51445 Mdot
.42747 .35543 Mdot
.4465 .64981 Mdot
.6126 .45464 Mdot
.44089 .59051 Mdot
.61408 .52642 Mdot
.25021 .58304 Mdot
.44 .36411 Mdot
.54335 .63804 Mdot
.56791 .3781 Mdot
.65941 .57197 Mdot
.4739 .66306 Mdot
.67261 .45621 Mdot
.47156 .29395 Mdot
.4478 .43378 Mdot
.40901 .35576 Mdot
.50828 .57937 Mdot
.38615 .39409 Mdot
.63008 .44808 Mdot
.68955 .50103 Mdot
.66755 .34106 Mdot
.62147 .61848 Mdot
.471 .38653 Mdot
.59671 .69483 Mdot
.62029 .32139 Mdot
.487 .61044 Mdot
.60799 .63031 Mdot
.40607 .35837 Mdot
.61752 .3596 Mdot
.60301 .51597 Mdot
.5985 .41989 Mdot
.59795 .58711 Mdot
.5745 .61421 Mdot
.66226 .585 Mdot
.52635 .30539 Mdot
.57041 .65903 Mdot
.43635 .39303 Mdot
.62414 .3945 Mdot
.33929 .35709 Mdot
.28784 .51262 Mdot
.46448 .40525 Mdot
.45786 .67861 Mdot
.50548 .48662 Mdot
.65343 .59648 Mdot
.41849 .34934 Mdot
.41496 .68205 Mdot
.51373 .66389 Mdot
.60587 .4022 Mdot
.39423 .50135 Mdot
.66051 .61941 Mdot
.68296 .49377 Mdot
.63403 .34948 Mdot
.46015 .65756 Mdot
.47603 .35922 Mdot
.31261 .56338 Mdot
.41676 .45787 Mdot
.69259 .43819 Mdot
.41007 .49928 Mdot
.43852 .4605 Mdot
.57303 .29506 Mdot
.61317 .63539 Mdot
.43689 .43959 Mdot
.46704 .68303 Mdot
.59256 .35916 Mdot
.62772 .42319 Mdot
.52534 .65061 Mdot
.33147 .28911 Mdot
.40122 .38976 Mdot
.45621 .46871 Mdot
.6026 .53733 Mdot
.38357 .69405 Mdot
.37612 .59656 Mdot
.62504 .43913 Mdot
.51326 .41649 Mdot
.5507 .36742 Mdot
.68368 .48743 Mdot
.59788 .6985 Mdot
.49501 .39868 Mdot
.41707 .58549 Mdot
.5163 .67367 Mdot
.4984 .43629 Mdot
.64893 .61665 Mdot
.48243 .42624 Mdot
.40386 .36748 Mdot
.63027 .38309 Mdot
.60108 .37113 Mdot
.65201 .53298 Mdot
.6809 .44795 Mdot
.57985 .63327 Mdot
.58574 .63344 Mdot
.50876 .38113 Mdot
.66415 .5535 Mdot
.62237 .47275 Mdot
.66291 .67528 Mdot
.51516 .61478 Mdot
.39578 .63481 Mdot
.33882 .58466 Mdot
.44001 .55371 Mdot
.40184 .29894 Mdot
.39385 .42342 Mdot
.46136 .66003 Mdot
.33747 .27805 Mdot
.37711 .55097 Mdot
.3533 .6052 Mdot
.51161 .29927 Mdot
.3203 .5763 Mdot
.23944 .57674 Mdot
.57472 .53208 Mdot
.6081 .36889 Mdot
.45672 .48947 Mdot
.32661 .57028 Mdot
.64685 .59639 Mdot
.38932 .67507 Mdot
.41861 .35078 Mdot
.52858 .35179 Mdot
.49422 .6425 Mdot
.54868 .65278 Mdot
.71825 .45803 Mdot
.71114 .52466 Mdot
.58037 .29312 Mdot
.65267 .53201 Mdot
.5556 .71842 Mdot
.63165 .28554 Mdot
.60793 .48179 Mdot
.4319 .59977 Mdot
.35412 .62682 Mdot
.43123 .37044 Mdot
.58141 .54833 Mdot
.33785 .33605 Mdot
.45291 .62049 Mdot
.44086 .48402 Mdot
.39353 .38189 Mdot
.36437 .38095 Mdot
.36244 .38914 Mdot
.67562 .52815 Mdot
.38852 .4222 Mdot
.39555 .35842 Mdot
.23758 .55247 Mdot
.56559 .46793 Mdot
.39323 .69718 Mdot
.38975 .56694 Mdot
.60601 .32117 Mdot
.562 .41911 Mdot
.57232 .60782 Mdot
.42625 .64618 Mdot
.39721 .34621 Mdot
.23927 .57274 Mdot
.62527 .53505 Mdot
.43389 .39908 Mdot
.57439 .38771 Mdot
.45966 .40056 Mdot
.52657 .37412 Mdot
.52885 .58084 Mdot
.68209 .49549 Mdot
.30715 .29878 Mdot
.58029 .34631 Mdot
.63334 .58128 Mdot
.48459 .6742 Mdot
.61276 .3222 Mdot
.59523 .64377 Mdot
.60919 .60987 Mdot
.44455 .63828 Mdot
.39124 .5933 Mdot
.46836 .52375 Mdot
.5596 .58686 Mdot
.40519 .43388 Mdot
.54717 .399 Mdot
.63152 .38361 Mdot
.57212 .31526 Mdot
.46518 .50974 Mdot
.5597 .46297 Mdot
.33362 .55931 Mdot
.62414 .3453 Mdot
.54851 .55441 Mdot
.33544 .59506 Mdot
.45607 .48571 Mdot
.51104 .63633 Mdot
.6394 .62608 Mdot
.40582 .58929 Mdot
.28656 .51779 Mdot
.45335 .37614 Mdot
.58626 .28309 Mdot
.5224 .3713 Mdot
.5409 .64486 Mdot
.69721 .46838 Mdot
.66083 .51285 Mdot
.36217 .55143 Mdot
.33162 .61292 Mdot
.51517 .54835 Mdot
.35537 .64124 Mdot
.68518 .59982 Mdot
.57789 .69693 Mdot
.56781 .63518 Mdot
.31388 .53995 Mdot
.44614 .5657 Mdot
.55329 .62832 Mdot
.39359 .52912 Mdot
.46415 .67763 Mdot
.59177 .66892 Mdot
.58688 .34948 Mdot
.63317 .38842 Mdot
.32954 .30077 Mdot
.55532 .44006 Mdot
.34856 .30313 Mdot
.5542 .33683 Mdot
.59887 .52856 Mdot
.39783 .65354 Mdot
.70251 .45627 Mdot
.53613 .3803 Mdot
.6046 .29904 Mdot
.52944 .37216 Mdot
.62326 .41553 Mdot
.657 .49568 Mdot
.29989 .58366 Mdot
.62228 .58275 Mdot
.68243 .47865 Mdot
.27748 .58583 Mdot
.63839 .41653 Mdot
.61162 .54216 Mdot
.66752 .64533 Mdot
.26343 .52595 Mdot
.27077 .57478 Mdot
.38091 .41776 Mdot
.30392 .59292 Mdot
.43311 .51418 Mdot
.49825 .71692 Mdot
.37319 .42359 Mdot
.62979 .53592 Mdot
.39763 .69907 Mdot
.5434 .65473 Mdot
.66047 .61249 Mdot
.47905 .67548 Mdot
.62853 .31813 Mdot
.70165 .47785 Mdot
.5607 .62493 Mdot
.36867 .55288 Mdot
.40901 .3986 Mdot
.37322 .54152 Mdot
.56098 .65341 Mdot
.40543 .57029 Mdot
.63835 .62393 Mdot
.43278 .64602 Mdot
.56812 .49891 Mdot
.62172 .62312 Mdot
.46349 .61378 Mdot
.46565 .67332 Mdot
.46144 .71596 Mdot
.50028 .36952 Mdot
.38585 .44088 Mdot
.54483 .59249 Mdot
.35167 .48276 Mdot
.49284 .48674 Mdot
.495 .61123 Mdot
.32912 .54794 Mdot
.52661 .6025 Mdot
.3492 .39862 Mdot
.63945 .70377 Mdot
.58307 .58392 Mdot
.52492 .40972 Mdot
.34275 .54187 Mdot
.3941 .656 Mdot
.47592 .6613 Mdot
.68261 .49 Mdot
.38233 .43548 Mdot
.48272 .36623 Mdot
.54546 .49733 Mdot
.32757 .56629 Mdot
.46229 .45349 Mdot
.38655 .43232 Mdot
.52199 .30003 Mdot
.51996 .37705 Mdot
.60162 .56021 Mdot
.32768 .36744 Mdot
.65882 .42843 Mdot
.43791 .5462 Mdot
.43974 .59502 Mdot
.58846 .34528 Mdot
.45971 .59574 Mdot
.47476 .57928 Mdot
.46798 .48482 Mdot
.60433 .33564 Mdot
.57773 .56513 Mdot
.61925 .54565 Mdot
.59083 .66775 Mdot
.38787 .36972 Mdot
.56136 .60922 Mdot
.60828 .61461 Mdot
.53928 .40722 Mdot
.37495 .49092 Mdot
.43201 .55796 Mdot
.65866 .62547 Mdot
.50811 .45239 Mdot
.57483 .6225 Mdot
.59302 .28362 Mdot
.58751 .54317 Mdot
.45813 .4989 Mdot
.32858 .36325 Mdot
.31998 .3548 Mdot
.40746 .61312 Mdot
.40937 .34146 Mdot
.63066 .53323 Mdot
.57125 .65002 Mdot
.62473 .56004 Mdot
.31281 .61096 Mdot
.61537 .70431 Mdot
.50921 .35831 Mdot
.72365 .45574 Mdot
.64662 .59284 Mdot
.43877 .61978 Mdot
.45683 .3581 Mdot
.55714 .4727 Mdot
.61691 .48473 Mdot
.69361 .47317 Mdot
.62349 .36464 Mdot
.61082 .35873 Mdot
.4204 .5558 Mdot
.65189 .45339 Mdot
.57522 .3516 Mdot
.60035 .63785 Mdot
.60534 .30416 Mdot
.5699 .36174 Mdot
.43688 .67759 Mdot
.59511 .36415 Mdot
.57756 .66545 Mdot
.67091 .45352 Mdot
.49258 .60722 Mdot
.59503 .53535 Mdot
.51064 .43345 Mdot
.57359 .65566 Mdot
.67323 .52413 Mdot
.58042 .49466 Mdot
.25811 .60332 Mdot
.4784 .66797 Mdot
.51274 .66814 Mdot
.36824 .61669 Mdot
.59739 .51189 Mdot
.34242 .3881 Mdot
.74467 .47746 Mdot
.28507 .59951 Mdot
.66658 .64575 Mdot
.2366 .55785 Mdot
.62063 .47594 Mdot
.36099 .66607 Mdot
.49771 .37191 Mdot
.62399 .47602 Mdot
.35398 .38207 Mdot
.60238 .2665 Mdot
.37078 .41624 Mdot
.58482 .60209 Mdot
.55274 .33819 Mdot
.60167 .32093 Mdot
.58824 .30737 Mdot
.3517 .3722 Mdot
.5716 .34082 Mdot
.2681 .5873 Mdot
.58196 .50781 Mdot
.32038 .60282 Mdot
.38594 .52125 Mdot
.58287 .33656 Mdot
.51949 .72712 Mdot
.4173 .40649 Mdot
.47567 .62873 Mdot
.63327 .40384 Mdot
.37896 .42259 Mdot
.25242 .56257 Mdot
.49365 .45585 Mdot
.60771 .43337 Mdot
.68301 .34326 Mdot
.33365 .34646 Mdot
.53114 .65135 Mdot
.50292 .39466 Mdot
.51592 .66181 Mdot
.48247 .68239 Mdot
.64089 .43599 Mdot
.46748 .63731 Mdot
.31041 .2953 Mdot
.64568 .48504 Mdot
.52975 .34198 Mdot
.61317 .53364 Mdot
.67027 .62612 Mdot
.39665 .49532 Mdot
.50617 .37915 Mdot
.50611 .3976 Mdot
.34328 .37095 Mdot
.42247 .41012 Mdot
.42418 .41898 Mdot
.34515 .3941 Mdot
.49562 .63556 Mdot
.30025 .59909 Mdot
.39327 .37839 Mdot
.40664 .63535 Mdot
.47642 .36932 Mdot
.67158 .58861 Mdot
.60152 .45394 Mdot
.61536 .64762 Mdot
.31843 .58719 Mdot
.31344 .59319 Mdot
.54394 .37875 Mdot
.65783 .57622 Mdot
.45467 .52774 Mdot
.45765 .47144 Mdot
.67738 .45172 Mdot
.31052 .61363 Mdot
.53106 .59013 Mdot
.3321 .3528 Mdot
.28433 .51766 Mdot
.4954 .27848 Mdot
.60396 .37072 Mdot
.62077 .58316 Mdot
.59113 .52165 Mdot
.60835 .65386 Mdot
.42775 .52362 Mdot
.29827 .55898 Mdot
.3924 .3701 Mdot
.5905 .5202 Mdot
.34579 .60669 Mdot
.39931 .46786 Mdot
.605 .61915 Mdot
.6528 .5543 Mdot
.50757 .58843 Mdot
.58754 .44806 Mdot
.25932 .52246 Mdot
.61063 .40189 Mdot
.59438 .28282 Mdot
.34309 .38614 Mdot
.65625 .54554 Mdot
.31439 .58771 Mdot
.4455 .44978 Mdot
.57591 .40813 Mdot
.32796 .35135 Mdot
.62801 .34422 Mdot
.46129 .66076 Mdot
.63308 .41232 Mdot
.65483 .56821 Mdot
.61377 .47892 Mdot
.29608 .59109 Mdot
.35271 .3933 Mdot
.42962 .6096 Mdot
.56073 .51663 Mdot
.47568 .44689 Mdot
.35188 .64611 Mdot
.54476 .63598 Mdot
.39136 .59646 Mdot
.6761 .54818 Mdot
.34224 .37309 Mdot
.6105 .41973 Mdot
.39347 .44376 Mdot
.3365 .36939 Mdot
.51742 .72252 Mdot
.57014 .63805 Mdot
.68784 .50605 Mdot
.33146 .56923 Mdot
.68316 .34117 Mdot
.25778 .541 Mdot
.24876 .59377 Mdot
.46546 .60844 Mdot
.49887 .406 Mdot
.31413 .29304 Mdot
.47185 .67206 Mdot
.60259 .40369 Mdot
.47199 .67805 Mdot
.59448 .29631 Mdot
.52663 .5765 Mdot
.46205 .64669 Mdot
.42224 .52475 Mdot
.65317 .49889 Mdot
.50013 .63489 Mdot
.44712 .39533 Mdot
.39598 .56038 Mdot
.45265 .64158 Mdot
.45319 .6475 Mdot
.42491 .59478 Mdot
.63119 .60783 Mdot
.43095 .39062 Mdot
.6163 .37462 Mdot
.32969 .2794 Mdot
.4045 .63714 Mdot
.32015 .59473 Mdot
.59939 .53487 Mdot
.46712 .39734 Mdot
.61533 .26945 Mdot
.31127 .30958 Mdot
.37306 .64437 Mdot
.64293 .62404 Mdot
.52356 .54023 Mdot
.33196 .60848 Mdot
.31036 .6029 Mdot
.66683 .48728 Mdot
.60031 .51987 Mdot
.44728 .51066 Mdot
.49444 .70857 Mdot
.70169 .59527 Mdot
.40683 .30673 Mdot
.33395 .28001 Mdot
.64008 .56024 Mdot
.39513 .60945 Mdot
.59805 .35427 Mdot
.66847 .6314 Mdot
.34211 .28379 Mdot
.63514 .51024 Mdot
.31153 .53855 Mdot
.37366 .5826 Mdot
.30737 .30705 Mdot
.38871 .40726 Mdot
.50761 .71568 Mdot
.58326 .64112 Mdot
.65556 .46919 Mdot
.53273 .38314 Mdot
.56495 .5372 Mdot
.57907 .33417 Mdot
.45375 .42786 Mdot
.50812 .38771 Mdot
.45794 .63377 Mdot
.49972 .57162 Mdot
.61773 .3982 Mdot
.54872 .34258 Mdot
.62405 .38898 Mdot
.42634 .48776 Mdot
.56615 .43242 Mdot
.64053 .40586 Mdot
.49784 .44772 Mdot
.63952 .52296 Mdot
.39551 .69331 Mdot
.51274 .55332 Mdot
.60225 .33285 Mdot
.49667 .70219 Mdot
.59369 .43215 Mdot
.48666 .64619 Mdot
.645 .59021 Mdot
.43311 .39422 Mdot
.56741 .64345 Mdot
.61756 .38332 Mdot
.32203 .59781 Mdot
.56508 .39309 Mdot
.39045 .64965 Mdot
.41154 .49351 Mdot
.50941 .32687 Mdot
.41371 .45225 Mdot
.49672 .28804 Mdot
.25243 .57365 Mdot
.38809 .54015 Mdot
.43944 .36825 Mdot
.2502 .57831 Mdot
.51534 .43415 Mdot
.61609 .45607 Mdot
.66619 .66707 Mdot
.41526 .35298 Mdot
.30259 .56123 Mdot
.57801 .65886 Mdot
.60891 .35937 Mdot
.50267 .28232 Mdot
.3347 .36934 Mdot
.6564 .57272 Mdot
.5325 .43153 Mdot
.60027 .29348 Mdot
.5504 .49756 Mdot
.56381 .33156 Mdot
.61296 .53362 Mdot
.48969 .68733 Mdot
.40349 .3637 Mdot
.62203 .46458 Mdot
.5094 .43769 Mdot
.33518 .59832 Mdot
.43421 .64451 Mdot
.28366 .57486 Mdot
.33796 .57761 Mdot
.6905 .38277 Mdot
.35224 .59771 Mdot
.63201 .44528 Mdot
.41248 .61495 Mdot
.59663 .35676 Mdot
.56683 .31625 Mdot
.5686 .41759 Mdot
.68711 .46091 Mdot
.33264 .37361 Mdot
.42484 .41647 Mdot
.39593 .70641 Mdot
.468 .67661 Mdot
.31425 .2988 Mdot
.57347 .3407 Mdot
.38258 .43436 Mdot
.36814 .59702 Mdot
.45059 .4317 Mdot
.50907 .36184 Mdot
.50399 .47383 Mdot
.74575 .47854 Mdot
.40882 .62816 Mdot
.57321 .65858 Mdot
.49357 .65292 Mdot
.67249 .55559 Mdot
.59951 .33134 Mdot
.55991 .62457 Mdot
.49828 .58174 Mdot
.49923 .4291 Mdot
.56248 .30501 Mdot
.64239 .57227 Mdot
.67586 .60629 Mdot
.39987 .65721 Mdot
.34259 .38212 Mdot
.49218 .67686 Mdot
.49643 .60436 Mdot
.55202 .57481 Mdot
.36939 .53627 Mdot
.66338 .58409 Mdot
.55972 .64008 Mdot
.44941 .66515 Mdot
.36658 .39826 Mdot
.56472 .5925 Mdot
.54921 .3371 Mdot
.64953 .43022 Mdot
.53817 .5745 Mdot
.57296 .32273 Mdot
.65904 .68605 Mdot
.36484 .39156 Mdot
.33281 .56332 Mdot
.51561 .29026 Mdot
.26434 .52897 Mdot
.45757 .61818 Mdot
.52162 .37547 Mdot
.56304 .53618 Mdot
.66197 .6144 Mdot
.47806 .65456 Mdot
.62043 .33305 Mdot
.35085 .28921 Mdot
.70332 .45233 Mdot
.61105 .44281 Mdot
.35525 .60674 Mdot
.34976 .61219 Mdot
.61779 .60292 Mdot
.60332 .53963 Mdot
.46197 .58185 Mdot
.58484 .44633 Mdot
.39333 .62842 Mdot
.53387 .34746 Mdot
.32971 .34501 Mdot
.44112 .67239 Mdot
.61227 .3039 Mdot
.409 .65966 Mdot
.42641 .66069 Mdot
.59939 .40353 Mdot
.58184 .594 Mdot
.52717 .42077 Mdot
.52191 .40578 Mdot
.59906 .68304 Mdot
.31291 .32862 Mdot
.57444 .62369 Mdot
.58671 .43079 Mdot
.66403 .46749 Mdot
.50307 .61638 Mdot
.67779 .33197 Mdot
.66914 .50844 Mdot
.61955 .32634 Mdot
.5957 .36365 Mdot
.6719 .49617 Mdot
.6234 .53983 Mdot
.61693 .62568 Mdot
.39111 .38373 Mdot
.61701 .45314 Mdot
.45204 .39242 Mdot
.67516 .54259 Mdot
.415 .57829 Mdot
.24342 .57901 Mdot
.31184 .56249 Mdot
.40805 .53802 Mdot
.42102 .44235 Mdot
.36833 .40414 Mdot
.48966 .2934 Mdot
.33152 .28125 Mdot
.66699 .45775 Mdot
.32062 .34412 Mdot
.50163 .63127 Mdot
.51176 .32831 Mdot
.54101 .40136 Mdot
.56318 .59172 Mdot
.28098 .59904 Mdot
.46325 .47977 Mdot
.55946 .35056 Mdot
.60944 .61978 Mdot
.5071 .65249 Mdot
.493 .36572 Mdot
.26675 .52837 Mdot
.37246 .67661 Mdot
.65669 .59885 Mdot
.67744 .33842 Mdot
.48729 .65581 Mdot
.33681 .34612 Mdot
.6928 .59645 Mdot
.69874 .45291 Mdot
.62048 .5976 Mdot
.51067 .39205 Mdot
.69567 .49792 Mdot
.64564 .61004 Mdot
.59653 .26913 Mdot
.68857 .60648 Mdot
.40273 .44293 Mdot
.52514 .6674 Mdot
.25195 .57413 Mdot
.4242 .46255 Mdot
.52571 .30656 Mdot
.48182 .3755 Mdot
.3063 .60557 Mdot
.59912 .44473 Mdot
.35999 .40557 Mdot
.62373 .40457 Mdot
.65174 .42733 Mdot
.66132 .5968 Mdot
.43905 .63029 Mdot
.70477 .46761 Mdot
.66268 .47673 Mdot
.3825 .65579 Mdot
.36899 .41483 Mdot
.41284 .433 Mdot
.56187 .53042 Mdot
.45343 .46338 Mdot
.40891 .37429 Mdot
.58614 .32494 Mdot
.66246 .33572 Mdot
.64306 .34832 Mdot
.32286 .55379 Mdot
.56539 .41089 Mdot
.45665 .54018 Mdot
.37982 .41376 Mdot
.65799 .49801 Mdot
.62154 .46288 Mdot
.61263 .38661 Mdot
.45757 .61844 Mdot
.28482 .5133 Mdot
.34648 .3777 Mdot
.38951 .5724 Mdot
.62905 .32772 Mdot
.67449 .53181 Mdot
.66881 .45798 Mdot
.32606 .34772 Mdot
.45435 .58099 Mdot
.39209 .54456 Mdot
.32766 .37001 Mdot
.43246 .35678 Mdot
.61435 .62553 Mdot
.38898 .49982 Mdot
.59893 .26441 Mdot
.67676 .47805 Mdot
.53656 .38888 Mdot
.57822 .69768 Mdot
.67074 .43288 Mdot
.35144 .57984 Mdot
.37962 .43289 Mdot
.5893 .44079 Mdot
.51858 .72103 Mdot
.44334 .63663 Mdot
.62 .43991 Mdot
.64048 .41964 Mdot
.38657 .6252 Mdot
.64064 .70336 Mdot
.43024 .50466 Mdot
.50346 .69393 Mdot
.489 .37705 Mdot
.32524 .332 Mdot
.40992 .66774 Mdot
.37586 .39118 Mdot
.36938 .67676 Mdot
.48001 .61784 Mdot
.40189 .66042 Mdot
.30531 .58367 Mdot
.62416 .43948 Mdot
.32324 .35073 Mdot
.39912 .61705 Mdot
.32662 .33544 Mdot
.51066 .35333 Mdot
.50827 .71113 Mdot
.41977 .59301 Mdot
.32767 .58474 Mdot
.55179 .61051 Mdot
.58994 .60173 Mdot
.67871 .4525 Mdot
.56357 .32941 Mdot
.63613 .48745 Mdot
.29306 .51947 Mdot
.4458 .46575 Mdot
.49847 .38326 Mdot
.61391 .47743 Mdot
.49322 .38287 Mdot
.42959 .47845 Mdot
.25485 .53468 Mdot
.32259 .36364 Mdot
.5694 .6511 Mdot
.36186 .56522 Mdot
.35238 .27536 Mdot
.51114 .32906 Mdot
.36417 .67882 Mdot
.68577 .59848 Mdot
.32983 .54287 Mdot
.67315 .43712 Mdot
.47649 .37845 Mdot
.40882 .6575 Mdot
.31957 .59198 Mdot
.69355 .44962 Mdot
.25908 .52446 Mdot
.33264 .59568 Mdot
.67359 .59627 Mdot
.65666 .44716 Mdot
.64746 .32136 Mdot
.64415 .59569 Mdot
.52223 .6297 Mdot
.25602 .60519 Mdot
.52181 .31163 Mdot
.63338 .43898 Mdot
.61588 .60235 Mdot
.65728 .5959 Mdot
.61872 .38513 Mdot
.42361 .42161 Mdot
.65698 .55686 Mdot
.55767 .32479 Mdot
.29949 .59717 Mdot
.4458 .45646 Mdot
.57803 .61424 Mdot
.40039 .581 Mdot
.41255 .38195 Mdot
.33876 .30286 Mdot
.50588 .29539 Mdot
.40868 .55836 Mdot
.43712 .37139 Mdot
.69793 .58938 Mdot
.58259 .27906 Mdot
.58374 .58978 Mdot
.4837 .64514 Mdot
.41203 .54338 Mdot
.58649 .5271 Mdot
.40641 .68618 Mdot
.38952 .5 Mdot
.41235 .48835 Mdot
.6959 .45923 Mdot
.59456 .52462 Mdot
.51353 .62294 Mdot
.53129 .61245 Mdot
.40818 .41322 Mdot
.40414 .6907 Mdot
.32213 .51713 Mdot
.5002 .29116 Mdot
.24197 .58664 Mdot
.52554 .30273 Mdot
.54512 .41366 Mdot
.68711 .47887 Mdot
.63918 .44222 Mdot
.65837 .4288 Mdot
.44958 .41258 Mdot
.40791 .37037 Mdot
.39276 .69036 Mdot
.38482 .40914 Mdot
.48243 .47377 Mdot
.66932 .52809 Mdot
.38175 .58105 Mdot
.32965 .35587 Mdot
.43853 .46876 Mdot
.42725 .33448 Mdot
.52679 .34987 Mdot
.47062 .39331 Mdot
.66194 .51055 Mdot
.60086 .6622 Mdot
.669 .45465 Mdot
.36652 .54969 Mdot
.50652 .65669 Mdot
.32781 .30307 Mdot
.53996 .37478 Mdot
.58954 .46833 Mdot
.58204 .60889 Mdot
.38929 .60268 Mdot
.37805 .5257 Mdot
.69509 .36752 Mdot
.40549 .57043 Mdot
.42433 .44111 Mdot
.36692 .40534 Mdot
.39843 .71055 Mdot
.507 .5258 Mdot
.43429 .46027 Mdot
.34545 .37206 Mdot
.6974 .36593 Mdot
.34418 .60702 Mdot
.39339 .67199 Mdot
.69003 .48057 Mdot
.51162 .28519 Mdot
.34198 .38581 Mdot
.68336 .47647 Mdot
.58439 .44525 Mdot
.68852 .61294 Mdot
.43843 .45297 Mdot
.45278 .67052 Mdot
.63358 .57708 Mdot
.43903 .30788 Mdot
.46471 .4472 Mdot
.30633 .33156 Mdot
.51907 .38296 Mdot
.52371 .42222 Mdot
.38825 .66175 Mdot
.60927 .38049 Mdot
.35602 .63346 Mdot
.66116 .55393 Mdot
.49792 .37318 Mdot
.69759 .43971 Mdot
.59676 .27995 Mdot
.54129 .58312 Mdot
.66242 .6803 Mdot
.56221 .41081 Mdot
.5173 .65705 Mdot
.59025 .50514 Mdot
.63788 .70511 Mdot
.54101 .6547 Mdot
.39156 .41369 Mdot
.57065 .56389 Mdot
.60955 .66651 Mdot
.40443 .62281 Mdot
.52815 .54854 Mdot
.59002 .58428 Mdot
.49739 .60382 Mdot
.50527 .58153 Mdot
.63992 .58092 Mdot
.51897 .53159 Mdot
.57592 .65103 Mdot
.63117 .55744 Mdot
.41802 .46626 Mdot
.61429 .43098 Mdot
.46489 .40672 Mdot
.63198 .28481 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0?ooooooB_ooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A006ooooo`03o`000?oooooooooo0?ooooooB_ooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0?ooooooB_oo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06
ooooo`?o0000oooooom:ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<oooo
o`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom:ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001_ooool00ol0003oooooooooo`3ooooood[ooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`2nooooo`?o000000Coooooo`000?l0003o0000Q?ooool001cooooo00?o
0000ooooooooool0_?ooool;o`0008;ooooo000Looooo`03o`000?oooooooooo0;cooooo1ol00000
0ooooooo0000o`000002o`00087ooooo000Looooo`03o`000?oooooooooo06[ooooo1Ol00003oooo
o`Co0000B?ooool:o`00087ooooo000Looooo`03o`000?oooooooooo06Sooooo2Ol000000ooooooo
0000o`000006o`0004Cooooo3?l0001oooooo`007?ooool00ol0003oooooooooo`1Wooooo`Go0000
0oooool2o`000003ooooool0003o000000;ooooo1Ol0000Rooooo`;o000000?oooooo`000?l00000
0ol0000Dooooo`;o00000oooool=o`0007kooooo000Looooo`03o`000?oooooooooo06Oooooo1Ol0
0006ooooo`_o00008?ooool2o`000003ooooool0003o000000Co00004ooooolCo`0007gooooo000L
ooooo`03o`000?oooooooooo06?ooooo0_l00003ooooo`;o000000?oooooo`000?l000001_ooool;
o`0002;ooooo1_l0000@ooooo`;o00000oooool4o`0000;ooooo2ol0001mooooo`007?ooool00ol0
003oooooooooo`1Rooooo`?o00000oooool2o`000004ooooool0003o0000ooooo`;o00001?ooool<
o`0001kooooo0_l00002ooooo`;o00000oooool2o`0000gooooo0_l00005ooooo`;o00000_ooool;
o`0007gooooo000Looooo`03o`000?oooooooooo067ooooo0ol00004ooooo`;o00001?ooool2o`00
00Cooooo3Ol0000Mooooo`?o00000oooool2o`000003ooooool0003o000000cooooo0_l00007oooo
o`;o000000?oooooo`000?l000002_l0001looooo`007?ooool00ol0003oooooooooo`1Pooooo`Co
00003?ooool2o`0000;ooooo3Ol0000Dooooo`;o000000?oooooo`000?l000001?l000000ooooooo
0000o`000002o`000004ooooool0003o0000ooooo`?o00002oooool3o`000003ooooool0003o0000
00?ooooo3ol0001looooo`007?ooool00ol0003oooooooooo`1Pooooo`Co00003?ooool@o`000003
ooooool0003o0000017ooooo3ol00004ooooo`?o00003?ooool2o`000003ooooool0003o000000;o
oooo1?l000000ooooooo0000o`000009o`0007cooooo000Looooo`;o0000H?ooool5o`0000?ooooo
0_l00006oooooaCo00003ooooolBo`0000;ooooo1?l0000Cooooo`;o00000_ooool<o`0007cooooo
000Looooo`03o`000?oooooooooo05oooooo1Ol00003ooooo`;o000000Coooooo`000?l0003ooooo
5ol0000<oooooaCo00000_ooool4o`0000Wooooo0_l0000<ooooo`co0000O?ooool001cooooo00?o
0000ooooooooool0G_ooool4o`0000Gooooo0_l000001?oooooo0000o`000?ooool?o`000003oooo
ool0003o000000Ko00002_oooolGo`000003ooooool0003o000000[ooooo0_l00006ooooo`;o0000
1?ooool<o`0007cooooo000Looooo`03o`000?oooooooooo05kooooo1Ol0000:oooooaSo00001_oo
ool2o`000003ooooool0003o000001Ko000000?oooooo`000?l000002_ooool2o`0000Kooooo0_l0
0007ooooo`Wo0000O?ooool001cooooo00?o0000ooooooooool0G_ooool2o`000003ooooool0003o
000000Wooooo5Ol000000ooooooo0000o`000007oooooako00007?ooool8o`0007cooooo000Loooo
o`03o`000?oooooooooo05kooooo0_l0000;oooooaKo000000?oooooo`000?l000002?oooolCo`00
0003ooooool0003o000000Oo00002oooool4o`0000kooooo2?l0001kooooo`007?ooool00ol0003o
ooooooooo`1Nooooo`;o00002ooooolHo`0000Oooooo5Ol000000ooooooo0000o`000006o`0000Oo
oooo0_l00003ooooo`Co00004?ooool:o`0007Oooooo000Looooo`03o`000?oooooooooo05kooooo
0_l0000;oooooaSo00001ooooolKo`000003ooooool0003o000000Oooooo0_l00005ooooo`;o0000
2?ooool5o`000003ooooool0003o000000;o00001?ooool5o`000003ooooool0003o000007?ooooo
000Looooo`03o`000?oooooooooo05kooooo0ol0000:oooooaOo00001oooool4o`000003ooooool0
003o000001Go000000?oooooo`000?l000002Oooool2o`0000?ooooo0_l00003ooooo`;o00000ooo
ool8o`0000Oooooo1?l000000ooooooo0000o`000003o`00073ooooo000Looooo`03o`000?oooooo
oooo05oooooo0_l000000ooooooo0000o`000006oooooaOo00000_ooool2o`0000?ooooo7_l00007
ooooo`;o00000_ooool4o`0000Kooooo0_l00008ooooo`;o00000_ooool2o`0000Wooooo1_l0001_
ooooo`007?ooool00ol0003oooooooooo`1Oooooo`Go00000_ooool2o`0000;ooooo5Ol00004oooo
o`;o00000oooool3o`000005ooooool0003o0000o`000?ooool05_l00007ooooo`;o00001?ooool2
o`0000[ooooo0_l00008ooooo`;o00003?ooool5o`0006gooooo000Looooo`03o`000?oooooooooo
05oooooo0ol00004ooooo`;o00000_ooool2o`000003ooooool0003o000000oo00002Oooool4o`00
0005ooooool0003o0000o`000?ooool05Ol0000>ooooo`;o00000oooool2o`0000Gooooo0ol00004
ooooo`;o000000?oooooo`000?l000003Oooool6o`0006_ooooo000Looooo`03o`000?oooooooooo
05oooooo0ol00004ooooo`;o00000_oooolBo`0000_ooooo1?l000000ooooooo0000o`00000Eo`00
00Oooooo0_l00003ooooo`?o00001_ooool4o`0000Cooooo0ol00003ooooo`;o00002oooool2o`00
00?ooooo1ol0001Zooooo`007?ooool00ol0003oooooooooo`1Zooooo`oo00002?ooool2o`0000Go
oooo0_l00003oooooaCo00002?ooool3o`0000?ooooo0ol00004ooooo`?o000000?oooooo`000?l0
00001Oooool2o`00013ooooo1?l000000ooooooo0000o`000006o`0006Wooooo000Looooo`03o`00
0?oooooooooo067ooooo1Ol00005ooooo`go00000oooool2o`0000Cooooo0_l00005ooooo`?o0000
0_ooool6o`000003ooooool0003o000000Oo000000Coooooo`000?l0003o00001_ooool4o`0000?o
oooo0_l00006ooooo`?o00003oooool2o`0000Wooooo1?l00003ooooo`Oo0000J?ooool001cooooo
00?o0000ooooooooool0HOoooolCo`0000Oooooo1?l00009ooooo`?o00001?ooool4o`0000Cooooo
0_l0000;ooooo`;o000000?oooooo`000?l000000ol00002ooooo`;o00002Oooool4o`0000[ooooo
0ol00006oooooa7o0000J?ooool001cooooo0_l0001Vooooo`Oo00000oooool3o`0000Gooooo0_l0
0004ooooo`;o00001Oooool2o`0000;ooooo1Ol0000Eooooo`Co000000Coooooo`000?l0003ooooo
0_l00006ooooo`;o00001Oooool4o`0000Sooooo1?l000001?oooooo0000o`000?oooolDo`0006So
oooo000Looooo`03o`000?oooooooooo06Gooooo1Ol0000=ooooo`;o00002_ooool3o`0000?ooooo
1_l0000Aooooo`Go00000_ooool3o`0000Sooooo0_l00002ooooo`?o00000_ooool2o`0000Sooooo
0_l00003ooooo`;o000000?oooooo`000?l000004_l0001Xooooo`007?ooool00ol0003ooooooooo
o`1Tooooo`;o000000?oooooo`000?l000000ol0000Eooooo`Co00000_ooool4o`000003ooooool0
003o000000?o00000oooool2o`0000;ooooo0ol000000ooooooo0000o`000002ooooo`Co00001?oo
ool2o`0000cooooo0ol00005ooooo`;o00003?oooolEo`0006Sooooo000Looooo`03o`000?oooooo
oooo06Cooooo0_l000001?oooooo0000o`000?ooool2o`00017ooooo0_l000001?oooooo0000o`00
0?l00004ooooo`Co00000_ooool6o`000004ooooool0003o0000ooooo`Co000000?oooooo`000?l0
00001?ooool2o`0001Wooooo0ol00002ooooo`Go00001?ooool5o`000003ooooool0003o000000oo
0000Ioooool001cooooo00?o0000ooooooooool0Ioooool2o`0001Cooooo0_l000000ooooooo0000
o`00000?ooooo`;o00001?ooool2o`0000Wooooo0_l0000Aooooo`;o00001_ooool2o`0000?ooooo
1Ol00004oooooaSo0000I_ooool001cooooo00?o0000ooooooooool0IOooool4o`0000[ooooo0_l0
000:ooooo`;o00002_ooool2o`0000cooooo0_l000000ooooooo0000o`000004ooooo`;o00004Ooo
ool2o`0000Oooooo0_l00007ooooo`;o00000_oooolHo`0006Kooooo000Looooo`03o`000?oooooo
oooo06Gooooo1ol00007ooooo`;o00002_ooool2o`0000[ooooo0_l0000:ooooo`Co000000?ooooo
o`000?l000004Oooool2o`0000gooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo5ol0001W
ooooo`007?ooool00ol0003oooooooooo`1Wooooo`Oo000000?oooooo`000?l000002Oooool4o`00
0003ooooool0003o000000;o00001Oooool5o`0000[ooooo0_l00005ooooo`?o00001Oooool4o`00
00Gooooo0_l0000>ooooo`Go00001ooooolGo`0006Oooooo000Looooo`03o`000?oooooooooo06Oo
oooo0ol000001Ooooooo0000o`000?l0003ooooo00;o00002Oooool4o`0000;ooooo0ol00005oooo
o`Co00003Oooool2o`0000?ooooo0ol00005ooooo`Co00000_ooool2o`00017ooooo0ol00002oooo
o`;o00001?oooolHo`0006Oooooo000Looooo`03o`000?oooooooooo06Sooooo0_l000000ooooooo
0000o`000002o`0000gooooo0_l00003ooooo`;o00003Oooool2o`0000Gooooo1_l000000ooooooo
0000o`000005ooooo`Co00000oooool2o`0000Oooooo0_l0000=ooooo`;o00001?ooool=o`000003
ooooool0003o000000Oo0000J?ooool001cooooo00?o0000ooooooooool0KOooool2o`0000Cooooo
0_l00007ooooo`;o00004_ooool2o`0000Gooooo0_l00002ooooo`;o00001?ooool2o`0000;ooooo
0_l00003ooooo`;o000000?oooooo`000?l000001_ooool2o`0000_ooooo0_l00006ooooo`Co0000
00?oooooo`000?l000004Ol0001Wooooo`007?ooool00ol0003oooooooooo`1/ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0000Kooooo0ol00004ooooo`;o00003?ooool2o`0000[ooooo1?l0
00000ooooooo0000o`000002ooooo`;o00000_ooool3o`000003ooooool0003o000001?ooooo0_l0
00000ooooooo0000o`000002oooooaWo0000Ioooool001cooooo00?o0000ooooooooool0Joooool3
o`000003ooooool0003o000000[ooooo0ol00004ooooo`;o00004Oooool2o`0000Gooooo1?l00000
0ooooooo0000o`000002ooooo`;o00000_ooool2o`0000cooooo0_l0000:ooooo`Co00000_oooolI
o`0006Oooooo000Looooo`03o`000?oooooooooo06_ooooo0ol00004ooooo`;o00002oooool2o`00
00Oooooo0_l0000;ooooo`;o00002_ooool2o`0000Sooooo0_l0000:ooooo`;o00002_ooool6o`00
0003ooooool0003o000001Go0000J?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2
ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo06cooooo0_l00000
1?oooooo0000o`000?ooool3o`000003ooooool0003o000000;ooooo0_l00003ooooo`;o00001ooo
ool4o`0000?ooooo0_l00004ooooo`;o00002oooool2o`0000Oooooo0_l00007ooooo`;o00004Ooo
ool2o`000005ooooool0003o0000o`000?ooool04ol0001Xooooo`0000KoooooogMgMonHV9Sooooo
oiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06co
oooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000go
oooo0ol000000ooooooo0000o`000002o`0000Cooooo0_l00009ooooo`Co00004?ooool2o`00017o
oooo0_l00002oooooaKo0000J?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool0
2Oooool5o`0000Kooooo00?o0000ooooooooool0K_ooool2o`0000?ooooo0_l0000<ooooo`;o0000
1_ooool2o`0000;ooooo0ol00004ooooo`;o00001oooool2o`000004ooooool0003o0000o`0000_o
oooo0_l0000Eooooo`Co00000_oooolEo`0006Wooooo00000ooooooo0000ooooo`02ooooo`03o`00
0?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`0006kooooo0_l00003ooooo`;o
00003?ooool2o`0000Kooooo0_l00007ooooo`Co00001oooool2o`0000;ooooo0_l00009ooooo`Co
00004Oooool6o`0000Cooooo0_l000000ooooooo0000o`00000@o`0006Wooooo00000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003o
ooooooooo`1aooooo`Go00007?ooool3o`0000Wooooo0_l00006ooooo`;o00001?ooool2o`00017o
oooo1ol000001?oooooo0000o`000?oooolFo`0006Wooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00[ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`1`ooooo`Ko
00000oooool4o`0000Oooooo0_l0000=ooooo`;o00002Oooool2o`0000Kooooo0_l00003ooooo`;o
00002_ooool2o`0000Kooooo1?l000001?oooooo0000o`000?ooool2o`000003ooooool0003o0000
00;o00000_ooool<o`0006gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^
odA4A?l000001oooool00ol0003oooooooooo`1`ooooo`?o00001_ooool4o`0000Oooooo0ol00007
ooooo`;o00000oooool2o`0001;ooooo0_l00002ooooo`;o00001_ooool3o`000003ooooool0003o
0000017ooooo0_l00005ooooo`;o000000?oooooo`000?l000001ol0001/ooooo`0000Koooooonk^
k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0LOoo
ool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000004ooooo`;o00000_oo
ool2o`0000Oooooo0_l0000Gooooo`;o00001?ooool2o`0000Cooooo0ol0000Aooooo`;o000000?o
ooooo`000?l000000oooool2o`0000Cooooo2?l0001/ooooo`007?ooool00ol0003oooooooooo`1d
ooooo`?o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o00000oooool2o`0001_ooooo0_l0
0008ooooo`;o00001_ooool2o`00013ooooo0_l00003ooooo`;o000000Coooooo`000?l0003o0000
1?ooool6o`0006gooooo000Looooo`03o`000?oooooooooo07Gooooo0_l000000ooooooo0000o`00
000<ooooo`;o00006oooool2o`0000;ooooo0_l0000:ooooo`Co00002?ooool2o`0000;ooooo0_l0
0007ooooo`;o00000_ooool4o`0007Gooooo000Looooo`03o`000?oooooooooo07Gooooo1?l00000
0ooooooo0000o`000002o`0000Sooooo0_l0000Nooooo`?o00002_ooool2o`0000[ooooo0_l00002
ooooo`;o00000oooool2o`0000;ooooo0_l00004ooooo`Co0000Loooool001cooooo00?o0000oooo
ooooool0MOooool4o`000003ooooool0003o000000;o00004_ooool2o`0000Oooooo0_l0000;oooo
o`;o00008?ooool2o`0000Kooooo0_l00002ooooo`?o0000L_ooool001cooooo00?o0000oooooooo
ool0T?ooool2o`0000Oooooo0_l00003ooooo`;o00004_ooool2o`000003ooooool0003o000000Co
oooo0_l00007ooooo`;o00001?ooool2o`0000?ooooo1Ol000000ooooooo0000o`00001booooo`00
7?ooool00ol0003oooooooooo`1gooooo`Go00001?ooool4o`0000[ooooo0ol0000=ooooo`;o0000
0_ooool4o`0000?ooooo0_l00007ooooo`Go00001?ooool4o`0000?ooooo1?l00004ooooo`;o0000
0oooool2o`000003ooooool0003o000000;ooooo1?l0001_ooooo`007?ooool00ol0003ooooooooo
o`1gooooo`Go00001?ooool4o`0000[ooooo0ol0000=ooooo`;o00000_ooool4o`0000?ooooo0_l0
0009ooooo`;o00001oooool2o`0000?ooooo0_l00008ooooo`;o00002?ooool4o`0006oooooo000L
ooooo`03o`000?oooooooooo07Sooooo0ol0000?ooooo`;o00004_ooool2o`0000;ooooo0_l0000=
ooooo`;o00004oooool3o`000003ooooool0003o000000;o00002Oooool2o`0000Cooooo1?l0001X
ooooo`007?ooool00ol0003oooooooooo`1jooooo`;o00000oooool2o`0000Cooooo0ol00002oooo
o`;o00005_ooool2o`0000gooooo0_l00009ooooo`;o00001Oooool2o`000005ooooool0003o0000
o`000?ooool01?l0000?ooooo`Co00000_ooool2o`0006Cooooo000Looooo`03o`000?oooooooooo
07[ooooo1?l000000ooooooo0000o`000004ooooo`?o0000<_ooool4o`000003ooooool0003o0000
00Co00001Oooool4o`0000[ooooo0_l000000ooooooo0000o`000006ooooo`?o0000Hoooool001co
oooo00?o0000ooooooooool0O?ooool2o`0001Gooooo0_l00002ooooo`;o00001Oooool2o`0001[o
oooo0ol00002ooooo`Co00001_ooool3o`0000Kooooo0_l00004ooooo`Go00001oooool2o`0006?o
oooo000Looooo`;o0000Noooool2o`0000Oooooo0_l00008ooooo`;o00001?ooool2o`0000;ooooo
0_l00005ooooo`;o000000?oooooo`000?l000006?ooool2o`0000?ooooo0_l00007ooooo`;o0000
1oooool2o`0000Cooooo0ol00002ooooo`;o00000_ooool2o`0006Kooooo000Looooo`03o`000?oo
oooooooo07Gooooo0ol00002ooooo`;o00001oooool2o`0000Kooooo1?l00003ooooo`;o00003Ooo
ool2o`0001gooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00005ooooo`;o00001?oo
ool5o`0000;ooooo1_l0001Vooooo`007?ooool00ol0003oooooooooo`1dooooo`Co00000_ooool2
o`0000Sooooo0_l00005ooooo`Co00000oooool2o`0000Wooooo0_l0000Qooooo`;o000000?ooooo
o`000?l000000_l00009ooooo`;o00000oooool4o`000003ooooool0003o000000?ooooo0ol00004
ooooo`?o0000H?ooool001cooooo00?o0000ooooooooool0Loooool9o`0000Sooooo0_l00003oooo
o`Ko00003_ooool2o`0002Gooooo0_l0000?ooooo`Co000000Goooooo`000?l0003o0000ooooo`04
o`0000Cooooo1_l0001Mooooo`007?ooool00ol0003oooooooooo`1cooooo`Oo00003?ooool2o`00
0003ooooool0003o000000;o00000oooool2o`00023ooooo0_l0000Booooo`;o00004oooool2o`00
0003ooooool0003o000000Gooooo1ol0001Mooooo`007?ooool00ol0003oooooooooo`1booooo`Oo
00000_ooool2o`000003ooooool0003o000000Cooooo1?l00005ooooo`;o000000?oooooo`000?l0
00008?ooool4o`00013ooooo0_l0000<ooooo`;o00002oooool2o`0000;ooooo2?l0001Looooo`00
7?ooool00ol0003oooooooooo`1booooo`Ko00000oooool2o`000003ooooool0003o000000Cooooo
0_l00005ooooo`Co000000?oooooo`000?l000008_ooool2o`0000Kooooo0_l0000Cooooo`;o0000
00?oooooo`000?l000002Oooool4o`000003ooooool0003o000000Wo0000F_ooool001cooooo00?o
0000ooooooooool0LOooool7o`0000?ooooo0_l0000>ooooo`;o00000oooool3o`0000Kooooo0_l0
0005ooooo`;o00003oooool2o`0000Wooooo0_l00008ooooo`;o00002?ooool3o`0000_ooooo0ol0
0003ooooo`go0000F?ooool001cooooo00?o0000ooooooooool0L?ooool;o`0001Kooooo0_l00006
ooooo`;o00001Oooool2o`0000oooooo0_l0000Cooooo`?o00001oooool2o`000003ooooool0003o
000000Gooooo0_l00002ooooo`;o00000oooool>o`0005Sooooo000Looooo`03o`000?oooooooooo
06gooooo3_l0000=ooooo`;o00002Oooool2o`0002oooooo1Ol0000:ooooo`;o00000oooool5o`00
00?ooooo0_l000000ooooooo0000o`00000<o`0005Sooooo000Looooo`03o`000?oooooooooo06go
oooo3_l0000=ooooo`;o00002Oooool2o`0002gooooo1?l0000Booooo`Ko00000_ooool2o`0000?o
oooo3?l0001Hooooo`007?ooool00ol0003oooooooooo`1]ooooo`oo00003oooool2o`0000?ooooo
0_l00002ooooo`;o0000;?ooool2o`000003ooooool0003o000000Oooooo0_l0000<ooooo`;o0000
1Oooool=o`0005Wooooo000Looooo`03o`000?oooooooooo06_ooooo4Ol00006ooooo`;o00000ooo
ool2o`0000;ooooo0_l00003ooooo`?o000000?oooooo`000?l000001_ooool2o`0000;ooooo0_l0
000Sooooo`;o00001?ooool2o`000003ooooool0003o000000Gooooo0_l00003ooooo`;o00001ooo
ool=o`0005Wooooo000Looooo`03o`000?oooooooooo06[ooooo4Ol00007ooooo`;o00000oooool2
o`0000Sooooo0_l00009ooooo`;o00000_ooool2o`0002Wooooo0_l00005ooooo`;o000000?ooooo
o`000?l000000oooool2o`0000Oooooo3Ol0001Iooooo`007?ooool00ol0003oooooooooo`1Zoooo
oa3o00000oooool2o`0000?ooooo0_l0000eooooo`;o00005oooool2o`0000?ooooo1Ol00007oooo
o`go0000FOooool001cooooo00?o0000ooooooooool0J?oooolBo`0000?ooooo0_l00003ooooo`;o
0000:Oooool4o`0000Sooooo0_l0000Gooooo`;o00000_ooool6o`0000;ooooo0_l00004ooooo`co
0000FOooool001cooooo0_l0001VoooooaCo00000_ooool3o`0000?ooooo0_l0000>ooooo`;o0000
6_ooool4o`0000Cooooo0_l0000Iooooo`Co00000_ooool2o`0000Cooooo1_l00002ooooo`co0000
FOooool001cooooo00?o0000ooooooooool0G_ooool4o`000003ooooool0003o000001Co00000_oo
ool3o`0000?ooooo0_l00005ooooo`;o00001oooool2o`0002;ooooo0_l0000Iooooo`;o00002_oo
ool2o`0000;ooooo4?l0001Iooooo`007?ooool00ol0003oooooooooo`1Joooooaoo00002_ooool2
o`0000?ooooo0_l0000_ooooo`;o000000?oooooo`000?l000007_ooool4o`000003ooooool0003o
000000co0000F_ooool001cooooo00?o0000ooooooooool0EooooolRo`0000[ooooo0_l00007oooo
o`Co00000oooool2o`0002Cooooo0_l000000ooooooo0000o`00000=ooooo`;o00001_ooool2o`00
0003ooooool0003o000000Cooooo1?l00002ooooo`go0000F_ooool001cooooo00?o0000oooooooo
ool0EOoooolSo`00017ooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l0000Yooooo`;o
00002oooool2o`0000Kooooo0_l000000ooooooo0000o`000005ooooo`;o00000oooool<o`0005_o
oooo000Looooo`03o`000?oooooooooo05?ooooo9Ol0000Aooooo`;o00009Oooool4o`0000[ooooo
1?l0000Aooooo`;o00002?ooool2o`0000?ooooo1?l000000ooooooo0000o`000003o`0005gooooo
000Looooo`03o`000?oooooooooo057ooooo1_l00002ooooo`Co00000_oooolHo`0003Wooooo1?l0
0008ooooo`;o000000Coooooo`000?l0003o00005oooool2o`0000Wooooo2?l0001Mooooo`007?oo
ool00ol0003oooooooooo`1?ooooo`Co00001_ooool5o`000003ooooool0003o000001Go000000Co
ooooo`000?l0003ooooo0_l00010ooooo`;o000000?oooooo`000?l000002oooool2o`0000_ooooo
0_l00002ooooo`;o00000_ooool9o`0005oooooo000Looooo`03o`000?oooooooooo04kooooo1_l0
0002ooooo`So000000?oooooo`000?l000005?l00002ooooo`;o000000?oooooo`000?l000002Ooo
ool4o`0000_ooooo0_l0000;ooooo`;o00006Oooool3o`0000Gooooo0_l00006ooooo`;o00002Ooo
ool2o`0000?ooooo0ol00002ooooo`Co0000I?ooool001cooooo00?o0000ooooooooool0C_oooolV
o`0000?ooooo0_l00003ooooo`;o00001oooool4o`0000Oooooo0_l00002ooooo`;o00002oooool2
o`0001Sooooo1_l00003ooooo`;o00004?ooool4o`0000;ooooo0_l00003ooooo`Co0000I?ooool0
01cooooo00?o0000ooooooooool0C?ooool4o`0000;ooooo4?l00002ooooo`ko00000oooool2o`00
00Gooooo0_l0000Booooo`;o00004oooool2o`0000cooooo0_l00002ooooo`;o00000_ooool2o`00
00;ooooo0_l0000?ooooo`;o00001?ooool4o`0000Oooooo1Ol0001Sooooo`007?ooool00ol0003o
ooooooooo`1<ooooo`Go000000?oooooo`000?l000003_l00003ooooo`co00001?ooool2o`0002ko
oooo0_l0000<ooooo`;o00000_ooool2o`0000Gooooo0ol00002ooooo`;o00000_ooool4o`0000Co
oooo0ol00005ooooo`;o00002?ooool5o`0006?ooooo000Looooo`03o`000?oooooooooo04cooooo
5ol00002ooooo`Co000000?oooooo`000?l000001?l000001?oooooo0000o`000?ooool2o`0000_o
oooo0_l0000`ooooo`?o00002?ooool4o`000003ooooool0003o000000;ooooo1?l00004ooooo`?o
00003?ooool8o`0006?ooooo000Looooo`03o`000?oooooooooo04cooooo0_l00002oooooaCo0000
0_ooool3o`0000;ooooo1Ol000001?oooooo0000o`000?ooool3o`0000?ooooo0_l00005ooooo`;o
00003_ooool2o`0001?ooooo0_l0000;ooooo`?o00002_ooool2o`0000Gooooo1?l0000Booooo`Wo
0000Hoooool001cooooo00?o0000ooooooooool0B_ooool4o`0000;ooooo4Ol000000ooooooo0000
o`000003ooooo`;o00000_ooool3o`0000Oooooo0_l00003ooooo`Co00001?ooool2o`0000gooooo
0_l0000Cooooo`;o00004oooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o0000
1Oooool2o`0000Sooooo0_l00002ooooo`[o0000Hoooool001cooooo00?o0000ooooooooool0B_oo
ool2o`0000Cooooo3ol00008ooooo`;o00004oooool2o`0000Cooooo0_l00006ooooo`;o0000;ooo
ool2o`0000Kooooo1?l00007ooooo`;o000000?oooooo`000?l000001Oooool2o`0000;ooooo2ol0
001Rooooo`007?ooool2o`0004Wooooo1?l00004ooooo`ko00002Oooool2o`0000[ooooo0_l00002
ooooo`;o00004Oooool2o`0001Sooooo0_l00002ooooo`;o00003oooool2o`0000[ooooo0_l0000:
ooooo`;o00001Oooool2o`000003ooooool0003o000000[o0000H_ooool001cooooo00?o0000oooo
ooooool0B?ooool3o`0000Cooooo3ol00007ooooo`;o00002oooool4o`000003ooooool0003o0000
01;ooooo0_l0000Fooooo`?o00000_ooool2o`0000oooooo0_l00004ooooo`;o00001_ooool2o`00
00[ooooo0ol00002ooooo`oo0000H_ooool001cooooo00?o0000ooooooooool0B?ooool3o`0000Co
oooo3_l00008ooooo`;o00002oooool4o`0000oooooo0_l00004ooooo`;o00005_ooool2o`0000Wo
oooo0_l0000?ooooo`;o00001_ooool2o`0000Oooooo1_l000001?oooooo0000o`000?ooool=o`00
06;ooooo000Looooo`03o`000?oooooooooo04Sooooo0ol00005ooooo`oo00002_ooool2o`0001;o
oooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo0_l0000Sooooo`;o00004?ooool2o`0000Go
oooo1?l000000ooooooo0000o`000002ooooo`Co00000oooool>o`000003ooooool0003o0000067o
oooo000Looooo`03o`000?oooooooooo04Sooooo0ol00003ooooo`ko000000?oooooo`000?l00000
0_l000000ooooooo0000o`000004ooooo`?o00004_ooool2o`0000;ooooo0_l00006ooooo`;o0000
2oooool2o`0002Kooooo1?l00005ooooo`Co000000?oooooo`000?l000002_ooool=o`000003oooo
ool0003o0000067ooooo000Looooo`03o`000?oooooooooo04Oooooo0ol00004ooooo`go00001?oo
ool2o`000003ooooool0003o000000?ooooo0ol00008ooooo`;o00006Oooool2o`0000Oooooo0_l0
000Nooooo`Co00001?ooool2o`0001Sooooo3ol0001Rooooo`007?ooool00ol0003oooooooooo`17
ooooo`?o00001Oooool:o`0000kooooo0ol00008ooooo`;o00001oooool2o`00013ooooo0_l0000W
ooooo`Co00002_ooool2o`0000_ooooo1?l00002oooooa3o0000H_ooool001cooooo00?o0000oooo
ooooool0B_ooool2o`0000?ooooo2_l0000=ooooo`Co00004Oooool2o`0000?ooooo0_l0000Moooo
o`;o00008oooool2o`0000Oooooo0_l00002ooooo`Co00000_ooool@o`0006;ooooo000Looooo`03
o`000?oooooooooo04Oooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l0
00001?l000000ooooooo0000o`00000<ooooo`;o00004oooool2o`0000?ooooo0_l0000Mooooo`;o
00002_ooool2o`0000?ooooo0_l0000Kooooo`;o00000_ooool3o`0000?ooooo4?l0001Rooooo`00
7?ooool00ol0003oooooooooo`17ooooo`Go00000_ooool2o`000003ooooool0003o000000Co0000
00?oooooo`000?l000002_ooool2o`0000Cooooo0_l0000Gooooo`;o00008_ooool2o`0000;ooooo
0_l00003ooooo`;o00006?ooool2o`0000Kooooo0_l00003ooooo`go0000IOooool001cooooo00?o
0000ooooooooool0B?ooool5o`000003ooooool0003o000001Cooooo0_l00004ooooo`;o00000_oo
ool2o`0000Sooooo0_l00004ooooo`;o00000oooool2o`0000_ooooo1?l00002ooooo`;o00001_oo
ool5o`0000Cooooo0ol0000Pooooo`Co00001?ooool2o`0000;ooooo4Ol0001Rooooo`007?ooool0
0ol0003oooooooooo`18ooooo`;o000000Coooooo`000?l0003ooooo0_l0000>ooooo`?o00001_oo
ool2o`000003ooooool0003o000000;ooooo0_l00006ooooo`Co00001?ooool2o`00013ooooo1?l0
0002ooooo`;o00001_ooool5o`0000Gooooo0_l00002ooooo`;o00003?ooool4o`0000Sooooo0_l0
0002ooooo`Co00001Oooool@o`000004ooooool0003o0000o`0006;ooooo000Looooo`03o`000?oo
oooooooo04Wooooo1?l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000001_oo
ool3o`000003ooooool0003o000000;o000000Coooooo`000?l0003ooooo0_l0000:ooooo`;o0000
3?ooool2o`0001Sooooo0_l0000<ooooo`;o00000_ooool4o`0000Kooooo1_l00006ooooo`;o0000
2oooool?o`000003ooooool0003o000000;o0000H_ooool001cooooo00?o0000ooooooooool0B?oo
ool5o`0000Kooooo0_l000000ooooooo0000o`000004ooooo`;o00001?ooool4o`0001[ooooo0_l0
0002ooooo`;o00001Oooool2o`00017ooooo0_l000000ooooooo0000o`000006ooooo`;o00001Ooo
ool4o`0000Kooooo0_l00002ooooo`;o00003_ooool2o`0000Kooooo2ol00002ooooo`Co0000H_oo
ool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o
410@olc<c006ooooo`03o`000?oooooooooo04Sooooo1?l000000ooooooo0000o`00000=ooooo`;o
000000Coooooo`000?l0003ooooo1?l00005ooooo`;o00003_ooool2o`0000?ooooo0_l00003oooo
o`;o00001?ooool2o`0001Cooooo0_l00006ooooo`;o00000_ooool2o`0000Cooooo0ol00003oooo
o`?o00000oooool2o`0000gooooo0_l00006ooooo`_o00000_ooool3o`0006?ooooo00001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_oo
ool00ol0003oooooooooo`19ooooo`Ko00003oooool3o`000003ooooool0003o000000;o00000_oo
ool5o`0000Oooooo1?l00003ooooo`;o00002?ooool3o`0000?ooooo0_l00005ooooo`;o00006Ooo
ool2o`0000Cooooo0ol00003ooooo`;o00001?ooool2o`0000cooooo2?l000000ooooooo0000o`00
0007o`000003ooooool0003o000000;ooooo0_l0001Sooooo`0000?ooooooa0@4?ooool00_ooool0
0ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`1;ooooo`?o00002_ooool3o`0000?ooooo0_l00002ooooo`Go000000Coooooo`000?l0003o0000
1?ooool2o`0000?ooooo1?l00003ooooo`;o00002Oooool2o`000003ooooool0003o000000;o0000
1Oooool2o`0003;ooooo0_l00004ooooo`Wo000000Coooooo`000?l0003o00000_ooool4o`000003
ooooool0003o000000?o0000I?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
2Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0001;ooooo`?o00000_ooool2o`0000Ko
oooo0ol00003ooooo`;o000000?oooooo`000?l000001?l00002ooooo`;o00001?ooool2o`0000[o
oooo0_l0000<ooooo`;o00007?ooool2o`00017ooooo1?l00006ooooo`Co00001?ooool2o`0000Co
oooo0_l00002ooooo`;o00000oooool2o`0000?ooooo1Ol0001Tooooo`0000?oooooo`000?ooool0
0_ooool00ol0003oooooooooo`09ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003o
ooooooooo`1;ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00002_ooool3o`000003
ooooool0003o000000Wooooo0_l0000:ooooo`;o00008?ooool3o`0000Oooooo0_l0000Aooooo`Co
00001_ooool3o`0000oooooo1?l00002ooooo`;o00000_ooool4o`0006Gooooo00000ooooooo410@
ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003ooooo
ooooo`1>ooooo`Go000000?oooooo`000?l000002_ooool2o`0000Kooooo0_l00002ooooo`Oo0000
2_ooool2o`0000Wooooo0_l00009ooooo`;o00001oooool4o`0001?ooooo0_l000001?oooooo0000
o`000?ooool2o`0000kooooo0_l0000<ooooo`?o00000_ooool2o`000004ooooool0003o0000o`00
06Oooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?ooool0
0ol0003oooooooooo`1>ooooo`So00003?ooool2o`0000Cooooo0_l00002ooooo`Oo00002_ooool2
o`0000Wooooo0_l00009ooooo`;o00001Oooool5o`0000[ooooo0_l00004ooooo`;o00000_ooool2
o`000004ooooool0003o0000ooooo`?o00001_ooool2o`0000Gooooo0_l00003ooooo`;o00000ooo
ool2o`0000;ooooo0_l00005ooooo`?o0000J?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^
3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo04oooooo0_l000000ooooooo
0000o`000007o`0000Kooooo0ol00004ooooo`;o00001?ooool2o`0000;ooooo0_l0000=ooooo`?o
00003oooool2o`0000Gooooo0_l000000ooooooo0000o`000005ooooo`;o00000oooool2o`0000?o
oooo0ol00006ooooo`Go00001_ooool2o`0000[ooooo0_l00003ooooo`;o00000_ooool2o`0000?o
oooo1?l0001Yooooo`007?ooool00ol0003oooooooooo`1Fooooo`Wo00000_ooool2o`0000Gooooo
0_l00008ooooo`Co00002?ooool2o`000004ooooool0003o0000o`0000gooooo1?l00003ooooo`;o
00001_ooool2o`0000;ooooo0_l00008ooooo`;o00001oooool3o`0000Sooooo0_l00002ooooo`;o
00001oooool2o`0000;ooooo0_l00002ooooo`?o00000_ooool4o`0006Wooooo000Looooo`03o`00
0?oooooooooo05[ooooo2_l0000@ooooo`;o00002?ooool2o`0000_ooooo0_l00002ooooo`Co0000
1Oooool2o`0000Kooooo0_l0000Oooooo`?o00000_ooool2o`0000Oooooo0_l00002ooooo`;o0000
0_ooool3o`0000?ooooo0_l0001Zooooo`007?ooool00ol0003oooooooooo`1Oooooo`So00006Ooo
ool2o`0000Wooooo0_l00002ooooo`;o00004_ooool2o`0000gooooo0_l00003ooooo`;o00002?oo
ool3o`0000;ooooo0_l00004ooooo`?o00001?ooool2o`0000?ooooo0ol000001?oooooo0000o`00
0?l0001Zooooo`007?ooool00ol0003oooooooooo`1Tooooo`Go00001_ooool2o`0000Wooooo0_l0
0004ooooo`?o00007oooool3o`0000gooooo0_l00003ooooo`;o00002oooool4o`0000Cooooo0ol0
0003ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`?o0000J_ooool001cooooo00?o
0000ooooooooool0IOooool5o`0000Gooooo0_l00009ooooo`Co00000oooool2o`0000Sooooo0_l0
000:ooooo`;o00001_ooool2o`000005ooooool0003o0000o`000?ooool00_l00008ooooo`;o0000
4?ooool5o`0000Gooooo0ol000000ooooooo0000o`000002o`0000;ooooo0_l000000ooooooo0000
o`000004o`0006[ooooo000Looooo`03o`000?oooooooooo06Oooooo1Ol00004ooooo`;o00002_oo
ool2o`0000gooooo0_l00004ooooo`;o00001?ooool2o`0000Kooooo0_l00002ooooo`;o000000?o
ooooo`000?l000002?ooool2o`0000Oooooo0ol00006ooooo`;o00002Oooool:o`0000;ooooo1Ol0
001[ooooo`007?ooool00ol0003oooooooooo`1Yooooo`Co00000oooool2o`0000_ooooo0_l00000
0ooooooo0000o`00000:ooooo`;o00000oooool2o`000003ooooool0003o000000Oooooo1?l00000
0ooooooo0000o`000009ooooo`;o00001_ooool2o`0000;ooooo0ol00007ooooo`;o00001Oooool2
o`0000;ooooo0ol000000ooooooo0000o`000003o`0000?ooooo1?l0001[ooooo`007?ooool00ol0
003oooooooooo`1Tooooo`Go000000?oooooo`000?l000000_l0000?ooooo`;o000000?oooooo`00
0?l000000_l00008ooooo`?o00001Oooool2o`0000Oooooo1?l000000ooooooo0000o`000008oooo
o`?o00000oooool2o`000003ooooool0003o000000Sooooo0_l00002ooooo`;o00001?ooool3o`00
00Oooooo0_l0001dooooo`007?ooool00ol0003oooooooooo`1Rooooo`go000000?oooooo`000?l0
00004?ooool2o`0000Wooooo1?l00002ooooo`;o00002?ooool2o`0000gooooo0ol00003ooooo`;o
000000?oooooo`000?l000000oooool2o`0000?ooooo0_l00006ooooo`Co000000Coooooo`000?l0
003o00001?ooool2o`0007Cooooo000Looooo`03o`000?oooooooooo06;ooooo4?l00003ooooo`;o
00004?ooool4o`0000Cooooo0_l000000ooooooo0000o`000003o`0000;ooooo0ol000000ooooooo
0000o`00000=ooooo`;o00001oooool2o`0000?ooooo0_l00002ooooo`;o00001oooool2o`000003
ooooool0003o000000Ko00000_ooool3o`0007;ooooo000Looooo`03o`000?oooooooooo067ooooo
3Ol000000ooooooo0000o`000004ooooo`;o00001?ooool2o`0000[ooooo1?l00004ooooo`;o0000
00Coooooo`000?l0003ooooo0_l00002ooooo`?o00004?ooool2o`00013ooooo0_l00004ooooo`;o
00000_ooool:o`000003ooooool0003o000000;o0000L_ooool001cooooo0_l0001Roooooa3o0000
2_ooool2o`00013ooooo1?l0000@ooooo`;o00001?ooool4o`0000?ooooo0_l00005ooooo`Co0000
2ooooolBo`0007?ooooo000Looooo`03o`000?oooooooooo067ooooo4?l00008ooooo`;o00000_oo
ool2o`0000kooooo0_l00009ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00001?oo
ool4o`000003ooooool0003o000000;o00000_ooool2o`000003ooooool0003o000000;o00002Ooo
ool2o`000003ooooool0003o000000?o000000?oooooo`000?l000002Ol0001cooooo`007?ooool0
0ol0003oooooooooo`1Rooooo`oo00002?ooool2o`000003ooooool0003o000000;o000000?ooooo
o`000?l000003oooool2o`0000Cooooo0_l000000ooooooo0000o`000002o`000005ooooool0003o
0000o`000?ooool00_l00006ooooo`?o00000oooool2o`0000;ooooo1?l00008oooooaCo0000Looo
ool001cooooo00?o0000ooooooooool0H_ooool?o`0000Wooooo2Ol00004ooooo`;o00002Oooool2
o`0000?ooooo0_l00007ooooo`?o000000?oooooo`000?l000004?ooool4o`0000[ooooo4_l0001c
ooooo`007?ooool00ol0003oooooooooo`1Roooooa3o00002?ooool2o`0000?ooooo1?l00003oooo
o`?o00001Oooool2o`0000;ooooo0_l00002ooooo`?o00002_ooool3o`0001Wooooo0_l00002oooo
oa?o0000Loooool001cooooo00?o0000ooooooooool0H_oooolBo`0000gooooo0_l00003ooooo`;o
00001_ooool2o`0000Kooooo1?l00009ooooo`;o00000_ooool2o`0000Gooooo0_l00008ooooo`;o
00000_ooool2o`000004ooooool0003o0000oooooaGo0000L_ooool001cooooo00?o0000oooooooo
ool0H_oooolBo`0000gooooo0_l0000<ooooo`;o00001oooool2o`0000Kooooo0_l000000ooooooo
0000o`000002ooooo`;o00001Oooool5o`0000Gooooo0_l00002ooooo`;o00001?oooolEo`0007;o
oooo000Looooo`03o`000?oooooooooo06;ooooo4Ol00009ooooo`?o00003Oooool2o`000003oooo
ool0003o000000?ooooo1?l00002ooooo`;o00001?ooool2o`0000;ooooo0_l00007oooooa7o0000
0_oooolEo`0007Cooooo000Looooo`03o`000?oooooooooo06?ooooo4?l000001?oooooo0000o`00
0?l00004ooooo`Co00003Oooool2o`0000Kooooo2_l00006ooooo`Co00000ooooolCo`0000;ooooo
5_l0001cooooo`007?ooool00ol0003oooooooooo`1SoooooaGo00000oooool2o`0000gooooo0_l0
0005ooooo`Wo00000_ooool2o`0000Oooooo1Ol000000ooooooo0000o`00000<o`000004ooooool0
003o0000o`0000?ooooo5_l0001cooooo`007?ooool00ol0003oooooooooo`1Voooooa;o00001_oo
ool2o`000003ooooool0003o000000Go00000_ooool2o`000005ooooool0003o0000o`000?ooool0
1ol000000ooooooo0000o`000007ooooo`So000000?oooooo`000?l000003?l00006oooooa?o0000
00?oooooo`000?l00000M?ooool001cooooo00?o0000ooooooooool0I_ooool9o`000003ooooool0
003o000000Co00001Oooool2o`000003ooooool0003o000000_o00000_ooool3o`000004ooooool0
003o0000ooooo`;o00000_ooool4o`0000Kooooo4?l00002ooooo`Go00001OoooolHo`0007?ooooo
000Looooo`03o`000?oooooooooo06Oooooo3_l00004ooooo`Co000000?oooooo`000?l000003Ol0
0004ooooo`co00001?oooolJo`0000?ooooo6?l0001cooooo`007?ooool00ol0003oooooooooo`1/
ooooo`;o000000Coooooo`000?l0003o00001oooool5o`0000;ooooo3_l00005ooooo`[o00000_oo
oolHo`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000003ol0001hooooo`007?ooool0
0ol0003oooooooooo`1hooooo`?o000000Goooooo`000?l0003o0000ooooo`0?o`0000Wooooo0_l0
0005oooooaWo00001?oooolEo`0007Sooooo000Looooo`03o`000?oooooooooo07Sooooo0ol00000
1Ooooooo0000o`000?l0003ooooo00oo00002?ooool3o`0000Kooooo6_l00002oooooaCo0000NOoo
ool001cooooo0_l0001jooooo`;o000000?oooooo`000?l000004_l00007ooooo`;o00001?ooool2
o`000003ooooool0003o000001So00000oooool3o`000003ooooool0003o000000co0000N_ooool0
01cooooo00?o0000ooooooooool0NOooool2o`0000Cooooo4Ol0000=oooooaSo00000_ooool2o`00
00Cooooo0_l00003ooooo`So000000?oooooo`000?l000000_l0001jooooo`007?ooool00ol0003o
ooooooooo`1moooooaCo00002oooool4o`000004ooooool0003o0000oooooa7o00002Oooool4o`00
00;ooooo1?l00003ooooo`?o0000Noooool001cooooo00?o0000ooooooooool0OOoooolEo`000004
ooooool0003o0000o`0000Cooooo1Ol00002ooooo`;o000000?oooooo`000?l000003ol00009oooo
o`Oo00000_ooool3o`0000;ooooo0_l0001kooooo`007?ooool00ol0003oooooooooo`1loooooa[o
00001?ooool5o`0000;ooooo0_l000000ooooooo0000o`00000>o`0000cooooo1Ol00002ooooo`?o
00000_ooool2o`0007_ooooo000Looooo`03o`000?oooooooooo07cooooo0_l00002oooooaCo0000
1_ooool3o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000003Ol0002Fooooo`00
7?ooool00ol0003oooooooooo`22ooooo`oo000000?oooooo`000?l000001_ooool6o`000004oooo
ool0003o0000ooooo`oo0000U_ooool001cooooo00?o0000ooooooooool0P_ooool?o`0000[ooooo
1ol00002ooooo`oo0000U_ooool001cooooo00?o0000ooooooooool0P_ooool;o`00013ooooo1_l0
00001Ooooooo0000o`000?l0003ooooo00Ko00000oooool2o`0009Kooooo000Looooo`03o`000?oo
oooooooo08;ooooo0_l00003ooooo`Oo00004Oooool8o`0000Cooooo0_l0002Looooo`007?ooool0
0ol0003oooooooooo`28ooooo`;o00000_ooool2o`0001Cooooo1ol000001?oooooo0000o`000?l0
002Looooo`007?ooool00ol0003oooooooooo`2Wooooo`;o000000?oooooo`000?l00000WOooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o
8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom:oooo
o`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonH
V9So8B4Q00Kooooo00?o0000ooooooooool0oooooom:ooooo`0000?ooooooa0@4?ooool00_ooool0
0ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`3ooooood[ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8b
oiRHV?ooooooV9RHoc8b<P06ooooo`?o0000oooooom:ooooo`0000?oooooo`000?ooool00_ooool0
0ol0003oooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003ooooooooo
o`3ooooood[ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go410@
okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo0?ooooooB_ooool00006oooooomgMgOo
V9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000oooooooo
ool0oooooom:ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000
oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Booooo`Co000000?o410@ooooooooool0
0oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`?o0000oooooom:
ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?oo
ooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003ooooooooo
o`3ooooooe;ooooo000Booooo`03oeEEEOmVIVKo00000?ooooooE?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00:Wooooo00Co410@o`000?l0003ooooo0_l000000ol@413ooooo
ooooo`0Gooooo`03o`000?o^k^kooooo00?ooooo1Ol0002Dooooo`00Z_ooool01Ol0003ooooooooo
oooooooo000000Wooooo1_l0000;ooooo`03oeEEEOnYZJWooooo00?ooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A02Dooooo`00Z_ooool01Ol0003ooooooooooooooooo000001[ooooo00?oZJVYoeEEEOoo
ool01?ooool00onHV9So8B4Qonk^kP2Eooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Wo
oooo1_l0000<ooooo`03ob4Q8Ooooooooooo00Cooooo00?oV9RHob4Q8Oo^k^h0U?ooool00:[ooooo
00Go0000ohN7QoooooooZJVYo`00000Kooooo`03oeEEEOo<c<cooooo00Gooooo00?oMgMgofIVI_oo
ool0Toooool00:Wooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Iooooo`03ojVY
ZOmgMgOooooo00Kooooo00?o0000ooooooooool0T_ooool00<Oooooo00Go410@oooooooooooooooo
oc8b<P03ooooo`05o`000?nj^[[ooooooiRHV?l@4100U?ooool00<Oooooo1Ol00003ooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`0U?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -20 0 ]
[.5 1.0125 20 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(78) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.57493 .69522 Mdot
.63012 .68955 Mdot
.66429 .40068 Mdot
.37763 .50116 Mdot
.39027 .31321 Mdot
.67282 .40368 Mdot
.68176 .57665 Mdot
.67876 .60264 Mdot
.64789 .39977 Mdot
.32039 .52333 Mdot
.7398 .53522 Mdot
.32695 .64288 Mdot
.68549 .58192 Mdot
.32447 .51295 Mdot
.23863 .56798 Mdot
.41214 .70317 Mdot
.59467 .6898 Mdot
.39698 .31453 Mdot
.40966 .68079 Mdot
.64639 .39041 Mdot
.44481 .33886 Mdot
.35106 .50431 Mdot
.58894 .70274 Mdot
.32073 .51119 Mdot
.40777 .6815 Mdot
.50723 .68504 Mdot
.57075 .69995 Mdot
.40395 .68708 Mdot
.32216 .63592 Mdot
.70191 .56805 Mdot
.39484 .6984 Mdot
.24402 .52334 Mdot
.50707 .342 Mdot
.53894 .69905 Mdot
.73407 .51036 Mdot
.75054 .51717 Mdot
.67304 .42463 Mdot
.74232 .53836 Mdot
.69437 .59317 Mdot
.73512 .51462 Mdot
.73708 .5129 Mdot
.50316 .6855 Mdot
.7491 .50902 Mdot
.69572 .53702 Mdot
.29565 .48489 Mdot
.49554 .72227 Mdot
.67321 .31396 Mdot
.32701 .47814 Mdot
.59521 .68075 Mdot
.66655 .32588 Mdot
.26183 .51074 Mdot
.65969 .59966 Mdot
.50558 .31556 Mdot
.45851 .71098 Mdot
.6902 .5865 Mdot
.40486 .67855 Mdot
.6834 .3792 Mdot
.31077 .49685 Mdot
.31792 .62719 Mdot
.52523 .71154 Mdot
.33512 .49862 Mdot
.43297 .30086 Mdot
.46099 .67877 Mdot
.68481 .37161 Mdot
.65548 .40021 Mdot
.72532 .55433 Mdot
.63637 .69227 Mdot
.72249 .54567 Mdot
.37026 .51417 Mdot
.66785 .29724 Mdot
.33614 .47817 Mdot
.74037 .53437 Mdot
.50041 .70174 Mdot
.35659 .51487 Mdot
.60044 .67481 Mdot
.72507 .53615 Mdot
.38045 .31188 Mdot
.5108 .69196 Mdot
.66421 .33399 Mdot
.40331 .48106 Mdot
.36014 .50103 Mdot
.6745 .63942 Mdot
.30364 .61431 Mdot
.47814 .70271 Mdot
.27478 .48742 Mdot
.66397 .65765 Mdot
.37277 .48352 Mdot
.40141 .70138 Mdot
.40112 .68258 Mdot
.32967 .62789 Mdot
.71726 .40665 Mdot
.6061 .70905 Mdot
.3411 .5106 Mdot
.36733 .5182 Mdot
.26632 .50596 Mdot
.26597 .49068 Mdot
.39873 .68034 Mdot
.54002 .32787 Mdot
.73574 .52583 Mdot
.48847 .31836 Mdot
.72294 .54253 Mdot
.50199 .3092 Mdot
.39218 .48454 Mdot
.69139 .40388 Mdot
.48901 .68066 Mdot
.53465 .33389 Mdot
.72816 .5303 Mdot
.33928 .51246 Mdot
.75013 .52331 Mdot
.60319 .70687 Mdot
.38817 .69166 Mdot
.40424 .28583 Mdot
.36281 .30591 Mdot
.57499 .71371 Mdot
.40048 .46604 Mdot
.33917 .49127 Mdot
.34652 .49963 Mdot
.62951 .70086 Mdot
.64962 .39311 Mdot
.6801 .34651 Mdot
.61763 .69813 Mdot
.73814 .5212 Mdot
.59699 .68544 Mdot
.48463 .33751 Mdot
.65218 .39835 Mdot
.49523 .3313 Mdot
.53591 .3171 Mdot
.2658 .52128 Mdot
.25944 .49654 Mdot
.46144 .31827 Mdot
.69389 .40581 Mdot
.62095 .69604 Mdot
.68161 .58992 Mdot
.36505 .52051 Mdot
.48189 .70316 Mdot
.69229 .58264 Mdot
.38265 .28445 Mdot
.38715 .27466 Mdot
.49551 .6997 Mdot
.39924 .46244 Mdot
.74401 .53788 Mdot
.67161 .61304 Mdot
.2779 .51234 Mdot
.48205 .70838 Mdot
.37943 .30652 Mdot
.67404 .6129 Mdot
.56218 .31248 Mdot
.38532 .68434 Mdot
.23215 .50061 Mdot
.6717 .63741 Mdot
.26645 .51116 Mdot
.46375 .3476 Mdot
.42822 .29521 Mdot
.69202 .58726 Mdot
.38101 .49138 Mdot
.61489 .68232 Mdot
.48731 .7049 Mdot
.30123 .64439 Mdot
.52691 .33888 Mdot
.32377 .49192 Mdot
.49221 .30704 Mdot
.53834 .3203 Mdot
.32746 .51253 Mdot
.51386 .71846 Mdot
.52439 .68188 Mdot
.3352 .48286 Mdot
.66655 .42535 Mdot
.39842 .31548 Mdot
.7473 .51982 Mdot
.27762 .49111 Mdot
.26968 .50494 Mdot
.31032 .65062 Mdot
.66805 .61373 Mdot
.71448 .52786 Mdot
.65158 .30534 Mdot
.71998 .55247 Mdot
.72602 .51041 Mdot
.70031 .38894 Mdot
.3151 .64365 Mdot
.4107 .28529 Mdot
.52267 .32424 Mdot
.33362 .48477 Mdot
.24743 .50449 Mdot
.33082 .63255 Mdot
.44373 .33477 Mdot
.47689 .35126 Mdot
.6284 .65269 Mdot
.74204 .50091 Mdot
.37469 .49198 Mdot
.37588 .67252 Mdot
.25363 .51093 Mdot
.70384 .57725 Mdot
.67659 .59374 Mdot
.65033 .37158 Mdot
.64746 .3839 Mdot
.65886 .31666 Mdot
.30166 .65516 Mdot
.32341 .65907 Mdot
.36788 .50176 Mdot
.49777 .32111 Mdot
.45797 .68125 Mdot
.4292 .29745 Mdot
.60371 .68563 Mdot
.67681 .63771 Mdot
.3229 .47082 Mdot
.41575 .68316 Mdot
.6747 .43865 Mdot
.72129 .40137 Mdot
.52537 .31141 Mdot
.41346 .30177 Mdot
.31404 .49433 Mdot
.57624 .70871 Mdot
.26581 .51243 Mdot
.49826 .3395 Mdot
.36176 .30809 Mdot
.60482 .69994 Mdot
.31884 .47495 Mdot
.68852 .57849 Mdot
.71285 .40337 Mdot
.37252 .48342 Mdot
.34572 .51632 Mdot
.50828 .69187 Mdot
.38262 .50615 Mdot
.38981 .67055 Mdot
.39302 .69146 Mdot
.65975 .31163 Mdot
.71945 .5341 Mdot
.70373 .55982 Mdot
.67368 .3118 Mdot
.49781 .69299 Mdot
.56349 .72225 Mdot
.68398 .39549 Mdot
.43566 .33318 Mdot
.74136 .5359 Mdot
.38714 .29645 Mdot
.68562 .40178 Mdot
.39741 .31343 Mdot
.3183 .62333 Mdot
.70145 .40735 Mdot
.39575 .28349 Mdot
.2626 .57696 Mdot
.53436 .32058 Mdot
.37116 .27843 Mdot
.68113 .57538 Mdot
.63344 .67087 Mdot
.33822 .48449 Mdot
.51273 .31785 Mdot
.48957 .33229 Mdot
.31159 .64143 Mdot
.52353 .30348 Mdot
.52157 .33754 Mdot
.31029 .6435 Mdot
.42792 .31152 Mdot
.68982 .6175 Mdot
.3932 .69734 Mdot
.59741 .68699 Mdot
.38197 .50426 Mdot
.71789 .52915 Mdot
.69285 .58318 Mdot
.32397 .49692 Mdot
.66557 .64611 Mdot
.67961 .5749 Mdot
.32672 .50736 Mdot
.69776 .5848 Mdot
.47994 .70201 Mdot
.32787 .47146 Mdot
.49827 .70615 Mdot
.3235 .5112 Mdot
.69776 .58592 Mdot
.67175 .32051 Mdot
.50092 .68701 Mdot
.34665 .50905 Mdot
.37123 .50489 Mdot
.5007 .32006 Mdot
.38973 .68998 Mdot
.65219 .61167 Mdot
.32586 .64346 Mdot
.70016 .37885 Mdot
.29388 .63559 Mdot
.42698 .28069 Mdot
.56313 .31046 Mdot
.48285 .70869 Mdot
.52643 .30441 Mdot
.67777 .39888 Mdot
.27712 .50919 Mdot
.30455 .47111 Mdot
.28966 .48595 Mdot
.51959 .33625 Mdot
.30139 .6141 Mdot
.67629 .57286 Mdot
.38395 .67578 Mdot
.46531 .31427 Mdot
.67845 .38028 Mdot
.49445 .31144 Mdot
.26929 .48884 Mdot
.59291 .70567 Mdot
.41564 .69287 Mdot
.70664 .39247 Mdot
.59223 .69892 Mdot
.32843 .48031 Mdot
.72138 .54495 Mdot
.43272 .27948 Mdot
.68079 .56854 Mdot
.40677 .69392 Mdot
.29537 .63713 Mdot
.66817 .30074 Mdot
.49295 .68981 Mdot
.6867 .59564 Mdot
.49956 .70351 Mdot
.28554 .51092 Mdot
.37191 .47658 Mdot
.48468 .712 Mdot
.40646 .27318 Mdot
.65181 .32332 Mdot
.73479 .53993 Mdot
.49729 .32845 Mdot
.65746 .2858 Mdot
.58913 .68546 Mdot
.68676 .40644 Mdot
.39562 .4499 Mdot
.71499 .39712 Mdot
.41658 .6905 Mdot
.66147 .2881 Mdot
.31025 .6533 Mdot
.28234 .48348 Mdot
.67826 .36656 Mdot
.53794 .33326 Mdot
.29785 .50357 Mdot
.48196 .70048 Mdot
.24307 .52679 Mdot
.30842 .51594 Mdot
.30203 .65421 Mdot
.68057 .38091 Mdot
.3982 .45897 Mdot
.39812 .69366 Mdot
.40732 .69042 Mdot
.60894 .6866 Mdot
.50626 .3284 Mdot
.37677 .28521 Mdot
.37737 .27603 Mdot
.55392 .29239 Mdot
.3234 .60999 Mdot
.38998 .466 Mdot
.49178 .69603 Mdot
.66385 .32449 Mdot
.62809 .66542 Mdot
.50042 .34037 Mdot
.67793 .60326 Mdot
.71254 .5318 Mdot
.37758 .48353 Mdot
.43563 .27405 Mdot
.41677 .67925 Mdot
.60683 .67524 Mdot
.50393 .6994 Mdot
.68525 .59748 Mdot
.29005 .61457 Mdot
.35479 .53077 Mdot
.33296 .49434 Mdot
.67298 .60737 Mdot
.49499 .33555 Mdot
.31451 .62749 Mdot
.22935 .50911 Mdot
.70935 .51301 Mdot
.2938 .49129 Mdot
.52854 .70462 Mdot
.29759 .4822 Mdot
.26978 .51951 Mdot
.30375 .4908 Mdot
.48661 .69635 Mdot
.36707 .66311 Mdot
.24631 .48793 Mdot
.6886 .43693 Mdot
.315 .46951 Mdot
.40654 .27554 Mdot
.34756 .51346 Mdot
.32416 .48923 Mdot
.37652 .30162 Mdot
.57405 .7112 Mdot
.2714 .50262 Mdot
.6837 .62165 Mdot
.3447 .50729 Mdot
.7478 .51852 Mdot
.30369 .62538 Mdot
.25314 .52495 Mdot
.39825 .691 Mdot
.5898 .70414 Mdot
.68832 .60142 Mdot
.7442 .51385 Mdot
.49128 .30347 Mdot
.69303 .58338 Mdot
.2808 .48839 Mdot
.30403 .62288 Mdot
.57559 .71412 Mdot
.53456 .32252 Mdot
.60953 .70896 Mdot
.3866 .24576 Mdot
.67586 .58094 Mdot
.50527 .31135 Mdot
.29076 .64444 Mdot
.66683 .59401 Mdot
.68796 .61575 Mdot
.38819 .69263 Mdot
.49414 .33482 Mdot
.57493 .6969 Mdot
.66538 .29395 Mdot
.50903 .33907 Mdot
.69007 .58858 Mdot
.29683 .48477 Mdot
.39263 .67931 Mdot
.69058 .59355 Mdot
.52721 .70159 Mdot
.38295 .68903 Mdot
.3412 .50734 Mdot
.49833 .68365 Mdot
.62348 .70347 Mdot
.34925 .48267 Mdot
.36575 .48826 Mdot
.67065 .39008 Mdot
.51346 .33681 Mdot
.51256 .33556 Mdot
.53895 .3169 Mdot
.71112 .39208 Mdot
.64705 .31161 Mdot
.72333 .52637 Mdot
.25544 .52593 Mdot
.71544 .54303 Mdot
.5124 .31483 Mdot
.66962 .39165 Mdot
.29393 .48289 Mdot
.29463 .60705 Mdot
.69044 .60176 Mdot
.64305 .30262 Mdot
.38627 .48587 Mdot
.61048 .68029 Mdot
.661 .60322 Mdot
.32504 .65506 Mdot
.66432 .31592 Mdot
.43469 .296 Mdot
.3959 .46701 Mdot
.66447 .60426 Mdot
.53038 .69089 Mdot
.66495 .60414 Mdot
.32315 .48853 Mdot
.27708 .49814 Mdot
.6297 .67459 Mdot
.40782 .27555 Mdot
.3228 .64477 Mdot
.32121 .50761 Mdot
.66331 .32768 Mdot
.62467 .66565 Mdot
.37981 .27314 Mdot
.32239 .62887 Mdot
.52976 .31057 Mdot
.43953 .30716 Mdot
.36421 .50532 Mdot
.30924 .64668 Mdot
.4679 .32066 Mdot
.69886 .57577 Mdot
.39863 .2736 Mdot
.67937 .43893 Mdot
.59769 .69797 Mdot
.72041 .52974 Mdot
.51755 .2995 Mdot
.73634 .53754 Mdot
.29326 .58661 Mdot
.51402 .30929 Mdot
.71267 .52215 Mdot
.32638 .28941 Mdot
.53009 .33191 Mdot
.67689 .37628 Mdot
.2889 .50894 Mdot
.31534 .64659 Mdot
.33998 .50767 Mdot
.37928 .28287 Mdot
.62849 .69421 Mdot
.73162 .50413 Mdot
.70505 .5607 Mdot
.33383 .51689 Mdot
.48295 .70938 Mdot
.64378 .65216 Mdot
.49383 .31545 Mdot
.40042 .29323 Mdot
.38869 .29391 Mdot
.34205 .52008 Mdot
.30242 .6099 Mdot
.49065 .69428 Mdot
.34624 .50945 Mdot
.34291 .5207 Mdot
.65783 .29918 Mdot
.48857 .68461 Mdot
.70234 .40419 Mdot
.41222 .67926 Mdot
.39 .47336 Mdot
.71929 .54279 Mdot
.69098 .57213 Mdot
.50642 .33161 Mdot
.70382 .55919 Mdot
.65107 .3012 Mdot
.51341 .33559 Mdot
.34755 .50914 Mdot
.56794 .71045 Mdot
.34474 .51006 Mdot
.34395 .50815 Mdot
.30449 .48804 Mdot
.38928 .46723 Mdot
.70916 .42201 Mdot
.40735 .29276 Mdot
.32 .62552 Mdot
.70164 .38585 Mdot
.6682 .43447 Mdot
.26438 .50591 Mdot
.35656 .50914 Mdot
.33756 .50246 Mdot
.51595 .68792 Mdot
.38611 .67797 Mdot
.67024 .59373 Mdot
.62987 .67416 Mdot
.37157 .48443 Mdot
.67306 .30482 Mdot
.27322 .50307 Mdot
.48729 .71189 Mdot
.72523 .51769 Mdot
.65701 .66542 Mdot
.50683 .29897 Mdot
.48558 .32531 Mdot
.51963 .33727 Mdot
.54064 .31702 Mdot
.75004 .51366 Mdot
.66856 .39251 Mdot
.42356 .27352 Mdot
.37962 .47254 Mdot
.37162 .48938 Mdot
.27472 .49609 Mdot
.6563 .29133 Mdot
.49628 .34308 Mdot
.29166 .50881 Mdot
.40702 .70956 Mdot
.70048 .41718 Mdot
.53996 .32637 Mdot
.57606 .67753 Mdot
.59737 .70374 Mdot
.66557 .31134 Mdot
.74134 .53934 Mdot
.39468 .28125 Mdot
.60352 .2969 Mdot
.61564 .70574 Mdot
.4732 .67588 Mdot
.6915 .41958 Mdot
.3065 .62297 Mdot
.4329 .68078 Mdot
.68307 .40959 Mdot
.38172 .6754 Mdot
.63354 .69685 Mdot
.53538 .3197 Mdot
.29774 .62309 Mdot
.3088 .6393 Mdot
.64337 .38432 Mdot
.37027 .50874 Mdot
.72089 .39112 Mdot
.67727 .3785 Mdot
.51401 .32992 Mdot
.68065 .38122 Mdot
.6824 .56923 Mdot
.69559 .39646 Mdot
.52691 .6977 Mdot
.35202 .52221 Mdot
.4563 .70882 Mdot
.22977 .56268 Mdot
.34663 .49001 Mdot
.66334 .58999 Mdot
.72003 .52685 Mdot
.35308 .49302 Mdot
.37995 .31021 Mdot
.67257 .37913 Mdot
.65407 .31376 Mdot
.39476 .6762 Mdot
.6603 .29009 Mdot
.59049 .70522 Mdot
.72122 .53553 Mdot
.71962 .52746 Mdot
.5129 .33839 Mdot
.48073 .70679 Mdot
.74745 .50216 Mdot
.73749 .52063 Mdot
.43161 .27782 Mdot
.34459 .48355 Mdot
.54035 .68866 Mdot
.31418 .62776 Mdot
.40211 .31489 Mdot
.3462 .50598 Mdot
.70241 .40158 Mdot
.65586 .31128 Mdot
.23463 .56447 Mdot
.68203 .39388 Mdot
.50229 .33055 Mdot
.51191 .68101 Mdot
.40491 .67743 Mdot
.62265 .69819 Mdot
.37414 .5143 Mdot
.7186 .53315 Mdot
.59414 .70344 Mdot
.43821 .33434 Mdot
.32692 .50007 Mdot
.49882 .72115 Mdot
.32424 .62693 Mdot
.34222 .50646 Mdot
.65404 .39253 Mdot
.37719 .30331 Mdot
.44626 .31927 Mdot
.69512 .43053 Mdot
.42009 .30587 Mdot
.57013 .69133 Mdot
.65251 .39397 Mdot
.39838 .30438 Mdot
.55728 .29388 Mdot
.5316 .30659 Mdot
.40672 .29814 Mdot
.27521 .48778 Mdot
.69418 .58412 Mdot
.6329 .68073 Mdot
.2885 .49974 Mdot
.39476 .42005 Mdot
.45037 .70744 Mdot
.49822 .31835 Mdot
.33862 .50558 Mdot
.32818 .48948 Mdot
.48742 .70914 Mdot
.68093 .63356 Mdot
.68355 .37335 Mdot
.49169 .32462 Mdot
.61735 .70219 Mdot
.67429 .63995 Mdot
.65544 .39464 Mdot
.38625 .30096 Mdot
.69651 .56804 Mdot
.5666 .71125 Mdot
.50465 .31744 Mdot
.68158 .57589 Mdot
.69941 .4274 Mdot
.26247 .5099 Mdot
.39161 .70498 Mdot
.68258 .41966 Mdot
.26289 .51073 Mdot
.41771 .68245 Mdot
.66004 .31724 Mdot
.70561 .57154 Mdot
.60476 .70723 Mdot
.68336 .60356 Mdot
.3945 .29141 Mdot
.50228 .70286 Mdot
.6095 .70869 Mdot
.69105 .57164 Mdot
.44875 .7032 Mdot
.29672 .61618 Mdot
.72594 .53498 Mdot
.31201 .61665 Mdot
.27651 .51174 Mdot
.50702 .31911 Mdot
.41001 .28801 Mdot
.71986 .53509 Mdot
.50602 .68487 Mdot
.68027 .56133 Mdot
.25113 .50721 Mdot
.38254 .68086 Mdot
.39898 .27871 Mdot
.62174 .65565 Mdot
.70663 .56656 Mdot
.67102 .59093 Mdot
.66322 .32706 Mdot
.37455 .30675 Mdot
.27859 .48519 Mdot
.64711 .2831 Mdot
.2812 .49288 Mdot
.65986 .6084 Mdot
.41448 .67751 Mdot
.60335 .69503 Mdot
.72749 .53944 Mdot
.41834 .68808 Mdot
.32566 .63979 Mdot
.36372 .49024 Mdot
.65971 .31008 Mdot
.63914 .69008 Mdot
.53474 .34273 Mdot
.34161 .49009 Mdot
.31853 .50476 Mdot
.48765 .33199 Mdot
.25654 .52466 Mdot
.69671 .59953 Mdot
.51803 .34118 Mdot
.69755 .41733 Mdot
.53577 .32477 Mdot
.49948 .32721 Mdot
.57812 .70105 Mdot
.66253 .32103 Mdot
.48577 .32809 Mdot
.31205 .50442 Mdot
.3336 .51182 Mdot
.69129 .59856 Mdot
.29975 .61699 Mdot
.31037 .63522 Mdot
.6982 .3776 Mdot
.42887 .27316 Mdot
.29086 .50444 Mdot
.47881 .70301 Mdot
.38249 .27624 Mdot
.48308 .30989 Mdot
.59466 .69492 Mdot
.26305 .49173 Mdot
.6576 .29834 Mdot
.5324 .32658 Mdot
.47723 .31989 Mdot
.39872 .28138 Mdot
.66825 .61456 Mdot
.49894 .7156 Mdot
.67668 .37776 Mdot
.39719 .70402 Mdot
.41584 .25504 Mdot
.66451 .30596 Mdot
.50733 .3203 Mdot
.51696 .30794 Mdot
.48339 .70696 Mdot
.52452 .70171 Mdot
.48133 .30182 Mdot
.70142 .38401 Mdot
.7351 .4974 Mdot
.73276 .53628 Mdot
.29962 .64176 Mdot
.69555 .56365 Mdot
.60353 .7074 Mdot
.26113 .52087 Mdot
.38888 .29674 Mdot
.66807 .5908 Mdot
.51785 .33882 Mdot
.60889 .7059 Mdot
.51426 .70588 Mdot
.31936 .50963 Mdot
.35398 .50476 Mdot
.67321 .31489 Mdot
.24578 .51 Mdot
.68366 .60927 Mdot
.37707 .28814 Mdot
.66411 .38993 Mdot
.39489 .67752 Mdot
.61326 .68216 Mdot
.54285 .35431 Mdot
.32834 .63044 Mdot
.69497 .38221 Mdot
.63002 .68812 Mdot
.37449 .28195 Mdot
.4067 .29407 Mdot
.34891 .48565 Mdot
.46984 .35087 Mdot
.67156 .5816 Mdot
.48339 .70163 Mdot
.58719 .67859 Mdot
.32016 .63628 Mdot
.35445 .50873 Mdot
.38884 .6728 Mdot
.74232 .50342 Mdot
.27595 .4889 Mdot
.39044 .27878 Mdot
.63476 .69649 Mdot
.28808 .48316 Mdot
.36499 .29837 Mdot
.53311 .34338 Mdot
.52173 .31087 Mdot
.67289 .36611 Mdot
.36884 .29201 Mdot
.36793 .29931 Mdot
.36277 .29735 Mdot
.71245 .53187 Mdot
.3257 .65309 Mdot
.39933 .24865 Mdot
.3697 .50859 Mdot
.28085 .51191 Mdot
.38522 .70098 Mdot
.71771 .5503 Mdot
.66915 .30479 Mdot
.31763 .49217 Mdot
.37032 .50585 Mdot
.64335 .67309 Mdot
.41079 .70469 Mdot
.32694 .48347 Mdot
.6006 .69046 Mdot
.54533 .68606 Mdot
.65296 .37392 Mdot
.6671 .63935 Mdot
.64792 .27804 Mdot
.32039 .62069 Mdot
.31711 .61416 Mdot
.59661 .71464 Mdot
.69668 .57527 Mdot
.31671 .61546 Mdot
.66638 .61421 Mdot
.61979 .70938 Mdot
.39514 .70781 Mdot
.52754 .70047 Mdot
.43374 .3012 Mdot
.3215 .4884 Mdot
.68791 .57059 Mdot
.32177 .49015 Mdot
.69168 .56935 Mdot
.40642 .4608 Mdot
.30851 .60929 Mdot
.37935 .49263 Mdot
.26616 .48689 Mdot
.4487 .34052 Mdot
.35632 .50647 Mdot
.66197 .33166 Mdot
.61856 .68399 Mdot
.4442 .28964 Mdot
.37381 .69585 Mdot
.28789 .50816 Mdot
.34027 .50258 Mdot
.44903 .70702 Mdot
.34921 .49832 Mdot
.64966 .28057 Mdot
.32377 .62342 Mdot
.33008 .48403 Mdot
.67724 .59584 Mdot
.74105 .5289 Mdot
.57526 .71445 Mdot
.51361 .30808 Mdot
.62704 .65378 Mdot
.32792 .50819 Mdot
.66717 .37238 Mdot
.42753 .31859 Mdot
.37014 .29794 Mdot
.63151 .68312 Mdot
.32853 .30115 Mdot
.74926 .51034 Mdot
.66385 .4262 Mdot
.39201 .69785 Mdot
.70134 .4102 Mdot
.68937 .37337 Mdot
.62388 .665 Mdot
.40948 .28888 Mdot
.28464 .50491 Mdot
.5271 .70942 Mdot
.52068 .67593 Mdot
.31989 .63809 Mdot
.654 .37739 Mdot
.46849 .3213 Mdot
.35042 .67164 Mdot
.41785 .31071 Mdot
.41047 .30656 Mdot
.68965 .57664 Mdot
.66829 .37101 Mdot
.49353 .32523 Mdot
.39425 .30268 Mdot
.65037 .37583 Mdot
.52711 .30292 Mdot
.65672 .32316 Mdot
.48945 .69674 Mdot
.39367 .45677 Mdot
.50973 .72115 Mdot
.70491 .5566 Mdot
.66569 .3234 Mdot
.50098 .69097 Mdot
.47752 .70923 Mdot
.49912 .3235 Mdot
.6813 .43029 Mdot
.46081 .69446 Mdot
.33685 .48579 Mdot
.53015 .31554 Mdot
.32081 .51463 Mdot
.37793 .31146 Mdot
.33302 .50974 Mdot
.6722 .31396 Mdot
.66775 .59866 Mdot
.67433 .38672 Mdot
.68835 .57483 Mdot
.25044 .52628 Mdot
.32076 .50163 Mdot
.34969 .51168 Mdot
.30407 .62637 Mdot
.5807 .70783 Mdot
.53215 .7036 Mdot
.68925 .38052 Mdot
.67596 .38393 Mdot
.37601 .69826 Mdot
.60307 .68089 Mdot
.56005 .31981 Mdot
.31474 .61615 Mdot
.35406 .49746 Mdot
.61741 .68487 Mdot
.38065 .69656 Mdot
.74339 .49694 Mdot
.30014 .62487 Mdot
.58302 .70484 Mdot
.64613 .30701 Mdot
.34332 .52124 Mdot
.48642 .31918 Mdot
.46137 .32014 Mdot
.32669 .61418 Mdot
.39908 .31487 Mdot
.60165 .69984 Mdot
.48819 .31188 Mdot
.62069 .68092 Mdot
.71425 .3942 Mdot
.74984 .50498 Mdot
.60645 .69044 Mdot
.34119 .50009 Mdot
.64458 .28324 Mdot
.69512 .57941 Mdot
.30773 .48585 Mdot
.72847 .53528 Mdot
.50425 .69656 Mdot
.62074 .69272 Mdot
.5267 .30268 Mdot
.3818 .67613 Mdot
.66935 .58553 Mdot
.37507 .48885 Mdot
.52995 .69822 Mdot
.41579 .69377 Mdot
.40611 .31467 Mdot
.2773 .50178 Mdot
.36399 .47833 Mdot
.66007 .33415 Mdot
.25688 .50591 Mdot
.72287 .51371 Mdot
.74899 .52157 Mdot
.73115 .50351 Mdot
.57402 .70408 Mdot
.45019 .318 Mdot
.50889 .71165 Mdot
.50437 .33249 Mdot
.67506 .42904 Mdot
.3072 .488 Mdot
.54201 .31902 Mdot
.72192 .52938 Mdot
.41272 .29659 Mdot
.3306 .63211 Mdot
.67466 .41884 Mdot
.51899 .30481 Mdot
.67372 .58473 Mdot
.51723 .68399 Mdot
.59848 .69491 Mdot
.65118 .31683 Mdot
.29496 .48245 Mdot
.35186 .50606 Mdot
.72735 .52154 Mdot
.48351 .35533 Mdot
.41592 .30696 Mdot
.53753 .33344 Mdot
.7269 .52481 Mdot
.30081 .62101 Mdot
.50909 .69479 Mdot
.32724 .48704 Mdot
.30425 .61906 Mdot
.7166 .52271 Mdot
.53996 .67845 Mdot
.42478 .30328 Mdot
.39169 .47791 Mdot
.60369 .70006 Mdot
.68287 .58997 Mdot
.56151 .29875 Mdot
.40152 .67253 Mdot
.37291 .49603 Mdot
.32702 .47293 Mdot
.30531 .64313 Mdot
.39934 .70036 Mdot
.51061 .29904 Mdot
.33727 .47579 Mdot
.37399 .69524 Mdot
.40513 .70464 Mdot
.27348 .4991 Mdot
.27032 .49902 Mdot
.61803 .68805 Mdot
.30321 .65453 Mdot
.69824 .40382 Mdot
.38084 .67391 Mdot
.53477 .35665 Mdot
.39402 .69595 Mdot
.2958 .63956 Mdot
.55104 .68056 Mdot
.31096 .59646 Mdot
.62856 .70533 Mdot
.58682 .68787 Mdot
.70468 .55687 Mdot
.41563 .69076 Mdot
.6948 .38159 Mdot
.47231 .31857 Mdot
.66744 .3044 Mdot
.61997 .68683 Mdot
.65073 .37896 Mdot
.72547 .55415 Mdot
.6823 .41982 Mdot
.70234 .41395 Mdot
.66613 .59964 Mdot
.63462 .67725 Mdot
.32732 .63039 Mdot
.66443 .59924 Mdot
.4804 .3267 Mdot
.3875 .30014 Mdot
.52066 .6766 Mdot
.52995 .33868 Mdot
.38629 .4841 Mdot
.71109 .51784 Mdot
.67456 .42434 Mdot
.32132 .47144 Mdot
.60623 .67467 Mdot
.37237 .2793 Mdot
.60852 .69212 Mdot
.5078 .29721 Mdot
.43014 .29486 Mdot
.27324 .48637 Mdot
.52855 .35806 Mdot
.70416 .57734 Mdot
.28004 .50564 Mdot
.54876 .6875 Mdot
.66751 .30579 Mdot
.67296 .57513 Mdot
.68676 .61594 Mdot
.48836 .32089 Mdot
.5847 .70084 Mdot
.52034 .70705 Mdot
.51106 .3341 Mdot
.68098 .59002 Mdot
.45964 .70865 Mdot
.34049 .48728 Mdot
.69765 .56087 Mdot
.28673 .50373 Mdot
.3992 .46372 Mdot
.39491 .27044 Mdot
.53837 .31737 Mdot
.40866 .70636 Mdot
.65633 .40276 Mdot
.37983 .70198 Mdot
.39004 .49561 Mdot
.24334 .51439 Mdot
.36753 .49723 Mdot
.31614 .47139 Mdot
.6503 .29801 Mdot
.58334 .7163 Mdot
.52455 .31973 Mdot
.50361 .3195 Mdot
.41778 .694 Mdot
.63859 .27213 Mdot
.40796 .30232 Mdot
.65409 .32341 Mdot
.32203 .50314 Mdot
.35845 .50054 Mdot
.51513 .6996 Mdot
.39884 .45473 Mdot
.53705 .32131 Mdot
.36797 .49444 Mdot
.31938 .60566 Mdot
.68118 .5966 Mdot
.36073 .47904 Mdot
.34032 .51985 Mdot
.74735 .50144 Mdot
.67945 .59406 Mdot
.66031 .30491 Mdot
.53321 .30693 Mdot
.67551 .3656 Mdot
.41713 .30919 Mdot
.32785 .4747 Mdot
.25593 .52258 Mdot
.2949 .62606 Mdot
.427 .30689 Mdot
.39586 .69307 Mdot
.39535 .49175 Mdot
.3664 .5158 Mdot
.40996 .30593 Mdot
.70013 .57253 Mdot
.61354 .68655 Mdot
.39869 .46143 Mdot
.50316 .32086 Mdot
.40454 .70365 Mdot
.3657 .30423 Mdot
.62185 .68139 Mdot
.5166 .71754 Mdot
.62769 .69144 Mdot
.67527 .58625 Mdot
.66382 .31739 Mdot
.43044 .29397 Mdot
.60754 .69225 Mdot
.65152 .402 Mdot
.72026 .53905 Mdot
.30469 .64913 Mdot
.70402 .56687 Mdot
.62458 .66506 Mdot
.58082 .69869 Mdot
.5832 .68602 Mdot
.39764 .67494 Mdot
.3135 .47085 Mdot
.50096 .33129 Mdot
.72599 .52452 Mdot
.65898 .40691 Mdot
.24816 .51187 Mdot
.53445 .7075 Mdot
.26482 .4752 Mdot
.26963 .48707 Mdot
.33229 .51027 Mdot
.35565 .51644 Mdot
.49791 .29986 Mdot
.38177 .48858 Mdot
.36785 .51016 Mdot
.68253 .6107 Mdot
.66298 .30569 Mdot
.31817 .50264 Mdot
.52188 .31189 Mdot
.43364 .27172 Mdot
.37278 .27855 Mdot
.39316 .46998 Mdot
.45485 .68197 Mdot
.60917 .68559 Mdot
.70453 .38972 Mdot
.66009 .37136 Mdot
.38305 .28082 Mdot
.67801 .6038 Mdot
.62855 .69664 Mdot
.64377 .30468 Mdot
.42973 .29036 Mdot
.29794 .49389 Mdot
.30403 .62792 Mdot
.30903 .59515 Mdot
.31255 .64776 Mdot
.30507 .48869 Mdot
.5301 .335 Mdot
.70567 .38789 Mdot
.31488 .65482 Mdot
.49275 .72126 Mdot
.3719 .305 Mdot
.38137 .29941 Mdot
.49934 .6792 Mdot
.38737 .49964 Mdot
.68524 .57151 Mdot
.30383 .61052 Mdot
.65204 .61319 Mdot
.64351 .65589 Mdot
.39021 .24647 Mdot
.27269 .50307 Mdot
.2691 .50594 Mdot
.37788 .48383 Mdot
.4892 .68065 Mdot
.53587 .69298 Mdot
.50805 .68552 Mdot
.68182 .59761 Mdot
.27262 .5101 Mdot
.74044 .51274 Mdot
.53679 .31988 Mdot
.59547 .70248 Mdot
.33176 .66353 Mdot
.67605 .38455 Mdot
.40374 .70644 Mdot
.41137 .28264 Mdot
.31606 .63594 Mdot
.51766 .31521 Mdot
.37252 .47565 Mdot
.66952 .39314 Mdot
.50666 .69241 Mdot
.39771 .70679 Mdot
.70239 .42814 Mdot
.33578 .47602 Mdot
.46537 .32829 Mdot
.54351 .32386 Mdot
.43318 .3006 Mdot
.27246 .50716 Mdot
.40427 .27649 Mdot
.67044 .58508 Mdot
.32079 .50013 Mdot
.33253 .48403 Mdot
.34326 .50378 Mdot
.2722 .4905 Mdot
.68805 .59196 Mdot
.41264 .68982 Mdot
.48119 .33207 Mdot
.5379 .31115 Mdot
.39561 .69774 Mdot
.41351 .29088 Mdot
.73351 .5351 Mdot
.66137 .30304 Mdot
.50207 .33978 Mdot
.43594 .29323 Mdot
.28248 .50621 Mdot
.35367 .49525 Mdot
.5336 .30998 Mdot
.27432 .48786 Mdot
.40453 .68143 Mdot
.69023 .41487 Mdot
.40929 .69872 Mdot
.36821 .2876 Mdot
.40809 .28077 Mdot
.69328 .5863 Mdot
.60595 .69196 Mdot
.38398 .28362 Mdot
.66458 .39534 Mdot
.36116 .48157 Mdot
.27477 .501 Mdot
.5268 .69913 Mdot
.24751 .50474 Mdot
.36738 .2891 Mdot
.27734 .48578 Mdot
.48456 .68739 Mdot
.45328 .69938 Mdot
.37266 .49699 Mdot
.40049 .68385 Mdot
.57771 .69871 Mdot
.39048 .30156 Mdot
.67557 .60675 Mdot
.22245 .54669 Mdot
.66714 .61335 Mdot
.50561 .68454 Mdot
.48845 .31513 Mdot
.63301 .67237 Mdot
.48694 .31591 Mdot
.54367 .67435 Mdot
.34721 .5217 Mdot
.52935 .69453 Mdot
.47647 .3327 Mdot
.68907 .37914 Mdot
.69004 .42794 Mdot
.53147 .32611 Mdot
.59868 .70072 Mdot
.50696 .3306 Mdot
.39155 .28594 Mdot
.71198 .53964 Mdot
.58389 .68921 Mdot
.70038 .41654 Mdot
.67418 .42349 Mdot
.72655 .52074 Mdot
.33558 .50716 Mdot
.32936 .48745 Mdot
.68131 .41757 Mdot
.6522 .61047 Mdot
.59682 .71263 Mdot
.35146 .50702 Mdot
.5118 .34123 Mdot
.69549 .40784 Mdot
.7525 .53228 Mdot
.50943 .70264 Mdot
.40126 .70835 Mdot
.24332 .5155 Mdot
.74878 .51779 Mdot
.35535 .48052 Mdot
.40014 .68066 Mdot
.39389 .30786 Mdot
.38493 .47647 Mdot
.28186 .51262 Mdot
.7462 .52264 Mdot
.48779 .32727 Mdot
.31437 .64791 Mdot
.71545 .41025 Mdot
.34219 .48155 Mdot
.32767 .27419 Mdot
.53458 .31124 Mdot
.29274 .49588 Mdot
.50779 .34568 Mdot
.622 .69789 Mdot
.34989 .5034 Mdot
.71962 .54158 Mdot
.69625 .38534 Mdot
.29499 .48258 Mdot
.43749 .33533 Mdot
.72668 .54131 Mdot
.51612 .31421 Mdot
.41899 .30584 Mdot
.38314 .69202 Mdot
.24434 .52696 Mdot
.65604 .2914 Mdot
.40373 .29658 Mdot
.33446 .50556 Mdot
.66501 .38647 Mdot
.73937 .533 Mdot
.52751 .32248 Mdot
.2873 .50696 Mdot
.73645 .5259 Mdot
.6736 .6011 Mdot
.40858 .27815 Mdot
.57131 .72621 Mdot
.35 .52454 Mdot
.32544 .51373 Mdot
.55271 .7116 Mdot
.51811 .70569 Mdot
.31936 .48873 Mdot
.30933 .50918 Mdot
.68225 .5748 Mdot
.24016 .49224 Mdot
.37025 .4754 Mdot
.4745 .33158 Mdot
.67237 .57508 Mdot
.66015 .3681 Mdot
.6741 .42708 Mdot
.39612 .29638 Mdot
.63134 .69052 Mdot
.39967 .27198 Mdot
.69749 .39186 Mdot
.30538 .50004 Mdot
.66295 .60975 Mdot
.38861 .7139 Mdot
.72621 .53275 Mdot
.66771 .404 Mdot
.49074 .71092 Mdot
.29064 .61663 Mdot
.32712 .27639 Mdot
.65166 .63069 Mdot
.65101 .31366 Mdot
.37083 .29858 Mdot
.49244 .72122 Mdot
.3289 .50348 Mdot
.30418 .65194 Mdot
.29622 .48343 Mdot
.45302 .31705 Mdot
.66231 .29426 Mdot
.52718 .30291 Mdot
.4887 .32178 Mdot
.32049 .47404 Mdot
.67321 .60229 Mdot
.7452 .5123 Mdot
.49849 .30702 Mdot
.67549 .58882 Mdot
.3172 .51043 Mdot
.67443 .40511 Mdot
.56802 .6783 Mdot
.35255 .49752 Mdot
.4257 .27307 Mdot
.73072 .55159 Mdot
.478 .71167 Mdot
.65706 .37103 Mdot
.27 .50591 Mdot
.63575 .65038 Mdot
.66588 .59298 Mdot
.38831 .46937 Mdot
.69352 .38298 Mdot
.50363 .34002 Mdot
.66724 .38155 Mdot
.29824 .49764 Mdot
.26832 .50223 Mdot
.48572 .33009 Mdot
.35159 .49854 Mdot
.59066 .72195 Mdot
.39861 .67158 Mdot
.40148 .7117 Mdot
.36994 .50893 Mdot
.55199 .69081 Mdot
.73341 .54391 Mdot
.49586 .30732 Mdot
.30529 .64358 Mdot
.2622 .49315 Mdot
.57297 .70162 Mdot
.73361 .53697 Mdot
.68618 .62835 Mdot
.68473 .59424 Mdot
.6902 .37851 Mdot
.67593 .60419 Mdot
.37643 .48331 Mdot
.61433 .71213 Mdot
.68825 .39672 Mdot
.50958 .31487 Mdot
.65207 .40983 Mdot
.34245 .49031 Mdot
.73093 .55312 Mdot
.66722 .42707 Mdot
.38602 .6745 Mdot
.62061 .70766 Mdot
.50918 .35912 Mdot
.45865 .6795 Mdot
.30526 .50082 Mdot
.29884 .48442 Mdot
.53827 .33219 Mdot
.69166 .58883 Mdot
.51283 .70505 Mdot
.65915 .32542 Mdot
.37047 .28337 Mdot
.62724 .70634 Mdot
.38294 .27429 Mdot
.30668 .62357 Mdot
.54889 .69706 Mdot
.31964 .60619 Mdot
.69274 .57254 Mdot
.59804 .69719 Mdot
.36613 .3069 Mdot
.37633 .67223 Mdot
.40516 .2881 Mdot
.65643 .37806 Mdot
.31764 .61524 Mdot
.6964 .41558 Mdot
.71867 .5265 Mdot
.65808 .3119 Mdot
.66969 .58193 Mdot
.44023 .33616 Mdot
.41366 .67684 Mdot
.74447 .53287 Mdot
.71575 .54467 Mdot
.70219 .39774 Mdot
.50906 .30657 Mdot
.41075 .69243 Mdot
.477 .3092 Mdot
.50194 .30324 Mdot
.74732 .51334 Mdot
.59598 .69421 Mdot
.60629 .6805 Mdot
.44249 .28753 Mdot
.59871 .69234 Mdot
.68705 .40825 Mdot
.30124 .62539 Mdot
.28916 .64142 Mdot
.7327 .54511 Mdot
.384 .69372 Mdot
.38231 .4807 Mdot
.66297 .28809 Mdot
.67986 .40705 Mdot
.67858 .59978 Mdot
.59904 .67108 Mdot
.48507 .31259 Mdot
.50707 .70415 Mdot
.61426 .70488 Mdot
.61873 .69752 Mdot
.63298 .66855 Mdot
.26458 .50979 Mdot
.66369 .58889 Mdot
.60319 .70139 Mdot
.29136 .50272 Mdot
.32902 .5193 Mdot
.5035 .3386 Mdot
.45127 .31867 Mdot
.40514 .68641 Mdot
.49871 .33041 Mdot
.35952 .49198 Mdot
.6806 .38148 Mdot
.4439 .32394 Mdot
.48091 .31734 Mdot
.69992 .38354 Mdot
.70164 .38365 Mdot
.48521 .30569 Mdot
.44517 .32252 Mdot
.58635 .72114 Mdot
.3877 .66334 Mdot
.54834 .68833 Mdot
.66978 .43071 Mdot
.72612 .50855 Mdot
.52837 .6969 Mdot
.3024 .4829 Mdot
.52156 .34267 Mdot
.67178 .39434 Mdot
.58861 .6842 Mdot
.35558 .51166 Mdot
.50144 .32438 Mdot
.39823 .28855 Mdot
.50959 .31302 Mdot
.53164 .3349 Mdot
.53539 .68559 Mdot
.69736 .53066 Mdot
.48451 .70931 Mdot
.7057 .42289 Mdot
.51784 .31906 Mdot
.45274 .70512 Mdot
.66843 .32301 Mdot
.71094 .54178 Mdot
.39733 .67034 Mdot
.37446 .50528 Mdot
.70501 .39079 Mdot
.59057 .70546 Mdot
.69762 .59026 Mdot
.31383 .59985 Mdot
.60636 .69299 Mdot
.52026 .29978 Mdot
.53356 .32898 Mdot
.69708 .40689 Mdot
.52018 .6836 Mdot
.39902 .681 Mdot
.60935 .6973 Mdot
.73017 .52086 Mdot
.27716 .48312 Mdot
.62673 .65359 Mdot
.49491 .32555 Mdot
.60786 .68295 Mdot
.6601 .40591 Mdot
.39146 .27787 Mdot
.27897 .4899 Mdot
.6656 .64511 Mdot
.3369 .50378 Mdot
.72898 .51798 Mdot
.41848 .26268 Mdot
.37545 .68688 Mdot
.3007 .48973 Mdot
.30134 .64544 Mdot
.71684 .54861 Mdot
.30628 .49159 Mdot
.29216 .61799 Mdot
.51013 .72004 Mdot
.49686 .70015 Mdot
.32095 .50421 Mdot
.68333 .4151 Mdot
.72347 .39047 Mdot
.33454 .51827 Mdot
.70344 .42972 Mdot
.30295 .60839 Mdot
.47306 .31694 Mdot
.41146 .31478 Mdot
.26099 .5205 Mdot
.28941 .49059 Mdot
.37865 .49265 Mdot
.276 .48288 Mdot
.30191 .59097 Mdot
.69668 .38802 Mdot
.67496 .36689 Mdot
.38948 .28909 Mdot
.33626 .47272 Mdot
.40472 .27999 Mdot
.73864 .53476 Mdot
.41755 .68462 Mdot
.54372 .31793 Mdot
.60431 .68899 Mdot
.34661 .50219 Mdot
.65775 .3839 Mdot
.293 .49501 Mdot
.3892 .68368 Mdot
.69082 .40799 Mdot
.67252 .38916 Mdot
.72031 .39541 Mdot
.36641 .29545 Mdot
.62759 .68362 Mdot
.36468 .48484 Mdot
.38321 .31007 Mdot
.47957 .32295 Mdot
.22367 .55776 Mdot
.63181 .70085 Mdot
.61893 .67998 Mdot
.62692 .6725 Mdot
.37438 .48727 Mdot
.37295 .48625 Mdot
.73389 .51391 Mdot
.52324 .7078 Mdot
.65912 .6077 Mdot
.70704 .39596 Mdot
.71742 .41462 Mdot
.29063 .49302 Mdot
.43067 .28166 Mdot
.41257 .28939 Mdot
.65962 .41978 Mdot
.54088 .32394 Mdot
.39825 .27429 Mdot
.36483 .4868 Mdot
.70125 .40583 Mdot
.36653 .30227 Mdot
.61786 .66477 Mdot
.67975 .6276 Mdot
.39525 .27579 Mdot
.49081 .32502 Mdot
.52003 .71427 Mdot
.25603 .51587 Mdot
.39037 .27137 Mdot
.73651 .54057 Mdot
.3285 .63054 Mdot
.54006 .32072 Mdot
.42755 .28464 Mdot
.23526 .49917 Mdot
.69428 .3965 Mdot
.48938 .32485 Mdot
.36847 .30991 Mdot
.293 .64882 Mdot
.41088 .27603 Mdot
.61473 .68047 Mdot
.4489 .69138 Mdot
.29361 .48753 Mdot
.38072 .68243 Mdot
.70396 .56231 Mdot
.65485 .37978 Mdot
.66383 .37145 Mdot
.52583 .69033 Mdot
.29906 .63382 Mdot
.68703 .41954 Mdot
.30135 .64275 Mdot
.44252 .30486 Mdot
.29079 .50276 Mdot
.44294 .2864 Mdot
.37449 .67537 Mdot
.36016 .30129 Mdot
.39341 .27667 Mdot
.72743 .54973 Mdot
.66892 .59831 Mdot
.69126 .58733 Mdot
.69105 .41702 Mdot
.30982 .62981 Mdot
.67271 .36826 Mdot
.56031 .72171 Mdot
.40596 .30203 Mdot
.64507 .30299 Mdot
.38369 .48589 Mdot
.36367 .49125 Mdot
.38726 .70297 Mdot
.52247 .34034 Mdot
.30173 .49904 Mdot
.73611 .5216 Mdot
.65156 .40266 Mdot
.728 .55506 Mdot
.5074 .68178 Mdot
.55646 .71917 Mdot
.67557 .38774 Mdot
.4478 .30011 Mdot
.41331 .28501 Mdot
.22681 .509 Mdot
.45795 .3244 Mdot
.67776 .37649 Mdot
.37336 .51397 Mdot
.58202 .68982 Mdot
.64576 .31587 Mdot
.34678 .50449 Mdot
.67188 .42435 Mdot
.67073 .32645 Mdot
.37645 .67891 Mdot
.25773 .50537 Mdot
.70518 .57161 Mdot
.30265 .63891 Mdot
.36283 .29263 Mdot
.48679 .33205 Mdot
.33582 .663 Mdot
.69899 .39243 Mdot
.64735 .39887 Mdot
.38169 .27803 Mdot
.48104 .71225 Mdot
.59763 .68136 Mdot
.58479 .72032 Mdot
.73491 .51816 Mdot
.35866 .51961 Mdot
.70034 .40472 Mdot
.49944 .70948 Mdot
.37028 .47826 Mdot
.68429 .57771 Mdot
.65818 .42096 Mdot
.35153 .49871 Mdot
.29962 .49104 Mdot
.40134 .28125 Mdot
.43258 .27066 Mdot
.48677 .33716 Mdot
.71017 .54602 Mdot
.28176 .47259 Mdot
.41792 .68728 Mdot
.37324 .49655 Mdot
.58925 .71218 Mdot
.50999 .33276 Mdot
.40969 .28955 Mdot
.32823 .48189 Mdot
.29646 .64451 Mdot
.58205 .69978 Mdot
.691 .57149 Mdot
.5112 .31904 Mdot
.29783 .47081 Mdot
.34525 .50033 Mdot
.28795 .48484 Mdot
.39738 .67496 Mdot
.38597 .48961 Mdot
.66827 .30253 Mdot
.47745 .70417 Mdot
.39911 .31124 Mdot
.62357 .69212 Mdot
.66136 .32286 Mdot
.40219 .67189 Mdot
.3173 .62531 Mdot
.55186 .69364 Mdot
.62307 .70724 Mdot
.72856 .52114 Mdot
.66312 .59249 Mdot
.43287 .28132 Mdot
.28991 .49875 Mdot
.53486 .3138 Mdot
.61011 .70105 Mdot
.65609 .3782 Mdot
.40522 .2793 Mdot
.6499 .31327 Mdot
.36883 .4978 Mdot
.70042 .39759 Mdot
.52761 .32658 Mdot
.51392 .68077 Mdot
.6841 .38233 Mdot
.50447 .34009 Mdot
.38699 .30206 Mdot
.32641 .63737 Mdot
.45483 .31314 Mdot
.49005 .31636 Mdot
.28531 .49782 Mdot
.36544 .69377 Mdot
.38159 .68779 Mdot
.4716 .32858 Mdot
.65152 .37324 Mdot
.49427 .32081 Mdot
.47838 .71444 Mdot
.37782 .67936 Mdot
.6553 .40153 Mdot
.52732 .70179 Mdot
.39547 .67043 Mdot
.48735 .31422 Mdot
.63397 .69764 Mdot
.66403 .32724 Mdot
.58221 .68413 Mdot
.27517 .51616 Mdot
.3468 .51803 Mdot
.69562 .41683 Mdot
.40302 .28798 Mdot
.73978 .50892 Mdot
.75168 .51936 Mdot
.71726 .54488 Mdot
.7095 .40882 Mdot
.34989 .50082 Mdot
.60117 .69883 Mdot
.6673 .59378 Mdot
.51583 .70194 Mdot
.66248 .39389 Mdot
.67692 .41044 Mdot
.38992 .70358 Mdot
.40736 .27972 Mdot
.38288 .48628 Mdot
.65688 .37798 Mdot
.66141 .31128 Mdot
.45935 .70932 Mdot
.36202 .29835 Mdot
.4086 .67846 Mdot
.45872 .31111 Mdot
.34921 .47852 Mdot
.52994 .7138 Mdot
.53444 .32461 Mdot
.51299 .68176 Mdot
.32192 .49294 Mdot
.72466 .47585 Mdot
.66862 .32166 Mdot
.30111 .63842 Mdot
.70482 .57493 Mdot
.66248 .60011 Mdot
.68845 .38474 Mdot
.35964 .50655 Mdot
.64845 .31022 Mdot
.39487 .29608 Mdot
.37075 .68831 Mdot
.49482 .30682 Mdot
.52182 .70091 Mdot
.66653 .60914 Mdot
.43802 .33077 Mdot
.73969 .50914 Mdot
.69322 .58211 Mdot
.55144 .68427 Mdot
.2932 .48818 Mdot
.67767 .39449 Mdot
.67503 .41512 Mdot
.44341 .28803 Mdot
.65422 .28132 Mdot
.6118 .67328 Mdot
.72227 .47478 Mdot
.3169 .658 Mdot
.32778 .50061 Mdot
.5145 .29909 Mdot
.5327 .31401 Mdot
.66052 .31745 Mdot
.30734 .49114 Mdot
.49605 .69258 Mdot
.66759 .36723 Mdot
.68119 .42623 Mdot
.38341 .67844 Mdot
.66742 .59846 Mdot
.46232 .3304 Mdot
.68381 .40741 Mdot
.22359 .55007 Mdot
.28834 .49314 Mdot
.65146 .62722 Mdot
.68561 .4062 Mdot
.64727 .27333 Mdot
.73691 .49671 Mdot
.49108 .70876 Mdot
.32437 .64904 Mdot
.50742 .69888 Mdot
.40119 .2754 Mdot
.67308 .37227 Mdot
.74421 .52013 Mdot
.51483 .31657 Mdot
.72254 .38672 Mdot
.69244 .41901 Mdot
.61842 .68673 Mdot
.29255 .48548 Mdot
.39618 .47208 Mdot
.34622 .49906 Mdot
.23985 .49133 Mdot
.36526 .2901 Mdot
.75179 .51961 Mdot
.72698 .52272 Mdot
.32422 .64948 Mdot
.36539 .30078 Mdot
.69 .37579 Mdot
.69218 .4068 Mdot
.66606 .64274 Mdot
.53187 .3343 Mdot
.68546 .37283 Mdot
.28346 .49679 Mdot
.72086 .39778 Mdot
.53673 .70579 Mdot
.66753 .60098 Mdot
.26648 .49023 Mdot
.69562 .41859 Mdot
.53779 .68477 Mdot
.30624 .63252 Mdot
.33193 .51684 Mdot
.49499 .34438 Mdot
.66465 .5921 Mdot
.55146 .71878 Mdot
.66451 .2899 Mdot
.34818 .52119 Mdot
.73769 .53163 Mdot
.46494 .34804 Mdot
.7185 .37837 Mdot
.63108 .68627 Mdot
.67333 .42282 Mdot
.67318 .60783 Mdot
.5229 .32592 Mdot
.40136 .31163 Mdot
.67092 .37912 Mdot
.67558 .42877 Mdot
.3944 .69169 Mdot
.44606 .29664 Mdot
.38686 .27232 Mdot
.60219 .71195 Mdot
.68364 .57351 Mdot
.38669 .68251 Mdot
.22163 .54173 Mdot
.3701 .4853 Mdot
.69404 .58448 Mdot
.46523 .71593 Mdot
.36375 .51914 Mdot
.37116 .50289 Mdot
.38847 .47103 Mdot
.48695 .71537 Mdot
.59774 .7057 Mdot
.28262 .47099 Mdot
.40097 .68565 Mdot
.313 .62432 Mdot
.61132 .68552 Mdot
.62406 .68713 Mdot
.31638 .63293 Mdot
.39192 .68961 Mdot
.5309 .70086 Mdot
.67173 .5935 Mdot
.66249 .59961 Mdot
.62049 .69724 Mdot
.38482 .70174 Mdot
.6966 .57438 Mdot
.51446 .69532 Mdot
.66964 .40477 Mdot
.29973 .6125 Mdot
.62637 .69855 Mdot
.3144 .61281 Mdot
.67102 .58444 Mdot
.2199 .53109 Mdot
.30289 .60785 Mdot
.38284 .49622 Mdot
.29675 .48777 Mdot
.37314 .30231 Mdot
.51339 .31337 Mdot
.48528 .30556 Mdot
.69054 .59055 Mdot
.38068 .48776 Mdot
.50535 .68606 Mdot
.37691 .48667 Mdot
.24502 .51037 Mdot
.22212 .52739 Mdot
.32667 .65886 Mdot
.62966 .68865 Mdot
.50569 .68515 Mdot
.71317 .41672 Mdot
.65037 .39118 Mdot
.29314 .63252 Mdot
.66376 .59486 Mdot
.60214 .68493 Mdot
.65944 .60741 Mdot
.69799 .39323 Mdot
.67546 .39326 Mdot
.50516 .33475 Mdot
.48937 .32536 Mdot
.6879 .38961 Mdot
.70053 .42971 Mdot
.22006 .54369 Mdot
.5258 .70168 Mdot
.49129 .72333 Mdot
.24768 .52406 Mdot
.39951 .46317 Mdot
.40104 .28917 Mdot
.44214 .32358 Mdot
.73798 .52367 Mdot
.30774 .64926 Mdot
.33653 .49379 Mdot
.49403 .31485 Mdot
.70335 .55755 Mdot
.41913 .29711 Mdot
.66498 .60096 Mdot
.40965 .3095 Mdot
.65636 .40217 Mdot
.35722 .49992 Mdot
.3786 .4949 Mdot
.72909 .52314 Mdot
.7181 .4036 Mdot
.70187 .40756 Mdot
.40462 .29106 Mdot
.25021 .52241 Mdot
.69795 .40328 Mdot
.62671 .69942 Mdot
.64428 .65959 Mdot
.53186 .32102 Mdot
.35692 .50994 Mdot
.25592 .52023 Mdot
.37846 .67789 Mdot
.47888 .32107 Mdot
.51044 .31932 Mdot
.57399 .72691 Mdot
.33802 .48557 Mdot
.68659 .62967 Mdot
.48603 .3262 Mdot
.63144 .67314 Mdot
.67982 .39283 Mdot
.4795 .31697 Mdot
.46522 .31625 Mdot
.34731 .25342 Mdot
.48632 .30353 Mdot
.5888 .69605 Mdot
.50574 .69594 Mdot
.40924 .69537 Mdot
.47319 .7237 Mdot
.42975 .30445 Mdot
.41379 .29481 Mdot
.66953 .32003 Mdot
.72064 .54384 Mdot
.37984 .47267 Mdot
.40478 .29978 Mdot
.60263 .67093 Mdot
.39755 .70544 Mdot
.3961 .70024 Mdot
.40079 .69786 Mdot
.51386 .70037 Mdot
.27094 .5038 Mdot
.665 .29971 Mdot
.61672 .68617 Mdot
.40876 .69951 Mdot
.3897 .50039 Mdot
.58195 .71583 Mdot
.68881 .57356 Mdot
.37993 .70439 Mdot
.60134 .69689 Mdot
.31822 .60306 Mdot
.67533 .57731 Mdot
.29931 .64579 Mdot
.6593 .43998 Mdot
.6442 .273 Mdot
.67637 .59882 Mdot
.65945 .42213 Mdot
.70216 .39997 Mdot
.69081 .4129 Mdot
.60419 .70608 Mdot
.68669 .43052 Mdot
.50084 .68477 Mdot
.65095 .31304 Mdot
.30646 .47119 Mdot
.43053 .29475 Mdot
.65932 .30913 Mdot
.619 .69675 Mdot
.55109 .71337 Mdot
.32625 .28999 Mdot
.33865 .52165 Mdot
.74594 .52713 Mdot
.38741 .29288 Mdot
.30224 .62515 Mdot
.39272 .30793 Mdot
.69516 .38353 Mdot
.31489 .47417 Mdot
.28888 .49273 Mdot
.68218 .62747 Mdot
.40338 .28627 Mdot
.62539 .68821 Mdot
.39589 .69411 Mdot
.66449 .36386 Mdot
.39696 .29589 Mdot
.40883 .28127 Mdot
.32711 .51381 Mdot
.50753 .69476 Mdot
.70739 .3927 Mdot
.68566 .56607 Mdot
.66459 .33234 Mdot
.25174 .57511 Mdot
.33601 .48504 Mdot
.34766 .52212 Mdot
.30622 .62066 Mdot
.65756 .31962 Mdot
.67562 .59286 Mdot
.24656 .50592 Mdot
.66689 .28772 Mdot
.24314 .51195 Mdot
.49382 .67922 Mdot
.65438 .30851 Mdot
.53027 .3176 Mdot
.50214 .33856 Mdot
.34818 .50906 Mdot
.3257 .2796 Mdot
.28088 .50911 Mdot
.6971 .56917 Mdot
.51486 .30919 Mdot
.66817 .43199 Mdot
.59458 .68104 Mdot
.3432 .25583 Mdot
.40404 .68412 Mdot
.68654 .56612 Mdot
.69513 .40421 Mdot
.332 .26485 Mdot
.3727 .29818 Mdot
.29645 .60683 Mdot
.32726 .51909 Mdot
.34962 .51029 Mdot
.68846 .58224 Mdot
.69991 .56921 Mdot
.51629 .72009 Mdot
.46824 .307 Mdot
.64057 .65235 Mdot
.72423 .53391 Mdot
.33431 .26223 Mdot
.53277 .31162 Mdot
.48713 .6992 Mdot
.51082 .29978 Mdot
.70424 .56346 Mdot
.32029 .49107 Mdot
.50688 .69578 Mdot
.52853 .32872 Mdot
.46539 .67942 Mdot
.38714 .69594 Mdot
.22316 .55093 Mdot
.3306 .51042 Mdot
.61674 .67506 Mdot
.61609 .68405 Mdot
.50657 .68795 Mdot
.52792 .33349 Mdot
.36838 .49478 Mdot
.36508 .51239 Mdot
.36006 .51822 Mdot
.46245 .71263 Mdot
.35334 .50138 Mdot
.59099 .67993 Mdot
.29517 .61776 Mdot
.7305 .47858 Mdot
.3771 .49371 Mdot
.68203 .60149 Mdot
.33993 .51111 Mdot
.37534 .2767 Mdot
.32315 .64379 Mdot
.38273 .67323 Mdot
.67869 .5875 Mdot
.38975 .49522 Mdot
.5347 .35655 Mdot
.36103 .48591 Mdot
.42186 .307 Mdot
.73407 .50131 Mdot
.26734 .51219 Mdot
.46103 .70979 Mdot
.61312 .69682 Mdot
.66174 .3848 Mdot
.68561 .6076 Mdot
.68815 .37846 Mdot
.38437 .66291 Mdot
.52843 .30577 Mdot
.64585 .3071 Mdot
.22134 .53824 Mdot
.3204 .49184 Mdot
.53924 .33025 Mdot
.51284 .68542 Mdot
.66745 .30692 Mdot
.3987 .45618 Mdot
.38925 .7039 Mdot
.38397 .27832 Mdot
.39092 .30572 Mdot
.41643 .2557 Mdot
.50493 .70693 Mdot
.55339 .70854 Mdot
.68726 .58127 Mdot
.68989 .41975 Mdot
.36121 .30054 Mdot
.66013 .66937 Mdot
.69996 .57838 Mdot
.66291 .31624 Mdot
.66566 .60818 Mdot
.37334 .49385 Mdot
.4829 .30684 Mdot
.50239 .7178 Mdot
.49839 .30922 Mdot
.3595 .48165 Mdot
.68724 .42592 Mdot
.53531 .32883 Mdot
.38108 .30859 Mdot
.68025 .60535 Mdot
.67735 .38372 Mdot
.2892 .48584 Mdot
.61446 .68287 Mdot
.3479 .66833 Mdot
.6606 .28061 Mdot
.38551 .67274 Mdot
.38731 .67172 Mdot
.48815 .71829 Mdot
.47327 .32218 Mdot
.70548 .35944 Mdot
.37908 .67219 Mdot
.71749 .53375 Mdot
.42217 .27587 Mdot
.64629 .29185 Mdot
.66616 .37206 Mdot
.68988 .398 Mdot
.33295 .48904 Mdot
.67399 .36495 Mdot
.31808 .63991 Mdot
.66157 .36532 Mdot
.74223 .50033 Mdot
.27734 .5054 Mdot
.69009 .40606 Mdot
.48465 .3237 Mdot
.28126 .49399 Mdot
.4944 .6999 Mdot
.68722 .37005 Mdot
.38296 .49624 Mdot
.69151 .43577 Mdot
.72874 .52023 Mdot
.52377 .33572 Mdot
.32818 .62441 Mdot
.67192 .5894 Mdot
.58913 .69994 Mdot
.33274 .64191 Mdot
.39769 .29945 Mdot
.49477 .68877 Mdot
.42651 .27502 Mdot
.41091 .28034 Mdot
.30517 .61397 Mdot
.6148 .7103 Mdot
.52548 .31186 Mdot
.38967 .30371 Mdot
.41757 .31333 Mdot
.69194 .39773 Mdot
.67305 .31401 Mdot
.4923 .32201 Mdot
.28587 .48533 Mdot
.65227 .29702 Mdot
.67559 .60269 Mdot
.32987 .51848 Mdot
.69768 .41195 Mdot
.52146 .31228 Mdot
.36644 .50776 Mdot
.40225 .68578 Mdot
.50574 .72024 Mdot
.4745 .30556 Mdot
.42418 .30412 Mdot
.5004 .69705 Mdot
.34517 .52181 Mdot
.43463 .3022 Mdot
.66574 .33061 Mdot
.27391 .49618 Mdot
.63242 .68339 Mdot
.61131 .6673 Mdot
.65605 .37648 Mdot
.69014 .56991 Mdot
.67238 .41531 Mdot
.41408 .3098 Mdot
.32588 .29211 Mdot
.4972 .33147 Mdot
.3717 .68039 Mdot
.32163 .64 Mdot
.66361 .37806 Mdot
.62663 .68386 Mdot
.6547 .654 Mdot
.32437 .64237 Mdot
.27641 .49711 Mdot
.35238 .51232 Mdot
.65595 .3145 Mdot
.59341 .68297 Mdot
.35479 .51145 Mdot
.44799 .32079 Mdot
.27284 .50131 Mdot
.38927 .28466 Mdot
.64413 .41477 Mdot
.49739 .33883 Mdot
.45733 .71057 Mdot
.52773 .33145 Mdot
.6857 .41043 Mdot
.3214 .60569 Mdot
.31029 .62545 Mdot
.38643 .24605 Mdot
.58749 .69707 Mdot
.54027 .68463 Mdot
.67657 .3968 Mdot
.66245 .32413 Mdot
.40711 .68476 Mdot
.39851 .69265 Mdot
.28323 .49351 Mdot
.69454 .38334 Mdot
.64595 .38938 Mdot
.52061 .30269 Mdot
.53866 .32739 Mdot
.29209 .63647 Mdot
.65744 .39896 Mdot
.35681 .50038 Mdot
.3806 .69444 Mdot
.69903 .5846 Mdot
.49983 .7033 Mdot
.74145 .53928 Mdot
.69971 .58426 Mdot
.39421 .45962 Mdot
.26796 .47609 Mdot
.73612 .51698 Mdot
.72142 .55153 Mdot
.66583 .31718 Mdot
.29221 .64378 Mdot
.39834 .2763 Mdot
.24213 .49134 Mdot
.68864 .37736 Mdot
.3566 .494 Mdot
.61986 .66979 Mdot
.49888 .29811 Mdot
.66222 .65908 Mdot
.37389 .38877 Mdot
.4132 .68741 Mdot
.65877 .29461 Mdot
.48952 .31546 Mdot
.4989 .30748 Mdot
.25385 .51526 Mdot
.3565 .50157 Mdot
.65703 .37555 Mdot
.29314 .6484 Mdot
.72456 .53464 Mdot
.66548 .32039 Mdot
.50431 .70897 Mdot
.3424 .50906 Mdot
.57425 .71031 Mdot
.68984 .59897 Mdot
.42088 .28234 Mdot
.36823 .29705 Mdot
.35784 .48675 Mdot
.39853 .67026 Mdot
.71764 .52763 Mdot
.40393 .69032 Mdot
.39067 .68541 Mdot
.49832 .32201 Mdot
.40717 .67731 Mdot
.32743 .5201 Mdot
.35528 .52479 Mdot
.47949 .32311 Mdot
.70094 .57732 Mdot
.29156 .50881 Mdot
.48774 .31321 Mdot
.32883 .63969 Mdot
.67833 .61169 Mdot
.40535 .68842 Mdot
.68478 .59486 Mdot
.66291 .31878 Mdot
.73202 .51981 Mdot
.39767 .31114 Mdot
.66245 .31227 Mdot
.49257 .7231 Mdot
.60068 .6981 Mdot
.66134 .5942 Mdot
.38645 .30094 Mdot
.68119 .59972 Mdot
.67421 .37979 Mdot
.72088 .52602 Mdot
.45302 .69865 Mdot
.22625 .5555 Mdot
.39254 .46252 Mdot
.65354 .60473 Mdot
.65154 .39615 Mdot
.61948 .69784 Mdot
.71925 .5445 Mdot
.32586 .63049 Mdot
.37176 .29556 Mdot
.3462 .51089 Mdot
.68377 .60348 Mdot
.65851 .30371 Mdot
.5292 .71237 Mdot
.40883 .3085 Mdot
.55464 .72079 Mdot
.65763 .38872 Mdot
.27892 .50354 Mdot
.74949 .50499 Mdot
.71378 .3688 Mdot
.72814 .5246 Mdot
.39503 .47839 Mdot
.53776 .3164 Mdot
.46452 .31 Mdot
.54171 .69145 Mdot
.5411 .33032 Mdot
.45086 .34358 Mdot
.71553 .54114 Mdot
.48035 .70598 Mdot
.70953 .42 Mdot
.28487 .48496 Mdot
.41659 .68927 Mdot
.50029 .32975 Mdot
.60766 .6793 Mdot
.39556 .67494 Mdot
.50508 .33619 Mdot
.29559 .61665 Mdot
.50469 .69992 Mdot
.69405 .37604 Mdot
.28502 .49692 Mdot
.74959 .51039 Mdot
.72791 .53745 Mdot
.52197 .30026 Mdot
.74226 .51113 Mdot
.32858 .64031 Mdot
.61874 .7086 Mdot
.40954 .69311 Mdot
.38849 .28612 Mdot
.5931 .72142 Mdot
.49066 .30002 Mdot
.35525 .2505 Mdot
.28379 .49886 Mdot
.67659 .39463 Mdot
.71951 .38203 Mdot
.29208 .6327 Mdot
.6117 .68726 Mdot
.31765 .64374 Mdot
.40038 .6749 Mdot
.40157 .69139 Mdot
.69029 .41944 Mdot
.30441 .62381 Mdot
.35431 .50061 Mdot
.68477 .56823 Mdot
.28511 .5845 Mdot
.39501 .48835 Mdot
.44811 .31803 Mdot
.38239 .67348 Mdot
.74431 .50405 Mdot
.52397 .70349 Mdot
.67882 .39577 Mdot
.49338 .69225 Mdot
.51652 .70566 Mdot
.59648 .70314 Mdot
.65858 .66998 Mdot
.37891 .67279 Mdot
.67394 .63923 Mdot
.53823 .70494 Mdot
.39867 .46741 Mdot
.60691 .67258 Mdot
.6889 .3493 Mdot
.47952 .70537 Mdot
.58859 .69943 Mdot
.56903 .67767 Mdot
.59443 .6829 Mdot
.28626 .48919 Mdot
.26333 .49168 Mdot
.3219 .66186 Mdot
.65097 .31012 Mdot
.34843 .49824 Mdot
.48019 .30693 Mdot
.38398 .28807 Mdot
.48304 .71208 Mdot
.51161 .3169 Mdot
.30856 .61225 Mdot
.54285 .33844 Mdot
.32052 .51131 Mdot
.36334 .50813 Mdot
.40205 .69623 Mdot
.22236 .52212 Mdot
.64846 .30422 Mdot
.6279 .67523 Mdot
.39502 .49005 Mdot
.71956 .37973 Mdot
.2968 .50071 Mdot
.31771 .6458 Mdot
.36234 .52187 Mdot
.67761 .39443 Mdot
.50959 .71118 Mdot
.49948 .30328 Mdot
.57346 .71603 Mdot
.33342 .50567 Mdot
.55802 .32415 Mdot
.43458 .28973 Mdot
.35918 .50898 Mdot
.57878 .7157 Mdot
.39746 .67466 Mdot
.58667 .7051 Mdot
.60465 .71497 Mdot
.27629 .49751 Mdot
.4959 .71185 Mdot
.59871 .70676 Mdot
.3989 .69191 Mdot
.6579 .29485 Mdot
.7113 .54157 Mdot
.30261 .50098 Mdot
.40867 .30797 Mdot
.30522 .48955 Mdot
.40975 .27624 Mdot
.47985 .30965 Mdot
.49174 .3186 Mdot
.27448 .50746 Mdot
.65145 .40578 Mdot
.39561 .27151 Mdot
.64997 .306 Mdot
.44639 .70582 Mdot
.54807 .68604 Mdot
.72296 .53404 Mdot
.6734 .31295 Mdot
.49366 .31973 Mdot
.28649 .51201 Mdot
.25543 .57579 Mdot
.73906 .513 Mdot
.50974 .67982 Mdot
.28729 .50786 Mdot
.53645 .3348 Mdot
.69787 .37762 Mdot
.67605 .41407 Mdot
.71582 .53923 Mdot
.56482 .67872 Mdot
.37098 .49041 Mdot
.53581 .33478 Mdot
.40008 .71221 Mdot
.51477 .31323 Mdot
.50497 .3015 Mdot
.66114 .42576 Mdot
.36605 .49918 Mdot
.30776 .60906 Mdot
.70349 .39486 Mdot
.41698 .28906 Mdot
.51838 .68198 Mdot
.42779 .30588 Mdot
.68383 .62397 Mdot
.50878 .72159 Mdot
.69131 .38727 Mdot
.50505 .34126 Mdot
.34575 .49661 Mdot
.51301 .70525 Mdot
.51673 .68735 Mdot
.49462 .70364 Mdot
.38743 .2891 Mdot
.66336 .37058 Mdot
.6604 .32955 Mdot
.29071 .48762 Mdot
.6258 .7047 Mdot
.34845 .25272 Mdot
.30121 .49185 Mdot
.6637 .59689 Mdot
.39123 .67491 Mdot
.62735 .69359 Mdot
.37255 .68671 Mdot
.54862 .69576 Mdot
.68046 .41445 Mdot
.34802 .48857 Mdot
.28204 .48941 Mdot
.26588 .51159 Mdot
.41849 .29791 Mdot
.58085 .69653 Mdot
.27497 .47341 Mdot
.34909 .47854 Mdot
.25769 .51776 Mdot
.3591 .51271 Mdot
.39177 .46347 Mdot
.46328 .32354 Mdot
.49871 .33432 Mdot
.3227 .63572 Mdot
.33497 .51653 Mdot
.58577 .71767 Mdot
.51299 .71693 Mdot
.43548 .68174 Mdot
.69526 .5809 Mdot
.47827 .70672 Mdot
.70387 .39155 Mdot
.69181 .37186 Mdot
.71738 .411 Mdot
.39261 .31351 Mdot
.40773 .68854 Mdot
.33942 .492 Mdot
.69592 .5707 Mdot
.39714 .30124 Mdot
.62648 .70574 Mdot
.40722 .27804 Mdot
.30115 .64051 Mdot
.39276 .31 Mdot
.53051 .30548 Mdot
.73926 .49664 Mdot
.38096 .69461 Mdot
.4248 .29261 Mdot
.49939 .69981 Mdot
.28291 .50978 Mdot
.25817 .50197 Mdot
.55003 .71409 Mdot
.38627 .27581 Mdot
.66479 .333 Mdot
.29096 .50087 Mdot
.32789 .47178 Mdot
.68866 .59176 Mdot
.40133 .31142 Mdot
.66134 .60536 Mdot
.39336 .6787 Mdot
.5329 .68189 Mdot
.61514 .69035 Mdot
.72536 .53885 Mdot
.31747 .6451 Mdot
.39587 .312 Mdot
.69082 .39074 Mdot
.29857 .65258 Mdot
.64712 .30312 Mdot
.52154 .34708 Mdot
.26261 .51578 Mdot
.66616 .29972 Mdot
.3924 .49567 Mdot
.73282 .52985 Mdot
.37764 .48402 Mdot
.37389 .68263 Mdot
.32729 .4794 Mdot
.70638 .40167 Mdot
.68926 .39863 Mdot
.64829 .31308 Mdot
.34279 .48446 Mdot
.38394 .50856 Mdot
.52084 .69914 Mdot
.66082 .37262 Mdot
.60539 .70409 Mdot
.61445 .67673 Mdot
.66136 .42434 Mdot
.58232 .70697 Mdot
.40838 .28053 Mdot
.32161 .47597 Mdot
.73287 .5292 Mdot
.72626 .52688 Mdot
.68838 .38811 Mdot
.66887 .42941 Mdot
.67598 .39306 Mdot
.39482 .67653 Mdot
.61383 .7098 Mdot
.25136 .48326 Mdot
.32911 .51244 Mdot
.38115 .49003 Mdot
.5057 .70957 Mdot
.32564 .63929 Mdot
.39822 .42708 Mdot
.38673 .27842 Mdot
.68382 .40885 Mdot
.66756 .61197 Mdot
.35006 .67229 Mdot
.69033 .56678 Mdot
.27047 .49939 Mdot
.71505 .52934 Mdot
.50544 .68003 Mdot
.38363 .30689 Mdot
.38016 .68368 Mdot
.37016 .30282 Mdot
.69913 .5837 Mdot
.51933 .69007 Mdot
.30047 .62876 Mdot
.27439 .50384 Mdot
.31016 .63363 Mdot
.55785 .29554 Mdot
.54869 .69783 Mdot
.67747 .5779 Mdot
.38148 .6917 Mdot
.51847 .3467 Mdot
.41644 .71012 Mdot
.33023 .48995 Mdot
.39044 .48748 Mdot
.37979 .47429 Mdot
.2652 .48925 Mdot
.49054 .70939 Mdot
.3095 .64448 Mdot
.51253 .34146 Mdot
.27665 .48793 Mdot
.6696 .63713 Mdot
.32766 .50278 Mdot
.37996 .49456 Mdot
.3497 .49262 Mdot
.39274 .48476 Mdot
.4784 .71373 Mdot
.40182 .69863 Mdot
.6913 .56814 Mdot
.34052 .47558 Mdot
.72449 .54568 Mdot
.68381 .38637 Mdot
.48358 .3009 Mdot
.49217 .71568 Mdot
.36936 .30165 Mdot
.69101 .61385 Mdot
.3215 .47189 Mdot
.71425 .4171 Mdot
.24907 .50464 Mdot
.45271 .31494 Mdot
.48919 .30495 Mdot
.39905 .31303 Mdot
.69453 .4201 Mdot
.67269 .59811 Mdot
.37166 .51497 Mdot
.61022 .70259 Mdot
.59792 .69201 Mdot
.27553 .4902 Mdot
.70538 .54902 Mdot
.72798 .537 Mdot
.66035 .30936 Mdot
.37132 .49124 Mdot
.2665 .48969 Mdot
.58803 .71111 Mdot
.6672 .32713 Mdot
.31358 .62059 Mdot
.40282 .29402 Mdot
.30972 .50875 Mdot
.52081 .34172 Mdot
.30767 .64156 Mdot
.69371 .57165 Mdot
.52591 .31547 Mdot
.32053 .49867 Mdot
.26656 .47614 Mdot
.37405 .69599 Mdot
.44001 .28051 Mdot
.64907 .38272 Mdot
.27896 .49851 Mdot
.29168 .49715 Mdot
.50557 .70062 Mdot
.7307 .52156 Mdot
.6277 .6839 Mdot
.45497 .70104 Mdot
.49219 .31882 Mdot
.72814 .51932 Mdot
.38397 .48152 Mdot
.74042 .5037 Mdot
.39019 .67459 Mdot
.30531 .50064 Mdot
.67923 .57681 Mdot
.59115 .71548 Mdot
.62328 .65538 Mdot
.26426 .50455 Mdot
.38971 .68282 Mdot
.30476 .4901 Mdot
.66643 .32473 Mdot
.5038 .29757 Mdot
.27359 .50318 Mdot
.59987 .68704 Mdot
.2992 .49115 Mdot
.69651 .58875 Mdot
.42717 .2883 Mdot
.60789 .68939 Mdot
.66021 .2929 Mdot
.68388 .41836 Mdot
.65221 .38474 Mdot
.53004 .30575 Mdot
.40311 .6754 Mdot
.50098 .69179 Mdot
.6318 .68085 Mdot
.31343 .63765 Mdot
.68602 .41016 Mdot
.39637 .28668 Mdot
.28704 .48181 Mdot
.52163 .34237 Mdot
.74979 .51499 Mdot
.46636 .71801 Mdot
.2943 .61962 Mdot
.42406 .3096 Mdot
.27045 .57934 Mdot
.50095 .32059 Mdot
.3707 .49873 Mdot
.39886 .31166 Mdot
.66914 .42698 Mdot
.37833 .70127 Mdot
.46026 .32517 Mdot
.65046 .30086 Mdot
.70342 .41608 Mdot
.72541 .54228 Mdot
.652 .37452 Mdot
.37016 .30518 Mdot
.48809 .32767 Mdot
.60191 .69256 Mdot
.36031 .50494 Mdot
.50098 .32666 Mdot
.67491 .40582 Mdot
.53068 .3089 Mdot
.37752 .50235 Mdot
.56896 .70625 Mdot
.67935 .37892 Mdot
.29424 .49454 Mdot
.37701 .67417 Mdot
.49453 .72143 Mdot
.66115 .30049 Mdot
.31702 .64245 Mdot
.362 .30556 Mdot
.71549 .40769 Mdot
.70488 .40541 Mdot
.2712 .49395 Mdot
.37538 .29053 Mdot
.33588 .50807 Mdot
.66918 .59776 Mdot
.33134 .62746 Mdot
.72898 .52307 Mdot
.24459 .51334 Mdot
.27117 .48583 Mdot
.32105 .65374 Mdot
.52199 .67665 Mdot
.4953 .35858 Mdot
.24284 .52242 Mdot
.36549 .51278 Mdot
.6126 .67115 Mdot
.31669 .61312 Mdot
.2306 .5625 Mdot
.50707 .71377 Mdot
.4326 .2919 Mdot
.68966 .59246 Mdot
.29309 .48202 Mdot
.68095 .63058 Mdot
.39079 .28477 Mdot
.25138 .51517 Mdot
.29013 .62564 Mdot
.62477 .68593 Mdot
.34846 .49002 Mdot
.61047 .69423 Mdot
.31388 .49526 Mdot
.48833 .72079 Mdot
.7185 .5404 Mdot
.38211 .47593 Mdot
.48684 .32577 Mdot
.71403 .36936 Mdot
.39393 .46324 Mdot
.40207 .28241 Mdot
.37384 .68621 Mdot
.49627 .31688 Mdot
.66505 .60107 Mdot
.71167 .55137 Mdot
.67546 .39446 Mdot
.68878 .56364 Mdot
.48453 .69934 Mdot
.65884 .305 Mdot
.53692 .31947 Mdot
.38763 .70916 Mdot
.36131 .29498 Mdot
.72836 .51822 Mdot
.35116 .51613 Mdot
.373 .48584 Mdot
.65557 .31448 Mdot
.64547 .41993 Mdot
.5683 .69895 Mdot
.50565 .72276 Mdot
.51826 .69109 Mdot
.41723 .29455 Mdot
.65863 .29969 Mdot
.32759 .49372 Mdot
.35882 .49742 Mdot
.68845 .42875 Mdot
.50774 .71122 Mdot
.38112 .29112 Mdot
.46561 .30947 Mdot
.6967 .57059 Mdot
.64712 .31671 Mdot
.60622 .69045 Mdot
.64384 .29914 Mdot
.66138 .32892 Mdot
.57737 .67626 Mdot
.24599 .52215 Mdot
.67311 .5912 Mdot
.64432 .29457 Mdot
.62962 .69126 Mdot
.26906 .50128 Mdot
.51171 .30867 Mdot
.53173 .30736 Mdot
.54761 .69337 Mdot
.68672 .38231 Mdot
.37524 .28742 Mdot
.3377 .48808 Mdot
.42329 .31244 Mdot
.51401 .70775 Mdot
.65545 .39329 Mdot
.52293 .32022 Mdot
.67469 .61313 Mdot
.30078 .49001 Mdot
.3858 .28742 Mdot
.67512 .58943 Mdot
.50079 .33848 Mdot
.32589 .47468 Mdot
.33255 .64099 Mdot
.38714 .67075 Mdot
.68837 .59009 Mdot
.31402 .62945 Mdot
.31799 .51286 Mdot
.73285 .53024 Mdot
.42776 .27504 Mdot
.70805 .36317 Mdot
.33065 .63011 Mdot
.71548 .54163 Mdot
.68976 .42966 Mdot
.65157 .37346 Mdot
.67428 .31265 Mdot
.64857 .30377 Mdot
.72993 .54098 Mdot
.51338 .32361 Mdot
.65233 .32389 Mdot
.73046 .52206 Mdot
.30692 .64722 Mdot
.29212 .48221 Mdot
.28978 .64272 Mdot
.49897 .33905 Mdot
.52053 .33524 Mdot
.52054 .71071 Mdot
.39545 .70175 Mdot
.52041 .3185 Mdot
.34505 .51963 Mdot
.51302 .68686 Mdot
.67283 .58106 Mdot
.34063 .25692 Mdot
.70056 .56636 Mdot
.37939 .70308 Mdot
.71521 .39548 Mdot
.66121 .30605 Mdot
.35923 .50591 Mdot
.69949 .59428 Mdot
.33361 .26305 Mdot
.29478 .48213 Mdot
.3801 .68374 Mdot
.24326 .51167 Mdot
.27613 .48844 Mdot
.47862 .69277 Mdot
.52733 .33798 Mdot
.50834 .68791 Mdot
.67449 .58663 Mdot
.42799 .28705 Mdot
.44556 .33983 Mdot
.69077 .58863 Mdot
.33217 .5032 Mdot
.51561 .29817 Mdot
.35088 .51064 Mdot
.36382 .5171 Mdot
.35461 .47726 Mdot
.44022 .30698 Mdot
.67762 .38681 Mdot
.36739 .30067 Mdot
.58824 .69199 Mdot
.46698 .7169 Mdot
.39936 .28209 Mdot
.29578 .6486 Mdot
.31106 .61579 Mdot
.64916 .42618 Mdot
.5986 .69128 Mdot
.40429 .27535 Mdot
.68549 .59897 Mdot
.24049 .57216 Mdot
.30543 .65486 Mdot
.6834 .56769 Mdot
.37429 .50435 Mdot
.63214 .6796 Mdot
.51624 .71125 Mdot
.72374 .52026 Mdot
.63191 .68497 Mdot
.31309 .62665 Mdot
.39518 .67981 Mdot
.69444 .57134 Mdot
.24748 .52982 Mdot
.72704 .52269 Mdot
.39455 .45107 Mdot
.38534 .68223 Mdot
.61023 .68839 Mdot
.39504 .471 Mdot
.5926 .71937 Mdot
.50965 .33555 Mdot
.34618 .47765 Mdot
.3985 .28581 Mdot
.3107 .63148 Mdot
.66104 .28884 Mdot
.49948 .67771 Mdot
.62329 .69501 Mdot
.704 .5682 Mdot
.62288 .68052 Mdot
.54263 .6885 Mdot
.65289 .60582 Mdot
.47829 .70287 Mdot
.33359 .50505 Mdot
.47935 .72675 Mdot
.49733 .69198 Mdot
.68408 .58032 Mdot
.39204 .29462 Mdot
.49567 .70625 Mdot
.65985 .32468 Mdot
.28237 .49603 Mdot
.6629 .39761 Mdot
.38014 .27509 Mdot
.49118 .71467 Mdot
.40185 .28465 Mdot
.67232 .39964 Mdot
.45182 .3161 Mdot
.74783 .53102 Mdot
.73747 .50626 Mdot
.46305 .31465 Mdot
.71603 .53455 Mdot
.59169 .68611 Mdot
.65097 .29421 Mdot
.35496 .48429 Mdot
.36911 .49155 Mdot
.37384 .27756 Mdot
.58975 .68422 Mdot
.71158 .53313 Mdot
.51348 .31677 Mdot
.53022 .70024 Mdot
.67323 .61194 Mdot
.66374 .31008 Mdot
.31091 .61031 Mdot
.72354 .54189 Mdot
.50849 .34184 Mdot
.49794 .31994 Mdot
.35221 .51267 Mdot
.25484 .51003 Mdot
.41169 .30902 Mdot
.68723 .34971 Mdot
.41164 .70319 Mdot
.66934 .43082 Mdot
.33945 .4964 Mdot
.40947 .70031 Mdot
.33652 .52171 Mdot
.36573 .30414 Mdot
.72956 .54383 Mdot
.59746 .69598 Mdot
.4181 .27929 Mdot
.68346 .4189 Mdot
.31915 .60577 Mdot
.25854 .4989 Mdot
.31825 .63086 Mdot
.70155 .38403 Mdot
.60333 .67757 Mdot
.68445 .3938 Mdot
.73304 .53184 Mdot
.40345 .27897 Mdot
.39543 .67528 Mdot
.49852 .33935 Mdot
.66484 .37606 Mdot
.6615 .59286 Mdot
.65832 .29041 Mdot
.71252 .55123 Mdot
.4935 .31825 Mdot
.32463 .62499 Mdot
.674 .36458 Mdot
.50641 .3062 Mdot
.53928 .69929 Mdot
.29309 .46938 Mdot
.55231 .68008 Mdot
.69341 .3822 Mdot
.38275 .24589 Mdot
.6784 .58506 Mdot
.72379 .55314 Mdot
.39935 .45978 Mdot
.32597 .27851 Mdot
.36779 .47819 Mdot
.73047 .50233 Mdot
.73263 .52756 Mdot
.68543 .59052 Mdot
.68221 .39565 Mdot
.58316 .71445 Mdot
.46724 .67799 Mdot
.69323 .37698 Mdot
.26423 .52202 Mdot
.62642 .70574 Mdot
.32077 .66116 Mdot
.67572 .36724 Mdot
.39981 .69388 Mdot
.53782 .70818 Mdot
.39636 .27313 Mdot
.2689 .51494 Mdot
.7256 .53795 Mdot
.3053 .48524 Mdot
.67542 .64028 Mdot
.67736 .39986 Mdot
.51853 .30539 Mdot
.70402 .57224 Mdot
.3774 .48728 Mdot
.35278 .49406 Mdot
.32183 .50872 Mdot
.37313 .27962 Mdot
.53391 .70623 Mdot
.32079 .48886 Mdot
.31286 .47338 Mdot
.41838 .69215 Mdot
.67284 .30568 Mdot
.37217 .30504 Mdot
.24 .49396 Mdot
.69526 .4322 Mdot
.52849 .70429 Mdot
.386 .48643 Mdot
.73149 .54581 Mdot
.39825 .7016 Mdot
.68776 .57298 Mdot
.66601 .61408 Mdot
.64747 .32008 Mdot
.60285 .6834 Mdot
.41439 .68824 Mdot
.64627 .39785 Mdot
.5069 .6746 Mdot
.41206 .69437 Mdot
.49466 .72381 Mdot
.7017 .57422 Mdot
.32519 .29132 Mdot
.73281 .54722 Mdot
.53407 .30937 Mdot
.4826 .69866 Mdot
.64404 .66925 Mdot
.30932 .64152 Mdot
.61128 .70662 Mdot
.65494 .31274 Mdot
.50161 .69048 Mdot
.60955 .28895 Mdot
.51855 .68796 Mdot
.68197 .58526 Mdot
.72542 .52183 Mdot
.40673 .69347 Mdot
.33929 .50385 Mdot
.2992 .62265 Mdot
.51381 .31624 Mdot
.32466 .62798 Mdot
.70334 .39574 Mdot
.65737 .32469 Mdot
.73824 .49781 Mdot
.48026 .69342 Mdot
.67136 .57473 Mdot
.35066 .49427 Mdot
.38605 .68078 Mdot
.26304 .49162 Mdot
.72078 .5383 Mdot
.43123 .70531 Mdot
.33221 .51301 Mdot
.4073 .68932 Mdot
.7025 .38139 Mdot
.67306 .43486 Mdot
.55976 .67877 Mdot
.64817 .32109 Mdot
.36397 .51211 Mdot
.40985 .29885 Mdot
.38707 .31296 Mdot
.26132 .50203 Mdot
.71995 .38695 Mdot
.31249 .62021 Mdot
.34946 .51654 Mdot
.32175 .6072 Mdot
.6985 .37767 Mdot
.54428 .32168 Mdot
.678 .40871 Mdot
.4791 .71595 Mdot
.48544 .30463 Mdot
.70018 .40688 Mdot
.30174 .61033 Mdot
.49819 .32422 Mdot
.7053 .36129 Mdot
.38787 .28392 Mdot
.3332 .51922 Mdot
.40532 .4529 Mdot
.6658 .3683 Mdot
.67793 .59299 Mdot
.48894 .70555 Mdot
.68899 .56956 Mdot
.68239 .43457 Mdot
.2516 .51828 Mdot
.50811 .33834 Mdot
.71654 .55458 Mdot
.41959 .68162 Mdot
.40427 .30151 Mdot
.73663 .54501 Mdot
.40669 .67622 Mdot
.2586 .50123 Mdot
.32999 .26815 Mdot
.37884 .49086 Mdot
.6558 .32394 Mdot
.72979 .51773 Mdot
.44672 .29885 Mdot
.35951 .50301 Mdot
.65972 .40077 Mdot
.41648 .31412 Mdot
.3465 .51305 Mdot
.66291 .29557 Mdot
.29347 .49689 Mdot
.39947 .31136 Mdot
.50505 .69813 Mdot
.33186 .62728 Mdot
.36094 .28506 Mdot
.41878 .28008 Mdot
.37718 .47439 Mdot
.26241 .49021 Mdot
.67873 .34484 Mdot
.62462 .68472 Mdot
.27596 .50157 Mdot
.36923 .2808 Mdot
.50546 .68312 Mdot
.49199 .69286 Mdot
.37689 .70045 Mdot
.68272 .61009 Mdot
.68283 .38146 Mdot
.4003 .30678 Mdot
.66528 .32814 Mdot
.29599 .48361 Mdot
.37551 .69294 Mdot
.39256 .27874 Mdot
.6647 .59383 Mdot
.4046 .67827 Mdot
.71156 .52403 Mdot
.33904 .47545 Mdot
.73427 .54795 Mdot
.38655 .48463 Mdot
.39308 .47324 Mdot
.50818 .69201 Mdot
.67094 .63962 Mdot
.71583 .54717 Mdot
.67858 .41646 Mdot
.52231 .32107 Mdot
.46825 .71846 Mdot
.38699 .28809 Mdot
.46598 .67644 Mdot
.37656 .49678 Mdot
.3237 .49476 Mdot
.50548 .69157 Mdot
.25706 .49893 Mdot
.48879 .68484 Mdot
.66327 .32546 Mdot
.3253 .28028 Mdot
.60227 .69543 Mdot
.62265 .69053 Mdot
.37189 .66204 Mdot
.72145 .39895 Mdot
.51883 .68172 Mdot
.29463 .48178 Mdot
.67481 .43497 Mdot
.44068 .28229 Mdot
.38443 .29672 Mdot
.44647 .30083 Mdot
.51119 .67926 Mdot
.28941 .61851 Mdot
.3888 .67285 Mdot
.27698 .50711 Mdot
.27505 .58064 Mdot
.73413 .53049 Mdot
.32758 .48268 Mdot
.50736 .31727 Mdot
.67605 .40415 Mdot
.38649 .50374 Mdot
.34303 .52002 Mdot
.59646 .69807 Mdot
.42641 .28162 Mdot
.65889 .59063 Mdot
.50417 .30486 Mdot
.65926 .37019 Mdot
.41147 .28918 Mdot
.58037 .70681 Mdot
.39646 .4622 Mdot
.47573 .31836 Mdot
.5376 .33219 Mdot
.37 .50796 Mdot
.27843 .49919 Mdot
.48664 .33647 Mdot
.69054 .57876 Mdot
.67632 .41585 Mdot
.49197 .30578 Mdot
.31078 .62843 Mdot
.32827 .61763 Mdot
.36187 .4954 Mdot
.59919 .71825 Mdot
.66011 .5969 Mdot
.51416 .33718 Mdot
.64533 .29425 Mdot
.28543 .48183 Mdot
.30119 .64836 Mdot
.56129 .31551 Mdot
.51041 .32015 Mdot
.4688 .67714 Mdot
.37244 .30149 Mdot
.38549 .68281 Mdot
.3333 .47371 Mdot
.32784 .63821 Mdot
.37967 .48401 Mdot
.67217 .42788 Mdot
.67451 .6089 Mdot
.46169 .31858 Mdot
.68427 .40803 Mdot
.49244 .69293 Mdot
.27477 .50705 Mdot
.61286 .67571 Mdot
.6302 .68004 Mdot
.5453 .6881 Mdot
.69468 .58601 Mdot
.45807 .71109 Mdot
.48462 .33373 Mdot
.37433 .49156 Mdot
.73705 .52132 Mdot
.52139 .6814 Mdot
.32473 .64787 Mdot
.50356 .6801 Mdot
.58304 .6927 Mdot
.33019 .64091 Mdot
.40255 .6862 Mdot
.31298 .47236 Mdot
.3896 .49087 Mdot
.37032 .29466 Mdot
.63891 .68748 Mdot
.30552 .65245 Mdot
.32274 .49247 Mdot
.36402 .50357 Mdot
.40564 .69576 Mdot
.43744 .30756 Mdot
.25217 .5012 Mdot
.37514 .49603 Mdot
.23736 .49662 Mdot
.32312 .64762 Mdot
.60328 .67462 Mdot
.75116 .52101 Mdot
.37688 .70106 Mdot
.71003 .41517 Mdot
.51305 .70339 Mdot
.40307 .27296 Mdot
.47316 .68676 Mdot
.39019 .6687 Mdot
.67846 .60117 Mdot
.62729 .6934 Mdot
.67255 .37856 Mdot
.67492 .59408 Mdot
.72699 .52285 Mdot
.40228 .69743 Mdot
.67363 .42022 Mdot
.43128 .28589 Mdot
.72487 .5441 Mdot
.41869 .7102 Mdot
.68182 .58645 Mdot
.5687 .68241 Mdot
.32337 .6232 Mdot
.32971 .47398 Mdot
.5144 .32785 Mdot
.46269 .32229 Mdot
.73163 .53425 Mdot
.40057 .29434 Mdot
.40674 .67942 Mdot
.49356 .7046 Mdot
.40096 .29936 Mdot
.53155 .71099 Mdot
.66522 .30868 Mdot
.52132 .70692 Mdot
.65799 .3167 Mdot
.60754 .7085 Mdot
.26673 .51542 Mdot
.42097 .27921 Mdot
.49638 .34338 Mdot
.29794 .63615 Mdot
.52546 .32178 Mdot
.3847 .50183 Mdot
.41182 .68449 Mdot
.33194 .50537 Mdot
.71729 .41464 Mdot
.37581 .27514 Mdot
.50191 .68877 Mdot
.43596 .33182 Mdot
.67095 .5805 Mdot
.31664 .6326 Mdot
.51324 .30372 Mdot
.38904 .68197 Mdot
.49642 .68271 Mdot
.59113 .70406 Mdot
.48434 .71975 Mdot
.71533 .4096 Mdot
.48477 .35536 Mdot
.35176 .49623 Mdot
.43862 .32766 Mdot
.73037 .52805 Mdot
.71613 .53061 Mdot
.66466 .38677 Mdot
.32878 .30224 Mdot
.68738 .40814 Mdot
.43413 .27265 Mdot
.60316 .70931 Mdot
.42623 .30229 Mdot
.34161 .50042 Mdot
.49902 .71206 Mdot
.46594 .67821 Mdot
.42519 .27681 Mdot
.37179 .30341 Mdot
.71786 .52897 Mdot
.73591 .51642 Mdot
.53106 .3135 Mdot
.32188 .64779 Mdot
.3223 .6511 Mdot
.36478 .48526 Mdot
.73359 .53585 Mdot
.39515 .68452 Mdot
.7492 .5298 Mdot
.37977 .68825 Mdot
.37168 .27717 Mdot
.70419 .40923 Mdot
.72606 .47641 Mdot
.50867 .70691 Mdot
.2767 .5075 Mdot
.54783 .68407 Mdot
.29379 .47011 Mdot
.71375 .55385 Mdot
.42269 .27107 Mdot
.67912 .39041 Mdot
.68777 .61483 Mdot
.70076 .41314 Mdot
.38962 .3235 Mdot
.28625 .63053 Mdot
.70362 .57066 Mdot
.32123 .62842 Mdot
.65774 .41735 Mdot
.39 .49353 Mdot
.48632 .31071 Mdot
.51545 .29818 Mdot
.40036 .66666 Mdot
.50256 .722 Mdot
.36888 .29522 Mdot
.34163 .5001 Mdot
.55124 .69916 Mdot
.34649 .49924 Mdot
.34895 .49838 Mdot
.36343 .51801 Mdot
.723 .5347 Mdot
.32018 .62319 Mdot
.3368 .50443 Mdot
.64755 .31197 Mdot
.44504 .29019 Mdot
.66803 .36306 Mdot
.50968 .69222 Mdot
.39723 .30129 Mdot
.51705 .70323 Mdot
.30337 .62373 Mdot
.70266 .56547 Mdot
.53395 .70718 Mdot
.39519 .69077 Mdot
.49952 .67818 Mdot
.72145 .55301 Mdot
.37861 .28419 Mdot
.50238 .31772 Mdot
.65483 .65762 Mdot
.65002 .30613 Mdot
.51886 .31171 Mdot
.66383 .30094 Mdot
.38465 .48792 Mdot
.60258 .69051 Mdot
.52348 .31942 Mdot
.65846 .60407 Mdot
.66223 .42656 Mdot
.33364 .47223 Mdot
.29529 .49029 Mdot
.70246 .3869 Mdot
.50828 .326 Mdot
.30998 .63041 Mdot
.31273 .6132 Mdot
.65661 .41568 Mdot
.65132 .62367 Mdot
.72849 .52999 Mdot
.39 .29618 Mdot
.59422 .68157 Mdot
.59345 .70128 Mdot
.6692 .58426 Mdot
.69452 .60762 Mdot
.28851 .49046 Mdot
.29549 .49333 Mdot
.30227 .63483 Mdot
.3927 .4837 Mdot
.64797 .29179 Mdot
.51511 .3115 Mdot
.61398 .70078 Mdot
.41291 .68616 Mdot
.39897 .70558 Mdot
.33366 .50153 Mdot
.25215 .5208 Mdot
.68511 .37742 Mdot
.38252 .68058 Mdot
.40148 .31133 Mdot
.46256 .71197 Mdot
.29068 .49839 Mdot
.37059 .27746 Mdot
.5972 .70504 Mdot
.69487 .35423 Mdot
.67924 .59246 Mdot
.64897 .40354 Mdot
.64745 .40118 Mdot
.55603 .29317 Mdot
.51005 .70391 Mdot
.51879 .31197 Mdot
.65365 .28398 Mdot
.52331 .3009 Mdot
.37751 .30631 Mdot
.26066 .50733 Mdot
.65318 .31187 Mdot
.66289 .36493 Mdot
.70173 .57939 Mdot
.34086 .48102 Mdot
.31134 .51004 Mdot
.71477 .54359 Mdot
.36078 .51076 Mdot
.39671 .2803 Mdot
.74175 .52007 Mdot
.62764 .692 Mdot
.37272 .29136 Mdot
.7365 .54112 Mdot
.59047 .70087 Mdot
.40151 .69614 Mdot
.32335 .64896 Mdot
.49032 .70031 Mdot
.58348 .70914 Mdot
.28632 .48964 Mdot
.64394 .31001 Mdot
.60438 .6993 Mdot
.48342 .7055 Mdot
.48538 .7215 Mdot
.65312 .39108 Mdot
.40373 .31512 Mdot
.69567 .59216 Mdot
.33356 .50811 Mdot
.70939 .40497 Mdot
.41535 .30335 Mdot
.62415 .69792 Mdot
.32749 .51997 Mdot
.29805 .48417 Mdot
.40545 .30077 Mdot
.37332 .30766 Mdot
.39935 .29642 Mdot
.72315 .52448 Mdot
.3978 .69299 Mdot
.49279 .68569 Mdot
.71772 .5509 Mdot
.39704 .27387 Mdot
.35884 .29399 Mdot
.54211 .35448 Mdot
.29017 .49239 Mdot
.36488 .3023 Mdot
.46405 .71509 Mdot
.30036 .60549 Mdot
.5223 .30051 Mdot
.39187 .24668 Mdot
.72346 .39694 Mdot
.42173 .25878 Mdot
.67679 .60715 Mdot
.38378 .69298 Mdot
.38224 .29548 Mdot
.49312 .32589 Mdot
.293 .49036 Mdot
.27451 .48614 Mdot
.4091 .297 Mdot
.24533 .5168 Mdot
.59292 .6951 Mdot
.5487 .67856 Mdot
.40049 .30199 Mdot
.66005 .41417 Mdot
.69426 .37568 Mdot
.69136 .39999 Mdot
.3674 .4977 Mdot
.32756 .66095 Mdot
.25164 .57583 Mdot
.48155 .71864 Mdot
.73284 .5197 Mdot
.59914 .70732 Mdot
.53406 .71559 Mdot
.4945 .69039 Mdot
.66629 .43124 Mdot
.40037 .29399 Mdot
.59756 .71877 Mdot
.72412 .52205 Mdot
.73039 .53572 Mdot
.66688 .36647 Mdot
.68637 .41131 Mdot
.69096 .38881 Mdot
.4945 .71506 Mdot
.55889 .701 Mdot
.32739 .6324 Mdot
.63026 .68208 Mdot
.69638 .43364 Mdot
.66301 .32461 Mdot
.66941 .36605 Mdot
.68307 .57802 Mdot
.60305 .71541 Mdot
.29097 .49645 Mdot
.40308 .48216 Mdot
.69527 .37567 Mdot
.38722 .2754 Mdot
.47304 .72369 Mdot
.32644 .27708 Mdot
.38088 .69737 Mdot
.66303 .60286 Mdot
.49834 .33109 Mdot
.32082 .5071 Mdot
.67615 .41366 Mdot
.3989 .24861 Mdot
.52958 .33601 Mdot
.31812 .63763 Mdot
.44745 .70614 Mdot
.67106 .60188 Mdot
.31538 .61207 Mdot
.48632 .31506 Mdot
.41624 .68459 Mdot
.74123 .52307 Mdot
.66506 .37439 Mdot
.67396 .30899 Mdot
.518 .71231 Mdot
.27101 .50913 Mdot
.49852 .33553 Mdot
.35226 .48339 Mdot
.69926 .40467 Mdot
.37362 .29199 Mdot
.69996 .3971 Mdot
.59918 .67617 Mdot
.65555 .37731 Mdot
.31918 .51259 Mdot
.49956 .68351 Mdot
.73022 .53115 Mdot
.24339 .57227 Mdot
.43818 .33579 Mdot
.6583 .39024 Mdot
.49251 .34134 Mdot
.39981 .70305 Mdot
.38739 .70964 Mdot
.4603 .31895 Mdot
.31941 .51452 Mdot
.68023 .57591 Mdot
.48708 .68698 Mdot
.66672 .58462 Mdot
.4084 .31521 Mdot
.6561 .66346 Mdot
.67935 .59343 Mdot
.32734 .66327 Mdot
.37495 .28667 Mdot
.25053 .51895 Mdot
.33583 .51719 Mdot
.66233 .60865 Mdot
.31701 .62738 Mdot
.55112 .6993 Mdot
.30266 .61081 Mdot
.32719 .47554 Mdot
.67464 .57928 Mdot
.53733 .31858 Mdot
.31583 .61495 Mdot
.42025 .31384 Mdot
.72934 .54106 Mdot
.32753 .61488 Mdot
.51237 .30969 Mdot
.41166 .28489 Mdot
.37107 .28534 Mdot
.40758 .2888 Mdot
.32293 .51125 Mdot
.38907 .47193 Mdot
.4171 .27777 Mdot
.65273 .60664 Mdot
.41569 .27953 Mdot
.41693 .26185 Mdot
.71521 .5227 Mdot
.37077 .30554 Mdot
.35258 .5166 Mdot
.38027 .68927 Mdot
.38545 .69447 Mdot
.66526 .3975 Mdot
.66251 .65767 Mdot
.65201 .3213 Mdot
.32971 .49401 Mdot
.55153 .71817 Mdot
.50177 .6924 Mdot
.47445 .33068 Mdot
.3195 .47543 Mdot
.39545 .67048 Mdot
.48773 .69659 Mdot
.305 .63545 Mdot
.52456 .70434 Mdot
.48245 .31442 Mdot
.31773 .50885 Mdot
.50965 .69762 Mdot
.53496 .68356 Mdot
.2448 .5232 Mdot
.52935 .70071 Mdot
.61397 .70774 Mdot
.73052 .52039 Mdot
.6819 .60388 Mdot
.67871 .57651 Mdot
.68616 .41523 Mdot
.62333 .6921 Mdot
.27853 .50544 Mdot
.67943 .41543 Mdot
.37498 .50289 Mdot
.67241 .58113 Mdot
.37109 .47623 Mdot
.62334 .69016 Mdot
.34408 .51725 Mdot
.31269 .66066 Mdot
.66496 .29951 Mdot
.40601 .30005 Mdot
.51029 .72185 Mdot
.67115 .32368 Mdot
.72494 .54278 Mdot
.62768 .66686 Mdot
.42048 .26699 Mdot
.41797 .68435 Mdot
.30794 .51115 Mdot
.36401 .51934 Mdot
.41774 .6849 Mdot
.2868 .62404 Mdot
.5375 .32966 Mdot
.68378 .41873 Mdot
.64912 .39335 Mdot
.28086 .49255 Mdot
.61841 .69411 Mdot
.40554 .31309 Mdot
.36447 .2813 Mdot
.46326 .32856 Mdot
.30867 .61628 Mdot
.31354 .4735 Mdot
.35706 .4786 Mdot
.27563 .50796 Mdot
.66814 .38875 Mdot
.54364 .32028 Mdot
.30945 .64004 Mdot
.40536 .28166 Mdot
.28479 .50414 Mdot
.51148 .69403 Mdot
.62606 .69948 Mdot
.68986 .3814 Mdot
.74979 .51035 Mdot
.47517 .31064 Mdot
.67561 .36516 Mdot
.28134 .49327 Mdot
.41057 .703 Mdot
.74168 .51086 Mdot
.57587 .69921 Mdot
.41589 .28967 Mdot
.67593 .41077 Mdot
.42704 .29202 Mdot
.62407 .68102 Mdot
.62344 .69855 Mdot
.26498 .4932 Mdot
.46468 .34689 Mdot
.66133 .37648 Mdot
.36003 .49604 Mdot
.70342 .38899 Mdot
.65904 .31452 Mdot
.74642 .53392 Mdot
.27505 .50168 Mdot
.47311 .67556 Mdot
.68479 .57178 Mdot
.3406 .49431 Mdot
.39469 .6989 Mdot
.40248 .67769 Mdot
.6609 .41878 Mdot
.40713 .27173 Mdot
.41396 .28301 Mdot
.61583 .66585 Mdot
.61801 .72314 Mdot
.34763 .47887 Mdot
.65454 .39129 Mdot
.42809 .70622 Mdot
.6816 .59579 Mdot
.60367 .71069 Mdot
.69964 .52223 Mdot
.68469 .58176 Mdot
.28949 .49419 Mdot
.39861 .28227 Mdot
.58238 .70372 Mdot
.52209 .30015 Mdot
.21905 .548 Mdot
.50882 .34586 Mdot
.48257 .35456 Mdot
.50355 .30674 Mdot
.70638 .54098 Mdot
.69529 .38865 Mdot
.50611 .68084 Mdot
.66006 .60168 Mdot
.68017 .59879 Mdot
.66506 .33372 Mdot
.49167 .72049 Mdot
.56728 .67899 Mdot
.45567 .70993 Mdot
.65056 .30639 Mdot
.39882 .29026 Mdot
.29787 .61333 Mdot
.69009 .40073 Mdot
.66565 .28606 Mdot
.71965 .52255 Mdot
.71586 .53174 Mdot
.56456 .70687 Mdot
.30947 .48661 Mdot
.48469 .72094 Mdot
.37954 .50045 Mdot
.26147 .50786 Mdot
.66667 .59167 Mdot
.60441 .71024 Mdot
.73225 .50445 Mdot
.27455 .49428 Mdot
.31145 .49572 Mdot
.67773 .43782 Mdot
.51049 .3147 Mdot
.65419 .43333 Mdot
.26963 .502 Mdot
.69269 .4122 Mdot
.55553 .68968 Mdot
.48931 .32642 Mdot
.30223 .65068 Mdot
.73494 .51043 Mdot
.51039 .33814 Mdot
.48501 .32081 Mdot
.33056 .52826 Mdot
.52098 .7055 Mdot
.62715 .67125 Mdot
.39147 .31297 Mdot
.74157 .50097 Mdot
.74443 .53229 Mdot
.71017 .52849 Mdot
.2874 .49486 Mdot
.72791 .51248 Mdot
.4679 .30679 Mdot
.34294 .49324 Mdot
.41146 .69133 Mdot
.52169 .7138 Mdot
.3517 .48185 Mdot
.3809 .67219 Mdot
.68013 .58317 Mdot
.56134 .3179 Mdot
.34648 .47941 Mdot
.69618 .38334 Mdot
.57715 .71258 Mdot
.50953 .71364 Mdot
.38032 .30078 Mdot
.71814 .54149 Mdot
.3264 .28919 Mdot
.60326 .71121 Mdot
.29989 .49462 Mdot
.68413 .59206 Mdot
.49819 .33278 Mdot
.51967 .32754 Mdot
.49294 .34328 Mdot
.62221 .70697 Mdot
.4943 .32814 Mdot
.54557 .68437 Mdot
.30374 .63115 Mdot
.26111 .50525 Mdot
.69435 .58389 Mdot
.39847 .28852 Mdot
.44642 .31968 Mdot
.66416 .3149 Mdot
.31797 .64819 Mdot
.25599 .50612 Mdot
.65796 .66935 Mdot
.39531 .28492 Mdot
.32719 .50575 Mdot
.53817 .32983 Mdot
.33726 .66277 Mdot
.34785 .25359 Mdot
.51668 .30752 Mdot
.39793 .70737 Mdot
.5887 .69061 Mdot
.52581 .31895 Mdot
.62958 .69544 Mdot
.32834 .50406 Mdot
.31557 .63434 Mdot
.61919 .67042 Mdot
.64148 .65477 Mdot
.47458 .31652 Mdot
.73586 .54319 Mdot
.31466 .62511 Mdot
.35965 .51591 Mdot
.32369 .66103 Mdot
.50764 .33369 Mdot
.65321 .64336 Mdot
.70871 .39937 Mdot
.65561 .33021 Mdot
.65153 .28355 Mdot
.71247 .5503 Mdot
.74298 .49753 Mdot
.26982 .48507 Mdot
.43927 .68462 Mdot
.32571 .6608 Mdot
.69699 .56497 Mdot
.29351 .60808 Mdot
.33904 .50395 Mdot
.37097 .50481 Mdot
.70356 .38875 Mdot
.70176 .57626 Mdot
.37743 .70117 Mdot
.31031 .63768 Mdot
.3889 .27235 Mdot
.63059 .68644 Mdot
.33954 .5096 Mdot
.65645 .66912 Mdot
.6584 .41458 Mdot
.6626 .66449 Mdot
.35351 .51556 Mdot
.50978 .31466 Mdot
.7401 .50478 Mdot
.72917 .52707 Mdot
.66525 .41856 Mdot
.66347 .41441 Mdot
.36114 .51482 Mdot
.67616 .57258 Mdot
.29379 .60927 Mdot
.31288 .61537 Mdot
.50421 .32608 Mdot
.3977 .30854 Mdot
.38242 .5048 Mdot
.56076 .67953 Mdot
.45058 .34327 Mdot
.36393 .49576 Mdot
.6201 .67543 Mdot
.68653 .3878 Mdot
.66632 .30928 Mdot
.60068 .70291 Mdot
.66269 .30518 Mdot
.66106 .66302 Mdot
.37995 .47106 Mdot
.38716 .30966 Mdot
.35631 .66486 Mdot
.42178 .28221 Mdot
.51091 .33711 Mdot
.29129 .49335 Mdot
.68293 .34833 Mdot
.6533 .28151 Mdot
.34986 .6715 Mdot
.67053 .59531 Mdot
.53235 .30742 Mdot
.39631 .6871 Mdot
.38188 .27263 Mdot
.67773 .40292 Mdot
.49427 .30003 Mdot
.2784 .50326 Mdot
.51245 .70575 Mdot
.3734 .69212 Mdot
.50754 .30134 Mdot
.51759 .33501 Mdot
.48022 .30648 Mdot
.73618 .54149 Mdot
.47905 .70777 Mdot
.71843 .52535 Mdot
.66899 .30669 Mdot
.32668 .62962 Mdot
.30555 .49823 Mdot
.60172 .70759 Mdot
.36332 .48883 Mdot
.68752 .5679 Mdot
.50066 .73011 Mdot
.39681 .29455 Mdot
.48101 .31852 Mdot
.68441 .62361 Mdot
.52025 .29918 Mdot
.41671 .69212 Mdot
.41179 .70708 Mdot
.51008 .69098 Mdot
.70583 .56095 Mdot
.39442 .49184 Mdot
.64803 .38138 Mdot
.4162 .28771 Mdot
.72598 .52136 Mdot
.41417 .69439 Mdot
.33759 .51868 Mdot
.39747 .28659 Mdot
.71661 .53184 Mdot
.45975 .32831 Mdot
.66552 .58106 Mdot
.51431 .34661 Mdot
.35682 .67986 Mdot
.35002 .5132 Mdot
.50836 .31234 Mdot
.49429 .69522 Mdot
.73402 .52234 Mdot
.50471 .71853 Mdot
.48295 .31468 Mdot
.66208 .3171 Mdot
.72814 .51969 Mdot
.29049 .50421 Mdot
.47414 .68658 Mdot
.55644 .70388 Mdot
.47948 .70273 Mdot
.59287 .31216 Mdot
.65475 .31937 Mdot
.69137 .38604 Mdot
.68454 .57814 Mdot
.71002 .40738 Mdot
.37478 .28581 Mdot
.29647 .61548 Mdot
.6596 .40314 Mdot
.48044 .71003 Mdot
.69803 .41803 Mdot
.2921 .63428 Mdot
.7288 .54923 Mdot
.6826 .36781 Mdot
.37343 .48817 Mdot
.39551 .69692 Mdot
.52357 .333 Mdot
.44183 .30445 Mdot
.30538 .63034 Mdot
.32154 .48576 Mdot
.49859 .31544 Mdot
.34765 .51619 Mdot
.68492 .5689 Mdot
.24574 .57109 Mdot
.32857 .64045 Mdot
.66143 .31096 Mdot
.64312 .65816 Mdot
.64904 .39664 Mdot
.35742 .30172 Mdot
.36162 .49164 Mdot
.34192 .51552 Mdot
.39917 .67977 Mdot
.4821 .72843 Mdot
.72389 .53194 Mdot
.32807 .62895 Mdot
.6533 .30184 Mdot
.50745 .68459 Mdot
.51072 .68735 Mdot
.28126 .50957 Mdot
.5104 .31104 Mdot
.67227 .61201 Mdot
.32073 .51167 Mdot
.52348 .30171 Mdot
.32668 .47667 Mdot
.71083 .54746 Mdot
.65427 .3208 Mdot
.66463 .28985 Mdot
.52046 .68666 Mdot
.69834 .37976 Mdot
.3972 .67927 Mdot
.49671 .32935 Mdot
.6506 .28308 Mdot
.72245 .53596 Mdot
.41763 .28788 Mdot
.37243 .50031 Mdot
.24611 .52068 Mdot
.69888 .37949 Mdot
.67554 .41918 Mdot
.29323 .61075 Mdot
.6597 .66962 Mdot
.51228 .35932 Mdot
.73785 .52704 Mdot
.51272 .6933 Mdot
.3985 .45331 Mdot
.37115 .38531 Mdot
.68685 .59612 Mdot
.4111 .69738 Mdot
.69124 .37556 Mdot
.56316 .30873 Mdot
.49023 .69316 Mdot
.41759 .28916 Mdot
.36315 .48734 Mdot
.5047 .68792 Mdot
.64822 .29621 Mdot
.4797 .69234 Mdot
.51934 .3184 Mdot
.72508 .55147 Mdot
.67295 .39757 Mdot
.7014 .57826 Mdot
.47071 .67693 Mdot
.39819 .29207 Mdot
.27698 .51252 Mdot
.37779 .68728 Mdot
.53234 .7089 Mdot
.40094 .69168 Mdot
.46432 .31372 Mdot
.39982 .69542 Mdot
.51636 .69173 Mdot
.33779 .5176 Mdot
.37795 .48154 Mdot
.66793 .3214 Mdot
.36807 .50946 Mdot
.28787 .48245 Mdot
.31378 .66101 Mdot
.36901 .49432 Mdot
.34939 .49796 Mdot
.27496 .49927 Mdot
.60466 .67896 Mdot
.3322 .47804 Mdot
.56897 .70535 Mdot
.57589 .69058 Mdot
.66818 .30464 Mdot
.37651 .27454 Mdot
.37957 .31 Mdot
.3368 .47732 Mdot
.2485 .52091 Mdot
.49747 .72133 Mdot
.59975 .71718 Mdot
.73089 .52966 Mdot
.32545 .64057 Mdot
.50762 .35962 Mdot
.37165 .47837 Mdot
.66443 .39668 Mdot
.6576 .41008 Mdot
.38368 .49409 Mdot
.32679 .27446 Mdot
.25644 .49521 Mdot
.29556 .62922 Mdot
.32768 .51231 Mdot
.26734 .49789 Mdot
.65145 .38968 Mdot
.26433 .51525 Mdot
.38905 .67239 Mdot
.52255 .69111 Mdot
.42202 .29273 Mdot
.52141 .31529 Mdot
.31547 .63426 Mdot
.39388 .45926 Mdot
.52251 .70918 Mdot
.40136 .6797 Mdot
.6707 .40473 Mdot
.61897 .70041 Mdot
.29746 .63419 Mdot
.72693 .54538 Mdot
.21809 .54134 Mdot
.65526 .66257 Mdot
.73439 .53873 Mdot
.41271 .28574 Mdot
.66989 .37668 Mdot
.32029 .50146 Mdot
.69219 .41989 Mdot
.27731 .49639 Mdot
.30986 .60966 Mdot
.38797 .30913 Mdot
.49014 .71054 Mdot
.73575 .5109 Mdot
.5986 .6852 Mdot
.56984 .67975 Mdot
.27662 .58012 Mdot
.64042 .3937 Mdot
.6576 .37576 Mdot
.43975 .33086 Mdot
.54369 .69102 Mdot
.28344 .48249 Mdot
.45544 .70766 Mdot
.60575 .68869 Mdot
.50929 .71009 Mdot
.22288 .54761 Mdot
.23072 .50363 Mdot
.27914 .50044 Mdot
.49813 .69379 Mdot
.67175 .37494 Mdot
.38352 .30944 Mdot
.28065 .48809 Mdot
.49786 .33025 Mdot
.5201 .68623 Mdot
.69203 .37865 Mdot
.27195 .51436 Mdot
.68957 .41271 Mdot
.49521 .6874 Mdot
.65238 .40653 Mdot
.74796 .5318 Mdot
.65892 .40049 Mdot
.37959 .50944 Mdot
.33168 .51488 Mdot
.51489 .68957 Mdot
.62338 .69839 Mdot
.41639 .69074 Mdot
.37243 .49107 Mdot
.51686 .68136 Mdot
.7052 .42121 Mdot
.59318 .7208 Mdot
.4067 .67891 Mdot
.29198 .48387 Mdot
.41771 .27915 Mdot
.32671 .62193 Mdot
.23325 .56397 Mdot
.32966 .63865 Mdot
.40216 .29184 Mdot
.4428 .6852 Mdot
.30425 .50187 Mdot
.24532 .51159 Mdot
.65106 .30022 Mdot
.37465 .48579 Mdot
.48969 .32969 Mdot
.4059 .67429 Mdot
.22041 .52242 Mdot
.41362 .69203 Mdot
.48415 .70101 Mdot
.49689 .68561 Mdot
.69043 .4297 Mdot
.49472 .69161 Mdot
.49445 .33114 Mdot
.67088 .61192 Mdot
.56818 .68206 Mdot
.54331 .31921 Mdot
.51894 .33945 Mdot
.48443 .33356 Mdot
.51116 .30468 Mdot
.50285 .3587 Mdot
.66404 .33088 Mdot
.52206 .33724 Mdot
.54178 .68861 Mdot
.721 .388 Mdot
.42394 .27073 Mdot
.67179 .61233 Mdot
.48646 .3232 Mdot
.37381 .48534 Mdot
.40655 .6826 Mdot
.63211 .66711 Mdot
.71378 .5529 Mdot
.46952 .31205 Mdot
.28404 .48371 Mdot
.52744 .68771 Mdot
.33968 .50808 Mdot
.4 .27147 Mdot
.62362 .68883 Mdot
.67944 .41185 Mdot
.38841 .30824 Mdot
.49159 .3075 Mdot
.39947 .30049 Mdot
.70265 .39869 Mdot
.66121 .58538 Mdot
.36072 .48664 Mdot
.44878 .31661 Mdot
.37386 .27887 Mdot
.36902 .48522 Mdot
.54052 .69012 Mdot
.47132 .31235 Mdot
.30612 .48502 Mdot
.39757 .68402 Mdot
.58956 .69869 Mdot
.67597 .63704 Mdot
.32107 .49966 Mdot
.4115 .70648 Mdot
.52304 .68913 Mdot
.52001 .3017 Mdot
.68222 .41503 Mdot
.33046 .52062 Mdot
.66566 .59786 Mdot
.67035 .58237 Mdot
.64811 .29836 Mdot
.63382 .67862 Mdot
.71509 .39583 Mdot
.38894 .50006 Mdot
.48565 .31935 Mdot
.32882 .51902 Mdot
.69355 .43462 Mdot
.66379 .6495 Mdot
.58516 .70753 Mdot
.66815 .30003 Mdot
.28317 .4708 Mdot
.68359 .60908 Mdot
.6621 .30916 Mdot
.52078 .69066 Mdot
.62721 .67983 Mdot
.60366 .70332 Mdot
.4047 .31078 Mdot
.68574 .40969 Mdot
.61164 .67158 Mdot
.58782 .68831 Mdot
.40427 .67882 Mdot
.38365 .49326 Mdot
.51006 .69594 Mdot
.64959 .30893 Mdot
.41844 .28591 Mdot
.65649 .29928 Mdot
.4474 .34174 Mdot
.73632 .51943 Mdot
.29323 .64154 Mdot
.31848 .64922 Mdot
.32763 .30092 Mdot
.288 .50514 Mdot
.32224 .51033 Mdot
.48662 .717 Mdot
.44612 .30301 Mdot
.4299 .30283 Mdot
.54017 .68924 Mdot
.58192 .70596 Mdot
.39252 .30488 Mdot
.38521 .47399 Mdot
.24354 .52813 Mdot
.2774 .47176 Mdot
.47662 .70725 Mdot
.54617 .68078 Mdot
.67225 .58758 Mdot
.51806 .68597 Mdot
.71897 .37587 Mdot
.67298 .36665 Mdot
.65798 .3887 Mdot
.73029 .52319 Mdot
.31709 .50049 Mdot
.6544 .37762 Mdot
.38338 .68371 Mdot
.71222 .366 Mdot
.39929 .70194 Mdot
.64579 .28615 Mdot
.37046 .48963 Mdot
.69988 .59405 Mdot
.70654 .54358 Mdot
.41168 .68128 Mdot
.38708 .4706 Mdot
.41309 .2935 Mdot
.4869 .71767 Mdot
.69356 .56807 Mdot
.48766 .72116 Mdot
.34718 .51439 Mdot
.50034 .70329 Mdot
.73935 .51291 Mdot
.65329 .6463 Mdot
.39353 .67103 Mdot
.38757 .6828 Mdot
.4997 .7245 Mdot
.51292 .67892 Mdot
.68422 .41521 Mdot
.51456 .70916 Mdot
.5939 .67983 Mdot
.39836 .6986 Mdot
.68973 .37313 Mdot
.31494 .59964 Mdot
.48662 .70955 Mdot
.40583 .31405 Mdot
.62427 .68389 Mdot
.39703 .30585 Mdot
.62118 .66891 Mdot
.66862 .32336 Mdot
.34401 .49641 Mdot
.66731 .30396 Mdot
.38817 .27594 Mdot
.64599 .39037 Mdot
.6917 .56462 Mdot
.49213 .31858 Mdot
.6829 .57265 Mdot
.29723 .62005 Mdot
.48354 .71936 Mdot
.67724 .60745 Mdot
.28843 .58466 Mdot
.33244 .51795 Mdot
.62226 .66877 Mdot
.67308 .40518 Mdot
.65577 .29277 Mdot
.3048 .62404 Mdot
.60993 .71137 Mdot
.69338 .42647 Mdot
.42059 .709 Mdot
.69244 .3531 Mdot
.41136 .67852 Mdot
.70443 .5157 Mdot
.48574 .68933 Mdot
.65355 .2918 Mdot
.29452 .62634 Mdot
.57884 .69276 Mdot
.6672 .37049 Mdot
.66333 .58385 Mdot
.66651 .59793 Mdot
.35109 .52362 Mdot
.70045 .58323 Mdot
.66565 .39934 Mdot
.66189 .66698 Mdot
.61087 .67257 Mdot
.66414 .65207 Mdot
.40133 .29487 Mdot
.6791 .378 Mdot
.50372 .32721 Mdot
.46339 .68064 Mdot
.70539 .41084 Mdot
.32538 .28415 Mdot
.63278 .27246 Mdot
.71482 .41343 Mdot
.62541 .68872 Mdot
.61984 .70817 Mdot
.37984 .69846 Mdot
.30612 .62711 Mdot
.67691 .40093 Mdot
.72089 .38333 Mdot
.31139 .47257 Mdot
.49212 .31536 Mdot
.64517 .29948 Mdot
.28133 .50559 Mdot
.39939 .6889 Mdot
.73471 .52946 Mdot
.31186 .49529 Mdot
.57417 .70539 Mdot
.26276 .50006 Mdot
.68933 .56922 Mdot
.6677 .43329 Mdot
.34723 .51526 Mdot
.41456 .28705 Mdot
.65983 .59718 Mdot
.66277 .59104 Mdot
.64363 .38297 Mdot
.63413 .67877 Mdot
.517 .71716 Mdot
.68603 .4119 Mdot
.39326 .69367 Mdot
.49959 .31863 Mdot
.28027 .5016 Mdot
.49831 .71154 Mdot
.48267 .71795 Mdot
.67837 .37752 Mdot
.35516 .48292 Mdot
.6893 .58524 Mdot
.71196 .41813 Mdot
.40794 .70223 Mdot
.65992 .38503 Mdot
.54798 .33605 Mdot
.66863 .36427 Mdot
.5425 .68381 Mdot
.47302 .32817 Mdot
.4993 .70569 Mdot
.53364 .33044 Mdot
.55845 .29447 Mdot
.41215 .28428 Mdot
.65173 .39446 Mdot
.63916 .65417 Mdot
.66545 .29625 Mdot
.36507 .49286 Mdot
.29345 .49694 Mdot
.70658 .39931 Mdot
.39577 .29029 Mdot
.42377 .25998 Mdot
.43429 .28785 Mdot
.62676 .69383 Mdot
.39672 .67008 Mdot
.64499 .27282 Mdot
.67043 .294 Mdot
.74417 .51591 Mdot
.53298 .69394 Mdot
.52382 .33891 Mdot
.69287 .56295 Mdot
.66294 .58904 Mdot
.38791 .29269 Mdot
.66623 .28737 Mdot
.50838 .70626 Mdot
.7014 .57178 Mdot
.57667 .69502 Mdot
.24467 .5096 Mdot
.51014 .30232 Mdot
.43914 .32628 Mdot
.53803 .32742 Mdot
.30616 .63656 Mdot
.69786 .58748 Mdot
.35147 .50233 Mdot
.38697 .27135 Mdot
.73211 .52454 Mdot
.42348 .28144 Mdot
.41003 .70015 Mdot
.66626 .43111 Mdot
.58523 .73088 Mdot
.35904 .52181 Mdot
.34071 .4923 Mdot
.73422 .51756 Mdot
.39294 .46882 Mdot
.52141 .6957 Mdot
.60156 .67783 Mdot
.69449 .3888 Mdot
.22647 .5558 Mdot
.26098 .49356 Mdot
.28223 .48685 Mdot
.70128 .40827 Mdot
.51502 .31016 Mdot
.65858 .32953 Mdot
.28773 .4865 Mdot
.67826 .58254 Mdot
.4122 .69411 Mdot
.67713 .61358 Mdot
.38973 .4974 Mdot
.34817 .49404 Mdot
.38529 .68444 Mdot
.40512 .6927 Mdot
.68271 .57299 Mdot
.51119 .30681 Mdot
.47849 .31256 Mdot
.48086 .7077 Mdot
.37502 .48976 Mdot
.30331 .47024 Mdot
.31998 .51094 Mdot
.41278 .29287 Mdot
.23347 .5687 Mdot
.29077 .63214 Mdot
.31752 .62116 Mdot
.3389 .47362 Mdot
.33215 .50431 Mdot
.73785 .51531 Mdot
.61352 .71223 Mdot
.68815 .5895 Mdot
.7178 .55729 Mdot
.6885 .42642 Mdot
.42464 .28289 Mdot
.36267 .51407 Mdot
.37808 .29197 Mdot
.24751 .4869 Mdot
.3618 .30289 Mdot
.31277 .6385 Mdot
.29615 .60943 Mdot
.41447 .31115 Mdot
.31822 .51226 Mdot
.70244 .39161 Mdot
.65161 .37298 Mdot
.38414 .69345 Mdot
.38524 .50313 Mdot
.74657 .52003 Mdot
.66359 .60963 Mdot
.65818 .32375 Mdot
.66725 .33805 Mdot
.40031 .27135 Mdot
.56141 .31494 Mdot
.4009 .69625 Mdot
.35918 .51923 Mdot
.50091 .30786 Mdot
.71142 .39435 Mdot
.53042 .33357 Mdot
.66271 .32224 Mdot
.69518 .56991 Mdot
.67423 .60368 Mdot
.37953 .49435 Mdot
.33434 .26182 Mdot
.60499 .68645 Mdot
.61978 .70775 Mdot
.66277 .61178 Mdot
.64908 .39641 Mdot
.52393 .3238 Mdot
.46415 .71465 Mdot
.52837 .69264 Mdot
.37546 .2798 Mdot
.33242 .52026 Mdot
.66517 .36909 Mdot
.5052 .67998 Mdot
.38916 .2735 Mdot
.33046 .64398 Mdot
.72052 .40101 Mdot
.3507 .50723 Mdot
.41313 .70815 Mdot
.58491 .71235 Mdot
.30974 .6284 Mdot
.48736 .71039 Mdot
.66762 .59004 Mdot
.69931 .57368 Mdot
.34509 .49377 Mdot
.57179 .7259 Mdot
.55457 .68992 Mdot
.70004 .5782 Mdot
.40768 .31122 Mdot
.49897 .32403 Mdot
.42147 .28023 Mdot
.69495 .38411 Mdot
.41338 .2852 Mdot
.7012 .41553 Mdot
.6605 .3074 Mdot
.50754 .69909 Mdot
.39726 .28616 Mdot
.30343 .65539 Mdot
.50063 .32984 Mdot
.35831 .29495 Mdot
.3197 .63427 Mdot
.41465 .70043 Mdot
.67502 .39079 Mdot
.37744 .28881 Mdot
.30825 .51095 Mdot
.67834 .62752 Mdot
.72715 .55106 Mdot
.69184 .56535 Mdot
.52106 .31944 Mdot
.67202 .37881 Mdot
.5035 .71099 Mdot
.3273 .47627 Mdot
.52313 .67673 Mdot
.30324 .48346 Mdot
.36835 .50301 Mdot
.55239 .68723 Mdot
.50285 .71148 Mdot
.33688 .49582 Mdot
.27949 .50739 Mdot
.49631 .32659 Mdot
.66466 .59119 Mdot
.62436 .69213 Mdot
.61792 .69661 Mdot
.67094 .41402 Mdot
.51325 .6872 Mdot
.47346 .35037 Mdot
.69511 .56494 Mdot
.52022 .29945 Mdot
.68702 .57942 Mdot
.39519 .24776 Mdot
.71343 .41163 Mdot
.62838 .65297 Mdot
.63323 .67149 Mdot
.39699 .67704 Mdot
.51025 .69719 Mdot
.39816 .29642 Mdot
.50802 .68648 Mdot
.5014 .69534 Mdot
.37532 .48823 Mdot
.50011 .30612 Mdot
.51997 .33598 Mdot
.30792 .63909 Mdot
.60597 .68666 Mdot
.33537 .50048 Mdot
.32424 .63446 Mdot
.35827 .48937 Mdot
.30928 .63023 Mdot
.61577 .67368 Mdot
.39516 .46007 Mdot
.50949 .69194 Mdot
.56333 .70402 Mdot
.44735 .34241 Mdot
.5047 .33227 Mdot
.53176 .33532 Mdot
.75124 .53451 Mdot
.30736 .48612 Mdot
.66514 .30704 Mdot
.39551 .69301 Mdot
.48794 .31404 Mdot
.32824 .6638 Mdot
.37075 .29383 Mdot
.277 .4953 Mdot
.50058 .31061 Mdot
.67658 .40792 Mdot
.39588 .67761 Mdot
.2917 .49321 Mdot
.52142 .31326 Mdot
.51119 .7017 Mdot
.59443 .69839 Mdot
.53266 .6973 Mdot
.39292 .30097 Mdot
.69151 .57376 Mdot
.39708 .69121 Mdot
.69702 .38822 Mdot
.66699 .30866 Mdot
.49995 .70643 Mdot
.66271 .42215 Mdot
.6689 .60426 Mdot
.29415 .4905 Mdot
.6723 .58181 Mdot
.37393 .2984 Mdot
.62228 .68905 Mdot
.39404 .68299 Mdot
.3716 .67911 Mdot
.49735 .68542 Mdot
.49163 .32544 Mdot
.43126 .28933 Mdot
.65804 .42125 Mdot
.59044 .70796 Mdot
.69351 .57249 Mdot
.6691 .41721 Mdot
.38896 .67981 Mdot
.36363 .30913 Mdot
.31316 .49555 Mdot
.3787 .50133 Mdot
.45331 .68128 Mdot
.38665 .48635 Mdot
.66933 .30777 Mdot
.4831 .71484 Mdot
.41361 .68631 Mdot
.30133 .60998 Mdot
.35224 .25085 Mdot
.42156 .27252 Mdot
.33225 .50815 Mdot
.32438 .662 Mdot
.36976 .47929 Mdot
.64222 .65546 Mdot
.30784 .62468 Mdot
.69535 .43089 Mdot
.43866 .32741 Mdot
.71849 .55747 Mdot
.49801 .31408 Mdot
.66447 .42845 Mdot
.27636 .50677 Mdot
.31636 .49514 Mdot
.58975 .72347 Mdot
.41251 .70009 Mdot
.6838 .59776 Mdot
.39076 .46412 Mdot
.6711 .40613 Mdot
.65137 .28022 Mdot
.38927 .50307 Mdot
.52388 .69732 Mdot
.68996 .61095 Mdot
.49521 .30894 Mdot
.53474 .33336 Mdot
.38584 .27596 Mdot
.68328 .43358 Mdot
.49557 .3448 Mdot
.68861 .58447 Mdot
.30895 .51257 Mdot
.29098 .63372 Mdot
.68326 .63088 Mdot
.4933 .68375 Mdot
.74372 .53279 Mdot
.38894 .24662 Mdot
.35974 .50055 Mdot
.60811 .68111 Mdot
.49091 .69266 Mdot
.37521 .27763 Mdot
.66589 .31893 Mdot
.65087 .3043 Mdot
.32899 .27203 Mdot
.47131 .31993 Mdot
.71147 .39579 Mdot
.49567 .3436 Mdot
.39069 .69208 Mdot
.31578 .6355 Mdot
.73167 .54973 Mdot
.36918 .49306 Mdot
.55438 .70885 Mdot
.4822 .70483 Mdot
.32823 .51331 Mdot
.42533 .2952 Mdot
.48242 .72783 Mdot
.37761 .67879 Mdot
.32223 .52388 Mdot
.6723 .37458 Mdot
.36639 .49767 Mdot
.4752 .3518 Mdot
.52702 .30289 Mdot
.3802 .48524 Mdot
.68327 .41378 Mdot
.47376 .32879 Mdot
.42786 .29706 Mdot
.47784 .7037 Mdot
.4998 .31488 Mdot
.40929 .70224 Mdot
.28607 .50082 Mdot
.41059 .31069 Mdot
.3875 .68695 Mdot
.54383 .67906 Mdot
.54093 .33156 Mdot
.65688 .39265 Mdot
.58174 .70223 Mdot
.35871 .49569 Mdot
.49659 .32395 Mdot
.34151 .52037 Mdot
.57622 .6767 Mdot
.37419 .50511 Mdot
.65289 .6399 Mdot
.58844 .71508 Mdot
.68075 .59006 Mdot
.39971 .68023 Mdot
.35349 .50741 Mdot
.49216 .34161 Mdot
.52468 .32706 Mdot
.28258 .48373 Mdot
.4979 .70658 Mdot
.49528 .69493 Mdot
.52466 .70376 Mdot
.66579 .40964 Mdot
.26571 .47669 Mdot
.67566 .59132 Mdot
.50846 .30755 Mdot
.69964 .58575 Mdot
.32474 .65874 Mdot
.39735 .30212 Mdot
.66905 .63655 Mdot
.29626 .48689 Mdot
.61237 .70884 Mdot
.24964 .52842 Mdot
.636 .6949 Mdot
.75464 .52696 Mdot
.74484 .53033 Mdot
.60994 .69028 Mdot
.32842 .50846 Mdot
.30439 .63557 Mdot
.28955 .62845 Mdot
.69816 .58438 Mdot
.48222 .30669 Mdot
.55711 .3468 Mdot
.67677 .36917 Mdot
.36189 .30715 Mdot
.72703 .51981 Mdot
.71188 .53101 Mdot
.40674 .6789 Mdot
.58711 .69892 Mdot
.6943 .58152 Mdot
.67209 .57486 Mdot
.66805 .39692 Mdot
.40166 .67796 Mdot
.34985 .51041 Mdot
.49474 .33223 Mdot
.72676 .54228 Mdot
.27374 .48738 Mdot
.41734 .69198 Mdot
.6611 .32741 Mdot
.51153 .71325 Mdot
.67774 .63793 Mdot
.32752 .6559 Mdot
.53422 .70785 Mdot
.68004 .3464 Mdot
.61165 .67194 Mdot
.33876 .5007 Mdot
.51627 .32424 Mdot
.65939 .4181 Mdot
.30168 .49409 Mdot
.66807 .298 Mdot
.68766 .59689 Mdot
.6853 .6245 Mdot
.31812 .65388 Mdot
.7107 .36527 Mdot
.33503 .49784 Mdot
.3763 .68738 Mdot
.40594 .27968 Mdot
.69558 .58633 Mdot
.57561 .716 Mdot
.34132 .52206 Mdot
.67843 .41901 Mdot
.68258 .36872 Mdot
.4895 .70556 Mdot
.53228 .69582 Mdot
.63703 .6528 Mdot
.50623 .32792 Mdot
.67228 .42542 Mdot
.49725 .32497 Mdot
.31562 .52071 Mdot
.7011 .57428 Mdot
.42824 .29809 Mdot
.65318 .40831 Mdot
.72317 .52581 Mdot
.41456 .70078 Mdot
.63251 .68808 Mdot
.46089 .68013 Mdot
.38161 .6863 Mdot
.67958 .43255 Mdot
.40946 .30293 Mdot
.31323 .62456 Mdot
.38607 .67095 Mdot
.40183 .30798 Mdot
.66685 .40526 Mdot
.59858 .69425 Mdot
.48679 .69472 Mdot
.60572 .71514 Mdot
.29599 .64512 Mdot
.45364 .70036 Mdot
.25837 .50867 Mdot
.38005 .48262 Mdot
.61911 .66447 Mdot
.32723 .48104 Mdot
.69198 .56582 Mdot
.59847 .71218 Mdot
.30956 .62942 Mdot
.41836 .6823 Mdot
.25917 .50287 Mdot
.33618 .48846 Mdot
.40642 .69536 Mdot
.30752 .48604 Mdot
.55004 .68428 Mdot
.48223 .7175 Mdot
.31618 .62179 Mdot
.70359 .56015 Mdot
.40525 .29863 Mdot
.59343 .67946 Mdot
.3664 .50031 Mdot
.5518 .68313 Mdot
.31906 .62846 Mdot
.65288 .63913 Mdot
.40572 .69788 Mdot
.66865 .43378 Mdot
.29269 .50548 Mdot
.67515 .3646 Mdot
.37345 .67636 Mdot
.55332 .68228 Mdot
.73199 .54667 Mdot
.37715 .67801 Mdot
.72338 .3987 Mdot
.39068 .46307 Mdot
.51768 .3269 Mdot
.41395 .28251 Mdot
.478 .33246 Mdot
.68342 .57141 Mdot
.30468 .48994 Mdot
.29479 .50257 Mdot
.39097 .48917 Mdot
.31621 .52109 Mdot
.50282 .33144 Mdot
.39726 .31433 Mdot
.57247 .68092 Mdot
.28303 .49584 Mdot
.65325 .37659 Mdot
.59165 .68871 Mdot
.26928 .50529 Mdot
.28713 .62852 Mdot
.40299 .70822 Mdot
.60727 .68719 Mdot
.63544 .68042 Mdot
.50959 .35974 Mdot
.40453 .28728 Mdot
.35504 .49093 Mdot
.42412 .31177 Mdot
.39514 .6894 Mdot
.68471 .57579 Mdot
.39276 .48637 Mdot
.71262 .41242 Mdot
.30243 .62022 Mdot
.66566 .40522 Mdot
.34417 .48987 Mdot
.62689 .6853 Mdot
.6983 .57606 Mdot
.64995 .29642 Mdot
.64651 .29837 Mdot
.24999 .50527 Mdot
.65732 .27841 Mdot
.38657 .29765 Mdot
.39166 .29567 Mdot
.69622 .57931 Mdot
.32455 .51029 Mdot
.30712 .62009 Mdot
.3653 .66328 Mdot
.31005 .48785 Mdot
.31569 .50064 Mdot
.72077 .53124 Mdot
.72888 .52302 Mdot
.65283 .40557 Mdot
.33141 .49619 Mdot
.27196 .49034 Mdot
.61684 .68561 Mdot
.42436 .27825 Mdot
.6791 .42879 Mdot
.39197 .27277 Mdot
.69612 .40791 Mdot
.22091 .5222 Mdot
.49809 .30353 Mdot
.39245 .29868 Mdot
.72988 .51255 Mdot
.61424 .70575 Mdot
.49793 .33173 Mdot
.68168 .38975 Mdot
.66662 .42412 Mdot
.27084 .50391 Mdot
.48851 .68508 Mdot
.60444 .67624 Mdot
.39369 .30313 Mdot
.66166 .60918 Mdot
.38308 .68388 Mdot
.53805 .32828 Mdot
.37446 .24614 Mdot
.67345 .42227 Mdot
.64433 .66103 Mdot
.45966 .68364 Mdot
.36316 .50852 Mdot
.59553 .69828 Mdot
.35709 .51055 Mdot
.51445 .70877 Mdot
.57643 .69121 Mdot
.39052 .49925 Mdot
.53052 .70397 Mdot
.71354 .40119 Mdot
.64452 .28003 Mdot
.41621 .68508 Mdot
.74882 .50396 Mdot
.39409 .69232 Mdot
.65516 .32687 Mdot
.25024 .52718 Mdot
.29312 .4989 Mdot
.36757 .50096 Mdot
.37707 .32353 Mdot
.34286 .47785 Mdot
.5339 .32495 Mdot
.5169 .32748 Mdot
.59514 .69384 Mdot
.48173 .33495 Mdot
.30693 .63525 Mdot
.39275 .28422 Mdot
.69348 .38804 Mdot
.24715 .51335 Mdot
.40145 .30476 Mdot
.48291 .69934 Mdot
.38832 .67322 Mdot
.60892 .66871 Mdot
.65925 .36781 Mdot
.51313 .31228 Mdot
.68684 .59667 Mdot
.32882 .62321 Mdot
.67548 .41316 Mdot
.72861 .53486 Mdot
.31488 .64647 Mdot
.6696 .43544 Mdot
.70072 .56123 Mdot
.64334 .27859 Mdot
.73504 .53358 Mdot
.66836 .6127 Mdot
.29591 .63585 Mdot
.39264 .28357 Mdot
.4768 .33349 Mdot
.41828 .31385 Mdot
.73395 .54326 Mdot
.65254 .32759 Mdot
.67005 .38303 Mdot
.30588 .6111 Mdot
.45438 .70054 Mdot
.48532 .32234 Mdot
.32243 .49861 Mdot
.73462 .52465 Mdot
.2474 .48564 Mdot
.47709 .33332 Mdot
.6734 .60133 Mdot
.37308 .67745 Mdot
.23001 .56494 Mdot
.50804 .32404 Mdot
.51181 .33737 Mdot
.38059 .28582 Mdot
.65584 .31301 Mdot
.61833 .67133 Mdot
.36945 .29126 Mdot
.39051 .47928 Mdot
.36888 .4901 Mdot
.68445 .57244 Mdot
.5013 .3144 Mdot
.67106 .59559 Mdot
.4258 .28871 Mdot
.39181 .31312 Mdot
.47898 .7027 Mdot
.52475 .70155 Mdot
.51669 .34674 Mdot
.33819 .47271 Mdot
.35583 .4794 Mdot
.58283 .72177 Mdot
.6258 .67635 Mdot
.38174 .47053 Mdot
.43481 .29708 Mdot
.37978 .28344 Mdot
.37484 .68342 Mdot
.32317 .62875 Mdot
.40891 .69122 Mdot
.32605 .64857 Mdot
.66992 .45005 Mdot
.39673 .67977 Mdot
.66063 .42397 Mdot
.32742 .64777 Mdot
.73371 .50284 Mdot
.38475 .69596 Mdot
.36342 .51129 Mdot
.69158 .4035 Mdot
.36832 .48454 Mdot
.6887 .37881 Mdot
.3471 .49669 Mdot
.69271 .43531 Mdot
.69696 .38845 Mdot
.57426 .33382 Mdot
.26722 .57907 Mdot
.53307 .32695 Mdot
.4259 .30517 Mdot
.45021 .31747 Mdot
.27125 .51388 Mdot
.60239 .69484 Mdot
.45077 .70539 Mdot
.36472 .50837 Mdot
.6673 .39362 Mdot
.68396 .6016 Mdot
.37159 .6882 Mdot
.37736 .50877 Mdot
.38676 .69254 Mdot
.63296 .68754 Mdot
.67519 .37558 Mdot
.41143 .27856 Mdot
.66949 .32754 Mdot
.65117 .3193 Mdot
.71567 .40772 Mdot
.34516 .53176 Mdot
.39707 .70653 Mdot
.47603 .35198 Mdot
.50836 .71723 Mdot
.42985 .2663 Mdot
.49726 .69048 Mdot
.49626 .31623 Mdot
.38864 .27729 Mdot
.24297 .57047 Mdot
.59487 .68369 Mdot
.70133 .40771 Mdot
.35114 .50632 Mdot
.51298 .30586 Mdot
.41651 .31408 Mdot
.57493 .70369 Mdot
.41189 .31075 Mdot
.68654 .3931 Mdot
.50122 .32184 Mdot
.26129 .47802 Mdot
.39795 .45489 Mdot
.30983 .60774 Mdot
.35634 .50575 Mdot
.39405 .30495 Mdot
.4901 .68401 Mdot
.3855 .69184 Mdot
.73119 .53847 Mdot
.30599 .62825 Mdot
.32 .4977 Mdot
.70652 .36084 Mdot
.63051 .68794 Mdot
.40136 .29332 Mdot
.73533 .5254 Mdot
.40653 .28703 Mdot
.5341 .33242 Mdot
.51628 .70563 Mdot
.53558 .3319 Mdot
.41299 .698 Mdot
.69222 .5865 Mdot
.60215 .67774 Mdot
.66217 .33222 Mdot
.47209 .31722 Mdot
.70724 .39677 Mdot
.24221 .5723 Mdot
.49349 .70403 Mdot
.7177 .54569 Mdot
.67007 .32549 Mdot
.65202 .61525 Mdot
.31842 .61634 Mdot
.66138 .60102 Mdot
.36578 .50737 Mdot
.60089 .71671 Mdot
.68708 .60592 Mdot
.64725 .30114 Mdot
.32111 .66159 Mdot
.54041 .32037 Mdot
.32385 .51496 Mdot
.6628 .65821 Mdot
.70598 .54912 Mdot
.51413 .69241 Mdot
.72648 .51886 Mdot
.32692 .49181 Mdot
.49985 .32814 Mdot
.37837 .49098 Mdot
.73951 .53618 Mdot
.72071 .52648 Mdot
.65841 .29707 Mdot
.34927 .50372 Mdot
.41184 .29091 Mdot
.6659 .43036 Mdot
.68727 .37113 Mdot
.65609 .40724 Mdot
.5461 .69789 Mdot
.4853 .30903 Mdot
.50857 .32846 Mdot
.24879 .52464 Mdot
.66792 .5968 Mdot
.53302 .32599 Mdot
.28498 .49904 Mdot
.27016 .51049 Mdot
.60054 .71558 Mdot
.6858 .39888 Mdot
.33642 .49252 Mdot
.4154 .68194 Mdot
.52426 .31764 Mdot
.68666 .41054 Mdot
.5097 .70328 Mdot
.67002 .33917 Mdot
.29796 .49105 Mdot
.41016 .68396 Mdot
.49197 .68674 Mdot
.5468 .67699 Mdot
.34295 .47636 Mdot
.35539 .51157 Mdot
.67068 .5816 Mdot
.50752 .65437 Mdot
.32647 .57835 Mdot
.44052 .51754 Mdot
.48121 .32079 Mdot
.59803 .56047 Mdot
.46054 .6397 Mdot
.36967 .66357 Mdot
.50011 .58625 Mdot
.34858 .66072 Mdot
.54916 .61509 Mdot
.63075 .43129 Mdot
.4711 .56401 Mdot
.63393 .29206 Mdot
.68003 .5014 Mdot
.37728 .70556 Mdot
.34382 .33124 Mdot
.66358 .56615 Mdot
.51093 .62609 Mdot
.6855 .50415 Mdot
.60099 .44815 Mdot
.65691 .34368 Mdot
.64106 .38934 Mdot
.61047 .40188 Mdot
.30686 .51355 Mdot
.5429 .6408 Mdot
.35054 .60494 Mdot
.63304 .60085 Mdot
.6865 .46559 Mdot
.40754 .67279 Mdot
.40714 .35571 Mdot
.61587 .56924 Mdot
.44872 .38895 Mdot
.38735 .64584 Mdot
.62746 .45329 Mdot
.34787 .59925 Mdot
.40289 .40225 Mdot
.38632 .65706 Mdot
.55447 .58618 Mdot
.59958 .59373 Mdot
.40854 .6316 Mdot
.62627 .5531 Mdot
.68994 .42263 Mdot
.49199 .68193 Mdot
.68671 .52572 Mdot
.4529 .3727 Mdot
.64786 .54426 Mdot
.49919 .58719 Mdot
.5081 .34514 Mdot
.59971 .553 Mdot
.25906 .4824 Mdot
.6416 .68634 Mdot
.65266 .48022 Mdot
.67407 .46213 Mdot
.42304 .64014 Mdot
.68796 .47599 Mdot
.24741 .56609 Mdot
.51582 .62819 Mdot
.46727 .64276 Mdot
.60381 .4446 Mdot
.58512 .35828 Mdot
.63097 .67869 Mdot
.36221 .36471 Mdot
.56049 .43152 Mdot
.40753 .52249 Mdot
.66129 .49576 Mdot
.42135 .6587 Mdot
.53649 .7123 Mdot
.60821 .72078 Mdot
.63886 .34992 Mdot
.47019 .36374 Mdot
.61749 .3991 Mdot
.57017 .43149 Mdot
.65199 .53474 Mdot
.29661 .57173 Mdot
.58545 .6124 Mdot
.60985 .36413 Mdot
.50437 .66522 Mdot
.36851 .33629 Mdot
.55346 .51497 Mdot
.42984 .34193 Mdot
.44299 .6457 Mdot
.61114 .45572 Mdot
.43697 .59079 Mdot
.61608 .52765 Mdot
.23277 .53508 Mdot
.43962 .35249 Mdot
.5457 .63979 Mdot
.57415 .38232 Mdot
.65913 .56857 Mdot
.47024 .65765 Mdot
.67243 .47026 Mdot
.52506 .29909 Mdot
.45137 .43515 Mdot
.41026 .34015 Mdot
.50949 .58017 Mdot
.39421 .37735 Mdot
.6273 .45072 Mdot
.69775 .51004 Mdot
.70435 .37915 Mdot
.619 .62524 Mdot
.46721 .38311 Mdot
.55985 .70448 Mdot
.6423 .32717 Mdot
.48751 .60952 Mdot
.60744 .63651 Mdot
.40708 .34224 Mdot
.63777 .35811 Mdot
.60485 .51705 Mdot
.60027 .41835 Mdot
.59778 .58829 Mdot
.57525 .61656 Mdot
.65564 .58327 Mdot
.55225 .3303 Mdot
.56762 .66356 Mdot
.43786 .38554 Mdot
.63086 .38795 Mdot
.34889 .31868 Mdot
.31799 .47527 Mdot
.46337 .40352 Mdot
.44537 .67535 Mdot
.50497 .49037 Mdot
.64322 .59854 Mdot
.42187 .33533 Mdot
.40718 .67121 Mdot
.51779 .66224 Mdot
.61022 .39796 Mdot
.38602 .52006 Mdot
.64518 .63902 Mdot
.69022 .50329 Mdot
.66134 .35689 Mdot
.45582 .65305 Mdot
.46978 .353 Mdot
.28667 .53681 Mdot
.42514 .46506 Mdot
.69487 .46435 Mdot
.40638 .51591 Mdot
.44265 .46668 Mdot
.60686 .30037 Mdot
.61291 .64326 Mdot
.44246 .4416 Mdot
.45226 .67766 Mdot
.60728 .36039 Mdot
.62553 .42138 Mdot
.52931 .65125 Mdot
.37468 .25521 Mdot
.40681 .37599 Mdot
.45778 .47514 Mdot
.60365 .53754 Mdot
.35447 .66747 Mdot
.36338 .59072 Mdot
.62265 .44031 Mdot
.51115 .41916 Mdot
.55565 .37603 Mdot
.69093 .49853 Mdot
.55784 .7089 Mdot
.49107 .3999 Mdot
.40953 .58555 Mdot
.51711 .67189 Mdot
.49729 .43888 Mdot
.63859 .6299 Mdot
.48156 .42786 Mdot
.40571 .35126 Mdot
.64329 .37706 Mdot
.614 .36914 Mdot
.65677 .53474 Mdot
.68033 .46655 Mdot
.57975 .63697 Mdot
.58559 .6375 Mdot
.50386 .38507 Mdot
.6696 .55418 Mdot
.62123 .47525 Mdot
.61914 .71495 Mdot
.51716 .61499 Mdot
.38809 .62735 Mdot
.32067 .56799 Mdot
.43512 .5584 Mdot
.43786 .29833 Mdot
.40661 .41493 Mdot
.45672 .65531 Mdot
.38442 .24933 Mdot
.35454 .55083 Mdot
.34148 .59434 Mdot
.54479 .32404 Mdot
.29781 .55193 Mdot
.22754 .52527 Mdot
.57566 .53188 Mdot
.62307 .36593 Mdot
.45644 .49713 Mdot
.30307 .54834 Mdot
.63895 .59744 Mdot
.3745 .65639 Mdot
.42169 .33669 Mdot
.52852 .36467 Mdot
.49544 .63992 Mdot
.55008 .6562 Mdot
.73811 .49313 Mdot
.70732 .55269 Mdot
.61518 .29603 Mdot
.65746 .53389 Mdot
.5008 .72733 Mdot
.67046 .31431 Mdot
.60757 .48308 Mdot
.42716 .59874 Mdot
.34399 .61835 Mdot
.4316 .35871 Mdot
.58216 .54811 Mdot
.35709 .29095 Mdot
.45103 .61814 Mdot
.44167 .49298 Mdot
.3984 .36507 Mdot
.37148 .35589 Mdot
.37142 .36476 Mdot
.68365 .5339 Mdot
.402 .41174 Mdot
.39587 .33983 Mdot
.24151 .49334 Mdot
.56526 .46864 Mdot
.36743 .66859 Mdot
.37484 .56688 Mdot
.62946 .3231 Mdot
.56296 .4209 Mdot
.57329 .60971 Mdot
.42338 .64093 Mdot
.3969 .32869 Mdot
.22945 .51953 Mdot
.62755 .53606 Mdot
.43641 .39233 Mdot
.58006 .38993 Mdot
.45867 .39761 Mdot
.52467 .38186 Mdot
.53037 .58172 Mdot
.68916 .50452 Mdot
.33857 .26112 Mdot
.59675 .35153 Mdot
.6312 .57943 Mdot
.47834 .66602 Mdot
.63519 .32521 Mdot
.5945 .64835 Mdot
.60771 .61369 Mdot
.44165 .63444 Mdot
.38002 .58985 Mdot
.46657 .52952 Mdot
.56116 .58775 Mdot
.41697 .43125 Mdot
.54803 .40331 Mdot
.64437 .37776 Mdot
.59845 .32349 Mdot
.46366 .51647 Mdot
.55923 .46383 Mdot
.30761 .53956 Mdot
.6471 .34935 Mdot
.54981 .55502 Mdot
.32029 .57697 Mdot
.45616 .49328 Mdot
.51367 .63554 Mdot
.63349 .64103 Mdot
.3967 .58802 Mdot
.31208 .47984 Mdot
.45117 .36815 Mdot
.62553 .28532 Mdot
.51934 .37931 Mdot
.54343 .64701 Mdot
.70861 .48853 Mdot
.66545 .51699 Mdot
.33492 .5446 Mdot
.32168 .59291 Mdot
.516 .54995 Mdot
.34117 .63383 Mdot
.65891 .61996 Mdot
.53895 .71149 Mdot
.56843 .6383 Mdot
.29552 .51397 Mdot
.44219 .56878 Mdot
.55496 .63021 Mdot
.37684 .53957 Mdot
.45208 .67274 Mdot
.58118 .67317 Mdot
.60344 .35295 Mdot
.64303 .38241 Mdot
.36872 .26197 Mdot
.5547 .44132 Mdot
.39345 .27002 Mdot
.56859 .3502 Mdot
.60025 .52899 Mdot
.39129 .64308 Mdot
.71532 .48254 Mdot
.5363 .38766 Mdot
.63799 .30034 Mdot
.52835 .3805 Mdot
.62335 .41183 Mdot
.65993 .50073 Mdot
.27561 .55154 Mdot
.62071 .5824 Mdot
.68892 .49148 Mdot
.25241 .5464 Mdot
.63492 .41395 Mdot
.61282 .54251 Mdot
.64292 .68653 Mdot
.29013 .47637 Mdot
.24826 .53044 Mdot
.39463 .40387 Mdot
.28221 .5616 Mdot
.42919 .52433 Mdot
.46129 .70252 Mdot
.38927 .40832 Mdot
.63235 .53689 Mdot
.37268 .66967 Mdot
.54552 .658 Mdot
.64491 .62718 Mdot
.4709 .66772 Mdot
.65179 .33021 Mdot
.71601 .49742 Mdot
.56203 .62699 Mdot
.3437 .54901 Mdot
.41516 .38788 Mdot
.34635 .54141 Mdot
.56056 .65763 Mdot
.39485 .57179 Mdot
.63245 .63741 Mdot
.42974 .64124 Mdot
.5689 .49953 Mdot
.61969 .63087 Mdot
.46241 .6123 Mdot
.45581 .66792 Mdot
.41737 .71201 Mdot
.49289 .37224 Mdot
.40404 .43561 Mdot
.54642 .59327 Mdot
.38056 .47803 Mdot
.49232 .4914 Mdot
.49597 .61052 Mdot
.30359 .52597 Mdot
.52835 .60317 Mdot
.36099 .37178 Mdot
.58557 .72519 Mdot
.58386 .58495 Mdot
.52306 .41331 Mdot
.31572 .52407 Mdot
.38609 .64453 Mdot
.47303 .65601 Mdot
.68967 .50033 Mdot
.4002 .42711 Mdot
.47503 .36277 Mdot
.5458 .49845 Mdot
.30309 .54463 Mdot
.46417 .45812 Mdot
.40266 .42436 Mdot
.55258 .32524 Mdot
.51653 .38366 Mdot
.60161 .56008 Mdot
.3388 .33054 Mdot
.65075 .43588 Mdot
.43276 .5519 Mdot
.43584 .59478 Mdot
.60648 .34899 Mdot
.45804 .59569 Mdot
.47402 .58021 Mdot
.46785 .49136 Mdot
.62578 .33839 Mdot
.5786 .56537 Mdot
.62052 .54602 Mdot
.58104 .67199 Mdot
.39055 .34966 Mdot
.56281 .6106 Mdot
.60687 .6191 Mdot
.53871 .4112 Mdot
.37561 .50726 Mdot
.42587 .56222 Mdot
.64426 .64864 Mdot
.50706 .45563 Mdot
.57538 .62532 Mdot
.63337 .28596 Mdot
.58824 .54294 Mdot
.45704 .50659 Mdot
.3398 .32538 Mdot
.33384 .31408 Mdot
.40041 .60915 Mdot
.41294 .32764 Mdot
.63332 .53437 Mdot
.5701 .65401 Mdot
.62521 .55923 Mdot
.29716 .58092 Mdot
.56821 .71596 Mdot
.50186 .36487 Mdot
.74363 .49441 Mdot
.63981 .59295 Mdot
.43562 .61696 Mdot
.45527 .34726 Mdot
.55694 .47367 Mdot
.61658 .48673 Mdot
.70374 .49044 Mdot
.64424 .3624 Mdot
.6294 .35749 Mdot
.41228 .5604 Mdot
.6485 .4608 Mdot
.58914 .35724 Mdot
.60022 .64299 Mdot
.63605 .30538 Mdot
.57991 .3674 Mdot
.42763 .67621 Mdot
.60893 .36427 Mdot
.56974 .67069 Mdot
.66967 .46723 Mdot
.49335 .60663 Mdot
.59602 .53541 Mdot
.50911 .4362 Mdot
.57145 .6599 Mdot
.68047 .5294 Mdot
.58121 .49527 Mdot
.23601 .5614 Mdot
.47346 .66155 Mdot
.51518 .66572 Mdot
.35688 .6096 Mdot
.599 .51277 Mdot
.35295 .35797 Mdot
.74971 .53074 Mdot
.26154 .56267 Mdot
.64211 .68696 Mdot
.23639 .50004 Mdot
.61962 .47826 Mdot
.33286 .65238 Mdot
.49063 .37373 Mdot
.62306 .47875 Mdot
.3623 .35417 Mdot
.64973 .27682 Mdot
.38522 .39866 Mdot
.58526 .60416 Mdot
.5662 .3518 Mdot
.6257 .32268 Mdot
.61794 .30926 Mdot
.35842 .34178 Mdot
.58837 .34871 Mdot
.24468 .54523 Mdot
.58311 .50821 Mdot
.30496 .57745 Mdot
.36665 .53348 Mdot
.60275 .34226 Mdot
.46938 .71645 Mdot
.42336 .39895 Mdot
.47535 .62637 Mdot
.63441 .39814 Mdot
.39407 .4091 Mdot
.24523 .50651 Mdot
.49318 .45962 Mdot
.60744 .43261 Mdot
.71404 .39077 Mdot
.34791 .30345 Mdot
.53464 .65286 Mdot
.49855 .39699 Mdot
.52101 .66088 Mdot
.47189 .67296 Mdot
.63594 .43887 Mdot
.46617 .63422 Mdot
.34345 .25832 Mdot
.64664 .48984 Mdot
.53277 .35817 Mdot
.61485 .53447 Mdot
.6502 .65507 Mdot
.39235 .51496 Mdot
.50071 .38266 Mdot
.50229 .40021 Mdot
.35137 .33788 Mdot
.4281 .40415 Mdot
.43051 .41526 Mdot
.35647 .36559 Mdot
.49695 .63353 Mdot
.27886 .56607 Mdot
.39751 .36102 Mdot
.40104 .62877 Mdot
.4701 .36468 Mdot
.65799 .5934 Mdot
.60056 .454 Mdot
.61392 .6569 Mdot
.29835 .56173 Mdot
.29384 .56534 Mdot
.54586 .38612 Mdot
.65585 .5728 Mdot
.45179 .53432 Mdot
.45889 .47804 Mdot
.67696 .46825 Mdot
.29456 .58213 Mdot
.53264 .5909 Mdot
.34448 .31176 Mdot
.31097 .47884 Mdot
.54706 .29182 Mdot
.61754 .36823 Mdot
.61928 .58301 Mdot
.59266 .52203 Mdot
.60643 .66059 Mdot
.42223 .53324 Mdot
.27213 .52706 Mdot
.395 .35137 Mdot
.59208 .52059 Mdot
.33456 .59354 Mdot
.40937 .48158 Mdot
.60399 .62389 Mdot
.65656 .55286 Mdot
.5088 .58898 Mdot
.58713 .448 Mdot
.28882 .47194 Mdot
.6149 .3968 Mdot
.63544 .28563 Mdot
.35323 .35588 Mdot
.66133 .54572 Mdot
.29371 .56057 Mdot
.44946 .45395 Mdot
.57894 .40903 Mdot
.34151 .30977 Mdot
.65242 .35029 Mdot
.45652 .65601 Mdot
.6319 .40847 Mdot
.65574 .56518 Mdot
.61306 .48067 Mdot
.27258 .55737 Mdot
.36322 .36666 Mdot
.42507 .60749 Mdot
.56159 .51682 Mdot
.47629 .45033 Mdot
.33528 .63731 Mdot
.54698 .63774 Mdot
.3805 .5927 Mdot
.68373 .55433 Mdot
.35078 .34017 Mdot
.61123 .41739 Mdot
.40952 .44245 Mdot
.34591 .33422 Mdot
.47111 .71034 Mdot
.57052 .64146 Mdot
.69543 .5144 Mdot
.30784 .54913 Mdot
.71546 .3886 Mdot
.27251 .48368 Mdot
.22946 .54884 Mdot
.46446 .60738 Mdot
.49557 .40776 Mdot
.34886 .25657 Mdot
.4638 .66574 Mdot
.60678 .40015 Mdot
.4611 .67118 Mdot
.62897 .2963 Mdot
.52809 .57744 Mdot
.45934 .64286 Mdot
.41577 .53478 Mdot
.65608 .50325 Mdot
.50186 .63314 Mdot
.44736 .38974 Mdot
.38198 .56234 Mdot
.45011 .63783 Mdot
.45006 .64352 Mdot
.41904 .59414 Mdot
.62622 .61289 Mdot
.43298 .38196 Mdot
.63106 .36967 Mdot
.37288 .24832 Mdot
.39874 .6301 Mdot
.30236 .56972 Mdot
.60044 .53505 Mdot
.46494 .39484 Mdot
.66454 .28866 Mdot
.34051 .26927 Mdot
.35976 .63693 Mdot
.63566 .63932 Mdot
.52441 .54173 Mdot
.32074 .58867 Mdot
.29212 .573 Mdot
.67044 .49514 Mdot
.60222 .52075 Mdot
.44494 .51914 Mdot
.46491 .69409 Mdot
.66969 .6278 Mdot
.43676 .30397 Mdot
.37925 .24975 Mdot
.64147 .55842 Mdot
.38598 .60475 Mdot
.61508 .3553 Mdot
.64873 .66348 Mdot
.3915 .25505 Mdot
.63756 .51263 Mdot
.29555 .51183 Mdot
.35833 .57707 Mdot
.33661 .26761 Mdot
.39916 .39356 Mdot
.47124 .70083 Mdot
.58261 .64523 Mdot
.65515 .47666 Mdot
.53206 .38988 Mdot
.56581 .53714 Mdot
.59929 .34074 Mdot
.45599 .42856 Mdot
.50367 .39114 Mdot
.456 .63072 Mdot
.5007 .57266 Mdot
.62323 .39166 Mdot
.55933 .35639 Mdot
.63357 .38233 Mdot
.42708 .50004 Mdot
.56637 .43336 Mdot
.63976 .40094 Mdot
.49702 .45091 Mdot
.6428 .52489 Mdot
.37383 .66654 Mdot
.51363 .55485 Mdot
.62419 .33541 Mdot
.47395 .68738 Mdot
.59426 .43151 Mdot
.48683 .64279 Mdot
.63937 .5895 Mdot
.43523 .3865 Mdot
.56741 .64702 Mdot
.62932 .37654 Mdot
.30554 .57353 Mdot
.56896 .39636 Mdot
.38136 .63935 Mdot
.41006 .51014 Mdot
.51366 .34329 Mdot
.42331 .45755 Mdot
.54482 .30576 Mdot
.23809 .52198 Mdot
.36844 .546 Mdot
.43881 .35712 Mdot
.23445 .52832 Mdot
.51374 .43703 Mdot
.61447 .45756 Mdot
.62738 .70992 Mdot
.41749 .3384 Mdot
.27569 .5313 Mdot
.57439 .66312 Mdot
.62698 .35812 Mdot
.55086 .29926 Mdot
.34449 .33381 Mdot
.65572 .56947 Mdot
.53118 .43421 Mdot
.63662 .29496 Mdot
.55084 .49851 Mdot
.5826 .34246 Mdot
.61463 .53444 Mdot
.47815 .67597 Mdot
.40479 .34715 Mdot
.62046 .46696 Mdot
.50803 .4405 Mdot
.32104 .5801 Mdot
.43112 .63984 Mdot
.25743 .5365 Mdot
.31736 .56042 Mdot
.69074 .42302 Mdot
.33864 .5864 Mdot
.62888 .44799 Mdot
.40618 .6112 Mdot
.61278 .35765 Mdot
.59237 .32645 Mdot
.57008 .41892 Mdot
.69291 .47953 Mdot
.34301 .33863 Mdot
.43078 .41225 Mdot
.36446 .67433 Mdot
.45695 .67064 Mdot
.34759 .26074 Mdot
.5906 .34815 Mdot
.4001 .42569 Mdot
.35478 .58984 Mdot
.45359 .43284 Mdot
.50209 .36794 Mdot
.50334 .47769 Mdot
.74972 .53227 Mdot
.40299 .62265 Mdot
.57031 .66297 Mdot
.49468 .64907 Mdot
.6788 .55944 Mdot
.62174 .33398 Mdot
.5613 .62656 Mdot
.49926 .58234 Mdot
.49768 .43139 Mdot
.59226 .31563 Mdot
.64152 .56971 Mdot
.65334 .62428 Mdot
.39434 .64624 Mdot
.3522 .35106 Mdot
.48739 .6683 Mdot
.49734 .60401 Mdot
.55357 .57559 Mdot
.34103 .53515 Mdot
.65704 .58223 Mdot
.56066 .64307 Mdot
.44341 .6613 Mdot
.37717 .37647 Mdot
.56611 .59356 Mdot
.56197 .35197 Mdot
.6431 .4344 Mdot
.53978 .57534 Mdot
.59658 .33094 Mdot
.61009 .72112 Mdot
.37415 .36826 Mdot
.30765 .54349 Mdot
.5554 .31236 Mdot
.28819 .47906 Mdot
.45606 .61621 Mdot
.51846 .38259 Mdot
.56391 .53616 Mdot
.64579 .63104 Mdot
.47625 .64994 Mdot
.6423 .33845 Mdot
.40214 .26327 Mdot
.71564 .47994 Mdot
.60993 .44305 Mdot
.34369 .59649 Mdot
.33928 .60104 Mdot
.61545 .60579 Mdot
.60428 .53977 Mdot
.4602 .58297 Mdot
.58455 .44627 Mdot
.38497 .62157 Mdot
.53723 .36211 Mdot
.34523 .30158 Mdot
.43291 .67069 Mdot
.64244 .30785 Mdot
.40615 .65048 Mdot
.42457 .65532 Mdot
.60376 .40053 Mdot
.58259 .59553 Mdot
.52562 .42373 Mdot
.51966 .40959 Mdot
.57574 .68824 Mdot
.3354 .2856 Mdot
.57497 .62655 Mdot
.58749 .43051 Mdot
.66442 .4772 Mdot
.50457 .6158 Mdot
.7152 .37523 Mdot
.67456 .51408 Mdot
.64144 .33163 Mdot
.60977 .36373 Mdot
.67705 .50356 Mdot
.62541 .54057 Mdot
.61566 .63288 Mdot
.39656 .36656 Mdot
.61539 .45451 Mdot
.45133 .38703 Mdot
.68371 .54847 Mdot
.40667 .57917 Mdot
.22953 .52844 Mdot
.28574 .53573 Mdot
.39686 .54635 Mdot
.42948 .44431 Mdot
.3801 .38376 Mdot
.53723 .30927 Mdot
.37557 .24999 Mdot
.66604 .46949 Mdot
.33737 .30107 Mdot
.50339 .62986 Mdot
.51486 .34535 Mdot
.54085 .40582 Mdot
.56461 .59272 Mdot
.25713 .56129 Mdot
.46359 .48652 Mdot
.57041 .36021 Mdot
.60812 .62512 Mdot
.51032 .65024 Mdot
.48501 .36594 Mdot
.29044 .47988 Mdot
.34529 .65882 Mdot
.64463 .60279 Mdot
.7128 .38273 Mdot
.48705 .65131 Mdot
.35052 .30324 Mdot
.66373 .62166 Mdot
.70845 .47821 Mdot
.61794 .59937 Mdot
.50684 .39559 Mdot
.7054 .50843 Mdot
.63663 .61833 Mdot
.64173 .27625 Mdot
.66063 .63272 Mdot
.41593 .44309 Mdot
.52709 .6686 Mdot
.23755 .52255 Mdot
.43038 .47045 Mdot
.55049 .33169 Mdot
.47532 .37277 Mdot
.28741 .57385 Mdot
.59865 .44437 Mdot
.37254 .38275 Mdot
.62626 .39852 Mdot
.64484 .43164 Mdot
.64815 .6003 Mdot
.43597 .62673 Mdot
.72057 .49193 Mdot
.6645 .48507 Mdot
.3694 .64416 Mdot
.38319 .39637 Mdot
.42262 .43149 Mdot
.56276 .53046 Mdot
.45571 .46941 Mdot
.41154 .35977 Mdot
.6098 .3296 Mdot
.70193 .37039 Mdot
.6754 .36298 Mdot
.29736 .53033 Mdot
.56736 .41288 Mdot
.45364 .54555 Mdot
.3928 .39871 Mdot
.66122 .50293 Mdot
.61991 .46517 Mdot
.62234 .38033 Mdot
.45606 .61644 Mdot
.31542 .47479 Mdot
.35494 .34691 Mdot
.37535 .5714 Mdot
.65295 .3387 Mdot
.6829 .53734 Mdot
.66829 .47039 Mdot
.34096 .30513 Mdot
.45169 .58224 Mdot
.37495 .55005 Mdot
.33873 .33368 Mdot
.43439 .34369 Mdot
.61318 .63228 Mdot
.38037 .51893 Mdot
.64553 .27357 Mdot
.68136 .4896 Mdot
.5364 .39496 Mdot
.53863 .71227 Mdot
.66327 .44755 Mdot
.3327 .56805 Mdot
.39742 .42271 Mdot
.58915 .44051 Mdot
.47316 .70897 Mdot
.4404 .63285 Mdot
.61831 .44051 Mdot
.63565 .41787 Mdot
.37702 .61827 Mdot
.5867 .7254 Mdot
.42766 .516 Mdot
.49023 .6817 Mdot
.48252 .37635 Mdot
.34728 .28707 Mdot
.40704 .65741 Mdot
.38436 .37116 Mdot
.34011 .6591 Mdot
.48021 .61628 Mdot
.39759 .64924 Mdot
.28207 .55346 Mdot
.62191 .44057 Mdot
.33761 .30904 Mdot
.39114 .61192 Mdot
.34686 .29044 Mdot
.50395 .36141 Mdot
.47671 .69605 Mdot
.41309 .59229 Mdot
.30826 .5633 Mdot
.5535 .61163 Mdot
.59006 .60392 Mdot
.67879 .46943 Mdot
.58324 .34049 Mdot
.63667 .49101 Mdot
.31369 .48406 Mdot
.44856 .47238 Mdot
.49287 .38504 Mdot
.61312 .47917 Mdot
.48753 .38346 Mdot
.43217 .48906 Mdot
.27485 .47854 Mdot
.33482 .32532 Mdot
.56831 .65514 Mdot
.33941 .55746 Mdot
.40557 .25384 Mdot
.51367 .34539 Mdot
.33051 .65976 Mdot
.65955 .61845 Mdot
.30596 .52059 Mdot
.66729 .45309 Mdot
.47109 .37496 Mdot
.40567 .64849 Mdot
.30092 .56682 Mdot
.69968 .47359 Mdot
.28741 .47321 Mdot
.31742 .57638 Mdot
.65467 .60578 Mdot
.65193 .45566 Mdot
.68226 .34827 Mdot
.63726 .59635 Mdot
.52504 .63 Mdot
.23414 .56317 Mdot
.54126 .33693 Mdot
.62971 .44137 Mdot
.61374 .60507 Mdot
.64596 .59835 Mdot
.62991 .37814 Mdot
.43033 .41842 Mdot
.66109 .5548 Mdot
.57825 .33815 Mdot
.27761 .56406 Mdot
.4495 .46184 Mdot
.5786 .6168 Mdot
.38959 .58014 Mdot
.41582 .3691 Mdot
.38118 .26521 Mdot
.54477 .31811 Mdot
.39808 .56211 Mdot
.43687 .36048 Mdot
.66837 .61778 Mdot
.6228 .28211 Mdot
.58442 .59112 Mdot
.48353 .64172 Mdot
.40192 .55041 Mdot
.5877 .52714 Mdot
.39553 .66766 Mdot
.38091 .51908 Mdot
.41281 .50453 Mdot
.70538 .48157 Mdot
.59605 .52504 Mdot
.51575 .62284 Mdot
.53334 .61315 Mdot
.41666 .40551 Mdot
.38883 .66846 Mdot
.3342 .49149 Mdot
.54488 .31121 Mdot
.22591 .53899 Mdot
.55374 .32757 Mdot
.54492 .41682 Mdot
.69522 .49276 Mdot
.63494 .44574 Mdot
.6504 .43615 Mdot
.45114 .41036 Mdot
.41008 .35518 Mdot
.37154 .66478 Mdot
.39614 .39466 Mdot
.4823 .47894 Mdot
.67641 .5326 Mdot
.36749 .57728 Mdot
.34179 .31577 Mdot
.44157 .47625 Mdot
.44061 .32223 Mdot
.52629 .36317 Mdot
.4676 .39074 Mdot
.66655 .51502 Mdot
.59594 .66613 Mdot
.66768 .46747 Mdot
.33987 .5452 Mdot
.50993 .65403 Mdot
.36527 .26333 Mdot
.54144 .38317 Mdot
.58896 .46869 Mdot
.58251 .61132 Mdot
.37875 .59806 Mdot
.35495 .53315 Mdot
.70456 .41729 Mdot
.39493 .57191 Mdot
.43222 .44284 Mdot
.37903 .38469 Mdot
.36439 .67769 Mdot
.50716 .52846 Mdot
.43913 .46671 Mdot
.35327 .33984 Mdot
.70803 .41695 Mdot
.33308 .59323 Mdot
.38246 .65525 Mdot
.69914 .49468 Mdot
.55566 .30483 Mdot
.35217 .3552 Mdot
.69 .49006 Mdot
.58414 .44518 Mdot
.661 .64242 Mdot
.44318 .45777 Mdot
.44424 .6671 Mdot
.63203 .57516 Mdot
.48285 .297 Mdot
.46638 .4509 Mdot
.32715 .28968 Mdot
.51573 .38869 Mdot
.52201 .4252 Mdot
.3771 .64807 Mdot
.62065 .37529 Mdot
.34394 .62575 Mdot
.66612 .55341 Mdot
.49103 .37502 Mdot
.70307 .46789 Mdot
.63995 .28429 Mdot
.54291 .58392 Mdot
.61601 .71842 Mdot
.56396 .41315 Mdot
.52236 .65649 Mdot
.59154 .50591 Mdot
.58409 .72568 Mdot
.54349 .65781 Mdot
.40291 .40223 Mdot
.57168 .56418 Mdot
.60004 .67272 Mdot
.39768 .61752 Mdot
.52924 .54976 Mdot
.59038 .58528 Mdot
.49834 .60352 Mdot
.50643 .58223 Mdot
.63746 .57828 Mdot
.51964 .53347 Mdot
.57415 .65508 Mdot
.63224 .55645 Mdot
.42445 .47605 Mdot
.61367 .43002 Mdot
.46387 .40522 Mdot
.67114 .31409 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0?ooooooB_ooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A006ooooo`03o`000?oooooooooo0?ooooooB_ooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0?ooooooB_oo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06
ooooo`?o0000oooooom:ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<oooo
o`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom:ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001_ooool00ol0003oooooooooo`3ooooood[ooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0M_ooool2o`000004ooooool0003o0000o`000<gooooo000Looooo`03o`00
0?oooooooooo07Gooooo0ol000000ooooooo0000o`000005o`000<Wooooo000Looooo`;o0000L?oo
ool3o`0000?ooooo2ol00039ooooo`007?ooool00ol0003oooooooooo`1]ooooo`Go00001?ooool3
o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l00000a?ooool001cooooo00?o0000oooo
ooooool0Joooool5o`0000Kooooo0_l00003ooooo`;o00000oooool2o`000004ooooool0003o0000
o`000<?ooooo000Looooo`03o`000?oooooooooo06[ooooo1_l0000Dooooo`Co0000`Oooool001co
oooo00?o0000ooooooooool0JOooool3o`000003ooooool0003o000000Cooooo0ol00009ooooo`;o
00000oooool4o`000<7ooooo000Looooo`03o`000?oooooooooo06Sooooo1?l00007ooooo`?o0000
0_ooool2o`0000Gooooo0_l00003ooooo`?o000000?oooooo`000?l00000_oooool001cooooo00?o
0000ooooooooool0Ioooool6o`0000_ooooo0_l00002ooooo`?o00001_ooool6o`000;kooooo000L
ooooo`03o`000?oooooooooo06Oooooo0_l00002ooooo`;o00002oooool;o`0000;ooooo1_l0000o
ooooo`Ko0000NOooool001cooooo00?o0000ooooooooool0I_ooool3o`0000gooooo3_l000000ooo
oooo0000o`000005o`0003kooooo1ol0001hooooo`007?ooool00ol0003oooooooooo`1Vooooo`?o
00003?oooolGo`00047ooooo1?l000000ooooooo0000o`00001eooooo`007?ooool00ol0003ooooo
ooooo`1Vooooo`;o00002ooooolJo`0003[ooooo0_l00004ooooo`So0000M?ooool001cooooo00?o
0000ooooooooool0I_ooool2o`000003ooooool0003o000000Oooooo6ol0000jooooo`;o000000?o
ooooo`000?l000002_l0001cooooo`007?ooool00ol0003oooooooooo`1Vooooo`;o000000?ooooo
o`000?l000000_ooool2o`0000?ooooo5?l000000ooooooo0000o`000002o`000003ooooool0003o
000003Cooooo0_l00003ooooo`;o000000?oooooo`000?l000002ol0001booooo`007?ooool00ol0
003oooooooooo`1Vooooo`?o00001?ooool2o`000004ooooool0003o0000oooooa?o000000?ooooo
o`000?l000000_l000001?oooooo0000o`000?l0000Oooooo`Co00004?ooool2o`0000Kooooo0_l0
0002ooooo`Wo0000L_ooool001cooooo00?o0000ooooooooool0I_ooool3o`0000Cooooo0_l00000
0ooooooo0000o`00000Jo`000003ooooool0003o000001oooooo1_l0000Fooooo`?o000000?ooooo
o`000?l000002?l0001aooooo`007?ooool00ol0003oooooooooo`1aoooooa_o000000?oooooo`00
0?l000002_ooool2o`0000?ooooo1Ol000000ooooooo0000o`00000;ooooo`?o00003?ooool2o`00
00;ooooo0_l00003ooooo`Co000000?oooooo`000?l000002?l0001aooooo`007?ooool2o`0006So
oooo0_l000000ooooooo0000o`000002o`0000?ooooo5Ol000000ooooooo0000o`000003o`000004
ooooool0003o0000o`0000Wooooo0_l000000ooooooo0000o`00000;o`0000Kooooo0_l00002oooo
o`;o00002oooool3o`000003ooooool0003o000000?ooooo3_l0001booooo`007?ooool00ol0003o
ooooooooo`1Wooooo`;o000000?oooooo`000?l000006Ol000000ooooooo0000o`000008o`0000Wo
oooo4?l00006ooooo`;o00000_ooool2o`0000cooooo0_l00008ooooo`co0000L_ooool001cooooo
00?o0000ooooooooool0Ioooool2o`0000;ooooo9?l00005oooooaOo00000_ooool2o`0000;ooooo
0_l0000Hooooo`ko0000L?ooool001cooooo00?o0000ooooooooool0J_ooool3o`0000Gooooo5ol0
00000ooooooo0000o`000002o`0000Gooooo7?l00002ooooo`Co00004?ooool2o`0000Cooooo3_l0
001`ooooo`007?ooool00ol0003oooooooooo`1Zooooo`Co00001?ooool4o`000003ooooool0003o
0000013o00001ooooolOo`0000;ooooo1?l00008ooooo`;o00001_ooool2o`0000Kooooo3?l0001`
ooooo`007?ooool00ol0003oooooooooo`1Yooooo`Go00002OoooolBo`0000Gooooo8Ol00002oooo
o`Co00002?ooool2o`0000oooooo2ol0001`ooooo`007?ooool00ol0003oooooooooo`1Yooooo`Co
000000?oooooo`000?l000003Oooool9o`000003ooooool0003o000000Cooooo1?l000000ooooooo
0000o`00000Ko`0000?ooooo0ol00008ooooo`;o00003oooool;o`00073ooooo000Looooo`03o`00
0?oooooooooo06kooooo0_l0000Gooooo`;o00000_ooool6o`000003ooooool0003o000001_o0000
0oooool3o`0001;ooooo1?l00004ooooo`Wo0000LOooool001cooooo00?o0000ooooooooool0JOoo
ool4o`0000[ooooo0_l00002ooooo`;o00003_ooool5o`000003ooooool0003o000001co000000Co
ooooo`000?l0003o00003?ooool2o`0000Kooooo1_l00002ooooo`Wo0000LOooool001cooooo00?o
0000ooooooooool0JOooool4o`0000[ooooo0_l00002ooooo`Co00000oooool2o`0000Oooooo0ol0
0003oooooako000000Coooooo`000?l0003o00002_ooool4o`0000[ooooo1?l000000ooooooo0000
o`000006o`00077ooooo000Looooo`03o`000?oooooooooo06[ooooo1?l0000?ooooo`;o00000ooo
ool2o`0000Kooooo0ol00005oooooaco000000Coooooo`000?l0003o00002oooool3o`0000;ooooo
0_l00009ooooo`;o000000?oooooo`000?l000001_l0001aooooo`007?ooool00ol0003ooooooooo
o`1Zooooo`Go00005_ooool2o`0000?ooooo1?l00004ooooo`;o00000_oooolHo`000004ooooool0
003o0000o`0000Gooooo0_l00005ooooo`;o00000_ooool2o`0000;ooooo0ol00004ooooo`;o0000
00?oooooo`000?l000001?l0001cooooo`007?ooool00ol0003oooooooooo`1Zooooo`Ko00001?oo
ool2o`0000kooooo0ol00003ooooo`Co00002Oooool5o`000003ooooool0003o0000017o00001ooo
ool3o`0000cooooo0ol00004ooooo`;o00001?ooool4o`0007;ooooo000Looooo`03o`000?oooooo
oooo06cooooo1Ol00003ooooo`;o00001oooool2o`0000?ooooo1Ol00004ooooo`Go00002_ooool@
o`0000;ooooo1?l00008ooooo`Co00000oooool2o`0000Kooooo0_l00004ooooo`;o000000?ooooo
o`000?l000000oooool3o`00077ooooo000Looooo`03o`000?oooooooooo06kooooo1Ol0000:oooo
o`;o000000?oooooo`000?l000000_l00004ooooo`?o00000_ooool4o`0000_ooooo4?l0000=oooo
o`?o00000oooool3o`0000kooooo1?l00002ooooo`;o0000LOooool001cooooo00?o0000oooooooo
ool0L?ooool3o`0000gooooo0_l00006ooooo`?o00000oooool4o`000003ooooool0003o000000Oo
oooo0ol00002ooooo`Oo000000Coooooo`000?l0003o00001Oooool2o`0000Kooooo0_l00005oooo
o`;o00004?ooool2o`0000Gooooo0_l0001^ooooo`007?ooool2o`00077ooooo0_l00009ooooo`;o
00000oooool2o`0000kooooo0_l000000ooooooo0000o`000003o`0000Wooooo1ol00009ooooo`;o
00000_ooool2o`0000Cooooo0ol00003ooooo`;o00002Oooool6o`0000Oooooo1Ol0001[ooooo`00
7?ooool00ol0003oooooooooo`1_ooooo`;o00002_ooool4o`000003ooooool0003o000000Wooooo
0_l00006ooooo`Ko00006_ooool4o`0000Cooooo2?l00009ooooo`Ko00002?ooool5o`0006[ooooo
000Looooo`03o`000?oooooooooo06oooooo0_l000001?oooooo0000o`000?ooool2o`0000Kooooo
0_l000001?oooooo0000o`000?l00008ooooo`;o00002?ooool7o`0000kooooo1Ol00003ooooo`Co
00002?ooool4o`0000;ooooo0_l0000=ooooo`;o00002?ooool3o`0006Wooooo000Looooo`03o`00
0?oooooooooo06oooooo0_l000001?oooooo0000o`000?ooool2o`0000[ooooo0ol00004ooooo`;o
000000?oooooo`000?l000003?ooool3o`000004ooooool0003o0000ooooo`Go00000oooool7o`00
00?ooooo0_l00002ooooo`;o00000_ooool4o`0000Gooooo0ol00002ooooo`Go00001_ooool2o`00
00Wooooo0_l000000ooooooo0000o`00001Vooooo`007?ooool00ol0003oooooooooo`1_ooooo`;o
00003?ooool2o`0000?ooooo0_l00004ooooo`Co00002oooool2o`0000Cooooo0_l000000ooooooo
0000o`000003o`0000;ooooo1_l00009ooooo`;o00000_ooool4o`0000?ooooo1?l00003ooooo`Oo
00001_ooool2o`000003ooooool0003o000000Oooooo0ol0001Uooooo`007?ooool00ol0003ooooo
ooooo`1`ooooo`Co000000?oooooo`000?l000001_ooool3o`0000[ooooo0_l00009ooooo`Co0000
00?oooooo`000?l000000oooool3o`0000Gooooo0ol000000ooooooo0000o`00000Dooooo`?o0000
0oooool2o`0000Cooooo0_l00004ooooo`Oo00001oooool5o`0006?ooooo000Looooo`03o`000?oo
oooooooo073ooooo1?l000001?oooooo0000o`000?l00005ooooo`?o00000oooool2o`0000[ooooo
0_l00004ooooo`;o00000oooool2o`0000?ooooo0_l00007ooooo`;o00003oooool2o`0000Oooooo
1ol00009ooooo`[o00001oooool3o`0006?ooooo000Looooo`03o`000?oooooooooo07;ooooo0_l0
0002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l0000:ooooo`;o00002ooo
ool2o`000003ooooool0003o000001Sooooo0_l00009ooooo`?o00000_ooool2o`0000Cooooo0_l0
00000ooooooo0000o`00000;o`000003ooooool0003o000000;ooooo0_l0001Sooooo`007?ooool0
0ol0003oooooooooo`1booooo`;o00001Oooool2o`0001Cooooo0_l00004ooooo`Co00000oooool2
o`0002Sooooo0_l000000ooooooo0000o`000004oooooa3o000000?oooooo`000?l000000oooool2
o`0006;ooooo000Looooo`03o`000?oooooooooo07Oooooo0_l00003ooooo`;o00000_ooool2o`00
00gooooo0_l00004ooooo`Ko000000?oooooo`000?l000004oooool2o`0001?ooooo0_l000000ooo
oooo0000o`000002oooooaCo00001?ooool3o`00067ooooo000Looooo`03o`000?oooooooooo07Oo
oooo0_l00003ooooo`;o00000_ooool2o`0001Oooooo0_l0000:ooooo`;o000000?oooooo`000?l0
00001oooool2o`0001?ooooo0_l000000ooooooo0000o`000002oooooaKo00000oooool2o`00067o
oooo000Looooo`03o`000?oooooooooo07Gooooo1Ol0000?ooooo`;o00002Oooool2o`0000Gooooo
0_l00002ooooo`;o00000oooool6o`0000;ooooo0_l00009ooooo`;o00003Oooool2o`0000;ooooo
0_l000000ooooooo0000o`00000Do`000003ooooool0003o000000;o0000HOooool001cooooo00?o
0000ooooooooool0MOooool5o`0000Wooooo0_l00004ooooo`?o00000oooool2o`0000?ooooo0_l0
0005ooooo`?o000000Coooooo`000?l0003o00000_ooool5o`000003ooooool0003o000000Co0000
1oooool2o`00013ooooo0ol000000ooooooo0000o`00000Do`000003ooooool0003o000000?o0000
H?ooool001cooooo00?o0000ooooooooool0MOooool3o`0000_ooooo0_l00005ooooo`;o00000_oo
ool3o`0000?ooooo0_l00006ooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`?o00000_oo
ool2o`0000Wooooo0_l0000>ooooo`;o000000?oooooo`000?l000005Ol000000ooooooo0000o`00
0003o`00063ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o0000
00?o410@ooooooooool01?ooool00ol0003oooooooooo`1fooooo`;o00001_ooool2o`0000[ooooo
0_l00002ooooo`;o00001?ooool2o`0000[ooooo0_l00002ooooo`;o00000oooool2o`0000kooooo
0_l0000<ooooo`;o00000ooooolMo`00063ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0NOooool2o`0000;o
oooo0ol0000:ooooo`;o00001oooool2o`0000Wooooo1Ol00007ooooo`;o00002Oooool2o`0000go
oooo0_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000006?l0001Pooooo`00
00?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`Go00001_ooool00ol0003ooooo
ooooo`1iooooo`;o000000Coooooo`000?l0003o00001oooool2o`0000Wooooo1?l00007ooooo`Oo
00001oooool2o`0000Wooooo0_l0000:ooooo`Ko000000?oooooo`000?l000000_l00002oooooa_o
0000H?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?m4A4CogMgM
ooooool00007ooooo`?o0000NOooool2o`000004ooooool0003o0000ooooo`;o00001Oooool2o`00
00Wooooo0_l00009ooooo`;o000000?oooooo`000?l000003Oooool2o`00013ooooo1ol000000ooo
oooo0000o`00000<o`000005ooooool0003o0000o`000?ooool03_l0001Pooooo`0000?oooooo`00
0?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000
ooooooooool0O?ooool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`00000:
ooooo`;o00005oooool4o`00013ooooo0_l000000ooooooo0000o`000007ooooo`;o000000?ooooo
o`000?l000002Ol000000ooooooo0000o`00000;o`00067ooooo00000ooooooo410@ooooo`02oooo
o`03oa0@4?oooooooooo00[ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`1koooo
o`?o00001_ooool2o`000003ooooool0003o000000[ooooo0_l00008ooooo`;o00003Oooool2o`00
00[ooooo0_l0000?ooooo`;o00001?oooolHo`0006;ooooo00001_ooooooMgMgoiRHV?ooooooV9RH
ogMgM`cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`1kooooo`?o000000?ooooo
o`000?l000001oooool2o`0000Gooooo0_l0000<ooooo`;o00001_ooool2o`0000Cooooo0_l0000;
ooooo`;o00003Oooool4o`0000Gooooo1_l00002ooooo`oo0000H_ooool00006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo07oooooo0ol0
0006ooooo`;o00001Oooool2o`0001Cooooo0ol00003ooooo`;o00001_ooool4o`00013ooooo0_l0
00001?oooooo0000o`000?ooool2o`000003ooooool0003o000001Go0000H_ooool001cooooo00?o
0000ooooooooool0P?ooool2o`0000Kooooo0_l0000Looooo`;o00001Oooool2o`0000Cooooo1?l0
0008ooooo`;o00000_ooool2o`0000Gooooo1Ol00002oooooaKo0000H_ooool001cooooo00?o0000
ooooooooool0O?ooool2o`0000[ooooo0_l0000Hooooo`;o00002Oooool2o`0000Cooooo1?l00008
ooooo`;o00000_ooool2o`0000;ooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo5Ol0
001Sooooo`007?ooool00ol0003oooooooooo`1looooo`Go00008Oooool2o`0000?ooooo0_l0000:
ooooo`Co00004?ooool2o`0000Gooooo0_l00002ooooo`ko000000?oooooo`000?l000000_l0001T
ooooo`007?ooool00ol0003oooooooooo`1mooooo`Co00006?ooool2o`0000_ooooo0ol0000Voooo
o`;o000000?oooooo`000?l000004Ol0001Tooooo`007?ooool00ol0003oooooooooo`1nooooo`;o
00004?ooool2o`0000Oooooo0_l0000;ooooo`;o00004oooool2o`0000Oooooo0_l00009ooooo`;o
00000_ooool@o`0006Kooooo000Looooo`03o`000?oooooooooo08Cooooo1?l00008ooooo`;o0000
3?ooool2o`0001;ooooo1Ol00004ooooo`Co00000oooool4o`0000?ooooo0_l00003ooooo`;o0000
00Coooooo`000?l0003ooooo3ol0001Vooooo`007?ooool00ol0003oooooooooo`20ooooo`;o0000
0_ooool4o`0000Oooooo0ol0000<ooooo`;o00000_ooool3o`0000Cooooo0_l00007ooooo`Go0000
1_ooool2o`0000?ooooo0_l00005ooooo`;o00000_ooool6o`0000;ooooo2ol0001Yooooo`007?oo
ool00ol0003oooooooooo`20ooooo`;o00003Oooool2o`0000gooooo0_l00002ooooo`?o00001?oo
ool2o`0001_ooooo0_l00003ooooo`Wo000000?oooooo`000?l000002?l0001Zooooo`007?ooool0
0ol0003oooooooooo`21ooooo`Co00001?ooool2o`000003ooooool0003o0000013ooooo0_l00000
0ooooooo0000o`00000=ooooo`;o00002_ooool2o`0000Cooooo0_l000001Ooooooo0000o`000?l0
003ooooo00Co00001Oooool2o`0000?ooooo1?l0001^ooooo`007?ooool00ol0003oooooooooo`21
ooooo`Co00000oooool3o`000003ooooool0003o000001?ooooo0_l0000=ooooo`;o00002?ooool4
o`000003ooooool0003o000000?o000000Goooooo`000?l0003o0000ooooo`03o`0007gooooo000L
ooooo`03o`000?oooooooooo08Sooooo0_l0000`ooooo`?o00000_ooool3o`0000Kooooo1?l00008
ooooo`;o0000Loooool001cooooo0_l0001mooooo`?o00005Oooool2o`000003ooooool0003o0000
00Gooooo0_l0000Kooooo`;o00000_ooool2o`0000Oooooo0_l0000:ooooo`Co0000LOooool001co
oooo00?o0000ooooooooool0O?ooool6o`0000cooooo0_l00004ooooo`;o000000?oooooo`000?l0
00001Oooool2o`000003ooooool0003o000001cooooo0_l00002ooooo`?o00000_ooool2o`0000Ko
oooo0_l00003ooooo`?o0000LOooool001cooooo00?o0000ooooooooool0O?ooool6o`0000Cooooo
0_l00004ooooo`Co00000oooool2o`0000cooooo0_l0000Looooo`;o00000_ooool3o`0000;ooooo
0_l00006ooooo`;o00000oooool2o`0007;ooooo000Looooo`03o`000?oooooooooo07cooooo1_l0
0004ooooo`;o00001?ooool4o`0000?ooooo0_l00007ooooo`;o00009_ooool2o`0000Wooooo0_l0
001hooooo`007?ooool00ol0003oooooooooo`1kooooo`Oo00003?ooool2o`0000cooooo0_l0000D
ooooo`;o00006oooool2o`0000Kooooo0_l00005ooooo`;o0000JOooool001cooooo00?o0000oooo
ooooool0Noooool5o`0000Kooooo0_l00003ooooo`?o00009?ooool2o`0001;ooooo0_l0000=oooo
o`So000000Coooooo`000?l0003ooooo0_l0001Vooooo`007?ooool00ol0003oooooooooo`1Hoooo
o`;o000000?oooooo`000?l000001?l000000ooooooo0000o`000003o`00017ooooo2?l00006oooo
o`Co000000Coooooo`000?l0003o00000_ooool2o`0002;ooooo0_l00006ooooo`;o00002?ooool2
o`0000gooooo2?l00004ooooo`;o0000I_ooool001cooooo00?o0000ooooooooool0E_oooolFo`00
00cooooo1ol00009ooooo`;o00001?ooool4o`0001oooooo0_l000000ooooooo0000o`000006oooo
o`;o00005oooool6o`0000Cooooo0_l0001Xooooo`007?ooool00ol0003oooooooooo`1Booooo`?o
000000?oooooo`000?l000001Ol00003ooooo`ko000000?oooooo`000?l000001?ooool:o`0000Oo
oooo0_l00004ooooo`Co000000?oooooo`000?l000007_ooool2o`0001?ooooo0_l00009ooooo`;o
000000?oooooo`000?l000001_ooool2o`000003ooooool0003o000000Kooooo0ol0001Oooooo`00
7?ooool00ol0003oooooooooo`1Aooooo`Co000000?oooooo`000?l000000_ooool3o`0000Cooooo
7_l00007ooooo`;o00001?ooool2o`0000?ooooo0_l00006ooooo`;o00001Oooool2o`00027ooooo
1_l00007ooooo`?o000000?oooooo`000?l000001_ooool3o`0000?ooooo0_l000000ooooooo0000
o`000004o`0005kooooo000Looooo`03o`000?oooooooooo04kooooo1Ol00003ooooo`ko00000_oo
oolMo`0000kooooo0_l00006ooooo`;o00001Oooool2o`00023ooooo1ol00007ooooo`;o00002ooo
ool2o`0000;ooooo0ol000000ooooooo0000o`000002ooooo`;o0000G_ooool001cooooo00?o0000
ooooooooool0COooool5o`0000;ooooo4?l000000ooooooo0000o`00000Go`000003ooooool0003o
000000;o00004?ooool2o`0002gooooo0ol0000?ooooo`;o00002oooool2o`0000;ooooo0_l0001R
ooooo`007?ooool00ol0003oooooooooo`1<ooooo`?o00000oooool]o`0000[ooooo0_l00008oooo
o`;o0000<?ooool2o`0000gooooo0_l00004ooooo`;o00001_ooool2o`0006Gooooo000Looooo`03
o`000?oooooooooo04[ooooo1Ol00003ooooobgo00002_ooool2o`0000Wooooo0_l00006ooooo`;o
00000_ooool2o`0002?ooooo0_l00004ooooo`;o000000?oooooo`000?l000002_ooool4o`0000?o
oooo0ol00002ooooo`;o0000HOooool001cooooo00?o0000ooooooooool0B_ooool3o`0000?ooooo
;ol0000=ooooo`;o00000_ooool2o`0000;ooooo0_l00006ooooo`;o00000_ooool2o`0001Oooooo
0_l0000@ooooo`;o000000?oooooo`000?l000000oooool2o`000003ooooool0003o000000Cooooo
1ol00003ooooo`;o00001?ooool4o`0005Wooooo000Looooo`03o`000?oooooooooo04Wooooo1?l0
0003ooooobko00003_ooool2o`0000;ooooo0ol0000Kooooo`?o00002?ooool2o`0001Sooooo0_l0
00000ooooooo0000o`000005ooooo`Co00001?ooool2o`0000Cooooo1Ol0001Iooooo`007?ooool2
o`0004Wooooo0ol00003oooooboo00002_ooool2o`0000Sooooo0_l0000Kooooo`?o00001?ooool2
o`0001cooooo0_l00004ooooo`;o000000Coooooo`000?l0003o00001_ooool2o`0000Cooooo1_l0
001Hooooo`007?ooool00ol0003oooooooooo`17ooooo`Co00000_oooolDo`000003ooooool0003o
000001Wo00001Oooool2o`0000?ooooo0_l0000/ooooo`;o00006_ooool4o`0000?ooooo1_l0000;
ooooo`Wo0000Eoooool001cooooo00?o0000ooooooooool0Aoooool2o`0000?ooooo4ol00003oooo
oa_o00001Oooool2o`0000gooooo0_l0000Yooooo`;o00004oooool4o`0000?ooooo0_l000001?oo
oooo0000o`000?l0000;ooooo`Wo0000Eoooool001cooooo00?o0000ooooooooool0A_ooool3o`00
00?ooooo4Ol00003oooooa_o00001_ooool2o`0000kooooo0_l0000Wooooo`Co00008Oooool4o`00
00Gooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000005Oooooo000Looooo`03
o`000?oooooooooo04Kooooo0ol00002oooooa?o00000_oooolKo`0000Kooooo0_l0000gooooo`;o
00000oooool2o`0000[ooooo0_l0000:ooooo`;o00001_ooool6o`0000;ooooo2ol0001Gooooo`00
7?ooool00ol0003oooooooooo`1;ooooo`Ko000000?oooooo`000?l000001ol000000ooooooo0000
o`000002ooooo`?o000000?oooooo`000?l000004_l00004ooooo`;o00000_ooool2o`0000Gooooo
0_l0000:ooooo`;o00006oooool2o`000003ooooool0003o000000[ooooo1?l00008ooooo`;o0000
1oooool5o`0000Gooooo0_l000000ooooooo0000o`000002o`0000;ooooo2ol0001Gooooo`007?oo
ool00ol0003oooooooooo`17ooooo`;o00000_ooool=o`0000Sooooo0_l00002oooooa[o00000_oo
ool2o`0000Gooooo0_l00002ooooo`Co00001?ooool2o`0001_ooooo0_l000000ooooooo0000o`00
000<ooooo`;o00004Oooool3o`0000Oooooo0_l000000ooooooo0000o`000002o`0000;ooooo2ol0
001Gooooo`007?ooool00ol0003oooooooooo`14oooooa;o00002_ooool2o`000005ooooool0003o
0000o`000?ooool03ol00002ooooo`Co00001Oooool2o`0000Sooooo1?l0000^ooooo`;o000000?o
ooooo`000?l000007Oooool2o`0000;ooooo3ol0001Gooooo`007?ooool00ol0003oooooooooo`14
ooooo`Co000000?oooooo`000?l000002_l0000:ooooo`?o000000?oooooo`000?l000000_l00000
0ooooooo0000o`00000;o`0000cooooo0_l00005ooooo`;o0000<oooool5o`0000_ooooo0_l0000<
ooooo`;o00000_ooool2o`0000;ooooo3ol0001Gooooo`007?ooool00ol0003oooooooooo`14oooo
o`Ko000000?oooooo`000?l000001Ol00003ooooo`;o00002?ooool2o`0000;ooooo1?l000000ooo
oooo0000o`000004ooooo`Co00005_ooool2o`0000[ooooo0_l0000;ooooo`;o00006?ooool2o`00
0004ooooool0003o0000o`0000?ooooo0_l00007ooooo`;o00002_ooool4o`0000Kooooo3Ol00000
0ooooooo0000o`00001Fooooo`007?ooool00ol0003oooooooooo`14ooooo`;o000000Goooooo`00
0?l0003o0000ooooo`05o`0000Gooooo0ol00005ooooo`;o00002Oooool2o`0000;ooooo0_l00002
ooooo`;o00008_ooool2o`0000_ooooo0_l0000@ooooo`;o00000_ooool2o`0000;ooooo0_l00002
ooooo`;o00000oooool2o`0001;ooooo0ol00004ooooo`;o00000_ooool@o`0005Kooooo000Loooo
o`03o`000?oooooooooo04Cooooo0_l00002ooooo`;o00000oooool2o`0000Oooooo0_l000000ooo
oooo0000o`000002ooooo`;o00003?ooool3o`0000;ooooo0_l000000ooooooo0000o`00000>oooo
o`Co00002?ooool2o`0001Cooooo0_l0000<ooooo`;o00000_ooool2o`0000Gooooo0ol00003oooo
o`;o00001?ooool2o`0000Cooooo1?l00004ooooo`Co00000oooool2o`0000;ooooo4?l0001Foooo
o`007?ooool00ol0003oooooooooo`14ooooo`;o00000_ooool2o`0000Kooooo0_l00007ooooo`;o
00004?ooool2o`0000?ooooo0_l000000ooooooo0000o`00000>ooooo`Co00002?ooool2o`0001Co
oooo0_l0000<ooooo`?o00002?ooool4o`0000;ooooo0_l00002ooooo`Co00001?ooool4o`0000Ko
oooo0_l00002ooooo`;o00000oooool?o`0005Oooooo000Looooo`03o`000?oooooooooo04?ooooo
1Ol00008ooooo`;o00001oooool2o`0000Gooooo0_l0000;ooooo`;o00002?ooool2o`0002kooooo
0_l0000:ooooo`?o00002_ooool3o`0000Cooooo1Ol0000>ooooo`;o00000_ooool2o`0000;ooooo
3_l0001Iooooo`007?ooool00ol0003oooooooooo`13ooooo`Go00005oooool3o`0000Oooooo0_l0
0002ooooo`;o00002?ooool2o`0002kooooo0_l0000Booooo`;o00001?ooool4o`0000;ooooo0_l0
0006ooooo`;o00004Oooool=o`0005[ooooo000Looooo`03o`000?oooooooooo04?ooooo1?l00005
ooooo`Co00003oooool3o`0000Oooooo1?l00007ooooo`;o00001oooool2o`00017ooooo0_l0000W
ooooo`Co00001_ooool2o`000003ooooool0003o000000Oooooo0_l00002ooooo`;o00003Oooool;
o`0005cooooo000Looooo`;o0000A?ooool6o`0000?ooooo1?l0000?ooooo`?o00002Oooool3o`00
0003ooooool0003o000000?ooooo1?l00005ooooo`Co00003oooool2o`0001;ooooo0_l00002oooo
o`;o00003oooool2o`0000_ooooo0_l0000;ooooo`;o00001Oooool2o`0000Gooooo3?l0001Loooo
o`007?ooool00ol0003oooooooooo`15ooooo`Co00003Oooool4o`0000?ooooo1Ol0000:ooooo`;o
000000?oooooo`000?l000001Oooool2o`0000Oooooo0_l00008ooooo`;o00006Oooool2o`0000;o
oooo0_l0000Eooooo`;o00001oooool2o`0000Oooooo0_l00002ooooo`?o00000_ooool2o`0000Go
oooo2ol0001Mooooo`007?ooool00ol0003oooooooooo`16ooooo`;o00003Oooool5o`0000?ooooo
0_l0000Zooooo`;o00006?ooool2o`0000[ooooo0_l0000>ooooo`;o00001oooool4o`0000Gooooo
1ol00002ooooo`;o00001Oooool;o`0005gooooo000Looooo`03o`000?oooooooooo04Gooooo0ol0
000=ooooo`;o00003?ooool2o`0000Kooooo0_l0000Eooooo`;o00001_ooool2o`0001Oooooo0_l0
000:ooooo`;o00003oooool2o`0000Gooooo0_l000001?oooooo0000o`000?ooool2o`0000Cooooo
0_l00004ooooo`?o00001Oooool2o`0000;ooooo1_l0001Nooooo`007?ooool00ol0003ooooooooo
o`15ooooo`Ko00001Oooool3o`0000Gooooo0_l00002ooooo`?o000000Coooooo`000?l0003ooooo
0_l00006ooooo`;o00002oooool2o`0000Cooooo0_l00002ooooo`;o00000oooool2o`000003oooo
ool0003o000003;ooooo1?l00005ooooo`;o00001?ooool2o`0000[ooooo0_l00002ooooo`Ko0000
0oooool2o`00067ooooo000Looooo`03o`000?oooooooooo04Oooooo1?l00002ooooo`;o000000Co
ooooo`000?l0003o00000oooool4o`0000;ooooo0ol000000ooooooo0000o`00000Fooooo`;o0000
1?ooool2o`0000Oooooo0_l0000<ooooo`;o00007oooool4o`0000Cooooo0_l0000Aooooo`;o0000
00?oooooo`000?l000000oooool;o`0006Gooooo000Looooo`03o`000?oooooooooo04Oooooo1Ol0
00000ooooooo0000o`000007ooooo`?o00000oooool4o`0000Cooooo0_l00002ooooo`;o00003?oo
ool2o`0001Cooooo0_l00007ooooo`;o00007oooool4o`0000[ooooo0_l0000;ooooo`Go00000ooo
ool;o`0006Gooooo000Looooo`03o`000?oooooooooo04Sooooo1_l0000?ooooo`?o00001?ooool2
o`0000;ooooo0_l0000<ooooo`;o00001Oooool2o`0000gooooo0_l0000Aooooo`;o00008oooool2
o`0000Oooooo0_l00002ooooo`?o00001?ooool;o`0006Kooooo000Looooo`03o`000?oooooooooo
04[ooooo1ol00009ooooo`So00005?ooool2o`0000Gooooo0_l0000Pooooo`;o00002oooool2o`00
00;ooooo0_l0000Hooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo3Ol0001Voooo
o`007?ooool00ol0003oooooooooo`1>ooooo`?o000000?oooooo`000?l000001_ooool3o`0000;o
oooo0ol000000ooooooo0000o`000003o`0000Wooooo0_l000000ooooooo0000o`00000booooo`;o
00000_ooool2o`0000;ooooo0_l0000Hooooo`?o00001?ooool2o`0000?ooooo3Ol0001Vooooo`00
7?ooool00ol0003oooooooooo`1Booooo`Ko00001Oooool4o`0000;ooooo1Ol00009ooooo`;o0000
00?oooooo`000?l000001Oooool2o`0000?ooooo0_l0000Dooooo`;o00002_ooool2o`0000Cooooo
0ol0000Nooooo`Co00001oooool?o`0006Kooooo000Looooo`03o`000?oooooooooo05?ooooo1Ol0
00000ooooooo0000o`000004o`0000Kooooo0_l0000Dooooo`;o00000oooool2o`0000gooooo0_l0
00000ooooooo0000o`000002ooooo`;o00001_ooool2o`000004ooooool0003o0000o`0000Gooooo
0_l00002ooooo`;o00002oooool2o`0000Wooooo0ol000000ooooooo0000o`000006oooooa7o0000
Ioooool001cooooo00?o0000ooooooooool0FOooool5o`0000cooooo0_l0000Aooooo`;o00000_oo
ool2o`0000cooooo0_l000000ooooooo0000o`00000:ooooo`Go00002_ooool2o`000004ooooool0
003o0000ooooo`;o00001Oooool4o`0000Oooooo0ol00009oooooa7o0000Ioooool001cooooo00?o
0000ooooooooool0G?ooool4o`0000Cooooo0_l00004ooooo`;o00001?ooool4o`0000Cooooo0_l0
0003ooooo`;o00000_ooool2o`0000Oooooo0_l0000Booooo`?o000000?oooooo`000?l000001Ooo
ool2o`0000Gooooo0_l000000ooooooo0000o`000005ooooo`Ko00003?ooool2o`0000Cooooo3ol0
001Xooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<00Kooooo00?o0000ooooooooool0G_ooool2o`0000Cooooo0ol000000ooooooo
0000o`000003o`0000?ooooo1?l00004ooooo`;o00002?ooool4o`0000Cooooo0_l0000Fooooo`;o
00001Oooool2o`0000?ooooo0_l00004ooooo`;o00001?ooool2o`0000;ooooo0ol0000;ooooo`;o
00001?ooool@o`0006Oooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44oooo
o`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1Qooooo`;o00000_ooool2
o`000003ooooool0003o000000Co00002_ooool2o`0000Sooooo1?l00004ooooo`;o00001Oooool2
o`0001_ooooo0_l00004ooooo`;o00000oooool2o`0000Cooooo0_l0000:ooooo`?o00001?ooool@
o`0006Oooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo067ooooo1?l00007ooooo`?o00002?ooool2
o`0000kooooo0_l000000ooooooo0000o`000005ooooo`;o00009_ooool2o`0000[ooooo0_l00004
ooooo`Ko000000?oooooo`000?l000003Ol0001Xooooo`0000?oooooo`000?ooool00_ooool00ol0
003oooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0006;ooooo1?l00004
ooooo`;o000000?oooooo`000?l000002?ooool2o`0000kooooo0_l0000Eooooo`;o00002?ooool2
o`0001_ooooo0_l00003ooooo`Oo000000?oooooo`000?l000003Ol0001Xooooo`0000?oooooo`00
0?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool0
0ol0003oooooooooo`1Nooooo`;o00001?ooool3o`0000?ooooo0_l00002ooooo`;o00002_ooool2
o`00023ooooo1?l00008ooooo`;o00004?ooool4o`0000Kooooo0_l00004ooooo`;o00000_ooool@
o`0006_ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEEohN7
Qoooool02?ooool00ol0003oooooooooo`1Looooo`Oo000000Coooooo`000?l0003o00001oooool4
o`0000Sooooo0_l00002ooooo`;o00001_ooool2o`0000_ooooo0_l00006ooooo`Go00005_ooool2
o`0000;ooooo1?l00006ooooo`;o00002_ooool=o`000003ooooool0003o000006Wooooo00001_oo
ooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003ooooooooo
o`1Looooo`_o00002Oooool2o`0000Wooooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l0
000:ooooo`?o00001_ooool4o`00017ooooo0_l000001?oooooo0000o`000?ooool2o`000004oooo
ool0003o0000o`0001Cooooo4?l0001Yooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<oooo
o`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0F_ooool?o`0001;ooooo0_l00003
ooooo`;o00004?ooool2o`0000Wooooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool2
o`0000Cooooo0ol000000ooooooo0000o`000004ooooo`?o00001_ooool2o`0000Cooooo0_l00006
ooooo`;o000000?oooooo`000?l000002_l0001Zooooo`007?ooool00ol0003oooooooooo`1Joooo
o`oo00000oooool2o`0000Wooooo0_l00004ooooo`;o00002oooool2o`0000?ooooo0ol00006oooo
o`;o00001_ooool2o`0000;ooooo0_l00003ooooo`;o00001?ooool2o`0000Kooooo0ol00008oooo
o`;o00001?ooool2o`000003ooooool0003o000000?ooooo1?l000000ooooooo0000o`000003o`00
0003ooooool0003o000000;o0000J_ooool001cooooo00?o0000ooooooooool0F_ooool?o`0000?o
oooo0_l00009ooooo`Co00000_ooool2o`0000_ooooo0_l00003ooooo`?o00001_ooool2o`0001go
oooo0ol00007ooooo`;o00002?ooool2o`0000Gooooo1Ol00003ooooo`Co0000Joooool001cooooo
00?o0000ooooooooool0FOooool2o`000003ooooool0003o000000_o00004?ooool2o`0000Cooooo
0_l0000Sooooo`;o00006_ooool4o`0000cooooo1_l00004ooooo`?o0000K?ooool001cooooo00?o
0000ooooooooool0FOoooolAo`0000;ooooo0_l0000<ooooo`;o00000oooool2o`0000Wooooo0_l0
000;ooooo`;o00002Oooool4o`0000gooooo0_l00002ooooo`;o00001oooool4o`000003ooooool0
003o000000Oooooo1?l00004ooooo`;o000000?oooooo`000?l000000_l0001/ooooo`007?ooool0
0ol0003oooooooooo`1Ioooooa7o00000_ooool2o`0000cooooo0_l00002ooooo`?o00002Oooool2
o`0000Cooooo0_l00005ooooo`;o00001oooool6o`000003ooooool0003o000000Oooooo0_l00000
0ooooooo0000o`000002ooooo`;o00003?ooool3o`0000Cooooo1_l00004ooooo`;o000000?ooooo
o`000?l000000_l0001/ooooo`007?ooool00ol0003oooooooooo`1Ioooooa7o000000?oooooo`00
0?l000004Oooool5o`0000Sooooo0_l00003ooooo`;o00000_ooool2o`0000Sooooo1?l00005oooo
o`;o00001oooool2o`00017ooooo1Ol00004ooooo`Ko000000?oooooo`000?l000001?ooool4o`00
06cooooo000Looooo`03o`000?oooooooooo05_ooooo4_l00004ooooo`;o00003_ooool2o`0000So
oooo0ol00006ooooo`;o00002?ooool3o`0000;ooooo0_l0000Dooooo`;o00001oooool4o`0000Co
oooo0_l00007ooooo`;o000000?oooooo`000?l000000ol0001^ooooo`007?ooool00ol0003ooooo
ooooo`1Koooooa3o00001_ooool2o`0000Gooooo0_l0000<ooooo`Co00000_ooool4o`0000;ooooo
0_l00009ooooo`;o00001?ooool2o`0000Sooooo0ol00005ooooo`;o00000_ooool3o`0000Kooooo
0_l00006ooooo`?o000000?oooooo`000?l000000_l00003ooooo`Go0000Koooool001cooooo00?o
0000ooooooooool0F_ooool@o`0000kooooo0_l000000ooooooo0000o`000009ooooo`Co00001?oo
ool2o`000003ooooool0003o000000?o00000oooool3o`000003ooooool0003o000000kooooo0ol0
0002ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0000?ooooo0_l00002ooooo`;o0000
1Oooool3o`000003ooooool0003o000000;o000000?oooooo`000?l000001Ol0001_ooooo`007?oo
ool00ol0003oooooooooo`1Joooooa3o00002_ooool2o`0000Cooooo1?l00008ooooo`Co00000_oo
ool4o`000004ooooool0003o0000ooooo`;o00000oooool3o`00017ooooo0_l00003ooooo`;o0000
0_ooool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o00001Oooool2o`0000Cooooo
0_l000000ooooooo0000o`000002o`0007;ooooo000Looooo`03o`000?oooooooooo05_ooooo3ol0
000:ooooo`;o000000Coooooo`000?l0003ooooo1Ol000000ooooooo0000o`00000:ooooo`;o0000
3oooool2o`0000kooooo0_l00006ooooo`;o00000_ooool2o`0000;ooooo0_l0000>ooooo`;o0000
00?oooooo`000?l000000_ooool2o`0007?ooooo000Looooo`;o0000G?ooool?o`0000gooooo0_l0
0004ooooo`;o000000?oooooo`000?l000005Oooool2o`000004ooooool0003o0000ooooo`;o0000
0oooool2o`0000Cooooo1?l000000ooooooo0000o`000006ooooo`;o00001_ooool2o`0000Wooooo
0_l000000ooooooo0000o`000002o`0000Gooooo0_l0001cooooo`007?ooool00ol0003ooooooooo
o`1Mooooo`go00003_ooool2o`0000Kooooo0_l00004ooooo`;o00002?ooool3o`0000Cooooo0_l0
00000ooooooo0000o`000005ooooo`?o00001?ooool4o`0000Wooooo1?l0000=ooooo`Co000000?o
ooooo`000?l000001_l000000ooooooo0000o`00001cooooo`007?ooool00ol0003oooooooooo`1N
ooooo`_o00000oooool2o`0000Sooooo1_l00004ooooo`;o00000oooool3o`0000Sooooo0ol00002
ooooo`?o00002Oooool3o`0000;ooooo0_l00005ooooo`Co000000Coooooo`000?l0003ooooo1?l0
000;ooooo`Ko00000_ooool:o`0007?ooooo000Looooo`03o`000?oooooooooo06;ooooo2?l00000
0ooooooo0000o`000003o`0000Gooooo0ol00002ooooo`;o00001?ooool2o`0000?ooooo0_l00005
ooooo`;o00000oooool2o`0000;ooooo0ol0000=ooooo`?o00001Oooool4o`000003ooooool0003o
000000;ooooo0_l00009ooooo`;o000000?oooooo`000?l000001oooool3o`000003ooooool0003o
000000?o0000Loooool001cooooo00?o0000ooooooooool0H_ooool;o`000003ooooool0003o0000
00;o000000?oooooo`000?l000000_l00002ooooo`?o00004?ooool2o`0000Sooooo0_l0000<oooo
o`?o00003_ooool4o`0000Sooooo0_l00002ooooo`Co00001?ooool8o`0007Cooooo000Looooo`03
o`000?oooooooooo06Oooooo1Ol00003ooooo`?o000000?oooooo`000?l000000ol000001Ooooooo
0000o`000?l0003ooooo00?o00003Oooool2o`000004ooooool0003o0000ooooo`Co000000?ooooo
o`000?l000001_ooool2o`0000;ooooo0_l0000?ooooo`Co00001Oooool2o`0000?ooooo2Ol00003
ooooo`Ko0000M?ooool001cooooo00?o0000ooooooooool0KOooool4o`0000?ooooo1?l00002oooo
o`Ko000000?oooooo`000?l000001_ooool2o`0000;ooooo0_l000000ooooooo0000o`000005o`00
0004ooooool0003o0000ooooo`;o00000oooool2o`0000;ooooo0_l000000ooooooo0000o`00000<
ooooo`;o00001oooool>o`000003ooooool0003o000000;ooooo1?l0001dooooo`007?ooool00ol0
003oooooooooo`1]ooooo`?o00000oooool@o`0000Kooooo0_l00004ooooo`Go00000_ooool2o`00
00?ooooo0_l00007ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Kooooo0_l00002oooo
o`;o00001?ooool=o`000003ooooool0003o000000;ooooo1?l0001dooooo`007?ooool00ol0003o
ooooooooo`1^ooooo`;o00000ooooolBo`0000;ooooo0_l00004ooooo`Co00000oooool6o`0000Oo
oooo0_l000000ooooooo0000o`000002o`0000Gooooo0ol00007ooooo`Co00001?ooool=o`000003
ooooool0003o000007[ooooo000Looooo`03o`000?oooooooooo073ooooo0_l000000ooooooo0000
o`00000Ao`000003ooooool0003o000000Cooooo3Ol00003ooooo`_o00001?ooool>o`000003oooo
ool0003o0000013o0000O?ooool001cooooo00?o0000ooooooooool0L?ooool2o`000003ooooool0
003o000001;o00000_ooool3o`0000?ooooo1ol00005oooooako00000_oooolBo`0007cooooo000L
ooooo`03o`000?oooooooooo07Gooooo4_l00002ooooo`Go000000?oooooo`000?l000001?l00000
0ooooooo0000o`000003oooooaOo00000oooool3o`000003ooooool0003o0000017o000000?ooooo
o`000?l00000N_ooool001cooooo00?o0000ooooooooool0MOoooolAo`0000Gooooo0ol00008oooo
o`;o00000_oooolIo`0000Cooooo6?l0001jooooo`007?ooool00ol0003oooooooooo`1eoooooa7o
00002?ooool2o`0000Kooooo5Ol000000ooooooo0000o`000005o`0000;ooooo6_l0001jooooo`00
7?ooool00ol0003oooooooooo`1cooooo`;o000000?oooooo`000?l000003_l00008ooooo`;o0000
0_ooool3o`0000?ooooo6_l00003oooooaWo0000Noooool001cooooo00?o0000ooooooooool0Looo
ool2o`000003ooooool0003o000000ko00002Oooool2o`000004ooooool0003o0000o`0000;ooooo
3_l000000ooooooo0000o`000005o`000004ooooool0003o0000o`0000Cooooo6?l0001looooo`00
7?ooool2o`0007Oooooo1Ol000000ooooooo0000o`000007o`0000[ooooo0ol00003oooooaSo0000
00Goooooo`000?l0003o0000ooooo`02o`000003ooooool0003o000001Go0000OOooool001cooooo
00?o0000ooooooooool0Moooool>o`0000Wooooo1_l000000ooooooo0000o`00000Fo`0000;ooooo
1_l000000ooooooo0000o`00000Co`0007kooooo000Looooo`03o`000?oooooooooo07Oooooo3Ol0
0003ooooo`?o00000oooool7o`0000?ooooo5_l00004oooooaWo0000Ooooool001cooooo00?o0000
ooooooooool0Moooool2o`000004ooooool0003o0000ooooo`go00000oooool7o`000003ooooool0
003o000001Ko00000oooool3o`000003ooooool0003o000001Co0000Ooooool001cooooo00?o0000
ooooooooool0N_ooool2o`0000;ooooo1?l00002ooooo`?o00002OoooolMo`0000;ooooo1?l00000
0ooooooo0000o`00000Do`0007oooooo000Looooo`03o`000?oooooooooo07[ooooo0_l00002oooo
o`?o00000oooool2o`0000cooooo1Ol000000ooooooo0000o`00000Co`0000;ooooo0ol00003oooo
o`ko000000Coooooo`000?l0003o0000P_ooool001cooooo00?o0000ooooooooool0Toooool4o`00
0003ooooool0003o000000co00001?ooool2o`0000?ooooo1?l00002ooooo`ko000000Coooooo`00
0?l0003o0000P_ooool001cooooo00?o0000ooooooooool0U?ooool4o`000003ooooool0003o0000
00_o00002Oooool6o`0000Gooooo1ol000000ooooooo0000o`000003o`0008;ooooo000Looooo`03
o`000?oooooooooo09Kooooo3_l0000<ooooo`Go000000?oooooo`000?l000000_ooool5o`0000?o
oooo0_l000000ooooooo0000o`000022ooooo`007?ooool00ol0003oooooooooo`2Hooooo`?o0000
0_ooool4o`0001Gooooo0ol000001?oooooo0000o`000?l0002<ooooo`007?ooool00ol0003ooooo
ooooo`2Iooooo`;o00001?ooool2o`0001Kooooo0_l000000ooooooo0000o`00002=ooooo`007?oo
ool00ol0003oooooooooo`2Oooooo`;o00006Oooool2o`0008gooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0
003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q
8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?ooooooB_ooool00006oooooomgMgOoV9RH
oooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`00
0?oooooooooo0?ooooooB_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooom:ooooo`0000?o
ooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80
1_ooool3o`000?ooooooB_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Ooo
ool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom:ooooo`0000?o
oooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@4100
1_ooool00ol0003oooooooooo`3ooooood[ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_o
oooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0?ooooooB_ooool00006
ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooooooo
ool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
B_ooool001Cooooo00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o0000
ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03
o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`004_oo
ool00omEEEGoIVIVo`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo002Yooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05oooool00ol0003o
k^k^ooooo`03ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0U?ooool00:[ooooo00Go0000oooooooo
ooooooooo`000009ooooo`Ko00002oooool00omEEEGoZJVYooooo`03ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40U?ooool00:[ooooo00Go0000ooooooooooooooooo`00000Jooooo`03ojVYZOmEEEGo
oooo00?ooooo00Go0000ooooooooooooooooo`00002Dooooo`00Z_ooool01Ol0003ooooooooooooo
oooo000000Wooooo1_l0000<ooooo`03ob4Q8Ooooooooooo00;ooooo00Go<S8boiRHV?ooooooV9RH
oc8b<P2Dooooo`00Z_ooool01Ol0003oQhN7oooooonYZJWo000001_ooooo00?oEEEEolc<c?ooool0
0_ooool01Oo<c<co0000o`000?l0003oc<c<09Cooooo002Yooooo`03oa0@4?l0003oMgMg00;o0000
00?oV9RHooooooooool06Oooool00onYZJWoMgMgooooo`02ooooo`05oa0@4?nj^[[ooooookZj^_l@
4100U?ooool00<Oooooo00Go410@oooooooooooooooooc8b<P03ooooo`05o`000?nj^[[ooooookZj
^_l00000U?ooool00<Oooooo1Ol00003ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0U?ooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -20 0 ]
[.5 1.0125 20 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(84) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.55307 .69874 Mdot
.59044 .72453 Mdot
.6771 .40848 Mdot
.36418 .51057 Mdot
.4029 .2799 Mdot
.68132 .4171 Mdot
.67695 .59836 Mdot
.65229 .62099 Mdot
.66214 .39723 Mdot
.30403 .48407 Mdot
.7235 .58145 Mdot
.2959 .61916 Mdot
.67175 .60787 Mdot
.31838 .47863 Mdot
.22681 .52456 Mdot
.3647 .68622 Mdot
.57479 .70151 Mdot
.40689 .28439 Mdot
.38423 .67611 Mdot
.66562 .39042 Mdot
.44995 .32417 Mdot
.34497 .49354 Mdot
.55657 .70854 Mdot
.31707 .47628 Mdot
.38188 .67547 Mdot
.49597 .68743 Mdot
.54356 .70278 Mdot
.37298 .67496 Mdot
.29559 .61201 Mdot
.68681 .60413 Mdot
.35609 .67021 Mdot
.24352 .47043 Mdot
.50662 .33707 Mdot
.50521 .70652 Mdot
.74273 .55494 Mdot
.74657 .57089 Mdot
.66736 .43154 Mdot
.72222 .58628 Mdot
.66346 .62647 Mdot
.73987 .56082 Mdot
.74213 .56019 Mdot
.49286 .68592 Mdot
.75169 .56061 Mdot
.70332 .54948 Mdot
.32654 .45746 Mdot
.44588 .70807 Mdot
.70206 .35031 Mdot
.36129 .46894 Mdot
.58341 .695 Mdot
.69245 .35268 Mdot
.26883 .45664 Mdot
.65147 .6001 Mdot
.5375 .327 Mdot
.42313 .6921 Mdot
.66779 .61658 Mdot
.38266 .67208 Mdot
.70681 .4166 Mdot
.32562 .46795 Mdot
.29889 .60403 Mdot
.47783 .71249 Mdot
.34528 .48234 Mdot
.45326 .29787 Mdot
.45227 .66677 Mdot
.71215 .41229 Mdot
.66988 .40113 Mdot
.70439 .59364 Mdot
.59353 .72918 Mdot
.71024 .57775 Mdot
.34636 .51168 Mdot
.70607 .33229 Mdot
.36834 .47393 Mdot
.7244 .58122 Mdot
.47078 .69398 Mdot
.33651 .50132 Mdot
.59175 .69207 Mdot
.71972 .5681 Mdot
.39666 .27433 Mdot
.489 .69366 Mdot
.68914 .35735 Mdot
.40558 .50105 Mdot
.35311 .49955 Mdot
.643 .66897 Mdot
.29634 .58251 Mdot
.45378 .68518 Mdot
.30633 .44642 Mdot
.63392 .69192 Mdot
.3831 .49714 Mdot
.35733 .67685 Mdot
.37607 .6716 Mdot
.30863 .61317 Mdot
.71508 .45594 Mdot
.55821 .72221 Mdot
.33269 .48823 Mdot
.34008 .51125 Mdot
.27735 .45346 Mdot
.29491 .44349 Mdot
.37698 .66889 Mdot
.54862 .35086 Mdot
.73061 .57047 Mdot
.52217 .31649 Mdot
.71322 .57352 Mdot
.54225 .32164 Mdot
.3931 .50452 Mdot
.69296 .43479 Mdot
.48648 .67543 Mdot
.53686 .35145 Mdot
.72549 .56644 Mdot
.32929 .48761 Mdot
.74091 .57708 Mdot
.5592 .71885 Mdot
.35907 .66293 Mdot
.44018 .27679 Mdot
.38622 .26495 Mdot
.53228 .71573 Mdot
.41337 .47925 Mdot
.35727 .48334 Mdot
.34925 .48962 Mdot
.58108 .73155 Mdot
.66772 .39366 Mdot
.71118 .38413 Mdot
.57448 .72229 Mdot
.73502 .56949 Mdot
.58017 .69974 Mdot
.49588 .32466 Mdot
.66752 .39815 Mdot
.51189 .32501 Mdot
.55586 .34379 Mdot
.25989 .47097 Mdot
.28343 .44398 Mdot
.48643 .30925 Mdot
.69299 .43805 Mdot
.57812 .72333 Mdot
.6637 .61129 Mdot
.33671 .51087 Mdot
.45687 .68641 Mdot
.67169 .61483 Mdot
.42569 .26026 Mdot
.43703 .25921 Mdot
.47046 .69028 Mdot
.41438 .47319 Mdot
.7237 .58698 Mdot
.64409 .62731 Mdot
.27628 .46395 Mdot
.45095 .69042 Mdot
.40047 .26921 Mdot
.64517 .62929 Mdot
.58937 .33795 Mdot
.36474 .6588 Mdot
.24859 .44578 Mdot
.64113 .66478 Mdot
.27109 .45881 Mdot
.46736 .3331 Mdot
.45264 .2935 Mdot
.66746 .61892 Mdot
.37686 .50762 Mdot
.5911 .70945 Mdot
.45911 .68967 Mdot
.2751 .59881 Mdot
.52557 .34883 Mdot
.34573 .47437 Mdot
.53678 .31414 Mdot
.5547 .34639 Mdot
.32113 .48004 Mdot
.46146 .71266 Mdot
.51156 .68987 Mdot
.36466 .47756 Mdot
.66256 .42698 Mdot
.40737 .28605 Mdot
.74193 .57266 Mdot
.30403 .44967 Mdot
.28067 .45382 Mdot
.27733 .61036 Mdot
.64233 .62517 Mdot
.72295 .55236 Mdot
.69058 .32322 Mdot
.70404 .5869 Mdot
.73876 .54772 Mdot
.71145 .43501 Mdot
.28493 .60952 Mdot
.44548 .28115 Mdot
.53645 .34021 Mdot
.3617 .47774 Mdot
.26282 .4481 Mdot
.30699 .61637 Mdot
.45001 .3205 Mdot
.47861 .33672 Mdot
.615 .67331 Mdot
.7523 .54715 Mdot
.37208 .50461 Mdot
.36338 .64811 Mdot
.26206 .45534 Mdot
.67947 .61797 Mdot
.65998 .60944 Mdot
.67716 .38069 Mdot
.67043 .387 Mdot
.68933 .33742 Mdot
.26909 .60994 Mdot
.28517 .62663 Mdot
.35711 .505 Mdot
.52667 .32344 Mdot
.4469 .66884 Mdot
.4515 .29488 Mdot
.58374 .70412 Mdot
.64449 .66759 Mdot
.36294 .46078 Mdot
.38771 .67966 Mdot
.66301 .4473 Mdot
.72281 .45361 Mdot
.55434 .33591 Mdot
.42913 .2876 Mdot
.3329 .46922 Mdot
.53901 .71127 Mdot
.26921 .45998 Mdot
.50373 .33013 Mdot
.38372 .26695 Mdot
.56787 .71465 Mdot
.35671 .46222 Mdot
.67545 .60702 Mdot
.71177 .4513 Mdot
.38314 .49692 Mdot
.32855 .49336 Mdot
.48759 .69237 Mdot
.3639 .51577 Mdot
.38062 .65788 Mdot
.36226 .66675 Mdot
.69279 .33521 Mdot
.72052 .56108 Mdot
.69475 .58975 Mdot
.70329 .34917 Mdot
.47993 .68758 Mdot
.51468 .72451 Mdot
.69521 .42427 Mdot
.44044 .3179 Mdot
.72362 .58335 Mdot
.41666 .26778 Mdot
.69122 .4283 Mdot
.40788 .28373 Mdot
.30188 .6022 Mdot
.69697 .44562 Mdot
.43652 .26966 Mdot
.24922 .53443 Mdot
.55026 .3451 Mdot
.41751 .24986 Mdot
.67814 .5961 Mdot
.60944 .70532 Mdot
.36552 .48049 Mdot
.5384 .33236 Mdot
.50628 .32256 Mdot
.28406 .60506 Mdot
.56191 .32891 Mdot
.52088 .34404 Mdot
.28173 .60511 Mdot
.43945 .30095 Mdot
.65303 .6484 Mdot
.35626 .66855 Mdot
.57904 .70112 Mdot
.36494 .51451 Mdot
.72393 .55601 Mdot
.67126 .61585 Mdot
.33916 .47535 Mdot
.63674 .67531 Mdot
.67847 .59404 Mdot
.32706 .47842 Mdot
.67101 .62156 Mdot
.45642 .68506 Mdot
.36634 .46362 Mdot
.46439 .69573 Mdot
.31968 .47738 Mdot
.67002 .62265 Mdot
.69886 .35373 Mdot
.48949 .68569 Mdot
.33739 .49153 Mdot
.35629 .50842 Mdot
.52958 .32515 Mdot
.36188 .66371 Mdot
.63713 .61258 Mdot
.29424 .61872 Mdot
.71951 .42872 Mdot
.27548 .58815 Mdot
.46569 .28667 Mdot
.59178 .33525 Mdot
.45124 .69092 Mdot
.563 .33081 Mdot
.68852 .4195 Mdot
.27948 .46052 Mdot
.34589 .45218 Mdot
.31988 .45451 Mdot
.51987 .34183 Mdot
.29431 .58035 Mdot
.67905 .58816 Mdot
.37122 .65542 Mdot
.49625 .30722 Mdot
.70248 .4128 Mdot
.53437 .31758 Mdot
.30001 .44417 Mdot
.55533 .71267 Mdot
.37793 .68393 Mdot
.71384 .44107 Mdot
.56321 .70698 Mdot
.36107 .47154 Mdot
.71068 .57575 Mdot
.47307 .28705 Mdot
.68327 .58608 Mdot
.36828 .67881 Mdot
.27571 .59001 Mdot
.70452 .33569 Mdot
.48083 .68314 Mdot
.65906 .62176 Mdot
.46819 .69466 Mdot
.28283 .46501 Mdot
.39118 .48863 Mdot
.44888 .69426 Mdot
.45297 .2713 Mdot
.68118 .33633 Mdot
.71806 .58139 Mdot
.5169 .32525 Mdot
.70293 .31254 Mdot
.57518 .69533 Mdot
.68822 .43135 Mdot
.41512 .45302 Mdot
.71797 .44935 Mdot
.38132 .68335 Mdot
.70535 .31807 Mdot
.2759 .61258 Mdot
.31657 .449 Mdot
.70844 .40291 Mdot
.54081 .35303 Mdot
.30125 .46431 Mdot
.45997 .68477 Mdot
.24077 .47495 Mdot
.29827 .47482 Mdot
.26981 .609 Mdot
.70361 .41507 Mdot
.41547 .46731 Mdot
.36271 .67149 Mdot
.37214 .67831 Mdot
.58451 .70853 Mdot
.52173 .33086 Mdot
.41967 .25658 Mdot
.42618 .25245 Mdot
.59246 .31514 Mdot
.31299 .59577 Mdot
.40717 .47741 Mdot
.47255 .68622 Mdot
.69011 .34865 Mdot
.61031 .69451 Mdot
.50409 .3315 Mdot
.65173 .62085 Mdot
.71878 .55446 Mdot
.38531 .49899 Mdot
.47997 .28298 Mdot
.3927 .67756 Mdot
.59466 .69664 Mdot
.47546 .69452 Mdot
.65727 .6221 Mdot
.28177 .57168 Mdot
.32603 .51228 Mdot
.34965 .48032 Mdot
.64767 .62098 Mdot
.50633 .3267 Mdot
.29642 .60112 Mdot
.24 .45461 Mdot
.72322 .53731 Mdot
.31567 .45849 Mdot
.48829 .70902 Mdot
.33147 .45711 Mdot
.26393 .46976 Mdot
.32651 .46319 Mdot
.46859 .68404 Mdot
.35498 .63893 Mdot
.27453 .43602 Mdot
.67482 .45566 Mdot
.35633 .45561 Mdot
.45112 .27301 Mdot
.3327 .4936 Mdot
.34924 .47384 Mdot
.40286 .26454 Mdot
.53412 .71337 Mdot
.28481 .45256 Mdot
.64842 .64943 Mdot
.33867 .48976 Mdot
.74348 .57141 Mdot
.29064 .58981 Mdot
.2488 .47393 Mdot
.36555 .67101 Mdot
.55536 .71005 Mdot
.65616 .62895 Mdot
.74522 .56464 Mdot
.5394 .31178 Mdot
.67111 .6162 Mdot
.30993 .45038 Mdot
.29249 .58874 Mdot
.53241 .71613 Mdot
.54821 .34612 Mdot
.56047 .72431 Mdot
.44015 .23425 Mdot
.67159 .59719 Mdot
.54216 .325 Mdot
.26722 .59495 Mdot
.65924 .59957 Mdot
.65168 .64501 Mdot
.35807 .66322 Mdot
.50663 .32595 Mdot
.55149 .70015 Mdot
.70608 .32741 Mdot
.51026 .33623 Mdot
.66585 .61839 Mdot
.32775 .45794 Mdot
.3745 .66362 Mdot
.66162 .62351 Mdot
.49002 .70672 Mdot
.35795 .65817 Mdot
.33698 .48751 Mdot
.49211 .68232 Mdot
.5741 .72963 Mdot
.37389 .48501 Mdot
.37331 .49709 Mdot
.68963 .4092 Mdot
.51515 .33801 Mdot
.51617 .33704 Mdot
.55908 .34471 Mdot
.71803 .44387 Mdot
.68332 .32344 Mdot
.72756 .559 Mdot
.24987 .47558 Mdot
.71114 .56854 Mdot
.54204 .33117 Mdot
.68773 .40889 Mdot
.32727 .45555 Mdot
.28846 .56953 Mdot
.65712 .63124 Mdot
.68381 .31452 Mdot
.38765 .50416 Mdot
.59183 .7046 Mdot
.64849 .60579 Mdot
.28826 .62493 Mdot
.69357 .3427 Mdot
.46065 .29622 Mdot
.40995 .48045 Mdot
.64878 .60965 Mdot
.50587 .69896 Mdot
.64904 .60988 Mdot
.34915 .47301 Mdot
.29463 .45251 Mdot
.6047 .70917 Mdot
.4521 .27381 Mdot
.29045 .61694 Mdot
.32229 .47509 Mdot
.6888 .3507 Mdot
.60862 .69346 Mdot
.43037 .25259 Mdot
.30099 .60874 Mdot
.5586 .33706 Mdot
.45928 .30287 Mdot
.35116 .50392 Mdot
.27891 .6064 Mdot
.49431 .31043 Mdot
.67921 .61263 Mdot
.44682 .2668 Mdot
.66671 .45094 Mdot
.5672 .70905 Mdot
.72433 .55868 Mdot
.56163 .32271 Mdot
.72059 .58042 Mdot
.28422 .55004 Mdot
.54952 .32927 Mdot
.72485 .54656 Mdot
.35355 .25249 Mdot
.53411 .34757 Mdot
.70357 .4091 Mdot
.28785 .46455 Mdot
.28328 .61161 Mdot
.33585 .48681 Mdot
.42418 .25718 Mdot
.58497 .72683 Mdot
.74457 .54568 Mdot
.69425 .59248 Mdot
.32057 .48559 Mdot
.45052 .69151 Mdot
.6233 .67774 Mdot
.5299 .31881 Mdot
.42918 .27585 Mdot
.42058 .26792 Mdot
.32228 .49238 Mdot
.29695 .57796 Mdot
.47393 .68461 Mdot
.33671 .49136 Mdot
.32217 .49332 Mdot
.69863 .32533 Mdot
.48357 .67781 Mdot
.70027 .44456 Mdot
.38818 .67613 Mdot
.40231 .48968 Mdot
.71229 .57101 Mdot
.68178 .60049 Mdot
.51785 .332 Mdot
.6953 .58848 Mdot
.69224 .3202 Mdot
.51656 .33755 Mdot
.33766 .49217 Mdot
.52867 .71284 Mdot
.33526 .4905 Mdot
.33726 .48947 Mdot
.33106 .46267 Mdot
.40612 .47933 Mdot
.69902 .46004 Mdot
.43462 .28073 Mdot
.30152 .605 Mdot
.71513 .43404 Mdot
.65892 .43751 Mdot
.27622 .45269 Mdot
.34242 .49924 Mdot
.34157 .4844 Mdot
.4978 .69287 Mdot
.37148 .65784 Mdot
.65995 .60261 Mdot
.60515 .70866 Mdot
.38136 .49755 Mdot
.70584 .3429 Mdot
.2853 .45367 Mdot
.45095 .69501 Mdot
.73446 .55394 Mdot
.62693 .70174 Mdot
.5548 .3172 Mdot
.5118 .31728 Mdot
.51919 .34248 Mdot
.56073 .34529 Mdot
.74901 .56681 Mdot
.6863 .40826 Mdot
.46774 .28032 Mdot
.39809 .48533 Mdot
.37419 .50132 Mdot
.29581 .45034 Mdot
.70056 .31718 Mdot
.49851 .33242 Mdot
.29025 .4654 Mdot
.35674 .68735 Mdot
.69055 .45011 Mdot
.55007 .35005 Mdot
.5703 .68484 Mdot
.56012 .71333 Mdot
.69694 .34091 Mdot
.72095 .58644 Mdot
.43773 .26793 Mdot
.63986 .30739 Mdot
.56697 .72597 Mdot
.46993 .66662 Mdot
.68199 .44299 Mdot
.29432 .59118 Mdot
.41178 .67645 Mdot
.68357 .42905 Mdot
.36906 .6535 Mdot
.5876 .73109 Mdot
.55224 .34507 Mdot
.28658 .58344 Mdot
.28378 .60134 Mdot
.66546 .38511 Mdot
.35182 .50941 Mdot
.72868 .44541 Mdot
.70257 .41067 Mdot
.52377 .33613 Mdot
.70345 .41528 Mdot
.68314 .58839 Mdot
.70144 .43566 Mdot
.49375 .7042 Mdot
.32714 .50163 Mdot
.42198 .69079 Mdot
.21953 .51864 Mdot
.3625 .48746 Mdot
.66103 .59347 Mdot
.72643 .55622 Mdot
.36118 .49247 Mdot
.39764 .27256 Mdot
.69826 .40632 Mdot
.68765 .33074 Mdot
.37862 .6639 Mdot
.70396 .31933 Mdot
.55444 .71124 Mdot
.71981 .56369 Mdot
.72585 .55628 Mdot
.51317 .33838 Mdot
.45168 .68881 Mdot
.75484 .551 Mdot
.73539 .56849 Mdot
.47311 .28578 Mdot
.37034 .48332 Mdot
.51909 .69665 Mdot
.29601 .60095 Mdot
.41069 .28797 Mdot
.34093 .49051 Mdot
.70254 .44318 Mdot
.69037 .33101 Mdot
.22367 .52073 Mdot
.69516 .42176 Mdot
.51703 .3291 Mdot
.50398 .68567 Mdot
.38385 .67145 Mdot
.57731 .72573 Mdot
.34925 .51439 Mdot
.72101 .55968 Mdot
.55872 .71152 Mdot
.4433 .3195 Mdot
.33724 .47751 Mdot
.44885 .70822 Mdot
.30398 .60914 Mdot
.33867 .48799 Mdot
.67275 .39602 Mdot
.40177 .26596 Mdot
.46146 .31003 Mdot
.68205 .45529 Mdot
.43249 .29369 Mdot
.55149 .69516 Mdot
.67034 .39581 Mdot
.41583 .27845 Mdot
.59479 .31637 Mdot
.56449 .33442 Mdot
.42809 .28175 Mdot
.30636 .44684 Mdot
.67069 .61791 Mdot
.60091 .71759 Mdot
.29964 .45879 Mdot
.41133 .41107 Mdot
.41514 .69137 Mdot
.53024 .32295 Mdot
.3378 .48555 Mdot
.35238 .47635 Mdot
.45417 .69276 Mdot
.64718 .66386 Mdot
.71033 .41271 Mdot
.51809 .32049 Mdot
.57066 .72468 Mdot
.64287 .66963 Mdot
.67302 .3981 Mdot
.41102 .26908 Mdot
.68605 .59906 Mdot
.52642 .71365 Mdot
.53475 .32703 Mdot
.67767 .59721 Mdot
.68689 .45655 Mdot
.27022 .45594 Mdot
.34835 .67243 Mdot
.67621 .43461 Mdot
.26948 .45703 Mdot
.39046 .6799 Mdot
.68984 .33904 Mdot
.68493 .6118 Mdot
.55949 .72005 Mdot
.653 .62653 Mdot
.42733 .27112 Mdot
.47043 .6957 Mdot
.56068 .72409 Mdot
.68223 .59981 Mdot
.41615 .68845 Mdot
.2886 .57804 Mdot
.72096 .56796 Mdot
.30158 .59183 Mdot
.27616 .46285 Mdot
.53387 .32906 Mdot
.44195 .28138 Mdot
.7198 .56225 Mdot
.49544 .68682 Mdot
.68615 .57595 Mdot
.26392 .45065 Mdot
.36568 .65574 Mdot
.44298 .26991 Mdot
.61088 .67587 Mdot
.68945 .60478 Mdot
.66223 .60115 Mdot
.68887 .35009 Mdot
.39625 .26774 Mdot
.31174 .4476 Mdot
.6936 .30212 Mdot
.3042 .45235 Mdot
.64327 .61205 Mdot
.3922 .67545 Mdot
.57309 .71035 Mdot
.7169 .57387 Mdot
.3857 .68287 Mdot
.29631 .61666 Mdot
.36956 .49713 Mdot
.69368 .33423 Mdot
.59778 .72841 Mdot
.5317 .35629 Mdot
.36004 .4845 Mdot
.32325 .47316 Mdot
.50505 .32153 Mdot
.25133 .47403 Mdot
.66183 .63427 Mdot
.51586 .34428 Mdot
.68794 .44742 Mdot
.54694 .34771 Mdot
.51974 .32625 Mdot
.55015 .7041 Mdot
.68988 .34445 Mdot
.50848 .31852 Mdot
.31602 .47045 Mdot
.3263 .48373 Mdot
.65902 .6288 Mdot
.29155 .58107 Mdot
.28791 .60078 Mdot
.71886 .42648 Mdot
.47333 .28116 Mdot
.29506 .46226 Mdot
.45415 .68553 Mdot
.43172 .25641 Mdot
.52536 .31025 Mdot
.56937 .70521 Mdot
.29118 .44271 Mdot
.69885 .32446 Mdot
.54148 .34708 Mdot
.50849 .31147 Mdot
.44058 .27106 Mdot
.64206 .62657 Mdot
.45457 .70329 Mdot
.70252 .40968 Mdot
.35242 .6751 Mdot
.46909 .25823 Mdot
.69922 .33621 Mdot
.53253 .32955 Mdot
.5528 .3298 Mdot
.45368 .68971 Mdot
.48724 .70598 Mdot
.53166 .30575 Mdot
.71649 .43284 Mdot
.74853 .53978 Mdot
.72087 .57594 Mdot
.27581 .59561 Mdot
.68973 .59044 Mdot
.55873 .71944 Mdot
.2572 .4695 Mdot
.41755 .26903 Mdot
.6617 .5983 Mdot
.51683 .34229 Mdot
.56289 .72159 Mdot
.47478 .70401 Mdot
.31754 .4751 Mdot
.34573 .4958 Mdot
.70176 .35098 Mdot
.25615 .45386 Mdot
.65079 .63342 Mdot
.41721 .25802 Mdot
.68415 .40299 Mdot
.37746 .66465 Mdot
.59073 .70815 Mdot
.53698 .36738 Mdot
.30558 .61375 Mdot
.71306 .42756 Mdot
.59175 .7234 Mdot
.41956 .25364 Mdot
.43265 .28061 Mdot
.3696 .4866 Mdot
.47213 .33642 Mdot
.66989 .59369 Mdot
.45992 .68601 Mdot
.57999 .68899 Mdot
.29366 .61043 Mdot
.34156 .49735 Mdot
.37822 .65843 Mdot
.75129 .55053 Mdot
.30564 .44778 Mdot
.43658 .26364 Mdot
.58909 .73141 Mdot
.32182 .45235 Mdot
.39463 .25909 Mdot
.52976 .35575 Mdot
.5524 .33407 Mdot
.70323 .39765 Mdot
.40483 .25591 Mdot
.39687 .26036 Mdot
.39312 .25789 Mdot
.71868 .55446 Mdot
.28968 .6241 Mdot
.45379 .2438 Mdot
.35156 .50896 Mdot
.27837 .4645 Mdot
.34757 .66579 Mdot
.70535 .58158 Mdot
.70301 .33965 Mdot
.33955 .47076 Mdot
.35471 .50824 Mdot
.61339 .71155 Mdot
.36253 .68625 Mdot
.35734 .47284 Mdot
.57734 .7055 Mdot
.52768 .69311 Mdot
.68012 .38441 Mdot
.6382 .66558 Mdot
.69473 .29801 Mdot
.30503 .60234 Mdot
.30637 .59426 Mdot
.54731 .72198 Mdot
.67938 .61013 Mdot
.30541 .59497 Mdot
.64143 .6245 Mdot
.56751 .73137 Mdot
.34878 .67738 Mdot
.49145 .70612 Mdot
.45416 .29829 Mdot
.34784 .47198 Mdot
.68283 .59528 Mdot
.34608 .4727 Mdot
.68432 .59676 Mdot
.4197 .47118 Mdot
.30197 .58251 Mdot
.37391 .50765 Mdot
.29897 .44156 Mdot
.4538 .32598 Mdot
.34508 .49815 Mdot
.68686 .35282 Mdot
.59047 .71326 Mdot
.48057 .29371 Mdot
.34207 .65836 Mdot
.28801 .4636 Mdot
.34289 .48611 Mdot
.41361 .69144 Mdot
.35211 .49114 Mdot
.69654 .30159 Mdot
.30595 .60679 Mdot
.35948 .47507 Mdot
.65809 .61213 Mdot
.72922 .57745 Mdot
.53175 .71643 Mdot
.55063 .32829 Mdot
.61409 .67464 Mdot
.32688 .4793 Mdot
.69567 .39666 Mdot
.43541 .30455 Mdot
.40042 .26007 Mdot
.59786 .71936 Mdot
.35251 .26284 Mdot
.75092 .56235 Mdot
.66021 .42559 Mdot
.35501 .66782 Mdot
.695 .44698 Mdot
.71484 .4172 Mdot
.6086 .69207 Mdot
.44057 .28123 Mdot
.28996 .46002 Mdot
.48181 .71174 Mdot
.51476 .68364 Mdot
.29213 .61102 Mdot
.68066 .3877 Mdot
.4946 .31078 Mdot
.3221 .64214 Mdot
.42675 .29496 Mdot
.42263 .28783 Mdot
.67739 .60588 Mdot
.69721 .39679 Mdot
.51862 .32184 Mdot
.41466 .27479 Mdot
.67686 .38384 Mdot
.56501 .32959 Mdot
.68474 .34024 Mdot
.47018 .68554 Mdot
.41357 .4629 Mdot
.4563 .71306 Mdot
.69772 .58383 Mdot
.69211 .34974 Mdot
.48444 .68807 Mdot
.44582 .69023 Mdot
.52432 .32493 Mdot
.66962 .44287 Mdot
.4409 .67822 Mdot
.36324 .4804 Mdot
.55279 .34062 Mdot
.31309 .47812 Mdot
.39507 .27294 Mdot
.32854 .48287 Mdot
.70111 .34935 Mdot
.65516 .60516 Mdot
.6948 .4114 Mdot
.67906 .60208 Mdot
.24619 .47532 Mdot
.32986 .47401 Mdot
.33576 .49454 Mdot
.29027 .59068 Mdot
.54428 .71084 Mdot
.49309 .70929 Mdot
.71022 .42222 Mdot
.69797 .41186 Mdot
.34221 .66053 Mdot
.58805 .69984 Mdot
.58153 .34632 Mdot
.30369 .59379 Mdot
.35526 .49428 Mdot
.58908 .71321 Mdot
.34831 .66076 Mdot
.75408 .54248 Mdot
.2879 .58637 Mdot
.5498 .70849 Mdot
.68479 .31972 Mdot
.32202 .49403 Mdot
.51935 .3156 Mdot
.4847 .31018 Mdot
.31357 .60113 Mdot
.40825 .28595 Mdot
.56673 .71267 Mdot
.52847 .31386 Mdot
.59462 .7121 Mdot
.71925 .44717 Mdot
.75469 .55576 Mdot
.57943 .70943 Mdot
.34648 .48631 Mdot
.6908 .30046 Mdot
.67521 .61391 Mdot
.33712 .4635 Mdot
.72103 .57077 Mdot
.4792 .69306 Mdot
.58163 .72102 Mdot
.56496 .32923 Mdot
.36864 .65381 Mdot
.66595 .59522 Mdot
.37655 .5031 Mdot
.49626 .70512 Mdot
.37717 .6844 Mdot
.41402 .29034 Mdot
.28961 .45461 Mdot
.38598 .48784 Mdot
.68463 .35313 Mdot
.27075 .45027 Mdot
.73547 .54811 Mdot
.74158 .57501 Mdot
.7444 .54464 Mdot
.54208 .70688 Mdot
.46852 .30957 Mdot
.46511 .70524 Mdot
.51572 .33104 Mdot
.66617 .43717 Mdot
.33393 .46399 Mdot
.56018 .3468 Mdot
.72495 .55985 Mdot
.43437 .28545 Mdot
.30701 .616 Mdot
.67173 .42759 Mdot
.55747 .32838 Mdot
.66763 .59867 Mdot
.5037 .6899 Mdot
.57131 .70726 Mdot
.68379 .33026 Mdot
.32867 .45588 Mdot
.34323 .49454 Mdot
.73237 .55922 Mdot
.48286 .34276 Mdot
.42704 .29167 Mdot
.54015 .35297 Mdot
.72963 .56125 Mdot
.29076 .5847 Mdot
.48424 .69456 Mdot
.35423 .47486 Mdot
.29482 .58661 Mdot
.7275 .55007 Mdot
.53016 .68593 Mdot
.44017 .29518 Mdot
.39923 .49665 Mdot
.56728 .71406 Mdot
.66372 .61263 Mdot
.59661 .3216 Mdot
.38632 .6665 Mdot
.36608 .50553 Mdot
.36472 .46453 Mdot
.27872 .60064 Mdot
.35668 .67454 Mdot
.55723 .3191 Mdot
.37048 .47213 Mdot
.34281 .65799 Mdot
.3577 .68192 Mdot
.29097 .45126 Mdot
.28893 .44978 Mdot
.58578 .71596 Mdot
.27045 .6098 Mdot
.69706 .44129 Mdot
.36909 .6523 Mdot
.52679 .36569 Mdot
.35816 .66881 Mdot
.27445 .592 Mdot
.53997 .68672 Mdot
.30522 .57089 Mdot
.57792 .73386 Mdot
.5712 .69616 Mdot
.69745 .58423 Mdot
.38004 .68302 Mdot
.71341 .42705 Mdot
.50296 .30977 Mdot
.70202 .33785 Mdot
.5878 .71646 Mdot
.67662 .38625 Mdot
.70456 .59344 Mdot
.67594 .4345 Mdot
.69374 .44979 Mdot
.65389 .60486 Mdot
.60504 .7142 Mdot
.30453 .6131 Mdot
.65394 .60285 Mdot
.50491 .31548 Mdot
.41278 .26944 Mdot
.51421 .68432 Mdot
.52883 .3508 Mdot
.38971 .50229 Mdot
.72476 .54213 Mdot
.66852 .43247 Mdot
.36129 .46059 Mdot
.59485 .69559 Mdot
.41863 .251 Mdot
.57816 .71196 Mdot
.55662 .31584 Mdot
.4555 .29412 Mdot
.30601 .44501 Mdot
.51923 .36388 Mdot
.67954 .61827 Mdot
.28568 .4585 Mdot
.53013 .69394 Mdot
.70131 .33891 Mdot
.67596 .58792 Mdot
.65078 .64436 Mdot
.5195 .31729 Mdot
.55615 .70522 Mdot
.47803 .70771 Mdot
.51717 .33564 Mdot
.66357 .61073 Mdot
.42653 .68972 Mdot
.36338 .48302 Mdot
.69252 .58704 Mdot
.29307 .46017 Mdot
.41372 .4753 Mdot
.44653 .2625 Mdot
.55799 .34479 Mdot
.35967 .68594 Mdot
.66893 .40327 Mdot
.3426 .66449 Mdot
.38069 .5131 Mdot
.24999 .45907 Mdot
.36154 .50286 Mdot
.3567 .45804 Mdot
.69311 .31736 Mdot
.53651 .71913 Mdot
.54332 .34004 Mdot
.5317 .32693 Mdot
.37907 .68551 Mdot
.68344 .28756 Mdot
.42444 .28406 Mdot
.68279 .33823 Mdot
.32892 .47492 Mdot
.35271 .49808 Mdot
.48187 .70055 Mdot
.41693 .4609 Mdot
.55218 .34646 Mdot
.36529 .50186 Mdot
.31124 .58819 Mdot
.65758 .61704 Mdot
.38394 .48729 Mdot
.32148 .49109 Mdot
.75515 .55 Mdot
.65977 .61279 Mdot
.69709 .33159 Mdot
.56535 .33515 Mdot
.70605 .39971 Mdot
.42684 .29364 Mdot
.36416 .46646 Mdot
.25224 .47113 Mdot
.28223 .58292 Mdot
.44061 .29812 Mdot
.36213 .66952 Mdot
.38926 .5116 Mdot
.34186 .50954 Mdot
.42274 .28716 Mdot
.68239 .60944 Mdot
.58599 .71174 Mdot
.41455 .47143 Mdot
.52976 .32695 Mdot
.35793 .68079 Mdot
.39031 .26385 Mdot
.59458 .7132 Mdot
.4643 .71323 Mdot
.58687 .72457 Mdot
.66663 .60152 Mdot
.69249 .3432 Mdot
.45683 .29383 Mdot
.57769 .71136 Mdot
.66474 .40015 Mdot
.71612 .56676 Mdot
.27436 .60506 Mdot
.68842 .6036 Mdot
.60888 .69247 Mdot
.55568 .70227 Mdot
.56998 .69337 Mdot
.38151 .66521 Mdot
.35452 .45625 Mdot
.51541 .3285 Mdot
.72964 .56017 Mdot
.66847 .40758 Mdot
.25635 .4563 Mdot
.49163 .71233 Mdot
.30528 .43406 Mdot
.3021 .44343 Mdot
.32736 .48253 Mdot
.33441 .50123 Mdot
.54807 .31336 Mdot
.38111 .50551 Mdot
.34866 .50833 Mdot
.64972 .63414 Mdot
.69838 .3346 Mdot
.32588 .47266 Mdot
.55127 .33477 Mdot
.47895 .28034 Mdot
.41948 .25085 Mdot
.40655 .48496 Mdot
.44211 .66968 Mdot
.5857 .70796 Mdot
.71429 .43803 Mdot
.68847 .38876 Mdot
.42924 .25906 Mdot
.6513 .62153 Mdot
.58302 .72842 Mdot
.68356 .31646 Mdot
.45961 .29194 Mdot
.31545 .46122 Mdot
.28913 .59141 Mdot
.30334 .56806 Mdot
.2806 .61 Mdot
.3308 .46317 Mdot
.5315 .34893 Mdot
.71671 .43767 Mdot
.27908 .61752 Mdot
.44489 .70597 Mdot
.39547 .26571 Mdot
.40911 .26551 Mdot
.49716 .67965 Mdot
.37422 .51485 Mdot
.6818 .59427 Mdot
.29805 .57974 Mdot
.63605 .61467 Mdot
.62226 .68396 Mdot
.44439 .23688 Mdot
.28498 .45345 Mdot
.27905 .45448 Mdot
.38507 .49943 Mdot
.48667 .67551 Mdot
.50894 .70124 Mdot
.49585 .6881 Mdot
.65676 .6187 Mdot
.2759 .45988 Mdot
.74391 .56177 Mdot
.55351 .34565 Mdot
.56062 .71142 Mdot
.2939 .63424 Mdot
.69761 .4122 Mdot
.35559 .68224 Mdot
.44886 .2807 Mdot
.29108 .60646 Mdot
.54453 .33445 Mdot
.39231 .48755 Mdot
.68665 .40942 Mdot
.4859 .6919 Mdot
.35102 .67801 Mdot
.68989 .45967 Mdot
.36926 .47162 Mdot
.48302 .31503 Mdot
.55716 .34977 Mdot
.45378 .29782 Mdot
.27941 .45689 Mdot
.44863 .27226 Mdot
.66659 .59585 Mdot
.33191 .47384 Mdot
.36147 .4766 Mdot
.34255 .48819 Mdot
.30065 .44648 Mdot
.66248 .61962 Mdot
.37786 .68121 Mdot
.49911 .31941 Mdot
.56468 .34 Mdot
.35722 .67065 Mdot
.44152 .28439 Mdot
.7221 .57559 Mdot
.69886 .33135 Mdot
.50572 .33223 Mdot
.46519 .29521 Mdot
.28656 .45999 Mdot
.35825 .49352 Mdot
.5623 .33802 Mdot
.3055 .44637 Mdot
.3795 .6735 Mdot
.68412 .43888 Mdot
.3659 .68219 Mdot
.40792 .25305 Mdot
.4481 .27758 Mdot
.66862 .61912 Mdot
.57754 .71007 Mdot
.42752 .26089 Mdot
.6811 .40602 Mdot
.38104 .48998 Mdot
.28919 .45295 Mdot
.49209 .70507 Mdot
.26267 .44833 Mdot
.40563 .2537 Mdot
.31012 .44713 Mdot
.47756 .67749 Mdot
.42579 .68385 Mdot
.36488 .5058 Mdot
.37434 .6715 Mdot
.55262 .70183 Mdot
.41334 .27191 Mdot
.64875 .62269 Mdot
.21694 .50069 Mdot
.64212 .62384 Mdot
.49561 .68642 Mdot
.52548 .31528 Mdot
.60813 .70733 Mdot
.52315 .31473 Mdot
.53698 .68131 Mdot
.3243 .4974 Mdot
.50002 .70214 Mdot
.49339 .31864 Mdot
.71101 .42117 Mdot
.67761 .44818 Mdot
.54112 .34637 Mdot
.5644 .71163 Mdot
.51936 .332 Mdot
.43106 .26733 Mdot
.71269 .5618 Mdot
.56753 .69611 Mdot
.69073 .44962 Mdot
.66877 .43139 Mdot
.73274 .55781 Mdot
.33366 .48391 Mdot
.35554 .47632 Mdot
.67677 .43198 Mdot
.63796 .61086 Mdot
.54921 .72017 Mdot
.34194 .49451 Mdot
.51072 .33987 Mdot
.6924 .44046 Mdot
.73547 .58605 Mdot
.47481 .69948 Mdot
.35267 .68198 Mdot
.24902 .46037 Mdot
.74482 .57096 Mdot
.3798 .48633 Mdot
.37746 .67011 Mdot
.40962 .27755 Mdot
.3972 .49263 Mdot
.27823 .46553 Mdot
.73831 .5753 Mdot
.5114 .31918 Mdot
.28183 .61168 Mdot
.71123 .45676 Mdot
.37078 .48049 Mdot
.35909 .24016 Mdot
.56168 .33936 Mdot
.308 .45927 Mdot
.50528 .34115 Mdot
.57714 .72513 Mdot
.34564 .49253 Mdot
.71354 .56951 Mdot
.71146 .4303 Mdot
.32855 .45596 Mdot
.44221 .32025 Mdot
.71499 .57533 Mdot
.54488 .33315 Mdot
.43122 .29301 Mdot
.35501 .65952 Mdot
.24157 .47536 Mdot
.70033 .317 Mdot
.42773 .27915 Mdot
.33509 .48294 Mdot
.68696 .40223 Mdot
.72529 .57918 Mdot
.54198 .34273 Mdot
.28906 .46249 Mdot
.73067 .57118 Mdot
.65325 .61402 Mdot
.45056 .27612 Mdot
.52108 .72888 Mdot
.32441 .50202 Mdot
.31824 .47942 Mdot
.5096 .71568 Mdot
.47775 .7058 Mdot
.34554 .47084 Mdot
.30647 .47124 Mdot
.67875 .59636 Mdot
.26347 .43858 Mdot
.39149 .48638 Mdot
.49218 .31752 Mdot
.67574 .58732 Mdot
.68892 .38629 Mdot
.66666 .43465 Mdot
.42279 .2737 Mdot
.59042 .7259 Mdot
.44891 .26649 Mdot
.70683 .43473 Mdot
.31436 .46632 Mdot
.64332 .6158 Mdot
.34179 .68119 Mdot
.72304 .56639 Mdot
.67731 .41313 Mdot
.45434 .69553 Mdot
.28196 .57352 Mdot
.35791 .24188 Mdot
.63009 .6446 Mdot
.68546 .32784 Mdot
.40051 .26067 Mdot
.44473 .70583 Mdot
.33397 .47916 Mdot
.27245 .60757 Mdot
.32878 .45705 Mdot
.47385 .30898 Mdot
.7039 .32513 Mdot
.56507 .32959 Mdot
.51887 .31777 Mdot
.35875 .46228 Mdot
.65216 .61508 Mdot
.74709 .56312 Mdot
.54181 .3181 Mdot
.66442 .60395 Mdot
.31397 .47469 Mdot
.68138 .4191 Mdot
.56099 .68426 Mdot
.35457 .49325 Mdot
.47016 .28037 Mdot
.70831 .59282 Mdot
.4436 .69241 Mdot
.68514 .38567 Mdot
.2796 .4548 Mdot
.61934 .67197 Mdot
.65972 .59793 Mdot
.40443 .48277 Mdot
.71139 .42693 Mdot
.50628 .3333 Mdot
.69183 .40212 Mdot
.3099 .46241 Mdot
.28336 .45105 Mdot
.50581 .31956 Mdot
.35276 .49279 Mdot
.53933 .72758 Mdot
.3853 .664 Mdot
.3514 .68552 Mdot
.35139 .50926 Mdot
.53047 .69666 Mdot
.71435 .58475 Mdot
.53945 .31654 Mdot
.27839 .60092 Mdot
.28902 .44312 Mdot
.54393 .70447 Mdot
.72042 .57738 Mdot
.65079 .65968 Mdot
.65999 .61845 Mdot
.71226 .42164 Mdot
.6508 .61999 Mdot
.38503 .49835 Mdot
.56172 .72994 Mdot
.69683 .4289 Mdot
.54045 .32938 Mdot
.66011 .40666 Mdot
.36011 .48506 Mdot
.7076 .59509 Mdot
.66209 .42925 Mdot
.37435 .65675 Mdot
.56923 .73064 Mdot
.50049 .35589 Mdot
.44871 .66748 Mdot
.31308 .4665 Mdot
.33001 .45872 Mdot
.54216 .35257 Mdot
.66589 .62013 Mdot
.4746 .70277 Mdot
.6856 .34447 Mdot
.41376 .25206 Mdot
.57606 .73379 Mdot
.43313 .25567 Mdot
.29407 .59168 Mdot
.51948 .70383 Mdot
.31135 .58905 Mdot
.68155 .60276 Mdot
.56832 .70867 Mdot
.38854 .26622 Mdot
.36416 .64832 Mdot
.4383 .27804 Mdot
.68306 .3901 Mdot
.30619 .59561 Mdot
.68794 .44531 Mdot
.72615 .55471 Mdot
.69152 .33365 Mdot
.66907 .59227 Mdot
.44534 .32137 Mdot
.39209 .67466 Mdot
.72779 .58302 Mdot
.70976 .57119 Mdot
.70554 .44097 Mdot
.54955 .32464 Mdot
.37324 .68131 Mdot
.51888 .30723 Mdot
.54791 .318 Mdot
.74754 .5653 Mdot
.57087 .70542 Mdot
.58989 .70176 Mdot
.47953 .29243 Mdot
.57436 .70564 Mdot
.68701 .43245 Mdot
.2886 .58764 Mdot
.26775 .5914 Mdot
.71316 .58563 Mdot
.35395 .66085 Mdot
.3914 .49719 Mdot
.70638 .31917 Mdot
.68359 .42477 Mdot
.65464 .6176 Mdot
.59286 .68708 Mdot
.52462 .31243 Mdot
.47172 .69917 Mdot
.56676 .72442 Mdot
.57556 .7227 Mdot
.61072 .70151 Mdot
.27161 .45662 Mdot
.66188 .59292 Mdot
.56557 .71476 Mdot
.29767 .4615 Mdot
.31463 .48412 Mdot
.50789 .33268 Mdot
.46975 .3099 Mdot
.37453 .67569 Mdot
.51526 .32678 Mdot
.36536 .49572 Mdot
.70323 .41537 Mdot
.45499 .31216 Mdot
.51544 .31209 Mdot
.71567 .43167 Mdot
.71694 .43274 Mdot
.53177 .30953 Mdot
.4577 .31152 Mdot
.53622 .72522 Mdot
.38264 .65174 Mdot
.52873 .69488 Mdot
.66188 .43487 Mdot
.73947 .54595 Mdot
.49615 .70387 Mdot
.33522 .45966 Mdot
.51823 .34781 Mdot
.68757 .41203 Mdot
.57601 .69408 Mdot
.33921 .49931 Mdot
.5244 .32667 Mdot
.433 .27308 Mdot
.54272 .32865 Mdot
.53312 .34993 Mdot
.51765 .69374 Mdot
.7062 .54465 Mdot
.45182 .69193 Mdot
.69449 .45828 Mdot
.53974 .33587 Mdot
.42017 .68871 Mdot
.69497 .35235 Mdot
.71075 .5636 Mdot
.38565 .66244 Mdot
.35825 .51056 Mdot
.71383 .43898 Mdot
.55419 .71148 Mdot
.66683 .62654 Mdot
.30789 .57697 Mdot
.57649 .71101 Mdot
.56331 .32417 Mdot
.54004 .34875 Mdot
.69405 .44153 Mdot
.50611 .69053 Mdot
.37648 .66941 Mdot
.57248 .71587 Mdot
.73368 .56146 Mdot
.31262 .4457 Mdot
.61396 .67422 Mdot
.51912 .32283 Mdot
.58807 .70495 Mdot
.6701 .40786 Mdot
.43803 .26393 Mdot
.30659 .44992 Mdot
.63686 .6738 Mdot
.33924 .48418 Mdot
.73547 .55783 Mdot
.46996 .26769 Mdot
.35217 .65327 Mdot
.3247 .46142 Mdot
.27446 .59978 Mdot
.70657 .57814 Mdot
.32815 .4646 Mdot
.28315 .57562 Mdot
.45727 .71219 Mdot
.47072 .69121 Mdot
.32657 .4744 Mdot
.67964 .43208 Mdot
.73211 .44467 Mdot
.31939 .48648 Mdot
.6909 .46173 Mdot
.29794 .57715 Mdot
.50565 .30909 Mdot
.41846 .29368 Mdot
.25741 .46898 Mdot
.3133 .45602 Mdot
.37346 .50727 Mdot
.31189 .44488 Mdot
.29574 .55904 Mdot
.70949 .43206 Mdot
.70519 .40031 Mdot
.42639 .26683 Mdot
.37156 .46856 Mdot
.44621 .2749 Mdot
.72364 .57999 Mdot
.38819 .68097 Mdot
.56324 .34638 Mdot
.58036 .70697 Mdot
.34591 .49011 Mdot
.6814 .39437 Mdot
.30947 .45914 Mdot
.36815 .66186 Mdot
.68948 .43604 Mdot
.69174 .41063 Mdot
.72511 .44905 Mdot
.39884 .2574 Mdot
.59499 .7182 Mdot
.37779 .49421 Mdot
.40007 .27385 Mdot
.50821 .31354 Mdot
.21512 .51328 Mdot
.58336 .73277 Mdot
.59498 .71014 Mdot
.60513 .70514 Mdot
.37853 .50163 Mdot
.37939 .49999 Mdot
.74009 .55892 Mdot
.47989 .70931 Mdot
.64348 .61076 Mdot
.71132 .44331 Mdot
.71194 .46051 Mdot
.31065 .45739 Mdot
.46892 .2879 Mdot
.44243 .2834 Mdot
.66044 .41668 Mdot
.55377 .34906 Mdot
.44595 .26691 Mdot
.37503 .49564 Mdot
.69785 .44466 Mdot
.3928 .26238 Mdot
.60586 .68866 Mdot
.64598 .65502 Mdot
.44243 .26559 Mdot
.51688 .32008 Mdot
.47028 .7124 Mdot
.25843 .46197 Mdot
.44221 .25984 Mdot
.71811 .58361 Mdot
.30569 .6139 Mdot
.5561 .34719 Mdot
.46261 .28862 Mdot
.25345 .44403 Mdot
.70055 .43459 Mdot
.51592 .31916 Mdot
.38839 .26953 Mdot
.26639 .60038 Mdot
.45417 .27609 Mdot
.59304 .70767 Mdot
.42648 .67883 Mdot
.32113 .45728 Mdot
.36233 .65473 Mdot
.69256 .59495 Mdot
.68073 .38988 Mdot
.69248 .39266 Mdot
.50219 .69781 Mdot
.28103 .59034 Mdot
.67902 .43858 Mdot
.27632 .59748 Mdot
.46579 .30232 Mdot
.29722 .4613 Mdot
.48101 .29173 Mdot
.35966 .64811 Mdot
.38722 .26042 Mdot
.44038 .26472 Mdot
.70818 .58784 Mdot
.65559 .60593 Mdot
.66722 .61831 Mdot
.68326 .44098 Mdot
.29171 .59775 Mdot
.70252 .39919 Mdot
.51149 .72408 Mdot
.42333 .28255 Mdot
.68575 .31623 Mdot
.38588 .50346 Mdot
.36807 .49766 Mdot
.34727 .66828 Mdot
.52013 .3466 Mdot
.31159 .46441 Mdot
.7343 .56786 Mdot
.66434 .40064 Mdot
.70516 .59633 Mdot
.50029 .6849 Mdot
.5077 .72182 Mdot
.69508 .41305 Mdot
.4788 .30014 Mdot
.44781 .28257 Mdot
.23717 .45517 Mdot
.47571 .31283 Mdot
.70416 .41002 Mdot
.34896 .51371 Mdot
.56526 .69602 Mdot
.6799 .32554 Mdot
.34304 .49062 Mdot
.66675 .43036 Mdot
.69699 .35752 Mdot
.36002 .65067 Mdot
.27214 .45 Mdot
.68468 .61168 Mdot
.27999 .59589 Mdot
.3973 .25464 Mdot
.50423 .32117 Mdot
.30027 .63537 Mdot
.70749 .43607 Mdot
.66204 .39645 Mdot
.42994 .25671 Mdot
.4457 .69351 Mdot
.58434 .69691 Mdot
.53522 .72387 Mdot
.73696 .56395 Mdot
.33301 .50507 Mdot
.69793 .44344 Mdot
.46139 .69872 Mdot
.38874 .49025 Mdot
.67602 .60214 Mdot
.65856 .41756 Mdot
.3525 .49278 Mdot
.32158 .46129 Mdot
.44261 .27296 Mdot
.47835 .27905 Mdot
.498 .32501 Mdot
.70718 .569 Mdot
.32384 .44148 Mdot
.38602 .68233 Mdot
.36572 .50594 Mdot
.54533 .71699 Mdot
.51824 .33454 Mdot
.43997 .28155 Mdot
.35969 .47254 Mdot
.2716 .59681 Mdot
.55537 .70353 Mdot
.68236 .59955 Mdot
.53608 .33173 Mdot
.33957 .44857 Mdot
.34781 .48892 Mdot
.31976 .45301 Mdot
.38133 .66503 Mdot
.38313 .5075 Mdot
.70362 .33717 Mdot
.45137 .68619 Mdot
.41073 .28321 Mdot
.58367 .72253 Mdot
.68832 .34466 Mdot
.38741 .66648 Mdot
.29982 .60242 Mdot
.52721 .69963 Mdot
.5716 .73188 Mdot
.73302 .56009 Mdot
.6591 .59539 Mdot
.47169 .28814 Mdot
.30193 .45897 Mdot
.55891 .34127 Mdot
.5686 .71895 Mdot
.68266 .38989 Mdot
.44712 .27476 Mdot
.68481 .32667 Mdot
.36168 .50388 Mdot
.7041 .43974 Mdot
.53734 .34405 Mdot
.50552 .68611 Mdot
.70516 .41892 Mdot
.50668 .33387 Mdot
.41038 .27008 Mdot
.29881 .61595 Mdot
.48005 .30683 Mdot
.52572 .31669 Mdot
.30025 .45647 Mdot
.33417 .65529 Mdot
.35804 .65681 Mdot
.4916 .31519 Mdot
.67855 .38279 Mdot
.52487 .32099 Mdot
.44099 .695 Mdot
.36148 .65179 Mdot
.66881 .40182 Mdot
.48992 .70688 Mdot
.38441 .66131 Mdot
.52531 .31431 Mdot
.58754 .73179 Mdot
.68963 .3511 Mdot
.57092 .69155 Mdot
.27058 .46727 Mdot
.32741 .49492 Mdot
.68668 .4453 Mdot
.43692 .27647 Mdot
.74649 .55668 Mdot
.74562 .57354 Mdot
.70993 .57261 Mdot
.70486 .45204 Mdot
.34898 .49206 Mdot
.56775 .71164 Mdot
.65952 .59979 Mdot
.47998 .70232 Mdot
.68024 .40351 Mdot
.67906 .42383 Mdot
.34845 .67022 Mdot
.44842 .27643 Mdot
.38487 .50361 Mdot
.68356 .39044 Mdot
.69411 .33669 Mdot
.42557 .69039 Mdot
.39149 .25842 Mdot
.38575 .67402 Mdot
.48839 .30563 Mdot
.37758 .48104 Mdot
.4802 .71546 Mdot
.5457 .34708 Mdot
.50374 .68665 Mdot
.34276 .47349 Mdot
.73385 .51171 Mdot
.6954 .35146 Mdot
.27928 .59436 Mdot
.68185 .61574 Mdot
.65239 .60244 Mdot
.7064 .42388 Mdot
.347 .50088 Mdot
.68535 .32345 Mdot
.42234 .27277 Mdot
.34492 .65248 Mdot
.5391 .31562 Mdot
.48565 .70446 Mdot
.64487 .61767 Mdot
.44396 .31637 Mdot
.74628 .55691 Mdot
.67236 .61509 Mdot
.53666 .69018 Mdot
.31982 .45726 Mdot
.69179 .41774 Mdot
.6744 .42512 Mdot
.48053 .29273 Mdot
.70095 .30544 Mdot
.59817 .69738 Mdot
.73062 .50979 Mdot
.27949 .62157 Mdot
.33715 .47811 Mdot
.55986 .32097 Mdot
.55683 .3406 Mdot
.69008 .3397 Mdot
.32993 .46501 Mdot
.47935 .68642 Mdot
.69727 .39316 Mdot
.67155 .4391 Mdot
.36859 .65576 Mdot
.65533 .60458 Mdot
.47682 .3169 Mdot
.68571 .42885 Mdot
.21701 .50453 Mdot
.30882 .45626 Mdot
.63067 .63839 Mdot
.68773 .43013 Mdot
.6936 .29281 Mdot
.74992 .53981 Mdot
.45705 .69403 Mdot
.28997 .62065 Mdot
.47801 .6961 Mdot
.44726 .26961 Mdot
.70176 .40263 Mdot
.73941 .57198 Mdot
.54115 .33329 Mdot
.73349 .44121 Mdot
.68304 .44356 Mdot
.58737 .7153 Mdot
.323 .45598 Mdot
.40676 .48884 Mdot
.34989 .48932 Mdot
.2636 .43796 Mdot
.40221 .25369 Mdot
.7455 .57384 Mdot
.73137 .55978 Mdot
.28962 .6208 Mdot
.39296 .26092 Mdot
.71384 .4195 Mdot
.69121 .43683 Mdot
.63735 .67035 Mdot
.5338 .3498 Mdot
.71209 .41378 Mdot
.30053 .45514 Mdot
.72439 .45089 Mdot
.49598 .71136 Mdot
.65275 .60792 Mdot
.29586 .4435 Mdot
.68577 .44637 Mdot
.52106 .69264 Mdot
.28734 .59567 Mdot
.31934 .48433 Mdot
.4965 .33331 Mdot
.66 .59619 Mdot
.5018 .72177 Mdot
.70691 .32233 Mdot
.32537 .4978 Mdot
.726 .57657 Mdot
.46838 .3335 Mdot
.7347 .433 Mdot
.59442 .72216 Mdot
.6686 .4301 Mdot
.64738 .62172 Mdot
.53449 .3408 Mdot
.41217 .28499 Mdot
.69675 .40465 Mdot
.66665 .43731 Mdot
.36278 .66797 Mdot
.47841 .29798 Mdot
.43826 .25773 Mdot
.5532 .72222 Mdot
.67998 .59579 Mdot
.36758 .65949 Mdot
.21771 .49485 Mdot
.37953 .49759 Mdot
.67037 .6181 Mdot
.42674 .69579 Mdot
.33654 .50887 Mdot
.35819 .50749 Mdot
.40335 .48557 Mdot
.44693 .69809 Mdot
.55792 .71504 Mdot
.32534 .44069 Mdot
.3727 .67224 Mdot
.2978 .59814 Mdot
.58644 .70943 Mdot
.58932 .71922 Mdot
.29354 .6054 Mdot
.36358 .66542 Mdot
.49452 .70716 Mdot
.66018 .604 Mdot
.65294 .60178 Mdot
.57672 .72376 Mdot
.3466 .66622 Mdot
.68021 .60891 Mdot
.48682 .69757 Mdot
.67817 .41511 Mdot
.29326 .57778 Mdot
.57972 .72831 Mdot
.305 .59069 Mdot
.66726 .59581 Mdot
.22004 .48185 Mdot
.29805 .57664 Mdot
.37284 .51117 Mdot
.32353 .45892 Mdot
.39913 .26395 Mdot
.54439 .33121 Mdot
.53196 .30951 Mdot
.66422 .62066 Mdot
.38139 .50447 Mdot
.49345 .68732 Mdot
.38059 .5022 Mdot
.2551 .45431 Mdot
.22342 .47694 Mdot
.28866 .62845 Mdot
.59101 .7236 Mdot
.49487 .68686 Mdot
.70569 .45912 Mdot
.66961 .39297 Mdot
.2768 .58558 Mdot
.6575 .59797 Mdot
.5837 .70252 Mdot
.6439 .61053 Mdot
.70603 .4358 Mdot
.69113 .41513 Mdot
.51339 .33231 Mdot
.51527 .31932 Mdot
.70232 .42581 Mdot
.6877 .45941 Mdot
.21566 .49741 Mdot
.48849 .70639 Mdot
.44229 .70768 Mdot
.24557 .47191 Mdot
.41418 .47444 Mdot
.43423 .27531 Mdot
.45267 .31168 Mdot
.73286 .57106 Mdot
.27633 .60722 Mdot
.35251 .48233 Mdot
.53068 .31871 Mdot
.69662 .58465 Mdot
.43969 .28966 Mdot
.65228 .60561 Mdot
.42 .28905 Mdot
.66938 .40292 Mdot
.35295 .49701 Mdot
.37081 .50833 Mdot
.73151 .56212 Mdot
.71751 .45479 Mdot
.69727 .44606 Mdot
.43456 .27837 Mdot
.24846 .47008 Mdot
.6973 .4408 Mdot
.57938 .72906 Mdot
.62134 .6904 Mdot
.54735 .34429 Mdot
.34182 .49981 Mdot
.25412 .46795 Mdot
.3633 .65181 Mdot
.50935 .31255 Mdot
.53532 .33132 Mdot
.52337 .72977 Mdot
.36431 .481 Mdot
.65127 .66156 Mdot
.51115 .31784 Mdot
.60675 .70784 Mdot
.69451 .41923 Mdot
.51422 .31129 Mdot
.49422 .30823 Mdot
.38797 .22632 Mdot
.53486 .30912 Mdot
.5647 .70314 Mdot
.48082 .6935 Mdot
.36908 .68108 Mdot
.42826 .70431 Mdot
.4459 .29828 Mdot
.43733 .28564 Mdot
.6966 .35114 Mdot
.71157 .5735 Mdot
.3981 .48561 Mdot
.42486 .28087 Mdot
.59538 .68878 Mdot
.35175 .67666 Mdot
.35493 .67187 Mdot
.36003 .67488 Mdot
.4802 .70037 Mdot
.28291 .45331 Mdot
.70303 .33222 Mdot
.58742 .71371 Mdot
.36464 .68204 Mdot
.3762 .51611 Mdot
.53599 .71843 Mdot
.68029 .60062 Mdot
.34075 .66667 Mdot
.57017 .71032 Mdot
.31083 .58422 Mdot
.67497 .59273 Mdot
.27285 .59902 Mdot
.65105 .44065 Mdot
.69024 .29085 Mdot
.6554 .6143 Mdot
.65898 .41905 Mdot
.70365 .44214 Mdot
.68588 .43842 Mdot
.56058 .71886 Mdot
.67393 .44754 Mdot
.49238 .68431 Mdot
.68578 .32738 Mdot
.34772 .45319 Mdot
.45614 .29422 Mdot
.69398 .33325 Mdot
.57649 .72241 Mdot
.50579 .71724 Mdot
.35323 .25299 Mdot
.31864 .49101 Mdot
.73385 .57919 Mdot
.42076 .26671 Mdot
.28963 .58837 Mdot
.40873 .27691 Mdot
.71214 .42846 Mdot
.3541 .45991 Mdot
.3098 .4564 Mdot
.64768 .6563 Mdot
.43909 .27628 Mdot
.5888 .72088 Mdot
.36106 .66981 Mdot
.6942 .38724 Mdot
.42388 .27412 Mdot
.44824 .27841 Mdot
.31937 .48024 Mdot
.48334 .69375 Mdot
.7143 .44171 Mdot
.6859 .58627 Mdot
.68957 .35619 Mdot
.23848 .53221 Mdot
.36338 .47949 Mdot
.3243 .49809 Mdot
.29554 .58958 Mdot
.68691 .3382 Mdot
.66078 .6076 Mdot
.26065 .44944 Mdot
.70899 .32101 Mdot
.25198 .45615 Mdot
.49177 .67671 Mdot
.69098 .32785 Mdot
.55027 .34184 Mdot
.5072 .33182 Mdot
.33803 .49259 Mdot
.35541 .24446 Mdot
.28158 .46175 Mdot
.68509 .60156 Mdot
.55012 .32966 Mdot
.66015 .43494 Mdot
.58272 .69488 Mdot
.38231 .22751 Mdot
.37622 .6742 Mdot
.68608 .58706 Mdot
.69493 .43853 Mdot
.36654 .23308 Mdot
.40277 .26096 Mdot
.29074 .57071 Mdot
.31357 .48322 Mdot
.3373 .49404 Mdot
.67166 .61094 Mdot
.68538 .60432 Mdot
.46182 .71512 Mdot
.50833 .30373 Mdot
.62153 .67697 Mdot
.72174 .56531 Mdot
.36991 .23128 Mdot
.55974 .33899 Mdot
.46569 .686 Mdot
.55679 .31995 Mdot
.69158 .59743 Mdot
.34367 .47208 Mdot
.48168 .69401 Mdot
.53581 .34534 Mdot
.45819 .66725 Mdot
.354 .66377 Mdot
.21641 .50555 Mdot
.32599 .48149 Mdot
.59878 .70289 Mdot
.58957 .71163 Mdot
.4917 .6891 Mdot
.53058 .34671 Mdot
.36507 .50226 Mdot
.34444 .50719 Mdot
.33512 .50555 Mdot
.42645 .69289 Mdot
.34955 .49453 Mdot
.58146 .69203 Mdot
.28641 .57789 Mdot
.74175 .51683 Mdot
.37128 .50688 Mdot
.65365 .62297 Mdot
.33136 .48762 Mdot
.42342 .25148 Mdot
.29131 .6167 Mdot
.37194 .65358 Mdot
.66583 .60614 Mdot
.38076 .51276 Mdot
.52671 .36557 Mdot
.37476 .49301 Mdot
.43397 .29525 Mdot
.74711 .54396 Mdot
.27041 .46025 Mdot
.42725 .69049 Mdot
.5743 .71819 Mdot
.68478 .39835 Mdot
.65239 .63326 Mdot
.71077 .41997 Mdot
.37973 .64949 Mdot
.56301 .33264 Mdot
.68446 .31959 Mdot
.21864 .49059 Mdot
.3428 .47234 Mdot
.54531 .35186 Mdot
.49902 .68973 Mdot
.70066 .33967 Mdot
.41664 .46305 Mdot
.34777 .67006 Mdot
.43191 .25861 Mdot
.40937 .27435 Mdot
.46968 .25922 Mdot
.46748 .69986 Mdot
.51353 .71311 Mdot
.67251 .60889 Mdot
.68075 .44152 Mdot
.38887 .25997 Mdot
.62788 .70732 Mdot
.67702 .61673 Mdot
.6924 .34143 Mdot
.64548 .61575 Mdot
.36892 .50476 Mdot
.52833 .30883 Mdot
.45446 .70677 Mdot
.5396 .31918 Mdot
.38022 .48922 Mdot
.67587 .4438 Mdot
.54199 .34959 Mdot
.39984 .27168 Mdot
.65097 .62551 Mdot
.69916 .41313 Mdot
.31962 .45419 Mdot
.59036 .70961 Mdot
.31887 .64038 Mdot
.70637 .30902 Mdot
.37537 .65577 Mdot
.37788 .65687 Mdot
.44482 .70137 Mdot
.50077 .31163 Mdot
.73287 .40873 Mdot
.36806 .65034 Mdot
.71995 .55946 Mdot
.46474 .28203 Mdot
.6914 .3091 Mdot
.69473 .39543 Mdot
.69675 .43096 Mdot
.3566 .47913 Mdot
.70463 .39779 Mdot
.28949 .61022 Mdot
.69076 .38549 Mdot
.75261 .54647 Mdot
.28449 .45718 Mdot
.69053 .43448 Mdot
.51276 .31622 Mdot
.30286 .45285 Mdot
.4696 .68982 Mdot
.71477 .41269 Mdot
.37295 .51123 Mdot
.6777 .45691 Mdot
.73377 .55955 Mdot
.52457 .34474 Mdot
.30933 .61025 Mdot
.66352 .60083 Mdot
.56016 .70632 Mdot
.30392 .62222 Mdot
.42031 .27574 Mdot
.48325 .68349 Mdot
.46976 .2825 Mdot
.45073 .27931 Mdot
.29778 .58367 Mdot
.56317 .72878 Mdot
.55388 .33627 Mdot
.41052 .27251 Mdot
.42495 .29635 Mdot
.69818 .43286 Mdot
.70189 .35019 Mdot
.52188 .32005 Mdot
.31748 .45203 Mdot
.69529 .31843 Mdot
.65204 .61788 Mdot
.31612 .48405 Mdot
.69092 .44453 Mdot
.55051 .33482 Mdot
.35013 .5064 Mdot
.37332 .67332 Mdot
.45413 .71035 Mdot
.51927 .30476 Mdot
.43885 .2952 Mdot
.47647 .69128 Mdot
.32284 .49587 Mdot
.45482 .29906 Mdot
.69097 .35586 Mdot
.29513 .44999 Mdot
.59819 .71996 Mdot
.60145 .68881 Mdot
.68312 .38872 Mdot
.68366 .59624 Mdot
.6725 .42305 Mdot
.42333 .29201 Mdot
.35221 .25488 Mdot
.51299 .32622 Mdot
.35251 .64868 Mdot
.29221 .61348 Mdot
.69018 .39685 Mdot
.59422 .71796 Mdot
.62903 .68429 Mdot
.2933 .61699 Mdot
.29559 .45168 Mdot
.33656 .49688 Mdot
.68854 .33307 Mdot
.58022 .69574 Mdot
.33893 .49858 Mdot
.46301 .31099 Mdot
.28757 .45224 Mdot
.43068 .26522 Mdot
.64989 .40913 Mdot
.50396 .32943 Mdot
.42191 .69207 Mdot
.53228 .34576 Mdot
.68452 .43209 Mdot
.31287 .58998 Mdot
.2953 .5962 Mdot
.44002 .23445 Mdot
.56264 .70337 Mdot
.52368 .69234 Mdot
.68928 .41755 Mdot
.68888 .34686 Mdot
.37782 .67636 Mdot
.36396 .67158 Mdot
.30479 .4537 Mdot
.71186 .4279 Mdot
.66569 .38956 Mdot
.56069 .32711 Mdot
.54739 .35013 Mdot
.27335 .58803 Mdot
.67255 .40181 Mdot
.35218 .49681 Mdot
.35041 .6595 Mdot
.67148 .62247 Mdot
.4686 .69466 Mdot
.72105 .58647 Mdot
.67194 .62273 Mdot
.4129 .46755 Mdot
.30869 .43621 Mdot
.73819 .56413 Mdot
.70508 .58632 Mdot
.69414 .34519 Mdot
.26879 .59467 Mdot
.44435 .26808 Mdot
.26658 .43798 Mdot
.71182 .41958 Mdot
.36126 .49501 Mdot
.60389 .69747 Mdot
.54997 .31229 Mdot
.6324 .6936 Mdot
.38909 .36778 Mdot
.38086 .68052 Mdot
.70129 .32243 Mdot
.52614 .31603 Mdot
.54169 .31861 Mdot
.25743 .46098 Mdot
.3506 .49686 Mdot
.68439 .38894 Mdot
.26672 .59995 Mdot
.72112 .56624 Mdot
.69266 .34711 Mdot
.46495 .70097 Mdot
.33534 .48866 Mdot
.53527 .7126 Mdot
.658 .62792 Mdot
.4575 .28523 Mdot
.39929 .25896 Mdot
.3722 .49187 Mdot
.38649 .66318 Mdot
.72496 .55466 Mdot
.36963 .67563 Mdot
.36725 .66346 Mdot
.5258 .32403 Mdot
.38577 .67254 Mdot
.31262 .48394 Mdot
.32795 .50647 Mdot
.50794 .31358 Mdot
.67831 .61614 Mdot
.29017 .46536 Mdot
.52676 .31412 Mdot
.30011 .61878 Mdot
.64743 .63158 Mdot
.37257 .67636 Mdot
.65942 .61909 Mdot
.69113 .34319 Mdot
.73498 .56246 Mdot
.40975 .28221 Mdot
.69425 .33838 Mdot
.4433 .70787 Mdot
.56844 .7108 Mdot
.65669 .59593 Mdot
.41119 .26919 Mdot
.65486 .62021 Mdot
.69926 .40829 Mdot
.72723 .55643 Mdot
.42607 .68334 Mdot
.21794 .51066 Mdot
.41045 .47208 Mdot
.64294 .60389 Mdot
.66808 .39652 Mdot
.5756 .72343 Mdot
.71069 .57345 Mdot
.30301 .61216 Mdot
.40446 .25903 Mdot
.33495 .49172 Mdot
.65319 .62684 Mdot
.69658 .32902 Mdot
.48091 .7143 Mdot
.42002 .2879 Mdot
.50512 .7235 Mdot
.67858 .39673 Mdot
.28804 .45648 Mdot
.75449 .55561 Mdot
.73558 .42149 Mdot
.73009 .56229 Mdot
.40065 .49815 Mdot
.55851 .34399 Mdot
.49909 .30505 Mdot
.51728 .6995 Mdot
.54773 .35248 Mdot
.4552 .32893 Mdot
.71282 .56602 Mdot
.45229 .68807 Mdot
.69985 .45888 Mdot
.31712 .45129 Mdot
.38259 .68275 Mdot
.51698 .32756 Mdot
.59158 .7016 Mdot
.38027 .66379 Mdot
.51161 .33277 Mdot
.28724 .57744 Mdot
.47521 .69522 Mdot
.71671 .42253 Mdot
.30132 .45595 Mdot
.75108 .56255 Mdot
.71886 .57222 Mdot
.56415 .32534 Mdot
.74625 .56041 Mdot
.29943 .61894 Mdot
.56718 .73012 Mdot
.37152 .68066 Mdot
.42865 .26513 Mdot
.54134 .72785 Mdot
.54212 .30953 Mdot
.39902 .22571 Mdot
.29784 .45621 Mdot
.69092 .41675 Mdot
.73339 .43691 Mdot
.27572 .58518 Mdot
.58462 .71096 Mdot
.28665 .61187 Mdot
.38325 .66713 Mdot
.36702 .6739 Mdot
.68121 .44172 Mdot
.29223 .58964 Mdot
.35093 .49507 Mdot
.68425 .58887 Mdot
.27417 .5447 Mdot
.39179 .50878 Mdot
.46518 .30958 Mdot
.37134 .65339 Mdot
.75208 .55215 Mdot
.48496 .70687 Mdot
.69161 .41935 Mdot
.47814 .68479 Mdot
.47664 .705 Mdot
.56037 .71242 Mdot
.62649 .70804 Mdot
.36737 .65043 Mdot
.64263 .66846 Mdot
.49853 .7109 Mdot
.41147 .48146 Mdot
.59655 .69343 Mdot
.7202 .39175 Mdot
.4522 .68742 Mdot
.56047 .70567 Mdot
.5625 .68389 Mdot
.58091 .69627 Mdot
.31286 .45379 Mdot
.2915 .44279 Mdot
.28287 .62797 Mdot
.68747 .32557 Mdot
.3519 .49061 Mdot
.52531 .30755 Mdot
.42322 .26263 Mdot
.44748 .6939 Mdot
.539 .33136 Mdot
.30096 .58514 Mdot
.54369 .3575 Mdot
.31671 .47626 Mdot
.34768 .5043 Mdot
.3625 .6755 Mdot
.2258 .47057 Mdot
.68839 .31969 Mdot
.6033 .70922 Mdot
.39035 .5102 Mdot
.73487 .43452 Mdot
.30415 .4627 Mdot
.28542 .61315 Mdot
.33412 .50976 Mdot
.69179 .41766 Mdot
.46607 .70525 Mdot
.54615 .31656 Mdot
.52822 .71797 Mdot
.33423 .4823 Mdot
.57573 .35018 Mdot
.46653 .29308 Mdot
.34418 .50133 Mdot
.53358 .7178 Mdot
.38166 .66493 Mdot
.55221 .70974 Mdot
.55282 .7264 Mdot
.29497 .45181 Mdot
.45663 .69875 Mdot
.55716 .71632 Mdot
.36494 .67175 Mdot
.70058 .32188 Mdot
.71105 .56357 Mdot
.30968 .46538 Mdot
.4203 .28748 Mdot
.32982 .46353 Mdot
.45307 .27556 Mdot
.52214 .30855 Mdot
.52496 .31857 Mdot
.28014 .45791 Mdot
.66213 .40305 Mdot
.44621 .26355 Mdot
.68886 .32213 Mdot
.4108 .69133 Mdot
.53089 .69256 Mdot
.7214 .56419 Mdot
.70261 .34975 Mdot
.52548 .32022 Mdot
.28234 .4663 Mdot
.2421 .53303 Mdot
.74295 .56145 Mdot
.50409 .68398 Mdot
.28792 .46316 Mdot
.53795 .353 Mdot
.7186 .42628 Mdot
.67581 .42527 Mdot
.71461 .56382 Mdot
.5571 .68429 Mdot
.37238 .50157 Mdot
.53734 .35259 Mdot
.35016 .68523 Mdot
.54531 .33191 Mdot
.55141 .31836 Mdot
.65848 .4238 Mdot
.35852 .50281 Mdot
.30147 .58167 Mdot
.70915 .44026 Mdot
.44661 .2859 Mdot
.50691 .68854 Mdot
.44223 .29804 Mdot
.64862 .65261 Mdot
.4553 .71305 Mdot
.70645 .4276 Mdot
.50587 .33505 Mdot
.35299 .48855 Mdot
.47452 .70299 Mdot
.49906 .69263 Mdot
.46527 .69224 Mdot
.42487 .2654 Mdot
.69212 .3915 Mdot
.68558 .34924 Mdot
.31858 .45578 Mdot
.57547 .73186 Mdot
.38956 .226 Mdot
.32214 .46224 Mdot
.65589 .59976 Mdot
.37779 .66094 Mdot
.58459 .72583 Mdot
.34861 .65215 Mdot
.52062 .70263 Mdot
.67837 .42909 Mdot
.36512 .48763 Mdot
.30943 .45147 Mdot
.27025 .45908 Mdot
.43814 .28952 Mdot
.55801 .70058 Mdot
.31701 .4382 Mdot
.37748 .481 Mdot
.25768 .46477 Mdot
.34023 .50259 Mdot
.40952 .4735 Mdot
.48448 .31202 Mdot
.51039 .32813 Mdot
.29624 .61235 Mdot
.32173 .4862 Mdot
.53729 .72117 Mdot
.46245 .71109 Mdot
.41475 .67617 Mdot
.67384 .6156 Mdot
.44936 .68831 Mdot
.71225 .43867 Mdot
.7175 .41752 Mdot
.71325 .4584 Mdot
.40437 .28127 Mdot
.37436 .67806 Mdot
.35642 .48366 Mdot
.68356 .60291 Mdot
.41806 .27608 Mdot
.57562 .73295 Mdot
.4496 .27515 Mdot
.27776 .59562 Mdot
.40705 .27841 Mdot
.56484 .333 Mdot
.7515 .54067 Mdot
.35055 .65977 Mdot
.45123 .29096 Mdot
.47255 .69232 Mdot
.28208 .46305 Mdot
.27642 .44743 Mdot
.50373 .71789 Mdot
.43551 .25912 Mdot
.68979 .35702 Mdot
.29979 .46039 Mdot
.36615 .46393 Mdot
.66279 .62001 Mdot
.4123 .28483 Mdot
.64659 .60891 Mdot
.37549 .66397 Mdot
.51956 .68997 Mdot
.58222 .71551 Mdot
.71716 .5711 Mdot
.28566 .6125 Mdot
.40782 .28174 Mdot
.70325 .42892 Mdot
.26833 .60597 Mdot
.68773 .31784 Mdot
.5161 .35136 Mdot
.26334 .46278 Mdot
.70376 .33326 Mdot
.38309 .51372 Mdot
.7266 .57064 Mdot
.38468 .49957 Mdot
.3538 .65064 Mdot
.36074 .47015 Mdot
.70614 .44601 Mdot
.69588 .4306 Mdot
.6836 .32531 Mdot
.36824 .48293 Mdot
.36309 .51767 Mdot
.4866 .703 Mdot
.68903 .39043 Mdot
.56346 .71811 Mdot
.59657 .70354 Mdot
.65936 .42218 Mdot
.54659 .71038 Mdot
.44853 .27765 Mdot
.35831 .46435 Mdot
.72719 .5702 Mdot
.72785 .56215 Mdot
.7038 .42555 Mdot
.66197 .43289 Mdot
.69165 .41556 Mdot
.37835 .6641 Mdot
.5628 .72775 Mdot
.28422 .4338 Mdot
.32243 .48105 Mdot
.37879 .50661 Mdot
.4652 .70213 Mdot
.29662 .61639 Mdot
.41512 .42117 Mdot
.43397 .26073 Mdot
.68459 .42948 Mdot
.643 .62219 Mdot
.32129 .64255 Mdot
.68628 .59134 Mdot
.28856 .45006 Mdot
.72229 .55396 Mdot
.50124 .68281 Mdot
.40315 .27137 Mdot
.36066 .65462 Mdot
.39585 .26358 Mdot
.67225 .62168 Mdot
.49719 .69589 Mdot
.2857 .58878 Mdot
.28494 .45472 Mdot
.289 .59983 Mdot
.59465 .31842 Mdot
.51838 .7046 Mdot
.675 .59555 Mdot
.35397 .6584 Mdot
.51372 .34923 Mdot
.3659 .694 Mdot
.35342 .47772 Mdot
.38891 .50684 Mdot
.39676 .48804 Mdot
.29575 .44239 Mdot
.45595 .69425 Mdot
.28052 .60507 Mdot
.51124 .34064 Mdot
.30739 .44776 Mdot
.63977 .66334 Mdot
.33398 .4783 Mdot
.37205 .50894 Mdot
.36028 .4902 Mdot
.39329 .50489 Mdot
.44176 .69434 Mdot
.36007 .67603 Mdot
.68532 .59445 Mdot
.37294 .47347 Mdot
.71062 .57943 Mdot
.70198 .42056 Mdot
.53489 .30637 Mdot
.45018 .70044 Mdot
.39616 .26246 Mdot
.65411 .64496 Mdot
.36111 .46104 Mdot
.707 .46004 Mdot
.26436 .44824 Mdot
.47503 .30786 Mdot
.53611 .31139 Mdot
.40938 .28446 Mdot
.68414 .44628 Mdot
.65595 .60962 Mdot
.34662 .513 Mdot
.56703 .7201 Mdot
.57435 .70495 Mdot
.3037 .44814 Mdot
.70365 .57 Mdot
.71932 .57185 Mdot
.69453 .33443 Mdot
.37136 .50224 Mdot
.29649 .44323 Mdot
.54583 .71562 Mdot
.69293 .35441 Mdot
.30064 .59632 Mdot
.42994 .27779 Mdot
.30748 .4712 Mdot
.51794 .34657 Mdot
.28141 .60169 Mdot
.68246 .60231 Mdot
.54967 .33868 Mdot
.33369 .47353 Mdot
.3071 .43555 Mdot
.3422 .65851 Mdot
.48109 .28815 Mdot
.67292 .38726 Mdot
.2953 .45364 Mdot
.30538 .45917 Mdot
.47481 .69611 Mdot
.73321 .56251 Mdot
.59476 .7185 Mdot
.42676 .68463 Mdot
.52513 .31893 Mdot
.73426 .55819 Mdot
.39135 .4986 Mdot
.75008 .55018 Mdot
.37745 .66006 Mdot
.31339 .46647 Mdot
.67648 .59605 Mdot
.54285 .72069 Mdot
.61177 .67598 Mdot
.27782 .45145 Mdot
.36932 .6621 Mdot
.32859 .46348 Mdot
.6926 .35164 Mdot
.55375 .31429 Mdot
.28537 .45391 Mdot
.58053 .70265 Mdot
.32098 .46111 Mdot
.66737 .62425 Mdot
.45857 .29007 Mdot
.58108 .70973 Mdot
.70297 .3221 Mdot
.67783 .4348 Mdot
.67519 .39053 Mdot
.56422 .33318 Mdot
.38461 .66915 Mdot
.4834 .68855 Mdot
.60015 .71727 Mdot
.28803 .60478 Mdot
.68492 .43228 Mdot
.43376 .27118 Mdot
.3223 .45098 Mdot
.51842 .34761 Mdot
.74781 .56827 Mdot
.42624 .69792 Mdot
.28486 .57847 Mdot
.4353 .29784 Mdot
.2574 .53731 Mdot
.52903 .32544 Mdot
.36183 .50541 Mdot
.41023 .28334 Mdot
.66345 .4307 Mdot
.34185 .66354 Mdot
.47852 .31319 Mdot
.69186 .31943 Mdot
.69401 .45199 Mdot
.71386 .57538 Mdot
.67894 .38407 Mdot
.39371 .26545 Mdot
.51111 .31952 Mdot
.57548 .70775 Mdot
.34909 .50089 Mdot
.52125 .32704 Mdot
.68119 .41984 Mdot
.56125 .33609 Mdot
.36312 .51103 Mdot
.53432 .70876 Mdot
.70402 .41291 Mdot
.31117 .45961 Mdot
.36378 .64953 Mdot
.4459 .70681 Mdot
.70016 .32942 Mdot
.28706 .61059 Mdot
.38573 .26452 Mdot
.71248 .45536 Mdot
.70188 .44701 Mdot
.2958 .4476 Mdot
.41325 .25805 Mdot
.33264 .4843 Mdot
.65616 .60555 Mdot
.31072 .61374 Mdot
.73155 .56196 Mdot
.25194 .4579 Mdot
.30471 .44359 Mdot
.28474 .62119 Mdot
.51521 .6846 Mdot
.49031 .35027 Mdot
.24334 .46907 Mdot
.34432 .50764 Mdot
.59988 .69496 Mdot
.30655 .593 Mdot
.22033 .51847 Mdot
.46168 .70591 Mdot
.46184 .29362 Mdot
.66238 .62163 Mdot
.3275 .45465 Mdot
.64698 .65981 Mdot
.43168 .26638 Mdot
.25562 .46065 Mdot
.27778 .57908 Mdot
.59099 .71869 Mdot
.36333 .48853 Mdot
.57635 .71467 Mdot
.33144 .46928 Mdot
.4424 .70394 Mdot
.71437 .56717 Mdot
.39637 .49106 Mdot
.51243 .3181 Mdot
.73554 .42221 Mdot
.41084 .47362 Mdot
.44211 .27404 Mdot
.35075 .6523 Mdot
.53042 .32103 Mdot
.65218 .60582 Mdot
.70325 .57897 Mdot
.69025 .41559 Mdot
.68823 .58485 Mdot
.46353 .68502 Mdot
.69606 .33018 Mdot
.55413 .34547 Mdot
.34309 .67469 Mdot
.39355 .25584 Mdot
.73511 .55743 Mdot
.33201 .49751 Mdot
.37999 .49962 Mdot
.68829 .33266 Mdot
.64847 .4141 Mdot
.54192 .70191 Mdot
.45235 .71278 Mdot
.49508 .69635 Mdot
.44072 .28774 Mdot
.69893 .32651 Mdot
.34669 .47704 Mdot
.35716 .49765 Mdot
.67594 .44743 Mdot
.46477 .70436 Mdot
.41789 .26184 Mdot
.50141 .30483 Mdot
.68375 .60345 Mdot
.6806 .32713 Mdot
.57935 .70927 Mdot
.68642 .31265 Mdot
.68665 .34973 Mdot
.57239 .68389 Mdot
.24573 .46914 Mdot
.66221 .60348 Mdot
.68865 .30964 Mdot
.58847 .72549 Mdot
.2851 .45067 Mdot
.54887 .32756 Mdot
.56377 .33523 Mdot
.52214 .7004 Mdot
.70707 .42116 Mdot
.41619 .25656 Mdot
.36081 .48167 Mdot
.43288 .29899 Mdot
.47263 .70512 Mdot
.67378 .39739 Mdot
.5416 .33931 Mdot
.64539 .6302 Mdot
.32437 .46154 Mdot
.42529 .26367 Mdot
.66386 .60408 Mdot
.50656 .33094 Mdot
.3626 .46544 Mdot
.30418 .62163 Mdot
.3784 .65629 Mdot
.66419 .61818 Mdot
.29464 .6016 Mdot
.31203 .47625 Mdot
.72626 .57096 Mdot
.47104 .28275 Mdot
.73354 .41376 Mdot
.30832 .61492 Mdot
.71238 .56665 Mdot
.67691 .44948 Mdot
.67858 .38299 Mdot
.70355 .35035 Mdot
.68872 .31952 Mdot
.71589 .57801 Mdot
.53147 .33423 Mdot
.6813 .33724 Mdot
.73273 .56264 Mdot
.27697 .60486 Mdot
.32645 .45424 Mdot
.26747 .59291 Mdot
.50475 .3302 Mdot
.52169 .34205 Mdot
.47442 .71018 Mdot
.35317 .67219 Mdot
.54204 .33729 Mdot
.32466 .49434 Mdot
.49726 .69101 Mdot
.67074 .59437 Mdot
.37875 .22799 Mdot
.68813 .59992 Mdot
.34133 .66538 Mdot
.71926 .44846 Mdot
.69703 .3332 Mdot
.34742 .50034 Mdot
.66571 .63164 Mdot
.36889 .23184 Mdot
.32884 .45561 Mdot
.36055 .65459 Mdot
.25234 .45583 Mdot
.30636 .44767 Mdot
.46515 .67895 Mdot
.52657 .34858 Mdot
.49286 .68987 Mdot
.66618 .60107 Mdot
.46076 .28985 Mdot
.45046 .32507 Mdot
.66591 .6191 Mdot
.3368 .48114 Mdot
.56133 .32044 Mdot
.3375 .49509 Mdot
.33868 .50809 Mdot
.3821 .48227 Mdot
.46051 .30295 Mdot
.69727 .41469 Mdot
.3951 .26124 Mdot
.56838 .69989 Mdot
.42781 .69659 Mdot
.44042 .27186 Mdot
.26857 .60073 Mdot
.30128 .59027 Mdot
.64883 .42172 Mdot
.5755 .70484 Mdot
.44958 .27151 Mdot
.65624 .62378 Mdot
.22795 .52896 Mdot
.27176 .6112 Mdot
.68438 .58691 Mdot
.359 .51003 Mdot
.60151 .71607 Mdot
.47059 .70858 Mdot
.7322 .55475 Mdot
.59633 .72125 Mdot
.29615 .59939 Mdot
.37551 .66587 Mdot
.68283 .6025 Mdot
.24239 .47967 Mdot
.73141 .55981 Mdot
.4144 .45454 Mdot
.36681 .65832 Mdot
.58291 .7107 Mdot
.40686 .48699 Mdot
.54169 .7254 Mdot
.51473 .33531 Mdot
.37578 .47847 Mdot
.43616 .27252 Mdot
.29099 .59935 Mdot
.70483 .31855 Mdot
.49791 .67837 Mdot
.58054 .72423 Mdot
.68718 .60599 Mdot
.5959 .71294 Mdot
.52182 .69617 Mdot
.6417 .60501 Mdot
.45375 .68532 Mdot
.3352 .48231 Mdot
.43149 .70831 Mdot
.48087 .68675 Mdot
.67337 .60492 Mdot
.4221 .27039 Mdot
.46276 .69451 Mdot
.68644 .34457 Mdot
.30091 .45428 Mdot
.67818 .4057 Mdot
.4298 .25392 Mdot
.45057 .6991 Mdot
.43973 .27468 Mdot
.68402 .41473 Mdot
.47264 .3085 Mdot
.73196 .58329 Mdot
.74697 .55208 Mdot
.49224 .3074 Mdot
.71855 .55927 Mdot
.57631 .69713 Mdot
.69523 .31503 Mdot
.37441 .48883 Mdot
.36989 .50108 Mdot
.42122 .25099 Mdot
.57675 .69468 Mdot
.71724 .55504 Mdot
.54017 .3325 Mdot
.49442 .70662 Mdot
.64523 .62722 Mdot
.69638 .33827 Mdot
.30338 .58543 Mdot
.71394 .57317 Mdot
.50773 .33796 Mdot
.52824 .32326 Mdot
.3361 .49689 Mdot
.26417 .45427 Mdot
.42186 .29003 Mdot
.71864 .39135 Mdot
.36421 .68589 Mdot
.66153 .43465 Mdot
.35057 .4846 Mdot
.36452 .68287 Mdot
.31723 .48974 Mdot
.39043 .26377 Mdot
.71337 .5813 Mdot
.56951 .70749 Mdot
.45788 .28273 Mdot
.67723 .43481 Mdot
.31103 .5881 Mdot
.28029 .44522 Mdot
.29634 .60622 Mdot
.71657 .43293 Mdot
.59126 .69689 Mdot
.69681 .42409 Mdot
.72487 .57239 Mdot
.44607 .27333 Mdot
.37988 .66388 Mdot
.50409 .33016 Mdot
.69216 .39683 Mdot
.65791 .59475 Mdot
.7024 .31801 Mdot
.70353 .57937 Mdot
.52683 .3196 Mdot
.30565 .60838 Mdot
.70469 .39747 Mdot
.54816 .32278 Mdot
.50533 .70672 Mdot
.3357 .44485 Mdot
.54191 .68619 Mdot
.71191 .42638 Mdot
.43573 .23237 Mdot
.66813 .60366 Mdot
.70459 .59067 Mdot
.41577 .46882 Mdot
.35602 .24358 Mdot
.38775 .48922 Mdot
.74423 .54284 Mdot
.72857 .56876 Mdot
.66338 .61572 Mdot
.69394 .4226 Mdot
.53849 .71741 Mdot
.46121 .66663 Mdot
.7155 .42268 Mdot
.2583 .47162 Mdot
.57556 .73291 Mdot
.28186 .62667 Mdot
.70582 .40125 Mdot
.36344 .67299 Mdot
.49474 .71325 Mdot
.44546 .26495 Mdot
.26809 .46388 Mdot
.71806 .57036 Mdot
.33545 .46208 Mdot
.6436 .67057 Mdot
.68749 .41949 Mdot
.55656 .32864 Mdot
.68372 .61183 Mdot
.37997 .50303 Mdot
.35957 .49262 Mdot
.3214 .47568 Mdot
.41943 .25163 Mdot
.49235 .71136 Mdot
.34668 .47171 Mdot
.35274 .4583 Mdot
.38166 .68485 Mdot
.70524 .34348 Mdot
.39567 .26581 Mdot
.2623 .4398 Mdot
.68198 .45692 Mdot
.48857 .7088 Mdot
.38682 .50462 Mdot
.71222 .58553 Mdot
.35493 .67428 Mdot
.68074 .59879 Mdot
.64134 .62398 Mdot
.67923 .33021 Mdot
.58551 .70178 Mdot
.38125 .68141 Mdot
.66141 .39543 Mdot
.50512 .67782 Mdot
.37254 .6828 Mdot
.44421 .70939 Mdot
.6812 .61297 Mdot
.35165 .25425 Mdot
.71193 .58836 Mdot
.56337 .33768 Mdot
.46256 .6839 Mdot
.61621 .70616 Mdot
.28251 .60309 Mdot
.56355 .72363 Mdot
.68887 .33097 Mdot
.48544 .68811 Mdot
.64761 .29888 Mdot
.49948 .69377 Mdot
.66821 .60753 Mdot
.73157 .55758 Mdot
.36869 .67865 Mdot
.3407 .48569 Mdot
.28827 .58433 Mdot
.54101 .33254 Mdot
.30363 .61002 Mdot
.70827 .44064 Mdot
.68446 .34211 Mdot
.75068 .54172 Mdot
.46627 .67984 Mdot
.67548 .58602 Mdot
.35837 .49125 Mdot
.36881 .65856 Mdot
.29128 .44264 Mdot
.71699 .5663 Mdot
.38837 .69453 Mdot
.32389 .48314 Mdot
.37319 .67804 Mdot
.71941 .43178 Mdot
.66213 .4415 Mdot
.55134 .68451 Mdot
.67938 .33166 Mdot
.34397 .50623 Mdot
.42955 .28416 Mdot
.40081 .27835 Mdot
.27879 .4485 Mdot
.73052 .44158 Mdot
.30012 .59508 Mdot
.33055 .49632 Mdot
.3127 .59185 Mdot
.71904 .42673 Mdot
.56014 .34889 Mdot
.68109 .42377 Mdot
.4401 .69653 Mdot
.53299 .30917 Mdot
.6961 .44438 Mdot
.29614 .57773 Mdot
.52286 .32454 Mdot
.73215 .41106 Mdot
.43029 .26389 Mdot
.31747 .48614 Mdot
.42111 .45912 Mdot
.69516 .39221 Mdot
.66069 .61018 Mdot
.45944 .69082 Mdot
.68383 .59464 Mdot
.66948 .44818 Mdot
.25279 .46472 Mdot
.51065 .33541 Mdot
.70178 .58831 Mdot
.39325 .67995 Mdot
.42271 .28118 Mdot
.71494 .58854 Mdot
.3865 .67158 Mdot
.2777 .44696 Mdot
.36338 .23552 Mdot
.37584 .5064 Mdot
.68374 .34008 Mdot
.7359 .5584 Mdot
.47785 .29934 Mdot
.35064 .49965 Mdot
.67338 .40461 Mdot
.42331 .29618 Mdot
.33262 .49269 Mdot
.70377 .3269 Mdot
.30706 .45993 Mdot
.4109 .28354 Mdot
.47765 .69439 Mdot
.31139 .61388 Mdot
.40041 .24935 Mdot
.45776 .28348 Mdot
.3955 .48733 Mdot
.29209 .4416 Mdot
.70922 .3815 Mdot
.59222 .71765 Mdot
.28909 .45386 Mdot
.41384 .25011 Mdot
.4974 .68535 Mdot
.47653 .68442 Mdot
.34119 .6625 Mdot
.65001 .63354 Mdot
.70485 .41734 Mdot
.41508 .28111 Mdot
.69074 .35321 Mdot
.32837 .45702 Mdot
.34662 .65677 Mdot
.43822 .26518 Mdot
.65871 .59771 Mdot
.38276 .67175 Mdot
.72289 .54729 Mdot
.37195 .47262 Mdot
.71227 .5903 Mdot
.38925 .50298 Mdot
.404 .49019 Mdot
.48734 .69241 Mdot
.64061 .66771 Mdot
.70759 .57507 Mdot
.6758 .42895 Mdot
.54013 .33916 Mdot
.42778 .69827 Mdot
.42555 .26473 Mdot
.46019 .66533 Mdot
.36754 .508 Mdot
.34197 .47489 Mdot
.48631 .69078 Mdot
.27884 .44484 Mdot
.48355 .67805 Mdot
.6893 .34882 Mdot
.35476 .24503 Mdot
.57223 .70993 Mdot
.58493 .72084 Mdot
.36287 .64061 Mdot
.72444 .45178 Mdot
.50751 .68845 Mdot
.3291 .45535 Mdot
.66346 .44296 Mdot
.48074 .28924 Mdot
.41437 .26621 Mdot
.47582 .30047 Mdot
.50558 .68392 Mdot
.28006 .57384 Mdot
.37814 .65842 Mdot
.28196 .45849 Mdot
.26244 .53926 Mdot
.72625 .57238 Mdot
.35851 .47269 Mdot
.53634 .32876 Mdot
.68327 .42005 Mdot
.37002 .51654 Mdot
.32292 .49302 Mdot
.5665 .70845 Mdot
.46417 .28692 Mdot
.65762 .5916 Mdot
.54791 .32048 Mdot
.68773 .38709 Mdot
.44179 .28263 Mdot
.54523 .70983 Mdot
.41283 .47237 Mdot
.50805 .31036 Mdot
.54132 .35231 Mdot
.3524 .50891 Mdot
.29401 .4537 Mdot
.49869 .32444 Mdot
.6753 .60918 Mdot
.67475 .42668 Mdot
.53779 .31337 Mdot
.29336 .59804 Mdot
.31317 .60484 Mdot
.36127 .49868 Mdot
.54706 .72686 Mdot
.65375 .59782 Mdot
.51507 .33857 Mdot
.6898 .31021 Mdot
.32087 .45001 Mdot
.27248 .60234 Mdot
.58622 .34165 Mdot
.53426 .3315 Mdot
.46362 .66644 Mdot
.39926 .26315 Mdot
.36636 .65857 Mdot
.36886 .46818 Mdot
.29992 .61736 Mdot
.38578 .50023 Mdot
.66496 .43393 Mdot
.64716 .62434 Mdot
.48656 .3094 Mdot
.6855 .42957 Mdot
.47673 .6847 Mdot
.28083 .45764 Mdot
.59677 .70122 Mdot
.60001 .71578 Mdot
.52538 .69526 Mdot
.66918 .62009 Mdot
.42245 .69233 Mdot
.50024 .32175 Mdot
.37243 .50419 Mdot
.73471 .56855 Mdot
.50966 .68894 Mdot
.29085 .62023 Mdot
.5 .68226 Mdot
.56349 .69848 Mdot
.30113 .62024 Mdot
.37305 .67364 Mdot
.35337 .45744 Mdot
.3848 .50949 Mdot
.40387 .258 Mdot
.59935 .72622 Mdot
.27305 .60876 Mdot
.34416 .47389 Mdot
.35284 .50316 Mdot
.36561 .67844 Mdot
.45573 .3025 Mdot
.27125 .44563 Mdot
.36745 .50683 Mdot
.2575 .44188 Mdot
.2893 .6188 Mdot
.5935 .69362 Mdot
.74381 .57508 Mdot
.34069 .66305 Mdot
.70234 .45615 Mdot
.4765 .70182 Mdot
.4506 .26917 Mdot
.4642 .67372 Mdot
.38218 .65703 Mdot
.65347 .61903 Mdot
.58473 .72567 Mdot
.69857 .40599 Mdot
.65966 .60794 Mdot
.73127 .55988 Mdot
.36158 .67608 Mdot
.67022 .42789 Mdot
.46586 .29034 Mdot
.71211 .57746 Mdot
.36851 .69527 Mdot
.66704 .60842 Mdot
.55816 .68761 Mdot
.30577 .60636 Mdot
.36607 .46675 Mdot
.52661 .3359 Mdot
.48476 .31131 Mdot
.72248 .57301 Mdot
.42801 .27624 Mdot
.38323 .67371 Mdot
.46349 .69236 Mdot
.42265 .27801 Mdot
.48485 .71399 Mdot
.69817 .33874 Mdot
.47905 .70801 Mdot
.68871 .33656 Mdot
.55957 .72267 Mdot
.26624 .46373 Mdot
.4607 .28389 Mdot
.49831 .33273 Mdot
.2785 .59075 Mdot
.54143 .3413 Mdot
.36961 .51479 Mdot
.38235 .67875 Mdot
.33359 .48134 Mdot
.71177 .46044 Mdot
.42472 .25093 Mdot
.48783 .68725 Mdot
.44107 .3168 Mdot
.67076 .59204 Mdot
.29396 .60549 Mdot
.55499 .32474 Mdot
.36972 .66134 Mdot
.49202 .68074 Mdot
.55625 .71059 Mdot
.44052 .70167 Mdot
.7114 .45631 Mdot
.48379 .34317 Mdot
.35607 .49243 Mdot
.44583 .31401 Mdot
.72778 .56693 Mdot
.72192 .55578 Mdot
.68645 .40204 Mdot
.35248 .26388 Mdot
.68729 .43272 Mdot
.47906 .28143 Mdot
.55631 .72063 Mdot
.44268 .29558 Mdot
.34623 .48663 Mdot
.45837 .7005 Mdot
.4594 .66649 Mdot
.46707 .2838 Mdot
.39684 .26445 Mdot
.72406 .55585 Mdot
.73859 .56339 Mdot
.5561 .33963 Mdot
.28804 .6179 Mdot
.28704 .62036 Mdot
.37723 .49456 Mdot
.72144 .57634 Mdot
.37072 .6671 Mdot
.73431 .58277 Mdot
.3559 .65584 Mdot
.41873 .24948 Mdot
.69862 .44865 Mdot
.73572 .5128 Mdot
.4699 .70184 Mdot
.2813 .45874 Mdot
.5327 .69059 Mdot
.33608 .44589 Mdot
.7017 .58499 Mdot
.46846 .27754 Mdot
.6958 .41761 Mdot
.65159 .64376 Mdot
.69266 .44797 Mdot
.39677 .29076 Mdot
.27112 .58139 Mdot
.68499 .6093 Mdot
.30039 .60755 Mdot
.66039 .4143 Mdot
.38255 .51164 Mdot
.52785 .31233 Mdot
.56121 .32039 Mdot
.39107 .66214 Mdot
.45068 .71067 Mdot
.40175 .25795 Mdot
.34664 .48659 Mdot
.52021 .70525 Mdot
.34976 .48952 Mdot
.35193 .49098 Mdot
.33749 .50814 Mdot
.72087 .5647 Mdot
.30327 .60382 Mdot
.33825 .48422 Mdot
.68356 .32403 Mdot
.48146 .29404 Mdot
.69836 .39016 Mdot
.48796 .69329 Mdot
.41807 .27617 Mdot
.47952 .70374 Mdot
.29143 .5886 Mdot
.68938 .59999 Mdot
.49141 .712 Mdot
.36417 .66839 Mdot
.49774 .67881 Mdot
.70402 .58885 Mdot
.4224 .25732 Mdot
.53328 .3256 Mdot
.62812 .68997 Mdot
.68883 .32225 Mdot
.54955 .33324 Mdot
.70161 .3321 Mdot
.38408 .50567 Mdot
.57803 .70683 Mdot
.54298 .33934 Mdot
.64631 .60558 Mdot
.65888 .42516 Mdot
.37002 .46691 Mdot
.31849 .45894 Mdot
.7149 .43513 Mdot
.52579 .33149 Mdot
.29136 .59818 Mdot
.30364 .58956 Mdot
.66048 .41266 Mdot
.6315 .63193 Mdot
.72581 .56653 Mdot
.41895 .26956 Mdot
.58199 .69511 Mdot
.56097 .70948 Mdot
.66694 .59397 Mdot
.6583 .64055 Mdot
.31283 .45551 Mdot
.31403 .45989 Mdot
.28283 .59339 Mdot
.39424 .50386 Mdot
.69311 .31047 Mdot
.54759 .3312 Mdot
.5703 .72141 Mdot
.38179 .6799 Mdot
.35257 .67776 Mdot
.34026 .48185 Mdot
.25104 .4682 Mdot
.70918 .41684 Mdot
.36591 .65565 Mdot
.41249 .28488 Mdot
.42715 .69226 Mdot
.30291 .45915 Mdot
.41722 .24902 Mdot
.55844 .71425 Mdot
.72542 .40012 Mdot
.66121 .61109 Mdot
.66111 .40048 Mdot
.66089 .39814 Mdot
.59398 .31572 Mdot
.47389 .70062 Mdot
.54917 .33337 Mdot
.70003 .30771 Mdot
.56441 .32642 Mdot
.39914 .26827 Mdot
.27219 .45256 Mdot
.68811 .32873 Mdot
.69229 .3865 Mdot
.67666 .61923 Mdot
.37017 .47925 Mdot
.30767 .47235 Mdot
.71047 .56886 Mdot
.34329 .50325 Mdot
.44005 .26906 Mdot
.73776 .57102 Mdot
.58628 .72494 Mdot
.40965 .25711 Mdot
.71766 .58419 Mdot
.55984 .70769 Mdot
.36222 .67502 Mdot
.28894 .6198 Mdot
.46661 .68808 Mdot
.54486 .71267 Mdot
.3123 .45398 Mdot
.68116 .32021 Mdot
.56845 .71393 Mdot
.45544 .68857 Mdot
.43967 .70379 Mdot
.6726 .39462 Mdot
.41185 .28919 Mdot
.66478 .6266 Mdot
.33102 .48283 Mdot
.70705 .44985 Mdot
.42928 .28952 Mdot
.5786 .72653 Mdot
.31279 .48387 Mdot
.3296 .45825 Mdot
.42427 .28171 Mdot
.3944 .26828 Mdot
.42483 .27593 Mdot
.72894 .55744 Mdot
.36323 .67106 Mdot
.48577 .68062 Mdot
.70485 .58264 Mdot
.44537 .26583 Mdot
.39144 .25465 Mdot
.53593 .36726 Mdot
.31124 .45696 Mdot
.39113 .26208 Mdot
.42616 .6951 Mdot
.29576 .57254 Mdot
.56413 .32569 Mdot
.4463 .23799 Mdot
.72816 .4502 Mdot
.4742 .2643 Mdot
.64887 .62434 Mdot
.35454 .66035 Mdot
.41407 .26434 Mdot
.51747 .3218 Mdot
.3164 .4578 Mdot
.30737 .44563 Mdot
.43109 .28311 Mdot
.24947 .46209 Mdot
.56825 .70441 Mdot
.53931 .68504 Mdot
.41961 .27876 Mdot
.66449 .41271 Mdot
.7171 .4224 Mdot
.69602 .43316 Mdot
.36094 .50298 Mdot
.2892 .63043 Mdot
.23831 .53293 Mdot
.43952 .69982 Mdot
.73524 .56319 Mdot
.55671 .71696 Mdot
.48276 .71775 Mdot
.48108 .6843 Mdot
.6593 .43279 Mdot
.42827 .27601 Mdot
.54564 .72668 Mdot
.731 .55651 Mdot
.72092 .57311 Mdot
.69663 .39183 Mdot
.68426 .43316 Mdot
.70494 .42811 Mdot
.45235 .7008 Mdot
.52816 .70515 Mdot
.30327 .61418 Mdot
.59805 .7179 Mdot
.68296 .45918 Mdot
.68924 .34783 Mdot
.69946 .39405 Mdot
.67564 .60131 Mdot
.55139 .72592 Mdot
.30589 .4586 Mdot
.40446 .50254 Mdot
.71786 .42307 Mdot
.43654 .25963 Mdot
.42814 .70429 Mdot
.35692 .24244 Mdot
.34769 .66136 Mdot
.64974 .60663 Mdot
.51419 .32677 Mdot
.3226 .47477 Mdot
.67617 .42511 Mdot
.45338 .24354 Mdot
.5302 .34907 Mdot
.29116 .60917 Mdot
.41205 .69124 Mdot
.65233 .61245 Mdot
.30604 .5909 Mdot
.52337 .31407 Mdot
.38685 .68046 Mdot
.73442 .57333 Mdot
.69296 .39597 Mdot
.70454 .34725 Mdot
.47077 .71013 Mdot
.27614 .45831 Mdot
.50878 .32847 Mdot
.37437 .4869 Mdot
.69707 .44257 Mdot
.40998 .25787 Mdot
.70414 .43918 Mdot
.58995 .6929 Mdot
.68235 .38887 Mdot
.3137 .47648 Mdot
.49317 .68288 Mdot
.72503 .56912 Mdot
.23069 .5291 Mdot
.44295 .32078 Mdot
.67839 .39806 Mdot
.49757 .32981 Mdot
.35483 .67647 Mdot
.34267 .67517 Mdot
.48408 .3096 Mdot
.31176 .47761 Mdot
.67757 .59593 Mdot
.48016 .67843 Mdot
.66594 .59205 Mdot
.41567 .29217 Mdot
.627 .69885 Mdot
.66034 .6121 Mdot
.28841 .63204 Mdot
.41658 .25605 Mdot
.25143 .4655 Mdot
.32153 .48699 Mdot
.64403 .61395 Mdot
.29814 .60332 Mdot
.51992 .70541 Mdot
.2969 .57894 Mdot
.36306 .46682 Mdot
.67293 .59427 Mdot
.55556 .34512 Mdot
.30506 .59378 Mdot
.42813 .2982 Mdot
.71569 .57754 Mdot
.31391 .60213 Mdot
.54812 .32858 Mdot
.44666 .28158 Mdot
.41305 .25334 Mdot
.43925 .27992 Mdot
.31915 .47715 Mdot
.40297 .48718 Mdot
.45828 .28116 Mdot
.64099 .60602 Mdot
.45554 .28164 Mdot
.46925 .2664 Mdot
.72655 .54893 Mdot
.39396 .26586 Mdot
.33242 .49886 Mdot
.35536 .65657 Mdot
.3543 .66201 Mdot
.68017 .40765 Mdot
.63293 .69169 Mdot
.68224 .33468 Mdot
.34794 .47836 Mdot
.50215 .72121 Mdot
.48308 .68932 Mdot
.49312 .31686 Mdot
.35693 .4629 Mdot
.38436 .66132 Mdot
.46916 .68466 Mdot
.28425 .59601 Mdot
.48463 .70762 Mdot
.5201 .31173 Mdot
.31661 .4742 Mdot
.48086 .69656 Mdot
.51964 .69159 Mdot
.24416 .47035 Mdot
.49305 .70677 Mdot
.56432 .72628 Mdot
.73414 .56144 Mdot
.65229 .62546 Mdot
.67664 .59514 Mdot
.68132 .43502 Mdot
.58357 .72236 Mdot
.28512 .4577 Mdot
.67704 .42892 Mdot
.36086 .50977 Mdot
.67056 .59403 Mdot
.39116 .48786 Mdot
.58565 .72106 Mdot
.32664 .49259 Mdot
.27513 .6213 Mdot
.70311 .33203 Mdot
.42542 .28183 Mdot
.45637 .71399 Mdot
.69773 .35565 Mdot
.71331 .57563 Mdot
.60928 .69671 Mdot
.469 .27273 Mdot
.3889 .68099 Mdot
.3024 .47159 Mdot
.33652 .50917 Mdot
.38813 .68118 Mdot
.27494 .57646 Mdot
.54369 .35094 Mdot
.67753 .43497 Mdot
.66704 .39355 Mdot
.30438 .45203 Mdot
.5791 .72031 Mdot
.41456 .28885 Mdot
.40733 .24821 Mdot
.47977 .31539 Mdot
.29942 .58861 Mdot
.35331 .45874 Mdot
.38257 .4851 Mdot
.28014 .4588 Mdot
.6884 .40624 Mdot
.56077 .34797 Mdot
.28365 .60231 Mdot
.44521 .2762 Mdot
.29114 .45959 Mdot
.48666 .69531 Mdot
.57881 .72869 Mdot
.70998 .4232 Mdot
.75123 .56258 Mdot
.51504 .3071 Mdot
.70624 .39942 Mdot
.30381 .45259 Mdot
.36339 .68503 Mdot
.74611 .55985 Mdot
.55003 .70221 Mdot
.44492 .28552 Mdot
.67817 .42323 Mdot
.45458 .29164 Mdot
.59591 .71402 Mdot
.57754 .72647 Mdot
.29152 .4443 Mdot
.46854 .33231 Mdot
.68856 .39361 Mdot
.35963 .49791 Mdot
.71396 .43691 Mdot
.69066 .33625 Mdot
.72839 .58504 Mdot
.28839 .45351 Mdot
.46993 .66638 Mdot
.68152 .59427 Mdot
.35386 .48488 Mdot
.3555 .67025 Mdot
.38184 .67013 Mdot
.66212 .41624 Mdot
.45461 .27066 Mdot
.45052 .28228 Mdot
.60433 .68918 Mdot
.56101 .7417 Mdot
.37625 .48063 Mdot
.67398 .39569 Mdot
.38303 .69506 Mdot
.65831 .6167 Mdot
.55524 .72202 Mdot
.70959 .53923 Mdot
.67189 .60693 Mdot
.30812 .45715 Mdot
.4397 .27137 Mdot
.5507 .70729 Mdot
.56433 .32527 Mdot
.21347 .50263 Mdot
.50607 .34207 Mdot
.48241 .34149 Mdot
.54574 .32133 Mdot
.70911 .55978 Mdot
.70798 .43139 Mdot
.50069 .6837 Mdot
.64962 .60305 Mdot
.65559 .61817 Mdot
.69009 .35798 Mdot
.44492 .70481 Mdot
.55967 .68471 Mdot
.42026 .69197 Mdot
.68917 .32291 Mdot
.43149 .27395 Mdot
.29087 .57691 Mdot
.69468 .43223 Mdot
.70865 .31836 Mdot
.72915 .55268 Mdot
.72089 .55652 Mdot
.52877 .70974 Mdot
.33795 .46464 Mdot
.43968 .703 Mdot
.36608 .51137 Mdot
.27206 .45339 Mdot
.66078 .59767 Mdot
.5561 .72209 Mdot
.74493 .54649 Mdot
.29791 .44942 Mdot
.32805 .46809 Mdot
.66546 .44847 Mdot
.54116 .32989 Mdot
.64978 .43146 Mdot
.28453 .45136 Mdot
.68756 .43989 Mdot
.53598 .69478 Mdot
.51383 .31967 Mdot
.27185 .60526 Mdot
.7431 .55566 Mdot
.51205 .3367 Mdot
.51628 .3154 Mdot
.30876 .49296 Mdot
.48022 .70696 Mdot
.60616 .70339 Mdot
.40393 .28024 Mdot
.75201 .54705 Mdot
.72824 .58252 Mdot
.71921 .5501 Mdot
.30573 .45633 Mdot
.73866 .55159 Mdot
.50801 .30356 Mdot
.35631 .48607 Mdot
.37507 .68126 Mdot
.47218 .71273 Mdot
.37624 .48561 Mdot
.37046 .65174 Mdot
.6702 .60373 Mdot
.58461 .3441 Mdot
.37515 .48063 Mdot
.71303 .42907 Mdot
.53551 .71486 Mdot
.46347 .707 Mdot
.40687 .26563 Mdot
.71326 .56834 Mdot
.35364 .25229 Mdot
.55451 .72222 Mdot
.31635 .46233 Mdot
.66189 .61581 Mdot
.51199 .32727 Mdot
.53012 .33919 Mdot
.49601 .33169 Mdot
.571 .73115 Mdot
.51534 .3233 Mdot
.52979 .69131 Mdot
.28663 .59273 Mdot
.2749 .4509 Mdot
.67094 .61782 Mdot
.4332 .27325 Mdot
.46142 .31024 Mdot
.69401 .34187 Mdot
.28437 .61489 Mdot
.26973 .45025 Mdot
.62624 .70724 Mdot
.43479 .26981 Mdot
.32956 .47845 Mdot
.54437 .35126 Mdot
.30255 .63574 Mdot
.38873 .22654 Mdot
.5531 .32937 Mdot
.35084 .67874 Mdot
.57 .69906 Mdot
.54519 .34037 Mdot
.58491 .72819 Mdot
.33273 .47888 Mdot
.29193 .60527 Mdot
.60317 .69798 Mdot
.62145 .68138 Mdot
.50825 .3093 Mdot
.71568 .58596 Mdot
.29826 .6 Mdot
.33721 .50425 Mdot
.28489 .62831 Mdot
.51594 .33345 Mdot
.62996 .66635 Mdot
.71014 .44637 Mdot
.6812 .34542 Mdot
.69816 .30573 Mdot
.70428 .57767 Mdot
.75373 .54309 Mdot
.3042 .44248 Mdot
.41785 .67712 Mdot
.28703 .62928 Mdot
.68884 .59414 Mdot
.28691 .5695 Mdot
.3404 .48555 Mdot
.35619 .50822 Mdot
.71427 .43686 Mdot
.67951 .61544 Mdot
.34111 .66326 Mdot
.28599 .60189 Mdot
.44018 .25929 Mdot
.59389 .72213 Mdot
.33301 .48695 Mdot
.62518 .7069 Mdot
.66277 .41226 Mdot
.63129 .70093 Mdot
.334 .49913 Mdot
.54082 .32943 Mdot
.74932 .55147 Mdot
.72836 .56507 Mdot
.66537 .41931 Mdot
.66687 .41551 Mdot
.3393 .50504 Mdot
.67919 .58768 Mdot
.28707 .5706 Mdot
.30275 .5915 Mdot
.52362 .3289 Mdot
.41173 .28041 Mdot
.36489 .51502 Mdot
.55182 .68513 Mdot
.45498 .32863 Mdot
.36155 .50006 Mdot
.59986 .70565 Mdot
.70278 .42373 Mdot
.69859 .34023 Mdot
.5628 .71441 Mdot
.69848 .33398 Mdot
.63053 .69886 Mdot
.39931 .48309 Mdot
.40323 .27521 Mdot
.33483 .63818 Mdot
.4586 .2855 Mdot
.51352 .33663 Mdot
.31064 .45781 Mdot
.7145 .38764 Mdot
.7001 .30499 Mdot
.3212 .6421 Mdot
.65858 .60434 Mdot
.56417 .33543 Mdot
.36863 .6686 Mdot
.43288 .2539 Mdot
.6854 .42108 Mdot
.5451 .31149 Mdot
.28812 .45606 Mdot
.4736 .70304 Mdot
.34496 .65565 Mdot
.55323 .31967 Mdot
.51937 .3398 Mdot
.5258 .30737 Mdot
.71724 .58432 Mdot
.44895 .68929 Mdot
.72679 .55366 Mdot
.70188 .34096 Mdot
.3044 .61229 Mdot
.31735 .46591 Mdot
.55767 .71854 Mdot
.37144 .49608 Mdot
.68495 .59071 Mdot
.44627 .71874 Mdot
.42529 .27361 Mdot
.51439 .31256 Mdot
.64903 .65251 Mdot
.56376 .32347 Mdot
.3798 .68415 Mdot
.36221 .68863 Mdot
.48986 .69269 Mdot
.6942 .59352 Mdot
.38831 .51144 Mdot
.67248 .38585 Mdot
.44739 .28503 Mdot
.73209 .55774 Mdot
.37478 .68386 Mdot
.32102 .48876 Mdot
.4346 .27197 Mdot
.72122 .55712 Mdot
.47506 .31544 Mdot
.66849 .58774 Mdot
.51033 .34654 Mdot
.32945 .64615 Mdot
.33421 .4953 Mdot
.54283 .32755 Mdot
.47508 .68702 Mdot
.73326 .56634 Mdot
.4552 .70846 Mdot
.52036 .31209 Mdot
.69138 .34113 Mdot
.73399 .55851 Mdot
.2951 .46198 Mdot
.46559 .67388 Mdot
.52204 .70837 Mdot
.45514 .68547 Mdot
.62443 .32576 Mdot
.68509 .33524 Mdot
.70745 .42698 Mdot
.6756 .6029 Mdot
.70633 .45159 Mdot
.41706 .25556 Mdot
.28859 .57733 Mdot
.67161 .40586 Mdot
.44769 .69144 Mdot
.68804 .44832 Mdot
.27475 .58636 Mdot
.70901 .58812 Mdot
.71208 .40746 Mdot
.37677 .50166 Mdot
.35801 .67033 Mdot
.52682 .34338 Mdot
.46493 .30204 Mdot
.28841 .59383 Mdot
.35058 .47088 Mdot
.53363 .32213 Mdot
.32974 .49469 Mdot
.6838 .59001 Mdot
.23308 .52794 Mdot
.29934 .619 Mdot
.69431 .33651 Mdot
.62125 .68767 Mdot
.66512 .39557 Mdot
.38399 .26059 Mdot
.36669 .49671 Mdot
.3273 .49039 Mdot
.37779 .66895 Mdot
.43273 .71081 Mdot
.72332 .56355 Mdot
.30628 .6128 Mdot
.69385 .32269 Mdot
.49669 .68719 Mdot
.49511 .6905 Mdot
.28125 .46232 Mdot
.54551 .32823 Mdot
.64481 .62646 Mdot
.31648 .47652 Mdot
.56369 .32724 Mdot
.36194 .46752 Mdot
.70622 .57168 Mdot
.68407 .33606 Mdot
.707 .32234 Mdot
.50248 .69328 Mdot
.71748 .42823 Mdot
.37714 .6672 Mdot
.51537 .32519 Mdot
.69733 .30459 Mdot
.71961 .56525 Mdot
.44851 .28585 Mdot
.36139 .50712 Mdot
.24689 .46722 Mdot
.71807 .42839 Mdot
.6721 .42859 Mdot
.28615 .5713 Mdot
.62747 .70761 Mdot
.50304 .35765 Mdot
.72995 .57329 Mdot
.48843 .69543 Mdot
.41679 .4587 Mdot
.38624 .3631 Mdot
.65869 .62238 Mdot
.36883 .68305 Mdot
.7149 .42017 Mdot
.59287 .33326 Mdot
.47502 .68372 Mdot
.44708 .28626 Mdot
.37354 .49506 Mdot
.49061 .68817 Mdot
.69192 .3142 Mdot
.46693 .67898 Mdot
.5415 .33661 Mdot
.70618 .58883 Mdot
.68606 .41443 Mdot
.6776 .61762 Mdot
.46623 .66674 Mdot
.42902 .27395 Mdot
.27559 .46383 Mdot
.35469 .65438 Mdot
.48789 .71278 Mdot
.36634 .67343 Mdot
.49515 .30694 Mdot
.36188 .6734 Mdot
.49294 .69599 Mdot
.32239 .48844 Mdot
.38809 .49685 Mdot
.69473 .35051 Mdot
.34952 .5082 Mdot
.32238 .45183 Mdot
.27592 .62233 Mdot
.36599 .50242 Mdot
.35268 .49119 Mdot
.29173 .45204 Mdot
.5906 .69916 Mdot
.36548 .47173 Mdot
.53534 .70792 Mdot
.55835 .69515 Mdot
.7024 .33867 Mdot
.42584 .25104 Mdot
.39753 .27225 Mdot
.36929 .47344 Mdot
.2484 .46784 Mdot
.44786 .70785 Mdot
.54794 .72601 Mdot
.72646 .56864 Mdot
.29556 .61692 Mdot
.49899 .35566 Mdot
.3892 .49092 Mdot
.68007 .40655 Mdot
.66508 .40876 Mdot
.37595 .51033 Mdot
.35793 .2404 Mdot
.28149 .44234 Mdot
.28106 .5853 Mdot
.32156 .48012 Mdot
.28825 .44786 Mdot
.67162 .39273 Mdot
.26499 .46271 Mdot
.3787 .65838 Mdot
.49826 .69778 Mdot
.44775 .28979 Mdot
.54673 .33648 Mdot
.29193 .60514 Mdot
.41289 .46687 Mdot
.47775 .70995 Mdot
.37916 .67051 Mdot
.67898 .41594 Mdot
.57298 .72464 Mdot
.27943 .58937 Mdot
.71142 .58108 Mdot
.21452 .49497 Mdot
.62676 .69745 Mdot
.71899 .5798 Mdot
.44656 .28245 Mdot
.6969 .40226 Mdot
.3297 .47372 Mdot
.68238 .44388 Mdot
.29715 .45181 Mdot
.30285 .58396 Mdot
.40425 .27516 Mdot
.45437 .69497 Mdot
.74312 .55683 Mdot
.58141 .70051 Mdot
.56185 .68572 Mdot
.26414 .53904 Mdot
.65694 .39077 Mdot
.68494 .3896 Mdot
.44618 .31669 Mdot
.52008 .69872 Mdot
.3185 .44916 Mdot
.42178 .69004 Mdot
.58116 .70776 Mdot
.467 .70433 Mdot
.21704 .50174 Mdot
.24498 .44877 Mdot
.29264 .45471 Mdot
.47915 .68821 Mdot
.69941 .40303 Mdot
.40081 .27341 Mdot
.31024 .45018 Mdot
.51496 .32619 Mdot
.50275 .6928 Mdot
.71353 .42309 Mdot
.27057 .46421 Mdot
.68525 .4371 Mdot
.48524 .68291 Mdot
.66254 .40394 Mdot
.73144 .58398 Mdot
.67288 .40377 Mdot
.35823 .51559 Mdot
.32136 .48345 Mdot
.49488 .69381 Mdot
.57764 .72633 Mdot
.38085 .68339 Mdot
.37214 .5028 Mdot
.50667 .68753 Mdot
.69418 .45669 Mdot
.54159 .72719 Mdot
.38371 .67335 Mdot
.32439 .45493 Mdot
.45764 .28244 Mdot
.30949 .60766 Mdot
.22249 .52015 Mdot
.30185 .61873 Mdot
.43196 .27677 Mdot
.42256 .67609 Mdot
.31033 .46639 Mdot
.25418 .45582 Mdot
.69275 .31957 Mdot
.38078 .50032 Mdot
.50978 .3213 Mdot
.38783 .66991 Mdot
.22399 .47111 Mdot
.37663 .68259 Mdot
.4613 .68589 Mdot
.48861 .68274 Mdot
.67752 .45013 Mdot
.47973 .68514 Mdot
.51155 .3245 Mdot
.64428 .62505 Mdot
.55792 .68727 Mdot
.56147 .34727 Mdot
.51738 .34353 Mdot
.50027 .32157 Mdot
.55275 .32451 Mdot
.49561 .35266 Mdot
.68912 .35429 Mdot
.52162 .34425 Mdot
.52074 .69641 Mdot
.73095 .4425 Mdot
.46984 .27752 Mdot
.64447 .62646 Mdot
.51515 .31698 Mdot
.38104 .49949 Mdot
.3797 .67526 Mdot
.61118 .69883 Mdot
.70245 .58329 Mdot
.50521 .30628 Mdot
.31773 .45014 Mdot
.5071 .69565 Mdot
.3351 .48671 Mdot
.44956 .26635 Mdot
.58722 .72027 Mdot
.67963 .42666 Mdot
.40534 .2747 Mdot
.5358 .31399 Mdot
.42041 .2774 Mdot
.70517 .44178 Mdot
.66354 .58799 Mdot
.37359 .49332 Mdot
.4673 .30882 Mdot
.42064 .2517 Mdot
.37916 .4969 Mdot
.51752 .69823 Mdot
.50767 .30671 Mdot
.33651 .46238 Mdot
.37255 .66905 Mdot
.56201 .7055 Mdot
.64391 .66626 Mdot
.3328 .47395 Mdot
.3622 .68798 Mdot
.50128 .69617 Mdot
.56132 .326 Mdot
.67903 .43099 Mdot
.31426 .48562 Mdot
.65568 .60223 Mdot
.66887 .5933 Mdot
.69092 .31567 Mdot
.60337 .71556 Mdot
.71889 .44868 Mdot
.37559 .51566 Mdot
.51843 .31523 Mdot
.3148 .48386 Mdot
.6799 .4576 Mdot
.6352 .67995 Mdot
.54813 .71153 Mdot
.70489 .33512 Mdot
.32594 .44084 Mdot
.65083 .63314 Mdot
.69582 .33606 Mdot
.49745 .69688 Mdot
.5986 .71433 Mdot
.56359 .71649 Mdot
.41535 .28666 Mdot
.68511 .4318 Mdot
.5992 .69497 Mdot
.57154 .69692 Mdot
.38197 .67189 Mdot
.37691 .50978 Mdot
.48331 .69576 Mdot
.68703 .32354 Mdot
.4514 .28551 Mdot
.69756 .32407 Mdot
.45195 .32695 Mdot
.73618 .56641 Mdot
.27107 .59273 Mdot
.28429 .616 Mdot
.35161 .26274 Mdot
.29206 .46156 Mdot
.31965 .47643 Mdot
.445 .69962 Mdot
.47342 .30159 Mdot
.44722 .29759 Mdot
.51818 .69732 Mdot
.54752 .70934 Mdot
.41127 .27477 Mdot
.39953 .48921 Mdot
.24038 .47686 Mdot
.32002 .43833 Mdot
.44708 .68848 Mdot
.53429 .68753 Mdot
.66499 .59968 Mdot
.50174 .69187 Mdot
.73651 .43026 Mdot
.70324 .39821 Mdot
.67894 .39701 Mdot
.73175 .56332 Mdot
.32769 .47178 Mdot
.68101 .38816 Mdot
.36376 .65709 Mdot
.73561 .41783 Mdot
.35535 .67536 Mdot
.69196 .30385 Mdot
.37332 .50076 Mdot
.66603 .63174 Mdot
.70772 .56293 Mdot
.38552 .67731 Mdot
.40298 .48446 Mdot
.43824 .28482 Mdot
.44453 .70038 Mdot
.68566 .59639 Mdot
.44159 .70412 Mdot
.33146 .49366 Mdot
.46888 .69492 Mdot
.74318 .56149 Mdot
.62962 .67124 Mdot
.38268 .66042 Mdot
.36794 .66028 Mdot
.44717 .7121 Mdot
.50701 .68416 Mdot
.68012 .43305 Mdot
.47154 .70634 Mdot
.58344 .69352 Mdot
.35787 .67314 Mdot
.71523 .41724 Mdot
.30873 .57755 Mdot
.45315 .69279 Mdot
.41418 .28972 Mdot
.59293 .71681 Mdot
.41359 .27835 Mdot
.60506 .69688 Mdot
.69511 .35284 Mdot
.3525 .4874 Mdot
.70217 .33741 Mdot
.4369 .2606 Mdot
.66518 .3902 Mdot
.68821 .58887 Mdot
.52532 .31881 Mdot
.68063 .59385 Mdot
.28776 .58123 Mdot
.44032 .70105 Mdot
.64886 .62514 Mdot
.27817 .54594 Mdot
.31841 .48512 Mdot
.60562 .69726 Mdot
.68037 .41807 Mdot
.69968 .31805 Mdot
.29237 .59012 Mdot
.55895 .72651 Mdot
.68123 .45021 Mdot
.37115 .69534 Mdot
.72346 .39785 Mdot
.38816 .67523 Mdot
.71647 .53676 Mdot
.47652 .6792 Mdot
.69818 .31518 Mdot
.28172 .58277 Mdot
.55945 .69737 Mdot
.69624 .39534 Mdot
.66545 .58844 Mdot
.65574 .6031 Mdot
.32562 .50203 Mdot
.67303 .62233 Mdot
.67914 .40891 Mdot
.63004 .70422 Mdot
.59825 .69584 Mdot
.63505 .68396 Mdot
.42792 .27693 Mdot
.70435 .41213 Mdot
.52194 .32893 Mdot
.45482 .66803 Mdot
.69885 .45039 Mdot
.35384 .24817 Mdot
.67625 .286 Mdot
.70909 .45819 Mdot
.58828 .72127 Mdot
.56828 .73052 Mdot
.34575 .66164 Mdot
.29127 .59295 Mdot
.68636 .41949 Mdot
.73392 .43814 Mdot
.35177 .45686 Mdot
.52851 .31764 Mdot
.68766 .31388 Mdot
.28662 .45904 Mdot
.36834 .67157 Mdot
.72727 .57214 Mdot
.32913 .46823 Mdot
.54072 .7081 Mdot
.28228 .44748 Mdot
.68416 .59442 Mdot
.65918 .43592 Mdot
.33051 .49402 Mdot
.44665 .28392 Mdot
.65334 .59795 Mdot
.66013 .59382 Mdot
.66651 .38437 Mdot
.60343 .71583 Mdot
.46498 .71314 Mdot
.68362 .43312 Mdot
.36009 .66756 Mdot
.53074 .32399 Mdot
.29167 .45593 Mdot
.45848 .69973 Mdot
.4411 .69939 Mdot
.70405 .41118 Mdot
.37644 .48802 Mdot
.6688 .61458 Mdot
.70366 .45923 Mdot
.36158 .68262 Mdot
.68292 .3968 Mdot
.55271 .35769 Mdot
.69891 .3918 Mdot
.52696 .69123 Mdot
.49397 .31504 Mdot
.4655 .69595 Mdot
.53879 .34936 Mdot
.59558 .31687 Mdot
.44771 .28167 Mdot
.66923 .39565 Mdot
.62036 .67954 Mdot
.70505 .32964 Mdot
.36628 .49934 Mdot
.30697 .45994 Mdot
.70822 .44485 Mdot
.42943 .27174 Mdot
.47561 .26597 Mdot
.46785 .29199 Mdot
.58389 .72567 Mdot
.38551 .6619 Mdot
.69108 .29107 Mdot
.70915 .33057 Mdot
.7434 .56717 Mdot
.50459 .70202 Mdot
.52236 .34663 Mdot
.68973 .58693 Mdot
.66156 .5924 Mdot
.42134 .26698 Mdot
.70866 .32025 Mdot
.47039 .70125 Mdot
.68336 .60937 Mdot
.55512 .69872 Mdot
.25554 .45333 Mdot
.5541 .3219 Mdot
.44708 .31305 Mdot
.54659 .34993 Mdot
.28416 .5976 Mdot
.66873 .62426 Mdot
.34761 .49341 Mdot
.43887 .25722 Mdot
.73103 .56608 Mdot
.46117 .2858 Mdot
.36513 .68321 Mdot
.65934 .43263 Mdot
.53161 .73599 Mdot
.33185 .50697 Mdot
.35662 .48451 Mdot
.73726 .5627 Mdot
.40722 .48301 Mdot
.49107 .70106 Mdot
.59017 .69599 Mdot
.7073 .43088 Mdot
.21806 .51099 Mdot
.28755 .44283 Mdot
.31293 .45058 Mdot
.6962 .44596 Mdot
.54909 .33034 Mdot
.68393 .34744 Mdot
.31761 .45362 Mdot
.67048 .60119 Mdot
.37292 .6828 Mdot
.64629 .63303 Mdot
.37877 .51424 Mdot
.3576 .48955 Mdot
.36463 .6588 Mdot
.36809 .67717 Mdot
.68034 .59417 Mdot
.55054 .32601 Mdot
.51737 .30918 Mdot
.45072 .68959 Mdot
.37525 .5036 Mdot
.34507 .45075 Mdot
.31659 .47587 Mdot
.43869 .28445 Mdot
.22188 .52524 Mdot
.27486 .58416 Mdot
.30276 .60007 Mdot
.3729 .47067 Mdot
.33521 .48129 Mdot
.74027 .56368 Mdot
.56105 .7295 Mdot
.66468 .61742 Mdot
.70013 .59416 Mdot
.67676 .44542 Mdot
.46101 .28684 Mdot
.34106 .50597 Mdot
.41438 .26026 Mdot
.27684 .43548 Mdot
.38761 .26211 Mdot
.28697 .60459 Mdot
.28994 .57253 Mdot
.42291 .29308 Mdot
.31298 .47599 Mdot
.711 .43782 Mdot
.67867 .38266 Mdot
.35433 .66079 Mdot
.36915 .51567 Mdot
.74121 .57264 Mdot
.64365 .61605 Mdot
.68549 .34216 Mdot
.69281 .36439 Mdot
.44987 .26645 Mdot
.58676 .34098 Mdot
.36172 .67454 Mdot
.33366 .50531 Mdot
.5428 .32017 Mdot
.71652 .4454 Mdot
.53292 .34847 Mdot
.68969 .34561 Mdot
.6842 .60096 Mdot
.65106 .61775 Mdot
.37198 .50861 Mdot
.37 .23098 Mdot
.58334 .70562 Mdot
.56849 .73018 Mdot
.6416 .61835 Mdot
.66529 .39545 Mdot
.5379 .34088 Mdot
.42664 .69465 Mdot
.5015 .70036 Mdot
.42213 .25324 Mdot
.31588 .48632 Mdot
.69434 .3922 Mdot
.50115 .68268 Mdot
.43953 .26007 Mdot
.29972 .62201 Mdot
.72199 .45335 Mdot
.34133 .49398 Mdot
.36303 .69037 Mdot
.54213 .71596 Mdot
.29274 .59703 Mdot
.4527 .69375 Mdot
.66213 .59731 Mdot
.68118 .61035 Mdot
.35659 .48752 Mdot
.52164 .72856 Mdot
.53456 .6952 Mdot
.67721 .61657 Mdot
.41741 .28892 Mdot
.52355 .32498 Mdot
.46025 .28457 Mdot
.71152 .42864 Mdot
.44767 .28266 Mdot
.69192 .44975 Mdot
.69577 .33337 Mdot
.4778 .69628 Mdot
.43492 .27169 Mdot
.27016 .61085 Mdot
.51705 .32781 Mdot
.39003 .25529 Mdot
.29481 .6091 Mdot
.36917 .68662 Mdot
.69256 .41373 Mdot
.4169 .25853 Mdot
.30299 .47162 Mdot
.64507 .65403 Mdot
.70719 .58964 Mdot
.68766 .59023 Mdot
.54129 .33795 Mdot
.69796 .4056 Mdot
.46233 .70201 Mdot
.36269 .46751 Mdot
.5161 .68479 Mdot
.33541 .4603 Mdot
.35618 .50581 Mdot
.53474 .69294 Mdot
.46141 .70203 Mdot
.34999 .48293 Mdot
.28294 .45966 Mdot
.51868 .32405 Mdot
.6606 .59552 Mdot
.58406 .72307 Mdot
.57623 .72154 Mdot
.67243 .4211 Mdot
.49697 .69138 Mdot
.47573 .33575 Mdot
.68855 .5924 Mdot
.56353 .32378 Mdot
.6744 .60674 Mdot
.44986 .24083 Mdot
.70804 .45623 Mdot
.61495 .67376 Mdot
.6089 .70619 Mdot
.37909 .66586 Mdot
.48179 .69661 Mdot
.42406 .27511 Mdot
.49455 .68878 Mdot
.47915 .69083 Mdot
.37755 .50288 Mdot
.54393 .31866 Mdot
.52046 .34197 Mdot
.28337 .60045 Mdot
.58346 .70647 Mdot
.34292 .48277 Mdot
.29861 .61294 Mdot
.36862 .49364 Mdot
.29105 .59743 Mdot
.59944 .70041 Mdot
.41321 .46851 Mdot
.48822 .69302 Mdot
.53039 .70721 Mdot
.45168 .32755 Mdot
.51616 .33117 Mdot
.53291 .35021 Mdot
.73256 .5875 Mdot
.33642 .46341 Mdot
.69903 .33754 Mdot
.362 .66921 Mdot
.5261 .31456 Mdot
.2894 .63287 Mdot
.40518 .25761 Mdot
.29836 .45116 Mdot
.5399 .32139 Mdot
.68075 .42221 Mdot
.37793 .66538 Mdot
.31114 .45798 Mdot
.54928 .3354 Mdot
.47694 .69983 Mdot
.56503 .70768 Mdot
.50024 .7047 Mdot
.41559 .2732 Mdot
.6803 .60347 Mdot
.36472 .67007 Mdot
.70957 .4324 Mdot
.69939 .34046 Mdot
.46503 .69681 Mdot
.66151 .4204 Mdot
.6498 .61343 Mdot
.31716 .45843 Mdot
.6699 .59458 Mdot
.40373 .26151 Mdot
.58632 .71961 Mdot
.37171 .66583 Mdot
.35322 .64808 Mdot
.48915 .68287 Mdot
.51695 .32073 Mdot
.46258 .292 Mdot
.65829 .41784 Mdot
.55105 .71369 Mdot
.68166 .60342 Mdot
.66896 .42159 Mdot
.3718 .66075 Mdot
.38467 .26819 Mdot
.33024 .46894 Mdot
.36479 .51127 Mdot
.44032 .6693 Mdot
.38737 .50473 Mdot
.70155 .3421 Mdot
.44448 .69641 Mdot
.38235 .68029 Mdot
.29581 .57708 Mdot
.39478 .22531 Mdot
.46645 .27866 Mdot
.33005 .482 Mdot
.28541 .6295 Mdot
.38733 .49134 Mdot
.62168 .6828 Mdot
.29418 .5934 Mdot
.68224 .45583 Mdot
.44597 .31383 Mdot
.70017 .59492 Mdot
.53452 .32115 Mdot
.65949 .42853 Mdot
.28207 .45795 Mdot
.3343 .47061 Mdot
.53809 .72895 Mdot
.36754 .68496 Mdot
.65682 .62091 Mdot
.40862 .47437 Mdot
.67824 .41699 Mdot
.69833 .30241 Mdot
.37371 .51735 Mdot
.49129 .70301 Mdot
.65398 .64086 Mdot
.53737 .31692 Mdot
.53735 .35127 Mdot
.43508 .25887 Mdot
.67036 .4478 Mdot
.49659 .33392 Mdot
.66946 .61321 Mdot
.30199 .47275 Mdot
.27408 .58543 Mdot
.6487 .66145 Mdot
.48847 .67973 Mdot
.72732 .58249 Mdot
.44299 .23634 Mdot
.35338 .4991 Mdot
.59008 .70361 Mdot
.47609 .68375 Mdot
.42284 .25191 Mdot
.69355 .34649 Mdot
.69048 .32193 Mdot
.36127 .23847 Mdot
.50019 .31029 Mdot
.71548 .44625 Mdot
.49763 .33275 Mdot
.36025 .66501 Mdot
.29122 .606 Mdot
.70996 .59085 Mdot
.36779 .50191 Mdot
.51444 .71321 Mdot
.45518 .68773 Mdot
.32075 .48072 Mdot
.44906 .29225 Mdot
.43323 .71017 Mdot
.36162 .65147 Mdot
.30515 .48514 Mdot
.70009 .40335 Mdot
.36039 .50236 Mdot
.47682 .33738 Mdot
.56497 .32953 Mdot
.38444 .50177 Mdot
.68056 .4313 Mdot
.4943 .31552 Mdot
.45013 .29417 Mdot
.45234 .68587 Mdot
.53503 .32277 Mdot
.36278 .68365 Mdot
.29658 .45824 Mdot
.41998 .2904 Mdot
.36359 .66119 Mdot
.53352 .68613 Mdot
.54629 .3531 Mdot
.6756 .39815 Mdot
.55205 .70575 Mdot
.35964 .497 Mdot
.5223 .32342 Mdot
.32166 .49219 Mdot
.57091 .68412 Mdot
.3582 .51032 Mdot
.6301 .66051 Mdot
.54144 .71934 Mdot
.66353 .61052 Mdot
.37764 .6696 Mdot
.34246 .49617 Mdot
.49704 .32996 Mdot
.53441 .34227 Mdot
.31652 .44927 Mdot
.4637 .69582 Mdot
.47602 .68738 Mdot
.4853 .70731 Mdot
.67184 .41464 Mdot
.30583 .43548 Mdot
.66218 .60628 Mdot
.54818 .32494 Mdot
.67065 .62412 Mdot
.28663 .62721 Mdot
.41732 .27662 Mdot
.63942 .66218 Mdot
.32435 .45842 Mdot
.56243 .72604 Mdot
.24452 .4781 Mdot
.59127 .73098 Mdot
.74216 .58145 Mdot
.73018 .5812 Mdot
.58069 .71177 Mdot
.3269 .47965 Mdot
.28375 .59551 Mdot
.27572 .58082 Mdot
.67146 .62149 Mdot
.52778 .30842 Mdot
.56116 .36575 Mdot
.70632 .40379 Mdot
.38447 .26597 Mdot
.73357 .55753 Mdot
.71892 .55333 Mdot
.38375 .67336 Mdot
.56017 .70462 Mdot
.6731 .61541 Mdot
.67575 .58681 Mdot
.68279 .40972 Mdot
.38104 .66971 Mdot
.33728 .49426 Mdot
.51037 .32509 Mdot
.71411 .57664 Mdot
.30547 .44581 Mdot
.38064 .68437 Mdot
.68674 .34814 Mdot
.46526 .70767 Mdot
.64513 .66831 Mdot
.29085 .62707 Mdot
.49102 .71251 Mdot
.71109 .38399 Mdot
.59898 .69547 Mdot
.34463 .4849 Mdot
.53226 .33622 Mdot
.66131 .41523 Mdot
.31929 .46303 Mdot
.70586 .3332 Mdot
.65836 .6239 Mdot
.64977 .65424 Mdot
.28206 .61912 Mdot
.73474 .41678 Mdot
.34626 .48216 Mdot
.35278 .65384 Mdot
.44736 .27548 Mdot
.66911 .62118 Mdot
.5304 .71789 Mdot
.31992 .49305 Mdot
.67407 .43078 Mdot
.71175 .40826 Mdot
.45981 .69108 Mdot
.50156 .70349 Mdot
.61955 .67647 Mdot
.5223 .3307 Mdot
.66641 .43169 Mdot
.52136 .32415 Mdot
.30146 .48053 Mdot
.68098 .61261 Mdot
.44949 .29477 Mdot
.66214 .40564 Mdot
.72795 .55844 Mdot
.36878 .6867 Mdot
.59363 .72441 Mdot
.45155 .66776 Mdot
.35959 .65641 Mdot
.66764 .44386 Mdot
.42495 .28537 Mdot
.29778 .59848 Mdot
.37727 .65555 Mdot
.41528 .28292 Mdot
.67574 .4131 Mdot
.57214 .70686 Mdot
.4707 .68308 Mdot
.55352 .72718 Mdot
.27085 .59725 Mdot
.42545 .68452 Mdot
.26888 .45322 Mdot
.38779 .49877 Mdot
.60663 .68885 Mdot
.3595 .47136 Mdot
.6873 .59117 Mdot
.55065 .72052 Mdot
.29184 .59732 Mdot
.3913 .67998 Mdot
.27622 .44842 Mdot
.35948 .48089 Mdot
.36656 .67896 Mdot
.33667 .46346 Mdot
.53503 .69041 Mdot
.44119 .69882 Mdot
.30149 .59931 Mdot
.69443 .59033 Mdot
.42649 .28085 Mdot
.58346 .69294 Mdot
.35758 .50349 Mdot
.53823 .68903 Mdot
.29873 .6057 Mdot
.63014 .65924 Mdot
.36374 .67915 Mdot
.65956 .43712 Mdot
.29504 .46354 Mdot
.70586 .3985 Mdot
.35765 .64778 Mdot
.54083 .68813 Mdot
.71187 .58704 Mdot
.3615 .65089 Mdot
.72707 .45159 Mdot
.40915 .47254 Mdot
.52969 .33777 Mdot
.45105 .2821 Mdot
.49545 .31874 Mdot
.68169 .59249 Mdot
.32873 .46339 Mdot
.3003 .46273 Mdot
.38768 .50843 Mdot
.30176 .48104 Mdot
.51621 .32972 Mdot
.40722 .2844 Mdot
.56362 .68709 Mdot
.30158 .45453 Mdot
.68 .38655 Mdot
.57386 .69905 Mdot
.27999 .45396 Mdot
.27312 .58 Mdot
.35407 .68319 Mdot
.58335 .70777 Mdot
.60278 .71817 Mdot
.50064 .35678 Mdot
.43877 .27738 Mdot
.36501 .49268 Mdot
.43432 .29907 Mdot
.36559 .66804 Mdot
.67794 .60005 Mdot
.39175 .50645 Mdot
.70671 .45618 Mdot
.29269 .58568 Mdot
.67488 .4121 Mdot
.36153 .48598 Mdot
.59284 .71936 Mdot
.67886 .61251 Mdot
.69346 .31588 Mdot
.68943 .31428 Mdot
.2647 .44885 Mdot
.70389 .30432 Mdot
.41489 .26789 Mdot
.42068 .27047 Mdot
.67547 .61476 Mdot
.32164 .47761 Mdot
.29656 .59012 Mdot
.35177 .63857 Mdot
.33704 .46539 Mdot
.32584 .47106 Mdot
.72329 .56011 Mdot
.73157 .56183 Mdot
.66363 .40337 Mdot
.34616 .47973 Mdot
.30063 .44628 Mdot
.58808 .71336 Mdot
.46504 .28457 Mdot
.6688 .43984 Mdot
.44238 .26169 Mdot
.69274 .4411 Mdot
.22451 .47081 Mdot
.54482 .31585 Mdot
.4178 .272 Mdot
.73955 .55358 Mdot
.56609 .72502 Mdot
.51313 .32675 Mdot
.69805 .41985 Mdot
.66327 .42581 Mdot
.2827 .45336 Mdot
.48311 .67805 Mdot
.59283 .6962 Mdot
.41382 .27465 Mdot
.64333 .61422 Mdot
.36332 .65691 Mdot
.54577 .35039 Mdot
.4253 .22864 Mdot
.66898 .42967 Mdot
.62071 .69278 Mdot
.44789 .67041 Mdot
.34716 .50429 Mdot
.56577 .70813 Mdot
.34128 .50016 Mdot
.47188 .70602 Mdot
.55834 .69573 Mdot
.37807 .5156 Mdot
.491 .70912 Mdot
.71385 .45059 Mdot
.69101 .29772 Mdot
.38634 .68067 Mdot
.75471 .55398 Mdot
.36195 .66787 Mdot
.68194 .34208 Mdot
.24558 .47651 Mdot
.30388 .46044 Mdot
.35768 .50448 Mdot
.38752 .28694 Mdot
.37336 .47706 Mdot
.54474 .34703 Mdot
.52848 .33742 Mdot
.57083 .70471 Mdot
.49625 .32181 Mdot
.28567 .59763 Mdot
.43368 .26767 Mdot
.70725 .42973 Mdot
.25405 .45807 Mdot
.41771 .28081 Mdot
.4621 .68442 Mdot
.37746 .65821 Mdot
.59962 .68946 Mdot
.68792 .38521 Mdot
.54556 .33052 Mdot
.65824 .6229 Mdot
.31071 .60971 Mdot
.67609 .42424 Mdot
.72144 .57055 Mdot
.28303 .61113 Mdot
.65934 .43949 Mdot
.69287 .59035 Mdot
.6897 .29573 Mdot
.72375 .57572 Mdot
.64291 .62389 Mdot
.27702 .58939 Mdot
.4342 .26734 Mdot
.49291 .31935 Mdot
.42559 .2971 Mdot
.71503 .58444 Mdot
.67979 .34067 Mdot
.69362 .40558 Mdot
.29948 .58197 Mdot
.42636 .68442 Mdot
.51495 .31609 Mdot
.33544 .47463 Mdot
.73142 .56858 Mdot
.27735 .43467 Mdot
.49342 .31927 Mdot
.65303 .6141 Mdot
.35644 .64802 Mdot
.21933 .5211 Mdot
.52816 .33088 Mdot
.51368 .33725 Mdot
.42279 .25932 Mdot
.68933 .33204 Mdot
.6022 .69877 Mdot
.40624 .25561 Mdot
.39731 .498 Mdot
.37195 .50008 Mdot
.68094 .59494 Mdot
.53647 .32362 Mdot
.65831 .60518 Mdot
.45655 .28972 Mdot
.40408 .28054 Mdot
.45465 .68535 Mdot
.48762 .70596 Mdot
.51223 .34817 Mdot
.37291 .4694 Mdot
.38119 .4854 Mdot
.53314 .72503 Mdot
.6013 .70971 Mdot
.40048 .48275 Mdot
.45976 .29676 Mdot
.42418 .25776 Mdot
.35438 .65141 Mdot
.30173 .60932 Mdot
.37276 .67969 Mdot
.29198 .62163 Mdot
.65928 .45872 Mdot
.37642 .66713 Mdot
.65898 .42152 Mdot
.29388 .62216 Mdot
.7464 .54556 Mdot
.35225 .66237 Mdot
.34446 .50551 Mdot
.69336 .4348 Mdot
.37984 .496 Mdot
.71095 .42064 Mdot
.35347 .48943 Mdot
.67898 .45752 Mdot
.70933 .43249 Mdot
.59282 .35289 Mdot
.25397 .53675 Mdot
.5417 .34761 Mdot
.44025 .29667 Mdot
.46896 .30929 Mdot
.2707 .46343 Mdot
.57297 .70961 Mdot
.41727 .68955 Mdot
.34835 .5054 Mdot
.68451 .40759 Mdot
.65416 .62498 Mdot
.3461 .65269 Mdot
.35714 .51392 Mdot
.35722 .66207 Mdot
.59449 .7241 Mdot
.70251 .40698 Mdot
.45255 .27838 Mdot
.69548 .35717 Mdot
.68251 .33223 Mdot
.71268 .45549 Mdot
.31833 .50607 Mdot
.35077 .67733 Mdot
.47753 .33761 Mdot
.45891 .70917 Mdot
.47774 .2738 Mdot
.48268 .68584 Mdot
.53106 .32078 Mdot
.43628 .2616 Mdot
.23052 .52723 Mdot
.58046 .69713 Mdot
.69662 .44572 Mdot
.34259 .49407 Mdot
.5526 .32631 Mdot
.42337 .29617 Mdot
.54353 .70651 Mdot
.42094 .29122 Mdot
.6987 .42587 Mdot
.52756 .32591 Mdot
.30008 .43414 Mdot
.41637 .46096 Mdot
.30336 .58212 Mdot
.34584 .49794 Mdot
.4123 .27584 Mdot
.48543 .67822 Mdot
.35708 .66089 Mdot
.71847 .57651 Mdot
.29036 .59337 Mdot
.33458 .47309 Mdot
.73319 .41059 Mdot
.59224 .72353 Mdot
.42971 .27655 Mdot
.7309 .56979 Mdot
.44047 .27876 Mdot
.53746 .35044 Mdot
.47649 .70486 Mdot
.53932 .35118 Mdot
.36996 .68456 Mdot
.6682 .61837 Mdot
.59054 .69628 Mdot
.68701 .35354 Mdot
.50394 .3091 Mdot
.71086 .4439 Mdot
.22956 .52912 Mdot
.46413 .69195 Mdot
.7093 .57416 Mdot
.69634 .35607 Mdot
.63471 .61761 Mdot
.30616 .59719 Mdot
.65093 .603 Mdot
.35009 .50578 Mdot
.54905 .72611 Mdot
.65379 .63265 Mdot
.68881 .31674 Mdot
.2821 .62725 Mdot
.55688 .34711 Mdot
.31552 .47939 Mdot
.633 .69248 Mdot
.70372 .57066 Mdot
.49053 .69551 Mdot
.73407 .55617 Mdot
.34855 .47623 Mdot
.51878 .32677 Mdot
.37539 .50623 Mdot
.72266 .58203 Mdot
.72685 .5566 Mdot
.70005 .32427 Mdot
.34499 .49217 Mdot
.44015 .28331 Mdot
.65948 .43156 Mdot
.71432 .41367 Mdot
.66562 .40606 Mdot
.51504 .7052 Mdot
.52852 .31106 Mdot
.52282 .3323 Mdot
.24598 .47287 Mdot
.65706 .60317 Mdot
.54273 .34712 Mdot
.29834 .45687 Mdot
.27403 .45942 Mdot
.54945 .72479 Mdot
.69363 .42733 Mdot
.35414 .48199 Mdot
.38851 .67902 Mdot
.54574 .339 Mdot
.68502 .4331 Mdot
.47432 .70002 Mdot
.69655 .36819 Mdot
.31986 .46048 Mdot
.38133 .67772 Mdot
.48393 .68082 Mdot
.53853 .68367 Mdot
.3742 .47548 Mdot
.33918 .49911 Mdot
.66965 .59286 Mdot
.51161 .65652 Mdot
.3147 .55773 Mdot
.43588 .52728 Mdot
.51236 .31344 Mdot
.59835 .56077 Mdot
.46064 .63595 Mdot
.35912 .64014 Mdot
.50138 .58762 Mdot
.32238 .63619 Mdot
.55003 .61759 Mdot
.6314 .42745 Mdot
.46974 .56692 Mdot
.67644 .30204 Mdot
.6832 .51589 Mdot
.33774 .66735 Mdot
.36036 .29542 Mdot
.67174 .57225 Mdot
.51334 .6278 Mdot
.69051 .5202 Mdot
.60098 .44777 Mdot
.68217 .36042 Mdot
.65995 .38782 Mdot
.61886 .39995 Mdot
.2987 .47266 Mdot
.54394 .64474 Mdot
.33801 .59607 Mdot
.62855 .59625 Mdot
.68066 .48531 Mdot
.39067 .6695 Mdot
.41299 .33484 Mdot
.61664 .56873 Mdot
.45197 .38029 Mdot
.38498 .63563 Mdot
.62494 .45372 Mdot
.33543 .58964 Mdot
.41562 .39016 Mdot
.38267 .64541 Mdot
.55549 .58776 Mdot
.59822 .59428 Mdot
.4045 .62672 Mdot
.62905 .55436 Mdot
.67939 .4437 Mdot
.48869 .67785 Mdot
.69446 .53842 Mdot
.45474 .36106 Mdot
.65361 .54853 Mdot
.50045 .58852 Mdot
.5058 .34085 Mdot
.60022 .5535 Mdot
.2948 .43574 Mdot
.60267 .72597 Mdot
.64951 .48745 Mdot
.66592 .47529 Mdot
.41857 .6359 Mdot
.68653 .49613 Mdot
.23529 .52284 Mdot
.51822 .6304 Mdot
.46822 .63936 Mdot
.60402 .444 Mdot
.59803 .36884 Mdot
.6017 .71456 Mdot
.37616 .33706 Mdot
.56014 .43374 Mdot
.39338 .53356 Mdot
.661 .50498 Mdot
.41323 .65577 Mdot
.48896 .71599 Mdot
.55311 .73401 Mdot
.66517 .35624 Mdot
.4696 .35194 Mdot
.62762 .39609 Mdot
.57053 .43318 Mdot
.65733 .54048 Mdot
.28439 .53617 Mdot
.58378 .61538 Mdot
.62821 .36866 Mdot
.50698 .66736 Mdot
.37986 .30327 Mdot
.55398 .51617 Mdot
.43305 .32436 Mdot
.43928 .6404 Mdot
.60984 .45593 Mdot
.43299 .59075 Mdot
.61807 .5304 Mdot
.22882 .48643 Mdot
.44239 .33704 Mdot
.54661 .64378 Mdot
.57904 .38981 Mdot
.66734 .5721 Mdot
.47123 .65255 Mdot
.66688 .48355 Mdot
.56725 .32487 Mdot
.45689 .43708 Mdot
.41362 .31737 Mdot
.51073 .58187 Mdot
.40491 .35838 Mdot
.62507 .45069 Mdot
.7068 .5291 Mdot
.72252 .43104 Mdot
.61074 .63049 Mdot
.467 .37526 Mdot
.52571 .70823 Mdot
.67204 .33375 Mdot
.48891 .60972 Mdot
.60131 .64523 Mdot
.41101 .31885 Mdot
.6637 .36423 Mdot
.60645 .51934 Mdot
.60452 .41779 Mdot
.59698 .5887 Mdot
.57434 .61981 Mdot
.66076 .58327 Mdot
.56304 .35549 Mdot
.56534 .67027 Mdot
.44268 .37487 Mdot
.64777 .38504 Mdot
.36714 .27983 Mdot
.3558 .46208 Mdot
.46487 .39951 Mdot
.43241 .66605 Mdot
.50456 .49489 Mdot
.63928 .59281 Mdot
.42459 .31586 Mdot
.39193 .66817 Mdot
.51904 .66707 Mdot
.61957 .39654 Mdot
.36098 .52571 Mdot
.62591 .65623 Mdot
.69619 .52108 Mdot
.6901 .37802 Mdot
.45366 .64703 Mdot
.47149 .33895 Mdot
.27091 .49364 Mdot
.43221 .47653 Mdot
.6907 .48846 Mdot
.392 .52907 Mdot
.44697 .47579 Mdot
.64271 .30995 Mdot
.60558 .65513 Mdot
.44961 .44499 Mdot
.44065 .6666 Mdot
.62598 .3661 Mdot
.62922 .4167 Mdot
.53106 .65543 Mdot
.42733 .23627 Mdot
.41543 .35905 Mdot
.45952 .48368 Mdot
.60489 .53883 Mdot
.33054 .63958 Mdot
.35017 .58215 Mdot
.62223 .43865 Mdot
.50895 .42071 Mdot
.55526 .3857 Mdot
.69627 .51738 Mdot
.51867 .71264 Mdot
.48833 .39799 Mdot
.40148 .58429 Mdot
.51425 .67804 Mdot
.497 .44127 Mdot
.62298 .6394 Mdot
.48219 .42878 Mdot
.41113 .3292 Mdot
.66806 .38025 Mdot
.63209 .37197 Mdot
.66266 .54115 Mdot
.67376 .48315 Mdot
.5781 .64314 Mdot
.5832 .64429 Mdot
.49813 .38355 Mdot
.67935 .5625 Mdot
.61912 .47747 Mdot
.56426 .73525 Mdot
.51917 .61702 Mdot
.38296 .61886 Mdot
.30627 .54208 Mdot
.42893 .56224 Mdot
.46323 .29829 Mdot
.4201 .40701 Mdot
.45448 .64894 Mdot
.43852 .2365 Mdot
.32965 .53584 Mdot
.32963 .58291 Mdot
.55859 .35025 Mdot
.28216 .5139 Mdot
.22878 .47392 Mdot
.57646 .53238 Mdot
.64435 .36869 Mdot
.45523 .50651 Mdot
.28632 .51086 Mdot
.63559 .59212 Mdot
.36808 .63849 Mdot
.42442 .31717 Mdot
.52009 .37023 Mdot
.49865 .64014 Mdot
.54994 .66167 Mdot
.75115 .53583 Mdot
.70127 .57807 Mdot
.653 .30429 Mdot
.6633 .54046 Mdot
.44684 .71567 Mdot
.69937 .34796 Mdot
.60659 .48466 Mdot
.42246 .59744 Mdot
.32865 .60912 Mdot
.43512 .34271 Mdot
.58284 .5485 Mdot
.39129 .25236 Mdot
.44987 .61599 Mdot
.44072 .50444 Mdot
.40676 .34439 Mdot
.3834 .32803 Mdot
.38415 .33865 Mdot
.69165 .54489 Mdot
.41606 .40196 Mdot
.40095 .31289 Mdot
.26456 .43931 Mdot
.56476 .46985 Mdot
.35297 .64179 Mdot
.35775 .56086 Mdot
.66106 .32709 Mdot
.56333 .42378 Mdot
.57285 .61231 Mdot
.41888 .63666 Mdot
.40122 .29927 Mdot
.23347 .46661 Mdot
.63051 .53916 Mdot
.44197 .38306 Mdot
.58556 .39527 Mdot
.46064 .39194 Mdot
.51815 .38556 Mdot
.53165 .58351 Mdot
.6951 .52175 Mdot
.37575 .23086 Mdot
.6154 .36072 Mdot
.6331 .57687 Mdot
.48052 .66092 Mdot
.66625 .32909 Mdot
.59163 .65829 Mdot
.60302 .61602 Mdot
.43882 .63027 Mdot
.36827 .58379 Mdot
.46411 .53582 Mdot
.56202 .58929 Mdot
.42962 .4302 Mdot
.54669 .40818 Mdot
.66937 .38129 Mdot
.6271 .33509 Mdot
.46126 .52412 Mdot
.55858 .46523 Mdot
.28936 .50066 Mdot
.67333 .35975 Mdot
.55087 .5563 Mdot
.30897 .553 Mdot
.45541 .50272 Mdot
.51636 .63772 Mdot
.61903 .65618 Mdot
.38708 .58478 Mdot
.34754 .46263 Mdot
.45305 .35547 Mdot
.66664 .29496 Mdot
.51235 .38169 Mdot
.54415 .65149 Mdot
.7176 .51652 Mdot
.66958 .52625 Mdot
.31059 .51715 Mdot
.31393 .57407 Mdot
.51676 .55227 Mdot
.31972 .62061 Mdot
.63615 .62868 Mdot
.49262 .71584 Mdot
.56775 .64361 Mdot
.28799 .47046 Mdot
.43769 .57145 Mdot
.55542 .63387 Mdot
.3508 .53576 Mdot
.44286 .66283 Mdot
.57757 .68153 Mdot
.62338 .36059 Mdot
.6661 .38371 Mdot
.41928 .23858 Mdot
.55376 .4432 Mdot
.44575 .26129 Mdot
.57755 .36635 Mdot
.60156 .53044 Mdot
.38863 .63435 Mdot
.72468 .51423 Mdot
.53204 .39341 Mdot
.67922 .3099 Mdot
.52213 .38514 Mdot
.63009 .40739 Mdot
.66045 .50939 Mdot
.26183 .5091 Mdot
.6206 .58043 Mdot
.69218 .51052 Mdot
.24162 .50132 Mdot
.64125 .40747 Mdot
.61455 .54414 Mdot
.60386 .7264 Mdot
.32945 .44922 Mdot
.24267 .4806 Mdot
.409 .39046 Mdot
.26867 .52119 Mdot
.42205 .53411 Mdot
.43413 .68418 Mdot
.40515 .39484 Mdot
.63578 .54028 Mdot
.36058 .64471 Mdot
.54537 .66341 Mdot
.62724 .63598 Mdot
.4702 .66057 Mdot
.67818 .34242 Mdot
.73005 .52816 Mdot
.56205 .63065 Mdot
.31902 .5277 Mdot
.42408 .37474 Mdot
.3191 .519 Mdot
.55968 .66353 Mdot
.38246 .57005 Mdot
.61864 .65024 Mdot
.42565 .63678 Mdot
.56942 .50079 Mdot
.61073 .63854 Mdot
.46229 .61123 Mdot
.45023 .65911 Mdot
.36643 .69595 Mdot
.48763 .36623 Mdot
.42062 .43385 Mdot
.54743 .595 Mdot
.39352 .49346 Mdot
.49187 .49702 Mdot
.49768 .61116 Mdot
.28765 .48329 Mdot
.52978 .60516 Mdot
.37582 .34523 Mdot
.53408 .72961 Mdot
.58401 .58592 Mdot
.5201 .41588 Mdot
.29921 .48347 Mdot
.38363 .63408 Mdot
.47478 .65162 Mdot
.69502 .51844 Mdot
.41663 .42163 Mdot
.47379 .35116 Mdot
.54599 .5002 Mdot
.2859 .5062 Mdot
.46717 .46406 Mdot
.41811 .41837 Mdot
.5675 .35186 Mdot
.51021 .38535 Mdot
.60203 .56038 Mdot
.35611 .29449 Mdot
.64628 .43385 Mdot
.42594 .5567 Mdot
.43195 .59428 Mdot
.62843 .35661 Mdot
.45681 .59585 Mdot
.47353 .58162 Mdot
.46742 .4994 Mdot
.65284 .3439 Mdot
.57922 .56599 Mdot
.62272 .54777 Mdot
.57765 .68036 Mdot
.39814 .32395 Mdot
.56308 .61301 Mdot
.60165 .62267 Mdot
.53636 .41502 Mdot
.35721 .51217 Mdot
.41836 .56533 Mdot
.62427 .67196 Mdot
.50638 .45928 Mdot
.57426 .62963 Mdot
.67644 .29714 Mdot
.589 .54347 Mdot
.45496 .51544 Mdot
.35763 .28839 Mdot
.35453 .27561 Mdot
.39398 .60449 Mdot
.41599 .30511 Mdot
.63668 .53796 Mdot
.56928 .66095 Mdot
.62773 .55978 Mdot
.28734 .54614 Mdot
.52317 .71794 Mdot
.49407 .35972 Mdot
.75462 .53931 Mdot
.63824 .58797 Mdot
.4327 .61427 Mdot
.45888 .3328 Mdot
.55656 .47518 Mdot
.61543 .48918 Mdot
.71139 .51592 Mdot
.67067 .37022 Mdot
.65389 .36254 Mdot
.40193 .5627 Mdot
.64265 .46504 Mdot
.60366 .36706 Mdot
.59623 .65256 Mdot
.67473 .31271 Mdot
.58905 .37713 Mdot
.40812 .67359 Mdot
.62701 .3689 Mdot
.56573 .67745 Mdot
.66311 .4789 Mdot
.49481 .60723 Mdot
.59703 .53637 Mdot
.50788 .43868 Mdot
.57014 .66727 Mdot
.68797 .54052 Mdot
.58167 .49649 Mdot
.22544 .51748 Mdot
.47527 .65653 Mdot
.51542 .67048 Mdot
.34451 .60055 Mdot
.60031 .5146 Mdot
.36773 .32778 Mdot
.73394 .58379 Mdot
.24885 .51993 Mdot
.60281 .72656 Mdot
.25432 .44459 Mdot
.61764 .48057 Mdot
.29928 .62789 Mdot
.4859 .36748 Mdot
.62094 .48143 Mdot
.3755 .32457 Mdot
.69659 .2979 Mdot
.40028 .38208 Mdot
.58421 .60621 Mdot
.57335 .36781 Mdot
.6572 .32728 Mdot
.65269 .31584 Mdot
.37197 .30916 Mdot
.60564 .36036 Mdot
.23542 .49945 Mdot
.58396 .50936 Mdot
.29491 .5459 Mdot
.33801 .52423 Mdot
.62601 .35148 Mdot
.43051 .69614 Mdot
.43192 .38963 Mdot
.47689 .62501 Mdot
.64766 .39302 Mdot
.40925 .39688 Mdot
.25884 .44999 Mdot
.49335 .46404 Mdot
.60928 .43135 Mdot
.7217 .44434 Mdot
.37266 .26265 Mdot
.53581 .65742 Mdot
.49468 .39572 Mdot
.52242 .66573 Mdot
.46938 .66434 Mdot
.63383 .43615 Mdot
.46692 .63152 Mdot
.38261 .22937 Mdot
.64516 .49598 Mdot
.52436 .36601 Mdot
.61681 .53675 Mdot
.62619 .68469 Mdot
.37051 .52528 Mdot
.495 .38023 Mdot
.49842 .39976 Mdot
.36633 .30376 Mdot
.43615 .39671 Mdot
.43898 .41106 Mdot
.37126 .3372 Mdot
.49986 .63396 Mdot
.26566 .52543 Mdot
.40545 .33929 Mdot
.39688 .62313 Mdot
.46942 .35306 Mdot
.65459 .5939 Mdot
.6 .45385 Mdot
.60589 .67492 Mdot
.28416 .52564 Mdot
.28043 .52824 Mdot
.54315 .39329 Mdot
.66363 .57436 Mdot
.44764 .54107 Mdot
.46019 .48663 Mdot
.67089 .48342 Mdot
.28468 .54619 Mdot
.53389 .59272 Mdot
.36549 .27179 Mdot
.34735 .46147 Mdot
.58712 .31548 Mdot
.6368 .37086 Mdot
.61898 .58117 Mdot
.59399 .52337 Mdot
.60062 .67731 Mdot
.41289 .54134 Mdot
.26108 .4798 Mdot
.40199 .32694 Mdot
.59342 .52195 Mdot
.32408 .57992 Mdot
.41126 .50042 Mdot
.59913 .62893 Mdot
.66474 .55754 Mdot
.51015 .59057 Mdot
.58706 .44824 Mdot
.33067 .44491 Mdot
.62529 .39461 Mdot
.67915 .29768 Mdot
.36788 .32535 Mdot
.66915 .55212 Mdot
.27964 .52285 Mdot
.45473 .46012 Mdot
.58217 .41207 Mdot
.36334 .26987 Mdot
.67862 .36422 Mdot
.45414 .64953 Mdot
.64037 .40241 Mdot
.66407 .56808 Mdot
.61159 .48257 Mdot
.25929 .51519 Mdot
.37723 .33954 Mdot
.4206 .60532 Mdot
.56224 .51773 Mdot
.47806 .4544 Mdot
.30998 .62095 Mdot
.54786 .64164 Mdot
.36921 .58651 Mdot
.69052 .56747 Mdot
.36573 .30651 Mdot
.61602 .4151 Mdot
.42472 .44429 Mdot
.36196 .29904 Mdot
.43806 .69047 Mdot
.56967 .64727 Mdot
.70416 .5315 Mdot
.29042 .5132 Mdot
.72474 .44271 Mdot
.308 .44324 Mdot
.22228 .50318 Mdot
.46431 .60675 Mdot
.49312 .40718 Mdot
.39021 .2289 Mdot
.46171 .65777 Mdot
.61511 .39911 Mdot
.45584 .66134 Mdot
.6694 .30411 Mdot
.52935 .57924 Mdot
.45913 .63866 Mdot
.40428 .54234 Mdot
.65691 .51109 Mdot
.50474 .63408 Mdot
.45088 .3811 Mdot
.36518 .55862 Mdot
.44848 .63374 Mdot
.44806 .63881 Mdot
.41304 .59281 Mdot
.61838 .61297 Mdot
.43831 .36995 Mdot
.65354 .37163 Mdot
.42369 .22981 Mdot
.39463 .6239 Mdot
.28981 .53616 Mdot
.60156 .53622 Mdot
.46571 .38919 Mdot
.70727 .32087 Mdot
.37698 .23686 Mdot
.3469 .62238 Mdot
.6204 .65405 Mdot
.52517 .54396 Mdot
.31244 .568 Mdot
.28 .53579 Mdot
.67106 .50726 Mdot
.60384 .52274 Mdot
.44073 .52824 Mdot
.44691 .67772 Mdot
.63986 .64891 Mdot
.45702 .30058 Mdot
.43236 .23406 Mdot
.64678 .55998 Mdot
.37719 .59824 Mdot
.63714 .36096 Mdot
.62216 .69776 Mdot
.4464 .24634 Mdot
.63926 .51738 Mdot
.29019 .46878 Mdot
.34271 .56685 Mdot
.37212 .23541 Mdot
.41141 .37881 Mdot
.44807 .6829 Mdot
.58097 .65279 Mdot
.65124 .48431 Mdot
.52756 .39465 Mdot
.56652 .53777 Mdot
.62232 .35096 Mdot
.46034 .42922 Mdot
.49867 .39012 Mdot
.45544 .62763 Mdot
.50178 .57444 Mdot
.63681 .3888 Mdot
.56192 .37187 Mdot
.65394 .38097 Mdot
.42339 .51457 Mdot
.56634 .43513 Mdot
.65262 .39585 Mdot
.49685 .45441 Mdot
.64613 .52994 Mdot
.36381 .6441 Mdot
.51446 .55709 Mdot
.65192 .34097 Mdot
.4647 .67432 Mdot
.59615 .43141 Mdot
.48988 .64175 Mdot
.63916 .58499 Mdot
.44058 .37572 Mdot
.56672 .65301 Mdot
.64979 .37641 Mdot
.2942 .54174 Mdot
.57155 .40167 Mdot
.37778 .62804 Mdot
.39851 .5252 Mdot
.51134 .34311 Mdot
.43286 .46676 Mdot
.57647 .33417 Mdot
.23975 .4686 Mdot
.3427 .53783 Mdot
.44164 .34203 Mdot
.23302 .47745 Mdot
.5123 .4397 Mdot
.6128 .45805 Mdot
.57445 .73631 Mdot
.42006 .31762 Mdot
.26255 .48555 Mdot
.5724 .6708 Mdot
.6509 .36296 Mdot
.58679 .32523 Mdot
.36076 .2985 Mdot
.66372 .5716 Mdot
.52936 .43698 Mdot
.67934 .30536 Mdot
.55109 .5001 Mdot
.60041 .35698 Mdot
.61658 .53671 Mdot
.47641 .66785 Mdot
.40969 .32405 Mdot
.61833 .4685 Mdot
.50703 .44321 Mdot
.31059 .55728 Mdot
.42722 .63541 Mdot
.24713 .48958 Mdot
.30098 .53112 Mdot
.67986 .44478 Mdot
.3268 .57233 Mdot
.62667 .44745 Mdot
.40046 .60715 Mdot
.63365 .36321 Mdot
.61901 .33989 Mdot
.57135 .42154 Mdot
.69396 .50158 Mdot
.35916 .3042 Mdot
.43894 .40729 Mdot
.34472 .64388 Mdot
.4505 .66108 Mdot
.38834 .23169 Mdot
.60875 .35934 Mdot
.41634 .41967 Mdot
.34163 .58001 Mdot
.45859 .43433 Mdot
.4946 .36341 Mdot
.50295 .48233 Mdot
.73265 .58512 Mdot
.39826 .61746 Mdot
.56824 .67008 Mdot
.49888 .6491 Mdot
.68622 .57255 Mdot
.64983 .33979 Mdot
.5614 .63014 Mdot
.50048 .58378 Mdot
.49692 .4331 Mdot
.62265 .32947 Mdot
.64605 .56908 Mdot
.63236 .6339 Mdot
.39175 .6384 Mdot
.36686 .31958 Mdot
.48947 .66516 Mdot
.49882 .60488 Mdot
.55471 .57704 Mdot
.31465 .50755 Mdot
.66313 .58269 Mdot
.56047 .64804 Mdot
.4366 .65408 Mdot
.39027 .35371 Mdot
.56665 .59515 Mdot
.56687 .36851 Mdot
.64117 .43047 Mdot
.54107 .57701 Mdot
.62246 .34284 Mdot
.55459 .73542 Mdot
.38683 .34332 Mdot
.28959 .50583 Mdot
.58162 .34006 Mdot
.32589 .45007 Mdot
.45543 .6145 Mdot
.51194 .38476 Mdot
.56461 .53684 Mdot
.62691 .64302 Mdot
.47868 .64676 Mdot
.66864 .34533 Mdot
.45714 .26169 Mdot
.72424 .51201 Mdot
.61002 .44218 Mdot
.33152 .58593 Mdot
.32783 .59039 Mdot
.61102 .60545 Mdot
.6055 .541 Mdot
.45865 .58431 Mdot
.58455 .44661 Mdot
.37861 .6131 Mdot
.53014 .37142 Mdot
.37065 .26106 Mdot
.41905 .66572 Mdot
.68067 .31767 Mdot
.40169 .64628 Mdot
.4171 .65164 Mdot
.61163 .40002 Mdot
.58229 .597 Mdot
.52336 .42637 Mdot
.51634 .4119 Mdot
.56033 .69339 Mdot
.36546 .24857 Mdot
.57387 .63098 Mdot
.58912 .43104 Mdot
.66049 .48743 Mdot
.5066 .61691 Mdot
.73365 .4295 Mdot
.67921 .52564 Mdot
.66968 .3377 Mdot
.62822 .36835 Mdot
.68008 .51685 Mdot
.62827 .54317 Mdot
.60751 .64111 Mdot
.40541 .34584 Mdot
.61399 .45472 Mdot
.45405 .37822 Mdot
.69142 .56007 Mdot
.39746 .57836 Mdot
.22899 .47786 Mdot
.27008 .49224 Mdot
.38006 .54897 Mdot
.43914 .44841 Mdot
.3937 .36304 Mdot
.56613 .33806 Mdot
.42772 .23242 Mdot
.6601 .47974 Mdot
.36223 .26144 Mdot
.50607 .63091 Mdot
.51137 .34577 Mdot
.53844 .41028 Mdot
.56523 .59431 Mdot
.24485 .51829 Mdot
.46371 .49488 Mdot
.57747 .37328 Mdot
.60229 .63043 Mdot
.51387 .65264 Mdot
.48139 .35653 Mdot
.32728 .45193 Mdot
.31713 .63515 Mdot
.63856 .59717 Mdot
.72671 .43703 Mdot
.49079 .64986 Mdot
.3756 .26226 Mdot
.63794 .63468 Mdot
.71401 .50725 Mdot
.61459 .59739 Mdot
.50231 .39559 Mdot
.71751 .53164 Mdot
.62398 .61984 Mdot
.68779 .29271 Mdot
.63466 .65175 Mdot
.4291 .44615 Mdot
.52429 .67518 Mdot
.23887 .46942 Mdot
.43527 .48252 Mdot
.55946 .35612 Mdot
.47351 .36346 Mdot
.27515 .53509 Mdot
.59904 .44392 Mdot
.38708 .3603 Mdot
.63792 .39409 Mdot
.64342 .42745 Mdot
.64251 .59588 Mdot
.43302 .6232 Mdot
.73411 .52549 Mdot
.66226 .49543 Mdot
.36168 .62837 Mdot
.39821 .37887 Mdot
.43395 .43106 Mdot
.56346 .53121 Mdot
.45834 .4775 Mdot
.41731 .34056 Mdot
.63805 .33797 Mdot
.72586 .42142 Mdot
.70642 .39729 Mdot
.28094 .48753 Mdot
.56867 .41633 Mdot
.44983 .55092 Mdot
.40673 .38377 Mdot
.66231 .51189 Mdot
.61779 .46654 Mdot
.63978 .3795 Mdot
.45544 .61472 Mdot
.35405 .46059 Mdot
.3691 .31497 Mdot
.35942 .56538 Mdot
.67792 .35185 Mdot
.69094 .54796 Mdot
.66264 .48181 Mdot
.36453 .265 Mdot
.44906 .58347 Mdot
.35218 .54492 Mdot
.35581 .29816 Mdot
.4376 .32711 Mdot
.60569 .64009 Mdot
.35334 .52153 Mdot
.69176 .29212 Mdot
.68222 .50577 Mdot
.533 .39991 Mdot
.49143 .71638 Mdot
.65392 .4519 Mdot
.31668 .54741 Mdot
.41381 .4151 Mdot
.58965 .44051 Mdot
.44158 .68953 Mdot
.43751 .62882 Mdot
.61831 .43909 Mdot
.64033 .41136 Mdot
.36867 .60912 Mdot
.53492 .73016 Mdot
.42089 .52762 Mdot
.48715 .67678 Mdot
.47942 .36879 Mdot
.3804 .24917 Mdot
.40131 .65431 Mdot
.39575 .34886 Mdot
.30814 .63448 Mdot
.48169 .61578 Mdot
.39434 .64293 Mdot
.2679 .51219 Mdot
.62156 .43899 Mdot
.35971 .26952 Mdot
.38403 .6055 Mdot
.37814 .2517 Mdot
.49571 .35631 Mdot
.45926 .68046 Mdot
.4062 .59061 Mdot
.29383 .531 Mdot
.55421 .61399 Mdot
.58858 .60577 Mdot
.67322 .48546 Mdot
.60203 .35522 Mdot
.63548 .49554 Mdot
.34505 .46578 Mdot
.45137 .48178 Mdot
.4885 .3814 Mdot
.61153 .481 Mdot
.48377 .37855 Mdot
.43166 .50293 Mdot
.31419 .44166 Mdot
.35321 .28853 Mdot
.56751 .66194 Mdot
.31849 .53679 Mdot
.45981 .25261 Mdot
.51037 .345 Mdot
.29316 .63116 Mdot
.6369 .62634 Mdot
.29241 .47821 Mdot
.6572 .46119 Mdot
.47006 .36571 Mdot
.4016 .64396 Mdot
.28764 .53236 Mdot
.70052 .49924 Mdot
.32868 .44519 Mdot
.30618 .55078 Mdot
.64271 .60592 Mdot
.64494 .45972 Mdot
.71382 .38719 Mdot
.63427 .5914 Mdot
.52714 .63272 Mdot
.22344 .51932 Mdot
.54239 .35617 Mdot
.62801 .4395 Mdot
.60964 .60482 Mdot
.64166 .59348 Mdot
.6502 .37758 Mdot
.4391 .41504 Mdot
.67007 .56049 Mdot
.59634 .35495 Mdot
.26435 .52312 Mdot
.45386 .46945 Mdot
.57739 .62021 Mdot
.37769 .57651 Mdot
.42219 .35244 Mdot
.43461 .2484 Mdot
.56427 .34658 Mdot
.38483 .56214 Mdot
.43989 .34545 Mdot
.64106 .6317 Mdot
.66373 .29225 Mdot
.58421 .59231 Mdot
.48634 .6403 Mdot
.38777 .5533 Mdot
.58878 .52805 Mdot
.38697 .65977 Mdot
.35403 .522 Mdot
.40417 .52077 Mdot
.71095 .50886 Mdot
.59738 .52643 Mdot
.51799 .6249 Mdot
.53481 .61545 Mdot
.42718 .39695 Mdot
.38122 .65602 Mdot
.35423 .48046 Mdot
.57142 .34021 Mdot
.22211 .49138 Mdot
.56723 .3535 Mdot
.54335 .42029 Mdot
.7004 .51409 Mdot
.63202 .44465 Mdot
.64592 .43411 Mdot
.45526 .4068 Mdot
.41547 .33483 Mdot
.36132 .64181 Mdot
.40901 .37956 Mdot
.48248 .48532 Mdot
.68393 .54271 Mdot
.35208 .56929 Mdot
.36162 .27678 Mdot
.44411 .48697 Mdot
.45123 .31065 Mdot
.51728 .36785 Mdot
.46769 .38451 Mdot
.67049 .52468 Mdot
.59175 .67995 Mdot
.66117 .47821 Mdot
.3146 .52039 Mdot
.51373 .65655 Mdot
.41428 .23795 Mdot
.53736 .39042 Mdot
.58824 .46928 Mdot
.58124 .61423 Mdot
.36801 .59124 Mdot
.32587 .51504 Mdot
.69476 .45363 Mdot
.38257 .57017 Mdot
.44132 .44654 Mdot
.39292 .36393 Mdot
.34282 .64543 Mdot
.5072 .5318 Mdot
.44379 .47621 Mdot
.36782 .3063 Mdot
.69905 .45594 Mdot
.32292 .57909 Mdot
.3794 .64198 Mdot
.70606 .51739 Mdot
.58744 .3312 Mdot
.36696 .32444 Mdot
.69319 .5097 Mdot
.58421 .44553 Mdot
.63437 .6678 Mdot
.449 .46523 Mdot
.43528 .65911 Mdot
.6344 .57324 Mdot
.53558 .30303 Mdot
.46939 .45554 Mdot
.35437 .25263 Mdot
.51011 .39027 Mdot
.51972 .42776 Mdot
.3728 .63383 Mdot
.63891 .37588 Mdot
.3264 .61551 Mdot
.67544 .56065 Mdot
.48629 .36914 Mdot
.70286 .49561 Mdot
.68511 .29853 Mdot
.54411 .58559 Mdot
.56041 .73633 Mdot
.56482 .41678 Mdot
.5248 .66074 Mdot
.59244 .50746 Mdot
.53268 .72979 Mdot
.54349 .66314 Mdot
.41564 .39013 Mdot
.57244 .56495 Mdot
.59278 .68946 Mdot
.39196 .61175 Mdot
.53021 .55172 Mdot
.59019 .58593 Mdot
.49983 .60445 Mdot
.50769 .58384 Mdot
.6404 .5755 Mdot
.52023 .53605 Mdot
.57325 .66265 Mdot
.63586 .55752 Mdot
.42809 .49072 Mdot
.61588 .428 Mdot
.46542 .40159 Mdot
.70008 .34845 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0?ooooooB_ooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A006ooooo`03o`000?oooooooooo0?ooooooB_ooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0?ooooooB_oo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06
ooooo`?o0000oooooom:ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<oooo
o`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom:ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001_ooool00ol0003oooooooooo`3ooooood[ooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0N?ooool8o`000<Wooooo000Looooo`03o`000?oooooooooo07Oooooo2Ol00006ooooo`;o0000
`Oooool001cooooo00?o0000ooooooooool0Loooool:o`0000Wooooo0ol000000ooooooo0000o`00
002mooooo`007?ooool00ol0003oooooooooo`1booooo`Oo000000?oooooo`000?l000002oooool8
o`000;[ooooo000Looooo`03o`000?oooooooooo07;ooooo0_l000000ooooooo0000o`000002o`00
00[ooooo0ol000000ooooooo0000o`000006o`000;[ooooo000Looooo`03o`000?oooooooooo073o
oooo1?l0000?ooooo`?o00001oooool3o`000;Wooooo000Looooo`03o`000?oooooooooo073ooooo
0ol0000Kooooo`Co0000]oooool001cooooo00?o0000ooooooooool0Koooool3o`000003ooooool0
003o000000?ooooo0_l00007ooooo`;o000000?oooooo`000?l000000oooool2o`0000;ooooo0_l0
00000ooooooo0000o`00002gooooo`007?ooool2o`00073ooooo0_l00002ooooo`;o00000_ooool3
o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000002?l00002ooooo`;o0000^_oo
ool001cooooo00?o0000ooooooooool0K_ooool3o`0000Kooooo0_l00002oooooa3o00001oooool2
o`000;Gooooo000Looooo`03o`000?oooooooooo06kooooo0ol0000:oooooa;o00001Oooool2o`00
0003ooooool0003o00000;;ooooo000Looooo`03o`000?oooooooooo07;ooooo0_l000000ooooooo
0000o`000002oooooaKo00001_ooool2o`000;;ooooo000Looooo`03o`000?oooooooooo06kooooo
0ol000001?oooooo0000o`000?ooool3o`000003ooooool0003o000000Oo000000?oooooo`000?l0
00002_l00002ooooo`;o00000_ooool3o`000;7ooooo000Looooo`03o`000?oooooooooo06kooooo
0ol00002ooooo`Go000000?oooooo`000?l000005Ol000000ooooooo0000o`000002ooooo`Co0000
/?ooool001cooooo00?o0000ooooooooool0LOooool4o`0000Cooooo6Ol00003ooooo`Co0000/?oo
ool001cooooo00?o0000ooooooooool0LOooool4o`0000Cooooo2?l000000ooooooo0000o`00000>
o`0000?ooooo1?l0002`ooooo`007?ooool00ol0003oooooooooo`1_ooooo`;o000000Coooooo`00
0?l0003o00002?oooolEo`0000?ooooo1?l0002`ooooo`007?ooool00ol0003oooooooooo`1_oooo
o`;o000000?oooooo`000?l000000_l00007oooooaGo00000_ooool3o`000003ooooool0003o0000
0:oooooo000Looooo`03o`000?oooooooooo07Cooooo0_l00008oooooaco0000[oooool001cooooo
00?o0000ooooooooool0OooooolKo`0003kooooo0_l0001_ooooo`007?ooool00ol0003ooooooooo
o`1_ooooo`?o00002?ooool2o`0000Cooooo6ol0000mooooo`Co0000KOooool001cooooo00?o0000
ooooooooool0Koooool3o`0000Sooooo0_l000000ooooooo0000o`000003ooooo`So000000Cooooo
o`000?l0003ooooo3Ol0000iooooo`;o00001?ooool5o`0006[ooooo000Looooo`03o`000?oooooo
oooo073ooooo0ol0000:ooooo`;o00001?ooool:o`000003ooooool0003o000000Ko00000_ooool3
o`0003Wooooo0ol00005ooooo`Co0000JOooool001cooooo00?o0000ooooooooool0L?ooool3o`00
017ooooo4_l00002ooooo`?o0000>_ooool2o`000003ooooool0003o000000Ko0000JOooool001co
oooo0_l0001aooooo`Co00002oooool2o`0000Gooooo3ol000000ooooooo0000o`000002o`0003Go
oooo0_l00007ooooo`So0000JOooool001cooooo00?o0000ooooooooool0LOooool4o`0000?ooooo
0_l00005ooooo`;o00002?ooool4o`0000?ooooo2_l00007ooooo`;o00000_ooool2o`0000?ooooo
0_l0000Sooooo`?o00001?ooool4o`0000?ooooo1_l0001Vooooo`007?ooool00ol0003ooooooooo
o`1aooooo`Go00000_ooool2o`0000Wooooo0_l00005ooooo`;o00001?ooool6o`000005ooooool0
003o0000o`000?ooool02?l000000ooooooo0000o`000006o`00023ooooo0_l00002ooooo`;o0000
1?ooool5o`0000;ooooo1_l0001Vooooo`007?ooool00ol0003oooooooooo`1cooooo`Co00003?oo
ool2o`0000[ooooo0_l000000ooooooo0000o`00000?o`000003ooooool0003o000000So00007_oo
ool3o`0000[ooooo0_l000000ooooooo0000o`000006o`0006Gooooo000Looooo`03o`000?oooooo
oooo07Gooooo0_l00008ooooo`;o00003?ooool?o`000003ooooool0003o000001;o00007?ooool2
o`0000Sooooo2?l00002ooooo`?o0000IOooool001cooooo00?o0000ooooooooool0M?ooool2o`00
00Wooooo0_l00005ooooo`;o00001?ooool9o`0000;ooooo7?l00008ooooo`Go00004?ooool2o`00
00Gooooo0_l000000ooooooo0000o`000007o`0006Kooooo000Looooo`03o`000?oooooooooo07?o
oooo0ol0000<ooooo`Ko00000oooool4o`0000Sooooo1?l000000ooooooo0000o`00000Eo`0000So
oooo1Ol0000@ooooo`;o00001oooool;o`0006Gooooo000Looooo`03o`000?oooooooooo07?ooooo
0_l0000=ooooo`Ko00000oooool5o`0000cooooo6Ol00008ooooo`?o00006Oooool<o`0006Cooooo
000Looooo`03o`000?oooooooooo07?ooooo1Ol00006ooooo`;o000000?oooooo`000?l000001_oo
ool2o`000003ooooool0003o000000Co00002ooooolIo`0000Gooooo0_l000000ooooooo0000o`00
0007ooooo`;o00004?ooool<o`0006Cooooo000Looooo`03o`000?oooooooooo07?ooooo1Ol00000
0ooooooo0000o`000003ooooo`Ko00001Oooool3o`0000;ooooo1?l0000;ooooo`?o000000?ooooo
o`000?l000004ol00005ooooo`;o00002_ooool2o`0000Wooooo1Ol00002ooooo`_o0000IOooool0
01cooooo00?o0000ooooooooool0M?ooool2o`0000?ooooo0_l00004ooooo`;o000000?oooooo`00
0?l000001_ooool2o`0000?ooooo0ol00002ooooo`;o00001ooooolIo`0000Gooooo0_l00009oooo
o`;o00002_ooool5o`0000;ooooo3?l0001Tooooo`007?ooool00ol0003oooooooooo`22ooooo`?o
00003?ooool2o`000003ooooool0003o000000Oooooo5Ol000001Ooooooo0000o`000?l0003ooooo
00;o00000_ooool4o`0000Oooooo1?l0000=ooooo`ko0000I?ooool001cooooo00?o0000oooooooo
ool0MOooool3o`000003ooooool0003o000000Oooooo0ol00007ooooo`;o00000oooool2o`000003
ooooool0003o000000Co00001?ooool2o`000003ooooool0003o000000So000000?oooooo`000?l0
00002?l000000ooooooo0000o`000003ooooo`?o00002Oooool2o`000003ooooool0003o000000Wo
oooo3Ol0001Vooooo`007?ooool00ol0003oooooooooo`1eooooo`Ko00001Oooool2o`0000;ooooo
0_l00006ooooo`;o00001oooool6o`0000Gooooo6?l000000ooooooo0000o`000003o`0000Oooooo
0_l00004ooooo`;o00000_ooool3o`0000Cooooo0_l000000ooooooo0000o`000008o`0006Kooooo
000Looooo`03o`000?oooooooooo07Oooooo0_l000000ooooooo0000o`000004ooooo`;o00000_oo
ool2o`0000Cooooo1?l00007ooooo`;o00000_ooool2o`0000Gooooo6?l000000ooooooo0000o`00
0002o`0000Sooooo0ol00007ooooo`?o00001_ooool;o`0006Kooooo000Looooo`03o`000?oooooo
oooo07Kooooo0_l00002ooooo`;o00001?ooool2o`0000Sooooo1?l0000;ooooo`;o00001_oooolE
o`0000?ooooo0ol0000:ooooo`;o00002?ooool2o`0000?ooooo0_l000000ooooooo0000o`000009
o`0006Kooooo000Looooo`;o0000Moooool2o`0000Gooooo0_l000000ooooooo0000o`000009oooo
o`;o00003oooool2o`0000Cooooo5?l000000ooooooo0000o`000002o`0000_ooooo0_l0000=oooo
o`;o00000_ooool:o`0006Kooooo000Looooo`03o`000?oooooooooo07_ooooo1?l00006ooooo`;o
00003_ooool3o`0000Cooooo0ol00004ooooo`?o000000?oooooo`000?l000004?l00004ooooo`;o
00001oooool4o`0000kooooo0_l000000ooooooo0000o`000006o`0006Kooooo000Looooo`03o`00
0?oooooooooo07_ooooo0_l00008ooooo`;o00002?ooool2o`0000Cooooo0ol000000ooooooo0000
o`000002ooooo`Co00000oooool2o`0000;ooooo2?l00002ooooo`Go00001_ooool5o`0000Kooooo
0_l0000:ooooo`;o00000_ooool2o`000003ooooool0003o000000Co0000J?ooool001cooooo00?o
0000ooooooooool0P?ooool2o`000003ooooool0003o000000[ooooo0_l00008ooooo`;o00000_oo
ool5o`0000Kooooo0ol000001Ooooooo0000o`000?l0003ooooo00Go00002Oooool6o`0000Cooooo
0_l0000:ooooo`;o000000?oooooo`000?l000000oooool5o`0006Sooooo000Looooo`03o`000?oo
oooooooo07[ooooo1?l00002ooooo`;o000000?oooooo`000?l000002oooool2o`0000_ooooo0_l0
00000ooooooo0000o`00000;ooooo`;o000000?oooooo`000?l000003oooool5o`000004ooooool0
003o0000ooooo`?o00000oooool3o`0000Cooooo0_l000000ooooooo0000o`000005o`0006Sooooo
000Looooo`03o`000?oooooooooo07[ooooo1?l0000Booooo`;o00000oooool3o`0000?ooooo1?l0
0006ooooo`Co00002_ooool2o`0000?ooooo0_l00007ooooo`;o000000Coooooo`000?l0003ooooo
1_l00003ooooo`?o000000?oooooo`000?l000000oooool3o`000003ooooool0003o000006[ooooo
000Looooo`03o`000?oooooooooo07_ooooo0ol0000Gooooo`[o00001Oooool5o`000004ooooool0
003o0000o`0000Kooooo1ol00004ooooo`Co00001_ooool2o`0000Cooooo0_l00004ooooo`;o0000
0oooool2o`0000;ooooo0ol0001Yooooo`007?ooool00ol0003oooooooooo`1kooooo`;o00003_oo
ool2o`0000_ooooo1?l00008ooooo`?o000000?oooooo`000?l000000ol00006ooooo`Go00001_oo
ool4o`0000Kooooo1Ol000000ooooooo0000o`000002o`0000Cooooo0_l00006ooooo`;o0000JOoo
ool001cooooo00?o0000ooooooooool0Q_ooool2o`0000?ooooo0ol00006ooooo`;o00003oooool2
o`000003ooooool0003o000000Wooooo0_l00003ooooo`;o00004?ooool3o`0000?ooooo0_l00004
ooooo`;o0000LOooool001cooooo00?o0000ooooooooool0Q_ooool2o`0000?ooooo0ol00002oooo
o`;o00000_ooool2o`0000?ooooo0_l0000Mooooo`;o00000_ooool2o`0000kooooo0_l000000ooo
oooo0000o`00000;ooooo`;o0000Joooool001cooooo00?o0000ooooooooool0O_ooool2o`000004
ooooool0003o0000o`0000Oooooo0_l00002ooooo`?o00001oooool6o`0000Cooooo0_l0000Goooo
o`;o00003_ooool2o`000003ooooool0003o000000;o00000_ooool5o`0000;ooooo0_l00005oooo
o`;o0000I?ooool001cooooo00?o0000ooooooooool0O_ooool6o`0000Sooooo0_l000000ooooooo
0000o`000003ooooo`;o00001Oooool5o`0000?ooooo0_l0000Wooooo`;o00000oooool2o`0000;o
oooo1_l00008ooooo`;o0000I?ooool001cooooo00?o0000ooooooooool0O_ooool4o`0000[ooooo
0_l00006ooooo`;o00002?ooool2o`0000;ooooo1_l00009ooooo`;o00007?ooool2o`0000;ooooo
3Ol00003ooooo`?o0000Hoooool001cooooo00?o0000ooooooooool0POooool4o`0000Cooooo0_l0
0009ooooo`;o00002?ooool2o`0000;ooooo0_l000001?oooooo0000o`000?l00003ooooo`;o0000
1?ooool2o`0000Gooooo0_l0000Aooooo`;o00000_ooool2o`000003ooooool0003o000000go0000
0oooool2o`0006?ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o
000000?o410@ooooooooool01?ooool00ol0003oooooooooo`21ooooo`Co00001?ooool2o`0000Oo
oooo1?l00008ooooo`;o00000_ooool2o`0000Gooooo1_l00009ooooo`;o00004Oooool2o`0000;o
oooo0_l000000ooooooo0000o`00000=o`0000Gooooo0_l0001Qooooo`0000KoooooogMgMonHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
083ooooo0ol00004ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Wooooo1?l00007oooo
o`?o00000_ooool2o`0000_ooooo0_l00009ooooo`Go000000?oooooo`000?l000000_ooool3o`00
0003ooooool0003o000000co00001Oooool2o`00067ooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00Wooooo1Ol00006ooooo`03o`000?oooooooooo083ooooo0ol00004ooooo`;o
000000?oooooo`000?l000001oooool2o`0000Kooooo1_l00007ooooo`?o00003oooool2o`0000Oo
oooo1ol00006ooooo`;o000000?oooooo`000?l000003ol00003ooooo`?o0000Goooool00003oooo
ool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?m4A4CogMgMooooool00007ooooo`?o
0000Poooool2o`0000kooooo0_l00006ooooo`;o000000?oooooo`000?l000002Oooool2o`0000_o
oooo0_l0000;ooooo`Co00001Oooool2o`0000Gooooo4Ol00003ooooo`?o0000Goooool00003oooo
ool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?oMgMgoEEEEooooool00007ooooo`03
o`000?oooooooooo08?ooooo0_l0000>ooooo`;o00008Oooool2o`0001Cooooo0_l00005oooooa7o
0000IOooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00omgMgOoc<c<
o`000007ooooo`03o`000?oooooooooo08Gooooo0_l00004ooooo`;o00000oooool2o`0000[ooooo
0_l0000@ooooo`;o00006Oooool2o`0000;ooooo1?l00002oooooa?o00001?ooool2o`0005gooooo
00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l000001oooool00ol0003o
ooooooooo`22ooooo`;o000000?oooooo`000?l000001?ooool2o`0000?ooooo0_l0000:ooooo`;o
00001_ooool2o`0000Gooooo0_l000000ooooooo0000o`000009ooooo`;o00003_ooool2o`000003
ooooool0003o000000?o00000_oooolCo`0000Cooooo0_l0001Mooooo`0000Koooooonk^k_lb<S;o
0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0P_ooool3o`00
00Kooooo0_l0000Gooooo`;o00001?ooool3o`0000cooooo0_l00009ooooo`;o00001_ooool2o`00
0003ooooool0003o000000;ooooo4ol00004ooooo`;o0000GOooool001cooooo00?o0000oooooooo
ool0Poooool3o`0000Gooooo0_l0000Hooooo`;o00000oooool2o`0000Sooooo0ol0000:ooooo`;o
000000?oooooo`000?l000000oooool2o`0000Cooooo0_l000000ooooooo0000o`00000Co`0000?o
oooo0ol0001Looooo`007?ooool00ol0003oooooooooo`23ooooo`?o00007?ooool2o`000003oooo
ool0003o000000Kooooo0_l00005ooooo`Co00002Oooool2o`0000Kooooo0_l00004ooooo`;o0000
00?oooooo`000?l000004ol000001?oooooo0000o`000?ooool2o`0005cooooo000Looooo`03o`00
0?oooooooooo08?ooooo0ol0000Looooo`;o00002Oooool2o`0000Cooooo0_l000000ooooooo0000
o`00000Gooooo`;o000000?oooooo`000?l000004ol000001?oooooo0000o`000?ooool2o`0005co
oooo000Looooo`03o`000?oooooooooo0:Gooooo0ol0000;ooooo`;o00003oooool2o`0000?ooooo
0_l00002ooooo`;o00000oooool:o`0000;ooooo2_l00003ooooo`;o0000G?ooool001cooooo00?o
0000ooooooooool0R?ooool3o`0000Oooooo0_l00005ooooo`;o00002_ooool3o`0001Cooooo0_l0
0006ooooo`;o00000oooool2o`000004ooooool0003o0000o`0000?ooooo5ol00002ooooo`;o0000
G?ooool001cooooo00?o0000ooooooooool0FOooool2o`0000?ooooo0ol0000Tooooo`;o000000Co
ooooo`000?l0003o00001oooool2o`0000Gooooo0_l00003ooooo`;o00004_ooool2o`0000;ooooo
0_l00004ooooo`Co00000_ooool2o`0000Sooooo1Ol000000ooooooo0000o`00000Eo`0000;ooooo
0_l0001Looooo`007?ooool00ol0003oooooooooo`1Eooooo`?o000000Coooooo`000?l0003ooooo
1ol0000Rooooo`;o00002_ooool2o`0000_ooooo0_l00008ooooo`;o00002?ooool6o`0000Kooooo
0_l00002ooooo`;o00001_ooool2o`0000;ooooo0ol000000ooooooo0000o`000003o`000003oooo
ool0003o000001?o0000G?ooool001cooooo00?o0000ooooooooool0DOooool7o`0000Cooooo0_l0
0002ooooo`Ko0000:oooool2o`0000kooooo1?l00003ooooo`;o00002_ooool2o`0000oooooo1ol0
0006oooooaGo000000?oooooo`000?l000000ol0001Looooo`007?ooool00ol0003oooooooooo`1@
ooooo`Go00000oooool@o`0003Kooooo0_l000000ooooooo0000o`000002o`0000_ooooo0_l0000:
ooooo`;o00001?ooool2o`000003ooooool0003o000000?o00001_ooool8o`000003ooooool0003o
000000co000000?oooooo`000?l000000ol0001Looooo`007?ooool00ol0003oooooooooo`1=oooo
o`Go00000_ooool2o`000003ooooool0003o000000_o000000?oooooo`000?l000001?l0000Koooo
o`Co00001?ooool2o`0000kooooo0_l000000ooooooo0000o`00000=ooooo`;o00002?ooool4o`00
0003ooooool0003o000000?o00001_ooool2o`0000Cooooo0_l000000ooooooo0000o`00000Go`00
05gooooo000Looooo`03o`000?oooooooooo04cooooo6_l000000ooooooo0000o`000004o`0001Wo
oooo1?l000000ooooooo0000o`000003o`0002[ooooo0ol00002ooooo`?o00001_ooool4o`0000So
oooo6?l0001Mooooo`007?ooool2o`0004gooooo0_l00002oooooaWo00000_ooool4o`0001cooooo
0ol0000/ooooo`?o00000_ooool2o`0000Kooooo0ol00007ooooo`;o000000?oooooo`000?l00000
1Ol000000ooooooo0000o`00000=o`0005kooooo000Looooo`03o`000?oooooooooo04Wooooo0ol0
0003oooooa[o00000oooool3o`000003ooooool0003o0000017ooooo0_l0000@ooooo`;o000000?o
ooooo`000?l000001?ooool2o`0001oooooo0_l00003ooooo`;o000000?oooooo`000?l000002?oo
ool2o`0000;ooooo1ol000000ooooooo0000o`00000<o`0005kooooo000Looooo`03o`000?oooooo
oooo04Wooooo0ol00002oooooaco00000oooool5o`00017ooooo0ol0000?ooooo`;o000000?ooooo
o`000?l000001?ooool2o`0001oooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o
000000Wooooo0_l00003ooooo`Ko000000?oooooo`000?l000002Ol0001Pooooo`007?ooool00ol0
003oooooooooo`1=ooooo`Go00000_oooolGo`0000;ooooo1ol0000@ooooo`?o00002Oooool2o`00
00oooooo0_l0000Oooooo`?o00002Oooool2o`0000;ooooo0_l00004ooooo`ko0000Hoooool001co
oooo00?o0000ooooooooool0COoooolOo`000003ooooool0003o000000Ko00003_ooool4o`0000Wo
oooo0_l00002ooooo`;o00001_ooool2o`0000?ooooo0_l0000[ooooo`;o00000_ooool2o`0000Ko
oooo2ol0001Tooooo`007?ooool00ol0003oooooooooo`18ooooo`;o00000_oooolSo`000003oooo
ool0003o000000Co00003?ooool4o`0000?ooooo0_l00003ooooo`;o00001?ooool2o`0000Kooooo
0_l0000Dooooo`;o00004Oooool2o`0000Kooooo0_l0001jooooo`007?ooool00ol0003ooooooooo
o`15oooooa7o000000?oooooo`000?l000001?l00004ooooo`Co000000?oooooo`000?l000002?l0
00000ooooooo0000o`000004o`0000_ooooo0ol00004ooooo`;o00000oooool4o`00023ooooo1?l0
0005ooooo`;o00002?ooool2o`0000Kooooo0_l0001jooooo`007?ooool00ol0003oooooooooo`15
ooooo`Co000000?oooooo`000?l000002?l00006ooooo`So000000?oooooo`000?l000004_l0000:
ooooo`Ko00002Oooool2o`0002;ooooo0_l00005ooooo`;o00002?ooool2o`0008;ooooo000Loooo
o`03o`000?oooooooooo04Gooooo1?l000000ooooooo0000o`000006o`0000_ooooo6ol00009oooo
o`Ko00000_ooool2o`000004ooooool0003o0000o`0002;ooooo0_l0000Rooooo`;o0000L_ooool0
01cooooo00?o0000ooooooooool0AOooool:o`0000;ooooo0_l00008ooooo`Co00000ooooolFo`00
00Sooooo1Ol00004ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0001kooooo0_l0000B
ooooo`;o00003?ooool4o`0007;ooooo000Looooo`03o`000?oooooooooo04Cooooo0_l000001Ooo
oooo0000o`000?l0003ooooo00?o00000oooool2o`0000Oooooo0ol000000ooooooo0000o`000002
oooooaSo00001?ooool7o`0000Gooooo0_l00003ooooo`Co00003Oooool2o`00027ooooo1Ol0000;
ooooo`Ko0000L?ooool001cooooo00?o0000ooooooooool0A?ooool2o`000003ooooool0003o0000
00;ooooo0_l00005ooooo`;o00001_ooool2o`000003ooooool0003o000000;o000000?oooooo`00
0?l000006Ol000000ooooooo0000o`000004o`0000Kooooo0_l00003ooooo`;o000000?oooooo`00
0?l000001Oooool2o`0000Gooooo0_l0000Oooooo`Oo00002?ooool2o`000003ooooool0003o0000
00Ko0000K_ooool001cooooo00?o0000ooooooooool0Aoooool2o`0000Cooooo0_l00003ooooo`;o
00001?ooool2o`0000?ooooo1?l000000ooooooo0000o`00000No`0000_ooooo0_l00003ooooo`;o
00001Oooool2o`0002Kooooo0_l000000ooooooo0000o`000009ooooo`?o000000?oooooo`000?l0
00001_l00002ooooo`;o0000J_ooool001cooooo00?o0000ooooooooool0@oooool3o`0000Oooooo
0_l00005ooooo`;o00000_ooool2o`0000Wooooo7ol00005ooooo`;o00001?ooool2o`0000?ooooo
0_l0000`ooooo`;o00002Oooool2o`0000;ooooo0_l00008ooooo`;o0000J_ooool001cooooo00?o
0000ooooooooool0@_ooool4o`0000kooooo0_l0000;ooooob3o00001_ooool2o`0000[ooooo0_l0
000;ooooo`;o0000:Oooool2o`0000Kooooo0_l0000<ooooo`;o0000I_ooool001cooooo00?o0000
ooooooooool0@_ooool3o`0000oooooo0_l0000;ooooo`;o000000?oooooo`000?l000006_l0000C
ooooo`;o00001oooool2o`0000;ooooo0_l0000Gooooo`;o00004?ooool2o`000003ooooool0003o
000000?ooooo0_l00006ooooo`;o00001?ooool2o`0006Kooooo000Looooo`;o0000@oooool3o`00
00Cooooo1?l0000=ooooo`;o00002OoooolOo`00013ooooo0_l00006ooooo`;o00004?ooool3o`00
00Cooooo0_l00002ooooo`;o00004oooool2o`0000_ooooo0_l000000ooooooo0000o`000002o`00
06Oooooo000Looooo`03o`000?oooooooooo04;ooooo1?l00003ooooo`Co00003Oooool2o`0000[o
oooo6?l00002ooooo`Co00001?ooool2o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o
00006?ooool3o`0000Cooooo0_l0000Looooo`;o00002Oooool4o`0006Oooooo000Looooo`03o`00
0?oooooooooo04;ooooo1?l0000Cooooo`?o00001_oooolLo`0000;ooooo0_l00006ooooo`;o0000
00?oooooo`000?l000000oooool2o`0002_ooooo0_l0000Dooooo`;o000000?oooooo`000?l00000
0_ooool2o`0000Sooooo0_l0001Sooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00003?oo
ool2o`0000Kooooo0ol00006ooooo`Co000000?oooooo`000?l000005Ol0000Booooo`;o0000:?oo
ool2o`000003ooooool0003o000001?ooooo0ol000000ooooooo0000o`000002ooooo`;o000000?o
ooooo`000?l000001?ooool3o`0000Cooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`12
ooooo`?o00003?ooool4o`0000?ooooo1Ol00009ooooo`;o000000?oooooo`000?l000004ol0000l
ooooo`;o00005_ooool3o`0000Sooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo1_l0
001Looooo`007?ooool00ol0003oooooooooo`12ooooo`;o00003Oooool4o`0000?ooooo0_l00000
0ooooooo0000o`000004ooooo`;o00000oooool2o`0000?ooooo4_l00009ooooo`;o00002?ooool2
o`0001kooooo0_l0000=ooooo`;o00004_ooool2o`0000Cooooo0ol00004ooooo`;o000000?ooooo
o`000?l000001Ol000000ooooooo0000o`000002o`0005[ooooo000Looooo`03o`000?oooooooooo
04Cooooo1?l00004ooooo`?o00000_ooool2o`0000kooooo1ol00006ooooo`;o000000?oooooo`00
0?l000001_l0000=ooooo`;o00002?ooool2o`0001kooooo0_l000000ooooooo0000o`00000:oooo
o`Co00002Oooool2o`0000_ooooo0ol000001?oooooo0000o`000?l00002ooooo`Go00001_ooool2
o`0005[ooooo000Looooo`03o`000?oooooooooo04Cooooo1?l000001?oooooo0000o`000?ooool3
o`0000?ooooo1?l000000ooooooo0000o`000009ooooo`Co00002Oooool2o`000003ooooool0003o
000000;ooooo0_l00008ooooo`;o0000<Oooool2o`0000Sooooo0_l000001?oooooo0000o`000?l0
0009ooooo`;o00003oooool3o`0000;ooooo0_l0001Uooooo`007?ooool00ol0003oooooooooo`14
ooooo`Co000000?oooooo`000?l000001oooool4o`000003ooooool0003o000000;o00003oooool2
o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0000Oooooo1?l0000@ooooo`;o0000:Ooo
ool5o`0001Cooooo0_l000000ooooooo0000o`000003ooooo`;o00002oooool2o`0005cooooo000L
ooooo`03o`000?oooooooooo04Cooooo1_l00009ooooo`;o00000_ooool4o`0000Wooooo0_l00004
ooooo`;o00001_ooool2o`000003ooooool0003o000000Gooooo1?l00005ooooo`;o00000oooool3
o`0000Gooooo0_l0000Wooooo`;o000000?oooooo`000?l000005_ooool2o`000003ooooool0003o
000000Oooooo0_l00005ooooo`Co0000G?ooool001cooooo00?o0000ooooooooool0A_ooool6o`00
00_ooooo0_l000000ooooooo0000o`000004o`0000Cooooo0_l0000Fooooo`;o00001oooool2o`00
00?ooooo0ol0000Dooooo`;o00004?ooool2o`0000;ooooo0_l00002ooooo`;o00000oooool2o`00
00?ooooo0_l00007ooooo`;o00004Oooool3o`000003ooooool0003o000000;ooooo0_l0001Noooo
o`007?ooool00ol0003oooooooooo`1:ooooo`Go00001oooool3o`000003ooooool0003o000000Co
00003_ooool2o`0000cooooo0_l00007ooooo`;o00006_ooool2o`00013ooooo0_l00002ooooo`;o
00001oooool2o`0000?ooooo0_l00007ooooo`;o00004Oooool2o`0000;ooooo0_l0001Rooooo`00
7?ooool00ol0003oooooooooo`1:ooooo`So00001?ooool6o`0000Sooooo0_l000000ooooooo0000
o`000003ooooo`Co00003?ooool2o`0000Oooooo0_l0000<ooooo`;o00004?ooool2o`0000gooooo
0_l00008ooooo`Go00000_ooool2o`0000Cooooo0_l0000Aooooo`;o00001Oooool4o`0000Oooooo
0_l0001Gooooo`007?ooool00ol0003oooooooooo`1?ooooo`Go00001Oooool5o`0000Kooooo0_l0
00000ooooooo0000o`000003ooooo`;o00005?ooool2o`0000[ooooo0_l00003ooooo`;o00004?oo
ool2o`0000gooooo0_l00008ooooo`Go00000_ooool2o`0000;ooooo1?l00005ooooo`Co00001_oo
ool4o`0000?ooooo1_l00006ooooo`Co0000E_ooool001cooooo00?o0000ooooooooool0D_ooool2
o`000003ooooool0003o000000Gooooo0_l00002ooooo`;o00003Oooool2o`0000oooooo1?l0000:
ooooo`;o00005oooool2o`0001?ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool5
o`0000Gooooo1?l00004ooooo`Go00000oooool3o`0000?ooooo0_l00004ooooo`Go0000E_ooool0
01cooooo00?o0000ooooooooool0EOooool9o`0000;ooooo0_l000000ooooooo0000o`00000:oooo
o`;o00003oooool2o`0002Gooooo0_l0000Cooooo`;o00001_ooool6o`00013ooooo0_l000000ooo
oooo0000o`000003ooooo`;o00000oooool3o`000003ooooool0003o000000Ko0000E_ooool001co
oooo0_l0001Hooooo`Oo00000_ooool2o`000003ooooool0003o000001?ooooo0_l0000Dooooo`;o
0000:_ooool2o`0000[ooooo0_l00009ooooo`;o00002_ooool2o`0000;ooooo0_l00003ooooo`go
0000E_ooool001cooooo00?o0000ooooooooool0FOooool2o`0000Gooooo0ol0000Eooooo`Co0000
4_ooool2o`0001Cooooo0_l00002ooooo`;o00004?ooool2o`0000?ooooo0_l0000@ooooo`;o0000
0oooool2o`0000Wooooo0_l00003ooooo`So000000?oooooo`000?l000000_l0001Fooooo`007?oo
ool00ol0003oooooooooo`1Qooooo`;o00005oooool2o`0000_ooooo0_l0000Jooooo`?o00000_oo
ool2o`0000Gooooo0_l0000>ooooo`;o00002?ooool2o`0000_ooooo0_l0000=ooooo`ko0000E_oo
ool001cooooo00?o0000ooooooooool0G?ooool2o`0000?ooooo1?l0000>ooooo`;o00004_ooool2
o`0001[ooooo0_l0000:ooooo`;o00003oooool2o`0000Kooooo1Ol000000ooooooo0000o`000004
ooooo`;o00001oooool2o`0000Cooooo4?l0001Fooooo`007?ooool00ol0003oooooooooo`1Loooo
o`;o00001Oooool2o`0000_ooooo0_l000000ooooooo0000o`000004ooooo`;o00001?ooool2o`00
00Oooooo0_l0000eooooo`?o00001_ooool2o`000004ooooool0003o0000ooooo`;o00001?ooool7
o`0000;ooooo0_l00003oooooa3o0000Eoooool001cooooo00?o0000ooooooooool0L?ooool3o`00
00Kooooo0_l00004ooooo`;o00000oooool2o`0000;ooooo0_l0000/ooooo`Co00001Oooool2o`00
01Gooooo1Ol00007oooooa3o0000Eoooool001cooooo00?o0000ooooooooool0FOooool3o`0000?o
oooo0_l000000ooooooo0000o`000008ooooo`;o000000?oooooo`000?l000000_l0000Aooooo`;o
00003oooool2o`0001oooooo1?l0000;ooooo`;o00001oooool2o`0000Cooooo0_l00007ooooo`;o
00000oooool?o`0005Sooooo000Looooo`03o`000?oooooooooo05Sooooo1_l000001?oooooo0000
o`000?ooool2o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l000001oooool3o`0000oo
oooo0_l00009ooooo`;o0000;_ooool2o`0000Oooooo0_l00004ooooo`Co00000oooool4o`0000;o
oooo4?l0001Hooooo`007?ooool00ol0003oooooooooo`1Gooooo`Oo000000Coooooo`000?l0003o
oooo0_l00002ooooo`;o00004?ooool3o`0000oooooo0_l0000Cooooo`;o0000:Oooool4o`0000Ko
oooo1?l00003ooooo`;o00001?ooool@o`0005Sooooo000Looooo`03o`000?oooooooooo05Kooooo
2Ol000000ooooooo0000o`000002o`0001?ooooo0_l00004ooooo`;o00008?ooool2o`0000_ooooo
0_l00002ooooo`;o00006?ooool4o`0000Kooooo0_l00005ooooo`;o00000oooool@o`0005Wooooo
000Looooo`03o`000?oooooooooo05Cooooo3ol00002ooooo`?o00000oooool2o`0000[ooooo0_l0
0004ooooo`;o00005oooool2o`0000[ooooo0_l00004ooooo`;o00000_ooool2o`0000;ooooo0_l0
000Cooooo`?o00000_ooool2o`0000oooooo0_l00003ooooo`oo0000F_ooool001cooooo00?o0000
ooooooooool0E?ooool?o`0000;ooooo1?l00002ooooo`;o000000?oooooo`000?l000001?ooool2
o`0000Cooooo0_l00003ooooo`;o00003Oooool2o`000003ooooool0003o000000?ooooo0_l00007
ooooo`Go00001?ooool3o`0001[ooooo0ol00004ooooo`;o00001Oooool3o`0000Kooooo4ol0001J
ooooo`007?ooool00ol0003oooooooooo`1Eooooo`ko00001?ooool3o`0000Cooooo0_l00004oooo
o`;o00001?ooool2o`0000?ooooo0_l0000=ooooo`;o000000?oooooo`000?l000003?ooool4o`00
00Kooooo0_l00002ooooo`;o00000_ooool2o`0000Oooooo1?l0000>ooooo`;o00001Oooool4o`00
0003ooooool0003o000001?o0000G?ooool001cooooo00?o0000ooooooooool0EOooool?o`0000?o
oooo1?l00009ooooo`;o00002_ooool2o`0000Oooooo0_l0000Dooooo`;o000000?oooooo`000?l0
00002Oooool2o`0000;ooooo1?l00005ooooo`Ko00003?ooool2o`0000Kooooo0ol000000ooooooo
0000o`00000?o`000004ooooool0003o0000o`0005cooooo00001_ooooook^k^oc8b<_l0003o<S8b
onk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003ooooooooo
o`1Coooooa7o00000oooool4o`0000Wooooo0_l0000:ooooo`Co00001Oooool2o`0001Cooooo0_l0
00000ooooooo0000o`000006ooooo`;o00001oooool3o`0000Cooooo0_l00002ooooo`?o00002Ooo
ool5o`0000;ooooo5Ol0001Sooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q
1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0DooooolAo`0000Ko
oooo0_l0000Fooooo`;o00001Oooool2o`0000Kooooo0_l0000Gooooo`;o00000_ooool2o`0000Co
oooo0_l00003ooooo`?o00000oooool2o`0000?ooooo0_l00002ooooo`Oo00000_oooolCo`0006Go
oooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo05?ooooo4Ol00006ooooo`;o00002oooool2o`0000co
oooo0_l0000:ooooo`;o00006oooool2o`0000Cooooo0_l00003ooooo`;o00002Oooool2o`0000;o
oooo0_l00002ooooo`?o000000?oooooo`000?l000003Ol000000ooooooo0000o`000002o`0006Go
oooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oiRHV?oooooo
V9RHob4Q8@06ooooo`?o0000Doooool>o`000003ooooool0003o000000Sooooo0_l00009ooooo`;o
00003?ooool2o`0004Sooooo4?l0001Zooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooo
ooooo`09ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`1Coooooa7o
00002?ooool2o`0000_ooooo0_l000000ooooooo0000o`000007ooooo`;o00005oooool3o`0000Oo
oooo0_l0000@ooooo`?o00001Oooool3o`0000Oooooo4_l0001[ooooo`0000?ooooooa0@4?ooool0
0_ooool00ol@413oooooooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0
DooooolAo`0000?ooooo0_l0000;ooooo`;o00000oooool2o`000003ooooool0003o000000;o0000
1Oooool2o`0000cooooo0_l00006ooooo`Ko00001oooool2o`00013ooooo0ol00005ooooo`?o0000
1ooooolBo`0006_ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nH
V9P02?ooool00ol0003oooooooooo`1Dooooo`oo00001?ooool2o`0000_ooooo0_l00006ooooo`Co
00004_ooool3o`0000Kooooo1Ol0000Fooooo`;o00004ooooolBo`0006cooooo00001_ooooook^k^
oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`1D
ooooo`oo00000oooool2o`0000oooooo0_l00003ooooo`;o00002oooool2o`0000Gooooo1?l00005
ooooo`;o00000oooool2o`0000[ooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l0
00001?oooooo0000o`000?l00009ooooo`;o00001?oooolBo`0006cooooo000Looooo`03o`000?oo
oooooooo05Oooooo3?l00003ooooo`;o00003oooool4o`0000?ooooo0_l00009ooooo`;o00000ooo
ool4o`0000Oooooo0_l00006ooooo`;o00000_ooool2o`0000?ooooo0_l00003ooooo`?o000000?o
ooooo`000?l000001?ooool3o`0000Cooooo0_l00003ooooo`;o00000ooooolBo`0006gooooo000L
ooooo`03o`000?oooooooooo05Kooooo3Ol000000ooooooo0000o`00000Cooooo`;o00000oooool2
o`0000kooooo0_l0000Aooooo`;o00000_ooool2o`0000Sooooo0_l00006ooooo`?o00001_ooool2
o`0000Gooooo0_l000001?oooooo0000o`000?ooool>o`0006kooooo000Looooo`03o`000?oooooo
oooo05Kooooo3Ol000000ooooooo0000o`000007ooooo`;o00003Oooool3o`0000[ooooo0_l0000<
ooooo`;o00002oooool2o`00017ooooo0ol00006ooooo`;o00001Oooool2o`0000Cooooo3Ol0001_
ooooo`007?ooool00ol0003oooooooooo`1Fooooo`_o00003?ooool2o`0000Sooooo0_l00003oooo
o`?o000000?oooooo`000?l000001oooool2o`0000Gooooo0_l00005ooooo`;o00002_ooool3o`00
01[ooooo0_l00009ooooo`ko0000L?ooool001cooooo00?o0000ooooooooool0F?ooool7o`0001?o
oooo0_l00003ooooo`;o00001oooool2o`0000Sooooo0ol00003ooooo`;o00003oooool6o`0000co
oooo0_l00002ooooo`;o00001_ooool3o`000003ooooool0003o000000Kooooo3?l0001booooo`00
7?ooool00ol0003oooooooooo`1Iooooo`Go00005?ooool2o`000003ooooool0003o000000;ooooo
1?l0000=ooooo`?o000000?oooooo`000?l000001?ooool2o`0000Wooooo1?l00002ooooo`Co0000
2?ooool4o`0000;ooooo0_l00006ooooo`?o000000?oooooo`000?l000001?ooool>o`0007;ooooo
000Looooo`03o`000?oooooooooo05[ooooo2?l000000ooooooo0000o`000002o`0000kooooo0_l0
0002ooooo`Co00001oooool2o`000003ooooool0003o000000Gooooo0_l00002ooooo`Co00002Ooo
ool3o`0000Gooooo0_l00008ooooo`;o00005Oooool?o`0007;ooooo000Looooo`03o`000?oooooo
oooo05kooooo1?l000000ooooooo0000o`000002o`000004ooooool0003o0000o`0000Cooooo1?l0
00000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000001_ooool2o`000003ooooool0
003o000000;ooooo0_l000001?oooooo0000o`000?ooool5o`0000Cooooo0_l00002ooooo`;o0000
1?ooool2o`0001_ooooo1?l00002ooooo`Ko00001Oooool2o`0007Gooooo000Looooo`03o`000?oo
oooooooo06Cooooo0ol000001?oooooo0000o`000?l00004ooooo`Oo00000_ooool2o`0000;ooooo
0_l0000=ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000004ooooo`?o
000000?oooooo`000?l000001?ooool2o`0000Sooooo0_l00005ooooo`;o000000?oooooo`000?l0
00001oooool4o`0000;ooooo1?l00006ooooo`?o0000MOooool001cooooo00?o0000ooooooooool0
IOooool4o`0000?ooooo0_l000000ooooooo0000o`000003o`0000Cooooo0ol000001?oooooo0000
o`000?ooool2o`0001[ooooo0_l0000@ooooo`?o00001Oooool2o`000003ooooool0003o000000;o
00001?ooool4o`0000Cooooo0ol00005ooooo`?o0000M_ooool001cooooo00?o0000ooooooooool0
Ioooool2o`0000?ooooo0_l000000ooooooo0000o`000004o`0000?ooooo0ol00004ooooo`;o0000
3oooool2o`0000Kooooo0_l00004ooooo`;o00003Oooool3o`0000;ooooo0_l000000ooooooo0000
o`000003ooooo`;o00001?ooool2o`0000Oooooo0_l000001?oooooo0000o`000?ooool4o`0007Ko
oooo000Looooo`;o0000KOooool;o`000004ooooool0003o0000o`0000Wooooo0_l0000:ooooo`;o
00000oooool5o`0000;ooooo1?l00003ooooo`;o00002?ooool2o`0000?ooooo0_l000000ooooooo
0000o`000002ooooo`;o00000oooool2o`0000Gooooo0_l00003ooooo`Co000000Coooooo`000?l0
003o0000Moooool001cooooo00?o0000ooooooooool0JOooool2o`000003ooooool0003o000000go
00001?ooool2o`000003ooooool0003o000000;o00001?ooool2o`0000Wooooo0ol00004ooooo`;o
00001Oooool2o`0000Cooooo0_l00002ooooo`;o00001Oooool2o`0000?ooooo0_l00003ooooo`;o
000000?oooooo`000?l000000_ooool3o`0000;ooooo0_l00002ooooo`?o0000N?ooool001cooooo
00?o0000ooooooooool0JOoooolAo`0000Gooooo0_l000000ooooooo0000o`000006ooooo`;o0000
1_ooool2o`0000?ooooo0_l00009ooooo`?o00001?ooool3o`0000Sooooo0_l00006ooooo`;o0000
0oooool2o`0000;ooooo1Ol00004ooooo`?o0000N?ooool001cooooo00?o0000ooooooooool0Jooo
oolAo`0000kooooo0_l00002ooooo`Ko000000?oooooo`000?l000000ol00008ooooo`?o00000_oo
ool2o`000003ooooool0003o000000?ooooo0_l00004ooooo`;o00001Oooool2o`0000Oooooo0_l0
00001?oooooo0000o`000?l00003ooooo`Co0000Moooool001cooooo00?o0000ooooooooool0Jooo
oolBo`0000gooooo2?l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l0000:ooooo`;o0000
1?ooool4o`000004ooooool0003o0000ooooo`?o00004Oooool2o`000003ooooool0003o000000Co
0000Moooool001cooooo00?o0000ooooooooool0J_oooolDo`0000Kooooo0_l00003oooooa3o0000
0_ooool2o`0000Cooooo0_l00002ooooo`?o00001Oooool2o`0000?ooooo0_l000001?oooooo0000
o`000?l0000Aooooo`Oo0000NOooool001cooooo00?o0000ooooooooool0J_ooool5o`000003oooo
ool0003o000000co00001_ooool2o`0000?ooooo4?l00008ooooo`;o000000?oooooo`000?l00000
0_l0000<ooooo`Co00004Oooool7o`0007Wooooo000Looooo`03o`000?oooooooooo06gooooo4?l0
0004ooooo`;o00002?ooool5o`0000?ooooo0_l0000?ooooo`;o00003_ooool4o`0000cooooo3?l0
001iooooo`007?ooool00ol0003oooooooooo`1/oooooa;o00000oooool7o`0000_ooooo0_l00002
ooooo`;o000000?oooooo`000?l000000_l00009ooooo`;o00002oooool2o`0000Wooooo2_l00002
ooooo`;o0000O?ooool001cooooo00?o0000ooooooooool0K?oooolBo`0000Cooooo1ol00002oooo
o`Co00000_ooool5o`000003ooooool0003o000000Wo000000?oooooo`000?l000000_ooool2o`00
00_ooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000So00000_ooool2o`00
07cooooo000Looooo`03o`000?oooooooooo06_ooooo0_l000000ooooooo0000o`00000>o`0000Wo
oooo0_l00002ooooo`Go000000?oooooo`000?l000003ol000000ooooooo0000o`000006ooooo`;o
00002oooool2o`0000;ooooo0_l00008ooooo`?o00000_ooool2o`0007cooooo000Looooo`03o`00
0?oooooooooo06_ooooo0_l000000ooooooo0000o`00000=o`0000Wooooo1Ol00003oooooaSo0000
0_ooool6o`000003ooooool0003o000000Wo00003?ooool6o`0007gooooo000Looooo`03o`000?oo
oooooooo06kooooo3?l00009ooooo`So000000?oooooo`000?l000006?l00002ooooo`Ko000000?o
ooooo`000?l000001ol000000ooooooo0000o`000002ooooo`Ko00000oooool6o`0007gooooo000L
ooooo`03o`000?oooooooooo073ooooo1?l0000>ooooo`Oo00000_oooolIo`000003ooooool0003o
000000Oo00000oooool4o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000001_l0
0002ooooo`Ko0000OOooool001cooooo00?o0000ooooooooool0L_ooool5o`0000;ooooo0ol00006
ooooo`Oo00000_oooolRo`0000;ooooo0_l000001?oooooo0000o`000?ooool<o`000003ooooool0
003o000000;ooooo1_l0001mooooo`007?ooool00ol0003oooooooooo`1cooooo`Co00000_ooool3
o`0000_ooooo0ol000000ooooooo0000o`00000Fo`000003ooooool0003o000000Ko00000ooooolF
o`000003ooooool0003o000000Co0000OOooool001cooooo0_l00028ooooo`?o000000?oooooo`00
0?l000007_l000001?oooooo0000o`000?oooolFo`000003ooooool0003o000000?o0000O_ooool0
01cooooo00?o0000ooooooooool0Qoooool2o`0000;ooooo7ol00002oooooaWo00000oooool3o`00
07kooooo000Looooo`03o`000?oooooooooo08Oooooo0ol000000ooooooo0000o`00000Eo`0000;o
oooo8_l000000ooooooo0000o`000002o`0007kooooo000Looooo`03o`000?oooooooooo08Sooooo
0ol000000ooooooo0000o`00000Do`0000?ooooo8Ol000001?oooooo0000o`000?l0001oooooo`00
7?ooool00ol0003oooooooooo`29ooooo`;o00000_oooolCo`0000?ooooo8_l00024ooooo`007?oo
ool00ol0003oooooooooo`2=oooooa;o00000_oooolTo`0008Cooooo000Looooo`03o`000?oooooo
oooo08gooooo0_l00003ooooo`;o00001?ooool6o`0000;ooooo1?l00002oooooaco0000Qoooool0
01cooooo00?o0000ooooooooool0SOooool2o`0000[ooooo0_l00004ooooo`Co00000ooooolLo`00
08Oooooo000Looooo`03o`000?oooooooooo09oooooo1_l00004oooooaWo0000Qoooool001cooooo
00?o0000ooooooooool0X_ooool6o`000003ooooool0003o000001Oo0000Qoooool001cooooo00?o
0000ooooooooool0YOooool3o`000003ooooool0003o000001Go0000ROooool001cooooo00?o0000
ooooooooool0ZOooool3o`0000Cooooo0_l000000ooooooo0000o`000009o`0008_ooooo000Loooo
o`03o`000?oooooooooo0:Wooooo0_l00005ooooo`Ko000000Coooooo`000?l0003o0000Soooool0
01cooooo00?o0000ooooooooool0/_ooool2o`0000?ooooo0_l0002@ooooo`007?ooool00ol0003o
ooooooooo`2booooo`;o0000UOooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<
c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom:ooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo
00?o0000ooooooooool0oooooom:ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooood[ooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RH
oc8b<P06ooooo`?o0000oooooom:ooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooooooo
o`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`3ooooood[ooooo
00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go410@okZj^_oooooo^[Zj
oa0@4006ooooo`03o`000?oooooooooo0?ooooooB_ooool00006oooooomgMgOoV9RHoooooonHV9So
MgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0oooooom:oooo
o`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Booooo`Co000000?o410@ooooooooool00oooool00ol0003o
ooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`?o0000oooooom:ooooo`005?ooool0
0ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Co
oooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo
000Booooo`03oeEEEOmVIVKo00000?ooooooE?ooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00:Wooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0Eooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`01Oooool2o`000003oa0@4?oooooooooo09;ooooo002Zooooo`05
o`000?ooooooooooooooool000002Oooool6o`0000Wooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06
ooooo`03o`000?oooooooooo09?ooooo002Zooooo`05o`000?ooooooooooooooool000006?ooool0
1Ol0003ooooooooooooooooo000000?ooooo1Ol0002Dooooo`00Z_ooool01Ol0003ooooooooooooo
oooo000000Wooooo1_l00009ooooo`05oc8b<_nHV9SooooooiRHV?lb<S800oooool01?m4A4CogMgM
ooooool0002Eooooo`00Z_ooool01Ol0003oQhN7oooooonYZJWo000001Sooooo00Goc<c<o`000?l0
003o0000olc<c003ooooo`04omgMgOmEEEGoooooo`0009Gooooo002Yooooo`03oa0@4?l0003oMgMg
00;o000000?oV9RHooooooooool05_ooool01Ol@413o^[Zjoooooonj^[[o410@00Cooooo00?oMgMg
olc<c?l00000UOooool00<Oooooo00Go0000okZj^_oooooo^[Zjo`000004ooooo`03onk^k_m4A4Co
000009Gooooo0037ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01Oooool00omgMgOo0000ooooo`2D
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -20 0 ]
[.5 1.0125 20 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(90) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.53898 .70702 Mdot
.53821 .74217 Mdot
.69633 .42692 Mdot
.34113 .49518 Mdot
.43179 .24611 Mdot
.69425 .4361 Mdot
.66126 .62276 Mdot
.6335 .62436 Mdot
.68805 .40594 Mdot
.31098 .4348 Mdot
.69921 .6189 Mdot
.26634 .58129 Mdot
.64936 .62836 Mdot
.33304 .44309 Mdot
.22566 .48046 Mdot
.32349 .64982 Mdot
.55235 .71997 Mdot
.43217 .25053 Mdot
.34623 .6607 Mdot
.69287 .40323 Mdot
.45602 .30619 Mdot
.341 .47188 Mdot
.53131 .7135 Mdot
.33391 .44191 Mdot
.34447 .65872 Mdot
.47702 .69038 Mdot
.5241 .70619 Mdot
.3383 .6508 Mdot
.27025 .57601 Mdot
.65731 .63596 Mdot
.33277 .63583 Mdot
.25812 .42058 Mdot
.52121 .32675 Mdot
.46571 .70348 Mdot
.73484 .60715 Mdot
.7227 .62152 Mdot
.67375 .43264 Mdot
.69376 .62464 Mdot
.63026 .64097 Mdot
.72734 .61073 Mdot
.72919 .61159 Mdot
.47596 .68865 Mdot
.73694 .6147 Mdot
.71224 .57501 Mdot
.35926 .45174 Mdot
.40804 .6833 Mdot
.72129 .38708 Mdot
.37914 .48252 Mdot
.56363 .71903 Mdot
.71475 .38061 Mdot
.2955 .40852 Mdot
.65399 .60541 Mdot
.55885 .34531 Mdot
.39386 .67132 Mdot
.63991 .63303 Mdot
.34837 .65852 Mdot
.71258 .46043 Mdot
.35033 .45297 Mdot
.27732 .57416 Mdot
.43179 .69562 Mdot
.35309 .47389 Mdot
.46784 .28852 Mdot
.45243 .65883 Mdot
.71981 .46252 Mdot
.69365 .41521 Mdot
.67704 .62986 Mdot
.53856 .74712 Mdot
.69939 .60626 Mdot
.32732 .47907 Mdot
.73129 .37294 Mdot
.3806 .48975 Mdot
.69979 .61911 Mdot
.44709 .68249 Mdot
.32819 .46474 Mdot
.57075 .71904 Mdot
.71313 .6018 Mdot
.42937 .24069 Mdot
.4623 .69095 Mdot
.7119 .38318 Mdot
.39516 .51811 Mdot
.34112 .48012 Mdot
.61203 .69541 Mdot
.29073 .55664 Mdot
.44102 .67064 Mdot
.34886 .42917 Mdot
.59999 .7254 Mdot
.36999 .508 Mdot
.32706 .63923 Mdot
.34345 .65295 Mdot
.2811 .58729 Mdot
.69895 .48917 Mdot
.51743 .72091 Mdot
.33726 .45962 Mdot
.32333 .47359 Mdot
.30854 .40977 Mdot
.3388 .41811 Mdot
.34675 .65325 Mdot
.54403 .35979 Mdot
.71365 .6118 Mdot
.55936 .33252 Mdot
.70502 .60316 Mdot
.56894 .34738 Mdot
.37701 .5166 Mdot
.68926 .45573 Mdot
.48138 .67968 Mdot
.53396 .35228 Mdot
.71668 .60447 Mdot
.33507 .4558 Mdot
.71241 .62411 Mdot
.52186 .71919 Mdot
.34213 .63634 Mdot
.46968 .27185 Mdot
.42224 .2324 Mdot
.49452 .71136 Mdot
.41637 .4964 Mdot
.36141 .48602 Mdot
.34854 .47721 Mdot
.52515 .73949 Mdot
.69422 .40772 Mdot
.73102 .43321 Mdot
.5298 .73016 Mdot
.71637 .61407 Mdot
.55742 .72192 Mdot
.52088 .31644 Mdot
.69282 .41105 Mdot
.54143 .32619 Mdot
.55695 .36285 Mdot
.27399 .42032 Mdot
.32462 .40964 Mdot
.51537 .30834 Mdot
.68701 .45726 Mdot
.53106 .73306 Mdot
.64479 .62424 Mdot
.32122 .47056 Mdot
.44318 .67266 Mdot
.64223 .63485 Mdot
.47222 .25673 Mdot
.48349 .26553 Mdot
.45172 .68084 Mdot
.42057 .48885 Mdot
.69383 .62615 Mdot
.62463 .62839 Mdot
.297 .4151 Mdot
.43235 .67236 Mdot
.43841 .24014 Mdot
.62322 .63211 Mdot
.60951 .36326 Mdot
.34965 .64041 Mdot
.27818 .39843 Mdot
.61143 .6888 Mdot
.29616 .41043 Mdot
.47434 .31845 Mdot
.47039 .28667 Mdot
.63769 .63521 Mdot
.35586 .50659 Mdot
.5529 .73479 Mdot
.44203 .67518 Mdot
.26672 .55097 Mdot
.52707 .34312 Mdot
.36137 .47433 Mdot
.57253 .3409 Mdot
.55371 .36283 Mdot
.33459 .4462 Mdot
.41808 .69027 Mdot
.49253 .69473 Mdot
.37377 .48929 Mdot
.67302 .42658 Mdot
.4313 .25181 Mdot
.71699 .62095 Mdot
.344 .42801 Mdot
.31228 .41158 Mdot
.26034 .56059 Mdot
.62586 .62415 Mdot
.72853 .58985 Mdot
.72794 .35145 Mdot
.68534 .61858 Mdot
.73885 .59693 Mdot
.7037 .4733 Mdot
.26588 .56516 Mdot
.47094 .27708 Mdot
.54313 .34612 Mdot
.37106 .48756 Mdot
.29514 .402 Mdot
.27767 .5881 Mdot
.45643 .30275 Mdot
.4871 .32265 Mdot
.59406 .69548 Mdot
.74854 .59848 Mdot
.35286 .50088 Mdot
.35759 .63506 Mdot
.28868 .40625 Mdot
.64175 .64484 Mdot
.64624 .61963 Mdot
.70418 .40392 Mdot
.69783 .4042 Mdot
.71947 .36244 Mdot
.25436 .55656 Mdot
.25551 .58074 Mdot
.33909 .48505 Mdot
.55478 .33686 Mdot
.44493 .65819 Mdot
.46788 .28624 Mdot
.55464 .72721 Mdot
.61319 .69381 Mdot
.38667 .47572 Mdot
.34688 .66402 Mdot
.6607 .44262 Mdot
.70909 .49363 Mdot
.56317 .35915 Mdot
.4499 .26547 Mdot
.35574 .46115 Mdot
.50851 .70963 Mdot
.29294 .41073 Mdot
.52592 .32222 Mdot
.41776 .23324 Mdot
.53356 .72202 Mdot
.38088 .47526 Mdot
.6508 .6307 Mdot
.69602 .48294 Mdot
.37022 .50795 Mdot
.32914 .45536 Mdot
.46275 .68978 Mdot
.33825 .49807 Mdot
.3606 .65136 Mdot
.34055 .63991 Mdot
.72238 .36393 Mdot
.72101 .59603 Mdot
.67772 .62032 Mdot
.7224 .38696 Mdot
.46272 .68431 Mdot
.46399 .71596 Mdot
.69827 .45386 Mdot
.44718 .29626 Mdot
.69739 .62136 Mdot
.45747 .25116 Mdot
.69283 .45135 Mdot
.43373 .25055 Mdot
.28072 .57569 Mdot
.68515 .46536 Mdot
.47342 .26782 Mdot
.24684 .48951 Mdot
.55081 .35909 Mdot
.4706 .2436 Mdot
.66425 .62094 Mdot
.57098 .73878 Mdot
.3713 .49072 Mdot
.55322 .34641 Mdot
.5386 .32175 Mdot
.26875 .56144 Mdot
.57982 .35913 Mdot
.52679 .33607 Mdot
.26725 .55973 Mdot
.45069 .28007 Mdot
.61967 .66826 Mdot
.33459 .63535 Mdot
.55535 .72236 Mdot
.3399 .49835 Mdot
.72661 .59412 Mdot
.64116 .63547 Mdot
.35498 .4675 Mdot
.60687 .70319 Mdot
.66689 .61854 Mdot
.34192 .4537 Mdot
.63603 .64136 Mdot
.44409 .67177 Mdot
.38724 .47933 Mdot
.43945 .6802 Mdot
.33566 .44478 Mdot
.63489 .64176 Mdot
.71847 .38784 Mdot
.47315 .68744 Mdot
.33764 .46449 Mdot
.33596 .48564 Mdot
.5549 .33915 Mdot
.34331 .63902 Mdot
.63254 .60868 Mdot
.26545 .5796 Mdot
.71536 .47735 Mdot
.27304 .54389 Mdot
.49433 .29246 Mdot
.61419 .36008 Mdot
.43211 .67273 Mdot
.57912 .36046 Mdot
.69745 .44499 Mdot
.30408 .41382 Mdot
.37839 .46093 Mdot
.35564 .44446 Mdot
.52815 .33425 Mdot
.29047 .55268 Mdot
.67415 .61095 Mdot
.35672 .64411 Mdot
.53472 .31109 Mdot
.71178 .4546 Mdot
.56723 .34142 Mdot
.34384 .42246 Mdot
.52528 .71493 Mdot
.33377 .65829 Mdot
.70257 .47851 Mdot
.53885 .71595 Mdot
.37662 .48409 Mdot
.70187 .60399 Mdot
.50572 .29541 Mdot
.67806 .60998 Mdot
.33193 .64771 Mdot
.27233 .54542 Mdot
.72855 .37496 Mdot
.46917 .68284 Mdot
.63386 .6311 Mdot
.44408 .68152 Mdot
.30325 .41749 Mdot
.38678 .50633 Mdot
.42579 .674 Mdot
.48888 .28017 Mdot
.7154 .35391 Mdot
.69733 .61592 Mdot
.54555 .3298 Mdot
.73965 .34968 Mdot
.55856 .71515 Mdot
.68872 .44949 Mdot
.42888 .46212 Mdot
.7039 .48705 Mdot
.33711 .66088 Mdot
.73859 .35774 Mdot
.25777 .56158 Mdot
.35692 .44002 Mdot
.72255 .45255 Mdot
.53553 .35537 Mdot
.32672 .42684 Mdot
.44842 .67319 Mdot
.2529 .4258 Mdot
.3119 .42749 Mdot
.25562 .55572 Mdot
.71111 .45682 Mdot
.42425 .48112 Mdot
.33608 .64117 Mdot
.33455 .65078 Mdot
.55004 .7303 Mdot
.54243 .33376 Mdot
.46861 .2492 Mdot
.4769 .25161 Mdot
.62444 .33951 Mdot
.29505 .57873 Mdot
.412 .49514 Mdot
.45869 .68025 Mdot
.71475 .37392 Mdot
.58027 .72733 Mdot
.52471 .32293 Mdot
.63354 .62367 Mdot
.72544 .58878 Mdot
.37111 .51015 Mdot
.51915 .2948 Mdot
.35571 .66552 Mdot
.56841 .7257 Mdot
.45012 .685 Mdot
.63326 .63006 Mdot
.28372 .53305 Mdot
.31363 .46628 Mdot
.3589 .47914 Mdot
.63244 .62067 Mdot
.5333 .32268 Mdot
.27814 .57009 Mdot
.26316 .40536 Mdot
.73252 .57445 Mdot
.34889 .44114 Mdot
.44456 .69822 Mdot
.36398 .45652 Mdot
.27887 .41902 Mdot
.35517 .45372 Mdot
.45789 .67725 Mdot
.35109 .62081 Mdot
.31738 .39968 Mdot
.66453 .45761 Mdot
.38508 .46866 Mdot
.48526 .27977 Mdot
.33228 .45991 Mdot
.3647 .47731 Mdot
.44524 .23981 Mdot
.49953 .71027 Mdot
.31863 .41365 Mdot
.61702 .66782 Mdot
.34021 .46574 Mdot
.71935 .6207 Mdot
.28342 .55728 Mdot
.26106 .42422 Mdot
.33816 .6435 Mdot
.52836 .71373 Mdot
.62656 .63881 Mdot
.72715 .61636 Mdot
.57677 .34055 Mdot
.64082 .6357 Mdot
.34966 .43398 Mdot
.28502 .55818 Mdot
.49428 .71158 Mdot
.54807 .35786 Mdot
.51746 .72344 Mdot
.49342 .24126 Mdot
.66227 .61726 Mdot
.56499 .34831 Mdot
.26148 .54318 Mdot
.6579 .61082 Mdot
.61915 .66214 Mdot
.34106 .63552 Mdot
.53463 .3227 Mdot
.53606 .7072 Mdot
.73397 .36814 Mdot
.52589 .32772 Mdot
.63793 .63314 Mdot
.36005 .45324 Mdot
.35062 .65011 Mdot
.63265 .63559 Mdot
.44816 .69765 Mdot
.34498 .63408 Mdot
.34117 .46413 Mdot
.47982 .68631 Mdot
.52251 .73421 Mdot
.37335 .49767 Mdot
.35944 .49943 Mdot
.70461 .44076 Mdot
.5285 .33065 Mdot
.53058 .33098 Mdot
.55984 .36516 Mdot
.70565 .48375 Mdot
.72293 .34507 Mdot
.72517 .5997 Mdot
.26105 .42606 Mdot
.70922 .59682 Mdot
.55773 .34918 Mdot
.70348 .43862 Mdot
.36123 .4517 Mdot
.28884 .53535 Mdot
.62516 .64279 Mdot
.72616 .33756 Mdot
.37046 .51366 Mdot
.55858 .7316 Mdot
.64638 .60808 Mdot
.25837 .58088 Mdot
.71901 .37141 Mdot
.4792 .29306 Mdot
.41252 .49832 Mdot
.64282 .6113 Mdot
.47329 .69975 Mdot
.64271 .61165 Mdot
.36539 .47694 Mdot
.33064 .4202 Mdot
.56319 .74086 Mdot
.4857 .28077 Mdot
.26401 .57511 Mdot
.34052 .44832 Mdot
.71334 .37487 Mdot
.57986 .72576 Mdot
.48063 .25493 Mdot
.27578 .57877 Mdot
.56667 .36166 Mdot
.47241 .29452 Mdot
.33565 .47859 Mdot
.26434 .55868 Mdot
.52909 .3112 Mdot
.64589 .63936 Mdot
.48606 .27446 Mdot
.66159 .4487 Mdot
.53938 .71922 Mdot
.72443 .59687 Mdot
.58605 .35507 Mdot
.69923 .61598 Mdot
.28273 .50979 Mdot
.56637 .354 Mdot
.73218 .58533 Mdot
.38448 .22209 Mdot
.53502 .3483 Mdot
.71497 .45311 Mdot
.30958 .41903 Mdot
.26337 .56544 Mdot
.34101 .463 Mdot
.47243 .25326 Mdot
.53202 .73944 Mdot
.74431 .59509 Mdot
.67378 .62463 Mdot
.32878 .44531 Mdot
.43066 .67286 Mdot
.5978 .70414 Mdot
.56256 .33877 Mdot
.46099 .2629 Mdot
.46121 .25461 Mdot
.32436 .44806 Mdot
.29297 .55247 Mdot
.46184 .68022 Mdot
.33731 .46383 Mdot
.32345 .44828 Mdot
.73095 .36061 Mdot
.47721 .68102 Mdot
.68827 .4679 Mdot
.35093 .66316 Mdot
.39833 .50941 Mdot
.70733 .59996 Mdot
.6593 .62899 Mdot
.53808 .33123 Mdot
.67969 .61828 Mdot
.73045 .35024 Mdot
.53031 .33131 Mdot
.33724 .46477 Mdot
.49263 .70955 Mdot
.33706 .46235 Mdot
.33949 .46436 Mdot
.35991 .45873 Mdot
.40977 .49758 Mdot
.68194 .47926 Mdot
.46076 .2679 Mdot
.27862 .57702 Mdot
.70783 .47611 Mdot
.66278 .43203 Mdot
.30786 .4089 Mdot
.334 .46948 Mdot
.34794 .46951 Mdot
.47175 .69394 Mdot
.35451 .64545 Mdot
.6541 .61413 Mdot
.56402 .74064 Mdot
.36771 .50686 Mdot
.72636 .38287 Mdot
.3182 .41431 Mdot
.42713 .67503 Mdot
.73199 .60043 Mdot
.58968 .73645 Mdot
.58495 .34991 Mdot
.54973 .32474 Mdot
.52689 .33412 Mdot
.56182 .36612 Mdot
.72891 .61912 Mdot
.70286 .43674 Mdot
.50206 .29087 Mdot
.39723 .50533 Mdot
.35724 .50166 Mdot
.33411 .42071 Mdot
.73638 .35387 Mdot
.51686 .32134 Mdot
.3116 .42047 Mdot
.31745 .6466 Mdot
.67754 .46193 Mdot
.5461 .3606 Mdot
.5616 .70169 Mdot
.52915 .71725 Mdot
.72151 .37304 Mdot
.69301 .62433 Mdot
.47618 .2684 Mdot
.67617 .32229 Mdot
.52107 .72795 Mdot
.47092 .66546 Mdot
.67671 .44998 Mdot
.28434 .56161 Mdot
.38742 .66395 Mdot
.68747 .4437 Mdot
.35724 .64174 Mdot
.53134 .74385 Mdot
.55254 .36056 Mdot
.28442 .54859 Mdot
.27151 .55881 Mdot
.69339 .39839 Mdot
.33223 .48198 Mdot
.71876 .49142 Mdot
.7132 .45334 Mdot
.53767 .33583 Mdot
.71083 .4568 Mdot
.67516 .61355 Mdot
.69428 .46437 Mdot
.45415 .69798 Mdot
.32075 .45569 Mdot
.39319 .67063 Mdot
.21979 .47472 Mdot
.36111 .48999 Mdot
.66415 .60557 Mdot
.72725 .59624 Mdot
.35453 .48918 Mdot
.43207 .24017 Mdot
.7126 .44702 Mdot
.72228 .35525 Mdot
.35302 .65345 Mdot
.73719 .35836 Mdot
.52605 .71392 Mdot
.71809 .59776 Mdot
.72701 .59585 Mdot
.52622 .32977 Mdot
.43496 .67169 Mdot
.74765 .60401 Mdot
.71769 .61346 Mdot
.50662 .29484 Mdot
.37222 .49465 Mdot
.4958 .69994 Mdot
.27804 .5696 Mdot
.43302 .25451 Mdot
.34107 .46789 Mdot
.69081 .46925 Mdot
.72361 .35806 Mdot
.22336 .47665 Mdot
.70006 .45286 Mdot
.54093 .3303 Mdot
.48762 .6911 Mdot
.35022 .65919 Mdot
.52826 .73388 Mdot
.32782 .48379 Mdot
.72252 .59519 Mdot
.52994 .71581 Mdot
.44992 .29913 Mdot
.35131 .46541 Mdot
.41079 .68383 Mdot
.27818 .58148 Mdot
.34194 .46584 Mdot
.69802 .41432 Mdot
.44279 .23963 Mdot
.47265 .30003 Mdot
.66926 .46055 Mdot
.44829 .27075 Mdot
.54032 .70397 Mdot
.69601 .41184 Mdot
.44645 .25259 Mdot
.62647 .34013 Mdot
.57718 .36274 Mdot
.45423 .26288 Mdot
.34861 .42937 Mdot
.63918 .6371 Mdot
.55245 .74524 Mdot
.33041 .42502 Mdot
.42705 .40563 Mdot
.3821 .67263 Mdot
.55796 .33948 Mdot
.34377 .46524 Mdot
.36494 .48082 Mdot
.43314 .67474 Mdot
.61542 .68921 Mdot
.71806 .46124 Mdot
.55214 .33034 Mdot
.52498 .72921 Mdot
.61185 .69632 Mdot
.69758 .41619 Mdot
.45052 .24696 Mdot
.66236 .62988 Mdot
.48867 .70989 Mdot
.55662 .34321 Mdot
.66279 .62193 Mdot
.67248 .46511 Mdot
.29775 .40851 Mdot
.32316 .63215 Mdot
.67839 .44013 Mdot
.29594 .40892 Mdot
.35027 .66563 Mdot
.71886 .3643 Mdot
.6489 .64291 Mdot
.52081 .71996 Mdot
.62809 .63304 Mdot
.46417 .26088 Mdot
.44457 .68302 Mdot
.51786 .72339 Mdot
.66016 .62855 Mdot
.38581 .67043 Mdot
.28746 .5451 Mdot
.71372 .60245 Mdot
.28786 .5688 Mdot
.29796 .41433 Mdot
.55351 .34262 Mdot
.46694 .27404 Mdot
.7196 .59647 Mdot
.4773 .68987 Mdot
.68927 .59521 Mdot
.29447 .40385 Mdot
.35299 .64017 Mdot
.47928 .27268 Mdot
.5909 .69884 Mdot
.65807 .63797 Mdot
.6564 .61463 Mdot
.71358 .37426 Mdot
.43419 .23722 Mdot
.35335 .43497 Mdot
.73578 .33113 Mdot
.34188 .42862 Mdot
.63841 .60957 Mdot
.35703 .66439 Mdot
.54161 .72362 Mdot
.70585 .60581 Mdot
.34196 .66395 Mdot
.26799 .57981 Mdot
.35612 .4962 Mdot
.72336 .36399 Mdot
.54355 .74963 Mdot
.52647 .35255 Mdot
.36228 .48798 Mdot
.34335 .44973 Mdot
.53799 .32062 Mdot
.2634 .4242 Mdot
.62612 .65072 Mdot
.52221 .3337 Mdot
.67748 .45783 Mdot
.54547 .35741 Mdot
.54654 .33195 Mdot
.53006 .7088 Mdot
.71634 .36946 Mdot
.54502 .32248 Mdot
.33846 .44136 Mdot
.3361 .45234 Mdot
.62728 .64065 Mdot
.28848 .55086 Mdot
.27419 .562 Mdot
.71615 .47579 Mdot
.50988 .29273 Mdot
.32103 .4222 Mdot
.44109 .67098 Mdot
.48006 .2592 Mdot
.56735 .33197 Mdot
.545 .71869 Mdot
.33502 .41483 Mdot
.73158 .35997 Mdot
.54115 .35286 Mdot
.54978 .32004 Mdot
.47577 .27117 Mdot
.62438 .62627 Mdot
.42124 .6811 Mdot
.71378 .45265 Mdot
.32466 .63576 Mdot
.51498 .27488 Mdot
.72499 .37104 Mdot
.55189 .3416 Mdot
.5688 .35593 Mdot
.43612 .6729 Mdot
.44607 .69591 Mdot
.57538 .33184 Mdot
.70986 .47674 Mdot
.75045 .58755 Mdot
.70455 .61062 Mdot
.26927 .54936 Mdot
.67485 .61956 Mdot
.52072 .71925 Mdot
.27237 .41873 Mdot
.45721 .25217 Mdot
.65993 .6113 Mdot
.52504 .33288 Mdot
.52223 .72285 Mdot
.43757 .68879 Mdot
.33559 .44261 Mdot
.33926 .47246 Mdot
.72098 .38752 Mdot
.28288 .40441 Mdot
.6217 .64185 Mdot
.46534 .24801 Mdot
.70412 .43119 Mdot
.35145 .65272 Mdot
.55409 .73371 Mdot
.52786 .36689 Mdot
.27734 .58549 Mdot
.71008 .47126 Mdot
.5401 .7425 Mdot
.47027 .24735 Mdot
.45919 .26629 Mdot
.36795 .49483 Mdot
.47929 .322 Mdot
.6661 .61174 Mdot
.44705 .67379 Mdot
.5662 .71057 Mdot
.26995 .57322 Mdot
.33514 .46861 Mdot
.35832 .65024 Mdot
.74532 .60286 Mdot
.34729 .42908 Mdot
.47922 .26665 Mdot
.53276 .74523 Mdot
.35883 .44555 Mdot
.4378 .23251 Mdot
.52538 .35102 Mdot
.56342 .35738 Mdot
.72107 .44441 Mdot
.45346 .23759 Mdot
.44035 .23439 Mdot
.43612 .23109 Mdot
.72539 .5887 Mdot
.25972 .58102 Mdot
.50346 .25713 Mdot
.33235 .48147 Mdot
.29879 .41597 Mdot
.32806 .62864 Mdot
.69315 .60953 Mdot
.7256 .37742 Mdot
.35976 .4679 Mdot
.33491 .48391 Mdot
.57007 .74507 Mdot
.32213 .6484 Mdot
.37227 .4826 Mdot
.54953 .72405 Mdot
.51165 .69777 Mdot
.70612 .41069 Mdot
.60953 .68915 Mdot
.73683 .32676 Mdot
.28329 .57826 Mdot
.28969 .57406 Mdot
.50655 .71688 Mdot
.64829 .63709 Mdot
.28843 .57388 Mdot
.62605 .62269 Mdot
.51635 .73181 Mdot
.3191 .63514 Mdot
.45014 .69799 Mdot
.46867 .2893 Mdot
.36527 .4755 Mdot
.66602 .62332 Mdot
.3632 .47428 Mdot
.66459 .62604 Mdot
.42612 .4857 Mdot
.29395 .56162 Mdot
.35283 .50389 Mdot
.34449 .42042 Mdot
.45953 .30909 Mdot
.33666 .47184 Mdot
.71163 .37546 Mdot
.54843 .73647 Mdot
.51454 .30059 Mdot
.32542 .62261 Mdot
.31081 .41876 Mdot
.3472 .4707 Mdot
.37965 .67304 Mdot
.34918 .48011 Mdot
.73795 .33217 Mdot
.28145 .58157 Mdot
.3719 .48509 Mdot
.64312 .62014 Mdot
.70568 .61766 Mdot
.49305 .71171 Mdot
.56854 .3542 Mdot
.59316 .69743 Mdot
.34091 .45338 Mdot
.71548 .43752 Mdot
.44508 .28025 Mdot
.44559 .23642 Mdot
.54819 .74447 Mdot
.38104 .23073 Mdot
.73461 .61613 Mdot
.67199 .42414 Mdot
.33418 .63426 Mdot
.68282 .46426 Mdot
.71872 .46783 Mdot
.58086 .72376 Mdot
.46566 .27283 Mdot
.31709 .41865 Mdot
.43607 .69691 Mdot
.50305 .69042 Mdot
.26871 .57225 Mdot
.70616 .41465 Mdot
.52934 .31143 Mdot
.29624 .60975 Mdot
.44241 .26811 Mdot
.44401 .26104 Mdot
.6524 .63116 Mdot
.7166 .43888 Mdot
.55095 .33084 Mdot
.4489 .25101 Mdot
.70363 .40694 Mdot
.58286 .3603 Mdot
.7156 .36058 Mdot
.45764 .6788 Mdot
.42456 .47541 Mdot
.4133 .68945 Mdot
.6871 .61073 Mdot
.71543 .377 Mdot
.46573 .68654 Mdot
.42668 .67088 Mdot
.55136 .33522 Mdot
.66809 .44237 Mdot
.43091 .66258 Mdot
.36946 .48923 Mdot
.55695 .35957 Mdot
.32739 .4379 Mdot
.42854 .23933 Mdot
.33896 .45506 Mdot
.72082 .38525 Mdot
.6495 .61254 Mdot
.70695 .44718 Mdot
.65693 .62872 Mdot
.25776 .42595 Mdot
.34861 .45757 Mdot
.33372 .46306 Mdot
.28268 .55757 Mdot
.51557 .71032 Mdot
.44942 .70059 Mdot
.71133 .46635 Mdot
.70891 .45025 Mdot
.32437 .62363 Mdot
.56158 .72606 Mdot
.59315 .37096 Mdot
.28791 .57183 Mdot
.34827 .48303 Mdot
.5476 .73557 Mdot
.33288 .627 Mdot
.75269 .59238 Mdot
.28394 .55226 Mdot
.52451 .7109 Mdot
.72564 .34315 Mdot
.32269 .44839 Mdot
.55805 .33013 Mdot
.51147 .30825 Mdot
.29285 .5828 Mdot
.43225 .25211 Mdot
.53511 .72047 Mdot
.56657 .33599 Mdot
.55242 .73834 Mdot
.70598 .48677 Mdot
.74388 .60981 Mdot
.54623 .72747 Mdot
.34987 .47465 Mdot
.73371 .3276 Mdot
.64379 .63707 Mdot
.36454 .4648 Mdot
.71062 .60516 Mdot
.45497 .68625 Mdot
.53523 .73422 Mdot
.58317 .36004 Mdot
.35668 .64161 Mdot
.66382 .61077 Mdot
.35863 .50453 Mdot
.45619 .69959 Mdot
.33283 .65787 Mdot
.43443 .25783 Mdot
.32251 .41721 Mdot
.38196 .5045 Mdot
.71028 .37376 Mdot
.30332 .40561 Mdot
.73698 .59499 Mdot
.71454 .62272 Mdot
.74498 .59357 Mdot
.51746 .70787 Mdot
.48343 .30331 Mdot
.42841 .68555 Mdot
.53741 .32967 Mdot
.66899 .43562 Mdot
.36154 .46215 Mdot
.55969 .36663 Mdot
.7236 .59841 Mdot
.45631 .2688 Mdot
.27788 .58789 Mdot
.68002 .43282 Mdot
.57531 .35727 Mdot
.66007 .61605 Mdot
.48219 .69373 Mdot
.54398 .72098 Mdot
.72018 .35122 Mdot
.36226 .45319 Mdot
.33875 .46998 Mdot
.72648 .60373 Mdot
.48986 .32769 Mdot
.44485 .26603 Mdot
.5351 .35498 Mdot
.7236 .60331 Mdot
.28641 .55345 Mdot
.45702 .68925 Mdot
.36783 .48156 Mdot
.28756 .5587 Mdot
.732 .59093 Mdot
.5203 .69254 Mdot
.45491 .2775 Mdot
.38949 .51415 Mdot
.53388 .72141 Mdot
.64338 .62543 Mdot
.62651 .34508 Mdot
.35775 .65874 Mdot
.34621 .49496 Mdot
.38536 .47993 Mdot
.26848 .55463 Mdot
.32888 .63794 Mdot
.58534 .35183 Mdot
.38398 .48889 Mdot
.32677 .62278 Mdot
.3225 .64247 Mdot
.32759 .41729 Mdot
.32661 .41558 Mdot
.54259 .73474 Mdot
.25558 .55677 Mdot
.68757 .46287 Mdot
.35838 .64106 Mdot
.51894 .35948 Mdot
.3358 .63688 Mdot
.26996 .54597 Mdot
.53179 .69406 Mdot
.30032 .54905 Mdot
.52108 .73889 Mdot
.5555 .71387 Mdot
.68643 .61137 Mdot
.33612 .65965 Mdot
.71075 .47134 Mdot
.54335 .31565 Mdot
.72583 .37496 Mdot
.54337 .73636 Mdot
.7032 .40922 Mdot
.67737 .62959 Mdot
.67827 .43989 Mdot
.6803 .46486 Mdot
.6494 .61134 Mdot
.55913 .74476 Mdot
.27649 .58432 Mdot
.65171 .60968 Mdot
.54212 .31886 Mdot
.45204 .24838 Mdot
.50174 .69092 Mdot
.5283 .34685 Mdot
.37417 .51399 Mdot
.73329 .58064 Mdot
.67403 .43398 Mdot
.3856 .47526 Mdot
.56951 .72465 Mdot
.47095 .24506 Mdot
.54264 .72777 Mdot
.58792 .34886 Mdot
.47367 .28895 Mdot
.34943 .42826 Mdot
.51329 .35493 Mdot
.6416 .64518 Mdot
.31356 .41591 Mdot
.51443 .69853 Mdot
.72487 .37532 Mdot
.67356 .60853 Mdot
.61884 .66053 Mdot
.55659 .33076 Mdot
.53472 .71172 Mdot
.43629 .69246 Mdot
.53313 .33132 Mdot
.64538 .62365 Mdot
.40094 .66929 Mdot
.36669 .48983 Mdot
.6806 .61475 Mdot
.32077 .4205 Mdot
.4189 .49159 Mdot
.48933 .27227 Mdot
.55835 .36465 Mdot
.32046 .64649 Mdot
.6919 .4157 Mdot
.32222 .6256 Mdot
.3562 .51217 Mdot
.27236 .4084 Mdot
.34434 .48923 Mdot
.38398 .47153 Mdot
.73224 .34818 Mdot
.49657 .71355 Mdot
.54935 .35188 Mdot
.55438 .34086 Mdot
.33365 .66021 Mdot
.72492 .3097 Mdot
.4489 .26068 Mdot
.71546 .35699 Mdot
.34691 .45638 Mdot
.34236 .47989 Mdot
.44723 .69054 Mdot
.42801 .47246 Mdot
.55118 .36095 Mdot
.34821 .49286 Mdot
.29762 .57188 Mdot
.63825 .62397 Mdot
.38038 .50364 Mdot
.32472 .44704 Mdot
.74858 .60271 Mdot
.64279 .62201 Mdot
.72653 .36497 Mdot
.57751 .36344 Mdot
.72244 .44831 Mdot
.44332 .26718 Mdot
.38353 .48174 Mdot
.26629 .42082 Mdot
.28181 .5444 Mdot
.45367 .2794 Mdot
.33774 .64026 Mdot
.36733 .51786 Mdot
.32551 .47353 Mdot
.44467 .26076 Mdot
.65 .63872 Mdot
.54724 .73291 Mdot
.4216 .4866 Mdot
.55291 .33938 Mdot
.32369 .64175 Mdot
.42859 .23279 Mdot
.55125 .73899 Mdot
.41994 .69155 Mdot
.53541 .73967 Mdot
.65637 .61839 Mdot
.71824 .37081 Mdot
.47571 .28981 Mdot
.54306 .72719 Mdot
.68951 .41013 Mdot
.71313 .59828 Mdot
.26191 .55478 Mdot
.65861 .63623 Mdot
.58077 .72438 Mdot
.5376 .71001 Mdot
.55697 .71071 Mdot
.3539 .65604 Mdot
.38344 .46901 Mdot
.54027 .32912 Mdot
.72474 .60242 Mdot
.68953 .41806 Mdot
.28145 .40621 Mdot
.44556 .7018 Mdot
.35326 .41922 Mdot
.3465 .42392 Mdot
.33822 .45368 Mdot
.32675 .46276 Mdot
.58264 .34499 Mdot
.36193 .5095 Mdot
.33086 .47853 Mdot
.62093 .64232 Mdot
.72545 .36882 Mdot
.3463 .45299 Mdot
.56158 .35692 Mdot
.51888 .29323 Mdot
.47182 .24556 Mdot
.40612 .50398 Mdot
.43858 .65721 Mdot
.55135 .73071 Mdot
.7046 .4773 Mdot
.71213 .42336 Mdot
.4763 .25912 Mdot
.63275 .62433 Mdot
.52927 .73898 Mdot
.72547 .33918 Mdot
.48104 .29117 Mdot
.34648 .4412 Mdot
.28165 .55707 Mdot
.29955 .54429 Mdot
.26287 .56234 Mdot
.35928 .45856 Mdot
.53189 .34741 Mdot
.70723 .47927 Mdot
.25651 .56754 Mdot
.40902 .68135 Mdot
.43474 .2359 Mdot
.45154 .24452 Mdot
.48757 .68586 Mdot
.3488 .50742 Mdot
.66709 .62131 Mdot
.29304 .55553 Mdot
.62987 .61044 Mdot
.59455 .71356 Mdot
.49696 .24604 Mdot
.318 .41404 Mdot
.30966 .411 Mdot
.3705 .51017 Mdot
.48151 .67981 Mdot
.47554 .70154 Mdot
.47604 .69075 Mdot
.63648 .62517 Mdot
.30068 .41235 Mdot
.7289 .61363 Mdot
.55312 .36169 Mdot
.53181 .71663 Mdot
.26008 .59437 Mdot
.70842 .45016 Mdot
.32064 .64169 Mdot
.47541 .28004 Mdot
.27143 .56835 Mdot
.55619 .35161 Mdot
.38902 .5058 Mdot
.70244 .43781 Mdot
.46195 .68883 Mdot
.32061 .6366 Mdot
.67436 .47108 Mdot
.38342 .48809 Mdot
.50514 .30973 Mdot
.55385 .36595 Mdot
.46853 .28888 Mdot
.30773 .41211 Mdot
.48309 .2776 Mdot
.66326 .61196 Mdot
.35048 .45986 Mdot
.37205 .48698 Mdot
.34475 .47001 Mdot
.34284 .4239 Mdot
.63631 .63136 Mdot
.33573 .65687 Mdot
.53073 .31618 Mdot
.572 .36535 Mdot
.33326 .63673 Mdot
.46389 .27434 Mdot
.7053 .61099 Mdot
.72754 .36641 Mdot
.52573 .32405 Mdot
.48682 .29531 Mdot
.31299 .41682 Mdot
.35127 .48619 Mdot
.57049 .36354 Mdot
.34809 .42839 Mdot
.34401 .65632 Mdot
.68072 .44861 Mdot
.32751 .64756 Mdot
.45873 .23854 Mdot
.47739 .27863 Mdot
.6377 .63649 Mdot
.54445 .7265 Mdot
.47361 .2588 Mdot
.70047 .42977 Mdot
.37445 .50417 Mdot
.32371 .41656 Mdot
.45164 .69772 Mdot
.2948 .4021 Mdot
.45563 .23715 Mdot
.35203 .43309 Mdot
.47156 .6777 Mdot
.40473 .66553 Mdot
.34493 .49378 Mdot
.34248 .6514 Mdot
.53523 .70851 Mdot
.45032 .24939 Mdot
.63088 .62414 Mdot
.22218 .45648 Mdot
.62707 .62192 Mdot
.47797 .68967 Mdot
.56299 .33457 Mdot
.56804 .74027 Mdot
.56175 .3326 Mdot
.5312 .6894 Mdot
.32182 .45129 Mdot
.46291 .69952 Mdot
.52144 .31352 Mdot
.71275 .46655 Mdot
.67056 .45198 Mdot
.54149 .35231 Mdot
.53457 .71869 Mdot
.53928 .33226 Mdot
.47101 .26332 Mdot
.71629 .59147 Mdot
.55326 .71188 Mdot
.6779 .4617 Mdot
.67497 .43343 Mdot
.72793 .60275 Mdot
.34219 .46085 Mdot
.36747 .48313 Mdot
.68071 .43881 Mdot
.63484 .60717 Mdot
.51041 .71625 Mdot
.33797 .46881 Mdot
.52212 .32943 Mdot
.68499 .4579 Mdot
.70277 .62952 Mdot
.44314 .68668 Mdot
.31856 .64014 Mdot
.27043 .40959 Mdot
.72098 .6209 Mdot
.37713 .50205 Mdot
.34584 .65389 Mdot
.44111 .24858 Mdot
.39005 .51086 Mdot
.29759 .41664 Mdot
.71224 .62112 Mdot
.54777 .32498 Mdot
.26243 .56447 Mdot
.69429 .48658 Mdot
.37579 .4943 Mdot
.39376 .21276 Mdot
.56828 .36388 Mdot
.34001 .4331 Mdot
.51564 .3287 Mdot
.52873 .73344 Mdot
.34258 .47276 Mdot
.70928 .59927 Mdot
.70675 .47109 Mdot
.3621 .45311 Mdot
.44878 .29942 Mdot
.70362 .60627 Mdot
.55792 .35167 Mdot
.44763 .26953 Mdot
.3413 .63187 Mdot
.25343 .42621 Mdot
.73635 .35352 Mdot
.45646 .26214 Mdot
.34427 .46257 Mdot
.70647 .43358 Mdot
.70226 .61717 Mdot
.54575 .35175 Mdot
.31332 .4189 Mdot
.71285 .61249 Mdot
.6403 .61779 Mdot
.48172 .28034 Mdot
.47075 .72053 Mdot
.31846 .45468 Mdot
.33211 .44281 Mdot
.46362 .70946 Mdot
.43799 .69119 Mdot
.36446 .47331 Mdot
.3262 .43184 Mdot
.66396 .62174 Mdot
.30169 .39664 Mdot
.38926 .50469 Mdot
.52007 .3128 Mdot
.67412 .60758 Mdot
.71271 .42109 Mdot
.67107 .43426 Mdot
.45763 .25738 Mdot
.53725 .74287 Mdot
.48844 .27541 Mdot
.69954 .46897 Mdot
.34058 .4398 Mdot
.63496 .61315 Mdot
.30941 .6366 Mdot
.71605 .60254 Mdot
.69397 .42979 Mdot
.43007 .67633 Mdot
.28376 .53513 Mdot
.392 .21396 Mdot
.60831 .65281 Mdot
.72243 .35077 Mdot
.44529 .23673 Mdot
.40899 .68121 Mdot
.34708 .46171 Mdot
.25872 .55541 Mdot
.36158 .45384 Mdot
.49268 .30493 Mdot
.73393 .36443 Mdot
.58292 .36031 Mdot
.55562 .33041 Mdot
.38247 .4762 Mdot
.63915 .61771 Mdot
.73025 .61585 Mdot
.57256 .34578 Mdot
.65313 .61885 Mdot
.33195 .43877 Mdot
.69298 .43711 Mdot
.55441 .69764 Mdot
.34883 .48244 Mdot
.50566 .29168 Mdot
.68018 .62957 Mdot
.42167 .67168 Mdot
.70981 .41692 Mdot
.31004 .4114 Mdot
.59701 .69416 Mdot
.66003 .6095 Mdot
.40563 .50182 Mdot
.70903 .46951 Mdot
.5251 .32474 Mdot
.71005 .43832 Mdot
.33924 .43508 Mdot
.31829 .41228 Mdot
.54059 .32072 Mdot
.34793 .48057 Mdot
.49289 .72017 Mdot
.35898 .65729 Mdot
.31478 .64274 Mdot
.33204 .48149 Mdot
.51274 .70058 Mdot
.69227 .61907 Mdot
.57228 .34382 Mdot
.268 .5546 Mdot
.33215 .41336 Mdot
.52257 .70715 Mdot
.70275 .61204 Mdot
.61817 .68438 Mdot
.63717 .62768 Mdot
.71348 .46788 Mdot
.63428 .62158 Mdot
.37128 .50972 Mdot
.51316 .72806 Mdot
.69595 .45721 Mdot
.55844 .34778 Mdot
.68191 .41108 Mdot
.36174 .48811 Mdot
.67765 .63251 Mdot
.67107 .42782 Mdot
.3574 .64679 Mdot
.51826 .73222 Mdot
.50241 .34171 Mdot
.4478 .65799 Mdot
.339 .43835 Mdot
.36162 .45595 Mdot
.53692 .35586 Mdot
.6363 .63508 Mdot
.43887 .68808 Mdot
.71407 .36537 Mdot
.46564 .2422 Mdot
.51993 .73788 Mdot
.48181 .25978 Mdot
.28387 .56172 Mdot
.48865 .70407 Mdot
.29721 .57272 Mdot
.65669 .63131 Mdot
.54054 .71973 Mdot
.42469 .23354 Mdot
.35813 .63575 Mdot
.4667 .27048 Mdot
.70764 .4195 Mdot
.28864 .57485 Mdot
.67885 .45637 Mdot
.72847 .59462 Mdot
.72267 .36139 Mdot
.66742 .60943 Mdot
.45179 .30182 Mdot
.35764 .664 Mdot
.69965 .6231 Mdot
.70617 .59854 Mdot
.69456 .47083 Mdot
.57176 .35212 Mdot
.33241 .65278 Mdot
.5642 .32571 Mdot
.57786 .34826 Mdot
.72872 .61762 Mdot
.54572 .71975 Mdot
.56053 .72852 Mdot
.51337 .29966 Mdot
.54763 .72215 Mdot
.68716 .44868 Mdot
.28369 .55384 Mdot
.26348 .54117 Mdot
.69075 .61997 Mdot
.3393 .6313 Mdot
.37968 .51203 Mdot
.73865 .35965 Mdot
.69052 .44193 Mdot
.63732 .62192 Mdot
.57499 .71258 Mdot
.56503 .33277 Mdot
.44111 .68507 Mdot
.52243 .72683 Mdot
.53009 .73107 Mdot
.57513 .7354 Mdot
.29879 .40927 Mdot
.66483 .60551 Mdot
.53185 .7207 Mdot
.32513 .42371 Mdot
.32349 .44026 Mdot
.52764 .3253 Mdot
.48528 .30397 Mdot
.33858 .65237 Mdot
.54227 .3288 Mdot
.35434 .49265 Mdot
.7106 .45666 Mdot
.46291 .29795 Mdot
.55734 .32563 Mdot
.70978 .47547 Mdot
.71036 .47709 Mdot
.57275 .33515 Mdot
.46665 .299 Mdot
.49066 .71767 Mdot
.36793 .64753 Mdot
.51169 .69914 Mdot
.66713 .43146 Mdot
.74069 .59461 Mdot
.45709 .69885 Mdot
.36585 .46158 Mdot
.5213 .33731 Mdot
.70158 .4403 Mdot
.56007 .71434 Mdot
.33182 .46666 Mdot
.54935 .33538 Mdot
.46699 .26562 Mdot
.56124 .34941 Mdot
.53236 .34909 Mdot
.49683 .6978 Mdot
.71541 .57225 Mdot
.43161 .67349 Mdot
.67837 .4734 Mdot
.55042 .34793 Mdot
.39207 .66958 Mdot
.71627 .38268 Mdot
.71342 .59195 Mdot
.36087 .65674 Mdot
.33601 .48879 Mdot
.70358 .47736 Mdot
.5255 .71395 Mdot
.63142 .64379 Mdot
.3004 .55821 Mdot
.5428 .72622 Mdot
.5864 .35622 Mdot
.53845 .35258 Mdot
.68539 .46012 Mdot
.48444 .69455 Mdot
.3459 .6529 Mdot
.53504 .72551 Mdot
.72461 .60667 Mdot
.35523 .43479 Mdot
.59319 .69675 Mdot
.55016 .33128 Mdot
.55604 .73005 Mdot
.69086 .41966 Mdot
.48023 .26774 Mdot
.34669 .43065 Mdot
.60725 .701 Mdot
.34634 .46703 Mdot
.72878 .60493 Mdot
.5124 .28354 Mdot
.34207 .62697 Mdot
.35483 .45135 Mdot
.26558 .55116 Mdot
.69789 .60451 Mdot
.35559 .45577 Mdot
.2842 .53814 Mdot
.41488 .68884 Mdot
.45069 .68134 Mdot
.34529 .45363 Mdot
.68277 .44091 Mdot
.72381 .49189 Mdot
.32668 .44428 Mdot
.67502 .47443 Mdot
.29387 .55243 Mdot
.54767 .31717 Mdot
.43619 .26273 Mdot
.27296 .41814 Mdot
.34868 .43835 Mdot
.3526 .5033 Mdot
.35498 .43362 Mdot
.29387 .52667 Mdot
.70375 .47014 Mdot
.72149 .44829 Mdot
.46766 .25965 Mdot
.38783 .48563 Mdot
.47792 .27638 Mdot
.70073 .61716 Mdot
.34632 .66479 Mdot
.56481 .36766 Mdot
.54959 .72684 Mdot
.34537 .47341 Mdot
.70548 .42182 Mdot
.34185 .43464 Mdot
.34873 .64423 Mdot
.68613 .45276 Mdot
.70527 .4438 Mdot
.71296 .49212 Mdot
.44482 .23415 Mdot
.54664 .74202 Mdot
.36683 .50286 Mdot
.43394 .24192 Mdot
.54812 .32062 Mdot
.21687 .4697 Mdot
.52655 .74199 Mdot
.55466 .73719 Mdot
.56727 .7376 Mdot
.36173 .50576 Mdot
.36371 .50595 Mdot
.72928 .60941 Mdot
.43637 .69435 Mdot
.63977 .60847 Mdot
.69896 .47754 Mdot
.69501 .49039 Mdot
.34484 .43579 Mdot
.49845 .29426 Mdot
.46567 .27489 Mdot
.67744 .41826 Mdot
.55071 .3631 Mdot
.48506 .27397 Mdot
.36262 .5007 Mdot
.68634 .46562 Mdot
.43313 .23312 Mdot
.58149 .71823 Mdot
.61529 .67562 Mdot
.48275 .27113 Mdot
.55172 .32941 Mdot
.42567 .69273 Mdot
.27953 .41096 Mdot
.48756 .26905 Mdot
.69493 .61905 Mdot
.27739 .58566 Mdot
.55453 .36417 Mdot
.48808 .29181 Mdot
.28543 .3975 Mdot
.69432 .46305 Mdot
.55196 .32853 Mdot
.42241 .23564 Mdot
.25786 .54687 Mdot
.48626 .28307 Mdot
.55605 .73447 Mdot
.40956 .66218 Mdot
.35465 .4464 Mdot
.35165 .63697 Mdot
.67 .62755 Mdot
.7059 .41691 Mdot
.71445 .43099 Mdot
.46996 .69805 Mdot
.27729 .54929 Mdot
.67757 .44455 Mdot
.26859 .55096 Mdot
.48236 .29823 Mdot
.32477 .42337 Mdot
.51645 .29968 Mdot
.35375 .63162 Mdot
.42611 .22992 Mdot
.4816 .26952 Mdot
.68578 .62177 Mdot
.64877 .61351 Mdot
.63822 .63434 Mdot
.67879 .44925 Mdot
.27833 .56361 Mdot
.71984 .44526 Mdot
.46016 .7152 Mdot
.44935 .25939 Mdot
.72751 .34075 Mdot
.36882 .51226 Mdot
.35435 .49496 Mdot
.32547 .62963 Mdot
.52391 .33712 Mdot
.33932 .43682 Mdot
.71796 .61219 Mdot
.68892 .41012 Mdot
.67506 .63361 Mdot
.48442 .68989 Mdot
.45645 .71287 Mdot
.70607 .4484 Mdot
.50704 .30289 Mdot
.47258 .27954 Mdot
.25949 .40617 Mdot
.49376 .30722 Mdot
.71486 .45421 Mdot
.32796 .48293 Mdot
.55179 .71058 Mdot
.7193 .34389 Mdot
.34257 .47018 Mdot
.67408 .43149 Mdot
.71694 .39064 Mdot
.35262 .63328 Mdot
.30528 .40596 Mdot
.6489 .64261 Mdot
.27294 .55234 Mdot
.4438 .23184 Mdot
.5371 .31997 Mdot
.26575 .59851 Mdot
.69927 .4702 Mdot
.68814 .40526 Mdot
.47814 .25787 Mdot
.42301 .67279 Mdot
.56246 .72149 Mdot
.49044 .71649 Mdot
.72315 .61102 Mdot
.32257 .46301 Mdot
.68702 .46494 Mdot
.433 .68039 Mdot
.38257 .50687 Mdot
.65651 .62634 Mdot
.67508 .4177 Mdot
.34774 .4803 Mdot
.35207 .4479 Mdot
.47596 .27313 Mdot
.51859 .29242 Mdot
.52405 .31729 Mdot
.70701 .59476 Mdot
.36676 .44087 Mdot
.34266 .66394 Mdot
.34559 .49474 Mdot
.50978 .71369 Mdot
.53534 .33184 Mdot
.46477 .27238 Mdot
.37451 .48389 Mdot
.26471 .54727 Mdot
.53591 .71053 Mdot
.66053 .62832 Mdot
.55206 .3445 Mdot
.37495 .45462 Mdot
.34815 .47572 Mdot
.35664 .44396 Mdot
.35392 .65586 Mdot
.36283 .51188 Mdot
.72721 .37565 Mdot
.43734 .67013 Mdot
.43704 .25165 Mdot
.53515 .7364 Mdot
.7154 .36813 Mdot
.35907 .65913 Mdot
.27909 .57405 Mdot
.50488 .70224 Mdot
.51874 .73432 Mdot
.72582 .60502 Mdot
.66207 .60637 Mdot
.50274 .2954 Mdot
.33304 .42709 Mdot
.56265 .36359 Mdot
.52921 .7245 Mdot
.70737 .4189 Mdot
.47904 .2771 Mdot
.7226 .34917 Mdot
.3436 .48963 Mdot
.69392 .46879 Mdot
.54044 .34849 Mdot
.48897 .6916 Mdot
.70963 .46027 Mdot
.52487 .32515 Mdot
.44893 .24673 Mdot
.27013 .58143 Mdot
.50501 .30582 Mdot
.56173 .33519 Mdot
.33345 .4253 Mdot
.31378 .6185 Mdot
.34607 .63371 Mdot
.52071 .31182 Mdot
.70503 .40742 Mdot
.55634 .33534 Mdot
.41583 .67275 Mdot
.35329 .63515 Mdot
.69244 .41467 Mdot
.44794 .6977 Mdot
.36069 .65567 Mdot
.56378 .33405 Mdot
.53097 .74429 Mdot
.71365 .3761 Mdot
.55877 .70929 Mdot
.28762 .41678 Mdot
.32677 .45426 Mdot
.67809 .45527 Mdot
.46703 .26916 Mdot
.73605 .61003 Mdot
.71945 .62325 Mdot
.70478 .60015 Mdot
.6891 .47737 Mdot
.34571 .47653 Mdot
.53691 .72068 Mdot
.65773 .61125 Mdot
.44357 .69042 Mdot
.70109 .42728 Mdot
.68819 .43672 Mdot
.32516 .63114 Mdot
.47887 .27863 Mdot
.36753 .51163 Mdot
.70798 .42033 Mdot
.7222 .3665 Mdot
.39895 .66982 Mdot
.43342 .2306 Mdot
.34991 .66111 Mdot
.52173 .30758 Mdot
.38113 .49793 Mdot
.43193 .69902 Mdot
.54495 .35623 Mdot
.48619 .69167 Mdot
.35973 .47116 Mdot
.73752 .55032 Mdot
.71676 .38211 Mdot
.27322 .55086 Mdot
.64441 .64448 Mdot
.65159 .60816 Mdot
.70696 .46372 Mdot
.33539 .47381 Mdot
.72447 .3469 Mdot
.45815 .25687 Mdot
.33304 .62139 Mdot
.57292 .34309 Mdot
.44607 .6943 Mdot
.63422 .61553 Mdot
.45089 .2964 Mdot
.73565 .61019 Mdot
.64209 .6357 Mdot
.52562 .69648 Mdot
.35354 .44511 Mdot
.70074 .44768 Mdot
.68391 .43318 Mdot
.51503 .30008 Mdot
.74031 .33954 Mdot
.56972 .72783 Mdot
.73367 .54718 Mdot
.25425 .57196 Mdot
.35066 .46528 Mdot
.58599 .35363 Mdot
.56063 .36231 Mdot
.71863 .3651 Mdot
.35698 .45793 Mdot
.46376 .68354 Mdot
.71807 .43564 Mdot
.67179 .44017 Mdot
.35475 .64246 Mdot
.6502 .6122 Mdot
.49338 .30936 Mdot
.68897 .44587 Mdot
.22118 .46047 Mdot
.34373 .43375 Mdot
.61023 .64196 Mdot
.68931 .44849 Mdot
.73549 .31986 Mdot
.75136 .58787 Mdot
.43463 .6764 Mdot
.26152 .57781 Mdot
.45005 .68687 Mdot
.48401 .27573 Mdot
.71745 .44732 Mdot
.71593 .61897 Mdot
.55453 .34873 Mdot
.72665 .49 Mdot
.677 .45114 Mdot
.54426 .73553 Mdot
.35722 .44782 Mdot
.40371 .50797 Mdot
.34937 .47796 Mdot
.30212 .39631 Mdot
.45116 .23459 Mdot
.7191 .62343 Mdot
.72563 .60344 Mdot
.26121 .57769 Mdot
.43433 .23249 Mdot
.71632 .46823 Mdot
.68669 .45489 Mdot
.60822 .69602 Mdot
.53298 .34944 Mdot
.71877 .46341 Mdot
.33503 .42541 Mdot
.71155 .49284 Mdot
.45084 .70307 Mdot
.6458 .61292 Mdot
.33981 .41883 Mdot
.67684 .45534 Mdot
.5027 .6972 Mdot
.27777 .55825 Mdot
.32864 .44405 Mdot
.51318 .32129 Mdot
.66173 .60779 Mdot
.44949 .71153 Mdot
.7373 .36346 Mdot
.32239 .4523 Mdot
.70544 .61462 Mdot
.47548 .31897 Mdot
.73147 .48468 Mdot
.54321 .74371 Mdot
.67575 .43248 Mdot
.63155 .62161 Mdot
.54103 .34485 Mdot
.43687 .2533 Mdot
.71233 .44454 Mdot
.66927 .436 Mdot
.33965 .64057 Mdot
.50777 .30191 Mdot
.48558 .26541 Mdot
.51241 .71879 Mdot
.66478 .62205 Mdot
.35067 .64309 Mdot
.22455 .45019 Mdot
.36567 .50532 Mdot
.63894 .63701 Mdot
.39602 .67342 Mdot
.32243 .46887 Mdot
.338 .48714 Mdot
.40247 .50508 Mdot
.41938 .67578 Mdot
.5251 .71702 Mdot
.36803 .4407 Mdot
.3408 .65006 Mdot
.28111 .56945 Mdot
.55013 .73195 Mdot
.54169 .7387 Mdot
.27346 .56996 Mdot
.34268 .64086 Mdot
.45258 .70001 Mdot
.65243 .61549 Mdot
.6526 .60799 Mdot
.5298 .73241 Mdot
.32648 .62831 Mdot
.64965 .63659 Mdot
.45521 .69171 Mdot
.6934 .43174 Mdot
.29058 .54886 Mdot
.52729 .73684 Mdot
.291 .57064 Mdot
.66339 .61241 Mdot
.23031 .4358 Mdot
.29408 .55191 Mdot
.3496 .50442 Mdot
.35561 .44942 Mdot
.44104 .23723 Mdot
.55972 .351 Mdot
.5729 .33523 Mdot
.63557 .63419 Mdot
.36295 .50933 Mdot
.47473 .68957 Mdot
.3636 .50782 Mdot
.28134 .40469 Mdot
.23505 .43009 Mdot
.25726 .58498 Mdot
.53932 .74208 Mdot
.47668 .68976 Mdot
.68811 .48396 Mdot
.69605 .40882 Mdot
.27554 .54278 Mdot
.65908 .6079 Mdot
.55637 .72602 Mdot
.64021 .60847 Mdot
.69809 .46874 Mdot
.70209 .44575 Mdot
.53374 .32838 Mdot
.55127 .32807 Mdot
.70221 .461 Mdot
.67267 .46911 Mdot
.22181 .45318 Mdot
.44692 .69674 Mdot
.4047 .68269 Mdot
.25923 .42212 Mdot
.41975 .49045 Mdot
.46581 .26686 Mdot
.46044 .29637 Mdot
.71379 .61393 Mdot
.26184 .55765 Mdot
.35903 .48202 Mdot
.56327 .33932 Mdot
.6855 .61186 Mdot
.45806 .27462 Mdot
.64802 .61072 Mdot
.44081 .26016 Mdot
.69244 .41589 Mdot
.34367 .48027 Mdot
.34925 .50117 Mdot
.72325 .60552 Mdot
.70214 .49032 Mdot
.68516 .46593 Mdot
.46304 .26751 Mdot
.26324 .41984 Mdot
.68802 .46282 Mdot
.52638 .73704 Mdot
.59068 .72302 Mdot
.54904 .35659 Mdot
.33309 .469 Mdot
.2704 .41711 Mdot
.35497 .63688 Mdot
.55016 .3211 Mdot
.55194 .34386 Mdot
.47321 .72152 Mdot
.36969 .49002 Mdot
.61842 .68717 Mdot
.54859 .32439 Mdot
.56625 .74041 Mdot
.70147 .45114 Mdot
.55674 .32435 Mdot
.53054 .31048 Mdot
.43348 .20862 Mdot
.57541 .33624 Mdot
.54413 .71484 Mdot
.45568 .68721 Mdot
.33033 .64937 Mdot
.39127 .68005 Mdot
.45933 .28349 Mdot
.45885 .27128 Mdot
.71755 .38291 Mdot
.70447 .60211 Mdot
.39698 .50559 Mdot
.45232 .26017 Mdot
.57526 .71576 Mdot
.32258 .63617 Mdot
.33017 .63567 Mdot
.33105 .64019 Mdot
.44612 .68965 Mdot
.31555 .41276 Mdot
.72943 .37059 Mdot
.54601 .73478 Mdot
.32687 .64661 Mdot
.34996 .50972 Mdot
.49662 .71313 Mdot
.65878 .62809 Mdot
.31816 .6258 Mdot
.53994 .72166 Mdot
.29943 .56762 Mdot
.66804 .6142 Mdot
.26458 .54956 Mdot
.65334 .43493 Mdot
.73221 .31608 Mdot
.64056 .61962 Mdot
.67485 .41895 Mdot
.69229 .4697 Mdot
.68217 .45022 Mdot
.52309 .71982 Mdot
.66846 .44939 Mdot
.47757 .6876 Mdot
.72287 .35068 Mdot
.3795 .46289 Mdot
.47445 .28944 Mdot
.72407 .36346 Mdot
.53092 .73149 Mdot
.45753 .70958 Mdot
.38399 .22251 Mdot
.32194 .44543 Mdot
.70626 .62218 Mdot
.46248 .25453 Mdot
.28385 .55532 Mdot
.44078 .24785 Mdot
.70864 .47086 Mdot
.38067 .47239 Mdot
.34476 .43481 Mdot
.61626 .67825 Mdot
.46917 .27089 Mdot
.53985 .73916 Mdot
.33682 .63939 Mdot
.71702 .42686 Mdot
.45819 .25835 Mdot
.47674 .27895 Mdot
.33256 .44405 Mdot
.45738 .68849 Mdot
.70276 .47929 Mdot
.67893 .61119 Mdot
.71234 .38208 Mdot
.23617 .48772 Mdot
.3706 .48911 Mdot
.32128 .45166 Mdot
.28606 .56164 Mdot
.71779 .36083 Mdot
.64836 .61886 Mdot
.2914 .4022 Mdot
.73924 .36341 Mdot
.2765 .406 Mdot
.48548 .68234 Mdot
.72573 .35594 Mdot
.55376 .35804 Mdot
.52793 .32464 Mdot
.3371 .46513 Mdot
.38847 .21577 Mdot
.30518 .41521 Mdot
.65924 .63218 Mdot
.56646 .35447 Mdot
.66568 .43045 Mdot
.56336 .71857 Mdot
.42565 .20769 Mdot
.34102 .6536 Mdot
.67801 .61258 Mdot
.68795 .4594 Mdot
.40391 .20834 Mdot
.44794 .23835 Mdot
.29032 .53847 Mdot
.32308 .43933 Mdot
.33526 .46452 Mdot
.64607 .63112 Mdot
.65644 .63539 Mdot
.4164 .69265 Mdot
.5544 .31654 Mdot
.59695 .70257 Mdot
.71687 .60062 Mdot
.40842 .20754 Mdot
.56593 .36297 Mdot
.453 .67664 Mdot
.58408 .35246 Mdot
.66662 .63043 Mdot
.36186 .47202 Mdot
.4557 .68783 Mdot
.53818 .34816 Mdot
.45893 .66137 Mdot
.33692 .63218 Mdot
.22028 .4616 Mdot
.33795 .4521 Mdot
.56468 .73337 Mdot
.54957 .73506 Mdot
.47076 .68989 Mdot
.53293 .34537 Mdot
.3477 .49275 Mdot
.32881 .4741 Mdot
.32375 .46524 Mdot
.39807 .67144 Mdot
.34356 .47683 Mdot
.56495 .71482 Mdot
.28605 .54312 Mdot
.74602 .55775 Mdot
.35061 .50101 Mdot
.63174 .62839 Mdot
.33678 .45816 Mdot
.47497 .24884 Mdot
.26471 .57566 Mdot
.3589 .64334 Mdot
.65071 .6218 Mdot
.35652 .51209 Mdot
.51887 .35929 Mdot
.36504 .49996 Mdot
.44864 .2727 Mdot
.74723 .59313 Mdot
.29404 .41116 Mdot
.40133 .66974 Mdot
.53366 .72777 Mdot
.70673 .42867 Mdot
.6224 .64269 Mdot
.71342 .46575 Mdot
.36755 .6445 Mdot
.57718 .36134 Mdot
.72538 .34276 Mdot
.22658 .44548 Mdot
.36088 .47117 Mdot
.54016 .35765 Mdot
.47713 .69257 Mdot
.72408 .37546 Mdot
.42692 .47534 Mdot
.3245 .63073 Mdot
.47915 .26116 Mdot
.44391 .24733 Mdot
.51528 .27583 Mdot
.43675 .68338 Mdot
.47107 .70866 Mdot
.64835 .62996 Mdot
.67684 .44797 Mdot
.42879 .23025 Mdot
.58832 .74166 Mdot
.64164 .64154 Mdot
.71895 .369 Mdot
.63619 .61408 Mdot
.34946 .49767 Mdot
.57061 .33266 Mdot
.41745 .6836 Mdot
.56957 .34515 Mdot
.37435 .50347 Mdot
.67204 .44711 Mdot
.53929 .35424 Mdot
.43558 .24083 Mdot
.62857 .63006 Mdot
.70898 .45207 Mdot
.35565 .44413 Mdot
.55227 .73444 Mdot
.29103 .60817 Mdot
.74283 .34706 Mdot
.35899 .64669 Mdot
.35961 .64891 Mdot
.41358 .67758 Mdot
.53883 .3149 Mdot
.7411 .46379 Mdot
.35953 .63929 Mdot
.7224 .59416 Mdot
.49635 .29035 Mdot
.73325 .3378 Mdot
.71529 .43563 Mdot
.69442 .45793 Mdot
.36542 .48485 Mdot
.72214 .44551 Mdot
.26788 .56943 Mdot
.71425 .42186 Mdot
.74924 .59763 Mdot
.31356 .41488 Mdot
.68792 .45315 Mdot
.55157 .32517 Mdot
.33993 .42737 Mdot
.45161 .68023 Mdot
.72175 .46422 Mdot
.34967 .50455 Mdot
.66579 .4602 Mdot
.72657 .60513 Mdot
.52938 .33944 Mdot
.28329 .58598 Mdot
.65695 .61534 Mdot
.53723 .71404 Mdot
.27172 .58985 Mdot
.45338 .25559 Mdot
.47066 .68405 Mdot
.5036 .29239 Mdot
.47899 .28135 Mdot
.29089 .55903 Mdot
.5154 .72791 Mdot
.56232 .35903 Mdot
.44681 .24743 Mdot
.44007 .26829 Mdot
.69399 .46007 Mdot
.72117 .38682 Mdot
.5554 .33311 Mdot
.35545 .44161 Mdot
.73297 .35104 Mdot
.63672 .61987 Mdot
.32527 .44131 Mdot
.68138 .45884 Mdot
.56086 .35641 Mdot
.33308 .47863 Mdot
.3401 .65079 Mdot
.4137 .68652 Mdot
.56614 .32439 Mdot
.45342 .2764 Mdot
.45518 .68421 Mdot
.32186 .44973 Mdot
.46891 .29001 Mdot
.71317 .38299 Mdot
.33364 .4201 Mdot
.54804 .745 Mdot
.57872 .71751 Mdot
.70791 .41817 Mdot
.66502 .62502 Mdot
.68395 .43058 Mdot
.44151 .26419 Mdot
.38238 .22407 Mdot
.54094 .32714 Mdot
.34495 .62522 Mdot
.26723 .57405 Mdot
.71132 .43274 Mdot
.54631 .74137 Mdot
.59901 .71483 Mdot
.26583 .57754 Mdot
.33258 .42079 Mdot
.33216 .46405 Mdot
.72149 .35803 Mdot
.56118 .7182 Mdot
.33229 .46637 Mdot
.47464 .30144 Mdot
.32243 .41538 Mdot
.47275 .26273 Mdot
.66871 .40845 Mdot
.52706 .32208 Mdot
.39206 .67154 Mdot
.53508 .346 Mdot
.68586 .44595 Mdot
.29804 .57404 Mdot
.28125 .56586 Mdot
.49336 .24146 Mdot
.54237 .71385 Mdot
.50668 .69707 Mdot
.69927 .44494 Mdot
.71477 .37087 Mdot
.34 .65549 Mdot
.3367 .64221 Mdot
.34138 .42938 Mdot
.70877 .47036 Mdot
.69305 .40252 Mdot
.58033 .3578 Mdot
.54362 .35861 Mdot
.27088 .54238 Mdot
.69566 .41816 Mdot
.34327 .47946 Mdot
.33644 .62792 Mdot
.63558 .64278 Mdot
.44442 .68171 Mdot
.69303 .62442 Mdot
.63563 .64345 Mdot
.42208 .48173 Mdot
.35537 .42348 Mdot
.72344 .61201 Mdot
.68656 .61793 Mdot
.71826 .37438 Mdot
.26313 .54401 Mdot
.48238 .27318 Mdot
.30616 .39734 Mdot
.71457 .46648 Mdot
.35188 .48899 Mdot
.5733 .72984 Mdot
.5852 .34454 Mdot
.59808 .72744 Mdot
.40672 .3481 Mdot
.33874 .65923 Mdot
.73404 .35995 Mdot
.56273 .33532 Mdot
.57189 .34595 Mdot
.27925 .41002 Mdot
.34196 .47771 Mdot
.70885 .41963 Mdot
.25845 .54656 Mdot
.71566 .601 Mdot
.7167 .37482 Mdot
.43329 .68292 Mdot
.33887 .46242 Mdot
.50195 .70995 Mdot
.62786 .63871 Mdot
.48336 .28798 Mdot
.44464 .23517 Mdot
.3642 .49771 Mdot
.36109 .65738 Mdot
.72804 .59365 Mdot
.33574 .64796 Mdot
.34668 .64381 Mdot
.55347 .33626 Mdot
.35135 .66071 Mdot
.32137 .4392 Mdot
.31802 .46036 Mdot
.54776 .32043 Mdot
.6425 .64208 Mdot
.31154 .42041 Mdot
.56507 .33505 Mdot
.2696 .58444 Mdot
.62199 .63696 Mdot
.33671 .65073 Mdot
.63646 .62795 Mdot
.71753 .36944 Mdot
.724 .60845 Mdot
.43694 .25061 Mdot
.72137 .3681 Mdot
.40557 .68294 Mdot
.53828 .72076 Mdot
.66043 .60534 Mdot
.4506 .24712 Mdot
.63473 .62539 Mdot
.71214 .44915 Mdot
.72733 .59706 Mdot
.40556 .66517 Mdot
.22041 .4667 Mdot
.4179 .48803 Mdot
.64566 .60264 Mdot
.69382 .41033 Mdot
.52943 .73151 Mdot
.7042 .60152 Mdot
.27554 .58253 Mdot
.45124 .23876 Mdot
.3357 .46208 Mdot
.62784 .63363 Mdot
.7278 .36222 Mdot
.4334 .69841 Mdot
.44175 .25947 Mdot
.45257 .71371 Mdot
.7026 .42085 Mdot
.3186 .41667 Mdot
.74381 .60965 Mdot
.73806 .47628 Mdot
.72263 .60455 Mdot
.39032 .51551 Mdot
.5597 .3646 Mdot
.5409 .31178 Mdot
.48985 .70153 Mdot
.54175 .35972 Mdot
.46066 .31228 Mdot
.71242 .59547 Mdot
.43642 .6715 Mdot
.68286 .47884 Mdot
.35571 .4411 Mdot
.33876 .66158 Mdot
.54278 .33009 Mdot
.56165 .72918 Mdot
.3543 .65476 Mdot
.53144 .32739 Mdot
.28669 .54333 Mdot
.44901 .68515 Mdot
.7168 .47221 Mdot
.33521 .42626 Mdot
.7346 .61632 Mdot
.70832 .60528 Mdot
.58614 .35711 Mdot
.73216 .61336 Mdot
.26902 .58401 Mdot
.51726 .7308 Mdot
.33205 .65113 Mdot
.47116 .26116 Mdot
.495 .72074 Mdot
.5808 .3395 Mdot
.44844 .21233 Mdot
.33078 .42322 Mdot
.70086 .44632 Mdot
.72806 .48706 Mdot
.27456 .54174 Mdot
.54736 .73163 Mdot
.26513 .56823 Mdot
.3536 .65777 Mdot
.33605 .6453 Mdot
.67702 .44842 Mdot
.28432 .55861 Mdot
.3441 .47829 Mdot
.67493 .61478 Mdot
.27205 .5014 Mdot
.37247 .51808 Mdot
.47837 .30171 Mdot
.35871 .6429 Mdot
.74464 .60514 Mdot
.44317 .69531 Mdot
.69952 .4482 Mdot
.4649 .68229 Mdot
.43795 .69022 Mdot
.53043 .71695 Mdot
.58644 .74243 Mdot
.35903 .63901 Mdot
.61187 .69457 Mdot
.45401 .70377 Mdot
.41327 .49925 Mdot
.57231 .72249 Mdot
.73658 .44432 Mdot
.43699 .67112 Mdot
.53816 .71389 Mdot
.55588 .69782 Mdot
.56112 .7191 Mdot
.35003 .43762 Mdot
.33534 .41512 Mdot
.2535 .58137 Mdot
.72495 .35068 Mdot
.34958 .47996 Mdot
.56935 .33007 Mdot
.46829 .25566 Mdot
.42462 .67345 Mdot
.5549 .34681 Mdot
.29184 .56327 Mdot
.53469 .35981 Mdot
.33353 .44152 Mdot
.33305 .47547 Mdot
.33196 .64215 Mdot
.2398 .42299 Mdot
.72832 .34627 Mdot
.56193 .74035 Mdot
.36967 .51789 Mdot
.73105 .48579 Mdot
.33205 .42933 Mdot
.26352 .56818 Mdot
.32016 .46756 Mdot
.7008 .44764 Mdot
.4292 .68587 Mdot
.57789 .34672 Mdot
.48676 .7124 Mdot
.3442 .46166 Mdot
.5818 .37399 Mdot
.49066 .2952 Mdot
.33328 .47144 Mdot
.49409 .71257 Mdot
.35432 .65607 Mdot
.52554 .71237 Mdot
.50824 .72216 Mdot
.33172 .42033 Mdot
.4285 .67883 Mdot
.52284 .71728 Mdot
.33708 .64308 Mdot
.73396 .35888 Mdot
.71361 .59212 Mdot
.33611 .43475 Mdot
.44232 .2594 Mdot
.35807 .45757 Mdot
.48533 .28216 Mdot
.56618 .32884 Mdot
.55922 .33512 Mdot
.30757 .41287 Mdot
.68569 .41001 Mdot
.48817 .27264 Mdot
.72747 .34891 Mdot
.37534 .67362 Mdot
.51654 .69756 Mdot
.71804 .59937 Mdot
.72177 .38699 Mdot
.5577 .33574 Mdot
.30143 .4182 Mdot
.23978 .48836 Mdot
.72849 .61297 Mdot
.48969 .69003 Mdot
.3112 .41856 Mdot
.53353 .35383 Mdot
.71601 .47551 Mdot
.68486 .4344 Mdot
.71533 .5946 Mdot
.5506 .69642 Mdot
.35516 .49999 Mdot
.53341 .35324 Mdot
.31405 .64214 Mdot
.5597 .35183 Mdot
.58063 .34979 Mdot
.67164 .42191 Mdot
.34203 .48598 Mdot
.29409 .56044 Mdot
.69824 .47379 Mdot
.46853 .27935 Mdot
.48788 .69336 Mdot
.45554 .28065 Mdot
.61697 .67295 Mdot
.41244 .68928 Mdot
.70422 .46545 Mdot
.52264 .3254 Mdot
.35263 .48144 Mdot
.43855 .68815 Mdot
.47335 .69425 Mdot
.44475 .67912 Mdot
.4676 .25805 Mdot
.7145 .42953 Mdot
.71203 .3702 Mdot
.35356 .4435 Mdot
.52131 .73634 Mdot
.43565 .20893 Mdot
.35183 .44864 Mdot
.65637 .60839 Mdot
.35557 .65172 Mdot
.53272 .73868 Mdot
.33855 .62355 Mdot
.49162 .70349 Mdot
.684 .43841 Mdot
.36309 .49182 Mdot
.34841 .43377 Mdot
.29495 .41038 Mdot
.45662 .27329 Mdot
.5415 .71018 Mdot
.36169 .43166 Mdot
.38108 .49788 Mdot
.27652 .41366 Mdot
.32967 .46838 Mdot
.41636 .48996 Mdot
.50979 .30889 Mdot
.53595 .32566 Mdot
.27047 .57682 Mdot
.32937 .44669 Mdot
.49545 .71474 Mdot
.42031 .68917 Mdot
.39259 .66283 Mdot
.64193 .63753 Mdot
.43286 .67066 Mdot
.70222 .47579 Mdot
.72098 .46921 Mdot
.69653 .48963 Mdot
.4322 .24757 Mdot
.33617 .65274 Mdot
.36045 .48548 Mdot
.65712 .63282 Mdot
.45093 .25385 Mdot
.5204 .73711 Mdot
.48149 .27925 Mdot
.27106 .55072 Mdot
.4376 .24747 Mdot
.57914 .36218 Mdot
.75196 .58938 Mdot
.33644 .62813 Mdot
.47052 .2848 Mdot
.45071 .68269 Mdot
.3044 .41612 Mdot
.31306 .4068 Mdot
.45448 .70949 Mdot
.48221 .26444 Mdot
.71232 .38336 Mdot
.32891 .42526 Mdot
.38688 .47961 Mdot
.63597 .63209 Mdot
.43714 .25328 Mdot
.64269 .60915 Mdot
.35088 .651 Mdot
.50318 .6952 Mdot
.54101 .73208 Mdot
.70895 .60312 Mdot
.26412 .5679 Mdot
.43539 .24938 Mdot
.70061 .46319 Mdot
.25644 .5523 Mdot
.72853 .34394 Mdot
.51732 .34043 Mdot
.28398 .41196 Mdot
.72929 .37212 Mdot
.35846 .51435 Mdot
.71227 .60902 Mdot
.36994 .50996 Mdot
.34538 .62726 Mdot
.37761 .48305 Mdot
.69275 .47443 Mdot
.69411 .45692 Mdot
.72233 .3469 Mdot
.37089 .49309 Mdot
.33659 .49853 Mdot
.44837 .69401 Mdot
.7124 .42568 Mdot
.52628 .72103 Mdot
.56261 .73293 Mdot
.67362 .42128 Mdot
.51875 .71078 Mdot
.47782 .27903 Mdot
.38045 .47761 Mdot
.71294 .60905 Mdot
.72212 .60267 Mdot
.7036 .46219 Mdot
.66851 .43018 Mdot
.70214 .4465 Mdot
.35262 .65328 Mdot
.51608 .72701 Mdot
.33017 .40381 Mdot
.33492 .44776 Mdot
.35863 .5079 Mdot
.43209 .68365 Mdot
.26836 .57989 Mdot
.43018 .41928 Mdot
.4797 .26415 Mdot
.68781 .44495 Mdot
.62929 .61963 Mdot
.29484 .60986 Mdot
.67238 .61948 Mdot
.32587 .41541 Mdot
.7273 .59092 Mdot
.48784 .68879 Mdot
.43975 .24256 Mdot
.35026 .63538 Mdot
.43671 .23519 Mdot
.63636 .64256 Mdot
.46712 .69526 Mdot
.2814 .55209 Mdot
.31672 .41443 Mdot
.27546 .56241 Mdot
.62557 .34239 Mdot
.48623 .7044 Mdot
.66463 .61782 Mdot
.34094 .63052 Mdot
.51663 .33751 Mdot
.32012 .65882 Mdot
.36444 .48216 Mdot
.37018 .51557 Mdot
.39342 .50728 Mdot
.34048 .41829 Mdot
.43323 .67614 Mdot
.26649 .55882 Mdot
.52176 .33002 Mdot
.349 .43071 Mdot
.6108 .68624 Mdot
.3479 .46179 Mdot
.35014 .50267 Mdot
.35626 .48857 Mdot
.377 .51687 Mdot
.41744 .67245 Mdot
.3299 .64063 Mdot
.66784 .62356 Mdot
.38482 .49073 Mdot
.69748 .60883 Mdot
.70593 .45835 Mdot
.57742 .33376 Mdot
.42016 .67806 Mdot
.43791 .23489 Mdot
.62042 .66333 Mdot
.38515 .4757 Mdot
.68939 .48587 Mdot
.297 .40252 Mdot
.49539 .30479 Mdot
.57449 .33863 Mdot
.4346 .25163 Mdot
.67591 .45408 Mdot
.64502 .61666 Mdot
.32673 .48036 Mdot
.52694 .72417 Mdot
.54836 .72175 Mdot
.34483 .42723 Mdot
.70449 .59351 Mdot
.70888 .60517 Mdot
.72363 .365 Mdot
.35364 .49921 Mdot
.34068 .4192 Mdot
.51191 .71311 Mdot
.71457 .38306 Mdot
.28406 .57087 Mdot
.4597 .26375 Mdot
.32752 .4327 Mdot
.52203 .33616 Mdot
.26969 .55721 Mdot
.65745 .63145 Mdot
.55618 .35665 Mdot
.35225 .46182 Mdot
.35425 .42174 Mdot
.32555 .62274 Mdot
.51847 .29781 Mdot
.69993 .40668 Mdot
.33032 .42087 Mdot
.337 .43043 Mdot
.44754 .68531 Mdot
.72337 .60716 Mdot
.54618 .74203 Mdot
.40558 .66592 Mdot
.55892 .3353 Mdot
.72805 .6043 Mdot
.3786 .51282 Mdot
.74469 .60222 Mdot
.35622 .65096 Mdot
.33937 .4387 Mdot
.66417 .61959 Mdot
.50277 .7152 Mdot
.5914 .69917 Mdot
.31102 .40922 Mdot
.34914 .64534 Mdot
.35692 .45612 Mdot
.71512 .37956 Mdot
.58676 .34717 Mdot
.31804 .41442 Mdot
.55456 .72432 Mdot
.35167 .44723 Mdot
.633 .6414 Mdot
.48106 .28996 Mdot
.54679 .72871 Mdot
.73515 .36075 Mdot
.67945 .44125 Mdot
.70135 .41195 Mdot
.57816 .36203 Mdot
.35316 .65914 Mdot
.46425 .68629 Mdot
.55189 .74469 Mdot
.27114 .56459 Mdot
.68598 .44644 Mdot
.4695 .26596 Mdot
.36015 .44543 Mdot
.52161 .33718 Mdot
.7264 .61989 Mdot
.39356 .67497 Mdot
.28488 .54246 Mdot
.44819 .27512 Mdot
.25495 .49214 Mdot
.55415 .33875 Mdot
.34257 .49033 Mdot
.43642 .25146 Mdot
.67119 .42964 Mdot
.32175 .62484 Mdot
.49839 .30803 Mdot
.73057 .34914 Mdot
.67962 .46686 Mdot
.70325 .60559 Mdot
.70523 .40917 Mdot
.43244 .23497 Mdot
.54722 .32485 Mdot
.54592 .724 Mdot
.33677 .47582 Mdot
.54668 .33309 Mdot
.69236 .43724 Mdot
.57112 .3623 Mdot
.33989 .4943 Mdot
.50488 .7078 Mdot
.71291 .45595 Mdot
.34338 .43647 Mdot
.35706 .63625 Mdot
.40926 .68216 Mdot
.72934 .36581 Mdot
.26629 .56764 Mdot
.4218 .23205 Mdot
.69588 .48653 Mdot
.68847 .47102 Mdot
.33655 .42012 Mdot
.4613 .24483 Mdot
.34101 .45969 Mdot
.64937 .61364 Mdot
.28351 .58891 Mdot
.72342 .60542 Mdot
.27536 .40736 Mdot
.34899 .42629 Mdot
.25782 .57444 Mdot
.5027 .69113 Mdot
.49493 .3349 Mdot
.25876 .41904 Mdot
.3284 .47426 Mdot
.57299 .72578 Mdot
.29065 .57334 Mdot
.2206 .47446 Mdot
.42481 .68489 Mdot
.48291 .29306 Mdot
.63446 .6338 Mdot
.36204 .45154 Mdot
.61564 .68332 Mdot
.47245 .26367 Mdot
.27753 .4097 Mdot
.279 .53788 Mdot
.54334 .73958 Mdot
.36061 .49071 Mdot
.53856 .72767 Mdot
.35447 .45965 Mdot
.40832 .67938 Mdot
.71196 .59755 Mdot
.3904 .50949 Mdot
.5497 .32549 Mdot
.73767 .47683 Mdot
.4174 .48992 Mdot
.47439 .27294 Mdot
.34098 .62534 Mdot
.56037 .33946 Mdot
.64776 .61082 Mdot
.69585 .60399 Mdot
.70121 .44508 Mdot
.68171 .60949 Mdot
.45192 .67504 Mdot
.72688 .36277 Mdot
.5539 .3621 Mdot
.31534 .63121 Mdot
.4377 .23032 Mdot
.72905 .6043 Mdot
.32818 .4595 Mdot
.36463 .50639 Mdot
.72159 .35745 Mdot
.66475 .41181 Mdot
.52303 .70537 Mdot
.41004 .68865 Mdot
.46442 .69467 Mdot
.4605 .27474 Mdot
.73042 .36201 Mdot
.35954 .4755 Mdot
.34617 .48461 Mdot
.66989 .4504 Mdot
.42913 .68486 Mdot
.46355 .25044 Mdot
.54456 .31294 Mdot
.65657 .63355 Mdot
.71927 .34576 Mdot
.54637 .72733 Mdot
.72878 .33777 Mdot
.71248 .37173 Mdot
.56344 .70135 Mdot
.26111 .41896 Mdot
.65344 .61668 Mdot
.73098 .33632 Mdot
.53579 .74126 Mdot
.32086 .41326 Mdot
.56778 .35299 Mdot
.57538 .36284 Mdot
.49632 .70237 Mdot
.70954 .46305 Mdot
.46517 .24637 Mdot
.36601 .48798 Mdot
.44518 .27421 Mdot
.43461 .68839 Mdot
.69845 .41641 Mdot
.54854 .35023 Mdot
.62249 .63365 Mdot
.35445 .45104 Mdot
.46945 .25795 Mdot
.65291 .61851 Mdot
.52829 .324 Mdot
.38305 .48028 Mdot
.27218 .58961 Mdot
.36053 .6488 Mdot
.6379 .63136 Mdot
.27683 .56873 Mdot
.32802 .43689 Mdot
.7118 .60907 Mdot
.50539 .29293 Mdot
.73951 .46913 Mdot
.27994 .58813 Mdot
.71163 .59577 Mdot
.66933 .45279 Mdot
.70504 .40766 Mdot
.72246 .3884 Mdot
.72859 .34639 Mdot
.70069 .61017 Mdot
.54545 .34088 Mdot
.71502 .3548 Mdot
.72308 .6069 Mdot
.26403 .55639 Mdot
.36139 .45034 Mdot
.26258 .542 Mdot
.52707 .32279 Mdot
.52938 .33566 Mdot
.43097 .69253 Mdot
.32827 .63476 Mdot
.55095 .35008 Mdot
.32485 .45099 Mdot
.47368 .69276 Mdot
.66552 .61317 Mdot
.42061 .20707 Mdot
.66228 .63193 Mdot
.3198 .62545 Mdot
.70569 .48759 Mdot
.72556 .36632 Mdot
.33613 .47409 Mdot
.62875 .64964 Mdot
.40703 .20777 Mdot
.36258 .45322 Mdot
.35019 .63527 Mdot
.27712 .40575 Mdot
.34807 .42972 Mdot
.45859 .67233 Mdot
.52811 .34369 Mdot
.47084 .69069 Mdot
.6569 .61759 Mdot
.48432 .29127 Mdot
.45643 .30722 Mdot
.63727 .63397 Mdot
.34742 .46469 Mdot
.58809 .35319 Mdot
.33447 .46482 Mdot
.32441 .47001 Mdot
.38398 .49959 Mdot
.47415 .29534 Mdot
.70653 .45133 Mdot
.43721 .23375 Mdot
.5502 .71512 Mdot
.3968 .67391 Mdot
.47484 .2712 Mdot
.25978 .54788 Mdot
.28875 .56747 Mdot
.66195 .41762 Mdot
.54918 .72246 Mdot
.48485 .2781 Mdot
.63143 .63161 Mdot
.2259 .48487 Mdot
.25567 .55864 Mdot
.6775 .61172 Mdot
.33684 .48918 Mdot
.55416 .74458 Mdot
.42941 .68991 Mdot
.73049 .59939 Mdot
.5455 .74451 Mdot
.27928 .56874 Mdot
.34892 .65142 Mdot
.65733 .63191 Mdot
.25197 .43107 Mdot
.72561 .6035 Mdot
.42807 .4642 Mdot
.35129 .64201 Mdot
.54671 .73038 Mdot
.40503 .5061 Mdot
.49709 .71847 Mdot
.53134 .32979 Mdot
.38237 .4956 Mdot
.47028 .26802 Mdot
.27677 .56395 Mdot
.73807 .35798 Mdot
.48958 .68516 Mdot
.53167 .73509 Mdot
.65566 .63816 Mdot
.55244 .73959 Mdot
.50037 .69976 Mdot
.64397 .6027 Mdot
.44086 .6707 Mdot
.34497 .46276 Mdot
.39228 .6835 Mdot
.46455 .68439 Mdot
.6529 .62696 Mdot
.46028 .25635 Mdot
.43956 .67895 Mdot
.71447 .36625 Mdot
.33628 .42567 Mdot
.6985 .4264 Mdot
.47943 .25555 Mdot
.42209 .6773 Mdot
.47137 .27115 Mdot
.69752 .43783 Mdot
.49086 .30431 Mdot
.70176 .62549 Mdot
.74081 .60435 Mdot
.52763 .3094 Mdot
.72203 .59294 Mdot
.55766 .71747 Mdot
.7344 .34732 Mdot
.36948 .49892 Mdot
.35288 .49726 Mdot
.47329 .24689 Mdot
.56001 .71532 Mdot
.72427 .58824 Mdot
.55456 .34786 Mdot
.4529 .69966 Mdot
.62513 .62892 Mdot
.72246 .37011 Mdot
.29322 .56529 Mdot
.70564 .60323 Mdot
.52138 .32757 Mdot
.55612 .33801 Mdot
.33183 .46361 Mdot
.29198 .40602 Mdot
.44169 .26199 Mdot
.73542 .44362 Mdot
.32344 .6492 Mdot
.667 .43109 Mdot
.35502 .47951 Mdot
.32609 .6471 Mdot
.32154 .4442 Mdot
.42881 .2328 Mdot
.69599 .61326 Mdot
.54262 .71991 Mdot
.48587 .28744 Mdot
.679 .44088 Mdot
.29749 .57172 Mdot
.31972 .4081 Mdot
.27437 .57308 Mdot
.70988 .47686 Mdot
.56629 .72463 Mdot
.69942 .45541 Mdot
.70978 .60944 Mdot
.47927 .27588 Mdot
.35389 .65448 Mdot
.52633 .32242 Mdot
.71279 .43456 Mdot
.66199 .60496 Mdot
.73697 .35592 Mdot
.69544 .6048 Mdot
.55938 .33667 Mdot
.28028 .58228 Mdot
.72232 .44523 Mdot
.57269 .35069 Mdot
.46569 .70362 Mdot
.37371 .44939 Mdot
.53439 .69386 Mdot
.70988 .46973 Mdot
.48924 .23699 Mdot
.65384 .62154 Mdot
.68053 .62532 Mdot
.42385 .48309 Mdot
.38936 .21513 Mdot
.3825 .50589 Mdot
.746 .59101 Mdot
.71497 .6088 Mdot
.6402 .62803 Mdot
.69868 .45193 Mdot
.50104 .71282 Mdot
.46255 .66206 Mdot
.71562 .47121 Mdot
.27193 .42109 Mdot
.5204 .73706 Mdot
.25338 .57928 Mdot
.72147 .4495 Mdot
.33498 .64216 Mdot
.44807 .70371 Mdot
.48629 .27295 Mdot
.28806 .41352 Mdot
.71008 .60295 Mdot
.36446 .46316 Mdot
.6122 .69785 Mdot
.69677 .44387 Mdot
.57401 .35705 Mdot
.64832 .64208 Mdot
.36237 .50759 Mdot
.35315 .48761 Mdot
.33905 .44713 Mdot
.47132 .24602 Mdot
.44705 .70151 Mdot
.36458 .47448 Mdot
.38076 .47038 Mdot
.33644 .66194 Mdot
.72569 .38295 Mdot
.43496 .23605 Mdot
.29962 .39697 Mdot
.66877 .46236 Mdot
.44502 .69821 Mdot
.36914 .51336 Mdot
.69049 .61942 Mdot
.32769 .63679 Mdot
.66114 .62626 Mdot
.62651 .62183 Mdot
.71683 .34725 Mdot
.55815 .72638 Mdot
.3384 .6599 Mdot
.68775 .40397 Mdot
.49747 .68594 Mdot
.33078 .653 Mdot
.40521 .68446 Mdot
.64618 .64134 Mdot
.38185 .22358 Mdot
.68685 .62392 Mdot
.57232 .36379 Mdot
.45205 .67396 Mdot
.57678 .74041 Mdot
.26934 .55895 Mdot
.5207 .72456 Mdot
.72286 .35659 Mdot
.4665 .687 Mdot
.68516 .31409 Mdot
.47227 .69501 Mdot
.64934 .62501 Mdot
.72775 .60159 Mdot
.3323 .64799 Mdot
.34592 .46838 Mdot
.28509 .55086 Mdot
.55527 .34854 Mdot
.27736 .58172 Mdot
.69721 .47319 Mdot
.71455 .36213 Mdot
.75086 .59067 Mdot
.45917 .67352 Mdot
.67524 .60569 Mdot
.35374 .48659 Mdot
.35224 .64373 Mdot
.33519 .41488 Mdot
.71398 .59839 Mdot
.33978 .67289 Mdot
.33436 .44943 Mdot
.33546 .65167 Mdot
.71332 .47879 Mdot
.66307 .4362 Mdot
.54487 .69487 Mdot
.71631 .34854 Mdot
.32916 .47313 Mdot
.45323 .2646 Mdot
.43088 .24433 Mdot
.3152 .40864 Mdot
.72239 .48943 Mdot
.28465 .56962 Mdot
.3281 .45788 Mdot
.29685 .57568 Mdot
.71617 .47602 Mdot
.55793 .36758 Mdot
.68957 .43884 Mdot
.41319 .67369 Mdot
.57397 .33544 Mdot
.68513 .46375 Mdot
.29251 .55145 Mdot
.55079 .33412 Mdot
.73941 .46625 Mdot
.47371 .26224 Mdot
.32487 .44278 Mdot
.43196 .46982 Mdot
.71664 .4329 Mdot
.6456 .62073 Mdot
.441 .67585 Mdot
.66712 .62306 Mdot
.665 .44747 Mdot
.27142 .4137 Mdot
.52727 .32758 Mdot
.68245 .62031 Mdot
.35414 .66682 Mdot
.45012 .25851 Mdot
.68812 .62522 Mdot
.35311 .6609 Mdot
.31506 .40732 Mdot
.39963 .20973 Mdot
.35561 .50519 Mdot
.7151 .35951 Mdot
.72837 .60578 Mdot
.50577 .30229 Mdot
.33905 .47737 Mdot
.69514 .42075 Mdot
.43881 .26735 Mdot
.33304 .45974 Mdot
.73282 .36615 Mdot
.33829 .43215 Mdot
.43692 .25191 Mdot
.45201 .68602 Mdot
.28431 .5894 Mdot
.45049 .23095 Mdot
.48511 .2876 Mdot
.39267 .5064 Mdot
.33683 .41504 Mdot
.72985 .42929 Mdot
.54521 .73987 Mdot
.32267 .41672 Mdot
.46699 .24125 Mdot
.48106 .68943 Mdot
.46411 .68137 Mdot
.32147 .62407 Mdot
.62135 .6415 Mdot
.7105 .45913 Mdot
.44318 .25305 Mdot
.71369 .37961 Mdot
.36123 .45343 Mdot
.33321 .62427 Mdot
.47923 .26819 Mdot
.6599 .60856 Mdot
.34878 .6585 Mdot
.73068 .58475 Mdot
.38477 .48972 Mdot
.68496 .62693 Mdot
.37318 .51407 Mdot
.39983 .50967 Mdot
.4625 .68969 Mdot
.61068 .69297 Mdot
.70147 .60134 Mdot
.68218 .43632 Mdot
.54735 .34896 Mdot
.39533 .67505 Mdot
.4688 .25849 Mdot
.46239 .66076 Mdot
.34607 .49761 Mdot
.35771 .47038 Mdot
.46376 .68853 Mdot
.31812 .40704 Mdot
.477 .6812 Mdot
.71425 .37332 Mdot
.38755 .21617 Mdot
.54159 .72285 Mdot
.5374 .73643 Mdot
.35978 .62832 Mdot
.71145 .49345 Mdot
.48877 .69338 Mdot
.36298 .45333 Mdot
.66329 .43835 Mdot
.51731 .29831 Mdot
.45654 .24884 Mdot
.5012 .302 Mdot
.49153 .69018 Mdot
.28237 .53415 Mdot
.35828 .65018 Mdot
.30914 .41401 Mdot
.26007 .49404 Mdot
.71016 .61043 Mdot
.37338 .48324 Mdot
.55581 .34455 Mdot
.69358 .43957 Mdot
.34384 .50454 Mdot
.32441 .44882 Mdot
.53956 .71852 Mdot
.4918 .29192 Mdot
.66348 .60176 Mdot
.57513 .34964 Mdot
.7117 .42088 Mdot
.46566 .27416 Mdot
.51788 .7101 Mdot
.41971 .48805 Mdot
.54992 .31929 Mdot
.53649 .35524 Mdot
.33295 .48222 Mdot
.32875 .41993 Mdot
.52573 .31735 Mdot
.64853 .63259 Mdot
.68304 .43429 Mdot
.57404 .34093 Mdot
.2789 .5653 Mdot
.29052 .58496 Mdot
.34807 .48865 Mdot
.50199 .72096 Mdot
.65725 .60497 Mdot
.52776 .33076 Mdot
.73181 .3378 Mdot
.35969 .44395 Mdot
.2623 .55153 Mdot
.60306 .36707 Mdot
.55088 .34302 Mdot
.46497 .66283 Mdot
.44185 .23697 Mdot
.35079 .64171 Mdot
.38595 .48469 Mdot
.27019 .5833 Mdot
.37075 .51092 Mdot
.67022 .43273 Mdot
.6287 .62554 Mdot
.51551 .30843 Mdot
.68831 .44594 Mdot
.46391 .68158 Mdot
.30868 .41312 Mdot
.56512 .73104 Mdot
.55284 .74371 Mdot
.5065 .69926 Mdot
.63691 .63806 Mdot
.39266 .67161 Mdot
.53073 .31744 Mdot
.35351 .50106 Mdot
.71734 .61305 Mdot
.49102 .69394 Mdot
.26229 .57806 Mdot
.48719 .68817 Mdot
.54832 .71149 Mdot
.26971 .58626 Mdot
.33962 .65061 Mdot
.38182 .46982 Mdot
.36338 .51393 Mdot
.45119 .23789 Mdot
.54622 .74928 Mdot
.25834 .55679 Mdot
.36049 .47261 Mdot
.33741 .48002 Mdot
.33084 .64552 Mdot
.46762 .29198 Mdot
.30773 .40338 Mdot
.34667 .49697 Mdot
.29198 .39688 Mdot
.26213 .57568 Mdot
.57043 .72165 Mdot
.71644 .62379 Mdot
.32037 .6241 Mdot
.6856 .47845 Mdot
.44148 .68852 Mdot
.48801 .27767 Mdot
.46095 .66827 Mdot
.36271 .65154 Mdot
.63573 .62259 Mdot
.53296 .7387 Mdot
.71301 .44705 Mdot
.64775 .61825 Mdot
.7255 .60345 Mdot
.33082 .64167 Mdot
.6786 .43206 Mdot
.49176 .29391 Mdot
.70027 .60709 Mdot
.32153 .6618 Mdot
.64823 .62477 Mdot
.5504 .69994 Mdot
.28153 .58118 Mdot
.38482 .48253 Mdot
.54 .33769 Mdot
.5108 .30869 Mdot
.70841 .60841 Mdot
.45961 .26201 Mdot
.34742 .65935 Mdot
.44301 .67834 Mdot
.4532 .25786 Mdot
.43747 .69996 Mdot
.72314 .37229 Mdot
.43683 .69312 Mdot
.71961 .36111 Mdot
.51827 .72186 Mdot
.28622 .41316 Mdot
.48895 .28932 Mdot
.51627 .32146 Mdot
.27462 .54786 Mdot
.54654 .35075 Mdot
.34437 .50319 Mdot
.34192 .65991 Mdot
.34465 .46106 Mdot
.6948 .49018 Mdot
.47642 .24941 Mdot
.46967 .68758 Mdot
.44795 .29545 Mdot
.66802 .6103 Mdot
.27361 .57041 Mdot
.57681 .35456 Mdot
.35013 .64545 Mdot
.48166 .68531 Mdot
.52862 .71434 Mdot
.40848 .6774 Mdot
.69454 .48637 Mdot
.49073 .32805 Mdot
.35082 .48411 Mdot
.45315 .29506 Mdot
.71681 .60666 Mdot
.72598 .59236 Mdot
.70622 .43296 Mdot
.38079 .23165 Mdot
.68714 .44908 Mdot
.51849 .29381 Mdot
.51715 .71891 Mdot
.45752 .27977 Mdot
.34934 .47433 Mdot
.42807 .68036 Mdot
.46082 .66132 Mdot
.49857 .29192 Mdot
.43752 .23613 Mdot
.72679 .59406 Mdot
.72432 .61175 Mdot
.56085 .36154 Mdot
.26188 .57397 Mdot
.25975 .57529 Mdot
.36592 .50244 Mdot
.70425 .61144 Mdot
.34488 .64751 Mdot
.7036 .62605 Mdot
.3445 .63133 Mdot
.47191 .24417 Mdot
.68499 .46897 Mdot
.7397 .55215 Mdot
.43624 .68542 Mdot
.30807 .41378 Mdot
.52031 .6963 Mdot
.37351 .45051 Mdot
.68709 .61422 Mdot
.50503 .28989 Mdot
.70347 .45155 Mdot
.61936 .65992 Mdot
.68035 .46252 Mdot
.41839 .25359 Mdot
.27088 .53585 Mdot
.65126 .64041 Mdot
.27606 .57755 Mdot
.67851 .4166 Mdot
.3593 .51308 Mdot
.56745 .33473 Mdot
.588 .35316 Mdot
.3677 .65796 Mdot
.41027 .68635 Mdot
.44853 .23633 Mdot
.34971 .4748 Mdot
.48827 .7049 Mdot
.34905 .47779 Mdot
.34921 .47994 Mdot
.32357 .46911 Mdot
.7173 .59943 Mdot
.28076 .57779 Mdot
.34549 .46593 Mdot
.72286 .34578 Mdot
.51604 .301 Mdot
.71966 .43334 Mdot
.46187 .69035 Mdot
.45086 .25387 Mdot
.44163 .69091 Mdot
.28458 .55711 Mdot
.66276 .63261 Mdot
.44558 .7015 Mdot
.34006 .64186 Mdot
.48899 .68544 Mdot
.68262 .62207 Mdot
.4707 .25186 Mdot
.55718 .34198 Mdot
.59599 .7228 Mdot
.7274 .34899 Mdot
.56179 .3553 Mdot
.72864 .36939 Mdot
.36519 .51189 Mdot
.54842 .72523 Mdot
.54974 .3514 Mdot
.64566 .60635 Mdot
.67108 .42306 Mdot
.38786 .4836 Mdot
.35113 .44424 Mdot
.70694 .47643 Mdot
.54461 .33665 Mdot
.27783 .56356 Mdot
.29076 .56888 Mdot
.67939 .41553 Mdot
.61436 .63158 Mdot
.71668 .60479 Mdot
.4581 .25349 Mdot
.56276 .71846 Mdot
.5343 .71593 Mdot
.66525 .61 Mdot
.623 .65831 Mdot
.34862 .43779 Mdot
.34624 .43962 Mdot
.27683 .55283 Mdot
.37891 .51661 Mdot
.73426 .3406 Mdot
.56244 .35341 Mdot
.52792 .72702 Mdot
.34022 .65977 Mdot
.32223 .63722 Mdot
.34952 .46842 Mdot
.26708 .41755 Mdot
.71431 .46265 Mdot
.35322 .64033 Mdot
.43728 .25339 Mdot
.39962 .67096 Mdot
.33404 .42804 Mdot
.47082 .24289 Mdot
.52649 .71691 Mdot
.73816 .45408 Mdot
.64473 .62188 Mdot
.68592 .40748 Mdot
.68654 .40564 Mdot
.62584 .33966 Mdot
.44096 .68673 Mdot
.56133 .35508 Mdot
.73932 .34202 Mdot
.58536 .35795 Mdot
.43753 .23902 Mdot
.30308 .40729 Mdot
.72369 .35398 Mdot
.71544 .42435 Mdot
.63968 .64372 Mdot
.37666 .49352 Mdot
.32657 .43293 Mdot
.70862 .59671 Mdot
.33109 .47119 Mdot
.4772 .27038 Mdot
.71611 .6171 Mdot
.5347 .73944 Mdot
.4581 .24167 Mdot
.69414 .6197 Mdot
.53542 .71453 Mdot
.33228 .6418 Mdot
.26129 .57624 Mdot
.45135 .67804 Mdot
.51415 .71139 Mdot
.34932 .43707 Mdot
.72219 .34055 Mdot
.5348 .72206 Mdot
.43929 .67306 Mdot
.40545 .67908 Mdot
.69827 .41302 Mdot
.43324 .25596 Mdot
.63058 .64219 Mdot
.34111 .45796 Mdot
.69194 .47777 Mdot
.44848 .2664 Mdot
.52829 .73514 Mdot
.32162 .43925 Mdot
.36154 .45527 Mdot
.45099 .25989 Mdot
.43129 .23665 Mdot
.4572 .25937 Mdot
.727 .59936 Mdot
.33681 .6415 Mdot
.4764 .68364 Mdot
.69154 .61119 Mdot
.48543 .27323 Mdot
.43508 .22867 Mdot
.52695 .36623 Mdot
.34587 .43638 Mdot
.4309 .23227 Mdot
.3958 .67297 Mdot
.29351 .54477 Mdot
.58577 .35738 Mdot
.49839 .24793 Mdot
.71692 .49436 Mdot
.51856 .28073 Mdot
.62919 .62676 Mdot
.34023 .63169 Mdot
.45779 .24808 Mdot
.55012 .32998 Mdot
.35011 .4418 Mdot
.35029 .42974 Mdot
.45551 .26555 Mdot
.26973 .41119 Mdot
.54515 .71758 Mdot
.5319 .69263 Mdot
.44971 .25551 Mdot
.68342 .41819 Mdot
.71724 .47247 Mdot
.69238 .45809 Mdot
.34377 .48863 Mdot
.25709 .58757 Mdot
.23588 .48843 Mdot
.40914 .67586 Mdot
.72333 .6092 Mdot
.52164 .71738 Mdot
.43284 .70191 Mdot
.46788 .68345 Mdot
.66631 .42859 Mdot
.46007 .2622 Mdot
.50058 .72048 Mdot
.72851 .60012 Mdot
.70788 .60749 Mdot
.71789 .43372 Mdot
.68492 .44611 Mdot
.7026 .46434 Mdot
.42192 .67886 Mdot
.50015 .70533 Mdot
.27473 .58399 Mdot
.54946 .74383 Mdot
.66912 .46571 Mdot
.71456 .37219 Mdot
.71944 .43824 Mdot
.65748 .62514 Mdot
.50722 .72132 Mdot
.33818 .4309 Mdot
.39298 .5189 Mdot
.71752 .47333 Mdot
.48279 .26547 Mdot
.39114 .68005 Mdot
.39066 .21431 Mdot
.33161 .62685 Mdot
.64603 .60966 Mdot
.54133 .32806 Mdot
.34115 .44874 Mdot
.68524 .43462 Mdot
.50315 .2567 Mdot
.53074 .34662 Mdot
.26952 .57019 Mdot
.37736 .67328 Mdot
.64142 .61598 Mdot
.29163 .57151 Mdot
.56254 .33252 Mdot
.34504 .66379 Mdot
.71218 .61695 Mdot
.71375 .43454 Mdot
.72387 .38603 Mdot
.42808 .69112 Mdot
.30246 .41155 Mdot
.53385 .32466 Mdot
.37163 .49848 Mdot
.68686 .46362 Mdot
.458 .24227 Mdot
.69429 .46856 Mdot
.56905 .71938 Mdot
.7073 .41757 Mdot
.32979 .43845 Mdot
.48009 .68691 Mdot
.7136 .60645 Mdot
.22868 .48493 Mdot
.44948 .30027 Mdot
.702 .42168 Mdot
.5183 .31947 Mdot
.32539 .63777 Mdot
.31451 .63149 Mdot
.51069 .30789 Mdot
.32629 .43678 Mdot
.66441 .62029 Mdot
.47356 .67992 Mdot
.66675 .60711 Mdot
.43472 .26012 Mdot
.59106 .73347 Mdot
.64358 .62194 Mdot
.25604 .58899 Mdot
.46587 .24641 Mdot
.26942 .41458 Mdot
.32845 .44648 Mdot
.63708 .6117 Mdot
.27744 .57303 Mdot
.48768 .70497 Mdot
.2926 .55353 Mdot
.38237 .4817 Mdot
.66593 .61466 Mdot
.5556 .36305 Mdot
.28895 .57286 Mdot
.44154 .2712 Mdot
.70118 .60946 Mdot
.29274 .58364 Mdot
.56594 .35293 Mdot
.47192 .27824 Mdot
.46408 .24233 Mdot
.46565 .27151 Mdot
.33532 .44417 Mdot
.40089 .50682 Mdot
.48767 .28719 Mdot
.6427 .60302 Mdot
.48352 .28571 Mdot
.51208 .28234 Mdot
.73226 .58902 Mdot
.43252 .23527 Mdot
.32729 .46013 Mdot
.34349 .63111 Mdot
.33867 .63191 Mdot
.69898 .42972 Mdot
.59923 .72513 Mdot
.71695 .35346 Mdot
.35931 .47698 Mdot
.4502 .71121 Mdot
.46297 .68649 Mdot
.52224 .31285 Mdot
.3805 .47586 Mdot
.36063 .65566 Mdot
.45776 .67787 Mdot
.27588 .55574 Mdot
.4422 .6956 Mdot
.56198 .32906 Mdot
.33547 .44168 Mdot
.45167 .68844 Mdot
.50173 .69638 Mdot
.2588 .42045 Mdot
.45132 .69912 Mdot
.51872 .72673 Mdot
.72478 .60701 Mdot
.62896 .63093 Mdot
.6653 .61857 Mdot
.68172 .4438 Mdot
.53524 .73625 Mdot
.31375 .41537 Mdot
.68315 .43724 Mdot
.33866 .49115 Mdot
.66586 .61263 Mdot
.38748 .50576 Mdot
.53767 .73705 Mdot
.32818 .453 Mdot
.25147 .57047 Mdot
.72958 .37047 Mdot
.45187 .26084 Mdot
.41259 .69036 Mdot
.71753 .38903 Mdot
.7028 .60554 Mdot
.5778 .72989 Mdot
.50869 .28714 Mdot
.34725 .66519 Mdot
.32067 .42917 Mdot
.32221 .46908 Mdot
.34605 .66483 Mdot
.2763 .53377 Mdot
.53956 .35605 Mdot
.6791 .44117 Mdot
.69364 .40702 Mdot
.34238 .42876 Mdot
.53435 .7321 Mdot
.43605 .25699 Mdot
.45998 .23526 Mdot
.49925 .30924 Mdot
.28878 .56458 Mdot
.38091 .47103 Mdot
.3813 .50179 Mdot
.30664 .41322 Mdot
.70541 .43765 Mdot
.55963 .36742 Mdot
.27067 .55933 Mdot
.47553 .27586 Mdot
.31901 .41924 Mdot
.45808 .69066 Mdot
.52638 .73648 Mdot
.7104 .4666 Mdot
.73471 .61638 Mdot
.56024 .3228 Mdot
.72272 .44815 Mdot
.34123 .42826 Mdot
.32358 .6479 Mdot
.7326 .61285 Mdot
.53217 .70777 Mdot
.46672 .27766 Mdot
.688 .43557 Mdot
.47439 .28757 Mdot
.55132 .7403 Mdot
.5277 .73444 Mdot
.33431 .41577 Mdot
.47586 .31795 Mdot
.71122 .42832 Mdot
.34767 .48709 Mdot
.70496 .47646 Mdot
.72078 .36272 Mdot
.6981 .62582 Mdot
.32215 .4162 Mdot
.47106 .66527 Mdot
.66702 .62115 Mdot
.35726 .48297 Mdot
.33225 .63544 Mdot
.34936 .65746 Mdot
.67933 .41908 Mdot
.49139 .28078 Mdot
.47634 .28188 Mdot
.58019 .71872 Mdot
.50437 .7382 Mdot
.38041 .49732 Mdot
.69914 .41527 Mdot
.33343 .67041 Mdot
.63867 .62428 Mdot
.51471 .71938 Mdot
.71926 .56908 Mdot
.65043 .62761 Mdot
.34209 .43309 Mdot
.47463 .27056 Mdot
.52685 .71062 Mdot
.58643 .35705 Mdot
.21808 .45894 Mdot
.51553 .32952 Mdot
.48982 .3266 Mdot
.57226 .34899 Mdot
.71541 .58738 Mdot
.70288 .46849 Mdot
.48625 .68923 Mdot
.64972 .60664 Mdot
.63685 .62346 Mdot
.71233 .38488 Mdot
.41019 .68034 Mdot
.55298 .69764 Mdot
.38966 .6718 Mdot
.7273 .34989 Mdot
.46486 .26454 Mdot
.28923 .54579 Mdot
.69219 .45639 Mdot
.74035 .36012 Mdot
.73112 .59496 Mdot
.72503 .59225 Mdot
.49606 .70786 Mdot
.36417 .46573 Mdot
.40621 .67844 Mdot
.34269 .49775 Mdot
.30217 .40767 Mdot
.66049 .60994 Mdot
.5155 .71983 Mdot
.74394 .59632 Mdot
.33728 .42226 Mdot
.35251 .45587 Mdot
.66194 .44538 Mdot
.55845 .34837 Mdot
.65726 .42643 Mdot
.31945 .4131 Mdot
.68222 .45272 Mdot
.52176 .69989 Mdot
.54969 .32703 Mdot
.25987 .55315 Mdot
.73439 .60802 Mdot
.52711 .3287 Mdot
.55555 .32763 Mdot
.31054 .44305 Mdot
.43885 .69305 Mdot
.56974 .7363 Mdot
.43261 .24679 Mdot
.7484 .5983 Mdot
.70033 .62274 Mdot
.72766 .585 Mdot
.3401 .43061 Mdot
.73557 .60143 Mdot
.5541 .31626 Mdot
.35778 .48529 Mdot
.3335 .65428 Mdot
.42699 .69371 Mdot
.37468 .49964 Mdot
.35968 .64136 Mdot
.65396 .62326 Mdot
.59923 .36901 Mdot
.37942 .49705 Mdot
.70902 .47192 Mdot
.49982 .71118 Mdot
.42516 .68628 Mdot
.44903 .24288 Mdot
.71031 .59797 Mdot
.38463 .22193 Mdot
.51379 .7192 Mdot
.34639 .44221 Mdot
.63995 .62672 Mdot
.53866 .32658 Mdot
.53889 .34068 Mdot
.51405 .32013 Mdot
.51901 .73352 Mdot
.54668 .3285 Mdot
.51599 .69654 Mdot
.27959 .55572 Mdot
.30793 .40756 Mdot
.63931 .63723 Mdot
.46699 .26579 Mdot
.47251 .30014 Mdot
.71958 .37104 Mdot
.26164 .56868 Mdot
.30204 .40528 Mdot
.58652 .74169 Mdot
.47175 .26656 Mdot
.34412 .45669 Mdot
.53987 .3567 Mdot
.26813 .59986 Mdot
.43459 .20907 Mdot
.56962 .35588 Mdot
.31979 .63694 Mdot
.55204 .71549 Mdot
.55069 .35353 Mdot
.53068 .74005 Mdot
.34633 .46033 Mdot
.27274 .5684 Mdot
.57235 .73019 Mdot
.59523 .7095 Mdot
.55084 .319 Mdot
.69142 .6215 Mdot
.27997 .57111 Mdot
.32624 .46643 Mdot
.25468 .58267 Mdot
.53469 .33018 Mdot
.60454 .68798 Mdot
.69638 .4783 Mdot
.71115 .36227 Mdot
.73848 .33833 Mdot
.69759 .60261 Mdot
.75213 .59316 Mdot
.34911 .42519 Mdot
.39699 .66257 Mdot
.25582 .5849 Mdot
.66946 .62485 Mdot
.28773 .53422 Mdot
.34583 .46808 Mdot
.33601 .48543 Mdot
.70529 .47671 Mdot
.64343 .64242 Mdot
.32085 .62439 Mdot
.27234 .56099 Mdot
.48621 .26768 Mdot
.54276 .74333 Mdot
.33873 .45998 Mdot
.58555 .7414 Mdot
.68189 .41677 Mdot
.59435 .73543 Mdot
.32826 .46178 Mdot
.55871 .34806 Mdot
.74311 .60387 Mdot
.71906 .60554 Mdot
.68082 .42329 Mdot
.68437 .42177 Mdot
.32705 .46858 Mdot
.67472 .61037 Mdot
.28772 .5356 Mdot
.28886 .56954 Mdot
.54613 .33494 Mdot
.44058 .2508 Mdot
.33961 .49862 Mdot
.5451 .69557 Mdot
.46047 .31193 Mdot
.34686 .48882 Mdot
.56263 .73613 Mdot
.70417 .46048 Mdot
.72267 .37402 Mdot
.53011 .71903 Mdot
.72585 .36837 Mdot
.59439 .73336 Mdot
.40033 .50298 Mdot
.43634 .2442 Mdot
.31984 .60994 Mdot
.48467 .28871 Mdot
.52862 .32944 Mdot
.34443 .4358 Mdot
.73296 .43839 Mdot
.73988 .33857 Mdot
.29473 .60959 Mdot
.6515 .61453 Mdot
.57569 .3631 Mdot
.34223 .64588 Mdot
.48239 .25805 Mdot
.69428 .4423 Mdot
.58172 .34242 Mdot
.31914 .41662 Mdot
.43777 .68773 Mdot
.3313 .62284 Mdot
.58091 .35134 Mdot
.53004 .33337 Mdot
.56984 .33019 Mdot
.69385 .6197 Mdot
.43137 .67112 Mdot
.72947 .59409 Mdot
.72429 .3777 Mdot
.27677 .58372 Mdot
.34422 .44329 Mdot
.52074 .71843 Mdot
.35881 .49765 Mdot
.67276 .61794 Mdot
.40044 .69438 Mdot
.45992 .25948 Mdot
.55598 .32503 Mdot
.61722 .67296 Mdot
.58762 .35563 Mdot
.33516 .66006 Mdot
.32021 .65054 Mdot
.46438 .69086 Mdot
.67242 .62619 Mdot
.36628 .51716 Mdot
.69975 .40492 Mdot
.47015 .27982 Mdot
.72777 .60217 Mdot
.33143 .6555 Mdot
.32634 .44607 Mdot
.46945 .26672 Mdot
.72473 .59305 Mdot
.49124 .3083 Mdot
.67102 .6037 Mdot
.5157 .33416 Mdot
.3086 .61295 Mdot
.33189 .46161 Mdot
.56262 .34934 Mdot
.45962 .68178 Mdot
.71927 .61023 Mdot
.41647 .68515 Mdot
.56188 .32942 Mdot
.7186 .36771 Mdot
.72766 .60438 Mdot
.32138 .42217 Mdot
.46219 .669 Mdot
.48778 .70673 Mdot
.44225 .6714 Mdot
.65681 .34181 Mdot
.71835 .35661 Mdot
.70551 .46606 Mdot
.65555 .62679 Mdot
.69063 .47837 Mdot
.46667 .24653 Mdot
.28763 .54433 Mdot
.69307 .41982 Mdot
.42755 .67204 Mdot
.67696 .45853 Mdot
.27304 .54202 Mdot
.68577 .62256 Mdot
.72274 .45842 Mdot
.35981 .50418 Mdot
.33419 .63718 Mdot
.53249 .34041 Mdot
.48122 .2976 Mdot
.27962 .55802 Mdot
.36846 .47706 Mdot
.5615 .34195 Mdot
.32894 .45688 Mdot
.67327 .61635 Mdot
.23137 .4837 Mdot
.26892 .58398 Mdot
.72239 .36655 Mdot
.59206 .719 Mdot
.69134 .40708 Mdot
.42136 .22934 Mdot
.35431 .49377 Mdot
.33075 .45358 Mdot
.34718 .65397 Mdot
.39205 .68592 Mdot
.7193 .60032 Mdot
.27859 .58541 Mdot
.73002 .354 Mdot
.47806 .6904 Mdot
.47219 .69179 Mdot
.30422 .41544 Mdot
.56408 .35122 Mdot
.62571 .62747 Mdot
.333 .44125 Mdot
.5837 .3585 Mdot
.3809 .48183 Mdot
.70424 .59682 Mdot
.71735 .35632 Mdot
.73734 .36354 Mdot
.47637 .6956 Mdot
.71369 .47544 Mdot
.34855 .65309 Mdot
.54438 .3287 Mdot
.73809 .33636 Mdot
.71621 .59908 Mdot
.47096 .28106 Mdot
.34093 .4905 Mdot
.26352 .41672 Mdot
.71416 .47603 Mdot
.67959 .43371 Mdot
.28698 .53572 Mdot
.58773 .74196 Mdot
.50375 .34446 Mdot
.71033 .61394 Mdot
.45945 .69149 Mdot
.42874 .46956 Mdot
.40404 .34203 Mdot
.63322 .63162 Mdot
.32849 .65023 Mdot
.71681 .46951 Mdot
.61664 .35786 Mdot
.46383 .68036 Mdot
.46884 .27988 Mdot
.36169 .49925 Mdot
.47097 .68904 Mdot
.73257 .34382 Mdot
.46029 .67324 Mdot
.55119 .34951 Mdot
.68361 .62276 Mdot
.69907 .4399 Mdot
.64105 .64297 Mdot
.46728 .66407 Mdot
.46276 .26255 Mdot
.29635 .41485 Mdot
.34416 .62966 Mdot
.44135 .70049 Mdot
.33615 .64459 Mdot
.53311 .31048 Mdot
.33368 .64106 Mdot
.46285 .69364 Mdot
.32797 .44766 Mdot
.37598 .51071 Mdot
.71665 .38041 Mdot
.33151 .47922 Mdot
.35963 .44581 Mdot
.25145 .57193 Mdot
.34837 .49373 Mdot
.34957 .48072 Mdot
.3277 .41798 Mdot
.56365 .72659 Mdot
.38025 .48674 Mdot
.50725 .70744 Mdot
.54667 .70668 Mdot
.72568 .37603 Mdot
.47734 .25031 Mdot
.4322 .23996 Mdot
.38183 .48969 Mdot
.26465 .41731 Mdot
.41019 .68332 Mdot
.50362 .72038 Mdot
.71452 .6071 Mdot
.26733 .57935 Mdot
.50117 .34133 Mdot
.38245 .50744 Mdot
.69948 .42895 Mdot
.68585 .41603 Mdot
.35322 .50689 Mdot
.39224 .21283 Mdot
.32335 .40753 Mdot
.28013 .54543 Mdot
.33494 .44673 Mdot
.3276 .41452 Mdot
.6979 .41047 Mdot
.2858 .41209 Mdot
.3587 .65051 Mdot
.46564 .69662 Mdot
.46706 .28156 Mdot
.55588 .35377 Mdot
.27283 .56832 Mdot
.42236 .48082 Mdot
.43395 .69377 Mdot
.34662 .65545 Mdot
.69345 .43301 Mdot
.52656 .7306 Mdot
.27642 .54748 Mdot
.69566 .61186 Mdot
.22127 .45076 Mdot
.59146 .73199 Mdot
.69946 .61426 Mdot
.47109 .27837 Mdot
.7138 .44302 Mdot
.34874 .45741 Mdot
.67637 .45095 Mdot
.3343 .42209 Mdot
.29373 .56362 Mdot
.43754 .2447 Mdot
.43074 .67603 Mdot
.73325 .60918 Mdot
.55733 .72325 Mdot
.55468 .69941 Mdot
.26175 .49401 Mdot
.68358 .39754 Mdot
.70919 .42085 Mdot
.45311 .29773 Mdot
.49499 .70131 Mdot
.35839 .44173 Mdot
.39348 .67016 Mdot
.54912 .72776 Mdot
.431 .68565 Mdot
.222 .45757 Mdot
.27206 .40058 Mdot
.32609 .41912 Mdot
.46128 .68421 Mdot
.71534 .44572 Mdot
.4352 .24214 Mdot
.3501 .43423 Mdot
.54274 .32852 Mdot
.47733 .69536 Mdot
.7136 .46968 Mdot
.29044 .41418 Mdot
.68268 .44888 Mdot
.47304 .68458 Mdot
.68567 .41092 Mdot
.70086 .62602 Mdot
.69509 .41973 Mdot
.33337 .49234 Mdot
.33158 .44634 Mdot
.46762 .69335 Mdot
.52789 .73443 Mdot
.33664 .66052 Mdot
.35411 .50023 Mdot
.48876 .69267 Mdot
.67838 .47139 Mdot
.49572 .72016 Mdot
.34828 .65958 Mdot
.35915 .44871 Mdot
.48577 .28721 Mdot
.28479 .58453 Mdot
.22232 .47609 Mdot
.27116 .58579 Mdot
.46244 .26524 Mdot
.40536 .66099 Mdot
.33589 .43539 Mdot
.27927 .40578 Mdot
.73105 .35009 Mdot
.36501 .50731 Mdot
.54411 .32417 Mdot
.35639 .6607 Mdot
.23768 .4239 Mdot
.33364 .65633 Mdot
.44865 .67438 Mdot
.47615 .68563 Mdot
.66935 .45369 Mdot
.46572 .68318 Mdot
.54175 .32588 Mdot
.62688 .62493 Mdot
.55029 .69953 Mdot
.56133 .36736 Mdot
.52428 .3338 Mdot
.53092 .31741 Mdot
.57491 .35348 Mdot
.49915 .33754 Mdot
.71253 .37935 Mdot
.52722 .33675 Mdot
.4985 .69987 Mdot
.7227 .49015 Mdot
.50702 .2902 Mdot
.62558 .62727 Mdot
.55326 .32731 Mdot
.36589 .50725 Mdot
.34255 .65688 Mdot
.57762 .73255 Mdot
.68977 .61136 Mdot
.54892 .31575 Mdot
.35705 .44133 Mdot
.47928 .69796 Mdot
.34056 .46223 Mdot
.48922 .27569 Mdot
.53932 .73776 Mdot
.68661 .43852 Mdot
.43917 .24512 Mdot
.57191 .3403 Mdot
.45181 .2559 Mdot
.6938 .47093 Mdot
.66834 .60135 Mdot
.36371 .49904 Mdot
.48181 .30237 Mdot
.47238 .24693 Mdot
.36585 .50479 Mdot
.49163 .70082 Mdot
.55173 .3175 Mdot
.36505 .46406 Mdot
.34388 .64943 Mdot
.53954 .7146 Mdot
.61299 .69175 Mdot
.35111 .46082 Mdot
.32067 .64989 Mdot
.47109 .69688 Mdot
.58225 .3574 Mdot
.68311 .43988 Mdot
.32178 .44077 Mdot
.65311 .61047 Mdot
.66632 .61054 Mdot
.73148 .34452 Mdot
.55648 .74499 Mdot
.7052 .48741 Mdot
.34964 .50899 Mdot
.55759 .32927 Mdot
.32392 .44031 Mdot
.66715 .46205 Mdot
.60471 .70952 Mdot
.51911 .7118 Mdot
.72908 .37471 Mdot
.36845 .4412 Mdot
.62186 .64142 Mdot
.72336 .36766 Mdot
.46605 .69585 Mdot
.55299 .742 Mdot
.52829 .72035 Mdot
.43851 .25596 Mdot
.68645 .44644 Mdot
.57257 .72554 Mdot
.55502 .7147 Mdot
.34784 .65799 Mdot
.35453 .50752 Mdot
.45469 .68931 Mdot
.72566 .34851 Mdot
.47495 .28343 Mdot
.73116 .35852 Mdot
.45773 .30949 Mdot
.7203 .61234 Mdot
.26631 .54421 Mdot
.26081 .56951 Mdot
.38005 .2307 Mdot
.31803 .42026 Mdot
.33655 .44488 Mdot
.41564 .67628 Mdot
.49612 .30151 Mdot
.46114 .28409 Mdot
.49368 .70031 Mdot
.52098 .71058 Mdot
.44549 .24863 Mdot
.39548 .50895 Mdot
.25154 .42795 Mdot
.36413 .43405 Mdot
.43002 .67013 Mdot
.52431 .69416 Mdot
.65858 .61527 Mdot
.47736 .69455 Mdot
.73504 .48313 Mdot
.72085 .44494 Mdot
.70282 .42148 Mdot
.72205 .6067 Mdot
.34878 .45524 Mdot
.70639 .4155 Mdot
.35057 .63899 Mdot
.73981 .47304 Mdot
.32694 .63751 Mdot
.73435 .33216 Mdot
.35664 .50061 Mdot
.62887 .65002 Mdot
.71207 .58945 Mdot
.34649 .66194 Mdot
.40292 .50394 Mdot
.46038 .27179 Mdot
.4143 .67678 Mdot
.66551 .62628 Mdot
.40726 .67948 Mdot
.33125 .45861 Mdot
.44431 .68195 Mdot
.72862 .61309 Mdot
.60334 .69542 Mdot
.35989 .65439 Mdot
.35014 .64366 Mdot
.40585 .6873 Mdot
.493 .69049 Mdot
.68241 .44177 Mdot
.43244 .68874 Mdot
.56494 .71743 Mdot
.3312 .63814 Mdot
.71904 .4681 Mdot
.30075 .55918 Mdot
.43205 .67442 Mdot
.43504 .25745 Mdot
.5465 .7399 Mdot
.44436 .25115 Mdot
.57464 .72939 Mdot
.71622 .38335 Mdot
.35349 .48111 Mdot
.72614 .3747 Mdot
.4823 .26609 Mdot
.69246 .40269 Mdot
.67642 .61637 Mdot
.55919 .33542 Mdot
.66739 .61997 Mdot
.28597 .54761 Mdot
.40887 .67688 Mdot
.62838 .62798 Mdot
.27632 .50353 Mdot
.32686 .44329 Mdot
.57472 .72995 Mdot
.69302 .43553 Mdot
.73549 .3542 Mdot
.28409 .5591 Mdot
.51398 .72431 Mdot
.67167 .45559 Mdot
.32352 .66344 Mdot
.73733 .45142 Mdot
.35174 .66288 Mdot
.72657 .57028 Mdot
.46946 .67847 Mdot
.73598 .3498 Mdot
.28153 .54386 Mdot
.54599 .7088 Mdot
.71646 .43682 Mdot
.6692 .60278 Mdot
.65208 .61127 Mdot
.31934 .45518 Mdot
.63637 .6439 Mdot
.69758 .42935 Mdot
.5919 .73862 Mdot
.57122 .72617 Mdot
.60344 .71493 Mdot
.45885 .26203 Mdot
.71368 .45574 Mdot
.54491 .33372 Mdot
.45457 .66061 Mdot
.68442 .47043 Mdot
.38576 .21861 Mdot
.7167 .30582 Mdot
.69177 .48597 Mdot
.53916 .739 Mdot
.5177 .73163 Mdot
.32873 .62588 Mdot
.28159 .56002 Mdot
.69601 .44264 Mdot
.72827 .48805 Mdot
.3809 .46853 Mdot
.56282 .33752 Mdot
.72944 .33999 Mdot
.3141 .41657 Mdot
.33907 .64606 Mdot
.71072 .61092 Mdot
.35338 .4571 Mdot
.51436 .70822 Mdot
.32054 .41041 Mdot
.66752 .62291 Mdot
.6641 .43085 Mdot
.33017 .45763 Mdot
.47005 .27882 Mdot
.65691 .6048 Mdot
.66361 .60537 Mdot
.6945 .39848 Mdot
.55636 .74519 Mdot
.42059 .69168 Mdot
.68455 .44543 Mdot
.33844 .63814 Mdot
.55712 .33994 Mdot
.32362 .41873 Mdot
.42909 .67995 Mdot
.41147 .67565 Mdot
.71405 .45489 Mdot
.37213 .50037 Mdot
.64198 .63199 Mdot
.68608 .48237 Mdot
.32453 .64503 Mdot
.70604 .42556 Mdot
.54495 .36695 Mdot
.71972 .43553 Mdot
.51221 .69634 Mdot
.52512 .31247 Mdot
.44013 .68081 Mdot
.53705 .35219 Mdot
.62713 .34043 Mdot
.47315 .27921 Mdot
.69507 .4107 Mdot
.59532 .70644 Mdot
.7321 .36967 Mdot
.35117 .49334 Mdot
.33817 .43206 Mdot
.6952 .47562 Mdot
.46533 .26264 Mdot
.51974 .28237 Mdot
.49365 .29538 Mdot
.53242 .73812 Mdot
.36125 .65642 Mdot
.73304 .31671 Mdot
.73432 .37343 Mdot
.72339 .61738 Mdot
.4688 .70095 Mdot
.52588 .33893 Mdot
.67965 .6136 Mdot
.66504 .60477 Mdot
.46279 .25511 Mdot
.73944 .36239 Mdot
.43737 .68537 Mdot
.65046 .63936 Mdot
.54082 .70787 Mdot
.28247 .40402 Mdot
.57923 .35282 Mdot
.45459 .29481 Mdot
.54309 .35792 Mdot
.27459 .5567 Mdot
.63347 .64254 Mdot
.3432 .47484 Mdot
.48645 .26548 Mdot
.71878 .6084 Mdot
.48814 .29019 Mdot
.32617 .64775 Mdot
.66646 .4285 Mdot
.48017 .72804 Mdot
.32031 .46317 Mdot
.3597 .48571 Mdot
.72455 .61027 Mdot
.40816 .50168 Mdot
.45447 .69518 Mdot
.56652 .72318 Mdot
.70264 .46766 Mdot
.22043 .46702 Mdot
.33058 .41209 Mdot
.35253 .43712 Mdot
.68434 .46481 Mdot
.56474 .35411 Mdot
.71182 .36677 Mdot
.35437 .44211 Mdot
.65713 .62104 Mdot
.33099 .65329 Mdot
.62043 .63853 Mdot
.35354 .51105 Mdot
.35498 .48606 Mdot
.34958 .6403 Mdot
.33343 .64709 Mdot
.66693 .62019 Mdot
.57108 .35322 Mdot
.56135 .32571 Mdot
.43303 .67181 Mdot
.35686 .50354 Mdot
.37829 .459 Mdot
.33378 .44143 Mdot
.46111 .27205 Mdot
.22049 .48128 Mdot
.27406 .54036 Mdot
.28278 .5752 Mdot
.38724 .48801 Mdot
.34599 .46289 Mdot
.72468 .61313 Mdot
.51301 .72743 Mdot
.63868 .631 Mdot
.67428 .62936 Mdot
.67166 .44906 Mdot
.48709 .29044 Mdot
.32751 .47061 Mdot
.4611 .24683 Mdot
.32052 .40057 Mdot
.42577 .23097 Mdot
.27074 .56353 Mdot
.28943 .53996 Mdot
.44041 .26471 Mdot
.32944 .43778 Mdot
.70154 .47425 Mdot
.70514 .4074 Mdot
.3397 .63163 Mdot
.34345 .50323 Mdot
.71647 .62056 Mdot
.63493 .61352 Mdot
.71509 .36307 Mdot
.71442 .3961 Mdot
.48947 .27592 Mdot
.6042 .36645 Mdot
.33246 .64128 Mdot
.32284 .46371 Mdot
.57109 .34719 Mdot
.70339 .48332 Mdot
.53337 .34806 Mdot
.71573 .37041 Mdot
.65956 .63101 Mdot
.63657 .61909 Mdot
.35027 .50245 Mdot
.40856 .20733 Mdot
.55273 .7279 Mdot
.51817 .73151 Mdot
.63167 .61494 Mdot
.69153 .40712 Mdot
.54376 .34761 Mdot
.39684 .67262 Mdot
.46624 .69913 Mdot
.47282 .24903 Mdot
.32294 .4418 Mdot
.716 .43216 Mdot
.48789 .68869 Mdot
.48501 .26761 Mdot
.2678 .58658 Mdot
.70802 .49287 Mdot
.33806 .46824 Mdot
.31955 .65272 Mdot
.50717 .71258 Mdot
.27936 .56408 Mdot
.43045 .67479 Mdot
.66105 .61048 Mdot
.64865 .63875 Mdot
.35642 .48534 Mdot
.47149 .72027 Mdot
.51957 .69997 Mdot
.64183 .64155 Mdot
.43863 .25857 Mdot
.55075 .33466 Mdot
.48776 .28933 Mdot
.70796 .47039 Mdot
.47232 .27944 Mdot
.67881 .46298 Mdot
.72485 .36529 Mdot
.44964 .68685 Mdot
.47001 .26693 Mdot
.25465 .55775 Mdot
.54253 .33017 Mdot
.43266 .22839 Mdot
.27151 .57344 Mdot
.32588 .65304 Mdot
.70393 .44641 Mdot
.46472 .24803 Mdot
.3214 .42955 Mdot
.61482 .67374 Mdot
.68306 .62443 Mdot
.67436 .61839 Mdot
.54961 .34962 Mdot
.71274 .44625 Mdot
.42981 .68255 Mdot
.38155 .4822 Mdot
.50364 .69129 Mdot
.36564 .46218 Mdot
.33768 .48428 Mdot
.52136 .69832 Mdot
.42899 .68226 Mdot
.3564 .47919 Mdot
.30903 .41493 Mdot
.54836 .33103 Mdot
.66246 .60747 Mdot
.53492 .73695 Mdot
.53156 .73083 Mdot
.68531 .42945 Mdot
.47291 .69285 Mdot
.48372 .32177 Mdot
.67173 .62211 Mdot
.58705 .35589 Mdot
.65098 .62955 Mdot
.50075 .2524 Mdot
.69083 .48343 Mdot
.59391 .69619 Mdot
.56976 .73943 Mdot
.35128 .65436 Mdot
.45235 .68892 Mdot
.45735 .25862 Mdot
.4739 .69069 Mdot
.45787 .68531 Mdot
.35986 .50534 Mdot
.57373 .34695 Mdot
.52846 .33472 Mdot
.27194 .5579 Mdot
.55183 .72847 Mdot
.35071 .4712 Mdot
.27167 .57927 Mdot
.35925 .49518 Mdot
.27826 .56281 Mdot
.56755 .73151 Mdot
.42191 .48298 Mdot
.46245 .69035 Mdot
.50111 .7066 Mdot
.45744 .31 Mdot
.53764 .32998 Mdot
.53197 .34914 Mdot
.69981 .62985 Mdot
.36409 .46427 Mdot
.72417 .37205 Mdot
.33796 .6401 Mdot
.56414 .33476 Mdot
.25653 .59049 Mdot
.45296 .23865 Mdot
.33626 .423 Mdot
.56728 .34609 Mdot
.69043 .43781 Mdot
.35098 .6533 Mdot
.34484 .43634 Mdot
.55921 .35559 Mdot
.44431 .68784 Mdot
.5394 .71729 Mdot
.46105 .70095 Mdot
.45137 .25138 Mdot
.65554 .63122 Mdot
.33866 .64261 Mdot
.70358 .47036 Mdot
.72298 .37503 Mdot
.43863 .68096 Mdot
.67671 .42148 Mdot
.63989 .6148 Mdot
.35031 .44271 Mdot
.66516 .61282 Mdot
.44866 .23921 Mdot
.53937 .7368 Mdot
.3467 .6482 Mdot
.34605 .62551 Mdot
.47647 .68587 Mdot
.551 .32952 Mdot
.48535 .29291 Mdot
.67467 .41772 Mdot
.51975 .71377 Mdot
.65597 .63212 Mdot
.68221 .42714 Mdot
.35193 .64701 Mdot
.41834 .23421 Mdot
.35374 .45834 Mdot
.34141 .49627 Mdot
.43627 .65675 Mdot
.36973 .51374 Mdot
.72358 .37851 Mdot
.41848 .67426 Mdot
.34046 .66036 Mdot
.29246 .55037 Mdot
.44261 .2103 Mdot
.50133 .28972 Mdot
.34112 .45691 Mdot
.25464 .58437 Mdot
.37998 .50723 Mdot
.59472 .7117 Mdot
.2827 .56298 Mdot
.66922 .46124 Mdot
.45333 .29497 Mdot
.67347 .63041 Mdot
.5634 .34256 Mdot
.66935 .42571 Mdot
.30984 .41387 Mdot
.35556 .46256 Mdot
.49062 .72142 Mdot
.32615 .65055 Mdot
.63433 .62806 Mdot
.41511 .4912 Mdot
.69229 .43275 Mdot
.7391 .33427 Mdot
.34688 .50822 Mdot
.45272 .69626 Mdot
.62101 .65635 Mdot
.57025 .34287 Mdot
.53447 .35245 Mdot
.48196 .26393 Mdot
.66583 .44761 Mdot
.51274 .32169 Mdot
.64342 .63127 Mdot
.31895 .42921 Mdot
.27271 .54086 Mdot
.61666 .68623 Mdot
.47979 .68384 Mdot
.69991 .62224 Mdot
.49589 .24493 Mdot
.34182 .48049 Mdot
.55864 .73003 Mdot
.46462 .68088 Mdot
.47423 .2487 Mdot
.71742 .37508 Mdot
.72855 .35021 Mdot
.39671 .2117 Mdot
.53891 .31414 Mdot
.70198 .48295 Mdot
.51533 .32125 Mdot
.34106 .63783 Mdot
.27184 .56819 Mdot
.68315 .62709 Mdot
.35034 .49542 Mdot
.47222 .70886 Mdot
.43994 .67254 Mdot
.33355 .4457 Mdot
.46686 .28345 Mdot
.39303 .68522 Mdot
.35367 .63516 Mdot
.31155 .43602 Mdot
.7157 .44653 Mdot
.34385 .4879 Mdot
.48462 .32318 Mdot
.58287 .36026 Mdot
.36822 .51063 Mdot
.68396 .44145 Mdot
.52537 .31273 Mdot
.46676 .28495 Mdot
.43874 .67035 Mdot
.56187 .34308 Mdot
.32435 .64647 Mdot
.3272 .42241 Mdot
.43979 .26108 Mdot
.34677 .64002 Mdot
.52426 .693 Mdot
.5399 .35886 Mdot
.69971 .41881 Mdot
.5301 .71032 Mdot
.34862 .48719 Mdot
.55172 .33364 Mdot
.32395 .44752 Mdot
.56227 .70108 Mdot
.33613 .48861 Mdot
.60554 .67897 Mdot
.50262 .71423 Mdot
.64561 .62343 Mdot
.34646 .65396 Mdot
.3368 .46935 Mdot
.51736 .31939 Mdot
.53974 .34558 Mdot
.35668 .44005 Mdot
.43871 .67994 Mdot
.4599 .68238 Mdot
.44309 .69573 Mdot
.68901 .4254 Mdot
.35326 .42086 Mdot
.65011 .61895 Mdot
.57019 .35156 Mdot
.6343 .64395 Mdot
.25624 .58221 Mdot
.44969 .25337 Mdot
.61075 .68439 Mdot
.35667 .45001 Mdot
.51742 .72562 Mdot
.2547 .42919 Mdot
.53537 .74659 Mdot
.71042 .62831 Mdot
.70252 .62228 Mdot
.54426 .72939 Mdot
.34059 .45336 Mdot
.27596 .55501 Mdot
.27623 .53815 Mdot
.63619 .64168 Mdot
.5705 .33204 Mdot
.55359 .37827 Mdot
.7204 .45179 Mdot
.4193 .23272 Mdot
.72846 .60317 Mdot
.72614 .58781 Mdot
.34831 .65961 Mdot
.53907 .71323 Mdot
.64193 .63668 Mdot
.67464 .60689 Mdot
.69965 .43382 Mdot
.34895 .65678 Mdot
.33506 .46452 Mdot
.53979 .32513 Mdot
.70181 .60733 Mdot
.34842 .42813 Mdot
.33579 .66087 Mdot
.7131 .3701 Mdot
.42596 .68735 Mdot
.61352 .69499 Mdot
.25926 .58485 Mdot
.44477 .70165 Mdot
.73097 .433 Mdot
.57199 .72602 Mdot
.34988 .47281 Mdot
.54374 .34163 Mdot
.679 .41787 Mdot
.34858 .44555 Mdot
.73065 .37369 Mdot
.63173 .63339 Mdot
.61762 .6759 Mdot
.2573 .5706 Mdot
.73938 .47202 Mdot
.35409 .47502 Mdot
.34245 .62775 Mdot
.47861 .27748 Mdot
.63597 .63924 Mdot
.48974 .71246 Mdot
.32157 .44701 Mdot
.67953 .43635 Mdot
.72198 .45894 Mdot
.44108 .67612 Mdot
.46371 .70075 Mdot
.5959 .70138 Mdot
.54305 .33414 Mdot
.67289 .43215 Mdot
.55021 .333 Mdot
.31052 .43138 Mdot
.64645 .64081 Mdot
.46553 .28465 Mdot
.68451 .41172 Mdot
.7258 .59949 Mdot
.32559 .65284 Mdot
.54108 .74439 Mdot
.45103 .65922 Mdot
.34787 .63499 Mdot
.66603 .44205 Mdot
.44819 .26157 Mdot
.28084 .56965 Mdot
.36047 .64762 Mdot
.4417 .25395 Mdot
.69284 .42819 Mdot
.54494 .72132 Mdot
.4608 .67785 Mdot
.50825 .72302 Mdot
.26377 .54706 Mdot
.40366 .66601 Mdot
.29849 .40663 Mdot
.37418 .51145 Mdot
.58183 .71868 Mdot
.37545 .48308 Mdot
.67297 .61968 Mdot
.51151 .71685 Mdot
.27872 .56345 Mdot
.3513 .66611 Mdot
.31196 .40714 Mdot
.36576 .48702 Mdot
.33086 .64641 Mdot
.36423 .46446 Mdot
.5234 .69645 Mdot
.41215 .67529 Mdot
.28246 .57359 Mdot
.6768 .6212 Mdot
.45373 .26145 Mdot
.56543 .7168 Mdot
.34072 .48512 Mdot
.5283 .69576 Mdot
.27608 .57501 Mdot
.60573 .67699 Mdot
.32907 .64446 Mdot
.66367 .43184 Mdot
.31961 .42246 Mdot
.72281 .44701 Mdot
.35152 .62946 Mdot
.53205 .69531 Mdot
.68844 .62177 Mdot
.35399 .63481 Mdot
.71512 .49477 Mdot
.41659 .48881 Mdot
.54002 .33996 Mdot
.47718 .28228 Mdot
.52506 .31417 Mdot
.6694 .6188 Mdot
.35712 .45627 Mdot
.32714 .42588 Mdot
.36756 .51549 Mdot
.31046 .43182 Mdot
.53946 .32982 Mdot
.43249 .25068 Mdot
.55576 .70153 Mdot
.33684 .42633 Mdot
.70579 .41279 Mdot
.55438 .7177 Mdot
.31131 .41127 Mdot
.27356 .53589 Mdot
.3187 .64169 Mdot
.55028 .72913 Mdot
.55402 .74644 Mdot
.50219 .34285 Mdot
.46779 .27078 Mdot
.35739 .49236 Mdot
.44644 .27516 Mdot
.34119 .64307 Mdot
.65925 .62553 Mdot
.374 .51695 Mdot
.68956 .48226 Mdot
.28705 .55606 Mdot
.69277 .42677 Mdot
.36191 .48914 Mdot
.54401 .74115 Mdot
.64593 .63893 Mdot
.73308 .3469 Mdot
.73069 .34182 Mdot
.29691 .40298 Mdot
.74231 .33948 Mdot
.45564 .24971 Mdot
.45889 .25512 Mdot
.64303 .63812 Mdot
.33744 .44716 Mdot
.28622 .56294 Mdot
.34719 .61823 Mdot
.3628 .46518 Mdot
.34776 .45312 Mdot
.72284 .59733 Mdot
.72357 .60532 Mdot
.68698 .41138 Mdot
.35647 .47503 Mdot
.34298 .42382 Mdot
.5468 .73502 Mdot
.49491 .29143 Mdot
.66923 .43898 Mdot
.48618 .26991 Mdot
.68481 .4586 Mdot
.23834 .42349 Mdot
.57752 .34579 Mdot
.45466 .25293 Mdot
.73412 .6042 Mdot
.52132 .72686 Mdot
.5404 .32731 Mdot
.70342 .45467 Mdot
.67443 .42626 Mdot
.31524 .41265 Mdot
.4766 .68103 Mdot
.56781 .7245 Mdot
.44819 .25037 Mdot
.63639 .61167 Mdot
.35046 .63854 Mdot
.54194 .35746 Mdot
.47878 .22731 Mdot
.67635 .43244 Mdot
.58888 .72629 Mdot
.4451 .65953 Mdot
.3327 .47498 Mdot
.53942 .71793 Mdot
.33243 .46859 Mdot
.43305 .68866 Mdot
.54626 .70714 Mdot
.35202 .51107 Mdot
.44735 .69954 Mdot
.69854 .48428 Mdot
.7339 .32452 Mdot
.34429 .66352 Mdot
.74529 .60777 Mdot
.33925 .63983 Mdot
.71312 .35982 Mdot
.25651 .42733 Mdot
.33394 .42903 Mdot
.33998 .48552 Mdot
.41137 .24987 Mdot
.38173 .4939 Mdot
.54414 .35547 Mdot
.53956 .33912 Mdot
.54647 .71935 Mdot
.52412 .31545 Mdot
.27543 .55802 Mdot
.47288 .26538 Mdot
.7034 .4671 Mdot
.27765 .40748 Mdot
.44591 .25455 Mdot
.45108 .67401 Mdot
.35802 .64962 Mdot
.57719 .71801 Mdot
.71204 .41903 Mdot
.5615 .35182 Mdot
.63267 .63194 Mdot
.28522 .58653 Mdot
.6858 .43412 Mdot
.711 .60522 Mdot
.26357 .56491 Mdot
.66189 .43368 Mdot
.67618 .62065 Mdot
.73248 .32153 Mdot
.70564 .61222 Mdot
.62744 .62235 Mdot
.27398 .54589 Mdot
.47364 .26569 Mdot
.5201 .31361 Mdot
.4401 .26916 Mdot
.69289 .61891 Mdot
.71242 .35654 Mdot
.70946 .44231 Mdot
.29275 .55905 Mdot
.40514 .66583 Mdot
.55382 .32686 Mdot
.35262 .4636 Mdot
.71608 .61075 Mdot
.32146 .40032 Mdot
.52107 .31374 Mdot
.64018 .61768 Mdot
.34994 .62843 Mdot
.21897 .47728 Mdot
.54706 .33834 Mdot
.52802 .32969 Mdot
.47 .25353 Mdot
.72251 .35792 Mdot
.57096 .73076 Mdot
.45532 .23852 Mdot
.38627 .51435 Mdot
.35561 .49898 Mdot
.66604 .62165 Mdot
.56204 .34423 Mdot
.65043 .61502 Mdot
.47856 .28847 Mdot
.43251 .24703 Mdot
.44184 .67112 Mdot
.44646 .69608 Mdot
.51613 .33613 Mdot
.38829 .48672 Mdot
.37959 .50177 Mdot
.48696 .7174 Mdot
.55975 .73995 Mdot
.40177 .50242 Mdot
.47749 .29264 Mdot
.47212 .25366 Mdot
.34562 .62813 Mdot
.27609 .57975 Mdot
.33356 .65167 Mdot
.26244 .58031 Mdot
.65249 .45631 Mdot
.34818 .65243 Mdot
.67367 .42059 Mdot
.26355 .58228 Mdot
.74563 .59526 Mdot
.3364 .63035 Mdot
.33002 .47318 Mdot
.6895 .45613 Mdot
.36734 .50515 Mdot
.71309 .46624 Mdot
.35205 .48182 Mdot
.66653 .46152 Mdot
.70331 .47019 Mdot
.60725 .37327 Mdot
.25145 .49167 Mdot
.54086 .35323 Mdot
.45412 .27835 Mdot
.48426 .30334 Mdot
.29132 .41358 Mdot
.54238 .7232 Mdot
.3868 .67088 Mdot
.33267 .47659 Mdot
.70199 .43445 Mdot
.62985 .63168 Mdot
.33473 .62214 Mdot
.33341 .49006 Mdot
.34124 .63451 Mdot
.54209 .74482 Mdot
.71545 .45088 Mdot
.48218 .28263 Mdot
.71589 .38884 Mdot
.7184 .35164 Mdot
.69609 .48681 Mdot
.31138 .45716 Mdot
.32102 .63608 Mdot
.48543 .32338 Mdot
.41907 .68662 Mdot
.51993 .28893 Mdot
.46718 .68482 Mdot
.56115 .33991 Mdot
.48087 .26597 Mdot
.22888 .48306 Mdot
.56009 .71971 Mdot
.68481 .46507 Mdot
.33878 .46939 Mdot
.5727 .35428 Mdot
.43886 .26737 Mdot
.51968 .70806 Mdot
.44004 .26227 Mdot
.69934 .45791 Mdot
.55253 .33768 Mdot
.34837 .41566 Mdot
.42755 .47259 Mdot
.29505 .56212 Mdot
.33734 .47255 Mdot
.4455 .24959 Mdot
.47856 .68196 Mdot
.3421 .6341 Mdot
.7032 .60985 Mdot
.28085 .55947 Mdot
.3534 .46276 Mdot
.74062 .46583 Mdot
.54044 .74291 Mdot
.46074 .26341 Mdot
.71454 .61142 Mdot
.468 .27237 Mdot
.53521 .35203 Mdot
.43799 .69007 Mdot
.53596 .35351 Mdot
.3279 .65205 Mdot
.63833 .63531 Mdot
.56646 .72365 Mdot
.71154 .37647 Mdot
.54522 .31604 Mdot
.69822 .47747 Mdot
.22752 .48498 Mdot
.44414 .67846 Mdot
.70299 .60141 Mdot
.71651 .38826 Mdot
.62661 .61286 Mdot
.28753 .5759 Mdot
.65034 .60756 Mdot
.3335 .4783 Mdot
.50469 .72077 Mdot
.62323 .64269 Mdot
.72964 .3438 Mdot
.25327 .58011 Mdot
.55542 .36472 Mdot
.32902 .44009 Mdot
.59901 .72611 Mdot
.70396 .59422 Mdot
.46125 .69242 Mdot
.72986 .60226 Mdot
.36192 .47741 Mdot
.54517 .33128 Mdot
.35525 .5047 Mdot
.6983 .61919 Mdot
.72705 .59693 Mdot
.73231 .36081 Mdot
.34246 .47209 Mdot
.4634 .27292 Mdot
.6673 .42781 Mdot
.7207 .46482 Mdot
.68762 .41469 Mdot
.48069 .70441 Mdot
.56904 .33436 Mdot
.5415 .33469 Mdot
.25904 .42317 Mdot
.65243 .61235 Mdot
.54226 .35389 Mdot
.33074 .42371 Mdot
.29895 .41154 Mdot
.50621 .71971 Mdot
.69506 .45343 Mdot
.36059 .48359 Mdot
.34859 .66426 Mdot
.5525 .35359 Mdot
.68544 .44688 Mdot
.44203 .68667 Mdot
.71777 .40462 Mdot
.35116 .44598 Mdot
.34186 .65882 Mdot
.47463 .68311 Mdot
.53171 .69146 Mdot
.38403 .49278 Mdot
.33198 .46662 Mdot
.66692 .61055 Mdot
.51245 .66285 Mdot
.30681 .53305 Mdot
.42896 .5361 Mdot
.55324 .32383 Mdot
.59907 .56188 Mdot
.46379 .63439 Mdot
.35612 .62532 Mdot
.50241 .59009 Mdot
.29739 .60648 Mdot
.54898 .62076 Mdot
.63879 .42395 Mdot
.46838 .57025 Mdot
.71905 .32133 Mdot
.68243 .53423 Mdot
.31346 .62554 Mdot
.38333 .26236 Mdot
.68053 .58725 Mdot
.5145 .63191 Mdot
.69165 .54165 Mdot
.60182 .44805 Mdot
.70752 .38091 Mdot
.6875 .39684 Mdot
.63131 .40297 Mdot
.31479 .4271 Mdot
.5426 .65099 Mdot
.32435 .58255 Mdot
.6321 .59319 Mdot
.67011 .49926 Mdot
.36053 .66128 Mdot
.42453 .31018 Mdot
.6193 .56972 Mdot
.4586 .36955 Mdot
.37866 .63183 Mdot
.62469 .45242 Mdot
.32164 .57717 Mdot
.42976 .37888 Mdot
.37308 .64224 Mdot
.55566 .58958 Mdot
.59748 .59338 Mdot
.3986 .62253 Mdot
.633 .55879 Mdot
.67453 .44901 Mdot
.48178 .68249 Mdot
.70051 .56084 Mdot
.46062 .34625 Mdot
.65924 .55845 Mdot
.5015 .59096 Mdot
.51643 .32866 Mdot
.60102 .55498 Mdot
.34213 .413 Mdot
.55027 .75109 Mdot
.64429 .49218 Mdot
.65626 .48045 Mdot
.41361 .63051 Mdot
.67973 .51474 Mdot
.23464 .47856 Mdot
.5191 .63498 Mdot
.47187 .63899 Mdot
.60547 .44406 Mdot
.60952 .38316 Mdot
.55543 .74371 Mdot
.39457 .30961 Mdot
.55849 .43644 Mdot
.37201 .53553 Mdot
.65722 .51477 Mdot
.40232 .64832 Mdot
.4401 .70313 Mdot
.50228 .72891 Mdot
.69518 .36634 Mdot
.47442 .33662 Mdot
.6435 .39874 Mdot
.56986 .4358 Mdot
.66146 .5514 Mdot
.2811 .49359 Mdot
.57997 .61669 Mdot
.65092 .37782 Mdot
.50495 .67497 Mdot
.40009 .26991 Mdot
.55417 .51791 Mdot
.44044 .30095 Mdot
.43916 .63471 Mdot
.60955 .45576 Mdot
.42916 .59064 Mdot
.61946 .53462 Mdot
.23705 .43997 Mdot
.44874 .31782 Mdot
.545 .65 Mdot
.57985 .39967 Mdot
.677 .58569 Mdot
.47552 .6529 Mdot
.65826 .4914 Mdot
.59019 .35666 Mdot
.4631 .4402 Mdot
.42517 .28811 Mdot
.5116 .58448 Mdot
.41905 .33846 Mdot
.62547 .44909 Mdot
.71313 .55754 Mdot
.71731 .48012 Mdot
.59988 .63063 Mdot
.47089 .36414 Mdot
.49328 .70685 Mdot
.70865 .34571 Mdot
.49054 .61167 Mdot
.58918 .6523 Mdot
.42313 .28969 Mdot
.69323 .37533 Mdot
.60732 .52255 Mdot
.61039 .41988 Mdot
.59682 .58821 Mdot
.57087 .62218 Mdot
.66868 .5953 Mdot
.55843 .37239 Mdot
.56086 .683 Mdot
.45098 .36224 Mdot
.67304 .39053 Mdot
.39305 .24514 Mdot
.38026 .47473 Mdot
.46898 .39414 Mdot
.42638 .65398 Mdot
.50407 .50013 Mdot
.64601 .59259 Mdot
.43395 .28883 Mdot
.36344 .66098 Mdot
.5169 .67479 Mdot
.63298 .40023 Mdot
.33321 .50506 Mdot
.60366 .67109 Mdot
.69818 .5448 Mdot
.71392 .41251 Mdot
.45626 .64303 Mdot
.47804 .32406 Mdot
.27366 .4445 Mdot
.43547 .49042 Mdot
.68099 .50807 Mdot
.36964 .53151 Mdot
.44968 .48738 Mdot
.67918 .32434 Mdot
.59077 .6667 Mdot
.45665 .45007 Mdot
.43808 .65493 Mdot
.64865 .37608 Mdot
.63975 .41479 Mdot
.53043 .66237 Mdot
.4822 .2373 Mdot
.42771 .34055 Mdot
.46032 .49355 Mdot
.60596 .54141 Mdot
.31181 .60965 Mdot
.33694 .57048 Mdot
.62546 .43674 Mdot
.50746 .42099 Mdot
.54817 .39242 Mdot
.69724 .5412 Mdot
.47871 .70891 Mdot
.48821 .39337 Mdot
.393 .58196 Mdot
.50744 .68618 Mdot
.49748 .44366 Mdot
.60539 .64259 Mdot
.48428 .42952 Mdot
.42309 .30282 Mdot
.69638 .39584 Mdot
.65518 .38008 Mdot
.66712 .55351 Mdot
.66377 .49368 Mdot
.57165 .65015 Mdot
.57562 .65169 Mdot
.49604 .3767 Mdot
.68751 .57919 Mdot
.61686 .47866 Mdot
.51043 .73321 Mdot
.52012 .62077 Mdot
.37795 .61247 Mdot
.29872 .50693 Mdot
.42189 .56525 Mdot
.48138 .29527 Mdot
.43375 .40098 Mdot
.45721 .64489 Mdot
.49238 .2434 Mdot
.31263 .50382 Mdot
.31649 .57054 Mdot
.55519 .36722 Mdot
.28075 .46669 Mdot
.24154 .42601 Mdot
.57695 .53352 Mdot
.67154 .37712 Mdot
.45259 .51641 Mdot
.28456 .46264 Mdot
.64189 .59097 Mdot
.36428 .62853 Mdot
.43369 .29034 Mdot
.51347 .36335 Mdot
.50079 .64415 Mdot
.54746 .67058 Mdot
.75323 .58269 Mdot
.69599 .60181 Mdot
.69103 .31874 Mdot
.66763 .553 Mdot
.4029 .691 Mdot
.72018 .38224 Mdot
.60527 .486 Mdot
.41779 .59605 Mdot
.31099 .59192 Mdot
.44261 .32304 Mdot
.58339 .54955 Mdot
.4358 .22739 Mdot
.45009 .61459 Mdot
.43708 .51624 Mdot
.41983 .32143 Mdot
.40092 .29934 Mdot
.40137 .31209 Mdot
.69858 .56584 Mdot
.43047 .39403 Mdot
.41587 .28135 Mdot
.30288 .39745 Mdot
.56388 .47148 Mdot
.34802 .62145 Mdot
.3404 .54881 Mdot
.69801 .33799 Mdot
.56193 .42733 Mdot
.57041 .61417 Mdot
.41392 .63117 Mdot
.41868 .26411 Mdot
.24984 .41741 Mdot
.63314 .54493 Mdot
.45057 .37237 Mdot
.58852 .40333 Mdot
.46555 .38458 Mdot
.51229 .38261 Mdot
.53227 .586 Mdot
.69714 .54502 Mdot
.41645 .20849 Mdot
.63614 .37365 Mdot
.64045 .57906 Mdot
.48424 .66419 Mdot
.70357 .34029 Mdot
.58073 .67063 Mdot
.59768 .61438 Mdot
.43823 .62597 Mdot
.35626 .57497 Mdot
.46094 .54234 Mdot
.56202 .59086 Mdot
.44127 .43169 Mdot
.54254 .41182 Mdot
.69743 .39779 Mdot
.65794 .3498 Mdot
.45803 .53197 Mdot
.55751 .46708 Mdot
.28907 .45003 Mdot
.7016 .37372 Mdot
.55155 .5581 Mdot
.30233 .52387 Mdot
.45322 .5129 Mdot
.51729 .6427 Mdot
.59946 .66963 Mdot
.37705 .57987 Mdot
.37322 .47092 Mdot
.45901 .33969 Mdot
.70695 .31194 Mdot
.50735 .37691 Mdot
.5426 .65858 Mdot
.72205 .54981 Mdot
.67082 .5403 Mdot
.3019 .47037 Mdot
.30547 .55652 Mdot
.51725 .5552 Mdot
.29474 .59721 Mdot
.61925 .62764 Mdot
.44394 .70448 Mdot
.56324 .65052 Mdot
.30372 .42206 Mdot
.43287 .57375 Mdot
.55316 .63888 Mdot
.32674 .51282 Mdot
.44217 .65277 Mdot
.56804 .70033 Mdot
.64666 .37217 Mdot
.69419 .39758 Mdot
.47463 .23511 Mdot
.55204 .44548 Mdot
.48956 .27132 Mdot
.57882 .38344 Mdot
.60246 .53288 Mdot
.38229 .63034 Mdot
.72873 .54989 Mdot
.52575 .3945 Mdot
.72219 .32993 Mdot
.51552 .38289 Mdot
.64353 .40721 Mdot
.65763 .51946 Mdot
.26265 .46224 Mdot
.62433 .58008 Mdot
.6907 .5326 Mdot
.24487 .45577 Mdot
.6581 .40648 Mdot
.61634 .54742 Mdot
.55163 .75194 Mdot
.36695 .44991 Mdot
.25179 .43212 Mdot
.42448 .37854 Mdot
.26747 .47543 Mdot
.41172 .54159 Mdot
.41679 .66537 Mdot
.42164 .38382 Mdot
.6389 .54672 Mdot
.35653 .63039 Mdot
.54323 .67196 Mdot
.60941 .63739 Mdot
.47473 .66066 Mdot
.71049 .35709 Mdot
.7377 .56728 Mdot
.55924 .6352 Mdot
.30553 .48785 Mdot
.43587 .36053 Mdot
.30679 .47422 Mdot
.55627 .67394 Mdot
.36869 .56502 Mdot
.60009 .66033 Mdot
.42207 .63109 Mdot
.5695 .50246 Mdot
.59722 .64176 Mdot
.46344 .61136 Mdot
.45174 .65233 Mdot
.31985 .66149 Mdot
.48848 .35407 Mdot
.43441 .43628 Mdot
.54744 .59714 Mdot
.38511 .51036 Mdot
.49125 .50349 Mdot
.49921 .61365 Mdot
.29316 .43224 Mdot
.53017 .60824 Mdot
.3944 .3193 Mdot
.48567 .72185 Mdot
.58399 .58644 Mdot
.51713 .41659 Mdot
.30537 .43221 Mdot
.37768 .6299 Mdot
.47924 .65304 Mdot
.69616 .54174 Mdot
.43135 .41998 Mdot
.47854 .33595 Mdot
.54587 .50245 Mdot
.28499 .45706 Mdot
.47006 .47129 Mdot
.43242 .41576 Mdot
.56762 .37208 Mdot
.50584 .38085 Mdot
.60301 .56166 Mdot
.37938 .26163 Mdot
.65226 .42869 Mdot
.4179 .56032 Mdot
.42829 .59376 Mdot
.65417 .36828 Mdot
.45631 .59664 Mdot
.47329 .58379 Mdot
.46616 .50838 Mdot
.68539 .35338 Mdot
.57972 .56689 Mdot
.62536 .55175 Mdot
.56851 .69889 Mdot
.41308 .29514 Mdot
.5614 .61538 Mdot
.59469 .62216 Mdot
.5327 .41737 Mdot
.33435 .48882 Mdot
.40981 .56709 Mdot
.59997 .69524 Mdot
.50598 .46337 Mdot
.5697 .63369 Mdot
.71878 .31681 Mdot
.58962 .54482 Mdot
.45134 .52464 Mdot
.38167 .25506 Mdot
.3807 .24251 Mdot
.38756 .59956 Mdot
.42832 .27312 Mdot
.63955 .54466 Mdot
.56397 .6721 Mdot
.632 .5635 Mdot
.28456 .50624 Mdot
.47991 .71217 Mdot
.49531 .34635 Mdot
.75461 .58812 Mdot
.64572 .58875 Mdot
.43041 .61169 Mdot
.46432 .31683 Mdot
.55584 .47711 Mdot
.61373 .49122 Mdot
.7145 .54643 Mdot
.69897 .38592 Mdot
.68358 .37162 Mdot
.3899 .5626 Mdot
.63875 .46406 Mdot
.61811 .38078 Mdot
.58442 .66278 Mdot
.71681 .33001 Mdot
.5945 .39001 Mdot
.38348 .66321 Mdot
.64929 .37814 Mdot
.56036 .69186 Mdot
.65445 .48439 Mdot
.49625 .6095 Mdot
.59779 .53829 Mdot
.50726 .4409 Mdot
.5646 .68014 Mdot
.6938 .56061 Mdot
.58167 .49809 Mdot
.22595 .47332 Mdot
.48003 .65837 Mdot
.51234 .67859 Mdot
.33249 .58659 Mdot
.60102 .51714 Mdot
.38734 .29843 Mdot
.7026 .62693 Mdot
.24866 .475 Mdot
.55024 .75152 Mdot
.28633 .39794 Mdot
.61541 .48198 Mdot
.26565 .59129 Mdot
.48691 .35552 Mdot
.61854 .48303 Mdot
.39425 .29492 Mdot
.73821 .32756 Mdot
.41694 .36701 Mdot
.5819 .60686 Mdot
.57183 .38322 Mdot
.69349 .33811 Mdot
.69003 .32865 Mdot
.39237 .27714 Mdot
.6229 .37545 Mdot
.23957 .45414 Mdot
.58432 .51102 Mdot
.29062 .5085 Mdot
.31714 .48814 Mdot
.65248 .36437 Mdot
.4009 .67343 Mdot
.44267 .37989 Mdot
.47966 .62616 Mdot
.67124 .3963 Mdot
.42495 .38685 Mdot
.28872 .40221 Mdot
.49383 .46911 Mdot
.61327 .43159 Mdot
.70962 .48705 Mdot
.40504 .22949 Mdot
.53479 .66473 Mdot
.49345 .3911 Mdot
.52059 .67334 Mdot
.47178 .66344 Mdot
.63826 .43197 Mdot
.46988 .63118 Mdot
.42622 .20919 Mdot
.64137 .50129 Mdot
.51687 .35888 Mdot
.61848 .54076 Mdot
.59688 .71513 Mdot
.34204 .51238 Mdot
.49359 .37227 Mdot
.49668 .39623 Mdot
.38783 .27122 Mdot
.44609 .38922 Mdot
.44854 .4077 Mdot
.39035 .30952 Mdot
.50184 .63762 Mdot
.26423 .48 Mdot
.41864 .31494 Mdot
.39156 .61848 Mdot
.47416 .33786 Mdot
.66021 .60204 Mdot
.60004 .45412 Mdot
.58815 .69647 Mdot
.28115 .48097 Mdot
.27777 .4838 Mdot
.53636 .39678 Mdot
.67376 .58693 Mdot
.44255 .54749 Mdot
.4605 .49648 Mdot
.66149 .49285 Mdot
.28242 .50546 Mdot
.53429 .59529 Mdot
.39354 .23767 Mdot
.37405 .47016 Mdot
.61881 .34171 Mdot
.66158 .37891 Mdot
.62218 .58044 Mdot
.5948 .52547 Mdot
.58429 .69941 Mdot
.40007 .5465 Mdot
.26895 .43032 Mdot
.41601 .29918 Mdot
.59423 .52406 Mdot
.31171 .56664 Mdot
.40259 .51734 Mdot
.59081 .6305 Mdot
.67272 .5703 Mdot
.51109 .59324 Mdot
.58701 .44929 Mdot
.37011 .44739 Mdot
.64083 .39794 Mdot
.72201 .31842 Mdot
.3875 .29563 Mdot
.67614 .56618 Mdot
.27744 .47743 Mdot
.45954 .46803 Mdot
.58381 .41725 Mdot
.39164 .23613 Mdot
.70502 .3831 Mdot
.45679 .64531 Mdot
.65887 .40253 Mdot
.67385 .58061 Mdot
.60984 .48393 Mdot
.25949 .4691 Mdot
.39548 .3126 Mdot
.41617 .60302 Mdot
.56254 .51921 Mdot
.48038 .45934 Mdot
.27955 .59293 Mdot
.54616 .64761 Mdot
.35787 .57774 Mdot
.69673 .58634 Mdot
.38695 .2743 Mdot
.62444 .41596 Mdot
.43696 .45001 Mdot
.38434 .26619 Mdot
.41656 .66956 Mdot
.56464 .65508 Mdot
.71055 .55863 Mdot
.2875 .46519 Mdot
.71405 .48807 Mdot
.35217 .42893 Mdot
.22663 .45871 Mdot
.4652 .60726 Mdot
.49262 .40457 Mdot
.43704 .21149 Mdot
.4655 .65492 Mdot
.62667 .40286 Mdot
.45867 .65618 Mdot
.7106 .32058 Mdot
.53005 .58172 Mdot
.46245 .63666 Mdot
.3888 .54588 Mdot
.65466 .52056 Mdot
.50643 .63805 Mdot
.45772 .37049 Mdot
.34675 .54847 Mdot
.44967 .63032 Mdot
.44951 .63476 Mdot
.40687 .59104 Mdot
.61397 .60767 Mdot
.44724 .35586 Mdot
.68234 .3805 Mdot
.47746 .22785 Mdot
.38938 .61906 Mdot
.28537 .49461 Mdot
.60244 .5385 Mdot
.46963 .38136 Mdot
.73828 .36217 Mdot
.41804 .2132 Mdot
.33962 .60388 Mdot
.6006 .66654 Mdot
.52565 .54678 Mdot
.30547 .54749 Mdot
.27718 .49246 Mdot
.66758 .5208 Mdot
.60476 .52562 Mdot
.43478 .53667 Mdot
.43902 .66355 Mdot
.61248 .66346 Mdot
.47065 .29202 Mdot
.48658 .23748 Mdot
.65404 .56771 Mdot
.36892 .59049 Mdot
.66411 .37081 Mdot
.58722 .73231 Mdot
.4969 .25787 Mdot
.63915 .52376 Mdot
.30793 .42178 Mdot
.32823 .55277 Mdot
.41119 .21104 Mdot
.42581 .36424 Mdot
.43663 .66711 Mdot
.57329 .66274 Mdot
.64541 .48878 Mdot
.52177 .39486 Mdot
.56692 .53898 Mdot
.64799 .36456 Mdot
.46594 .43057 Mdot
.49661 .38467 Mdot
.45727 .62588 Mdot
.50263 .57705 Mdot
.6575 .39253 Mdot
.5538 .38281 Mdot
.68168 .38889 Mdot
.41433 .52693 Mdot
.56524 .43761 Mdot
.67718 .39965 Mdot
.49718 .45841 Mdot
.64787 .53828 Mdot
.35965 .63206 Mdot
.51498 .55996 Mdot
.68493 .3507 Mdot
.46105 .66891 Mdot
.59875 .43304 Mdot
.49285 .64486 Mdot
.64729 .58695 Mdot
.44928 .36316 Mdot
.56206 .66197 Mdot
.6772 .38431 Mdot
.28943 .50283 Mdot
.57063 .40838 Mdot
.37369 .62105 Mdot
.37875 .53156 Mdot
.5194 .33166 Mdot
.43907 .47868 Mdot
.59362 .36357 Mdot
.25545 .41876 Mdot
.32143 .51213 Mdot
.44824 .32324 Mdot
.24425 .42927 Mdot
.51129 .44212 Mdot
.61212 .45782 Mdot
.51691 .73884 Mdot
.4301 .28963 Mdot
.26794 .43654 Mdot
.56625 .68505 Mdot
.68016 .37199 Mdot
.61349 .35234 Mdot
.38328 .26567 Mdot
.67394 .58406 Mdot
.52722 .43946 Mdot
.72252 .32575 Mdot
.55102 .50216 Mdot
.61662 .37425 Mdot
.61824 .54069 Mdot
.47646 .66925 Mdot
.422 .29617 Mdot
.61666 .46889 Mdot
.50652 .44584 Mdot
.30411 .53088 Mdot
.42405 .62996 Mdot
.25271 .44208 Mdot
.2939 .48991 Mdot
.67416 .45017 Mdot
.31522 .55784 Mdot
.62774 .44526 Mdot
.39439 .60317 Mdot
.65923 .37297 Mdot
.64709 .35577 Mdot
.57106 .42538 Mdot
.68969 .52416 Mdot
.38113 .27193 Mdot
.44844 .40287 Mdot
.33675 .61702 Mdot
.45199 .65405 Mdot
.43472 .21294 Mdot
.62752 .37399 Mdot
.43109 .41736 Mdot
.32818 .56762 Mdot
.46451 .43682 Mdot
.49476 .35094 Mdot
.50264 .48757 Mdot
.70094 .62768 Mdot
.39272 .61297 Mdot
.5631 .68331 Mdot
.50105 .65412 Mdot
.6914 .591 Mdot
.68281 .34992 Mdot
.55871 .63462 Mdot
.5015 .58624 Mdot
.49721 .43441 Mdot
.65405 .34566 Mdot
.65498 .57594 Mdot
.61354 .63492 Mdot
.38462 .63488 Mdot
.38688 .28903 Mdot
.48968 .67008 Mdot
.50015 .60733 Mdot
.5553 .57883 Mdot
.30788 .45821 Mdot
.67042 .59572 Mdot
.55717 .6556 Mdot
.43467 .64534 Mdot
.40683 .33095 Mdot
.56622 .59651 Mdot
.56135 .38195 Mdot
.64855 .42556 Mdot
.54176 .57922 Mdot
.65046 .35756 Mdot
.50252 .7305 Mdot
.40367 .31795 Mdot
.28816 .45612 Mdot
.59697 .36694 Mdot
.36368 .448 Mdot
.45621 .6138 Mdot
.50719 .38049 Mdot
.56499 .53809 Mdot
.6069 .64931 Mdot
.48292 .64883 Mdot
.70122 .35567 Mdot
.50061 .2761 Mdot
.72761 .54743 Mdot
.61199 .44172 Mdot
.31794 .57373 Mdot
.31312 .5777 Mdot
.60911 .60191 Mdot
.60663 .54354 Mdot
.4575 .58612 Mdot
.58446 .44785 Mdot
.37311 .60545 Mdot
.52181 .36855 Mdot
.40306 .22839 Mdot
.40675 .65481 Mdot
.72245 .33799 Mdot
.39132 .64236 Mdot
.40893 .6441 Mdot
.622 .40413 Mdot
.58135 .59749 Mdot
.52088 .42809 Mdot
.51338 .41193 Mdot
.54974 .70602 Mdot
.40016 .21951 Mdot
.56922 .63529 Mdot
.59077 .43318 Mdot
.65352 .49429 Mdot
.50801 .61998 Mdot
.73186 .48184 Mdot
.68061 .54257 Mdot
.70485 .34815 Mdot
.651 .37758 Mdot
.67928 .53389 Mdot
.6311 .54832 Mdot
.59441 .64588 Mdot
.41881 .32307 Mdot
.61388 .45434 Mdot
.46027 .36711 Mdot
.69906 .57928 Mdot
.38756 .57584 Mdot
.24015 .43028 Mdot
.27322 .44306 Mdot
.35923 .54369 Mdot
.44769 .45499 Mdot
.41017 .3428 Mdot
.57584 .36508 Mdot
.4818 .23294 Mdot
.65213 .48479 Mdot
.39266 .229 Mdot
.50765 .63478 Mdot
.51717 .33376 Mdot
.53419 .41289 Mdot
.56489 .59574 Mdot
.24504 .47358 Mdot
.46281 .50441 Mdot
.57764 .38769 Mdot
.59307 .63197 Mdot
.51465 .65872 Mdot
.48488 .34227 Mdot
.36364 .45006 Mdot
.28868 .60468 Mdot
.64451 .59538 Mdot
.71914 .48537 Mdot
.49388 .65385 Mdot
.409 .22928 Mdot
.61585 .63751 Mdot
.71464 .53882 Mdot
.61495 .59392 Mdot
.49981 .39159 Mdot
.72667 .5654 Mdot
.61648 .61328 Mdot
.73024 .31716 Mdot
.60925 .66657 Mdot
.44007 .45236 Mdot
.52017 .68357 Mdot
.2541 .41976 Mdot
.43646 .4963 Mdot
.55336 .37077 Mdot
.47685 .35008 Mdot
.2725 .49113 Mdot
.6003 .44438 Mdot
.40453 .33867 Mdot
.65776 .39639 Mdot
.65253 .42273 Mdot
.64861 .59645 Mdot
.43117 .61965 Mdot
.74096 .566 Mdot
.65638 .50451 Mdot
.35991 .61554 Mdot
.41503 .36281 Mdot
.44461 .4329 Mdot
.56382 .53253 Mdot
.46019 .48738 Mdot
.42805 .31792 Mdot
.66994 .35027 Mdot
.72732 .47406 Mdot
.72375 .44614 Mdot
.28466 .437 Mdot
.56798 .42074 Mdot
.44539 .55606 Mdot
.4223 .36984 Mdot
.66001 .52279 Mdot
.61626 .46677 Mdot
.66368 .38567 Mdot
.45624 .614 Mdot
.38008 .47288 Mdot
.38926 .2838 Mdot
.34324 .55442 Mdot
.70655 .36647 Mdot
.6983 .56841 Mdot
.6545 .48787 Mdot
.3944 .23177 Mdot
.4467 .58492 Mdot
.33052 .52671 Mdot
.37864 .26556 Mdot
.44423 .3053 Mdot
.59327 .64449 Mdot
.32758 .49401 Mdot
.73385 .31826 Mdot
.67839 .52324 Mdot
.52784 .40164 Mdot
.44236 .70437 Mdot
.65101 .44802 Mdot
.30629 .51801 Mdot
.42905 .41116 Mdot
.59044 .44161 Mdot
.42213 .66958 Mdot
.43661 .62467 Mdot
.62134 .43789 Mdot
.65543 .40948 Mdot
.36239 .59886 Mdot
.48635 .72243 Mdot
.41037 .53672 Mdot
.48122 .68119 Mdot
.48144 .35678 Mdot
.42046 .22187 Mdot
.38651 .65018 Mdot
.41115 .32565 Mdot
.27494 .60128 Mdot
.4838 .6173 Mdot
.38581 .63973 Mdot
.26787 .46533 Mdot
.62469 .4372 Mdot
.38761 .23618 Mdot
.37739 .59895 Mdot
.4163 .22298 Mdot
.49795 .34212 Mdot
.45132 .67042 Mdot
.39899 .5884 Mdot
.28838 .48867 Mdot
.55307 .61679 Mdot
.58621 .60584 Mdot
.66385 .4964 Mdot
.61951 .37255 Mdot
.63256 .4995 Mdot
.36858 .47105 Mdot
.45265 .49291 Mdot
.4882 .37316 Mdot
.60972 .48224 Mdot
.48447 .36919 Mdot
.42668 .51651 Mdot
.35838 .43309 Mdot
.37728 .25557 Mdot
.56258 .6731 Mdot
.30571 .5021 Mdot
.50733 .2688 Mdot
.51692 .33287 Mdot
.25991 .59071 Mdot
.62155 .62425 Mdot
.30161 .42784 Mdot
.65022 .45944 Mdot
.47376 .35257 Mdot
.39236 .64017 Mdot
.28357 .48951 Mdot
.69598 .52471 Mdot
.36856 .44659 Mdot
.30012 .51962 Mdot
.64366 .60411 Mdot
.64108 .45756 Mdot
.73253 .43768 Mdot
.64033 .59025 Mdot
.52739 .63756 Mdot
.22348 .47523 Mdot
.53421 .35802 Mdot
.63111 .43641 Mdot
.60783 .60157 Mdot
.64827 .59427 Mdot
.67757 .38537 Mdot
.44871 .4128 Mdot
.67839 .57471 Mdot
.61155 .37382 Mdot
.26327 .47749 Mdot
.45732 .47905 Mdot
.57353 .62251 Mdot
.36493 .57002 Mdot
.43271 .3332 Mdot
.48635 .25432 Mdot
.56622 .36818 Mdot
.36951 .55815 Mdot
.44687 .32693 Mdot
.61952 .63389 Mdot
.70326 .30906 Mdot
.58366 .5927 Mdot
.48958 .64284 Mdot
.37005 .55074 Mdot
.58947 .52974 Mdot
.36499 .65549 Mdot
.32801 .49507 Mdot
.38698 .53038 Mdot
.7116 .53909 Mdot
.59823 .52866 Mdot
.51893 .62909 Mdot
.53481 .61893 Mdot
.43905 .3887 Mdot
.36287 .65029 Mdot
.36226 .48351 Mdot
.58153 .36798 Mdot
.22956 .44605 Mdot
.56627 .37285 Mdot
.54016 .42313 Mdot
.7009 .53968 Mdot
.63366 .44111 Mdot
.65176 .42894 Mdot
.46135 .40293 Mdot
.42646 .31047 Mdot
.35821 .62862 Mdot
.4239 .36488 Mdot
.48253 .49261 Mdot
.68982 .56137 Mdot
.337 .5571 Mdot
.38798 .2429 Mdot
.44419 .49938 Mdot
.45929 .29484 Mdot
.51142 .35968 Mdot
.47123 .37564 Mdot
.67137 .53894 Mdot
.57804 .70182 Mdot
.6528 .48306 Mdot
.3037 .4758 Mdot
.51436 .66296 Mdot
.46901 .23134 Mdot
.53012 .39252 Mdot
.58739 .47014 Mdot
.57782 .61577 Mdot
.3576 .58193 Mdot
.31237 .46986 Mdot
.67973 .46905 Mdot
.36885 .56517 Mdot
.44968 .45244 Mdot
.40958 .3438 Mdot
.33303 .61688 Mdot
.50701 .53571 Mdot
.44654 .48836 Mdot
.3889 .27401 Mdot
.68279 .47528 Mdot
.31084 .56541 Mdot
.37289 .63809 Mdot
.70865 .5455 Mdot
.61082 .35798 Mdot
.38672 .29456 Mdot
.69154 .53219 Mdot
.58416 .44682 Mdot
.60689 .69144 Mdot
.45366 .47476 Mdot
.4323 .64912 Mdot
.64166 .57615 Mdot
.58015 .33076 Mdot
.4728 .46137 Mdot
.38542 .22219 Mdot
.50609 .38661 Mdot
.5175 .42939 Mdot
.36877 .62556 Mdot
.66326 .38291 Mdot
.30671 .59556 Mdot
.68363 .57634 Mdot
.48708 .35758 Mdot
.69708 .52198 Mdot
.72856 .32223 Mdot
.54451 .58777 Mdot
.50662 .73279 Mdot
.56354 .42105 Mdot
.52393 .66794 Mdot
.59277 .50947 Mdot
.48397 .72198 Mdot
.54153 .67144 Mdot
.42978 .37885 Mdot
.57298 .56606 Mdot
.57329 .71588 Mdot
.3861 .60652 Mdot
.53085 .55428 Mdot
.59024 .58603 Mdot
.50113 .60694 Mdot
.50862 .58642 Mdot
.64931 .57981 Mdot
.52058 .53921 Mdot
.56705 .67476 Mdot
.64129 .56276 Mdot
.42581 .50634 Mdot
.62135 .42766 Mdot
.46944 .39674 Mdot
.72042 .38339 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0?ooooooB_ooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A006ooooo`03o`000?oooooooooo0?ooooooB_ooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0?ooooooB_oo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06
ooooo`?o0000oooooom:ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<oooo
o`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0Ooooool4o`000003ooooool0003o000000Ko0000_Oooool00006oooooomgMgOoV9RHoooooonH
V9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0OOoooolC
o`000;Wooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c006ooooo`03o`000?oooooooooo07_ooooo1Ol00002ooooo`Co00000oooool7o`000;Wooooo
000Looooo`03o`000?oooooooooo07[ooooo1?l00006ooooo`;o00000oooool2o`000;kooooo000L
ooooo`03o`000?oooooooooo07[ooooo0_l00002ooooo`;o0000bOooool001cooooo00?o0000oooo
ooooool0N?ooool4o`0000;ooooo0_l00003ooooo`Co0000`_ooool001cooooo00?o0000oooooooo
ool0N?ooool3o`0000Sooooo1?l00003ooooo`;o00003?ooool2o`000:oooooo000Looooo`03o`00
0?oooooooooo07Sooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l00002ooooo`Oo0000
2oooool3o`000:oooooo000Looooo`03o`000?oooooooooo07Sooooo0_l00002ooooo`;o000000?o
ooooo`000?l000000_l000000ooooooo0000o`000008o`000003ooooool0003o000000Cooooo1_l0
002^ooooo`007?ooool00ol0003oooooooooo`1hooooo`Ko00001_ooool=o`000004ooooool0003o
0000ooooo`?o000000?oooooo`000?l000000_l0002/ooooo`007?ooool00ol0003oooooooooo`1j
ooooo`Co00001_ooool@o`0000;ooooo0_l000000ooooooo0000o`000002o`000:cooooo000Loooo
o`03o`000?oooooooooo07Sooooo1_l00009oooooa3o00000_ooool3o`000003ooooool0003o0000
0:[ooooo000Looooo`03o`000?oooooooooo07Sooooo1_l0000:ooooo`Go000000?oooooo`000?l0
00002?l00004ooooo`Co0000ZOooool001cooooo00?o0000ooooooooool0O?ooool2o`0000[ooooo
4Ol00003ooooo`Co0000ZOooool001cooooo0_l00023ooooo`;o00001?oooolAo`0000Gooooo0ol0
002Xooooo`007?ooool00ol0003oooooooooo`1hooooo`;o00002?ooool4o`0000;ooooo5?l00003
ooooo`;o0000Z?ooool001cooooo00?o0000ooooooooool0Moooool3o`0000[ooooo0_l00003oooo
oa?o00000_ooool4o`000:Oooooo000Looooo`03o`000?oooooooooo07Oooooo0_l0000@oooooa;o
00000oooool4o`000:Oooooo000Looooo`03o`000?oooooooooo07Oooooo1?l00009ooooo`;o0000
0ooooolBo`000:kooooo000Looooo`03o`000?oooooooooo07Oooooo1?l00009ooooo`;o00001?oo
oolBo`000:gooooo000Looooo`03o`000?oooooooooo07Oooooo1?l00003ooooo`;o00002ooooolB
o`0000Cooooo0_l0002Vooooo`007?ooool00ol0003oooooooooo`1hooooo`Co00000_ooool2o`00
00Oooooo0_l00002oooooa;o00001?ooool2o`000:Kooooo000Looooo`03o`000?oooooooooo07So
oooo1Ol0000:ooooo`;o00000ooooolAo`0000;ooooo0_l00003ooooo`;o0000Xoooool001cooooo
00?o0000ooooooooool0N_ooool4o`0000oooooo4?l00002ooooo`;o00000oooool2o`000:?ooooo
000Looooo`03o`000?oooooooooo07cooooo0_l00005ooooo`;o00002?ooool6o`000003ooooool0
003o000000So00001Oooool4o`000:;ooooo000Looooo`03o`000?oooooooooo07_ooooo0_l00006
ooooo`;o00002?ooool2o`000003ooooool0003o000000co00001Oooool4o`000:;ooooo000Loooo
o`03o`000?oooooooooo07[ooooo0ol00009ooooo`;o000000?oooooo`000?l000001_ooool<o`00
00Cooooo1_l0002Rooooo`007?ooool00ol0003oooooooooo`1jooooo`;o00002_ooool5o`0000Wo
oooo3ol00002ooooo`;o0000X_ooool001cooooo00?o0000ooooooooool0N_ooool4o`0000Cooooo
0_l00002ooooo`Go00000oooool5o`000003ooooool0003o000000ko000000?oooooo`000?l00000
X_ooool001cooooo00?o0000ooooooooool0N_ooool4o`0000Cooooo0_l000000ooooooo0000o`00
0007ooooo`Oo000000?oooooo`000?l000003ol0002Rooooo`007?ooool2o`0007_ooooo0_l00002
ooooo`;o00000oooool4o`0000Cooooo0_l000001Ooooooo0000o`000?l0003ooooo00Ko000000?o
ooooo`000?l000000_ooool2o`0000Cooooo1?l0002Rooooo`007?ooool00ol0003oooooooooo`1n
ooooo`;o00000oooool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000003
o`000003ooooool0003o0000013o0000Xoooool001cooooo00?o0000ooooooooool0Q_ooool2o`00
00Gooooo1_l00005ooooo`_o00000oooool2o`0003gooooo0_l0001Rooooo`007?ooool00ol0003o
ooooooooo`1kooooo`?o00002?ooool3o`0000Cooooo0_l000000ooooooo0000o`000002o`0000So
oooo3ol0000fooooo`;o00000_ooool2o`000003ooooool0003o000005oooooo000Looooo`03o`00
0?oooooooooo07_ooooo1_l00005ooooo`?o00002?ooool3o`0000Sooooo4ol0000booooo`?o0000
1?ooool2o`0005oooooo000Looooo`03o`000?oooooooooo07gooooo1?l00003ooooo`;o00003?oo
ool3o`00013ooooo3Ol0000Yooooo`;o00001Oooool2o`0000;ooooo0_l00002ooooo`;o0000GOoo
ool001cooooo00?o0000ooooooooool0O?ooool2o`000003ooooool0003o000000?ooooo0_l00000
0ooooooo0000o`000005ooooo`;o00000oooool2o`000004ooooool0003o0000o`0000[ooooo3ol0
000Yooooo`Co00001oooool7o`0005cooooo000Looooo`03o`000?oooooooooo07cooooo0_l00000
0ooooooo0000o`000003ooooo`Go00000oooool4o`0000Kooooo1_l00007ooooo`ko000000?ooooo
o`000?l000009?ooool2o`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l000001Ol0001L
ooooo`007?ooool00ol0003oooooooooo`22ooooo`Go00001Oooool4o`0000Sooooo1?l00007oooo
oa?o00008_ooool3o`0000Sooooo0_l000000ooooooo0000o`000005o`0005cooooo000Looooo`03
o`000?oooooooooo08;ooooo0_l00009ooooo`;o00002Oooool6o`0000Kooooo4_l0000Sooooo`;o
000000?oooooo`000?l000002Oooool2o`0000;ooooo0ol0001Kooooo`007?ooool00ol0003ooooo
ooooo`20ooooo`;o00002oooool2o`0000cooooo0ol00006oooooaOo00008Oooool2o`0000Oooooo
1?l00002ooooo`?o0000Foooool001cooooo00?o0000ooooooooool0P?ooool2o`0000Oooooo0_l0
000Booooo`;o00001OoooolGo`0002[ooooo1?l00002ooooo`?o0000Foooool001cooooo00?o0000
ooooooooool0Q?ooool2o`0000?ooooo0_l0000;ooooo`Co00000oooool3o`0000Cooooo1_l00000
0ooooooo0000o`00000=o`0002?ooooo1?l00006ooooo`So0000F_ooool001cooooo00?o0000oooo
ooooool0P?ooool2o`0000;ooooo0_l000000ooooooo0000o`000008ooooo`;o00000oooool4o`00
00Cooooo0ol00003oooooaOo00002_ooool5o`0001?ooooo1_l00004ooooo`So0000F_ooool001co
oooo00?o0000ooooooooool0P?ooool3o`0000Cooooo0_l00008ooooo`;o00001oooool2o`0000;o
oooo1?l00002ooooo`;o000000?oooooo`000?l000004ol00009ooooo`Go00002?ooool2o`0000go
oooo0_l00003ooooo`Wo0000F_ooool001cooooo00?o0000ooooooooool0P?ooool3o`0000oooooo
0_l00006ooooo`;o000000?oooooo`000?l000000ol00005oooooaKo00002_ooool3o`0000Oooooo
0ol0000>ooooo`;o000000?oooooo`000?l000002?l0001Jooooo`007?ooool2o`00087ooooo0_l0
000@ooooo`;o00000oooool2o`0000Cooooo0_l00009oooooaGo00002oooool2o`0000Oooooo0ol0
0002ooooo`;o00000_ooool3o`0000Cooooo0ol000000ooooooo0000o`000008o`0005[ooooo000L
ooooo`03o`000?oooooooooo083ooooo0_l0000Dooooo`?o00000_ooool4o`0000Sooooo5_l00006
ooooo`;o00003Oooool2o`0000;ooooo0_l00002ooooo`?o00001?ooool2o`0000;ooooo2Ol0001K
ooooo`007?ooool00ol0003oooooooooo`2>ooooo`;o00001_ooool2o`000003ooooool0003o0000
00;o00001_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000Bo`0000Gooooo0_l00009oooo
o`;o00002oooool2o`0000?ooooo0_l000000ooooooo0000o`000009o`0005_ooooo000Looooo`03
o`000?oooooooooo08kooooo0_l00009ooooo`?o00001_ooool5o`0000?ooooo5?l00005ooooo`Co
00001oooool3o`0000oooooo0_l000000ooooooo0000o`00000:o`0005[ooooo000Looooo`03o`00
0?oooooooooo08?ooooo0_l00005ooooo`;o00000_ooool3o`0000Wooooo0_l00006ooooo`Go0000
0ooooolBo`0000Kooooo1Ol00008ooooo`;o00004_ooool<o`0005[ooooo000Looooo`03o`000?oo
oooooooo08?ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00000_ooool3o`0000Cooooo
0_l0000<ooooo`;o00000_ooool2o`0000Gooooo3_l000000ooooooo0000o`000003ooooo`;o0000
2oooool3o`0000cooooo0_l00003ooooo`_o0000Foooool001cooooo00?o0000ooooooooool0Q?oo
ool5o`0000Wooooo0_l000000ooooooo0000o`000003ooooo`;o00001oooool2o`000003ooooool0
003o000000;o00000oooool2o`000003ooooool0003o000000Wo00000_ooool5o`0000gooooo1?l0
000;ooooo`;o00000_ooool<o`0005_ooooo000Looooo`03o`000?oooooooooo08Cooooo0ol00008
ooooo`Go00001_ooool2o`000003ooooool0003o000000Oooooo1?l00003ooooo`;o000000?ooooo
o`000?l000001Ol00002ooooo`;o00000_ooool5o`0000?ooooo0_l00007ooooo`;o000000Cooooo
o`000?l0003ooooo0_l00003ooooo`?o00001_ooool;o`0005cooooo000Looooo`03o`000?oooooo
oooo08Gooooo0_l00008ooooo`Co00002?ooool4o`00017ooooo1ol00002ooooo`;o00000_ooool2
o`0000;ooooo2Ol000001?oooooo0000o`000?ooool2o`0000;ooooo1?l00003ooooo`?o000000Co
ooooo`000?l0003ooooo0_l000000ooooooo0000o`000008o`0005cooooo000Looooo`03o`000?oo
oooooooo08Kooooo0_l0000=ooooo`;o00001?ooool4o`0000;ooooo0_l0000=ooooo`;o00000_oo
ool2o`0000?ooooo0_l00006ooooo`Wo000000?oooooo`000?l000000_ooool5o`0000;ooooo0_l0
0005ooooo`;o000000Coooooo`000?l0003ooooo2_l0001Looooo`007?ooool00ol0003ooooooooo
o`26ooooo`Co00000_ooool2o`0000Oooooo0_l00006ooooo`;o00000_ooool2o`0000gooooo0_l0
000Cooooo`;o00002?ooool6o`000003ooooool0003o000000;ooooo0_l00006ooooo`So0000Gooo
ool001cooooo00?o0000ooooooooool0QOooool2o`000003ooooool0003o000000;ooooo0_l00005
ooooo`Co00001oooool2o`000003ooooool0003o000000?o00002_ooool2o`000004ooooool0003o
0000ooooo`Co00002?ooool2o`000003ooooool0003o000000[ooooo1Ol00002ooooo`Co00001Ooo
ool9o`0005oooooo000Looooo`03o`000?oooooooooo08Gooooo0ol0000;ooooo`;o00002Oooool2
o`000003ooooool0003o000000?o00002_ooool2o`000004ooooool0003o0000ooooo`Co00002?oo
ool2o`00013ooooo0_l00002ooooo`;o00001Oooool;o`0005oooooo000Looooo`03o`000?oooooo
oooo08Kooooo0_l00003ooooo`Co00004_ooool2o`0001Gooooo0_l00003ooooo`;o00005Oooool2
o`000003ooooool0003o000000?o00000oooool2o`0000?ooooo1Ol0001Pooooo`0000Koooooonk^
k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool0R?ooool2o`000003ooooool0003o000000;o00003?ooool6o`0000Oooooo0_l0
0004ooooo`;o00003Oooool2o`0001?ooooo0_l00003ooooo`;o000000?oooooo`000?l000002Ooo
ool4o`00063ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0Foooool2o`000003ooooool0003o000002Sooooo
0_l0000;ooooo`;o00001?ooool6o`0000Gooooo1_l00002ooooo`;o00008_ooool2o`0000;ooooo
0_l00004ooooo`Co00001?ooool2o`0006?ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oo
oooooooo00Wooooo1Ol00006ooooo`03o`000?oooooooooo05Oooooo1_l000000ooooooo0000o`00
0002o`000003ooooool0003o0000033ooooo0_l00007ooooo`;o00001_ooool3o`000003ooooool0
003o000000gooooo0_l0000?ooooo`Go00000oooool2o`0000;ooooo2ol00003ooooo`;o0000Hooo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?m4A4CogMgMooooool0
0007ooooo`?o0000EOooool=o`000003ooooool0003o000000;o00008_ooool2o`0000?ooooo0_l0
0002ooooo`;o00005?ooool2o`0000oooooo1?l0000;ooooo`Oo00000oooool2o`0000Cooooo1?l0
00000ooooooo0000o`000002o`0006Sooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`1Aooooo`?o000000?o
ooooo`000?l000002ol00002ooooo`?o000000?oooooo`000?l000007Oooool4o`0000?ooooo0_l0
0002ooooo`;o00002?ooool2o`0000[ooooo0_l0000Aooooo`;o00002Oooool5o`0000Oooooo0_l0
0007ooooo`So00000_ooool2o`0006;ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooo
oooo00[ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`1Aooooo`?o000000?ooooo
o`000?l000004?l000000ooooooo0000o`00000Mooooo`;o00001Oooool2o`0000cooooo0_l0000H
ooooo`;o00003_ooool2o`0000Gooooo0_l00002ooooo`?o000000?oooooo`000?l000001?ooool8
o`0000;ooooo0_l0001Rooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4
A4Co000000Oooooo00?o0000ooooooooool0E?oooolFo`0001kooooo0_l00004ooooo`;o00004ooo
ool2o`0000Oooooo0_l00008ooooo`;o00005Oooool2o`0000;ooooo1_l00003ooooo`co0000Hooo
ool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`00
0?oooooooooo05Cooooo6ol0000Iooooo`;o00001?ooool2o`0001?ooooo0_l00005ooooo`Co0000
7_ooool2o`0000Kooooo0_l00003ooooo`go0000Hoooool001cooooo00?o0000ooooooooool0COoo
ool2o`0000?ooooo1_l000000ooooooo0000o`00000Do`0001Wooooo0ol00003ooooo`;o00005?oo
ool2o`0000?ooooo0ol0000>ooooo`;o00002oooool2o`0000?ooooo0_l00005ooooo`;o00000_oo
ool>o`0006Cooooo000Looooo`03o`000?oooooooooo04gooooo3?l000001?oooooo0000o`000?oo
oolAo`000003ooooool0003o000001Oooooo0ol0000Fooooo`;o000000?oooooo`000?l000000ooo
ool2o`0000Sooooo1?l00003ooooo`;o00001_ooool2o`0000?ooooo0_l0000:ooooo`;o00000_oo
ool?o`0006?ooooo000Looooo`03o`000?oooooooooo04Wooooo0ol00003ooooo`[o00001_oooolC
o`0001Kooooo0_l0000Gooooo`;o00002Oooool2o`0000Gooooo1?l0000;ooooo`;o00002?ooool2
o`0000;ooooo0_l00004oooooa7o0000H_ooool001cooooo00?o0000ooooooooool0BOooool4o`00
0003ooooool0003o000000Co00002_ooool3o`000003ooooool0003o000000ko0000>_ooool2o`00
00Gooooo0_l000000ooooooo0000o`00000>ooooo`;o00001?ooool2o`000003ooooool0003o0000
00?o000000?oooooo`000?l000004?l0001Rooooo`007?ooool00ol0003oooooooooo`19ooooo`[o
000000?oooooo`000?l000002?ooool2o`0000;ooooo3ol0000Sooooo`;o00001?ooool2o`0000So
oooo0ol0000<ooooo`;o000000?oooooo`000?l000003_ooool2o`0000Oooooo2_l000000ooooooo
0000o`00000;o`0000;ooooo0_l0001Nooooo`007?ooool00ol0003oooooooooo`19ooooo`So0000
0oooool2o`0000Kooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000oo0000
5oooool3o`0000Gooooo0_l00004ooooo`;o00002?ooool3o`0001Gooooo0_l000000ooooooo0000
o`000002ooooo`;o00001oooool2o`0000;ooooo0_l000000ooooooo0000o`00000Co`000004oooo
ool0003o0000o`0005gooooo000Looooo`03o`000?oooooooooo04Oooooo0_l00005ooooo`;o0000
0oooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool4o`0000?ooooo3ol0000Dooooo`;o
000000Coooooo`000?l0003o00001?ooool2o`0000Wooooo0_l0000Booooo`;o000000?oooooo`00
0?l000001Oooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`Co000000?oooooo`00
0?l000000_ooool2o`000003ooooool0003o000001?o00000_ooool2o`0005gooooo000Looooo`03
o`000?oooooooooo04Oooooo1?l00008ooooo`;o00001?ooool2o`0000Kooooo0_l00002ooooo`go
00005oooool2o`0000Sooooo0_l00009ooooo`;o00001oooool2o`0000Wooooo1Ol0000?ooooo`Go
00001Oooool2o`0000;ooooo1?l000000ooooooo0000o`00000=o`0000;ooooo0_l0001Mooooo`00
7?ooool00ol0003oooooooooo`19ooooo`;o00000oooool2o`0000Gooooo0_l0000:ooooo`;o0000
0_oooolAo`0001gooooo0_l0000<ooooo`?o00000oooool2o`0000_ooooo0_l00006ooooo`;o0000
1Oooool2o`000003ooooool0003o000000;ooooo0_l00007ooooo`Go000000?oooooo`000?l00000
3Ol00002ooooo`;o0000GOooool001cooooo00?o0000ooooooooool0A_ooool3o`0000Gooooo0_l0
0005ooooo`;o00002_ooool2o`0000;ooooo4Ol0000Xooooo`;o000000Coooooo`000?l0003o0000
3?ooool2o`0000[ooooo0_l000000ooooooo0000o`000004o`0000?ooooo1?l00007ooooo`Co0000
00?oooooo`000?l000003ol00002ooooo`;o0000G?ooool001cooooo00?o0000ooooooooool0A_oo
ool3o`0000cooooo0_l0000>ooooo`So000000?oooooo`000?l000002?l0000Vooooo`;o000000?o
ooooo`000?l000003Oooool2o`0000Sooooo0ol00002ooooo`Co00001?ooool3o`0000Kooooo0_l0
00000ooooooo0000o`000009o`000003ooooool0003o000000So00000_ooool2o`0005cooooo000L
ooooo`;o0000AOooool3o`0001?ooooo0_l00009ooooo`Wo000000?oooooo`000?l000001ol0000B
ooooo`?o000000Coooooo`000?l0003ooooo0_l0000Wooooo`?o00000oooool2o`0000Gooooo0_l0
0007ooooo`;o000000?oooooo`000?l000005?l00003ooooo`;o0000Foooool001cooooo00?o0000
ooooooooool0A?ooool3o`0000?ooooo0_l0000>ooooo`;o00002?oooolAo`000003ooooool0003o
000001;ooooo0ol000001?oooooo0000o`000?ooool2o`0002cooooo0_l00003ooooo`;o000000?o
ooooo`000?l000003OoooolCo`0000?ooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`14
ooooo`Co00000_ooool4o`0000_ooooo0ol00004ooooo`?o000000?oooooo`000?l000003_l00002
ooooo`;o00005_ooool2o`0000kooooo0_l0000Oooooo`;o000000?oooooo`000?l000000_l00006
ooooo`;o00000_ooool2o`0000;ooooo4_l000000ooooooo0000o`000003ooooo`;o0000Foooool0
01cooooo00?o0000ooooooooool0@oooool5o`0000Cooooo0_l0000;ooooo`?o00001?ooool3o`00
0004ooooool0003o0000ooooo`ko00000_ooool2o`0001gooooo1?l00004ooooo`;o00008_ooool3
o`0000Oooooo0_l000001?oooooo0000o`000?l00002oooooaGo0000H?ooool001cooooo00?o0000
ooooooooool0@oooool3o`0000cooooo0_l00005ooooo`;o00002OoooolAo`0000;ooooo0ol0000=
ooooo`?o00003?ooool4o`0000Oooooo0_l0000Yooooo`;o000000?oooooo`000?l000000ooooolE
o`0000Cooooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00003?ooool3o`00
00;ooooo1Ol00006oooooa?o00000oooool2o`0000gooooo0ol00008ooooo`;o00003Oooool2o`00
00kooooo0_l0000Aooooo`;o00001_ooool2o`0000Oooooo5?l00003ooooo`?o0000F_ooool001co
oooo00?o0000ooooooooool0@oooool3o`0000_ooooo1?l00002ooooo`;o000000?oooooo`000?l0
00000_ooool2o`0000;ooooo6Ol0000=ooooo`?o00001oooool2o`0000Wooooo0_l0000Booooo`;o
00002?ooool2o`0000Oooooo0ol0000?oooooa;o00001?ooool3o`0005[ooooo000Looooo`03o`00
0?oooooooooo04?ooooo0_l000000ooooooo0000o`000004ooooo`;o00000oooool2o`0000_ooooo
0_l00002ooooo`;o000000?oooooo`000?l000005?l0000<ooooo`Co00002_ooool2o`0000Kooooo
0_l0000Dooooo`;o00001_ooool2o`0000Sooooo0_l0000@oooooa?o00000_ooool3o`0005[ooooo
000Looooo`03o`000?oooooooooo04?ooooo1Ol00004ooooo`?o00001?ooool2o`0000[ooooo0ol0
0003oooooa7o00000_ooool4o`0000[ooooo0ol00007ooooo`;o00000oooool2o`0001[ooooo1?l0
000Rooooo`Go000000?oooooo`000?l000002?l000000ooooooo0000o`000002ooooo`?o0000F_oo
ool001cooooo00?o0000ooooooooool0@oooool4o`0000;ooooo0_l00002ooooo`;o00000oooool3
o`000003ooooool0003o000000Oooooo0ol00004oooooa3o00000_ooool4o`0000[ooooo0ol00002
ooooo`;o00000oooool3o`0001kooooo0_l0000Booooo`;o00004?ooool2o`000003ooooool0003o
000000_o00001Oooool2o`0005_ooooo000Looooo`03o`000?oooooooooo04Cooooo1ol00007oooo
o`;o00000_ooool4o`0000cooooo5_l00009ooooo`?o00000oooool2o`0000Cooooo0_l0000_oooo
o`Go00002Oooool3o`0000Oooooo3Ol00003ooooo`?o0000G?ooool001cooooo00?o0000oooooooo
ool0A?ooool5o`0000kooooo0ol0000=oooooaGo00002Oooool4o`0003Sooooo1_l00009ooooo`?o
00002?ooool8o`0000?ooooo0_l00002ooooo`?o0000G?ooool001cooooo00?o0000ooooooooool0
A_ooool8o`0000Wooooo1Ol00004ooooo`;o000000?oooooo`000?l000000_oooolEo`0000Sooooo
1Ol00004ooooo`?o00000_ooool2o`0000cooooo0_l0000Oooooo`?o00002_ooool5o`0000Wooooo
4?l0001Mooooo`007?ooool00ol0003oooooooooo`19ooooo`So00001?ooool9o`0000;ooooo0_l0
00000ooooooo0000o`000004oooooa?o00001oooool4o`0000?ooooo0_l000001?oooooo0000o`00
0?l00002ooooo`;o00001Oooool2o`0000Gooooo0_l0000Rooooo`;o00001oooool3o`000004oooo
ool0003o0000o`0000[ooooo3Ol0001Nooooo`007?ooool00ol0003oooooooooo`1>ooooo`Go0000
0_ooool6o`000003ooooool0003o000000Wooooo5?l00007ooooo`Go00000oooool2o`0000?ooooo
0_l000000ooooooo0000o`000005ooooo`;o0000:Oooool2o`0000Oooooo0_l000000ooooooo0000
o`000004o`0000Sooooo3?l0001Oooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o00001Ooo
ool3o`0000cooooo0_l000000ooooooo0000o`00000?o`0000Kooooo1Ol00004ooooo`;o00000ooo
ool2o`000003ooooool0003o000002Gooooo0_l0000Eooooo`;o000000Coooooo`000?l0003o0000
3?ooool5o`0006;ooooo000Looooo`;o0000E_ooool2o`0001?ooooo4Ol00005ooooo`Ko00001?oo
ool2o`000003ooooool0003o000000?ooooo0_l0000<ooooo`;o00005oooool2o`0000oooooo0_l0
00000ooooooo0000o`000005ooooo`Co0000LOooool001cooooo00?o0000ooooooooool0EOooool3
o`0000;ooooo0_l00004ooooo`Co00002?oooolAo`000003ooooool0003o000000Go00002?ooool2
o`0000Cooooo0_l00007ooooo`;o00000_ooool2o`0000cooooo0ol00004ooooo`;o00004oooool2
o`000003ooooool0003o000000;ooooo0_l00003ooooo`;o0000LOooool001cooooo00?o0000oooo
ooooool0E_ooool6o`000004ooooool0003o0000ooooo`Co00001Oooool2o`000003ooooool0003o
000001Co00001Oooool2o`0000[ooooo0_l00007ooooo`;o00004?ooool3o`0000Cooooo0_l0000J
ooooo`;o00001_ooool2o`0006kooooo000Looooo`03o`000?oooooooooo05Sooooo1ol0000:oooo
o`;o00000_oooolEo`0000Gooooo0_l0000;ooooo`;o00009?ooool2o`000003ooooool0003o0000
01[ooooo0_l0001^ooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o000000?oooooo`000?l0
00002?ooool3o`0000?ooooo5Ol0000?ooooo`;o00000oooool2o`0002Cooooo0_l000000ooooooo
0000o`00002:ooooo`007?ooool00ol0003oooooooooo`1Uooooo`?o00000oooool2o`0000?ooooo
3Ol0000:ooooo`;o000000?oooooo`000?l000000oooool2o`0002kooooo0_l0000Aooooo`;o0000
1Oooool2o`0006kooooo000Looooo`03o`000?oooooooooo05kooooo1?l0000?ooooo`So000000?o
ooooo`000?l000001Ol00006ooooo`;o000000?oooooo`000?l000000oooool2o`0001oooooo0_l0
00000ooooooo0000o`00000:ooooo`;o00004Oooool2o`0000Gooooo0_l0001^ooooo`007?ooool0
0ol0003oooooooooo`1Nooooo`Co00004_ooool3o`0000Gooooo1Ol0000_ooooo`;o000000?ooooo
o`000?l000003?ooool2o`0000kooooo1_l00002ooooo`;o00001?ooool2o`0006Sooooo000Loooo
o`03o`000?oooooooooo05kooooo0_l0000_ooooo`;o0000;?ooool2o`0000;ooooo0_l00009oooo
o`;o00000oooool6o`0000;ooooo0_l000000ooooooo0000o`000003o`0006Sooooo000Looooo`03
o`000?oooooooooo05cooooo1?l00008ooooo`;o00006Oooool2o`0000[ooooo0_l0000/ooooo`Ko
00002Oooool2o`0000kooooo1?l0001Yooooo`007?ooool00ol0003oooooooooo`1Looooo`;o0000
00?oooooo`000?l000001oooool2o`0000[ooooo0_l000001?oooooo0000o`000?ooool2o`0000Oo
oooo0_l0000<ooooo`;o00008?ooool2o`0000Oooooo0_l000000ooooooo0000o`00000Looooo`;o
0000J_ooool001cooooo00?o0000ooooooooool0E_ooool6o`0000?ooooo0ol0000Booooo`Go0000
00?oooooo`000?l000005Oooool2o`0000kooooo0_l0000@ooooo`;o00000oooool2o`0000;ooooo
0_l00002ooooo`;o00000oooool2o`0001;ooooo0ol000000ooooooo0000o`00001Zooooo`007?oo
ool00ol0003oooooooooo`1Dooooo`Wo00000oooool2o`0001?ooooo0_l0000;ooooo`;o00001?oo
ool3o`0001Kooooo0_l0000Aooooo`;o00000_ooool2o`0000Cooooo1?l00003ooooo`;o00002?oo
ool2o`0000Sooooo0ol00008ooooo`;o0000Hoooool001cooooo00?o0000ooooooooool0D_ooool;
o`0002Gooooo0_l00004ooooo`?o00006_ooool2o`0000gooooo0_l00008ooooo`Go00000_ooool2
o`0000Sooooo0_l00005ooooo`;o00001Oooool5o`000004ooooool0003o0000o`0006?ooooo000L
ooooo`03o`000?oooooooooo057ooooo3ol0000Aooooo`;o00003oooool2o`0000kooooo0_l0000A
ooooo`;o00003Oooool2o`0000Kooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo1?l00008
ooooo`;o000000?oooooo`000?l000000_ooool5o`000003ooooool0003o000006Cooooo000Loooo
o`03o`000?oooooooooo053ooooo4_l0000?ooooo`;o00002?ooool2o`000003ooooool0003o0000
00cooooo0_l00004ooooo`;o00004oooool2o`0001?ooooo0_l00003ooooo`;o000000?oooooo`00
0?l000001?ooool4o`0000_ooooo0_l00004ooooo`;o000000?oooooo`000?l000000_l00003oooo
o`Co0000G?ooool001cooooo0_l0001Aooooo`go000000?oooooo`000?l000000_l00009ooooo`Co
00001Oooool2o`0000Gooooo0_l000000ooooooo0000o`00000<ooooo`;o00006Oooool2o`00017o
oooo0_l00008ooooo`;o00000oooool2o`000003ooooool0003o000001Cooooo1?l000000ooooooo
0000o`000005o`0005_ooooo000Looooo`03o`000?oooooooooo053ooooo4?l00007ooooo`;o0000
0_ooool4o`0000Gooooo0_l0000cooooo`;o00003oooool2o`0000_ooooo1?l00008ooooo`Co0000
4?ooool4o`000003ooooool0003o000005_ooooo000Looooo`03o`000?oooooooooo04oooooo3ol0
0002ooooo`;o00001Oooool2o`000003ooooool0003o000000;o00007oooool2o`0001Gooooo0_l0
0003ooooo`;o00005?ooool2o`0000Kooooo0_l0000:ooooo`Co00005Oooool2o`0005_ooooo000L
ooooo`03o`000?oooooooooo04oooooo4ol000000ooooooo0000o`000005ooooo`Co00001_ooool2
o`0000kooooo0_l00007ooooo`;o00005Oooool2o`0000Wooooo0_l0000>ooooo`;o00002Oooool2
o`0000Kooooo0_l0000?ooooo`?o00002Oooool2o`0005Sooooo000Looooo`03o`000?oooooooooo
04oooooo4Ol00003ooooo`;o00003oooool2o`0000Gooooo0_l00007ooooo`;o00007_ooool2o`00
00Wooooo0_l0000>ooooo`?o00002?ooool2o`000003ooooool0003o000000?ooooo0_l00008oooo
o`Ko000000Coooooo`000?l0003o00002Oooool2o`0005Sooooo000Looooo`03o`000?oooooooooo
053ooooo3_l00003ooooo`;o00004Oooool2o`0000Gooooo0_l00008ooooo`;o0000;oooool2o`00
00Oooooo0ol00008ooooo`;o000000?oooooo`000?l000002Oooool2o`0000;ooooo1_l00006oooo
o`;o00000oooool2o`0005[ooooo000Looooo`03o`000?oooooooooo053ooooo4?l000001?oooooo
0000o`000?l00003ooooo`;o00002oooool2o`0000_ooooo0_l00002ooooo`;o0000;oooool2o`00
0003ooooool0003o000001Kooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo1?l00002oooo
o`?o0000F_ooool001cooooo00?o0000ooooooooool0C_oooolBo`0000;ooooo0ol00002ooooo`;o
000000?oooooo`000?l000001oooool2o`0000cooooo0_l0000Aooooo`;o00008oooool2o`0000[o
oooo0_l0000:ooooo`;o00001?ooool2o`0000Kooooo0_l00004ooooo`Go00000_ooool2o`0005_o
oooo000Looooo`03o`000?oooooooooo04kooooo4Ol00004ooooo`?o00001?ooool2o`0000Cooooo
0_l000000ooooooo0000o`000005ooooo`;o00003Oooool2o`0000Wooooo0_l0000_ooooo`;o0000
4?ooool4o`0000Wooooo0ol000000ooooooo0000o`000002o`0005gooooo000Looooo`03o`000?oo
oooooooo053ooooo3ol00003ooooo`Go00002Oooool3o`0000Oooooo0_l0000=ooooo`;o00005Ooo
ool2o`0000oooooo0_l0000Jooooo`;o00000_ooool2o`0000Kooooo0ol00008ooooo`;o00001?oo
ool2o`0005gooooo000Looooo`03o`000?oooooooooo04oooooo3ol00004ooooo`;o000000?ooooo
o`000?l000002Oooool3o`0000Cooooo0_l00003ooooo`;o00008_ooool2o`0000Kooooo0_l00002
ooooo`;o00000oooool2o`0001?ooooo0ol00003ooooo`Oo00001?ooool2o`000003ooooool0003o
000000;o000000?oooooo`000?l000002Oooool2o`0005gooooo000Looooo`03o`000?oooooooooo
04oooooo3_l00009ooooo`;o00002?ooool2o`0000Gooooo0_l00003ooooo`;o00003oooool2o`00
00Oooooo0_l0000:ooooo`;o00001?ooool2o`0000;ooooo0_l0000Hooooo`?o00000oooool2o`00
0003ooooool0003o000000Kooooo0_l00003ooooo`;o000000?oooooo`000?l000002?ooool3o`00
00Gooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`1?ooooo`ko00002Oooool4o`0002?o
oooo0_l00002ooooo`;o00000oooool2o`0000Oooooo1Ol00005ooooo`;o00000_ooool2o`0000_o
oooo1?l0000@ooooo`;o00001oooool4o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l0
00000_l00004ooooo`?o0000E_ooool001cooooo00?o0000ooooooooool0Coooool<o`0000gooooo
0_l0000:ooooo`;o00002?ooool4o`0000Kooooo0_l00007ooooo`;o00003?ooool4o`0000Kooooo
0_l00002ooooo`;o00000_ooool4o`0000Gooooo1_l0000<ooooo`Co00001oooool4o`0000;ooooo
1?l00003ooooo`So00000oooool4o`0005Kooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGo
oooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`1?oooo
o`co00001_ooool2o`00017ooooo0_l00008ooooo`Co00001Oooool3o`0001Gooooo0_l000000ooo
oooo0000o`00000=ooooo`Co00001Oooool2o`0000;ooooo0_l00004ooooo`;o00001?ooool7o`00
00cooooo0_l00002ooooo`;o000000?oooooo`000?l000001_l00002ooooo`Go0000E_ooool00006
oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q
8@06ooooo`03o`000?oooooooooo057ooooo1?l00002ooooo`;o00000oooool2o`0000;ooooo0ol0
000Qooooo`;o000000?oooooo`000?l000001oooool2o`00013ooooo0_l00006ooooo`;o00000_oo
ool2o`0000Cooooo0_l00004ooooo`;o00000_ooool2o`0000Cooooo0_l00004ooooo`;o00000_oo
ool3o`0000Cooooo0ol00004ooooo`;o00000ooooolBo`0005Kooooo00000ooooooo410@ooooo`02
ooooo`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo057ooooo1?l00007ooooo`;o00000_ooool2o`00013ooooo0_l00003ooooo`;o000000?o
ooooo`000?l000002?ooool2o`0000[ooooo0_l0000Hooooo`;o00000_ooool2o`0000Cooooo0_l0
0003ooooo`;o00004oooool3o`0000Cooooo0ol00004ooooo`;o00000ooooolAo`0005Oooooo0000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oiRHV?ooooooV9RHob4Q
8@06ooooo`?o0000Doooool2o`000003ooooool0003o000001[ooooo0_l00003ooooo`;o000000?o
ooooo`000?l000000_l00005ooooo`;o0000=?ooool2o`0000Oooooo0_l00009ooooo`?o00000ooo
ool5o`0000Kooooo3ol000000ooooooo0000o`000002o`0005Oooooo00000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oo
oooooooo05Kooooo0_l00002ooooo`;o000000?oooooo`000?l000003?ooool2o`0000Sooooo0_l0
0003ooooo`Co00001Oooool2o`0003Kooooo0_l00005ooooo`;o00002Oooool=o`0000Cooooo4ol0
001Hooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`03oeEEEOn7QhOo
oooo00Sooooo00?o0000ooooooooool0F_ooool5o`0000?ooooo0_l00007ooooo`;o00002?ooool2
o`0000?ooooo0_l0000Gooooo`;o00002?ooool4o`0000Oooooo0_l0000?ooooo`Co00001oooool2
o`0000Cooooo4_l000000ooooooo0000o`00000Bo`0005Sooooo00001_ooooooMgMgoiRHV?oooooo
V9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`1Kooooo`Co00000ooo
ool4o`00017ooooo0_l0000?ooooo`;o00002Oooool2o`0000Oooooo1Ol00007ooooo`;o00003ooo
ool2o`0000Wooooo0_l00003ooooobCo000000?oooooo`000?l00000FOooool00006ooooooo^k^ko
<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo05co
oooo0ol00002ooooo`;o000000?oooooo`000?l000002oooool2o`0000Cooooo0_l00003ooooo`;o
00002_ooool2o`0000Cooooo1?l000000ooooooo0000o`000007ooooo`Co00004oooool2o`000003
ooooool0003o000000;o00001?ooool2o`0000Cooooo0_l00002ooooobSo0000FOooool001cooooo
00?o0000ooooooooool0HOooool3o`0000Cooooo1?l000000ooooooo0000o`000002ooooo`;o0000
2?ooool3o`00013ooooo1?l00007ooooo`;o00000oooool2o`0000[ooooo0_l00004ooooo`;o0000
00Coooooo`000?l0003ooooo1Ol00003ooooo`;o00001?ooool2o`0000;ooooo9_l0001Kooooo`00
7?ooool00ol0003oooooooooo`1Rooooo`;o00001?ooool4o`000004ooooool0003o0000o`0000Ko
oooo0_l00003ooooo`;o00002oooool2o`0000oooooo0_l00006ooooo`;o00000_ooool2o`0000?o
oooo0_l00003ooooo`?o00001oooool2o`0000gooooo6ol000000ooooooo0000o`000007o`0005co
oooo000Looooo`03o`000?oooooooooo06Cooooo2?l000001?oooooo0000o`000?l00006ooooo`;o
00000oooool2o`000003ooooool0003o000000Sooooo1?l0000Eooooo`;o00000_ooool2o`0000So
oooo0_l00005ooooo`?o00001?ooool2o`0000Oooooo9Ol0001Nooooo`007?ooool00ol0003ooooo
ooooo`1Rooooo`go000000?oooooo`000?l000000_ooool2o`0000Sooooo0_l0000:ooooo`?o0000
1?ooool2o`0000Gooooo0_l0000Looooo`?o00001?ooool2o`0000Kooooo8ol0001Qooooo`007?oo
ool00ol0003oooooooooo`1RoooooaCo000000Coooooo`000?l0003o00002Oooool5o`0000?ooooo
0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000;ooooo`;o
00005Oooool2o`000003ooooool0003o000000Cooooo8?l0001Tooooo`007?ooool00ol0003ooooo
ooooo`1Roooooa?o00000_ooool3o`0000Wooooo1Ol00006ooooo`;o00001Oooool2o`0000cooooo
1?l0000>ooooo`;o00001Oooool5o`0000?ooooo5ol00005ooooo`;o000000?oooooo`000?l00000
I?ooool001cooooo00?o0000ooooooooool0HOoooolBo`0000Cooooo1?l0000@ooooo`;o000000?o
ooooo`000?l000000_ooool3o`0000cooooo1_l0000;ooooo`;o000000?oooooo`000?l000001_oo
ool2o`0000?ooooo4ol00002ooooo`?o0000Koooool001cooooo00?o0000ooooooooool0HOooool2
o`000003ooooool0003o000000go00000_ooool2o`0000;ooooo1Ol0000=ooooo`;o000000?ooooo
o`000?l000000_ooool3o`000003ooooool0003o000000Oooooo1?l00002ooooo`;o000000?ooooo
o`000?l000001_ooool4o`000003ooooool0003o000000_ooooo4_l0001eooooo`007?ooool00ol0
003oooooooooo`1Roooooa7o00000_ooool2o`0000?ooooo1?l0000Booooo`;o00001?ooool2o`00
00?ooooo0_l00002ooooo`Co000000?oooooo`000?l000000_ooool2o`0000Kooooo0_l0000<oooo
o`;o000000?oooooo`000?l000004Ol0001eooooo`007?ooool00ol0003oooooooooo`1Roooooa7o
000000Coooooo`000?l0003o00001?ooool2o`0000Cooooo0_l00006ooooo`;o00001Oooool3o`00
00Sooooo0ol000000ooooooo0000o`000003ooooo`;o00005oooool3o`000004ooooool0003o0000
o`0000;ooooo2ol0001hooooo`007?ooool00ol0003oooooooooo`1Soooooa3o000000?oooooo`00
0?l000002Oooool4o`0000Kooooo0_l00006ooooo`;o00001_ooool2o`000004ooooool0003o0000
ooooo`;o00003Oooool2o`0000gooooo0_l00002ooooo`;o00001Oooool8o`0007Wooooo000Loooo
o`;o0000IOoooolBo`0000Cooooo0_l00003ooooo`;o00002?ooool2o`000004ooooool0003o0000
ooooo`;o00002?ooool2o`00017ooooo1?l00003ooooo`;o000000Coooooo`000?l0003o00000ooo
ool2o`0000?ooooo0ol00004ooooo`;o0000Ooooool001cooooo00?o0000ooooooooool0I?oooolA
o`0000Gooooo0_l00004ooooo`;o00001Oooool2o`0000;ooooo0ol000000ooooooo0000o`000002
ooooo`;o00000_ooool3o`0000?ooooo1?l0000;ooooo`?o00000_ooool8o`0000?ooooo0_l00004
ooooo`;o00001?ooool2o`0007oooooo000Looooo`03o`000?oooooooooo06Cooooo4_l0000:oooo
o`;o00001Oooool2o`000003ooooool0003o000000Wo00000_ooool3o`0000?ooooo1?l00002oooo
o`;o00001oooool2o`0000?ooooo0_l000000ooooooo0000o`00000@ooooo`?o0000P?ooool001co
oooo00?o0000ooooooooool0I?ooool3o`000003ooooool0003o000000co00002_ooool2o`0000So
oooo2_l00002ooooo`Co00002Oooool2o`0000Oooooo0_l00005ooooo`;o00002_ooool2o`0000Co
oooo1?l00020ooooo`007?ooool00ol0003oooooooooo`1Tooooo`?o00000_ooool;o`0000Gooooo
1_l000001?oooooo0000o`000?l00005ooooo`;o000000?oooooo`000?l000002ol00002ooooo`;o
00001oooool2o`0000Cooooo0ol00007ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?o
oooo0_l00002ooooo`Go0000POooool001cooooo00?o0000ooooooooool0IOooool2o`0000Cooooo
1ol00007ooooo`[o000000?oooooo`000?l000000_ooool5o`0000Gooooo1Ol00003ooooo`;o0000
1oooool2o`000004ooooool0003o0000ooooo`?o00002_ooool2o`0000;ooooo1?l000001?oooooo
0000o`000?ooool6o`00087ooooo000Looooo`03o`000?oooooooooo06Wooooo0_l00003ooooo`Co
00002?ooool8o`0000;ooooo2_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o0000
00;o00000_ooool2o`0000Wooooo0_l00006ooooo`;o00002Oooool2o`000004ooooool0003o0000
ooooo`Go000000Coooooo`000?l0003o0000POooool001cooooo00?o0000ooooooooool0JOooool4
o`0000Wooooo2ol000000ooooooo0000o`00000@o`0000?ooooo0_l00002ooooo`;o00002?ooool2
o`0000Gooooo1?l000000ooooooo0000o`000002o`0000Cooooo0_l00004ooooo`?o00000_ooool3
o`0008;ooooo000Looooo`03o`000?oooooooooo06_ooooo0_l00009ooooo`Co000000?oooooo`00
0?l000000ol000000ooooooo0000o`00000Ao`0000cooooo0_l00002ooooo`?o00001Oooool3o`00
00;ooooo1Ol0000;ooooo`;o000000Coooooo`000?l0003o0000P_ooool001cooooo00?o0000oooo
ooooool0Noooool4o`000003ooooool0003o000001Ko000000?oooooo`000?l000001Oooool2o`00
0004ooooool0003o0000o`0000kooooo0_l0000;ooooo`;o000000Coooooo`000?l0003o0000P_oo
ool001cooooo00?o0000ooooooooool0Noooool3o`0000;ooooo7?l00007ooooo`Co00002oooool4
o`0000_ooooo0_l000000ooooooo0000o`000023ooooo`007?ooool00ol0003oooooooooo`1loooo
o`;o00000_oooolMo`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000_ooooo1?l0000=
ooooo`Co0000P_ooool001cooooo00?o0000ooooooooool0O?ooool2o`0000;ooooo7Ol000001?oo
oooo0000o`000?ooool2o`0000Kooooo0_l00009ooooo`;o00002oooool6o`0008;ooooo000Loooo
o`03o`000?oooooooooo07oooooo7ol000001?oooooo0000o`000?l00003ooooo`;o00000_ooool2
o`0000Oooooo0_l0000=ooooo`Ko0000P_ooool001cooooo00?o0000ooooooooool0O_ooool3o`00
0003ooooool0003o000001[o000000Coooooo`000?l0003o00000oooool7o`000003ooooool0003o
000000?ooooo0_l00009ooooo`Wo0000Poooool001cooooo00?o0000ooooooooool0O_ooool2o`00
00Oooooo9Ol000000ooooooo0000o`000004o`0000;ooooo0_l00004ooooo`_o0000Poooool001co
oooo0_l0002:oooooa7o000000?oooooo`000?l000003?l00006ooooo`So000000?oooooo`000?l0
00001_l000000ooooooo0000o`000002o`0008Cooooo000Looooo`03o`000?oooooooooo08Wooooo
7ol00004ooooo`;o000000?oooooo`000?l000001_l000000ooooooo0000o`000006o`000003oooo
ool0003o000008Kooooo000Looooo`03o`000?oooooooooo08_ooooo1ol00002ooooo`;o00000_oo
ool@o`000003ooooool0003o000000Ko00003Oooool2o`000003ooooool0003o000008Kooooo000L
ooooo`03o`000?oooooooooo08kooooo3?l000000ooooooo0000o`00000Io`0000Sooooo0_l00000
0ooooooo0000o`000026ooooo`007?ooool00ol0003oooooooooo`2>ooooobSo000000?oooooo`00
0?l000001?ooool3o`000003ooooool0003o000008Kooooo000Looooo`03o`000?oooooooooo08ko
oooo1ol00003ooooob;o00000oooool5o`0008Oooooo000Looooo`03o`000?oooooooooo09;ooooo
1Ol00003ooooob7o00000_ooool5o`0008Oooooo000Looooo`03o`000?oooooooooo09Gooooo0ol0
00000ooooooo0000o`00000Po`000003ooooool0003o000000;o0000ROooool001cooooo00?o0000
ooooooooool0U_ooool2o`000003ooooool0003o000001go000000Coooooo`000?l0003ooooo1Ol0
0028ooooo`007?ooool00ol0003oooooooooo`2Hooooo`;o00001Oooool2o`0000;ooooo6?l00000
0ooooooo0000o`000003o`0008Sooooo000Looooo`03o`000?oooooooooo09Sooooo0_l00005oooo
ob7o0000ROooool001cooooo00?o0000ooooooooool0WooooolKo`000003ooooool0003o000000;o
0000R_ooool001cooooo00?o0000ooooooooool0X?oooolIo`0000?ooooo0ol0002:ooooo`007?oo
ool00ol0003oooooooooo`2Pooooo`;o00000_oooolJo`0008_ooooo000Looooo`03o`000?oooooo
oooo0:Oooooo4?l000000ooooooo0000o`000003o`0008cooooo000Looooo`03o`000?oooooooooo
0:Wooooo2ol000000ooooooo0000o`000004ooooo`;o0000S?ooool001cooooo0_l0002[ooooo`So
0000Uoooool001cooooo00?o0000ooooooooool0[Oooool4o`0009Sooooo000Looooo`03o`000?oo
oooooooo0:oooooo0_l0002Hooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Go
c<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?ooooooB_ooool00006oooooomg
MgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06oooo
o`03o`000?oooooooooo0?ooooooB_ooool00003ooooool@413ooooo00;ooooo00?o410@oooooooo
ool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooom:oooo
o`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRH
V?lb<S801_ooool3o`000?ooooooB_ooool00003ooooool0003ooooo00;ooooo00?o0000oooooooo
ool02Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom:oooo
o`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj
^_l@41001_ooool00ol0003oooooooooo`3ooooood[ooooo00001_ooooooMgMgoiRHV?ooooooV9RH
ogMgM`_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0?ooooooB_oo
ool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Ko
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo
00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000D
ooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBoooo
o`004_ooool00omEEEGoIVIVo`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo002Yooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05Oooool0
1?l@413o0000odA4A?o<c<`4ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0U?ooool00:[ooooo00Go
0000ooooooooooooooooo`000009ooooo`Ko00002oooool00onHV9So410@omgMg@03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0U?ooool00:[ooooo00Go0000ooooooooooooooooo`00000Kooooo`03
ohN7QomEEEGooooo00;ooooo00Go410@oooooooooooooooooa0@402Dooooo`00Z_ooool01Ol0003o
oooooooooooooooo000000Wooooo1_l00009ooooo`05olc<c?lQ8B7o0000oeEEEOl000000oooool0
1Ol0003ooooooooooooooooo000009Cooooo002Zooooo`05o`000?n7QhOoooooojVYZOl000006?oo
ool01OlQ8B7oQhN7oooooonHV9So000000?ooooo00Go0000ooooooooooooooooo`00002Dooooo`00
ZOooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo01Kooooo00Go0000oooooooooooo
ooooo`000003ooooo`05oa0@4?ooooooooooooooool@4100U?ooool00<Oooooo00Go8B4QoiRHV?oo
ooooMgMgoeEEE@03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0U?ooool00<Oooooo00Goc<c<oa0@
4?l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0U?ooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -20 0 ]
[.5 1.0125 20 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(96) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.52042 .72409 Mdot
.48522 .73646 Mdot
.7098 .45912 Mdot
.33434 .4558 Mdot
.47361 .2245 Mdot
.70369 .46424 Mdot
.63691 .6408 Mdot
.62715 .62465 Mdot
.7138 .42883 Mdot
.34384 .39525 Mdot
.67028 .64925 Mdot
.2496 .53135 Mdot
.62631 .63764 Mdot
.36455 .42534 Mdot
.23484 .43716 Mdot
.30043 .605 Mdot
.51779 .73925 Mdot
.47152 .22672 Mdot
.30669 .62706 Mdot
.71737 .42906 Mdot
.46861 .28192 Mdot
.35005 .44314 Mdot
.50876 .72327 Mdot
.36574 .42627 Mdot
.3073 .62471 Mdot
.45381 .68786 Mdot
.50746 .71499 Mdot
.31093 .61668 Mdot
.2559 .52901 Mdot
.62069 .65001 Mdot
.32044 .60766 Mdot
.28423 .3774 Mdot
.54797 .32563 Mdot
.42503 .68696 Mdot
.7088 .65514 Mdot
.68498 .65938 Mdot
.69306 .44092 Mdot
.65923 .65354 Mdot
.60623 .63892 Mdot
.69864 .65392 Mdot
.69927 .65537 Mdot
.45424 .68693 Mdot
.70415 .66059 Mdot
.71603 .61278 Mdot
.37112 .46263 Mdot
.37971 .65657 Mdot
.73469 .42494 Mdot
.37055 .49466 Mdot
.52794 .74428 Mdot
.7344 .4101 Mdot
.33507 .37372 Mdot
.65572 .62387 Mdot
.56905 .36122 Mdot
.36781 .64929 Mdot
.61798 .63544 Mdot
.3099 .628 Mdot
.70149 .49682 Mdot
.36521 .45314 Mdot
.26062 .53371 Mdot
.39774 .6683 Mdot
.35318 .46203 Mdot
.4846 .27162 Mdot
.45486 .66012 Mdot
.70648 .50513 Mdot
.71402 .44534 Mdot
.63897 .65373 Mdot
.48335 .74129 Mdot
.68748 .63756 Mdot
.33746 .43259 Mdot
.74466 .41445 Mdot
.36729 .49871 Mdot
.67051 .64956 Mdot
.42786 .67009 Mdot
.34808 .42545 Mdot
.53472 .74642 Mdot
.70108 .6401 Mdot
.47312 .22042 Mdot
.4342 .6812 Mdot
.73222 .41174 Mdot
.37503 .52312 Mdot
.34452 .44476 Mdot
.58012 .71959 Mdot
.28128 .53142 Mdot
.43463 .66245 Mdot
.38058 .43796 Mdot
.56068 .75405 Mdot
.34706 .49724 Mdot
.31314 .60355 Mdot
.31177 .62185 Mdot
.25512 .54728 Mdot
.67971 .50572 Mdot
.48654 .71566 Mdot
.35677 .4357 Mdot
.33829 .42593 Mdot
.35253 .38279 Mdot
.38077 .41894 Mdot
.3134 .62495 Mdot
.54393 .35181 Mdot
.68883 .64786 Mdot
.58347 .36111 Mdot
.69544 .63648 Mdot
.5763 .37075 Mdot
.35206 .51015 Mdot
.68854 .46945 Mdot
.47037 .68585 Mdot
.54204 .34254 Mdot
.69952 .64409 Mdot
.35812 .43179 Mdot
.67534 .65762 Mdot
.49406 .71816 Mdot
.32667 .6171 Mdot
.49832 .26785 Mdot
.46542 .21182 Mdot
.46053 .70225 Mdot
.40991 .51084 Mdot
.35071 .47714 Mdot
.34909 .45565 Mdot
.47667 .72705 Mdot
.71683 .43641 Mdot
.73233 .48667 Mdot
.49014 .72661 Mdot
.68762 .65092 Mdot
.51954 .743 Mdot
.55494 .32247 Mdot
.71502 .43951 Mdot
.57476 .34361 Mdot
.55232 .36453 Mdot
.30223 .37755 Mdot
.37225 .39802 Mdot
.54887 .3152 Mdot
.68615 .46767 Mdot
.48813 .72825 Mdot
.63119 .63148 Mdot
.33849 .42233 Mdot
.43462 .66433 Mdot
.61626 .63832 Mdot
.5127 .26699 Mdot
.51697 .27914 Mdot
.43417 .67233 Mdot
.41779 .50362 Mdot
.65788 .65491 Mdot
.61804 .62301 Mdot
.33376 .37791 Mdot
.42347 .65878 Mdot
.48561 .22743 Mdot
.6123 .62664 Mdot
.62546 .38738 Mdot
.32753 .62463 Mdot
.31608 .36127 Mdot
.58121 .71068 Mdot
.33503 .37511 Mdot
.48283 .30186 Mdot
.48788 .27272 Mdot
.61467 .63619 Mdot
.33628 .47998 Mdot
.50318 .74493 Mdot
.43078 .66467 Mdot
.27229 .50758 Mdot
.54264 .33431 Mdot
.35771 .47378 Mdot
.58681 .37204 Mdot
.54961 .36191 Mdot
.36364 .42869 Mdot
.38697 .66209 Mdot
.47297 .69565 Mdot
.36027 .49193 Mdot
.69525 .43611 Mdot
.46964 .22678 Mdot
.68098 .65667 Mdot
.3788 .43217 Mdot
.35684 .38686 Mdot
.26342 .50955 Mdot
.62413 .61979 Mdot
.72157 .63714 Mdot
.75733 .38817 Mdot
.65875 .64645 Mdot
.72199 .64874 Mdot
.68814 .49566 Mdot
.26307 .5172 Mdot
.49523 .27009 Mdot
.5569 .34769 Mdot
.35856 .48863 Mdot
.33733 .36972 Mdot
.25234 .54572 Mdot
.4697 .27798 Mdot
.49699 .31021 Mdot
.56712 .71814 Mdot
.73027 .65111 Mdot
.33701 .4716 Mdot
.33911 .62653 Mdot
.32698 .36944 Mdot
.6078 .65159 Mdot
.63826 .62893 Mdot
.72286 .43942 Mdot
.71973 .43453 Mdot
.74739 .39299 Mdot
.25926 .50449 Mdot
.2429 .52655 Mdot
.3399 .44597 Mdot
.57542 .35766 Mdot
.44714 .65619 Mdot
.48591 .27025 Mdot
.51175 .74364 Mdot
.58137 .71759 Mdot
.38424 .49349 Mdot
.30482 .62978 Mdot
.67406 .44034 Mdot
.68858 .51934 Mdot
.55958 .3669 Mdot
.48244 .24614 Mdot
.36196 .46309 Mdot
.48467 .70779 Mdot
.33048 .37382 Mdot
.55879 .32866 Mdot
.45832 .2107 Mdot
.50194 .7275 Mdot
.37747 .49236 Mdot
.62344 .64036 Mdot
.67912 .49639 Mdot
.3473 .49746 Mdot
.3547 .42338 Mdot
.43601 .68114 Mdot
.33115 .45657 Mdot
.32687 .63608 Mdot
.32257 .61659 Mdot
.74732 .39706 Mdot
.71129 .64037 Mdot
.65024 .64587 Mdot
.73527 .42555 Mdot
.44207 .67977 Mdot
.41548 .69472 Mdot
.69545 .47862 Mdot
.46425 .26802 Mdot
.66589 .65124 Mdot
.5016 .25022 Mdot
.69356 .47124 Mdot
.47353 .2277 Mdot
.26138 .5377 Mdot
.68003 .47048 Mdot
.50507 .2711 Mdot
.2561 .44451 Mdot
.54938 .3566 Mdot
.51852 .25741 Mdot
.64076 .64096 Mdot
.52011 .7586 Mdot
.35671 .49004 Mdot
.56376 .3562 Mdot
.57523 .34002 Mdot
.26704 .51729 Mdot
.57843 .38212 Mdot
.54808 .332 Mdot
.26764 .51474 Mdot
.47382 .25385 Mdot
.58949 .68244 Mdot
.32212 .60928 Mdot
.51743 .742 Mdot
.33183 .45771 Mdot
.71652 .64137 Mdot
.61527 .63828 Mdot
.35777 .46366 Mdot
.57396 .72913 Mdot
.64554 .64042 Mdot
.36205 .44148 Mdot
.60822 .64291 Mdot
.43644 .66446 Mdot
.38268 .4962 Mdot
.42279 .66509 Mdot
.36509 .42992 Mdot
.6075 .64289 Mdot
.73312 .42404 Mdot
.45178 .68543 Mdot
.3538 .43706 Mdot
.33782 .44424 Mdot
.573 .35782 Mdot
.32492 .6189 Mdot
.63806 .61295 Mdot
.25043 .52916 Mdot
.69649 .5105 Mdot
.27999 .5062 Mdot
.51587 .29688 Mdot
.63328 .38396 Mdot
.42282 .65879 Mdot
.57646 .3822 Mdot
.70036 .47301 Mdot
.34447 .38137 Mdot
.38349 .48143 Mdot
.37418 .45521 Mdot
.55145 .33262 Mdot
.28408 .52719 Mdot
.66128 .63674 Mdot
.32938 .63103 Mdot
.57717 .33193 Mdot
.70413 .49253 Mdot
.58073 .36895 Mdot
.382 .42812 Mdot
.50159 .71931 Mdot
.30116 .61619 Mdot
.68511 .49848 Mdot
.51246 .72958 Mdot
.36679 .49278 Mdot
.69237 .636 Mdot
.53627 .30469 Mdot
.66538 .63681 Mdot
.30973 .61036 Mdot
.27884 .50723 Mdot
.74241 .41458 Mdot
.45161 .68252 Mdot
.6185 .63036 Mdot
.42602 .66805 Mdot
.34139 .38249 Mdot
.36737 .51161 Mdot
.41393 .65637 Mdot
.51388 .28866 Mdot
.75023 .38089 Mdot
.67261 .64611 Mdot
.5754 .34822 Mdot
.76367 .39431 Mdot
.52755 .73934 Mdot
.69219 .4657 Mdot
.43497 .47471 Mdot
.68403 .50793 Mdot
.30108 .62016 Mdot
.75813 .40302 Mdot
.26003 .50954 Mdot
.37815 .45392 Mdot
.71405 .50095 Mdot
.54082 .34518 Mdot
.36797 .41025 Mdot
.43903 .66724 Mdot
.27646 .38239 Mdot
.34896 .39287 Mdot
.26119 .50409 Mdot
.70241 .49321 Mdot
.42478 .49566 Mdot
.31861 .61249 Mdot
.30869 .61344 Mdot
.50477 .74122 Mdot
.56917 .34573 Mdot
.51389 .2596 Mdot
.52007 .26771 Mdot
.6531 .36354 Mdot
.27234 .55045 Mdot
.40521 .51011 Mdot
.442 .67627 Mdot
.73793 .40155 Mdot
.53839 .75452 Mdot
.55643 .32772 Mdot
.62812 .62412 Mdot
.72053 .63476 Mdot
.34766 .50006 Mdot
.56042 .31179 Mdot
.31149 .63805 Mdot
.52655 .75011 Mdot
.42795 .67262 Mdot
.61958 .62915 Mdot
.28971 .49782 Mdot
.33307 .4155 Mdot
.35308 .47172 Mdot
.63173 .62104 Mdot
.56835 .33541 Mdot
.264 .53171 Mdot
.29554 .36468 Mdot
.7314 .61857 Mdot
.37306 .44636 Mdot
.40783 .6742 Mdot
.3719 .46914 Mdot
.30855 .37671 Mdot
.36694 .45936 Mdot
.44423 .67423 Mdot
.34453 .61231 Mdot
.36619 .38339 Mdot
.66848 .45359 Mdot
.38648 .48787 Mdot
.50873 .2854 Mdot
.35403 .42884 Mdot
.35876 .47854 Mdot
.49437 .23395 Mdot
.46988 .70393 Mdot
.3644 .39424 Mdot
.58795 .68128 Mdot
.35383 .44102 Mdot
.68285 .65741 Mdot
.27636 .52755 Mdot
.28603 .38084 Mdot
.31784 .61494 Mdot
.50581 .72116 Mdot
.60674 .63476 Mdot
.69293 .65751 Mdot
.59238 .37359 Mdot
.61492 .63829 Mdot
.37808 .44255 Mdot
.27649 .5295 Mdot
.45993 .70224 Mdot
.54868 .3543 Mdot
.48396 .71637 Mdot
.53866 .26414 Mdot
.64512 .63727 Mdot
.57148 .36702 Mdot
.27135 .49691 Mdot
.65198 .63031 Mdot
.58981 .67236 Mdot
.32668 .61584 Mdot
.56997 .33662 Mdot
.51792 .72271 Mdot
.74892 .41116 Mdot
.55394 .3296 Mdot
.61725 .63442 Mdot
.37065 .46416 Mdot
.31882 .62769 Mdot
.61266 .63404 Mdot
.41189 .67553 Mdot
.33059 .61893 Mdot
.35514 .44223 Mdot
.46184 .68767 Mdot
.47901 .72338 Mdot
.35436 .49456 Mdot
.34208 .47932 Mdot
.7072 .47726 Mdot
.55504 .33225 Mdot
.55756 .33409 Mdot
.55343 .36841 Mdot
.68601 .50633 Mdot
.75785 .37707 Mdot
.70967 .64575 Mdot
.28527 .38258 Mdot
.70445 .63382 Mdot
.56379 .35998 Mdot
.70768 .47478 Mdot
.37271 .46439 Mdot
.29192 .50363 Mdot
.60249 .63948 Mdot
.76218 .37033 Mdot
.34615 .50213 Mdot
.51119 .74807 Mdot
.649 .62075 Mdot
.24489 .52752 Mdot
.74103 .40222 Mdot
.49398 .28488 Mdot
.40467 .51265 Mdot
.64474 .62074 Mdot
.43833 .68883 Mdot
.64445 .62091 Mdot
.35969 .4791 Mdot
.37399 .41174 Mdot
.5099 .75579 Mdot
.50879 .28613 Mdot
.25349 .52407 Mdot
.36509 .43824 Mdot
.73683 .40154 Mdot
.53895 .75328 Mdot
.52152 .27238 Mdot
.25645 .53574 Mdot
.56204 .37191 Mdot
.48598 .27952 Mdot
.34287 .43902 Mdot
.26689 .51144 Mdot
.56998 .32757 Mdot
.6133 .64621 Mdot
.5134 .28442 Mdot
.67108 .44546 Mdot
.50942 .73113 Mdot
.71233 .64301 Mdot
.59222 .38281 Mdot
.67412 .64647 Mdot
.28985 .46528 Mdot
.56735 .36894 Mdot
.72715 .63274 Mdot
.41704 .19857 Mdot
.54699 .34109 Mdot
.70732 .49474 Mdot
.34981 .38763 Mdot
.26188 .51514 Mdot
.35582 .44182 Mdot
.51514 .26532 Mdot
.48252 .73086 Mdot
.72836 .64792 Mdot
.64203 .64795 Mdot
.36036 .41962 Mdot
.42114 .65813 Mdot
.56666 .73012 Mdot
.57942 .36472 Mdot
.49691 .25662 Mdot
.50319 .25492 Mdot
.35487 .41448 Mdot
.28576 .52835 Mdot
.44553 .67823 Mdot
.35411 .43649 Mdot
.35383 .41341 Mdot
.75251 .40081 Mdot
.46369 .68488 Mdot
.68048 .47548 Mdot
.30835 .63255 Mdot
.38211 .51858 Mdot
.70036 .63522 Mdot
.62811 .64459 Mdot
.56686 .34108 Mdot
.65448 .64487 Mdot
.75905 .38875 Mdot
.55691 .3339 Mdot
.35347 .43655 Mdot
.45902 .70082 Mdot
.35495 .43589 Mdot
.35451 .43973 Mdot
.36676 .46651 Mdot
.40165 .51222 Mdot
.67032 .48113 Mdot
.4927 .25724 Mdot
.25922 .53681 Mdot
.68994 .50204 Mdot
.68151 .4339 Mdot
.35198 .38182 Mdot
.34866 .43359 Mdot
.35367 .45337 Mdot
.44276 .68652 Mdot
.32623 .62976 Mdot
.64701 .63013 Mdot
.51089 .75616 Mdot
.34524 .49386 Mdot
.73834 .42275 Mdot
.3636 .39409 Mdot
.41467 .65734 Mdot
.71341 .64955 Mdot
.54492 .76259 Mdot
.59499 .38017 Mdot
.58346 .35087 Mdot
.54985 .33165 Mdot
.55455 .37048 Mdot
.69213 .66018 Mdot
.70834 .47292 Mdot
.53102 .30089 Mdot
.38218 .51566 Mdot
.33936 .47763 Mdot
.37655 .41613 Mdot
.75943 .3973 Mdot
.54545 .3207 Mdot
.35203 .39002 Mdot
.29608 .60024 Mdot
.67666 .463 Mdot
.54477 .35378 Mdot
.54094 .72583 Mdot
.50345 .72305 Mdot
.74085 .40621 Mdot
.65883 .65312 Mdot
.50715 .27385 Mdot
.71102 .34177 Mdot
.48379 .72014 Mdot
.46817 .67133 Mdot
.68429 .45372 Mdot
.27343 .53161 Mdot
.36214 .64561 Mdot
.69514 .46128 Mdot
.33221 .63045 Mdot
.47864 .73326 Mdot
.54966 .35889 Mdot
.28367 .51932 Mdot
.2701 .51792 Mdot
.71895 .42258 Mdot
.33836 .43866 Mdot
.69918 .52484 Mdot
.70587 .49316 Mdot
.56239 .34114 Mdot
.70221 .49291 Mdot
.65824 .63939 Mdot
.68649 .47995 Mdot
.41779 .67892 Mdot
.34716 .41324 Mdot
.36723 .64891 Mdot
.22991 .43192 Mdot
.34834 .47793 Mdot
.66133 .6292 Mdot
.71472 .6438 Mdot
.34469 .46827 Mdot
.47711 .22208 Mdot
.70893 .4887 Mdot
.75303 .38779 Mdot
.3177 .63058 Mdot
.75694 .40284 Mdot
.50323 .71951 Mdot
.70796 .64001 Mdot
.71498 .64329 Mdot
.55263 .33026 Mdot
.42697 .65982 Mdot
.72507 .65581 Mdot
.68904 .65105 Mdot
.5383 .30492 Mdot
.35515 .49233 Mdot
.47377 .69924 Mdot
.26434 .5313 Mdot
.4702 .22906 Mdot
.35267 .44265 Mdot
.68128 .47905 Mdot
.75177 .3919 Mdot
.23326 .43364 Mdot
.69722 .48008 Mdot
.57082 .34381 Mdot
.46856 .69228 Mdot
.31071 .62995 Mdot
.48494 .72669 Mdot
.33441 .43658 Mdot
.71301 .64047 Mdot
.50547 .72316 Mdot
.46557 .27189 Mdot
.35729 .45783 Mdot
.38309 .65714 Mdot
.25604 .53995 Mdot
.35424 .44366 Mdot
.71661 .44837 Mdot
.49134 .23132 Mdot
.48394 .28366 Mdot
.67076 .4579 Mdot
.47709 .24718 Mdot
.52364 .72221 Mdot
.71647 .44348 Mdot
.48815 .23966 Mdot
.65529 .36368 Mdot
.57306 .38159 Mdot
.48923 .24933 Mdot
.38033 .43788 Mdot
.61289 .63868 Mdot
.4971 .75086 Mdot
.37196 .41425 Mdot
.44206 .40495 Mdot
.34828 .65074 Mdot
.57491 .3606 Mdot
.35514 .44633 Mdot
.35672 .47998 Mdot
.42181 .65998 Mdot
.58395 .71178 Mdot
.70558 .50266 Mdot
.58016 .35443 Mdot
.48669 .72312 Mdot
.57976 .72076 Mdot
.71562 .45009 Mdot
.49706 .24244 Mdot
.62859 .64724 Mdot
.4522 .69928 Mdot
.56971 .3593 Mdot
.63868 .64099 Mdot
.67089 .46374 Mdot
.3382 .37495 Mdot
.31343 .59767 Mdot
.6923 .44982 Mdot
.33547 .37417 Mdot
.30637 .63369 Mdot
.74587 .39443 Mdot
.61213 .65297 Mdot
.49206 .71762 Mdot
.6139 .62936 Mdot
.50199 .25989 Mdot
.42483 .66879 Mdot
.48459 .7166 Mdot
.6289 .64479 Mdot
.35553 .64931 Mdot
.28744 .51689 Mdot
.70056 .64091 Mdot
.27064 .53907 Mdot
.33552 .37802 Mdot
.56816 .35653 Mdot
.49398 .26533 Mdot
.71009 .63988 Mdot
.45474 .68783 Mdot
.6907 .62473 Mdot
.33573 .37051 Mdot
.33024 .627 Mdot
.50665 .27784 Mdot
.56371 .72274 Mdot
.6196 .65277 Mdot
.64706 .63192 Mdot
.73728 .40103 Mdot
.48112 .22232 Mdot
.37944 .4472 Mdot
.76972 .36695 Mdot
.37739 .43037 Mdot
.64276 .61674 Mdot
.31345 .63837 Mdot
.50616 .73373 Mdot
.69244 .63918 Mdot
.30167 .62578 Mdot
.25162 .53084 Mdot
.34159 .47352 Mdot
.74759 .39798 Mdot
.48683 .74748 Mdot
.53468 .34022 Mdot
.35031 .47883 Mdot
.36507 .44256 Mdot
.57549 .33924 Mdot
.28863 .38086 Mdot
.59715 .65412 Mdot
.54373 .32841 Mdot
.67922 .45947 Mdot
.54723 .3522 Mdot
.57425 .34949 Mdot
.51137 .72006 Mdot
.74138 .39782 Mdot
.58124 .34596 Mdot
.36836 .43283 Mdot
.36075 .43255 Mdot
.60528 .63708 Mdot
.28423 .52408 Mdot
.26877 .52267 Mdot
.69778 .51012 Mdot
.54549 .30564 Mdot
.36392 .40091 Mdot
.43434 .66262 Mdot
.51811 .27432 Mdot
.59093 .36546 Mdot
.51401 .73467 Mdot
.37897 .41179 Mdot
.75318 .40064 Mdot
.54833 .34737 Mdot
.58739 .34892 Mdot
.50447 .27409 Mdot
.62082 .62063 Mdot
.4003 .65763 Mdot
.70667 .49332 Mdot
.3128 .60028 Mdot
.55668 .29657 Mdot
.74327 .40702 Mdot
.56818 .35509 Mdot
.56837 .37183 Mdot
.42692 .66083 Mdot
.41176 .67381 Mdot
.59937 .36845 Mdot
.6914 .50461 Mdot
.73967 .63779 Mdot
.68519 .643 Mdot
.2748 .50835 Mdot
.64917 .64428 Mdot
.49261 .71739 Mdot
.30109 .37613 Mdot
.50057 .25019 Mdot
.65203 .63191 Mdot
.54834 .33002 Mdot
.49081 .71936 Mdot
.41122 .66705 Mdot
.36627 .42904 Mdot
.3491 .44071 Mdot
.73438 .42536 Mdot
.32016 .36659 Mdot
.60146 .63681 Mdot
.51153 .25623 Mdot
.71207 .46992 Mdot
.31708 .62904 Mdot
.50516 .74548 Mdot
.5272 .35381 Mdot
.25327 .54295 Mdot
.69391 .50106 Mdot
.48664 .73828 Mdot
.51638 .25976 Mdot
.49224 .2552 Mdot
.35114 .48779 Mdot
.48789 .30704 Mdot
.65465 .63516 Mdot
.43711 .66682 Mdot
.53798 .73717 Mdot
.25815 .52645 Mdot
.34991 .43467 Mdot
.32538 .63403 Mdot
.72309 .65494 Mdot
.37981 .43636 Mdot
.51154 .27615 Mdot
.47906 .73538 Mdot
.37539 .45884 Mdot
.4878 .22288 Mdot
.53469 .3386 Mdot
.56114 .36648 Mdot
.71692 .49436 Mdot
.50525 .24083 Mdot
.49015 .22599 Mdot
.48629 .22081 Mdot
.72056 .63465 Mdot
.24577 .52803 Mdot
.54499 .28119 Mdot
.3388 .43837 Mdot
.3358 .37924 Mdot
.32102 .60033 Mdot
.67796 .63936 Mdot
.74015 .41506 Mdot
.36059 .46984 Mdot
.33848 .44219 Mdot
.51633 .76186 Mdot
.30013 .60348 Mdot
.36315 .48799 Mdot
.51127 .73923 Mdot
.49987 .70508 Mdot
.72198 .45083 Mdot
.57978 .71089 Mdot
.77094 .3614 Mdot
.26139 .54166 Mdot
.26902 .54383 Mdot
.4745 .70878 Mdot
.61601 .64497 Mdot
.26802 .54278 Mdot
.62556 .61886 Mdot
.47408 .7189 Mdot
.30587 .59603 Mdot
.41355 .67669 Mdot
.4849 .2728 Mdot
.36058 .47838 Mdot
.63836 .64367 Mdot
.35943 .47574 Mdot
.63398 .64522 Mdot
.42497 .49997 Mdot
.28028 .53773 Mdot
.3355 .47412 Mdot
.3835 .42717 Mdot
.47085 .28661 Mdot
.34838 .43738 Mdot
.73579 .40095 Mdot
.4977 .74178 Mdot
.55095 .31181 Mdot
.32105 .5949 Mdot
.35169 .38862 Mdot
.35269 .45243 Mdot
.34403 .65104 Mdot
.34757 .4572 Mdot
.77075 .36927 Mdot
.25809 .54262 Mdot
.3611 .48855 Mdot
.63697 .6272 Mdot
.67671 .64969 Mdot
.45779 .70178 Mdot
.56956 .37121 Mdot
.56582 .72083 Mdot
.36197 .43994 Mdot
.71607 .48536 Mdot
.46829 .25136 Mdot
.49568 .23198 Mdot
.4933 .74682 Mdot
.41203 .20557 Mdot
.70036 .66059 Mdot
.69544 .4336 Mdot
.32264 .60851 Mdot
.67917 .46767 Mdot
.70331 .50732 Mdot
.54135 .75187 Mdot
.49374 .26374 Mdot
.36044 .3949 Mdot
.40082 .67035 Mdot
.49236 .69711 Mdot
.25847 .52464 Mdot
.72071 .45598 Mdot
.57023 .32789 Mdot
.27258 .57274 Mdot
.47244 .24178 Mdot
.47899 .23974 Mdot
.62336 .64182 Mdot
.71612 .48741 Mdot
.57876 .35345 Mdot
.49217 .24173 Mdot
.72181 .44345 Mdot
.58278 .38378 Mdot
.74706 .38776 Mdot
.44236 .67488 Mdot
.42717 .48986 Mdot
.38152 .66118 Mdot
.67137 .63943 Mdot
.73643 .40583 Mdot
.44323 .68181 Mdot
.41832 .65544 Mdot
.57468 .35443 Mdot
.68208 .44355 Mdot
.4295 .65326 Mdot
.35587 .48758 Mdot
.5539 .36193 Mdot
.3632 .41514 Mdot
.47254 .2192 Mdot
.36026 .43736 Mdot
.73512 .42189 Mdot
.64722 .62606 Mdot
.70503 .48341 Mdot
.62763 .64277 Mdot
.28172 .38248 Mdot
.36142 .45222 Mdot
.35286 .43152 Mdot
.27575 .5272 Mdot
.49406 .71169 Mdot
.41023 .67763 Mdot
.69738 .49924 Mdot
.70457 .48714 Mdot
.3196 .59464 Mdot
.51919 .7472 Mdot
.59561 .39279 Mdot
.26886 .54105 Mdot
.3453 .45647 Mdot
.49761 .74064 Mdot
.3262 .60406 Mdot
.73896 .64361 Mdot
.28072 .52308 Mdot
.50409 .71728 Mdot
.75996 .37677 Mdot
.35298 .41247 Mdot
.58484 .35927 Mdot
.54166 .31279 Mdot
.2683 .55193 Mdot
.47067 .22749 Mdot
.50483 .72834 Mdot
.58598 .36699 Mdot
.50032 .74624 Mdot
.68588 .50959 Mdot
.71608 .65965 Mdot
.50512 .73788 Mdot
.35123 .45725 Mdot
.76882 .3614 Mdot
.61441 .64178 Mdot
.36707 .47318 Mdot
.6957 .64107 Mdot
.43138 .67588 Mdot
.49018 .73128 Mdot
.58348 .38379 Mdot
.33184 .63005 Mdot
.6545 .63356 Mdot
.33895 .48137 Mdot
.41817 .6806 Mdot
.30093 .61528 Mdot
.46979 .23133 Mdot
.36771 .40029 Mdot
.36182 .50699 Mdot
.73615 .39798 Mdot
.34733 .37686 Mdot
.72244 .64607 Mdot
.67797 .65723 Mdot
.73021 .64631 Mdot
.49857 .7119 Mdot
.49463 .29401 Mdot
.40465 .66207 Mdot
.5674 .34026 Mdot
.687 .43942 Mdot
.366 .46929 Mdot
.55256 .36942 Mdot
.71018 .64387 Mdot
.48709 .25281 Mdot
.25256 .54565 Mdot
.69772 .44685 Mdot
.57451 .37823 Mdot
.64606 .63517 Mdot
.45754 .69099 Mdot
.51076 .73472 Mdot
.75402 .38181 Mdot
.37257 .46602 Mdot
.35057 .43956 Mdot
.70588 .64918 Mdot
.49972 .31496 Mdot
.47647 .24247 Mdot
.54077 .34478 Mdot
.70454 .6474 Mdot
.28113 .52572 Mdot
.43019 .67785 Mdot
.35916 .48324 Mdot
.2776 .53167 Mdot
.72278 .63964 Mdot
.51258 .70437 Mdot
.47966 .25519 Mdot
.368 .51765 Mdot
.50285 .72761 Mdot
.62917 .63151 Mdot
.65407 .36806 Mdot
.31786 .63629 Mdot
.3369 .45987 Mdot
.37994 .49631 Mdot
.27151 .51204 Mdot
.31588 .6047 Mdot
.59393 .38115 Mdot
.37203 .5009 Mdot
.32249 .5961 Mdot
.30534 .60126 Mdot
.37225 .40591 Mdot
.37199 .40366 Mdot
.49473 .73647 Mdot
.2606 .50494 Mdot
.68311 .47165 Mdot
.33389 .63093 Mdot
.52321 .34409 Mdot
.32189 .611 Mdot
.27691 .50579 Mdot
.52224 .70949 Mdot
.29249 .52875 Mdot
.47327 .72472 Mdot
.52649 .73695 Mdot
.66992 .63992 Mdot
.30144 .61858 Mdot
.69441 .50181 Mdot
.58451 .3416 Mdot
.74133 .41226 Mdot
.49352 .73731 Mdot
.72097 .44641 Mdot
.6395 .65361 Mdot
.69239 .44957 Mdot
.67702 .46681 Mdot
.64826 .62514 Mdot
.50388 .75553 Mdot
.25346 .54125 Mdot
.65077 .6255 Mdot
.58125 .34228 Mdot
.49769 .24422 Mdot
.49013 .69698 Mdot
.54101 .33682 Mdot
.34984 .50585 Mdot
.73053 .62699 Mdot
.69269 .44204 Mdot
.38321 .493 Mdot
.52865 .74986 Mdot
.51812 .25871 Mdot
.50232 .7353 Mdot
.60055 .38077 Mdot
.48975 .27718 Mdot
.38144 .43779 Mdot
.51982 .33949 Mdot
.60749 .65204 Mdot
.35681 .38999 Mdot
.50255 .70658 Mdot
.74082 .41184 Mdot
.66415 .63435 Mdot
.58978 .66972 Mdot
.58315 .35848 Mdot
.5132 .7248 Mdot
.40581 .66815 Mdot
.56064 .3364 Mdot
.63216 .63141 Mdot
.38056 .6482 Mdot
.35295 .48472 Mdot
.66035 .6419 Mdot
.3644 .39989 Mdot
.41473 .50638 Mdot
.51946 .28626 Mdot
.55253 .36698 Mdot
.29977 .60158 Mdot
.7129 .44423 Mdot
.3158 .59397 Mdot
.33459 .4862 Mdot
.30555 .36765 Mdot
.33951 .45344 Mdot
.38351 .48999 Mdot
.76101 .38766 Mdot
.46191 .70382 Mdot
.55545 .35389 Mdot
.57074 .35735 Mdot
.29941 .61713 Mdot
.76063 .33628 Mdot
.48482 .24378 Mdot
.749 .38399 Mdot
.36172 .44943 Mdot
.34515 .44638 Mdot
.41881 .67244 Mdot
.43145 .48627 Mdot
.54837 .35808 Mdot
.33909 .46055 Mdot
.27832 .54721 Mdot
.62958 .62724 Mdot
.36014 .50509 Mdot
.35579 .41458 Mdot
.72713 .65484 Mdot
.63404 .62845 Mdot
.74791 .40177 Mdot
.57308 .38213 Mdot
.71617 .49784 Mdot
.47404 .24196 Mdot
.37637 .49701 Mdot
.29329 .3778 Mdot
.28494 .51298 Mdot
.47719 .25523 Mdot
.32048 .61392 Mdot
.3422 .50275 Mdot
.34001 .42769 Mdot
.47995 .24023 Mdot
.61542 .64816 Mdot
.49983 .73964 Mdot
.41985 .50133 Mdot
.57134 .35603 Mdot
.30737 .6018 Mdot
.47509 .21596 Mdot
.49881 .74559 Mdot
.38815 .66316 Mdot
.48482 .73286 Mdot
.64209 .6345 Mdot
.74116 .40089 Mdot
.49152 .27975 Mdot
.50324 .73549 Mdot
.71345 .43535 Mdot
.70493 .63737 Mdot
.26739 .50666 Mdot
.62109 .65119 Mdot
.54083 .75235 Mdot
.51697 .72556 Mdot
.53059 .73488 Mdot
.31633 .6321 Mdot
.38434 .48799 Mdot
.57116 .34301 Mdot
.70626 .64747 Mdot
.71065 .44441 Mdot
.31766 .3675 Mdot
.40533 .67672 Mdot
.38863 .43164 Mdot
.38249 .43165 Mdot
.36085 .43601 Mdot
.34828 .42307 Mdot
.59608 .37728 Mdot
.33946 .48947 Mdot
.34009 .43515 Mdot
.60065 .63727 Mdot
.74484 .40497 Mdot
.36381 .44762 Mdot
.55948 .36431 Mdot
.5603 .31067 Mdot
.51866 .25971 Mdot
.39503 .51689 Mdot
.44068 .65265 Mdot
.50543 .74231 Mdot
.68706 .4996 Mdot
.72078 .47054 Mdot
.51459 .2713 Mdot
.62689 .62417 Mdot
.48079 .72909 Mdot
.76134 .37188 Mdot
.49718 .28575 Mdot
.37198 .4435 Mdot
.27566 .52595 Mdot
.29437 .52245 Mdot
.26387 .51265 Mdot
.36636 .46582 Mdot
.54443 .33873 Mdot
.68831 .50384 Mdot
.25415 .51444 Mdot
.38279 .65545 Mdot
.48238 .2221 Mdot
.49995 .24282 Mdot
.47336 .69021 Mdot
.33179 .47402 Mdot
.6416 .64262 Mdot
.28365 .53156 Mdot
.63463 .61281 Mdot
.56008 .74217 Mdot
.54066 .26982 Mdot
.36345 .39376 Mdot
.35355 .38432 Mdot
.34704 .49945 Mdot
.47042 .68594 Mdot
.43951 .6904 Mdot
.45207 .68755 Mdot
.62719 .62713 Mdot
.34034 .37848 Mdot
.69703 .65652 Mdot
.54968 .36043 Mdot
.5063 .72485 Mdot
.23822 .54424 Mdot
.70429 .48661 Mdot
.30373 .59968 Mdot
.4969 .27521 Mdot
.2627 .52438 Mdot
.56011 .35876 Mdot
.37054 .51267 Mdot
.70749 .47327 Mdot
.43613 .68048 Mdot
.30706 .59762 Mdot
.66916 .47038 Mdot
.37186 .50018 Mdot
.52873 .31004 Mdot
.54823 .36474 Mdot
.48501 .27241 Mdot
.3504 .3832 Mdot
.50707 .28274 Mdot
.65266 .63415 Mdot
.36043 .45559 Mdot
.36 .48939 Mdot
.35237 .44857 Mdot
.38064 .42818 Mdot
.61895 .63205 Mdot
.30369 .61692 Mdot
.56984 .33133 Mdot
.56581 .37857 Mdot
.32014 .60843 Mdot
.49082 .26221 Mdot
.68515 .64359 Mdot
.74721 .40418 Mdot
.55693 .3288 Mdot
.50231 .29252 Mdot
.35566 .38982 Mdot
.34475 .46217 Mdot
.56527 .37647 Mdot
.38064 .43659 Mdot
.30913 .62341 Mdot
.68804 .45652 Mdot
.30629 .60678 Mdot
.51075 .24626 Mdot
.49992 .27708 Mdot
.61319 .63737 Mdot
.50497 .73637 Mdot
.51243 .26907 Mdot
.71063 .46551 Mdot
.35289 .49939 Mdot
.36909 .4012 Mdot
.41541 .6774 Mdot
.33683 .36959 Mdot
.50801 .24258 Mdot
.37989 .44438 Mdot
.45997 .68168 Mdot
.38944 .64652 Mdot
.337 .45768 Mdot
.31268 .62059 Mdot
.51633 .72324 Mdot
.49504 .2428 Mdot
.62637 .62288 Mdot
.23693 .41462 Mdot
.62687 .61891 Mdot
.45586 .68806 Mdot
.58428 .36433 Mdot
.51571 .75809 Mdot
.58528 .36279 Mdot
.52331 .70423 Mdot
.3505 .41269 Mdot
.4256 .68402 Mdot
.55719 .32188 Mdot
.69844 .50077 Mdot
.67746 .45201 Mdot
.54916 .34753 Mdot
.50636 .72751 Mdot
.56738 .34239 Mdot
.50655 .26775 Mdot
.71298 .63327 Mdot
.52674 .73448 Mdot
.67708 .46296 Mdot
.6938 .44245 Mdot
.70796 .6493 Mdot
.35753 .44323 Mdot
.35776 .48346 Mdot
.69449 .45143 Mdot
.6411 .61306 Mdot
.48096 .71052 Mdot
.35105 .43829 Mdot
.54706 .32705 Mdot
.68446 .46568 Mdot
.6628 .65979 Mdot
.41922 .66903 Mdot
.30207 .59772 Mdot
.30273 .36847 Mdot
.68397 .65821 Mdot
.35665 .50088 Mdot
.31229 .6243 Mdot
.48438 .2333 Mdot
.36998 .51608 Mdot
.33377 .37897 Mdot
.67753 .65503 Mdot
.58157 .34921 Mdot
.26215 .51369 Mdot
.67678 .49873 Mdot
.35903 .49577 Mdot
.42899 .19222 Mdot
.56258 .37463 Mdot
.37385 .43093 Mdot
.53763 .32287 Mdot
.48581 .72683 Mdot
.34994 .44568 Mdot
.70201 .63584 Mdot
.69144 .49745 Mdot
.37249 .46585 Mdot
.46457 .27198 Mdot
.69051 .63871 Mdot
.56112 .36 Mdot
.47717 .2461 Mdot
.33015 .61512 Mdot
.27689 .38278 Mdot
.75964 .39689 Mdot
.49233 .25148 Mdot
.35699 .44666 Mdot
.71229 .47403 Mdot
.67489 .64826 Mdot
.55301 .35102 Mdot
.35524 .39099 Mdot
.68751 .64803 Mdot
.63884 .62365 Mdot
.50353 .28217 Mdot
.42176 .70017 Mdot
.34491 .41069 Mdot
.36413 .42381 Mdot
.41831 .68964 Mdot
.40896 .66822 Mdot
.36131 .47664 Mdot
.36505 .41146 Mdot
.63944 .64145 Mdot
.34744 .3696 Mdot
.37128 .51218 Mdot
.55515 .32041 Mdot
.66579 .63361 Mdot
.72218 .46861 Mdot
.68976 .43994 Mdot
.4972 .25179 Mdot
.48404 .73632 Mdot
.51614 .28671 Mdot
.68734 .48832 Mdot
.37025 .43512 Mdot
.63769 .61738 Mdot
.29081 .59216 Mdot
.70157 .64237 Mdot
.70703 .45916 Mdot
.4168 .65906 Mdot
.28923 .50096 Mdot
.42675 .19291 Mdot
.58631 .65515 Mdot
.75532 .38308 Mdot
.49522 .23189 Mdot
.38287 .65537 Mdot
.35831 .45076 Mdot
.26468 .50499 Mdot
.37154 .46578 Mdot
.50712 .30113 Mdot
.75114 .4072 Mdot
.58289 .38382 Mdot
.58275 .35756 Mdot
.37879 .49325 Mdot
.63819 .62293 Mdot
.69619 .65857 Mdot
.58156 .37363 Mdot
.64074 .63281 Mdot
.36632 .42217 Mdot
.70242 .46355 Mdot
.53798 .71946 Mdot
.34594 .45722 Mdot
.53768 .30301 Mdot
.64186 .65456 Mdot
.4104 .65383 Mdot
.72194 .46167 Mdot
.35389 .38482 Mdot
.56961 .71647 Mdot
.65417 .63077 Mdot
.39513 .51536 Mdot
.69395 .49882 Mdot
.55541 .32839 Mdot
.71205 .48076 Mdot
.37231 .4309 Mdot
.36448 .39324 Mdot
.57831 .34166 Mdot
.34671 .45533 Mdot
.45056 .70518 Mdot
.32039 .63678 Mdot
.29531 .5971 Mdot
.3386 .43813 Mdot
.49904 .70683 Mdot
.6641 .64821 Mdot
.58333 .37287 Mdot
.27124 .51159 Mdot
.37731 .40777 Mdot
.50505 .7145 Mdot
.68203 .64372 Mdot
.58674 .70563 Mdot
.62401 .62958 Mdot
.69839 .50234 Mdot
.6314 .62288 Mdot
.34794 .49991 Mdot
.47331 .71559 Mdot
.6919 .47777 Mdot
.56591 .36071 Mdot
.70852 .42982 Mdot
.34982 .47818 Mdot
.63723 .65639 Mdot
.69279 .43556 Mdot
.3275 .63232 Mdot
.47609 .72016 Mdot
.51258 .3277 Mdot
.45013 .65722 Mdot
.37033 .43223 Mdot
.37015 .46683 Mdot
.5416 .3459 Mdot
.61442 .63536 Mdot
.41338 .66733 Mdot
.74316 .39161 Mdot
.51501 .25328 Mdot
.47296 .72363 Mdot
.51944 .2757 Mdot
.27309 .5313 Mdot
.45719 .69708 Mdot
.27749 .54759 Mdot
.62465 .6449 Mdot
.50971 .73208 Mdot
.46887 .2137 Mdot
.33892 .62724 Mdot
.49663 .26439 Mdot
.71972 .46279 Mdot
.2677 .54357 Mdot
.68137 .45902 Mdot
.71716 .64267 Mdot
.7492 .39463 Mdot
.65869 .63367 Mdot
.46627 .27543 Mdot
.31435 .63862 Mdot
.66601 .65323 Mdot
.70121 .63343 Mdot
.68288 .48407 Mdot
.57479 .37392 Mdot
.30535 .61254 Mdot
.59399 .36002 Mdot
.58574 .37707 Mdot
.69311 .65906 Mdot
.51335 .73549 Mdot
.51578 .7479 Mdot
.54927 .31074 Mdot
.51203 .73742 Mdot
.69176 .46354 Mdot
.2793 .52461 Mdot
.27351 .49633 Mdot
.66158 .64877 Mdot
.32901 .61283 Mdot
.35636 .50948 Mdot
.75694 .40516 Mdot
.69804 .4637 Mdot
.63218 .62504 Mdot
.54378 .74046 Mdot
.58795 .36474 Mdot
.41906 .66745 Mdot
.48654 .72069 Mdot
.48942 .72705 Mdot
.52709 .75842 Mdot
.33928 .37592 Mdot
.66186 .62932 Mdot
.50208 .72596 Mdot
.36776 .40681 Mdot
.35793 .4105 Mdot
.55852 .33068 Mdot
.49675 .29575 Mdot
.30962 .61743 Mdot
.57335 .34487 Mdot
.34252 .46939 Mdot
.70212 .49261 Mdot
.47652 .27626 Mdot
.58849 .35671 Mdot
.69174 .5036 Mdot
.69174 .50538 Mdot
.59323 .3695 Mdot
.47928 .27943 Mdot
.44929 .70347 Mdot
.34035 .63745 Mdot
.49898 .70581 Mdot
.68693 .43554 Mdot
.72544 .6469 Mdot
.41993 .68083 Mdot
.37038 .4731 Mdot
.53973 .32939 Mdot
.70555 .47413 Mdot
.52954 .73928 Mdot
.34932 .4302 Mdot
.57308 .35256 Mdot
.50092 .26389 Mdot
.56658 .36328 Mdot
.54333 .33989 Mdot
.47747 .69882 Mdot
.71875 .61085 Mdot
.4215 .65881 Mdot
.67081 .47407 Mdot
.56025 .35406 Mdot
.36615 .64838 Mdot
.73415 .41443 Mdot
.71088 .63196 Mdot
.32321 .63795 Mdot
.3357 .4469 Mdot
.68629 .49859 Mdot
.50263 .71913 Mdot
.6045 .64436 Mdot
.28772 .53803 Mdot
.50413 .73511 Mdot
.59189 .38344 Mdot
.54619 .34506 Mdot
.68335 .46741 Mdot
.46009 .69218 Mdot
.31318 .62407 Mdot
.49926 .7293 Mdot
.70133 .64999 Mdot
.38063 .44881 Mdot
.56609 .71987 Mdot
.57773 .35282 Mdot
.51019 .74561 Mdot
.71065 .44732 Mdot
.51169 .27736 Mdot
.37855 .4369 Mdot
.57493 .72641 Mdot
.35473 .45051 Mdot
.70614 .65109 Mdot
.55199 .30168 Mdot
.33459 .61387 Mdot
.36857 .45785 Mdot
.27146 .50681 Mdot
.68849 .63563 Mdot
.36559 .46079 Mdot
.28868 .50565 Mdot
.3841 .66085 Mdot
.43262 .67189 Mdot
.36308 .44636 Mdot
.69425 .45474 Mdot
.70584 .52873 Mdot
.35919 .41622 Mdot
.66792 .47394 Mdot
.28635 .52881 Mdot
.58777 .34577 Mdot
.46878 .23476 Mdot
.30204 .37564 Mdot
.37479 .44453 Mdot
.33563 .47329 Mdot
.38123 .44767 Mdot
.29655 .49163 Mdot
.6897 .4936 Mdot
.71519 .49733 Mdot
.50653 .26361 Mdot
.37923 .50062 Mdot
.50225 .27724 Mdot
.67375 .6479 Mdot
.30397 .62993 Mdot
.55647 .37367 Mdot
.50822 .74004 Mdot
.35038 .45006 Mdot
.71744 .46304 Mdot
.37382 .43405 Mdot
.32316 .62481 Mdot
.6885 .46443 Mdot
.7059 .47975 Mdot
.69248 .52097 Mdot
.49546 .2298 Mdot
.49295 .74361 Mdot
.34598 .49002 Mdot
.47876 .22435 Mdot
.58566 .34812 Mdot
.22807 .42737 Mdot
.47581 .72907 Mdot
.50315 .74753 Mdot
.51634 .75621 Mdot
.34072 .4861 Mdot
.34216 .48855 Mdot
.70165 .65404 Mdot
.40384 .66913 Mdot
.64447 .61676 Mdot
.68295 .49396 Mdot
.67651 .50374 Mdot
.37454 .43818 Mdot
.52235 .30023 Mdot
.49211 .26421 Mdot
.70302 .4332 Mdot
.54687 .35956 Mdot
.5124 .28346 Mdot
.34369 .48381 Mdot
.68064 .47196 Mdot
.48147 .21948 Mdot
.54562 .74721 Mdot
.58605 .69281 Mdot
.51174 .28057 Mdot
.58075 .35388 Mdot
.3938 .66483 Mdot
.31312 .37058 Mdot
.51925 .28367 Mdot
.66642 .64867 Mdot
.2532 .54315 Mdot
.54965 .36372 Mdot
.50603 .29212 Mdot
.32565 .36254 Mdot
.68731 .47923 Mdot
.58177 .35388 Mdot
.46472 .21374 Mdot
.26714 .49791 Mdot
.50832 .28743 Mdot
.50643 .7474 Mdot
.39919 .64541 Mdot
.37218 .45523 Mdot
.33235 .62469 Mdot
.63578 .649 Mdot
.71971 .45828 Mdot
.71868 .47941 Mdot
.43577 .68686 Mdot
.27969 .51546 Mdot
.68877 .45141 Mdot
.27349 .50912 Mdot
.49541 .29029 Mdot
.36756 .4062 Mdot
.55458 .31266 Mdot
.33924 .62263 Mdot
.47213 .21267 Mdot
.51174 .27906 Mdot
.65508 .64942 Mdot
.64599 .62625 Mdot
.61586 .63567 Mdot
.6864 .45494 Mdot
.26911 .52762 Mdot
.71523 .49438 Mdot
.41161 .69294 Mdot
.48629 .24384 Mdot
.76192 .37523 Mdot
.34484 .49936 Mdot
.3412 .47045 Mdot
.31797 .59848 Mdot
.54337 .33055 Mdot
.37135 .43189 Mdot
.69072 .65021 Mdot
.71312 .43481 Mdot
.63411 .65652 Mdot
.46486 .69062 Mdot
.40887 .68976 Mdot
.70376 .48331 Mdot
.53554 .30837 Mdot
.49472 .27219 Mdot
.29091 .36513 Mdot
.5085 .30306 Mdot
.70666 .49529 Mdot
.3351 .43599 Mdot
.52686 .73284 Mdot
.75607 .37319 Mdot
.35162 .44527 Mdot
.69391 .44039 Mdot
.73158 .42737 Mdot
.33682 .62338 Mdot
.34981 .37842 Mdot
.61232 .65257 Mdot
.27536 .51412 Mdot
.49502 .22745 Mdot
.57504 .3383 Mdot
.24035 .5515 Mdot
.68652 .48881 Mdot
.71402 .42803 Mdot
.51723 .27229 Mdot
.41131 .6548 Mdot
.52446 .74527 Mdot
.44984 .70285 Mdot
.69518 .65196 Mdot
.34456 .41887 Mdot
.68149 .4723 Mdot
.41577 .66188 Mdot
.36174 .50886 Mdot
.63061 .64063 Mdot
.70125 .43082 Mdot
.3468 .45497 Mdot
.36972 .4531 Mdot
.50305 .27463 Mdot
.56 .31002 Mdot
.55963 .3257 Mdot
.70501 .63075 Mdot
.38445 .46084 Mdot
.30215 .62636 Mdot
.33674 .45906 Mdot
.48255 .70952 Mdot
.56305 .33852 Mdot
.49324 .2627 Mdot
.36467 .49065 Mdot
.27254 .50285 Mdot
.51519 .72489 Mdot
.62933 .64481 Mdot
.56508 .35522 Mdot
.3836 .47574 Mdot
.34988 .45478 Mdot
.37516 .45588 Mdot
.3165 .63207 Mdot
.33943 .49265 Mdot
.74154 .41428 Mdot
.43119 .66043 Mdot
.47709 .23074 Mdot
.48787 .7318 Mdot
.74191 .3956 Mdot
.31902 .63749 Mdot
.26161 .53519 Mdot
.48645 .70394 Mdot
.47473 .72137 Mdot
.70394 .64966 Mdot
.65894 .62943 Mdot
.53026 .30309 Mdot
.37332 .41889 Mdot
.55665 .36932 Mdot
.49579 .7248 Mdot
.71979 .46186 Mdot
.50273 .27855 Mdot
.75605 .38144 Mdot
.3389 .45305 Mdot
.68358 .4821 Mdot
.5522 .34565 Mdot
.47018 .693 Mdot
.69934 .49381 Mdot
.55471 .32827 Mdot
.49547 .24088 Mdot
.25159 .53391 Mdot
.53018 .30842 Mdot
.58258 .36364 Mdot
.3744 .41843 Mdot
.30259 .58425 Mdot
.33165 .61967 Mdot
.55665 .32057 Mdot
.72238 .44538 Mdot
.5782 .35895 Mdot
.40048 .6524 Mdot
.3355 .62476 Mdot
.71356 .44354 Mdot
.41162 .67544 Mdot
.32378 .63747 Mdot
.58551 .3646 Mdot
.47808 .73339 Mdot
.73624 .40326 Mdot
.53322 .73414 Mdot
.32052 .37613 Mdot
.35351 .41991 Mdot
.68156 .45787 Mdot
.49803 .26453 Mdot
.70732 .65733 Mdot
.68116 .65946 Mdot
.6989 .63388 Mdot
.67594 .48365 Mdot
.34849 .45111 Mdot
.50595 .72969 Mdot
.65145 .6305 Mdot
.41535 .6704 Mdot
.71226 .46391 Mdot
.69996 .45805 Mdot
.31667 .59887 Mdot
.50134 .27866 Mdot
.34371 .49749 Mdot
.71957 .46397 Mdot
.74544 .39965 Mdot
.37698 .64834 Mdot
.48285 .21844 Mdot
.30903 .63055 Mdot
.56009 .31967 Mdot
.36313 .50264 Mdot
.39437 .67032 Mdot
.54798 .35147 Mdot
.46577 .69193 Mdot
.35837 .47099 Mdot
.73461 .59052 Mdot
.73457 .41396 Mdot
.27639 .5131 Mdot
.60914 .65253 Mdot
.65209 .62431 Mdot
.69545 .49314 Mdot
.34631 .43665 Mdot
.75786 .38027 Mdot
.49817 .25224 Mdot
.32891 .60063 Mdot
.58486 .37298 Mdot
.41348 .67311 Mdot
.63577 .6186 Mdot
.46723 .26907 Mdot
.70678 .65727 Mdot
.6152 .63902 Mdot
.51607 .70992 Mdot
.37253 .45335 Mdot
.70078 .47782 Mdot
.69969 .45115 Mdot
.55204 .31193 Mdot
.76957 .38076 Mdot
.52621 .75187 Mdot
.73074 .58619 Mdot
.24847 .51784 Mdot
.35713 .45682 Mdot
.59338 .38217 Mdot
.55553 .36687 Mdot
.74523 .39507 Mdot
.36497 .46326 Mdot
.44416 .68012 Mdot
.71898 .4859 Mdot
.68725 .44432 Mdot
.32934 .62908 Mdot
.64781 .62629 Mdot
.50734 .30407 Mdot
.69464 .46409 Mdot
.23497 .41846 Mdot
.37524 .43562 Mdot
.59392 .63575 Mdot
.69318 .46583 Mdot
.77046 .35177 Mdot
.74033 .63801 Mdot
.42164 .66128 Mdot
.24951 .5255 Mdot
.42575 .67307 Mdot
.50969 .28305 Mdot
.71225 .49354 Mdot
.68213 .65463 Mdot
.5621 .3573 Mdot
.70948 .52886 Mdot
.68369 .45461 Mdot
.495 .73783 Mdot
.37269 .45854 Mdot
.39031 .51924 Mdot
.34899 .45709 Mdot
.34804 .36959 Mdot
.50289 .23601 Mdot
.68077 .65947 Mdot
.70565 .64857 Mdot
.2494 .52526 Mdot
.48332 .2201 Mdot
.70076 .50533 Mdot
.68746 .4661 Mdot
.57709 .72002 Mdot
.54366 .34041 Mdot
.70514 .50467 Mdot
.3755 .42042 Mdot
.69103 .52054 Mdot
.40945 .67981 Mdot
.6453 .62386 Mdot
.38131 .42085 Mdot
.68048 .45736 Mdot
.4876 .70109 Mdot
.27311 .52331 Mdot
.36096 .41898 Mdot
.53857 .31847 Mdot
.65696 .63047 Mdot
.40282 .68634 Mdot
.75372 .40838 Mdot
.3506 .41376 Mdot
.68035 .64691 Mdot
.48392 .30277 Mdot
.71568 .52698 Mdot
.48904 .74205 Mdot
.69488 .4425 Mdot
.63015 .62123 Mdot
.55658 .34552 Mdot
.47578 .2312 Mdot
.71012 .48697 Mdot
.68713 .43985 Mdot
.32144 .61586 Mdot
.53747 .3084 Mdot
.51944 .28061 Mdot
.48137 .71224 Mdot
.63939 .64209 Mdot
.32559 .62619 Mdot
.24072 .40842 Mdot
.34404 .49039 Mdot
.61292 .63847 Mdot
.3697 .65044 Mdot
.34063 .42225 Mdot
.33788 .44687 Mdot
.38972 .51704 Mdot
.40295 .65482 Mdot
.49966 .71988 Mdot
.38558 .46109 Mdot
.31302 .61871 Mdot
.26583 .53398 Mdot
.50317 .74171 Mdot
.49011 .73674 Mdot
.2622 .52734 Mdot
.32284 .61879 Mdot
.41391 .6788 Mdot
.64497 .63 Mdot
.65271 .62486 Mdot
.48778 .72721 Mdot
.31981 .59879 Mdot
.61698 .64538 Mdot
.42556 .67744 Mdot
.70567 .46014 Mdot
.28677 .52304 Mdot
.48111 .72717 Mdot
.27218 .54248 Mdot
.65215 .63452 Mdot
.2496 .39376 Mdot
.28682 .52839 Mdot
.33352 .47141 Mdot
.37045 .4578 Mdot
.48994 .22818 Mdot
.56334 .36171 Mdot
.59331 .3696 Mdot
.61525 .63417 Mdot
.34032 .49046 Mdot
.45157 .68667 Mdot
.34139 .48993 Mdot
.31808 .36641 Mdot
.25591 .38764 Mdot
.2413 .53162 Mdot
.48618 .73728 Mdot
.45402 .68754 Mdot
.67341 .49085 Mdot
.71746 .43952 Mdot
.2822 .50699 Mdot
.65561 .62906 Mdot
.51445 .74422 Mdot
.64476 .61705 Mdot
.68648 .48661 Mdot
.70275 .47792 Mdot
.56403 .33663 Mdot
.58164 .35313 Mdot
.69366 .48661 Mdot
.66892 .46777 Mdot
.23723 .4115 Mdot
.41169 .67456 Mdot
.3755 .65589 Mdot
.28485 .37884 Mdot
.41619 .50522 Mdot
.49874 .26277 Mdot
.47509 .27324 Mdot
.68628 .64963 Mdot
.266 .50867 Mdot
.35145 .4726 Mdot
.57945 .36535 Mdot
.66844 .64023 Mdot
.48467 .2563 Mdot
.64816 .62378 Mdot
.47587 .2367 Mdot
.71312 .44497 Mdot
.34533 .44849 Mdot
.33494 .46792 Mdot
.70175 .64858 Mdot
.68227 .50983 Mdot
.6797 .47091 Mdot
.49544 .25975 Mdot
.29026 .37682 Mdot
.68344 .47213 Mdot
.48008 .72672 Mdot
.55211 .75208 Mdot
.55057 .35469 Mdot
.34847 .4324 Mdot
.29956 .37466 Mdot
.33512 .62662 Mdot
.58683 .34969 Mdot
.5657 .35511 Mdot
.42431 .70151 Mdot
.3556 .48809 Mdot
.58646 .70945 Mdot
.58279 .34976 Mdot
.51355 .75725 Mdot
.69919 .48055 Mdot
.58911 .3556 Mdot
.57221 .32836 Mdot
.48228 .20109 Mdot
.5951 .37108 Mdot
.51735 .73221 Mdot
.43104 .67654 Mdot
.30694 .60962 Mdot
.35828 .65455 Mdot
.48015 .26171 Mdot
.488 .25604 Mdot
.73455 .41579 Mdot
.6964 .63532 Mdot
.38172 .51575 Mdot
.48909 .24689 Mdot
.54157 .7441 Mdot
.30995 .59884 Mdot
.31855 .6051 Mdot
.31591 .6074 Mdot
.41874 .67155 Mdot
.36066 .39057 Mdot
.74524 .41032 Mdot
.49697 .73902 Mdot
.30651 .60594 Mdot
.33165 .47782 Mdot
.46237 .70369 Mdot
.62893 .6435 Mdot
.30898 .59121 Mdot
.50714 .73213 Mdot
.28224 .54511 Mdot
.65243 .63772 Mdot
.27152 .5047 Mdot
.66804 .43329 Mdot
.76785 .34596 Mdot
.63706 .62515 Mdot
.70055 .43174 Mdot
.68194 .48089 Mdot
.68781 .45884 Mdot
.49499 .71921 Mdot
.67733 .44909 Mdot
.45753 .68726 Mdot
.75556 .38332 Mdot
.38349 .48308 Mdot
.49031 .27823 Mdot
.7482 .39802 Mdot
.48965 .72773 Mdot
.41156 .68734 Mdot
.41641 .19887 Mdot
.35365 .41034 Mdot
.67223 .65397 Mdot
.50461 .25623 Mdot
.27817 .52613 Mdot
.48444 .23273 Mdot
.69299 .49929 Mdot
.37904 .49036 Mdot
.37509 .43747 Mdot
.58633 .69676 Mdot
.49864 .26715 Mdot
.48841 .73559 Mdot
.32061 .6128 Mdot
.7226 .47682 Mdot
.49711 .25259 Mdot
.49904 .27644 Mdot
.36371 .42491 Mdot
.43139 .67786 Mdot
.68493 .49931 Mdot
.66434 .63816 Mdot
.73284 .41039 Mdot
.24473 .44348 Mdot
.35704 .48875 Mdot
.34971 .41221 Mdot
.2744 .53298 Mdot
.74785 .38987 Mdot
.63974 .62977 Mdot
.3322 .36802 Mdot
.75506 .40941 Mdot
.31151 .36636 Mdot
.47353 .68811 Mdot
.75383 .39139 Mdot
.5523 .35836 Mdot
.5595 .33084 Mdot
.35319 .43642 Mdot
.42233 .1939 Mdot
.34536 .38273 Mdot
.62478 .64746 Mdot
.56705 .36913 Mdot
.68576 .43407 Mdot
.52813 .74386 Mdot
.47181 .19663 Mdot
.30985 .6199 Mdot
.6617 .6392 Mdot
.68543 .46993 Mdot
.44194 .19059 Mdot
.49806 .23567 Mdot
.2918 .50921 Mdot
.35794 .40962 Mdot
.3527 .43387 Mdot
.62191 .6377 Mdot
.62082 .6488 Mdot
.38276 .66372 Mdot
.59344 .34904 Mdot
.56665 .72805 Mdot
.70427 .64151 Mdot
.4478 .19094 Mdot
.56047 .37191 Mdot
.43987 .6712 Mdot
.59133 .38095 Mdot
.63056 .65001 Mdot
.35972 .47344 Mdot
.43038 .6767 Mdot
.55046 .34351 Mdot
.45975 .66501 Mdot
.32639 .61061 Mdot
.23376 .41956 Mdot
.36172 .43529 Mdot
.51622 .75257 Mdot
.49987 .7422 Mdot
.44593 .68501 Mdot
.54762 .33851 Mdot
.33892 .45985 Mdot
.34203 .43071 Mdot
.34417 .42118 Mdot
.37437 .64924 Mdot
.34758 .44781 Mdot
.53323 .74139 Mdot
.28772 .51356 Mdot
.74245 .59971 Mdot
.33574 .46918 Mdot
.62116 .62686 Mdot
.35748 .43475 Mdot
.51986 .26435 Mdot
.2534 .52496 Mdot
.33215 .63219 Mdot
.6359 .63351 Mdot
.33482 .48643 Mdot
.52324 .34389 Mdot
.34593 .48633 Mdot
.47621 .24838 Mdot
.73283 .64562 Mdot
.33174 .37451 Mdot
.38084 .64847 Mdot
.49581 .72873 Mdot
.71494 .47029 Mdot
.60113 .63828 Mdot
.69942 .50093 Mdot
.34214 .63589 Mdot
.57385 .38106 Mdot
.75997 .37613 Mdot
.24378 .40367 Mdot
.35939 .47218 Mdot
.54286 .34815 Mdot
.45155 .68852 Mdot
.74048 .41132 Mdot
.4295 .48948 Mdot
.31611 .59813 Mdot
.51575 .27433 Mdot
.48879 .23574 Mdot
.55701 .29736 Mdot
.41648 .6647 Mdot
.42777 .69192 Mdot
.62391 .63823 Mdot
.68583 .45267 Mdot
.47618 .21471 Mdot
.54166 .76591 Mdot
.61017 .64651 Mdot
.74262 .39952 Mdot
.6382 .6187 Mdot
.33697 .46543 Mdot
.59346 .36729 Mdot
.39251 .65788 Mdot
.57914 .37117 Mdot
.353 .49884 Mdot
.68237 .449 Mdot
.54535 .34624 Mdot
.48149 .22526 Mdot
.61786 .62651 Mdot
.70358 .4883 Mdot
.37442 .45504 Mdot
.50287 .74426 Mdot
.26503 .57008 Mdot
.76727 .39191 Mdot
.32911 .63346 Mdot
.32776 .63464 Mdot
.39267 .6541 Mdot
.58026 .33763 Mdot
.73239 .51429 Mdot
.33665 .63048 Mdot
.71401 .63946 Mdot
.52063 .29751 Mdot
.76623 .37498 Mdot
.71692 .4838 Mdot
.69048 .47645 Mdot
.35473 .48175 Mdot
.71739 .49564 Mdot
.26046 .52186 Mdot
.72287 .47029 Mdot
.7317 .65025 Mdot
.35721 .38954 Mdot
.68935 .46663 Mdot
.58455 .35257 Mdot
.37716 .4276 Mdot
.43472 .67204 Mdot
.70773 .50786 Mdot
.33349 .47161 Mdot
.66806 .45609 Mdot
.70435 .65011 Mdot
.54865 .33451 Mdot
.25736 .5477 Mdot
.64629 .63274 Mdot
.51307 .72763 Mdot
.24771 .54391 Mdot
.49381 .24706 Mdot
.4522 .68347 Mdot
.53334 .3023 Mdot
.49964 .27956 Mdot
.27964 .53385 Mdot
.47651 .71669 Mdot
.55877 .36601 Mdot
.49241 .23888 Mdot
.46978 .24034 Mdot
.68888 .47713 Mdot
.73474 .42446 Mdot
.57984 .35787 Mdot
.37613 .45348 Mdot
.75964 .39158 Mdot
.63491 .62303 Mdot
.35937 .41324 Mdot
.68152 .46215 Mdot
.55918 .36345 Mdot
.34135 .43701 Mdot
.31195 .61821 Mdot
.38464 .65922 Mdot
.59683 .35978 Mdot
.47889 .2536 Mdot
.43391 .67547 Mdot
.35135 .41205 Mdot
.48475 .27345 Mdot
.73281 .41242 Mdot
.3764 .41514 Mdot
.4929 .74709 Mdot
.54348 .74621 Mdot
.72037 .46155 Mdot
.6355 .64459 Mdot
.70123 .44933 Mdot
.47394 .23904 Mdot
.41435 .20002 Mdot
.57347 .34331 Mdot
.33793 .61438 Mdot
.25619 .52508 Mdot
.7158 .47789 Mdot
.4929 .7428 Mdot
.56335 .74358 Mdot
.25239 .52737 Mdot
.37538 .41445 Mdot
.35128 .42985 Mdot
.75105 .39007 Mdot
.52659 .74274 Mdot
.3498 .43067 Mdot
.48524 .28608 Mdot
.36833 .39917 Mdot
.50857 .26931 Mdot
.69656 .41892 Mdot
.56053 .32966 Mdot
.36481 .64951 Mdot
.54946 .34029 Mdot
.69276 .46071 Mdot
.2779 .54893 Mdot
.26859 .5318 Mdot
.53855 .26437 Mdot
.51708 .73066 Mdot
.49389 .70275 Mdot
.70147 .47482 Mdot
.73984 .39809 Mdot
.30755 .61965 Mdot
.31807 .61331 Mdot
.37669 .43034 Mdot
.69333 .4991 Mdot
.71766 .42823 Mdot
.58044 .38178 Mdot
.54472 .35111 Mdot
.27901 .50281 Mdot
.71379 .45044 Mdot
.34574 .44773 Mdot
.32896 .6083 Mdot
.60697 .64491 Mdot
.42614 .6683 Mdot
.65876 .6532 Mdot
.60647 .64603 Mdot
.42234 .49651 Mdot
.38746 .43756 Mdot
.69423 .65278 Mdot
.66069 .64609 Mdot
.7389 .40493 Mdot
.27246 .49875 Mdot
.50962 .28087 Mdot
.35302 .37314 Mdot
.7 .50251 Mdot
.34334 .46418 Mdot
.52869 .7544 Mdot
.6003 .37784 Mdot
.55805 .75589 Mdot
.42755 .32995 Mdot
.30343 .62021 Mdot
.75429 .40244 Mdot
.58327 .3644 Mdot
.58063 .37323 Mdot
.31321 .36983 Mdot
.34648 .44544 Mdot
.72038 .46407 Mdot
.26782 .49794 Mdot
.70324 .64105 Mdot
.73811 .40412 Mdot
.41328 .66295 Mdot
.35557 .43851 Mdot
.47415 .70486 Mdot
.60743 .63511 Mdot
.50168 .28661 Mdot
.49493 .23028 Mdot
.3465 .48449 Mdot
.32303 .63831 Mdot
.71787 .64141 Mdot
.31212 .61368 Mdot
.32228 .62298 Mdot
.57511 .35642 Mdot
.31037 .6316 Mdot
.35602 .40727 Mdot
.34146 .41358 Mdot
.58552 .34777 Mdot
.61011 .64785 Mdot
.35197 .38994 Mdot
.58561 .36575 Mdot
.24937 .53671 Mdot
.60612 .63151 Mdot
.31007 .61526 Mdot
.6234 .62937 Mdot
.74182 .3988 Mdot
.69886 .65075 Mdot
.47764 .23028 Mdot
.74405 .40062 Mdot
.37654 .65611 Mdot
.50689 .73071 Mdot
.65899 .62797 Mdot
.49703 .24256 Mdot
.62622 .62625 Mdot
.70743 .48957 Mdot
.7139 .64463 Mdot
.391 .64641 Mdot
.23262 .42437 Mdot
.41507 .50318 Mdot
.65209 .6161 Mdot
.71579 .43949 Mdot
.48841 .72671 Mdot
.69698 .63467 Mdot
.25395 .53889 Mdot
.50222 .23948 Mdot
.35451 .43393 Mdot
.61306 .62987 Mdot
.75025 .39993 Mdot
.39651 .67033 Mdot
.47749 .23726 Mdot
.4048 .68933 Mdot
.71624 .45948 Mdot
.36327 .39566 Mdot
.71612 .65953 Mdot
.72557 .52269 Mdot
.70251 .64764 Mdot
.36859 .51888 Mdot
.55361 .36789 Mdot
.58386 .33707 Mdot
.4617 .69683 Mdot
.54226 .35 Mdot
.47131 .29078 Mdot
.70743 .63462 Mdot
.42873 .66047 Mdot
.67107 .481 Mdot
.37665 .45343 Mdot
.30154 .62182 Mdot
.57269 .34557 Mdot
.51637 .74883 Mdot
.31778 .63206 Mdot
.5619 .33438 Mdot
.28796 .51419 Mdot
.42669 .67199 Mdot
.69965 .50829 Mdot
.37525 .42113 Mdot
.70019 .66071 Mdot
.69443 .63992 Mdot
.59076 .38371 Mdot
.70037 .65781 Mdot
.24929 .53586 Mdot
.47618 .71897 Mdot
.3066 .61163 Mdot
.5084 .2674 Mdot
.45313 .70597 Mdot
.59875 .37437 Mdot
.49998 .21298 Mdot
.37303 .41384 Mdot
.70165 .47712 Mdot
.71121 .52731 Mdot
.28197 .50501 Mdot
.50132 .7395 Mdot
.26038 .51858 Mdot
.31457 .6324 Mdot
.31485 .61333 Mdot
.68565 .45306 Mdot
.27576 .52934 Mdot
.34679 .44886 Mdot
.65625 .64047 Mdot
.28075 .45541 Mdot
.34705 .50743 Mdot
.48885 .28893 Mdot
.33239 .6319 Mdot
.72058 .65651 Mdot
.40961 .67221 Mdot
.69972 .477 Mdot
.4469 .6804 Mdot
.41 .66779 Mdot
.50482 .72392 Mdot
.53897 .76604 Mdot
.33648 .63003 Mdot
.58019 .71846 Mdot
.41203 .68169 Mdot
.40526 .51334 Mdot
.53342 .74938 Mdot
.73361 .49803 Mdot
.42977 .66062 Mdot
.51395 .72818 Mdot
.53892 .71989 Mdot
.52559 .74331 Mdot
.37596 .44551 Mdot
.37912 .41238 Mdot
.24104 .52654 Mdot
.7565 .3849 Mdot
.34784 .4578 Mdot
.59473 .36526 Mdot
.5098 .26258 Mdot
.4129 .65569 Mdot
.56445 .35763 Mdot
.2774 .53801 Mdot
.53658 .34823 Mdot
.36574 .42556 Mdot
.34377 .43503 Mdot
.31494 .60878 Mdot
.26289 .38036 Mdot
.76 .38247 Mdot
.50875 .75467 Mdot
.34439 .50486 Mdot
.71517 .52765 Mdot
.37146 .41853 Mdot
.25957 .51746 Mdot
.33943 .41954 Mdot
.70084 .47785 Mdot
.40526 .66248 Mdot
.5874 .37646 Mdot
.44728 .69968 Mdot
.35755 .4464 Mdot
.5747 .39009 Mdot
.50803 .2953 Mdot
.34688 .43349 Mdot
.45874 .70251 Mdot
.31669 .63247 Mdot
.50397 .71856 Mdot
.47187 .71108 Mdot
.37484 .4131 Mdot
.41222 .65937 Mdot
.49694 .71832 Mdot
.31754 .61384 Mdot
.75497 .40121 Mdot
.71087 .63225 Mdot
.37091 .42658 Mdot
.47821 .23773 Mdot
.36608 .4642 Mdot
.50749 .28628 Mdot
.59291 .36296 Mdot
.58063 .36151 Mdot
.34983 .38338 Mdot
.7112 .43187 Mdot
.51759 .28551 Mdot
.75848 .3849 Mdot
.33659 .65135 Mdot
.50564 .70687 Mdot
.70626 .64131 Mdot
.73496 .42515 Mdot
.57881 .36021 Mdot
.33837 .38174 Mdot
.24857 .44387 Mdot
.69731 .6559 Mdot
.47275 .69264 Mdot
.35233 .38889 Mdot
.54034 .3435 Mdot
.69769 .5098 Mdot
.6995 .45297 Mdot
.70981 .63564 Mdot
.53582 .71735 Mdot
.33878 .47386 Mdot
.54071 .34305 Mdot
.29469 .59653 Mdot
.56241 .36165 Mdot
.5883 .37869 Mdot
.69617 .43169 Mdot
.34069 .44889 Mdot
.28112 .53683 Mdot
.68404 .49019 Mdot
.49124 .26807 Mdot
.46673 .69321 Mdot
.47826 .25723 Mdot
.58741 .68917 Mdot
.38054 .66098 Mdot
.69255 .49126 Mdot
.55125 .32644 Mdot
.34838 .46289 Mdot
.41296 .66721 Mdot
.44455 .68732 Mdot
.42924 .6676 Mdot
.5076 .26293 Mdot
.71942 .47819 Mdot
.73909 .39522 Mdot
.37371 .45257 Mdot
.47574 .72366 Mdot
.48508 .20247 Mdot
.36904 .45319 Mdot
.65406 .62767 Mdot
.32142 .6323 Mdot
.48379 .73099 Mdot
.33336 .60799 Mdot
.46289 .69831 Mdot
.69654 .45461 Mdot
.34885 .48106 Mdot
.37753 .44105 Mdot
.33337 .37445 Mdot
.48417 .25456 Mdot
.51978 .72777 Mdot
.38662 .44969 Mdot
.36309 .50257 Mdot
.30823 .37223 Mdot
.3467 .42854 Mdot
.41245 .50517 Mdot
.5381 .31211 Mdot
.56906 .33832 Mdot
.25532 .52987 Mdot
.35999 .42095 Mdot
.45903 .70383 Mdot
.39085 .66159 Mdot
.3715 .64458 Mdot
.61338 .64105 Mdot
.42577 .65841 Mdot
.68594 .49588 Mdot
.70513 .51025 Mdot
.67777 .50411 Mdot
.47331 .22542 Mdot
.30785 .6155 Mdot
.35035 .47564 Mdot
.62331 .64664 Mdot
.49233 .24429 Mdot
.47412 .72352 Mdot
.50384 .28158 Mdot
.27516 .51105 Mdot
.48053 .2297 Mdot
.57565 .38289 Mdot
.74003 .63986 Mdot
.32882 .6084 Mdot
.48912 .27188 Mdot
.43114 .67232 Mdot
.34378 .38263 Mdot
.35956 .38507 Mdot
.40862 .68617 Mdot
.5164 .2778 Mdot
.73232 .41235 Mdot
.37054 .41236 Mdot
.38205 .49634 Mdot
.61793 .63244 Mdot
.47613 .23141 Mdot
.64596 .61911 Mdot
.3182 .62812 Mdot
.4897 .70015 Mdot
.49652 .73488 Mdot
.6975 .63855 Mdot
.26016 .5176 Mdot
.47642 .22854 Mdot
.69131 .4861 Mdot
.26358 .50164 Mdot
.76116 .37983 Mdot
.53207 .3289 Mdot
.31824 .37215 Mdot
.74422 .41191 Mdot
.33543 .49072 Mdot
.69162 .64496 Mdot
.34653 .4987 Mdot
.33697 .61627 Mdot
.36854 .49335 Mdot
.67976 .48459 Mdot
.6909 .47557 Mdot
.75681 .37871 Mdot
.35485 .4904 Mdot
.33002 .45612 Mdot
.41603 .67419 Mdot
.71988 .47301 Mdot
.49706 .72188 Mdot
.51426 .75122 Mdot
.69833 .43265 Mdot
.49771 .71364 Mdot
.50002 .27761 Mdot
.37539 .49355 Mdot
.69193 .64532 Mdot
.70444 .64611 Mdot
.69394 .48875 Mdot
.68904 .43549 Mdot
.70235 .47842 Mdot
.31749 .63018 Mdot
.47833 .71675 Mdot
.37815 .39765 Mdot
.36291 .42964 Mdot
.33752 .48418 Mdot
.41112 .6627 Mdot
.25175 .53116 Mdot
.44306 .42279 Mdot
.51399 .27577 Mdot
.69453 .46232 Mdot
.62982 .61862 Mdot
.27056 .57245 Mdot
.64753 .64333 Mdot
.37143 .40279 Mdot
.71993 .63799 Mdot
.47109 .69149 Mdot
.4862 .22975 Mdot
.33292 .62312 Mdot
.48529 .22335 Mdot
.60744 .64501 Mdot
.43523 .68475 Mdot
.27953 .52151 Mdot
.36157 .39257 Mdot
.26894 .52412 Mdot
.65367 .36587 Mdot
.45284 .69608 Mdot
.64539 .63886 Mdot
.33099 .6143 Mdot
.53304 .32731 Mdot
.29026 .60994 Mdot
.35543 .47983 Mdot
.34542 .5034 Mdot
.37597 .51567 Mdot
.3819 .42087 Mdot
.42043 .66049 Mdot
.26792 .5134 Mdot
.54606 .32694 Mdot
.37972 .43932 Mdot
.58133 .70707 Mdot
.35848 .45202 Mdot
.33465 .47016 Mdot
.34603 .4706 Mdot
.35197 .51032 Mdot
.40322 .65279 Mdot
.31457 .60646 Mdot
.6391 .6447 Mdot
.37192 .50228 Mdot
.68238 .63961 Mdot
.69778 .48898 Mdot
.59997 .37027 Mdot
.4019 .656 Mdot
.48695 .2242 Mdot
.59042 .67452 Mdot
.3824 .49326 Mdot
.67375 .49414 Mdot
.33971 .37108 Mdot
.51209 .30272 Mdot
.59156 .37189 Mdot
.47396 .22874 Mdot
.68063 .456 Mdot
.64164 .62596 Mdot
.33614 .43301 Mdot
.49419 .72308 Mdot
.51299 .73779 Mdot
.37967 .4325 Mdot
.70437 .62817 Mdot
.69484 .64013 Mdot
.74697 .3993 Mdot
.33834 .47148 Mdot
.38181 .42214 Mdot
.48624 .71049 Mdot
.73333 .41366 Mdot
.26664 .53738 Mdot
.49478 .25531 Mdot
.36601 .41362 Mdot
.54157 .32928 Mdot
.27045 .51505 Mdot
.62481 .64556 Mdot
.55522 .35974 Mdot
.3597 .45867 Mdot
.38781 .43503 Mdot
.32116 .59507 Mdot
.55854 .31306 Mdot
.72008 .43995 Mdot
.37348 .41178 Mdot
.37383 .42557 Mdot
.42509 .67116 Mdot
.69995 .64962 Mdot
.49251 .74321 Mdot
.39049 .64683 Mdot
.58021 .36127 Mdot
.70631 .65035 Mdot
.3549 .50902 Mdot
.72287 .65441 Mdot
.32271 .63259 Mdot
.37032 .43292 Mdot
.64267 .63991 Mdot
.47028 .70673 Mdot
.56395 .72322 Mdot
.35611 .38461 Mdot
.32234 .6254 Mdot
.36621 .46242 Mdot
.73503 .40895 Mdot
.60026 .37955 Mdot
.36335 .39397 Mdot
.51469 .74242 Mdot
.37 .45234 Mdot
.60702 .64126 Mdot
.4978 .28523 Mdot
.50413 .73853 Mdot
.75426 .40412 Mdot
.69219 .45147 Mdot
.71916 .44839 Mdot
.57452 .38206 Mdot
.31287 .63246 Mdot
.44169 .68101 Mdot
.49683 .75003 Mdot
.26555 .5216 Mdot
.69251 .46109 Mdot
.50302 .26669 Mdot
.37635 .46003 Mdot
.54025 .3295 Mdot
.68919 .65967 Mdot
.36485 .65144 Mdot
.28742 .51207 Mdot
.47431 .2495 Mdot
.26458 .44649 Mdot
.57291 .35714 Mdot
.33797 .45264 Mdot
.47642 .23016 Mdot
.69206 .4369 Mdot
.31527 .5932 Mdot
.51669 .30601 Mdot
.75975 .38755 Mdot
.67535 .46835 Mdot
.69119 .63796 Mdot
.722 .44813 Mdot
.47973 .21983 Mdot
.58118 .34864 Mdot
.50876 .73681 Mdot
.34554 .43883 Mdot
.57331 .34981 Mdot
.702 .46295 Mdot
.56666 .37643 Mdot
.33424 .45409 Mdot
.48092 .70556 Mdot
.70424 .49444 Mdot
.37344 .4369 Mdot
.33752 .62717 Mdot
.38242 .65596 Mdot
.74823 .40508 Mdot
.26129 .51921 Mdot
.46484 .21144 Mdot
.67787 .50004 Mdot
.67872 .47772 Mdot
.3786 .4186 Mdot
.50972 .25155 Mdot
.35795 .44125 Mdot
.64608 .62674 Mdot
.25656 .55039 Mdot
.70197 .64861 Mdot
.30963 .36718 Mdot
.38239 .43576 Mdot
.24952 .52114 Mdot
.49143 .69745 Mdot
.50475 .32181 Mdot
.28554 .376 Mdot
.34163 .43048 Mdot
.53146 .75178 Mdot
.27029 .54403 Mdot
.23084 .43166 Mdot
.40096 .66047 Mdot
.49862 .28833 Mdot
.61538 .6332 Mdot
.3735 .46499 Mdot
.58519 .70378 Mdot
.50755 .26924 Mdot
.31124 .36931 Mdot
.28607 .5028 Mdot
.49087 .73864 Mdot
.34759 .47751 Mdot
.49956 .73231 Mdot
.36212 .46107 Mdot
.38349 .65428 Mdot
.70508 .63606 Mdot
.37098 .51549 Mdot
.58275 .35105 Mdot
.72494 .52299 Mdot
.41367 .505 Mdot
.50175 .27298 Mdot
.3347 .61187 Mdot
.5768 .36279 Mdot
.64796 .62368 Mdot
.68742 .63473 Mdot
.70259 .47669 Mdot
.66865 .63726 Mdot
.44047 .66985 Mdot
.74957 .39972 Mdot
.55014 .36145 Mdot
.30207 .5919 Mdot
.48857 .22166 Mdot
.707 .65084 Mdot
.35151 .4235 Mdot
.34277 .49 Mdot
.75143 .38954 Mdot
.69136 .42002 Mdot
.507 .71398 Mdot
.37795 .6604 Mdot
.4326 .68328 Mdot
.48712 .25875 Mdot
.75135 .40187 Mdot
.35556 .47188 Mdot
.34336 .45357 Mdot
.67796 .45052 Mdot
.4063 .66203 Mdot
.50844 .25587 Mdot
.58711 .34064 Mdot
.62245 .64698 Mdot
.75549 .37522 Mdot
.50537 .73795 Mdot
.76371 .37224 Mdot
.73835 .39724 Mdot
.5425 .72557 Mdot
.28823 .37598 Mdot
.64373 .63146 Mdot
.76545 .37168 Mdot
.48388 .73403 Mdot
.36729 .39642 Mdot
.56976 .3702 Mdot
.57104 .38024 Mdot
.47226 .70022 Mdot
.69774 .49541 Mdot
.51231 .25525 Mdot
.35343 .48337 Mdot
.47174 .24721 Mdot
.40854 .66569 Mdot
.71597 .45113 Mdot
.55657 .35296 Mdot
.61 .62811 Mdot
.3686 .45726 Mdot
.50934 .26476 Mdot
.64116 .63243 Mdot
.56057 .33106 Mdot
.37679 .49603 Mdot
.24811 .54391 Mdot
.32897 .63516 Mdot
.61947 .63296 Mdot
.26453 .52962 Mdot
.36433 .41572 Mdot
.69132 .64477 Mdot
.53665 .30343 Mdot
.729 .51786 Mdot
.25392 .54726 Mdot
.70672 .63439 Mdot
.6758 .45207 Mdot
.72232 .44575 Mdot
.73491 .42769 Mdot
.76009 .38282 Mdot
.68316 .64147 Mdot
.56443 .34918 Mdot
.74965 .38149 Mdot
.70006 .64931 Mdot
.26796 .50958 Mdot
.37379 .46381 Mdot
.27255 .49653 Mdot
.55992 .32978 Mdot
.55188 .33381 Mdot
.4 .66627 Mdot
.31743 .60298 Mdot
.55836 .35479 Mdot
.35378 .41619 Mdot
.44665 .68707 Mdot
.65233 .636 Mdot
.46464 .19408 Mdot
.62657 .64906 Mdot
.31185 .59211 Mdot
.68556 .51015 Mdot
.74664 .40238 Mdot
.3465 .43751 Mdot
.59903 .65326 Mdot
.44595 .19078 Mdot
.37283 .46632 Mdot
.33298 .62303 Mdot
.31237 .36628 Mdot
.37983 .43761 Mdot
.44978 .67191 Mdot
.5434 .335 Mdot
.44515 .68525 Mdot
.64331 .63426 Mdot
.50123 .28881 Mdot
.46872 .28328 Mdot
.61604 .63484 Mdot
.35651 .45179 Mdot
.59719 .38277 Mdot
.3521 .4329 Mdot
.34157 .42461 Mdot
.36612 .50595 Mdot
.48733 .28151 Mdot
.70234 .48549 Mdot
.48653 .22303 Mdot
.52132 .73543 Mdot
.37055 .65069 Mdot
.50358 .27316 Mdot
.26858 .49981 Mdot
.27221 .53885 Mdot
.68689 .42331 Mdot
.51279 .73854 Mdot
.50918 .28449 Mdot
.61703 .6295 Mdot
.23419 .44133 Mdot
.25965 .50651 Mdot
.66258 .63829 Mdot
.33589 .44783 Mdot
.49906 .75176 Mdot
.40104 .66444 Mdot
.71343 .64815 Mdot
.49075 .74458 Mdot
.26552 .53188 Mdot
.31641 .62647 Mdot
.6243 .64591 Mdot
.27366 .3875 Mdot
.70557 .64859 Mdot
.43371 .47717 Mdot
.32711 .62637 Mdot
.50224 .73879 Mdot
.39282 .51823 Mdot
.45834 .70578 Mdot
.55965 .33459 Mdot
.36587 .50267 Mdot
.50203 .26785 Mdot
.26823 .52639 Mdot
.75767 .40297 Mdot
.47685 .69047 Mdot
.48654 .72922 Mdot
.61836 .65135 Mdot
.49962 .74697 Mdot
.48172 .70123 Mdot
.65088 .61509 Mdot
.4344 .6624 Mdot
.35706 .44775 Mdot
.35779 .65695 Mdot
.44417 .68071 Mdot
.62898 .63882 Mdot
.50095 .25442 Mdot
.42422 .66471 Mdot
.74276 .39285 Mdot
.37618 .42213 Mdot
.71125 .46074 Mdot
.52001 .27199 Mdot
.40538 .65636 Mdot
.50046 .26952 Mdot
.70452 .46869 Mdot
.50413 .2996 Mdot
.6656 .65586 Mdot
.71694 .6554 Mdot
.56865 .32547 Mdot
.71505 .63812 Mdot
.52448 .7405 Mdot
.76243 .38824 Mdot
.3501 .49092 Mdot
.33899 .46941 Mdot
.51933 .26169 Mdot
.52853 .7401 Mdot
.72023 .6337 Mdot
.56307 .35732 Mdot
.41463 .67883 Mdot
.61763 .62378 Mdot
.74301 .40376 Mdot
.27733 .54026 Mdot
.69568 .63685 Mdot
.54753 .32598 Mdot
.57513 .35892 Mdot
.35135 .42931 Mdot
.33148 .37067 Mdot
.47566 .23822 Mdot
.73262 .49718 Mdot
.30088 .60467 Mdot
.68695 .43521 Mdot
.35078 .46608 Mdot
.30533 .60555 Mdot
.35378 .40934 Mdot
.47541 .21611 Mdot
.67511 .64335 Mdot
.51098 .73351 Mdot
.50529 .28867 Mdot
.69217 .45083 Mdot
.27824 .54704 Mdot
.36754 .39231 Mdot
.26005 .53028 Mdot
.69139 .50472 Mdot
.52524 .74871 Mdot
.69523 .48068 Mdot
.6898 .64408 Mdot
.50395 .27855 Mdot
.31763 .63163 Mdot
.55919 .32906 Mdot
.71581 .48062 Mdot
.6605 .62802 Mdot
.75843 .39997 Mdot
.68607 .63542 Mdot
.57909 .36179 Mdot
.25684 .54225 Mdot
.71773 .49551 Mdot
.57699 .37454 Mdot
.42488 .68702 Mdot
.38534 .47087 Mdot
.52443 .71005 Mdot
.6945 .49986 Mdot
.53614 .25838 Mdot
.63693 .63533 Mdot
.64653 .65092 Mdot
.42361 .49764 Mdot
.42347 .19349 Mdot
.362 .50824 Mdot
.73316 .64307 Mdot
.6933 .6462 Mdot
.62465 .63161 Mdot
.69691 .47807 Mdot
.46985 .70532 Mdot
.46248 .66638 Mdot
.69885 .50655 Mdot
.29953 .37817 Mdot
.47416 .72349 Mdot
.24236 .52434 Mdot
.71453 .49816 Mdot
.31705 .61165 Mdot
.4062 .67906 Mdot
.5148 .28409 Mdot
.3227 .37402 Mdot
.69825 .63909 Mdot
.36806 .47241 Mdot
.57966 .72276 Mdot
.70062 .47167 Mdot
.57325 .37705 Mdot
.61241 .6515 Mdot
.3405 .48834 Mdot
.34486 .4656 Mdot
.36523 .43573 Mdot
.518 .25967 Mdot
.40704 .67711 Mdot
.36062 .47725 Mdot
.3804 .48888 Mdot
.29985 .62053 Mdot
.73803 .42235 Mdot
.4826 .22235 Mdot
.34464 .36863 Mdot
.66937 .45929 Mdot
.40828 .67437 Mdot
.3449 .50059 Mdot
.66207 .64821 Mdot
.31549 .6032 Mdot
.63208 .64345 Mdot
.6265 .61853 Mdot
.75345 .37507 Mdot
.51564 .74547 Mdot
.30265 .62035 Mdot
.7141 .42607 Mdot
.48707 .69268 Mdot
.30397 .61133 Mdot
.37481 .65711 Mdot
.61203 .64912 Mdot
.41376 .19956 Mdot
.65361 .65152 Mdot
.56715 .37816 Mdot
.44169 .66938 Mdot
.52652 .76199 Mdot
.26907 .51604 Mdot
.48706 .7188 Mdot
.75242 .38969 Mdot
.44367 .68229 Mdot
.72032 .33431 Mdot
.44226 .68704 Mdot
.63098 .63505 Mdot
.70915 .64846 Mdot
.30973 .61075 Mdot
.35375 .45009 Mdot
.2824 .52222 Mdot
.5628 .3579 Mdot
.25544 .53954 Mdot
.68358 .48861 Mdot
.74562 .38851 Mdot
.73817 .64185 Mdot
.44925 .67292 Mdot
.66884 .63209 Mdot
.3458 .46614 Mdot
.3261 .62758 Mdot
.37908 .412 Mdot
.70524 .63798 Mdot
.29592 .63382 Mdot
.36161 .42924 Mdot
.30844 .61448 Mdot
.69405 .50957 Mdot
.67989 .43692 Mdot
.53234 .71434 Mdot
.75269 .37606 Mdot
.34298 .43044 Mdot
.48676 .24875 Mdot
.47338 .22311 Mdot
.3617 .38813 Mdot
.70378 .52584 Mdot
.26781 .53708 Mdot
.3524 .42286 Mdot
.27577 .54942 Mdot
.69774 .51031 Mdot
.55074 .36902 Mdot
.69943 .46086 Mdot
.39564 .6521 Mdot
.59426 .37013 Mdot
.681 .46943 Mdot
.28617 .52699 Mdot
.57539 .3538 Mdot
.72952 .51578 Mdot
.50983 .27011 Mdot
.35819 .41322 Mdot
.43592 .48281 Mdot
.71929 .48268 Mdot
.6365 .62933 Mdot
.429 .66437 Mdot
.63934 .64397 Mdot
.67529 .44605 Mdot
.30218 .37187 Mdot
.55601 .33072 Mdot
.65393 .64734 Mdot
.30944 .63773 Mdot
.48783 .2444 Mdot
.65342 .65294 Mdot
.31153 .63317 Mdot
.36192 .3872 Mdot
.43644 .19083 Mdot
.33668 .4784 Mdot
.74748 .38624 Mdot
.70494 .65138 Mdot
.5333 .30746 Mdot
.34556 .44167 Mdot
.71233 .45253 Mdot
.46896 .23905 Mdot
.35457 .42984 Mdot
.74947 .40822 Mdot
.37352 .42813 Mdot
.47677 .23074 Mdot
.42865 .67403 Mdot
.25713 .55136 Mdot
.50278 .23245 Mdot
.50417 .28806 Mdot
.37527 .51482 Mdot
.38026 .41387 Mdot
.7327 .48239 Mdot
.49247 .74059 Mdot
.36807 .40021 Mdot
.51661 .25349 Mdot
.46039 .68917 Mdot
.44696 .6798 Mdot
.31504 .59257 Mdot
.60156 .63623 Mdot
.70064 .49399 Mdot
.48387 .23667 Mdot
.73446 .40787 Mdot
.37152 .46527 Mdot
.32796 .60286 Mdot
.5103 .27662 Mdot
.65518 .63004 Mdot
.31022 .62838 Mdot
.72664 .6315 Mdot
.37251 .50175 Mdot
.64882 .65362 Mdot
.34878 .505 Mdot
.38418 .51927 Mdot
.43582 .68099 Mdot
.57968 .71621 Mdot
.69558 .63331 Mdot
.69683 .45146 Mdot
.55705 .35179 Mdot
.36748 .65141 Mdot
.50837 .26432 Mdot
.46326 .66526 Mdot
.33533 .46185 Mdot
.3575 .46819 Mdot
.4386 .68132 Mdot
.36584 .38998 Mdot
.46325 .68488 Mdot
.73811 .40046 Mdot
.42121 .19412 Mdot
.50699 .73355 Mdot
.48947 .73325 Mdot
.34674 .62241 Mdot
.69093 .52105 Mdot
.46813 .69358 Mdot
.3731 .46671 Mdot
.67916 .43849 Mdot
.55647 .31258 Mdot
.50225 .24869 Mdot
.52419 .30488 Mdot
.47545 .69335 Mdot
.28871 .49889 Mdot
.32539 .63398 Mdot
.35146 .38517 Mdot
.26965 .44801 Mdot
.68869 .64508 Mdot
.3639 .48931 Mdot
.56762 .35852 Mdot
.70131 .46578 Mdot
.33053 .46675 Mdot
.35452 .41483 Mdot
.51031 .73103 Mdot
.51183 .29493 Mdot
.66504 .62521 Mdot
.58059 .37633 Mdot
.72161 .46768 Mdot
.49268 .26403 Mdot
.49724 .71292 Mdot
.41716 .50295 Mdot
.58805 .34855 Mdot
.54175 .34535 Mdot
.3386 .43941 Mdot
.37243 .40919 Mdot
.56216 .32731 Mdot
.62052 .64044 Mdot
.69853 .45101 Mdot
.58858 .37269 Mdot
.26802 .52927 Mdot
.26496 .552 Mdot
.34162 .45806 Mdot
.46359 .70831 Mdot
.65778 .62573 Mdot
.55393 .33167 Mdot
.76542 .37415 Mdot
.3771 .45875 Mdot
.26905 .50451 Mdot
.61373 .39083 Mdot
.5659 .35418 Mdot
.46416 .66757 Mdot
.49098 .22876 Mdot
.32704 .62591 Mdot
.37743 .49961 Mdot
.2504 .53588 Mdot
.3471 .50028 Mdot
.68961 .43834 Mdot
.6236 .62268 Mdot
.54908 .31533 Mdot
.69421 .46341 Mdot
.44649 .67975 Mdot
.35123 .3844 Mdot
.51845 .75157 Mdot
.49823 .75013 Mdot
.49187 .70371 Mdot
.6112 .63855 Mdot
.36572 .64952 Mdot
.56915 .33186 Mdot
.33727 .47253 Mdot
.68931 .65057 Mdot
.47123 .69471 Mdot
.24981 .52609 Mdot
.47068 .69101 Mdot
.52349 .73207 Mdot
.24834 .53873 Mdot
.31186 .61774 Mdot
.38198 .48853 Mdot
.33928 .49515 Mdot
.50226 .23868 Mdot
.48928 .74908 Mdot
.26365 .50585 Mdot
.35807 .47228 Mdot
.34275 .4413 Mdot
.31103 .60874 Mdot
.48271 .2739 Mdot
.35384 .37873 Mdot
.33599 .46194 Mdot
.33443 .36462 Mdot
.25176 .52372 Mdot
.53216 .74834 Mdot
.67857 .6588 Mdot
.3132 .59179 Mdot
.6731 .48214 Mdot
.41547 .66871 Mdot
.51404 .28712 Mdot
.45594 .67064 Mdot
.32961 .63737 Mdot
.63054 .6246 Mdot
.48396 .73114 Mdot
.7092 .48911 Mdot
.64044 .62891 Mdot
.70555 .64851 Mdot
.31441 .60759 Mdot
.6972 .4449 Mdot
.51062 .29561 Mdot
.68706 .63851 Mdot
.28948 .6133 Mdot
.63111 .63414 Mdot
.53394 .72169 Mdot
.25836 .54238 Mdot
.37745 .49795 Mdot
.56332 .34361 Mdot
.54016 .31258 Mdot
.69045 .64256 Mdot
.49601 .2549 Mdot
.30852 .62741 Mdot
.42836 .66635 Mdot
.49186 .24731 Mdot
.39907 .67254 Mdot
.74188 .40679 Mdot
.40566 .66866 Mdot
.74839 .39172 Mdot
.48674 .71644 Mdot
.32054 .37342 Mdot
.50876 .29189 Mdot
.54426 .32035 Mdot
.27903 .51166 Mdot
.55461 .35146 Mdot
.33146 .46568 Mdot
.30477 .62312 Mdot
.35807 .44697 Mdot
.67637 .50332 Mdot
.52086 .26584 Mdot
.44705 .68392 Mdot
.46512 .26731 Mdot
.6579 .63462 Mdot
.2619 .52778 Mdot
.57812 .37881 Mdot
.3229 .62625 Mdot
.46538 .68799 Mdot
.50557 .72161 Mdot
.38541 .65326 Mdot
.677 .49869 Mdot
.50066 .31546 Mdot
.34583 .46082 Mdot
.46953 .26835 Mdot
.69689 .64567 Mdot
.71788 .63921 Mdot
.71245 .4733 Mdot
.41163 .20635 Mdot
.69149 .46372 Mdot
.55956 .3108 Mdot
.48808 .71501 Mdot
.48072 .25814 Mdot
.3512 .45637 Mdot
.41004 .65979 Mdot
.46147 .6654 Mdot
.52382 .29948 Mdot
.48594 .2245 Mdot
.71669 .64139 Mdot
.69515 .65305 Mdot
.55608 .36645 Mdot
.25312 .52201 Mdot
.25042 .52241 Mdot
.34542 .48871 Mdot
.68386 .64365 Mdot
.31762 .62198 Mdot
.66669 .65679 Mdot
.3329 .61777 Mdot
.5194 .25874 Mdot
.67777 .47322 Mdot
.73672 .59305 Mdot
.41365 .66517 Mdot
.3501 .38417 Mdot
.51079 .70755 Mdot
.38452 .47185 Mdot
.66637 .64274 Mdot
.53717 .3019 Mdot
.70021 .48268 Mdot
.59012 .66881 Mdot
.67847 .46474 Mdot
.45247 .22387 Mdot
.28083 .49518 Mdot
.61471 .65111 Mdot
.25749 .53499 Mdot
.7045 .43256 Mdot
.3363 .49006 Mdot
.58818 .36694 Mdot
.59708 .38273 Mdot
.33223 .64211 Mdot
.38018 .65879 Mdot
.49923 .23475 Mdot
.35108 .45703 Mdot
.45577 .69718 Mdot
.34896 .45656 Mdot
.34769 .45721 Mdot
.34146 .42335 Mdot
.70582 .64089 Mdot
.25991 .53919 Mdot
.35518 .44906 Mdot
.75752 .37783 Mdot
.55334 .31291 Mdot
.72163 .4842 Mdot
.43437 .68082 Mdot
.49223 .24422 Mdot
.41292 .66967 Mdot
.27711 .52825 Mdot
.62628 .65 Mdot
.4056 .67652 Mdot
.32046 .61649 Mdot
.47579 .69045 Mdot
.65201 .64883 Mdot
.51439 .26299 Mdot
.57151 .35985 Mdot
.55753 .75182 Mdot
.75841 .38494 Mdot
.5611 .36413 Mdot
.74565 .40835 Mdot
.34142 .4952 Mdot
.50918 .73881 Mdot
.55621 .3541 Mdot
.64966 .61897 Mdot
.69506 .43217 Mdot
.38062 .49923 Mdot
.37192 .45032 Mdot
.68914 .50137 Mdot
.56824 .34812 Mdot
.26895 .52712 Mdot
.27297 .54117 Mdot
.70547 .43226 Mdot
.60506 .62495 Mdot
.69913 .64431 Mdot
.50061 .25144 Mdot
.5277 .74355 Mdot
.50895 .72641 Mdot
.65645 .63352 Mdot
.59227 .66687 Mdot
.37512 .44411 Mdot
.37287 .4423 Mdot
.27683 .5181 Mdot
.35409 .51175 Mdot
.76567 .37941 Mdot
.56365 .36465 Mdot
.49191 .72449 Mdot
.30386 .62158 Mdot
.30879 .59901 Mdot
.35486 .4556 Mdot
.29558 .37491 Mdot
.70176 .49989 Mdot
.33024 .62723 Mdot
.47624 .23157 Mdot
.37719 .64898 Mdot
.3736 .42062 Mdot
.51905 .25706 Mdot
.50122 .7209 Mdot
.73165 .50639 Mdot
.63464 .62962 Mdot
.71206 .42903 Mdot
.71293 .42726 Mdot
.65467 .36338 Mdot
.41701 .66785 Mdot
.56078 .36356 Mdot
.76779 .38391 Mdot
.58879 .38377 Mdot
.48487 .22604 Mdot
.34623 .37756 Mdot
.75427 .38757 Mdot
.72263 .47357 Mdot
.60781 .64869 Mdot
.36048 .49633 Mdot
.3649 .41237 Mdot
.70426 .63338 Mdot
.34568 .43116 Mdot
.5065 .27528 Mdot
.68425 .65319 Mdot
.48453 .73236 Mdot
.50873 .24775 Mdot
.66491 .64915 Mdot
.51121 .72667 Mdot
.3155 .60898 Mdot
.2507 .5239 Mdot
.43677 .67095 Mdot
.4911 .71122 Mdot
.37594 .44439 Mdot
.759 .37138 Mdot
.50283 .72843 Mdot
.43019 .66248 Mdot
.37956 .65384 Mdot
.71723 .44703 Mdot
.46954 .22984 Mdot
.6054 .64119 Mdot
.35908 .44109 Mdot
.67781 .4867 Mdot
.48023 .2454 Mdot
.48369 .72713 Mdot
.35629 .40762 Mdot
.37054 .46644 Mdot
.48778 .24552 Mdot
.47746 .21978 Mdot
.49524 .25174 Mdot
.71117 .64643 Mdot
.31878 .61327 Mdot
.46006 .68553 Mdot
.67438 .64062 Mdot
.51344 .2835 Mdot
.48585 .21873 Mdot
.52677 .35285 Mdot
.37467 .43977 Mdot
.47865 .21735 Mdot
.36967 .65018 Mdot
.29076 .51971 Mdot
.58991 .38368 Mdot
.54159 .27194 Mdot
.69714 .52608 Mdot
.56113 .30183 Mdot
.62225 .62398 Mdot
.32946 .61396 Mdot
.50412 .24968 Mdot
.57896 .35255 Mdot
.37317 .44804 Mdot
.38101 .43986 Mdot
.48865 .25121 Mdot
.30123 .36975 Mdot
.51528 .73423 Mdot
.52288 .70799 Mdot
.48965 .24342 Mdot
.70705 .43861 Mdot
.69999 .50886 Mdot
.68908 .47425 Mdot
.33965 .45247 Mdot
.23967 .53471 Mdot
.24428 .44415 Mdot
.3877 .65256 Mdot
.69751 .65087 Mdot
.49545 .71752 Mdot
.39276 .67273 Mdot
.44931 .68209 Mdot
.68736 .43313 Mdot
.49639 .25545 Mdot
.46186 .70762 Mdot
.71129 .64783 Mdot
.69136 .64154 Mdot
.71989 .484 Mdot
.69211 .45976 Mdot
.69204 .4889 Mdot
.40359 .65694 Mdot
.47586 .70277 Mdot
.25265 .53972 Mdot
.49486 .74743 Mdot
.66793 .46283 Mdot
.73892 .39941 Mdot
.71876 .48878 Mdot
.63252 .64032 Mdot
.47116 .71036 Mdot
.37418 .42734 Mdot
.37188 .52267 Mdot
.69998 .50969 Mdot
.51624 .27861 Mdot
.35809 .65456 Mdot
.4251 .19301 Mdot
.32513 .60274 Mdot
.64777 .62168 Mdot
.57313 .34385 Mdot
.36504 .43924 Mdot
.69958 .45353 Mdot
.54473 .28079 Mdot
.54389 .33772 Mdot
.26049 .52386 Mdot
.34011 .6512 Mdot
.64088 .62307 Mdot
.27226 .54348 Mdot
.58604 .3632 Mdot
.3038 .62819 Mdot
.68185 .65146 Mdot
.71645 .48151 Mdot
.73624 .4253 Mdot
.39821 .66461 Mdot
.34329 .37923 Mdot
.56738 .33623 Mdot
.35226 .49306 Mdot
.6822 .47131 Mdot
.50828 .24794 Mdot
.68396 .48236 Mdot
.53281 .74635 Mdot
.72025 .4603 Mdot
.36508 .4188 Mdot
.46161 .68797 Mdot
.69555 .64369 Mdot
.23717 .44125 Mdot
.46488 .27312 Mdot
.71553 .45973 Mdot
.54903 .32129 Mdot
.31227 .60162 Mdot
.30061 .59147 Mdot
.54033 .31222 Mdot
.36265 .41322 Mdot
.64177 .64056 Mdot
.46025 .68334 Mdot
.6612 .63132 Mdot
.46867 .23254 Mdot
.54781 .76057 Mdot
.63433 .6289 Mdot
.23821 .53622 Mdot
.51291 .25581 Mdot
.29951 .37247 Mdot
.35943 .41953 Mdot
.64034 .61752 Mdot
.26145 .53304 Mdot
.45471 .69692 Mdot
.28479 .52925 Mdot
.37495 .49649 Mdot
.65049 .63722 Mdot
.5511 .36365 Mdot
.26908 .54249 Mdot
.46969 .24317 Mdot
.68451 .64094 Mdot
.26787 .55246 Mdot
.56785 .36832 Mdot
.49517 .27129 Mdot
.5136 .25231 Mdot
.49479 .26345 Mdot
.36527 .42921 Mdot
.38682 .51777 Mdot
.50806 .29009 Mdot
.64979 .61455 Mdot
.50303 .28589 Mdot
.55171 .30084 Mdot
.72449 .63742 Mdot
.47971 .22003 Mdot
.35047 .42259 Mdot
.33238 .61688 Mdot
.32799 .61236 Mdot
.7098 .46406 Mdot
.55997 .75384 Mdot
.75132 .38162 Mdot
.35458 .47186 Mdot
.40363 .68624 Mdot
.43995 .68042 Mdot
.55885 .32233 Mdot
.37662 .4926 Mdot
.32371 .63742 Mdot
.44346 .67447 Mdot
.27421 .51955 Mdot
.40836 .67195 Mdot
.58901 .36115 Mdot
.36673 .42851 Mdot
.42557 .67445 Mdot
.4866 .70021 Mdot
.28504 .37728 Mdot
.41357 .67778 Mdot
.48219 .71819 Mdot
.70105 .65028 Mdot
.61691 .62758 Mdot
.64465 .63973 Mdot
.69178 .45516 Mdot
.4881 .73182 Mdot
.35726 .38995 Mdot
.6968 .45302 Mdot
.33553 .45059 Mdot
.6533 .63573 Mdot
.3685 .51175 Mdot
.48903 .73358 Mdot
.3554 .42134 Mdot
.24716 .51561 Mdot
.74538 .41031 Mdot
.48807 .24659 Mdot
.37985 .66182 Mdot
.7323 .42523 Mdot
.69096 .63776 Mdot
.53385 .75582 Mdot
.54505 .30227 Mdot
.30435 .63097 Mdot
.36017 .40304 Mdot
.3403 .4222 Mdot
.30377 .62976 Mdot
.28533 .49561 Mdot
.54384 .34712 Mdot
.69203 .45108 Mdot
.71672 .43495 Mdot
.37755 .43098 Mdot
.49174 .73016 Mdot
.47228 .23197 Mdot
.51273 .24424 Mdot
.51786 .30701 Mdot
.27411 .53699 Mdot
.38017 .48938 Mdot
.36193 .50488 Mdot
.3484 .38281 Mdot
.70943 .47591 Mdot
.55212 .36999 Mdot
.26938 .51754 Mdot
.5004 .27465 Mdot
.36281 .39731 Mdot
.42979 .67882 Mdot
.48062 .72651 Mdot
.69653 .49845 Mdot
.70028 .66079 Mdot
.59321 .35655 Mdot
.71655 .49784 Mdot
.37728 .42948 Mdot
.30209 .60416 Mdot
.70124 .65769 Mdot
.51412 .72083 Mdot
.49094 .26594 Mdot
.70056 .45708 Mdot
.49119 .27717 Mdot
.49818 .74645 Mdot
.48387 .72654 Mdot
.37816 .4119 Mdot
.48429 .30196 Mdot
.71789 .47417 Mdot
.34243 .45682 Mdot
.68765 .49931 Mdot
.74765 .39441 Mdot
.66211 .6554 Mdot
.36773 .39934 Mdot
.46843 .67121 Mdot
.6418 .64247 Mdot
.34989 .47026 Mdot
.32034 .60703 Mdot
.3115 .62855 Mdot
.70415 .43556 Mdot
.51747 .2908 Mdot
.49647 .27676 Mdot
.54402 .74756 Mdot
.45544 .71987 Mdot
.36249 .50165 Mdot
.7168 .45051 Mdot
.29283 .62762 Mdot
.62931 .62773 Mdot
.48413 .71368 Mdot
.72176 .60829 Mdot
.62756 .63775 Mdot
.37485 .4334 Mdot
.50391 .27283 Mdot
.50678 .71876 Mdot
.59129 .3838 Mdot
.23204 .41717 Mdot
.53685 .32316 Mdot
.49978 .31407 Mdot
.57815 .37395 Mdot
.7155 .62855 Mdot
.68995 .49165 Mdot
.46826 .69108 Mdot
.65211 .62189 Mdot
.62975 .62599 Mdot
.73171 .41471 Mdot
.38536 .65501 Mdot
.53697 .71929 Mdot
.36087 .6498 Mdot
.75793 .38587 Mdot
.49974 .2613 Mdot
.28792 .51864 Mdot
.69 .47312 Mdot
.75771 .40664 Mdot
.71852 .64399 Mdot
.71742 .63875 Mdot
.46638 .70173 Mdot
.36612 .4732 Mdot
.38119 .65357 Mdot
.33357 .45913 Mdot
.34479 .37716 Mdot
.65387 .63135 Mdot
.48484 .71424 Mdot
.72698 .64918 Mdot
.37846 .42127 Mdot
.36397 .45708 Mdot
.67357 .44305 Mdot
.56525 .36068 Mdot
.67697 .42812 Mdot
.36562 .39483 Mdot
.68617 .46008 Mdot
.51004 .71063 Mdot
.58133 .35145 Mdot
.2667 .50393 Mdot
.70759 .65546 Mdot
.55482 .33077 Mdot
.58535 .35651 Mdot
.33941 .39947 Mdot
.4078 .66942 Mdot
.52002 .75665 Mdot
.47431 .22534 Mdot
.73024 .65096 Mdot
.66697 .65303 Mdot
.7246 .63082 Mdot
.37536 .42971 Mdot
.71512 .65168 Mdot
.5934 .34868 Mdot
.34883 .47173 Mdot
.3047 .61412 Mdot
.39435 .66573 Mdot
.3546 .49679 Mdot
.33476 .63196 Mdot
.63446 .63669 Mdot
.6068 .39245 Mdot
.36139 .50051 Mdot
.69277 .50038 Mdot
.46947 .70432 Mdot
.39988 .66124 Mdot
.49806 .23977 Mdot
.70383 .63541 Mdot
.41723 .19846 Mdot
.48297 .71312 Mdot
.37126 .44384 Mdot
.62639 .63041 Mdot
.57144 .34105 Mdot
.55933 .34275 Mdot
.54083 .31857 Mdot
.47578 .72115 Mdot
.57751 .34902 Mdot
.50563 .70596 Mdot
.27581 .52303 Mdot
.35262 .38121 Mdot
.61279 .6389 Mdot
.50077 .26391 Mdot
.48378 .28367 Mdot
.74147 .40229 Mdot
.25783 .51697 Mdot
.34566 .37582 Mdot
.53924 .76557 Mdot
.50459 .26915 Mdot
.36073 .44531 Mdot
.5435 .34757 Mdot
.24184 .55398 Mdot
.48376 .20205 Mdot
.5693 .37262 Mdot
.30574 .59719 Mdot
.52228 .73657 Mdot
.5547 .35522 Mdot
.48091 .73033 Mdot
.359 .44937 Mdot
.26316 .52562 Mdot
.52733 .75426 Mdot
.56247 .73708 Mdot
.58897 .34897 Mdot
.66047 .65028 Mdot
.26403 .53402 Mdot
.3455 .42403 Mdot
.24101 .52831 Mdot
.56367 .33773 Mdot
.57662 .70858 Mdot
.68086 .49198 Mdot
.74352 .38617 Mdot
.76895 .37831 Mdot
.69073 .6337 Mdot
.73789 .64475 Mdot
.38311 .43495 Mdot
.37894 .64438 Mdot
.24036 .53111 Mdot
.6386 .64644 Mdot
.29158 .50133 Mdot
.35391 .44991 Mdot
.33799 .44412 Mdot
.6878 .49986 Mdot
.61023 .64893 Mdot
.31392 .59229 Mdot
.26884 .52026 Mdot
.51853 .28207 Mdot
.48879 .74135 Mdot
.35709 .43791 Mdot
.53799 .76517 Mdot
.70666 .43575 Mdot
.55109 .76239 Mdot
.35011 .42435 Mdot
.5658 .36093 Mdot
.7198 .65544 Mdot
.69939 .64623 Mdot
.70315 .44045 Mdot
.70602 .44274 Mdot
.3447 .42594 Mdot
.66248 .63634 Mdot
.29126 .50349 Mdot
.27096 .54028 Mdot
.57109 .34946 Mdot
.4822 .23345 Mdot
.33152 .45779 Mdot
.53219 .71523 Mdot
.47119 .2903 Mdot
.34093 .45617 Mdot
.51195 .75285 Mdot
.69531 .48838 Mdot
.74073 .40836 Mdot
.5025 .7243 Mdot
.74527 .40483 Mdot
.55189 .76081 Mdot
.38753 .51513 Mdot
.4808 .22736 Mdot
.31278 .58228 Mdot
.50297 .2881 Mdot
.55625 .33217 Mdot
.37434 .43771 Mdot
.73218 .49198 Mdot
.76969 .37922 Mdot
.27038 .57223 Mdot
.64582 .62874 Mdot
.57124 .38059 Mdot
.31778 .61924 Mdot
.52122 .27523 Mdot
.70006 .46808 Mdot
.59719 .37596 Mdot
.36399 .39623 Mdot
.41264 .66671 Mdot
.32672 .60005 Mdot
.5873 .37941 Mdot
.55475 .33397 Mdot
.59511 .36551 Mdot
.66466 .64909 Mdot
.42361 .65784 Mdot
.71832 .64242 Mdot
.73952 .41428 Mdot
.25396 .54089 Mdot
.36968 .44161 Mdot
.49338 .71719 Mdot
.34261 .47777 Mdot
.65005 .64228 Mdot
.36245 .6656 Mdot
.49826 .25475 Mdot
.58795 .35554 Mdot
.58756 .68922 Mdot
.59438 .38366 Mdot
.3005 .61814 Mdot
.29646 .60351 Mdot
.43673 .68224 Mdot
.63917 .64873 Mdot
.34136 .50113 Mdot
.72049 .43725 Mdot
.49231 .26976 Mdot
.70851 .64885 Mdot
.30213 .61299 Mdot
.35794 .41634 Mdot
.50234 .26676 Mdot
.7165 .63947 Mdot
.50402 .30226 Mdot
.66818 .62913 Mdot
.53388 .32533 Mdot
.29322 .5784 Mdot
.35268 .4288 Mdot
.56805 .36468 Mdot
.44134 .6774 Mdot
.69385 .64943 Mdot
.38965 .65864 Mdot
.58859 .3613 Mdot
.74339 .39782 Mdot
.70594 .6502 Mdot
.36432 .40131 Mdot
.45661 .67167 Mdot
.45331 .69761 Mdot
.43506 .66337 Mdot
.68974 .36079 Mdot
.75069 .38595 Mdot
.69316 .49302 Mdot
.6298 .64036 Mdot
.67668 .48606 Mdot
.51357 .2565 Mdot
.28797 .51603 Mdot
.71172 .44966 Mdot
.41829 .65631 Mdot
.67831 .45976 Mdot
.28077 .50414 Mdot
.65417 .65011 Mdot
.7113 .505 Mdot
.33995 .48255 Mdot
.3205 .60949 Mdot
.55181 .33694 Mdot
.49427 .289 Mdot
.27403 .52487 Mdot
.36279 .48221 Mdot
.57503 .36377 Mdot
.35363 .42361 Mdot
.65275 .64121 Mdot
.24031 .43997 Mdot
.24925 .53576 Mdot
.74547 .39987 Mdot
.55532 .74835 Mdot
.71545 .43305 Mdot
.46483 .20966 Mdot
.34185 .46983 Mdot
.35688 .42506 Mdot
.31306 .62555 Mdot
.35628 .6589 Mdot
.7058 .64278 Mdot
.25407 .54379 Mdot
.75663 .39281 Mdot
.45519 .6883 Mdot
.44572 .68615 Mdot
.34385 .38219 Mdot
.56756 .36623 Mdot
.61992 .62247 Mdot
.36558 .42467 Mdot
.58552 .38333 Mdot
.37304 .49576 Mdot
.70169 .63089 Mdot
.75037 .38483 Mdot
.7537 .40849 Mdot
.44719 .68902 Mdot
.69538 .50754 Mdot
.31466 .62654 Mdot
.57537 .34692 Mdot
.7695 .37532 Mdot
.70564 .63993 Mdot
.49208 .27088 Mdot
.33708 .45155 Mdot
.29188 .37405 Mdot
.69563 .5084 Mdot
.69693 .44701 Mdot
.29083 .50334 Mdot
.54081 .766 Mdot
.51336 .32995 Mdot
.68424 .64814 Mdot
.43035 .67981 Mdot
.43296 .48301 Mdot
.42522 .32227 Mdot
.61764 .63048 Mdot
.30463 .6086 Mdot
.70074 .50659 Mdot
.6375 .38151 Mdot
.44773 .67943 Mdot
.49109 .26848 Mdot
.34381 .48207 Mdot
.44713 .68488 Mdot
.76325 .38254 Mdot
.45069 .67339 Mdot
.55911 .35488 Mdot
.65206 .64969 Mdot
.70425 .47158 Mdot
.60893 .64831 Mdot
.46549 .66917 Mdot
.49917 .25858 Mdot
.333 .37748 Mdot
.33416 .61691 Mdot
.40235 .67413 Mdot
.31557 .61327 Mdot
.57551 .33036 Mdot
.31719 .61015 Mdot
.4319 .68221 Mdot
.35837 .41921 Mdot
.35266 .50522 Mdot
.73523 .41135 Mdot
.33997 .43612 Mdot
.37571 .45977 Mdot
.24607 .51693 Mdot
.33865 .46135 Mdot
.34736 .45796 Mdot
.37213 .40653 Mdot
.52077 .74851 Mdot
.36892 .49724 Mdot
.48493 .70656 Mdot
.52648 .72746 Mdot
.74079 .41342 Mdot
.52119 .26709 Mdot
.47739 .22209 Mdot
.36879 .49973 Mdot
.29291 .37462 Mdot
.3827 .65676 Mdot
.46661 .70868 Mdot
.69519 .6447 Mdot
.25168 .52998 Mdot
.51118 .32736 Mdot
.36139 .50908 Mdot
.71049 .4639 Mdot
.7093 .43873 Mdot
.33453 .47751 Mdot
.42713 .19206 Mdot
.37144 .39533 Mdot
.28357 .51339 Mdot
.36353 .42938 Mdot
.3732 .40403 Mdot
.7179 .44341 Mdot
.32049 .37263 Mdot
.32553 .6344 Mdot
.43191 .68444 Mdot
.48824 .26727 Mdot
.55776 .35891 Mdot
.26326 .52565 Mdot
.42298 .49559 Mdot
.40193 .66801 Mdot
.31144 .62549 Mdot
.70499 .46114 Mdot
.4868 .72456 Mdot
.28037 .51296 Mdot
.6768 .64198 Mdot
.23714 .40922 Mdot
.54893 .75948 Mdot
.67656 .64489 Mdot
.49434 .27048 Mdot
.71197 .48744 Mdot
.36157 .45237 Mdot
.68331 .4541 Mdot
.37624 .4174 Mdot
.27882 .53924 Mdot
.4821 .22859 Mdot
.41788 .65925 Mdot
.70543 .65567 Mdot
.5181 .74358 Mdot
.53732 .72184 Mdot
.27132 .44794 Mdot
.71251 .41534 Mdot
.72006 .4656 Mdot
.46857 .27119 Mdot
.47097 .69928 Mdot
.37785 .45624 Mdot
.36802 .64863 Mdot
.50686 .73994 Mdot
.40758 .6631 Mdot
.2365 .41567 Mdot
.3079 .36175 Mdot
.37038 .40549 Mdot
.44052 .67899 Mdot
.71159 .49055 Mdot
.48032 .2255 Mdot
.37815 .44321 Mdot
.57402 .34528 Mdot
.44877 .68938 Mdot
.6976 .50363 Mdot
.32542 .37494 Mdot
.68899 .45874 Mdot
.45472 .6846 Mdot
.71092 .43293 Mdot
.66435 .65613 Mdot
.7128 .45152 Mdot
.33197 .44823 Mdot
.36177 .42412 Mdot
.43802 .68446 Mdot
.48406 .72664 Mdot
.30107 .61956 Mdot
.33804 .47266 Mdot
.46881 .69331 Mdot
.6719 .47217 Mdot
.4547 .70594 Mdot
.30896 .62832 Mdot
.37327 .46092 Mdot
.50529 .2885 Mdot
.25924 .54762 Mdot
.23228 .43314 Mdot
.24948 .53914 Mdot
.49666 .25865 Mdot
.39339 .64406 Mdot
.37044 .42658 Mdot
.31506 .36672 Mdot
.75939 .38902 Mdot
.34274 .49114 Mdot
.579 .34562 Mdot
.31487 .63589 Mdot
.26028 .38145 Mdot
.30286 .61515 Mdot
.43801 .66791 Mdot
.4577 .68611 Mdot
.67521 .45276 Mdot
.44691 .68101 Mdot
.57535 .34386 Mdot
.62361 .62106 Mdot
.53406 .72116 Mdot
.55349 .37105 Mdot
.54652 .32975 Mdot
.56942 .33202 Mdot
.577 .377 Mdot
.50963 .32432 Mdot
.73413 .4066 Mdot
.54808 .33245 Mdot
.47854 .70048 Mdot
.70425 .52664 Mdot
.54088 .303 Mdot
.62012 .6222 Mdot
.58395 .35476 Mdot
.3435 .49209 Mdot
.30779 .62238 Mdot
.53196 .75756 Mdot
.67269 .64048 Mdot
.58958 .34546 Mdot
.37729 .45478 Mdot
.44862 .69096 Mdot
.35619 .441 Mdot
.5171 .28746 Mdot
.48942 .73483 Mdot
.69794 .45744 Mdot
.48402 .23022 Mdot
.58677 .37152 Mdot
.49177 .24557 Mdot
.68229 .48331 Mdot
.66887 .62607 Mdot
.3454 .48441 Mdot
.49289 .29216 Mdot
.51849 .26108 Mdot
.34439 .49021 Mdot
.46551 .69748 Mdot
.59074 .34854 Mdot
.36804 .47337 Mdot
.31524 .62142 Mdot
.51433 .72944 Mdot
.58168 .71486 Mdot
.35997 .45674 Mdot
.29741 .60331 Mdot
.43857 .68704 Mdot
.58401 .38231 Mdot
.69511 .45453 Mdot
.35572 .40838 Mdot
.65064 .627 Mdot
.65642 .63429 Mdot
.76237 .38262 Mdot
.50106 .75379 Mdot
.68513 .50951 Mdot
.33171 .47663 Mdot
.58532 .35858 Mdot
.35839 .41108 Mdot
.66819 .45827 Mdot
.5702 .73692 Mdot
.4973 .7142 Mdot
.74275 .41472 Mdot
.38558 .4617 Mdot
.60191 .63626 Mdot
.745 .40189 Mdot
.43325 .68442 Mdot
.49908 .74906 Mdot
.49954 .72323 Mdot
.47602 .23344 Mdot
.69278 .46161 Mdot
.53119 .7515 Mdot
.5253 .73736 Mdot
.31 .62734 Mdot
.3351 .4795 Mdot
.42767 .67648 Mdot
.75777 .38301 Mdot
.49415 .27586 Mdot
.75403 .3987 Mdot
.46933 .28642 Mdot
.69182 .65148 Mdot
.27484 .50119 Mdot
.25638 .51745 Mdot
.4109 .20549 Mdot
.36104 .39663 Mdot
.36544 .43126 Mdot
.39686 .65389 Mdot
.51446 .30155 Mdot
.48141 .26355 Mdot
.46963 .69832 Mdot
.50045 .7149 Mdot
.48992 .23777 Mdot
.37821 .51738 Mdot
.27423 .38448 Mdot
.38687 .45308 Mdot
.42295 .65677 Mdot
.51603 .70735 Mdot
.64677 .63369 Mdot
.4497 .68916 Mdot
.72065 .52685 Mdot
.7164 .49467 Mdot
.71608 .46028 Mdot
.69968 .64862 Mdot
.36306 .45182 Mdot
.72051 .45714 Mdot
.32959 .62475 Mdot
.72855 .52078 Mdot
.31419 .60281 Mdot
.7686 .36776 Mdot
.3395 .47624 Mdot
.59881 .65399 Mdot
.71189 .6287 Mdot
.306 .62807 Mdot
.39078 .51639 Mdot
.48924 .25771 Mdot
.39443 .65383 Mdot
.63425 .64588 Mdot
.38186 .65423 Mdot
.35422 .42712 Mdot
.42577 .66832 Mdot
.6973 .65604 Mdot
.57368 .71872 Mdot
.32369 .63649 Mdot
.32467 .62587 Mdot
.37351 .65927 Mdot
.47745 .69398 Mdot
.69349 .45481 Mdot
.40575 .66501 Mdot
.53068 .74358 Mdot
.31762 .60691 Mdot
.70354 .50779 Mdot
.28758 .53906 Mdot
.42099 .65933 Mdot
.47077 .2315 Mdot
.49368 .74182 Mdot
.48672 .23729 Mdot
.53059 .75459 Mdot
.73385 .41539 Mdot
.34902 .46412 Mdot
.74157 .4122 Mdot
.51523 .2785 Mdot
.71728 .42799 Mdot
.65493 .64224 Mdot
.58029 .36153 Mdot
.64375 .64171 Mdot
.28511 .51904 Mdot
.38642 .65305 Mdot
.6204 .62448 Mdot
.28474 .4578 Mdot
.35987 .41615 Mdot
.53025 .75497 Mdot
.70335 .46251 Mdot
.75877 .3971 Mdot
.27523 .52957 Mdot
.47813 .71462 Mdot
.67596 .45522 Mdot
.28999 .61564 Mdot
.73166 .50408 Mdot
.30915 .63307 Mdot
.72735 .61164 Mdot
.45668 .68137 Mdot
.76172 .39225 Mdot
.28506 .51214 Mdot
.52421 .72895 Mdot
.71709 .48579 Mdot
.66787 .62773 Mdot
.64944 .62687 Mdot
.34576 .41163 Mdot
.60641 .64716 Mdot
.70921 .4624 Mdot
.54705 .76439 Mdot
.5292 .75141 Mdot
.56723 .74346 Mdot
.49513 .25406 Mdot
.70493 .49507 Mdot
.57126 .34814 Mdot
.45635 .66268 Mdot
.67655 .47407 Mdot
.41889 .19588 Mdot
.75224 .33008 Mdot
.6753 .49601 Mdot
.48807 .73504 Mdot
.47595 .71959 Mdot
.32306 .59958 Mdot
.27329 .52819 Mdot
.70089 .47017 Mdot
.71156 .52817 Mdot
.38169 .4875 Mdot
.58099 .3649 Mdot
.7633 .37555 Mdot
.35725 .39081 Mdot
.31592 .61629 Mdot
.68835 .64574 Mdot
.36342 .4587 Mdot
.4944 .71036 Mdot
.36788 .39456 Mdot
.63976 .64405 Mdot
.68373 .43355 Mdot
.35408 .42544 Mdot
.49304 .2695 Mdot
.65779 .62537 Mdot
.66118 .62887 Mdot
.71958 .42352 Mdot
.50085 .75383 Mdot
.38881 .66333 Mdot
.69233 .45901 Mdot
.32271 .61402 Mdot
.57375 .35985 Mdot
.36825 .40242 Mdot
.41174 .66004 Mdot
.39132 .65278 Mdot
.70567 .49492 Mdot
.35174 .49444 Mdot
.61983 .63586 Mdot
.67245 .48747 Mdot
.30549 .60362 Mdot
.71602 .46699 Mdot
.53995 .35822 Mdot
.72051 .48633 Mdot
.50138 .7044 Mdot
.56361 .32478 Mdot
.42284 .66564 Mdot
.54518 .34401 Mdot
.65599 .36381 Mdot
.49551 .27272 Mdot
.71635 .44114 Mdot
.56386 .73313 Mdot
.74702 .41143 Mdot
.34032 .46496 Mdot
.37351 .42794 Mdot
.68105 .48832 Mdot
.50179 .26154 Mdot
.56262 .30339 Mdot
.51298 .29745 Mdot
.48411 .73063 Mdot
.32396 .6381 Mdot
.76853 .347 Mdot
.74615 .41721 Mdot
.68893 .65655 Mdot
.43112 .68725 Mdot
.54452 .33218 Mdot
.66135 .6406 Mdot
.66283 .62864 Mdot
.50454 .25672 Mdot
.75576 .40851 Mdot
.41488 .66568 Mdot
.61513 .64926 Mdot
.52119 .7257 Mdot
.31977 .36621 Mdot
.58323 .37939 Mdot
.47081 .26866 Mdot
.54496 .35047 Mdot
.27294 .51912 Mdot
.60632 .64341 Mdot
.34877 .44696 Mdot
.52039 .28129 Mdot
.69581 .64789 Mdot
.50705 .29156 Mdot
.30485 .60588 Mdot
.68758 .43314 Mdot
.43072 .70833 Mdot
.34225 .41704 Mdot
.34973 .47463 Mdot
.69704 .65221 Mdot
.39837 .51538 Mdot
.42109 .6781 Mdot
.52679 .74794 Mdot
.69022 .49088 Mdot
.23257 .42467 Mdot
.37647 .40522 Mdot
.3776 .44784 Mdot
.67985 .46932 Mdot
.56545 .36721 Mdot
.74111 .39139 Mdot
.37514 .45274 Mdot
.63845 .63694 Mdot
.30386 .61163 Mdot
.60365 .63277 Mdot
.33328 .4825 Mdot
.34679 .46783 Mdot
.32758 .62455 Mdot
.31141 .61142 Mdot
.64315 .64169 Mdot
.57314 .37349 Mdot
.59159 .3589 Mdot
.42477 .65892 Mdot
.33818 .47843 Mdot
.38456 .47987 Mdot
.36594 .4259 Mdot
.48979 .25857 Mdot
.2291 .43813 Mdot
.28219 .50302 Mdot
.26301 .53913 Mdot
.37687 .50207 Mdot
.35725 .44932 Mdot
.69399 .65414 Mdot
.47369 .71522 Mdot
.6202 .63311 Mdot
.63728 .65224 Mdot
.68055 .4503 Mdot
.50534 .29082 Mdot
.3436 .42756 Mdot
.50835 .25228 Mdot
.36947 .38671 Mdot
.47132 .21301 Mdot
.26623 .52052 Mdot
.29085 .51103 Mdot
.47232 .23838 Mdot
.36515 .41806 Mdot
.68615 .49403 Mdot
.72244 .44543 Mdot
.32908 .61337 Mdot
.33099 .46508 Mdot
.6809 .65616 Mdot
.63746 .61762 Mdot
.74527 .38993 Mdot
.72928 .43453 Mdot
.51732 .28774 Mdot
.61584 .3903 Mdot
.31609 .60901 Mdot
.34438 .41951 Mdot
.57865 .37271 Mdot
.68422 .50373 Mdot
.54542 .3399 Mdot
.74052 .39834 Mdot
.62609 .64657 Mdot
.63551 .62238 Mdot
.33482 .47008 Mdot
.44798 .19081 Mdot
.50945 .74255 Mdot
.47665 .7198 Mdot
.63396 .61682 Mdot
.71554 .43326 Mdot
.5558 .34851 Mdot
.37155 .64993 Mdot
.42988 .68549 Mdot
.51786 .26291 Mdot
.35654 .41034 Mdot
.7192 .48165 Mdot
.47125 .69147 Mdot
.51715 .28111 Mdot
.24701 .53799 Mdot
.68755 .51767 Mdot
.35147 .43831 Mdot
.29414 .60485 Mdot
.47968 .70794 Mdot
.26916 .52889 Mdot
.4189 .65868 Mdot
.65345 .63203 Mdot
.61485 .64727 Mdot
.34801 .46974 Mdot
.4227 .70011 Mdot
.50749 .70962 Mdot
.61023 .64664 Mdot
.47434 .2344 Mdot
.57483 .35382 Mdot
.50697 .29094 Mdot
.6927 .49827 Mdot
.49457 .27191 Mdot
.67701 .46451 Mdot
.74715 .40065 Mdot
.42538 .67282 Mdot
.50268 .26738 Mdot
.259 .50553 Mdot
.57239 .34533 Mdot
.48243 .21661 Mdot
.2586 .52793 Mdot
.29989 .60807 Mdot
.70353 .48005 Mdot
.51096 .25576 Mdot
.36088 .40411 Mdot
.58599 .68996 Mdot
.6497 .65093 Mdot
.65044 .64321 Mdot
.55794 .35369 Mdot
.70947 .48839 Mdot
.40968 .66135 Mdot
.37358 .49627 Mdot
.49274 .69787 Mdot
.36979 .47315 Mdot
.33972 .4445 Mdot
.51073 .70949 Mdot
.40904 .66091 Mdot
.35169 .46806 Mdot
.3509 .38546 Mdot
.57656 .35107 Mdot
.65783 .6305 Mdot
.48716 .7318 Mdot
.49087 .72798 Mdot
.70267 .44991 Mdot
.4455 .68675 Mdot
.49311 .30841 Mdot
.64361 .64513 Mdot
.59323 .38355 Mdot
.62503 .63958 Mdot
.54301 .27662 Mdot
.67542 .49226 Mdot
.56678 .71913 Mdot
.51825 .75841 Mdot
.31542 .62932 Mdot
.42572 .67498 Mdot
.49596 .25175 Mdot
.44922 .68661 Mdot
.43549 .67737 Mdot
.33948 .48351 Mdot
.58171 .37467 Mdot
.55146 .33295 Mdot
.27094 .51762 Mdot
.50813 .74205 Mdot
.35367 .45792 Mdot
.25394 .53293 Mdot
.34424 .47733 Mdot
.26972 .52701 Mdot
.52081 .75304 Mdot
.42165 .49775 Mdot
.43504 .68113 Mdot
.47616 .70355 Mdot
.46902 .28693 Mdot
.56741 .34051 Mdot
.54287 .3397 Mdot
.65985 .65943 Mdot
.36699 .47251 Mdot
.74237 .40745 Mdot
.32077 .61411 Mdot
.58508 .36512 Mdot
.23779 .53834 Mdot
.50445 .24121 Mdot
.37739 .42047 Mdot
.576 .36913 Mdot
.70057 .46118 Mdot
.31615 .62879 Mdot
.3742 .43853 Mdot
.5584 .36177 Mdot
.41905 .67001 Mdot
.51149 .73049 Mdot
.42197 .68363 Mdot
.49472 .24424 Mdot
.62433 .64401 Mdot
.31896 .61526 Mdot
.68946 .49355 Mdot
.74031 .40984 Mdot
.42111 .6649 Mdot
.70093 .43526 Mdot
.64078 .6213 Mdot
.37261 .44869 Mdot
.6526 .6356 Mdot
.4988 .23708 Mdot
.49043 .73464 Mdot
.31805 .62379 Mdot
.33857 .61508 Mdot
.45787 .6863 Mdot
.58009 .35325 Mdot
.50168 .29036 Mdot
.70086 .43054 Mdot
.4964 .71521 Mdot
.6236 .64516 Mdot
.70212 .44493 Mdot
.32268 .62811 Mdot
.45892 .21144 Mdot
.36262 .45966 Mdot
.33382 .45694 Mdot
.43786 .65115 Mdot
.34541 .50148 Mdot
.73888 .41468 Mdot
.4031 .6539 Mdot
.30353 .62212 Mdot
.28685 .52576 Mdot
.49333 .20754 Mdot
.53017 .30006 Mdot
.35975 .44089 Mdot
.23988 .53007 Mdot
.35838 .50683 Mdot
.56108 .73987 Mdot
.27152 .53117 Mdot
.67035 .45847 Mdot
.46971 .26831 Mdot
.63552 .65292 Mdot
.57608 .36546 Mdot
.69206 .43292 Mdot
.35249 .3857 Mdot
.36096 .46334 Mdot
.4465 .70527 Mdot
.30231 .60709 Mdot
.6225 .62817 Mdot
.41046 .50643 Mdot
.70452 .45973 Mdot
.77087 .37271 Mdot
.33043 .47344 Mdot
.41808 .67746 Mdot
.59158 .66304 Mdot
.58217 .37139 Mdot
.54235 .34282 Mdot
.51652 .27743 Mdot
.67602 .44654 Mdot
.53751 .31837 Mdot
.62112 .63617 Mdot
.35796 .40095 Mdot
.28102 .50257 Mdot
.58538 .70793 Mdot
.46426 .6868 Mdot
.66715 .65248 Mdot
.53993 .2685 Mdot
.34455 .44573 Mdot
.51263 .74742 Mdot
.44811 .67995 Mdot
.51928 .2637 Mdot
.7382 .40502 Mdot
.7583 .38724 Mdot
.4327 .19187 Mdot
.58071 .33721 Mdot
.68319 .502 Mdot
.54262 .31971 Mdot
.32471 .6165 Mdot
.26298 .52465 Mdot
.647 .65326 Mdot
.33868 .46496 Mdot
.42909 .69244 Mdot
.43146 .66262 Mdot
.36334 .42693 Mdot
.48675 .2679 Mdot
.3579 .65825 Mdot
.33579 .62498 Mdot
.34409 .3962 Mdot
.71141 .49138 Mdot
.34019 .45201 Mdot
.49409 .30987 Mdot
.58283 .38377 Mdot
.34461 .49738 Mdot
.69457 .45626 Mdot
.56388 .32512 Mdot
.4857 .26857 Mdot
.43248 .6612 Mdot
.57412 .36406 Mdot
.30411 .60404 Mdot
.37016 .40872 Mdot
.47403 .23624 Mdot
.32604 .62218 Mdot
.51645 .70622 Mdot
.54152 .34871 Mdot
.7156 .45486 Mdot
.51025 .72089 Mdot
.34281 .45837 Mdot
.57656 .35458 Mdot
.35473 .41376 Mdot
.54183 .72514 Mdot
.33588 .44683 Mdot
.57923 .696 Mdot
.47099 .70638 Mdot
.63253 .6314 Mdot
.31262 .62489 Mdot
.35018 .43689 Mdot
.54735 .32049 Mdot
.55469 .34438 Mdot
.37798 .45372 Mdot
.42229 .66461 Mdot
.44098 .67774 Mdot
.40908 .67239 Mdot
.7068 .4505 Mdot
.38775 .43355 Mdot
.63997 .63096 Mdot
.57361 .37235 Mdot
.60556 .64619 Mdot
.24241 .52833 Mdot
.49127 .24298 Mdot
.58169 .70449 Mdot
.37068 .45916 Mdot
.4816 .71705 Mdot
.2772 .38562 Mdot
.48071 .73848 Mdot
.67046 .66066 Mdot
.66923 .65312 Mdot
.50167 .73679 Mdot
.36189 .43947 Mdot
.27478 .51904 Mdot
.2843 .50159 Mdot
.60804 .64351 Mdot
.59397 .36688 Mdot
.54261 .37624 Mdot
.71227 .49905 Mdot
.46077 .21082 Mdot
.70786 .64982 Mdot
.72165 .63382 Mdot
.30896 .62836 Mdot
.51531 .72847 Mdot
.61414 .63999 Mdot
.66698 .63308 Mdot
.70798 .4679 Mdot
.3118 .62798 Mdot
.35259 .4336 Mdot
.57386 .34184 Mdot
.68788 .63911 Mdot
.38098 .4367 Mdot
.30027 .61923 Mdot
.73962 .39594 Mdot
.39971 .66201 Mdot
.58135 .71919 Mdot
.24276 .53204 Mdot
.40468 .67631 Mdot
.73237 .48645 Mdot
.53016 .7516 Mdot
.35234 .45693 Mdot
.5623 .34763 Mdot
.70438 .43417 Mdot
.36984 .44789 Mdot
.74396 .4148 Mdot
.61494 .63141 Mdot
.58749 .69361 Mdot
.25227 .51753 Mdot
.72815 .51994 Mdot
.353 .46376 Mdot
.33436 .61463 Mdot
.50202 .27817 Mdot
.60981 .63959 Mdot
.45184 .70079 Mdot
.35246 .41051 Mdot
.69535 .44871 Mdot
.71025 .5048 Mdot
.42878 .66451 Mdot
.42522 .68485 Mdot
.56634 .72642 Mdot
.56933 .34637 Mdot
.6925 .4399 Mdot
.57607 .35311 Mdot
.34497 .3934 Mdot
.61248 .64855 Mdot
.48482 .26737 Mdot
.70994 .43283 Mdot
.71027 .64594 Mdot
.29981 .60777 Mdot
.48678 .74085 Mdot
.45336 .65989 Mdot
.33161 .62134 Mdot
.68018 .44235 Mdot
.48337 .24347 Mdot
.26554 .53387 Mdot
.3299 .63472 Mdot
.48139 .23549 Mdot
.7073 .45671 Mdot
.51105 .73545 Mdot
.44675 .67631 Mdot
.47108 .71141 Mdot
.27191 .50195 Mdot
.38741 .64667 Mdot
.34015 .37434 Mdot
.35054 .50405 Mdot
.54565 .74768 Mdot
.36621 .49128 Mdot
.64767 .6437 Mdot
.48198 .71126 Mdot
.26938 .52788 Mdot
.30714 .63493 Mdot
.35805 .3843 Mdot
.35376 .48278 Mdot
.31019 .60904 Mdot
.367 .47273 Mdot
.51402 .709 Mdot
.39265 .65271 Mdot
.26388 .5378 Mdot
.64844 .64624 Mdot
.48974 .24855 Mdot
.53177 .74324 Mdot
.34067 .4472 Mdot
.51869 .71017 Mdot
.25938 .53319 Mdot
.57972 .6932 Mdot
.31044 .60692 Mdot
.68271 .43409 Mdot
.36212 .39929 Mdot
.71726 .49705 Mdot
.33955 .62034 Mdot
.52192 .71087 Mdot
.65749 .64996 Mdot
.33639 .62495 Mdot
.69498 .52515 Mdot
.4132 .50408 Mdot
.56117 .34381 Mdot
.4971 .27787 Mdot
.56275 .32545 Mdot
.6466 .64169 Mdot
.36625 .46269 Mdot
.36874 .41036 Mdot
.34291 .50085 Mdot
.34467 .39358 Mdot
.56967 .3423 Mdot
.47185 .22699 Mdot
.53691 .72471 Mdot
.3761 .42319 Mdot
.72114 .45333 Mdot
.52171 .73908 Mdot
.3557 .38586 Mdot
.28295 .49691 Mdot
.30119 .59847 Mdot
.50619 .7411 Mdot
.49801 .7529 Mdot
.51199 .32859 Mdot
.49743 .26564 Mdot
.34456 .47366 Mdot
.47251 .24856 Mdot
.31992 .61778 Mdot
.63231 .64175 Mdot
.34888 .50787 Mdot
.67486 .48983 Mdot
.27941 .52876 Mdot
.70802 .45548 Mdot
.3494 .47872 Mdot
.49084 .74053 Mdot
.61364 .64568 Mdot
.76206 .38674 Mdot
.76323 .37871 Mdot
.33943 .37132 Mdot
.77086 .38119 Mdot
.50064 .24801 Mdot
.5003 .25265 Mdot
.61324 .64259 Mdot
.36452 .43334 Mdot
.27348 .53406 Mdot
.34209 .60791 Mdot
.36519 .47164 Mdot
.3642 .44971 Mdot
.71093 .64255 Mdot
.70218 .64864 Mdot
.71159 .4346 Mdot
.35419 .4673 Mdot
.38076 .42826 Mdot
.49736 .73973 Mdot
.51749 .29692 Mdot
.68561 .44181 Mdot
.51687 .28291 Mdot
.6839 .46585 Mdot
.26112 .38099 Mdot
.58786 .37595 Mdot
.4972 .24778 Mdot
.71113 .65299 Mdot
.48525 .71995 Mdot
.57277 .34283 Mdot
.6983 .48443 Mdot
.69667 .43699 Mdot
.36028 .3902 Mdot
.46291 .68469 Mdot
.52697 .74917 Mdot
.49185 .24089 Mdot
.63977 .61712 Mdot
.32994 .62449 Mdot
.5445 .34938 Mdot
.52921 .24412 Mdot
.69538 .44302 Mdot
.54861 .75472 Mdot
.44718 .65758 Mdot
.34395 .43445 Mdot
.51084 .73075 Mdot
.34836 .43152 Mdot
.40651 .66521 Mdot
.52581 .72768 Mdot
.33236 .48113 Mdot
.40912 .67602 Mdot
.68042 .50016 Mdot
.76915 .3574 Mdot
.3035 .6274 Mdot
.71947 .65834 Mdot
.32184 .61531 Mdot
.7463 .38496 Mdot
.27983 .3838 Mdot
.373 .42099 Mdot
.34002 .44689 Mdot
.44475 .22082 Mdot
.36599 .50138 Mdot
.54812 .35061 Mdot
.56152 .34329 Mdot
.5143 .73576 Mdot
.56068 .32509 Mdot
.27233 .52094 Mdot
.50656 .27004 Mdot
.69107 .49137 Mdot
.3124 .36762 Mdot
.48603 .23964 Mdot
.4407 .66892 Mdot
.3256 .63361 Mdot
.54167 .74648 Mdot
.72256 .46581 Mdot
.56427 .36354 Mdot
.61706 .63048 Mdot
.25896 .54957 Mdot
.7002 .45377 Mdot
.69582 .64132 Mdot
.26235 .51497 Mdot
.67963 .43471 Mdot
.64869 .64559 Mdot
.76821 .35298 Mdot
.68367 .64481 Mdot
.62683 .6194 Mdot
.27978 .50917 Mdot
.507 .27085 Mdot
.55485 .32073 Mdot
.4693 .24092 Mdot
.66486 .64817 Mdot
.74727 .38128 Mdot
.70945 .48281 Mdot
.28098 .53488 Mdot
.38987 .64673 Mdot
.58476 .35498 Mdot
.35885 .4595 Mdot
.69149 .6482 Mdot
.37036 .38714 Mdot
.55645 .32163 Mdot
.63888 .6235 Mdot
.33938 .6191 Mdot
.22841 .43439 Mdot
.56837 .35058 Mdot
.55521 .3317 Mdot
.51274 .26326 Mdot
.75148 .39082 Mdot
.52528 .75407 Mdot
.50731 .24345 Mdot
.36377 .51582 Mdot
.33967 .47408 Mdot
.64061 .64238 Mdot
.57301 .36418 Mdot
.64496 .62838 Mdot
.49549 .28206 Mdot
.47404 .22537 Mdot
.43495 .66305 Mdot
.41194 .67406 Mdot
.53322 .32644 Mdot
.37911 .50146 Mdot
.35978 .50324 Mdot
.44415 .70228 Mdot
.5066 .75298 Mdot
.38975 .51514 Mdot
.49214 .28301 Mdot
.51461 .26529 Mdot
.33647 .61699 Mdot
.25588 .53678 Mdot
.30718 .61301 Mdot
.24806 .5284 Mdot
.65686 .45121 Mdot
.315 .62603 Mdot
.69871 .43217 Mdot
.24725 .53091 Mdot
.72956 .64815 Mdot
.32725 .60932 Mdot
.34356 .43116 Mdot
.68845 .46994 Mdot
.34551 .49218 Mdot
.69888 .5009 Mdot
.34786 .46208 Mdot
.66795 .45752 Mdot
.68936 .49316 Mdot
.61799 .39419 Mdot
.26085 .44625 Mdot
.54772 .34721 Mdot
.47831 .25502 Mdot
.49565 .29463 Mdot
.32687 .37482 Mdot
.50716 .73419 Mdot
.35685 .64949 Mdot
.34267 .43541 Mdot
.70906 .4705 Mdot
.61634 .62877 Mdot
.33022 .60281 Mdot
.33344 .44616 Mdot
.32773 .61576 Mdot
.48753 .74209 Mdot
.70886 .49382 Mdot
.5029 .28345 Mdot
.73167 .42371 Mdot
.75287 .38087 Mdot
.67792 .50053 Mdot
.33476 .40851 Mdot
.30794 .5977 Mdot
.49502 .31028 Mdot
.39172 .65987 Mdot
.56246 .30831 Mdot
.44693 .68209 Mdot
.57696 .36351 Mdot
.51378 .27732 Mdot
.23776 .43948 Mdot
.52405 .74321 Mdot
.67999 .46994 Mdot
.35098 .4395 Mdot
.57398 .37519 Mdot
.469 .2391 Mdot
.50104 .7132 Mdot
.47353 .23695 Mdot
.69363 .48188 Mdot
.57293 .35565 Mdot
.3875 .4238 Mdot
.43097 .48648 Mdot
.28093 .53868 Mdot
.3482 .43838 Mdot
.48925 .23803 Mdot
.46451 .68568 Mdot
.32869 .61649 Mdot
.68539 .64185 Mdot
.2734 .52712 Mdot
.35967 .46052 Mdot
.73123 .51572 Mdot
.48679 .73896 Mdot
.49623 .25643 Mdot
.68981 .64797 Mdot
.49633 .26615 Mdot
.54349 .34295 Mdot
.41021 .66775 Mdot
.54284 .34411 Mdot
.30246 .60899 Mdot
.61474 .63661 Mdot
.5263 .7482 Mdot
.73519 .40213 Mdot
.58625 .34346 Mdot
.68247 .49314 Mdot
.23591 .44135 Mdot
.42935 .66702 Mdot
.69644 .634 Mdot
.73212 .42324 Mdot
.63049 .61278 Mdot
.26616 .54343 Mdot
.65188 .62302 Mdot
.34185 .43714 Mdot
.46785 .70919 Mdot
.60158 .63854 Mdot
.76178 .38043 Mdot
.24171 .52514 Mdot
.55012 .36488 Mdot
.36354 .41818 Mdot
.55945 .75471 Mdot
.70356 .62851 Mdot
.43137 .68103 Mdot
.70988 .64987 Mdot
.35619 .47538 Mdot
.57374 .34809 Mdot
.33666 .47756 Mdot
.66916 .64937 Mdot
.71387 .64439 Mdot
.75292 .40209 Mdot
.35034 .44539 Mdot
.49145 .26133 Mdot
.68886 .43314 Mdot
.70639 .50734 Mdot
.71086 .43897 Mdot
.44424 .6937 Mdot
.59013 .36754 Mdot
.56746 .34486 Mdot
.28421 .37983 Mdot
.64845 .62785 Mdot
.5482 .34861 Mdot
.3728 .41406 Mdot
.33834 .37714 Mdot
.4712 .70944 Mdot
.69368 .47481 Mdot
.3515 .47529 Mdot
.30584 .63126 Mdot
.55583 .35655 Mdot
.69191 .46073 Mdot
.41814 .66842 Mdot
.7298 .44978 Mdot
.37067 .45119 Mdot
.30568 .62258 Mdot
.45833 .68476 Mdot
.52313 .70666 Mdot
.36961 .5027 Mdot
.34944 .43038 Mdot
.65681 .63451 Mdot
.50955 .6725 Mdot
.30261 .50601 Mdot
.42004 .54252 Mdot
.5869 .35314 Mdot
.60004 .56415 Mdot
.46723 .6371 Mdot
.34631 .61886 Mdot
.50261 .59326 Mdot
.27401 .57079 Mdot
.54552 .62314 Mdot
.6524 .42618 Mdot
.46696 .57384 Mdot
.75708 .3477 Mdot
.67695 .55437 Mdot
.30108 .58794 Mdot
.41109 .23427 Mdot
.68507 .61427 Mdot
.51308 .63764 Mdot
.68816 .56682 Mdot
.60279 .45027 Mdot
.73132 .40503 Mdot
.71551 .4166 Mdot
.64668 .4116 Mdot
.35337 .39546 Mdot
.53655 .65852 Mdot
.31308 .56262 Mdot
.64293 .60007 Mdot
.65907 .50439 Mdot
.31928 .63943 Mdot
.44333 .28366 Mdot
.62335 .57418 Mdot
.46906 .35815 Mdot
.36606 .62575 Mdot
.62757 .45234 Mdot
.30876 .5576 Mdot
.44578 .36956 Mdot
.35235 .635 Mdot
.55509 .59088 Mdot
.59936 .5926 Mdot
.39306 .61677 Mdot
.63624 .567 Mdot
.68318 .45172 Mdot
.46825 .68701 Mdot
.70191 .5916 Mdot
.47145 .32983 Mdot
.66229 .57443 Mdot
.50172 .59414 Mdot
.53893 .32326 Mdot
.60172 .55772 Mdot
.38442 .41626 Mdot
.49213 .75342 Mdot
.63979 .49275 Mdot
.65114 .47753 Mdot
.4116 .6239 Mdot
.66856 .52934 Mdot
.24493 .43503 Mdot
.5171 .64107 Mdot
.47478 .64322 Mdot
.6074 .44645 Mdot
.61896 .40023 Mdot
.50069 .75217 Mdot
.41772 .2832 Mdot
.55517 .43903 Mdot
.34869 .52591 Mdot
.65043 .52257 Mdot
.39497 .63632 Mdot
.39885 .67562 Mdot
.4578 .71241 Mdot
.72884 .38193 Mdot
.48317 .32042 Mdot
.66445 .40763 Mdot
.56722 .43898 Mdot
.66243 .56711 Mdot
.29018 .4465 Mdot
.57596 .615 Mdot
.67776 .39167 Mdot
.50119 .6856 Mdot
.42766 .24062 Mdot
.55382 .51991 Mdot
.45761 .27259 Mdot
.44286 .63196 Mdot
.61037 .45684 Mdot
.42596 .59043 Mdot
.61953 .53987 Mdot
.2557 .39723 Mdot
.46128 .29488 Mdot
.53864 .65725 Mdot
.5737 .40862 Mdot
.68203 .61152 Mdot
.47729 .65979 Mdot
.65105 .4918 Mdot
.59799 .3851 Mdot
.46845 .44522 Mdot
.44804 .25728 Mdot
.51158 .58757 Mdot
.43737 .31863 Mdot
.62922 .44914 Mdot
.71357 .5925 Mdot
.69799 .51427 Mdot
.59184 .62447 Mdot
.47937 .35154 Mdot
.46261 .70018 Mdot
.74722 .36833 Mdot
.4913 .61531 Mdot
.5732 .65601 Mdot
.4459 .25922 Mdot
.72457 .39056 Mdot
.60703 .52592 Mdot
.61621 .42604 Mdot
.59874 .58815 Mdot
.5659 .62186 Mdot
.67319 .61958 Mdot
.54884 .37331 Mdot
.54682 .70002 Mdot
.46331 .34893 Mdot
.70355 .40391 Mdot
.42362 .21818 Mdot
.37706 .49185 Mdot
.47572 .38874 Mdot
.42637 .6448 Mdot
.50302 .50573 Mdot
.65667 .60679 Mdot
.45535 .25794 Mdot
.32356 .64116 Mdot
.51308 .68604 Mdot
.64951 .40945 Mdot
.32485 .46173 Mdot
.57931 .68424 Mdot
.69543 .57294 Mdot
.72582 .45881 Mdot
.46035 .64492 Mdot
.48653 .30855 Mdot
.29309 .39916 Mdot
.43333 .50363 Mdot
.66777 .5206 Mdot
.34507 .51988 Mdot
.44904 .49893 Mdot
.71432 .3437 Mdot
.57122 .67707 Mdot
.46177 .45728 Mdot
.44051 .65035 Mdot
.67512 .39038 Mdot
.65612 .41933 Mdot
.52543 .6722 Mdot
.53056 .25735 Mdot
.44442 .32163 Mdot
.45898 .50384 Mdot
.60628 .54502 Mdot
.29881 .57773 Mdot
.32455 .55443 Mdot
.63211 .43816 Mdot
.50716 .42048 Mdot
.53941 .39124 Mdot
.69352 .56859 Mdot
.43778 .69491 Mdot
.49136 .38726 Mdot
.38449 .57845 Mdot
.50009 .6953 Mdot
.49823 .44654 Mdot
.58997 .637 Mdot
.48718 .43097 Mdot
.44323 .27458 Mdot
.72129 .42077 Mdot
.68292 .3934 Mdot
.66818 .57141 Mdot
.65498 .49516 Mdot
.56013 .65535 Mdot
.56289 .65691 Mdot
.49929 .36642 Mdot
.69269 .60769 Mdot
.61541 .47897 Mdot
.46552 .7175 Mdot
.5189 .62546 Mdot
.37034 .60721 Mdot
.30208 .46218 Mdot
.41461 .567 Mdot
.4956 .28798 Mdot
.44762 .39845 Mdot
.46112 .64722 Mdot
.53715 .26634 Mdot
.31247 .45653 Mdot
.30221 .5516 Mdot
.54872 .36683 Mdot
.29627 .41854 Mdot
.26399 .38307 Mdot
.57692 .53505 Mdot
.70278 .39145 Mdot
.44784 .52556 Mdot
.30138 .414 Mdot
.65292 .60274 Mdot
.35084 .62361 Mdot
.45473 .25966 Mdot
.51656 .34866 Mdot
.50003 .65127 Mdot
.5386 .68284 Mdot
.74475 .63067 Mdot
.69043 .63259 Mdot
.72695 .33898 Mdot
.66852 .571 Mdot
.36727 .66241 Mdot
.73588 .41692 Mdot
.60397 .487 Mdot
.41371 .5943 Mdot
.29525 .5658 Mdot
.45628 .3008 Mdot
.58365 .55117 Mdot
.48718 .21855 Mdot
.45173 .61489 Mdot
.43006 .52619 Mdot
.43839 .29757 Mdot
.42435 .27148 Mdot
.42358 .28604 Mdot
.70125 .59654 Mdot
.44551 .3894 Mdot
.44128 .25044 Mdot
.34886 .37101 Mdot
.56229 .47348 Mdot
.34191 .61179 Mdot
.3246 .53138 Mdot
.73571 .35742 Mdot
.55793 .43052 Mdot
.56701 .61379 Mdot
.41203 .62446 Mdot
.44898 .23232 Mdot
.27593 .37469 Mdot
.63398 .55272 Mdot
.46246 .36163 Mdot
.58622 .41314 Mdot
.47355 .37677 Mdot
.51146 .37408 Mdot
.53187 .58855 Mdot
.69447 .57277 Mdot
.45887 .19384 Mdot
.65922 .38956 Mdot
.64919 .59001 Mdot
.48236 .673 Mdot
.74217 .3611 Mdot
.56328 .68275 Mdot
.59604 .60968 Mdot
.44061 .62365 Mdot
.34479 .5634 Mdot
.45715 .54845 Mdot
.56147 .59177 Mdot
.45061 .4371 Mdot
.53708 .41242 Mdot
.72132 .42461 Mdot
.69036 .36784 Mdot
.45363 .53915 Mdot
.55568 .46925 Mdot
.30956 .4023 Mdot
.73148 .39219 Mdot
.55172 .56009 Mdot
.30182 .48916 Mdot
.44883 .52238 Mdot
.51503 .64972 Mdot
.57678 .68164 Mdot
.36699 .57354 Mdot
.37173 .48434 Mdot
.46987 .3221 Mdot
.74332 .33459 Mdot
.50846 .36647 Mdot
.53582 .66768 Mdot
.72049 .5867 Mdot
.66806 .5574 Mdot
.31796 .41849 Mdot
.29337 .53823 Mdot
.51708 .55835 Mdot
.26955 .56319 Mdot
.61439 .62106 Mdot
.40164 .67812 Mdot
.55342 .65677 Mdot
.33972 .38494 Mdot
.42816 .57547 Mdot
.54684 .64313 Mdot
.31824 .47033 Mdot
.44517 .64988 Mdot
.5465 .72445 Mdot
.67325 .38739 Mdot
.71963 .42194 Mdot
.52511 .25213 Mdot
.54922 .4478 Mdot
.52042 .28604 Mdot
.57048 .39526 Mdot
.60252 .53599 Mdot
.37118 .62409 Mdot
.72662 .58818 Mdot
.52177 .39 Mdot
.76028 .35887 Mdot
.51396 .37453 Mdot
.66287 .41364 Mdot
.65159 .52848 Mdot
.27788 .41674 Mdot
.63106 .58535 Mdot
.68438 .55607 Mdot
.2605 .41238 Mdot
.68341 .41401 Mdot
.61738 .55233 Mdot
.49305 .75505 Mdot
.37875 .4683 Mdot
.27313 .38853 Mdot
.44169 .36906 Mdot
.28045 .42909 Mdot
.39906 .54543 Mdot
.40827 .64918 Mdot
.43931 .37597 Mdot
.64007 .55569 Mdot
.34247 .62275 Mdot
.53528 .68446 Mdot
.59633 .63046 Mdot
.47465 .66789 Mdot
.74565 .38047 Mdot
.73567 .61075 Mdot
.55267 .63821 Mdot
.31363 .43648 Mdot
.45126 .34643 Mdot
.32136 .42161 Mdot
.54482 .68746 Mdot
.35463 .55649 Mdot
.57873 .66748 Mdot
.42227 .62525 Mdot
.56897 .5043 Mdot
.58355 .63774 Mdot
.46515 .61337 Mdot
.45489 .65311 Mdot
.28834 .61264 Mdot
.49572 .33974 Mdot
.44426 .44346 Mdot
.54635 .59883 Mdot
.36373 .51273 Mdot
.4899 .51024 Mdot
.49946 .61768 Mdot
.32028 .38785 Mdot
.52884 .61148 Mdot
.41714 .29439 Mdot
.43959 .70441 Mdot
.58476 .58673 Mdot
.51533 .41566 Mdot
.33706 .39108 Mdot
.36573 .62422 Mdot
.48067 .66065 Mdot
.69261 .56875 Mdot
.44389 .42354 Mdot
.48708 .32041 Mdot
.54517 .50495 Mdot
.3032 .40887 Mdot
.47152 .47968 Mdot
.44519 .41797 Mdot
.55678 .3785 Mdot
.50661 .37167 Mdot
.60427 .56443 Mdot
.40704 .23371 Mdot
.66912 .42887 Mdot
.40928 .56213 Mdot
.42535 .59318 Mdot
.68338 .38383 Mdot
.45649 .59834 Mdot
.47303 .58669 Mdot
.46344 .51727 Mdot
.72048 .36962 Mdot
.58028 .56806 Mdot
.62704 .55822 Mdot
.54751 .72243 Mdot
.43599 .26613 Mdot
.55796 .61616 Mdot
.59065 .61679 Mdot
.52901 .41768 Mdot
.33477 .44573 Mdot
.40083 .56725 Mdot
.57136 .71817 Mdot
.50543 .46789 Mdot
.5621 .63488 Mdot
.75623 .34261 Mdot
.58984 .54689 Mdot
.44625 .53284 Mdot
.41007 .22743 Mdot
.41032 .21585 Mdot
.3806 .59471 Mdot
.45562 .2413 Mdot
.64033 .55364 Mdot
.55076 .68511 Mdot
.63623 .57143 Mdot
.29136 .46101 Mdot
.43725 .69708 Mdot
.50336 .33168 Mdot
.74325 .63763 Mdot
.65629 .60247 Mdot
.42977 .60954 Mdot
.47402 .29721 Mdot
.55447 .47932 Mdot
.61199 .49239 Mdot
.71229 .58061 Mdot
.72547 .40649 Mdot
.71612 .38617 Mdot
.37713 .55974 Mdot
.6398 .46117 Mdot
.63239 .39763 Mdot
.56732 .67156 Mdot
.75566 .35638 Mdot
.59422 .40436 Mdot
.35589 .64561 Mdot
.67561 .39197 Mdot
.54438 .71225 Mdot
.64898 .48274 Mdot
.49666 .61322 Mdot
.59789 .54098 Mdot
.50698 .44325 Mdot
.54998 .69609 Mdot
.69528 .58892 Mdot
.58109 .4998 Mdot
.23686 .43041 Mdot
.48056 .66666 Mdot
.50782 .68964 Mdot
.32356 .56835 Mdot
.6009 .51986 Mdot
.41179 .27087 Mdot
.66503 .65736 Mdot
.26075 .43067 Mdot
.49189 .75372 Mdot
.32674 .36312 Mdot
.61382 .48248 Mdot
.24321 .54243 Mdot
.49407 .34139 Mdot
.61682 .48352 Mdot
.41861 .26687 Mdot
.77178 .36294 Mdot
.43607 .35396 Mdot
.58004 .60553 Mdot
.56145 .3911 Mdot
.73045 .35676 Mdot
.72635 .34802 Mdot
.41877 .24843 Mdot
.64056 .39309 Mdot
.25542 .41122 Mdot
.58404 .51285 Mdot
.29578 .46401 Mdot
.32365 .43506 Mdot
.68193 .38067 Mdot
.37725 .65042 Mdot
.4558 .37104 Mdot
.48155 .63034 Mdot
.70107 .40909 Mdot
.44169 .37999 Mdot
.32861 .3669 Mdot
.4939 .47488 Mdot
.61824 .43541 Mdot
.6893 .51327 Mdot
.44123 .20621 Mdot
.52894 .67514 Mdot
.49578 .38437 Mdot
.51682 .68458 Mdot
.47027 .66976 Mdot
.64922 .43245 Mdot
.47266 .63456 Mdot
.47278 .19809 Mdot
.63679 .50353 Mdot
.52152 .34345 Mdot
.61904 .54604 Mdot
.56136 .74403 Mdot
.32647 .47597 Mdot
.49779 .36093 Mdot
.49811 .39071 Mdot
.41483 .24275 Mdot
.45789 .38303 Mdot
.45864 .40672 Mdot
.41395 .28315 Mdot
.50134 .64379 Mdot
.27615 .43399 Mdot
.43797 .28953 Mdot
.38488 .61315 Mdot
.48294 .32167 Mdot
.66243 .62463 Mdot
.6002 .45587 Mdot
.56261 .71922 Mdot
.2931 .43287 Mdot
.28915 .4364 Mdot
.53022 .39437 Mdot
.67927 .61188 Mdot
.43683 .55284 Mdot
.45876 .50666 Mdot
.65339 .49379 Mdot
.28976 .46005 Mdot
.53347 .5978 Mdot
.42533 .21192 Mdot
.37309 .48482 Mdot
.64588 .36688 Mdot
.69098 .39263 Mdot
.62857 .585 Mdot
.59483 .52794 Mdot
.55874 .72335 Mdot
.38532 .54746 Mdot
.29232 .38657 Mdot
.43787 .27056 Mdot
.59425 .52649 Mdot
.29715 .5481 Mdot
.38617 .52534 Mdot
.58258 .62682 Mdot
.67738 .59254 Mdot
.511 .59648 Mdot
.58615 .45172 Mdot
.38312 .46808 Mdot
.66088 .40719 Mdot
.75945 .34546 Mdot
.41216 .26787 Mdot
.67954 .58895 Mdot
.2903 .42983 Mdot
.46212 .47729 Mdot
.58191 .42383 Mdot
.4234 .21063 Mdot
.72931 .40648 Mdot
.46067 .64755 Mdot
.68506 .41123 Mdot
.67983 .60479 Mdot
.60838 .4847 Mdot
.27334 .42379 Mdot
.41836 .28662 Mdot
.41261 .60044 Mdot
.5623 .52097 Mdot
.48207 .46541 Mdot
.25199 .55159 Mdot
.53986 .65433 Mdot
.34705 .56667 Mdot
.70086 .61782 Mdot
.4136 .24584 Mdot
.6352 .42172 Mdot
.44452 .45939 Mdot
.41175 .23794 Mdot
.40454 .65121 Mdot
.55373 .66248 Mdot
.71129 .5928 Mdot
.30389 .41587 Mdot
.69373 .51812 Mdot
.38253 .44112 Mdot
.24114 .41651 Mdot
.46655 .6094 Mdot
.49445 .401 Mdot
.48725 .20559 Mdot
.46798 .66004 Mdot
.64024 .41201 Mdot
.46163 .65999 Mdot
.74849 .34415 Mdot
.52982 .58433 Mdot
.46617 .63928 Mdot
.37102 .5438 Mdot
.6493 .52922 Mdot
.50547 .64434 Mdot
.46828 .35933 Mdot
.32958 .532 Mdot
.45304 .63017 Mdot
.45337 .63452 Mdot
.40075 .5887 Mdot
.61878 .60501 Mdot
.46044 .34099 Mdot
.71362 .39521 Mdot
.52817 .24445 Mdot
.38232 .61372 Mdot
.29368 .44723 Mdot
.60259 .54168 Mdot
.47705 .37264 Mdot
.75512 .40763 Mdot
.46127 .19781 Mdot
.33669 .58895 Mdot
.57805 .67701 Mdot
.52554 .54982 Mdot
.29717 .52843 Mdot
.28684 .44565 Mdot
.66024 .53278 Mdot
.60464 .52884 Mdot
.427 .54316 Mdot
.43936 .65826 Mdot
.58583 .67349 Mdot
.48535 .27624 Mdot
.53394 .25852 Mdot
.65984 .58306 Mdot
.36058 .58277 Mdot
.69488 .3858 Mdot
.54372 .75928 Mdot
.53704 .28098 Mdot
.63658 .53017 Mdot
.34608 .38744 Mdot
.3151 .5351 Mdot
.45156 .19428 Mdot
.44317 .3507 Mdot
.43353 .65887 Mdot
.55905 .67214 Mdot
.64107 .48864 Mdot
.51867 .38997 Mdot
.5668 .54051 Mdot
.67632 .38116 Mdot
.47153 .43363 Mdot
.4988 .37639 Mdot
.46035 .62736 Mdot
.50281 .58011 Mdot
.68444 .4034 Mdot
.54285 .38168 Mdot
.71216 .40404 Mdot
.40177 .53434 Mdot
.56234 .44042 Mdot
.70689 .41452 Mdot
.49737 .46315 Mdot
.64672 .54869 Mdot
.34354 .62518 Mdot
.51484 .56306 Mdot
.72021 .36732 Mdot
.45548 .67111 Mdot
.60049 .43735 Mdot
.49301 .65176 Mdot
.65751 .60138 Mdot
.46192 .35003 Mdot
.55073 .67169 Mdot
.70835 .39854 Mdot
.29553 .45676 Mdot
.56475 .41407 Mdot
.36505 .61658 Mdot
.35521 .52564 Mdot
.54125 .32608 Mdot
.4404 .49138 Mdot
.59996 .38945 Mdot
.2819 .37576 Mdot
.31537 .4687 Mdot
.46069 .30151 Mdot
.26598 .38605 Mdot
.51054 .44456 Mdot
.61286 .45856 Mdot
.46904 .72321 Mdot
.45189 .25883 Mdot
.28887 .39231 Mdot
.55029 .70292 Mdot
.71261 .38657 Mdot
.63541 .37793 Mdot
.41071 .23747 Mdot
.6797 .60873 Mdot
.52498 .44158 Mdot
.76044 .35413 Mdot
.55035 .50447 Mdot
.63197 .39342 Mdot
.61879 .54594 Mdot
.47174 .67643 Mdot
.44358 .26675 Mdot
.61632 .46919 Mdot
.50623 .44873 Mdot
.30149 .50195 Mdot
.42447 .62466 Mdot
.27115 .39824 Mdot
.30254 .44082 Mdot
.682 .45229 Mdot
.30263 .54027 Mdot
.63276 .44524 Mdot
.38821 .59882 Mdot
.68886 .38762 Mdot
.67679 .374 Mdot
.5678 .42962 Mdot
.68048 .54558 Mdot
.4079 .24371 Mdot
.45889 .40055 Mdot
.33367 .6002 Mdot
.45495 .65498 Mdot
.48455 .20556 Mdot
.6474 .39119 Mdot
.44399 .4202 Mdot
.3155 .55042 Mdot
.46994 .44114 Mdot
.50208 .33629 Mdot
.50182 .49323 Mdot
.66283 .65768 Mdot
.3863 .60794 Mdot
.54836 .7005 Mdot
.4997 .66272 Mdot
.69452 .621 Mdot
.71791 .36667 Mdot
.5523 .63762 Mdot
.50173 .58937 Mdot
.49824 .43597 Mdot
.68635 .3645 Mdot
.66296 .59278 Mdot
.60139 .62827 Mdot
.37277 .62749 Mdot
.41207 .26088 Mdot
.48591 .67957 Mdot
.50036 .61105 Mdot
.55541 .58042 Mdot
.32992 .40831 Mdot
.67429 .62055 Mdot
.54775 .66351 Mdot
.43833 .64053 Mdot
.42742 .30873 Mdot
.56542 .59695 Mdot
.54931 .38405 Mdot
.66526 .42651 Mdot
.54167 .58136 Mdot
.6806 .37517 Mdot
.45708 .71348 Mdot
.42518 .29293 Mdot
.30703 .40757 Mdot
.604 .39144 Mdot
.37724 .46439 Mdot
.45809 .61504 Mdot
.50773 .37122 Mdot
.56484 .53964 Mdot
.58728 .64882 Mdot
.48411 .65592 Mdot
.73765 .37401 Mdot
.5349 .29383 Mdot
.72517 .58524 Mdot
.61526 .44395 Mdot
.30387 .55427 Mdot
.29762 .5565 Mdot
.61436 .60052 Mdot
.60708 .54721 Mdot
.45675 .58847 Mdot
.58334 .45044 Mdot
.36642 .5993 Mdot
.52198 .3546 Mdot
.43882 .20525 Mdot
.39857 .64059 Mdot
.75976 .36851 Mdot
.38035 .63263 Mdot
.40558 .63419 Mdot
.63355 .41344 Mdot
.58111 .59694 Mdot
.51882 .42885 Mdot
.51198 .41008 Mdot
.52925 .72801 Mdot
.43639 .19841 Mdot
.56133 .63675 Mdot
.59092 .43739 Mdot
.64687 .49551 Mdot
.50762 .6245 Mdot
.71634 .52513 Mdot
.67763 .56333 Mdot
.74288 .36886 Mdot
.6779 .39148 Mdot
.67397 .55281 Mdot
.63243 .55585 Mdot
.57946 .64517 Mdot
.43748 .29956 Mdot
.61532 .45531 Mdot
.47056 .35512 Mdot
.70393 .61167 Mdot
.37729 .57183 Mdot
.26134 .38733 Mdot
.29291 .39791 Mdot
.33883 .52978 Mdot
.45329 .46397 Mdot
.43021 .32353 Mdot
.57023 .3815 Mdot
.53109 .25203 Mdot
.64703 .48339 Mdot
.42573 .2049 Mdot
.50672 .6407 Mdot
.53635 .32581 Mdot
.5299 .41276 Mdot
.56409 .59629 Mdot
.25718 .4296 Mdot
.4603 .51386 Mdot
.56933 .39811 Mdot
.58418 .6278 Mdot
.51181 .66785 Mdot
.49334 .3272 Mdot
.37583 .46553 Mdot
.2615 .56646 Mdot
.65498 .60886 Mdot
.69978 .52012 Mdot
.49341 .66217 Mdot
.44653 .2064 Mdot
.60107 .6312 Mdot
.71049 .57239 Mdot
.62175 .59447 Mdot
.50096 .38493 Mdot
.72712 .60565 Mdot
.61993 .60918 Mdot
.76636 .34672 Mdot
.58349 .67797 Mdot
.44691 .46178 Mdot
.51476 .69553 Mdot
.28001 .37668 Mdot
.43287 .50905 Mdot
.54561 .36878 Mdot
.48524 .33509 Mdot
.28249 .44458 Mdot
.60146 .44703 Mdot
.42555 .31813 Mdot
.68436 .40646 Mdot
.67199 .42475 Mdot
.65792 .61249 Mdot
.43154 .61681 Mdot
.73823 .6097 Mdot
.64902 .50899 Mdot
.35267 .60956 Mdot
.43452 .3486 Mdot
.4533 .43827 Mdot
.56364 .53415 Mdot
.45984 .49764 Mdot
.44524 .29343 Mdot
.70366 .36752 Mdot
.71147 .51777 Mdot
.71875 .49663 Mdot
.30786 .39183 Mdot
.56406 .42503 Mdot
.44054 .56045 Mdot
.4403 .35771 Mdot
.65428 .53296 Mdot
.61616 .46709 Mdot
.6929 .39842 Mdot
.45813 .61524 Mdot
.37804 .49068 Mdot
.41488 .25531 Mdot
.32772 .5384 Mdot
.73813 .38749 Mdot
.70162 .59935 Mdot
.64854 .48724 Mdot
.42735 .20723 Mdot
.44483 .5866 Mdot
.3173 .49598 Mdot
.40592 .23752 Mdot
.45965 .27854 Mdot
.57909 .64322 Mdot
.32769 .4458 Mdot
.76923 .34923 Mdot
.66999 .53965 Mdot
.52367 .39926 Mdot
.40017 .67744 Mdot
.65921 .44377 Mdot
.30496 .47903 Mdot
.44302 .41216 Mdot
.59036 .44465 Mdot
.41309 .65302 Mdot
.43853 .62218 Mdot
.62694 .43972 Mdot
.67918 .41579 Mdot
.35574 .59053 Mdot
.44018 .70492 Mdot
.39671 .54121 Mdot
.46871 .68633 Mdot
.48893 .34289 Mdot
.46463 .20463 Mdot
.36892 .63805 Mdot
.43111 .30244 Mdot
.24709 .558 Mdot
.48514 .62093 Mdot
.37291 .63127 Mdot
.28284 .41909 Mdot
.63109 .43865 Mdot
.41882 .21052 Mdot
.37018 .59295 Mdot
.45821 .20395 Mdot
.5071 .32787 Mdot
.44449 .66718 Mdot
.39172 .58537 Mdot
.29784 .44014 Mdot
.54985 .61844 Mdot
.58517 .6041 Mdot
.6546 .4989 Mdot
.63661 .39167 Mdot
.62887 .50129 Mdot
.36687 .47987 Mdot
.451 .50413 Mdot
.49313 .36218 Mdot
.60827 .48291 Mdot
.49039 .35741 Mdot
.41743 .52691 Mdot
.3836 .44967 Mdot
.40539 .22802 Mdot
.54961 .68647 Mdot
.30818 .45482 Mdot
.54735 .29083 Mdot
.5366 .32531 Mdot
.23989 .53943 Mdot
.62098 .61767 Mdot
.33366 .38687 Mdot
.653 .45452 Mdot
.48242 .33784 Mdot
.38249 .63099 Mdot
.29326 .44173 Mdot
.68661 .54916 Mdot
.38222 .4668 Mdot
.30114 .4817 Mdot
.64976 .61598 Mdot
.6441 .45433 Mdot
.73203 .49123 Mdot
.65125 .60116 Mdot
.52437 .6436 Mdot
.23374 .43229 Mdot
.53757 .34679 Mdot
.63901 .43705 Mdot
.61273 .60017 Mdot
.65833 .60997 Mdot
.70864 .39962 Mdot
.45842 .41323 Mdot
.68321 .59956 Mdot
.62461 .39403 Mdot
.27566 .4316 Mdot
.45836 .48953 Mdot
.56837 .6218 Mdot
.35205 .56057 Mdot
.44834 .31282 Mdot
.52739 .27502 Mdot
.55759 .37507 Mdot
.35333 .54958 Mdot
.45957 .30593 Mdot
.60745 .62784 Mdot
.73898 .3311 Mdot
.58401 .59244 Mdot
.49026 .64929 Mdot
.35139 .5419 Mdot
.58949 .53188 Mdot
.32986 .63999 Mdot
.3273 .44715 Mdot
.36541 .52922 Mdot
.70746 .57161 Mdot
.59828 .53134 Mdot
.51729 .6346 Mdot
.53254 .62244 Mdot
.45246 .38236 Mdot
.33076 .63704 Mdot
.35277 .47754 Mdot
.57641 .38679 Mdot
.24677 .40396 Mdot
.55505 .37813 Mdot
.53609 .42445 Mdot
.69669 .56839 Mdot
.64088 .44046 Mdot
.66833 .42901 Mdot
.46909 .4002 Mdot
.44485 .28402 Mdot
.34527 .62204 Mdot
.44163 .35144 Mdot
.48161 .50047 Mdot
.69158 .58833 Mdot
.32281 .54065 Mdot
.41829 .21624 Mdot
.44083 .51109 Mdot
.47469 .27103 Mdot
.51603 .34472 Mdot
.47879 .36559 Mdot
.6682 .55601 Mdot
.55301 .72666 Mdot
.64781 .48114 Mdot
.31746 .42349 Mdot
.51133 .67263 Mdot
.52108 .24512 Mdot
.52505 .38808 Mdot
.58623 .47155 Mdot
.57403 .6144 Mdot
.34783 .57093 Mdot
.32964 .4179 Mdot
.67417 .47041 Mdot
.35483 .55668 Mdot
.45537 .46081 Mdot
.42975 .32473 Mdot
.33006 .59686 Mdot
.50625 .53981 Mdot
.44556 .50032 Mdot
.41561 .24547 Mdot
.67276 .4775 Mdot
.29638 .54702 Mdot
.35492 .63176 Mdot
.70615 .57753 Mdot
.62941 .38329 Mdot
.41149 .26675 Mdot
.68506 .55596 Mdot
.58303 .4495 Mdot
.57735 .71367 Mdot
.45555 .48545 Mdot
.43469 .64303 Mdot
.64968 .58748 Mdot
.60557 .36834 Mdot
.47504 .46841 Mdot
.41814 .19876 Mdot
.50624 .37897 Mdot
.5159 .43027 Mdot
.35769 .62133 Mdot
.69263 .39607 Mdot
.28861 .56678 Mdot
.68867 .60324 Mdot
.49397 .34374 Mdot
.68661 .54642 Mdot
.76523 .35246 Mdot
.54396 .58973 Mdot
.46102 .71611 Mdot
.55914 .42474 Mdot
.51986 .67854 Mdot
.59241 .51153 Mdot
.43726 .70411 Mdot
.53402 .68371 Mdot
.44579 .36952 Mdot
.57339 .56737 Mdot
.53969 .74393 Mdot
.37913 .60142 Mdot
.53087 .55705 Mdot
.5916 .58632 Mdot
.5013 .61065 Mdot
.50866 .58954 Mdot
.65822 .59468 Mdot
.52038 .54261 Mdot
.55261 .68866 Mdot
.64584 .57328 Mdot
.41833 .51854 Mdot
.62892 .43138 Mdot
.47594 .39201 Mdot
.73557 .4188 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo08cooooo0ol0002jooooo`0000Koooooonk^k_lb
<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0Q_ooool:
o`000003ooooool0003o00000;Kooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ
8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`24ooooo`So0000
0_ooool7o`000003ooooool0003o00000;7ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oo
oooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`23ooooo`Co00000ooo
ool2o`0000?ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o0000/Oooool00003ooooool0
003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06ooooo`?o0000Pooo
ool3o`0000Cooooo0_l00006ooooo`;o00000_ooool2o`000004ooooool0003o0000o`000:gooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Ooo
ool00ol0003oooooooooo`22ooooo`;o00000oooool2o`0000;ooooo0ol00003ooooo`Co00001?oo
ool4o`000:cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`22ooooo`;o00000oooool2o`0000;ooooo1?l00002
ooooo`Co00001Oooool4o`000:_ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go
0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo08;ooooo1ol00004ooooo`;o0000
0_ooool4o`0000Oooooo0_l0002[ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`24ooooo`Co00002Oooool8o`00
00Kooooo0_l0002Xooooo`007?ooool00ol0003oooooooooo`22ooooo`Ko00002oooool8o`0000Co
oooo0_l0002Xooooo`007?ooool00ol0003oooooooooo`22ooooo`Ko00001Oooool2o`0000Oooooo
1_l0002]ooooo`007?ooool00ol0003oooooooooo`2=ooooo`Co00001Oooool7o`000:cooooo000L
ooooo`03o`000?oooooooooo087ooooo0_l0000<ooooo`;o00001?ooool:o`000:[ooooo000Loooo
o`03o`000?oooooooooo083ooooo0ol0000Booooo`[o0000Z_ooool001cooooo00?o0000oooooooo
ool0P?ooool2o`0000cooooo0_l00004ooooo`_o000000?oooooo`000?l00000Yoooool001cooooo
00?o0000ooooooooool0P?ooool4o`0000[ooooo0_l00004ooooo`ko0000Yoooool001cooooo00?o
0000ooooooooool0P?ooool4o`00017ooooo3Ol0002Wooooo`007?ooool00ol0003oooooooooo`20
ooooo`Go00000_ooool2o`0000Oooooo0_l00003ooooo`ko0000Y_ooool001cooooo00?o0000oooo
ooooool0POooool4o`0000;ooooo0_l00007ooooo`;o00000ooooolBo`000003ooooool0003o0000
09oooooo000Looooo`03o`000?oooooooooo087ooooo1Ol0000?oooooa;o000000?oooooo`000?l0
0000Woooool001cooooo0_l00025ooooo`;o00001_ooool2o`0000Kooooo1Ol000000ooooooo0000
o`000009o`0000;ooooo1?l0002Nooooo`007?ooool00ol0003oooooooooo`23ooooo`;o00001ooo
ool2o`0000Kooooo4_l000000ooooooo0000o`000002o`0009kooooo000Looooo`03o`000?oooooo
oooo08?ooooo0_l00009ooooo`Co00001?oooolAo`0000;ooooo0ol0002Mooooo`007?ooool00ol0
003oooooooooo`22ooooo`;o00002Oooool5o`0000Kooooo3ol00002ooooo`?o0000WOooool001co
oooo00?o0000ooooooooool0P_ooool2o`0000Wooooo1Ol00006ooooo`oo00001?ooool2o`0009co
oooo000Looooo`03o`000?oooooooooo08;ooooo1?l00004ooooo`Co00001Oooool2o`0000?ooooo
4?l00003ooooo`;o0000W?ooool001cooooo00?o0000ooooooooool0P_ooool4o`0000Cooooo1?l0
0005ooooo`Co00000oooool>o`0000?ooooo0ol0002Kooooo`007?ooool00ol0003oooooooooo`22
ooooo`;o00000_ooool2o`0000;ooooo0_l00005oooooaOo00001?ooool2o`0009_ooooo000Loooo
o`03o`000?oooooooooo08Kooooo0_l00004ooooo`;o00000ooooolIo`0000;ooooo0ol0002Joooo
o`007?ooool00ol0003oooooooooo`2<ooooo`;o00001?oooolHo`0000?ooooo0_l0002Jooooo`00
7?ooool00ol0003oooooooooo`23ooooo`?o00003?ooool5o`000003ooooool0003o000000go0000
1?ooool4o`0009[ooooo000Looooo`03o`000?oooooooooo08?ooooo1Ol00004ooooo`?o00001Ooo
ool3o`0000;ooooo3_l00004ooooo`Co0000V_ooool001cooooo00?o0000ooooooooool0Q?ooool4
o`0000Cooooo0ol00006ooooo`;o00000_ooool>o`000:;ooooo000Looooo`03o`000?oooooooooo
08Cooooo0_l00005ooooo`;o00002?ooool2o`0000Cooooo2ol00008ooooo`;o0000VOooool001co
oooo00?o0000ooooooooool0Q?ooool4o`0000?ooooo1?l00003ooooo`;o000000?oooooo`000?l0
00001Oooool:o`0000Cooooo0_l00002ooooo`;o0000VOooool001cooooo00?o0000ooooooooool0
Q?ooool4o`0000?ooooo1?l00003ooooo`;o00000_ooool2o`0000Gooooo2_l00003ooooo`;o0000
1Oooool2o`0009Kooooo000Looooo`;o0000Roooool3o`0000?ooooo1?l00002ooooo`;o00001_oo
ool=o`0000Cooooo1?l0002Fooooo`007?ooool00ol0003oooooooooo`28ooooo`Co00001?ooool4
o`0000Gooooo0ol00004ooooo`Go000000?oooooo`000?l000002_l000000ooooooo0000o`00002D
ooooo`007?ooool00ol0003oooooooooo`28ooooo`;o00002?ooool2o`0000Gooooo1?l00003oooo
o`Ko000000?oooooo`000?l000001_l00004ooooo`;o0000U?ooool001cooooo00?o0000oooooooo
ool0Qoooool2o`0000Wooooo0_l00006ooooo`Ko00001?ooool2o`000003ooooool0003o000000So
000000Coooooo`000?l0003o0000U?ooool001cooooo00?o0000ooooooooool0Qoooool2o`0000Go
oooo0_l0000:ooooo`Ko00002?ooool6o`000003ooooool0003o000000Co0000U?ooool001cooooo
00?o0000ooooooooool0S_ooool2o`0000oooooo0_l0000:ooooo`?o000000?oooooo`000?l00000
0ol0002Eooooo`007?ooool00ol0003oooooooooo`26ooooo`;o00000_ooool2o`0001?ooooo0_l0
000:ooooo`?o000000Coooooo`000?l0003ooooo0_l0002Eooooo`007?ooool00ol0003ooooooooo
o`26ooooo`;o00000_ooool2o`000003ooooool0003o000000Kooooo0_l00002ooooo`?o00001?oo
ool2o`0000Wooooo2Ol0002Eooooo`007?ooool00ol0003oooooooooo`26ooooo`Co00000oooool2
o`0000Kooooo0_l00002ooooo`?o00001?ooool4o`0000Kooooo3Ol0002Booooo`007?ooool00ol0
003oooooooooo`28ooooo`;o00004_ooool2o`0000?ooooo1?l00004ooooo`oo0000TOooool001co
oooo00?o0000ooooooooool0Qoooool2o`0000cooooo0_l00005ooooo`;o00000_ooool5o`0000Co
oooo0_l000000ooooooo0000o`00000<o`0003;ooooo0_l00003ooooo`;o0000E_ooool001cooooo
00?o0000ooooooooool0Qoooool2o`0000cooooo0_l00003ooooo`;o00001?ooool2o`000003oooo
ool0003o000000Oooooo3_l0000/ooooo`;o00001?ooool4o`000003ooooool0003o000005Kooooo
000Looooo`03o`000?oooooooooo09Wooooo0ol00003ooooo`;o00002OoooolBo`0002[ooooo0_l0
0006ooooo`;o00000oooool2o`0005Cooooo000Looooo`03o`000?oooooooooo09;ooooo0_l00005
ooooo`;o00000_ooool4o`0000Cooooo0_l00003ooooo`Oo000000?oooooo`000?l000002Ol0000[
ooooo`;o00002Oooool2o`0005Cooooo000Looooo`03o`000?oooooooooo09;ooooo0_l00007oooo
o`Co00001Oooool4o`0000;ooooo4ol0000Vooooo`?o00000_ooool2o`0000Gooooo0_l000000ooo
oooo0000o`00001Eooooo`007?ooool00ol0003oooooooooo`2?ooooo`;o00002_ooool4o`0000Go
oooo1?l00003oooooa?o00009Oooool3o`0000Wooooo0_l000000ooooooo0000o`000004o`00057o
oooo000Looooo`;o0000R_ooool2o`000004ooooool0003o0000ooooo`;o000000Coooooo`000?l0
003o00003oooool2o`0000Gooooo5?l0000Yooooo`;o00002?ooool6o`00057ooooo000Looooo`03
o`000?oooooooooo08Wooooo1Ol00004ooooo`?o00000oooool2o`0000[ooooo0_l000000ooooooo
0000o`000002oooooaCo0000:Oooool2o`0000_ooooo0ol0001Aooooo`007?ooool00ol0003ooooo
ooooo`2:ooooo`Co00001oooool2o`000003ooooool0003o000000cooooo0ol00004oooooa;o0000
:_ooool2o`0000Oooooo1_l0001Aooooo`007?ooool00ol0003oooooooooo`2;ooooo`;o00001ooo
ool3o`0000Gooooo0_l00008ooooo`;o00001?oooolDo`0002Wooooo1?l00005ooooo`?o000000?o
ooooo`000?l00000DOooool001cooooo00?o0000ooooooooool0H?ooool2o`000004ooooool0003o
0000ooooo`;o00008oooool2o`0000Gooooo1Ol00005ooooo`Co00003?oooolDo`0001cooooo0_l0
000=ooooo`Co00001?ooool2o`000004ooooool0003o0000o`00053ooooo000Looooo`03o`000?oo
oooooooo05_ooooo0ol00002ooooo`So000000?oooooo`000?l000009oooool2o`0000Cooooo0_l0
0002ooooo`Co00003_oooolBo`00013ooooo0ol00008ooooo`?o00003oooool2o`0000Oooooo0ol0
001@ooooo`007?ooool00ol0003oooooooooo`1Kooooo`?o000000?oooooo`000?l000002_l00000
0ooooooo0000o`00000Nooooo`;o00002_ooool2o`0000Cooooo0_l000000ooooooo0000o`00000:
oooooaKo00002oooool5o`0000Sooooo0ol00003ooooo`;o00000_ooool3o`0000Kooooo0ol00002
ooooo`;o000000Coooooo`000?l0003o0000D?ooool001cooooo00?o0000ooooooooool0G_oooolB
o`0001cooooo0ol000000ooooooo0000o`00000<ooooo`;o000000?oooooo`000?l000002_oooolF
o`0000_ooooo0_l000000ooooooo0000o`000009ooooo`;o00000oooool2o`0000;ooooo0ol00006
ooooo`?o00000_ooool6o`00053ooooo000Looooo`03o`000?oooooooooo05Kooooo0_l00003oooo
oaKo00007?ooool2o`000003ooooool0003o000000Gooooo0_l00008ooooo`Co00002_oooolBo`00
01Oooooo0ol0000;ooooo`;o00001?ooool2o`0000?ooooo2?l0001@ooooo`007?ooool00ol0003o
ooooooooo`1Fooooo`[o000000Coooooo`000?l0003ooooo3Ol0000Jooooo`;o00002Oooool3o`00
00Gooooo0_l00002ooooo`?o00001oooool2o`000003ooooool0003o0000013o00002_ooool2o`00
00_ooooo0ol0000Aooooo`;o00000oooool8o`00053ooooo000Looooo`03o`000?oooooooooo057o
oooo0ol00003ooooo`Wo000000Coooooo`000?l0003ooooo0_l00002ooooo`Wo00006_ooool3o`00
00Sooooo0_l00006ooooo`;o000000?oooooo`000?l000002Oooool3o`0000;ooooo0_l000000ooo
oooo0000o`00000;o`0000[ooooo0_l0000;ooooo`Co00004_ooool;o`00053ooooo000Looooo`03
o`000?oooooooooo057ooooo0ol000000ooooooo0000o`000005o`0000gooooo3?l0000Gooooo`;o
000000?oooooo`000?l000000_l0000:ooooo`;o00000_ooool2o`0000[ooooo1?l00004ooooo`co
00002?ooool4o`0000_ooooo1?l0000=ooooo`;o00000oooool;o`00053ooooo000Looooo`03o`00
0?oooooooooo04oooooo3_l00007ooooo`;o00000oooool>o`0001Sooooo1?l00009ooooo`Go0000
3_ooool2o`0000Gooooo2_l00007ooooo`Go00002oooool2o`000003ooooool0003o000000Co0000
1?ooool3o`0000;ooooo0_l000000ooooooo0000o`00000:o`00057ooooo000Looooo`03o`000?oo
oooooooo04oooooo2Ol00003ooooo`;o00001oooool2o`0000?ooooo3_l0000Fooooo`;o00002?oo
ool2o`0000?ooooo1Ol00004ooooo`Co00003_ooool2o`0000Gooooo0ol00003ooooo`;o000000?o
ooooo`000?l000002Oooool2o`0000?ooooo0ol00002ooooo`Co00001?ooool3o`000003ooooool0
003o000000;ooooo2_l0001Cooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q
1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0COooool2o`0000Kooooo
0_l00003ooooo`;o00001?ooool2o`0000Sooooo3?l0000Gooooo`;o00002?ooool2o`0000Gooooo
0_l00005ooooo`Co00000_ooool2o`0000Kooooo0_l00002ooooo`;o00001Oooool5o`000004oooo
ool0003o0000ooooo`Oo000000Coooooo`000?l0003ooooo0_l00004ooooo`Co000000Coooooo`00
0?l0003ooooo0_l00006ooooo`Co000000?oooooo`000?l000002?l0001Booooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo04gooooo0_l0000;ooooo`;o00001?ooool2o`0000Sooooo3Ol0000Pooooo`;o00003ooo
ool2o`000003ooooool0003o000000Kooooo0_l000000ooooooo0000o`000006ooooo`Go00000_oo
ool9o`000003ooooool0003o000000Oooooo1?l000001?oooooo0000o`000?ooool2o`0000;ooooo
0_l00004ooooo`go0000D_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Ooo
ool5o`0000Kooooo00?o0000ooooooooool0Coooool2o`0000?ooooo0_l00005ooooo`;o00003_oo
ool3o`000003ooooool0003o000000So00005Oooool2o`0000Gooooo0_l0000?ooooo`Co00002ooo
ool3o`0000gooooo0_l00003ooooo`;o00004Oooool2o`0000?ooooo1?l00005ooooo`_o0000Dooo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?m4A4CogMgMooooool0
0007ooooo`?o0000Coooool2o`0000?ooooo0_l00005ooooo`;o00001?ooool2o`0000Sooooo0_l0
0004ooooo`So00005Oooool2o`000003ooooool0003o000000;ooooo0_l00006ooooo`;o00001ooo
ool2o`0000gooooo0_l0000>ooooo`;o00000oooool2o`00017ooooo0_l00003ooooo`;o00001ooo
ool:o`0005Cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CogMgM
oeEEEOoooooo00001oooool00ol0003oooooooooo`1;ooooo`?o00004oooool2o`0000kooooo2?l0
000Cooooo`;o00000oooool2o`0000[ooooo0_l0000Nooooo`;o00007?ooool2o`0000Cooooo0_l0
00000ooooooo0000o`000004ooooo`[o0000EOooool00003ooooool@413ooooo00;ooooo00?o410@
ooooooooool02_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo04Wooooo1Ol0000A
ooooo`?o00001Oooool4o`0000Cooooo1?l000000ooooooo0000o`000003o`0001?ooooo0_l00003
ooooo`;o00009?ooool2o`0000Cooooo0_l0000@ooooo`;o00000_ooool3o`0000Gooooo0_l00003
ooooo`?o000000?oooooo`000?l000000_ooool<o`0005Gooooo00001_ooooooMgMgoiRHV?oooooo
V9RHogMgM`cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`19ooooo`?o00000ooo
ool4o`0000cooooo0ol00005ooooo`Co000000?oooooo`000?l000002ol0000Cooooo`;o00000ooo
ool2o`00013ooooo0_l00006ooooo`;o00002_ooool2o`0001?ooooo1Ol00002ooooo`?o00001Ooo
ool2o`0000?ooooo0_l00006ooooo`co0000EOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^
3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo04Wooooo0_l00004ooooo`Co0000
2oooool2o`0000Sooooo0_l000000ooooooo0000o`00000=o`0001;ooooo0_l00003ooooo`;o0000
4?ooool3o`0000;ooooo0_l000000ooooooo0000o`000007ooooo`;o00001Oooool2o`0000gooooo
1_l00004ooooo`;o00001?ooool3o`0000Gooooo1?l00004ooooo`Oo0000F?ooool001cooooo00?o
0000ooooooooool0B?ooool5o`0000[ooooo0_l00004ooooo`Co00000oooool2o`000005ooooool0
003o0000o`000?ooool04?l0000Booooo`;o00000_ooool2o`00017ooooo0_l00002ooooo`;o0000
2_ooool2o`0000Gooooo0_l0000=ooooo`;o00002?ooool2o`0000?ooooo0ol00006ooooo`Go0000
0oooool7o`0005Sooooo000Looooo`03o`000?oooooooooo04Sooooo1Ol0000:ooooo`?o00000ooo
ool4o`0000?ooooo1Ol00002ooooo`?o000000?oooooo`000?l000002_l0000Aooooo`?o00004_oo
ool2o`0000Gooooo0_l0000Qooooo`;o00001?ooool2o`0000Kooooo0_l00002ooooo`?o00001Ooo
ool3o`0000?ooooo0_l00002ooooo`;o0000F?ooool001cooooo00?o0000ooooooooool0B?ooool2
o`0000_ooooo0_l000000ooooooo0000o`000009ooooo`Co00000ooooolBo`00013ooooo0_l0000C
ooooo`;o00001oooool2o`0000Kooooo0_l00005ooooo`;o00004?ooool2o`0000Cooooo0_l00003
ooooo`;o00000oooool5o`0000Kooooo0ol000000ooooooo0000o`000002o`0005_ooooo000Loooo
o`03o`000?oooooooooo04Kooooo1?l0000;ooooo`;o00003?ooool2o`0000Gooooo4_l0000@oooo
o`;o00007?ooool2o`0000Kooooo0ol00004ooooo`;o00002Oooool2o`0000[ooooo0_l00002oooo
o`Co00000oooool2o`0000Oooooo1Ol000000ooooooo0000o`000002o`0005_ooooo000Looooo`03
o`000?oooooooooo04Kooooo0_l000000ooooooo0000o`000005ooooo`?o00001?ooool2o`0000;o
oooo0_l0000=oooooa7o00007oooool2o`0000Sooooo0ol0000:ooooo`Ko00003Oooool2o`0000[o
oooo0_l00002ooooo`Ko00001_ooool7o`0000?ooooo0ol0001Looooo`007?ooool00ol0003ooooo
ooooo`17ooooo`Co00001Oooool3o`0000?ooooo0ol00002ooooo`;o00003?oooolDo`0001Sooooo
0_l00003ooooo`;o00002?ooool3o`0000[ooooo0_l00002ooooo`;o00004_ooool2o`0000Cooooo
0_l00004oooooa;o0000H_ooool001cooooo00?o0000ooooooooool0A_ooool5o`000003ooooool0
003o000000Sooooo0_l00002ooooo`?o00001Oooool2o`000003ooooool0003o000000;ooooo5?l0
000Booooo`;o00001?ooool2o`0000Oooooo0_l0000Uooooo`;o00000_ooool2o`000004ooooool0
003o0000ooooo`;o00001?ooool2o`0000;ooooo3ol000000ooooooo0000o`00001Nooooo`007?oo
ool00ol0003oooooooooo`16ooooo`So00003?ooool2o`000003ooooool0003o000000?ooooo0_l0
00000ooooooo0000o`000002oooooa?o00004oooool2o`0000gooooo0_l0000Aooooo`;o000000?o
ooooo`000?l000001_ooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`00
0004o`0000_ooooo4_l0001Nooooo`007?ooool00ol0003oooooooooo`17ooooo`Go00004?ooool5
o`0000Wooooo4_l0000Cooooo`;o00001?ooool2o`0000[ooooo0_l00004ooooo`;o00002?ooool5
o`0000Kooooo0_l000000ooooooo0000o`000007ooooo`Ko00002Oooool9o`000003ooooool0003o
000000Ko0000H?ooool001cooooo00?o0000ooooooooool0B?ooool3o`000003ooooool0003o0000
00Go00001Oooool3o`000004ooooool0003o0000ooooo`;o00001_oooolDo`0001;ooooo0_l00005
ooooo`?o00002_ooool3o`0000?ooooo0_l0000:ooooo`;o00001oooool2o`0000Cooooo1?l00004
ooooo`Co00001?ooool2o`0000;ooooo4ol0001Pooooo`007?ooool00ol0003oooooooooo`1<oooo
o`[o00000_ooool6o`0000Wooooo4ol0000Cooooo`;o00001Oooool2o`0000Sooooo0_l000001?oo
oooo0000o`000?l0000;ooooo`;o00002Oooool4o`0000;ooooo1_l00003ooooo`?o00001_ooool2
o`0000;ooooo1ol000000ooooooo0000o`000002o`000003ooooool0003o000000Co0000H?ooool0
01cooooo0_l0001Cooooo`Co00001Oooool3o`0000Wooooo5Ol0000Rooooo`;o000000?oooooo`00
0?l000003?ooool2o`0000Wooooo0ol00003ooooo`;o00001_ooool3o`0000Oooooo0_l00004oooo
oa?o0000G_ooool001cooooo00?o0000ooooooooool0Eoooool2o`0000Oooooo0_l00007oooooa?o
0000?_ooool3o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo0_l000000ooooooo
0000o`000002o`000004ooooool0003o0000oooooa?o0000G_ooool001cooooo00?o0000oooooooo
ool0Eoooool4o`000003ooooool0003o000000;ooooo1?l00003oooooa;o000000?oooooo`000?l0
00005_ooool2o`0002_ooooo0_l000000ooooooo0000o`000002o`0000Oooooo0_l000000ooooooo
0000o`000003ooooo`oo000000Coooooo`000?l0003o0000HOooool001cooooo00?o0000oooooooo
ool0FOooool5o`0000Cooooo0_l00002oooooaKo00004Oooool2o`000003ooooool0003o000000;o
0000:oooool2o`000004ooooool0003o0000o`0000Oooooo0_l00007ooooo`?o000000?oooooo`00
0?l000003ol0001Oooooo`007?ooool00ol0003oooooooooo`1Jooooo`Ko00001_ooool2o`000003
ooooool0003o0000017o00004Oooool5o`0000cooooo0_l0000/ooooo`;o00001ooooolEo`0005oo
oooo000Looooo`03o`000?oooooooooo05[ooooo1_l00008oooooa;o00005Oooool2o`0000Sooooo
0_l00003ooooo`Co00008_ooool2o`0000oooooo5?l0001Pooooo`007?ooool00ol0003ooooooooo
o`1Jooooo`;o00001oooool3o`0000;ooooo4ol0000Looooo`Co00001Oooool2o`0000oooooo0_l0
000Aooooo`;o00003oooool:o`000003ooooool0003o000000Oo0000H?ooool001cooooo00?o0000
ooooooooool0Hoooool3o`0000;ooooo4ol0000Looooo`;o00006?ooool4o`0000Kooooo0_l00007
ooooo`;o00003oooool:o`000003ooooool0003o000000Oo0000H?ooool001cooooo00?o0000oooo
ooooool0I_oooolAo`0000;ooooo0_l0000>ooooo`?o00004Oooool2o`0001Cooooo0_l00006oooo
o`;o00006?oooolDo`00063ooooo000Looooo`03o`000?oooooooooo05oooooo0_l00005ooooo`oo
00001?ooool2o`0000kooooo0ol00006ooooo`;o000000?oooooo`000?l000001_ooool2o`00017o
oooo0_l0000Booooo`;o00002_ooool2o`0000Gooooo4_l0001Pooooo`007?ooool00ol0003ooooo
ooooo`1Nooooo`?o00001oooool=o`0000Cooooo0_l0000>ooooo`?o00001_ooool2o`000003oooo
ool0003o000001Wooooo0_l0000@ooooo`Co00002?ooool4o`0000Cooooo4_l00002ooooo`;o0000
GOooool001cooooo00?o0000ooooooooool0G_ooool2o`0000Sooooo3?l000000ooooooo0000o`00
0002ooooo`;o00003Oooool4o`0000Cooooo0_l0000`ooooo`Go00001oooool3o`0000Gooooo1_l0
00000ooooooo0000o`00000:o`000003ooooool0003o000005gooooo000Looooo`03o`000?oooooo
oooo05kooooo0_l00009ooooo`_o000000Coooooo`000?l0003ooooo1?l0000<ooooo`;o00001_oo
ool3o`0002gooooo1?l000000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l000001_oo
oolBo`000003ooooool0003o000005gooooo000Looooo`03o`000?oooooooooo05gooooo0ol00009
ooooo`co00000_ooool5o`0000_ooooo0ol000000ooooooo0000o`000004ooooo`;o0000;Oooool2
o`000003ooooool0003o000000Oooooo0_l000001?oooooo0000o`000?l00005oooooa7o00000_oo
ool2o`0005gooooo000Looooo`03o`000?oooooooooo05Sooooo0ol00002ooooo`;o00002_oooolB
o`0000_ooooo0ol00002ooooo`;o00004_ooool2o`0002;ooooo0_l00007ooooo`Oo00001?ooool@
o`0000?ooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1Cooooo`Co000000?oooooo`00
0?l000000_l00007ooooo`;o00001OoooolAo`0000[ooooo0ol0000:ooooo`;o00002oooool2o`00
02_ooooo1ol00004oooooa7o00000_ooool2o`0005gooooo000Looooo`;o0000Doooool;o`0000Ko
oooo0_l00006oooooa3o00002_ooool3o`0000Gooooo0ol00002ooooo`;o00001Oooool2o`0001ko
oooo0_l0000=ooooo`;o00001oooool2o`0000Gooooo2_l00002ooooo`Co00000_ooool2o`0005go
oooo000Looooo`03o`000?oooooooooo057ooooo3?l000000ooooooo0000o`00000;ooooo`oo0000
2?ooool6o`000003ooooool0003o000000;ooooo1_l00006ooooo`;o00004_ooool4o`0000Cooooo
0_l00002ooooo`;o00003Oooool2o`000003ooooool0003o000000Cooooo0ol00004ooooo`ko0000
1?ooool2o`0005gooooo000Looooo`03o`000?oooooooooo053ooooo3Ol000001?oooooo0000o`00
0?l0000:ooooo`ko00002Oooool4o`0000?ooooo0_l00004ooooo`Co00003Oooool2o`0000_ooooo
1?l00004ooooo`;o00005?ooool2o`0000Gooooo0_l00004ooooo`go00001Oooool2o`0005gooooo
000Looooo`03o`000?oooooooooo053ooooo3Ol00002ooooo`;o00003?ooool8o`0000_ooooo1Ol0
0004ooooo`Co00001?ooool2o`0000Sooooo0_l00003ooooo`;o0000;Oooool2o`0000Sooooo2ol0
0006ooooo`;o0000GOooool001cooooo00?o0000ooooooooool0DOooool<o`0001;ooooo2?l00008
ooooo`Co00001_ooool4o`0000Gooooo0_l00007ooooo`;o00007Oooool2o`000003ooooool0003o
0000013ooooo0_l00009ooooo`Wo0000I_ooool001cooooo00?o0000ooooooooool0C?ooool@o`00
01?ooooo0_l000000ooooooo0000o`00000>o`00013ooooo0ol0000Uooooo`;o000000?oooooo`00
0?l000007Oooool2o`000003ooooool0003o000000Sooooo0ol0001Mooooo`007?ooool00ol0003o
ooooooooo`1<oooooa7o00003oooool2o`0000Cooooo3_l00004ooooo`;o00003Oooool2o`0001_o
oooo0_l0000=ooooo`;o00006oooool6o`000003ooooool0003o000000Cooooo0ol0001Mooooo`00
7?ooool00ol0003oooooooooo`1=oooooa7o00003_ooool2o`0000Kooooo2_l00006ooooo`;o0000
2?ooool2o`00023ooooo0_l000000ooooooo0000o`00000:ooooo`;o00003_ooool2o`0000Cooooo
0_l00005ooooo`Ko000000?oooooo`000?l000000oooool3o`0005kooooo000Looooo`03o`000?oo
oooooooo04_ooooo4?l000000ooooooo0000o`00000@ooooo`Co00000oooool3o`0000;ooooo0_l0
000<ooooo`;o00001?ooool2o`0002?ooooo0_l00008ooooo`;o00000_ooool2o`0000cooooo0_l0
0004ooooo`;o00001_ooool6o`0000;ooooo0_l000001?oooooo0000o`000?l0001Nooooo`007?oo
ool00ol0003oooooooooo`1;oooooaCo00003oooool4o`000003ooooool0003o000000Gooooo0_l0
0008ooooo`;o00000_ooool2o`0000Cooooo0_l0000]ooooo`;o00000_ooool2o`0000cooooo0ol0
0003ooooo`;o00001oooool:o`00067ooooo000Looooo`03o`000?oooooooooo04[ooooo5Ol00007
ooooo`?o000000?oooooo`000?l000001oooool2o`0000oooooo0_l0000fooooo`Oo00002?ooool2
o`0000;ooooo0ol00003ooooo`;o00002_ooool7o`00067ooooo000Looooo`03o`000?oooooooooo
04[ooooo4?l00009ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0001?ooooo0_l0000<
ooooo`;o00009?ooool2o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000002_ooool2
o`0000Cooooo1?l0001dooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o000000?oooooo`00
0?l000003ol00005ooooo`;o00000_ooool2o`0001Kooooo0_l0000<ooooo`;o00009?ooool2o`00
00?ooooo0_l00006ooooo`;o00003oooool4o`0007Cooooo000Looooo`03o`000?oooooooooo04[o
oooo0_l000000ooooooo0000o`00000?o`000003ooooool0003o000000Cooooo1?l00005ooooo`;o
00003Oooool2o`00017ooooo0_l0000?ooooo`;o00004Oooool2o`0000Sooooo1?l00003ooooo`;o
00003oooool2o`00077ooooo000Looooo`03o`000?oooooooooo04[ooooo3ol000000ooooooo0000
o`000003ooooo`;o00001?ooool2o`0000Oooooo0_l00005ooooo`;o00001_ooool2o`0000Kooooo
1?l00007ooooo`;o00003oooool2o`0000;ooooo0_l0000=ooooo`;o00002?ooool5o`0000;ooooo
0_l0000?ooooo`;o0000LOooool001cooooo00?o0000ooooooooool0B_ooool8o`000003ooooool0
003o000000Go00000oooool2o`0001Kooooo0_l00002ooooo`;o00000oooool2o`0000Gooooo1?l0
000Looooo`;o00005Oooool2o`0000?ooooo0_l00002ooooo`;o00004_ooool4o`0006cooooo000L
ooooo`;o0000Coooool4o`0000?ooooo1Ol00003ooooo`;o00001?ooool2o`0000[ooooo0_l00008
ooooo`;o00000oooool2o`00017ooooo0_l0000Dooooo`;o00004Oooool4o`0000?ooooo0_l00002
ooooo`;o00001oooool2o`0000Wooooo1?l0001/ooooo`007?ooool00ol0003oooooooooo`1:oooo
o`?o000000?oooooo`000?l000002Ol00005ooooo`?o00000_ooool2o`0000[ooooo0_l0000Ioooo
o`;o00001Oooool2o`0001Cooooo0_l0000Aooooo`;o00002Oooool2o`0000?ooooo1_l00007oooo
o`;o00000_ooool2o`0006cooooo000Looooo`03o`000?oooooooooo04[ooooo0ol000000ooooooo
0000o`000005o`0000Sooooo1?l00005ooooo`;o00001oooool3o`0001Sooooo0_l0000Mooooo`;o
00006_ooool2o`0000?ooooo1?l00007ooooo`Go000000?oooooo`000?l00000K?ooool001cooooo
00?o0000ooooooooool0COooool2o`0000kooooo0_l00002ooooo`;o00000oooool2o`0000Oooooo
0ol00005ooooo`;o00004_ooool2o`0001Oooooo0_l00003ooooo`;o00001?ooool2o`0000oooooo
0_l00006ooooo`Ko00001oooool2o`000004ooooool0003o0000ooooo`;o0000K?ooool001cooooo
00?o0000ooooooooool0COooool2o`0000Gooooo0_l0000;ooooo`?o00002?ooool2o`000003oooo
ool0003o000000Kooooo0_l00008ooooo`;o00002?ooool2o`0001Kooooo0ol00009ooooo`;o0000
3oooool2o`0000Kooooo0_l0000;ooooo`;o000000?oooooo`000?l00000Koooool001cooooo00?o
0000ooooooooool0DOooool2o`000003ooooool0003o000000Kooooo0_l00004ooooo`;o00002?oo
ool2o`000003ooooool0003o0000013ooooo0_l0000Pooooo`;o00006_ooool4o`0001Gooooo0_l0
001_ooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o00001oooool4o`0000Oooooo0_l00006
ooooo`;o00003oooool2o`0000?ooooo0_l0000aooooo`;o000000?oooooo`000?l000001?ooool4
o`0000Sooooo0_l00006ooooo`;o00001oooool5o`0006Sooooo000Looooo`03o`000?oooooooooo
05;ooooo1Ol00003ooooo`;o00002Oooool2o`0000Kooooo0_l00008ooooo`;o00001Oooool2o`00
00?ooooo0_l0000aooooo`;o000000?oooooo`000?l000004?ooool2o`0000Kooooo1?l00005oooo
o`Go000000Coooooo`000?l0003o0000I?ooool001cooooo00?o0000ooooooooool0D_ooool5o`00
01Kooooo0_l00004ooooo`;o00000_ooool2o`0000kooooo0_l0000;ooooo`;o0000<Oooool2o`00
00;ooooo0_l000000ooooooo0000o`000003ooooo`Co00001oooool2o`0000;ooooo0ol0001Toooo
o`007?ooool00ol0003oooooooooo`1Looooo`?o00005?ooool2o`0000Cooooo0_l0000<ooooo`;o
00002oooool2o`00037ooooo0_l00005ooooo`;o00000oooool2o`0000Wooooo0_l00002ooooo`;o
0000IOooool001cooooo00?o0000ooooooooool0G?ooool3o`0001[ooooo0_l0000Uooooo`;o0000
2_ooool2o`0000?ooooo0_l0000_ooooo`Co0000Hoooool001cooooo00?o0000ooooooooool0Gooo
ool2o`000003ooooool0003o000000gooooo0_l0000]ooooo`;o00001_ooool2o`0000;ooooo0_l0
0003ooooo`;o00005Oooool2o`0000Wooooo0_l0000?ooooo`;o0000Hoooool001cooooo00?o0000
ooooooooool0G_ooool3o`000003ooooool0003o000000gooooo0_l00009ooooo`;o00003oooool2
o`0000Oooooo0_l0000:ooooo`;o00001?ooool2o`00013ooooo1?l000000ooooooo0000o`000007
ooooo`?o00001?ooool2o`0000;ooooo0_l0000Aooooo`Ko0000GOooool001cooooo00?o0000oooo
ooooool0G_ooool2o`000003ooooool0003o000000Oooooo0_l00004ooooo`;o00002_ooool4o`00
00Oooooo0_l00004ooooo`;o00000_ooool2o`0000?ooooo0_l00007ooooo`Go00001Oooool2o`00
00;ooooo0_l00002ooooo`;o00001oooool4o`000003ooooool0003o000000Sooooo0_l00004oooo
o`;o00002?ooool2o`0000;ooooo0ol00006ooooo`Oo0000G?ooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oo
oooooooo05_ooooo0_l000001?oooooo0000o`000?ooool4o`0000Gooooo0_l00004ooooo`;o0000
0oooool2o`0000Oooooo0_l00003ooooo`;o000000Coooooo`000?l0003o00002?ooool2o`0000co
oooo1?l00006ooooo`;o00000_ooool2o`0000;ooooo1?l00005ooooo`;o00000oooool2o`0000ko
oooo0_l00003ooooo`;o00000_ooool3o`0000;ooooo1Ol000001?oooooo0000o`000?l00005oooo
o`?o0000Foooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEE
ogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo05_ooooo3_l0000<ooooo`;o000000?o
ooooo`000?l000002Oooool2o`000003ooooool0003o000001Oooooo1Ol0000?ooooo`?o00000ooo
ool3o`0000?ooooo0_l00005ooooo`;o00002_ooool4o`0000;ooooo0_l00006ooooo`;o000000Co
ooooo`000?l0003o00001_ooool2o`0005_ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oo
oooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo05cooooo
3ol00008ooooo`;o00000oooool4o`0000Kooooo0_l0000=ooooo`;o00003oooool2o`0000Kooooo
0_l00002ooooo`;o00000oooool3o`0000?ooooo0_l00008ooooo`;o000000?oooooo`000?l00000
1Oooool2o`0000?ooooo0_l00006ooooo`;o00001?ooool2o`0000_ooooo0_l0001Jooooo`0000?o
ooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B40
1_ooool3o`0005cooooo3ol00008ooooo`;o00000_ooool2o`000003ooooool0003o000000Kooooo
0_l0000=ooooo`;o00005oooool2o`0000;ooooo0_l0000Cooooo`?o00001oooool2o`000003oooo
ool0003o000000;o00001_ooool4o`0000;ooooo0_l0000;ooooo`;o0000F_ooool00003ooooool0
003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo
00?o0000ooooooooool0G?ooool>o`0000gooooo0_l00010ooooo`?o00002?ooool3o`0000Wooooo
1?l00005ooooo`;o000000?oooooo`000?l000002_ooool2o`0005oooooo00000ooooooo410@oooo
o`02ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003ooooooooo
o`1Loooooa7o00000_ooool2o`0000Cooooo0_l00003ooooo`;o00003?ooool2o`0000[ooooo0_l0
000Sooooo`?o00000_ooool2o`0000Gooooo0ol00009ooooo`?o00001Oooool2o`0000;ooooo0_l0
0008ooooo`?o00000_ooool2o`0005_ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo
00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`1Jooooo`?o000000?oooooo`000?l00000
3_l000000ooooooo0000o`000004ooooo`;o00000oooool2o`0000cooooo0_l0000:ooooo`;o0000
2Oooool2o`0000Oooooo0_l0000Dooooo`;o00001_ooool2o`000004ooooool0003o0000o`0000Go
oooo0ol00005ooooo`?o000000?oooooo`000?l000000_ooool2o`0000;ooooo1Ol000001?oooooo
0000o`000?l0001Kooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co
0000oa0@40Kooooo00?o0000ooooooooool0F_ooool3o`000003ooooool0003o000000ko00002_oo
ool3o`0001Cooooo1_l00007ooooo`Go00001oooool2o`0000[ooooo0_l000000ooooooo0000o`00
000@ooooo`Go000000?oooooo`000?l000000ol00005ooooo`Co00001?ooool2o`0000;ooooo1Ol0
00000ooooooo0000o`00001Looooo`007?ooool00ol0003oooooooooo`1Jooooo`;o00000_ooool>
o`000003ooooool0003o000000Cooooo0_l00003ooooo`?o000000?oooooo`000?l000002_ooool2
o`0000Gooooo1_l00007ooooo`Co00003oooool4o`000004ooooool0003o0000ooooo`;o00000ooo
ool2o`0000Sooooo3?l00009ooooo`;o00000oooool2o`0000Sooooo0_l0001Mooooo`007?ooool0
0ol0003oooooooooo`1Noooooa7o000000Coooooo`000?l0003ooooo0_l00007ooooo`;o00002_oo
ool2o`00013ooooo0_l00002ooooo`;o00003oooool4o`000004ooooool0003o0000o`0000Gooooo
0_l00006ooooo`ko00001Oooool2o`0000Gooooo1?l00008ooooo`;o0000GOooool001cooooo00?o
0000ooooooooool0G_oooolDo`000003ooooool0003o000000;o00002oooool2o`0000;ooooo0_l0
0003ooooo`;o00003Oooool2o`0000Gooooo0_l00006ooooo`;o00000_ooool2o`0000Gooooo0ol0
0005ooooo`;o00000oooool2o`000003ooooool0003o000000oo00000_ooool2o`0000Cooooo0ol0
001Yooooo`007?ooool00ol0003oooooooooo`1Kooooo`;o000000?oooooo`000?l000004?l00003
ooooo`Co00002oooool2o`000004ooooool0003o0000o`0000?ooooo0_l00005ooooo`;o00003Ooo
ool2o`0000;ooooo0_l00002ooooo`;o00000_ooool2o`0000[ooooo1Ol00003oooooaKo00001_oo
ool2o`0000;ooooo0_l00006ooooo`;o0000G_ooool001cooooo00?o0000ooooooooool0Foooool2
o`000003ooooool0003o000000ko00001Oooool4o`0000;ooooo0_l0000:ooooo`;o00002?ooool2
o`000003ooooool0003o000000Gooooo0_l0000:ooooo`;o00004_ooool3o`0000;ooooo6Ol00009
ooooo`Oo000000Coooooo`000?l0003o00000oooool2o`0005Wooooo000Looooo`03o`000?oooooo
oooo05cooooo0_l000000ooooooo0000o`00000;o`0000Cooooo0_l00003ooooo`;o000000Cooooo
o`000?l0003o00001Oooool2o`0000[ooooo0_l000000ooooooo0000o`000008ooooo`;o00008ooo
oolIo`0000Gooooo3_l00004ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0G?ooool2
o`0000;ooooo3Ol00002ooooo`?o00001_ooool2o`0000?ooooo0_l000000ooooooo0000o`00000:
ooooo`;o00000_ooool2o`0000;ooooo1?l0000<ooooo`;o00003Oooool2o`0000Oooooo6ol00004
ooooo`oo0000Goooool001cooooo00?o0000ooooooooool0H?ooool:o`000003ooooool0003o0000
00;ooooo0_l00003ooooo`;o00001oooool2o`0000cooooo0_l00003ooooo`;o00000_ooool4o`00
00_ooooo0ol0000:ooooo`;o000000?oooooo`000?l000001Oooool`o`0000;ooooo1?l0001Ioooo
o`007?ooool00ol0003oooooooooo`1Qooooo`Wo00002_ooool2o`0000Sooooo0_l00009ooooo`Co
00001oooool4o`0000Wooooo1Ol000000ooooooo0000o`000005ooooo`Co00001_ooool4o`0000?o
oooo:_l000000ooooooo0000o`000004o`0005Wooooo000Looooo`03o`000?oooooooooo06Gooooo
0_l000000ooooooo0000o`000006ooooo`Co000000?oooooo`000?l000000_l000000ooooooo0000
o`000004o`0000Oooooo1?l00007ooooo`;o00000_ooool2o`0000Oooooo1?l000001?oooooo0000
o`000?ooool2o`0000Gooooo0_l00008ooooo`;o00001oooool]o`0005_ooooo000Looooo`03o`00
0?oooooooooo073ooooo4?l000000ooooooo0000o`000004ooooo`;o00002Oooool2o`0000Oooooo
0_l00002ooooo`?o00000_ooool2o`0001;ooooo0_l000000ooooooo0000o`000004ooooobgo0000
Foooool001cooooo0_l0001[ooooo`Go000000?oooooo`000?l000004Ol00007ooooo`Go00000ooo
ool2o`0000Oooooo0ol000000ooooooo0000o`000003ooooo`;o00005Oooool2o`0000Cooooo9Ol0
00000ooooooo0000o`000003o`0005gooooo000Looooo`03o`000?oooooooooo06[ooooo1Ol00002
oooooaGo00000_ooool7o`000003ooooool0003o000000Oooooo0_l000001?oooooo0000o`000?oo
ool2o`0000_ooooo0_l00004ooooo`;o00001oooool2o`000005ooooool0003o0000o`000?ooool0
:_l0001Mooooo`007?ooool00ol0003oooooooooo`1`ooooo`?o00000ooooolLo`0000Oooooo0_l0
000@ooooo`?o00000_ooool5o`000003ooooool0003o000000?ooooo0_l000001?oooooo0000o`00
0?l00002ooooo`;o00001OoooolPo`0005oooooo000Looooo`03o`000?oooooooooo073ooooo0ol0
0003ooooob3o000000Coooooo`000?l0003o00004Oooool2o`0000?ooooo0_l000001?oooooo0000
o`000?ooool2o`0001;ooooo0ol00006oooooa7o000000Coooooo`000?l0003o0000HOooool001co
oooo00?o0000ooooooooool0M?oooolHo`0000Cooooo1_l000001?oooooo0000o`000?l00003oooo
o`Co00003Oooool4o`0000[ooooo0_l0000Eooooo`Go000000?oooooo`000?l000001?l000001?oo
oooo0000o`000?l00002ooooo`;o0000H_ooool001cooooo00?o0000ooooooooool0L_ooool4o`00
00?ooooo5_l000000ooooooo0000o`000003o`000003ooooool0003o000000;o00000oooool4o`00
0003ooooool0003o000000Kooooo0_l00002ooooo`Co00001_ooool2o`0000;ooooo0ol0002:oooo
o`007?ooool00ol0003oooooooooo`1booooo`;o00002?oooolCo`000003ooooool0003o000000So
00002?ooool2o`0000Kooooo0_l0000<ooooo`;o00000_ooool3o`0008[ooooo000Looooo`03o`00
0?oooooooooo07cooooo6ol00002ooooo`;o00001oooool2o`0000?ooooo0_l00006ooooo`;o0000
00Coooooo`000?l0003ooooo0_l00004ooooo`?o0000Roooool001cooooo00?o0000ooooooooool0
O?oooolGo`0000;ooooo0_l00002ooooo`;o00001oooool2o`0000?ooooo0ol00005ooooo`;o0000
00Coooooo`000?l0003ooooo1Ol000001?oooooo0000o`000?l0002;ooooo`007?ooool00ol0003o
ooooooooo`1noooooa;o00001Oooool2o`0000?ooooo0_l00009ooooo`;o000000?oooooo`000?l0
00003?ooool8o`0008_ooooo000Looooo`03o`000?oooooooooo07oooooo2?l000000ooooooo0000
o`00000:o`0000Kooooo0_l00009ooooo`;o00001?ooool2o`0000Kooooo0_l00003ooooo`Ko0000
Roooool001cooooo00?o0000ooooooooool0OooooolHo`0000Sooooo0_l00002ooooo`?o00001?oo
ool3o`0000;ooooo0_l00002ooooo`;o00000oooool2o`000004ooooool0003o0000o`0008_ooooo
000Looooo`03o`000?oooooooooo07oooooo6Ol00007ooooo`Oo00001?ooool2o`000003ooooool0
003o000000?o00001_ooool2o`000003ooooool0003o000008cooooo000Looooo`03o`000?oooooo
oooo083ooooo6Ol000000ooooooo0000o`000005ooooo`;o00002_ooool2o`000003ooooool0003o
000000Wooooo0_l0002<ooooo`007?ooool00ol0003oooooooooo`22ooooo`?o00000_ooool9o`00
0003ooooool0003o000000Ko000000?oooooo`000?l000000oooool2o`0000;ooooo0_l0000Doooo
o`Co0000S?ooool001cooooo00?o0000ooooooooool0P_ooool3o`0000Gooooo0_l000000ooooooo
0000o`00000:o`0000;ooooo0ol000000ooooooo0000o`000002ooooo`;o00002_ooool2o`0000Oo
oooo1Ol0002<ooooo`007?ooool2o`0008Kooooo0ol00002ooooo`;o00000_ooool@o`00013ooooo
0ol00007ooooo`;o000000?oooooo`000?l00000S?ooool001cooooo00?o0000ooooooooool0QOoo
ool3o`0000;ooooo5ol00002ooooo`;o000000?oooooo`000?l000001_ooool3o`0000Sooooo0ol0
002=ooooo`007?ooool00ol0003oooooooooo`2:oooooako00001oooool2o`0000Sooooo1?l0002<
ooooo`007?ooool00ol0003oooooooooo`28ooooo`;o00000ooooolLo`0000oooooo1Ol0002<oooo
o`007?ooool00ol0003oooooooooo`28ooooo`;o00001oooool2o`000003ooooool0003o000001Go
00000_ooool2o`0000Wooooo1Ol0002<ooooo`007?ooool00ol0003oooooooooo`2Aoooooa;o0000
1_ooool3o`000003ooooool0003o000000Kooooo0_l000000ooooooo0000o`000002o`0008gooooo
000Looooo`03o`000?oooooooooo093ooooo1Ol000000ooooooo0000o`00000<o`0000Gooooo1?l0
0006ooooo`So0000S_ooool001cooooo00?o0000ooooooooool0T?ooool2o`0000?ooooo4ol00002
ooooo`?o000000?oooooo`000?l000000_ooool9o`0008kooooo000Looooo`03o`000?oooooooooo
09Gooooo4ol00002ooooo`co000000?oooooo`000?l000000_l0002>ooooo`007?ooool00ol0003o
ooooooooo`2FoooooaCo000000?oooooo`000?l000001Ol00002ooooo`;o000000?oooooo`000?l0
0000T?ooool001cooooo00?o0000ooooooooool0UooooolCo`0000[ooooo0_l000000ooooooo0000
o`00002@ooooo`007?ooool00ol0003oooooooooo`2Hoooooa?o00002?ooool3o`0009?ooooo000L
ooooo`03o`000?oooooooooo09Sooooo5Ol00006ooooo`Co0000T_ooool001cooooo00?o0000oooo
ooooool0V?oooolGo`0000?ooooo1Ol0002Booooo`007?ooool00ol0003oooooooooo`2Ioooooa;o
000000Coooooo`000?l0003o00000oooool4o`0009?ooooo000Looooo`03o`000?oooooooooo09[o
oooo5Ol00002ooooo`Go0000Toooool001cooooo0_l0002KoooooaGo00000_ooool2o`0009Kooooo
000Looooo`03o`000?oooooooooo09_ooooo4ol00002ooooo`Co0000UOooool001cooooo00?o0000
ooooooooool0W?oooolHo`0009Gooooo000Looooo`03o`000?oooooooooo09cooooo0_l00002oooo
o`co000000?oooooo`000?l000000_l000000ooooooo0000o`00002Eooooo`007?ooool00ol0003o
ooooooooo`2Tooooo`Go00001?ooool5o`0009Oooooo000Looooo`03o`000?oooooooooo0:Cooooo
0_l000000ooooooo0000o`000002ooooo`Oo0000Uoooool001cooooo00?o0000ooooooooool0Zooo
ool5o`0009Wooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool00006
ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<
c006ooooo`03o`000?oooooooooo0?ooooooB_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?oo
ooooB_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool0oooooom:ooooo`0000?oooooo`000?ooool0
0_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`000?oo
ooooB_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Oo<c<co0000
o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom:ooooo`0000?ooooooa0@4?ooool0
0_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003o
ooooooooo`3ooooood[ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj
^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0?ooooooB_ooool00006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?oo
ooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom:oooo
o`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo
00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o0000ooooooooool0oooo
oomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo
0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`004_ooool00omEEEGoIVIV
o`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Yooooo`04
oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05Oooool01?l@413o0000odA4A?o<c<`4
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0U?ooool00:[ooooo00Go0000ooooooooooooooooo`00
0009ooooo`Ko00002oooool00onHV9So410@omgMg@03ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40
U?ooool00:[ooooo00Go0000ooooooooooooooooo`00000Kooooo`03ohN7QomEEEGooooo00;ooooo
00Go0000ooooooooooooooooo`00002Dooooo`00Z_ooool01Ol0003ooooooooooooooooo000000Wo
oooo1_l00009ooooo`05olc<c?lQ8B7o0000oeEEEOl000000oooool01Ol0003oV9RHoooooonHV9So
8B4Q09Cooooo002Zooooo`05o`000?n7QhOoooooojVYZOl000006?ooool01OlQ8B7oQhN7oooooonH
V9So000000?ooooo00Go0000oeEEEOl0003o410@olc<c02Dooooo`00ZOooool00ol@413o0000ogMg
M`02o`000003oiRHV?oooooooooo01Kooooo00Go0000ooooooooooooooooo`000003ooooo`03oeEE
EOn7QhOooooo09Kooooo0037ooooo`05ob4Q8OnHV9SoooooogMgMomEEED00oooool00ooMgMgo410@
oiRHV02Fooooo`00aoooool01Oo<c<co410@o`000?lb<S;ok^k^00Cooooo00Coc<c<odA4A?l0003o
410@U?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(102) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.48747 .74254 Mdot
.44307 .71696 Mdot
.70891 .49662 Mdot
.36076 .41387 Mdot
.52251 .21817 Mdot
.70335 .49516 Mdot
.615 .64765 Mdot
.62719 .63508 Mdot
.73005 .4628 Mdot
.38845 .37606 Mdot
.63399 .66941 Mdot
.25189 .47816 Mdot
.6127 .63968 Mdot
.38733 .43072 Mdot
.25368 .39598 Mdot
.29431 .56664 Mdot
.47191 .74714 Mdot
.51907 .21748 Mdot
.28251 .58093 Mdot
.73122 .46532 Mdot
.49378 .25528 Mdot
.37386 .42277 Mdot
.4775 .73495 Mdot
.38659 .43282 Mdot
.28497 .58034 Mdot
.43067 .67935 Mdot
.4837 .73036 Mdot
.29426 .58074 Mdot
.25857 .47934 Mdot
.59446 .64576 Mdot
.30699 .58843 Mdot
.31827 .34246 Mdot
.58235 .33992 Mdot
.39173 .65955 Mdot
.66929 .69035 Mdot
.6418 .68043 Mdot
.71398 .46336 Mdot
.61788 .66554 Mdot
.5965 .63066 Mdot
.66034 .68379 Mdot
.65962 .68485 Mdot
.43218 .67951 Mdot
.66031 .69055 Mdot
.70787 .65641 Mdot
.36193 .46225 Mdot
.3571 .6301 Mdot
.73991 .46708 Mdot
.35068 .48805 Mdot
.48032 .7563 Mdot
.75058 .44206 Mdot
.37962 .35253 Mdot
.64778 .65333 Mdot
.57619 .37086 Mdot
.34322 .62517 Mdot
.60908 .63421 Mdot
.28361 .58402 Mdot
.68341 .51889 Mdot
.36634 .44805 Mdot
.25684 .48582 Mdot
.37553 .64006 Mdot
.35874 .43887 Mdot
.5135 .254 Mdot
.45249 .66745 Mdot
.68396 .53128 Mdot
.71893 .48746 Mdot
.60144 .6561 Mdot
.43751 .71772 Mdot
.66872 .67236 Mdot
.3763 .40104 Mdot
.75124 .45492 Mdot
.34669 .48807 Mdot
.63394 .66963 Mdot
.41278 .65783 Mdot
.38504 .40901 Mdot
.48726 .76122 Mdot
.67818 .67985 Mdot
.52255 .21495 Mdot
.40863 .66352 Mdot
.74849 .44316 Mdot
.35251 .51572 Mdot
.37241 .41694 Mdot
.5457 .74043 Mdot
.26972 .49949 Mdot
.42858 .66062 Mdot
.38163 .45608 Mdot
.51726 .77369 Mdot
.33458 .4666 Mdot
.30584 .57863 Mdot
.29007 .58307 Mdot
.2426 .49587 Mdot
.66769 .50851 Mdot
.46184 .7135 Mdot
.37936 .42731 Mdot
.37977 .39697 Mdot
.3983 .3733 Mdot
.39715 .44 Mdot
.28809 .58565 Mdot
.56079 .34483 Mdot
.65801 .67681 Mdot
.58812 .38514 Mdot
.67726 .67528 Mdot
.57306 .3795 Mdot
.33251 .4863 Mdot
.69386 .48345 Mdot
.45813 .69045 Mdot
.56603 .33969 Mdot
.67237 .68075 Mdot
.38234 .42695 Mdot
.63227 .67577 Mdot
.46916 .72185 Mdot
.30262 .59639 Mdot
.52785 .26618 Mdot
.51222 .20288 Mdot
.4297 .68721 Mdot
.39802 .51845 Mdot
.34786 .44894 Mdot
.36382 .42922 Mdot
.43932 .70701 Mdot
.72625 .47699 Mdot
.71567 .5347 Mdot
.45711 .71898 Mdot
.65319 .67736 Mdot
.47137 .75001 Mdot
.59208 .34599 Mdot
.72341 .48057 Mdot
.59646 .37443 Mdot
.55929 .35568 Mdot
.33891 .34514 Mdot
.40751 .40841 Mdot
.58759 .33548 Mdot
.69381 .47969 Mdot
.45336 .71721 Mdot
.62263 .64072 Mdot
.38088 .39441 Mdot
.42676 .66103 Mdot
.60477 .63472 Mdot
.54137 .28225 Mdot
.53938 .29096 Mdot
.41817 .66227 Mdot
.40865 .513 Mdot
.61559 .6657 Mdot
.62282 .62816 Mdot
.37749 .35493 Mdot
.41809 .65167 Mdot
.53487 .23217 Mdot
.61363 .627 Mdot
.6389 .41047 Mdot
.2967 .59906 Mdot
.35807 .33497 Mdot
.54909 .72988 Mdot
.37939 .35356 Mdot
.49892 .2805 Mdot
.51587 .25736 Mdot
.6057 .63291 Mdot
.34205 .43738 Mdot
.45277 .73492 Mdot
.42198 .65886 Mdot
.28452 .47085 Mdot
.5709 .33733 Mdot
.35104 .45486 Mdot
.58286 .39043 Mdot
.55883 .35275 Mdot
.38456 .43209 Mdot
.36454 .63426 Mdot
.45642 .69613 Mdot
.34336 .4751 Mdot
.71776 .45992 Mdot
.51647 .21583 Mdot
.63983 .67738 Mdot
.38509 .45026 Mdot
.40172 .38132 Mdot
.27837 .46718 Mdot
.63016 .63071 Mdot
.69874 .68601 Mdot
.77605 .43021 Mdot
.62422 .66237 Mdot
.6896 .69379 Mdot
.67797 .50302 Mdot
.27301 .47424 Mdot
.52378 .26341 Mdot
.5776 .35573 Mdot
.34385 .47003 Mdot
.38282 .35065 Mdot
.24173 .49262 Mdot
.49644 .25167 Mdot
.50885 .29531 Mdot
.53517 .73851 Mdot
.6988 .69679 Mdot
.34954 .429 Mdot
.30809 .60883 Mdot
.37023 .3453 Mdot
.58465 .64485 Mdot
.62994 .64512 Mdot
.72696 .48412 Mdot
.7286 .47559 Mdot
.7687 .42942 Mdot
.27829 .45949 Mdot
.25079 .47107 Mdot
.37047 .41239 Mdot
.58378 .3771 Mdot
.44648 .66224 Mdot
.51547 .25432 Mdot
.46264 .74317 Mdot
.54734 .73814 Mdot
.36619 .4989 Mdot
.27904 .58116 Mdot
.69903 .44955 Mdot
.6687 .53157 Mdot
.56371 .36115 Mdot
.52444 .23908 Mdot
.35816 .45055 Mdot
.4651 .70984 Mdot
.37393 .35016 Mdot
.59295 .35317 Mdot
.50192 .19877 Mdot
.46748 .73057 Mdot
.35827 .49264 Mdot
.60786 .63929 Mdot
.67222 .49761 Mdot
.33457 .46707 Mdot
.38804 .4166 Mdot
.41102 .66475 Mdot
.35781 .41233 Mdot
.28838 .60331 Mdot
.30016 .59244 Mdot
.76536 .43433 Mdot
.68631 .68493 Mdot
.6178 .65733 Mdot
.73977 .4684 Mdot
.42041 .66875 Mdot
.37624 .66199 Mdot
.6911 .49823 Mdot
.49517 .24204 Mdot
.62689 .66802 Mdot
.54197 .26402 Mdot
.69489 .4903 Mdot
.52139 .21992 Mdot
.25338 .48969 Mdot
.68907 .47575 Mdot
.53125 .27482 Mdot
.27675 .40238 Mdot
.56266 .35015 Mdot
.55388 .28229 Mdot
.61692 .65003 Mdot
.46223 .75684 Mdot
.34242 .46912 Mdot
.57658 .36419 Mdot
.6002 .37393 Mdot
.27444 .47727 Mdot
.56893 .38765 Mdot
.57957 .34262 Mdot
.27683 .47532 Mdot
.51108 .2349 Mdot
.56078 .69304 Mdot
.30663 .59062 Mdot
.46975 .74783 Mdot
.35756 .41359 Mdot
.69012 .6878 Mdot
.60407 .6342 Mdot
.35756 .44578 Mdot
.53746 .75081 Mdot
.62064 .65289 Mdot
.37459 .43741 Mdot
.59423 .63415 Mdot
.42878 .66213 Mdot
.36379 .49986 Mdot
.41164 .65342 Mdot
.38352 .43473 Mdot
.59371 .63395 Mdot
.73996 .46463 Mdot
.42945 .67731 Mdot
.37844 .42418 Mdot
.37053 .40914 Mdot
.58189 .37466 Mdot
.29956 .5952 Mdot
.64445 .6351 Mdot
.25456 .4767 Mdot
.67514 .52663 Mdot
.28946 .47266 Mdot
.53053 .29816 Mdot
.65119 .40683 Mdot
.41729 .65126 Mdot
.5672 .38597 Mdot
.69649 .49944 Mdot
.3901 .36506 Mdot
.36691 .48937 Mdot
.36669 .46067 Mdot
.58342 .34697 Mdot
.27439 .49829 Mdot
.63803 .6613 Mdot
.29359 .60303 Mdot
.60769 .37005 Mdot
.68701 .51843 Mdot
.57787 .38314 Mdot
.39062 .44857 Mdot
.4752 .72888 Mdot
.28768 .57194 Mdot
.67473 .50308 Mdot
.47479 .73967 Mdot
.34784 .48279 Mdot
.67514 .67372 Mdot
.56923 .31786 Mdot
.64255 .66336 Mdot
.29908 .57781 Mdot
.28808 .47375 Mdot
.75021 .45373 Mdot
.43176 .67662 Mdot
.61496 .63205 Mdot
.41266 .65628 Mdot
.38651 .36354 Mdot
.34484 .49998 Mdot
.40779 .64412 Mdot
.53133 .29211 Mdot
.77772 .41672 Mdot
.64058 .66936 Mdot
.59278 .37597 Mdot
.77493 .44059 Mdot
.48311 .75401 Mdot
.6978 .48438 Mdot
.43356 .48707 Mdot
.66914 .5136 Mdot
.28445 .57339 Mdot
.76422 .44879 Mdot
.2764 .46496 Mdot
.36949 .4645 Mdot
.69162 .5348 Mdot
.56249 .33964 Mdot
.39861 .41989 Mdot
.42926 .66435 Mdot
.30841 .34604 Mdot
.39393 .37927 Mdot
.27981 .46013 Mdot
.68573 .51705 Mdot
.41839 .50637 Mdot
.30172 .58765 Mdot
.29592 .57767 Mdot
.45686 .73485 Mdot
.58998 .36944 Mdot
.54771 .28044 Mdot
.54966 .28885 Mdot
.68015 .3876 Mdot
.25328 .50847 Mdot
.39233 .51733 Mdot
.42403 .66811 Mdot
.75873 .43308 Mdot
.48843 .76782 Mdot
.59119 .3504 Mdot
.62837 .63556 Mdot
.69974 .68357 Mdot
.33336 .47055 Mdot
.60068 .34215 Mdot
.27668 .59224 Mdot
.4746 .75778 Mdot
.4101 .65813 Mdot
.61725 .632 Mdot
.30003 .46217 Mdot
.37546 .38391 Mdot
.35174 .44706 Mdot
.63393 .63687 Mdot
.59793 .36591 Mdot
.26054 .48634 Mdot
.33372 .33313 Mdot
.71888 .66392 Mdot
.37237 .45417 Mdot
.38355 .64641 Mdot
.3598 .46858 Mdot
.34649 .34547 Mdot
.3617 .45417 Mdot
.42913 .66927 Mdot
.32613 .60336 Mdot
.40864 .38458 Mdot
.68693 .45635 Mdot
.36981 .49607 Mdot
.52653 .28485 Mdot
.38475 .41989 Mdot
.34884 .46066 Mdot
.54219 .2466 Mdot
.44526 .69561 Mdot
.40484 .3969 Mdot
.5599 .69144 Mdot
.3754 .4264 Mdot
.64126 .67853 Mdot
.26929 .49309 Mdot
.31961 .34566 Mdot
.29907 .58734 Mdot
.47697 .73228 Mdot
.60074 .62828 Mdot
.65156 .68249 Mdot
.58943 .39669 Mdot
.60379 .63403 Mdot
.376 .45806 Mdot
.26793 .49458 Mdot
.42869 .68678 Mdot
.56378 .34883 Mdot
.45801 .71118 Mdot
.57555 .29351 Mdot
.62404 .65182 Mdot
.57291 .37437 Mdot
.28972 .45632 Mdot
.63765 .65432 Mdot
.5629 .67835 Mdot
.30379 .59617 Mdot
.5984 .36785 Mdot
.48629 .74022 Mdot
.75502 .45308 Mdot
.58773 .3486 Mdot
.60955 .63337 Mdot
.36104 .46291 Mdot
.28839 .59177 Mdot
.60626 .63086 Mdot
.38723 .64875 Mdot
.30457 .6001 Mdot
.37439 .42874 Mdot
.44373 .68522 Mdot
.44559 .70787 Mdot
.33923 .47076 Mdot
.34537 .44004 Mdot
.69705 .51001 Mdot
.58743 .35098 Mdot
.58881 .35451 Mdot
.55745 .35911 Mdot
.67103 .513 Mdot
.78354 .41622 Mdot
.67923 .68679 Mdot
.31837 .3471 Mdot
.68741 .67754 Mdot
.57332 .3645 Mdot
.69878 .50837 Mdot
.36223 .46559 Mdot
.29778 .47195 Mdot
.59271 .63035 Mdot
.78909 .40867 Mdot
.33163 .47226 Mdot
.4594 .74462 Mdot
.64614 .64809 Mdot
.25174 .4727 Mdot
.75922 .43612 Mdot
.51374 .26929 Mdot
.39128 .51917 Mdot
.64333 .64584 Mdot
.40669 .66816 Mdot
.64296 .64579 Mdot
.34882 .4624 Mdot
.3996 .42793 Mdot
.45377 .74756 Mdot
.52631 .28533 Mdot
.2618 .47383 Mdot
.37693 .43971 Mdot
.75833 .4323 Mdot
.48962 .76738 Mdot
.5491 .292 Mdot
.25227 .48536 Mdot
.56166 .36561 Mdot
.51027 .25982 Mdot
.37567 .41172 Mdot
.27891 .47148 Mdot
.60387 .36227 Mdot
.59412 .63903 Mdot
.53249 .28955 Mdot
.69328 .45187 Mdot
.47052 .73758 Mdot
.68453 .68687 Mdot
.58458 .40051 Mdot
.64207 .67013 Mdot
.30961 .41908 Mdot
.56831 .37058 Mdot
.70774 .68185 Mdot
.44961 .18148 Mdot
.57308 .34435 Mdot
.68777 .52352 Mdot
.39528 .37531 Mdot
.27396 .47155 Mdot
.37467 .4294 Mdot
.54513 .28405 Mdot
.44435 .71286 Mdot
.69833 .69465 Mdot
.60981 .65382 Mdot
.39129 .421 Mdot
.41563 .64972 Mdot
.53031 .75196 Mdot
.58033 .38138 Mdot
.53405 .26109 Mdot
.54079 .26788 Mdot
.39248 .40797 Mdot
.27509 .50004 Mdot
.42689 .67102 Mdot
.37886 .42427 Mdot
.39271 .40543 Mdot
.76358 .44274 Mdot
.44876 .68589 Mdot
.6866 .47963 Mdot
.27896 .58569 Mdot
.36074 .51565 Mdot
.68272 .67669 Mdot
.60547 .64472 Mdot
.5921 .36629 Mdot
.62237 .6595 Mdot
.77639 .4319 Mdot
.5883 .35371 Mdot
.37885 .42346 Mdot
.4283 .6858 Mdot
.3793 .42503 Mdot
.37636 .4266 Mdot
.35779 .46 Mdot
.38744 .51825 Mdot
.67452 .47944 Mdot
.52944 .25598 Mdot
.25296 .48773 Mdot
.67529 .51139 Mdot
.70877 .44822 Mdot
.39783 .37187 Mdot
.3806 .41556 Mdot
.36562 .43319 Mdot
.41464 .67048 Mdot
.29179 .59967 Mdot
.6341 .65144 Mdot
.45458 .7486 Mdot
.33573 .46077 Mdot
.74283 .46489 Mdot
.40443 .39592 Mdot
.40792 .64495 Mdot
.67935 .69032 Mdot
.49599 .7762 Mdot
.58945 .40154 Mdot
.59762 .38365 Mdot
.58203 .34463 Mdot
.55694 .36131 Mdot
.64851 .68382 Mdot
.70022 .50738 Mdot
.55881 .31224 Mdot
.36112 .51355 Mdot
.34579 .43621 Mdot
.39743 .43442 Mdot
.76966 .44251 Mdot
.58113 .335 Mdot
.39717 .3797 Mdot
.29028 .56062 Mdot
.69109 .46744 Mdot
.56017 .34626 Mdot
.50715 .74829 Mdot
.47318 .73115 Mdot
.75586 .44117 Mdot
.61784 .66509 Mdot
.53107 .278 Mdot
.7428 .36543 Mdot
.45502 .71171 Mdot
.462 .68067 Mdot
.70157 .46696 Mdot
.2647 .49372 Mdot
.33611 .62289 Mdot
.7019 .48396 Mdot
.29697 .60518 Mdot
.43764 .7108 Mdot
.56117 .35131 Mdot
.27993 .49118 Mdot
.27505 .48022 Mdot
.73601 .45443 Mdot
.37405 .40613 Mdot
.67687 .54683 Mdot
.68767 .52078 Mdot
.58816 .36162 Mdot
.68579 .51661 Mdot
.63189 .66032 Mdot
.68668 .48923 Mdot
.3907 .65254 Mdot
.3896 .39649 Mdot
.34252 .62493 Mdot
.24922 .39133 Mdot
.34704 .44665 Mdot
.64694 .65873 Mdot
.68608 .6883 Mdot
.35375 .43382 Mdot
.52773 .22023 Mdot
.69184 .52059 Mdot
.77466 .42703 Mdot
.28549 .59196 Mdot
.76365 .448 Mdot
.47636 .73008 Mdot
.68384 .68316 Mdot
.68683 .68816 Mdot
.58601 .34746 Mdot
.42147 .65445 Mdot
.68857 .69863 Mdot
.65452 .67803 Mdot
.57292 .3195 Mdot
.34064 .46949 Mdot
.4556 .69814 Mdot
.26104 .48631 Mdot
.51656 .21762 Mdot
.37417 .42581 Mdot
.68504 .48292 Mdot
.771 .43121 Mdot
.25259 .39284 Mdot
.6909 .50138 Mdot
.59299 .37077 Mdot
.4514 .69152 Mdot
.28245 .58578 Mdot
.45099 .71391 Mdot
.37221 .40077 Mdot
.68774 .68575 Mdot
.47484 .73273 Mdot
.49495 .24563 Mdot
.36206 .44061 Mdot
.36204 .63107 Mdot
.24823 .48886 Mdot
.37333 .42833 Mdot
.71808 .49296 Mdot
.53977 .24119 Mdot
.50636 .26166 Mdot
.68803 .46015 Mdot
.5177 .23388 Mdot
.49233 .74278 Mdot
.72122 .48697 Mdot
.53381 .24307 Mdot
.68272 .38745 Mdot
.56421 .38202 Mdot
.53003 .24858 Mdot
.38147 .4559 Mdot
.60186 .63321 Mdot
.44427 .73385 Mdot
.39724 .42863 Mdot
.4553 .4103 Mdot
.31141 .62457 Mdot
.58067 .37677 Mdot
.37117 .43091 Mdot
.34744 .45938 Mdot
.41515 .65117 Mdot
.55105 .7313 Mdot
.68382 .52816 Mdot
.59099 .38132 Mdot
.45638 .71504 Mdot
.54505 .74176 Mdot
.71663 .49375 Mdot
.54139 .25504 Mdot
.60258 .64684 Mdot
.41828 .68059 Mdot
.57833 .3713 Mdot
.61572 .64878 Mdot
.68511 .46467 Mdot
.38334 .35534 Mdot
.30917 .57506 Mdot
.7082 .47121 Mdot
.38006 .35311 Mdot
.27688 .58499 Mdot
.76712 .43004 Mdot
.58606 .64752 Mdot
.46729 .71965 Mdot
.61214 .62918 Mdot
.5366 .26837 Mdot
.41032 .65547 Mdot
.45869 .71183 Mdot
.60571 .64527 Mdot
.32358 .62455 Mdot
.28485 .48915 Mdot
.67686 .67997 Mdot
.25757 .49701 Mdot
.37968 .35608 Mdot
.57967 .36935 Mdot
.52595 .26035 Mdot
.68576 .68412 Mdot
.43222 .68005 Mdot
.68298 .665 Mdot
.3808 .3504 Mdot
.2973 .60225 Mdot
.52776 .27855 Mdot
.53042 .74394 Mdot
.5908 .64865 Mdot
.63192 .6519 Mdot
.75893 .43195 Mdot
.53203 .22444 Mdot
.37352 .46216 Mdot
.79482 .40619 Mdot
.38573 .44782 Mdot
.6453 .64152 Mdot
.27768 .59389 Mdot
.46503 .73509 Mdot
.6717 .67527 Mdot
.28011 .57661 Mdot
.2538 .47874 Mdot
.34968 .43446 Mdot
.76464 .43567 Mdot
.43727 .7243 Mdot
.55591 .33337 Mdot
.34668 .45 Mdot
.3739 .44196 Mdot
.60109 .37384 Mdot
.32256 .34598 Mdot
.57498 .64843 Mdot
.5752 .3363 Mdot
.69511 .46683 Mdot
.56399 .34708 Mdot
.59065 .37507 Mdot
.48279 .73525 Mdot
.76305 .4308 Mdot
.60002 .38059 Mdot
.38098 .44098 Mdot
.38159 .43084 Mdot
.59737 .62918 Mdot
.27646 .49607 Mdot
.27041 .48327 Mdot
.67609 .52742 Mdot
.58421 .32558 Mdot
.40276 .40429 Mdot
.42808 .66049 Mdot
.54323 .29024 Mdot
.59335 .39325 Mdot
.47146 .74236 Mdot
.40157 .43171 Mdot
.76394 .443 Mdot
.5692 .34677 Mdot
.60327 .38604 Mdot
.52861 .27498 Mdot
.62727 .62884 Mdot
.38886 .63739 Mdot
.68808 .52174 Mdot
.30769 .57645 Mdot
.59785 .3251 Mdot
.75595 .44396 Mdot
.58097 .36929 Mdot
.56667 .37239 Mdot
.42072 .65501 Mdot
.3888 .64806 Mdot
.60296 .39993 Mdot
.67466 .51554 Mdot
.71815 .68558 Mdot
.65989 .67354 Mdot
.28517 .47336 Mdot
.61887 .65625 Mdot
.4681 .72014 Mdot
.33789 .34376 Mdot
.54104 .2629 Mdot
.63572 .6549 Mdot
.58085 .34217 Mdot
.46451 .71875 Mdot
.395 .64575 Mdot
.38427 .43555 Mdot
.37573 .42023 Mdot
.73954 .46767 Mdot
.36229 .34046 Mdot
.59398 .62836 Mdot
.54755 .27669 Mdot
.7039 .50825 Mdot
.28644 .59074 Mdot
.45436 .7372 Mdot
.53946 .33968 Mdot
.2442 .49023 Mdot
.67764 .51425 Mdot
.44316 .71876 Mdot
.55017 .28236 Mdot
.53004 .25462 Mdot
.34143 .45983 Mdot
.50195 .28806 Mdot
.6339 .65724 Mdot
.4273 .66305 Mdot
.49691 .75725 Mdot
.26276 .47835 Mdot
.3802 .41781 Mdot
.28828 .60082 Mdot
.68645 .6975 Mdot
.38227 .4544 Mdot
.53396 .28383 Mdot
.43674 .71201 Mdot
.36588 .46448 Mdot
.53825 .2312 Mdot
.55657 .33268 Mdot
.56544 .36275 Mdot
.6961 .53221 Mdot
.54965 .26174 Mdot
.53978 .23583 Mdot
.53741 .22837 Mdot
.69985 .68346 Mdot
.25202 .47352 Mdot
.58269 .30762 Mdot
.37443 .40645 Mdot
.3799 .35719 Mdot
.31281 .58535 Mdot
.65569 .66948 Mdot
.74891 .45302 Mdot
.3538 .45496 Mdot
.37211 .40854 Mdot
.45804 .75704 Mdot
.29465 .56559 Mdot
.34647 .47495 Mdot
.46483 .74089 Mdot
.48322 .71904 Mdot
.71985 .49824 Mdot
.54788 .7301 Mdot
.79703 .39867 Mdot
.25011 .49328 Mdot
.2536 .50007 Mdot
.44969 .701 Mdot
.59731 .63871 Mdot
.25355 .49845 Mdot
.63188 .63114 Mdot
.44127 .70271 Mdot
.30324 .56611 Mdot
.38802 .64987 Mdot
.51313 .25493 Mdot
.3495 .46288 Mdot
.6125 .64978 Mdot
.35047 .45891 Mdot
.60823 .64824 Mdot
.4178 .51011 Mdot
.26538 .50321 Mdot
.3467 .4304 Mdot
.39246 .44846 Mdot
.49394 .26046 Mdot
.37811 .41743 Mdot
.75843 .43083 Mdot
.45037 .7286 Mdot
.59065 .3348 Mdot
.31584 .58062 Mdot
.39703 .37801 Mdot
.36639 .43141 Mdot
.3049 .62362 Mdot
.3625 .42861 Mdot
.79451 .40985 Mdot
.24741 .49247 Mdot
.3451 .47303 Mdot
.63116 .64361 Mdot
.64173 .67239 Mdot
.42548 .68517 Mdot
.56805 .37341 Mdot
.53304 .74169 Mdot
.37578 .43648 Mdot
.69863 .52458 Mdot
.50594 .22998 Mdot
.54404 .24646 Mdot
.44325 .72811 Mdot
.44367 .18679 Mdot
.65635 .6883 Mdot
.71912 .45708 Mdot
.30767 .59093 Mdot
.69015 .47294 Mdot
.68089 .53015 Mdot
.49341 .76767 Mdot
.52683 .25958 Mdot
.4024 .39377 Mdot
.37801 .64198 Mdot
.48018 .70966 Mdot
.26474 .47709 Mdot
.7159 .50357 Mdot
.60394 .36271 Mdot
.25361 .53005 Mdot
.51443 .22664 Mdot
.52306 .23179 Mdot
.60603 .64018 Mdot
.69779 .52626 Mdot
.59069 .37988 Mdot
.53696 .24901 Mdot
.724 .48918 Mdot
.57232 .39271 Mdot
.77218 .42296 Mdot
.42595 .66811 Mdot
.42217 .50127 Mdot
.35681 .63272 Mdot
.64699 .66682 Mdot
.75469 .43759 Mdot
.41991 .66995 Mdot
.41414 .64652 Mdot
.58631 .37612 Mdot
.70527 .45702 Mdot
.42826 .65129 Mdot
.34322 .46569 Mdot
.56265 .35482 Mdot
.39441 .41981 Mdot
.52181 .21346 Mdot
.37786 .43282 Mdot
.7421 .46178 Mdot
.63914 .65003 Mdot
.69241 .51258 Mdot
.60741 .64327 Mdot
.31435 .34662 Mdot
.36666 .44247 Mdot
.38277 .41988 Mdot
.26928 .49235 Mdot
.47359 .71937 Mdot
.38306 .64873 Mdot
.68019 .51639 Mdot
.69013 .51487 Mdot
.31504 .57906 Mdot
.46825 .75128 Mdot
.58725 .40874 Mdot
.2551 .49744 Mdot
.36302 .42548 Mdot
.45121 .72813 Mdot
.31412 .59175 Mdot
.71441 .69109 Mdot
.27478 .49316 Mdot
.479 .72964 Mdot
.78476 .41686 Mdot
.39289 .40331 Mdot
.59129 .38629 Mdot
.57796 .32688 Mdot
.24952 .50764 Mdot
.51767 .21715 Mdot
.46919 .73321 Mdot
.58591 .3885 Mdot
.44946 .73309 Mdot
.66931 .51677 Mdot
.67416 .69672 Mdot
.46012 .73453 Mdot
.36252 .4329 Mdot
.79566 .39816 Mdot
.59986 .63551 Mdot
.35502 .46633 Mdot
.67248 .67765 Mdot
.41084 .66087 Mdot
.45273 .71977 Mdot
.57301 .3933 Mdot
.29683 .60472 Mdot
.63572 .65676 Mdot
.34233 .44028 Mdot
.38944 .6533 Mdot
.2881 .57143 Mdot
.51523 .21858 Mdot
.40447 .40747 Mdot
.34022 .49051 Mdot
.76085 .42743 Mdot
.39335 .36323 Mdot
.69235 .69253 Mdot
.63578 .67655 Mdot
.70185 .69361 Mdot
.47815 .72297 Mdot
.51039 .27728 Mdot
.39129 .64088 Mdot
.59329 .36668 Mdot
.71094 .45711 Mdot
.35618 .46147 Mdot
.55605 .35957 Mdot
.68167 .6862 Mdot
.526 .24744 Mdot
.24191 .49265 Mdot
.71232 .47357 Mdot
.56647 .38043 Mdot
.62722 .65197 Mdot
.43416 .68275 Mdot
.46816 .73937 Mdot
.77899 .42022 Mdot
.36151 .46676 Mdot
.37661 .42145 Mdot
.67219 .68614 Mdot
.51143 .30183 Mdot
.51895 .23075 Mdot
.56273 .33944 Mdot
.67288 .6847 Mdot
.27308 .49547 Mdot
.40718 .66028 Mdot
.34654 .46566 Mdot
.26718 .49691 Mdot
.69784 .68851 Mdot
.49468 .72338 Mdot
.51685 .24046 Mdot
.34518 .50619 Mdot
.46818 .7314 Mdot
.62126 .63922 Mdot
.68072 .3913 Mdot
.28175 .59578 Mdot
.3588 .41915 Mdot
.36035 .49784 Mdot
.28071 .47551 Mdot
.30663 .58221 Mdot
.5876 .40112 Mdot
.35066 .49443 Mdot
.31612 .58265 Mdot
.30141 .5693 Mdot
.40271 .41921 Mdot
.40403 .41599 Mdot
.4524 .72487 Mdot
.27902 .46068 Mdot
.69001 .47955 Mdot
.29868 .60671 Mdot
.53798 .33189 Mdot
.30493 .59072 Mdot
.28816 .4709 Mdot
.49987 .73067 Mdot
.28148 .50264 Mdot
.43581 .70355 Mdot
.48357 .75238 Mdot
.64451 .66633 Mdot
.28609 .57304 Mdot
.6775 .51552 Mdot
.60702 .38022 Mdot
.75142 .44966 Mdot
.45058 .72409 Mdot
.72178 .49261 Mdot
.6019 .6562 Mdot
.70839 .47106 Mdot
.68908 .47062 Mdot
.64091 .65011 Mdot
.44837 .74288 Mdot
.24565 .48871 Mdot
.6423 .65156 Mdot
.60344 .37928 Mdot
.54114 .25664 Mdot
.47816 .70883 Mdot
.5673 .33661 Mdot
.33228 .47942 Mdot
.7145 .67473 Mdot
.71316 .46414 Mdot
.36496 .49783 Mdot
.47733 .75907 Mdot
.55269 .28285 Mdot
.46021 .73168 Mdot
.59777 .40601 Mdot
.5148 .2614 Mdot
.38255 .45632 Mdot
.53422 .32823 Mdot
.584 .64546 Mdot
.40102 .38468 Mdot
.48496 .72172 Mdot
.75152 .44873 Mdot
.64407 .66199 Mdot
.56359 .6742 Mdot
.59019 .38452 Mdot
.48002 .73835 Mdot
.38698 .64335 Mdot
.59018 .35861 Mdot
.62336 .64143 Mdot
.36407 .62627 Mdot
.34371 .45912 Mdot
.63084 .66214 Mdot
.40336 .40363 Mdot
.40449 .51515 Mdot
.54015 .29647 Mdot
.5577 .35756 Mdot
.2951 .5643 Mdot
.71933 .48511 Mdot
.31236 .57438 Mdot
.33599 .44489 Mdot
.34483 .33755 Mdot
.36494 .41676 Mdot
.36577 .49577 Mdot
.7782 .43156 Mdot
.43092 .68864 Mdot
.57093 .35452 Mdot
.58076 .37224 Mdot
.28513 .57098 Mdot
.78998 .36498 Mdot
.52834 .24087 Mdot
.77529 .41974 Mdot
.36878 .44127 Mdot
.37119 .41866 Mdot
.39873 .65159 Mdot
.42757 .49796 Mdot
.56055 .35028 Mdot
.3591 .42166 Mdot
.25962 .50935 Mdot
.62609 .63792 Mdot
.33927 .48694 Mdot
.3927 .40932 Mdot
.69212 .69866 Mdot
.62782 .64178 Mdot
.76146 .44064 Mdot
.56412 .3826 Mdot
.69448 .53419 Mdot
.51625 .22808 Mdot
.35604 .49529 Mdot
.32855 .34395 Mdot
.28663 .48335 Mdot
.51416 .23825 Mdot
.30141 .58984 Mdot
.32935 .47103 Mdot
.3803 .40026 Mdot
.52401 .23309 Mdot
.59327 .64205 Mdot
.45395 .72982 Mdot
.41155 .51114 Mdot
.58236 .3728 Mdot
.30288 .57166 Mdot
.52535 .21318 Mdot
.44861 .73145 Mdot
.36555 .63503 Mdot
.44549 .71539 Mdot
.62545 .64922 Mdot
.76038 .43452 Mdot
.51467 .26421 Mdot
.46081 .73254 Mdot
.72571 .47329 Mdot
.68414 .68015 Mdot
.28254 .46669 Mdot
.59339 .6472 Mdot
.49255 .76777 Mdot
.4828 .74112 Mdot
.48995 .75335 Mdot
.28364 .59172 Mdot
.36708 .49486 Mdot
.594 .37092 Mdot
.67434 .68568 Mdot
.71843 .4831 Mdot
.35914 .34042 Mdot
.37789 .64639 Mdot
.39327 .45484 Mdot
.38829 .45173 Mdot
.37889 .43285 Mdot
.38629 .40727 Mdot
.59246 .40137 Mdot
.33608 .45127 Mdot
.37671 .40579 Mdot
.59274 .62862 Mdot
.75804 .44245 Mdot
.37027 .44303 Mdot
.56585 .36006 Mdot
.6007 .34096 Mdot
.55268 .28383 Mdot
.37791 .51986 Mdot
.44119 .6569 Mdot
.4567 .73597 Mdot
.67514 .50599 Mdot
.70892 .51645 Mdot
.54058 .28565 Mdot
.62752 .63468 Mdot
.44353 .71084 Mdot
.78796 .41058 Mdot
.51579 .27266 Mdot
.3741 .45126 Mdot
.27023 .49135 Mdot
.28644 .49732 Mdot
.27651 .47056 Mdot
.35788 .45887 Mdot
.57142 .34088 Mdot
.67354 .51194 Mdot
.26942 .46611 Mdot
.36271 .63022 Mdot
.53335 .22556 Mdot
.54398 .25843 Mdot
.4598 .69402 Mdot
.34454 .42828 Mdot
.61557 .65117 Mdot
.27149 .50116 Mdot
.64223 .63283 Mdot
.51938 .7639 Mdot
.57738 .29825 Mdot
.40442 .39538 Mdot
.39913 .37566 Mdot
.33336 .46932 Mdot
.45815 .69052 Mdot
.40692 .66942 Mdot
.42804 .67793 Mdot
.62462 .63612 Mdot
.38561 .35956 Mdot
.65644 .68418 Mdot
.56 .352 Mdot
.47394 .7338 Mdot
.23227 .48839 Mdot
.69026 .51418 Mdot
.30063 .5668 Mdot
.52177 .26711 Mdot
.26674 .47992 Mdot
.57128 .35981 Mdot
.34803 .50343 Mdot
.69957 .50689 Mdot
.41185 .66472 Mdot
.30392 .56847 Mdot
.67921 .46983 Mdot
.3506 .49366 Mdot
.55356 .3153 Mdot
.55553 .35388 Mdot
.51345 .2548 Mdot
.39619 .3718 Mdot
.52576 .28139 Mdot
.63349 .65584 Mdot
.36393 .44314 Mdot
.34417 .47246 Mdot
.36951 .42869 Mdot
.38956 .44799 Mdot
.61349 .63308 Mdot
.28946 .5742 Mdot
.60181 .36485 Mdot
.55944 .37231 Mdot
.30614 .58831 Mdot
.52486 .25559 Mdot
.65915 .67373 Mdot
.75933 .44316 Mdot
.59111 .35144 Mdot
.51777 .28303 Mdot
.40016 .38327 Mdot
.35841 .42912 Mdot
.56059 .37078 Mdot
.38279 .45499 Mdot
.28726 .58126 Mdot
.70188 .4728 Mdot
.29954 .57308 Mdot
.55213 .26965 Mdot
.52287 .27089 Mdot
.60337 .63273 Mdot
.46144 .73424 Mdot
.53964 .2826 Mdot
.70563 .50304 Mdot
.33631 .47423 Mdot
.40445 .40997 Mdot
.38948 .65094 Mdot
.38223 .35026 Mdot
.55131 .26487 Mdot
.37576 .46078 Mdot
.44529 .68246 Mdot
.37949 .62799 Mdot
.36058 .41758 Mdot
.29166 .58351 Mdot
.48431 .73952 Mdot
.53922 .25281 Mdot
.62851 .63374 Mdot
.26048 .37588 Mdot
.63275 .63213 Mdot
.43388 .68094 Mdot
.58619 .38634 Mdot
.45819 .75337 Mdot
.58869 .38718 Mdot
.5034 .72474 Mdot
.3918 .40016 Mdot
.39489 .65842 Mdot
.59454 .34766 Mdot
.67993 .51891 Mdot
.69739 .46002 Mdot
.56994 .3476 Mdot
.47137 .73435 Mdot
.59139 .36704 Mdot
.53497 .27559 Mdot
.69475 .68021 Mdot
.48575 .75135 Mdot
.69143 .46774 Mdot
.71346 .46552 Mdot
.67408 .68738 Mdot
.37346 .43237 Mdot
.34596 .46407 Mdot
.70808 .47482 Mdot
.64639 .63691 Mdot
.45823 .7072 Mdot
.37758 .42133 Mdot
.58045 .33946 Mdot
.69416 .47653 Mdot
.61764 .67216 Mdot
.40293 .65138 Mdot
.29949 .56388 Mdot
.34141 .33767 Mdot
.64177 .67941 Mdot
.33808 .4793 Mdot
.28812 .58442 Mdot
.53169 .23444 Mdot
.34728 .5061 Mdot
.37737 .35572 Mdot
.6372 .67513 Mdot
.59735 .3817 Mdot
.27497 .47038 Mdot
.66916 .49891 Mdot
.34133 .47715 Mdot
.4636 .1784 Mdot
.56003 .36765 Mdot
.3836 .44547 Mdot
.56865 .32813 Mdot
.45195 .71475 Mdot
.37186 .42406 Mdot
.68343 .67782 Mdot
.67842 .50812 Mdot
.36152 .46652 Mdot
.49393 .24559 Mdot
.67041 .67417 Mdot
.57111 .36108 Mdot
.51827 .23339 Mdot
.30765 .59874 Mdot
.30882 .34643 Mdot
.77013 .4421 Mdot
.53211 .25329 Mdot
.3708 .43349 Mdot
.70178 .51197 Mdot
.64099 .67109 Mdot
.57094 .3518 Mdot
.3996 .38406 Mdot
.65642 .67628 Mdot
.63621 .64366 Mdot
.52256 .2769 Mdot
.37998 .6681 Mdot
.38825 .39141 Mdot
.38856 .42911 Mdot
.38208 .65852 Mdot
.391 .64488 Mdot
.35065 .46221 Mdot
.39703 .41785 Mdot
.61561 .64943 Mdot
.39387 .3566 Mdot
.34882 .50355 Mdot
.59321 .34498 Mdot
.64687 .66251 Mdot
.71091 .51576 Mdot
.71253 .45972 Mdot
.53685 .25947 Mdot
.44186 .71595 Mdot
.53519 .29348 Mdot
.68204 .49648 Mdot
.37936 .44476 Mdot
.64152 .63921 Mdot
.28276 .55135 Mdot
.67606 .68111 Mdot
.70773 .49397 Mdot
.40931 .6471 Mdot
.29797 .46706 Mdot
.46099 .17853 Mdot
.56652 .65164 Mdot
.77871 .42267 Mdot
.54363 .24594 Mdot
.3629 .6302 Mdot
.36755 .4375 Mdot
.28169 .46311 Mdot
.36095 .46533 Mdot
.51936 .29369 Mdot
.75837 .44956 Mdot
.57242 .39283 Mdot
.59059 .38404 Mdot
.35959 .49449 Mdot
.63648 .64282 Mdot
.65383 .68478 Mdot
.57526 .3852 Mdot
.62671 .64793 Mdot
.39005 .43029 Mdot
.70327 .49331 Mdot
.50813 .74179 Mdot
.36242 .42677 Mdot
.57189 .31799 Mdot
.60238 .65777 Mdot
.40548 .64114 Mdot
.71389 .50965 Mdot
.39941 .37645 Mdot
.53786 .73657 Mdot
.63887 .65562 Mdot
.37824 .51881 Mdot
.67881 .5122 Mdot
.58984 .34964 Mdot
.69801 .51737 Mdot
.38314 .44399 Mdot
.40514 .39578 Mdot
.6014 .37702 Mdot
.36403 .42624 Mdot
.41179 .6819 Mdot
.28296 .59804 Mdot
.28957 .55792 Mdot
.37443 .40606 Mdot
.48145 .71983 Mdot
.62787 .6659 Mdot
.5777 .38677 Mdot
.28097 .47484 Mdot
.40365 .42558 Mdot
.48201 .7287 Mdot
.65547 .67251 Mdot
.55473 .72376 Mdot
.61999 .63481 Mdot
.67915 .5203 Mdot
.63183 .63746 Mdot
.33357 .47058 Mdot
.44244 .70132 Mdot
.6902 .49356 Mdot
.57433 .36722 Mdot
.72734 .46105 Mdot
.34704 .44875 Mdot
.59743 .65755 Mdot
.71658 .4574 Mdot
.29116 .60194 Mdot
.44358 .70468 Mdot
.52544 .31819 Mdot
.44905 .6639 Mdot
.38162 .44292 Mdot
.35964 .46454 Mdot
.56287 .34058 Mdot
.60634 .63238 Mdot
.39736 .64709 Mdot
.76825 .42471 Mdot
.55261 .27738 Mdot
.43608 .70295 Mdot
.54437 .29196 Mdot
.26474 .49324 Mdot
.42845 .68371 Mdot
.25872 .50911 Mdot
.603 .64306 Mdot
.46984 .738 Mdot
.51698 .20645 Mdot
.30735 .60895 Mdot
.52886 .26322 Mdot
.71171 .50922 Mdot
.25288 .49898 Mdot
.69664 .46849 Mdot
.68955 .68877 Mdot
.76798 .43274 Mdot
.63929 .65898 Mdot
.49422 .24892 Mdot
.27807 .5948 Mdot
.6253 .66902 Mdot
.68528 .6759 Mdot
.68272 .48845 Mdot
.56948 .37888 Mdot
.29452 .57416 Mdot
.60138 .39459 Mdot
.57803 .391 Mdot
.65041 .68355 Mdot
.47004 .74197 Mdot
.4642 .74868 Mdot
.58882 .33253 Mdot
.46702 .74112 Mdot
.69899 .48223 Mdot
.27287 .49325 Mdot
.29134 .45628 Mdot
.62463 .66471 Mdot
.30868 .59733 Mdot
.33561 .48856 Mdot
.76197 .45073 Mdot
.7015 .48907 Mdot
.63013 .63898 Mdot
.50172 .76089 Mdot
.59024 .39017 Mdot
.40438 .65101 Mdot
.45818 .71452 Mdot
.45591 .71829 Mdot
.4713 .76253 Mdot
.38455 .35679 Mdot
.64734 .65905 Mdot
.46912 .73049 Mdot
.40061 .41548 Mdot
.3955 .40787 Mdot
.59168 .35399 Mdot
.51164 .28051 Mdot
.29292 .57966 Mdot
.59414 .37335 Mdot
.35277 .43223 Mdot
.6859 .51628 Mdot
.50361 .25177 Mdot
.5976 .38943 Mdot
.67536 .51475 Mdot
.67442 .51667 Mdot
.59329 .39635 Mdot
.50456 .25542 Mdot
.41088 .68033 Mdot
.30336 .61405 Mdot
.48193 .71905 Mdot
.71266 .45323 Mdot
.69536 .69372 Mdot
.39124 .65417 Mdot
.35706 .47026 Mdot
.56887 .33256 Mdot
.69806 .50583 Mdot
.48553 .75505 Mdot
.38286 .41424 Mdot
.58687 .37435 Mdot
.53284 .26814 Mdot
.57257 .36848 Mdot
.56935 .34012 Mdot
.46151 .70112 Mdot
.71018 .65434 Mdot
.4156 .65033 Mdot
.67886 .47354 Mdot
.57538 .35986 Mdot
.3411 .62458 Mdot
.74719 .44835 Mdot
.69423 .67837 Mdot
.28443 .60136 Mdot
.36777 .40867 Mdot
.67531 .50422 Mdot
.47622 .72952 Mdot
.58982 .63478 Mdot
.27223 .50808 Mdot
.46194 .73334 Mdot
.58389 .40057 Mdot
.56885 .34424 Mdot
.69256 .47673 Mdot
.43737 .68487 Mdot
.28876 .58513 Mdot
.46333 .72828 Mdot
.66716 .68385 Mdot
.37359 .46404 Mdot
.53364 .74056 Mdot
.59039 .37885 Mdot
.45978 .74251 Mdot
.71642 .48628 Mdot
.53344 .28443 Mdot
.38094 .45406 Mdot
.53916 .7479 Mdot
.36786 .43275 Mdot
.67046 .68704 Mdot
.59279 .32729 Mdot
.31334 .60108 Mdot
.3632 .45531 Mdot
.28468 .46937 Mdot
.67188 .67188 Mdot
.3604 .45346 Mdot
.29466 .47417 Mdot
.36103 .63303 Mdot
.41674 .66122 Mdot
.37111 .44137 Mdot
.70581 .47753 Mdot
.68432 .55595 Mdot
.39278 .41573 Mdot
.67591 .47255 Mdot
.27536 .50066 Mdot
.60642 .38418 Mdot
.51265 .21982 Mdot
.3391 .34351 Mdot
.3739 .4553 Mdot
.34747 .42965 Mdot
.37477 .46377 Mdot
.30738 .45245 Mdot
.67987 .50297 Mdot
.69366 .53298 Mdot
.5379 .27437 Mdot
.35891 .50048 Mdot
.52459 .27345 Mdot
.63994 .67045 Mdot
.27833 .5807 Mdot
.55629 .36468 Mdot
.46096 .73794 Mdot
.36835 .42715 Mdot
.71031 .50738 Mdot
.38093 .44799 Mdot
.29312 .59494 Mdot
.69692 .47958 Mdot
.69493 .51068 Mdot
.67138 .53676 Mdot
.54435 .24438 Mdot
.44498 .72577 Mdot
.3384 .45636 Mdot
.52892 .22328 Mdot
.60226 .38461 Mdot
.24808 .38729 Mdot
.43666 .7071 Mdot
.45112 .73632 Mdot
.45981 .75286 Mdot
.33922 .44728 Mdot
.33797 .45138 Mdot
.66312 .68562 Mdot
.38338 .64279 Mdot
.64646 .64253 Mdot
.67633 .49723 Mdot
.66653 .50479 Mdot
.3779 .45168 Mdot
.54081 .30557 Mdot
.52497 .25785 Mdot
.7231 .46225 Mdot
.55798 .35014 Mdot
.53164 .288 Mdot
.34223 .44633 Mdot
.68857 .47736 Mdot
.53301 .22271 Mdot
.5008 .76597 Mdot
.55666 .70719 Mdot
.53199 .28584 Mdot
.59211 .38178 Mdot
.37281 .63731 Mdot
.35314 .34157 Mdot
.54085 .29514 Mdot
.63002 .66727 Mdot
.24401 .49038 Mdot
.55754 .35388 Mdot
.52131 .28628 Mdot
.3694 .33922 Mdot
.68745 .48959 Mdot
.5931 .38268 Mdot
.51105 .20369 Mdot
.28651 .45598 Mdot
.52527 .28555 Mdot
.45468 .73959 Mdot
.3961 .63195 Mdot
.3659 .45825 Mdot
.30142 .60324 Mdot
.60488 .6515 Mdot
.71395 .50526 Mdot
.70341 .52194 Mdot
.40516 .66593 Mdot
.28092 .48522 Mdot
.70553 .4692 Mdot
.28395 .47356 Mdot
.51238 .27455 Mdot
.40091 .41452 Mdot
.5946 .33855 Mdot
.31107 .60742 Mdot
.52154 .20811 Mdot
.53264 .28516 Mdot
.61764 .66114 Mdot
.63809 .6495 Mdot
.60716 .63326 Mdot
.70205 .46991 Mdot
.26615 .48739 Mdot
.69446 .53079 Mdot
.37315 .65959 Mdot
.52984 .24269 Mdot
.78667 .41548 Mdot
.33237 .46775 Mdot
.35189 .43156 Mdot
.31186 .58056 Mdot
.57369 .33673 Mdot
.38207 .44378 Mdot
.65719 .6785 Mdot
.72595 .47223 Mdot
.59535 .65658 Mdot
.44642 .68818 Mdot
.37175 .65605 Mdot
.69183 .51114 Mdot
.56775 .31924 Mdot
.52199 .26373 Mdot
.32829 .33279 Mdot
.52027 .29629 Mdot
.68708 .52326 Mdot
.3731 .40097 Mdot
.48714 .75056 Mdot
.78456 .41004 Mdot
.37215 .42591 Mdot
.71474 .46355 Mdot
.73741 .46953 Mdot
.30755 .60608 Mdot
.39583 .36666 Mdot
.58659 .64699 Mdot
.2804 .48061 Mdot
.54436 .24193 Mdot
.60148 .37309 Mdot
.22999 .49784 Mdot
.68141 .49593 Mdot
.73063 .46153 Mdot
.54323 .28865 Mdot
.40581 .642 Mdot
.47548 .75443 Mdot
.41202 .68033 Mdot
.65941 .68136 Mdot
.38654 .39846 Mdot
.68883 .47842 Mdot
.40564 .64741 Mdot
.33982 .49238 Mdot
.61171 .64375 Mdot
.72358 .45766 Mdot
.36435 .42606 Mdot
.36703 .45384 Mdot
.52703 .27352 Mdot
.6005 .34014 Mdot
.59521 .35231 Mdot
.69069 .67534 Mdot
.37245 .47489 Mdot
.27998 .57726 Mdot
.35937 .41839 Mdot
.46108 .70839 Mdot
.59082 .36176 Mdot
.52699 .25863 Mdot
.34674 .47886 Mdot
.28763 .46478 Mdot
.48175 .7397 Mdot
.60594 .64551 Mdot
.57851 .36572 Mdot
.36782 .48524 Mdot
.36452 .42958 Mdot
.36691 .46224 Mdot
.28376 .59183 Mdot
.33389 .45569 Mdot
.75005 .45273 Mdot
.42611 .6576 Mdot
.52446 .22505 Mdot
.44986 .71768 Mdot
.76498 .4285 Mdot
.28162 .59745 Mdot
.25589 .48763 Mdot
.46999 .71017 Mdot
.44051 .70381 Mdot
.66985 .6852 Mdot
.6445 .65756 Mdot
.5571 .31282 Mdot
.39409 .43448 Mdot
.55941 .36122 Mdot
.46452 .72452 Mdot
.71218 .50851 Mdot
.52409 .27442 Mdot
.78015 .42099 Mdot
.36509 .41584 Mdot
.68418 .48773 Mdot
.57467 .35043 Mdot
.45358 .69301 Mdot
.68392 .51411 Mdot
.58918 .34882 Mdot
.54059 .25242 Mdot
.25091 .48125 Mdot
.55669 .31547 Mdot
.58485 .3845 Mdot
.39475 .43507 Mdot
.30108 .55378 Mdot
.30494 .60117 Mdot
.59462 .34641 Mdot
.72324 .49176 Mdot
.58479 .37987 Mdot
.39337 .63564 Mdot
.30488 .60564 Mdot
.72004 .4849 Mdot
.387 .6486 Mdot
.28514 .60154 Mdot
.58743 .38766 Mdot
.43683 .71048 Mdot
.75669 .43413 Mdot
.49352 .75394 Mdot
.36107 .34778 Mdot
.38947 .41169 Mdot
.69744 .46778 Mdot
.52994 .26492 Mdot
.66597 .69056 Mdot
.63759 .67907 Mdot
.68285 .67522 Mdot
.67791 .48406 Mdot
.3675 .42555 Mdot
.46884 .73438 Mdot
.637 .65412 Mdot
.39664 .649 Mdot
.7073 .50322 Mdot
.70574 .48619 Mdot
.31085 .57948 Mdot
.52295 .27298 Mdot
.33292 .46454 Mdot
.71107 .51006 Mdot
.76263 .43614 Mdot
.3582 .62558 Mdot
.53451 .22313 Mdot
.28098 .58487 Mdot
.59838 .3489 Mdot
.3422 .48741 Mdot
.369 .64022 Mdot
.56539 .34747 Mdot
.44697 .68922 Mdot
.35279 .45311 Mdot
.72475 .63084 Mdot
.74769 .44786 Mdot
.28174 .48029 Mdot
.5846 .64638 Mdot
.64455 .65166 Mdot
.68253 .50919 Mdot
.37813 .41442 Mdot
.78174 .42052 Mdot
.53761 .26091 Mdot
.31866 .59013 Mdot
.57952 .3885 Mdot
.3916 .64869 Mdot
.63923 .63879 Mdot
.49776 .24339 Mdot
.66542 .6902 Mdot
.60328 .63452 Mdot
.4945 .72985 Mdot
.36736 .45755 Mdot
.69367 .50376 Mdot
.71015 .47966 Mdot
.59192 .33587 Mdot
.78767 .42628 Mdot
.47295 .75825 Mdot
.72132 .62594 Mdot
.26224 .46644 Mdot
.36285 .43972 Mdot
.58645 .40117 Mdot
.56026 .35884 Mdot
.76641 .43035 Mdot
.35863 .45474 Mdot
.42295 .67035 Mdot
.70091 .52737 Mdot
.7086 .46168 Mdot
.29493 .60223 Mdot
.63929 .65043 Mdot
.51908 .29634 Mdot
.69988 .48572 Mdot
.25761 .37935 Mdot
.38015 .45055 Mdot
.5864 .62721 Mdot
.69813 .48556 Mdot
.79802 .38552 Mdot
.71878 .68566 Mdot
.41381 .65155 Mdot
.25723 .47318 Mdot
.40679 .65658 Mdot
.52855 .28469 Mdot
.69208 .52749 Mdot
.64309 .67677 Mdot
.57425 .36221 Mdot
.68813 .55827 Mdot
.70066 .46714 Mdot
.45145 .7254 Mdot
.36438 .46101 Mdot
.37144 .51997 Mdot
.36263 .43016 Mdot
.39448 .35696 Mdot
.54941 .25629 Mdot
.63715 .67894 Mdot
.67262 .68577 Mdot
.25736 .47293 Mdot
.53485 .22516 Mdot
.67948 .52559 Mdot
.69539 .47982 Mdot
.54298 .74087 Mdot
.56956 .34063 Mdot
.68297 .52951 Mdot
.39352 .43769 Mdot
.67036 .53503 Mdot
.37992 .64928 Mdot
.64028 .64787 Mdot
.39592 .44201 Mdot
.69713 .46636 Mdot
.47321 .7099 Mdot
.2714 .48726 Mdot
.39175 .42114 Mdot
.57209 .32712 Mdot
.64159 .65695 Mdot
.36721 .65213 Mdot
.7586 .45258 Mdot
.39133 .40138 Mdot
.6496 .67289 Mdot
.49957 .28191 Mdot
.69452 .55981 Mdot
.4426 .72206 Mdot
.71394 .46653 Mdot
.63267 .63577 Mdot
.57914 .35527 Mdot
.5227 .22402 Mdot
.69349 .52046 Mdot
.71082 .45762 Mdot
.30015 .59118 Mdot
.57131 .32076 Mdot
.5422 .294 Mdot
.45755 .70794 Mdot
.61487 .64968 Mdot
.29377 .59772 Mdot
.26555 .37023 Mdot
.33741 .45522 Mdot
.6021 .63312 Mdot
.34551 .62592 Mdot
.38281 .39658 Mdot
.36903 .41081 Mdot
.37077 .51812 Mdot
.39519 .63773 Mdot
.47296 .72746 Mdot
.37361 .47583 Mdot
.2935 .58334 Mdot
.25915 .48943 Mdot
.45504 .73346 Mdot
.44786 .72103 Mdot
.26388 .48176 Mdot
.29828 .59317 Mdot
.38628 .65074 Mdot
.63283 .65009 Mdot
.64443 .65226 Mdot
.45393 .7167 Mdot
.31287 .58286 Mdot
.59744 .63953 Mdot
.40175 .65696 Mdot
.7066 .49352 Mdot
.27933 .49605 Mdot
.44552 .7106 Mdot
.25656 .50102 Mdot
.6326 .65564 Mdot
.27678 .35639 Mdot
.27603 .50057 Mdot
.34775 .42666 Mdot
.3636 .45769 Mdot
.53904 .23726 Mdot
.57143 .36432 Mdot
.59333 .39646 Mdot
.60822 .63223 Mdot
.33576 .45297 Mdot
.42801 .67737 Mdot
.33661 .45282 Mdot
.35982 .33969 Mdot
.28445 .3504 Mdot
.24547 .47436 Mdot
.44347 .71804 Mdot
.43129 .67945 Mdot
.67123 .49008 Mdot
.72437 .48209 Mdot
.2901 .47434 Mdot
.64208 .65568 Mdot
.46514 .74599 Mdot
.64646 .64296 Mdot
.6827 .49426 Mdot
.69447 .50597 Mdot
.59311 .36221 Mdot
.5937 .38245 Mdot
.68558 .50229 Mdot
.68048 .46747 Mdot
.26131 .37306 Mdot
.38796 .6483 Mdot
.35115 .62935 Mdot
.31869 .34377 Mdot
.40644 .51427 Mdot
.53179 .2653 Mdot
.50364 .24884 Mdot
.65324 .67629 Mdot
.28042 .46797 Mdot
.35101 .4458 Mdot
.57973 .38143 Mdot
.64224 .66576 Mdot
.52165 .24636 Mdot
.64232 .64936 Mdot
.52055 .22707 Mdot
.71889 .48614 Mdot
.36949 .42018 Mdot
.35138 .42432 Mdot
.66913 .68358 Mdot
.66723 .51486 Mdot
.68864 .47574 Mdot
.53091 .26039 Mdot
.3253 .34268 Mdot
.6899 .48021 Mdot
.44447 .70958 Mdot
.50719 .77093 Mdot
.56539 .35036 Mdot
.38131 .41458 Mdot
.33643 .34227 Mdot
.30305 .60605 Mdot
.60202 .38614 Mdot
.57908 .36645 Mdot
.38215 .6699 Mdot
.34286 .46585 Mdot
.55367 .72852 Mdot
.59801 .38285 Mdot
.4566 .75133 Mdot
.69139 .50401 Mdot
.59926 .38982 Mdot
.60551 .36445 Mdot
.53333 .20509 Mdot
.59477 .39853 Mdot
.47713 .74426 Mdot
.40969 .66072 Mdot
.29804 .57473 Mdot
.32596 .62787 Mdot
.51416 .24423 Mdot
.52525 .24984 Mdot
.74631 .45083 Mdot
.67926 .67503 Mdot
.36053 .51335 Mdot
.53116 .24741 Mdot
.49722 .76279 Mdot
.30607 .57238 Mdot
.30787 .58535 Mdot
.30457 .5833 Mdot
.39961 .65141 Mdot
.40352 .38909 Mdot
.75421 .44963 Mdot
.45209 .72726 Mdot
.30018 .57294 Mdot
.34123 .43268 Mdot
.43183 .68897 Mdot
.60729 .64445 Mdot
.30679 .56498 Mdot
.46748 .73577 Mdot
.26403 .51018 Mdot
.62898 .65652 Mdot
.286 .46668 Mdot
.69301 .44203 Mdot
.79612 .3777 Mdot
.63339 .64285 Mdot
.72279 .45846 Mdot
.68423 .48504 Mdot
.70021 .47447 Mdot
.46925 .72307 Mdot
.69853 .45786 Mdot
.43725 .68201 Mdot
.77866 .42313 Mdot
.3667 .49059 Mdot
.51462 .26243 Mdot
.76477 .43617 Mdot
.4555 .71862 Mdot
.37611 .65458 Mdot
.44888 .18163 Mdot
.39421 .40195 Mdot
.63174 .67239 Mdot
.54126 .26995 Mdot
.27121 .49349 Mdot
.53195 .23418 Mdot
.67813 .51153 Mdot
.36043 .4925 Mdot
.37855 .45187 Mdot
.55617 .71237 Mdot
.52861 .26634 Mdot
.44713 .71917 Mdot
.30253 .58976 Mdot
.70774 .52292 Mdot
.53634 .25969 Mdot
.52262 .26976 Mdot
.38767 .42941 Mdot
.40868 .66112 Mdot
.67416 .50388 Mdot
.63967 .66325 Mdot
.74975 .44156 Mdot
.26383 .40167 Mdot
.34315 .46828 Mdot
.39157 .39867 Mdot
.26438 .4954 Mdot
.77123 .42597 Mdot
.62982 .64646 Mdot
.37678 .34654 Mdot
.7585 .4546 Mdot
.35203 .33786 Mdot
.46101 .69308 Mdot
.77213 .43199 Mdot
.56408 .35263 Mdot
.59252 .35505 Mdot
.37896 .42302 Mdot
.45585 .17848 Mdot
.39096 .36696 Mdot
.59996 .6451 Mdot
.56792 .3703 Mdot
.71225 .45099 Mdot
.48084 .75624 Mdot
.51961 .19437 Mdot
.2909 .58062 Mdot
.63541 .66223 Mdot
.69213 .48062 Mdot
.479 .17962 Mdot
.5452 .25184 Mdot
.2939 .48011 Mdot
.39597 .40693 Mdot
.38096 .42097 Mdot
.60965 .63723 Mdot
.5959 .64451 Mdot
.35693 .63426 Mdot
.60994 .38805 Mdot
.53105 .74976 Mdot
.67919 .68207 Mdot
.48628 .18107 Mdot
.56049 .36463 Mdot
.42641 .66572 Mdot
.58401 .39869 Mdot
.60053 .64984 Mdot
.35169 .45715 Mdot
.40867 .66028 Mdot
.5747 .34836 Mdot
.45541 .67283 Mdot
.3085 .59473 Mdot
.25606 .38033 Mdot
.37941 .43361 Mdot
.46177 .75104 Mdot
.45179 .73054 Mdot
.4207 .67258 Mdot
.57563 .3444 Mdot
.35959 .42096 Mdot
.37987 .40503 Mdot
.38531 .40012 Mdot
.3535 .62565 Mdot
.37014 .42244 Mdot
.48861 .75794 Mdot
.28789 .48492 Mdot
.73118 .64105 Mdot
.35085 .42594 Mdot
.62107 .63179 Mdot
.38007 .42773 Mdot
.55131 .28702 Mdot
.26088 .47457 Mdot
.2958 .60589 Mdot
.62319 .6448 Mdot
.33595 .44529 Mdot
.53806 .33175 Mdot
.34092 .45157 Mdot
.51614 .23367 Mdot
.70566 .69312 Mdot
.3754 .35127 Mdot
.36435 .62647 Mdot
.46067 .72491 Mdot
.70532 .51117 Mdot
.59237 .6294 Mdot
.68032 .52011 Mdot
.30692 .61435 Mdot
.56505 .38226 Mdot
.78513 .41597 Mdot
.26939 .36582 Mdot
.35225 .45556 Mdot
.5625 .34247 Mdot
.42633 .6777 Mdot
.75177 .44776 Mdot
.42482 .50088 Mdot
.31092 .57829 Mdot
.54017 .28787 Mdot
.53583 .24136 Mdot
.59822 .32601 Mdot
.40387 .64864 Mdot
.39121 .66367 Mdot
.61046 .63856 Mdot
.70318 .46749 Mdot
.52678 .21312 Mdot
.49128 .77731 Mdot
.59169 .63838 Mdot
.76197 .43387 Mdot
.64077 .6406 Mdot
.35439 .42369 Mdot
.59525 .39607 Mdot
.37636 .63392 Mdot
.57479 .38214 Mdot
.33663 .47376 Mdot
.70286 .46155 Mdot
.56691 .34381 Mdot
.5314 .22655 Mdot
.61871 .62981 Mdot
.68897 .51466 Mdot
.3669 .46086 Mdot
.45291 .73427 Mdot
.24535 .52544 Mdot
.77879 .4395 Mdot
.29194 .60392 Mdot
.29004 .60333 Mdot
.37946 .63254 Mdot
.60639 .37591 Mdot
.71317 .55562 Mdot
.30232 .60863 Mdot
.68965 .68557 Mdot
.53793 .30268 Mdot
.78918 .4167 Mdot
.70006 .52403 Mdot
.69043 .49095 Mdot
.34587 .45852 Mdot
.69626 .53353 Mdot
.26817 .47626 Mdot
.71079 .5176 Mdot
.70133 .69625 Mdot
.40141 .3846 Mdot
.69595 .48213 Mdot
.59711 .38498 Mdot
.38795 .44529 Mdot
.41914 .66256 Mdot
.68456 .53499 Mdot
.34756 .42685 Mdot
.68546 .45789 Mdot
.66976 .68561 Mdot
.57903 .34424 Mdot
.24379 .49744 Mdot
.63037 .65159 Mdot
.47723 .73939 Mdot
.24012 .48826 Mdot
.53588 .25327 Mdot
.43184 .67727 Mdot
.56364 .31454 Mdot
.52109 .27158 Mdot
.26714 .49998 Mdot
.44686 .7044 Mdot
.56371 .36011 Mdot
.53855 .24786 Mdot
.51182 .22386 Mdot
.68936 .48971 Mdot
.74024 .46625 Mdot
.58734 .38136 Mdot
.36855 .46194 Mdot
.77446 .43571 Mdot
.63408 .64023 Mdot
.39444 .41278 Mdot
.69476 .47106 Mdot
.56631 .35945 Mdot
.3763 .40858 Mdot
.29345 .58215 Mdot
.36302 .63236 Mdot
.60556 .39526 Mdot
.51681 .23894 Mdot
.41448 .66253 Mdot
.39246 .40066 Mdot
.51263 .25519 Mdot
.7482 .44449 Mdot
.39812 .43333 Mdot
.44276 .72804 Mdot
.49852 .7647 Mdot
.71272 .50866 Mdot
.60984 .64872 Mdot
.71188 .4793 Mdot
.51731 .22642 Mdot
.44649 .18228 Mdot
.59565 .37313 Mdot
.31652 .60288 Mdot
.26286 .47608 Mdot
.70205 .51825 Mdot
.44551 .7253 Mdot
.52251 .76512 Mdot
.25772 .47615 Mdot
.39822 .43185 Mdot
.38357 .41671 Mdot
.77219 .42847 Mdot
.47972 .75481 Mdot
.38272 .41521 Mdot
.50625 .26445 Mdot
.40526 .40651 Mdot
.53569 .27836 Mdot
.72506 .43976 Mdot
.59413 .35548 Mdot
.33841 .62516 Mdot
.57638 .34693 Mdot
.7013 .48099 Mdot
.25875 .51056 Mdot
.26232 .49002 Mdot
.57539 .29367 Mdot
.47825 .74346 Mdot
.47871 .71424 Mdot
.69581 .50212 Mdot
.76232 .43002 Mdot
.28976 .57845 Mdot
.30069 .58725 Mdot
.38535 .44732 Mdot
.67838 .51176 Mdot
.73185 .464 Mdot
.5707 .3891 Mdot
.56221 .34501 Mdot
.29123 .46737 Mdot
.71569 .49234 Mdot
.37015 .42017 Mdot
.31279 .59584 Mdot
.59118 .63579 Mdot
.41253 .65639 Mdot
.6177 .66509 Mdot
.58959 .63694 Mdot
.41541 .50707 Mdot
.3882 .45904 Mdot
.65762 .68118 Mdot
.62648 .66337 Mdot
.75628 .43812 Mdot
.28971 .45921 Mdot
.52934 .28347 Mdot
.39906 .36355 Mdot
.67988 .52215 Mdot
.35676 .42907 Mdot
.47467 .76118 Mdot
.59857 .40463 Mdot
.51376 .77483 Mdot
.45187 .3133 Mdot
.28634 .57522 Mdot
.7628 .44595 Mdot
.58494 .38528 Mdot
.57463 .38416 Mdot
.35338 .34099 Mdot
.37198 .41973 Mdot
.71155 .51078 Mdot
.28697 .45631 Mdot
.67887 .68135 Mdot
.75668 .43649 Mdot
.40153 .64603 Mdot
.37724 .42729 Mdot
.45221 .69991 Mdot
.60099 .62879 Mdot
.51912 .27787 Mdot
.54373 .24428 Mdot
.34228 .45043 Mdot
.28407 .60145 Mdot
.69139 .68834 Mdot
.29743 .58118 Mdot
.29409 .59357 Mdot
.58474 .3767 Mdot
.2809 .58657 Mdot
.3966 .40182 Mdot
.38477 .39007 Mdot
.60244 .38434 Mdot
.59014 .64012 Mdot
.39714 .37956 Mdot
.58656 .38793 Mdot
.24697 .48239 Mdot
.60329 .62636 Mdot
.29504 .57952 Mdot
.61982 .63431 Mdot
.76236 .43235 Mdot
.66411 .68281 Mdot
.52529 .22538 Mdot
.76142 .43633 Mdot
.35257 .62954 Mdot
.46867 .73534 Mdot
.64616 .65697 Mdot
.54131 .25508 Mdot
.62492 .63507 Mdot
.69045 .51972 Mdot
.68446 .68836 Mdot
.38208 .62862 Mdot
.25381 .38461 Mdot
.40544 .51254 Mdot
.65238 .6464 Mdot
.72372 .48103 Mdot
.4551 .71723 Mdot
.68041 .6749 Mdot
.24792 .48679 Mdot
.5476 .25863 Mdot
.38085 .42339 Mdot
.61087 .62902 Mdot
.76364 .44006 Mdot
.37201 .64071 Mdot
.52226 .22896 Mdot
.36767 .65503 Mdot
.71159 .50313 Mdot
.40385 .39743 Mdot
.67429 .69667 Mdot
.70549 .56045 Mdot
.67085 .68366 Mdot
.34572 .50775 Mdot
.55796 .35877 Mdot
.60994 .37659 Mdot
.43623 .68697 Mdot
.56034 .3429 Mdot
.49281 .26512 Mdot
.68894 .67936 Mdot
.42311 .65597 Mdot
.67531 .47957 Mdot
.36886 .46251 Mdot
.28339 .57452 Mdot
.59297 .37289 Mdot
.46423 .74957 Mdot
.28446 .59288 Mdot
.59266 .35912 Mdot
.28751 .48582 Mdot
.40918 .65715 Mdot
.67782 .52731 Mdot
.3928 .43814 Mdot
.65611 .68829 Mdot
.67267 .67654 Mdot
.58221 .39974 Mdot
.65848 .68668 Mdot
.24766 .48164 Mdot
.44461 .70452 Mdot
.29624 .57505 Mdot
.53691 .27762 Mdot
.41506 .68361 Mdot
.59777 .40256 Mdot
.54999 .23058 Mdot
.39784 .42925 Mdot
.69446 .50418 Mdot
.68958 .55761 Mdot
.2914 .47137 Mdot
.45535 .73117 Mdot
.27087 .47348 Mdot
.28251 .59045 Mdot
.29905 .58389 Mdot
.70282 .46765 Mdot
.26762 .49392 Mdot
.36929 .42211 Mdot
.62891 .65941 Mdot
.30228 .41048 Mdot
.33014 .47972 Mdot
.50783 .26889 Mdot
.29627 .60595 Mdot
.68205 .69727 Mdot
.38776 .64648 Mdot
.69376 .50188 Mdot
.42662 .67249 Mdot
.39275 .64529 Mdot
.47354 .73245 Mdot
.48771 .77615 Mdot
.3024 .60833 Mdot
.54608 .73913 Mdot
.38129 .65125 Mdot
.39192 .51979 Mdot
.48378 .7619 Mdot
.71535 .54352 Mdot
.42425 .65674 Mdot
.47751 .7402 Mdot
.50878 .74228 Mdot
.47817 .75438 Mdot
.37349 .45727 Mdot
.40121 .43253 Mdot
.24907 .47032 Mdot
.77804 .42568 Mdot
.36202 .42937 Mdot
.59836 .3968 Mdot
.54165 .27768 Mdot
.40706 .64324 Mdot
.57589 .36507 Mdot
.26306 .50126 Mdot
.55455 .33822 Mdot
.38718 .43229 Mdot
.37827 .41027 Mdot
.30296 .58274 Mdot
.29328 .34378 Mdot
.78127 .42462 Mdot
.45319 .74592 Mdot
.3295 .47497 Mdot
.6941 .56021 Mdot
.39389 .43241 Mdot
.27131 .47194 Mdot
.38235 .39311 Mdot
.69367 .50385 Mdot
.39174 .6413 Mdot
.58066 .39254 Mdot
.41032 .67745 Mdot
.37097 .43408 Mdot
.56359 .39191 Mdot
.52205 .29022 Mdot
.38018 .41322 Mdot
.4265 .68604 Mdot
.28356 .59224 Mdot
.47782 .73018 Mdot
.44335 .69898 Mdot
.39898 .43004 Mdot
.4033 .64423 Mdot
.47191 .72466 Mdot
.29994 .58681 Mdot
.76411 .44486 Mdot
.69397 .67864 Mdot
.38678 .43891 Mdot
.52294 .22992 Mdot
.35846 .45709 Mdot
.52485 .28396 Mdot
.59768 .39468 Mdot
.58461 .38237 Mdot
.39561 .37147 Mdot
.7272 .46621 Mdot
.53775 .29436 Mdot
.77896 .42684 Mdot
.29432 .62091 Mdot
.48756 .72347 Mdot
.68103 .68298 Mdot
.73987 .4676 Mdot
.5841 .38053 Mdot
.38291 .36074 Mdot
.26819 .40201 Mdot
.65725 .68402 Mdot
.4578 .69479 Mdot
.39761 .37891 Mdot
.56297 .33857 Mdot
.6761 .52697 Mdot
.70887 .48117 Mdot
.68986 .68107 Mdot
.50735 .7395 Mdot
.34863 .43221 Mdot
.5638 .33867 Mdot
.28869 .55706 Mdot
.57072 .36312 Mdot
.58075 .39455 Mdot
.72041 .45526 Mdot
.36869 .41501 Mdot
.26657 .50315 Mdot
.67947 .49449 Mdot
.52174 .25843 Mdot
.44767 .69031 Mdot
.51435 .24025 Mdot
.55825 .70232 Mdot
.35546 .63247 Mdot
.68239 .50447 Mdot
.58631 .34418 Mdot
.35798 .43385 Mdot
.39698 .64681 Mdot
.41646 .67195 Mdot
.41724 .65851 Mdot
.53935 .27541 Mdot
.70451 .52158 Mdot
.76434 .42597 Mdot
.36817 .45855 Mdot
.44041 .70524 Mdot
.53593 .20815 Mdot
.36685 .45304 Mdot
.64241 .65432 Mdot
.28666 .5964 Mdot
.44582 .71395 Mdot
.31713 .5978 Mdot
.43704 .68819 Mdot
.70676 .47974 Mdot
.34497 .45019 Mdot
.37685 .45658 Mdot
.37743 .35211 Mdot
.522 .24498 Mdot
.48358 .74405 Mdot
.37949 .46805 Mdot
.34218 .48731 Mdot
.34704 .34181 Mdot
.38285 .40957 Mdot
.40195 .51406 Mdot
.5723 .32331 Mdot
.59628 .36773 Mdot
.2573 .4798 Mdot
.39048 .42184 Mdot
.42602 .68663 Mdot
.37095 .63497 Mdot
.35171 .62288 Mdot
.59989 .63458 Mdot
.42095 .65279 Mdot
.67676 .5012 Mdot
.68185 .5348 Mdot
.6672 .50578 Mdot
.52187 .21842 Mdot
.29361 .57743 Mdot
.34884 .44714 Mdot
.60002 .64373 Mdot
.53582 .25033 Mdot
.43798 .70386 Mdot
.52308 .27688 Mdot
.28309 .47701 Mdot
.52884 .22808 Mdot
.56628 .38584 Mdot
.71749 .68772 Mdot
.31257 .59579 Mdot
.51749 .2581 Mdot
.41443 .6603 Mdot
.38924 .36555 Mdot
.4041 .38185 Mdot
.37363 .65289 Mdot
.5392 .28983 Mdot
.74808 .44409 Mdot
.39812 .42516 Mdot
.36297 .4995 Mdot
.6122 .63277 Mdot
.52304 .22448 Mdot
.64571 .64541 Mdot
.28774 .59138 Mdot
.47609 .71071 Mdot
.45546 .72625 Mdot
.67681 .67733 Mdot
.27151 .47247 Mdot
.52458 .22321 Mdot
.68495 .49926 Mdot
.2826 .45875 Mdot
.78364 .42164 Mdot
.55615 .32667 Mdot
.35901 .34415 Mdot
.75274 .4511 Mdot
.33314 .45152 Mdot
.66419 .67712 Mdot
.33352 .46799 Mdot
.31383 .60334 Mdot
.34919 .48503 Mdot
.68052 .48643 Mdot
.69113 .49074 Mdot
.78212 .41785 Mdot
.34143 .4672 Mdot
.35716 .41135 Mdot
.39354 .65032 Mdot
.70717 .51775 Mdot
.46859 .7254 Mdot
.46066 .74883 Mdot
.72117 .45802 Mdot
.47623 .7234 Mdot
.52261 .27119 Mdot
.35574 .49175 Mdot
.66406 .67739 Mdot
.67422 .68417 Mdot
.68442 .50419 Mdot
.71415 .45461 Mdot
.69399 .50593 Mdot
.28571 .59161 Mdot
.44969 .70605 Mdot
.41052 .41141 Mdot
.38382 .43178 Mdot
.33916 .44348 Mdot
.39906 .64456 Mdot
.25358 .47907 Mdot
.45206 .43222 Mdot
.53716 .28647 Mdot
.70099 .48417 Mdot
.63503 .63416 Mdot
.25128 .52921 Mdot
.61878 .655 Mdot
.40436 .41426 Mdot
.69641 .68653 Mdot
.45597 .69317 Mdot
.53477 .23432 Mdot
.30328 .60321 Mdot
.53578 .22918 Mdot
.59142 .63601 Mdot
.40641 .66499 Mdot
.27551 .49095 Mdot
.40361 .3922 Mdot
.26917 .48457 Mdot
.68052 .3895 Mdot
.42209 .68033 Mdot
.62235 .65237 Mdot
.30924 .59906 Mdot
.55856 .32656 Mdot
.27807 .56145 Mdot
.34714 .45758 Mdot
.33066 .47354 Mdot
.35368 .50976 Mdot
.39625 .44234 Mdot
.41292 .65034 Mdot
.27806 .47423 Mdot
.57913 .33828 Mdot
.37975 .45679 Mdot
.55012 .72542 Mdot
.36659 .43846 Mdot
.34945 .42613 Mdot
.35209 .43737 Mdot
.33242 .48647 Mdot
.39726 .63715 Mdot
.30455 .58149 Mdot
.61171 .65068 Mdot
.35033 .49551 Mdot
.6608 .67119 Mdot
.68588 .50869 Mdot
.60273 .40092 Mdot
.39262 .6376 Mdot
.53712 .23136 Mdot
.56274 .68172 Mdot
.36389 .49746 Mdot
.66957 .49334 Mdot
.38554 .35317 Mdot
.52407 .29867 Mdot
.58944 .39538 Mdot
.5215 .2209 Mdot
.69798 .46546 Mdot
.63543 .64659 Mdot
.37524 .39989 Mdot
.46468 .72277 Mdot
.46776 .74217 Mdot
.38537 .4511 Mdot
.69227 .67266 Mdot
.6728 .67683 Mdot
.76333 .43683 Mdot
.35029 .42982 Mdot
.39513 .44342 Mdot
.46518 .71197 Mdot
.74747 .44665 Mdot
.25652 .49276 Mdot
.53259 .25787 Mdot
.39604 .42151 Mdot
.5717 .33433 Mdot
.27766 .47774 Mdot
.60229 .64363 Mdot
.56576 .35506 Mdot
.36139 .44414 Mdot
.39027 .45717 Mdot
.31581 .58085 Mdot
.59863 .34203 Mdot
.72525 .48393 Mdot
.3994 .42749 Mdot
.38841 .44083 Mdot
.40805 .6559 Mdot
.66636 .68298 Mdot
.4449 .72526 Mdot
.38099 .62858 Mdot
.58441 .38196 Mdot
.67139 .68685 Mdot
.33466 .48687 Mdot
.68651 .69715 Mdot
.28735 .59775 Mdot
.38104 .44341 Mdot
.61932 .65091 Mdot
.44384 .69656 Mdot
.53045 .74447 Mdot
.40145 .37828 Mdot
.29213 .59431 Mdot
.35951 .45569 Mdot
.7517 .44086 Mdot
.59771 .40537 Mdot
.40431 .39554 Mdot
.46656 .74552 Mdot
.36763 .45376 Mdot
.59498 .63247 Mdot
.51653 .2729 Mdot
.45865 .73366 Mdot
.76145 .44797 Mdot
.70711 .47258 Mdot
.71941 .49448 Mdot
.56548 .38399 Mdot
.28159 .58909 Mdot
.41857 .66867 Mdot
.44444 .73298 Mdot
.27023 .47993 Mdot
.70094 .48104 Mdot
.53263 .27128 Mdot
.36606 .46644 Mdot
.56962 .33309 Mdot
.64587 .68214 Mdot
.33749 .62625 Mdot
.28898 .48281 Mdot
.51346 .23256 Mdot
.28603 .40365 Mdot
.58245 .37452 Mdot
.36515 .41456 Mdot
.5239 .22408 Mdot
.71551 .45834 Mdot
.31212 .5731 Mdot
.53091 .30463 Mdot
.77761 .43083 Mdot
.68675 .47069 Mdot
.67191 .67414 Mdot
.72143 .49498 Mdot
.53114 .22125 Mdot
.59751 .38123 Mdot
.46427 .73783 Mdot
.37662 .4148 Mdot
.58961 .37424 Mdot
.70346 .49238 Mdot
.56169 .37215 Mdot
.36189 .41256 Mdot
.46173 .706 Mdot
.68607 .51999 Mdot
.37856 .44967 Mdot
.30564 .60795 Mdot
.36179 .63038 Mdot
.7589 .44501 Mdot
.2707 .47469 Mdot
.51141 .20225 Mdot
.66923 .50076 Mdot
.68422 .47985 Mdot
.39635 .43827 Mdot
.54855 .27241 Mdot
.37498 .43189 Mdot
.63757 .64974 Mdot
.24195 .50015 Mdot
.66929 .68372 Mdot
.34967 .33807 Mdot
.38501 .45507 Mdot
.26086 .46958 Mdot
.47916 .70961 Mdot
.51689 .31074 Mdot
.32005 .34142 Mdot
.37978 .40435 Mdot
.47981 .76178 Mdot
.25437 .50111 Mdot
.25032 .39108 Mdot
.38747 .63864 Mdot
.51579 .27593 Mdot
.60933 .63183 Mdot
.36252 .46701 Mdot
.5539 .72136 Mdot
.53481 .27717 Mdot
.35116 .34014 Mdot
.29511 .46913 Mdot
.44699 .7222 Mdot
.34726 .44534 Mdot
.46066 .72884 Mdot
.35963 .44903 Mdot
.36463 .62982 Mdot
.68562 .67936 Mdot
.34832 .50626 Mdot
.59676 .38306 Mdot
.70478 .56047 Mdot
.40344 .51398 Mdot
.52711 .27156 Mdot
.31519 .60034 Mdot
.58002 .37878 Mdot
.64228 .64919 Mdot
.67176 .67099 Mdot
.69513 .50486 Mdot
.64608 .66501 Mdot
.42851 .66584 Mdot
.76365 .4393 Mdot
.55966 .35274 Mdot
.30044 .55962 Mdot
.53926 .231 Mdot
.67156 .68745 Mdot
.3871 .41216 Mdot
.33717 .45371 Mdot
.77273 .42809 Mdot
.7204 .43925 Mdot
.48405 .72945 Mdot
.35202 .63194 Mdot
.40448 .66288 Mdot
.52294 .25007 Mdot
.76235 .44323 Mdot
.35187 .45034 Mdot
.36528 .42116 Mdot
.69848 .45932 Mdot
.39354 .64169 Mdot
.54492 .27385 Mdot
.61027 .38029 Mdot
.59907 .64358 Mdot
.78337 .41247 Mdot
.46026 .73476 Mdot
.78915 .41187 Mdot
.76239 .42798 Mdot
.50889 .74805 Mdot
.32315 .3417 Mdot
.63021 .64963 Mdot
.79038 .41167 Mdot
.44345 .71501 Mdot
.40583 .40206 Mdot
.56902 .37335 Mdot
.5625 .37831 Mdot
.45237 .69706 Mdot
.68234 .51356 Mdot
.54886 .2768 Mdot
.34459 .4584 Mdot
.51147 .22941 Mdot
.39298 .64392 Mdot
.71615 .4951 Mdot
.57282 .35562 Mdot
.61004 .62658 Mdot
.36366 .45498 Mdot
.53968 .27789 Mdot
.62743 .64814 Mdot
.59337 .3562 Mdot
.35673 .4949 Mdot
.24036 .48847 Mdot
.29086 .60465 Mdot
.61295 .63377 Mdot
.26264 .48525 Mdot
.39438 .42187 Mdot
.66412 .67691 Mdot
.56998 .31747 Mdot
.70908 .55752 Mdot
.24184 .49522 Mdot
.68861 .67891 Mdot
.69574 .45899 Mdot
.723 .49219 Mdot
.73856 .47161 Mdot
.78108 .42512 Mdot
.65948 .67217 Mdot
.58325 .36472 Mdot
.7771 .4171 Mdot
.66682 .68293 Mdot
.28082 .47028 Mdot
.36315 .4664 Mdot
.29065 .45623 Mdot
.59349 .35494 Mdot
.58323 .34793 Mdot
.38071 .64013 Mdot
.30874 .58305 Mdot
.573 .35766 Mdot
.39131 .40826 Mdot
.41987 .67353 Mdot
.63095 .65608 Mdot
.50902 .18848 Mdot
.59916 .64727 Mdot
.30929 .56855 Mdot
.66886 .51724 Mdot
.76063 .44047 Mdot
.37768 .41517 Mdot
.57703 .64681 Mdot
.48398 .18058 Mdot
.36156 .46731 Mdot
.30341 .60322 Mdot
.35305 .33799 Mdot
.38127 .45544 Mdot
.4387 .67205 Mdot
.57168 .33844 Mdot
.41931 .67202 Mdot
.62649 .64998 Mdot
.51794 .27902 Mdot
.49332 .25669 Mdot
.60815 .63295 Mdot
.36679 .43578 Mdot
.59194 .40461 Mdot
.38173 .41965 Mdot
.38251 .39967 Mdot
.34412 .49345 Mdot
.51027 .26214 Mdot
.68989 .51124 Mdot
.53705 .23016 Mdot
.47875 .74837 Mdot
.34669 .62611 Mdot
.5285 .27368 Mdot
.28682 .45897 Mdot
.25872 .49799 Mdot
.7157 .44091 Mdot
.46698 .74218 Mdot
.5274 .28487 Mdot
.61465 .63086 Mdot
.2522 .39971 Mdot
.27766 .46175 Mdot
.63751 .66241 Mdot
.36737 .40942 Mdot
.44545 .73596 Mdot
.38396 .63997 Mdot
.68073 .6897 Mdot
.44245 .72484 Mdot
.26098 .48765 Mdot
.28825 .58904 Mdot
.60153 .64365 Mdot
.30428 .35043 Mdot
.67251 .68574 Mdot
.43175 .4895 Mdot
.29489 .59921 Mdot
.45679 .73193 Mdot
.37483 .52014 Mdot
.4235 .68678 Mdot
.59049 .35695 Mdot
.34449 .49012 Mdot
.53096 .27044 Mdot
.26687 .48578 Mdot
.76398 .44851 Mdot
.46435 .69628 Mdot
.45068 .71589 Mdot
.59158 .64664 Mdot
.44843 .73295 Mdot
.46588 .70551 Mdot
.65206 .64461 Mdot
.42837 .66048 Mdot
.36994 .43417 Mdot
.32434 .62933 Mdot
.42236 .67047 Mdot
.61297 .64184 Mdot
.53909 .26522 Mdot
.41388 .65446 Mdot
.76733 .42584 Mdot
.39231 .43972 Mdot
.70859 .49946 Mdot
.54713 .29081 Mdot
.39718 .63939 Mdot
.52845 .26908 Mdot
.70098 .49993 Mdot
.51712 .29015 Mdot
.62288 .67039 Mdot
.67835 .69498 Mdot
.60366 .35965 Mdot
.69191 .68498 Mdot
.47867 .7525 Mdot
.77857 .4329 Mdot
.33933 .46179 Mdot
.35217 .42859 Mdot
.55226 .2853 Mdot
.48373 .75491 Mdot
.70033 .6824 Mdot
.57504 .36339 Mdot
.38709 .65106 Mdot
.62163 .62831 Mdot
.75851 .43958 Mdot
.26165 .50291 Mdot
.67708 .67559 Mdot
.58158 .33956 Mdot
.58237 .37688 Mdot
.3839 .41645 Mdot
.3756 .34826 Mdot
.51969 .22767 Mdot
.71417 .54266 Mdot
.29506 .56686 Mdot
.71279 .45292 Mdot
.35563 .43932 Mdot
.29954 .57157 Mdot
.39476 .40106 Mdot
.52576 .21359 Mdot
.6471 .66959 Mdot
.46956 .73937 Mdot
.52179 .28316 Mdot
.70751 .47199 Mdot
.25959 .50914 Mdot
.40704 .39694 Mdot
.26005 .48258 Mdot
.6746 .51565 Mdot
.47401 .75633 Mdot
.68976 .49957 Mdot
.66344 .67594 Mdot
.52508 .27577 Mdot
.28465 .59248 Mdot
.59314 .3538 Mdot
.70073 .5205 Mdot
.64742 .65779 Mdot
.76679 .4453 Mdot
.66961 .67079 Mdot
.58285 .38091 Mdot
.2469 .49147 Mdot
.69665 .53368 Mdot
.57071 .38111 Mdot
.39152 .6595 Mdot
.3707 .48281 Mdot
.50139 .73147 Mdot
.67852 .51374 Mdot
.57367 .28861 Mdot
.62157 .64598 Mdot
.60943 .65746 Mdot
.41667 .50807 Mdot
.45718 .17836 Mdot
.34014 .49197 Mdot
.70759 .69125 Mdot
.66433 .67837 Mdot
.61819 .63607 Mdot
.69201 .49947 Mdot
.44414 .69586 Mdot
.45799 .67498 Mdot
.67778 .52476 Mdot
.33564 .34523 Mdot
.43806 .70388 Mdot
.2517 .46925 Mdot
.6928 .53305 Mdot
.30163 .58577 Mdot
.3767 .64772 Mdot
.53449 .29089 Mdot
.36417 .347 Mdot
.67688 .67796 Mdot
.35593 .46684 Mdot
.54441 .74398 Mdot
.69744 .49861 Mdot
.56597 .37841 Mdot
.58774 .64555 Mdot
.33741 .45019 Mdot
.35576 .4319 Mdot
.37888 .43851 Mdot
.55197 .28336 Mdot
.37965 .64725 Mdot
.35009 .46187 Mdot
.36223 .49257 Mdot
.28307 .57262 Mdot
.74295 .46404 Mdot
.53349 .22594 Mdot
.39108 .354 Mdot
.68588 .4605 Mdot
.38394 .64668 Mdot
.33175 .46943 Mdot
.6257 .66479 Mdot
.30743 .58099 Mdot
.6092 .6462 Mdot
.63278 .6316 Mdot
.78233 .41114 Mdot
.4656 .74758 Mdot
.28559 .57469 Mdot
.73187 .45812 Mdot
.47672 .7043 Mdot
.29409 .57247 Mdot
.34939 .62996 Mdot
.59003 .64227 Mdot
.44582 .1818 Mdot
.61413 .6611 Mdot
.5607 .37326 Mdot
.43056 .66654 Mdot
.47074 .76525 Mdot
.27627 .47765 Mdot
.46021 .71469 Mdot
.77295 .42896 Mdot
.42005 .67037 Mdot
.75162 .3584 Mdot
.41348 .67026 Mdot
.61856 .64175 Mdot
.67609 .68766 Mdot
.29877 .57794 Mdot
.36824 .43128 Mdot
.27653 .49354 Mdot
.57432 .36308 Mdot
.24824 .48817 Mdot
.68028 .49266 Mdot
.77111 .42286 Mdot
.71437 .68974 Mdot
.43716 .67215 Mdot
.65236 .66326 Mdot
.3554 .4334 Mdot
.29313 .59866 Mdot
.40147 .43205 Mdot
.68375 .68069 Mdot
.26942 .58164 Mdot
.38418 .42989 Mdot
.29486 .5777 Mdot
.67372 .52325 Mdot
.70646 .44993 Mdot
.5059 .73633 Mdot
.78146 .41199 Mdot
.38041 .40607 Mdot
.5278 .24532 Mdot
.52252 .21706 Mdot
.40476 .3872 Mdot
.68143 .55121 Mdot
.25744 .49336 Mdot
.38768 .41284 Mdot
.25659 .50959 Mdot
.67603 .52759 Mdot
.55482 .3584 Mdot
.70378 .48808 Mdot
.38574 .63318 Mdot
.59424 .39749 Mdot
.69017 .47593 Mdot
.2763 .49919 Mdot
.58749 .37674 Mdot
.70959 .55598 Mdot
.53628 .28005 Mdot
.39412 .41114 Mdot
.43315 .49455 Mdot
.70242 .52512 Mdot
.62843 .64397 Mdot
.42017 .6577 Mdot
.61268 .65047 Mdot
.6978 .45443 Mdot
.34009 .34038 Mdot
.5892 .35136 Mdot
.61902 .65986 Mdot
.27557 .59042 Mdot
.53115 .24484 Mdot
.61271 .66181 Mdot
.28029 .58842 Mdot
.40513 .38631 Mdot
.47237 .17873 Mdot
.34371 .43558 Mdot
.77324 .42145 Mdot
.66898 .68645 Mdot
.56331 .31714 Mdot
.3747 .41645 Mdot
.71382 .49299 Mdot
.5113 .22249 Mdot
.38405 .42121 Mdot
.75713 .44972 Mdot
.38595 .44281 Mdot
.52409 .22474 Mdot
.40941 .65876 Mdot
.24184 .50151 Mdot
.55029 .25291 Mdot
.52096 .2816 Mdot
.35296 .50861 Mdot
.40067 .43484 Mdot
.7171 .53142 Mdot
.44684 .72405 Mdot
.40466 .4077 Mdot
.55407 .27846 Mdot
.44023 .68448 Mdot
.42732 .67241 Mdot
.31208 .57228 Mdot
.59461 .62795 Mdot
.68444 .51569 Mdot
.52995 .2358 Mdot
.75232 .43906 Mdot
.36114 .46489 Mdot
.31649 .59184 Mdot
.53226 .28251 Mdot
.64058 .65585 Mdot
.28347 .58446 Mdot
.70807 .68048 Mdot
.35102 .4956 Mdot
.60821 .65994 Mdot
.33193 .47766 Mdot
.36328 .5172 Mdot
.41093 .6646 Mdot
.5463 .7365 Mdot
.68059 .67347 Mdot
.70894 .47717 Mdot
.57427 .35609 Mdot
.34155 .62634 Mdot
.53908 .2767 Mdot
.45929 .67423 Mdot
.35645 .41948 Mdot
.35444 .44945 Mdot
.41414 .66655 Mdot
.40674 .39282 Mdot
.44805 .68557 Mdot
.75972 .43179 Mdot
.45455 .17845 Mdot
.46593 .73584 Mdot
.45023 .71955 Mdot
.32241 .60998 Mdot
.67031 .53572 Mdot
.44977 .69153 Mdot
.36159 .46795 Mdot
.70525 .45084 Mdot
.59658 .33994 Mdot
.54338 .26399 Mdot
.54434 .30953 Mdot
.46115 .69687 Mdot
.29887 .46367 Mdot
.28831 .6008 Mdot
.3971 .37458 Mdot
.29145 .40465 Mdot
.66117 .67579 Mdot
.34652 .47695 Mdot
.57752 .36888 Mdot
.70145 .49416 Mdot
.34947 .42063 Mdot
.3922 .40786 Mdot
.47143 .73835 Mdot
.5262 .29342 Mdot
.65511 .65848 Mdot
.57283 .38544 Mdot
.71082 .51464 Mdot
.52563 .25842 Mdot
.47627 .72266 Mdot
.40801 .51242 Mdot
.6043 .38614 Mdot
.56351 .34046 Mdot
.37383 .40689 Mdot
.40076 .42346 Mdot
.5968 .35559 Mdot
.60577 .63777 Mdot
.70984 .4784 Mdot
.58482 .39255 Mdot
.2643 .48774 Mdot
.24697 .50593 Mdot
.36142 .42258 Mdot
.43067 .69121 Mdot
.64754 .65539 Mdot
.58663 .3495 Mdot
.7892 .41519 Mdot
.367 .46641 Mdot
.28467 .46507 Mdot
.6194 .41371 Mdot
.58007 .36664 Mdot
.45931 .67644 Mdot
.53998 .23884 Mdot
.29521 .599 Mdot
.35676 .49821 Mdot
.24836 .48225 Mdot
.33298 .47041 Mdot
.71324 .45799 Mdot
.62693 .63169 Mdot
.58779 .33574 Mdot
.70014 .4847 Mdot
.42669 .67204 Mdot
.39693 .37366 Mdot
.46468 .75241 Mdot
.44556 .73407 Mdot
.4762 .71382 Mdot
.6007 .63231 Mdot
.33983 .6252 Mdot
.60086 .36458 Mdot
.34893 .43002 Mdot
.65534 .67797 Mdot
.45421 .69441 Mdot
.25696 .47381 Mdot
.45563 .69271 Mdot
.48395 .74832 Mdot
.24459 .48362 Mdot
.29381 .58194 Mdot
.36413 .49357 Mdot
.33224 .45918 Mdot
.54795 .25805 Mdot
.43863 .72718 Mdot
.28057 .46344 Mdot
.35199 .45392 Mdot
.37429 .41295 Mdot
.30096 .57858 Mdot
.51053 .25382 Mdot
.39964 .37012 Mdot
.35673 .42005 Mdot
.3797 .34478 Mdot
.26073 .47271 Mdot
.48275 .76064 Mdot
.63518 .67773 Mdot
.3106 .56963 Mdot
.67643 .48146 Mdot
.39853 .64873 Mdot
.53221 .29153 Mdot
.44731 .67457 Mdot
.29018 .60631 Mdot
.62949 .63755 Mdot
.4459 .71414 Mdot
.69181 .52118 Mdot
.63125 .64671 Mdot
.67259 .68569 Mdot
.3036 .58173 Mdot
.71341 .47112 Mdot
.52456 .2927 Mdot
.6672 .6726 Mdot
.27556 .5632 Mdot
.61969 .64156 Mdot
.50283 .74394 Mdot
.24775 .49237 Mdot
.35708 .49694 Mdot
.58695 .36293 Mdot
.57564 .32539 Mdot
.6659 .67569 Mdot
.53403 .25925 Mdot
.28331 .5826 Mdot
.41747 .65773 Mdot
.53381 .25106 Mdot
.37362 .64247 Mdot
.75571 .44267 Mdot
.38628 .64345 Mdot
.77002 .4286 Mdot
.46153 .71388 Mdot
.36157 .34578 Mdot
.52404 .2887 Mdot
.57971 .3336 Mdot
.2843 .47992 Mdot
.57217 .35346 Mdot
.35097 .42018 Mdot
.28483 .5775 Mdot
.37051 .43506 Mdot
.66663 .5042 Mdot
.55175 .28836 Mdot
.42343 .67327 Mdot
.49635 .24154 Mdot
.63742 .65887 Mdot
.26338 .48185 Mdot
.56958 .38456 Mdot
.29186 .59514 Mdot
.44922 .68793 Mdot
.47635 .73227 Mdot
.3684 .62982 Mdot
.66935 .49897 Mdot
.51242 .30284 Mdot
.35953 .42931 Mdot
.50035 .2433 Mdot
.6682 .67999 Mdot
.69343 .68688 Mdot
.70227 .5115 Mdot
.4432 .18742 Mdot
.69875 .48208 Mdot
.59998 .34063 Mdot
.46428 .71489 Mdot
.51652 .24298 Mdot
.36324 .43219 Mdot
.40028 .64307 Mdot
.45728 .67386 Mdot
.54363 .30632 Mdot
.53607 .2306 Mdot
.69027 .68788 Mdot
.65816 .68173 Mdot
.56101 .35877 Mdot
.26352 .47184 Mdot
.26072 .471 Mdot
.33906 .45412 Mdot
.65767 .67321 Mdot
.29265 .5887 Mdot
.6234 .67154 Mdot
.30799 .60142 Mdot
.55406 .2837 Mdot
.686 .47589 Mdot
.72656 .63367 Mdot
.39984 .64679 Mdot
.39582 .37243 Mdot
.49149 .72603 Mdot
.36955 .48299 Mdot
.63662 .66551 Mdot
.57099 .31701 Mdot
.69055 .50679 Mdot
.56405 .67274 Mdot
.6914 .47019 Mdot
.49246 .20559 Mdot
.29622 .45646 Mdot
.5896 .64551 Mdot
.25363 .48528 Mdot
.72407 .46243 Mdot
.33405 .45098 Mdot
.58871 .39079 Mdot
.59178 .4045 Mdot
.29049 .61116 Mdot
.35635 .63125 Mdot
.54661 .25234 Mdot
.3627 .43255 Mdot
.426 .68271 Mdot
.36307 .42973 Mdot
.3625 .42875 Mdot
.38299 .39846 Mdot
.68112 .68256 Mdot
.25119 .49015 Mdot
.369 .43249 Mdot
.78295 .41708 Mdot
.59328 .33783 Mdot
.70395 .52812 Mdot
.40924 .66357 Mdot
.53575 .25018 Mdot
.39442 .6474 Mdot
.26913 .49419 Mdot
.59786 .64791 Mdot
.37843 .64642 Mdot
.299 .59033 Mdot
.46292 .6956 Mdot
.61568 .65921 Mdot
.54588 .2824 Mdot
.57908 .37328 Mdot
.5139 .77166 Mdot
.7789 .42685 Mdot
.56743 .36204 Mdot
.75569 .44734 Mdot
.33323 .4602 Mdot
.46283 .73856 Mdot
.5715 .35529 Mdot
.64829 .64726 Mdot
.71952 .45507 Mdot
.36079 .50053 Mdot
.36943 .455 Mdot
.67525 .50989 Mdot
.58716 .36882 Mdot
.26651 .4869 Mdot
.25785 .50045 Mdot
.72466 .46271 Mdot
.60869 .62247 Mdot
.67177 .68063 Mdot
.54043 .26353 Mdot
.48053 .75585 Mdot
.47474 .73614 Mdot
.63748 .65776 Mdot
.56594 .66952 Mdot
.37423 .45548 Mdot
.37502 .45173 Mdot
.27739 .48575 Mdot
.33359 .48966 Mdot
.78632 .42288 Mdot
.5691 .36535 Mdot
.46103 .72058 Mdot
.28547 .57615 Mdot
.30504 .57129 Mdot
.3638 .43611 Mdot
.3318 .34183 Mdot
.68202 .5217 Mdot
.29714 .60234 Mdot
.5231 .22466 Mdot
.35813 .62594 Mdot
.39271 .43628 Mdot
.55465 .2824 Mdot
.47332 .72891 Mdot
.71221 .54926 Mdot
.62698 .64269 Mdot
.72925 .46206 Mdot
.73068 .45955 Mdot
.68203 .38727 Mdot
.40135 .64963 Mdot
.56766 .36148 Mdot
.78448 .42997 Mdot
.57942 .39799 Mdot
.53455 .23051 Mdot
.39218 .36306 Mdot
.77528 .42758 Mdot
.70914 .52025 Mdot
.58767 .64071 Mdot
.34211 .47914 Mdot
.39647 .41872 Mdot
.68772 .67715 Mdot
.38104 .41011 Mdot
.52948 .27765 Mdot
.64704 .67694 Mdot
.44557 .71499 Mdot
.54959 .2691 Mdot
.62779 .66664 Mdot
.47646 .73778 Mdot
.30312 .58343 Mdot
.25967 .47237 Mdot
.42277 .66365 Mdot
.47054 .71661 Mdot
.37421 .45663 Mdot
.78688 .40893 Mdot
.46735 .73148 Mdot
.4233 .65789 Mdot
.35872 .62877 Mdot
.71923 .4919 Mdot
.51542 .21752 Mdot
.59374 .63207 Mdot
.37503 .43329 Mdot
.67741 .48783 Mdot
.52216 .23606 Mdot
.44899 .71285 Mdot
.39651 .40256 Mdot
.36005 .46467 Mdot
.53051 .24523 Mdot
.5284 .2188 Mdot
.5349 .25699 Mdot
.68007 .68783 Mdot
.3011 .58797 Mdot
.44253 .68344 Mdot
.64948 .66845 Mdot
.53294 .28916 Mdot
.5374 .22626 Mdot
.53939 .33885 Mdot
.37691 .45266 Mdot
.52979 .21777 Mdot
.34562 .62578 Mdot
.28508 .49349 Mdot
.58102 .39896 Mdot
.57842 .3 Mdot
.67546 .54709 Mdot
.60218 .33241 Mdot
.62474 .63132 Mdot
.30806 .59794 Mdot
.54457 .26648 Mdot
.59173 .37994 Mdot
.37125 .45524 Mdot
.38045 .45784 Mdot
.52845 .24861 Mdot
.33942 .33844 Mdot
.47319 .74333 Mdot
.5012 .72908 Mdot
.53355 .24669 Mdot
.72126 .47296 Mdot
.67795 .52827 Mdot
.69119 .48771 Mdot
.36578 .41615 Mdot
.24122 .47695 Mdot
.26323 .40226 Mdot
.37258 .63012 Mdot
.66276 .68215 Mdot
.47111 .72304 Mdot
.36485 .6414 Mdot
.4286 .67472 Mdot
.71384 .45103 Mdot
.53413 .25995 Mdot
.42819 .68979 Mdot
.67887 .68848 Mdot
.66798 .67573 Mdot
.70233 .52669 Mdot
.70164 .47955 Mdot
.68357 .50214 Mdot
.39424 .6387 Mdot
.45657 .70102 Mdot
.24641 .48683 Mdot
.44417 .72957 Mdot
.6823 .46283 Mdot
.76092 .43101 Mdot
.69975 .52936 Mdot
.61315 .64476 Mdot
.44265 .69814 Mdot
.38687 .44273 Mdot
.34906 .51345 Mdot
.67776 .52912 Mdot
.53862 .29 Mdot
.32567 .62787 Mdot
.45908 .17828 Mdot
.31427 .59018 Mdot
.6443 .64796 Mdot
.59486 .37291 Mdot
.37615 .4402 Mdot
.70854 .48177 Mdot
.58234 .30726 Mdot
.57111 .33993 Mdot
.26646 .47785 Mdot
.2991 .62236 Mdot
.63827 .64501 Mdot
.25606 .50194 Mdot
.58925 .38801 Mdot
.27964 .57944 Mdot
.64613 .67521 Mdot
.70079 .52176 Mdot
.74029 .46844 Mdot
.37961 .63878 Mdot
.38896 .36234 Mdot
.59647 .36534 Mdot
.33902 .46668 Mdot
.68974 .47842 Mdot
.5491 .26888 Mdot
.68419 .48835 Mdot
.48492 .76006 Mdot
.71321 .50753 Mdot
.39251 .426 Mdot
.44312 .68512 Mdot
.66931 .67859 Mdot
.25555 .39964 Mdot
.49378 .24665 Mdot
.71111 .50268 Mdot
.58572 .33921 Mdot
.30661 .57666 Mdot
.29846 .55807 Mdot
.57596 .32534 Mdot
.39535 .41695 Mdot
.61802 .65054 Mdot
.44449 .68306 Mdot
.64443 .65949 Mdot
.51335 .21842 Mdot
.49998 .77575 Mdot
.62754 .64218 Mdot
.2383 .47894 Mdot
.54912 .27764 Mdot
.33686 .34041 Mdot
.39112 .41961 Mdot
.64313 .64088 Mdot
.258 .48573 Mdot
.42447 .68189 Mdot
.27373 .50018 Mdot
.35464 .49361 Mdot
.62801 .65523 Mdot
.55888 .35452 Mdot
.25441 .49889 Mdot
.51063 .22549 Mdot
.66162 .67252 Mdot
.249 .50794 Mdot
.5692 .37095 Mdot
.52294 .26382 Mdot
.55176 .27589 Mdot
.52796 .26074 Mdot
.38412 .43444 Mdot
.36686 .51739 Mdot
.524 .28689 Mdot
.65156 .64338 Mdot
.52064 .27884 Mdot
.59249 .3264 Mdot
.70151 .68661 Mdot
.53112 .22141 Mdot
.38721 .40987 Mdot
.30827 .60078 Mdot
.30819 .59647 Mdot
.70608 .50096 Mdot
.51644 .77348 Mdot
.77784 .4183 Mdot
.35179 .44908 Mdot
.36815 .65213 Mdot
.41683 .66733 Mdot
.59598 .34949 Mdot
.35728 .4921 Mdot
.28511 .60144 Mdot
.42784 .66879 Mdot
.27512 .48499 Mdot
.38645 .64581 Mdot
.59444 .39066 Mdot
.38473 .43571 Mdot
.40504 .6566 Mdot
.47267 .7089 Mdot
.31922 .34245 Mdot
.38691 .65024 Mdot
.45425 .70985 Mdot
.66658 .6838 Mdot
.61668 .62985 Mdot
.62081 .65212 Mdot
.70452 .4754 Mdot
.45008 .71791 Mdot
.40136 .3851 Mdot
.7079 .47856 Mdot
.36515 .41108 Mdot
.63205 .6566 Mdot
.34598 .50101 Mdot
.44949 .71921 Mdot
.38924 .41575 Mdot
.26213 .46415 Mdot
.75427 .44971 Mdot
.53026 .24603 Mdot
.35389 .6329 Mdot
.7389 .46632 Mdot
.67191 .67395 Mdot
.4816 .76578 Mdot
.58366 .3229 Mdot
.27775 .58164 Mdot
.40033 .40251 Mdot
.38258 .39615 Mdot
.27832 .58046 Mdot
.29861 .45784 Mdot
.56446 .34271 Mdot
.70729 .47208 Mdot
.72717 .47472 Mdot
.38531 .44844 Mdot
.45534 .72106 Mdot
.51813 .22106 Mdot
.5548 .26925 Mdot
.53286 .30617 Mdot
.2614 .49806 Mdot
.36187 .49275 Mdot
.34074 .48846 Mdot
.39417 .36969 Mdot
.69907 .51097 Mdot
.55532 .35987 Mdot
.27511 .4793 Mdot
.52484 .27053 Mdot
.40321 .39888 Mdot
.40558 .66013 Mdot
.44539 .71001 Mdot
.6802 .51477 Mdot
.65616 .68839 Mdot
.60333 .39255 Mdot
.69485 .53451 Mdot
.38643 .44698 Mdot
.29689 .56768 Mdot
.65945 .68713 Mdot
.48452 .73713 Mdot
.52278 .25723 Mdot
.70656 .4859 Mdot
.51599 .26265 Mdot
.44756 .73145 Mdot
.44974 .71287 Mdot
.40114 .43129 Mdot
.50004 .28104 Mdot
.70529 .51698 Mdot
.36249 .42256 Mdot
.67561 .50619 Mdot
.76768 .43133 Mdot
.61951 .66834 Mdot
.40494 .40624 Mdot
.46232 .68062 Mdot
.61587 .65122 Mdot
.35254 .44181 Mdot
.30747 .58815 Mdot
.28404 .58565 Mdot
.72224 .46642 Mdot
.53541 .29667 Mdot
.52044 .26729 Mdot
.49863 .76575 Mdot
.41228 .69254 Mdot
.34195 .48585 Mdot
.71686 .49529 Mdot
.27102 .57483 Mdot
.62539 .63792 Mdot
.4602 .71078 Mdot
.71273 .6515 Mdot
.61339 .64051 Mdot
.38189 .44839 Mdot
.52902 .27397 Mdot
.47999 .732 Mdot
.58292 .40025 Mdot
.25454 .37821 Mdot
.56723 .32755 Mdot
.51145 .30094 Mdot
.57207 .38203 Mdot
.70053 .67581 Mdot
.68112 .50181 Mdot
.45174 .69094 Mdot
.64718 .65047 Mdot
.62751 .63754 Mdot
.74612 .44736 Mdot
.36709 .63061 Mdot
.50728 .74157 Mdot
.33203 .62516 Mdot
.77805 .42774 Mdot
.53368 .26611 Mdot
.28371 .49148 Mdot
.69226 .48785 Mdot
.76148 .45279 Mdot
.68967 .69006 Mdot
.69346 .68633 Mdot
.44046 .69185 Mdot
.35448 .46515 Mdot
.36149 .62899 Mdot
.35757 .41597 Mdot
.39073 .36163 Mdot
.6379 .65569 Mdot
.46071 .71156 Mdot
.69568 .6953 Mdot
.39406 .4406 Mdot
.36311 .44882 Mdot
.69725 .4513 Mdot
.57385 .36643 Mdot
.70508 .44109 Mdot
.40536 .39878 Mdot
.69856 .47387 Mdot
.48897 .72841 Mdot
.595 .38189 Mdot
.28355 .46307 Mdot
.66771 .68977 Mdot
.58801 .35009 Mdot
.59438 .38641 Mdot
.38304 .37538 Mdot
.38831 .64469 Mdot
.46316 .75578 Mdot
.52322 .21937 Mdot
.69887 .69669 Mdot
.6265 .66939 Mdot
.70653 .67973 Mdot
.38525 .44575 Mdot
.6791 .69217 Mdot
.61018 .3878 Mdot
.35143 .44178 Mdot
.29273 .57413 Mdot
.37283 .6379 Mdot
.33836 .47325 Mdot
.2991 .6078 Mdot
.61855 .64464 Mdot
.60615 .41338 Mdot
.34145 .4837 Mdot
.67745 .51239 Mdot
.4442 .69529 Mdot
.38517 .63839 Mdot
.54361 .25471 Mdot
.68531 .67837 Mdot
.44984 .18142 Mdot
.45905 .70958 Mdot
.37376 .45054 Mdot
.62062 .6368 Mdot
.59604 .37078 Mdot
.5841 .35838 Mdot
.57552 .32931 Mdot
.44234 .70464 Mdot
.59384 .37804 Mdot
.48804 .72268 Mdot
.27269 .4892 Mdot
.39846 .37179 Mdot
.60158 .63326 Mdot
.5327 .26797 Mdot
.50623 .26157 Mdot
.75928 .43653 Mdot
.27062 .47038 Mdot
.39171 .36107 Mdot
.48811 .77596 Mdot
.53222 .27373 Mdot
.3717 .43771 Mdot
.56371 .34266 Mdot
.22987 .50129 Mdot
.53473 .20693 Mdot
.56671 .37353 Mdot
.30291 .56689 Mdot
.47894 .74946 Mdot
.56906 .35391 Mdot
.44271 .71133 Mdot
.36862 .43763 Mdot
.26578 .48121 Mdot
.4728 .76005 Mdot
.52365 .75916 Mdot
.60492 .38678 Mdot
.62196 .66463 Mdot
.25829 .48819 Mdot
.3846 .40442 Mdot
.24788 .47159 Mdot
.59199 .3622 Mdot
.54599 .72716 Mdot
.67626 .49416 Mdot
.77148 .41873 Mdot
.78883 .42255 Mdot
.67603 .67177 Mdot
.71255 .69207 Mdot
.38627 .45472 Mdot
.36379 .62402 Mdot
.24507 .47359 Mdot
.60944 .65134 Mdot
.29904 .46825 Mdot
.36838 .43137 Mdot
.3707 .40925 Mdot
.67538 .5069 Mdot
.58904 .6416 Mdot
.31118 .57086 Mdot
.27257 .48137 Mdot
.54042 .29374 Mdot
.44289 .72155 Mdot
.37762 .42895 Mdot
.48647 .77504 Mdot
.72303 .46871 Mdot
.50413 .77797 Mdot
.38627 .41095 Mdot
.57405 .36713 Mdot
.6818 .69639 Mdot
.66978 .68147 Mdot
.71858 .47167 Mdot
.71799 .47683 Mdot
.38334 .40494 Mdot
.63979 .6618 Mdot
.29751 .47155 Mdot
.25694 .49824 Mdot
.5882 .37196 Mdot
.52925 .23201 Mdot
.35728 .41345 Mdot
.50526 .7373 Mdot
.49288 .26456 Mdot
.36285 .42044 Mdot
.45744 .74769 Mdot
.6852 .50546 Mdot
.7541 .44387 Mdot
.47113 .73057 Mdot
.75827 .44258 Mdot
.50527 .77705 Mdot
.36808 .51585 Mdot
.52996 .22705 Mdot
.3108 .55941 Mdot
.51985 .28038 Mdot
.58868 .3523 Mdot
.37816 .4512 Mdot
.71442 .53869 Mdot
.78873 .42408 Mdot
.25105 .52894 Mdot
.63495 .65026 Mdot
.56264 .37894 Mdot
.29516 .58822 Mdot
.54722 .29312 Mdot
.6995 .49499 Mdot
.59469 .40184 Mdot
.40412 .39883 Mdot
.39709 .64649 Mdot
.31726 .58877 Mdot
.57895 .39383 Mdot
.58622 .35138 Mdot
.59865 .39719 Mdot
.62756 .66649 Mdot
.41894 .65123 Mdot
.69091 .68909 Mdot
.74923 .45143 Mdot
.24624 .48864 Mdot
.37501 .44737 Mdot
.46914 .72086 Mdot
.34659 .4393 Mdot
.62184 .65621 Mdot
.32803 .63537 Mdot
.5364 .26208 Mdot
.59806 .38872 Mdot
.55835 .7024 Mdot
.58742 .40279 Mdot
.28555 .57214 Mdot
.28947 .56274 Mdot
.41078 .66543 Mdot
.60716 .65292 Mdot
.32973 .4684 Mdot
.72721 .48003 Mdot
.52158 .26027 Mdot
.67508 .68748 Mdot
.29096 .57153 Mdot
.39239 .41414 Mdot
.532 .27051 Mdot
.69191 .68653 Mdot
.5163 .2923 Mdot
.6548 .66168 Mdot
.56097 .32625 Mdot
.28468 .54274 Mdot
.38453 .41799 Mdot
.57246 .37039 Mdot
.42196 .66784 Mdot
.66103 .67977 Mdot
.3713 .63334 Mdot
.59383 .39028 Mdot
.76363 .43232 Mdot
.67119 .68657 Mdot
.40271 .40523 Mdot
.44748 .67554 Mdot
.4216 .68105 Mdot
.4282 .66107 Mdot
.72173 .3836 Mdot
.77483 .42324 Mdot
.68163 .50649 Mdot
.61159 .64311 Mdot
.67691 .48675 Mdot
.54936 .27855 Mdot
.28597 .48816 Mdot
.71536 .48961 Mdot
.41339 .64688 Mdot
.69434 .46625 Mdot
.29133 .46981 Mdot
.61608 .66085 Mdot
.68835 .53574 Mdot
.34185 .44217 Mdot
.30544 .58896 Mdot
.58126 .34886 Mdot
.51205 .27265 Mdot
.27044 .48922 Mdot
.34852 .46933 Mdot
.57808 .37727 Mdot
.38765 .41526 Mdot
.62515 .65754 Mdot
.25929 .39853 Mdot
.24772 .48154 Mdot
.76244 .43643 Mdot
.51218 .76872 Mdot
.72796 .47088 Mdot
.51155 .20108 Mdot
.35239 .43182 Mdot
.38753 .42114 Mdot
.28739 .58557 Mdot
.32145 .63051 Mdot
.67905 .68343 Mdot
.2441 .49151 Mdot
.77204 .43555 Mdot
.43258 .68048 Mdot
.41931 .67263 Mdot
.38935 .36525 Mdot
.57076 .37016 Mdot
.62485 .62908 Mdot
.3879 .43145 Mdot
.57538 .39473 Mdot
.35282 .49129 Mdot
.68796 .67413 Mdot
.77538 .42166 Mdot
.75853 .4527 Mdot
.41891 .67434 Mdot
.67523 .52232 Mdot
.28735 .58747 Mdot
.59396 .37571 Mdot
.79088 .4183 Mdot
.68201 .682 Mdot
.52066 .26049 Mdot
.36546 .41301 Mdot
.32774 .34053 Mdot
.67511 .52349 Mdot
.71192 .47301 Mdot
.29737 .47119 Mdot
.49016 .777 Mdot
.52629 .32012 Mdot
.65275 .67492 Mdot
.4052 .66065 Mdot
.42985 .49493 Mdot
.45004 .30389 Mdot
.6141 .63166 Mdot
.29681 .57208 Mdot
.6791 .52677 Mdot
.65749 .40439 Mdot
.42884 .67291 Mdot
.52135 .25843 Mdot
.34359 .44466 Mdot
.42264 .6735 Mdot
.78293 .42624 Mdot
.43863 .67314 Mdot
.57363 .35854 Mdot
.61469 .6595 Mdot
.69905 .50226 Mdot
.58884 .64045 Mdot
.46004 .67813 Mdot
.53503 .26466 Mdot
.37659 .35416 Mdot
.31012 .602 Mdot
.37651 .64416 Mdot
.29945 .58463 Mdot
.60728 .36795 Mdot
.303 .58553 Mdot
.40467 .66217 Mdot
.39103 .41779 Mdot
.33419 .48067 Mdot
.7499 .44435 Mdot
.37617 .4063 Mdot
.36575 .46553 Mdot
.26022 .46487 Mdot
.35833 .42186 Mdot
.36187 .42894 Mdot
.40229 .41985 Mdot
.46909 .75302 Mdot
.34854 .4885 Mdot
.4663 .70972 Mdot
.49102 .74727 Mdot
.75035 .45097 Mdot
.55151 .2892 Mdot
.5281 .22054 Mdot
.34777 .49037 Mdot
.3288 .34117 Mdot
.36168 .63081 Mdot
.43568 .69357 Mdot
.6678 .67878 Mdot
.25466 .47803 Mdot
.52374 .31752 Mdot
.33949 .4923 Mdot
.70649 .50149 Mdot
.72195 .47503 Mdot
.34327 .43351 Mdot
.46145 .17788 Mdot
.4083 .404 Mdot
.28539 .48353 Mdot
.38401 .43239 Mdot
.40427 .41761 Mdot
.7219 .48771 Mdot
.36167 .34517 Mdot
.28818 .60116 Mdot
.40249 .66273 Mdot
.51939 .25506 Mdot
.56893 .35719 Mdot
.26579 .48132 Mdot
.41635 .50628 Mdot
.38179 .64159 Mdot
.28663 .58411 Mdot
.70574 .49373 Mdot
.45523 .71534 Mdot
.28381 .48208 Mdot
.65097 .66988 Mdot
.26152 .37101 Mdot
.50156 .77532 Mdot
.64713 .67068 Mdot
.5228 .26266 Mdot
.69453 .52261 Mdot
.36656 .44276 Mdot
.70073 .46639 Mdot
.39632 .43542 Mdot
.26337 .50325 Mdot
.53087 .22912 Mdot
.41056 .64793 Mdot
.66532 .68858 Mdot
.46946 .749 Mdot
.50601 .74419 Mdot
.29331 .40447 Mdot
.73705 .43962 Mdot
.71063 .51181 Mdot
.4982 .2455 Mdot
.45072 .69558 Mdot
.36838 .46559 Mdot
.34391 .62481 Mdot
.45971 .73649 Mdot
.39425 .64266 Mdot
.25981 .37683 Mdot
.34841 .33322 Mdot
.40232 .41667 Mdot
.41916 .66751 Mdot
.69272 .52467 Mdot
.53013 .2255 Mdot
.37556 .45854 Mdot
.59434 .37409 Mdot
.42109 .67566 Mdot
.67814 .52065 Mdot
.36744 .34868 Mdot
.70086 .47556 Mdot
.43491 .67943 Mdot
.72642 .4677 Mdot
.62137 .66996 Mdot
.71463 .49246 Mdot
.36399 .40675 Mdot
.38827 .42657 Mdot
.41026 .66677 Mdot
.4499 .71307 Mdot
.28494 .57313 Mdot
.34921 .43066 Mdot
.45111 .69202 Mdot
.68111 .47221 Mdot
.4176 .68461 Mdot
.2828 .58346 Mdot
.36385 .4635 Mdot
.52184 .28304 Mdot
.24502 .49823 Mdot
.2516 .39239 Mdot
.24496 .4846 Mdot
.5327 .26156 Mdot
.38723 .62849 Mdot
.38672 .43839 Mdot
.35616 .33906 Mdot
.77634 .43243 Mdot
.33639 .45526 Mdot
.5983 .37862 Mdot
.28022 .59312 Mdot
.29014 .34474 Mdot
.29022 .57292 Mdot
.42734 .66384 Mdot
.4384 .68187 Mdot
.69486 .45908 Mdot
.42603 .67263 Mdot
.59674 .37501 Mdot
.62858 .63096 Mdot
.50331 .74345 Mdot
.55572 .36135 Mdot
.57849 .33992 Mdot
.60101 .36491 Mdot
.56933 .38227 Mdot
.52198 .31455 Mdot
.75318 .43715 Mdot
.57937 .34279 Mdot
.46199 .70262 Mdot
.68212 .55247 Mdot
.57728 .32032 Mdot
.62524 .62909 Mdot
.59446 .38482 Mdot
.33611 .45711 Mdot
.28742 .57973 Mdot
.47845 .76553 Mdot
.64745 .6677 Mdot
.60859 .38454 Mdot
.36862 .46404 Mdot
.41944 .67587 Mdot
.37528 .42945 Mdot
.53625 .29476 Mdot
.4488 .71989 Mdot
.70541 .48365 Mdot
.53235 .23221 Mdot
.58322 .39027 Mdot
.53462 .25021 Mdot
.68293 .48724 Mdot
.6586 .6601 Mdot
.34215 .44892 Mdot
.50969 .27432 Mdot
.55166 .28444 Mdot
.33767 .45524 Mdot
.44226 .69022 Mdot
.60725 .38707 Mdot
.35548 .46768 Mdot
.29208 .58625 Mdot
.47666 .74095 Mdot
.54835 .73494 Mdot
.36295 .44325 Mdot
.29091 .56339 Mdot
.4086 .6678 Mdot
.57402 .39265 Mdot
.70628 .47822 Mdot
.39592 .40261 Mdot
.64053 .65223 Mdot
.6365 .658 Mdot
.78238 .42599 Mdot
.44653 .73933 Mdot
.66895 .5162 Mdot
.34228 .43127 Mdot
.59245 .38666 Mdot
.39533 .40912 Mdot
.68484 .45938 Mdot
.53152 .75884 Mdot
.47543 .72332 Mdot
.75026 .45416 Mdot
.37344 .47626 Mdot
.59496 .628 Mdot
.7606 .43864 Mdot
.40423 .66362 Mdot
.44684 .73397 Mdot
.46956 .72793 Mdot
.52206 .22546 Mdot
.70071 .48175 Mdot
.47957 .76146 Mdot
.48188 .75177 Mdot
.28423 .58373 Mdot
.3418 .43626 Mdot
.40548 .65835 Mdot
.77989 .42401 Mdot
.51918 .26471 Mdot
.7659 .44117 Mdot
.49267 .26011 Mdot
.65683 .67951 Mdot
.28989 .46354 Mdot
.2693 .46992 Mdot
.44238 .18659 Mdot
.40236 .3963 Mdot
.38242 .4361 Mdot
.38636 .63446 Mdot
.52728 .29972 Mdot
.51457 .24648 Mdot
.44897 .69407 Mdot
.47783 .72603 Mdot
.5364 .2441 Mdot
.35604 .51256 Mdot
.30547 .34773 Mdot
.37807 .47072 Mdot
.41897 .65025 Mdot
.49595 .7273 Mdot
.62953 .65213 Mdot
.42276 .67635 Mdot
.70039 .56222 Mdot
.69551 .53202 Mdot
.71108 .50369 Mdot
.66726 .68248 Mdot
.36711 .44443 Mdot
.71512 .50463 Mdot
.29846 .60097 Mdot
.70883 .55982 Mdot
.30692 .57935 Mdot
.79387 .40702 Mdot
.34701 .43493 Mdot
.57629 .64801 Mdot
.69765 .67528 Mdot
.28123 .58095 Mdot
.37227 .51808 Mdot
.52565 .25195 Mdot
.38251 .63328 Mdot
.60762 .64878 Mdot
.36208 .62945 Mdot
.38585 .41892 Mdot
.41204 .65612 Mdot
.65712 .68409 Mdot
.54051 .7393 Mdot
.28565 .60084 Mdot
.29333 .59675 Mdot
.34623 .63109 Mdot
.46368 .69862 Mdot
.70546 .47682 Mdot
.39 .64232 Mdot
.48412 .75762 Mdot
.30592 .58501 Mdot
.68097 .53083 Mdot
.27164 .50876 Mdot
.41457 .65024 Mdot
.51644 .21946 Mdot
.44693 .72546 Mdot
.53296 .2397 Mdot
.47733 .76267 Mdot
.74637 .44975 Mdot
.35705 .43554 Mdot
.75155 .44975 Mdot
.53732 .28888 Mdot
.73187 .46336 Mdot
.62578 .65908 Mdot
.58425 .38205 Mdot
.61796 .65216 Mdot
.28125 .49121 Mdot
.37018 .62998 Mdot
.62307 .63028 Mdot
.30596 .41232 Mdot
.393 .4166 Mdot
.47669 .76264 Mdot
.70426 .49332 Mdot
.76945 .44194 Mdot
.26717 .49368 Mdot
.45101 .70546 Mdot
.6946 .46123 Mdot
.2751 .56481 Mdot
.71225 .54751 Mdot
.27901 .58664 Mdot
.71689 .65558 Mdot
.4405 .68008 Mdot
.77519 .43741 Mdot
.28745 .48225 Mdot
.48733 .74718 Mdot
.69926 .52579 Mdot
.65584 .66081 Mdot
.63979 .65154 Mdot
.38883 .39332 Mdot
.58832 .63831 Mdot
.70676 .49895 Mdot
.49865 .77817 Mdot
.47694 .76007 Mdot
.52673 .76503 Mdot
.53359 .25781 Mdot
.68615 .52123 Mdot
.58953 .37195 Mdot
.45267 .66971 Mdot
.6845 .47577 Mdot
.45181 .17951 Mdot
.78192 .35688 Mdot
.66965 .49574 Mdot
.44725 .71871 Mdot
.44379 .70445 Mdot
.31469 .58623 Mdot
.26742 .49112 Mdot
.6985 .49764 Mdot
.69019 .55873 Mdot
.36394 .49257 Mdot
.5819 .38298 Mdot
.78724 .41645 Mdot
.40117 .38602 Mdot
.29694 .5857 Mdot
.66004 .67587 Mdot
.36173 .44911 Mdot
.4748 .719 Mdot
.40663 .40009 Mdot
.61283 .65074 Mdot
.71073 .44924 Mdot
.38678 .41743 Mdot
.52236 .26092 Mdot
.64791 .65521 Mdot
.64716 .65851 Mdot
.73563 .45647 Mdot
.44631 .73919 Mdot
.36645 .63526 Mdot
.70223 .47917 Mdot
.30264 .59212 Mdot
.58056 .37556 Mdot
.40341 .41063 Mdot
.40219 .64419 Mdot
.37825 .63141 Mdot
.68665 .52192 Mdot
.3381 .46765 Mdot
.61011 .63531 Mdot
.67248 .48644 Mdot
.30061 .57077 Mdot
.70761 .50935 Mdot
.55184 .34556 Mdot
.7022 .52889 Mdot
.48501 .71934 Mdot
.59929 .35506 Mdot
.41113 .65355 Mdot
.56861 .34306 Mdot
.68353 .38749 Mdot
.52227 .26472 Mdot
.72281 .48368 Mdot
.52651 .75518 Mdot
.75412 .45224 Mdot
.3559 .42633 Mdot
.38612 .44264 Mdot
.67887 .49071 Mdot
.53525 .26854 Mdot
.60341 .33467 Mdot
.52651 .29588 Mdot
.44651 .71411 Mdot
.28491 .60209 Mdot
.79665 .37912 Mdot
.75024 .45973 Mdot
.64855 .68043 Mdot
.39888 .66308 Mdot
.57458 .3386 Mdot
.63335 .66239 Mdot
.64909 .65922 Mdot
.5409 .27008 Mdot
.75931 .45394 Mdot
.4009 .64774 Mdot
.59186 .6433 Mdot
.48689 .74384 Mdot
.36188 .34004 Mdot
.57408 .38979 Mdot
.50149 .24383 Mdot
.56298 .34489 Mdot
.27504 .48359 Mdot
.59227 .63416 Mdot
.37082 .42339 Mdot
.54334 .29516 Mdot
.66461 .68021 Mdot
.52242 .28681 Mdot
.29894 .57124 Mdot
.714 .45118 Mdot
.38697 .67754 Mdot
.38513 .39408 Mdot
.34947 .44546 Mdot
.66084 .68237 Mdot
.3826 .51968 Mdot
.39542 .65402 Mdot
.47641 .75707 Mdot
.68168 .50156 Mdot
.25368 .38488 Mdot
.40496 .4215 Mdot
.3723 .46056 Mdot
.68962 .47475 Mdot
.56832 .36807 Mdot
.76752 .42306 Mdot
.36845 .46037 Mdot
.6204 .64738 Mdot
.29376 .57248 Mdot
.59997 .62585 Mdot
.33823 .43941 Mdot
.35418 .43596 Mdot
.29682 .59909 Mdot
.29907 .57989 Mdot
.61761 .65178 Mdot
.56871 .37733 Mdot
.59931 .39272 Mdot
.41953 .65256 Mdot
.34446 .43648 Mdot
.36839 .48893 Mdot
.3869 .43279 Mdot
.52577 .25293 Mdot
.24715 .3969 Mdot
.29285 .46846 Mdot
.25299 .49187 Mdot
.35586 .49965 Mdot
.3687 .4353 Mdot
.65588 .68154 Mdot
.44334 .70158 Mdot
.61337 .63421 Mdot
.60208 .65438 Mdot
.70083 .46108 Mdot
.52112 .28471 Mdot
.38206 .40472 Mdot
.54691 .27175 Mdot
.4096 .39088 Mdot
.52041 .20775 Mdot
.27141 .47956 Mdot
.29196 .48235 Mdot
.51563 .22462 Mdot
.39303 .42533 Mdot
.67805 .49971 Mdot
.72325 .49184 Mdot
.30825 .59752 Mdot
.35112 .41937 Mdot
.64019 .67706 Mdot
.6412 .63929 Mdot
.77012 .42426 Mdot
.73272 .47954 Mdot
.53645 .2951 Mdot
.62327 .41354 Mdot
.3034 .58407 Mdot
.38618 .39886 Mdot
.57329 .38208 Mdot
.67139 .50867 Mdot
.57218 .34239 Mdot
.76236 .43082 Mdot
.60185 .64507 Mdot
.63516 .64042 Mdot
.34962 .42617 Mdot
.4865 .18101 Mdot
.46081 .74038 Mdot
.44475 .70508 Mdot
.63938 .63606 Mdot
.72785 .47129 Mdot
.57583 .35455 Mdot
.34868 .62576 Mdot
.39894 .66172 Mdot
.5498 .28496 Mdot
.39515 .40581 Mdot
.70281 .5242 Mdot
.45622 .69327 Mdot
.53884 .29197 Mdot
.24436 .48222 Mdot
.66804 .52841 Mdot
.37757 .42188 Mdot
.28561 .5616 Mdot
.45835 .70552 Mdot
.26509 .48836 Mdot
.41231 .64839 Mdot
.63672 .65574 Mdot
.59391 .64081 Mdot
.35282 .43905 Mdot
.38095 .66824 Mdot
.48747 .72654 Mdot
.59159 .63856 Mdot
.51964 .22433 Mdot
.58702 .37621 Mdot
.52256 .28632 Mdot
.67854 .51029 Mdot
.52206 .26347 Mdot
.69046 .46886 Mdot
.7622 .43867 Mdot
.40659 .65629 Mdot
.53185 .27107 Mdot
.27763 .4604 Mdot
.59294 .37255 Mdot
.53406 .22086 Mdot
.26155 .47982 Mdot
.29207 .56775 Mdot
.69356 .50845 Mdot
.54729 .27594 Mdot
.39999 .40453 Mdot
.55709 .70337 Mdot
.61163 .65892 Mdot
.62109 .6567 Mdot
.57353 .35715 Mdot
.69234 .52089 Mdot
.39848 .64331 Mdot
.35325 .49219 Mdot
.48019 .71039 Mdot
.35667 .4696 Mdot
.37138 .4113 Mdot
.49028 .72771 Mdot
.39808 .64282 Mdot
.3542 .44212 Mdot
.39652 .37434 Mdot
.59107 .37756 Mdot
.64231 .65741 Mdot
.44907 .717 Mdot
.45655 .71991 Mdot
.71196 .48121 Mdot
.41842 .67257 Mdot
.50587 .29143 Mdot
.61397 .65333 Mdot
.58573 .40177 Mdot
.60975 .6398 Mdot
.58001 .30376 Mdot
.67195 .49224 Mdot
.53452 .73968 Mdot
.46034 .75528 Mdot
.28541 .58949 Mdot
.40465 .65677 Mdot
.53562 .25789 Mdot
.42428 .67547 Mdot
.41443 .66384 Mdot
.34077 .44327 Mdot
.5748 .38578 Mdot
.58326 .34711 Mdot
.27562 .4806 Mdot
.45963 .73875 Mdot
.36197 .43627 Mdot
.25338 .48166 Mdot
.34706 .44095 Mdot
.2669 .48742 Mdot
.46625 .75484 Mdot
.41436 .50813 Mdot
.40979 .66409 Mdot
.45645 .70146 Mdot
.49219 .26065 Mdot
.59307 .36673 Mdot
.56877 .3396 Mdot
.61496 .67049 Mdot
.35528 .46561 Mdot
.75534 .44387 Mdot
.3014 .59017 Mdot
.58648 .38729 Mdot
.2362 .48127 Mdot
.5488 .26149 Mdot
.39429 .43911 Mdot
.5742 .37895 Mdot
.70399 .48947 Mdot
.2862 .58983 Mdot
.37762 .45145 Mdot
.56704 .3582 Mdot
.40166 .6514 Mdot
.47304 .73929 Mdot
.39095 .65632 Mdot
.5382 .2531 Mdot
.6039 .64224 Mdot
.29934 .58855 Mdot
.6798 .50266 Mdot
.7528 .44558 Mdot
.40967 .6521 Mdot
.72105 .46339 Mdot
.64006 .64397 Mdot
.37069 .45492 Mdot
.63164 .65615 Mdot
.54541 .2537 Mdot
.44998 .72077 Mdot
.29127 .58962 Mdot
.31665 .60352 Mdot
.43852 .68204 Mdot
.59207 .38109 Mdot
.51787 .28071 Mdot
.72354 .45701 Mdot
.47377 .72299 Mdot
.60202 .64271 Mdot
.71514 .47562 Mdot
.2903 .59556 Mdot
.50273 .19944 Mdot
.36084 .44868 Mdot
.3595 .4144 Mdot
.43868 .65414 Mdot
.33157 .47094 Mdot
.7487 .45164 Mdot
.39618 .63748 Mdot
.28473 .57614 Mdot
.27767 .4985 Mdot
.54382 .21955 Mdot
.55701 .31122 Mdot
.37514 .43407 Mdot
.24546 .4726 Mdot
.33756 .48714 Mdot
.52117 .76186 Mdot
.26413 .49189 Mdot
.68736 .46032 Mdot
.50054 .2433 Mdot
.60026 .65418 Mdot
.57732 .37845 Mdot
.71729 .45387 Mdot
.39805 .37603 Mdot
.35788 .44948 Mdot
.40612 .67992 Mdot
.29567 .56937 Mdot
.62053 .63323 Mdot
.39935 .51498 Mdot
.70639 .49205 Mdot
.7931 .4149 Mdot
.34408 .42714 Mdot
.39256 .65224 Mdot
.56652 .6634 Mdot
.57749 .38516 Mdot
.56628 .34009 Mdot
.53953 .2898 Mdot
.69836 .4552 Mdot
.57031 .3261 Mdot
.61072 .63612 Mdot
.3996 .39772 Mdot
.29247 .46753 Mdot
.55314 .72661 Mdot
.44827 .68679 Mdot
.62718 .66919 Mdot
.5766 .29711 Mdot
.37167 .41755 Mdot
.46127 .74565 Mdot
.42886 .67333 Mdot
.55099 .28629 Mdot
.75596 .43775 Mdot
.77719 .42963 Mdot
.46794 .17884 Mdot
.6071 .37573 Mdot
.67172 .50586 Mdot
.57775 .33164 Mdot
.30167 .59446 Mdot
.2666 .48034 Mdot
.60718 .6589 Mdot
.35547 .42474 Mdot
.39235 .66454 Mdot
.4247 .65876 Mdot
.38601 .43045 Mdot
.5176 .25388 Mdot
.32404 .63012 Mdot
.30506 .60592 Mdot
.38866 .37713 Mdot
.69223 .52511 Mdot
.36629 .41637 Mdot
.5065 .29351 Mdot
.57237 .39274 Mdot
.33339 .465 Mdot
.70494 .47918 Mdot
.59939 .35551 Mdot
.51621 .25323 Mdot
.42717 .65895 Mdot
.57723 .37645 Mdot
.29926 .5696 Mdot
.40028 .4204 Mdot
.51852 .22502 Mdot
.29752 .59701 Mdot
.49687 .72614 Mdot
.56051 .3418 Mdot
.71388 .49826 Mdot
.48104 .73493 Mdot
.36129 .42411 Mdot
.58768 .37796 Mdot
.39281 .40702 Mdot
.50847 .74762 Mdot
.36793 .4088 Mdot
.55098 .71121 Mdot
.4454 .69717 Mdot
.62363 .6417 Mdot
.28775 .58494 Mdot
.37864 .41942 Mdot
.58387 .33699 Mdot
.57824 .35308 Mdot
.36948 .4642 Mdot
.41149 .65296 Mdot
.42112 .66765 Mdot
.38692 .64629 Mdot
.71298 .48577 Mdot
.39124 .45594 Mdot
.6285 .64692 Mdot
.56996 .37748 Mdot
.58872 .63697 Mdot
.24905 .47222 Mdot
.53542 .24848 Mdot
.55101 .72217 Mdot
.36299 .45895 Mdot
.45428 .70909 Mdot
.30861 .34897 Mdot
.43657 .71447 Mdot
.625 .67607 Mdot
.62905 .67055 Mdot
.45821 .7312 Mdot
.37615 .43612 Mdot
.27579 .48498 Mdot
.29487 .46684 Mdot
.59347 .63465 Mdot
.5962 .39645 Mdot
.54403 .3621 Mdot
.69044 .5317 Mdot
.50552 .19978 Mdot
.67345 .68754 Mdot
.70154 .68276 Mdot
.28277 .58348 Mdot
.4785 .74128 Mdot
.60154 .63442 Mdot
.64891 .66286 Mdot
.70301 .50261 Mdot
.28468 .58561 Mdot
.38117 .42069 Mdot
.59734 .3732 Mdot
.66735 .6732 Mdot
.383 .45523 Mdot
.28453 .57236 Mdot
.76398 .42722 Mdot
.38421 .63856 Mdot
.54688 .73999 Mdot
.24624 .47539 Mdot
.37746 .64597 Mdot
.71576 .53454 Mdot
.47812 .7608 Mdot
.36278 .43396 Mdot
.58273 .36213 Mdot
.72313 .46464 Mdot
.3708 .45098 Mdot
.75073 .455 Mdot
.61085 .63073 Mdot
.55758 .70828 Mdot
.26601 .4678 Mdot
.7082 .55894 Mdot
.35742 .44005 Mdot
.31241 .60126 Mdot
.52376 .27348 Mdot
.59869 .63217 Mdot
.41649 .68077 Mdot
.39368 .40056 Mdot
.71019 .47313 Mdot
.6874 .53461 Mdot
.41979 .6576 Mdot
.39375 .65861 Mdot
.53137 .74798 Mdot
.58956 .36971 Mdot
.71423 .46188 Mdot
.5887 .37732 Mdot
.3898 .37561 Mdot
.59095 .64163 Mdot
.51602 .25181 Mdot
.72612 .46686 Mdot
.67964 .68717 Mdot
.29214 .56756 Mdot
.4413 .71988 Mdot
.45103 .66683 Mdot
.30344 .60162 Mdot
.70441 .45465 Mdot
.52679 .23893 Mdot
.25913 .48913 Mdot
.29197 .60521 Mdot
.52758 .2322 Mdot
.7093 .49204 Mdot
.46769 .73975 Mdot
.43056 .67149 Mdot
.4417 .69829 Mdot
.28777 .46327 Mdot
.37612 .62731 Mdot
.38576 .3561 Mdot
.33325 .47762 Mdot
.50064 .7663 Mdot
.34776 .48099 Mdot
.61844 .65519 Mdot
.45906 .70827 Mdot
.26604 .4878 Mdot
.27633 .58644 Mdot
.40311 .37964 Mdot
.34501 .45826 Mdot
.30031 .57783 Mdot
.35518 .46583 Mdot
.49332 .72835 Mdot
.38044 .632 Mdot
.25464 .49127 Mdot
.61602 .6564 Mdot
.53097 .2489 Mdot
.48567 .75803 Mdot
.36986 .414 Mdot
.49653 .73076 Mdot
.25662 .48472 Mdot
.5519 .70757 Mdot
.30203 .57732 Mdot
.70975 .44913 Mdot
.40239 .40045 Mdot
.69575 .53451 Mdot
.31326 .60667 Mdot
.4988 .73207 Mdot
.61933 .66277 Mdot
.30582 .60633 Mdot
.67351 .54444 Mdot
.40303 .51321 Mdot
.58488 .36053 Mdot
.52024 .26838 Mdot
.59821 .35483 Mdot
.61996 .65393 Mdot
.35938 .456 Mdot
.3988 .42087 Mdot
.33064 .46868 Mdot
.38946 .37547 Mdot
.5934 .36935 Mdot
.51943 .21793 Mdot
.50374 .7469 Mdot
.39134 .44063 Mdot
.71776 .50094 Mdot
.47642 .75009 Mdot
.40095 .37914 Mdot
.29663 .45939 Mdot
.29818 .56361 Mdot
.45827 .73627 Mdot
.44408 .73616 Mdot
.52467 .31873 Mdot
.52865 .26451 Mdot
.34977 .43821 Mdot
.51181 .23077 Mdot
.29751 .59006 Mdot
.61137 .64538 Mdot
.33111 .48141 Mdot
.673 .48968 Mdot
.27008 .49629 Mdot
.71033 .49161 Mdot
.34662 .4487 Mdot
.4454 .72275 Mdot
.59496 .63851 Mdot
.77944 .43093 Mdot
.78539 .42092 Mdot
.38518 .3532 Mdot
.78823 .42723 Mdot
.54216 .26188 Mdot
.53949 .26374 Mdot
.59815 .6355 Mdot
.38079 .43621 Mdot
.26311 .49546 Mdot
.32604 .60019 Mdot
.35471 .46256 Mdot
.36879 .44472 Mdot
.68373 .68593 Mdot
.66944 .68384 Mdot
.72555 .47083 Mdot
.35486 .44453 Mdot
.38959 .44811 Mdot
.45178 .7277 Mdot
.53283 .29962 Mdot
.70872 .45823 Mdot
.53778 .29249 Mdot
.69378 .47611 Mdot
.29116 .34433 Mdot
.58161 .39283 Mdot
.53889 .25771 Mdot
.67345 .6907 Mdot
.45712 .7131 Mdot
.5955 .37237 Mdot
.68873 .50592 Mdot
.71806 .46208 Mdot
.40338 .38833 Mdot
.44767 .68529 Mdot
.47577 .75769 Mdot
.53705 .24825 Mdot
.64305 .6402 Mdot
.29905 .60118 Mdot
.56335 .34411 Mdot
.57001 .27407 Mdot
.71384 .46752 Mdot
.5021 .77196 Mdot
.44595 .6635 Mdot
.37866 .4101 Mdot
.47219 .73876 Mdot
.38177 .41385 Mdot
.39082 .64275 Mdot
.49011 .74715 Mdot
.33883 .43718 Mdot
.38333 .64768 Mdot
.67093 .50197 Mdot
.79656 .39278 Mdot
.2801 .57875 Mdot
.67928 .69773 Mdot
.30091 .59148 Mdot
.77344 .41914 Mdot
.31194 .34759 Mdot
.39223 .43604 Mdot
.36991 .41307 Mdot
.48223 .20278 Mdot
.34488 .48905 Mdot
.56625 .34734 Mdot
.58561 .36086 Mdot
.47082 .74291 Mdot
.5965 .35292 Mdot
.27322 .48468 Mdot
.53332 .27626 Mdot
.68173 .50287 Mdot
.35284 .33906 Mdot
.5314 .24027 Mdot
.42973 .66579 Mdot
.28871 .60081 Mdot
.49615 .76438 Mdot
.71247 .51363 Mdot
.57056 .36584 Mdot
.61361 .63136 Mdot
.24388 .50029 Mdot
.70858 .48258 Mdot
.6723 .67781 Mdot
.2743 .47172 Mdot
.70683 .44786 Mdot
.61697 .65635 Mdot
.79636 .3867 Mdot
.65607 .67353 Mdot
.63232 .63242 Mdot
.28695 .47678 Mdot
.53312 .27699 Mdot
.59276 .34491 Mdot
.51102 .22386 Mdot
.62877 .6663 Mdot
.77598 .41535 Mdot
.69527 .51659 Mdot
.26748 .50167 Mdot
.38005 .62827 Mdot
.59512 .38562 Mdot
.36073 .44371 Mdot
.66022 .67818 Mdot
.41 .39207 Mdot
.59393 .34685 Mdot
.6364 .64364 Mdot
.31411 .60598 Mdot
.24706 .39354 Mdot
.58511 .36922 Mdot
.5879 .35093 Mdot
.54402 .28107 Mdot
.77175 .42968 Mdot
.47034 .75848 Mdot
.55034 .26504 Mdot
.34118 .50137 Mdot
.34888 .43297 Mdot
.61524 .6505 Mdot
.57639 .3754 Mdot
.63479 .64961 Mdot
.51641 .26881 Mdot
.52285 .21912 Mdot
.42838 .66094 Mdot
.38878 .64823 Mdot
.55927 .3263 Mdot
.35868 .50101 Mdot
.33948 .48471 Mdot
.40448 .67706 Mdot
.45193 .74307 Mdot
.37103 .51681 Mdot
.5133 .26661 Mdot
.54455 .28363 Mdot
.31262 .60337 Mdot
.25096 .48595 Mdot
.29546 .57607 Mdot
.2535 .4749 Mdot
.67197 .45261 Mdot
.28794 .58752 Mdot
.72161 .45768 Mdot
.25059 .47664 Mdot
.69976 .69483 Mdot
.3104 .59504 Mdot
.38028 .40736 Mdot
.69353 .48372 Mdot
.33688 .45875 Mdot
.68007 .5195 Mdot
.3586 .43263 Mdot
.68482 .4588 Mdot
.68 .50226 Mdot
.62588 .41568 Mdot
.28189 .40367 Mdot
.56869 .34616 Mdot
.51548 .23916 Mdot
.51105 .2786 Mdot
.36927 .34923 Mdot
.46544 .73606 Mdot
.32566 .62475 Mdot
.37765 .40914 Mdot
.70197 .50597 Mdot
.61487 .63014 Mdot
.31841 .59269 Mdot
.3665 .40628 Mdot
.30481 .597 Mdot
.44115 .72102 Mdot
.68924 .52442 Mdot
.52147 .27704 Mdot
.73967 .46326 Mdot
.77902 .41831 Mdot
.66904 .50139 Mdot
.37735 .37942 Mdot
.30463 .56939 Mdot
.50721 .29439 Mdot
.37366 .63449 Mdot
.60291 .33976 Mdot
.42501 .67284 Mdot
.57953 .379 Mdot
.53606 .28681 Mdot
.25651 .39807 Mdot
.47641 .75331 Mdot
.68935 .47532 Mdot
.37665 .42193 Mdot
.56792 .37851 Mdot
.51133 .22255 Mdot
.47952 .72542 Mdot
.51764 .22492 Mdot
.6884 .49868 Mdot
.58385 .37445 Mdot
.3977 .44772 Mdot
.427 .49816 Mdot
.26539 .50436 Mdot
.37742 .41777 Mdot
.5356 .24345 Mdot
.44948 .68668 Mdot
.30502 .59793 Mdot
.66149 .67322 Mdot
.26833 .49042 Mdot
.35993 .44548 Mdot
.71177 .55644 Mdot
.44276 .71911 Mdot
.53346 .26014 Mdot
.65888 .67729 Mdot
.52738 .26336 Mdot
.56757 .34121 Mdot
.39306 .64539 Mdot
.56583 .34091 Mdot
.29435 .57025 Mdot
.60532 .63314 Mdot
.47564 .75684 Mdot
.75716 .43201 Mdot
.607 .38203 Mdot
.67657 .49615 Mdot
.25412 .39973 Mdot
.41799 .65849 Mdot
.68065 .67426 Mdot
.74014 .46265 Mdot
.63896 .6297 Mdot
.25195 .49785 Mdot
.6458 .65092 Mdot
.37644 .40929 Mdot
.43755 .69481 Mdot
.5926 .62962 Mdot
.78357 .42274 Mdot
.25057 .46958 Mdot
.55712 .35488 Mdot
.39267 .42362 Mdot
.51567 .77408 Mdot
.69138 .67271 Mdot
.40521 .66158 Mdot
.67538 .68866 Mdot
.34982 .45439 Mdot
.59154 .37436 Mdot
.34442 .43466 Mdot
.63252 .66891 Mdot
.68467 .68823 Mdot
.76264 .4446 Mdot
.37209 .42438 Mdot
.52599 .25595 Mdot
.71494 .45199 Mdot
.68349 .53324 Mdot
.72232 .47664 Mdot
.41059 .67349 Mdot
.59074 .3929 Mdot
.58935 .36756 Mdot
.31776 .34455 Mdot
.63793 .65148 Mdot
.56802 .34688 Mdot
.39762 .42925 Mdot
.3833 .35716 Mdot
.44342 .69798 Mdot
.69273 .49325 Mdot
.34919 .44828 Mdot
.27851 .58281 Mdot
.56905 .35513 Mdot
.70091 .48013 Mdot
.4022 .65052 Mdot
.72602 .49921 Mdot
.36858 .45393 Mdot
.28591 .57803 Mdot
.44042 .68201 Mdot
.50211 .72758 Mdot
.34794 .49373 Mdot
.38279 .41452 Mdot
.63658 .65827 Mdot
.50021 .68509 Mdot
.3028 .47694 Mdot
.4102 .54572 Mdot
.59906 .38729 Mdot
.60078 .56777 Mdot
.46803 .64371 Mdot
.32412 .6078 Mdot
.50137 .5964 Mdot
.25492 .52865 Mdot
.54004 .62345 Mdot
.67109 .43542 Mdot
.4651 .57741 Mdot
.78795 .37801 Mdot
.66751 .57557 Mdot
.29949 .55571 Mdot
.44151 .21239 Mdot
.68241 .65338 Mdot
.50783 .64363 Mdot
.6803 .59523 Mdot
.60246 .45502 Mdot
.75315 .43343 Mdot
.73819 .44246 Mdot
.66499 .42533 Mdot
.39736 .38665 Mdot
.5249 .66548 Mdot
.30563 .53827 Mdot
.65069 .62222 Mdot
.65338 .50056 Mdot
.28066 .59917 Mdot
.46965 .25807 Mdot
.62608 .58325 Mdot
.48387 .34715 Mdot
.35201 .61214 Mdot
.63276 .45628 Mdot
.29986 .53181 Mdot
.46399 .36284 Mdot
.32476 .61672 Mdot
.55425 .59125 Mdot
.60483 .59524 Mdot
.39054 .6088 Mdot
.63656 .57863 Mdot
.70202 .46437 Mdot
.45441 .68964 Mdot
.6964 .62862 Mdot
.48777 .31291 Mdot
.6607 .59618 Mdot
.5005 .59732 Mdot
.57057 .32946 Mdot
.6016 .56151 Mdot
.40136 .43904 Mdot
.43917 .73309 Mdot
.63865 .49079 Mdot
.65557 .47406 Mdot
.41387 .61907 Mdot
.65611 .53737 Mdot
.26541 .39426 Mdot
.51094 .64729 Mdot
.47394 .65141 Mdot
.60823 .45195 Mdot
.62636 .41929 Mdot
.44682 .73768 Mdot
.44519 .25913 Mdot
.55048 .44093 Mdot
.32905 .50539 Mdot
.64288 .52531 Mdot
.39197 .62409 Mdot
.37063 .64404 Mdot
.41888 .68938 Mdot
.76254 .40695 Mdot
.49749 .3029 Mdot
.69003 .42259 Mdot
.56221 .44183 Mdot
.65901 .58681 Mdot
.31447 .40174 Mdot
.57439 .61115 Mdot
.70729 .41056 Mdot
.49161 .7005 Mdot
.45978 .21853 Mdot
.55264 .52192 Mdot
.48675 .24556 Mdot
.44633 .63479 Mdot
.61136 .46054 Mdot
.42385 .59025 Mdot
.61783 .54507 Mdot
.28297 .35944 Mdot
.48303 .26973 Mdot
.52692 .66363 Mdot
.56327 .41164 Mdot
.68014 .64966 Mdot
.47398 .67081 Mdot
.65027 .48804 Mdot
.59255 .40633 Mdot
.47131 .45262 Mdot
.48106 .23178 Mdot
.5102 .5904 Mdot
.46021 .29937 Mdot
.63531 .45367 Mdot
.70644 .63151 Mdot
.67558 .5324 Mdot
.59281 .6187 Mdot
.49316 .33896 Mdot
.43498 .68831 Mdot
.77979 .39974 Mdot
.48996 .61985 Mdot
.55588 .656 Mdot
.47819 .23367 Mdot
.7561 .41427 Mdot
.60566 .52879 Mdot
.62036 .43656 Mdot
.60328 .59096 Mdot
.56143 .61842 Mdot
.66869 .6563 Mdot
.55059 .36153 Mdot
.52415 .71762 Mdot
.48021 .33605 Mdot
.7336 .42415 Mdot
.45617 .19918 Mdot
.35792 .4919 Mdot
.48511 .38463 Mdot
.42968 .64346 Mdot
.50081 .51124 Mdot
.65958 .63806 Mdot
.48924 .23217 Mdot
.28294 .60401 Mdot
.5011 .7015 Mdot
.66926 .42372 Mdot
.34867 .41342 Mdot
.55326 .69548 Mdot
.68829 .60479 Mdot
.71851 .50834 Mdot
.46132 .65249 Mdot
.50069 .28952 Mdot
.32423 .36218 Mdot
.42669 .51338 Mdot
.65552 .52362 Mdot
.32629 .49594 Mdot
.44475 .50902 Mdot
.74628 .36746 Mdot
.54856 .6859 Mdot
.46329 .46644 Mdot
.4417 .65438 Mdot
.70427 .40928 Mdot
.67747 .43071 Mdot
.51322 .68367 Mdot
.56764 .28694 Mdot
.46593 .30297 Mdot
.455 .51301 Mdot
.6054 .54899 Mdot
.29361 .54555 Mdot
.31488 .53381 Mdot
.64082 .44507 Mdot
.50819 .42011 Mdot
.53664 .38139 Mdot
.68556 .59907 Mdot
.40118 .67021 Mdot
.49819 .38107 Mdot
.376 .57352 Mdot
.48824 .7108 Mdot
.49854 .45049 Mdot
.58116 .62794 Mdot
.49001 .43419 Mdot
.47163 .24859 Mdot
.73808 .45231 Mdot
.71307 .41253 Mdot
.66476 .59428 Mdot
.65292 .49086 Mdot
.54536 .65782 Mdot
.54719 .65932 Mdot
.50844 .35514 Mdot
.68962 .64684 Mdot
.61506 .47989 Mdot
.42809 .69574 Mdot
.5145 .62977 Mdot
.36163 .59864 Mdot
.32312 .41391 Mdot
.40759 .56706 Mdot
.51353 .2729 Mdot
.46109 .40086 Mdot
.46171 .65527 Mdot
.57336 .29499 Mdot
.33774 .40736 Mdot
.29059 .52433 Mdot
.55455 .35568 Mdot
.32642 .3783 Mdot
.29413 .3462 Mdot
.57613 .53665 Mdot
.73433 .41228 Mdot
.44147 .53277 Mdot
.33306 .37485 Mdot
.65764 .63058 Mdot
.32847 .61107 Mdot
.48801 .23362 Mdot
.52854 .33507 Mdot
.49473 .66061 Mdot
.52167 .6961 Mdot
.72677 .67639 Mdot
.67678 .67094 Mdot
.75865 .36364 Mdot
.66492 .59386 Mdot
.33575 .633 Mdot
.74596 .45348 Mdot
.60268 .4883 Mdot
.41102 .59222 Mdot
.28359 .53322 Mdot
.47754 .27711 Mdot
.58332 .55313 Mdot
.53861 .22723 Mdot
.45333 .61766 Mdot
.42106 .53267 Mdot
.4628 .27414 Mdot
.45297 .24685 Mdot
.45056 .26194 Mdot
.69624 .63452 Mdot
.46094 .38919 Mdot
.47459 .22634 Mdot
.39528 .35885 Mdot
.55957 .47572 Mdot
.32313 .60256 Mdot
.31193 .5079 Mdot
.76927 .38378 Mdot
.55219 .43205 Mdot
.56433 .61112 Mdot
.4144 .6197 Mdot
.48672 .21116 Mdot
.30921 .33933 Mdot
.63168 .56163 Mdot
.47818 .35171 Mdot
.57699 .42098 Mdot
.48505 .36984 Mdot
.51773 .36273 Mdot
.53031 .5904 Mdot
.6874 .60431 Mdot
.50106 .18618 Mdot
.68455 .40833 Mdot
.6539 .61164 Mdot
.47646 .68577 Mdot
.77576 .38948 Mdot
.5413 .69376 Mdot
.60141 .60825 Mdot
.44359 .62537 Mdot
.33428 .55029 Mdot
.4526 .55354 Mdot
.56097 .59177 Mdot
.45586 .44686 Mdot
.53338 .40957 Mdot
.7355 .45937 Mdot
.72236 .39017 Mdot
.44803 .54495 Mdot
.55278 .47159 Mdot
.34405 .36617 Mdot
.7613 .41848 Mdot
.55125 .56188 Mdot
.31218 .44737 Mdot
.44257 .52996 Mdot
.5079 .65755 Mdot
.55184 .69199 Mdot
.35649 .56619 Mdot
.35416 .48124 Mdot
.48671 .30342 Mdot
.77412 .36078 Mdot
.51668 .354 Mdot
.52248 .67703 Mdot
.71222 .62588 Mdot
.66117 .57633 Mdot
.3548 .37963 Mdot
.27877 .51057 Mdot
.51594 .56121 Mdot
.24918 .51971 Mdot
.62173 .6252 Mdot
.37199 .64604 Mdot
.5394 .66079 Mdot
.38427 .36415 Mdot
.42392 .57647 Mdot
.53713 .64532 Mdot
.33653 .4202 Mdot
.44623 .65493 Mdot
.51353 .74686 Mdot
.70219 .40669 Mdot
.7367 .45359 Mdot
.56354 .28117 Mdot
.54536 .44974 Mdot
.54165 .29725 Mdot
.55889 .39435 Mdot
.60147 .53917 Mdot
.36025 .61133 Mdot
.71765 .62808 Mdot
.52316 .38141 Mdot
.79048 .39269 Mdot
.51983 .36297 Mdot
.68758 .42703 Mdot
.64386 .53352 Mdot
.3051 .3768 Mdot
.637 .59851 Mdot
.67408 .58049 Mdot
.28625 .37357 Mdot
.71319 .43103 Mdot
.61661 .55824 Mdot
.43927 .7352 Mdot
.36504 .47542 Mdot
.3035 .35135 Mdot
.46089 .36253 Mdot
.30667 .38743 Mdot
.38592 .54505 Mdot
.40654 .63827 Mdot
.45818 .37203 Mdot
.63767 .56635 Mdot
.31549 .60915 Mdot
.51872 .69848 Mdot
.59361 .62344 Mdot
.46962 .67878 Mdot
.77557 .41338 Mdot
.72408 .65403 Mdot
.5436 .63803 Mdot
.34644 .39186 Mdot
.47065 .33317 Mdot
.35952 .38278 Mdot
.52565 .70153 Mdot
.3414 .54491 Mdot
.55665 .67168 Mdot
.42563 .62307 Mdot
.56761 .50619 Mdot
.57402 .62909 Mdot
.4659 .61731 Mdot
.45499 .66092 Mdot
.27434 .56252 Mdot
.50791 .32607 Mdot
.44859 .45485 Mdot
.54451 .59934 Mdot
.34123 .49814 Mdot
.48716 .51675 Mdot
.49726 .62233 Mdot
.35894 .35659 Mdot
.52546 .61376 Mdot
.44393 .27131 Mdot
.39764 .67638 Mdot
.58698 .58786 Mdot
.51538 .41388 Mdot
.38046 .36697 Mdot
.35204 .61119 Mdot
.47692 .67213 Mdot
.68478 .59897 Mdot
.45262 .43291 Mdot
.50068 .30357 Mdot
.54356 .50747 Mdot
.33565 .37086 Mdot
.47028 .48841 Mdot
.45504 .42617 Mdot
.55342 .36896 Mdot
.51398 .36042 Mdot
.6051 .5688 Mdot
.43717 .21167 Mdot
.69488 .43913 Mdot
.40078 .56186 Mdot
.42363 .59276 Mdot
.71411 .40425 Mdot
.45664 .60109 Mdot
.47212 .59002 Mdot
.45875 .52521 Mdot
.75416 .39336 Mdot
.58088 .56964 Mdot
.62624 .56649 Mdot
.51558 .74461 Mdot
.46595 .24095 Mdot
.554 .61444 Mdot
.59326 .61288 Mdot
.5267 .41607 Mdot
.36776 .40709 Mdot
.39213 .56541 Mdot
.53874 .73859 Mdot
.50405 .47296 Mdot
.55328 .63235 Mdot
.78681 .37181 Mdot
.58932 .54931 Mdot
.43971 .53916 Mdot
.44064 .20614 Mdot
.44135 .19572 Mdot
.37348 .58817 Mdot
.49388 .21842 Mdot
.63754 .56396 Mdot
.53089 .69784 Mdot
.63755 .58379 Mdot
.31211 .41463 Mdot
.39901 .67101 Mdot
.51548 .31942 Mdot
.72228 .68448 Mdot
.6601 .63195 Mdot
.43088 .60907 Mdot
.49304 .27285 Mdot
.55213 .48172 Mdot
.6106 .49322 Mdot
.70449 .61753 Mdot
.74913 .43234 Mdot
.74877 .40825 Mdot
.36459 .554 Mdot
.64649 .46193 Mdot
.64697 .41651 Mdot
.54689 .67858 Mdot
.78722 .38821 Mdot
.58617 .41663 Mdot
.32568 .62251 Mdot
.70478 .41064 Mdot
.51761 .73324 Mdot
.65143 .47913 Mdot
.49493 .61756 Mdot
.59708 .54394 Mdot
.5066 .44627 Mdot
.52783 .71216 Mdot
.69058 .62399 Mdot
.57978 .50155 Mdot
.25728 .39002 Mdot
.4758 .67871 Mdot
.49634 .70583 Mdot
.31798 .54962 Mdot
.59996 .52223 Mdot
.44029 .24672 Mdot
.62133 .67121 Mdot
.28404 .39002 Mdot
.43886 .73324 Mdot
.37066 .34016 Mdot
.61309 .48334 Mdot
.23812 .4855 Mdot
.5064 .32765 Mdot
.61616 .48423 Mdot
.44752 .24256 Mdot
.79716 .40102 Mdot
.45793 .34317 Mdot
.58085 .60339 Mdot
.55251 .38485 Mdot
.76387 .38214 Mdot
.75884 .37277 Mdot
.44922 .22537 Mdot
.65929 .41254 Mdot
.2809 .37265 Mdot
.58301 .51462 Mdot
.31587 .4169 Mdot
.36066 .39313 Mdot
.71267 .40142 Mdot
.3573 .62665 Mdot
.47166 .36403 Mdot
.48064 .63678 Mdot
.73058 .42941 Mdot
.45949 .37713 Mdot
.37254 .344 Mdot
.49262 .48132 Mdot
.62277 .44339 Mdot
.66973 .52371 Mdot
.47828 .19183 Mdot
.51552 .68702 Mdot
.50225 .37704 Mdot
.50426 .69967 Mdot
.46467 .67967 Mdot
.66552 .43985 Mdot
.4728 .64114 Mdot
.52147 .19638 Mdot
.63355 .50244 Mdot
.53589 .33124 Mdot
.61779 .55168 Mdot
.52024 .76549 Mdot
.33923 .42857 Mdot
.50791 .34907 Mdot
.50332 .38463 Mdot
.44522 .2202 Mdot
.47169 .3793 Mdot
.46855 .40952 Mdot
.4416 .25922 Mdot
.49669 .65172 Mdot
.30099 .39191 Mdot
.46362 .26503 Mdot
.37985 .60436 Mdot
.49729 .30434 Mdot
.65288 .6572 Mdot
.59934 .45969 Mdot
.53086 .73989 Mdot
.32081 .39013 Mdot
.31556 .39328 Mdot
.52909 .3865 Mdot
.67763 .6496 Mdot
.43056 .55649 Mdot
.45449 .51561 Mdot
.65188 .48971 Mdot
.31068 .41389 Mdot
.53139 .5994 Mdot
.45854 .19415 Mdot
.35532 .48292 Mdot
.67099 .39137 Mdot
.72196 .41263 Mdot
.63445 .59713 Mdot
.59394 .53033 Mdot
.52566 .74485 Mdot
.37023 .54383 Mdot
.3255 .35142 Mdot
.46707 .24509 Mdot
.59336 .52881 Mdot
.28288 .51954 Mdot
.36689 .52365 Mdot
.57864 .61989 Mdot
.67616 .62444 Mdot
.50938 .59943 Mdot
.58326 .4554 Mdot
.36894 .47929 Mdot
.68527 .42201 Mdot
.78972 .37578 Mdot
.44084 .24372 Mdot
.67732 .62037 Mdot
.31802 .38772 Mdot
.4612 .48697 Mdot
.57453 .4297 Mdot
.45635 .19278 Mdot
.75118 .43416 Mdot
.46129 .65563 Mdot
.71506 .42881 Mdot
.67857 .641 Mdot
.60729 .4858 Mdot
.29923 .38315 Mdot
.44555 .26278 Mdot
.41079 .59777 Mdot
.56126 .52274 Mdot
.48193 .47253 Mdot
.23835 .4995 Mdot
.52856 .65995 Mdot
.3369 .55481 Mdot
.69536 .66053 Mdot
.44374 .22296 Mdot
.64731 .43303 Mdot
.44599 .47106 Mdot
.4421 .21574 Mdot
.40031 .63724 Mdot
.53828 .66812 Mdot
.7045 .63153 Mdot
.33615 .3764 Mdot
.67228 .53373 Mdot
.38091 .4595 Mdot
.26476 .3776 Mdot
.46702 .61317 Mdot
.49891 .39782 Mdot
.53808 .21293 Mdot
.46547 .67004 Mdot
.65585 .42592 Mdot
.45975 .66933 Mdot
.78003 .37212 Mdot
.52847 .58635 Mdot
.46697 .64619 Mdot
.35354 .53575 Mdot
.64218 .53436 Mdot
.50023 .65207 Mdot
.48311 .34862 Mdot
.31586 .50912 Mdot
.45544 .63448 Mdot
.45593 .63937 Mdot
.39559 .58524 Mdot
.62869 .61415 Mdot
.47839 .32637 Mdot
.74462 .41619 Mdot
.56898 .27433 Mdot
.37659 .60446 Mdot
.3183 .40201 Mdot
.60169 .5451 Mdot
.48853 .36442 Mdot
.75958 .45255 Mdot
.50521 .19031 Mdot
.32962 .5799 Mdot
.55368 .68561 Mdot
.52452 .55263 Mdot
.28647 .50357 Mdot
.31088 .40128 Mdot
.65033 .54062 Mdot
.60345 .53179 Mdot
.41836 .54703 Mdot
.43766 .66184 Mdot
.55996 .68023 Mdot
.51163 .25733 Mdot
.57118 .28853 Mdot
.66082 .60661 Mdot
.35135 .57527 Mdot
.72659 .40681 Mdot
.49466 .77346 Mdot
.57148 .30488 Mdot
.63207 .53479 Mdot
.39136 .37158 Mdot
.30335 .51178 Mdot
.49136 .18453 Mdot
.46383 .33868 Mdot
.42988 .65807 Mdot
.54024 .68009 Mdot
.64102 .48652 Mdot
.52069 .38169 Mdot
.56597 .54206 Mdot
.70626 .40157 Mdot
.47571 .43936 Mdot
.5062 .36709 Mdot
.46195 .63239 Mdot
.50184 .58306 Mdot
.71455 .42152 Mdot
.54167 .36842 Mdot
.74111 .42516 Mdot
.38768 .53598 Mdot
.55734 .44271 Mdot
.73365 .43698 Mdot
.49659 .46866 Mdot
.64206 .55928 Mdot
.3155 .6106 Mdot
.51367 .5659 Mdot
.75377 .39111 Mdot
.4464 .67458 Mdot
.59953 .44418 Mdot
.48869 .66147 Mdot
.66119 .63095 Mdot
.47899 .33744 Mdot
.53372 .68039 Mdot
.73887 .41909 Mdot
.31774 .41008 Mdot
.55611 .41482 Mdot
.35305 .60576 Mdot
.33413 .50773 Mdot
.57273 .33279 Mdot
.43656 .50243 Mdot
.59456 .40983 Mdot
.31592 .3408 Mdot
.33458 .41845 Mdot
.48107 .27787 Mdot
.29593 .34887 Mdot
.50971 .44751 Mdot
.61417 .46199 Mdot
.43036 .70024 Mdot
.48504 .2329 Mdot
.32048 .35599 Mdot
.52615 .72096 Mdot
.74505 .40824 Mdot
.65546 .40203 Mdot
.441 .21527 Mdot
.67847 .646 Mdot
.52273 .44354 Mdot
.79086 .38663 Mdot
.54878 .50682 Mdot
.64719 .41367 Mdot
.61754 .55154 Mdot
.46396 .68579 Mdot
.47385 .24088 Mdot
.61707 .47127 Mdot
.50562 .45235 Mdot
.30451 .47026 Mdot
.42775 .62295 Mdot
.29965 .36025 Mdot
.33068 .39577 Mdot
.70089 .46381 Mdot
.29009 .51506 Mdot
.64047 .45046 Mdot
.38268 .59277 Mdot
.71994 .40799 Mdot
.70725 .39545 Mdot
.56145 .43243 Mdot
.66771 .56512 Mdot
.43775 .22083 Mdot
.46977 .40179 Mdot
.32284 .59136 Mdot
.45463 .66297 Mdot
.53563 .21112 Mdot
.66886 .41048 Mdot
.45348 .42905 Mdot
.3051 .52697 Mdot
.47325 .44797 Mdot
.51412 .32346 Mdot
.49976 .49909 Mdot
.61884 .67041 Mdot
.38126 .60036 Mdot
.52528 .71806 Mdot
.49312 .67408 Mdot
.68861 .66255 Mdot
.75129 .39024 Mdot
.5434 .63749 Mdot
.5006 .59247 Mdot
.49938 .43864 Mdot
.71808 .38705 Mdot
.66506 .62063 Mdot
.60212 .6224 Mdot
.36158 .61362 Mdot
.44121 .2369 Mdot
.47861 .69264 Mdot
.49844 .6152 Mdot
.5552 .58147 Mdot
.37111 .37617 Mdot
.6692 .65737 Mdot
.53316 .6703 Mdot
.44258 .64334 Mdot
.45229 .28755 Mdot
.56516 .59649 Mdot
.5454 .37295 Mdot
.68978 .43659 Mdot
.54076 .58283 Mdot
.71149 .39656 Mdot
.4173 .68958 Mdot
.4514 .26942 Mdot
.34056 .37013 Mdot
.60119 .41232 Mdot
.36527 .47078 Mdot
.45942 .61866 Mdot
.51508 .35971 Mdot
.56397 .54117 Mdot
.57109 .64137 Mdot
.48059 .66674 Mdot
.77181 .40185 Mdot
.56716 .31117 Mdot
.71628 .62469 Mdot
.61823 .45011 Mdot
.29337 .52719 Mdot
.28489 .52653 Mdot
.62419 .60804 Mdot
.60629 .55137 Mdot
.45592 .59137 Mdot
.57995 .45408 Mdot
.35747 .59164 Mdot
.53317 .34051 Mdot
.47523 .19074 Mdot
.39694 .62867 Mdot
.78838 .40535 Mdot
.37139 .61779 Mdot
.40683 .62626 Mdot
.64615 .42722 Mdot
.58308 .59655 Mdot
.51767 .42923 Mdot
.51289 .40734 Mdot
.49361 .74868 Mdot
.47228 .18489 Mdot
.55201 .63448 Mdot
.58803 .44319 Mdot
.64486 .49249 Mdot
.50422 .62944 Mdot
.6948 .55828 Mdot
.67046 .58728 Mdot
.77637 .39842 Mdot
.70747 .41041 Mdot
.6647 .57247 Mdot
.63075 .56494 Mdot
.56624 .63807 Mdot
.46174 .27648 Mdot
.61735 .45932 Mdot
.48544 .34343 Mdot
.69878 .6535 Mdot
.3671 .56607 Mdot
.29054 .35 Mdot
.32422 .36111 Mdot
.32231 .50788 Mdot
.45406 .47443 Mdot
.45414 .30539 Mdot
.56152 .37886 Mdot
.56978 .2823 Mdot
.64902 .48015 Mdot
.45941 .18836 Mdot
.50178 .64768 Mdot
.56516 .32818 Mdot
.52754 .41002 Mdot
.56369 .5959 Mdot
.28019 .38926 Mdot
.45551 .52218 Mdot
.55745 .39704 Mdot
.58007 .62059 Mdot
.50267 .67938 Mdot
.50587 .31255 Mdot
.36389 .4701 Mdot
.24194 .52061 Mdot
.65775 .63978 Mdot
.67654 .54109 Mdot
.48774 .67362 Mdot
.48531 .19279 Mdot
.59883 .62428 Mdot
.70178 .60788 Mdot
.63077 .60511 Mdot
.50651 .37717 Mdot
.71739 .64832 Mdot
.62974 .61863 Mdot
.79501 .37842 Mdot
.5574 .68685 Mdot
.44801 .47308 Mdot
.50007 .71332 Mdot
.31357 .34138 Mdot
.42532 .5181 Mdot
.55059 .35582 Mdot
.49894 .32016 Mdot
.30621 .40069 Mdot
.60084 .45229 Mdot
.45038 .29885 Mdot
.71442 .42426 Mdot
.69905 .43685 Mdot
.65868 .64602 Mdot
.43379 .61651 Mdot
.72639 .65267 Mdot
.64356 .50779 Mdot
.3386 .60166 Mdot
.45706 .33632 Mdot
.4582 .44757 Mdot
.5627 .53574 Mdot
.45652 .50724 Mdot
.46945 .26899 Mdot
.73635 .39024 Mdot
.68766 .54762 Mdot
.69743 .53533 Mdot
.34298 .3576 Mdot
.55717 .42693 Mdot
.43547 .56374 Mdot
.46096 .34778 Mdot
.64592 .54011 Mdot
.61711 .46943 Mdot
.72371 .41805 Mdot
.45948 .61888 Mdot
.35924 .49183 Mdot
.44452 .23166 Mdot
.31474 .51655 Mdot
.768 .41685 Mdot
.69673 .63803 Mdot
.6493 .48381 Mdot
.46116 .19056 Mdot
.44334 .58864 Mdot
.31957 .45464 Mdot
.43586 .21509 Mdot
.48666 .25136 Mdot
.56689 .63568 Mdot
.36106 .40252 Mdot
.7972 .38205 Mdot
.6585 .55306 Mdot
.52333 .39336 Mdot
.37076 .64533 Mdot
.67768 .44771 Mdot
.31929 .43151 Mdot
.45449 .4194 Mdot
.58775 .44945 Mdot
.40947 .6423 Mdot
.44148 .62343 Mdot
.63382 .44643 Mdot
.70855 .43156 Mdot
.34641 .58335 Mdot
.3982 .677 Mdot
.38217 .54063 Mdot
.45552 .6897 Mdot
.50187 .32901 Mdot
.51144 .19753 Mdot
.35095 .61912 Mdot
.4559 .28006 Mdot
.23206 .5071 Mdot
.4842 .62611 Mdot
.36038 .61585 Mdot
.3106 .37875 Mdot
.63941 .44547 Mdot
.45111 .19201 Mdot
.36163 .58577 Mdot
.50178 .19408 Mdot
.51935 .31689 Mdot
.43619 .66762 Mdot
.38502 .58098 Mdot
.32501 .39569 Mdot
.54533 .61783 Mdot
.58777 .60292 Mdot
.6511 .49478 Mdot
.65413 .41193 Mdot
.62628 .50076 Mdot
.35174 .47224 Mdot
.4463 .5136 Mdot
.50362 .3508 Mdot
.60724 .48403 Mdot
.50183 .34551 Mdot
.40624 .5322 Mdot
.37602 .46659 Mdot
.43555 .20638 Mdot
.52968 .69973 Mdot
.33314 .40642 Mdot
.5866 .31596 Mdot
.56583 .32817 Mdot
.23759 .48197 Mdot
.6293 .62693 Mdot
.37645 .36147 Mdot
.66564 .45486 Mdot
.49652 .32305 Mdot
.37525 .61717 Mdot
.31919 .39742 Mdot
.67381 .57238 Mdot
.36844 .47762 Mdot
.31497 .43612 Mdot
.65074 .64488 Mdot
.65369 .45594 Mdot
.71436 .53808 Mdot
.65667 .62761 Mdot
.517 .64951 Mdot
.25341 .39165 Mdot
.55687 .3381 Mdot
.65036 .44384 Mdot
.62238 .60707 Mdot
.65997 .64302 Mdot
.73896 .42016 Mdot
.46728 .41768 Mdot
.68139 .63492 Mdot
.63602 .4149 Mdot
.30081 .38986 Mdot
.45588 .49947 Mdot
.56429 .61794 Mdot
.34007 .54891 Mdot
.46959 .29212 Mdot
.557 .29681 Mdot
.5562 .36622 Mdot
.33846 .53653 Mdot
.47952 .28339 Mdot
.60803 .62516 Mdot
.76962 .35652 Mdot
.58644 .59289 Mdot
.4866 .65864 Mdot
.33464 .52672 Mdot
.58864 .53405 Mdot
.28887 .60792 Mdot
.35995 .40327 Mdot
.34378 .51722 Mdot
.69885 .60641 Mdot
.59737 .53402 Mdot
.51197 .6399 Mdot
.52771 .62471 Mdot
.4675 .379 Mdot
.29148 .60706 Mdot
.34791 .45198 Mdot
.5659 .3901 Mdot
.27256 .36603 Mdot
.55241 .36816 Mdot
.53266 .42402 Mdot
.68836 .59981 Mdot
.65233 .44615 Mdot
.6938 .43902 Mdot
.47811 .4 Mdot
.47099 .25832 Mdot
.32031 .60947 Mdot
.46253 .33968 Mdot
.47892 .50811 Mdot
.68737 .62244 Mdot
.31073 .51835 Mdot
.45018 .19691 Mdot
.43421 .52003 Mdot
.50425 .24693 Mdot
.52857 .33169 Mdot
.49102 .35565 Mdot
.66094 .57458 Mdot
.51875 .74884 Mdot
.65061 .47784 Mdot
.3538 .38312 Mdot
.50164 .68514 Mdot
.56214 .27366 Mdot
.52596 .37855 Mdot
.58411 .47379 Mdot
.57229 .61087 Mdot
.3382 .56016 Mdot
.37111 .3836 Mdot
.68445 .47164 Mdot
.34164 .54518 Mdot
.45657 .47094 Mdot
.45374 .30687 Mdot
.32137 .58648 Mdot
.50448 .54368 Mdot
.44083 .51044 Mdot
.44593 .22267 Mdot
.67888 .47712 Mdot
.28175 .51842 Mdot
.33095 .61537 Mdot
.69857 .61288 Mdot
.64585 .40702 Mdot
.44024 .24263 Mdot
.67463 .58062 Mdot
.57952 .45321 Mdot
.54512 .7334 Mdot
.45347 .49565 Mdot
.43837 .64479 Mdot
.65371 .6085 Mdot
.61365 .40056 Mdot
.47485 .47643 Mdot
.45088 .18182 Mdot
.51211 .36934 Mdot
.5151 .43102 Mdot
.34064 .60971 Mdot
.72354 .41588 Mdot
.27373 .53096 Mdot
.68607 .64059 Mdot
.50624 .33017 Mdot
.67292 .56874 Mdot
.79428 .38544 Mdot
.5426 .59078 Mdot
.42187 .69277 Mdot
.55269 .42601 Mdot
.50769 .69197 Mdot
.59135 .5134 Mdot
.39493 .67524 Mdot
.51787 .69761 Mdot
.46401 .36279 Mdot
.57368 .56883 Mdot
.49497 .76211 Mdot
.37234 .59421 Mdot
.53003 .55955 Mdot
.5948 .58831 Mdot
.49934 .61474 Mdot
.50731 .59246 Mdot
.66166 .62181 Mdot
.51923 .54581 Mdot
.53163 .7023 Mdot
.64651 .58908 Mdot
.40716 .52542 Mdot
.6374 .4402 Mdot
.48483 .38874 Mdot
.74446 .45653 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`2@ooooo`Go0000]?ooool001cooooo00?o0000ooooooooool0
S_ooool>o`000:gooooo000Looooo`03o`000?oooooooooo08gooooo1?l000000ooooooo0000o`00
000:o`000:_ooooo000Looooo`03o`000?oooooooooo08cooooo1Ol00005ooooo`;o00001?ooool2
o`000003ooooool0003o00000:Sooooo000Looooo`03o`000?oooooooooo08cooooo0_l00003oooo
o`?o00000_ooool3o`0000Kooooo1Ol0002Uooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5
ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0Soooool5o`0000?ooooo1Ol00004
ooooo`Co0000YOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo08cooooo1ol00005ooooo`Co0000
0oooool2o`0000Cooooo0ol0002Qooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0S?ooool7o`0000cooooo1Ol0
00001?oooooo0000o`000?l0002Qooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooooooo
o`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0002@ooooo`;o00001oooool2o`0000Cooooo1_l0
002Tooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKo
oooo00Gooooo00?o0000ooooooooool0Roooool2o`0000cooooo0_l000000ooooooo0000o`000004
ooooo`?o00001?ooool2o`0009kooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo
00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2:ooooo`?o00003oooool2o`00
00Cooooo1_l000001?oooooo0000o`000?l0002Mooooo`0000KoooooogMgMonHV9SooooooiRHV?mg
MgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`2:ooooo`;o0000
3_ooool2o`0000Sooooo1?l00002ooooo`;o0000WOooool00006ooooooo^k^ko<S8bo`000?lb<S;o
k^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0R_ooool4o`00
00cooooo0_l0000:ooooo`?o000000Coooooo`000?l0003o0000W?ooool001cooooo00?o0000oooo
ooooool0R_ooool4o`0000Cooooo0_l00009ooooo`;o00001?ooool7o`000003ooooool0003o0000
09cooooo000Looooo`03o`000?oooooooooo08[ooooo1Ol00003ooooo`;o00002Oooool2o`0000Co
oooo2Ol000000ooooooo0000o`00002Jooooo`007?ooool00ol0003oooooooooo`2:ooooo`Go0000
4oooool:o`000003ooooool0003o000009[ooooo000Looooo`03o`000?oooooooooo08cooooo1?l0
0006ooooo`;o00002_ooool;o`0009cooooo000Looooo`03o`000?oooooooooo08kooooo0_l00006
ooooo`;o00002Oooool<o`0000;ooooo0_l0002Hooooo`007?ooool00ol0003oooooooooo`2=oooo
o`;o00002Oooool5o`0000Cooooo3?l00002ooooo`;o0000V?ooool001cooooo00?o0000oooooooo
ool0S?ooool3o`0000Wooooo1Ol00005ooooo`co0000Voooool001cooooo00?o0000ooooooooool0
S?ooool2o`0001Cooooo3?l0002Kooooo`007?ooool00ol0003oooooooooo`2;ooooo`;o000000?o
ooooo`000?l000001?ooool4o`0000Gooooo0_l00004ooooo`?o000000?oooooo`000?l000001_l0
002Jooooo`007?ooool00ol0003oooooooooo`2;ooooo`;o000000?oooooo`000?l000001?ooool4
o`0000;ooooo0_l000000ooooooo0000o`000002o`0000;ooooo3?l0002Jooooo`007?ooool00ol0
003oooooooooo`2;ooooo`;o00000_ooool2o`0000?ooooo0ol00003ooooo`;o000000?oooooo`00
0?l000000ol000001?oooooo0000o`000?ooool9o`0009[ooooo000Looooo`;o0000S?ooool2o`00
00;ooooo0_l00004ooooo`;o00000oooool2o`000003ooooool0003o000000?o000000?oooooo`00
0?l000002ol0002Iooooo`007?ooool00ol0003oooooooooo`2Jooooo`;o000000?oooooo`000?l0
00004_l0002Hooooo`007?ooool00ol0003oooooooooo`2Eooooo`;o00001Oooool3o`000003oooo
ool0003o000000oo0000V?ooool001cooooo00?o0000ooooooooool0S?ooool3o`0000Kooooo0_l0
0005ooooo`?o00000_ooool@o`0009Sooooo000Looooo`03o`000?oooooooooo08cooooo1Ol0000;
ooooo`?o00000_ooool@o`0009Sooooo000Looooo`03o`000?oooooooooo08gooooo1?l00002oooo
o`;o00001oooool2o`0000?ooooo4?l0002Hooooo`007?ooool00ol0003oooooooooo`2?ooooo`;o
00000_ooool4o`0000;ooooo0_l000000ooooooo0000o`000003oooooa7o0000Uoooool001cooooo
00?o0000ooooooooool0S?ooool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o0000
00?oooooo`000?l000000ooooolAo`000003ooooool0003o000009Cooooo000Looooo`03o`000?oo
oooooooo08cooooo0_l00004ooooo`?o00001oooool2o`0000Cooooo3ol00002ooooo`Co0000T_oo
ool001cooooo00?o0000ooooooooool0T?ooool5o`0000;ooooo1?l00007oooooa3o00000oooool2
o`0009;ooooo000Looooo`03o`000?oooooooooo093ooooo0_l00005ooooo`Co00000oooool3o`00
0003ooooool0003o000000ko000000?oooooo`000?l000000_l0002Booooo`007?ooool00ol0003o
ooooooooo`2Hooooo`;o00001?ooool3o`000003ooooool0003o000000ko000000?oooooo`000?l0
00000_l0002Booooo`007?ooool00ol0003oooooooooo`2?ooooo`;o00001oooool2o`0000Gooooo
0_l00005ooooo`co00000oooool4o`00093ooooo000Looooo`03o`000?oooooooooo08oooooo0_l0
0004ooooo`;o00002?ooool4o`000003ooooool0003o000000;o000000?oooooo`000?l000001_l0
0004ooooo`Co0000T?ooool001cooooo00?o0000ooooooooool0UOooool2o`0000Sooooo4_l00005
ooooo`?o0000T?ooool001cooooo00?o0000ooooooooool0XOooool3o`000003ooooool0003o0000
00Wo000000?oooooo`000?l000000oooool4o`0008oooooo000Looooo`;o0000T?ooool2o`000003
ooooool0003o000000kooooo0_l000000ooooooo0000o`000007o`0000?ooooo0_l00005ooooo`;o
0000Soooool001cooooo00?o0000ooooooooool0S_ooool3o`000003ooooool0003o000000;o0000
1?ooool2o`0000;ooooo0ol000001Ooooooo0000o`000?l0003ooooo00Oo00002oooool3o`0008ko
oooo000Looooo`03o`000?oooooooooo08kooooo1?l00002ooooo`;o00001?ooool2o`0000;ooooo
0ol000001?oooooo0000o`000?l00004ooooo`Ko00001oooool2o`000003ooooool0003o000008ko
oooo000Looooo`03o`000?oooooooooo093ooooo0_l0000Booooo`;o00000oooool2o`000004oooo
ool0003o0000o`0000Oooooo0_l000000ooooooo0000o`00002>ooooo`007?ooool00ol0003ooooo
ooooo`2?ooooo`;o00002_ooool2o`0000Cooooo0_l000000ooooooo0000o`000007ooooo`;o0000
0_ooool5o`0009?ooooo000Looooo`03o`000?oooooooooo08oooooo0_l0000:ooooo`;o00001?oo
ool2o`0000;ooooo0ol00008ooooo`So00000oooool2o`0008cooooo000Looooo`03o`000?oooooo
oooo09kooooo0_l00004ooooo`Go00001oooool8o`0000?ooooo0_l0002<ooooo`007?ooool00ol0
003oooooooooo`2Nooooo`;o00001?ooool5o`0000[ooooo2Ol0002=ooooo`007?ooool00ol0003o
ooooooooo`2Nooooo`;o000000?oooooo`000?l000000_l0000=ooooo`;o000000?oooooo`000?l0
00001Ol00002ooooo`?o0000R?ooool001cooooo00?o0000ooooooooool0V?ooool2o`0000Gooooo
1_l00005ooooo`;o00001Oooool;o`000003ooooool0003o000000;o0000R?ooool001cooooo00?o
0000ooooooooool0V?ooool2o`0000Gooooo1?l00005ooooo`Go00001?ooool9o`0000?ooooo0_l0
00000ooooooo0000o`000027ooooo`007?ooool00ol0003oooooooooo`1Wooooo`Co00000_ooool2
o`0000;ooooo0_l0000Rooooo`;o00002_ooool2o`0000Gooooo1Ol00004ooooo`;o00000_ooool9
o`0000;ooooo0_l00027ooooo`007?ooool00ol0003oooooooooo`1Wooooo`co00007_ooool2o`00
00;ooooo0_l000000ooooooo0000o`00000>ooooo`;o00001_ooool?o`000003ooooool0003o0000
08Oooooo000Looooo`03o`000?oooooooooo067ooooo2?l000000ooooooo0000o`00000;o`0001[o
oooo1?l00003ooooo`;o00000_ooool2o`0000_ooooo1?l00003oooooa;o0000Qoooool001cooooo
00?o0000ooooooooool0Foooool3o`0000?ooooo5_l000000ooooooo0000o`00000Gooooo`Co0000
1Oooool4o`0000_ooooo1?l00005ooooo`_o000000?oooooo`000?l000000_l00027ooooo`007?oo
ool00ol0003oooooooooo`1Kooooo`?o00000_ooool<o`000003ooooool0003o000000;ooooo2Ol0
000Gooooo`?o00001Oooool3o`0000?ooooo0_l0000>ooooo`;o000000?oooooo`000?l000003Ol0
0028ooooo`007?ooool2o`0005[ooooo1Ol000000ooooooo0000o`000006o`0000;ooooo0ol00000
0ooooooo0000o`000003ooooo`Wo00005oooool2o`0000Gooooo0_l00004ooooo`Co00003?oooolB
o`0008Sooooo000Looooo`03o`000?oooooooooo05Wooooo1Ol000000ooooooo0000o`000002o`00
00?ooooo0_l0000<ooooo`Wo00006oooool3o`0000Gooooo0ol000000ooooooo0000o`00000;oooo
oa3o0000R?ooool001cooooo00?o0000ooooooooool0E_ooool2o`0000Oooooo0_l00003ooooo`Co
00002Oooool2o`0000?ooooo2?l0000Jooooo`;o00000_ooool2o`0000?ooooo0_l000000ooooooo
0000o`000009ooooo`_o000000?oooooo`000?l000001?l0000eooooo`;o00000_ooool2o`0004go
oooo000Looooo`03o`000?oooooooooo05Kooooo1?l0000:ooooo`;o00001_ooool2o`0000?ooooo
0_l00004ooooo`So00007Oooool2o`0000?ooooo0_l000000ooooooo0000o`000009oooooa?o0000
;_ooool2o`0000Cooooo0_l00002ooooo`;o0000COooool001cooooo00?o0000ooooooooool0F?oo
ool2o`0000Cooooo0_l00006ooooo`;o00001?ooool2o`0000Wooooo2?l0000Cooooo`?o00003_oo
ool4o`0000Kooooo3?l000000ooooooo0000o`000003o`000003ooooool0003o000002kooooo0_l0
0006ooooo`;o0000Coooool001cooooo00?o0000ooooooooool0E?ooool3o`0000Oooooo0_l00006
ooooo`;o00001?ooool2o`0000Wooooo2Ol0000Booooo`Go00001?ooool2o`0000Kooooo1?l00006
oooooaKo0000:_ooool2o`0000Cooooo0_l00003ooooo`;o00000oooool2o`0004[ooooo000Loooo
o`03o`000?oooooooooo05Cooooo0ol0000Eooooo`;o00002_ooool8o`0001Gooooo0_l00004oooo
o`;o00001?ooool4o`0000Oooooo0_l00002oooooa?o0000:_ooool4o`0000;ooooo0_l00008oooo
o`;o0000B_ooool001cooooo00?o0000ooooooooool0DOooool4o`0001Cooooo1?l0000;ooooo`;o
000000?oooooo`000?l000000ol0000Aooooo`;o00001oooool2o`0000Gooooo1?l00007ooooo`;o
00000_oooolDo`0002_ooooo0_l00009ooooo`Co0000Boooool001cooooo00?o0000ooooooooool0
DOooool4o`0000?ooooo0ol0000=ooooo`Go00003?ooool7o`00017ooooo0_l00007ooooo`;o0000
4Oooool2o`0000?ooooo4_l0000_ooooo`;o00001Oooool4o`0004_ooooo000Looooo`03o`000?oo
oooooooo04oooooo1Ol00004ooooo`?o00001?ooool2o`0000Gooooo1Ol0000:ooooo`;o00000_oo
ool8o`00017ooooo0_l0000;ooooo`Co00001?ooool2o`0000Cooooo0_l00003oooooa;o0000;ooo
ool2o`0000Oooooo1Ol00018ooooo`007?ooool00ol0003oooooooooo`1?ooooo`Go00002oooool4
o`0000?ooooo0_l000000ooooooo0000o`000005ooooo`;o00000oooool4o`000003ooooool0003o
000000Go00004Oooool5o`0000Oooooo1Ol00002ooooo`Co00000_ooool2o`0000Kooooo4Ol0000h
ooooo`Go0000B?ooool001cooooo00?o0000ooooooooool0Coooool3o`0000_ooooo0_l00002oooo
o`;o00003?ooool4o`0000;ooooo1?l00003ooooo`Oo00004Oooool3o`0000?ooooo0_l00002oooo
o`Co00000oooool3o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000003ol0000Soooo
o`;o00002oooool4o`0000Oooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`1=ooooo`Co
00003?ooool2o`000003ooooool0003o000000;ooooo0_l00009ooooo`Co00000_ooool3o`0000Go
oooo1_l0000Gooooo`;o00001?ooool2o`0000Kooooo0_l00006ooooo`;o000000?oooooo`000?l0
00003ol0000Eooooo`?o00002Oooool4o`0000_ooooo1?l00005ooooo`Co0000B?ooool001cooooo
00?o0000ooooooooool0COooool5o`0000Gooooo1?l00003ooooo`Co00000_ooool2o`0001?ooooo
0_l00002ooooo`Ko00003oooool2o`0000Kooooo0_l0000<ooooo`;o00002_ooool@o`0001Gooooo
0ol00009ooooo`Co00000_ooool2o`0000?ooooo0_l00006ooooo`;o00000_ooool5o`0004Sooooo
00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@oooooooo
ool01?ooool00ol0003oooooooooo`1=ooooo`Go00001Oooool4o`0000?ooooo0_l00003ooooo`?o
00001oooool2o`0000;ooooo0_l00005ooooo`Go00000_ooool4o`0000oooooo0_l00006ooooo`;o
00002_ooool2o`0000_ooooo4Ol0000Booooo`;o000000?oooooo`000?l000003?ooool2o`0000;o
oooo0_l00003ooooo`?o00001Oooool2o`0000;ooooo1Ol00018ooooo`0000KoooooogMgMonHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
04gooooo1?l00002ooooo`;o00002Oooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`00
00?ooooo0_l00002ooooo`;o00001Oooool5o`0000;ooooo1?l0000Sooooo`;o00002Oooool4o`00
0003ooooool0003o000000_o00004oooool2o`000003ooooool0003o000000Oooooo0ol0000<oooo
o`;o00002_ooool4o`0004Sooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wo
oooo1Ol00006ooooo`03o`000?oooooooooo04gooooo2?l0000?ooooo`Ko00003?ooool<o`0001Ko
oooo0_l00004ooooo`;o00004Oooool3o`0000?ooooo3?l0000Oooooo`?o00004oooool3o`0000Co
oooo0_l00018ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04odA4
A?oMgMgoooooo`0000Oooooo0ol0001>ooooo`Oo000000?oooooo`000?l000002?ooool6o`0000_o
oooo0ol000000ooooooo0000o`00000;o`00013ooooo0_l000001?oooooo0000o`000?ooool2o`00
00Cooooo0_l0000Hooooo`[o00000_ooool2o`0000_ooooo0_l0000?ooooo`Co00004Oooool4o`00
00Cooooo0_l00018ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04
omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0D_ooool3o`000003ooooool0003o0000
00Ko00000_ooool6o`0000;ooooo0_l00007oooooa;o00003oooool2o`000003ooooool0003o0000
02?ooooo2?l00002ooooo`;o00002oooool3o`0000kooooo1?l0000Aooooo`;o00000oooool5o`00
04Sooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oMgMgolc<c?l0
00001oooool00ol0003oooooooooo`1Hooooo`Ko00002_ooool4o`0000Oooooo4?l0000Pooooo`;o
00005_ooool6o`0000gooooo1_l00007ooooo`;o00000oooool3o`000003ooooool0003o000000Co
00001?ooool3o`0000?ooooo0_l00006ooooo`Co0000BOooool00006oooooomgMgOoV9RHoooooonH
V9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo05kooooo1?l000000ooo
oooo0000o`000005ooooo`;o00001?oooolDo`0000cooooo0_l00002ooooo`;o00003Oooool2o`00
00?ooooo0ol00008ooooo`;o00001_ooool4o`000003ooooool0003o000000[ooooo2?l000000ooo
oooo0000o`000004ooooo`;o00000oooool:o`000004ooooool0003o0000ooooo`?o00000oooool2
o`0000Cooooo1_l00019ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0
003ooooo00Kooooo00?o0000ooooooooool0G_ooool9o`0000Oooooo5_l0000<ooooo`;o00000_oo
ool2o`0000kooooo0_l00002ooooo`?o00001_ooool4o`0000Sooooo0_l000001?oooooo0000o`00
0?l00002ooooo`Co00000_ooool5o`000005ooooool0003o0000o`000?ooool00_l0000:ooooo`Go
000000?oooooo`000?l000000_ooool2o`0000Gooooo0_l00004ooooo`So0000BOooool001cooooo
00?o0000ooooooooool0HOooool6o`0000;ooooo0_l00003oooooaCo00004_ooool2o`0000kooooo
0_l000000ooooooo0000o`000008ooooo`;o00002?ooool2o`0000Cooooo0_l00002ooooo`Go0000
00Coooooo`000?l0003ooooo0_l0000Gooooo`;o00001Oooool2o`0000;ooooo0ol000000ooooooo
0000o`000008o`0004Wooooo000Looooo`03o`000?oooooooooo067ooooo1?l00004ooooo`?o0000
0_oooolDo`0000kooooo0_l00002ooooo`;o00002oooool2o`0000Cooooo0_l0000?ooooo`;o0000
00?oooooo`000?l000002oooool2o`0000Cooooo0_l0000Dooooo`;o000000?oooooo`000?l00000
0oooool4o`0000?ooooo0_l000000ooooooo0000o`000007o`0004[ooooo000Looooo`03o`000?oo
oooooooo067ooooo0_l00007ooooo`;o00000_oooolDo`0000kooooo0_l0000?ooooo`;o00001_oo
ool2o`0000gooooo0_l0000>ooooo`;o00003?ooool2o`0000?ooooo0ol00006ooooo`;o00001?oo
ool4o`0000Sooooo2?l0001;ooooo`007?ooool00ol0003oooooooooo`1/oooooaGo00003oooool2
o`0001Oooooo0_l00005ooooo`?o00006oooool2o`000004ooooool0003o0000ooooo`Co00000ooo
ool3o`0000Kooooo0_l00004ooooo`;o000000?oooooo`000?l000001?ooool;o`0004_ooooo000L
ooooo`03o`000?oooooooooo06[ooooo5ol0000?ooooo`;o00004_ooool2o`0000[ooooo0ol00004
ooooo`;o00005Oooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000;ooooo0_l0
0006ooooo`;o00001?ooool2o`000003ooooool0003o000000Cooooo2ol0001;ooooo`007?ooool0
0ol0003oooooooooo`1Tooooo`;o00001?oooolGo`0000kooooo0ol0000Booooo`;o00002_ooool2
o`000003ooooool0003o000000;ooooo0_l0000Eooooo`;o00002?ooool2o`0000Sooooo1?l00004
ooooo`;o00001?ooool=o`0004cooooo000Looooo`03o`000?oooooooooo06?ooooo0ol00004oooo
oaOo00003_ooool2o`0000[ooooo0_l0000Cooooo`;o000000?oooooo`000?l000004Oooool2o`00
00Kooooo0_l00006ooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`;o00001oooool2
o`0000?ooooo2ol0001>ooooo`007?ooool00ol0003oooooooooo`1Sooooo`;o00001OoooolGo`00
01Kooooo0_l00002ooooo`;o000000?oooooo`000?l000009_ooool2o`0000?ooooo0_l00007oooo
o`Co00001?ooool5o`0000Gooooo1?l000001?oooooo0000o`000?l00003ooooo`[o0000C_ooool0
01cooooo00?o0000ooooooooool0J_oooolGo`0001Kooooo0_l00005ooooo`;o00003oooool6o`00
00Kooooo0_l0000:ooooo`;o00000_ooool2o`0000Oooooo0_l00007ooooo`?o000000?oooooo`00
0?l000000_ooool5o`0000;ooooo0_l000000ooooooo0000o`00000:o`0004kooooo000Looooo`03
o`000?oooooooooo06Wooooo5_l0000Rooooo`;o00000oooool2o`0000Oooooo1_l00006ooooo`;o
00000_ooool2o`0000Kooooo0_l000000ooooooo0000o`000002o`000004ooooool0003o0000o`00
00_ooooo0_l00002ooooo`;o00000_ooool2o`0000Gooooo0_l000000ooooooo0000o`000009o`00
04oooooo000Looooo`03o`000?oooooooooo06;ooooo0_l00005oooooaKo00004Oooool3o`0000?o
oooo0_l00009ooooo`?o00000_ooool2o`0001?ooooo0_l00002ooooo`;o00002Oooool4o`000004
ooooool0003o0000o`0000Kooooo0_l00005ooooo`;o000000Coooooo`000?l0003o00002_ooool8
o`0005;ooooo000Looooo`;o0000HOooool4o`0000Cooooo5ol0000Aooooo`?o00000_ooool3o`00
00Kooooo1_l00009ooooo`;o00003?ooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2
o`0000Gooooo0_l00008ooooo`Co00000oooool9o`0000Kooooo0_l000000ooooooo0000o`000005
o`0005?ooooo000Looooo`03o`000?oooooooooo063ooooo0_l00002ooooo`;o00000_oooolFo`00
013ooooo0_l00005ooooo`;o00001oooool4o`0000_ooooo0_l00009ooooo`Co00000oooool5o`00
0003ooooool0003o000000Cooooo0ol00006ooooo`Co00001Oooool;o`0000?ooooo0ol000000ooo
oooo0000o`000005o`0005?ooooo000Looooo`03o`000?oooooooooo05Sooooo1ol00005ooooo`;o
00000ooooolEo`00013ooooo0_l0000Xooooo`Co00001?ooool2o`0000Sooooo0ol00004ooooo`;o
000000?oooooo`000?l000001Oooool2o`0000;ooooo2_l000001Ooooooo0000o`000?l0003ooooo
00So0000Doooool001cooooo00?o0000ooooooooool0E_ooool9o`0000Wooooo5Ol00012ooooo`;o
00000_ooool4o`0000?ooooo0_l00005ooooo`;o00002?oooolGo`0005Oooooo000Looooo`03o`00
0?oooooooooo057ooooo0_l00003ooooo`Ko000000Coooooo`000?l0003o00002?oooolDo`0004?o
oooo0_l00002ooooo`Co00001oooool2o`0000[ooooo6?l0001Gooooo`007?ooool00ol0003ooooo
ooooo`1Aooooo`oo00002?ooool@o`0001_ooooo0_l0000_ooooo`;o00002?ooool2o`0000Wooooo
2_l000000ooooooo0000o`00000:o`0005Wooooo000Looooo`03o`000?oooooooooo04gooooo0ol0
00000ooooooo0000o`00000>o`0000Kooooo4ol0000Cooooo`;o00000_ooool4o`0000Wooooo0_l0
000Uooooo`;o00004_ooool=o`000003ooooool0003o000000Ko0000F_ooool001cooooo00?o0000
ooooooooool0C?oooolEo`0000Kooooo3_l00002ooooo`?o00004oooool3o`000003ooooool0003o
000000Kooooo0_l00003ooooo`Co00003_ooool2o`0000Sooooo0_l00009ooooo`;o00002_ooool2
o`0000Gooooo4ol000001?oooooo0000o`000?l0001Jooooo`007?ooool00ol0003oooooooooo`1;
oooooaKo00001_ooool:o`0000;ooooo1Ol0000Fooooo`Co00001?ooool2o`000003ooooool0003o
000000Gooooo0_l0000>ooooo`Co00001_ooool2o`0000Wooooo0_l0000:ooooo`;o00001OoooolC
o`000003ooooool0003o000005_ooooo000Looooo`03o`000?oooooooooo04[ooooo5?l000000ooo
oooo0000o`000006ooooo`So00001?ooool5o`0001Sooooo0_l00004ooooo`;o00006_ooool2o`00
013ooooo0_l00009ooooo`?o00001OoooolEo`0005gooooo000Looooo`03o`000?oooooooooo04Wo
oooo5Ol0000:ooooo`[o00000_ooool3o`0002Gooooo0_l0000Booooo`;o00004Oooool3o`0000Wo
oooo0ol00005ooooo`ko000000?oooooo`000?l000001?l0001Mooooo`007?ooool00ol0003ooooo
ooooo`19oooooaCo00002oooool:o`0000;ooooo0ol0000Uooooo`;o00004_ooool2o`0000oooooo
1Ol00006ooooo`;o000000?oooooo`000?l000001_oooolCo`0005oooooo000Looooo`03o`000?oo
oooooooo04Sooooo5?l0000<ooooo`So00000oooool3o`0001;ooooo0ol00007ooooo`;o000000?o
ooooo`000?l00000:Oooool3o`000003ooooool0003o000000Kooooo0_l000000ooooooo0000o`00
0006oooooa?o0000Goooool001cooooo00?o0000ooooooooool0B?oooolCo`0000kooooo3Ol0000B
ooooo`?o00001oooool2o`000003ooooool0003o000002Wooooo0_l0000:ooooo`Ko00001?oooolC
o`00063ooooo000Looooo`03o`000?oooooooooo04_ooooo4?l0000>ooooo`go00004_ooool3o`00
00Gooooo0_l0000aooooo`;o00001oooool6o`0000Cooooo4ol0001Pooooo`007?ooool00ol0003o
ooooooooo`17ooooo`;o00000_ooool@o`0000_ooooo0_l00003ooooo`_o00004Oooool4o`0000Go
oooo0_l0000aooooo`;o00002oooool2o`0000Cooooo4ol0001Pooooo`007?ooool2o`0004Sooooo
0_l000000ooooooo0000o`00000?o`0000_ooooo0_l00003ooooo`Co000000?oooooo`000?l00000
1?l0000?ooooo`Co00001oooool2o`0000gooooo0_l0000Hooooo`;o00003Oooool2o`0000Kooooo
0_l00004oooooaCo0000Goooool001cooooo00?o0000ooooooooool0Aoooool2o`000003ooooool0
003o000000oo00004?ooool:o`00013ooooo0ol00002ooooo`;o00001?ooool2o`0000gooooo0_l0
000Hooooo`;o00003Oooool4o`0000Cooooo0_l00003oooooa;o000000?oooooo`000?l00000Gooo
ool001cooooo00?o0000ooooooooool0B?ooool2o`0000?ooooo2_l000001?oooooo0000o`000?l0
0007ooooo`;o000000?oooooo`000?l000001?l000000ooooooo0000o`000002o`0001?ooooo0ol0
0004ooooo`;o00001Oooool2o`0001[ooooo0ol00005ooooo`;o00004oooool2o`000003ooooool0
003o000000Kooooo4_l0001Rooooo`007?ooool00ol0003oooooooooo`18ooooo`;o00000oooool7
o`000003ooooool0003o000000;o00002Oooool9o`000003ooooool0003o000000?o00004Oooool4
o`0000Gooooo1?l00002ooooo`;o00001Oooool2o`0001?ooooo0ol00005ooooo`;o00005_ooool2
o`0000Kooooo4ol0001Qooooo`007?ooool00ol0003oooooooooo`1?ooooo`Go000000?oooooo`00
0?l000000_l00006ooooo`;o00000_ooool2o`0000Wooooo1_l0000;ooooo`Oo000000?oooooo`00
0?l000000_ooool4o`000003ooooool0003o000000Kooooo0_l00005ooooo`;o00006oooool2o`00
01Oooooo4ol0001Qooooo`007?ooool00ol0003oooooooooo`1Kooooo`;o00000_ooool2o`0000;o
oooo0_l00007ooooo`_o00001Oooool7o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l0
00002?ooool2o`0000?ooooo0_l0000Iooooo`Co00005ooooolAo`0006?ooooo000Looooo`03o`00
0?oooooooooo04gooooo0_l00009ooooo`;o000000?oooooo`000?l000001?ooool4o`0000Oooooo
0_l000000ooooooo0000o`00000Ao`0000Cooooo0_l000000ooooooo0000o`000005ooooo`;o0000
2?ooool2o`0001kooooo0_l0000Ioooooa3o0000I?ooool001cooooo00?o0000ooooooooool0Booo
ool4o`0000Wooooo0_l00007ooooo`;o00004?ooool=o`0000Kooooo0_l000000ooooooo0000o`00
0005ooooo`;o00007_ooool2o`000003ooooool0003o000000[ooooo0_l0000Fooooo`ko0000I?oo
ool001cooooo00?o0000ooooooooool0Boooool3o`0000_ooooo1?l0000Fooooo`;o00003?ooool2
o`0000gooooo0ol0000Mooooo`;o000000?oooooo`000?l000002_ooool2o`0000cooooo0_l00002
ooooo`;o00000oooool>o`0006Gooooo000Looooo`03o`000?oooooooooo04cooooo1Ol00008oooo
o`Go000000?oooooo`000?l000002?ooool2o`0000Sooooo0_l0000<ooooo`;o00003_ooool2o`00
02[ooooo0_l00002ooooo`;o00002_ooool2o`0000;ooooo0_l00002ooooo`ko0000I_ooool001co
oooo00?o0000ooooooooool0C_ooool3o`0000Cooooo0_l00005ooooo`Go00002?ooool2o`0001Go
oooo0_l00003ooooo`;o00001Oooool2o`0002oooooo0_l000001?oooooo0000o`000?l0000Boooo
o`;o000000?oooooo`000?l000002Ol00002ooooo`;o0000H_ooool001cooooo00?o0000oooooooo
ool0Coooool2o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`;o00000oooool2o`0000[o
oooo0_l0000?ooooo`;o00000oooool2o`0000Gooooo0_l0000Uooooo`;o00001_ooool7o`0000So
oooo0_l000000ooooooo0000o`000006ooooo`co00001?ooool2o`0006;ooooo000Looooo`03o`00
0?oooooooooo05Sooooo0_l00006ooooo`;o000000?oooooo`000?l000001Oooool2o`0000?ooooo
0_l00009ooooo`;o00004?ooool2o`0002Gooooo0_l00002ooooo`;o00000_ooool2o`000003oooo
ool0003o000000[ooooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool3o`000003oooo
ool0003o000000Go00000oooool3o`0006;ooooo000Looooo`03o`000?oooooooooo063ooooo0_l0
0008ooooo`;o00003?ooool4o`0000oooooo0_l0000Vooooo`;o00000_ooool2o`0000Oooooo0_l0
000<ooooo`Go00000oooool4o`0000[ooooo0_l0001Sooooo`007?ooool00ol0003oooooooooo`1I
ooooo`;o00004?ooool2o`0000Sooooo0_l000000ooooooo0000o`000002o`0000oooooo0_l00000
0ooooooo0000o`00000@ooooo`;o00004Oooool3o`0000Sooooo1?l0000<ooooo`?o00001_ooool3
o`0000[ooooo0ol0001Rooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o000000?oooooo`00
0?l000003Oooool2o`0000Sooooo0_l00003ooooo`;o00001_ooool4o`0000Sooooo0_l0000@oooo
o`;o00000oooool2o`0000gooooo0_l00008ooooo`Co00000oooool2o`00013ooooo0ol00002oooo
o`;o00001_ooool3o`0006;ooooo000Looooo`;o0000GOooool2o`0000Kooooo0_l00003ooooo`Co
00005Oooool4o`0001oooooo0_l0000Eooooo`;o00000_ooool3o`0000;ooooo0_l0000Aooooo`Ko
00001_ooool2o`0006?ooooo000Looooo`03o`000?oooooooooo05Sooooo0_l00004ooooo`;o0000
1?ooool2o`0000?ooooo1?l00006ooooo`;o00006_ooool2o`0001Kooooo0_l0000Aooooo`Co0000
0oooool2o`0000;ooooo0_l0000;ooooo`;o00001_ooool2o`0000Sooooo0_l0001Sooooo`007?oo
ool00ol0003oooooooooo`1Hooooo`Co00000_ooool2o`0000[ooooo0_l00007ooooo`;o00004ooo
ool2o`0000Gooooo0_l0000Fooooo`;o00004Oooool2o`0000Gooooo0_l00002ooooo`;o00002ooo
ool2o`0000Kooooo0_l00007ooooo`?o0000Hoooool001cooooo00?o0000ooooooooool0F_ooool2
o`000005ooooool0003o0000o`000?ooool00_l00007ooooo`;o00007?ooool2o`0001kooooo0_l0
000Kooooo`;o00001_ooool2o`0000_ooooo1_l000000ooooooo0000o`000003o`0006?ooooo000L
ooooo`03o`000?oooooooooo05Gooooo2ol000000ooooooo0000o`000007ooooo`;o00004_ooool2
o`0002Cooooo0_l00002ooooo`;o00001Oooool2o`0000oooooo0_l00003ooooo`;o00000_ooool2
o`0000;ooooo0_l0000=ooooo`Wo0000I?ooool001cooooo00?o0000ooooooooool0EOooool=o`00
00kooooo0_l00002ooooo`;o00001_ooool4o`0000[ooooo0_l0000Gooooo`?o00002Oooool2o`00
00oooooo0_l00006ooooo`Go00002?ooool2o`0000Wooooo0ol0001Vooooo`007?ooool00ol0003o
ooooooooo`1Fooooo`;o00000oooool8o`0000gooooo0_l00002ooooo`;o00001_ooool2o`0000?o
oooo0_l00007ooooo`;o00005oooool2o`0001;ooooo1?l00004ooooo`Co00001Oooool5o`0000So
oooo1?l0001`ooooo`007?ooool00ol0003oooooooooo`1Hooooo`co00007Oooool2o`0003Cooooo
1?l00004ooooo`Co00004Oooool2o`000003ooooool0003o0000073ooooo000Looooo`03o`000?oo
oooooooo05Cooooo0_l00002ooooo`co00002_ooool2o`0000Kooooo0_l0001Kooooo`Ko0000L?oo
ool001cooooo00?o0000ooooooooool0E?ooool2o`000003ooooool0003o000000_o00002_ooool2
o`0000Kooooo0_l0000>ooooo`;o00002oooool2o`0003Kooooo0_l00006ooooo`Co0000L_ooool0
01cooooo00?o0000ooooooooool0E?ooool2o`000003ooooool0003o000000co00000_ooool2o`00
013ooooo0_l0000;ooooo`;o00002oooool2o`0001cooooo0_l0000Hooooo`;o00001_ooool2o`00
00;ooooo0_l0001`ooooo`007?ooool00ol0003oooooooooo`1Doooooa7o00000_ooool2o`0000Co
oooo0_l0000:ooooo`;o00009?ooool2o`0000_ooooo0_l00003ooooo`;o00005Oooool2o`000003
ooooool0003o000000[ooooo0_l0001`ooooo`007?ooool00ol0003oooooooooo`1Foooooa7o0000
1_ooool2o`0000?ooooo0_l00002ooooo`;o00001Oooool2o`00023ooooo0_l00007ooooo`;o0000
0_ooool2o`0000gooooo0_l0000;ooooo`;o000000?oooooo`000?l000001Oooool2o`0000;ooooo
0_l0001aooooo`007?ooool00ol0003oooooooooo`1Foooooa7o00002oooool2o`0000;ooooo0_l0
0005ooooo`;o00001oooool2o`0000Cooooo0_l00008ooooo`;o00002_ooool2o`0000Cooooo0_l0
0002ooooo`;o00000_ooool2o`0000Wooooo1?l000000ooooooo0000o`00000<ooooo`;o00000_oo
ool2o`0000;ooooo0_l0001aooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0E_oooolAo`0000Wo
oooo0_l00003ooooo`;o00000_ooool2o`0000Oooooo0_l00002ooooo`;o00001?ooool2o`0000;o
oooo0_l00004ooooo`;o00001oooool5o`0000Cooooo0_l00002ooooo`;o00000_ooool4o`0000Oo
oooo1?l000000ooooooo0000o`00000<ooooo`;o00001?ooool2o`0007?ooooo00001_ooooooMgMg
oiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool0
0ol0003oooooooooo`1Foooooa7o00002Oooool2o`0000?ooooo0_l00002ooooo`;o00001oooool2
o`0000;ooooo0_l00008ooooo`;o00003Oooool4o`0000oooooo1?l00004ooooo`?o00001?ooool2
o`0000Oooooo0_l00007ooooo`?o00000oooool2o`0006kooooo00000ooooooo410@ooooo`02oooo
o`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo05Oooooo3_l000000ooooooo0000o`00000:ooooo`;o00001?ooool2o`0000Sooooo0_l0000K
ooooo`;o000000?oooooo`000?l000001Oooool2o`0000;ooooo0_l00004ooooo`?o00001?ooool2
o`0000Gooooo0_l00007ooooo`?o00001_ooool2o`0000Cooooo1Ol0001[ooooo`0000?oooooo`00
0?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3
o`0005Oooooo4Ol00002ooooo`;o00001_ooool2o`0000Cooooo0_l00008ooooo`;o00003Oooool2
o`0000oooooo0_l00005ooooo`;o00000_ooool2o`0000[ooooo1?l0000>ooooo`;o00003_ooool3
o`0006_ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oeEE
EOl0003o410@olc<c006ooooo`03o`000?oooooooooo05Sooooo4?l00002ooooo`;o00000oooool2
o`0000Kooooo0ol0000Gooooo`;o00009_ooool4o`0000cooooo0_l00008ooooo`;o00001_ooool3
o`000003ooooool0003o000006Sooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo
00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`1Hoooooa3o00000oooool2o`00
00;ooooo0_l00006ooooo`?o000000?oooooo`000?l000002oooool2o`0003Kooooo0_l00004oooo
o`Go00001_ooool4o`0000Kooooo0ol000001?oooooo0000o`000?l0001Wooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0F_oo
ool?o`0000;ooooo0_l00002ooooo`Co00002?ooool2o`0000_ooooo0_l0000Zooooo`Go00001ooo
ool2o`0000Cooooo0ol00008ooooo`;o00003Oooool2o`0006Oooooo00001_ooooook^k^oc8b<_l0
003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`1Kooooo`;o
00000_ooool3o`000003ooooool0003o000000Go00001Oooool5o`00023ooooo0_l00008ooooo`;o
00001oooool2o`0000Oooooo0_l00002ooooo`Go00001?ooool2o`0000Wooooo0_l00007ooooo`;o
00003?ooool2o`0006Sooooo000Looooo`03o`000?oooooooooo05oooooo0ol00004ooooo`Co0000
1oooool3o`000004ooooool0003o0000o`00017ooooo0_l00005ooooo`Ko00001oooool3o`0000Oo
oooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0ol00007ooooo`;o00002Oooool3o`00
01Cooooo1?l0001Vooooo`007?ooool00ol0003oooooooooo`1Looooo`;o00002?ooool2o`0000Ko
oooo0_l00005ooooo`?o00002oooool2o`0000Cooooo0_l00005ooooo`Ko00001Oooool4o`0000ko
oooo0_l00004ooooo`?o00000_ooool3o`0000;ooooo0_l0000:ooooo`;o00002?ooool3o`0000;o
oooo0_l00007ooooo`;o0000I_ooool001cooooo00?o0000ooooooooool0G?ooool7o`0000;ooooo
0ol000000ooooooo0000o`000006o`000003ooooool0003o000000Sooooo0_l00005ooooo`;o0000
0_ooool2o`0000?ooooo0_l0000=ooooo`;o000000?oooooo`000?l000002?ooool2o`0000;ooooo
0_l0000:ooooo`?o00000_ooool7o`0000cooooo0_l000001?oooooo0000o`000?l00002ooooo`;o
000000?oooooo`000?l000000_l00006ooooo`;o0000H_ooool001cooooo00?o0000ooooooooool0
GOooool6o`0000;ooooo4?l000000ooooooo0000o`000002o`0000;ooooo0_l00002ooooo`;o0000
1Oooool2o`0000?ooooo0_l0000<ooooo`;o00000_ooool2o`0000Sooooo0_l00002ooooo`;o0000
2ooooolBo`0000Gooooo1?l00004ooooo`;o000000?oooooo`000?l000000_l00005ooooo`Go0000
H?ooool001cooooo00?o0000ooooooooool0IOoooolGo`000004ooooool0003o0000ooooo`;o0000
2_ooool2o`0000cooooo0_l00004ooooo`;o000000?oooooo`000?l000004_oooolDo`000003oooo
ool0003o000000Cooooo0ol00009ooooo`;o00001?ooool6o`0005oooooo000Looooo`03o`000?oo
oooooooo06Gooooo0ol000000ooooooo0000o`000002ooooo`oo000000?oooooo`000?l000004ooo
ool2o`0000cooooo0_l000000ooooooo0000o`00000;ooooo`;o00001Oooool2o`0000Cooooo4_l0
0003ooooo`?o00002Oooool2o`000004ooooool0003o0000o`0000Cooooo0_l0001Oooooo`007?oo
ool00ol0003oooooooooo`1Wooooo`Co00001?oooolAo`0000gooooo0_l000000ooooooo0000o`00
0002o`0000Cooooo0_l0000Fooooo`;o00000_ooool2o`0000Gooooo5Ol00003ooooo`;o00001Ooo
ool2o`0000;ooooo0_l000001?oooooo0000o`000?l00004ooooo`;o0000Goooool001cooooo00?o
0000ooooooooool0Ioooool2o`0000[ooooo3ol0000;ooooo`;o000000?oooooo`000?l000001_oo
ool2o`0000Wooooo0_l00008ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Gooooo5Ol0
0002ooooo`;o00001_ooool2o`0000;ooooo0ol0001Xooooo`007?ooool00ol0003oooooooooo`1c
oooooa3o00001Oooool2o`0000;ooooo0_l00002ooooo`;o00001?ooool2o`0000Wooooo1?l00008
ooooo`;o00001Oooool4o`0000?ooooo6_l00004ooooo`Co00000_ooool2o`0000Wooooo0_l0001M
ooooo`007?ooool00ol0003oooooooooo`1coooooa;o00000oooool2o`000004ooooool0003o0000
o`0000Kooooo1?l00009ooooo`;o00002?ooool2o`0000Wooooo0_l00002oooooa_o00001?ooool4
o`0000gooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1eoooooa3o00001_ooool2o`00
00Oooooo0_l00009ooooo`;o000000?oooooo`000?l000000_l00005ooooo`;o00002_oooolMo`00
00Cooooo0ol000000ooooooo0000o`000007ooooo`;o0000H_ooool001cooooo0_l0001eooooo`;o
000000?oooooo`000?l000004?l00009ooooo`;o00000_ooool2o`0000Kooooo0ol000000ooooooo
0000o`000002o`0000kooooo0_l000001Ooooooo0000o`000?l0003ooooo01Ko00001oooool3o`00
0003ooooool0003o000000Kooooo0ol000000ooooooo0000o`00001Oooooo`007?ooool00ol0003o
ooooooooo`1doooooaGo00000_ooool4o`0000?ooooo0_l00002ooooo`;o00001_ooool3o`0001?o
oooo0_l00009oooooa;o00002Oooool2o`0000?ooooo0_l00002ooooo`Oo0000Goooool001cooooo
00?o0000ooooooooool0M?ooool6o`000003ooooool0003o000000go000000?oooooo`000?l00000
0_l00003ooooo`;o00001_ooool2o`0000Gooooo0_l0000:ooooo`;o00000_ooool2o`0000_ooooo
5Ol00002ooooo`?o00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000005o`00063ooooo
000Looooo`03o`000?oooooooooo07Gooooo1Ol000000ooooooo0000o`00000Ao`0000;ooooo0_l0
0008ooooo`Go00000_ooool2o`0000Gooooo0_l000000ooooooo0000o`000003o`000003ooooool0
003o000000_ooooo5_l000001?oooooo0000o`000?l00006ooooo`;o00000_ooool2o`0006Gooooo
000Looooo`03o`000?oooooooooo07Gooooo0ol00003oooooa7o000000?oooooo`000?l000000ol0
0009ooooo`Co00002?ooool3o`000004ooooool0003o0000ooooo`;o00001?ooool2o`0000cooooo
4_l00006ooooo`Ko00001_ooool2o`00067ooooo000Looooo`03o`000?oooooooooo07Sooooo0_l0
00000ooooooo0000o`00000?o`000003ooooool0003o000000?o00001_ooool2o`0000gooooo0_l0
0002ooooo`;o00001oooool2o`0000kooooo3_l00008ooooo`Co00002?ooool2o`00067ooooo000L
ooooo`03o`000?oooooooooo07Sooooo0_l00004ooooo`ko00000oooool2o`000005ooooool0003o
0000o`000?ooool01?l0000=ooooo`Ko00001oooool2o`0000kooooo4Ol000000ooooooo0000o`00
0002o`0006oooooo000Looooo`03o`000?oooooooooo07Sooooo0_l00004ooooo`oo00000_ooool6
o`000004ooooool0003o0000o`0000;ooooo0ol0000;ooooo`;o00001_ooool5o`0000kooooo5ol0
00001?oooooo0000o`000?l0001Zooooo`007?ooool00ol0003oooooooooo`1moooooaKo00001?oo
ool2o`0000;ooooo0ol00008ooooo`;o00002Oooool4o`00013ooooo7Ol00002ooooo`;o00000_oo
ool2o`0005oooooo000Looooo`03o`000?oooooooooo07[ooooo0_l000000ooooooo0000o`00000A
o`000003ooooool0003o000000Ko00001oooool2o`0000Cooooo0_l00002ooooo`Ko00000_ooool3
o`0001;ooooo0_l000000ooooooo0000o`00000Jo`0000;ooooo0_l0001Oooooo`007?ooool00ol0
003oooooooooo`1jooooo`;o00001?ooool?o`0000?ooooo1ol00007ooooo`;o000000?oooooo`00
0?l000001Oooool6o`0000;ooooo0ol0000FoooooaWo0000IOooool001cooooo00?o0000oooooooo
ool0P_ooool>o`0000;ooooo0ol00002ooooo`;o00001_ooool2o`0000;ooooo0_l00009ooooo`Co
000000?oooooo`000?l000006OoooolFo`000003ooooool0003o000000;o0000H?ooool001cooooo
00?o0000ooooooooool0Q?ooool>o`000003ooooool0003o000000;ooooo0_l00006ooooo`;o0000
0oooool2o`0000Sooooo1Ol0000Loooooa?o00000_ooool5o`00063ooooo000Looooo`03o`000?oo
oooooooo08;ooooo4Ol00005ooooo`;o00001oooool2o`000003ooooool0003o000000Wooooo1Ol0
000Moooooa3o000000?oooooo`000?l000000ol0001Rooooo`007?ooool00ol0003oooooooooo`22
ooooo`;o000000?oooooo`000?l000003_l00003ooooo`;o00001oooool2o`0000Wooooo0_l00000
0ooooooo0000o`000003o`0001oooooo2?l000000ooooooo0000o`000008o`0006?ooooo000Loooo
o`03o`000?oooooooooo08Oooooo0_l000000ooooooo0000o`000009o`0000oooooo1?l000001?oo
oooo0000o`000?ooool2o`0000;ooooo1?l0000Sooooo`co0000I_ooool001cooooo0_l00029oooo
o`;o00000_ooool9o`0000Oooooo0_l000001?oooooo0000o`000?l00002ooooo`Oo0000;?ooool;
o`0006Oooooo000Looooo`03o`000?oooooooooo08Sooooo3?l00003ooooo`;o00000oooool2o`00
0004ooooool0003o0000o`0000Gooooo1?l00006ooooo`?o0000UOooool001cooooo00?o0000oooo
ooooool0R_ooool<o`000003ooooool0003o000000Cooooo0_l0000:ooooo`;o00001Oooool4o`00
09Gooooo000Looooo`03o`000?oooooooooo08[ooooo4?l000000ooooooo0000o`000002o`00013o
oooo1?l0002Fooooo`007?ooool00ol0003oooooooooo`2:oooooa3o000000?oooooo`000?l00000
0_ooool2o`0000Oooooo0_l00005ooooo`Co0000U_ooool001cooooo00?o0000ooooooooool0R_oo
ool@o`0000Gooooo0_l00007ooooo`;o00001oooool2o`0009Kooooo000Looooo`03o`000?oooooo
oooo08[ooooo3_l000001?oooooo0000o`000?l0000:ooooo`?o0000X?ooool001cooooo00?o0000
ooooooooool0R_oooolEo`0000Oooooo0ol00006ooooo`?o0000Uoooool001cooooo00?o0000oooo
ooooool0R_oooolHo`0000Gooooo0_l00006ooooo`?o0000Uoooool001cooooo00?o0000oooooooo
ool0R_oooolHo`0000cooooo1?l0002Gooooo`007?ooool00ol0003oooooooooo`2;oooooaKo0000
3Oooool4o`0009Oooooo000Looooo`03o`000?oooooooooo08_ooooo4?l00003ooooo`?o00000ooo
ool2o`0000Oooooo1?l0002Hooooo`007?ooool00ol0003oooooooooo`2;oooooa7o00001?ooool3
o`000003ooooool0003o000000Cooooo1_l0002Iooooo`007?ooool00ol0003oooooooooo`2=oooo
o`oo00001?ooool3o`0000Kooooo1ol0002Iooooo`007?ooool00ol0003oooooooooo`2=oooooa7o
00000_ooool6o`000003ooooool0003o000000Oo0000VOooool001cooooo00?o0000ooooooooool0
S_ooool@o`0000;ooooo1_l000000ooooooo0000o`000006o`0009[ooooo000Looooo`;o0000T?oo
ool@o`000003ooooool0003o000000Go00000_ooool4o`0009cooooo000Looooo`03o`000?oooooo
oooo093ooooo3ol00006ooooo`;o000000?oooooo`000?l000000ol0002Looooo`007?ooool00ol0
003oooooooooo`2Aooooo`oo00001oooool3o`0009oooooo000Looooo`03o`000?oooooooooo097o
oooo3?l000000ooooooo0000o`000006ooooo`Go0000W_ooool001cooooo00?o0000ooooooooool0
UOooool<o`0000Gooooo0_l000000ooooooo0000o`00002Nooooo`007?ooool00ol0003ooooooooo
o`2Eooooo`co00001?ooool4o`000:3ooooo000Looooo`03o`000?oooooooooo09Gooooo0_l00000
0ooooooo0000o`000007o`0000;ooooo1_l0002Pooooo`007?ooool00ol0003oooooooooo`2Koooo
o`[o0000Y?ooool001cooooo00?o0000ooooooooool0V_ooool<o`000:?ooooo000Looooo`03o`00
0?oooooooooo09[ooooo2?l000001?oooooo0000o`000?l0002Sooooo`007?ooool00ol0003ooooo
ooooo`2Kooooo`Oo0000Yoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool00006
ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<
c006ooooo`03o`000?oooooooooo0?ooooooB_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?oo
ooooB_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool0oooooom:ooooo`0000?oooooo`000?ooool0
0_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`000?oo
ooooB_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Oo<c<co0000
o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom:ooooo`0000?ooooooa0@4?ooool0
0_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003o
ooooooooo`3ooooood[ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj
^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0?ooooooB_ooool00006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?oo
ooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom:oooo
o`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo
00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o0000ooooooooool0oooo
oomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo
0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`004_ooool00omEEEGoIVIV
o`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Uooooo`04
oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05_ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^h3ooooo`Go0000T?ooool00:Kooooo00Go0000oooooooooooooooo
o`000009ooooo`Ko00003?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OnHV9So8B4Qonk^k_ooooooA4A4093ooooo002Vooooo`05o`000?oooooooooooooo
ool000006oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001?ooool0
0onHV9So8B4Qonk^kP2Aooooo`00Y_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l0000<
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`03oiRHV?lQ
8B7ok^k^093ooooo002Vooooo`05o`000?n7QhOoooooojVYZOl000006oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000001_ooool00omgMgOoIVIVooooo`2?ooooo`00YOoo
ool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo01Wooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00Oooooo00?o0000ooooooooool0S_ooool00<Kooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go0000okZj^_oooooo
V9RHoa0@402@ooooo`00a?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01OnHV9So410@o`000?lQ8B7oc<c<093ooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(108) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.44287 .74926 Mdot
.41169 .69276 Mdot
.69433 .5305 Mdot
.40465 .39874 Mdot
.57292 .22794 Mdot
.69319 .52425 Mdot
.60153 .65154 Mdot
.62314 .66083 Mdot
.73165 .50301 Mdot
.42874 .37452 Mdot
.59699 .67277 Mdot
.27239 .42872 Mdot
.60808 .6494 Mdot
.38688 .43878 Mdot
.28157 .35874 Mdot
.29326 .54068 Mdot
.42271 .73634 Mdot
.56975 .22391 Mdot
.27845 .53677 Mdot
.72973 .50716 Mdot
.53134 .23599 Mdot
.39659 .42037 Mdot
.43576 .73734 Mdot
.38452 .43955 Mdot
.28052 .53877 Mdot
.41126 .66644 Mdot
.44566 .74077 Mdot
.28402 .54922 Mdot
.27642 .43316 Mdot
.58525 .63679 Mdot
.28413 .56482 Mdot
.35731 .31574 Mdot
.61236 .37256 Mdot
.3695 .62902 Mdot
.62368 .70946 Mdot
.59702 .68377 Mdot
.72389 .49692 Mdot
.58641 .65903 Mdot
.59929 .63114 Mdot
.61732 .69996 Mdot
.61559 .69969 Mdot
.41376 .66811 Mdot
.61235 .70211 Mdot
.68775 .69906 Mdot
.35648 .44112 Mdot
.33836 .60324 Mdot
.73308 .51252 Mdot
.33637 .464 Mdot
.42729 .75002 Mdot
.76167 .47697 Mdot
.42234 .3426 Mdot
.62594 .68354 Mdot
.58738 .37675 Mdot
.31946 .59857 Mdot
.60976 .64412 Mdot
.27676 .53928 Mdot
.67063 .52696 Mdot
.37049 .43125 Mdot
.26894 .43685 Mdot
.36098 .61379 Mdot
.38163 .41526 Mdot
.55435 .24594 Mdot
.44508 .67728 Mdot
.66338 .54194 Mdot
.70526 .52833 Mdot
.58153 .64549 Mdot
.40425 .68804 Mdot
.63784 .7044 Mdot
.41703 .40062 Mdot
.74957 .49731 Mdot
.33423 .46118 Mdot
.59676 .67279 Mdot
.40074 .64461 Mdot
.41 .41897 Mdot
.43358 .75903 Mdot
.64265 .71322 Mdot
.57319 .22469 Mdot
.39015 .6419 Mdot
.75949 .478 Mdot
.33385 .4987 Mdot
.40228 .41403 Mdot
.50893 .75555 Mdot
.26361 .45586 Mdot
.42068 .66043 Mdot
.36399 .45485 Mdot
.47181 .78268 Mdot
.34579 .42665 Mdot
.29138 .56023 Mdot
.28057 .54532 Mdot
.24868 .4394 Mdot
.66853 .50734 Mdot
.43424 .71498 Mdot
.39095 .42868 Mdot
.41949 .39809 Mdot
.4355 .37677 Mdot
.38379 .45393 Mdot
.27779 .54413 Mdot
.5905 .35079 Mdot
.61953 .69615 Mdot
.58412 .39515 Mdot
.64551 .71111 Mdot
.57868 .37673 Mdot
.32657 .45379 Mdot
.70081 .50316 Mdot
.44228 .69873 Mdot
.59852 .35459 Mdot
.635 .70919 Mdot
.39118 .43133 Mdot
.59068 .67455 Mdot
.43655 .7254 Mdot
.27491 .56274 Mdot
.55897 .26937 Mdot
.56074 .20546 Mdot
.4046 .66737 Mdot
.3841 .51806 Mdot
.36951 .41459 Mdot
.39115 .4138 Mdot
.41197 .68505 Mdot
.71677 .52086 Mdot
.68953 .57035 Mdot
.42574 .71086 Mdot
.6122 .69174 Mdot
.42088 .73745 Mdot
.61565 .38441 Mdot
.71218 .52393 Mdot
.59669 .4027 Mdot
.58321 .35396 Mdot
.37954 .32267 Mdot
.41756 .43269 Mdot
.61841 .37292 Mdot
.70389 .49922 Mdot
.42286 .70548 Mdot
.61484 .65916 Mdot
.42066 .3952 Mdot
.41824 .65941 Mdot
.60532 .63968 Mdot
.56095 .29304 Mdot
.55569 .29579 Mdot
.40455 .65069 Mdot
.39615 .51557 Mdot
.58443 .65809 Mdot
.62472 .65313 Mdot
.42011 .34398 Mdot
.41284 .64816 Mdot
.57932 .25376 Mdot
.61859 .64522 Mdot
.65116 .43313 Mdot
.26984 .55804 Mdot
.40071 .31822 Mdot
.5148 .74453 Mdot
.42206 .34352 Mdot
.52751 .25751 Mdot
.55508 .25041 Mdot
.60731 .63985 Mdot
.37715 .40095 Mdot
.41107 .71065 Mdot
.41301 .65417 Mdot
.2994 .43668 Mdot
.60427 .35905 Mdot
.36337 .42341 Mdot
.57713 .39123 Mdot
.58412 .35216 Mdot
.3854 .43699 Mdot
.34748 .60709 Mdot
.43835 .70134 Mdot
.34248 .44065 Mdot
.72883 .494 Mdot
.56678 .21994 Mdot
.59608 .68002 Mdot
.36997 .45272 Mdot
.43504 .39016 Mdot
.29886 .43092 Mdot
.62832 .66 Mdot
.66329 .72591 Mdot
.78337 .47481 Mdot
.59409 .66138 Mdot
.64615 .72552 Mdot
.6808 .5077 Mdot
.28872 .4371 Mdot
.55835 .26318 Mdot
.59947 .37574 Mdot
.34683 .435 Mdot
.42547 .3421 Mdot
.25071 .43619 Mdot
.53585 .23407 Mdot
.53022 .27558 Mdot
.49916 .75352 Mdot
.65791 .73187 Mdot
.38851 .39978 Mdot
.27172 .57482 Mdot
.41308 .33179 Mdot
.57499 .63236 Mdot
.61625 .66587 Mdot
.71219 .52927 Mdot
.7195 .51978 Mdot
.781 .46992 Mdot
.30477 .42153 Mdot
.27607 .42309 Mdot
.4069 .40765 Mdot
.58731 .38721 Mdot
.44108 .67166 Mdot
.55597 .24815 Mdot
.41548 .72398 Mdot
.5111 .75326 Mdot
.34566 .48881 Mdot
.27486 .53444 Mdot
.72518 .47197 Mdot
.65572 .53287 Mdot
.58562 .36086 Mdot
.56949 .24832 Mdot
.36888 .425 Mdot
.43967 .71634 Mdot
.41674 .3378 Mdot
.61144 .39005 Mdot
.54608 .19646 Mdot
.42867 .72594 Mdot
.33934 .47602 Mdot
.60491 .64461 Mdot
.68046 .49942 Mdot
.34528 .42727 Mdot
.40129 .43007 Mdot
.39242 .64415 Mdot
.40355 .39445 Mdot
.2625 .55408 Mdot
.27669 .55889 Mdot
.77536 .47416 Mdot
.64835 .72014 Mdot
.59357 .6545 Mdot
.732 .51415 Mdot
.40245 .65387 Mdot
.34773 .62581 Mdot
.68827 .5151 Mdot
.53669 .22657 Mdot
.592 .6666 Mdot
.57016 .28493 Mdot
.69537 .51108 Mdot
.57166 .2285 Mdot
.26251 .43808 Mdot
.70501 .49132 Mdot
.55569 .27713 Mdot
.30739 .36598 Mdot
.5899 .35519 Mdot
.57802 .30549 Mdot
.6005 .65328 Mdot
.40957 .73371 Mdot
.34739 .4328 Mdot
.59263 .37617 Mdot
.60084 .40566 Mdot
.28621 .44109 Mdot
.5702 .37915 Mdot
.60883 .37178 Mdot
.28959 .43996 Mdot
.55772 .23065 Mdot
.53232 .7002 Mdot
.28209 .56511 Mdot
.42018 .73434 Mdot
.40289 .39535 Mdot
.65102 .72335 Mdot
.60495 .63873 Mdot
.37415 .41997 Mdot
.49795 .76544 Mdot
.60042 .65657 Mdot
.38023 .43074 Mdot
.59393 .63141 Mdot
.42007 .66105 Mdot
.34341 .4882 Mdot
.40291 .64288 Mdot
.38233 .43788 Mdot
.59342 .631 Mdot
.73493 .50941 Mdot
.41071 .66482 Mdot
.39442 .42584 Mdot
.41012 .40441 Mdot
.58804 .38428 Mdot
.27422 .55918 Mdot
.63719 .67319 Mdot
.2758 .42899 Mdot
.6618 .53044 Mdot
.30092 .43985 Mdot
.54503 .29201 Mdot
.66891 .42999 Mdot
.41205 .64729 Mdot
.57001 .37638 Mdot
.68839 .52154 Mdot
.43074 .3616 Mdot
.346 .47911 Mdot
.35839 .44386 Mdot
.60894 .37798 Mdot
.26794 .45806 Mdot
.60756 .67485 Mdot
.26549 .55805 Mdot
.61358 .40792 Mdot
.67239 .52972 Mdot
.57927 .38278 Mdot
.37403 .45612 Mdot
.4377 .73299 Mdot
.28665 .53707 Mdot
.67828 .50595 Mdot
.42967 .73609 Mdot
.33761 .45468 Mdot
.64439 .70916 Mdot
.60572 .34181 Mdot
.61027 .67951 Mdot
.28822 .55336 Mdot
.29886 .4408 Mdot
.75006 .49527 Mdot
.41514 .66714 Mdot
.61643 .64953 Mdot
.40188 .64425 Mdot
.42787 .35763 Mdot
.32872 .47512 Mdot
.40541 .63793 Mdot
.54794 .28799 Mdot
.79571 .45748 Mdot
.60305 .67842 Mdot
.5934 .39852 Mdot
.77382 .48696 Mdot
.43141 .75132 Mdot
.70111 .50772 Mdot
.42554 .49613 Mdot
.6662 .51267 Mdot
.28421 .53456 Mdot
.76183 .49229 Mdot
.29948 .42774 Mdot
.35555 .45128 Mdot
.66735 .55278 Mdot
.59489 .35045 Mdot
.39936 .44091 Mdot
.41939 .66205 Mdot
.34603 .31725 Mdot
.43193 .38222 Mdot
.30544 .42256 Mdot
.67283 .52702 Mdot
.40746 .51138 Mdot
.28143 .55934 Mdot
.28697 .54967 Mdot
.41489 .71468 Mdot
.59661 .39381 Mdot
.56916 .29883 Mdot
.56972 .30534 Mdot
.70604 .41327 Mdot
.2475 .4573 Mdot
.37746 .51581 Mdot
.40871 .65782 Mdot
.77394 .46877 Mdot
.43526 .76542 Mdot
.61211 .38699 Mdot
.62363 .66197 Mdot
.66605 .72482 Mdot
.34079 .43195 Mdot
.62479 .38583 Mdot
.26359 .53941 Mdot
.42095 .74567 Mdot
.39698 .64235 Mdot
.61848 .65204 Mdot
.31927 .42513 Mdot
.41968 .37522 Mdot
.37234 .41588 Mdot
.62684 .66697 Mdot
.60519 .40041 Mdot
.27044 .43954 Mdot
.37488 .31062 Mdot
.69659 .70563 Mdot
.36477 .44339 Mdot
.36853 .62024 Mdot
.35069 .44707 Mdot
.38768 .32477 Mdot
.36483 .43203 Mdot
.41608 .66318 Mdot
.29941 .58415 Mdot
.43712 .39817 Mdot
.71276 .47263 Mdot
.34902 .48819 Mdot
.54714 .27748 Mdot
.39819 .42931 Mdot
.35657 .42832 Mdot
.57919 .2736 Mdot
.42615 .68871 Mdot
.42684 .41653 Mdot
.53202 .69824 Mdot
.39251 .42412 Mdot
.59713 .68189 Mdot
.2683 .4505 Mdot
.35847 .31887 Mdot
.28046 .55647 Mdot
.43711 .73588 Mdot
.60542 .63309 Mdot
.60732 .69282 Mdot
.5775 .40141 Mdot
.60478 .63838 Mdot
.36157 .4509 Mdot
.26622 .45069 Mdot
.40302 .66612 Mdot
.59174 .35596 Mdot
.43158 .70967 Mdot
.6104 .32432 Mdot
.60431 .65989 Mdot
.58241 .37436 Mdot
.31512 .41828 Mdot
.61368 .67387 Mdot
.53784 .68067 Mdot
.27575 .56384 Mdot
.60398 .40169 Mdot
.44265 .7473 Mdot
.75293 .49565 Mdot
.61086 .38288 Mdot
.61076 .64426 Mdot
.35577 .44114 Mdot
.2725 .54708 Mdot
.60905 .63946 Mdot
.37202 .62299 Mdot
.27327 .56614 Mdot
.39013 .42452 Mdot
.42925 .68307 Mdot
.42013 .69292 Mdot
.34471 .43289 Mdot
.37687 .40525 Mdot
.68123 .53186 Mdot
.6091 .38423 Mdot
.60751 .38758 Mdot
.57917 .354 Mdot
.66785 .51322 Mdot
.79939 .45873 Mdot
.63829 .71611 Mdot
.35695 .31994 Mdot
.65539 .71755 Mdot
.59024 .37234 Mdot
.68282 .53217 Mdot
.35352 .44554 Mdot
.30789 .43949 Mdot
.59473 .62871 Mdot
.80689 .44961 Mdot
.33781 .43433 Mdot
.41163 .72144 Mdot
.62869 .6808 Mdot
.27606 .4247 Mdot
.77144 .47286 Mdot
.54756 .25532 Mdot
.37641 .51711 Mdot
.6275 .6778 Mdot
.38354 .64142 Mdot
.62714 .67746 Mdot
.35478 .4303 Mdot
.39239 .44752 Mdot
.40566 .71933 Mdot
.54677 .27764 Mdot
.28296 .4307 Mdot
.37718 .43491 Mdot
.77443 .4676 Mdot
.43689 .76588 Mdot
.56817 .30657 Mdot
.26621 .43405 Mdot
.5803 .36079 Mdot
.54875 .24676 Mdot
.40748 .4125 Mdot
.295 .43622 Mdot
.61459 .40173 Mdot
.59039 .63357 Mdot
.54986 .28732 Mdot
.71982 .47156 Mdot
.42687 .73089 Mdot
.64466 .71973 Mdot
.57249 .40023 Mdot
.6039 .6799 Mdot
.34445 .37999 Mdot
.58191 .36895 Mdot
.67723 .72452 Mdot
.48144 .16998 Mdot
.60298 .36538 Mdot
.66955 .53619 Mdot
.43331 .37776 Mdot
.29202 .43459 Mdot
.38934 .42523 Mdot
.56463 .29815 Mdot
.41564 .6927 Mdot
.65806 .73046 Mdot
.59108 .64857 Mdot
.39672 .43619 Mdot
.41098 .64538 Mdot
.49017 .76615 Mdot
.58214 .38376 Mdot
.56568 .27476 Mdot
.56685 .28563 Mdot
.41152 .42439 Mdot
.26746 .45995 Mdot
.41118 .66122 Mdot
.39426 .42632 Mdot
.41439 .42135 Mdot
.76684 .48406 Mdot
.43505 .68854 Mdot
.70088 .49334 Mdot
.27124 .53691 Mdot
.34152 .50287 Mdot
.65069 .71495 Mdot
.59759 .643 Mdot
.60023 .39584 Mdot
.59478 .65822 Mdot
.78187 .47718 Mdot
.60775 .38666 Mdot
.39511 .42582 Mdot
.40286 .66538 Mdot
.39341 .42721 Mdot
.39213 .42522 Mdot
.35832 .43481 Mdot
.37191 .51541 Mdot
.6931 .48503 Mdot
.56575 .26652 Mdot
.26426 .43625 Mdot
.67176 .51426 Mdot
.73231 .47443 Mdot
.43542 .37465 Mdot
.40304 .42179 Mdot
.38693 .41814 Mdot
.39268 .64846 Mdot
.26711 .554 Mdot
.61334 .67016 Mdot
.40598 .72085 Mdot
.35258 .41991 Mdot
.73655 .51036 Mdot
.42748 .41491 Mdot
.405 .63829 Mdot
.63562 .71733 Mdot
.44482 .77653 Mdot
.57653 .40613 Mdot
.59188 .40618 Mdot
.60935 .37522 Mdot
.57746 .35469 Mdot
.60318 .69134 Mdot
.68391 .53276 Mdot
.58922 .32803 Mdot
.34164 .50088 Mdot
.38027 .40252 Mdot
.38723 .45007 Mdot
.76983 .48675 Mdot
.61383 .36767 Mdot
.43354 .38486 Mdot
.29236 .53057 Mdot
.71132 .48482 Mdot
.58904 .35071 Mdot
.4646 .76094 Mdot
.43403 .73199 Mdot
.76507 .4779 Mdot
.58669 .65862 Mdot
.5536 .27829 Mdot
.77005 .39214 Mdot
.42811 .70611 Mdot
.44965 .69353 Mdot
.71657 .49203 Mdot
.26525 .44776 Mdot
.30915 .59638 Mdot
.70249 .51079 Mdot
.26566 .5624 Mdot
.40758 .68496 Mdot
.58764 .35398 Mdot
.27641 .45637 Mdot
.28337 .44442 Mdot
.74276 .49209 Mdot
.41324 .40474 Mdot
.65693 .55954 Mdot
.67114 .53296 Mdot
.6016 .39011 Mdot
.67316 .52662 Mdot
.60277 .66847 Mdot
.69397 .50248 Mdot
.37382 .62617 Mdot
.42256 .40677 Mdot
.31848 .59836 Mdot
.27704 .35434 Mdot
.37151 .41193 Mdot
.61968 .68351 Mdot
.64545 .72126 Mdot
.38583 .40694 Mdot
.57681 .23494 Mdot
.67281 .53683 Mdot
.7858 .46992 Mdot
.27082 .54478 Mdot
.76218 .49103 Mdot
.43804 .7345 Mdot
.64671 .71808 Mdot
.64652 .72163 Mdot
.61038 .38064 Mdot
.41559 .65233 Mdot
.64226 .72734 Mdot
.61358 .69317 Mdot
.60998 .34648 Mdot
.34672 .43184 Mdot
.43672 .70192 Mdot
.2707 .43986 Mdot
.567 .22166 Mdot
.39337 .42249 Mdot
.69757 .49539 Mdot
.78025 .4735 Mdot
.28069 .35591 Mdot
.68583 .51779 Mdot
.59733 .39778 Mdot
.4353 .69392 Mdot
.27432 .53925 Mdot
.42247 .7015 Mdot
.41528 .39608 Mdot
.64951 .72123 Mdot
.4346 .73401 Mdot
.53561 .22916 Mdot
.37926 .42015 Mdot
.3454 .60488 Mdot
.25943 .43529 Mdot
.39078 .42316 Mdot
.70141 .53335 Mdot
.57961 .26714 Mdot
.54377 .24551 Mdot
.71236 .47656 Mdot
.56501 .23633 Mdot
.44871 .75237 Mdot
.70671 .52945 Mdot
.5745 .26249 Mdot
.70898 .41312 Mdot
.57031 .37112 Mdot
.56952 .26216 Mdot
.36412 .45451 Mdot
.60348 .63617 Mdot
.40382 .70272 Mdot
.39081 .44617 Mdot
.46455 .42201 Mdot
.27274 .58962 Mdot
.58576 .383 Mdot
.38836 .42252 Mdot
.3577 .42581 Mdot
.40923 .64534 Mdot
.51625 .74607 Mdot
.66504 .53815 Mdot
.58858 .3976 Mdot
.42744 .7088 Mdot
.50798 .75684 Mdot
.70016 .53318 Mdot
.57454 .27937 Mdot
.59264 .64176 Mdot
.39001 .65408 Mdot
.58844 .37931 Mdot
.60089 .6522 Mdot
.70789 .47884 Mdot
.42563 .34721 Mdot
.29673 .56036 Mdot
.71499 .50193 Mdot
.42273 .34337 Mdot
.26958 .53531 Mdot
.77983 .4698 Mdot
.57444 .63475 Mdot
.43623 .72302 Mdot
.61585 .64492 Mdot
.5631 .28106 Mdot
.39957 .64216 Mdot
.4319 .7107 Mdot
.59716 .64331 Mdot
.2891 .59471 Mdot
.28203 .45642 Mdot
.64101 .71233 Mdot
.25786 .44657 Mdot
.42218 .34616 Mdot
.59073 .38071 Mdot
.56138 .26454 Mdot
.6483 .71954 Mdot
.41344 .66825 Mdot
.66011 .70793 Mdot
.4236 .34098 Mdot
.26783 .56057 Mdot
.5513 .27481 Mdot
.49271 .75869 Mdot
.57842 .63638 Mdot
.61094 .66795 Mdot
.77498 .4675 Mdot
.57935 .24329 Mdot
.35797 .45267 Mdot
.81183 .44683 Mdot
.37214 .45108 Mdot
.63341 .67779 Mdot
.26317 .54087 Mdot
.42306 .7242 Mdot
.63895 .70726 Mdot
.27917 .53253 Mdot
.27349 .43009 Mdot
.38368 .40409 Mdot
.77386 .47543 Mdot
.40115 .69148 Mdot
.58635 .33922 Mdot
.36805 .41478 Mdot
.37546 .43369 Mdot
.6021 .40608 Mdot
.36168 .31977 Mdot
.56167 .6373 Mdot
.6085 .36308 Mdot
.71398 .48708 Mdot
.59281 .35548 Mdot
.59279 .39568 Mdot
.4414 .74219 Mdot
.77757 .46843 Mdot
.59574 .40796 Mdot
.37587 .44027 Mdot
.38692 .43317 Mdot
.60146 .63097 Mdot
.27101 .45768 Mdot
.27813 .44389 Mdot
.66183 .53204 Mdot
.61906 .36082 Mdot
.41873 .42622 Mdot
.42016 .66009 Mdot
.56022 .29958 Mdot
.58286 .40454 Mdot
.42471 .7334 Mdot
.39161 .45112 Mdot
.76676 .48458 Mdot
.59821 .36158 Mdot
.5971 .41258 Mdot
.55402 .2741 Mdot
.62739 .65651 Mdot
.38267 .62041 Mdot
.67072 .53444 Mdot
.29446 .56034 Mdot
.63016 .36646 Mdot
.76218 .48204 Mdot
.59156 .38233 Mdot
.57924 .36837 Mdot
.41412 .65178 Mdot
.37483 .62369 Mdot
.5912 .41898 Mdot
.66838 .51762 Mdot
.68884 .72637 Mdot
.625 .6974 Mdot
.29725 .43972 Mdot
.59547 .6551 Mdot
.4367 .72391 Mdot
.37857 .3212 Mdot
.56988 .28349 Mdot
.61134 .67194 Mdot
.60999 .37265 Mdot
.43398 .72008 Mdot
.38585 .62781 Mdot
.38133 .43924 Mdot
.39881 .42061 Mdot
.73243 .51313 Mdot
.40489 .32457 Mdot
.59778 .6285 Mdot
.57032 .2967 Mdot
.68484 .53728 Mdot
.27249 .54489 Mdot
.41117 .71313 Mdot
.55853 .33318 Mdot
.25485 .435 Mdot
.67103 .5183 Mdot
.4108 .6935 Mdot
.57212 .30227 Mdot
.56678 .26638 Mdot
.35614 .42179 Mdot
.52722 .26581 Mdot
.60739 .67017 Mdot
.41764 .66033 Mdot
.44781 .76327 Mdot
.27949 .43498 Mdot
.40069 .42343 Mdot
.2644 .55197 Mdot
.63993 .72537 Mdot
.36558 .45389 Mdot
.55327 .28517 Mdot
.40571 .68465 Mdot
.35495 .44766 Mdot
.58204 .256 Mdot
.5874 .33944 Mdot
.5858 .36326 Mdot
.67094 .55365 Mdot
.57954 .29045 Mdot
.58165 .26212 Mdot
.58226 .25231 Mdot
.66626 .72479 Mdot
.27581 .42543 Mdot
.61918 .34079 Mdot
.41293 .40547 Mdot
.42232 .34737 Mdot
.29168 .56861 Mdot
.6223 .69289 Mdot
.75004 .49384 Mdot
.36363 .42572 Mdot
.41079 .40543 Mdot
.40618 .731 Mdot
.29403 .54023 Mdot
.34321 .44317 Mdot
.419 .72545 Mdot
.45286 .73424 Mdot
.69964 .53988 Mdot
.51364 .74477 Mdot
.81568 .43638 Mdot
.25647 .44005 Mdot
.25268 .44797 Mdot
.42902 .69633 Mdot
.59447 .6354 Mdot
.25402 .44632 Mdot
.62937 .66165 Mdot
.41711 .68589 Mdot
.29901 .54918 Mdot
.37222 .6238 Mdot
.55359 .24621 Mdot
.35439 .43139 Mdot
.59739 .64934 Mdot
.35867 .42763 Mdot
.59585 .64581 Mdot
.40667 .5146 Mdot
.25819 .45647 Mdot
.38557 .39875 Mdot
.37524 .45755 Mdot
.52975 .23986 Mdot
.40133 .42082 Mdot
.7757 .46585 Mdot
.41255 .70532 Mdot
.62104 .37427 Mdot
.29831 .56762 Mdot
.43396 .3823 Mdot
.38873 .4178 Mdot
.26612 .58565 Mdot
.39183 .41201 Mdot
.80987 .45218 Mdot
.25526 .43827 Mdot
.34452 .43966 Mdot
.61865 .66667 Mdot
.60163 .68 Mdot
.39828 .66211 Mdot
.57954 .37 Mdot
.49608 .75659 Mdot
.381 .43127 Mdot
.67431 .54786 Mdot
.55262 .22274 Mdot
.58077 .27495 Mdot
.40579 .69829 Mdot
.47496 .1735 Mdot
.60932 .69867 Mdot
.73209 .49039 Mdot
.28268 .56621 Mdot
.70747 .48936 Mdot
.66255 .53836 Mdot
.44202 .76865 Mdot
.56232 .26525 Mdot
.42831 .41091 Mdot
.36355 .61582 Mdot
.45515 .72596 Mdot
.28172 .43518 Mdot
.69443 .54259 Mdot
.61433 .402 Mdot
.24438 .48302 Mdot
.5632 .22727 Mdot
.57047 .24049 Mdot
.60281 .64299 Mdot
.67332 .54877 Mdot
.58937 .39681 Mdot
.57407 .27052 Mdot
.70725 .53317 Mdot
.56932 .38596 Mdot
.78818 .46342 Mdot
.41186 .65988 Mdot
.41206 .50746 Mdot
.33657 .60454 Mdot
.61235 .68414 Mdot
.76813 .47236 Mdot
.40067 .65345 Mdot
.41145 .64326 Mdot
.58949 .39034 Mdot
.72559 .48341 Mdot
.42497 .65441 Mdot
.3507 .42957 Mdot
.58758 .35717 Mdot
.39785 .4383 Mdot
.5725 .22247 Mdot
.38488 .43081 Mdot
.73866 .5058 Mdot
.61928 .67483 Mdot
.67811 .5293 Mdot
.60059 .64441 Mdot
.35257 .31875 Mdot
.37633 .42656 Mdot
.39834 .42746 Mdot
.26898 .44994 Mdot
.44277 .72815 Mdot
.366 .62082 Mdot
.67089 .52177 Mdot
.67587 .52913 Mdot
.29865 .56602 Mdot
.41708 .73481 Mdot
.57359 .41208 Mdot
.2559 .44596 Mdot
.39473 .41046 Mdot
.41363 .70599 Mdot
.28838 .57208 Mdot
.68225 .73072 Mdot
.27163 .45437 Mdot
.4411 .73671 Mdot
.79969 .46004 Mdot
.41669 .41873 Mdot
.58532 .39941 Mdot
.61355 .35753 Mdot
.24532 .4548 Mdot
.5683 .22227 Mdot
.42857 .72839 Mdot
.58024 .39341 Mdot
.40907 .70655 Mdot
.66436 .51549 Mdot
.62556 .71651 Mdot
.4184 .71829 Mdot
.38759 .41481 Mdot
.81482 .43562 Mdot
.5999 .63549 Mdot
.35188 .44009 Mdot
.63779 .70845 Mdot
.39557 .64338 Mdot
.42061 .70535 Mdot
.5694 .38692 Mdot
.2659 .56195 Mdot
.60953 .67205 Mdot
.37514 .40339 Mdot
.37142 .6257 Mdot
.28715 .53719 Mdot
.56545 .22131 Mdot
.41673 .43037 Mdot
.32934 .46115 Mdot
.7793 .46318 Mdot
.43351 .36116 Mdot
.65077 .72662 Mdot
.59275 .67668 Mdot
.66363 .73107 Mdot
.44485 .73304 Mdot
.53992 .25901 Mdot
.38395 .62344 Mdot
.60067 .39719 Mdot
.72833 .48662 Mdot
.35661 .43522 Mdot
.57715 .35319 Mdot
.64173 .71761 Mdot
.56718 .25628 Mdot
.25083 .43629 Mdot
.71397 .50798 Mdot
.57318 .37202 Mdot
.6068 .66308 Mdot
.41515 .67104 Mdot
.4233 .72875 Mdot
.79401 .46267 Mdot
.35244 .44635 Mdot
.39749 .42245 Mdot
.6304 .71049 Mdot
.53012 .28424 Mdot
.56698 .23513 Mdot
.59522 .35061 Mdot
.63238 .71067 Mdot
.26894 .45496 Mdot
.391 .64018 Mdot
.35124 .43217 Mdot
.26371 .45199 Mdot
.66076 .72694 Mdot
.46224 .74023 Mdot
.56271 .24066 Mdot
.3281 .48304 Mdot
.42881 .72688 Mdot
.61529 .65789 Mdot
.70659 .41647 Mdot
.26482 .54426 Mdot
.40013 .40118 Mdot
.34051 .48346 Mdot
.2918 .44131 Mdot
.28902 .56247 Mdot
.57492 .40375 Mdot
.33411 .47211 Mdot
.2971 .56918 Mdot
.29586 .55128 Mdot
.40363 .44148 Mdot
.40816 .43879 Mdot
.41691 .70625 Mdot
.30445 .42315 Mdot
.70253 .49595 Mdot
.26565 .56506 Mdot
.55517 .32712 Mdot
.28084 .56343 Mdot
.30177 .43756 Mdot
.46405 .747 Mdot
.27184 .46617 Mdot
.40806 .68011 Mdot
.43281 .7509 Mdot
.60976 .68168 Mdot
.28523 .53606 Mdot
.67002 .51934 Mdot
.60625 .41231 Mdot
.75438 .48934 Mdot
.41556 .70378 Mdot
.70382 .53545 Mdot
.58184 .64574 Mdot
.71517 .50193 Mdot
.70832 .48636 Mdot
.62093 .67656 Mdot
.40303 .71177 Mdot
.25747 .43417 Mdot
.621 .67812 Mdot
.60144 .4098 Mdot
.57351 .28016 Mdot
.45351 .72427 Mdot
.60096 .35426 Mdot
.33153 .44472 Mdot
.68834 .71741 Mdot
.72284 .49746 Mdot
.34449 .48681 Mdot
.42296 .74885 Mdot
.57598 .30479 Mdot
.42036 .71763 Mdot
.58463 .41893 Mdot
.55247 .2517 Mdot
.36397 .45602 Mdot
.5497 .32288 Mdot
.57382 .63291 Mdot
.43305 .39544 Mdot
.45292 .7367 Mdot
.7553 .48793 Mdot
.61308 .6809 Mdot
.53976 .67493 Mdot
.58587 .39755 Mdot
.43624 .74116 Mdot
.37595 .62118 Mdot
.60525 .39099 Mdot
.61469 .6598 Mdot
.35108 .60306 Mdot
.35733 .4227 Mdot
.6003 .66782 Mdot
.41964 .42575 Mdot
.39142 .51664 Mdot
.55442 .29999 Mdot
.58024 .35348 Mdot
.29493 .53954 Mdot
.70685 .52628 Mdot
.29974 .5611 Mdot
.36729 .40355 Mdot
.38656 .31732 Mdot
.40258 .40574 Mdot
.34519 .48515 Mdot
.78324 .47742 Mdot
.40609 .66921 Mdot
.59563 .36697 Mdot
.58923 .38248 Mdot
.28553 .53374 Mdot
.81307 .39402 Mdot
.57151 .25431 Mdot
.79238 .46057 Mdot
.37722 .42776 Mdot
.40071 .4142 Mdot
.38653 .63204 Mdot
.41841 .50518 Mdot
.58745 .35284 Mdot
.39798 .40346 Mdot
.25144 .46067 Mdot
.62008 .66139 Mdot
.33053 .45624 Mdot
.41001 .42616 Mdot
.64733 .72954 Mdot
.6179 .66377 Mdot
.76794 .48011 Mdot
.56985 .37143 Mdot
.66948 .55451 Mdot
.56485 .23018 Mdot
.3375 .47724 Mdot
.36845 .31924 Mdot
.28823 .4511 Mdot
.56038 .23615 Mdot
.27949 .55956 Mdot
.33737 .43247 Mdot
.41867 .40362 Mdot
.571 .24269 Mdot
.58716 .63438 Mdot
.41524 .70967 Mdot
.39947 .51444 Mdot
.58972 .38463 Mdot
.29505 .5542 Mdot
.57574 .22535 Mdot
.40918 .70483 Mdot
.34857 .60773 Mdot
.41549 .69479 Mdot
.60825 .66146 Mdot
.77336 .47148 Mdot
.55103 .25321 Mdot
.42042 .71858 Mdot
.7196 .51592 Mdot
.6494 .71716 Mdot
.30206 .43124 Mdot
.58264 .63687 Mdot
.44085 .76815 Mdot
.43801 .74486 Mdot
.44008 .7563 Mdot
.26987 .54324 Mdot
.34634 .48511 Mdot
.59781 .39905 Mdot
.63335 .71207 Mdot
.70805 .5234 Mdot
.40155 .32359 Mdot
.36014 .61743 Mdot
.37275 .4635 Mdot
.37023 .45705 Mdot
.38471 .43188 Mdot
.41194 .41797 Mdot
.57959 .40942 Mdot
.36201 .40979 Mdot
.41358 .40699 Mdot
.596 .62789 Mdot
.7647 .48079 Mdot
.37502 .43083 Mdot
.58823 .36288 Mdot
.6255 .3847 Mdot
.57579 .30531 Mdot
.36096 .51394 Mdot
.43773 .66663 Mdot
.41399 .71485 Mdot
.67602 .50907 Mdot
.68416 .54938 Mdot
.55891 .29404 Mdot
.62367 .66084 Mdot
.41576 .69112 Mdot
.80522 .45215 Mdot
.54733 .25907 Mdot
.36738 .44246 Mdot
.27039 .44986 Mdot
.27894 .46391 Mdot
.2945 .43441 Mdot
.35959 .43359 Mdot
.60316 .36165 Mdot
.67023 .51373 Mdot
.294 .42666 Mdot
.34689 .60463 Mdot
.58007 .24565 Mdot
.57514 .28381 Mdot
.44254 .70292 Mdot
.38569 .39567 Mdot
.59822 .65202 Mdot
.26402 .45855 Mdot
.63669 .67031 Mdot
.47573 .77522 Mdot
.61294 .3292 Mdot
.42793 .41408 Mdot
.43565 .38032 Mdot
.34207 .43018 Mdot
.44228 .6988 Mdot
.38288 .64199 Mdot
.40779 .66337 Mdot
.62054 .6596 Mdot
.42735 .35279 Mdot
.61194 .69698 Mdot
.58597 .35293 Mdot
.43292 .73354 Mdot
.2439 .43143 Mdot
.67637 .52859 Mdot
.29698 .5484 Mdot
.55487 .26248 Mdot
.27988 .43881 Mdot
.59238 .36907 Mdot
.33047 .48123 Mdot
.68401 .53162 Mdot
.3936 .64487 Mdot
.29802 .55219 Mdot
.70071 .47982 Mdot
.33427 .47112 Mdot
.57981 .32579 Mdot
.57916 .35 Mdot
.55396 .2464 Mdot
.43436 .3737 Mdot
.54838 .27415 Mdot
.60838 .66966 Mdot
.37612 .42427 Mdot
.34482 .43819 Mdot
.39117 .41934 Mdot
.37386 .4547 Mdot
.61439 .6484 Mdot
.28624 .54036 Mdot
.61025 .40207 Mdot
.57321 .36206 Mdot
.28359 .56399 Mdot
.56291 .26023 Mdot
.62374 .69672 Mdot
.76454 .48244 Mdot
.61132 .38761 Mdot
.54239 .26794 Mdot
.43331 .39269 Mdot
.39124 .4081 Mdot
.57538 .3623 Mdot
.36522 .45497 Mdot
.28089 .54163 Mdot
.71195 .49855 Mdot
.29206 .55153 Mdot
.57931 .29698 Mdot
.55318 .26564 Mdot
.60518 .63742 Mdot
.41994 .71976 Mdot
.55904 .29124 Mdot
.68875 .53394 Mdot
.33919 .43764 Mdot
.41439 .43296 Mdot
.37342 .62496 Mdot
.42495 .34145 Mdot
.58014 .29352 Mdot
.35939 .45346 Mdot
.43269 .68366 Mdot
.37468 .61118 Mdot
.4018 .4017 Mdot
.28085 .54724 Mdot
.44067 .74536 Mdot
.57393 .27571 Mdot
.62509 .66099 Mdot
.29159 .34167 Mdot
.62939 .66307 Mdot
.41574 .67026 Mdot
.58202 .39308 Mdot
.40729 .72751 Mdot
.583 .39648 Mdot
.47107 .74218 Mdot
.41978 .41375 Mdot
.37478 .63031 Mdot
.61646 .38743 Mdot
.66899 .52422 Mdot
.71944 .4819 Mdot
.59853 .36287 Mdot
.42997 .73101 Mdot
.59924 .39513 Mdot
.55767 .28197 Mdot
.66199 .72145 Mdot
.43598 .75218 Mdot
.71136 .48533 Mdot
.72159 .49949 Mdot
.63168 .71237 Mdot
.38623 .42592 Mdot
.3527 .42992 Mdot
.71183 .50584 Mdot
.63768 .67524 Mdot
.43421 .70851 Mdot
.39746 .42334 Mdot
.6112 .37053 Mdot
.70656 .49621 Mdot
.5819 .66521 Mdot
.39311 .63562 Mdot
.29787 .54441 Mdot
.38288 .31658 Mdot
.59735 .68293 Mdot
.3354 .44548 Mdot
.27879 .54367 Mdot
.57632 .2527 Mdot
.32962 .48408 Mdot
.41995 .3447 Mdot
.5951 .67712 Mdot
.5927 .40532 Mdot
.29375 .43365 Mdot
.67666 .49924 Mdot
.33958 .44267 Mdot
.49693 .17032 Mdot
.57727 .36019 Mdot
.37322 .44689 Mdot
.60434 .3496 Mdot
.42294 .70298 Mdot
.39556 .41904 Mdot
.65055 .71581 Mdot
.67644 .51306 Mdot
.35264 .44606 Mdot
.5343 .22878 Mdot
.63835 .70607 Mdot
.59131 .36912 Mdot
.56569 .23654 Mdot
.27673 .56871 Mdot
.34645 .31765 Mdot
.77039 .48647 Mdot
.56871 .26806 Mdot
.38552 .42388 Mdot
.6817 .53872 Mdot
.60199 .67909 Mdot
.5972 .36592 Mdot
.43266 .39368 Mdot
.61766 .69454 Mdot
.62267 .67092 Mdot
.54925 .2684 Mdot
.34928 .63093 Mdot
.42449 .39753 Mdot
.38862 .43885 Mdot
.35716 .62457 Mdot
.38056 .62437 Mdot
.35522 .43155 Mdot
.40102 .43812 Mdot
.60012 .65208 Mdot
.4344 .35338 Mdot
.33105 .48187 Mdot
.61713 .38444 Mdot
.61609 .68371 Mdot
.68601 .55031 Mdot
.72686 .49102 Mdot
.56856 .27725 Mdot
.41075 .6911 Mdot
.55061 .29283 Mdot
.68761 .50503 Mdot
.37292 .44194 Mdot
.63154 .67433 Mdot
.2844 .51416 Mdot
.63911 .71206 Mdot
.6957 .52684 Mdot
.40508 .63981 Mdot
.31298 .43259 Mdot
.49402 .16984 Mdot
.55124 .64388 Mdot
.79189 .46584 Mdot
.58064 .27417 Mdot
.34719 .60467 Mdot
.38165 .42344 Mdot
.30443 .42663 Mdot
.35355 .44405 Mdot
.5386 .27918 Mdot
.75771 .49136 Mdot
.56931 .38612 Mdot
.58647 .39791 Mdot
.34013 .47915 Mdot
.6237 .67102 Mdot
.60863 .69552 Mdot
.57613 .38221 Mdot
.61066 .66281 Mdot
.38741 .4411 Mdot
.6947 .52228 Mdot
.46869 .75631 Mdot
.39355 .4107 Mdot
.60886 .3442 Mdot
.58067 .64683 Mdot
.40425 .63493 Mdot
.69039 .54693 Mdot
.43569 .38152 Mdot
.50238 .75157 Mdot
.61352 .67519 Mdot
.36121 .51314 Mdot
.67332 .51711 Mdot
.61169 .38544 Mdot
.67698 .53996 Mdot
.3742 .44511 Mdot
.42795 .41493 Mdot
.60011 .40763 Mdot
.39399 .41207 Mdot
.38073 .6503 Mdot
.26365 .54643 Mdot
.29171 .52684 Mdot
.41331 .40504 Mdot
.4505 .73376 Mdot
.59439 .66619 Mdot
.5766 .38511 Mdot
.29272 .44057 Mdot
.39836 .4473 Mdot
.44497 .73868 Mdot
.61935 .69303 Mdot
.52126 .7375 Mdot
.61847 .65596 Mdot
.66768 .52534 Mdot
.62472 .66557 Mdot
.34092 .432 Mdot
.41947 .68696 Mdot
.69171 .50982 Mdot
.58888 .374 Mdot
.7321 .49937 Mdot
.36942 .41386 Mdot
.57645 .64526 Mdot
.73063 .48982 Mdot
.26502 .55503 Mdot
.41931 .68943 Mdot
.53986 .30988 Mdot
.44293 .67347 Mdot
.3746 .44263 Mdot
.35411 .4419 Mdot
.59486 .35134 Mdot
.60826 .64029 Mdot
.38836 .63012 Mdot
.78483 .46374 Mdot
.57722 .30172 Mdot
.40876 .68015 Mdot
.56102 .30178 Mdot
.26574 .44743 Mdot
.40433 .66492 Mdot
.25094 .46009 Mdot
.59742 .64084 Mdot
.42589 .73024 Mdot
.56682 .21175 Mdot
.27093 .57427 Mdot
.56133 .26932 Mdot
.68881 .54497 Mdot
.25314 .44657 Mdot
.71357 .48989 Mdot
.64958 .72341 Mdot
.77775 .47368 Mdot
.61074 .67583 Mdot
.53381 .23133 Mdot
.26279 .54158 Mdot
.58996 .66612 Mdot
.6543 .71591 Mdot
.6928 .49862 Mdot
.57656 .37368 Mdot
.28878 .54612 Mdot
.59075 .41451 Mdot
.57396 .38836 Mdot
.6054 .69249 Mdot
.42352 .73167 Mdot
.41425 .72885 Mdot
.6206 .37092 Mdot
.42102 .72798 Mdot
.70329 .50638 Mdot
.27025 .45313 Mdot
.31643 .41818 Mdot
.59263 .66302 Mdot
.27875 .56924 Mdot
.32734 .45748 Mdot
.75857 .49423 Mdot
.69786 .51619 Mdot
.62214 .66485 Mdot
.45389 .76832 Mdot
.58185 .39929 Mdot
.39559 .63683 Mdot
.4297 .71097 Mdot
.42489 .70912 Mdot
.41635 .74641 Mdot
.42664 .34932 Mdot
.61991 .68393 Mdot
.43041 .72768 Mdot
.40597 .43728 Mdot
.41213 .42653 Mdot
.60988 .38968 Mdot
.5391 .26218 Mdot
.28427 .54725 Mdot
.59611 .39968 Mdot
.38704 .4049 Mdot
.67343 .52639 Mdot
.54477 .23725 Mdot
.58887 .40807 Mdot
.66934 .51735 Mdot
.66748 .51846 Mdot
.58156 .40626 Mdot
.54438 .24031 Mdot
.38037 .64887 Mdot
.26615 .57548 Mdot
.45151 .73355 Mdot
.73186 .48234 Mdot
.65427 .72868 Mdot
.37325 .62699 Mdot
.34894 .44673 Mdot
.60374 .35329 Mdot
.68429 .52902 Mdot
.43368 .75385 Mdot
.40427 .4228 Mdot
.59112 .39072 Mdot
.56077 .2763 Mdot
.58669 .37234 Mdot
.60163 .35879 Mdot
.44081 .70876 Mdot
.69044 .69653 Mdot
.41048 .64553 Mdot
.69934 .48246 Mdot
.59509 .37404 Mdot
.31642 .598 Mdot
.75367 .48588 Mdot
.66263 .7202 Mdot
.2618 .54969 Mdot
.41039 .40111 Mdot
.67768 .50742 Mdot
.43829 .73417 Mdot
.58803 .62909 Mdot
.26176 .46559 Mdot
.42108 .72014 Mdot
.57196 .39975 Mdot
.59909 .36003 Mdot
.7058 .49511 Mdot
.41946 .67526 Mdot
.27849 .54461 Mdot
.426 .72071 Mdot
.62601 .70565 Mdot
.35689 .45492 Mdot
.49702 .75552 Mdot
.58993 .39618 Mdot
.41301 .72051 Mdot
.70492 .52526 Mdot
.55261 .28494 Mdot
.36561 .45219 Mdot
.5004 .76276 Mdot
.38698 .42024 Mdot
.62757 .7093 Mdot
.62567 .3677 Mdot
.28131 .57512 Mdot
.36356 .43473 Mdot
.30097 .43499 Mdot
.64211 .70639 Mdot
.3657 .42996 Mdot
.30313 .4425 Mdot
.34281 .60561 Mdot
.40336 .64901 Mdot
.37663 .43026 Mdot
.70897 .50692 Mdot
.66317 .57621 Mdot
.40248 .4332 Mdot
.69656 .48037 Mdot
.26742 .46067 Mdot
.60312 .41372 Mdot
.56226 .22011 Mdot
.3799 .32126 Mdot
.36387 .44606 Mdot
.38671 .39871 Mdot
.35743 .4558 Mdot
.33319 .41069 Mdot
.68214 .50885 Mdot
.66905 .55235 Mdot
.56077 .28505 Mdot
.33917 .48533 Mdot
.55261 .26888 Mdot
.60147 .67801 Mdot
.27443 .53376 Mdot
.57488 .35588 Mdot
.41706 .72025 Mdot
.39289 .41721 Mdot
.68882 .54211 Mdot
.37059 .4465 Mdot
.27175 .55279 Mdot
.70499 .50173 Mdot
.68014 .53024 Mdot
.65463 .54127 Mdot
.58186 .27341 Mdot
.40884 .69844 Mdot
.35868 .41609 Mdot
.57709 .23899 Mdot
.59636 .4112 Mdot
.27622 .35077 Mdot
.40782 .68243 Mdot
.40882 .70989 Mdot
.40878 .72822 Mdot
.36772 .40727 Mdot
.36326 .41064 Mdot
.61945 .70273 Mdot
.37109 .61893 Mdot
.6338 .67898 Mdot
.68449 .50114 Mdot
.67022 .50332 Mdot
.36734 .44676 Mdot
.55582 .3081 Mdot
.56204 .26182 Mdot
.72891 .49949 Mdot
.58436 .35017 Mdot
.54976 .2853 Mdot
.36993 .40842 Mdot
.70357 .49257 Mdot
.58043 .24243 Mdot
.45209 .77161 Mdot
.52611 .71797 Mdot
.55088 .28422 Mdot
.58896 .3991 Mdot
.3584 .61128 Mdot
.3951 .32298 Mdot
.55574 .29993 Mdot
.59514 .66856 Mdot
.25456 .43507 Mdot
.58185 .35157 Mdot
.54303 .2736 Mdot
.41234 .32556 Mdot
.69397 .5035 Mdot
.58897 .40058 Mdot
.55927 .20544 Mdot
.31282 .41781 Mdot
.54597 .27676 Mdot
.41004 .71447 Mdot
.39627 .62298 Mdot
.36074 .44047 Mdot
.26926 .56486 Mdot
.58949 .64488 Mdot
.69227 .54285 Mdot
.67834 .54981 Mdot
.3832 .63962 Mdot
.28168 .45198 Mdot
.71598 .49754 Mdot
.29621 .43967 Mdot
.54332 .25798 Mdot
.40728 .43639 Mdot
.62204 .38012 Mdot
.27549 .57643 Mdot
.57185 .21678 Mdot
.55167 .28451 Mdot
.58973 .65575 Mdot
.61883 .67374 Mdot
.60856 .64159 Mdot
.71437 .49556 Mdot
.27199 .44407 Mdot
.67002 .55055 Mdot
.34515 .62373 Mdot
.57183 .25754 Mdot
.80165 .45881 Mdot
.34296 .42791 Mdot
.38736 .40363 Mdot
.29465 .56552 Mdot
.60703 .36179 Mdot
.37406 .44385 Mdot
.61705 .69577 Mdot
.72067 .51459 Mdot
.57547 .64419 Mdot
.43128 .68726 Mdot
.34534 .62111 Mdot
.67893 .52736 Mdot
.6038 .34153 Mdot
.55711 .26114 Mdot
.36901 .30917 Mdot
.53836 .28259 Mdot
.66944 .53524 Mdot
.41564 .39724 Mdot
.43811 .75289 Mdot
.80345 .45048 Mdot
.39364 .42045 Mdot
.72398 .49765 Mdot
.7297 .51485 Mdot
.2722 .57248 Mdot
.43484 .36682 Mdot
.57542 .63431 Mdot
.28598 .44704 Mdot
.58286 .27136 Mdot
.6032 .40596 Mdot
.23475 .44241 Mdot
.68781 .50398 Mdot
.73316 .50137 Mdot
.56078 .29868 Mdot
.40422 .63561 Mdot
.42319 .74441 Mdot
.3819 .64964 Mdot
.61795 .69848 Mdot
.42064 .40698 Mdot
.70291 .49384 Mdot
.40041 .63729 Mdot
.32825 .46339 Mdot
.60315 .64846 Mdot
.73367 .49278 Mdot
.39414 .4123 Mdot
.36485 .43744 Mdot
.554 .27161 Mdot
.62582 .38387 Mdot
.61379 .39108 Mdot
.66076 .7172 Mdot
.35255 .46651 Mdot
.27865 .53281 Mdot
.40092 .40112 Mdot
.43643 .71201 Mdot
.60312 .39295 Mdot
.56293 .26494 Mdot
.34018 .44831 Mdot
.30721 .42954 Mdot
.43752 .74333 Mdot
.59707 .64353 Mdot
.59271 .37875 Mdot
.34678 .47522 Mdot
.39078 .41475 Mdot
.35695 .44595 Mdot
.26985 .54338 Mdot
.35648 .41359 Mdot
.75084 .49371 Mdot
.41948 .65725 Mdot
.57315 .23613 Mdot
.41886 .70104 Mdot
.78036 .46666 Mdot
.26327 .54518 Mdot
.26642 .43766 Mdot
.44455 .72042 Mdot
.41542 .68532 Mdot
.62834 .70834 Mdot
.61772 .68097 Mdot
.58619 .32699 Mdot
.38554 .44735 Mdot
.58059 .35666 Mdot
.4299 .72135 Mdot
.68948 .54466 Mdot
.55172 .2688 Mdot
.79407 .46412 Mdot
.40343 .4051 Mdot
.6939 .49913 Mdot
.60084 .37011 Mdot
.43691 .69687 Mdot
.67431 .52241 Mdot
.61175 .3843 Mdot
.57519 .27684 Mdot
.26897 .43042 Mdot
.586 .32846 Mdot
.58254 .39078 Mdot
.38547 .44831 Mdot
.30146 .53205 Mdot
.27285 .56707 Mdot
.61732 .38655 Mdot
.70533 .53536 Mdot
.58586 .38921 Mdot
.39017 .62279 Mdot
.27028 .56971 Mdot
.70725 .52663 Mdot
.3718 .62281 Mdot
.2621 .55024 Mdot
.58184 .39506 Mdot
.40652 .68405 Mdot
.77219 .46895 Mdot
.44428 .75902 Mdot
.40317 .33079 Mdot
.40697 .42625 Mdot
.71443 .48976 Mdot
.56094 .27136 Mdot
.61948 .70679 Mdot
.59291 .67935 Mdot
.65208 .71441 Mdot
.69303 .49113 Mdot
.39451 .41531 Mdot
.42739 .72829 Mdot
.61329 .67319 Mdot
.38562 .62986 Mdot
.68946 .53559 Mdot
.70157 .51651 Mdot
.29462 .56422 Mdot
.55193 .26677 Mdot
.34667 .42382 Mdot
.68802 .54526 Mdot
.77268 .47487 Mdot
.3423 .60117 Mdot
.58149 .24423 Mdot
.27388 .53775 Mdot
.61872 .39047 Mdot
.33206 .45785 Mdot
.35085 .61116 Mdot
.59409 .35726 Mdot
.43145 .6883 Mdot
.36559 .42293 Mdot
.70812 .67013 Mdot
.75436 .48529 Mdot
.28736 .44693 Mdot
.57378 .6337 Mdot
.6235 .68025 Mdot
.67786 .51671 Mdot
.40448 .41793 Mdot
.79544 .46395 Mdot
.56827 .27881 Mdot
.29489 .57457 Mdot
.57653 .38752 Mdot
.37832 .62568 Mdot
.62972 .67234 Mdot
.5398 .22846 Mdot
.61902 .70615 Mdot
.60401 .63807 Mdot
.45833 .74523 Mdot
.36145 .44134 Mdot
.68459 .52267 Mdot
.70826 .51289 Mdot
.62143 .37603 Mdot
.795 .47281 Mdot
.41923 .74451 Mdot
.70536 .66513 Mdot
.28877 .42409 Mdot
.3801 .42025 Mdot
.57394 .4027 Mdot
.58283 .35634 Mdot
.77928 .46978 Mdot
.36431 .42959 Mdot
.40514 .65685 Mdot
.67529 .5529 Mdot
.72354 .49119 Mdot
.2667 .55854 Mdot
.61902 .67505 Mdot
.53747 .28179 Mdot
.70043 .51108 Mdot
.28807 .34452 Mdot
.36842 .44806 Mdot
.58884 .62357 Mdot
.70016 .50933 Mdot
.81853 .41926 Mdot
.68961 .72636 Mdot
.40719 .6443 Mdot
.28041 .42767 Mdot
.39385 .63941 Mdot
.54865 .27956 Mdot
.66935 .54462 Mdot
.60014 .68255 Mdot
.5926 .37303 Mdot
.66674 .58127 Mdot
.71613 .49153 Mdot
.4156 .70526 Mdot
.35791 .44194 Mdot
.35342 .51179 Mdot
.39033 .41314 Mdot
.43484 .35405 Mdot
.58165 .28681 Mdot
.59254 .67897 Mdot
.63121 .71074 Mdot
.28069 .42754 Mdot
.58126 .24666 Mdot
.6646 .53194 Mdot
.70432 .50069 Mdot
.50615 .75594 Mdot
.60156 .35927 Mdot
.66386 .5391 Mdot
.38316 .44921 Mdot
.65479 .53835 Mdot
.36101 .61953 Mdot
.62244 .67552 Mdot
.38191 .45458 Mdot
.71531 .48807 Mdot
.44798 .72237 Mdot
.27466 .44761 Mdot
.39658 .4367 Mdot
.60802 .35232 Mdot
.61498 .67805 Mdot
.34144 .6177 Mdot
.7551 .4959 Mdot
.4185 .41493 Mdot
.61079 .68744 Mdot
.52756 .259 Mdot
.67258 .58641 Mdot
.40837 .69444 Mdot
.72074 .50117 Mdot
.62677 .6655 Mdot
.60078 .3775 Mdot
.57189 .23339 Mdot
.67349 .53835 Mdot
.72786 .48724 Mdot
.27773 .55856 Mdot
.60812 .34613 Mdot
.55772 .30069 Mdot
.43306 .70799 Mdot
.59927 .65139 Mdot
.26967 .55467 Mdot
.2976 .33694 Mdot
.35935 .41434 Mdot
.60375 .63636 Mdot
.32267 .59924 Mdot
.42075 .40047 Mdot
.40843 .40456 Mdot
.35246 .50985 Mdot
.39157 .62506 Mdot
.43643 .73054 Mdot
.35295 .46861 Mdot
.28169 .54925 Mdot
.26662 .44086 Mdot
.41397 .71211 Mdot
.41467 .69946 Mdot
.27666 .43837 Mdot
.27532 .55722 Mdot
.36904 .62317 Mdot
.6136 .66886 Mdot
.62279 .68024 Mdot
.4238 .7061 Mdot
.29374 .56744 Mdot
.59407 .63584 Mdot
.38617 .63523 Mdot
.69557 .52546 Mdot
.27315 .45957 Mdot
.41841 .69353 Mdot
.25379 .45017 Mdot
.60777 .66871 Mdot
.31035 .32466 Mdot
.26801 .46103 Mdot
.38944 .39663 Mdot
.36124 .43746 Mdot
.5806 .26284 Mdot
.58907 .37017 Mdot
.58157 .40637 Mdot
.61024 .64226 Mdot
.36031 .41138 Mdot
.40817 .66326 Mdot
.36103 .41155 Mdot
.40231 .3231 Mdot
.31899 .31929 Mdot
.2687 .42339 Mdot
.41156 .69357 Mdot
.41225 .66713 Mdot
.68358 .49274 Mdot
.71165 .52607 Mdot
.29968 .44191 Mdot
.61672 .67841 Mdot
.41641 .72812 Mdot
.63344 .67914 Mdot
.68929 .50361 Mdot
.68321 .52547 Mdot
.60432 .39519 Mdot
.5895 .40124 Mdot
.68404 .51348 Mdot
.7027 .4786 Mdot
.29275 .33921 Mdot
.37343 .62326 Mdot
.32973 .60186 Mdot
.35765 .317 Mdot
.39364 .51626 Mdot
.56182 .2738 Mdot
.54581 .23522 Mdot
.61299 .69147 Mdot
.29943 .43241 Mdot
.3735 .41415 Mdot
.58172 .3832 Mdot
.60781 .67942 Mdot
.56439 .25008 Mdot
.62313 .67778 Mdot
.56933 .23376 Mdot
.706 .527 Mdot
.39941 .41362 Mdot
.39323 .39801 Mdot
.62873 .70729 Mdot
.66414 .51268 Mdot
.70479 .49099 Mdot
.56419 .27066 Mdot
.36503 .31739 Mdot
.70196 .49654 Mdot
.4177 .69193 Mdot
.45964 .77754 Mdot
.59267 .35846 Mdot
.40404 .42153 Mdot
.37714 .31953 Mdot
.26878 .56834 Mdot
.59528 .41156 Mdot
.59253 .37957 Mdot
.351 .63261 Mdot
.35048 .42947 Mdot
.51928 .74295 Mdot
.59264 .4064 Mdot
.40665 .72458 Mdot
.68395 .52062 Mdot
.59032 .4101 Mdot
.61475 .40379 Mdot
.58214 .22197 Mdot
.58255 .40968 Mdot
.4298 .74081 Mdot
.39412 .64237 Mdot
.29006 .55057 Mdot
.29234 .59785 Mdot
.55897 .24052 Mdot
.56562 .25696 Mdot
.75093 .48952 Mdot
.6481 .71239 Mdot
.34102 .50036 Mdot
.5708 .26276 Mdot
.44761 .76742 Mdot
.29661 .55684 Mdot
.28733 .56466 Mdot
.28666 .56107 Mdot
.38803 .63275 Mdot
.43211 .40389 Mdot
.7557 .49018 Mdot
.41504 .70664 Mdot
.2925 .55224 Mdot
.3802 .39674 Mdot
.40756 .67031 Mdot
.59926 .64436 Mdot
.30182 .54943 Mdot
.42505 .72713 Mdot
.25421 .46339 Mdot
.60362 .66482 Mdot
.30439 .43186 Mdot
.72124 .46222 Mdot
.81778 .40944 Mdot
.6211 .66838 Mdot
.73253 .49371 Mdot
.6957 .49674 Mdot
.71013 .49901 Mdot
.4358 .72587 Mdot
.72131 .48042 Mdot
.42066 .67421 Mdot
.79149 .46643 Mdot
.34586 .48026 Mdot
.55185 .25213 Mdot
.77344 .47614 Mdot
.42426 .70869 Mdot
.35196 .62095 Mdot
.48062 .16996 Mdot
.41826 .41806 Mdot
.59267 .67228 Mdot
.5662 .28704 Mdot
.26903 .45215 Mdot
.5766 .25275 Mdot
.67342 .51611 Mdot
.34087 .47759 Mdot
.36724 .4476 Mdot
.52474 .72423 Mdot
.55931 .27035 Mdot
.41504 .69796 Mdot
.28014 .56071 Mdot
.68177 .55444 Mdot
.56808 .27677 Mdot
.55373 .26479 Mdot
.38831 .43819 Mdot
.39237 .64157 Mdot
.67711 .50645 Mdot
.60743 .67669 Mdot
.76178 .4759 Mdot
.29252 .36454 Mdot
.34827 .43244 Mdot
.42114 .41154 Mdot
.26345 .44881 Mdot
.78521 .46687 Mdot
.6148 .66585 Mdot
.41982 .3355 Mdot
.75352 .49867 Mdot
.39417 .31935 Mdot
.44409 .70321 Mdot
.77997 .47511 Mdot
.59022 .35786 Mdot
.60972 .39095 Mdot
.39554 .42567 Mdot
.48828 .16864 Mdot
.43126 .36456 Mdot
.59211 .63959 Mdot
.58182 .36849 Mdot
.733 .47926 Mdot
.42788 .75046 Mdot
.56791 .2013 Mdot
.28275 .54537 Mdot
.6044 .67242 Mdot
.70251 .49879 Mdot
.5147 .17477 Mdot
.57948 .28019 Mdot
.29687 .44915 Mdot
.41333 .4257 Mdot
.3974 .42641 Mdot
.60799 .64588 Mdot
.58812 .63707 Mdot
.33598 .6054 Mdot
.60707 .41748 Mdot
.49153 .76418 Mdot
.642 .7146 Mdot
.52354 .17759 Mdot
.57992 .35922 Mdot
.41443 .66004 Mdot
.57248 .39775 Mdot
.58733 .64186 Mdot
.36081 .4266 Mdot
.39311 .64143 Mdot
.6021 .3693 Mdot
.44624 .68298 Mdot
.2805 .5682 Mdot
.28622 .34526 Mdot
.38376 .43293 Mdot
.41105 .72826 Mdot
.41274 .70765 Mdot
.39974 .65462 Mdot
.60496 .36852 Mdot
.39872 .40342 Mdot
.41436 .40928 Mdot
.4193 .40816 Mdot
.33499 .60013 Mdot
.39726 .41606 Mdot
.4359 .75769 Mdot
.28782 .45297 Mdot
.71313 .68011 Mdot
.39168 .39874 Mdot
.62135 .65484 Mdot
.39042 .42964 Mdot
.57285 .30587 Mdot
.28184 .43079 Mdot
.26461 .56208 Mdot
.61106 .65948 Mdot
.36694 .40388 Mdot
.55528 .32706 Mdot
.36453 .4125 Mdot
.56346 .23455 Mdot
.66933 .73178 Mdot
.4182 .33949 Mdot
.35141 .60323 Mdot
.42556 .71679 Mdot
.68388 .54141 Mdot
.59497 .62805 Mdot
.6684 .52589 Mdot
.26924 .57824 Mdot
.5708 .37196 Mdot
.80047 .45894 Mdot
.30204 .33313 Mdot
.36274 .42517 Mdot
.59351 .35174 Mdot
.40503 .66148 Mdot
.75633 .48652 Mdot
.41514 .50748 Mdot
.29559 .56346 Mdot
.55766 .29485 Mdot
.57666 .26325 Mdot
.63024 .36765 Mdot
.39704 .63614 Mdot
.36574 .63069 Mdot
.6075 .64706 Mdot
.71669 .49381 Mdot
.57695 .22654 Mdot
.43886 .77482 Mdot
.58787 .63183 Mdot
.77453 .4716 Mdot
.62963 .67434 Mdot
.39516 .40023 Mdot
.58372 .40852 Mdot
.3661 .61189 Mdot
.57797 .37969 Mdot
.33988 .43695 Mdot
.72126 .4871 Mdot
.5974 .35749 Mdot
.57839 .24475 Mdot
.62107 .65198 Mdot
.67563 .52774 Mdot
.35821 .4443 Mdot
.41156 .71046 Mdot
.23732 .47624 Mdot
.77646 .48751 Mdot
.26401 .55735 Mdot
.2634 .55536 Mdot
.37194 .61306 Mdot
.60795 .41 Mdot
.69013 .58975 Mdot
.26708 .56984 Mdot
.65205 .72222 Mdot
.55143 .30266 Mdot
.8024 .46126 Mdot
.67535 .5487 Mdot
.69379 .50751 Mdot
.35837 .42366 Mdot
.67087 .55531 Mdot
.28426 .43654 Mdot
.68549 .55187 Mdot
.66186 .73242 Mdot
.43329 .39547 Mdot
.70257 .50361 Mdot
.59073 .40598 Mdot
.37509 .45083 Mdot
.40576 .6518 Mdot
.66267 .54716 Mdot
.38918 .39662 Mdot
.71083 .47328 Mdot
.62789 .70836 Mdot
.60751 .37215 Mdot
.24828 .44124 Mdot
.60991 .66637 Mdot
.43241 .73866 Mdot
.25306 .43176 Mdot
.57123 .27244 Mdot
.41481 .66734 Mdot
.59754 .33389 Mdot
.55169 .26385 Mdot
.26136 .45446 Mdot
.42375 .69366 Mdot
.58618 .36048 Mdot
.57576 .27135 Mdot
.56087 .22265 Mdot
.69446 .50532 Mdot
.73389 .51157 Mdot
.58633 .393 Mdot
.35737 .44726 Mdot
.77762 .48092 Mdot
.62408 .66842 Mdot
.40635 .43125 Mdot
.71097 .49103 Mdot
.589 .36318 Mdot
.41072 .40976 Mdot
.28261 .5488 Mdot
.3462 .60576 Mdot
.59619 .41846 Mdot
.56299 .23942 Mdot
.39908 .64693 Mdot
.41936 .41493 Mdot
.55297 .24594 Mdot
.75796 .48007 Mdot
.38823 .44989 Mdot
.40533 .69783 Mdot
.4492 .76953 Mdot
.68979 .54521 Mdot
.59656 .64711 Mdot
.70902 .51394 Mdot
.56631 .2299 Mdot
.47797 .17006 Mdot
.59716 .40147 Mdot
.28468 .57858 Mdot
.28174 .43319 Mdot
.67852 .54498 Mdot
.40965 .69867 Mdot
.47922 .77668 Mdot
.27857 .43027 Mdot
.38915 .44899 Mdot
.40154 .42587 Mdot
.7833 .4706 Mdot
.42737 .7487 Mdot
.40323 .42361 Mdot
.54238 .24739 Mdot
.41801 .42972 Mdot
.55687 .28405 Mdot
.74774 .46719 Mdot
.61062 .39235 Mdot
.31204 .59807 Mdot
.60415 .37074 Mdot
.70492 .50696 Mdot
.25042 .46178 Mdot
.2676 .44338 Mdot
.61023 .3244 Mdot
.43143 .74166 Mdot
.45117 .72862 Mdot
.68625 .52335 Mdot
.77798 .46704 Mdot
.28383 .54311 Mdot
.28126 .55817 Mdot
.37238 .45027 Mdot
.6734 .51646 Mdot
.73134 .50547 Mdot
.57051 .38176 Mdot
.59194 .35249 Mdot
.30739 .43334 Mdot
.70052 .53107 Mdot
.39937 .41433 Mdot
.28413 .57256 Mdot
.58902 .63035 Mdot
.40162 .64416 Mdot
.58657 .65854 Mdot
.58627 .62994 Mdot
.40398 .5115 Mdot
.36718 .46338 Mdot
.61566 .69691 Mdot
.59519 .66377 Mdot
.7683 .4739 Mdot
.31328 .42201 Mdot
.54972 .27956 Mdot
.4376 .36437 Mdot
.66694 .52806 Mdot
.39098 .40644 Mdot
.41978 .7481 Mdot
.58571 .41856 Mdot
.4674 .78257 Mdot
.47945 .2981 Mdot
.28415 .5376 Mdot
.76344 .48802 Mdot
.58201 .39114 Mdot
.57644 .38098 Mdot
.39539 .32254 Mdot
.39965 .41599 Mdot
.68814 .54627 Mdot
.31298 .41824 Mdot
.64222 .71416 Mdot
.77005 .47195 Mdot
.3958 .63368 Mdot
.39125 .42654 Mdot
.43237 .69903 Mdot
.60534 .63352 Mdot
.54645 .26538 Mdot
.5814 .27285 Mdot
.36617 .41213 Mdot
.26151 .54955 Mdot
.65228 .72429 Mdot
.28489 .55293 Mdot
.27332 .55318 Mdot
.58815 .38839 Mdot
.2723 .5386 Mdot
.41895 .41956 Mdot
.42358 .39213 Mdot
.59677 .41125 Mdot
.58486 .63166 Mdot
.43357 .38463 Mdot
.58108 .39404 Mdot
.26441 .42951 Mdot
.6088 .63433 Mdot
.28526 .54961 Mdot
.61874 .65559 Mdot
.77597 .46996 Mdot
.62294 .70283 Mdot
.57375 .23728 Mdot
.77205 .47442 Mdot
.33178 .60215 Mdot
.42655 .72833 Mdot
.62036 .68256 Mdot
.57446 .27931 Mdot
.62156 .65926 Mdot
.67282 .53448 Mdot
.64339 .72019 Mdot
.37848 .61296 Mdot
.28311 .34883 Mdot
.39246 .51455 Mdot
.63721 .68402 Mdot
.71202 .52459 Mdot
.4247 .70778 Mdot
.64954 .71298 Mdot
.26123 .43336 Mdot
.57869 .28696 Mdot
.39498 .42772 Mdot
.61474 .64343 Mdot
.76935 .48055 Mdot
.35508 .61237 Mdot
.5704 .23718 Mdot
.34062 .61992 Mdot
.69188 .53902 Mdot
.42587 .41705 Mdot
.62572 .71658 Mdot
.68316 .59205 Mdot
.63078 .70876 Mdot
.32836 .4853 Mdot
.57999 .35427 Mdot
.61279 .41231 Mdot
.41655 .67464 Mdot
.59099 .34945 Mdot
.52672 .24333 Mdot
.65572 .71911 Mdot
.41676 .65433 Mdot
.69379 .48554 Mdot
.35693 .44825 Mdot
.28312 .53417 Mdot
.59576 .39816 Mdot
.41389 .72948 Mdot
.26936 .54445 Mdot
.60656 .39337 Mdot
.28675 .45379 Mdot
.39662 .64146 Mdot
.66274 .533 Mdot
.38251 .44893 Mdot
.60907 .69852 Mdot
.639 .70829 Mdot
.57093 .3975 Mdot
.61274 .69935 Mdot
.26568 .42928 Mdot
.42081 .69074 Mdot
.28898 .54863 Mdot
.5583 .28523 Mdot
.38402 .65327 Mdot
.58513 .41619 Mdot
.59081 .26226 Mdot
.39064 .44704 Mdot
.68449 .52384 Mdot
.66777 .58112 Mdot
.30354 .43866 Mdot
.41578 .71177 Mdot
.28841 .43526 Mdot
.27015 .5418 Mdot
.28332 .55561 Mdot
.71644 .49371 Mdot
.26663 .44996 Mdot
.39761 .41488 Mdot
.60083 .6651 Mdot
.33643 .37307 Mdot
.32987 .44479 Mdot
.54193 .25136 Mdot
.26481 .56249 Mdot
.6342 .72217 Mdot
.37458 .62259 Mdot
.68602 .52107 Mdot
.40959 .66113 Mdot
.38283 .62584 Mdot
.43347 .73274 Mdot
.43437 .77185 Mdot
.26727 .56964 Mdot
.50963 .75424 Mdot
.36151 .621 Mdot
.37719 .51779 Mdot
.42907 .75664 Mdot
.69038 .57859 Mdot
.41774 .65556 Mdot
.43228 .73933 Mdot
.46926 .75672 Mdot
.42596 .74701 Mdot
.36206 .44753 Mdot
.39081 .45149 Mdot
.27482 .42185 Mdot
.78889 .46955 Mdot
.39113 .41199 Mdot
.58678 .41255 Mdot
.56282 .29094 Mdot
.40507 .63708 Mdot
.59152 .37547 Mdot
.25773 .45319 Mdot
.58433 .34108 Mdot
.38512 .43975 Mdot
.40888 .41368 Mdot
.28618 .55932 Mdot
.32913 .3136 Mdot
.79192 .46914 Mdot
.40581 .71759 Mdot
.33375 .43808 Mdot
.67232 .58671 Mdot
.38687 .44577 Mdot
.29016 .43386 Mdot
.42163 .3946 Mdot
.68453 .52275 Mdot
.38432 .62391 Mdot
.57447 .39107 Mdot
.38167 .64735 Mdot
.38481 .42448 Mdot
.56383 .3788 Mdot
.54182 .27795 Mdot
.40559 .41893 Mdot
.39959 .66352 Mdot
.26934 .54347 Mdot
.43949 .73594 Mdot
.42192 .68741 Mdot
.39066 .44845 Mdot
.39979 .63475 Mdot
.43734 .72867 Mdot
.28127 .55726 Mdot
.76507 .48718 Mdot
.66215 .72029 Mdot
.37925 .44417 Mdot
.57078 .23876 Mdot
.36168 .43198 Mdot
.54644 .27509 Mdot
.58675 .41058 Mdot
.58397 .38981 Mdot
.43402 .37296 Mdot
.72686 .50686 Mdot
.55269 .2961 Mdot
.78838 .47134 Mdot
.25802 .57754 Mdot
.45453 .73881 Mdot
.64347 .71616 Mdot
.73268 .51316 Mdot
.58498 .38851 Mdot
.42486 .35258 Mdot
.29753 .36518 Mdot
.61313 .69758 Mdot
.44025 .70164 Mdot
.43404 .38395 Mdot
.59578 .35038 Mdot
.66209 .5315 Mdot
.70668 .51349 Mdot
.65556 .72031 Mdot
.46876 .75455 Mdot
.38523 .40153 Mdot
.59666 .35142 Mdot
.29089 .52505 Mdot
.58947 .36911 Mdot
.57321 .39258 Mdot
.73435 .48815 Mdot
.40429 .40828 Mdot
.25911 .45709 Mdot
.68798 .50109 Mdot
.55947 .25788 Mdot
.43176 .68954 Mdot
.56018 .23791 Mdot
.52833 .71197 Mdot
.3347 .60421 Mdot
.68171 .51233 Mdot
.61264 .37862 Mdot
.38671 .41088 Mdot
.38801 .62974 Mdot
.39406 .65039 Mdot
.40628 .64898 Mdot
.56154 .28722 Mdot
.67928 .55044 Mdot
.78194 .4633 Mdot
.36053 .44318 Mdot
.41451 .68568 Mdot
.58437 .22777 Mdot
.36556 .43649 Mdot
.61842 .67858 Mdot
.26735 .54798 Mdot
.41675 .69479 Mdot
.28829 .57682 Mdot
.41737 .67596 Mdot
.70732 .51015 Mdot
.36736 .41374 Mdot
.363 .45034 Mdot
.42021 .3412 Mdot
.56524 .24959 Mdot
.43737 .7469 Mdot
.35893 .46495 Mdot
.3321 .4577 Mdot
.38859 .32168 Mdot
.40945 .41749 Mdot
.38847 .51516 Mdot
.60879 .34922 Mdot
.60206 .40018 Mdot
.27524 .43274 Mdot
.39596 .43593 Mdot
.39842 .66319 Mdot
.35688 .60947 Mdot
.33347 .59828 Mdot
.60063 .63507 Mdot
.41608 .65131 Mdot
.68165 .50513 Mdot
.6611 .54489 Mdot
.67006 .50458 Mdot
.5723 .22754 Mdot
.28614 .5469 Mdot
.37156 .4137 Mdot
.59361 .63911 Mdot
.57264 .27029 Mdot
.41145 .6825 Mdot
.54959 .26894 Mdot
.29191 .4435 Mdot
.57605 .24351 Mdot
.56941 .37555 Mdot
.68739 .72798 Mdot
.28393 .57235 Mdot
.55614 .25265 Mdot
.40091 .64657 Mdot
.43 .36169 Mdot
.43605 .39191 Mdot
.34969 .61939 Mdot
.55593 .29492 Mdot
.75831 .47938 Mdot
.39359 .4448 Mdot
.34268 .48722 Mdot
.61355 .64691 Mdot
.57208 .23415 Mdot
.63054 .67954 Mdot
.27256 .54632 Mdot
.45047 .72465 Mdot
.41918 .71055 Mdot
.64322 .71147 Mdot
.28974 .43452 Mdot
.57364 .23459 Mdot
.68621 .51022 Mdot
.30827 .42108 Mdot
.79579 .46601 Mdot
.58624 .33523 Mdot
.40119 .32692 Mdot
.75363 .49199 Mdot
.35945 .40913 Mdot
.62781 .70173 Mdot
.34359 .42829 Mdot
.2808 .57658 Mdot
.33704 .4588 Mdot
.69305 .49514 Mdot
.69413 .50796 Mdot
.7975 .46051 Mdot
.34898 .42988 Mdot
.40341 .39295 Mdot
.3798 .62754 Mdot
.68237 .54917 Mdot
.43348 .72595 Mdot
.41092 .72554 Mdot
.73219 .49251 Mdot
.44258 .73173 Mdot
.55284 .26547 Mdot
.33796 .47281 Mdot
.62741 .70167 Mdot
.63441 .71153 Mdot
.68236 .51401 Mdot
.73179 .48477 Mdot
.68312 .52494 Mdot
.27127 .54476 Mdot
.42611 .69782 Mdot
.41694 .4368 Mdot
.38577 .43604 Mdot
.37067 .40403 Mdot
.39312 .63112 Mdot
.27305 .43021 Mdot
.45405 .44632 Mdot
.55514 .29056 Mdot
.70208 .51025 Mdot
.62982 .66636 Mdot
.2423 .48163 Mdot
.59667 .65486 Mdot
.41018 .43721 Mdot
.65994 .72538 Mdot
.43912 .69891 Mdot
.57856 .25578 Mdot
.27047 .56658 Mdot
.58086 .25168 Mdot
.58916 .63059 Mdot
.38577 .64039 Mdot
.27357 .45324 Mdot
.43003 .40886 Mdot
.27624 .44403 Mdot
.70641 .41492 Mdot
.39568 .65717 Mdot
.60234 .65822 Mdot
.27802 .57044 Mdot
.59038 .3375 Mdot
.2808 .52059 Mdot
.35962 .42356 Mdot
.3359 .43614 Mdot
.33445 .49239 Mdot
.38194 .4551 Mdot
.40699 .64328 Mdot
.29147 .43917 Mdot
.6108 .36844 Mdot
.36303 .45359 Mdot
.51681 .7395 Mdot
.38078 .42318 Mdot
.39085 .39765 Mdot
.38208 .40817 Mdot
.32641 .45397 Mdot
.39502 .62643 Mdot
.28819 .56038 Mdot
.59587 .64889 Mdot
.33361 .47318 Mdot
.62831 .69789 Mdot
.6793 .51918 Mdot
.5908 .41946 Mdot
.38788 .62308 Mdot
.58119 .25517 Mdot
.53683 .68516 Mdot
.34352 .48565 Mdot
.67994 .4949 Mdot
.42774 .34593 Mdot
.54026 .28786 Mdot
.57798 .40046 Mdot
.57153 .22946 Mdot
.71629 .48777 Mdot
.61927 .67084 Mdot
.41686 .39791 Mdot
.43133 .72118 Mdot
.42112 .72921 Mdot
.36939 .45378 Mdot
.66442 .71579 Mdot
.63889 .70847 Mdot
.77228 .47617 Mdot
.38815 .40101 Mdot
.38058 .45513 Mdot
.43857 .7175 Mdot
.75544 .48329 Mdot
.26144 .44213 Mdot
.56664 .27146 Mdot
.39625 .44088 Mdot
.60604 .35787 Mdot
.28739 .44303 Mdot
.59612 .64052 Mdot
.59078 .3608 Mdot
.37549 .42247 Mdot
.36935 .46332 Mdot
.29812 .56778 Mdot
.62319 .38508 Mdot
.71106 .52842 Mdot
.3926 .44712 Mdot
.37855 .44729 Mdot
.39622 .64038 Mdot
.62571 .70477 Mdot
.40905 .69809 Mdot
.37682 .61233 Mdot
.58414 .38941 Mdot
.62887 .71002 Mdot
.32762 .45506 Mdot
.64019 .72523 Mdot
.26653 .54929 Mdot
.37411 .44248 Mdot
.60149 .65545 Mdot
.4238 .68726 Mdot
.49257 .7592 Mdot
.43628 .38511 Mdot
.27188 .55156 Mdot
.36332 .43134 Mdot
.76348 .47558 Mdot
.58467 .41838 Mdot
.42775 .41429 Mdot
.41807 .72945 Mdot
.36494 .43801 Mdot
.59606 .63107 Mdot
.54771 .25995 Mdot
.41747 .71637 Mdot
.76091 .49014 Mdot
.71351 .50256 Mdot
.70138 .5358 Mdot
.56998 .37349 Mdot
.27067 .54042 Mdot
.39974 .65189 Mdot
.40442 .70229 Mdot
.28149 .44114 Mdot
.70479 .5067 Mdot
.55874 .27734 Mdot
.35349 .45026 Mdot
.60434 .35454 Mdot
.60101 .68837 Mdot
.31027 .59865 Mdot
.29064 .45099 Mdot
.56083 .23102 Mdot
.31796 .36708 Mdot
.58847 .385 Mdot
.40463 .40404 Mdot
.5729 .23469 Mdot
.72933 .49066 Mdot
.30045 .55998 Mdot
.5439 .29839 Mdot
.78362 .47623 Mdot
.70675 .48484 Mdot
.6402 .7071 Mdot
.70243 .53756 Mdot
.57928 .23923 Mdot
.59309 .40538 Mdot
.42047 .724 Mdot
.40422 .41667 Mdot
.5928 .3942 Mdot
.69555 .52148 Mdot
.57532 .36396 Mdot
.40588 .39876 Mdot
.4384 .71144 Mdot
.67101 .53052 Mdot
.36904 .44557 Mdot
.26972 .57206 Mdot
.34538 .60448 Mdot
.76242 .48489 Mdot
.28708 .43642 Mdot
.55966 .20446 Mdot
.67571 .50078 Mdot
.69948 .49178 Mdot
.38435 .45199 Mdot
.57345 .29542 Mdot
.38647 .42719 Mdot
.61813 .6733 Mdot
.24493 .44317 Mdot
.62881 .70746 Mdot
.39166 .31897 Mdot
.3659 .45722 Mdot
.28577 .42643 Mdot
.45415 .72545 Mdot
.53237 .29712 Mdot
.35939 .31515 Mdot
.41506 .4084 Mdot
.4246 .75301 Mdot
.25237 .44937 Mdot
.27832 .3542 Mdot
.37997 .61998 Mdot
.54527 .26125 Mdot
.61161 .6433 Mdot
.35238 .44758 Mdot
.52105 .73478 Mdot
.5567 .28243 Mdot
.39311 .32121 Mdot
.30857 .43581 Mdot
.41304 .69891 Mdot
.37284 .41095 Mdot
.42279 .71756 Mdot
.37047 .42501 Mdot
.35007 .60497 Mdot
.65181 .71765 Mdot
.33038 .4849 Mdot
.59144 .40501 Mdot
.68246 .59181 Mdot
.39019 .5154 Mdot
.55526 .27083 Mdot
.28413 .57636 Mdot
.5839 .38249 Mdot
.62325 .6777 Mdot
.64273 .70603 Mdot
.68416 .52513 Mdot
.61282 .68311 Mdot
.41749 .66192 Mdot
.77007 .47956 Mdot
.5852 .35288 Mdot
.30025 .53985 Mdot
.58283 .25668 Mdot
.62861 .71035 Mdot
.40638 .42468 Mdot
.36065 .41265 Mdot
.7839 .47039 Mdot
.74456 .46606 Mdot
.44667 .74055 Mdot
.32983 .60347 Mdot
.38481 .63836 Mdot
.56381 .25414 Mdot
.76582 .48409 Mdot
.36866 .41924 Mdot
.39859 .40977 Mdot
.72049 .48188 Mdot
.38672 .62546 Mdot
.56827 .29257 Mdot
.61128 .4142 Mdot
.59266 .63851 Mdot
.80156 .45354 Mdot
.41839 .71851 Mdot
.80533 .45429 Mdot
.77963 .46462 Mdot
.46687 .76102 Mdot
.36276 .31605 Mdot
.61182 .66624 Mdot
.8062 .45426 Mdot
.41326 .69246 Mdot
.42232 .42477 Mdot
.58033 .37077 Mdot
.57155 .36775 Mdot
.43384 .69784 Mdot
.6741 .52062 Mdot
.57208 .29802 Mdot
.35826 .42257 Mdot
.55928 .22674 Mdot
.38425 .62568 Mdot
.69913 .53422 Mdot
.59634 .36972 Mdot
.61513 .64096 Mdot
.36386 .43491 Mdot
.56076 .28873 Mdot
.61105 .66351 Mdot
.60946 .39223 Mdot
.33803 .47735 Mdot
.25312 .43201 Mdot
.26292 .55715 Mdot
.61341 .64811 Mdot
.27253 .44015 Mdot
.39584 .4396 Mdot
.6279 .70163 Mdot
.60663 .34215 Mdot
.68618 .59023 Mdot
.24864 .43853 Mdot
.65568 .71875 Mdot
.71891 .47987 Mdot
.70493 .53566 Mdot
.72891 .5178 Mdot
.79136 .46973 Mdot
.62556 .69682 Mdot
.59634 .38448 Mdot
.79512 .45775 Mdot
.62633 .70514 Mdot
.29747 .43526 Mdot
.35298 .44741 Mdot
.31591 .41814 Mdot
.61054 .39158 Mdot
.60822 .37839 Mdot
.36907 .6166 Mdot
.28994 .56455 Mdot
.59511 .37059 Mdot
.41102 .42384 Mdot
.39766 .65384 Mdot
.60585 .66698 Mdot
.55267 .19023 Mdot
.58881 .64003 Mdot
.3015 .55468 Mdot
.6638 .51563 Mdot
.76776 .47942 Mdot
.40374 .41819 Mdot
.56503 .63515 Mdot
.52071 .17667 Mdot
.35199 .44708 Mdot
.27055 .56672 Mdot
.39524 .31972 Mdot
.36448 .45385 Mdot
.42808 .67233 Mdot
.60456 .36068 Mdot
.39803 .65305 Mdot
.60831 .66247 Mdot
.54491 .26504 Mdot
.53032 .23696 Mdot
.60975 .64254 Mdot
.38375 .42128 Mdot
.5786 .41203 Mdot
.39865 .42634 Mdot
.41938 .4049 Mdot
.33044 .46665 Mdot
.54777 .24813 Mdot
.67835 .52541 Mdot
.58151 .25387 Mdot
.4295 .74451 Mdot
.32438 .59948 Mdot
.55476 .27341 Mdot
.31127 .42159 Mdot
.25769 .44801 Mdot
.74038 .46739 Mdot
.42034 .72835 Mdot
.54772 .27839 Mdot
.61705 .64865 Mdot
.2795 .36188 Mdot
.3027 .42415 Mdot
.60616 .67452 Mdot
.40969 .40147 Mdot
.40387 .70504 Mdot
.37408 .61833 Mdot
.63776 .71812 Mdot
.40673 .6957 Mdot
.26932 .44077 Mdot
.27495 .54571 Mdot
.59533 .64005 Mdot
.34105 .32074 Mdot
.63112 .71065 Mdot
.4234 .49814 Mdot
.2689 .5564 Mdot
.41674 .71372 Mdot
.35734 .51317 Mdot
.39423 .66083 Mdot
.60678 .39039 Mdot
.33207 .46257 Mdot
.55821 .27493 Mdot
.27395 .44338 Mdot
.76193 .49183 Mdot
.44592 .70795 Mdot
.42089 .70162 Mdot
.58114 .63557 Mdot
.40815 .70541 Mdot
.44279 .71464 Mdot
.63802 .6827 Mdot
.4205 .66025 Mdot
.38492 .42345 Mdot
.2899 .59851 Mdot
.4041 .65621 Mdot
.60606 .64965 Mdot
.56685 .28257 Mdot
.40496 .64498 Mdot
.78348 .46468 Mdot
.38122 .44977 Mdot
.69237 .53302 Mdot
.56519 .30395 Mdot
.3937 .62754 Mdot
.55755 .27135 Mdot
.68903 .52654 Mdot
.53839 .27396 Mdot
.58712 .66588 Mdot
.63109 .71844 Mdot
.6163 .4002 Mdot
.65528 .72295 Mdot
.42739 .7465 Mdot
.78216 .47929 Mdot
.35358 .42255 Mdot
.38995 .40182 Mdot
.57479 .30576 Mdot
.43166 .75229 Mdot
.66751 .72428 Mdot
.59223 .37418 Mdot
.36994 .6237 Mdot
.62384 .65255 Mdot
.76779 .47704 Mdot
.25579 .45428 Mdot
.64504 .71109 Mdot
.61198 .3716 Mdot
.58665 .38529 Mdot
.40179 .42595 Mdot
.41854 .33668 Mdot
.56842 .23337 Mdot
.68888 .5772 Mdot
.29358 .54175 Mdot
.73213 .48198 Mdot
.38101 .41269 Mdot
.2932 .55074 Mdot
.41929 .41728 Mdot
.57608 .22617 Mdot
.61017 .68454 Mdot
.42468 .73028 Mdot
.54496 .27139 Mdot
.71413 .50224 Mdot
.25149 .46042 Mdot
.42789 .41733 Mdot
.27403 .4365 Mdot
.66826 .51768 Mdot
.42098 .74421 Mdot
.68697 .51503 Mdot
.62784 .70089 Mdot
.55146 .27054 Mdot
.26985 .54441 Mdot
.61114 .3906 Mdot
.67678 .54585 Mdot
.62122 .68389 Mdot
.76613 .48888 Mdot
.64028 .70454 Mdot
.58397 .38698 Mdot
.25583 .43717 Mdot
.67113 .55582 Mdot
.57584 .37576 Mdot
.36924 .62891 Mdot
.34908 .47467 Mdot
.46543 .74781 Mdot
.67194 .51834 Mdot
.60772 .3197 Mdot
.60852 .65784 Mdot
.58698 .64977 Mdot
.40542 .5126 Mdot
.48975 .16883 Mdot
.32864 .46297 Mdot
.67292 .73091 Mdot
.62692 .70206 Mdot
.61585 .65444 Mdot
.6875 .51713 Mdot
.42453 .68739 Mdot
.44791 .68618 Mdot
.66424 .52989 Mdot
.376 .32199 Mdot
.41157 .6826 Mdot
.27816 .42207 Mdot
.66842 .55166 Mdot
.28295 .5588 Mdot
.35738 .61741 Mdot
.551 .29034 Mdot
.40656 .33114 Mdot
.64276 .71172 Mdot
.35155 .4415 Mdot
.50678 .75902 Mdot
.68921 .52172 Mdot
.57424 .37065 Mdot
.57782 .63325 Mdot
.36398 .40917 Mdot
.38822 .4074 Mdot
.37804 .436 Mdot
.57472 .30446 Mdot
.36214 .61861 Mdot
.35549 .43071 Mdot
.34224 .47906 Mdot
.28343 .53266 Mdot
.73728 .50923 Mdot
.58008 .24618 Mdot
.43233 .34921 Mdot
.71023 .47575 Mdot
.3689 .62054 Mdot
.34075 .43029 Mdot
.59345 .66388 Mdot
.29063 .56262 Mdot
.59877 .64618 Mdot
.62977 .66271 Mdot
.80159 .45141 Mdot
.4161 .72957 Mdot
.28411 .53652 Mdot
.73713 .49661 Mdot
.45417 .71986 Mdot
.28968 .54462 Mdot
.32683 .60203 Mdot
.58313 .63256 Mdot
.4772 .16952 Mdot
.58703 .65386 Mdot
.57365 .36364 Mdot
.41979 .66361 Mdot
.4155 .74875 Mdot
.28674 .44236 Mdot
.43177 .7135 Mdot
.78316 .47164 Mdot
.40052 .65364 Mdot
.77807 .38497 Mdot
.39128 .64743 Mdot
.61047 .65511 Mdot
.63384 .71401 Mdot
.28799 .55308 Mdot
.38855 .41965 Mdot
.27265 .45582 Mdot
.59199 .37326 Mdot
.26012 .43469 Mdot
.68932 .50025 Mdot
.78774 .46278 Mdot
.68267 .72975 Mdot
.42576 .67086 Mdot
.62311 .68913 Mdot
.3867 .40811 Mdot
.26858 .55461 Mdot
.39132 .4513 Mdot
.64851 .71714 Mdot
.26301 .52864 Mdot
.3879 .43508 Mdot
.28649 .54847 Mdot
.66304 .5253 Mdot
.72998 .4756 Mdot
.46845 .75205 Mdot
.80067 .45232 Mdot
.41327 .41103 Mdot
.5693 .25697 Mdot
.57304 .22684 Mdot
.43376 .4011 Mdot
.66013 .56818 Mdot
.26142 .44305 Mdot
.40558 .42596 Mdot
.24933 .4599 Mdot
.66169 .53221 Mdot
.57608 .35172 Mdot
.69937 .51705 Mdot
.38108 .61698 Mdot
.58223 .40826 Mdot
.7054 .49237 Mdot
.26892 .46005 Mdot
.58972 .39199 Mdot
.6864 .5888 Mdot
.5567 .28567 Mdot
.40817 .42926 Mdot
.4249 .50259 Mdot
.6769 .552 Mdot
.61619 .66445 Mdot
.41124 .65194 Mdot
.59681 .64959 Mdot
.72248 .47646 Mdot
.38126 .31871 Mdot
.61005 .386 Mdot
.59196 .65589 Mdot
.26401 .53776 Mdot
.57186 .26081 Mdot
.58528 .65361 Mdot
.2702 .53918 Mdot
.4344 .39971 Mdot
.50691 .17258 Mdot
.37952 .40068 Mdot
.78995 .46194 Mdot
.62622 .7079 Mdot
.59739 .33562 Mdot
.40265 .41616 Mdot
.69915 .53043 Mdot
.56053 .22114 Mdot
.39695 .42942 Mdot
.75698 .49122 Mdot
.37608 .44676 Mdot
.57291 .23547 Mdot
.39549 .64186 Mdot
.24392 .44465 Mdot
.58391 .28495 Mdot
.54534 .26942 Mdot
.33387 .49059 Mdot
.38895 .45281 Mdot
.69093 .56815 Mdot
.41176 .69946 Mdot
.41663 .43068 Mdot
.57909 .30357 Mdot
.42439 .67858 Mdot
.41082 .66185 Mdot
.30099 .55929 Mdot
.59888 .62868 Mdot
.6733 .52444 Mdot
.5746 .25201 Mdot
.76559 .47326 Mdot
.35396 .44367 Mdot
.29112 .57385 Mdot
.55239 .28232 Mdot
.61495 .67695 Mdot
.27625 .53939 Mdot
.67826 .72345 Mdot
.33404 .4738 Mdot
.58344 .65042 Mdot
.33286 .44218 Mdot
.34427 .5057 Mdot
.39243 .64405 Mdot
.5105 .75157 Mdot
.65095 .71248 Mdot
.71005 .50914 Mdot
.59704 .37171 Mdot
.31647 .59914 Mdot
.56071 .28746 Mdot
.44936 .68617 Mdot
.39923 .39909 Mdot
.36994 .42055 Mdot
.3952 .64721 Mdot
.43115 .4108 Mdot
.43442 .68773 Mdot
.77545 .46773 Mdot
.48682 .16832 Mdot
.42346 .72541 Mdot
.41811 .70203 Mdot
.29089 .58598 Mdot
.6544 .53927 Mdot
.43354 .6923 Mdot
.3515 .44791 Mdot
.72878 .47614 Mdot
.62284 .3824 Mdot
.57155 .28626 Mdot
.56163 .31443 Mdot
.44261 .70599 Mdot
.31698 .4275 Mdot
.26444 .55198 Mdot
.43455 .3778 Mdot
.32413 .36791 Mdot
.62487 .69886 Mdot
.34167 .44571 Mdot
.58973 .378 Mdot
.69353 .52141 Mdot
.39394 .39388 Mdot
.4116 .42405 Mdot
.42725 .73206 Mdot
.5436 .28436 Mdot
.63139 .69099 Mdot
.57435 .38049 Mdot
.68621 .54925 Mdot
.56221 .26305 Mdot
.44313 .73143 Mdot
.39541 .51494 Mdot
.59862 .41335 Mdot
.5956 .35203 Mdot
.41249 .40537 Mdot
.39714 .44488 Mdot
.61272 .39412 Mdot
.60439 .64197 Mdot
.70923 .51125 Mdot
.57681 .39421 Mdot
.27079 .44307 Mdot
.24445 .45166 Mdot
.39739 .4066 Mdot
.40441 .66986 Mdot
.62366 .68371 Mdot
.60952 .38256 Mdot
.80335 .4591 Mdot
.3537 .45113 Mdot
.30493 .42953 Mdot
.61984 .43524 Mdot
.59299 .38083 Mdot
.44864 .68824 Mdot
.58072 .26525 Mdot
.26922 .55661 Mdot
.33771 .48113 Mdot
.26581 .42999 Mdot
.34066 .43173 Mdot
.72861 .48906 Mdot
.62537 .65851 Mdot
.61844 .37332 Mdot
.7014 .51014 Mdot
.41005 .66114 Mdot
.43458 .37651 Mdot
.41315 .73198 Mdot
.40492 .70383 Mdot
.44887 .72686 Mdot
.60298 .63476 Mdot
.31423 .59825 Mdot
.60941 .40146 Mdot
.38731 .40004 Mdot
.61481 .69393 Mdot
.43693 .6983 Mdot
.27973 .42804 Mdot
.43898 .69832 Mdot
.43547 .74926 Mdot
.261 .42969 Mdot
.28292 .54913 Mdot
.34375 .48159 Mdot
.35163 .41722 Mdot
.57933 .28688 Mdot
.40144 .69411 Mdot
.30341 .42689 Mdot
.36457 .42313 Mdot
.40629 .41229 Mdot
.28848 .55583 Mdot
.55146 .24331 Mdot
.43687 .37331 Mdot
.39885 .39984 Mdot
.42279 .33486 Mdot
.28319 .42915 Mdot
.42805 .75466 Mdot
.59147 .67702 Mdot
.3017 .55636 Mdot
.69355 .48788 Mdot
.38878 .63145 Mdot
.54885 .28841 Mdot
.43828 .68082 Mdot
.26141 .55821 Mdot
.62286 .66377 Mdot
.41673 .69495 Mdot
.67246 .53745 Mdot
.61572 .66719 Mdot
.63125 .7107 Mdot
.28739 .55959 Mdot
.71636 .50614 Mdot
.5427 .2824 Mdot
.6357 .70335 Mdot
.27689 .52046 Mdot
.61158 .65624 Mdot
.46119 .75699 Mdot
.25562 .43831 Mdot
.33808 .47993 Mdot
.59987 .3889 Mdot
.61173 .3542 Mdot
.63135 .70297 Mdot
.56676 .27389 Mdot
.27772 .53831 Mdot
.40723 .64905 Mdot
.57089 .26864 Mdot
.35638 .61379 Mdot
.76345 .47999 Mdot
.37486 .62079 Mdot
.78228 .4696 Mdot
.43368 .71475 Mdot
.40383 .32918 Mdot
.54378 .27817 Mdot
.61324 .36524 Mdot
.28969 .44704 Mdot
.59721 .36812 Mdot
.39542 .39475 Mdot
.28213 .53722 Mdot
.38379 .4247 Mdot
.67073 .50283 Mdot
.57338 .30703 Mdot
.40358 .65771 Mdot
.53833 .22659 Mdot
.60912 .67396 Mdot
.27633 .43812 Mdot
.57266 .37721 Mdot
.27103 .5517 Mdot
.43462 .69 Mdot
.43648 .73528 Mdot
.35594 .60619 Mdot
.67681 .49936 Mdot
.53057 .28577 Mdot
.39125 .40935 Mdot
.54317 .22939 Mdot
.63052 .70565 Mdot
.65588 .72442 Mdot
.68219 .53878 Mdot
.47445 .17398 Mdot
.70336 .50602 Mdot
.6251 .38423 Mdot
.436 .71815 Mdot
.56161 .24213 Mdot
.38824 .4151 Mdot
.39621 .63185 Mdot
.44763 .68479 Mdot
.56015 .31135 Mdot
.58068 .25341 Mdot
.65115 .72346 Mdot
.61599 .69756 Mdot
.58378 .35705 Mdot
.28553 .42986 Mdot
.28456 .42767 Mdot
.3614 .41394 Mdot
.622 .69525 Mdot
.27693 .54995 Mdot
.58673 .66707 Mdot
.27519 .57021 Mdot
.57808 .30641 Mdot
.70328 .48916 Mdot
.70957 .67295 Mdot
.39249 .63227 Mdot
.43403 .37431 Mdot
.45719 .74174 Mdot
.34826 .47395 Mdot
.60268 .67417 Mdot
.60779 .34257 Mdot
.68169 .5222 Mdot
.54062 .67284 Mdot
.70992 .48762 Mdot
.53426 .19865 Mdot
.32027 .41809 Mdot
.57993 .63386 Mdot
.26731 .43468 Mdot
.72919 .50012 Mdot
.36071 .40879 Mdot
.58039 .39763 Mdot
.57845 .41175 Mdot
.25882 .56363 Mdot
.33663 .60368 Mdot
.58055 .28172 Mdot
.38793 .41477 Mdot
.40066 .66195 Mdot
.39072 .41333 Mdot
.39169 .4121 Mdot
.42012 .40357 Mdot
.64391 .71609 Mdot
.2604 .43764 Mdot
.38704 .42127 Mdot
.7985 .45971 Mdot
.62142 .37869 Mdot
.67766 .55636 Mdot
.39096 .64243 Mdot
.57267 .2701 Mdot
.38362 .62769 Mdot
.26726 .45123 Mdot
.58674 .63965 Mdot
.36094 .61771 Mdot
.27792 .55713 Mdot
.44486 .70648 Mdot
.59009 .65377 Mdot
.56614 .29803 Mdot
.58745 .38049 Mdot
.46784 .78014 Mdot
.78833 .47133 Mdot
.58793 .36518 Mdot
.75853 .48718 Mdot
.35136 .41861 Mdot
.41852 .72251 Mdot
.5956 .36797 Mdot
.63192 .68208 Mdot
.73409 .48756 Mdot
.34074 .48678 Mdot
.36388 .44108 Mdot
.67289 .51285 Mdot
.59546 .39015 Mdot
.27264 .44396 Mdot
.25501 .4501 Mdot
.72918 .50077 Mdot
.61583 .63688 Mdot
.63438 .70871 Mdot
.56895 .2832 Mdot
.42773 .74997 Mdot
.43208 .73504 Mdot
.6102 .67392 Mdot
.54323 .66794 Mdot
.36374 .44657 Mdot
.36705 .44385 Mdot
.27902 .45064 Mdot
.3255 .45827 Mdot
.79657 .46846 Mdot
.5866 .36788 Mdot
.42899 .71641 Mdot
.28321 .53718 Mdot
.29675 .55541 Mdot
.38398 .41833 Mdot
.37219 .31807 Mdot
.66822 .52913 Mdot
.26769 .56049 Mdot
.57209 .23438 Mdot
.34201 .60134 Mdot
.3837 .44745 Mdot
.57927 .3062 Mdot
.43576 .73135 Mdot
.68789 .58293 Mdot
.6163 .66307 Mdot
.73199 .50161 Mdot
.73514 .49839 Mdot
.7082 .41297 Mdot
.39231 .63403 Mdot
.58853 .36529 Mdot
.78971 .4765 Mdot
.57031 .39443 Mdot
.5796 .2518 Mdot
.43264 .36033 Mdot
.78557 .47094 Mdot
.68343 .55303 Mdot
.58146 .63048 Mdot
.33806 .44599 Mdot
.39976 .43864 Mdot
.65603 .71743 Mdot
.40894 .41631 Mdot
.55287 .27629 Mdot
.60469 .68606 Mdot
.41582 .69474 Mdot
.57623 .29461 Mdot
.59376 .66652 Mdot
.43265 .73727 Mdot
.28569 .5597 Mdot
.28277 .42829 Mdot
.41038 .65598 Mdot
.44148 .72445 Mdot
.3627 .44767 Mdot
.80538 .44951 Mdot
.4279 .72601 Mdot
.41565 .65518 Mdot
.34152 .60293 Mdot
.70264 .53309 Mdot
.56561 .22053 Mdot
.59481 .63014 Mdot
.38485 .4282 Mdot
.69037 .49412 Mdot
.5687 .24308 Mdot
.42102 .69862 Mdot
.41817 .42046 Mdot
.35403 .44242 Mdot
.57125 .26029 Mdot
.5776 .23413 Mdot
.56861 .27368 Mdot
.63842 .71703 Mdot
.28085 .55876 Mdot
.42848 .68104 Mdot
.61421 .6867 Mdot
.55038 .28754 Mdot
.58282 .25008 Mdot
.55829 .33259 Mdot
.36642 .44666 Mdot
.57886 .23436 Mdot
.32289 .59917 Mdot
.27964 .46032 Mdot
.57059 .39606 Mdot
.61423 .33124 Mdot
.65606 .55925 Mdot
.63101 .37552 Mdot
.62409 .65678 Mdot
.27772 .56883 Mdot
.57151 .28864 Mdot
.58997 .39813 Mdot
.36375 .44323 Mdot
.36228 .45535 Mdot
.5684 .26018 Mdot
.38069 .31679 Mdot
.42598 .73584 Mdot
.46644 .74588 Mdot
.57275 .26511 Mdot
.71732 .51388 Mdot
.66225 .53424 Mdot
.69652 .50503 Mdot
.40313 .40615 Mdot
.26244 .4238 Mdot
.29179 .365 Mdot
.36236 .60832 Mdot
.62174 .70153 Mdot
.43767 .72745 Mdot
.34395 .61067 Mdot
.41122 .66353 Mdot
.73392 .47987 Mdot
.56642 .27436 Mdot
.40067 .66669 Mdot
.63646 .71633 Mdot
.63397 .70469 Mdot
.67656 .55349 Mdot
.70624 .50564 Mdot
.68372 .51147 Mdot
.38963 .6248 Mdot
.43618 .70432 Mdot
.25989 .43285 Mdot
.40594 .69993 Mdot
.70597 .47585 Mdot
.77659 .46745 Mdot
.67402 .55391 Mdot
.60316 .64981 Mdot
.42132 .68623 Mdot
.37653 .44755 Mdot
.33078 .49419 Mdot
.66167 .53515 Mdot
.55527 .29437 Mdot
.29191 .59778 Mdot
.49186 .16918 Mdot
.28965 .5716 Mdot
.62667 .67924 Mdot
.59686 .40047 Mdot
.37684 .4345 Mdot
.70609 .51388 Mdot
.61884 .34027 Mdot
.60337 .36084 Mdot
.28182 .4369 Mdot
.26134 .58152 Mdot
.62321 .67302 Mdot
.25278 .45093 Mdot
.58276 .39743 Mdot
.27688 .53384 Mdot
.60468 .68467 Mdot
.67644 .54714 Mdot
.73228 .51437 Mdot
.36822 .61549 Mdot
.42998 .35761 Mdot
.60433 .39917 Mdot
.3486 .42791 Mdot
.70331 .49457 Mdot
.57571 .29404 Mdot
.69351 .49968 Mdot
.43051 .75605 Mdot
.69064 .54452 Mdot
.39184 .44053 Mdot
.42846 .68234 Mdot
.63313 .70633 Mdot
.28325 .36207 Mdot
.53386 .22954 Mdot
.69184 .53821 Mdot
.61512 .37459 Mdot
.29349 .55969 Mdot
.2994 .53634 Mdot
.61202 .35441 Mdot
.40155 .43622 Mdot
.60083 .65427 Mdot
.43139 .68311 Mdot
.61575 .68107 Mdot
.56304 .21951 Mdot
.44991 .77819 Mdot
.61727 .66354 Mdot
.25785 .42441 Mdot
.57213 .29871 Mdot
.37779 .31797 Mdot
.39804 .4352 Mdot
.63175 .67617 Mdot
.26975 .43748 Mdot
.39859 .66008 Mdot
.26629 .45918 Mdot
.33685 .47417 Mdot
.60406 .66376 Mdot
.58327 .35305 Mdot
.25419 .44712 Mdot
.55913 .22296 Mdot
.62829 .69879 Mdot
.24483 .45496 Mdot
.58231 .36986 Mdot
.55761 .26233 Mdot
.57646 .30019 Mdot
.56229 .26717 Mdot
.38266 .43827 Mdot
.34805 .50752 Mdot
.5445 .27657 Mdot
.6383 .6817 Mdot
.54684 .26744 Mdot
.62562 .36652 Mdot
.66674 .72703 Mdot
.57922 .23936 Mdot
.40902 .4221 Mdot
.27588 .57019 Mdot
.27892 .56845 Mdot
.69026 .53234 Mdot
.47081 .78229 Mdot
.79474 .45965 Mdot
.37005 .41792 Mdot
.34269 .61783 Mdot
.39833 .64991 Mdot
.61637 .38955 Mdot
.33883 .47454 Mdot
.26216 .55015 Mdot
.4144 .66187 Mdot
.27859 .44848 Mdot
.37325 .62162 Mdot
.58518 .40474 Mdot
.38118 .43981 Mdot
.39134 .63795 Mdot
.44794 .72136 Mdot
.35837 .31592 Mdot
.37034 .62332 Mdot
.42848 .70461 Mdot
.62532 .70515 Mdot
.61955 .65033 Mdot
.60139 .65678 Mdot
.71046 .50351 Mdot
.41896 .70139 Mdot
.43303 .39628 Mdot
.7086 .50981 Mdot
.40806 .4008 Mdot
.60634 .66818 Mdot
.32935 .47703 Mdot
.41753 .70099 Mdot
.40224 .43033 Mdot
.29007 .4218 Mdot
.75566 .49032 Mdot
.57074 .26058 Mdot
.33216 .60424 Mdot
.73306 .51122 Mdot
.64036 .70705 Mdot
.42647 .75829 Mdot
.61918 .35769 Mdot
.27302 .53394 Mdot
.41929 .42296 Mdot
.42079 .39958 Mdot
.27462 .53362 Mdot
.32141 .41951 Mdot
.59547 .35415 Mdot
.71399 .50216 Mdot
.71931 .51821 Mdot
.3715 .45125 Mdot
.42254 .70912 Mdot
.56842 .22629 Mdot
.58306 .29887 Mdot
.54595 .30146 Mdot
.25926 .44919 Mdot
.34196 .479 Mdot
.33063 .45869 Mdot
.43329 .36991 Mdot
.68125 .53493 Mdot
.57606 .35279 Mdot
.28437 .44353 Mdot
.55457 .26775 Mdot
.42416 .4191 Mdot
.38887 .63882 Mdot
.4186 .69321 Mdot
.67212 .52025 Mdot
.60906 .6986 Mdot
.59401 .41541 Mdot
.66971 .55521 Mdot
.37311 .45096 Mdot
.29421 .54466 Mdot
.61362 .70021 Mdot
.44229 .74445 Mdot
.56072 .2585 Mdot
.70206 .51687 Mdot
.55297 .25364 Mdot
.40815 .70374 Mdot
.42182 .69961 Mdot
.3915 .4506 Mdot
.52838 .25825 Mdot
.6812 .54681 Mdot
.39743 .40775 Mdot
.67619 .50954 Mdot
.77889 .47174 Mdot
.58583 .66231 Mdot
.41808 .42929 Mdot
.44995 .69364 Mdot
.5984 .65229 Mdot
.3779 .41204 Mdot
.28474 .56517 Mdot
.27557 .54043 Mdot
.72421 .50524 Mdot
.54954 .2952 Mdot
.55397 .26096 Mdot
.44924 .77034 Mdot
.37744 .65782 Mdot
.33276 .45563 Mdot
.69944 .53488 Mdot
.26779 .52563 Mdot
.6196 .6609 Mdot
.43414 .71212 Mdot
.69348 .69318 Mdot
.60775 .65008 Mdot
.37047 .44785 Mdot
.55489 .27415 Mdot
.44047 .73856 Mdot
.57125 .39857 Mdot
.28472 .34329 Mdot
.60267 .34748 Mdot
.53039 .28317 Mdot
.57616 .37741 Mdot
.67165 .71957 Mdot
.68344 .50893 Mdot
.43591 .69392 Mdot
.62782 .68235 Mdot
.62142 .66228 Mdot
.75412 .48395 Mdot
.35344 .60609 Mdot
.46777 .75608 Mdot
.30208 .59716 Mdot
.78693 .47225 Mdot
.5625 .27649 Mdot
.27948 .45831 Mdot
.69672 .50614 Mdot
.75649 .49695 Mdot
.64879 .724 Mdot
.65626 .72416 Mdot
.42114 .6814 Mdot
.35288 .4382 Mdot
.34568 .60372 Mdot
.4018 .39737 Mdot
.43153 .35779 Mdot
.61256 .67421 Mdot
.4342 .71298 Mdot
.65395 .72968 Mdot
.38162 .45194 Mdot
.37017 .42851 Mdot
.72327 .47297 Mdot
.58915 .37331 Mdot
.73221 .46503 Mdot
.42539 .41955 Mdot
.71016 .49701 Mdot
.45293 .74277 Mdot
.59075 .40264 Mdot
.30577 .42675 Mdot
.62217 .70793 Mdot
.61011 .38416 Mdot
.58751 .40316 Mdot
.42494 .36999 Mdot
.37682 .62241 Mdot
.41064 .73343 Mdot
.57337 .2298 Mdot
.65806 .73184 Mdot
.59066 .66713 Mdot
.67673 .72295 Mdot
.37358 .44873 Mdot
.63396 .71784 Mdot
.60761 .4175 Mdot
.37765 .41111 Mdot
.28788 .54399 Mdot
.35808 .61152 Mdot
.34162 .4363 Mdot
.26536 .56639 Mdot
.60747 .65499 Mdot
.59566 .42991 Mdot
.33388 .45247 Mdot
.67233 .51649 Mdot
.42489 .68727 Mdot
.37688 .61847 Mdot
.5767 .28098 Mdot
.65228 .71706 Mdot
.48169 .16997 Mdot
.43364 .71033 Mdot
.36796 .44144 Mdot
.61715 .65703 Mdot
.5992 .40136 Mdot
.60169 .38444 Mdot
.61084 .35767 Mdot
.41761 .68782 Mdot
.59258 .40029 Mdot
.45555 .73837 Mdot
.27361 .44997 Mdot
.43583 .37488 Mdot
.60319 .63593 Mdot
.56078 .27605 Mdot
.54365 .24538 Mdot
.77106 .47344 Mdot
.29114 .43186 Mdot
.43241 .35769 Mdot
.43487 .77192 Mdot
.55696 .27784 Mdot
.38053 .42797 Mdot
.5947 .35324 Mdot
.23261 .4466 Mdot
.58342 .22533 Mdot
.5784 .36893 Mdot
.29838 .54997 Mdot
.42916 .74524 Mdot
.59448 .36438 Mdot
.41439 .69036 Mdot
.38128 .42467 Mdot
.27811 .4392 Mdot
.41839 .74558 Mdot
.48133 .77188 Mdot
.59928 .41402 Mdot
.59046 .66094 Mdot
.26737 .43943 Mdot
.41499 .41288 Mdot
.27279 .42234 Mdot
.60353 .39421 Mdot
.51268 .74152 Mdot
.68603 .49864 Mdot
.79104 .45756 Mdot
.79838 .46884 Mdot
.64706 .70896 Mdot
.67937 .7315 Mdot
.3668 .45806 Mdot
.35176 .60183 Mdot
.26868 .42273 Mdot
.59343 .64751 Mdot
.31281 .43407 Mdot
.38842 .41986 Mdot
.41002 .4047 Mdot
.67542 .5101 Mdot
.58247 .63167 Mdot
.30129 .55776 Mdot
.28106 .44388 Mdot
.55576 .2986 Mdot
.40898 .69446 Mdot
.38936 .42798 Mdot
.4328 .77017 Mdot
.72239 .50874 Mdot
.45521 .78172 Mdot
.40778 .42252 Mdot
.58875 .37367 Mdot
.6344 .72156 Mdot
.63124 .7073 Mdot
.71727 .51097 Mdot
.71278 .51624 Mdot
.41443 .41239 Mdot
.60874 .6766 Mdot
.30806 .43898 Mdot
.25636 .44752 Mdot
.59367 .392 Mdot
.57529 .2477 Mdot
.40274 .39496 Mdot
.46725 .75274 Mdot
.52699 .24289 Mdot
.39934 .40653 Mdot
.40865 .72204 Mdot
.68157 .51583 Mdot
.76142 .48116 Mdot
.43238 .72985 Mdot
.76466 .48109 Mdot
.45661 .78141 Mdot
.34921 .5066 Mdot
.57716 .24371 Mdot
.30642 .54401 Mdot
.54537 .26748 Mdot
.60903 .38613 Mdot
.36776 .44658 Mdot
.68856 .57347 Mdot
.79727 .47058 Mdot
.24209 .48128 Mdot
.61529 .67093 Mdot
.57121 .36816 Mdot
.27821 .55247 Mdot
.56487 .30536 Mdot
.69245 .52028 Mdot
.58192 .41242 Mdot
.42469 .41928 Mdot
.38845 .62977 Mdot
.29408 .573 Mdot
.57265 .39101 Mdot
.608 .38337 Mdot
.587 .41312 Mdot
.59369 .66626 Mdot
.41435 .64884 Mdot
.65112 .72432 Mdot
.7517 .4914 Mdot
.25803 .43433 Mdot
.3706 .43984 Mdot
.43723 .72507 Mdot
.37814 .40547 Mdot
.59776 .6575 Mdot
.29459 .60396 Mdot
.56671 .27792 Mdot
.58965 .40833 Mdot
.5284 .71205 Mdot
.57459 .40551 Mdot
.2854 .53491 Mdot
.29133 .53181 Mdot
.39151 .64406 Mdot
.58989 .6467 Mdot
.34026 .42879 Mdot
.71499 .52489 Mdot
.5586 .25882 Mdot
.63277 .71319 Mdot
.28868 .54048 Mdot
.40431 .43128 Mdot
.55881 .27624 Mdot
.65417 .72371 Mdot
.5369 .27566 Mdot
.62809 .69124 Mdot
.59418 .33973 Mdot
.28357 .50645 Mdot
.40012 .42782 Mdot
.58516 .37271 Mdot
.40561 .65549 Mdot
.62137 .69945 Mdot
.35842 .60895 Mdot
.5848 .40382 Mdot
.77648 .47065 Mdot
.62885 .70978 Mdot
.41783 .42725 Mdot
.43814 .68156 Mdot
.39447 .65696 Mdot
.41997 .66036 Mdot
.75067 .41027 Mdot
.78928 .46503 Mdot
.67989 .51342 Mdot
.60372 .64833 Mdot
.69064 .49286 Mdot
.57213 .29942 Mdot
.28373 .45571 Mdot
.7022 .52797 Mdot
.41023 .64277 Mdot
.71393 .48597 Mdot
.30505 .43664 Mdot
.58878 .65464 Mdot
.66496 .55118 Mdot
.3733 .40459 Mdot
.28261 .56347 Mdot
.60633 .37709 Mdot
.54413 .25638 Mdot
.27242 .44841 Mdot
.34823 .43813 Mdot
.58378 .37996 Mdot
.40284 .42841 Mdot
.5991 .66067 Mdot
.2876 .36143 Mdot
.26582 .42923 Mdot
.77234 .47514 Mdot
.46617 .77739 Mdot
.72305 .51345 Mdot
.55979 .20357 Mdot
.38731 .40426 Mdot
.39678 .4327 Mdot
.27754 .5434 Mdot
.28593 .59867 Mdot
.64075 .71493 Mdot
.25359 .43612 Mdot
.7768 .47941 Mdot
.41377 .66873 Mdot
.39754 .65314 Mdot
.43011 .36137 Mdot
.58409 .37098 Mdot
.6256 .65518 Mdot
.38607 .43985 Mdot
.56998 .38959 Mdot
.33636 .46987 Mdot
.65863 .71574 Mdot
.79088 .46317 Mdot
.75496 .49605 Mdot
.39561 .65305 Mdot
.66439 .52522 Mdot
.27589 .54419 Mdot
.59429 .39993 Mdot
.80244 .46398 Mdot
.64542 .7165 Mdot
.55778 .25778 Mdot
.4062 .40298 Mdot
.36791 .31599 Mdot
.66362 .52657 Mdot
.71435 .50702 Mdot
.3083 .43852 Mdot
.43746 .77395 Mdot
.54073 .31235 Mdot
.61336 .69073 Mdot
.38784 .63858 Mdot
.42112 .50269 Mdot
.47831 .28708 Mdot
.61598 .64843 Mdot
.29137 .54765 Mdot
.6637 .53313 Mdot
.67752 .42788 Mdot
.41297 .66351 Mdot
.55916 .25738 Mdot
.37199 .40784 Mdot
.40205 .65685 Mdot
.79173 .47153 Mdot
.42744 .67269 Mdot
.59491 .37161 Mdot
.58904 .65335 Mdot
.68692 .52677 Mdot
.58306 .63104 Mdot
.44876 .69025 Mdot
.56421 .27754 Mdot
.41925 .34281 Mdot
.27695 .5726 Mdot
.35968 .61586 Mdot
.28288 .55624 Mdot
.61435 .40666 Mdot
.28387 .56015 Mdot
.38573 .6384 Mdot
.39991 .4338 Mdot
.3317 .44677 Mdot
.75892 .48043 Mdot
.41306 .40704 Mdot
.35408 .44881 Mdot
.28825 .42173 Mdot
.39763 .40283 Mdot
.39155 .41156 Mdot
.40248 .44201 Mdot
.41726 .73691 Mdot
.33506 .46298 Mdot
.44097 .7173 Mdot
.44469 .75395 Mdot
.75265 .49104 Mdot
.57282 .30726 Mdot
.57702 .23557 Mdot
.33381 .46493 Mdot
.36901 .3168 Mdot
.34499 .60467 Mdot
.41241 .67625 Mdot
.63106 .70509 Mdot
.27478 .43002 Mdot
.53831 .30839 Mdot
.32808 .4632 Mdot
.69011 .53321 Mdot
.71591 .51672 Mdot
.38099 .39871 Mdot
.49449 .16936 Mdot
.42185 .42806 Mdot
.28704 .45106 Mdot
.38507 .43667 Mdot
.40668 .44041 Mdot
.70672 .53057 Mdot
.40397 .32866 Mdot
.26408 .55217 Mdot
.38204 .63673 Mdot
.559 .25294 Mdot
.59249 .36548 Mdot
.27801 .43929 Mdot
.40509 .51096 Mdot
.36962 .61766 Mdot
.27842 .54203 Mdot
.69508 .52496 Mdot
.42604 .70742 Mdot
.28713 .44925 Mdot
.61503 .6883 Mdot
.29317 .33738 Mdot
.45195 .77859 Mdot
.6093 .6847 Mdot
.55825 .26161 Mdot
.67269 .5417 Mdot
.37604 .4267 Mdot
.71673 .49079 Mdot
.38603 .44987 Mdot
.25675 .45546 Mdot
.57731 .2467 Mdot
.40592 .6409 Mdot
.62003 .70547 Mdot
.41934 .73471 Mdot
.46505 .75782 Mdot
.32628 .36777 Mdot
.75647 .46885 Mdot
.68703 .54654 Mdot
.53987 .23018 Mdot
.43272 .69524 Mdot
.35457 .45149 Mdot
.32066 .59841 Mdot
.41673 .7184 Mdot
.38712 .62637 Mdot
.29077 .34246 Mdot
.3906 .31416 Mdot
.40606 .43893 Mdot
.40159 .65238 Mdot
.67087 .54216 Mdot
.57761 .24238 Mdot
.36108 .45092 Mdot
.59568 .40007 Mdot
.39782 .65543 Mdot
.66693 .52513 Mdot
.40996 .33386 Mdot
.70939 .50071 Mdot
.41839 .67097 Mdot
.7251 .50861 Mdot
.58622 .66472 Mdot
.69992 .53044 Mdot
.40934 .39504 Mdot
.39131 .43685 Mdot
.38966 .64392 Mdot
.42186 .69986 Mdot
.28459 .53491 Mdot
.38691 .40075 Mdot
.43478 .69392 Mdot
.70179 .48263 Mdot
.38676 .65532 Mdot
.27662 .53834 Mdot
.35552 .44448 Mdot
.54506 .27135 Mdot
.2485 .4425 Mdot
.27963 .35543 Mdot
.26057 .43054 Mdot
.56456 .27335 Mdot
.38578 .61583 Mdot
.37961 .44369 Mdot
.39846 .32152 Mdot
.78132 .47787 Mdot
.35872 .41393 Mdot
.5953 .40568 Mdot
.26603 .54178 Mdot
.32556 .31427 Mdot
.2874 .54045 Mdot
.41717 .66054 Mdot
.42262 .67551 Mdot
.71823 .47945 Mdot
.40849 .66051 Mdot
.59645 .40316 Mdot
.62702 .65908 Mdot
.46202 .75675 Mdot
.57588 .35382 Mdot
.60951 .36903 Mdot
.6093 .4017 Mdot
.57402 .3754 Mdot
.53666 .30418 Mdot
.76781 .47108 Mdot
.60858 .37169 Mdot
.44048 .70995 Mdot
.66084 .5703 Mdot
.61413 .35075 Mdot
.62587 .65545 Mdot
.58858 .40281 Mdot
.35656 .41592 Mdot
.28199 .54117 Mdot
.42283 .75532 Mdot
.6122 .68467 Mdot
.6065 .41512 Mdot
.35569 .44985 Mdot
.39518 .65384 Mdot
.38918 .4259 Mdot
.55109 .29479 Mdot
.41638 .70029 Mdot
.70366 .51337 Mdot
.57753 .25129 Mdot
.57744 .39143 Mdot
.57185 .26891 Mdot
.69365 .49772 Mdot
.63494 .69419 Mdot
.36747 .41072 Mdot
.54096 .25633 Mdot
.57398 .30478 Mdot
.35948 .41448 Mdot
.42463 .68309 Mdot
.60299 .41551 Mdot
.35078 .44215 Mdot
.27883 .54858 Mdot
.43095 .73872 Mdot
.51285 .74996 Mdot
.37619 .42333 Mdot
.29234 .53394 Mdot
.38649 .64278 Mdot
.57043 .38704 Mdot
.70849 .50807 Mdot
.41797 .42013 Mdot
.61849 .6765 Mdot
.60909 .67295 Mdot
.79156 .47109 Mdot
.4031 .70794 Mdot
.66447 .5148 Mdot
.38199 .39632 Mdot
.5858 .40091 Mdot
.4107 .42785 Mdot
.70971 .47427 Mdot
.49016 .77232 Mdot
.44182 .73111 Mdot
.74972 .49592 Mdot
.3527 .46898 Mdot
.59929 .62892 Mdot
.76953 .47696 Mdot
.3838 .63828 Mdot
.40614 .70471 Mdot
.43267 .72756 Mdot
.57101 .23397 Mdot
.70412 .5073 Mdot
.42442 .75252 Mdot
.43117 .74914 Mdot
.27746 .53965 Mdot
.37788 .39991 Mdot
.39035 .63851 Mdot
.79148 .46802 Mdot
.55461 .25826 Mdot
.76929 .48319 Mdot
.52833 .2394 Mdot
.61577 .69568 Mdot
.30993 .42795 Mdot
.29075 .43076 Mdot
.47351 .17309 Mdot
.42617 .41484 Mdot
.38069 .43778 Mdot
.38116 .61784 Mdot
.5421 .29101 Mdot
.55842 .24237 Mdot
.43148 .69261 Mdot
.44241 .73417 Mdot
.57589 .2661 Mdot
.3366 .49701 Mdot
.3426 .31842 Mdot
.35735 .46657 Mdot
.41511 .64856 Mdot
.46142 .74364 Mdot
.60863 .66548 Mdot
.40001 .65735 Mdot
.67861 .59206 Mdot
.67054 .5529 Mdot
.69129 .53915 Mdot
.62726 .70541 Mdot
.37413 .42874 Mdot
.69339 .54306 Mdot
.26928 .56077 Mdot
.68641 .59261 Mdot
.2916 .56143 Mdot
.81077 .44798 Mdot
.38195 .40245 Mdot
.56339 .63656 Mdot
.66869 .7187 Mdot
.2773 .53579 Mdot
.35414 .5104 Mdot
.56502 .2589 Mdot
.3763 .61509 Mdot
.59478 .64557 Mdot
.34635 .60409 Mdot
.39906 .42975 Mdot
.40121 .64369 Mdot
.6129 .69749 Mdot
.50416 .75434 Mdot
.26297 .55001 Mdot
.2703 .55379 Mdot
.32168 .60246 Mdot
.4442 .70905 Mdot
.70949 .50585 Mdot
.38106 .62293 Mdot
.43069 .75399 Mdot
.28616 .56281 Mdot
.66219 .53924 Mdot
.26105 .46592 Mdot
.4092 .64462 Mdot
.56684 .22325 Mdot
.411 .70018 Mdot
.57529 .2588 Mdot
.4219 .75161 Mdot
.75198 .48782 Mdot
.38495 .41116 Mdot
.75436 .48952 Mdot
.55439 .29221 Mdot
.73198 .50455 Mdot
.59819 .66154 Mdot
.58398 .38922 Mdot
.59905 .65415 Mdot
.27742 .45718 Mdot
.35863 .60701 Mdot
.62366 .65502 Mdot
.3407 .37471 Mdot
.40148 .43423 Mdot
.42133 .75107 Mdot
.69498 .52319 Mdot
.7702 .48595 Mdot
.26661 .44946 Mdot
.42792 .69938 Mdot
.71689 .48136 Mdot
.276 .5214 Mdot
.68761 .58119 Mdot
.27048 .53746 Mdot
.69665 .69704 Mdot
.42696 .67741 Mdot
.77646 .48336 Mdot
.2899 .45012 Mdot
.44017 .7514 Mdot
.67439 .54971 Mdot
.6304 .69208 Mdot
.6184 .67569 Mdot
.42402 .40113 Mdot
.58381 .62982 Mdot
.69184 .53098 Mdot
.44803 .77931 Mdot
.42216 .74912 Mdot
.48411 .77713 Mdot
.5673 .27262 Mdot
.67029 .53203 Mdot
.59444 .39368 Mdot
.44462 .67922 Mdot
.70245 .48799 Mdot
.48382 .16869 Mdot
.80591 .38448 Mdot
.67876 .49689 Mdot
.41544 .69794 Mdot
.41973 .68964 Mdot
.29295 .57022 Mdot
.26913 .44772 Mdot
.69017 .52186 Mdot
.66856 .5829 Mdot
.34359 .48036 Mdot
.58187 .38639 Mdot
.80138 .46035 Mdot
.43248 .39775 Mdot
.28099 .55378 Mdot
.62322 .69785 Mdot
.37008 .42731 Mdot
.44423 .72881 Mdot
.42476 .42201 Mdot
.59664 .64974 Mdot
.73302 .47645 Mdot
.40048 .4296 Mdot
.55891 .26019 Mdot
.62433 .68403 Mdot
.62018 .6837 Mdot
.74055 .49538 Mdot
.40298 .70771 Mdot
.3498 .60809 Mdot
.70671 .50572 Mdot
.27828 .56143 Mdot
.58661 .38268 Mdot
.4131 .43325 Mdot
.39832 .63389 Mdot
.37067 .61194 Mdot
.67007 .5333 Mdot
.34707 .4288 Mdot
.60987 .6457 Mdot
.68689 .49024 Mdot
.29438 .55158 Mdot
.68616 .54172 Mdot
.57789 .34306 Mdot
.67603 .5556 Mdot
.45454 .73516 Mdot
.6153 .39521 Mdot
.40217 .64249 Mdot
.59942 .3592 Mdot
.7099 .41315 Mdot
.55666 .26194 Mdot
.70958 .52704 Mdot
.48533 .76875 Mdot
.7532 .49418 Mdot
.39332 .40364 Mdot
.37628 .44677 Mdot
.68969 .49755 Mdot
.56206 .27945 Mdot
.63099 .37812 Mdot
.54293 .28686 Mdot
.41745 .69572 Mdot
.26152 .55053 Mdot
.8181 .4112 Mdot
.74501 .50426 Mdot
.60471 .68912 Mdot
.37644 .634 Mdot
.60706 .36404 Mdot
.60243 .67046 Mdot
.62217 .68563 Mdot
.56578 .2867 Mdot
.75443 .49796 Mdot
.39333 .63339 Mdot
.58448 .63411 Mdot
.44146 .74947 Mdot
.40448 .32405 Mdot
.57229 .38479 Mdot
.54451 .23041 Mdot
.59282 .35334 Mdot
.2799 .44734 Mdot
.59149 .63024 Mdot
.3963 .41748 Mdot
.55899 .30261 Mdot
.6257 .70261 Mdot
.5435 .27507 Mdot
.29311 .54978 Mdot
.73393 .48012 Mdot
.35381 .63994 Mdot
.42239 .39884 Mdot
.37341 .4127 Mdot
.61907 .69998 Mdot
.36645 .5153 Mdot
.37936 .62974 Mdot
.42294 .74684 Mdot
.68376 .50922 Mdot
.28294 .34906 Mdot
.40333 .4442 Mdot
.35894 .44958 Mdot
.70597 .49075 Mdot
.58389 .36791 Mdot
.78582 .46127 Mdot
.35877 .44535 Mdot
.6061 .65663 Mdot
.2895 .54423 Mdot
.60615 .63132 Mdot
.37315 .40015 Mdot
.38399 .40889 Mdot
.26987 .55817 Mdot
.28659 .55434 Mdot
.59917 .65385 Mdot
.57711 .37234 Mdot
.58916 .41142 Mdot
.41421 .64983 Mdot
.37925 .40186 Mdot
.34724 .4797 Mdot
.38456 .43983 Mdot
.56469 .25972 Mdot
.27413 .3591 Mdot
.30751 .43492 Mdot
.25995 .43992 Mdot
.33685 .48209 Mdot
.3839 .42296 Mdot
.61302 .69554 Mdot
.42062 .68822 Mdot
.61344 .64874 Mdot
.58389 .64484 Mdot
.72076 .48518 Mdot
.5437 .27204 Mdot
.41467 .41094 Mdot
.57167 .29354 Mdot
.43403 .4087 Mdot
.57069 .21555 Mdot
.28241 .44162 Mdot
.29347 .45107 Mdot
.56498 .22677 Mdot
.39251 .44057 Mdot
.68383 .50458 Mdot
.70529 .53544 Mdot
.2782 .56887 Mdot
.39587 .39426 Mdot
.59663 .68014 Mdot
.63117 .67415 Mdot
.78609 .46411 Mdot
.71935 .52584 Mdot
.55114 .29523 Mdot
.62613 .43519 Mdot
.28533 .56016 Mdot
.42033 .40722 Mdot
.57699 .37843 Mdot
.67117 .50951 Mdot
.60312 .3633 Mdot
.7773 .46805 Mdot
.59399 .64072 Mdot
.6248 .66939 Mdot
.39091 .39782 Mdot
.52378 .17757 Mdot
.41532 .72078 Mdot
.42068 .69107 Mdot
.63206 .67115 Mdot
.72261 .51397 Mdot
.59911 .37315 Mdot
.32757 .59949 Mdot
.37769 .63371 Mdot
.57088 .30334 Mdot
.41431 .42386 Mdot
.67736 .55145 Mdot
.43932 .69919 Mdot
.55475 .29582 Mdot
.26193 .42857 Mdot
.65707 .52822 Mdot
.39691 .42364 Mdot
.28811 .5269 Mdot
.43534 .70803 Mdot
.27055 .44406 Mdot
.40773 .64232 Mdot
.61142 .673 Mdot
.58888 .63422 Mdot
.38067 .41007 Mdot
.35033 .63111 Mdot
.45246 .74085 Mdot
.58763 .63185 Mdot
.56912 .23053 Mdot
.58984 .39128 Mdot
.54382 .27476 Mdot
.67469 .51518 Mdot
.55731 .26109 Mdot
.71016 .48569 Mdot
.77012 .47792 Mdot
.39385 .63922 Mdot
.55837 .27628 Mdot
.3037 .42249 Mdot
.59599 .39805 Mdot
.5816 .2415 Mdot
.27747 .43539 Mdot
.29135 .53897 Mdot
.68125 .52676 Mdot
.5703 .29607 Mdot
.41712 .4253 Mdot
.52719 .71333 Mdot
.58726 .65155 Mdot
.59663 .6568 Mdot
.59582 .3711 Mdot
.67283 .53767 Mdot
.39316 .63024 Mdot
.33632 .47134 Mdot
.45479 .7266 Mdot
.34937 .44556 Mdot
.408 .4075 Mdot
.45481 .74275 Mdot
.3929 .62973 Mdot
.37793 .41367 Mdot
.43423 .37717 Mdot
.59125 .39674 Mdot
.61533 .6788 Mdot
.41845 .69984 Mdot
.42458 .7104 Mdot
.70748 .51611 Mdot
.39628 .65224 Mdot
.52926 .27033 Mdot
.5948 .65109 Mdot
.5733 .40279 Mdot
.60581 .64655 Mdot
.61635 .33568 Mdot
.68316 .49483 Mdot
.49815 .75468 Mdot
.40847 .73083 Mdot
.27299 .54345 Mdot
.39062 .63764 Mdot
.5686 .27501 Mdot
.40326 .65891 Mdot
.3979 .64705 Mdot
.3718 .40483 Mdot
.57543 .38228 Mdot
.60875 .37792 Mdot
.28325 .4451 Mdot
.41519 .71897 Mdot
.3841 .41654 Mdot
.2707 .43189 Mdot
.3768 .40717 Mdot
.27231 .44462 Mdot
.41372 .73533 Mdot
.40274 .51226 Mdot
.39128 .64298 Mdot
.4358 .70435 Mdot
.52756 .23974 Mdot
.60048 .39698 Mdot
.60131 .35782 Mdot
.58087 .6626 Mdot
.35257 .43945 Mdot
.762 .48164 Mdot
.27921 .55963 Mdot
.5815 .39373 Mdot
.25361 .42578 Mdot
.57867 .28966 Mdot
.38267 .45094 Mdot
.57987 .37734 Mdot
.6982 .51881 Mdot
.27317 .54425 Mdot
.3675 .44626 Mdot
.59035 .36358 Mdot
.39119 .63453 Mdot
.42821 .73404 Mdot
.37106 .62752 Mdot
.57301 .27481 Mdot
.59916 .64127 Mdot
.27956 .55704 Mdot
.68235 .50853 Mdot
.75901 .48341 Mdot
.40153 .64108 Mdot
.72676 .50044 Mdot
.62585 .67452 Mdot
.36401 .44235 Mdot
.60641 .66772 Mdot
.57883 .28174 Mdot
.41706 .70204 Mdot
.27564 .54887 Mdot
.28459 .57899 Mdot
.42274 .6757 Mdot
.5894 .39887 Mdot
.54381 .2662 Mdot
.73427 .49178 Mdot
.44039 .72962 Mdot
.59682 .64003 Mdot
.71294 .51259 Mdot
.26996 .55053 Mdot
.54739 .1974 Mdot
.37068 .42596 Mdot
.40373 .39791 Mdot
.43561 .66282 Mdot
.33908 .43243 Mdot
.75125 .49158 Mdot
.39319 .62572 Mdot
.28287 .53641 Mdot
.27042 .46037 Mdot
.58886 .24687 Mdot
.58567 .32581 Mdot
.38392 .42886 Mdot
.26965 .42218 Mdot
.32932 .45617 Mdot
.47813 .77383 Mdot
.26671 .44601 Mdot
.71167 .47636 Mdot
.54342 .22951 Mdot
.58243 .64389 Mdot
.58236 .37957 Mdot
.73394 .48501 Mdot
.43494 .38021 Mdot
.37007 .4237 Mdot
.37452 .64589 Mdot
.29255 .54451 Mdot
.62001 .65542 Mdot
.38548 .51538 Mdot
.69672 .5237 Mdot
.80609 .45942 Mdot
.38605 .39455 Mdot
.37673 .62723 Mdot
.54585 .65924 Mdot
.5776 .38386 Mdot
.59858 .35508 Mdot
.55627 .29526 Mdot
.72249 .47757 Mdot
.60641 .34972 Mdot
.60975 .64664 Mdot
.42375 .41587 Mdot
.30814 .43362 Mdot
.51923 .7408 Mdot
.4341 .68852 Mdot
.59136 .6675 Mdot
.61198 .32789 Mdot
.40174 .41376 Mdot
.41282 .72384 Mdot
.4127 .6636 Mdot
.57246 .30517 Mdot
.76852 .47324 Mdot
.78457 .47448 Mdot
.50187 .17171 Mdot
.60908 .41032 Mdot
.67357 .50705 Mdot
.61218 .36173 Mdot
.27581 .56107 Mdot
.27938 .43905 Mdot
.58366 .64944 Mdot
.39458 .40207 Mdot
.36662 .6316 Mdot
.41699 .65676 Mdot
.38721 .43728 Mdot
.55797 .25021 Mdot
.28944 .59905 Mdot
.27028 .57009 Mdot
.42882 .37602 Mdot
.67042 .54216 Mdot
.40292 .4069 Mdot
.52902 .27277 Mdot
.56933 .38602 Mdot
.34656 .42446 Mdot
.70735 .508 Mdot
.61505 .39555 Mdot
.55705 .24829 Mdot
.41994 .65865 Mdot
.58383 .37894 Mdot
.29439 .54908 Mdot
.39991 .44207 Mdot
.56789 .22998 Mdot
.27186 .55788 Mdot
.46309 .74283 Mdot
.59172 .34917 Mdot
.69592 .53595 Mdot
.43957 .74061 Mdot
.39601 .40761 Mdot
.58895 .39251 Mdot
.41263 .42352 Mdot
.46653 .76065 Mdot
.41032 .40141 Mdot
.52064 .72312 Mdot
.42557 .68943 Mdot
.61461 .66003 Mdot
.27823 .54349 Mdot
.39922 .42311 Mdot
.61492 .37142 Mdot
.60166 .37563 Mdot
.35575 .45091 Mdot
.4031 .64267 Mdot
.40447 .65453 Mdot
.37353 .62204 Mdot
.70416 .52195 Mdot
.37055 .46299 Mdot
.61321 .66459 Mdot
.57793 .3734 Mdot
.58519 .62945 Mdot
.27368 .42324 Mdot
.57324 .26849 Mdot
.51835 .73579 Mdot
.35994 .43818 Mdot
.42899 .70444 Mdot
.34598 .31995 Mdot
.40442 .68574 Mdot
.58495 .67152 Mdot
.59188 .66958 Mdot
.41865 .71518 Mdot
.38133 .43138 Mdot
.27893 .44894 Mdot
.31065 .43259 Mdot
.59263 .63118 Mdot
.58457 .40987 Mdot
.56053 .3498 Mdot
.66711 .548 Mdot
.55135 .19912 Mdot
.63081 .71192 Mdot
.66885 .72473 Mdot
.27658 .53832 Mdot
.43288 .7409 Mdot
.60243 .63633 Mdot
.61853 .68575 Mdot
.68795 .53106 Mdot
.27604 .54093 Mdot
.39767 .42645 Mdot
.59822 .40341 Mdot
.63538 .70361 Mdot
.36508 .45541 Mdot
.2846 .53399 Mdot
.78088 .4646 Mdot
.37536 .61798 Mdot
.5102 .75513 Mdot
.26893 .42438 Mdot
.35981 .61706 Mdot
.68962 .57026 Mdot
.42306 .75069 Mdot
.38645 .4158 Mdot
.598 .38343 Mdot
.72648 .503 Mdot
.36745 .43875 Mdot
.74925 .4973 Mdot
.61369 .64437 Mdot
.52667 .71923 Mdot
.29054 .42705 Mdot
.68557 .59144 Mdot
.38043 .41489 Mdot
.28001 .57438 Mdot
.5521 .26797 Mdot
.60092 .63322 Mdot
.38752 .65288 Mdot
.4196 .41582 Mdot
.7138 .50573 Mdot
.66453 .54896 Mdot
.41075 .6515 Mdot
.37303 .62973 Mdot
.4924 .76255 Mdot
.59616 .39332 Mdot
.72543 .49503 Mdot
.59001 .39369 Mdot
.42969 .37484 Mdot
.58473 .63281 Mdot
.55747 .24722 Mdot
.72569 .50737 Mdot
.63847 .71652 Mdot
.2915 .53891 Mdot
.408 .69222 Mdot
.44392 .67633 Mdot
.27154 .56582 Mdot
.72639 .48021 Mdot
.5712 .25097 Mdot
.2669 .44063 Mdot
.26313 .55847 Mdot
.57398 .24599 Mdot
.69777 .52609 Mdot
.42258 .72833 Mdot
.41673 .66492 Mdot
.41988 .68507 Mdot
.3086 .42746 Mdot
.36954 .60897 Mdot
.42772 .34915 Mdot
.33378 .4423 Mdot
.45184 .77178 Mdot
.3389 .45208 Mdot
.59623 .65465 Mdot
.43445 .70988 Mdot
.27154 .4443 Mdot
.26791 .53581 Mdot
.43661 .38788 Mdot
.35849 .42272 Mdot
.28876 .55476 Mdot
.35235 .43963 Mdot
.45785 .74387 Mdot
.37386 .61341 Mdot
.26174 .44003 Mdot
.59318 .6532 Mdot
.57003 .2636 Mdot
.43225 .75546 Mdot
.40533 .4086 Mdot
.46015 .74643 Mdot
.26994 .43592 Mdot
.52211 .71872 Mdot
.29004 .55631 Mdot
.73247 .47593 Mdot
.42228 .4211 Mdot
.67037 .55599 Mdot
.27871 .57786 Mdot
.46207 .74787 Mdot
.58969 .65782 Mdot
.27064 .57107 Mdot
.65511 .55421 Mdot
.3897 .51465 Mdot
.60052 .3859 Mdot
.55317 .26125 Mdot
.61451 .39446 Mdot
.59876 .65588 Mdot
.36297 .43155 Mdot
.39827 .44195 Mdot
.34067 .4292 Mdot
.42947 .37444 Mdot
.59863 .39803 Mdot
.57008 .22469 Mdot
.46094 .75921 Mdot
.38013 .44968 Mdot
.69696 .54118 Mdot
.42614 .74297 Mdot
.43568 .38626 Mdot
.31861 .42189 Mdot
.29717 .54253 Mdot
.41541 .71673 Mdot
.40252 .70418 Mdot
.53919 .31015 Mdot
.56044 .26962 Mdot
.38043 .407 Mdot
.55938 .22809 Mdot
.27752 .55546 Mdot
.60119 .64814 Mdot
.32914 .44718 Mdot
.6856 .49319 Mdot
.26621 .45355 Mdot
.69853 .5264 Mdot
.36932 .41352 Mdot
.41104 .69742 Mdot
.59175 .63386 Mdot
.78474 .47689 Mdot
.79738 .46567 Mdot
.42744 .34582 Mdot
.7947 .47403 Mdot
.57152 .28408 Mdot
.56802 .28232 Mdot
.5978 .63445 Mdot
.38056 .43621 Mdot
.26268 .44795 Mdot
.3006 .58248 Mdot
.35535 .43528 Mdot
.37353 .43079 Mdot
.64443 .7189 Mdot
.6289 .70762 Mdot
.72175 .51254 Mdot
.37553 .41623 Mdot
.37378 .45483 Mdot
.41445 .70642 Mdot
.54625 .29506 Mdot
.72643 .48685 Mdot
.55345 .29495 Mdot
.70675 .49546 Mdot
.32672 .31396 Mdot
.57481 .39189 Mdot
.57109 .27849 Mdot
.6284 .71295 Mdot
.42945 .70919 Mdot
.59763 .40115 Mdot
.68197 .51964 Mdot
.72677 .49731 Mdot
.43246 .40259 Mdot
.43412 .68723 Mdot
.42207 .74664 Mdot
.5745 .27005 Mdot
.63224 .67585 Mdot
.26942 .56144 Mdot
.5936 .35345 Mdot
.60248 .30746 Mdot
.71977 .50236 Mdot
.45304 .7764 Mdot
.44025 .6725 Mdot
.40905 .41388 Mdot
.42773 .73299 Mdot
.40478 .42127 Mdot
.38194 .62367 Mdot
.44362 .75333 Mdot
.37522 .3987 Mdot
.36723 .62057 Mdot
.67616 .50284 Mdot
.81655 .42847 Mdot
.27788 .53374 Mdot
.63064 .72055 Mdot
.27788 .55944 Mdot
.7918 .45898 Mdot
.3498 .31922 Mdot
.38364 .44686 Mdot
.40623 .40774 Mdot
.52057 .19432 Mdot
.33278 .46138 Mdot
.59505 .35822 Mdot
.60069 .38686 Mdot
.42375 .73294 Mdot
.61443 .39226 Mdot
.27796 .44692 Mdot
.5561 .28024 Mdot
.68277 .51038 Mdot
.39496 .32065 Mdot
.57395 .25754 Mdot
.41916 .66281 Mdot
.26464 .55229 Mdot
.446 .76795 Mdot
.68789 .54951 Mdot
.58729 .36956 Mdot
.61578 .64777 Mdot
.24616 .44415 Mdot
.70542 .51483 Mdot
.63744 .70836 Mdot
.29204 .43492 Mdot
.73117 .4733 Mdot
.59395 .65376 Mdot
.81715 .42068 Mdot
.6194 .69377 Mdot
.62886 .66294 Mdot
.29493 .44405 Mdot
.55551 .28029 Mdot
.61684 .38406 Mdot
.55994 .222 Mdot
.59481 .66707 Mdot
.79567 .45497 Mdot
.67646 .53625 Mdot
.26055 .45624 Mdot
.37546 .61163 Mdot
.5886 .40382 Mdot
.37609 .42138 Mdot
.62158 .69843 Mdot
.4334 .41068 Mdot
.61652 .3864 Mdot
.62286 .67108 Mdot
.28014 .57819 Mdot
.27437 .35613 Mdot
.59399 .38761 Mdot
.60945 .3846 Mdot
.56428 .29529 Mdot
.78197 .47195 Mdot
.41662 .7422 Mdot
.57887 .29287 Mdot
.32596 .47504 Mdot
.38466 .40232 Mdot
.59868 .65172 Mdot
.58406 .37786 Mdot
.6158 .67073 Mdot
.55012 .25751 Mdot
.57309 .2292 Mdot
.42026 .66042 Mdot
.37465 .62373 Mdot
.59157 .33804 Mdot
.33894 .48576 Mdot
.33196 .45331 Mdot
.37426 .6436 Mdot
.40591 .71439 Mdot
.35259 .50875 Mdot
.54855 .25339 Mdot
.56408 .2973 Mdot
.27919 .57554 Mdot
.26459 .43388 Mdot
.28791 .54829 Mdot
.27616 .42714 Mdot
.69537 .46451 Mdot
.27614 .54475 Mdot
.73272 .49215 Mdot
.27238 .42704 Mdot
.6601 .73112 Mdot
.28213 .57009 Mdot
.41191 .4124 Mdot
.70047 .50313 Mdot
.35537 .41804 Mdot
.66867 .525 Mdot
.38792 .41067 Mdot
.70991 .47376 Mdot
.6828 .50831 Mdot
.63027 .43654 Mdot
.31323 .36711 Mdot
.59801 .36069 Mdot
.56158 .23822 Mdot
.53971 .26036 Mdot
.41188 .33507 Mdot
.42283 .72491 Mdot
.29221 .59551 Mdot
.4101 .41175 Mdot
.68544 .53323 Mdot
.61776 .64853 Mdot
.29302 .57555 Mdot
.4108 .39715 Mdot
.27575 .56518 Mdot
.40722 .69262 Mdot
.66959 .53856 Mdot
.54849 .26732 Mdot
.73588 .50748 Mdot
.79538 .46011 Mdot
.675 .50132 Mdot
.42078 .37094 Mdot
.29789 .55354 Mdot
.52927 .27401 Mdot
.36145 .61064 Mdot
.6281 .38366 Mdot
.40659 .65941 Mdot
.58342 .38194 Mdot
.554 .2895 Mdot
.28451 .36078 Mdot
.42464 .74471 Mdot
.70545 .49112 Mdot
.397 .42276 Mdot
.57566 .37226 Mdot
.56056 .22121 Mdot
.4446 .73529 Mdot
.567 .229 Mdot
.68738 .51293 Mdot
.58932 .38681 Mdot
.37969 .46067 Mdot
.41776 .5053 Mdot
.25764 .45767 Mdot
.40105 .42035 Mdot
.57561 .26474 Mdot
.43546 .68959 Mdot
.27514 .5657 Mdot
.62751 .69878 Mdot
.27025 .44783 Mdot
.37429 .42209 Mdot
.68879 .59011 Mdot
.41014 .69325 Mdot
.56588 .27365 Mdot
.62038 .69704 Mdot
.56039 .26758 Mdot
.5993 .35711 Mdot
.3832 .62611 Mdot
.59773 .35493 Mdot
.29128 .54356 Mdot
.60681 .63957 Mdot
.4223 .746 Mdot
.77418 .46659 Mdot
.60522 .4131 Mdot
.68522 .50043 Mdot
.28164 .36204 Mdot
.40737 .64975 Mdot
.65035 .71285 Mdot
.73671 .5067 Mdot
.63592 .66607 Mdot
.25349 .44505 Mdot
.6257 .68126 Mdot
.40998 .41069 Mdot
.41506 .67883 Mdot
.59511 .62829 Mdot
.79494 .46741 Mdot
.2768 .42188 Mdot
.5808 .35169 Mdot
.39419 .43911 Mdot
.46982 .78256 Mdot
.66341 .71563 Mdot
.38704 .63875 Mdot
.63217 .71377 Mdot
.3637 .42193 Mdot
.59384 .39665 Mdot
.38076 .40039 Mdot
.59604 .6713 Mdot
.64375 .72028 Mdot
.76462 .48612 Mdot
.39522 .41949 Mdot
.56358 .26199 Mdot
.73392 .48157 Mdot
.66244 .54403 Mdot
.71475 .5188 Mdot
.38486 .6461 Mdot
.58048 .40091 Mdot
.59767 .3927 Mdot
.35655 .31752 Mdot
.61674 .67391 Mdot
.59701 .36017 Mdot
.39054 .44687 Mdot
.42546 .34906 Mdot
.4225 .68719 Mdot
.6925 .51192 Mdot
.37056 .41494 Mdot
.27296 .53505 Mdot
.5938 .36484 Mdot
.70558 .50566 Mdot
.39281 .63489 Mdot
.70433 .54383 Mdot
.36481 .43917 Mdot
.28231 .53863 Mdot
.42589 .67798 Mdot
.46823 .7447 Mdot
.33266 .46931 Mdot
.40397 .423 Mdot
.60892 .67305 Mdot
.48196 .69881 Mdot
.30787 .44495 Mdot
.40025 .5454 Mdot
.5913 .40895 Mdot
.60032 .57244 Mdot
.46361 .65322 Mdot
.29436 .5858 Mdot
.49829 .59885 Mdot
.24542 .48173 Mdot
.53362 .62162 Mdot
.69423 .45187 Mdot
.46236 .58082 Mdot
.81119 .40925 Mdot
.65518 .59736 Mdot
.30042 .53403 Mdot
.47265 .1966 Mdot
.66542 .69675 Mdot
.49842 .64899 Mdot
.66871 .62718 Mdot
.59944 .46175 Mdot
.77104 .46635 Mdot
.75476 .47343 Mdot
.68601 .44387 Mdot
.43037 .39664 Mdot
.50905 .67125 Mdot
.30244 .51248 Mdot
.64692 .65908 Mdot
.6583 .49681 Mdot
.26116 .54576 Mdot
.50243 .23779 Mdot
.62543 .5964 Mdot
.50328 .33754 Mdot
.33797 .59216 Mdot
.63916 .46497 Mdot
.29568 .50219 Mdot
.48443 .35886 Mdot
.29262 .59053 Mdot
.55336 .59091 Mdot
.61042 .60449 Mdot
.39163 .60171 Mdot
.6326 .59289 Mdot
.71879 .48955 Mdot
.43905 .69526 Mdot
.68233 .6688 Mdot
.50976 .29567 Mdot
.6537 .62385 Mdot
.49741 .59982 Mdot
.60611 .35277 Mdot
.60012 .56566 Mdot
.38728 .45628 Mdot
.39931 .69873 Mdot
.64207 .4907 Mdot
.66912 .47743 Mdot
.41812 .61972 Mdot
.64482 .53851 Mdot
.29501 .3583 Mdot
.50054 .65265 Mdot
.46747 .66204 Mdot
.60654 .45995 Mdot
.63094 .43881 Mdot
.4042 .70708 Mdot
.47608 .23952 Mdot
.54523 .44162 Mdot
.31711 .47575 Mdot
.63829 .52263 Mdot
.39426 .61606 Mdot
.35091 .6135 Mdot
.38652 .65883 Mdot
.78984 .43968 Mdot
.51918 .283 Mdot
.71765 .44396 Mdot
.55551 .44299 Mdot
.65095 .61041 Mdot
.35195 .36717 Mdot
.57644 .60848 Mdot
.7359 .43519 Mdot
.46973 .71766 Mdot
.49335 .2043 Mdot
.55036 .52374 Mdot
.52508 .22754 Mdot
.44624 .64278 Mdot
.61104 .46718 Mdot
.42277 .59087 Mdot
.61435 .5488 Mdot
.31701 .32768 Mdot
.51446 .24765 Mdot
.51134 .66869 Mdot
.55628 .40392 Mdot
.66438 .69279 Mdot
.46297 .68486 Mdot
.6582 .48758 Mdot
.57897 .41432 Mdot
.47019 .4621 Mdot
.51981 .21643 Mdot
.50725 .5924 Mdot
.48748 .28127 Mdot
.64278 .46317 Mdot
.69091 .6718 Mdot
.65878 .53779 Mdot
.6023 .62246 Mdot
.51196 .3276 Mdot
.41367 .67365 Mdot
.80373 .43539 Mdot
.48565 .6245 Mdot
.5395 .65292 Mdot
.51597 .21768 Mdot
.78392 .44593 Mdot
.60357 .53074 Mdot
.62215 .44996 Mdot
.60782 .59899 Mdot
.55846 .61356 Mdot
.65014 .69737 Mdot
.56911 .35107 Mdot
.49488 .7323 Mdot
.50153 .32424 Mdot
.76034 .45138 Mdot
.48866 .18709 Mdot
.33926 .47484 Mdot
.49724 .38268 Mdot
.42968 .64911 Mdot
.49696 .51641 Mdot
.6485 .67986 Mdot
.53051 .21774 Mdot
.25886 .55105 Mdot
.47804 .71774 Mdot
.69174 .44287 Mdot
.39534 .38783 Mdot
.5256 .70403 Mdot
.67614 .64031 Mdot
.69464 .54876 Mdot
.45669 .66402 Mdot
.52562 .26702 Mdot
.3621 .33479 Mdot
.41664 .51884 Mdot
.6499 .51968 Mdot
.31811 .46361 Mdot
.43727 .51635 Mdot
.7735 .39438 Mdot
.52417 .69241 Mdot
.4601 .47635 Mdot
.43896 .6646 Mdot
.73281 .43363 Mdot
.70271 .44901 Mdot
.49401 .69484 Mdot
.59948 .31606 Mdot
.49221 .28504 Mdot
.44821 .52014 Mdot
.603 .55242 Mdot
.29379 .51525 Mdot
.3082 .50969 Mdot
.65109 .45715 Mdot
.51049 .42073 Mdot
.54461 .3679 Mdot
.67342 .63296 Mdot
.37432 .6383 Mdot
.50923 .37586 Mdot
.36839 .56581 Mdot
.46241 .72842 Mdot
.4976 .45593 Mdot
.58158 .62105 Mdot
.49172 .43988 Mdot
.50617 .22943 Mdot
.74579 .4892 Mdot
.74169 .43776 Mdot
.65637 .62227 Mdot
.66084 .4895 Mdot
.5295 .65797 Mdot
.53067 .65931 Mdot
.52353 .34529 Mdot
.67345 .68963 Mdot
.615 .48318 Mdot
.39797 .66909 Mdot
.50712 .63266 Mdot
.35435 .58464 Mdot
.3628 .37761 Mdot
.4015 .56531 Mdot
.54531 .25751 Mdot
.47271 .40885 Mdot
.45647 .66725 Mdot
.60798 .32467 Mdot
.38347 .3771 Mdot
.28312 .4897 Mdot
.57697 .35016 Mdot
.36562 .34985 Mdot
.33001 .31579 Mdot
.57435 .53802 Mdot
.76312 .43994 Mdot
.43359 .53748 Mdot
.37293 .3482 Mdot
.64947 .6712 Mdot
.30053 .58865 Mdot
.5287 .21863 Mdot
.54403 .3268 Mdot
.48333 .67072 Mdot
.4983 .70813 Mdot
.70184 .71653 Mdot
.64864 .70909 Mdot
.78499 .39079 Mdot
.65643 .62175 Mdot
.30585 .60297 Mdot
.74824 .49367 Mdot
.60085 .49078 Mdot
.41025 .59067 Mdot
.27846 .49596 Mdot
.50696 .2553 Mdot
.58197 .55498 Mdot
.58342 .25213 Mdot
.45293 .62293 Mdot
.41089 .53512 Mdot
.49274 .25362 Mdot
.48513 .22813 Mdot
.48148 .24216 Mdot
.68141 .67553 Mdot
.47581 .39399 Mdot
.51178 .21171 Mdot
.43533 .35664 Mdot
.5555 .47806 Mdot
.29473 .58285 Mdot
.30276 .47752 Mdot
.79559 .41393 Mdot
.54669 .4311 Mdot
.56337 .60782 Mdot
.41875 .62057 Mdot
.52702 .2015 Mdot
.34742 .31144 Mdot
.62617 .57007 Mdot
.49782 .34336 Mdot
.56516 .42186 Mdot
.50032 .36455 Mdot
.53127 .3522 Mdot
.52764 .59121 Mdot
.67535 .63962 Mdot
.54219 .18539 Mdot
.71079 .43114 Mdot
.65043 .64452 Mdot
.46076 .70168 Mdot
.80137 .42164 Mdot
.51609 .70297 Mdot
.6102 .61731 Mdot
.44414 .63152 Mdot
.32446 .53763 Mdot
.44725 .55742 Mdot
.56079 .5913 Mdot
.45489 .45911 Mdot
.53375 .40375 Mdot
.73756 .50003 Mdot
.75148 .41693 Mdot
.44154 .54915 Mdot
.54863 .47393 Mdot
.38452 .34282 Mdot
.78573 .45267 Mdot
.54994 .56324 Mdot
.34077 .40406 Mdot
.43474 .53506 Mdot
.49562 .66496 Mdot
.52529 .69978 Mdot
.34588 .5568 Mdot
.34102 .45811 Mdot
.51013 .28399 Mdot
.79908 .38852 Mdot
.53149 .34371 Mdot
.50398 .68535 Mdot
.69688 .66539 Mdot
.65065 .59645 Mdot
.39901 .35899 Mdot
.2677 .47177 Mdot
.51354 .56346 Mdot
.24095 .46991 Mdot
.62557 .6499 Mdot
.35165 .61492 Mdot
.52329 .66283 Mdot
.42593 .35704 Mdot
.42045 .57702 Mdot
.5255 .64516 Mdot
.38052 .38561 Mdot
.44285 .66552 Mdot
.47307 .76068 Mdot
.73065 .43101 Mdot
.7439 .4909 Mdot
.5934 .31058 Mdot
.54089 .45104 Mdot
.5563 .30214 Mdot
.55882 .38049 Mdot
.59935 .54167 Mdot
.35088 .59346 Mdot
.70174 .66757 Mdot
.53165 .37123 Mdot
.8122 .4278 Mdot
.53332 .35212 Mdot
.71501 .44751 Mdot
.63713 .53303 Mdot
.34101 .34502 Mdot
.63729 .62064 Mdot
.66118 .6063 Mdot
.31995 .34093 Mdot
.74061 .45605 Mdot
.6133 .56401 Mdot
.39849 .70043 Mdot
.34834 .46059 Mdot
.34011 .32149 Mdot
.48203 .35894 Mdot
.3429 .35447 Mdot
.37348 .54032 Mdot
.40654 .63357 Mdot
.47781 .37202 Mdot
.63148 .57701 Mdot
.28091 .58106 Mdot
.49502 .71132 Mdot
.60089 .62585 Mdot
.45696 .69378 Mdot
.79662 .45215 Mdot
.70402 .69448 Mdot
.53373 .63543 Mdot
.39248 .36773 Mdot
.49393 .3211 Mdot
.40506 .36427 Mdot
.5005 .7139 Mdot
.32963 .53153 Mdot
.53489 .67304 Mdot
.42866 .62657 Mdot
.56519 .50809 Mdot
.57142 .62171 Mdot
.46415 .62274 Mdot
.44913 .67221 Mdot
.27519 .51924 Mdot
.52496 .31353 Mdot
.44524 .46759 Mdot
.54222 .59865 Mdot
.32696 .47108 Mdot
.48255 .52257 Mdot
.49199 .62666 Mdot
.4005 .33787 Mdot
.52022 .61453 Mdot
.47422 .25162 Mdot
.3664 .64081 Mdot
.59002 .59112 Mdot
.5178 .41209 Mdot
.42252 .35787 Mdot
.33831 .5916 Mdot
.46509 .68637 Mdot
.67277 .63271 Mdot
.45448 .44683 Mdot
.52155 .28412 Mdot
.54071 .50986 Mdot
.37546 .34515 Mdot
.46563 .49665 Mdot
.45926 .43926 Mdot
.56893 .35677 Mdot
.52799 .35028 Mdot
.60435 .57434 Mdot
.46794 .19537 Mdot
.72343 .46017 Mdot
.39311 .55913 Mdot
.423 .59341 Mdot
.74306 .43001 Mdot
.45559 .60502 Mdot
.4699 .59347 Mdot
.45227 .53141 Mdot
.78257 .42277 Mdot
.58099 .57167 Mdot
.62245 .57533 Mdot
.47632 .75894 Mdot
.5004 .2231 Mdot
.55066 .61116 Mdot
.60217 .61731 Mdot
.52709 .41307 Mdot
.41111 .3994 Mdot
.38452 .56099 Mdot
.50264 .75361 Mdot
.50107 .47867 Mdot
.54533 .6273 Mdot
.81037 .40182 Mdot
.58768 .55153 Mdot
.43192 .54309 Mdot
.47164 .19074 Mdot
.47245 .18123 Mdot
.36805 .57861 Mdot
.53703 .20845 Mdot
.63108 .57388 Mdot
.50609 .70898 Mdot
.63451 .60009 Mdot
.34803 .37676 Mdot
.37102 .63774 Mdot
.5312 .30723 Mdot
.69435 .72476 Mdot
.651 .67341 Mdot
.43221 .61167 Mdot
.52433 .25002 Mdot
.5485 .48421 Mdot
.60946 .49505 Mdot
.69039 .6562 Mdot
.76937 .46348 Mdot
.7777 .43798 Mdot
.35245 .54527 Mdot
.6578 .46912 Mdot
.66202 .43707 Mdot
.52469 .68339 Mdot
.81019 .42172 Mdot
.57169 .42042 Mdot
.29261 .59409 Mdot
.73332 .43496 Mdot
.48298 .74905 Mdot
.66252 .48086 Mdot
.49043 .62161 Mdot
.59513 .54647 Mdot
.50562 .45043 Mdot
.49984 .72589 Mdot
.67772 .66341 Mdot
.57746 .50346 Mdot
.28634 .35385 Mdot
.46227 .69385 Mdot
.4722 .72324 Mdot
.31249 .5332 Mdot
.59836 .52405 Mdot
.47133 .2277 Mdot
.58534 .66575 Mdot
.31655 .35554 Mdot
.39894 .69869 Mdot
.41366 .32692 Mdot
.61257 .48621 Mdot
.25294 .42919 Mdot
.52367 .31517 Mdot
.61599 .48699 Mdot
.4793 .22411 Mdot
.81518 .43962 Mdot
.48263 .33429 Mdot
.58501 .6038 Mdot
.55806 .36996 Mdot
.79068 .4114 Mdot
.78561 .40062 Mdot
.48139 .20907 Mdot
.67915 .43409 Mdot
.31411 .33994 Mdot
.58115 .51628 Mdot
.35261 .37872 Mdot
.40848 .37612 Mdot
.74167 .42717 Mdot
.34039 .60151 Mdot
.49038 .35927 Mdot
.4754 .64436 Mdot
.75605 .45623 Mdot
.47774 .37853 Mdot
.41554 .33139 Mdot
.48916 .48807 Mdot
.62572 .4551 Mdot
.66064 .52306 Mdot
.51479 .18487 Mdot
.49519 .6984 Mdot
.51372 .37041 Mdot
.48151 .71509 Mdot
.45237 .69371 Mdot
.68647 .45452 Mdot
.46804 .6499 Mdot
.57046 .20453 Mdot
.63395 .50089 Mdot
.55223 .32584 Mdot
.61424 .5565 Mdot
.47651 .77666 Mdot
.38078 .39264 Mdot
.5239 .33897 Mdot
.51297 .37914 Mdot
.47686 .20407 Mdot
.48713 .37865 Mdot
.47695 .41715 Mdot
.47235 .23964 Mdot
.48694 .65992 Mdot
.33605 .35769 Mdot
.49482 .24463 Mdot
.37894 .59449 Mdot
.51873 .28483 Mdot
.62936 .6888 Mdot
.59618 .4653 Mdot
.49447 .75485 Mdot
.35978 .35889 Mdot
.35341 .36051 Mdot
.53576 .37552 Mdot
.662 .69265 Mdot
.42418 .55838 Mdot
.44756 .52252 Mdot
.65983 .48871 Mdot
.34629 .37611 Mdot
.52826 .59978 Mdot
.49142 .1831 Mdot
.34072 .46134 Mdot
.69515 .4168 Mdot
.75057 .43891 Mdot
.63513 .61775 Mdot
.59214 .53223 Mdot
.48744 .75942 Mdot
.3564 .53592 Mdot
.36433 .3253 Mdot
.50132 .22655 Mdot
.59159 .53066 Mdot
.27307 .48209 Mdot
.349 .51368 Mdot
.58153 .61533 Mdot
.66571 .66408 Mdot
.50599 .60147 Mdot
.57739 .45927 Mdot
.34883 .46887 Mdot
.712 .44287 Mdot
.81272 .40671 Mdot
.47198 .22492 Mdot
.66712 .65885 Mdot
.35631 .35638 Mdot
.45615 .49585 Mdot
.56471 .43139 Mdot
.48897 .18145 Mdot
.76938 .46637 Mdot
.45604 .66765 Mdot
.74253 .45405 Mdot
.66494 .68365 Mdot
.60597 .48843 Mdot
.33429 .35007 Mdot
.47625 .24305 Mdot
.41119 .5962 Mdot
.5592 .52432 Mdot
.47892 .4804 Mdot
.24217 .44218 Mdot
.51378 .66402 Mdot
.32648 .54352 Mdot
.67472 .70457 Mdot
.47528 .20635 Mdot
.66108 .44875 Mdot
.44068 .4819 Mdot
.47335 .1997 Mdot
.39966 .62905 Mdot
.52023 .67195 Mdot
.68914 .67189 Mdot
.37675 .35037 Mdot
.65645 .53756 Mdot
.36164 .45748 Mdot
.29613 .34356 Mdot
.46523 .61819 Mdot
.50626 .39599 Mdot
.58568 .23538 Mdot
.45599 .68384 Mdot
.67349 .44394 Mdot
.45124 .68165 Mdot
.80465 .40167 Mdot
.52595 .58743 Mdot
.46236 .65623 Mdot
.33838 .52288 Mdot
.63559 .53421 Mdot
.48996 .65983 Mdot
.50242 .33933 Mdot
.30606 .47904 Mdot
.454 .64259 Mdot
.45391 .64831 Mdot
.39243 .58069 Mdot
.63334 .64045 Mdot
.50097 .31247 Mdot
.77309 .44533 Mdot
.60116 .30744 Mdot
.37452 .59351 Mdot
.35686 .36802 Mdot
.59959 .548 Mdot
.50438 .35752 Mdot
.75561 .49612 Mdot
.54837 .19037 Mdot
.31469 .57062 Mdot
.52846 .69146 Mdot
.52231 .55491 Mdot
.27665 .46918 Mdot
.34751 .36631 Mdot
.64034 .5427 Mdot
.6014 .53394 Mdot
.40955 .54789 Mdot
.43134 .66698 Mdot
.53501 .68367 Mdot
.55109 .24641 Mdot
.60455 .31875 Mdot
.65479 .63861 Mdot
.3407 .5648 Mdot
.75552 .43379 Mdot
.44332 .77377 Mdot
.60709 .3321 Mdot
.62697 .53588 Mdot
.43112 .37073 Mdot
.29522 .48101 Mdot
.53007 .18157 Mdot
.4878 .32826 Mdot
.42351 .65985 Mdot
.51867 .68618 Mdot
.64613 .48717 Mdot
.52924 .37218 Mdot
.56419 .54333 Mdot
.73498 .4267 Mdot
.47699 .44807 Mdot
.51955 .35838 Mdot
.45969 .64018 Mdot
.49928 .58543 Mdot
.74273 .44667 Mdot
.55551 .35471 Mdot
.76691 .45361 Mdot
.37409 .53199 Mdot
.55129 .44374 Mdot
.75578 .46474 Mdot
.49395 .47502 Mdot
.63405 .56842 Mdot
.2805 .58192 Mdot
.51122 .56811 Mdot
.78203 .42027 Mdot
.43731 .6803 Mdot
.59404 .45227 Mdot
.47782 .67272 Mdot
.65218 .67236 Mdot
.50038 .32598 Mdot
.51297 .68753 Mdot
.76683 .44715 Mdot
.35574 .37404 Mdot
.55058 .40876 Mdot
.34137 .58845 Mdot
.32035 .48055 Mdot
.6074 .35773 Mdot
.4284 .50988 Mdot
.58056 .41938 Mdot
.35484 .31383 Mdot
.37822 .38359 Mdot
.51034 .25568 Mdot
.33186 .3184 Mdot
.50835 .45143 Mdot
.61451 .46859 Mdot
.40005 .67319 Mdot
.5249 .2177 Mdot
.35836 .32842 Mdot
.49581 .73567 Mdot
.77408 .4374 Mdot
.67508 .42618 Mdot
.47213 .19912 Mdot
.66375 .68898 Mdot
.52054 .44568 Mdot
.81303 .42015 Mdot
.54603 .50908 Mdot
.66263 .43505 Mdot
.61402 .55631 Mdot
.44962 .69906 Mdot
.5098 .22311 Mdot
.61771 .47624 Mdot
.50406 .4571 Mdot
.31625 .43519 Mdot
.43049 .62674 Mdot
.3352 .32938 Mdot
.37285 .36576 Mdot
.71874 .48815 Mdot
.28074 .48051 Mdot
.65024 .461 Mdot
.38002 .58482 Mdot
.7488 .43423 Mdot
.73606 .42107 Mdot
.55427 .43181 Mdot
.6532 .58254 Mdot
.46871 .2038 Mdot
.48001 .40753 Mdot
.29996 .57691 Mdot
.44824 .67399 Mdot
.58405 .23141 Mdot
.69161 .43254 Mdot
.45658 .44273 Mdot
.29906 .49831 Mdot
.47302 .45718 Mdot
.53006 .31173 Mdot
.49591 .5048 Mdot
.58392 .6639 Mdot
.38007 .5914 Mdot
.49583 .73266 Mdot
.47859 .68715 Mdot
.66726 .70657 Mdot
.77961 .41909 Mdot
.53366 .63494 Mdot
.49769 .59494 Mdot
.49993 .44305 Mdot
.74716 .41357 Mdot
.65744 .65883 Mdot
.6099 .63121 Mdot
.35223 .59521 Mdot
.47247 .2187 Mdot
.46055 .70918 Mdot
.49386 .61885 Mdot
.55466 .58203 Mdot
.41496 .36305 Mdot
.65012 .69828 Mdot
.51514 .67547 Mdot
.44186 .65251 Mdot
.48127 .26843 Mdot
.56578 .59593 Mdot
.5576 .35886 Mdot
.71794 .4564 Mdot
.53905 .5834 Mdot
.74051 .42244 Mdot
.3844 .65805 Mdot
.48178 .24948 Mdot
.38099 .34564 Mdot
.58836 .42622 Mdot
.35047 .45494 Mdot
.45829 .62438 Mdot
.52915 .34947 Mdot
.56214 .54243 Mdot
.56148 .63105 Mdot
.46957 .68 Mdot
.79757 .43616 Mdot
.60215 .33419 Mdot
.70076 .66395 Mdot
.61959 .45978 Mdot
.28703 .49382 Mdot
.27738 .48973 Mdot
.62995 .6296 Mdot
.60381 .5551 Mdot
.4543 .59485 Mdot
.57375 .45765 Mdot
.34859 .57879 Mdot
.55 .33216 Mdot
.51102 .18345 Mdot
.39928 .62181 Mdot
.80781 .44472 Mdot
.36547 .60113 Mdot
.41049 .6242 Mdot
.65989 .44463 Mdot
.58721 .59863 Mdot
.51758 .42986 Mdot
.51671 .40468 Mdot
.4472 .75626 Mdot
.50726 .17809 Mdot
.54332 .62962 Mdot
.58048 .44878 Mdot
.64976 .49146 Mdot
.49742 .63376 Mdot
.67244 .58462 Mdot
.6596 .61433 Mdot
.80146 .43291 Mdot
.73609 .43507 Mdot
.65249 .59206 Mdot
.62583 .5741 Mdot
.5573 .62917 Mdot
.49139 .25608 Mdot
.61857 .46673 Mdot
.50508 .33304 Mdot
.68009 .69659 Mdot
.35727 .55753 Mdot
.32578 .3191 Mdot
.36211 .33383 Mdot
.31164 .47778 Mdot
.44924 .48441 Mdot
.48177 .28862 Mdot
.57035 .36718 Mdot
.60225 .3136 Mdot
.65895 .48171 Mdot
.49247 .17822 Mdot
.49214 .65457 Mdot
.60006 .34561 Mdot
.52878 .40535 Mdot
.56401 .59526 Mdot
.31222 .35488 Mdot
.4487 .52855 Mdot
.55634 .38414 Mdot
.58345 .61636 Mdot
.48569 .69171 Mdot
.52404 .29626 Mdot
.35048 .45277 Mdot
.23513 .47015 Mdot
.64612 .68099 Mdot
.65717 .55062 Mdot
.47397 .68748 Mdot
.52358 .18692 Mdot
.60601 .62968 Mdot
.68809 .64523 Mdot
.63413 .62802 Mdot
.51748 .36985 Mdot
.69852 .68929 Mdot
.63361 .64725 Mdot
.81685 .41026 Mdot
.53118 .69261 Mdot
.44273 .48355 Mdot
.47287 .73114 Mdot
.35218 .31392 Mdot
.41496 .52287 Mdot
.57144 .34783 Mdot
.51809 .30506 Mdot
.34186 .36538 Mdot
.59698 .45928 Mdot
.47885 .28124 Mdot
.7424 .44938 Mdot
.72762 .45914 Mdot
.64411 .6863 Mdot
.43558 .6202 Mdot
.70658 .69275 Mdot
.64382 .5046 Mdot
.32045 .58486 Mdot
.48248 .32584 Mdot
.45738 .4593 Mdot
.56077 .53705 Mdot
.45009 .51485 Mdot
.50028 .24803 Mdot
.76524 .41793 Mdot
.6642 .56677 Mdot
.67148 .55838 Mdot
.38299 .33468 Mdot
.55063 .42496 Mdot
.43037 .5659 Mdot
.48446 .33987 Mdot
.63733 .54165 Mdot
.61784 .47476 Mdot
.7519 .44431 Mdot
.45833 .62463 Mdot
.3401 .47588 Mdot
.47617 .21419 Mdot
.30527 .48779 Mdot
.79039 .4536 Mdot
.6813 .67947 Mdot
.6582 .48445 Mdot
.49446 .18052 Mdot
.44171 .59142 Mdot
.34429 .41095 Mdot
.46658 .19835 Mdot
.52365 .23206 Mdot
.55904 .62707 Mdot
.4084 .3874 Mdot
.81826 .41486 Mdot
.64499 .56262 Mdot
.5287 .38551 Mdot
.3503 .61418 Mdot
.70333 .4621 Mdot
.35462 .38973 Mdot
.46084 .43243 Mdot
.58136 .45449 Mdot
.40872 .63854 Mdot
.44234 .62912 Mdot
.64113 .45789 Mdot
.73647 .45583 Mdot
.33483 .57193 Mdot
.3667 .64137 Mdot
.36862 .53526 Mdot
.44009 .69613 Mdot
.51989 .31631 Mdot
.55875 .20012 Mdot
.33385 .59604 Mdot
.48529 .26019 Mdot
.23164 .45346 Mdot
.47971 .63199 Mdot
.34967 .59628 Mdot
.34734 .34738 Mdot
.64906 .4574 Mdot
.48316 .17967 Mdot
.35359 .57447 Mdot
.54481 .19237 Mdot
.53439 .30563 Mdot
.42666 .66828 Mdot
.38008 .57448 Mdot
.36545 .36432 Mdot
.54039 .61532 Mdot
.59362 .60589 Mdot
.65721 .49264 Mdot
.67235 .43367 Mdot
.62603 .5004 Mdot
.34638 .44447 Mdot
.43875 .52053 Mdot
.51981 .34093 Mdot
.60594 .48682 Mdot
.51888 .3352 Mdot
.39427 .53231 Mdot
.35716 .46015 Mdot
.46615 .19028 Mdot
.50457 .71132 Mdot
.37709 .37479 Mdot
.62268 .35181 Mdot
.60087 .34635 Mdot
.25482 .4265 Mdot
.62986 .65609 Mdot
.41874 .34985 Mdot
.68628 .46514 Mdot
.51594 .30851 Mdot
.37133 .60239 Mdot
.358 .36455 Mdot
.65925 .59503 Mdot
.34921 .46637 Mdot
.34808 .39332 Mdot
.63652 .68238 Mdot
.66875 .4651 Mdot
.68843 .57287 Mdot
.64969 .66747 Mdot
.50566 .65415 Mdot
.28175 .35493 Mdot
.58809 .34324 Mdot
.6647 .4565 Mdot
.62857 .6275 Mdot
.64687 .68444 Mdot
.76666 .44821 Mdot
.47362 .42703 Mdot
.66849 .67663 Mdot
.64646 .43615 Mdot
.33592 .35595 Mdot
.44972 .50769 Mdot
.56231 .61319 Mdot
.32898 .53646 Mdot
.49669 .27216 Mdot
.58265 .31637 Mdot
.5739 .35661 Mdot
.32603 .51996 Mdot
.5075 .26157 Mdot
.61386 .63801 Mdot
.79476 .38362 Mdot
.59043 .596 Mdot
.4767 .6696 Mdot
.3215 .50591 Mdot
.58683 .5358 Mdot
.25968 .55896 Mdot
.40752 .38723 Mdot
.32693 .49642 Mdot
.68542 .64329 Mdot
.59546 .53614 Mdot
.50308 .64403 Mdot
.52081 .62523 Mdot
.48377 .37916 Mdot
.26164 .55985 Mdot
.3661 .41781 Mdot
.56654 .3789 Mdot
.30545 .33348 Mdot
.56816 .35586 Mdot
.53101 .42217 Mdot
.67584 .63429 Mdot
.66736 .4582 Mdot
.72229 .45974 Mdot
.48767 .40327 Mdot
.50386 .23794 Mdot
.28778 .5846 Mdot
.48667 .32957 Mdot
.474 .51486 Mdot
.67511 .66154 Mdot
.30211 .4893 Mdot
.48206 .18393 Mdot
.42508 .52543 Mdot
.54715 .23419 Mdot
.54374 .32392 Mdot
.50797 .34703 Mdot
.65014 .59392 Mdot
.47838 .76264 Mdot
.66155 .48001 Mdot
.39885 .36218 Mdot
.48322 .69863 Mdot
.59201 .30512 Mdot
.5352 .36739 Mdot
.58017 .47676 Mdot
.57373 .60813 Mdot
.32755 .55007 Mdot
.41618 .37194 Mdot
.70463 .48419 Mdot
.32985 .53193 Mdot
.45231 .48107 Mdot
.48135 .29037 Mdot
.30062 .57371 Mdot
.50136 .54697 Mdot
.43284 .5174 Mdot
.4777 .20634 Mdot
.69792 .48546 Mdot
.27157 .48055 Mdot
.30321 .59137 Mdot
.68533 .6507 Mdot
.66148 .4304 Mdot
.47134 .2239 Mdot
.66162 .60664 Mdot
.57319 .45677 Mdot
.51021 .74831 Mdot
.44731 .50417 Mdot
.43774 .65343 Mdot
.65014 .63986 Mdot
.60976 .42562 Mdot
.47119 .48483 Mdot
.48287 .17053 Mdot
.52443 .36011 Mdot
.51506 .43231 Mdot
.32106 .58957 Mdot
.75192 .44219 Mdot
.2653 .48955 Mdot
.67157 .68287 Mdot
.52344 .31806 Mdot
.65776 .58956 Mdot
.8157 .41896 Mdot
.54057 .59076 Mdot
.38946 .66271 Mdot
.54711 .42378 Mdot
.48681 .70554 Mdot
.58961 .51511 Mdot
.36385 .63944 Mdot
.49449 .71043 Mdot
.48445 .35879 Mdot
.57347 .57042 Mdot
.44454 .76552 Mdot
.36753 .58351 Mdot
.52808 .5615 Mdot
.59882 .59353 Mdot
.49473 .61829 Mdot
.5043 .5946 Mdot
.65466 .66032 Mdot
.5168 .54849 Mdot
.50571 .71409 Mdot
.64226 .60997 Mdot
.39489 .52635 Mdot
.64655 .45356 Mdot
.49607 .38781 Mdot
.74477 .49802 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Iooooo`Go0000Zooo
ool001cooooo00?o0000ooooooooool0Uoooool:o`000:Sooooo000Looooo`03o`000?oooooooooo
09Kooooo1Ol00002ooooo`So0000Y?ooool001cooooo00?o0000ooooooooool0U_ooool3o`0000?o
oooo0_l00003ooooo`Oo0000XOooool001cooooo00?o0000ooooooooool0U_ooool2o`000003oooo
ool0003o000000Co00000_ooool2o`0000;ooooo0ol0002Qooooo`007?ooool00ol0003ooooooooo
o`2Fooooo`;o000000?oooooo`000?l000001?l00003ooooo`;o00001?ooool2o`0009oooooo000L
ooooo`03o`000?oooooooooo09Wooooo1Ol00004ooooo`?o000000?oooooo`000?l000000_l00002
ooooo`;o0000Voooool001cooooo00?o0000ooooooooool0U?ooool3o`0000Cooooo0_l00006oooo
o`;o000000?oooooo`000?l000001?ooool6o`0009Oooooo00001_ooooook^k^oc8b<_l0003o<S8b
onk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`2Dooooo`?o00005_ooool5
o`0009Oooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`2Dooooo`Co00003Oooool2o`0000Kooooo
0ol0002Iooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ
8B7ok^k^00Oooooo00?o0000ooooooooool0U?ooool4o`0000gooooo0_l00003ooooo`;o00000_oo
ool3o`0009Sooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RH
ob4Q8Oo^k^h01_ooool3o`0009Cooooo1?l0000?ooooo`;o000000?oooooo`000?l000000_ooool3
o`000004ooooool0003o0000ooooo`;o0000T_ooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo09Cooooo0_l00000
0ooooooo0000o`000003ooooo`;o00002Oooool2o`0000Wooooo0_l000001?oooooo0000o`000?l0
002Aooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0U?ooool2o`000003ooooool0003o000000;o000000?ooooo
o`000?l000003Oooool2o`0000Gooooo0_l00002ooooo`;o0000TOooool00006oooooomgMgOoV9RH
oooooonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
Uoooool4o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0009?ooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo
09Oooooo0_l00009ooooo`;o00004?ooool2o`0009?ooooo000Looooo`03o`000?oooooooooo09Oo
oooo0_l0000;ooooo`Oo00002oooool2o`00097ooooo000Looooo`03o`000?oooooooooo09Kooooo
0_l0000<ooooo`Oo00001oooool6o`00097ooooo000Looooo`03o`000?oooooooooo09Gooooo1Ol0
0005ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Kooooo2?l000000ooooooo0000o`00
002>ooooo`007?ooool00ol0003oooooooooo`2Eooooo`Go00001Oooool2o`000003ooooool0003o
000000?ooooo0_l00002ooooo`;o00000oooool<o`0008gooooo000Looooo`03o`000?oooooooooo
09Gooooo0ol00002ooooo`;o00000oooool4o`0000Cooooo0_l000000ooooooo0000o`000003o`00
00;ooooo2ol0002=ooooo`007?ooool00ol0003oooooooooo`2Jooooo`;o00001Oooool2o`0000?o
oooo0_l00002ooooo`Go00000_ooool7o`0000;ooooo0_l0002=ooooo`007?ooool00ol0003ooooo
ooooo`2Vooooo`Ko00000_ooool2o`0000;ooooo2_l0002=ooooo`007?ooool00ol0003ooooooooo
o`2Fooooo`?o00001_ooool3o`0000Kooooo1?l000001?oooooo0000o`000?l00002ooooo`[o0000
SOooool001cooooo00?o0000ooooooooool0U_ooool5o`0000Cooooo0ol00005ooooo`?o00000ooo
ool2o`0000?ooooo2Ol0002>ooooo`007?ooool00ol0003oooooooooo`2Gooooo`Co00000_ooool2
o`0000Sooooo0_l00004ooooo`ko0000S_ooool001cooooo00?o0000ooooooooool0WOooool4o`00
00;ooooo0_l00002ooooo`;o00000oooool7o`0000;ooooo1_l000000ooooooo0000o`00002;oooo
o`007?ooool2o`0009Oooooo0_l000000ooooooo0000o`000004ooooo`;o00000_ooool2o`0000;o
oooo0_l00003ooooo`Oo000000?oooooo`000?l000002?l0002;ooooo`007?ooool00ol0003ooooo
ooooo`2Fooooo`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00001?ooool2o`0000?o
oooo4?l0002=ooooo`007?ooool00ol0003oooooooooo`2Looooo`;o00000oooool3o`0000Cooooo
0_l00002oooooa3o0000SOooool001cooooo00?o0000ooooooooool0V_ooool4o`0000?ooooo0ol0
0004ooooo`;o00000_ooool@o`0008gooooo000Looooo`03o`000?oooooooooo09[ooooo0_l00005
ooooo`;o00001Oooool2o`000003ooooool0003o000000ko000000?oooooo`000?l00000Roooool0
01cooooo00?o0000ooooooooool0Yoooool2o`0000;ooooo4?l000000ooooooo0000o`00002;oooo
o`007?ooool00ol0003oooooooooo`2Iooooo`;o00003?ooool3o`0000;ooooo3ol0002>ooooo`00
7?ooool00ol0003oooooooooo`2Iooooo`;o00000oooool2o`0000Sooooo0_l000000ooooooo0000
o`00000?o`0008gooooo000Looooo`03o`000?oooooooooo09kooooo0_l00008ooooo`;o000000?o
ooooo`000?l000003ol0002=ooooo`007?ooool00ol0003oooooooooo`2Xooooo`;o000000?ooooo
o`000?l000003_l0002>ooooo`007?ooool00ol0003oooooooooo`2Hooooo`;o000000?oooooo`00
0?l000002?ooool2o`0000;ooooo4_l0002>ooooo`007?ooool00ol0003oooooooooo`2Hooooo`;o
000000Coooooo`000?l0003o00001?ooool2o`000003ooooool0003o000001Go0000SOooool001co
oooo00?o0000ooooooooool0V?ooool3o`000003ooooool0003o000000Cooooo0_l000000ooooooo
0000o`000004o`000003ooooool0003o000000ko0000SOooool001cooooo00?o0000ooooooooool0
V?ooool3o`00017ooooo3ol0002>ooooo`007?ooool00ol0003oooooooooo`2Iooooo`;o00004Ooo
ool?o`0008kooooo000Looooo`03o`000?oooooooooo09Sooooo0_l00008ooooo`;o00000_ooool2
o`000003ooooool0003o000000;ooooo3_l0002>ooooo`007?ooool2o`0009Wooooo0_l00008oooo
o`;o00000_ooool2o`000003ooooool0003o000000;ooooo3ol0002=ooooo`007?ooool00ol0003o
ooooooooo`2[ooooo`;o000000?oooooo`000?l000003?l0002=ooooo`007?ooool00ol0003ooooo
ooooo`2Uooooo`;o00000_ooool4o`0000;ooooo2ol00003ooooo`Go0000Qoooool001cooooo00?o
0000ooooooooool0M?ooool4o`0002cooooo0ol00002ooooo`Go00000oooool2o`000003ooooool0
003o000000Co00000oooool5o`0008Oooooo000Looooo`03o`000?oooooooooo06Kooooo0ol00004
ooooo`Go00000_ooool4o`0002Oooooo0_l00003ooooo`;o000000Goooooo`000?l0003o0000oooo
o`03o`0000?ooooo0ol00009ooooo`;o000000?oooooo`000?l00000Qoooool001cooooo00?o0000
ooooooooool0I_ooool3o`0000Cooooo2Ol00002ooooo`Go00008_ooool2o`0000Cooooo1Ol00002
ooooo`;o00001?ooool3o`0000Cooooo0_l00004ooooo`?o0000Qoooool001cooooo00?o0000oooo
ooooool0I?ooool6o`0000;ooooo5?l0000Uooooo`?o00002oooool2o`0000Cooooo0_l00004oooo
o`Go0000QOooool001cooooo00?o0000ooooooooool0I?ooool6o`000003ooooool0003o000001Co
00007?ooool2o`0000Oooooo0_l00007ooooo`;o00004?ooool3o`0008Gooooo000Looooo`03o`00
0?oooooooooo067ooooo0_l00008ooooo`;o00001_ooool2o`000003ooooool0003o000000co0000
5Oooool2o`0000;ooooo1?l0000<ooooo`Go00001oooool3o`0000Kooooo0_l00025ooooo`007?oo
ool00ol0003oooooooooo`1Qooooo`Co00001?ooool2o`0000Kooooo1?l00005ooooo`;o00000ooo
ool6o`0001Cooooo1?l00002ooooo`;o00000_ooool2o`0000Sooooo0_l000001?oooooo0000o`00
0?l00006ooooo`Go00001?ooool3o`0008Cooooo000Looooo`03o`000?oooooooooo06?ooooo0_l0
0004ooooo`;o00001_ooool2o`0000cooooo1_l0000Eooooo`?o00001_ooool2o`0000Sooooo1_l0
0008ooooo`?o00000oooool5o`0008?ooooo000Looooo`03o`000?oooooooooo05kooooo0ol0000A
ooooo`;o00001Oooool2o`0000Cooooo2Ol0000Aooooo`?o00001?ooool2o`0000?ooooo0_l00008
ooooo`;o000000?oooooo`000?l000001oooool2o`000003ooooool0003o000000?o000000?ooooo
o`000?l00000Poooool001cooooo00?o0000ooooooooool0G?ooool5o`00017ooooo0_l00005oooo
o`;o00000oooool2o`000003ooooool0003o000000Go00004Oooool2o`0000Gooooo0_l00003oooo
o`;o00002oooool2o`0000Oooooo1ol00002ooooo`;o0000Poooool001cooooo00?o0000oooooooo
ool0Foooool4o`0000?ooooo1?l0000Hooooo`;o00001?ooool4o`0001;ooooo0_l00003ooooo`?o
00000oooool3o`0001;ooooo2?l00002ooooo`?o0000P_ooool001cooooo00?o0000ooooooooool0
FOooool5o`0000Cooooo1?l0000Cooooo`;o00002Oooool4o`0001;ooooo0_l00002ooooo`?o0000
1?ooool3o`000003ooooool0003o000000gooooo1ol000000ooooooo0000o`000002o`000003oooo
ool0003o000008;ooooo000Looooo`03o`000?oooooooooo05Wooooo1Ol0000=ooooo`Co00001ooo
ool5o`0000Wooooo1Ol0000Eooooo`;o000000?oooooo`000?l000000oooool2o`000003ooooool0
003o000000_ooooo1?l000000ooooooo0000o`000002ooooo`Go0000QOooool001cooooo0_l0001G
ooooo`Go00003_ooool6o`0000Cooooo1ol0000:ooooo`Oo00005_ooool2o`0000?ooooo1?l00008
ooooo`;o00000_ooool@o`0008?ooooo000Looooo`03o`000?oooooooooo05Kooooo1Ol0000>oooo
o`;o00002?ooool6o`0000_ooooo2?l0000Looooo`?o00001oooool2o`000003ooooool0003o0000
017o0000POooool001cooooo00?o0000ooooooooool0EOooool6o`0000Oooooo0ol00004ooooo`;o
000000?oooooo`000?l000000_ooool2o`0001Cooooo1_l0000Mooooo`;o00001_ooool2o`0000;o
oooo4?l000000ooooooo0000o`000021ooooo`007?ooool00ol0003oooooooooo`1Eooooo`Go0000
0_ooool2o`0000Cooooo0ol00004ooooo`;o000000?oooooo`000?l000000_ooool3o`0000_ooooo
0_l00006ooooo`Ko00003Oooool5o`0000;ooooo0_l00003ooooo`Co00002?ooool2o`0000;ooooo
4_l00022ooooo`007?ooool00ol0003oooooooooo`1Eooooo`Wo00002oooool2o`0000Cooooo1?l0
000;ooooo`;o00000oooool2o`000003ooooool0003o000000?o00003_ooool5o`0000;ooooo0_l0
0003ooooo`Co00002?ooool2o`0000?ooooo4Ol00022ooooo`007?ooool00ol0003oooooooooo`1G
ooooo`So000000?oooooo`000?l000002Oooool<o`0000Oooooo1?l000000ooooooo0000o`000003
ooooo`Co00004oooool2o`0001Gooooo4Ol00022ooooo`007?ooool00ol0003oooooooooo`1Koooo
o`Co000000?oooooo`000?l000001_l00003ooooo`co00001Oooool2o`0000;ooooo0_l00006oooo
o`Co00004oooool2o`0000Wooooo0_l000000ooooooo0000o`000006oooooa7o000000?oooooo`00
0?l000000_l0001nooooo`007?ooool00ol0003oooooooooo`1Rooooo`Ko00001oooool3o`0000[o
oooo0_l00005ooooo`Wo00002oooool2o`0000[ooooo0ol00002ooooo`Co000000?oooooo`000?l0
00000oooool2o`000003ooooool0003o000001Co0000O_ooool001cooooo00?o0000ooooooooool0
J_ooool3o`0000?ooooo0_l00005ooooo`;o00002_ooool9o`0000_ooooo0_l0000:ooooo`?o0000
0_ooool4o`0000Kooooo0_l000000ooooooo0000o`00000Ao`000003ooooool0003o000007kooooo
000Looooo`03o`000?oooooooooo06[ooooo1Ol000000ooooooo0000o`000002o`0000?ooooo1?l0
0006ooooo`;o00000_ooool2o`000003ooooool0003o000000;o00002oooool2o`000003ooooool0
003o000000Kooooo0_l00006ooooo`;o00002OoooolCo`000003ooooool0003o000007kooooo000L
ooooo`03o`000?oooooooooo06cooooo1Ol000000ooooooo0000o`000005ooooo`;o00001_ooool2
o`0000Gooooo1?l0000;ooooo`Go00001_ooool3o`0000gooooo4ol000001?oooooo0000o`000?oo
ool2o`0007kooooo000Looooo`03o`000?oooooooooo06cooooo0_l000000ooooooo0000o`000006
ooooo`;o00004?ooool3o`0000gooooo0_l00003ooooo`;o00000oooool2o`0000cooooo6Ol0000d
ooooo`;o00000_ooool2o`0004Gooooo000Looooo`03o`000?oooooooooo07Oooooo0ol00003oooo
o`;o00000_ooool2o`0000Kooooo0ol0000Aooooo`?o00002?ooool2o`0000Oooooo0_l00002oooo
oaGo0000;oooool2o`0000?ooooo0_l00002ooooo`;o0000AOooool001cooooo00?o0000oooooooo
ool0Koooool2o`0000Oooooo0_l00003ooooo`;o00000_ooool2o`0000Oooooo0_l0000Aooooo`;o
00002Oooool2o`0000_ooooo5?l0000`ooooo`Co00000oooool2o`0004Oooooo00001_ooooook^k^
oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0
003oooooooooo`1]ooooo`Co00001oooool2o`0000;ooooo0_l000000ooooooo0000o`000005oooo
o`;o000000Coooooo`000?l0003o00002oooool2o`0001cooooo4_l0000_ooooo`;o00000oooool2
o`0000?ooooo0_l00002ooooo`;o0000@oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Ooo
ool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1]ooooo`;o00002Ooo
oolDo`0000_ooooo0_l00008ooooo`;o00004_oooolAo`00033ooooo0ol0000;ooooo`;o0000@ooo
ool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo00?o0000
ooooooooool0MOoooolGo`0001Gooooo0_l0000Boooooa7o0000<Oooool2o`00053ooooo00000ooo
oooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool3
o`0007Gooooo4ol000001?oooooo0000o`000?l0000?ooooo`;o00006Oooool@o`0003Gooooo0_l0
0005ooooo`?o0000A?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool0
1?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo06_ooooo0_l00006oooooaGo000000?o
ooooo`000?l000004?ooool2o`0000Oooooo0_l00002ooooo`Co00001Oooool2o`0000?ooooo4?l0
000eooooo`;o00001Oooool3o`0004Cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooo
oooo00[ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`1[ooooo`;o00001?oooolJ
o`0000_ooooo1?l0000:ooooo`;o00000_ooool4o`0000?ooooo1?l00004ooooo`_o00000_ooool2
o`0003kooooo1?l00011ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4
A4Co000000Oooooo00?o0000ooooooooool0JOooool2o`000003ooooool0003o000000?ooooo6_l0
000;ooooo`Co00002_ooool2o`0000Wooooo0_l00006ooooo`oo0000:_ooool2o`0000_ooooo0_l0
0005ooooo`Co0000@Oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000
ooooo`06ooooo`03o`000?oooooooooo06Wooooo0_l000000ooooooo0000o`000002oooooa_o0000
6Oooool2o`000003ooooool0003o000000kooooo3_l0000Mooooo`?o00002_ooool3o`0000_ooooo
1?l00005ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0H_ooool4o`0000Sooooo6ol0
000>ooooo`;o00003_ooool2o`0000oooooo3Ol0000Iooooo`;o00000_ooool3o`0000[ooooo0ol0
0003ooooo`;o00002?ooool2o`0000Gooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`1J
ooooo`?o00000_ooool8o`0000Oooooo6ol0000>ooooo`;o00002Oooool2o`0001;ooooo0_l00000
0ooooooo0000o`000005o`000004ooooool0003o0000o`0001[ooooo0_l00002ooooo`;o00001ooo
ool2o`0000?ooooo0_l00003ooooo`;o00000_ooool3o`0000Cooooo0_l000000ooooooo0000o`00
0003o`00047ooooo000Looooo`03o`000?oooooooooo053ooooo2Ol000001?oooooo0000o`000?l0
0002ooooo`So00001_oooolKo`0000_ooooo0_l0000=ooooo`;o00001Oooool2o`0000?ooooo0_l0
0004ooooo`Co000000?oooooo`000?l000000ol0000]ooooo`Co00002_ooool3o`0000Cooooo0_l0
00000ooooooo0000o`000003o`00047ooooo000Looooo`03o`000?oooooooooo04oooooo5ol00006
oooooaco00002oooool2o`000003ooooool0003o0000017ooooo0_l00003ooooo`?o00000oooool2
o`0000Gooooo0_l00005ooooo`;o00004oooool3o`00017ooooo1?l0000;ooooo`;o00002?ooool2
o`0004?ooooo000Looooo`03o`000?oooooooooo04kooooo6?l00005oooooaco00003oooool2o`00
00cooooo0_l00009ooooo`;o00002_ooool2o`000003ooooool0003o000000;ooooo0_l0000?oooo
o`Oo00004?ooool6o`0001Cooooo0ol00012ooooo`007?ooool00ol0003oooooooooo`1<oooooaSo
00001_oooolMo`0000_ooooo0_l0000@ooooo`;o00002?ooool4o`0000;ooooo0_l00008ooooo`;o
00004?ooool2o`000003ooooool0003o000000Ko00000_ooool2o`0000Cooooo0_l00005ooooo`;o
00000_ooool2o`0000;ooooo0_l0000=ooooo`;o00000_ooool2o`0004;ooooo000Looooo`03o`00
0?oooooooooo04cooooo6Ol00004oooooago00003?ooool2o`00013ooooo0_l00008ooooo`Co0000
0_ooool2o`00013ooooo1Ol00003ooooo`Co000000?oooooo`000?l000000_ooool4o`0000;ooooo
0_l00004ooooo`;o00001Oooool3o`0000;ooooo0_l000000ooooooo0000o`00000;ooooo`Co0000
0_ooool2o`0004;ooooo000Looooo`03o`000?oooooooooo04gooooo6?l00004oooooa[o000000?o
ooooo`000?l000002oooool2o`0000Wooooo0_l0000Xooooo`Go00000oooool2o`0000?ooooo0_l0
000Eooooo`So00000_ooool2o`0000;ooooo0ol00002ooooo`Ko00000_ooool2o`0004;ooooo000L
ooooo`03o`000?oooooooooo04Wooooo6Ol00006oooooa_o00003_ooool2o`0000Wooooo0_l00000
0ooooooo0000o`00000<ooooo`;o00000_ooool2o`0001Kooooo0_l0000Booooo`;o00001?ooool2
o`0000Sooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool3o`0000;ooooo0_l00006
ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0BOoooolIo`0000Gooooo6ol0000>oooo
o`?o00003?ooool2o`0000Cooooo0_l00006ooooo`Ko00008?ooool2o`0000;ooooo0_l00002oooo
o`Co00001?ooool4o`0000Wooooo0_l00005ooooo`;o00000_ooool2o`0000Kooooo0_l00014oooo
o`007?ooool00ol0003oooooooooo`18ooooo`;o00000_oooolCo`000003ooooool0003o000000Go
oooo6_l0000?ooooo`;o00001Oooool2o`0000cooooo0_l00008ooooo`;o00002?ooool2o`0001So
oooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`?o00001_ooool2o`000003
ooooool0003o000000?ooooo1?l00002ooooo`;o00001Oooool4o`0004?ooooo000Looooo`;o0000
BOooool2o`0000;ooooo4ol00008ooooo`Ko000000?oooooo`000?l000004?l0000@ooooo`;o0000
1Oooool2o`0000Oooooo0ol00009ooooo`;o00002oooool2o`0000;ooooo0_l00007ooooo`;o0000
2oooool2o`0000Wooooo1?l00002ooooo`;o00001oooool2o`0000Cooooo1?l00008ooooo`Oo0000
@oooool001cooooo00?o0000ooooooooool0B?ooool2o`0000;ooooo4_l00008ooooo`Ko00000_oo
ool?o`0002?ooooo0ol00009ooooo`;o00002oooool2o`0000;ooooo0_l00007ooooo`?o00001Ooo
ool2o`0000_ooooo0_l000000ooooooo0000o`00000=ooooo`;o00001?ooool4o`0000Cooooo2_l0
0014ooooo`007?ooool00ol0003oooooooooo`18ooooo`;o00000_ooool@o`0000[ooooo1ol00000
0ooooooo0000o`00000=o`0001Wooooo0_l00006ooooo`Co00005?ooool5o`0000cooooo0_l00003
ooooo`Ko00000_ooool3o`0000Cooooo0_l00008ooooo`;o00001?ooool4o`0000?ooooo0_l00000
0ooooooo0000o`000004ooooo`Wo0000AOooool001cooooo00?o0000ooooooooool0COooool=o`00
00cooooo2Ol000000ooooooo0000o`00000:o`0001Cooooo0ol00003ooooo`;o00001_ooool4o`00
01Cooooo1?l00004ooooo`Go00000_ooool2o`0000Gooooo0_l000001?oooooo0000o`000?l00002
ooooo`?o00003_ooool:o`0000?ooooo0_l00007ooooo`Wo0000AOooool001cooooo00?o0000oooo
ooooool0COooool4o`0000;ooooo1_l0000;ooooo`;o000000?oooooo`000?l000001_l000001Ooo
oooo0000o`000?l0003ooooo00?o000000?oooooo`000?l000005_ooool3o`0000;ooooo0_l0000Q
ooooo`;o00001?ooool5o`0000;ooooo0_l00006ooooo`Co00003Oooool2o`000003ooooool0003o
000000?ooooo1Ol00007ooooo`;o00000_ooool2o`000003ooooool0003o000000Wo0000AOooool0
01cooooo00?o0000ooooooooool0Coooool4o`0000;ooooo1?l0000;ooooo`;o000000?oooooo`00
0?l000000ol00002ooooo`Go000000Coooooo`000?l0003o00005_ooool2o`0000Kooooo0_l0000W
ooooo`;o00000oooool4o`0000Gooooo0ol00006ooooo`;o00001?ooool2o`000004ooooool0003o
0000ooooo`;o00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`000003ooooool0
003o000000;ooooo3Ol00016ooooo`007?ooool00ol0003oooooooooo`19ooooo`Co00001?ooool2
o`0000;ooooo0ol0000>ooooo`Ko00000_ooool4o`0001_ooooo0_l0000_ooooo`;o00000oooool4
o`0000Gooooo0_l00004ooooo`;o000000?oooooo`000?l000001?ooool2o`0000gooooo0_l00000
0ooooooo0000o`000002o`000003ooooool0003o000000;ooooo3?l00017ooooo`007?ooool00ol0
003oooooooooo`19ooooo`Co00001_ooool2o`000003ooooool0003o000000kooooo1_l000000ooo
oooo0000o`000002o`0003gooooo0_l0000Dooooo`;o00003?ooool2o`0000oooooo2Ol00005oooo
o`?o000000?oooooo`000?l000002ol00017ooooo`007?ooool00ol0003oooooooooo`19ooooo`;o
00002?ooool2o`0000kooooo0_l000000ooooooo0000o`000008o`0002;ooooo0_l00009ooooo`;o
00003oooool2o`0000Wooooo0_l0000:ooooo`;o00006oooool:o`0000Gooooo0_l000000ooooooo
0000o`00000:o`0004Wooooo000Looooo`03o`000?oooooooooo04Wooooo0_l0000Dooooo`Ko0000
00Goooooo`000?l0003o0000ooooo`06o`0002;ooooo0_l00009ooooo`Co00004?ooool2o`0000Ko
oooo0_l0000:ooooo`;o00003?ooool2o`000003ooooool0003o000000Sooooo3Ol00005ooooo`go
0000B_ooool001cooooo00?o0000ooooooooool0Boooool3o`0000Oooooo1?l00003ooooo`;o0000
00?oooooo`000?l000001Ol000000ooooooo0000o`000006o`0001cooooo0_l00002ooooo`;o0000
1oooool2o`0000Gooooo0_l0000@ooooo`;o00004Oooool2o`0000cooooo0ol000000ooooooo0000
o`000006ooooo`Ko000000?oooooo`000?l000001_l00005ooooo`_o0000C?ooool001cooooo00?o
0000ooooooooool0Boooool3o`0000Oooooo1?l00003ooooo`;o00001_ooool2o`000003ooooool0
003o000000Ko00007?ooool6o`0000Cooooo0_l000000ooooooo0000o`00000Dooooo`;o00004ooo
ool3o`0000cooooo0ol00008oooooa3o00001?ooool:o`0004kooooo000Looooo`03o`000?oooooo
oooo05;ooooo0_l0000:ooooo`?o00001_ooool9o`0001cooooo1?l00005ooooo`;o00001?ooool2
o`00017ooooo0_l0000Aooooo`Go00002?ooool2o`0000;ooooo0ol00008oooooa3o000000?ooooo
o`000?l000002_l0001?ooooo`007?ooool00ol0003oooooooooo`1Booooo`;o00000_ooool4o`00
00Cooooo0ol00008ooooo`Oo0000:oooool2o`0002;ooooo1?l000000ooooooo0000o`000007oooo
o`Co000000Coooooo`000?l0003o00001_oooolOo`0004oooooo000Looooo`03o`000?oooooooooo
05Kooooo1_l0000<ooooo`?o0000E?ooool2o`000003ooooool0003o000000Wooooo1?l000000ooo
oooo0000o`000005oooooago0000Doooool001cooooo00?o0000ooooooooool0Eoooool2o`000004
ooooool0003o0000ooooo`;o00001oooool6o`0001[ooooo0_l00008ooooo`;o000000?oooooo`00
0?l00000;Oooool2o`0000kooooo0_l00005oooooaco0000E?ooool001cooooo0_l0001Hooooo`;o
00001?ooool2o`0000Oooooo0_l000000ooooooo0000o`000002o`0001Wooooo0_l00008ooooo`;o
000000?oooooo`000?l00000<oooool4o`0000Kooooo0_l00003oooooago0000EOooool001cooooo
00?o0000ooooooooool0G?ooool2o`0000gooooo0_l0000Hooooo`?o00001_ooool2o`0000gooooo
0_l0000Iooooo`;o00003_ooool4o`000003ooooool0003o000000Oooooo6_l0001Iooooo`007?oo
ool00ol0003oooooooooo`1Hooooo`;o00000_ooool2o`0000Oooooo0_l00004ooooo`Go00004_oo
ool6o`0000Kooooo0_l0000=ooooo`;o00005Oooool2o`0000;ooooo0_l0000Cooooo`;o00001_oo
oolKo`0005Wooooo000Looooo`03o`000?oooooooooo05Sooooo0_l00006ooooo`;o00000oooool2
o`0000Gooooo1Ol0000?ooooo`Ko000000?oooooo`000?l000001Oooool2o`0001cooooo1?l00004
ooooo`;o00007ooooolIo`0005_ooooo000Looooo`03o`000?oooooooooo05Wooooo0_l00004oooo
o`?o00003?ooool6o`0000_ooooo1?l00004ooooo`;o00008oooool4o`0002Cooooo6_l0001Koooo
o`007?ooool00ol0003oooooooooo`1Iooooo`;o000000Coooooo`000?l0003ooooo0_l0000=oooo
oaGo00001oooool2o`0000;ooooo0_l00006ooooo`;o00001_ooool2o`0001Wooooo0_l000000ooo
oooo0000o`00000FoooooaWo0000G?ooool001cooooo00?o0000ooooooooool0E_ooool2o`0000Co
oooo0_l00008ooooo`;o00002oooool?o`0000;ooooo0_l00003ooooo`?o00000_ooool2o`0000Ko
oooo0_l00006ooooo`;o00006Oooool2o`000003ooooool0003o0000017ooooo0_l00003oooooaCo
000000Coooooo`000?l0003o0000GOooool001cooooo00?o0000ooooooooool0E_ooool3o`0000go
oooo0_l00002ooooo`;o00002oooool4o`0000Sooooo0ol00003ooooo`Co000000?oooooo`000?l0
00002Oooool2o`00037ooooo0_l000000ooooooo0000o`000002oooooaGo000000?oooooo`000?l0
0000G_ooool001cooooo00?o0000ooooooooool0Doooool2o`000004ooooool0003o0000o`0000;o
oooo0_l0000=ooooo`;o00004Oooool2o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`;o
000000?oooooo`000?l000002Oooool2o`0001Cooooo0_l000000ooooooo0000o`00000;ooooo`;o
00002oooool2o`0000Gooooo5Ol0001Qooooo`007?ooool00ol0003oooooooooo`1Booooo`?o0000
1Oooool3o`00023ooooo0_l00007ooooo`;o00001_ooool2o`0001oooooo0_l000000ooooooo0000
o`00000;ooooo`;o00004OoooolFo`00067ooooo000Looooo`03o`000?oooooooooo05;ooooo0_l0
0003ooooo`Ko000000?oooooo`000?l000001oooool2o`0000gooooo0_l00004ooooo`;o00004?oo
ool3o`0002_ooooo0ol000000ooooooo0000o`00000@oooooaCo0000Hoooool001cooooo00?o0000
ooooooooool0Doooool:o`000003ooooool0003o000000;ooooo0_l00003ooooo`;o00002oooool4
o`0000Cooooo0_l00004ooooo`;o00001Oooool2o`0000Cooooo0_l0000Zooooo`Co000000?ooooo
o`000?l000002Oooool2o`0000Cooooo4ol0001Uooooo`007?ooool00ol0003oooooooooo`1Boooo
o`_o000000?oooooo`000?l000000_ooool2o`0000;ooooo0ol00007ooooo`;o00000_ooool2o`00
00cooooo0_l00005ooooo`;o00009oooool2o`0000?ooooo0_l00002ooooo`;o000000?oooooo`00
0?l000000_l00006ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00000A
o`0006Gooooo000Looooo`03o`000?oooooooooo05;ooooo3_l00006ooooo`?o00001oooool2o`00
00Cooooo0_l0000Aooooo`;o00009oooool2o`0000?ooooo0_l00005ooooo`?o00001oooool2o`00
0004ooooool0003o0000ooooo`;o000000?oooooo`000?l000003ol0001Wooooo`007?ooool00ol0
003oooooooooo`1Boooooa3o00001?ooool2o`0000kooooo0_l0000Aooooo`;o0000:?ooool2o`00
00[ooooo0_l0000:ooooo`?o00000ooooolBo`0006Kooooo000Looooo`03o`000?oooooooooo057o
oooo3_l000000ooooooo0000o`000004ooooo`;o00001oooool2o`0000gooooo0_l000000ooooooo
0000o`000006ooooo`;o00005?ooool2o`0001;ooooo0_l00009ooooo`?o00002oooool2o`0000Go
oooo3Ol000000ooooooo0000o`00001Vooooo`007?ooool2o`00057ooooo4?l00007ooooo`;o0000
1_ooool2o`0000gooooo0_l000000ooooooo0000o`000009ooooo`;o00004Oooool2o`0000?ooooo
0_l0000Hooooo`?o00000oooool2o`0000cooooo3_l0001Yooooo`007?ooool00ol0003ooooooooo
o`1@oooooa3o00001oooool2o`0002?ooooo0_l0000Fooooo`;o00005Oooool2o`0000?ooooo0_l0
0002ooooo`;o00002oooool?o`0006Wooooo000Looooo`03o`000?oooooooooo05;ooooo3_l0000=
ooooo`;o0000=oooool2o`00017ooooo1?l00003ooooo`;o00000_ooool2o`0000_ooooo0_l00002
ooooo`So0000K?ooool001cooooo00?o0000ooooooooool0DOooool?o`0000gooooo0_l000000ooo
oooo0000o`00000:ooooo`;o00002?ooool2o`0000Kooooo0_l0000Fooooo`;o00004Oooool2o`00
00Gooooo0_l00002ooooo`;o00002oooool3o`0000;ooooo1_l0001]ooooo`007?ooool00ol0003o
ooooooooo`1Aooooo`oo00004?ooool2o`0000Oooooo0_l000000ooooooo0000o`000008ooooo`;o
00001_ooool2o`0001?ooooo0_l00003ooooo`;o00001Oooool2o`0001gooooo0_l000001?oooooo
0000o`000?l00002ooooo`;o0000LOooool001cooooo00?o0000ooooooooool0D?ooool@o`0000_o
oooo0_l00007ooooo`;o00000oooool2o`0000Cooooo0_l00007ooooo`;o00006Oooool2o`0000?o
oooo0_l00005ooooo`;o00003_ooool2o`0000;ooooo0_l00009ooooo`;o0000NOooool001cooooo
00?o0000ooooooooool0D?ooool?o`0000cooooo0_l00007ooooo`;o00002Oooool2o`0000Oooooo
0_l0000Hooooo`;o00006oooool2o`0000;ooooo0_l00005ooooo`;o00001oooool3o`0000Oooooo
0_l0001Zooooo`007?ooool00ol0003oooooooooo`1Cooooo`co00000oooool2o`0000Gooooo0_l0
000gooooo`;o00004oooool4o`0000Cooooo0_l00007ooooo`Co00001oooool3o`0000Kooooo0ol0
001Zooooo`007?ooool00ol0003oooooooooo`1Cooooo`go00000_ooool2o`0000Gooooo0_l00004
ooooo`;o00001oooool2o`0003gooooo1?l00004ooooo`Co00000oooool5o`0000Sooooo0_l00007
ooooo`;o0000Joooool001cooooo00?o0000ooooooooool0D?ooool2o`000003ooooool0003o0000
00_o00003_ooool3o`0000?ooooo0_l00002ooooo`;o00002oooool2o`0003[ooooo0_l00003oooo
o`Go00002Oooool2o`0000Kooooo0_l0001[ooooo`007?ooool00ol0003oooooooooo`1@ooooo`?o
000000?oooooo`000?l000001_l00002ooooo`;o00003_ooool2o`0000Cooooo0_l00006ooooo`;o
00001oooool2o`0000_ooooo0_l0000eooooo`;o00002Oooool3o`0000Gooooo0_l0001[ooooo`00
7?ooool00ol0003oooooooooo`1Aooooo`;o00001?ooool9o`0000Cooooo0_l00009ooooo`;o0000
0oooool2o`0000;ooooo0_l00002ooooo`;o00005?ooool2o`0001Oooooo0_l00003ooooo`;o0000
7_ooool2o`0000?ooooo1?l00003ooooo`;o0000Joooool001cooooo00?o0000ooooooooool0Dooo
ool2o`0000Gooooo1_l00004ooooo`;o00002Oooool2o`0000?ooooo0_l00002ooooo`;o00009?oo
ool2o`0000Oooooo0_l00002ooooo`;o00000oooool2o`0001kooooo0_l00003ooooo`Co00000ooo
ool2o`0006_ooooo000Looooo`03o`000?oooooooooo05?ooooo1?l00004ooooo`Go00001Oooool2
o`0000Cooooo0_l0000Eooooo`;o00000_ooool2o`0001Kooooo0_l00007ooooo`?o00000_ooool2
o`0000;ooooo0_l0000:ooooo`;o00005?ooool2o`0000?ooooo0_l00002ooooo`?o0000Joooool0
0006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@
olc<c006ooooo`03o`000?oooooooooo05Gooooo0_l00004ooooo`;o000000Coooooo`000?l0003o
00001?ooool2o`0000?ooooo0ol000000ooooooo0000o`000006ooooo`Co00002?ooool2o`0000;o
oooo0_l00004ooooo`;o00001oooool2o`0000[ooooo0_l00005ooooo`;o00000_ooool2o`0000;o
oooo1?l00008ooooo`;o000000?oooooo`000?l000002Oooool2o`0000?ooooo1Ol00005ooooo`Go
0000Joooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMg
MoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo05[ooooo0ol000000ooooooo0000o`000003
o`0000Kooooo0ol00002ooooo`?o00001Oooool4o`0000Sooooo0_l00002ooooo`;o00001?ooool2
o`0000;ooooo0_l00003ooooo`;o00001oooool5o`0000oooooo1?l00006ooooo`;o000000?ooooo
o`000?l000001_ooool2o`000003ooooool0003o000000?ooooo1Ol00005ooooo`Co0000K?ooool0
0003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool0FOooool4o`000004ooooool0003o0000ooooo`[o00000ooo
ool3o`0000Kooooo0_l00009ooooo`;o00003?ooool2o`0000cooooo1?l00006ooooo`;o00000_oo
ool2o`0000Gooooo0ol00005ooooo`?o00001?ooool2o`0000?ooooo0_l000000ooooooo0000o`00
0004ooooo`Co0000MOooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool0
1Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0001Iooooo`Co00000oooool=o`000004ooooool0
003o0000o`0000;ooooo1?l00004ooooo`;o00008Oooool2o`000003ooooool0003o000000Gooooo
0_l00002ooooo`;o00003Oooool2o`0000Gooooo0_l00006ooooo`;o0000OOooool00003ooooool0
003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo
00?o0000ooooooooool0G?ooool2o`0000;ooooo0_l00003ooooo`go000000?oooooo`000?l00000
0_l00004ooooo`;o00004oooool2o`0000oooooo0_l0000Gooooo`;o000000?oooooo`000?l00000
1?ooool2o`0000kooooo0_l0001dooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0G?ooool2o`0000[ooooo3_l0
000Jooooo`;o00008Oooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000Cooooo
0_l0000>ooooo`;o0000M?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo
410@oiRHV008ooooo`03o`000?oooooooooo06cooooo3Ol0000@ooooo`;o00009?ooool2o`0000;o
oooo0_l00002ooooo`;o00005?ooool2o`000003ooooool0003o000007Oooooo00001_ooooook^k^
oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`1/
ooooo`go000000?oooooo`000?l000003Oooool2o`0001[ooooo0_l00005ooooo`;o000000Cooooo
o`000?l0003ooooo0ol00004ooooo`;o00004_ooool2o`000003ooooool0003o000000;o0000MOoo
ool001cooooo00?o0000ooooooooool0JooooolCo`0001Gooooo0_l00008ooooo`;o00001_ooool2
o`0000Gooooo0_l00004ooooo`?o00001?ooool3o`0000Cooooo1?l00007ooooo`;o00001Oooool2
o`0007Gooooo000Looooo`03o`000?oooooooooo06_ooooo4?l000000ooooooo0000o`000002o`00
00Cooooo0_l00004ooooo`;o00001oooool2o`0000Oooooo0ol0000;ooooo`;o00002_ooool2o`00
0004ooooool0003o0000o`0000Cooooo1?l00007ooooo`;o00001?ooool2o`0007Kooooo000Loooo
o`03o`000?oooooooooo06_ooooo5Ol00002ooooo`Co00001?ooool2o`0000?ooooo1_l00005oooo
o`Co00003?ooool2o`0000[ooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l00009oooo
o`;o00001?ooool2o`0007Kooooo000Looooo`03o`000?oooooooooo06cooooo0ol000000ooooooo
0000o`000002ooooo`_o00000oooool2o`0000?ooooo0ol00005ooooo`Ko00001Oooool4o`0000Oo
oooo0_l00006ooooo`;o00000oooool2o`0000Oooooo1ol00006ooooo`Co00001Oooool2o`0000;o
oooo0_l0001booooo`007?ooool00ol0003oooooooooo`1]ooooo`?o00000oooool=o`0000Oooooo
0ol00002ooooo`;o00003_ooool2o`0000Oooooo0_l00006ooooo`;o00000_ooool4o`0000Cooooo
2ol00004ooooo`Co00002Oooool2o`0007;ooooo000Looooo`03o`000?oooooooooo06kooooo0_l0
0003ooooo`Ko000000?oooooo`000?l000001_l0000:ooooo`?o00002Oooool2o`0000Cooooo0_l0
00000ooooooo0000o`00000:ooooo`;o00000_ooool4o`0000;ooooo3Ol00005ooooo`;o00003?oo
ool3o`0006oooooo000Looooo`03o`000?oooooooooo06kooooo0_l00003ooooo`;o00000_ooool;
o`0000_ooooo0_l00009ooooo`;o00001?ooool2o`000003ooooool0003o000000Oooooo0_l00007
ooooo`?o000000?oooooo`000?l000003Ol0000Aooooo`?o0000Koooool001cooooo00?o0000oooo
ooooool0Koooool2o`000004ooooool0003o0000ooooo`ko00003oooool2o`0001Kooooo0_l00007
ooooo`?o000000?oooooo`000?l000003Ol00004ooooo`;o00000oooool4o`0000Gooooo0_l0001_
ooooo`007?ooool00ol0003oooooooooo`1_ooooo`;o000000?oooooo`000?l000001?l000000ooo
oooo0000o`000009o`0000Wooooo0_l000000ooooooo0000o`000002o`0002Oooooo2ol00004oooo
o`;o00000oooool4o`0000Gooooo0_l000000ooooooo0000o`00001/ooooo`007?ooool00ol0003o
ooooooooo`1cooooo`;o000000Coooooo`000?l0003ooooo2ol00009ooooo`;o000000?oooooo`00
0?l000001Oooool2o`0000Oooooo0_l00005ooooo`;o00001_ooool2o`0000Kooooo4?l00008oooo
o`;o00002_ooool3o`0006_ooooo000Looooo`03o`000?oooooooooo07Kooooo3ol00003ooooo`;o
00001_ooool2o`0000Gooooo0_l00005ooooo`Co00001Oooool2o`0000Kooooo0_l00006oooooa3o
00000oooool2o`0000?ooooo0_l0000;ooooo`;o0000Joooool001cooooo0_l0001iooooo`;o0000
00?oooooo`000?l000002?l00003ooooo`;o00000_ooool2o`0000;ooooo0_l00002ooooo`;o0000
2?ooool3o`0001Sooooo4?l000000ooooooo0000o`00000?ooooo`;o0000K?ooool001cooooo00?o
0000ooooooooool0N?ooool@o`0000;ooooo1?l00005ooooo`?o00001_ooool2o`000004ooooool0
003o0000o`0000Wooooo0_l0000=oooooa3o00004Oooool2o`0006cooooo000Looooo`03o`000?oo
oooooooo07Oooooo4Ol00002ooooo`;o00001_ooool3o`0000Oooooo0_l00002ooooo`;o00001_oo
ool2o`000003ooooool0003o000000gooooo4Ol00007ooooo`;o000000?oooooo`000?l000001Ooo
ool2o`0006_ooooo000Looooo`03o`000?oooooooooo07Oooooo4Ol0000:ooooo`Co00001?ooool3
o`0000_ooooo0ol00003ooooo`;o00002_oooolAo`0000?ooooo0_l000001Ooooooo0000o`000?l0
003ooooo00;o000000?oooooo`000?l000000_ooool2o`0006_ooooo000Looooo`03o`000?oooooo
oooo07_ooooo3Ol00002ooooo`?o00001?ooool2o`000003ooooool0003o000000Cooooo1Ol00004
ooooo`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00002OoooolBo`0000?ooooo0_l0
00001?oooooo0000o`000?ooool2o`0000;ooooo0_l00006ooooo`?o0000I_ooool001cooooo00?o
0000ooooooooool0Noooool2o`000003ooooool0003o000000Oo000000?oooooo`000?l000001?l0
0002ooooo`?o00002_ooool2o`0000Cooooo0_l000000ooooooo0000o`000005ooooo`;o00002_oo
oolDo`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000Gooooo1?l0001Vooooo`007?ooool0
0ol0003oooooooooo`1nooooo`So000000?oooooo`000?l000001Ol00002ooooo`?o00001?ooool4
o`0000Oooooo0_l00009ooooo`;o00002_oooolDo`0000;ooooo0_l00009ooooo`;o00000oooool5
o`0006Gooooo000Looooo`03o`000?oooooooooo07kooooo2ol00002ooooo`Go00001oooool4o`00
00Oooooo0_l000000ooooooo0000o`000003ooooo`Co00003?oooolCo`0000;ooooo0ol00008oooo
o`Go00000oooool3o`0006Cooooo000Looooo`03o`000?oooooooooo07kooooo0_l00002ooooo`Oo
00000_ooool5o`0000Oooooo0_l0000;ooooo`?o00000oooool4o`0000cooooo4ol00003ooooo`;o
00000oooool2o`0000?ooooo1Ol00004ooooo`;o0000I?ooool001cooooo00?o0000ooooooooool0
POooool8o`000003ooooool0003o000000?o00001_ooool2o`0000gooooo0_l00006ooooo`;o0000
3_oooolAo`0000;ooooo0_l00004ooooo`;o00000oooool2o`0000Sooooo0_l0001Sooooo`007?oo
ool00ol0003oooooooooo`21oooooa3o00001?ooool2o`00013ooooo0_l000001?oooooo0000o`00
0?l0000@oooooaCo00000oooool4o`0000;ooooo0_l00008ooooo`;o0000Hoooool001cooooo00?o
0000ooooooooool0P?oooolBo`000003ooooool0003o000000_ooooo0_l00003ooooo`Co000000Co
ooooo`000?l0003o00004OoooolBo`0000Cooooo1?l0001aooooo`007?ooool00ol0003ooooooooo
o`20ooooo`co00000_ooool4o`000004ooooool0003o0000ooooo`Co00001_ooool2o`000003oooo
ool0003o000000;o00001?ooool2o`00017ooooo4_l00004ooooo`;o000000?oooooo`000?l00000
1_ooool2o`0006Sooooo000Looooo`03o`000?oooooooooo07oooooo3Ol00002ooooo`;o00001_oo
ool6o`0000Oooooo0_l00002ooooo`Co00005?ooool<o`0000Sooooo0ol000000ooooooo0000o`00
0006ooooo`;o000000?oooooo`000?l00000IOooool001cooooo00?o0000ooooooooool0Ooooool>
o`000003ooooool0003o000000Co00001_ooool2o`000003ooooool0003o000000Sooooo1?l0000E
ooooo`co00001oooool3o`0000Oooooo0_l00002ooooo`?o0000IOooool001cooooo00?o0000oooo
ooooool0O_oooolFo`0000Gooooo0_l00002ooooo`;o00002_ooool2o`0001Oooooo2_l00003oooo
o`;o00000oooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o0000
06Kooooo000Looooo`;o0000OooooolBo`0000;ooooo0_l00005ooooo`;o00000_ooool2o`0000So
oooo1?l0000Gooooo`So00001Oooool2o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l0
00000_l0001Yooooo`007?ooool00ol0003oooooooooo`1noooooa7o00000oooool2o`00013ooooo
0_l000000ooooooo0000o`000002o`0001Sooooo2ol00009ooooo`;o0000L?ooool001cooooo00?o
0000ooooooooool0Ooooool@o`0000_ooooo0_l00002ooooo`;o00001?ooool2o`000003ooooool0
003o000001cooooo2_l00004ooooo`Ko00001Oooool2o`0006Wooooo000Looooo`03o`000?oooooo
oooo07oooooo4?l00003ooooo`;o00001_ooool2o`000003ooooool0003o000000Co00008_ooool<
o`0000;ooooo1?l00007ooooo`;o0000JOooool001cooooo00?o0000ooooooooool0Ooooool@o`00
00?ooooo0_l00009ooooo`Ko00001?ooool3o`0001gooooo2ol0001gooooo`007?ooool00ol0003o
ooooooooo`1oooooo`oo00002oooool2o`0000Cooooo1?l00004ooooo`?o00007Oooool?o`0000Ko
oooo0_l00002ooooo`;o0000Ioooool001cooooo00?o0000ooooooooool0P?ooool?o`000003oooo
ool0003o000000?ooooo0_l000001?oooooo0000o`000?l0000;ooooo`?o00007_oooolAo`0000Co
oooo0_l00002ooooo`;o0000Ioooool001cooooo00?o0000ooooooooool0P?ooool<o`000003oooo
ool0003o000000?o00000oooool5o`0000_ooooo1?l0000Poooooa;o0000K_ooool001cooooo00?o
0000ooooooooool0P?oooolBo`0000Cooooo0_l00007ooooo`;o00001?ooool4o`00027ooooo3Ol0
00001Ooooooo0000o`000?l0003ooooo00Co0000JOooool001cooooo00?o0000ooooooooool0P?oo
oolDo`0000_ooooo0_l00006ooooo`;o00008oooool;o`000003ooooool0003o000000Ko0000JOoo
ool001cooooo00?o0000ooooooooool0P?oooolAo`000003ooooool0003o000000;ooooo0_l00005
ooooo`;o0000;_ooool3o`000003ooooool0003o000000[o0000K?ooool001cooooo00?o0000oooo
ooooool0P?oooolBo`0000Cooooo0_l00005ooooo`;o00001_ooool2o`0002_ooooo2_l0001]oooo
o`007?ooool00ol0003oooooooooo`21oooooa7o00002oooool2o`0000Kooooo0ol0002Qooooo`00
7?ooool00ol0003oooooooooo`24oooooa3o000000?oooooo`000?l000003?ooool5o`000:7ooooo
000Looooo`03o`000?oooooooooo08Cooooo4ol0000<ooooo`Co0000X_ooool001cooooo00?o0000
ooooooooool0Q?ooool:o`000003ooooool0003o000000Go00003?ooool5o`000:;ooooo000Loooo
o`;o0000Q?ooool;o`0000Cooooo1?l00003ooooo`;o00001oooool4o`000:?ooooo000Looooo`03
o`000?oooooooooo08?ooooo3Ol00004ooooo`;o00000oooool2o`0000?ooooo1ol0002Tooooo`00
7?ooool00ol0003oooooooooo`25ooooo`_o00000_ooool5o`0000Kooooo1ol0002Uooooo`007?oo
ool00ol0003oooooooooo`26ooooo`[o00000_ooool7o`0000;ooooo1Ol000001?oooooo0000o`00
0?l0002Uooooo`007?ooool00ol0003oooooooooo`27ooooo`Go000000Coooooo`000?l0003o0000
0_ooool8o`000005ooooool0003o0000o`000?ooool01?l0002Vooooo`007?ooool00ol0003ooooo
ooooo`2:ooooo`;o000000Coooooo`000?l0003o00000oooool3o`0000;ooooo0_l000000ooooooo
0000o`000004o`000:Sooooo000Looooo`03o`000?oooooooooo08[ooooo2?l00008ooooo`Ko0000
ZOooool001cooooo00?o0000ooooooooool0ROooool9o`0000Oooooo1?l0002/ooooo`007?ooool0
0ol0003oooooooooo`29ooooo`So00001_ooool6o`000:cooooo000Looooo`03o`000?oooooooooo
08[ooooo1ol000000ooooooo0000o`000002o`000003ooooool0003o000000;o0000[_ooool001co
oooo00?o0000ooooooooool0SOooool9o`000003ooooool0003o000000;o0000[_ooool001cooooo
00?o0000ooooooooool0S_ooool5o`000003ooooool0003o000000;o0000/Oooool001cooooo00?o
0000ooooooooool0U?ooool4o`000;7ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
0006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Q
olc<c006ooooo`03o`000?oooooooooo0?ooooooB_ooool00006oooooomgMgOoV9RHoooooonHV9So
MgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo
0?ooooooB_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooom:ooooo`0000?oooooo`000?oo
ool00_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`00
0?ooooooB_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Oo<c<co
0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom:ooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0
003oooooooooo`3ooooood[ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000
okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0?ooooooB_ooool00006ooooooo^k^ko
<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`00
0?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom:
ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool001Co
oooo00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o0000ooooooooool0
oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooo
oooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`004_ooool00omEEEGo
IVIVo`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Uoooo
o`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05_ooool4o`000008oa0@4?oooooo
ooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0T?ooool00:Ko
oooo00Go0000ooooooooooooooooo`000009ooooo`Ko00003?ooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OlQ8B7oV9RHoooooonHV9So8B4Q093ooooo002V
ooooo`05o`000?ooooooooooooooool000006oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41000oooool01Ol0003ooooooooooooooooo0000093ooooo002Vooooo`05o`00
0?ooooooooooooooool000002Oooool6o`0000cooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P2@ooooo`00Y_ooool01Ol0
003oQhN7oooooonYZJWo000001_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Goc<c<o`000?l0003o0000olc<c02@ooooo`00YOooool00ol@413o0000ogMg
M`02o`000003oiRHV?oooooooooo01Wooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@00?ooooo00Go410@okZj^_oooooo^[Zjoa0@402@ooooo`00a_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Ol0003o^[Zjoooooonj^[[o0000
093ooooo0034ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`05ojVYZOl@413o0000oa0@4?nYZJT0T?ooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(114) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.39255 .73939 Mdot
.38997 .66943 Mdot
.67386 .55253 Mdot
.43288 .41392 Mdot
.61844 .25397 Mdot
.67873 .545 Mdot
.59372 .66269 Mdot
.60245 .69182 Mdot
.71714 .54383 Mdot
.45905 .3826 Mdot
.57532 .66374 Mdot
.30423 .38971 Mdot
.59928 .66956 Mdot
.37863 .42977 Mdot
.31737 .32734 Mdot
.28542 .52165 Mdot
.37916 .7083 Mdot
.61726 .24647 Mdot
.28175 .50722 Mdot
.71167 .54787 Mdot
.576 .23006 Mdot
.40412 .42464 Mdot
.38911 .7241 Mdot
.37737 .42866 Mdot
.28128 .51092 Mdot
.39782 .65408 Mdot
.39806 .7363 Mdot
.27371 .52017 Mdot
.30309 .39481 Mdot
.58824 .63712 Mdot
.26081 .52654 Mdot
.39877 .29741 Mdot
.61994 .41246 Mdot
.35628 .59995 Mdot
.57678 .71231 Mdot
.56776 .67127 Mdot
.71918 .53424 Mdot
.57594 .64828 Mdot
.60384 .64878 Mdot
.57458 .69932 Mdot
.57322 .69729 Mdot
.40029 .65818 Mdot
.56996 .69703 Mdot
.65889 .73572 Mdot
.37216 .41122 Mdot
.3225 .57498 Mdot
.71015 .55432 Mdot
.33443 .42906 Mdot
.37759 .72454 Mdot
.76602 .51466 Mdot
.46012 .33977 Mdot
.59124 .70341 Mdot
.6043 .3895 Mdot
.29637 .56887 Mdot
.60345 .66833 Mdot
.27926 .50771 Mdot
.66829 .5311 Mdot
.3888 .41251 Mdot
.29414 .39327 Mdot
.35128 .58891 Mdot
.41031 .40974 Mdot
.60082 .25497 Mdot
.42702 .69101 Mdot
.65325 .5417 Mdot
.68032 .55849 Mdot
.58101 .63759 Mdot
.38273 .65718 Mdot
.59518 .72566 Mdot
.43451 .42234 Mdot
.73591 .54085 Mdot
.33512 .42521 Mdot
.57512 .66358 Mdot
.39417 .63433 Mdot
.4086 .43376 Mdot
.3814 .73916 Mdot
.59745 .73387 Mdot
.61944 .25013 Mdot
.37955 .62038 Mdot
.76376 .51534 Mdot
.32161 .47495 Mdot
.41282 .42547 Mdot
.47032 .76368 Mdot
.27195 .40525 Mdot
.41121 .66339 Mdot
.35561 .42847 Mdot
.42637 .78159 Mdot
.38304 .39566 Mdot
.26811 .53174 Mdot
.27604 .51545 Mdot
.27351 .38636 Mdot
.68114 .51351 Mdot
.39829 .71001 Mdot
.39305 .42568 Mdot
.43869 .42002 Mdot
.46219 .38755 Mdot
.36395 .44174 Mdot
.27597 .51174 Mdot
.62205 .37768 Mdot
.57823 .69972 Mdot
.58862 .39343 Mdot
.60251 .73559 Mdot
.60058 .37959 Mdot
.3348 .41666 Mdot
.70324 .52905 Mdot
.4136 .70826 Mdot
.62489 .38943 Mdot
.58906 .7244 Mdot
.38941 .42767 Mdot
.56874 .66141 Mdot
.39506 .71856 Mdot
.2593 .516 Mdot
.59114 .27717 Mdot
.60811 .21885 Mdot
.38831 .64582 Mdot
.37063 .51054 Mdot
.4091 .39982 Mdot
.41233 .4166 Mdot
.39286 .66539 Mdot
.6922 .55697 Mdot
.66256 .59645 Mdot
.39369 .69739 Mdot
.57502 .68908 Mdot
.37735 .70717 Mdot
.61489 .42059 Mdot
.68746 .55782 Mdot
.58854 .41182 Mdot
.61571 .3718 Mdot
.42091 .30889 Mdot
.39929 .4467 Mdot
.62604 .41527 Mdot
.70879 .52641 Mdot
.39426 .69112 Mdot
.5972 .68141 Mdot
.44232 .41632 Mdot
.40867 .65938 Mdot
.60338 .66135 Mdot
.57868 .29529 Mdot
.57411 .29195 Mdot
.39632 .64053 Mdot
.38298 .51115 Mdot
.5746 .64678 Mdot
.60853 .68917 Mdot
.45799 .34075 Mdot
.40673 .6475 Mdot
.61022 .28774 Mdot
.6085 .67847 Mdot
.66276 .45628 Mdot
.26169 .50866 Mdot
.442 .30925 Mdot
.47854 .75293 Mdot
.45974 .34077 Mdot
.56798 .24413 Mdot
.59973 .25955 Mdot
.60445 .66337 Mdot
.42243 .39478 Mdot
.38234 .67891 Mdot
.40456 .65055 Mdot
.31897 .40389 Mdot
.62496 .39757 Mdot
.397 .40216 Mdot
.58894 .38482 Mdot
.61691 .3714 Mdot
.38123 .42736 Mdot
.33407 .57982 Mdot
.40876 .70664 Mdot
.36455 .40555 Mdot
.72556 .53203 Mdot
.61542 .23958 Mdot
.56945 .66783 Mdot
.35941 .42985 Mdot
.4546 .40972 Mdot
.32482 .39889 Mdot
.60747 .69583 Mdot
.62107 .75455 Mdot
.78088 .5184 Mdot
.58099 .65615 Mdot
.59721 .74317 Mdot
.6906 .52035 Mdot
.30818 .40241 Mdot
.59488 .27284 Mdot
.6093 .40213 Mdot
.37441 .40267 Mdot
.4629 .34008 Mdot
.27818 .38476 Mdot
.58212 .23058 Mdot
.56536 .25828 Mdot
.46059 .76095 Mdot
.61172 .75555 Mdot
.42859 .40389 Mdot
.24845 .52505 Mdot
.45291 .32601 Mdot
.57662 .62747 Mdot
.59371 .68508 Mdot
.68425 .56353 Mdot
.69453 .55727 Mdot
.7843 .51165 Mdot
.33971 .38931 Mdot
.31168 .38666 Mdot
.42157 .42481 Mdot
.59583 .39375 Mdot
.42589 .68457 Mdot
.60117 .25863 Mdot
.37948 .69197 Mdot
.47297 .76166 Mdot
.33067 .46696 Mdot
.28111 .50119 Mdot
.7441 .5035 Mdot
.65332 .53008 Mdot
.614 .37939 Mdot
.60801 .27359 Mdot
.39666 .40694 Mdot
.40224 .71714 Mdot
.45562 .33307 Mdot
.60737 .41942 Mdot
.5893 .20272 Mdot
.38834 .70896 Mdot
.32945 .44662 Mdot
.60037 .66386 Mdot
.69704 .51306 Mdot
.38205 .39597 Mdot
.39153 .43431 Mdot
.38153 .62354 Mdot
.43697 .40726 Mdot
.26134 .50035 Mdot
.26308 .51603 Mdot
.7765 .51522 Mdot
.60207 .74191 Mdot
.58528 .6537 Mdot
.70827 .55564 Mdot
.39144 .63868 Mdot
.32641 .59076 Mdot
.68672 .5321 Mdot
.58303 .22521 Mdot
.5756 .65647 Mdot
.58852 .30042 Mdot
.69266 .53348 Mdot
.61751 .25368 Mdot
.28824 .39062 Mdot
.71694 .51853 Mdot
.58452 .27767 Mdot
.34603 .33788 Mdot
.61971 .38059 Mdot
.59659 .32452 Mdot
.59171 .6618 Mdot
.37084 .69497 Mdot
.37751 .40115 Mdot
.60627 .39513 Mdot
.589 .41802 Mdot
.30187 .40455 Mdot
.59171 .37325 Mdot
.61806 .40905 Mdot
.30571 .40499 Mdot
.60748 .24365 Mdot
.50389 .70334 Mdot
.2597 .52456 Mdot
.37822 .70411 Mdot
.43598 .40822 Mdot
.60464 .74574 Mdot
.60366 .66032 Mdot
.40402 .40701 Mdot
.45738 .77167 Mdot
.58933 .66249 Mdot
.39038 .41897 Mdot
.59955 .64346 Mdot
.41029 .66297 Mdot
.32909 .4651 Mdot
.39832 .63651 Mdot
.37986 .42573 Mdot
.59905 .64246 Mdot
.71408 .55155 Mdot
.39768 .6526 Mdot
.39686 .42637 Mdot
.42675 .42359 Mdot
.59839 .39338 Mdot
.26213 .51355 Mdot
.60912 .70968 Mdot
.30667 .39148 Mdot
.66104 .52846 Mdot
.31724 .4066 Mdot
.56951 .27986 Mdot
.68687 .45507 Mdot
.40621 .64631 Mdot
.59284 .37156 Mdot
.68014 .53858 Mdot
.46346 .36517 Mdot
.33237 .45421 Mdot
.36908 .41419 Mdot
.61364 .41187 Mdot
.27303 .40956 Mdot
.58164 .67561 Mdot
.25996 .50476 Mdot
.60222 .43083 Mdot
.66672 .53485 Mdot
.59711 .38311 Mdot
.35752 .43682 Mdot
.39277 .72393 Mdot
.285 .5136 Mdot
.69046 .51742 Mdot
.3845 .7162 Mdot
.34481 .41745 Mdot
.60194 .7338 Mdot
.63567 .38143 Mdot
.58048 .68035 Mdot
.27179 .52569 Mdot
.31374 .4074 Mdot
.73835 .53832 Mdot
.40224 .65948 Mdot
.60448 .6787 Mdot
.3961 .6357 Mdot
.46219 .35917 Mdot
.32277 .44126 Mdot
.40292 .63584 Mdot
.57356 .27829 Mdot
.80403 .50127 Mdot
.57597 .67155 Mdot
.58942 .40541 Mdot
.76365 .53087 Mdot
.38074 .72993 Mdot
.69793 .53428 Mdot
.41316 .4996 Mdot
.67584 .51637 Mdot
.28549 .50905 Mdot
.75003 .53572 Mdot
.32881 .39592 Mdot
.35737 .42036 Mdot
.64812 .55863 Mdot
.62505 .38228 Mdot
.3802 .44072 Mdot
.40909 .66256 Mdot
.38683 .29652 Mdot
.45748 .39587 Mdot
.33973 .3903 Mdot
.66925 .53266 Mdot
.3946 .51 Mdot
.26413 .52105 Mdot
.2745 .52305 Mdot
.38355 .68579 Mdot
.59381 .40657 Mdot
.58395 .30922 Mdot
.58501 .31587 Mdot
.72967 .4418 Mdot
.25805 .40308 Mdot
.36357 .50682 Mdot
.39816 .64747 Mdot
.78116 .50779 Mdot
.38268 .7469 Mdot
.60997 .4186 Mdot
.60215 .69274 Mdot
.62523 .75503 Mdot
.37339 .39822 Mdot
.6263 .42514 Mdot
.2711 .49351 Mdot
.37408 .71419 Mdot
.38961 .62876 Mdot
.60434 .68251 Mdot
.35374 .39157 Mdot
.45372 .38097 Mdot
.40833 .40284 Mdot
.6019 .6979 Mdot
.5949 .41895 Mdot
.29238 .39586 Mdot
.4171 .29643 Mdot
.66766 .74084 Mdot
.37077 .41782 Mdot
.35979 .59593 Mdot
.36104 .41389 Mdot
.42877 .3128 Mdot
.3866 .40944 Mdot
.40471 .65853 Mdot
.26801 .55355 Mdot
.44976 .42181 Mdot
.73485 .50104 Mdot
.33321 .46777 Mdot
.57933 .26993 Mdot
.39229 .43151 Mdot
.38859 .40168 Mdot
.60096 .30307 Mdot
.40505 .68632 Mdot
.42287 .44011 Mdot
.5041 .70112 Mdot
.39916 .42379 Mdot
.56903 .6697 Mdot
.2798 .40287 Mdot
.3998 .30057 Mdot
.26627 .51898 Mdot
.39096 .72483 Mdot
.60651 .6557 Mdot
.5708 .68529 Mdot
.58022 .39185 Mdot
.60375 .65991 Mdot
.35999 .42246 Mdot
.27834 .40198 Mdot
.38638 .64324 Mdot
.62042 .38328 Mdot
.39889 .70404 Mdot
.64198 .36242 Mdot
.58972 .6681 Mdot
.60424 .38252 Mdot
.35299 .38566 Mdot
.58664 .68341 Mdot
.51473 .67937 Mdot
.25865 .51754 Mdot
.59326 .41857 Mdot
.39266 .73781 Mdot
.7402 .53904 Mdot
.61165 .41568 Mdot
.60398 .66944 Mdot
.37184 .4109 Mdot
.27153 .50727 Mdot
.60571 .66478 Mdot
.36369 .59958 Mdot
.25587 .51711 Mdot
.39868 .42225 Mdot
.41047 .68624 Mdot
.39793 .68107 Mdot
.37534 .40031 Mdot
.42029 .39878 Mdot
.66825 .54317 Mdot
.60926 .41465 Mdot
.60555 .41466 Mdot
.61224 .36709 Mdot
.67705 .51756 Mdot
.80577 .50346 Mdot
.59032 .73097 Mdot
.39816 .30124 Mdot
.61294 .74582 Mdot
.60858 .39069 Mdot
.66852 .54475 Mdot
.36457 .41347 Mdot
.32619 .40601 Mdot
.60105 .64203 Mdot
.81681 .49084 Mdot
.36801 .39932 Mdot
.37769 .68627 Mdot
.5956 .70571 Mdot
.31056 .38804 Mdot
.77562 .5123 Mdot
.59207 .25547 Mdot
.36265 .50787 Mdot
.59604 .70319 Mdot
.36994 .61422 Mdot
.59588 .70265 Mdot
.38526 .40229 Mdot
.37296 .44151 Mdot
.37367 .67931 Mdot
.57898 .26972 Mdot
.31065 .39546 Mdot
.3842 .41977 Mdot
.78265 .50649 Mdot
.38424 .74849 Mdot
.5833 .31542 Mdot
.29454 .39007 Mdot
.61085 .37326 Mdot
.596 .24998 Mdot
.41562 .42837 Mdot
.31488 .40308 Mdot
.60506 .42805 Mdot
.59494 .64082 Mdot
.57514 .27935 Mdot
.74047 .50187 Mdot
.38467 .70959 Mdot
.59724 .73863 Mdot
.5777 .38902 Mdot
.57556 .673 Mdot
.38954 .35643 Mdot
.60703 .37929 Mdot
.64046 .75707 Mdot
.51218 .1633 Mdot
.61943 .40044 Mdot
.66057 .5386 Mdot
.4605 .38862 Mdot
.31394 .40111 Mdot
.39774 .42213 Mdot
.57941 .30355 Mdot
.39393 .67485 Mdot
.61225 .75474 Mdot
.58735 .64901 Mdot
.38281 .43514 Mdot
.4058 .64439 Mdot
.4488 .77137 Mdot
.59715 .3867 Mdot
.59086 .28849 Mdot
.58597 .29684 Mdot
.40278 .43794 Mdot
.27125 .41117 Mdot
.39956 .65153 Mdot
.39623 .42657 Mdot
.40741 .43815 Mdot
.7616 .52584 Mdot
.41255 .69494 Mdot
.71333 .51842 Mdot
.27743 .49936 Mdot
.32749 .483 Mdot
.60766 .74126 Mdot
.59652 .6552 Mdot
.59416 .41146 Mdot
.58371 .65616 Mdot
.77725 .52105 Mdot
.60642 .41447 Mdot
.39689 .42688 Mdot
.38639 .6427 Mdot
.39505 .42653 Mdot
.39771 .42424 Mdot
.3813 .40759 Mdot
.35785 .50516 Mdot
.71439 .50602 Mdot
.59574 .28362 Mdot
.29122 .39041 Mdot
.67985 .52026 Mdot
.74766 .50775 Mdot
.46295 .38441 Mdot
.40336 .43027 Mdot
.40686 .41579 Mdot
.37934 .62492 Mdot
.26394 .50443 Mdot
.58881 .68215 Mdot
.37326 .68078 Mdot
.3943 .3932 Mdot
.71472 .5529 Mdot
.42534 .43888 Mdot
.40239 .63577 Mdot
.58667 .72899 Mdot
.3943 .7646 Mdot
.57595 .3964 Mdot
.58402 .40911 Mdot
.61588 .41106 Mdot
.61031 .36569 Mdot
.56844 .68134 Mdot
.66841 .54626 Mdot
.62238 .35389 Mdot
.32747 .48052 Mdot
.42364 .39927 Mdot
.36842 .44027 Mdot
.76105 .5299 Mdot
.62513 .40987 Mdot
.457 .40073 Mdot
.29159 .51026 Mdot
.72579 .51457 Mdot
.62111 .37596 Mdot
.41844 .76112 Mdot
.3899 .71911 Mdot
.76693 .51699 Mdot
.57653 .64822 Mdot
.58266 .2763 Mdot
.79202 .42044 Mdot
.39798 .69799 Mdot
.42321 .70699 Mdot
.72114 .52564 Mdot
.28053 .39901 Mdot
.28159 .5659 Mdot
.69476 .53833 Mdot
.25579 .50849 Mdot
.38769 .65938 Mdot
.61881 .37701 Mdot
.27981 .41206 Mdot
.29615 .40562 Mdot
.73622 .5334 Mdot
.4274 .42547 Mdot
.63999 .56444 Mdot
.6636 .53689 Mdot
.59884 .41017 Mdot
.66976 .53251 Mdot
.58266 .66816 Mdot
.70157 .5241 Mdot
.36469 .60212 Mdot
.43035 .43049 Mdot
.29498 .56862 Mdot
.31254 .32265 Mdot
.41262 .39949 Mdot
.58567 .69501 Mdot
.59775 .74015 Mdot
.42065 .40792 Mdot
.61839 .26562 Mdot
.66132 .54162 Mdot
.78741 .51326 Mdot
.2723 .50419 Mdot
.7515 .53415 Mdot
.39241 .72514 Mdot
.60078 .73963 Mdot
.59905 .74124 Mdot
.61283 .41431 Mdot
.4082 .65249 Mdot
.5914 .74111 Mdot
.57525 .69137 Mdot
.63648 .3893 Mdot
.37817 .40015 Mdot
.4071 .70524 Mdot
.29222 .39622 Mdot
.61547 .2417 Mdot
.40129 .42338 Mdot
.71001 .51876 Mdot
.78004 .51588 Mdot
.31652 .32465 Mdot
.68339 .5329 Mdot
.59165 .4094 Mdot
.40996 .69887 Mdot
.27804 .50483 Mdot
.3959 .68872 Mdot
.43913 .41564 Mdot
.60327 .74342 Mdot
.38952 .7209 Mdot
.58167 .22673 Mdot
.40441 .41097 Mdot
.33203 .57794 Mdot
.28806 .38734 Mdot
.40047 .42184 Mdot
.67483 .56141 Mdot
.60408 .29891 Mdot
.5916 .24444 Mdot
.73297 .50528 Mdot
.61119 .25675 Mdot
.39932 .74639 Mdot
.68047 .56063 Mdot
.60253 .29086 Mdot
.73282 .44172 Mdot
.59578 .36891 Mdot
.60003 .28522 Mdot
.35605 .42812 Mdot
.60411 .65696 Mdot
.37848 .66606 Mdot
.37282 .43914 Mdot
.46645 .43847 Mdot
.24337 .54448 Mdot
.5988 .39036 Mdot
.40139 .41957 Mdot
.39218 .40041 Mdot
.40397 .64282 Mdot
.47966 .75454 Mdot
.65701 .53779 Mdot
.58804 .39924 Mdot
.39607 .69852 Mdot
.46911 .76482 Mdot
.67432 .56026 Mdot
.59444 .30196 Mdot
.59334 .64867 Mdot
.37232 .62432 Mdot
.60253 .3918 Mdot
.59276 .66203 Mdot
.72851 .50617 Mdot
.46216 .34615 Mdot
.27249 .53666 Mdot
.70945 .53566 Mdot
.46034 .34079 Mdot
.27717 .4963 Mdot
.78367 .51111 Mdot
.57505 .62881 Mdot
.39586 .71689 Mdot
.60682 .67522 Mdot
.58609 .28911 Mdot
.39382 .63217 Mdot
.39861 .70496 Mdot
.59595 .65475 Mdot
.25617 .55712 Mdot
.28445 .41457 Mdot
.59559 .73196 Mdot
.27666 .39431 Mdot
.45945 .34391 Mdot
.60199 .39492 Mdot
.59524 .2772 Mdot
.60226 .74159 Mdot
.39986 .65783 Mdot
.62348 .74241 Mdot
.46142 .3383 Mdot
.25874 .50821 Mdot
.58372 .27191 Mdot
.45271 .76506 Mdot
.5803 .631 Mdot
.58868 .67847 Mdot
.7831 .50654 Mdot
.61574 .27697 Mdot
.35643 .42295 Mdot
.82145 .48731 Mdot
.36178 .42984 Mdot
.60254 .70917 Mdot
.27007 .49403 Mdot
.38501 .70084 Mdot
.59528 .72792 Mdot
.28443 .50311 Mdot
.3038 .39121 Mdot
.42405 .40418 Mdot
.77436 .51643 Mdot
.37811 .65604 Mdot
.62086 .36251 Mdot
.40832 .39887 Mdot
.38592 .41764 Mdot
.58954 .41951 Mdot
.40306 .30212 Mdot
.55614 .62763 Mdot
.62449 .40358 Mdot
.72505 .51844 Mdot
.6213 .38416 Mdot
.59098 .40318 Mdot
.39254 .73307 Mdot
.7837 .50861 Mdot
.58489 .41451 Mdot
.37596 .42305 Mdot
.38679 .42576 Mdot
.60508 .6503 Mdot
.27533 .41069 Mdot
.29268 .40296 Mdot
.65971 .53015 Mdot
.63534 .40656 Mdot
.40495 .44364 Mdot
.41075 .66252 Mdot
.57502 .29969 Mdot
.58095 .39737 Mdot
.38194 .70863 Mdot
.37041 .44437 Mdot
.76101 .52653 Mdot
.61991 .39388 Mdot
.58278 .4192 Mdot
.58571 .27414 Mdot
.60874 .69306 Mdot
.38145 .60695 Mdot
.6623 .53791 Mdot
.2703 .53472 Mdot
.64434 .41252 Mdot
.761 .52177 Mdot
.60088 .39648 Mdot
.60563 .37596 Mdot
.40674 .6506 Mdot
.36775 .60206 Mdot
.57614 .41964 Mdot
.67522 .52094 Mdot
.65527 .75874 Mdot
.58304 .70728 Mdot
.31315 .40638 Mdot
.5864 .65616 Mdot
.39586 .71795 Mdot
.42005 .30728 Mdot
.58904 .29914 Mdot
.58623 .67984 Mdot
.6182 .41049 Mdot
.39538 .71252 Mdot
.38213 .61258 Mdot
.37773 .4261 Mdot
.40399 .42648 Mdot
.70923 .55475 Mdot
.44576 .31685 Mdot
.60367 .64482 Mdot
.58531 .30877 Mdot
.66536 .55195 Mdot
.27306 .5061 Mdot
.38126 .68053 Mdot
.5778 .33371 Mdot
.28374 .38525 Mdot
.67664 .52304 Mdot
.38877 .6687 Mdot
.58773 .31568 Mdot
.59629 .28475 Mdot
.39551 .39643 Mdot
.5655 .25005 Mdot
.58475 .67429 Mdot
.40758 .65906 Mdot
.39631 .75351 Mdot
.30333 .39746 Mdot
.40056 .42951 Mdot
.26405 .50095 Mdot
.58941 .7382 Mdot
.35714 .42824 Mdot
.57839 .28079 Mdot
.38542 .65685 Mdot
.36215 .41612 Mdot
.61117 .29147 Mdot
.62211 .36382 Mdot
.61267 .38088 Mdot
.64939 .56195 Mdot
.59763 .31445 Mdot
.60806 .29646 Mdot
.6131 .28818 Mdot
.62553 .7551 Mdot
.30984 .38857 Mdot
.64578 .3859 Mdot
.42625 .4261 Mdot
.45939 .34537 Mdot
.26372 .53667 Mdot
.58256 .70192 Mdot
.73973 .53651 Mdot
.39429 .40407 Mdot
.42556 .425 Mdot
.36925 .69014 Mdot
.28617 .52181 Mdot
.36191 .40794 Mdot
.38142 .69668 Mdot
.40978 .73817 Mdot
.67065 .56709 Mdot
.47735 .75315 Mdot
.82752 .4732 Mdot
.28145 .38907 Mdot
.27067 .39375 Mdot
.40365 .69386 Mdot
.59857 .64741 Mdot
.27344 .39274 Mdot
.60741 .69746 Mdot
.39809 .67312 Mdot
.2824 .5319 Mdot
.36356 .60003 Mdot
.60017 .2544 Mdot
.38376 .40297 Mdot
.59193 .65688 Mdot
.39035 .40237 Mdot
.59313 .65389 Mdot
.39402 .51292 Mdot
.2677 .40329 Mdot
.42785 .39992 Mdot
.35707 .43948 Mdot
.5739 .23238 Mdot
.40419 .42846 Mdot
.78497 .50487 Mdot
.38602 .67775 Mdot
.62839 .41682 Mdot
.27081 .54205 Mdot
.45859 .39634 Mdot
.40731 .41701 Mdot
.24005 .53669 Mdot
.4146 .41607 Mdot
.81784 .49446 Mdot
.28173 .38746 Mdot
.36719 .40539 Mdot
.59501 .68858 Mdot
.57385 .6711 Mdot
.38054 .63563 Mdot
.60494 .37709 Mdot
.45668 .76351 Mdot
.38959 .41994 Mdot
.65434 .55649 Mdot
.60218 .23182 Mdot
.60202 .30547 Mdot
.38191 .66544 Mdot
.50524 .1651 Mdot
.56922 .69159 Mdot
.7316 .52842 Mdot
.25921 .52589 Mdot
.71983 .51777 Mdot
.65528 .53701 Mdot
.38983 .75481 Mdot
.59516 .27875 Mdot
.43047 .43558 Mdot
.3542 .59105 Mdot
.41592 .73381 Mdot
.30479 .39853 Mdot
.66665 .56598 Mdot
.60465 .42799 Mdot
.24698 .4346 Mdot
.61217 .24495 Mdot
.61245 .26663 Mdot
.6001 .66094 Mdot
.65333 .55698 Mdot
.58889 .39979 Mdot
.59822 .29576 Mdot
.67859 .56499 Mdot
.58708 .37647 Mdot
.79476 .50647 Mdot
.40089 .65173 Mdot
.39926 .5073 Mdot
.31948 .57529 Mdot
.5795 .68537 Mdot
.77419 .51065 Mdot
.38888 .63624 Mdot
.40711 .64375 Mdot
.59396 .39738 Mdot
.73534 .51764 Mdot
.41767 .66288 Mdot
.38359 .39987 Mdot
.61728 .37934 Mdot
.38071 .43751 Mdot
.6194 .24683 Mdot
.39016 .42257 Mdot
.71982 .54862 Mdot
.59038 .69167 Mdot
.66938 .53849 Mdot
.59794 .65945 Mdot
.39367 .2992 Mdot
.396 .41317 Mdot
.39475 .43038 Mdot
.28074 .40274 Mdot
.4002 .72657 Mdot
.35553 .59454 Mdot
.67322 .52632 Mdot
.66866 .53673 Mdot
.27178 .5414 Mdot
.37579 .70149 Mdot
.57019 .40261 Mdot
.27553 .39308 Mdot
.41668 .41748 Mdot
.38664 .67948 Mdot
.25947 .53588 Mdot
.64606 .76178 Mdot
.2784 .40793 Mdot
.39452 .72958 Mdot
.80502 .50531 Mdot
.41113 .43826 Mdot
.58567 .39641 Mdot
.63257 .40178 Mdot
.25793 .40025 Mdot
.61642 .24338 Mdot
.3871 .7102 Mdot
.58881 .38854 Mdot
.38241 .67415 Mdot
.6728 .51748 Mdot
.57577 .71842 Mdot
.38446 .69168 Mdot
.41099 .41431 Mdot
.82704 .47224 Mdot
.6025 .65339 Mdot
.37124 .40842 Mdot
.59304 .72715 Mdot
.3868 .62721 Mdot
.39259 .68809 Mdot
.58651 .37709 Mdot
.25638 .5082 Mdot
.58494 .67746 Mdot
.42016 .39546 Mdot
.3612 .60008 Mdot
.28513 .51407 Mdot
.61427 .24011 Mdot
.40006 .44484 Mdot
.33107 .42468 Mdot
.78957 .50292 Mdot
.46558 .36539 Mdot
.60324 .74745 Mdot
.56903 .66409 Mdot
.62009 .75779 Mdot
.40038 .73118 Mdot
.58327 .25124 Mdot
.38182 .60935 Mdot
.5936 .41266 Mdot
.73352 .52253 Mdot
.38004 .40701 Mdot
.61009 .36416 Mdot
.59418 .73499 Mdot
.60255 .27829 Mdot
.27825 .38485 Mdot
.70219 .54173 Mdot
.59837 .37181 Mdot
.58922 .672 Mdot
.40095 .6618 Mdot
.38303 .70392 Mdot
.79892 .50778 Mdot
.3629 .4138 Mdot
.4014 .42651 Mdot
.58306 .7199 Mdot
.5612 .26592 Mdot
.6127 .25729 Mdot
.62518 .38275 Mdot
.58523 .72214 Mdot
.27617 .40712 Mdot
.38188 .62095 Mdot
.38088 .4022 Mdot
.27555 .40185 Mdot
.61719 .75409 Mdot
.4205 .74646 Mdot
.60831 .25907 Mdot
.31958 .45108 Mdot
.38799 .70966 Mdot
.59835 .68145 Mdot
.73033 .44477 Mdot
.26933 .49765 Mdot
.42898 .41412 Mdot
.3277 .45746 Mdot
.30618 .40668 Mdot
.26511 .53048 Mdot
.57663 .39324 Mdot
.32775 .43927 Mdot
.26897 .54192 Mdot
.27834 .531 Mdot
.38276 .44421 Mdot
.38738 .44513 Mdot
.38921 .68376 Mdot
.33819 .39097 Mdot
.71161 .52211 Mdot
.2533 .51087 Mdot
.572 .32567 Mdot
.26063 .52239 Mdot
.32086 .40461 Mdot
.42105 .75143 Mdot
.27189 .41992 Mdot
.38962 .65712 Mdot
.38201 .73089 Mdot
.57887 .68077 Mdot
.28501 .51145 Mdot
.67514 .52336 Mdot
.59147 .42758 Mdot
.74765 .53098 Mdot
.38925 .68078 Mdot
.67513 .56538 Mdot
.58123 .63793 Mdot
.70952 .53576 Mdot
.72291 .51489 Mdot
.59072 .69445 Mdot
.37454 .67165 Mdot
.28708 .38576 Mdot
.58986 .69503 Mdot
.58716 .42132 Mdot
.59324 .30129 Mdot
.4145 .73204 Mdot
.62637 .3913 Mdot
.34958 .40739 Mdot
.65593 .75188 Mdot
.7179 .53459 Mdot
.32999 .46382 Mdot
.37463 .71937 Mdot
.59331 .32195 Mdot
.38627 .69374 Mdot
.57208 .41524 Mdot
.59743 .25774 Mdot
.35429 .42993 Mdot
.56588 .31849 Mdot
.57474 .62747 Mdot
.44909 .41803 Mdot
.40887 .7397 Mdot
.74983 .52915 Mdot
.58192 .68492 Mdot
.5185 .67228 Mdot
.58728 .39627 Mdot
.3879 .72684 Mdot
.37087 .60197 Mdot
.60113 .4141 Mdot
.59666 .68146 Mdot
.34103 .57911 Mdot
.39549 .39777 Mdot
.58133 .66503 Mdot
.40604 .44391 Mdot
.3781 .51095 Mdot
.57118 .29452 Mdot
.61333 .36789 Mdot
.28714 .52179 Mdot
.68269 .55729 Mdot
.27514 .53964 Mdot
.41452 .38925 Mdot
.42824 .30533 Mdot
.42342 .42017 Mdot
.3307 .46199 Mdot
.77801 .52167 Mdot
.38993 .64865 Mdot
.61468 .394 Mdot
.60015 .39396 Mdot
.2866 .5091 Mdot
.83089 .4224 Mdot
.60555 .28137 Mdot
.79959 .50453 Mdot
.39448 .41465 Mdot
.41235 .42444 Mdot
.38058 .61439 Mdot
.40605 .50654 Mdot
.61912 .37585 Mdot
.42581 .41486 Mdot
.25908 .4073 Mdot
.59955 .6887 Mdot
.3364 .41921 Mdot
.39987 .43801 Mdot
.59755 .74658 Mdot
.5963 .68665 Mdot
.76624 .52086 Mdot
.59512 .3687 Mdot
.6483 .5623 Mdot
.6128 .24968 Mdot
.32769 .44759 Mdot
.41 .30315 Mdot
.29407 .41252 Mdot
.6085 .25204 Mdot
.26332 .51909 Mdot
.36958 .39778 Mdot
.43148 .42635 Mdot
.61158 .26944 Mdot
.59102 .63766 Mdot
.38624 .68342 Mdot
.38638 .51094 Mdot
.59856 .39536 Mdot
.27533 .5321 Mdot
.62085 .25284 Mdot
.38321 .67328 Mdot
.33538 .58054 Mdot
.39294 .67578 Mdot
.59131 .67359 Mdot
.77807 .51112 Mdot
.59579 .2574 Mdot
.38583 .69429 Mdot
.69747 .55319 Mdot
.60485 .74135 Mdot
.32807 .39901 Mdot
.58527 .63441 Mdot
.38849 .75353 Mdot
.38832 .73137 Mdot
.38817 .74218 Mdot
.27287 .50233 Mdot
.33151 .46249 Mdot
.59113 .41064 Mdot
.58583 .72384 Mdot
.6853 .55493 Mdot
.44254 .31503 Mdot
.34821 .59017 Mdot
.35204 .44591 Mdot
.35515 .43522 Mdot
.38864 .42319 Mdot
.41032 .43457 Mdot
.57558 .40137 Mdot
.40783 .39067 Mdot
.42438 .42797 Mdot
.6024 .64256 Mdot
.76373 .5208 Mdot
.39002 .41526 Mdot
.6143 .38347 Mdot
.62808 .42458 Mdot
.59311 .3222 Mdot
.34666 .50132 Mdot
.42473 .67828 Mdot
.38276 .68488 Mdot
.68665 .51861 Mdot
.65819 .56591 Mdot
.57693 .29379 Mdot
.60289 .69235 Mdot
.39467 .67416 Mdot
.81446 .49425 Mdot
.59074 .25801 Mdot
.37229 .41889 Mdot
.28167 .40338 Mdot
.27813 .42042 Mdot
.31646 .40141 Mdot
.38329 .40738 Mdot
.62239 .39857 Mdot
.67887 .5191 Mdot
.32444 .39456 Mdot
.33427 .57829 Mdot
.61494 .28004 Mdot
.59347 .30542 Mdot
.41179 .71123 Mdot
.42898 .39596 Mdot
.59075 .65868 Mdot
.27007 .4081 Mdot
.60996 .70754 Mdot
.4309 .77631 Mdot
.64382 .36943 Mdot
.42672 .43825 Mdot
.46063 .3932 Mdot
.37625 .39728 Mdot
.41356 .7083 Mdot
.36859 .61389 Mdot
.39437 .64822 Mdot
.60107 .68859 Mdot
.46262 .35328 Mdot
.57201 .69252 Mdot
.61804 .3742 Mdot
.38831 .71863 Mdot
.27217 .38045 Mdot
.66934 .5366 Mdot
.28145 .52999 Mdot
.59388 .26844 Mdot
.29945 .40024 Mdot
.61181 .3915 Mdot
.32166 .44979 Mdot
.66937 .54516 Mdot
.38288 .62514 Mdot
.27938 .53305 Mdot
.72301 .50418 Mdot
.32833 .43799 Mdot
.60785 .34341 Mdot
.61264 .36383 Mdot
.60037 .25494 Mdot
.46262 .38284 Mdot
.58234 .26885 Mdot
.58579 .67543 Mdot
.39896 .41143 Mdot
.36924 .40437 Mdot
.4054 .41985 Mdot
.35849 .43498 Mdot
.60381 .67576 Mdot
.28246 .51658 Mdot
.59935 .42456 Mdot
.60399 .36647 Mdot
.26117 .52553 Mdot
.59855 .27628 Mdot
.58208 .70538 Mdot
.76192 .52301 Mdot
.60883 .41817 Mdot
.58223 .25943 Mdot
.45158 .41373 Mdot
.4195 .4131 Mdot
.60606 .3687 Mdot
.35577 .42931 Mdot
.27925 .51377 Mdot
.71228 .53026 Mdot
.27549 .52827 Mdot
.5972 .31897 Mdot
.59094 .26845 Mdot
.60447 .65955 Mdot
.38488 .69429 Mdot
.57847 .29173 Mdot
.6692 .55159 Mdot
.36565 .40218 Mdot
.396 .44506 Mdot
.36478 .60139 Mdot
.46254 .33919 Mdot
.59833 .31723 Mdot
.35594 .42447 Mdot
.41309 .68964 Mdot
.37347 .59643 Mdot
.42859 .41567 Mdot
.27443 .51639 Mdot
.39082 .7345 Mdot
.59561 .29894 Mdot
.60401 .69372 Mdot
.32905 .31365 Mdot
.60661 .69823 Mdot
.4019 .66216 Mdot
.58962 .39033 Mdot
.37153 .68745 Mdot
.58724 .39274 Mdot
.43142 .74969 Mdot
.41886 .43655 Mdot
.36369 .60427 Mdot
.6138 .42263 Mdot
.66991 .52743 Mdot
.73307 .5141 Mdot
.61907 .39486 Mdot
.38699 .71351 Mdot
.59414 .41006 Mdot
.58261 .28314 Mdot
.62057 .75142 Mdot
.38458 .73508 Mdot
.72537 .51519 Mdot
.71474 .5365 Mdot
.58369 .72215 Mdot
.39691 .42023 Mdot
.3845 .40101 Mdot
.70388 .5382 Mdot
.60874 .71128 Mdot
.40162 .70644 Mdot
.40016 .42702 Mdot
.62061 .41041 Mdot
.71298 .52465 Mdot
.56666 .65089 Mdot
.38776 .62214 Mdot
.28518 .52792 Mdot
.42467 .30382 Mdot
.56854 .67062 Mdot
.353 .40817 Mdot
.27673 .51266 Mdot
.60888 .28444 Mdot
.32028 .45314 Mdot
.45775 .34153 Mdot
.57071 .66538 Mdot
.58497 .40937 Mdot
.31661 .40064 Mdot
.69443 .51085 Mdot
.36007 .40649 Mdot
.5289 .16721 Mdot
.60886 .3696 Mdot
.3669 .42671 Mdot
.63117 .38924 Mdot
.39556 .69006 Mdot
.4058 .42312 Mdot
.60706 .74156 Mdot
.68431 .52188 Mdot
.36342 .41359 Mdot
.57989 .22587 Mdot
.59505 .72684 Mdot
.61138 .39031 Mdot
.61149 .25763 Mdot
.25508 .52221 Mdot
.38727 .29697 Mdot
.76166 .52968 Mdot
.59625 .28811 Mdot
.39969 .41831 Mdot
.66322 .55096 Mdot
.57473 .67096 Mdot
.61617 .3951 Mdot
.45034 .41531 Mdot
.57764 .69686 Mdot
.59564 .69503 Mdot
.58694 .26587 Mdot
.32671 .59471 Mdot
.44207 .42043 Mdot
.37858 .43111 Mdot
.34015 .59239 Mdot
.37649 .60693 Mdot
.384 .4035 Mdot
.38244 .43974 Mdot
.59225 .66101 Mdot
.46799 .35581 Mdot
.32185 .4509 Mdot
.61625 .42188 Mdot
.58269 .69023 Mdot
.65915 .56859 Mdot
.72788 .52768 Mdot
.59117 .29357 Mdot
.38951 .66723 Mdot
.57265 .28492 Mdot
.69618 .52233 Mdot
.37338 .42231 Mdot
.60225 .70575 Mdot
.29003 .4815 Mdot
.59311 .72995 Mdot
.67727 .54972 Mdot
.40191 .63678 Mdot
.33935 .39909 Mdot
.52573 .16615 Mdot
.54167 .63529 Mdot
.795 .5106 Mdot
.60208 .30486 Mdot
.3347 .57842 Mdot
.40034 .41504 Mdot
.33539 .39444 Mdot
.36668 .41223 Mdot
.57184 .26459 Mdot
.74788 .5341 Mdot
.58696 .37656 Mdot
.58717 .39707 Mdot
.32865 .45137 Mdot
.59652 .69628 Mdot
.57036 .68856 Mdot
.59575 .37969 Mdot
.59199 .67703 Mdot
.3756 .43206 Mdot
.68093 .54413 Mdot
.42458 .75903 Mdot
.41632 .41666 Mdot
.63675 .38612 Mdot
.57899 .63811 Mdot
.40291 .6332 Mdot
.66288 .56788 Mdot
.46001 .39524 Mdot
.4644 .75936 Mdot
.58567 .68353 Mdot
.34682 .50054 Mdot
.67905 .52341 Mdot
.61065 .41753 Mdot
.66064 .54858 Mdot
.36925 .42586 Mdot
.4258 .43897 Mdot
.58741 .41859 Mdot
.4146 .41787 Mdot
.36091 .61593 Mdot
.26736 .49765 Mdot
.29293 .50467 Mdot
.427 .42582 Mdot
.40693 .7362 Mdot
.57793 .65822 Mdot
.59393 .38139 Mdot
.30779 .40633 Mdot
.37674 .44543 Mdot
.398 .73441 Mdot
.57984 .69815 Mdot
.48605 .74569 Mdot
.60182 .68449 Mdot
.66823 .52762 Mdot
.60084 .69523 Mdot
.37344 .3983 Mdot
.40006 .67695 Mdot
.69306 .52957 Mdot
.60687 .38991 Mdot
.72134 .53964 Mdot
.40979 .39925 Mdot
.574 .63604 Mdot
.73139 .52728 Mdot
.26227 .50274 Mdot
.39881 .67809 Mdot
.55896 .29806 Mdot
.42679 .68689 Mdot
.37254 .42406 Mdot
.36999 .41075 Mdot
.62464 .38311 Mdot
.60479 .66459 Mdot
.38429 .61567 Mdot
.79246 .5056 Mdot
.59465 .32064 Mdot
.3905 .65811 Mdot
.57586 .30305 Mdot
.28117 .399 Mdot
.38877 .64438 Mdot
.25903 .40656 Mdot
.5979 .65428 Mdot
.38424 .70802 Mdot
.61509 .22964 Mdot
.24843 .52395 Mdot
.59213 .27996 Mdot
.66251 .5643 Mdot
.27238 .39266 Mdot
.72211 .5216 Mdot
.60263 .74469 Mdot
.77833 .51533 Mdot
.58319 .67988 Mdot
.57929 .22759 Mdot
.26942 .49409 Mdot
.5741 .65479 Mdot
.61216 .74429 Mdot
.70478 .51943 Mdot
.60057 .37589 Mdot
.27859 .52266 Mdot
.57799 .41468 Mdot
.5893 .38089 Mdot
.56953 .68367 Mdot
.38185 .70606 Mdot
.37635 .69409 Mdot
.63006 .41443 Mdot
.3817 .70055 Mdot
.70025 .53406 Mdot
.27866 .40615 Mdot
.35458 .38551 Mdot
.57869 .65503 Mdot
.2555 .52441 Mdot
.33228 .42053 Mdot
.74585 .53778 Mdot
.68771 .54041 Mdot
.59904 .69223 Mdot
.40438 .76196 Mdot
.58468 .39261 Mdot
.39073 .62537 Mdot
.3967 .70247 Mdot
.39394 .69544 Mdot
.3707 .71164 Mdot
.46263 .34895 Mdot
.58562 .69547 Mdot
.38886 .71218 Mdot
.38624 .44259 Mdot
.40032 .43972 Mdot
.60615 .41782 Mdot
.58129 .25294 Mdot
.27559 .51961 Mdot
.58995 .40916 Mdot
.42323 .40757 Mdot
.67009 .53248 Mdot
.59379 .2386 Mdot
.5813 .40722 Mdot
.67612 .52126 Mdot
.67407 .52108 Mdot
.57898 .39844 Mdot
.59352 .24085 Mdot
.36105 .61495 Mdot
.24496 .52293 Mdot
.40833 .73679 Mdot
.74018 .51807 Mdot
.60751 .75123 Mdot
.3633 .60195 Mdot
.3606 .41297 Mdot
.62861 .39233 Mdot
.67173 .54278 Mdot
.38216 .7344 Mdot
.40237 .43178 Mdot
.59411 .39932 Mdot
.58743 .28321 Mdot
.60737 .38656 Mdot
.62367 .39537 Mdot
.40719 .7137 Mdot
.66235 .73314 Mdot
.40521 .64401 Mdot
.72041 .5063 Mdot
.60885 .39683 Mdot
.29204 .56815 Mdot
.75093 .5261 Mdot
.62183 .75095 Mdot
.26427 .49747 Mdot
.43131 .4199 Mdot
.68899 .51826 Mdot
.39281 .72522 Mdot
.59328 .63483 Mdot
.26435 .41482 Mdot
.38553 .69595 Mdot
.5777 .38843 Mdot
.62148 .394 Mdot
.71374 .52304 Mdot
.40442 .67033 Mdot
.27584 .51276 Mdot
.38888 .70263 Mdot
.58061 .7127 Mdot
.35335 .42519 Mdot
.45789 .76261 Mdot
.58953 .40016 Mdot
.37923 .68704 Mdot
.68235 .55495 Mdot
.57813 .27991 Mdot
.3592 .42628 Mdot
.46038 .76951 Mdot
.40434 .4171 Mdot
.58063 .71626 Mdot
.63837 .41304 Mdot
.25304 .53187 Mdot
.38268 .41066 Mdot
.32271 .40243 Mdot
.60017 .73064 Mdot
.38953 .40846 Mdot
.31727 .4087 Mdot
.32798 .57756 Mdot
.39553 .63867 Mdot
.39097 .41598 Mdot
.70159 .53783 Mdot
.64349 .59255 Mdot
.38747 .43733 Mdot
.71937 .50299 Mdot
.2708 .41193 Mdot
.58776 .42582 Mdot
.61172 .23642 Mdot
.42137 .30765 Mdot
.367 .41937 Mdot
.42839 .40087 Mdot
.35252 .4265 Mdot
.3775 .37984 Mdot
.69044 .5221 Mdot
.64916 .55904 Mdot
.58269 .289 Mdot
.3265 .45932 Mdot
.58845 .26971 Mdot
.57509 .66997 Mdot
.28123 .50007 Mdot
.60728 .36375 Mdot
.38247 .69132 Mdot
.40806 .42001 Mdot
.66382 .56094 Mdot
.36708 .42448 Mdot
.26662 .50871 Mdot
.70633 .52982 Mdot
.6693 .54077 Mdot
.64715 .53848 Mdot
.60368 .30522 Mdot
.38511 .66911 Mdot
.40155 .39356 Mdot
.6167 .2705 Mdot
.58322 .41748 Mdot
.31172 .31935 Mdot
.38868 .65817 Mdot
.38072 .67591 Mdot
.37243 .68924 Mdot
.41317 .39281 Mdot
.40822 .39224 Mdot
.57547 .70361 Mdot
.36439 .59729 Mdot
.60241 .7101 Mdot
.69787 .51695 Mdot
.6855 .51116 Mdot
.36639 .42236 Mdot
.57112 .30489 Mdot
.59723 .27629 Mdot
.71915 .5389 Mdot
.61762 .37001 Mdot
.5762 .27757 Mdot
.41416 .39551 Mdot
.71519 .51908 Mdot
.61687 .27675 Mdot
.40237 .76389 Mdot
.49415 .72443 Mdot
.5775 .27774 Mdot
.58715 .40047 Mdot
.34854 .58659 Mdot
.43622 .31285 Mdot
.57198 .29551 Mdot
.57684 .6601 Mdot
.28338 .3852 Mdot
.61516 .36824 Mdot
.57892 .26391 Mdot
.45291 .31953 Mdot
.70047 .52511 Mdot
.58623 .40152 Mdot
.60653 .21804 Mdot
.35061 .38531 Mdot
.57901 .26847 Mdot
.37968 .68014 Mdot
.39964 .62135 Mdot
.37436 .41305 Mdot
.25539 .51279 Mdot
.58859 .64597 Mdot
.66528 .56459 Mdot
.65478 .5619 Mdot
.37058 .61339 Mdot
.28755 .41068 Mdot
.71477 .53145 Mdot
.31214 .40621 Mdot
.58724 .25332 Mdot
.38779 .44283 Mdot
.62582 .42092 Mdot
.24937 .52913 Mdot
.61944 .23923 Mdot
.5778 .27868 Mdot
.58132 .64958 Mdot
.59069 .69072 Mdot
.60421 .66564 Mdot
.71645 .52838 Mdot
.28855 .39983 Mdot
.65075 .55718 Mdot
.32379 .58896 Mdot
.6038 .28451 Mdot
.80761 .50347 Mdot
.37937 .39575 Mdot
.42481 .40694 Mdot
.26789 .53761 Mdot
.62458 .40162 Mdot
.37085 .42469 Mdot
.57646 .69673 Mdot
.69909 .55229 Mdot
.57317 .63507 Mdot
.41005 .69077 Mdot
.32505 .58726 Mdot
.6715 .53724 Mdot
.63447 .38002 Mdot
.59566 .27018 Mdot
.41116 .29376 Mdot
.56967 .26709 Mdot
.6612 .53771 Mdot
.438 .41741 Mdot
.3866 .73769 Mdot
.81396 .49188 Mdot
.40396 .4224 Mdot
.71835 .53518 Mdot
.70584 .55575 Mdot
.25037 .52273 Mdot
.46486 .37346 Mdot
.57661 .62882 Mdot
.2957 .40862 Mdot
.60547 .30442 Mdot
.59038 .42048 Mdot
.25438 .38868 Mdot
.69718 .52152 Mdot
.71993 .5423 Mdot
.5757 .29955 Mdot
.40264 .63361 Mdot
.37617 .71518 Mdot
.36291 .61638 Mdot
.57574 .69911 Mdot
.42849 .43037 Mdot
.71371 .52008 Mdot
.39788 .63162 Mdot
.32853 .42701 Mdot
.59696 .66386 Mdot
.72981 .53192 Mdot
.41432 .41813 Mdot
.37918 .41348 Mdot
.58736 .27274 Mdot
.62906 .42412 Mdot
.60899 .422 Mdot
.62041 .74844 Mdot
.34142 .4389 Mdot
.28402 .50301 Mdot
.42917 .41455 Mdot
.40165 .71096 Mdot
.59795 .41299 Mdot
.5956 .27929 Mdot
.35384 .41157 Mdot
.33565 .39699 Mdot
.38833 .72974 Mdot
.59573 .65471 Mdot
.60415 .39631 Mdot
.33431 .449 Mdot
.41114 .41687 Mdot
.36552 .41526 Mdot
.27277 .50239 Mdot
.40106 .39033 Mdot
.74046 .53643 Mdot
.41097 .65989 Mdot
.61583 .26408 Mdot
.39321 .6837 Mdot
.78716 .50747 Mdot
.26783 .49661 Mdot
.29155 .39242 Mdot
.4054 .72407 Mdot
.39654 .67045 Mdot
.58183 .71661 Mdot
.58552 .69138 Mdot
.61793 .35009 Mdot
.36921 .43634 Mdot
.61281 .37079 Mdot
.39151 .70809 Mdot
.66302 .56446 Mdot
.58803 .2687 Mdot
.79778 .50943 Mdot
.42441 .4201 Mdot
.70484 .52062 Mdot
.61463 .40083 Mdot
.40979 .70231 Mdot
.67432 .52926 Mdot
.61148 .41709 Mdot
.59609 .30108 Mdot
.29989 .38916 Mdot
.61816 .35139 Mdot
.59161 .38998 Mdot
.36856 .43724 Mdot
.29565 .51848 Mdot
.2549 .51759 Mdot
.61514 .42297 Mdot
.6763 .56617 Mdot
.59383 .39297 Mdot
.39068 .61476 Mdot
.25161 .51849 Mdot
.68268 .55792 Mdot
.36345 .59934 Mdot
.26405 .498 Mdot
.58799 .39093 Mdot
.38661 .6575 Mdot
.77992 .50749 Mdot
.39241 .74759 Mdot
.4435 .32253 Mdot
.39855 .43591 Mdot
.72261 .52188 Mdot
.59065 .28066 Mdot
.574 .70643 Mdot
.56729 .66621 Mdot
.60983 .74203 Mdot
.71092 .51192 Mdot
.4105 .42023 Mdot
.38624 .70864 Mdot
.58677 .68271 Mdot
.38062 .61295 Mdot
.66827 .55398 Mdot
.68818 .54355 Mdot
.26843 .53685 Mdot
.58949 .26776 Mdot
.38613 .39371 Mdot
.66194 .56401 Mdot
.77428 .51532 Mdot
.32895 .57485 Mdot
.61666 .27928 Mdot
.27864 .50306 Mdot
.61461 .4259 Mdot
.33628 .42103 Mdot
.33715 .58316 Mdot
.621 .38693 Mdot
.40966 .69158 Mdot
.39826 .40323 Mdot
.68543 .7065 Mdot
.75211 .52529 Mdot
.29697 .40911 Mdot
.57442 .62796 Mdot
.5908 .6991 Mdot
.68208 .52598 Mdot
.40846 .4292 Mdot
.79876 .50973 Mdot
.59021 .29418 Mdot
.26478 .54348 Mdot
.59177 .3825 Mdot
.37213 .60556 Mdot
.60149 .70308 Mdot
.58721 .22816 Mdot
.57383 .70554 Mdot
.60348 .659 Mdot
.41388 .74818 Mdot
.37326 .41413 Mdot
.67809 .53684 Mdot
.69437 .54404 Mdot
.6277 .41809 Mdot
.7913 .51915 Mdot
.37324 .71143 Mdot
.68319 .70184 Mdot
.32187 .39112 Mdot
.40435 .41168 Mdot
.57676 .39184 Mdot
.61458 .37319 Mdot
.78334 .5109 Mdot
.38967 .40731 Mdot
.39386 .64287 Mdot
.65205 .5639 Mdot
.72579 .5269 Mdot
.26012 .50593 Mdot
.59004 .69136 Mdot
.56935 .26599 Mdot
.69383 .53724 Mdot
.32515 .3157 Mdot
.36483 .42429 Mdot
.59545 .63137 Mdot
.69576 .5353 Mdot
.83298 .45177 Mdot
.65625 .7587 Mdot
.40226 .64063 Mdot
.31162 .39215 Mdot
.38659 .62406 Mdot
.57895 .27254 Mdot
.65445 .5488 Mdot
.571 .67175 Mdot
.6088 .39366 Mdot
.64676 .60109 Mdot
.72149 .52482 Mdot
.38861 .68159 Mdot
.37157 .41254 Mdot
.33901 .49713 Mdot
.41313 .41554 Mdot
.46819 .35669 Mdot
.60087 .31394 Mdot
.56725 .66576 Mdot
.5838 .72086 Mdot
.31198 .39211 Mdot
.61523 .28181 Mdot
.66143 .53156 Mdot
.7073 .52827 Mdot
.46737 .76384 Mdot
.62328 .39567 Mdot
.65559 .53825 Mdot
.36677 .43636 Mdot
.64894 .53547 Mdot
.34852 .59151 Mdot
.59264 .6962 Mdot
.3625 .44106 Mdot
.7247 .52024 Mdot
.40855 .72767 Mdot
.28646 .40385 Mdot
.38208 .4354 Mdot
.63193 .39413 Mdot
.58505 .68645 Mdot
.32116 .58442 Mdot
.74165 .53953 Mdot
.41624 .43711 Mdot
.57637 .68507 Mdot
.56772 .24516 Mdot
.65191 .61042 Mdot
.38585 .66614 Mdot
.71235 .538 Mdot
.60274 .69716 Mdot
.6085 .40417 Mdot
.61612 .2598 Mdot
.66046 .54384 Mdot
.73261 .52317 Mdot
.26366 .51696 Mdot
.6354 .38788 Mdot
.57294 .29816 Mdot
.40096 .70484 Mdot
.59205 .65979 Mdot
.26436 .50726 Mdot
.33551 .31006 Mdot
.40317 .39256 Mdot
.60417 .65736 Mdot
.30092 .56965 Mdot
.43659 .42346 Mdot
.42613 .42273 Mdot
.33782 .49467 Mdot
.3917 .61724 Mdot
.39265 .72117 Mdot
.34047 .44232 Mdot
.27291 .51791 Mdot
.28851 .39461 Mdot
.38404 .6833 Mdot
.39037 .67728 Mdot
.29768 .3984 Mdot
.26413 .51398 Mdot
.35894 .59736 Mdot
.58985 .68223 Mdot
.59017 .69812 Mdot
.39466 .69262 Mdot
.2661 .53789 Mdot
.598 .64723 Mdot
.37801 .6148 Mdot
.67843 .54814 Mdot
.27554 .41352 Mdot
.39612 .67912 Mdot
.26971 .3961 Mdot
.58602 .67444 Mdot
.34882 .29952 Mdot
.27106 .4126 Mdot
.4304 .40045 Mdot
.37853 .41124 Mdot
.60679 .29641 Mdot
.60979 .38826 Mdot
.5789 .39858 Mdot
.60481 .66768 Mdot
.4056 .39081 Mdot
.39494 .64867 Mdot
.40603 .39145 Mdot
.44332 .31472 Mdot
.35785 .29506 Mdot
.305 .38398 Mdot
.38954 .66974 Mdot
.39881 .6557 Mdot
.70323 .50876 Mdot
.68577 .55984 Mdot
.31349 .40835 Mdot
.5862 .68907 Mdot
.37827 .69581 Mdot
.6019 .70985 Mdot
.69825 .52213 Mdot
.67485 .53853 Mdot
.59735 .41527 Mdot
.58606 .40267 Mdot
.68722 .52744 Mdot
.72495 .50378 Mdot
.33034 .31154 Mdot
.36577 .60078 Mdot
.31045 .57223 Mdot
.39906 .29865 Mdot
.3804 .51117 Mdot
.58947 .2831 Mdot
.59491 .23772 Mdot
.57578 .68984 Mdot
.3238 .40019 Mdot
.41066 .40254 Mdot
.59749 .38601 Mdot
.57869 .67709 Mdot
.60491 .2699 Mdot
.59193 .69783 Mdot
.61451 .25794 Mdot
.68171 .55753 Mdot
.41291 .42315 Mdot
.43111 .40549 Mdot
.58268 .71652 Mdot
.6739 .51542 Mdot
.71713 .51806 Mdot
.5925 .28424 Mdot
.40665 .30066 Mdot
.71082 .52242 Mdot
.39619 .67729 Mdot
.4116 .7728 Mdot
.61953 .38609 Mdot
.40393 .43087 Mdot
.41875 .30538 Mdot
.25202 .51598 Mdot
.5824 .4167 Mdot
.60342 .39646 Mdot
.32841 .59621 Mdot
.38355 .3997 Mdot
.48321 .75136 Mdot
.58426 .41011 Mdot
.37222 .68439 Mdot
.68004 .53429 Mdot
.58067 .41045 Mdot
.60477 .42934 Mdot
.62571 .25227 Mdot
.57708 .40308 Mdot
.38266 .71936 Mdot
.3852 .62516 Mdot
.2752 .52613 Mdot
.25997 .56151 Mdot
.60611 .25503 Mdot
.60154 .27701 Mdot
.74498 .53085 Mdot
.60543 .73825 Mdot
.32697 .47965 Mdot
.60034 .28701 Mdot
.39631 .75722 Mdot
.27468 .53475 Mdot
.26262 .52988 Mdot
.26476 .5273 Mdot
.38223 .61603 Mdot
.44044 .42976 Mdot
.74771 .53226 Mdot
.38751 .68158 Mdot
.27518 .52898 Mdot
.42572 .39265 Mdot
.39167 .65112 Mdot
.59692 .65776 Mdot
.28475 .53393 Mdot
.38508 .70508 Mdot
.25961 .41079 Mdot
.58582 .66827 Mdot
.33009 .3994 Mdot
.74461 .49163 Mdot
.83363 .44015 Mdot
.59591 .69225 Mdot
.72806 .53276 Mdot
.70793 .51913 Mdot
.71116 .52973 Mdot
.39414 .71793 Mdot
.73568 .51274 Mdot
.40608 .67136 Mdot
.79425 .51111 Mdot
.33194 .45577 Mdot
.5968 .25742 Mdot
.77339 .51724 Mdot
.39369 .69441 Mdot
.33422 .58861 Mdot
.51131 .16309 Mdot
.41247 .43894 Mdot
.5721 .66069 Mdot
.58486 .29701 Mdot
.27876 .40467 Mdot
.609 .28473 Mdot
.67992 .5226 Mdot
.32971 .44951 Mdot
.36528 .42303 Mdot
.49173 .73133 Mdot
.59064 .27811 Mdot
.39129 .67694 Mdot
.26258 .52029 Mdot
.65555 .57072 Mdot
.59113 .29269 Mdot
.59182 .26854 Mdot
.37955 .43039 Mdot
.38305 .62286 Mdot
.68928 .51716 Mdot
.58029 .6759 Mdot
.76718 .51324 Mdot
.32929 .33454 Mdot
.37857 .40121 Mdot
.42307 .43481 Mdot
.27836 .39896 Mdot
.78992 .50945 Mdot
.59268 .68316 Mdot
.45871 .33149 Mdot
.73782 .54283 Mdot
.43556 .30901 Mdot
.41312 .71265 Mdot
.77811 .51788 Mdot
.61851 .3829 Mdot
.60517 .41827 Mdot
.39709 .4271 Mdot
.51952 .1637 Mdot
.46305 .3694 Mdot
.59438 .64721 Mdot
.60724 .37896 Mdot
.74399 .51422 Mdot
.37795 .72554 Mdot
.61368 .21746 Mdot
.27673 .5175 Mdot
.58109 .67108 Mdot
.70878 .52516 Mdot
.54895 .17477 Mdot
.59917 .30761 Mdot
.30356 .41402 Mdot
.40193 .44 Mdot
.39613 .42898 Mdot
.60138 .66759 Mdot
.59147 .6406 Mdot
.31832 .57566 Mdot
.59193 .43225 Mdot
.4506 .7698 Mdot
.59586 .73386 Mdot
.55934 .17915 Mdot
.61141 .37187 Mdot
.40384 .65484 Mdot
.57976 .38694 Mdot
.58889 .64248 Mdot
.39246 .40286 Mdot
.38424 .6237 Mdot
.61596 .40161 Mdot
.42522 .69657 Mdot
.2569 .52505 Mdot
.32308 .31606 Mdot
.38714 .42322 Mdot
.37419 .69101 Mdot
.38512 .67928 Mdot
.38677 .63534 Mdot
.61813 .40392 Mdot
.42593 .41538 Mdot
.4215 .43059 Mdot
.42593 .43123 Mdot
.3186 .57221 Mdot
.40963 .42285 Mdot
.38372 .73981 Mdot
.29231 .4138 Mdot
.68946 .71553 Mdot
.43017 .40529 Mdot
.60477 .6874 Mdot
.39173 .42594 Mdot
.58906 .31966 Mdot
.30966 .39519 Mdot
.25541 .50772 Mdot
.59449 .67678 Mdot
.41413 .38929 Mdot
.5721 .32567 Mdot
.40796 .39465 Mdot
.61085 .25332 Mdot
.62805 .76028 Mdot
.45677 .33524 Mdot
.34145 .57935 Mdot
.39055 .70007 Mdot
.66229 .55595 Mdot
.60141 .64167 Mdot
.66812 .52861 Mdot
.24496 .5278 Mdot
.59589 .36977 Mdot
.80649 .50374 Mdot
.34018 .30695 Mdot
.39475 .40308 Mdot
.62362 .38201 Mdot
.39123 .64396 Mdot
.75206 .52733 Mdot
.40263 .50799 Mdot
.26971 .5373 Mdot
.57577 .29307 Mdot
.60361 .29351 Mdot
.64381 .41352 Mdot
.39332 .62691 Mdot
.34974 .59887 Mdot
.60038 .66775 Mdot
.71919 .52779 Mdot
.6213 .25526 Mdot
.38756 .75954 Mdot
.59245 .63666 Mdot
.77863 .51163 Mdot
.60021 .70393 Mdot
.42952 .40976 Mdot
.57851 .40248 Mdot
.35999 .59075 Mdot
.59856 .38031 Mdot
.36704 .40181 Mdot
.72889 .52111 Mdot
.62243 .3906 Mdot
.61443 .27778 Mdot
.60629 .68552 Mdot
.66981 .53528 Mdot
.3684 .41443 Mdot
.38285 .67941 Mdot
.24211 .42653 Mdot
.76513 .53194 Mdot
.25967 .50342 Mdot
.26099 .50166 Mdot
.36839 .59533 Mdot
.59403 .42747 Mdot
.66679 .62029 Mdot
.24987 .51676 Mdot
.60645 .74587 Mdot
.56834 .29518 Mdot
.80649 .50677 Mdot
.6542 .55833 Mdot
.69611 .52886 Mdot
.39491 .39914 Mdot
.64888 .56435 Mdot
.30527 .40045 Mdot
.65844 .57017 Mdot
.61724 .7579 Mdot
.44924 .41807 Mdot
.70329 .53055 Mdot
.58358 .40768 Mdot
.36277 .43183 Mdot
.39736 .64223 Mdot
.64923 .54865 Mdot
.43027 .40021 Mdot
.73314 .50114 Mdot
.58134 .71612 Mdot
.61693 .40802 Mdot
.27157 .38762 Mdot
.58907 .67678 Mdot
.38571 .72099 Mdot
.28385 .38266 Mdot
.59533 .29383 Mdot
.40178 .65915 Mdot
.6319 .36697 Mdot
.59132 .2658 Mdot
.27171 .40278 Mdot
.40064 .68613 Mdot
.61457 .37983 Mdot
.59908 .29811 Mdot
.61043 .23807 Mdot
.69868 .52723 Mdot
.7115 .55355 Mdot
.59097 .39498 Mdot
.36374 .41671 Mdot
.77101 .52464 Mdot
.59849 .69569 Mdot
.39138 .43881 Mdot
.71986 .52152 Mdot
.61457 .38453 Mdot
.41962 .42903 Mdot
.27359 .51867 Mdot
.3328 .57867 Mdot
.58067 .42367 Mdot
.60896 .2581 Mdot
.39015 .63264 Mdot
.41692 .43744 Mdot
.59982 .25352 Mdot
.76066 .51783 Mdot
.36912 .44081 Mdot
.38152 .66461 Mdot
.39859 .76027 Mdot
.66302 .56537 Mdot
.59281 .65517 Mdot
.69358 .54558 Mdot
.61379 .25068 Mdot
.50841 .1626 Mdot
.58946 .41148 Mdot
.2539 .53781 Mdot
.30699 .39701 Mdot
.65793 .55595 Mdot
.38589 .67025 Mdot
.4348 .77842 Mdot
.30762 .39358 Mdot
.3702 .4406 Mdot
.39739 .43166 Mdot
.78511 .51326 Mdot
.37803 .72336 Mdot
.40099 .4315 Mdot
.58955 .24469 Mdot
.40168 .4452 Mdot
.58106 .28378 Mdot
.76384 .50013 Mdot
.60509 .41977 Mdot
.28566 .56754 Mdot
.61597 .40422 Mdot
.70012 .53562 Mdot
.25761 .40862 Mdot
.28653 .39688 Mdot
.64184 .36245 Mdot
.38367 .72179 Mdot
.4099 .73359 Mdot
.67781 .53877 Mdot
.78536 .50706 Mdot
.27915 .51706 Mdot
.26506 .52042 Mdot
.36277 .42924 Mdot
.67965 .52289 Mdot
.71427 .54659 Mdot
.59076 .37489 Mdot
.62228 .3808 Mdot
.33201 .40046 Mdot
.67595 .55822 Mdot
.412 .42352 Mdot
.25589 .53198 Mdot
.59411 .63681 Mdot
.39578 .63536 Mdot
.57648 .6481 Mdot
.59109 .63369 Mdot
.3909 .50927 Mdot
.34938 .44226 Mdot
.5747 .69567 Mdot
.58025 .65818 Mdot
.77283 .51267 Mdot
.34874 .3892 Mdot
.57963 .27345 Mdot
.46756 .37057 Mdot
.66556 .52964 Mdot
.42157 .4118 Mdot
.37248 .71567 Mdot
.57286 .41535 Mdot
.42109 .78008 Mdot
.51001 .28503 Mdot
.28357 .51235 Mdot
.75552 .53029 Mdot
.59116 .38954 Mdot
.59669 .37944 Mdot
.43654 .31248 Mdot
.40994 .42463 Mdot
.66165 .5653 Mdot
.35058 .3857 Mdot
.59638 .73388 Mdot
.77569 .51071 Mdot
.39289 .62464 Mdot
.39595 .42446 Mdot
.40498 .69918 Mdot
.60629 .65608 Mdot
.58715 .26134 Mdot
.60339 .30449 Mdot
.40926 .39558 Mdot
.2642 .49716 Mdot
.60612 .74722 Mdot
.27076 .52233 Mdot
.26687 .51047 Mdot
.59513 .39514 Mdot
.27721 .50196 Mdot
.41116 .44023 Mdot
.44666 .41185 Mdot
.58343 .41791 Mdot
.58908 .63346 Mdot
.45714 .40033 Mdot
.58856 .38969 Mdot
.29687 .38627 Mdot
.60796 .65995 Mdot
.27382 .5215 Mdot
.60226 .68466 Mdot
.78116 .50996 Mdot
.5787 .70757 Mdot
.6157 .2659 Mdot
.77439 .51453 Mdot
.31331 .57276 Mdot
.38561 .70764 Mdot
.58678 .69561 Mdot
.5944 .30184 Mdot
.60212 .68962 Mdot
.66309 .5394 Mdot
.59533 .73777 Mdot
.37859 .60009 Mdot
.31949 .31874 Mdot
.37897 .50918 Mdot
.60419 .71562 Mdot
.68695 .55845 Mdot
.39449 .69458 Mdot
.60709 .73954 Mdot
.29114 .38706 Mdot
.59696 .3112 Mdot
.39437 .42805 Mdot
.60694 .67306 Mdot
.7666 .52185 Mdot
.34296 .58561 Mdot
.61387 .2629 Mdot
.31921 .58569 Mdot
.66699 .55989 Mdot
.42125 .44037 Mdot
.5759 .71861 Mdot
.66105 .62122 Mdot
.5842 .71947 Mdot
.31915 .45415 Mdot
.61294 .36822 Mdot
.60026 .43299 Mdot
.40136 .66587 Mdot
.62294 .37707 Mdot
.56956 .23389 Mdot
.61272 .74686 Mdot
.4088 .65487 Mdot
.71466 .50682 Mdot
.3621 .41753 Mdot
.28523 .50782 Mdot
.59071 .40788 Mdot
.37579 .69427 Mdot
.27176 .50245 Mdot
.60061 .41652 Mdot
.29079 .41406 Mdot
.38959 .62805 Mdot
.6596 .53149 Mdot
.36671 .43559 Mdot
.56911 .69126 Mdot
.59481 .72836 Mdot
.57877 .38617 Mdot
.57131 .69485 Mdot
.2982 .38675 Mdot
.39953 .68076 Mdot
.27639 .52429 Mdot
.58122 .2863 Mdot
.36426 .61959 Mdot
.57408 .41224 Mdot
.61712 .30106 Mdot
.37222 .43982 Mdot
.67686 .53791 Mdot
.64749 .60128 Mdot
.32183 .40551 Mdot
.38566 .68517 Mdot
.31002 .40079 Mdot
.27403 .50183 Mdot
.2679 .52163 Mdot
.71922 .52755 Mdot
.27928 .40157 Mdot
.41117 .42247 Mdot
.58361 .66496 Mdot
.37926 .34802 Mdot
.34761 .40747 Mdot
.58783 .24726 Mdot
.25515 .50818 Mdot
.58395 .73133 Mdot
.36795 .60144 Mdot
.68007 .5363 Mdot
.3977 .64963 Mdot
.37913 .60933 Mdot
.38911 .71885 Mdot
.38258 .75365 Mdot
.25013 .51663 Mdot
.47127 .7625 Mdot
.34853 .5924 Mdot
.36353 .50871 Mdot
.37765 .73296 Mdot
.66516 .60697 Mdot
.40949 .65671 Mdot
.38531 .72122 Mdot
.42521 .75948 Mdot
.3774 .72029 Mdot
.36481 .4193 Mdot
.36968 .44418 Mdot
.31147 .38513 Mdot
.78979 .51383 Mdot
.4146 .41548 Mdot
.57729 .40932 Mdot
.58088 .29586 Mdot
.40291 .63508 Mdot
.6065 .39359 Mdot
.27031 .40006 Mdot
.61851 .36206 Mdot
.3771 .42925 Mdot
.41451 .43004 Mdot
.26591 .52601 Mdot
.3686 .29079 Mdot
.79217 .51432 Mdot
.37459 .67805 Mdot
.35945 .40191 Mdot
.65175 .61074 Mdot
.37104 .43587 Mdot
.3131 .40008 Mdot
.44341 .41557 Mdot
.67799 .53687 Mdot
.38207 .60985 Mdot
.58725 .38281 Mdot
.36369 .61511 Mdot
.39892 .41816 Mdot
.58456 .36906 Mdot
.57522 .266 Mdot
.4075 .43056 Mdot
.38202 .63778 Mdot
.27243 .5019 Mdot
.39319 .72749 Mdot
.40209 .68041 Mdot
.3714 .44116 Mdot
.39834 .62989 Mdot
.39436 .7212 Mdot
.26582 .52009 Mdot
.75745 .52951 Mdot
.62114 .7508 Mdot
.37091 .42871 Mdot
.61343 .26504 Mdot
.38587 .40745 Mdot
.58041 .26779 Mdot
.57859 .40721 Mdot
.5928 .39114 Mdot
.46265 .38171 Mdot
.70976 .54667 Mdot
.57217 .28963 Mdot
.7878 .51574 Mdot
.23852 .52341 Mdot
.4104 .7421 Mdot
.59717 .73588 Mdot
.70943 .55484 Mdot
.59414 .39172 Mdot
.46067 .35226 Mdot
.33487 .33592 Mdot
.57251 .69386 Mdot
.41028 .70857 Mdot
.45777 .39919 Mdot
.62562 .38306 Mdot
.66037 .52966 Mdot
.6931 .54374 Mdot
.612 .74739 Mdot
.42515 .75787 Mdot
.42652 .40308 Mdot
.62568 .38491 Mdot
.29322 .50155 Mdot
.61071 .38819 Mdot
.5849 .38305 Mdot
.73538 .52626 Mdot
.42033 .42352 Mdot
.26786 .40421 Mdot
.6999 .519 Mdot
.59869 .27075 Mdot
.40929 .69266 Mdot
.60787 .25371 Mdot
.4975 .71742 Mdot
.31688 .57459 Mdot
.68748 .52476 Mdot
.61603 .41545 Mdot
.41582 .41118 Mdot
.38402 .61521 Mdot
.38033 .62712 Mdot
.39935 .64183 Mdot
.58202 .29155 Mdot
.65503 .56343 Mdot
.79107 .50401 Mdot
.37064 .41485 Mdot
.39545 .66935 Mdot
.62547 .2611 Mdot
.38065 .41322 Mdot
.58745 .69155 Mdot
.26836 .50216 Mdot
.3941 .6775 Mdot
.25755 .53938 Mdot
.40183 .66777 Mdot
.69717 .54054 Mdot
.40881 .39763 Mdot
.36109 .42259 Mdot
.45844 .33765 Mdot
.60553 .27043 Mdot
.38713 .7322 Mdot
.34494 .43994 Mdot
.33646 .42085 Mdot
.42991 .31004 Mdot
.41016 .43256 Mdot
.37484 .50876 Mdot
.63422 .39149 Mdot
.5927 .41576 Mdot
.30264 .39393 Mdot
.38313 .4344 Mdot
.38034 .63625 Mdot
.34705 .58502 Mdot
.3169 .57069 Mdot
.60306 .65362 Mdot
.40914 .65249 Mdot
.69298 .51875 Mdot
.64972 .54496 Mdot
.68448 .51208 Mdot
.61816 .25302 Mdot
.27666 .52107 Mdot
.41072 .40076 Mdot
.59593 .64881 Mdot
.59739 .29401 Mdot
.39308 .6632 Mdot
.58677 .26655 Mdot
.30396 .40844 Mdot
.61378 .2746 Mdot
.59257 .37067 Mdot
.65319 .75999 Mdot
.25586 .53161 Mdot
.59966 .26262 Mdot
.39325 .63499 Mdot
.4629 .36507 Mdot
.45397 .41248 Mdot
.33172 .58713 Mdot
.57471 .29146 Mdot
.7616 .51694 Mdot
.37516 .43989 Mdot
.32866 .46348 Mdot
.60416 .67396 Mdot
.61595 .26087 Mdot
.59834 .70712 Mdot
.27209 .50693 Mdot
.41063 .73072 Mdot
.38892 .68872 Mdot
.59911 .73366 Mdot
.31196 .40056 Mdot
.61669 .26264 Mdot
.69096 .52601 Mdot
.34377 .38863 Mdot
.79735 .51209 Mdot
.62024 .35845 Mdot
.44192 .31824 Mdot
.74422 .53451 Mdot
.40598 .38842 Mdot
.58408 .71277 Mdot
.37954 .39627 Mdot
.25206 .53282 Mdot
.33978 .42245 Mdot
.70795 .51598 Mdot
.69571 .52955 Mdot
.80295 .50584 Mdot
.38198 .39945 Mdot
.4381 .40484 Mdot
.37336 .60735 Mdot
.65721 .56419 Mdot
.39207 .71515 Mdot
.37526 .68852 Mdot
.72925 .53114 Mdot
.3984 .72834 Mdot
.59086 .26799 Mdot
.33 .44162 Mdot
.58367 .71225 Mdot
.58733 .72475 Mdot
.68621 .52672 Mdot
.73752 .52117 Mdot
.67536 .53796 Mdot
.27253 .50468 Mdot
.40057 .69128 Mdot
.39662 .44898 Mdot
.38263 .42695 Mdot
.41688 .39229 Mdot
.39049 .62086 Mdot
.30333 .39108 Mdot
.44618 .46087 Mdot
.57657 .2871 Mdot
.69526 .53751 Mdot
.60507 .70028 Mdot
.24536 .43285 Mdot
.58754 .65756 Mdot
.38982 .44527 Mdot
.61651 .75279 Mdot
.41065 .70578 Mdot
.60866 .28903 Mdot
.25435 .51532 Mdot
.61235 .28678 Mdot
.59421 .63715 Mdot
.37397 .61576 Mdot
.28064 .4079 Mdot
.4341 .4341 Mdot
.29126 .40211 Mdot
.7301 .44333 Mdot
.37906 .63098 Mdot
.58952 .66524 Mdot
.2544 .52484 Mdot
.62535 .36492 Mdot
.28862 .48896 Mdot
.39561 .39982 Mdot
.36397 .40051 Mdot
.32239 .46666 Mdot
.36215 .44166 Mdot
.40247 .64003 Mdot
.30823 .40486 Mdot
.62191 .40881 Mdot
.35688 .42642 Mdot
.48146 .74781 Mdot
.40067 .41418 Mdot
.43064 .40311 Mdot
.41903 .40558 Mdot
.33448 .41686 Mdot
.39593 .62134 Mdot
.26606 .52857 Mdot
.59101 .65486 Mdot
.32691 .44053 Mdot
.58635 .71167 Mdot
.68018 .52941 Mdot
.57579 .41987 Mdot
.38729 .61266 Mdot
.6109 .29022 Mdot
.5124 .68491 Mdot
.32946 .46182 Mdot
.69943 .50879 Mdot
.46414 .34526 Mdot
.56838 .27261 Mdot
.58138 .39115 Mdot
.61719 .25475 Mdot
.72548 .52029 Mdot
.59286 .69056 Mdot
.43776 .41879 Mdot
.39266 .70986 Mdot
.38121 .70151 Mdot
.35816 .43066 Mdot
.6259 .74904 Mdot
.59459 .72832 Mdot
.77271 .51693 Mdot
.42762 .40506 Mdot
.3614 .44068 Mdot
.40064 .71662 Mdot
.75519 .52241 Mdot
.28366 .39272 Mdot
.59323 .28772 Mdot
.37856 .43841 Mdot
.62689 .39784 Mdot
.30076 .40638 Mdot
.59706 .65253 Mdot
.61706 .38536 Mdot
.40115 .40973 Mdot
.35043 .44352 Mdot
.27053 .54198 Mdot
.62431 .42431 Mdot
.68395 .562 Mdot
.37331 .44129 Mdot
.36729 .43101 Mdot
.38962 .62725 Mdot
.58068 .7119 Mdot
.38544 .66915 Mdot
.37632 .59858 Mdot
.59318 .39117 Mdot
.58167 .71804 Mdot
.3347 .41797 Mdot
.58974 .7383 Mdot
.26701 .50192 Mdot
.3727 .42359 Mdot
.5909 .66358 Mdot
.40378 .68269 Mdot
.45247 .7655 Mdot
.45851 .40138 Mdot
.26767 .50838 Mdot
.38711 .408 Mdot
.76844 .51336 Mdot
.57245 .4146 Mdot
.42631 .43839 Mdot
.37888 .69847 Mdot
.37839 .41394 Mdot
.60166 .64572 Mdot
.59082 .25906 Mdot
.38471 .6896 Mdot
.75152 .53277 Mdot
.70822 .53553 Mdot
.67338 .56405 Mdot
.59424 .36992 Mdot
.27521 .50154 Mdot
.3883 .63466 Mdot
.37925 .6664 Mdot
.29819 .40252 Mdot
.70038 .53526 Mdot
.58578 .28128 Mdot
.35791 .41835 Mdot
.62821 .39394 Mdot
.5683 .67726 Mdot
.28305 .56762 Mdot
.29629 .41334 Mdot
.60991 .24692 Mdot
.35793 .33991 Mdot
.59793 .39413 Mdot
.42603 .41981 Mdot
.61622 .26217 Mdot
.7297 .52795 Mdot
.27665 .53942 Mdot
.56554 .28592 Mdot
.77958 .52024 Mdot
.72329 .51243 Mdot
.5971 .72916 Mdot
.67342 .5666 Mdot
.61781 .27247 Mdot
.58513 .40985 Mdot
.38319 .69739 Mdot
.40995 .4283 Mdot
.592 .40253 Mdot
.68188 .54397 Mdot
.60501 .36952 Mdot
.43315 .41462 Mdot
.40366 .71279 Mdot
.66547 .53462 Mdot
.36813 .42256 Mdot
.24949 .5207 Mdot
.33217 .57771 Mdot
.75803 .52588 Mdot
.3076 .40136 Mdot
.60669 .21717 Mdot
.69244 .51171 Mdot
.714 .51601 Mdot
.36557 .4401 Mdot
.58917 .31146 Mdot
.39517 .42127 Mdot
.5904 .68959 Mdot
.2662 .38863 Mdot
.58269 .7167 Mdot
.43313 .30807 Mdot
.3536 .43262 Mdot
.31729 .39256 Mdot
.41486 .73308 Mdot
.55775 .28 Mdot
.40098 .2973 Mdot
.4231 .43 Mdot
.37479 .72523 Mdot
.26909 .395 Mdot
.31396 .32273 Mdot
.37791 .60472 Mdot
.58823 .25747 Mdot
.60504 .66971 Mdot
.36114 .41503 Mdot
.48632 .74281 Mdot
.58184 .28235 Mdot
.43439 .31063 Mdot
.33081 .40261 Mdot
.38911 .67476 Mdot
.41418 .39983 Mdot
.3881 .69682 Mdot
.39701 .40801 Mdot
.33876 .57968 Mdot
.60793 .74334 Mdot
.32058 .45459 Mdot
.58456 .40774 Mdot
.66044 .62071 Mdot
.37668 .50943 Mdot
.58851 .27369 Mdot
.25441 .53536 Mdot
.59869 .38811 Mdot
.59207 .69797 Mdot
.60124 .73106 Mdot
.67546 .53893 Mdot
.58047 .68557 Mdot
.40684 .65971 Mdot
.76799 .52076 Mdot
.61751 .37328 Mdot
.28998 .52587 Mdot
.61151 .29253 Mdot
.58126 .71793 Mdot
.40049 .43448 Mdot
.4051 .39207 Mdot
.78571 .5132 Mdot
.76183 .49863 Mdot
.39938 .73711 Mdot
.31014 .57326 Mdot
.37387 .61438 Mdot
.60248 .27269 Mdot
.76095 .52562 Mdot
.40358 .40258 Mdot
.41779 .42013 Mdot
.73373 .51437 Mdot
.38457 .61258 Mdot
.58388 .30328 Mdot
.59776 .4331 Mdot
.59545 .64726 Mdot
.81097 .49608 Mdot
.38434 .69179 Mdot
.81337 .49717 Mdot
.78851 .50478 Mdot
.42144 .76202 Mdot
.40441 .2989 Mdot
.59043 .67928 Mdot
.81404 .49716 Mdot
.39168 .67142 Mdot
.4096 .44463 Mdot
.60503 .37836 Mdot
.59896 .3681 Mdot
.40677 .6999 Mdot
.67607 .52733 Mdot
.58734 .3119 Mdot
.3961 .39824 Mdot
.60898 .24105 Mdot
.38111 .61046 Mdot
.67315 .56056 Mdot
.61282 .39613 Mdot
.60863 .67197 Mdot
.3825 .41098 Mdot
.58078 .29176 Mdot
.59176 .67769 Mdot
.60408 .41866 Mdot
.328 .44795 Mdot
.28376 .38283 Mdot
.25903 .50277 Mdot
.60336 .67452 Mdot
.29309 .39741 Mdot
.37902 .43705 Mdot
.58422 .71283 Mdot
.63615 .38235 Mdot
.66338 .61982 Mdot
.27412 .38575 Mdot
.61282 .74664 Mdot
.73474 .5114 Mdot
.67587 .56626 Mdot
.70332 .5585 Mdot
.79127 .51482 Mdot
.58388 .70775 Mdot
.6004 .40259 Mdot
.80344 .50154 Mdot
.58114 .71279 Mdot
.31847 .40253 Mdot
.36165 .41509 Mdot
.35398 .3855 Mdot
.60553 .41933 Mdot
.61281 .41138 Mdot
.36231 .59479 Mdot
.26427 .53253 Mdot
.61165 .39523 Mdot
.40326 .43726 Mdot
.38397 .63255 Mdot
.58588 .67161 Mdot
.59491 .19884 Mdot
.59128 .64344 Mdot
.28116 .5369 Mdot
.67224 .51731 Mdot
.76685 .51988 Mdot
.40799 .42879 Mdot
.56131 .62635 Mdot
.55599 .1777 Mdot
.36167 .41436 Mdot
.25426 .51551 Mdot
.43658 .30962 Mdot
.35693 .42754 Mdot
.41402 .67814 Mdot
.62391 .39903 Mdot
.38499 .6328 Mdot
.59066 .67387 Mdot
.58615 .25974 Mdot
.57462 .2304 Mdot
.60435 .66735 Mdot
.40306 .41523 Mdot
.57324 .40429 Mdot
.39624 .42986 Mdot
.43022 .42797 Mdot
.32809 .43119 Mdot
.5946 .25015 Mdot
.67314 .53498 Mdot
.61178 .28921 Mdot
.38106 .72185 Mdot
.30336 .56999 Mdot
.58655 .27456 Mdot
.34671 .38892 Mdot
.27513 .39542 Mdot
.75776 .49994 Mdot
.38104 .70004 Mdot
.57912 .27101 Mdot
.60544 .67889 Mdot
.31506 .32981 Mdot
.33551 .39211 Mdot
.58089 .67377 Mdot
.4306 .41999 Mdot
.37783 .66757 Mdot
.36928 .59926 Mdot
.58898 .73157 Mdot
.38366 .66495 Mdot
.29037 .39606 Mdot
.2736 .50931 Mdot
.59676 .6514 Mdot
.38145 .29894 Mdot
.58373 .72072 Mdot
.41106 .50102 Mdot
.26272 .50712 Mdot
.38546 .68733 Mdot
.34302 .49962 Mdot
.37504 .63076 Mdot
.60289 .41527 Mdot
.33221 .42659 Mdot
.58711 .27935 Mdot
.29052 .40041 Mdot
.75053 .53516 Mdot
.41266 .7171 Mdot
.39458 .68669 Mdot
.58392 .63222 Mdot
.38199 .67246 Mdot
.40607 .71921 Mdot
.60584 .71573 Mdot
.41107 .66306 Mdot
.40027 .41756 Mdot
.25735 .56119 Mdot
.39267 .64139 Mdot
.59795 .66763 Mdot
.58754 .29481 Mdot
.39968 .63914 Mdot
.79084 .50624 Mdot
.36552 .43543 Mdot
.67125 .55363 Mdot
.58007 .30989 Mdot
.39342 .62035 Mdot
.5892 .27662 Mdot
.6754 .54408 Mdot
.57476 .26067 Mdot
.57157 .65314 Mdot
.58126 .72535 Mdot
.60769 .42861 Mdot
.61075 .74865 Mdot
.37868 .72129 Mdot
.77535 .52378 Mdot
.39299 .39569 Mdot
.42714 .4074 Mdot
.59172 .32157 Mdot
.38071 .73107 Mdot
.62739 .75515 Mdot
.60777 .3938 Mdot
.36004 .59823 Mdot
.60817 .68814 Mdot
.76932 .51669 Mdot
.2677 .40053 Mdot
.60186 .73516 Mdot
.62039 .4116 Mdot
.59719 .39226 Mdot
.39734 .43191 Mdot
.45739 .33239 Mdot
.6141 .25666 Mdot
.66355 .60471 Mdot
.28476 .52276 Mdot
.74071 .51767 Mdot
.41344 .40759 Mdot
.27686 .52882 Mdot
.41397 .43903 Mdot
.62086 .25414 Mdot
.57755 .68276 Mdot
.38333 .70657 Mdot
.58181 .26409 Mdot
.70881 .53552 Mdot
.25928 .40699 Mdot
.42318 .44092 Mdot
.29792 .3958 Mdot
.6751 .52093 Mdot
.3746 .71277 Mdot
.68647 .53107 Mdot
.58445 .71239 Mdot
.58673 .26941 Mdot
.27205 .50295 Mdot
.60673 .4194 Mdot
.65667 .5557 Mdot
.58676 .69724 Mdot
.75657 .53187 Mdot
.59857 .72826 Mdot
.59508 .39 Mdot
.28318 .38696 Mdot
.64893 .56528 Mdot
.59884 .37626 Mdot
.35595 .59976 Mdot
.33581 .4494 Mdot
.42266 .75239 Mdot
.67716 .52366 Mdot
.63942 .35586 Mdot
.59395 .67315 Mdot
.58317 .6447 Mdot
.39253 .51068 Mdot
.52111 .16423 Mdot
.32914 .42661 Mdot
.63332 .76072 Mdot
.583 .71187 Mdot
.60099 .6806 Mdot
.68445 .5335 Mdot
.40434 .68364 Mdot
.42514 .69995 Mdot
.66276 .52951 Mdot
.41742 .30744 Mdot
.39319 .66343 Mdot
.3142 .38642 Mdot
.64931 .55773 Mdot
.2651 .52242 Mdot
.34403 .589 Mdot
.57421 .28305 Mdot
.44675 .32375 Mdot
.59833 .73334 Mdot
.36922 .40937 Mdot
.46756 .76673 Mdot
.68016 .53938 Mdot
.60011 .37209 Mdot
.58044 .62886 Mdot
.40957 .39158 Mdot
.42021 .4102 Mdot
.3826 .4212 Mdot
.59148 .32039 Mdot
.3507 .5916 Mdot
.38517 .40296 Mdot
.33003 .45224 Mdot
.28622 .50628 Mdot
.71622 .55187 Mdot
.61468 .2806 Mdot
.4672 .35032 Mdot
.73178 .50363 Mdot
.36019 .59631 Mdot
.37511 .3969 Mdot
.57878 .65621 Mdot
.26602 .5322 Mdot
.59525 .65769 Mdot
.60718 .69831 Mdot
.81217 .49312 Mdot
.37738 .69653 Mdot
.28424 .51114 Mdot
.7277 .53763 Mdot
.41698 .72921 Mdot
.28039 .52225 Mdot
.30624 .57193 Mdot
.58692 .63235 Mdot
.50755 .16194 Mdot
.58041 .646 Mdot
.60351 .36775 Mdot
.40899 .66405 Mdot
.36943 .71389 Mdot
.30095 .40564 Mdot
.39703 .70632 Mdot
.78395 .51449 Mdot
.38855 .63611 Mdot
.79931 .41266 Mdot
.37782 .62304 Mdot
.59706 .67475 Mdot
.58569 .72532 Mdot
.27191 .52536 Mdot
.40505 .41797 Mdot
.27784 .40975 Mdot
.60842 .39309 Mdot
.28915 .38731 Mdot
.70147 .519 Mdot
.79502 .50551 Mdot
.64676 .76113 Mdot
.4124 .67517 Mdot
.5854 .70162 Mdot
.41924 .40941 Mdot
.26401 .50614 Mdot
.37012 .44434 Mdot
.60366 .74066 Mdot
.27243 .48465 Mdot
.38405 .42785 Mdot
.27537 .52211 Mdot
.6657 .52457 Mdot
.74517 .50887 Mdot
.42543 .7561 Mdot
.81102 .49439 Mdot
.41869 .4316 Mdot
.60303 .28121 Mdot
.6188 .2527 Mdot
.44437 .4263 Mdot
.64113 .57931 Mdot
.28271 .3934 Mdot
.39846 .43472 Mdot
.25784 .40627 Mdot
.65947 .5303 Mdot
.60867 .36185 Mdot
.68711 .54244 Mdot
.38067 .60394 Mdot
.57791 .40121 Mdot
.71618 .51987 Mdot
.2722 .41198 Mdot
.59273 .39828 Mdot
.66336 .61813 Mdot
.58009 .28482 Mdot
.39485 .43876 Mdot
.41299 .50547 Mdot
.65321 .56378 Mdot
.5946 .68466 Mdot
.40348 .6477 Mdot
.59129 .65623 Mdot
.73959 .5082 Mdot
.42291 .30551 Mdot
.60884 .41629 Mdot
.58302 .65219 Mdot
.27196 .49275 Mdot
.60199 .28689 Mdot
.57898 .64446 Mdot
.2756 .50008 Mdot
.44615 .42445 Mdot
.54 .17127 Mdot
.42399 .39661 Mdot
.79704 .50532 Mdot
.57989 .71413 Mdot
.63159 .36886 Mdot
.41027 .42689 Mdot
.67578 .55644 Mdot
.61016 .23621 Mdot
.39211 .43067 Mdot
.7475 .53382 Mdot
.36745 .42869 Mdot
.61594 .2631 Mdot
.3876 .62672 Mdot
.26402 .38973 Mdot
.60406 .31453 Mdot
.58343 .26311 Mdot
.32217 .46396 Mdot
.36773 .44422 Mdot
.66334 .59437 Mdot
.38769 .67343 Mdot
.39975 .44496 Mdot
.59782 .32399 Mdot
.40824 .67853 Mdot
.39889 .65138 Mdot
.27779 .53932 Mdot
.60433 .64591 Mdot
.67186 .53053 Mdot
.60834 .28222 Mdot
.77188 .511 Mdot
.36743 .41207 Mdot
.26124 .53972 Mdot
.57949 .27767 Mdot
.58569 .68604 Mdot
.27893 .50719 Mdot
.64202 .75646 Mdot
.3269 .44151 Mdot
.57959 .6415 Mdot
.35388 .40528 Mdot
.32996 .4874 Mdot
.38162 .62353 Mdot
.47273 .75994 Mdot
.60927 .74033 Mdot
.69935 .54091 Mdot
.61153 .39782 Mdot
.29193 .56886 Mdot
.58141 .29075 Mdot
.4265 .70032 Mdot
.43134 .41122 Mdot
.4024 .40441 Mdot
.38392 .6277 Mdot
.43315 .43607 Mdot
.41244 .69385 Mdot
.78314 .507 Mdot
.51794 .16307 Mdot
.38472 .70206 Mdot
.39214 .68319 Mdot
.25792 .54951 Mdot
.64808 .53631 Mdot
.40935 .69612 Mdot
.36026 .41505 Mdot
.74393 .50934 Mdot
.62553 .42252 Mdot
.58907 .30294 Mdot
.57668 .31712 Mdot
.41033 .71333 Mdot
.34904 .39394 Mdot
.26405 .50099 Mdot
.46118 .38897 Mdot
.36493 .34134 Mdot
.58226 .7078 Mdot
.35782 .40967 Mdot
.60395 .3927 Mdot
.68144 .54235 Mdot
.43375 .39993 Mdot
.40323 .43779 Mdot
.38441 .71076 Mdot
.57268 .27201 Mdot
.59333 .71293 Mdot
.59515 .37728 Mdot
.65952 .56741 Mdot
.59651 .27726 Mdot
.39914 .72869 Mdot
.38213 .51034 Mdot
.58361 .42125 Mdot
.62475 .38444 Mdot
.42621 .4258 Mdot
.37724 .44246 Mdot
.60599 .42252 Mdot
.60155 .66181 Mdot
.69661 .54282 Mdot
.58612 .38624 Mdot
.28887 .39844 Mdot
.25941 .39683 Mdot
.42178 .41706 Mdot
.38732 .64684 Mdot
.589 .70047 Mdot
.61075 .41433 Mdot
.80883 .50382 Mdot
.35684 .41943 Mdot
.3331 .39717 Mdot
.61395 .45313 Mdot
.6025 .39746 Mdot
.42477 .70204 Mdot
.60587 .2983 Mdot
.26266 .50752 Mdot
.32641 .45301 Mdot
.29771 .38729 Mdot
.37352 .398 Mdot
.73109 .52572 Mdot
.6058 .69273 Mdot
.62578 .41554 Mdot
.69517 .53697 Mdot
.39827 .6502 Mdot
.46174 .38699 Mdot
.37417 .69579 Mdot
.37931 .66786 Mdot
.40778 .73094 Mdot
.60447 .65528 Mdot
.28881 .568 Mdot
.59857 .42346 Mdot
.4281 .40319 Mdot
.57576 .69321 Mdot
.40909 .70331 Mdot
.31071 .39223 Mdot
.41083 .70525 Mdot
.38472 .7321 Mdot
.29373 .38466 Mdot
.2734 .51909 Mdot
.33026 .45651 Mdot
.39499 .39065 Mdot
.59778 .31179 Mdot
.37787 .65807 Mdot
.33401 .3948 Mdot
.39771 .40272 Mdot
.41566 .42739 Mdot
.26987 .52693 Mdot
.59954 .24978 Mdot
.46433 .38274 Mdot
.43046 .41187 Mdot
.46135 .33141 Mdot
.31247 .39422 Mdot
.37712 .72997 Mdot
.56769 .66375 Mdot
.28045 .53799 Mdot
.71327 .50898 Mdot
.38408 .61645 Mdot
.57392 .2794 Mdot
.41928 .69113 Mdot
.25666 .50315 Mdot
.60034 .69263 Mdot
.39402 .67756 Mdot
.66074 .54199 Mdot
.59246 .6847 Mdot
.58385 .72087 Mdot
.26619 .52737 Mdot
.70522 .541 Mdot
.57317 .26982 Mdot
.59271 .72291 Mdot
.28607 .48646 Mdot
.59701 .67647 Mdot
.41452 .75689 Mdot
.28207 .38762 Mdot
.32702 .45155 Mdot
.59851 .40795 Mdot
.63338 .39791 Mdot
.58755 .71764 Mdot
.59193 .28933 Mdot
.28039 .508 Mdot
.40034 .64269 Mdot
.59714 .291 Mdot
.34426 .58688 Mdot
.76388 .51933 Mdot
.36935 .60095 Mdot
.78544 .5117 Mdot
.39795 .70924 Mdot
.44431 .32113 Mdot
.57653 .26771 Mdot
.62646 .40789 Mdot
.29883 .41013 Mdot
.61447 .39622 Mdot
.43404 .40235 Mdot
.28296 .51046 Mdot
.39865 .41753 Mdot
.68634 .511 Mdot
.58987 .3212 Mdot
.39105 .64107 Mdot
.58519 .22599 Mdot
.58335 .67735 Mdot
.29774 .39806 Mdot
.59516 .37414 Mdot
.26723 .50755 Mdot
.41143 .6956 Mdot
.39064 .72379 Mdot
.34706 .58294 Mdot
.69447 .51104 Mdot
.56098 .26742 Mdot
.41794 .41391 Mdot
.59147 .23098 Mdot
.58535 .7178 Mdot
.61111 .74988 Mdot
.66337 .55143 Mdot
.50469 .16545 Mdot
.70071 .53369 Mdot
.62776 .42419 Mdot
.39809 .71391 Mdot
.60709 .25938 Mdot
.41065 .41501 Mdot
.39458 .62453 Mdot
.42559 .69859 Mdot
.57506 .31241 Mdot
.61137 .2883 Mdot
.60478 .74589 Mdot
.57459 .69637 Mdot
.61494 .37485 Mdot
.31365 .39551 Mdot
.31506 .39333 Mdot
.40491 .3936 Mdot
.58103 .70245 Mdot
.27081 .51313 Mdot
.57035 .65386 Mdot
.25335 .52246 Mdot
.5969 .32532 Mdot
.71798 .51529 Mdot
.68659 .70908 Mdot
.3889 .62053 Mdot
.46223 .38363 Mdot
.41327 .74544 Mdot
.33567 .4479 Mdot
.57863 .6696 Mdot
.63674 .38355 Mdot
.6778 .53419 Mdot
.52008 .66962 Mdot
.72259 .51713 Mdot
.5758 .20054 Mdot
.35924 .38534 Mdot
.58301 .63022 Mdot
.29489 .39105 Mdot
.71857 .53977 Mdot
.40722 .38896 Mdot
.58544 .39049 Mdot
.57333 .40389 Mdot
.24929 .50746 Mdot
.31985 .57479 Mdot
.60015 .3096 Mdot
.41105 .41456 Mdot
.38433 .63851 Mdot
.41291 .41596 Mdot
.41449 .41601 Mdot
.43236 .42676 Mdot
.59782 .73625 Mdot
.28704 .38923 Mdot
.40305 .41777 Mdot
.80433 .50481 Mdot
.62586 .41988 Mdot
.65272 .57047 Mdot
.38042 .62143 Mdot
.5975 .29391 Mdot
.37914 .61055 Mdot
.27847 .40297 Mdot
.58927 .64064 Mdot
.34931 .59066 Mdot
.26496 .51664 Mdot
.4123 .71539 Mdot
.58297 .64942 Mdot
.58086 .30513 Mdot
.6013 .3912 Mdot
.42117 .77794 Mdot
.78777 .51572 Mdot
.61275 .38434 Mdot
.75294 .52847 Mdot
.39395 .39162 Mdot
.38248 .69428 Mdot
.61391 .39449 Mdot
.59862 .70962 Mdot
.73588 .52542 Mdot
.32736 .46197 Mdot
.37394 .41548 Mdot
.68169 .51978 Mdot
.59588 .40381 Mdot
.28907 .40011 Mdot
.27087 .39636 Mdot
.71786 .54053 Mdot
.61119 .66932 Mdot
.58849 .72351 Mdot
.58855 .29782 Mdot
.37795 .72492 Mdot
.38696 .71846 Mdot
.58411 .67874 Mdot
.52441 .66313 Mdot
.36629 .41969 Mdot
.37032 .41976 Mdot
.28655 .4085 Mdot
.32994 .42132 Mdot
.7959 .51499 Mdot
.61034 .38417 Mdot
.39331 .70438 Mdot
.28343 .51121 Mdot
.27585 .53412 Mdot
.40662 .41357 Mdot
.41388 .30289 Mdot
.66532 .53147 Mdot
.25875 .50804 Mdot
.61587 .26115 Mdot
.32846 .57486 Mdot
.36847 .43505 Mdot
.59874 .32626 Mdot
.39169 .72083 Mdot
.66373 .61143 Mdot
.59558 .68447 Mdot
.71888 .54227 Mdot
.72443 .53927 Mdot
.73198 .44156 Mdot
.38757 .62082 Mdot
.61294 .3851 Mdot
.78408 .52195 Mdot
.58087 .38329 Mdot
.61138 .2861 Mdot
.46518 .36401 Mdot
.78627 .51441 Mdot
.65685 .57007 Mdot
.58559 .62961 Mdot
.35502 .40893 Mdot
.38144 .43921 Mdot
.61387 .74611 Mdot
.41141 .43154 Mdot
.5836 .27436 Mdot
.57242 .67788 Mdot
.39326 .67621 Mdot
.59287 .314 Mdot
.57719 .6578 Mdot
.3865 .72045 Mdot
.2654 .52565 Mdot
.31296 .39336 Mdot
.40086 .64854 Mdot
.4004 .72337 Mdot
.36468 .41985 Mdot
.81578 .49064 Mdot
.38772 .70799 Mdot
.40719 .654 Mdot
.32719 .57566 Mdot
.67566 .562 Mdot
.61445 .23936 Mdot
.60087 .64345 Mdot
.39382 .42073 Mdot
.70715 .5135 Mdot
.61032 .2675 Mdot
.39604 .68532 Mdot
.40988 .44021 Mdot
.3692 .41113 Mdot
.60196 .28588 Mdot
.61915 .26529 Mdot
.59308 .29146 Mdot
.59013 .73157 Mdot
.26442 .52021 Mdot
.41085 .68426 Mdot
.57948 .68907 Mdot
.57534 .28003 Mdot
.6146 .28628 Mdot
.57729 .33299 Mdot
.36642 .42162 Mdot
.61982 .26644 Mdot
.30125 .56963 Mdot
.27983 .41716 Mdot
.5797 .3848 Mdot
.64447 .37253 Mdot
.63952 .56368 Mdot
.64095 .41978 Mdot
.60577 .6908 Mdot
.25535 .52315 Mdot
.58821 .30443 Mdot
.5882 .40112 Mdot
.3709 .41701 Mdot
.35456 .42815 Mdot
.60071 .28262 Mdot
.42249 .30355 Mdot
.38179 .71173 Mdot
.42453 .75142 Mdot
.60014 .29071 Mdot
.69776 .54988 Mdot
.65823 .53262 Mdot
.6997 .5284 Mdot
.42297 .42091 Mdot
.2989 .38138 Mdot
.32848 .33483 Mdot
.35595 .58701 Mdot
.57803 .70537 Mdot
.39523 .72093 Mdot
.32751 .58077 Mdot
.39877 .65264 Mdot
.744 .51521 Mdot
.59148 .28919 Mdot
.38264 .6406 Mdot
.588 .72925 Mdot
.58984 .72144 Mdot
.65262 .5656 Mdot
.70214 .53488 Mdot
.68895 .52539 Mdot
.38901 .61514 Mdot
.40543 .7061 Mdot
.29041 .38607 Mdot
.38162 .66663 Mdot
.7285 .50219 Mdot
.78411 .50706 Mdot
.65106 .56445 Mdot
.59603 .6643 Mdot
.40212 .67899 Mdot
.36665 .42975 Mdot
.31966 .46751 Mdot
.65708 .53339 Mdot
.57462 .29037 Mdot
.25947 .56127 Mdot
.52339 .16505 Mdot
.2607 .53674 Mdot
.59435 .70283 Mdot
.58985 .41048 Mdot
.3848 .41922 Mdot
.69246 .54379 Mdot
.64571 .38515 Mdot
.62312 .3982 Mdot
.30299 .39977 Mdot
.23857 .52947 Mdot
.59484 .69644 Mdot
.26809 .39663 Mdot
.58642 .39286 Mdot
.28255 .5026 Mdot
.5732 .67684 Mdot
.65567 .55711 Mdot
.7084 .55591 Mdot
.36152 .59372 Mdot
.46381 .35977 Mdot
.59492 .41742 Mdot
.38398 .39768 Mdot
.71321 .52107 Mdot
.59222 .313 Mdot
.70413 .52095 Mdot
.37904 .73369 Mdot
.66375 .56523 Mdot
.37704 .43483 Mdot
.41017 .68505 Mdot
.58806 .72113 Mdot
.31915 .33065 Mdot
.57932 .22625 Mdot
.6675 .55894 Mdot
.62106 .41523 Mdot
.27001 .53349 Mdot
.29176 .52166 Mdot
.63346 .39823 Mdot
.38386 .43875 Mdot
.59126 .66247 Mdot
.41226 .68825 Mdot
.58391 .68868 Mdot
.61241 .23635 Mdot
.40039 .76885 Mdot
.59598 .68581 Mdot
.29391 .37977 Mdot
.58742 .31254 Mdot
.41951 .30404 Mdot
.38427 .43542 Mdot
.60151 .7068 Mdot
.29404 .39413 Mdot
.38186 .63522 Mdot
.27108 .40984 Mdot
.32858 .44308 Mdot
.58685 .66859 Mdot
.61599 .37113 Mdot
.27289 .39343 Mdot
.60888 .23705 Mdot
.58589 .71201 Mdot
.25737 .40042 Mdot
.60674 .3802 Mdot
.59511 .27148 Mdot
.59331 .31855 Mdot
.59391 .27986 Mdot
.37927 .42629 Mdot
.33343 .49073 Mdot
.5781 .26716 Mdot
.60665 .71548 Mdot
.58594 .26307 Mdot
.63903 .41218 Mdot
.62559 .7566 Mdot
.61771 .27258 Mdot
.40464 .43482 Mdot
.25365 .52295 Mdot
.25609 .52387 Mdot
.67092 .55113 Mdot
.4251 .78092 Mdot
.80175 .50411 Mdot
.40548 .40257 Mdot
.32279 .58473 Mdot
.38723 .63238 Mdot
.61248 .42353 Mdot
.32974 .44435 Mdot
.26414 .49802 Mdot
.40313 .65569 Mdot
.28824 .40658 Mdot
.36636 .60002 Mdot
.58185 .4001 Mdot
.37684 .42644 Mdot
.38375 .62078 Mdot
.40892 .72705 Mdot
.39987 .2978 Mdot
.36089 .59841 Mdot
.39905 .69771 Mdot
.58013 .71166 Mdot
.60618 .68284 Mdot
.58988 .66375 Mdot
.70608 .53487 Mdot
.39313 .68401 Mdot
.44832 .41935 Mdot
.69803 .54087 Mdot
.43105 .41828 Mdot
.58538 .6725 Mdot
.32243 .44391 Mdot
.39213 .6819 Mdot
.39138 .43519 Mdot
.32481 .38916 Mdot
.74752 .53245 Mdot
.60155 .28552 Mdot
.31324 .57412 Mdot
.71102 .55301 Mdot
.59735 .7293 Mdot
.37519 .73254 Mdot
.63749 .4039 Mdot
.28021 .4987 Mdot
.40808 .44227 Mdot
.43768 .42234 Mdot
.28142 .50014 Mdot
.35998 .38651 Mdot
.62357 .3862 Mdot
.70886 .53535 Mdot
.69558 .55552 Mdot
.36145 .42953 Mdot
.39219 .69236 Mdot
.61592 .24827 Mdot
.60284 .32384 Mdot
.56533 .29046 Mdot
.27522 .39714 Mdot
.32988 .45202 Mdot
.33422 .42197 Mdot
.46299 .37733 Mdot
.66577 .54634 Mdot
.60876 .36265 Mdot
.29789 .40543 Mdot
.59025 .27119 Mdot
.41691 .44178 Mdot
.37962 .61829 Mdot
.39644 .67921 Mdot
.67542 .52563 Mdot
.56906 .69131 Mdot
.57919 .41849 Mdot
.64824 .56348 Mdot
.36212 .43044 Mdot
.28276 .52548 Mdot
.57157 .69623 Mdot
.39291 .73549 Mdot
.59881 .27262 Mdot
.68797 .54425 Mdot
.59716 .25984 Mdot
.38259 .67146 Mdot
.39626 .68689 Mdot
.37065 .44379 Mdot
.56895 .24495 Mdot
.65774 .5603 Mdot
.42031 .41787 Mdot
.68646 .51906 Mdot
.78104 .51322 Mdot
.57286 .65008 Mdot
.40202 .44499 Mdot
.42346 .70717 Mdot
.59071 .65897 Mdot
.41394 .40463 Mdot
.26086 .52739 Mdot
.27784 .50711 Mdot
.70978 .5439 Mdot
.57073 .28637 Mdot
.59448 .26653 Mdot
.39872 .76106 Mdot
.35371 .6192 Mdot
.33914 .41848 Mdot
.67288 .56155 Mdot
.27751 .48555 Mdot
.59949 .68791 Mdot
.39969 .70833 Mdot
.66627 .72977 Mdot
.59866 .66956 Mdot
.36536 .42557 Mdot
.58612 .2751 Mdot
.393 .72994 Mdot
.57814 .3872 Mdot
.32147 .31404 Mdot
.63121 .38591 Mdot
.56195 .26493 Mdot
.59826 .37741 Mdot
.63424 .75321 Mdot
.69101 .52298 Mdot
.41046 .6994 Mdot
.59381 .70534 Mdot
.60008 .69053 Mdot
.7535 .52327 Mdot
.34332 .58175 Mdot
.42345 .75861 Mdot
.27159 .56458 Mdot
.78593 .51637 Mdot
.5882 .28549 Mdot
.28087 .41524 Mdot
.69849 .52964 Mdot
.74177 .54094 Mdot
.60137 .74442 Mdot
.61173 .75 Mdot
.40401 .67605 Mdot
.37429 .40743 Mdot
.3329 .57738 Mdot
.43374 .4105 Mdot
.46496 .36045 Mdot
.58557 .68196 Mdot
.3993 .70887 Mdot
.60678 .75161 Mdot
.36416 .438 Mdot
.39244 .4103 Mdot
.74227 .50428 Mdot
.60749 .38989 Mdot
.75234 .49651 Mdot
.4178 .44234 Mdot
.71338 .52757 Mdot
.40721 .74336 Mdot
.58574 .40521 Mdot
.33673 .39448 Mdot
.57601 .70989 Mdot
.61016 .41555 Mdot
.58393 .40174 Mdot
.45768 .37507 Mdot
.37161 .60316 Mdot
.37175 .69548 Mdot
.61817 .25662 Mdot
.61192 .75562 Mdot
.57402 .65588 Mdot
.64009 .75597 Mdot
.36477 .42867 Mdot
.58458 .72768 Mdot
.59261 .43269 Mdot
.41503 .40382 Mdot
.2801 .52054 Mdot
.34794 .58656 Mdot
.36903 .40192 Mdot
.25187 .51207 Mdot
.59522 .6711 Mdot
.58098 .43625 Mdot
.3436 .41467 Mdot
.67887 .52228 Mdot
.40469 .684 Mdot
.37361 .60148 Mdot
.59593 .30531 Mdot
.60885 .74341 Mdot
.51246 .16335 Mdot
.40022 .70678 Mdot
.37378 .41849 Mdot
.60019 .68333 Mdot
.59051 .41355 Mdot
.60343 .4078 Mdot
.63031 .40066 Mdot
.39783 .67489 Mdot
.58798 .40558 Mdot
.41193 .74249 Mdot
.28354 .40514 Mdot
.46312 .38481 Mdot
.60406 .65651 Mdot
.58759 .28308 Mdot
.59153 .24425 Mdot
.77485 .51293 Mdot
.31627 .39861 Mdot
.46565 .36055 Mdot
.38305 .75401 Mdot
.58463 .27948 Mdot
.39429 .41726 Mdot
.6236 .38463 Mdot
.24956 .39294 Mdot
.62561 .25739 Mdot
.60469 .37533 Mdot
.28134 .53193 Mdot
.38053 .72207 Mdot
.61614 .3914 Mdot
.39362 .67181 Mdot
.39873 .41559 Mdot
.29779 .39967 Mdot
.37231 .712 Mdot
.43795 .77486 Mdot
.58402 .42245 Mdot
.57831 .65204 Mdot
.29048 .39407 Mdot
.41694 .43389 Mdot
.30934 .38478 Mdot
.59739 .41402 Mdot
.4771 .74982 Mdot
.70104 .51551 Mdot
.80099 .50017 Mdot
.79685 .51594 Mdot
.60575 .73599 Mdot
.64205 .76207 Mdot
.353 .43426 Mdot
.34246 .57871 Mdot
.30543 .38346 Mdot
.58999 .65146 Mdot
.33767 .40044 Mdot
.40479 .41799 Mdot
.42633 .42384 Mdot
.68551 .51906 Mdot
.58641 .63122 Mdot
.27912 .53856 Mdot
.29491 .40425 Mdot
.57268 .2944 Mdot
.38651 .6669 Mdot
.39403 .424 Mdot
.38094 .75081 Mdot
.70515 .5469 Mdot
.40675 .77456 Mdot
.40374 .43418 Mdot
.60709 .38961 Mdot
.58428 .73098 Mdot
.58541 .71936 Mdot
.70044 .54674 Mdot
.69331 .55005 Mdot
.41737 .43322 Mdot
.58126 .67752 Mdot
.32693 .40554 Mdot
.27449 .39447 Mdot
.59391 .40259 Mdot
.61112 .27847 Mdot
.43628 .40756 Mdot
.42369 .75623 Mdot
.56998 .23367 Mdot
.42201 .41854 Mdot
.37499 .68381 Mdot
.68429 .52783 Mdot
.76152 .52031 Mdot
.38944 .7159 Mdot
.7634 .5212 Mdot
.40829 .77487 Mdot
.33438 .48999 Mdot
.61429 .27569 Mdot
.29298 .53195 Mdot
.58481 .26182 Mdot
.60788 .41541 Mdot
.36667 .4225 Mdot
.66241 .59992 Mdot
.79474 .51741 Mdot
.24521 .43244 Mdot
.58973 .68499 Mdot
.59835 .36804 Mdot
.26908 .51536 Mdot
.5798 .31097 Mdot
.68232 .54039 Mdot
.57487 .40601 Mdot
.4173 .44201 Mdot
.38463 .61566 Mdot
.26442 .54173 Mdot
.58589 .38166 Mdot
.60896 .41328 Mdot
.57703 .4101 Mdot
.5773 .65761 Mdot
.40813 .64936 Mdot
.60447 .74637 Mdot
.74345 .53351 Mdot
.28749 .38611 Mdot
.3763 .41904 Mdot
.39586 .71917 Mdot
.42092 .40016 Mdot
.5866 .65953 Mdot
.26315 .56803 Mdot
.58973 .29167 Mdot
.58151 .4083 Mdot
.49754 .7175 Mdot
.57513 .395 Mdot
.28579 .51029 Mdot
.29044 .51107 Mdot
.38022 .62244 Mdot
.58766 .64703 Mdot
.37621 .39555 Mdot
.68874 .56028 Mdot
.59775 .27041 Mdot
.58471 .72375 Mdot
.2834 .51833 Mdot
.39064 .43735 Mdot
.58651 .28076 Mdot
.60895 .7483 Mdot
.57232 .26104 Mdot
.58942 .70886 Mdot
.62837 .37084 Mdot
.28787 .47031 Mdot
.39435 .43193 Mdot
.60651 .38493 Mdot
.39525 .6431 Mdot
.57847 .70364 Mdot
.34965 .58547 Mdot
.58232 .39888 Mdot
.78074 .51101 Mdot
.58174 .71789 Mdot
.40341 .44369 Mdot
.41877 .69167 Mdot
.37735 .62955 Mdot
.41043 .66243 Mdot
.77464 .44 Mdot
.79408 .50877 Mdot
.68592 .52443 Mdot
.5974 .66448 Mdot
.70821 .5124 Mdot
.58743 .31313 Mdot
.28661 .41456 Mdot
.67899 .55602 Mdot
.40602 .64245 Mdot
.72612 .51709 Mdot
.32578 .40371 Mdot
.58131 .64819 Mdot
.64793 .55525 Mdot
.41842 .39494 Mdot
.26121 .52424 Mdot
.61243 .4091 Mdot
.58857 .25285 Mdot
.2843 .40326 Mdot
.37161 .40553 Mdot
.60074 .38694 Mdot
.3942 .43433 Mdot
.58543 .66181 Mdot
.32388 .33087 Mdot
.29835 .38679 Mdot
.77381 .51557 Mdot
.41933 .77509 Mdot
.70147 .55212 Mdot
.60658 .21626 Mdot
.42403 .40735 Mdot
.38765 .43277 Mdot
.27648 .51109 Mdot
.25334 .55987 Mdot
.59402 .73281 Mdot
.28155 .38553 Mdot
.77193 .52254 Mdot
.40009 .65853 Mdot
.38419 .63222 Mdot
.46307 .36466 Mdot
.60715 .38279 Mdot
.60801 .69111 Mdot
.37698 .43002 Mdot
.58495 .37912 Mdot
.3304 .43694 Mdot
.61814 .7466 Mdot
.79662 .50718 Mdot
.7414 .53971 Mdot
.38125 .62979 Mdot
.66654 .52536 Mdot
.27519 .50963 Mdot
.58896 .40728 Mdot
.80449 .51021 Mdot
.59972 .73778 Mdot
.598 .2687 Mdot
.42776 .41964 Mdot
.40968 .29999 Mdot
.66501 .52611 Mdot
.70344 .54088 Mdot
.32769 .40511 Mdot
.38593 .75778 Mdot
.55941 .3017 Mdot
.57648 .68986 Mdot
.37828 .6172 Mdot
.40886 .5048 Mdot
.50967 .27289 Mdot
.60484 .67753 Mdot
.27854 .52555 Mdot
.66011 .53205 Mdot
.69756 .45381 Mdot
.40085 .65474 Mdot
.59884 .27001 Mdot
.41586 .3967 Mdot
.38918 .63889 Mdot
.78998 .51692 Mdot
.41329 .67784 Mdot
.61076 .39551 Mdot
.5824 .64811 Mdot
.67458 .54264 Mdot
.58722 .63136 Mdot
.42389 .70387 Mdot
.58854 .28827 Mdot
.45736 .33911 Mdot
.25248 .52612 Mdot
.34827 .58926 Mdot
.2672 .5214 Mdot
.6036 .43068 Mdot
.26429 .52392 Mdot
.37523 .6152 Mdot
.38625 .43583 Mdot
.34753 .40917 Mdot
.76088 .51855 Mdot
.4241 .42779 Mdot
.36013 .41701 Mdot
.32321 .38871 Mdot
.42658 .41404 Mdot
.41516 .41556 Mdot
.38176 .44386 Mdot
.375 .70328 Mdot
.33425 .4275 Mdot
.40296 .71904 Mdot
.39388 .7443 Mdot
.74455 .53311 Mdot
.58914 .32083 Mdot
.61826 .26654 Mdot
.33176 .42977 Mdot
.41074 .301 Mdot
.33153 .57769 Mdot
.39612 .66102 Mdot
.58624 .7182 Mdot
.30487 .39181 Mdot
.55812 .29557 Mdot
.32853 .42678 Mdot
.67023 .55195 Mdot
.6947 .55219 Mdot
.42554 .39572 Mdot
.52622 .16582 Mdot
.40656 .44632 Mdot
.29306 .41204 Mdot
.38171 .42687 Mdot
.38547 .44539 Mdot
.67977 .56186 Mdot
.44449 .32066 Mdot
.26374 .50072 Mdot
.37077 .61171 Mdot
.60114 .26623 Mdot
.61453 .38979 Mdot
.29762 .39968 Mdot
.39203 .50902 Mdot
.36268 .59566 Mdot
.27795 .51142 Mdot
.67869 .54721 Mdot
.3957 .69609 Mdot
.29475 .41072 Mdot
.5792 .69085 Mdot
.33077 .30989 Mdot
.40276 .77019 Mdot
.57677 .68173 Mdot
.59584 .27178 Mdot
.65791 .5473 Mdot
.39577 .41306 Mdot
.72256 .52419 Mdot
.36787 .43918 Mdot
.26743 .40188 Mdot
.6128 .279 Mdot
.40234 .63805 Mdot
.57496 .70604 Mdot
.37745 .70357 Mdot
.4194 .75886 Mdot
.36734 .34147 Mdot
.76979 .5031 Mdot
.66088 .56473 Mdot
.58738 .22955 Mdot
.40718 .69717 Mdot
.35671 .4202 Mdot
.29816 .56891 Mdot
.38313 .6899 Mdot
.38465 .61328 Mdot
.32815 .31425 Mdot
.43244 .30305 Mdot
.38556 .44387 Mdot
.39091 .63718 Mdot
.65687 .54654 Mdot
.61525 .27462 Mdot
.35982 .42226 Mdot
.58952 .40893 Mdot
.38337 .63317 Mdot
.66801 .52693 Mdot
.4497 .32729 Mdot
.70899 .53117 Mdot
.4047 .66631 Mdot
.70706 .54783 Mdot
.57151 .65193 Mdot
.67609 .55707 Mdot
.43815 .41132 Mdot
.3816 .43165 Mdot
.37753 .62036 Mdot
.39618 .68708 Mdot
.28544 .50971 Mdot
.42749 .40366 Mdot
.40953 .69836 Mdot
.72192 .50764 Mdot
.36716 .6225 Mdot
.27984 .50679 Mdot
.36701 .41337 Mdot
.58191 .26415 Mdot
.27081 .38859 Mdot
.31536 .32405 Mdot
.29273 .38498 Mdot
.59108 .28627 Mdot
.38663 .60638 Mdot
.37152 .42856 Mdot
.43963 .31221 Mdot
.77612 .52182 Mdot
.40283 .39186 Mdot
.58607 .41243 Mdot
.27148 .49742 Mdot
.36474 .29105 Mdot
.28287 .51744 Mdot
.40694 .65855 Mdot
.40764 .67462 Mdot
.73464 .51068 Mdot
.39656 .64806 Mdot
.58817 .41188 Mdot
.60687 .69438 Mdot
.41568 .75707 Mdot
.60859 .36324 Mdot
.62049 .40833 Mdot
.59835 .42351 Mdot
.59742 .37435 Mdot
.55817 .28964 Mdot
.7752 .50893 Mdot
.61796 .40878 Mdot
.40628 .71411 Mdot
.64144 .58295 Mdot
.63725 .39569 Mdot
.60807 .69147 Mdot
.58464 .40276 Mdot
.39997 .39222 Mdot
.28006 .51418 Mdot
.37297 .7264 Mdot
.57907 .68541 Mdot
.59139 .4299 Mdot
.35934 .41879 Mdot
.38017 .62949 Mdot
.39685 .42246 Mdot
.5719 .2871 Mdot
.39148 .68002 Mdot
.69221 .54175 Mdot
.6104 .28397 Mdot
.58895 .38518 Mdot
.5976 .29224 Mdot
.70604 .51899 Mdot
.59632 .71816 Mdot
.41103 .39542 Mdot
.58517 .25016 Mdot
.59046 .31989 Mdot
.40321 .39274 Mdot
.40653 .68138 Mdot
.58741 .42716 Mdot
.36793 .40959 Mdot
.27262 .5147 Mdot
.38446 .71932 Mdot
.47546 .75843 Mdot
.4002 .41082 Mdot
.28967 .51435 Mdot
.37352 .6171 Mdot
.58744 .37776 Mdot
.70005 .53886 Mdot
.41013 .4399 Mdot
.58873 .691 Mdot
.58402 .67707 Mdot
.79024 .51638 Mdot
.376 .66884 Mdot
.67322 .51706 Mdot
.42686 .39373 Mdot
.58474 .39789 Mdot
.3979 .4396 Mdot
.73192 .50183 Mdot
.44787 .7768 Mdot
.39783 .72729 Mdot
.73744 .53911 Mdot
.34018 .44275 Mdot
.60451 .64648 Mdot
.77036 .51712 Mdot
.37239 .61353 Mdot
.38025 .66975 Mdot
.3907 .715 Mdot
.6154 .25969 Mdot
.69944 .53556 Mdot
.37475 .72454 Mdot
.38107 .72768 Mdot
.27934 .50882 Mdot
.4233 .39431 Mdot
.38197 .61983 Mdot
.79287 .5129 Mdot
.59631 .26539 Mdot
.76396 .52531 Mdot
.57193 .23154 Mdot
.5755 .6952 Mdot
.34035 .39523 Mdot
.31714 .39758 Mdot
.50362 .16448 Mdot
.42408 .43857 Mdot
.37997 .42446 Mdot
.38046 .60445 Mdot
.56803 .27686 Mdot
.60501 .25616 Mdot
.4075 .69432 Mdot
.39709 .72951 Mdot
.60167 .2947 Mdot
.32371 .47375 Mdot
.38315 .29701 Mdot
.34338 .44157 Mdot
.40908 .64999 Mdot
.41849 .74844 Mdot
.58881 .67489 Mdot
.38563 .63631 Mdot
.65732 .61992 Mdot
.64949 .56064 Mdot
.66666 .55954 Mdot
.58194 .71394 Mdot
.39281 .41315 Mdot
.66584 .56572 Mdot
.25918 .50946 Mdot
.66391 .62276 Mdot
.26744 .53256 Mdot
.82024 .48882 Mdot
.42456 .40087 Mdot
.55856 .62697 Mdot
.63056 .75201 Mdot
.28171 .50506 Mdot
.33955 .49577 Mdot
.60016 .27775 Mdot
.37423 .59946 Mdot
.59243 .6525 Mdot
.33372 .57781 Mdot
.39173 .43244 Mdot
.39545 .63474 Mdot
.5724 .69362 Mdot
.46561 .76215 Mdot
.26467 .49872 Mdot
.26529 .50758 Mdot
.29878 .57163 Mdot
.41035 .71666 Mdot
.70302 .53692 Mdot
.37813 .60685 Mdot
.37956 .7318 Mdot
.26329 .52766 Mdot
.6544 .53778 Mdot
.26368 .4149 Mdot
.40422 .64246 Mdot
.61527 .24341 Mdot
.38671 .67289 Mdot
.60499 .28888 Mdot
.3731 .72139 Mdot
.74758 .52865 Mdot
.41542 .4099 Mdot
.74745 .53122 Mdot
.57525 .2877 Mdot
.71571 .54573 Mdot
.58413 .66098 Mdot
.59328 .39091 Mdot
.58995 .66023 Mdot
.28006 .41327 Mdot
.35082 .58461 Mdot
.60652 .68951 Mdot
.38435 .35048 Mdot
.38583 .4373 Mdot
.37281 .72029 Mdot
.68019 .54529 Mdot
.76195 .52904 Mdot
.27974 .40113 Mdot
.40126 .69436 Mdot
.7321 .51262 Mdot
.28541 .48707 Mdot
.6632 .60918 Mdot
.27666 .499 Mdot
.66911 .73305 Mdot
.41109 .68058 Mdot
.76812 .52736 Mdot
.29638 .41243 Mdot
.38905 .73848 Mdot
.65315 .55895 Mdot
.59162 .71213 Mdot
.58915 .69065 Mdot
.43792 .42501 Mdot
.58837 .63128 Mdot
.67257 .551 Mdot
.39837 .76899 Mdot
.37395 .7189 Mdot
.44034 .77989 Mdot
.59294 .28922 Mdot
.66395 .53548 Mdot
.59301 .40413 Mdot
.42567 .69271 Mdot
.71851 .51361 Mdot
.51473 .16269 Mdot
.82472 .41177 Mdot
.69745 .50992 Mdot
.39164 .67748 Mdot
.3991 .67876 Mdot
.26432 .53891 Mdot
.28297 .40095 Mdot
.68023 .54024 Mdot
.64838 .60409 Mdot
.33042 .45476 Mdot
.59493 .38747 Mdot
.80627 .5056 Mdot
.44661 .42158 Mdot
.26878 .51864 Mdot
.58103 .70521 Mdot
.39402 .40939 Mdot
.40153 .72829 Mdot
.41474 .44386 Mdot
.59104 .65606 Mdot
.74652 .51049 Mdot
.39204 .43339 Mdot
.59702 .27169 Mdot
.58942 .70147 Mdot
.58598 .69576 Mdot
.73121 .53707 Mdot
.37597 .66859 Mdot
.33701 .58119 Mdot
.7022 .53523 Mdot
.26141 .51878 Mdot
.59929 .39116 Mdot
.39465 .44445 Mdot
.39656 .62773 Mdot
.36692 .5939 Mdot
.66289 .53645 Mdot
.3818 .39785 Mdot
.6026 .6694 Mdot
.70706 .50804 Mdot
.27698 .53016 Mdot
.66299 .55825 Mdot
.61039 .35705 Mdot
.65189 .56827 Mdot
.41162 .73984 Mdot
.6084 .42529 Mdot
.39754 .63558 Mdot
.62223 .39384 Mdot
.7338 .44177 Mdot
.59496 .27016 Mdot
.68384 .5597 Mdot
.44299 .77291 Mdot
.74179 .53723 Mdot
.42519 .41158 Mdot
.36748 .42884 Mdot
.70411 .51655 Mdot
.58632 .28672 Mdot
.63962 .4216 Mdot
.57084 .27353 Mdot
.39431 .67897 Mdot
.26343 .4977 Mdot
.8337 .4422 Mdot
.72623 .54817 Mdot
.57078 .6803 Mdot
.36398 .60677 Mdot
.62279 .40321 Mdot
.58102 .66827 Mdot
.58657 .69912 Mdot
.58477 .29626 Mdot
.73916 .54205 Mdot
.38943 .62176 Mdot
.58804 .63463 Mdot
.3908 .73823 Mdot
.44539 .31622 Mdot
.59075 .37777 Mdot
.59315 .23272 Mdot
.62241 .38251 Mdot
.29032 .40629 Mdot
.59697 .63949 Mdot
.40779 .42286 Mdot
.57391 .30167 Mdot
.58155 .71076 Mdot
.57832 .26533 Mdot
.27765 .52814 Mdot
.74375 .51555 Mdot
.32968 .60214 Mdot
.43947 .42177 Mdot
.41243 .40148 Mdot
.57612 .70127 Mdot
.3523 .5039 Mdot
.37126 .60766 Mdot
.3752 .71729 Mdot
.69089 .52345 Mdot
.31929 .31891 Mdot
.38154 .44624 Mdot
.36097 .41981 Mdot
.71789 .51845 Mdot
.6088 .38105 Mdot
.79511 .50294 Mdot
.3671 .41558 Mdot
.5932 .66978 Mdot
.28065 .52185 Mdot
.6076 .65447 Mdot
.4201 .39054 Mdot
.41819 .40765 Mdot
.2616 .50874 Mdot
.27021 .5245 Mdot
.59026 .66031 Mdot
.60177 .37575 Mdot
.5792 .4103 Mdot
.4076 .64972 Mdot
.42333 .39763 Mdot
.33297 .4557 Mdot
.37695 .42891 Mdot
.59953 .27796 Mdot
.30919 .32646 Mdot
.33049 .4019 Mdot
.28472 .39042 Mdot
.32556 .45392 Mdot
.40094 .41645 Mdot
.57352 .69234 Mdot
.40057 .67916 Mdot
.60298 .6749 Mdot
.5839 .63968 Mdot
.73057 .51858 Mdot
.58047 .26339 Mdot
.41937 .43223 Mdot
.58719 .30797 Mdot
.43765 .43481 Mdot
.61851 .23685 Mdot
.2984 .40323 Mdot
.29889 .41442 Mdot
.6135 .24591 Mdot
.3772 .43537 Mdot
.69459 .51959 Mdot
.67624 .56623 Mdot
.25552 .52361 Mdot
.43446 .40193 Mdot
.56982 .66818 Mdot
.60195 .70531 Mdot
.79292 .50652 Mdot
.69122 .56342 Mdot
.57171 .28755 Mdot
.62389 .45474 Mdot
.26487 .52546 Mdot
.42792 .43055 Mdot
.59842 .37872 Mdot
.68233 .51638 Mdot
.6211 .39957 Mdot
.78393 .50804 Mdot
.59518 .64996 Mdot
.59853 .69684 Mdot
.43055 .40338 Mdot
.55962 .17919 Mdot
.38088 .68975 Mdot
.39927 .68078 Mdot
.60454 .70463 Mdot
.7008 .55249 Mdot
.61128 .40057 Mdot
.30798 .57043 Mdot
.3661 .6076 Mdot
.58629 .3153 Mdot
.4046 .43953 Mdot
.65365 .56336 Mdot
.41069 .70616 Mdot
.57354 .29109 Mdot
.29541 .3844 Mdot
.6582 .52534 Mdot
.39975 .42678 Mdot
.29115 .50223 Mdot
.40281 .70743 Mdot
.28767 .39902 Mdot
.40361 .64019 Mdot
.58557 .68017 Mdot
.59304 .63951 Mdot
.41664 .40564 Mdot
.328 .59497 Mdot
.40704 .74186 Mdot
.59217 .63641 Mdot
.61539 .25392 Mdot
.59332 .39813 Mdot
.57877 .26537 Mdot
.68153 .52256 Mdot
.59577 .27038 Mdot
.72443 .51504 Mdot
.7697 .51858 Mdot
.3867 .624 Mdot
.58629 .28027 Mdot
.33788 .39038 Mdot
.59087 .40807 Mdot
.61815 .2763 Mdot
.30145 .39679 Mdot
.28576 .51879 Mdot
.67295 .53833 Mdot
.58535 .30826 Mdot
.40458 .44218 Mdot
.49613 .71911 Mdot
.58218 .64556 Mdot
.58618 .65804 Mdot
.61152 .39623 Mdot
.66071 .54253 Mdot
.39106 .62063 Mdot
.32963 .43898 Mdot
.41524 .73412 Mdot
.36243 .41198 Mdot
.42199 .42537 Mdot
.40977 .74468 Mdot
.39099 .6202 Mdot
.41198 .40571 Mdot
.46127 .38791 Mdot
.58964 .40191 Mdot
.58488 .6872 Mdot
.39341 .68255 Mdot
.39306 .69564 Mdot
.69088 .54693 Mdot
.38273 .6304 Mdot
.56646 .25382 Mdot
.58862 .65419 Mdot
.57625 .3917 Mdot
.59973 .66579 Mdot
.64512 .37868 Mdot
.7018 .51041 Mdot
.45927 .76194 Mdot
.37113 .69139 Mdot
.27433 .50588 Mdot
.38289 .61991 Mdot
.59238 .29225 Mdot
.38987 .64091 Mdot
.38822 .63113 Mdot
.41729 .39391 Mdot
.59515 .37908 Mdot
.61353 .41167 Mdot
.29533 .40605 Mdot
.38167 .68854 Mdot
.40877 .41256 Mdot
.29991 .39103 Mdot
.41908 .40038 Mdot
.28817 .40039 Mdot
.37318 .69921 Mdot
.38965 .50968 Mdot
.38055 .62192 Mdot
.40509 .70573 Mdot
.57088 .23153 Mdot
.59362 .41235 Mdot
.62419 .3944 Mdot
.56733 .64867 Mdot
.37247 .40822 Mdot
.76132 .52117 Mdot
.26317 .51884 Mdot
.58894 .39003 Mdot
.28828 .37902 Mdot
.59658 .31303 Mdot
.36537 .43776 Mdot
.60111 .38116 Mdot
.68505 .54329 Mdot
.27385 .50652 Mdot
.36706 .42205 Mdot
.61491 .38631 Mdot
.38564 .61975 Mdot
.38425 .71316 Mdot
.35955 .60042 Mdot
.59538 .29733 Mdot
.59902 .65666 Mdot
.26551 .51825 Mdot
.69078 .52197 Mdot
.75756 .52296 Mdot
.39746 .63441 Mdot
.71665 .53944 Mdot
.59637 .70001 Mdot
.37217 .41651 Mdot
.58575 .67248 Mdot
.59808 .30793 Mdot
.39127 .68183 Mdot
.27126 .51135 Mdot
.2537 .53814 Mdot
.40768 .67487 Mdot
.58748 .40085 Mdot
.58451 .25954 Mdot
.7313 .53083 Mdot
.39694 .72508 Mdot
.598 .65329 Mdot
.69673 .5463 Mdot
.26778 .50598 Mdot
.59103 .20418 Mdot
.39584 .40883 Mdot
.43365 .41232 Mdot
.4242 .67388 Mdot
.37131 .39815 Mdot
.74293 .53371 Mdot
.39373 .6192 Mdot
.28378 .51013 Mdot
.27313 .41304 Mdot
.62088 .2857 Mdot
.6168 .34849 Mdot
.39293 .42048 Mdot
.30667 .38345 Mdot
.33532 .41914 Mdot
.43392 .77578 Mdot
.28322 .39836 Mdot
.73258 .50481 Mdot
.59179 .23124 Mdot
.58283 .63773 Mdot
.60065 .38521 Mdot
.73851 .52211 Mdot
.46024 .39294 Mdot
.39859 .4068 Mdot
.35425 .61032 Mdot
.28196 .52419 Mdot
.60334 .68619 Mdot
.37176 .50825 Mdot
.68027 .54717 Mdot
.8109 .50417 Mdot
.4296 .39474 Mdot
.36867 .6048 Mdot
.53014 .65256 Mdot
.59549 .38181 Mdot
.62462 .38991 Mdot
.57473 .29207 Mdot
.73876 .50955 Mdot
.6324 .39054 Mdot
.60197 .6698 Mdot
.4203 .43904 Mdot
.33257 .40065 Mdot
.48354 .74915 Mdot
.41175 .69415 Mdot
.57441 .65654 Mdot
.6433 .36737 Mdot
.41307 .42493 Mdot
.37752 .68913 Mdot
.4005 .65445 Mdot
.58847 .31864 Mdot
.77359 .51189 Mdot
.7821 .51832 Mdot
.53436 .1695 Mdot
.59537 .42865 Mdot
.68607 .51572 Mdot
.62833 .40469 Mdot
.26096 .51605 Mdot
.29883 .40017 Mdot
.58061 .64105 Mdot
.42722 .41114 Mdot
.35056 .59971 Mdot
.40815 .65641 Mdot
.38085 .42892 Mdot
.60177 .26267 Mdot
.25693 .56155 Mdot
.25131 .51889 Mdot
.45863 .38485 Mdot
.65669 .54621 Mdot
.42195 .42141 Mdot
.56524 .25575 Mdot
.58705 .37651 Mdot
.38551 .39418 Mdot
.69973 .53815 Mdot
.60796 .42524 Mdot
.60187 .25996 Mdot
.41105 .66137 Mdot
.60157 .38653 Mdot
.2791 .5286 Mdot
.38005 .44209 Mdot
.61476 .2522 Mdot
.26251 .51062 Mdot
.42093 .7484 Mdot
.62355 .37767 Mdot
.67069 .55979 Mdot
.39119 .73016 Mdot
.42039 .41665 Mdot
.5921 .39765 Mdot
.40429 .43817 Mdot
.42102 .76159 Mdot
.43088 .42022 Mdot
.48815 .73042 Mdot
.40421 .68601 Mdot
.59645 .68147 Mdot
.27666 .51193 Mdot
.40068 .42823 Mdot
.62324 .413 Mdot
.61059 .40418 Mdot
.35793 .42003 Mdot
.39866 .63663 Mdot
.39414 .64144 Mdot
.36659 .6004 Mdot
.6844 .55093 Mdot
.3512 .44379 Mdot
.59246 .68079 Mdot
.60181 .37714 Mdot
.58999 .63231 Mdot
.30951 .38588 Mdot
.59869 .29349 Mdot
.48362 .74393 Mdot
.37733 .41095 Mdot
.39954 .69825 Mdot
.3867 .29904 Mdot
.3835 .65591 Mdot
.56556 .6567 Mdot
.57338 .65826 Mdot
.38621 .6904 Mdot
.38942 .42027 Mdot
.28808 .4071 Mdot
.33658 .3994 Mdot
.59809 .64164 Mdot
.57801 .40466 Mdot
.58446 .3482 Mdot
.65107 .55202 Mdot
.59602 .20755 Mdot
.5829 .72103 Mdot
.62912 .75578 Mdot
.27983 .50672 Mdot
.38515 .72289 Mdot
.60346 .65621 Mdot
.58343 .69425 Mdot
.67114 .54785 Mdot
.27769 .50796 Mdot
.39609 .4292 Mdot
.58892 .41389 Mdot
.59211 .72265 Mdot
.35526 .42978 Mdot
.28602 .5087 Mdot
.78931 .50519 Mdot
.37144 .60007 Mdot
.4717 .76338 Mdot
.30455 .38483 Mdot
.34789 .58985 Mdot
.66263 .59637 Mdot
.3742 .7214 Mdot
.40975 .41399 Mdot
.60195 .40389 Mdot
.71367 .54225 Mdot
.37766 .41609 Mdot
.73567 .5408 Mdot
.60572 .67252 Mdot
.49442 .72575 Mdot
.32085 .3943 Mdot
.66302 .62111 Mdot
.41074 .40851 Mdot
.25279 .53004 Mdot
.58879 .26864 Mdot
.60398 .65214 Mdot
.3694 .62186 Mdot
.41595 .43818 Mdot
.70472 .53916 Mdot
.6491 .552 Mdot
.40311 .64701 Mdot
.3613 .60271 Mdot
.45179 .76846 Mdot
.59395 .40587 Mdot
.72235 .53232 Mdot
.59149 .39927 Mdot
.45952 .3833 Mdot
.58866 .63407 Mdot
.60256 .2595 Mdot
.70852 .54677 Mdot
.59036 .73134 Mdot
.28588 .51883 Mdot
.38608 .66432 Mdot
.42642 .68985 Mdot
.25548 .51542 Mdot
.73902 .51382 Mdot
.60732 .27791 Mdot
.28895 .39461 Mdot
.25794 .50388 Mdot
.61134 .27563 Mdot
.67862 .55054 Mdot
.3827 .70275 Mdot
.40489 .66041 Mdot
.40127 .67646 Mdot
.33928 .3949 Mdot
.3664 .59167 Mdot
.46354 .34908 Mdot
.35477 .40543 Mdot
.40208 .7639 Mdot
.34879 .41469 Mdot
.58733 .65696 Mdot
.40111 .70746 Mdot
.28803 .39974 Mdot
.27578 .49503 Mdot
.45714 .40601 Mdot
.39603 .3985 Mdot
.2709 .52677 Mdot
.37211 .40827 Mdot
.4136 .7471 Mdot
.37124 .5969 Mdot
.28596 .3914 Mdot
.58586 .65287 Mdot
.59946 .28671 Mdot
.38063 .73465 Mdot
.42009 .42445 Mdot
.41601 .74977 Mdot
.29576 .39322 Mdot
.49034 .72559 Mdot
.27032 .52862 Mdot
.74657 .50972 Mdot
.41264 .44258 Mdot
.64845 .56506 Mdot
.25025 .53275 Mdot
.41819 .75139 Mdot
.57988 .65012 Mdot
.2507 .52019 Mdot
.64061 .55608 Mdot
.37607 .50856 Mdot
.60138 .40732 Mdot
.59392 .26583 Mdot
.60779 .42425 Mdot
.58852 .66031 Mdot
.38675 .40794 Mdot
.37921 .44078 Mdot
.3762 .39601 Mdot
.45951 .38267 Mdot
.59212 .41094 Mdot
.61735 .2477 Mdot
.41362 .75823 Mdot
.36526 .43452 Mdot
.66862 .56641 Mdot
.37892 .71692 Mdot
.45752 .40338 Mdot
.35513 .38874 Mdot
.28618 .526 Mdot
.38294 .68753 Mdot
.37664 .6657 Mdot
.55845 .29818 Mdot
.59158 .27906 Mdot
.42039 .40342 Mdot
.60906 .24252 Mdot
.26629 .51566 Mdot
.59581 .66133 Mdot
.34415 .40966 Mdot
.70456 .51014 Mdot
.2757 .40447 Mdot
.67865 .5515 Mdot
.41006 .39895 Mdot
.38769 .67131 Mdot
.59647 .64273 Mdot
.77975 .52133 Mdot
.79863 .51226 Mdot
.46391 .34504 Mdot
.79013 .52034 Mdot
.58995 .30151 Mdot
.58838 .2961 Mdot
.60172 .65062 Mdot
.38237 .42315 Mdot
.27869 .39785 Mdot
.26978 .55308 Mdot
.37938 .40641 Mdot
.3899 .4142 Mdot
.59729 .73804 Mdot
.58272 .71688 Mdot
.70136 .55062 Mdot
.40856 .4055 Mdot
.35835 .43506 Mdot
.38712 .68073 Mdot
.56873 .28384 Mdot
.73218 .52226 Mdot
.57323 .28925 Mdot
.7138 .52395 Mdot
.36599 .29087 Mdot
.58678 .38353 Mdot
.59223 .29741 Mdot
.57995 .71905 Mdot
.39743 .70125 Mdot
.58986 .41177 Mdot
.68058 .53182 Mdot
.72044 .53556 Mdot
.44195 .42821 Mdot
.41245 .69327 Mdot
.37461 .71627 Mdot
.59875 .29591 Mdot
.60223 .70713 Mdot
.25863 .51006 Mdot
.62282 .3835 Mdot
.63251 .34153 Mdot
.71066 .53876 Mdot
.40385 .76874 Mdot
.42481 .68498 Mdot
.41431 .43027 Mdot
.38435 .71191 Mdot
.40445 .43127 Mdot
.37903 .60783 Mdot
.39269 .74296 Mdot
.42194 .39073 Mdot
.35757 .59516 Mdot
.69123 .51368 Mdot
.82984 .46312 Mdot
.28311 .50338 Mdot
.58042 .72676 Mdot
.26293 .51742 Mdot
.80046 .5023 Mdot
.39073 .2991 Mdot
.36898 .43446 Mdot
.42133 .42443 Mdot
.55832 .19311 Mdot
.33375 .42529 Mdot
.6208 .38861 Mdot
.60071 .40788 Mdot
.38144 .70718 Mdot
.6089 .42313 Mdot
.28927 .40507 Mdot
.58269 .27999 Mdot
.6895 .5238 Mdot
.43624 .3105 Mdot
.60485 .2867 Mdot
.40853 .66265 Mdot
.26395 .50131 Mdot
.39436 .75669 Mdot
.66058 .56907 Mdot
.60952 .38585 Mdot
.60511 .67693 Mdot
.2669 .38951 Mdot
.69117 .54437 Mdot
.5926 .72674 Mdot
.31358 .4014 Mdot
.74767 .50616 Mdot
.58609 .65393 Mdot
.83161 .45356 Mdot
.57945 .69852 Mdot
.60619 .69779 Mdot
.30623 .40962 Mdot
.58235 .27942 Mdot
.61621 .42147 Mdot
.60963 .23667 Mdot
.57764 .65906 Mdot
.80578 .49768 Mdot
.66305 .54394 Mdot
.26962 .40403 Mdot
.37451 .59723 Mdot
.584 .40356 Mdot
.40259 .4094 Mdot
.57909 .70333 Mdot
.43531 .43642 Mdot
.61444 .42222 Mdot
.59571 .69532 Mdot
.25094 .534 Mdot
.3095 .32386 Mdot
.59733 .40125 Mdot
.6093 .41514 Mdot
.57968 .30083 Mdot
.78285 .51448 Mdot
.37237 .70737 Mdot
.59659 .31549 Mdot
.32093 .44018 Mdot
.42582 .40347 Mdot
.59133 .65916 Mdot
.60247 .38626 Mdot
.59023 .68565 Mdot
.59358 .25978 Mdot
.6182 .25567 Mdot
.41074 .66284 Mdot
.36745 .60193 Mdot
.62652 .36661 Mdot
.32628 .45979 Mdot
.34074 .41577 Mdot
.355 .60897 Mdot
.37615 .67565 Mdot
.33781 .49347 Mdot
.59357 .255 Mdot
.57901 .3022 Mdot
.25169 .53065 Mdot
.29339 .38913 Mdot
.27617 .52325 Mdot
.30875 .39013 Mdot
.72072 .48761 Mdot
.27484 .51018 Mdot
.72997 .53084 Mdot
.30578 .38851 Mdot
.615 .75624 Mdot
.2564 .52812 Mdot
.41673 .43146 Mdot
.70315 .52884 Mdot
.39773 .39319 Mdot
.66904 .52796 Mdot
.41614 .41203 Mdot
.73226 .50134 Mdot
.69117 .52207 Mdot
.63074 .45641 Mdot
.35265 .33948 Mdot
.62049 .39323 Mdot
.60859 .25543 Mdot
.58263 .25205 Mdot
.4514 .329 Mdot
.3845 .70097 Mdot
.25964 .55931 Mdot
.41706 .42983 Mdot
.66855 .54802 Mdot
.606 .67963 Mdot
.26258 .54259 Mdot
.4364 .41505 Mdot
.25754 .51852 Mdot
.38507 .66363 Mdot
.65889 .54092 Mdot
.58724 .26444 Mdot
.71635 .54976 Mdot
.8018 .50491 Mdot
.69145 .51181 Mdot
.45492 .37517 Mdot
.2783 .53377 Mdot
.56501 .2568 Mdot
.35351 .58768 Mdot
.6326 .4245 Mdot
.39451 .64533 Mdot
.59901 .38735 Mdot
.57647 .28508 Mdot
.32053 .32972 Mdot
.37715 .71686 Mdot
.71733 .51855 Mdot
.40094 .42632 Mdot
.60055 .37429 Mdot
.61019 .23631 Mdot
.39909 .73218 Mdot
.61444 .25026 Mdot
.68869 .52936 Mdot
.59671 .39579 Mdot
.35704 .44657 Mdot
.40534 .50651 Mdot
.26625 .40441 Mdot
.40473 .428 Mdot
.60214 .29349 Mdot
.41235 .69601 Mdot
.2569 .51837 Mdot
.58502 .71102 Mdot
.28354 .40163 Mdot
.40141 .4086 Mdot
.66564 .62038 Mdot
.38816 .6677 Mdot
.5916 .28809 Mdot
.57858 .70116 Mdot
.59289 .27784 Mdot
.62362 .39216 Mdot
.37949 .60972 Mdot
.62428 .38899 Mdot
.2821 .52262 Mdot
.6043 .66267 Mdot
.37499 .71585 Mdot
.78336 .50523 Mdot
.59013 .42723 Mdot
.69897 .51672 Mdot
.31739 .33033 Mdot
.40018 .64309 Mdot
.60827 .74007 Mdot
.7176 .54913 Mdot
.61127 .70434 Mdot
.27407 .39158 Mdot
.59226 .70235 Mdot
.41831 .42912 Mdot
.39834 .66622 Mdot
.60151 .64206 Mdot
.79566 .51333 Mdot
.31316 .38583 Mdot
.61414 .3671 Mdot
.37887 .43542 Mdot
.42397 .78086 Mdot
.6246 .74854 Mdot
.37697 .61647 Mdot
.58376 .72339 Mdot
.39886 .40125 Mdot
.59079 .40487 Mdot
.42482 .39745 Mdot
.57561 .66223 Mdot
.59579 .73814 Mdot
.75813 .52808 Mdot
.40521 .4231 Mdot
.59769 .27816 Mdot
.74223 .51754 Mdot
.65119 .5442 Mdot
.69243 .55379 Mdot
.36909 .61692 Mdot
.58263 .39249 Mdot
.59499 .40723 Mdot
.39788 .2989 Mdot
.58894 .68776 Mdot
.62041 .39192 Mdot
.37226 .43959 Mdot
.46171 .34829 Mdot
.40271 .68104 Mdot
.69105 .53218 Mdot
.40896 .40086 Mdot
.27955 .49963 Mdot
.61553 .39089 Mdot
.70188 .53453 Mdot
.38777 .62161 Mdot
.67354 .57429 Mdot
.37672 .4147 Mdot
.28211 .51209 Mdot
.40988 .67981 Mdot
.42715 .751 Mdot
.32813 .43504 Mdot
.40201 .43168 Mdot
.58383 .67688 Mdot
.4554 .71029 Mdot
.32082 .41056 Mdot
.39119 .54145 Mdot
.58194 .4106 Mdot
.59754 .57679 Mdot
.45215 .66399 Mdot
.26182 .55165 Mdot
.49339 .60044 Mdot
.24791 .4332 Mdot
.52728 .61876 Mdot
.71859 .47601 Mdot
.45831 .58423 Mdot
.8281 .44001 Mdot
.64076 .62077 Mdot
.2938 .52003 Mdot
.50343 .18617 Mdot
.63439 .7349 Mdot
.48579 .65289 Mdot
.65189 .66313 Mdot
.59286 .46867 Mdot
.78149 .504 Mdot
.76506 .50827 Mdot
.7083 .46795 Mdot
.4463 .41983 Mdot
.49031 .67493 Mdot
.30123 .4876 Mdot
.62567 .70173 Mdot
.67371 .50199 Mdot
.26615 .4949 Mdot
.53871 .22617 Mdot
.62039 .61308 Mdot
.52655 .32955 Mdot
.32518 .56808 Mdot
.64588 .47758 Mdot
.29569 .46886 Mdot
.50667 .35721 Mdot
.2597 .55483 Mdot
.55205 .59049 Mdot
.61169 .62035 Mdot
.39561 .59878 Mdot
.62481 .60929 Mdot
.72492 .52344 Mdot
.41243 .70317 Mdot
.65899 .70744 Mdot
.53828 .27871 Mdot
.64033 .65873 Mdot
.49244 .60148 Mdot
.6304 .3934 Mdot
.59681 .56902 Mdot
.36446 .44669 Mdot
.37447 .65958 Mdot
.65005 .49589 Mdot
.68971 .49164 Mdot
.41938 .62743 Mdot
.64032 .53384 Mdot
.33209 .32938 Mdot
.48699 .65644 Mdot
.45312 .67347 Mdot
.60118 .46863 Mdot
.6321 .45807 Mdot
.37744 .66918 Mdot
.50859 .22597 Mdot
.5408 .4411 Mdot
.31321 .43923 Mdot
.63979 .51881 Mdot
.39774 .61353 Mdot
.33616 .58438 Mdot
.3652 .62412 Mdot
.80804 .47623 Mdot
.55069 .26416 Mdot
.74261 .47178 Mdot
.54924 .44233 Mdot
.63864 .63918 Mdot
.39599 .34676 Mdot
.58069 .60965 Mdot
.76019 .46494 Mdot
.43631 .7298 Mdot
.52667 .19717 Mdot
.54674 .52525 Mdot
.56764 .2216 Mdot
.43926 .6543 Mdot
.6079 .47554 Mdot
.42191 .59353 Mdot
.60987 .5501 Mdot
.35592 .303 Mdot
.55286 .23484 Mdot
.49327 .67167 Mdot
.56199 .38874 Mdot
.63444 .73141 Mdot
.4404 .69961 Mdot
.67382 .4958 Mdot
.57198 .40723 Mdot
.46384 .47234 Mdot
.56 .21134 Mdot
.50272 .59349 Mdot
.51886 .26603 Mdot
.65114 .47669 Mdot
.66732 .70965 Mdot
.65271 .53559 Mdot
.60747 .64122 Mdot
.53514 .3178 Mdot
.39841 .66129 Mdot
.81891 .4717 Mdot
.47815 .62861 Mdot
.52571 .64793 Mdot
.55525 .21157 Mdot
.80215 .48318 Mdot
.6011 .53188 Mdot
.62044 .46443 Mdot
.60848 .6117 Mdot
.55708 .60989 Mdot
.61571 .73207 Mdot
.59811 .35503 Mdot
.46107 .74093 Mdot
.52685 .31393 Mdot
.782 .48487 Mdot
.52048 .18071 Mdot
.3299 .44493 Mdot
.51173 .38286 Mdot
.42331 .65933 Mdot
.49117 .52098 Mdot
.62 .71924 Mdot
.57412 .2156 Mdot
.26005 .49718 Mdot
.44564 .72892 Mdot
.71493 .46773 Mdot
.43708 .39139 Mdot
.49694 .70881 Mdot
.65754 .67817 Mdot
.66548 .57318 Mdot
.44264 .67729 Mdot
.56319 .25079 Mdot
.40287 .31669 Mdot
.40507 .51908 Mdot
.65521 .51665 Mdot
.31944 .42631 Mdot
.4273 .52007 Mdot
.79524 .42282 Mdot
.49867 .69581 Mdot
.4513 .48515 Mdot
.42655 .6769 Mdot
.75726 .46302 Mdot
.72767 .47474 Mdot
.46908 .70383 Mdot
.63123 .3486 Mdot
.52307 .2695 Mdot
.43927 .52479 Mdot
.59923 .55447 Mdot
.29603 .48811 Mdot
.30477 .48419 Mdot
.66315 .47334 Mdot
.51368 .42296 Mdot
.56329 .35859 Mdot
.65569 .66994 Mdot
.35798 .60654 Mdot
.52459 .37219 Mdot
.36275 .5547 Mdot
.42437 .73802 Mdot
.49431 .46303 Mdot
.58809 .62382 Mdot
.49102 .44816 Mdot
.54354 .21962 Mdot
.74166 .52986 Mdot
.76554 .46826 Mdot
.64244 .65663 Mdot
.67756 .4978 Mdot
.51419 .65598 Mdot
.51497 .6571 Mdot
.54371 .33822 Mdot
.6452 .72808 Mdot
.61399 .48913 Mdot
.3779 .6387 Mdot
.49765 .63406 Mdot
.34914 .56778 Mdot
.41021 .3611 Mdot
.39702 .5622 Mdot
.58936 .25484 Mdot
.4802 .42176 Mdot
.44137 .68098 Mdot
.64001 .36183 Mdot
.43045 .37004 Mdot
.28285 .44924 Mdot
.60974 .36161 Mdot
.40748 .33316 Mdot
.3696 .29287 Mdot
.5714 .5389 Mdot
.78587 .47319 Mdot
.42482 .53939 Mdot
.41443 .33326 Mdot
.62392 .71244 Mdot
.26935 .55752 Mdot
.57188 .21574 Mdot
.56156 .32078 Mdot
.46557 .68004 Mdot
.46989 .71665 Mdot
.67228 .74987 Mdot
.60784 .73715 Mdot
.80574 .41889 Mdot
.64251 .65592 Mdot
.27666 .56997 Mdot
.73855 .53612 Mdot
.59775 .49449 Mdot
.41078 .59139 Mdot
.28044 .45541 Mdot
.54272 .24069 Mdot
.57923 .55616 Mdot
.61414 .28855 Mdot
.44846 .63035 Mdot
.40066 .53345 Mdot
.52663 .23942 Mdot
.51867 .21656 Mdot
.51455 .2287 Mdot
.65672 .71411 Mdot
.48863 .40317 Mdot
.54946 .20592 Mdot
.46806 .35992 Mdot
.55011 .48037 Mdot
.26259 .54944 Mdot
.29969 .4395 Mdot
.81455 .44495 Mdot
.54373 .42767 Mdot
.56363 .60596 Mdot
.41979 .62863 Mdot
.56743 .20087 Mdot
.38842 .29144 Mdot
.61845 .57655 Mdot
.52099 .33672 Mdot
.56001 .41275 Mdot
.5192 .36107 Mdot
.55029 .34514 Mdot
.52391 .59122 Mdot
.65688 .67743 Mdot
.58202 .19067 Mdot
.73512 .45863 Mdot
.63392 .68575 Mdot
.43137 .71591 Mdot
.81876 .45443 Mdot
.48842 .70891 Mdot
.6129 .63937 Mdot
.43962 .64133 Mdot
.31332 .52483 Mdot
.44121 .56034 Mdot
.56036 .5911 Mdot
.44568 .47074 Mdot
.5403 .39625 Mdot
.72426 .54191 Mdot
.7755 .44719 Mdot
.43445 .55188 Mdot
.54337 .47612 Mdot
.42501 .33014 Mdot
.80085 .49205 Mdot
.54746 .56412 Mdot
.38781 .37602 Mdot
.42585 .53727 Mdot
.47903 .67086 Mdot
.49767 .70404 Mdot
.33602 .54228 Mdot
.34379 .42205 Mdot
.54112 .26607 Mdot
.81856 .4164 Mdot
.55125 .33703 Mdot
.48153 .69149 Mdot
.67451 .70284 Mdot
.63752 .61833 Mdot
.43962 .3518 Mdot
.26729 .42469 Mdot
.50974 .56505 Mdot
.24692 .41832 Mdot
.61109 .68739 Mdot
.33656 .58538 Mdot
.50669 .66273 Mdot
.4608 .35785 Mdot
.41775 .57796 Mdot
.51364 .64343 Mdot
.42956 .37923 Mdot
.42973 .67917 Mdot
.42946 .76358 Mdot
.75524 .46016 Mdot
.73839 .53198 Mdot
.62242 .34028 Mdot
.5365 .45192 Mdot
.57167 .29845 Mdot
.57753 .36848 Mdot
.59636 .54298 Mdot
.3434 .57306 Mdot
.67917 .7046 Mdot
.54769 .36313 Mdot
.82649 .46239 Mdot
.55234 .34512 Mdot
.74014 .47504 Mdot
.63479 .52927 Mdot
.38169 .32266 Mdot
.62935 .65302 Mdot
.64565 .63489 Mdot
.35918 .31624 Mdot
.76239 .48733 Mdot
.60804 .56789 Mdot
.37317 .66032 Mdot
.34424 .42829 Mdot
.38045 .29949 Mdot
.50462 .35778 Mdot
.38452 .33214 Mdot
.36267 .53076 Mdot
.40554 .63374 Mdot
.49749 .37514 Mdot
.62227 .58668 Mdot
.25044 .53764 Mdot
.46559 .72035 Mdot
.60623 .64431 Mdot
.43051 .70847 Mdot
.80827 .49381 Mdot
.67761 .72998 Mdot
.52448 .63175 Mdot
.43562 .36097 Mdot
.52077 .31051 Mdot
.44459 .36004 Mdot
.47065 .72224 Mdot
.3189 .51784 Mdot
.51453 .67142 Mdot
.42724 .63575 Mdot
.56151 .50991 Mdot
.57478 .61962 Mdot
.45844 .62915 Mdot
.4329 .68667 Mdot
.28458 .4837 Mdot
.5474 .30012 Mdot
.43367 .47748 Mdot
.53942 .59734 Mdot
.32321 .43562 Mdot
.47599 .52737 Mdot
.48389 .63006 Mdot
.44032 .32874 Mdot
.5138 .61398 Mdot
.50668 .23723 Mdot
.34559 .60469 Mdot
.59137 .59653 Mdot
.52286 .41096 Mdot
.45805 .35776 Mdot
.32584 .56782 Mdot
.44192 .70093 Mdot
.65513 .66967 Mdot
.44664 .4612 Mdot
.55273 .26525 Mdot
.53645 .51202 Mdot
.41654 .3306 Mdot
.45742 .50358 Mdot
.45475 .45479 Mdot
.59863 .35897 Mdot
.5473 .34326 Mdot
.60104 .57948 Mdot
.49836 .18427 Mdot
.74692 .48969 Mdot
.38713 .55385 Mdot
.42245 .59636 Mdot
.76724 .46039 Mdot
.45214 .61002 Mdot
.46587 .5969 Mdot
.44416 .53557 Mdot
.80323 .45494 Mdot
.57966 .57367 Mdot
.61564 .58318 Mdot
.4338 .76295 Mdot
.5365 .21387 Mdot
.54803 .60812 Mdot
.60785 .63477 Mdot
.53116 .40955 Mdot
.43381 .41817 Mdot
.3789 .55382 Mdot
.46418 .76133 Mdot
.49575 .48484 Mdot
.539 .62211 Mdot
.82807 .43139 Mdot
.58468 .5529 Mdot
.42377 .54466 Mdot
.50219 .18047 Mdot
.50278 .17173 Mdot
.36526 .56678 Mdot
.58093 .21005 Mdot
.62182 .58225 Mdot
.47746 .71652 Mdot
.62709 .6204 Mdot
.39314 .35461 Mdot
.35354 .60461 Mdot
.55328 .29244 Mdot
.66234 .7572 Mdot
.62491 .71442 Mdot
.4314 .61811 Mdot
.56548 .23815 Mdot
.54355 .48659 Mdot
.60789 .49863 Mdot
.66925 .6941 Mdot
.78276 .50018 Mdot
.79875 .47264 Mdot
.34165 .53258 Mdot
.67313 .48301 Mdot
.67786 .45997 Mdot
.50177 .68536 Mdot
.82579 .45486 Mdot
.56431 .41281 Mdot
.26001 .55819 Mdot
.75771 .46442 Mdot
.44397 .75592 Mdot
.68032 .49238 Mdot
.48319 .62489 Mdot
.59201 .54792 Mdot
.50331 .45618 Mdot
.46756 .73428 Mdot
.65539 .70251 Mdot
.5739 .50549 Mdot
.3228 .32382 Mdot
.43598 .70881 Mdot
.43771 .73441 Mdot
.30397 .52036 Mdot
.59614 .52549 Mdot
.50321 .21477 Mdot
.5699 .65234 Mdot
.35585 .32944 Mdot
.37405 .65934 Mdot
.45398 .32117 Mdot
.61118 .4914 Mdot
.28546 .38098 Mdot
.54619 .30223 Mdot
.61524 .49232 Mdot
.51186 .21233 Mdot
.8263 .47746 Mdot
.50941 .32741 Mdot
.58921 .60872 Mdot
.58057 .36118 Mdot
.81043 .4419 Mdot
.80624 .42968 Mdot
.5134 .19928 Mdot
.69964 .45908 Mdot
.35299 .3148 Mdot
.57831 .51786 Mdot
.39881 .35804 Mdot
.44712 .3785 Mdot
.76602 .45731 Mdot
.32603 .5745 Mdot
.51166 .35657 Mdot
.46503 .65189 Mdot
.77652 .4893 Mdot
.49554 .38336 Mdot
.45522 .32614 Mdot
.48301 .49469 Mdot
.62631 .46875 Mdot
.66608 .52099 Mdot
.55027 .1839 Mdot
.46929 .70729 Mdot
.53009 .36534 Mdot
.45012 .72597 Mdot
.42586 .70776 Mdot
.70975 .47708 Mdot
.45698 .6594 Mdot
.61687 .22262 Mdot
.63809 .50296 Mdot
.56872 .3228 Mdot
.60893 .55882 Mdot
.43163 .77771 Mdot
.42755 .38817 Mdot
.54451 .33124 Mdot
.52732 .37501 Mdot
.50819 .19393 Mdot
.50376 .38077 Mdot
.48172 .42915 Mdot
.50458 .22588 Mdot
.47209 .66709 Mdot
.37736 .33387 Mdot
.52953 .23157 Mdot
.38107 .58609 Mdot
.54967 .26598 Mdot
.5921 .70958 Mdot
.58982 .47121 Mdot
.45532 .76178 Mdot
.40299 .34094 Mdot
.39654 .3407 Mdot
.55106 .36638 Mdot
.63175 .73113 Mdot
.41821 .55889 Mdot
.43871 .52699 Mdot
.67614 .49698 Mdot
.39104 .35342 Mdot
.5242 .59932 Mdot
.52334 .17771 Mdot
.34027 .42613 Mdot
.71784 .44476 Mdot
.77394 .47053 Mdot
.62831 .64827 Mdot
.58948 .53344 Mdot
.4468 .7651 Mdot
.34459 .52355 Mdot
.40542 .30793 Mdot
.5377 .21682 Mdot
.58897 .5319 Mdot
.27174 .43803 Mdot
.335 .49817 Mdot
.58762 .61852 Mdot
.64315 .70468 Mdot
.5008 .60254 Mdot
.56946 .46225 Mdot
.33849 .44053 Mdot
.73691 .47003 Mdot
.82964 .43706 Mdot
.50382 .21227 Mdot
.64583 .69918 Mdot
.39894 .33735 Mdot
.44708 .50256 Mdot
.55782 .42639 Mdot
.52062 .17562 Mdot
.78035 .50359 Mdot
.44085 .68147 Mdot
.76464 .48539 Mdot
.63742 .72321 Mdot
.60351 .49276 Mdot
.37488 .32641 Mdot
.50881 .22922 Mdot
.41261 .59779 Mdot
.55589 .52564 Mdot
.47225 .48817 Mdot
.26366 .38773 Mdot
.49701 .66605 Mdot
.3144 .53094 Mdot
.64263 .74156 Mdot
.50656 .19575 Mdot
.67686 .46864 Mdot
.42894 .48898 Mdot
.50426 .18921 Mdot
.40102 .62725 Mdot
.50094 .67344 Mdot
.66547 .70988 Mdot
.41837 .33652 Mdot
.65084 .53499 Mdot
.35203 .43058 Mdot
.33388 .3161 Mdot
.46009 .62389 Mdot
.51639 .39576 Mdot
.62364 .27139 Mdot
.43406 .69874 Mdot
.69296 .46651 Mdot
.43057 .69623 Mdot
.8231 .4312 Mdot
.52226 .5877 Mdot
.45021 .66765 Mdot
.32657 .5075 Mdot
.6328 .53077 Mdot
.475 .66637 Mdot
.52557 .33168 Mdot
.30256 .44154 Mdot
.44611 .65307 Mdot
.44476 .65972 Mdot
.39183 .57618 Mdot
.62174 .68015 Mdot
.52781 .29945 Mdot
.79398 .48045 Mdot
.63114 .34114 Mdot
.37502 .58289 Mdot
.40148 .34921 Mdot
.59628 .5497 Mdot
.52423 .35235 Mdot
.74185 .53984 Mdot
.59022 .19748 Mdot
.294 .55111 Mdot
.50287 .69394 Mdot
.51875 .55659 Mdot
.27496 .42504 Mdot
.39099 .34463 Mdot
.63477 .5385 Mdot
.59877 .53519 Mdot
.40138 .54582 Mdot
.41894 .67585 Mdot
.51118 .68356 Mdot
.59812 .25199 Mdot
.6365 .35353 Mdot
.63914 .67796 Mdot
.33062 .54863 Mdot
.77894 .46571 Mdot
.39211 .76093 Mdot
.63912 .37036 Mdot
.62366 .53425 Mdot
.46142 .37788 Mdot
.29254 .44186 Mdot
.56751 .18416 Mdot
.51465 .31959 Mdot
.41438 .66603 Mdot
.49534 .68968 Mdot
.65617 .49374 Mdot
.54494 .36442 Mdot
.5612 .54413 Mdot
.75958 .45624 Mdot
.47366 .45891 Mdot
.5381 .35179 Mdot
.45164 .64957 Mdot
.495 .58703 Mdot
.76576 .47769 Mdot
.57785 .34979 Mdot
.78698 .48846 Mdot
.36213 .52235 Mdot
.54573 .4433 Mdot
.77179 .49848 Mdot
.48851 .48196 Mdot
.62413 .57472 Mdot
.24994 .53837 Mdot
.50737 .56961 Mdot
.8028 .45195 Mdot
.41875 .69014 Mdot
.58479 .45862 Mdot
.45967 .68355 Mdot
.62655 .71355 Mdot
.52565 .31605 Mdot
.48954 .69224 Mdot
.78843 .48145 Mdot
.40139 .35468 Mdot
.55422 .39664 Mdot
.33106 .56651 Mdot
.31463 .44529 Mdot
.62786 .39865 Mdot
.41725 .51284 Mdot
.56969 .41405 Mdot
.39627 .2951 Mdot
.42747 .37563 Mdot
.54667 .24096 Mdot
.37164 .29546 Mdot
.50579 .4568 Mdot
.61244 .47731 Mdot
.38007 .64337 Mdot
.56678 .21371 Mdot
.39919 .30961 Mdot
.46136 .74411 Mdot
.79575 .47155 Mdot
.69457 .45231 Mdot
.50295 .18847 Mdot
.63475 .72802 Mdot
.51832 .44863 Mdot
.82832 .45296 Mdot
.54187 .51112 Mdot
.67865 .45852 Mdot
.60875 .55861 Mdot
.42065 .71166 Mdot
.54798 .21492 Mdot
.61706 .48385 Mdot
.50073 .46328 Mdot
.34077 .40089 Mdot
.42874 .63595 Mdot
.37517 .30646 Mdot
.41768 .35242 Mdot
.72636 .52168 Mdot
.27849 .43836 Mdot
.66201 .47595 Mdot
.3807 .57696 Mdot
.77252 .46542 Mdot
.76079 .45063 Mdot
.54964 .4277 Mdot
.63778 .59875 Mdot
.49945 .19235 Mdot
.48802 .41741 Mdot
.27006 .54899 Mdot
.43136 .68836 Mdot
.62412 .26568 Mdot
.71423 .45866 Mdot
.45034 .45791 Mdot
.29765 .46456 Mdot
.46755 .46766 Mdot
.55153 .29814 Mdot
.48996 .51005 Mdot
.56975 .65042 Mdot
.38185 .58349 Mdot
.46202 .7412 Mdot
.45565 .69908 Mdot
.63303 .74319 Mdot
.80073 .4505 Mdot
.52451 .6313 Mdot
.49298 .59659 Mdot
.49904 .44951 Mdot
.77143 .44341 Mdot
.63635 .70063 Mdot
.60982 .65756 Mdot
.34491 .57475 Mdot
.50409 .20662 Mdot
.42825 .72248 Mdot
.4869 .62154 Mdot
.5533 .58237 Mdot
.45181 .36174 Mdot
.61528 .73264 Mdot
.49501 .67832 Mdot
.43313 .66558 Mdot
.51364 .25344 Mdot
.56638 .59623 Mdot
.58129 .35336 Mdot
.74291 .48467 Mdot
.53644 .58339 Mdot
.76508 .45234 Mdot
.3626 .62234 Mdot
.5148 .23539 Mdot
.42184 .33238 Mdot
.57411 .42686 Mdot
.35096 .42237 Mdot
.45298 .63158 Mdot
.54851 .3425 Mdot
.5591 .54321 Mdot
.55769 .62312 Mdot
.44905 .69332 Mdot
.81434 .47238 Mdot
.63531 .37038 Mdot
.67865 .70109 Mdot
.61812 .47135 Mdot
.28727 .45511 Mdot
.27749 .44782 Mdot
.62314 .66578 Mdot
.59979 .55734 Mdot
.45112 .59897 Mdot
.56587 .4601 Mdot
.3415 .56125 Mdot
.56794 .32851 Mdot
.54574 .18199 Mdot
.40339 .62271 Mdot
.81934 .48426 Mdot
.36272 .58456 Mdot
.41191 .62859 Mdot
.67515 .4654 Mdot
.59033 .60416 Mdot
.51835 .43152 Mdot
.52388 .40267 Mdot
.39656 .74785 Mdot
.54089 .17644 Mdot
.53611 .62449 Mdot
.57015 .45134 Mdot
.66144 .49688 Mdot
.48802 .63677 Mdot
.65154 .60794 Mdot
.64498 .64601 Mdot
.81767 .46843 Mdot
.76037 .46484 Mdot
.63836 .61236 Mdot
.61811 .58195 Mdot
.5531 .62221 Mdot
.52495 .24162 Mdot
.61738 .47655 Mdot
.5287 .32423 Mdot
.65087 .73405 Mdot
.34874 .54464 Mdot
.36512 .29547 Mdot
.40288 .31573 Mdot
.30771 .44085 Mdot
.43901 .49199 Mdot
.51282 .27425 Mdot
.5979 .36677 Mdot
.63352 .34724 Mdot
.67506 .49205 Mdot
.52433 .17349 Mdot
.47843 .66015 Mdot
.63037 .38203 Mdot
.53508 .3997 Mdot
.56427 .59529 Mdot
.35108 .32845 Mdot
.44022 .53269 Mdot
.57286 .37061 Mdot
.59007 .62083 Mdot
.46146 .70233 Mdot
.551 .27833 Mdot
.3535 .41996 Mdot
.24175 .41934 Mdot
.61682 .71954 Mdot
.64366 .55186 Mdot
.45074 .70043 Mdot
.56086 .18742 Mdot
.60808 .65253 Mdot
.6682 .68286 Mdot
.62616 .66384 Mdot
.53382 .36411 Mdot
.67236 .72571 Mdot
.61885 .68779 Mdot
.83276 .44114 Mdot
.505 .69476 Mdot
.43149 .49071 Mdot
.43651 .74123 Mdot
.39345 .29464 Mdot
.40367 .52258 Mdot
.6013 .3546 Mdot
.54347 .28908 Mdot
.38458 .34223 Mdot
.58981 .46596 Mdot
.51053 .26666 Mdot
.76517 .48048 Mdot
.75058 .4892 Mdot
.61243 .72237 Mdot
.4338 .62813 Mdot
.68067 .72811 Mdot
.65105 .50567 Mdot
.30058 .56055 Mdot
.51043 .31714 Mdot
.44882 .47082 Mdot
.5576 .53791 Mdot
.44107 .51994 Mdot
.53564 .23462 Mdot
.78807 .44886 Mdot
.64367 .57865 Mdot
.64875 .56938 Mdot
.42368 .32147 Mdot
.54792 .41893 Mdot
.42551 .56742 Mdot
.51019 .33399 Mdot
.63224 .53791 Mdot
.61713 .48271 Mdot
.77477 .47634 Mdot
.45298 .63186 Mdot
.33 .44674 Mdot
.5079 .20303 Mdot
.30163 .45178 Mdot
.80334 .49457 Mdot
.6558 .71792 Mdot
.67389 .4937 Mdot
.52659 .17605 Mdot
.43912 .59542 Mdot
.39013 .38272 Mdot
.49699 .1869 Mdot
.56566 .2246 Mdot
.55582 .62047 Mdot
.44315 .39798 Mdot
.83339 .44652 Mdot
.63228 .56641 Mdot
.54111 .37779 Mdot
.33495 .58452 Mdot
.72883 .48736 Mdot
.4034 .36913 Mdot
.45869 .44887 Mdot
.57215 .45769 Mdot
.40601 .63876 Mdot
.43835 .63864 Mdot
.64859 .47276 Mdot
.75884 .48667 Mdot
.32314 .55355 Mdot
.34578 .60514 Mdot
.35699 .5246 Mdot
.41288 .70475 Mdot
.54306 .30351 Mdot
.6045 .21199 Mdot
.31802 .5694 Mdot
.51818 .2454 Mdot
.24491 .40047 Mdot
.47143 .63755 Mdot
.34097 .5744 Mdot
.38855 .32618 Mdot
.6602 .47328 Mdot
.5143 .1726 Mdot
.34727 .55895 Mdot
.58679 .19821 Mdot
.55608 .29092 Mdot
.41422 .67418 Mdot
.37788 .56641 Mdot
.40991 .34842 Mdot
.53548 .61218 Mdot
.599 .61531 Mdot
.67227 .49893 Mdot
.69125 .45821 Mdot
.62777 .50299 Mdot
.36222 .41003 Mdot
.42915 .52419 Mdot
.5407 .33335 Mdot
.60339 .49136 Mdot
.54031 .32671 Mdot
.38296 .52714 Mdot
.34777 .43194 Mdot
.49626 .17919 Mdot
.47542 .71912 Mdot
.42418 .3643 Mdot
.64405 .39879 Mdot
.63056 .3834 Mdot
.28933 .37992 Mdot
.61112 .69436 Mdot
.45604 .34715 Mdot
.71048 .48604 Mdot
.541 .29346 Mdot
.37088 .58883 Mdot
.4021 .34615 Mdot
.64334 .61836 Mdot
.34012 .43688 Mdot
.39604 .36958 Mdot
.60407 .71415 Mdot
.68832 .48227 Mdot
.66216 .59911 Mdot
.62545 .70928 Mdot
.49163 .65704 Mdot
.31772 .32397 Mdot
.62233 .36808 Mdot
.68216 .47503 Mdot
.62271 .66251 Mdot
.61654 .72219 Mdot
.78816 .48256 Mdot
.47492 .44022 Mdot
.64294 .71649 Mdot
.65577 .45806 Mdot
.37707 .33221 Mdot
.44045 .51327 Mdot
.56196 .60998 Mdot
.31782 .52323 Mdot
.52915 .25618 Mdot
.60791 .33741 Mdot
.60607 .36331 Mdot
.31661 .50243 Mdot
.54253 .24581 Mdot
.60938 .66833 Mdot
.81464 .41101 Mdot
.59285 .60227 Mdot
.45954 .68026 Mdot
.31313 .48116 Mdot
.58403 .53686 Mdot
.25435 .50329 Mdot
.44284 .39722 Mdot
.31681 .46907 Mdot
.66583 .68094 Mdot
.59271 .53731 Mdot
.49147 .64671 Mdot
.51281 .62431 Mdot
.50065 .38235 Mdot
.25529 .50458 Mdot
.40437 .39978 Mdot
.58774 .37066 Mdot
.3438 .30764 Mdot
.59731 .3577 Mdot
.53208 .41952 Mdot
.65777 .67141 Mdot
.68588 .47677 Mdot
.74609 .48903 Mdot
.49675 .40993 Mdot
.54043 .22637 Mdot
.25493 .54599 Mdot
.51349 .32127 Mdot
.46664 .52039 Mdot
.65316 .70092 Mdot
.29925 .45309 Mdot
.51321 .17625 Mdot
.41477 .52688 Mdot
.59643 .23791 Mdot
.56103 .31755 Mdot
.52928 .34027 Mdot
.63693 .61448 Mdot
.43582 .76645 Mdot
.67895 .49156 Mdot
.43977 .35557 Mdot
.45679 .70986 Mdot
.61883 .33487 Mdot
.5525 .35916 Mdot
.5742 .47982 Mdot
.57706 .60867 Mdot
.31471 .5366 Mdot
.45196 .37508 Mdot
.72261 .51069 Mdot
.31907 .51827 Mdot
.44236 .48909 Mdot
.5123 .27621 Mdot
.2718 .54746 Mdot
.49671 .5496 Mdot
.42252 .52045 Mdot
.50919 .19617 Mdot
.71767 .50868 Mdot
.27014 .43589 Mdot
.27307 .56071 Mdot
.66495 .6888 Mdot
.67708 .45496 Mdot
.50309 .21127 Mdot
.64599 .63546 Mdot
.56522 .45905 Mdot
.47318 .75665 Mdot
.43773 .50988 Mdot
.42923 .66554 Mdot
.63497 .68004 Mdot
.59622 .44098 Mdot
.46361 .49261 Mdot
.51375 .16415 Mdot
.5426 .35311 Mdot
.51544 .43489 Mdot
.30058 .56351 Mdot
.77498 .47414 Mdot
.26591 .44431 Mdot
.64475 .722 Mdot
.54565 .30607 Mdot
.64171 .61013 Mdot
.83068 .4515 Mdot
.53784 .59012 Mdot
.36772 .62819 Mdot
.54542 .41802 Mdot
.45855 .71592 Mdot
.58708 .51681 Mdot
.34272 .60312 Mdot
.46528 .71954 Mdot
.5067 .35712 Mdot
.57193 .57187 Mdot
.39238 .75335 Mdot
.36569 .57125 Mdot
.52482 .56282 Mdot
.60037 .60202 Mdot
.4878 .62086 Mdot
.49958 .59583 Mdot
.63312 .70247 Mdot
.5129 .55056 Mdot
.47585 .7219 Mdot
.63278 .63714 Mdot
.38285 .52141 Mdot
.65642 .47027 Mdot
.50916 .38914 Mdot
.73146 .54112 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0:7ooooo1Ol0002Sooooo`00
7?ooool00ol0003oooooooooo`2Pooooo`Wo0000X?ooool001cooooo00?o0000ooooooooool0X?oo
ool:o`0009oooooo000Looooo`03o`000?oooooooooo0:3ooooo0_l00006ooooo`Ko0000Voooool0
01cooooo00?o0000ooooooooool0X?ooool2o`000003ooooool0003o000000;ooooo0_l000000ooo
oooo0000o`000002o`000003ooooool0003o000009Sooooo000Looooo`03o`000?oooooooooo0:?o
oooo1_l00003ooooo`;o000000?oooooo`000?l000000_l0002Fooooo`007?ooool00ol0003ooooo
ooooo`2Mooooo`Co00000_ooool6o`0000?ooooo0_l00003ooooo`?o0000UOooool001cooooo00?o
0000ooooooooool0WOooool4o`0000Cooooo0_l00007ooooo`?o000000Coooooo`000?l0003ooooo
0_l0002Booooo`007?ooool00ol0003oooooooooo`2Nooooo`Co00003?ooool3o`000004ooooool0
003o0000ooooo`;o0000T_ooool001cooooo00?o0000ooooooooool0W_ooool4o`00013ooooo0_l0
0005ooooo`;o0000S_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo
1Ol00006ooooo`03o`000?oooooooooo09kooooo1?l0000@ooooo`;o00001Oooool2o`0008kooooo
00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@01_ooool00ol0003oooooooooo`2Nooooo`;o000000Coooooo`000?l0003o00003_ooool2
o`0009Gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q
8Oo^k^h01oooool00ol0003oooooooooo`2Qooooo`Co00000_ooool2o`0001;ooooo1?l0002:oooo
o`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Ko
oooo0ol0002Qooooo`Co00000_ooool2o`0000cooooo1?l00002ooooo`Co0000R_ooool00003oooo
ool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`00
0?oooooooooo0:7ooooo0_l0000<ooooo`;o00001?ooool4o`0000?ooooo0_l0002;ooooo`0000?o
oooooa0@4?ooool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0X?ooool2o`0000gooooo0_l0000;ooooo`Co0000ROooool00006oooooomgMgOo
V9RHoooooonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000oooooooo
ool0X?ooool2o`000003ooooool0003o000000cooooo0ol00005ooooo`;o00000oooool2o`000003
ooooool0003o000008Kooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0:3ooooo0_l000000ooooooo0000o`000006
ooooo`;o000000Coooooo`000?l0003ooooo1Ol00003ooooo`;o00001_ooool2o`0008Kooooo000L
ooooo`03o`000?oooooooooo0:3ooooo0_l00003ooooo`;o00001?ooool2o`000003ooooool0003o
000000Cooooo1Ol00008ooooo`;o000000?oooooo`000?l00000Poooool001cooooo00?o0000oooo
ooooool0YOooool2o`0000Cooooo1?l00006ooooo`Co00002?ooool5o`0008?ooooo000Looooo`03
o`000?oooooooooo0:gooooo0_l00005ooooo`?o00002oooool2o`000003ooooool0003o000008;o
oooo000Looooo`03o`000?oooooooooo0:3ooooo0ol00008ooooo`?o00001_ooool2o`0000;ooooo
1?l00009ooooo`;o0000P_ooool001cooooo00?o0000ooooooooool0X?ooool5o`0000Kooooo0ol0
0009ooooo`Ko00001oooool2o`0008?ooooo000Looooo`03o`000?oooooooooo0:;ooooo0ol00003
ooooo`;o00002oooool:o`000003ooooool0003o000000;ooooo0_l00023ooooo`007?ooool00ol0
003oooooooooo`2Sooooo`;o00000oooool4o`0000Cooooo0_l00003ooooo`Co00000oooool3o`00
0003ooooool0003o000000Go0000P_ooool001cooooo00?o0000ooooooooool0XOooool4o`0000;o
oooo0_l000000ooooooo0000o`000004ooooo`;o00000_ooool2o`0000Oooooo0ol00002ooooo`Go
0000P_ooool001cooooo00?o0000ooooooooool0XOooool2o`0000Cooooo0_l00004ooooo`?o0000
1?ooool2o`0000Oooooo0ol00002ooooo`Go0000P_ooool001cooooo00?o0000ooooooooool0YOoo
ool4o`0000?ooooo1?l00005ooooo`;o00001Oooool3o`0000?ooooo1?l00023ooooo`007?ooool0
0ol0003oooooooooo`2Uooooo`;o00001Oooool2o`0000Oooooo0_l00004ooooo`?o00001?ooool5
o`0008;ooooo000Looooo`;o0000]?ooool3o`0000?ooooo2?l000000ooooooo0000o`000005o`00
083ooooo000Looooo`03o`000?oooooooooo0:?ooooo0_l0000>ooooo`?o00000oooool@o`00083o
oooo000Looooo`03o`000?oooooooooo0:?ooooo0_l00003ooooo`;o00002_ooool2o`0000?ooooo
4?l00020ooooo`007?ooool00ol0003oooooooooo`2Xooooo`;o00002_oooolEo`00083ooooo000L
ooooo`03o`000?oooooooooo0:oooooo0_l00005oooooa?o0000P?ooool001cooooo00?o0000oooo
ooooool0X_ooool2o`000003ooooool0003o000000Gooooo0_l000000ooooooo0000o`00000Ho`00
083ooooo000Looooo`03o`000?oooooooooo0:;ooooo0_l000001?oooooo0000o`000?l00004oooo
o`;o000000?oooooo`000?l000006?l00020ooooo`007?ooool00ol0003oooooooooo`2Rooooo`;o
00000_ooool2o`0000gooooo5?l00020ooooo`007?ooool00ol0003oooooooooo`2Rooooo`?o0000
4?oooolDo`00083ooooo000Looooo`03o`000?oooooooooo0:?ooooo0_l00006ooooo`;o00000_oo
ool4o`0000;ooooo4_l00022ooooo`007?ooool00ol0003oooooooooo`2[ooooo`;o00000_ooool4
o`0000;ooooo4_l00022ooooo`007?ooool00ol0003oooooooooo`2Rooooo`;o00004?oooolDo`00
087ooooo000Looooo`03o`000?oooooooooo0:;ooooo0_l00009ooooo`;o00001OoooolDo`00087o
oooo000Looooo`03o`000?oooooooooo07?ooooo0ol00004ooooo`;o0000<Oooool2o`000003oooo
ool0003o000001Co0000Poooool001cooooo00?o0000ooooooooool0LOooool6o`0000?ooooo1Ol0
0003ooooo`;o0000:?ooool2o`0000;ooooo4_l000000ooooooo0000o`000024ooooo`007?ooool0
0ol0003oooooooooo`1aooooo`Ko00000_ooool8o`000003ooooool0003o000000;o00009_ooool2
o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000003_l00024ooooo`007?ooool2
o`0006oooooo0_l00008ooooo`ko00008_ooool2o`0000Cooooo0ol000000ooooooo0000o`000002
ooooo`ko000000?oooooo`000?l00000P_ooool001cooooo00?o0000ooooooooool0K_ooool4o`00
00Kooooo4?l000000ooooooo0000o`00000Mooooo`;o00000oooool3o`0000;ooooo0_l00003oooo
o`co00000_ooool2o`0008;ooooo000Looooo`03o`000?oooooooooo06_ooooo0ol00002ooooo`;o
00001?ooool2o`0000Oooooo3?l0000Rooooo`?o00001_ooool=o`0008Kooooo000Looooo`03o`00
0?oooooooooo06Sooooo1_l00008ooooo`;o00001_ooool4o`0000;ooooo2_l0000Gooooo`;o0000
1_ooool2o`0000Oooooo0_l000000ooooooo0000o`000007o`0008Oooooo000Looooo`03o`000?oo
oooooooo06Oooooo1?l0000Cooooo`Co00000oooool2o`000003ooooool0003o000000Co00005ooo
ool4o`0000kooooo2_l00028ooooo`007?ooool00ol0003oooooooooo`1Uooooo`Ko00001?ooool4
o`0000cooooo0_l00007ooooo`Oo00006?ooool2o`0000kooooo2ol00027ooooo`007?ooool00ol0
003oooooooooo`1Rooooo`Wo00001?ooool4o`0000cooooo0_l0000;ooooo`Go00004Oooool3o`00
00;ooooo0_l000000ooooooo0000o`000006ooooo`Co00000_ooool:o`0008Oooooo000Looooo`03
o`000?oooooooooo06;ooooo1?l0000Booooo`;o00003?ooool2o`0000Cooooo1_l0000@ooooo`?o
00001Oooool2o`0000Kooooo1Ol000001?oooooo0000o`000?ooool6o`0008Sooooo000Looooo`03
o`000?oooooooooo067ooooo1_l0000Aooooo`Co00002_ooool2o`0000Cooooo1_l0000Aooooo`;o
00000oooool2o`0000Wooooo1Ol00004ooooo`Ko0000Qoooool001cooooo00?o0000ooooooooool0
HOooool6o`000003ooooool0003o000000Cooooo0_l00006ooooo`;o00000_ooool2o`0000oooooo
1ol0000@ooooo`;o00001?ooool2o`0000;ooooo0_l00007ooooo`?o00001_ooool4o`0008Oooooo
000Looooo`03o`000?oooooooooo067ooooo1_l000000ooooooo0000o`000004ooooo`Co00001?oo
ool5o`0000Wooooo1?l00003ooooo`;o000000?oooooo`000?l000001?l0000>ooooo`;o00000ooo
ool2o`0000?ooooo0ol00006ooooo`;o0000T_ooool001cooooo00?o0000ooooooooool0Hoooool6
o`0000Oooooo0_l00005ooooo`Co00001_ooool7o`0000Sooooo1?l0000>ooooo`;o00000oooool2
o`0000?ooooo0ol00009ooooo`;o00002oooool2o`0008;ooooo000Looooo`03o`000?oooooooooo
06Oooooo1?l00002ooooo`;o00002?ooool2o`0000Gooooo0_l000000ooooooo0000o`000003o`00
00[ooooo1?l0000>ooooo`;o000000?oooooo`000?l000001Oooool5o`0000Oooooo0_l00008oooo
o`;o000000?oooooo`000?l00000P_ooool001cooooo00?o0000ooooooooool0JOooool2o`0000;o
oooo2Ol00007ooooo`Co00000oooool2o`0000_ooooo1?l0000@ooooo`;o000000?oooooo`000?l0
00000oooool4o`00017ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o0000OOooool001co
oooo00?o0000ooooooooool0Koooool7o`0000?ooooo2?l0000@ooooo`Co00004oooool2o`0000Co
oooo0_l0000Booooo`;o00000_ooool2o`000004ooooool0003o0000o`0007gooooo000Looooo`03
o`000?oooooooooo07Wooooo2?l0000?ooooo`Go00006Oooool4o`00013ooooo0_l00006ooooo`;o
0000OOooool001cooooo0_l0001hooooo`Co00000_ooool6o`0000gooooo1_l0000Iooooo`?o0000
1_ooool4o`0000Wooooo0_l00002ooooo`?o0000OOooool001cooooo00?o0000ooooooooool0Mooo
ool6o`0000;ooooo1?l000000ooooooo0000o`000005ooooo`;o00001Oooool4o`00017ooooo0_l0
0002ooooo`?o00002_ooool4o`0000Wooooo0ol000000ooooooo0000o`000002o`0007cooooo000L
ooooo`03o`000?oooooooooo07_ooooo0ol000000ooooooo0000o`000003ooooo`;o00001Oooool2
o`0000Gooooo1?l0000;ooooo`?o00000oooool2o`0000;ooooo0ol0000;ooooo`;o00001?ooool5
o`000004ooooool0003o0000o`0000?ooooo0ol0001kooooo`007?ooool00ol0003oooooooooo`1k
ooooo`Ko00002_ooool4o`0000;ooooo1Ol0000:ooooo`Co00003?ooool2o`000003ooooool0003o
000000Wooooo1_l00002ooooo`;o00001?ooool2o`0007_ooooo000Looooo`03o`000?oooooooooo
07kooooo0_l00002ooooo`;o00001_ooool2o`000003ooooool0003o000000Oo00002_ooool3o`00
00;ooooo0_l00007ooooo`Co000000?oooooo`000?l000001?ooool2o`0000?ooooo1_l000001?oo
oooo0000o`000?l00004ooooo`?o0000N_ooool001cooooo00?o0000ooooooooool0P_ooool2o`00
00;ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0ol0000?ooooo`;o000000?oooooo`00
0?l000000_l000000ooooooo0000o`000002o`0000Sooooo0_l00006ooooo`So00000oooool3o`00
07[ooooo000Looooo`03o`000?oooooooooo07oooooo0_l00005ooooo`;o00002oooool2o`0001?o
oooo1?l000000ooooooo0000o`000002o`0000Oooooo1?l00002ooooo`go00000_ooool2o`0007[o
oooo000Looooo`03o`000?oooooooooo07gooooo1?l00007ooooo`;o00002Oooool3o`00017ooooo
0_l0000=oooooa[o0000NOooool001cooooo00?o0000ooooooooool0OOooool2o`0000Sooooo0ol0
0005ooooo`Oo00002?ooool2o`0000Oooooo0ol0000<ooooo`;o00000oooool<o`000004ooooool0
003o0000ooooo`Go0000NOooool001cooooo00?o0000ooooooooool0N_ooool2o`0000_ooooo0_l0
0004ooooo`So00002Oooool2o`0000Sooooo0_l00002ooooo`;o00003Oooool>o`0000Gooooo0_l0
001iooooo`007?ooool00ol0003oooooooooo`1Eooooo`;o00000_ooool6o`0001Sooooo0_l00000
0ooooooo0000o`00000<ooooo`;o00000oooool2o`000003ooooool0003o000000?o00002oooool2
o`0000[ooooo0_l0000<ooooo`oo000000Goooooo`000?l0003o0000ooooo`02o`0007Wooooo000L
ooooo`03o`000?oooooooooo05Gooooo3_l0000Dooooo`;o00000_ooool2o`0000_ooooo0_l00006
ooooo`Go00002?ooool7o`0001Gooooo5?l0001looooo`007?ooool00ol0003oooooooooo`1Boooo
o`;o000000?oooooo`000?l000003Ol0000:ooooo`Go00002?ooool2o`0001Cooooo1?l00008oooo
o`Co000000?oooooo`000?l000005?oooolEo`000003ooooool0003o000007Wooooo000Looooo`03
o`000?oooooooooo04oooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000[o
000000Coooooo`000?l0003o00000_ooool9o`0000[ooooo3?l00009ooooo`;o00003_ooool2o`00
00oooooo0_l00003oooooaGo000000?oooooo`000?l00000NOooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooo
oooo04gooooo1?l000000ooooooo0000o`00000Do`000003ooooool0003o000000Oo00002?ooool?
o`000003ooooool0003o000000Kooooo0_l0000>ooooo`;o00003oooool2o`0000;ooooo5_l0001l
ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo04gooooo0_l00002oooooaco000000Coooooo`000?l0003o0000
1OoooolFo`0000Gooooo0ol0000@ooooo`;o00001_ooool2o`0000;ooooo0_l00005oooooaKo0000
O?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo00?o
0000ooooooooool0D?oooolMo`0000Oooooo1ol000001Ooooooo0000o`000?l0003ooooo00_o0000
00?oooooo`000?l000000oooool3o`00013ooooo0_l00004ooooo`Co00000_ooool2o`0000Gooooo
6?l0001jooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04odA4A?oM
gMgoooooo`0000Oooooo0ol0001<ooooo`;o00000_ooool2o`000003ooooool0003o000001So0000
1?oooolJo`000003ooooool0003o000000?ooooo0_l00008ooooo`;o00002Oooool2o`0000;ooooo
0_l00009oooooaOo000000?oooooo`000?l00000N_ooool00003ooooool0003ooooo00;ooooo00?o
0000ooooooooool02Oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo04cooooo
0_l00002ooooo`;o000000?oooooo`000?l000006?l00002oooooako00001?ooool2o`0000Sooooo
0_l00009ooooo`;o00003OoooolHo`0007cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oo
oooooooo00[ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`1@oooooaWo00001?oo
oolPo`0000Cooooo0_l0000SoooooaCo000000?oooooo`000?l00000O?ooool00006oooooomgMgOo
V9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo053ooooo
0ol000000ooooooo0000o`00000@o`0000Kooooo8ol000000ooooooo0000o`00000<ooooo`;o0000
1_ooool2o`000003ooooool0003o000000_ooooo3?l000000ooooooo0000o`000005o`000003oooo
ool0003o000000?o0000=Oooool2o`000003ooooool0003o000003oooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`1Aoooooa7o
00000_ooool2o`0000Kooooo9_l0000<ooooo`;o00001_ooool2o`000003ooooool0003o000000Oo
oooo6Ol000000ooooooo0000o`000002o`00033ooooo0_l00003ooooo`;o000000?oooooo`000?l0
0000?oooool001cooooo00?o0000ooooooooool0C?ooool2o`0000Cooooo3ol00008ooooo`Oo0000
00?oooooo`000?l000007_l0000:ooooo`;o00004?ooool2o`0000?ooooo6Ol000001?oooooo0000
o`000?l0000aooooo`;o00001?ooool2o`00047ooooo000Looooo`03o`000?oooooooooo04_ooooo
0ol00007ooooo`Co00003_ooool7o`000003ooooool0003o000001oo00002?ooool2o`000003oooo
ool0003o000000cooooo0_l00002ooooo`?o00001oooool?o`0000;ooooo0_l00002ooooo`;o0000
;oooool2o`0000?ooooo0_l00002ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0Booo
ool2o`0000Kooooo1_l0000>ooooobWo00002?ooool2o`0000Wooooo0_l00004ooooo`;o00000ooo
ool2o`0000Oooooo3ol000000ooooooo0000o`000005o`0002oooooo0ol00002ooooo`;o00001_oo
ool2o`0003gooooo000Looooo`03o`000?oooooooooo04_ooooo0_l00006ooooo`;o000000?ooooo
o`000?l000003?ooool2o`000003ooooool0003o000002Ko00005?ooool2o`0000Sooooo1_l00004
ooooo`oo000000?oooooo`000?l000000ol0000booooo`;o00002_ooool2o`0003gooooo000Loooo
o`03o`000?oooooooooo04_ooooo0_l00009ooooo`;o00003?ooool2o`000003ooooool0003o0000
00Go000000?oooooo`000?l000007_l0000:ooooo`;o00004_ooool6o`0000Cooooo0_l00002oooo
o`_o00000_ooool2o`0003Sooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`1<ooooo`?o
00006?ooool4o`000003ooooool0003o0000023o00002oooool2o`0000[ooooo0_l0000Eooooo`So
0000?_ooool2o`0000Cooooo0ol0000nooooo`007?ooool00ol0003oooooooooo`1<ooooo`?o0000
1Oooool2o`0000oooooo1Ol000000ooooooo0000o`00000Oo`0001Sooooo0ol0000Booooo`;o0000
00?oooooo`000?l000000ol00017ooooo`Co0000?Oooool001cooooo00?o0000ooooooooool0COoo
ool2o`0000Gooooo1Ol00005ooooo`;o00000_ooool2o`000003ooooool0003o000000?o000000Go
ooooo`000?l0003o0000ooooo`0Mo`0000Sooooo0_l000000ooooooo0000o`00000;ooooo`;o0000
4oooool2o`0003gooooo0_l0000?ooooo`Co0000??ooool001cooooo00?o0000ooooooooool0EOoo
ool4o`0000;ooooo0_l000000ooooooo0000o`000004o`000003ooooool0003o000000;o000000?o
ooooo`000?l000007Ol0000;ooooo`;o000000?oooooo`000?l000004oooool5o`0000gooooo0_l0
000Yooooo`Co00002oooool2o`0000Wooooo0_l00004ooooo`Co0000??ooool001cooooo00?o0000
ooooooooool0Doooool2o`0000Kooooo0_l00002ooooo`Go000000?oooooo`000?l000000_l00000
0ooooooo0000o`000005o`000003ooooool0003o000001Co00009?ooool5o`0000gooooo0_l0000U
ooooo`;o00000_ooool4o`0000[ooooo0_l0000:ooooo`Co00001?ooool2o`0003cooooo000Loooo
o`03o`000?oooooooooo05?ooooo0_l000000ooooooo0000o`000002o`0000Sooooo0_l000000ooo
oooo0000o`000004o`0000?ooooo1?l000000ooooooo0000o`00000@o`0000cooooo0_l00009oooo
o`Co00001Oooool2o`0003kooooo0_l00002ooooo`;o00003?ooool3o`0000;ooooo0_l00007oooo
o`;o00001?ooool2o`0003cooooo000Looooo`;o0000Eoooool4o`0000Cooooo0_l00004ooooo`Oo
00001Oooool2o`000003ooooool0003o000000Sooooo0ol0000Aooooo`;o00002Oooool4o`0000Go
oooo0_l00004ooooo`;o00002?ooool2o`0002Oooooo0_l0000Cooooo`Co000000?oooooo`000?l0
00000_ooool2o`0000;ooooo0ol00007ooooo`?o0000??ooool001cooooo00?o0000ooooooooool0
Eoooool2o`000004ooooool0003o0000ooooo`?o00001?ooool6o`0002Kooooo0_l0000Iooooo`;o
00002?ooool2o`0000gooooo0_l000000ooooooo0000o`00000?ooooo`;o000000Coooooo`000?l0
003ooooo0ol0000Booooo`Co00002Oooool3o`0000?ooooo1ol0000looooo`007?ooool00ol0003o
ooooooooo`1Gooooo`;o000000Coooooo`000?l0003ooooo0_l00005ooooo`Ko00009Oooool3o`00
00kooooo0ol0000Cooooo`;o00000_ooool2o`0000Sooooo0_l000000ooooooo0000o`000003o`00
00Gooooo1?l00003ooooo`Wo00000oooool2o`0000Gooooo0_l00006ooooo`Co00002_ooool2o`00
00?ooooo1_l0000mooooo`007?ooool00ol0003oooooooooo`1Vooooo`Co00008oooool4o`0000Go
oooo0_l00008ooooo`?o00004Oooool4o`0000;ooooo0_l0000=ooooo`?o00001Oooool4o`0000?o
oooo0ol00002ooooo`Co00000oooool2o`0000Gooooo0_l00005ooooo`Go0000D_ooool001cooooo
00?o0000ooooooooool0GOooool2o`0000Kooooo1Ol0000Sooooo`;o00001oooool2o`0000Gooooo
1?l0000Cooooo`?o00003oooool2o`00013ooooo0_l00005ooooo`;o00004Oooool5o`0001;ooooo
0ol0000mooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o00001Oooool7o`0002Wooooo0_l0
0007ooooo`Co00005?ooool2o`0000Gooooo0_l00008ooooo`;o00004?ooool2o`0000?ooooo0_l0
0003ooooo`Co00003?ooool3o`0000;ooooo1?l0000>ooooo`?o0000?Oooool001cooooo00?o0000
ooooooooool0F_ooool4o`0000Gooooo2?l0000Rooooo`?o00001?ooool2o`0002Kooooo0ol00000
0ooooooo0000o`000006ooooo`;o00001oooool2o`0000Gooooo0_l00003ooooo`;o00000oooool4
o`0000Kooooo0_l00007ooooo`Ko00002oooool2o`00047ooooo000Looooo`03o`000?oooooooooo
05[ooooo1?l00005ooooo`Co00009_ooool3o`0000?ooooo0_l0000Wooooo`?o000000?oooooo`00
0?l000000oooool2o`000003ooooool0003o000000Gooooo1ol00002ooooo`;o00004_ooool3o`00
00Kooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0ol00003ooooo`?o000000?ooooo
o`000?l00000?_ooool001cooooo00?o0000ooooooooool0IOooool2o`0002cooooo0_l0000Hoooo
o`;o00003Oooool2o`0000Cooooo0_l000000ooooooo0000o`000008ooooo`?o000000Coooooo`00
0?l0003o00001?ooool3o`0000Kooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l0
0009ooooo`;o000000?oooooo`000?l000000_ooool3o`000003ooooool0003o000000?o000000?o
ooooo`000?l00000?_ooool001cooooo00?o0000ooooooooool0IOooool3o`00027ooooo0_l0000R
ooooo`;o00002?ooool2o`0000Wooooo1Ol00007ooooo`Co000000?oooooo`000?l000001Oooool3
o`0000Kooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00006ooooo`;o000000?o
ooooo`000?l000002Oooool2o`0000Cooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`1J
ooooo`;o00001_ooool2o`0000;ooooo0ol0000Pooooo`;o00004?ooool2o`0001;ooooo0_l00006
ooooo`;o00002_ooool4o`0000Oooooo0_l00007ooooo`;o00000oooool2o`0001Oooooo0_l00005
ooooo`Co000000?oooooo`000?l000001_ooool2o`0003kooooo000Looooo`03o`000?oooooooooo
05Gooooo0ol000001?oooooo0000o`000?l00003ooooo`;o000000?oooooo`000?l000000oooool2
o`0002Kooooo0_l0000:ooooo`Co00004?ooool2o`0001Cooooo0_l0000@ooooo`;o00000oooool2
o`0000Gooooo0_l00009ooooo`;o00001Oooool2o`0000?ooooo1_l000000ooooooo0000o`000003
ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0EOooool3o`000003ooooool0003o0000
00Ko00001_ooool2o`0001oooooo0_l00002ooooo`;o000000?oooooo`000?l000001Oooool2o`00
00Gooooo0_l0000>ooooo`;o00005Oooool3o`0001cooooo0_l000001?oooooo0000o`000?ooool2
o`0000?ooooo1?l000000ooooooo0000o`000002o`000003ooooool0003o000000Co00002?ooool3
o`00043ooooo000Looooo`03o`000?oooooooooo05Wooooo1ol00007ooooo`Co00007Oooool2o`00
0004ooooool0003o0000o`0000Gooooo0_l000000ooooooo0000o`00000Eooooo`;o00004Oooool2
o`000004ooooool0003o0000o`00017ooooo1?l000000ooooooo0000o`000008ooooo`;o000000?o
ooooo`000?l000000oooool4o`000004ooooool0003o0000o`0000;ooooo0_l00002ooooo`;o0000
0_ooool2o`0000?ooooo1?l00010ooooo`007?ooool00ol0003oooooooooo`1Cooooo`Go00004Ooo
ool4o`0001_ooooo0_l000000ooooooo0000o`000006ooooo`;o00001?ooool2o`0002?ooooo1?l0
00001?oooooo0000o`000?l0000;ooooo`;o00001?ooool4o`000003ooooool0003o0000013ooooo
0ol0000?ooooo`So0000@Oooool001cooooo00?o0000ooooooooool0DOooool8o`00013ooooo1?l0
000/ooooo`;o00008oooool6o`0000_ooooo1_l00002ooooo`?o00005oooool2o`000004ooooool0
003o0000ooooo`;o00002?ooool7o`00047ooooo000Looooo`;o0000D_ooool9o`0000;ooooo0_l0
000;ooooo`Ko00004oooool2o`0003kooooo0_l0000;ooooo`;o00000_ooool2o`0000;ooooo0ol0
000@ooooo`Go00000_ooool5o`000004ooooool0003o0000ooooo`;o00001?ooool7o`0004;ooooo
000Looooo`03o`000?oooooooooo04oooooo3ol00005ooooo`;o00001oooool5o`00013ooooo0ol0
0009ooooo`;o00000_ooool2o`0003Gooooo0_l000000ooooooo0000o`00000:ooooo`;o00003Ooo
ool:o`0000;ooooo1_l00002ooooo`co0000@oooool001cooooo00?o0000ooooooooool0COooool@
o`0000Kooooo0_l000000ooooooo0000o`000007ooooo`Go00002_ooool6o`0000Wooooo0_l00002
ooooo`;o00009?ooool2o`0000oooooo0_l000000ooooooo0000o`000003ooooo`;o00001Oooool2
o`0000Wooooo2_l000000ooooooo0000o`000002o`0000Gooooo0_l00002ooooo`co0000@oooool0
01cooooo00?o0000ooooooooool0COooool@o`0000Wooooo0_l00009ooooo`?o000000?oooooo`00
0?l000003Ol00006ooooo`;o00003oooool2o`0000oooooo0_l00005ooooo`;o00000_ooool2o`00
01Oooooo0_l00009ooooo`;o000000?oooooo`000?l000004Ol00004ooooo`oo0000AOooool001co
oooo00?o0000ooooooooool0C_ooool?o`0001Gooooo0_l000000ooooooo0000o`000007o`0000Ko
oooo0_l00004ooooo`?o00003_ooool2o`0000gooooo1?l00005ooooo`;o00009?ooool@o`000003
ooooool0003o000000Go00001?ooool?o`0004Gooooo000Looooo`03o`000?oooooooooo04gooooo
3ol0000Pooooo`;o00001_ooool2o`0000Gooooo0_l0000Mooooo`;o00003oooool2o`0001Cooooo
0_l00004oooooaWo00001?ooool>o`0004Oooooo000Looooo`03o`000?oooooooooo04gooooo4Ol0
00000ooooooo0000o`000003ooooo`;o00006_ooool2o`0000Gooooo0_l00003ooooo`;o00001_oo
ool2o`0002;ooooo0_l000000ooooooo0000o`00000?ooooo`;o00000oooool2o`0000Cooooo6Ol0
0003ooooo`ko0000B?ooool001cooooo00?o0000ooooooooool0B_oooolDo`000003ooooool0003o
000000?ooooo0_l0000<ooooo`;o00001Oooool2o`0000Cooooo0ol00004ooooo`?o00000oooool2
o`0000Kooooo0_l00006ooooo`;o00006_ooool2o`0001;ooooo0_l00007oooooa[o00000_ooool?
o`0004Wooooo000Looooo`03o`000?oooooooooo04[ooooo4ol00005ooooo`Co00001_ooool2o`00
00;ooooo1?l00005ooooo`;o00001?ooool2o`0000Gooooo1?l000000ooooooo0000o`00000?oooo
o`;o00004?ooool2o`000003ooooool0003o000000_ooooo0_l0000Boooooaco00000_ooool=o`00
04cooooo000Looooo`03o`000?oooooooooo04[ooooo4_l00006ooooo`;o00002?ooool2o`0000;o
oooo0_l00007ooooo`;o00002?ooool2o`0000?ooooo0_l000000ooooooo0000o`00000:ooooo`;o
00005Oooool2o`000003ooooool0003o000000_ooooo0_l0000:ooooo`;o00001_oooolKo`0000;o
oooo2ol0001?ooooo`007?ooool00ol0003oooooooooo`1:oooooa?o00001Oooool2o`0000Oooooo
0_l00005ooooo`;o00001Oooool2o`0000Sooooo0_l00006ooooo`;o00002_ooool2o`0002?ooooo
0_l000000ooooooo0000o`000009ooooo`;o00001?oooolXo`00057ooooo000Looooo`03o`000?oo
oooooooo04kooooo0ol000000ooooooo0000o`000009o`0000Gooooo0_l00007ooooo`;o00001Ooo
ool2o`0000[ooooo0_l0000;ooooo`Co0000;Oooool2o`000003ooooool0003o000000Kooooo0_l0
00000ooooooo0000o`000002o`000003ooooool0003o000002Ko0000D_ooool001cooooo00?o0000
ooooooooool0B_ooool2o`000003ooooool0003o000000co00002?ooool2o`0001Wooooo0_l00007
ooooo`;o00001?ooool2o`0002;ooooo0_l00007ooooo`Oo00001_ooool2o`000003ooooool0003o
000001co000000?oooooo`000?l000001ol0001Gooooo`007?ooool00ol0003oooooooooo`1:oooo
o`;o000000?oooooo`000?l000002ol00009ooooo`;o00005_ooool2o`0000Wooooo0ol0000Xoooo
o`;o00000oooool2o`0000;ooooo0_l000000ooooooo0000o`00000;ooooo`;o00000_oooolRo`00
05Wooooo000Looooo`03o`000?oooooooooo04_ooooo0_l00003ooooo`Wo00004?ooool2o`0000?o
oooo0_l0000;ooooo`;o00002Oooool2o`0002[ooooo0ol000000ooooooo0000o`000006ooooo`;o
00003ooooolPo`0005[ooooo000Looooo`03o`000?oooooooooo04_ooooo0_l00002ooooo`;o0000
00?oooooo`000?l000000ol0000Booooo`;o00000oooool2o`0000oooooo0_l00005ooooo`;o0000
:_ooool3o`0000Sooooo0ol0000?oooooaWo00001?ooool2o`0005_ooooo000Looooo`;o0000D?oo
ool8o`0000Gooooo0_l0000:ooooo`;o00005Oooool2o`0001gooooo0_l00003ooooo`;o00006?oo
ool3o`0000;ooooo0_l0000;oooooa_o0000Goooool001cooooo00?o0000ooooooooool0D?ooool6
o`0000Kooooo0_l00007ooooo`;o000000?oooooo`000?l000003Oooool2o`000003ooooool0003o
000000gooooo0_l0000Cooooo`;o00000oooool2o`0001Gooooo0_l00002ooooo`;o00000_ooool2
o`0000Wooooo5Ol000000ooooooo0000o`000005o`0005oooooo000Looooo`03o`000?oooooooooo
053ooooo1_l0000?ooooo`;o00002oooool2o`0000?ooooo0_l000000ooooooo0000o`00000=oooo
o`;o00006_ooool2o`00017ooooo1?l00003ooooo`;o00002ooooolKo`0006;ooooo000Looooo`03
o`000?oooooooooo04oooooo1?l000000ooooooo0000o`00000Gooooo`;o00000oooool2o`00013o
oooo0_l00006ooooo`;o00005oooool2o`00017ooooo0_l00005ooooo`;o000000?oooooo`000?l0
00002?ooool2o`000003ooooool0003o000000oo000000?oooooo`000?l000000_l0001Tooooo`00
7?ooool00ol0003oooooooooo`1?ooooo`Co000000Coooooo`000?l0003o00001oooool2o`0000_o
oooo1?l0000>ooooo`;o00001Oooool2o`0000Kooooo0_l0000Iooooo`;o00006Oooool2o`0000_o
oooo4?l00002ooooo`;o0000I_ooool001cooooo00?o0000ooooooooool0D?ooool3o`0000;ooooo
0_l000000ooooooo0000o`000004ooooo`;o00002?ooool2o`000003ooooool0003o000000[ooooo
0_l00004ooooo`;o00008oooool2o`0000?ooooo0_l00005ooooo`;o00006_ooool4o`000003oooo
ool0003o000000_o000000?oooooo`000?l00000J_ooool001cooooo00?o0000ooooooooool0D_oo
ool2o`000004ooooool0003o0000ooooo`So00001?ooool6o`0000Cooooo0_l00003ooooo`;o0000
0_ooool2o`0000gooooo0_l0000Iooooo`?o00002_ooool2o`0000kooooo0_l00002ooooo`;o0000
1_ooool4o`000003ooooool0003o000000[o0000K_ooool001cooooo00?o0000ooooooooool0D_oo
ool2o`0000;ooooo4_l00006ooooo`;o00000oooool2o`00017ooooo0_l0000Iooooo`;o00004ooo
ool2o`0000Kooooo0_l00002ooooo`;o00002oooool9o`00077ooooo000Looooo`03o`000?oooooo
oooo05Kooooo0_l00005ooooo`co00000_ooool3o`0000Gooooo0_l00011ooooo`;o000000?ooooo
o`000?l000003?ooool2o`0000Oooooo1_l000000ooooooo0000o`00001`ooooo`007?ooool00ol0
003oooooooooo`1Qooooo`go00002_ooool2o`0000;ooooo0_l00006ooooo`;o0000<oooool2o`00
00?ooooo0_l00005ooooo`Co00001?ooool2o`0000Gooooo0_l000000ooooooo0000o`00001`oooo
o`007?ooool00ol0003oooooooooo`1Wooooo`Oo00002_ooool2o`0000;ooooo0_l00006ooooo`;o
0000>?ooool3o`0000Cooooo0_l00005ooooo`?o0000N_ooool001cooooo00?o0000ooooooooool0
IOooool;o`0000;ooooo0_l00002ooooo`Co00005oooool2o`0001Oooooo0_l00004ooooo`;o0000
3Oooool2o`0000?ooooo1?l00004ooooo`?o0000N_ooool001cooooo00?o0000ooooooooool0I?oo
ool@o`0000;ooooo1?l0000Gooooo`;o00002_ooool2o`0000Oooooo0_l00002ooooo`;o00001?oo
ool2o`0001;ooooo1?l00005ooooo`;o0000N_ooool001cooooo00?o0000ooooooooool0I?ooool?
o`0000;ooooo0_l000000ooooooo0000o`00000Sooooo`;o00001oooool2o`0000?ooooo0_l00003
ooooo`Co00004_ooool2o`00087ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ
8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`1Uooooo`?o0000
00?oooooo`000?l000003?l0000;ooooo`;o000000?oooooo`000?l000006Oooool2o`0000Cooooo
0_l00003ooooo`;o00000oooool4o`0001Wooooo0_l0001jooooo`0000KoooooogMgMonHV9Sooooo
oiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000oooo
ooooool0I_ooool3o`0000;ooooo3Ol0000:ooooo`;o000000?oooooo`000?l000001?ooool2o`00
00Oooooo0_l00006ooooo`;o000000Coooooo`000?l0003o00002Oooool2o`0000Oooooo0_l00006
ooooo`;o00003oooool2o`0000Cooooo0ol0001cooooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`1V
ooooo`?o00001Oooool;o`0000Cooooo0_l00003ooooo`;o000000?oooooo`000?l000001?ooool2
o`0000;ooooo0_l00003ooooo`;o00001_ooool5o`0000Kooooo0_l00002ooooo`;o00001oooool2
o`0000Kooooo0_l0000=ooooo`;o00001_ooool3o`0007?ooooo00000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000Ioooool2
o`0000?ooooo3Ol00004ooooo`;o00000oooool2o`0000_ooooo0_l0000;ooooo`Go00001_ooool2
o`0001Cooooo1?l0000:ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0007Cooooo0000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<
c006ooooo`03o`000?oooooooooo06Oooooo0_l00003oooooa3o00008?ooool2o`000003ooooool0
003o000001;ooooo0_l00007ooooo`Go00003Oooool3o`0000?ooooo0_l0001cooooo`0000?ooooo
oa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000
ooooooooool0KOooool?o`0003;ooooo0_l00003ooooo`;o00000oooool3o`000003ooooool0003o
000000Wooooo0_l00006ooooo`?o00000_ooool2o`0007?ooooo00001_ooooooMgMgoiRHV?oooooo
V9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`1_ooooo`go00004ooo
ool2o`0001Wooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l00003ooooo`?o000000?o
ooooo`000?l000001?ooool2o`0000?ooooo0_l00003ooooo`?o000000?oooooo`000?l000000_oo
ool2o`0007?ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o
410@1_ooool00ol0003oooooooooo`1_ooooo`;o000000?oooooo`000?l000002ol0000@ooooo`;o
00004_ooool2o`0000Gooooo0_l00005ooooo`Co00002_ooool2o`000003ooooool0003o000000;o
oooo0_l00003ooooo`Co000000?oooooo`000?l000000_ooool2o`0007?ooooo000Looooo`03o`00
0?oooooooooo07;ooooo3Ol00009ooooo`;o00006Oooool2o`0000?ooooo0_l0000Aooooo`;o0000
0_ooool2o`0000Gooooo0_l00003ooooo`Co00001Oooool2o`0007?ooooo000Looooo`03o`000?oo
oooooooo06oooooo0_l000000ooooooo0000o`00000<o`0000Sooooo0_l0000@ooooo`?o00002ooo
ool2o`0000Oooooo0_l00004ooooo`;o00000_ooool3o`0000Gooooo0_l00003ooooo`;o000000?o
ooooo`000?l000000_l00003ooooo`Go0000L_ooool001cooooo00?o0000ooooooooool0Koooool2
o`000003ooooool0003o000000go00004Oooool2o`0000Gooooo1?l00006ooooo`;o00001Oooool3
o`0000?ooooo0ol00004ooooo`;o00000_ooool3o`0000Gooooo0_l00003ooooo`;o00000_ooool2
o`0000Cooooo1Ol0001booooo`007?ooool00ol0003oooooooooo`1booooo`oo00000oooool2o`00
00?ooooo0_l00007ooooo`;o00001Oooool2o`0000Sooooo0_l00005ooooo`?o00000oooool5o`00
00;ooooo0ol000000ooooooo0000o`00000Gooooo`;o0000Loooool001cooooo00?o0000oooooooo
ool0M?ooool=o`000003ooooool0003o000000?o00000_ooool2o`0000?ooooo0_l000000ooooooo
0000o`000005ooooo`?o00003?ooool2o`0000Sooooo1?l00002ooooo`Ko0000S?ooool001cooooo
00?o0000ooooooooool0M_ooool>o`000003ooooool0003o000000Oooooo1Ol00005ooooo`?o0000
0oooool2o`0000Oooooo0_l0000>ooooo`Wo0000ROooool001cooooo00?o0000ooooooooool0N?oo
ool:o`0000Gooooo0ol00005ooooo`;o00002_ooool2o`000003ooooool0003o000000Oooooo0_l0
0003ooooo`;o00002?ooool3o`000003ooooool0003o000000Co00000_ooool2o`0000Kooooo0_l0
0002ooooo`;o0000NOooool001cooooo00?o0000ooooooooool0Moooool;o`0000Gooooo0ol00000
0ooooooo0000o`000008ooooo`;o00001?ooool2o`0000oooooo0_l00008ooooo`[o00000_ooool3
o`0000Gooooo1_l0001iooooo`007?ooool00ol0003oooooooooo`1gooooo`_o00002Oooool2o`00
00Sooooo0_l0000<ooooo`;o00004oooool=o`0000Oooooo0_l0001kooooo`007?ooool00ol0003o
ooooooooo`1hooooo`_o00002?ooool2o`0000oooooo0_l00005ooooo`;o00004oooool<o`0000[o
oooo0_l0001iooooo`007?ooool00ol0003oooooooooo`1jooooo`Wo00003?ooool2o`0000_ooooo
0_l00009ooooo`;o00003?ooool>o`0000Gooooo0_l00004ooooo`;o0000NOooool001cooooo0_l0
001kooooo`Wo00003?ooool2o`0000;ooooo0_l0000Booooo`?o00002_ooool@o`0000Cooooo0_l0
001oooooo`007?ooool00ol0003oooooooooo`1iooooo`[o00002?ooool4o`0000Cooooo0_l00005
ooooo`;o00003?ooool2o`0000[ooooo4?l00005ooooo`;o00000_ooool2o`0007[ooooo000Loooo
o`03o`000?oooooooooo07Oooooo3?l00008ooooo`Co00002oooool4o`0000Gooooo0ol0000>oooo
oa3o00001Oooool2o`000004ooooool0003o0000o`0007[ooooo000Looooo`03o`000?oooooooooo
07Gooooo3ol00002ooooo`;o00001Oooool2o`0000;ooooo0_l00005ooooo`Ko00001Oooool3o`00
00kooooo4?l00008ooooo`?o0000N_ooool001cooooo00?o0000ooooooooool0MOoooolCo`0000Go
oooo1_l00005ooooo`;o00001oooool2o`0000Cooooo0_l0000<ooooo`oo00000_ooool4o`0000Ko
oooo0_l0001gooooo`007?ooool00ol0003oooooooooo`1gooooo`oo00000_ooool3o`0000?ooooo
0ol00005ooooo`?o00001Oooool2o`000003ooooool0003o000000Cooooo0_l0000;ooooo`oo0000
0oooool4o`0000Kooooo0_l0001gooooo`007?ooool00ol0003oooooooooo`1fooooo`co000000?o
ooooo`000?l000000oooool3o`0000?ooooo0_l00006ooooo`Co00001?ooool2o`0000Gooooo0_l0
000=oooooa7o00000_ooool2o`0000Sooooo0_l0001fooooo`007?ooool00ol0003oooooooooo`1f
ooooo`co000000Coooooo`000?l0003ooooo0_l00007ooooo`;o00001oooool2o`0000;ooooo0_l0
00000ooooooo0000o`000002ooooo`Co00003_ooool@o`0000cooooo0ol0001eooooo`007?ooool0
0ol0003oooooooooo`1foooooa?o00000oooool2o`000003ooooool0003o000000_ooooo0_l00000
0ooooooo0000o`000002ooooo`Co00003_ooool?o`0000kooooo0_l0001eooooo`007?ooool00ol0
003oooooooooo`1foooooaCo00000_ooool2o`0000Cooooo0ol00007ooooo`?o00001?ooool2o`00
013ooooo3ol00002ooooo`;o00000_ooool4o`0000Cooooo0_l0001eooooo`007?ooool00ol0003o
ooooooooo`1fooooo`oo000000?oooooo`000?l000000_l000001?oooooo0000o`000?l00004oooo
o`?o00002?ooool2o`0000?ooooo0ol0000@ooooo`oo00000_ooool2o`0000;ooooo1?l00004oooo
o`Go0000L_ooool001cooooo00?o0000ooooooooool0MOooool?o`0000;ooooo2?l00004ooooo`;o
00002oooool2o`000004ooooool0003o0000o`00013ooooo3_l00007ooooo`;o00002?ooool3o`00
07;ooooo000Looooo`03o`000?oooooooooo07Gooooo3ol00002ooooo`Go00004_ooool4o`0000;o
oooo0_l0000@oooooa;o00000oooool2o`0000Sooooo0_l0001cooooo`007?ooool00ol0003ooooo
ooooo`1dooooo`co000000?oooooo`000?l000000ol000001?oooooo0000o`000?l0000?ooooo`Ko
00005_oooolBo`0000gooooo0_l0001cooooo`007?ooool00ol0003oooooooooo`1doooooa;o0000
00?oooooo`000?l000001Oooool2o`0000Wooooo1?l000000ooooooo0000o`000002o`0001?ooooo
4?l0000Aooooo`;o0000LOooool001cooooo00?o0000ooooooooool0MOooool?o`0000;ooooo1Ol0
0003ooooo`;o00003_ooool4o`0001?ooooo4?l0000Aooooo`;o0000LOooool001cooooo0_l0001f
ooooo`oo00000_ooool8o`000004ooooool0003o0000o`0000kooooo0_l0000Cooooo`oo00000ooo
ool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000Oooooo0ol0001]ooooo`007?ooool0
0ol0003oooooooooo`1eooooo`oo00000_ooool3o`0000;ooooo0ol000000ooooooo0000o`000003
o`000003ooooool0003o000000Oooooo1?l0000Eooooo`ko00000_ooool2o`000003ooooool0003o
000000Oo00001?ooool5o`0006gooooo000Looooo`03o`000?oooooooooo07Gooooo4?l000001?oo
oooo0000o`000?l00009ooooo`;o000000?oooooo`000?l000001oooool4o`0001Gooooo3_l00005
ooooo`;o000000?oooooo`000?l000000_ooool3o`0000?ooooo1_l0001/ooooo`007?ooool00ol0
003oooooooooo`1eoooooa3o000000?oooooo`000?l000001?l00004ooooo`?o00000_ooool2o`00
00Cooooo0_l000000ooooooo0000o`00000Gooooo`go00000oooool2o`0000Wooooo1Ol00004oooo
o`;o0000K?ooool001cooooo00?o0000ooooooooool0M?ooool@o`000004ooooool0003o0000oooo
o`Co00001?ooool3o`0000Sooooo0_l000000ooooooo0000o`00000Gooooo`go00000oooool3o`00
00Sooooo1Ol00004ooooo`;o0000K?ooool001cooooo00?o0000ooooooooool0M?ooool@o`000004
ooooool0003o0000ooooo`;o00001oooool2o`0000;ooooo1?l00005ooooo`;o00006?ooool7o`00
0004ooooool0003o0000o`0000Cooooo0ol00003ooooo`;o00000oooool2o`0000Sooooo0_l0001[
ooooo`007?ooool00ol0003oooooooooo`1eooooo`oo00001?ooool2o`0000Oooooo2?l00004oooo
o`?o00005oooool6o`000003ooooool0003o000000?o00000_ooool3o`0000Gooooo0_l00002oooo
o`;o00002Oooool2o`0006_ooooo000Looooo`03o`000?oooooooooo07Gooooo3Ol00005ooooo`;o
00002_ooool6o`0000Cooooo0_l0000Hooooo`Wo00000oooool5o`0000?ooooo0_l000001?oooooo
0000o`000?ooool2o`0007Kooooo000Looooo`03o`000?oooooooooo07Gooooo3Ol00005ooooo`;o
00001Oooool2o`0000Gooooo1?l00003ooooo`?o00006_ooool7o`0000?ooooo0ol00005ooooo`;o
000000?oooooo`000?l000001oooool2o`00073ooooo000Looooo`03o`000?oooooooooo07Gooooo
3_l000000ooooooo0000o`000004ooooo`;o000000Coooooo`000?l0003o00003?ooool3o`0001[o
oooo2?l00009ooooo`;o00000_ooool2o`0000Gooooo1_l0001^ooooo`007?ooool00ol0003ooooo
ooooo`1foooooa3o00001?ooool2o`000003ooooool0003o000000cooooo0ol0000Looooo`So0000
0_ooool2o`0000?ooooo0ol00002ooooo`;o00001Oooool2o`000004ooooool0003o0000o`0006ko
oooo000Looooo`03o`000?oooooooooo07Kooooo2_l000000ooooooo0000o`000002o`0000Gooooo
0_l00008ooooo`;o00001Oooool3o`0001cooooo2Ol000000ooooooo0000o`000003ooooo`?o0000
1?ooool5o`000003ooooool0003o000000;o0000Koooool001cooooo00?o0000ooooooooool0Mooo
ool>o`000003ooooool0003o000000;ooooo0_l00008ooooo`;o00009_ooool8o`0000Kooooo0_l0
0004ooooo`Go000000?oooooo`000?l00000LOooool001cooooo00?o0000ooooooooool0N?ooool<
o`0000;ooooo0_l00002ooooo`;o00001_ooool2o`0002Sooooo2?l00009ooooo`;o00001_ooool2
o`0007;ooooo000Looooo`03o`000?oooooooooo07Sooooo1_l00002ooooo`Co00001_ooool2o`00
00Kooooo0_l00005ooooo`?o00008?ooool9o`0000;ooooo0_l000001?oooooo0000o`000?ooool2
o`0000Kooooo0_l0001booooo`007?ooool00ol0003oooooooooo`1iooooo`;o000000?oooooo`00
0?l000000_l000000ooooooo0000o`000004o`0000_ooooo0_l00005ooooo`?o00008_ooool;o`00
0003ooooool0003o000007gooooo000Looooo`;o0000NOooool3o`000003ooooool0003o000000;o
00000oooool7o`0000gooooo1Ol0000Rooooo`co00003Oooool2o`00073ooooo000Looooo`03o`00
0?oooooooooo07Sooooo1ol00004ooooo`Oo00003Oooool4o`0002Kooooo2ol00005ooooo`;o0000
1?ooool2o`00073ooooo000Looooo`03o`000?oooooooooo07Wooooo1_l00004ooooo`;o000000?o
ooooo`000?l000001?ooool2o`0000Sooooo1?l0000Wooooo`ko00000_ooool4o`0007Cooooo000L
ooooo`03o`000?oooooooooo07[ooooo1_l00003ooooo`Go00001?ooool2o`0000Gooooo0_l00000
0ooooooo0000o`000002o`0002Wooooo2?l000001Ooooooo0000o`000?l0003ooooo00Go0000M?oo
ool001cooooo00?o0000ooooooooool0N_ooool8o`000003ooooool0003o000000Ko00001Oooool9
o`0002cooooo1ol000000ooooooo0000o`000004o`0007Kooooo000Looooo`03o`000?oooooooooo
07cooooo1_l00002ooooo`?o000000?oooooo`000?l000000_l000000ooooooo0000o`000009o`00
03;ooooo0_l000001?oooooo0000o`000?l0001iooooo`007?ooool00ol0003oooooooooo`1loooo
o`Go00002Oooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000000ol0002boooo
o`007?ooool00ol0003oooooooooo`1nooooo`?o000000?oooooo`000?l000002?ooool8o`000;Go
oooo000Looooo`03o`000?oooooooooo07oooooo1ol00003ooooo`Oo000000?oooooo`000?l00000
]_ooool001cooooo00?o0000ooooooooool0P?ooool3o`000005ooooool0003o0000o`000?ooool0
1Ol000000ooooooo0000o`00002iooooo`007?ooool00ol0003oooooooooo`25ooooo`So000000?o
ooooo`000?l00000^Oooool001cooooo00?o0000ooooooooool0QOooool4o`0000;ooooo0_l0002l
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q
8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?ooooooB_ooool00006oooooomgMgOoV9RH
oooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`00
0?oooooooooo0?ooooooB_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooom:ooooo`0000?o
ooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80
1_ooool3o`000?ooooooB_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Ooo
ool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom:ooooo`0000?o
oooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@4100
1_ooool00ol0003oooooooooo`3ooooood[ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_o
oooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0?ooooooB_ooool00006
ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooooooo
ool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
B_ooool001Cooooo00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o0000
ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03
o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`004_oo
ool00omEEEGoIVIVo`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo002Uooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05_ooool4o`000004
oa0@4?ooooooooooooooo`Co000000?o410@ooooooooool00_ooool2o`000003oa0@4?oooooooooo
08kooooo002Vooooo`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08oooooo002Vooooo`05
o`000?ooooooooooooooool000006oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo1Ol0002@ooooo`00Y_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l0000<oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01?m4A4CogMgMooooool0002A
ooooo`00Y_ooool01Ol0003oQhN7oooooonYZJWo000001_ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`02ooooo`04omgMgOmEEEGoooooo`00097ooooo002Uooooo`03oa0@4?l0003o
MgMg00;o000000?oV9RHooooooooool06Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00?ooooo00?oMgMgolc<c?l00000TOooool00<Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03ooooo`03onk^k_m4A4Co0000097ooooo0034ooooo`03oeEEEOmVIVKo000000Go
oooo00?oEEEEofIVI_l000001_ooool00omgMgOo0000ooooo`2@ooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(120) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.34472 .71174 Mdot
.37516 .64989 Mdot
.65606 .56192 Mdot
.43077 .43564 Mdot
.65168 .29484 Mdot
.66597 .55771 Mdot
.57951 .68196 Mdot
.56479 .71267 Mdot
.68951 .57599 Mdot
.47988 .39637 Mdot
.57165 .66128 Mdot
.34249 .36112 Mdot
.57619 .69382 Mdot
.384 .40549 Mdot
.35956 .30393 Mdot
.26741 .49651 Mdot
.35088 .66824 Mdot
.65526 .28469 Mdot
.27774 .48581 Mdot
.68213 .57765 Mdot
.62278 .23795 Mdot
.4022 .42143 Mdot
.347 .69255 Mdot
.38494 .40445 Mdot
.27379 .48772 Mdot
.3856 .64833 Mdot
.34966 .71371 Mdot
.26378 .48457 Mdot
.33618 .36318 Mdot
.59021 .65254 Mdot
.25452 .47731 Mdot
.44065 .28684 Mdot
.60849 .43523 Mdot
.34867 .57312 Mdot
.54217 .69973 Mdot
.56174 .65866 Mdot
.70004 .56829 Mdot
.57812 .65066 Mdot
.59184 .68126 Mdot
.54931 .68604 Mdot
.54985 .68338 Mdot
.38525 .65501 Mdot
.54779 .68095 Mdot
.62493 .76442 Mdot
.40681 .39725 Mdot
.30883 .5447 Mdot
.67631 .58346 Mdot
.34648 .38999 Mdot
.34077 .683 Mdot
.76193 .55413 Mdot
.49335 .34144 Mdot
.55406 .70649 Mdot
.61838 .41135 Mdot
.27449 .53573 Mdot
.57858 .69744 Mdot
.27617 .48428 Mdot
.67479 .54017 Mdot
.41317 .40816 Mdot
.32869 .35832 Mdot
.34469 .56444 Mdot
.42351 .42155 Mdot
.64249 .28341 Mdot
.39325 .70031 Mdot
.65579 .5407 Mdot
.65448 .57287 Mdot
.58568 .64605 Mdot
.37343 .63021 Mdot
.54792 .72986 Mdot
.42297 .4407 Mdot
.70822 .57899 Mdot
.35104 .38739 Mdot
.57161 .66097 Mdot
.38984 .629 Mdot
.39304 .42706 Mdot
.33714 .70268 Mdot
.54794 .73889 Mdot
.6546 .29053 Mdot
.3773 .60327 Mdot
.75948 .55457 Mdot
.31715 .44706 Mdot
.40477 .4279 Mdot
.43118 .7642 Mdot
.29716 .35522 Mdot
.39007 .67014 Mdot
.3703 .39422 Mdot
.38245 .77194 Mdot
.42712 .39411 Mdot
.25228 .48736 Mdot
.26856 .48461 Mdot
.31347 .34393 Mdot
.69781 .53424 Mdot
.35846 .69112 Mdot
.39621 .41395 Mdot
.42896 .44181 Mdot
.47992 .40333 Mdot
.35903 .40693 Mdot
.27195 .48289 Mdot
.63758 .41991 Mdot
.5511 .68905 Mdot
.60832 .39701 Mdot
.55322 .74505 Mdot
.62571 .4034 Mdot
.35894 .3828 Mdot
.69643 .55787 Mdot
.37183 .70564 Mdot
.62959 .42826 Mdot
.54339 .72235 Mdot
.39184 .41196 Mdot
.56634 .65346 Mdot
.35265 .69415 Mdot
.26471 .46878 Mdot
.62366 .29126 Mdot
.65219 .2424 Mdot
.38093 .62838 Mdot
.35944 .49641 Mdot
.43652 .41439 Mdot
.41497 .42534 Mdot
.37831 .65066 Mdot
.66223 .57782 Mdot
.6387 .61772 Mdot
.36294 .67609 Mdot
.55686 .67754 Mdot
.35049 .66578 Mdot
.6007 .43546 Mdot
.65884 .57622 Mdot
.59146 .40699 Mdot
.63833 .41108 Mdot
.4612 .30279 Mdot
.37616 .42848 Mdot
.61368 .44222 Mdot
.70328 .55781 Mdot
.36639 .6723 Mdot
.56799 .69926 Mdot
.43702 .44074 Mdot
.38997 .66495 Mdot
.58321 .69208 Mdot
.60536 .29078 Mdot
.60478 .28474 Mdot
.39001 .63594 Mdot
.37117 .50005 Mdot
.57725 .64832 Mdot
.57054 .71733 Mdot
.49125 .34224 Mdot
.39439 .65357 Mdot
.62628 .31876 Mdot
.57538 .70977 Mdot
.67416 .48116 Mdot
.27137 .46723 Mdot
.48129 .30665 Mdot
.44099 .75481 Mdot
.49277 .34254 Mdot
.61466 .24601 Mdot
.63932 .28698 Mdot
.58235 .69458 Mdot
.44817 .41478 Mdot
.36705 .64779 Mdot
.39135 .65414 Mdot
.34732 .37336 Mdot
.62305 .43224 Mdot
.42991 .40903 Mdot
.61523 .39354 Mdot
.6393 .41159 Mdot
.38879 .40647 Mdot
.32314 .55159 Mdot
.36758 .70016 Mdot
.40598 .38994 Mdot
.70745 .56858 Mdot
.65715 .27414 Mdot
.56471 .65816 Mdot
.3718 .39651 Mdot
.45766 .43448 Mdot
.36038 .37229 Mdot
.56696 .72097 Mdot
.57547 .77217 Mdot
.76948 .56079 Mdot
.57992 .66158 Mdot
.54675 .74681 Mdot
.69981 .5449 Mdot
.33455 .36896 Mdot
.62805 .29244 Mdot
.60839 .42008 Mdot
.4166 .39437 Mdot
.49566 .34216 Mdot
.31988 .34524 Mdot
.63005 .24203 Mdot
.61124 .2553 Mdot
.42117 .76028 Mdot
.56296 .76743 Mdot
.44009 .42722 Mdot
.2483 .46938 Mdot
.48944 .32571 Mdot
.58165 .63232 Mdot
.56495 .6971 Mdot
.65369 .58125 Mdot
.66351 .57936 Mdot
.77899 .55384 Mdot
.38699 .36935 Mdot
.35332 .36187 Mdot
.40959 .43406 Mdot
.61196 .40412 Mdot
.39489 .69486 Mdot
.6405 .2874 Mdot
.35983 .65452 Mdot
.43412 .76268 Mdot
.32422 .43712 Mdot
.28357 .47933 Mdot
.75367 .5402 Mdot
.66187 .53233 Mdot
.63124 .41547 Mdot
.63225 .30583 Mdot
.42358 .41133 Mdot
.35825 .70131 Mdot
.49062 .33359 Mdot
.59485 .42705 Mdot
.6309 .21618 Mdot
.35462 .67818 Mdot
.33018 .40755 Mdot
.58036 .69085 Mdot
.7105 .54156 Mdot
.42625 .39376 Mdot
.38383 .41532 Mdot
.379 .60694 Mdot
.44178 .43251 Mdot
.27635 .46088 Mdot
.26602 .47212 Mdot
.76937 .55646 Mdot
.55202 .74966 Mdot
.58271 .66462 Mdot
.67412 .58407 Mdot
.38585 .62796 Mdot
.30988 .55648 Mdot
.68449 .55145 Mdot
.62982 .2371 Mdot
.57474 .65647 Mdot
.60744 .30482 Mdot
.68569 .55577 Mdot
.65132 .29402 Mdot
.32571 .35397 Mdot
.71848 .55412 Mdot
.62087 .28433 Mdot
.38992 .32038 Mdot
.63338 .42038 Mdot
.61223 .34059 Mdot
.57963 .67886 Mdot
.35221 .64981 Mdot
.42005 .39533 Mdot
.61377 .41497 Mdot
.58576 .41153 Mdot
.32515 .36731 Mdot
.62376 .38889 Mdot
.60872 .43159 Mdot
.32916 .36916 Mdot
.65096 .27506 Mdot
.47551 .7021 Mdot
.2561 .47495 Mdot
.35272 .66365 Mdot
.43976 .43331 Mdot
.55471 .75481 Mdot
.58402 .69159 Mdot
.4255 .41603 Mdot
.41677 .76976 Mdot
.57865 .67646 Mdot
.40482 .41082 Mdot
.59316 .67235 Mdot
.38953 .66907 Mdot
.32335 .43399 Mdot
.3931 .63617 Mdot
.39056 .40525 Mdot
.59357 .67077 Mdot
.68147 .58215 Mdot
.38615 .64696 Mdot
.39692 .41671 Mdot
.41492 .43702 Mdot
.61317 .40658 Mdot
.26772 .47011 Mdot
.56537 .73243 Mdot
.34351 .36305 Mdot
.67071 .53456 Mdot
.34245 .37412 Mdot
.60826 .27241 Mdot
.70466 .48371 Mdot
.39462 .65214 Mdot
.62513 .38864 Mdot
.67391 .55285 Mdot
.48949 .37229 Mdot
.32893 .41865 Mdot
.4006 .39613 Mdot
.60353 .42844 Mdot
.29466 .35932 Mdot
.56797 .67577 Mdot
.27317 .46296 Mdot
.5873 .43446 Mdot
.67125 .54177 Mdot
.62125 .40132 Mdot
.36046 .40079 Mdot
.3492 .69645 Mdot
.27344 .49186 Mdot
.70231 .5425 Mdot
.34892 .68044 Mdot
.37175 .38558 Mdot
.55278 .74317 Mdot
.64588 .4291 Mdot
.56471 .67735 Mdot
.25833 .48567 Mdot
.33703 .37338 Mdot
.71258 .57732 Mdot
.38574 .65851 Mdot
.57237 .70635 Mdot
.39129 .63255 Mdot
.49023 .3645 Mdot
.32747 .40016 Mdot
.3972 .64088 Mdot
.61284 .27432 Mdot
.80345 .54544 Mdot
.56715 .66726 Mdot
.59821 .40366 Mdot
.74352 .57293 Mdot
.3399 .6911 Mdot
.68715 .55922 Mdot
.39895 .49636 Mdot
.6919 .53365 Mdot
.27823 .48915 Mdot
.72629 .57682 Mdot
.3684 .37142 Mdot
.38308 .39149 Mdot
.63805 .55584 Mdot
.63586 .42469 Mdot
.37017 .41269 Mdot
.38879 .66778 Mdot
.42875 .28388 Mdot
.47091 .41657 Mdot
.3866 .37007 Mdot
.67446 .54173 Mdot
.38221 .50202 Mdot
.26165 .47536 Mdot
.26134 .48688 Mdot
.3649 .65444 Mdot
.59872 .40774 Mdot
.6017 .31037 Mdot
.6001 .31926 Mdot
.74921 .47335 Mdot
.28387 .35141 Mdot
.35249 .49114 Mdot
.3887 .64365 Mdot
.78047 .54874 Mdot
.33646 .71352 Mdot
.59717 .42887 Mdot
.56421 .71292 Mdot
.58104 .77429 Mdot
.41852 .39036 Mdot
.61272 .44874 Mdot
.28458 .46221 Mdot
.34441 .6703 Mdot
.38669 .61928 Mdot
.57033 .70869 Mdot
.40368 .3757 Mdot
.47699 .39416 Mdot
.4323 .41611 Mdot
.5619 .71624 Mdot
.58731 .4164 Mdot
.32451 .35865 Mdot
.45864 .28943 Mdot
.63492 .76892 Mdot
.39711 .39806 Mdot
.35542 .57305 Mdot
.3942 .39126 Mdot
.46809 .30808 Mdot
.41652 .40582 Mdot
.38761 .66062 Mdot
.24247 .51187 Mdot
.4419 .44472 Mdot
.74771 .53705 Mdot
.32593 .43891 Mdot
.62205 .27405 Mdot
.38789 .41498 Mdot
.42727 .40356 Mdot
.61448 .32203 Mdot
.37399 .68226 Mdot
.39726 .44145 Mdot
.47631 .69968 Mdot
.40141 .41769 Mdot
.56351 .65892 Mdot
.30667 .35602 Mdot
.44147 .29008 Mdot
.26382 .47655 Mdot
.34777 .69532 Mdot
.58862 .68987 Mdot
.55632 .67122 Mdot
.60383 .38917 Mdot
.58432 .69138 Mdot
.3826 .39353 Mdot
.30616 .35478 Mdot
.3795 .62392 Mdot
.63137 .42225 Mdot
.3617 .68725 Mdot
.6627 .40971 Mdot
.57511 .68087 Mdot
.62453 .40862 Mdot
.404 .37051 Mdot
.56465 .68675 Mdot
.49398 .67481 Mdot
.26281 .4692 Mdot
.587 .41498 Mdot
.34515 .71022 Mdot
.71367 .57838 Mdot
.59984 .42852 Mdot
.57808 .69879 Mdot
.40695 .39693 Mdot
.27525 .47627 Mdot
.58211 .69671 Mdot
.36006 .57747 Mdot
.26118 .4673 Mdot
.40324 .41704 Mdot
.37833 .68705 Mdot
.37301 .66983 Mdot
.41891 .39328 Mdot
.44233 .41918 Mdot
.6638 .54964 Mdot
.59843 .42525 Mdot
.59579 .42155 Mdot
.63917 .40365 Mdot
.69215 .53522 Mdot
.80345 .54815 Mdot
.54263 .7296 Mdot
.43982 .29041 Mdot
.56535 .761 Mdot
.61855 .41592 Mdot
.66216 .55126 Mdot
.39771 .39316 Mdot
.35618 .3761 Mdot
.59469 .67197 Mdot
.81944 .53175 Mdot
.41351 .38814 Mdot
.36107 .64843 Mdot
.555 .71416 Mdot
.35095 .36242 Mdot
.77167 .55297 Mdot
.63776 .27548 Mdot
.35167 .4921 Mdot
.55637 .71274 Mdot
.36431 .58989 Mdot
.55653 .7121 Mdot
.42493 .40176 Mdot
.36493 .41036 Mdot
.36034 .639 Mdot
.62189 .27361 Mdot
.34426 .36661 Mdot
.40113 .40693 Mdot
.78282 .54766 Mdot
.33754 .71645 Mdot
.59924 .31727 Mdot
.33225 .35699 Mdot
.63481 .40845 Mdot
.64216 .27348 Mdot
.40258 .43068 Mdot
.34242 .37174 Mdot
.59028 .43356 Mdot
.59266 .66408 Mdot
.61373 .27617 Mdot
.7518 .53828 Mdot
.35276 .67469 Mdot
.547 .74261 Mdot
.60374 .38579 Mdot
.56604 .66777 Mdot
.43445 .34961 Mdot
.62838 .40957 Mdot
.60093 .78007 Mdot
.54193 .16085 Mdot
.61504 .42932 Mdot
.66481 .54085 Mdot
.47797 .40531 Mdot
.34302 .37052 Mdot
.4031 .41638 Mdot
.60081 .29927 Mdot
.37456 .65958 Mdot
.56364 .76711 Mdot
.58558 .66302 Mdot
.37866 .41008 Mdot
.39532 .65016 Mdot
.40758 .7681 Mdot
.61842 .40287 Mdot
.61537 .2982 Mdot
.6077 .29872 Mdot
.38531 .42452 Mdot
.29178 .36054 Mdot
.38776 .64886 Mdot
.39636 .41633 Mdot
.38732 .42778 Mdot
.7463 .56725 Mdot
.37583 .69501 Mdot
.71636 .55265 Mdot
.28356 .47544 Mdot
.3207 .45971 Mdot
.55902 .75385 Mdot
.58508 .67959 Mdot
.59405 .41097 Mdot
.58104 .66477 Mdot
.76413 .56318 Mdot
.59648 .42225 Mdot
.39624 .41686 Mdot
.37962 .62358 Mdot
.39588 .4155 Mdot
.40024 .41677 Mdot
.417 .40192 Mdot
.347 .48865 Mdot
.72842 .5399 Mdot
.62045 .30049 Mdot
.3288 .35547 Mdot
.69222 .53882 Mdot
.75346 .54523 Mdot
.48199 .39852 Mdot
.39494 .42231 Mdot
.41416 .4213 Mdot
.37544 .60525 Mdot
.27502 .46658 Mdot
.56592 .68873 Mdot
.35961 .63971 Mdot
.43578 .39842 Mdot
.68107 .58371 Mdot
.40043 .4427 Mdot
.39681 .64045 Mdot
.54038 .72439 Mdot
.34704 .74139 Mdot
.59659 .38887 Mdot
.59225 .40167 Mdot
.6058 .43037 Mdot
.63866 .40051 Mdot
.55664 .66657 Mdot
.66046 .55259 Mdot
.65055 .39413 Mdot
.32085 .45628 Mdot
.4434 .42083 Mdot
.36358 .40723 Mdot
.742 .57176 Mdot
.61516 .43853 Mdot
.46687 .42358 Mdot
.28192 .49244 Mdot
.7295 .55159 Mdot
.63834 .41812 Mdot
.37231 .7503 Mdot
.34983 .68878 Mdot
.76018 .557 Mdot
.57878 .65115 Mdot
.62082 .28142 Mdot
.80853 .44908 Mdot
.36443 .68182 Mdot
.38328 .71049 Mdot
.71205 .56176 Mdot
.31101 .35401 Mdot
.25583 .52978 Mdot
.68071 .56081 Mdot
.26827 .46192 Mdot
.37726 .63826 Mdot
.63599 .41735 Mdot
.29864 .36349 Mdot
.31827 .36541 Mdot
.71511 .57248 Mdot
.41322 .43814 Mdot
.62878 .56213 Mdot
.66786 .54139 Mdot
.59705 .41357 Mdot
.67492 .54191 Mdot
.57316 .67213 Mdot
.7018 .55315 Mdot
.36064 .57947 Mdot
.41078 .44202 Mdot
.27266 .53528 Mdot
.35428 .29821 Mdot
.43823 .41603 Mdot
.55695 .69306 Mdot
.54744 .74442 Mdot
.43023 .42622 Mdot
.64361 .30723 Mdot
.66248 .5438 Mdot
.77989 .55629 Mdot
.27803 .47516 Mdot
.729 .57552 Mdot
.34856 .69722 Mdot
.55071 .7466 Mdot
.54876 .74655 Mdot
.60156 .42898 Mdot
.39292 .65902 Mdot
.54132 .74028 Mdot
.55538 .67963 Mdot
.64134 .43513 Mdot
.42123 .395 Mdot
.36647 .69756 Mdot
.32402 .35873 Mdot
.65634 .27716 Mdot
.40265 .41912 Mdot
.71388 .55171 Mdot
.77142 .55777 Mdot
.35855 .3011 Mdot
.68192 .55021 Mdot
.59509 .40782 Mdot
.37153 .69569 Mdot
.27862 .48146 Mdot
.36827 .67273 Mdot
.43385 .43972 Mdot
.55333 .75191 Mdot
.34875 .68999 Mdot
.62868 .23786 Mdot
.42022 .4181 Mdot
.32082 .54953 Mdot
.32845 .35214 Mdot
.4043 .4182 Mdot
.6501 .57307 Mdot
.61788 .32149 Mdot
.64038 .26345 Mdot
.74308 .54205 Mdot
.64595 .29383 Mdot
.35018 .72453 Mdot
.65324 .57557 Mdot
.61973 .31296 Mdot
.75237 .4733 Mdot
.62804 .38928 Mdot
.62109 .30623 Mdot
.37121 .39422 Mdot
.5865 .6892 Mdot
.36789 .63329 Mdot
.3677 .40835 Mdot
.45823 .45552 Mdot
.22992 .49134 Mdot
.61599 .40599 Mdot
.40751 .41837 Mdot
.43017 .40489 Mdot
.39483 .64734 Mdot
.44188 .75651 Mdot
.66193 .53879 Mdot
.60353 .3991 Mdot
.36332 .67983 Mdot
.42982 .76509 Mdot
.65051 .57128 Mdot
.61043 .3133 Mdot
.58806 .66989 Mdot
.36477 .59716 Mdot
.61579 .4103 Mdot
.57973 .6803 Mdot
.73903 .54247 Mdot
.49347 .34912 Mdot
.25089 .49563 Mdot
.69184 .56573 Mdot
.49328 .34265 Mdot
.2857 .47095 Mdot
.77905 .55307 Mdot
.57984 .63264 Mdot
.35389 .69369 Mdot
.57593 .70594 Mdot
.61315 .29355 Mdot
.39013 .62713 Mdot
.3611 .68761 Mdot
.58522 .67852 Mdot
.23394 .51186 Mdot
.30044 .3673 Mdot
.54671 .73548 Mdot
.31116 .34969 Mdot
.49174 .34617 Mdot
.61275 .41068 Mdot
.62489 .2958 Mdot
.55228 .74955 Mdot
.38516 .65416 Mdot
.58004 .76471 Mdot
.49476 .34 Mdot
.2704 .46417 Mdot
.62385 .27974 Mdot
.41231 .76291 Mdot
.58521 .63837 Mdot
.56826 .68615 Mdot
.78309 .54784 Mdot
.63533 .31471 Mdot
.37866 .39211 Mdot
.82491 .52653 Mdot
.37351 .39763 Mdot
.55847 .72546 Mdot
.28383 .46205 Mdot
.35782 .6678 Mdot
.54744 .73183 Mdot
.28358 .48276 Mdot
.34059 .36175 Mdot
.43719 .4253 Mdot
.76648 .55751 Mdot
.36861 .62471 Mdot
.64686 .40466 Mdot
.43746 .41314 Mdot
.4049 .40762 Mdot
.58462 .41298 Mdot
.44456 .29224 Mdot
.55527 .62347 Mdot
.61816 .43487 Mdot
.72441 .55563 Mdot
.63122 .42327 Mdot
.6011 .40359 Mdot
.34619 .70521 Mdot
.78154 .55028 Mdot
.58732 .40599 Mdot
.39254 .40228 Mdot
.39346 .40979 Mdot
.59148 .68371 Mdot
.29586 .36093 Mdot
.31775 .36234 Mdot
.66864 .53498 Mdot
.63045 .44375 Mdot
.38149 .42971 Mdot
.39011 .66909 Mdot
.60018 .2923 Mdot
.60021 .39277 Mdot
.35212 .67102 Mdot
.36019 .41192 Mdot
.74512 .568 Mdot
.6209 .42705 Mdot
.58188 .40794 Mdot
.62369 .28332 Mdot
.5692 .72023 Mdot
.38408 .59829 Mdot
.66637 .54135 Mdot
.25081 .49196 Mdot
.64255 .45047 Mdot
.75031 .56223 Mdot
.61098 .41002 Mdot
.63053 .40602 Mdot
.39283 .65616 Mdot
.36518 .58213 Mdot
.57654 .40791 Mdot
.688 .53682 Mdot
.61946 .78319 Mdot
.54845 .70021 Mdot
.33712 .37269 Mdot
.58188 .66802 Mdot
.35338 .69457 Mdot
.4606 .30103 Mdot
.60819 .30408 Mdot
.5669 .68387 Mdot
.60801 .43244 Mdot
.35577 .68953 Mdot
.38313 .60193 Mdot
.38895 .40399 Mdot
.39991 .42174 Mdot
.67532 .58354 Mdot
.48392 .31497 Mdot
.59427 .67677 Mdot
.60267 .31106 Mdot
.65318 .5565 Mdot
.27657 .47717 Mdot
.36573 .64785 Mdot
.59611 .33677 Mdot
.32562 .34853 Mdot
.6873 .53913 Mdot
.3748 .64766 Mdot
.60199 .32131 Mdot
.61982 .30181 Mdot
.43477 .40291 Mdot
.61142 .24916 Mdot
.56997 .67857 Mdot
.3893 .6638 Mdot
.34766 .73 Mdot
.33382 .36457 Mdot
.39461 .42013 Mdot
.27735 .46399 Mdot
.53994 .73553 Mdot
.3721 .39469 Mdot
.61554 .27994 Mdot
.37603 .6331 Mdot
.39248 .39257 Mdot
.62565 .32274 Mdot
.64706 .40682 Mdot
.62921 .41532 Mdot
.63671 .56041 Mdot
.61073 .32985 Mdot
.62145 .32386 Mdot
.62845 .32169 Mdot
.58144 .77446 Mdot
.34969 .36254 Mdot
.65529 .43295 Mdot
.41152 .43764 Mdot
.49133 .34787 Mdot
.2466 .48889 Mdot
.55151 .6948 Mdot
.71553 .57602 Mdot
.42661 .40846 Mdot
.41229 .43681 Mdot
.35268 .64461 Mdot
.26797 .49716 Mdot
.40135 .38946 Mdot
.35842 .66041 Mdot
.36215 .72557 Mdot
.64458 .57818 Mdot
.43973 .75493 Mdot
.83384 .50822 Mdot
.32046 .34941 Mdot
.3049 .347 Mdot
.3695 .68571 Mdot
.59052 .67512 Mdot
.30882 .34747 Mdot
.56629 .72211 Mdot
.37713 .66381 Mdot
.25963 .50046 Mdot
.35974 .5776 Mdot
.64248 .28222 Mdot
.42334 .40114 Mdot
.58286 .67535 Mdot
.4274 .40521 Mdot
.58501 .67433 Mdot
.38195 .50487 Mdot
.29438 .35267 Mdot
.44487 .42284 Mdot
.35674 .40335 Mdot
.62066 .23899 Mdot
.39756 .42238 Mdot
.78595 .54641 Mdot
.36969 .65128 Mdot
.61645 .44488 Mdot
.24736 .49991 Mdot
.47155 .41692 Mdot
.41268 .42192 Mdot
.23222 .48071 Mdot
.41648 .4268 Mdot
.81869 .53636 Mdot
.32215 .34872 Mdot
.4085 .39145 Mdot
.56298 .7011 Mdot
.56606 .66472 Mdot
.37427 .61232 Mdot
.62945 .40621 Mdot
.41673 .76207 Mdot
.40314 .41049 Mdot
.64315 .55622 Mdot
.64924 .25635 Mdot
.61515 .32548 Mdot
.37125 .63622 Mdot
.53453 .16089 Mdot
.55101 .67559 Mdot
.71682 .56691 Mdot
.25439 .47584 Mdot
.72133 .55407 Mdot
.66051 .53774 Mdot
.34217 .72766 Mdot
.62373 .29673 Mdot
.40777 .44464 Mdot
.34844 .56723 Mdot
.36999 .72676 Mdot
.33442 .36569 Mdot
.64328 .57448 Mdot
.59001 .43321 Mdot
.26095 .38792 Mdot
.65307 .27999 Mdot
.63942 .30395 Mdot
.5822 .68848 Mdot
.64221 .55628 Mdot
.60362 .40003 Mdot
.6149 .31195 Mdot
.64985 .57992 Mdot
.619 .38667 Mdot
.79181 .55057 Mdot
.38846 .65084 Mdot
.3864 .50056 Mdot
.30472 .54426 Mdot
.56135 .6794 Mdot
.77222 .55084 Mdot
.38387 .62298 Mdot
.39663 .65051 Mdot
.60802 .40359 Mdot
.73312 .5565 Mdot
.39607 .67377 Mdot
.42534 .3985 Mdot
.63305 .41787 Mdot
.37456 .41065 Mdot
.65635 .28629 Mdot
.39952 .41137 Mdot
.68816 .58145 Mdot
.56009 .69695 Mdot
.66955 .54614 Mdot
.58265 .68476 Mdot
.43549 .28761 Mdot
.41483 .41305 Mdot
.39054 .41634 Mdot
.30762 .35639 Mdot
.35342 .70691 Mdot
.34931 .56984 Mdot
.68202 .53964 Mdot
.6709 .54431 Mdot
.24822 .4999 Mdot
.35266 .65938 Mdot
.58616 .39017 Mdot
.31092 .34852 Mdot
.41552 .42862 Mdot
.36928 .65343 Mdot
.24524 .48544 Mdot
.60806 .78459 Mdot
.30083 .35935 Mdot
.34848 .70373 Mdot
.8014 .55041 Mdot
.38895 .4304 Mdot
.60417 .39579 Mdot
.62921 .43953 Mdot
.2854 .34902 Mdot
.65622 .27999 Mdot
.35343 .67782 Mdot
.61225 .39506 Mdot
.36877 .64404 Mdot
.68862 .5329 Mdot
.53796 .70527 Mdot
.36235 .6601 Mdot
.41749 .4238 Mdot
.83362 .50713 Mdot
.58813 .68485 Mdot
.40909 .39553 Mdot
.5458 .72887 Mdot
.38394 .61481 Mdot
.36734 .66789 Mdot
.61834 .3866 Mdot
.26888 .46219 Mdot
.56812 .68074 Mdot
.44629 .41512 Mdot
.3562 .57603 Mdot
.27315 .49222 Mdot
.65628 .27434 Mdot
.37763 .4271 Mdot
.34624 .38645 Mdot
.79091 .5453 Mdot
.4911 .37266 Mdot
.55288 .7551 Mdot
.56579 .65545 Mdot
.57406 .77415 Mdot
.3525 .7112 Mdot
.6326 .26293 Mdot
.38377 .5999 Mdot
.59268 .41132 Mdot
.72584 .56134 Mdot
.41715 .40088 Mdot
.63911 .39863 Mdot
.54472 .73672 Mdot
.62651 .30416 Mdot
.31991 .34533 Mdot
.68071 .56766 Mdot
.62897 .39485 Mdot
.57253 .68275 Mdot
.38404 .65868 Mdot
.35527 .66809 Mdot
.79393 .55294 Mdot
.39587 .39231 Mdot
.39883 .41989 Mdot
.54116 .71213 Mdot
.60487 .25877 Mdot
.64627 .29545 Mdot
.63555 .42504 Mdot
.54137 .7165 Mdot
.29955 .35796 Mdot
.38036 .60607 Mdot
.42186 .39843 Mdot
.30366 .35366 Mdot
.57026 .76975 Mdot
.37538 .73944 Mdot
.64308 .29398 Mdot
.32125 .41163 Mdot
.35409 .67837 Mdot
.56819 .70085 Mdot
.74988 .4763 Mdot
.2817 .466 Mdot
.4277 .43375 Mdot
.32457 .42234 Mdot
.32817 .3702 Mdot
.25232 .48377 Mdot
.59951 .38752 Mdot
.33263 .39859 Mdot
.24627 .4984 Mdot
.2571 .49603 Mdot
.3682 .41705 Mdot
.37016 .42011 Mdot
.36832 .66014 Mdot
.38425 .37019 Mdot
.71065 .55522 Mdot
.2643 .46177 Mdot
.59052 .32272 Mdot
.25897 .47374 Mdot
.34942 .37419 Mdot
.37586 .74367 Mdot
.28631 .37004 Mdot
.37925 .63908 Mdot
.34018 .69319 Mdot
.56365 .67591 Mdot
.27548 .4906 Mdot
.68589 .53855 Mdot
.58146 .42347 Mdot
.72823 .57202 Mdot
.36983 .65788 Mdot
.64793 .57839 Mdot
.58576 .64661 Mdot
.69177 .56584 Mdot
.72702 .55146 Mdot
.55837 .69918 Mdot
.36299 .63386 Mdot
.32872 .3507 Mdot
.55782 .69846 Mdot
.58206 .4128 Mdot
.60991 .31119 Mdot
.3683 .72436 Mdot
.62944 .43019 Mdot
.3884 .383 Mdot
.62044 .77772 Mdot
.69879 .56809 Mdot
.32425 .43231 Mdot
.34185 .67568 Mdot
.60798 .33426 Mdot
.36202 .66395 Mdot
.57728 .40259 Mdot
.63938 .28302 Mdot
.36696 .39455 Mdot
.58693 .3111 Mdot
.57935 .63119 Mdot
.44403 .44192 Mdot
.36095 .7261 Mdot
.73221 .5704 Mdot
.56244 .68192 Mdot
.50035 .66684 Mdot
.60529 .39711 Mdot
.34517 .69409 Mdot
.36998 .58503 Mdot
.59411 .41757 Mdot
.56786 .69857 Mdot
.33282 .5539 Mdot
.43372 .40433 Mdot
.57472 .66848 Mdot
.38205 .43077 Mdot
.36653 .49864 Mdot
.60086 .28543 Mdot
.63947 .40547 Mdot
.26888 .49787 Mdot
.6565 .57285 Mdot
.25109 .50064 Mdot
.44945 .40429 Mdot
.46875 .3007 Mdot
.41629 .43374 Mdot
.32517 .42977 Mdot
.76419 .56395 Mdot
.38184 .63271 Mdot
.61754 .42278 Mdot
.61315 .40854 Mdot
.279 .48961 Mdot
.84406 .44964 Mdot
.62619 .30924 Mdot
.797 .54965 Mdot
.4123 .41246 Mdot
.40578 .4273 Mdot
.38107 .60162 Mdot
.39291 .50165 Mdot
.63717 .41676 Mdot
.42458 .43251 Mdot
.28243 .35548 Mdot
.56459 .70707 Mdot
.35875 .38429 Mdot
.38378 .42257 Mdot
.54691 .75021 Mdot
.5645 .70157 Mdot
.75558 .56148 Mdot
.62754 .38836 Mdot
.63583 .56054 Mdot
.65114 .28676 Mdot
.32846 .40853 Mdot
.45127 .29473 Mdot
.31037 .36899 Mdot
.64773 .28649 Mdot
.26339 .47365 Mdot
.41566 .38786 Mdot
.41582 .44098 Mdot
.63692 .30562 Mdot
.59167 .6561 Mdot
.36729 .65597 Mdot
.3744 .50071 Mdot
.6114 .40736 Mdot
.25484 .49406 Mdot
.65389 .29446 Mdot
.36967 .64425 Mdot
.32472 .55258 Mdot
.3737 .65895 Mdot
.57188 .68646 Mdot
.77475 .55199 Mdot
.63877 .28103 Mdot
.36157 .66382 Mdot
.66802 .5765 Mdot
.55544 .75157 Mdot
.36504 .37307 Mdot
.58889 .6464 Mdot
.34095 .7253 Mdot
.34388 .69932 Mdot
.34097 .71126 Mdot
.27969 .47437 Mdot
.3256 .43072 Mdot
.59366 .4082 Mdot
.54119 .71873 Mdot
.65957 .57168 Mdot
.48102 .3126 Mdot
.33968 .56345 Mdot
.34668 .41022 Mdot
.36058 .39896 Mdot
.39798 .41049 Mdot
.39286 .42855 Mdot
.5928 .39141 Mdot
.44511 .40336 Mdot
.40783 .43699 Mdot
.59501 .67338 Mdot
.75363 .56118 Mdot
.40985 .40971 Mdot
.62748 .41797 Mdot
.61527 .44958 Mdot
.60784 .33437 Mdot
.33649 .48324 Mdot
.39644 .68952 Mdot
.36485 .65286 Mdot
.69853 .54132 Mdot
.63904 .57013 Mdot
.60539 .28818 Mdot
.56485 .71356 Mdot
.3752 .66005 Mdot
.81612 .53609 Mdot
.63581 .2766 Mdot
.39653 .39921 Mdot
.30782 .35724 Mdot
.29118 .37146 Mdot
.34608 .3715 Mdot
.41805 .40307 Mdot
.61943 .43089 Mdot
.69245 .53739 Mdot
.36328 .36973 Mdot
.32379 .55067 Mdot
.63318 .31654 Mdot
.60871 .3158 Mdot
.36907 .70625 Mdot
.45037 .41784 Mdot
.58144 .67534 Mdot
.29299 .3573 Mdot
.56677 .73159 Mdot
.38737 .76845 Mdot
.66138 .41767 Mdot
.40221 .44342 Mdot
.47541 .41189 Mdot
.42125 .39131 Mdot
.37177 .70564 Mdot
.36228 .58834 Mdot
.38579 .63864 Mdot
.56544 .70888 Mdot
.49206 .35751 Mdot
.55255 .67813 Mdot
.63792 .41487 Mdot
.34933 .68654 Mdot
.315 .33986 Mdot
.67138 .54461 Mdot
.25977 .49824 Mdot
.63095 .28823 Mdot
.32677 .36416 Mdot
.61882 .41929 Mdot
.32323 .41035 Mdot
.66207 .55217 Mdot
.38018 .60921 Mdot
.25674 .4986 Mdot
.73627 .53925 Mdot
.33386 .39736 Mdot
.63643 .37142 Mdot
.64091 .40049 Mdot
.64229 .28298 Mdot
.48246 .39626 Mdot
.62472 .2763 Mdot
.5696 .68053 Mdot
.41813 .41449 Mdot
.41109 .39217 Mdot
.40843 .42123 Mdot
.36384 .39946 Mdot
.57364 .7037 Mdot
.2694 .49134 Mdot
.58766 .42578 Mdot
.63434 .39537 Mdot
.25576 .47666 Mdot
.62657 .2987 Mdot
.54913 .69745 Mdot
.74972 .5638 Mdot
.59645 .42738 Mdot
.62999 .26949 Mdot
.45093 .43824 Mdot
.42263 .4285 Mdot
.63473 .39964 Mdot
.36928 .39472 Mdot
.27073 .48703 Mdot
.70038 .56235 Mdot
.25737 .49121 Mdot
.61113 .3345 Mdot
.62975 .28502 Mdot
.58494 .69164 Mdot
.36119 .66262 Mdot
.60773 .28789 Mdot
.65516 .55826 Mdot
.40962 .38867 Mdot
.37523 .42476 Mdot
.36101 .5792 Mdot
.49555 .3411 Mdot
.61194 .33367 Mdot
.37613 .39251 Mdot
.37901 .69153 Mdot
.375 .58388 Mdot
.42554 .43435 Mdot
.2674 .48347 Mdot
.34464 .70508 Mdot
.6121 .31165 Mdot
.56501 .71582 Mdot
.37127 .29336 Mdot
.56523 .72191 Mdot
.38435 .66013 Mdot
.61135 .39661 Mdot
.35584 .6437 Mdot
.60798 .39546 Mdot
.3888 .74606 Mdot
.39473 .43546 Mdot
.35839 .57966 Mdot
.59913 .43605 Mdot
.67861 .53857 Mdot
.73543 .55228 Mdot
.61929 .4269 Mdot
.35155 .68054 Mdot
.59539 .41009 Mdot
.61608 .28587 Mdot
.57503 .76968 Mdot
.34035 .70021 Mdot
.72851 .55219 Mdot
.69447 .56854 Mdot
.54045 .71499 Mdot
.40542 .41543 Mdot
.42525 .40013 Mdot
.68548 .5654 Mdot
.56464 .73328 Mdot
.36207 .69234 Mdot
.39764 .41916 Mdot
.6101 .4348 Mdot
.70817 .5579 Mdot
.56692 .64472 Mdot
.38637 .613 Mdot
.26378 .50001 Mdot
.46552 .29856 Mdot
.56265 .65902 Mdot
.39173 .38485 Mdot
.27123 .48405 Mdot
.62672 .31488 Mdot
.32106 .41454 Mdot
.49085 .34312 Mdot
.5669 .65782 Mdot
.59239 .40261 Mdot
.347 .37117 Mdot
.70998 .53843 Mdot
.401 .38774 Mdot
.55953 .16845 Mdot
.63593 .40323 Mdot
.38148 .39857 Mdot
.63572 .43238 Mdot
.36744 .67325 Mdot
.40469 .42228 Mdot
.55823 .75357 Mdot
.69384 .5425 Mdot
.39658 .39254 Mdot
.62648 .23601 Mdot
.54752 .73069 Mdot
.61975 .41853 Mdot
.64548 .29498 Mdot
.25555 .47064 Mdot
.42918 .28439 Mdot
.74278 .57153 Mdot
.61763 .30392 Mdot
.40885 .4169 Mdot
.65316 .55441 Mdot
.56671 .66556 Mdot
.61723 .42451 Mdot
.44802 .43966 Mdot
.55278 .6862 Mdot
.55982 .70611 Mdot
.6292 .27894 Mdot
.30932 .55956 Mdot
.43255 .4433 Mdot
.382 .40597 Mdot
.32755 .56152 Mdot
.37762 .59368 Mdot
.42307 .40168 Mdot
.37259 .4129 Mdot
.58027 .67893 Mdot
.49582 .36094 Mdot
.32295 .41181 Mdot
.60158 .43782 Mdot
.55921 .68635 Mdot
.63787 .57436 Mdot
.71461 .5654 Mdot
.61202 .30177 Mdot
.37577 .64749 Mdot
.60859 .27791 Mdot
.70084 .54943 Mdot
.39217 .40059 Mdot
.55918 .72261 Mdot
.29792 .4519 Mdot
.54513 .73134 Mdot
.66022 .5612 Mdot
.3961 .64082 Mdot
.38133 .37569 Mdot
.55616 .16676 Mdot
.53597 .62896 Mdot
.78844 .55513 Mdot
.61528 .32497 Mdot
.32434 .55092 Mdot
.41353 .41652 Mdot
.37855 .3719 Mdot
.40105 .39405 Mdot
.61814 .26426 Mdot
.7255 .57505 Mdot
.61887 .38662 Mdot
.60462 .39737 Mdot
.32747 .41371 Mdot
.55961 .70815 Mdot
.55392 .67366 Mdot
.62328 .39828 Mdot
.56977 .68953 Mdot
.37894 .40518 Mdot
.6678 .55824 Mdot
.37985 .75115 Mdot
.41639 .42816 Mdot
.64381 .43286 Mdot
.58426 .6447 Mdot
.39809 .63878 Mdot
.6402 .57514 Mdot
.47353 .41496 Mdot
.42534 .75937 Mdot
.56436 .6856 Mdot
.33664 .48242 Mdot
.68878 .54071 Mdot
.59814 .42871 Mdot
.65419 .55075 Mdot
.38429 .3993 Mdot
.40094 .44314 Mdot
.58456 .41076 Mdot
.41425 .42725 Mdot
.35011 .58394 Mdot
.28072 .46395 Mdot
.28763 .48772 Mdot
.41246 .43804 Mdot
.35892 .72166 Mdot
.57636 .66004 Mdot
.6209 .3971 Mdot
.33043 .37067 Mdot
.36334 .41582 Mdot
.34995 .71186 Mdot
.55302 .68901 Mdot
.44967 .74774 Mdot
.56788 .70714 Mdot
.67715 .53779 Mdot
.5623 .71302 Mdot
.41852 .39046 Mdot
.376 .66942 Mdot
.69062 .55303 Mdot
.61875 .41402 Mdot
.69612 .5738 Mdot
.43752 .41428 Mdot
.57892 .63869 Mdot
.71802 .56576 Mdot
.27541 .46368 Mdot
.37487 .66869 Mdot
.58876 .28454 Mdot
.39489 .6969 Mdot
.38907 .40051 Mdot
.40563 .39565 Mdot
.63482 .42487 Mdot
.58172 .69579 Mdot
.3844 .60551 Mdot
.79082 .54909 Mdot
.60891 .33392 Mdot
.37951 .64122 Mdot
.59882 .29615 Mdot
.31158 .35433 Mdot
.3817 .62798 Mdot
.28283 .3547 Mdot
.58603 .68051 Mdot
.35347 .6729 Mdot
.65844 .25981 Mdot
.24917 .46856 Mdot
.62191 .29415 Mdot
.64228 .56994 Mdot
.30767 .34699 Mdot
.71821 .55843 Mdot
.55244 .7524 Mdot
.77067 .55688 Mdot
.56612 .6801 Mdot
.62616 .23737 Mdot
.2835 .46156 Mdot
.5738 .65385 Mdot
.56451 .75939 Mdot
.70976 .55033 Mdot
.62816 .40074 Mdot
.26285 .49077 Mdot
.58298 .40219 Mdot
.61855 .39207 Mdot
.55625 .66907 Mdot
.35354 .6687 Mdot
.35691 .65315 Mdot
.6196 .44459 Mdot
.35653 .66382 Mdot
.68849 .56029 Mdot
.30263 .35801 Mdot
.40586 .37098 Mdot
.57828 .65843 Mdot
.25366 .47261 Mdot
.35167 .38423 Mdot
.72039 .57815 Mdot
.67495 .55878 Mdot
.56265 .70871 Mdot
.35646 .74355 Mdot
.60636 .39321 Mdot
.38889 .61863 Mdot
.36155 .68341 Mdot
.36404 .67501 Mdot
.34355 .66565 Mdot
.49315 .35244 Mdot
.55664 .69329 Mdot
.35306 .68154 Mdot
.37167 .41707 Mdot
.382 .42356 Mdot
.5946 .42457 Mdot
.63064 .26274 Mdot
.26465 .48616 Mdot
.59465 .40637 Mdot
.43225 .42717 Mdot
.67518 .54208 Mdot
.64256 .25888 Mdot
.59288 .39828 Mdot
.68843 .53754 Mdot
.68696 .53631 Mdot
.59797 .39187 Mdot
.64221 .26116 Mdot
.35066 .5835 Mdot
.24726 .46609 Mdot
.3605 .72332 Mdot
.73634 .55775 Mdot
.55764 .7611 Mdot
.35866 .5783 Mdot
.39482 .39068 Mdot
.6308 .43223 Mdot
.6657 .55145 Mdot
.3391 .69747 Mdot
.3926 .42208 Mdot
.60621 .40443 Mdot
.61793 .29111 Mdot
.62193 .41339 Mdot
.62337 .43028 Mdot
.36373 .70393 Mdot
.6292 .76229 Mdot
.3951 .64939 Mdot
.73277 .54135 Mdot
.613 .41799 Mdot
.26887 .53432 Mdot
.73633 .56731 Mdot
.57679 .76995 Mdot
.27921 .46073 Mdot
.42275 .43785 Mdot
.70051 .54237 Mdot
.34877 .69773 Mdot
.59382 .655 Mdot
.28278 .36376 Mdot
.36059 .66471 Mdot
.60421 .38545 Mdot
.62234 .42815 Mdot
.71076 .55683 Mdot
.3818 .66924 Mdot
.27098 .48321 Mdot
.35832 .6739 Mdot
.54414 .70285 Mdot
.3725 .3918 Mdot
.41811 .76142 Mdot
.60369 .40076 Mdot
.36179 .65056 Mdot
.65798 .56993 Mdot
.61579 .27917 Mdot
.3767 .39469 Mdot
.42016 .76821 Mdot
.41166 .41985 Mdot
.54202 .70637 Mdot
.63278 .44899 Mdot
.24531 .47812 Mdot
.41331 .40376 Mdot
.35416 .37358 Mdot
.55133 .73905 Mdot
.41901 .40733 Mdot
.3407 .37511 Mdot
.31548 .54784 Mdot
.38985 .63365 Mdot
.40922 .41052 Mdot
.68456 .56397 Mdot
.62527 .60641 Mdot
.3781 .4138 Mdot
.73429 .5373 Mdot
.29078 .36123 Mdot
.5797 .41838 Mdot
.65578 .26789 Mdot
.46182 .30165 Mdot
.39227 .39622 Mdot
.4439 .42412 Mdot
.36983 .39215 Mdot
.42838 .37468 Mdot
.6977 .54609 Mdot
.63841 .55661 Mdot
.61181 .28997 Mdot
.32313 .4248 Mdot
.62789 .28322 Mdot
.56754 .66529 Mdot
.28466 .47811 Mdot
.63737 .39558 Mdot
.36162 .65747 Mdot
.40922 .42315 Mdot
.64505 .56593 Mdot
.385 .3977 Mdot
.27281 .47206 Mdot
.69728 .55973 Mdot
.66698 .5481 Mdot
.65117 .53658 Mdot
.61681 .32705 Mdot
.37246 .64314 Mdot
.43996 .40338 Mdot
.63957 .31019 Mdot
.58377 .4068 Mdot
.35321 .29493 Mdot
.37828 .63862 Mdot
.36697 .64358 Mdot
.35598 .64587 Mdot
.44589 .40884 Mdot
.44416 .40569 Mdot
.5469 .69047 Mdot
.3617 .57685 Mdot
.55811 .72601 Mdot
.70801 .54552 Mdot
.70265 .53463 Mdot
.38767 .3967 Mdot
.59485 .29574 Mdot
.62616 .2973 Mdot
.69517 .57235 Mdot
.64069 .41086 Mdot
.61546 .27604 Mdot
.44363 .41278 Mdot
.71672 .55394 Mdot
.6364 .31527 Mdot
.35458 .74447 Mdot
.46103 .72565 Mdot
.61639 .27731 Mdot
.60204 .39904 Mdot
.34134 .56171 Mdot
.47522 .3094 Mdot
.60083 .28673 Mdot
.57469 .6603 Mdot
.32527 .34828 Mdot
.64046 .40746 Mdot
.62511 .26969 Mdot
.49052 .31883 Mdot
.69983 .5536 Mdot
.60066 .39888 Mdot
.65075 .24077 Mdot
.40129 .36939 Mdot
.62262 .27281 Mdot
.36479 .64581 Mdot
.39955 .62753 Mdot
.40613 .39925 Mdot
.26463 .46428 Mdot
.58731 .66171 Mdot
.64348 .57182 Mdot
.63973 .56283 Mdot
.36564 .59019 Mdot
.30613 .36501 Mdot
.7004 .56427 Mdot
.33596 .37225 Mdot
.63538 .26867 Mdot
.37235 .41808 Mdot
.61205 .44549 Mdot
.24552 .4733 Mdot
.65963 .2755 Mdot
.61616 .27815 Mdot
.58219 .65685 Mdot
.56076 .69675 Mdot
.58076 .69605 Mdot
.70544 .56233 Mdot
.31722 .3586 Mdot
.64058 .55541 Mdot
.30704 .55462 Mdot
.62358 .30969 Mdot
.80512 .54804 Mdot
.42443 .39184 Mdot
.43403 .4275 Mdot
.24785 .49286 Mdot
.6195 .43393 Mdot
.38708 .39977 Mdot
.55222 .68517 Mdot
.66966 .57642 Mdot
.57774 .63721 Mdot
.37567 .69002 Mdot
.30906 .55363 Mdot
.67179 .54645 Mdot
.64564 .42777 Mdot
.63027 .2914 Mdot
.45305 .28562 Mdot
.61452 .2644 Mdot
.66571 .54062 Mdot
.43105 .44012 Mdot
.34093 .70488 Mdot
.81682 .53307 Mdot
.40484 .42081 Mdot
.69844 .56877 Mdot
.67208 .58321 Mdot
.25165 .46862 Mdot
.48815 .38305 Mdot
.58172 .63362 Mdot
.31515 .36701 Mdot
.61859 .32822 Mdot
.58417 .41441 Mdot
.2864 .34112 Mdot
.70241 .54924 Mdot
.69277 .57567 Mdot
.60071 .29256 Mdot
.39773 .63894 Mdot
.34518 .67256 Mdot
.35279 .58512 Mdot
.55019 .68661 Mdot
.40882 .44068 Mdot
.71458 .55427 Mdot
.3943 .63238 Mdot
.34125 .38761 Mdot
.57949 .68674 Mdot
.71116 .56965 Mdot
.41384 .42712 Mdot
.40797 .40234 Mdot
.62543 .28416 Mdot
.61674 .44993 Mdot
.59526 .43092 Mdot
.57514 .76752 Mdot
.34463 .4 Mdot
.28344 .48249 Mdot
.42732 .43407 Mdot
.36009 .69586 Mdot
.59402 .41465 Mdot
.62346 .29754 Mdot
.38932 .38663 Mdot
.37738 .37356 Mdot
.34441 .69757 Mdot
.58518 .6782 Mdot
.61204 .41323 Mdot
.33245 .41157 Mdot
.4142 .42457 Mdot
.3963 .39427 Mdot
.27962 .4743 Mdot
.44144 .39894 Mdot
.71629 .57607 Mdot
.39152 .66723 Mdot
.6431 .30431 Mdot
.36984 .66546 Mdot
.78521 .54985 Mdot
.28147 .46322 Mdot
.32716 .35662 Mdot
.35877 .71021 Mdot
.37783 .65965 Mdot
.54244 .70779 Mdot
.55924 .69052 Mdot
.64766 .38696 Mdot
.36932 .40493 Mdot
.63757 .40793 Mdot
.35638 .68126 Mdot
.64243 .57042 Mdot
.62822 .28208 Mdot
.79165 .55449 Mdot
.4171 .4343 Mdot
.70838 .55139 Mdot
.61187 .42483 Mdot
.36993 .698 Mdot
.68054 .54228 Mdot
.59904 .4293 Mdot
.61171 .31436 Mdot
.33838 .35902 Mdot
.64774 .38879 Mdot
.61281 .3984 Mdot
.36769 .40521 Mdot
.28029 .50012 Mdot
.25994 .46714 Mdot
.60026 .43763 Mdot
.64801 .5801 Mdot
.61172 .40182 Mdot
.39134 .61127 Mdot
.25643 .46609 Mdot
.65608 .57359 Mdot
.3598 .57717 Mdot
.27884 .46108 Mdot
.60986 .39536 Mdot
.3769 .63519 Mdot
.77988 .54808 Mdot
.34403 .72074 Mdot
.48093 .3204 Mdot
.38565 .42089 Mdot
.71823 .55881 Mdot
.62094 .29296 Mdot
.54415 .69218 Mdot
.56335 .65518 Mdot
.56174 .75609 Mdot
.72165 .54554 Mdot
.4099 .42493 Mdot
.35397 .67551 Mdot
.56514 .68646 Mdot
.38156 .60093 Mdot
.6524 .56012 Mdot
.67151 .56183 Mdot
.24858 .49251 Mdot
.62952 .28296 Mdot
.43023 .39406 Mdot
.64218 .56923 Mdot
.76756 .55622 Mdot
.31745 .54636 Mdot
.63498 .31715 Mdot
.28055 .48037 Mdot
.59888 .43953 Mdot
.35675 .38522 Mdot
.3264 .55495 Mdot
.6283 .42451 Mdot
.37494 .69027 Mdot
.42892 .4104 Mdot
.65784 .73833 Mdot
.73832 .5664 Mdot
.31597 .36787 Mdot
.57896 .63146 Mdot
.55592 .70249 Mdot
.68857 .54426 Mdot
.39844 .42562 Mdot
.79219 .55504 Mdot
.61121 .30111 Mdot
.24321 .49742 Mdot
.61881 .39533 Mdot
.3709 .5882 Mdot
.55954 .71968 Mdot
.63493 .24265 Mdot
.54461 .69126 Mdot
.5848 .69041 Mdot
.36701 .73691 Mdot
.40388 .39879 Mdot
.67508 .55017 Mdot
.6741 .56565 Mdot
.61518 .44514 Mdot
.77779 .56321 Mdot
.34539 .66713 Mdot
.65582 .73427 Mdot
.36237 .36714 Mdot
.41921 .4183 Mdot
.60069 .38679 Mdot
.6367 .41142 Mdot
.77901 .55275 Mdot
.42062 .40701 Mdot
.38703 .63403 Mdot
.637 .56445 Mdot
.71394 .56419 Mdot
.2725 .46393 Mdot
.56022 .69631 Mdot
.61472 .26345 Mdot
.68161 .55941 Mdot
.36732 .29453 Mdot
.38375 .39653 Mdot
.59596 .65249 Mdot
.68489 .55887 Mdot
.84213 .48279 Mdot
.62067 .78324 Mdot
.39476 .64404 Mdot
.34856 .36518 Mdot
.38454 .61275 Mdot
.62029 .2754 Mdot
.64966 .54859 Mdot
.56378 .66221 Mdot
.6159 .41702 Mdot
.6283 .61993 Mdot
.71339 .56117 Mdot
.36917 .65764 Mdot
.40473 .39727 Mdot
.32964 .47834 Mdot
.41662 .42563 Mdot
.49575 .36199 Mdot
.61422 .33274 Mdot
.56347 .65486 Mdot
.54107 .71381 Mdot
.34903 .36526 Mdot
.63276 .31815 Mdot
.66922 .5368 Mdot
.69991 .55881 Mdot
.42807 .76394 Mdot
.62273 .43015 Mdot
.66022 .5387 Mdot
.36777 .40381 Mdot
.65426 .53499 Mdot
.33969 .56432 Mdot
.55804 .70286 Mdot
.35886 .40589 Mdot
.72194 .55747 Mdot
.36142 .71615 Mdot
.31147 .35984 Mdot
.37796 .40988 Mdot
.63316 .43534 Mdot
.56232 .68672 Mdot
.30481 .55083 Mdot
.71468 .57911 Mdot
.39271 .43363 Mdot
.55998 .67601 Mdot
.61432 .24667 Mdot
.63221 .63467 Mdot
.37392 .6416 Mdot
.69118 .56888 Mdot
.56276 .71671 Mdot
.60627 .41998 Mdot
.64636 .30016 Mdot
.65937 .54562 Mdot
.7243 .56184 Mdot
.26538 .47307 Mdot
.64102 .4339 Mdot
.5998 .2897 Mdot
.36243 .69033 Mdot
.58103 .67779 Mdot
.27336 .46904 Mdot
.37772 .29105 Mdot
.44144 .40311 Mdot
.58626 .68958 Mdot
.28056 .53709 Mdot
.42392 .44231 Mdot
.41542 .43631 Mdot
.3287 .47553 Mdot
.39194 .61427 Mdot
.3502 .69377 Mdot
.34102 .4039 Mdot
.26574 .48268 Mdot
.32228 .35605 Mdot
.36626 .65315 Mdot
.37197 .65662 Mdot
.32688 .36246 Mdot
.26792 .47224 Mdot
.35364 .57331 Mdot
.56605 .69015 Mdot
.55616 .70093 Mdot
.36576 .67391 Mdot
.24675 .49184 Mdot
.59044 .67424 Mdot
.37709 .59901 Mdot
.66236 .56041 Mdot
.29376 .36363 Mdot
.37328 .66589 Mdot
.30209 .34816 Mdot
.57027 .68021 Mdot
.39051 .28218 Mdot
.2905 .36193 Mdot
.44568 .42412 Mdot
.41078 .40137 Mdot
.62055 .32237 Mdot
.62113 .41632 Mdot
.59781 .39189 Mdot
.5797 .69819 Mdot
.44379 .4023 Mdot
.38602 .63984 Mdot
.44369 .40342 Mdot
.48181 .3124 Mdot
.39936 .27867 Mdot
.34825 .35815 Mdot
.37482 .64955 Mdot
.38549 .65102 Mdot
.71812 .5396 Mdot
.65655 .57764 Mdot
.33587 .37376 Mdot
.56088 .68989 Mdot
.35722 .65638 Mdot
.55767 .72527 Mdot
.70234 .55022 Mdot
.67185 .54958 Mdot
.59165 .41567 Mdot
.5996 .39937 Mdot
.69006 .54822 Mdot
.73806 .53908 Mdot
.37253 .29154 Mdot
.36265 .57975 Mdot
.29311 .54046 Mdot
.44086 .28809 Mdot
.36872 .49942 Mdot
.61876 .29325 Mdot
.64356 .25875 Mdot
.55677 .67879 Mdot
.35773 .37275 Mdot
.43348 .41721 Mdot
.61914 .40296 Mdot
.56559 .67352 Mdot
.63367 .30019 Mdot
.55696 .70303 Mdot
.64675 .29725 Mdot
.65583 .57254 Mdot
.40751 .42738 Mdot
.43961 .42957 Mdot
.54293 .70856 Mdot
.69068 .53189 Mdot
.71918 .55376 Mdot
.61896 .29731 Mdot
.44818 .29155 Mdot
.70975 .55519 Mdot
.37423 .66455 Mdot
.36554 .75816 Mdot
.62799 .4231 Mdot
.39446 .42288 Mdot
.45959 .29887 Mdot
.25898 .46456 Mdot
.58413 .4056 Mdot
.6117 .41254 Mdot
.31105 .56097 Mdot
.42539 .39832 Mdot
.446 .75346 Mdot
.59135 .40252 Mdot
.35753 .64164 Mdot
.67874 .54937 Mdot
.58944 .39983 Mdot
.58963 .43467 Mdot
.65772 .29491 Mdot
.59304 .39314 Mdot
.34626 .6817 Mdot
.3827 .61177 Mdot
.25899 .48946 Mdot
.23609 .51839 Mdot
.64486 .28819 Mdot
.62704 .30228 Mdot
.72586 .57156 Mdot
.55653 .74971 Mdot
.32051 .45496 Mdot
.62029 .30778 Mdot
.34796 .73408 Mdot
.25318 .49576 Mdot
.25199 .48144 Mdot
.25521 .48067 Mdot
.38221 .60386 Mdot
.4238 .44741 Mdot
.72691 .57331 Mdot
.36875 .65616 Mdot
.25672 .49144 Mdot
.45211 .41237 Mdot
.38268 .63705 Mdot
.58352 .68218 Mdot
.26097 .50389 Mdot
.3555 .67123 Mdot
.28088 .35926 Mdot
.5741 .67606 Mdot
.3677 .37372 Mdot
.7604 .52662 Mdot
.84459 .46944 Mdot
.56127 .70464 Mdot
.70866 .56994 Mdot
.71213 .55125 Mdot
.70038 .56148 Mdot
.35249 .69254 Mdot
.73873 .55119 Mdot
.38233 .67184 Mdot
.78739 .5555 Mdot
.32802 .42084 Mdot
.63926 .28208 Mdot
.76489 .5583 Mdot
.36448 .67395 Mdot
.32074 .55724 Mdot
.54099 .16043 Mdot
.389 .4317 Mdot
.56992 .65609 Mdot
.60711 .29782 Mdot
.30406 .35686 Mdot
.62669 .31523 Mdot
.69011 .5406 Mdot
.32901 .41142 Mdot
.38591 .3963 Mdot
.45746 .73291 Mdot
.6228 .29132 Mdot
.3725 .6576 Mdot
.26219 .47346 Mdot
.63473 .57606 Mdot
.61255 .30114 Mdot
.63006 .28604 Mdot
.38361 .40617 Mdot
.38101 .6082 Mdot
.70169 .54167 Mdot
.56717 .67444 Mdot
.76428 .55269 Mdot
.37216 .31385 Mdot
.42082 .39608 Mdot
.39946 .43828 Mdot
.30902 .35293 Mdot
.78548 .5527 Mdot
.56598 .69448 Mdot
.49367 .33231 Mdot
.70881 .58115 Mdot
.47518 .3055 Mdot
.36997 .70843 Mdot
.76787 .55977 Mdot
.63045 .42075 Mdot
.59373 .42407 Mdot
.39601 .41705 Mdot
.54963 .16304 Mdot
.48795 .37777 Mdot
.58921 .66978 Mdot
.62873 .40956 Mdot
.74407 .55315 Mdot
.34043 .68429 Mdot
.65641 .24259 Mdot
.26685 .48625 Mdot
.57053 .67227 Mdot
.70492 .55675 Mdot
.58179 .17908 Mdot
.61222 .3245 Mdot
.3192 .37341 Mdot
.38248 .42478 Mdot
.39304 .41689 Mdot
.57821 .69473 Mdot
.59086 .65981 Mdot
.3031 .54429 Mdot
.58002 .42951 Mdot
.40964 .76695 Mdot
.54647 .73733 Mdot
.59376 .1851 Mdot
.63609 .40773 Mdot
.38879 .65679 Mdot
.60722 .38622 Mdot
.58873 .65876 Mdot
.42756 .40674 Mdot
.38206 .60992 Mdot
.61204 .42639 Mdot
.3888 .70386 Mdot
.25386 .47394 Mdot
.36517 .2944 Mdot
.39731 .4095 Mdot
.35666 .64877 Mdot
.36859 .6514 Mdot
.38184 .61959 Mdot
.6119 .4294 Mdot
.42401 .43283 Mdot
.40277 .43563 Mdot
.40529 .43913 Mdot
.3042 .54204 Mdot
.40652 .42496 Mdot
.33843 .70506 Mdot
.30771 .36926 Mdot
.66157 .74621 Mdot
.43927 .42907 Mdot
.5683 .71239 Mdot
.39528 .41312 Mdot
.60343 .32731 Mdot
.34331 .36612 Mdot
.26847 .46113 Mdot
.57038 .69264 Mdot
.44924 .40421 Mdot
.59059 .32277 Mdot
.44193 .40851 Mdot
.64804 .28967 Mdot
.58466 .77924 Mdot
.49125 .33607 Mdot
.33335 .55424 Mdot
.36033 .67403 Mdot
.64794 .559 Mdot
.59509 .67177 Mdot
.67637 .53841 Mdot
.24373 .46968 Mdot
.62792 .39021 Mdot
.80391 .54843 Mdot
.3823 .28867 Mdot
.42803 .40823 Mdot
.63501 .42359 Mdot
.38423 .63112 Mdot
.73615 .56866 Mdot
.38973 .50221 Mdot
.249 .49401 Mdot
.60515 .28675 Mdot
.61939 .31626 Mdot
.64146 .45101 Mdot
.39124 .62308 Mdot
.33898 .56877 Mdot
.57774 .69376 Mdot
.70793 .56287 Mdot
.65271 .2974 Mdot
.34061 .7322 Mdot
.59279 .65644 Mdot
.77467 .55267 Mdot
.55828 .71882 Mdot
.43336 .43159 Mdot
.59476 .39367 Mdot
.35747 .57046 Mdot
.62421 .40167 Mdot
.41106 .38925 Mdot
.72404 .55908 Mdot
.6263 .42718 Mdot
.63393 .31436 Mdot
.57032 .71266 Mdot
.67278 .54391 Mdot
.39974 .39577 Mdot
.36719 .64876 Mdot
.25765 .37974 Mdot
.74398 .57413 Mdot
.27387 .46174 Mdot
.27548 .46165 Mdot
.36783 .57888 Mdot
.58317 .42523 Mdot
.6433 .65039 Mdot
.25641 .46403 Mdot
.55697 .75633 Mdot
.59819 .28477 Mdot
.80177 .55193 Mdot
.64172 .55795 Mdot
.69296 .55416 Mdot
.43244 .4054 Mdot
.6349 .56389 Mdot
.33305 .36681 Mdot
.63654 .57633 Mdot
.57028 .77275 Mdot
.44418 .44194 Mdot
.69454 .55906 Mdot
.5935 .40039 Mdot
.37138 .39919 Mdot
.3904 .63855 Mdot
.64598 .54645 Mdot
.44593 .4238 Mdot
.74627 .53701 Mdot
.54249 .70683 Mdot
.60849 .42999 Mdot
.3103 .34388 Mdot
.56943 .68558 Mdot
.34683 .68613 Mdot
.32736 .34696 Mdot
.61402 .30685 Mdot
.38564 .65769 Mdot
.65216 .41388 Mdot
.63162 .28347 Mdot
.299 .35321 Mdot
.37156 .67703 Mdot
.63113 .41621 Mdot
.6146 .31507 Mdot
.65456 .26946 Mdot
.69623 .55437 Mdot
.67793 .58319 Mdot
.60852 .39984 Mdot
.39308 .39366 Mdot
.75567 .56642 Mdot
.56078 .71037 Mdot
.37841 .41704 Mdot
.71656 .55783 Mdot
.62656 .41869 Mdot
.40363 .43379 Mdot
.26516 .48372 Mdot
.3217 .55034 Mdot
.57656 .41294 Mdot
.64404 .2936 Mdot
.38619 .62245 Mdot
.39285 .43433 Mdot
.64276 .28096 Mdot
.7544 .55729 Mdot
.36337 .40803 Mdot
.37108 .6351 Mdot
.35036 .73857 Mdot
.64186 .5717 Mdot
.58414 .67502 Mdot
.67215 .56669 Mdot
.65108 .2885 Mdot
.53789 .15927 Mdot
.59216 .40747 Mdot
.24094 .48471 Mdot
.33844 .3659 Mdot
.64561 .55717 Mdot
.37254 .64507 Mdot
.39175 .77146 Mdot
.34251 .36447 Mdot
.3643 .40832 Mdot
.39028 .41861 Mdot
.77803 .55579 Mdot
.34165 .68204 Mdot
.39229 .42104 Mdot
.6385 .26199 Mdot
.37848 .42866 Mdot
.61493 .28464 Mdot
.77294 .53758 Mdot
.59306 .42533 Mdot
.2609 .53235 Mdot
.61028 .4274 Mdot
.68649 .56144 Mdot
.28007 .35696 Mdot
.3183 .35608 Mdot
.66257 .40976 Mdot
.34542 .68502 Mdot
.36259 .72201 Mdot
.67278 .55159 Mdot
.78425 .54896 Mdot
.26776 .48841 Mdot
.26235 .47598 Mdot
.37504 .39781 Mdot
.68967 .54066 Mdot
.68523 .57744 Mdot
.62251 .38925 Mdot
.63507 .4221 Mdot
.36966 .37471 Mdot
.6526 .56976 Mdot
.4067 .42682 Mdot
.24675 .47981 Mdot
.59369 .65846 Mdot
.39109 .63188 Mdot
.57877 .65101 Mdot
.59275 .65119 Mdot
.37858 .5002 Mdot
.34793 .40523 Mdot
.55197 .68293 Mdot
.57853 .66232 Mdot
.76917 .55294 Mdot
.39839 .37199 Mdot
.62033 .2766 Mdot
.49111 .37933 Mdot
.67367 .53772 Mdot
.42565 .42882 Mdot
.34259 .67067 Mdot
.57785 .40275 Mdot
.37651 .76885 Mdot
.5433 .27543 Mdot
.27369 .49019 Mdot
.73639 .57202 Mdot
.61289 .39778 Mdot
.62395 .39918 Mdot
.47559 .30909 Mdot
.40455 .42561 Mdot
.64121 .5709 Mdot
.40119 .36971 Mdot
.54692 .73783 Mdot
.77333 .55114 Mdot
.3915 .62104 Mdot
.39918 .41563 Mdot
.36764 .69085 Mdot
.58823 .69008 Mdot
.63189 .27578 Mdot
.61652 .32603 Mdot
.44158 .41031 Mdot
.27931 .46032 Mdot
.55639 .75709 Mdot
.2613 .48275 Mdot
.27145 .47323 Mdot
.61048 .40392 Mdot
.28115 .47827 Mdot
.38736 .43159 Mdot
.44697 .43672 Mdot
.58346 .40727 Mdot
.59153 .64889 Mdot
.46731 .42298 Mdot
.61118 .39535 Mdot
.33816 .35616 Mdot
.58662 .69458 Mdot
.2626 .48537 Mdot
.56805 .70775 Mdot
.7783 .55119 Mdot
.54621 .6963 Mdot
.6417 .3058 Mdot
.76847 .55533 Mdot
.29689 .54133 Mdot
.35428 .67399 Mdot
.5568 .69487 Mdot
.61044 .31312 Mdot
.56557 .71082 Mdot
.66572 .54295 Mdot
.54514 .74016 Mdot
.38241 .59175 Mdot
.3615 .29612 Mdot
.3672 .49699 Mdot
.55877 .73199 Mdot
.65814 .57667 Mdot
.36469 .67509 Mdot
.55849 .75209 Mdot
.33173 .35364 Mdot
.60989 .32566 Mdot
.39351 .41543 Mdot
.57729 .70441 Mdot
.75485 .56271 Mdot
.33362 .55861 Mdot
.64282 .30191 Mdot
.30203 .55138 Mdot
.64722 .56635 Mdot
.39544 .44021 Mdot
.53792 .70555 Mdot
.63867 .65089 Mdot
.54201 .71286 Mdot
.31988 .41576 Mdot
.63907 .40547 Mdot
.5852 .43555 Mdot
.3823 .66226 Mdot
.6387 .42003 Mdot
.61553 .23808 Mdot
.56491 .76157 Mdot
.39216 .66152 Mdot
.72808 .54087 Mdot
.39074 .39299 Mdot
.27936 .4879 Mdot
.59622 .40617 Mdot
.35646 .65283 Mdot
.27927 .47327 Mdot
.5917 .41871 Mdot
.30615 .36891 Mdot
.38686 .6188 Mdot
.66779 .5358 Mdot
.36877 .40327 Mdot
.55115 .67525 Mdot
.54695 .73172 Mdot
.60693 .38503 Mdot
.5503 .67985 Mdot
.339 .35701 Mdot
.37382 .67174 Mdot
.26084 .48949 Mdot
.61313 .28654 Mdot
.35365 .58751 Mdot
.582 .39907 Mdot
.63157 .33526 Mdot
.36647 .40859 Mdot
.67338 .55029 Mdot
.62882 .6204 Mdot
.35005 .37485 Mdot
.36617 .65659 Mdot
.33836 .36892 Mdot
.28044 .47524 Mdot
.26154 .47947 Mdot
.70827 .56267 Mdot
.30743 .35495 Mdot
.40759 .42596 Mdot
.57566 .67112 Mdot
.42381 .33689 Mdot
.38574 .38232 Mdot
.63689 .26314 Mdot
.26795 .46126 Mdot
.53777 .72441 Mdot
.36567 .58199 Mdot
.6765 .55095 Mdot
.38744 .64466 Mdot
.38101 .59779 Mdot
.34958 .68764 Mdot
.33639 .72233 Mdot
.25676 .46407 Mdot
.43228 .76323 Mdot
.33939 .56478 Mdot
.35256 .49311 Mdot
.33687 .69262 Mdot
.64176 .63294 Mdot
.39182 .66356 Mdot
.34651 .68599 Mdot
.38059 .75174 Mdot
.34296 .6784 Mdot
.3907 .39498 Mdot
.35993 .41141 Mdot
.35427 .36082 Mdot
.78133 .55738 Mdot
.41721 .42665 Mdot
.58796 .39719 Mdot
.60611 .29319 Mdot
.39745 .64027 Mdot
.61526 .41476 Mdot
.29979 .35085 Mdot
.64555 .40278 Mdot
.38389 .40453 Mdot
.40011 .43028 Mdot
.25686 .48052 Mdot
.41013 .2757 Mdot
.7829 .55837 Mdot
.36141 .63899 Mdot
.40413 .38501 Mdot
.6321 .63508 Mdot
.37106 .40545 Mdot
.34289 .36974 Mdot
.43917 .44011 Mdot
.675 .55014 Mdot
.38387 .60037 Mdot
.61572 .39096 Mdot
.35438 .5849 Mdot
.40884 .41634 Mdot
.61608 .37798 Mdot
.62065 .26789 Mdot
.3964 .4253 Mdot
.37564 .61508 Mdot
.27992 .47356 Mdot
.34824 .70031 Mdot
.37522 .67471 Mdot
.36439 .40937 Mdot
.39532 .63189 Mdot
.35115 .69569 Mdot
.26274 .47659 Mdot
.73899 .57121 Mdot
.57587 .76952 Mdot
.38105 .40135 Mdot
.64106 .30338 Mdot
.41894 .40468 Mdot
.62404 .27369 Mdot
.59105 .3964 Mdot
.61258 .40006 Mdot
.48301 .39461 Mdot
.68167 .57573 Mdot
.60499 .28145 Mdot
.77784 .55901 Mdot
.24049 .46527 Mdot
.3627 .72927 Mdot
.54723 .74024 Mdot
.67543 .58371 Mdot
.61287 .40164 Mdot
.49072 .35611 Mdot
.37808 .31641 Mdot
.55189 .67972 Mdot
.36842 .70297 Mdot
.46875 .42118 Mdot
.63562 .42552 Mdot
.66946 .535 Mdot
.67375 .5647 Mdot
.56387 .76144 Mdot
.38061 .75044 Mdot
.43996 .42567 Mdot
.63402 .42658 Mdot
.29022 .48434 Mdot
.62148 .41715 Mdot
.61391 .38888 Mdot
.72259 .56547 Mdot
.41032 .4328 Mdot
.29383 .35346 Mdot
.70708 .54814 Mdot
.6308 .29493 Mdot
.37409 .69072 Mdot
.64646 .28802 Mdot
.46563 .71804 Mdot
.30137 .54329 Mdot
.69305 .54639 Mdot
.60367 .433 Mdot
.42345 .42556 Mdot
.38425 .60499 Mdot
.37618 .60742 Mdot
.39215 .64118 Mdot
.60968 .29109 Mdot
.63891 .56514 Mdot
.79114 .54696 Mdot
.40099 .39729 Mdot
.37789 .65734 Mdot
.65237 .30493 Mdot
.40897 .40321 Mdot
.55955 .69311 Mdot
.27832 .46939 Mdot
.37329 .66189 Mdot
.24165 .48837 Mdot
.38161 .66429 Mdot
.67924 .56395 Mdot
.43915 .41224 Mdot
.38327 .39412 Mdot
.49228 .33889 Mdot
.63351 .30115 Mdot
.34287 .69915 Mdot
.34661 .40179 Mdot
.35718 .38516 Mdot
.46961 .30558 Mdot
.39516 .42778 Mdot
.36327 .49554 Mdot
.63737 .43554 Mdot
.58938 .41268 Mdot
.33657 .36256 Mdot
.37979 .40981 Mdot
.37385 .61244 Mdot
.33965 .56009 Mdot
.3022 .54068 Mdot
.58823 .68551 Mdot
.39362 .65974 Mdot
.70292 .54492 Mdot
.64955 .54287 Mdot
.7013 .53486 Mdot
.65211 .29352 Mdot
.26359 .48796 Mdot
.43587 .41596 Mdot
.58884 .6732 Mdot
.61512 .30949 Mdot
.37928 .64914 Mdot
.62873 .27924 Mdot
.32409 .37023 Mdot
.63503 .31138 Mdot
.62503 .38751 Mdot
.6169 .78401 Mdot
.24707 .47944 Mdot
.6371 .28956 Mdot
.38872 .62814 Mdot
.48908 .37214 Mdot
.45473 .43708 Mdot
.31778 .55534 Mdot
.60557 .28465 Mdot
.75612 .55624 Mdot
.36817 .40994 Mdot
.32344 .43147 Mdot
.57509 .70257 Mdot
.6455 .30118 Mdot
.55582 .71892 Mdot
.27565 .47665 Mdot
.36362 .72031 Mdot
.36566 .66349 Mdot
.54963 .74036 Mdot
.34098 .36956 Mdot
.64468 .30335 Mdot
.69368 .54925 Mdot
.39242 .36996 Mdot
.7891 .55717 Mdot
.64795 .39922 Mdot
.47996 .31574 Mdot
.7216 .57491 Mdot
.4453 .39919 Mdot
.5458 .70643 Mdot
.42427 .39241 Mdot
.24395 .47848 Mdot
.35992 .38668 Mdot
.71567 .54837 Mdot
.69193 .55445 Mdot
.79901 .55122 Mdot
.4244 .39697 Mdot
.44584 .42998 Mdot
.37231 .5904 Mdot
.63959 .56725 Mdot
.35288 .68777 Mdot
.3585 .64765 Mdot
.71161 .56882 Mdot
.35154 .70658 Mdot
.63003 .2846 Mdot
.33321 .40158 Mdot
.5459 .70553 Mdot
.54201 .72096 Mdot
.69027 .54713 Mdot
.73063 .56064 Mdot
.67271 .54941 Mdot
.2777 .47577 Mdot
.36897 .68043 Mdot
.37337 .42921 Mdot
.38998 .40731 Mdot
.44804 .40956 Mdot
.38978 .61548 Mdot
.34022 .3615 Mdot
.42722 .46925 Mdot
.60995 .2827 Mdot
.68195 .56039 Mdot
.56321 .72173 Mdot
.25968 .38618 Mdot
.58137 .67055 Mdot
.37152 .42154 Mdot
.56943 .76837 Mdot
.36966 .7013 Mdot
.62455 .31825 Mdot
.26161 .46526 Mdot
.6284 .31989 Mdot
.59365 .65902 Mdot
.37024 .59492 Mdot
.30276 .36013 Mdot
.41304 .44625 Mdot
.31734 .36119 Mdot
.74965 .47487 Mdot
.37337 .60819 Mdot
.57691 .67869 Mdot
.25254 .47235 Mdot
.64865 .40941 Mdot
.29516 .46422 Mdot
.43213 .40651 Mdot
.40935 .38667 Mdot
.31856 .43464 Mdot
.35792 .40647 Mdot
.39522 .64378 Mdot
.33231 .37013 Mdot
.61215 .4352 Mdot
.37441 .39374 Mdot
.44474 .74981 Mdot
.4148 .41651 Mdot
.44235 .42704 Mdot
.4326 .42394 Mdot
.35827 .38283 Mdot
.39586 .62297 Mdot
.2544 .48277 Mdot
.58386 .67255 Mdot
.33125 .39988 Mdot
.54755 .70769 Mdot
.68402 .54575 Mdot
.57605 .40817 Mdot
.38826 .60643 Mdot
.62586 .32144 Mdot
.48977 .681 Mdot
.32437 .42922 Mdot
.71517 .53835 Mdot
.49535 .34832 Mdot
.61042 .26713 Mdot
.60519 .38971 Mdot
.65042 .29514 Mdot
.72246 .55766 Mdot
.56129 .69952 Mdot
.42941 .4407 Mdot
.35591 .68405 Mdot
.35577 .66413 Mdot
.3696 .3964 Mdot
.58246 .7703 Mdot
.54677 .73145 Mdot
.76469 .55783 Mdot
.43805 .42764 Mdot
.35854 .40528 Mdot
.35718 .69912 Mdot
.74444 .56299 Mdot
.31944 .35248 Mdot
.61673 .3003 Mdot
.37214 .41034 Mdot
.62496 .43372 Mdot
.32222 .36781 Mdot
.58692 .678 Mdot
.62709 .42099 Mdot
.42111 .41541 Mdot
.34754 .40689 Mdot
.24721 .49963 Mdot
.60998 .44669 Mdot
.65435 .57923 Mdot
.36541 .41032 Mdot
.37545 .40087 Mdot
.38712 .61836 Mdot
.54464 .70215 Mdot
.37267 .64359 Mdot
.37918 .58826 Mdot
.61277 .40045 Mdot
.54151 .70904 Mdot
.35754 .38338 Mdot
.54018 .7359 Mdot
.27794 .46776 Mdot
.38986 .4005 Mdot
.57829 .67919 Mdot
.37493 .6784 Mdot
.41201 .76328 Mdot
.46782 .42397 Mdot
.27336 .47293 Mdot
.41869 .40565 Mdot
.76513 .55302 Mdot
.5782 .40184 Mdot
.4017 .44318 Mdot
.35621 .65924 Mdot
.40695 .40197 Mdot
.59274 .67652 Mdot
.6353 .27762 Mdot
.36352 .65881 Mdot
.73011 .57424 Mdot
.69119 .5651 Mdot
.64786 .57563 Mdot
.6266 .3886 Mdot
.28102 .47616 Mdot
.38367 .62122 Mdot
.36859 .63428 Mdot
.32328 .3647 Mdot
.68706 .56129 Mdot
.61873 .28807 Mdot
.38605 .39098 Mdot
.62924 .43274 Mdot
.55892 .66326 Mdot
.25777 .53175 Mdot
.31177 .37042 Mdot
.65094 .28104 Mdot
.40225 .32425 Mdot
.61234 .40635 Mdot
.41868 .43503 Mdot
.64473 .30263 Mdot
.71577 .56607 Mdot
.25215 .50167 Mdot
.60129 .27505 Mdot
.76669 .56263 Mdot
.72986 .54879 Mdot
.54876 .73473 Mdot
.6463 .57904 Mdot
.63924 .3125 Mdot
.59197 .40304 Mdot
.35885 .66303 Mdot
.40016 .42651 Mdot
.60216 .40403 Mdot
.66837 .55865 Mdot
.63375 .39946 Mdot
.43016 .43616 Mdot
.36104 .69949 Mdot
.6705 .54094 Mdot
.38853 .39769 Mdot
.25274 .46664 Mdot
.32107 .54944 Mdot
.74302 .5672 Mdot
.33487 .36823 Mdot
.65069 .23974 Mdot
.70789 .53838 Mdot
.71957 .55068 Mdot
.36203 .40582 Mdot
.60404 .3178 Mdot
.40338 .41446 Mdot
.56143 .69564 Mdot
.30272 .34281 Mdot
.54284 .70874 Mdot
.473 .30421 Mdot
.36259 .39633 Mdot
.35521 .367 Mdot
.36869 .72545 Mdot
.59546 .26779 Mdot
.44283 .28715 Mdot
.4045 .43667 Mdot
.33881 .68195 Mdot
.30213 .34735 Mdot
.35579 .29862 Mdot
.38071 .59418 Mdot
.63458 .27364 Mdot
.57846 .7 Mdot
.39294 .39167 Mdot
.45033 .7448 Mdot
.61635 .2845 Mdot
.4738 .30692 Mdot
.36617 .37552 Mdot
.37253 .65294 Mdot
.43837 .41716 Mdot
.36112 .66858 Mdot
.42224 .412 Mdot
.32957 .55337 Mdot
.55914 .75561 Mdot
.32077 .41666 Mdot
.59385 .40122 Mdot
.6382 .65018 Mdot
.36505 .49669 Mdot
.6253 .28606 Mdot
.24308 .48231 Mdot
.61792 .40507 Mdot
.55696 .70333 Mdot
.55242 .74047 Mdot
.67165 .55029 Mdot
.56157 .68063 Mdot
.38849 .66361 Mdot
.75707 .56157 Mdot
.63829 .41369 Mdot
.2695 .50223 Mdot
.62556 .32395 Mdot
.54136 .70857 Mdot
.38834 .42168 Mdot
.44282 .4037 Mdot
.77857 .55585 Mdot
.77213 .53571 Mdot
.35067 .71567 Mdot
.29253 .54112 Mdot
.37059 .5942 Mdot
.63064 .30006 Mdot
.74593 .56697 Mdot
.43128 .41316 Mdot
.41289 .43009 Mdot
.73563 .55268 Mdot
.38554 .60395 Mdot
.60372 .30318 Mdot
.58356 .43422 Mdot
.58955 .67113 Mdot
.81241 .53846 Mdot
.36224 .66003 Mdot
.81378 .53984 Mdot
.78864 .5472 Mdot
.37592 .75236 Mdot
.4461 .28938 Mdot
.56804 .68895 Mdot
.81434 .53982 Mdot
.3752 .65382 Mdot
.38423 .43419 Mdot
.62844 .4071 Mdot
.63057 .39188 Mdot
.36855 .69322 Mdot
.68331 .54192 Mdot
.60279 .31653 Mdot
.43367 .40522 Mdot
.65285 .27263 Mdot
.38278 .59999 Mdot
.64977 .57095 Mdot
.61499 .42163 Mdot
.57919 .70485 Mdot
.41279 .40374 Mdot
.60895 .29003 Mdot
.5693 .68966 Mdot
.59282 .42346 Mdot
.32851 .40906 Mdot
.32716 .34702 Mdot
.27388 .46066 Mdot
.57426 .70224 Mdot
.32362 .35974 Mdot
.37418 .40962 Mdot
.54583 .70663 Mdot
.64573 .42992 Mdot
.64055 .64941 Mdot
.31461 .34382 Mdot
.56507 .76148 Mdot
.73934 .54952 Mdot
.64775 .57997 Mdot
.66901 .58495 Mdot
.78168 .55871 Mdot
.54859 .70151 Mdot
.60506 .41137 Mdot
.80274 .54583 Mdot
.54434 .70347 Mdot
.34786 .37258 Mdot
.3933 .39198 Mdot
.40516 .37074 Mdot
.59355 .42533 Mdot
.60319 .42732 Mdot
.35959 .57402 Mdot
.25025 .48511 Mdot
.61538 .42023 Mdot
.38635 .42459 Mdot
.3794 .6144 Mdot
.57197 .67828 Mdot
.63543 .21378 Mdot
.58966 .66238 Mdot
.25648 .50324 Mdot
.68824 .53248 Mdot
.75706 .56039 Mdot
.39874 .42518 Mdot
.56189 .62334 Mdot
.58989 .18312 Mdot
.39417 .39177 Mdot
.26135 .46535 Mdot
.47606 .30626 Mdot
.37287 .39428 Mdot
.38538 .68395 Mdot
.62073 .4322 Mdot
.38048 .61578 Mdot
.57159 .6858 Mdot
.63226 .27356 Mdot
.62115 .23752 Mdot
.57969 .69751 Mdot
.41393 .41847 Mdot
.58827 .3922 Mdot
.39196 .41723 Mdot
.4129 .44087 Mdot
.33782 .39088 Mdot
.64123 .27233 Mdot
.6748 .5457 Mdot
.62696 .3214 Mdot
.34412 .68265 Mdot
.28382 .53773 Mdot
.62385 .28451 Mdot
.396 .3711 Mdot
.30867 .34958 Mdot
.76782 .53669 Mdot
.3565 .66268 Mdot
.62127 .27457 Mdot
.57286 .70744 Mdot
.35731 .30577 Mdot
.38007 .37043 Mdot
.56874 .67378 Mdot
.42207 .43752 Mdot
.36694 .63388 Mdot
.36823 .58197 Mdot
.54141 .72888 Mdot
.37277 .63783 Mdot
.32251 .3577 Mdot
.27377 .47937 Mdot
.58753 .67659 Mdot
.4233 .28533 Mdot
.5411 .71361 Mdot
.39713 .49734 Mdot
.27282 .46729 Mdot
.36498 .65801 Mdot
.33316 .4812 Mdot
.36761 .60383 Mdot
.59375 .41963 Mdot
.34601 .3878 Mdot
.62065 .28826 Mdot
.31836 .3599 Mdot
.72725 .57636 Mdot
.36807 .71131 Mdot
.36882 .66951 Mdot
.58814 .6426 Mdot
.36907 .64219 Mdot
.3608 .70698 Mdot
.56057 .73378 Mdot
.39012 .66978 Mdot
.41003 .41713 Mdot
.2343 .51745 Mdot
.38632 .63138 Mdot
.57719 .6907 Mdot
.60972 .29884 Mdot
.39347 .63983 Mdot
.78906 .54939 Mdot
.36822 .4026 Mdot
.65395 .56149 Mdot
.59907 .30759 Mdot
.39332 .61889 Mdot
.62344 .28878 Mdot
.66572 .55486 Mdot
.62305 .26385 Mdot
.57171 .65038 Mdot
.53771 .7162 Mdot
.59207 .43608 Mdot
.56209 .76147 Mdot
.34315 .68028 Mdot
.7601 .56593 Mdot
.43362 .40044 Mdot
.43483 .42895 Mdot
.60632 .33224 Mdot
.33935 .69236 Mdot
.58392 .77523 Mdot
.61546 .41606 Mdot
.35504 .57438 Mdot
.57068 .71627 Mdot
.76233 .55703 Mdot
.29653 .35056 Mdot
.55248 .7441 Mdot
.60931 .43521 Mdot
.61377 .40498 Mdot
.38995 .41866 Mdot
.49233 .33311 Mdot
.64741 .29564 Mdot
.6404 .62951 Mdot
.26617 .49655 Mdot
.73727 .55733 Mdot
.4275 .42219 Mdot
.25744 .49295 Mdot
.38988 .43296 Mdot
.6531 .296 Mdot
.56185 .67579 Mdot
.3539 .67069 Mdot
.62714 .27252 Mdot
.69158 .56534 Mdot
.28283 .35515 Mdot
.39754 .44237 Mdot
.32977 .36133 Mdot
.68792 .53674 Mdot
.34553 .66926 Mdot
.68558 .55052 Mdot
.5462 .70646 Mdot
.62713 .28122 Mdot
.27896 .47396 Mdot
.59438 .42646 Mdot
.64509 .55643 Mdot
.55576 .69589 Mdot
.73579 .57378 Mdot
.55033 .73555 Mdot
.61473 .40195 Mdot
.32395 .34925 Mdot
.63437 .56532 Mdot
.62706 .39919 Mdot
.34823 .57283 Mdot
.33328 .41238 Mdot
.37782 .74514 Mdot
.68717 .53986 Mdot
.66256 .40138 Mdot
.57265 .68957 Mdot
.58481 .65471 Mdot
.38028 .50214 Mdot
.55129 .16391 Mdot
.34226 .38739 Mdot
.59158 .78116 Mdot
.54579 .70449 Mdot
.56955 .70362 Mdot
.68174 .55128 Mdot
.37481 .67967 Mdot
.38762 .70626 Mdot
.6715 .53615 Mdot
.45805 .30063 Mdot
.37925 .64949 Mdot
.35636 .36238 Mdot
.63937 .55535 Mdot
.26043 .47706 Mdot
.33401 .56094 Mdot
.61101 .27779 Mdot
.48395 .32232 Mdot
.54893 .73935 Mdot
.4065 .39462 Mdot
.42802 .76665 Mdot
.67299 .55353 Mdot
.62986 .39689 Mdot
.58518 .63623 Mdot
.44531 .40545 Mdot
.42692 .42732 Mdot
.39835 .40616 Mdot
.60577 .33049 Mdot
.34293 .56556 Mdot
.42431 .40218 Mdot
.32808 .41527 Mdot
.2816 .48679 Mdot
.68302 .58325 Mdot
.63273 .31678 Mdot
.4966 .35448 Mdot
.74343 .5399 Mdot
.3559 .57348 Mdot
.42055 .39029 Mdot
.57792 .65942 Mdot
.25118 .4861 Mdot
.58315 .68007 Mdot
.56573 .72251 Mdot
.81488 .53464 Mdot
.3563 .6562 Mdot
.27527 .48992 Mdot
.70343 .57407 Mdot
.37152 .72395 Mdot
.26375 .49234 Mdot
.28749 .53958 Mdot
.59024 .64543 Mdot
.53691 .15845 Mdot
.58285 .65302 Mdot
.6336 .3962 Mdot
.38798 .66888 Mdot
.34142 .66716 Mdot
.32309 .36749 Mdot
.3597 .68671 Mdot
.77591 .5569 Mdot
.38356 .62245 Mdot
.81545 .44038 Mdot
.37376 .60265 Mdot
.57225 .69457 Mdot
.54069 .72 Mdot
.25865 .48557 Mdot
.41066 .42056 Mdot
.29883 .36077 Mdot
.6163 .41648 Mdot
.32955 .35271 Mdot
.70809 .54871 Mdot
.7928 .54962 Mdot
.60892 .78419 Mdot
.38525 .68054 Mdot
.55265 .69773 Mdot
.42748 .42638 Mdot
.27395 .4679 Mdot
.36004 .41177 Mdot
.55404 .75 Mdot
.28821 .45042 Mdot
.38929 .40844 Mdot
.26236 .48724 Mdot
.67721 .53435 Mdot
.75043 .54662 Mdot
.38105 .74914 Mdot
.81334 .53627 Mdot
.40021 .43378 Mdot
.62495 .30661 Mdot
.65268 .29342 Mdot
.43136 .44705 Mdot
.62361 .58509 Mdot
.31796 .3523 Mdot
.38705 .42039 Mdot
.28171 .3545 Mdot
.66834 .53495 Mdot
.63902 .39484 Mdot
.67232 .56025 Mdot
.38402 .59595 Mdot
.59514 .39262 Mdot
.71636 .55503 Mdot
.29203 .36149 Mdot
.60673 .40279 Mdot
.64055 .64725 Mdot
.61373 .28431 Mdot
.38035 .41944 Mdot
.39972 .50233 Mdot
.63772 .56477 Mdot
.56541 .69799 Mdot
.39204 .65078 Mdot
.5831 .67403 Mdot
.74625 .54597 Mdot
.4636 .29987 Mdot
.59726 .42593 Mdot
.58224 .66079 Mdot
.2854 .46187 Mdot
.62129 .30946 Mdot
.58247 .65036 Mdot
.28234 .47496 Mdot
.43503 .44637 Mdot
.57167 .17431 Mdot
.44689 .41762 Mdot
.79446 .5499 Mdot
.5429 .70362 Mdot
.65081 .41597 Mdot
.402 .4264 Mdot
.65374 .56748 Mdot
.65486 .26671 Mdot
.38894 .41461 Mdot
.72536 .57474 Mdot
.37892 .39975 Mdot
.64389 .30339 Mdot
.38497 .6155 Mdot
.29912 .34297 Mdot
.618 .33663 Mdot
.62874 .2734 Mdot
.31898 .43055 Mdot
.35871 .41079 Mdot
.6389 .61497 Mdot
.37236 .65001 Mdot
.37737 .42701 Mdot
.61346 .34113 Mdot
.38015 .67973 Mdot
.38742 .64776 Mdot
.25295 .5025 Mdot
.59393 .67843 Mdot
.67781 .54176 Mdot
.62744 .31267 Mdot
.77008 .55089 Mdot
.40187 .39447 Mdot
.24316 .49068 Mdot
.61796 .27909 Mdot
.56273 .68726 Mdot
.27659 .48366 Mdot
.60294 .77986 Mdot
.33075 .40103 Mdot
.58385 .64847 Mdot
.39555 .38397 Mdot
.32242 .46594 Mdot
.37912 .60703 Mdot
.43399 .76108 Mdot
.56121 .75443 Mdot
.67996 .56546 Mdot
.61302 .42089 Mdot
.26876 .53488 Mdot
.60998 .28989 Mdot
.3892 .70695 Mdot
.43281 .43336 Mdot
.42854 .41357 Mdot
.38061 .6117 Mdot
.41088 .44673 Mdot
.37629 .69412 Mdot
.78268 .54835 Mdot
.54798 .16205 Mdot
.35704 .66841 Mdot
.36971 .66363 Mdot
.23703 .50182 Mdot
.65297 .53534 Mdot
.37241 .69322 Mdot
.39219 .39119 Mdot
.74892 .54722 Mdot
.61161 .44637 Mdot
.60694 .30823 Mdot
.5946 .31403 Mdot
.36692 .70652 Mdot
.39713 .37552 Mdot
.27733 .46403 Mdot
.47834 .40566 Mdot
.40933 .32689 Mdot
.54779 .69989 Mdot
.39566 .38791 Mdot
.61535 .41197 Mdot
.67005 .55693 Mdot
.44856 .42408 Mdot
.38571 .42477 Mdot
.35198 .67543 Mdot
.61516 .26968 Mdot
.55032 .71727 Mdot
.62455 .39606 Mdot
.6388 .57283 Mdot
.62523 .2972 Mdot
.35203 .70767 Mdot
.37029 .49898 Mdot
.58037 .41051 Mdot
.6337 .42568 Mdot
.41184 .43751 Mdot
.3664 .41295 Mdot
.59286 .42883 Mdot
.58212 .69069 Mdot
.67652 .56574 Mdot
.61226 .39151 Mdot
.31885 .35808 Mdot
.2892 .34669 Mdot
.41896 .43153 Mdot
.37972 .62774 Mdot
.55458 .70117 Mdot
.59982 .42671 Mdot
.806 .54836 Mdot
.38368 .3909 Mdot
.37363 .3731 Mdot
.60229 .46493 Mdot
.61049 .41192 Mdot
.38659 .70763 Mdot
.61935 .32301 Mdot
.27255 .46749 Mdot
.32533 .41562 Mdot
.33801 .35706 Mdot
.41874 .39026 Mdot
.71982 .56414 Mdot
.56675 .71712 Mdot
.61327 .44218 Mdot
.68258 .5599 Mdot
.38755 .64593 Mdot
.47983 .40261 Mdot
.35455 .65289 Mdot
.36831 .63551 Mdot
.36026 .71814 Mdot
.58782 .68807 Mdot
.26481 .53349 Mdot
.58757 .42402 Mdot
.4407 .42637 Mdot
.55434 .68162 Mdot
.36896 .69806 Mdot
.34741 .36495 Mdot
.37 .70109 Mdot
.34143 .69693 Mdot
.33619 .35356 Mdot
.26473 .48373 Mdot
.32661 .42155 Mdot
.43759 .39584 Mdot
.6107 .32718 Mdot
.3682 .62618 Mdot
.37641 .37182 Mdot
.42941 .40977 Mdot
.40375 .43045 Mdot
.25683 .48472 Mdot
.64429 .27652 Mdot
.48386 .39589 Mdot
.43142 .43329 Mdot
.496 .33251 Mdot
.34765 .36659 Mdot
.33786 .68879 Mdot
.56456 .65401 Mdot
.25545 .50357 Mdot
.72559 .54297 Mdot
.38396 .60576 Mdot
.61263 .27526 Mdot
.38435 .69699 Mdot
.27213 .4589 Mdot
.56314 .71064 Mdot
.37322 .66182 Mdot
.66178 .54379 Mdot
.56496 .6952 Mdot
.54109 .71388 Mdot
.25556 .48186 Mdot
.68334 .56844 Mdot
.61675 .26866 Mdot
.54661 .7249 Mdot
.29486 .45899 Mdot
.57111 .69568 Mdot
.36778 .74473 Mdot
.32234 .34899 Mdot
.32628 .41364 Mdot
.59909 .41203 Mdot
.63235 .43815 Mdot
.5448 .71449 Mdot
.61515 .29988 Mdot
.27621 .48547 Mdot
.39242 .64331 Mdot
.61643 .30691 Mdot
.33504 .55985 Mdot
.75532 .55939 Mdot
.36791 .58301 Mdot
.77984 .55416 Mdot
.35867 .6901 Mdot
.48193 .31911 Mdot
.62089 .27014 Mdot
.61784 .43849 Mdot
.31703 .36927 Mdot
.61551 .42324 Mdot
.44568 .42688 Mdot
.27511 .48869 Mdot
.40964 .41601 Mdot
.70342 .53491 Mdot
.60452 .33003 Mdot
.38481 .62892 Mdot
.6323 .23913 Mdot
.56766 .67876 Mdot
.32729 .36232 Mdot
.62603 .39345 Mdot
.27393 .47204 Mdot
.37442 .69467 Mdot
.34795 .69395 Mdot
.34027 .55891 Mdot
.7099 .53863 Mdot
.60414 .25975 Mdot
.42068 .4281 Mdot
.63977 .24846 Mdot
.54356 .71244 Mdot
.56244 .76261 Mdot
.65275 .55496 Mdot
.53395 .1611 Mdot
.68918 .56024 Mdot
.61479 .44911 Mdot
.35656 .69398 Mdot
.64235 .29328 Mdot
.41644 .42375 Mdot
.39334 .62323 Mdot
.38858 .70544 Mdot
.59503 .30711 Mdot
.62693 .32028 Mdot
.55487 .75504 Mdot
.55142 .68344 Mdot
.63565 .41313 Mdot
.34791 .36764 Mdot
.35167 .36688 Mdot
.44152 .40547 Mdot
.55056 .69376 Mdot
.26984 .47841 Mdot
.57017 .64982 Mdot
.25407 .46993 Mdot
.61282 .34182 Mdot
.72299 .55105 Mdot
.65888 .7406 Mdot
.38805 .61332 Mdot
.4818 .39748 Mdot
.36625 .73417 Mdot
.33398 .41033 Mdot
.57006 .66872 Mdot
.64552 .43098 Mdot
.67784 .54793 Mdot
.50295 .66385 Mdot
.72418 .55383 Mdot
.61612 .20937 Mdot
.41094 .37267 Mdot
.5873 .63962 Mdot
.33163 .35764 Mdot
.6939 .57287 Mdot
.44569 .40055 Mdot
.60853 .39285 Mdot
.58866 .39198 Mdot
.2629 .45723 Mdot
.30533 .544 Mdot
.61308 .32754 Mdot
.41718 .42392 Mdot
.37829 .61822 Mdot
.41599 .42559 Mdot
.4165 .42671 Mdot
.41635 .44164 Mdot
.54787 .74115 Mdot
.32577 .35259 Mdot
.4104 .41911 Mdot
.80112 .54989 Mdot
.61221 .44484 Mdot
.63341 .57458 Mdot
.37821 .60473 Mdot
.61523 .30955 Mdot
.38062 .59838 Mdot
.30536 .3555 Mdot
.58962 .6574 Mdot
.34115 .56429 Mdot
.26583 .47421 Mdot
.36825 .70974 Mdot
.58312 .65847 Mdot
.60119 .30252 Mdot
.616 .40885 Mdot
.37648 .7669 Mdot
.77784 .55898 Mdot
.62589 .41717 Mdot
.73581 .56992 Mdot
.43642 .39639 Mdot
.36011 .65979 Mdot
.61684 .42218 Mdot
.55494 .72125 Mdot
.72406 .56471 Mdot
.32293 .42891 Mdot
.40239 .39951 Mdot
.69396 .53947 Mdot
.60228 .40778 Mdot
.3174 .35901 Mdot
.30328 .3486 Mdot
.69271 .57327 Mdot
.58272 .70455 Mdot
.54319 .72094 Mdot
.60845 .30224 Mdot
.34077 .68363 Mdot
.34881 .68488 Mdot
.5671 .68051 Mdot
.50986 .6565 Mdot
.39131 .3959 Mdot
.3941 .39823 Mdot
.30716 .36296 Mdot
.3477 .38428 Mdot
.78554 .55974 Mdot
.62507 .41505 Mdot
.35914 .68064 Mdot
.2747 .48943 Mdot
.25416 .49623 Mdot
.41718 .4205 Mdot
.45509 .29532 Mdot
.67232 .53881 Mdot
.27052 .46407 Mdot
.64525 .30142 Mdot
.31681 .54621 Mdot
.37057 .40374 Mdot
.61545 .3446 Mdot
.34988 .69238 Mdot
.64081 .63857 Mdot
.56575 .69915 Mdot
.69199 .57523 Mdot
.69902 .57452 Mdot
.75152 .47313 Mdot
.38649 .61197 Mdot
.62525 .41768 Mdot
.76895 .56505 Mdot
.61095 .38528 Mdot
.62792 .3185 Mdot
.49119 .37088 Mdot
.77785 .55728 Mdot
.63579 .57559 Mdot
.58928 .64095 Mdot
.39338 .38612 Mdot
.37275 .41211 Mdot
.56655 .76186 Mdot
.39692 .42839 Mdot
.62242 .28119 Mdot
.56144 .66754 Mdot
.37361 .65973 Mdot
.60617 .32429 Mdot
.5758 .65899 Mdot
.34749 .68633 Mdot
.2571 .4798 Mdot
.34906 .36626 Mdot
.38993 .64837 Mdot
.35452 .70437 Mdot
.38987 .39507 Mdot
.81873 .53148 Mdot
.35492 .67665 Mdot
.39144 .6594 Mdot
.3149 .54635 Mdot
.65016 .57434 Mdot
.65665 .27337 Mdot
.59372 .67341 Mdot
.40364 .41345 Mdot
.7176 .54573 Mdot
.63774 .30297 Mdot
.37008 .67046 Mdot
.38657 .43059 Mdot
.40451 .39527 Mdot
.62181 .30873 Mdot
.64437 .30731 Mdot
.61417 .30249 Mdot
.54233 .72997 Mdot
.26247 .47525 Mdot
.37963 .68594 Mdot
.55896 .68183 Mdot
.61356 .27675 Mdot
.63056 .32126 Mdot
.59556 .33546 Mdot
.38874 .3965 Mdot
.64419 .3087 Mdot
.281 .53713 Mdot
.29468 .36841 Mdot
.60883 .38508 Mdot
.66062 .42092 Mdot
.62877 .561 Mdot
.63607 .45406 Mdot
.56755 .71574 Mdot
.25484 .47149 Mdot
.6059 .30897 Mdot
.60215 .4002 Mdot
.39827 .39796 Mdot
.36966 .3937 Mdot
.62296 .30523 Mdot
.46343 .29784 Mdot
.35024 .67372 Mdot
.38019 .74509 Mdot
.61829 .3102 Mdot
.67066 .57322 Mdot
.6659 .53588 Mdot
.69527 .55576 Mdot
.4151 .43375 Mdot
.34371 .35383 Mdot
.37134 .31395 Mdot
.35235 .566 Mdot
.54726 .69378 Mdot
.35177 .6964 Mdot
.31403 .54983 Mdot
.38679 .64856 Mdot
.74296 .55435 Mdot
.6151 .2993 Mdot
.37574 .61742 Mdot
.54127 .72577 Mdot
.54474 .72049 Mdot
.63626 .56724 Mdot
.68842 .56187 Mdot
.69325 .54768 Mdot
.38945 .60977 Mdot
.36479 .69645 Mdot
.33181 .35267 Mdot
.37065 .63692 Mdot
.74189 .53775 Mdot
.78334 .54865 Mdot
.63611 .56486 Mdot
.57898 .68595 Mdot
.37599 .67357 Mdot
.37687 .39988 Mdot
.31673 .4353 Mdot
.66432 .53589 Mdot
.60629 .28361 Mdot
.23575 .51799 Mdot
.55369 .16521 Mdot
.24516 .48709 Mdot
.55573 .71016 Mdot
.5933 .40713 Mdot
.40219 .40721 Mdot
.67336 .5644 Mdot
.65558 .43238 Mdot
.62053 .43124 Mdot
.33112 .36551 Mdot
.23622 .47172 Mdot
.55883 .70599 Mdot
.29983 .3481 Mdot
.60735 .39481 Mdot
.28301 .48146 Mdot
.56246 .66771 Mdot
.64342 .55739 Mdot
.67414 .5844 Mdot
.35881 .57297 Mdot
.49135 .36538 Mdot
.58871 .41537 Mdot
.42671 .39668 Mdot
.71298 .55494 Mdot
.60566 .32251 Mdot
.70751 .55142 Mdot
.33746 .69438 Mdot
.64231 .57187 Mdot
.37597 .40742 Mdot
.37865 .68597 Mdot
.54351 .7183 Mdot
.36153 .3076 Mdot
.62588 .23607 Mdot
.64809 .56542 Mdot
.60824 .43788 Mdot
.25157 .49055 Mdot
.27369 .50076 Mdot
.63226 .43837 Mdot
.37464 .41287 Mdot
.5791 .6788 Mdot
.37895 .6899 Mdot
.56058 .68678 Mdot
.65622 .26814 Mdot
.35328 .74888 Mdot
.56497 .70059 Mdot
.33949 .35017 Mdot
.60263 .31736 Mdot
.46047 .29771 Mdot
.37902 .41098 Mdot
.55819 .72256 Mdot
.32775 .35867 Mdot
.37611 .61349 Mdot
.29262 .35918 Mdot
.3313 .4031 Mdot
.57414 .67757 Mdot
.63897 .4107 Mdot
.30767 .3476 Mdot
.65385 .26713 Mdot
.54713 .70755 Mdot
.28462 .3492 Mdot
.62749 .40985 Mdot
.62914 .29174 Mdot
.60707 .33001 Mdot
.62253 .29606 Mdot
.38947 .40498 Mdot
.32512 .47052 Mdot
.62259 .27113 Mdot
.56153 .73444 Mdot
.63025 .27588 Mdot
.63405 .44893 Mdot
.58145 .77558 Mdot
.6391 .31252 Mdot
.38994 .42466 Mdot
.25384 .47046 Mdot
.25457 .4725 Mdot
.65631 .55879 Mdot
.38099 .77092 Mdot
.79926 .54923 Mdot
.43181 .41426 Mdot
.30682 .55135 Mdot
.38309 .61837 Mdot
.59768 .43552 Mdot
.33154 .40477 Mdot
.27888 .46118 Mdot
.38798 .65661 Mdot
.31036 .36238 Mdot
.36376 .57988 Mdot
.59889 .39485 Mdot
.38796 .40354 Mdot
.38237 .60784 Mdot
.36191 .71596 Mdot
.44171 .28742 Mdot
.35628 .57498 Mdot
.36507 .68293 Mdot
.54451 .70137 Mdot
.57146 .71077 Mdot
.57796 .67806 Mdot
.69062 .56365 Mdot
.36966 .66558 Mdot
.44178 .443 Mdot
.67933 .56472 Mdot
.42441 .43692 Mdot
.57128 .67822 Mdot
.32608 .40319 Mdot
.37035 .66263 Mdot
.38267 .41553 Mdot
.36766 .36644 Mdot
.72655 .57346 Mdot
.62177 .30804 Mdot
.29656 .54225 Mdot
.67791 .58248 Mdot
.54896 .73511 Mdot
.33561 .6906 Mdot
.63454 .44379 Mdot
.28528 .47602 Mdot
.38433 .43089 Mdot
.42597 .44237 Mdot
.2847 .47825 Mdot
.41164 .37408 Mdot
.63114 .4258 Mdot
.6918 .56522 Mdot
.66522 .57798 Mdot
.37372 .39732 Mdot
.36498 .67051 Mdot
.65365 .28647 Mdot
.61965 .34557 Mdot
.59863 .27885 Mdot
.30741 .35053 Mdot
.32807 .41491 Mdot
.35297 .38539 Mdot
.48527 .38832 Mdot
.65926 .55105 Mdot
.63876 .39579 Mdot
.32013 .36608 Mdot
.62768 .28622 Mdot
.39105 .43758 Mdot
.37821 .60239 Mdot
.37336 .66638 Mdot
.68423 .54035 Mdot
.55108 .67526 Mdot
.5801 .40656 Mdot
.63506 .56232 Mdot
.3729 .39808 Mdot
.263 .49643 Mdot
.54949 .68129 Mdot
.34584 .70807 Mdot
.6294 .29646 Mdot
.67062 .56234 Mdot
.63804 .2847 Mdot
.36989 .64205 Mdot
.36934 .6719 Mdot
.36093 .41143 Mdot
.61593 .24716 Mdot
.6423 .56197 Mdot
.41688 .4311 Mdot
.69801 .54157 Mdot
.7749 .5549 Mdot
.57412 .64929 Mdot
.37882 .42873 Mdot
.38353 .71073 Mdot
.58125 .67552 Mdot
.4318 .42053 Mdot
.25366 .47807 Mdot
.27648 .48251 Mdot
.68386 .57311 Mdot
.60607 .2777 Mdot
.63248 .2874 Mdot
.35058 .73951 Mdot
.3392 .58304 Mdot
.36328 .38449 Mdot
.64906 .57208 Mdot
.29114 .45434 Mdot
.56497 .70649 Mdot
.35997 .69152 Mdot
.63403 .75942 Mdot
.57604 .69304 Mdot
.38219 .39733 Mdot
.62328 .2844 Mdot
.34737 .70253 Mdot
.60559 .38505 Mdot
.36343 .29209 Mdot
.63822 .43074 Mdot
.60611 .25838 Mdot
.62607 .39944 Mdot
.59306 .77589 Mdot
.69705 .54706 Mdot
.37166 .69655 Mdot
.5543 .71143 Mdot
.56397 .70893 Mdot
.74195 .56401 Mdot
.33532 .55654 Mdot
.37848 .75039 Mdot
.24568 .52549 Mdot
.77566 .55935 Mdot
.61656 .29341 Mdot
.29696 .36682 Mdot
.69315 .55602 Mdot
.71389 .58034 Mdot
.551 .75117 Mdot
.56324 .76312 Mdot
.37861 .67335 Mdot
.41257 .39713 Mdot
.32213 .54951 Mdot
.43532 .43415 Mdot
.49206 .36632 Mdot
.56536 .68444 Mdot
.35952 .69147 Mdot
.55669 .76088 Mdot
.36389 .40368 Mdot
.41755 .40981 Mdot
.75151 .54114 Mdot
.61895 .41462 Mdot
.76509 .53252 Mdot
.39188 .43889 Mdot
.7046 .5605 Mdot
.35882 .72792 Mdot
.59694 .4006 Mdot
.38039 .37222 Mdot
.54318 .69678 Mdot
.59866 .4268 Mdot
.59906 .39725 Mdot
.48228 .3853 Mdot
.37082 .58643 Mdot
.35277 .65083 Mdot
.64976 .29771 Mdot
.56323 .76763 Mdot
.57336 .65455 Mdot
.6005 .77918 Mdot
.37719 .39848 Mdot
.53925 .72129 Mdot
.58031 .4305 Mdot
.4333 .42058 Mdot
.265 .49113 Mdot
.34046 .56138 Mdot
.41267 .3905 Mdot
.26202 .46177 Mdot
.57425 .68982 Mdot
.57126 .43079 Mdot
.373 .38412 Mdot
.68963 .53979 Mdot
.37489 .68027 Mdot
.37443 .5875 Mdot
.61031 .31852 Mdot
.56032 .75636 Mdot
.54222 .16096 Mdot
.36103 .69095 Mdot
.39799 .40003 Mdot
.56765 .70449 Mdot
.59059 .40961 Mdot
.60092 .41611 Mdot
.627 .43745 Mdot
.3761 .6649 Mdot
.59746 .40263 Mdot
.36456 .73071 Mdot
.30775 .35931 Mdot
.48194 .39907 Mdot
.58679 .68878 Mdot
.61808 .29119 Mdot
.64032 .26318 Mdot
.77045 .55357 Mdot
.34843 .37004 Mdot
.49258 .36651 Mdot
.33674 .72302 Mdot
.61964 .28563 Mdot
.40863 .41301 Mdot
.63262 .42499 Mdot
.27797 .34469 Mdot
.65473 .30084 Mdot
.63045 .40451 Mdot
.25877 .49955 Mdot
.34374 .68238 Mdot
.62058 .42316 Mdot
.37591 .6568 Mdot
.41233 .41557 Mdot
.32569 .36311 Mdot
.34447 .66703 Mdot
.39539 .76906 Mdot
.5796 .41215 Mdot
.57908 .65578 Mdot
.32457 .35683 Mdot
.39664 .43308 Mdot
.35222 .35996 Mdot
.59285 .4149 Mdot
.43999 .75161 Mdot
.71154 .5454 Mdot
.80163 .54411 Mdot
.78561 .56085 Mdot
.55725 .74836 Mdot
.60297 .78414 Mdot
.35992 .39771 Mdot
.3349 .55423 Mdot
.34905 .35793 Mdot
.58545 .66836 Mdot
.37796 .37603 Mdot
.41055 .42038 Mdot
.41429 .43686 Mdot
.69732 .54103 Mdot
.58995 .64357 Mdot
.25422 .50295 Mdot
.31849 .3641 Mdot
.60207 .28611 Mdot
.37409 .6431 Mdot
.39902 .41423 Mdot
.33515 .71773 Mdot
.67804 .57397 Mdot
.36073 .75797 Mdot
.39029 .42382 Mdot
.61909 .41414 Mdot
.53809 .72429 Mdot
.5427 .71397 Mdot
.67496 .57153 Mdot
.66791 .57097 Mdot
.39766 .43323 Mdot
.56667 .67652 Mdot
.35772 .37606 Mdot
.30868 .34881 Mdot
.6028 .4056 Mdot
.63118 .31229 Mdot
.44084 .43271 Mdot
.37891 .74859 Mdot
.61602 .23809 Mdot
.4173 .4323 Mdot
.35995 .64383 Mdot
.68801 .54687 Mdot
.75235 .56044 Mdot
.35132 .68543 Mdot
.75294 .56165 Mdot
.36236 .75894 Mdot
.32596 .46966 Mdot
.63486 .31262 Mdot
.27101 .50785 Mdot
.63034 .27382 Mdot
.597 .42433 Mdot
.38764 .39689 Mdot
.63917 .62262 Mdot
.78244 .562 Mdot
.2596 .38575 Mdot
.56426 .69177 Mdot
.63019 .39121 Mdot
.26754 .47771 Mdot
.59854 .30869 Mdot
.67268 .55569 Mdot
.58858 .39395 Mdot
.39142 .43814 Mdot
.38474 .60581 Mdot
.24373 .49504 Mdot
.61573 .38911 Mdot
.599 .42409 Mdot
.58695 .39768 Mdot
.57599 .65897 Mdot
.39448 .65622 Mdot
.55444 .75518 Mdot
.72172 .57388 Mdot
.32887 .35112 Mdot
.39857 .40171 Mdot
.35285 .69558 Mdot
.44085 .42085 Mdot
.57995 .67096 Mdot
.23862 .52711 Mdot
.61274 .29899 Mdot
.59198 .39909 Mdot
.46566 .71812 Mdot
.59673 .38761 Mdot
.27719 .49023 Mdot
.28021 .49272 Mdot
.37755 .60498 Mdot
.58644 .66162 Mdot
.42214 .38979 Mdot
.65808 .57976 Mdot
.63076 .29372 Mdot
.54046 .71757 Mdot
.26846 .49305 Mdot
.37966 .41583 Mdot
.61939 .28853 Mdot
.55981 .75995 Mdot
.62026 .26215 Mdot
.5505 .7089 Mdot
.64715 .41708 Mdot
.29678 .43308 Mdot
.38833 .41654 Mdot
.62313 .4119 Mdot
.38824 .63614 Mdot
.5486 .69259 Mdot
.3433 .56166 Mdot
.60007 .39457 Mdot
.77692 .5523 Mdot
.54164 .70895 Mdot
.38047 .42859 Mdot
.38356 .69704 Mdot
.37128 .60562 Mdot
.3899 .66876 Mdot
.79246 .47128 Mdot
.78931 .55291 Mdot
.69246 .54527 Mdot
.57918 .68772 Mdot
.71927 .54503 Mdot
.60244 .31806 Mdot
.3022 .36794 Mdot
.6555 .56907 Mdot
.39649 .64861 Mdot
.72685 .55436 Mdot
.35762 .37492 Mdot
.58263 .65572 Mdot
.64018 .55241 Mdot
.44605 .4138 Mdot
.25719 .47559 Mdot
.6044 .42583 Mdot
.63642 .26947 Mdot
.31019 .3584 Mdot
.41207 .39432 Mdot
.61963 .4068 Mdot
.38528 .41726 Mdot
.57823 .67121 Mdot
.36637 .30899 Mdot
.33912 .3571 Mdot
.76694 .55644 Mdot
.37421 .76356 Mdot
.67136 .57746 Mdot
.6504 .23855 Mdot
.43303 .4274 Mdot
.38405 .41215 Mdot
.27262 .48309 Mdot
.23169 .51499 Mdot
.54515 .7347 Mdot
.32315 .34747 Mdot
.75848 .56412 Mdot
.38499 .65503 Mdot
.37974 .61448 Mdot
.48933 .37162 Mdot
.62525 .41155 Mdot
.56934 .71817 Mdot
.38268 .40475 Mdot
.61649 .38665 Mdot
.33634 .39655 Mdot
.57226 .76503 Mdot
.79263 .55177 Mdot
.7143 .57922 Mdot
.37669 .60983 Mdot
.67737 .53534 Mdot
.27374 .48115 Mdot
.59613 .40444 Mdot
.79711 .55607 Mdot
.54971 .74414 Mdot
.63211 .29269 Mdot
.42023 .43585 Mdot
.4512 .29154 Mdot
.67555 .53504 Mdot
.68229 .5675 Mdot
.35927 .37604 Mdot
.33917 .72926 Mdot
.5874 .28847 Mdot
.55709 .67945 Mdot
.37657 .60039 Mdot
.39548 .50063 Mdot
.54355 .26333 Mdot
.57322 .70597 Mdot
.26054 .49247 Mdot
.66791 .53643 Mdot
.71642 .48371 Mdot
.38708 .65308 Mdot
.6314 .29454 Mdot
.44301 .41494 Mdot
.38348 .62498 Mdot
.7786 .56068 Mdot
.38483 .68324 Mdot
.61483 .41946 Mdot
.58325 .65678 Mdot
.66703 .55306 Mdot
.59051 .64447 Mdot
.38501 .70857 Mdot
.6147 .29556 Mdot
.49106 .34029 Mdot
.25013 .47234 Mdot
.34007 .56301 Mdot
.26167 .47863 Mdot
.58832 .43523 Mdot
.25866 .47751 Mdot
.37249 .59607 Mdot
.3794 .4123 Mdot
.38395 .38306 Mdot
.75378 .5582 Mdot
.40783 .43673 Mdot
.38972 .39175 Mdot
.36586 .36584 Mdot
.42612 .43248 Mdot
.41731 .42707 Mdot
.36787 .41624 Mdot
.35115 .66043 Mdot
.34772 .38879 Mdot
.35812 .70358 Mdot
.34531 .71815 Mdot
.7231 .57368 Mdot
.60377 .32888 Mdot
.64295 .30803 Mdot
.34274 .39019 Mdot
.45216 .29276 Mdot
.32021 .54917 Mdot
.38183 .65153 Mdot
.5438 .7137 Mdot
.34119 .36247 Mdot
.5892 .28177 Mdot
.34141 .38744 Mdot
.65521 .55921 Mdot
.66706 .57396 Mdot
.44877 .41674 Mdot
.55667 .16656 Mdot
.3813 .43343 Mdot
.30985 .36825 Mdot
.3897 .40668 Mdot
.36883 .41949 Mdot
.6522 .57668 Mdot
.48218 .31866 Mdot
.27738 .46351 Mdot
.36655 .58964 Mdot
.63501 .29389 Mdot
.6214 .42116 Mdot
.32552 .36304 Mdot
.37964 .50027 Mdot
.35983 .57471 Mdot
.27258 .4847 Mdot
.66348 .55972 Mdot
.3644 .67769 Mdot
.31249 .36801 Mdot
.5577 .68273 Mdot
.37292 .29 Mdot
.35591 .75148 Mdot
.56196 .67438 Mdot
.62913 .29272 Mdot
.65358 .54839 Mdot
.41491 .41287 Mdot
.71505 .56092 Mdot
.36465 .40621 Mdot
.2952 .3515 Mdot
.63208 .31408 Mdot
.39597 .64213 Mdot
.54499 .69242 Mdot
.35255 .66257 Mdot
.37353 .74889 Mdot
.41167 .32746 Mdot
.77561 .54161 Mdot
.64118 .5697 Mdot
.63541 .24426 Mdot
.37025 .69174 Mdot
.3826 .39113 Mdot
.27684 .53608 Mdot
.36264 .65714 Mdot
.38542 .60443 Mdot
.37035 .29376 Mdot
.47311 .29916 Mdot
.37017 .41801 Mdot
.38574 .62633 Mdot
.65361 .54719 Mdot
.63606 .31252 Mdot
.38273 .39337 Mdot
.59471 .4059 Mdot
.37851 .61404 Mdot
.67746 .5372 Mdot
.4862 .32657 Mdot
.69712 .56188 Mdot
.38396 .66644 Mdot
.67863 .57572 Mdot
.57202 .64946 Mdot
.65341 .56843 Mdot
.43788 .4365 Mdot
.38286 .40774 Mdot
.37423 .60102 Mdot
.36922 .67193 Mdot
.27751 .48965 Mdot
.43977 .42657 Mdot
.37145 .69492 Mdot
.73298 .54314 Mdot
.35707 .59094 Mdot
.27717 .48432 Mdot
.3999 .3946 Mdot
.62717 .27266 Mdot
.30871 .34412 Mdot
.35732 .30023 Mdot
.33494 .35327 Mdot
.61703 .29703 Mdot
.38913 .60165 Mdot
.38164 .40156 Mdot
.47861 .30932 Mdot
.76254 .56387 Mdot
.44163 .402 Mdot
.58983 .40549 Mdot
.28272 .46778 Mdot
.40617 .27548 Mdot
.26891 .49213 Mdot
.38907 .66283 Mdot
.38175 .67598 Mdot
.73997 .54869 Mdot
.38738 .64176 Mdot
.59125 .40675 Mdot
.56698 .71934 Mdot
.36914 .74554 Mdot
.63842 .39626 Mdot
.61108 .43364 Mdot
.58741 .42392 Mdot
.62725 .39605 Mdot
.59213 .27574 Mdot
.77474 .54901 Mdot
.60881 .43137 Mdot
.36278 .7033 Mdot
.6238 .59088 Mdot
.63832 .43954 Mdot
.56925 .71847 Mdot
.59869 .39833 Mdot
.43979 .40071 Mdot
.27052 .48803 Mdot
.33714 .68222 Mdot
.56114 .67897 Mdot
.58053 .42625 Mdot
.38687 .39188 Mdot
.37529 .60851 Mdot
.40235 .41583 Mdot
.60662 .27897 Mdot
.37106 .66031 Mdot
.67542 .56241 Mdot
.62803 .31593 Mdot
.61496 .39371 Mdot
.61608 .30836 Mdot
.71107 .5504 Mdot
.55062 .72507 Mdot
.44247 .41112 Mdot
.63441 .26362 Mdot
.60471 .32887 Mdot
.44136 .40338 Mdot
.37752 .68018 Mdot
.57896 .41993 Mdot
.40509 .39386 Mdot
.26867 .4809 Mdot
.34714 .68335 Mdot
.43696 .75995 Mdot
.41934 .41514 Mdot
.27664 .49506 Mdot
.36901 .59502 Mdot
.61892 .38809 Mdot
.68255 .56405 Mdot
.38693 .43055 Mdot
.56017 .6944 Mdot
.56805 .6794 Mdot
.77935 .56016 Mdot
.36489 .63314 Mdot
.68923 .53279 Mdot
.45163 .41416 Mdot
.60242 .39587 Mdot
.38095 .42188 Mdot
.74483 .53773 Mdot
.4062 .77292 Mdot
.35143 .70502 Mdot
.71099 .57783 Mdot
.34048 .40438 Mdot
.59366 .67918 Mdot
.76268 .55769 Mdot
.3685 .59219 Mdot
.36858 .63803 Mdot
.35235 .68608 Mdot
.64602 .29964 Mdot
.68625 .56103 Mdot
.33915 .6812 Mdot
.34114 .68884 Mdot
.27518 .4849 Mdot
.44911 .41435 Mdot
.38078 .60558 Mdot
.78471 .55707 Mdot
.63393 .28836 Mdot
.74894 .56672 Mdot
.61805 .23715 Mdot
.55276 .68314 Mdot
.38502 .37353 Mdot
.35056 .36974 Mdot
.53278 .15994 Mdot
.39905 .44144 Mdot
.39248 .40507 Mdot
.38373 .59614 Mdot
.60813 .26958 Mdot
.64368 .28843 Mdot
.3719 .69013 Mdot
.3503 .70632 Mdot
.61759 .31507 Mdot
.31861 .44564 Mdot
.42504 .28376 Mdot
.34392 .40345 Mdot
.39487 .65746 Mdot
.37275 .73999 Mdot
.5706 .68405 Mdot
.38034 .61866 Mdot
.63587 .64871 Mdot
.6376 .55853 Mdot
.64729 .56571 Mdot
.54406 .70537 Mdot
.41378 .41095 Mdot
.64304 .57369 Mdot
.26975 .46529 Mdot
.64089 .65315 Mdot
.25138 .48755 Mdot
.8232 .52874 Mdot
.44178 .42289 Mdot
.55837 .62315 Mdot
.58832 .77397 Mdot
.28005 .4838 Mdot
.33015 .47685 Mdot
.626 .3014 Mdot
.37579 .58681 Mdot
.58563 .67226 Mdot
.32315 .55012 Mdot
.38639 .41488 Mdot
.39096 .63103 Mdot
.55199 .67943 Mdot
.42637 .76214 Mdot
.27883 .46245 Mdot
.27337 .47013 Mdot
.27756 .53826 Mdot
.36581 .70904 Mdot
.68638 .56393 Mdot
.38038 .59553 Mdot
.3384 .69239 Mdot
.25437 .47988 Mdot
.6592 .53805 Mdot
.28213 .36385 Mdot
.39519 .64726 Mdot
.65553 .27945 Mdot
.37204 .64829 Mdot
.62216 .3142 Mdot
.33984 .67679 Mdot
.73064 .56967 Mdot
.42503 .42466 Mdot
.72779 .57223 Mdot
.60867 .282 Mdot
.68702 .57718 Mdot
.57847 .66902 Mdot
.61303 .40045 Mdot
.58026 .67555 Mdot
.29785 .36468 Mdot
.34529 .56178 Mdot
.56872 .7156 Mdot
.42889 .34105 Mdot
.3774 .41291 Mdot
.34026 .67547 Mdot
.66619 .55885 Mdot
.74366 .57082 Mdot
.30828 .35489 Mdot
.36785 .68331 Mdot
.73618 .55046 Mdot
.29432 .45977 Mdot
.64035 .63546 Mdot
.28356 .47441 Mdot
.63707 .76224 Mdot
.38159 .68355 Mdot
.75085 .56918 Mdot
.31262 .36983 Mdot
.34234 .70776 Mdot
.64071 .5581 Mdot
.54986 .71446 Mdot
.56049 .69471 Mdot
.42404 .44372 Mdot
.59132 .64541 Mdot
.65709 .55963 Mdot
.35138 .74817 Mdot
.34171 .67479 Mdot
.39787 .77415 Mdot
.61558 .30091 Mdot
.66891 .54068 Mdot
.60089 .40572 Mdot
.39086 .70117 Mdot
.72517 .54933 Mdot
.54462 .16089 Mdot
.83897 .43819 Mdot
.71293 .53873 Mdot
.37237 .65851 Mdot
.37465 .66961 Mdot
.24521 .49167 Mdot
.31128 .35637 Mdot
.67202 .55432 Mdot
.62966 .62473 Mdot
.32741 .41902 Mdot
.61665 .40079 Mdot
.80238 .55063 Mdot
.43774 .44464 Mdot
.26445 .47889 Mdot
.54879 .69623 Mdot
.41936 .41052 Mdot
.35419 .70983 Mdot
.38877 .43764 Mdot
.58314 .6736 Mdot
.74998 .54855 Mdot
.38528 .41538 Mdot
.62957 .29391 Mdot
.55425 .70255 Mdot
.55654 .69394 Mdot
.7071 .57453 Mdot
.3649 .63291 Mdot
.32678 .55364 Mdot
.68802 .56217 Mdot
.26331 .47171 Mdot
.61546 .40679 Mdot
.37489 .4234 Mdot
.39431 .62802 Mdot
.36614 .57693 Mdot
.6676 .54072 Mdot
.42509 .39535 Mdot
.57744 .69745 Mdot
.72157 .5402 Mdot
.25668 .49402 Mdot
.64639 .56189 Mdot
.64143 .39057 Mdot
.63425 .57095 Mdot
.36427 .72831 Mdot
.59377 .4335 Mdot
.39268 .63447 Mdot
.62323 .42857 Mdot
.75334 .47336 Mdot
.63006 .29063 Mdot
.65556 .57638 Mdot
.4011 .76841 Mdot
.71686 .57703 Mdot
.4283 .43045 Mdot
.37871 .39983 Mdot
.71252 .54746 Mdot
.61497 .29218 Mdot
.6339 .45446 Mdot
.61251 .26939 Mdot
.37264 .66333 Mdot
.27865 .46019 Mdot
.84432 .47179 Mdot
.69421 .58305 Mdot
.55916 .66737 Mdot
.35787 .58103 Mdot
.61646 .43335 Mdot
.57233 .67035 Mdot
.55449 .69704 Mdot
.60759 .29719 Mdot
.71061 .58076 Mdot
.38835 .61476 Mdot
.59066 .64934 Mdot
.34369 .70904 Mdot
.48364 .31426 Mdot
.62145 .39159 Mdot
.64162 .25159 Mdot
.63362 .4231 Mdot
.31241 .36314 Mdot
.59429 .66509 Mdot
.40577 .42364 Mdot
.5983 .29356 Mdot
.54573 .70196 Mdot
.62381 .2701 Mdot
.25829 .49329 Mdot
.74236 .55477 Mdot
.3113 .56573 Mdot
.42829 .44303 Mdot
.43551 .41744 Mdot
.54892 .68872 Mdot
.34176 .48662 Mdot
.3688 .58831 Mdot
.34337 .67402 Mdot
.69646 .54734 Mdot
.36129 .29624 Mdot
.36575 .41867 Mdot
.38706 .39306 Mdot
.71917 .55438 Mdot
.62746 .4122 Mdot
.79495 .54672 Mdot
.39727 .3953 Mdot
.57472 .68638 Mdot
.26418 .49237 Mdot
.59009 .68941 Mdot
.45114 .40811 Mdot
.42939 .4248 Mdot
.27128 .46719 Mdot
.25915 .48338 Mdot
.58028 .67599 Mdot
.6288 .40184 Mdot
.58865 .39876 Mdot
.39389 .65617 Mdot
.44533 .41877 Mdot
.32874 .42097 Mdot
.38432 .40433 Mdot
.62564 .30088 Mdot
.35099 .30116 Mdot
.36627 .3751 Mdot
.32243 .35191 Mdot
.32442 .41675 Mdot
.41172 .41731 Mdot
.55367 .6791 Mdot
.37509 .67186 Mdot
.57384 .70214 Mdot
.58693 .65096 Mdot
.7284 .55671 Mdot
.62663 .27075 Mdot
.39974 .43447 Mdot
.60407 .31191 Mdot
.4174 .44868 Mdot
.65979 .27166 Mdot
.32279 .36516 Mdot
.31354 .37211 Mdot
.65336 .282 Mdot
.37534 .40782 Mdot
.70308 .54642 Mdot
.64794 .58015 Mdot
.25448 .47197 Mdot
.44652 .42647 Mdot
.56487 .65873 Mdot
.55906 .72194 Mdot
.79038 .55019 Mdot
.65845 .58469 Mdot
.60613 .27926 Mdot
.61554 .47067 Mdot
.25717 .47922 Mdot
.40803 .44036 Mdot
.62532 .40055 Mdot
.697 .53718 Mdot
.61725 .43037 Mdot
.78226 .5497 Mdot
.58794 .67335 Mdot
.56029 .71125 Mdot
.44193 .42732 Mdot
.59406 .18519 Mdot
.36163 .65436 Mdot
.3737 .67139 Mdot
.56155 .72432 Mdot
.67063 .57751 Mdot
.61048 .4215 Mdot
.29005 .53878 Mdot
.36075 .58317 Mdot
.60104 .31966 Mdot
.38435 .42639 Mdot
.63822 .56436 Mdot
.36958 .7016 Mdot
.60498 .28361 Mdot
.33807 .35421 Mdot
.66998 .53104 Mdot
.39775 .41881 Mdot
.28839 .48435 Mdot
.36242 .69446 Mdot
.31724 .35773 Mdot
.39594 .64488 Mdot
.56654 .68325 Mdot
.59215 .66045 Mdot
.43146 .42273 Mdot
.31085 .55999 Mdot
.35865 .72646 Mdot
.5927 .65581 Mdot
.64992 .29329 Mdot
.60709 .40329 Mdot
.62415 .27054 Mdot
.69126 .54146 Mdot
.63016 .29166 Mdot
.72799 .55187 Mdot
.76063 .5593 Mdot
.38468 .61285 Mdot
.61967 .28796 Mdot
.38411 .36971 Mdot
.59609 .40641 Mdot
.63773 .31574 Mdot
.3324 .36343 Mdot
.26964 .49525 Mdot
.67129 .54823 Mdot
.60287 .31048 Mdot
.38218 .4282 Mdot
.4639 .71999 Mdot
.58397 .65443 Mdot
.58076 .66928 Mdot
.61444 .42041 Mdot
.66112 .54431 Mdot
.3905 .61603 Mdot
.33441 .39853 Mdot
.3691 .72652 Mdot
.39753 .39139 Mdot
.40921 .43453 Mdot
.36192 .73103 Mdot
.39051 .61564 Mdot
.42962 .42012 Mdot
.47898 .40408 Mdot
.60191 .40181 Mdot
.5618 .68699 Mdot
.37051 .66487 Mdot
.3636 .67402 Mdot
.66935 .5665 Mdot
.37844 .61178 Mdot
.61269 .25262 Mdot
.58357 .66907 Mdot
.60026 .38642 Mdot
.57887 .69153 Mdot
.65817 .42702 Mdot
.71596 .54076 Mdot
.41966 .761 Mdot
.35397 .64681 Mdot
.277 .47832 Mdot
.38172 .60651 Mdot
.61337 .30224 Mdot
.38365 .62718 Mdot
.38451 .61891 Mdot
.44666 .412 Mdot
.62342 .39728 Mdot
.60356 .42822 Mdot
.31709 .36528 Mdot
.36261 .65434 Mdot
.41918 .42175 Mdot
.3366 .36 Mdot
.43969 .42011 Mdot
.31633 .35869 Mdot
.35209 .65525 Mdot
.37742 .50029 Mdot
.3782 .60509 Mdot
.3647 .69579 Mdot
.61674 .23662 Mdot
.59298 .41114 Mdot
.62467 .43019 Mdot
.56833 .64373 Mdot
.41028 .39626 Mdot
.75124 .5615 Mdot
.2636 .4734 Mdot
.61115 .39584 Mdot
.33397 .34676 Mdot
.60956 .32718 Mdot
.36499 .40409 Mdot
.6247 .40482 Mdot
.67045 .55986 Mdot
.27633 .47818 Mdot
.38859 .39697 Mdot
.62499 .41983 Mdot
.38468 .60921 Mdot
.35057 .67737 Mdot
.35355 .57523 Mdot
.61254 .30987 Mdot
.58477 .68387 Mdot
.26442 .47546 Mdot
.69805 .54619 Mdot
.74592 .56367 Mdot
.39298 .6336 Mdot
.69285 .57183 Mdot
.5579 .71067 Mdot
.39986 .39863 Mdot
.57139 .67867 Mdot
.61119 .32361 Mdot
.37007 .66141 Mdot
.27154 .47805 Mdot
.24061 .48497 Mdot
.38165 .67622 Mdot
.60195 .3995 Mdot
.63145 .27178 Mdot
.71375 .56903 Mdot
.35144 .70205 Mdot
.58669 .67978 Mdot
.67322 .56908 Mdot
.27533 .47163 Mdot
.63301 .21839 Mdot
.42075 .41153 Mdot
.43313 .43517 Mdot
.39777 .68571 Mdot
.41689 .3891 Mdot
.72105 .57398 Mdot
.3939 .61835 Mdot
.27594 .48902 Mdot
.29202 .3627 Mdot
.63703 .32477 Mdot
.64648 .38425 Mdot
.40367 .41281 Mdot
.35034 .35827 Mdot
.3573 .38405 Mdot
.39081 .76884 Mdot
.31397 .3551 Mdot
.74314 .54144 Mdot
.64012 .24896 Mdot
.58679 .64788 Mdot
.62112 .40607 Mdot
.73026 .56179 Mdot
.47522 .41164 Mdot
.42434 .41247 Mdot
.34227 .57773 Mdot
.26317 .49493 Mdot
.5679 .70998 Mdot
.36033 .49427 Mdot
.66411 .56062 Mdot
.80768 .54861 Mdot
.45207 .41626 Mdot
.36569 .58434 Mdot
.51909 .64545 Mdot
.62145 .39897 Mdot
.62893 .42832 Mdot
.60514 .28522 Mdot
.7443 .54762 Mdot
.63604 .43386 Mdot
.57692 .69706 Mdot
.39473 .43837 Mdot
.37035 .37493 Mdot
.44665 .75123 Mdot
.37549 .69383 Mdot
.57352 .65539 Mdot
.66178 .41542 Mdot
.4055 .42794 Mdot
.35979 .65037 Mdot
.387 .65239 Mdot
.60275 .32547 Mdot
.77052 .55217 Mdot
.77054 .56089 Mdot
.56547 .1717 Mdot
.58361 .42757 Mdot
.70032 .53871 Mdot
.62223 .43813 Mdot
.2655 .47012 Mdot
.32623 .36384 Mdot
.58459 .64906 Mdot
.43017 .43123 Mdot
.33995 .56967 Mdot
.39095 .6622 Mdot
.38639 .40657 Mdot
.63787 .29152 Mdot
.23401 .51783 Mdot
.25582 .46623 Mdot
.47849 .39989 Mdot
.65381 .54677 Mdot
.41379 .43328 Mdot
.61106 .25332 Mdot
.61896 .38668 Mdot
.42957 .39416 Mdot
.68321 .56328 Mdot
.59343 .43309 Mdot
.63988 .28927 Mdot
.39089 .66844 Mdot
.62024 .40754 Mdot
.2588 .49503 Mdot
.36848 .41374 Mdot
.65066 .29086 Mdot
.27011 .46905 Mdot
.37584 .74119 Mdot
.63865 .42084 Mdot
.64906 .56846 Mdot
.34611 .70086 Mdot
.41848 .43066 Mdot
.60704 .40197 Mdot
.38578 .42565 Mdot
.37542 .75183 Mdot
.42205 .43778 Mdot
.45412 .73227 Mdot
.37359 .68114 Mdot
.56782 .6983 Mdot
.27189 .48366 Mdot
.39632 .41985 Mdot
.61145 .4386 Mdot
.6071 .42204 Mdot
.38406 .39162 Mdot
.39337 .63673 Mdot
.3877 .63346 Mdot
.36397 .58026 Mdot
.66227 .56679 Mdot
.34787 .40734 Mdot
.56745 .69261 Mdot
.62797 .40302 Mdot
.59229 .64828 Mdot
.35156 .36074 Mdot
.61614 .31064 Mdot
.44748 .74594 Mdot
.41062 .40054 Mdot
.36502 .6839 Mdot
.42855 .28626 Mdot
.37437 .63003 Mdot
.56417 .64768 Mdot
.57193 .65563 Mdot
.36372 .66131 Mdot
.4026 .41045 Mdot
.30972 .36263 Mdot
.37712 .37519 Mdot
.59363 .66872 Mdot
.59266 .39457 Mdot
.60952 .35791 Mdot
.64459 .5505 Mdot
.63873 .224 Mdot
.54049 .71309 Mdot
.58615 .77625 Mdot
.27724 .48427 Mdot
.34557 .68751 Mdot
.58669 .68807 Mdot
.55683 .68987 Mdot
.65985 .55576 Mdot
.27568 .48282 Mdot
.39272 .41692 Mdot
.58962 .40865 Mdot
.54621 .72402 Mdot
.36812 .39482 Mdot
.279 .48901 Mdot
.78886 .54786 Mdot
.37135 .58449 Mdot
.43266 .7641 Mdot
.34715 .35855 Mdot
.33931 .56312 Mdot
.63874 .61764 Mdot
.34049 .6775 Mdot
.41751 .42285 Mdot
.60427 .41334 Mdot
.68813 .57317 Mdot
.40353 .40198 Mdot
.70802 .57889 Mdot
.57695 .70286 Mdot
.46107 .72697 Mdot
.35848 .36886 Mdot
.64023 .65099 Mdot
.42535 .42111 Mdot
.24673 .47617 Mdot
.62866 .28283 Mdot
.58966 .68485 Mdot
.36075 .59272 Mdot
.39167 .43396 Mdot
.68493 .5666 Mdot
.64326 .54972 Mdot
.39213 .64987 Mdot
.35538 .57737 Mdot
.41104 .76591 Mdot
.59948 .40744 Mdot
.70455 .56781 Mdot
.60532 .40209 Mdot
.47989 .39739 Mdot
.59116 .64925 Mdot
.64046 .28944 Mdot
.68063 .57533 Mdot
.54257 .72998 Mdot
.26971 .49536 Mdot
.37468 .64037 Mdot
.39307 .69923 Mdot
.26247 .46592 Mdot
.74023 .55281 Mdot
.62914 .30847 Mdot
.32267 .35628 Mdot
.27265 .46053 Mdot
.63282 .3103 Mdot
.65994 .56284 Mdot
.35578 .66675 Mdot
.38686 .66221 Mdot
.37689 .67049 Mdot
.3837 .37306 Mdot
.36597 .57524 Mdot
.49388 .35269 Mdot
.39639 .38447 Mdot
.35428 .74433 Mdot
.37974 .38584 Mdot
.58167 .6698 Mdot
.36127 .69252 Mdot
.31685 .35828 Mdot
.28596 .46811 Mdot
.46306 .43005 Mdot
.43345 .40546 Mdot
.25724 .4856 Mdot
.40993 .39604 Mdot
.36666 .7358 Mdot
.37159 .5822 Mdot
.32277 .3531 Mdot
.58331 .66461 Mdot
.61998 .3066 Mdot
.33809 .69662 Mdot
.40912 .43289 Mdot
.36964 .73963 Mdot
.33027 .35909 Mdot
.45712 .72723 Mdot
.25556 .48654 Mdot
.75078 .54762 Mdot
.38736 .43475 Mdot
.63422 .56481 Mdot
.243 .47741 Mdot
.37228 .74224 Mdot
.58122 .65578 Mdot
.25416 .46686 Mdot
.63396 .55193 Mdot
.36441 .49563 Mdot
.6007 .41388 Mdot
.63274 .28627 Mdot
.59364 .432 Mdot
.57988 .67387 Mdot
.41863 .4054 Mdot
.36953 .41234 Mdot
.42187 .39017 Mdot
.48018 .39643 Mdot
.59375 .40914 Mdot
.65475 .28642 Mdot
.36673 .74535 Mdot
.36928 .40194 Mdot
.64399 .57613 Mdot
.34579 .67605 Mdot
.46537 .42677 Mdot
.40604 .37402 Mdot
.26557 .4996 Mdot
.36375 .65506 Mdot
.36608 .6313 Mdot
.58824 .28458 Mdot
.6224 .29296 Mdot
.43616 .42312 Mdot
.65229 .27465 Mdot
.26689 .47509 Mdot
.5809 .68354 Mdot
.37891 .38217 Mdot
.71825 .54145 Mdot
.30145 .35567 Mdot
.65905 .56384 Mdot
.43801 .41417 Mdot
.3732 .6483 Mdot
.59236 .66784 Mdot
.76586 .56382 Mdot
.79003 .5576 Mdot
.49522 .34804 Mdot
.77569 .56424 Mdot
.60793 .30765 Mdot
.6092 .30056 Mdot
.58963 .68161 Mdot
.3954 .40638 Mdot
.31033 .35249 Mdot
.2438 .5122 Mdot
.41728 .40011 Mdot
.41126 .40935 Mdot
.5471 .74214 Mdot
.54275 .70893 Mdot
.67237 .57586 Mdot
.42881 .41795 Mdot
.36359 .39949 Mdot
.36896 .65501 Mdot
.60556 .27474 Mdot
.72512 .56083 Mdot
.60607 .28175 Mdot
.70962 .55762 Mdot
.40744 .27545 Mdot
.61486 .39083 Mdot
.61068 .30611 Mdot
.53998 .7086 Mdot
.36249 .68343 Mdot
.59205 .40796 Mdot
.6817 .5478 Mdot
.69948 .5699 Mdot
.42672 .44728 Mdot
.3766 .6937 Mdot
.3436 .67263 Mdot
.61516 .3127 Mdot
.55874 .7236 Mdot
.269 .46514 Mdot
.63304 .42389 Mdot
.65851 .38155 Mdot
.68921 .56884 Mdot
.35677 .75038 Mdot
.39343 .69499 Mdot
.39974 .4302 Mdot
.35131 .67638 Mdot
.39419 .42337 Mdot
.38138 .59696 Mdot
.34433 .71572 Mdot
.45189 .40881 Mdot
.35224 .57135 Mdot
.70569 .53962 Mdot
.83754 .49609 Mdot
.28257 .48256 Mdot
.53666 .71702 Mdot
.26483 .47256 Mdot
.79952 .54703 Mdot
.43258 .287 Mdot
.37168 .40359 Mdot
.40988 .43378 Mdot
.59476 .1977 Mdot
.34917 .38722 Mdot
.62655 .42521 Mdot
.59993 .41358 Mdot
.35272 .66925 Mdot
.59486 .4319 Mdot
.3127 .36192 Mdot
.61852 .28381 Mdot
.69527 .54681 Mdot
.47561 .30708 Mdot
.62307 .31239 Mdot
.38831 .66739 Mdot
.27707 .46418 Mdot
.34619 .73241 Mdot
.63831 .57568 Mdot
.62324 .41511 Mdot
.57376 .70575 Mdot
.30306 .34351 Mdot
.67211 .56422 Mdot
.54555 .72805 Mdot
.34229 .37053 Mdot
.75463 .54336 Mdot
.58291 .66579 Mdot
.84067 .4849 Mdot
.55256 .68901 Mdot
.56501 .72118 Mdot
.32574 .37176 Mdot
.61878 .28308 Mdot
.60165 .43745 Mdot
.65442 .26706 Mdot
.5758 .66037 Mdot
.80729 .54064 Mdot
.66069 .54706 Mdot
.2958 .35367 Mdot
.37646 .58542 Mdot
.59764 .39827 Mdot
.42193 .41627 Mdot
.54911 .69281 Mdot
.41353 .44826 Mdot
.59983 .43634 Mdot
.55972 .7064 Mdot
.24235 .47901 Mdot
.35111 .29871 Mdot
.60538 .408 Mdot
.59821 .42562 Mdot
.60221 .29643 Mdot
.77504 .55667 Mdot
.34703 .66257 Mdot
.6098 .32988 Mdot
.32637 .39867 Mdot
.43909 .42561 Mdot
.58127 .67643 Mdot
.62076 .40839 Mdot
.56393 .69287 Mdot
.63635 .28101 Mdot
.65041 .29665 Mdot
.38995 .66933 Mdot
.36477 .58179 Mdot
.64848 .41181 Mdot
.32283 .42543 Mdot
.36812 .38373 Mdot
.34379 .57733 Mdot
.36333 .63873 Mdot
.32874 .47411 Mdot
.63879 .27645 Mdot
.60112 .29739 Mdot
.24559 .47615 Mdot
.33208 .35596 Mdot
.26165 .48868 Mdot
.3471 .36319 Mdot
.74052 .51998 Mdot
.27318 .48106 Mdot
.71258 .56874 Mdot
.34527 .36109 Mdot
.56729 .7701 Mdot
.25051 .47635 Mdot
.39943 .43229 Mdot
.69665 .55767 Mdot
.43791 .40055 Mdot
.67754 .53846 Mdot
.4224 .42618 Mdot
.74542 .53718 Mdot
.69818 .54648 Mdot
.62621 .47442 Mdot
.39688 .323 Mdot
.62206 .42715 Mdot
.6457 .2905 Mdot
.63196 .26311 Mdot
.48749 .32863 Mdot
.35753 .6673 Mdot
.23598 .51553 Mdot
.40152 .43211 Mdot
.65862 .55435 Mdot
.57282 .70849 Mdot
.24235 .49501 Mdot
.43218 .43806 Mdot
.26101 .4692 Mdot
.37418 .63844 Mdot
.66161 .54187 Mdot
.63016 .2782 Mdot
.68456 .58125 Mdot
.79866 .5502 Mdot
.70705 .53804 Mdot
.48035 .38539 Mdot
.25574 .49819 Mdot
.61076 .25399 Mdot
.34845 .565 Mdot
.62249 .45227 Mdot
.38688 .63669 Mdot
.61869 .40513 Mdot
.61141 .28108 Mdot
.3629 .30703 Mdot
.34478 .67485 Mdot
.71869 .55428 Mdot
.39889 .41952 Mdot
.62905 .39936 Mdot
.65485 .26687 Mdot
.35122 .71083 Mdot
.6517 .2883 Mdot
.68866 .55046 Mdot
.61043 .40568 Mdot
.34959 .41177 Mdot
.39221 .50144 Mdot
.29195 .35337 Mdot
.39834 .42264 Mdot
.61839 .3146 Mdot
.37509 .69566 Mdot
.26069 .46875 Mdot
.54727 .70574 Mdot
.31111 .35706 Mdot
.42271 .41513 Mdot
.64237 .65037 Mdot
.37483 .64602 Mdot
.61591 .29874 Mdot
.55029 .69053 Mdot
.6237 .29363 Mdot
.62607 .42873 Mdot
.38136 .59834 Mdot
.6294 .42764 Mdot
.26423 .49419 Mdot
.58275 .69391 Mdot
.34407 .67246 Mdot
.78447 .54643 Mdot
.58071 .42203 Mdot
.70897 .54574 Mdot
.35973 .30686 Mdot
.39211 .64339 Mdot
.55994 .75345 Mdot
.686 .58111 Mdot
.56884 .73042 Mdot
.31044 .34711 Mdot
.555 .70696 Mdot
.40293 .43285 Mdot
.38071 .65869 Mdot
.59489 .67227 Mdot
.7867 .55805 Mdot
.3556 .36175 Mdot
.64035 .40534 Mdot
.37623 .40854 Mdot
.37974 .77051 Mdot
.58077 .76942 Mdot
.37479 .59859 Mdot
.53999 .7163 Mdot
.43167 .40958 Mdot
.5993 .40442 Mdot
.44633 .41895 Mdot
.57273 .66055 Mdot
.54557 .7409 Mdot
.74102 .56964 Mdot
.40448 .42186 Mdot
.62493 .29905 Mdot
.73874 .5572 Mdot
.65148 .54262 Mdot
.66452 .57444 Mdot
.36194 .59015 Mdot
.60505 .39143 Mdot
.59851 .40903 Mdot
.43967 .28811 Mdot
.56231 .69255 Mdot
.6232 .4265 Mdot
.36679 .40843 Mdot
.49256 .35158 Mdot
.37521 .67593 Mdot
.6865 .55389 Mdot
.43513 .41509 Mdot
.28424 .477 Mdot
.62078 .42245 Mdot
.68871 .56148 Mdot
.38651 .61269 Mdot
.6441 .58965 Mdot
.40511 .4011 Mdot
.27314 .48895 Mdot
.38093 .68203 Mdot
.38348 .74579 Mdot
.3354 .39435 Mdot
.39255 .4218 Mdot
.5681 .67905 Mdot
.42244 .71543 Mdot
.34414 .37697 Mdot
.38391 .53407 Mdot
.58985 .40097 Mdot
.59177 .57914 Mdot
.43243 .6733 Mdot
.23876 .50635 Mdot
.48708 .6013 Mdot
.26206 .38625 Mdot
.52128 .61599 Mdot
.73882 .50736 Mdot
.45276 .58763 Mdot
.83973 .46948 Mdot
.62419 .64778 Mdot
.277 .50072 Mdot
.53311 .18055 Mdot
.59523 .76223 Mdot
.47084 .65465 Mdot
.62704 .70071 Mdot
.58356 .47305 Mdot
.78414 .54457 Mdot
.76742 .54677 Mdot
.72837 .4983 Mdot
.43862 .44344 Mdot
.46964 .67569 Mdot
.30219 .46607 Mdot
.58816 .73547 Mdot
.69387 .52113 Mdot
.28144 .4596 Mdot
.57591 .22305 Mdot
.6115 .63278 Mdot
.5531 .32353 Mdot
.31406 .54076 Mdot
.653 .49364 Mdot
.30161 .43232 Mdot
.53021 .35756 Mdot
.23664 .50969 Mdot
.54954 .59041 Mdot
.60648 .64221 Mdot
.39896 .60193 Mdot
.61417 .62776 Mdot
.71793 .56077 Mdot
.37216 .70106 Mdot
.62799 .74011 Mdot
.57332 .26657 Mdot
.61648 .69821 Mdot
.48602 .60241 Mdot
.63197 .43396 Mdot
.59136 .57027 Mdot
.35435 .41304 Mdot
.36433 .62418 Mdot
.66207 .50772 Mdot
.71143 .5182 Mdot
.41262 .63975 Mdot
.64479 .53168 Mdot
.37473 .30949 Mdot
.47126 .65794 Mdot
.43034 .68255 Mdot
.59192 .47493 Mdot
.6287 .47614 Mdot
.36624 .63479 Mdot
.5414 .21888 Mdot
.53843 .44042 Mdot
.31943 .39663 Mdot
.64792 .52142 Mdot
.39947 .61848 Mdot
.32469 .55532 Mdot
.35381 .59063 Mdot
.8174 .5132 Mdot
.59105 .25475 Mdot
.76127 .5045 Mdot
.54552 .44045 Mdot
.62006 .67508 Mdot
.43863 .33969 Mdot
.5828 .6153 Mdot
.77788 .49826 Mdot
.39616 .73131 Mdot
.55918 .19569 Mdot
.54177 .52631 Mdot
.61092 .22636 Mdot
.42208 .66667 Mdot
.60155 .48328 Mdot
.41969 .59936 Mdot
.60558 .54907 Mdot
.3978 .28649 Mdot
.59388 .23267 Mdot
.4737 .67184 Mdot
.58426 .3794 Mdot
.59572 .75945 Mdot
.40677 .70799 Mdot
.69426 .5161 Mdot
.5846 .39398 Mdot
.45167 .48101 Mdot
.59973 .21455 Mdot
.49686 .59385 Mdot
.55342 .25634 Mdot
.66063 .49398 Mdot
.63724 .74184 Mdot
.65842 .53605 Mdot
.59851 .6739 Mdot
.56252 .30913 Mdot
.38295 .65488 Mdot
.82699 .50726 Mdot
.46815 .63154 Mdot
.51498 .64234 Mdot
.59404 .21354 Mdot
.81109 .52181 Mdot
.59819 .5328 Mdot
.61382 .47753 Mdot
.6042 .62783 Mdot
.55606 .60872 Mdot
.57096 .75354 Mdot
.63016 .37736 Mdot
.4246 .74206 Mdot
.55582 .30522 Mdot
.79474 .5224 Mdot
.55085 .17923 Mdot
.33136 .40549 Mdot
.52806 .38446 Mdot
.40334 .67263 Mdot
.48354 .52476 Mdot
.57843 .74659 Mdot
.61748 .22343 Mdot
.27712 .45662 Mdot
.40789 .73132 Mdot
.73499 .49863 Mdot
.45977 .41208 Mdot
.46723 .70912 Mdot
.63054 .71439 Mdot
.63894 .58399 Mdot
.41743 .6884 Mdot
.60835 .24849 Mdot
.44343 .3072 Mdot
.39343 .51411 Mdot
.67047 .52378 Mdot
.33106 .38581 Mdot
.41634 .51995 Mdot
.81142 .45153 Mdot
.47237 .69527 Mdot
.43743 .49072 Mdot
.39914 .68863 Mdot
.77534 .49599 Mdot
.74734 .50675 Mdot
.43968 .70817 Mdot
.65758 .39033 Mdot
.55773 .25943 Mdot
.42913 .52666 Mdot
.59447 .55451 Mdot
.2991 .46569 Mdot
.30548 .46008 Mdot
.67703 .49422 Mdot
.5171 .42723 Mdot
.58751 .35739 Mdot
.62981 .7069 Mdot
.34902 .57755 Mdot
.54382 .37007 Mdot
.3594 .54101 Mdot
.38068 .7345 Mdot
.4879 .47118 Mdot
.59085 .63581 Mdot
.48648 .45829 Mdot
.5812 .21827 Mdot
.7239 .57009 Mdot
.78251 .50227 Mdot
.61907 .69563 Mdot
.69862 .51941 Mdot
.5004 .65214 Mdot
.50099 .65304 Mdot
.5673 .33339 Mdot
.60941 .75759 Mdot
.61083 .4965 Mdot
.37004 .61145 Mdot
.48724 .63403 Mdot
.34535 .54899 Mdot
.45154 .36049 Mdot
.3945 .55861 Mdot
.63632 .27219 Mdot
.48128 .4374 Mdot
.41465 .69198 Mdot
.66125 .40906 Mdot
.46551 .37622 Mdot
.29171 .40479 Mdot
.63983 .3955 Mdot
.44753 .32632 Mdot
.41124 .27785 Mdot
.56725 .53919 Mdot
.79997 .50914 Mdot
.41622 .53898 Mdot
.45356 .32759 Mdot
.58446 .7428 Mdot
.24338 .51698 Mdot
.61491 .22266 Mdot
.58323 .31301 Mdot
.44197 .68614 Mdot
.43761 .71979 Mdot
.64015 .77651 Mdot
.55978 .75104 Mdot
.82125 .44683 Mdot
.61932 .69488 Mdot
.25117 .53239 Mdot
.71479 .57541 Mdot
.59287 .49851 Mdot
.41074 .5959 Mdot
.29017 .41198 Mdot
.58151 .23571 Mdot
.5749 .5563 Mdot
.6293 .32281 Mdot
.43865 .6388 Mdot
.39151 .52793 Mdot
.5623 .23289 Mdot
.55191 .21173 Mdot
.54812 .22206 Mdot
.62454 .74592 Mdot
.49775 .41481 Mdot
.58639 .20731 Mdot
.49473 .36588 Mdot
.54394 .48223 Mdot
.23976 .50384 Mdot
.30617 .3951 Mdot
.82721 .47548 Mdot
.54497 .42327 Mdot
.56327 .60636 Mdot
.4126 .64125 Mdot
.6067 .20715 Mdot
.43054 .2793 Mdot
.60858 .57903 Mdot
.54702 .33214 Mdot
.56833 .39939 Mdot
.54115 .3595 Mdot
.57278 .34163 Mdot
.51922 .59082 Mdot
.62994 .71378 Mdot
.62048 .20128 Mdot
.75453 .49035 Mdot
.60186 .72347 Mdot
.39091 .71952 Mdot
.82966 .48638 Mdot
.45878 .71049 Mdot
.60249 .67314 Mdot
.42698 .65284 Mdot
.30062 .50738 Mdot
.43481 .56288 Mdot
.55857 .59149 Mdot
.42853 .47716 Mdot
.55388 .38934 Mdot
.69668 .57682 Mdot
.79297 .47927 Mdot
.42738 .55341 Mdot
.53758 .478 Mdot
.4628 .32546 Mdot
.80665 .53316 Mdot
.54358 .56452 Mdot
.43624 .37405 Mdot
.41697 .53702 Mdot
.45887 .67398 Mdot
.46915 .70399 Mdot
.32779 .52272 Mdot
.36527 .38734 Mdot
.57872 .25581 Mdot
.83319 .44362 Mdot
.57397 .33245 Mdot
.45603 .69403 Mdot
.64609 .73558 Mdot
.62226 .64376 Mdot
.47397 .35241 Mdot
.28063 .37555 Mdot
.50463 .56604 Mdot
.26448 .36962 Mdot
.57368 .71824 Mdot
.32494 .55609 Mdot
.49062 .66028 Mdot
.48947 .36274 Mdot
.4155 .58046 Mdot
.50274 .64042 Mdot
.46302 .39033 Mdot
.40185 .69077 Mdot
.38561 .7566 Mdot
.77368 .4928 Mdot
.71864 .57155 Mdot
.64978 .37655 Mdot
.53276 .45322 Mdot
.5987 .28939 Mdot
.6071 .37161 Mdot
.59274 .54319 Mdot
.33737 .55078 Mdot
.6511 .73698 Mdot
.56959 .35944 Mdot
.83488 .49544 Mdot
.57467 .34182 Mdot
.75886 .50788 Mdot
.63871 .52828 Mdot
.42364 .30999 Mdot
.60781 .69377 Mdot
.62604 .66857 Mdot
.40154 .30043 Mdot
.77733 .52322 Mdot
.60132 .56865 Mdot
.36282 .62353 Mdot
.35852 .39119 Mdot
.42229 .28571 Mdot
.52819 .35866 Mdot
.42694 .32074 Mdot
.3537 .51606 Mdot
.39993 .64041 Mdot
.51651 .37998 Mdot
.61124 .59383 Mdot
.23925 .48265 Mdot
.43223 .72343 Mdot
.59594 .67746 Mdot
.39193 .71394 Mdot
.81148 .53551 Mdot
.64708 .75948 Mdot
.51642 .6279 Mdot
.47015 .36348 Mdot
.55089 .30182 Mdot
.47686 .36331 Mdot
.43751 .72496 Mdot
.30825 .50096 Mdot
.4963 .66703 Mdot
.41692 .64952 Mdot
.55654 .51132 Mdot
.57886 .62385 Mdot
.44853 .63549 Mdot
.40233 .69723 Mdot
.2949 .45382 Mdot
.57723 .28679 Mdot
.41523 .47942 Mdot
.53596 .5963 Mdot
.3304 .39434 Mdot
.46765 .53108 Mdot
.47369 .63213 Mdot
.47699 .32634 Mdot
.50695 .61273 Mdot
.54003 .22919 Mdot
.33123 .57058 Mdot
.58873 .60271 Mdot
.53025 .41099 Mdot
.48736 .3623 Mdot
.31501 .54076 Mdot
.40834 .70898 Mdot
.62926 .7067 Mdot
.42793 .46966 Mdot
.59359 .25585 Mdot
.53087 .51389 Mdot
.45535 .32479 Mdot
.44624 .50816 Mdot
.43872 .46638 Mdot
.63151 .38233 Mdot
.57009 .33947 Mdot
.59483 .58257 Mdot
.5277 .17771 Mdot
.7629 .52459 Mdot
.38334 .54678 Mdot
.42022 .6027 Mdot
.78474 .49373 Mdot
.44562 .61572 Mdot
.45984 .60018 Mdot
.43512 .53796 Mdot
.81647 .48753 Mdot
.57594 .57487 Mdot
.60632 .58826 Mdot
.39085 .75734 Mdot
.57223 .21209 Mdot
.54546 .6064 Mdot
.60178 .66455 Mdot
.53926 .40658 Mdot
.42674 .43832 Mdot
.37541 .5446 Mdot
.42493 .76117 Mdot
.48802 .49102 Mdot
.53432 .61829 Mdot
.84071 .4598 Mdot
.58034 .55306 Mdot
.41599 .5444 Mdot
.5316 .17483 Mdot
.53203 .16665 Mdot
.36488 .55419 Mdot
.62394 .22069 Mdot
.61092 .58726 Mdot
.44577 .71918 Mdot
.61535 .6459 Mdot
.43726 .34841 Mdot
.34288 .57401 Mdot
.58587 .27788 Mdot
.62813 .78243 Mdot
.58554 .74456 Mdot
.4257 .62808 Mdot
.61095 .23982 Mdot
.53772 .48859 Mdot
.60483 .50357 Mdot
.64124 .72795 Mdot
.78823 .54046 Mdot
.81075 .50885 Mdot
.33282 .51451 Mdot
.69179 .50482 Mdot
.69448 .48654 Mdot
.47861 .68392 Mdot
.83553 .48661 Mdot
.57234 .39955 Mdot
.23632 .51418 Mdot
.77564 .49753 Mdot
.40334 .7536 Mdot
.70151 .51569 Mdot
.47384 .62699 Mdot
.5879 .54809 Mdot
.49871 .46352 Mdot
.43254 .73617 Mdot
.62446 .736 Mdot
.56899 .50725 Mdot
.36503 .30186 Mdot
.39878 .71476 Mdot
.39765 .73522 Mdot
.28987 .5039 Mdot
.59313 .52689 Mdot
.53474 .20778 Mdot
.57014 .64837 Mdot
.39898 .31344 Mdot
.36387 .62358 Mdot
.49134 .32074 Mdot
.60782 .49789 Mdot
.33006 .34672 Mdot
.57547 .28925 Mdot
.61275 .4994 Mdot
.54391 .20684 Mdot
.83192 .51349 Mdot
.53817 .32274 Mdot
.58961 .61728 Mdot
.61024 .3682 Mdot
.82392 .47207 Mdot
.82112 .45857 Mdot
.54453 .19513 Mdot
.71894 .48883 Mdot
.39534 .29836 Mdot
.57437 .51925 Mdot
.44239 .35411 Mdot
.47394 .39015 Mdot
.78387 .49029 Mdot
.31367 .54526 Mdot
.53496 .35582 Mdot
.44951 .65795 Mdot
.78934 .52683 Mdot
.51188 .38989 Mdot
.49155 .32618 Mdot
.4741 .50066 Mdot
.62308 .4828 Mdot
.68017 .53204 Mdot
.58443 .18775 Mdot
.43911 .71132 Mdot
.55083 .36238 Mdot
.41359 .7289 Mdot
.38628 .71219 Mdot
.73031 .50756 Mdot
.43901 .66752 Mdot
.65939 .25061 Mdot
.64472 .51029 Mdot
.58802 .31757 Mdot
.60319 .5578 Mdot
.3882 .76992 Mdot
.45692 .40573 Mdot
.56864 .32502 Mdot
.54595 .3724 Mdot
.53859 .18899 Mdot
.52084 .3845 Mdot
.48045 .44377 Mdot
.53706 .21835 Mdot
.45262 .67174 Mdot
.4204 .32126 Mdot
.56535 .22643 Mdot
.38516 .58086 Mdot
.58948 .25601 Mdot
.55139 .71285 Mdot
.58102 .47493 Mdot
.41542 .76026 Mdot
.44409 .3345 Mdot
.43851 .3328 Mdot
.57303 .36216 Mdot
.59238 .7589 Mdot
.41304 .55879 Mdot
.42878 .52874 Mdot
.69702 .51809 Mdot
.43529 .3464 Mdot
.51936 .59852 Mdot
.55391 .17705 Mdot
.35659 .38887 Mdot
.73729 .47602 Mdot
.78988 .50538 Mdot
.6088 .6883 Mdot
.58599 .53414 Mdot
.40582 .76203 Mdot
.33497 .50604 Mdot
.44641 .29848 Mdot
.57397 .21486 Mdot
.58548 .5327 Mdot
.28217 .39135 Mdot
.32606 .47945 Mdot
.59011 .62899 Mdot
.60981 .73824 Mdot
.49432 .60281 Mdot
.56145 .46292 Mdot
.34076 .40145 Mdot
.75606 .50234 Mdot
.84148 .46611 Mdot
.53519 .20552 Mdot
.61382 .73362 Mdot
.44038 .32951 Mdot
.43491 .50619 Mdot
.55816 .41679 Mdot
.55093 .17448 Mdot
.78366 .54382 Mdot
.41385 .69246 Mdot
.77973 .52126 Mdot
.60042 .75313 Mdot
.59891 .49768 Mdot
.41737 .31296 Mdot
.54183 .22192 Mdot
.41247 .6038 Mdot
.55124 .52655 Mdot
.46191 .49489 Mdot
.29985 .34164 Mdot
.47929 .66551 Mdot
.30133 .51173 Mdot
.60483 .76843 Mdot
.53697 .1904 Mdot
.69429 .49367 Mdot
.41269 .48953 Mdot
.53415 .18365 Mdot
.39862 .63297 Mdot
.48128 .67207 Mdot
.63511 .74209 Mdot
.45698 .33194 Mdot
.65661 .53515 Mdot
.3638 .3943 Mdot
.37622 .29683 Mdot
.45112 .62949 Mdot
.5287 .3967 Mdot
.64497 .31457 Mdot
.39911 .70706 Mdot
.71236 .4949 Mdot
.39554 .70492 Mdot
.83625 .45973 Mdot
.51754 .58751 Mdot
.42911 .67743 Mdot
.31747 .4899 Mdot
.63578 .52951 Mdot
.4559 .67037 Mdot
.55191 .32605 Mdot
.30875 .39765 Mdot
.42962 .66375 Mdot
.42597 .67084 Mdot
.39301 .57364 Mdot
.58834 .71843 Mdot
.55901 .28852 Mdot
.80558 .51821 Mdot
.65736 .38069 Mdot
.37844 .57475 Mdot
.4436 .34404 Mdot
.59203 .54982 Mdot
.54745 .34927 Mdot
.71465 .57942 Mdot
.6305 .21082 Mdot
.27057 .52187 Mdot
.47717 .69251 Mdot
.51389 .55774 Mdot
.28686 .37636 Mdot
.43398 .33597 Mdot
.63678 .53502 Mdot
.59567 .53583 Mdot
.3947 .54129 Mdot
.39121 .68537 Mdot
.48892 .67993 Mdot
.64254 .27767 Mdot
.66087 .39794 Mdot
.60999 .71635 Mdot
.32211 .52721 Mdot
.7947 .50022 Mdot
.34458 .73605 Mdot
.6564 .41871 Mdot
.62336 .53297 Mdot
.48384 .38919 Mdot
.29971 .39699 Mdot
.6035 .19139 Mdot
.54401 .31302 Mdot
.39152 .67451 Mdot
.47071 .68964 Mdot
.67054 .50777 Mdot
.56642 .36049 Mdot
.55688 .54433 Mdot
.77799 .48882 Mdot
.46405 .46988 Mdot
.56073 .3479 Mdot
.43646 .65865 Mdot
.48931 .58799 Mdot
.78189 .51273 Mdot
.60188 .3549 Mdot
.79777 .52722 Mdot
.3521 .50714 Mdot
.54241 .4421 Mdot
.78086 .53658 Mdot
.4802 .4889 Mdot
.61335 .57658 Mdot
.23842 .48343 Mdot
.50221 .5705 Mdot
.81639 .48404 Mdot
.38429 .69589 Mdot
.57413 .46079 Mdot
.43458 .69083 Mdot
.5878 .74425 Mdot
.5544 .30785 Mdot
.46408 .6933 Mdot
.80086 .51904 Mdot
.44411 .35068 Mdot
.57003 .3856 Mdot
.32212 .54148 Mdot
.31904 .40361 Mdot
.62545 .43478 Mdot
.40502 .51067 Mdot
.57624 .40113 Mdot
.43829 .28417 Mdot
.46305 .38425 Mdot
.58649 .23645 Mdot
.41337 .28065 Mdot
.50118 .46372 Mdot
.60734 .4861 Mdot
.37208 .61655 Mdot
.6084 .21885 Mdot
.44032 .29895 Mdot
.42442 .745 Mdot
.80846 .50754 Mdot
.71309 .48207 Mdot
.53273 .18267 Mdot
.59652 .75677 Mdot
.51561 .45316 Mdot
.83796 .48433 Mdot
.53642 .51276 Mdot
.69527 .48545 Mdot
.60306 .55762 Mdot
.37879 .71277 Mdot
.58585 .21493 Mdot
.61378 .49275 Mdot
.49504 .47057 Mdot
.38216 .37707 Mdot
.4183 .64947 Mdot
.41701 .29194 Mdot
.45687 .35101 Mdot
.72135 .55924 Mdot
.28776 .3921 Mdot
.67586 .49595 Mdot
.3835 .57114 Mdot
.78905 .49959 Mdot
.7794 .48287 Mdot
.55027 .4214 Mdot
.62204 .61448 Mdot
.52926 .18572 Mdot
.49157 .43045 Mdot
.24475 .50749 Mdot
.39972 .69857 Mdot
.64847 .30929 Mdot
.73397 .48957 Mdot
.43254 .46796 Mdot
.30301 .42605 Mdot
.45626 .47741 Mdot
.58185 .28425 Mdot
.48193 .51462 Mdot
.57057 .6469 Mdot
.38581 .57874 Mdot
.4256 .74235 Mdot
.42544 .70602 Mdot
.59249 .76828 Mdot
.81474 .48243 Mdot
.51652 .62749 Mdot
.48688 .59753 Mdot
.49536 .45793 Mdot
.78947 .47511 Mdot
.60203 .73518 Mdot
.58939 .69359 Mdot
.33909 .55262 Mdot
.53504 .20027 Mdot
.38628 .72387 Mdot
.47814 .6231 Mdot
.55046 .58263 Mdot
.4817 .36668 Mdot
.5703 .75364 Mdot
.47362 .67813 Mdot
.41133 .67857 Mdot
.54796 .24465 Mdot
.56519 .59756 Mdot
.6081 .36108 Mdot
.76026 .51871 Mdot
.53272 .58323 Mdot
.78333 .48482 Mdot
.35059 .5883 Mdot
.54874 .22815 Mdot
.45998 .3276 Mdot
.57008 .41695 Mdot
.3735 .3897 Mdot
.44277 .63925 Mdot
.57122 .33876 Mdot
.55472 .54346 Mdot
.55729 .62024 Mdot
.41921 .70203 Mdot
.82316 .50838 Mdot
.65296 .41834 Mdot
.6509 .73383 Mdot
.61289 .48263 Mdot
.29546 .41208 Mdot
.28721 .40282 Mdot
.59561 .7068 Mdot
.59472 .55734 Mdot
.44572 .60378 Mdot
.55833 .46024 Mdot
.3362 .54087 Mdot
.58766 .32488 Mdot
.57911 .18524 Mdot
.40188 .6297 Mdot
.82404 .52302 Mdot
.36256 .56834 Mdot
.40648 .63806 Mdot
.69181 .49058 Mdot
.58951 .61194 Mdot
.51948 .43497 Mdot
.53424 .40148 Mdot
.34762 .72399 Mdot
.57311 .17931 Mdot
.53076 .62049 Mdot
.56203 .44985 Mdot
.67832 .51201 Mdot
.47681 .63824 Mdot
.63195 .63107 Mdot
.62371 .68306 Mdot
.82657 .50334 Mdot
.77806 .49816 Mdot
.62299 .63479 Mdot
.60814 .58662 Mdot
.55157 .61914 Mdot
.56047 .23465 Mdot
.61311 .48679 Mdot
.55577 .31726 Mdot
.61559 .7628 Mdot
.34226 .52739 Mdot
.40673 .27988 Mdot
.4435 .30618 Mdot
.31377 .39759 Mdot
.4246 .49482 Mdot
.54664 .2645 Mdot
.63014 .38947 Mdot
.65946 .38916 Mdot
.69543 .51334 Mdot
.55487 .17332 Mdot
.46128 .66342 Mdot
.64034 .42808 Mdot
.54702 .39446 Mdot
.56293 .59624 Mdot
.39412 .31186 Mdot
.43088 .53463 Mdot
.60103 .37043 Mdot
.5922 .63335 Mdot
.43149 .70795 Mdot
.58799 .26559 Mdot
.37944 .38967 Mdot
.25894 .37188 Mdot
.57399 .74519 Mdot
.63947 .54759 Mdot
.41924 .70785 Mdot
.59672 .19301 Mdot
.59164 .68784 Mdot
.64146 .71777 Mdot
.59982 .705 Mdot
.55483 .36084 Mdot
.64138 .75584 Mdot
.58229 .72301 Mdot
.84366 .47063 Mdot
.47908 .69289 Mdot
.41591 .49191 Mdot
.3957 .74054 Mdot
.4355 .28322 Mdot
.39249 .51732 Mdot
.63333 .37965 Mdot
.5768 .27538 Mdot
.42794 .33178 Mdot
.58002 .46955 Mdot
.54468 .25715 Mdot
.78104 .5158 Mdot
.76623 .5243 Mdot
.56775 .74428 Mdot
.42541 .63942 Mdot
.65072 .75777 Mdot
.66427 .51479 Mdot
.28046 .53044 Mdot
.54057 .31073 Mdot
.43251 .47792 Mdot
.55311 .53828 Mdot
.43048 .52214 Mdot
.57261 .22976 Mdot
.80391 .481 Mdot
.62519 .58455 Mdot
.63187 .57151 Mdot
.46205 .31568 Mdot
.55224 .41101 Mdot
.4209 .5693 Mdot
.5378 .33032 Mdot
.6337 .53486 Mdot
.61371 .49182 Mdot
.79009 .51198 Mdot
.44272 .63956 Mdot
.33053 .4078 Mdot
.53886 .19759 Mdot
.30688 .40938 Mdot
.80719 .53651 Mdot
.62304 .74919 Mdot
.69421 .51432 Mdot
.55739 .1762 Mdot
.4348 .60089 Mdot
.43867 .38395 Mdot
.5264 .18002 Mdot
.60899 .22815 Mdot
.55496 .61794 Mdot
.45791 .42169 Mdot
.84336 .47674 Mdot
.62183 .56506 Mdot
.56017 .37244 Mdot
.32299 .55493 Mdot
.74762 .52061 Mdot
.44732 .37021 Mdot
.44505 .46258 Mdot
.56353 .45799 Mdot
.39836 .64522 Mdot
.42667 .65022 Mdot
.65622 .49064 Mdot
.77413 .52216 Mdot
.31281 .52964 Mdot
.33136 .57092 Mdot
.34728 .50873 Mdot
.37215 .70256 Mdot
.5723 .29104 Mdot
.64768 .23252 Mdot
.30401 .54004 Mdot
.55291 .23746 Mdot
.26911 .35153 Mdot
.45977 .64195 Mdot
.3338 .55069 Mdot
.43018 .31496 Mdot
.67296 .49344 Mdot
.54421 .17014 Mdot
.34278 .54058 Mdot
.62729 .21055 Mdot
.58941 .27663 Mdot
.38738 .68104 Mdot
.37804 .55822 Mdot
.45043 .34486 Mdot
.53097 .60971 Mdot
.59868 .63092 Mdot
.69245 .51806 Mdot
.70984 .48706 Mdot
.63018 .50928 Mdot
.39952 .39052 Mdot
.41873 .52442 Mdot
.56515 .32747 Mdot
.59857 .49639 Mdot
.56553 .3196 Mdot
.37283 .51687 Mdot
.35791 .39453 Mdot
.52532 .17249 Mdot
.44306 .72179 Mdot
.46177 .36726 Mdot
.6466 .44206 Mdot
.63949 .42903 Mdot
.33468 .34801 Mdot
.57089 .72338 Mdot
.4881 .34945 Mdot
.73132 .51699 Mdot
.57308 .28026 Mdot
.37261 .57666 Mdot
.44379 .34044 Mdot
.6261 .64448 Mdot
.34535 .39774 Mdot
.44177 .3684 Mdot
.55893 .73077 Mdot
.70907 .50871 Mdot
.63885 .6214 Mdot
.5869 .74092 Mdot
.47604 .65762 Mdot
.35978 .30073 Mdot
.64482 .41173 Mdot
.7013 .50048 Mdot
.59686 .70361 Mdot
.57331 .74697 Mdot
.80033 .52034 Mdot
.46877 .45498 Mdot
.60799 .7479 Mdot
.6646 .48135 Mdot
.41995 .31945 Mdot
.4291 .51556 Mdot
.56175 .60958 Mdot
.30623 .50577 Mdot
.56503 .24752 Mdot
.63386 .36442 Mdot
.63672 .39396 Mdot
.30928 .48585 Mdot
.58131 .23983 Mdot
.58207 .70239 Mdot
.82975 .43792 Mdot
.59117 .61032 Mdot
.43537 .68772 Mdot
.31131 .45569 Mdot
.58024 .53731 Mdot
.27023 .45728 Mdot
.45841 .42068 Mdot
.31477 .43711 Mdot
.63915 .71619 Mdot
.5893 .53776 Mdot
.47828 .64748 Mdot
.50472 .62254 Mdot
.51726 .38717 Mdot
.27034 .45891 Mdot
.43512 .41172 Mdot
.62007 .38237 Mdot
.38594 .28991 Mdot
.62997 .37972 Mdot
.53648 .41738 Mdot
.63179 .70806 Mdot
.70571 .50296 Mdot
.76232 .52378 Mdot
.50379 .41915 Mdot
.57796 .22346 Mdot
.2367 .49582 Mdot
.54275 .3151 Mdot
.45728 .52452 Mdot
.62211 .73473 Mdot
.30486 .41058 Mdot
.54309 .17334 Mdot
.40447 .52425 Mdot
.64483 .26008 Mdot
.58369 .30858 Mdot
.55399 .33574 Mdot
.622 .6378 Mdot
.39317 .76101 Mdot
.69988 .5144 Mdot
.47376 .35703 Mdot
.4242 .71494 Mdot
.64505 .36861 Mdot
.57503 .35592 Mdot
.56699 .482 Mdot
.57909 .61297 Mdot
.30144 .5158 Mdot
.47843 .38513 Mdot
.73112 .54675 Mdot
.30837 .50133 Mdot
.42783 .4928 Mdot
.54601 .26645 Mdot
.24631 .50679 Mdot
.49062 .5516 Mdot
.41147 .51939 Mdot
.5398 .19133 Mdot
.72905 .54362 Mdot
.281 .38884 Mdot
.24673 .52189 Mdot
.63715 .7234 Mdot
.69301 .48228 Mdot
.53433 .20447 Mdot
.62621 .66931 Mdot
.55781 .45896 Mdot
.43489 .75799 Mdot
.42585 .5118 Mdot
.40702 .67872 Mdot
.60455 .71867 Mdot
.58129 .44274 Mdot
.45233 .4986 Mdot
.54359 .16204 Mdot
.56503 .34926 Mdot
.51554 .43946 Mdot
.28038 .53255 Mdot
.79049 .50951 Mdot
.2772 .39823 Mdot
.60953 .75251 Mdot
.57394 .29373 Mdot
.62524 .63203 Mdot
.8402 .48257 Mdot
.53422 .58954 Mdot
.35663 .59468 Mdot
.55021 .4109 Mdot
.42484 .71988 Mdot
.5835 .51852 Mdot
.32772 .56878 Mdot
.43199 .7227 Mdot
.53026 .35745 Mdot
.56839 .57266 Mdot
.34421 .7274 Mdot
.36586 .55854 Mdot
.52028 .56364 Mdot
.59728 .61227 Mdot
.47917 .6223 Mdot
.49356 .59634 Mdot
.59769 .73662 Mdot
.50763 .55205 Mdot
.44308 .72444 Mdot
.61616 .67291 Mdot
.37194 .51078 Mdot
.66725 .49034 Mdot
.52347 .39195 Mdot
.70379 .57816 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`2Yooooo`Co0000W?ooool001cooooo00?o0000ooooooooool0ZOooool8o`0009So
oooo000Looooo`03o`000?oooooooooo0:[ooooo2?l0002Gooooo`007?ooool00ol0003ooooooooo
o`2Yooooo`;o00001?ooool5o`0009Gooooo000Looooo`03o`000?oooooooooo0:Wooooo0_l00002
ooooo`;o00000_ooool5o`0009?ooooo000Looooo`03o`000?oooooooooo0:Oooooo1?l00002oooo
o`Go00000_ooool4o`00097ooooo000Looooo`03o`000?oooooooooo0:Oooooo1?l00002ooooo`Ko
00000oooool2o`00097ooooo000Looooo`03o`000?oooooooooo0:Oooooo1?l00004ooooo`Co0000
0oooool2o`000003ooooool0003o000008kooooo000Looooo`03o`000?oooooooooo0:Oooooo1Ol0
0003ooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`;o0000Roooool001cooooo00?o
0000ooooooooool0Z?ooool4o`0000cooooo0_l00002ooooo`?o0000R_ooool001cooooo00?o0000
ooooooooool0Z?ooool2o`000003ooooool0003o000000_ooooo1?l000000ooooooo0000o`00002:
ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o
0000ooooooooool0Zoooool3o`0000cooooo0_l00002ooooo`Co0000Qoooool00006oooooomgMgOo
V9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03
o`000?oooooooooo0:cooooo0ol00003ooooo`;o00002_ooool4o`0008Oooooo00000ooooooo410@
ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003ooooo
ooooo`2[ooooo`Co00000oooool2o`0000Wooooo0_l0002:ooooo`0000?oooooo`000?ooool00_oo
ool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0002Zooooo`?o00004?oo
ool2o`0000Oooooo0_l00021ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<
ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0Z_ooool2o`0001[ooooo0_l00021
ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0Z_ooool2o`000003ooooool0003o000000cooooo0_l00004oooo
o`;o0000Q_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonH
V9So410@00Kooooo00?o0000ooooooooool0Z_ooool2o`000004ooooool0003o0000ooooo`;o0000
1?ooool2o`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l000000_ooool3o`0007kooooo
00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006oooo
o`03o`000?oooooooooo0;3ooooo0_l00004ooooo`?o00000_ooool6o`0000?ooooo0_l00002oooo
o`Go0000O?ooool001cooooo00?o0000ooooooooool0Zoooool2o`0000[ooooo2_l00008ooooo`Co
0000O?ooool001cooooo00?o0000ooooooooool0Zoooool3o`0000_ooooo0_l00007ooooo`;o0000
0oooool5o`0007gooooo000Looooo`03o`000?oooooooooo0:cooooo1?l00007ooooo`?o00002?oo
ool7o`0000?ooooo0_l0001kooooo`007?ooool00ol0003oooooooooo`2/ooooo`Co00001?ooool2
o`000004ooooool0003o0000o`0000Wooooo1?l00005ooooo`;o0000Noooool001cooooo00?o0000
ooooooooool0[?ooool4o`0000Cooooo1?l0000:ooooo`?o0000Q?ooool001cooooo00?o0000oooo
ooooool0[?ooool4o`0000?ooooo0_l000000ooooooo0000o`000005ooooo`;o00000oooool2o`00
00_ooooo0_l0001hooooo`007?ooool00ol0003oooooooooo`2booooo`?o00001?ooool6o`0000Ko
oooo0_l000000ooooooo0000o`000005ooooo`;o0000N?ooool001cooooo00?o0000ooooooooool0
/?ooool4o`0000Gooooo1?l00006ooooo`Wo00000oooool3o`0007Oooooo000Looooo`03o`000?oo
oooooooo0;3ooooo0_l00007ooooo`;o00002?ooool9o`0000?ooooo1?l0001fooooo`007?ooool0
0ol0003oooooooooo`2^ooooo`;o00005?ooool2o`0000?ooooo1?l00003ooooo`?o0000M_ooool0
01cooooo00?o0000ooooooooool0[_ooool2o`0000Cooooo0_l0000<ooooo`Co00001Oooool3o`00
07_ooooo000Looooo`;o0000]Oooool2o`0000cooooo1?l00006ooooo`?o00000oooool2o`0007Go
oooo000Looooo`03o`000?oooooooooo0;cooooo0_l00005ooooo`;o00002?ooool2o`0000?ooooo
0_l0001eooooo`007?ooool00ol0003oooooooooo`2]ooooo`;o000000?oooooo`000?l000001_oo
ool2o`0000;ooooo0ol00002ooooo`Co00002_ooool2o`0007Sooooo000Looooo`03o`000?oooooo
oooo0:gooooo0_l000001?oooooo0000o`000?l00005ooooo`;o00000_ooool3o`000004ooooool0
003o0000o`0000[ooooo1?l000000ooooooo0000o`00001eooooo`007?ooool00ol0003ooooooooo
o`2]ooooo`?o000000?oooooo`000?l000003Oooool3o`000003ooooool0003o000000[o00000_oo
ool2o`0007Gooooo000Looooo`03o`000?oooooooooo0:gooooo0ol00006ooooo`;o00000oooool2
o`000003ooooool0003o000000?ooooo2ol00003ooooo`;o0000M_ooool001cooooo00?o0000oooo
ooooool0[_ooool2o`0000Kooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool;o`00
00Cooooo0_l0001fooooo`007?ooool00ol0003oooooooooo`32ooooo`go000000?oooooo`000?l0
00000ol0001dooooo`007?ooool00ol0003oooooooooo`20ooooo`?o0000:_ooool2o`0000Wooooo
0_l00002ooooo`?o000000?oooooo`000?l000003Ol000000ooooooo0000o`000003o`0007Cooooo
000Looooo`03o`000?oooooooooo07kooooo1_l00004ooooo`;o00008oooool2o`0000Wooooo0_l0
00000ooooooo0000o`00000Bo`000003ooooool0003o000000;o0000MOooool001cooooo00?o0000
ooooooooool0Noooool2o`000003ooooool0003o000000Go00000oooool4o`0002[ooooo0_l00003
ooooo`?o000000?oooooo`000?l000003_l000001?oooooo0000o`000?l0001fooooo`007?ooool0
0ol0003oooooooooo`1kooooo`;o00001_ooool:o`0000;ooooo0_l0000Uooooo`;o000000?ooooo
o`000?l000000ol000000ooooooo0000o`00000>o`000004ooooool0003o0000o`0007Kooooo000L
ooooo`03o`000?oooooooooo07Sooooo0_l00003ooooo`;o00001_ooool<o`00027ooooo0_l00003
ooooo`Ko00000_oooolDo`0007Kooooo000Looooo`03o`000?oooooooooo07;ooooo0_l000000ooo
oooo0000o`000005o`000003ooooool0003o000000Gooooo0_l00003ooooo`[o00007oooool2o`00
00;ooooo1?l000000ooooooo0000o`000002oooooaCo0000M_ooool001cooooo00?o0000oooooooo
ool0Koooool2o`000003ooooool0003o000000Go000000?oooooo`000?l000002?ooool2o`0000Go
oooo2?l0000Sooooo`?o00001_oooolEo`0007Gooooo000Looooo`03o`000?oooooooooo06oooooo
2Ol00005ooooo`;o00003_ooool8o`0002;ooooo0_l00004ooooo`oo000000?oooooo`000?l00000
1Ol0001eooooo`007?ooool2o`0006oooooo1_l00002ooooo`;o00001Oooool4o`0000[ooooo1?l0
0002ooooo`Oo00009Oooool?o`0000;ooooo1Ol0001fooooo`007?ooool00ol0003oooooooooo`1^
ooooo`Oo00002_ooool2o`0000[ooooo0_l00004ooooo`Oo00005oooool2o`0000kooooo4Ol00000
0ooooooo0000o`00001fooooo`007?ooool00ol0003oooooooooo`1`ooooo`Go00005oooool2o`00
00Cooooo0_l000000ooooooo0000o`000004o`0001Cooooo1?l0000;oooooaCo0000Moooool001co
oooo00?o0000ooooooooool0L?ooool5o`000003ooooool0003o000000kooooo0_l00004ooooo`;o
00001_ooool7o`00017ooooo0_l00002ooooo`Go00001Oooool2o`0000;ooooo5?l0001gooooo`00
7?ooool00ol0003oooooooooo`1cooooo`Go00001?ooool4o`0000Cooooo1?l0000<ooooo`;o0000
00?oooooo`000?l000000_l0000Aooooo`?o00001?ooool2o`0000Gooooo0ol00002oooooa;o0000
N?ooool001cooooo00?o0000ooooooooool0MOooool4o`0000?ooooo1?l00004ooooo`;o00000_oo
ool2o`0000Sooooo0_l00004ooooo`?o00004_ooool2o`0000_ooooo1Ol000000ooooooo0000o`00
000>o`0007Wooooo000Looooo`03o`000?oooooooooo07Oooooo0_l0000<ooooo`;o000000?ooooo
o`000?l000002?ooool2o`0000Cooooo0ol000000ooooooo0000o`00000?ooooo`;o00000_ooool2
o`000003ooooool0003o000000Gooooo4_l000000ooooooo0000o`00001iooooo`007?ooool00ol0
003oooooooooo`1kooooo`Co00001_ooool4o`0000oooooo0ol000000ooooooo0000o`00000=oooo
o`;o00001?ooool2o`000003ooooool0003o000000Gooooo0ol000000ooooooo0000o`00000;o`00
07gooooo000Looooo`03o`000?oooooooooo07_ooooo1_l00004ooooo`Co00001Oooool4o`000003
ooooool0003o000000;ooooo1ol0000=ooooo`;o00000oooool2o`0000?ooooo0_l00004ooooo`?o
00000_ooool=o`0007cooooo000Looooo`03o`000?oooooooooo07oooooo1Ol0000:ooooo`Oo0000
0_ooool2o`000003ooooool0003o000000;o00004_ooool2o`0000;ooooo0ol00004ooooo`;o0000
0oooool9o`0000;ooooo0_l0001looooo`007?ooool00ol0003oooooooooo`21ooooo`?o00000ooo
ool2o`0000;ooooo0_l00003ooooo`Co00001_ooool5o`0000cooooo0_l000000ooooooo0000o`00
0004ooooo`;o000000?oooooo`000?l000001oooool7o`0008;ooooo000Looooo`03o`000?oooooo
oooo08Oooooo0_l00002ooooo`Co00000_ooool2o`0000Wooooo0ol0000<ooooo`;o000000?ooooo
o`000?l000001Oooool4o`0000Gooooo0_l000000ooooooo0000o`000003o`0000?ooooo0_l0001n
ooooo`007?ooool00ol0003oooooooooo`26ooooo`;o000000?oooooo`000?l000001?l0000=oooo
o`?o00004Oooool2o`0000?ooooo0_l00007ooooo`;o00000_ooool5o`0000;ooooo0_l0001noooo
o`007?ooool00ol0003oooooooooo`1Iooooo`;o00000oooool2o`0000?ooooo0_l0000Qooooo`So
00003_ooool3o`00017ooooo0_l00003ooooo`?o00001_ooool2o`0000?ooooo1?l00022ooooo`00
7?ooool00ol0003oooooooooo`1Gooooo`Co00000_ooool8o`0002?ooooo0_l000001?oooooo0000
o`000?l0000>ooooo`?o00005_ooool4o`0000[ooooo0ol00023ooooo`007?ooool00ol0003ooooo
ooooo`1Gooooo`;o000000Coooooo`000?l0003ooooo3_l0000Oooooo`Co000000?oooooo`000?l0
00002oooool3o`0001?ooooo0_l00003ooooo`;o00002_ooool4o`0008;ooooo000Looooo`;o0000
F_ooool3o`000003ooooool0003o000000Co000000?oooooo`000?l000001ol0000Looooo`?o0000
00?oooooo`000?l000000_l0000:ooooo`Co00003oooool2o`0000;ooooo1?l0000?ooooo`;o0000
P_ooool001cooooo00?o0000ooooooooool0E?ooool2o`0000;ooooo2ol000000ooooooo0000o`00
0008o`0001_ooooo0ol000000ooooooo0000o`000002ooooo`;o00000oooool2o`0000?ooooo1?l0
000?ooooo`;o00001?ooool2o`0009?ooooo000Looooo`03o`000?oooooooooo05Cooooo0_l00000
1Ooooooo0000o`000?l0003ooooo01?o00007_ooool2o`0000?ooooo0_l00003ooooo`;o00001?oo
ool4o`0000[ooooo0_l0000;ooooo`;o00001oooool2o`0008Oooooo000Looooo`03o`000?oooooo
oooo05Oooooo0ol000000ooooooo0000o`00000?o`000003ooooool0003o000000;o00006oooool2
o`0000Sooooo0_l00004ooooo`Co00002?ooool6o`0000Oooooo1?l00002ooooo`;o00000oooool4
o`0008Gooooo000Looooo`03o`000?oooooooooo05Sooooo0_l000000ooooooo0000o`00000Eo`00
01gooooo0_l00006ooooo`;o00000_ooool4o`0000Wooooo0_l00002ooooo`;o000000Coooooo`00
0?l0003o00000_ooool4o`0000?ooooo0_l00005ooooo`;o0000QOooool001cooooo00?o0000oooo
ooooool0F?ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000004?l000000ooo
oooo0000o`00000Jooooo`;o00001?ooool4o`0000;ooooo1?l0000@ooooo`?o00000_ooool4o`00
00[ooooo0_l00006ooooo`;o0000OOooool001cooooo00?o0000ooooooooool0F?ooool2o`0000;o
oooo6_l00004ooooo`;o00000oooool2o`0000_ooooo0_l00004ooooo`;o000000?oooooo`000?l0
00000_ooool6o`0002?ooooo0_l00006ooooo`;o00000_ooool2o`0007Wooooo000Looooo`03o`00
0?oooooooooo053ooooo1?l00005oooooago000000?oooooo`000?l000002Ol0000:ooooo`Co0000
0_ooool2o`0000Gooooo1Ol0000?ooooo`?o00000_ooool2o`0000_ooooo1Ol00007ooooo`;o0000
00?oooooo`000?l00000NOooool001cooooo00?o0000ooooooooool0D?ooool4o`0000?ooooo1_l0
0005ooooob;o00000oooool2o`000003ooooool0003o000000;ooooo0_l0000;ooooo`?o00003ooo
ool3o`0000;ooooo0_l0000;ooooo`Co00002?ooool2o`0007cooooo000Looooo`03o`000?oooooo
oooo05Oooooo1?l00009ooooo`;o00000ooooolBo`0000;ooooo1ol00003ooooo`;o000000?ooooo
o`000?l000001oooool2o`0000Kooooo0ol0000Vooooo`;o00000oooool2o`0000Cooooo0_l0001h
ooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00001oooool2o`00017ooooo0_l00002oooo
o`?o00001?ooool3o`0000Gooooo0_l0000Booooo`;o00001_ooool3o`0000Kooooo0_l0000Doooo
o`;o00002?ooool2o`0000?ooooo0ol00003ooooo`;o000000?oooooo`000?l00000MOooool001co
oooo00?o0000ooooooooool0D?ooool2o`0001_ooooo4_l0000<ooooo`;o00001_ooool2o`0000Ko
oooo0ol00006ooooo`?o000000?oooooo`000?l000004?ooool2o`0000[ooooo0_l000001?oooooo
0000o`000?l00002ooooo`;o00000_ooool2o`0007Gooooo000Looooo`03o`000?oooooooooo057o
oooo0_l0000Eooooo`;o000000?oooooo`000?l000006?l00006ooooo`;o00001_ooool2o`0000?o
oooo1Ol00007ooooo`?o000000?oooooo`000?l000002oooool2o`0000Oooooo3Ol00003ooooo`?o
0000N?ooool001cooooo00?o0000ooooooooool0DOooool2o`0000Gooooo0_l0000>oooooaoo0000
3?ooool2o`000003ooooool0003o000000Co00001oooool3o`0000[ooooo0_l00003ooooo`;o0000
1?ooool2o`000003ooooool0003o000000_o00000_ooool4o`000003ooooool0003o000007Gooooo
00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@oooooooo
ool01?ooool00ol0003oooooooooo`1Hooooo`Co00003_ooool5o`000005ooooool0003o0000o`00
0?ooool05_l00009ooooo`;o000000Coooooo`000?l0003ooooo0ol00007ooooo`;o000000?ooooo
o`000?l000002?ooool2o`0000Sooooo5ol000000ooooooo0000o`00001eooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo05Sooooo1?l00002ooooo`Co00000_ooool2o`0000;ooooo1?l00005oooooa_o00002ooo
ool4o`0000_ooooo1?l00004ooooo`;o00002_oooolDo`0000;ooooo0_l0001gooooo`0000?ooooo
oa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`Go00001_ooool00ol0003oooooooooo`1F
ooooo`;o00001_ooool@o`0000?ooooo7_l00008ooooo`Co00003Oooool2o`0000Cooooo0_l00005
ooooo`?o000000?oooooo`000?l000004ol000001Ooooooo0000o`000?l0003ooooo00;o0000M?oo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?m4A4CogMgMooooool0
0007ooooo`?o0000E_ooool2o`0000;ooooo0_l00005ooooo`?o00000_ooool9o`000003ooooool0
003o000001Ko000000?oooooo`000?l000001?l00009ooooo`?o00003oooool2o`0000Wooooo7?l0
0002ooooo`;o0000M?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool0
1?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo05[ooooo0ol00007ooooo`_o000000?o
ooooo`000?l000007_l000000ooooooo0000o`000005ooooo`;o00004?ooool2o`0000_ooooo6Ol0
0003ooooo`;o0000M?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool0
0omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo05_ooooo0_l00003ooooo`;o00000_ooool2
o`000005ooooool0003o0000o`000?ooool01?l00002ooooob;o00001Oooool2o`00017ooooo0_l0
000:oooooa[o00000_ooool2o`0007Cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo
00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`1Kooooo`?o000000Coooooo`000?l0003o
00000oooool6o`0000;ooooo0ol000000ooooooo0000o`00000No`000003ooooool0003o000000?o
oooo0_l0000?ooooo`;o000000?oooooo`000?l000000_ooool3o`0000Gooooo6_l00002ooooo`;o
0000M?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06oooo
o`03o`000?oooooooooo05_ooooo0ol000000ooooooo0000o`000004ooooo`Ko00000_oooolTo`00
0003ooooool0003o000000;ooooo0ol00005ooooo`;o00002?ooool2o`0000Gooooo0ol00006oooo
oa[o000000?oooooo`000?l00000M?ooool001cooooo00?o0000ooooooooool0I?ooool5o`0000Ko
oooo0_l000000ooooooo0000o`00000Mo`0000Cooooo0ol00006ooooo`;o00002_ooool2o`0000Ko
oooo0_l000001?oooooo0000o`000?oooolMo`0007Cooooo000Looooo`03o`000?oooooooooo06Co
oooo1Ol00009ooooob7o00000_ooool2o`0000Wooooo0_l00008ooooo`;o00000oooool2o`000004
ooooool0003o0000ooooo`;o000000?oooooo`000?l000006ol0001dooooo`007?ooool00ol0003o
ooooooooo`1Uooooo`Co00002ooooolLo`000004ooooool0003o0000ooooo`?o00002Oooool2o`00
00_ooooo1?l00007oooooaKo00001Oooool2o`0007Cooooo000Looooo`03o`000?oooooooooo05oo
oooo0_l00004ooooo`?o00003_oooolJo`0000?ooooo0ol0000>ooooo`;o00001oooool2o`0000[o
oooo5?l000000ooooooo0000o`000002ooooo`;o0000MOooool001cooooo00?o0000ooooooooool0
Goooool2o`0000?ooooo1?l0000>oooooaWo00001?ooool2o`0000Oooooo0_l00006ooooo`;o0000
4?ooool2o`000003ooooool0003o000001Go00000_ooool2o`0007Gooooo000Looooo`03o`000?oo
oooooooo05gooooo0ol00004ooooo`Co00003_oooolIo`0000Cooooo0_l00007ooooo`;o00006?oo
ool2o`000004ooooool0003o0000oooooaCo000000?oooooo`000?l00000M_ooool001cooooo00?o
0000ooooooooool0GOooool3o`0000?ooooo1Ol0000@oooooaOo000000Coooooo`000?l0003o0000
4_ooool2o`0001?ooooo5Ol00002ooooo`;o0000M_ooool001cooooo00?o0000ooooooooool0Hooo
ool5o`00017ooooo6_l00006ooooo`;o00002Oooool3o`0001?ooooo5Ol0000kooooo`;o000000?o
ooooo`000?l00000>_ooool001cooooo00?o0000ooooooooool0I_ooool2o`0001?ooooo5_l00008
ooooo`;o00002Oooool2o`0000Gooooo1?l0000:ooooo`;o00001?oooolAo`0003Gooooo0_l00003
ooooo`;o000000?oooooo`000?l00000>_ooool001cooooo00?o0000ooooooooool0I?ooool2o`00
01Oooooo4_l00009ooooo`;o00004Oooool4o`0000[ooooo0_l00008ooooo`Co00000_ooool3o`00
00;ooooo0_l0000eooooo`;o00001?ooool2o`0003cooooo000Looooo`03o`000?oooooooooo06?o
oooo0ol0000Iooooo`oo00002_ooool2o`0002Sooooo1Ol00002ooooo`?o0000=oooool2o`0000;o
oooo0_l00002ooooo`;o0000??ooool001cooooo0_l0001Kooooo`;o000000?oooooo`000?l00000
1?ooool2o`0001gooooo2?l0000Yooooo`;o00003Oooool6o`0000;ooooo0_l000000ooooooo0000
o`00000dooooo`?o000000?oooooo`000?l000001Oooool2o`0003Wooooo000Looooo`03o`000?oo
oooooooo05[ooooo1Ol00002ooooo`;o000000?oooooo`000?l00000:oooool2o`0000;ooooo0_l0
000=ooooo`;o00000oooool2o`0000Sooooo0_l0000?ooooo`Co00000_ooool5o`0003Gooooo0_l0
0008ooooo`;o0000>Oooool001cooooo00?o0000ooooooooool0D_ooool6o`0000?ooooo0ol00003
ooooo`;o000000?oooooo`000?l00000:oooool2o`0000;ooooo0_l00003ooooo`;o000000?ooooo
o`000?l000001Oooool2o`0000?ooooo0_l00008ooooo`;o00005Oooool3o`0003[ooooo0_l00010
ooooo`007?ooool00ol0003oooooooooo`1Aooooo`[o000000?oooooo`000?l000000_ooool2o`00
00;ooooo0_l0000dooooo`;o000000?oooooo`000?l000004_ooool4o`0000;ooooo0_l0001>oooo
o`;o00000oooool3o`0003[ooooo000Looooo`03o`000?oooooooooo053ooooo2ol000000ooooooo
0000o`000002ooooo`;o00000_ooool2o`0002Oooooo0_l0000?ooooo`?o00004?ooool4o`0000;o
oooo0_l00007ooooo`;o0000B_ooool3o`0003[ooooo000Looooo`03o`000?oooooooooo04[ooooo
0_l000000ooooooo0000o`00000<o`000003ooooool0003o000000;o00001Oooool2o`0002;ooooo
1_l0000?ooooo`?o00004_ooool2o`0000_ooooo0_l0001<ooooo`;o0000>Oooool001cooooo00?o
0000ooooooooool0B_oooolAo`0000;ooooo0ol00005ooooo`?o00007oooool6o`0000Kooooo0_l0
0008ooooo`;o00006_ooool2o`0000Wooooo0_l00017ooooo`Co0000>?ooool001cooooo00?o0000
ooooooooool0BOoooolBo`0000_ooooo0ol0000Nooooo`;o00002_ooool2o`0000Kooooo1?l0000J
ooooo`?o00002?ooool2o`0002[ooooo0ol0000;ooooo`;o00002?ooool2o`0000?ooooo1?l0000h
ooooo`007?ooool00ol0003oooooooooo`19ooooo`;o000000?oooooo`000?l000003Ol0000<oooo
o`?o00007Oooool2o`0001;ooooo0_l0000Looooo`Go00002_ooool2o`0002;ooooo0_l00002oooo
o`?o00002_ooool3o`0000Sooooo0ol00003ooooo`;o0000>Oooool001cooooo00?o0000oooooooo
ool0Boooool@o`0000_ooooo1?l0000Iooooo`;o00000_ooool4o`0000Gooooo0_l0000Iooooo`;o
00003?ooool2o`000003ooooool0003o000000Kooooo0_l00002ooooo`;o00008_ooool2o`0000;o
oooo0_l0000;ooooo`?o00002Oooool2o`0000?ooooo0_l0000iooooo`007?ooool00ol0003ooooo
ooooo`18oooooa?o00002oooool6o`0001Oooooo0_l00004ooooo`;o00001?ooool3o`0001Wooooo
1?l00005ooooo`;o00002_ooool2o`000005ooooool0003o0000o`000?ooool00_l0000;ooooo`;o
000000?oooooo`000?l000001?ooool2o`0000Gooooo0_l0000Cooooo`;o00000oooool2o`000003
ooooool0003o000000;ooooo0_l00006ooooo`?o0000>Oooool001cooooo00?o0000ooooooooool0
B?oooolEo`0000Cooooo0_l00005ooooo`Co00008oooool2o`0001cooooo0_l00005ooooo`;o0000
2_ooool5o`0000;ooooo0_l0000;ooooo`;o000000?oooooo`000?l000001?ooool3o`000004oooo
ool0003o0000ooooo`?o00004_ooool4o`0000Cooooo0_l00002ooooo`;o00000oooool6o`0003Wo
oooo000Looooo`03o`000?oooooooooo04[ooooo4ol00004ooooo`;o00002?ooool4o`0001?ooooo
0_l0000Dooooo`;o00004Oooool2o`0001Gooooo0ol0000Iooooo`;o000000?oooooo`000?l00000
1Ol00003ooooo`;o00003?ooool4o`0000Sooooo0_l00003ooooo`Go0000>_ooool001cooooo00?o
0000ooooooooool0Aoooool2o`0000;ooooo4Ol00007ooooo`;o00001_ooool6o`00017ooooo0ol0
0005ooooo`;o00003?ooool2o`000003ooooool0003o000000kooooo0_l0000Fooooo`?o00002ooo
ool2o`0000;ooooo0_l00006ooooo`?o00000oooool2o`000003ooooool0003o000000?ooooo0_l0
0004ooooo`;o00001_ooool4o`0000Sooooo0_l00005ooooo`;o0000>oooool001cooooo00?o0000
ooooooooool0Aoooool2o`0000;ooooo3ol00009ooooo`;o00002_ooool6o`0000kooooo0_l00000
1Ooooooo0000o`000?l0003ooooo00;o00001_ooool2o`0000Oooooo0_l0000Wooooo`;o00002_oo
ool:o`0000?ooooo0ol00004ooooo`;o00002oooool2o`0000Gooooo0_l000000ooooooo0000o`00
000>ooooo`;o0000??ooool001cooooo00?o0000ooooooooool0BOooool@o`0001Kooooo1ol00007
ooooo`?o00001_ooool3o`0000Kooooo0_l000000ooooooo0000o`00000Yooooo`Co000000?ooooo
o`000?l000000_l0000:ooooo`;o000000?oooooo`000?l000000_ooool3o`0000Cooooo0_l00004
ooooo`;o00000oooool4o`0000_ooooo1Ol0000>ooooo`?o0000>oooool001cooooo0_l0001:oooo
oa3o00001oooool2o`0000oooooo3ol0000?ooooo`;o00001Oooool2o`0002Gooooo1?l000001?oo
oooo0000o`000?l0000Cooooo`;o00001_ooool2o`0000Oooooo1?l0000;ooooo`?o000000?ooooo
o`000?l000000_l0000<ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0BOooool3o`00
0003ooooool0003o000000[o000000?oooooo`000?l000001?ooool2o`0001;ooooo3?l0000Foooo
o`;o0000:Oooool4o`0001Sooooo0_l000001?oooooo0000o`000?l0000?ooooo`?o00001Oooool6
o`0000Wooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`1:ooooo`Wo000000?oooooo`00
0?l000001?ooool2o`0000;ooooo1?l00007ooooo`;o00001?ooool2o`0000Oooooo0_l000001?oo
oooo0000o`000?ooool2o`0000[ooooo0_l0000Yooooo`;o00002_ooool2o`00013ooooo0_l00000
0ooooooo0000o`000005ooooo`;o00000_ooool2o`0000Kooooo0_l000001?oooooo0000o`000?oo
ool2o`000004ooooool0003o0000o`0000Gooooo0_l000000ooooooo0000o`000004ooooo`;o0000
1?ooool4o`0003cooooo000Looooo`03o`000?oooooooooo04Wooooo1Ol00006ooooo`;o00002?oo
ool4o`0000Oooooo0_l00002ooooo`Co00001?ooool2o`0000Wooooo0_l00008ooooo`;o000000?o
ooooo`000?l000009_ooool2o`0001;ooooo0_l00003ooooo`;o00000oooool2o`000003ooooool0
003o000000_ooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o0000
2?ooool2o`000004ooooool0003o0000ooooo`?o00000_ooool5o`0003cooooo000Looooo`03o`00
0?oooooooooo04Sooooo1Ol0000Aooooo`;o00003Oooool2o`0000Kooooo0_l00005ooooo`;o0000
0_ooool2o`0000Gooooo0_l00004ooooo`;o00006_ooool3o`0000Gooooo0_l0000Fooooo`;o0000
0oooool2o`0000Wooooo0_l00003ooooo`;o00000oooool2o`0001Gooooo0_l000001?oooooo0000
o`000?ooool2o`0000;ooooo2Ol0000looooo`007?ooool00ol0003oooooooooo`18ooooo`Go0000
4Oooool2o`0000Sooooo0_l00005ooooo`;o00001?ooool2o`0000Gooooo0_l00009ooooo`?o0000
3oooool2o`0000kooooo0ol00005ooooo`;o00008Oooool2o`0000?ooooo0_l00003ooooo`Co0000
2?ooool2o`0000kooooo0_l000000ooooooo0000o`000007ooooo`;o00000_ooool2o`0003gooooo
000Looooo`03o`000?oooooooooo04Sooooo1Ol0000Aooooo`;o00002?ooool2o`0000Gooooo0_l0
0004ooooo`;o00001Oooool2o`0000Cooooo0ol00003ooooo`;o00003oooool2o`0001cooooo0_l0
00000ooooooo0000o`00000Hooooo`;o00001oooool5o`000003ooooool0003o000000Gooooo0_l0
00000ooooooo0000o`000004ooooo`;o00001Oooool2o`0000Cooooo1?l00015ooooo`007?ooool0
0ol0003oooooooooo`18ooooo`?o000000?oooooo`000?l000001_ooool2o`00017ooooo0_l0000I
ooooo`?o00000oooool2o`0002gooooo0_l000000ooooooo0000o`00000Cooooo`;o00003?ooool4
o`0000;ooooo0_l00008ooooo`Co00000_ooool2o`0000?ooooo0ol00003ooooo`So00000_ooool2
o`0003oooooo000Looooo`03o`000?oooooooooo04cooooo0_l00006ooooo`;o00004Oooool2o`00
01Oooooo0_l00002ooooo`;o00000_ooool2o`0000Oooooo0_l00006ooooo`;o00004Oooool2o`00
0003ooooool0003o000001kooooo0_l00005ooooo`;o00001_ooool2o`0000oooooo0_l00003oooo
o`?o000000Coooooo`000?l0003o00000oooool2o`0000Cooooo0_l00002ooooo`;o0000?oooool0
01cooooo00?o0000ooooooooool0B_ooool4o`0001Cooooo0_l000000ooooooo0000o`000004oooo
o`;o00003_ooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`0000Oooooo0_l00006oooo
o`;o00004Oooool2o`000003ooooool0003o000000cooooo0_l0000<ooooo`?o00002?ooool2o`00
01_ooooo1?l00006ooooo`Co00001oooool2o`0003oooooo000Looooo`03o`000?oooooooooo04[o
oooo0_l00002ooooo`Go00001?ooool2o`0000Wooooo0_l000000ooooooo0000o`000004ooooo`;o
00003_ooool2o`0000_ooooo0_l0000:ooooo`;o00009?ooool2o`000003ooooool0003o000000co
oooo1Ol00003ooooo`;o000000Coooooo`000?l0003ooooo0_l000001?oooooo0000o`000?l0000D
ooooo`Co00001_ooool4o`0000Gooooo1?l0000oooooo`007?ooool00ol0003oooooooooo`1>oooo
o`_o00008?ooool2o`0000gooooo0_l0000:ooooo`;o00009?ooool3o`0000;ooooo0_l00006oooo
o`;o000000Goooooo`000?l0003o0000ooooo`0=o`000003ooooool0003o000000Go00004_ooool4
o`0000Wooooo1_l00011ooooo`007?ooool00ol0003oooooooooo`1Booooo`[o00007Oooool2o`00
00Wooooo0_l00002ooooo`Co00009?ooool2o`0000Oooooo2?l00006ooooo`;o000000Coooooo`00
0?l0003o00000ooooolGo`0000Cooooo1ol00004ooooo`?o000000?oooooo`000?l000001_ooool6
o`00047ooooo000Looooo`03o`000?oooooooooo05Kooooo2ol000000ooooooo0000o`000003o`00
00;ooooo0_l000000ooooooo0000o`000003ooooo`;o00002Oooool2o`0000Gooooo0ol00004oooo
o`;o00009?ooool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l0000@oooo
ob?o00000oooool8o`0000Cooooo1_l00011ooooo`007?ooool00ol0003oooooooooo`1Jooooo`go
00000_ooool2o`000003ooooool0003o000000?ooooo0_l00003ooooo`;o00001?ooool2o`0000Go
oooo0_l0000[ooooo`?o000000?oooooo`000?l000001oooool2o`00013ooooo9?l00005ooooo`;o
000000Coooooo`000?l0003o00000oooool3o`000003ooooool0003o000004;ooooo000Looooo`03
o`000?oooooooooo05gooooo2?l0000Aooooo`;o000000?oooooo`000?l000002?ooool2o`0002_o
oooo0ol00008ooooo`Co00003OoooolWo`0000;ooooo0_l00003ooooo`[o0000AOooool001cooooo
0_l0001Pooooo`;o000000?oooooo`000?l000001?l000000ooooooo0000o`000003o`0000_ooooo
0_l00010ooooo`Co00000_ooool2o`0000Wooooo9ol00002oooooa3o0000A?ooool001cooooo00?o
0000ooooooooool0G_ooool@o`0000Gooooo0_l0000Booooo`;o00004oooool2o`0000?ooooo0_l0
000Fooooo`;o00000_ooool2o`0000;ooooo0_l00007ooooobSo00000_oooolAo`0004Cooooo000L
ooooo`03o`000?oooooooooo05kooooo1Ol000000ooooooo0000o`000006o`0000Oooooo0_l0000B
ooooo`;o00004oooool2o`0000?ooooo0_l0000Dooooo`Co00000_ooool2o`0000_ooooo3ol00000
0ooooooo0000o`00000Do`000003ooooool0003o0000013o0000A_ooool001cooooo00?o0000oooo
ooooool0H?ooool3o`000003ooooool0003o000000;o000000?oooooo`000?l000000_l00006oooo
o`;o00000_ooool2o`0000?ooooo0_l00004ooooo`;o00007oooool2o`0001;ooooo0_l00004oooo
o`;o000000?oooooo`000?l000002Oooool>o`000003ooooool0003o000001Co000000?oooooo`00
0?l000003_l00018ooooo`007?ooool00ol0003oooooooooo`1Qooooo`;o00001?ooool7o`0000Go
oooo0_l00002ooooo`;o00000oooool2o`0000Cooooo0_l00005ooooo`;o00006?ooool2o`0001_o
oooo0_l00006ooooo`;o000000?oooooo`000?l000008?l000000ooooooo0000o`00000?o`0004[o
oooo000Looooo`03o`000?oooooooooo067ooooo0_l00004ooooo`[o00006?ooool2o`0001Gooooo
0_l00003ooooo`;o00001_ooool2o`0001Oooooo=ol0001<ooooo`007?ooool00ol0003ooooooooo
o`1Qooooo`;o00001?ooool2o`000003ooooool0003o000000Go000000?oooooo`000?l000004Ooo
ool2o`0001Wooooo0_l00003ooooo`;o00001_ooool2o`00017ooooo0_l00004ooooo`;o00000_oo
ool;o`000003ooooool0003o0000017o000000?oooooo`000?l000003_l0001?ooooo`007?ooool0
0ol0003oooooooooo`1Wooooo`go00001Oooool2o`0000[ooooo0_l0000Hooooo`;o00005?ooool2
o`0000Gooooo0_l00002ooooo`;o00001ooooolYo`0005Oooooo000Looooo`03o`000?oooooooooo
06Sooooo0_l00002ooooo`Wo00000_ooool4o`000003ooooool0003o0000027ooooo0_l0000Doooo
o`Co00000oooool2o`0000_ooooo9ol0001Iooooo`007?ooool00ol0003oooooooooo`1[ooooo`ko
000000?oooooo`000?l000000_l0000iooooo`;o00002_ooool2o`0000Gooooo8ol000000ooooooo
0000o`00001Iooooo`007?ooool00ol0003oooooooooo`1[ooooo`co00000_ooool3o`0000Oooooo
0_l0000gooooo`;o00001?ooool3o`0000Gooooo3_l00002ooooo`Co000000?oooooo`000?l00000
2Ol0001Oooooo`007?ooool00ol0003oooooooooo`1Zooooo`;o00000_ooool:o`000003ooooool0
003o000000Sooooo0_l0000Tooooo`;o00001?ooool2o`0000_ooooo0ol00003ooooo`;o00000ooo
ool2o`0000?ooooo5?l00002ooooo`Co0000Hoooool001cooooo00?o0000ooooooooool0J_ooool2
o`0000;ooooo2ol0000Fooooo`;o00002_ooool2o`0000Oooooo0_l00003ooooo`;o00001?ooool2
o`0000cooooo0_l00003ooooo`?o00000_ooool2o`0000?ooooo0_l00004ooooo`;o00000_ooool6
o`0000;ooooo0_l0001Yooooo`007?ooool00ol0003oooooooooo`1^ooooo`_o00005_ooool2o`00
00[ooooo0_l00007ooooo`?o00000oooool2o`0000?ooooo0_l0000@ooooo`Co00000_ooool2o`00
00Cooooo0_l0001jooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool0
1Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0K_ooool<o`0002Cooooo0_l0
0005ooooo`;o00000oooool2o`0000?ooooo0_l000000ooooooo0000o`00000=ooooo`Co00000_oo
ool2o`0000Cooooo0_l0001jooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q
1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0L?ooool;o`0000Oo
oooo0_l0000Iooooo`?o00002_ooool2o`0000Kooooo0ol0000>ooooo`;o0000Q?ooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool0L?ooool2o`000003ooooool0003o000000Ko00001oooool2o`000003
ooooool0003o000000_ooooo0_l00006ooooo`;o000000?oooooo`000?l000001_ooool2o`0000?o
oooo0_l00007ooooo`?o0000Toooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
2Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0001fooooo`Oo000000?oooooo`000?l0
00001Oooool2o`0000;ooooo0_l00007ooooo`;o00001_ooool2o`000003ooooool0003o000000Ko
oooo0_l0000=ooooo`;o00001Oooool2o`0008cooooo00000ooooooo0000ooooo`02ooooo`03o`00
0?oooooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo07Co
oooo2Ol000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;o
oooo0_l0000;ooooo`;o000000?oooooo`000?l000003_ooool2o`0000Cooooo0_l00006ooooo`;o
00002_ooool2o`00083ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo
00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`1dooooo`So00001_ooool2o`0000Wooooo
0_l0000Jooooo`;o00000_ooool2o`0000;ooooo1?l0000Booooo`;o0000P?ooool00006oooooomg
MgOoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo07Co
oooo2Ol0000Tooooo`;o00001_ooool2o`0000Kooooo1?l00007ooooo`Co0000ROooool00006oooo
ooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooo
oooo07Cooooo2_l0000?ooooo`;o00004_ooool2o`0001Gooooo2?l00006ooooo`;o00001?ooool2
o`0007_ooooo000Looooo`03o`000?oooooooooo07Gooooo2ol0000=ooooo`;o00005oooool2o`00
00;ooooo0_l00004ooooo`;o00001_ooool6o`0000Sooooo0_l00004ooooo`;o0000Noooool001co
oooo00?o0000ooooooooool0MOooool;o`0002Kooooo0_l000001?oooooo0000o`000?l00003oooo
o`Co00002Oooool2o`0000[ooooo0_l00002ooooo`;o0000Noooool001cooooo00?o0000oooooooo
ool0L_ooool4o`0000;ooooo1ol0000Iooooo`;o00001_ooool2o`0000Oooooo0_l00004ooooo`Ko
00000oooool2o`0000kooooo0ol000000ooooooo0000o`00001kooooo`007?ooool00ol0003ooooo
ooooo`1booooo`Co00000_ooool8o`0000Oooooo0_l0000=ooooo`Co00001_ooool2o`0000;ooooo
0_l0000;ooooo`Co00000oooool2o`0000Kooooo0_l00002ooooo`;o00000oooool2o`000003oooo
ool0003o000007_ooooo000Looooo`03o`000?oooooooooo07?ooooo3_l00006ooooo`;o00001_oo
ool2o`0000Gooooo0_l0000<ooooo`;o00001?ooool2o`0000cooooo0_l00002ooooo`;o000000Co
ooooo`000?l0003o00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`00001kooooo`007?oo
ool00ol0003oooooooooo`1booooo`oo00003_ooool2o`0000?ooooo1?l00003ooooo`;o00003Ooo
ool2o`0000cooooo0ol000000ooooooo0000o`000003o`0000;ooooo0_l00002ooooo`Co000000Co
ooooo`000?l0003o0000N_ooool001cooooo00?o0000ooooooooool0L_ooool>o`0000kooooo0_l0
0004ooooo`Co00000oooool2o`0001_ooooo1ol00004ooooo`;o00000_ooool2o`000003ooooool0
003o000000?o0000N_ooool001cooooo00?o0000ooooooooool0LOoooolCo`0000;ooooo0_l00003
ooooo`Go00001oooool2o`0000Oooooo0_l0000Fooooo`Ko00002?ooool3o`000003ooooool0003o
000000;o0000Noooool001cooooo00?o0000ooooooooool0L?oooolDo`0000;ooooo0_l00003oooo
o`?o00001?ooool2o`0000?ooooo0_l00007ooooo`;o00000_ooool2o`0001;ooooo1_l00003oooo
o`;o00000oooool2o`0000Cooooo0_l0001kooooo`007?ooool00ol0003oooooooooo`1_oooooa7o
00000_ooool2o`0000kooooo0_l0000@ooooo`?o00003Oooool3o`0000?ooooo1?l00003ooooo`;o
000000?oooooo`000?l000001?l0001oooooo`007?ooool00ol0003oooooooooo`1_ooooo`[o0000
00?oooooo`000?l000001?l00004ooooo`;o00004_ooool2o`0000_ooooo0_l0000<ooooo`co0000
1Oooool6o`000004ooooool0003o0000o`0007_ooooo000Looooo`;o0000L?ooool@o`0000Gooooo
0_l000000ooooooo0000o`00000?ooooo`;o00001Oooool2o`0001;ooooo3Ol00007ooooo`;o0000
0_ooool4o`0007[ooooo000Looooo`03o`000?oooooooooo06oooooo4?l00008ooooo`;o00003?oo
ool2o`0000Sooooo0_l0000Booooo`go00003?ooool3o`0007[ooooo000Looooo`03o`000?oooooo
oooo06oooooo4?l0000;ooooo`;o00000_ooool2o`0000Gooooo1?l00006ooooo`;o000000?ooooo
o`000?l000003oooool<o`0000gooooo0_l0001kooooo`007?ooool00ol0003oooooooooo`1^oooo
oa7o00002oooool2o`0000;ooooo0_l00005ooooo`Co00000oooool2o`0000Cooooo0_l0000?oooo
o`co0000R_ooool001cooooo00?o0000ooooooooool0KOoooolAo`0000[ooooo0_l00008ooooo`;o
00002?ooool2o`0000;ooooo0_l0000@ooooo`go000000?oooooo`000?l00000Qoooool001cooooo
00?o0000ooooooooool0JooooolCo`0000Oooooo0_l000001?oooooo0000o`000?ooool2o`0000Go
oooo0_l00004ooooo`;o00000oooool5o`0000oooooo1_l000000ooooooo0000o`000005o`000003
ooooool0003o000008Oooooo000Looooo`03o`000?oooooooooo06_ooooo4_l00008ooooo`Co0000
0_ooool2o`0000?ooooo0_l00006ooooo`;o00000oooool4o`00013ooooo3_l00009ooooo`;o0000
Ooooool001cooooo00?o0000ooooooooool0K?oooolEo`0000Kooooo1?l00004ooooo`Co00000ooo
ool2o`000003ooooool0003o000001Gooooo4_l00002ooooo`;o00000_ooool2o`0007oooooo000L
ooooo`03o`000?oooooooooo06_ooooo3ol000000ooooooo0000o`000004o`0000Oooooo0ol00004
ooooo`Co00000_ooool3o`000003ooooool0003o000000;ooooo0_l0000@oooooa?o00000_ooool4
o`00087ooooo000Looooo`03o`000?oooooooooo06_ooooo4_l00003ooooo`Co00001?ooool2o`00
00_ooooo0ol00003ooooo`Co00004?oooolAo`0000Kooooo0_l00021ooooo`007?ooool00ol0003o
ooooooooo`1Zoooooa;o00001?ooool4o`0000Cooooo0_l0000<ooooo`;o00000oooool2o`00017o
oooo4Ol00008ooooo`;o0000P?ooool001cooooo00?o0000ooooooooool0J_oooolEo`0000Wooooo
0_l00002ooooo`;o00002_ooool2o`000003ooooool0003o0000017ooooo4?l00009ooooo`;o0000
P?ooool001cooooo00?o0000ooooooooool0J_ooool<o`000003ooooool0003o000000Oo00001?oo
ool2o`0000Cooooo1?l00007ooooo`;o000000?oooooo`000?l000005Oooool?o`0000Cooooo0_l0
0025ooooo`007?ooool00ol0003oooooooooo`1Yoooooa3o00001?ooool4o`0000;ooooo0ol00003
ooooo`?o00002Oooool5o`0001?ooooo4Ol00004ooooo`;o0000QOooool001cooooo00?o0000oooo
ooooool0JOoooolBo`000003ooooool0003o000000?o00000_ooool2o`0000Cooooo0_l00005oooo
o`;o000000Coooooo`000?l0003ooooo1?l0000Coooooa7o00001?ooool2o`000003ooooool0003o
000008;ooooo000Looooo`03o`000?oooooooooo06[ooooo4Ol000000ooooooo0000o`000003o`00
00oooooo0_l000001?oooooo0000o`000?ooool2o`0001Gooooo4Ol00004ooooo`Go0000P_ooool0
01cooooo0_l0001[ooooo`go00000_ooool8o`0000?ooooo0_l0000Aooooo`;o00004oooool?o`00
00Wooooo0_l00002ooooo`;o0000Ooooool001cooooo00?o0000ooooooooool0J_ooool=o`0000Co
oooo1?l00005ooooo`;o00003oooool4o`0001?ooooo4?l00002ooooo`?o00001oooool2o`0007oo
oooo000Looooo`03o`000?oooooooooo06[ooooo3Ol00003ooooo`So00000_ooool6o`000003oooo
ool0003o000000Sooooo0_l0000Doooooa7o00000_ooool3o`0000Sooooo0_l0001nooooo`007?oo
ool00ol0003oooooooooo`1[ooooo`co00000_ooool4o`000003ooooool0003o000000?o000000?o
ooooo`000?l000001?l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000005Ooo
ool>o`0000Gooooo0_l00009ooooo`;o0000O_ooool001cooooo00?o0000ooooooooool0J_ooool<
o`000003ooooool0003o000000Go00000oooool2o`0000Sooooo0_l00004ooooo`;o000000?ooooo
o`000?l000005_ooool=o`00013ooooo0_l0001nooooo`007?ooool00ol0003oooooooooo`1Zoooo
o`Ko00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000004o`0000Gooooo0ol0000Soooo
o`go00002_ooool2o`0000Gooooo0_l000000ooooooo0000o`00001kooooo`007?ooool00ol0003o
ooooooooo`1Yooooo`Oo000000Coooooo`000?l0003o00001oooool2o`000003ooooool0003o0000
00Gooooo0ol00002ooooo`;o000000?oooooo`000?l000001?ooool3o`0001Gooooo3_l00002oooo
o`;o00001?ooool3o`0000Sooooo0ol0001jooooo`007?ooool00ol0003oooooooooo`1Yooooo`Go
00000oooool3o`0000Oooooo0_l00009ooooo`;o000000?oooooo`000?l000001?l00004ooooo`?o
00005Oooool4o`000003ooooool0003o000000_o00000oooool3o`0000Sooooo1?l0001jooooo`00
7?ooool00ol0003oooooooooo`1Zooooo`Ko000000?oooooo`000?l000001?l00003ooooo`;o0000
3Oooool5o`0000Cooooo0_l0000Gooooo`go000000?oooooo`000?l000001Oooool2o`0000Wooooo
0_l0001looooo`007?ooool00ol0003oooooooooo`1Zooooo`Ko000000?oooooo`000?l000001?l0
0003ooooo`;o00001oooool2o`0000Gooooo1?l00003ooooo`?o00005oooool:o`0001Sooooo0_l0
001jooooo`007?ooool00ol0003oooooooooo`1Zooooo`Go00000_ooool4o`0000Sooooo0_l00002
ooooo`Co00002oooool4o`0001Sooooo1?l00002ooooo`Go00005_ooool2o`0007[ooooo000Loooo
o`03o`000?oooooooooo06_ooooo1?l00003ooooo`?o00000oooool2o`0000?ooooo0_l00002oooo
o`;o00003Oooool3o`0001Wooooo1Ol000000ooooooo0000o`000003o`0000Cooooo0_l00003oooo
o`;o00000_ooool5o`0000Gooooo1Ol0001fooooo`007?ooool00ol0003oooooooooo`1/ooooo`Co
00000oooool2o`0000?ooooo0_l00003ooooo`;o00002_ooool2o`00027ooooo1Ol000000ooooooo
0000o`000002o`0000Gooooo0_l000000ooooooo0000o`000009o`0000Gooooo1_l0001eooooo`00
7?ooool00ol0003oooooooooo`1/ooooo`Co00000oooool5o`0000Gooooo0_l00007ooooo`;o0000
00?oooooo`000?l000008Oooool6o`0000Wooooo0_l000000ooooooo0000o`000002ooooo`;o0000
1?ooool2o`000003ooooool0003o000000?ooooo1?l0001eooooo`007?ooool00ol0003ooooooooo
o`1]ooooo`Go00000_ooool6o`0000?ooooo0_l00007ooooo`?o00001_ooool2o`0001_ooooo1_l0
0003ooooo`Co000000Coooooo`000?l0003o00002oooool2o`000003ooooool0003o000000Gooooo
0_l0001eooooo`007?ooool00ol0003oooooooooo`1^ooooo`Co000000?oooooo`000?l000002?l0
0009ooooo`?o00001Oooool3o`0001gooooo1Ol00002ooooo`So00001Oooool2o`0000?ooooo0_l0
000:ooooo`;o0000M?ooool001cooooo0_l0001_ooooo`Co000000?oooooo`000?l000002?l0000@
ooooo`?o00007_ooool6o`0000;ooooo1?l00008ooooo`;o00000oooool2o`0000[ooooo0_l0001d
ooooo`007?ooool00ol0003oooooooooo`1_ooooo`?o00000oooool5o`0000Gooooo0_l0000:oooo
o`Co00007oooool:o`0000Oooooo0_l000000ooooooo0000o`000003ooooo`;o0000P?ooool001co
oooo00?o0000ooooooooool0L?ooool2o`0000Cooooo1ol00002ooooo`;o00002_ooool4o`00027o
oooo2?l00006ooooo`?o000000?oooooo`000?l000002Oooool2o`0007[ooooo000Looooo`03o`00
0?oooooooooo077ooooo1?l00005ooooo`?o00001_ooool5o`0000;ooooo1?l0000Rooooo`Ko0000
1oooool3o`0000;ooooo0_l00006ooooo`;o000000?oooooo`000?l000000ol0001gooooo`007?oo
ool00ol0003oooooooooo`1aooooo`Co000000?oooooo`000?l000001?ooool2o`0000;ooooo3?l0
000Uooooo`Go00001oooool3o`0000Cooooo0_l00003ooooo`Co000000?oooooo`000?l000000_l0
001gooooo`007?ooool00ol0003oooooooooo`1fooooo`;o00001?ooool2o`0000;ooooo2ol0000V
ooooo`Oo000000?oooooo`000?l000000oooool2o`0000Cooooo0_l000000ooooooo0000o`000004
o`0007cooooo000Looooo`03o`000?oooooooooo07Oooooo0_l000000ooooooo0000o`00000?o`00
02Sooooo2?l00002ooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`00001moooo
o`007?ooool00ol0003oooooooooo`1gooooo`co000000Coooooo`000?l0003o0000;?ooool8o`00
00;ooooo0_l00002ooooo`;o00001oooool2o`0007gooooo000Looooo`03o`000?oooooooooo07So
oooo0_l00002ooooo`Ko0000<oooool:o`0008[ooooo000Looooo`03o`000?oooooooooo07kooooo
0_l0000gooooo`So00001oooool2o`0000Cooooo0_l0001kooooo`007?ooool00ol0003ooooooooo
o`2jooooo`Co000000Coooooo`000?l0003o00001?ooool2o`0000Cooooo0_l0001kooooo`007?oo
ool00ol0003oooooooooo`2jooooo`Co000000?oooooo`000?l000000ol000000ooooooo0000o`00
0003o`0007oooooo000Looooo`03o`000?oooooooooo0<3ooooo1?l000000ooooooo0000o`000003
o`0007oooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oo
oooooooo0?ooooooB_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo
00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooB_ooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool0oooooom:ooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooo
ooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`000?ooooooB_ooool00003oooo
ool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Oo<c<co0000o`000?l0003oc<c<00Ko
oooo00?o0000ooooooooool0oooooom:ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooo
ooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`3ooooood[o
oooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zjo`000006
ooooo`03o`000?oooooooooo0?ooooooB_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2ooo
ool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003o
oooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`004_ooool4o`00
0003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool0
1Oooool3o`000?ooooooB_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool0
0ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Co
oooo00?o0000ooooooooool0oooooomBooooo`004_ooool00omEEEGoIVIVo`00003ooooooeCooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo002Uooooo`04oa0@4?l0003o0000oooo
o`;o000000?o410@ooooooooool05_ooool4o`000003oa0@4?oooooooooo00Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^093ooooo002Vooooo`05o`000?ooooooooooooooool000002Oooool6
o`0000cooooo00?o0000ooooooooool00_ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`2@ooooo`00Y_ooool01Ol0003ooooooooooooooooo000001_ooooo
00?o0000ooooooooool00oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@
4100T?ooool00:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00003?ooool00ol0003o
ooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00002@oooo
o`00Y_ooool01Ol0003oQhN7oooooonYZJWo000001_ooooo00?o0000ooooooooool01Oooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000T?ooool00:Gooooo00?o410@o`00
0?mgMgL00_l000000onHV9Soooooooooo`0Iooooo`03o`000?oooooooooo00Kooooo00Go0000oooo
oooooooooooooa0@4003ooooo`03oa0@4?oooooooooo08kooooo0036ooooo`03o`000?oooooooooo
00;ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0T?oo
ool00<Cooooo00?oEEEEofIVI_l000001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP2@ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(126) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.3088 .66794 Mdot
.36131 .63752 Mdot
.64921 .56598 Mdot
.40711 .43425 Mdot
.66657 .33894 Mdot
.66045 .56749 Mdot
.55129 .70363 Mdot
.52372 .71368 Mdot
.65746 .59264 Mdot
.4927 .41226 Mdot
.56773 .6755 Mdot
.38732 .34373 Mdot
.54061 .70865 Mdot
.40927 .38975 Mdot
.40578 .29046 Mdot
.25396 .45474 Mdot
.34192 .62721 Mdot
.67622 .33186 Mdot
.267 .4558 Mdot
.65093 .59119 Mdot
.66749 .25755 Mdot
.40233 .40453 Mdot
.32157 .64668 Mdot
.41108 .39067 Mdot
.26359 .45351 Mdot
.36466 .64717 Mdot
.31077 .67369 Mdot
.26409 .44245 Mdot
.37737 .34019 Mdot
.57963 .67996 Mdot
.26849 .43115 Mdot
.48197 .28389 Mdot
.59862 .43409 Mdot
.34418 .54749 Mdot
.52859 .68266 Mdot
.56522 .66215 Mdot
.67216 .59135 Mdot
.57568 .6689 Mdot
.55726 .71285 Mdot
.54416 .67672 Mdot
.5458 .6753 Mdot
.35945 .65228 Mdot
.54536 .67181 Mdot
.58831 .78525 Mdot
.43248 .4087 Mdot
.29786 .51242 Mdot
.64387 .59536 Mdot
.37291 .35665 Mdot
.32553 .63321 Mdot
.74956 .59336 Mdot
.5228 .34643 Mdot
.52737 .69696 Mdot
.62339 .43384 Mdot
.25635 .4982 Mdot
.53833 .71396 Mdot
.26732 .45358 Mdot
.68419 .56215 Mdot
.42317 .41559 Mdot
.37131 .33323 Mdot
.34021 .53968 Mdot
.41466 .4252 Mdot
.66786 .32438 Mdot
.34923 .694 Mdot
.66682 .55107 Mdot
.63643 .57465 Mdot
.58098 .66722 Mdot
.37099 .61566 Mdot
.50744 .71657 Mdot
.3973 .42921 Mdot
.67074 .60308 Mdot
.38196 .35848 Mdot
.56792 .67511 Mdot
.37882 .63257 Mdot
.39085 .39775 Mdot
.30914 .6527 Mdot
.50363 .72806 Mdot
.67188 .33659 Mdot
.38027 .59397 Mdot
.74662 .59379 Mdot
.32238 .41745 Mdot
.39661 .40759 Mdot
.39217 .75795 Mdot
.3361 .31401 Mdot
.35357 .66843 Mdot
.40621 .376 Mdot
.34118 .7551 Mdot
.4493 .41683 Mdot
.25627 .43699 Mdot
.2649 .44682 Mdot
.36334 .3169 Mdot
.70702 .57031 Mdot
.32653 .65534 Mdot
.40803 .40031 Mdot
.40241 .43628 Mdot
.48884 .42087 Mdot
.37761 .3701 Mdot
.26742 .44902 Mdot
.63085 .45493 Mdot
.5428 .68036 Mdot
.63107 .42041 Mdot
.50552 .73944 Mdot
.635 .43862 Mdot
.39829 .36319 Mdot
.6806 .58336 Mdot
.32736 .68305 Mdot
.618 .45061 Mdot
.51017 .70462 Mdot
.40786 .39661 Mdot
.56847 .66066 Mdot
.32257 .65303 Mdot
.28027 .43468 Mdot
.65413 .31192 Mdot
.69085 .27566 Mdot
.37463 .62309 Mdot
.35118 .47639 Mdot
.43259 .43324 Mdot
.40487 .41724 Mdot
.36117 .64158 Mdot
.6368 .58266 Mdot
.61735 .63684 Mdot
.33885 .64573 Mdot
.55287 .67672 Mdot
.34315 .62493 Mdot
.59409 .43008 Mdot
.63566 .57939 Mdot
.61265 .40702 Mdot
.63758 .45243 Mdot
.49972 .30286 Mdot
.37624 .3884 Mdot
.59922 .44553 Mdot
.68612 .58687 Mdot
.34241 .64622 Mdot
.53516 .70441 Mdot
.41166 .44318 Mdot
.35601 .6643 Mdot
.54395 .71419 Mdot
.64475 .29403 Mdot
.64791 .28956 Mdot
.3749 .64047 Mdot
.36172 .48266 Mdot
.57614 .66471 Mdot
.52339 .72407 Mdot
.52065 .34712 Mdot
.36565 .6586 Mdot
.63763 .33717 Mdot
.52883 .72176 Mdot
.68588 .50942 Mdot
.2835 .43934 Mdot
.51855 .30943 Mdot
.40314 .7502 Mdot
.52196 .34757 Mdot
.66131 .26198 Mdot
.66311 .32488 Mdot
.54175 .71527 Mdot
.44467 .4375 Mdot
.36098 .62582 Mdot
.36314 .65687 Mdot
.38652 .35139 Mdot
.60991 .4461 Mdot
.43359 .42707 Mdot
.63742 .42518 Mdot
.63826 .45324 Mdot
.41195 .39437 Mdot
.3144 .52194 Mdot
.32564 .67358 Mdot
.43906 .40384 Mdot
.67833 .59507 Mdot
.68461 .32168 Mdot
.56691 .66454 Mdot
.40612 .3777 Mdot
.44178 .45182 Mdot
.40688 .36065 Mdot
.52035 .72437 Mdot
.52901 .77922 Mdot
.75023 .60045 Mdot
.56966 .68506 Mdot
.50047 .73698 Mdot
.69807 .5789 Mdot
.371 .34091 Mdot
.65453 .31724 Mdot
.61097 .42633 Mdot
.44185 .41347 Mdot
.52471 .34737 Mdot
.36996 .32149 Mdot
.67453 .26644 Mdot
.6595 .27002 Mdot
.38208 .75231 Mdot
.51436 .76859 Mdot
.42272 .43942 Mdot
.2697 .4225 Mdot
.52285 .32963 Mdot
.58116 .64492 Mdot
.53673 .69942 Mdot
.62961 .58389 Mdot
.63687 .58514 Mdot
.76549 .59541 Mdot
.436 .37351 Mdot
.40148 .35078 Mdot
.39354 .41394 Mdot
.62698 .42616 Mdot
.35189 .69068 Mdot
.66337 .32613 Mdot
.35435 .62411 Mdot
.39528 .757 Mdot
.32956 .40182 Mdot
.27549 .45684 Mdot
.75446 .57949 Mdot
.67694 .54871 Mdot
.62819 .4473 Mdot
.64647 .33093 Mdot
.42596 .42323 Mdot
.32041 .66567 Mdot
.52221 .33789 Mdot
.59684 .42012 Mdot
.67051 .23569 Mdot
.33557 .6392 Mdot
.34498 .36437 Mdot
.54378 .71063 Mdot
.71146 .57964 Mdot
.44902 .41626 Mdot
.39799 .3891 Mdot
.38118 .59916 Mdot
.42047 .44269 Mdot
.29136 .43558 Mdot
.27731 .43793 Mdot
.75429 .59628 Mdot
.50422 .74351 Mdot
.56779 .69092 Mdot
.6421 .59529 Mdot
.37704 .628 Mdot
.2971 .52163 Mdot
.67963 .57372 Mdot
.6735 .26016 Mdot
.57156 .67311 Mdot
.63755 .30587 Mdot
.6754 .5766 Mdot
.66674 .3381 Mdot
.37079 .32944 Mdot
.70473 .59075 Mdot
.65827 .30498 Mdot
.43479 .31475 Mdot
.62654 .45105 Mdot
.62692 .35337 Mdot
.55433 .7014 Mdot
.35168 .61288 Mdot
.44307 .41582 Mdot
.61796 .4302 Mdot
.60342 .40513 Mdot
.36033 .33414 Mdot
.64558 .42873 Mdot
.60164 .43218 Mdot
.36396 .3374 Mdot
.67963 .3207 Mdot
.44728 .69624 Mdot
.27149 .43105 Mdot
.34535 .62532 Mdot
.41749 .44129 Mdot
.50599 .75069 Mdot
.54463 .71457 Mdot
.42195 .4256 Mdot
.37712 .76052 Mdot
.55678 .69828 Mdot
.41589 .40841 Mdot
.56519 .70632 Mdot
.35366 .66719 Mdot
.32972 .39725 Mdot
.3767 .64306 Mdot
.41452 .39619 Mdot
.56672 .7051 Mdot
.64804 .59577 Mdot
.3659 .64657 Mdot
.40519 .40053 Mdot
.39462 .42006 Mdot
.62534 .42788 Mdot
.27972 .43821 Mdot
.51682 .73571 Mdot
.38758 .34518 Mdot
.68464 .55582 Mdot
.37843 .34807 Mdot
.65574 .28364 Mdot
.71984 .51691 Mdot
.36688 .65757 Mdot
.64652 .42931 Mdot
.67106 .56882 Mdot
.51056 .38097 Mdot
.33896 .37666 Mdot
.42991 .40373 Mdot
.60148 .42536 Mdot
.3304 .31562 Mdot
.5579 .68643 Mdot
.2883 .43626 Mdot
.58579 .42439 Mdot
.67966 .56091 Mdot
.63425 .43407 Mdot
.38545 .3686 Mdot
.31968 .6524 Mdot
.26055 .45591 Mdot
.70306 .57801 Mdot
.33203 .63625 Mdot
.41497 .37533 Mdot
.50542 .73706 Mdot
.63702 .46542 Mdot
.55659 .68432 Mdot
.26124 .43896 Mdot
.37116 .34408 Mdot
.67577 .60354 Mdot
.35675 .65575 Mdot
.53039 .71551 Mdot
.37766 .63774 Mdot
.51353 .37188 Mdot
.34557 .35689 Mdot
.37661 .64975 Mdot
.65913 .28967 Mdot
.79461 .58935 Mdot
.56296 .67697 Mdot
.62037 .41234 Mdot
.71186 .61023 Mdot
.31904 .64045 Mdot
.67233 .57929 Mdot
.38543 .48565 Mdot
.70297 .56766 Mdot
.26512 .45819 Mdot
.68992 .60872 Mdot
.41718 .36523 Mdot
.42152 .38691 Mdot
.63876 .55416 Mdot
.62664 .45532 Mdot
.38653 .37806 Mdot
.3537 .66561 Mdot
.4707 .27905 Mdot
.47072 .43827 Mdot
.43553 .37409 Mdot
.68243 .56284 Mdot
.37161 .48768 Mdot
.27321 .43587 Mdot
.26104 .44166 Mdot
.35632 .62944 Mdot
.617 .41375 Mdot
.63038 .30696 Mdot
.62401 .31527 Mdot
.7631 .50698 Mdot
.32057 .30892 Mdot
.34495 .47001 Mdot
.36939 .64617 Mdot
.77152 .59065 Mdot
.30309 .66725 Mdot
.597 .42275 Mdot
.52341 .71333 Mdot
.53582 .78343 Mdot
.44698 .41073 Mdot
.59716 .45223 Mdot
.29428 .44017 Mdot
.33724 .62371 Mdot
.38203 .61914 Mdot
.52809 .7156 Mdot
.44728 .38884 Mdot
.49125 .41017 Mdot
.42732 .4306 Mdot
.52023 .71412 Mdot
.60021 .409 Mdot
.36598 .33046 Mdot
.49905 .28915 Mdot
.60011 .79014 Mdot
.42593 .40167 Mdot
.35369 .55172 Mdot
.42983 .39618 Mdot
.50538 .30926 Mdot
.428 .41746 Mdot
.35624 .65918 Mdot
.23131 .46271 Mdot
.41718 .45033 Mdot
.75082 .57638 Mdot
.33036 .40441 Mdot
.66508 .29884 Mdot
.40157 .3927 Mdot
.43828 .42373 Mdot
.63053 .32927 Mdot
.33747 .66315 Mdot
.3804 .40877 Mdot
.44878 .69383 Mdot
.40629 .4044 Mdot
.56613 .66421 Mdot
.34695 .31864 Mdot
.48235 .28716 Mdot
.2724 .43839 Mdot
.31988 .65006 Mdot
.54861 .71705 Mdot
.55571 .67045 Mdot
.63292 .41054 Mdot
.54491 .71469 Mdot
.4193 .38697 Mdot
.34725 .31782 Mdot
.37602 .61665 Mdot
.62345 .44978 Mdot
.33004 .65479 Mdot
.66884 .45698 Mdot
.55256 .69821 Mdot
.62953 .43891 Mdot
.44888 .38189 Mdot
.54708 .69178 Mdot
.47623 .66738 Mdot
.27918 .4333 Mdot
.60125 .40793 Mdot
.30974 .66608 Mdot
.67626 .60487 Mdot
.59914 .42339 Mdot
.53723 .71457 Mdot
.43291 .40865 Mdot
.27476 .44849 Mdot
.54015 .71675 Mdot
.35967 .55775 Mdot
.28027 .43064 Mdot
.40791 .40615 Mdot
.33718 .67208 Mdot
.3453 .65146 Mdot
.44445 .41365 Mdot
.43294 .43834 Mdot
.66671 .5612 Mdot
.60093 .41998 Mdot
.60215 .41585 Mdot
.64476 .44845 Mdot
.70197 .56909 Mdot
.79292 .5922 Mdot
.50476 .7129 Mdot
.4807 .28723 Mdot
.51658 .7638 Mdot
.61927 .43501 Mdot
.66402 .56125 Mdot
.4306 .39987 Mdot
.39842 .35889 Mdot
.56647 .70682 Mdot
.81599 .57104 Mdot
.44565 .40662 Mdot
.35888 .61928 Mdot
.52078 .70539 Mdot
.39806 .34962 Mdot
.75971 .59335 Mdot
.67162 .31418 Mdot
.34417 .47092 Mdot
.52226 .70531 Mdot
.36411 .56945 Mdot
.52286 .70482 Mdot
.43882 .42166 Mdot
.38241 .37447 Mdot
.36184 .60894 Mdot
.66518 .29825 Mdot
.38639 .34699 Mdot
.4186 .40568 Mdot
.77458 .58991 Mdot
.30256 .67158 Mdot
.62462 .31266 Mdot
.37665 .33518 Mdot
.63666 .44855 Mdot
.67532 .31493 Mdot
.39279 .40671 Mdot
.3801 .34731 Mdot
.58854 .4246 Mdot
.57198 .69727 Mdot
.65906 .29214 Mdot
.75397 .57752 Mdot
.33806 .63416 Mdot
.50164 .73211 Mdot
.63406 .40749 Mdot
.56237 .67631 Mdot
.47154 .35491 Mdot
.63106 .44284 Mdot
.56049 .79453 Mdot
.57073 .16209 Mdot
.60672 .43701 Mdot
.67492 .55645 Mdot
.4857 .42396 Mdot
.38186 .34736 Mdot
.40861 .40612 Mdot
.63666 .29631 Mdot
.35362 .64481 Mdot
.51508 .76865 Mdot
.56995 .69146 Mdot
.39948 .38457 Mdot
.36878 .65645 Mdot
.36752 .75706 Mdot
.63127 .43193 Mdot
.64627 .30735 Mdot
.64208 .30087 Mdot
.3883 .39038 Mdot
.32613 .3158 Mdot
.36524 .6495 Mdot
.40534 .40008 Mdot
.38617 .39288 Mdot
.71956 .60563 Mdot
.33288 .6768 Mdot
.70445 .58909 Mdot
.2795 .45395 Mdot
.32157 .43646 Mdot
.5098 .75249 Mdot
.55472 .70694 Mdot
.61087 .41037 Mdot
.56733 .68958 Mdot
.7428 .60229 Mdot
.60206 .41666 Mdot
.40466 .3999 Mdot
.37619 .61647 Mdot
.40605 .39977 Mdot
.40679 .40349 Mdot
.43315 .4168 Mdot
.34013 .46692 Mdot
.72997 .58005 Mdot
.64614 .31433 Mdot
.37343 .33213 Mdot
.69888 .57162 Mdot
.74973 .58469 Mdot
.49357 .41436 Mdot
.39739 .39854 Mdot
.40833 .41592 Mdot
.37793 .59337 Mdot
.28518 .44141 Mdot
.54499 .69453 Mdot
.36114 .609 Mdot
.45122 .42286 Mdot
.64704 .59737 Mdot
.38143 .41202 Mdot
.37661 .64916 Mdot
.50699 .70538 Mdot
.30567 .70863 Mdot
.62732 .40252 Mdot
.61825 .40614 Mdot
.6011 .42869 Mdot
.64694 .44617 Mdot
.55862 .66607 Mdot
.66154 .56111 Mdot
.66277 .44391 Mdot
.32262 .43143 Mdot
.43242 .43953 Mdot
.38372 .37258 Mdot
.71105 .60904 Mdot
.60117 .44301 Mdot
.46105 .44523 Mdot
.26592 .46333 Mdot
.71881 .5911 Mdot
.6328 .45502 Mdot
.32909 .72991 Mdot
.32552 .64517 Mdot
.74484 .59617 Mdot
.57574 .67029 Mdot
.66018 .30318 Mdot
.81993 .47726 Mdot
.33454 .65251 Mdot
.33774 .69707 Mdot
.68963 .59307 Mdot
.35351 .32013 Mdot
.23823 .48839 Mdot
.66626 .57712 Mdot
.28725 .4315 Mdot
.36855 .62895 Mdot
.63108 .45252 Mdot
.33243 .31955 Mdot
.35333 .32903 Mdot
.68182 .60109 Mdot
.3927 .41907 Mdot
.62532 .55723 Mdot
.67708 .55862 Mdot
.61061 .41356 Mdot
.68265 .56323 Mdot
.56083 .68849 Mdot
.69033 .58386 Mdot
.36022 .55947 Mdot
.38854 .41954 Mdot
.25435 .49742 Mdot
.40044 .28301 Mdot
.43215 .43494 Mdot
.53999 .68888 Mdot
.50144 .73459 Mdot
.41552 .43162 Mdot
.6538 .34263 Mdot
.67038 .55685 Mdot
.76409 .59783 Mdot
.27649 .45042 Mdot
.69361 .6087 Mdot
.31891 .65265 Mdot
.50346 .73936 Mdot
.50195 .73797 Mdot
.59988 .42454 Mdot
.36113 .66194 Mdot
.4989 .72566 Mdot
.551 .67719 Mdot
.62877 .46559 Mdot
.44423 .416 Mdot
.32621 .66991 Mdot
.36532 .33016 Mdot
.68208 .32501 Mdot
.40523 .40529 Mdot
.7032 .58766 Mdot
.75491 .59782 Mdot
.4047 .28715 Mdot
.67928 .57167 Mdot
.61459 .41034 Mdot
.32987 .67318 Mdot
.27066 .45423 Mdot
.34233 .64865 Mdot
.40807 .43937 Mdot
.50507 .74675 Mdot
.32417 .64553 Mdot
.67264 .26049 Mdot
.41546 .42193 Mdot
.31198 .51975 Mdot
.37533 .3305 Mdot
.40708 .40693 Mdot
.63354 .57328 Mdot
.63238 .33167 Mdot
.67972 .3016 Mdot
.7422 .58186 Mdot
.66246 .33464 Mdot
.30862 .6885 Mdot
.63304 .5768 Mdot
.63698 .32391 Mdot
.76616 .50686 Mdot
.64781 .43162 Mdot
.642 .31956 Mdot
.40744 .37686 Mdot
.54769 .71491 Mdot
.36722 .61205 Mdot
.38821 .37546 Mdot
.43847 .46523 Mdot
.23386 .43626 Mdot
.62718 .43043 Mdot
.40841 .40984 Mdot
.43882 .42606 Mdot
.37047 .65374 Mdot
.40388 .75197 Mdot
.67406 .55339 Mdot
.62703 .41655 Mdot
.33586 .64944 Mdot
.39073 .75854 Mdot
.63557 .57166 Mdot
.63302 .31606 Mdot
.56482 .70057 Mdot
.36441 .5749 Mdot
.62311 .43116 Mdot
.55289 .70263 Mdot
.73772 .58247 Mdot
.52074 .3548 Mdot
.24715 .4438 Mdot
.6683 .58567 Mdot
.52239 .34774 Mdot
.28622 .4504 Mdot
.76622 .59471 Mdot
.58011 .64465 Mdot
.32331 .65373 Mdot
.53149 .71885 Mdot
.6485 .3023 Mdot
.38009 .6307 Mdot
.32962 .65452 Mdot
.55578 .70617 Mdot
.22514 .46302 Mdot
.33192 .3228 Mdot
.50432 .72292 Mdot
.35684 .31832 Mdot
.52001 .35146 Mdot
.62139 .42829 Mdot
.65099 .31592 Mdot
.50443 .74355 Mdot
.36009 .65148 Mdot
.53427 .77517 Mdot
.52452 .34498 Mdot
.28627 .43561 Mdot
.66275 .30527 Mdot
.3726 .75304 Mdot
.58264 .65531 Mdot
.54756 .69505 Mdot
.77466 .59013 Mdot
.64395 .34225 Mdot
.4173 .3832 Mdot
.82284 .56399 Mdot
.40718 .3794 Mdot
.51444 .72081 Mdot
.29402 .43972 Mdot
.34454 .63354 Mdot
.50631 .71872 Mdot
.2728 .45873 Mdot
.3843 .34272 Mdot
.42219 .43668 Mdot
.75052 .59699 Mdot
.36915 .60391 Mdot
.65248 .45145 Mdot
.43472 .43357 Mdot
.41966 .40885 Mdot
.60101 .40558 Mdot
.48502 .28974 Mdot
.55396 .62414 Mdot
.60486 .44296 Mdot
.70882 .59349 Mdot
.62266 .45005 Mdot
.62201 .41522 Mdot
.31286 .66017 Mdot
.77104 .59238 Mdot
.61016 .40345 Mdot
.41895 .3982 Mdot
.41136 .39842 Mdot
.55514 .71451 Mdot
.33084 .31702 Mdot
.35509 .32748 Mdot
.68252 .55486 Mdot
.61351 .46191 Mdot
.37976 .39031 Mdot
.35412 .66763 Mdot
.63966 .29114 Mdot
.62902 .40942 Mdot
.34048 .63054 Mdot
.37466 .373 Mdot
.71757 .60623 Mdot
.61145 .44131 Mdot
.6032 .401 Mdot
.66005 .30729 Mdot
.52193 .72578 Mdot
.38644 .59516 Mdot
.67583 .5577 Mdot
.25072 .44035 Mdot
.63092 .47678 Mdot
.72896 .6012 Mdot
.62121 .42643 Mdot
.6356 .44382 Mdot
.36253 .65974 Mdot
.36583 .5648 Mdot
.59727 .39869 Mdot
.69749 .56786 Mdot
.58287 .80052 Mdot
.53162 .68698 Mdot
.37177 .34391 Mdot
.56474 .69366 Mdot
.32256 .65416 Mdot
.49946 .30098 Mdot
.63848 .30584 Mdot
.55002 .69194 Mdot
.60058 .43194 Mdot
.32676 .65125 Mdot
.38528 .5979 Mdot
.41463 .39461 Mdot
.40083 .40258 Mdot
.64317 .5951 Mdot
.51959 .31802 Mdot
.5624 .71073 Mdot
.6305 .30834 Mdot
.65245 .5605 Mdot
.27409 .45016 Mdot
.36064 .62423 Mdot
.61521 .33777 Mdot
.37433 .32683 Mdot
.69488 .56892 Mdot
.36275 .63517 Mdot
.62401 .3188 Mdot
.64495 .31469 Mdot
.44487 .42635 Mdot
.65865 .26339 Mdot
.55524 .69103 Mdot
.35599 .66293 Mdot
.30626 .69431 Mdot
.37323 .339 Mdot
.39978 .39816 Mdot
.28883 .43989 Mdot
.50014 .71883 Mdot
.40811 .37774 Mdot
.65824 .29683 Mdot
.37076 .62192 Mdot
.42752 .39535 Mdot
.63607 .34131 Mdot
.65121 .45288 Mdot
.62666 .44527 Mdot
.63488 .55726 Mdot
.62576 .33675 Mdot
.63353 .33841 Mdot
.63789 .34286 Mdot
.53633 .78373 Mdot
.39633 .34891 Mdot
.65117 .47138 Mdot
.39198 .41731 Mdot
.51917 .35329 Mdot
.25156 .43518 Mdot
.5376 .685 Mdot
.67941 .60378 Mdot
.43174 .42465 Mdot
.39311 .41763 Mdot
.35336 .60855 Mdot
.25379 .45578 Mdot
.43623 .40032 Mdot
.34993 .62806 Mdot
.31754 .69748 Mdot
.62549 .57697 Mdot
.40184 .75019 Mdot
.83511 .5417 Mdot
.36794 .324 Mdot
.35097 .31339 Mdot
.33359 .66157 Mdot
.56131 .70717 Mdot
.35562 .31597 Mdot
.51975 .72497 Mdot
.35047 .65111 Mdot
.2471 .45385 Mdot
.35921 .55763 Mdot
.66884 .3234 Mdot
.43847 .42051 Mdot
.55809 .70147 Mdot
.43635 .4243 Mdot
.55962 .7024 Mdot
.37162 .49084 Mdot
.33389 .31159 Mdot
.4321 .44105 Mdot
.37749 .36751 Mdot
.66572 .25759 Mdot
.39882 .40072 Mdot
.77842 .58901 Mdot
.35942 .6323 Mdot
.60099 .45111 Mdot
.24173 .44634 Mdot
.47127 .43841 Mdot
.40689 .41448 Mdot
.24422 .42494 Mdot
.40462 .41908 Mdot
.8136 .5765 Mdot
.37027 .32471 Mdot
.43936 .40651 Mdot
.53323 .70074 Mdot
.56406 .67316 Mdot
.37571 .59832 Mdot
.63474 .44284 Mdot
.37729 .75312 Mdot
.41544 .40696 Mdot
.64383 .55599 Mdot
.68754 .29509 Mdot
.62962 .33444 Mdot
.36785 .61923 Mdot
.56301 .16037 Mdot
.5496 .67013 Mdot
.68873 .59821 Mdot
.26973 .43026 Mdot
.70753 .59166 Mdot
.6734 .55179 Mdot
.30282 .68886 Mdot
.64996 .31524 Mdot
.38524 .41966 Mdot
.34479 .54352 Mdot
.32485 .70428 Mdot
.37321 .33977 Mdot
.6278 .57276 Mdot
.5886 .42414 Mdot
.28424 .34537 Mdot
.67766 .32675 Mdot
.65196 .33654 Mdot
.54626 .71068 Mdot
.64295 .55563 Mdot
.6263 .41695 Mdot
.6358 .3185 Mdot
.62761 .58059 Mdot
.6438 .42298 Mdot
.78017 .594 Mdot
.36411 .65172 Mdot
.3752 .48712 Mdot
.29276 .51103 Mdot
.55455 .68256 Mdot
.7622 .5914 Mdot
.37874 .62062 Mdot
.36951 .65756 Mdot
.6255 .42215 Mdot
.71689 .59554 Mdot
.3577 .67498 Mdot
.44311 .42016 Mdot
.62796 .44983 Mdot
.39427 .38098 Mdot
.6762 .33354 Mdot
.41267 .40367 Mdot
.6532 .59747 Mdot
.53679 .69453 Mdot
.67445 .56246 Mdot
.5495 .70847 Mdot
.47688 .28383 Mdot
.41812 .41719 Mdot
.40182 .39492 Mdot
.3478 .31925 Mdot
.31548 .66774 Mdot
.34558 .54574 Mdot
.69049 .56616 Mdot
.67716 .56219 Mdot
.24215 .44682 Mdot
.34779 .62171 Mdot
.61548 .39357 Mdot
.35738 .31766 Mdot
.40225 .41838 Mdot
.35787 .63373 Mdot
.25407 .43163 Mdot
.56949 .79979 Mdot
.33781 .31775 Mdot
.31482 .65997 Mdot
.78933 .59465 Mdot
.3846 .39525 Mdot
.62967 .41559 Mdot
.61297 .45732 Mdot
.32371 .30746 Mdot
.68012 .32789 Mdot
.33559 .63774 Mdot
.63463 .42321 Mdot
.36344 .62434 Mdot
.70087 .56526 Mdot
.52059 .6851 Mdot
.3517 .63169 Mdot
.40813 .41971 Mdot
.83511 .54048 Mdot
.55193 .71314 Mdot
.4357 .40942 Mdot
.50688 .71394 Mdot
.38175 .61195 Mdot
.34612 .64355 Mdot
.64344 .42239 Mdot
.28727 .43226 Mdot
.5532 .69082 Mdot
.4421 .43733 Mdot
.35437 .55423 Mdot
.26014 .4559 Mdot
.68383 .32179 Mdot
.37887 .38757 Mdot
.37517 .355 Mdot
.78362 .58827 Mdot
.51181 .38131 Mdot
.50445 .74985 Mdot
.56803 .66239 Mdot
.52743 .78024 Mdot
.31312 .67243 Mdot
.67534 .29567 Mdot
.38603 .59648 Mdot
.60947 .40945 Mdot
.7036 .59773 Mdot
.43454 .41663 Mdot
.64891 .44489 Mdot
.50258 .72319 Mdot
.64517 .32351 Mdot
.36993 .32156 Mdot
.65831 .5818 Mdot
.64434 .43717 Mdot
.55078 .69697 Mdot
.35593 .65429 Mdot
.34348 .63133 Mdot
.78032 .59656 Mdot
.43007 .39799 Mdot
.40244 .40173 Mdot
.51784 .69213 Mdot
.65303 .269 Mdot
.66172 .33608 Mdot
.62614 .45518 Mdot
.51426 .69667 Mdot
.33723 .31647 Mdot
.38242 .59961 Mdot
.4408 .4187 Mdot
.3451 .31608 Mdot
.52279 .77462 Mdot
.3315 .7207 Mdot
.66033 .33245 Mdot
.33574 .36798 Mdot
.33528 .63889 Mdot
.53395 .70604 Mdot
.76361 .51003 Mdot
.28898 .44377 Mdot
.40648 .43118 Mdot
.33421 .38114 Mdot
.36201 .33721 Mdot
.26032 .43404 Mdot
.63046 .40459 Mdot
.35126 .35666 Mdot
.24247 .44404 Mdot
.24962 .44775 Mdot
.37937 .37887 Mdot
.37837 .38105 Mdot
.35264 .63828 Mdot
.43354 .37306 Mdot
.69595 .58881 Mdot
.28546 .42827 Mdot
.61567 .31648 Mdot
.27396 .43266 Mdot
.38919 .35318 Mdot
.33233 .72508 Mdot
.31497 .32409 Mdot
.36868 .6323 Mdot
.31775 .64266 Mdot
.55739 .68179 Mdot
.26258 .45682 Mdot
.69435 .56773 Mdot
.58934 .41152 Mdot
.69527 .60585 Mdot
.35458 .63813 Mdot
.62734 .57802 Mdot
.58081 .66813 Mdot
.66814 .58571 Mdot
.71643 .59086 Mdot
.53453 .69462 Mdot
.36408 .60666 Mdot
.37658 .32997 Mdot
.53512 .69359 Mdot
.59883 .40432 Mdot
.63423 .31372 Mdot
.32307 .70049 Mdot
.61674 .4514 Mdot
.43261 .3877 Mdot
.58357 .79603 Mdot
.67133 .59061 Mdot
.33075 .39478 Mdot
.3315 .62723 Mdot
.62282 .34092 Mdot
.34865 .63456 Mdot
.60122 .3954 Mdot
.66641 .32203 Mdot
.40096 .37291 Mdot
.61785 .30288 Mdot
.5797 .6425 Mdot
.42025 .4499 Mdot
.31651 .69727 Mdot
.70106 .60579 Mdot
.55234 .68582 Mdot
.48616 .65947 Mdot
.62938 .41741 Mdot
.31967 .6468 Mdot
.37236 .57131 Mdot
.60463 .41288 Mdot
.53569 .70369 Mdot
.32622 .52723 Mdot
.44224 .42713 Mdot
.56379 .68655 Mdot
.37919 .39125 Mdot
.35763 .48001 Mdot
.64408 .28693 Mdot
.64355 .44968 Mdot
.25378 .45711 Mdot
.63766 .5754 Mdot
.2429 .44928 Mdot
.45742 .42966 Mdot
.50757 .30206 Mdot
.3982 .42027 Mdot
.33213 .39119 Mdot
.74216 .60302 Mdot
.37272 .62871 Mdot
.61323 .4365 Mdot
.62354 .42826 Mdot
.26533 .45916 Mdot
.85307 .47553 Mdot
.64181 .32734 Mdot
.78573 .59346 Mdot
.4176 .41493 Mdot
.39771 .40829 Mdot
.3838 .59603 Mdot
.38106 .49021 Mdot
.63259 .45343 Mdot
.40525 .42813 Mdot
.31711 .31154 Mdot
.52841 .70807 Mdot
.39692 .36346 Mdot
.3894 .38884 Mdot
.50019 .74091 Mdot
.53298 .7028 Mdot
.7354 .60051 Mdot
.64813 .43047 Mdot
.63384 .55721 Mdot
.67135 .33199 Mdot
.34303 .3652 Mdot
.49117 .29319 Mdot
.34172 .32725 Mdot
.66895 .32999 Mdot
.27525 .43649 Mdot
.4473 .4072 Mdot
.39238 .42291 Mdot
.64936 .33562 Mdot
.57791 .68637 Mdot
.35571 .63361 Mdot
.36459 .4842 Mdot
.62382 .42631 Mdot
.25052 .44454 Mdot
.66886 .33963 Mdot
.36356 .62565 Mdot
.31617 .52316 Mdot
.35404 .64334 Mdot
.54704 .69904 Mdot
.76337 .59294 Mdot
.66776 .32003 Mdot
.34863 .63399 Mdot
.64173 .58385 Mdot
.50682 .74777 Mdot
.41246 .364 Mdot
.58229 .66954 Mdot
.3024 .68507 Mdot
.31532 .6515 Mdot
.30689 .66545 Mdot
.27768 .45151 Mdot
.33214 .39251 Mdot
.61316 .40924 Mdot
.51217 .69914 Mdot
.64078 .57568 Mdot
.51717 .31538 Mdot
.33369 .5368 Mdot
.35974 .3688 Mdot
.3873 .36827 Mdot
.41292 .40244 Mdot
.38914 .398 Mdot
.62277 .40046 Mdot
.4541 .42826 Mdot
.39014 .41379 Mdot
.56559 .70825 Mdot
.73359 .60023 Mdot
.41965 .41302 Mdot
.62313 .44435 Mdot
.59904 .45521 Mdot
.62273 .34099 Mdot
.33055 .4615 Mdot
.35455 .68731 Mdot
.35737 .6279 Mdot
.70102 .57616 Mdot
.62849 .56733 Mdot
.64631 .29234 Mdot
.52298 .7146 Mdot
.35329 .64592 Mdot
.81143 .57644 Mdot
.66987 .31385 Mdot
.42459 .40165 Mdot
.34741 .31974 Mdot
.31949 .32535 Mdot
.38589 .3499 Mdot
.43242 .41777 Mdot
.6079 .44174 Mdot
.70033 .57084 Mdot
.41186 .36131 Mdot
.31543 .52152 Mdot
.64201 .34193 Mdot
.63055 .31722 Mdot
.3251 .68123 Mdot
.44405 .43999 Mdot
.55796 .70008 Mdot
.32954 .3139 Mdot
.51805 .73606 Mdot
.34597 .75282 Mdot
.66423 .4632 Mdot
.38218 .41411 Mdot
.479 .43228 Mdot
.44796 .41256 Mdot
.32732 .683 Mdot
.36142 .56657 Mdot
.37117 .6394 Mdot
.52699 .7107 Mdot
.51718 .36395 Mdot
.54971 .67348 Mdot
.63456 .45349 Mdot
.32709 .64255 Mdot
.36696 .31514 Mdot
.67729 .56265 Mdot
.24876 .45142 Mdot
.65879 .31772 Mdot
.36464 .33399 Mdot
.61658 .43629 Mdot
.33788 .36671 Mdot
.66322 .56175 Mdot
.38124 .60273 Mdot
.24715 .45022 Mdot
.73797 .57921 Mdot
.35307 .35603 Mdot
.65965 .41287 Mdot
.64914 .4469 Mdot
.6681 .32391 Mdot
.49516 .41147 Mdot
.66525 .30357 Mdot
.55328 .69223 Mdot
.41805 .42 Mdot
.44041 .40866 Mdot
.4055 .41034 Mdot
.39183 .37093 Mdot
.53269 .71435 Mdot
.2587 .45182 Mdot
.59251 .41597 Mdot
.64759 .44034 Mdot
.26984 .4317 Mdot
.64923 .3196 Mdot
.53443 .68523 Mdot
.72676 .60264 Mdot
.59771 .42109 Mdot
.6713 .30153 Mdot
.43034 .45173 Mdot
.40745 .42555 Mdot
.64429 .44395 Mdot
.40423 .37509 Mdot
.26321 .45027 Mdot
.67853 .58782 Mdot
.25456 .44327 Mdot
.62492 .34351 Mdot
.66091 .31457 Mdot
.54499 .71545 Mdot
.34942 .63262 Mdot
.64832 .29405 Mdot
.6526 .56263 Mdot
.44268 .40515 Mdot
.37889 .38537 Mdot
.36071 .55955 Mdot
.52493 .34622 Mdot
.62545 .34292 Mdot
.41464 .38109 Mdot
.33621 .67673 Mdot
.3797 .57543 Mdot
.4043 .4294 Mdot
.26587 .44517 Mdot
.31215 .65907 Mdot
.63487 .31591 Mdot
.52112 .71693 Mdot
.41644 .28207 Mdot
.51915 .72366 Mdot
.3548 .65587 Mdot
.63303 .42324 Mdot
.35663 .6101 Mdot
.63197 .41923 Mdot
.34686 .73283 Mdot
.38375 .40287 Mdot
.35702 .55814 Mdot
.59264 .43012 Mdot
.68865 .56344 Mdot
.72401 .59185 Mdot
.61075 .43979 Mdot
.33283 .63858 Mdot
.61268 .41123 Mdot
.65482 .30088 Mdot
.5284 .77692 Mdot
.31282 .65059 Mdot
.71712 .59161 Mdot
.6675 .58886 Mdot
.51502 .69461 Mdot
.41082 .40835 Mdot
.4411 .42124 Mdot
.66406 .58244 Mdot
.51607 .736 Mdot
.32704 .66021 Mdot
.40267 .4008 Mdot
.59976 .43515 Mdot
.69039 .58922 Mdot
.56905 .65127 Mdot
.38396 .61218 Mdot
.24948 .45579 Mdot
.50468 .29936 Mdot
.56569 .66347 Mdot
.43342 .3909 Mdot
.26613 .44899 Mdot
.63933 .33339 Mdot
.33451 .37124 Mdot
.52004 .34805 Mdot
.56802 .66639 Mdot
.61747 .40653 Mdot
.38755 .35048 Mdot
.71397 .57698 Mdot
.43739 .39887 Mdot
.58892 .17352 Mdot
.64198 .44691 Mdot
.41387 .38686 Mdot
.62276 .45896 Mdot
.3418 .64819 Mdot
.40253 .40678 Mdot
.5091 .75168 Mdot
.69625 .5745 Mdot
.43035 .39865 Mdot
.67038 .25714 Mdot
.50683 .71731 Mdot
.61764 .43692 Mdot
.66143 .33512 Mdot
.27467 .42816 Mdot
.47109 .27963 Mdot
.71213 .60898 Mdot
.64263 .31424 Mdot
.41074 .41126 Mdot
.65386 .55909 Mdot
.56379 .67474 Mdot
.61171 .43694 Mdot
.42588 .45099 Mdot
.54583 .67986 Mdot
.52863 .70218 Mdot
.66542 .31009 Mdot
.2959 .5239 Mdot
.4064 .4412 Mdot
.40708 .38781 Mdot
.31786 .53041 Mdot
.38192 .58625 Mdot
.43759 .42048 Mdot
.38927 .37968 Mdot
.55426 .70213 Mdot
.51943 .36785 Mdot
.33707 .36832 Mdot
.59282 .43262 Mdot
.54709 .68611 Mdot
.62399 .57162 Mdot
.68821 .59634 Mdot
.64213 .30709 Mdot
.36305 .63617 Mdot
.65458 .28856 Mdot
.69389 .58165 Mdot
.42028 .39762 Mdot
.51562 .71821 Mdot
.30821 .42715 Mdot
.50515 .7166 Mdot
.65276 .5673 Mdot
.37582 .64912 Mdot
.4296 .37658 Mdot
.58539 .17124 Mdot
.5327 .62608 Mdot
.77323 .59808 Mdot
.62988 .33387 Mdot
.31605 .52188 Mdot
.41341 .41561 Mdot
.42802 .3717 Mdot
.43214 .40303 Mdot
.66577 .28505 Mdot
.69015 .60711 Mdot
.64375 .42283 Mdot
.62884 .41687 Mdot
.33997 .37078 Mdot
.52682 .70396 Mdot
.55264 .67077 Mdot
.63813 .43476 Mdot
.54403 .69906 Mdot
.40526 .38489 Mdot
.66103 .56883 Mdot
.33712 .73409 Mdot
.40331 .41923 Mdot
.63275 .46618 Mdot
.58083 .66437 Mdot
.37866 .64832 Mdot
.6251 .57281 Mdot
.47492 .43597 Mdot
.38651 .75227 Mdot
.5483 .69062 Mdot
.3308 .46065 Mdot
.69447 .57073 Mdot
.5978 .42297 Mdot
.65738 .55708 Mdot
.41549 .38967 Mdot
.38143 .41279 Mdot
.60305 .40409 Mdot
.40257 .41677 Mdot
.3447 .55555 Mdot
.29053 .44115 Mdot
.27374 .46395 Mdot
.39229 .41835 Mdot
.31509 .69045 Mdot
.56987 .67935 Mdot
.63776 .43223 Mdot
.36447 .33877 Mdot
.3749 .37638 Mdot
.31151 .67144 Mdot
.54319 .68217 Mdot
.41274 .74364 Mdot
.52886 .7116 Mdot
.68806 .56203 Mdot
.52302 .71144 Mdot
.4469 .41082 Mdot
.34621 .65441 Mdot
.68216 .57787 Mdot
.62109 .43477 Mdot
.66428 .59364 Mdot
.43351 .43393 Mdot
.57917 .65278 Mdot
.69108 .598 Mdot
.28838 .43845 Mdot
.34648 .65257 Mdot
.63055 .28 Mdot
.35162 .69225 Mdot
.41807 .3945 Mdot
.43343 .4071 Mdot
.62545 .45438 Mdot
.54061 .71565 Mdot
.38519 .60256 Mdot
.78049 .59231 Mdot
.62345 .34109 Mdot
.36765 .63484 Mdot
.63642 .29297 Mdot
.35395 .32058 Mdot
.37511 .6236 Mdot
.31792 .31102 Mdot
.55428 .70841 Mdot
.33967 .63328 Mdot
.69248 .30221 Mdot
.27108 .4225 Mdot
.65141 .31173 Mdot
.63128 .56777 Mdot
.35446 .31504 Mdot
.69934 .59344 Mdot
.50432 .7467 Mdot
.75508 .59686 Mdot
.55407 .68822 Mdot
.67037 .25861 Mdot
.29427 .439 Mdot
.57247 .66863 Mdot
.51548 .76171 Mdot
.70097 .58545 Mdot
.63886 .44015 Mdot
.25724 .4461 Mdot
.60859 .39846 Mdot
.64045 .4273 Mdot
.55683 .66831 Mdot
.3425 .63011 Mdot
.35346 .62013 Mdot
.60352 .45352 Mdot
.34688 .62911 Mdot
.67199 .58059 Mdot
.34084 .31777 Mdot
.45008 .38304 Mdot
.57143 .67956 Mdot
.27181 .42795 Mdot
.38557 .3579 Mdot
.68304 .60749 Mdot
.66499 .57294 Mdot
.52675 .70763 Mdot
.31328 .71503 Mdot
.63246 .4162 Mdot
.38374 .62041 Mdot
.33276 .65095 Mdot
.33989 .64598 Mdot
.33946 .61903 Mdot
.51954 .35841 Mdot
.53973 .68875 Mdot
.33238 .64094 Mdot
.38328 .38009 Mdot
.38683 .38738 Mdot
.59872 .41779 Mdot
.67425 .29395 Mdot
.26254 .44405 Mdot
.61561 .40958 Mdot
.41622 .43344 Mdot
.6827 .56348 Mdot
.68271 .29627 Mdot
.62081 .40514 Mdot
.69717 .56857 Mdot
.69718 .56693 Mdot
.62769 .40631 Mdot
.68172 .29934 Mdot
.34552 .5556 Mdot
.27065 .41972 Mdot
.31613 .69364 Mdot
.71879 .59677 Mdot
.50833 .75906 Mdot
.35758 .5574 Mdot
.43073 .39634 Mdot
.61721 .45397 Mdot
.66669 .56339 Mdot
.31392 .64698 Mdot
.39623 .39651 Mdot
.62385 .42052 Mdot
.65234 .30576 Mdot
.62355 .43765 Mdot
.6112 .44529 Mdot
.32198 .67379 Mdot
.59325 .78389 Mdot
.36917 .65565 Mdot
.73276 .58143 Mdot
.61497 .43027 Mdot
.25038 .49576 Mdot
.70846 .60446 Mdot
.5305 .77798 Mdot
.29284 .43667 Mdot
.39914 .42767 Mdot
.70158 .57745 Mdot
.31865 .65338 Mdot
.57964 .68589 Mdot
.31391 .31824 Mdot
.34771 .63373 Mdot
.63451 .40768 Mdot
.61169 .44318 Mdot
.6941 .58975 Mdot
.34846 .66041 Mdot
.26686 .44831 Mdot
.33984 .63906 Mdot
.52726 .68622 Mdot
.41114 .37764 Mdot
.37879 .75279 Mdot
.62571 .41717 Mdot
.35791 .62222 Mdot
.64166 .57352 Mdot
.65886 .29656 Mdot
.41313 .38193 Mdot
.38065 .75968 Mdot
.40861 .41345 Mdot
.52287 .68791 Mdot
.61659 .46824 Mdot
.26062 .42649 Mdot
.42862 .41488 Mdot
.39692 .35656 Mdot
.50567 .73094 Mdot
.42771 .4194 Mdot
.37508 .34714 Mdot
.30567 .51686 Mdot
.37609 .63785 Mdot
.4184 .41236 Mdot
.6651 .58106 Mdot
.60792 .61765 Mdot
.39457 .38403 Mdot
.73759 .57717 Mdot
.32456 .31624 Mdot
.59187 .40712 Mdot
.68712 .31352 Mdot
.50054 .30182 Mdot
.42421 .3966 Mdot
.42971 .441 Mdot
.40748 .37525 Mdot
.46353 .39137 Mdot
.69518 .57838 Mdot
.63876 .55478 Mdot
.64979 .29903 Mdot
.33226 .38435 Mdot
.66164 .31161 Mdot
.56418 .67534 Mdot
.27759 .4566 Mdot
.64982 .44176 Mdot
.35323 .62861 Mdot
.40378 .41111 Mdot
.63745 .56446 Mdot
.41742 .39001 Mdot
.2787 .44403 Mdot
.67906 .58475 Mdot
.67065 .56212 Mdot
.66401 .54598 Mdot
.6299 .33799 Mdot
.36484 .62803 Mdot
.44894 .42776 Mdot
.64907 .34198 Mdot
.60612 .40137 Mdot
.39913 .27931 Mdot
.36865 .6306 Mdot
.36321 .62161 Mdot
.35619 .61232 Mdot
.44878 .43278 Mdot
.45053 .43003 Mdot
.54031 .67758 Mdot
.36179 .55842 Mdot
.51409 .72108 Mdot
.70477 .58168 Mdot
.71085 .57187 Mdot
.42033 .39228 Mdot
.63272 .29053 Mdot
.65019 .31824 Mdot
.66467 .59203 Mdot
.6405 .45332 Mdot
.66025 .29379 Mdot
.44176 .43519 Mdot
.70326 .59005 Mdot
.64454 .3439 Mdot
.31178 .71533 Mdot
.4271 .72156 Mdot
.66023 .29579 Mdot
.62637 .41502 Mdot
.33622 .53634 Mdot
.51208 .31154 Mdot
.64331 .28778 Mdot
.56923 .67777 Mdot
.37408 .32647 Mdot
.64299 .45118 Mdot
.66863 .29739 Mdot
.52546 .3226 Mdot
.68824 .58306 Mdot
.62581 .41352 Mdot
.68983 .27299 Mdot
.44715 .37953 Mdot
.66595 .29823 Mdot
.36152 .6211 Mdot
.38608 .63831 Mdot
.42992 .40906 Mdot
.28399 .43104 Mdot
.57169 .69118 Mdot
.63036 .57003 Mdot
.63638 .55982 Mdot
.36595 .57091 Mdot
.33986 .32326 Mdot
.6765 .58897 Mdot
.37052 .34298 Mdot
.67461 .30489 Mdot
.38293 .38076 Mdot
.59728 .44789 Mdot
.2644 .42342 Mdot
.68569 .32366 Mdot
.65965 .2962 Mdot
.57366 .68128 Mdot
.53701 .69504 Mdot
.54001 .71497 Mdot
.68293 .59036 Mdot
.35735 .3257 Mdot
.64192 .55436 Mdot
.29401 .51954 Mdot
.64051 .325 Mdot
.79469 .59197 Mdot
.44963 .41389 Mdot
.41737 .43488 Mdot
.2483 .43953 Mdot
.60627 .44363 Mdot
.41725 .39242 Mdot
.54628 .67865 Mdot
.64293 .58452 Mdot
.57847 .64984 Mdot
.33445 .67208 Mdot
.29661 .51925 Mdot
.67602 .56396 Mdot
.63716 .46459 Mdot
.65603 .31894 Mdot
.49416 .28464 Mdot
.6625 .28191 Mdot
.67593 .55686 Mdot
.40478 .43686 Mdot
.31024 .65689 Mdot
.81326 .57279 Mdot
.40429 .40704 Mdot
.67041 .59091 Mdot
.64109 .59348 Mdot
.27323 .42409 Mdot
.50568 .39394 Mdot
.58119 .64678 Mdot
.34844 .32803 Mdot
.63042 .34116 Mdot
.59929 .40634 Mdot
.32797 .30258 Mdot
.69549 .58228 Mdot
.66023 .59376 Mdot
.63999 .29168 Mdot
.3783 .64828 Mdot
.33627 .6262 Mdot
.34847 .55817 Mdot
.54432 .67786 Mdot
.38808 .4168 Mdot
.70083 .58956 Mdot
.37978 .63974 Mdot
.367 .35252 Mdot
.54697 .70691 Mdot
.68069 .59745 Mdot
.40239 .4163 Mdot
.42733 .411 Mdot
.66009 .30962 Mdot
.60016 .45676 Mdot
.59401 .42392 Mdot
.52845 .77516 Mdot
.36371 .36084 Mdot
.27289 .45849 Mdot
.4059 .43093 Mdot
.32425 .66171 Mdot
.60735 .41161 Mdot
.64925 .31549 Mdot
.43029 .39018 Mdot
.42632 .37229 Mdot
.31683 .64982 Mdot
.55605 .70589 Mdot
.61875 .42812 Mdot
.34504 .36886 Mdot
.40512 .41633 Mdot
.42869 .39933 Mdot
.27773 .45141 Mdot
.45558 .42408 Mdot
.68013 .60416 Mdot
.35631 .66711 Mdot
.65473 .33985 Mdot
.34837 .64433 Mdot
.77473 .5925 Mdot
.29166 .44044 Mdot
.37063 .33147 Mdot
.31717 .67638 Mdot
.3539 .64851 Mdot
.52198 .68933 Mdot
.54284 .68923 Mdot
.66374 .43574 Mdot
.39418 .37619 Mdot
.63948 .45038 Mdot
.33336 .64382 Mdot
.63093 .56831 Mdot
.66268 .31126 Mdot
.7769 .59786 Mdot
.39828 .42123 Mdot
.69842 .5857 Mdot
.60881 .43202 Mdot
.32799 .67381 Mdot
.68667 .56676 Mdot
.59794 .42381 Mdot
.63286 .31804 Mdot
.38312 .34018 Mdot
.66297 .43787 Mdot
.63244 .42543 Mdot
.3916 .37491 Mdot
.261 .46762 Mdot
.27992 .42944 Mdot
.59215 .43196 Mdot
.62634 .58023 Mdot
.62891 .42539 Mdot
.38786 .61469 Mdot
.27843 .42573 Mdot
.63667 .57593 Mdot
.35934 .55738 Mdot
.29235 .43695 Mdot
.63307 .42103 Mdot
.36997 .62524 Mdot
.77159 .5899 Mdot
.30534 .6801 Mdot
.51556 .32322 Mdot
.39279 .39039 Mdot
.69892 .59369 Mdot
.65203 .31001 Mdot
.5371 .67723 Mdot
.56633 .65988 Mdot
.51235 .75658 Mdot
.71765 .58549 Mdot
.40227 .41193 Mdot
.33763 .63611 Mdot
.54737 .69206 Mdot
.38426 .59577 Mdot
.64879 .56276 Mdot
.65926 .57328 Mdot
.24903 .43962 Mdot
.66245 .31309 Mdot
.45162 .41748 Mdot
.63189 .56701 Mdot
.75283 .59585 Mdot
.30843 .51641 Mdot
.64308 .34439 Mdot
.27233 .45533 Mdot
.58988 .4334 Mdot
.39303 .36206 Mdot
.31777 .52541 Mdot
.61907 .44758 Mdot
.33391 .67157 Mdot
.43117 .42673 Mdot
.62686 .76483 Mdot
.71155 .60413 Mdot
.3488 .32893 Mdot
.57944 .64268 Mdot
.53124 .69509 Mdot
.69048 .5724 Mdot
.39565 .40192 Mdot
.77701 .59842 Mdot
.6423 .30575 Mdot
.24172 .44129 Mdot
.63808 .42957 Mdot
.37358 .57464 Mdot
.51704 .71522 Mdot
.67849 .26977 Mdot
.53827 .67668 Mdot
.54579 .71442 Mdot
.32267 .71336 Mdot
.42918 .40735 Mdot
.67467 .56795 Mdot
.65647 .57731 Mdot
.59989 .45025 Mdot
.75628 .6037 Mdot
.33998 .62145 Mdot
.6247 .76127 Mdot
.41184 .35947 Mdot
.41453 .42098 Mdot
.63158 .40518 Mdot
.63585 .45121 Mdot
.76648 .59441 Mdot
.42919 .42037 Mdot
.37429 .6357 Mdot
.63196 .56102 Mdot
.6888 .59531 Mdot
.28714 .43691 Mdot
.5374 .69421 Mdot
.66276 .28116 Mdot
.66846 .57666 Mdot
.41275 .28238 Mdot
.41748 .38861 Mdot
.58219 .68311 Mdot
.67123 .57795 Mdot
.84703 .5122 Mdot
.5843 .80074 Mdot
.37275 .65095 Mdot
.39339 .34935 Mdot
.38284 .6103 Mdot
.66347 .29823 Mdot
.65467 .55365 Mdot
.56475 .66815 Mdot
.61714 .4328 Mdot
.61047 .63866 Mdot
.69153 .59331 Mdot
.35472 .63719 Mdot
.43126 .4073 Mdot
.32464 .45695 Mdot
.4058 .41905 Mdot
.51905 .36902 Mdot
.62699 .3434 Mdot
.5664 .65964 Mdot
.51636 .69375 Mdot
.39401 .34971 Mdot
.64122 .34319 Mdot
.68195 .55652 Mdot
.68216 .58565 Mdot
.38896 .75714 Mdot
.61075 .44457 Mdot
.67258 .55226 Mdot
.39317 .3748 Mdot
.66797 .54632 Mdot
.33354 .53737 Mdot
.53123 .69732 Mdot
.37833 .36958 Mdot
.70412 .59407 Mdot
.31776 .68573 Mdot
.34974 .32286 Mdot
.39898 .38393 Mdot
.61853 .45817 Mdot
.54709 .68941 Mdot
.29193 .51606 Mdot
.67686 .60588 Mdot
.38403 .40008 Mdot
.55575 .67812 Mdot
.66111 .2625 Mdot
.6118 .66107 Mdot
.366 .62826 Mdot
.66461 .58755 Mdot
.51998 .71547 Mdot
.61 .42407 Mdot
.65913 .33943 Mdot
.66619 .55614 Mdot
.70148 .59764 Mdot
.27621 .43791 Mdot
.62853 .46461 Mdot
.6407 .2891 Mdot
.32837 .65857 Mdot
.55549 .70186 Mdot
.28202 .44256 Mdot
.42243 .28093 Mdot
.45074 .42769 Mdot
.54725 .715 Mdot
.26327 .50063 Mdot
.39752 .43159 Mdot
.3955 .42026 Mdot
.32433 .45405 Mdot
.38728 .61842 Mdot
.32192 .65049 Mdot
.35742 .36286 Mdot
.26641 .44326 Mdot
.36523 .32797 Mdot
.35753 .62986 Mdot
.35577 .63949 Mdot
.36605 .33345 Mdot
.27759 .4397 Mdot
.35112 .55073 Mdot
.54353 .6957 Mdot
.53265 .694 Mdot
.34103 .64691 Mdot
.24871 .43802 Mdot
.56199 .70638 Mdot
.38066 .59017 Mdot
.65504 .56766 Mdot
.32664 .31845 Mdot
.34838 .64852 Mdot
.34668 .31246 Mdot
.55355 .69268 Mdot
.43399 .27315 Mdot
.32383 .31678 Mdot
.43193 .44198 Mdot
.43004 .41272 Mdot
.63349 .33555 Mdot
.62033 .43759 Mdot
.62756 .40615 Mdot
.53804 .71572 Mdot
.45402 .42723 Mdot
.37064 .64087 Mdot
.45261 .42816 Mdot
.51799 .31526 Mdot
.44212 .2704 Mdot
.39625 .34544 Mdot
.36149 .63685 Mdot
.36264 .64921 Mdot
.72038 .57994 Mdot
.63314 .58004 Mdot
.36931 .34345 Mdot
.54368 .69034 Mdot
.35178 .62338 Mdot
.51409 .71976 Mdot
.69426 .58274 Mdot
.67302 .56581 Mdot
.60449 .41055 Mdot
.62491 .41264 Mdot
.6873 .57522 Mdot
.73981 .57899 Mdot
.41761 .28038 Mdot
.36271 .56112 Mdot
.27838 .50574 Mdot
.48202 .28514 Mdot
.35957 .48136 Mdot
.65109 .30786 Mdot
.68335 .29656 Mdot
.55224 .67774 Mdot
.4028 .35892 Mdot
.42709 .43175 Mdot
.63156 .4326 Mdot
.55921 .68162 Mdot
.65062 .32804 Mdot
.53092 .69649 Mdot
.66103 .33773 Mdot
.63757 .57485 Mdot
.3985 .40988 Mdot
.42005 .43972 Mdot
.52165 .69024 Mdot
.70317 .5655 Mdot
.70582 .59075 Mdot
.64813 .31055 Mdot
.48862 .28963 Mdot
.69515 .58844 Mdot
.34956 .64848 Mdot
.32296 .73528 Mdot
.61972 .44666 Mdot
.39643 .39817 Mdot
.49876 .29864 Mdot
.28097 .42652 Mdot
.60762 .40104 Mdot
.61922 .42764 Mdot
.29773 .52543 Mdot
.44337 .42005 Mdot
.40844 .74927 Mdot
.61675 .40559 Mdot
.35868 .60936 Mdot
.67802 .5695 Mdot
.61693 .40265 Mdot
.58728 .42548 Mdot
.67255 .34128 Mdot
.62265 .40193 Mdot
.32982 .63545 Mdot
.38198 .60765 Mdot
.25716 .44255 Mdot
.22432 .4723 Mdot
.66568 .32961 Mdot
.64664 .32263 Mdot
.69302 .60475 Mdot
.50783 .74656 Mdot
.3227 .42947 Mdot
.64062 .32003 Mdot
.30639 .69969 Mdot
.24809 .44523 Mdot
.26283 .43198 Mdot
.2656 .43344 Mdot
.38425 .59898 Mdot
.39629 .43638 Mdot
.69279 .60635 Mdot
.35577 .63546 Mdot
.25403 .44312 Mdot
.45176 .43663 Mdot
.37075 .6343 Mdot
.55186 .70751 Mdot
.24594 .45881 Mdot
.34137 .634 Mdot
.31364 .31436 Mdot
.55736 .69318 Mdot
.41538 .36606 Mdot
.7679 .56471 Mdot
.85134 .49718 Mdot
.53009 .70224 Mdot
.6781 .5965 Mdot
.7021 .5868 Mdot
.67947 .58732 Mdot
.32358 .65125 Mdot
.72854 .59092 Mdot
.34736 .66299 Mdot
.7719 .59828 Mdot
.33737 .37931 Mdot
.66712 .32125 Mdot
.74819 .59763 Mdot
.34082 .64553 Mdot
.3102 .52518 Mdot
.56977 .16145 Mdot
.38336 .39594 Mdot
.56994 .6674 Mdot
.64215 .29986 Mdot
.34331 .31786 Mdot
.63916 .33371 Mdot
.6956 .57145 Mdot
.34221 .3684 Mdot
.41931 .39053 Mdot
.42238 .72889 Mdot
.65383 .31104 Mdot
.35503 .64089 Mdot
.27517 .43532 Mdot
.62042 .57291 Mdot
.64284 .30704 Mdot
.66022 .31551 Mdot
.40823 .38935 Mdot
.38211 .60241 Mdot
.70339 .57726 Mdot
.55888 .68427 Mdot
.75328 .59207 Mdot
.41816 .30471 Mdot
.44276 .41668 Mdot
.38428 .40804 Mdot
.35197 .31856 Mdot
.77243 .59541 Mdot
.53923 .69867 Mdot
.52539 .33683 Mdot
.67038 .60526 Mdot
.51285 .30767 Mdot
.32542 .68435 Mdot
.74958 .59932 Mdot
.62354 .44824 Mdot
.59848 .41701 Mdot
.40432 .39967 Mdot
.57863 .16614 Mdot
.5075 .38754 Mdot
.56538 .70131 Mdot
.6313 .44317 Mdot
.73196 .59277 Mdot
.32435 .63423 Mdot
.69376 .27665 Mdot
.26287 .44613 Mdot
.56065 .68579 Mdot
.6888 .58715 Mdot
.61333 .18718 Mdot
.62848 .33067 Mdot
.34866 .3335 Mdot
.38583 .38793 Mdot
.40281 .39701 Mdot
.54023 .71143 Mdot
.5747 .6911 Mdot
.29072 .51069 Mdot
.58377 .41646 Mdot
.36968 .75636 Mdot
.50339 .72511 Mdot
.62674 .19471 Mdot
.63826 .44944 Mdot
.35959 .65701 Mdot
.63638 .41146 Mdot
.57465 .68837 Mdot
.43457 .42483 Mdot
.3822 .60513 Mdot
.60761 .43288 Mdot
.34387 .69452 Mdot
.27089 .42884 Mdot
.41073 .28172 Mdot
.41373 .40198 Mdot
.35573 .61563 Mdot
.35915 .63106 Mdot
.37872 .61504 Mdot
.60507 .43413 Mdot
.40454 .42768 Mdot
.38842 .40907 Mdot
.38699 .41296 Mdot
.29238 .50924 Mdot
.40047 .40856 Mdot
.3086 .65619 Mdot
.33864 .32653 Mdot
.63095 .77169 Mdot
.42022 .4393 Mdot
.52459 .71703 Mdot
.4085 .39958 Mdot
.62266 .32831 Mdot
.38532 .34614 Mdot
.28786 .43073 Mdot
.54098 .70187 Mdot
.45728 .42956 Mdot
.61571 .31656 Mdot
.44492 .4319 Mdot
.66686 .33279 Mdot
.54076 .78913 Mdot
.52225 .34052 Mdot
.32685 .52768 Mdot
.34013 .64119 Mdot
.64642 .55987 Mdot
.56688 .70687 Mdot
.68693 .56197 Mdot
.26486 .4203 Mdot
.6471 .43246 Mdot
.7932 .59249 Mdot
.42665 .27914 Mdot
.43311 .42556 Mdot
.62631 .454 Mdot
.37452 .62973 Mdot
.70693 .60544 Mdot
.37833 .48995 Mdot
.24779 .44119 Mdot
.647 .29119 Mdot
.63512 .32688 Mdot
.6294 .47649 Mdot
.38304 .62718 Mdot
.3318 .54001 Mdot
.5409 .71021 Mdot
.6846 .59185 Mdot
.66601 .34154 Mdot
.30124 .69444 Mdot
.57815 .68742 Mdot
.76267 .59358 Mdot
.51741 .71309 Mdot
.41289 .43538 Mdot
.62439 .40416 Mdot
.35697 .5513 Mdot
.63567 .43677 Mdot
.44314 .4065 Mdot
.70434 .59573 Mdot
.6155 .44667 Mdot
.64324 .34046 Mdot
.52484 .71936 Mdot
.67907 .56308 Mdot
.42972 .4029 Mdot
.36048 .62693 Mdot
.282 .33774 Mdot
.71157 .61126 Mdot
.28959 .43525 Mdot
.29036 .43607 Mdot
.36944 .56448 Mdot
.58941 .41367 Mdot
.61744 .68172 Mdot
.2797 .42408 Mdot
.50781 .75364 Mdot
.64172 .2847 Mdot
.78869 .59617 Mdot
.6416 .55651 Mdot
.68251 .57969 Mdot
.43991 .42743 Mdot
.63045 .56001 Mdot
.37062 .33918 Mdot
.62152 .57352 Mdot
.52296 .77729 Mdot
.42045 .45002 Mdot
.67773 .58298 Mdot
.62026 .40696 Mdot
.40302 .37756 Mdot
.37365 .64336 Mdot
.65249 .55063 Mdot
.43251 .44197 Mdot
.74942 .57641 Mdot
.52279 .68856 Mdot
.60283 .43115 Mdot
.3594 .31486 Mdot
.54807 .69585 Mdot
.3264 .64023 Mdot
.37719 .32697 Mdot
.6391 .31333 Mdot
.35741 .65494 Mdot
.65331 .45911 Mdot
.6628 .3155 Mdot
.33961 .31368 Mdot
.33984 .65598 Mdot
.62752 .44741 Mdot
.63357 .32099 Mdot
.68544 .31541 Mdot
.68467 .58153 Mdot
.6451 .59565 Mdot
.62897 .42177 Mdot
.42701 .39632 Mdot
.73073 .60515 Mdot
.52506 .70731 Mdot
.39105 .38422 Mdot
.69846 .5925 Mdot
.6218 .44364 Mdot
.39048 .4088 Mdot
.26522 .44327 Mdot
.3129 .5206 Mdot
.593 .40231 Mdot
.66122 .33299 Mdot
.38037 .62213 Mdot
.38349 .40059 Mdot
.67002 .32255 Mdot
.73844 .59653 Mdot
.38263 .37279 Mdot
.36829 .61783 Mdot
.30823 .70648 Mdot
.62929 .56953 Mdot
.55873 .70228 Mdot
.65407 .57719 Mdot
.67009 .3334 Mdot
.56643 .15957 Mdot
.61273 .40776 Mdot
.25136 .42912 Mdot
.3785 .34266 Mdot
.64549 .55766 Mdot
.3638 .63001 Mdot
.35087 .75691 Mdot
.38524 .34503 Mdot
.38359 .37336 Mdot
.39886 .39451 Mdot
.76285 .59706 Mdot
.32686 .63281 Mdot
.39727 .39618 Mdot
.67918 .29852 Mdot
.37818 .38894 Mdot
.65495 .29901 Mdot
.77397 .57773 Mdot
.59696 .41781 Mdot
.24269 .49222 Mdot
.60587 .43163 Mdot
.6693 .58033 Mdot
.31356 .31256 Mdot
.3605 .3254 Mdot
.66866 .45704 Mdot
.32669 .63808 Mdot
.31792 .69362 Mdot
.67161 .56748 Mdot
.77468 .59145 Mdot
.26104 .44837 Mdot
.27271 .4368 Mdot
.40863 .3808 Mdot
.6952 .57122 Mdot
.6533 .59225 Mdot
.64465 .42826 Mdot
.62712 .45339 Mdot
.41731 .36791 Mdot
.63842 .57102 Mdot
.39864 .409 Mdot
.26038 .42831 Mdot
.57703 .6908 Mdot
.37792 .63682 Mdot
.5758 .67008 Mdot
.58153 .67927 Mdot
.36824 .48467 Mdot
.36423 .36516 Mdot
.54735 .67679 Mdot
.56886 .6843 Mdot
.75751 .59289 Mdot
.44461 .38184 Mdot
.66285 .29926 Mdot
.50961 .38909 Mdot
.68521 .55988 Mdot
.40945 .42835 Mdot
.33549 .62309 Mdot
.60191 .39574 Mdot
.33476 .75024 Mdot
.57857 .27142 Mdot
.26173 .45495 Mdot
.70446 .60806 Mdot
.63298 .42525 Mdot
.63774 .43571 Mdot
.51251 .31127 Mdot
.39883 .40686 Mdot
.62953 .56855 Mdot
.44704 .37995 Mdot
.50346 .72604 Mdot
.76291 .59188 Mdot
.3843 .62522 Mdot
.40759 .40273 Mdot
.33002 .66451 Mdot
.54821 .7169 Mdot
.66874 .30981 Mdot
.63012 .33637 Mdot
.4424 .43314 Mdot
.29322 .43616 Mdot
.50725 .75406 Mdot
.26567 .43927 Mdot
.27719 .44342 Mdot
.62647 .42467 Mdot
.27462 .45469 Mdot
.38228 .39436 Mdot
.42526 .4486 Mdot
.60538 .40139 Mdot
.58226 .67493 Mdot
.46197 .44467 Mdot
.63382 .42236 Mdot
.38467 .33879 Mdot
.54383 .71906 Mdot
.26304 .44178 Mdot
.52839 .71235 Mdot
.7673 .59276 Mdot
.53442 .68209 Mdot
.65288 .33993 Mdot
.75456 .59508 Mdot
.28318 .50719 Mdot
.33896 .63502 Mdot
.5383 .69 Mdot
.63315 .31591 Mdot
.52538 .71271 Mdot
.67391 .55827 Mdot
.50136 .72783 Mdot
.38598 .58784 Mdot
.4073 .28265 Mdot
.35819 .47835 Mdot
.5126 .72882 Mdot
.63484 .57956 Mdot
.33993 .64674 Mdot
.5094 .75036 Mdot
.37827 .33338 Mdot
.62684 .3304 Mdot
.40482 .39762 Mdot
.53301 .71881 Mdot
.73343 .60166 Mdot
.32644 .53092 Mdot
.6556 .33776 Mdot
.28851 .51599 Mdot
.6385 .56568 Mdot
.38012 .40631 Mdot
.52035 .68529 Mdot
.61345 .6827 Mdot
.51772 .6933 Mdot
.33311 .3726 Mdot
.64313 .44953 Mdot
.58356 .42474 Mdot
.35267 .65546 Mdot
.63193 .45605 Mdot
.66037 .25378 Mdot
.51612 .76407 Mdot
.35945 .66322 Mdot
.72872 .58102 Mdot
.42596 .39409 Mdot
.26647 .45838 Mdot
.61685 .41099 Mdot
.35339 .6194 Mdot
.27879 .45048 Mdot
.60167 .41232 Mdot
.33716 .32577 Mdot
.38231 .61879 Mdot
.68129 .55494 Mdot
.39516 .37556 Mdot
.54984 .66995 Mdot
.50606 .71826 Mdot
.63656 .41003 Mdot
.54754 .673 Mdot
.3852 .33969 Mdot
.3441 .65395 Mdot
.25789 .4436 Mdot
.65273 .29833 Mdot
.34956 .56043 Mdot
.60836 .39594 Mdot
.64183 .36213 Mdot
.38628 .37467 Mdot
.67339 .56707 Mdot
.61081 .63945 Mdot
.38973 .35386 Mdot
.35506 .63285 Mdot
.37623 .34355 Mdot
.2772 .45249 Mdot
.26909 .43785 Mdot
.68512 .59189 Mdot
.34863 .31852 Mdot
.39995 .40969 Mdot
.56172 .69018 Mdot
.46401 .33763 Mdot
.4313 .38554 Mdot
.67778 .29895 Mdot
.28754 .43049 Mdot
.50518 .70455 Mdot
.36649 .56511 Mdot
.67482 .56915 Mdot
.36806 .64593 Mdot
.38421 .5925 Mdot
.32631 .64384 Mdot
.30016 .6797 Mdot
.27992 .42437 Mdot
.39335 .75724 Mdot
.33306 .53756 Mdot
.34494 .47208 Mdot
.3158 .64088 Mdot
.61887 .65918 Mdot
.35826 .6645 Mdot
.32638 .63984 Mdot
.33796 .73493 Mdot
.33048 .6302 Mdot
.42418 .39474 Mdot
.37476 .37264 Mdot
.40312 .35069 Mdot
.76444 .59909 Mdot
.40528 .41983 Mdot
.61587 .39958 Mdot
.64396 .29616 Mdot
.37721 .64932 Mdot
.61882 .4316 Mdot
.34204 .31274 Mdot
.65236 .44979 Mdot
.41019 .38966 Mdot
.39178 .40455 Mdot
.26658 .43453 Mdot
.45235 .26842 Mdot
.76504 .60026 Mdot
.3625 .61019 Mdot
.44169 .39873 Mdot
.61166 .66167 Mdot
.39594 .37771 Mdot
.38221 .34703 Mdot
.41422 .44469 Mdot
.67465 .56788 Mdot
.38604 .59701 Mdot
.63942 .42387 Mdot
.35075 .55906 Mdot
.4114 .41133 Mdot
.64512 .4108 Mdot
.6667 .29132 Mdot
.39484 .4002 Mdot
.37611 .60293 Mdot
.27878 .45106 Mdot
.31674 .65564 Mdot
.34261 .65795 Mdot
.38267 .37382 Mdot
.38076 .63993 Mdot
.32099 .65327 Mdot
.27217 .43746 Mdot
.70805 .60807 Mdot
.52939 .77719 Mdot
.411 .38679 Mdot
.65351 .33748 Mdot
.43099 .41874 Mdot
.66633 .30058 Mdot
.61964 .40205 Mdot
.6309 .42584 Mdot
.49648 .40929 Mdot
.65183 .58907 Mdot
.65004 .28768 Mdot
.75967 .60003 Mdot
.26342 .41606 Mdot
.31813 .70214 Mdot
.50263 .7293 Mdot
.64317 .59533 Mdot
.62961 .42648 Mdot
.51642 .36235 Mdot
.42383 .30872 Mdot
.54868 .67423 Mdot
.32536 .6772 Mdot
.46492 .44291 Mdot
.62596 .45546 Mdot
.68327 .55539 Mdot
.65734 .57645 Mdot
.51493 .76328 Mdot
.33792 .73373 Mdot
.42413 .43887 Mdot
.62371 .45437 Mdot
.27862 .4629 Mdot
.61979 .43817 Mdot
.63944 .42036 Mdot
.69585 .59956 Mdot
.39503 .41412 Mdot
.33274 .31188 Mdot
.70104 .58319 Mdot
.6534 .32164 Mdot
.33322 .67112 Mdot
.66694 .33046 Mdot
.4332 .71364 Mdot
.28867 .50958 Mdot
.69149 .57599 Mdot
.59782 .42916 Mdot
.4108 .42581 Mdot
.38527 .60189 Mdot
.3784 .59617 Mdot
.373 .64683 Mdot
.64779 .29768 Mdot
.63312 .56209 Mdot
.78251 .59006 Mdot
.42905 .40459 Mdot
.3558 .64666 Mdot
.66234 .3474 Mdot
.42684 .41183 Mdot
.54036 .69136 Mdot
.28315 .4463 Mdot
.35161 .64528 Mdot
.249 .43209 Mdot
.3511 .65635 Mdot
.66169 .57855 Mdot
.43742 .43398 Mdot
.41928 .38768 Mdot
.52253 .34357 Mdot
.64994 .32861 Mdot
.31491 .65072 Mdot
.36495 .36261 Mdot
.39379 .36239 Mdot
.50739 .30701 Mdot
.3914 .39974 Mdot
.35468 .47602 Mdot
.62346 .4623 Mdot
.60548 .40778 Mdot
.37832 .34024 Mdot
.4009 .38563 Mdot
.3753 .59792 Mdot
.33423 .53454 Mdot
.28998 .50777 Mdot
.55154 .71366 Mdot
.3614 .66296 Mdot
.70086 .57981 Mdot
.65867 .54969 Mdot
.70949 .57176 Mdot
.66774 .33808 Mdot
.26042 .44418 Mdot
.43033 .43318 Mdot
.5621 .70437 Mdot
.63761 .31659 Mdot
.36243 .64142 Mdot
.66502 .30989 Mdot
.35692 .3347 Mdot
.64522 .33878 Mdot
.64714 .42809 Mdot
.57991 .80081 Mdot
.26097 .4282 Mdot
.66008 .32453 Mdot
.37862 .6307 Mdot
.51026 .38081 Mdot
.43621 .45267 Mdot
.30699 .52302 Mdot
.64858 .29021 Mdot
.74135 .59549 Mdot
.38705 .37613 Mdot
.33038 .39358 Mdot
.53384 .71483 Mdot
.65802 .33947 Mdot
.5169 .71081 Mdot
.27445 .44905 Mdot
.3189 .69241 Mdot
.34962 .63806 Mdot
.50408 .73124 Mdot
.37952 .34561 Mdot
.65642 .34043 Mdot
.68875 .5777 Mdot
.44029 .37664 Mdot
.77219 .60006 Mdot
.65727 .44801 Mdot
.5155 .3184 Mdot
.68616 .60551 Mdot
.45892 .42456 Mdot
.52496 .69028 Mdot
.44896 .41444 Mdot
.25911 .42612 Mdot
.39688 .36503 Mdot
.70878 .58602 Mdot
.68141 .57928 Mdot
.78649 .59526 Mdot
.44424 .41867 Mdot
.42734 .44451 Mdot
.37549 .57777 Mdot
.63168 .5644 Mdot
.32725 .6469 Mdot
.35763 .61617 Mdot
.68189 .59711 Mdot
.31471 .66583 Mdot
.66134 .31459 Mdot
.3505 .35927 Mdot
.52578 .68959 Mdot
.51062 .70222 Mdot
.68868 .57481 Mdot
.70941 .59834 Mdot
.6738 .5662 Mdot
.27579 .45043 Mdot
.33672 .65615 Mdot
.37308 .38847 Mdot
.41192 .39547 Mdot
.45029 .43372 Mdot
.38541 .61781 Mdot
.38394 .34238 Mdot
.4028 .46352 Mdot
.65295 .29303 Mdot
.66753 .57744 Mdot
.518 .72135 Mdot
.28318 .3438 Mdot
.56244 .69558 Mdot
.37837 .38237 Mdot
.52175 .77297 Mdot
.32671 .67669 Mdot
.63693 .33475 Mdot
.28192 .42937 Mdot
.63832 .34064 Mdot
.57658 .69157 Mdot
.37228 .57905 Mdot
.33954 .31896 Mdot
.38816 .4256 Mdot
.3555 .32678 Mdot
.76346 .50855 Mdot
.37532 .59343 Mdot
.55465 .69837 Mdot
.27126 .42701 Mdot
.65137 .45507 Mdot
.29884 .44615 Mdot
.43832 .42788 Mdot
.44412 .40326 Mdot
.32618 .3983 Mdot
.37644 .36935 Mdot
.37323 .65104 Mdot
.36722 .33977 Mdot
.60052 .43723 Mdot
.41176 .37974 Mdot
.40752 .74551 Mdot
.41402 .41678 Mdot
.42524 .44103 Mdot
.41972 .43285 Mdot
.39722 .36266 Mdot
.38602 .63081 Mdot
.26271 .43436 Mdot
.56104 .69974 Mdot
.34936 .35739 Mdot
.52457 .69261 Mdot
.68564 .57059 Mdot
.59644 .39873 Mdot
.3874 .60688 Mdot
.63655 .33991 Mdot
.46948 .67374 Mdot
.33173 .39042 Mdot
.71872 .57834 Mdot
.52265 .35403 Mdot
.65833 .28086 Mdot
.63353 .41241 Mdot
.66526 .33857 Mdot
.70443 .59434 Mdot
.53443 .69759 Mdot
.40307 .43574 Mdot
.33098 .64603 Mdot
.34637 .62862 Mdot
.40317 .37562 Mdot
.53735 .78068 Mdot
.50606 .7178 Mdot
.74848 .59716 Mdot
.4206 .43798 Mdot
.37842 .36917 Mdot
.32119 .66234 Mdot
.72176 .6018 Mdot
.36452 .32466 Mdot
.64512 .31029 Mdot
.39168 .37902 Mdot
.61091 .44899 Mdot
.35635 .33252 Mdot
.55693 .70707 Mdot
.62041 .44492 Mdot
.41915 .42232 Mdot
.36275 .36621 Mdot
.2419 .44594 Mdot
.59545 .44779 Mdot
.63086 .58127 Mdot
.38307 .37467 Mdot
.40619 .38148 Mdot
.38264 .61855 Mdot
.52812 .68599 Mdot
.36465 .62873 Mdot
.38402 .58279 Mdot
.63064 .42612 Mdot
.52044 .68979 Mdot
.39567 .36221 Mdot
.50013 .71942 Mdot
.28492 .44442 Mdot
.41869 .3953 Mdot
.55408 .70023 Mdot
.34026 .66075 Mdot
.37226 .75333 Mdot
.46207 .44531 Mdot
.27786 .44502 Mdot
.42962 .41881 Mdot
.75374 .59247 Mdot
.60273 .39532 Mdot
.38193 .41344 Mdot
.34965 .62495 Mdot
.42722 .41024 Mdot
.56146 .70972 Mdot
.66888 .31437 Mdot
.35289 .63183 Mdot
.69567 .60807 Mdot
.66848 .58495 Mdot
.62973 .57517 Mdot
.6474 .43017 Mdot
.27665 .45339 Mdot
.37932 .61849 Mdot
.36737 .61393 Mdot
.35994 .3319 Mdot
.66987 .58051 Mdot
.65475 .30488 Mdot
.42428 .38942 Mdot
.61537 .45268 Mdot
.56236 .66435 Mdot
.23995 .49098 Mdot
.34231 .32869 Mdot
.67532 .32684 Mdot
.44588 .32051 Mdot
.62517 .42703 Mdot
.39874 .42302 Mdot
.65678 .33992 Mdot
.68863 .59725 Mdot
.24263 .45109 Mdot
.64798 .27964 Mdot
.74587 .60193 Mdot
.72229 .58859 Mdot
.50587 .72343 Mdot
.62582 .5783 Mdot
.64778 .3438 Mdot
.61673 .4063 Mdot
.34834 .63066 Mdot
.39567 .40349 Mdot
.62214 .41639 Mdot
.66093 .56941 Mdot
.64367 .44336 Mdot
.40619 .43387 Mdot
.32261 .66634 Mdot
.6798 .55997 Mdot
.42013 .39336 Mdot
.27534 .42345 Mdot
.31231 .51976 Mdot
.71595 .60542 Mdot
.37197 .3409 Mdot
.68978 .27153 Mdot
.71216 .57638 Mdot
.70979 .58882 Mdot
.38294 .37125 Mdot
.62696 .31614 Mdot
.41096 .40665 Mdot
.53807 .69494 Mdot
.35023 .30977 Mdot
.52145 .69033 Mdot
.51099 .30613 Mdot
.39275 .36936 Mdot
.40202 .35474 Mdot
.3235 .70196 Mdot
.64111 .27051 Mdot
.48405 .28455 Mdot
.38857 .411 Mdot
.32478 .63128 Mdot
.34724 .31204 Mdot
.40193 .28382 Mdot
.38443 .58903 Mdot
.67135 .30992 Mdot
.53642 .71597 Mdot
.42861 .39534 Mdot
.41367 .7407 Mdot
.65582 .30037 Mdot
.51121 .30892 Mdot
.41271 .36594 Mdot
.35872 .6371 Mdot
.4311 .43535 Mdot
.34474 .63746 Mdot
.42411 .42246 Mdot
.32214 .52555 Mdot
.50983 .75434 Mdot
.33347 .37376 Mdot
.61978 .40754 Mdot
.61322 .68184 Mdot
.35629 .47759 Mdot
.6586 .31061 Mdot
.25507 .4284 Mdot
.62898 .432 Mdot
.53066 .69674 Mdot
.5058 .73361 Mdot
.67218 .56611 Mdot
.55368 .68389 Mdot
.35548 .66214 Mdot
.7369 .6006 Mdot
.63569 .45345 Mdot
.25183 .46206 Mdot
.63576 .34272 Mdot
.5207 .68933 Mdot
.39381 .39281 Mdot
.45141 .4283 Mdot
.76329 .59721 Mdot
.77445 .57556 Mdot
.31085 .67702 Mdot
.27762 .50614 Mdot
.37282 .57888 Mdot
.64946 .3248 Mdot
.71941 .60537 Mdot
.42978 .42911 Mdot
.39896 .41582 Mdot
.72377 .59223 Mdot
.38644 .60192 Mdot
.6366 .3014 Mdot
.5833 .42267 Mdot
.5643 .70289 Mdot
.80704 .57973 Mdot
.35171 .63152 Mdot
.80767 .58124 Mdot
.7801 .59009 Mdot
.33294 .73358 Mdot
.48691 .28722 Mdot
.54469 .69686 Mdot
.80819 .58113 Mdot
.35834 .64079 Mdot
.37787 .39508 Mdot
.6333 .44216 Mdot
.64765 .43552 Mdot
.32929 .66776 Mdot
.68911 .56817 Mdot
.62707 .31407 Mdot
.44111 .42775 Mdot
.68246 .31884 Mdot
.38528 .59582 Mdot
.63543 .57108 Mdot
.61293 .43361 Mdot
.53326 .72112 Mdot
.42834 .41454 Mdot
.64792 .2964 Mdot
.54392 .69867 Mdot
.5983 .41613 Mdot
.34284 .36578 Mdot
.37694 .32689 Mdot
.29047 .4339 Mdot
.53391 .71366 Mdot
.3641 .33028 Mdot
.39498 .3806 Mdot
.5248 .69047 Mdot
.63656 .46578 Mdot
.61528 .68069 Mdot
.36473 .31751 Mdot
.5163 .76409 Mdot
.73095 .58938 Mdot
.62621 .57995 Mdot
.6381 .59451 Mdot
.76356 .60038 Mdot
.53049 .68814 Mdot
.61712 .42082 Mdot
.79368 .58978 Mdot
.52684 .68686 Mdot
.3879 .35155 Mdot
.4286 .39578 Mdot
.44964 .38251 Mdot
.59732 .41801 Mdot
.60224 .42443 Mdot
.35949 .55513 Mdot
.25761 .434 Mdot
.61422 .43337 Mdot
.389 .3913 Mdot
.37893 .60714 Mdot
.55536 .6929 Mdot
.67402 .23418 Mdot
.57204 .6935 Mdot
.24392 .45559 Mdot
.7008 .56467 Mdot
.738 .59948 Mdot
.3963 .40208 Mdot
.56115 .62561 Mdot
.6224 .19219 Mdot
.42938 .3964 Mdot
.28174 .42922 Mdot
.51355 .30852 Mdot
.40941 .37839 Mdot
.34341 .67588 Mdot
.60809 .44376 Mdot
.37916 .60984 Mdot
.54772 .69825 Mdot
.67035 .30799 Mdot
.66586 .25617 Mdot
.53853 .71515 Mdot
.4113 .41574 Mdot
.61742 .39667 Mdot
.40169 .39607 Mdot
.39055 .4203 Mdot
.36068 .35284 Mdot
.67552 .31312 Mdot
.67898 .56529 Mdot
.63714 .34099 Mdot
.32798 .63484 Mdot
.26707 .5018 Mdot
.65925 .30817 Mdot
.44291 .37963 Mdot
.35395 .31685 Mdot
.76994 .57633 Mdot
.34758 .62815 Mdot
.66441 .29851 Mdot
.52965 .71704 Mdot
.40383 .29185 Mdot
.42984 .3712 Mdot
.55945 .68533 Mdot
.39894 .42695 Mdot
.36656 .6115 Mdot
.36996 .5673 Mdot
.50454 .71132 Mdot
.36753 .62288 Mdot
.36428 .32876 Mdot
.27122 .44881 Mdot
.55844 .70638 Mdot
.46529 .27971 Mdot
.51655 .69357 Mdot
.38405 .4863 Mdot
.28378 .44053 Mdot
.35382 .63274 Mdot
.32758 .45963 Mdot
.36839 .58296 Mdot
.60239 .41372 Mdot
.37382 .35542 Mdot
.6554 .30703 Mdot
.35769 .32692 Mdot
.69122 .60871 Mdot
.3235 .68586 Mdot
.34496 .64654 Mdot
.58331 .66321 Mdot
.36444 .62282 Mdot
.31928 .67442 Mdot
.51315 .73269 Mdot
.35379 .66818 Mdot
.41104 .41231 Mdot
.22336 .47098 Mdot
.3754 .63214 Mdot
.54331 .70739 Mdot
.64327 .30254 Mdot
.37472 .64667 Mdot
.77864 .59248 Mdot
.39509 .37503 Mdot
.6483 .56464 Mdot
.63051 .30238 Mdot
.38651 .6245 Mdot
.65594 .31026 Mdot
.66338 .56552 Mdot
.66931 .28899 Mdot
.57236 .66197 Mdot
.51186 .69504 Mdot
.58793 .4278 Mdot
.51294 .76217 Mdot
.32929 .63197 Mdot
.73608 .60471 Mdot
.44703 .42423 Mdot
.41661 .43587 Mdot
.62254 .33706 Mdot
.31779 .64146 Mdot
.53941 .78535 Mdot
.61777 .43211 Mdot
.35296 .55237 Mdot
.52376 .72315 Mdot
.74699 .59623 Mdot
.33792 .31126 Mdot
.50505 .73787 Mdot
.59904 .43472 Mdot
.62706 .42811 Mdot
.39857 .39423 Mdot
.52394 .33755 Mdot
.66248 .33704 Mdot
.6182 .65424 Mdot
.25327 .45386 Mdot
.72022 .59644 Mdot
.41721 .42857 Mdot
.25284 .44495 Mdot
.38277 .39736 Mdot
.66719 .34059 Mdot
.55683 .67974 Mdot
.34126 .63201 Mdot
.66844 .30224 Mdot
.66851 .58529 Mdot
.31775 .31132 Mdot
.37992 .40979 Mdot
.37046 .33506 Mdot
.6975 .56776 Mdot
.33872 .62346 Mdot
.68149 .57387 Mdot
.5251 .69059 Mdot
.6629 .30961 Mdot
.27792 .45066 Mdot
.597 .41937 Mdot
.64545 .55695 Mdot
.53719 .6898 Mdot
.7024 .60927 Mdot
.50647 .72572 Mdot
.63024 .42831 Mdot
.37199 .32617 Mdot
.62862 .5614 Mdot
.63955 .43852 Mdot
.3436 .54703 Mdot
.34535 .36979 Mdot
.33456 .72746 Mdot
.69411 .5693 Mdot
.67197 .44996 Mdot
.54391 .70205 Mdot
.57599 .68008 Mdot
.3699 .48731 Mdot
.58034 .16737 Mdot
.36859 .35297 Mdot
.54935 .79303 Mdot
.52662 .68868 Mdot
.53201 .71004 Mdot
.67794 .57212 Mdot
.3394 .66171 Mdot
.34251 .69595 Mdot
.68437 .55745 Mdot
.49701 .3001 Mdot
.36216 .64167 Mdot
.4055 .35305 Mdot
.64059 .55401 Mdot
.27131 .43567 Mdot
.32654 .53271 Mdot
.65648 .29077 Mdot
.51818 .32553 Mdot
.50405 .72941 Mdot
.435 .40714 Mdot
.38883 .75969 Mdot
.66969 .56872 Mdot
.64321 .43921 Mdot
.58293 .65209 Mdot
.45198 .43 Mdot
.41184 .42915 Mdot
.4181 .40337 Mdot
.62285 .33424 Mdot
.33766 .53952 Mdot
.43784 .42139 Mdot
.33978 .37258 Mdot
.26859 .45955 Mdot
.64862 .59754 Mdot
.64167 .34171 Mdot
.52202 .36076 Mdot
.74451 .57963 Mdot
.35432 .55232 Mdot
.4484 .4113 Mdot
.57069 .68034 Mdot
.25707 .43532 Mdot
.5536 .70576 Mdot
.51934 .72485 Mdot
.81093 .57483 Mdot
.35139 .62235 Mdot
.26285 .45617 Mdot
.67002 .59709 Mdot
.32619 .70227 Mdot
.25593 .44814 Mdot
.27147 .504 Mdot
.58333 .66876 Mdot
.56529 .15855 Mdot
.5763 .67627 Mdot
.64635 .44071 Mdot
.35257 .6658 Mdot
.3365 .61948 Mdot
.35766 .33292 Mdot
.32987 .65223 Mdot
.75987 .59773 Mdot
.37876 .61974 Mdot
.82691 .46753 Mdot
.37626 .58915 Mdot
.53946 .70518 Mdot
.51071 .70039 Mdot
.26152 .43905 Mdot
.40734 .41248 Mdot
.33448 .31784 Mdot
.61777 .43303 Mdot
.37627 .33152 Mdot
.70132 .58388 Mdot
.78187 .59305 Mdot
.57047 .7996 Mdot
.34443 .67285 Mdot
.53502 .6884 Mdot
.41316 .42943 Mdot
.2834 .44199 Mdot
.37459 .37286 Mdot
.50579 .7452 Mdot
.30344 .42297 Mdot
.41017 .39467 Mdot
.26092 .44266 Mdot
.69041 .55956 Mdot
.74537 .58623 Mdot
.33835 .7327 Mdot
.80886 .57694 Mdot
.3886 .40618 Mdot
.64294 .32378 Mdot
.66831 .33829 Mdot
.40472 .44337 Mdot
.60862 .5841 Mdot
.36292 .32365 Mdot
.39442 .39161 Mdot
.31655 .31086 Mdot
.68226 .55466 Mdot
.65177 .44167 Mdot
.66161 .57256 Mdot
.38667 .59288 Mdot
.62515 .40384 Mdot
.70161 .59063 Mdot
.32588 .31657 Mdot
.62552 .42067 Mdot
.6157 .67799 Mdot
.65448 .29761 Mdot
.39017 .38569 Mdot
.38721 .49294 Mdot
.63233 .5615 Mdot
.53597 .70058 Mdot
.36616 .65456 Mdot
.55945 .70045 Mdot
.74172 .58573 Mdot
.50262 .30035 Mdot
.59951 .42011 Mdot
.57083 .68632 Mdot
.29502 .44 Mdot
.63977 .32243 Mdot
.57763 .67204 Mdot
.279 .45316 Mdot
.40892 .44599 Mdot
.60205 .18118 Mdot
.44008 .43906 Mdot
.78319 .5935 Mdot
.52574 .68619 Mdot
.65034 .45989 Mdot
.39675 .40494 Mdot
.64158 .56957 Mdot
.68711 .31182 Mdot
.40281 .39364 Mdot
.69018 .60683 Mdot
.41065 .38464 Mdot
.65578 .3398 Mdot
.38219 .6136 Mdot
.34533 .30803 Mdot
.63035 .35218 Mdot
.66877 .30458 Mdot
.32748 .39229 Mdot
.37365 .3718 Mdot
.61736 .63273 Mdot
.36074 .63435 Mdot
.37872 .38744 Mdot
.62804 .35515 Mdot
.34161 .66735 Mdot
.36588 .64833 Mdot
.24251 .45262 Mdot
.5609 .7119 Mdot
.6852 .5649 Mdot
.64062 .3319 Mdot
.76027 .5911 Mdot
.43226 .40386 Mdot
.24779 .435 Mdot
.66016 .29875 Mdot
.54654 .69022 Mdot
.26803 .45362 Mdot
.56288 .79477 Mdot
.34836 .35829 Mdot
.57913 .66994 Mdot
.43669 .39276 Mdot
.32117 .444 Mdot
.38126 .59938 Mdot
.39526 .75544 Mdot
.51183 .75456 Mdot
.66036 .57992 Mdot
.61258 .43138 Mdot
.25032 .49629 Mdot
.64867 .29728 Mdot
.34435 .69746 Mdot
.41079 .43537 Mdot
.42716 .42724 Mdot
.38065 .60572 Mdot
.38653 .42445 Mdot
.33347 .67645 Mdot
.77383 .5906 Mdot
.57693 .16478 Mdot
.34383 .63328 Mdot
.34986 .64269 Mdot
.2328 .4481 Mdot
.66641 .54594 Mdot
.33133 .67174 Mdot
.42849 .39451 Mdot
.74326 .58688 Mdot
.59677 .44859 Mdot
.6348 .30869 Mdot
.62309 .30742 Mdot
.32346 .67957 Mdot
.44279 .38566 Mdot
.28878 .43992 Mdot
.48587 .42426 Mdot
.45209 .32442 Mdot
.53169 .68622 Mdot
.43359 .39532 Mdot
.62136 .43106 Mdot
.66399 .5692 Mdot
.43566 .44324 Mdot
.38831 .39076 Mdot
.33726 .6341 Mdot
.66222 .28769 Mdot
.51709 .70413 Mdot
.64077 .43487 Mdot
.62595 .57014 Mdot
.65001 .31716 Mdot
.31445 .66759 Mdot
.36092 .48126 Mdot
.59934 .40198 Mdot
.62385 .45364 Mdot
.39229 .41755 Mdot
.38161 .37627 Mdot
.59398 .42097 Mdot
.54451 .71216 Mdot
.6579 .57851 Mdot
.63694 .42087 Mdot
.35965 .32652 Mdot
.32997 .30664 Mdot
.40206 .42251 Mdot
.37456 .62091 Mdot
.53218 .69282 Mdot
.60067 .42178 Mdot
.7954 .59225 Mdot
.42252 .3873 Mdot
.42243 .36948 Mdot
.58883 .467 Mdot
.61924 .42633 Mdot
.34136 .69654 Mdot
.63265 .33514 Mdot
.28349 .44051 Mdot
.33746 .3728 Mdot
.38391 .3391 Mdot
.44722 .4107 Mdot
.69448 .59774 Mdot
.52111 .72005 Mdot
.5989 .44508 Mdot
.66851 .57743 Mdot
.36723 .64701 Mdot
.48917 .42 Mdot
.35219 .6177 Mdot
.36693 .61487 Mdot
.31654 .68717 Mdot
.5494 .71513 Mdot
.24637 .49416 Mdot
.5938 .41446 Mdot
.42411 .43963 Mdot
.54945 .67788 Mdot
.32738 .67288 Mdot
.39189 .34848 Mdot
.32701 .6768 Mdot
.3157 .64745 Mdot
.38387 .33638 Mdot
.26515 .44288 Mdot
.33604 .38017 Mdot
.45557 .42048 Mdot
.62671 .33311 Mdot
.36865 .60496 Mdot
.42585 .37033 Mdot
.43231 .42692 Mdot
.39363 .4076 Mdot
.26168 .43731 Mdot
.67436 .31909 Mdot
.49663 .41066 Mdot
.40977 .43421 Mdot
.52752 .33714 Mdot
.3913 .34931 Mdot
.31919 .63725 Mdot
.56719 .65969 Mdot
.24321 .45543 Mdot
.72419 .5831 Mdot
.38483 .60244 Mdot
.65868 .29028 Mdot
.33998 .68569 Mdot
.29093 .43039 Mdot
.52518 .71001 Mdot
.35166 .64515 Mdot
.66979 .55643 Mdot
.53855 .69814 Mdot
.51632 .69383 Mdot
.26441 .43446 Mdot
.65927 .58358 Mdot
.66371 .28827 Mdot
.50983 .70957 Mdot
.30234 .43915 Mdot
.53838 .70484 Mdot
.32401 .72198 Mdot
.37032 .32498 Mdot
.33904 .37062 Mdot
.61335 .41503 Mdot
.61666 .45926 Mdot
.51776 .69662 Mdot
.64489 .3084 Mdot
.26642 .45431 Mdot
.3717 .64875 Mdot
.63998 .31556 Mdot
.32812 .5324 Mdot
.7372 .59853 Mdot
.3695 .56783 Mdot
.76597 .59585 Mdot
.32723 .65452 Mdot
.51683 .32201 Mdot
.66608 .29387 Mdot
.60334 .44569 Mdot
.34906 .33025 Mdot
.61191 .43481 Mdot
.42951 .44308 Mdot
.26359 .45525 Mdot
.41216 .41209 Mdot
.7113 .5723 Mdot
.62231 .33284 Mdot
.37597 .628 Mdot
.67597 .26394 Mdot
.55527 .68876 Mdot
.36664 .33366 Mdot
.64367 .4342 Mdot
.27892 .44505 Mdot
.33195 .67515 Mdot
.32091 .64884 Mdot
.33524 .53395 Mdot
.71373 .57712 Mdot
.65226 .26937 Mdot
.40639 .4236 Mdot
.68237 .28014 Mdot
.51885 .69394 Mdot
.51342 .76353 Mdot
.65312 .55929 Mdot
.56238 .16045 Mdot
.67253 .58091 Mdot
.59874 .45429 Mdot
.32408 .65648 Mdot
.66031 .33141 Mdot
.40742 .4186 Mdot
.38427 .62907 Mdot
.34362 .69577 Mdot
.62758 .29978 Mdot
.63744 .33959 Mdot
.50611 .75103 Mdot
.54676 .67669 Mdot
.63362 .45078 Mdot
.39107 .3499 Mdot
.39699 .35225 Mdot
.44806 .42956 Mdot
.53839 .68331 Mdot
.27151 .44476 Mdot
.57132 .65989 Mdot
.2742 .42663 Mdot
.62776 .3557 Mdot
.71274 .58997 Mdot
.62799 .76681 Mdot
.38497 .614 Mdot
.49393 .41314 Mdot
.32174 .70994 Mdot
.34699 .36769 Mdot
.56292 .68165 Mdot
.63591 .46623 Mdot
.67894 .56825 Mdot
.49006 .65657 Mdot
.71071 .5922 Mdot
.6547 .22378 Mdot
.45302 .38673 Mdot
.58352 .65822 Mdot
.37544 .33503 Mdot
.66327 .5919 Mdot
.45784 .42587 Mdot
.63392 .41812 Mdot
.61791 .39687 Mdot
.28706 .42213 Mdot
.29356 .51098 Mdot
.62782 .33543 Mdot
.4078 .4194 Mdot
.37705 .60947 Mdot
.40539 .41837 Mdot
.40473 .41909 Mdot
.39233 .42389 Mdot
.50268 .73087 Mdot
.37183 .32888 Mdot
.40889 .41239 Mdot
.78941 .59408 Mdot
.59754 .44724 Mdot
.62048 .57108 Mdot
.38096 .59628 Mdot
.63761 .31674 Mdot
.38385 .59275 Mdot
.34579 .3178 Mdot
.57603 .68713 Mdot
.33551 .53795 Mdot
.27513 .43892 Mdot
.32386 .68428 Mdot
.57286 .68417 Mdot
.63533 .2989 Mdot
.62456 .43107 Mdot
.33451 .74818 Mdot
.75971 .6 Mdot
.62261 .44253 Mdot
.70552 .60632 Mdot
.45404 .42094 Mdot
.35112 .62912 Mdot
.61337 .43559 Mdot
.515 .71235 Mdot
.69817 .5995 Mdot
.33078 .38998 Mdot
.42763 .40656 Mdot
.69956 .57303 Mdot
.61885 .41733 Mdot
.35725 .32597 Mdot
.34792 .31329 Mdot
.66202 .5917 Mdot
.53582 .7239 Mdot
.51127 .70283 Mdot
.64 .30438 Mdot
.32506 .6338 Mdot
.32826 .64051 Mdot
.55354 .68958 Mdot
.50001 .6494 Mdot
.4238 .39558 Mdot
.42377 .39901 Mdot
.34251 .32246 Mdot
.37912 .35518 Mdot
.76649 .6019 Mdot
.62396 .44112 Mdot
.33445 .64588 Mdot
.26283 .45535 Mdot
.24811 .44628 Mdot
.41099 .419 Mdot
.49481 .29439 Mdot
.68321 .55977 Mdot
.28639 .4356 Mdot
.65772 .33944 Mdot
.30765 .51609 Mdot
.39716 .37715 Mdot
.63074 .36193 Mdot
.3228 .64883 Mdot
.61746 .66687 Mdot
.53503 .7019 Mdot
.65994 .59304 Mdot
.66603 .59552 Mdot
.76535 .5067 Mdot
.38439 .61119 Mdot
.62173 .44204 Mdot
.74601 .60438 Mdot
.63921 .41421 Mdot
.63856 .3386 Mdot
.51242 .37924 Mdot
.7613 .59841 Mdot
.62151 .5726 Mdot
.58428 .66126 Mdot
.43352 .39273 Mdot
.39039 .37969 Mdot
.51805 .76539 Mdot
.39185 .40144 Mdot
.6611 .30469 Mdot
.56113 .6712 Mdot
.35339 .64389 Mdot
.62531 .32584 Mdot
.57039 .67746 Mdot
.32651 .64093 Mdot
.26748 .43431 Mdot
.39352 .35015 Mdot
.36668 .65096 Mdot
.31718 .66565 Mdot
.42349 .39398 Mdot
.81547 .57077 Mdot
.33688 .63809 Mdot
.35975 .66118 Mdot
.30523 .51559 Mdot
.63236 .57455 Mdot
.68472 .32068 Mdot
.5647 .70757 Mdot
.41226 .40702 Mdot
.71347 .58475 Mdot
.65126 .33419 Mdot
.34437 .64874 Mdot
.38266 .39308 Mdot
.43313 .40614 Mdot
.64044 .32234 Mdot
.65441 .34331 Mdot
.64245 .30973 Mdot
.50437 .71317 Mdot
.27347 .43653 Mdot
.33837 .67239 Mdot
.55185 .68238 Mdot
.65871 .29245 Mdot
.63938 .34444 Mdot
.61526 .3357 Mdot
.42134 .39328 Mdot
.6537 .34434 Mdot
.26378 .50075 Mdot
.32484 .32257 Mdot
.63791 .41201 Mdot
.66214 .46553 Mdot
.62586 .55631 Mdot
.62221 .4751 Mdot
.52197 .71949 Mdot
.2735 .42815 Mdot
.63371 .30864 Mdot
.62547 .41549 Mdot
.42677 .40268 Mdot
.40578 .37532 Mdot
.64329 .32063 Mdot
.50269 .29827 Mdot
.33801 .63103 Mdot
.33717 .72854 Mdot
.63823 .3201 Mdot
.64611 .58178 Mdot
.67948 .55382 Mdot
.68229 .5817 Mdot
.39734 .41905 Mdot
.39275 .34069 Mdot
.41743 .30463 Mdot
.35032 .54495 Mdot
.53742 .68061 Mdot
.32077 .65455 Mdot
.30348 .51787 Mdot
.36502 .64841 Mdot
.72945 .59392 Mdot
.64531 .30788 Mdot
.37558 .60542 Mdot
.50648 .70752 Mdot
.51239 .70327 Mdot
.62864 .56381 Mdot
.6701 .58153 Mdot
.69019 .57671 Mdot
.38709 .61145 Mdot
.32593 .66711 Mdot
.379 .333 Mdot
.36736 .61923 Mdot
.74458 .57739 Mdot
.77414 .591 Mdot
.63071 .56127 Mdot
.54757 .70588 Mdot
.34355 .65785 Mdot
.40857 .38272 Mdot
.32479 .39927 Mdot
.67795 .55284 Mdot
.64977 .2902 Mdot
.22421 .47174 Mdot
.58281 .16919 Mdot
.25246 .43289 Mdot
.52441 .70214 Mdot
.6139 .40863 Mdot
.41879 .40655 Mdot
.65744 .57604 Mdot
.65177 .47116 Mdot
.60844 .44298 Mdot
.36908 .3374 Mdot
.25456 .41909 Mdot
.52859 .70107 Mdot
.34382 .31129 Mdot
.63208 .41826 Mdot
.27332 .45766 Mdot
.56136 .67245 Mdot
.64342 .55687 Mdot
.64194 .59568 Mdot
.35853 .55391 Mdot
.51421 .37289 Mdot
.60235 .40892 Mdot
.4462 .41914 Mdot
.69851 .58945 Mdot
.62568 .32302 Mdot
.69758 .58544 Mdot
.31497 .64298 Mdot
.62947 .5698 Mdot
.39955 .38211 Mdot
.3378 .67143 Mdot
.51374 .70003 Mdot
.40779 .29501 Mdot
.66988 .25692 Mdot
.64007 .56521 Mdot
.59648 .43597 Mdot
.25251 .43947 Mdot
.25539 .4634 Mdot
.61649 .45932 Mdot
.39177 .38116 Mdot
.55442 .70078 Mdot
.33662 .67525 Mdot
.54688 .68774 Mdot
.68729 .31392 Mdot
.31109 .72012 Mdot
.53381 .70237 Mdot
.38977 .33657 Mdot
.62648 .31481 Mdot
.49978 .29765 Mdot
.39879 .38488 Mdot
.5152 .71714 Mdot
.3699 .33271 Mdot
.37688 .60193 Mdot
.32797 .31502 Mdot
.34795 .3603 Mdot
.55591 .69459 Mdot
.63857 .45263 Mdot
.35409 .31535 Mdot
.68621 .31221 Mdot
.52454 .69217 Mdot
.32256 .3075 Mdot
.63025 .44207 Mdot
.6554 .31796 Mdot
.62374 .3344 Mdot
.65013 .31355 Mdot
.41402 .39512 Mdot
.32226 .44898 Mdot
.66668 .29658 Mdot
.51359 .73439 Mdot
.66801 .30841 Mdot
.6184 .46925 Mdot
.53643 .7847 Mdot
.64766 .34371 Mdot
.39147 .39443 Mdot
.27364 .42679 Mdot
.2725 .42854 Mdot
.65287 .56357 Mdot
.33954 .75364 Mdot
.78813 .59321 Mdot
.42897 .42977 Mdot
.29429 .51692 Mdot
.37994 .61496 Mdot
.59209 .42918 Mdot
.34742 .36189 Mdot
.29227 .4371 Mdot
.35929 .65618 Mdot
.34651 .32345 Mdot
.36412 .56206 Mdot
.62711 .40939 Mdot
.41435 .39363 Mdot
.38311 .60323 Mdot
.31814 .68591 Mdot
.48293 .28463 Mdot
.35464 .55359 Mdot
.33383 .65423 Mdot
.52875 .68527 Mdot
.52667 .71873 Mdot
.55522 .69896 Mdot
.66966 .58375 Mdot
.34825 .64423 Mdot
.41727 .44902 Mdot
.66084 .57912 Mdot
.40117 .42898 Mdot
.55548 .69212 Mdot
.34309 .35956 Mdot
.35074 .6426 Mdot
.3968 .38804 Mdot
.41832 .36187 Mdot
.69229 .60633 Mdot
.64088 .32172 Mdot
.2827 .50783 Mdot
.64542 .59482 Mdot
.50583 .72407 Mdot
.31619 .63839 Mdot
.61872 .4655 Mdot
.28039 .45498 Mdot
.38075 .39197 Mdot
.39942 .43376 Mdot
.27749 .45671 Mdot
.45302 .38888 Mdot
.6211 .45109 Mdot
.6688 .58532 Mdot
.6388 .58423 Mdot
.40769 .37956 Mdot
.3437 .64316 Mdot
.67368 .33274 Mdot
.63496 .36655 Mdot
.64437 .28067 Mdot
.35176 .31656 Mdot
.33993 .37217 Mdot
.38679 .35916 Mdot
.50118 .40097 Mdot
.66171 .55954 Mdot
.65084 .44242 Mdot
.35505 .33044 Mdot
.65926 .31318 Mdot
.37955 .40132 Mdot
.38135 .59426 Mdot
.348 .64901 Mdot
.69143 .56786 Mdot
.54978 .6699 Mdot
.60269 .39916 Mdot
.63191 .55853 Mdot
.40605 .3789 Mdot
.25176 .45152 Mdot
.54643 .67345 Mdot
.31112 .6636 Mdot
.65178 .32114 Mdot
.6581 .57321 Mdot
.66442 .32215 Mdot
.36472 .6237 Mdot
.34314 .64913 Mdot
.37609 .37312 Mdot
.66288 .26407 Mdot
.63967 .5596 Mdot
.40099 .42029 Mdot
.70034 .57616 Mdot
.76081 .5957 Mdot
.57411 .66289 Mdot
.37842 .38904 Mdot
.33803 .69745 Mdot
.55777 .70005 Mdot
.42233 .43135 Mdot
.26724 .43097 Mdot
.26905 .4529 Mdot
.65534 .58757 Mdot
.65252 .28598 Mdot
.66 .31874 Mdot
.30841 .70774 Mdot
.33001 .54977 Mdot
.40387 .36742 Mdot
.63386 .57194 Mdot
.30302 .43066 Mdot
.52895 .70791 Mdot
.3268 .65723 Mdot
.59885 .78189 Mdot
.54121 .70792 Mdot
.41553 .3873 Mdot
.65912 .30752 Mdot
.31502 .65764 Mdot
.63559 .40872 Mdot
.40903 .27882 Mdot
.62637 .46045 Mdot
.65437 .26952 Mdot
.63874 .43774 Mdot
.55056 .78897 Mdot
.69364 .57848 Mdot
.32961 .67413 Mdot
.52302 .70204 Mdot
.52674 .70923 Mdot
.71799 .60258 Mdot
.32902 .53014 Mdot
.33559 .73277 Mdot
.23021 .48181 Mdot
.75733 .59996 Mdot
.65016 .30568 Mdot
.32834 .32163 Mdot
.68042 .5807 Mdot
.67547 .60657 Mdot
.50329 .7445 Mdot
.51435 .76453 Mdot
.34472 .66044 Mdot
.43614 .41246 Mdot
.31362 .52015 Mdot
.41208 .43761 Mdot
.51453 .37396 Mdot
.54952 .69077 Mdot
.32667 .65673 Mdot
.5074 .75823 Mdot
.38772 .37181 Mdot
.42363 .41893 Mdot
.75149 .58056 Mdot
.62063 .43509 Mdot
.7699 .57155 Mdot
.37899 .40292 Mdot
.68416 .58891 Mdot
.31475 .69799 Mdot
.62238 .41038 Mdot
.42966 .37295 Mdot
.53208 .68069 Mdot
.59977 .42144 Mdot
.62596 .41104 Mdot
.49986 .39765 Mdot
.37353 .57321 Mdot
.35187 .61423 Mdot
.66312 .34022 Mdot
.51467 .76893 Mdot
.572 .66908 Mdot
.55988 .79369 Mdot
.41014 .38286 Mdot
.50869 .70131 Mdot
.58333 .41752 Mdot
.42351 .43249 Mdot
.25756 .448 Mdot
.3351 .53576 Mdot
.4431 .40849 Mdot
.28438 .42652 Mdot
.54374 .70383 Mdot
.57434 .4198 Mdot
.4174 .37584 Mdot
.69602 .5707 Mdot
.33904 .66233 Mdot
.37873 .57775 Mdot
.62969 .32115 Mdot
.51091 .75586 Mdot
.57103 .16227 Mdot
.32751 .65775 Mdot
.42474 .40327 Mdot
.531 .70887 Mdot
.60943 .40729 Mdot
.61069 .41768 Mdot
.61143 .45367 Mdot
.34952 .65083 Mdot
.62086 .41136 Mdot
.31991 .70503 Mdot
.34584 .32072 Mdot
.49323 .41505 Mdot
.5482 .71483 Mdot
.65234 .30597 Mdot
.67981 .30121 Mdot
.75806 .59369 Mdot
.39037 .35111 Mdot
.51492 .37416 Mdot
.30022 .68076 Mdot
.65686 .30444 Mdot
.41519 .41155 Mdot
.62308 .45223 Mdot
.31483 .3041 Mdot
.66642 .3452 Mdot
.63691 .44333 Mdot
.24731 .45232 Mdot
.32796 .63436 Mdot
.61434 .43944 Mdot
.35603 .64402 Mdot
.41396 .41462 Mdot
.36411 .33291 Mdot
.33937 .6208 Mdot
.35458 .75539 Mdot
.59709 .40276 Mdot
.57333 .67703 Mdot
.36738 .32979 Mdot
.38708 .40309 Mdot
.4007 .34894 Mdot
.6062 .41092 Mdot
.40247 .7469 Mdot
.70817 .58265 Mdot
.79373 .58791 Mdot
.76575 .60285 Mdot
.50852 .7457 Mdot
.56337 .79839 Mdot
.3874 .36749 Mdot
.32885 .52831 Mdot
.39734 .34573 Mdot
.56531 .69699 Mdot
.42616 .3746 Mdot
.40748 .41237 Mdot
.39434 .41943 Mdot
.70038 .57556 Mdot
.58389 .66568 Mdot
.24288 .45392 Mdot
.3546 .32863 Mdot
.64475 .28833 Mdot
.36527 .63002 Mdot
.40912 .4028 Mdot
.30063 .67288 Mdot
.65056 .58579 Mdot
.31843 .73331 Mdot
.39267 .39461 Mdot
.62115 .43512 Mdot
.50552 .70448 Mdot
.51717 .69476 Mdot
.65056 .58223 Mdot
.64668 .57868 Mdot
.38758 .40396 Mdot
.55729 .68571 Mdot
.40076 .36004 Mdot
.3545 .31651 Mdot
.62106 .41738 Mdot
.64263 .33554 Mdot
.41918 .44197 Mdot
.33596 .73126 Mdot
.66088 .25405 Mdot
.40021 .42097 Mdot
.3604 .61347 Mdot
.68732 .57341 Mdot
.73293 .59954 Mdot
.32862 .6432 Mdot
.73239 .60067 Mdot
.32003 .73497 Mdot
.32324 .4479 Mdot
.64456 .33977 Mdot
.25103 .46916 Mdot
.66936 .30649 Mdot
.60068 .41858 Mdot
.42014 .3923 Mdot
.61773 .64416 Mdot
.76174 .60335 Mdot
.28317 .34338 Mdot
.54192 .69504 Mdot
.64786 .43466 Mdot
.27184 .44232 Mdot
.62938 .30324 Mdot
.6671 .56983 Mdot
.61736 .39809 Mdot
.37931 .40202 Mdot
.38531 .60317 Mdot
.24409 .43928 Mdot
.64045 .4223 Mdot
.60235 .41924 Mdot
.61457 .39899 Mdot
.57045 .67764 Mdot
.36389 .66084 Mdot
.50574 .75091 Mdot
.68689 .60479 Mdot
.37649 .33029 Mdot
.42335 .40406 Mdot
.32171 .6547 Mdot
.42961 .4381 Mdot
.56193 .69457 Mdot
.22475 .48356 Mdot
.64458 .3054 Mdot
.61967 .40468 Mdot
.43321 .71371 Mdot
.62768 .40165 Mdot
.26386 .45802 Mdot
.26441 .46221 Mdot
.38025 .59572 Mdot
.57146 .69047 Mdot
.44993 .41122 Mdot
.63303 .58342 Mdot
.65435 .32086 Mdot
.51281 .69739 Mdot
.2569 .4524 Mdot
.39383 .38529 Mdot
.65471 .30584 Mdot
.51035 .75914 Mdot
.66781 .28475 Mdot
.52453 .69596 Mdot
.64466 .4592 Mdot
.31198 .39522 Mdot
.40002 .39298 Mdot
.62567 .43844 Mdot
.37377 .63911 Mdot
.53908 .68062 Mdot
.33884 .53718 Mdot
.62806 .41048 Mdot
.76502 .59362 Mdot
.52058 .68979 Mdot
.38001 .38921 Mdot
.33919 .68515 Mdot
.37307 .58871 Mdot
.35411 .66722 Mdot
.80399 .50268 Mdot
.77587 .59612 Mdot
.69226 .5751 Mdot
.5461 .70728 Mdot
.71581 .58477 Mdot
.62596 .3154 Mdot
.33346 .32385 Mdot
.64102 .57172 Mdot
.3708 .65586 Mdot
.71285 .59308 Mdot
.40132 .35958 Mdot
.57454 .68002 Mdot
.64316 .5522 Mdot
.44334 .43638 Mdot
.27163 .43222 Mdot
.60413 .42493 Mdot
.67484 .30668 Mdot
.34932 .32154 Mdot
.43889 .41067 Mdot
.62829 .43398 Mdot
.39681 .39023 Mdot
.56168 .69297 Mdot
.41232 .29784 Mdot
.38529 .3398 Mdot
.75204 .59599 Mdot
.3319 .74401 Mdot
.64345 .58639 Mdot
.68952 .26983 Mdot
.41664 .4341 Mdot
.4019 .38944 Mdot
.26741 .44974 Mdot
.22232 .46755 Mdot
.50371 .7209 Mdot
.37216 .32466 Mdot
.73602 .603 Mdot
.35933 .65204 Mdot
.37913 .60766 Mdot
.51062 .38019 Mdot
.6273 .44038 Mdot
.52243 .72375 Mdot
.40896 .3885 Mdot
.64226 .42084 Mdot
.35609 .35615 Mdot
.52492 .77152 Mdot
.77997 .5953 Mdot
.67643 .60581 Mdot
.3784 .59901 Mdot
.68992 .5604 Mdot
.26952 .44972 Mdot
.61838 .4105 Mdot
.78127 .59972 Mdot
.50307 .73589 Mdot
.65563 .32161 Mdot
.39907 .42475 Mdot
.49154 .29009 Mdot
.68857 .55909 Mdot
.65956 .58242 Mdot
.40311 .36122 Mdot
.30062 .69004 Mdot
.62728 .28249 Mdot
.55215 .6786 Mdot
.37986 .59068 Mdot
.38317 .48976 Mdot
.57894 .25998 Mdot
.53087 .71603 Mdot
.25465 .44618 Mdot
.681 .55545 Mdot
.73137 .51785 Mdot
.3617 .65238 Mdot
.65389 .32204 Mdot
.43851 .4365 Mdot
.37745 .6224 Mdot
.75901 .60163 Mdot
.34316 .67479 Mdot
.61459 .43256 Mdot
.57408 .68199 Mdot
.66612 .56515 Mdot
.58381 .6674 Mdot
.33961 .69638 Mdot
.64791 .30503 Mdot
.52102 .34497 Mdot
.26934 .42544 Mdot
.33429 .53667 Mdot
.26995 .43755 Mdot
.58597 .42557 Mdot
.27044 .43437 Mdot
.37525 .58243 Mdot
.39765 .38521 Mdot
.42952 .38476 Mdot
.73683 .5974 Mdot
.39035 .41367 Mdot
.4263 .39276 Mdot
.41656 .36065 Mdot
.40643 .42951 Mdot
.40497 .42 Mdot
.37984 .37837 Mdot
.34646 .62121 Mdot
.37563 .35686 Mdot
.31925 .66807 Mdot
.30681 .67709 Mdot
.68849 .60519 Mdot
.62229 .33076 Mdot
.65293 .34276 Mdot
.36739 .35466 Mdot
.49231 .29142 Mdot
.31129 .5193 Mdot
.36112 .64602 Mdot
.51794 .6952 Mdot
.38466 .34339 Mdot
.63174 .27808 Mdot
.36735 .35252 Mdot
.65168 .56336 Mdot
.64301 .58082 Mdot
.44326 .43893 Mdot
.5859 .17114 Mdot
.37631 .39353 Mdot
.34166 .32659 Mdot
.41239 .39524 Mdot
.37755 .38027 Mdot
.63139 .57755 Mdot
.51717 .32159 Mdot
.28933 .43933 Mdot
.36728 .5714 Mdot
.65574 .32526 Mdot
.61633 .43938 Mdot
.36395 .33277 Mdot
.36918 .48502 Mdot
.35973 .55575 Mdot
.26586 .45057 Mdot
.65655 .56765 Mdot
.33776 .64868 Mdot
.34473 .3274 Mdot
.55052 .68192 Mdot
.41796 .27878 Mdot
.31349 .72407 Mdot
.55765 .67852 Mdot
.65464 .31855 Mdot
.65857 .55521 Mdot
.41838 .41727 Mdot
.69341 .59384 Mdot
.38627 .37289 Mdot
.33561 .31125 Mdot
.64233 .33825 Mdot
.37481 .65022 Mdot
.53758 .67786 Mdot
.34591 .62427 Mdot
.33025 .72908 Mdot
.45409 .32533 Mdot
.77343 .58246 Mdot
.63064 .56729 Mdot
.67899 .27217 Mdot
.33083 .66811 Mdot
.42147 .38642 Mdot
.259 .499 Mdot
.3538 .6294 Mdot
.38621 .60232 Mdot
.41559 .2823 Mdot
.51208 .30113 Mdot
.38059 .38 Mdot
.37787 .62612 Mdot
.6595 .5544 Mdot
.64538 .3409 Mdot
.41954 .38704 Mdot
.61609 .40952 Mdot
.37845 .60562 Mdot
.68877 .56183 Mdot
.51949 .33017 Mdot
.67646 .58587 Mdot
.35108 .66034 Mdot
.6497 .58776 Mdot
.57266 .66114 Mdot
.64036 .57024 Mdot
.41369 .44114 Mdot
.40593 .38857 Mdot
.37699 .58838 Mdot
.3431 .64901 Mdot
.26439 .4579 Mdot
.42309 .43898 Mdot
.33012 .67237 Mdot
.7312 .58319 Mdot
.35412 .56493 Mdot
.26769 .45449 Mdot
.43089 .40243 Mdot
.66839 .30241 Mdot
.3573 .31405 Mdot
.40349 .2859 Mdot
.38249 .3354 Mdot
.64771 .30834 Mdot
.38952 .60261 Mdot
.41128 .38737 Mdot
.51543 .31184 Mdot
.74054 .60285 Mdot
.45226 .42679 Mdot
.61276 .40521 Mdot
.28768 .44614 Mdot
.44849 .2678 Mdot
.25783 .452 Mdot
.35626 .66202 Mdot
.34477 .66575 Mdot
.73248 .5886 Mdot
.37004 .6436 Mdot
.61271 .40676 Mdot
.52068 .72261 Mdot
.32545 .72351 Mdot
.65018 .44272 Mdot
.60121 .43545 Mdot
.59377 .41431 Mdot
.64231 .43691 Mdot
.63614 .27479 Mdot
.76617 .59002 Mdot
.60187 .43216 Mdot
.32172 .67215 Mdot
.60743 .59335 Mdot
.62389 .46562 Mdot
.52231 .72397 Mdot
.62509 .41124 Mdot
.45203 .42555 Mdot
.26223 .45071 Mdot
.32312 .63083 Mdot
.55478 .68195 Mdot
.58656 .41345 Mdot
.42411 .3904 Mdot
.37731 .59605 Mdot
.40888 .40553 Mdot
.65258 .28752 Mdot
.35271 .6415 Mdot
.66109 .57564 Mdot
.63952 .33586 Mdot
.63714 .42502 Mdot
.63878 .31648 Mdot
.70211 .58591 Mdot
.51117 .71311 Mdot
.44241 .43384 Mdot
.67614 .29781 Mdot
.62283 .3313 Mdot
.45033 .4279 Mdot
.34013 .66504 Mdot
.58982 .40797 Mdot
.43486 .40575 Mdot
.26874 .44499 Mdot
.32884 .63772 Mdot
.39843 .75479 Mdot
.41811 .42099 Mdot
.26066 .46091 Mdot
.37056 .5778 Mdot
.64305 .42437 Mdot
.66369 .58017 Mdot
.38296 .39341 Mdot
.5392 .69285 Mdot
.5546 .6897 Mdot
.76012 .6013 Mdot
.36543 .60822 Mdot
.70147 .56556 Mdot
.44936 .43781 Mdot
.62868 .4138 Mdot
.38784 .38638 Mdot
.74749 .57725 Mdot
.3662 .7616 Mdot
.31542 .66379 Mdot
.67393 .60325 Mdot
.35655 .36314 Mdot
.56012 .71235 Mdot
.74664 .59691 Mdot
.36994 .57517 Mdot
.36628 .61783 Mdot
.3284 .64474 Mdot
.65911 .33876 Mdot
.66962 .57995 Mdot
.32556 .63078 Mdot
.32136 .63903 Mdot
.26648 .45306 Mdot
.44624 .4374 Mdot
.38284 .59949 Mdot
.76794 .59934 Mdot
.65974 .32078 Mdot
.72298 .60526 Mdot
.66275 .25409 Mdot
.54773 .67764 Mdot
.43342 .37677 Mdot
.39375 .35255 Mdot
.56102 .15912 Mdot
.38151 .41 Mdot
.41604 .3981 Mdot
.38643 .59286 Mdot
.65585 .28106 Mdot
.66467 .32909 Mdot
.33238 .66829 Mdot
.31421 .66455 Mdot
.63487 .32376 Mdot
.32369 .41513 Mdot
.46705 .27833 Mdot
.36086 .36312 Mdot
.36357 .66203 Mdot
.32879 .71979 Mdot
.54957 .69594 Mdot
.37813 .61248 Mdot
.61166 .68015 Mdot
.63682 .55606 Mdot
.63923 .5651 Mdot
.525 .68827 Mdot
.42011 .41638 Mdot
.62834 .57187 Mdot
.28508 .4363 Mdot
.61484 .68527 Mdot
.25558 .43666 Mdot
.82051 .56692 Mdot
.42862 .43932 Mdot
.55739 .62444 Mdot
.54468 .78587 Mdot
.26951 .45665 Mdot
.32542 .45532 Mdot
.64701 .32087 Mdot
.38074 .57865 Mdot
.56174 .70101 Mdot
.31475 .52092 Mdot
.40054 .39139 Mdot
.37835 .63576 Mdot
.54885 .67407 Mdot
.38731 .7551 Mdot
.29105 .43862 Mdot
.28086 .44345 Mdot
.26001 .50109 Mdot
.3222 .68136 Mdot
.66636 .58189 Mdot
.38403 .59005 Mdot
.31708 .64116 Mdot
.26602 .4324 Mdot
.672 .5512 Mdot
.31312 .31833 Mdot
.3708 .6539 Mdot
.67992 .32712 Mdot
.36179 .63241 Mdot
.63743 .32772 Mdot
.32907 .62725 Mdot
.69994 .60482 Mdot
.41288 .42704 Mdot
.69461 .60586 Mdot
.65246 .2914 Mdot
.65478 .59271 Mdot
.56357 .69113 Mdot
.63076 .42635 Mdot
.55765 .69912 Mdot
.33073 .32022 Mdot
.3414 .53821 Mdot
.52271 .72052 Mdot
.46785 .34315 Mdot
.39487 .38343 Mdot
.33027 .6263 Mdot
.65928 .56838 Mdot
.71371 .60856 Mdot
.34966 .31897 Mdot
.33446 .65756 Mdot
.72677 .5902 Mdot
.30152 .44016 Mdot
.61756 .66264 Mdot
.28066 .45303 Mdot
.60243 .7846 Mdot
.34065 .67211 Mdot
.7231 .60752 Mdot
.34365 .32862 Mdot
.30939 .66136 Mdot
.64056 .55626 Mdot
.51938 .70092 Mdot
.53892 .69338 Mdot
.3972 .43299 Mdot
.58382 .66932 Mdot
.65248 .56458 Mdot
.3095 .71865 Mdot
.33197 .62638 Mdot
.35755 .76111 Mdot
.64424 .30969 Mdot
.67867 .55884 Mdot
.62001 .41548 Mdot
.34636 .69339 Mdot
.71699 .58895 Mdot
.57349 .16282 Mdot
.8492 .46358 Mdot
.71636 .57804 Mdot
.35428 .64149 Mdot
.34575 .65308 Mdot
.24803 .43702 Mdot
.35209 .32127 Mdot
.66818 .56866 Mdot
.61123 .64609 Mdot
.33765 .37703 Mdot
.63225 .42984 Mdot
.79019 .59487 Mdot
.41222 .44692 Mdot
.27013 .44015 Mdot
.53552 .68391 Mdot
.42388 .42027 Mdot
.31453 .6719 Mdot
.37808 .40018 Mdot
.55988 .70008 Mdot
.74297 .58816 Mdot
.39908 .39039 Mdot
.65383 .31973 Mdot
.53092 .69367 Mdot
.53911 .6891 Mdot
.67277 .59902 Mdot
.36547 .608 Mdot
.31852 .52464 Mdot
.66949 .58154 Mdot
.2771 .43527 Mdot
.6262 .43011 Mdot
.37993 .38444 Mdot
.38228 .63496 Mdot
.36727 .56161 Mdot
.67748 .55807 Mdot
.44651 .4175 Mdot
.53808 .7128 Mdot
.72314 .5805 Mdot
.2514 .44555 Mdot
.64272 .56137 Mdot
.65671 .43836 Mdot
.62381 .56736 Mdot
.31952 .70211 Mdot
.59099 .42585 Mdot
.37744 .64096 Mdot
.61209 .44425 Mdot
.76709 .50689 Mdot
.65657 .31827 Mdot
.63363 .57837 Mdot
.36067 .75605 Mdot
.68015 .60516 Mdot
.40997 .43097 Mdot
.41037 .38445 Mdot
.70683 .5844 Mdot
.65032 .30332 Mdot
.61917 .47387 Mdot
.66014 .28484 Mdot
.35037 .64572 Mdot
.293 .43569 Mdot
.85077 .4998 Mdot
.65703 .60136 Mdot
.56023 .66884 Mdot
.35613 .55871 Mdot
.60435 .44022 Mdot
.56219 .68583 Mdot
.53597 .68949 Mdot
.64283 .29981 Mdot
.67217 .60562 Mdot
.38469 .61579 Mdot
.58164 .67516 Mdot
.30947 .66375 Mdot
.51944 .31728 Mdot
.64243 .42944 Mdot
.68358 .28532 Mdot
.6251 .45239 Mdot
.34828 .32486 Mdot
.57199 .69931 Mdot
.40153 .40778 Mdot
.63718 .29089 Mdot
.52883 .68655 Mdot
.66777 .29664 Mdot
.25286 .44572 Mdot
.72835 .59431 Mdot
.29738 .52941 Mdot
.40154 .43672 Mdot
.4285 .43331 Mdot
.54237 .67817 Mdot
.33537 .46466 Mdot
.37054 .57261 Mdot
.33393 .62647 Mdot
.69291 .5783 Mdot
.4071 .28272 Mdot
.37491 .3788 Mdot
.42317 .39087 Mdot
.70507 .59115 Mdot
.62812 .44269 Mdot
.78607 .59015 Mdot
.42846 .40063 Mdot
.54701 .70192 Mdot
.25605 .44847 Mdot
.54991 .71784 Mdot
.45516 .43316 Mdot
.41621 .43063 Mdot
.28352 .43923 Mdot
.26438 .43786 Mdot
.55722 .69954 Mdot
.63827 .44105 Mdot
.6163 .40122 Mdot
.36341 .66042 Mdot
.43691 .43943 Mdot
.33785 .37951 Mdot
.41073 .39007 Mdot
.6473 .32012 Mdot
.39752 .28525 Mdot
.41304 .3658 Mdot
.36844 .32638 Mdot
.33629 .37411 Mdot
.41162 .41384 Mdot
.55011 .67524 Mdot
.34432 .65544 Mdot
.53391 .71311 Mdot
.57914 .6756 Mdot
.7117 .59506 Mdot
.66896 .29986 Mdot
.38771 .40615 Mdot
.63073 .31016 Mdot
.3907 .432 Mdot
.68801 .31898 Mdot
.359 .33177 Mdot
.34314 .33043 Mdot
.67646 .32874 Mdot
.3984 .38155 Mdot
.69933 .58086 Mdot
.62627 .58028 Mdot
.27287 .42816 Mdot
.43092 .44337 Mdot
.56682 .66538 Mdot
.51579 .71731 Mdot
.77916 .59346 Mdot
.6312 .59044 Mdot
.65209 .28727 Mdot
.60295 .47964 Mdot
.26811 .43406 Mdot
.38779 .41593 Mdot
.63733 .43746 Mdot
.70393 .57257 Mdot
.60697 .43947 Mdot
.77223 .59191 Mdot
.56159 .70382 Mdot
.52423 .70765 Mdot
.42452 .44081 Mdot
.62707 .19484 Mdot
.3553 .62576 Mdot
.3443 .65353 Mdot
.51643 .72262 Mdot
.6429 .58613 Mdot
.61086 .42914 Mdot
.27455 .50383 Mdot
.35991 .56196 Mdot
.6243 .31623 Mdot
.3855 .38994 Mdot
.63323 .56116 Mdot
.32656 .67691 Mdot
.64874 .28904 Mdot
.3858 .33789 Mdot
.68562 .55263 Mdot
.40315 .40094 Mdot
.2765 .46225 Mdot
.32596 .66269 Mdot
.35803 .32538 Mdot
.37298 .65241 Mdot
.5507 .69108 Mdot
.57476 .69266 Mdot
.41995 .43167 Mdot
.29765 .52459 Mdot
.31461 .69613 Mdot
.57858 .68649 Mdot
.66596 .3368 Mdot
.62528 .42115 Mdot
.66776 .29741 Mdot
.69549 .57253 Mdot
.65578 .31899 Mdot
.71695 .59129 Mdot
.7429 .59842 Mdot
.3829 .61053 Mdot
.65523 .30581 Mdot
.43354 .37252 Mdot
.61655 .41094 Mdot
.64564 .3456 Mdot
.37224 .33763 Mdot
.2561 .45532 Mdot
.6739 .5647 Mdot
.63101 .30787 Mdot
.38181 .38933 Mdot
.43099 .71574 Mdot
.57586 .67911 Mdot
.5635 .69378 Mdot
.61364 .43254 Mdot
.66879 .55636 Mdot
.38571 .61903 Mdot
.35312 .35707 Mdot
.32397 .70342 Mdot
.43198 .39874 Mdot
.39294 .41382 Mdot
.3175 .70365 Mdot
.38585 .61862 Mdot
.42095 .42962 Mdot
.48746 .42211 Mdot
.62398 .41564 Mdot
.54676 .6891 Mdot
.34891 .64459 Mdot
.34063 .64466 Mdot
.65253 .57575 Mdot
.37913 .6033 Mdot
.6606 .26807 Mdot
.56416 .69617 Mdot
.63131 .4044 Mdot
.54289 .70966 Mdot
.65718 .46906 Mdot
.7173 .58061 Mdot
.38045 .75269 Mdot
.35415 .6116 Mdot
.27309 .45114 Mdot
.38313 .60127 Mdot
.64232 .30876 Mdot
.37635 .62493 Mdot
.3807 .6168 Mdot
.44604 .43527 Mdot
.63907 .43445 Mdot
.60168 .42529 Mdot
.35203 .32829 Mdot
.35569 .62678 Mdot
.41123 .42121 Mdot
.38015 .33938 Mdot
.42915 .43713 Mdot
.35624 .32518 Mdot
.34947 .61762 Mdot
.36722 .48448 Mdot
.38089 .59659 Mdot
.32623 .66636 Mdot
.6613 .25281 Mdot
.60989 .40961 Mdot
.61236 .44657 Mdot
.57022 .65117 Mdot
.43567 .41055 Mdot
.73069 .60053 Mdot
.27554 .43653 Mdot
.63346 .42262 Mdot
.38493 .33102 Mdot
.62611 .33223 Mdot
.38889 .37268 Mdot
.6331 .43803 Mdot
.66086 .57133 Mdot
.27303 .45048 Mdot
.4208 .39324 Mdot
.61961 .44239 Mdot
.38413 .6067 Mdot
.33522 .63466 Mdot
.35072 .55196 Mdot
.63632 .31467 Mdot
.55098 .70973 Mdot
.2736 .43834 Mdot
.69532 .57861 Mdot
.7227 .60245 Mdot
.37816 .64018 Mdot
.66327 .59057 Mdot
.52436 .7047 Mdot
.42709 .40433 Mdot
.55502 .69261 Mdot
.62828 .32865 Mdot
.35173 .64128 Mdot
.27219 .4461 Mdot
.25089 .42915 Mdot
.34457 .66586 Mdot
.62595 .41508 Mdot
.67101 .30544 Mdot
.68365 .5982 Mdot
.31712 .66041 Mdot
.55521 .70834 Mdot
.65204 .57951 Mdot
.27961 .44611 Mdot
.67286 .23897 Mdot
.42358 .42138 Mdot
.40938 .43608 Mdot
.3567 .68504 Mdot
.44707 .40894 Mdot
.68614 .60459 Mdot
.3871 .62443 Mdot
.26381 .45617 Mdot
.32517 .31753 Mdot
.64507 .35449 Mdot
.66406 .43236 Mdot
.41302 .40713 Mdot
.39881 .34664 Mdot
.39481 .3622 Mdot
.34966 .75406 Mdot
.35618 .32227 Mdot
.74283 .58123 Mdot
.68262 .281 Mdot
.58068 .67069 Mdot
.62983 .43513 Mdot
.7078 .59911 Mdot
.47895 .43208 Mdot
.42516 .424 Mdot
.33459 .54701 Mdot
.25322 .45017 Mdot
.5265 .7143 Mdot
.35202 .4742 Mdot
.65593 .56867 Mdot
.79701 .5923 Mdot
.4477 .43936 Mdot
.36638 .56683 Mdot
.51254 .63989 Mdot
.63646 .43349 Mdot
.61732 .44996 Mdot
.64791 .29018 Mdot
.7381 .58744 Mdot
.62246 .46006 Mdot
.53827 .71194 Mdot
.38122 .40458 Mdot
.41802 .36849 Mdot
.40933 .74705 Mdot
.33293 .67544 Mdot
.57167 .67036 Mdot
.66553 .46153 Mdot
.39694 .40824 Mdot
.35693 .62005 Mdot
.3622 .65174 Mdot
.62293 .32527 Mdot
.75944 .59239 Mdot
.75117 .60066 Mdot
.59527 .17764 Mdot
.58805 .41589 Mdot
.70518 .57472 Mdot
.60698 .44963 Mdot
.2792 .43624 Mdot
.36421 .33352 Mdot
.57916 .67129 Mdot
.41071 .4327 Mdot
.33291 .54094 Mdot
.35813 .66288 Mdot
.41004 .39203 Mdot
.65893 .32646 Mdot
.22303 .4715 Mdot
.27791 .42537 Mdot
.48944 .41704 Mdot
.66002 .5542 Mdot
.39686 .41763 Mdot
.65903 .26772 Mdot
.64377 .42296 Mdot
.45101 .41747 Mdot
.66501 .57997 Mdot
.59108 .42532 Mdot
.6616 .3269 Mdot
.35515 .66764 Mdot
.62796 .43471 Mdot
.2513 .44764 Mdot
.3833 .37749 Mdot
.66815 .33516 Mdot
.28134 .4397 Mdot
.33213 .72266 Mdot
.63149 .45634 Mdot
.63752 .5684 Mdot
.31544 .65469 Mdot
.40252 .42185 Mdot
.62637 .42078 Mdot
.38739 .39102 Mdot
.33239 .73284 Mdot
.3987 .427 Mdot
.41907 .72836 Mdot
.33798 .66172 Mdot
.53591 .70342 Mdot
.26667 .44938 Mdot
.40112 .39961 Mdot
.59812 .43919 Mdot
.60873 .42595 Mdot
.42215 .3878 Mdot
.37656 .64379 Mdot
.37499 .63569 Mdot
.36436 .56249 Mdot
.64777 .57277 Mdot
.36281 .3666 Mdot
.54103 .69886 Mdot
.63671 .44061 Mdot
.58291 .67441 Mdot
.39954 .34901 Mdot
.63718 .31847 Mdot
.41068 .74175 Mdot
.43094 .41242 Mdot
.33317 .65509 Mdot
.4703 .28142 Mdot
.3715 .61662 Mdot
.56682 .65247 Mdot
.57095 .66896 Mdot
.35105 .63417 Mdot
.41523 .40649 Mdot
.3456 .3233 Mdot
.42553 .37336 Mdot
.56851 .70305 Mdot
.6219 .40251 Mdot
.63246 .3767 Mdot
.64851 .55278 Mdot
.67876 .24756 Mdot
.51665 .69272 Mdot
.54223 .78705 Mdot
.26776 .45452 Mdot
.32478 .64061 Mdot
.5487 .71424 Mdot
.543 .68649 Mdot
.65835 .563 Mdot
.26853 .45235 Mdot
.40257 .39674 Mdot
.60956 .4062 Mdot
.51026 .70827 Mdot
.40242 .37401 Mdot
.26565 .45877 Mdot
.77975 .59082 Mdot
.37434 .57222 Mdot
.3937 .75813 Mdot
.39468 .34507 Mdot
.33325 .53643 Mdot
.61737 .63672 Mdot
.32916 .62817 Mdot
.40903 .41961 Mdot
.61494 .42044 Mdot
.65852 .58956 Mdot
.42545 .40781 Mdot
.6706 .60291 Mdot
.53406 .71702 Mdot
.42694 .72285 Mdot
.40595 .35792 Mdot
.61471 .68268 Mdot
.41653 .42663 Mdot
.26345 .42584 Mdot
.66223 .31214 Mdot
.55286 .71429 Mdot
.35899 .56822 Mdot
.38303 .39939 Mdot
.66237 .58301 Mdot
.64771 .5517 Mdot
.3669 .65387 Mdot
.35302 .55459 Mdot
.37116 .75562 Mdot
.61772 .41443 Mdot
.67647 .59321 Mdot
.6254 .41911 Mdot
.49216 .41354 Mdot
.5819 .6753 Mdot
.66182 .32749 Mdot
.65136 .58823 Mdot
.5045 .71332 Mdot
.25607 .45547 Mdot
.36683 .62796 Mdot
.34914 .69305 Mdot
.28183 .43069 Mdot
.72829 .59247 Mdot
.64353 .32982 Mdot
.36552 .32831 Mdot
.29007 .43293 Mdot
.64439 .33541 Mdot
.65071 .56849 Mdot
.34459 .63075 Mdot
.35497 .65976 Mdot
.3457 .65629 Mdot
.4324 .37557 Mdot
.36711 .56019 Mdot
.52011 .35872 Mdot
.43685 .39363 Mdot
.31153 .71506 Mdot
.42402 .38272 Mdot
.56313 .69517 Mdot
.32665 .65956 Mdot
.35716 .32535 Mdot
.28942 .44755 Mdot
.45205 .45017 Mdot
.44065 .42782 Mdot
.2608 .43828 Mdot
.43569 .41021 Mdot
.32225 .71195 Mdot
.37468 .57059 Mdot
.36797 .3271 Mdot
.56795 .69141 Mdot
.64138 .31875 Mdot
.3138 .64572 Mdot
.3943 .41308 Mdot
.32551 .7177 Mdot
.37271 .33463 Mdot
.42286 .72336 Mdot
.25886 .43813 Mdot
.74474 .58722 Mdot
.3795 .39678 Mdot
.62893 .56084 Mdot
.25898 .42502 Mdot
.32847 .72178 Mdot
.574 .67905 Mdot
.27634 .42461 Mdot
.63589 .55063 Mdot
.35571 .47632 Mdot
.61258 .41701 Mdot
.66099 .31833 Mdot
.59205 .42434 Mdot
.55925 .69721 Mdot
.42989 .41871 Mdot
.38612 .37757 Mdot
.4494 .41155 Mdot
.49294 .41226 Mdot
.61236 .40959 Mdot
.67465 .33313 Mdot
.32303 .7221 Mdot
.39729 .37587 Mdot
.62684 .57467 Mdot
.33412 .62977 Mdot
.45717 .44797 Mdot
.44941 .3873 Mdot
.25073 .45653 Mdot
.3556 .6287 Mdot
.36647 .60774 Mdot
.62987 .27984 Mdot
.65246 .31156 Mdot
.42345 .4353 Mdot
.6808 .32082 Mdot
.27442 .44034 Mdot
.55006 .70603 Mdot
.42529 .38011 Mdot
.71868 .58171 Mdot
.34107 .31602 Mdot
.64901 .56891 Mdot
.43403 .43425 Mdot
.36203 .63384 Mdot
.56863 .70128 Mdot
.74398 .60299 Mdot
.77276 .60058 Mdot
.52261 .35372 Mdot
.7534 .60434 Mdot
.63576 .30887 Mdot
.64171 .30351 Mdot
.55541 .71178 Mdot
.41636 .40071 Mdot
.35385 .3191 Mdot
.23205 .46337 Mdot
.43561 .41652 Mdot
.42076 .41427 Mdot
.50185 .7316 Mdot
.52125 .69043 Mdot
.64523 .58514 Mdot
.42254 .42849 Mdot
.39144 .37073 Mdot
.35668 .63473 Mdot
.65272 .28309 Mdot
.70341 .5972 Mdot
.65071 .28885 Mdot
.69206 .5897 Mdot
.44973 .26789 Mdot
.63895 .42293 Mdot
.6382 .30976 Mdot
.51982 .68856 Mdot
.33293 .65196 Mdot
.61219 .40781 Mdot
.68177 .57032 Mdot
.67018 .59218 Mdot
.39956 .43922 Mdot
.33381 .67636 Mdot
.33509 .62534 Mdot
.63538 .31938 Mdot
.51512 .71892 Mdot
.28497 .43553 Mdot
.62409 .45215 Mdot
.67499 .42897 Mdot
.66317 .5866 Mdot
.31415 .72313 Mdot
.35015 .68998 Mdot
.39166 .40424 Mdot
.33627 .63439 Mdot
.3957 .39798 Mdot
.38459 .592 Mdot
.30696 .67324 Mdot
.45524 .43385 Mdot
.34945 .54855 Mdot
.70906 .57681 Mdot
.84043 .52763 Mdot
.27213 .45793 Mdot
.51034 .69562 Mdot
.27661 .43713 Mdot
.78991 .59089 Mdot
.47412 .28277 Mdot
.39873 .37813 Mdot
.39394 .4141 Mdot
.62971 .20715 Mdot
.37915 .35721 Mdot
.61704 .44608 Mdot
.61244 .41617 Mdot
.34186 .62976 Mdot
.59297 .42471 Mdot
.34956 .32445 Mdot
.65743 .30222 Mdot
.69262 .5774 Mdot
.51294 .30928 Mdot
.63879 .32694 Mdot
.35351 .66493 Mdot
.28852 .43996 Mdot
.30515 .69684 Mdot
.62329 .5731 Mdot
.62275 .43934 Mdot
.53114 .7164 Mdot
.35039 .31039 Mdot
.65686 .57532 Mdot
.50723 .71278 Mdot
.38076 .34683 Mdot
.75261 .58272 Mdot
.56685 .69231 Mdot
.8453 .51472 Mdot
.54311 .68173 Mdot
.51916 .72261 Mdot
.35788 .33637 Mdot
.65805 .30206 Mdot
.59314 .43231 Mdot
.68663 .31221 Mdot
.56949 .67907 Mdot
.80117 .5831 Mdot
.66616 .55781 Mdot
.3352 .31265 Mdot
.38171 .57817 Mdot
.62449 .41012 Mdot
.4188 .42306 Mdot
.53898 .68126 Mdot
.38796 .42832 Mdot
.59287 .43059 Mdot
.52836 .70236 Mdot
.25725 .42576 Mdot
.39739 .28273 Mdot
.62028 .42045 Mdot
.60046 .42022 Mdot
.63921 .29535 Mdot
.75928 .59737 Mdot
.34316 .61926 Mdot
.62525 .33612 Mdot
.34506 .35536 Mdot
.42347 .4382 Mdot
.55688 .70089 Mdot
.62748 .43538 Mdot
.54083 .69549 Mdot
.6667 .31802 Mdot
.66434 .33977 Mdot
.35387 .66771 Mdot
.3653 .56422 Mdot
.64966 .45654 Mdot
.33181 .38519 Mdot
.41134 .3714 Mdot
.33669 .54736 Mdot
.36364 .61222 Mdot
.32467 .45254 Mdot
.67136 .31583 Mdot
.63784 .29526 Mdot
.26239 .42532 Mdot
.37714 .33464 Mdot
.25908 .4434 Mdot
.39241 .34752 Mdot
.75136 .55753 Mdot
.26944 .44917 Mdot
.68287 .5975 Mdot
.39104 .34541 Mdot
.51938 .77343 Mdot
.26648 .42804 Mdot
.38951 .40489 Mdot
.68101 .58337 Mdot
.45056 .42512 Mdot
.68786 .56272 Mdot
.40943 .42495 Mdot
.74847 .57663 Mdot
.6951 .57882 Mdot
.6159 .48841 Mdot
.44112 .31846 Mdot
.61214 .44244 Mdot
.66458 .33194 Mdot
.6749 .29543 Mdot
.52031 .33245 Mdot
.34479 .63288 Mdot
.22517 .46829 Mdot
.39087 .40646 Mdot
.6586 .56147 Mdot
.52882 .71799 Mdot
.24337 .43851 Mdot
.40663 .43654 Mdot
.27854 .43174 Mdot
.36763 .62529 Mdot
.67124 .55514 Mdot
.66633 .31034 Mdot
.65068 .59592 Mdot
.78688 .5942 Mdot
.71173 .57587 Mdot
.49819 .3981 Mdot
.24707 .44925 Mdot
.65882 .26824 Mdot
.34513 .54203 Mdot
.60492 .46337 Mdot
.37277 .63839 Mdot
.62933 .43271 Mdot
.65498 .29342 Mdot
.40901 .29475 Mdot
.33433 .62807 Mdot
.70473 .59092 Mdot
.40291 .40183 Mdot
.6406 .44034 Mdot
.68702 .31203 Mdot
.31261 .67105 Mdot
.67073 .33354 Mdot
.68375 .57555 Mdot
.62488 .42501 Mdot
.36179 .37028 Mdot
.38041 .48976 Mdot
.33033 .31131 Mdot
.39894 .40137 Mdot
.63548 .32412 Mdot
.33216 .67667 Mdot
.27882 .43118 Mdot
.52616 .69075 Mdot
.35138 .32147 Mdot
.42074 .42339 Mdot
.61664 .68176 Mdot
.36378 .63371 Mdot
.64605 .30828 Mdot
.54128 .68066 Mdot
.65233 .31334 Mdot
.61439 .44721 Mdot
.38441 .59324 Mdot
.61819 .45012 Mdot
.25434 .45018 Mdot
.54242 .71514 Mdot
.33555 .62546 Mdot
.77712 .58886 Mdot
.58983 .41008 Mdot
.70541 .58212 Mdot
.40611 .29371 Mdot
.37145 .64862 Mdot
.51064 .7527 Mdot
.65178 .59631 Mdot
.51989 .73664 Mdot
.35781 .31674 Mdot
.52714 .69824 Mdot
.39096 .40786 Mdot
.35506 .65088 Mdot
.56637 .7072 Mdot
.76902 .60056 Mdot
.40463 .35213 Mdot
.64462 .44989 Mdot
.39858 .38236 Mdot
.33822 .75289 Mdot
.53528 .77929 Mdot
.37793 .58708 Mdot
.51367 .6957 Mdot
.43428 .42845 Mdot
.62032 .41358 Mdot
.43791 .43977 Mdot
.56851 .67587 Mdot
.50133 .72903 Mdot
.71162 .60718 Mdot
.40291 .40661 Mdot
.64851 .31807 Mdot
.72188 .5964 Mdot
.66088 .55033 Mdot
.64089 .58012 Mdot
.36081 .56747 Mdot
.63264 .41361 Mdot
.61572 .41382 Mdot
.48087 .28497 Mdot
.54109 .69366 Mdot
.61341 .44324 Mdot
.38689 .37486 Mdot
.51925 .35743 Mdot
.34188 .65896 Mdot
.67817 .57606 Mdot
.43071 .43241 Mdot
.27834 .45554 Mdot
.615 .43932 Mdot
.67075 .58143 Mdot
.38416 .61198 Mdot
.6204 .59391 Mdot
.42726 .4088 Mdot
.26235 .45368 Mdot
.34086 .67014 Mdot
.34088 .73056 Mdot
.35612 .35427 Mdot
.39653 .39645 Mdot
.55495 .68947 Mdot
.38581 .71231 Mdot
.37892 .35018 Mdot
.37854 .52412 Mdot
.61683 .40369 Mdot
.58381 .5784 Mdot
.40469 .67768 Mdot
.23133 .45442 Mdot
.47993 .6014 Mdot
.28559 .34359 Mdot
.5158 .61388 Mdot
.75133 .54352 Mdot
.4458 .591 Mdot
.84688 .49765 Mdot
.6028 .67974 Mdot
.25795 .46571 Mdot
.56168 .17903 Mdot
.55264 .77831 Mdot
.45469 .65366 Mdot
.59277 .73343 Mdot
.57443 .4727 Mdot
.77843 .58683 Mdot
.76179 .58675 Mdot
.74227 .53368 Mdot
.41338 .44677 Mdot
.44785 .67295 Mdot
.30303 .44884 Mdot
.54152 .75357 Mdot
.71028 .55525 Mdot
.29482 .43586 Mdot
.61231 .22708 Mdot
.59841 .65625 Mdot
.58267 .31944 Mdot
.30503 .51109 Mdot
.66071 .51363 Mdot
.3153 .39425 Mdot
.5547 .36001 Mdot
.22805 .45972 Mdot
.54526 .59048 Mdot
.59272 .67095 Mdot
.39597 .61124 Mdot
.60087 .64859 Mdot
.69633 .59486 Mdot
.32863 .6788 Mdot
.59185 .76488 Mdot
.61257 .26393 Mdot
.57928 .73175 Mdot
.47871 .60251 Mdot
.6177 .45614 Mdot
.5844 .56885 Mdot
.36621 .37179 Mdot
.36583 .59799 Mdot
.67706 .52847 Mdot
.72569 .55554 Mdot
.39261 .65264 Mdot
.65634 .53983 Mdot
.4201 .30043 Mdot
.4544 .65658 Mdot
.4 .68557 Mdot
.58189 .47648 Mdot
.61986 .49114 Mdot
.36596 .6116 Mdot
.57337 .21771 Mdot
.5383 .44073 Mdot
.33906 .35237 Mdot
.66027 .53376 Mdot
.39068 .62914 Mdot
.31551 .52506 Mdot
.34963 .56276 Mdot
.81981 .54936 Mdot
.63501 .25816 Mdot
.7721 .53992 Mdot
.54529 .43874 Mdot
.58993 .71306 Mdot
.47569 .34214 Mdot
.57949 .62326 Mdot
.78802 .53307 Mdot
.35402 .72173 Mdot
.59044 .19922 Mdot
.53572 .52674 Mdot
.65291 .23945 Mdot
.39352 .67405 Mdot
.59207 .48765 Mdot
.41376 .60836 Mdot
.60213 .54758 Mdot
.44099 .27847 Mdot
.63451 .23964 Mdot
.45349 .66873 Mdot
.61557 .38491 Mdot
.55316 .77614 Mdot
.36646 .70485 Mdot
.71169 .54954 Mdot
.61267 .39481 Mdot
.43455 .48487 Mdot
.63792 .22449 Mdot
.49037 .59375 Mdot
.58928 .25386 Mdot
.6713 .51627 Mdot
.60281 .76709 Mdot
.67214 .54934 Mdot
.56761 .71061 Mdot
.59472 .30259 Mdot
.35876 .64994 Mdot
.82934 .54136 Mdot
.45652 .63267 Mdot
.50784 .63758 Mdot
.63138 .22215 Mdot
.81218 .55973 Mdot
.59467 .53386 Mdot
.60333 .48619 Mdot
.59461 .64701 Mdot
.5531 .60963 Mdot
.52279 .76062 Mdot
.65459 .41857 Mdot
.38747 .73576 Mdot
.58899 .29936 Mdot
.79825 .56093 Mdot
.58011 .18195 Mdot
.34693 .36253 Mdot
.54566 .38707 Mdot
.36647 .67743 Mdot
.47453 .52761 Mdot
.53107 .75905 Mdot
.65921 .23898 Mdot
.29461 .42982 Mdot
.36808 .72418 Mdot
.74836 .53405 Mdot
.46081 .437 Mdot
.43682 .70462 Mdot
.59589 .74411 Mdot
.61912 .58397 Mdot
.38243 .69095 Mdot
.65513 .26081 Mdot
.48216 .30481 Mdot
.38329 .50409 Mdot
.68823 .54672 Mdot
.3555 .34672 Mdot
.40582 .51607 Mdot
.82251 .47963 Mdot
.44567 .69047 Mdot
.42077 .4906 Mdot
.35803 .68788 Mdot
.78603 .53056 Mdot
.75916 .54259 Mdot
.40703 .70642 Mdot
.67111 .43947 Mdot
.59427 .25694 Mdot
.41909 .52599 Mdot
.58932 .55283 Mdot
.30046 .44901 Mdot
.30951 .43984 Mdot
.69205 .52149 Mdot
.51985 .4334 Mdot
.61128 .3628 Mdot
.5956 .73819 Mdot
.34396 .55056 Mdot
.56624 .37001 Mdot
.35741 .52548 Mdot
.33681 .71867 Mdot
.47793 .47909 Mdot
.58608 .65406 Mdot
.47708 .4685 Mdot
.61772 .2238 Mdot
.69244 .60307 Mdot
.79155 .53757 Mdot
.58319 .72981 Mdot
.71474 .55454 Mdot
.48909 .64698 Mdot
.48964 .64767 Mdot
.59386 .32952 Mdot
.56972 .77733 Mdot
.60482 .50361 Mdot
.37149 .59239 Mdot
.47685 .63238 Mdot
.34254 .52849 Mdot
.4829 .36865 Mdot
.39336 .55588 Mdot
.67311 .30963 Mdot
.47448 .45307 Mdot
.37817 .69359 Mdot
.66724 .45669 Mdot
.48992 .38818 Mdot
.31148 .36002 Mdot
.65197 .44254 Mdot
.484 .32676 Mdot
.4535 .2707 Mdot
.56194 .5387 Mdot
.80569 .54537 Mdot
.40873 .53691 Mdot
.489 .32857 Mdot
.538 .75851 Mdot
.22994 .47039 Mdot
.65637 .23719 Mdot
.61355 .30486 Mdot
.41348 .68712 Mdot
.40306 .71647 Mdot
.60664 .79709 Mdot
.5106 .75019 Mdot
.83205 .47403 Mdot
.58366 .72924 Mdot
.23439 .49063 Mdot
.67908 .603 Mdot
.58613 .5014 Mdot
.40712 .60487 Mdot
.30918 .36805 Mdot
.62023 .23949 Mdot
.56923 .55527 Mdot
.63842 .34504 Mdot
.42265 .64604 Mdot
.38399 .51887 Mdot
.59784 .23368 Mdot
.58418 .21277 Mdot
.58112 .2217 Mdot
.58773 .76944 Mdot
.50216 .42777 Mdot
.622 .21459 Mdot
.51699 .3734 Mdot
.53779 .48342 Mdot
.23368 .45039 Mdot
.3266 .34961 Mdot
.8347 .50499 Mdot
.55085 .41942 Mdot
.56019 .60828 Mdot
.39181 .65397 Mdot
.64422 .21904 Mdot
.47251 .27466 Mdot
.59823 .57688 Mdot
.57547 .32988 Mdot
.59003 .39146 Mdot
.56537 .36021 Mdot
.59707 .33945 Mdot
.51389 .59028 Mdot
.5952 .74362 Mdot
.6573 .21635 Mdot
.76711 .52463 Mdot
.55819 .74807 Mdot
.34688 .70923 Mdot
.8352 .51721 Mdot
.42758 .70709 Mdot
.57153 .71157 Mdot
.4041 .66195 Mdot
.28756 .48177 Mdot
.42848 .56546 Mdot
.55441 .59213 Mdot
.40727 .47321 Mdot
.57377 .3855 Mdot
.66255 .59646 Mdot
.80382 .51156 Mdot
.42072 .55468 Mdot
.53153 .47981 Mdot
.49736 .32665 Mdot
.8044 .57373 Mdot
.53837 .56436 Mdot
.46892 .39006 Mdot
.40912 .53491 Mdot
.43601 .6734 Mdot
.44001 .69924 Mdot
.322 .49903 Mdot
.40471 .36997 Mdot
.61912 .25599 Mdot
.84352 .46993 Mdot
.59987 .328 Mdot
.42801 .69203 Mdot
.61345 .76228 Mdot
.60264 .67404 Mdot
.50301 .35745 Mdot
.30682 .33019 Mdot
.49849 .56652 Mdot
.29135 .3266 Mdot
.52543 .72808 Mdot
.31566 .52568 Mdot
.47605 .65547 Mdot
.51341 .36985 Mdot
.41242 .5856 Mdot
.49364 .63665 Mdot
.48129 .40869 Mdot
.3613 .6904 Mdot
.3436 .74121 Mdot
.7849 .52707 Mdot
.68595 .60197 Mdot
.66888 .42257 Mdot
.5297 .45547 Mdot
.63972 .28823 Mdot
.63688 .39413 Mdot
.58866 .54283 Mdot
.33259 .52681 Mdot
.61918 .76359 Mdot
.59408 .36022 Mdot
.83824 .52711 Mdot
.59867 .33976 Mdot
.76956 .54364 Mdot
.64791 .53509 Mdot
.46427 .30612 Mdot
.56824 .72816 Mdot
.59797 .70543 Mdot
.4444 .29407 Mdot
.7838 .56133 Mdot
.5941 .56631 Mdot
.36445 .59545 Mdot
.39088 .36495 Mdot
.46428 .27997 Mdot
.55243 .36155 Mdot
.46698 .31876 Mdot
.34686 .49672 Mdot
.37894 .65083 Mdot
.5345 .38556 Mdot
.59823 .59767 Mdot
.25141 .427 Mdot
.39665 .71951 Mdot
.56322 .71213 Mdot
.34787 .70484 Mdot
.80755 .57621 Mdot
.61402 .78294 Mdot
.5101 .62476 Mdot
.49724 .37104 Mdot
.5846 .29651 Mdot
.50279 .37051 Mdot
.40245 .72119 Mdot
.29811 .47825 Mdot
.48119 .66033 Mdot
.3929 .66094 Mdot
.55059 .51192 Mdot
.5779 .63291 Mdot
.43443 .64032 Mdot
.36112 .69539 Mdot
.30541 .43046 Mdot
.61548 .28007 Mdot
.39528 .47015 Mdot
.53151 .59575 Mdot
.35078 .35271 Mdot
.4582 .53357 Mdot
.4624 .63243 Mdot
.51052 .32892 Mdot
.50026 .61121 Mdot
.57289 .22733 Mdot
.3212 .53832 Mdot
.58204 .60816 Mdot
.53934 .41239 Mdot
.51176 .36931 Mdot
.30624 .51139 Mdot
.36845 .70587 Mdot
.59495 .73804 Mdot
.40369 .46438 Mdot
.63853 .26009 Mdot
.5243 .51522 Mdot
.49082 .32539 Mdot
.43344 .50984 Mdot
.41456 .46664 Mdot
.65391 .42571 Mdot
.5951 .33683 Mdot
.58629 .58244 Mdot
.55608 .17532 Mdot
.77063 .56249 Mdot
.38132 .5389 Mdot
.41345 .61216 Mdot
.79474 .52804 Mdot
.43572 .62121 Mdot
.45213 .60296 Mdot
.42634 .53866 Mdot
.82349 .51934 Mdot
.5699 .57451 Mdot
.59526 .58971 Mdot
.34936 .74344 Mdot
.60693 .21639 Mdot
.54184 .60601 Mdot
.57693 .70224 Mdot
.55107 .40484 Mdot
.40169 .43147 Mdot
.37348 .53405 Mdot
.3859 .75389 Mdot
.47793 .49649 Mdot
.53021 .61646 Mdot
.84907 .48691 Mdot
.57479 .55206 Mdot
.40934 .54303 Mdot
.56006 .17322 Mdot
.5604 .16542 Mdot
.36521 .54088 Mdot
.66503 .23846 Mdot
.59881 .58809 Mdot
.41219 .71604 Mdot
.59711 .67736 Mdot
.47377 .3534 Mdot
.33605 .54486 Mdot
.62772 .27417 Mdot
.59299 .80102 Mdot
.53964 .76049 Mdot
.41176 .63892 Mdot
.65596 .25323 Mdot
.5314 .49028 Mdot
.59916 .50841 Mdot
.60812 .75562 Mdot
.78496 .5824 Mdot
.81502 .54456 Mdot
.32643 .49183 Mdot
.70917 .53631 Mdot
.70987 .51835 Mdot
.45572 .67879 Mdot
.84032 .51711 Mdot
.59548 .39212 Mdot
.22594 .46632 Mdot
.78611 .53226 Mdot
.36329 .74309 Mdot
.71779 .55079 Mdot
.46334 .62752 Mdot
.58299 .54725 Mdot
.4912 .47152 Mdot
.39622 .73122 Mdot
.58765 .76115 Mdot
.56299 .50797 Mdot
.41077 .2897 Mdot
.35619 .70817 Mdot
.35617 .72566 Mdot
.27139 .47587 Mdot
.58902 .52829 Mdot
.56518 .20606 Mdot
.57138 .65813 Mdot
.44249 .30815 Mdot
.36545 .59675 Mdot
.52583 .32465 Mdot
.60168 .50401 Mdot
.38038 .32849 Mdot
.61269 .28215 Mdot
.6076 .50676 Mdot
.5749 .20679 Mdot
.83246 .54792 Mdot
.56876 .32057 Mdot
.58456 .62738 Mdot
.63847 .3919 Mdot
.83216 .50135 Mdot
.83106 .48663 Mdot
.57453 .19577 Mdot
.7338 .52328 Mdot
.43873 .29133 Mdot
.56927 .52005 Mdot
.47704 .36074 Mdot
.49067 .40562 Mdot
.79439 .52423 Mdot
.30389 .51439 Mdot
.55982 .35725 Mdot
.42933 .66105 Mdot
.79265 .566 Mdot
.52634 .39684 Mdot
.52479 .3303 Mdot
.46281 .50496 Mdot
.61488 .4949 Mdot
.69422 .55944 Mdot
.61724 .19574 Mdot
.40593 .70917 Mdot
.57478 .36221 Mdot
.3748 .72279 Mdot
.34123 .70047 Mdot
.74356 .54387 Mdot
.41439 .6717 Mdot
.69526 .2886 Mdot
.6538 .52413 Mdot
.61585 .31024 Mdot
.59804 .55511 Mdot
.34696 .75449 Mdot
.46348 .43088 Mdot
.59671 .31918 Mdot
.56813 .37193 Mdot
.56784 .18848 Mdot
.53777 .38898 Mdot
.47185 .4579 Mdot
.56865 .21658 Mdot
.42932 .67263 Mdot
.46139 .31879 Mdot
.60073 .22833 Mdot
.38912 .5787 Mdot
.63316 .25876 Mdot
.52121 .70066 Mdot
.57227 .47472 Mdot
.37603 .7512 Mdot
.48051 .33626 Mdot
.47606 .33394 Mdot
.59792 .36333 Mdot
.54907 .77473 Mdot
.4089 .55922 Mdot
.41902 .52814 Mdot
.71372 .55262 Mdot
.47244 .35071 Mdot
.51404 .59772 Mdot
.58327 .1806 Mdot
.38972 .36285 Mdot
.75152 .50999 Mdot
.79755 .54115 Mdot
.57137 .72444 Mdot
.58151 .53441 Mdot
.36572 .75098 Mdot
.32794 .48373 Mdot
.48593 .29603 Mdot
.60921 .21926 Mdot
.58095 .53306 Mdot
.30459 .34672 Mdot
.32103 .45835 Mdot
.58616 .64356 Mdot
.56957 .76122 Mdot
.48739 .60251 Mdot
.55565 .46125 Mdot
.3585 .3609 Mdot
.76754 .53754 Mdot
.84896 .49377 Mdot
.56544 .20396 Mdot
.57443 .75807 Mdot
.47782 .33016 Mdot
.42158 .50575 Mdot
.56837 .40809 Mdot
.58011 .17742 Mdot
.77863 .58591 Mdot
.37703 .69393 Mdot
.78624 .55912 Mdot
.5587 .77194 Mdot
.59207 .50166 Mdot
.45874 .30904 Mdot
.57415 .22064 Mdot
.40661 .61401 Mdot
.54546 .52678 Mdot
.44872 .49896 Mdot
.34688 .30755 Mdot
.46162 .66203 Mdot
.2889 .48527 Mdot
.5645 .78563 Mdot
.56624 .18951 Mdot
.71047 .52526 Mdot
.39602 .48157 Mdot
.56291 .18228 Mdot
.38245 .64326 Mdot
.4621 .66755 Mdot
.60028 .76714 Mdot
.49151 .33376 Mdot
.67052 .54767 Mdot
.39642 .37007 Mdot
.42108 .28696 Mdot
.43858 .63381 Mdot
.54262 .39862 Mdot
.65304 .34993 Mdot
.35658 .70208 Mdot
.72761 .52928 Mdot
.35197 .69896 Mdot
.84501 .48717 Mdot
.51211 .58711 Mdot
.39941 .68151 Mdot
.31 .46904 Mdot
.64394 .53503 Mdot
.4335 .67076 Mdot
.5811 .32243 Mdot
.32857 .35223 Mdot
.40394 .67045 Mdot
.39728 .67673 Mdot
.39433 .57361 Mdot
.53971 .73931 Mdot
.59449 .28263 Mdot
.80851 .5557 Mdot
.67424 .42802 Mdot
.38284 .56925 Mdot
.47916 .34789 Mdot
.58722 .54874 Mdot
.57321 .34864 Mdot
.67666 .60612 Mdot
.66901 .22939 Mdot
.25062 .48376 Mdot
.45168 .68702 Mdot
.50794 .55834 Mdot
.31275 .33056 Mdot
.47217 .33738 Mdot
.64585 .53913 Mdot
.59206 .5364 Mdot
.38991 .53505 Mdot
.34902 .68122 Mdot
.46878 .67299 Mdot
.67243 .3194 Mdot
.67141 .44706 Mdot
.56902 .74416 Mdot
.316 .50202 Mdot
.80262 .53532 Mdot
.3039 .70099 Mdot
.65693 .46358 Mdot
.62609 .53528 Mdot
.49962 .40235 Mdot
.3201 .35147 Mdot
.63788 .20268 Mdot
.57593 .30929 Mdot
.35266 .67296 Mdot
.44534 .68555 Mdot
.68765 .53193 Mdot
.59091 .36092 Mdot
.55132 .54385 Mdot
.78929 .52272 Mdot
.44844 .47763 Mdot
.58603 .34648 Mdot
.41378 .66473 Mdot
.48274 .58833 Mdot
.78946 .54934 Mdot
.62351 .36713 Mdot
.79923 .56684 Mdot
.34463 .48676 Mdot
.5419 .44143 Mdot
.7815 .5772 Mdot
.46906 .49462 Mdot
.60296 .57359 Mdot
.24988 .42736 Mdot
.49605 .57088 Mdot
.8239 .5153 Mdot
.34013 .68474 Mdot
.56625 .45842 Mdot
.40373 .69199 Mdot
.54243 .76107 Mdot
.58703 .30239 Mdot
.43713 .6901 Mdot
.8043 .55687 Mdot
.47876 .35631 Mdot
.59588 .38292 Mdot
.31513 .51422 Mdot
.33664 .35913 Mdot
.6109 .45019 Mdot
.39341 .50344 Mdot
.60034 .39415 Mdot
.48003 .28091 Mdot
.48441 .39996 Mdot
.62631 .24121 Mdot
.45566 .27374 Mdot
.49409 .47141 Mdot
.59851 .49219 Mdot
.37303 .59982 Mdot
.64854 .23112 Mdot
.48007 .29561 Mdot
.38705 .73848 Mdot
.81329 .54313 Mdot
.7281 .51601 Mdot
.56139 .18104 Mdot
.55404 .7741 Mdot
.51158 .45914 Mdot
.8429 .51436 Mdot
.53003 .51389 Mdot
.71057 .51741 Mdot
.59792 .55497 Mdot
.33294 .69618 Mdot
.62247 .22167 Mdot
.60726 .50102 Mdot
.48623 .478 Mdot
.43001 .37834 Mdot
.39467 .66079 Mdot
.45891 .28595 Mdot
.48881 .35636 Mdot
.70144 .59504 Mdot
.30973 .34707 Mdot
.69109 .52272 Mdot
.38645 .56726 Mdot
.79773 .5346 Mdot
.7912 .51618 Mdot
.55733 .41535 Mdot
.60625 .62946 Mdot
.55803 .18344 Mdot
.48938 .44462 Mdot
.23497 .45631 Mdot
.35753 .69561 Mdot
.65755 .34812 Mdot
.74789 .52432 Mdot
.40801 .46495 Mdot
.31731 .38535 Mdot
.4395 .48247 Mdot
.62176 .27829 Mdot
.47224 .5181 Mdot
.5718 .65674 Mdot
.38936 .5766 Mdot
.38852 .73615 Mdot
.3904 .70493 Mdot
.54948 .78248 Mdot
.82266 .51356 Mdot
.51022 .62439 Mdot
.47991 .59775 Mdot
.48777 .46707 Mdot
.80103 .50711 Mdot
.55945 .75735 Mdot
.54664 .72038 Mdot
.33458 .5289 Mdot
.56482 .19884 Mdot
.34194 .71116 Mdot
.46844 .62327 Mdot
.54585 .5826 Mdot
.5058 .37453 Mdot
.522 .76028 Mdot
.45169 .67444 Mdot
.3756 .68326 Mdot
.5828 .24269 Mdot
.56109 .5992 Mdot
.63297 .38008 Mdot
.76946 .55576 Mdot
.52786 .58295 Mdot
.79452 .51819 Mdot
.34519 .55905 Mdot
.58234 .22745 Mdot
.49459 .3289 Mdot
.58198 .40542 Mdot
.41423 .3782 Mdot
.42709 .64536 Mdot
.59623 .33594 Mdot
.54912 .54303 Mdot
.55555 .62146 Mdot
.38292 .7016 Mdot
.82582 .54308 Mdot
.65215 .46208 Mdot
.61909 .76088 Mdot
.60364 .49086 Mdot
.31373 .36786 Mdot
.30764 .35823 Mdot
.5494 .73373 Mdot
.58927 .55532 Mdot
.43754 .6088 Mdot
.55302 .45867 Mdot
.33198 .51832 Mdot
.61276 .31877 Mdot
.61124 .19256 Mdot
.38671 .64196 Mdot
.82309 .56003 Mdot
.36353 .55282 Mdot
.38663 .65081 Mdot
.70755 .52176 Mdot
.58379 .62029 Mdot
.52014 .44035 Mdot
.54729 .4015 Mdot
.30694 .68623 Mdot
.60411 .18616 Mdot
.52628 .61836 Mdot
.55885 .4454 Mdot
.69683 .53915 Mdot
.46487 .63778 Mdot
.61213 .65578 Mdot
.5919 .71953 Mdot
.82969 .53686 Mdot
.78819 .53297 Mdot
.60543 .66061 Mdot
.59681 .5873 Mdot
.54915 .61934 Mdot
.59592 .235 Mdot
.60494 .49502 Mdot
.58642 .31231 Mdot
.57723 .78266 Mdot
.33775 .50672 Mdot
.44923 .27232 Mdot
.48231 .30368 Mdot
.33337 .35255 Mdot
.40863 .49134 Mdot
.58219 .26112 Mdot
.64901 .43292 Mdot
.67335 .4379 Mdot
.71294 .54667 Mdot
.58421 .17725 Mdot
.44155 .66344 Mdot
.62995 .46108 Mdot
.56412 .39111 Mdot
.55897 .59755 Mdot
.43806 .30596 Mdot
.42182 .53464 Mdot
.63097 .38725 Mdot
.58716 .6509 Mdot
.39747 .70647 Mdot
.63151 .26587 Mdot
.42028 .38342 Mdot
.28483 .32985 Mdot
.52555 .75488 Mdot
.6451 .5487 Mdot
.38249 .70616 Mdot
.63107 .20298 Mdot
.55217 .71779 Mdot
.60893 .74709 Mdot
.55518 .73415 Mdot
.57902 .36068 Mdot
.6074 .77943 Mdot
.53274 .73996 Mdot
.85033 .49857 Mdot
.4537 .68699 Mdot
.39959 .4854 Mdot
.35439 .72998 Mdot
.4774 .2795 Mdot
.38292 .50733 Mdot
.65626 .42309 Mdot
.61629 .27102 Mdot
.46746 .33191 Mdot
.57119 .46843 Mdot
.57989 .25419 Mdot
.78826 .55284 Mdot
.7737 .56225 Mdot
.51852 .74959 Mdot
.40745 .65023 Mdot
.61827 .78158 Mdot
.68137 .53577 Mdot
.26263 .49485 Mdot
.573 .3073 Mdot
.41176 .47569 Mdot
.54743 .53799 Mdot
.41983 .52143 Mdot
.60922 .23251 Mdot
.81329 .51275 Mdot
.60987 .58326 Mdot
.62143 .56751 Mdot
.49813 .31605 Mdot
.56418 .4045 Mdot
.41632 .57251 Mdot
.56712 .32909 Mdot
.64149 .53826 Mdot
.60693 .50011 Mdot
.79663 .54864 Mdot
.42694 .64566 Mdot
.34517 .36467 Mdot
.56866 .19696 Mdot
.32425 .36455 Mdot
.80323 .57789 Mdot
.58594 .77205 Mdot
.71183 .54748 Mdot
.58694 .18054 Mdot
.42747 .60769 Mdot
.46603 .40503 Mdot
.55481 .17733 Mdot
.65114 .24049 Mdot
.55273 .61874 Mdot
.45014 .44417 Mdot
.84915 .50537 Mdot
.61648 .55921 Mdot
.58408 .37099 Mdot
.31348 .52424 Mdot
.75772 .558 Mdot
.47775 .38285 Mdot
.42139 .46616 Mdot
.55827 .45531 Mdot
.37447 .65429 Mdot
.40475 .65968 Mdot
.66437 .51224 Mdot
.7813 .56 Mdot
.30429 .50184 Mdot
.32133 .53862 Mdot
.34027 .48768 Mdot
.32824 .68023 Mdot
.6086 .28384 Mdot
.68701 .26111 Mdot
.29236 .5077 Mdot
.58773 .23656 Mdot
.30122 .30966 Mdot
.44527 .64411 Mdot
.32801 .52529 Mdot
.46992 .31237 Mdot
.68713 .51967 Mdot
.57311 .17159 Mdot
.3397 .52022 Mdot
.66601 .22821 Mdot
.63249 .27444 Mdot
.34596 .67508 Mdot
.37934 .55102 Mdot
.48448 .34901 Mdot
.52642 .60833 Mdot
.59108 .65 Mdot
.70986 .55128 Mdot
.72509 .52087 Mdot
.63247 .51914 Mdot
.43408 .39976 Mdot
.40884 .52149 Mdot
.59306 .32258 Mdot
.59151 .50033 Mdot
.59508 .31349 Mdot
.36471 .50183 Mdot
.38695 .36526 Mdot
.55344 .16987 Mdot
.40888 .7184 Mdot
.48941 .37678 Mdot
.63614 .47338 Mdot
.62856 .46076 Mdot
.38519 .33232 Mdot
.52271 .73082 Mdot
.51588 .35481 Mdot
.7435 .5544 Mdot
.61141 .27455 Mdot
.37567 .56649 Mdot
.47975 .34335 Mdot
.60518 .675 Mdot
.36602 .35984 Mdot
.47414 .38107 Mdot
.51307 .72752 Mdot
.72459 .54412 Mdot
.61753 .64232 Mdot
.54077 .75782 Mdot
.4599 .65547 Mdot
.40584 .28709 Mdot
.64506 .45521 Mdot
.71761 .53365 Mdot
.55119 .73205 Mdot
.52494 .75607 Mdot
.80354 .55844 Mdot
.45383 .46658 Mdot
.56774 .76894 Mdot
.6732 .50717 Mdot
.461 .31668 Mdot
.41739 .51432 Mdot
.55909 .61136 Mdot
.29547 .48168 Mdot
.602 .24708 Mdot
.65689 .40191 Mdot
.65052 .44013 Mdot
.30158 .4668 Mdot
.62052 .24308 Mdot
.53624 .72158 Mdot
.84062 .46401 Mdot
.58478 .61846 Mdot
.40525 .68929 Mdot
.31591 .43203 Mdot
.5754 .53716 Mdot
.29099 .42694 Mdot
.45152 .44369 Mdot
.32309 .40195 Mdot
.60625 .74574 Mdot
.58517 .53787 Mdot
.46465 .64596 Mdot
.4973 .62036 Mdot
.53302 .39259 Mdot
.2901 .42926 Mdot
.43448 .43149 Mdot
.64638 .41916 Mdot
.43002 .28101 Mdot
.65391 .42168 Mdot
.54385 .41665 Mdot
.59791 .73908 Mdot
.72161 .53715 Mdot
.77029 .56156 Mdot
.50742 .42999 Mdot
.61467 .22784 Mdot
.23725 .44008 Mdot
.57436 .31168 Mdot
.44694 .52684 Mdot
.58478 .75988 Mdot
.32219 .36594 Mdot
.57196 .17437 Mdot
.39525 .5179 Mdot
.68369 .29908 Mdot
.61588 .2999 Mdot
.58134 .33319 Mdot
.60417 .66518 Mdot
.35192 .74729 Mdot
.7166 .54896 Mdot
.50193 .36284 Mdot
.38801 .71203 Mdot
.66589 .41119 Mdot
.5994 .35688 Mdot
.55971 .48221 Mdot
.57602 .61944 Mdot
.28937 .48846 Mdot
.4967 .39808 Mdot
.72577 .58672 Mdot
.29825 .47854 Mdot
.41127 .49007 Mdot
.58151 .26292 Mdot
.23636 .45553 Mdot
.48347 .55293 Mdot
.40103 .5143 Mdot
.56925 .19103 Mdot
.72689 .5837 Mdot
.30388 .34423 Mdot
.23131 .47744 Mdot
.60344 .75166 Mdot
.7078 .51404 Mdot
.56446 .20281 Mdot
.59793 .7062 Mdot
.55282 .45722 Mdot
.39651 .75255 Mdot
.41352 .50971 Mdot
.36969 .68281 Mdot
.56156 .74497 Mdot
.57613 .43298 Mdot
.43855 .50122 Mdot
.57243 .16365 Mdot
.58999 .34812 Mdot
.51451 .44596 Mdot
.26271 .49667 Mdot
.79741 .54582 Mdot
.29892 .35421 Mdot
.56974 .77305 Mdot
.60983 .28616 Mdot
.60742 .65659 Mdot
.84527 .51218 Mdot
.52954 .58912 Mdot
.35337 .56731 Mdot
.56184 .4051 Mdot
.38831 .716 Mdot
.57867 .51975 Mdot
.3168 .53568 Mdot
.39643 .71883 Mdot
.55477 .35988 Mdot
.5629 .57231 Mdot
.30421 .68938 Mdot
.36668 .54563 Mdot
.5147 .56398 Mdot
.58935 .62229 Mdot
.46963 .62239 Mdot
.48689 .59631 Mdot
.55395 .75753 Mdot
.50129 .55296 Mdot
.4086 .7209 Mdot
.58644 .71146 Mdot
.36305 .49479 Mdot
.67909 .51531 Mdot
.53832 .39558 Mdot
.66744 .60056 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`2booooo`Co0000Toooool001cooooo00?o0000ooooooooool0/_ooool7o`00093o
oooo000Looooo`03o`000?oooooooooo0;;ooooo2?l0002?ooooo`007?ooool00ol0003ooooooooo
o`2booooo`;o00000_ooool6o`0008gooooo000Looooo`03o`000?oooooooooo0;3ooooo0_l00004
ooooo`;o000000?oooooo`000?l000000_l0002<ooooo`007?ooool00ol0003oooooooooo`2`oooo
o`Co00000_ooool2o`0000;ooooo1?l0002;ooooo`007?ooool00ol0003oooooooooo`2`ooooo`Co
00000_ooool2o`000003ooooool0003o000000Go0000ROooool001cooooo00?o0000ooooooooool0
/?ooool2o`000003ooooool0003o000000Cooooo1?l000000ooooooo0000o`000002o`0008Oooooo
000Looooo`03o`000?oooooooooo0;7ooooo1?l00004ooooo`Co00000oooool2o`0008Oooooo000L
ooooo`03o`000?oooooooooo0;7ooooo1?l00004ooooo`;o00001Oooool2o`000003ooooool0003o
000008Cooooo000Looooo`03o`000?oooooooooo0;Cooooo0ol00009ooooo`;o000000?oooooo`00
0?l00000Q?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006
ooooo`03o`000?oooooooooo0;Cooooo0ol0000<ooooo`;o000000?oooooo`000?l00000POooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A006ooooo`03o`000?oooooooooo0;Gooooo1?l0000:ooooo`Oo0000Ooooool00003ooooool@
413ooooo00;ooooo00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oo
oooooooo0;Cooooo1Ol00003ooooo`;o00001oooool2o`000003ooooool0003o000007oooooo0000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3
o`000;Cooooo0_l00006ooooo`;o00002oooool4o`0007cooooo00000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`2doooo
o`;o00004oooool4o`0007cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2dooooo`;o000000?oooooo`000?l0
00004?ooool2o`0007kooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj
^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0;Oooooo0_l0000@ooooo`;o0000O_ooool0
0006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo
00?o0000ooooooooool0^_ooool2o`0000[ooooo0_l00021ooooo`007?ooool00ol0003ooooooooo
o`2eooooo`?o00000_ooool2o`0000Gooooo0_l00003ooooo`;o00002_ooool2o`0007Gooooo000L
ooooo`03o`000?oooooooooo0;Gooooo1?l00008ooooo`?o00002Oooool2o`0000?ooooo0_l0001e
ooooo`007?ooool00ol0003oooooooooo`2gooooo`Co00001oooool2o`000005ooooool0003o0000
o`000?ooool01_l00002ooooo`;o0000M_ooool001cooooo00?o0000ooooooooool0]_ooool2o`00
0003ooooool0003o000000Sooooo1Ol000000ooooooo0000o`000002o`0000Cooooo0_l0001foooo
o`007?ooool00ol0003oooooooooo`2fooooo`;o000000?oooooo`000?l000001?ooool2o`0000;o
oooo0ol0000?ooooo`?o0000LOooool001cooooo00?o0000ooooooooool0__ooool3o`000003oooo
ool0003o000000;o00002Oooool2o`0000Cooooo0ol0001aooooo`007?ooool00ol0003ooooooooo
o`2kooooo`;o000000?oooooo`000?l000000_ooool2o`0000_ooooo0_l00005ooooo`?o0000L?oo
ool001cooooo00?o0000ooooooooool0^oooool2o`000003ooooool0003o000000Kooooo0_l00002
ooooo`;o00001?ooool9o`00073ooooo000Looooo`03o`000?oooooooooo0;[ooooo0_l0000:oooo
o`Ko00001?ooool6o`000003ooooool0003o0000073ooooo000Looooo`03o`000?oooooooooo0;[o
oooo0_l0000:ooooo`Co00001_ooool2o`0007Oooooo000Looooo`03o`000?oooooooooo0<3ooooo
0_l0000Gooooo`;o0000K_ooool001cooooo0_l00031ooooo`;o00005oooool2o`0006kooooo000L
ooooo`03o`000?oooooooooo0;Wooooo0_l000000ooooooo0000o`00000Cooooo`Co0000M?ooool0
01cooooo00?o0000ooooooooool0^Oooool2o`000004ooooool0003o0000o`0000Kooooo0_l00003
ooooo`;o00001Oooool7o`00077ooooo000Looooo`03o`000?oooooooooo0;Sooooo0ol00002oooo
o`;o00001_ooool2o`0000?ooooo1?l00003ooooo`;o000000?oooooo`000?l000000ol00002oooo
o`;o0000K?ooool001cooooo00?o0000ooooooooool0^?ooool3o`0000Sooooo0_l00005ooooo`Co
00000oooool9o`000003ooooool0003o000006cooooo000Looooo`03o`000?oooooooooo08kooooo
0_l0000Yooooo`;o00002?ooool2o`0000Cooooo0_l00007ooooo`Co000000Coooooo`000?l0003o
0000Koooool001cooooo00?o0000ooooooooool0S?ooool6o`0003Oooooo0_l000000ooooooo0000
o`000002ooooo`Go00000_ooool4o`000003ooooool0003o000006_ooooo000Looooo`03o`000?oo
oooooooo08Wooooo0_l000000ooooooo0000o`000004o`0002Kooooo0_l0000:ooooo`;o00001_oo
ool2o`0000;ooooo1Ol00004ooooo`;o000000?oooooo`000?l00000Joooool001cooooo00?o0000
ooooooooool0ROooool2o`0000?ooooo1?l00004ooooo`;o00008?ooool2o`0000Wooooo0ol00002
ooooo`Go00003?ooool2o`000003ooooool0003o000000;o0000JOooool001cooooo00?o0000oooo
ooooool0O_ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000000_ooool2
o`0000Kooooo1_l0000Zooooo`[o00000_ooool2o`0000Wooooo0_l000001?oooooo0000o`000?l0
001Yooooo`007?ooool00ol0003oooooooooo`1mooooo`go000000?oooooo`000?l000001_ooool7
o`0002?ooooo0_l00004ooooo`So00000oooool7o`0000Gooooo0_l0001]ooooo`007?ooool00ol0
003oooooooooo`1mooooo`[o000000?oooooo`000?l000001oooool2o`0000;ooooo1_l00002oooo
o`;o00007_ooool2o`0000?ooooo0ol00003ooooo`;o00000oooool:o`0000?ooooo0_l0001]oooo
o`007?ooool00ol0003oooooooooo`1mooooo`Go00000oooool2o`0000[ooooo0_l00004ooooo`Go
000000Coooooo`000?l0003o00008_ooool2o`0000Sooooo3?l00002ooooo`;o00000_ooool2o`00
06Wooooo000Looooo`03o`000?oooooooooo07oooooo1Ol000000ooooooo0000o`000004ooooo`;o
00002oooool8o`0002[ooooo3_l00006ooooo`;o0000JOooool001cooooo00?o0000ooooooooool0
Ooooool5o`0000Oooooo1?l0000;ooooo`Go0000:oooool?o`0000?ooooo0_l0001[ooooo`007?oo
ool00ol0003oooooooooo`20ooooo`Co00002Oooool2o`0000Wooooo2_l0000Hooooo`;o00003ooo
oolCo`0006_ooooo000Looooo`;o0000Poooool2o`000003ooooool0003o0000017ooooo1?l00002
ooooo`Co000000?oooooo`000?l000005Oooool4o`0000Kooooo0_l00002ooooo`;o000000?ooooo
o`000?l000003ol0001]ooooo`007?ooool00ol0003oooooooooo`1Sooooo`;o00000_ooool2o`00
01_ooooo0ol0000Booooo`;o00000oooool7o`0001Kooooo1?l00005ooooo`?o000000?oooooo`00
0?l000004_l000000ooooooo0000o`00001Zooooo`007?ooool00ol0003oooooooooo`1Sooooo`Ko
00001?ooool2o`0001Gooooo0_l00005ooooo`;o00001_ooool2o`0000Cooooo0_l00004ooooo`Ko
00004Oooool2o`0000?ooooo1?l00005oooooaGo00001?ooool2o`0006[ooooo000Looooo`03o`00
0?oooooooooo05kooooo0_l00003ooooo`Ko00000oooool4o`0001Kooooo0_l00003ooooo`?o0000
0oooool4o`0000Cooooo0_l00005ooooo`Oo00003oooool3o`0000_ooooo0_l000000ooooooo0000
o`00000@o`00073ooooo000Looooo`03o`000?oooooooooo05kooooo0_l00002ooooo`Co000000?o
ooooo`000?l000001ol0000Fooooo`;o00001?ooool2o`0000?ooooo0_l00002ooooo`;o00002Ooo
ool7o`00013ooooo0_l00002ooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0
003o0000017o000000?oooooo`000?l00000K?ooool001cooooo00?o0000ooooooooool0H_oooolC
o`0001Cooooo0_l00007ooooo`;o000000?oooooo`000?l000001oooool2o`0000?ooooo0ol0000A
ooooo`;o00000_ooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`00000A
o`000003ooooool0003o000006cooooo000Looooo`03o`000?oooooooooo06;ooooo0_l000000ooo
oooo0000o`00000>o`0001Cooooo0_l000000ooooooo0000o`000004ooooo`Co00002?ooool2o`00
00Cooooo0ol0000Booooo`;o00000oooool2o`0000?ooooo0ol000000ooooooo0000o`00000Eo`00
06_ooooo000Looooo`03o`000?oooooooooo06;ooooo0_l00002ooooo`co000000Coooooo`000?l0
003o00005_ooool3o`0000?ooooo1?l0000>ooooo`Go00003?ooool2o`0000;ooooo0_l00002oooo
o`?o00000oooool2o`0000;ooooo5ol0001[ooooo`007?ooool00ol0003oooooooooo`1SoooooaCo
00005_ooool5o`0000[ooooo0_l00006ooooo`Go00003?ooool2o`0000;ooooo0_l00002ooooo`;o
00002?oooolAo`000003ooooool0003o000000;o0000K?ooool001cooooo00?o0000ooooooooool0
Foooool2o`0000Kooooo0ol00003oooooa7o00005Oooool3o`0000Oooooo1ol00002ooooo`;o0000
00?oooooo`000?l000000_l0000;ooooo`;o00002Oooool2o`0000Gooooo4Ol000000ooooooo0000
o`000003o`0006cooooo000Looooo`03o`000?oooooooooo05Wooooo1?l00003ooooo`Co00001_oo
oolAo`0001Wooooo0_l000000ooooooo0000o`000007o`0000;ooooo0_l000000ooooooo0000o`00
0002o`0000_ooooo0_l000000ooooooo0000o`000004ooooo`Co00001OoooolEo`0006kooooo000L
ooooo`03o`000?oooooooooo05Wooooo0_l00005ooooo`Co00002?ooool?o`0001Wooooo0_l00000
0ooooooo0000o`000003ooooo`;o00001oooool4o`0000kooooo1?l00002ooooo`;o00001oooool<
o`000003ooooool0003o000000Go0000Koooool001cooooo00?o0000ooooooooool0F?ooool2o`00
01Cooooo3ol0000Fooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00002?ooool4o`00
00oooooo0_l00003ooooo`;o00001?oooolFo`0006oooooo000Looooo`03o`000?oooooooooo05So
oooo0_l0000Gooooo`go00005Oooool2o`000003ooooool0003o000000;o00003?ooool4o`0001Co
oooo0ol00003oooooaGo0000L?ooool001cooooo00?o0000ooooooooool0F?ooool3o`0000Cooooo
0_l0000Booooo`_o00005_ooool2o`000004ooooool0003o0000o`0000cooooo0_l0000Fooooo`?o
00001OoooolCo`00073ooooo000Looooo`03o`000?oooooooooo05Sooooo0ol00004ooooo`Co0000
3Oooool2o`0000;ooooo3?l0000Dooooo`;o000000Coooooo`000?l0003o00002oooool4o`0001;o
oooo0_l0000:ooooo`?o000000?oooooo`000?l000002_l0001booooo`007?ooool2o`0005[ooooo
0_l00004ooooo`Co00000oooool2o`0000Sooooo0_l00004ooooo`_o00005Oooool6o`0000Wooooo
1?l0000=ooooo`;o00000oooool3o`0000kooooo2ol0001booooo`007?ooool00ol0003ooooooooo
o`1Tooooo`So00000_ooool2o`000003ooooool0003o000000?o000000Coooooo`000?l0003ooooo
2?l0000Dooooo`;o00000_ooool2o`0000Wooooo0ol0000>ooooo`;o00001?ooool2o`0000[ooooo
0ol00005ooooo`Co0000MOooool001cooooo00?o0000ooooooooool0GOooool2o`0000Gooooo0_l0
00000ooooooo0000o`00000@o`000003ooooool0003o000000Ko00004oooool5o`000003ooooool0
003o000000Oooooo1?l0000Gooooo`;o00001oooool3o`0000?ooooo0_l0001iooooo`007?ooool0
0ol0003oooooooooo`1Mooooo`;o000000Coooooo`000?l0003o00001oooool8o`000003ooooool0
003o000000Oo000000?oooooo`000?l000001Ol0000Aooooo`;o000000Coooooo`000?l0003ooooo
0_l00003ooooo`;o00000_ooool3o`0000Wooooo1_l00007ooooo`Co00001oooool2o`0000Cooooo
0_l0001iooooo`007?ooool00ol0003oooooooooo`1Pooooo`?o00001oooool;o`0000;ooooo3ol0
000Aooooo`;o00001_ooool3o`0000;ooooo1?l00008ooooo`Ko000000Coooooo`000?l0003o0000
0_ooool3o`0000Cooooo0_l00004ooooo`;o00000_ooool2o`0007[ooooo000Looooo`03o`000?oo
oooooooo06Gooooo0ol00004ooooo`?o000000?oooooo`000?l000000ol00005ooooo`co00004Ooo
ool2o`0000Kooooo0_l00003ooooo`Co00002?ooool2o`0000Gooooo0ol00002ooooo`Co00000ooo
ool2o`0000Cooooo0_l00002ooooo`;o0000N_ooool001cooooo00?o0000ooooooooool0HOooool3
o`000005ooooool0003o0000o`000?ooool01_l00002ooooo`Co00000_ooool:o`000003ooooool0
003o000000;o00004oooool2o`0000Oooooo1Ol0000Gooooo`;o00001oooool2o`000003ooooool0
003o000007gooooo000Looooo`03o`000?oooooooooo067ooooo0ol00005ooooo`Ko00000_ooool4
o`000003ooooool0003o000001?o00003_ooool2o`0000?ooooo2Ol0000=ooooo`?o00000oooool2
o`0000_ooooo0_l000000ooooooo0000o`00001mooooo`007?ooool00ol0003oooooooooo`1Xoooo
o`Ko00001?ooool3o`000003ooooool0003o000001Co00004_ooool8o`0000kooooo0ol00003oooo
o`;o0000SOooool001cooooo00?o0000ooooooooool0J?ooool5o`0000Wooooo5ol0000>ooooo`;o
00001?ooool5o`0002Cooooo0_l0001mooooo`007?ooool00ol0003oooooooooo`1Yooooo`?o0000
2_oooolIo`0000Oooooo0_l00003ooooo`;o00001Oooool3o`0002Gooooo0_l0001mooooo`007?oo
ool00ol0003oooooooooo`1Xooooo`Co00002_oooolDo`0000;ooooo1?l00006ooooo`?o00002Ooo
ool3o`0001Wooooo0_l0000:ooooo`;o0000OOooool001cooooo00?o0000ooooooooool0Hoooool2
o`0000?ooooo0_l0000=oooooaCo000000?oooooo`000?l000000ol00006ooooo`;o00002?ooool2
o`0000Oooooo0_l000000ooooooo0000o`000008ooooo`;o00001Oooool2o`0000Cooooo0_l00003
ooooo`;o0000O_ooool001cooooo00?o0000ooooooooool0Hoooool2o`0000?ooooo0_l0000;oooo
oaKo000000?oooooo`000?l000000ol00004ooooo`;o00001?ooool2o`0000Cooooo0ol00006oooo
o`Go00002?ooool2o`0000_ooooo0_l00003ooooo`;o0000O_ooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooo
oooo06Oooooo0ol0000;oooooaOo00000_ooool3o`0000;ooooo1?l00004ooooo`;o00000oooool4
o`0000Gooooo1?l00006ooooo`;o00001oooool4o`0000Cooooo0_l00006ooooo`;o0000Noooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1Rooooo`?o00000_ooool3o`0000gooooo5Ol00007ooooo`;o00002ooo
ool2o`0000Gooooo1_l00006ooooo`;o00001oooool;o`0000Cooooo0ol0001kooooo`0000?ooooo
oa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`Go00001_ooool00ol0003oooooooooo`1R
ooooo`?o000000?oooooo`000?l000000_l0000=oooooaOo00003?ooool2o`0000;ooooo0ol00006
ooooo`;o00000_ooool3o`00013ooooo2Ol00004ooooo`;o0000O?ooool00003ooooool0003ooooo
00;ooooo00?o0000ooooooooool02Oooool01?m4A4CogMgMooooool00007ooooo`?o0000IOooool4
o`0000kooooo6?l0000;ooooo`;o00000_ooool3o`0000_ooooo1?l0000=ooooo`go00002?ooool2
o`0007Gooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEE
EOoooooo00001oooool00ol0003oooooooooo`1Uooooo`Go00003OoooolHo`0000Gooooo0_l00006
ooooo`;o000000?oooooo`000?l000003Oooool3o`0000;ooooo0_l00004ooooo`;o00000_ooool>
o`0000Oooooo0_l0001eooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:oooo
o`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0J?ooool2o`0000kooooo6?l00004oooo
o`;o00000oooool2o`000003ooooool0003o000000;o00003oooool2o`0000;ooooo1?l00002oooo
o`;o000000Coooooo`000?l0003ooooo3_l0001looooo`0000KoooooogMgMonHV9SooooooiRHV?mg
MgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0N?oooolHo`0000Wooooo0_l0
00000ooooooo0000o`000002o`0000_ooooo0_l00008ooooo`;o00001Oooool2o`000003ooooool0
003o000000co000000?oooooo`000?l000001Oooool2o`0007;ooooo00001_ooooook^k^oc8b<_l0
003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`1Uooooo`;o0000
4OoooolHo`0000cooooo1?l0000;ooooo`;o00001?ooool2o`0000Sooooo1?l000000ooooooo0000
o`00000>o`0000;ooooo0_l000000ooooooo0000o`00001booooo`007?ooool00ol0003ooooooooo
o`1Booooo`;o00004Oooool2o`00017ooooo6Ol0000:ooooo`Co00003_ooool2o`0000;ooooo0_l0
0007oooooaCo00000oooool3o`0007Gooooo000Looooo`03o`000?oooooooooo04oooooo0_l00000
0ooooooo0000o`000002o`0000oooooo0_l0000BoooooaWo00002Oooool2o`00013ooooo1?l00006
ooooo`;o000000?oooooo`000?l000001_l000000ooooooo0000o`00000;o`000003ooooool0003o
000007Kooooo000Looooo`03o`000?oooooooooo04oooooo0_l000000ooooooo0000o`000005o`00
0003ooooool0003o000000?ooooo0_l0000Hoooooa[o00001oooool3o`0001;ooooo0_l00006oooo
o`;o000000?oooooo`000?l000005?l000000ooooooo0000o`000002ooooo`;o0000L_ooool001co
oooo00?o0000ooooooooool0C?oooolAo`0000;ooooo0ol0000HoooooaWo00001oooool3o`0000;o
oooo0_l0000IoooooaGo00000_ooool2o`0000;ooooo0_l0001booooo`007?ooool00ol0003ooooo
ooooo`1<oooooa;o000000Coooooo`000?l0003o00000oooool2o`0001?ooooo0_l000000ooooooo
0000o`00000Fo`0000[ooooo1?l0000HoooooaSo00001?ooool2o`00073ooooo000Looooo`03o`00
0?oooooooooo04gooooo4Ol000000ooooooo0000o`000002ooooo`Co00004ooooolKo`0000?ooooo
0_l00007ooooo`;o00000_ooool2o`00013ooooo0_l00003oooooaGo00000oooool2o`000003oooo
ool0003o0000073ooooo000Looooo`03o`000?oooooooooo04Sooooo0_l00003oooooa7o00001Ooo
ool4o`0001Cooooo6Ol00003ooooo`?o00002oooool2o`00013ooooo0_l00003oooooaGo00000ooo
ool2o`0007?ooooo000Looooo`03o`000?oooooooooo04Sooooo6?l000000ooooooo0000o`000002
ooooo`;o00005_oooolDo`000004ooooool0003o0000ooooo`Co00005?ooool2o`0000oooooo6ol0
001`ooooo`007?ooool00ol0003oooooooooo`19oooooaOo000000?oooooo`000?l000006ooooolB
o`0000?ooooo1?l0000>ooooo`;o00001?ooool4o`00013ooooo6_l0001`ooooo`007?ooool00ol0
003oooooooooo`1;oooooaCo00001_ooool2o`0001Wooooo3?l00002ooooo`?o000000Coooooo`00
0?l0003o00001_ooool2o`0000Kooooo1?l00004ooooo`?o00001?ooool2o`0000_ooooo4ol00000
0ooooooo0000o`00001dooooo`007?ooool00ol0003oooooooooo`18ooooo`;o000000?oooooo`00
0?l000003ol000000ooooooo0000o`000002o`0000Cooooo0_l0000Jooooo`So00001Oooool6o`00
00Oooooo0_l00006ooooo`;o00003Oooool2o`0000[ooooo3?l000000ooooooo0000o`000004o`00
0005ooooool0003o0000o`000?ooool00_l0001aooooo`007?ooool2o`0004Wooooo0_l000000ooo
oooo0000o`00000?o`0000;ooooo0ol00004ooooo`?o00006_ooool8o`0000;ooooo0_l000000ooo
oooo0000o`000002o`0002_ooooo5_l00002ooooo`;o0000LOooool001cooooo00?o0000oooooooo
ool0AooooolDo`0000_ooooo0_l0000Looooo`[o000000?oooooo`000?l000001Oooool2o`00013o
oooo0_l00008ooooo`;o00002_oooolDo`0000Cooooo0_l0001aooooo`007?ooool00ol0003ooooo
ooooo`17oooooa;o00003?ooool3o`0002;ooooo0_l0000:ooooo`;o00004?ooool2o`0000Kooooo
1_l00009ooooo`?o000000?oooooo`000?l000003Ol00003ooooo`;o0000L_ooool001cooooo00?o
0000ooooooooool0A_ooool2o`000004ooooool0003o0000ooooo`co00003Oooool5o`0002cooooo
0_l0000:ooooo`;o00003?ooool3o`000003ooooool0003o000000Wooooo0_l00002ooooo`So0000
0oooool4o`0000;ooooo0ol0001booooo`007?ooool00ol0003oooooooooo`15ooooo`Go00000_oo
ool=o`0000kooooo1?l0000Dooooo`Co00007oooool2o`0000gooooo0_l0000>ooooo`;o000000?o
ooooo`000?l000001ol000000ooooooo0000o`000006o`0003Oooooo0_l000000ooooooo0000o`00
000gooooo`007?ooool00ol0003oooooooooo`15ooooo`Go00001?ooool;o`0000Gooooo0_l00009
ooooo`Co00004_ooool8o`0000Cooooo0_l00003ooooo`;o00002Oooool2o`0001kooooo0_l00004
ooooo`;o000000?oooooo`000?l000001ol00003ooooo`Ko0000<oooool2o`0000;ooooo0_l00000
0ooooooo0000o`00000gooooo`007?ooool00ol0003oooooooooo`15ooooo`Co00001Oooool5o`00
00_ooooo0_l000000ooooooo0000o`000008ooooo`?o00003oooool2o`0000Cooooo1?l00004oooo
o`;o00000oooool2o`0000Gooooo0_l00002ooooo`;o00006Oooool2o`0000?ooooo0_l00008oooo
o`So00001Oooool3o`0003Cooooo0_l00003ooooo`;o0000>Oooool001cooooo00?o0000oooooooo
ool0AOooool4o`0000Gooooo0_l0000Aooooo`;o00002Oooool2o`000003ooooool0003o000000co
oooo0_l00002ooooo`;o00005?ooool2o`0000?ooooo0ol0000Gooooo`?o00003?ooool2o`0000Co
oooo0_l00003ooooo`Co0000=_ooool2o`0000;ooooo0_l0000iooooo`007?ooool00ol0003ooooo
ooooo`15ooooo`;o00003Oooool2o`0001Kooooo1_l0000?ooooo`?o00006?ooool3o`0001Oooooo
1Ol0000:ooooo`?o000000?oooooo`000?l000000_l00003ooooo`;o0000=Oooool2o`000003oooo
ool0003o000000Gooooo0_l0000fooooo`007?ooool00ol0003oooooooooo`17ooooo`;o00002ooo
ool2o`0000Oooooo0_l0000?ooooo`Go00003oooool2o`0000[ooooo0_l00007ooooo`;o000000?o
ooooo`000?l000003Oooool2o`0000_ooooo0_l000000ooooooo0000o`000005ooooo`;o00001?oo
ool2o`000003ooooool0003o000003cooooo0_l00008ooooo`;o0000=_ooool001cooooo00?o0000
ooooooooool0Aoooool2o`00017ooooo1Ol0000Aooooo`Co00002Oooool2o`0000cooooo0_l00000
0ooooooo0000o`000007ooooo`;o000000?oooooo`000?l000003Oooool4o`0000Gooooo0_l0000<
ooooo`;o0000AOooool2o`00043ooooo000Looooo`03o`000?oooooooooo04Gooooo1?l00005oooo
o`;o00002_ooool4o`0000Wooooo0_l00008ooooo`Go00000oooool2o`0000;ooooo0ol00009oooo
o`Co00007_ooool2o`0000Gooooo0_l0000<ooooo`;o0000Qoooool001cooooo00?o0000oooooooo
ool0AOooool2o`0000?ooooo0_l00002ooooo`;o00002_ooool2o`0000_ooooo0_l00002ooooo`?o
00001Oooool5o`000003ooooool0003o000000?ooooo0_l00009ooooo`;o0000<_ooool2o`000003
ooooool0003o000000;ooooo0_l00014ooooo`;o00000oooool3o`0003Oooooo000Looooo`03o`00
0?oooooooooo04Sooooo1Ol0000=ooooo`;o00002_ooool2o`0000?ooooo0ol00006ooooo`Oo0000
1_ooool3o`000003ooooool0003o000002;ooooo0_l0000Booooo`Go00000_ooool4o`0004;ooooo
0_l00003ooooo`?o0000=oooool001cooooo00?o0000ooooooooool0B?ooool8o`0000;ooooo0_l0
000Booooo`;o00002_ooool2o`000003ooooool0003o000000Go00001Oooool3o`000003ooooool0
003o000000kooooo0_l0000Booooo`;o00005?ooool4o`000003ooooool0003o000000;o0000B?oo
ool2o`0003Oooooo000Looooo`03o`000?oooooooooo04cooooo2?l0000Iooooo`;o00000oooool2
o`0000Kooooo0_l0000Iooooo`Co0000:?ooool2o`000003ooooool0003o000004Wooooo1?l0000f
ooooo`007?ooool2o`0004oooooo1ol0000:ooooo`;o00001?ooool2o`0000Kooooo0_l00004oooo
o`;o00005_ooool2o`000003ooooool0003o000000Oooooo0_l0000Rooooo`Co00000_ooool2o`00
04Oooooo0_l00003ooooo`Co0000=_ooool001cooooo00?o0000ooooooooool0D?ooool7o`0000So
oooo0_l00002ooooo`Co00003?ooool2o`0000Cooooo0_l000000ooooooo0000o`00000=ooooo`;o
000000?oooooo`000?l000000oooool2o`0002Kooooo1?l000001?oooooo0000o`000?l0000noooo
o`;o00001oooool3o`0000Cooooo0_l0000fooooo`007?ooool00ol0003oooooooooo`1Dooooo`Wo
00001_ooool2o`0000Gooooo0_l0000=ooooo`;o000000?oooooo`000?l000001oooool2o`0000co
oooo0_l0000Nooooo`;o00002oooool4o`0001?ooooo0_l0000Kooooo`?o00002Oooool3o`0000So
oooo0_l00003ooooo`;o0000=oooool001cooooo00?o0000ooooooooool0E_ooool8o`000003oooo
ool0003o000000Wooooo0_l0000=ooooo`;o00002?ooool4o`0000;ooooo0_l0000Xooooo`;o0000
2_ooool2o`000003ooooool0003o000001?ooooo0_l00002ooooo`;o00004oooool2o`0000;ooooo
0ol00009ooooo`;o00003_ooool2o`0003Oooooo000Looooo`03o`000?oooooooooo05[ooooo2?l0
00000ooooooo0000o`00000Nooooo`;o00001?ooool2o`0001gooooo0_l00005ooooo`;o00003_oo
ool2o`0001;ooooo0ol00005ooooo`;o00001Oooool2o`0000cooooo0_l00002ooooo`;o00002ooo
ool2o`000004ooooool0003o0000ooooo`;o00001_ooool2o`0003Sooooo000Looooo`03o`000?oo
oooooooo05[ooooo2?l000000ooooooo0000o`00000Jooooo`?o00000_ooool2o`00027ooooo0ol0
0005ooooo`;o00008_ooool5o`000003ooooool0003o000000Oooooo0_l00002ooooo`;o000000?o
ooooo`000?l000004_ooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool3o`000003oooo
ool0003o000000Co0000>?ooool001cooooo00?o0000ooooooooool0F_ooool:o`0000Cooooo0_l0
00000ooooooo0000o`00000<ooooo`;o00000_ooool5o`0000;ooooo0_l0000@ooooo`;o00003ooo
ool2o`0000cooooo0_l000000ooooooo0000o`00000@ooooo`;o00002_ooool2o`000003ooooool0
003o000000;o00001_ooool2o`000004ooooool0003o0000ooooo`?o00004Oooool3o`0000Sooooo
0_l000000ooooooo0000o`000004o`0003Sooooo000Looooo`03o`000?oooooooooo05cooooo2Ol0
0003ooooo`;o000000?oooooo`000?l000003?ooool2o`0000;ooooo0_l00002ooooo`;o00000_oo
ool2o`0000oooooo0_l0000Mooooo`;o000000?oooooo`000?l000004?ooool2o`0000oooooo1?l0
0003ooooo`?o00000oooool5o`00013ooooo0ol00008ooooo`;o0000?oooool001cooooo00?o0000
ooooooooool0G?ooool3o`000003ooooool0003o000000Oo00001oooool2o`0000Gooooo0_l00008
ooooo`;o000000Coooooo`000?l0003o0000B_ooool2o`0000[ooooo0_l00003ooooo`?o00000ooo
ool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o00001_ooool3o`0004Wooooo000L
ooooo`03o`000?oooooooooo05cooooo0ol00002ooooo`[o000000?oooooo`000?l000000_ooool2
o`0000Gooooo0_l0000;ooooo`;o00001oooool2o`0000Oooooo0_l0000Booooo`;o000000?ooooo
o`000?l000003Oooool2o`0001?ooooo0_l00005ooooo`;o00002Oooool2o`0000Cooooo0_l00004
ooooo`;o00001?ooool2o`0000Cooooo0_l000000ooooooo0000o`00000<ooooo`?o0000>_ooool0
01cooooo00?o0000ooooooooool0GOooool2o`0000Gooooo1ol000000ooooooo0000o`00000Foooo
o`;o00001oooool2o`0000Oooooo0_l0000Booooo`;o000000?oooooo`000?l000003Oooool2o`00
01[ooooo0_l00002ooooo`;o00002oooool2o`00013ooooo1Ol0000<ooooo`?o0000>_ooool001co
oooo00?o0000ooooooooool0Hoooool8o`0000_ooooo0_l00003ooooo`;o00001?ooool2o`0000;o
oooo0_l0000:ooooo`;o00009_ooool2o`0000;ooooo0_l00009ooooo`;o00000oooool4o`0000;o
oooo0_l00005ooooo`Co00001oooool2o`0000Kooooo1?l0000;ooooo`;o000000?oooooo`000?l0
00000_l00016ooooo`007?ooool00ol0003oooooooooo`1Sooooo`Co000000?oooooo`000?l00000
0ol00009ooooo`;o00000oooool2o`0000Cooooo0_l00002ooooo`Co00002?ooool2o`0001_ooooo
0_l00003ooooo`;o00000_ooool5o`000003ooooool0003o000000Wooooo0_l00003ooooo`Co0000
0_ooool2o`0000Gooooo0_l00007ooooo`Ko00001?ooool4o`0000Gooooo0_l00004ooooo`Oo0000
1oooool2o`0003gooooo000Looooo`03o`000?oooooooooo06Gooooo0_l000000ooooooo0000o`00
0003o`0000Kooooo0_l00003ooooo`;o00001oooool2o`0000Cooooo0_l0000Uooooo`;o00000ooo
ool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000kooooo0ol000000ooooooo0000
o`00000<ooooo`;o00000_ooool2o`0000;ooooo0_l0000=ooooo`?o00001?ooool4o`0000Wooooo
0ol0000looooo`007?ooool00ol0003oooooooooo`1Xooooo`So00000oooool2o`0000?ooooo0_l0
0007ooooo`;o0000;?ooool2o`0000[ooooo0_l0000Aooooo`;o000000?oooooo`000?l000003?oo
ool2o`0000Oooooo0_l00004ooooo`Co000000Coooooo`000?l0003ooooo0ol00006ooooo`;o0000
0oooool3o`000003ooooool0003o000000?o0000??ooool001cooooo00?o0000ooooooooool0JOoo
ool7o`0000?ooooo0_l0000<ooooo`;o0000;?ooool2o`0000Wooooo0ol00003ooooo`;o00004_oo
ool4o`0000Cooooo0_l00005ooooo`?o00000_ooool2o`0000Cooooo1?l000001?oooooo0000o`00
0?ooool2o`0000Oooooo0_l000000ooooooo0000o`000003o`000004ooooool0003o0000ooooo`;o
0000??ooool001cooooo0_l0001Xooooo`Wo00000oooool2o`0000;ooooo0_l00011ooooo`?o0000
0oooool2o`0000Wooooo0_l000000ooooooo0000o`00000:o`0000;ooooo0_l00005ooooo`Co0000
5_ooool4o`000003ooooool0003o000000;ooooo0_l00003ooooo`;o0000??ooool001cooooo00?o
0000ooooooooool0Ioooool2o`0000?ooooo2?l00003ooooo`;o00008?ooool2o`0000Cooooo0_l0
000Fooooo`;o00000_ooool3o`0000gooooo4_l00006ooooo`Co00005Oooool5o`0000Gooooo0_l0
0011ooooo`007?ooool00ol0003oooooooooo`1/ooooo`So00002?ooool2o`0000Oooooo0_l0000B
ooooo`;o00001?ooool2o`0001Cooooo1?l00003ooooo`Co00001ooooolFo`0000Kooooo0ol00002
ooooo`;o00001?ooool2o`0000Kooooo0_l00004ooooo`;o00000oooool4o`0004Cooooo000Loooo
o`03o`000?oooooooooo06cooooo2_l00006ooooo`;o00000oooool2o`0000;ooooo0_l0000Joooo
o`;o00004_ooool2o`0000Gooooo1?l00004ooooo`;o000000?oooooo`000?l000005ol00003oooo
o`?o00000_ooool2o`0000Cooooo1_l00002ooooo`;o00000_ooool4o`0000?ooooo1Ol00002oooo
o`;o0000?oooool001cooooo00?o0000ooooooooool0K?ooool:o`0000_ooooo0_l0000Nooooo`;o
00008Oooool2o`0000;ooooo6?l0000@ooooo`Co00000_ooool8o`000003ooooool0003o000000;o
000000?oooooo`000?l000000_ooool2o`0003oooooo000Looooo`03o`000?oooooooooo06kooooo
2_l0000?ooooo`;o00005Oooool2o`0000?ooooo0_l00006ooooo`;o00004?ooool2o`0000Wooooo
5_l00002ooooo`?o00004oooool4o`000004ooooool0003o0000ooooo`?o00001_ooool2o`00043o
oooo000Looooo`03o`000?oooooooooo06oooooo2Ol000001?oooooo0000o`000?l0000;ooooo`;o
00005Oooool2o`0000?ooooo0_l00006ooooo`;o00003Oooool2o`000003ooooool0003o000000Oo
oooo7Ol0000Cooooo`;o00001_ooool4o`0000Gooooo0_l00010ooooo`007?ooool00ol0003ooooo
ooooo`1_ooooo`Wo000000Coooooo`000?l0003o00001oooool2o`0001Sooooo0_l0000Dooooo`;o
00001Oooool2o`0000[ooooo7ol0000Aooooo`;o00002?ooool2o`0000?ooooo1?l00010ooooo`00
7?ooool00ol0003oooooooooo`1cooooo`Oo00000_ooool2o`0000Gooooo0_l0000Hooooo`;o0000
5?ooool4o`0000Wooooo0_l00004oooooa7o000000?oooooo`000?l000002ol0000Aooooo`Co0000
1oooool2o`000004ooooool0003o0000o`0004;ooooo000Looooo`03o`000?oooooooooo07?ooooo
1ol000001?oooooo0000o`000?l0000gooooo`;o00000oooool2o`0000?ooooo0ol00004ooooob;o
00001?ooool7o`0000?ooooo1_l00005ooooo`Go0000@oooool001cooooo00?o0000ooooooooool0
MOooool5o`000003ooooool0003o000003gooooo0_l00003ooooo`;o00001_ooool/o`0000?ooooo
1_l00005ooooo`Go0000@oooool001cooooo00?o0000ooooooooool0M?ooool4o`000003ooooool0
003o000002gooooo0_l00004ooooo`;o00002oooool2o`0000Gooooo0_l000001?oooooo0000o`00
0?ooool[o`0000Cooooo0_l00002ooooo`;o00000oooool5o`0004Cooooo000Looooo`03o`000?oo
oooooooo07Cooooo2?l00006ooooo`;o00007oooool2o`0000?ooooo0_l00004ooooo`;o00002ooo
ool2o`000005ooooool0003o0000o`000?ooool00_l000000ooooooo0000o`000002ooooob[o0000
00Coooooo`000?l0003ooooo1_l000000ooooooo0000o`000002o`0004Oooooo000Looooo`03o`00
0?oooooooooo07Gooooo1ol00006ooooo`;o00002Oooool2o`0000[ooooo0_l00008ooooo`;o0000
0oooool2o`0000?ooooo0_l0000?ooooo`?o00002?oooolWo`0000?ooooo3Ol00019ooooo`0000Ko
ooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
00Kooooo00?o0000ooooooooool0MOooool7o`00017ooooo0_l0000:ooooo`;o000000?oooooo`00
0?l000001Oooool2o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000003?ooool2o`00
00;ooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l00002oooooaco00000ooooolB
o`0004Sooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1cooooo`Wo00007_ooool4o`0000_ooooo
0_l00005ooooo`;o00004?ooool2o`0000;ooooo0_l00003ooooocKo0000B?ooool00003ooooool@
413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0Loooool9o`0001cooooo1?l00007ooooo`;o00001?ooool2o`0000Oooooo
0_l0000;ooooo`;o00002_ooool7o`000003ooooool0003o000001Co000000?oooooo`000?l00000
4ol0001:ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?nH
V9SooooooiRHV?lQ8B401_ooool3o`0007?ooooo2_l0000Booooo`;o00001oooool2o`000003oooo
ool0003o000000Kooooo0_l0000=ooooo`;o00002oooool2o`0000kooooo1Ol000000ooooooo0000
o`00000Uo`0004gooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go
0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo07?ooooo2_l00004ooooo`;o0000
3?ooool2o`0000Oooooo0_l000000ooooooo0000o`00000?ooooo`;o00009?ooool2o`000003oooo
ool0003o000002;o0000D?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Ooo
ool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo06oooooo3Ol00005ooooo`Co00000_oo
ool2o`000003ooooool0003o000001_ooooo0_l00003ooooo`;o00000_ooool4o`0000Gooooo0_l0
000Koooooa?o000000Coooooo`000?l0003o00000_ooool5o`0005Gooooo00001_ooooooMgMgoiRH
V?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`1_ooooo`Oo
000000?oooooo`000?l000000ol000000ooooooo0000o`000004ooooo`;o00000_ooool2o`000003
ooooool0003o000001?ooooo0_l00006ooooo`;o00001oooool4o`0000Gooooo0_l0000Oooooo`co
000000?oooooo`000?l00000H?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<
c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo06oooooo3Ol000001?oooooo0000o`000?oo
ool2o`000003ooooool0003o000001[ooooo0_l00003ooooo`;o00003?ooool2o`0002oooooo0_l0
001Tooooo`007?ooool00ol0003oooooooooo`1^ooooo`ko00001?ooool2o`0002;ooooo0_l00000
1?oooooo0000o`000?l00006ooooo`;o00002?ooool2o`0000Kooooo0_l00025ooooo`007?ooool0
0ol0003oooooooooo`1Zoooooa;o00003_ooool2o`0001;ooooo0_l00007ooooo`?o00001Oooool4
o`0000Cooooo0_l000000ooooooo0000o`000006ooooo`;o0000QOooool001cooooo00?o0000oooo
ooooool0JOoooolCo`0000kooooo0_l00008ooooo`?o00001oooool2o`0000;ooooo0_l0000;oooo
o`Co00001?ooool7o`0008_ooooo000Looooo`03o`000?oooooooooo06Oooooo5Ol0000Gooooo`Co
00002oooool2o`0000Gooooo0_l00005ooooo`Go00000oooool6o`0008_ooooo000Looooo`03o`00
0?oooooooooo06Gooooo6?l0000Fooooo`;o00005?ooool2o`0000Sooooo0_l00005ooooo`;o0000
1Oooool2o`0008Kooooo000Looooo`03o`000?oooooooooo06Gooooo6?l0000>ooooo`;o00001?oo
ool3o`0000?ooooo0_l0000Oooooo`;o00001oooool2o`0000;ooooo0_l00022ooooo`007?ooool0
0ol0003oooooooooo`1ToooooaKo00004Oooool2o`0000Cooooo0ol00003ooooo`;o00001?ooool2
o`0001Wooooo0_l0000;ooooo`;o0000P_ooool001cooooo00?o0000ooooooooool0HooooolIo`00
00Kooooo0_l00005ooooo`;o00002?ooool2o`0000Sooooo0_l00002ooooo`Co00007_ooool4o`00
08;ooooo000Looooo`03o`000?oooooooooo06?ooooo6Ol00006ooooo`;o00001Oooool2o`0000So
oooo0_l0000<ooooo`Co00004oooool5o`0000Kooooo1?l00022ooooo`007?ooool00ol0003ooooo
ooooo`1Roooooa[o00002_ooool3o`0000Cooooo0_l00004ooooo`;o00008oooool5o`0000Kooooo
1?l00022ooooo`007?ooool00ol0003oooooooooo`1RoooooaOo00003Oooool3o`0000Cooooo0_l0
0004ooooo`;o00001_ooool2o`0000;ooooo0_l0000Hooooo`;o00000_ooool4o`0000;ooooo1?l0
0022ooooo`007?ooool2o`0006;ooooo6?l000000ooooooo0000o`000002o`0000?ooooo0_l0000H
ooooo`;o00000_ooool2o`0001?ooooo0ol000000ooooooo0000o`000007o`0008Sooooo000Loooo
o`03o`000?oooooooooo067ooooo2_l000000ooooooo0000o`00000;o`000003ooooool0003o0000
00;o00000oooool2o`0000gooooo1?l00003ooooo`;o00006oooool3o`000003ooooool0003o0000
00Co00001Oooool4o`0008;ooooo000Looooo`03o`000?oooooooooo067ooooo5ol00004ooooo`;o
00004_ooool4o`0000?ooooo0_l00002ooooo`;o00006Oooool2o`000003ooooool0003o000000;o
00000_ooool2o`000003ooooool0003o000000?o0000P_ooool001cooooo00?o0000ooooooooool0
HOooool4o`000003ooooool0003o000000ko00001_ooool2o`0000;ooooo0_l00006ooooo`;o0000
1_ooool4o`0000Gooooo1?l0000Gooooo`Co00000_ooool2o`0000?ooooo2?l00022ooooo`007?oo
ool00ol0003oooooooooo`1Qoooooa?o00002?ooool2o`0000;ooooo0_l000000ooooooo0000o`00
0003ooooo`;o00000_ooool2o`0000Cooooo0_l00005ooooo`?o00005oooool9o`0000Cooooo1ol0
0022ooooo`007?ooool00ol0003oooooooooo`1OoooooaGo00003oooool2o`0000Oooooo0_l00004
ooooo`;o00000oooool2o`0001Wooooo2_l00004ooooo`;o00000oooool2o`0008;ooooo000Loooo
o`03o`000?oooooooooo05oooooo3ol000001?oooooo0000o`000?l0000=ooooo`;o00002?ooool2
o`0000Gooooo1?l00003ooooo`;o00005_ooool=o`000003ooooool0003o000000Kooooo0_l00022
ooooo`007?ooool00ol0003oooooooooo`1Noooooa3o000000?oooooo`000?l000002oooool2o`00
0003ooooool0003o000000;ooooo0_l00003ooooo`Co00000_ooool4o`0000?ooooo0_l0000Foooo
o`So000000?oooooo`000?l000001?l000001?oooooo0000o`000?ooool2o`0008Oooooo000Loooo
o`03o`000?oooooooooo05kooooo5?l000000ooooooo0000o`000007ooooo`?o00001?ooool2o`00
00?ooooo1?l00002ooooo`?o00001?ooool2o`0001Cooooo1ol000000ooooooo0000o`000007o`00
00;ooooo1Ol00026ooooo`007?ooool00ol0003oooooooooo`1Noooooa7o000000Coooooo`000?l0
003ooooo0_l00008ooooo`;o000000?oooooo`000?l000003Oooool3o`0001Wooooo4?l00003oooo
o`So0000Poooool001cooooo00?o0000ooooooooool0G_ooool3o`0000Cooooo1?l00005ooooo`;o
00001?ooool4o`0000Kooooo1?l0000>ooooo`;o00005_oooolCo`0000Gooooo0_l000000ooooooo
0000o`000002o`0008;ooooo000Looooo`03o`000?oooooooooo05kooooo1?l000000ooooooo0000
o`000004o`000005ooooool0003o0000o`000?ooool01?l00002ooooo`Co00001_ooool2o`0000go
oooo0_l0000FoooooaKo00002?ooool4o`0008;ooooo000Looooo`03o`000?oooooooooo05oooooo
2Ol00002ooooo`?o00000_ooool4o`0000_ooooo1?l000000ooooooo0000o`000008ooooo`Go0000
4ooooolFo`0000Wooooo0_l00023ooooo`007?ooool00ol0003oooooooooo`1Nooooo`So00002?oo
ool6o`0000Cooooo0_l00005ooooo`?o000000?oooooo`000?l000000_ooool2o`000004ooooool0
003o0000ooooo`Go00004_oooolFo`0008oooooo000Looooo`03o`000?oooooooooo05kooooo1?l0
00001?oooooo0000o`000?l00006ooooo`So00000oooool3o`0000Gooooo0_l00006ooooo`;o0000
00Coooooo`000?l0003ooooo0ol0000BoooooaSo0000Soooool001cooooo00?o0000ooooooooool0
G_ooool8o`0000;ooooo3?l00003ooooo`;o00005Oooool2o`0001;ooooo5_l0002Aooooo`007?oo
ool2o`00063ooooo2?l000000ooooooo0000o`000004o`000004ooooool0003o0000o`0000Oooooo
0_l0000@ooooo`;o000000?oooooo`000?l000004OoooolGo`00097ooooo000Looooo`03o`000?oo
oooooooo05oooooo0ol000000ooooooo0000o`000003o`0000?ooooo1?l000001?oooooo0000o`00
0?ooool2o`0000Cooooo1?l0000=ooooo`?o00004ooooolJo`0008oooooo000Looooo`03o`000?oo
oooooooo063ooooo0_l000000ooooooo0000o`000003o`0000Gooooo0_l000001?oooooo0000o`00
0?ooool3o`0000?ooooo1_l000000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l00000
5?oooolGo`000003ooooool0003o000000Cooooo0_l00029ooooo`007?ooool00ol0003ooooooooo
o`1Pooooo`;o00000oooool2o`0000Cooooo1?l000000ooooooo0000o`000002ooooo`;o00000ooo
ool2o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`;o00005ooooolGo`0000Oooooo0_l0
0029ooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o00000oooool2o`0000Cooooo1?l0000;
ooooo`;o00001?ooool2o`0000Oooooo0_l0000EoooooaSo00000oooool3o`0008_ooooo000Loooo
o`03o`000?oooooooooo067ooooo0ol000000ooooooo0000o`00000Cooooo`;o00000oooool2o`00
0003ooooool0003o000000Cooooo0ol0000EoooooaGo000000?oooooo`000?l000000oooool3o`00
08_ooooo000Looooo`03o`000?oooooooooo067ooooo0ol00002ooooo`?o000000?oooooo`000?l0
00003_ooool2o`000003ooooool0003o000000Go00001?ooool2o`0001Gooooo5?l00009ooooo`;o
0000Roooool001cooooo00?o0000ooooooooool0HOooool3o`000003ooooool0003o000000Go0000
0oooool2o`0000Gooooo0_l00005ooooo`Ko00000oooool3o`0001Kooooo3Ol000000ooooooo0000
o`000003o`0000[ooooo0_l0002;ooooo`007?ooool00ol0003oooooooooo`1Rooooo`;o000000?o
ooooo`000?l000000ol00005ooooo`?o00000_ooool4o`0000Oooooo1?l00003ooooo`?o00005Ooo
ool>o`0000[ooooo0_l0002Aooooo`007?ooool00ol0003oooooooooo`1Rooooo`;o00001?ooool4
o`0000Cooooo0_l00002ooooo`;o00003_ooool3o`0001Oooooo2ol000000ooooooo0000o`000009
ooooo`?o00000_ooool2o`0008gooooo000Looooo`03o`000?oooooooooo06Oooooo2_l0000<oooo
o`;o00001Oooool3o`0001Sooooo0ol000001?oooooo0000o`000?ooool3o`0000Kooooo0_l00004
ooooo`;o000000?oooooo`000?l000000_l0002=ooooo`007?ooool00ol0003oooooooooo`1Toooo
o`go00002Oooool2o`000003ooooool0003o0000023ooooo2Ol00007ooooo`Co00001Oooool2o`00
00?ooooo0_l0002:ooooo`007?ooool00ol0003oooooooooo`1Tooooo`?o000000?oooooo`000?l0
00000_l0000>ooooo`;o00008oooool8o`0000Sooooo1?l0000:ooooo`?o0000ROooool001cooooo
00?o0000ooooooooool0K?ooool2o`0000cooooo0_l00006ooooo`?o00006_ooool3o`0000?ooooo
0_l00002ooooo`;o000000?oooooo`000?l000003oooool3o`0008Wooooo000Looooo`03o`000?oo
oooooooo06Sooooo0_l00002ooooo`Co00000_ooool2o`0000kooooo0ol0000Jooooo`Co00001_oo
ool2o`000003ooooool0003o000000Gooooo1?l00007ooooo`;o0000ROooool001cooooo00?o0000
ooooooooool0J?ooool3o`0000?ooooo0ol000000ooooooo0000o`00000;ooooo`Go00007?ooool3
o`0000oooooo1Ol00007ooooo`;o000000Coooooo`000?l0003o0000QOooool001cooooo0_l0001Z
ooooo`;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000007ooooo`Co00007Oooool4
o`000003ooooool0003o000000_ooooo0_l0000=ooooo`?o0000QOooool001cooooo00?o0000oooo
ooooool0JOooool7o`0000?ooooo2Ol000000ooooooo0000o`000004o`0001gooooo1?l000000ooo
oooo0000o`000005ooooo`;o00004_ooool2o`0008Oooooo000Looooo`03o`000?oooooooooo06[o
oooo2Ol000000ooooooo0000o`00000;o`00023ooooo1?l00002ooooo`;o00000oooool2o`0000;o
oooo1?l0000<ooooo`Co0000QOooool001cooooo00?o0000ooooooooool0Joooool2o`000003oooo
ool0003o000000?o000000?oooooo`000?l000002_l0000Qooooo`Co000000?oooooo`000?l00000
1_l00002ooooo`Co00000oooool2o`000003ooooool0003o000000Kooooo0_l00025ooooo`007?oo
ool00ol0003oooooooooo`1`ooooo`;o000000?oooooo`000?l000000_ooool3o`000004ooooool0
003o0000o`0002?ooooo1ol000000ooooooo0000o`000003o`0000Oooooo1?l000001?oooooo0000
o`000?l00006ooooo`Ko0000P?ooool001cooooo00?o0000ooooooooool0L?ooool2o`000003oooo
ool0003o000002kooooo1?l00005ooooo`;o00001oooool2o`0000Cooooo0ol00005ooooo`Oo0000
Ooooool001cooooo00?o0000ooooooooool0Xoooool4o`0000kooooo0_l00004ooooo`?o000000Co
ooooo`000?l0003o00001_ooool2o`0007oooooo000Looooo`03o`000?oooooooooo0:?ooooo1_l0
0009ooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo0ol00007ooooo`;o0000O_oo
ool001cooooo00?o0000ooooooooool0YOooool7o`0000?ooooo1Ol000000ooooooo0000o`000004
ooooo`;o00003?ooool2o`0007kooooo000Looooo`03o`000?oooooooooo0:Gooooo1ol00003oooo
o`?o00000oooool2o`0009;ooooo000Looooo`03o`000?oooooooooo0:Kooooo1ol00003ooooo`;o
00000oooool2o`0000Sooooo0_l000001?oooooo0000o`000?ooool2o`0008;ooooo000Looooo`03
o`000?oooooooooo0:Sooooo1Ol00002ooooo`;o00001oooool2o`000003ooooool0003o000000[o
0000P_ooool001cooooo00?o0000ooooooooool0Z_ooool7o`0000?ooooo0_l00002ooooo`;o0000
00?oooooo`000?l000000_l000000ooooooo0000o`000002ooooo`;o0000Poooool001cooooo00?o
0000ooooooooool0Zoooool6o`0000?ooooo0_l00009ooooo`;o0000R?ooool00006ooooooo^k^ko
<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03
o`000?oooooooooo0:cooooo0_l000001?oooooo0000o`000?ooool2o`0000_ooooo0_l00028oooo
o`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonH
V9So8B4Q00Kooooo00?o0000ooooooooool0[oooool2o`000004ooooool0003o0000o`0000Gooooo
0_l00005ooooo`;o0000Q_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0/oooool5o`0000;ooooo
0_l00005ooooo`;o0000Q_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Ooo
ool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0002cooooo`Go000000Goooooo`000?l0003o
0000ooooo`02o`0008[ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo
00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo0;Wooooo0ol000000ooooooo
0000o`00002:ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05oa0@
4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`3ooooood[ooooo00001_ooooooMgMg
oiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooo
oooo0?ooooooB_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`00
0?l@413oZJVY00Kooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`004_ooool4o`000003oa0@4?oooooooooo
00?ooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool3o`000?oooooo
B_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3o
oooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000oooooooo
ool0oooooomBooooo`004_ooool00omEEEGoIVIVo`00003ooooooeCooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo002Uooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@oooo
ooooool05_ooool4o`000003oa0@4?oooooooooo00Go00000oooool01Oo^k^ko<S8bo`000?l@413o
c<c<093ooooo002Vooooo`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo00?o0000
ooooooooool00_ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoEEEEogMgMoooooooV9RH
ob4Q8@2@ooooo`00Y_ooool01Ol0003ooooooooooooooooo000001_ooooo00?o0000ooooooooool0
0oooool00onHV9So8B4Qonk^kP04ooooo`05o`000?ooooooooooooooool00000T?ooool00:Kooooo
00Go0000ooooooooooooooooo`000009ooooo`Ko00003?ooool00ol0003oooooooooo`04ooooo`03
oiRHV?lQ8B7ok^k^00?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@2@ooooo`00Y_ooool01Ol0003o
QhN7oooooonYZJWo000001_ooooo00?o0000ooooooooool01Oooool00omgMgOoIVIVooooo`02oooo
o`05o`000?mEEEGo0000oa0@4?o<c<`0T?ooool00:Gooooo00?o410@o`000?mgMgL00_l000000onH
V9Soooooooooo`0Iooooo`03o`000?oooooooooo00Kooooo00Ko0000oooooooooooooooooeEEEOn7
QhNCooooo`00a_ooool00ol0003oooooooooo`02ooooo`05o`000?nj^[[ooooooiRHV?l@41000ooo
ool00ooMgMgo410@oiRHV02Booooo`00a?ooool00omEEEGoIVIVo`000004ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01?ooool01?o<c<coA4A4o`000?l@412@ooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(132) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.29285 .61365 Mdot
.33983 .62636 Mdot
.64999 .57576 Mdot
.39493 .40111 Mdot
.66998 .37243 Mdot
.66065 .58306 Mdot
.51372 .71237 Mdot
.49582 .69762 Mdot
.63302 .59454 Mdot
.49715 .42774 Mdot
.549 .7027 Mdot
.43583 .34336 Mdot
.50593 .70656 Mdot
.43158 .39337 Mdot
.45318 .28837 Mdot
.25878 .40384 Mdot
.34601 .60098 Mdot
.67974 .3746 Mdot
.26444 .41181 Mdot
.62895 .5913 Mdot
.70731 .28653 Mdot
.41657 .38598 Mdot
.32003 .59884 Mdot
.43177 .39561 Mdot
.26558 .4076 Mdot
.33159 .63614 Mdot
.28981 .62135 Mdot
.27769 .40218 Mdot
.4253 .33125 Mdot
.55046 .71283 Mdot
.29112 .3991 Mdot
.52205 .28783 Mdot
.60906 .42686 Mdot
.34198 .52255 Mdot
.53004 .6809 Mdot
.55916 .68205 Mdot
.6463 .60032 Mdot
.55881 .69716 Mdot
.50743 .7232 Mdot
.54169 .6878 Mdot
.54317 .68733 Mdot
.32573 .63505 Mdot
.54496 .68279 Mdot
.55027 .79883 Mdot
.42944 .42067 Mdot
.29031 .47803 Mdot
.61995 .59319 Mdot
.41306 .33474 Mdot
.33159 .59248 Mdot
.72887 .63078 Mdot
.54942 .35427 Mdot
.51558 .68878 Mdot
.62435 .44985 Mdot
.2461 .45716 Mdot
.49928 .70857 Mdot
.2668 .4106 Mdot
.68573 .59644 Mdot
.41666 .4111 Mdot
.42016 .32181 Mdot
.33755 .5146 Mdot
.40495 .40312 Mdot
.67681 .36167 Mdot
.30608 .67044 Mdot
.67837 .57861 Mdot
.62939 .57388 Mdot
.56262 .69687 Mdot
.3631 .61449 Mdot
.48386 .69293 Mdot
.39329 .39049 Mdot
.63694 .60944 Mdot
.42506 .34606 Mdot
.54949 .7023 Mdot
.35105 .63627 Mdot
.41508 .37119 Mdot
.30388 .59893 Mdot
.47146 .70453 Mdot
.67507 .37487 Mdot
.38031 .59567 Mdot
.72507 .63087 Mdot
.33726 .38725 Mdot
.41136 .37884 Mdot
.35432 .74533 Mdot
.38371 .28551 Mdot
.31311 .64411 Mdot
.44048 .38565 Mdot
.30342 .73253 Mdot
.43985 .43619 Mdot
.28016 .39361 Mdot
.27311 .40487 Mdot
.41657 .30525 Mdot
.69951 .61178 Mdot
.31463 .609 Mdot
.42221 .39329 Mdot
.39132 .40027 Mdot
.48885 .437 Mdot
.41523 .34617 Mdot
.27155 .40805 Mdot
.61489 .46755 Mdot
.53823 .69075 Mdot
.63865 .45615 Mdot
.46577 .72045 Mdot
.62709 .46478 Mdot
.44072 .36903 Mdot
.66127 .60201 Mdot
.29302 .64158 Mdot
.60904 .45298 Mdot
.49707 .68348 Mdot
.42509 .39274 Mdot
.56149 .68107 Mdot
.31481 .60475 Mdot
.29224 .40911 Mdot
.67976 .34001 Mdot
.72157 .31785 Mdot
.35794 .62536 Mdot
.34665 .45147 Mdot
.41125 .42692 Mdot
.40713 .38939 Mdot
.33538 .62913 Mdot
.6235 .57932 Mdot
.5964 .6541 Mdot
.32787 .61178 Mdot
.54373 .69415 Mdot
.34815 .6 Mdot
.60816 .42232 Mdot
.62492 .57651 Mdot
.63807 .42868 Mdot
.62217 .47382 Mdot
.53628 .30867 Mdot
.40571 .35239 Mdot
.60004 .43462 Mdot
.66226 .60692 Mdot
.32826 .61509 Mdot
.50986 .69925 Mdot
.39227 .41375 Mdot
.31634 .64197 Mdot
.50033 .71312 Mdot
.68821 .31666 Mdot
.69156 .31514 Mdot
.34213 .63958 Mdot
.35557 .45961 Mdot
.56242 .69105 Mdot
.48455 .70834 Mdot
.54713 .35493 Mdot
.32504 .64517 Mdot
.655 .34422 Mdot
.48845 .70889 Mdot
.69609 .54268 Mdot
.28889 .41397 Mdot
.55388 .31703 Mdot
.36579 .73945 Mdot
.54828 .35542 Mdot
.7031 .28962 Mdot
.67391 .35743 Mdot
.49856 .71217 Mdot
.41981 .44108 Mdot
.35187 .61784 Mdot
.32465 .64175 Mdot
.4327 .34746 Mdot
.60735 .44289 Mdot
.41595 .42565 Mdot
.63836 .46411 Mdot
.62252 .47506 Mdot
.42902 .39726 Mdot
.30852 .4907 Mdot
.2978 .62754 Mdot
.43948 .42537 Mdot
.64817 .60589 Mdot
.69329 .36964 Mdot
.55857 .6867 Mdot
.43938 .38649 Mdot
.415 .45 Mdot
.44862 .37469 Mdot
.48315 .70692 Mdot
.4832 .77625 Mdot
.72333 .6363 Mdot
.53968 .71341 Mdot
.46355 .71538 Mdot
.6813 .61212 Mdot
.41651 .32509 Mdot
.67562 .34377 Mdot
.62388 .43502 Mdot
.43368 .43068 Mdot
.55108 .35526 Mdot
.42286 .31395 Mdot
.71217 .3018 Mdot
.7022 .29961 Mdot
.34448 .73784 Mdot
.46828 .75946 Mdot
.40078 .42012 Mdot
.29929 .39246 Mdot
.5537 .33732 Mdot
.57241 .66144 Mdot
.51568 .69759 Mdot
.6159 .5783 Mdot
.62164 .58165 Mdot
.74448 .63458 Mdot
.46311 .39933 Mdot
.44755 .36174 Mdot
.40382 .37747 Mdot
.63212 .45261 Mdot
.30821 .66813 Mdot
.67328 .3586 Mdot
.35199 .60964 Mdot
.35751 .7449 Mdot
.34765 .36433 Mdot
.26818 .41938 Mdot
.74649 .61972 Mdot
.68867 .58236 Mdot
.6168 .46001 Mdot
.66273 .34593 Mdot
.4125 .4157 Mdot
.30193 .61547 Mdot
.55111 .34556 Mdot
.61866 .41944 Mdot
.70734 .25999 Mdot
.33303 .60477 Mdot
.37517 .32555 Mdot
.50434 .7105 Mdot
.69494 .61859 Mdot
.43997 .43578 Mdot
.42651 .38001 Mdot
.37885 .603 Mdot
.39772 .42057 Mdot
.29881 .41552 Mdot
.28666 .40966 Mdot
.73158 .63356 Mdot
.46316 .72559 Mdot
.53248 .71747 Mdot
.61858 .59277 Mdot
.3546 .63121 Mdot
.28849 .48544 Mdot
.67052 .59848 Mdot
.71169 .29253 Mdot
.55303 .70144 Mdot
.67752 .31898 Mdot
.66414 .59645 Mdot
.67031 .37179 Mdot
.42106 .31952 Mdot
.67524 .62034 Mdot
.68649 .33947 Mdot
.47624 .32078 Mdot
.61329 .46028 Mdot
.64219 .3607 Mdot
.51676 .71361 Mdot
.35876 .59413 Mdot
.43304 .43231 Mdot
.62468 .44299 Mdot
.63152 .41712 Mdot
.40541 .31212 Mdot
.644 .47049 Mdot
.61295 .42857 Mdot
.40843 .31671 Mdot
.688 .3673 Mdot
.41937 .68641 Mdot
.29251 .40107 Mdot
.34855 .60234 Mdot
.39643 .41639 Mdot
.46246 .73536 Mdot
.50007 .71393 Mdot
.40838 .41193 Mdot
.33919 .74501 Mdot
.52045 .71391 Mdot
.41886 .40279 Mdot
.51765 .72528 Mdot
.31372 .64284 Mdot
.34914 .3588 Mdot
.34232 .6424 Mdot
.42886 .40049 Mdot
.51972 .72568 Mdot
.62297 .59448 Mdot
.3326 .6368 Mdot
.4209 .38967 Mdot
.39905 .38163 Mdot
.62998 .45107 Mdot
.28756 .41127 Mdot
.47443 .72029 Mdot
.43568 .34459 Mdot
.69128 .5924 Mdot
.42388 .33648 Mdot
.69785 .31518 Mdot
.7292 .55398 Mdot
.32649 .64537 Mdot
.64467 .47135 Mdot
.6685 .59092 Mdot
.52726 .39053 Mdot
.36444 .33604 Mdot
.43222 .41738 Mdot
.61865 .42593 Mdot
.3755 .28407 Mdot
.53384 .70723 Mdot
.29584 .41438 Mdot
.60307 .41559 Mdot
.68314 .59344 Mdot
.62975 .46272 Mdot
.42602 .35572 Mdot
.31326 .60288 Mdot
.26157 .40707 Mdot
.68716 .61462 Mdot
.33378 .59976 Mdot
.44687 .39331 Mdot
.46687 .717 Mdot
.61884 .48332 Mdot
.53603 .70453 Mdot
.28054 .39828 Mdot
.41537 .32672 Mdot
.64076 .61215 Mdot
.32214 .6352 Mdot
.49565 .70384 Mdot
.34559 .63964 Mdot
.53308 .38076 Mdot
.3783 .31921 Mdot
.33886 .64679 Mdot
.69748 .32573 Mdot
.77897 .63105 Mdot
.54574 .70185 Mdot
.63936 .44087 Mdot
.66978 .63574 Mdot
.32274 .59281 Mdot
.65886 .5952 Mdot
.37466 .46805 Mdot
.69786 .60937 Mdot
.26128 .41199 Mdot
.64896 .6233 Mdot
.45426 .38509 Mdot
.44187 .40527 Mdot
.64681 .56326 Mdot
.61132 .46343 Mdot
.42312 .36105 Mdot
.31448 .6412 Mdot
.51181 .28164 Mdot
.45812 .4547 Mdot
.46235 .40004 Mdot
.68361 .59588 Mdot
.3635 .4674 Mdot
.28763 .40558 Mdot
.27765 .39946 Mdot
.34749 .61623 Mdot
.63666 .43781 Mdot
.67132 .31382 Mdot
.66152 .31631 Mdot
.77059 .54134 Mdot
.36407 .27696 Mdot
.34185 .44452 Mdot
.33505 .63935 Mdot
.75462 .63157 Mdot
.28866 .6121 Mdot
.61738 .42087 Mdot
.49613 .69708 Mdot
.49104 .78318 Mdot
.44224 .43193 Mdot
.59406 .44207 Mdot
.29683 .41995 Mdot
.34596 .59396 Mdot
.36372 .62641 Mdot
.49494 .70231 Mdot
.46106 .41663 Mdot
.49652 .42602 Mdot
.40893 .42024 Mdot
.49401 .69589 Mdot
.62721 .41624 Mdot
.41449 .31555 Mdot
.53798 .29507 Mdot
.56422 .80516 Mdot
.43133 .41297 Mdot
.35356 .53147 Mdot
.43923 .41635 Mdot
.54064 .31561 Mdot
.41811 .41649 Mdot
.3196 .63747 Mdot
.23424 .41095 Mdot
.39375 .42751 Mdot
.74479 .61664 Mdot
.34754 .36739 Mdot
.69414 .34005 Mdot
.4254 .3847 Mdot
.42239 .42975 Mdot
.65715 .33224 Mdot
.31033 .62447 Mdot
.39729 .36528 Mdot
.42169 .68404 Mdot
.41827 .39106 Mdot
.55848 .68582 Mdot
.39634 .29468 Mdot
.52183 .29106 Mdot
.28445 .40651 Mdot
.31553 .60097 Mdot
.49936 .71914 Mdot
.54989 .68847 Mdot
.64718 .45149 Mdot
.50001 .71424 Mdot
.4403 .40333 Mdot
.39706 .29444 Mdot
.36349 .61989 Mdot
.61255 .45681 Mdot
.3165 .61094 Mdot
.66569 .49685 Mdot
.51962 .71035 Mdot
.62362 .45845 Mdot
.4679 .40848 Mdot
.52586 .70222 Mdot
.46276 .65804 Mdot
.29332 .40755 Mdot
.62858 .41666 Mdot
.29505 .61162 Mdot
.64041 .61369 Mdot
.61876 .42301 Mdot
.49834 .7082 Mdot
.42981 .42113 Mdot
.27437 .41351 Mdot
.49646 .71208 Mdot
.36075 .54039 Mdot
.29708 .40604 Mdot
.41749 .39308 Mdot
.30346 .6344 Mdot
.32334 .62134 Mdot
.43654 .43246 Mdot
.40843 .42954 Mdot
.67188 .58492 Mdot
.62279 .42331 Mdot
.62605 .42241 Mdot
.63125 .47927 Mdot
.69536 .60996 Mdot
.77556 .63418 Mdot
.48505 .68882 Mdot
.52022 .29092 Mdot
.4701 .7551 Mdot
.62144 .44526 Mdot
.66923 .58302 Mdot
.4363 .41778 Mdot
.44268 .36618 Mdot
.51845 .72653 Mdot
.80746 .60808 Mdot
.44426 .42907 Mdot
.35731 .60871 Mdot
.50378 .68963 Mdot
.44478 .35791 Mdot
.7401 .63202 Mdot
.68563 .35754 Mdot
.34103 .44543 Mdot
.50464 .69048 Mdot
.36599 .55396 Mdot
.50546 .69054 Mdot
.42432 .4298 Mdot
.41997 .35398 Mdot
.36614 .59783 Mdot
.69464 .33953 Mdot
.43387 .34453 Mdot
.42257 .40571 Mdot
.75824 .63124 Mdot
.28519 .61739 Mdot
.66321 .31464 Mdot
.4262 .32781 Mdot
.62299 .47067 Mdot
.68782 .36051 Mdot
.40963 .37459 Mdot
.42635 .33796 Mdot
.60633 .4166 Mdot
.52934 .72442 Mdot
.69613 .32851 Mdot
.74731 .61779 Mdot
.33858 .60331 Mdot
.46725 .7093 Mdot
.64987 .44957 Mdot
.54627 .70069 Mdot
.49977 .36683 Mdot
.62165 .46159 Mdot
.51952 .80101 Mdot
.59856 .16678 Mdot
.61222 .43481 Mdot
.68299 .58808 Mdot
.48382 .44058 Mdot
.42858 .33993 Mdot
.41779 .39397 Mdot
.68181 .31084 Mdot
.33122 .6243 Mdot
.46892 .75979 Mdot
.5332 .71913 Mdot
.43073 .38134 Mdot
.32862 .64601 Mdot
.32971 .73975 Mdot
.6298 .45878 Mdot
.68103 .32889 Mdot
.68327 .31986 Mdot
.4179 .36691 Mdot
.36971 .2828 Mdot
.33043 .63824 Mdot
.4213 .38986 Mdot
.41423 .36473 Mdot
.68134 .63541 Mdot
.29892 .63694 Mdot
.67665 .61949 Mdot
.27255 .42043 Mdot
.3282 .41436 Mdot
.46509 .73905 Mdot
.51109 .71721 Mdot
.63523 .42894 Mdot
.53364 .71613 Mdot
.7132 .63695 Mdot
.62555 .42275 Mdot
.42117 .38899 Mdot
.36369 .6198 Mdot
.42183 .39076 Mdot
.41919 .3917 Mdot
.42301 .42241 Mdot
.33776 .44146 Mdot
.71757 .62065 Mdot
.67578 .33334 Mdot
.42332 .32324 Mdot
.68972 .60972 Mdot
.73709 .62392 Mdot
.49716 .42958 Mdot
.41905 .37956 Mdot
.40965 .39375 Mdot
.3791 .59316 Mdot
.28787 .41618 Mdot
.52244 .70199 Mdot
.36578 .59727 Mdot
.43737 .44011 Mdot
.62097 .59577 Mdot
.3959 .36797 Mdot
.33917 .6464 Mdot
.49361 .68307 Mdot
.27278 .6681 Mdot
.6486 .43951 Mdot
.64192 .43433 Mdot
.61554 .4268 Mdot
.63496 .48004 Mdot
.55406 .68444 Mdot
.66698 .58127 Mdot
.65938 .4879 Mdot
.33161 .40749 Mdot
.40741 .42967 Mdot
.42235 .35499 Mdot
.66941 .63446 Mdot
.60365 .43274 Mdot
.44186 .45687 Mdot
.25784 .41814 Mdot
.69161 .62646 Mdot
.61656 .46983 Mdot
.2906 .7018 Mdot
.32353 .60045 Mdot
.7208 .63253 Mdot
.55758 .69925 Mdot
.68861 .33991 Mdot
.82669 .50467 Mdot
.32003 .6127 Mdot
.2969 .66718 Mdot
.65938 .61178 Mdot
.40397 .30028 Mdot
.23138 .44473 Mdot
.65621 .59049 Mdot
.30036 .41035 Mdot
.35058 .62607 Mdot
.61601 .46609 Mdot
.37693 .28715 Mdot
.39932 .3044 Mdot
.64694 .61258 Mdot
.3987 .37979 Mdot
.62877 .55834 Mdot
.68303 .59071 Mdot
.63323 .43053 Mdot
.68343 .5962 Mdot
.53214 .71099 Mdot
.66892 .60883 Mdot
.3613 .54222 Mdot
.39552 .37741 Mdot
.24436 .45608 Mdot
.44867 .27796 Mdot
.40988 .4272 Mdot
.52777 .69442 Mdot
.46557 .71249 Mdot
.40083 .40725 Mdot
.65974 .36497 Mdot
.67877 .58534 Mdot
.74097 .63624 Mdot
.27355 .41594 Mdot
.65214 .62512 Mdot
.31236 .6028 Mdot
.46441 .71964 Mdot
.46407 .71719 Mdot
.61832 .4241 Mdot
.32025 .64422 Mdot
.46952 .70088 Mdot
.54289 .69331 Mdot
.61091 .47594 Mdot
.43422 .4332 Mdot
.30088 .6236 Mdot
.41379 .31481 Mdot
.68901 .3714 Mdot
.41714 .38969 Mdot
.67683 .61828 Mdot
.73092 .63483 Mdot
.45236 .28403 Mdot
.67235 .59763 Mdot
.63746 .43314 Mdot
.29976 .63005 Mdot
.2677 .41376 Mdot
.32569 .6167 Mdot
.39232 .40685 Mdot
.46269 .73013 Mdot
.32264 .59961 Mdot
.71108 .29266 Mdot
.40786 .40307 Mdot
.30592 .48808 Mdot
.42631 .3241 Mdot
.41653 .39202 Mdot
.62755 .57194 Mdot
.65637 .33557 Mdot
.70086 .35167 Mdot
.73109 .62141 Mdot
.66784 .36459 Mdot
.28008 .64103 Mdot
.62432 .57394 Mdot
.66507 .33152 Mdot
.77355 .54099 Mdot
.64457 .47335 Mdot
.67052 .33273 Mdot
.4408 .38748 Mdot
.50047 .71659 Mdot
.36523 .60665 Mdot
.42599 .3623 Mdot
.4131 .46139 Mdot
.25552 .38453 Mdot
.62888 .45369 Mdot
.41468 .39368 Mdot
.42116 .43095 Mdot
.33148 .64536 Mdot
.36647 .74127 Mdot
.68419 .58521 Mdot
.63967 .45031 Mdot
.32332 .61177 Mdot
.35284 .74565 Mdot
.63092 .57177 Mdot
.66899 .32208 Mdot
.52117 .7217 Mdot
.36723 .55972 Mdot
.62635 .44907 Mdot
.51516 .71313 Mdot
.72497 .62208 Mdot
.54517 .3628 Mdot
.26585 .39227 Mdot
.64893 .59556 Mdot
.54866 .3556 Mdot
.28054 .42231 Mdot
.74583 .63416 Mdot
.57174 .66069 Mdot
.31459 .60573 Mdot
.49217 .7077 Mdot
.68542 .32773 Mdot
.35339 .63558 Mdot
.31663 .6104 Mdot
.51217 .71762 Mdot
.22858 .41302 Mdot
.37506 .28895 Mdot
.47602 .69839 Mdot
.40876 .3017 Mdot
.54535 .35937 Mdot
.62782 .44658 Mdot
.67575 .33933 Mdot
.46328 .72572 Mdot
.32656 .63506 Mdot
.48841 .77441 Mdot
.55152 .35283 Mdot
.2951 .41287 Mdot
.68794 .34363 Mdot
.33487 .7367 Mdot
.57084 .6786 Mdot
.52221 .70447 Mdot
.75815 .63146 Mdot
.65539 .35617 Mdot
.44226 .40001 Mdot
.81593 .5997 Mdot
.43896 .3886 Mdot
.48379 .70006 Mdot
.29701 .41954 Mdot
.34137 .60847 Mdot
.48111 .69454 Mdot
.26512 .41874 Mdot
.43282 .33971 Mdot
.40187 .41785 Mdot
.72668 .63368 Mdot
.37153 .5982 Mdot
.64116 .48665 Mdot
.41263 .42917 Mdot
.42032 .40699 Mdot
.62934 .41491 Mdot
.52399 .29388 Mdot
.549 .62768 Mdot
.60623 .43583 Mdot
.6769 .62356 Mdot
.61194 .45629 Mdot
.63819 .44409 Mdot
.30165 .60665 Mdot
.75269 .63305 Mdot
.63779 .42314 Mdot
.42969 .40555 Mdot
.4252 .39717 Mdot
.50509 .72261 Mdot
.37567 .28506 Mdot
.4023 .30503 Mdot
.69019 .5906 Mdot
.60017 .45927 Mdot
.40917 .35643 Mdot
.31375 .64373 Mdot
.68573 .30874 Mdot
.64579 .44764 Mdot
.34295 .60255 Mdot
.40997 .34429 Mdot
.67854 .6351 Mdot
.61181 .44101 Mdot
.63288 .414 Mdot
.68521 .34284 Mdot
.48259 .70955 Mdot
.38391 .60039 Mdot
.68275 .58942 Mdot
.27259 .39191 Mdot
.6134 .48961 Mdot
.69618 .63484 Mdot
.62919 .44606 Mdot
.62448 .46733 Mdot
.32241 .64346 Mdot
.36747 .5507 Mdot
.62823 .40671 Mdot
.69224 .60722 Mdot
.54583 .81148 Mdot
.52719 .68624 Mdot
.41629 .32725 Mdot
.52799 .71733 Mdot
.31368 .60573 Mdot
.53643 .30681 Mdot
.67818 .31981 Mdot
.52613 .70475 Mdot
.61245 .42753 Mdot
.31878 .60569 Mdot
.38201 .60336 Mdot
.43035 .40031 Mdot
.41751 .38405 Mdot
.61958 .59279 Mdot
.55319 .32561 Mdot
.51263 .72595 Mdot
.67073 .31488 Mdot
.65833 .57532 Mdot
.27263 .41392 Mdot
.35332 .61611 Mdot
.64095 .33523 Mdot
.42648 .32129 Mdot
.6888 .60616 Mdot
.34263 .62598 Mdot
.66009 .31896 Mdot
.67517 .33237 Mdot
.42682 .43692 Mdot
.70125 .29012 Mdot
.52804 .70838 Mdot
.3171 .6406 Mdot
.27649 .6485 Mdot
.42029 .32641 Mdot
.42045 .38266 Mdot
.29241 .41712 Mdot
.47599 .69322 Mdot
.4407 .3887 Mdot
.69277 .33266 Mdot
.35772 .6219 Mdot
.43838 .41376 Mdot
.65215 .34834 Mdot
.63862 .48664 Mdot
.61747 .45745 Mdot
.64116 .56318 Mdot
.64877 .33724 Mdot
.65216 .34285 Mdot
.65237 .3518 Mdot
.49162 .78367 Mdot
.44336 .35578 Mdot
.6391 .49921 Mdot
.39976 .37831 Mdot
.54407 .36124 Mdot
.27744 .38966 Mdot
.5314 .68993 Mdot
.64348 .61395 Mdot
.41608 .42283 Mdot
.40023 .37922 Mdot
.36101 .5901 Mdot
.25748 .40484 Mdot
.44022 .4224 Mdot
.3475 .60907 Mdot
.28279 .65681 Mdot
.61668 .57158 Mdot
.36448 .73927 Mdot
.83221 .57363 Mdot
.41964 .31392 Mdot
.40349 .29451 Mdot
.31077 .61987 Mdot
.51382 .72282 Mdot
.40826 .29941 Mdot
.48239 .70734 Mdot
.32457 .62578 Mdot
.25493 .40093 Mdot
.36023 .54001 Mdot
.67791 .3619 Mdot
.42485 .42914 Mdot
.51755 .71684 Mdot
.4203 .42784 Mdot
.51706 .71868 Mdot
.36352 .47114 Mdot
.38157 .28311 Mdot
.40666 .43066 Mdot
.41595 .34489 Mdot
.70603 .28587 Mdot
.41807 .38144 Mdot
.76269 .63074 Mdot
.34507 .62103 Mdot
.59785 .44092 Mdot
.25799 .39272 Mdot
.45886 .45474 Mdot
.41026 .39186 Mdot
.27501 .37984 Mdot
.40545 .38905 Mdot
.80343 .61435 Mdot
.42225 .31646 Mdot
.43725 .42686 Mdot
.51352 .69545 Mdot
.55007 .69779 Mdot
.37641 .59737 Mdot
.62431 .46591 Mdot
.33962 .7377 Mdot
.41983 .40228 Mdot
.65202 .56765 Mdot
.71129 .34518 Mdot
.65272 .3367 Mdot
.35932 .61654 Mdot
.59058 .16337 Mdot
.54776 .68362 Mdot
.65442 .61407 Mdot
.29257 .39928 Mdot
.67736 .62214 Mdot
.6844 .58349 Mdot
.27619 .64016 Mdot
.67603 .33784 Mdot
.39309 .37531 Mdot
.34284 .51974 Mdot
.28697 .66915 Mdot
.41994 .32675 Mdot
.62203 .56931 Mdot
.60671 .41635 Mdot
.3147 .30861 Mdot
.68321 .37127 Mdot
.66145 .35643 Mdot
.50482 .71255 Mdot
.65116 .56686 Mdot
.63901 .44962 Mdot
.66907 .32613 Mdot
.61626 .57481 Mdot
.64643 .46647 Mdot
.76076 .63559 Mdot
.32843 .6388 Mdot
.36642 .46752 Mdot
.28443 .47557 Mdot
.53768 .70136 Mdot
.74451 .63081 Mdot
.36131 .62572 Mdot
.32849 .64739 Mdot
.63457 .45015 Mdot
.68498 .62806 Mdot
.31362 .65466 Mdot
.42958 .43361 Mdot
.61496 .46103 Mdot
.4287 .37305 Mdot
.67938 .37589 Mdot
.42134 .39905 Mdot
.62568 .5972 Mdot
.5207 .69502 Mdot
.67745 .59098 Mdot
.5081 .71379 Mdot
.5171 .28716 Mdot
.41285 .40562 Mdot
.42378 .38518 Mdot
.39719 .29562 Mdot
.29739 .61551 Mdot
.34373 .52191 Mdot
.68739 .60206 Mdot
.67998 .59278 Mdot
.25796 .3932 Mdot
.35204 .60093 Mdot
.6441 .41845 Mdot
.40963 .30167 Mdot
.40505 .38607 Mdot
.34337 .62062 Mdot
.28226 .38919 Mdot
.53054 .80801 Mdot
.38471 .28847 Mdot
.30314 .60737 Mdot
.77026 .63654 Mdot
.41115 .36334 Mdot
.64169 .45269 Mdot
.60169 .45399 Mdot
.36872 .2768 Mdot
.68556 .37311 Mdot
.33429 .60377 Mdot
.63826 .46078 Mdot
.35378 .61872 Mdot
.69802 .60734 Mdot
.52256 .67657 Mdot
.3445 .6136 Mdot
.40638 .39361 Mdot
.83241 .57231 Mdot
.50375 .71875 Mdot
.43135 .42421 Mdot
.48583 .69036 Mdot
.36902 .61865 Mdot
.33166 .61663 Mdot
.64656 .46592 Mdot
.29955 .41094 Mdot
.52793 .70662 Mdot
.41661 .43825 Mdot
.35439 .53404 Mdot
.26135 .40689 Mdot
.69235 .36946 Mdot
.40966 .35454 Mdot
.41687 .33628 Mdot
.76837 .63036 Mdot
.52833 .39075 Mdot
.46149 .73376 Mdot
.56043 .68376 Mdot
.48163 .77665 Mdot
.29227 .62047 Mdot
.70188 .34365 Mdot
.38315 .60193 Mdot
.63473 .42672 Mdot
.66764 .62287 Mdot
.42436 .42397 Mdot
.6383 .48085 Mdot
.47447 .69837 Mdot
.66815 .33881 Mdot
.42281 .31398 Mdot
.64415 .58829 Mdot
.63648 .47394 Mdot
.5206 .70819 Mdot
.32308 .63328 Mdot
.34308 .60583 Mdot
.75914 .63778 Mdot
.43769 .41695 Mdot
.41883 .38614 Mdot
.51434 .67967 Mdot
.69744 .29415 Mdot
.66678 .36521 Mdot
.61097 .46278 Mdot
.50684 .68054 Mdot
.38441 .28746 Mdot
.37931 .60415 Mdot
.4283 .43114 Mdot
.39491 .29192 Mdot
.47657 .76914 Mdot
.29241 .69232 Mdot
.6676 .36066 Mdot
.36462 .32736 Mdot
.3332 .60431 Mdot
.50771 .69936 Mdot
.77087 .5445 Mdot
.28882 .41955 Mdot
.39667 .39778 Mdot
.35832 .34049 Mdot
.40596 .31491 Mdot
.2852 .39498 Mdot
.64927 .444 Mdot
.38429 .32062 Mdot
.26085 .39114 Mdot
.2637 .39605 Mdot
.41446 .35188 Mdot
.4122 .35161 Mdot
.33795 .61904 Mdot
.46154 .39856 Mdot
.66888 .61423 Mdot
.30277 .40649 Mdot
.6525 .31423 Mdot
.29163 .4039 Mdot
.43513 .35172 Mdot
.29332 .69765 Mdot
.35318 .28707 Mdot
.34721 .62875 Mdot
.31954 .59414 Mdot
.53905 .7028 Mdot
.26159 .40898 Mdot
.68945 .60524 Mdot
.61398 .40952 Mdot
.65493 .62356 Mdot
.33831 .62068 Mdot
.61776 .57277 Mdot
.56178 .69814 Mdot
.64876 .59549 Mdot
.68878 .62555 Mdot
.52005 .69317 Mdot
.36805 .59697 Mdot
.42797 .32485 Mdot
.52127 .69309 Mdot
.62783 .41204 Mdot
.67109 .3214 Mdot
.28603 .66332 Mdot
.60778 .45253 Mdot
.44917 .41209 Mdot
.54597 .80755 Mdot
.64637 .59954 Mdot
.35075 .35581 Mdot
.33969 .59262 Mdot
.64459 .34086 Mdot
.3412 .6129 Mdot
.6321 .4068 Mdot
.67739 .3586 Mdot
.43808 .37775 Mdot
.66001 .30427 Mdot
.57148 .65736 Mdot
.39573 .4293 Mdot
.28218 .65615 Mdot
.66043 .62691 Mdot
.53358 .70246 Mdot
.47714 .6512 Mdot
.64015 .4533 Mdot
.31826 .59814 Mdot
.37571 .56234 Mdot
.62954 .42344 Mdot
.5108 .69923 Mdot
.32175 .49895 Mdot
.4235 .43475 Mdot
.53531 .71152 Mdot
.40792 .35616 Mdot
.35208 .45609 Mdot
.68987 .30858 Mdot
.62935 .47877 Mdot
.25604 .40625 Mdot
.63003 .57479 Mdot
.25626 .39548 Mdot
.44163 .44642 Mdot
.5445 .30893 Mdot
.40106 .38391 Mdot
.35305 .3516 Mdot
.7119 .63745 Mdot
.35221 .62888 Mdot
.6167 .4403 Mdot
.62883 .44905 Mdot
.26049 .41296 Mdot
.85848 .50031 Mdot
.66401 .33862 Mdot
.76701 .63548 Mdot
.41441 .4049 Mdot
.4114 .38016 Mdot
.38187 .60021 Mdot
.37136 .47261 Mdot
.61697 .46848 Mdot
.39823 .39411 Mdot
.35884 .27815 Mdot
.50396 .69652 Mdot
.43945 .36768 Mdot
.41988 .36811 Mdot
.46145 .72073 Mdot
.51124 .69646 Mdot
.70518 .63502 Mdot
.64573 .47291 Mdot
.63989 .56262 Mdot
.67571 .37056 Mdot
.37291 .32589 Mdot
.52947 .298 Mdot
.38587 .29592 Mdot
.67463 .36689 Mdot
.28763 .40736 Mdot
.44566 .43002 Mdot
.39526 .38239 Mdot
.6609 .35315 Mdot
.54371 .71818 Mdot
.3432 .6186 Mdot
.35793 .46186 Mdot
.6305 .44901 Mdot
.26811 .3942 Mdot
.67182 .37504 Mdot
.35253 .61987 Mdot
.31046 .49229 Mdot
.33276 .62372 Mdot
.51775 .70614 Mdot
.74435 .63226 Mdot
.67926 .3585 Mdot
.34174 .61248 Mdot
.62709 .58203 Mdot
.46366 .73207 Mdot
.45131 .3815 Mdot
.56137 .7007 Mdot
.27751 .63472 Mdot
.31015 .60047 Mdot
.2933 .61035 Mdot
.27337 .41753 Mdot
.35264 .35309 Mdot
.63725 .4308 Mdot
.50314 .68085 Mdot
.63288 .57606 Mdot
.55133 .32282 Mdot
.32972 .50949 Mdot
.39003 .33297 Mdot
.42834 .35807 Mdot
.42249 .39934 Mdot
.41345 .36921 Mdot
.64719 .4337 Mdot
.4374 .44417 Mdot
.40161 .37506 Mdot
.51691 .72678 Mdot
.70304 .63466 Mdot
.41681 .40713 Mdot
.61634 .45342 Mdot
.59384 .4456 Mdot
.6445 .34092 Mdot
.32846 .43682 Mdot
.31028 .66594 Mdot
.34917 .61605 Mdot
.68703 .61285 Mdot
.6269 .56617 Mdot
.68968 .3165 Mdot
.49449 .69803 Mdot
.33006 .62474 Mdot
.80127 .61462 Mdot
.68474 .35601 Mdot
.43041 .41155 Mdot
.3965 .29562 Mdot
.35845 .28829 Mdot
.43246 .34584 Mdot
.42159 .42173 Mdot
.60916 .43786 Mdot
.69189 .6102 Mdot
.45206 .3785 Mdot
.3098 .49071 Mdot
.65469 .35404 Mdot
.6666 .32105 Mdot
.29272 .63756 Mdot
.41852 .44218 Mdot
.51884 .71593 Mdot
.37487 .28276 Mdot
.47498 .72149 Mdot
.30789 .73114 Mdot
.65908 .50021 Mdot
.39499 .36971 Mdot
.47186 .44932 Mdot
.44182 .43333 Mdot
.29302 .64147 Mdot
.36273 .54932 Mdot
.34054 .6361 Mdot
.50044 .69742 Mdot
.53907 .37228 Mdot
.54569 .68796 Mdot
.61881 .4709 Mdot
.32642 .60001 Mdot
.42093 .30623 Mdot
.67964 .59307 Mdot
.2588 .39919 Mdot
.67668 .34834 Mdot
.41104 .31588 Mdot
.61884 .44324 Mdot
.3672 .32641 Mdot
.66803 .58267 Mdot
.37623 .60734 Mdot
.25884 .39759 Mdot
.72828 .61944 Mdot
.38647 .32074 Mdot
.66792 .46325 Mdot
.63766 .48204 Mdot
.67721 .36156 Mdot
.50029 .42625 Mdot
.69044 .34434 Mdot
.52633 .70756 Mdot
.41058 .40574 Mdot
.43635 .42824 Mdot
.41312 .39002 Mdot
.43144 .36525 Mdot
.4976 .70459 Mdot
.26544 .40305 Mdot
.61566 .41395 Mdot
.63868 .47769 Mdot
.29112 .40043 Mdot
.67238 .33996 Mdot
.53007 .68743 Mdot
.69226 .63544 Mdot
.61913 .42067 Mdot
.69521 .34702 Mdot
.40381 .44056 Mdot
.40121 .39411 Mdot
.63271 .47677 Mdot
.43955 .3828 Mdot
.26892 .40539 Mdot
.65498 .6022 Mdot
.27259 .39568 Mdot
.64486 .34552 Mdot
.67986 .34843 Mdot
.49918 .71484 Mdot
.3432 .61221 Mdot
.69007 .3203 Mdot
.65656 .57631 Mdot
.44219 .42722 Mdot
.4108 .35377 Mdot
.3618 .54257 Mdot
.55159 .3541 Mdot
.64542 .34492 Mdot
.44232 .3968 Mdot
.30052 .63952 Mdot
.38355 .57222 Mdot
.39683 .39453 Mdot
.27518 .40484 Mdot
.30198 .60537 Mdot
.67032 .32344 Mdot
.49114 .69921 Mdot
.46257 .28057 Mdot
.48326 .70547 Mdot
.32147 .63347 Mdot
.6374 .45896 Mdot
.36294 .59468 Mdot
.64002 .45676 Mdot
.30774 .71136 Mdot
.40492 .36478 Mdot
.35761 .53907 Mdot
.60659 .42164 Mdot
.68837 .59961 Mdot
.69776 .62809 Mdot
.61246 .43931 Mdot
.33232 .60205 Mdot
.63583 .43151 Mdot
.68862 .3331 Mdot
.48241 .77374 Mdot
.30864 .5987 Mdot
.68894 .62616 Mdot
.645 .59673 Mdot
.50933 .67968 Mdot
.41684 .3967 Mdot
.42669 .43206 Mdot
.64869 .5917 Mdot
.47389 .72027 Mdot
.30999 .61378 Mdot
.41966 .38644 Mdot
.60917 .42807 Mdot
.66361 .61068 Mdot
.56466 .66625 Mdot
.36992 .6203 Mdot
.25461 .40351 Mdot
.54214 .30594 Mdot
.55881 .68443 Mdot
.44693 .41489 Mdot
.27118 .407 Mdot
.65835 .34185 Mdot
.36221 .33048 Mdot
.54628 .35587 Mdot
.55768 .69012 Mdot
.64126 .43375 Mdot
.43409 .34803 Mdot
.70064 .61734 Mdot
.44274 .42199 Mdot
.61726 .18195 Mdot
.62881 .47586 Mdot
.43679 .39772 Mdot
.60727 .46321 Mdot
.32607 .61592 Mdot
.41485 .38622 Mdot
.46462 .7378 Mdot
.68432 .60939 Mdot
.43727 .41734 Mdot
.7094 .28713 Mdot
.48275 .69342 Mdot
.61893 .44446 Mdot
.66687 .36403 Mdot
.29702 .40078 Mdot
.51214 .28228 Mdot
.67061 .6349 Mdot
.67484 .32968 Mdot
.41444 .39661 Mdot
.66105 .57552 Mdot
.54836 .6996 Mdot
.61539 .43912 Mdot
.3998 .4357 Mdot
.53924 .69241 Mdot
.51069 .69277 Mdot
.6853 .34946 Mdot
.28693 .48713 Mdot
.39051 .40795 Mdot
.43203 .39054 Mdot
.31154 .49863 Mdot
.38401 .58621 Mdot
.4241 .42818 Mdot
.42502 .36554 Mdot
.51601 .71397 Mdot
.54 .37629 Mdot
.3658 .32782 Mdot
.60454 .42331 Mdot
.53237 .69851 Mdot
.61887 .56709 Mdot
.65539 .61253 Mdot
.67967 .32428 Mdot
.34161 .62695 Mdot
.69558 .32022 Mdot
.67442 .61052 Mdot
.43111 .40684 Mdot
.48715 .69779 Mdot
.32132 .40611 Mdot
.48219 .69222 Mdot
.65258 .57843 Mdot
.33855 .64584 Mdot
.45615 .40115 Mdot
.61355 .17898 Mdot
.5291 .62652 Mdot
.7505 .63804 Mdot
.6533 .33625 Mdot
.31049 .49121 Mdot
.41206 .40002 Mdot
.45832 .39553 Mdot
.43443 .41967 Mdot
.70273 .32468 Mdot
.64986 .62191 Mdot
.6465 .46636 Mdot
.6403 .4525 Mdot
.36772 .33052 Mdot
.50813 .69259 Mdot
.54858 .68665 Mdot
.63185 .46728 Mdot
.5173 .70356 Mdot
.43347 .38795 Mdot
.65996 .58397 Mdot
.29824 .7093 Mdot
.40478 .38736 Mdot
.61423 .48006 Mdot
.56474 .69255 Mdot
.3414 .64713 Mdot
.61918 .56828 Mdot
.46477 .45268 Mdot
.34895 .73867 Mdot
.52738 .70254 Mdot
.32888 .43601 Mdot
.68659 .60671 Mdot
.61804 .42165 Mdot
.66601 .5766 Mdot
.43531 .40017 Mdot
.39534 .36845 Mdot
.63161 .41602 Mdot
.40659 .38643 Mdot
.34252 .52927 Mdot
.29268 .41872 Mdot
.26255 .42427 Mdot
.39906 .37911 Mdot
.28324 .64607 Mdot
.54583 .70811 Mdot
.63331 .46626 Mdot
.40843 .31778 Mdot
.40914 .34602 Mdot
.29199 .61877 Mdot
.53626 .69254 Mdot
.37584 .73387 Mdot
.49985 .69955 Mdot
.68915 .59849 Mdot
.49815 .69529 Mdot
.44205 .43194 Mdot
.32062 .62437 Mdot
.66824 .60142 Mdot
.62253 .44727 Mdot
.6376 .59781 Mdot
.4115 .42812 Mdot
.56987 .67303 Mdot
.65655 .61543 Mdot
.29351 .41596 Mdot
.32244 .62322 Mdot
.67676 .29181 Mdot
.30808 .66978 Mdot
.43259 .404 Mdot
.43162 .42152 Mdot
.61076 .46145 Mdot
.49784 .71159 Mdot
.37859 .60914 Mdot
.76225 .63415 Mdot
.64492 .34138 Mdot
.34425 .62982 Mdot
.68252 .30759 Mdot
.40428 .30083 Mdot
.35768 .6261 Mdot
.36003 .2779 Mdot
.50941 .71774 Mdot
.3402 .60402 Mdot
.71177 .35329 Mdot
.30014 .39326 Mdot
.67919 .33709 Mdot
.62955 .56767 Mdot
.40729 .29807 Mdot
.66744 .61828 Mdot
.46218 .72978 Mdot
.73195 .63411 Mdot
.53107 .70561 Mdot
.70944 .28913 Mdot
.2979 .41919 Mdot
.55767 .69545 Mdot
.46914 .75226 Mdot
.67695 .6162 Mdot
.62909 .46964 Mdot
.27118 .39883 Mdot
.63807 .41728 Mdot
.63932 .46701 Mdot
.55182 .68635 Mdot
.34386 .60398 Mdot
.35508 .60447 Mdot
.59822 .44429 Mdot
.34585 .60711 Mdot
.65723 .59543 Mdot
.38871 .29005 Mdot
.46813 .40965 Mdot
.54636 .70904 Mdot
.29591 .39885 Mdot
.42972 .35031 Mdot
.64408 .61902 Mdot
.6595 .5881 Mdot
.50394 .69503 Mdot
.27771 .6785 Mdot
.64274 .45541 Mdot
.36389 .62835 Mdot
.321 .6102 Mdot
.32792 .6128 Mdot
.34911 .59121 Mdot
.54299 .36652 Mdot
.52783 .69412 Mdot
.33014 .60328 Mdot
.41882 .35744 Mdot
.41838 .36429 Mdot
.62177 .4199 Mdot
.70234 .34122 Mdot
.27547 .40175 Mdot
.63851 .43383 Mdot
.40002 .40914 Mdot
.68325 .59637 Mdot
.70669 .34655 Mdot
.64383 .43616 Mdot
.69123 .60734 Mdot
.69284 .60656 Mdot
.64682 .44352 Mdot
.70397 .34998 Mdot
.34353 .5298 Mdot
.30146 .38995 Mdot
.28278 .65099 Mdot
.68629 .62946 Mdot
.46331 .74609 Mdot
.35829 .53879 Mdot
.43972 .4171 Mdot
.6063 .45468 Mdot
.66981 .58577 Mdot
.31241 .59616 Mdot
.4199 .378 Mdot
.63507 .44793 Mdot
.6841 .33417 Mdot
.62147 .45088 Mdot
.60874 .44351 Mdot
.29605 .62568 Mdot
.55582 .7985 Mdot
.32941 .64573 Mdot
.71974 .62152 Mdot
.62297 .43988 Mdot
.24096 .45376 Mdot
.66874 .62983 Mdot
.48467 .77561 Mdot
.29883 .41703 Mdot
.39549 .38999 Mdot
.68623 .61363 Mdot
.31154 .6033 Mdot
.5453 .71848 Mdot
.35321 .28248 Mdot
.34183 .61146 Mdot
.65002 .45001 Mdot
.61058 .44251 Mdot
.66632 .61336 Mdot
.31568 .6313 Mdot
.27212 .40721 Mdot
.33484 .60825 Mdot
.52639 .68229 Mdot
.44281 .39183 Mdot
.34115 .73766 Mdot
.63855 .44902 Mdot
.35451 .6112 Mdot
.63555 .57517 Mdot
.69319 .33297 Mdot
.44062 .39558 Mdot
.34272 .74486 Mdot
.41179 .394 Mdot
.52287 .67997 Mdot
.6015 .46989 Mdot
.29112 .39015 Mdot
.42095 .41699 Mdot
.44207 .36271 Mdot
.47077 .70875 Mdot
.41637 .4165 Mdot
.41956 .3323 Mdot
.29886 .48367 Mdot
.34448 .63864 Mdot
.41679 .40571 Mdot
.65102 .59158 Mdot
.59046 .62527 Mdot
.42728 .37445 Mdot
.72946 .6177 Mdot
.36749 .28262 Mdot
.61913 .40843 Mdot
.7002 .36412 Mdot
.53735 .30778 Mdot
.43487 .41059 Mdot
.40491 .42827 Mdot
.44182 .38658 Mdot
.47635 .41523 Mdot
.67914 .6102 Mdot
.64663 .56368 Mdot
.68821 .32648 Mdot
.35542 .34397 Mdot
.68238 .34727 Mdot
.54787 .70057 Mdot
.26968 .42077 Mdot
.64116 .47981 Mdot
.3477 .61266 Mdot
.4118 .38783 Mdot
.63894 .56848 Mdot
.43629 .40225 Mdot
.27992 .41424 Mdot
.65857 .60144 Mdot
.67445 .58806 Mdot
.67735 .57253 Mdot
.65036 .3403 Mdot
.35048 .62259 Mdot
.43049 .44066 Mdot
.65767 .36022 Mdot
.63514 .41722 Mdot
.44719 .27364 Mdot
.34895 .62742 Mdot
.35624 .61559 Mdot
.36187 .59721 Mdot
.42712 .44253 Mdot
.43109 .44274 Mdot
.53995 .68604 Mdot
.36294 .5422 Mdot
.48335 .7002 Mdot
.68499 .61686 Mdot
.70217 .61341 Mdot
.43613 .40584 Mdot
.6791 .30235 Mdot
.67371 .34004 Mdot
.63949 .59706 Mdot
.62467 .47758 Mdot
.69559 .33138 Mdot
.41719 .43674 Mdot
.67439 .61928 Mdot
.65492 .35882 Mdot
.27655 .67842 Mdot
.39278 .7122 Mdot
.69427 .33346 Mdot
.64051 .44897 Mdot
.33285 .5102 Mdot
.54698 .3186 Mdot
.68916 .30877 Mdot
.54722 .70611 Mdot
.42632 .32089 Mdot
.62815 .47899 Mdot
.6969 .34125 Mdot
.55789 .33039 Mdot
.66793 .60714 Mdot
.64134 .44759 Mdot
.72151 .31395 Mdot
.46812 .40591 Mdot
.695 .34008 Mdot
.35633 .61347 Mdot
.35315 .64462 Mdot
.42729 .41792 Mdot
.29888 .40819 Mdot
.53472 .7197 Mdot
.62679 .56865 Mdot
.64177 .56554 Mdot
.36829 .5568 Mdot
.38523 .29262 Mdot
.65218 .60149 Mdot
.41495 .32557 Mdot
.69472 .35195 Mdot
.41806 .35719 Mdot
.59677 .43705 Mdot
.29527 .39003 Mdot
.69373 .37152 Mdot
.69375 .33336 Mdot
.54583 .71169 Mdot
.52023 .69548 Mdot
.49847 .7106 Mdot
.65611 .60601 Mdot
.40602 .30595 Mdot
.65049 .5654 Mdot
.28518 .48297 Mdot
.66553 .3355 Mdot
.77759 .63382 Mdot
.44278 .43473 Mdot
.3998 .4114 Mdot
.27095 .39026 Mdot
.60668 .43758 Mdot
.43397 .40267 Mdot
.54055 .69148 Mdot
.62762 .58301 Mdot
.57021 .66801 Mdot
.30226 .63219 Mdot
.28817 .48333 Mdot
.67726 .59262 Mdot
.619 .48271 Mdot
.67476 .34638 Mdot
.53383 .29005 Mdot
.70217 .31815 Mdot
.68347 .58889 Mdot
.39221 .40225 Mdot
.30216 .60266 Mdot
.80429 .61033 Mdot
.41535 .38848 Mdot
.64533 .59923 Mdot
.61907 .59077 Mdot
.30033 .39621 Mdot
.51819 .40533 Mdot
.57229 .66428 Mdot
.39381 .30054 Mdot
.64914 .3448 Mdot
.62745 .41372 Mdot
.37561 .27506 Mdot
.6752 .61176 Mdot
.63425 .59629 Mdot
.68585 .30957 Mdot
.3411 .64688 Mdot
.34412 .59544 Mdot
.34715 .53369 Mdot
.54083 .68921 Mdot
.3975 .37541 Mdot
.67253 .61762 Mdot
.3462 .64231 Mdot
.40607 .32713 Mdot
.5092 .7107 Mdot
.64836 .6089 Mdot
.40692 .3862 Mdot
.42367 .41528 Mdot
.68334 .34453 Mdot
.59383 .44741 Mdot
.61327 .41916 Mdot
.48235 .77202 Mdot
.39833 .32989 Mdot
.26535 .41862 Mdot
.39656 .39711 Mdot
.3074 .61352 Mdot
.63218 .42571 Mdot
.67566 .33729 Mdot
.44516 .4129 Mdot
.45671 .39575 Mdot
.31288 .59967 Mdot
.51255 .71769 Mdot
.62672 .44354 Mdot
.3736 .32949 Mdot
.408 .38969 Mdot
.43546 .41569 Mdot
.27347 .4175 Mdot
.4426 .44267 Mdot
.64383 .61464 Mdot
.31518 .64512 Mdot
.66091 .36239 Mdot
.3311 .61919 Mdot
.75632 .6337 Mdot
.29431 .41885 Mdot
.42002 .32034 Mdot
.29164 .62695 Mdot
.32765 .62707 Mdot
.52122 .68016 Mdot
.52803 .69706 Mdot
.66335 .48242 Mdot
.4309 .37082 Mdot
.62479 .47483 Mdot
.32788 .60599 Mdot
.62875 .56784 Mdot
.68312 .34795 Mdot
.75458 .63844 Mdot
.40028 .3846 Mdot
.67426 .61476 Mdot
.61772 .43488 Mdot
.29858 .62948 Mdot
.68348 .60019 Mdot
.61744 .42211 Mdot
.66772 .32338 Mdot
.43214 .33686 Mdot
.6616 .48392 Mdot
.63539 .4587 Mdot
.42928 .36668 Mdot
.25239 .42154 Mdot
.29826 .4049 Mdot
.60441 .42265 Mdot
.61532 .57431 Mdot
.63365 .45467 Mdot
.37067 .62479 Mdot
.30144 .40069 Mdot
.62861 .57474 Mdot
.36039 .53987 Mdot
.29817 .41697 Mdot
.63915 .45858 Mdot
.35456 .62415 Mdot
.75531 .6309 Mdot
.282 .6284 Mdot
.54794 .33047 Mdot
.42177 .37298 Mdot
.66686 .61813 Mdot
.68071 .33662 Mdot
.53841 .68305 Mdot
.5608 .67875 Mdot
.46681 .74496 Mdot
.69604 .62318 Mdot
.41051 .3859 Mdot
.33663 .60436 Mdot
.52558 .70263 Mdot
.38226 .60009 Mdot
.6524 .5741 Mdot
.65384 .58479 Mdot
.2716 .39067 Mdot
.68163 .34894 Mdot
.44235 .43751 Mdot
.63081 .56748 Mdot
.73032 .63305 Mdot
.30215 .48417 Mdot
.65404 .35822 Mdot
.2677 .41588 Mdot
.60072 .42334 Mdot
.43669 .36228 Mdot
.31207 .49465 Mdot
.61178 .45185 Mdot
.30241 .63113 Mdot
.41424 .42289 Mdot
.59387 .78582 Mdot
.67226 .6311 Mdot
.3938 .30123 Mdot
.5713 .65753 Mdot
.51873 .69073 Mdot
.68125 .60506 Mdot
.41549 .3774 Mdot
.75428 .63891 Mdot
.68052 .32355 Mdot
.26233 .38899 Mdot
.63537 .46602 Mdot
.37752 .56698 Mdot
.49113 .69541 Mdot
.71451 .30779 Mdot
.53948 .68348 Mdot
.50053 .71475 Mdot
.28495 .67966 Mdot
.42836 .41696 Mdot
.67234 .59317 Mdot
.64702 .58496 Mdot
.59752 .43977 Mdot
.72781 .63958 Mdot
.34875 .59401 Mdot
.59131 .78262 Mdot
.45286 .37665 Mdot
.40819 .40177 Mdot
.64961 .44549 Mdot
.62096 .47106 Mdot
.74635 .63396 Mdot
.41682 .41853 Mdot
.34585 .6356 Mdot
.63583 .56407 Mdot
.65675 .61237 Mdot
.2943 .41422 Mdot
.5212 .69534 Mdot
.70256 .3173 Mdot
.65849 .59171 Mdot
.45938 .28011 Mdot
.43759 .40192 Mdot
.54969 .71668 Mdot
.65937 .59402 Mdot
.84819 .54015 Mdot
.54748 .81195 Mdot
.33493 .64502 Mdot
.44045 .35335 Mdot
.37089 .61737 Mdot
.69386 .33827 Mdot
.66506 .57283 Mdot
.5549 .69121 Mdot
.62211 .44259 Mdot
.59168 .65662 Mdot
.66082 .61318 Mdot
.33932 .62015 Mdot
.42987 .4192 Mdot
.32333 .43332 Mdot
.40597 .3906 Mdot
.53928 .37752 Mdot
.64615 .3463 Mdot
.56094 .67839 Mdot
.51135 .67989 Mdot
.44096 .35425 Mdot
.65378 .35503 Mdot
.68855 .59162 Mdot
.66018 .6038 Mdot
.35115 .74394 Mdot
.60897 .44258 Mdot
.68344 .58341 Mdot
.43071 .3688 Mdot
.68135 .57533 Mdot
.32949 .50989 Mdot
.51646 .69197 Mdot
.41641 .34681 Mdot
.67134 .62139 Mdot
.28668 .64026 Mdot
.39799 .29886 Mdot
.43079 .38053 Mdot
.6044 .45878 Mdot
.52857 .70076 Mdot
.28306 .47957 Mdot
.6403 .61494 Mdot
.4073 .36403 Mdot
.54287 .69787 Mdot
.703 .29022 Mdot
.58792 .69007 Mdot
.35054 .62366 Mdot
.64389 .5946 Mdot
.49238 .69703 Mdot
.62518 .43348 Mdot
.66361 .36601 Mdot
.6751 .58184 Mdot
.66576 .62162 Mdot
.28625 .40893 Mdot
.6109 .4747 Mdot
.68698 .30768 Mdot
.31216 .61308 Mdot
.51656 .71486 Mdot
.28403 .41523 Mdot
.46775 .2804 Mdot
.43294 .44191 Mdot
.50026 .71631 Mdot
.25233 .46047 Mdot
.3917 .39285 Mdot
.39943 .38231 Mdot
.32388 .43089 Mdot
.36775 .62813 Mdot
.31672 .60227 Mdot
.38918 .32782 Mdot
.27743 .40436 Mdot
.41469 .31369 Mdot
.34727 .61765 Mdot
.33698 .62273 Mdot
.41314 .31696 Mdot
.28459 .41099 Mdot
.35041 .52909 Mdot
.52093 .70137 Mdot
.5202 .69127 Mdot
.32726 .61437 Mdot
.27257 .38965 Mdot
.5149 .72289 Mdot
.38189 .59079 Mdot
.65468 .57993 Mdot
.36964 .28459 Mdot
.32679 .62203 Mdot
.3983 .29091 Mdot
.52587 .70805 Mdot
.47778 .27286 Mdot
.36638 .28282 Mdot
.40629 .4314 Mdot
.42397 .41838 Mdot
.65404 .33983 Mdot
.6199 .44716 Mdot
.64684 .44324 Mdot
.49717 .7097 Mdot
.43797 .44359 Mdot
.33909 .63672 Mdot
.43522 .44336 Mdot
.55217 .32275 Mdot
.48506 .2704 Mdot
.44412 .35278 Mdot
.34059 .62605 Mdot
.32928 .63574 Mdot
.70528 .6203 Mdot
.62196 .57603 Mdot
.41305 .32459 Mdot
.52691 .69845 Mdot
.35193 .60639 Mdot
.48466 .69876 Mdot
.67359 .6111 Mdot
.67302 .59119 Mdot
.63036 .42185 Mdot
.64152 .44613 Mdot
.67542 .6042 Mdot
.73075 .61911 Mdot
.46358 .27889 Mdot
.36393 .5452 Mdot
.26819 .46796 Mdot
.52187 .28905 Mdot
.35374 .45784 Mdot
.68214 .33426 Mdot
.70703 .34693 Mdot
.5426 .69483 Mdot
.44632 .37046 Mdot
.40808 .42051 Mdot
.62944 .45926 Mdot
.53956 .70408 Mdot
.66624 .34744 Mdot
.51722 .69126 Mdot
.66566 .36613 Mdot
.63038 .57443 Mdot
.41051 .38117 Mdot
.39878 .41751 Mdot
.51998 .68055 Mdot
.7001 .60776 Mdot
.67643 .6209 Mdot
.67923 .33292 Mdot
.52754 .29422 Mdot
.66853 .61358 Mdot
.32701 .62308 Mdot
.28543 .70596 Mdot
.61279 .4518 Mdot
.41881 .3783 Mdot
.53623 .30443 Mdot
.30197 .40269 Mdot
.63648 .4185 Mdot
.62732 .444 Mdot
.28882 .48881 Mdot
.42993 .43381 Mdot
.3712 .73913 Mdot
.64137 .43227 Mdot
.36441 .59547 Mdot
.67351 .59603 Mdot
.64286 .43004 Mdot
.60422 .41665 Mdot
.67498 .37957 Mdot
.64639 .43499 Mdot
.33325 .59739 Mdot
.37264 .61364 Mdot
.27502 .397 Mdot
.22404 .42547 Mdot
.67255 .36353 Mdot
.66928 .3396 Mdot
.65352 .62136 Mdot
.46465 .73094 Mdot
.3326 .40476 Mdot
.66974 .33171 Mdot
.275 .65607 Mdot
.2652 .3936 Mdot
.28795 .39559 Mdot
.28764 .39856 Mdot
.38079 .60423 Mdot
.38796 .39761 Mdot
.65246 .62256 Mdot
.34128 .61992 Mdot
.27239 .39528 Mdot
.4296 .44679 Mdot
.34584 .63187 Mdot
.50974 .71518 Mdot
.24935 .40563 Mdot
.34023 .60601 Mdot
.35365 .2797 Mdot
.52605 .71139 Mdot
.45253 .38502 Mdot
.76654 .60369 Mdot
.85444 .52356 Mdot
.51107 .69389 Mdot
.6469 .60678 Mdot
.67664 .61734 Mdot
.65624 .60255 Mdot
.3171 .60377 Mdot
.70479 .62798 Mdot
.31322 .63277 Mdot
.74891 .63798 Mdot
.36191 .33864 Mdot
.67823 .35874 Mdot
.72343 .63393 Mdot
.32861 .61329 Mdot
.30308 .49188 Mdot
.59757 .16594 Mdot
.40941 .36219 Mdot
.55764 .69252 Mdot
.68394 .31918 Mdot
.39191 .29172 Mdot
.65804 .34202 Mdot
.68687 .60769 Mdot
.3709 .3286 Mdot
.43706 .40436 Mdot
.38707 .71941 Mdot
.68038 .33915 Mdot
.33542 .623 Mdot
.28898 .40656 Mdot
.61415 .56769 Mdot
.67997 .32501 Mdot
.67887 .34836 Mdot
.43135 .39211 Mdot
.37692 .60746 Mdot
.68835 .61446 Mdot
.5365 .70617 Mdot
.73426 .63016 Mdot
.46282 .30799 Mdot
.43199 .43234 Mdot
.40153 .36774 Mdot
.40277 .29827 Mdot
.75173 .63575 Mdot
.51702 .69924 Mdot
.55451 .34461 Mdot
.63554 .61166 Mdot
.54859 .31491 Mdot
.29141 .64223 Mdot
.72355 .63536 Mdot
.6137 .45598 Mdot
.62188 .41924 Mdot
.4212 .38854 Mdot
.60661 .17255 Mdot
.52209 .39798 Mdot
.52102 .72253 Mdot
.62159 .462 Mdot
.70757 .62943 Mdot
.33021 .5923 Mdot
.72336 .31935 Mdot
.27328 .40299 Mdot
.53517 .7088 Mdot
.66426 .60884 Mdot
.64362 .19838 Mdot
.65484 .33243 Mdot
.39135 .30356 Mdot
.41707 .36311 Mdot
.42256 .38651 Mdot
.50263 .70814 Mdot
.53701 .72102 Mdot
.28202 .47474 Mdot
.60451 .41001 Mdot
.33188 .73945 Mdot
.47353 .70086 Mdot
.65819 .20765 Mdot
.62401 .47292 Mdot
.32258 .63877 Mdot
.64878 .45458 Mdot
.53949 .71869 Mdot
.41836 .42605 Mdot
.37477 .61078 Mdot
.61623 .43411 Mdot
.30167 .66784 Mdot
.29456 .39896 Mdot
.45762 .2789 Mdot
.42325 .40026 Mdot
.35935 .60104 Mdot
.3463 .61994 Mdot
.36553 .62007 Mdot
.61355 .43232 Mdot
.39823 .39323 Mdot
.40424 .37128 Mdot
.39994 .37239 Mdot
.28409 .47397 Mdot
.41257 .38355 Mdot
.30131 .6014 Mdot
.38227 .29397 Mdot
.59876 .79192 Mdot
.39913 .41743 Mdot
.49225 .70139 Mdot
.42298 .39382 Mdot
.65257 .3274 Mdot
.43295 .34288 Mdot
.30158 .41001 Mdot
.51378 .70254 Mdot
.44146 .44631 Mdot
.65252 .31429 Mdot
.42266 .43867 Mdot
.67191 .36716 Mdot
.49714 .79048 Mdot
.55046 .34823 Mdot
.32242 .49954 Mdot
.33286 .60991 Mdot
.65247 .57141 Mdot
.51882 .72686 Mdot
.68822 .59782 Mdot
.29718 .38728 Mdot
.64311 .47339 Mdot
.7757 .63444 Mdot
.47138 .27888 Mdot
.41657 .42463 Mdot
.61159 .46204 Mdot
.35193 .63095 Mdot
.66656 .62978 Mdot
.36907 .47165 Mdot
.26896 .39095 Mdot
.69048 .31598 Mdot
.66166 .33288 Mdot
.61169 .48821 Mdot
.35834 .63399 Mdot
.32715 .51124 Mdot
.50419 .70785 Mdot
.65616 .6078 Mdot
.66908 .37455 Mdot
.27299 .64791 Mdot
.5429 .71926 Mdot
.74305 .63266 Mdot
.49365 .69359 Mdot
.39705 .407 Mdot
.64617 .43853 Mdot
.3576 .53313 Mdot
.6288 .46505 Mdot
.44149 .42811 Mdot
.67007 .62229 Mdot
.61038 .44831 Mdot
.65586 .3532 Mdot
.48972 .70388 Mdot
.68063 .59428 Mdot
.43285 .41709 Mdot
.35068 .61824 Mdot
.31296 .30187 Mdot
.66911 .63647 Mdot
.29785 .41437 Mdot
.29755 .41533 Mdot
.37147 .55295 Mdot
.61305 .41079 Mdot
.58609 .71354 Mdot
.30372 .39969 Mdot
.46343 .73954 Mdot
.6885 .3041 Mdot
.76866 .63787 Mdot
.64928 .56658 Mdot
.66662 .60217 Mdot
.4211 .4325 Mdot
.63486 .56275 Mdot
.41674 .32392 Mdot
.61494 .56827 Mdot
.47689 .77193 Mdot
.39583 .42962 Mdot
.65938 .60003 Mdot
.64263 .43724 Mdot
.43733 .38283 Mdot
.33977 .64056 Mdot
.66389 .56944 Mdot
.40675 .43197 Mdot
.74331 .61665 Mdot
.52233 .68029 Mdot
.61461 .42925 Mdot
.41293 .30122 Mdot
.52139 .70533 Mdot
.32785 .59792 Mdot
.42958 .32349 Mdot
.67422 .32549 Mdot
.32297 .63518 Mdot
.6412 .49178 Mdot
.68001 .35078 Mdot
.38856 .28703 Mdot
.31778 .61982 Mdot
.61637 .45934 Mdot
.66586 .32632 Mdot
.69739 .365 Mdot
.66651 .60422 Mdot
.62072 .59371 Mdot
.63655 .45403 Mdot
.4371 .41344 Mdot
.6959 .6379 Mdot
.50373 .69361 Mdot
.4242 .36949 Mdot
.66756 .61733 Mdot
.61616 .4518 Mdot
.4061 .37292 Mdot
.2771 .40344 Mdot
.30691 .4891 Mdot
.62266 .40626 Mdot
.66786 .36196 Mdot
.36078 .62805 Mdot
.4064 .36362 Mdot
.67904 .36242 Mdot
.71259 .6324 Mdot
.42094 .35358 Mdot
.3606 .61505 Mdot
.27491 .66581 Mdot
.62605 .56788 Mdot
.51692 .71786 Mdot
.6448 .58351 Mdot
.67422 .37058 Mdot
.59411 .16335 Mdot
.63778 .42932 Mdot
.28137 .38598 Mdot
.42586 .33374 Mdot
.65301 .56968 Mdot
.34825 .6232 Mdot
.313 .73636 Mdot
.4332 .3421 Mdot
.42188 .35513 Mdot
.42277 .38138 Mdot
.7403 .63542 Mdot
.33286 .5932 Mdot
.42074 .37935 Mdot
.70251 .34856 Mdot
.40802 .35428 Mdot
.69003 .33167 Mdot
.76639 .61848 Mdot
.61987 .41829 Mdot
.23471 .44906 Mdot
.61618 .43214 Mdot
.65534 .59367 Mdot
.35393 .27839 Mdot
.41004 .30835 Mdot
.66542 .49687 Mdot
.32955 .5967 Mdot
.28386 .65162 Mdot
.67025 .59082 Mdot
.75711 .63271 Mdot
.27031 .40268 Mdot
.28638 .4058 Mdot
.43879 .39064 Mdot
.68675 .60736 Mdot
.63 .59288 Mdot
.64327 .46971 Mdot
.61248 .46242 Mdot
.45294 .38786 Mdot
.63439 .57253 Mdot
.41134 .38127 Mdot
.28966 .39133 Mdot
.53903 .7218 Mdot
.34636 .6392 Mdot
.5578 .69896 Mdot
.55238 .71272 Mdot
.36085 .46312 Mdot
.39758 .33291 Mdot
.54245 .69019 Mdot
.54009 .71231 Mdot
.73812 .63135 Mdot
.46407 .40907 Mdot
.6928 .33884 Mdot
.52356 .3993 Mdot
.68862 .59567 Mdot
.40002 .39807 Mdot
.34488 .59209 Mdot
.63272 .40782 Mdot
.29697 .72588 Mdot
.61457 .2741 Mdot
.26329 .40695 Mdot
.66284 .63056 Mdot
.63582 .45928 Mdot
.63096 .46709 Mdot
.54748 .31838 Mdot
.41319 .38146 Mdot
.62706 .56738 Mdot
.46772 .40644 Mdot
.47285 .70199 Mdot
.74483 .63131 Mdot
.36083 .63279 Mdot
.42012 .39274 Mdot
.30693 .62026 Mdot
.49914 .71865 Mdot
.6872 .35199 Mdot
.65162 .33883 Mdot
.41922 .43669 Mdot
.29961 .4169 Mdot
.46296 .73982 Mdot
.28163 .40185 Mdot
.28015 .4128 Mdot
.63304 .45172 Mdot
.26942 .41723 Mdot
.40935 .3606 Mdot
.3996 .43214 Mdot
.63454 .4165 Mdot
.55663 .708 Mdot
.44343 .45688 Mdot
.6385 .4597 Mdot
.43418 .33725 Mdot
.49557 .717 Mdot
.27814 .40105 Mdot
.49884 .69979 Mdot
.74856 .63276 Mdot
.53364 .68531 Mdot
.66013 .36093 Mdot
.73294 .63266 Mdot
.27336 .47007 Mdot
.33823 .6047 Mdot
.52598 .69367 Mdot
.66917 .32207 Mdot
.49755 .69785 Mdot
.68077 .58864 Mdot
.46998 .70377 Mdot
.38604 .59039 Mdot
.45464 .27915 Mdot
.35274 .45426 Mdot
.47608 .70871 Mdot
.62399 .57633 Mdot
.32717 .61333 Mdot
.46502 .73636 Mdot
.42878 .32826 Mdot
.65393 .33142 Mdot
.42295 .38908 Mdot
.49256 .70869 Mdot
.70173 .63566 Mdot
.32158 .50191 Mdot
.66234 .361 Mdot
.27909 .47866 Mdot
.63901 .5696 Mdot
.39874 .36373 Mdot
.52227 .67655 Mdot
.58173 .7152 Mdot
.51302 .68037 Mdot
.36038 .33174 Mdot
.62893 .47828 Mdot
.60001 .41552 Mdot
.32118 .63116 Mdot
.61542 .4696 Mdot
.70145 .27865 Mdot
.46968 .7552 Mdot
.31864 .64398 Mdot
.71501 .62138 Mdot
.43846 .41185 Mdot
.26182 .4133 Mdot
.63835 .4361 Mdot
.35563 .60353 Mdot
.27468 .41774 Mdot
.62711 .4198 Mdot
.3807 .29289 Mdot
.36413 .62624 Mdot
.68914 .59008 Mdot
.43202 .37183 Mdot
.54796 .68355 Mdot
.48135 .69404 Mdot
.64983 .4534 Mdot
.54527 .68581 Mdot
.43454 .33841 Mdot
.32064 .62208 Mdot
.27432 .39801 Mdot
.68973 .32886 Mdot
.34854 .53629 Mdot
.63825 .4143 Mdot
.65256 .38443 Mdot
.42444 .35932 Mdot
.67211 .59193 Mdot
.59184 .65785 Mdot
.4355 .35276 Mdot
.3439 .61749 Mdot
.42251 .33176 Mdot
.27242 .41778 Mdot
.28414 .40373 Mdot
.65657 .60818 Mdot
.39853 .29581 Mdot
.41142 .38289 Mdot
.53056 .71281 Mdot
.49752 .34665 Mdot
.45003 .4098 Mdot
.70125 .34833 Mdot
.30164 .40963 Mdot
.49249 .68199 Mdot
.36823 .55146 Mdot
.67128 .59369 Mdot
.33429 .63815 Mdot
.38336 .5957 Mdot
.325 .60022 Mdot
.27846 .6273 Mdot
.30356 .40011 Mdot
.35555 .74482 Mdot
.32889 .50983 Mdot
.34156 .44662 Mdot
.31861 .59206 Mdot
.59395 .68674 Mdot
.31742 .64419 Mdot
.32813 .59765 Mdot
.29908 .7105 Mdot
.33714 .59409 Mdot
.43659 .4102 Mdot
.41025 .34423 Mdot
.44891 .36267 Mdot
.74027 .63729 Mdot
.40509 .38994 Mdot
.64364 .42628 Mdot
.68689 .31792 Mdot
.33959 .64692 Mdot
.62399 .44415 Mdot
.39212 .288 Mdot
.6415 .48565 Mdot
.43214 .3944 Mdot
.41062 .37317 Mdot
.28684 .39992 Mdot
.49455 .26892 Mdot
.73994 .63831 Mdot
.36571 .60005 Mdot
.44709 .42328 Mdot
.58759 .69088 Mdot
.43162 .3739 Mdot
.4291 .34011 Mdot
.3933 .41765 Mdot
.67239 .59313 Mdot
.38293 .60261 Mdot
.64131 .46469 Mdot
.34996 .53587 Mdot
.41466 .39742 Mdot
.65595 .45809 Mdot
.70004 .33324 Mdot
.4163 .37634 Mdot
.37456 .60337 Mdot
.27426 .41808 Mdot
.30804 .60446 Mdot
.31644 .62389 Mdot
.42056 .35405 Mdot
.34698 .64302 Mdot
.3135 .60418 Mdot
.28547 .4058 Mdot
.66658 .63235 Mdot
.48346 .7744 Mdot
.4351 .39464 Mdot
.6616 .3588 Mdot
.41959 .42027 Mdot
.69341 .34261 Mdot
.64474 .43233 Mdot
.6343 .45703 Mdot
.50273 .42367 Mdot
.63148 .5899 Mdot
.6934 .31508 Mdot
.7343 .63721 Mdot
.29732 .38176 Mdot
.28242 .66332 Mdot
.46985 .70588 Mdot
.61941 .59303 Mdot
.63316 .4557 Mdot
.53885 .37061 Mdot
.46739 .31342 Mdot
.54482 .68813 Mdot
.29511 .63204 Mdot
.44838 .45674 Mdot
.61073 .46284 Mdot
.69045 .59138 Mdot
.64875 .58507 Mdot
.46864 .75381 Mdot
.29898 .70921 Mdot
.40202 .42121 Mdot
.60954 .45986 Mdot
.26656 .42663 Mdot
.61915 .44695 Mdot
.64441 .46274 Mdot
.65937 .61931 Mdot
.40463 .37875 Mdot
.37991 .28277 Mdot
.67945 .61542 Mdot
.6719 .34554 Mdot
.3025 .63007 Mdot
.67291 .36539 Mdot
.4004 .70421 Mdot
.27962 .47327 Mdot
.67835 .6071 Mdot
.61263 .42417 Mdot
.40259 .39852 Mdot
.37918 .60833 Mdot
.37845 .59717 Mdot
.33746 .64238 Mdot
.68807 .32325 Mdot
.63623 .56522 Mdot
.76597 .63212 Mdot
.43083 .41655 Mdot
.32972 .62756 Mdot
.66552 .37809 Mdot
.42255 .41482 Mdot
.52508 .69621 Mdot
.28118 .41813 Mdot
.33051 .62277 Mdot
.27699 .38649 Mdot
.31997 .6304 Mdot
.65063 .58846 Mdot
.41444 .432 Mdot
.43964 .40352 Mdot
.54991 .35135 Mdot
.6656 .34724 Mdot
.31041 .59965 Mdot
.39945 .33176 Mdot
.43727 .36339 Mdot
.5432 .31368 Mdot
.41412 .37209 Mdot
.34983 .45133 Mdot
.60729 .4677 Mdot
.63229 .42112 Mdot
.42649 .33226 Mdot
.43068 .38318 Mdot
.3763 .59646 Mdot
.33056 .50791 Mdot
.28125 .4721 Mdot
.50311 .71881 Mdot
.3199 .6454 Mdot
.68297 .61413 Mdot
.67075 .57235 Mdot
.7008 .61316 Mdot
.67118 .37266 Mdot
.27472 .40018 Mdot
.40959 .42457 Mdot
.51653 .72179 Mdot
.67129 .32636 Mdot
.33577 .63015 Mdot
.68527 .34898 Mdot
.40081 .30973 Mdot
.65753 .35295 Mdot
.64626 .47103 Mdot
.54252 .81117 Mdot
.29009 .39168 Mdot
.67243 .35424 Mdot
.35275 .63455 Mdot
.52703 .39039 Mdot
.40935 .44641 Mdot
.29957 .48905 Mdot
.69172 .31649 Mdot
.71718 .6318 Mdot
.42453 .36098 Mdot
.3508 .35445 Mdot
.49731 .70581 Mdot
.66288 .36499 Mdot
.49578 .69138 Mdot
.27375 .41358 Mdot
.28481 .65028 Mdot
.33786 .61617 Mdot
.46952 .70872 Mdot
.42617 .33643 Mdot
.66165 .36455 Mdot
.67403 .60592 Mdot
.46429 .40339 Mdot
.74782 .63944 Mdot
.64996 .48776 Mdot
.54897 .32565 Mdot
.64765 .61859 Mdot
.44721 .4444 Mdot
.52148 .68298 Mdot
.44146 .43476 Mdot
.29015 .38879 Mdot
.43864 .3685 Mdot
.68474 .62036 Mdot
.66616 .60131 Mdot
.76674 .63705 Mdot
.43203 .43408 Mdot
.40206 .42942 Mdot
.37994 .57202 Mdot
.63271 .56586 Mdot
.32283 .60298 Mdot
.35954 .60349 Mdot
.64959 .60931 Mdot
.29852 .61301 Mdot
.68004 .34884 Mdot
.3826 .32253 Mdot
.52245 .68321 Mdot
.49947 .68189 Mdot
.67709 .60497 Mdot
.67342 .62638 Mdot
.6733 .5919 Mdot
.27318 .4154 Mdot
.31689 .6174 Mdot
.40122 .35048 Mdot
.42805 .39739 Mdot
.42874 .44417 Mdot
.36677 .62681 Mdot
.43251 .33915 Mdot
.38439 .44062 Mdot
.69291 .32389 Mdot
.65692 .5914 Mdot
.48498 .70226 Mdot
.3137 .30727 Mdot
.52496 .71688 Mdot
.41159 .35212 Mdot
.47545 .76703 Mdot
.29607 .63218 Mdot
.65631 .34127 Mdot
.29951 .40576 Mdot
.65356 .34905 Mdot
.53796 .7223 Mdot
.3767 .57067 Mdot
.38656 .29002 Mdot
.39045 .38205 Mdot
.40318 .30502 Mdot
.77084 .54295 Mdot
.37755 .59074 Mdot
.51991 .71217 Mdot
.29663 .39774 Mdot
.63842 .48804 Mdot
.29655 .4256 Mdot
.41943 .43095 Mdot
.44552 .42659 Mdot
.34591 .36045 Mdot
.41385 .34449 Mdot
.3353 .64541 Mdot
.41178 .32086 Mdot
.60801 .42947 Mdot
.44161 .39347 Mdot
.37045 .73535 Mdot
.41138 .40082 Mdot
.40171 .42385 Mdot
.40241 .41285 Mdot
.4401 .36758 Mdot
.35779 .63859 Mdot
.28572 .39698 Mdot
.5202 .71823 Mdot
.38204 .32066 Mdot
.51901 .68408 Mdot
.67883 .60146 Mdot
.62741 .40606 Mdot
.37647 .61551 Mdot
.65301 .34675 Mdot
.45236 .66371 Mdot
.35294 .35075 Mdot
.70486 .61895 Mdot
.54725 .36203 Mdot
.70022 .31379 Mdot
.64626 .45348 Mdot
.66893 .3709 Mdot
.67138 .62168 Mdot
.51702 .69472 Mdot
.39198 .40001 Mdot
.32502 .60546 Mdot
.34612 .60622 Mdot
.43845 .38188 Mdot
.49226 .781 Mdot
.48176 .69362 Mdot
.72418 .6336 Mdot
.40009 .41696 Mdot
.41667 .34673 Mdot
.3053 .61246 Mdot
.68633 .63354 Mdot
.41526 .31137 Mdot
.67851 .32963 Mdot
.42745 .36865 Mdot
.60597 .44593 Mdot
.40125 .3083 Mdot
.51153 .71914 Mdot
.61446 .45132 Mdot
.40927 .4075 Mdot
.39514 .33278 Mdot
.25853 .39245 Mdot
.59526 .43682 Mdot
.61884 .57611 Mdot
.42073 .35493 Mdot
.4368 .38822 Mdot
.36449 .62618 Mdot
.52696 .68281 Mdot
.34975 .62295 Mdot
.38644 .5827 Mdot
.63395 .45679 Mdot
.5194 .67955 Mdot
.439 .3655 Mdot
.47552 .6938 Mdot
.28459 .41788 Mdot
.43225 .40481 Mdot
.51785 .71273 Mdot
.31325 .62433 Mdot
.33452 .73691 Mdot
.44343 .45729 Mdot
.27868 .41409 Mdot
.41831 .41864 Mdot
.7344 .63053 Mdot
.63346 .40814 Mdot
.39529 .36917 Mdot
.35006 .60594 Mdot
.4243 .41511 Mdot
.51232 .72453 Mdot
.68378 .35558 Mdot
.34458 .61481 Mdot
.65426 .62569 Mdot
.64984 .59531 Mdot
.62222 .57164 Mdot
.64507 .47232 Mdot
.27147 .41793 Mdot
.36305 .62421 Mdot
.3637 .6092 Mdot
.40609 .31081 Mdot
.65561 .59408 Mdot
.68549 .336 Mdot
.44155 .40862 Mdot
.60612 .45235 Mdot
.55678 .68419 Mdot
.23253 .44765 Mdot
.38593 .29712 Mdot
.68074 .37007 Mdot
.48487 .32736 Mdot
.63057 .45069 Mdot
.39902 .38606 Mdot
.662 .3643 Mdot
.65506 .61339 Mdot
.25419 .39711 Mdot
.69381 .30396 Mdot
.71713 .63697 Mdot
.69866 .62582 Mdot
.47671 .69936 Mdot
.61611 .5727 Mdot
.65635 .36141 Mdot
.64097 .43277 Mdot
.34479 .60971 Mdot
.41423 .37749 Mdot
.63742 .44477 Mdot
.65929 .58414 Mdot
.63226 .47595 Mdot
.39471 .40008 Mdot
.30235 .61745 Mdot
.68412 .593 Mdot
.43499 .40591 Mdot
.30202 .39683 Mdot
.30632 .48821 Mdot
.67698 .63386 Mdot
.41781 .32604 Mdot
.72174 .31185 Mdot
.69917 .61668 Mdot
.68289 .62196 Mdot
.42192 .35338 Mdot
.6639 .3184 Mdot
.41827 .39689 Mdot
.52061 .6963 Mdot
.40372 .29162 Mdot
.51974 .68049 Mdot
.54706 .31324 Mdot
.43303 .36579 Mdot
.44704 .36593 Mdot
.28617 .66547 Mdot
.68725 .28828 Mdot
.52396 .28873 Mdot
.40278 .3724 Mdot
.3318 .59062 Mdot
.39915 .29104 Mdot
.45002 .27924 Mdot
.38466 .59119 Mdot
.68864 .35399 Mdot
.49654 .70867 Mdot
.43916 .4149 Mdot
.37701 .73094 Mdot
.68934 .33367 Mdot
.54667 .31597 Mdot
.45062 .38357 Mdot
.33991 .62372 Mdot
.40887 .42634 Mdot
.33774 .61143 Mdot
.41183 .41329 Mdot
.31724 .49623 Mdot
.46496 .74122 Mdot
.36033 .3329 Mdot
.64205 .43715 Mdot
.58175 .71441 Mdot
.35111 .45322 Mdot
.68209 .34371 Mdot
.28558 .38783 Mdot
.62856 .45611 Mdot
.51689 .69119 Mdot
.46913 .71233 Mdot
.67204 .59072 Mdot
.53604 .70194 Mdot
.31729 .63937 Mdot
.70706 .63521 Mdot
.61992 .47223 Mdot
.25025 .41124 Mdot
.65137 .3501 Mdot
.52009 .6794 Mdot
.42091 .37462 Mdot
.43344 .44261 Mdot
.74065 .63561 Mdot
.76806 .61599 Mdot
.28751 .62569 Mdot
.26739 .4682 Mdot
.37725 .57094 Mdot
.66832 .34388 Mdot
.68128 .63517 Mdot
.41167 .42228 Mdot
.4056 .38251 Mdot
.69707 .62829 Mdot
.3799 .60886 Mdot
.67937 .31493 Mdot
.60086 .414 Mdot
.51916 .72262 Mdot
.79563 .61907 Mdot
.34467 .61348 Mdot
.79569 .62063 Mdot
.76352 .63197 Mdot
.29424 .70723 Mdot
.52628 .29166 Mdot
.5198 .70298 Mdot
.79627 .62043 Mdot
.33586 .62599 Mdot
.40388 .35663 Mdot
.62364 .46398 Mdot
.64185 .47528 Mdot
.30376 .62328 Mdot
.68427 .60231 Mdot
.66493 .31688 Mdot
.42196 .43381 Mdot
.69224 .36672 Mdot
.38292 .60069 Mdot
.63125 .57137 Mdot
.61893 .43905 Mdot
.49038 .71122 Mdot
.42108 .41666 Mdot
.68877 .32219 Mdot
.51771 .70326 Mdot
.6221 .41857 Mdot
.37251 .32637 Mdot
.42936 .32327 Mdot
.29988 .41392 Mdot
.49868 .70496 Mdot
.41217 .31374 Mdot
.42947 .37392 Mdot
.52124 .68297 Mdot
.61828 .48319 Mdot
.5842 .71294 Mdot
.41794 .30669 Mdot
.46985 .7553 Mdot
.70956 .62711 Mdot
.61539 .57406 Mdot
.61595 .59134 Mdot
.73825 .63813 Mdot
.52557 .68605 Mdot
.63157 .44041 Mdot
.77777 .6316 Mdot
.52557 .68235 Mdot
.43417 .34912 Mdot
.43873 .41498 Mdot
.46812 .4091 Mdot
.62018 .41871 Mdot
.61996 .42628 Mdot
.3606 .53802 Mdot
.28345 .39293 Mdot
.61991 .4401 Mdot
.41791 .36799 Mdot
.37201 .61072 Mdot
.52597 .70961 Mdot
.71003 .25901 Mdot
.53265 .72181 Mdot
.2509 .4016 Mdot
.69847 .60688 Mdot
.70943 .6345 Mdot
.41573 .37822 Mdot
.55576 .63064 Mdot
.6535 .2045 Mdot
.4387 .41594 Mdot
.29957 .40555 Mdot
.54911 .31581 Mdot
.44112 .39039 Mdot
.30457 .64428 Mdot
.60781 .43941 Mdot
.36992 .61411 Mdot
.5187 .7063 Mdot
.68957 .35172 Mdot
.70601 .28407 Mdot
.49794 .70963 Mdot
.41103 .39745 Mdot
.64527 .42445 Mdot
.42283 .38505 Mdot
.39624 .37922 Mdot
.3971 .32265 Mdot
.68929 .35919 Mdot
.67846 .59525 Mdot
.65283 .34867 Mdot
.33267 .59548 Mdot
.25604 .46217 Mdot
.68424 .34271 Mdot
.4643 .40671 Mdot
.4059 .29875 Mdot
.76356 .61685 Mdot
.34683 .60692 Mdot
.69408 .33924 Mdot
.49371 .70474 Mdot
.45156 .28969 Mdot
.45999 .39545 Mdot
.53538 .70756 Mdot
.39594 .38926 Mdot
.36553 .60537 Mdot
.37238 .55618 Mdot
.48619 .68742 Mdot
.35605 .62057 Mdot
.41314 .31321 Mdot
.27294 .41094 Mdot
.51272 .72001 Mdot
.50649 .2817 Mdot
.5117 .67987 Mdot
.3736 .46853 Mdot
.28768 .41491 Mdot
.34382 .61629 Mdot
.32568 .43536 Mdot
.37308 .57159 Mdot
.62718 .42145 Mdot
.4148 .335 Mdot
.68399 .33818 Mdot
.40583 .30679 Mdot
.65008 .62395 Mdot
.2897 .64329 Mdot
.32833 .61759 Mdot
.56689 .69157 Mdot
.35541 .61805 Mdot
.29428 .62512 Mdot
.47383 .71411 Mdot
.31333 .64403 Mdot
.41371 .39699 Mdot
.22372 .42391 Mdot
.34994 .63355 Mdot
.50791 .70794 Mdot
.6829 .32232 Mdot
.33893 .64344 Mdot
.76026 .6341 Mdot
.43222 .37148 Mdot
.65022 .57462 Mdot
.67384 .3106 Mdot
.3631 .63308 Mdot
.68158 .34081 Mdot
.66501 .58432 Mdot
.70272 .33213 Mdot
.56271 .68507 Mdot
.50613 .67817 Mdot
.60329 .41848 Mdot
.46695 .75169 Mdot
.33521 .59445 Mdot
.70306 .63817 Mdot
.43093 .43799 Mdot
.39874 .41117 Mdot
.64654 .33634 Mdot
.32054 .59317 Mdot
.49517 .78636 Mdot
.62303 .44309 Mdot
.35266 .53158 Mdot
.48546 .70745 Mdot
.72328 .63275 Mdot
.38718 .28479 Mdot
.46623 .71804 Mdot
.6089 .42741 Mdot
.63064 .45309 Mdot
.42286 .38101 Mdot
.5529 .34528 Mdot
.66705 .36685 Mdot
.59455 .6799 Mdot
.25933 .40274 Mdot
.68841 .6298 Mdot
.40383 .40767 Mdot
.26953 .39563 Mdot
.40786 .36195 Mdot
.67021 .37456 Mdot
.5413 .7004 Mdot
.34195 .60442 Mdot
.69308 .34565 Mdot
.64951 .59549 Mdot
.35973 .27808 Mdot
.39611 .36554 Mdot
.41828 .32186 Mdot
.69234 .60718 Mdot
.34707 .59488 Mdot
.67186 .5998 Mdot
.52123 .68328 Mdot
.68449 .34701 Mdot
.2741 .41719 Mdot
.61919 .41917 Mdot
.65334 .56923 Mdot
.52587 .69261 Mdot
.66026 .63049 Mdot
.47518 .70233 Mdot
.63206 .4568 Mdot
.42388 .31892 Mdot
.63175 .56267 Mdot
.6306 .46991 Mdot
.3413 .52189 Mdot
.37356 .33036 Mdot
.29548 .70118 Mdot
.68771 .60587 Mdot
.67084 .49243 Mdot
.51403 .70517 Mdot
.54825 .71155 Mdot
.36211 .46658 Mdot
.60836 .17414 Mdot
.40815 .32868 Mdot
.50696 .79669 Mdot
.52366 .6833 Mdot
.50253 .70072 Mdot
.67082 .59684 Mdot
.31215 .62457 Mdot
.3006 .66874 Mdot
.68988 .59353 Mdot
.53413 .30558 Mdot
.33547 .63009 Mdot
.45018 .36633 Mdot
.64902 .56431 Mdot
.28721 .40408 Mdot
.3215 .50334 Mdot
.69568 .3246 Mdot
.55003 .333 Mdot
.47078 .70632 Mdot
.43279 .42319 Mdot
.35087 .74643 Mdot
.66746 .58992 Mdot
.63385 .47378 Mdot
.57211 .67335 Mdot
.43316 .44373 Mdot
.40058 .40137 Mdot
.42438 .40507 Mdot
.64856 .33357 Mdot
.33442 .51338 Mdot
.42367 .42868 Mdot
.36683 .3322 Mdot
.26192 .41601 Mdot
.62208 .59624 Mdot
.65463 .35344 Mdot
.54472 .36891 Mdot
.7358 .61951 Mdot
.35433 .53237 Mdot
.44345 .43281 Mdot
.54514 .70954 Mdot
.28212 .39327 Mdot
.51206 .71554 Mdot
.4823 .707 Mdot
.80133 .6129 Mdot
.35264 .60492 Mdot
.26241 .40868 Mdot
.63955 .60295 Mdot
.28806 .66717 Mdot
.26801 .39919 Mdot
.26072 .46507 Mdot
.56265 .69982 Mdot
.59288 .1621 Mdot
.55213 .70745 Mdot
.6368 .47704 Mdot
.31383 .64037 Mdot
.34677 .58946 Mdot
.40267 .30945 Mdot
.31894 .60874 Mdot
.73651 .63545 Mdot
.36197 .62498 Mdot
.83406 .49404 Mdot
.37943 .58619 Mdot
.50974 .7033 Mdot
.50101 .68078 Mdot
.28053 .39854 Mdot
.41209 .39237 Mdot
.38026 .28703 Mdot
.62228 .44327 Mdot
.42706 .32546 Mdot
.679 .61583 Mdot
.76316 .63493 Mdot
.53162 .80806 Mdot
.30638 .6414 Mdot
.52676 .68993 Mdot
.40105 .40313 Mdot
.28578 .41561 Mdot
.40992 .34416 Mdot
.46365 .7284 Mdot
.32019 .40085 Mdot
.42783 .39525 Mdot
.27655 .39984 Mdot
.69332 .59825 Mdot
.73076 .62497 Mdot
.29934 .70828 Mdot
.79851 .61558 Mdot
.40678 .37037 Mdot
.66727 .33692 Mdot
.67162 .37334 Mdot
.38859 .40968 Mdot
.59685 .57795 Mdot
.41376 .30949 Mdot
.42222 .37536 Mdot
.35824 .2776 Mdot
.6901 .5903 Mdot
.64402 .48099 Mdot
.65685 .58585 Mdot
.38482 .59746 Mdot
.64673 .43885 Mdot
.67225 .61852 Mdot
.36915 .28321 Mdot
.63575 .44987 Mdot
.58542 .71012 Mdot
.69083 .32995 Mdot
.42254 .36853 Mdot
.37666 .47741 Mdot
.63585 .56451 Mdot
.51432 .69757 Mdot
.32791 .64256 Mdot
.51889 .71738 Mdot
.72686 .62451 Mdot
.53982 .30663 Mdot
.62149 .42191 Mdot
.53909 .71509 Mdot
.29762 .42021 Mdot
.66743 .3328 Mdot
.55682 .70251 Mdot
.27288 .41955 Mdot
.38984 .41566 Mdot
.63132 .19135 Mdot
.41389 .43727 Mdot
.76426 .6354 Mdot
.52583 .68107 Mdot
.63618 .49034 Mdot
.41369 .37885 Mdot
.63885 .57299 Mdot
.70116 .36272 Mdot
.4252 .38628 Mdot
.65003 .62168 Mdot
.43674 .39373 Mdot
.66147 .36326 Mdot
.36784 .62095 Mdot
.39794 .28715 Mdot
.64442 .36038 Mdot
.69136 .34787 Mdot
.34873 .35316 Mdot
.40896 .3428 Mdot
.59664 .64786 Mdot
.34314 .62363 Mdot
.40953 .35434 Mdot
.64279 .36403 Mdot
.30811 .63243 Mdot
.33153 .63797 Mdot
.25259 .39848 Mdot
.51069 .72553 Mdot
.68399 .59844 Mdot
.65997 .34159 Mdot
.74274 .63029 Mdot
.43375 .4199 Mdot
.27376 .38754 Mdot
.69208 .33617 Mdot
.52755 .70081 Mdot
.26702 .4112 Mdot
.52226 .80182 Mdot
.38072 .32115 Mdot
.55942 .70014 Mdot
.44795 .41755 Mdot
.32433 .42263 Mdot
.37877 .60332 Mdot
.35757 .74337 Mdot
.46654 .74238 Mdot
.64796 .58838 Mdot
.6206 .43799 Mdot
.2409 .45433 Mdot
.68871 .32378 Mdot
.3022 .67165 Mdot
.39606 .40515 Mdot
.41083 .41862 Mdot
.37361 .61047 Mdot
.39026 .38006 Mdot
.2994 .63695 Mdot
.75696 .63182 Mdot
.60489 .17084 Mdot
.34144 .60765 Mdot
.333 .61947 Mdot
.2463 .39344 Mdot
.67983 .57398 Mdot
.30136 .62936 Mdot
.43985 .41451 Mdot
.72763 .62544 Mdot
.59589 .43778 Mdot
.67412 .31839 Mdot
.66401 .30986 Mdot
.29275 .63423 Mdot
.45946 .41313 Mdot
.29234 .41712 Mdot
.48388 .44081 Mdot
.48956 .33179 Mdot
.52803 .68582 Mdot
.44291 .41809 Mdot
.6256 .447 Mdot
.66223 .58611 Mdot
.40918 .43638 Mdot
.41767 .36699 Mdot
.33825 .60258 Mdot
.69987 .32557 Mdot
.50253 .68674 Mdot
.63392 .47006 Mdot
.62203 .56684 Mdot
.67452 .33915 Mdot
.29691 .61494 Mdot
.35496 .45789 Mdot
.62928 .41097 Mdot
.61007 .45948 Mdot
.39975 .37865 Mdot
.41828 .35368 Mdot
.61498 .41763 Mdot
.50276 .71215 Mdot
.64715 .58633 Mdot
.64188 .46157 Mdot
.40849 .30819 Mdot
.37764 .27847 Mdot
.40127 .38764 Mdot
.35968 .6234 Mdot
.52127 .69022 Mdot
.62126 .42384 Mdot
.7782 .63401 Mdot
.44222 .40621 Mdot
.45569 .39154 Mdot
.58161 .45974 Mdot
.62837 .44381 Mdot
.29969 .66876 Mdot
.6539 .33898 Mdot
.2875 .41474 Mdot
.36447 .3322 Mdot
.43331 .33683 Mdot
.44255 .432 Mdot
.65966 .61741 Mdot
.48763 .70243 Mdot
.60006 .43416 Mdot
.65773 .59202 Mdot
.33312 .63822 Mdot
.4896 .43614 Mdot
.35653 .60038 Mdot
.36282 .61002 Mdot
.28533 .64189 Mdot
.50092 .71815 Mdot
.23764 .45148 Mdot
.6179 .41397 Mdot
.4016 .42165 Mdot
.54191 .69294 Mdot
.29901 .62792 Mdot
.43921 .35125 Mdot
.29615 .63255 Mdot
.31377 .59723 Mdot
.43391 .3348 Mdot
.2775 .4032 Mdot
.36035 .33949 Mdot
.44526 .44083 Mdot
.65187 .33405 Mdot
.3709 .59906 Mdot
.45764 .39354 Mdot
.41503 .42421 Mdot
.40949 .37562 Mdot
.28235 .39777 Mdot
.68409 .36333 Mdot
.50227 .42504 Mdot
.39626 .40321 Mdot
.55655 .34499 Mdot
.43838 .35124 Mdot
.32456 .59075 Mdot
.56131 .67884 Mdot
.25051 .40125 Mdot
.70695 .62265 Mdot
.37845 .60884 Mdot
.697 .32609 Mdot
.2991 .65423 Mdot
.30386 .41089 Mdot
.50066 .69562 Mdot
.33064 .62273 Mdot
.67849 .58465 Mdot
.51742 .6984 Mdot
.51123 .67992 Mdot
.28618 .39827 Mdot
.64321 .58976 Mdot
.70042 .32744 Mdot
.49225 .6874 Mdot
.30592 .42055 Mdot
.50994 .7022 Mdot
.28597 .69074 Mdot
.42222 .31667 Mdot
.36686 .33025 Mdot
.63386 .43433 Mdot
.60284 .45849 Mdot
.50986 .6825 Mdot
.67981 .32813 Mdot
.26574 .41036 Mdot
.33533 .64278 Mdot
.67305 .32787 Mdot
.3234 .50372 Mdot
.70922 .63376 Mdot
.37192 .55637 Mdot
.74462 .63501 Mdot
.31572 .60877 Mdot
.54949 .32937 Mdot
.69819 .33577 Mdot
.60323 .43627 Mdot
.39347 .30207 Mdot
.6173 .43857 Mdot
.40408 .43006 Mdot
.26368 .40868 Mdot
.41436 .39838 Mdot
.70227 .61381 Mdot
.64914 .33189 Mdot
.35415 .63049 Mdot
.71329 .29864 Mdot
.53066 .7069 Mdot
.41382 .31762 Mdot
.63763 .47221 Mdot
.27911 .41491 Mdot
.29945 .63409 Mdot
.31752 .60036 Mdot
.33182 .50786 Mdot
.70022 .6174 Mdot
.69688 .29416 Mdot
.40234 .39203 Mdot
.71455 .32413 Mdot
.51349 .68139 Mdot
.46733 .75345 Mdot
.66011 .57517 Mdot
.58993 .1633 Mdot
.65734 .5959 Mdot
.59414 .44452 Mdot
.31232 .60854 Mdot
.66822 .35978 Mdot
.40703 .39269 Mdot
.35773 .63626 Mdot
.3015 .6692 Mdot
.67232 .30665 Mdot
.65362 .347 Mdot
.46248 .73582 Mdot
.54239 .68965 Mdot
.61908 .46813 Mdot
.43799 .35142 Mdot
.44317 .35919 Mdot
.42807 .44061 Mdot
.53365 .68948 Mdot
.27716 .40903 Mdot
.56327 .68112 Mdot
.29841 .39916 Mdot
.64265 .36482 Mdot
.68517 .62372 Mdot
.59522 .78759 Mdot
.36907 .62291 Mdot
.49812 .42828 Mdot
.28431 .675 Mdot
.37601 .3288 Mdot
.54052 .70662 Mdot
.6175 .48298 Mdot
.67552 .59626 Mdot
.48262 .64897 Mdot
.68044 .62384 Mdot
.6908 .24259 Mdot
.4683 .41337 Mdot
.57015 .68372 Mdot
.42476 .32661 Mdot
.63844 .59635 Mdot
.44469 .44461 Mdot
.64207 .45776 Mdot
.6456 .4252 Mdot
.30945 .3993 Mdot
.28538 .47574 Mdot
.65092 .33684 Mdot
.40651 .39318 Mdot
.36968 .6119 Mdot
.40638 .39005 Mdot
.40549 .38919 Mdot
.39443 .38312 Mdot
.46879 .70792 Mdot
.42262 .3202 Mdot
.41278 .39432 Mdot
.77068 .63604 Mdot
.59741 .43635 Mdot
.61542 .56617 Mdot
.37993 .5991 Mdot
.67117 .32647 Mdot
.38304 .59586 Mdot
.39519 .2934 Mdot
.54172 .71809 Mdot
.33187 .5112 Mdot
.28463 .40882 Mdot
.29064 .6412 Mdot
.5424 .71413 Mdot
.67975 .31188 Mdot
.62711 .45075 Mdot
.29656 .72356 Mdot
.73436 .63719 Mdot
.6174 .45191 Mdot
.66464 .62972 Mdot
.4428 .44039 Mdot
.34679 .61107 Mdot
.61754 .4401 Mdot
.49297 .6919 Mdot
.66132 .62067 Mdot
.35226 .3503 Mdot
.42801 .41523 Mdot
.68893 .61076 Mdot
.63507 .44139 Mdot
.40576 .306 Mdot
.39957 .29227 Mdot
.63758 .59566 Mdot
.48941 .71636 Mdot
.49949 .68261 Mdot
.68007 .32022 Mdot
.33096 .59253 Mdot
.32858 .59961 Mdot
.52941 .7061 Mdot
.49547 .64367 Mdot
.43553 .41 Mdot
.43229 .41049 Mdot
.38898 .29366 Mdot
.42239 .34087 Mdot
.74041 .63981 Mdot
.61908 .45253 Mdot
.32641 .60823 Mdot
.26328 .40811 Mdot
.26412 .39435 Mdot
.40824 .39723 Mdot
.53293 .29968 Mdot
.68705 .59455 Mdot
.29521 .41292 Mdot
.66271 .36469 Mdot
.30127 .48367 Mdot
.43286 .37518 Mdot
.64566 .37705 Mdot
.31894 .60126 Mdot
.59063 .69683 Mdot
.51268 .69758 Mdot
.63466 .59569 Mdot
.63725 .59966 Mdot
.77278 .54089 Mdot
.37096 .61935 Mdot
.61729 .45081 Mdot
.71557 .63888 Mdot
.64897 .45829 Mdot
.65466 .34661 Mdot
.52961 .38854 Mdot
.73748 .63622 Mdot
.61555 .5675 Mdot
.56879 .68882 Mdot
.44532 .41628 Mdot
.42603 .36716 Mdot
.47146 .75749 Mdot
.41317 .37283 Mdot
.68773 .34183 Mdot
.55096 .69344 Mdot
.33213 .62349 Mdot
.65635 .32614 Mdot
.54805 .70631 Mdot
.32737 .59848 Mdot
.28739 .40045 Mdot
.44036 .3541 Mdot
.33048 .64042 Mdot
.30014 .61388 Mdot
.4368 .40933 Mdot
.80704 .60785 Mdot
.33458 .60512 Mdot
.31987 .64232 Mdot
.29851 .48251 Mdot
.62535 .57226 Mdot
.69383 .36892 Mdot
.51641 .72568 Mdot
.41848 .39847 Mdot
.6917 .62164 Mdot
.66247 .35341 Mdot
.32595 .61856 Mdot
.41062 .36066 Mdot
.43226 .42109 Mdot
.66773 .33337 Mdot
.65994 .36631 Mdot
.67801 .32643 Mdot
.48444 .68898 Mdot
.28695 .40617 Mdot
.30381 .63575 Mdot
.53744 .69915 Mdot
.6958 .32853 Mdot
.65233 .3551 Mdot
.64211 .33299 Mdot
.43593 .40707 Mdot
.65941 .36704 Mdot
.25281 .46066 Mdot
.36599 .28694 Mdot
.64952 .45587 Mdot
.65616 .50107 Mdot
.6296 .55801 Mdot
.60467 .48188 Mdot
.48857 .70235 Mdot
.29649 .40004 Mdot
.67331 .31746 Mdot
.63973 .44816 Mdot
.43099 .41394 Mdot
.44056 .38474 Mdot
.66999 .33484 Mdot
.54032 .30462 Mdot
.34143 .60088 Mdot
.29798 .7034 Mdot
.66879 .32957 Mdot
.63282 .58201 Mdot
.68838 .58829 Mdot
.66436 .60263 Mdot
.40163 .3827 Mdot
.44205 .34601 Mdot
.46222 .30782 Mdot
.34947 .52377 Mdot
.5365 .68675 Mdot
.31213 .60518 Mdot
.29618 .48385 Mdot
.33094 .63731 Mdot
.70309 .62999 Mdot
.68031 .32824 Mdot
.37251 .60583 Mdot
.4913 .68467 Mdot
.49997 .68351 Mdot
.62984 .56411 Mdot
.65475 .59468 Mdot
.67639 .60656 Mdot
.37246 .621 Mdot
.30309 .62028 Mdot
.42967 .32861 Mdot
.35922 .61612 Mdot
.73753 .61749 Mdot
.75695 .63223 Mdot
.63422 .56361 Mdot
.51047 .71059 Mdot
.31675 .62463 Mdot
.43713 .3911 Mdot
.3445 .36179 Mdot
.68779 .58677 Mdot
.69239 .31765 Mdot
.22414 .42476 Mdot
.61088 .17642 Mdot
.27994 .38889 Mdot
.50909 .68981 Mdot
.63802 .43123 Mdot
.42189 .40596 Mdot
.64927 .58495 Mdot
.64005 .49939 Mdot
.6086 .43919 Mdot
.41543 .32162 Mdot
.28902 .38017 Mdot
.51184 .69208 Mdot
.39497 .28827 Mdot
.64086 .45633 Mdot
.26625 .41831 Mdot
.54986 .69522 Mdot
.65115 .56793 Mdot
.61817 .59313 Mdot
.35948 .53638 Mdot
.53339 .38181 Mdot
.62915 .41845 Mdot
.43395 .43565 Mdot
.67048 .61612 Mdot
.6589 .32347 Mdot
.67377 .61412 Mdot
.31628 .5934 Mdot
.62603 .56813 Mdot
.43234 .38076 Mdot
.30408 .63408 Mdot
.50372 .68227 Mdot
.45466 .29437 Mdot
.70903 .28664 Mdot
.6411 .57004 Mdot
.60536 .42671 Mdot
.27498 .39247 Mdot
.25147 .41417 Mdot
.60271 .45842 Mdot
.42647 .3696 Mdot
.51739 .71333 Mdot
.30149 .63794 Mdot
.53046 .6995 Mdot
.70015 .3645 Mdot
.27574 .68433 Mdot
.51189 .69687 Mdot
.4398 .33958 Mdot
.66404 .31716 Mdot
.53747 .30362 Mdot
.43004 .38052 Mdot
.4881 .69646 Mdot
.41856 .32025 Mdot
.37551 .60289 Mdot
.37241 .28293 Mdot
.37964 .32273 Mdot
.52422 .71104 Mdot
.62305 .47504 Mdot
.40669 .29797 Mdot
.70005 .36273 Mdot
.51946 .68379 Mdot
.36712 .2765 Mdot
.62174 .46035 Mdot
.67531 .34512 Mdot
.64904 .33408 Mdot
.67742 .33693 Mdot
.42953 .39973 Mdot
.32346 .42689 Mdot
.69656 .33895 Mdot
.47314 .7167 Mdot
.68792 .35033 Mdot
.60259 .47237 Mdot
.49187 .78467 Mdot
.65634 .36119 Mdot
.41791 .37168 Mdot
.29797 .39896 Mdot
.2956 .39977 Mdot
.65602 .57688 Mdot
.30172 .73062 Mdot
.76977 .6353 Mdot
.41063 .42166 Mdot
.28572 .48084 Mdot
.36588 .62099 Mdot
.60684 .42084 Mdot
.37853 .32394 Mdot
.29797 .41702 Mdot
.32299 .63785 Mdot
.39369 .29689 Mdot
.36546 .54696 Mdot
.64477 .44586 Mdot
.43106 .39981 Mdot
.3768 .60899 Mdot
.28681 .64068 Mdot
.52285 .28866 Mdot
.35472 .53365 Mdot
.31817 .61342 Mdot
.52795 .68284 Mdot
.491 .70435 Mdot
.51942 .71297 Mdot
.65208 .5954 Mdot
.33119 .61901 Mdot
.39403 .42575 Mdot
.64925 .58826 Mdot
.39556 .39219 Mdot
.52687 .70923 Mdot
.37493 .32094 Mdot
.33319 .62021 Mdot
.42647 .3783 Mdot
.45662 .38195 Mdot
.65205 .62229 Mdot
.66839 .33332 Mdot
.27283 .47053 Mdot
.6216 .593 Mdot
.47615 .70011 Mdot
.3204 .59037 Mdot
.60338 .46792 Mdot
.27238 .42177 Mdot
.40926 .35815 Mdot
.39134 .39603 Mdot
.26955 .42078 Mdot
.4667 .41586 Mdot
.61038 .45566 Mdot
.64972 .59566 Mdot
.62412 .58139 Mdot
.43918 .38923 Mdot
.33166 .61424 Mdot
.67737 .37316 Mdot
.64957 .38766 Mdot
.69092 .30215 Mdot
.40329 .29696 Mdot
.36713 .33182 Mdot
.43073 .35257 Mdot
.51123 .41377 Mdot
.66846 .58069 Mdot
.64232 .48079 Mdot
.40073 .30637 Mdot
.68026 .34597 Mdot
.40166 .36074 Mdot
.3809 .59659 Mdot
.32624 .62202 Mdot
.68665 .60352 Mdot
.54796 .68345 Mdot
.63304 .41203 Mdot
.63711 .56252 Mdot
.43859 .38706 Mdot
.26097 .40014 Mdot
.54458 .68555 Mdot
.29794 .60928 Mdot
.67181 .34357 Mdot
.65275 .5841 Mdot
.67626 .35673 Mdot
.35465 .6192 Mdot
.32533 .61774 Mdot
.41197 .34579 Mdot
.70432 .29328 Mdot
.64555 .56721 Mdot
.40264 .38553 Mdot
.68637 .61246 Mdot
.73927 .63403 Mdot
.56283 .68733 Mdot
.40827 .35457 Mdot
.29712 .66784 Mdot
.51882 .71575 Mdot
.40491 .415 Mdot
.29078 .39807 Mdot
.26809 .41155 Mdot
.63579 .59021 Mdot
.69536 .31533 Mdot
.67636 .35018 Mdot
.27486 .66753 Mdot
.32476 .5185 Mdot
.44312 .37756 Mdot
.62894 .57125 Mdot
.31391 .41156 Mdot
.5043 .69679 Mdot
.31286 .61085 Mdot
.56212 .79766 Mdot
.50689 .70656 Mdot
.43746 .39957 Mdot
.68473 .34211 Mdot
.30514 .60542 Mdot
.65004 .45162 Mdot
.45598 .27531 Mdot
.60974 .46809 Mdot
.69847 .29568 Mdot
.63042 .46877 Mdot
.50781 .7933 Mdot
.67759 .60931 Mdot
.29899 .63103 Mdot
.50849 .68886 Mdot
.50208 .69616 Mdot
.68106 .6327 Mdot
.32471 .5023 Mdot
.29672 .70734 Mdot
.2259 .43715 Mdot
.73174 .63683 Mdot
.68352 .33183 Mdot
.37082 .28715 Mdot
.66388 .60106 Mdot
.63886 .61509 Mdot
.46217 .72656 Mdot
.46813 .75497 Mdot
.3146 .62793 Mdot
.42912 .42508 Mdot
.30782 .48898 Mdot
.3954 .40831 Mdot
.53334 .38292 Mdot
.52739 .70364 Mdot
.3133 .61033 Mdot
.46264 .74476 Mdot
.42734 .36017 Mdot
.41416 .41185 Mdot
.74251 .62057 Mdot
.62206 .44678 Mdot
.76597 .61143 Mdot
.39993 .36117 Mdot
.65857 .60628 Mdot
.28089 .65651 Mdot
.64168 .44189 Mdot
.45872 .39735 Mdot
.53353 .68219 Mdot
.62089 .42282 Mdot
.64312 .44612 Mdot
.51124 .41055 Mdot
.37727 .56536 Mdot
.3584 .59592 Mdot
.66673 .37058 Mdot
.46857 .75995 Mdot
.55705 .69594 Mdot
.51873 .8001 Mdot
.43796 .39274 Mdot
.49856 .68045 Mdot
.60343 .41062 Mdot
.40508 .41693 Mdot
.26919 .40004 Mdot
.33152 .50925 Mdot
.43962 .42921 Mdot
.30391 .40405 Mdot
.51201 .70609 Mdot
.59024 .41135 Mdot
.44816 .39527 Mdot
.68803 .60762 Mdot
.31148 .6249 Mdot
.38298 .5743 Mdot
.66335 .32388 Mdot
.46569 .74346 Mdot
.59886 .16703 Mdot
.31267 .61175 Mdot
.42903 .41186 Mdot
.50371 .69903 Mdot
.63576 .42521 Mdot
.63057 .43251 Mdot
.60315 .44993 Mdot
.32468 .62471 Mdot
.64025 .44082 Mdot
.28329 .66781 Mdot
.39405 .29501 Mdot
.49646 .43036 Mdot
.50071 .71694 Mdot
.68394 .33431 Mdot
.70119 .35137 Mdot
.738 .63206 Mdot
.43693 .35154 Mdot
.53365 .3831 Mdot
.27798 .62864 Mdot
.68648 .33772 Mdot
.41607 .402 Mdot
.61064 .45797 Mdot
.35706 .27267 Mdot
.66932 .37884 Mdot
.62581 .46864 Mdot
.25668 .39959 Mdot
.33297 .59511 Mdot
.61499 .44258 Mdot
.3323 .62599 Mdot
.41309 .40064 Mdot
.41088 .31491 Mdot
.34861 .5929 Mdot
.31664 .73554 Mdot
.62682 .40954 Mdot
.54986 .70715 Mdot
.41661 .31655 Mdot
.40787 .36804 Mdot
.4473 .35948 Mdot
.63168 .42399 Mdot
.36528 .73613 Mdot
.68774 .61878 Mdot
.77887 .62962 Mdot
.73895 .6404 Mdot
.46537 .73014 Mdot
.52339 .80528 Mdot
.42873 .35783 Mdot
.32469 .50079 Mdot
.44503 .3539 Mdot
.52485 .71992 Mdot
.45507 .39807 Mdot
.41223 .39255 Mdot
.39943 .38106 Mdot
.68705 .61227 Mdot
.56542 .69547 Mdot
.25165 .39977 Mdot
.40111 .30519 Mdot
.69002 .31072 Mdot
.3486 .62437 Mdot
.42066 .39468 Mdot
.2827 .6189 Mdot
.63325 .58693 Mdot
.28155 .7024 Mdot
.41875 .37324 Mdot
.62228 .4474 Mdot
.49291 .682 Mdot
.51107 .68101 Mdot
.63646 .58438 Mdot
.63607 .58014 Mdot
.40766 .36878 Mdot
.53456 .70621 Mdot
.44427 .36955 Mdot
.40672 .29895 Mdot
.63614 .44389 Mdot
.6582 .34695 Mdot
.39716 .41859 Mdot
.297 .70586 Mdot
.70189 .27921 Mdot
.40162 .38548 Mdot
.36256 .60244 Mdot
.67735 .60359 Mdot
.70273 .63412 Mdot
.32655 .60168 Mdot
.70111 .63485 Mdot
.28291 .70474 Mdot
.32489 .42572 Mdot
.65675 .3535 Mdot
.2457 .42067 Mdot
.69017 .34982 Mdot
.62338 .42229 Mdot
.43598 .40567 Mdot
.59596 .66515 Mdot
.73419 .64009 Mdot
.31372 .30689 Mdot
.52137 .69962 Mdot
.64268 .47497 Mdot
.27987 .40812 Mdot
.67231 .31044 Mdot
.66424 .5885 Mdot
.64501 .42611 Mdot
.40092 .36093 Mdot
.37815 .60999 Mdot
.26668 .38833 Mdot
.64367 .46439 Mdot
.62432 .42439 Mdot
.64276 .42422 Mdot
.5479 .70653 Mdot
.32256 .64553 Mdot
.46224 .73553 Mdot
.64869 .61835 Mdot
.42774 .32495 Mdot
.42732 .41047 Mdot
.31261 .60578 Mdot
.40624 .42624 Mdot
.52584 .71587 Mdot
.2211 .43954 Mdot
.68176 .32574 Mdot
.64348 .43467 Mdot
.4004 .70427 Mdot
.64921 .43888 Mdot
.26083 .41082 Mdot
.25762 .41592 Mdot
.37967 .598 Mdot
.53525 .71901 Mdot
.44539 .43336 Mdot
.61935 .5787 Mdot
.67278 .34596 Mdot
.50502 .68016 Mdot
.2636 .4026 Mdot
.42592 .37371 Mdot
.68473 .33667 Mdot
.46497 .74704 Mdot
.70396 .32557 Mdot
.51541 .68614 Mdot
.62802 .48536 Mdot
.33529 .35814 Mdot
.42451 .38283 Mdot
.62194 .45368 Mdot
.34205 .63794 Mdot
.53713 .68819 Mdot
.336 .512 Mdot
.64457 .44763 Mdot
.74547 .63309 Mdot
.51954 .67963 Mdot
.41014 .35632 Mdot
.29869 .65296 Mdot
.37735 .58256 Mdot
.31393 .64328 Mdot
.80982 .53334 Mdot
.75479 .63686 Mdot
.68 .60723 Mdot
.50859 .71018 Mdot
.69455 .62238 Mdot
.66329 .31737 Mdot
.37668 .29014 Mdot
.63645 .57392 Mdot
.33049 .64711 Mdot
.68214 .6252 Mdot
.44489 .36969 Mdot
.54751 .71088 Mdot
.65257 .56469 Mdot
.41848 .43908 Mdot
.29123 .40199 Mdot
.62077 .42819 Mdot
.69352 .35351 Mdot
.39811 .29791 Mdot
.43297 .42773 Mdot
.62669 .45573 Mdot
.42494 .37857 Mdot
.52748 .71466 Mdot
.45815 .29858 Mdot
.43461 .33858 Mdot
.7293 .63307 Mdot
.29378 .71829 Mdot
.62655 .5848 Mdot
.72187 .30941 Mdot
.39986 .41005 Mdot
.42811 .38483 Mdot
.27079 .40845 Mdot
.22418 .41964 Mdot
.47729 .69593 Mdot
.42462 .31817 Mdot
.70414 .63689 Mdot
.32588 .63477 Mdot
.37165 .61149 Mdot
.52758 .38971 Mdot
.62134 .45623 Mdot
.48447 .70737 Mdot
.43246 .39278 Mdot
.64666 .46442 Mdot
.38999 .32224 Mdot
.47853 .7669 Mdot
.75965 .63668 Mdot
.64001 .6147 Mdot
.37757 .60078 Mdot
.6922 .59855 Mdot
.27148 .4101 Mdot
.63947 .4375 Mdot
.758 .64052 Mdot
.46591 .71467 Mdot
.67262 .34776 Mdot
.39776 .38749 Mdot
.53036 .29505 Mdot
.69209 .59688 Mdot
.64467 .58928 Mdot
.44558 .37262 Mdot
.27416 .64162 Mdot
.67284 .29219 Mdot
.54169 .69571 Mdot
.38122 .59109 Mdot
.37308 .47257 Mdot
.6143 .26334 Mdot
.49518 .70463 Mdot
.26943 .39733 Mdot
.68855 .59035 Mdot
.73975 .55487 Mdot
.32669 .63716 Mdot
.67175 .34631 Mdot
.41362 .43405 Mdot
.3595 .62648 Mdot
.73235 .63835 Mdot
.3049 .64273 Mdot
.62083 .44015 Mdot
.54539 .71254 Mdot
.66774 .58607 Mdot
.56404 .69795 Mdot
.29832 .66749 Mdot
.68327 .32902 Mdot
.54805 .35274 Mdot
.29706 .39511 Mdot
.33047 .50964 Mdot
.28471 .40422 Mdot
.60253 .41648 Mdot
.28834 .40262 Mdot
.38013 .57695 Mdot
.42897 .37903 Mdot
.44935 .40848 Mdot
.70974 .63293 Mdot
.40187 .37513 Mdot
.43995 .41185 Mdot
.45585 .37991 Mdot
.39779 .39626 Mdot
.40481 .38953 Mdot
.41525 .35225 Mdot
.35199 .59923 Mdot
.4169 .33771 Mdot
.29928 .61744 Mdot
.2848 .62479 Mdot
.64968 .61947 Mdot
.65058 .32971 Mdot
.65925 .3644 Mdot
.40581 .32868 Mdot
.5309 .29645 Mdot
.30517 .48748 Mdot
.3313 .63207 Mdot
.51136 .68171 Mdot
.43304 .34049 Mdot
.67804 .29069 Mdot
.40656 .32738 Mdot
.65493 .57608 Mdot
.63082 .57995 Mdot
.41771 .44061 Mdot
.61408 .17899 Mdot
.40287 .35494 Mdot
.3861 .29548 Mdot
.4285 .3979 Mdot
.41142 .35043 Mdot
.6221 .5738 Mdot
.54993 .32898 Mdot
.29339 .417 Mdot
.36989 .55833 Mdot
.67004 .35046 Mdot
.61623 .44442 Mdot
.41075 .3147 Mdot
.36159 .46371 Mdot
.36085 .5387 Mdot
.26944 .40769 Mdot
.65631 .58082 Mdot
.32461 .61283 Mdot
.38953 .29774 Mdot
.53773 .69774 Mdot
.46383 .27715 Mdot
.27748 .68995 Mdot
.54279 .69974 Mdot
.67463 .34472 Mdot
.66828 .57621 Mdot
.4129 .40591 Mdot
.66198 .61466 Mdot
.42524 .35862 Mdot
.38404 .28367 Mdot
.65656 .34966 Mdot
.33714 .64589 Mdot
.5384 .68414 Mdot
.34951 .60183 Mdot
.29161 .7013 Mdot
.49111 .33277 Mdot
.7628 .6237 Mdot
.62924 .5671 Mdot
.71439 .3115 Mdot
.30405 .62475 Mdot
.44226 .40498 Mdot
.24842 .45829 Mdot
.34709 .61383 Mdot
.37943 .60927 Mdot
.46183 .28064 Mdot
.54921 .30846 Mdot
.41561 .35386 Mdot
.35661 .63005 Mdot
.66962 .57627 Mdot
.65659 .35568 Mdot
.4404 .4036 Mdot
.63882 .43433 Mdot
.37308 .60853 Mdot
.68995 .59878 Mdot
.55027 .33772 Mdot
.65535 .60023 Mdot
.31653 .63367 Mdot
.6308 .58812 Mdot
.56333 .68385 Mdot
.63703 .57284 Mdot
.39429 .41296 Mdot
.43077 .38941 Mdot
.38017 .58591 Mdot
.32545 .61762 Mdot
.26118 .41114 Mdot
.40126 .42022 Mdot
.30043 .62925 Mdot
.71608 .62287 Mdot
.35437 .54325 Mdot
.26605 .4115 Mdot
.43411 .41829 Mdot
.69292 .34575 Mdot
.41095 .29939 Mdot
.45136 .28219 Mdot
.4327 .33298 Mdot
.68076 .33104 Mdot
.3814 .61094 Mdot
.43477 .39508 Mdot
.55031 .3192 Mdot
.71002 .63718 Mdot
.43568 .44257 Mdot
.63899 .42743 Mdot
.28553 .42034 Mdot
.49097 .268 Mdot
.26469 .40272 Mdot
.31773 .63997 Mdot
.31035 .63336 Mdot
.71235 .62664 Mdot
.33696 .63814 Mdot
.63824 .42855 Mdot
.48489 .705 Mdot
.28719 .69309 Mdot
.64122 .48053 Mdot
.60994 .4294 Mdot
.61793 .41386 Mdot
.6343 .47214 Mdot
.68265 .28995 Mdot
.74979 .63025 Mdot
.61312 .42876 Mdot
.2972 .62348 Mdot
.59292 .59036 Mdot
.60709 .47194 Mdot
.48424 .70757 Mdot
.64254 .44536 Mdot
.43628 .44183 Mdot
.26814 .40486 Mdot
.33057 .58913 Mdot
.53839 .70096 Mdot
.60956 .40928 Mdot
.44058 .40898 Mdot
.37791 .59599 Mdot
.41837 .39432 Mdot
.69494 .31724 Mdot
.33454 .62128 Mdot
.65317 .58684 Mdot
.6567 .34441 Mdot
.6383 .46381 Mdot
.67189 .32734 Mdot
.6776 .61701 Mdot
.48978 .69102 Mdot
.41873 .43692 Mdot
.70094 .34633 Mdot
.65057 .3305 Mdot
.43224 .44173 Mdot
.30946 .62861 Mdot
.61623 .40776 Mdot
.43393 .42289 Mdot
.27615 .40697 Mdot
.33097 .59818 Mdot
.3608 .74328 Mdot
.40981 .40596 Mdot
.25643 .41267 Mdot
.37467 .56788 Mdot
.64452 .46684 Mdot
.65071 .59035 Mdot
.41072 .36109 Mdot
.52314 .69609 Mdot
.52946 .70702 Mdot
.73382 .63826 Mdot
.36793 .60021 Mdot
.69835 .60767 Mdot
.42594 .4456 Mdot
.64252 .45059 Mdot
.41994 .36544 Mdot
.7407 .6174 Mdot
.3284 .74405 Mdot
.30063 .61116 Mdot
.63944 .61105 Mdot
.38801 .32763 Mdot
.50981 .72522 Mdot
.72227 .63324 Mdot
.37358 .56452 Mdot
.36014 .61335 Mdot
.32511 .60251 Mdot
.66383 .36534 Mdot
.65599 .59369 Mdot
.3327 .59083 Mdot
.32576 .59319 Mdot
.26703 .40961 Mdot
.42186 .44257 Mdot
.37963 .6042 Mdot
.74381 .63812 Mdot
.67483 .35128 Mdot
.68585 .63627 Mdot
.70337 .28005 Mdot
.5418 .69143 Mdot
.45884 .4026 Mdot
.43997 .35615 Mdot
.58847 .16171 Mdot
.3975 .36682 Mdot
.42799 .40249 Mdot
.38467 .5973 Mdot
.69875 .31206 Mdot
.67224 .36213 Mdot
.30444 .62615 Mdot
.2993 .61135 Mdot
.66416 .32982 Mdot
.33905 .38343 Mdot
.50828 .28048 Mdot
.39352 .32967 Mdot
.32175 .64635 Mdot
.29 .69008 Mdot
.52152 .70663 Mdot
.36751 .61645 Mdot
.58069 .71305 Mdot
.6439 .56342 Mdot
.64028 .5696 Mdot
.52346 .6818 Mdot
.41436 .4078 Mdot
.62326 .56896 Mdot
.29351 .41271 Mdot
.58246 .71739 Mdot
.27991 .39297 Mdot
.81291 .60315 Mdot
.40485 .42591 Mdot
.55218 .62861 Mdot
.50096 .78862 Mdot
.26502 .41454 Mdot
.32462 .43183 Mdot
.67078 .33869 Mdot
.38454 .57622 Mdot
.5193 .71954 Mdot
.30907 .48999 Mdot
.42597 .38335 Mdot
.34759 .63868 Mdot
.54498 .68806 Mdot
.34961 .74162 Mdot
.29551 .4174 Mdot
.28207 .41516 Mdot
.24936 .46055 Mdot
.29116 .63606 Mdot
.65125 .59269 Mdot
.38407 .59234 Mdot
.31996 .59269 Mdot
.28883 .39819 Mdot
.68341 .58216 Mdot
.3522 .28254 Mdot
.33162 .64572 Mdot
.68562 .37244 Mdot
.34536 .6232 Mdot
.66207 .33531 Mdot
.33756 .59082 Mdot
.65978 .62552 Mdot
.40269 .40169 Mdot
.65432 .62317 Mdot
.69338 .32163 Mdot
.63082 .59374 Mdot
.53016 .71481 Mdot
.63383 .45698 Mdot
.51978 .71512 Mdot
.37445 .28696 Mdot
.33907 .51393 Mdot
.4877 .70387 Mdot
.49954 .35302 Mdot
.42789 .37472 Mdot
.33904 .59094 Mdot
.6586 .58275 Mdot
.67257 .63524 Mdot
.39968 .29682 Mdot
.31492 .61678 Mdot
.70311 .62737 Mdot
.30408 .42158 Mdot
.59198 .69144 Mdot
.27385 .4207 Mdot
.56644 .8006 Mdot
.30499 .6373 Mdot
.68465 .63786 Mdot
.38761 .29776 Mdot
.29827 .60649 Mdot
.64821 .56577 Mdot
.50733 .686 Mdot
.5225 .69615 Mdot
.39061 .39424 Mdot
.56249 .70075 Mdot
.6547 .57708 Mdot
.27461 .68204 Mdot
.34051 .59229 Mdot
.31986 .742 Mdot
.67869 .3283 Mdot
.68414 .59169 Mdot
.63699 .44195 Mdot
.30366 .66801 Mdot
.69148 .62477 Mdot
.60137 .16813 Mdot
.85567 .48792 Mdot
.70236 .6184 Mdot
.33471 .62271 Mdot
.3218 .62293 Mdot
.27265 .38877 Mdot
.40167 .29978 Mdot
.66626 .58884 Mdot
.59126 .66803 Mdot
.36305 .33635 Mdot
.6319 .45945 Mdot
.77109 .63672 Mdot
.3915 .41919 Mdot
.28187 .40575 Mdot
.53195 .68746 Mdot
.41325 .41235 Mdot
.29351 .62032 Mdot
.40071 .35919 Mdot
.51937 .71752 Mdot
.72608 .62642 Mdot
.42607 .38147 Mdot
.67348 .34467 Mdot
.52006 .68967 Mdot
.52723 .69382 Mdot
.64072 .60613 Mdot
.36811 .59998 Mdot
.31307 .4943 Mdot
.65423 .59431 Mdot
.28985 .40773 Mdot
.62865 .45248 Mdot
.41261 .35455 Mdot
.35097 .64049 Mdot
.36885 .54862 Mdot
.68378 .59054 Mdot
.43571 .43523 Mdot
.50058 .70751 Mdot
.70825 .62092 Mdot
.26775 .39523 Mdot
.64724 .56986 Mdot
.65272 .4823 Mdot
.62178 .56407 Mdot
.28337 .66378 Mdot
.60841 .4184 Mdot
.34387 .64153 Mdot
.61005 .44361 Mdot
.77445 .54096 Mdot
.67545 .34648 Mdot
.62371 .57514 Mdot
.32282 .73742 Mdot
.64325 .61558 Mdot
.39843 .40061 Mdot
.43674 .3934 Mdot
.68431 .61885 Mdot
.68534 .33039 Mdot
.6024 .47858 Mdot
.6999 .3204 Mdot
.3299 .62194 Mdot
.29992 .41647 Mdot
.85355 .52641 Mdot
.62672 .60262 Mdot
.55268 .6896 Mdot
.35652 .539 Mdot
.60805 .43391 Mdot
.53557 .70987 Mdot
.52586 .6914 Mdot
.68434 .31986 Mdot
.63678 .61276 Mdot
.36763 .62459 Mdot
.55604 .70811 Mdot
.2966 .609 Mdot
.5532 .32486 Mdot
.63982 .46908 Mdot
.71327 .33191 Mdot
.61159 .45976 Mdot
.3952 .29883 Mdot
.52791 .72564 Mdot
.41364 .38492 Mdot
.68358 .30627 Mdot
.52664 .68373 Mdot
.69701 .33987 Mdot
.26867 .3961 Mdot
.70123 .63015 Mdot
.28812 .49228 Mdot
.3906 .40028 Mdot
.4082 .42275 Mdot
.54012 .68815 Mdot
.33305 .43948 Mdot
.37385 .56227 Mdot
.34216 .59387 Mdot
.67712 .6088 Mdot
.45447 .27918 Mdot
.4083 .34709 Mdot
.43947 .40822 Mdot
.67519 .62069 Mdot
.62012 .45806 Mdot
.76958 .63231 Mdot
.43408 .41559 Mdot
.51469 .70773 Mdot
.2677 .39947 Mdot
.50002 .721 Mdot
.43604 .44726 Mdot
.40188 .40753 Mdot
.28904 .4139 Mdot
.28268 .40013 Mdot
.51923 .715 Mdot
.62813 .46931 Mdot
.64315 .42818 Mdot
.3225 .64477 Mdot
.41094 .43407 Mdot
.36229 .33884 Mdot
.43209 .39509 Mdot
.67147 .33842 Mdot
.44627 .27993 Mdot
.45092 .38359 Mdot
.41935 .31575 Mdot
.36287 .33338 Mdot
.41272 .39777 Mdot
.54445 .69039 Mdot
.31925 .62344 Mdot
.49932 .70454 Mdot
.55416 .7079 Mdot
.67893 .62566 Mdot
.69521 .344 Mdot
.40606 .36951 Mdot
.67003 .31632 Mdot
.38748 .38984 Mdot
.69827 .36876 Mdot
.40496 .30999 Mdot
.38614 .29861 Mdot
.68111 .37226 Mdot
.43172 .37897 Mdot
.68034 .61359 Mdot
.61522 .57435 Mdot
.29617 .39968 Mdot
.40512 .43178 Mdot
.55795 .68799 Mdot
.48823 .6969 Mdot
.7601 .63501 Mdot
.6131 .58601 Mdot
.69473 .31649 Mdot
.59034 .47864 Mdot
.28787 .40074 Mdot
.39804 .37468 Mdot
.62951 .4671 Mdot
.69392 .61259 Mdot
.61035 .43591 Mdot
.75428 .6328 Mdot
.51659 .72109 Mdot
.503 .69331 Mdot
.40128 .42291 Mdot
.65854 .20784 Mdot
.35076 .61218 Mdot
.3211 .62195 Mdot
.48299 .70299 Mdot
.62628 .5844 Mdot
.62145 .43571 Mdot
.26402 .46551 Mdot
.36097 .54422 Mdot
.66138 .31718 Mdot
.4155 .36321 Mdot
.63713 .56475 Mdot
.29588 .63237 Mdot
.69221 .31536 Mdot
.43557 .33753 Mdot
.69406 .59007 Mdot
.41974 .38706 Mdot
.26541 .42459 Mdot
.30716 .61559 Mdot
.40702 .30635 Mdot
.33428 .64621 Mdot
.52721 .7048 Mdot
.5356 .72234 Mdot
.40329 .41247 Mdot
.28881 .48807 Mdot
.28121 .6539 Mdot
.54405 .71858 Mdot
.66992 .36985 Mdot
.63526 .4497 Mdot
.69645 .34065 Mdot
.68567 .6081 Mdot
.67465 .34616 Mdot
.68903 .62594 Mdot
.71651 .63408 Mdot
.37073 .61768 Mdot
.68491 .33715 Mdot
.46189 .39794 Mdot
.63822 .43574 Mdot
.65461 .3619 Mdot
.41955 .32478 Mdot
.25949 .40509 Mdot
.67481 .59141 Mdot
.6714 .31492 Mdot
.41208 .35849 Mdot
.39771 .70643 Mdot
.54909 .71047 Mdot
.52734 .71651 Mdot
.62026 .43931 Mdot
.67754 .58386 Mdot
.36618 .62802 Mdot
.38616 .32157 Mdot
.28638 .66762 Mdot
.43834 .41907 Mdot
.40352 .377 Mdot
.28178 .66513 Mdot
.36655 .62772 Mdot
.40518 .41257 Mdot
.48671 .43846 Mdot
.6389 .44654 Mdot
.52888 .70029 Mdot
.3309 .61986 Mdot
.32944 .61257 Mdot
.64466 .58197 Mdot
.37505 .60642 Mdot
.7029 .29755 Mdot
.52511 .71855 Mdot
.64987 .44449 Mdot
.50524 .70912 Mdot
.64854 .50087 Mdot
.70087 .62021 Mdot
.34283 .7379 Mdot
.36087 .59457 Mdot
.27133 .41369 Mdot
.37841 .60659 Mdot
.67862 .32563 Mdot
.35702 .62806 Mdot
.36476 .62347 Mdot
.42234 .44121 Mdot
.63273 .46824 Mdot
.61884 .42608 Mdot
.39809 .30312 Mdot
.3499 .61348 Mdot
.4065 .39776 Mdot
.42903 .33358 Mdot
.40646 .42529 Mdot
.40491 .30484 Mdot
.35557 .59787 Mdot
.36005 .46269 Mdot
.37977 .59948 Mdot
.30387 .61967 Mdot
.70205 .27784 Mdot
.63494 .42731 Mdot
.60856 .44548 Mdot
.56534 .66659 Mdot
.43034 .42431 Mdot
.69897 .63457 Mdot
.28768 .40759 Mdot
.63811 .45934 Mdot
.43619 .33156 Mdot
.65211 .33291 Mdot
.42797 .36208 Mdot
.62622 .46243 Mdot
.65735 .5849 Mdot
.27188 .41327 Mdot
.43558 .40654 Mdot
.6159 .44915 Mdot
.37455 .61374 Mdot
.33674 .60127 Mdot
.3499 .52988 Mdot
.67191 .32382 Mdot
.50711 .71581 Mdot
.28486 .40736 Mdot
.67902 .61037 Mdot
.68708 .63425 Mdot
.34476 .64153 Mdot
.63974 .59559 Mdot
.50634 .6914 Mdot
.4297 .41445 Mdot
.52623 .70916 Mdot
.65623 .33038 Mdot
.33468 .62024 Mdot
.27596 .41024 Mdot
.28083 .38574 Mdot
.3102 .6333 Mdot
.64027 .44852 Mdot
.69194 .35019 Mdot
.65029 .61114 Mdot
.30438 .60876 Mdot
.50973 .71849 Mdot
.64048 .58347 Mdot
.27852 .41596 Mdot
.70978 .26459 Mdot
.41226 .41232 Mdot
.39495 .40468 Mdot
.31204 .66474 Mdot
.44391 .43094 Mdot
.64823 .61781 Mdot
.36368 .63323 Mdot
.26279 .40947 Mdot
.36794 .2836 Mdot
.65348 .37428 Mdot
.66504 .4799 Mdot
.4187 .3994 Mdot
.44615 .35592 Mdot
.43825 .36448 Mdot
.31165 .73319 Mdot
.40623 .30337 Mdot
.73244 .62088 Mdot
.7144 .32546 Mdot
.55949 .70183 Mdot
.62659 .45779 Mdot
.67108 .62595 Mdot
.47187 .44916 Mdot
.41145 .41505 Mdot
.33036 .51807 Mdot
.26366 .39935 Mdot
.49601 .69999 Mdot
.34765 .44916 Mdot
.65473 .58089 Mdot
.7799 .63389 Mdot
.42337 .44516 Mdot
.36827 .55306 Mdot
.50947 .63733 Mdot
.63154 .46511 Mdot
.60911 .45201 Mdot
.69135 .31581 Mdot
.72069 .62586 Mdot
.60682 .46415 Mdot
.50162 .70701 Mdot
.4011 .36368 Mdot
.45314 .38883 Mdot
.3722 .73704 Mdot
.29975 .63521 Mdot
.55573 .69769 Mdot
.66083 .49934 Mdot
.41101 .37928 Mdot
.35614 .60774 Mdot
.32735 .63715 Mdot
.65501 .32445 Mdot
.74068 .63122 Mdot
.72423 .63657 Mdot
.62404 .18713 Mdot
.61027 .41139 Mdot
.69304 .61411 Mdot
.60302 .44287 Mdot
.28971 .40962 Mdot
.41071 .31527 Mdot
.55821 .70209 Mdot
.39766 .40276 Mdot
.32847 .51247 Mdot
.31816 .64249 Mdot
.43004 .39466 Mdot
.67062 .35454 Mdot
.22326 .42463 Mdot
.30155 .40008 Mdot
.49124 .43331 Mdot
.67023 .57646 Mdot
.40262 .3816 Mdot
.70181 .29616 Mdot
.64642 .46645 Mdot
.44155 .43725 Mdot
.65209 .59099 Mdot
.60889 .41816 Mdot
.67179 .35746 Mdot
.3143 .64464 Mdot
.62595 .4555 Mdot
.2652 .39663 Mdot
.41992 .35641 Mdot
.67216 .37036 Mdot
.2869 .41307 Mdot
.29303 .69485 Mdot
.61495 .46934 Mdot
.63564 .57068 Mdot
.30782 .6031 Mdot
.40207 .38751 Mdot
.63607 .45088 Mdot
.41666 .36583 Mdot
.2937 .70623 Mdot
.39577 .38919 Mdot
.38371 .71886 Mdot
.31178 .62347 Mdot
.51115 .69923 Mdot
.27095 .40766 Mdot
.41993 .38443 Mdot
.60412 .42925 Mdot
.62286 .43271 Mdot
.44153 .4062 Mdot
.34185 .64278 Mdot
.34618 .63611 Mdot
.36573 .54753 Mdot
.64238 .5779 Mdot
.39509 .33306 Mdot
.51714 .70086 Mdot
.6271 .46735 Mdot
.55749 .70752 Mdot
.44628 .3587 Mdot
.66969 .32736 Mdot
.37389 .73188 Mdot
.42487 .41933 Mdot
.31714 .61358 Mdot
.51112 .28401 Mdot
.3624 .61616 Mdot
.56323 .66713 Mdot
.55673 .69532 Mdot
.34197 .61479 Mdot
.42011 .40204 Mdot
.3926 .29616 Mdot
.45546 .39659 Mdot
.5225 .72571 Mdot
.6457 .43482 Mdot
.65223 .4038 Mdot
.65862 .56848 Mdot
.7151 .27706 Mdot
.51263 .67937 Mdot
.49844 .78895 Mdot
.26605 .41157 Mdot
.3267 .59688 Mdot
.50152 .71693 Mdot
.53121 .69547 Mdot
.66233 .57994 Mdot
.26846 .41081 Mdot
.42268 .3862 Mdot
.63635 .42458 Mdot
.49385 .68642 Mdot
.43867 .38005 Mdot
.26102 .41292 Mdot
.76262 .63264 Mdot
.37803 .56495 Mdot
.35586 .74575 Mdot
.44278 .3512 Mdot
.32921 .50901 Mdot
.59642 .65392 Mdot
.33715 .59158 Mdot
.40685 .39475 Mdot
.63076 .43792 Mdot
.63666 .59282 Mdot
.42533 .41302 Mdot
.63692 .6092 Mdot
.4948 .70773 Mdot
.39246 .71343 Mdot
.44904 .37155 Mdot
.58303 .71496 Mdot
.40482 .40595 Mdot
.29321 .39154 Mdot
.68224 .34816 Mdot
.50361 .72042 Mdot
.36016 .54922 Mdot
.4068 .36279 Mdot
.64659 .59108 Mdot
.65811 .56725 Mdot
.32887 .64266 Mdot
.35273 .5335 Mdot
.33338 .73899 Mdot
.63655 .43892 Mdot
.64815 .60367 Mdot
.63691 .44931 Mdot
.49594 .42916 Mdot
.55609 .70834 Mdot
.67153 .35811 Mdot
.63181 .58909 Mdot
.48444 .68914 Mdot
.25929 .40523 Mdot
.35107 .62404 Mdot
.30596 .66927 Mdot
.29797 .40681 Mdot
.70294 .62895 Mdot
.66257 .3423 Mdot
.4149 .31412 Mdot
.30064 .41297 Mdot
.659 .34844 Mdot
.64933 .57774 Mdot
.34386 .60638 Mdot
.31863 .63677 Mdot
.31874 .62536 Mdot
.45894 .40098 Mdot
.3686 .54714 Mdot
.54344 .36684 Mdot
.44728 .41824 Mdot
.27639 .678 Mdot
.44716 .40426 Mdot
.52566 .71716 Mdot
.31049 .61288 Mdot
.40596 .30564 Mdot
.28598 .42206 Mdot
.42774 .45566 Mdot
.42148 .43337 Mdot
.28109 .39759 Mdot
.43065 .42429 Mdot
.28465 .67774 Mdot
.3782 .56345 Mdot
.41848 .31572 Mdot
.53209 .71791 Mdot
.67101 .33153 Mdot
.31317 .59512 Mdot
.40508 .37776 Mdot
.2872 .68616 Mdot
.4214 .3238 Mdot
.38813 .71405 Mdot
.28047 .39604 Mdot
.72909 .62574 Mdot
.40469 .35861 Mdot
.63256 .5625 Mdot
.29059 .3878 Mdot
.28977 .69228 Mdot
.54817 .70964 Mdot
.30147 .39851 Mdot
.64375 .55912 Mdot
.35072 .45175 Mdot
.63207 .4343 Mdot
.67714 .35086 Mdot
.61072 .41815 Mdot
.52219 .71532 Mdot
.41863 .41894 Mdot
.42294 .36028 Mdot
.44446 .43334 Mdot
.49742 .42767 Mdot
.63658 .43013 Mdot
.67813 .37429 Mdot
.28514 .69051 Mdot
.4336 .3747 Mdot
.61963 .57017 Mdot
.34018 .59664 Mdot
.43517 .45693 Mdot
.4643 .41474 Mdot
.25467 .40465 Mdot
.34808 .61498 Mdot
.36855 .60055 Mdot
.67596 .29129 Mdot
.6796 .33806 Mdot
.40348 .4184 Mdot
.68927 .36779 Mdot
.28274 .40913 Mdot
.51087 .71278 Mdot
.45029 .40283 Mdot
.70138 .62109 Mdot
.38966 .28924 Mdot
.64717 .57693 Mdot
.4117 .42877 Mdot
.34391 .62441 Mdot
.52365 .72474 Mdot
.71415 .63761 Mdot
.74813 .63993 Mdot
.5473 .36172 Mdot
.7241 .63969 Mdot
.67468 .31938 Mdot
.6815 .32137 Mdot
.50672 .72084 Mdot
.42578 .40307 Mdot
.40483 .29996 Mdot
.23453 .41169 Mdot
.42537 .42515 Mdot
.41637 .40841 Mdot
.46773 .70868 Mdot
.51944 .68044 Mdot
.62915 .58437 Mdot
.40686 .41387 Mdot
.43118 .36462 Mdot
.34216 .62023 Mdot
.69632 .31199 Mdot
.66792 .62249 Mdot
.69343 .31706 Mdot
.6646 .612 Mdot
.49212 .26819 Mdot
.64174 .46389 Mdot
.67584 .32223 Mdot
.51974 .67842 Mdot
.3201 .61101 Mdot
.6374 .42873 Mdot
.67576 .59893 Mdot
.64387 .59976 Mdot
.38805 .40211 Mdot
.2996 .63712 Mdot
.34359 .59378 Mdot
.66821 .32641 Mdot
.4861 .69833 Mdot
.29432 .41212 Mdot
.61122 .45877 Mdot
.67937 .47634 Mdot
.6436 .59337 Mdot
.27801 .68897 Mdot
.30666 .66628 Mdot
.41077 .373 Mdot
.3375 .60195 Mdot
.4185 .37736 Mdot
.38377 .59522 Mdot
.28753 .61993 Mdot
.43582 .44768 Mdot
.34837 .52629 Mdot
.69517 .61638 Mdot
.83937 .55768 Mdot
.26534 .41759 Mdot
.50422 .67771 Mdot
.28737 .40868 Mdot
.77313 .63302 Mdot
.5146 .28578 Mdot
.43368 .37778 Mdot
.40394 .37783 Mdot
.66282 .22065 Mdot
.42174 .34194 Mdot
.61171 .44923 Mdot
.63259 .43384 Mdot
.34396 .60311 Mdot
.61155 .41886 Mdot
.39698 .29951 Mdot
.68841 .33663 Mdot
.67784 .6083 Mdot
.54834 .31649 Mdot
.66327 .33569 Mdot
.31476 .64033 Mdot
.29209 .41701 Mdot
.2749 .65184 Mdot
.61709 .56812 Mdot
.61979 .45039 Mdot
.49482 .70515 Mdot
.40376 .29217 Mdot
.64942 .58429 Mdot
.48719 .6894 Mdot
.42737 .33845 Mdot
.74186 .62249 Mdot
.53058 .71781 Mdot
.84616 .54307 Mdot
.53674 .69212 Mdot
.48426 .70423 Mdot
.40112 .31121 Mdot
.68874 .33709 Mdot
.60516 .42323 Mdot
.70046 .36288 Mdot
.54595 .70764 Mdot
.78849 .62366 Mdot
.67397 .58283 Mdot
.38298 .28432 Mdot
.38519 .57609 Mdot
.64292 .44389 Mdot
.40856 .40733 Mdot
.53633 .68856 Mdot
.38837 .38449 Mdot
.60641 .42203 Mdot
.51041 .69268 Mdot
.28878 .38725 Mdot
.44596 .27697 Mdot
.63344 .44391 Mdot
.62226 .42292 Mdot
.68414 .31233 Mdot
.73619 .63508 Mdot
.35145 .59443 Mdot
.64888 .33641 Mdot
.37826 .31776 Mdot
.40193 .42013 Mdot
.51782 .71547 Mdot
.62519 .45507 Mdot
.52068 .69892 Mdot
.68009 .35615 Mdot
.66786 .37122 Mdot
.31358 .64359 Mdot
.36685 .54978 Mdot
.63548 .48774 Mdot
.35474 .34489 Mdot
.44677 .38735 Mdot
.33292 .5192 Mdot
.36429 .6037 Mdot
.32473 .42954 Mdot
.68421 .35865 Mdot
.68314 .31097 Mdot
.29292 .39038 Mdot
.427 .32797 Mdot
.27511 .39878 Mdot
.43997 .35103 Mdot
.75296 .59686 Mdot
.27202 .40974 Mdot
.65013 .61015 Mdot
.43916 .34811 Mdot
.47316 .76653 Mdot
.29337 .39544 Mdot
.40856 .37091 Mdot
.66159 .60229 Mdot
.43463 .44078 Mdot
.68836 .59879 Mdot
.40263 .39646 Mdot
.74216 .61684 Mdot
.67859 .61032 Mdot
.60256 .49493 Mdot
.48118 .32505 Mdot
.61141 .44244 Mdot
.67056 .36434 Mdot
.70176 .34316 Mdot
.55054 .34004 Mdot
.34202 .6082 Mdot
.22625 .42008 Mdot
.40836 .37262 Mdot
.66387 .57948 Mdot
.49242 .70507 Mdot
.26646 .38761 Mdot
.39332 .40311 Mdot
.29486 .40598 Mdot
.35385 .62258 Mdot
.68068 .58482 Mdot
.68554 .35042 Mdot
.62493 .59523 Mdot
.76782 .63613 Mdot
.6992 .61629 Mdot
.50941 .41141 Mdot
.25986 .39665 Mdot
.70167 .29675 Mdot
.34329 .51871 Mdot
.59388 .45624 Mdot
.34226 .63662 Mdot
.6282 .45668 Mdot
.69369 .32618 Mdot
.45565 .29427 Mdot
.34156 .59547 Mdot
.67506 .62042 Mdot
.41895 .38675 Mdot
.63045 .47164 Mdot
.70095 .36289 Mdot
.29303 .61858 Mdot
.67469 .37125 Mdot
.67199 .60187 Mdot
.63203 .44998 Mdot
.39233 .33487 Mdot
.3708 .47191 Mdot
.37681 .28148 Mdot
.41763 .38161 Mdot
.66418 .33057 Mdot
.29866 .63623 Mdot
.29567 .4057 Mdot
.52145 .68419 Mdot
.40069 .29936 Mdot
.40925 .40969 Mdot
.58527 .71373 Mdot
.34442 .62581 Mdot
.68028 .32928 Mdot
.53764 .68991 Mdot
.67816 .33905 Mdot
.60934 .44772 Mdot
.38323 .59679 Mdot
.60949 .4528 Mdot
.26446 .39984 Mdot
.49888 .71258 Mdot
.3439 .59424 Mdot
.76154 .63047 Mdot
.61524 .40898 Mdot
.68523 .61732 Mdot
.45336 .29245 Mdot
.3352 .64251 Mdot
.46573 .73966 Mdot
.62549 .59585 Mdot
.47578 .72339 Mdot
.41044 .30136 Mdot
.51417 .68938 Mdot
.40726 .3731 Mdot
.32574 .62986 Mdot
.51817 .7267 Mdot
.74406 .63926 Mdot
.44976 .36494 Mdot
.63052 .47987 Mdot
.43143 .37953 Mdot
.30043 .72953 Mdot
.48983 .77879 Mdot
.38123 .58502 Mdot
.50716 .6796 Mdot
.41559 .42684 Mdot
.63848 .44144 Mdot
.41171 .43542 Mdot
.54893 .70357 Mdot
.4691 .70528 Mdot
.67092 .63335 Mdot
.41515 .38671 Mdot
.67342 .33822 Mdot
.69064 .63026 Mdot
.67279 .57422 Mdot
.62938 .5787 Mdot
.36213 .54973 Mdot
.64485 .45383 Mdot
.63593 .43639 Mdot
.52077 .28874 Mdot
.52271 .69815 Mdot
.6116 .44417 Mdot
.42497 .36024 Mdot
.54301 .36551 Mdot
.31531 .62413 Mdot
.66693 .59818 Mdot
.41034 .42463 Mdot
.2708 .4206 Mdot
.61547 .44314 Mdot
.65538 .59501 Mdot
.3702 .62017 Mdot
.60278 .59002 Mdot
.42567 .41503 Mdot
.26496 .4067 Mdot
.30612 .63505 Mdot
.30165 .70697 Mdot
.39072 .32087 Mdot
.42014 .37839 Mdot
.52979 .70714 Mdot
.34797 .7006 Mdot
.42381 .3381 Mdot
.37466 .51215 Mdot
.64234 .43082 Mdot
.575 .57554 Mdot
.37065 .67442 Mdot
.23978 .40063 Mdot
.47271 .6007 Mdot
.31634 .30686 Mdot
.51073 .6128 Mdot
.75518 .58155 Mdot
.43762 .59386 Mdot
.85023 .52437 Mdot
.57187 .71396 Mdot
.25166 .41808 Mdot
.58944 .18115 Mdot
.50881 .78415 Mdot
.43829 .64949 Mdot
.55088 .75613 Mdot
.56857 .46813 Mdot
.76433 .6286 Mdot
.74819 .62688 Mdot
.74807 .57161 Mdot
.39222 .41978 Mdot
.42555 .66651 Mdot
.29988 .42812 Mdot
.49311 .75602 Mdot
.7137 .59828 Mdot
.30121 .4173 Mdot
.64708 .23694 Mdot
.58006 .68312 Mdot
.6157 .31855 Mdot
.29886 .47884 Mdot
.66906 .53926 Mdot
.33817 .35657 Mdot
.57988 .36496 Mdot
.233 .40801 Mdot
.53928 .59034 Mdot
.56775 .70412 Mdot
.38018 .62321 Mdot
.58392 .67123 Mdot
.66356 .617 Mdot
.29572 .63641 Mdot
.55264 .7816 Mdot
.65245 .27106 Mdot
.53171 .7512 Mdot
.47139 .60181 Mdot
.60512 .45658 Mdot
.57671 .5659 Mdot
.39807 .33786 Mdot
.37065 .58757 Mdot
.69112 .56051 Mdot
.72828 .59776 Mdot
.35666 .6556 Mdot
.6704 .56284 Mdot
.46432 .30276 Mdot
.43734 .65197 Mdot
.36414 .68012 Mdot
.57468 .47192 Mdot
.60684 .50014 Mdot
.36532 .60497 Mdot
.60422 .22182 Mdot
.53986 .44235 Mdot
.373 .31368 Mdot
.67436 .55895 Mdot
.3638 .63854 Mdot
.30943 .4936 Mdot
.34882 .53844 Mdot
.81659 .58405 Mdot
.6778 .27238 Mdot
.77501 .57588 Mdot
.54811 .43828 Mdot
.5464 .74096 Mdot
.50656 .35096 Mdot
.57034 .63095 Mdot
.79086 .56762 Mdot
.31395 .70242 Mdot
.62048 .20685 Mdot
.52895 .52631 Mdot
.69217 .25913 Mdot
.35556 .67064 Mdot
.5825 .48639 Mdot
.4008 .61895 Mdot
.59857 .54689 Mdot
.48396 .27928 Mdot
.67316 .25388 Mdot
.43346 .66218 Mdot
.64315 .40566 Mdot
.50912 .78232 Mdot
.32486 .6894 Mdot
.71718 .59182 Mdot
.64184 .41726 Mdot
.41616 .48148 Mdot
.67393 .23963 Mdot
.4838 .5931 Mdot
.6249 .25856 Mdot
.68235 .54573 Mdot
.56583 .78532 Mdot
.68423 .58052 Mdot
.51781 .72975 Mdot
.63206 .30209 Mdot
.32738 .63265 Mdot
.82699 .57399 Mdot
.44428 .63141 Mdot
.50383 .63454 Mdot
.66671 .23594 Mdot
.80708 .59599 Mdot
.58998 .53502 Mdot
.59144 .48679 Mdot
.58038 .66759 Mdot
.54702 .61136 Mdot
.47584 .75465 Mdot
.66047 .46905 Mdot
.35058 .72267 Mdot
.62601 .29944 Mdot
.79401 .59826 Mdot
.60851 .18839 Mdot
.37779 .32436 Mdot
.56405 .39111 Mdot
.32149 .66298 Mdot
.46487 .52921 Mdot
.48388 .75719 Mdot
.69803 .26063 Mdot
.30705 .4111 Mdot
.32926 .70827 Mdot
.75373 .57145 Mdot
.44347 .45198 Mdot
.40578 .69538 Mdot
.55592 .76502 Mdot
.60644 .57754 Mdot
.3418 .68148 Mdot
.69815 .28482 Mdot
.51868 .30881 Mdot
.37474 .48956 Mdot
.69888 .5852 Mdot
.39292 .31513 Mdot
.3968 .5092 Mdot
.82903 .50696 Mdot
.41879 .68165 Mdot
.40465 .48377 Mdot
.31341 .66871 Mdot
.78945 .56496 Mdot
.76265 .57978 Mdot
.3722 .6981 Mdot
.67171 .48506 Mdot
.63063 .26209 Mdot
.41038 .52336 Mdot
.58373 .55078 Mdot
.29661 .4279 Mdot
.31358 .42053 Mdot
.70379 .55659 Mdot
.52096 .44058 Mdot
.63313 .36983 Mdot
.55504 .76029 Mdot
.34164 .52485 Mdot
.59099 .37298 Mdot
.35598 .50823 Mdot
.29705 .69239 Mdot
.4646 .48459 Mdot
.57324 .67744 Mdot
.46329 .47604 Mdot
.65246 .23479 Mdot
.6541 .61976 Mdot
.79329 .57243 Mdot
.53714 .75102 Mdot
.71796 .59771 Mdot
.4816 .64141 Mdot
.48226 .64197 Mdot
.62458 .32717 Mdot
.52812 .78791 Mdot
.59569 .50771 Mdot
.37536 .58578 Mdot
.4677 .62931 Mdot
.34068 .50624 Mdot
.50559 .38108 Mdot
.39238 .55421 Mdot
.69006 .35489 Mdot
.46004 .46424 Mdot
.3368 .68264 Mdot
.66344 .49645 Mdot
.50529 .40246 Mdot
.34185 .31954 Mdot
.64391 .48156 Mdot
.51696 .33291 Mdot
.49558 .27143 Mdot
.55562 .53716 Mdot
.80455 .58045 Mdot
.40271 .53416 Mdot
.52114 .33471 Mdot
.49076 .75994 Mdot
.22939 .42208 Mdot
.69501 .25771 Mdot
.65399 .30468 Mdot
.38104 .68192 Mdot
.36747 .70677 Mdot
.57251 .8122 Mdot
.46592 .7367 Mdot
.83864 .50039 Mdot
.53776 .75074 Mdot
.22791 .44752 Mdot
.64367 .61305 Mdot
.57824 .50104 Mdot
.39493 .61702 Mdot
.33797 .32752 Mdot
.6574 .2504 Mdot
.56262 .55325 Mdot
.6516 .35514 Mdot
.4002 .64884 Mdot
.37824 .50721 Mdot
.63228 .2407 Mdot
.61529 .21878 Mdot
.61296 .22683 Mdot
.5482 .78477 Mdot
.50167 .43987 Mdot
.6558 .22665 Mdot
.53588 .3822 Mdot
.53183 .48411 Mdot
.2455 .39564 Mdot
.36035 .30986 Mdot
.8378 .53327 Mdot
.5607 .41772 Mdot
.55348 .61051 Mdot
.35501 .65637 Mdot
.67944 .23542 Mdot
.51372 .27727 Mdot
.58917 .57189 Mdot
.60619 .33036 Mdot
.61906 .39517 Mdot
.59115 .36377 Mdot
.62464 .33709 Mdot
.50809 .58967 Mdot
.55498 .76451 Mdot
.69188 .23506 Mdot
.77257 .55974 Mdot
.509 .75719 Mdot
.30548 .68641 Mdot
.83638 .54672 Mdot
.39526 .69863 Mdot
.52195 .73294 Mdot
.37165 .66308 Mdot
.27573 .44838 Mdot
.42196 .56858 Mdot
.54785 .59222 Mdot
.38864 .4571 Mdot
.59839 .38648 Mdot
.63368 .59898 Mdot
.80876 .54305 Mdot
.4147 .55634 Mdot
.52542 .48141 Mdot
.52917 .33254 Mdot
.79537 .61252 Mdot
.53205 .56349 Mdot
.48298 .41176 Mdot
.40276 .53188 Mdot
.41098 .66861 Mdot
.41033 .69021 Mdot
.3188 .47224 Mdot
.44252 .38015 Mdot
.65901 .26553 Mdot
.84988 .49516 Mdot
.6312 .32486 Mdot
.39791 .68528 Mdot
.57822 .78257 Mdot
.5744 .70795 Mdot
.528 .36551 Mdot
.34221 .29267 Mdot
.49183 .56642 Mdot
.32483 .2909 Mdot
.48247 .71469 Mdot
.30952 .49415 Mdot
.46436 .64868 Mdot
.53363 .3786 Mdot
.4064 .59351 Mdot
.48716 .63283 Mdot
.4861 .4273 Mdot
.31692 .67321 Mdot
.30496 .71875 Mdot
.78896 .56124 Mdot
.64969 .61546 Mdot
.67429 .47135 Mdot
.52678 .45848 Mdot
.68631 .30591 Mdot
.6571 .43529 Mdot
.58369 .54232 Mdot
.3292 .50098 Mdot
.58497 .78426 Mdot
.61893 .36326 Mdot
.83747 .55734 Mdot
.62599 .33726 Mdot
.77206 .58018 Mdot
.66012 .55395 Mdot
.50229 .30999 Mdot
.51585 .74326 Mdot
.55822 .73619 Mdot
.48583 .29674 Mdot
.7814 .5992 Mdot
.58742 .5623 Mdot
.36993 .58306 Mdot
.43346 .36122 Mdot
.50551 .28189 Mdot
.57713 .36679 Mdot
.50331 .32445 Mdot
.34232 .47334 Mdot
.3404 .64901 Mdot
.55122 .39188 Mdot
.58461 .59711 Mdot
.28261 .38461 Mdot
.36043 .70867 Mdot
.51273 .72753 Mdot
.30592 .68198 Mdot
.79746 .61496 Mdot
.57974 .80057 Mdot
.50527 .62283 Mdot
.51828 .38115 Mdot
.62128 .29711 Mdot
.52359 .37992 Mdot
.36673 .71091 Mdot
.2889 .4485 Mdot
.47039 .6522 Mdot
.35509 .66133 Mdot
.54417 .51133 Mdot
.5699 .64314 Mdot
.41648 .64176 Mdot
.3175 .6782 Mdot
.31637 .41097 Mdot
.65802 .28561 Mdot
.38037 .44897 Mdot
.52595 .59543 Mdot
.38512 .31726 Mdot
.44853 .5348 Mdot
.45109 .63044 Mdot
.54165 .3358 Mdot
.49428 .60969 Mdot
.60479 .23111 Mdot
.3145 .50579 Mdot
.5718 .61178 Mdot
.54929 .41497 Mdot
.53227 .3781 Mdot
.30022 .47941 Mdot
.32724 .69094 Mdot
.55416 .76007 Mdot
.38501 .4423 Mdot
.68216 .27575 Mdot
.51704 .51572 Mdot
.5233 .33114 Mdot
.42108 .50803 Mdot
.39257 .4505 Mdot
.65578 .47354 Mdot
.62362 .33461 Mdot
.5768 .57952 Mdot
.58368 .17648 Mdot
.76952 .60107 Mdot
.3802 .53118 Mdot
.39897 .62295 Mdot
.79797 .56189 Mdot
.42231 .62506 Mdot
.44325 .60474 Mdot
.41842 .53854 Mdot
.82546 .55004 Mdot
.56242 .5726 Mdot
.58368 .58722 Mdot
.31087 .72252 Mdot
.64015 .22575 Mdot
.53646 .60652 Mdot
.53155 .73013 Mdot
.56578 .40515 Mdot
.39407 .39486 Mdot
.37215 .52247 Mdot
.34826 .74015 Mdot
.46591 .50004 Mdot
.52548 .61641 Mdot
.85357 .51274 Mdot
.56838 .55017 Mdot
.40402 .54149 Mdot
.5877 .17517 Mdot
.58794 .16768 Mdot
.36568 .5272 Mdot
.70309 .26179 Mdot
.58709 .58457 Mdot
.37744 .70704 Mdot
.56755 .71177 Mdot
.50207 .36458 Mdot
.33217 .51694 Mdot
.67267 .28497 Mdot
.5574 .81371 Mdot
.49263 .76257 Mdot
.38753 .64573 Mdot
.69758 .276 Mdot
.52485 .49147 Mdot
.59111 .51127 Mdot
.57167 .77635 Mdot
.77358 .62405 Mdot
.81322 .57901 Mdot
.32266 .46547 Mdot
.71822 .57557 Mdot
.71996 .55514 Mdot
.43371 .67016 Mdot
.84106 .54619 Mdot
.62581 .39872 Mdot
.22776 .41728 Mdot
.78924 .5668 Mdot
.32532 .72534 Mdot
.72206 .59336 Mdot
.45279 .62601 Mdot
.57709 .54583 Mdot
.48069 .4785 Mdot
.35984 .71964 Mdot
.54723 .77758 Mdot
.55651 .50688 Mdot
.45732 .28847 Mdot
.3144 .68918 Mdot
.31669 .70697 Mdot
.25798 .43599 Mdot
.58344 .52909 Mdot
.59457 .20907 Mdot
.56404 .67822 Mdot
.48309 .31291 Mdot
.37051 .58565 Mdot
.55779 .33244 Mdot
.59272 .50723 Mdot
.43236 .32668 Mdot
.65449 .28653 Mdot
.5992 .5119 Mdot
.60467 .21147 Mdot
.82869 .58073 Mdot
.60126 .32183 Mdot
.57448 .63714 Mdot
.65827 .43264 Mdot
.83599 .52944 Mdot
.83662 .51372 Mdot
.60328 .20066 Mdot
.74147 .56077 Mdot
.48105 .29363 Mdot
.56312 .51952 Mdot
.50276 .37284 Mdot
.49812 .42145 Mdot
.7983 .55773 Mdot
.29709 .48116 Mdot
.58582 .36149 Mdot
.40523 .65953 Mdot
.78768 .60426 Mdot
.53879 .40387 Mdot
.55545 .33806 Mdot
.45023 .50703 Mdot
.60334 .50235 Mdot
.6968 .60035 Mdot
.64865 .20727 Mdot
.37085 .7005 Mdot
.60069 .365 Mdot
.33649 .70818 Mdot
.29971 .67344 Mdot
.74781 .58275 Mdot
.38411 .66981 Mdot
.72054 .33615 Mdot
.66444 .54637 Mdot
.65483 .30943 Mdot
.59333 .55249 Mdot
.30898 .73308 Mdot
.45048 .44943 Mdot
.63064 .31647 Mdot
.59289 .37466 Mdot
.59611 .19203 Mdot
.55418 .39432 Mdot
.45591 .46758 Mdot
.59921 .22004 Mdot
.40287 .66892 Mdot
.49841 .3247 Mdot
.63483 .23611 Mdot
.39051 .57998 Mdot
.67588 .27229 Mdot
.50882 .68691 Mdot
.56629 .47083 Mdot
.33841 .73556 Mdot
.51223 .34381 Mdot
.50873 .34145 Mdot
.62282 .36735 Mdot
.50436 .77964 Mdot
.40526 .56101 Mdot
.41059 .52578 Mdot
.71788 .59552 Mdot
.50163 .36158 Mdot
.50841 .59704 Mdot
.61174 .18773 Mdot
.43292 .35854 Mdot
.75928 .54529 Mdot
.79805 .57617 Mdot
.51978 .74198 Mdot
.57579 .53392 Mdot
.3279 .73338 Mdot
.32372 .45741 Mdot
.52377 .30009 Mdot
.64289 .22888 Mdot
.57517 .5326 Mdot
.33668 .30804 Mdot
.31897 .43483 Mdot
.57556 .66062 Mdot
.52549 .77333 Mdot
.48054 .60154 Mdot
.55286 .45858 Mdot
.39122 .32689 Mdot
.77115 .57364 Mdot
.85265 .52007 Mdot
.59462 .20702 Mdot
.53075 .77181 Mdot
.51091 .33704 Mdot
.40917 .50112 Mdot
.5869 .40383 Mdot
.60833 .184 Mdot
.76519 .62774 Mdot
.33543 .68261 Mdot
.78406 .5966 Mdot
.51475 .78018 Mdot
.58359 .50263 Mdot
.49713 .3135 Mdot
.60536 .22478 Mdot
.39011 .62631 Mdot
.53897 .52601 Mdot
.43433 .49933 Mdot
.40001 .2878 Mdot
.44504 .65557 Mdot
.27806 .452 Mdot
.52306 .79405 Mdot
.59451 .19271 Mdot
.72032 .56286 Mdot
.38222 .46546 Mdot
.59082 .18471 Mdot
.34733 .646 Mdot
.44437 .65999 Mdot
.56285 .78497 Mdot
.52257 .34035 Mdot
.68341 .5781 Mdot
.43576 .37064 Mdot
.46615 .28716 Mdot
.42298 .63536 Mdot
.55748 .40179 Mdot
.65848 .37389 Mdot
.31389 .683 Mdot
.73526 .5675 Mdot
.30907 .67747 Mdot
.84973 .5133 Mdot
.5062 .58652 Mdot
.36338 .67677 Mdot
.3032 .44311 Mdot
.65514 .55169 Mdot
.40845 .6668 Mdot
.61346 .32176 Mdot
.36191 .3123 Mdot
.37044 .66919 Mdot
.36071 .67307 Mdot
.39405 .57615 Mdot
.48785 .73876 Mdot
.6326 .28477 Mdot
.80474 .59176 Mdot
.67873 .47557 Mdot
.3854 .56651 Mdot
.5082 .35729 Mdot
.58167 .54727 Mdot
.60076 .35075 Mdot
.64002 .6151 Mdot
.705 .25214 Mdot
.24174 .43995 Mdot
.42678 .6777 Mdot
.50134 .5583 Mdot
.34904 .29263 Mdot
.50462 .34566 Mdot
.65781 .55637 Mdot
.58737 .53702 Mdot
.38657 .52826 Mdot
.30611 .65516 Mdot
.4516 .66325 Mdot
.68239 .36223 Mdot
.67055 .49038 Mdot
.52086 .75772 Mdot
.31212 .47379 Mdot
.80384 .5695 Mdot
.27296 .65744 Mdot
.64751 .49697 Mdot
.6315 .54361 Mdot
.50908 .41557 Mdot
.35281 .31139 Mdot
.67045 .21747 Mdot
.61038 .30974 Mdot
.31091 .64838 Mdot
.41952 .67744 Mdot
.70071 .5674 Mdot
.61619 .36388 Mdot
.54479 .54246 Mdot
.79377 .55632 Mdot
.42883 .4783 Mdot
.61326 .34689 Mdot
.3844 .66457 Mdot
.47595 .58793 Mdot
.78906 .58552 Mdot
.64237 .38205 Mdot
.79307 .60498 Mdot
.34013 .46188 Mdot
.54365 .44196 Mdot
.77348 .61798 Mdot
.45581 .49788 Mdot
.59481 .56815 Mdot
.28073 .38403 Mdot
.48943 .57071 Mdot
.82645 .54547 Mdot
.29936 .65311 Mdot
.56413 .45312 Mdot
.36874 .68575 Mdot
.49552 .76421 Mdot
.62351 .30228 Mdot
.40885 .68254 Mdot
.80055 .59336 Mdot
.50563 .36716 Mdot
.62467 .38969 Mdot
.31028 .48446 Mdot
.3685 .31929 Mdot
.60515 .44682 Mdot
.38344 .49138 Mdot
.63125 .40462 Mdot
.52067 .28468 Mdot
.49419 .41733 Mdot
.66449 .25338 Mdot
.49754 .27477 Mdot
.48411 .47821 Mdot
.58819 .49306 Mdot
.37465 .59671 Mdot
.68611 .24893 Mdot
.51814 .29904 Mdot
.35008 .72524 Mdot
.81195 .57753 Mdot
.73686 .55291 Mdot
.58921 .1831 Mdot
.50982 .78073 Mdot
.50559 .46545 Mdot
.84395 .54291 Mdot
.52302 .51416 Mdot
.72061 .55419 Mdot
.5932 .55239 Mdot
.29341 .66304 Mdot
.65723 .23367 Mdot
.59755 .50584 Mdot
.47457 .48403 Mdot
.45511 .40304 Mdot
.35776 .66146 Mdot
.49971 .28787 Mdot
.51493 .36562 Mdot
.66788 .62027 Mdot
.34223 .30793 Mdot
.70303 .55776 Mdot
.38799 .56553 Mdot
.79954 .56898 Mdot
.79655 .5491 Mdot
.56996 .41222 Mdot
.58937 .64248 Mdot
.58592 .18488 Mdot
.48171 .45712 Mdot
.2422 .40163 Mdot
.31388 .67674 Mdot
.66142 .37504 Mdot
.75448 .56093 Mdot
.38781 .44491 Mdot
.34194 .3456 Mdot
.42059 .48048 Mdot
.66585 .28607 Mdot
.46167 .52 Mdot
.56478 .67613 Mdot
.39059 .5776 Mdot
.35166 .72323 Mdot
.3528 .69484 Mdot
.50581 .78699 Mdot
.82557 .54363 Mdot
.50537 .62249 Mdot
.4728 .59719 Mdot
.47685 .47512 Mdot
.8067 .53846 Mdot
.51303 .76672 Mdot
.49698 .7208 Mdot
.3314 .50349 Mdot
.59347 .20179 Mdot
.30116 .68628 Mdot
.45901 .6218 Mdot
.53972 .58202 Mdot
.52503 .38411 Mdot
.47508 .75385 Mdot
.42986 .66718 Mdot
.33198 .67274 Mdot
.61697 .24709 Mdot
.55406 .60025 Mdot
.65363 .40996 Mdot
.76991 .59359 Mdot
.52209 .58239 Mdot
.79941 .55109 Mdot
.34312 .53238 Mdot
.61491 .23249 Mdot
.52617 .33492 Mdot
.60733 .40279 Mdot
.44437 .39485 Mdot
.40607 .64736 Mdot
.62494 .33353 Mdot
.54257 .5417 Mdot
.55001 .62487 Mdot
.34365 .69061 Mdot
.82343 .57635 Mdot
.63931 .49305 Mdot
.5848 .7819 Mdot
.59236 .49265 Mdot
.34265 .32686 Mdot
.33808 .31828 Mdot
.49627 .73761 Mdot
.5835 .55289 Mdot
.42675 .61301 Mdot
.55085 .45646 Mdot
.3289 .4933 Mdot
.64855 .31555 Mdot
.64203 .20333 Mdot
.35254 .64714 Mdot
.81718 .59538 Mdot
.36466 .5381 Mdot
.34912 .65278 Mdot
.71785 .55867 Mdot
.57345 .62767 Mdot
.51954 .44684 Mdot
.56225 .40321 Mdot
.28 .63731 Mdot
.63389 .19632 Mdot
.52168 .61794 Mdot
.56094 .44094 Mdot
.70781 .57824 Mdot
.45328 .63488 Mdot
.58978 .68258 Mdot
.54887 .74575 Mdot
.82809 .56902 Mdot
.79104 .5675 Mdot
.58318 .68995 Mdot
.58549 .58387 Mdot
.5438 .62154 Mdot
.63037 .24163 Mdot
.59414 .49827 Mdot
.62094 .31144 Mdot
.53733 .79432 Mdot
.33464 .48298 Mdot
.49157 .2729 Mdot
.519 .3076 Mdot
.367 .31292 Mdot
.39409 .48114 Mdot
.61783 .26467 Mdot
.64525 .47475 Mdot
.67505 .48383 Mdot
.71912 .58847 Mdot
.61256 .18469 Mdot
.42012 .65953 Mdot
.61259 .47222 Mdot
.5856 .3913 Mdot
.5521 .59831 Mdot
.47944 .3104 Mdot
.41386 .53357 Mdot
.65371 .42083 Mdot
.57487 .67249 Mdot
.36116 .69719 Mdot
.67552 .27859 Mdot
.44399 .40253 Mdot
.31695 .2945 Mdot
.47804 .74948 Mdot
.65578 .5634 Mdot
.34361 .69449 Mdot
.66365 .21668 Mdot
.50173 .72285 Mdot
.57235 .76936 Mdot
.50151 .74132 Mdot
.60499 .36336 Mdot
.57184 .79675 Mdot
.48266 .73571 Mdot
.85331 .52512 Mdot
.42923 .67733 Mdot
.38547 .47142 Mdot
.31525 .71075 Mdot
.51833 .28296 Mdot
.37493 .4933 Mdot
.65997 .47302 Mdot
.6579 .27806 Mdot
.50156 .33966 Mdot
.56635 .46356 Mdot
.61483 .25786 Mdot
.78724 .58946 Mdot
.7723 .60067 Mdot
.47195 .73969 Mdot
.37878 .65461 Mdot
.58458 .79981 Mdot
.69542 .57003 Mdot
.25138 .45446 Mdot
.60763 .30815 Mdot
.39268 .46213 Mdot
.54087 .53679 Mdot
.41045 .51834 Mdot
.64439 .24159 Mdot
.81719 .5435 Mdot
.59827 .57689 Mdot
.61902 .56334 Mdot
.53179 .32141 Mdot
.58267 .40189 Mdot
.41134 .57718 Mdot
.59806 .33103 Mdot
.65246 .55318 Mdot
.59704 .50479 Mdot
.79562 .58451 Mdot
.4058 .64764 Mdot
.37525 .32584 Mdot
.59729 .20065 Mdot
.35418 .32347 Mdot
.79264 .61748 Mdot
.54636 .78671 Mdot
.71796 .58938 Mdot
.61555 .1884 Mdot
.41606 .61427 Mdot
.46999 .42869 Mdot
.58244 .17826 Mdot
.69062 .2597 Mdot
.54702 .62137 Mdot
.4261 .45044 Mdot
.85122 .53256 Mdot
.61683 .55662 Mdot
.61036 .3742 Mdot
.30712 .49224 Mdot
.75896 .59674 Mdot
.4954 .40008 Mdot
.3975 .45325 Mdot
.55728 .45173 Mdot
.33452 .64851 Mdot
.37284 .66147 Mdot
.67293 .53928 Mdot
.77958 .59776 Mdot
.2987 .47089 Mdot
.31462 .50606 Mdot
.33604 .46238 Mdot
.29478 .63816 Mdot
.64942 .28715 Mdot
.72108 .29686 Mdot
.28413 .47268 Mdot
.62173 .24188 Mdot
.33847 .27607 Mdot
.42893 .64289 Mdot
.32402 .49806 Mdot
.50663 .31706 Mdot
.69899 .55347 Mdot
.60106 .17662 Mdot
.33762 .49774 Mdot
.7021 .25005 Mdot
.6784 .2875 Mdot
.30626 .64538 Mdot
.38057 .54495 Mdot
.51279 .3579 Mdot
.52138 .60789 Mdot
.57748 .67181 Mdot
.71507 .59381 Mdot
.73378 .55823 Mdot
.63419 .53241 Mdot
.43895 .42103 Mdot
.40054 .5161 Mdot
.62588 .32008 Mdot
.58294 .50109 Mdot
.63009 .31162 Mdot
.35831 .48248 Mdot
.42903 .35617 Mdot
.58082 .17086 Mdot
.37374 .70902 Mdot
.50902 .38914 Mdot
.61875 .49008 Mdot
.61147 .47053 Mdot
.43616 .33275 Mdot
.47968 .7167 Mdot
.5406 .36275 Mdot
.74607 .59428 Mdot
.65237 .27997 Mdot
.37881 .55976 Mdot
.50986 .35197 Mdot
.57633 .70871 Mdot
.40197 .3308 Mdot
.49271 .39917 Mdot
.4773 .70729 Mdot
.73017 .58475 Mdot
.59605 .6624 Mdot
.49344 .76043 Mdot
.44423 .65034 Mdot
.45332 .28422 Mdot
.62913 .48316 Mdot
.72576 .57273 Mdot
.49816 .73687 Mdot
.47758 .75054 Mdot
.79941 .59518 Mdot
.43195 .4699 Mdot
.52468 .77989 Mdot
.68191 .53768 Mdot
.49835 .32226 Mdot
.40695 .5098 Mdot
.55255 .61389 Mdot
.28592 .45068 Mdot
.63821 .254 Mdot
.66901 .45086 Mdot
.64294 .47941 Mdot
.29258 .44019 Mdot
.65834 .25382 Mdot
.49095 .71384 Mdot
.84751 .48918 Mdot
.57408 .62535 Mdot
.37072 .68363 Mdot
.32517 .41083 Mdot
.56952 .53622 Mdot
.3074 .40677 Mdot
.42803 .45106 Mdot
.34243 .36542 Mdot
.56904 .76794 Mdot
.57985 .53753 Mdot
.45174 .64187 Mdot
.49107 .61825 Mdot
.54758 .3985 Mdot
.3045 .40933 Mdot
.41377 .42814 Mdot
.65189 .46546 Mdot
.47429 .28141 Mdot
.65815 .47112 Mdot
.55332 .41745 Mdot
.55813 .76137 Mdot
.72875 .57671 Mdot
.76947 .60004 Mdot
.50716 .44059 Mdot
.6497 .23811 Mdot
.25792 .38721 Mdot
.60836 .31223 Mdot
.43658 .5276 Mdot
.54361 .77587 Mdot
.35172 .32472 Mdot
.59991 .17905 Mdot
.38788 .5088 Mdot
.70578 .34989 Mdot
.65837 .3014 Mdot
.61127 .33289 Mdot
.58015 .69633 Mdot
.31362 .72692 Mdot
.72152 .59123 Mdot
.52527 .37147 Mdot
.35045 .70071 Mdot
.67466 .46033 Mdot
.62346 .3594 Mdot
.55362 .48039 Mdot
.56717 .62549 Mdot
.27921 .45506 Mdot
.50794 .41173 Mdot
.70527 .62506 Mdot
.28911 .44878 Mdot
.39609 .4804 Mdot
.6172 .26629 Mdot
.24428 .40054 Mdot
.47583 .55345 Mdot
.39222 .50601 Mdot
.59765 .19487 Mdot
.70991 .62319 Mdot
.33632 .30582 Mdot
.22789 .43152 Mdot
.56584 .77241 Mdot
.71801 .55033 Mdot
.5935 .2057 Mdot
.55809 .73675 Mdot
.55105 .45502 Mdot
.35899 .74075 Mdot
.40257 .50369 Mdot
.32496 .66973 Mdot
.5118 .75551 Mdot
.58549 .42205 Mdot
.42454 .49976 Mdot
.60031 .1687 Mdot
.61665 .34847 Mdot
.51156 .45318 Mdot
.25157 .45634 Mdot
.79692 .58136 Mdot
.32943 .31543 Mdot
.52763 .78409 Mdot
.65088 .28922 Mdot
.58612 .68404 Mdot
.84653 .54029 Mdot
.52388 .58865 Mdot
.3537 .54498 Mdot
.57939 .40286 Mdot
.35102 .70431 Mdot
.57255 .51979 Mdot
.3097 .50252 Mdot
.36017 .70804 Mdot
.57998 .36483 Mdot
.55592 .57074 Mdot
.27695 .64108 Mdot
.36746 .53272 Mdot
.50837 .56372 Mdot
.57762 .63087 Mdot
.46041 .62096 Mdot
.48013 .5956 Mdot
.50706 .76499 Mdot
.49435 .55319 Mdot
.37332 .71125 Mdot
.54171 .73923 Mdot
.35639 .47384 Mdot
.69044 .54703 Mdot
.55308 .40008 Mdot
.63534 .60509 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0;_ooooo1?l0002:ooooo`00
7?ooool00ol0003oooooooooo`2kooooo`Go0000ROooool001cooooo00?o0000ooooooooool0^ooo
ool7o`0008Oooooo000Looooo`03o`000?oooooooooo0;Wooooo1?l00002ooooo`Co0000Q_ooool0
01cooooo00?o0000ooooooooool0^Oooool4o`0000Cooooo0ol00025ooooo`007?ooool00ol0003o
ooooooooo`2iooooo`Co00000_ooool6o`0008Cooooo000Looooo`03o`000?oooooooooo0;Wooooo
1Ol000000ooooooo0000o`000002ooooo`?o0000Poooool001cooooo00?o0000ooooooooool0_?oo
ool2o`000004ooooool0003o0000ooooo`Go0000P_ooool001cooooo00?o0000ooooooooool0^ooo
ool3o`0000Cooooo1ol00020ooooo`007?ooool00ol0003oooooooooo`2kooooo`?o00001?ooool4
o`000003ooooool0003o0000083ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ
8B44ooooo`Go00001_ooool00ol0003oooooooooo`2mooooo`?o00000_ooool4o`0000?ooooo0_l0
001nooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Q
onk^k_ooooooA4A400Kooooo00?o0000ooooooooool0_Oooool3o`0000Wooooo0ol0001mooooo`00
00?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo
00?o0000ooooooooool0__ooool2o`0000[ooooo0_l000000ooooooo0000o`00001jooooo`0000?o
ooooo`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0
002mooooo`Go00002oooool2o`0007[ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`2mooooo`Go00002oooool2
o`000003ooooool0003o000007Oooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo
00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2mooooo`;o00001oooool2o`00
00Gooooo1ol0001eooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`2mooooo`;o00000_ooool2o`0000?ooooo0_l0
0007ooooo`;o000000?oooooo`000?l00000MOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^
2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0`Oooool2o`0008Ko
oooo000Looooo`03o`000?oooooooooo0=Cooooo1?l0001aooooo`007?ooool00ol0003ooooooooo
o`2oooooo`;o00000oooool2o`0000kooooo1?l0001aooooo`007?ooool00ol0003oooooooooo`2o
ooooo`?o00000_ooool2o`0000kooooo0_l0001cooooo`007?ooool00ol0003oooooooooo`30oooo
o`Go00001oooool2o`0000?ooooo0_l0001fooooo`007?ooool00ol0003oooooooooo`31ooooo`Co
00001oooool3o`0000;ooooo0_l0001fooooo`007?ooool00ol0003oooooooooo`31ooooo`;o0000
00?oooooo`000?l000001oooool2o`0000?ooooo0_l0001eooooo`007?ooool00ol0003ooooooooo
o`31ooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo1_l000000ooooooo0000o`00
0002ooooo`;o00000_ooool2o`0006[ooooo000Looooo`03o`000?oooooooooo0<[ooooo0_l00002
ooooo`Co00000oooool6o`0000;ooooo0_l0001Zooooo`007?ooool00ol0003oooooooooo`36oooo
o`;o000000Coooooo`000?l0003o00000_ooool3o`0000Kooooo0_l00004ooooo`;o0000J_ooool0
01cooooo00?o0000ooooooooool0a_ooool2o`000004ooooool0003o0000o`0000;ooooo0_l0000=
ooooo`;o0000J_ooool001cooooo00?o0000ooooooooool0aOooool2o`0001Cooooo0_l0001/oooo
o`007?ooool2o`000<Kooooo0_l0000;ooooo`;o00001oooool2o`0000?ooooo0ol0001Vooooo`00
7?ooool00ol0003oooooooooo`3<ooooo`;o00001?ooool4o`000003ooooool0003o000000Oooooo
0ol0001Vooooo`007?ooool00ol0003oooooooooo`34ooooo`;o000000?oooooo`000?l000000ooo
ool2o`0000Cooooo1?l000000ooooooo0000o`000005ooooo`;o0000JOooool001cooooo00?o0000
ooooooooool0a?ooool2o`000003ooooool0003o000001Cooooo1?l000001?oooooo0000o`000?l0
001Tooooo`007?ooool00ol0003oooooooooo`34ooooo`?o00000_ooool2o`0001;ooooo2?l0001T
ooooo`007?ooool00ol0003oooooooooo`34ooooo`?o00000_ooool2o`0000Oooooo0_l0000=oooo
o`Co0000I?ooool001cooooo00?o0000ooooooooool0V_ooool5o`0002Kooooo0_l0000;ooooo`;o
0000MOooool001cooooo00?o0000ooooooooool0L?ooool2o`0001cooooo0_l00007ooooo`;o0000
00?oooooo`000?l000000ol0000aooooo`;o00001_ooool2o`0006oooooo000Looooo`03o`000?oo
oooooooo06[ooooo0_l00004ooooo`;o000000?oooooo`000?l000000ol0000Eooooo`Go00001Ooo
ool2o`0000?ooooo1?l0000Tooooo`;o00002_ooool2o`0000Kooooo1?l00003ooooo`;o00000ooo
ool2o`0006?ooooo000Looooo`03o`000?oooooooooo06[ooooo0_l00003ooooo`[o00005?ooool:
o`0000;ooooo0_l00003ooooo`;o00000oooool2o`0001oooooo0_l0000:ooooo`Co00001?ooool4
o`0000?ooooo1?l000000ooooooo0000o`00001Sooooo`007?ooool00ol0003oooooooooo`1_oooo
o`_o00004oooool;o`000003ooooool0003o000000Gooooo1ol0000Yooooo`Co00001?ooool2o`00
00Kooooo0ol0001Vooooo`007?ooool00ol0003oooooooooo`1_ooooo`;o00000_ooool9o`0001?o
oooo2Ol00008ooooo`Oo00008oooool2o`0000Kooooo1?l000000ooooooo0000o`000006ooooo`;o
000000?oooooo`000?l00000IOooool001cooooo00?o0000ooooooooool0KooooolAo`0000oooooo
1?l000000ooooooo0000o`000009ooooo`;o000000?oooooo`000?l000001?l0000Rooooo`;o0000
0oooool7o`000003ooooool0003o000000Co00000_ooool2o`000004ooooool0003o0000o`0006Co
oooo000Looooo`03o`000?oooooooooo06Kooooo0_l00007oooooa;o00003_ooool4o`000003oooo
ool0003o000000Wooooo0_l00003ooooo`Go000000?oooooo`000?l000008oooool4o`0000Cooooo
1_l00003ooooo`Go0000I?ooool001cooooo00?o0000ooooooooool0Hoooool2o`000003ooooool0
003o000000?ooooo0_l000000ooooooo0000o`000007ooooo`[o00003_ooool3o`0000Oooooo0_l0
000:ooooo`So0000:_ooool5o`0000?ooooo1_l0001Tooooo`007?ooool00ol0003oooooooooo`1S
ooooo`;o00001_ooool2o`000003ooooool0003o000000Sooooo2ol0000=ooooo`?o00001_ooool3
o`0000[ooooo1ol0000Iooooo`;o00005oooool6o`000003ooooool0003o0000067ooooo000Loooo
o`;o0000Noooool:o`0000gooooo0_l00007ooooo`;o00002Oooool6o`0001_ooooo1?l00008oooo
o`;o00002oooool4o`000003ooooool0003o000000;o0000HOooool001cooooo00?o0000oooooooo
ool0H_ooool2o`0001Oooooo2Ol0000?ooooo`;o00004?ooool3o`000003ooooool0003o000000?o
00006Oooool5o`0000Gooooo1?l00004ooooo`;o000000?oooooo`000?l000001?l00002ooooo`;o
0000Hoooool001cooooo00?o0000ooooooooool0H_ooool3o`0000Gooooo0_l0000?ooooo`Oo0000
0_ooool3o`0000_ooooo0ol0000@ooooo`;o00000oooool4o`0001Wooooo0_l000000ooooooo0000
o`000005ooooo`Co00000_ooool9o`0000Cooooo0_l0001Sooooo`007?ooool00ol0003ooooooooo
o`1Rooooo`?o00001Oooool3o`0000Cooooo0_l0000;ooooo`Wo00002oooool3o`0000?ooooo0_l0
0005ooooo`;o00001?ooool2o`0000?ooooo1ol0000Aooooo`;o00003Oooool2o`000004ooooool0
003o0000ooooo`;o000000?oooooo`000?l000000_l00006ooooo`;o000000?oooooo`000?l00000
H?ooool001cooooo00?o0000ooooooooool0Hoooool2o`0000Gooooo0ol00002ooooo`So00001ooo
ool:o`0000_ooooo0ol00002ooooo`?o00000oooool3o`0000Cooooo0_l00003ooooo`;o000000?o
ooooo`000?l000000_l0000Aooooo`;o00000_ooool2o`000003ooooool0003o000000Kooooo0_l0
00000ooooooo0000o`00000<o`0000;ooooo0_l000000ooooooo0000o`00001Pooooo`007?ooool0
0ol0003oooooooooo`1Wooooo`;o00001_ooool2o`000003ooooool0003o000000?o00001Oooool2
o`000003ooooool0003o000000Oo00003?ooool2o`0000?ooooo0_l00003ooooo`;o000000?ooooo
o`000?l000002Oooool6o`00013ooooo0_l00002ooooo`;o000000?oooooo`000?l000001?ooool3
o`000003ooooool0003o000000?o000000?oooooo`000?l000001ol00002ooooo`;o000000?ooooo
o`000?l00000H?ooool001cooooo00?o0000ooooooooool0Ioooool2o`000004ooooool0003o0000
o`0000Oooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000;ooooo2?l0000I
ooooo`;o00002Oooool6o`0001;ooooo0_l00002ooooo`?o00001?ooool3o`000003ooooool0003o
000000go00001Oooool2o`00063ooooo000Looooo`03o`000?oooooooooo06[ooooo0ol00007oooo
o`_o00000_ooool8o`0000kooooo0_l00005ooooo`;o00002Oooool2o`0000?ooooo1?l0000>oooo
o`;o000000Coooooo`000?l0003o00000_ooool2o`0000Wooooo3ol00005ooooo`;o0000H?ooool0
01cooooo00?o0000ooooooooool0Koooool2o`0000Cooooo2_l00003ooooo`So00003Oooool4o`00
00?ooooo1?l00007ooooo`;o00001?ooool3o`0000kooooo0_l000000ooooooo0000o`000004oooo
o`;o00001_oooolBo`000003ooooool0003o000006?ooooo000Looooo`03o`000?oooooooooo06[o
oooo1?l000000ooooooo0000o`000002ooooo`Ko000000Coooooo`000?l0003o00000oooool;o`00
00kooooo0ol00002ooooo`Co00003Oooool3o`0001Gooooo1?l00005oooooa?o000000?oooooo`00
0?l00000Hoooool001cooooo00?o0000ooooooooool0J_ooool4o`0000?ooooo1ol00002oooooa;o
00003_ooool3o`0000Wooooo0_l00006ooooo`Go00002oooool2o`000003ooooool0003o000000Co
oooo0_l00006oooooa?o00000_ooool2o`0006?ooooo000Looooo`03o`000?oooooooooo077ooooo
1ol00003ooooo`Ko000000?oooooo`000?l000002?l0000?ooooo`?o00001_ooool6o`0000Cooooo
1Ol0000;ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00000ooooolFo`0000;ooooo
0_l0001Sooooo`007?ooool00ol0003oooooooooo`1aooooo`Co00001_ooool5o`0000;ooooo2_l0
000@ooooo`;o00001?ooool8o`0000;ooooo0_l000000ooooooo0000o`000002o`00013ooooo0_l0
0002ooooo`?o00000_oooolFo`0000Cooooo0_l0001Qooooo`007?ooool00ol0003oooooooooo`1a
ooooo`Co00002Oooool2o`0000Cooooo2Ol0000Booooo`Go00000_ooool2o`0000Cooooo0_l00000
0ooooooo0000o`000002o`0001Cooooo0ol00004oooooaCo00001?ooool2o`00067ooooo000Loooo
o`03o`000?oooooooooo073ooooo1?l0000=ooooo`co00004_ooool6o`000003ooooool0003o0000
00Oooooo0ol0000LoooooaCo0000Ioooool001cooooo00?o0000ooooooooool0Joooool2o`0000?o
oooo0_l0000?ooooo`Oo000000?oooooo`000?l000000ol0000@ooooo`Co000000?oooooo`000?l0
00002_ooool4o`00013ooooo0_l00009oooooaOo0000I?ooool001cooooo0_l0001/ooooo`;o0000
0_ooool3o`0000gooooo3ol0000@ooooo`Go00003?ooool4o`0000cooooo0_l00002ooooo`Co0000
1ooooolGo`0006Cooooo000Looooo`03o`000?oooooooooo06kooooo0ol0000>ooooo`So000000?o
ooooo`000?l000001Ol0000@ooooo`Go00002_ooool3o`0000kooooo0_l00004ooooo`;o00002Ooo
ool5o`000003ooooool0003o000000go0000I?ooool001cooooo00?o0000ooooooooool0J_ooool2
o`0000;ooooo0ol0000>oooooa3o00004?ooool2o`000003ooooool0003o000000[ooooo0ol0000O
ooooo`Go000000?oooooo`000?l000002_l000000ooooooo0000o`00001Tooooo`007?ooool00ol0
003oooooooooo`1Yooooo`?o00000_ooool2o`0000kooooo4_l0000Aooooo`Co00002?ooool4o`00
01Kooooo0_l00007ooooo`ko0000Joooool001cooooo00?o0000ooooooooool0JOooool2o`000003
ooooool0003o000000;o00003_oooolBo`0000oooooo1_l00007ooooo`Co00002oooool2o`0000So
oooo1?l00004ooooo`?o000000?oooooo`000?l000002ol00002ooooo`;o0000Ioooool001cooooo
00?o0000ooooooooool0K?ooool3o`0000kooooo4ol0000?ooooo`;o00000oooool2o`0000;ooooo
0_l00002ooooo`Co00002Oooool5o`000003ooooool0003o000000;o000000Coooooo`000?l0003o
00001_ooool3o`000003ooooool0003o000000_o000000Coooooo`000?l0003o0000Ioooool001co
oooo00?o0000ooooooooool0K?ooool3o`0000kooooo4ol0000?ooooo`?o00000_ooool2o`0000;o
oooo0_l00003ooooo`;o00002Oooool3o`000004ooooool0003o0000ooooo`Co000000Coooooo`00
0?l0003ooooo0_l00004ooooo`;o00000oooool7o`000003ooooool0003o000000Ko0000Ioooool0
01cooooo00?o0000ooooooooool0KOooool2o`0000kooooo4ol0000?ooooo`?o00001Oooool2o`00
00;ooooo1?l00009ooooo`;o00003Oooool2o`000003ooooool0003o000000Kooooo0_l000000ooo
oooo0000o`00000:o`0006Sooooo000Looooo`03o`000?oooooooooo07cooooo4?l000001?oooooo
0000o`000?l0000@ooooo`;o00001Oooool2o`0000;ooooo0_l0000?ooooo`?o00000oooool2o`00
00Kooooo0_l00004oooooa3o0000JOooool001cooooo00?o0000ooooooooool0O?oooolEo`0000oo
oooo0_l00007ooooo`Go00003_ooool3o`0000?ooooo0_l0000:ooooo`oo0000K?ooool001cooooo
00?o0000ooooooooool0E_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000Loooooa?o0000
00Coooooo`000?l0003o00003_ooool2o`0000?ooooo0ol000000ooooooo0000o`000003o`00023o
oooo0_l00004ooooo`Oo0000K_ooool001cooooo00?o0000ooooooooool0Coooool2o`0000Gooooo
1_l000000ooooooo0000o`00000;ooooo`;o00003_oooolDo`000003ooooool0003o000000;o0000
3Oooool2o`0000?ooooo1ol0000Qooooo`;o000000?oooooo`000?l000001?ooool3o`00073ooooo
000Looooo`03o`000?oooooooooo04oooooo0ol000000ooooooo0000o`00000:o`0000_ooooo0_l0
000>oooooaWo00005?ooool5o`0001?ooooo0_l0000<ooooo`Go0000Moooool001cooooo00?o0000
ooooooooool0D?ooool@o`0000[ooooo0_l0000>oooooaSo00004?ooool2o`0000?ooooo0ol0000E
ooooo`;o00001_ooool2o`0000Kooooo0_l0001hooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^
k^h5ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0C?oo
ool2o`0000;ooooo4?l0000JoooooaWo00003oooool2o`0000?ooooo0ol00005ooooo`;o00000_oo
ool2o`0000Gooooo0_l0000;ooooo`;o0000P?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1<ooooo`;o0000
00?oooooo`000?l000003ol0000KoooooaWo00006oooool3o`000003ooooool0003o000000Gooooo
0_l00009ooooo`;o0000P_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Ooo
ool5o`0000Kooooo00?o0000ooooooooool0C?oooolGo`0001Oooooo6ol00007ooooo`?o00001ooo
ool2o`0000Kooooo1?l0000Cooooo`Co0000P?ooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool02Oooool01?m4A4CogMgMooooool00007ooooo`?o0000B_oooolIo`000003ooooool0
003o000001Cooooo5?l000000ooooooo0000o`000004o`0000Oooooo0ol000000ooooooo0000o`00
0004ooooo`;o00001_ooool7o`0000?ooooo0ol00006ooooo`;o00001?ooool2o`00083ooooo0000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo00001ooo
ool00ol0003oooooooooo`1:oooooaOo00000oooool3o`000003ooooool0003o0000013ooooo7?l0
000:ooooo`;o00000oooool2o`0000Cooooo0_l00004ooooo`Go00000_ooool5o`0000Cooooo0_l0
0003ooooo`Go00000_ooool2o`000003ooooool0003o000007Oooooo00000ooooooo410@ooooo`02
ooooo`03oa0@4?oooooooooo00[ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`18
ooooo`;o00000ooooolEo`0000?ooooo0_l000000ooooooo0000o`00000AoooooaGo00000oooool3
o`0000oooooo0_l00004ooooo`;o00001oooool2o`0000Gooooo0_l00005ooooo`[o000000Cooooo
o`000?l0003ooooo0_l0001gooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<ooooo`03onk^
k_m4A4Co000000Oooooo00?o0000ooooooooool0B?ooool2o`0000Cooooo0_l000000ooooooo0000
o`00000Bo`000003ooooool0003o000000;o00004?oooolFo`0000?ooooo0ol00003ooooo`;o0000
1_ooool3o`00017ooooo0_l00005ooooo`;o00000_ooool7o`000003ooooool0003o000000;o0000
1Oooool2o`0007Kooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?oo
ool01_ooool00ol0003oooooooooo`17ooooo`?o00001?oooolGo`000004ooooool0003o0000o`00
017ooooo5_l000000ooooooo0000o`000003o`000003ooooool0003o000000;o00001_ooool3o`00
00_ooooo0_l00004ooooo`;o00001Oooool2o`000003ooooool0003o000000Ko000000?oooooo`00
0?l000001?l00003ooooo`;o0000M_ooool001cooooo00?o0000ooooooooool0A_ooool3o`0000Go
oooo4_l00007ooooo`;o00004_oooolEo`000003ooooool0003o000000?o000000?oooooo`000?l0
00001?ooool2o`0000?ooooo0_l0000;ooooo`Go00002oooool@o`0007[ooooo000Looooo`03o`00
0?oooooooooo04Gooooo0ol00004oooooaSo00005ooooolEo`0000;ooooo1?l00007ooooo`?o0000
4?ooool4o`0000cooooo3ol00002ooooo`;o0000M_ooool001cooooo00?o0000ooooooooool0AOoo
ool4o`0000?ooooo1?l00002oooooa;o00000_ooool2o`0001?ooooo5?l0000?ooooo`Co00006?oo
ool2o`0000?ooooo4Ol000000ooooooo0000o`00001fooooo`007?ooool00ol0003oooooooooo`15
ooooo`Co00002Oooool3o`0000;ooooo1?l00002ooooo`;o00001_ooool3o`0001Cooooo0_l00000
0ooooooo0000o`00000>o`0000_ooooo0_l00002ooooo`Co00006?ooool2o`0000?ooooo4Ol0001i
ooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00003?ooool2o`0000Sooooo0ol00005oooo
o`?o00005?oooolCo`0000Kooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l0000Ooooo
o`So00000_ooool6o`0007Wooooo000Looooo`03o`000?oooooooooo04Kooooo0_l0000Fooooo`;o
00001Oooool3o`0001Gooooo4_l00006ooooo`;o00001Oooool4o`0001oooooo4Ol00002ooooo`;o
0000MOooool001cooooo00?o0000ooooooooool0A_ooool2o`0000Sooooo0_l0000Booooo`Go0000
5OoooolAo`0000cooooo0ol0000Poooooa;o00000_ooool2o`0007Gooooo000Looooo`03o`000?oo
oooooooo04Cooooo1?l00003ooooo`;o00000oooool2o`0000Wooooo0_l00007ooooo`Ko00005?oo
ool2o`000003ooooool0003o000000_o00003?ooool3o`0000;ooooo0_l0000=ooooo`;o00003_oo
oolCo`000003ooooool0003o000007Gooooo000Looooo`03o`000?oooooooooo04Cooooo0_l00005
ooooo`;o00003_ooool2o`0000;ooooo0_l00007ooooo`Co00003Oooool2o`0000Cooooo0_l00002
ooooo`co00002_ooool3o`0000?ooooo1?l00002ooooo`;o00001Oooool4o`0000;ooooo0_l00009
oooooaCo0000N?ooool001cooooo00?o0000ooooooooool0Aoooool2o`0001Kooooo0_l00009oooo
o`?o00003?ooool3o`0000?ooooo1?l000000ooooooo0000o`00000:o`0000Wooooo0_l00006oooo
o`;o00000_ooool2o`0000Gooooo0ol00003ooooo`;o00002OoooolDo`0007Sooooo000Looooo`03
o`000?oooooooooo04Kooooo1Ol0000;ooooo`;o00000_ooool2o`0000oooooo1?l00009ooooo`Co
00001Oooool2o`0000?ooooo2ol00005ooooo`;o00003Oooool2o`0001Kooooo5?l0001hooooo`00
7?ooool2o`0004Oooooo1Ol0000;ooooo`Ko00003oooool5o`0000Sooooo0_l00002ooooo`;o0000
1Oooool2o`0000;ooooo1ol000000ooooooo0000o`000005ooooo`;o00003Oooool2o`0000[ooooo
0_l0000:ooooo`;o000000?oooooo`000?l000003ol00005ooooo`;o0000LOooool001cooooo00?o
0000ooooooooool0BOooool4o`000003ooooool0003o000000Oooooo1?l0000Booooo`Co00002ooo
ool3o`0000Cooooo0_l00002ooooo`;o00000oooool2o`0000?ooooo1?l0000=ooooo`;o00002ooo
ool6o`0000_ooooo4Ol00005ooooo`;o0000LOooool001cooooo00?o0000ooooooooool0Boooool5
o`0000Oooooo0_l0000<ooooo`;o00001oooool4o`0000Wooooo1?l00008ooooo`;o000000?ooooo
o`000?l000001?l000000ooooooo0000o`000002o`0000Cooooo0_l00007ooooo`;o00000oooool2
o`0000Kooooo0ol000000ooooooo0000o`000008ooooo`;o000000?oooooo`000?l000004Ol0001f
ooooo`007?ooool00ol0003oooooooooo`1<ooooo`Co00005Oooool2o`0000Cooooo0_l00002oooo
o`Co00002?ooool2o`0000Gooooo0_l00006ooooo`Ko00002Oooool2o`0000cooooo0_l00006oooo
o`?o00001oooool2o`0000;ooooo5_l00004ooooo`;o0000L?ooool001cooooo00?o0000oooooooo
ool0COooool4o`0001Sooooo1?l00003ooooo`Co00002?ooool2o`0000Cooooo0_l0000>ooooo`;o
00008?ooool2o`0000?ooooo0_l00004oooooa7o00001Oooool4o`00073ooooo000Looooo`03o`00
0?oooooooooo04oooooo1_l0000@ooooo`;o00000_ooool2o`0000Kooooo1?l00003ooooo`;o0000
0_ooool2o`0001;ooooo1?l0000<ooooo`;o00004_ooool2o`0000[ooooo4_l00003ooooo`;o0000
L_ooool001cooooo00?o0000ooooooooool0DOooool6o`0000Kooooo0_l00006ooooo`;o00002ooo
ool3o`000003ooooool0003o000000;o00003oooool2o`0000Gooooo0_l0000>ooooo`;o00004_oo
ool3o`0000Wooooo5Ol0001dooooo`007?ooool00ol0003oooooooooo`1Cooooo`So00000_ooool2
o`0000?ooooo1?l00005ooooo`;o00000oooool8o`000003ooooool0003o000000kooooo0_l0000Y
ooooo`Go00001oooool@o`000003ooooool0003o000000;o00000_ooool2o`00073ooooo000Loooo
o`03o`000?oooooooooo05Oooooo1?l00007ooooo`Co00001Oooool2o`0000?ooooo1ol00002oooo
o`;o00006?ooool2o`0000;ooooo0_l0000Nooooo`;o00001oooool5o`000003ooooool0003o0000
00So000000?oooooo`000?l000000_l00002ooooo`Co0000K_ooool001cooooo00?o0000oooooooo
ool0Eoooool9o`0001Oooooo0_l0000?ooooo`;o00002Oooool2o`0000;ooooo1?l0000Qooooo`;o
00000_ooool2o`000003ooooool0003o000000_o00001?ooool2o`0000?ooooo0_l0001^ooooo`00
7?ooool00ol0003oooooooooo`1Gooooo`Wo00002Oooool2o`0000Kooooo0_l00004ooooo`;o0000
0oooool3o`0000Cooooo1?l000000ooooooo0000o`00000>ooooo`?o00003?ooool2o`0000Oooooo
0_l0000:ooooo`;o00000_ooool3o`000003ooooool0003o000000Wo000000?oooooo`000?l00000
0_ooool2o`0007?ooooo000Looooo`03o`000?oooooooooo05Wooooo1ol000000ooooooo0000o`00
0006ooooo`;o00001_ooool2o`0000Wooooo0ol000001?oooooo0000o`000?ooool4o`0000cooooo
0_l000000ooooooo0000o`00000?ooooo`Co00001Oooool2o`0000Oooooo0_l00006ooooo`;o0000
0_ooool2o`000003ooooool0003o000000Go000000Coooooo`000?l0003ooooo1_l0001`ooooo`00
7?ooool00ol0003oooooooooo`1Iooooo`[o00004oooool2o`0000Sooooo0_l0000Aooooo`;o0000
00?oooooo`000?l000004Oooool2o`0000kooooo0_l000000ooooooo0000o`000005ooooo`;o0000
0oooool2o`000003ooooool0003o000000Co000000Goooooo`000?l0003o0000ooooo`03o`0003Ko
oooo0_l000000ooooooo0000o`00000eooooo`007?ooool00ol0003oooooooooo`1Iooooo`?o0000
0_ooool5o`0001?ooooo0_l000000ooooooo0000o`00000/ooooo`;o00004oooool3o`0000Cooooo
1?l00004ooooo`?o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o0000=oooool2o`000003
ooooool0003o000003Gooooo000Looooo`03o`000?oooooooooo05[ooooo0_l00003ooooo`Go0000
0oooool2o`0000gooooo0_l000000ooooooo0000o`00000/ooooo`;o00004_ooool4o`000004oooo
ool0003o0000ooooo`Co00001?ooool3o`0000Sooooo0_l0000cooooo`;o00000oooool2o`0003Oo
oooo000Looooo`03o`000?oooooooooo067ooooo1?l000001Ooooooo0000o`000?l0003ooooo00;o
00002_ooool2o`0001Sooooo0_l0000Yooooo`Co000000?oooooo`000?l000002_ooool2o`000003
ooooool0003o000000?ooooo0_l0000eooooo`;o00000oooool2o`0003Oooooo000Looooo`;o0000
H_ooool8o`000003ooooool0003o000001Gooooo0_l00003ooooo`;o000000?oooooo`000?l00000
1Oooool2o`0000;ooooo0_l0000Rooooo`Co000000?oooooo`000?l000000_ooool2o`0000Wooooo
0_l000000ooooooo0000o`000005o`0003Oooooo0_l00004ooooo`;o0000=?ooool001cooooo00?o
0000ooooooooool0HOooool2o`0000;ooooo1Ol0000Eooooo`Co00000oooool2o`000003ooooool0
003o000000Wooooo0_l0000Rooooo`Co00000_ooool5o`0000Wooooo0_l000000ooooooo0000o`00
0004o`0003Cooooo0_l00002ooooo`;o00001?ooool2o`0003Cooooo000Looooo`03o`000?oooooo
oooo067ooooo0ol000000ooooooo0000o`000003o`000003ooooool0003o000000[ooooo0_l00003
ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Oooooo0_l0000Qooooo`;o00001oooool2
o`000003ooooool0003o000000?o0000Aoooool2o`0003kooooo000Looooo`03o`000?oooooooooo
06;ooooo0_l00003ooooo`?o000000?oooooo`000?l000000oooool2o`0000Gooooo0_l000000ooo
oooo0000o`000003o`000003ooooool0003o000000?ooooo0_l00007ooooo`;o00008Oooool2o`00
00[ooooo0ol00019ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0Ioooool5o`0000Co
oooo0_l00004ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o00009?ooool2o`00
00Gooooo0_l0000=ooooo`;o000000?oooooo`000?l00000Boooool2o`0000;ooooo0ol0000foooo
o`007?ooool00ol0003oooooooooo`1Wooooo`Go00002_ooool2o`0000Kooooo0_l0000Tooooo`Co
00001Oooool2o`0000gooooo0_l000000ooooooo0000o`00001;ooooo`;o00000_ooool3o`0003Ko
oooo000Looooo`03o`000?oooooooooo06Kooooo2?l0000@ooooo`;o00000_ooool2o`0000kooooo
0_l0000@ooooo`;o00003Oooool2o`000003ooooool0003o000005Wooooo0_l0000fooooo`007?oo
ool00ol0003oooooooooo`1Vooooo`Co000000Coooooo`000?l0003o00001oooool2o`0000_ooooo
0_l0000>ooooo`;o00007oooool2o`000003ooooool0003o000005Wooooo0_l0000fooooo`007?oo
ool00ol0003oooooooooo`1[ooooo`Go00001Oooool2o`0000_ooooo0_l0000Tooooo`;o000000?o
ooooo`000?l00000Hoooool4o`0003Gooooo000Looooo`03o`000?oooooooooo06_ooooo1Ol00003
ooooo`;o00001Oooool2o`0000Kooooo0_l00006ooooo`;o00001oooool2o`0001?ooooo0_l00000
0ooooooo0000o`00000=ooooo`;o0000D?ooool2o`0000;ooooo1?l0000eooooo`007?ooool00ol0
003oooooooooo`1/ooooo`Go00000_ooool3o`0000;ooooo1?l00003ooooo`;o00002Oooool2o`00
00Oooooo0_l0000Rooooo`;o000000?oooooo`000?l000003_ooool2o`00043ooooo0_l00003oooo
o`;o0000=_ooool001cooooo00?o0000ooooooooool0K?ooool6o`0000;ooooo0_l00002ooooo`;o
00001Oooool2o`0000;ooooo0_l00009ooooo`;o00009oooool2o`0000?ooooo0_l0000<ooooo`;o
0000=oooool2o`0000Oooooo0_l00003ooooo`;o0000=_ooool001cooooo00?o0000ooooooooool0
KOooool8o`0000[ooooo0_l00002ooooo`?o00002?ooool2o`0001cooooo0_l00003ooooo`;o0000
0_ooool9o`0001cooooo0_l0000Vooooo`?o00001oooool2o`0003_ooooo000Looooo`03o`000?oo
oooooooo06gooooo2?l0000:ooooo`;o00000oooool2o`0002Kooooo0_l00003ooooo`;o00000_oo
ool2o`0000;ooooo1?l0000Iooooo`?o000000?oooooo`000?l000006_ooool4o`0000Sooooo0_l0
000;ooooo`?o0000=oooool001cooooo00?o0000ooooooooool0Koooool5o`0000Cooooo0_l00005
ooooo`;o0000:oooool3o`0000_ooooo0_l0000=ooooo`;o00002oooool3o`0000Gooooo0_l0000F
ooooo`Co00002Oooool2o`000003ooooool0003o000000;o00001?ooool4o`0003Oooooo000Loooo
o`03o`000?oooooooooo06oooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l0000coooo
o`;o00002Oooool4o`0000?ooooo0_l00008ooooo`;o00002Oooool2o`0000Cooooo1_l0000Coooo
o`;o00000_ooool2o`0000[ooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o0000
00?o0000>?ooool001cooooo0_l0001booooo`Go0000?oooool2o`000003ooooool0003o000000;o
00000oooool2o`0001?ooooo0_l00004ooooo`Co00001oooool2o`0000cooooo0_l0000:ooooo`?o
00001_ooool3o`000004ooooool0003o0000o`0003[ooooo000Looooo`03o`000?oooooooooo077o
oooo1_l00005ooooo`;o00006Oooool2o`0000Cooooo0_l0000Dooooo`Co00000oooool2o`000003
ooooool0003o0000017ooooo1Ol0000:ooooo`;o00001?ooool3o`000004ooooool0003o0000oooo
o`;o00004Oooool3o`0000Kooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`1cooooo`Co
00001Oooool2o`0000Gooooo0_l0000Booooo`;o00001?ooool2o`0001Cooooo0_l00005ooooo`;o
000000?oooooo`000?l000001_ooool2o`0000Wooooo1Ol0000:ooooo`Co00000oooool2o`000004
ooooool0003o0000ooooo`;o00004?ooool2o`0000cooooo0_l0000kooooo`007?ooool00ol0003o
ooooooooo`1dooooo`Go00002_ooool2o`0001[ooooo0_l0000Tooooo`;o000000Coooooo`000?l0
003o00000_ooool2o`0000?ooooo0_l00003ooooo`;o00002?ooool2o`0000;ooooo0ol00003oooo
o`?o00002Oooool2o`0000Gooooo0ol0000;ooooo`?o0000>_ooool001cooooo00?o0000oooooooo
ool0M?ooool5o`0000Oooooo0_l0000Mooooo`;o00002?ooool2o`00013ooooo0_l00008ooooo`;o
000000?oooooo`000?l000001_l000000ooooooo0000o`000003ooooo`?o00001?ooool2o`0000;o
oooo0_l00002ooooo`?o00000oooool4o`0000;ooooo0_l00004ooooo`;o00000oooool2o`000003
ooooool0003o000000cooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`1fooooo`Ko0000
1?ooool2o`0001[ooooo0_l00003ooooo`;o00001_ooool2o`0000gooooo0_l000000ooooooo0000
o`000007ooooo`oo00000oooool2o`0000Gooooo0_l00007ooooo`;o00001Oooool2o`0000;ooooo
0_l00009ooooo`Go0000B?ooool001cooooo00?o0000ooooooooool0M_ooool6o`0000Wooooo0_l0
000Eooooo`;o00000oooool2o`0001Gooooo0_l00003ooooo`;o00001OoooolBo`0000[ooooo0_l0
0009ooooo`;o00004?ooool2o`000004ooooool0003o0000o`0000Kooooo0_l0000nooooo`007?oo
ool00ol0003oooooooooo`1eooooo`Ko00002_ooool2o`0001Cooooo0_l0000Dooooo`Co00001ooo
ool3o`0000Gooooo5_l00004ooooo`Co00001_ooool2o`000003ooooool0003o000000;ooooo1?l0
000:ooooo`Ko00001_ooool4o`0003cooooo000Looooo`03o`000?oooooooooo07Gooooo1_l0000P
ooooo`;o00005?ooool4o`0000;ooooo0_l00003ooooo`;o00001_oooolHo`0000;ooooo0_l00005
ooooo`;o000000?oooooo`000?l000001Oooool4o`0000Cooooo0_l00005ooooo`;o00002Oooool4
o`0003cooooo000Looooo`03o`000?oooooooooo07Sooooo1_l00004ooooo`;o0000<oooool2o`00
00Gooooo1Ol000000ooooooo0000o`00000Fo`0000Kooooo0_l000000ooooooo0000o`000002oooo
o`;o00003?ooool3o`0000Gooooo0_l00003ooooo`;o00000_ooool5o`0003cooooo000Looooo`03
o`000?oooooooooo07Sooooo1_l00004ooooo`;o0000:?ooool2o`0000[ooooo0_l00004ooooo`Go
000000?oooooo`000?l000005_l00006ooooo`;o00001Oooool2o`0000Kooooo0_l000001?oooooo
0000o`000?ooool3o`0000Gooooo0_l000000ooooooo0000o`000002o`0000;ooooo0ol0000noooo
o`007?ooool00ol0003oooooooooo`1dooooo`;o000000?oooooo`000?l000001?l0000Yooooo`;o
00001?ooool2o`0000[ooooo1Ol00009oooooaSo00002oooool2o`0000Cooooo1?l000001?oooooo
0000o`000?ooool2o`0000Kooooo0_l000000ooooooo0000o`000003o`0000;ooooo0_l0000noooo
o`007?ooool00ol0003oooooooooo`1dooooo`So00006oooool2o`0000Sooooo0_l00003ooooo`;o
00004_ooool3o`0000Kooooo0_l00003oooooaKo000000?oooooo`000?l000002?ooool2o`0000Co
oooo0_l0000;ooooo`;o000000?oooooo`000?l000001?ooool2o`0004;ooooo000Looooo`03o`00
0?oooooooooo06Cooooo2?l000001?oooooo0000o`000?l00002ooooo`;o000000?oooooo`000?l0
00001Ol0000Kooooo`;o00002?ooool2o`0000?ooooo0_l00003ooooo`;o00003Oooool2o`000004
ooooool0003o0000ooooo`;o000000?oooooo`000?l000000_l00002oooooaSo00001?ooool4o`00
01?ooooo0_l0001;ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool0
1Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0Hoooool=o`000004ooooool0
003o0000o`0000?ooooo1Ol00004ooooo`;o00002?ooool2o`0000gooooo0_l00006ooooo`;o0000
0oooool2o`0000?ooooo0_l000000ooooooo0000o`00000=ooooo`;o000000?oooooo`000?l00000
0_ooool4o`000003ooooool0003o000001Go00001?ooool5o`0000Kooooo0_l00005ooooo`;o0000
1?ooool2o`0000;ooooo1?l00015ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o
8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0H_ooool>o`00
0003ooooool0003o000000So00001Oooool2o`0000Sooooo0_l0000:ooooo`Go00001_ooool2o`00
00Cooooo0_l00005ooooo`;o00002_ooool2o`0000Sooooo6ol00005ooooo`Go00001_ooool6o`00
0003ooooool0003o000000?ooooo0_l00003ooooo`Co00000_ooool2o`00047ooooo00000ooooooo
410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo05oooooo7?l0000Kooooo`Co00001oooool2o`0000Cooooo0_l00007oooo
o`;o00002?ooool2o`0000[ooooo0ol000000ooooooo0000o`00000Eo`0000?ooooo0ol00002oooo
o`;o00001_ooool4o`000004ooooool0003o0000ooooo`Co000000?oooooo`000?l000001?l00000
1?oooooo0000o`000?l00011ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09
ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0005kooooo7Ol0000Jooooo`Go00005_oo
ool2o`0001Kooooo6Ol00003ooooo`?o00000_ooool2o`0000_ooooo1_l00002ooooo`;o00001?oo
ool3o`0004;ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000
oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo05gooooo7_l0000Aooooo`;o00001ooo
ool5o`00013ooooo0_l0000Looooo`;o000000Goooooo`000?l0003o0000ooooo`0@o`0001Kooooo
1?l00003ooooo`Co00001?ooool2o`0004?ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oo
oooooooo00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`1Moooooago00004_oo
ool2o`0000oooooo0_l00007ooooo`;o00000_ooool2o`0001oooooo5ol0000Cooooo`;o00001Ooo
ool4o`0000;ooooo0_l00015ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgM
gOl@413oV9RH00Sooooo00?o0000ooooooooool0F_ooool7o`000003ooooool0003o000001Ko0000
8oooool2o`0000?ooooo0_l00002ooooo`;o00001_ooool4o`0000Cooooo0_l0000CoooooaOo0000
4oooool2o`0000Sooooo1Ol00015ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`04
olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0F_oooolPo`0000Wooooo0_l00002oooo
o`;o00006Oooool2o`0000[ooooo1?l00004ooooo`;o00004ooooolGo`0001?ooooo0_l00008oooo
o`Co0000A_ooool001cooooo00?o0000ooooooooool0F?oooolQo`0000Cooooo0ol00003ooooo`;o
00000_ooool2o`0001?ooooo0_l00008ooooo`?o00001oooool2o`0001[ooooo5ol00006ooooo`;o
000000?oooooo`000?l000000ol00003ooooo`Go00001Oooool5o`0004Kooooo000Looooo`03o`00
0?oooooooooo05Sooooo7ol00006ooooo`?o00004Oooool3o`0000Sooooo0_l00008ooooo`?o0000
1?ooool3o`0001gooooo6ol000000ooooooo0000o`000006o`0000?ooooo1Ol00005ooooo`?o0000
B?ooool001cooooo00?o0000ooooooooool0FOoooolNo`000003ooooool0003o000000Cooooo0_l0
0005ooooo`;o00002_ooool3o`0000cooooo0_l0000;ooooo`Co00007?oooolTo`0000?ooooo0_l0
00000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l00000B?ooool001cooooo00?o0000
ooooooooool0EooooolPo`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000001Ooo
ool2o`0000Sooooo0_l0000?ooooo`;o00001_ooool2o`0000Gooooo0_l00003ooooo`;o000000?o
ooooo`000?l000000oooool2o`00017ooooo8_l00003ooooo`Go00000oooool2o`0004_ooooo000L
ooooo`03o`000?oooooooooo05Oooooo7ol00005ooooo`;o00004_ooool2o`0000?ooooo0_l0000B
ooooo`;o00001Oooool4o`000003ooooool0003o000000Co00000_ooool2o`0001?ooooo9ol00000
0ooooooo0000o`00001>ooooo`007?ooool00ol0003oooooooooo`1Gooooo`?o000000?oooooo`00
0?l000003_l000000ooooooo0000o`000006o`0001Wooooo1?l00003ooooo`;o00001?ooool2o`00
01Cooooo0ol00002ooooo`;o000000?oooooo`000?l000006OoooolYo`0004gooooo000Looooo`03
o`000?oooooooooo05Kooooo0ol00002oooooaWo00004_ooool2o`0000Gooooo1?l00009ooooo`;o
00001?ooool4o`0001?ooooo0_l0000LooooobOo0000COooool001cooooo00?o0000ooooooooool0
E_oooolNo`0001;ooooo0_l00007ooooo`;o00003oooool4o`0001?ooooo0_l0000MooooobCo0000
Coooool001cooooo00?o0000ooooooooool0EOoooolOo`00013ooooo0_l00002ooooo`;o00001Ooo
ool2o`0000Sooooo0_l0000Jooooo`;o00001Oooool2o`0001gooooo0_l000001?oooooo0000o`00
0?ooool2o`000003ooooool0003o000000oo000000?oooooo`000?l00000DOooool001cooooo00?o
0000ooooooooool0EOooool8o`0000;ooooo4_l00009ooooo`;o00002?ooool2o`0000;ooooo0_l0
0005ooooo`;o00002?ooool2o`0000;ooooo0_l0000Fooooo`;o00001Oooool2o`0008_ooooo000L
ooooo`03o`000?oooooooooo05Gooooo1Ol00005oooooa;o00002Oooool2o`0000;ooooo1?l00009
ooooo`;o00001_ooool2o`0000Cooooo0_l00002ooooo`;o00007oooool2o`0008Wooooo000Loooo
o`;o0000E_ooool6o`0000Kooooo0_l00004ooooo`Ko000000Coooooo`000?l0003o00003Oooool4
o`0000Sooooo1Ol00004ooooo`So00008oooool2o`0008Wooooo000Looooo`03o`000?oooooooooo
05Kooooo1Ol00002ooooo`Oo00002_ooool4o`0000Gooooo0_l0000Aooooo`;o000000?oooooo`00
0?l000001_ooool4o`0002Gooooo0_l00029ooooo`007?ooool00ol0003oooooooooo`1Eooooo`Go
00000oooool7o`0000cooooo0_l00005ooooo`;o00005?ooool2o`0000Cooooo0_l0000Qooooo`;o
00001?ooool4o`0008Wooooo000Looooo`03o`000?oooooooooo05Gooooo1Ol0000Fooooo`;o0000
0oooool2o`0000Wooooo0_l00003ooooo`;o00001_ooool2o`0000Cooooo0_l0000Qooooo`?o0000
0oooool2o`0008_ooooo000Looooo`03o`000?oooooooooo05Sooooo0ol000000ooooooo0000o`00
0004ooooo`;o000000?oooooo`000?l000002Oooool2o`0000?ooooo0_l00002ooooo`;o00001Ooo
ool2o`0000?ooooo0_l00002ooooo`;o00000_ooool4o`0002Gooooo0ol00005ooooo`;o0000ROoo
ool001cooooo00?o0000ooooooooool0EOooool?o`000003ooooool0003o000000kooooo0_l00002
ooooo`;o00001_ooool2o`0000?ooooo1Ol00004ooooo`;o00008_ooool5o`000004ooooool0003o
0000ooooo`Co0000ROooool001cooooo00?o0000ooooooooool0EOooool7o`000003ooooool0003o
000000Go00000_ooool2o`0000Sooooo0_l00003ooooo`;o00000_ooool2o`0000Cooooo1Ol00002
ooooo`Go0000:?ooool4o`0000;ooooo1Ol0002;ooooo`007?ooool00ol0003oooooooooo`1Ioooo
o`;o00000oooool7o`000003ooooool0003o000000;o00001_ooool3o`0000;ooooo0_l00002oooo
o`;o00001?ooool2o`000003ooooool0003o000000Gooooo0_l0000Zooooo`Oo0000SOooool001co
oooo00?o0000ooooooooool0FOooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`0000?o
oooo0_l00007ooooo`?o000000?oooooo`000?l000003_ooool2o`000003ooooool0003o000001co
oooo0_l0000<ooooo`Ko0000Soooool001cooooo00?o0000ooooooooool0E_ooool2o`000003oooo
ool0003o000000Kooooo1?l0000=ooooo`?o00004?ooool5o`0001Cooooo2_l0000:ooooo`Ko0000
1Oooool2o`0008[ooooo000Looooo`03o`000?oooooooooo05Gooooo0ol000000ooooooo0000o`00
0005ooooo`Go00001?ooool4o`0000Kooooo1?l000000ooooooo0000o`000007ooooo`;o000000Co
ooooo`000?l0003ooooo0_l0000CoooooaCo00000_ooool3o`000004ooooool0003o0000ooooo`;o
000000Coooooo`000?l0003o0000R_ooool001cooooo00?o0000ooooooooool0EOooool3o`0000;o
oooo0_l00002ooooo`Ko00001Oooool4o`0000Oooooo0ol000000ooooooo0000o`000004ooooo`;o
000000Coooooo`000?l0003ooooo0ol0000Eoooooa_o00000_ooool6o`0008[ooooo000Looooo`03
o`000?oooooooooo05Kooooo0ol000000ooooooo0000o`000002ooooo`Ko00000_ooool2o`0000co
oooo0_l00008ooooo`;o00001?ooool3o`0001?ooooo7Ol00004ooooo`Co0000R_ooool001cooooo
00?o0000ooooooooool0E_ooool9o`0000?ooooo0_l00002ooooo`?o00000oooool2o`0001Cooooo
0_l0000Eooooo`Ko000000?oooooo`000?l000005Ol00003ooooo`Go0000R_ooool001cooooo00?o
0000ooooooooool0E_ooool2o`000003ooooool0003o000000Co00002?ooool2o`0000?ooooo0_l0
00000ooooooo0000o`00000?ooooo`Co00004ooooolOo`0000Cooooo1Ol0002:ooooo`007?ooool0
0ol0003oooooooooo`1Jooooo`Co00003_ooool2o`000004ooooool0003o0000ooooo`;o000000?o
ooooo`000?l000001_ooool2o`000003ooooool0003o000001Cooooo8?l00003ooooo`;o000000?o
ooooo`000?l00000Roooool001cooooo0_l0001Looooo`?o00003oooool3o`0000;ooooo0_l00000
0ooooooo0000o`000006ooooo`;o00005_oooolPo`0000Cooooo0_l000000ooooooo0000o`00002;
ooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o000000?oooooo`000?l000000_l00003oooo
o`;o00002Oooool3o`0000Gooooo0_l00007ooooo`;o00005OoooolRo`0009;ooooo000Looooo`03
o`000?oooooooooo05Sooooo0ol000000ooooooo0000o`000002o`0000;ooooo0ol00002ooooo`;o
000000?oooooo`000?l000000_ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`00
0?l000001?ooool3o`0001Gooooo7_l00002ooooo`Co0000T?ooool001cooooo00?o0000oooooooo
ool0FOooool2o`000003ooooool0003o000000Co000000?oooooo`000?l000000_ooool2o`000003
ooooool0003o000000Gooooo2?l00004ooooo`;o00005OoooolOo`0000Cooooo0_l000000ooooooo
0000o`00002=ooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o000000Coooooo`000?l0003o
oooo0_l0000<ooooo`Co000000?oooooo`000?l000000_ooool4o`0001Gooooo8?l00002ooooo`So
0000S?ooool001cooooo00?o0000ooooooooool0N_ooool4o`0001Gooooo7ol00003ooooo`?o0000
00?oooooo`000?l000000_l0002<ooooo`007?ooool00ol0003oooooooooo`1Looooo`;o000000?o
ooooo`000?l000004?ooool2o`0000Kooooo0ol0000Goooooako00002?ooool3o`0008gooooo000L
ooooo`03o`000?oooooooooo05cooooo1ol0000;ooooo`Go00001_ooool3o`0001Kooooo1ol00005
oooooa7o0000V_ooool001cooooo00?o0000ooooooooool0GOooool2o`0000;ooooo0_l00003oooo
o`;o00001_ooool3o`00027ooooo0ol00002ooooo`;o00001Oooool?o`0009cooooo000Looooo`03
o`000?oooooooooo05gooooo0ol00002ooooo`;o00000_ooool2o`0000Kooooo0_l0000Rooooo`?o
00003Oooool8o`0009oooooo000Looooo`03o`000?oooooooooo05kooooo1_l0000Booooo`?o0000
6Oooool3o`0000kooooo1Ol000000ooooooo0000o`00002Nooooo`007?ooool00ol0003ooooooooo
o`1Nooooo`Oo00000_ooool2o`000003ooooool0003o000000Wooooo1?l0000Iooooo`?o00001?oo
ool2o`0000_ooooo0_l000000ooooooo0000o`00002Nooooo`007?ooool00ol0003oooooooooo`1Q
ooooo`oo00000oooool5o`0001[ooooo1?l00003ooooo`Oo00004_ooool2o`0009Gooooo000Loooo
o`03o`000?oooooooooo06;ooooo3_l000000ooooooo0000o`000004o`0001cooooo1Ol00003oooo
o`Ko00001?ooool2o`0000Gooooo1?l00002ooooo`;o0000UOooool001cooooo00?o0000oooooooo
ool0I?ooool2o`000003ooooool0003o000000ko00007?ooool5o`0000Oooooo0_l00003ooooo`?o
00001Oooool4o`0009Wooooo000Looooo`03o`000?oooooooooo06Oooooo0_l000000ooooooo0000
o`000007o`00023ooooo0ol0000>ooooo`;o00002Oooool2o`0009Sooooo000Looooo`;o0000Kooo
ool4o`00027ooooo0_l00002ooooo`?o00003oooool4o`0000;ooooo0_l0002Hooooo`007?ooool0
0ol0003oooooooooo`2Dooooo`Ko00003oooool4o`0009cooooo000Looooo`03o`000?oooooooooo
09Cooooo1ol000000ooooooo0000o`000004ooooo`;o00002oooool2o`0009Sooooo000Looooo`03
o`000?oooooooooo09Cooooo1ol000001?oooooo0000o`000?l00003ooooo`;o000000?oooooo`00
0?l000002?ooool4o`0009Kooooo000Looooo`03o`000?oooooooooo09Cooooo0ol00005ooooo`?o
00001_ooool2o`0000Wooooo1?l0002Eooooo`007?ooool00ol0003oooooooooo`2Fooooo`;o0000
1?ooool3o`0000;ooooo1?l0000<ooooo`?o0000UOooool001cooooo00?o0000ooooooooool0U_oo
ool4o`0000?ooooo0_l00002ooooo`Co00003?ooool2o`0000;ooooo0ol0002Aooooo`007?ooool0
0ol0003oooooooooo`2Gooooo`Co00003_ooool2o`0000Wooooo1?l0002Aooooo`007?ooool00ol0
003oooooooooo`2Gooooo`Ko00002_ooool4o`0000;ooooo0_l00005ooooo`;o0000Toooool001co
oooo00?o0000ooooooooool0VOooool4o`0000[ooooo0_l00004ooooo`?o00001_ooool2o`00097o
oooo000Looooo`03o`000?oooooooooo09Wooooo1Ol00002ooooo`Go00000_ooool2o`0000Gooooo
1?l00004ooooo`;o00000_ooool2o`0008gooooo000Looooo`03o`000?oooooooooo09cooooo0_l0
0002ooooo`Go00000_ooool3o`0000Cooooo1?l000001?oooooo0000o`000?l00002ooooo`Ko0000
Roooool001cooooo00?o0000ooooooooool0W?ooool3o`0000;ooooo0ol00004ooooo`;o00001?oo
ool2o`0000?ooooo0ol00002ooooo`So0000ROooool001cooooo00?o0000ooooooooool0WOooool6
o`0000Gooooo0_l00004ooooo`;o00003Oooool3o`0008Wooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`2Nooooo`Go00000oooool2o`0000?ooooo0_l0000Booooo`;o0000R?ooool00006oooooomg
MgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06oooo
o`03o`000?oooooooooo0:7ooooo0_l00003ooooo`;o00000oooool2o`0000Wooooo0_l00007oooo
o`;o0000R?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool0XOooool2o`0000;ooooo0_l00008oooo
o`Wo000000Coooooo`000?l0003o0000SOooool00003ooooool0003ooooo00;ooooo00?o0000oooo
ooooool02Oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0002Uooooo`?o00001oooool7
o`0000?ooooo0ol0002=ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09oooo
o`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`2Uooooo`?o00003?ooool2
o`0009?ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go410@okZj
^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo0:Kooooo0_l000000ooooooo0000o`000003
ooooo`;o00001?ooool2o`0009?ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go
0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0:Wooooo0_l000000ooooooo0000
o`000002o`0000Kooooo0_l0002Aooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05
ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`2/ooooo`Co000000?oooooo`00
0?l000000oooool2o`00097ooooo000Looooo`03o`000?oooooooooo0;7ooooo0_l0002Fooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBooo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001;ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oo
oooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
oooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo0ol0003ooooood[ooooo000Dooooo`03
o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?oo
ool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool0
01;ooooo00?oEEEEofIVI_l00000oooooomDooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00YOooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo01Kooooo1?l0
00002?l@413ooooooooooonHV9So410@o`000?lb<S;oc<c<0oooool5o`00093ooooo002Vooooo`05
o`000?ooooooooooooooool000002Oooool6o`0000cooooo00?o0000ooooooooool00_ooool01Ol@
413o^[ZjoooooomgMgOo<S8b00?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A02@ooooo`00Y_ooool0
1Ol0003ooooooooooooooooo000001_ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`02ooooo`03oiRHV?lQ8B7ok^k^097ooooo002Vooooo`05o`000?ooooooooooooooool000002Ooo
ool6o`0000cooooo00?o0000ooooooooool01Oooool00onYZJWo410@ooooo`04ooooo`03oiRHV?lQ
8B7ok^k^093ooooo002Vooooo`05o`000?n7QhOoooooojVYZOl000006oooool00ol0003ooooooooo
o`04ooooo`03oa0@4?l0003o^[Zj00Kooooo00?oMgMgofIVI_ooool0Soooool00:Gooooo00?o410@
o`000?mgMgL00_l000000onHV9Soooooooooo`0Iooooo`03o`000?oooooooooo00Gooooo00?o^[Zj
ob4Q8Oooool01_ooool00ol0003oooooooooo`2>ooooo`00a_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?nHV9SooooookZj^_l000000oooool01Ol0003o^[ZjoooooonHV9So410@093ooooo0034
ooooo`03oeEEEOmVIVKo000000Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`0T?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001
\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(138) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.29997 .56351 Mdot
.31493 .60287 Mdot
.65331 .59821 Mdot
.41951 .3606 Mdot
.67439 .39461 Mdot
.65965 .61053 Mdot
.47998 .70357 Mdot
.48595 .68561 Mdot
.62127 .59233 Mdot
.49405 .44072 Mdot
.50878 .72547 Mdot
.47154 .36449 Mdot
.48343 .6958 Mdot
.43467 .3991 Mdot
.49817 .29769 Mdot
.28487 .35601 Mdot
.34491 .59404 Mdot
.67837 .40468 Mdot
.28076 .36344 Mdot
.61903 .58801 Mdot
.74079 .32262 Mdot
.43742 .37702 Mdot
.33343 .57183 Mdot
.4332 .40018 Mdot
.28624 .36157 Mdot
.30291 .6028 Mdot
.29189 .56836 Mdot
.30002 .36847 Mdot
.46986 .34166 Mdot
.50248 .73172 Mdot
.3108 .37665 Mdot
.56048 .29804 Mdot
.63323 .4342 Mdot
.34191 .49813 Mdot
.52151 .70005 Mdot
.53839 .71087 Mdot
.63144 .6036 Mdot
.52333 .72595 Mdot
.46558 .70553 Mdot
.52057 .71244 Mdot
.52203 .71268 Mdot
.30194 .59745 Mdot
.52809 .70903 Mdot
.51143 .80561 Mdot
.4162 .40864 Mdot
.28703 .44099 Mdot
.60819 .58649 Mdot
.45966 .33163 Mdot
.34419 .57686 Mdot
.70027 .66423 Mdot
.57378 .36495 Mdot
.5064 .69633 Mdot
.62758 .46257 Mdot
.24529 .4145 Mdot
.47712 .69165 Mdot
.2837 .3637 Mdot
.67133 .63448 Mdot
.4189 .38818 Mdot
.46823 .32763 Mdot
.33691 .48904 Mdot
.42242 .37064 Mdot
.68167 .38569 Mdot
.27213 .6331 Mdot
.67938 .62026 Mdot
.63078 .5803 Mdot
.52736 .72679 Mdot
.33808 .61367 Mdot
.47972 .67581 Mdot
.42641 .35241 Mdot
.61509 .60411 Mdot
.46428 .35765 Mdot
.5096 .72554 Mdot
.31212 .61871 Mdot
.44769 .36748 Mdot
.31864 .55932 Mdot
.45457 .67821 Mdot
.67609 .40189 Mdot
.3693 .60504 Mdot
.69523 .66369 Mdot
.36173 .35724 Mdot
.44176 .36694 Mdot
.31835 .72729 Mdot
.43587 .27081 Mdot
.28802 .59801 Mdot
.44475 .40434 Mdot
.26992 .7054 Mdot
.41466 .43211 Mdot
.31002 .36623 Mdot
.29435 .36563 Mdot
.46872 .30975 Mdot
.67269 .64824 Mdot
.32328 .57385 Mdot
.43308 .38682 Mdot
.41723 .35799 Mdot
.48053 .4488 Mdot
.45927 .34513 Mdot
.28981 .36548 Mdot
.60994 .46434 Mdot
.5153 .71291 Mdot
.62851 .4829 Mdot
.43755 .69333 Mdot
.61812 .4722 Mdot
.45753 .39383 Mdot
.64414 .61631 Mdot
.27839 .5873 Mdot
.61672 .44959 Mdot
.50043 .68009 Mdot
.43393 .39044 Mdot
.54077 .70983 Mdot
.32643 .57144 Mdot
.30089 .38181 Mdot
.69851 .37102 Mdot
.74044 .36848 Mdot
.32422 .61669 Mdot
.34672 .42296 Mdot
.40551 .39372 Mdot
.4335 .36642 Mdot
.31092 .60097 Mdot
.62085 .5782 Mdot
.57424 .66842 Mdot
.32697 .58623 Mdot
.51435 .71816 Mdot
.34684 .59452 Mdot
.63457 .4304 Mdot
.62388 .57795 Mdot
.64789 .4675 Mdot
.60966 .4746 Mdot
.57081 .31969 Mdot
.45146 .33896 Mdot
.62075 .43163 Mdot
.64044 .61842 Mdot
.32375 .58804 Mdot
.49347 .69669 Mdot
.40682 .36958 Mdot
.29138 .59728 Mdot
.47257 .69442 Mdot
.71974 .35793 Mdot
.72208 .35852 Mdot
.30396 .61402 Mdot
.3534 .43195 Mdot
.5326 .7217 Mdot
.46516 .68438 Mdot
.57134 .3655 Mdot
.29229 .60613 Mdot
.68571 .35174 Mdot
.46809 .68634 Mdot
.70085 .58153 Mdot
.29424 .38082 Mdot
.58737 .32944 Mdot
.32985 .72341 Mdot
.57236 .36602 Mdot
.73784 .32578 Mdot
.68338 .37862 Mdot
.47244 .69298 Mdot
.40047 .41574 Mdot
.32853 .6079 Mdot
.29499 .60224 Mdot
.46751 .3671 Mdot
.62364 .44199 Mdot
.40809 .39755 Mdot
.62414 .48597 Mdot
.60901 .47588 Mdot
.43147 .39725 Mdot
.30597 .45741 Mdot
.29476 .5756 Mdot
.41931 .4242 Mdot
.62856 .60779 Mdot
.69025 .40898 Mdot
.53374 .71642 Mdot
.44323 .40405 Mdot
.39519 .42476 Mdot
.45949 .40307 Mdot
.46522 .68301 Mdot
.43963 .76397 Mdot
.68899 .66657 Mdot
.49105 .72451 Mdot
.4385 .68814 Mdot
.6518 .63551 Mdot
.46425 .32676 Mdot
.69445 .36938 Mdot
.63778 .45659 Mdot
.4131 .42107 Mdot
.5752 .36596 Mdot
.47224 .32204 Mdot
.74047 .34619 Mdot
.73513 .3405 Mdot
.30921 .71775 Mdot
.42646 .74103 Mdot
.40722 .37822 Mdot
.32377 .37485 Mdot
.58226 .34884 Mdot
.55675 .67937 Mdot
.49786 .70068 Mdot
.61178 .57481 Mdot
.61742 .57855 Mdot
.71667 .66967 Mdot
.45897 .42416 Mdot
.46786 .39011 Mdot
.44094 .35663 Mdot
.62826 .47334 Mdot
.27388 .63057 Mdot
.68235 .37927 Mdot
.33838 .60369 Mdot
.32148 .72748 Mdot
.37863 .32998 Mdot
.27515 .37059 Mdot
.73008 .65873 Mdot
.68558 .62574 Mdot
.61647 .45935 Mdot
.68845 .35895 Mdot
.41434 .38685 Mdot
.30865 .56863 Mdot
.57758 .35662 Mdot
.64369 .43943 Mdot
.7403 .28781 Mdot
.33564 .58729 Mdot
.4166 .29746 Mdot
.47791 .69577 Mdot
.66075 .64783 Mdot
.41492 .43194 Mdot
.443 .38769 Mdot
.3624 .6112 Mdot
.40475 .37772 Mdot
.29984 .38871 Mdot
.29695 .37764 Mdot
.70164 .66641 Mdot
.4323 .69956 Mdot
.48267 .72045 Mdot
.60701 .58598 Mdot
.31808 .6179 Mdot
.28456 .44719 Mdot
.65564 .62316 Mdot
.74277 .33226 Mdot
.51375 .72672 Mdot
.71437 .35189 Mdot
.6519 .61734 Mdot
.67472 .39391 Mdot
.46949 .32613 Mdot
.64006 .63398 Mdot
.70073 .37742 Mdot
.51096 .33646 Mdot
.61408 .45705 Mdot
.66509 .363 Mdot
.47965 .70628 Mdot
.35713 .59511 Mdot
.41198 .42159 Mdot
.63255 .46081 Mdot
.65124 .45024 Mdot
.45523 .30555 Mdot
.62663 .49639 Mdot
.63558 .43932 Mdot
.45754 .31162 Mdot
.68634 .40245 Mdot
.39147 .67301 Mdot
.30954 .37851 Mdot
.34502 .59684 Mdot
.40774 .37325 Mdot
.42732 .71131 Mdot
.47147 .69475 Mdot
.41621 .37996 Mdot
.30383 .72406 Mdot
.4806 .70914 Mdot
.42562 .38586 Mdot
.46896 .71436 Mdot
.28941 .59685 Mdot
.38132 .32449 Mdot
.30242 .61672 Mdot
.42921 .3983 Mdot
.46981 .71637 Mdot
.61052 .58802 Mdot
.30264 .60412 Mdot
.43541 .38387 Mdot
.43619 .35309 Mdot
.62859 .47011 Mdot
.29593 .37885 Mdot
.44501 .69309 Mdot
.47077 .36586 Mdot
.68063 .63451 Mdot
.4675 .34578 Mdot
.72482 .3623 Mdot
.73071 .59262 Mdot
.29277 .60736 Mdot
.62709 .49768 Mdot
.66063 .61921 Mdot
.54023 .40061 Mdot
.40243 .30426 Mdot
.4194 .41023 Mdot
.64074 .4443 Mdot
.42543 .26558 Mdot
.49343 .71725 Mdot
.29864 .38622 Mdot
.63139 .42072 Mdot
.67167 .63174 Mdot
.62057 .47442 Mdot
.46022 .36892 Mdot
.32612 .56894 Mdot
.28381 .35918 Mdot
.65503 .64088 Mdot
.34025 .58489 Mdot
.44478 .41306 Mdot
.44074 .68961 Mdot
.60376 .48261 Mdot
.49767 .71789 Mdot
.30575 .36926 Mdot
.46291 .32699 Mdot
.6168 .60759 Mdot
.30048 .5949 Mdot
.47964 .68766 Mdot
.30612 .61694 Mdot
.54968 .39077 Mdot
.42152 .2931 Mdot
.29827 .61847 Mdot
.7168 .37398 Mdot
.75776 .67018 Mdot
.50676 .72328 Mdot
.63968 .47783 Mdot
.62646 .64241 Mdot
.33737 .56901 Mdot
.64808 .6125 Mdot
.36751 .44402 Mdot
.67266 .64639 Mdot
.27827 .36215 Mdot
.61684 .62074 Mdot
.45748 .413 Mdot
.43146 .416 Mdot
.65507 .58747 Mdot
.61061 .45806 Mdot
.4562 .37043 Mdot
.29122 .59536 Mdot
.5514 .29109 Mdot
.43766 .45936 Mdot
.45736 .42475 Mdot
.66976 .63295 Mdot
.3591 .4419 Mdot
.30176 .37732 Mdot
.30297 .36759 Mdot
.32864 .60396 Mdot
.64061 .47357 Mdot
.7136 .34071 Mdot
.70579 .33511 Mdot
.77187 .57505 Mdot
.41097 .25599 Mdot
.34353 .41628 Mdot
.30111 .60805 Mdot
.73044 .66955 Mdot
.29554 .56141 Mdot
.64219 .43906 Mdot
.4867 .68563 Mdot
.44744 .77382 Mdot
.41858 .43165 Mdot
.61006 .43347 Mdot
.2949 .38926 Mdot
.35041 .58711 Mdot
.32866 .62141 Mdot
.48068 .68665 Mdot
.44664 .43465 Mdot
.49388 .43941 Mdot
.40984 .38608 Mdot
.4862 .68368 Mdot
.64952 .44514 Mdot
.46431 .31656 Mdot
.5755 .30703 Mdot
.52796 .81443 Mdot
.42203 .40697 Mdot
.35501 .51251 Mdot
.42299 .41831 Mdot
.57383 .32673 Mdot
.41533 .39327 Mdot
.29715 .59479 Mdot
.25051 .36072 Mdot
.39592 .38568 Mdot
.7302 .65582 Mdot
.37782 .33299 Mdot
.70297 .38487 Mdot
.43955 .38805 Mdot
.40784 .40747 Mdot
.69549 .34444 Mdot
.30632 .57978 Mdot
.44138 .34045 Mdot
.39477 .67084 Mdot
.43404 .38089 Mdot
.53451 .71546 Mdot
.44945 .28558 Mdot
.55973 .3012 Mdot
.29894 .37504 Mdot
.32903 .56949 Mdot
.46517 .69785 Mdot
.52541 .71606 Mdot
.63839 .48969 Mdot
.47107 .6949 Mdot
.4317 .41361 Mdot
.4503 .28589 Mdot
.33205 .61731 Mdot
.6162 .45442 Mdot
.32294 .57636 Mdot
.65944 .53107 Mdot
.48444 .70745 Mdot
.6212 .46423 Mdot
.46076 .43019 Mdot
.49617 .70981 Mdot
.45527 .6479 Mdot
.30306 .38204 Mdot
.65005 .44697 Mdot
.30367 .5627 Mdot
.61551 .60877 Mdot
.64212 .4423 Mdot
.47685 .69095 Mdot
.41605 .40941 Mdot
.28532 .36931 Mdot
.47099 .69192 Mdot
.36243 .52561 Mdot
.30747 .38342 Mdot
.43249 .38055 Mdot
.29229 .58351 Mdot
.31563 .58711 Mdot
.41415 .42565 Mdot
.4026 .39307 Mdot
.6685 .61916 Mdot
.64415 .44732 Mdot
.64608 .45024 Mdot
.6131 .48818 Mdot
.66885 .64524 Mdot
.7525 .67327 Mdot
.48374 .67453 Mdot
.55812 .30088 Mdot
.42845 .73641 Mdot
.62981 .45748 Mdot
.66753 .61631 Mdot
.42071 .41546 Mdot
.46085 .3929 Mdot
.46867 .71633 Mdot
.79439 .64288 Mdot
.4217 .4318 Mdot
.34202 .60638 Mdot
.49992 .68809 Mdot
.46831 .38542 Mdot
.7134 .66701 Mdot
.6884 .39027 Mdot
.34252 .41726 Mdot
.49955 .68912 Mdot
.36828 .54382 Mdot
.49989 .68972 Mdot
.40861 .40958 Mdot
.45874 .35972 Mdot
.35882 .60268 Mdot
.70366 .3848 Mdot
.46973 .36463 Mdot
.4242 .39208 Mdot
.73472 .66989 Mdot
.28907 .56425 Mdot
.70757 .3348 Mdot
.47134 .33886 Mdot
.61221 .47261 Mdot
.68836 .39514 Mdot
.44447 .36233 Mdot
.46844 .34979 Mdot
.63485 .42425 Mdot
.47776 .72359 Mdot
.71373 .37586 Mdot
.73219 .65704 Mdot
.33925 .59134 Mdot
.44639 .68206 Mdot
.64245 .49042 Mdot
.50839 .72304 Mdot
.5191 .3823 Mdot
.6181 .46429 Mdot
.47847 .80019 Mdot
.6256 .17439 Mdot
.63212 .44229 Mdot
.67637 .62883 Mdot
.47337 .45181 Mdot
.4689 .35422 Mdot
.43189 .38124 Mdot
.72052 .34563 Mdot
.31478 .59476 Mdot
.42698 .74157 Mdot
.48256 .72239 Mdot
.44303 .39314 Mdot
.29324 .60964 Mdot
.2949 .7169 Mdot
.62317 .47259 Mdot
.70802 .36427 Mdot
.71578 .35775 Mdot
.4511 .36839 Mdot
.41806 .26237 Mdot
.30045 .60348 Mdot
.43534 .38447 Mdot
.45201 .36239 Mdot
.63652 .64823 Mdot
.2866 .58428 Mdot
.64182 .63458 Mdot
.277 .37344 Mdot
.33832 .39192 Mdot
.42811 .71605 Mdot
.47338 .70356 Mdot
.64635 .46546 Mdot
.48437 .7207 Mdot
.67395 .66457 Mdot
.64568 .45002 Mdot
.43593 .384 Mdot
.33227 .6174 Mdot
.4348 .38545 Mdot
.43372 .3823 Mdot
.41275 .40234 Mdot
.33991 .41376 Mdot
.69248 .65702 Mdot
.70302 .36265 Mdot
.47039 .33185 Mdot
.66243 .64137 Mdot
.71602 .66094 Mdot
.49337 .4422 Mdot
.4422 .37776 Mdot
.43075 .37117 Mdot
.37029 .60182 Mdot
.29141 .38081 Mdot
.49523 .70726 Mdot
.35907 .6019 Mdot
.41138 .43255 Mdot
.60768 .58869 Mdot
.4392 .34098 Mdot
.29861 .61828 Mdot
.49641 .67714 Mdot
.25008 .62194 Mdot
.64757 .4832 Mdot
.6463 .47476 Mdot
.63826 .44113 Mdot
.61594 .49304 Mdot
.53266 .713 Mdot
.66677 .61388 Mdot
.64904 .52123 Mdot
.34618 .38418 Mdot
.40214 .39217 Mdot
.45938 .36378 Mdot
.62654 .64083 Mdot
.62551 .433 Mdot
.4164 .45298 Mdot
.26921 .36541 Mdot
.65128 .64887 Mdot
.60936 .46751 Mdot
.25847 .66803 Mdot
.33493 .57628 Mdot
.68801 .66382 Mdot
.52017 .72701 Mdot
.70093 .37986 Mdot
.82917 .53128 Mdot
.32323 .58004 Mdot
.26695 .62502 Mdot
.63356 .6179 Mdot
.4566 .29565 Mdot
.23437 .40141 Mdot
.64935 .60888 Mdot
.30637 .38687 Mdot
.31934 .61138 Mdot
.61161 .46388 Mdot
.42695 .26839 Mdot
.45016 .29485 Mdot
.62215 .61102 Mdot
.43689 .35172 Mdot
.63542 .5706 Mdot
.67406 .63031 Mdot
.64441 .46494 Mdot
.66927 .63294 Mdot
.48825 .71721 Mdot
.64446 .62427 Mdot
.36297 .52783 Mdot
.43551 .34679 Mdot
.24389 .41326 Mdot
.49611 .28381 Mdot
.40484 .39255 Mdot
.50601 .70831 Mdot
.44241 .68513 Mdot
.41796 .3691 Mdot
.67333 .37617 Mdot
.67467 .62491 Mdot
.71132 .67004 Mdot
.282 .37016 Mdot
.61854 .62426 Mdot
.3254 .56818 Mdot
.43677 .69252 Mdot
.43794 .68993 Mdot
.64135 .44258 Mdot
.29108 .60199 Mdot
.45486 .67541 Mdot
.51482 .71718 Mdot
.6022 .46935 Mdot
.41232 .42362 Mdot
.30148 .57317 Mdot
.46377 .31531 Mdot
.68634 .40774 Mdot
.43486 .37898 Mdot
.6429 .63415 Mdot
.69991 .66712 Mdot
.49823 .29201 Mdot
.65805 .62445 Mdot
.64452 .47083 Mdot
.294 .57834 Mdot
.28076 .36617 Mdot
.32129 .58662 Mdot
.41265 .36359 Mdot
.42971 .70503 Mdot
.3349 .5749 Mdot
.74236 .33231 Mdot
.42318 .37359 Mdot
.30333 .45435 Mdot
.47235 .33506 Mdot
.43312 .37896 Mdot
.62912 .57767 Mdot
.69314 .3462 Mdot
.70135 .39817 Mdot
.71051 .65859 Mdot
.67665 .38211 Mdot
.26856 .58591 Mdot
.62417 .57612 Mdot
.7006 .35098 Mdot
.77481 .57441 Mdot
.62643 .49884 Mdot
.70191 .35707 Mdot
.44362 .40561 Mdot
.46869 .6966 Mdot
.34893 .6095 Mdot
.456 .37459 Mdot
.39346 .44161 Mdot
.29381 .34418 Mdot
.62633 .46951 Mdot
.43165 .3772 Mdot
.40662 .40723 Mdot
.2949 .61094 Mdot
.33043 .72534 Mdot
.67974 .62715 Mdot
.63281 .48215 Mdot
.32537 .58237 Mdot
.3169 .72733 Mdot
.63358 .5804 Mdot
.70858 .34701 Mdot
.47293 .71343 Mdot
.36996 .55136 Mdot
.6288 .46486 Mdot
.47963 .70491 Mdot
.70187 .65854 Mdot
.56738 .37312 Mdot
.30132 .3553 Mdot
.63796 .60381 Mdot
.5727 .3662 Mdot
.28064 .37854 Mdot
.71853 .66966 Mdot
.55647 .67815 Mdot
.32566 .57189 Mdot
.47263 .68737 Mdot
.71022 .36712 Mdot
.31433 .62001 Mdot
.32354 .57616 Mdot
.47337 .7045 Mdot
.24297 .36475 Mdot
.42432 .26884 Mdot
.46479 .67568 Mdot
.46157 .30078 Mdot
.56847 .36977 Mdot
.63107 .46597 Mdot
.69809 .36657 Mdot
.43234 .69971 Mdot
.30221 .59809 Mdot
.44437 .76353 Mdot
.57622 .36365 Mdot
.29932 .38513 Mdot
.69811 .38176 Mdot
.29997 .71477 Mdot
.54913 .70641 Mdot
.49223 .70778 Mdot
.73447 .67005 Mdot
.67684 .36242 Mdot
.4354 .41378 Mdot
.80491 .63329 Mdot
.44126 .40495 Mdot
.47308 .67941 Mdot
.29534 .38918 Mdot
.33514 .59617 Mdot
.47475 .67552 Mdot
.27386 .36879 Mdot
.47145 .35798 Mdot
.40978 .3771 Mdot
.69528 .66559 Mdot
.36178 .60483 Mdot
.62186 .50611 Mdot
.40444 .39713 Mdot
.42282 .3896 Mdot
.65104 .44541 Mdot
.56143 .30422 Mdot
.54013 .6319 Mdot
.62651 .43701 Mdot
.63916 .6371 Mdot
.61619 .45367 Mdot
.63652 .47833 Mdot
.31338 .56307 Mdot
.7272 .67031 Mdot
.6511 .46189 Mdot
.42629 .40153 Mdot
.43082 .39217 Mdot
.46487 .70373 Mdot
.42554 .26635 Mdot
.45343 .29783 Mdot
.68099 .63283 Mdot
.60561 .44747 Mdot
.4524 .34756 Mdot
.28865 .5979 Mdot
.72317 .34576 Mdot
.63952 .48646 Mdot
.342 .59347 Mdot
.456 .33669 Mdot
.63399 .64626 Mdot
.62816 .44518 Mdot
.65315 .4473 Mdot
.69785 .37843 Mdot
.46196 .68448 Mdot
.36868 .61018 Mdot
.67496 .62948 Mdot
.30692 .36 Mdot
.59923 .48783 Mdot
.65225 .65634 Mdot
.6319 .46756 Mdot
.61524 .47127 Mdot
.29261 .60249 Mdot
.36929 .54067 Mdot
.65212 .43246 Mdot
.66771 .6423 Mdot
.50857 .81657 Mdot
.51489 .70341 Mdot
.46367 .32854 Mdot
.47952 .71619 Mdot
.32496 .57118 Mdot
.5714 .31797 Mdot
.7141 .35341 Mdot
.49327 .7108 Mdot
.63566 .43811 Mdot
.32865 .5753 Mdot
.36454 .61235 Mdot
.4298 .40016 Mdot
.43888 .3776 Mdot
.60804 .58613 Mdot
.5846 .33761 Mdot
.46599 .71155 Mdot
.71288 .3414 Mdot
.66258 .60503 Mdot
.28371 .36853 Mdot
.33118 .60811 Mdot
.67764 .33853 Mdot
.47319 .33224 Mdot
.66488 .63966 Mdot
.31619 .60492 Mdot
.70382 .33642 Mdot
.70366 .36139 Mdot
.40622 .41859 Mdot
.73661 .32599 Mdot
.48972 .7133 Mdot
.29294 .59622 Mdot
.26098 .59566 Mdot
.4673 .33227 Mdot
.4402 .38105 Mdot
.2939 .3848 Mdot
.46836 .67298 Mdot
.4426 .40625 Mdot
.70859 .37744 Mdot
.3267 .61436 Mdot
.42418 .41601 Mdot
.68034 .35389 Mdot
.61889 .50369 Mdot
.61885 .45828 Mdot
.6489 .58316 Mdot
.68562 .3427 Mdot
.68464 .34907 Mdot
.67794 .35708 Mdot
.44805 .77453 Mdot
.4687 .38267 Mdot
.62278 .51668 Mdot
.43832 .35206 Mdot
.56669 .37157 Mdot
.31194 .36161 Mdot
.51287 .70837 Mdot
.61804 .6102 Mdot
.41009 .39544 Mdot
.43818 .35315 Mdot
.36135 .59108 Mdot
.28259 .35599 Mdot
.4211 .42316 Mdot
.33703 .60059 Mdot
.26168 .60681 Mdot
.61541 .57079 Mdot
.32856 .72304 Mdot
.82574 .60415 Mdot
.46956 .3197 Mdot
.45729 .29044 Mdot
.3111 .57735 Mdot
.46888 .70917 Mdot
.46139 .29825 Mdot
.46403 .68299 Mdot
.31124 .59051 Mdot
.28366 .35281 Mdot
.36196 .52496 Mdot
.682 .38693 Mdot
.40922 .40963 Mdot
.47624 .70795 Mdot
.40822 .40367 Mdot
.47401 .70823 Mdot
.35868 .44645 Mdot
.43332 .26783 Mdot
.40106 .39277 Mdot
.46013 .34474 Mdot
.73998 .32135 Mdot
.44076 .37734 Mdot
.73994 .66995 Mdot
.32232 .60428 Mdot
.61524 .43429 Mdot
.29289 .35024 Mdot
.43872 .45964 Mdot
.43227 .37113 Mdot
.31586 .35104 Mdot
.43338 .36427 Mdot
.78871 .64973 Mdot
.47118 .32406 Mdot
.41711 .42249 Mdot
.49897 .69803 Mdot
.51468 .72334 Mdot
.36552 .60552 Mdot
.61616 .47006 Mdot
.30452 .71665 Mdot
.42616 .38685 Mdot
.65935 .59499 Mdot
.71608 .39657 Mdot
.68954 .34454 Mdot
.33339 .61252 Mdot
.61736 .16945 Mdot
.52908 .71068 Mdot
.62746 .616 Mdot
.31153 .37753 Mdot
.6405 .63658 Mdot
.68115 .62575 Mdot
.26526 .58552 Mdot
.6994 .36588 Mdot
.43382 .3433 Mdot
.34269 .49589 Mdot
.26001 .6249 Mdot
.46694 .33222 Mdot
.6232 .57192 Mdot
.63525 .42435 Mdot
.35035 .27892 Mdot
.6816 .40304 Mdot
.67963 .367 Mdot
.47577 .69686 Mdot
.65867 .59366 Mdot
.633 .48111 Mdot
.70619 .35059 Mdot
.61358 .5727 Mdot
.63057 .49673 Mdot
.73478 .67368 Mdot
.29915 .60237 Mdot
.3613 .44237 Mdot
.28071 .43708 Mdot
.50222 .71785 Mdot
.71951 .66704 Mdot
.32679 .6194 Mdot
.29222 .61116 Mdot
.63088 .47568 Mdot
.64331 .64518 Mdot
.28099 .61226 Mdot
.40929 .41872 Mdot
.6146 .45881 Mdot
.44884 .38589 Mdot
.67812 .40625 Mdot
.4288 .38768 Mdot
.61159 .59066 Mdot
.50257 .7035 Mdot
.66867 .62637 Mdot
.47592 .69975 Mdot
.55566 .29691 Mdot
.42226 .38053 Mdot
.43898 .38611 Mdot
.45013 .28685 Mdot
.30421 .56619 Mdot
.34375 .49829 Mdot
.66745 .63757 Mdot
.66927 .62917 Mdot
.29257 .35047 Mdot
.34813 .59792 Mdot
.65681 .46046 Mdot
.46256 .30151 Mdot
.43546 .36246 Mdot
.32223 .60275 Mdot
.31535 .36405 Mdot
.49155 .80984 Mdot
.43679 .27354 Mdot
.31447 .56456 Mdot
.74529 .67512 Mdot
.45127 .35697 Mdot
.63251 .48527 Mdot
.61051 .44506 Mdot
.41701 .25754 Mdot
.68313 .40712 Mdot
.33706 .58787 Mdot
.62566 .48423 Mdot
.32829 .60972 Mdot
.67471 .64571 Mdot
.52116 .69189 Mdot
.33052 .60061 Mdot
.43022 .3673 Mdot
.82614 .60272 Mdot
.46819 .69996 Mdot
.4149 .41347 Mdot
.48369 .67582 Mdot
.33801 .61964 Mdot
.32319 .59154 Mdot
.6309 .49657 Mdot
.30491 .38686 Mdot
.49175 .7127 Mdot
.40039 .40991 Mdot
.35604 .51559 Mdot
.28384 .35897 Mdot
.68945 .40813 Mdot
.45326 .34631 Mdot
.46264 .33759 Mdot
.74644 .66987 Mdot
.5413 .40066 Mdot
.42713 .70936 Mdot
.53773 .71319 Mdot
.43819 .76396 Mdot
.29516 .56834 Mdot
.70687 .39189 Mdot
.36677 .61135 Mdot
.64748 .4629 Mdot
.63219 .63031 Mdot
.41221 .40501 Mdot
.61881 .4977 Mdot
.46276 .67512 Mdot
.69627 .35893 Mdot
.4722 .32204 Mdot
.63838 .59767 Mdot
.61867 .48951 Mdot
.4873 .70759 Mdot
.30279 .59419 Mdot
.3388 .59592 Mdot
.73158 .67502 Mdot
.42185 .41674 Mdot
.43758 .38005 Mdot
.51448 .69002 Mdot
.73367 .33043 Mdot
.67587 .38205 Mdot
.61082 .45727 Mdot
.50956 .68501 Mdot
.43654 .27264 Mdot
.36169 .61234 Mdot
.40968 .41518 Mdot
.4486 .28264 Mdot
.43324 .75421 Mdot
.26043 .65704 Mdot
.67903 .37703 Mdot
.40463 .29648 Mdot
.33614 .58722 Mdot
.49229 .69503 Mdot
.77178 .57831 Mdot
.28907 .38312 Mdot
.42342 .35957 Mdot
.39477 .30748 Mdot
.45518 .30802 Mdot
.31162 .37036 Mdot
.64515 .48672 Mdot
.42797 .29672 Mdot
.29703 .35119 Mdot
.29651 .35566 Mdot
.45682 .35004 Mdot
.45572 .34672 Mdot
.32239 .59772 Mdot
.45713 .42375 Mdot
.63954 .62598 Mdot
.31291 .38574 Mdot
.69715 .3273 Mdot
.30585 .37943 Mdot
.46632 .37372 Mdot
.26092 .6638 Mdot
.39679 .2612 Mdot
.31532 .61036 Mdot
.33456 .56732 Mdot
.50118 .71938 Mdot
.28176 .36033 Mdot
.6665 .63987 Mdot
.64276 .42377 Mdot
.62161 .62387 Mdot
.32068 .59875 Mdot
.61633 .57187 Mdot
.52537 .72755 Mdot
.63784 .60364 Mdot
.64879 .64652 Mdot
.50425 .70217 Mdot
.36067 .60237 Mdot
.47334 .33716 Mdot
.50484 .70306 Mdot
.65096 .44004 Mdot
.71004 .34837 Mdot
.26118 .61648 Mdot
.61616 .44841 Mdot
.4338 .42575 Mdot
.50808 .81288 Mdot
.63218 .60328 Mdot
.38358 .32156 Mdot
.3484 .58237 Mdot
.67925 .34406 Mdot
.33014 .59781 Mdot
.65423 .43572 Mdot
.68365 .38295 Mdot
.44939 .39784 Mdot
.70501 .32195 Mdot
.55685 .67298 Mdot
.39585 .38826 Mdot
.26156 .60584 Mdot
.62406 .62978 Mdot
.49902 .7154 Mdot
.47451 .64458 Mdot
.63101 .48373 Mdot
.33241 .56968 Mdot
.37747 .55882 Mdot
.64707 .45488 Mdot
.49396 .69743 Mdot
.32004 .46881 Mdot
.40546 .41306 Mdot
.48911 .71985 Mdot
.45176 .34561 Mdot
.35091 .42786 Mdot
.72526 .34848 Mdot
.61173 .4856 Mdot
.27969 .35626 Mdot
.63127 .58135 Mdot
.28921 .35064 Mdot
.41534 .44314 Mdot
.57936 .32084 Mdot
.43588 .35657 Mdot
.38682 .31755 Mdot
.67181 .66453 Mdot
.31795 .61449 Mdot
.63141 .45009 Mdot
.62964 .46802 Mdot
.27666 .36241 Mdot
.86057 .52427 Mdot
.69491 .35501 Mdot
.74204 .67414 Mdot
.42317 .38176 Mdot
.44086 .3677 Mdot
.36703 .60965 Mdot
.36466 .4494 Mdot
.61051 .46661 Mdot
.4274 .35853 Mdot
.40424 .25538 Mdot
.49307 .69108 Mdot
.45767 .39191 Mdot
.45057 .3717 Mdot
.43331 .69397 Mdot
.49694 .69671 Mdot
.66374 .66075 Mdot
.62782 .49981 Mdot
.6476 .58181 Mdot
.67762 .39631 Mdot
.41402 .29709 Mdot
.5662 .30887 Mdot
.43666 .27937 Mdot
.67844 .39056 Mdot
.29991 .37778 Mdot
.42265 .43378 Mdot
.43288 .34954 Mdot
.68197 .36321 Mdot
.49253 .73064 Mdot
.32443 .60172 Mdot
.35511 .4347 Mdot
.63023 .47014 Mdot
.30161 .35793 Mdot
.67453 .39984 Mdot
.32638 .60938 Mdot
.308 .4594 Mdot
.31582 .5957 Mdot
.48874 .70484 Mdot
.71824 .66803 Mdot
.68447 .38471 Mdot
.3308 .59807 Mdot
.62375 .58246 Mdot
.4297 .70738 Mdot
.45716 .40915 Mdot
.52284 .72918 Mdot
.26986 .57949 Mdot
.32463 .5649 Mdot
.30222 .56126 Mdot
.2802 .37125 Mdot
.38608 .31895 Mdot
.64604 .46872 Mdot
.50685 .68243 Mdot
.63431 .58449 Mdot
.58336 .33479 Mdot
.32818 .48116 Mdot
.43318 .30948 Mdot
.45958 .37363 Mdot
.42878 .38935 Mdot
.44883 .36417 Mdot
.65026 .47768 Mdot
.41092 .43693 Mdot
.44104 .35238 Mdot
.46772 .71546 Mdot
.6611 .65964 Mdot
.42196 .38576 Mdot
.62134 .45507 Mdot
.60796 .43587 Mdot
.67912 .34408 Mdot
.32982 .40999 Mdot
.27553 .62818 Mdot
.32952 .60511 Mdot
.65656 .64027 Mdot
.63046 .57391 Mdot
.72041 .35881 Mdot
.48453 .68482 Mdot
.314 .59409 Mdot
.78645 .65024 Mdot
.68872 .38802 Mdot
.42264 .40514 Mdot
.44937 .28636 Mdot
.40326 .26308 Mdot
.46826 .36504 Mdot
.41272 .40032 Mdot
.6282 .44087 Mdot
.66441 .64306 Mdot
.45999 .40737 Mdot
.30741 .45782 Mdot
.67793 .36012 Mdot
.7078 .34394 Mdot
.28146 .583 Mdot
.39932 .41593 Mdot
.47773 .70861 Mdot
.42471 .26436 Mdot
.4446 .69446 Mdot
.27401 .70457 Mdot
.65121 .53074 Mdot
.43776 .34123 Mdot
.45629 .4583 Mdot
.41757 .43217 Mdot
.27848 .58718 Mdot
.3647 .53648 Mdot
.30613 .61002 Mdot
.48976 .6888 Mdot
.55847 .38252 Mdot
.52298 .71421 Mdot
.60989 .46987 Mdot
.33689 .57861 Mdot
.47221 .31343 Mdot
.6687 .62899 Mdot
.28953 .35383 Mdot
.69108 .37364 Mdot
.46061 .31351 Mdot
.63029 .45361 Mdot
.40765 .29612 Mdot
.66667 .61527 Mdot
.35629 .61427 Mdot
.29084 .35313 Mdot
.70837 .65705 Mdot
.43051 .29795 Mdot
.66147 .50756 Mdot
.61813 .49819 Mdot
.68189 .38591 Mdot
.49868 .43907 Mdot
.69837 .38477 Mdot
.49004 .71177 Mdot
.42165 .37817 Mdot
.4159 .4224 Mdot
.43407 .37396 Mdot
.45556 .38288 Mdot
.48029 .68923 Mdot
.29118 .35969 Mdot
.64343 .43048 Mdot
.61969 .4953 Mdot
.30935 .37742 Mdot
.69671 .36365 Mdot
.51507 .70594 Mdot
.64765 .6546 Mdot
.64345 .44099 Mdot
.69897 .39112 Mdot
.39287 .40499 Mdot
.42845 .36184 Mdot
.61473 .48721 Mdot
.44626 .40204 Mdot
.29103 .36284 Mdot
.63806 .61117 Mdot
.30348 .36195 Mdot
.67616 .34853 Mdot
.69194 .37695 Mdot
.46981 .69486 Mdot
.33162 .59907 Mdot
.71783 .3636 Mdot
.66032 .60448 Mdot
.42064 .42848 Mdot
.45419 .34707 Mdot
.36343 .52846 Mdot
.576 .36487 Mdot
.67711 .34812 Mdot
.43782 .4121 Mdot
.28529 .58732 Mdot
.38276 .57481 Mdot
.42623 .35757 Mdot
.29564 .36718 Mdot
.31428 .56246 Mdot
.7084 .34945 Mdot
.48085 .68293 Mdot
.50707 .28863 Mdot
.46687 .68218 Mdot
.302 .59314 Mdot
.62616 .48241 Mdot
.35925 .5976 Mdot
.62894 .48481 Mdot
.27349 .68342 Mdot
.44741 .34957 Mdot
.35948 .52262 Mdot
.63354 .42851 Mdot
.67097 .63736 Mdot
.65793 .65362 Mdot
.6298 .44505 Mdot
.3377 .58504 Mdot
.64488 .46813 Mdot
.7066 .3745 Mdot
.43876 .76098 Mdot
.32368 .56243 Mdot
.64858 .64692 Mdot
.63297 .60114 Mdot
.51158 .68616 Mdot
.42978 .38098 Mdot
.40842 .41413 Mdot
.64069 .60248 Mdot
.44457 .69307 Mdot
.31603 .57327 Mdot
.43748 .38121 Mdot
.63278 .43506 Mdot
.63814 .62052 Mdot
.55069 .68675 Mdot
.33805 .62106 Mdot
.2807 .35417 Mdot
.57756 .31779 Mdot
.536 .71382 Mdot
.43008 .42554 Mdot
.29076 .36488 Mdot
.68972 .3524 Mdot
.40129 .29883 Mdot
.57028 .36638 Mdot
.52959 .71975 Mdot
.64627 .47394 Mdot
.46793 .36884 Mdot
.66945 .65091 Mdot
.42326 .42572 Mdot
.64471 .1935 Mdot
.61205 .48205 Mdot
.43366 .40724 Mdot
.60809 .45496 Mdot
.32222 .58659 Mdot
.43702 .37483 Mdot
.42821 .71445 Mdot
.65706 .63719 Mdot
.42142 .41643 Mdot
.74214 .32399 Mdot
.47786 .67558 Mdot
.62947 .45412 Mdot
.67666 .38067 Mdot
.31318 .38048 Mdot
.55161 .29174 Mdot
.6274 .64191 Mdot
.70567 .35902 Mdot
.42947 .37798 Mdot
.66505 .6068 Mdot
.51126 .72367 Mdot
.6316 .44814 Mdot
.39381 .39722 Mdot
.5138 .71465 Mdot
.50024 .69462 Mdot
.69307 .38332 Mdot
.28276 .44832 Mdot
.41023 .36381 Mdot
.4367 .39863 Mdot
.30861 .46524 Mdot
.37818 .59374 Mdot
.40949 .40801 Mdot
.45346 .37597 Mdot
.47897 .70583 Mdot
.55828 .38634 Mdot
.4058 .29711 Mdot
.63084 .42787 Mdot
.50313 .71314 Mdot
.62019 .56872 Mdot
.62953 .61578 Mdot
.71127 .35898 Mdot
.3149 .60468 Mdot
.72014 .36738 Mdot
.64753 .62935 Mdot
.42594 .4039 Mdot
.47883 .67987 Mdot
.33466 .38677 Mdot
.47804 .67467 Mdot
.65453 .60175 Mdot
.29848 .61718 Mdot
.44864 .42339 Mdot
.64092 .1899 Mdot
.52336 .62893 Mdot
.72135 .67341 Mdot
.69029 .34458 Mdot
.30814 .45848 Mdot
.42648 .37657 Mdot
.45477 .42133 Mdot
.41878 .4142 Mdot
.72087 .37561 Mdot
.61827 .61953 Mdot
.63068 .49674 Mdot
.63163 .48364 Mdot
.40725 .29985 Mdot
.49922 .69264 Mdot
.52647 .71402 Mdot
.61838 .47932 Mdot
.49164 .70381 Mdot
.43872 .3995 Mdot
.65831 .61035 Mdot
.26488 .67876 Mdot
.43445 .36272 Mdot
.60162 .47542 Mdot
.53331 .72358 Mdot
.29983 .62082 Mdot
.62008 .56955 Mdot
.44685 .45976 Mdot
.31347 .71949 Mdot
.49635 .71102 Mdot
.33057 .40935 Mdot
.66195 .63823 Mdot
.64227 .44041 Mdot
.66898 .61048 Mdot
.43162 .40639 Mdot
.43851 .34072 Mdot
.65176 .44897 Mdot
.43555 .36446 Mdot
.34294 .50466 Mdot
.2927 .38569 Mdot
.26753 .37328 Mdot
.43746 .35173 Mdot
.26804 .59186 Mdot
.5009 .72629 Mdot
.61974 .48066 Mdot
.45728 .31238 Mdot
.45511 .3373 Mdot
.29605 .56698 Mdot
.51217 .71284 Mdot
.34011 .71879 Mdot
.48724 .68915 Mdot
.67289 .63732 Mdot
.49013 .68637 Mdot
.41841 .43146 Mdot
.31131 .58685 Mdot
.65088 .62194 Mdot
.62877 .45949 Mdot
.62403 .59677 Mdot
.40474 .39501 Mdot
.55137 .69773 Mdot
.62816 .61788 Mdot
.29571 .38514 Mdot
.31328 .58749 Mdot
.71923 .31726 Mdot
.27352 .63295 Mdot
.42827 .40455 Mdot
.41654 .41191 Mdot
.6116 .45609 Mdot
.47259 .69232 Mdot
.35633 .6165 Mdot
.73731 .67276 Mdot
.67919 .34467 Mdot
.31311 .60864 Mdot
.72186 .34173 Mdot
.45683 .29635 Mdot
.32356 .61696 Mdot
.40575 .25548 Mdot
.4721 .70273 Mdot
.33928 .59289 Mdot
.71364 .40293 Mdot
.32366 .37588 Mdot
.70078 .36854 Mdot
.63327 .57688 Mdot
.46054 .29621 Mdot
.63501 .62675 Mdot
.42942 .70461 Mdot
.7017 .66684 Mdot
.49414 .71472 Mdot
.74198 .3268 Mdot
.29633 .38964 Mdot
.52387 .72437 Mdot
.42806 .73284 Mdot
.64464 .63334 Mdot
.61563 .47758 Mdot
.29958 .36224 Mdot
.65429 .4555 Mdot
.62355 .48872 Mdot
.52912 .7146 Mdot
.34108 .59512 Mdot
.34592 .60235 Mdot
.61396 .4366 Mdot
.33862 .59844 Mdot
.64629 .61116 Mdot
.44161 .27725 Mdot
.46049 .43099 Mdot
.50072 .72712 Mdot
.31438 .37877 Mdot
.46458 .36743 Mdot
.61517 .61435 Mdot
.65457 .61114 Mdot
.49461 .69049 Mdot
.25118 .63597 Mdot
.63173 .48744 Mdot
.32774 .62274 Mdot
.32592 .57959 Mdot
.32596 .58673 Mdot
.35413 .58607 Mdot
.56415 .37677 Mdot
.50639 .70822 Mdot
.33574 .58386 Mdot
.45691 .36185 Mdot
.453 .36721 Mdot
.64526 .44333 Mdot
.7088 .39011 Mdot
.29921 .36657 Mdot
.64459 .47218 Mdot
.4162 .36953 Mdot
.66892 .63287 Mdot
.71047 .39597 Mdot
.64631 .47736 Mdot
.66641 .6417 Mdot
.66907 .64247 Mdot
.64337 .48464 Mdot
.70584 .39774 Mdot
.34409 .50567 Mdot
.32779 .37199 Mdot
.26478 .59864 Mdot
.64386 .64691 Mdot
.42456 .72442 Mdot
.36014 .5227 Mdot
.42296 .41934 Mdot
.61346 .44871 Mdot
.66594 .61801 Mdot
.32793 .56321 Mdot
.44341 .37805 Mdot
.63264 .4756 Mdot
.70443 .37124 Mdot
.62586 .45924 Mdot
.62416 .44351 Mdot
.29487 .57354 Mdot
.51759 .80654 Mdot
.29376 .60988 Mdot
.69505 .6578 Mdot
.63414 .45758 Mdot
.24132 .41058 Mdot
.62861 .63646 Mdot
.44096 .76371 Mdot
.29869 .3893 Mdot
.42861 .3538 Mdot
.655 .63987 Mdot
.32441 .56789 Mdot
.49407 .73197 Mdot
.39705 .25757 Mdot
.33197 .59773 Mdot
.64235 .49079 Mdot
.62623 .44466 Mdot
.63808 .62354 Mdot
.30183 .58777 Mdot
.29114 .36557 Mdot
.33302 .5906 Mdot
.51833 .69963 Mdot
.44213 .40942 Mdot
.306 .71691 Mdot
.63321 .48033 Mdot
.33768 .6062 Mdot
.63799 .58625 Mdot
.70853 .378 Mdot
.43721 .41023 Mdot
.30719 .72456 Mdot
.43095 .37379 Mdot
.51871 .6958 Mdot
.5998 .45772 Mdot
.32016 .36948 Mdot
.41581 .39654 Mdot
.4628 .38946 Mdot
.45054 .68161 Mdot
.41481 .39145 Mdot
.46547 .33703 Mdot
.29598 .44848 Mdot
.3061 .61523 Mdot
.42303 .38489 Mdot
.64321 .60454 Mdot
.57308 .62805 Mdot
.44738 .38527 Mdot
.71117 .65586 Mdot
.41521 .26145 Mdot
.64666 .42707 Mdot
.69659 .40858 Mdot
.57214 .31899 Mdot
.42489 .41028 Mdot
.40224 .38882 Mdot
.4452 .40573 Mdot
.47055 .43417 Mdot
.65168 .6332 Mdot
.65475 .58765 Mdot
.71214 .36823 Mdot
.39092 .31047 Mdot
.6937 .37868 Mdot
.50987 .72386 Mdot
.27488 .37256 Mdot
.62161 .49989 Mdot
.33288 .60249 Mdot
.43545 .37149 Mdot
.64486 .58511 Mdot
.4307 .40843 Mdot
.28803 .37347 Mdot
.64217 .61394 Mdot
.66839 .62266 Mdot
.68172 .61407 Mdot
.68526 .34588 Mdot
.32259 .60924 Mdot
.40677 .42586 Mdot
.67532 .36848 Mdot
.65293 .4534 Mdot
.49487 .27857 Mdot
.31732 .61092 Mdot
.33315 .60984 Mdot
.3567 .60026 Mdot
.4041 .42452 Mdot
.40651 .4288 Mdot
.52152 .71006 Mdot
.36445 .5286 Mdot
.47246 .67929 Mdot
.651 .63995 Mdot
.67498 .65017 Mdot
.4284 .40973 Mdot
.72112 .33222 Mdot
.69701 .36499 Mdot
.62667 .59762 Mdot
.60863 .47977 Mdot
.71108 .37818 Mdot
.4015 .4089 Mdot
.64017 .63277 Mdot
.67471 .36506 Mdot
.25032 .6358 Mdot
.35852 .69786 Mdot
.70866 .37916 Mdot
.63421 .48263 Mdot
.33165 .48307 Mdot
.57985 .33032 Mdot
.72485 .34828 Mdot
.50402 .72617 Mdot
.47317 .3317 Mdot
.6108 .48464 Mdot
.70376 .38775 Mdot
.58829 .34235 Mdot
.64519 .62301 Mdot
.63578 .48287 Mdot
.74215 .36345 Mdot
.46252 .42836 Mdot
.7034 .38555 Mdot
.33576 .60874 Mdot
.30966 .62712 Mdot
.41729 .40442 Mdot
.30698 .38524 Mdot
.48358 .72426 Mdot
.6294 .57523 Mdot
.64894 .58529 Mdot
.37065 .54844 Mdot
.43667 .27673 Mdot
.63609 .60865 Mdot
.46268 .32543 Mdot
.69628 .3942 Mdot
.45666 .36053 Mdot
.61571 .43138 Mdot
.32309 .37114 Mdot
.69045 .41115 Mdot
.70848 .37872 Mdot
.49821 .72815 Mdot
.50189 .70334 Mdot
.4742 .69211 Mdot
.63569 .61341 Mdot
.45748 .30172 Mdot
.65845 .59204 Mdot
.28113 .44401 Mdot
.69792 .35427 Mdot
.75496 .67289 Mdot
.41775 .43414 Mdot
.41426 .3709 Mdot
.30717 .35783 Mdot
.62611 .43843 Mdot
.42959 .40572 Mdot
.51563 .71472 Mdot
.62363 .58331 Mdot
.55364 .68968 Mdot
.29373 .58112 Mdot
.28437 .44518 Mdot
.66701 .62684 Mdot
.60396 .48189 Mdot
.69212 .37028 Mdot
.57203 .30159 Mdot
.72514 .36806 Mdot
.6761 .62951 Mdot
.41644 .3599 Mdot
.31559 .56077 Mdot
.79061 .64552 Mdot
.43549 .37626 Mdot
.63137 .60237 Mdot
.60873 .58448 Mdot
.32084 .37843 Mdot
.52596 .41646 Mdot
.55612 .68383 Mdot
.44492 .28792 Mdot
.68053 .34946 Mdot
.65034 .44202 Mdot
.42589 .25885 Mdot
.64705 .63036 Mdot
.62138 .59395 Mdot
.72297 .34702 Mdot
.29971 .62032 Mdot
.3483 .58753 Mdot
.34836 .51136 Mdot
.51846 .71313 Mdot
.43788 .34774 Mdot
.63988 .63046 Mdot
.30503 .61979 Mdot
.4529 .31694 Mdot
.48004 .69953 Mdot
.62629 .60957 Mdot
.43579 .36476 Mdot
.41787 .39852 Mdot
.69606 .3777 Mdot
.60689 .43715 Mdot
.64006 .43321 Mdot
.43861 .75908 Mdot
.44357 .31221 Mdot
.27413 .36879 Mdot
.4239 .35906 Mdot
.31423 .57129 Mdot
.64696 .45961 Mdot
.69977 .36514 Mdot
.42932 .42291 Mdot
.45284 .42066 Mdot
.32743 .56642 Mdot
.47344 .70478 Mdot
.63288 .46362 Mdot
.41399 .30037 Mdot
.43345 .36757 Mdot
.42176 .4134 Mdot
.28029 .37126 Mdot
.41622 .44055 Mdot
.61786 .61084 Mdot
.28811 .60026 Mdot
.67543 .37383 Mdot
.32029 .5922 Mdot
.73087 .67151 Mdot
.29379 .38694 Mdot
.46844 .32606 Mdot
.28967 .57327 Mdot
.31084 .59358 Mdot
.51768 .69522 Mdot
.50304 .70958 Mdot
.65449 .51957 Mdot
.45123 .38667 Mdot
.61025 .47744 Mdot
.33247 .58341 Mdot
.63219 .57633 Mdot
.69342 .37993 Mdot
.72587 .67457 Mdot
.43513 .35595 Mdot
.64367 .63063 Mdot
.6354 .44875 Mdot
.29354 .57751 Mdot
.66536 .63426 Mdot
.64167 .44005 Mdot
.7072 .34697 Mdot
.4723 .35407 Mdot
.65205 .51977 Mdot
.62547 .47977 Mdot
.45373 .38178 Mdot
.26137 .36905 Mdot
.30979 .38333 Mdot
.63103 .42733 Mdot
.61256 .57209 Mdot
.62742 .47601 Mdot
.33673 .62417 Mdot
.31736 .38193 Mdot
.62942 .58011 Mdot
.36209 .52489 Mdot
.29824 .38883 Mdot
.6274 .48442 Mdot
.32304 .61331 Mdot
.7317 .66915 Mdot
.27933 .57225 Mdot
.57803 .34184 Mdot
.44737 .37737 Mdot
.63464 .62621 Mdot
.70153 .36973 Mdot
.52387 .7065 Mdot
.5421 .70653 Mdot
.42774 .7236 Mdot
.65891 .65036 Mdot
.43663 .36911 Mdot
.33745 .59026 Mdot
.49558 .70974 Mdot
.36745 .60964 Mdot
.65687 .59946 Mdot
.65131 .60504 Mdot
.30727 .35851 Mdot
.69215 .37912 Mdot
.41609 .43568 Mdot
.63496 .5778 Mdot
.70042 .66586 Mdot
.29952 .44982 Mdot
.67458 .3639 Mdot
.27843 .36763 Mdot
.62705 .42478 Mdot
.45995 .38544 Mdot
.30958 .46196 Mdot
.61954 .45085 Mdot
.29491 .58022 Mdot
.40943 .39358 Mdot
.55979 .80131 Mdot
.63045 .63922 Mdot
.4447 .28839 Mdot
.55671 .67323 Mdot
.50602 .69987 Mdot
.65845 .63367 Mdot
.44332 .37166 Mdot
.72521 .67485 Mdot
.7121 .35907 Mdot
.30003 .351 Mdot
.62113 .48316 Mdot
.37866 .56606 Mdot
.48437 .68152 Mdot
.73945 .35534 Mdot
.52398 .70747 Mdot
.4708 .69548 Mdot
.25631 .63863 Mdot
.41831 .40518 Mdot
.66211 .62301 Mdot
.64386 .59906 Mdot
.61539 .43341 Mdot
.69286 .66962 Mdot
.3518 .58878 Mdot
.55663 .79829 Mdot
.46215 .40589 Mdot
.42431 .37313 Mdot
.64457 .48784 Mdot
.61092 .47143 Mdot
.71927 .66964 Mdot
.41346 .39326 Mdot
.30901 .61403 Mdot
.64253 .57982 Mdot
.63082 .61652 Mdot
.29768 .38504 Mdot
.5024 .704 Mdot
.72601 .36699 Mdot
.65065 .61126 Mdot
.50456 .28775 Mdot
.4314 .40989 Mdot
.49962 .73358 Mdot
.64959 .61264 Mdot
.84592 .56684 Mdot
.51043 .81736 Mdot
.29677 .61331 Mdot
.46832 .37885 Mdot
.34078 .61971 Mdot
.70431 .38312 Mdot
.67013 .60718 Mdot
.52623 .71997 Mdot
.63192 .45744 Mdot
.57059 .67235 Mdot
.63357 .61941 Mdot
.32155 .59932 Mdot
.41732 .40827 Mdot
.3243 .40755 Mdot
.43236 .36556 Mdot
.55717 .38751 Mdot
.67681 .34965 Mdot
.54245 .70603 Mdot
.51267 .68791 Mdot
.46807 .38005 Mdot
.67666 .36053 Mdot
.6786 .63313 Mdot
.64147 .61589 Mdot
.31532 .72527 Mdot
.62505 .44325 Mdot
.68038 .62546 Mdot
.45267 .38494 Mdot
.68354 .61761 Mdot
.32793 .48142 Mdot
.50371 .69866 Mdot
.45966 .34737 Mdot
.63612 .63171 Mdot
.27479 .58482 Mdot
.4502 .28982 Mdot
.44369 .39279 Mdot
.60915 .44996 Mdot
.49887 .7113 Mdot
.27906 .44033 Mdot
.61465 .60981 Mdot
.44904 .3522 Mdot
.5093 .71971 Mdot
.73772 .3266 Mdot
.55729 .7194 Mdot
.32155 .60989 Mdot
.63336 .59961 Mdot
.48382 .68299 Mdot
.63928 .45743 Mdot
.6742 .38058 Mdot
.67406 .62021 Mdot
.63146 .62805 Mdot
.29747 .37711 Mdot
.60296 .46815 Mdot
.72413 .34517 Mdot
.31817 .57442 Mdot
.47814 .70654 Mdot
.28977 .37735 Mdot
.51142 .28883 Mdot
.40793 .42977 Mdot
.46888 .69628 Mdot
.2505 .41831 Mdot
.4232 .35309 Mdot
.43605 .35387 Mdot
.32564 .40571 Mdot
.33182 .62484 Mdot
.3293 .57137 Mdot
.43263 .305 Mdot
.29749 .36884 Mdot
.46496 .31528 Mdot
.32693 .60443 Mdot
.31804 .59863 Mdot
.46257 .31634 Mdot
.29431 .37633 Mdot
.35145 .50845 Mdot
.49546 .70597 Mdot
.50622 .70135 Mdot
.32415 .58688 Mdot
.30875 .35844 Mdot
.46929 .70995 Mdot
.37374 .59961 Mdot
.65589 .6043 Mdot
.41783 .26365 Mdot
.31602 .59009 Mdot
.45257 .2841 Mdot
.48929 .71156 Mdot
.52076 .28079 Mdot
.41377 .2612 Mdot
.40034 .39351 Mdot
.41584 .40076 Mdot
.68861 .3477 Mdot
.62794 .45616 Mdot
.64359 .48447 Mdot
.47428 .69098 Mdot
.41143 .43691 Mdot
.305 .60928 Mdot
.40927 .43377 Mdot
.58425 .33481 Mdot
.52723 .27827 Mdot
.47132 .37935 Mdot
.31548 .60331 Mdot
.30246 .60067 Mdot
.67389 .65424 Mdot
.62029 .57531 Mdot
.4609 .32231 Mdot
.50096 .70933 Mdot
.34221 .60166 Mdot
.47529 .67914 Mdot
.64631 .62881 Mdot
.66445 .62282 Mdot
.64834 .45422 Mdot
.63706 .48233 Mdot
.65432 .62861 Mdot
.71181 .65695 Mdot
.5082 .28669 Mdot
.3655 .53241 Mdot
.26481 .4272 Mdot
.5601 .29922 Mdot
.35208 .42985 Mdot
.70386 .36947 Mdot
.71069 .39638 Mdot
.51281 .71799 Mdot
.46063 .39832 Mdot
.40939 .3854 Mdot
.62271 .47232 Mdot
.49992 .72024 Mdot
.68868 .36289 Mdot
.50477 .69891 Mdot
.67492 .38234 Mdot
.63188 .58146 Mdot
.44001 .36701 Mdot
.40836 .37509 Mdot
.51668 .6949 Mdot
.67709 .64671 Mdot
.64063 .63519 Mdot
.70426 .36572 Mdot
.56499 .30499 Mdot
.63982 .62546 Mdot
.31493 .59083 Mdot
.25401 .67179 Mdot
.62029 .45154 Mdot
.44306 .37672 Mdot
.57174 .31573 Mdot
.31584 .38335 Mdot
.65294 .4559 Mdot
.63275 .46452 Mdot
.28469 .4504 Mdot
.40942 .41928 Mdot
.33525 .72373 Mdot
.64734 .47276 Mdot
.35956 .59915 Mdot
.66057 .62492 Mdot
.64971 .47167 Mdot
.63263 .42258 Mdot
.67558 .40884 Mdot
.64888 .47817 Mdot
.34181 .58252 Mdot
.34633 .61788 Mdot
.30386 .36448 Mdot
.23307 .38023 Mdot
.67908 .38454 Mdot
.69602 .36049 Mdot
.62164 .62081 Mdot
.43103 .70604 Mdot
.34871 .38077 Mdot
.70242 .35556 Mdot
.25615 .60587 Mdot
.29978 .35554 Mdot
.31262 .37248 Mdot
.30932 .37426 Mdot
.36277 .6128 Mdot
.41604 .35461 Mdot
.6201 .62152 Mdot
.32238 .60078 Mdot
.30371 .36161 Mdot
.40467 .43215 Mdot
.31202 .61134 Mdot
.47506 .70157 Mdot
.27235 .35415 Mdot
.3373 .59417 Mdot
.39767 .2555 Mdot
.48545 .71268 Mdot
.45588 .41191 Mdot
.75684 .64144 Mdot
.85411 .54883 Mdot
.49935 .69544 Mdot
.62663 .60748 Mdot
.64348 .63358 Mdot
.63893 .61235 Mdot
.32878 .57271 Mdot
.66759 .6572 Mdot
.29926 .58707 Mdot
.71953 .67302 Mdot
.39906 .30622 Mdot
.68389 .3839 Mdot
.69068 .66511 Mdot
.32571 .58753 Mdot
.29976 .45673 Mdot
.62458 .17335 Mdot
.45078 .35351 Mdot
.52702 .72193 Mdot
.71649 .35751 Mdot
.44515 .2805 Mdot
.68939 .35229 Mdot
.66127 .63871 Mdot
.41121 .29895 Mdot
.42969 .41024 Mdot
.35209 .70486 Mdot
.69937 .37107 Mdot
.31732 .5975 Mdot
.30153 .37862 Mdot
.61361 .56752 Mdot
.7108 .35992 Mdot
.69169 .37589 Mdot
.43549 .39834 Mdot
.35671 .61456 Mdot
.65641 .64174 Mdot
.4959 .71883 Mdot
.70758 .66472 Mdot
.50234 .32276 Mdot
.41131 .4204 Mdot
.44404 .34727 Mdot
.45569 .29302 Mdot
.72426 .67207 Mdot
.49665 .7024 Mdot
.58128 .35587 Mdot
.61251 .60579 Mdot
.58239 .32698 Mdot
.27679 .58775 Mdot
.68989 .66602 Mdot
.61759 .45473 Mdot
.64557 .4428 Mdot
.43625 .38389 Mdot
.63385 .18198 Mdot
.53239 .40863 Mdot
.4723 .7141 Mdot
.61777 .46455 Mdot
.67062 .65893 Mdot
.34333 .57552 Mdot
.74143 .36993 Mdot
.29655 .36522 Mdot
.49211 .71878 Mdot
.64042 .62051 Mdot
.67255 .21249 Mdot
.69356 .34279 Mdot
.44109 .28821 Mdot
.45359 .36479 Mdot
.43788 .38499 Mdot
.4797 .69383 Mdot
.48516 .72741 Mdot
.2782 .43576 Mdot
.63315 .41691 Mdot
.297 .71698 Mdot
.45983 .67607 Mdot
.6881 .22343 Mdot
.61116 .47527 Mdot
.29696 .59793 Mdot
.63836 .49262 Mdot
.48821 .72775 Mdot
.40867 .40026 Mdot
.35141 .61656 Mdot
.63507 .44654 Mdot
.26983 .62761 Mdot
.31328 .37824 Mdot
.50332 .28606 Mdot
.42825 .3907 Mdot
.35185 .6027 Mdot
.32394 .60472 Mdot
.33369 .61869 Mdot
.63431 .4423 Mdot
.42805 .3581 Mdot
.44422 .35341 Mdot
.44111 .34853 Mdot
.28042 .43555 Mdot
.43862 .37079 Mdot
.31515 .55935 Mdot
.43266 .27585 Mdot
.56587 .8071 Mdot
.40867 .37516 Mdot
.47959 .68445 Mdot
.43283 .38803 Mdot
.69329 .33776 Mdot
.46998 .36198 Mdot
.30816 .38713 Mdot
.49166 .70082 Mdot
.41515 .44289 Mdot
.69717 .32736 Mdot
.40311 .41599 Mdot
.67713 .38876 Mdot
.45427 .78348 Mdot
.57628 .35917 Mdot
.3207 .46954 Mdot
.33063 .58963 Mdot
.65825 .5979 Mdot
.46882 .71701 Mdot
.67255 .63653 Mdot
.32684 .36809 Mdot
.62489 .49723 Mdot
.75256 .67347 Mdot
.51472 .28736 Mdot
.40901 .39737 Mdot
.61174 .45713 Mdot
.31613 .61566 Mdot
.62701 .63533 Mdot
.36294 .44785 Mdot
.30504 .35681 Mdot
.72108 .35876 Mdot
.6981 .34873 Mdot
.59831 .48482 Mdot
.31935 .62267 Mdot
.32533 .48172 Mdot
.48096 .69487 Mdot
.63417 .61413 Mdot
.67338 .39709 Mdot
.25835 .5952 Mdot
.49124 .73077 Mdot
.71642 .66804 Mdot
.4882 .68253 Mdot
.41615 .36607 Mdot
.64633 .4808 Mdot
.35934 .51641 Mdot
.61861 .47438 Mdot
.41967 .42829 Mdot
.63445 .6314 Mdot
.62142 .44764 Mdot
.67928 .36 Mdot
.47482 .68413 Mdot
.66847 .63028 Mdot
.41983 .41087 Mdot
.32755 .60724 Mdot
.3486 .273 Mdot
.62578 .643 Mdot
.30006 .38764 Mdot
.2991 .38779 Mdot
.37316 .5455 Mdot
.64178 .42436 Mdot
.54701 .74084 Mdot
.32067 .38185 Mdot
.42655 .7165 Mdot
.72606 .34092 Mdot
.74272 .67609 Mdot
.65671 .59191 Mdot
.64875 .62077 Mdot
.40566 .40853 Mdot
.64174 .57821 Mdot
.46468 .32591 Mdot
.61444 .56814 Mdot
.4336 .75745 Mdot
.39568 .38869 Mdot
.64425 .6142 Mdot
.64472 .47737 Mdot
.44479 .40029 Mdot
.30199 .61289 Mdot
.67033 .60369 Mdot
.40014 .39453 Mdot
.72858 .65574 Mdot
.51813 .69587 Mdot
.63647 .44164 Mdot
.46622 .30382 Mdot
.49094 .7074 Mdot
.33899 .57833 Mdot
.47485 .33685 Mdot
.7086 .35495 Mdot
.30083 .59549 Mdot
.62284 .51083 Mdot
.6902 .37888 Mdot
.44193 .27499 Mdot
.31484 .58231 Mdot
.6167 .45862 Mdot
.70438 .34769 Mdot
.69409 .40746 Mdot
.64671 .62115 Mdot
.60868 .58703 Mdot
.629 .47948 Mdot
.42389 .41432 Mdot
.65079 .65836 Mdot
.49595 .68977 Mdot
.45037 .37799 Mdot
.63583 .6263 Mdot
.62253 .45406 Mdot
.44438 .35687 Mdot
.29831 .36833 Mdot
.30434 .45552 Mdot
.64904 .42717 Mdot
.6783 .37885 Mdot
.32502 .62049 Mdot
.44869 .35062 Mdot
.68228 .38859 Mdot
.67599 .66191 Mdot
.45934 .36053 Mdot
.33589 .6125 Mdot
.25241 .61896 Mdot
.62876 .57422 Mdot
.47488 .70784 Mdot
.64256 .59675 Mdot
.67691 .39521 Mdot
.62099 .17009 Mdot
.64732 .46784 Mdot
.31739 .36063 Mdot
.46956 .34476 Mdot
.65962 .59724 Mdot
.32104 .60784 Mdot
.27898 .7109 Mdot
.47052 .36118 Mdot
.45915 .36336 Mdot
.44141 .3836 Mdot
.71111 .66934 Mdot
.34465 .57859 Mdot
.44254 .38001 Mdot
.7049 .39604 Mdot
.45236 .34386 Mdot
.70834 .37439 Mdot
.75107 .65797 Mdot
.64485 .43966 Mdot
.23651 .40593 Mdot
.6361 .44529 Mdot
.64591 .609 Mdot
.39801 .25455 Mdot
.46136 .30697 Mdot
.6591 .53101 Mdot
.34071 .57892 Mdot
.26525 .59952 Mdot
.66229 .62051 Mdot
.73244 .67087 Mdot
.29498 .36293 Mdot
.30081 .3764 Mdot
.43952 .40601 Mdot
.66147 .63853 Mdot
.61906 .58947 Mdot
.62611 .49507 Mdot
.61205 .45808 Mdot
.45438 .41381 Mdot
.63781 .58384 Mdot
.44007 .36813 Mdot
.31807 .36996 Mdot
.4868 .72974 Mdot
.30693 .61721 Mdot
.52065 .72688 Mdot
.50471 .73271 Mdot
.35753 .43644 Mdot
.44255 .31408 Mdot
.51827 .71468 Mdot
.49218 .72426 Mdot
.71147 .66618 Mdot
.45459 .43068 Mdot
.70332 .38279 Mdot
.53359 .40964 Mdot
.67506 .63567 Mdot
.42504 .36259 Mdot
.35132 .58462 Mdot
.6544 .4378 Mdot
.26392 .69712 Mdot
.64995 .28342 Mdot
.28526 .35995 Mdot
.62384 .63447 Mdot
.62527 .48053 Mdot
.61811 .47811 Mdot
.58042 .33017 Mdot
.44017 .37069 Mdot
.63022 .57473 Mdot
.46161 .42878 Mdot
.45809 .67659 Mdot
.7195 .66746 Mdot
.32231 .62361 Mdot
.43312 .38386 Mdot
.30858 .57485 Mdot
.46557 .69739 Mdot
.69225 .38714 Mdot
.6874 .34537 Mdot
.40244 .4107 Mdot
.29943 .38978 Mdot
.42606 .7168 Mdot
.30258 .37157 Mdot
.28962 .37314 Mdot
.62922 .47424 Mdot
.27811 .36942 Mdot
.45129 .352 Mdot
.39616 .39223 Mdot
.65294 .45198 Mdot
.51245 .73207 Mdot
.41826 .45397 Mdot
.62637 .48405 Mdot
.47341 .3559 Mdot
.46483 .69472 Mdot
.30151 .3685 Mdot
.48621 .68852 Mdot
.7227 .66926 Mdot
.51912 .70612 Mdot
.67603 .37122 Mdot
.70402 .66608 Mdot
.26979 .43008 Mdot
.33776 .59186 Mdot
.50614 .70676 Mdot
.70867 .34717 Mdot
.48708 .68692 Mdot
.67377 .62803 Mdot
.45343 .67751 Mdot
.37738 .59971 Mdot
.50086 .28601 Mdot
.35194 .42584 Mdot
.45608 .68204 Mdot
.62275 .57709 Mdot
.32516 .58633 Mdot
.42911 .7127 Mdot
.47303 .34147 Mdot
.6931 .34148 Mdot
.43616 .38636 Mdot
.47182 .68811 Mdot
.65886 .65965 Mdot
.31962 .47132 Mdot
.67686 .37318 Mdot
.2751 .43892 Mdot
.64452 .58586 Mdot
.4432 .34073 Mdot
.52101 .69176 Mdot
.54094 .74204 Mdot
.51321 .68955 Mdot
.39902 .29966 Mdot
.61152 .48465 Mdot
.62778 .41841 Mdot
.30427 .59138 Mdot
.60886 .46653 Mdot
.73701 .31033 Mdot
.42809 .73642 Mdot
.29061 .60082 Mdot
.68804 .657 Mdot
.42546 .41522 Mdot
.27728 .36321 Mdot
.64281 .47374 Mdot
.34725 .60209 Mdot
.28082 .37197 Mdot
.64792 .44903 Mdot
.43088 .27421 Mdot
.32914 .62157 Mdot
.6804 .63214 Mdot
.4509 .38852 Mdot
.5293 .71066 Mdot
.47549 .67535 Mdot
.64021 .49268 Mdot
.52508 .71209 Mdot
.47313 .35755 Mdot
.31376 .58557 Mdot
.30244 .36436 Mdot
.71067 .37161 Mdot
.35009 .51473 Mdot
.65562 .45175 Mdot
.6638 .40408 Mdot
.45766 .37049 Mdot
.66299 .62237 Mdot
.5705 .67417 Mdot
.46586 .37511 Mdot
.32591 .60179 Mdot
.46776 .33963 Mdot
.27937 .37105 Mdot
.30183 .37407 Mdot
.63421 .61457 Mdot
.45157 .28793 Mdot
.43893 .369 Mdot
.48552 .71657 Mdot
.52371 .36134 Mdot
.43595 .42511 Mdot
.70357 .39547 Mdot
.30861 .38695 Mdot
.49533 .67552 Mdot
.37007 .542 Mdot
.6607 .62234 Mdot
.30192 .60647 Mdot
.37165 .60574 Mdot
.33597 .57747 Mdot
.27579 .5718 Mdot
.3201 .38212 Mdot
.31957 .72702 Mdot
.32726 .48113 Mdot
.34279 .41838 Mdot
.33441 .56464 Mdot
.56422 .71425 Mdot
.28991 .60037 Mdot
.33931 .57837 Mdot
.26562 .68031 Mdot
.34605 .58228 Mdot
.42579 .41221 Mdot
.45624 .33696 Mdot
.46835 .3914 Mdot
.70975 .6706 Mdot
.43266 .36423 Mdot
.65243 .46867 Mdot
.71837 .3584 Mdot
.29869 .61918 Mdot
.63149 .46033 Mdot
.44634 .27804 Mdot
.62214 .50554 Mdot
.43409 .40021 Mdot
.44564 .36284 Mdot
.30742 .37455 Mdot
.53596 .2769 Mdot
.70868 .67124 Mdot
.35656 .60477 Mdot
.42687 .43072 Mdot
.55664 .72037 Mdot
.44916 .38959 Mdot
.46912 .35496 Mdot
.4042 .37362 Mdot
.66218 .62303 Mdot
.36602 .61187 Mdot
.62607 .48994 Mdot
.35154 .51508 Mdot
.42891 .37856 Mdot
.64594 .49971 Mdot
.71244 .38236 Mdot
.44418 .37218 Mdot
.35897 .61033 Mdot
.28023 .37208 Mdot
.32058 .56609 Mdot
.30986 .58373 Mdot
.45899 .36055 Mdot
.30525 .62107 Mdot
.32563 .57 Mdot
.30029 .37568 Mdot
.62553 .63767 Mdot
.43977 .76203 Mdot
.43491 .40397 Mdot
.67801 .36983 Mdot
.41307 .39719 Mdot
.70059 .38641 Mdot
.64945 .47492 Mdot
.6261 .47772 Mdot
.50252 .43647 Mdot
.62295 .58923 Mdot
.72284 .35979 Mdot
.7025 .66934 Mdot
.33065 .36053 Mdot
.25875 .61592 Mdot
.4517 .6792 Mdot
.60772 .58629 Mdot
.62652 .47574 Mdot
.55874 .38089 Mdot
.505 .32897 Mdot
.5222 .71402 Mdot
.28811 .57883 Mdot
.42448 .45667 Mdot
.61063 .45715 Mdot
.68062 .63351 Mdot
.64563 .60058 Mdot
.42741 .73453 Mdot
.26553 .67884 Mdot
.40694 .37992 Mdot
.61194 .45416 Mdot
.26871 .3779 Mdot
.6278 .4552 Mdot
.62971 .49255 Mdot
.62763 .62196 Mdot
.44052 .35832 Mdot
.43119 .26669 Mdot
.64732 .63504 Mdot
.69201 .36687 Mdot
.29608 .5793 Mdot
.67837 .38725 Mdot
.36725 .6902 Mdot
.27586 .43405 Mdot
.65397 .63177 Mdot
.63733 .43611 Mdot
.4255 .36546 Mdot
.35763 .61595 Mdot
.36699 .60597 Mdot
.29962 .6127 Mdot
.71474 .36502 Mdot
.6427 .58089 Mdot
.74272 .67135 Mdot
.41945 .40807 Mdot
.31092 .59549 Mdot
.67085 .40015 Mdot
.41783 .39694 Mdot
.50289 .70718 Mdot
.28476 .37599 Mdot
.31624 .59341 Mdot
.31421 .3587 Mdot
.30462 .59006 Mdot
.64519 .60328 Mdot
.40324 .40158 Mdot
.43121 .41301 Mdot
.57498 .36216 Mdot
.68859 .3622 Mdot
.32515 .56448 Mdot
.44487 .31453 Mdot
.45948 .3868 Mdot
.57698 .3252 Mdot
.44692 .36677 Mdot
.34981 .4227 Mdot
.6052 .45886 Mdot
.64962 .45539 Mdot
.47041 .34375 Mdot
.44161 .39399 Mdot
.36616 .60456 Mdot
.32912 .48004 Mdot
.27753 .43322 Mdot
.46778 .69965 Mdot
.28991 .60309 Mdot
.65149 .63745 Mdot
.6757 .61026 Mdot
.67322 .64946 Mdot
.67489 .39587 Mdot
.3005 .36552 Mdot
.40671 .39004 Mdot
.47091 .71004 Mdot
.70689 .35288 Mdot
.31001 .60195 Mdot
.69339 .38291 Mdot
.45033 .29981 Mdot
.68048 .36069 Mdot
.62897 .4992 Mdot
.50495 .81557 Mdot
.31801 .37054 Mdot
.68526 .37418 Mdot
.31448 .6188 Mdot
.54004 .40051 Mdot
.39296 .41608 Mdot
.29624 .45337 Mdot
.72121 .36029 Mdot
.68326 .66268 Mdot
.45658 .37195 Mdot
.38391 .32026 Mdot
.47878 .68941 Mdot
.67456 .37873 Mdot
.49217 .68311 Mdot
.28485 .369 Mdot
.26669 .59771 Mdot
.32551 .59642 Mdot
.44925 .68155 Mdot
.4689 .34793 Mdot
.67436 .37719 Mdot
.6515 .62782 Mdot
.45818 .42694 Mdot
.71729 .6738 Mdot
.63395 .51471 Mdot
.58024 .3373 Mdot
.61839 .61537 Mdot
.42216 .44589 Mdot
.51507 .69752 Mdot
.41658 .43279 Mdot
.32078 .36769 Mdot
.45663 .39188 Mdot
.64799 .64106 Mdot
.64917 .62019 Mdot
.74089 .67534 Mdot
.41055 .42184 Mdot
.39976 .38922 Mdot
.38008 .57384 Mdot
.63798 .5784 Mdot
.33285 .57724 Mdot
.34919 .6044 Mdot
.62708 .61056 Mdot
.30694 .56507 Mdot
.69167 .37743 Mdot
.42564 .29755 Mdot
.51537 .69827 Mdot
.50346 .68053 Mdot
.65498 .6302 Mdot
.63437 .63639 Mdot
.66408 .62331 Mdot
.28237 .36962 Mdot
.31676 .58032 Mdot
.44733 .33209 Mdot
.43119 .39602 Mdot
.40461 .42806 Mdot
.33149 .62348 Mdot
.47152 .35708 Mdot
.38184 .4028 Mdot
.71606 .36933 Mdot
.64934 .60978 Mdot
.47199 .68108 Mdot
.34928 .27775 Mdot
.47882 .71355 Mdot
.4552 .34643 Mdot
.43227 .75152 Mdot
.28878 .57924 Mdot
.68898 .35042 Mdot
.31007 .38427 Mdot
.68081 .35523 Mdot
.4857 .72926 Mdot
.3778 .57075 Mdot
.43888 .27581 Mdot
.42841 .34524 Mdot
.45446 .2986 Mdot
.77193 .5767 Mdot
.37088 .59807 Mdot
.48243 .7082 Mdot
.31615 .37828 Mdot
.61884 .50483 Mdot
.29148 .39269 Mdot
.40592 .40547 Mdot
.42394 .43143 Mdot
.3777 .32631 Mdot
.4591 .34154 Mdot
.29679 .61405 Mdot
.46019 .31789 Mdot
.6311 .43483 Mdot
.43975 .40965 Mdot
.33465 .71985 Mdot
.42573 .37619 Mdot
.4044 .38239 Mdot
.414 .37429 Mdot
.45812 .39235 Mdot
.31605 .62549 Mdot
.3099 .37205 Mdot
.4756 .71041 Mdot
.4254 .29577 Mdot
.51272 .69643 Mdot
.6599 .63082 Mdot
.65176 .43082 Mdot
.34786 .6208 Mdot
.68218 .35295 Mdot
.44009 .65213 Mdot
.38688 .31675 Mdot
.67436 .65352 Mdot
.56969 .37239 Mdot
.72694 .3615 Mdot
.63615 .49003 Mdot
.67437 .39156 Mdot
.63595 .63193 Mdot
.50128 .70044 Mdot
.41804 .3581 Mdot
.3318 .58064 Mdot
.33978 .59805 Mdot
.4463 .40063 Mdot
.44841 .77183 Mdot
.47637 .67528 Mdot
.69196 .66506 Mdot
.40972 .37516 Mdot
.45983 .34765 Mdot
.31331 .5692 Mdot
.6421 .64975 Mdot
.46606 .31389 Mdot
.70673 .36251 Mdot
.45179 .38118 Mdot
.62 .44293 Mdot
.45124 .29921 Mdot
.47149 .70492 Mdot
.62181 .45245 Mdot
.41995 .37793 Mdot
.43951 .31233 Mdot
.29371 .35041 Mdot
.61393 .43056 Mdot
.61633 .57428 Mdot
.45872 .36169 Mdot
.44003 .40302 Mdot
.32951 .62176 Mdot
.51813 .70041 Mdot
.32192 .60886 Mdot
.38209 .58914 Mdot
.62612 .47719 Mdot
.51733 .69374 Mdot
.45893 .38989 Mdot
.46731 .67313 Mdot
.2874 .37879 Mdot
.42763 .40446 Mdot
.48106 .70682 Mdot
.3079 .58174 Mdot
.29963 .71492 Mdot
.4183 .45433 Mdot
.28737 .37239 Mdot
.41382 .39486 Mdot
.70747 .66498 Mdot
.65473 .43887 Mdot
.43822 .34117 Mdot
.34188 .60026 Mdot
.4182 .39916 Mdot
.46682 .7098 Mdot
.68848 .38668 Mdot
.32917 .60118 Mdot
.61995 .62586 Mdot
.63907 .60452 Mdot
.62247 .57327 Mdot
.62724 .49874 Mdot
.27864 .37079 Mdot
.32923 .61961 Mdot
.34493 .61049 Mdot
.45635 .30525 Mdot
.64583 .60936 Mdot
.70327 .37392 Mdot
.42902 .4173 Mdot
.61508 .44712 Mdot
.53484 .71323 Mdot
.23479 .40458 Mdot
.43643 .28023 Mdot
.68017 .39939 Mdot
.51725 .34254 Mdot
.62906 .47075 Mdot
.43354 .3553 Mdot
.67464 .37716 Mdot
.62855 .616 Mdot
.28563 .35048 Mdot
.72895 .34386 Mdot
.67974 .66559 Mdot
.66059 .65314 Mdot
.46503 .67641 Mdot
.61421 .57131 Mdot
.67389 .3693 Mdot
.64676 .47297 Mdot
.33511 .59913 Mdot
.44309 .37001 Mdot
.63575 .47757 Mdot
.6575 .60981 Mdot
.61461 .48595 Mdot
.42017 .35974 Mdot
.30771 .57007 Mdot
.67305 .63209 Mdot
.42793 .40836 Mdot
.32181 .37928 Mdot
.30376 .45457 Mdot
.63296 .64411 Mdot
.46525 .32913 Mdot
.74328 .36059 Mdot
.66788 .64987 Mdot
.64523 .64047 Mdot
.45986 .36155 Mdot
.7071 .33912 Mdot
.42985 .38287 Mdot
.50114 .70396 Mdot
.45814 .28817 Mdot
.51661 .6947 Mdot
.58114 .32521 Mdot
.45577 .38494 Mdot
.46443 .39426 Mdot
.26058 .61956 Mdot
.72699 .31784 Mdot
.56226 .29914 Mdot
.4429 .35217 Mdot
.34506 .57502 Mdot
.45347 .28476 Mdot
.4971 .28555 Mdot
.37573 .60065 Mdot
.69184 .39012 Mdot
.475 .69013 Mdot
.42375 .41747 Mdot
.34138 .71594 Mdot
.70636 .3756 Mdot
.58013 .32776 Mdot
.45514 .40984 Mdot
.31777 .6015 Mdot
.40515 .39078 Mdot
.33069 .5944 Mdot
.416 .38451 Mdot
.31526 .46499 Mdot
.42729 .71876 Mdot
.39868 .30071 Mdot
.64438 .47694 Mdot
.54121 .74147 Mdot
.35062 .42471 Mdot
.69627 .37585 Mdot
.31853 .3644 Mdot
.62453 .46993 Mdot
.50468 .69862 Mdot
.44618 .68485 Mdot
.66398 .62186 Mdot
.50075 .71693 Mdot
.29422 .59509 Mdot
.66621 .66158 Mdot
.60959 .47168 Mdot
.26824 .3586 Mdot
.67842 .35515 Mdot
.51782 .69398 Mdot
.44602 .37733 Mdot
.40807 .43104 Mdot
.71139 .66955 Mdot
.7539 .65507 Mdot
.28666 .57104 Mdot
.26402 .4273 Mdot
.37819 .57137 Mdot
.69226 .36238 Mdot
.63654 .64798 Mdot
.40909 .39046 Mdot
.43816 .36141 Mdot
.65695 .65329 Mdot
.35767 .61662 Mdot
.71754 .34894 Mdot
.62888 .41777 Mdot
.47137 .71276 Mdot
.77953 .65553 Mdot
.33072 .60069 Mdot
.77912 .65717 Mdot
.74007 .67108 Mdot
.26143 .67541 Mdot
.56417 .30234 Mdot
.49317 .70556 Mdot
.77978 .65688 Mdot
.31427 .59945 Mdot
.44913 .34067 Mdot
.61726 .46795 Mdot
.62313 .49708 Mdot
.30394 .57444 Mdot
.66401 .6354 Mdot
.70831 .3385 Mdot
.40528 .41063 Mdot
.68966 .40526 Mdot
.36755 .61026 Mdot
.63415 .58045 Mdot
.63328 .45225 Mdot
.46719 .68859 Mdot
.41608 .39646 Mdot
.71582 .36457 Mdot
.49214 .70404 Mdot
.64594 .44238 Mdot
.41348 .29741 Mdot
.47474 .33644 Mdot
.30249 .38845 Mdot
.4807 .69009 Mdot
.46234 .31299 Mdot
.44841 .38737 Mdot
.51496 .69737 Mdot
.60342 .48211 Mdot
.54479 .7404 Mdot
.46959 .31193 Mdot
.42821 .73658 Mdot
.67529 .65856 Mdot
.61275 .57195 Mdot
.60505 .58444 Mdot
.70672 .67077 Mdot
.51421 .70226 Mdot
.63677 .46878 Mdot
.75619 .67082 Mdot
.51785 .6993 Mdot
.46735 .37012 Mdot
.42352 .417 Mdot
.46077 .43061 Mdot
.64486 .4404 Mdot
.6413 .44618 Mdot
.36227 .52303 Mdot
.31263 .36779 Mdot
.63295 .45383 Mdot
.45034 .36912 Mdot
.3492 .61544 Mdot
.48749 .71209 Mdot
.74238 .28706 Mdot
.48129 .72416 Mdot
.27783 .35194 Mdot
.67575 .64566 Mdot
.66996 .66202 Mdot
.44277 .37244 Mdot
.54567 .63584 Mdot
.68313 .21966 Mdot
.42293 .41744 Mdot
.31036 .38418 Mdot
.58274 .32789 Mdot
.44167 .40751 Mdot
.28353 .59408 Mdot
.62627 .4405 Mdot
.34353 .61701 Mdot
.48886 .70561 Mdot
.69359 .38924 Mdot
.74009 .31883 Mdot
.47494 .69136 Mdot
.42825 .37427 Mdot
.65442 .46789 Mdot
.43892 .38486 Mdot
.43539 .34867 Mdot
.44285 .30587 Mdot
.68986 .39527 Mdot
.66562 .62876 Mdot
.68057 .35453 Mdot
.34298 .58049 Mdot
.25372 .42019 Mdot
.69767 .37735 Mdot
.45623 .42917 Mdot
.45896 .29579 Mdot
.74913 .65629 Mdot
.33928 .59892 Mdot
.70362 .38412 Mdot
.4772 .68675 Mdot
.4967 .29932 Mdot
.45703 .42158 Mdot
.49372 .7185 Mdot
.42942 .35384 Mdot
.3506 .60871 Mdot
.37422 .54981 Mdot
.48578 .67456 Mdot
.32711 .61232 Mdot
.46348 .31347 Mdot
.28737 .36743 Mdot
.47103 .70617 Mdot
.54617 .29082 Mdot
.51289 .68817 Mdot
.36667 .44451 Mdot
.29255 .38021 Mdot
.32723 .60122 Mdot
.32676 .40898 Mdot
.37509 .57043 Mdot
.64711 .45063 Mdot
.46114 .33394 Mdot
.70113 .37401 Mdot
.45707 .30216 Mdot
.61746 .62202 Mdot
.27481 .58875 Mdot
.32116 .5892 Mdot
.53621 .72265 Mdot
.32978 .61057 Mdot
.29369 .57254 Mdot
.44934 .68666 Mdot
.2882 .59803 Mdot
.42906 .37725 Mdot
.2333 .37848 Mdot
.313 .61587 Mdot
.48277 .69767 Mdot
.71381 .35998 Mdot
.29983 .61497 Mdot
.73507 .67251 Mdot
.45125 .38845 Mdot
.65419 .59784 Mdot
.71601 .33889 Mdot
.32432 .62528 Mdot
.69838 .37338 Mdot
.66263 .61391 Mdot
.71548 .38245 Mdot
.53824 .71504 Mdot
.50972 .68212 Mdot
.63142 .42337 Mdot
.42635 .73166 Mdot
.34488 .58138 Mdot
.65948 .66179 Mdot
.40817 .42391 Mdot
.41379 .37015 Mdot
.68358 .34122 Mdot
.33559 .56733 Mdot
.45176 .7785 Mdot
.63189 .45876 Mdot
.35406 .51215 Mdot
.46694 .68422 Mdot
.69133 .6644 Mdot
.44039 .2724 Mdot
.43948 .69068 Mdot
.63286 .43438 Mdot
.62738 .47159 Mdot
.44168 .38359 Mdot
.57948 .35644 Mdot
.67514 .3844 Mdot
.56702 .70571 Mdot
.28654 .3557 Mdot
.64594 .64853 Mdot
.41847 .37239 Mdot
.30135 .35961 Mdot
.45002 .35114 Mdot
.67391 .39796 Mdot
.50523 .71995 Mdot
.33973 .59424 Mdot
.69862 .38822 Mdot
.63859 .60428 Mdot
.40538 .25554 Mdot
.44018 .33941 Mdot
.46652 .32568 Mdot
.66787 .64236 Mdot
.35025 .58868 Mdot
.65556 .62462 Mdot
.51465 .69758 Mdot
.69457 .38066 Mdot
.281 .37128 Mdot
.6441 .43976 Mdot
.66018 .59724 Mdot
.50728 .70619 Mdot
.62196 .63327 Mdot
.46059 .67753 Mdot
.62536 .47474 Mdot
.47187 .32784 Mdot
.6378 .57566 Mdot
.6161 .47939 Mdot
.34115 .49723 Mdot
.41376 .30112 Mdot
.26259 .66867 Mdot
.664 .63881 Mdot
.66541 .52894 Mdot
.4886 .70169 Mdot
.50084 .72964 Mdot
.35808 .44075 Mdot
.63563 .18398 Mdot
.45517 .32045 Mdot
.46483 .7926 Mdot
.51591 .69905 Mdot
.48787 .69152 Mdot
.65745 .62299 Mdot
.30712 .58111 Mdot
.26897 .62852 Mdot
.6783 .63489 Mdot
.56928 .31656 Mdot
.30999 .60166 Mdot
.46691 .39544 Mdot
.65721 .59004 Mdot
.30311 .37653 Mdot
.31942 .47252 Mdot
.71675 .37189 Mdot
.57957 .34445 Mdot
.4524 .67959 Mdot
.41613 .41453 Mdot
.31495 .72775 Mdot
.6605 .61803 Mdot
.61651 .48603 Mdot
.55272 .69821 Mdot
.40767 .43204 Mdot
.42256 .3652 Mdot
.42505 .39427 Mdot
.68689 .33988 Mdot
.3334 .48664 Mdot
.40901 .40793 Mdot
.40591 .3012 Mdot
.27448 .36516 Mdot
.60852 .58924 Mdot
.67832 .35958 Mdot
.56527 .37912 Mdot
.71781 .6576 Mdot
.35588 .51385 Mdot
.41925 .43351 Mdot
.49915 .72655 Mdot
.31151 .3672 Mdot
.47563 .70341 Mdot
.46428 .68276 Mdot
.78698 .64846 Mdot
.34425 .60118 Mdot
.28271 .36052 Mdot
.6223 .60056 Mdot
.26128 .62244 Mdot
.29699 .36001 Mdot
.25779 .42327 Mdot
.52487 .72898 Mdot
.61969 .16862 Mdot
.50795 .72961 Mdot
.61813 .49242 Mdot
.29171 .59412 Mdot
.35425 .58294 Mdot
.45266 .30124 Mdot
.32634 .5771 Mdot
.70645 .6686 Mdot
.32781 .61938 Mdot
.83723 .51978 Mdot
.37487 .59277 Mdot
.48913 .69786 Mdot
.50503 .68072 Mdot
.30548 .36938 Mdot
.43221 .37352 Mdot
.43126 .26996 Mdot
.63149 .45788 Mdot
.47254 .33709 Mdot
.6466 .63483 Mdot
.7379 .67345 Mdot
.4927 .81013 Mdot
.28705 .59153 Mdot
.51067 .70544 Mdot
.42128 .36676 Mdot
.29058 .37894 Mdot
.45597 .33652 Mdot
.43133 .70294 Mdot
.33692 .38194 Mdot
.43266 .39493 Mdot
.30195 .36686 Mdot
.67769 .63904 Mdot
.70726 .66089 Mdot
.26584 .67789 Mdot
.78344 .65153 Mdot
.44608 .35616 Mdot
.69747 .35685 Mdot
.67491 .39721 Mdot
.4071 .36481 Mdot
.58896 .5718 Mdot
.46504 .31113 Mdot
.44568 .37955 Mdot
.40347 .25483 Mdot
.68114 .63257 Mdot
.62469 .5039 Mdot
.65365 .6081 Mdot
.3717 .6077 Mdot
.64653 .48142 Mdot
.63895 .63069 Mdot
.41731 .26246 Mdot
.63151 .47708 Mdot
.54712 .73824 Mdot
.71012 .37349 Mdot
.45075 .37525 Mdot
.36878 .45633 Mdot
.64243 .58013 Mdot
.49727 .6996 Mdot
.29551 .6053 Mdot
.4761 .70914 Mdot
.70251 .66019 Mdot
.57499 .3182 Mdot
.64422 .44468 Mdot
.48955 .725 Mdot
.29539 .38996 Mdot
.70069 .35415 Mdot
.51673 .72881 Mdot
.27797 .37275 Mdot
.40315 .37103 Mdot
.65941 .2044 Mdot
.39971 .40633 Mdot
.7389 .6739 Mdot
.51916 .6982 Mdot
.61658 .50499 Mdot
.44207 .37005 Mdot
.64292 .58774 Mdot
.69776 .40778 Mdot
.43844 .38833 Mdot
.61853 .61934 Mdot
.43604 .40564 Mdot
.6751 .37541 Mdot
.33559 .62045 Mdot
.45313 .28102 Mdot
.66683 .36319 Mdot
.69663 .38813 Mdot
.38205 .31908 Mdot
.45521 .33414 Mdot
.57517 .6593 Mdot
.31884 .60404 Mdot
.45326 .34593 Mdot
.66399 .36782 Mdot
.29716 .58388 Mdot
.30112 .60413 Mdot
.28251 .35064 Mdot
.46531 .7099 Mdot
.6676 .63408 Mdot
.69088 .35344 Mdot
.71784 .66634 Mdot
.41834 .41347 Mdot
.31128 .35767 Mdot
.70529 .37992 Mdot
.49844 .71058 Mdot
.2832 .36417 Mdot
.48155 .80171 Mdot
.42378 .29562 Mdot
.52114 .72823 Mdot
.42994 .42793 Mdot
.32906 .39954 Mdot
.36207 .61145 Mdot
.32159 .72596 Mdot
.42823 .7204 Mdot
.64237 .60089 Mdot
.63463 .45385 Mdot
.24116 .41121 Mdot
.71452 .36608 Mdot
.26943 .63332 Mdot
.41697 .36417 Mdot
.41164 .387 Mdot
.35078 .6159 Mdot
.42908 .34391 Mdot
.28693 .58443 Mdot
.73289 .67014 Mdot
.63204 .17984 Mdot
.33608 .59585 Mdot
.32053 .59388 Mdot
.27649 .34626 Mdot
.68307 .6161 Mdot
.29597 .57825 Mdot
.42431 .41814 Mdot
.7028 .66084 Mdot
.6143 .43143 Mdot
.71331 .3482 Mdot
.70889 .33037 Mdot
.28428 .58001 Mdot
.44601 .43191 Mdot
.29385 .38474 Mdot
.47342 .45199 Mdot
.52048 .3466 Mdot
.51579 .70359 Mdot
.42497 .42353 Mdot
.63003 .4633 Mdot
.65879 .61282 Mdot
.39822 .40169 Mdot
.451 .36815 Mdot
.33974 .59054 Mdot
.71826 .37519 Mdot
.50198 .68574 Mdot
.61803 .48347 Mdot
.62421 .57061 Mdot
.69794 .36522 Mdot
.30404 .56563 Mdot
.3532 .42995 Mdot
.65197 .43979 Mdot
.61257 .45431 Mdot
.43816 .35225 Mdot
.45805 .35714 Mdot
.64191 .43363 Mdot
.47509 .6954 Mdot
.64299 .59958 Mdot
.62786 .48907 Mdot
.45966 .30546 Mdot
.42842 .26233 Mdot
.43343 .35863 Mdot
.32674 .61681 Mdot
.50779 .70165 Mdot
.64322 .44601 Mdot
.75558 .67303 Mdot
.43107 .4168 Mdot
.45461 .41764 Mdot
.58546 .44933 Mdot
.63324 .46578 Mdot
.26838 .62823 Mdot
.68913 .34696 Mdot
.29258 .38 Mdot
.40336 .30079 Mdot
.47305 .35481 Mdot
.41881 .43203 Mdot
.62916 .6207 Mdot
.47446 .68237 Mdot
.621 .43134 Mdot
.64964 .61067 Mdot
.30146 .60558 Mdot
.4817 .44806 Mdot
.35108 .60047 Mdot
.3434 .61055 Mdot
.27251 .58675 Mdot
.46725 .69795 Mdot
.23874 .40832 Mdot
.64491 .43278 Mdot
.40632 .3801 Mdot
.51468 .71644 Mdot
.29548 .57625 Mdot
.46891 .3758 Mdot
.2885 .57959 Mdot
.32888 .56514 Mdot
.47427 .3528 Mdot
.2988 .36859 Mdot
.39718 .30679 Mdot
.41935 .44128 Mdot
.69004 .3421 Mdot
.36065 .60548 Mdot
.45535 .41982 Mdot
.40876 .39543 Mdot
.44371 .36272 Mdot
.30723 .3703 Mdot
.68492 .39458 Mdot
.50149 .43772 Mdot
.41875 .3629 Mdot
.5833 .35631 Mdot
.46844 .37528 Mdot
.3395 .56868 Mdot
.54237 .70669 Mdot
.27759 .35163 Mdot
.67464 .65578 Mdot
.35654 .61619 Mdot
.71624 .37404 Mdot
.27352 .60576 Mdot
.31006 .38845 Mdot
.49177 .68828 Mdot
.31631 .5935 Mdot
.67497 .62433 Mdot
.4977 .70238 Mdot
.51259 .68785 Mdot
.30882 .37316 Mdot
.63626 .59743 Mdot
.71717 .37719 Mdot
.49269 .67886 Mdot
.3045 .39446 Mdot
.49047 .69772 Mdot
.25551 .65324 Mdot
.47111 .32425 Mdot
.40639 .29947 Mdot
.64201 .46851 Mdot
.60822 .4487 Mdot
.50956 .6885 Mdot
.70828 .36252 Mdot
.28325 .36309 Mdot
.29843 .61136 Mdot
.7065 .35584 Mdot
.32143 .47353 Mdot
.67015 .66159 Mdot
.37384 .54979 Mdot
.71653 .66999 Mdot
.32427 .57455 Mdot
.57989 .34091 Mdot
.70908 .38363 Mdot
.62337 .43487 Mdot
.44405 .28871 Mdot
.63289 .45009 Mdot
.40031 .39073 Mdot
.28365 .3611 Mdot
.42814 .37859 Mdot
.67478 .65039 Mdot
.68809 .33902 Mdot
.31816 .61708 Mdot
.74222 .34163 Mdot
.49245 .71483 Mdot
.46312 .31751 Mdot
.6202 .48973 Mdot
.28676 .37302 Mdot
.28976 .58184 Mdot
.33092 .57076 Mdot
.33052 .48051 Mdot
.66878 .65072 Mdot
.73333 .33022 Mdot
.43038 .36208 Mdot
.73058 .37681 Mdot
.51248 .69052 Mdot
.42637 .7338 Mdot
.66438 .60602 Mdot
.6167 .16927 Mdot
.64599 .61138 Mdot
.60892 .43518 Mdot
.32189 .57187 Mdot
.67982 .37644 Mdot
.43104 .36767 Mdot
.31747 .62379 Mdot
.26945 .62952 Mdot
.71577 .33288 Mdot
.68243 .35347 Mdot
.42717 .71186 Mdot
.51886 .71424 Mdot
.61195 .46769 Mdot
.46809 .37525 Mdot
.46619 .3863 Mdot
.40534 .42333 Mdot
.51451 .70944 Mdot
.2921 .36981 Mdot
.54197 .71 Mdot
.31613 .37992 Mdot
.66354 .36891 Mdot
.64608 .64296 Mdot
.56147 .80299 Mdot
.33589 .62228 Mdot
.49511 .44103 Mdot
.25675 .6322 Mdot
.41688 .30051 Mdot
.49765 .72194 Mdot
.60296 .48135 Mdot
.66209 .62663 Mdot
.48116 .6437 Mdot
.6418 .63969 Mdot
.72383 .26483 Mdot
.45886 .43353 Mdot
.54517 .71338 Mdot
.47061 .33644 Mdot
.62604 .59669 Mdot
.41896 .44411 Mdot
.62984 .48763 Mdot
.6542 .46883 Mdot
.32663 .38227 Mdot
.28174 .4375 Mdot
.68789 .34351 Mdot
.43057 .36726 Mdot
.34597 .61531 Mdot
.43285 .3658 Mdot
.43328 .36438 Mdot
.43172 .34923 Mdot
.44904 .68086 Mdot
.47057 .32815 Mdot
.43089 .37509 Mdot
.74602 .67474 Mdot
.61682 .43123 Mdot
.61594 .56699 Mdot
.36642 .6082 Mdot
.70677 .35286 Mdot
.37127 .60584 Mdot
.44851 .28388 Mdot
.49058 .72909 Mdot
.33056 .48359 Mdot
.29661 .37578 Mdot
.27704 .58641 Mdot
.49323 .72709 Mdot
.71913 .34541 Mdot
.62784 .46633 Mdot
.26349 .69445 Mdot
.70259 .66934 Mdot
.6232 .45518 Mdot
.62565 .63446 Mdot
.41621 .43862 Mdot
.33436 .60113 Mdot
.63195 .45099 Mdot
.48932 .68138 Mdot
.62843 .6244 Mdot
.38627 .31631 Mdot
.41936 .40382 Mdot
.66055 .6411 Mdot
.63729 .47356 Mdot
.45718 .30153 Mdot
.45363 .28599 Mdot
.62558 .59587 Mdot
.46085 .69182 Mdot
.5033 .68114 Mdot
.71446 .35553 Mdot
.34374 .5764 Mdot
.33812 .58021 Mdot
.49292 .71365 Mdot
.49444 .64207 Mdot
.42552 .41083 Mdot
.424 .40703 Mdot
.44105 .27991 Mdot
.46512 .34872 Mdot
.70824 .67239 Mdot
.62369 .45699 Mdot
.32983 .58326 Mdot
.284 .36056 Mdot
.29833 .35516 Mdot
.42784 .37101 Mdot
.56941 .31089 Mdot
.67451 .63438 Mdot
.29935 .38523 Mdot
.67468 .37821 Mdot
.2986 .44914 Mdot
.44868 .39167 Mdot
.66099 .38793 Mdot
.3315 .57265 Mdot
.55733 .72619 Mdot
.49649 .6983 Mdot
.62227 .59396 Mdot
.62227 .59734 Mdot
.77407 .57438 Mdot
.33963 .62097 Mdot
.62399 .4546 Mdot
.6764 .66641 Mdot
.63665 .49484 Mdot
.68349 .35367 Mdot
.54342 .39839 Mdot
.70709 .66931 Mdot
.61557 .56787 Mdot
.5402 .71963 Mdot
.42789 .42488 Mdot
.45254 .37835 Mdot
.4294 .73953 Mdot
.44626 .36596 Mdot
.69932 .38029 Mdot
.52055 .72056 Mdot
.3159 .59507 Mdot
.69737 .33939 Mdot
.50466 .72674 Mdot
.33838 .57832 Mdot
.30715 .37517 Mdot
.46776 .37964 Mdot
.29835 .60526 Mdot
.30818 .56649 Mdot
.42643 .41208 Mdot
.79403 .64268 Mdot
.33592 .58884 Mdot
.29261 .59968 Mdot
.29569 .44736 Mdot
.62616 .57606 Mdot
.69079 .40864 Mdot
.46809 .71388 Mdot
.42873 .3837 Mdot
.65446 .64676 Mdot
.68237 .36476 Mdot
.31944 .58767 Mdot
.45194 .35382 Mdot
.41705 .41242 Mdot
.70038 .35484 Mdot
.67259 .37805 Mdot
.70912 .3594 Mdot
.48298 .67421 Mdot
.30075 .37694 Mdot
.2911 .58488 Mdot
.50473 .7168 Mdot
.71353 .37569 Mdot
.67562 .36001 Mdot
.67973 .33721 Mdot
.42754 .41002 Mdot
.67192 .37861 Mdot
.25091 .41852 Mdot
.41294 .2641 Mdot
.6386 .49388 Mdot
.64727 .52977 Mdot
.63649 .57097 Mdot
.59511 .47323 Mdot
.47543 .68279 Mdot
.31352 .37983 Mdot
.71352 .3465 Mdot
.63428 .48151 Mdot
.42127 .407 Mdot
.44552 .40386 Mdot
.70008 .35801 Mdot
.57595 .31637 Mdot
.3427 .59113 Mdot
.26468 .67195 Mdot
.70366 .35304 Mdot
.63037 .58704 Mdot
.6811 .63056 Mdot
.64633 .61901 Mdot
.43686 .35668 Mdot
.47397 .37087 Mdot
.50189 .32261 Mdot
.35005 .50271 Mdot
.51899 .70885 Mdot
.32392 .56961 Mdot
.29305 .4479 Mdot
.30156 .60317 Mdot
.66387 .6573 Mdot
.70834 .36306 Mdot
.355 .61183 Mdot
.49304 .67653 Mdot
.50338 .68216 Mdot
.6349 .57501 Mdot
.64448 .60875 Mdot
.65287 .62997 Mdot
.34047 .62262 Mdot
.30615 .57218 Mdot
.47359 .34258 Mdot
.33385 .61222 Mdot
.72125 .65612 Mdot
.73259 .67047 Mdot
.64066 .57825 Mdot
.48075 .70047 Mdot
.30924 .58437 Mdot
.43798 .40489 Mdot
.376 .32777 Mdot
.68173 .62924 Mdot
.72065 .36221 Mdot
.23342 .37936 Mdot
.6382 .18683 Mdot
.31415 .36245 Mdot
.50229 .69196 Mdot
.64615 .46964 Mdot
.42388 .39126 Mdot
.64628 .601 Mdot
.62397 .51754 Mdot
.62709 .4411 Mdot
.46384 .32232 Mdot
.32601 .35707 Mdot
.50144 .69515 Mdot
.44968 .28007 Mdot
.62974 .48567 Mdot
.27501 .36892 Mdot
.51756 .7215 Mdot
.65827 .59444 Mdot
.60637 .58622 Mdot
.36126 .5208 Mdot
.54968 .39172 Mdot
.64951 .44955 Mdot
.41106 .42523 Mdot
.63934 .62809 Mdot
.70083 .33919 Mdot
.6438 .62998 Mdot
.33208 .5639 Mdot
.62864 .57434 Mdot
.44403 .39454 Mdot
.29302 .58348 Mdot
.50657 .68402 Mdot
.49831 .30549 Mdot
.74193 .32322 Mdot
.64663 .58775 Mdot
.63001 .43071 Mdot
.30801 .36198 Mdot
.26682 .36115 Mdot
.60817 .44857 Mdot
.45083 .38075 Mdot
.4802 .70666 Mdot
.2874 .58612 Mdot
.50115 .71218 Mdot
.69653 .40889 Mdot
.24863 .64353 Mdot
.49684 .69739 Mdot
.47592 .36234 Mdot
.70758 .33803 Mdot
.57321 .31511 Mdot
.44345 .39199 Mdot
.48095 .67988 Mdot
.46714 .32446 Mdot
.3601 .61017 Mdot
.42151 .26347 Mdot
.42218 .29649 Mdot
.48523 .71118 Mdot
.60928 .47624 Mdot
.45992 .29567 Mdot
.69658 .40733 Mdot
.51323 .69662 Mdot
.41493 .25673 Mdot
.61904 .46338 Mdot
.69328 .36999 Mdot
.68722 .34046 Mdot
.70049 .36667 Mdot
.42989 .39887 Mdot
.32632 .40283 Mdot
.70534 .38555 Mdot
.44666 .68926 Mdot
.69357 .3866 Mdot
.59911 .461 Mdot
.4484 .7757 Mdot
.67402 .36898 Mdot
.44772 .37151 Mdot
.31597 .37962 Mdot
.31315 .37926 Mdot
.65937 .60425 Mdot
.26831 .70307 Mdot
.74533 .67412 Mdot
.40925 .38892 Mdot
.28186 .44222 Mdot
.33358 .61944 Mdot
.63415 .42819 Mdot
.4207 .29716 Mdot
.29804 .38872 Mdot
.29804 .59744 Mdot
.44576 .28528 Mdot
.36704 .53519 Mdot
.63988 .48467 Mdot
.43035 .40088 Mdot
.35503 .61587 Mdot
.27458 .58534 Mdot
.56116 .29895 Mdot
.35636 .51538 Mdot
.32151 .57901 Mdot
.51861 .70092 Mdot
.47541 .68504 Mdot
.48133 .70807 Mdot
.64125 .60657 Mdot
.32051 .5922 Mdot
.39751 .3835 Mdot
.64385 .60198 Mdot
.42722 .35507 Mdot
.48827 .71266 Mdot
.41738 .29348 Mdot
.31977 .59436 Mdot
.44428 .38673 Mdot
.46249 .41075 Mdot
.6199 .621 Mdot
.70068 .35543 Mdot
.26924 .43044 Mdot
.61003 .58665 Mdot
.46375 .6766 Mdot
.33624 .56453 Mdot
.60249 .4562 Mdot
.27581 .37471 Mdot
.45196 .34944 Mdot
.42062 .35498 Mdot
.27479 .37251 Mdot
.45523 .43518 Mdot
.61561 .45219 Mdot
.63867 .60451 Mdot
.62066 .57972 Mdot
.44093 .40549 Mdot
.32573 .59051 Mdot
.67763 .4011 Mdot
.66249 .40919 Mdot
.728 .33941 Mdot
.45654 .29232 Mdot
.40632 .30092 Mdot
.46375 .37091 Mdot
.51557 .42616 Mdot
.66858 .61462 Mdot
.62266 .50201 Mdot
.45119 .2974 Mdot
.69397 .3756 Mdot
.44646 .34175 Mdot
.36903 .60614 Mdot
.31586 .58966 Mdot
.66523 .63743 Mdot
.5294 .71055 Mdot
.65377 .44461 Mdot
.64447 .57973 Mdot
.44221 .40378 Mdot
.29067 .35559 Mdot
.52489 .71162 Mdot
.30833 .56242 Mdot
.69359 .36548 Mdot
.65069 .60385 Mdot
.68463 .38011 Mdot
.32809 .61059 Mdot
.3201 .58678 Mdot
.45749 .34046 Mdot
.73802 .33145 Mdot
.65248 .58938 Mdot
.43526 .35935 Mdot
.65624 .63964 Mdot
.71085 .66819 Mdot
.53638 .71771 Mdot
.45243 .34449 Mdot
.26694 .62605 Mdot
.47792 .70854 Mdot
.4129 .37841 Mdot
.3117 .37578 Mdot
.2835 .36488 Mdot
.62762 .59245 Mdot
.72353 .36128 Mdot
.68954 .37467 Mdot
.25183 .62125 Mdot
.3227 .48735 Mdot
.45315 .40128 Mdot
.63117 .57843 Mdot
.32174 .39251 Mdot
.493 .69144 Mdot
.32044 .57363 Mdot
.52458 .8071 Mdot
.48393 .69652 Mdot
.43279 .4088 Mdot
.69824 .37743 Mdot
.31732 .56467 Mdot
.64139 .49178 Mdot
.50229 .28158 Mdot
.60648 .46108 Mdot
.73401 .33314 Mdot
.61677 .47849 Mdot
.46522 .7894 Mdot
.65126 .63167 Mdot
.29236 .57902 Mdot
.5029 .69103 Mdot
.49223 .68953 Mdot
.63718 .6457 Mdot
.32293 .47274 Mdot
.26356 .67616 Mdot
.23114 .39346 Mdot
.69959 .66859 Mdot
.70625 .36888 Mdot
.41909 .26592 Mdot
.64739 .61822 Mdot
.61333 .60959 Mdot
.43093 .70076 Mdot
.42681 .73576 Mdot
.30486 .58485 Mdot
.41342 .41141 Mdot
.30537 .4557 Mdot
.41393 .36611 Mdot
.54928 .39275 Mdot
.49505 .71139 Mdot
.3212 .57364 Mdot
.42436 .72273 Mdot
.45784 .37443 Mdot
.41769 .38602 Mdot
.72507 .65904 Mdot
.62896 .45875 Mdot
.75388 .65009 Mdot
.44502 .33995 Mdot
.63767 .61532 Mdot
.26047 .60627 Mdot
.64054 .47999 Mdot
.454 .4226 Mdot
.52215 .70313 Mdot
.64353 .44476 Mdot
.63832 .48363 Mdot
.51661 .42312 Mdot
.37858 .56373 Mdot
.35558 .59688 Mdot
.67345 .38932 Mdot
.42666 .74167 Mdot
.52287 .72452 Mdot
.47745 .79906 Mdot
.43732 .4065 Mdot
.50279 .67864 Mdot
.63193 .4167 Mdot
.4114 .37984 Mdot
.29707 .36124 Mdot
.33018 .48166 Mdot
.41768 .42693 Mdot
.31655 .38476 Mdot
.48674 .70036 Mdot
.6148 .41185 Mdot
.44457 .41508 Mdot
.66259 .63953 Mdot
.30646 .58085 Mdot
.38215 .57747 Mdot
.70416 .34332 Mdot
.42722 .72161 Mdot
.62591 .1747 Mdot
.31958 .57401 Mdot
.42196 .40352 Mdot
.49035 .69182 Mdot
.64886 .46235 Mdot
.64199 .46364 Mdot
.61463 .44348 Mdot
.31244 .58997 Mdot
.6403 .47843 Mdot
.25791 .62226 Mdot
.44674 .28423 Mdot
.4922 .44289 Mdot
.46844 .69699 Mdot
.70427 .3712 Mdot
.70189 .39801 Mdot
.71079 .66663 Mdot
.4674 .37474 Mdot
.54955 .3929 Mdot
.27435 .5732 Mdot
.70214 .37616 Mdot
.42572 .38218 Mdot
.61405 .45378 Mdot
.40191 .25081 Mdot
.67255 .40403 Mdot
.61491 .47355 Mdot
.287 .35277 Mdot
.34337 .58038 Mdot
.62886 .44906 Mdot
.3133 .5966 Mdot
.42621 .37806 Mdot
.46067 .31265 Mdot
.35258 .58755 Mdot
.28243 .71059 Mdot
.65093 .43557 Mdot
.50577 .7282 Mdot
.46616 .31931 Mdot
.44775 .35602 Mdot
.46925 .38765 Mdot
.64772 .45751 Mdot
.32951 .71997 Mdot
.65211 .64272 Mdot
.75827 .6688 Mdot
.70614 .67251 Mdot
.432 .70507 Mdot
.48343 .80547 Mdot
.45987 .37383 Mdot
.323 .47139 Mdot
.47126 .38086 Mdot
.47595 .71507 Mdot
.44953 .42103 Mdot
.4321 .37376 Mdot
.43674 .35323 Mdot
.65713 .64012 Mdot
.5314 .72627 Mdot
.28032 .35108 Mdot
.452 .29691 Mdot
.72412 .35155 Mdot
.32 .60879 Mdot
.43183 .38524 Mdot
.28552 .56468 Mdot
.62717 .58929 Mdot
.2511 .66683 Mdot
.44671 .37359 Mdot
.62859 .45921 Mdot
.49585 .67583 Mdot
.51159 .68849 Mdot
.63276 .5907 Mdot
.63552 .58888 Mdot
.44731 .35624 Mdot
.495 .71742 Mdot
.4597 .39651 Mdot
.4598 .2966 Mdot
.63588 .4757 Mdot
.6855 .35605 Mdot
.40618 .37562 Mdot
.2638 .67453 Mdot
.73734 .31116 Mdot
.43507 .35803 Mdot
.35206 .60528 Mdot
.65654 .6301 Mdot
.661 .65922 Mdot
.33556 .57973 Mdot
.65842 .65889 Mdot
.25206 .66992 Mdot
.32858 .40179 Mdot
.67962 .36072 Mdot
.25605 .36896 Mdot
.69496 .3884 Mdot
.64492 .44715 Mdot
.42845 .40947 Mdot
.57203 .68477 Mdot
.7005 .6713 Mdot
.34932 .27741 Mdot
.49764 .70574 Mdot
.624 .4978 Mdot
.29464 .37173 Mdot
.71509 .33749 Mdot
.65878 .61517 Mdot
.65333 .46933 Mdot
.44585 .34097 Mdot
.3551 .61712 Mdot
.3048 .35362 Mdot
.62838 .4926 Mdot
.64428 .45002 Mdot
.65311 .46612 Mdot
.50431 .72677 Mdot
.29095 .6049 Mdot
.42707 .71151 Mdot
.61943 .61568 Mdot
.47316 .33709 Mdot
.42231 .40066 Mdot
.32401 .57038 Mdot
.40438 .38796 Mdot
.48026 .71392 Mdot
.22604 .39687 Mdot
.71074 .36211 Mdot
.64709 .47597 Mdot
.36724 .69026 Mdot
.64845 .48315 Mdot
.27919 .36119 Mdot
.27122 .36341 Mdot
.36712 .60713 Mdot
.48433 .72423 Mdot
.42093 .43573 Mdot
.61591 .57603 Mdot
.69192 .36803 Mdot
.50848 .68327 Mdot
.29023 .35831 Mdot
.44761 .38313 Mdot
.70253 .3737 Mdot
.4257 .72582 Mdot
.72108 .37697 Mdot
.50889 .69476 Mdot
.60984 .49225 Mdot
.36761 .32488 Mdot
.44069 .38628 Mdot
.62406 .46062 Mdot
.30531 .61268 Mdot
.51771 .71035 Mdot
.33516 .48602 Mdot
.63836 .48562 Mdot
.71891 .66884 Mdot
.51732 .6939 Mdot
.45299 .34876 Mdot
.27406 .60375 Mdot
.37577 .58717 Mdot
.28913 .59747 Mdot
.81062 .56284 Mdot
.72711 .67348 Mdot
.65519 .63318 Mdot
.48039 .69889 Mdot
.65759 .64903 Mdot
.70695 .3376 Mdot
.42622 .27035 Mdot
.63972 .58635 Mdot
.29327 .61222 Mdot
.64232 .64159 Mdot
.46006 .397 Mdot
.5005 .7288 Mdot
.66096 .59321 Mdot
.40076 .4124 Mdot
.3077 .3783 Mdot
.64067 .44853 Mdot
.69491 .39433 Mdot
.45056 .28919 Mdot
.41398 .41802 Mdot
.62414 .46733 Mdot
.44377 .38502 Mdot
.48219 .71479 Mdot
.50022 .31091 Mdot
.4731 .3578 Mdot
.69911 .66569 Mdot
.26102 .688 Mdot
.62106 .58323 Mdot
.74441 .35724 Mdot
.41538 .37004 Mdot
.43989 .39157 Mdot
.28887 .36511 Mdot
.23533 .3734 Mdot
.46829 .67489 Mdot
.47261 .32758 Mdot
.66148 .66143 Mdot
.30228 .59736 Mdot
.34803 .61586 Mdot
.54086 .39977 Mdot
.62204 .46056 Mdot
.46608 .68377 Mdot
.43525 .40002 Mdot
.63155 .49586 Mdot
.43439 .30102 Mdot
.43502 .75224 Mdot
.73284 .6743 Mdot
.61455 .60951 Mdot
.36343 .60895 Mdot
.67618 .63887 Mdot
.28742 .36616 Mdot
.6424 .47556 Mdot
.72862 .67677 Mdot
.44135 .68726 Mdot
.69042 .36913 Mdot
.43184 .35472 Mdot
.56773 .30615 Mdot
.67758 .63775 Mdot
.63819 .59838 Mdot
.45858 .39955 Mdot
.26254 .58745 Mdot
.7159 .31576 Mdot
.51118 .71794 Mdot
.37304 .59986 Mdot
.366 .44961 Mdot
.6486 .27281 Mdot
.47845 .6876 Mdot
.29971 .36028 Mdot
.67963 .63217 Mdot
.74048 .59271 Mdot
.30013 .59972 Mdot
.69135 .36724 Mdot
.4016 .40279 Mdot
.32481 .61858 Mdot
.69932 .66971 Mdot
.28505 .59237 Mdot
.63321 .455 Mdot
.49724 .72833 Mdot
.66383 .61665 Mdot
.52791 .72791 Mdot
.26778 .62593 Mdot
.70855 .36636 Mdot
.57279 .36342 Mdot
.31929 .37647 Mdot
.32901 .48159 Mdot
.30158 .37467 Mdot
.63076 .42104 Mdot
.30532 .37678 Mdot
.3798 .58053 Mdot
.4443 .39006 Mdot
.43598 .4239 Mdot
.67142 .66137 Mdot
.44114 .35274 Mdot
.42606 .417 Mdot
.46307 .40901 Mdot
.42541 .35945 Mdot
.43289 .36373 Mdot
.45709 .35149 Mdot
.34947 .59621 Mdot
.46244 .33896 Mdot
.30502 .56823 Mdot
.28444 .56962 Mdot
.61944 .61688 Mdot
.69034 .33831 Mdot
.67347 .37508 Mdot
.4525 .31791 Mdot
.56801 .30756 Mdot
.30255 .45358 Mdot
.30675 .59967 Mdot
.51107 .68913 Mdot
.47121 .35909 Mdot
.72016 .31652 Mdot
.45344 .31765 Mdot
.6586 .60283 Mdot
.62963 .58465 Mdot
.39953 .41334 Mdot
.64145 .19001 Mdot
.44871 .33779 Mdot
.43705 .27922 Mdot
.43091 .3968 Mdot
.45566 .34447 Mdot
.62142 .5743 Mdot
.58043 .34058 Mdot
.29472 .38548 Mdot
.3722 .55109 Mdot
.68747 .36868 Mdot
.62817 .45108 Mdot
.46058 .31236 Mdot
.35807 .43723 Mdot
.3625 .52386 Mdot
.28883 .36394 Mdot
.65697 .60607 Mdot
.32476 .58395 Mdot
.44059 .28305 Mdot
.50656 .71641 Mdot
.50865 .28465 Mdot
.24911 .65088 Mdot
.50697 .72057 Mdot
.69343 .36903 Mdot
.67136 .61171 Mdot
.42204 .38077 Mdot
.63327 .62079 Mdot
.4583 .37075 Mdot
.43646 .26964 Mdot
.6824 .35731 Mdot
.29762 .61609 Mdot
.52274 .70753 Mdot
.346 .59705 Mdot
.25934 .6677 Mdot
.52169 .34738 Mdot
.74446 .66348 Mdot
.63309 .5763 Mdot
.7376 .36057 Mdot
.30276 .57554 Mdot
.43192 .41625 Mdot
.24721 .41582 Mdot
.33126 .6026 Mdot
.35687 .61685 Mdot
.50645 .28865 Mdot
.58435 .32085 Mdot
.4567 .35366 Mdot
.32035 .61871 Mdot
.67261 .61266 Mdot
.6779 .36263 Mdot
.43158 .41382 Mdot
.64439 .4728 Mdot
.35251 .61416 Mdot
.67349 .63787 Mdot
.57866 .34901 Mdot
.64023 .61086 Mdot
.29977 .58988 Mdot
.62349 .58796 Mdot
.53976 .7135 Mdot
.64097 .58626 Mdot
.40912 .36948 Mdot
.43723 .3966 Mdot
.3755 .59265 Mdot
.32026 .58683 Mdot
.27912 .36156 Mdot
.40739 .37858 Mdot
.29536 .57783 Mdot
.68849 .65794 Mdot
.35655 .52529 Mdot
.28221 .36394 Mdot
.41949 .41302 Mdot
.69849 .38813 Mdot
.46442 .30052 Mdot
.49773 .28952 Mdot
.47419 .34986 Mdot
.70619 .36575 Mdot
.35701 .6188 Mdot
.43453 .40372 Mdot
.58319 .33125 Mdot
.66929 .66371 Mdot
.40976 .43337 Mdot
.64916 .46706 Mdot
.2859 .38085 Mdot
.53269 .27574 Mdot
.29097 .35906 Mdot
.2938 .5959 Mdot
.29731 .58585 Mdot
.6799 .65901 Mdot
.30296 .60864 Mdot
.64806 .46751 Mdot
.46901 .68255 Mdot
.25627 .65649 Mdot
.62158 .5006 Mdot
.63279 .43666 Mdot
.64495 .43268 Mdot
.61744 .48533 Mdot
.7237 .31783 Mdot
.72596 .66767 Mdot
.63561 .43962 Mdot
.29801 .57204 Mdot
.58151 .58441 Mdot
.60239 .46284 Mdot
.46565 .6838 Mdot
.63846 .48274 Mdot
.41032 .43323 Mdot
.29109 .36213 Mdot
.34463 .57233 Mdot
.50304 .7182 Mdot
.63849 .41981 Mdot
.42822 .4164 Mdot
.36754 .6046 Mdot
.43172 .38211 Mdot
.72201 .36348 Mdot
.31896 .59596 Mdot
.64906 .60507 Mdot
.68665 .35306 Mdot
.62423 .48573 Mdot
.70644 .35428 Mdot
.64453 .63421 Mdot
.48735 .67884 Mdot
.40209 .41048 Mdot
.70432 .39374 Mdot
.69004 .33886 Mdot
.40752 .42884 Mdot
.30176 .58171 Mdot
.6448 .42368 Mdot
.41685 .41574 Mdot
.29384 .36849 Mdot
.34024 .58125 Mdot
.32476 .72645 Mdot
.42131 .3775 Mdot
.2734 .36073 Mdot
.37644 .56594 Mdot
.6284 .49487 Mdot
.64383 .60389 Mdot
.45185 .35434 Mdot
.5023 .70574 Mdot
.49186 .71396 Mdot
.7012 .66994 Mdot
.35773 .60565 Mdot
.67484 .64601 Mdot
.40252 .42714 Mdot
.63455 .48532 Mdot
.45247 .36993 Mdot
.72513 .65622 Mdot
.29361 .72119 Mdot
.31007 .56519 Mdot
.61635 .60625 Mdot
.43124 .30424 Mdot
.46507 .709 Mdot
.68955 .66447 Mdot
.37574 .56069 Mdot
.33775 .61113 Mdot
.33426 .57897 Mdot
.6747 .37991 Mdot
.64653 .60958 Mdot
.34566 .57602 Mdot
.33963 .57221 Mdot
.28498 .36333 Mdot
.40104 .41946 Mdot
.36188 .61248 Mdot
.71343 .67197 Mdot
.68825 .37396 Mdot
.64065 .65163 Mdot
.73839 .31266 Mdot
.51641 .71531 Mdot
.45083 .42563 Mdot
.46607 .3818 Mdot
.61513 .16746 Mdot
.44109 .34185 Mdot
.42767 .398 Mdot
.37167 .60754 Mdot
.72731 .35842 Mdot
.67968 .38252 Mdot
.30162 .57673 Mdot
.30865 .56447 Mdot
.70132 .34881 Mdot
.36482 .35202 Mdot
.54814 .28972 Mdot
.43769 .30883 Mdot
.29002 .60542 Mdot
.25869 .65358 Mdot
.48945 .70786 Mdot
.33872 .61745 Mdot
.54029 .74045 Mdot
.65189 .58539 Mdot
.64591 .58684 Mdot
.51728 .69773 Mdot
.42088 .38356 Mdot
.62486 .57266 Mdot
.29841 .3839 Mdot
.54135 .74364 Mdot
.3105 .36563 Mdot
.80113 .63716 Mdot
.40416 .3863 Mdot
.54275 .63318 Mdot
.45775 .78264 Mdot
.27814 .36552 Mdot
.3263 .40635 Mdot
.69724 .36131 Mdot
.38315 .58028 Mdot
.47384 .71023 Mdot
.30666 .45697 Mdot
.44056 .38833 Mdot
.30812 .61779 Mdot
.52238 .71404 Mdot
.31394 .72261 Mdot
.29593 .38718 Mdot
.28852 .37567 Mdot
.24781 .41831 Mdot
.28154 .58111 Mdot
.64259 .60506 Mdot
.37452 .60208 Mdot
.33529 .56637 Mdot
.31039 .37478 Mdot
.68122 .6244 Mdot
.39579 .25744 Mdot
.2947 .61144 Mdot
.68327 .40638 Mdot
.32005 .60558 Mdot
.69663 .35089 Mdot
.34876 .57943 Mdot
.62435 .62809 Mdot
.42294 .36749 Mdot
.62132 .62316 Mdot
.71806 .36741 Mdot
.61936 .59045 Mdot
.48306 .71689 Mdot
.62595 .47711 Mdot
.47898 .70903 Mdot
.42378 .2672 Mdot
.33859 .48905 Mdot
.47299 .68314 Mdot
.52367 .36776 Mdot
.44734 .38615 Mdot
.34941 .58039 Mdot
.65783 .60873 Mdot
.62892 .64325 Mdot
.4526 .28953 Mdot
.31632 .57855 Mdot
.66563 .65618 Mdot
.30125 .39433 Mdot
.5607 .7201 Mdot
.2776 .37425 Mdot
.52986 .81067 Mdot
.29023 .58683 Mdot
.6391 .65246 Mdot
.43828 .28179 Mdot
.31 .56079 Mdot
.65585 .59048 Mdot
.50502 .68867 Mdot
.502 .7053 Mdot
.4212 .3534 Mdot
.52404 .72953 Mdot
.65775 .60311 Mdot
.24816 .64046 Mdot
.34905 .58248 Mdot
.28554 .71779 Mdot
.70783 .3616 Mdot
.67426 .63142 Mdot
.63757 .47618 Mdot
.27105 .6286 Mdot
.65218 .64801 Mdot
.62845 .17634 Mdot
.85876 .51157 Mdot
.6711 .65218 Mdot
.31743 .59678 Mdot
.31332 .58687 Mdot
.30952 .35787 Mdot
.45414 .29339 Mdot
.6603 .61672 Mdot
.56796 .6894 Mdot
.40083 .30431 Mdot
.62354 .4756 Mdot
.74617 .67529 Mdot
.40132 .37522 Mdot
.29835 .37275 Mdot
.51598 .7071 Mdot
.41709 .38538 Mdot
.29662 .56855 Mdot
.44617 .33915 Mdot
.47611 .70954 Mdot
.69995 .66125 Mdot
.44188 .38774 Mdot
.69317 .36783 Mdot
.50773 .70041 Mdot
.5065 .70768 Mdot
.62109 .60335 Mdot
.35807 .60549 Mdot
.31074 .46197 Mdot
.64428 .6082 Mdot
.30083 .3796 Mdot
.62712 .46884 Mdot
.45495 .3503 Mdot
.30947 .62186 Mdot
.37036 .53891 Mdot
.67493 .63062 Mdot
.41236 .4268 Mdot
.47919 .69217 Mdot
.67801 .65535 Mdot
.30039 .35814 Mdot
.65325 .59249 Mdot
.63721 .51265 Mdot
.62501 .56894 Mdot
.25925 .61669 Mdot
.63637 .42774 Mdot
.30388 .61719 Mdot
.62498 .44474 Mdot
.7757 .57429 Mdot
.69221 .37105 Mdot
.62289 .57626 Mdot
.28833 .71345 Mdot
.61669 .61126 Mdot
.42227 .36271 Mdot
.43624 .40551 Mdot
.64879 .64014 Mdot
.70798 .36926 Mdot
.59526 .46874 Mdot
.72211 .37015 Mdot
.31697 .59251 Mdot
.30009 .38973 Mdot
.85289 .55189 Mdot
.6093 .59511 Mdot
.52626 .71789 Mdot
.35842 .52195 Mdot
.62907 .43753 Mdot
.49101 .71945 Mdot
.50864 .7056 Mdot
.71614 .35859 Mdot
.61295 .60705 Mdot
.33351 .6226 Mdot
.51171 .7319 Mdot
.30696 .56158 Mdot
.58479 .33691 Mdot
.62313 .49054 Mdot
.7246 .38551 Mdot
.61336 .45553 Mdot
.44702 .28774 Mdot
.47612 .72347 Mdot
.43779 .37275 Mdot
.72281 .3407 Mdot
.5171 .70109 Mdot
.70486 .38667 Mdot
.30029 .35919 Mdot
.66124 .65647 Mdot
.28371 .45346 Mdot
.41653 .35771 Mdot
.40768 .3872 Mdot
.51926 .71195 Mdot
.33473 .41206 Mdot
.37591 .55781 Mdot
.34858 .58489 Mdot
.65135 .63114 Mdot
.50072 .28603 Mdot
.45427 .33729 Mdot
.42819 .41481 Mdot
.63978 .63416 Mdot
.61998 .46045 Mdot
.74666 .67164 Mdot
.4213 .41165 Mdot
.48578 .70292 Mdot
.29652 .3599 Mdot
.46361 .69967 Mdot
.40986 .43887 Mdot
.41804 .37033 Mdot
.2944 .38092 Mdot
.305 .37175 Mdot
.47892 .70859 Mdot
.61545 .47636 Mdot
.65104 .47016 Mdot
.2915 .60395 Mdot
.40046 .4001 Mdot
.39943 .30646 Mdot
.43362 .40039 Mdot
.69767 .36179 Mdot
.494 .28597 Mdot
.4554 .41005 Mdot
.46891 .32109 Mdot
.40133 .30158 Mdot
.42831 .37637 Mdot
.51935 .7157 Mdot
.31169 .58538 Mdot
.48162 .69041 Mdot
.50985 .73086 Mdot
.63925 .63963 Mdot
.70066 .38891 Mdot
.44608 .35463 Mdot
.71194 .34237 Mdot
.42068 .34896 Mdot
.69469 .41149 Mdot
.45525 .30365 Mdot
.4363 .28139 Mdot
.6797 .40252 Mdot
.44522 .39294 Mdot
.64964 .63516 Mdot
.61242 .57209 Mdot
.31368 .37946 Mdot
.3995 .39338 Mdot
.53199 .71762 Mdot
.48066 .68013 Mdot
.73435 .67316 Mdot
.60492 .57945 Mdot
.72244 .36241 Mdot
.58552 .46923 Mdot
.3071 .37562 Mdot
.4386 .34787 Mdot
.61751 .47644 Mdot
.66465 .64517 Mdot
.6301 .44096 Mdot
.72918 .67043 Mdot
.47153 .70947 Mdot
.49581 .6891 Mdot
.405 .38125 Mdot
.68847 .22367 Mdot
.33477 .60433 Mdot
.31409 .58582 Mdot
.46915 .68065 Mdot
.62104 .58283 Mdot
.63643 .45386 Mdot
.26089 .42404 Mdot
.36274 .52983 Mdot
.70542 .33583 Mdot
.45319 .36287 Mdot
.6439 .58127 Mdot
.28844 .57935 Mdot
.72218 .35926 Mdot
.47417 .35717 Mdot
.68514 .63353 Mdot
.43706 .38151 Mdot
.26923 .37492 Mdot
.31263 .57232 Mdot
.4585 .30284 Mdot
.2958 .61408 Mdot
.49361 .71162 Mdot
.48361 .72727 Mdot
.41452 .37495 Mdot
.28473 .4497 Mdot
.26202 .60262 Mdot
.49271 .73115 Mdot
.6752 .39087 Mdot
.63146 .47641 Mdot
.70386 .38698 Mdot
.65967 .6379 Mdot
.69226 .37003 Mdot
.64881 .64687 Mdot
.6806 .6637 Mdot
.34039 .61983 Mdot
.70218 .37423 Mdot
.45806 .42327 Mdot
.64301 .4734 Mdot
.67264 .36903 Mdot
.46705 .3299 Mdot
.28431 .35701 Mdot
.66589 .62435 Mdot
.71331 .34202 Mdot
.4534 .35369 Mdot
.36416 .69234 Mdot
.50246 .72956 Mdot
.48004 .71528 Mdot
.63361 .45397 Mdot
.67471 .62316 Mdot
.33024 .6239 Mdot
.43 .29845 Mdot
.26004 .62264 Mdot
.42119 .41874 Mdot
.44106 .35597 Mdot
.25773 .61832 Mdot
.33079 .62392 Mdot
.41491 .37702 Mdot
.47752 .45009 Mdot
.63507 .47996 Mdot
.49956 .71135 Mdot
.31951 .59233 Mdot
.32674 .58792 Mdot
.64352 .59615 Mdot
.35629 .61314 Mdot
.73612 .33751 Mdot
.47713 .71435 Mdot
.64542 .48742 Mdot
.48006 .69599 Mdot
.63586 .52488 Mdot
.66745 .65213 Mdot
.30761 .71748 Mdot
.35807 .59666 Mdot
.28313 .3677 Mdot
.35875 .61419 Mdot
.70992 .35924 Mdot
.32187 .61771 Mdot
.33123 .62026 Mdot
.40183 .41832 Mdot
.61819 .48089 Mdot
.6408 .44466 Mdot
.44915 .29296 Mdot
.33283 .60442 Mdot
.42704 .36934 Mdot
.47162 .3475 Mdot
.40518 .38737 Mdot
.4565 .29997 Mdot
.35245 .59712 Mdot
.35689 .43586 Mdot
.36601 .60849 Mdot
.30717 .57236 Mdot
.73742 .30939 Mdot
.64722 .46366 Mdot
.6224 .44453 Mdot
.55102 .68732 Mdot
.41439 .41232 Mdot
.65585 .65768 Mdot
.29971 .37788 Mdot
.62635 .48343 Mdot
.47698 .35043 Mdot
.6907 .34145 Mdot
.45668 .37665 Mdot
.6194 .46971 Mdot
.6549 .60827 Mdot
.284 .36782 Mdot
.42775 .40936 Mdot
.62444 .4526 Mdot
.34785 .61877 Mdot
.34023 .58843 Mdot
.35097 .50897 Mdot
.7089 .35132 Mdot
.47322 .70011 Mdot
.29828 .37559 Mdot
.65142 .63314 Mdot
.64258 .65075 Mdot
.30446 .61791 Mdot
.62804 .59719 Mdot
.4995 .69077 Mdot
.42047 .40561 Mdot
.48811 .71216 Mdot
.69558 .34238 Mdot
.32015 .59559 Mdot
.29004 .36924 Mdot
.31725 .36012 Mdot
.2973 .58572 Mdot
.63436 .48222 Mdot
.69565 .39035 Mdot
.62623 .612 Mdot
.31491 .56631 Mdot
.47143 .70336 Mdot
.63801 .59332 Mdot
.28523 .37298 Mdot
.7426 .29404 Mdot
.41686 .38432 Mdot
.41656 .36317 Mdot
.27678 .62715 Mdot
.42054 .4327 Mdot
.61943 .6151 Mdot
.32481 .62575 Mdot
.28211 .36121 Mdot
.41572 .26232 Mdot
.66571 .38576 Mdot
.65666 .51845 Mdot
.42809 .3843 Mdot
.47077 .38346 Mdot
.45924 .38848 Mdot
.27762 .70735 Mdot
.45836 .29999 Mdot
.71267 .65834 Mdot
.72963 .37833 Mdot
.51998 .72932 Mdot
.62266 .46794 Mdot
.63284 .63471 Mdot
.45631 .45818 Mdot
.41455 .38531 Mdot
.32893 .48926 Mdot
.2935 .35706 Mdot
.48383 .68661 Mdot
.34818 .4205 Mdot
.65524 .60465 Mdot
.75754 .67282 Mdot
.40108 .42416 Mdot
.37027 .54394 Mdot
.50705 .63836 Mdot
.61973 .47788 Mdot
.61753 .44903 Mdot
.72153 .35919 Mdot
.69298 .66025 Mdot
.60717 .45539 Mdot
.4804 .69277 Mdot
.44513 .34351 Mdot
.45393 .4145 Mdot
.33634 .72171 Mdot
.28889 .58293 Mdot
.51997 .72531 Mdot
.65348 .53104 Mdot
.44141 .36671 Mdot
.34261 .60505 Mdot
.30039 .60023 Mdot
.69682 .33717 Mdot
.7147 .66658 Mdot
.69006 .66693 Mdot
.65173 .19943 Mdot
.63922 .42256 Mdot
.66214 .64508 Mdot
.61979 .43887 Mdot
.29884 .38003 Mdot
.4604 .31275 Mdot
.51847 .72906 Mdot
.42003 .36356 Mdot
.32679 .48336 Mdot
.29172 .59891 Mdot
.43348 .39759 Mdot
.68443 .37282 Mdot
.23258 .37945 Mdot
.31809 .38156 Mdot
.48453 .4457 Mdot
.67308 .61321 Mdot
.43795 .35735 Mdot
.73584 .3351 Mdot
.63057 .49671 Mdot
.41548 .43465 Mdot
.64477 .60532 Mdot
.63687 .42797 Mdot
.68267 .37676 Mdot
.28812 .59925 Mdot
.62406 .46628 Mdot
.29718 .35693 Mdot
.45779 .36225 Mdot
.67605 .39332 Mdot
.29379 .37893 Mdot
.26081 .66031 Mdot
.60876 .46597 Mdot
.64018 .58386 Mdot
.32109 .56501 Mdot
.4337 .35957 Mdot
.63097 .47782 Mdot
.45165 .36612 Mdot
.26098 .67412 Mdot
.42933 .35365 Mdot
.34867 .70422 Mdot
.30807 .5802 Mdot
.49413 .69772 Mdot
.28986 .36494 Mdot
.43891 .38093 Mdot
.62762 .43126 Mdot
.63885 .45403 Mdot
.43062 .41611 Mdot
.30194 .6167 Mdot
.30878 .61467 Mdot
.36735 .53598 Mdot
.64399 .5929 Mdot
.43945 .31252 Mdot
.49478 .70296 Mdot
.61635 .47393 Mdot
.51374 .73212 Mdot
.46897 .38657 Mdot
.70561 .35219 Mdot
.33823 .71662 Mdot
.41549 .40239 Mdot
.32078 .57835 Mdot
.5503 .29337 Mdot
.33554 .61434 Mdot
.54951 .68813 Mdot
.52318 .72397 Mdot
.32828 .59918 Mdot
.42639 .38714 Mdot
.44468 .28402 Mdot
.45096 .4204 Mdot
.47178 .71869 Mdot
.6485 .47758 Mdot
.66473 .44191 Mdot
.66566 .60006 Mdot
.7469 .31118 Mdot
.51371 .68842 Mdot
.45533 .78224 Mdot
.28213 .36399 Mdot
.33885 .57646 Mdot
.46892 .69745 Mdot
.50627 .7111 Mdot
.66347 .61018 Mdot
.2846 .36469 Mdot
.43811 .38504 Mdot
.64951 .46226 Mdot
.49513 .67951 Mdot
.44793 .39975 Mdot
.2771 .36262 Mdot
.73864 .67158 Mdot
.3792 .56354 Mdot
.31984 .72802 Mdot
.47133 .37717 Mdot
.32763 .48051 Mdot
.57428 .66815 Mdot
.34803 .57994 Mdot
.42945 .36836 Mdot
.63829 .46678 Mdot
.62666 .59411 Mdot
.41998 .39925 Mdot
.61522 .6039 Mdot
.47469 .68879 Mdot
.35809 .69905 Mdot
.46215 .40033 Mdot
.54269 .7419 Mdot
.42011 .37228 Mdot
.32023 .37177 Mdot
.69297 .37917 Mdot
.46628 .70106 Mdot
.36229 .53501 Mdot
.44917 .35043 Mdot
.63891 .60048 Mdot
.66561 .59877 Mdot
.29582 .6061 Mdot
.35426 .51414 Mdot
.29845 .7168 Mdot
.63969 .47424 Mdot
.6304 .60664 Mdot
.63236 .47837 Mdot
.49195 .44199 Mdot
.5116 .73207 Mdot
.68212 .37724 Mdot
.62393 .58912 Mdot
.48289 .67429 Mdot
.28398 .357 Mdot
.32141 .61052 Mdot
.27226 .63134 Mdot
.30744 .38421 Mdot
.66431 .65675 Mdot
.69134 .35625 Mdot
.46506 .3158 Mdot
.30431 .38826 Mdot
.68476 .35781 Mdot
.65143 .59859 Mdot
.33857 .59675 Mdot
.29746 .5936 Mdot
.30942 .58614 Mdot
.45191 .42481 Mdot
.36999 .53704 Mdot
.56452 .37708 Mdot
.42895 .42781 Mdot
.25028 .63524 Mdot
.43659 .41996 Mdot
.47874 .71419 Mdot
.31706 .57311 Mdot
.45749 .30144 Mdot
.28492 .38239 Mdot
.40335 .44182 Mdot
.40531 .40972 Mdot
.30674 .3693 Mdot
.41454 .41268 Mdot
.25646 .63597 Mdot
.37944 .56158 Mdot
.46815 .32036 Mdot
.48217 .72041 Mdot
.703 .35667 Mdot
.3289 .56292 Mdot
.44125 .35835 Mdot
.25698 .64777 Mdot
.46876 .33069 Mdot
.3535 .69968 Mdot
.30795 .36804 Mdot
.70447 .66119 Mdot
.44916 .3437 Mdot
.63889 .5762 Mdot
.32188 .36677 Mdot
.25836 .65622 Mdot
.50213 .72855 Mdot
.31962 .3804 Mdot
.65274 .58203 Mdot
.35057 .42312 Mdot
.64133 .4666 Mdot
.68923 .37599 Mdot
.63847 .42971 Mdot
.47962 .71091 Mdot
.4137 .39537 Mdot
.45668 .36965 Mdot
.42 .43484 Mdot
.49443 .44063 Mdot
.64618 .46763 Mdot
.67765 .40317 Mdot
.25491 .65277 Mdot
.44937 .39205 Mdot
.61986 .57085 Mdot
.34544 .58649 Mdot
.40983 .44858 Mdot
.45214 .43425 Mdot
.27967 .35485 Mdot
.33032 .60384 Mdot
.35776 .60613 Mdot
.71846 .31622 Mdot
.70007 .36958 Mdot
.40978 .37913 Mdot
.68717 .40403 Mdot
.29515 .37432 Mdot
.47833 .70152 Mdot
.44101 .42099 Mdot
.66753 .65273 Mdot
.44298 .2773 Mdot
.6496 .59637 Mdot
.40436 .3958 Mdot
.31823 .60506 Mdot
.47302 .71872 Mdot
.675 .66524 Mdot
.71733 .67422 Mdot
.56981 .37209 Mdot
.68791 .66889 Mdot
.71296 .34975 Mdot
.71406 .35785 Mdot
.4675 .70306 Mdot
.42674 .39528 Mdot
.45762 .29608 Mdot
.25044 .36137 Mdot
.41185 .40705 Mdot
.42088 .38611 Mdot
.44735 .6815 Mdot
.51651 .69449 Mdot
.62438 .5851 Mdot
.4143 .37968 Mdot
.45593 .38209 Mdot
.3223 .60162 Mdot
.72621 .35713 Mdot
.63264 .63018 Mdot
.72148 .36225 Mdot
.63781 .62168 Mdot
.53373 .27599 Mdot
.62673 .49005 Mdot
.71151 .35358 Mdot
.51844 .69284 Mdot
.32482 .57923 Mdot
.64752 .46707 Mdot
.65974 .62761 Mdot
.62943 .60156 Mdot
.4127 .35807 Mdot
.28693 .58465 Mdot
.34936 .58559 Mdot
.70564 .35002 Mdot
.47724 .6796 Mdot
.29945 .3843 Mdot
.61385 .45467 Mdot
.67574 .51828 Mdot
.63396 .59897 Mdot
.24966 .64967 Mdot
.27323 .62723 Mdot
.44579 .36294 Mdot
.33996 .58951 Mdot
.44371 .37575 Mdot
.37232 .60533 Mdot
.29037 .56666 Mdot
.4097 .43911 Mdot
.34904 .50465 Mdot
.66294 .64723 Mdot
.83486 .58636 Mdot
.27515 .36794 Mdot
.50801 .68016 Mdot
.2984 .37793 Mdot
.75027 .67231 Mdot
.55342 .29534 Mdot
.44699 .39412 Mdot
.44078 .35698 Mdot
.69399 .23749 Mdot
.46436 .34905 Mdot
.62162 .44918 Mdot
.64185 .46685 Mdot
.34197 .59453 Mdot
.63887 .43116 Mdot
.44891 .28955 Mdot
.70358 .37717 Mdot
.65241 .63162 Mdot
.58177 .32846 Mdot
.6969 .35226 Mdot
.29217 .59459 Mdot
.29376 .3845 Mdot
.25808 .60019 Mdot
.61737 .56877 Mdot
.62562 .45701 Mdot
.4776 .68761 Mdot
.45806 .28867 Mdot
.64691 .60092 Mdot
.4858 .67629 Mdot
.46884 .35131 Mdot
.72284 .66046 Mdot
.48097 .71891 Mdot
.84355 .57011 Mdot
.51292 .71289 Mdot
.46922 .68183 Mdot
.45034 .30108 Mdot
.70329 .37784 Mdot
.63146 .42834 Mdot
.69698 .40765 Mdot
.5014 .72614 Mdot
.77072 .66143 Mdot
.67219 .61982 Mdot
.43504 .2695 Mdot
.38365 .58022 Mdot
.63994 .48209 Mdot
.41992 .37707 Mdot
.51689 .71023 Mdot
.42456 .34584 Mdot
.63319 .42862 Mdot
.5002 .69436 Mdot
.32109 .36542 Mdot
.49393 .28229 Mdot
.63491 .47225 Mdot
.64411 .4464 Mdot
.72083 .34935 Mdot
.7063 .66829 Mdot
.3529 .59083 Mdot
.68613 .34209 Mdot
.42184 .29188 Mdot
.40784 .37887 Mdot
.47789 .70769 Mdot
.62411 .46516 Mdot
.49822 .705 Mdot
.6863 .3834 Mdot
.67376 .39117 Mdot
.2887 .59765 Mdot
.36861 .53923 Mdot
.61559 .50178 Mdot
.38999 .31129 Mdot
.44902 .40946 Mdot
.33181 .49135 Mdot
.35169 .60696 Mdot
.32711 .40464 Mdot
.68703 .38988 Mdot
.72113 .34681 Mdot
.32116 .37048 Mdot
.47186 .33967 Mdot
.3022 .36532 Mdot
.4695 .376 Mdot
.74564 .6355 Mdot
.28818 .36639 Mdot
.62688 .61136 Mdot
.47081 .37215 Mdot
.43028 .75041 Mdot
.31623 .37516 Mdot
.44668 .35885 Mdot
.64417 .61665 Mdot
.40937 .4303 Mdot
.67176 .63702 Mdot
.42708 .36448 Mdot
.72718 .65583 Mdot
.65112 .63277 Mdot
.59083 .49122 Mdot
.51438 .34058 Mdot
.62683 .44541 Mdot
.67789 .38399 Mdot
.70701 .39146 Mdot
.57837 .35126 Mdot
.33571 .59651 Mdot
.23732 .37325 Mdot
.4456 .35961 Mdot
.66519 .61089 Mdot
.47579 .68618 Mdot
.30506 .35303 Mdot
.41666 .36108 Mdot
.30577 .38228 Mdot
.32407 .61182 Mdot
.6769 .6258 Mdot
.69248 .38429 Mdot
.61208 .58905 Mdot
.74264 .6747 Mdot
.66826 .64974 Mdot
.51429 .42433 Mdot
.2927 .3533 Mdot
.7356 .33596 Mdot
.34313 .4951 Mdot
.60087 .44458 Mdot
.30649 .61184 Mdot
.62401 .46965 Mdot
.71452 .37205 Mdot
.49907 .30537 Mdot
.34702 .58611 Mdot
.63987 .6339 Mdot
.43717 .38039 Mdot
.61493 .48034 Mdot
.6975 .40784 Mdot
.29733 .56711 Mdot
.67694 .39652 Mdot
.65367 .62519 Mdot
.63008 .47238 Mdot
.43598 .31216 Mdot
.36426 .44843 Mdot
.42728 .26426 Mdot
.4406 .37679 Mdot
.70083 .3494 Mdot
.28707 .58356 Mdot
.30668 .38258 Mdot
.51387 .69832 Mdot
.45313 .29228 Mdot
.41819 .37936 Mdot
.54593 .741 Mdot
.31698 .60628 Mdot
.70749 .36394 Mdot
.51599 .71198 Mdot
.69891 .36879 Mdot
.62114 .44651 Mdot
.37077 .60682 Mdot
.61718 .44979 Mdot
.2937 .3578 Mdot
.4722 .69338 Mdot
.34916 .58622 Mdot
.73885 .66962 Mdot
.6439 .42427 Mdot
.65085 .64029 Mdot
.49765 .30298 Mdot
.29859 .61101 Mdot
.42843 .7169 Mdot
.61226 .58963 Mdot
.44394 .69679 Mdot
.46354 .30196 Mdot
.50514 .69556 Mdot
.44486 .35848 Mdot
.30726 .59386 Mdot
.46843 .7163 Mdot
.71297 .67282 Mdot
.4675 .39392 Mdot
.61241 .48802 Mdot
.44468 .39294 Mdot
.26711 .70169 Mdot
.44596 .76869 Mdot
.37679 .59168 Mdot
.5102 .68441 Mdot
.40713 .39814 Mdot
.63867 .47752 Mdot
.39993 .40237 Mdot
.50795 .72585 Mdot
.4513 .67869 Mdot
.62821 .64048 Mdot
.43672 .3754 Mdot
.69839 .36355 Mdot
.64817 .65028 Mdot
.67683 .61329 Mdot
.62868 .58289 Mdot
.36418 .53664 Mdot
.63455 .48893 Mdot
.64135 .47198 Mdot
.55905 .29879 Mdot
.4998 .70621 Mdot
.62561 .4464 Mdot
.45719 .37187 Mdot
.56445 .37577 Mdot
.30909 .58307 Mdot
.65277 .6201 Mdot
.40691 .39088 Mdot
.27575 .37286 Mdot
.62871 .44979 Mdot
.64483 .60941 Mdot
.3384 .62111 Mdot
.59173 .58229 Mdot
.41871 .40078 Mdot
.28677 .36083 Mdot
.2932 .58524 Mdot
.26788 .67702 Mdot
.4355 .30035 Mdot
.44315 .37861 Mdot
.49184 .71425 Mdot
.31138 .68055 Mdot
.46692 .34743 Mdot
.37211 .49869 Mdot
.6489 .47206 Mdot
.5663 .57158 Mdot
.3326 .66151 Mdot
.26344 .35009 Mdot
.46622 .59911 Mdot
.35226 .27731 Mdot
.50548 .6124 Mdot
.75077 .61911 Mdot
.42891 .59538 Mdot
.85 .54996 Mdot
.52841 .74029 Mdot
.26348 .36499 Mdot
.61668 .18679 Mdot
.46496 .78045 Mdot
.42287 .64233 Mdot
.50417 .7667 Mdot
.56799 .46142 Mdot
.74306 .66818 Mdot
.72666 .66482 Mdot
.74566 .60954 Mdot
.40134 .37599 Mdot
.40314 .6566 Mdot
.29392 .39667 Mdot
.44759 .74406 Mdot
.70269 .64178 Mdot
.30104 .3907 Mdot
.67981 .25153 Mdot
.55354 .71208 Mdot
.65182 .32393 Mdot
.29632 .44416 Mdot
.67596 .57308 Mdot
.37072 .32298 Mdot
.60575 .37307 Mdot
.25065 .3581 Mdot
.53209 .58951 Mdot
.52796 .73293 Mdot
.34815 .62688 Mdot
.5617 .69473 Mdot
.63275 .62316 Mdot
.28467 .58289 Mdot
.51162 .79038 Mdot
.6904 .28627 Mdot
.48029 .75354 Mdot
.46485 .60015 Mdot
.61122 .44908 Mdot
.56903 .56236 Mdot
.44323 .31843 Mdot
.36871 .59133 Mdot
.69579 .60172 Mdot
.72017 .63926 Mdot
.31262 .6394 Mdot
.67833 .60082 Mdot
.50445 .31599 Mdot
.42122 .64431 Mdot
.32583 .66486 Mdot
.5734 .46381 Mdot
.59334 .49973 Mdot
.35092 .60833 Mdot
.6339 .23051 Mdot
.54195 .44485 Mdot
.41693 .28678 Mdot
.6825 .59813 Mdot
.32186 .62941 Mdot
.30671 .46021 Mdot
.35058 .51707 Mdot
.80877 .61689 Mdot
.71657 .29485 Mdot
.77093 .61087 Mdot
.55274 .43926 Mdot
.49379 .75066 Mdot
.53148 .36421 Mdot
.55724 .6367 Mdot
.78762 .60097 Mdot
.27884 .67523 Mdot
.64944 .21823 Mdot
.52175 .52467 Mdot
.72742 .28369 Mdot
.31392 .65303 Mdot
.57695 .47863 Mdot
.3783 .62536 Mdot
.59388 .54743 Mdot
.52552 .28821 Mdot
.7087 .27354 Mdot
.41434 .65249 Mdot
.65993 .44078 Mdot
.46501 .7787 Mdot
.28737 .66339 Mdot
.70972 .63533 Mdot
.65616 .45773 Mdot
.40028 .47072 Mdot
.70727 .25892 Mdot
.47768 .59169 Mdot
.65914 .26944 Mdot
.68903 .58365 Mdot
.5274 .79682 Mdot
.68304 .62316 Mdot
.46722 .71969 Mdot
.67174 .31084 Mdot
.30491 .59701 Mdot
.82064 .60527 Mdot
.43288 .62743 Mdot
.50137 .63442 Mdot
.69958 .2539 Mdot
.79696 .63034 Mdot
.58348 .53545 Mdot
.58384 .47914 Mdot
.56048 .68926 Mdot
.53856 .61276 Mdot
.43335 .73729 Mdot
.65033 .50932 Mdot
.3157 .70348 Mdot
.66469 .30787 Mdot
.78389 .63354 Mdot
.63593 .19808 Mdot
.41979 .29728 Mdot
.58289 .39742 Mdot
.28273 .62876 Mdot
.45519 .52945 Mdot
.43997 .7426 Mdot
.73272 .28681 Mdot
.31369 .38978 Mdot
.29375 .68483 Mdot
.75121 .60864 Mdot
.41796 .44964 Mdot
.37411 .68195 Mdot
.51243 .77641 Mdot
.60012 .57152 Mdot
.3019 .65941 Mdot
.73468 .3176 Mdot
.55296 .31856 Mdot
.36835 .47118 Mdot
.69299 .63081 Mdot
.43945 .29753 Mdot
.38996 .50015 Mdot
.83131 .53341 Mdot
.39158 .66921 Mdot
.39156 .47036 Mdot
.27705 .63358 Mdot
.78675 .59823 Mdot
.75838 .61627 Mdot
.33666 .68309 Mdot
.66589 .52352 Mdot
.66556 .27365 Mdot
.40333 .51973 Mdot
.57714 .5488 Mdot
.29079 .39452 Mdot
.3154 .39749 Mdot
.70705 .59714 Mdot
.51979 .44786 Mdot
.65527 .37465 Mdot
.51031 .7719 Mdot
.34167 .50011 Mdot
.61708 .37946 Mdot
.35524 .48926 Mdot
.26412 .65853 Mdot
.44995 .48644 Mdot
.55151 .70465 Mdot
.44731 .47844 Mdot
.68506 .25031 Mdot
.62295 .61938 Mdot
.78904 .60593 Mdot
.48616 .75603 Mdot
.70818 .64067 Mdot
.47842 .63704 Mdot
.47929 .63764 Mdot
.66031 .33086 Mdot
.48547 .78974 Mdot
.58546 .5066 Mdot
.37266 .59071 Mdot
.46102 .62517 Mdot
.34027 .48253 Mdot
.52035 .39528 Mdot
.39041 .55396 Mdot
.69224 .39225 Mdot
.44164 .46785 Mdot
.29732 .65916 Mdot
.65641 .52996 Mdot
.51271 .41672 Mdot
.38043 .28759 Mdot
.6246 .50427 Mdot
.54656 .34393 Mdot
.53684 .2797 Mdot
.54867 .53451 Mdot
.79806 .61392 Mdot
.39765 .53174 Mdot
.55025 .34548 Mdot
.44585 .74812 Mdot
.23976 .37464 Mdot
.72974 .28269 Mdot
.69834 .31934 Mdot
.34595 .66975 Mdot
.33211 .69052 Mdot
.53823 .82225 Mdot
.42971 .71319 Mdot
.84136 .52582 Mdot
.48677 .75605 Mdot
.23058 .40492 Mdot
.61885 .60965 Mdot
.57075 .49672 Mdot
.37035 .62456 Mdot
.37507 .29459 Mdot
.69206 .26683 Mdot
.55528 .55019 Mdot
.67508 .35975 Mdot
.37137 .64537 Mdot
.37428 .49353 Mdot
.66506 .25283 Mdot
.64515 .22913 Mdot
.64357 .23662 Mdot
.50703 .79214 Mdot
.49611 .4501 Mdot
.6876 .2426 Mdot
.5522 .39194 Mdot
.52596 .48421 Mdot
.27417 .34738 Mdot
.40318 .28083 Mdot
.83699 .56032 Mdot
.57321 .41911 Mdot
.5442 .61178 Mdot
.31085 .63918 Mdot
.71206 .25537 Mdot
.55397 .28687 Mdot
.58147 .56732 Mdot
.63921 .33529 Mdot
.64628 .40886 Mdot
.61825 .37054 Mdot
.65802 .33891 Mdot
.50206 .58866 Mdot
.51118 .77566 Mdot
.72376 .25665 Mdot
.77136 .59408 Mdot
.46071 .75096 Mdot
.27086 .65397 Mdot
.83371 .57491 Mdot
.36202 .68523 Mdot
.46913 .72649 Mdot
.33211 .65203 Mdot
.27112 .40778 Mdot
.41489 .57179 Mdot
.53995 .59135 Mdot
.37883 .4295 Mdot
.6254 .39248 Mdot
.61876 .59478 Mdot
.80854 .57339 Mdot
.409 .55845 Mdot
.51912 .48251 Mdot
.55862 .34291 Mdot
.78121 .64862 Mdot
.52512 .56169 Mdot
.48167 .43081 Mdot
.3975 .52898 Mdot
.38381 .65938 Mdot
.38004 .677 Mdot
.318 .44259 Mdot
.4507 .40253 Mdot
.69634 .28229 Mdot
.85265 .51958 Mdot
.66887 .32915 Mdot
.36594 .67332 Mdot
.54156 .79665 Mdot
.53429 .73646 Mdot
.54921 .37615 Mdot
.38313 .26491 Mdot
.48513 .5654 Mdot
.36253 .26329 Mdot
.45671 .68815 Mdot
.30676 .46071 Mdot
.45724 .64092 Mdot
.55094 .38873 Mdot
.39525 .60273 Mdot
.48356 .62999 Mdot
.47986 .44165 Mdot
.2794 .64104 Mdot
.27102 .69076 Mdot
.78695 .59433 Mdot
.62238 .61425 Mdot
.66917 .51378 Mdot
.52319 .46173 Mdot
.72434 .34218 Mdot
.65696 .48576 Mdot
.57727 .54135 Mdot
.32779 .47314 Mdot
.54951 .79908 Mdot
.64518 .36689 Mdot
.83314 .58619 Mdot
.65951 .33894 Mdot
.76727 .61575 Mdot
.67003 .58698 Mdot
.53731 .32064 Mdot
.46297 .73605 Mdot
.50833 .75217 Mdot
.52437 .30742 Mdot
.77173 .63531 Mdot
.58112 .55908 Mdot
.37114 .58516 Mdot
.45918 .38165 Mdot
.5452 .29098 Mdot
.60234 .37505 Mdot
.53534 .33635 Mdot
.34042 .44646 Mdot
.29849 .62212 Mdot
.5669 .3995 Mdot
.57216 .59343 Mdot
.31914 .35974 Mdot
.32498 .69113 Mdot
.46507 .71347 Mdot
.27131 .64849 Mdot
.78259 .65098 Mdot
.54501 .81284 Mdot
.50103 .62228 Mdot
.53389 .39264 Mdot
.65922 .30541 Mdot
.53995 .39079 Mdot
.33151 .69446 Mdot
.28319 .41143 Mdot
.46555 .64436 Mdot
.31139 .6437 Mdot
.53782 .50929 Mdot
.55655 .65279 Mdot
.39541 .63886 Mdot
.28006 .64775 Mdot
.32523 .39206 Mdot
.6995 .30225 Mdot
.37552 .41646 Mdot
.51951 .59481 Mdot
.42978 .29447 Mdot
.43931 .53483 Mdot
.44124 .62626 Mdot
.57041 .3465 Mdot
.489 .6083 Mdot
.63553 .23981 Mdot
.31147 .4725 Mdot
.55964 .61269 Mdot
.55945 .41909 Mdot
.54968 .38832 Mdot
.29777 .44507 Mdot
.28973 .66575 Mdot
.50919 .77141 Mdot
.3814 .40541 Mdot
.72115 .30021 Mdot
.50933 .51507 Mdot
.55311 .34167 Mdot
.41042 .5036 Mdot
.38258 .41928 Mdot
.6421 .50884 Mdot
.65743 .33695 Mdot
.56765 .57523 Mdot
.61076 .18102 Mdot
.76031 .63831 Mdot
.37929 .52397 Mdot
.37461 .62821 Mdot
.79553 .59452 Mdot
.40635 .62545 Mdot
.43423 .60455 Mdot
.41164 .53813 Mdot
.8231 .57944 Mdot
.55425 .5695 Mdot
.57309 .58257 Mdot
.2767 .69603 Mdot
.67171 .23922 Mdot
.52925 .60702 Mdot
.47773 .73078 Mdot
.58248 .40839 Mdot
.42401 .35573 Mdot
.37142 .51036 Mdot
.31272 .72085 Mdot
.45337 .50108 Mdot
.51939 .61724 Mdot
.85456 .53757 Mdot
.56126 .54738 Mdot
.39932 .54073 Mdot
.61481 .18047 Mdot
.61479 .1732 Mdot
.36635 .51348 Mdot
.73704 .28927 Mdot
.57697 .57909 Mdot
.34256 .69214 Mdot
.52368 .738 Mdot
.52231 .37927 Mdot
.33094 .48897 Mdot
.71436 .30725 Mdot
.52156 .82101 Mdot
.44757 .75188 Mdot
.35278 .64285 Mdot
.73398 .30571 Mdot
.51809 .49187 Mdot
.58198 .51002 Mdot
.53328 .79011 Mdot
.75538 .66353 Mdot
.80659 .6118 Mdot
.32166 .436 Mdot
.71608 .61779 Mdot
.72186 .59465 Mdot
.41312 .65851 Mdot
.83815 .57396 Mdot
.65098 .41818 Mdot
.24011 .36962 Mdot
.78621 .60019 Mdot
.29083 .70168 Mdot
.7147 .63597 Mdot
.44357 .62254 Mdot
.57033 .5439 Mdot
.46787 .48242 Mdot
.32476 .7021 Mdot
.5048 .78523 Mdot
.55022 .50384 Mdot
.50138 .29806 Mdot
.27828 .66014 Mdot
.28165 .68085 Mdot
.25841 .38893 Mdot
.57626 .52816 Mdot
.62287 .21617 Mdot
.54462 .70592 Mdot
.51904 .32619 Mdot
.36985 .58877 Mdot
.58769 .34432 Mdot
.58301 .50548 Mdot
.47602 .3424 Mdot
.6958 .30203 Mdot
.58884 .51238 Mdot
.63332 .22025 Mdot
.82115 .61208 Mdot
.63539 .32798 Mdot
.56008 .64468 Mdot
.65931 .48356 Mdot
.83579 .55634 Mdot
.8382 .53971 Mdot
.63098 .20916 Mdot
.74121 .59883 Mdot
.52058 .30431 Mdot
.55647 .51682 Mdot
.52018 .38768 Mdot
.49771 .43542 Mdot
.79662 .59008 Mdot
.29424 .44575 Mdot
.61275 .36908 Mdot
.37736 .65281 Mdot
.77618 .64036 Mdot
.54931 .4113 Mdot
.58387 .34965 Mdot
.43794 .50646 Mdot
.59095 .5015 Mdot
.67978 .64153 Mdot
.67856 .22189 Mdot
.33533 .6851 Mdot
.62796 .37079 Mdot
.30083 .68603 Mdot
.26757 .63486 Mdot
.74332 .62136 Mdot
.34906 .66014 Mdot
.73022 .38878 Mdot
.67297 .57979 Mdot
.69974 .32415 Mdot
.58812 .55128 Mdot
.27508 .70681 Mdot
.42682 .45205 Mdot
.66995 .32269 Mdot
.61896 .381 Mdot
.62338 .19906 Mdot
.56997 .4013 Mdot
.43675 .46955 Mdot
.62852 .22801 Mdot
.37328 .66003 Mdot
.53066 .33723 Mdot
.66724 .24867 Mdot
.3865 .58603 Mdot
.71475 .29413 Mdot
.5049 .69024 Mdot
.5648 .46493 Mdot
.30344 .71427 Mdot
.53923 .35581 Mdot
.5364 .35384 Mdot
.64781 .37161 Mdot
.45992 .77432 Mdot
.40063 .56423 Mdot
.40371 .52262 Mdot
.70901 .63867 Mdot
.52289 .37623 Mdot
.50257 .59617 Mdot
.63922 .19811 Mdot
.46086 .37884 Mdot
.76035 .58027 Mdot
.79281 .60969 Mdot
.4657 .7363 Mdot
.56891 .53227 Mdot
.29329 .71019 Mdot
.32251 .42805 Mdot
.5599 .31023 Mdot
.67478 .24277 Mdot
.56824 .53088 Mdot
.37558 .27797 Mdot
.31841 .40852 Mdot
.55901 .67822 Mdot
.47993 .77456 Mdot
.47443 .59993 Mdot
.55305 .45626 Mdot
.43518 .30531 Mdot
.76765 .6089 Mdot
.85285 .54528 Mdot
.62275 .21407 Mdot
.48511 .7747 Mdot
.53974 .34893 Mdot
.39898 .493 Mdot
.61102 .40615 Mdot
.63572 .19373 Mdot
.74452 .66744 Mdot
.29602 .65872 Mdot
.7749 .63231 Mdot
.47039 .77832 Mdot
.57541 .49863 Mdot
.53191 .32508 Mdot
.63541 .2336 Mdot
.36057 .63038 Mdot
.53211 .52396 Mdot
.42107 .49612 Mdot
.45519 .2828 Mdot
.43082 .64641 Mdot
.27349 .41243 Mdot
.48108 .7943 Mdot
.6218 .19945 Mdot
.72092 .60319 Mdot
.37344 .44143 Mdot
.61809 .19066 Mdot
.30449 .62423 Mdot
.4293 .64983 Mdot
.5239 .79586 Mdot
.55039 .35116 Mdot
.68374 .62068 Mdot
.45348 .39112 Mdot
.50882 .29683 Mdot
.40534 .63318 Mdot
.57255 .40697 Mdot
.66835 .38767 Mdot
.27749 .65254 Mdot
.7341 .60675 Mdot
.27382 .64372 Mdot
.85082 .53841 Mdot
.50011 .58545 Mdot
.32436 .6616 Mdot
.29676 .41096 Mdot
.66516 .58231 Mdot
.38079 .65809 Mdot
.6487 .32678 Mdot
.40459 .28313 Mdot
.3316 .65686 Mdot
.32051 .65732 Mdot
.39021 .58173 Mdot
.44517 .71954 Mdot
.67069 .29539 Mdot
.79569 .62604 Mdot
.67491 .51758 Mdot
.38466 .56764 Mdot
.53118 .37045 Mdot
.57501 .54552 Mdot
.62993 .35614 Mdot
.61431 .60986 Mdot
.73753 .27793 Mdot
.24476 .39471 Mdot
.40251 .66515 Mdot
.49455 .55734 Mdot
.39138 .2653 Mdot
.53111 .35893 Mdot
.66786 .58864 Mdot
.58097 .53694 Mdot
.38414 .52167 Mdot
.27685 .6095 Mdot
.43903 .6518 Mdot
.6843 .39172 Mdot
.66482 .52728 Mdot
.47144 .75617 Mdot
.31081 .44264 Mdot
.79964 .60227 Mdot
.25393 .60781 Mdot
.63283 .5206 Mdot
.63631 .55915 Mdot
.51256 .42825 Mdot
.39414 .28124 Mdot
.70107 .2352 Mdot
.64652 .31623 Mdot
.28357 .60212 Mdot
.39325 .66579 Mdot
.70214 .61053 Mdot
.64267 .36795 Mdot
.53766 .53989 Mdot
.79246 .58886 Mdot
.40993 .47091 Mdot
.64322 .35013 Mdot
.34916 .65595 Mdot
.46949 .58671 Mdot
.78226 .62014 Mdot
.65894 .39585 Mdot
.78114 .64077 Mdot
.33884 .43347 Mdot
.54653 .44359 Mdot
.75818 .65686 Mdot
.44243 .49789 Mdot
.58874 .56402 Mdot
.31834 .35831 Mdot
.48283 .56964 Mdot
.82467 .57437 Mdot
.27436 .60415 Mdot
.56763 .44829 Mdot
.33189 .6711 Mdot
.45021 .75474 Mdot
.66172 .31009 Mdot
.37924 .67065 Mdot
.79131 .628 Mdot
.52516 .38106 Mdot
.64918 .40291 Mdot
.3085 .45244 Mdot
.41065 .29035 Mdot
.61864 .44291 Mdot
.37586 .47512 Mdot
.65404 .43154 Mdot
.55963 .29479 Mdot
.49413 .43279 Mdot
.69983 .27123 Mdot
.53852 .2834 Mdot
.47183 .48237 Mdot
.58041 .48714 Mdot
.36493 .60429 Mdot
.72033 .27093 Mdot
.55445 .30866 Mdot
.31519 .70603 Mdot
.80569 .61031 Mdot
.73803 .59086 Mdot
.61647 .18873 Mdot
.4655 .77728 Mdot
.49718 .47074 Mdot
.84144 .57016 Mdot
.51565 .51328 Mdot
.72262 .59354 Mdot
.58797 .55118 Mdot
.26601 .61788 Mdot
.68977 .24999 Mdot
.58677 .50467 Mdot
.46122 .48693 Mdot
.44624 .42386 Mdot
.31451 .64513 Mdot
.53865 .29697 Mdot
.53549 .37771 Mdot
.634 .6284 Mdot
.38209 .2779 Mdot
.70621 .59855 Mdot
.38671 .56694 Mdot
.79568 .60196 Mdot
.79627 .58102 Mdot
.58647 .41313 Mdot
.5706 .65199 Mdot
.61321 .18995 Mdot
.46869 .46471 Mdot
.26602 .35074 Mdot
.27732 .64453 Mdot
.66952 .39187 Mdot
.75371 .59741 Mdot
.3818 .40979 Mdot
.37657 .31169 Mdot
.40357 .47085 Mdot
.70795 .30568 Mdot
.45118 .52025 Mdot
.54641 .7027 Mdot
.38737 .58302 Mdot
.31675 .70426 Mdot
.31562 .67596 Mdot
.46235 .78242 Mdot
.82412 .57242 Mdot
.50108 .62194 Mdot
.4663 .59572 Mdot
.46321 .47924 Mdot
.80717 .56865 Mdot
.46617 .76333 Mdot
.46174 .6983 Mdot
.3301 .4763 Mdot
.62119 .20853 Mdot
.26753 .65233 Mdot
.451 .6188 Mdot
.53263 .58057 Mdot
.54004 .39469 Mdot
.43278 .73616 Mdot
.40863 .65668 Mdot
.29099 .64615 Mdot
.6498 .25702 Mdot
.54519 .59992 Mdot
.6648 .45289 Mdot
.76242 .63023 Mdot
.51574 .58123 Mdot
.79877 .58293 Mdot
.34389 .50795 Mdot
.64623 .24236 Mdot
.55517 .34545 Mdot
.63624 .41183 Mdot
.44127 .41229 Mdot
.37996 .64398 Mdot
.6592 .33598 Mdot
.53543 .53919 Mdot
.54092 .62857 Mdot
.3055 .66946 Mdot
.81679 .60823 Mdot
.62089 .51047 Mdot
.54912 .79699 Mdot
.58359 .48696 Mdot
.38043 .2939 Mdot
.37622 .28658 Mdot
.45108 .71983 Mdot
.57685 .55064 Mdot
.41411 .6146 Mdot
.55131 .45483 Mdot
.32774 .46573 Mdot
.69259 .3266 Mdot
.67145 .21722 Mdot
.30865 .62905 Mdot
.80703 .62871 Mdot
.36589 .52496 Mdot
.30479 .63227 Mdot
.71939 .59869 Mdot
.55982 .63245 Mdot
.51685 .4533 Mdot
.57836 .40741 Mdot
.27094 .58167 Mdot
.66246 .20952 Mdot
.516 .61861 Mdot
.56764 .43819 Mdot
.70528 .62257 Mdot
.44358 .62988 Mdot
.56204 .70996 Mdot
.49862 .75645 Mdot
.82253 .59978 Mdot
.78781 .60083 Mdot
.55281 .72007 Mdot
.5755 .57859 Mdot
.53564 .62431 Mdot
.66316 .25347 Mdot
.58403 .49467 Mdot
.65837 .31782 Mdot
.49647 .79827 Mdot
.33346 .45641 Mdot
.53306 .28122 Mdot
.55352 .31735 Mdot
.41028 .28465 Mdot
.38282 .46451 Mdot
.65241 .27449 Mdot
.62679 .50049 Mdot
.67019 .5233 Mdot
.71303 .63163 Mdot
.64002 .19529 Mdot
.39731 .65178 Mdot
.60549 .46695 Mdot
.61011 .39609 Mdot
.54354 .59785 Mdot
.5162 .32378 Mdot
.40723 .53208 Mdot
.66127 .46889 Mdot
.55498 .69681 Mdot
.32474 .6802 Mdot
.71567 .3011 Mdot
.43503 .41653 Mdot
.35329 .26653 Mdot
.43577 .73169 Mdot
.66451 .59419 Mdot
.30609 .67344 Mdot
.69438 .23348 Mdot
.46277 .7022 Mdot
.53323 .78419 Mdot
.45356 .72724 Mdot
.63225 .36866 Mdot
.53553 .80814 Mdot
.44251 .71399 Mdot
.85283 .55055 Mdot
.40577 .66453 Mdot
.37559 .45006 Mdot
.28053 .68456 Mdot
.5576 .29289 Mdot
.36907 .47585 Mdot
.64906 .51146 Mdot
.69771 .29464 Mdot
.52987 .35298 Mdot
.56686 .45732 Mdot
.64861 .26745 Mdot
.77967 .62446 Mdot
.76297 .63765 Mdot
.43334 .7179 Mdot
.34089 .64755 Mdot
.55043 .8128 Mdot
.69685 .61373 Mdot
.25022 .41171 Mdot
.64361 .3149 Mdot
.38062 .43798 Mdot
.53382 .53443 Mdot
.40274 .51381 Mdot
.67755 .2557 Mdot
.81634 .57301 Mdot
.59078 .57082 Mdot
.62199 .56666 Mdot
.56339 .33159 Mdot
.60555 .40459 Mdot
.40455 .58276 Mdot
.63051 .33715 Mdot
.66257 .58249 Mdot
.58625 .5033 Mdot
.78869 .61875 Mdot
.37955 .6442 Mdot
.41664 .29775 Mdot
.62487 .208 Mdot
.39399 .29145 Mdot
.77697 .65422 Mdot
.50525 .79346 Mdot
.71147 .63276 Mdot
.64313 .19951 Mdot
.40059 .6184 Mdot
.45573 .44344 Mdot
.60956 .18255 Mdot
.72613 .28398 Mdot
.53836 .62426 Mdot
.40188 .43371 Mdot
.84986 .55854 Mdot
.6204 .56117 Mdot
.63631 .38021 Mdot
.30425 .4583 Mdot
.75145 .63467 Mdot
.50257 .41704 Mdot
.38465 .42431 Mdot
.56001 .44908 Mdot
.29492 .61693 Mdot
.33342 .65109 Mdot
.6796 .5744 Mdot
.77042 .6339 Mdot
.29641 .43682 Mdot
.3116 .47278 Mdot
.33476 .43372 Mdot
.28243 .58427 Mdot
.69023 .30116 Mdot
.74814 .33945 Mdot
.28053 .4344 Mdot
.65425 .25248 Mdot
.37866 .25103 Mdot
.41183 .63816 Mdot
.32247 .46872 Mdot
.54003 .32796 Mdot
.70313 .59372 Mdot
.62837 .18481 Mdot
.33679 .47293 Mdot
.73486 .27506 Mdot
.71998 .31276 Mdot
.28356 .59619 Mdot
.38086 .54056 Mdot
.53574 .37026 Mdot
.51544 .60787 Mdot
.55703 .69574 Mdot
.70647 .63753 Mdot
.73435 .59685 Mdot
.635 .54947 Mdot
.42078 .42072 Mdot
.394 .5094 Mdot
.66361 .3252 Mdot
.57495 .49677 Mdot
.66934 .31859 Mdot
.354 .45949 Mdot
.46101 .3726 Mdot
.6076 .17508 Mdot
.3387 .69357 Mdot
.52123 .40248 Mdot
.60268 .4916 Mdot
.60594 .4646 Mdot
.47653 .35183 Mdot
.45251 .68949 Mdot
.56279 .37303 Mdot
.73952 .63363 Mdot
.6921 .29498 Mdot
.37997 .55722 Mdot
.53455 .36469 Mdot
.53634 .73711 Mdot
.44795 .31585 Mdot
.49966 .4171 Mdot
.45862 .68124 Mdot
.72547 .62603 Mdot
.57262 .68071 Mdot
.44815 .74961 Mdot
.4305 .64249 Mdot
.49896 .29234 Mdot
.61099 .49061 Mdot
.72401 .61358 Mdot
.4525 .71924 Mdot
.43524 .73287 Mdot
.7898 .62999 Mdot
.40982 .46205 Mdot
.48059 .78103 Mdot
.68771 .57439 Mdot
.53117 .33457 Mdot
.3985 .50301 Mdot
.54324 .61568 Mdot
.2806 .41284 Mdot
.67247 .26698 Mdot
.66519 .49851 Mdot
.62345 .50149 Mdot
.28574 .40381 Mdot
.69357 .27043 Mdot
.46478 .69057 Mdot
.85074 .5136 Mdot
.56046 .62946 Mdot
.33391 .6696 Mdot
.3365 .38972 Mdot
.56268 .53401 Mdot
.31782 .38759 Mdot
.40319 .43618 Mdot
.37314 .33168 Mdot
.52903 .78227 Mdot
.57314 .53628 Mdot
.44116 .63566 Mdot
.48612 .61646 Mdot
.56104 .40554 Mdot
.31221 .38788 Mdot
.40557 .39738 Mdot
.63776 .50115 Mdot
.51676 .29044 Mdot
.64629 .50899 Mdot
.56385 .42037 Mdot
.51439 .77383 Mdot
.72597 .61755 Mdot
.76053 .63719 Mdot
.50279 .44996 Mdot
.6826 .25317 Mdot
.29596 .34721 Mdot
.64415 .31856 Mdot
.42726 .5269 Mdot
.50038 .78262 Mdot
.39099 .29233 Mdot
.62721 .18696 Mdot
.38252 .49769 Mdot
.70796 .39829 Mdot
.70294 .31832 Mdot
.64415 .33688 Mdot
.54643 .72715 Mdot
.27943 .70114 Mdot
.7148 .63401 Mdot
.54454 .38232 Mdot
.31393 .68119 Mdot
.67065 .5056 Mdot
.64975 .36156 Mdot
.54934 .47725 Mdot
.55503 .62988 Mdot
.27483 .41595 Mdot
.51254 .42494 Mdot
.67038 .65617 Mdot
.28345 .41182 Mdot
.38423 .46399 Mdot
.65192 .27601 Mdot
.26958 .35011 Mdot
.46818 .55297 Mdot
.38567 .49519 Mdot
.62492 .2022 Mdot
.67882 .6568 Mdot
.37536 .2761 Mdot
.23478 .38646 Mdot
.52588 .78545 Mdot
.72062 .58953 Mdot
.62155 .21255 Mdot
.50828 .75258 Mdot
.5519 .45349 Mdot
.32309 .72359 Mdot
.39389 .49466 Mdot
.28498 .63963 Mdot
.4627 .74989 Mdot
.60658 .41867 Mdot
.41197 .49477 Mdot
.62741 .17669 Mdot
.64626 .35118 Mdot
.50569 .45962 Mdot
.2502 .4138 Mdot
.79063 .6153 Mdot
.36655 .28438 Mdot
.48434 .78593 Mdot
.69232 .30356 Mdot
.55827 .71241 Mdot
.84431 .56713 Mdot
.51751 .58773 Mdot
.35609 .52683 Mdot
.60093 .40533 Mdot
.31495 .68489 Mdot
.56541 .51771 Mdot
.30624 .46807 Mdot
.32468 .69046 Mdot
.60588 .37293 Mdot
.54812 .56799 Mdot
.26545 .58648 Mdot
.36818 .52027 Mdot
.50175 .5626 Mdot
.56281 .63645 Mdot
.45265 .61799 Mdot
.47392 .59414 Mdot
.46045 .75947 Mdot
.48723 .55239 Mdot
.33828 .6957 Mdot
.48741 .74631 Mdot
.35247 .4488 Mdot
.69608 .58588 Mdot
.5674 .40618 Mdot
.61633 .59981 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`34ooooo`Co0000POoo
ool001cooooo00?o0000ooooooooool0a?ooool4o`00087ooooo000Looooo`03o`000?oooooooooo
0<;ooooo2?l0001oooooo`007?ooool00ol0003oooooooooo`32ooooo`Co000000Coooooo`000?l0
003o0000Ooooool001cooooo00?o0000ooooooooool0`oooool3o`0000;ooooo1?l0001mooooo`00
7?ooool00ol0003oooooooooo`32ooooo`Co00001?ooool3o`0007cooooo000Looooo`03o`000?oo
oooooooo0<;ooooo0_l000001?oooooo0000o`000?ooool6o`0007_ooooo000Looooo`03o`000?oo
oooooooo0<?ooooo1?l000000ooooooo0000o`000002ooooo`?o0000N_ooool00006ooooooo^k^ko
<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0<?ooooo
1?l00004ooooo`Go0000NOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0<_ooooo1Ol0001ioooo
o`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo00?o0000ooooooooool0a_ooool3o`0000;ooooo1?l000000ooooooo0000o`00001gooooo`00
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo
0ol00036ooooo`?o00000_ooool4o`000003ooooool0003o000007Oooooo00000ooooooo0000oooo
o`02ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`37ooooo`;o00002Oooool2o`0007Gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooo
oooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`36ooooo`Go00001oooool2
o`0007Gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RH
oa0@4006ooooo`03o`000?oooooooooo0<Kooooo1Ol00008ooooo`;o0000M?ooool00006ooooooo^
k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000oooo
ooooool0a_ooool3o`0000[ooooo0_l00002ooooo`;o0000L?ooool001cooooo00?o0000oooooooo
ool0a_ooool3o`0000Kooooo0_l00005ooooo`?o0000L?ooool001cooooo00?o0000ooooooooool0
aoooool2o`000003ooooool0003o000000?ooooo0_l00005ooooo`;o00000_ooool2o`0006gooooo
000Looooo`03o`000?oooooooooo0<[ooooo0_l0000=ooooo`Go0000Joooool001cooooo00?o0000
ooooooooool0fOooool2o`000003ooooool0003o000006_ooooo000Looooo`03o`000?oooooooooo
0<Sooooo1?l00002ooooo`;o0000NOooool001cooooo00?o0000ooooooooool0b?ooool5o`000003
ooooool0003o000000kooooo0_l0001Yooooo`007?ooool00ol0003oooooooooo`3;ooooo`Co0000
3oooool4o`0006Oooooo000Looooo`03o`000?oooooooooo0<_ooooo1?l00007ooooo`;o00001_oo
ool4o`0006Oooooo000Looooo`03o`000?oooooooooo0<_ooooo0_l000000ooooooo0000o`000006
ooooo`?o00000oooool4o`0006Wooooo000Looooo`03o`000?oooooooooo0<kooooo0_l00007oooo
o`;o00000oooool2o`0006_ooooo000Looooo`03o`000?oooooooooo0=Gooooo0_l0001booooo`00
7?ooool2o`0007Sooooo0_l00006ooooo`;o0000E?ooool2o`0000;ooooo1Ol0001[ooooo`007?oo
ool00ol0003oooooooooo`1gooooo`;o00001Oooool4o`0004oooooo0_l000000ooooooo0000o`00
0003ooooo`Go000000?oooooo`000?l000000_ooool2o`0006Cooooo000Looooo`03o`000?oooooo
oooo07gooooo2Ol00019ooooo`Co000000?oooooo`000?l000000_ooool4o`0000?ooooo0_l00002
ooooo`;o00000_ooool2o`00063ooooo000Looooo`03o`000?oooooooooo07gooooo0_l000000ooo
oooo0000o`000004o`000003ooooool0003o000004Kooooo0_l00007ooooo`;o00002?ooool2o`00
00?ooooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`1booooo`;o00002Oooool4o`000003
ooooool0003o000000Go0000FOooool2o`0006Gooooo000Looooo`03o`000?oooooooooo06oooooo
0_l000000ooooooo0000o`000005ooooo`Co00000_ooool2o`000003ooooool0003o000000Ko0000
AOooool2o`0000Kooooo0_l00004ooooo`;o00002?ooool2o`00063ooooo000Looooo`03o`000?oo
oooooooo06oooooo0_l00008ooooo`Co00001oooool8o`0004?ooooo0_l000000ooooooo0000o`00
0003ooooo`;o00001?ooool2o`0000Sooooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`1^
ooooo`;o00005_ooool7o`0004;ooooo0_l000000ooooooo0000o`000002o`0000Oooooo0_l00000
0ooooooo0000o`000002o`0000;ooooo0_l0001Qooooo`007?ooool00ol0003oooooooooo`1^oooo
o`;o00001_ooool2o`00013ooooo1_l0000Kooooo`?o00008oooool3o`0000;ooooo0_l0000:oooo
o`Co00000_ooool2o`0000?ooooo0_l0001Looooo`007?ooool00ol0003oooooooooo`1^ooooo`?o
00001Oooool4o`0000kooooo2?l0000=ooooo`;o00002?ooool6o`0002?ooooo0_l0000Iooooo`?o
0000Foooool001cooooo00?o0000ooooooooool0K_ooool3o`0000Gooooo1?l00002ooooo`;o0000
00Coooooo`000?l0003o00002?ooool8o`0000_ooooo1?l00004ooooo`So0000<Oooool2o`0000Wo
oooo0_l000000ooooooo0000o`00001Kooooo`007?ooool00ol0003oooooooooo`1cooooo`;o0000
1oooool2o`000003ooooool0003o000000?o00001_ooool8o`0000_ooooo1_l00002ooooo`;o0000
0_ooool4o`0002;ooooo0_l0000;ooooo`Co00002?ooool3o`0005kooooo000Looooo`03o`000?oo
oooooooo07?ooooo0_l000000ooooooo0000o`000002o`0000Sooooo1?l00006ooooo`Oo00002_oo
ool8o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0001gooooo0_l0000;ooooo`;o00002_oo
ool7o`0005[ooooo000Looooo`03o`000?oooooooooo07Kooooo1?l000001?oooooo0000o`000?l0
0004ooooo`Go00001Oooool7o`0000_ooooo2?l000000ooooooo0000o`000004ooooo`Go0000>?oo
ool5o`0005[ooooo000Looooo`03o`000?oooooooooo07Kooooo1?l000001?oooooo0000o`000?l0
0004ooooo`Go000000?oooooo`000?l000001?ooool5o`0000_ooooo0_l00004ooooo`;o00001ooo
ool7o`0002;ooooo0_l00005ooooo`Co00000oooool3o`0000Kooooo0_l0001Jooooo`007?ooool0
0ol0003oooooooooo`1fooooo`Co00001_ooool:o`000004ooooool0003o0000ooooo`Ko00002_oo
ool3o`000003ooooool0003o000000Oooooo0_l00002ooooo`Go00008_ooool2o`0000Gooooo1?l0
0003ooooo`?o00001_ooool2o`0005[ooooo000Looooo`;o0000Ooooool?o`0000;ooooo1_l00009
ooooo`?o000000?oooooo`000?l000001oooool2o`0000Cooooo1?l000000ooooooo0000o`00000T
ooooo`;o00001oooool3o`00067ooooo000Looooo`03o`000?oooooooooo07kooooo2?l00002oooo
o`Co00000oooool7o`0000Sooooo0_l00005ooooo`;o00002oooool3o`000003ooooool0003o0000
02Cooooo1Ol00004ooooo`?o0000HOooool001cooooo00?o0000ooooooooool0O?ooool5o`0000Oo
oooo1_l00002ooooo`Ko00002?ooool2o`0000Gooooo1?l0000:ooooo`Ko00006Oooool2o`0000Wo
oooo1?l000000ooooooo0000o`000002o`0000Gooooo0_l0001Looooo`007?ooool00ol0003ooooo
ooooo`1kooooo`Go00002Oooool5o`0000;ooooo1?l000000ooooooo0000o`000007ooooo`?o0000
1_ooool2o`0000Oooooo2Ol0000Iooooo`Ko00002_ooool4o`0000Gooooo0ol0001Kooooo`007?oo
ool00ol0003oooooooooo`1gooooo`;o00000_ooool2o`0000cooooo1Ol00002ooooo`So00001ooo
ool2o`0000oooooo1ol0000Looooo`Go00003_ooool2o`0000Cooooo0_l000000ooooooo0000o`00
001Hooooo`007?ooool00ol0003oooooooooo`1gooooo`;o000000Coooooo`000?l0003o00003Ooo
ool>o`0000Sooooo0_l0000Cooooo`Co00005?ooool3o`0001Gooooo0ol00004ooooo`;o000000?o
ooooo`000?l00000F?ooool001cooooo00?o0000ooooooooool0N?ooool4o`00013ooooo2ol00009
ooooo`;o00003_ooool2o`0000?ooooo1Ol0000Cooooo`?o00000_ooool2o`0000;ooooo0_l00007
ooooo`Co00000_ooool5o`000003ooooool0003o000000;o0000F_ooool001cooooo00?o0000oooo
ooooool0MOooool2o`000003ooooool0003o000000;o00004?ooool2o`000003ooooool0003o0000
00Oo00001oooool2o`0000[ooooo0_l00003ooooo`;o00001?ooool6o`00017ooooo0_l00003oooo
o`;o00000_ooool2o`0000Oooooo1?l00003ooooo`Co000000?oooooo`000?l000000_l0001Joooo
o`007?ooool00ol0003oooooooooo`1dooooo`Oo00005Oooool8o`0000Oooooo0_l00003ooooo`?o
00000_ooool4o`0000_ooooo1?l0000Dooooo`;o00000_ooool4o`0000Oooooo1?l00008ooooo`Co
0000F_ooool001cooooo00?o0000ooooooooool0M?ooool6o`0001Wooooo1Ol00008ooooo`;o0000
0_ooool3o`0000;ooooo0_l000000ooooooo0000o`000009ooooo`Go00003oooool2o`0000;ooooo
0ol00002ooooo`?o00001_ooool4o`0000[ooooo1?l0001Jooooo`007?ooool00ol0003ooooooooo
o`1eooooo`Co00005Oooool2o`0000;ooooo1_l00008ooooo`;o00002_ooool2o`0000Gooooo0_l0
0002ooooo`Ko00003_ooool2o`0000;ooooo0_l00002ooooo`Co00001_ooool4o`000003ooooool0
003o000000;ooooo0_l00002ooooo`Go0000F_ooool001cooooo00?o0000ooooooooool0MOooool4
o`0001Gooooo2_l0000Aooooo`;o00002?ooool2o`0000Cooooo1?l0000?ooooo`;o00001Oooool2
o`0000cooooo0ol000001?oooooo0000o`000?l00002ooooo`Go0000F_ooool001cooooo00?o0000
ooooooooool0Moooool2o`0001Gooooo2_l0000:ooooo`;o00001Oooool3o`0000gooooo0ol0000=
ooooo`;o000000Coooooo`000?l0003o00000oooool2o`0000Cooooo0ol000000ooooooo0000o`00
0009o`0000Cooooo0_l0001Looooo`007?ooool00ol0003oooooooooo`2:ooooo`ko00002_ooool3
o`0000Cooooo0ol00004ooooo`;o00001oooool3o`0000gooooo0_l00002ooooo`;o00000oooool2
o`0000Cooooo6Ol0001Hooooo`007?ooool00ol0003oooooooooo`1Looooo`;o0000:_oooolAo`00
00[ooooo0ol00008ooooo`Ko00001?ooool5o`0001Gooooo0_l00005oooooaSo0000F?ooool001co
oooo00?o0000ooooooooool0EOooool3o`0000Cooooo0_l0000Xoooooa?o00002oooool4o`0000Ko
oooo1_l00002ooooo`Co000000?oooooo`000?l000007?ooool7o`000003ooooool0003o000000So
00000_ooool2o`0005[ooooo000Looooo`;o0000Doooool<o`0002Oooooo5?l0000<ooooo`?o0000
1?ooool2o`000003ooooool0003o000000;o00000oooool6o`00017ooooo0_l00009oooooa;o0000
0oooool2o`0005[ooooo000Looooo`03o`000?oooooooooo05;ooooo3ol00002ooooo`;o00003_oo
ool2o`00013ooooo5?l0000?ooooo`Ko000000?oooooo`000?l000001oooool4o`00017ooooo0ol0
0008oooooa;o0000Goooool001cooooo00?o0000ooooooooool0EOooool<o`0000;ooooo0_l00000
0ooooooo0000o`00000;ooooo`;o00003_ooool@o`0000;ooooo1?l0000?ooooo`Go00000_ooool2
o`0000Oooooo1?l0000=ooooo`;o00000oooool2o`0000Sooooo3_l000001?oooooo0000o`000?l0
0002ooooo`;o0000Foooool001cooooo00?o0000ooooooooool0C_ooool2o`0000?ooooo5Ol0000:
ooooo`;o00003_oooolFo`00017ooooo1?l0000:ooooo`Go00003Oooool2o`0000cooooo4ol00002
ooooo`Co0000FOooool001cooooo00?o0000ooooooooool0C_ooool2o`0000?ooooo4ol00002oooo
o`;o00002?ooool2o`0000kooooo5ol0000=ooooo`;o000000?oooooo`000?l000003?ooool2o`00
01Kooooo0_l00003oooooaKo00000_ooool4o`0005Wooooo000Looooo`03o`000?oooooooooo04_o
oooo0_l000000ooooooo0000o`000002oooooaGo000000?oooooo`000?l000005_oooolIo`0000go
oooo0_l000001?oooooo0000o`000?l00009ooooo`Co00005_ooool2o`0000?ooooo5_l00002oooo
o`Co0000FOooool001cooooo00?o0000ooooooooool0Boooool2o`0000;ooooo6Ol0000HoooooaOo
00003oooool2o`000004ooooool0003o0000o`0000Wooooo1?l0000:ooooo`;o00001Oooool2o`00
0004ooooool0003o0000o`0000Cooooo0_l000000ooooooo0000o`00000Ao`0000?ooooo0_l0001J
ooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o00000oooool4o`0000;ooooo5?l0000Foooo
oaWo00003_ooool2o`000004ooooool0003o0000o`0000Sooooo0ol0000<ooooo`Co000000?ooooo
o`000?l000000_l000000ooooooo0000o`000002o`0000?ooooo0_l000000ooooooo0000o`000002
o`000003ooooool0003o000000co00000oooool2o`0005[ooooo000Looooo`03o`000?oooooooooo
04Wooooo0ol00007oooooaKo00005_oooolIo`00017ooooo0ol00007ooooo`Co00002Oooool3o`00
00;ooooo0_l000000ooooooo0000o`000005ooooo`Co00001?ooool3o`000003ooooool0003o0000
00co00001?ooool2o`0005[ooooo000Looooo`03o`000?oooooooooo04Sooooo1?l00007oooooaCo
00006?oooolHo`0000oooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo1?l00009ooooo`?o
00003_ooool2o`0000?ooooo4_l000001?oooooo0000o`000?l0001Mooooo`007?ooool00ol0003o
ooooooooo`18ooooo`;o00002_ooool2o`000003ooooool0003o000000ko00001oooool2o`0000oo
oooo6?l0000?ooooo`?o000000?oooooo`000?l000000oooool2o`000003ooooool0003o000000;o
00003oooool2o`0000Cooooo0_l00009oooooa;o000000Coooooo`000?l0003o0000GOooool001co
oooo00?o0000ooooooooool0B?ooool2o`0000oooooo3ol00002ooooo`;o000000Coooooo`000?l0
003o00003Oooool2o`000003ooooool0003o000001Go00003_ooool4o`0000Cooooo0_l00003oooo
o`Co00003oooool2o`0000Cooooo0_l0000:oooooa3o0000H_ooool001cooooo00?o0000oooooooo
ool0BOooool2o`0000kooooo3ol000001Ooooooo0000o`000?l0003ooooo00;o00003_ooool2o`00
0003ooooool0003o000001Go00003_ooool2o`0000Kooooo0_l00002ooooo`?o00007ooooolDo`00
0003ooooool0003o000005oooooo000Looooo`03o`000?oooooooooo04Wooooo0_l00005ooooo`;o
00002Oooool;o`0000?ooooo0ol0000Aoooooa[o00003_ooool2o`0000Gooooo0_l000000ooooooo
0000o`000003o`0001oooooo4Ol00004ooooo`?o0000G_ooool00006ooooooo^k^ko<S8bo`000?lb
<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo
04Oooooo0_l00007ooooo`;o00002Oooool9o`000004ooooool0003o0000o`0000;ooooo0_l0000A
oooooaWo00005?ooool4o`000004ooooool0003o0000o`0001Gooooo0_l0000=ooooo`ko00001Ooo
ool2o`0005kooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0A_ooool3o`0000?ooooo0_l0000=ooooo`Ko0000
1?ooool3o`0000;ooooo0_l0000AoooooaWo00003oooool2o`0000?ooooo1?l000001?oooooo0000
o`000?l0000@ooooo`;o00000oooool2o`0000Wooooo0_l00002oooooa7o0000H_ooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo00?o0000ooooooooool0
A_ooool2o`0000Cooooo0_l0000=ooooo`Ko00000_ooool2o`0000;ooooo0_l0000CoooooaCo0000
00?oooooo`000?l000000ol0000?ooooo`;o00001Oooool3o`0000Gooooo0_l00004ooooo`;o0000
1_ooool2o`0000kooooo0_l00002oooooa7o0000H_ooool00003ooooool0003ooooo00;ooooo00?o
0000ooooooooool02Oooool01?m4A4CogMgMooooool00007ooooo`?o0000B?ooool2o`0001Wooooo
0_l000001?oooooo0000o`000?l0000?ooooo`;o00000_oooolHo`0001;ooooo0_l00004ooooo`?o
00001Oooool3o`0000?ooooo0_l0000Cooooo`;o00001Oooool7o`0000?ooooo1_l0001Sooooo`00
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oo
oooo00?o0000ooooooooool0Aoooool4o`0000kooooo0_l0000;ooooo`?o00003oooool2o`0000;o
oooo5Ol000000ooooooo0000o`00000Booooo`;o00001?ooool2o`0000Cooooo0_l000000ooooooo
0000o`000008ooooo`Ko00002_ooool2o`0000?ooooo0_l000000ooooooo0000o`000005o`0000Ko
oooo0_l0001Sooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03ogMg
Moo<c<co000000Oooooo00?o0000ooooooooool0Aoooool5o`0000Sooooo0_l00003ooooo`;o0000
2Oooool6o`0000kooooo0_l00002oooooaCo000000?oooooo`000?l000000_l0000Dooooo`;o0000
1oooool2o`000003ooooool0003o000000Co00001?ooool6o`0000Wooooo0_l00003ooooo`?o0000
00?oooooo`000?l000002?l0001Xooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<ooooo`03
onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0B_ooool3o`000003ooooool0003o000000Co
oooo0ol000000ooooooo0000o`000003ooooo`;o00001Oooool7o`0000gooooo0_l00004oooooaOo
00005?ooool3o`0000?ooooo0_l00005ooooo`Go00002Oooool2o`0000Gooooo0_l000000ooooooo
0000o`000003ooooo`;o00000oooool9o`0006Sooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^
kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`1;ooooo`Go00001Oooool5o`00
00?ooooo0_l00008ooooo`Ko00002oooool2o`0000Cooooo4Ol000000ooooooo0000o`000002o`00
01Kooooo0_l00003ooooo`;o00002_ooool2o`0000Oooooo0_l00005ooooo`;o00003oooool4o`00
06Wooooo000Looooo`03o`000?oooooooooo04cooooo1?l00006ooooo`?o00004_ooool3o`0000So
oooo0_l00004oooooa3o000000Coooooo`000?l0003ooooo0ol0000<ooooo`;o00000_ooool2o`00
00;ooooo0_l0000Booooo`;o00001?ooool2o`0000Gooooo1?l00004ooooo`;o0000Moooool001co
oooo00?o0000ooooooooool0COooool4o`0000Gooooo0_l0000Dooooo`?o00001oooool2o`000004
ooooool0003o0000oooooaOo00003?ooool2o`0000;ooooo0_l00002ooooo`;o00002Oooool3o`00
0003ooooool0003o000000Wooooo0_l00005ooooo`Ko00000_ooool2o`0007Oooooo000Looooo`03
o`000?oooooooooo04oooooo1?l0000Jooooo`?o00002Oooool2o`0000;ooooo5_l0000@ooooo`?o
00003?ooool3o`000003ooooool0003o0000013ooooo2?l0001iooooo`007?ooool00ol0003ooooo
ooooo`1@ooooo`Co00006Oooool4o`0000Sooooo0_l00002ooooo`oo000000?oooooo`000?l00000
1?l0000@ooooo`?o00008_ooool9o`0007Sooooo000Looooo`03o`000?oooooooooo05;ooooo1?l0
000?ooooo`;o00001oooool3o`0000Kooooo0_l00006ooooo`go00000oooool5o`0000Gooooo0_l0
0008ooooo`?o00007_ooool2o`0000?ooooo2Ol0001gooooo`007?ooool00ol0003oooooooooo`1D
ooooo`Co00003Oooool2o`0000;ooooo0ol00003ooooo`;o00001_ooool2o`0000Kooooo2_l00004
ooooo`;o000000?oooooo`000?l000000_l00005ooooo`;o00000_ooool2o`0000Cooooo0_l0000M
oooooa7o0000M_ooool001cooooo00?o0000ooooooooool0E_ooool3o`0000Cooooo0_l00006oooo
o`;o00000_ooool3o`0000?ooooo1?l0000<ooooo`Wo00001Oooool6o`0000;ooooo0_l00006oooo
o`Co00008?oooolBo`0007Kooooo000Looooo`03o`000?oooooooooo05Kooooo1?l00003ooooo`;o
00001_ooool2o`0000Wooooo0ol00005ooooo`;o00001Oooool8o`0000Kooooo1Ol00003ooooo`;o
00001_ooool4o`0000oooooo0_l00003ooooo`;o00002_oooolBo`0007Kooooo000Looooo`03o`00
0?oooooooooo05Kooooo1_l00005ooooo`;o000000?oooooo`000?l000002oooool3o`0000;ooooo
1?l00002ooooo`;o000000?oooooo`000?l000001Ol0000Booooo`;o00000_ooool5o`0000oooooo
0_l00003ooooo`;o00003_oooolAo`0007?ooooo000Looooo`03o`000?oooooooooo05Oooooo2?l0
0002ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Cooooo1ol00004ooooo`;o000000?o
ooooo`000?l000000_ooool4o`0000Wooooo0_l00006ooooo`Oo00003Oooool4o`0000oooooo0_l0
0002oooooa?o0000Loooool001cooooo00?o0000ooooooooool0F?ooool7o`0000cooooo0_l00002
ooooo`Oo00002oooool2o`000004ooooool0003o0000o`0000Wooooo0_l00006ooooo`Co00002Ooo
ool2o`0000Gooooo1?l00002ooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo5?l0
001fooooo`007?ooool2o`0005Wooooo2_l0000=ooooo`;o000000Goooooo`000?l0003o0000oooo
o`02o`0000Wooooo0_l000001?oooooo0000o`000?ooool2o`0000gooooo1Ol00002ooooo`;o0000
00?oooooo`000?l000000oooool2o`0000_ooooo0_l000000ooooooo0000o`000003ooooo`;o0000
1OoooolBo`0007Kooooo000Looooo`03o`000?oooooooooo05Sooooo0ol00002ooooo`Go00004Ooo
ool2o`000003ooooool0003o000000cooooo0_l000000ooooooo0000o`00000=ooooo`?o00001?oo
ool2o`000003ooooool0003o000000;ooooo0_l00009ooooo`?o00003ooooolBo`000003ooooool0
003o000007?ooooo000Looooo`03o`000?oooooooooo05Sooooo0_l00003ooooo`Go00001oooool2
o`0000Wooooo0_l0000>ooooo`Co00002?ooool2o`0001;ooooo0_l00009ooooo`?o00000_ooool2
o`0000Wooooo5?l000000ooooooo0000o`00001cooooo`007?ooool00ol0003oooooooooo`1Noooo
o`Co00001oooool2o`0000Cooooo0_l00003ooooo`;o00004?ooool2o`0000;ooooo1Ol000000ooo
oooo0000o`00000?ooooo`;o00000oooool2o`0000Sooooo0_l00002ooooo`?o00002?oooolEo`00
07Gooooo000Looooo`03o`000?oooooooooo063ooooo0ol0000<ooooo`;o00002?ooool2o`0000Ko
oooo0_l00007ooooo`Go00001Oooool2o`0000_ooooo0_l00003ooooo`;o00003?ooool4o`0000Oo
oooo3Ol000000ooooooo0000o`000005o`0007Gooooo000Looooo`03o`000?oooooooooo067ooooo
1?l00002ooooo`;o00004?ooool2o`0000Kooooo0_l00009ooooo`;o00001_ooool2o`0001kooooo
1?l00008oooooa?o0000M_ooool001cooooo00?o0000ooooooooool0H?ooool9o`0001;ooooo0_l0
00000ooooooo0000o`000003o`0000Oooooo1?l0000@ooooo`;o00006_ooool2o`0000;ooooo5ol0
001dooooo`007?ooool00ol0003oooooooooo`1Pooooo`?o000000?oooooo`000?l000000ol00000
0ooooooo0000o`000008ooooo`;o00001Oooool2o`000003ooooool0003o000000?o00001oooool2
o`0001;ooooo0_l0000Jooooo`;o00000_oooolGo`0007Cooooo000Looooo`03o`000?oooooooooo
067ooooo0_l000000ooooooo0000o`000006o`0000Sooooo1?l0000gooooo`;o00003OoooolCo`00
07Sooooo000Looooo`03o`000?oooooooooo06Oooooo0ol0000:ooooo`Co00005_ooool2o`0000?o
oooo0_l0000Jooooo`;o00001oooool4o`0000Cooooo4Ol0001hooooo`007?ooool00ol0003ooooo
ooooo`1Vooooo`Co000000?oooooo`000?l000008Oooool2o`0000?ooooo1Ol0000=ooooo`;o0000
4Oooool4o`0000Cooooo4Ol0001hooooo`007?ooool00ol0003oooooooooo`1Vooooo`Oo00008Ooo
ool2o`0000Cooooo1?l0000=ooooo`Co00005_ooool3o`000003ooooool0003o000000co000000?o
ooooo`000?l00000MOooool001cooooo00?o0000ooooooooool0IOooool7o`0000Cooooo0_l0000L
ooooo`;o00000_ooool2o`0001?ooooo0_l0000@ooooo`?o00000oooool2o`0000;ooooo3Ol00002
ooooo`;o0000MOooool001cooooo00?o0000ooooooooool0IOooool7o`0000Cooooo0_l0000Poooo
o`;o00004Oooool2o`0001;ooooo1Ol000000ooooooo0000o`00000?o`0007Wooooo000Looooo`03
o`000?oooooooooo06Sooooo0_l00002ooooo`;o00002?ooool2o`0000;ooooo1_l00002ooooo`;o
00008Oooool2o`0001?ooooo1?l00002ooooo`oo0000N_ooool001cooooo00?o0000ooooooooool0
Joooool3o`0000Oooooo0ol000000ooooooo0000o`000005o`0000;ooooo0_l000000ooooooo0000
o`000005ooooo`;o0000:?ooool3o`000003ooooool0003o000000Sooooo2_l00006ooooo`;o0000
Loooool001cooooo0_l0001/ooooo`?o00001oooool2o`0000;ooooo1?l00008ooooo`;o00001Ooo
ool2o`0000;ooooo0_l0000Tooooo`?o00000oooool3o`0000Gooooo2Ol000000ooooooo0000o`00
0004ooooo`;o0000Loooool001cooooo00?o0000ooooooooool0Joooool5o`0000_ooooo0_l00000
0ooooooo0000o`000002ooooo`;o00003?ooool2o`0001gooooo0_l0000:ooooo`Co00001Oooool9
o`000003ooooool0003o000007Wooooo000Looooo`03o`000?oooooooooo06cooooo1?l0000>oooo
o`;o00000_ooool2o`0000Oooooo0_l0000Rooooo`;o00002Oooool3o`0000Sooooo1?l0000:oooo
o`;o000000?oooooo`000?l00000LOooool001cooooo00?o0000ooooooooool0K?ooool4o`0000Go
oooo0_l00005ooooo`;o00003Oooool2o`0001kooooo0_l0000<ooooo`?o00002_ooool3o`0000Co
oooo1?l00002ooooo`;o000000?oooooo`000?l00000LOooool001cooooo00?o0000ooooooooool0
KOooool5o`000003ooooool0003o000000;o00001Oooool2o`000003ooooool0003o000002?ooooo
0_l00005ooooo`;o00003?ooool4o`0000Wooooo0ol00002ooooo`Ko00001Oooool2o`0003Wooooo
1?l0000dooooo`007?ooool00ol0003oooooooooo`1]ooooo`So00002_ooool2o`00027ooooo1?l0
000;ooooo`;o00002?ooool2o`0000[ooooo0_l000001?oooooo0000o`000?l00002ooooo`;o0000
1Oooool2o`0003Wooooo1?l0000dooooo`007?ooool00ol0003oooooooooo`1^ooooo`Go000000?o
ooooo`000?l000002Oooool2o`0000kooooo0_l0000Aooooo`;o00003Oooool2o`000003ooooool0
003o0000017ooooo0_l000000ooooooo0000o`000004ooooo`Co00000oooool3o`0003;ooooo0_l0
0003ooooo`;o0000=_ooool001cooooo00?o0000ooooooooool0LOooool5o`0000?ooooo0_l00004
ooooo`;o00003_ooool2o`0002?ooooo0_l0000Aooooo`;o000000?oooooo`000?l000000oooool5
o`0000;ooooo1?l0000booooo`;o00000oooool2o`0003Kooooo000Looooo`03o`000?oooooooooo
073ooooo1Ol00002ooooo`Co00001?ooool2o`0002Gooooo0_l000000ooooooo0000o`00000Ooooo
o`?o00000_ooool2o`0000Cooooo0ol0000eooooo`;o00001Oooool2o`0003?ooooo000Looooo`03
o`000?oooooooooo073ooooo1Ol00002ooooo`;o00001?ooool2o`0000Sooooo0_l00007ooooo`;o
00005?ooool2o`000003ooooool0003o000000cooooo0_l0000Booooo`;o00001oooool3o`0003Ko
oooo0_l00005ooooo`;o0000<oooool001cooooo00?o0000ooooooooool0L?ooool5o`0000Sooooo
0_l00002ooooo`;o00001?ooool2o`0000Oooooo0_l0000Sooooo`Co00005Oooool8o`0003Cooooo
0_l0000mooooo`007?ooool00ol0003oooooooooo`1booooo`?o00002?ooool2o`0000;ooooo0_l0
0008ooooo`;o00007Oooool2o`0000;ooooo0_l00003ooooo`Co00000oooool2o`0001;ooooo1_l0
000fooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0L_ooool4o`0000cooooo0_l00007
ooooo`;o00007Oooool2o`0000;ooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo0ol0
001>ooooo`;o00001Oooool3o`0003Gooooo000Looooo`03o`000?oooooooooo07?ooooo1?l00000
0ooooooo0000o`000004ooooo`;o00000_ooool2o`0002Kooooo0ol00009ooooo`Go0000DOooool2
o`0000?ooooo0ol0000eooooo`007?ooool00ol0003oooooooooo`1dooooo`?o000000?oooooo`00
0?l000001?ooool2o`0002[ooooo0ol00008ooooo`;o000000?oooooo`000?l00000D_ooool2o`00
03_ooooo000Looooo`03o`000?oooooooooo07Cooooo0ol0000looooo`Ko00001?ooool2o`0005;o
oooo0_l0000fooooo`007?ooool2o`0007Kooooo0ol0000iooooo`Co00000_ooool3o`000003oooo
ool0003o000000;o00002oooool2o`0004Cooooo1?l0000eooooo`007?ooool00ol0003ooooooooo
o`1dooooo`Co00000oooool2o`0001Oooooo0_l00005ooooo`;o00005?ooool2o`0000Gooooo0_l0
00000ooooooo0000o`00000=ooooo`;o0000A?ooool4o`0003Gooooo000Looooo`03o`000?oooooo
oooo07Cooooo0_l00002ooooo`;o000000?oooooo`000?l000005oooool2o`0000Gooooo1?l0000L
ooooo`;o0000Coooool2o`0000?ooooo0_l0000fooooo`007?ooool00ol0003oooooooooo`1Soooo
o`?o00004?ooool4o`0000Oooooo0_l0000Jooooo`;o00006_ooool2o`00013ooooo0_l0000ooooo
o`;o00000_ooool2o`0003Oooooo000Looooo`03o`000?oooooooooo05cooooo3Ol0000=ooooo`Co
00001oooool2o`0001cooooo0_l00006ooooo`;o00003?ooool2o`0000;ooooo0_l0000;ooooo`;o
00000oooool2o`0003Kooooo0_l00007ooooo`;o00000_ooool2o`0003Oooooo000Looooo`03o`00
0?oooooooooo05Wooooo4_l0000;ooooo`Co00001?ooool2o`0001[ooooo0_l00003ooooo`;o0000
1_ooool2o`0000cooooo0_l00004ooooo`;o00002Oooool2o`0003_ooooo0_l00014ooooo`007?oo
ool00ol0003oooooooooo`1IoooooaCo00002_ooool5o`0000;ooooo0_l0000Iooooo`?o00004_oo
ool4o`0000Oooooo1?l00007ooooo`Go0000>Oooool2o`0000[ooooo0ol0000hooooo`007?ooool0
0ol0003oooooooooo`1Fooooo`ko000000?oooooo`000?l000001ol00008ooooo`Ko00001oooool2
o`0001Cooooo0_l0000Cooooo`Co00000_ooool2o`0000?ooooo0_l000001?oooooo0000o`000?oo
ool2o`0000;ooooo1_l00002ooooo`;o0000=Oooool2o`0000Cooooo0_l00003ooooo`Co0000>?oo
ool001cooooo00?o0000ooooooooool0EOoooolIo`0000Sooooo1Ol00008ooooo`;o0000;oooool3
o`0000Gooooo0_l000000ooooooo0000o`000002ooooo`[o00002oooool3o`000003ooooool0003o
000001Wooooo0ol00009ooooo`Co000000Coooooo`000?l0003ooooo1Ol0000iooooo`007?ooool0
0ol0003oooooooooo`1Eooooo`;o00000ooooolEo`0000Wooooo0ol0000jooooo`Co00002_ooool<
o`0000Wooooo0ol000000ooooooo0000o`00000Iooooo`?o00002Oooool4o`000004ooooool0003o
0000ooooo`?o0000>oooool001cooooo00?o0000ooooooooool0E?ooool2o`0000;ooooo6?l00008
ooooo`Go00009oooool2o`0000?ooooo0_l0000<ooooo`?o00001oooool2o`000003ooooool0003o
000000_o00001_ooool2o`0000Oooooo0_l0000Aooooo`;o00000_ooool2o`0000Kooooo0_l00007
ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0E?oooolMo`0000Oooooo1Ol00003oooo
o`;o00008_ooool2o`0000?ooooo0_l0000;ooooo`Go000000?oooooo`000?l000000oooool3o`00
00;ooooo3?l000001Ooooooo0000o`000?l0003ooooo00;o00000oooool2o`0000;ooooo0_l0000A
ooooo`;o00002_ooool3o`0000Kooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`1Boooo
oaoo00001?ooool3o`0000;ooooo0_l00004ooooo`;o00004oooool2o`0000Sooooo0_l00003oooo
o`;o00004?ooool2o`000004ooooool0003o0000ooooo`;o00000ooooolGo`0000Cooooo1?l0000P
ooooo`;o00002Oooool2o`0003cooooo000Looooo`03o`000?oooooooooo05;ooooo7ol000000ooo
oooo0000o`000008o`0001Wooooo0_l00008ooooo`;o00000oooool2o`0000?ooooo0_l0000Foooo
oa?o000000Coooooo`000?l0003o00001_ooool2o`0000Kooooo0_l00004ooooo`;o00004?ooool3
o`0000[ooooo0_l0000looooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?oo
ool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0Doooool2o`000003oooo
ool0003o000001Wo000000?oooooo`000?l000001_l0000Looooo`?o00001_ooool2o`0000Sooooo
0_l000000ooooooo0000o`000008ooooo`;o00002_ooool=o`000003ooooool0003o000000Go0000
2_ooool2o`0000?ooooo0ol000000ooooooo0000o`000003o`0000Sooooo0_l00003ooooo`Go0000
B?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMgMooo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo053ooooo1Ol00003oooooa_o000000?oooooo`00
0?l000000ol0000?ooooo`;o00002_ooool5o`0000Kooooo0_l00004ooooo`;o00001Oooool2o`00
00Sooooo0_l0000:ooooo`;o000000?oooooo`000?l000000ol000000ooooooo0000o`000009o`00
00_ooooo0ol00003ooooo`;o000000?oooooo`000?l000000ol00002ooooo`;o00001?ooool2o`00
00?ooooo0_l000000ooooooo0000o`000018ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413o
ooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`1@oooo
o`Go00000ooooolKo`0000;ooooo1?l0000?ooooo`;o00002Oooool5o`0000Oooooo0_l00004oooo
o`;o00001_ooool2o`0001?ooooo5?l00004ooooo`;o00001_ooool2o`0000;ooooo0ol00002oooo
o`Co00000_ooool2o`0000Wooooo0_l000000ooooooo0000o`000006ooooo`;o0000@?ooool00003
ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q
00Kooooo0ol0001@ooooo`Go00000ooooolKo`0000;ooooo1?l00004ooooo`;o00005?ooool5o`00
01Gooooo0_l0000Eoooooa;o00000oooool3o`0000;ooooo0_l00002ooooo`;o00000_ooool2o`00
00Gooooo0_l0000=ooooo`;o000000Coooooo`000?l0003o00001Oooool4o`0003kooooo00000ooo
oooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006
ooooo`03o`000?oooooooooo04oooooo1?l00002ooooo`;o000000?oooooo`000?l000007_l00005
ooooo`;o00002_ooool2o`0003Sooooo1Ol000000ooooooo0000o`00000=o`000003ooooool0003o
000000?ooooo0_l00006ooooo`;o00005?ooool2o`000004ooooool0003o0000o`0000Gooooo1?l0
000nooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`03oeEEEOn7QhOo
oooo00Sooooo00?o0000ooooooooool0Coooool4o`0000;ooooo0ol00002ooooo`Oo000000?ooooo
o`000?l000004ol0000Booooo`;o00004?ooool2o`0000Oooooo0_l00002ooooo`;o00006Oooool4
o`000003ooooool0003o000000ko00004oooool2o`000003ooooool0003o000000;o00001?ooool2
o`0000Cooooo1?l00005ooooo`Go0000?oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2ooo
ool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo04oooooo1?l00003ooooo`Co000000?o
ooooo`000?l000006_l0000Tooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`;o000000?o
ooooo`000?l000000_l00003ooooo`;o00003oooool7o`000003ooooool0003o000000go00001_oo
ool2o`0000Wooooo0_l000000ooooooo0000o`000002o`0000Cooooo0ol00005ooooo`;o00000_oo
ool2o`000003ooooool0003o000000;o0000@?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^
3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo05Sooooo0_l000000ooooooo
0000o`00000Io`0000gooooo0_l0000Kooooo`;o00002Oooool4o`0000?ooooo0_l0000@oooooaSo
00000oooool3o`0000Gooooo0_l0000<ooooo`Co00001?ooool4o`000003ooooool0003o000000?o
oooo0_l00010ooooo`007?ooool00ol0003oooooooooo`1>ooooo`Oo00001ooooolGo`0000_ooooo
0_l00003ooooo`;o00002_ooool2o`0000Wooooo0_l00008ooooo`?o00001_ooool2o`0001Gooooo
6?l00003ooooo`;o00001?ooool5o`0000Wooooo1?l00005ooooo`Go00000_ooool2o`0004Cooooo
000Looooo`03o`000?oooooooooo04kooooo1ol00007oooooaKo00003?ooool2o`0000oooooo0_l0
0009ooooo`;o00000oooool2o`0000?ooooo0ol0000Nooooo`go000000?oooooo`000?l000001ol0
0009ooooo`;o000000?oooooo`000?l000001?ooool4o`000003ooooool0003o000000Gooooo1?l0
0005ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0C_ooool7o`0000Sooooo4_l00006
ooooo`;o00005Oooool2o`00017ooooo0_l00009ooooo`?o00006?oooolGo`0000Gooooo0_l0000;
ooooo`Co00001oooool3o`0004gooooo000Looooo`03o`000?oooooooooo053ooooo2?l00005oooo
oa;o00001_ooool4o`0000Oooooo0_l00007ooooo`;o000000?oooooo`000?l000001?ooool2o`00
00_ooooo0_l00009ooooo`?o00002Oooool2o`0000gooooo6?l00004ooooo`;o00001Oooool2o`00
00oooooo0_l00002ooooo`Co0000B?ooool001cooooo00?o0000ooooooooool0Doooool7o`0000Oo
oooo1ol00005ooooo`;o00000_ooool2o`0000?ooooo0ol00007ooooo`;o00001oooool2o`000003
ooooool0003o000000Cooooo0_l00005ooooo`;o00002oooool2o`0000Cooooo0_l00003ooooo`?o
00000_ooool2o`0000kooooo6Ol00009ooooo`;o00002_ooool2o`0000Oooooo1?l000000ooooooo
0000o`000015ooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o000000?oooooo`000?l00000
1Ol00005ooooo`Co00000_ooool2o`0000[ooooo0_l0000=ooooo`;o00002_ooool2o`0000_ooooo
0_l0000;ooooo`;o00001?ooool3o`0000;ooooo0ol0000Booooo`?o000000?oooooo`000?l00000
4ol00004ooooo`?o00001_ooool2o`0000Kooooo1_l000000ooooooo0000o`000004o`000003oooo
ool0003o000004Gooooo000Looooo`03o`000?oooooooooo04kooooo1?l000000ooooooo0000o`00
0003o`0000Oooooo0_l0000Oooooo`;o00002_ooool2o`0000[ooooo0_l00005ooooo`;o00002ooo
ool3o`0000;ooooo1?l0000AoooooaOo00001_ooool3o`0000Kooooo1_l000001?oooooo0000o`00
0?ooool4o`000003ooooool0003o000000?ooooo1?l00015ooooo`007?ooool00ol0003ooooooooo
o`1=ooooo`Go000000?oooooo`000?l000001?ooool2o`0000Kooooo0ol0000Iooooo`;o00000ooo
ool2o`0000Sooooo0_l0000:ooooo`;o00001Oooool4o`0000[ooooo0_l00002ooooo`Co00004_oo
oolDo`0000Oooooo1_l00006ooooo`Co000000Goooooo`000?l0003o0000ooooo`03o`0000Kooooo
0_l00017ooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o000000?oooooo`000?l000001Ooo
ool4o`0000Kooooo0ol0000;ooooo`;o00003?ooool2o`0000?ooooo0_l00002ooooo`Co00001ooo
ool2o`0000Gooooo0_l00003ooooo`;o00000_ooool2o`0002Cooooo1?l000000ooooooo0000o`00
000=o`0000Gooooo1Ol000000ooooooo0000o`00000:ooooo`Co00000_ooool4o`0000;ooooo0_l0
0019ooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00001_ooool4o`0000;ooooo0_l00004
ooooo`?o00002oooool2o`0000Cooooo0_l000000ooooooo0000o`00000;ooooo`Go00001oooool4
o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0001?ooooo0_l0000CoooooaCo00001Ooo
ool4o`0000kooooo0_l00006ooooo`;o000000Coooooo`000?l0003o0000BOooool001cooooo00?o
0000ooooooooool0COooool2o`000003ooooool0003o000000;ooooo1Ol00002ooooo`;o00001?oo
ool3o`0000Oooooo0_l00008ooooo`;o000000?oooooo`000?l000002oooool2o`000003ooooool0
003o000000Kooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000001Oooooo
0_l0000Foooooa3o00008?ooool5o`0004[ooooo000Looooo`;o0000C_ooool5o`000003ooooool0
003o000000Co00003oooool5o`0000[ooooo0_l00004ooooo`;o00001?ooool2o`0000?ooooo0_l0
00000ooooooo0000o`000003ooooo`;o00007oooool2o`0000?ooooo0_l0000Cooooo`ko00006?oo
ool2o`0000Oooooo1?l0001;ooooo`007?ooool00ol0003oooooooooo`1=ooooo`Go000000?ooooo
o`000?l000000ol0000:ooooo`;o00001?ooool3o`0000?ooooo0_l00007ooooo`;o00001?ooool2
o`0000Cooooo0_l00003ooooo`;o000000?oooooo`000?l000009?ooool2o`0000?ooooo0_l0000D
ooooo`Go000000?oooooo`000?l000001_l00009ooooo`;o00000oooool3o`0000Kooooo0_l00006
ooooo`Go0000Boooool001cooooo00?o0000ooooooooool0Coooool7o`0000Kooooo0_l00004oooo
o`Co00000_ooool2o`0000Cooooo0_l00008ooooo`;o00001Oooool5o`0004_ooooo3?l000000ooo
oooo0000o`00000>o`0000Cooooo1?l00005ooooo`;o0000C_ooool001cooooo00?o0000oooooooo
ool0D?ooool4o`0000?ooooo0_l00003ooooo`Co00001?ooool6o`0000Cooooo0_l00006ooooo`Go
00001?ooool5o`0003?ooooo0_l0000Gooooo`_o000000?oooooo`000?l000003_l00004ooooo`Co
00000oooool4o`0004kooooo000Looooo`03o`000?oooooooooo057ooooo0_l00004ooooo`;o0000
00Coooooo`000?l0003ooooo0ol00006ooooo`Co00001?ooool2o`0000Kooooo0_l000000ooooooo
0000o`000004ooooo`?o0000=Oooool2o`0001Wooooo4_l000000ooooooo0000o`000003o`0000Co
oooo0_l00002ooooo`;o00000oooool2o`00053ooooo000Looooo`03o`000?oooooooooo04kooooo
1Ol00007ooooo`;o00002_ooool2o`0001Cooooo0_l000001?oooooo0000o`000?l0000eooooo`;o
00007OoooolDo`0000Cooooo0_l00002ooooo`;o0000EOooool001cooooo00?o0000ooooooooool0
C_ooool6o`0000Kooooo0_l00004ooooo`;o00001_ooool3o`0000;ooooo0_l00008ooooo`;o0000
0_ooool3o`0003Wooooo0_l0000Nooooo`Co000000?oooooo`000?l000004ol000000ooooooo0000
o`00001Eooooo`007?ooool00ol0003oooooooooo`1>ooooo`Ko00003?ooool2o`0000Kooooo0ol0
0002ooooo`;o00001?ooool2o`0000;ooooo0_l00002ooooo`?o00005_ooool2o`0000?ooooo0_l0
000Fooooo`;o00000oooool3o`0002?ooooo6?l0001Eooooo`007?ooool00ol0003oooooooooo`1?
ooooo`Ko00000_ooool2o`0000Oooooo0_l000000ooooooo0000o`00000>ooooo`;o00000oooool2
o`000003ooooool0003o000001?ooooo3ol0000Booooo`;o00000oooool2o`0002[ooooo4_l0001E
ooooo`007?ooool00ol0003oooooooooo`1Aooooo`Co00000_ooool2o`0000Sooooo1?l000000ooo
oooo0000o`00000@ooooo`;o00005OoooolDo`0000kooooo0ol0000dooooo`Co000000?oooooo`00
0?l000000_l0001Hooooo`007?ooool00ol0003oooooooooo`1Booooo`Go000000?oooooo`000?l0
00001oooool3o`0000;ooooo0_l00002ooooo`;o00002_ooool2o`0001Gooooo5ol0000=ooooo`?o
00000_ooool2o`00097ooooo000Looooo`03o`000?oooooooooo05Gooooo1Ol00002ooooo`Co0000
0_ooool3o`0000Cooooo0ol00006ooooo`;o00000_ooool2o`0001Cooooo4_l000000ooooooo0000
o`000003o`0000_ooooo1?l00003ooooo`;o0000TOooool001cooooo00?o0000ooooooooool0DOoo
ool2o`0000Cooooo0_l00003ooooo`Co00000oooool2o`0000Cooooo0_l00007ooooo`;o00005ooo
oolJo`0000[ooooo1Ol000001?oooooo0000o`000?l0002Aooooo`007?ooool00ol0003ooooooooo
o`1Aooooo`;o000000?oooooo`000?l000004?ooool4o`0000;ooooo0_l00005ooooo`?o00005?oo
oolNo`0000Oooooo1Ol000000ooooooo0000o`00002Booooo`007?ooool00ol0003oooooooooo`1B
ooooo`Co00004?ooool8o`0000Gooooo0ol0000Cooooo`Ko00000ooooolFo`0000Wooooo1?l0002D
ooooo`007?ooool00ol0003oooooooooo`1Booooo`;o00000_ooool2o`00013ooooo1?l00005oooo
o`;o00005_ooool6o`0000?ooooo5Ol00008ooooo`Ko0000U?ooool001cooooo0_l0001Cooooo`?o
000000Coooooo`000?l0003o00000_ooool2o`0000Wooooo0_l00007ooooo`Co00005Oooool3o`00
0003ooooool0003o000000Cooooo5_l00007ooooo`Co0000U_ooool001cooooo00?o0000oooooooo
ool0Doooool6o`0000;ooooo0_l00006ooooo`;o000000?oooooo`000?l000001_ooool3o`0001Oo
oooo0ol00008oooooaGo00001_ooool3o`0009Sooooo000Looooo`03o`000?oooooooooo05?ooooo
1Ol0000;ooooo`;o00002Oooool3o`0001Oooooo0ol00008oooooaGo00001?ooool5o`0000?ooooo
0_l0002Cooooo`007?ooool00ol0003oooooooooo`1Dooooo`Ko00000_ooool2o`0000Gooooo0_l0
000Rooooo`?o00002OoooolGo`000003ooooool0003o000000Co00000_ooool3o`0009?ooooo000L
ooooo`03o`000?oooooooooo05Oooooo1ol000000ooooooo0000o`00000Vooooo`?o00000_ooool2
o`0000Gooooo7?l000000ooooooo0000o`000004o`0009?ooooo000Looooo`03o`000?oooooooooo
05[ooooo2?l00008ooooo`?o00006_ooool3o`0000;ooooo0_l00005oooooaco000000?oooooo`00
0?l000001?l0002Cooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o000000?oooooo`000?l0
00001_l00003ooooo`Ko00006_ooool4o`0000;ooooo1?l00003oooooa[o00000_ooool4o`0009Go
oooo000Looooo`03o`000?oooooooooo05Wooooo0_l000000ooooooo0000o`000003ooooo`?o0000
00?oooooo`000?l000001_l0000Iooooo`Go00000_ooool4o`0000?ooooo6_l00002ooooo`Co0000
UOooool001cooooo00?o0000ooooooooool0G?ooool2o`000003ooooool0003o000000_o00006_oo
ool3o`0000cooooo5ol00005ooooo`;o0000U_ooool001cooooo00?o0000ooooooooool0Goooool3
o`000003ooooool0003o000000Ko00006oooool3o`0000Oooooo0_l00003ooooo`;o00000_oooolB
o`0000?ooooo0_l000000ooooooo0000o`00002Fooooo`007?ooool00ol0003oooooooooo`1Soooo
o`Co00008?ooool2o`000003ooooool0003o000000Cooooo0_l00005oooooa?o00001?ooool2o`00
09Wooooo000Looooo`03o`000?oooooooooo08Oooooo0_l000000ooooooo0000o`00000;ooooo`;o
00000oooool9o`0000?ooooo0_l0002Oooooo`007?ooool00ol0003oooooooooo`27ooooo`Co0000
2?ooool3o`0000Wooooo0_l00005ooooo`;o00000_ooool2o`0000;ooooo0_l0002Iooooo`007?oo
ool00ol0003oooooooooo`27ooooo`Co00002?ooool3o`00013ooooo2_l0002Iooooo`007?ooool0
0ol0003oooooooooo`27ooooo`?o000000Coooooo`000?l0003ooooo0_l0000Hooooo`;o00000_oo
ool4o`0009Wooooo000Looooo`03o`000?oooooooooo08_ooooo1Ol0000;ooooo`;o00003oooool2
o`0009_ooooo000Looooo`;o0000ROooool2o`0000?ooooo0ol00002ooooo`?o00001_ooool4o`00
0:[ooooo000Looooo`03o`000?oooooooooo08Sooooo1?l00002ooooo`;o00000_ooool3o`0000?o
oooo0_l00003ooooo`;o00000_ooool2o`000:Kooooo000Looooo`03o`000?oooooooooo08Wooooo
0ol00002ooooo`;o00001Oooool2o`000003ooooool0003o000000;o00000_ooool2o`000003oooo
ool0003o00000:Kooooo000Looooo`03o`000?oooooooooo08Wooooo1?l000000ooooooo0000o`00
0002ooooo`;o000000?oooooo`000?l000000oooool2o`0000;ooooo0_l0002Yooooo`007?ooool0
0ol0003oooooooooo`2;ooooo`Co00000oooool4o`000;?ooooo000Looooo`03o`000?oooooooooo
08_ooooo1?l00005ooooo`;o00002_ooool2o`000:Oooooo000Looooo`03o`000?oooooooooo08_o
oooo1?l0000Aooooo`;o0000Yoooool001cooooo00?o0000ooooooooool0SOooool3o`0001;ooooo
0_l0002Uooooo`007?ooool00ol0003oooooooooo`2>ooooo`;o00000_ooool2o`0000Cooooo1?l0
0006ooooo`?o0000Y?ooool001cooooo00?o0000ooooooooool0S_ooool3o`000003ooooool0003o
000000?o000000?oooooo`000?l000000_l00006ooooo`?o0000Y?ooool001cooooo00?o0000oooo
ooooool0Soooool3o`000003ooooool0003o000000;o000000?oooooo`000?l000002Oooool2o`00
0:Cooooo000Looooo`03o`000?oooooooooo093ooooo1Ol00003ooooo`;o00001Oooool3o`0000Ko
oooo0ol0002Nooooo`007?ooool00ol0003oooooooooo`2@ooooo`Co00001_ooool2o`0000?ooooo
0ol00005ooooo`Co0000W_ooool001cooooo00?o0000ooooooooool0Toooool2o`0000Gooooo0_l0
0006ooooo`;o00000oooool4o`0009kooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2Cooooo`;o
00001?ooool3o`0000Cooooo1?l00005ooooo`;o0000W_ooool00006oooooomgMgOoV9RHoooooonH
V9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooo
oooo09?ooooo0_l00004ooooo`;o00001Oooool3o`0000?ooooo1?l00002ooooo`;o000000?ooooo
o`000?l00000V?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0Uoooool3o`0000Cooooo0_l00006
ooooo`Co00000_ooool2o`000003ooooool0003o000000;o0000U_ooool00003ooooool0003ooooo
00;ooooo00?o0000ooooooooool02Oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0002G
ooooo`Co00000oooool2o`0000oooooo1_l0002Dooooo`0000?oooooo`000?ooool00_ooool00ol0
003oooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`2I
ooooo`;o00001oooool4o`0000cooooo0ol0002Dooooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`2I
ooooo`;o000000?oooooo`000?l000001?ooool4o`000004ooooool0003o0000ooooo`;o00002?oo
ool2o`0009?ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo
^[Zjo`000006ooooo`03o`000?oooooooooo09cooooo0_l00003ooooo`;o00001?ooool5o`000003
ooooool0003o000000;o00000oooool2o`0009?ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^
kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo09cooooo0_l00002
ooooo`?o00001Oooool2o`0000?ooooo1?l0002Hooooo`007?ooool00ol0003oooooooooo`2Poooo
o`Co00001?ooool2o`0009oooooo000Looooo`03o`000?oooooooooo0:7ooooo0ol00002ooooo`;o
00000oooool2o`0009cooooo000Looooo`03o`000?oooooooooo0:Kooooo0_l00003ooooo`;o0000
W?ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?oooooo
Boooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001;ooooo1?l000000ol@413oooooooooo`03ooooo`03o`00
0?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo0ol0003ooooood[ooooo000Doooo
o`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`00
5?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_oo
ool001;ooooo00?oEEEEofIVI_l00000oooooomDooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00YOooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo01Kooooo
1?l000002?l@413ooooooooooonHV9So410@o`000?lb<S;oc<c<0oooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<093ooooo002Vooooo`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo00?o
0000ooooooooool00_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00Go8B4QoiRHV?oooooo
V9RHob4Q8@2@ooooo`00Y_ooool01Ol0003ooooooooooooooooo000001_ooooo00?o0000oooooooo
ool01_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0S_ooool00:Ko
oooo00Go0000ooooooooooooooooo`000009ooooo`Ko00003?ooool00ol0003oooooooooo`05oooo
o`03ojVYZOl@413ooooo00;ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P2@ooooo`00Y_ooool01Ol0
003oQhN7oooooonYZJWo000001_ooooo00?o0000ooooooooool01?ooool00ol@413o0000okZj^P03
ooooo`05olc<c?l0003o0000o`000?o<c<`0T?ooool00:Gooooo00?o410@o`000?mgMgL00_l00000
0onHV9Soooooooooo`0Iooooo`03o`000?oooooooooo00Gooooo00?o^[Zjob4Q8Oooool00_ooool0
1Ol@413o^[Zjoooooonj^[[o410@093ooooo0036ooooo`03o`000?oooooooooo00;ooooo00Go410@
oiRHV?oooooo^[Zjo`000003ooooo`05o`000?nj^[[ooooookZj^_l00000T?ooool00<Cooooo00?o
EEEEofIVI_l000001?ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@2@ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(144) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.32136 .53377 Mdot
.30099 .56765 Mdot
.64875 .63214 Mdot
.4681 .34488 Mdot
.68558 .40769 Mdot
.64657 .64475 Mdot
.45988 .68946 Mdot
.48012 .69179 Mdot
.61922 .59629 Mdot
.48417 .44895 Mdot
.45871 .72304 Mdot
.47682 .39347 Mdot
.46935 .69194 Mdot
.43255 .38787 Mdot
.53784 .31636 Mdot
.32579 .32409 Mdot
.32538 .58922 Mdot
.68165 .4271 Mdot
.31633 .32359 Mdot
.61822 .59228 Mdot
.76659 .36453 Mdot
.45461 .37533 Mdot
.33904 .5686 Mdot
.43158 .38714 Mdot
.32287 .32774 Mdot
.29556 .55854 Mdot
.31221 .53165 Mdot
.32538 .34134 Mdot
.49586 .36894 Mdot
.45047 .72217 Mdot
.32404 .35198 Mdot
.59726 .31411 Mdot
.65246 .46019 Mdot
.34403 .47379 Mdot
.49082 .72407 Mdot
.50026 .73603 Mdot
.62487 .61261 Mdot
.47244 .73607 Mdot
.4467 .67991 Mdot
.47799 .72783 Mdot
.47944 .72903 Mdot
.30072 .55506 Mdot
.48948 .73148 Mdot
.47221 .8061 Mdot
.42307 .37756 Mdot
.28951 .4018 Mdot
.60524 .58415 Mdot
.49848 .34907 Mdot
.34157 .57924 Mdot
.66408 .69184 Mdot
.59643 .37865 Mdot
.48279 .71293 Mdot
.63184 .47884 Mdot
.2532 .37228 Mdot
.46912 .68526 Mdot
.3188 .32616 Mdot
.63929 .66341 Mdot
.44501 .36382 Mdot
.50441 .34933 Mdot
.33859 .46272 Mdot
.46218 .35571 Mdot
.6951 .40097 Mdot
.25123 .58604 Mdot
.65957 .66208 Mdot
.63404 .5996 Mdot
.47663 .73936 Mdot
.30333 .5919 Mdot
.48242 .68051 Mdot
.47564 .34395 Mdot
.60717 .59969 Mdot
.47804 .3843 Mdot
.45946 .72389 Mdot
.28451 .57581 Mdot
.46366 .37963 Mdot
.33662 .54344 Mdot
.45249 .66143 Mdot
.68195 .42104 Mdot
.34373 .60764 Mdot
.65655 .69 Mdot
.39727 .33012 Mdot
.4649 .37328 Mdot
.28511 .70475 Mdot
.48792 .26969 Mdot
.28924 .54736 Mdot
.43035 .40241 Mdot
.2413 .67496 Mdot
.40154 .40393 Mdot
.33429 .34751 Mdot
.32513 .33616 Mdot
.51162 .3262 Mdot
.63153 .66977 Mdot
.33239 .56195 Mdot
.445 .37714 Mdot
.46827 .34041 Mdot
.46627 .45425 Mdot
.48826 .36752 Mdot
.3222 .33199 Mdot
.6239 .46145 Mdot
.47238 .72339 Mdot
.61767 .49082 Mdot
.42094 .66705 Mdot
.62253 .47303 Mdot
.44449 .40614 Mdot
.62908 .6314 Mdot
.28842 .53592 Mdot
.63692 .45792 Mdot
.49346 .69978 Mdot
.44132 .38064 Mdot
.50382 .73571 Mdot
.3359 .56264 Mdot
.31257 .34474 Mdot
.71192 .40136 Mdot
.74282 .42164 Mdot
.29259 .58256 Mdot
.35155 .39227 Mdot
.43486 .35767 Mdot
.46655 .36448 Mdot
.30127 .56358 Mdot
.62376 .58811 Mdot
.55014 .67949 Mdot
.32329 .57259 Mdot
.46754 .7242 Mdot
.32649 .59076 Mdot
.65475 .45616 Mdot
.62702 .59088 Mdot
.63548 .50427 Mdot
.61472 .46907 Mdot
.60351 .33568 Mdot
.4916 .35244 Mdot
.64738 .44527 Mdot
.62446 .62821 Mdot
.32006 .57061 Mdot
.47445 .70211 Mdot
.45357 .34139 Mdot
.29268 .5489 Mdot
.46359 .68127 Mdot
.73082 .40744 Mdot
.73201 .40892 Mdot
.28447 .56697 Mdot
.35643 .40104 Mdot
.48597 .74004 Mdot
.46445 .67145 Mdot
.59378 .37905 Mdot
.2848 .55491 Mdot
.72262 .37456 Mdot
.46642 .67515 Mdot
.69672 .62293 Mdot
.30929 .33865 Mdot
.61867 .34642 Mdot
.29624 .7027 Mdot
.59471 .37958 Mdot
.76357 .36903 Mdot
.70174 .39462 Mdot
.46483 .68092 Mdot
.41115 .37428 Mdot
.3022 .58104 Mdot
.29069 .55384 Mdot
.47207 .39319 Mdot
.64447 .45925 Mdot
.43238 .36229 Mdot
.61403 .48878 Mdot
.61324 .46958 Mdot
.43474 .38315 Mdot
.30747 .42199 Mdot
.31233 .53896 Mdot
.40826 .39702 Mdot
.61957 .6112 Mdot
.68645 .44202 Mdot
.49065 .73801 Mdot
.42973 .4007 Mdot
.39773 .38538 Mdot
.44222 .41391 Mdot
.46515 .6709 Mdot
.39938 .74304 Mdot
.64595 .68936 Mdot
.44633 .70648 Mdot
.42454 .66329 Mdot
.62089 .64501 Mdot
.50289 .34557 Mdot
.71269 .39625 Mdot
.63801 .48786 Mdot
.40944 .38862 Mdot
.59768 .37967 Mdot
.50954 .34394 Mdot
.75564 .39786 Mdot
.75496 .39047 Mdot
.27715 .69305 Mdot
.39031 .71531 Mdot
.44878 .34755 Mdot
.34073 .35777 Mdot
.60872 .36411 Mdot
.53435 .69754 Mdot
.47291 .70675 Mdot
.61219 .57856 Mdot
.61975 .58546 Mdot
.68309 .69942 Mdot
.43702 .42886 Mdot
.45624 .41022 Mdot
.47566 .36392 Mdot
.62421 .48482 Mdot
.25352 .58245 Mdot
.70086 .39448 Mdot
.31131 .5874 Mdot
.28806 .70551 Mdot
.42004 .30443 Mdot
.3038 .32288 Mdot
.70599 .69466 Mdot
.66374 .66753 Mdot
.63176 .46437 Mdot
.71972 .38283 Mdot
.44567 .35873 Mdot
.32655 .54571 Mdot
.60213 .37108 Mdot
.65319 .47533 Mdot
.769 .31817 Mdot
.32638 .58009 Mdot
.46331 .28343 Mdot
.46584 .6866 Mdot
.61979 .65905 Mdot
.40174 .40389 Mdot
.44416 .38812 Mdot
.33053 .6082 Mdot
.44693 .34578 Mdot
.30589 .34725 Mdot
.31422 .3401 Mdot
.66496 .69345 Mdot
.41165 .67235 Mdot
.44477 .69787 Mdot
.60392 .58304 Mdot
.28833 .57902 Mdot
.28647 .40719 Mdot
.63359 .64546 Mdot
.76461 .37846 Mdot
.46268 .72849 Mdot
.73387 .3981 Mdot
.6349 .63993 Mdot
.68622 .40674 Mdot
.5059 .34796 Mdot
.61257 .63383 Mdot
.7068 .40867 Mdot
.53728 .35869 Mdot
.63151 .46042 Mdot
.69905 .37118 Mdot
.45694 .68958 Mdot
.33578 .59729 Mdot
.40873 .38835 Mdot
.63394 .48394 Mdot
.64939 .49223 Mdot
.50236 .31346 Mdot
.60783 .50051 Mdot
.65042 .46877 Mdot
.50315 .3213 Mdot
.68605 .42871 Mdot
.3634 .65661 Mdot
.32127 .35154 Mdot
.32255 .59027 Mdot
.45224 .34457 Mdot
.40107 .68363 Mdot
.46258 .68027 Mdot
.45282 .35567 Mdot
.27174 .69871 Mdot
.45459 .69118 Mdot
.44693 .36889 Mdot
.44091 .68691 Mdot
.29144 .54752 Mdot
.42329 .29974 Mdot
.28088 .56854 Mdot
.43389 .38159 Mdot
.43972 .6887 Mdot
.60763 .58669 Mdot
.29397 .55919 Mdot
.44769 .37756 Mdot
.47779 .3548 Mdot
.62659 .48374 Mdot
.31234 .33942 Mdot
.43089 .66667 Mdot
.47532 .39403 Mdot
.65068 .67035 Mdot
.49109 .37281 Mdot
.73112 .41332 Mdot
.72421 .63048 Mdot
.2839 .55607 Mdot
.60784 .50242 Mdot
.641 .64916 Mdot
.54962 .41125 Mdot
.44736 .28511 Mdot
.42185 .38163 Mdot
.64868 .4785 Mdot
.47661 .26017 Mdot
.45378 .70428 Mdot
.30695 .34452 Mdot
.65596 .43961 Mdot
.64183 .66274 Mdot
.62203 .47633 Mdot
.46522 .39074 Mdot
.3378 .56052 Mdot
.32278 .32474 Mdot
.61985 .65065 Mdot
.33116 .58289 Mdot
.42533 .40932 Mdot
.42695 .66424 Mdot
.60471 .4711 Mdot
.45547 .70806 Mdot
.32803 .34587 Mdot
.50217 .34492 Mdot
.60725 .60295 Mdot
.30239 .55294 Mdot
.47462 .68716 Mdot
.2828 .57064 Mdot
.56352 .40218 Mdot
.46919 .28146 Mdot
.27676 .56848 Mdot
.71548 .41996 Mdot
.73211 .70572 Mdot
.45786 .71945 Mdot
.62413 .50148 Mdot
.59625 .63351 Mdot
.34325 .56802 Mdot
.63508 .6343 Mdot
.36552 .41421 Mdot
.63257 .66893 Mdot
.31489 .3212 Mdot
.60059 .61171 Mdot
.43611 .41962 Mdot
.41781 .39871 Mdot
.65531 .62563 Mdot
.62825 .45801 Mdot
.46161 .38939 Mdot
.2943 .54777 Mdot
.58927 .30662 Mdot
.4179 .45158 Mdot
.43504 .42833 Mdot
.63884 .66156 Mdot
.35911 .41208 Mdot
.31751 .34433 Mdot
.32799 .34335 Mdot
.30594 .57954 Mdot
.62714 .50023 Mdot
.74254 .38453 Mdot
.74168 .37201 Mdot
.76757 .60734 Mdot
.45896 .24578 Mdot
.34946 .38673 Mdot
.28887 .56086 Mdot
.70027 .70269 Mdot
.317 .52836 Mdot
.65287 .47384 Mdot
.48051 .69233 Mdot
.40626 .75581 Mdot
.40321 .40619 Mdot
.63706 .43916 Mdot
.30225 .34474 Mdot
.33727 .58932 Mdot
.29165 .58947 Mdot
.47627 .68805 Mdot
.42272 .43012 Mdot
.4841 .44792 Mdot
.44452 .35474 Mdot
.48187 .69105 Mdot
.65177 .48603 Mdot
.50653 .33189 Mdot
.61112 .32438 Mdot
.49152 .81844 Mdot
.42569 .38083 Mdot
.35837 .49509 Mdot
.41399 .3932 Mdot
.60508 .34255 Mdot
.43934 .36438 Mdot
.29976 .55094 Mdot
.27731 .31527 Mdot
.43323 .34719 Mdot
.70773 .69231 Mdot
.41899 .30707 Mdot
.702 .4182 Mdot
.44339 .38478 Mdot
.42193 .37082 Mdot
.73183 .37576 Mdot
.3187 .55176 Mdot
.48852 .34464 Mdot
.3679 .6548 Mdot
.45099 .37422 Mdot
.49224 .73784 Mdot
.50092 .29075 Mdot
.5958 .31702 Mdot
.31809 .34146 Mdot
.33877 .56317 Mdot
.45422 .67624 Mdot
.48067 .73288 Mdot
.61816 .50781 Mdot
.4622 .67992 Mdot
.41966 .3968 Mdot
.50171 .29157 Mdot
.29664 .58905 Mdot
.63419 .46078 Mdot
.33014 .56344 Mdot
.65335 .56328 Mdot
.4585 .69419 Mdot
.62952 .47223 Mdot
.43916 .43431 Mdot
.46267 .70572 Mdot
.45411 .63991 Mdot
.31377 .34684 Mdot
.65084 .4883 Mdot
.32487 .53613 Mdot
.60523 .60301 Mdot
.65065 .47737 Mdot
.4696 .68489 Mdot
.42214 .37829 Mdot
.31496 .32903 Mdot
.46486 .67936 Mdot
.36492 .51378 Mdot
.31569 .35148 Mdot
.45157 .37241 Mdot
.30534 .54189 Mdot
.31734 .56325 Mdot
.40576 .39483 Mdot
.43379 .35541 Mdot
.64855 .6556 Mdot
.6479 .48414 Mdot
.64671 .48848 Mdot
.60688 .48259 Mdot
.62919 .66514 Mdot
.72496 .70834 Mdot
.48573 .68197 Mdot
.59419 .31657 Mdot
.39327 .71025 Mdot
.63594 .47871 Mdot
.64977 .65363 Mdot
.41638 .38829 Mdot
.44751 .40814 Mdot
.43886 .68814 Mdot
.77772 .67529 Mdot
.4043 .40872 Mdot
.31148 .59154 Mdot
.48637 .70443 Mdot
.45932 .40705 Mdot
.68047 .69695 Mdot
.69354 .41231 Mdot
.34798 .38762 Mdot
.4852 .70461 Mdot
.3696 .53968 Mdot
.48487 .70522 Mdot
.42003 .37334 Mdot
.47363 .38253 Mdot
.33165 .60212 Mdot
.70238 .41873 Mdot
.4755 .39259 Mdot
.44068 .37188 Mdot
.70528 .70378 Mdot
.30963 .52647 Mdot
.74274 .37268 Mdot
.49887 .36616 Mdot
.6182 .46926 Mdot
.69033 .41897 Mdot
.46965 .37249 Mdot
.48784 .37797 Mdot
.65715 .4472 Mdot
.43893 .69773 Mdot
.71292 .41895 Mdot
.70937 .69346 Mdot
.32431 .58409 Mdot
.43834 .65984 Mdot
.62151 .51341 Mdot
.45949 .72098 Mdot
.52987 .39895 Mdot
.62873 .46878 Mdot
.43764 .79214 Mdot
.65215 .18482 Mdot
.64736 .46859 Mdot
.64945 .66515 Mdot
.45709 .45556 Mdot
.4837 .38327 Mdot
.45094 .37223 Mdot
.74216 .39445 Mdot
.30926 .565 Mdot
.39067 .71596 Mdot
.44298 .69917 Mdot
.4384 .39227 Mdot
.28195 .55813 Mdot
.26388 .68991 Mdot
.62392 .47841 Mdot
.71991 .40514 Mdot
.72881 .40514 Mdot
.46254 .38363 Mdot
.46794 .25404 Mdot
.2933 .55753 Mdot
.4471 .3779 Mdot
.46945 .37944 Mdot
.60114 .6439 Mdot
.29908 .53872 Mdot
.61351 .63552 Mdot
.30329 .32502 Mdot
.35069 .3692 Mdot
.39997 .68824 Mdot
.4555 .68387 Mdot
.63583 .5015 Mdot
.44557 .69918 Mdot
.62639 .68072 Mdot
.64667 .48798 Mdot
.4475 .37821 Mdot
.29673 .58929 Mdot
.44616 .378 Mdot
.44955 .37478 Mdot
.42927 .36928 Mdot
.34556 .385 Mdot
.65522 .68557 Mdot
.72047 .39924 Mdot
.50309 .3563 Mdot
.62563 .65775 Mdot
.6874 .69387 Mdot
.48316 .45009 Mdot
.45332 .38077 Mdot
.46178 .3647 Mdot
.34693 .60609 Mdot
.30746 .33665 Mdot
.46471 .70464 Mdot
.33246 .60191 Mdot
.40013 .40202 Mdot
.60383 .58524 Mdot
.4875 .34321 Mdot
.27713 .56837 Mdot
.49289 .69416 Mdot
.23893 .57178 Mdot
.62839 .51381 Mdot
.63014 .50726 Mdot
.65007 .47315 Mdot
.60504 .48937 Mdot
.49176 .73577 Mdot
.65087 .65198 Mdot
.63709 .5475 Mdot
.36569 .36149 Mdot
.43423 .3545 Mdot
.46972 .38619 Mdot
.59722 .63197 Mdot
.64958 .45136 Mdot
.39777 .43489 Mdot
.30062 .31823 Mdot
.61176 .65236 Mdot
.62051 .46354 Mdot
.2337 .6305 Mdot
.33604 .57346 Mdot
.64535 .68736 Mdot
.46858 .73421 Mdot
.70486 .41108 Mdot
.82759 .5572 Mdot
.32728 .56623 Mdot
.25129 .5743 Mdot
.61888 .62082 Mdot
.50554 .30456 Mdot
.24553 .35974 Mdot
.63863 .63405 Mdot
.31225 .35225 Mdot
.29454 .57522 Mdot
.6255 .46249 Mdot
.47805 .26325 Mdot
.4995 .29928 Mdot
.61117 .60792 Mdot
.47899 .354 Mdot
.64063 .59656 Mdot
.64563 .66407 Mdot
.63493 .49945 Mdot
.63832 .66114 Mdot
.45107 .70016 Mdot
.62337 .63413 Mdot
.36538 .51677 Mdot
.48257 .34681 Mdot
.25211 .37107 Mdot
.53974 .29957 Mdot
.43563 .35634 Mdot
.46998 .71458 Mdot
.43125 .66126 Mdot
.46175 .35014 Mdot
.69941 .38533 Mdot
.65058 .66227 Mdot
.67608 .6982 Mdot
.3114 .32672 Mdot
.60044 .61496 Mdot
.33793 .55932 Mdot
.42026 .6665 Mdot
.42298 .66457 Mdot
.65015 .47711 Mdot
.28804 .55147 Mdot
.45382 .66 Mdot
.46857 .72425 Mdot
.6129 .4606 Mdot
.40698 .39094 Mdot
.31902 .54301 Mdot
.50655 .33001 Mdot
.68459 .43771 Mdot
.45289 .37388 Mdot
.61467 .63616 Mdot
.66212 .69336 Mdot
.53956 .30944 Mdot
.63459 .64824 Mdot
.63092 .50319 Mdot
.31019 .54012 Mdot
.31394 .32444 Mdot
.32041 .568 Mdot
.46191 .34119 Mdot
.40635 .67742 Mdot
.33721 .57234 Mdot
.76428 .37857 Mdot
.45979 .35839 Mdot
.30498 .4184 Mdot
.50202 .36169 Mdot
.45316 .37207 Mdot
.63283 .59604 Mdot
.72973 .37565 Mdot
.69446 .43299 Mdot
.68164 .69117 Mdot
.69626 .39351 Mdot
.27709 .53329 Mdot
.62764 .58981 Mdot
.73017 .38673 Mdot
.77063 .60644 Mdot
.60724 .50321 Mdot
.72537 .39363 Mdot
.42906 .40228 Mdot
.45905 .67809 Mdot
.31565 .59851 Mdot
.45749 .39244 Mdot
.38525 .41098 Mdot
.33969 .32153 Mdot
.62665 .48075 Mdot
.45522 .36945 Mdot
.42171 .36986 Mdot
.2818 .56005 Mdot
.29673 .70474 Mdot
.65486 .6665 Mdot
.61929 .49554 Mdot
.32619 .56937 Mdot
.28374 .70453 Mdot
.63728 .60281 Mdot
.73588 .38871 Mdot
.44494 .68836 Mdot
.37014 .55077 Mdot
.6304 .48146 Mdot
.45831 .6893 Mdot
.66955 .68912 Mdot
.58787 .38604 Mdot
.33867 .33614 Mdot
.6313 .61994 Mdot
.59503 .37977 Mdot
.30187 .32942 Mdot
.68545 .69992 Mdot
.53452 .69583 Mdot
.33516 .56237 Mdot
.47007 .68018 Mdot
.71805 .4092 Mdot
.28464 .57844 Mdot
.33057 .56376 Mdot
.4545 .68421 Mdot
.26614 .32075 Mdot
.47503 .26235 Mdot
.46682 .66607 Mdot
.50863 .31297 Mdot
.58981 .38295 Mdot
.62998 .48473 Mdot
.71592 .3976 Mdot
.41164 .67248 Mdot
.3002 .55555 Mdot
.4036 .74339 Mdot
.59924 .37756 Mdot
.30839 .34454 Mdot
.70245 .41034 Mdot
.26874 .68839 Mdot
.5154 .73298 Mdot
.46253 .70183 Mdot
.70489 .70385 Mdot
.71066 .37605 Mdot
.42074 .40073 Mdot
.79024 .66503 Mdot
.42836 .39942 Mdot
.47482 .6769 Mdot
.30257 .34484 Mdot
.3171 .58236 Mdot
.47752 .67537 Mdot
.30388 .32141 Mdot
.48196 .388 Mdot
.45142 .34861 Mdot
.6558 .69108 Mdot
.33392 .60484 Mdot
.60356 .50891 Mdot
.43085 .35975 Mdot
.44333 .36872 Mdot
.6523 .4875 Mdot
.5969 .32005 Mdot
.52842 .63488 Mdot
.64832 .45712 Mdot
.60967 .63506 Mdot
.63454 .46027 Mdot
.62284 .49779 Mdot
.33205 .54405 Mdot
.69588 .7025 Mdot
.64177 .50224 Mdot
.43087 .38098 Mdot
.43989 .37868 Mdot
.44788 .67861 Mdot
.47666 .26086 Mdot
.50205 .30436 Mdot
.65238 .66985 Mdot
.62821 .44731 Mdot
.48469 .36502 Mdot
.28986 .54767 Mdot
.74357 .39546 Mdot
.62008 .50684 Mdot
.32382 .58689 Mdot
.49435 .35313 Mdot
.60021 .64073 Mdot
.64432 .46719 Mdot
.65225 .49082 Mdot
.70514 .40685 Mdot
.4611 .66857 Mdot
.33969 .61033 Mdot
.6473 .66441 Mdot
.33834 .34225 Mdot
.59751 .47513 Mdot
.60815 .65872 Mdot
.62899 .48651 Mdot
.62152 .47025 Mdot
.28869 .55265 Mdot
.37047 .5357 Mdot
.6607 .47278 Mdot
.62985 .66294 Mdot
.47112 .81615 Mdot
.48158 .72084 Mdot
.50181 .3476 Mdot
.44689 .69346 Mdot
.33542 .56133 Mdot
.60455 .33417 Mdot
.73236 .39955 Mdot
.46008 .7031 Mdot
.65123 .46743 Mdot
.33372 .56728 Mdot
.33256 .6099 Mdot
.43191 .38359 Mdot
.45379 .37722 Mdot
.60518 .58383 Mdot
.61388 .35379 Mdot
.44105 .6836 Mdot
.74173 .38492 Mdot
.65297 .64434 Mdot
.31446 .32758 Mdot
.30344 .58335 Mdot
.71971 .35716 Mdot
.50433 .35833 Mdot
.62893 .65936 Mdot
.2994 .56944 Mdot
.7401 .37246 Mdot
.72174 .39888 Mdot
.41018 .38095 Mdot
.76269 .3692 Mdot
.45555 .70012 Mdot
.29496 .54923 Mdot
.26287 .54068 Mdot
.50136 .35502 Mdot
.45021 .38074 Mdot
.3053 .34062 Mdot
.47132 .66717 Mdot
.42818 .40177 Mdot
.70967 .41589 Mdot
.29568 .58284 Mdot
.41635 .39177 Mdot
.71812 .37182 Mdot
.6019 .50343 Mdot
.63332 .46631 Mdot
.65093 .61698 Mdot
.72643 .3662 Mdot
.72318 .37127 Mdot
.71474 .37264 Mdot
.40681 .75675 Mdot
.46133 .40529 Mdot
.60402 .52353 Mdot
.479 .35593 Mdot
.58752 .38458 Mdot
.34068 .34584 Mdot
.47468 .72036 Mdot
.60723 .60524 Mdot
.43535 .36205 Mdot
.47812 .35702 Mdot
.3441 .59642 Mdot
.32368 .32207 Mdot
.4095 .39717 Mdot
.31355 .5852 Mdot
.2576 .55164 Mdot
.61712 .57791 Mdot
.29502 .70214 Mdot
.81587 .6333 Mdot
.5088 .33912 Mdot
.50736 .30005 Mdot
.32346 .5546 Mdot
.44596 .68364 Mdot
.50911 .31026 Mdot
.4639 .66977 Mdot
.31196 .56058 Mdot
.32672 .32132 Mdot
.36452 .51278 Mdot
.6942 .40258 Mdot
.42019 .37376 Mdot
.45295 .68759 Mdot
.42616 .36741 Mdot
.45106 .68621 Mdot
.35775 .41745 Mdot
.48529 .26584 Mdot
.43294 .35438 Mdot
.48886 .36764 Mdot
.76636 .36266 Mdot
.45384 .37903 Mdot
.71157 .70478 Mdot
.30262 .57435 Mdot
.6426 .44341 Mdot
.33607 .32663 Mdot
.41904 .45233 Mdot
.46163 .36626 Mdot
.35292 .33681 Mdot
.46883 .36292 Mdot
.77035 .68243 Mdot
.50793 .34608 Mdot
.40901 .39327 Mdot
.47628 .70744 Mdot
.46526 .72737 Mdot
.3384 .60668 Mdot
.62319 .47013 Mdot
.27286 .69106 Mdot
.44584 .37011 Mdot
.65602 .63564 Mdot
.70695 .43959 Mdot
.72842 .37105 Mdot
.3011 .58737 Mdot
.64361 .17818 Mdot
.48924 .73278 Mdot
.61389 .61445 Mdot
.32377 .35283 Mdot
.61107 .63557 Mdot
.65772 .66625 Mdot
.27309 .53279 Mdot
.7168 .39832 Mdot
.48407 .34092 Mdot
.34462 .47173 Mdot
.24592 .57452 Mdot
.50121 .35477 Mdot
.62688 .5854 Mdot
.65732 .44766 Mdot
.38956 .25715 Mdot
.68372 .42611 Mdot
.70974 .38147 Mdot
.4634 .68471 Mdot
.65609 .63408 Mdot
.62002 .49508 Mdot
.73213 .39076 Mdot
.61464 .57817 Mdot
.61046 .50501 Mdot
.70338 .70651 Mdot
.29358 .55617 Mdot
.36093 .41264 Mdot
.28361 .39652 Mdot
.45808 .71203 Mdot
.68825 .69854 Mdot
.29179 .58636 Mdot
.27979 .55889 Mdot
.62312 .48921 Mdot
.60792 .64415 Mdot
.27058 .55788 Mdot
.41082 .3833 Mdot
.63106 .46207 Mdot
.44681 .39281 Mdot
.68096 .43004 Mdot
.44467 .37334 Mdot
.608 .58905 Mdot
.47277 .71119 Mdot
.64295 .6584 Mdot
.46091 .68523 Mdot
.59251 .31257 Mdot
.45275 .36195 Mdot
.44534 .38282 Mdot
.50131 .2923 Mdot
.32437 .53991 Mdot
.34584 .47463 Mdot
.63288 .66105 Mdot
.64132 .65987 Mdot
.33567 .32659 Mdot
.32402 .59294 Mdot
.64705 .50507 Mdot
.50923 .31426 Mdot
.47046 .3638 Mdot
.30413 .57375 Mdot
.34122 .34902 Mdot
.45241 .80543 Mdot
.48877 .27257 Mdot
.33234 .54657 Mdot
.71564 .70942 Mdot
.47535 .37409 Mdot
.6171 .49733 Mdot
.63434 .44899 Mdot
.4662 .24928 Mdot
.68307 .43457 Mdot
.32655 .58135 Mdot
.61588 .48875 Mdot
.30046 .58169 Mdot
.63557 .67031 Mdot
.49847 .71786 Mdot
.31016 .57995 Mdot
.466 .36165 Mdot
.81646 .63179 Mdot
.45515 .67887 Mdot
.41735 .38186 Mdot
.48537 .68337 Mdot
.29935 .59538 Mdot
.31624 .57129 Mdot
.61073 .50519 Mdot
.31116 .35091 Mdot
.45732 .7019 Mdot
.41641 .36885 Mdot
.35946 .49917 Mdot
.32294 .32467 Mdot
.68619 .4402 Mdot
.48594 .36422 Mdot
.49587 .35947 Mdot
.71923 .70536 Mdot
.55088 .41122 Mdot
.40167 .68176 Mdot
.49789 .73744 Mdot
.39813 .74283 Mdot
.31561 .53404 Mdot
.70016 .4291 Mdot
.33627 .61029 Mdot
.63846 .50048 Mdot
.60881 .62663 Mdot
.42613 .37123 Mdot
.60334 .4957 Mdot
.46486 .66414 Mdot
.72245 .39005 Mdot
.50951 .34391 Mdot
.63531 .61792 Mdot
.60891 .48778 Mdot
.45994 .697 Mdot
.30449 .55446 Mdot
.31937 .58516 Mdot
.69879 .70674 Mdot
.4153 .39057 Mdot
.45135 .37736 Mdot
.49517 .71396 Mdot
.75912 .37541 Mdot
.69592 .39301 Mdot
.62879 .45768 Mdot
.49601 .70771 Mdot
.48855 .27164 Mdot
.32886 .60836 Mdot
.41441 .37994 Mdot
.50073 .28764 Mdot
.39439 .73091 Mdot
.23686 .61713 Mdot
.70185 .38952 Mdot
.45045 .27866 Mdot
.32671 .58045 Mdot
.47533 .70054 Mdot
.76712 .61065 Mdot
.30368 .33673 Mdot
.47018 .34799 Mdot
.43886 .28618 Mdot
.50192 .31591 Mdot
.33124 .35022 Mdot
.6251 .51372 Mdot
.47587 .28745 Mdot
.3386 .33014 Mdot
.3351 .33321 Mdot
.48304 .3717 Mdot
.486 .36678 Mdot
.30942 .57235 Mdot
.43479 .42741 Mdot
.618 .62984 Mdot
.31858 .35727 Mdot
.73753 .35648 Mdot
.31795 .3485 Mdot
.46579 .39756 Mdot
.23623 .62562 Mdot
.44266 .24612 Mdot
.29365 .57157 Mdot
.34309 .56485 Mdot
.45597 .71135 Mdot
.32005 .32341 Mdot
.63028 .66093 Mdot
.66086 .45166 Mdot
.60369 .616 Mdot
.30762 .57119 Mdot
.61845 .57943 Mdot
.47385 .73836 Mdot
.63128 .61974 Mdot
.6113 .64888 Mdot
.47519 .7125 Mdot
.33413 .60308 Mdot
.50112 .365 Mdot
.47466 .71311 Mdot
.65571 .48179 Mdot
.73529 .3913 Mdot
.25131 .56348 Mdot
.63713 .45649 Mdot
.41252 .41124 Mdot
.46995 .81241 Mdot
.6258 .61329 Mdot
.4259 .29736 Mdot
.34011 .58545 Mdot
.72039 .36276 Mdot
.31285 .57882 Mdot
.65972 .47887 Mdot
.69797 .39956 Mdot
.43661 .40198 Mdot
.74329 .35341 Mdot
.53625 .68838 Mdot
.43151 .349 Mdot
.25806 .55057 Mdot
.60217 .62176 Mdot
.45866 .7089 Mdot
.47562 .64281 Mdot
.61774 .49441 Mdot
.34028 .56598 Mdot
.37504 .56161 Mdot
.64394 .49348 Mdot
.474 .70273 Mdot
.32169 .43687 Mdot
.41543 .37482 Mdot
.44909 .70184 Mdot
.48627 .3618 Mdot
.35495 .39683 Mdot
.74262 .39948 Mdot
.60795 .47904 Mdot
.32059 .31979 Mdot
.63426 .60075 Mdot
.33281 .32425 Mdot
.39737 .42029 Mdot
.61231 .33776 Mdot
.47509 .35831 Mdot
.42962 .29412 Mdot
.62416 .67945 Mdot
.29118 .57635 Mdot
.64172 .47533 Mdot
.62827 .48401 Mdot
.31281 .32013 Mdot
.85939 .54765 Mdot
.72528 .38548 Mdot
.71208 .70826 Mdot
.45138 .36371 Mdot
.46419 .37292 Mdot
.33774 .60947 Mdot
.36224 .42121 Mdot
.62227 .46357 Mdot
.47188 .35128 Mdot
.45098 .24312 Mdot
.47944 .69978 Mdot
.44556 .40503 Mdot
.4592 .38548 Mdot
.41518 .66784 Mdot
.47645 .70532 Mdot
.61696 .67077 Mdot
.60808 .50574 Mdot
.65018 .61496 Mdot
.68592 .41199 Mdot
.46055 .28222 Mdot
.60099 .32503 Mdot
.48828 .27765 Mdot
.69029 .40404 Mdot
.31586 .34274 Mdot
.40383 .41204 Mdot
.47977 .34733 Mdot
.71346 .38054 Mdot
.4436 .71352 Mdot
.30615 .57527 Mdot
.35737 .40398 Mdot
.62685 .48572 Mdot
.33664 .33813 Mdot
.6824 .41676 Mdot
.29978 .57993 Mdot
.30946 .42444 Mdot
.30875 .56618 Mdot
.46355 .69817 Mdot
.68605 .69882 Mdot
.6967 .40207 Mdot
.31291 .57942 Mdot
.62551 .59344 Mdot
.4053 .67965 Mdot
.43749 .41654 Mdot
.47009 .73737 Mdot
.28168 .52864 Mdot
.33896 .55516 Mdot
.32381 .53356 Mdot
.30872 .32581 Mdot
.42876 .29532 Mdot
.63332 .50342 Mdot
.4962 .70434 Mdot
.63675 .60608 Mdot
.61323 .35106 Mdot
.32938 .45141 Mdot
.48076 .30123 Mdot
.46026 .39415 Mdot
.44296 .37448 Mdot
.46739 .37804 Mdot
.63286 .51275 Mdot
.39729 .40839 Mdot
.47918 .35918 Mdot
.43888 .68708 Mdot
.61468 .66775 Mdot
.44735 .36518 Mdot
.636 .46707 Mdot
.63455 .43992 Mdot
.72024 .36269 Mdot
.33267 .38075 Mdot
.25579 .579 Mdot
.30528 .58069 Mdot
.62148 .65177 Mdot
.63484 .5944 Mdot
.73046 .4086 Mdot
.48002 .69045 Mdot
.3096 .56412 Mdot
.76787 .68311 Mdot
.69524 .40966 Mdot
.42753 .38002 Mdot
.50065 .29138 Mdot
.45049 .24938 Mdot
.4742 .39207 Mdot
.4313 .36769 Mdot
.64697 .46304 Mdot
.62621 .66023 Mdot
.44096 .41735 Mdot
.30896 .42278 Mdot
.71301 .37502 Mdot
.73769 .38455 Mdot
.29447 .53488 Mdot
.41017 .37417 Mdot
.4533 .68885 Mdot
.47582 .25879 Mdot
.42961 .66762 Mdot
.24504 .67445 Mdot
.64402 .55866 Mdot
.48676 .34209 Mdot
.43718 .45679 Mdot
.40257 .40617 Mdot
.28859 .53588 Mdot
.36678 .52881 Mdot
.28968 .56517 Mdot
.4795 .69606 Mdot
.57593 .39454 Mdot
.47931 .73033 Mdot
.61883 .4657 Mdot
.33505 .57713 Mdot
.5129 .33261 Mdot
.64088 .65934 Mdot
.33103 .3266 Mdot
.70815 .39651 Mdot
.50496 .32563 Mdot
.63891 .47673 Mdot
.45374 .27929 Mdot
.64971 .65258 Mdot
.32104 .60595 Mdot
.33253 .3272 Mdot
.67971 .68978 Mdot
.47844 .28965 Mdot
.64947 .54219 Mdot
.60271 .49578 Mdot
.69499 .40137 Mdot
.4904 .44782 Mdot
.70023 .41396 Mdot
.45727 .70017 Mdot
.45523 .35976 Mdot
.40884 .39226 Mdot
.45835 .36994 Mdot
.4509 .39728 Mdot
.4736 .68803 Mdot
.32835 .33142 Mdot
.6583 .46319 Mdot
.60535 .49394 Mdot
.32213 .35107 Mdot
.71831 .39411 Mdot
.479 .72162 Mdot
.60585 .65489 Mdot
.65206 .4769 Mdot
.69617 .42228 Mdot
.41419 .36281 Mdot
.46998 .35552 Mdot
.60847 .48283 Mdot
.43245 .40212 Mdot
.32556 .33246 Mdot
.62712 .62299 Mdot
.33404 .34146 Mdot
.71626 .36447 Mdot
.70529 .40011 Mdot
.46143 .67873 Mdot
.31228 .58037 Mdot
.72429 .41186 Mdot
.65121 .64236 Mdot
.40576 .4035 Mdot
.4854 .36597 Mdot
.36576 .51776 Mdot
.59874 .37868 Mdot
.7173 .36476 Mdot
.42275 .40171 Mdot
.29554 .53974 Mdot
.37437 .58122 Mdot
.47218 .34904 Mdot
.32426 .33751 Mdot
.33285 .54404 Mdot
.73381 .39124 Mdot
.47969 .6872 Mdot
.548 .305 Mdot
.4672 .67206 Mdot
.30497 .55344 Mdot
.61741 .48775 Mdot
.33565 .5999 Mdot
.61641 .49279 Mdot
.2452 .65087 Mdot
.48227 .36253 Mdot
.36248 .50898 Mdot
.65507 .45256 Mdot
.63672 .66409 Mdot
.61379 .65997 Mdot
.64487 .46887 Mdot
.32963 .58101 Mdot
.63296 .50189 Mdot
.71106 .4116 Mdot
.39874 .73946 Mdot
.33912 .55129 Mdot
.6109 .64903 Mdot
.62783 .61329 Mdot
.49646 .7094 Mdot
.45151 .3699 Mdot
.41516 .37797 Mdot
.63481 .62247 Mdot
.43031 .66665 Mdot
.32912 .55588 Mdot
.45014 .37799 Mdot
.65185 .4609 Mdot
.62096 .62662 Mdot
.52685 .70938 Mdot
.29865 .59643 Mdot
.32304 .31959 Mdot
.61112 .33475 Mdot
.4953 .73729 Mdot
.41083 .40772 Mdot
.32344 .33271 Mdot
.72459 .37856 Mdot
.44662 .27979 Mdot
.59249 .37983 Mdot
.48322 .73733 Mdot
.6305 .50674 Mdot
.47101 .3947 Mdot
.6265 .66826 Mdot
.40832 .40207 Mdot
.67116 .20759 Mdot
.61063 .47606 Mdot
.42511 .39344 Mdot
.62731 .45405 Mdot
.32084 .56876 Mdot
.45701 .37356 Mdot
.40071 .68662 Mdot
.62403 .65095 Mdot
.41552 .38989 Mdot
.76718 .36652 Mdot
.48086 .67882 Mdot
.63838 .47609 Mdot
.69754 .39184 Mdot
.32231 .35516 Mdot
.58937 .30727 Mdot
.59728 .63335 Mdot
.72435 .39866 Mdot
.45467 .36769 Mdot
.65417 .64693 Mdot
.46192 .72426 Mdot
.64317 .47377 Mdot
.42212 .35576 Mdot
.46949 .72241 Mdot
.48042 .70754 Mdot
.70002 .40767 Mdot
.28452 .40786 Mdot
.45977 .33953 Mdot
.43286 .38963 Mdot
.3097 .43014 Mdot
.3607 .6011 Mdot
.42197 .37235 Mdot
.45593 .39088 Mdot
.45696 .68891 Mdot
.57466 .39799 Mdot
.45165 .2796 Mdot
.65403 .44939 Mdot
.46331 .71237 Mdot
.62326 .5798 Mdot
.61608 .61599 Mdot
.72581 .40328 Mdot
.29911 .56826 Mdot
.72272 .41628 Mdot
.62204 .63877 Mdot
.42848 .38249 Mdot
.48065 .68403 Mdot
.34782 .36632 Mdot
.48123 .67804 Mdot
.64773 .63533 Mdot
.27806 .56713 Mdot
.42511 .4215 Mdot
.66735 .20343 Mdot
.51487 .63172 Mdot
.68688 .70303 Mdot
.72885 .37169 Mdot
.30968 .42361 Mdot
.45647 .36372 Mdot
.43201 .42405 Mdot
.41735 .38549 Mdot
.71704 .42398 Mdot
.60267 .61147 Mdot
.61054 .50514 Mdot
.61796 .49508 Mdot
.45296 .28253 Mdot
.48172 .70589 Mdot
.48345 .73282 Mdot
.61658 .47819 Mdot
.46622 .701 Mdot
.43179 .39238 Mdot
.6455 .64334 Mdot
.23793 .64409 Mdot
.47029 .36294 Mdot
.60793 .4647 Mdot
.48587 .74139 Mdot
.27569 .57166 Mdot
.62321 .58042 Mdot
.4273 .45534 Mdot
.28101 .69569 Mdot
.46156 .706 Mdot
.33375 .3804 Mdot
.62739 .65611 Mdot
.652 .47543 Mdot
.65544 .65119 Mdot
.42576 .39055 Mdot
.48727 .34216 Mdot
.65048 .49141 Mdot
.46835 .36526 Mdot
.34578 .48116 Mdot
.3037 .34054 Mdot
.29216 .32311 Mdot
.4791 .35463 Mdot
.27295 .53796 Mdot
.45122 .71578 Mdot
.61632 .48016 Mdot
.50282 .32188 Mdot
.4937 .35325 Mdot
.3169 .53368 Mdot
.46957 .72046 Mdot
.30634 .69918 Mdot
.47779 .69428 Mdot
.63896 .66568 Mdot
.4818 .69521 Mdot
.40325 .40581 Mdot
.31555 .55935 Mdot
.63051 .64017 Mdot
.63428 .47864 Mdot
.62069 .60131 Mdot
.43318 .35818 Mdot
.52219 .72349 Mdot
.61355 .61603 Mdot
.30612 .34192 Mdot
.31586 .56131 Mdot
.75335 .35224 Mdot
.25225 .58592 Mdot
.42762 .38546 Mdot
.41938 .38138 Mdot
.63001 .45755 Mdot
.46552 .68096 Mdot
.31968 .60706 Mdot
.70695 .70638 Mdot
.7202 .36322 Mdot
.2944 .56894 Mdot
.74595 .38973 Mdot
.50558 .3054 Mdot
.29201 .58223 Mdot
.45277 .24367 Mdot
.45543 .68262 Mdot
.32275 .58459 Mdot
.70413 .44497 Mdot
.33972 .3582 Mdot
.71463 .40158 Mdot
.63771 .59994 Mdot
.50891 .3077 Mdot
.61371 .62645 Mdot
.40621 .67706 Mdot
.66482 .69371 Mdot
.45665 .70439 Mdot
.76611 .3706 Mdot
.30288 .34575 Mdot
.47398 .73569 Mdot
.39392 .70625 Mdot
.61663 .63723 Mdot
.61633 .47513 Mdot
.33134 .33911 Mdot
.64803 .49911 Mdot
.61173 .49073 Mdot
.48621 .73462 Mdot
.32153 .5867 Mdot
.31779 .59295 Mdot
.64097 .44467 Mdot
.31662 .5858 Mdot
.63446 .63192 Mdot
.49402 .27862 Mdot
.43879 .43477 Mdot
.45073 .71637 Mdot
.32512 .35532 Mdot
.46976 .39182 Mdot
.60203 .60659 Mdot
.64166 .64007 Mdot
.4809 .70085 Mdot
.2346 .58951 Mdot
.61537 .49802 Mdot
.29026 .58997 Mdot
.32886 .56816 Mdot
.32233 .57195 Mdot
.34161 .58998 Mdot
.58359 .38933 Mdot
.47033 .7149 Mdot
.32975 .57916 Mdot
.47079 .38298 Mdot
.46404 .38436 Mdot
.65119 .48084 Mdot
.7024 .42855 Mdot
.32684 .34024 Mdot
.63007 .50406 Mdot
.46052 .3488 Mdot
.63801 .66083 Mdot
.70197 .43591 Mdot
.62901 .5088 Mdot
.62895 .66151 Mdot
.63113 .66424 Mdot
.62386 .51023 Mdot
.69757 .4352 Mdot
.34705 .48272 Mdot
.34829 .35641 Mdot
.26545 .54332 Mdot
.60735 .64605 Mdot
.3933 .69704 Mdot
.36302 .50932 Mdot
.41299 .39427 Mdot
.63506 .45412 Mdot
.64689 .65323 Mdot
.34178 .55585 Mdot
.45311 .38216 Mdot
.62357 .49137 Mdot
.7131 .40702 Mdot
.63396 .47505 Mdot
.64385 .46121 Mdot
.31341 .53763 Mdot
.47901 .80854 Mdot
.28208 .5586 Mdot
.65907 .68676 Mdot
.63658 .48406 Mdot
.25021 .36846 Mdot
.60167 .62921 Mdot
.40057 .74296 Mdot
.30465 .34684 Mdot
.47535 .34769 Mdot
.62048 .6501 Mdot
.3375 .55823 Mdot
.44398 .71596 Mdot
.44265 .24311 Mdot
.31384 .58028 Mdot
.62135 .51358 Mdot
.64408 .46454 Mdot
.61862 .6276 Mdot
.30962 .55141 Mdot
.32303 .33321 Mdot
.32174 .57904 Mdot
.48844 .722 Mdot
.42609 .40382 Mdot
.27422 .69158 Mdot
.62057 .49483 Mdot
.30872 .58785 Mdot
.64012 .61136 Mdot
.70923 .41633 Mdot
.4238 .39957 Mdot
.27483 .6998 Mdot
.45895 .36658 Mdot
.4928 .72017 Mdot
.61663 .45148 Mdot
.34088 .35389 Mdot
.4361 .36721 Mdot
.45103 .4072 Mdot
.44499 .66137 Mdot
.44109 .36259 Mdot
.49743 .36044 Mdot
.298 .41116 Mdot
.28446 .56918 Mdot
.44816 .36567 Mdot
.63595 .62603 Mdot
.55691 .62634 Mdot
.44712 .39091 Mdot
.68411 .68962 Mdot
.46451 .25209 Mdot
.66117 .46002 Mdot
.69018 .44458 Mdot
.60511 .3352 Mdot
.42211 .38662 Mdot
.43693 .35222 Mdot
.42985 .40391 Mdot
.45238 .44098 Mdot
.62253 .64412 Mdot
.65494 .62552 Mdot
.71775 .4117 Mdot
.43449 .28817 Mdot
.70405 .40319 Mdot
.46052 .72303 Mdot
.30171 .32389 Mdot
.60393 .50023 Mdot
.30948 .58248 Mdot
.46082 .36983 Mdot
.64663 .61554 Mdot
.42389 .39128 Mdot
.3128 .33202 Mdot
.62905 .62846 Mdot
.64565 .65692 Mdot
.66629 .65836 Mdot
.72497 .36889 Mdot
.29799 .57663 Mdot
.40376 .38942 Mdot
.70589 .37969 Mdot
.64842 .49634 Mdot
.53975 .29322 Mdot
.29399 .57337 Mdot
.30307 .58579 Mdot
.33066 .59973 Mdot
.40426 .38581 Mdot
.40124 .39284 Mdot
.48116 .72773 Mdot
.3666 .51834 Mdot
.47416 .67609 Mdot
.61712 .64622 Mdot
.63318 .67247 Mdot
.42262 .38993 Mdot
.75104 .37529 Mdot
.71716 .39539 Mdot
.62323 .6047 Mdot
.61005 .47206 Mdot
.71016 .41869 Mdot
.41787 .36852 Mdot
.61353 .63334 Mdot
.70739 .37671 Mdot
.23397 .58931 Mdot
.32509 .67881 Mdot
.70842 .41747 Mdot
.61938 .49762 Mdot
.33295 .45463 Mdot
.61059 .34658 Mdot
.74254 .3991 Mdot
.454 .71875 Mdot
.50467 .35757 Mdot
.60805 .47747 Mdot
.70036 .42207 Mdot
.61678 .35844 Mdot
.62493 .63452 Mdot
.61972 .49974 Mdot
.74728 .41676 Mdot
.44151 .43384 Mdot
.70173 .41931 Mdot
.30553 .58742 Mdot
.27721 .58405 Mdot
.42812 .37442 Mdot
.31388 .35187 Mdot
.4421 .70138 Mdot
.63354 .59443 Mdot
.65028 .61874 Mdot
.37098 .54679 Mdot
.48844 .27532 Mdot
.62664 .61981 Mdot
.50262 .34261 Mdot
.69343 .4241 Mdot
.4722 .38168 Mdot
.64334 .44093 Mdot
.34305 .35566 Mdot
.6862 .44564 Mdot
.70868 .41692 Mdot
.44847 .71521 Mdot
.47253 .71058 Mdot
.46677 .68248 Mdot
.62353 .6213 Mdot
.50501 .31124 Mdot
.65659 .63251 Mdot
.2833 .40331 Mdot
.72675 .38754 Mdot
.72798 .70805 Mdot
.40156 .40902 Mdot
.45859 .34798 Mdot
.34049 .34081 Mdot
.64744 .45831 Mdot
.42641 .38783 Mdot
.47116 .72419 Mdot
.62509 .59379 Mdot
.52803 .71268 Mdot
.3083 .5416 Mdot
.28646 .40521 Mdot
.64088 .65721 Mdot
.60532 .47066 Mdot
.71142 .39477 Mdot
.60846 .31874 Mdot
.72712 .41838 Mdot
.6486 .66527 Mdot
.46676 .34142 Mdot
.33425 .54308 Mdot
.77325 .67815 Mdot
.45569 .37285 Mdot
.62551 .61203 Mdot
.60665 .58324 Mdot
.33351 .3584 Mdot
.52865 .42686 Mdot
.53233 .70411 Mdot
.49581 .28987 Mdot
.72009 .36822 Mdot
.65419 .48342 Mdot
.47663 .25417 Mdot
.62087 .63861 Mdot
.61871 .59731 Mdot
.74242 .397 Mdot
.276 .57098 Mdot
.335 .58861 Mdot
.35199 .49088 Mdot
.47525 .72628 Mdot
.48233 .35036 Mdot
.61496 .63201 Mdot
.27957 .57278 Mdot
.49889 .32325 Mdot
.46383 .68907 Mdot
.61626 .60995 Mdot
.46801 .36571 Mdot
.43444 .37039 Mdot
.7054 .40448 Mdot
.63319 .44037 Mdot
.65562 .46483 Mdot
.39871 .73722 Mdot
.49148 .311 Mdot
.30421 .3215 Mdot
.47063 .348 Mdot
.32914 .55279 Mdot
.64044 .49746 Mdot
.71754 .39812 Mdot
.4121 .40394 Mdot
.42979 .42219 Mdot
.34021 .55932 Mdot
.45426 .68437 Mdot
.63199 .48574 Mdot
.46018 .28514 Mdot
.46532 .36521 Mdot
.41867 .38691 Mdot
.30877 .32588 Mdot
.39835 .41704 Mdot
.6067 .60557 Mdot
.28726 .54872 Mdot
.70251 .38431 Mdot
.31432 .569 Mdot
.6997 .70414 Mdot
.30329 .34202 Mdot
.50533 .34728 Mdot
.30831 .53363 Mdot
.3087 .56122 Mdot
.49256 .71919 Mdot
.46683 .71202 Mdot
.64352 .54893 Mdot
.44661 .39572 Mdot
.61291 .47149 Mdot
.32857 .57616 Mdot
.63653 .59829 Mdot
.7029 .40414 Mdot
.69186 .705 Mdot
.47543 .35682 Mdot
.61788 .6354 Mdot
.64362 .47842 Mdot
.31023 .53924 Mdot
.63338 .65808 Mdot
.65201 .47461 Mdot
.73542 .3876 Mdot
.48612 .38423 Mdot
.64038 .54776 Mdot
.61918 .48476 Mdot
.45134 .39482 Mdot
.28745 .31987 Mdot
.31742 .35347 Mdot
.65432 .44881 Mdot
.6132 .57699 Mdot
.62219 .48505 Mdot
.29631 .59801 Mdot
.32577 .35859 Mdot
.63256 .59802 Mdot
.36463 .51274 Mdot
.3047 .34616 Mdot
.61626 .49077 Mdot
.29464 .57932 Mdot
.70202 .70266 Mdot
.29614 .52685 Mdot
.60591 .35718 Mdot
.45399 .38576 Mdot
.6138 .62587 Mdot
.71372 .40319 Mdot
.48691 .72805 Mdot
.50756 .73328 Mdot
.39666 .69606 Mdot
.61661 .65885 Mdot
.46323 .36954 Mdot
.3244 .58238 Mdot
.46241 .70517 Mdot
.33834 .60961 Mdot
.65125 .6363 Mdot
.64277 .63397 Mdot
.33995 .34137 Mdot
.70335 .40227 Mdot
.40015 .41002 Mdot
.63952 .60255 Mdot
.66347 .69278 Mdot
.3015 .41325 Mdot
.70797 .37574 Mdot
.31024 .32327 Mdot
.65261 .4422 Mdot
.45063 .40286 Mdot
.31096 .42732 Mdot
.63786 .46188 Mdot
.30996 .542 Mdot
.43698 .36013 Mdot
.52544 .8117 Mdot
.60136 .63217 Mdot
.49547 .2901 Mdot
.53608 .68876 Mdot
.4788 .71357 Mdot
.62777 .65116 Mdot
.45962 .37809 Mdot
.69091 .70501 Mdot
.72598 .404 Mdot
.34102 .33192 Mdot
.61499 .48359 Mdot
.37375 .57061 Mdot
.48265 .68874 Mdot
.74874 .40926 Mdot
.48611 .72853 Mdot
.4615 .67977 Mdot
.23773 .593 Mdot
.42745 .37592 Mdot
.63929 .6517 Mdot
.63981 .62415 Mdot
.64291 .44266 Mdot
.65066 .69265 Mdot
.33688 .59094 Mdot
.52153 .80858 Mdot
.44377 .41779 Mdot
.46024 .35926 Mdot
.62422 .51387 Mdot
.61828 .46753 Mdot
.6864 .7001 Mdot
.4388 .36289 Mdot
.28717 .56992 Mdot
.64629 .60998 Mdot
.61696 .6175 Mdot
.30744 .34323 Mdot
.47215 .71108 Mdot
.7287 .41775 Mdot
.63816 .63638 Mdot
.54604 .30404 Mdot
.42267 .39328 Mdot
.44758 .72179 Mdot
.63631 .63592 Mdot
.84036 .59252 Mdot
.4732 .81734 Mdot
.28071 .56285 Mdot
.46341 .40245 Mdot
.30171 .59763 Mdot
.70385 .41752 Mdot
.65871 .6492 Mdot
.47905 .73519 Mdot
.63633 .48124 Mdot
.54663 .68554 Mdot
.61792 .62149 Mdot
.30738 .5721 Mdot
.42372 .37801 Mdot
.32504 .37746 Mdot
.46759 .36271 Mdot
.57308 .39905 Mdot
.71658 .36582 Mdot
.50827 .73287 Mdot
.49574 .71142 Mdot
.46229 .40321 Mdot
.71178 .37444 Mdot
.64898 .66847 Mdot
.62712 .62842 Mdot
.28238 .70208 Mdot
.64437 .46194 Mdot
.65693 .66579 Mdot
.44848 .39591 Mdot
.66629 .6615 Mdot
.32912 .45159 Mdot
.47851 .71151 Mdot
.48622 .37067 Mdot
.61104 .63003 Mdot
.28559 .53315 Mdot
.5007 .29495 Mdot
.43889 .39269 Mdot
.63066 .45146 Mdot
.46266 .70834 Mdot
.28166 .39937 Mdot
.60374 .60323 Mdot
.48005 .36722 Mdot
.46181 .71969 Mdot
.76318 .37023 Mdot
.5186 .74356 Mdot
.29688 .57607 Mdot
.62913 .6131 Mdot
.48117 .68911 Mdot
.63784 .48992 Mdot
.6963 .39037 Mdot
.65362 .65967 Mdot
.6098 .62466 Mdot
.31508 .34047 Mdot
.61452 .46013 Mdot
.7446 .395 Mdot
.32956 .55844 Mdot
.4557 .68846 Mdot
.30997 .33427 Mdot
.55172 .30514 Mdot
.40094 .39532 Mdot
.45952 .67814 Mdot
.25749 .37596 Mdot
.47407 .34138 Mdot
.47718 .35551 Mdot
.32706 .37635 Mdot
.29209 .59495 Mdot
.33735 .56484 Mdot
.47987 .29661 Mdot
.3236 .33931 Mdot
.50736 .33072 Mdot
.30465 .57829 Mdot
.30664 .56893 Mdot
.50548 .33039 Mdot
.314 .33764 Mdot
.35462 .4889 Mdot
.46615 .70477 Mdot
.47737 .71394 Mdot
.32139 .5705 Mdot
.3411 .34208 Mdot
.44551 .68432 Mdot
.35246 .60547 Mdot
.64733 .63797 Mdot
.46774 .25506 Mdot
.31457 .56463 Mdot
.50436 .29137 Mdot
.45705 .69943 Mdot
.56153 .29581 Mdot
.46279 .25134 Mdot
.43186 .35451 Mdot
.43178 .37034 Mdot
.72643 .37332 Mdot
.63659 .47562 Mdot
.62411 .51037 Mdot
.46786 .68237 Mdot
.39751 .40869 Mdot
.28985 .56394 Mdot
.39853 .40245 Mdot
.61417 .35116 Mdot
.56777 .29296 Mdot
.46619 .40405 Mdot
.30076 .56827 Mdot
.29758 .55706 Mdot
.6298 .67367 Mdot
.62353 .58541 Mdot
.5026 .337 Mdot
.46585 .71012 Mdot
.31549 .58974 Mdot
.47729 .67926 Mdot
.62144 .63739 Mdot
.64163 .65373 Mdot
.64511 .49382 Mdot
.62049 .50097 Mdot
.62823 .64552 Mdot
.68433 .69044 Mdot
.54943 .3027 Mdot
.36745 .52374 Mdot
.26958 .38515 Mdot
.59662 .3152 Mdot
.35564 .39885 Mdot
.71445 .40514 Mdot
.70207 .43649 Mdot
.46616 .72252 Mdot
.44502 .41154 Mdot
.44482 .35396 Mdot
.62403 .47775 Mdot
.45445 .71052 Mdot
.71681 .38603 Mdot
.47896 .71238 Mdot
.69518 .3928 Mdot
.63493 .6015 Mdot
.46503 .37159 Mdot
.4516 .34624 Mdot
.49209 .71846 Mdot
.63794 .67263 Mdot
.61215 .63488 Mdot
.71791 .40268 Mdot
.60051 .32121 Mdot
.61863 .62992 Mdot
.31333 .56392 Mdot
.22959 .63467 Mdot
.63788 .46324 Mdot
.45433 .38101 Mdot
.60543 .33214 Mdot
.32283 .35834 Mdot
.64689 .49851 Mdot
.63132 .48604 Mdot
.28629 .41034 Mdot
.4103 .38397 Mdot
.30147 .70367 Mdot
.63205 .50707 Mdot
.33491 .60094 Mdot
.63636 .65083 Mdot
.63478 .50846 Mdot
.65639 .44308 Mdot
.67906 .43439 Mdot
.63126 .5118 Mdot
.33466 .58297 Mdot
.30797 .60083 Mdot
.33178 .34285 Mdot
.25 .33818 Mdot
.69525 .39774 Mdot
.72106 .39105 Mdot
.60543 .61386 Mdot
.40734 .67822 Mdot
.3709 .35752 Mdot
.72682 .39272 Mdot
.25225 .55196 Mdot
.33745 .33542 Mdot
.32987 .35167 Mdot
.32529 .35009 Mdot
.32995 .60917 Mdot
.46832 .33646 Mdot
.6035 .61357 Mdot
.30622 .57324 Mdot
.33452 .34145 Mdot
.39774 .39734 Mdot
.29122 .5699 Mdot
.45864 .68466 Mdot
.31264 .31384 Mdot
.32036 .58344 Mdot
.4432 .24149 Mdot
.45379 .69628 Mdot
.43496 .41766 Mdot
.74035 .67647 Mdot
.85057 .57323 Mdot
.47908 .70703 Mdot
.61779 .60915 Mdot
.61553 .63635 Mdot
.62721 .62439 Mdot
.33599 .56546 Mdot
.62173 .67063 Mdot
.30855 .54893 Mdot
.68484 .7023 Mdot
.44357 .28602 Mdot
.69722 .40077 Mdot
.649 .68921 Mdot
.32143 .57205 Mdot
.30101 .41965 Mdot
.6511 .18355 Mdot
.47888 .37024 Mdot
.47894 .73672 Mdot
.72937 .40533 Mdot
.49776 .28379 Mdot
.72448 .37818 Mdot
.62646 .65563 Mdot
.45731 .28295 Mdot
.42219 .39174 Mdot
.31851 .68547 Mdot
.71204 .40221 Mdot
.30752 .56799 Mdot
.31607 .34439 Mdot
.61449 .57409 Mdot
.72471 .40386 Mdot
.70621 .39895 Mdot
.43326 .38816 Mdot
.32135 .60637 Mdot
.6204 .65238 Mdot
.45358 .70668 Mdot
.6742 .6941 Mdot
.53345 .34606 Mdot
.40967 .38653 Mdot
.48372 .35618 Mdot
.5053 .30146 Mdot
.69126 .70294 Mdot
.47045 .70573 Mdot
.60616 .3706 Mdot
.60341 .59929 Mdot
.61402 .34373 Mdot
.28623 .53568 Mdot
.64748 .6894 Mdot
.63492 .46245 Mdot
.65168 .48053 Mdot
.44757 .37847 Mdot
.66035 .19419 Mdot
.53818 .41912 Mdot
.44382 .6884 Mdot
.62841 .46856 Mdot
.62436 .67417 Mdot
.34201 .5774 Mdot
.74338 .42266 Mdot
.32674 .33783 Mdot
.45172 .70381 Mdot
.62289 .62889 Mdot
.70011 .22906 Mdot
.73167 .37255 Mdot
.49171 .28764 Mdot
.46681 .38287 Mdot
.44644 .3809 Mdot
.46888 .68807 Mdot
.4408 .70535 Mdot
.28133 .39484 Mdot
.65755 .43485 Mdot
.26583 .69027 Mdot
.4613 .66269 Mdot
.71623 .24161 Mdot
.61524 .47052 Mdot
.29657 .55247 Mdot
.61734 .51018 Mdot
.44246 .70758 Mdot
.42983 .36485 Mdot
.31397 .60378 Mdot
.6452 .47592 Mdot
.25209 .57801 Mdot
.32459 .35438 Mdot
.54537 .30206 Mdot
.44164 .37493 Mdot
.32331 .59761 Mdot
.30294 .57589 Mdot
.29679 .59128 Mdot
.64801 .47084 Mdot
.47232 .35153 Mdot
.47869 .36373 Mdot
.48228 .35466 Mdot
.28347 .39496 Mdot
.46113 .37268 Mdot
.33431 .54102 Mdot
.48389 .27237 Mdot
.5329 .81755 Mdot
.4518 .3465 Mdot
.47758 .68664 Mdot
.4438 .37773 Mdot
.73357 .36684 Mdot
.47765 .39085 Mdot
.31349 .35398 Mdot
.46929 .70091 Mdot
.3973 .41982 Mdot
.73754 .35657 Mdot
.41179 .37624 Mdot
.69109 .40111 Mdot
.41289 .7682 Mdot
.60025 .37338 Mdot
.32229 .43772 Mdot
.32154 .57685 Mdot
.6534 .63661 Mdot
.43833 .68866 Mdot
.63916 .66513 Mdot
.35023 .35348 Mdot
.60651 .4998 Mdot
.72494 .70851 Mdot
.55496 .30338 Mdot
.43295 .36278 Mdot
.62964 .45834 Mdot
.2893 .57593 Mdot
.60107 .62759 Mdot
.36111 .41928 Mdot
.33994 .33904 Mdot
.73102 .40879 Mdot
.73061 .38235 Mdot
.59837 .47203 Mdot
.28538 .58421 Mdot
.32646 .45094 Mdot
.46872 .68942 Mdot
.62162 .61995 Mdot
.68349 .41147 Mdot
.25993 .5408 Mdot
.44272 .71282 Mdot
.68372 .69836 Mdot
.48391 .69185 Mdot
.46279 .34619 Mdot
.62777 .51094 Mdot
.36232 .50155 Mdot
.62093 .47485 Mdot
.40557 .4025 Mdot
.60991 .62875 Mdot
.64041 .46157 Mdot
.71405 .37592 Mdot
.47455 .6818 Mdot
.63962 .65959 Mdot
.42119 .38265 Mdot
.30229 .57992 Mdot
.38738 .25182 Mdot
.59543 .63404 Mdot
.30686 .34671 Mdot
.30605 .34597 Mdot
.37326 .54327 Mdot
.66023 .45208 Mdot
.50119 .75819 Mdot
.3303 .36004 Mdot
.39822 .68879 Mdot
.74894 .38963 Mdot
.71212 .70978 Mdot
.65502 .63078 Mdot
.62962 .63761 Mdot
.41998 .37056 Mdot
.64595 .60809 Mdot
.50348 .34472 Mdot
.61565 .57513 Mdot
.3944 .73466 Mdot
.43098 .34927 Mdot
.63065 .6308 Mdot
.62758 .50711 Mdot
.4325 .39941 Mdot
.28445 .56504 Mdot
.66102 .64643 Mdot
.43081 .35519 Mdot
.70588 .69209 Mdot
.49226 .71987 Mdot
.64913 .47217 Mdot
.5114 .31847 Mdot
.46219 .70053 Mdot
.33647 .57875 Mdot
.50223 .36521 Mdot
.72897 .3972 Mdot
.30206 .55342 Mdot
.60377 .51596 Mdot
.70317 .40038 Mdot
.49444 .27668 Mdot
.32152 .5606 Mdot
.6323 .46414 Mdot
.73382 .38629 Mdot
.68891 .44166 Mdot
.62762 .63556 Mdot
.60567 .58483 Mdot
.62012 .48896 Mdot
.41793 .3897 Mdot
.60635 .65998 Mdot
.48237 .7017 Mdot
.45382 .38913 Mdot
.61472 .62684 Mdot
.63694 .46776 Mdot
.47542 .36762 Mdot
.32457 .33994 Mdot
.30592 .41976 Mdot
.66211 .46183 Mdot
.69993 .39087 Mdot
.29 .58592 Mdot
.4815 .36507 Mdot
.69299 .40477 Mdot
.62937 .67994 Mdot
.47292 .38366 Mdot
.30263 .5894 Mdot
.24215 .56795 Mdot
.6329 .59289 Mdot
.45211 .6866 Mdot
.63985 .62176 Mdot
.68635 .40982 Mdot
.6473 .17949 Mdot
.63484 .50399 Mdot
.34647 .34691 Mdot
.49301 .37259 Mdot
.65502 .63746 Mdot
.29857 .57469 Mdot
.24939 .68176 Mdot
.47855 .3906 Mdot
.47006 .38569 Mdot
.44797 .38363 Mdot
.67621 .69773 Mdot
.34052 .58133 Mdot
.45131 .38247 Mdot
.69727 .43259 Mdot
.48784 .36 Mdot
.71177 .41309 Mdot
.72943 .69432 Mdot
.65349 .47651 Mdot
.24655 .36412 Mdot
.6464 .47561 Mdot
.63554 .63067 Mdot
.44352 .24078 Mdot
.507 .31927 Mdot
.65296 .56304 Mdot
.33721 .58024 Mdot
.26541 .54414 Mdot
.64146 .65113 Mdot
.70197 .70402 Mdot
.32804 .33585 Mdot
.3178 .34329 Mdot
.42712 .3985 Mdot
.62677 .65575 Mdot
.61768 .59317 Mdot
.60816 .4987 Mdot
.62947 .45923 Mdot
.43257 .41799 Mdot
.64078 .6096 Mdot
.46381 .37243 Mdot
.33806 .35326 Mdot
.44044 .70885 Mdot
.28296 .57135 Mdot
.46914 .73452 Mdot
.45187 .7248 Mdot
.35925 .40591 Mdot
.49059 .31216 Mdot
.47383 .72663 Mdot
.44715 .70703 Mdot
.67847 .69595 Mdot
.43159 .43137 Mdot
.70362 .41628 Mdot
.53935 .41981 Mdot
.64274 .66683 Mdot
.46869 .35245 Mdot
.34047 .58797 Mdot
.65855 .48175 Mdot
.23615 .66507 Mdot
.6835 .29844 Mdot
.32345 .32637 Mdot
.59893 .62557 Mdot
.61856 .48515 Mdot
.61741 .47719 Mdot
.61123 .3465 Mdot
.46103 .37423 Mdot
.63451 .59487 Mdot
.4403 .43369 Mdot
.45846 .66219 Mdot
.68799 .6988 Mdot
.2865 .58716 Mdot
.44802 .37518 Mdot
.32332 .55065 Mdot
.45512 .67629 Mdot
.69688 .41163 Mdot
.72673 .37015 Mdot
.41657 .37074 Mdot
.30479 .3477 Mdot
.39761 .68912 Mdot
.32373 .34402 Mdot
.31435 .33315 Mdot
.62376 .48642 Mdot
.30824 .32374 Mdot
.4804 .36908 Mdot
.42889 .35195 Mdot
.64928 .49507 Mdot
.45901 .7309 Mdot
.39926 .43704 Mdot
.61624 .48934 Mdot
.48538 .38638 Mdot
.45688 .67484 Mdot
.32621 .34248 Mdot
.47777 .69323 Mdot
.69092 .70073 Mdot
.48242 .72469 Mdot
.70482 .3823 Mdot
.66853 .69394 Mdot
.27392 .38846 Mdot
.32296 .5831 Mdot
.47168 .71456 Mdot
.73579 .38896 Mdot
.47963 .6932 Mdot
.64709 .66295 Mdot
.45092 .66051 Mdot
.35682 .60587 Mdot
.54329 .30208 Mdot
.35669 .39473 Mdot
.45341 .66427 Mdot
.62597 .58915 Mdot
.32238 .57112 Mdot
.40237 .68483 Mdot
.49777 .37006 Mdot
.73202 .37082 Mdot
.44517 .38004 Mdot
.46877 .67951 Mdot
.61261 .66611 Mdot
.32112 .43911 Mdot
.70393 .3845 Mdot
.278 .39771 Mdot
.64609 .61587 Mdot
.48886 .34685 Mdot
.49847 .71769 Mdot
.49286 .75735 Mdot
.49467 .71304 Mdot
.44409 .27993 Mdot
.60848 .47799 Mdot
.65385 .43424 Mdot
.30781 .5548 Mdot
.62098 .46246 Mdot
.76623 .34685 Mdot
.39294 .71024 Mdot
.28875 .55048 Mdot
.64803 .68374 Mdot
.41726 .3921 Mdot
.31289 .32086 Mdot
.62801 .50296 Mdot
.31916 .59389 Mdot
.3085 .3265 Mdot
.64845 .48869 Mdot
.48198 .27006 Mdot
.29185 .58995 Mdot
.65209 .66919 Mdot
.44482 .39673 Mdot
.48951 .73289 Mdot
.47839 .67603 Mdot
.61894 .51257 Mdot
.48334 .73108 Mdot
.48369 .38798 Mdot
.31798 .56105 Mdot
.331 .34188 Mdot
.71461 .41294 Mdot
.35402 .49553 Mdot
.6511 .49674 Mdot
.67555 .42147 Mdot
.46222 .39043 Mdot
.64061 .65231 Mdot
.54615 .68809 Mdot
.4642 .39842 Mdot
.30677 .57652 Mdot
.49646 .36543 Mdot
.30806 .32518 Mdot
.32078 .3438 Mdot
.6214 .62016 Mdot
.50251 .29421 Mdot
.46302 .37186 Mdot
.45012 .69778 Mdot
.5427 .37931 Mdot
.41391 .41241 Mdot
.6965 .43105 Mdot
.314 .35429 Mdot
.49313 .69161 Mdot
.37109 .53767 Mdot
.63856 .65019 Mdot
.29101 .56025 Mdot
.34646 .60868 Mdot
.33555 .57534 Mdot
.29157 .52501 Mdot
.32923 .35997 Mdot
.28627 .70469 Mdot
.32844 .45105 Mdot
.34803 .38851 Mdot
.34496 .56188 Mdot
.52818 .73814 Mdot
.28861 .54981 Mdot
.33665 .57899 Mdot
.23845 .64602 Mdot
.33828 .58463 Mdot
.42018 .38933 Mdot
.49423 .35373 Mdot
.45621 .41131 Mdot
.67377 .69812 Mdot
.46894 .36213 Mdot
.63895 .50834 Mdot
.72955 .40722 Mdot
.27637 .56938 Mdot
.63412 .48239 Mdot
.49917 .28211 Mdot
.6038 .50835 Mdot
.43147 .3881 Mdot
.46901 .37398 Mdot
.32369 .34869 Mdot
.57604 .29151 Mdot
.67204 .69823 Mdot
.32752 .60168 Mdot
.40702 .41133 Mdot
.51754 .74437 Mdot
.44337 .3958 Mdot
.48305 .38421 Mdot
.44888 .34257 Mdot
.63934 .65177 Mdot
.33488 .6103 Mdot
.61177 .4941 Mdot
.35539 .49657 Mdot
.45414 .36748 Mdot
.62462 .5248 Mdot
.70837 .42361 Mdot
.45897 .37932 Mdot
.32679 .6058 Mdot
.30788 .32611 Mdot
.33584 .55315 Mdot
.31775 .55682 Mdot
.4728 .38342 Mdot
.27866 .57429 Mdot
.3367 .56096 Mdot
.31823 .34272 Mdot
.59835 .62887 Mdot
.39958 .74081 Mdot
.42794 .39203 Mdot
.70698 .38246 Mdot
.43475 .36549 Mdot
.69977 .41779 Mdot
.63301 .51031 Mdot
.62077 .48426 Mdot
.4958 .44584 Mdot
.62226 .59628 Mdot
.73156 .41035 Mdot
.6647 .69539 Mdot
.36041 .34537 Mdot
.24939 .56321 Mdot
.44773 .66064 Mdot
.60472 .58372 Mdot
.62223 .48381 Mdot
.57666 .39306 Mdot
.53383 .35242 Mdot
.47857 .72967 Mdot
.30428 .53625 Mdot
.40486 .44311 Mdot
.62867 .45744 Mdot
.65139 .66992 Mdot
.64052 .62652 Mdot
.39285 .70811 Mdot
.23848 .64429 Mdot
.44739 .34856 Mdot
.6312 .45655 Mdot
.28994 .32666 Mdot
.63728 .47481 Mdot
.61119 .49988 Mdot
.61071 .61804 Mdot
.47407 .36529 Mdot
.48299 .26384 Mdot
.61753 .64038 Mdot
.71445 .39206 Mdot
.31151 .54236 Mdot
.69279 .40017 Mdot
.33426 .67175 Mdot
.27927 .39297 Mdot
.6255 .64601 Mdot
.65305 .46647 Mdot
.46683 .35534 Mdot
.32153 .60764 Mdot
.34007 .60745 Mdot
.28323 .56364 Mdot
.7212 .41138 Mdot
.64613 .61092 Mdot
.71421 .70627 Mdot
.42434 .37948 Mdot
.30682 .56187 Mdot
.68057 .41617 Mdot
.43602 .36923 Mdot
.46918 .71172 Mdot
.30766 .33043 Mdot
.31127 .56585 Mdot
.34526 .34461 Mdot
.30919 .55464 Mdot
.63849 .62749 Mdot
.42589 .36266 Mdot
.41997 .39578 Mdot
.59828 .37609 Mdot
.71736 .38543 Mdot
.33947 .55511 Mdot
.49264 .31443 Mdot
.44955 .40333 Mdot
.60877 .34153 Mdot
.46455 .37829 Mdot
.35521 .39188 Mdot
.62246 .45486 Mdot
.6451 .49572 Mdot
.49439 .3717 Mdot
.43732 .39139 Mdot
.33987 .6064 Mdot
.33033 .45061 Mdot
.28097 .39227 Mdot
.45511 .67849 Mdot
.28609 .55151 Mdot
.61924 .64544 Mdot
.66219 .65338 Mdot
.63146 .67075 Mdot
.68499 .40999 Mdot
.32862 .34098 Mdot
.43915 .35554 Mdot
.44679 .68523 Mdot
.73038 .39375 Mdot
.29988 .56314 Mdot
.70042 .40746 Mdot
.49858 .30379 Mdot
.71434 .37739 Mdot
.60898 .5062 Mdot
.46717 .81433 Mdot
.33741 .35352 Mdot
.70628 .39191 Mdot
.28569 .57742 Mdot
.54941 .41118 Mdot
.40431 .37403 Mdot
.29781 .41581 Mdot
.72982 .41024 Mdot
.6387 .68444 Mdot
.46021 .39089 Mdot
.42631 .29621 Mdot
.47236 .68656 Mdot
.6981 .3885 Mdot
.48571 .69509 Mdot
.3149 .32859 Mdot
.26803 .54263 Mdot
.31214 .57461 Mdot
.44299 .66074 Mdot
.48982 .37603 Mdot
.69926 .38684 Mdot
.6265 .64239 Mdot
.43595 .4305 Mdot
.6816 .70218 Mdot
.61468 .52933 Mdot
.60932 .35313 Mdot
.60491 .60877 Mdot
.40141 .42792 Mdot
.48807 .71908 Mdot
.40187 .40632 Mdot
.34332 .35316 Mdot
.44488 .40415 Mdot
.61399 .6442 Mdot
.63042 .6379 Mdot
.71018 .70894 Mdot
.40818 .38756 Mdot
.43476 .35112 Mdot
.37234 .58028 Mdot
.64264 .60589 Mdot
.33414 .57234 Mdot
.31931 .59637 Mdot
.61652 .61114 Mdot
.32679 .54106 Mdot
.7048 .40029 Mdot
.4732 .2871 Mdot
.4875 .71957 Mdot
.49526 .70136 Mdot
.62754 .64662 Mdot
.60638 .632 Mdot
.64089 .65356 Mdot
.31228 .32681 Mdot
.3242 .56118 Mdot
.49283 .33872 Mdot
.436 .38195 Mdot
.40122 .39076 Mdot
.29225 .59332 Mdot
.48281 .38713 Mdot
.40316 .36191 Mdot
.71825 .41585 Mdot
.63802 .63447 Mdot
.47313 .67689 Mdot
.38834 .25608 Mdot
.449 .69172 Mdot
.48617 .366 Mdot
.39383 .72773 Mdot
.30472 .53696 Mdot
.72532 .37616 Mdot
.31686 .3541 Mdot
.71779 .37331 Mdot
.44002 .70766 Mdot
.37152 .57652 Mdot
.49099 .27572 Mdot
.4799 .3382 Mdot
.50288 .30588 Mdot
.76745 .60901 Mdot
.34982 .60399 Mdot
.45658 .69243 Mdot
.32758 .35619 Mdot
.60176 .50498 Mdot
.29796 .3471 Mdot
.4233 .36771 Mdot
.40538 .40991 Mdot
.41916 .30104 Mdot
.4914 .36258 Mdot
.27998 .56348 Mdot
.50354 .3305 Mdot
.65129 .45899 Mdot
.42496 .40162 Mdot
.30104 .69964 Mdot
.45694 .3627 Mdot
.44353 .34881 Mdot
.45609 .35008 Mdot
.44562 .40567 Mdot
.28181 .58545 Mdot
.32802 .34979 Mdot
.44997 .68816 Mdot
.47317 .28548 Mdot
.48739 .71713 Mdot
.63114 .65178 Mdot
.66148 .46994 Mdot
.30787 .60362 Mdot
.71982 .37254 Mdot
.43325 .64001 Mdot
.42973 .29337 Mdot
.63069 .67364 Mdot
.59046 .38544 Mdot
.7335 .41341 Mdot
.61633 .50524 Mdot
.68773 .40311 Mdot
.61075 .63005 Mdot
.47515 .70984 Mdot
.46871 .34124 Mdot
.33075 .574 Mdot
.31767 .5866 Mdot
.43317 .40112 Mdot
.40707 .75374 Mdot
.47938 .67696 Mdot
.65095 .68969 Mdot
.45256 .34729 Mdot
.48599 .37113 Mdot
.32964 .55022 Mdot
.60449 .64778 Mdot
.50854 .32962 Mdot
.72127 .40262 Mdot
.45144 .39255 Mdot
.64241 .45613 Mdot
.49962 .30396 Mdot
.45262 .68307 Mdot
.63778 .46573 Mdot
.45552 .35785 Mdot
.48763 .30805 Mdot
.33659 .32729 Mdot
.64147 .43898 Mdot
.61859 .5814 Mdot
.47155 .38413 Mdot
.42909 .39665 Mdot
.29196 .59039 Mdot
.48744 .72223 Mdot
.29799 .57586 Mdot
.36739 .59633 Mdot
.62114 .48401 Mdot
.49376 .71804 Mdot
.44748 .40479 Mdot
.47018 .6664 Mdot
.30678 .33318 Mdot
.42776 .38471 Mdot
.45721 .6909 Mdot
.31823 .55417 Mdot
.26841 .6885 Mdot
.39936 .43754 Mdot
.3134 .33131 Mdot
.43729 .36437 Mdot
.6739 .69422 Mdot
.65806 .48335 Mdot
.487 .34248 Mdot
.31666 .58898 Mdot
.43384 .37113 Mdot
.4435 .68294 Mdot
.69621 .4078 Mdot
.30894 .57902 Mdot
.6009 .61673 Mdot
.632 .62146 Mdot
.62604 .58586 Mdot
.6078 .50386 Mdot
.30753 .32461 Mdot
.29316 .58839 Mdot
.31088 .59586 Mdot
.50337 .31399 Mdot
.63525 .63073 Mdot
.71051 .40805 Mdot
.41615 .39759 Mdot
.63704 .45448 Mdot
.49428 .73657 Mdot
.24517 .36295 Mdot
.48797 .27827 Mdot
.68503 .41863 Mdot
.54193 .36302 Mdot
.62621 .4846 Mdot
.47561 .3544 Mdot
.69947 .38696 Mdot
.61498 .61527 Mdot
.32987 .32142 Mdot
.74855 .39436 Mdot
.63297 .68451 Mdot
.61642 .66183 Mdot
.46686 .66674 Mdot
.61547 .5775 Mdot
.70417 .37972 Mdot
.63144 .50663 Mdot
.31402 .58321 Mdot
.46141 .37678 Mdot
.6231 .49638 Mdot
.64516 .6423 Mdot
.60932 .48152 Mdot
.46895 .34477 Mdot
.32523 .54618 Mdot
.64304 .664 Mdot
.42393 .38826 Mdot
.33412 .35917 Mdot
.3054 .41872 Mdot
.60048 .63786 Mdot
.50221 .3495 Mdot
.7501 .41375 Mdot
.62535 .66634 Mdot
.61217 .64148 Mdot
.47213 .38479 Mdot
.74036 .3782 Mdot
.44953 .37119 Mdot
.47142 .70994 Mdot
.50861 .29833 Mdot
.49223 .7183 Mdot
.61312 .34198 Mdot
.44928 .39887 Mdot
.45047 .41131 Mdot
.24905 .5675 Mdot
.7584 .35522 Mdot
.59888 .31535 Mdot
.47958 .36089 Mdot
.34363 .57742 Mdot
.50508 .29251 Mdot
.54021 .30166 Mdot
.35438 .60636 Mdot
.69464 .41508 Mdot
.46913 .68295 Mdot
.4149 .39296 Mdot
.30767 .69635 Mdot
.71017 .41231 Mdot
.61148 .34425 Mdot
.43528 .41554 Mdot
.30357 .5696 Mdot
.43746 .35518 Mdot
.31665 .57832 Mdot
.4485 .35847 Mdot
.31686 .43188 Mdot
.39805 .691 Mdot
.44363 .28082 Mdot
.62751 .5065 Mdot
.49319 .75701 Mdot
.35553 .3937 Mdot
.70709 .40308 Mdot
.34405 .35039 Mdot
.62605 .47881 Mdot
.47921 .71225 Mdot
.43682 .66141 Mdot
.64196 .65302 Mdot
.45812 .71062 Mdot
.29705 .54938 Mdot
.61922 .67338 Mdot
.61707 .46688 Mdot
.30416 .31423 Mdot
.716 .37144 Mdot
.49392 .71845 Mdot
.45391 .38438 Mdot
.40007 .39736 Mdot
.67644 .69792 Mdot
.73343 .6911 Mdot
.30551 .53011 Mdot
.26882 .38519 Mdot
.37163 .57728 Mdot
.7184 .38893 Mdot
.60129 .64363 Mdot
.43999 .35746 Mdot
.47124 .36575 Mdot
.61313 .65897 Mdot
.32114 .608 Mdot
.73792 .3967 Mdot
.65468 .43392 Mdot
.44442 .68703 Mdot
.75944 .68892 Mdot
.31018 .58013 Mdot
.75863 .69059 Mdot
.71114 .70567 Mdot
.23532 .63965 Mdot
.60018 .31859 Mdot
.4653 .70258 Mdot
.75939 .69023 Mdot
.30422 .56596 Mdot
.48986 .35256 Mdot
.62555 .46985 Mdot
.60563 .49809 Mdot
.32014 .5461 Mdot
.63128 .65714 Mdot
.74128 .37816 Mdot
.41777 .37232 Mdot
.68694 .43565 Mdot
.33807 .60999 Mdot
.63794 .6035 Mdot
.64047 .47938 Mdot
.46411 .67495 Mdot
.43625 .36737 Mdot
.72216 .41167 Mdot
.46626 .7015 Mdot
.65212 .48038 Mdot
.45993 .28232 Mdot
.50243 .36463 Mdot
.30814 .34964 Mdot
.47305 .68854 Mdot
.50626 .32629 Mdot
.44535 .39343 Mdot
.48813 .71894 Mdot
.6048 .47049 Mdot
.4981 .75727 Mdot
.51157 .32927 Mdot
.39301 .71043 Mdot
.62964 .67723 Mdot
.61346 .57701 Mdot
.60196 .58071 Mdot
.6697 .6974 Mdot
.48229 .72007 Mdot
.62921 .493 Mdot
.73011 .7063 Mdot
.4884 .72154 Mdot
.46953 .39537 Mdot
.4153 .39227 Mdot
.43917 .43462 Mdot
.653 .47736 Mdot
.64754 .48083 Mdot
.36476 .51054 Mdot
.33485 .34964 Mdot
.63921 .48013 Mdot
.46171 .3835 Mdot
.31233 .60164 Mdot
.45548 .6978 Mdot
.77062 .31733 Mdot
.44077 .70004 Mdot
.32097 .31624 Mdot
.63689 .67114 Mdot
.62287 .67626 Mdot
.45886 .37802 Mdot
.5325 .6393 Mdot
.71111 .23724 Mdot
.41481 .39222 Mdot
.31716 .35431 Mdot
.61417 .3446 Mdot
.42704 .40184 Mdot
.28856 .54257 Mdot
.6464 .46064 Mdot
.30581 .5982 Mdot
.46284 .69836 Mdot
.69577 .41542 Mdot
.76704 .35905 Mdot
.46795 .68308 Mdot
.45871 .36408 Mdot
.6413 .50905 Mdot
.44658 .3819 Mdot
.48105 .3489 Mdot
.49063 .30388 Mdot
.69073 .42039 Mdot
.63799 .6566 Mdot
.71797 .37253 Mdot
.33759 .58249 Mdot
.26026 .37774 Mdot
.70605 .4057 Mdot
.43357 .43109 Mdot
.50767 .30634 Mdot
.72809 .69277 Mdot
.31647 .58648 Mdot
.70284 .41797 Mdot
.47376 .68459 Mdot
.53612 .31847 Mdot
.43469 .42569 Mdot
.45279 .70493 Mdot
.47557 .34855 Mdot
.31803 .59938 Mdot
.37361 .54932 Mdot
.48722 .68347 Mdot
.29755 .58199 Mdot
.5069 .3276 Mdot
.31848 .33028 Mdot
.45092 .68335 Mdot
.58404 .30614 Mdot
.49567 .71174 Mdot
.3647 .41489 Mdot
.3088 .33715 Mdot
.30796 .57744 Mdot
.32847 .37921 Mdot
.36945 .57623 Mdot
.64696 .4896 Mdot
.49774 .35337 Mdot
.70981 .40613 Mdot
.50456 .3114 Mdot
.60056 .61287 Mdot
.28316 .53587 Mdot
.31778 .56885 Mdot
.4902 .74249 Mdot
.3005 .58332 Mdot
.31273 .53602 Mdot
.44062 .66338 Mdot
.28936 .54748 Mdot
.45548 .36682 Mdot
.25074 .3364 Mdot
.28753 .57405 Mdot
.46719 .69151 Mdot
.72566 .40615 Mdot
.28104 .5656 Mdot
.70433 .70574 Mdot
.44497 .39703 Mdot
.64976 .63273 Mdot
.74485 .38326 Mdot
.28681 .59031 Mdot
.70972 .40307 Mdot
.64686 .64897 Mdot
.70998 .42605 Mdot
.49726 .7388 Mdot
.49837 .7047 Mdot
.65557 .44341 Mdot
.3927 .70491 Mdot
.33822 .58366 Mdot
.61283 .66897 Mdot
.40578 .38814 Mdot
.45875 .34705 Mdot
.72508 .36334 Mdot
.34359 .5654 Mdot
.41034 .76205 Mdot
.63534 .48199 Mdot
.35747 .49426 Mdot
.46637 .67313 Mdot
.65023 .68907 Mdot
.49282 .27343 Mdot
.42473 .66504 Mdot
.65222 .46009 Mdot
.62533 .48296 Mdot
.44801 .3839 Mdot
.60411 .37104 Mdot
.69356 .39523 Mdot
.53382 .72893 Mdot
.32751 .32541 Mdot
.60798 .64861 Mdot
.45959 .35293 Mdot
.33496 .339 Mdot
.48112 .36698 Mdot
.68323 .4132 Mdot
.45816 .71545 Mdot
.32161 .58537 Mdot
.69789 .41835 Mdot
.63167 .62084 Mdot
.45234 .24361 Mdot
.48835 .342 Mdot
.50448 .34563 Mdot
.62998 .66311 Mdot
.33557 .5902 Mdot
.63237 .64576 Mdot
.48768 .71882 Mdot
.70252 .40594 Mdot
.30937 .32641 Mdot
.65314 .47604 Mdot
.65553 .63781 Mdot
.47303 .71551 Mdot
.59805 .62383 Mdot
.46193 .66396 Mdot
.62277 .48195 Mdot
.50631 .35161 Mdot
.64286 .60339 Mdot
.61515 .47672 Mdot
.34322 .47259 Mdot
.45986 .28573 Mdot
.23695 .63179 Mdot
.62878 .65825 Mdot
.65917 .56353 Mdot
.46668 .69784 Mdot
.44992 .71887 Mdot
.35846 .41072 Mdot
.66211 .19655 Mdot
.4997 .32955 Mdot
.42361 .78081 Mdot
.48711 .72023 Mdot
.47597 .6955 Mdot
.63524 .64726 Mdot
.31826 .55318 Mdot
.25104 .5793 Mdot
.6473 .66898 Mdot
.60257 .33258 Mdot
.30017 .56302 Mdot
.45278 .41339 Mdot
.65631 .62971 Mdot
.31913 .34539 Mdot
.32084 .44018 Mdot
.71677 .4183 Mdot
.6069 .35979 Mdot
.4487 .66118 Mdot
.41649 .3839 Mdot
.28191 .70461 Mdot
.64179 .64862 Mdot
.61032 .48298 Mdot
.5232 .72376 Mdot
.39916 .39872 Mdot
.46623 .35193 Mdot
.43838 .37432 Mdot
.72829 .3645 Mdot
.33491 .45895 Mdot
.42188 .37198 Mdot
.45139 .28333 Mdot
.30782 .31985 Mdot
.6047 .58614 Mdot
.71362 .37489 Mdot
.58422 .39149 Mdot
.6917 .69207 Mdot
.35926 .49703 Mdot
.40245 .4092 Mdot
.44994 .71455 Mdot
.33448 .3488 Mdot
.45721 .68559 Mdot
.46426 .66988 Mdot
.76882 .68131 Mdot
.31744 .59117 Mdot
.32081 .3243 Mdot
.61714 .60183 Mdot
.24813 .57109 Mdot
.33197 .33637 Mdot
.26362 .38074 Mdot
.4724 .73874 Mdot
.6459 .17776 Mdot
.45604 .7252 Mdot
.60657 .4902 Mdot
.29583 .54739 Mdot
.34454 .58783 Mdot
.5007 .3071 Mdot
.3311 .56669 Mdot
.67049 .69605 Mdot
.29245 .58713 Mdot
.83663 .54498 Mdot
.35773 .60025 Mdot
.4707 .69795 Mdot
.49622 .70205 Mdot
.32773 .34572 Mdot
.45907 .36772 Mdot
.48278 .26664 Mdot
.63593 .48099 Mdot
.50076 .36448 Mdot
.61711 .63961 Mdot
.70734 .707 Mdot
.45361 .80599 Mdot
.29387 .54322 Mdot
.47618 .7181 Mdot
.46474 .35175 Mdot
.30884 .33532 Mdot
.49444 .35287 Mdot
.4091 .67533 Mdot
.35382 .36261 Mdot
.43696 .38267 Mdot
.32813 .34239 Mdot
.64359 .67009 Mdot
.67594 .6918 Mdot
.23882 .64322 Mdot
.76443 .68462 Mdot
.4761 .36855 Mdot
.72451 .38945 Mdot
.68415 .41225 Mdot
.45643 .33813 Mdot
.58245 .56818 Mdot
.50865 .32582 Mdot
.45196 .3854 Mdot
.45002 .24243 Mdot
.65278 .66982 Mdot
.60567 .50823 Mdot
.64287 .63772 Mdot
.34538 .60984 Mdot
.62778 .51155 Mdot
.61405 .63141 Mdot
.46707 .25382 Mdot
.62231 .49075 Mdot
.50142 .75635 Mdot
.71307 .41394 Mdot
.45614 .38781 Mdot
.3647 .43022 Mdot
.64612 .61017 Mdot
.4737 .70613 Mdot
.28791 .55612 Mdot
.45162 .68797 Mdot
.66958 .6902 Mdot
.60832 .33483 Mdot
.64982 .48142 Mdot
.44511 .70587 Mdot
.30208 .34566 Mdot
.72758 .38993 Mdot
.46436 .73239 Mdot
.30499 .32503 Mdot
.44928 .3401 Mdot
.68639 .22007 Mdot
.41931 .36527 Mdot
.70835 .70754 Mdot
.49065 .72176 Mdot
.60035 .50371 Mdot
.46149 .37575 Mdot
.64402 .6161 Mdot
.69095 .44399 Mdot
.44308 .38382 Mdot
.60303 .61145 Mdot
.42666 .39462 Mdot
.7011 .38557 Mdot
.29689 .59396 Mdot
.50561 .28887 Mdot
.70082 .37187 Mdot
.69741 .41659 Mdot
.42431 .29483 Mdot
.49563 .34883 Mdot
.55253 .66651 Mdot
.30139 .57135 Mdot
.48626 .3637 Mdot
.6955 .37502 Mdot
.30928 .54569 Mdot
.29302 .55832 Mdot
.32687 .31908 Mdot
.44204 .68223 Mdot
.63572 .66005 Mdot
.72454 .3805 Mdot
.68654 .69767 Mdot
.41803 .38439 Mdot
.34378 .34261 Mdot
.70647 .41517 Mdot
.46314 .70788 Mdot
.31792 .32588 Mdot
.4409 .79449 Mdot
.47141 .28461 Mdot
.46892 .73562 Mdot
.40969 .41045 Mdot
.33354 .37299 Mdot
.32994 .60814 Mdot
.28824 .70396 Mdot
.39833 .69265 Mdot
.6374 .62367 Mdot
.63948 .48223 Mdot
.24991 .36913 Mdot
.72017 .41215 Mdot
.24925 .5862 Mdot
.46446 .34544 Mdot
.44465 .35664 Mdot
.31369 .603 Mdot
.48052 .33728 Mdot
.29934 .53902 Mdot
.70293 .7036 Mdot
.6586 .19169 Mdot
.31795 .583 Mdot
.31266 .56968 Mdot
.32175 .31214 Mdot
.66664 .66024 Mdot
.31198 .5416 Mdot
.41435 .39417 Mdot
.66965 .69064 Mdot
.64183 .44002 Mdot
.73669 .39329 Mdot
.74505 .36719 Mdot
.29947 .53471 Mdot
.42213 .42723 Mdot
.30532 .34055 Mdot
.45717 .4557 Mdot
.54411 .36615 Mdot
.4821 .72152 Mdot
.41033 .40085 Mdot
.63173 .48215 Mdot
.6442 .64492 Mdot
.42253 .36052 Mdot
.4628 .38336 Mdot
.32537 .58423 Mdot
.71539 .42208 Mdot
.4899 .70471 Mdot
.6131 .48164 Mdot
.62798 .5852 Mdot
.71713 .39645 Mdot
.32443 .53924 Mdot
.35681 .39893 Mdot
.6563 .48229 Mdot
.63162 .45721 Mdot
.47882 .35599 Mdot
.47618 .37972 Mdot
.65613 .46678 Mdot
.46431 .68384 Mdot
.63875 .6237 Mdot
.61301 .49511 Mdot
.50604 .31663 Mdot
.48006 .25876 Mdot
.47323 .35788 Mdot
.29383 .58454 Mdot
.47812 .71524 Mdot
.64846 .48203 Mdot
.72866 .70816 Mdot
.4171 .39907 Mdot
.43198 .42106 Mdot
.5997 .44442 Mdot
.63051 .48725 Mdot
.25075 .57888 Mdot
.72706 .37305 Mdot
.30904 .33709 Mdot
.44867 .28217 Mdot
.486 .38522 Mdot
.40309 .40687 Mdot
.61298 .61838 Mdot
.4753 .68063 Mdot
.64759 .44518 Mdot
.63768 .63515 Mdot
.29167 .55943 Mdot
.46779 .45383 Mdot
.32415 .59608 Mdot
.30955 .59465 Mdot
.28162 .53417 Mdot
.45638 .67753 Mdot
.2482 .36633 Mdot
.65772 .46775 Mdot
.44676 .34833 Mdot
.46897 .72384 Mdot
.31263 .53994 Mdot
.46636 .40041 Mdot
.30425 .53699 Mdot
.34173 .55908 Mdot
.48892 .38324 Mdot
.32457 .34039 Mdot
.4415 .28611 Mdot
.39997 .41992 Mdot
.72969 .36903 Mdot
.33207 .60451 Mdot
.43271 .42324 Mdot
.43475 .36114 Mdot
.46929 .37206 Mdot
.32792 .34729 Mdot
.68959 .41524 Mdot
.49428 .44683 Mdot
.46622 .3461 Mdot
.60825 .3711 Mdot
.46632 .39981 Mdot
.34468 .56844 Mdot
.50777 .73342 Mdot
.32087 .31592 Mdot
.62993 .67506 Mdot
.32011 .60705 Mdot
.7152 .41956 Mdot
.26934 .55041 Mdot
.31449 .35641 Mdot
.48112 .69743 Mdot
.31122 .56594 Mdot
.65139 .66218 Mdot
.47107 .7067 Mdot
.49573 .71134 Mdot
.32605 .34937 Mdot
.63327 .61539 Mdot
.71375 .42283 Mdot
.48941 .69285 Mdot
.30642 .35611 Mdot
.47163 .69929 Mdot
.23367 .61193 Mdot
.5078 .34628 Mdot
.45206 .28191 Mdot
.63105 .49912 Mdot
.63034 .44991 Mdot
.49292 .71062 Mdot
.72157 .40402 Mdot
.31895 .32558 Mdot
.28376 .56202 Mdot
.72756 .39637 Mdot
.3228 .44171 Mdot
.62316 .676 Mdot
.37331 .54924 Mdot
.68274 .69959 Mdot
.33226 .56321 Mdot
.60808 .35648 Mdot
.70585 .42213 Mdot
.64782 .45153 Mdot
.49472 .28995 Mdot
.64202 .47701 Mdot
.434 .3525 Mdot
.32108 .32531 Mdot
.4542 .36671 Mdot
.63279 .6724 Mdot
.7294 .36448 Mdot
.28905 .57841 Mdot
.75981 .39166 Mdot
.45559 .70287 Mdot
.50547 .33224 Mdot
.60952 .48899 Mdot
.3123 .33099 Mdot
.30403 .53918 Mdot
.33866 .56568 Mdot
.33176 .45159 Mdot
.62587 .66758 Mdot
.759 .37503 Mdot
.47024 .35786 Mdot
.72738 .42732 Mdot
.49319 .71343 Mdot
.3921 .70727 Mdot
.65403 .64602 Mdot
.64292 .1779 Mdot
.63406 .63167 Mdot
.63568 .43993 Mdot
.33342 .55951 Mdot
.7027 .38949 Mdot
.46551 .36275 Mdot
.28359 .5843 Mdot
.25092 .58076 Mdot
.74786 .37426 Mdot
.71971 .37319 Mdot
.40069 .68418 Mdot
.47477 .72701 Mdot
.6224 .46534 Mdot
.46603 .39962 Mdot
.45631 .40686 Mdot
.40561 .38541 Mdot
.47494 .72188 Mdot
.31946 .33473 Mdot
.50514 .73602 Mdot
.32597 .35694 Mdot
.69454 .37584 Mdot
.61136 .6441 Mdot
.52751 .8134 Mdot
.29626 .59565 Mdot
.48552 .44924 Mdot
.24029 .5845 Mdot
.46329 .28622 Mdot
.45191 .70961 Mdot
.60495 .46963 Mdot
.63636 .65275 Mdot
.48211 .64399 Mdot
.60991 .63827 Mdot
.75345 .28943 Mdot
.43662 .43586 Mdot
.50699 .73894 Mdot
.50024 .36259 Mdot
.62296 .60352 Mdot
.39938 .42367 Mdot
.61466 .49605 Mdot
.64066 .50958 Mdot
.33872 .36251 Mdot
.28456 .39716 Mdot
.72771 .36874 Mdot
.466 .36199 Mdot
.3091 .59917 Mdot
.46727 .36339 Mdot
.46873 .36289 Mdot
.47968 .34581 Mdot
.44297 .66029 Mdot
.50539 .35136 Mdot
.45756 .36733 Mdot
.71667 .70918 Mdot
.64443 .44163 Mdot
.61765 .57519 Mdot
.33786 .60846 Mdot
.73036 .39364 Mdot
.34588 .60866 Mdot
.50035 .28866 Mdot
.44314 .71055 Mdot
.33184 .45475 Mdot
.31596 .33954 Mdot
.28737 .53488 Mdot
.4459 .71032 Mdot
.74165 .39349 Mdot
.62918 .48104 Mdot
.23587 .66199 Mdot
.66482 .69542 Mdot
.63636 .46934 Mdot
.60049 .62624 Mdot
.39888 .4143 Mdot
.31159 .58323 Mdot
.64116 .47673 Mdot
.48547 .69203 Mdot
.60981 .62018 Mdot
.42908 .29284 Mdot
.42909 .37566 Mdot
.62419 .65589 Mdot
.62615 .49607 Mdot
.50479 .31084 Mdot
.50495 .29373 Mdot
.6228 .60259 Mdot
.45429 .6714 Mdot
.49466 .70188 Mdot
.73044 .40199 Mdot
.3416 .57856 Mdot
.33435 .57964 Mdot
.45703 .70311 Mdot
.49266 .6453 Mdot
.42155 .38777 Mdot
.42546 .38297 Mdot
.49334 .28077 Mdot
.48715 .37527 Mdot
.67088 .69883 Mdot
.63521 .47114 Mdot
.32744 .57374 Mdot
.32185 .32545 Mdot
.33675 .33414 Mdot
.46224 .36157 Mdot
.604 .32734 Mdot
.64303 .66595 Mdot
.30832 .3446 Mdot
.69862 .38803 Mdot
.30063 .41239 Mdot
.44117 .39689 Mdot
.68196 .39507 Mdot
.33738 .56764 Mdot
.51689 .7488 Mdot
.47461 .70527 Mdot
.61976 .59803 Mdot
.61842 .59994 Mdot
.76988 .60647 Mdot
.30002 .5976 Mdot
.63693 .46986 Mdot
.62872 .68336 Mdot
.61549 .5101 Mdot
.72026 .37428 Mdot
.55397 .40914 Mdot
.67097 .69664 Mdot
.61719 .57565 Mdot
.49706 .74227 Mdot
.41039 .40499 Mdot
.45386 .39147 Mdot
.3933 .71383 Mdot
.46552 .377 Mdot
.70394 .40999 Mdot
.47226 .73112 Mdot
.30944 .56606 Mdot
.7354 .37171 Mdot
.45434 .71984 Mdot
.33609 .57829 Mdot
.3229 .34863 Mdot
.46225 .4028 Mdot
.28995 .55757 Mdot
.32715 .54339 Mdot
.42031 .38985 Mdot
.77737 .67513 Mdot
.325 .58077 Mdot
.29142 .55093 Mdot
.29781 .41003 Mdot
.62984 .59176 Mdot
.68682 .44176 Mdot
.44064 .68615 Mdot
.44881 .37059 Mdot
.61549 .65328 Mdot
.71265 .38201 Mdot
.31857 .56685 Mdot
.47865 .37159 Mdot
.41892 .3823 Mdot
.72694 .39032 Mdot
.69743 .38683 Mdot
.72478 .40198 Mdot
.48519 .68104 Mdot
.31723 .34334 Mdot
.30317 .54182 Mdot
.46061 .71415 Mdot
.71295 .41864 Mdot
.71131 .37332 Mdot
.72206 .35713 Mdot
.42235 .38925 Mdot
.6965 .38714 Mdot
.25786 .37615 Mdot
.46199 .25352 Mdot
.61728 .5116 Mdot
.63898 .55555 Mdot
.64176 .59787 Mdot
.60237 .46144 Mdot
.47605 .68203 Mdot
.32321 .35515 Mdot
.7382 .3915 Mdot
.62013 .49696 Mdot
.42573 .38005 Mdot
.43107 .40279 Mdot
.72414 .39286 Mdot
.60974 .33325 Mdot
.3267 .58665 Mdot
.23833 .63603 Mdot
.72931 .39129 Mdot
.63146 .60313 Mdot
.65418 .66889 Mdot
.62893 .63455 Mdot
.47517 .3595 Mdot
.47437 .39922 Mdot
.53307 .34599 Mdot
.35258 .48187 Mdot
.47966 .72544 Mdot
.33615 .55935 Mdot
.29507 .40991 Mdot
.29433 .55798 Mdot
.61797 .66773 Mdot
.72107 .40453 Mdot
.32111 .60392 Mdot
.4911 .69091 Mdot
.49391 .70278 Mdot
.63984 .60017 Mdot
.63445 .62906 Mdot
.62597 .64438 Mdot
.30008 .59953 Mdot
.32304 .54651 Mdot
.49722 .37156 Mdot
.30163 .58759 Mdot
.69691 .69159 Mdot
.70237 .70377 Mdot
.64502 .60748 Mdot
.46336 .68986 Mdot
.31685 .55655 Mdot
.4275 .39604 Mdot
.4172 .30225 Mdot
.656 .66839 Mdot
.72768 .41177 Mdot
.25063 .33724 Mdot
.66465 .1999 Mdot
.34172 .3475 Mdot
.48434 .70824 Mdot
.6328 .50411 Mdot
.44155 .37097 Mdot
.64083 .62731 Mdot
.60541 .52537 Mdot
.64639 .46209 Mdot
.50427 .33921 Mdot
.35784 .34245 Mdot
.48065 .70873 Mdot
.50242 .28602 Mdot
.61602 .49436 Mdot
.30517 .32186 Mdot
.46885 .72898 Mdot
.65534 .63429 Mdot
.60303 .58276 Mdot
.36391 .50746 Mdot
.56323 .40301 Mdot
.64892 .49032 Mdot
.40531 .39191 Mdot
.61626 .63049 Mdot
.73736 .37403 Mdot
.61848 .6353 Mdot
.34416 .55975 Mdot
.63276 .59287 Mdot
.43706 .3944 Mdot
.30603 .54238 Mdot
.4947 .70568 Mdot
.53551 .32592 Mdot
.76723 .36541 Mdot
.64731 .61888 Mdot
.65262 .45257 Mdot
.33718 .34406 Mdot
.30035 .31525 Mdot
.63036 .44979 Mdot
.45162 .39133 Mdot
.45688 .69013 Mdot
.29854 .5403 Mdot
.4631 .7105 Mdot
.6901 .445 Mdot
.23037 .59933 Mdot
.47572 .70544 Mdot
.4824 .39288 Mdot
.74116 .37706 Mdot
.60713 .33175 Mdot
.43972 .39182 Mdot
.48197 .68553 Mdot
.50536 .34434 Mdot
.32825 .60644 Mdot
.47205 .25652 Mdot
.46953 .28468 Mdot
.45514 .69563 Mdot
.61316 .47001 Mdot
.50853 .30681 Mdot
.69034 .44276 Mdot
.48759 .71754 Mdot
.46369 .24779 Mdot
.62971 .46933 Mdot
.71192 .39562 Mdot
.72841 .36529 Mdot
.71628 .39993 Mdot
.43324 .38272 Mdot
.32848 .37439 Mdot
.70269 .42098 Mdot
.43526 .66419 Mdot
.69765 .41209 Mdot
.61445 .45329 Mdot
.40719 .75815 Mdot
.70447 .37952 Mdot
.45932 .38256 Mdot
.32607 .35671 Mdot
.32343 .35466 Mdot
.65049 .64132 Mdot
.23991 .67222 Mdot
.71608 .70868 Mdot
.44159 .35639 Mdot
.28423 .40176 Mdot
.29613 .59163 Mdot
.65546 .4526 Mdot
.46782 .28464 Mdot
.30465 .34594 Mdot
.29791 .55281 Mdot
.49728 .28819 Mdot
.36869 .52791 Mdot
.62101 .50605 Mdot
.43113 .38471 Mdot
.31859 .60587 Mdot
.28502 .53346 Mdot
.59777 .31505 Mdot
.35974 .49906 Mdot
.32736 .56414 Mdot
.48727 .72275 Mdot
.47412 .68254 Mdot
.45609 .69147 Mdot
.6329 .62467 Mdot
.31441 .56919 Mdot
.43639 .34618 Mdot
.63809 .62562 Mdot
.47403 .34756 Mdot
.45536 .69865 Mdot
.46459 .28017 Mdot
.31182 .56917 Mdot
.44528 .38877 Mdot
.44258 .42139 Mdot
.60356 .61312 Mdot
.72651 .39111 Mdot
.27336 .38879 Mdot
.60751 .58549 Mdot
.46546 .6658 Mdot
.34592 .56253 Mdot
.62049 .45174 Mdot
.30077 .32539 Mdot
.48289 .3669 Mdot
.47178 .34071 Mdot
.30164 .32383 Mdot
.4322 .43531 Mdot
.63487 .45865 Mdot
.63161 .62102 Mdot
.62319 .58891 Mdot
.42792 .39952 Mdot
.3184 .57313 Mdot
.68303 .42023 Mdot
.67338 .43111 Mdot
.7511 .3879 Mdot
.50625 .30135 Mdot
.45186 .2832 Mdot
.46612 .39406 Mdot
.5141 .43645 Mdot
.65211 .65351 Mdot
.60447 .50397 Mdot
.49994 .30227 Mdot
.70691 .40074 Mdot
.48859 .35141 Mdot
.3427 .60818 Mdot
.31494 .56436 Mdot
.63089 .65896 Mdot
.48972 .73289 Mdot
.65417 .48872 Mdot
.64804 .61117 Mdot
.42939 .39947 Mdot
.33089 .3287 Mdot
.48349 .73076 Mdot
.32865 .53946 Mdot
.71602 .39252 Mdot
.64297 .63277 Mdot
.70072 .39717 Mdot
.29959 .58194 Mdot
.31974 .5671 Mdot
.49188 .35973 Mdot
.76151 .37738 Mdot
.65219 .62501 Mdot
.473 .36064 Mdot
.62164 .65118 Mdot
.67653 .69698 Mdot
.49321 .7398 Mdot
.48732 .36092 Mdot
.25077 .57577 Mdot
.4535 .68896 Mdot
.45243 .35193 Mdot
.32568 .35235 Mdot
.31756 .32636 Mdot
.62641 .60307 Mdot
.73091 .41191 Mdot
.70689 .39601 Mdot
.24067 .57075 Mdot
.32392 .45569 Mdot
.43763 .40765 Mdot
.63497 .59878 Mdot
.3255 .36625 Mdot
.47907 .69988 Mdot
.33131 .55965 Mdot
.48671 .81077 Mdot
.46895 .69252 Mdot
.42374 .39383 Mdot
.70611 .40632 Mdot
.33424 .54898 Mdot
.62024 .51324 Mdot
.54543 .29673 Mdot
.62284 .45703 Mdot
.75814 .3795 Mdot
.61629 .47655 Mdot
.4235 .77737 Mdot
.62334 .64323 Mdot
.3083 .53933 Mdot
.48566 .70828 Mdot
.4803 .69838 Mdot
.60293 .64141 Mdot
.32432 .44139 Mdot
.23703 .64083 Mdot
.24433 .35207 Mdot
.66096 .69413 Mdot
.71554 .40692 Mdot
.46927 .25753 Mdot
.6304 .63544 Mdot
.60241 .60235 Mdot
.40955 .67352 Mdot
.39196 .70945 Mdot
.31383 .55284 Mdot
.41928 .37859 Mdot
.30698 .42021 Mdot
.46141 .34421 Mdot
.56246 .40394 Mdot
.46048 .70484 Mdot
.33164 .56022 Mdot
.39369 .69524 Mdot
.45835 .39377 Mdot
.44717 .36111 Mdot
.69985 .69426 Mdot
.63486 .47843 Mdot
.73504 .68584 Mdot
.48971 .34757 Mdot
.62419 .62422 Mdot
.25668 .5513 Mdot
.62334 .50378 Mdot
.43112 .42454 Mdot
.48837 .72566 Mdot
.64948 .48096 Mdot
.62043 .50336 Mdot
.51601 .43381 Mdot
.37443 .56771 Mdot
.33233 .5974 Mdot
.68886 .40003 Mdot
.39037 .71604 Mdot
.47277 .73501 Mdot
.4365 .7907 Mdot
.42619 .39668 Mdot
.49617 .69922 Mdot
.65681 .43391 Mdot
.45053 .35164 Mdot
.33087 .33693 Mdot
.33143 .45264 Mdot
.40584 .39922 Mdot
.32268 .35953 Mdot
.46695 .6958 Mdot
.64235 .42112 Mdot
.42391 .41081 Mdot
.62701 .65717 Mdot
.31802 .55244 Mdot
.37287 .58429 Mdot
.73657 .38122 Mdot
.3969 .69397 Mdot
.65247 .18521 Mdot
.3306 .55926 Mdot
.42928 .37801 Mdot
.47718 .69782 Mdot
.63983 .50102 Mdot
.63448 .49635 Mdot
.63862 .45127 Mdot
.31305 .56145 Mdot
.62399 .50262 Mdot
.24538 .57128 Mdot
.4985 .28789 Mdot
.48157 .45059 Mdot
.45846 .67802 Mdot
.71309 .40685 Mdot
.69481 .43313 Mdot
.67734 .69604 Mdot
.46586 .39889 Mdot
.56273 .40406 Mdot
.28941 .52543 Mdot
.70832 .40888 Mdot
.45072 .36656 Mdot
.63302 .45822 Mdot
.44783 .23858 Mdot
.67941 .42397 Mdot
.61927 .47173 Mdot
.32966 .32397 Mdot
.338 .58254 Mdot
.6419 .47145 Mdot
.30675 .56427 Mdot
.45494 .3644 Mdot
.50521 .32472 Mdot
.33881 .59042 Mdot
.25257 .68176 Mdot
.65843 .47626 Mdot
.45469 .72204 Mdot
.50675 .33662 Mdot
.4762 .37001 Mdot
.45924 .40897 Mdot
.64247 .4962 Mdot
.29609 .69912 Mdot
.61628 .64891 Mdot
.73317 .70441 Mdot
.66808 .69833 Mdot
.40886 .67719 Mdot
.44346 .79895 Mdot
.46026 .39447 Mdot
.32445 .44012 Mdot
.46524 .40506 Mdot
.44552 .69091 Mdot
.42609 .42011 Mdot
.45883 .36776 Mdot
.4778 .35554 Mdot
.62203 .65222 Mdot
.48202 .74169 Mdot
.32441 .31759 Mdot
.50085 .30243 Mdot
.73945 .4026 Mdot
.29716 .57421 Mdot
.44679 .37476 Mdot
.30539 .5247 Mdot
.627 .60084 Mdot
.22787 .62846 Mdot
.45733 .38282 Mdot
.63446 .47826 Mdot
.4933 .69236 Mdot
.49443 .71148 Mdot
.63273 .60794 Mdot
.63644 .61008 Mdot
.47599 .3698 Mdot
.45445 .70558 Mdot
.44493 .40962 Mdot
.5082 .30769 Mdot
.62434 .49546 Mdot
.72006 .37801 Mdot
.44944 .34517 Mdot
.23738 .63894 Mdot
.76637 .34803 Mdot
.4739 .35901 Mdot
.3219 .59888 Mdot
.62892 .6482 Mdot
.61469 .66727 Mdot
.33342 .57682 Mdot
.61242 .66504 Mdot
.22823 .63226 Mdot
.33212 .37432 Mdot
.71379 .37673 Mdot
.28074 .32059 Mdot
.69675 .41553 Mdot
.64835 .48456 Mdot
.42287 .38976 Mdot
.54464 .70241 Mdot
.661 .69599 Mdot
.38837 .25578 Mdot
.4676 .70683 Mdot
.6058 .49962 Mdot
.31901 .33723 Mdot
.74516 .38076 Mdot
.64249 .64591 Mdot
.63954 .5094 Mdot
.48913 .34977 Mdot
.31788 .60654 Mdot
.34255 .33655 Mdot
.61069 .49865 Mdot
.646 .48695 Mdot
.6408 .50697 Mdot
.45401 .71951 Mdot
.28507 .55331 Mdot
.40072 .68384 Mdot
.60584 .60943 Mdot
.50108 .36481 Mdot
.43219 .37618 Mdot
.33563 .56002 Mdot
.43924 .35276 Mdot
.44958 .69283 Mdot
.23814 .35647 Mdot
.72253 .40579 Mdot
.63029 .50875 Mdot
.33425 .6718 Mdot
.62935 .51466 Mdot
.31666 .32157 Mdot
.30496 .31762 Mdot
.33951 .60813 Mdot
.44257 .70181 Mdot
.40224 .41342 Mdot
.61801 .58249 Mdot
.71342 .39285 Mdot
.49668 .70568 Mdot
.32866 .32988 Mdot
.4491 .38968 Mdot
.71049 .40717 Mdot
.39394 .69853 Mdot
.71644 .42521 Mdot
.48623 .71403 Mdot
.60234 .48431 Mdot
.40818 .29924 Mdot
.4453 .38471 Mdot
.63264 .47369 Mdot
.28656 .56666 Mdot
.47698 .72484 Mdot
.33668 .45898 Mdot
.61965 .50479 Mdot
.68641 .6995 Mdot
.49361 .71814 Mdot
.48362 .36707 Mdot
.2713 .54852 Mdot
.36213 .59467 Mdot
.29065 .5477 Mdot
.80691 .59112 Mdot
.69398 .7046 Mdot
.62544 .64769 Mdot
.46462 .68934 Mdot
.61646 .65712 Mdot
.74109 .3761 Mdot
.47704 .26453 Mdot
.64168 .61284 Mdot
.27947 .56034 Mdot
.60923 .6403 Mdot
.44503 .41022 Mdot
.44994 .71777 Mdot
.65831 .63483 Mdot
.41432 .37132 Mdot
.3202 .34985 Mdot
.64553 .48281 Mdot
.69292 .42319 Mdot
.50121 .29465 Mdot
.41253 .38601 Mdot
.62782 .47714 Mdot
.44687 .38705 Mdot
.44987 .69463 Mdot
.53541 .3323 Mdot
.48343 .38823 Mdot
.66161 .6923 Mdot
.23401 .65438 Mdot
.62238 .5912 Mdot
.75313 .41006 Mdot
.45974 .3484 Mdot
.4397 .38772 Mdot
.32185 .33108 Mdot
.25449 .33093 Mdot
.47072 .66849 Mdot
.50687 .35163 Mdot
.61473 .66995 Mdot
.30101 .55523 Mdot
.31089 .601 Mdot
.55057 .41049 Mdot
.63232 .47135 Mdot
.46571 .67208 Mdot
.43156 .38916 Mdot
.61137 .5052 Mdot
.48206 .29408 Mdot
.39619 .72887 Mdot
.70067 .70652 Mdot
.60379 .60297 Mdot
.33332 .60768 Mdot
.64179 .66887 Mdot
.31975 .33005 Mdot
.62674 .50352 Mdot
.69433 .70725 Mdot
.42882 .66266 Mdot
.71211 .39229 Mdot
.47564 .35199 Mdot
.60321 .32267 Mdot
.64436 .66952 Mdot
.63472 .61801 Mdot
.44276 .41077 Mdot
.26879 .53408 Mdot
.75111 .34908 Mdot
.46461 .72077 Mdot
.35147 .60553 Mdot
.36328 .42147 Mdot
.681 .28755 Mdot
.47382 .68597 Mdot
.33332 .33835 Mdot
.65104 .66872 Mdot
.73393 .6293 Mdot
.29712 .55516 Mdot
.71396 .39174 Mdot
.42373 .36299 Mdot
.29136 .58431 Mdot
.66005 .6947 Mdot
.29132 .54251 Mdot
.63837 .48126 Mdot
.44776 .71458 Mdot
.64591 .65108 Mdot
.47663 .74029 Mdot
.25145 .57559 Mdot
.71818 .40717 Mdot
.59575 .37716 Mdot
.3332 .35686 Mdot
.33023 .45215 Mdot
.32004 .34369 Mdot
.65553 .43969 Mdot
.32022 .34742 Mdot
.36942 .58772 Mdot
.44193 .39122 Mdot
.41442 .41111 Mdot
.62454 .67664 Mdot
.4789 .35972 Mdot
.41567 .39451 Mdot
.44371 .42054 Mdot
.47084 .35002 Mdot
.4694 .36201 Mdot
.48166 .37356 Mdot
.32702 .59321 Mdot
.49472 .36127 Mdot
.32406 .5423 Mdot
.30332 .52781 Mdot
.60523 .61022 Mdot
.73134 .36533 Mdot
.70028 .38441 Mdot
.49845 .32401 Mdot
.60322 .32404 Mdot
.30424 .41748 Mdot
.30084 .55955 Mdot
.49346 .71177 Mdot
.48076 .38903 Mdot
.75403 .3515 Mdot
.49915 .32451 Mdot
.65074 .63987 Mdot
.63133 .60089 Mdot
.41283 .37163 Mdot
.66787 .20363 Mdot
.49169 .34815 Mdot
.48874 .27774 Mdot
.43525 .38224 Mdot
.48802 .36387 Mdot
.62484 .58569 Mdot
.60873 .35622 Mdot
.30518 .34151 Mdot
.3719 .55074 Mdot
.7117 .38933 Mdot
.64033 .47227 Mdot
.50521 .32434 Mdot
.35952 .40678 Mdot
.36495 .51163 Mdot
.32294 .33077 Mdot
.64712 .63989 Mdot
.32447 .56969 Mdot
.49232 .28316 Mdot
.46209 .71575 Mdot
.55024 .3003 Mdot
.22908 .60864 Mdot
.4592 .71772 Mdot
.71282 .39502 Mdot
.65696 .65308 Mdot
.45253 .36187 Mdot
.61665 .62188 Mdot
.46231 .39105 Mdot
.48866 .26896 Mdot
.71765 .37631 Mdot
.27853 .56568 Mdot
.48474 .72776 Mdot
.32311 .59108 Mdot
.23444 .63019 Mdot
.54519 .36664 Mdot
.71996 .69974 Mdot
.63757 .59926 Mdot
.74359 .41504 Mdot
.31868 .54579 Mdot
.41777 .3994 Mdot
.2548 .37354 Mdot
.30853 .58119 Mdot
.32007 .60759 Mdot
.54745 .30504 Mdot
.6174 .33817 Mdot
.47945 .37541 Mdot
.28887 .58126 Mdot
.65758 .65422 Mdot
.71132 .37693 Mdot
.41947 .39686 Mdot
.62959 .50418 Mdot
.31677 .60334 Mdot
.63925 .66637 Mdot
.60489 .36401 Mdot
.62931 .62521 Mdot
.30652 .55043 Mdot
.62332 .59617 Mdot
.50019 .73815 Mdot
.64279 .61364 Mdot
.4556 .34294 Mdot
.43487 .38868 Mdot
.35848 .60011 Mdot
.31977 .56725 Mdot
.31629 .32165 Mdot
.44871 .34791 Mdot
.31167 .54086 Mdot
.64832 .6844 Mdot
.36015 .51103 Mdot
.31723 .32497 Mdot
.41874 .38472 Mdot
.69792 .41814 Mdot
.51091 .31416 Mdot
.53982 .30644 Mdot
.49153 .37998 Mdot
.71824 .40452 Mdot
.31899 .60865 Mdot
.42814 .39141 Mdot
.61388 .34776 Mdot
.62181 .67732 Mdot
.39899 .40212 Mdot
.63675 .505 Mdot
.30363 .33345 Mdot
.57309 .29021 Mdot
.32865 .33091 Mdot
.29596 .54956 Mdot
.30791 .54677 Mdot
.63517 .68045 Mdot
.28936 .56231 Mdot
.6356 .50442 Mdot
.46936 .67449 Mdot
.23369 .61607 Mdot
.60386 .50118 Mdot
.65105 .46297 Mdot
.65779 .46765 Mdot
.61135 .48299 Mdot
.75625 .35435 Mdot
.69589 .70045 Mdot
.65023 .46916 Mdot
.31676 .53906 Mdot
.57265 .5784 Mdot
.61737 .45611 Mdot
.46524 .67167 Mdot
.62093 .50297 Mdot
.3993 .40227 Mdot
.32625 .33231 Mdot
.3453 .57414 Mdot
.45821 .71277 Mdot
.66015 .44244 Mdot
.41662 .39592 Mdot
.34167 .60687 Mdot
.45006 .37261 Mdot
.72777 .41335 Mdot
.30981 .56894 Mdot
.64079 .63189 Mdot
.72249 .37648 Mdot
.61424 .48864 Mdot
.72899 .39486 Mdot
.61589 .63745 Mdot
.48625 .68896 Mdot
.41662 .37034 Mdot
.69754 .42945 Mdot
.73097 .3657 Mdot
.4015 .39371 Mdot
.31421 .54861 Mdot
.66175 .45275 Mdot
.4154 .38573 Mdot
.32187 .33609 Mdot
.3347 .58163 Mdot
.29122 .70502 Mdot
.45596 .35896 Mdot
.30998 .31741 Mdot
.37204 .5705 Mdot
.60945 .50075 Mdot
.63689 .62641 Mdot
.47812 .37203 Mdot
.47031 .7111 Mdot
.45612 .7022 Mdot
.66259 .69538 Mdot
.32834 .60284 Mdot
.63555 .67054 Mdot
.40104 .38868 Mdot
.61771 .49984 Mdot
.46109 .38602 Mdot
.70153 .69213 Mdot
.26246 .69425 Mdot
.32904 .54371 Mdot
.60746 .60182 Mdot
.47845 .29529 Mdot
.44269 .68157 Mdot
.64751 .68839 Mdot
.37323 .56388 Mdot
.30487 .59024 Mdot
.3334 .575 Mdot
.69716 .38987 Mdot
.63572 .63157 Mdot
.34331 .5788 Mdot
.34209 .5725 Mdot
.32025 .32715 Mdot
.4078 .37838 Mdot
.32901 .60853 Mdot
.67774 .69997 Mdot
.70725 .39426 Mdot
.60243 .64895 Mdot
.76694 .35021 Mdot
.47148 .72514 Mdot
.42745 .42494 Mdot
.45903 .40361 Mdot
.6412 .17584 Mdot
.48771 .34626 Mdot
.43435 .37976 Mdot
.34543 .60974 Mdot
.73607 .41085 Mdot
.69721 .39594 Mdot
.31721 .54556 Mdot
.32823 .54181 Mdot
.73189 .3851 Mdot
.40206 .32461 Mdot
.5862 .30507 Mdot
.48547 .30324 Mdot
.28388 .55314 Mdot
.23608 .61259 Mdot
.46088 .69913 Mdot
.3012 .59458 Mdot
.4918 .75594 Mdot
.65296 .62114 Mdot
.647 .61765 Mdot
.48962 .7204 Mdot
.44973 .36258 Mdot
.62868 .58764 Mdot
.30898 .34329 Mdot
.49356 .75869 Mdot
.3353 .3475 Mdot
.7857 .66918 Mdot
.44047 .35144 Mdot
.53043 .63629 Mdot
.41595 .76803 Mdot
.31179 .3223 Mdot
.32799 .37703 Mdot
.72057 .39285 Mdot
.37267 .58715 Mdot
.44883 .68711 Mdot
.30823 .42176 Mdot
.44321 .38602 Mdot
.28313 .57261 Mdot
.47876 .72981 Mdot
.28124 .69903 Mdot
.30444 .34336 Mdot
.31088 .33287 Mdot
.25487 .37613 Mdot
.29576 .53378 Mdot
.63506 .62556 Mdot
.35217 .60706 Mdot
.34414 .5642 Mdot
.32555 .35105 Mdot
.65881 .66544 Mdot
.44115 .24274 Mdot
.28118 .56036 Mdot
.68335 .43333 Mdot
.30033 .57292 Mdot
.72868 .38326 Mdot
.34306 .58347 Mdot
.60357 .62053 Mdot
.4647 .35409 Mdot
.60381 .61534 Mdot
.72094 .4155 Mdot
.61766 .59392 Mdot
.44835 .69624 Mdot
.62117 .48375 Mdot
.4537 .68985 Mdot
.47458 .26073 Mdot
.3403 .46336 Mdot
.47333 .67925 Mdot
.54039 .38522 Mdot
.44631 .39148 Mdot
.34275 .58441 Mdot
.64618 .64211 Mdot
.59775 .63535 Mdot
.50314 .29629 Mdot
.32546 .55974 Mdot
.62013 .66831 Mdot
.30328 .35305 Mdot
.52235 .74384 Mdot
.30314 .32568 Mdot
.49305 .81531 Mdot
.30075 .54243 Mdot
.60091 .64935 Mdot
.48999 .28074 Mdot
.33038 .53902 Mdot
.65487 .62885 Mdot
.48943 .70845 Mdot
.47058 .7108 Mdot
.4729 .33976 Mdot
.47117 .73843 Mdot
.64979 .63918 Mdot
.23079 .59541 Mdot
.34054 .58574 Mdot
.25515 .68967 Mdot
.72235 .40284 Mdot
.64499 .66465 Mdot
.62453 .49785 Mdot
.25249 .57947 Mdot
.61293 .65232 Mdot
.65503 .18741 Mdot
.85857 .53481 Mdot
.62764 .67031 Mdot
.30832 .56788 Mdot
.31648 .56113 Mdot
.34221 .34199 Mdot
.50375 .30079 Mdot
.64261 .64795 Mdot
.53999 .70928 Mdot
.44563 .2847 Mdot
.62187 .48013 Mdot
.71664 .70961 Mdot
.44525 .34207 Mdot
.3201 .34062 Mdot
.4786 .72259 Mdot
.44779 .36009 Mdot
.317 .53535 Mdot
.49038 .34758 Mdot
.45121 .68814 Mdot
.66516 .69008 Mdot
.44398 .38698 Mdot
.71387 .39386 Mdot
.47942 .71497 Mdot
.47096 .71495 Mdot
.61427 .60265 Mdot
.32887 .60298 Mdot
.3122 .42768 Mdot
.63463 .62863 Mdot
.31464 .34397 Mdot
.62727 .48138 Mdot
.48243 .37055 Mdot
.28056 .57757 Mdot
.37135 .53377 Mdot
.64639 .66485 Mdot
.4044 .39489 Mdot
.47008 .68736 Mdot
.63429 .67723 Mdot
.33571 .33755 Mdot
.65157 .62809 Mdot
.61773 .52976 Mdot
.62883 .58444 Mdot
.24943 .56407 Mdot
.65664 .45374 Mdot
.28128 .5697 Mdot
.64353 .46321 Mdot
.77155 .60625 Mdot
.71074 .39545 Mdot
.62624 .58865 Mdot
.25793 .68545 Mdot
.60523 .60529 Mdot
.46781 .34955 Mdot
.42678 .39472 Mdot
.61516 .6442 Mdot
.71571 .40877 Mdot
.60559 .45769 Mdot
.7225 .4193 Mdot
.31252 .56621 Mdot
.30531 .34821 Mdot
.84904 .57645 Mdot
.60361 .59041 Mdot
.48045 .7343 Mdot
.3616 .50774 Mdot
.64915 .46031 Mdot
.45052 .70321 Mdot
.47456 .71654 Mdot
.72812 .40622 Mdot
.60326 .6004 Mdot
.29412 .59396 Mdot
.45843 .73016 Mdot
.3279 .53758 Mdot
.61426 .35315 Mdot
.61022 .49201 Mdot
.71706 .43352 Mdot
.63167 .45875 Mdot
.49798 .29106 Mdot
.43792 .69683 Mdot
.45914 .37306 Mdot
.74728 .38851 Mdot
.48588 .72174 Mdot
.70167 .42178 Mdot
.33469 .33811 Mdot
.6157 .66494 Mdot
.285 .4131 Mdot
.46798 .33954 Mdot
.44222 .35411 Mdot
.47706 .72665 Mdot
.33909 .38342 Mdot
.374 .56024 Mdot
.33786 .5872 Mdot
.62382 .64317 Mdot
.54316 .30211 Mdot
.49348 .3525 Mdot
.41795 .39431 Mdot
.61222 .63373 Mdot
.63207 .46891 Mdot
.71873 .70681 Mdot
.42049 .38464 Mdot
.46388 .69506 Mdot
.33177 .33597 Mdot
.4507 .67608 Mdot
.39575 .41082 Mdot
.46094 .35111 Mdot
.3093 .33881 Mdot
.32498 .346 Mdot
.45413 .68967 Mdot
.61722 .47414 Mdot
.63681 .50852 Mdot
.28641 .55298 Mdot
.42571 .35995 Mdot
.44395 .28635 Mdot
.43133 .38775 Mdot
.72021 .39362 Mdot
.53754 .30228 Mdot
.43541 .41589 Mdot
.50782 .34066 Mdot
.44641 .28232 Mdot
.45648 .36549 Mdot
.47413 .72797 Mdot
.31716 .55914 Mdot
.47334 .68948 Mdot
.45721 .72782 Mdot
.60799 .63661 Mdot
.69808 .42088 Mdot
.47759 .36696 Mdot
.74063 .38549 Mdot
.47337 .33506 Mdot
.68879 .44794 Mdot
.5027 .31157 Mdot
.48772 .27919 Mdot
.68313 .42373 Mdot
.43904 .39439 Mdot
.61936 .64271 Mdot
.61301 .57689 Mdot
.32372 .35512 Mdot
.43126 .35402 Mdot
.48767 .73768 Mdot
.48167 .68555 Mdot
.70311 .70605 Mdot
.60265 .57725 Mdot
.72904 .41254 Mdot
.59276 .45934 Mdot
.32241 .34871 Mdot
.48237 .35127 Mdot
.61845 .47559 Mdot
.625 .6613 Mdot
.64765 .46518 Mdot
.69824 .70303 Mdot
.44785 .68531 Mdot
.48288 .70125 Mdot
.44483 .34837 Mdot
.7166 .24189 Mdot
.30873 .58469 Mdot
.31788 .56143 Mdot
.4702 .6735 Mdot
.6225 .59097 Mdot
.63982 .4843 Mdot
.26641 .38161 Mdot
.3652 .5193 Mdot
.74118 .37273 Mdot
.469 .38086 Mdot
.64709 .612 Mdot
.30432 .5368 Mdot
.73147 .40964 Mdot
.48496 .38777 Mdot
.65792 .67192 Mdot
.44988 .37775 Mdot
.29295 .32436 Mdot
.3275 .55226 Mdot
.50565 .31312 Mdot
.2793 .56305 Mdot
.45945 .70351 Mdot
.43996 .70436 Mdot
.45597 .35095 Mdot
.2864 .40968 Mdot
.26028 .54714 Mdot
.44347 .7142 Mdot
.68863 .4026 Mdot
.62274 .4903 Mdot
.70093 .42128 Mdot
.62567 .65379 Mdot
.71168 .39471 Mdot
.61111 .64917 Mdot
.63462 .68374 Mdot
.30126 .59739 Mdot
.70995 .40728 Mdot
.43591 .42764 Mdot
.62834 .503 Mdot
.70325 .37894 Mdot
.50262 .35167 Mdot
.32462 .32411 Mdot
.64178 .65546 Mdot
.7415 .38598 Mdot
.47889 .37275 Mdot
.33099 .67369 Mdot
.45123 .72013 Mdot
.44812 .69334 Mdot
.63922 .48105 Mdot
.65204 .66146 Mdot
.29117 .59285 Mdot
.4778 .28982 Mdot
.24702 .57148 Mdot
.41326 .39221 Mdot
.47626 .36333 Mdot
.24716 .56639 Mdot
.29158 .59327 Mdot
.45466 .35264 Mdot
.46235 .4548 Mdot
.62134 .49691 Mdot
.463 .70898 Mdot
.31384 .56837 Mdot
.3215 .57306 Mdot
.64099 .62218 Mdot
.32178 .6054 Mdot
.75735 .38624 Mdot
.44706 .69112 Mdot
.62518 .51451 Mdot
.4671 .68869 Mdot
.62264 .54272 Mdot
.62372 .6672 Mdot
.27568 .69247 Mdot
.33518 .59873 Mdot
.31474 .3269 Mdot
.32403 .6075 Mdot
.72513 .40251 Mdot
.2905 .58156 Mdot
.29395 .59035 Mdot
.40921 .37766 Mdot
.61524 .47933 Mdot
.64844 .4789 Mdot
.49891 .29694 Mdot
.30761 .58314 Mdot
.46403 .35967 Mdot
.49185 .37654 Mdot
.44036 .35276 Mdot
.50449 .30877 Mdot
.32889 .59557 Mdot
.3588 .40525 Mdot
.33711 .60846 Mdot
.32365 .54752 Mdot
.76661 .34563 Mdot
.63773 .50089 Mdot
.64257 .46015 Mdot
.52687 .7101 Mdot
.41849 .38028 Mdot
.61054 .66212 Mdot
.31563 .34257 Mdot
.6167 .4888 Mdot
.49336 .38109 Mdot
.73041 .36889 Mdot
.45598 .39436 Mdot
.62517 .47284 Mdot
.64386 .639 Mdot
.3154 .32762 Mdot
.42298 .38892 Mdot
.63838 .46895 Mdot
.30901 .60243 Mdot
.32772 .58396 Mdot
.35421 .48929 Mdot
.73238 .39364 Mdot
.45887 .68272 Mdot
.31715 .34096 Mdot
.62236 .64384 Mdot
.60431 .64901 Mdot
.28091 .57065 Mdot
.62489 .60602 Mdot
.48366 .70536 Mdot
.42724 .37814 Mdot
.45576 .6984 Mdot
.73294 .37366 Mdot
.3107 .56984 Mdot
.31858 .33288 Mdot
.3468 .34642 Mdot
.308 .5467 Mdot
.6197 .49753 Mdot
.69564 .41858 Mdot
.61485 .61127 Mdot
.33195 .54873 Mdot
.45427 .68236 Mdot
.63712 .61536 Mdot
.31116 .32983 Mdot
.77094 .32601 Mdot
.44882 .35914 Mdot
.46482 .34425 Mdot
.25717 .57751 Mdot
.40337 .40903 Mdot
.60614 .60905 Mdot
.28686 .59113 Mdot
.31962 .32401 Mdot
.46519 .25305 Mdot
.68657 .39341 Mdot
.64599 .54909 Mdot
.44827 .37034 Mdot
.46328 .40662 Mdot
.44843 .40417 Mdot
.24826 .67782 Mdot
.50615 .31013 Mdot
.68462 .69149 Mdot
.72555 .4284 Mdot
.4672 .73533 Mdot
.62713 .47571 Mdot
.60629 .63002 Mdot
.43718 .4567 Mdot
.44735 .35772 Mdot
.33048 .46 Mdot
.33198 .33197 Mdot
.47814 .69072 Mdot
.35393 .38995 Mdot
.64651 .63751 Mdot
.73103 .70799 Mdot
.40312 .38414 Mdot
.37116 .5404 Mdot
.50205 .64244 Mdot
.6186 .47805 Mdot
.63769 .45835 Mdot
.73102 .40935 Mdot
.65443 .68737 Mdot
.62616 .45371 Mdot
.47034 .68861 Mdot
.48697 .35247 Mdot
.43179 .41818 Mdot
.30259 .70175 Mdot
.3024 .53929 Mdot
.46929 .73315 Mdot
.64673 .56018 Mdot
.46518 .37278 Mdot
.31294 .59144 Mdot
.29674 .5556 Mdot
.73592 .36864 Mdot
.68239 .69703 Mdot
.64742 .68997 Mdot
.67841 .21443 Mdot
.65975 .44746 Mdot
.6229 .65907 Mdot
.64449 .45223 Mdot
.31294 .34223 Mdot
.505 .32464 Mdot
.4659 .73397 Mdot
.46646 .34789 Mdot
.32797 .45313 Mdot
.29143 .54999 Mdot
.4342 .38551 Mdot
.70724 .39007 Mdot
.24969 .33753 Mdot
.32697 .35881 Mdot
.47153 .45232 Mdot
.65769 .65479 Mdot
.47483 .36145 Mdot
.75836 .38264 Mdot
.61047 .50498 Mdot
.40043 .40814 Mdot
.63687 .62799 Mdot
.65676 .45448 Mdot
.70323 .39214 Mdot
.28818 .54813 Mdot
.62856 .47654 Mdot
.33462 .33458 Mdot
.47065 .38393 Mdot
.68727 .40643 Mdot
.31094 .33769 Mdot
.23664 .62129 Mdot
.62141 .46196 Mdot
.64293 .6114 Mdot
.33658 .55237 Mdot
.47263 .35917 Mdot
.62169 .49048 Mdot
.46508 .38233 Mdot
.23506 .63806 Mdot
.47568 .34825 Mdot
.31511 .68466 Mdot
.31959 .55361 Mdot
.47382 .70295 Mdot
.32276 .33192 Mdot
.45029 .37933 Mdot
.65127 .45114 Mdot
.64044 .48672 Mdot
.41749 .39798 Mdot
.28061 .56827 Mdot
.28644 .57032 Mdot
.36893 .52904 Mdot
.64291 .62049 Mdot
.48758 .3082 Mdot
.46884 .70399 Mdot
.61989 .47298 Mdot
.4601 .73199 Mdot
.45944 .40811 Mdot
.73058 .39201 Mdot
.3046 .69674 Mdot
.4299 .37141 Mdot
.32759 .56311 Mdot
.58774 .3088 Mdot
.30112 .59016 Mdot
.52527 .71157 Mdot
.47341 .73497 Mdot
.31054 .57768 Mdot
.44552 .37053 Mdot
.49647 .28647 Mdot
.42765 .42065 Mdot
.43901 .69117 Mdot
.6311 .51108 Mdot
.66338 .48913 Mdot
.65893 .64214 Mdot
.7733 .3486 Mdot
.49603 .71221 Mdot
.41374 .76702 Mdot
.31712 .32492 Mdot
.33807 .57688 Mdot
.45838 .67853 Mdot
.46726 .71501 Mdot
.65033 .64782 Mdot
.31873 .32721 Mdot
.44639 .38117 Mdot
.64036 .50141 Mdot
.49042 .69522 Mdot
.43463 .402 Mdot
.31318 .32051 Mdot
.70917 .70579 Mdot
.37497 .56748 Mdot
.28648 .70578 Mdot
.4676 .40254 Mdot
.3288 .45055 Mdot
.55022 .6791 Mdot
.34205 .58366 Mdot
.46496 .36154 Mdot
.63095 .49383 Mdot
.62469 .60287 Mdot
.43381 .37285 Mdot
.60743 .59963 Mdot
.47016 .68243 Mdot
.32464 .67995 Mdot
.44571 .41397 Mdot
.49528 .75781 Mdot
.46037 .35443 Mdot
.33879 .35504 Mdot
.70347 .40301 Mdot
.45212 .67817 Mdot
.36483 .52604 Mdot
.48171 .36532 Mdot
.63424 .6197 Mdot
.65954 .64095 Mdot
.28729 .55684 Mdot
.3578 .49667 Mdot
.26719 .69028 Mdot
.62639 .49943 Mdot
.62208 .61272 Mdot
.62166 .49257 Mdot
.48134 .44988 Mdot
.45826 .73018 Mdot
.70264 .39219 Mdot
.62339 .59724 Mdot
.48511 .68107 Mdot
.32432 .3238 Mdot
.29626 .57634 Mdot
.25206 .58348 Mdot
.31502 .35179 Mdot
.61859 .66764 Mdot
.72291 .38328 Mdot
.50726 .33142 Mdot
.30968 .35122 Mdot
.7186 .37879 Mdot
.64683 .63062 Mdot
.31837 .58523 Mdot
.30116 .5505 Mdot
.31535 .55744 Mdot
.42869 .42498 Mdot
.37107 .53127 Mdot
.58391 .38962 Mdot
.40929 .40946 Mdot
.23413 .58858 Mdot
.41666 .40743 Mdot
.44832 .69196 Mdot
.32985 .55661 Mdot
.50508 .31097 Mdot
.30152 .33425 Mdot
.39095 .41275 Mdot
.41866 .37149 Mdot
.32864 .3466 Mdot
.41813 .38076 Mdot
.23871 .5895 Mdot
.37577 .56506 Mdot
.50763 .33916 Mdot
.4445 .69749 Mdot
.72596 .39423 Mdot
.34249 .55621 Mdot
.47402 .36607 Mdot
.23591 .60503 Mdot
.503 .35378 Mdot
.32001 .6803 Mdot
.33081 .347 Mdot
.67189 .69128 Mdot
.4874 .35666 Mdot
.64387 .60467 Mdot
.34547 .35253 Mdot
.23537 .61591 Mdot
.45133 .71892 Mdot
.32998 .35892 Mdot
.65486 .61898 Mdot
.35597 .39223 Mdot
.63207 .49732 Mdot
.70561 .39688 Mdot
.65666 .45836 Mdot
.4522 .69107 Mdot
.43675 .36465 Mdot
.46256 .38913 Mdot
.40216 .41154 Mdot
.48468 .44889 Mdot
.63414 .50283 Mdot
.68197 .42398 Mdot
.23329 .61129 Mdot
.44096 .39787 Mdot
.62304 .58132 Mdot
.33358 .58666 Mdot
.39334 .42571 Mdot
.4287 .43294 Mdot
.32151 .31912 Mdot
.30689 .58087 Mdot
.32807 .60308 Mdot
.75287 .35054 Mdot
.71353 .40172 Mdot
.45009 .34991 Mdot
.68599 .43196 Mdot
.31663 .33807 Mdot
.46081 .68769 Mdot
.41832 .4128 Mdot
.62349 .66761 Mdot
.49555 .27946 Mdot
.64638 .62756 Mdot
.43214 .35862 Mdot
.3001 .57121 Mdot
.43991 .6917 Mdot
.6273 .68177 Mdot
.68143 .70245 Mdot
.59066 .38516 Mdot
.64371 .69035 Mdot
.73522 .39481 Mdot
.72795 .40414 Mdot
.45117 .67976 Mdot
.43719 .37676 Mdot
.50638 .30569 Mdot
.27694 .3158 Mdot
.42383 .37285 Mdot
.4471 .36431 Mdot
.44005 .65984 Mdot
.49237 .71811 Mdot
.6253 .59555 Mdot
.45226 .35386 Mdot
.45161 .39712 Mdot
.30532 .57344 Mdot
.73619 .40927 Mdot
.60928 .62682 Mdot
.72835 .41209 Mdot
.6198 .62669 Mdot
.57403 .2905 Mdot
.61193 .49484 Mdot
.7312 .39802 Mdot
.4955 .71778 Mdot
.32866 .56698 Mdot
.63549 .50364 Mdot
.63351 .65077 Mdot
.624 .60954 Mdot
.46439 .33683 Mdot
.29919 .53915 Mdot
.33784 .58794 Mdot
.73244 .38973 Mdot
.4794 .68217 Mdot
.30926 .34433 Mdot
.63244 .45864 Mdot
.66853 .55583 Mdot
.6301 .61349 Mdot
.22976 .60713 Mdot
.25467 .57752 Mdot
.46889 .3742 Mdot
.3265 .58409 Mdot
.45529 .38108 Mdot
.34758 .60859 Mdot
.31091 .52929 Mdot
.39554 .4111 Mdot
.35181 .48362 Mdot
.6221 .66068 Mdot
.8272 .61379 Mdot
.30624 .32136 Mdot
.49862 .7021 Mdot
.31477 .34138 Mdot
.7227 .7075 Mdot
.59054 .31089 Mdot
.43816 .39714 Mdot
.47533 .36415 Mdot
.72299 .25706 Mdot
.48649 .37527 Mdot
.63966 .46301 Mdot
.63216 .49802 Mdot
.32271 .5872 Mdot
.65616 .46088 Mdot
.49946 .29384 Mdot
.70798 .41111 Mdot
.62433 .6444 Mdot
.61304 .34504 Mdot
.72788 .38478 Mdot
.29579 .5479 Mdot
.30548 .34035 Mdot
.25723 .54556 Mdot
.61974 .57762 Mdot
.63555 .47342 Mdot
.47323 .68513 Mdot
.50844 .29878 Mdot
.64144 .62783 Mdot
.48661 .68538 Mdot
.48658 .37992 Mdot
.69634 .69496 Mdot
.44517 .69579 Mdot
.83758 .59618 Mdot
.47016 .72117 Mdot
.46985 .67429 Mdot
.49844 .30507 Mdot
.70735 .41144 Mdot
.65418 .45059 Mdot
.69052 .44343 Mdot
.45164 .71606 Mdot
.74881 .6958 Mdot
.65189 .65837 Mdot
.48708 .26813 Mdot
.37318 .58702 Mdot
.62202 .50437 Mdot
.45628 .3573 Mdot
.47635 .7241 Mdot
.47691 .33529 Mdot
.65487 .45242 Mdot
.48064 .70742 Mdot
.34581 .35146 Mdot
.53821 .29778 Mdot
.62637 .49245 Mdot
.64855 .48313 Mdot
.73926 .39882 Mdot
.67046 .69583 Mdot
.33586 .5927 Mdot
.72705 .36603 Mdot
.46969 .28054 Mdot
.44884 .3484 Mdot
.45436 .68861 Mdot
.62937 .47605 Mdot
.46867 .70734 Mdot
.69829 .40208 Mdot
.68769 .40236 Mdot
.29012 .54755 Mdot
.36994 .53364 Mdot
.60008 .49845 Mdot
.43343 .28878 Mdot
.43034 .41028 Mdot
.33357 .46323 Mdot
.32041 .59937 Mdot
.32931 .37592 Mdot
.69342 .41059 Mdot
.74152 .39607 Mdot
.34116 .35474 Mdot
.49854 .36738 Mdot
.32986 .34206 Mdot
.46675 .40084 Mdot
.73067 .67164 Mdot
.32011 .33077 Mdot
.61587 .6114 Mdot
.4708 .39862 Mdot
.39222 .72627 Mdot
.33081 .35482 Mdot
.47329 .37169 Mdot
.62886 .63154 Mdot
.40102 .39724 Mdot
.63789 .66464 Mdot
.46789 .35628 Mdot
.70418 .69204 Mdot
.62239 .64342 Mdot
.58757 .47995 Mdot
.53947 .36191 Mdot
.64378 .46588 Mdot
.69526 .39631 Mdot
.70047 .42873 Mdot
.60408 .36612 Mdot
.31705 .58291 Mdot
.25677 .33026 Mdot
.47252 .37137 Mdot
.65146 .64934 Mdot
.47333 .6831 Mdot
.34323 .3362 Mdot
.46618 .34261 Mdot
.31542 .34946 Mdot
.2964 .5792 Mdot
.65246 .66407 Mdot
.69913 .40834 Mdot
.60921 .58836 Mdot
.71258 .70876 Mdot
.62583 .66661 Mdot
.51286 .43508 Mdot
.33392 .32881 Mdot
.75778 .38392 Mdot
.34498 .47106 Mdot
.62389 .44282 Mdot
.28802 .56673 Mdot
.62615 .47806 Mdot
.71576 .41658 Mdot
.53618 .3257 Mdot
.33531 .58725 Mdot
.61247 .63364 Mdot
.45104 .37715 Mdot
.61369 .47662 Mdot
.6908 .44395 Mdot
.31817 .5348 Mdot
.68549 .41197 Mdot
.63034 .64395 Mdot
.62523 .4866 Mdot
.48407 .30561 Mdot
.36207 .41999 Mdot
.47879 .25994 Mdot
.45444 .37852 Mdot
.73133 .38532 Mdot
.30007 .53857 Mdot
.31582 .35042 Mdot
.48628 .7186 Mdot
.50302 .2991 Mdot
.45389 .35707 Mdot
.49971 .75802 Mdot
.29835 .57065 Mdot
.72011 .4044 Mdot
.47387 .72376 Mdot
.71404 .40003 Mdot
.64091 .46035 Mdot
.34463 .60907 Mdot
.63711 .45854 Mdot
.33159 .33257 Mdot
.46431 .68075 Mdot
.33706 .58828 Mdot
.71042 .70435 Mdot
.66114 .45324 Mdot
.61678 .64628 Mdot
.53574 .3229 Mdot
.28423 .56182 Mdot
.39993 .68907 Mdot
.60921 .58884 Mdot
.42741 .66929 Mdot
.50988 .31527 Mdot
.48269 .7118 Mdot
.47376 .36966 Mdot
.30683 .55821 Mdot
.43869 .68801 Mdot
.6767 .70037 Mdot
.45415 .41263 Mdot
.60661 .48193 Mdot
.43892 .39384 Mdot
.23886 .67055 Mdot
.40489 .74965 Mdot
.36045 .59911 Mdot
.49692 .70725 Mdot
.43134 .36213 Mdot
.62403 .50001 Mdot
.4232 .36177 Mdot
.45775 .72247 Mdot
.44725 .66017 Mdot
.59877 .63231 Mdot
.45645 .3736 Mdot
.71874 .39562 Mdot
.60863 .65139 Mdot
.66149 .65612 Mdot
.63081 .59882 Mdot
.36636 .52885 Mdot
.61567 .50243 Mdot
.62849 .50027 Mdot
.59562 .31469 Mdot
.46832 .70887 Mdot
.64279 .46538 Mdot
.46054 .39128 Mdot
.58415 .38842 Mdot
.31784 .55583 Mdot
.63356 .64169 Mdot
.43843 .35633 Mdot
.30243 .32432 Mdot
.64136 .47191 Mdot
.63433 .62969 Mdot
.29893 .59675 Mdot
.58526 .57666 Mdot
.4322 .37278 Mdot
.32397 .32799 Mdot
.30482 .54344 Mdot
.24064 .64255 Mdot
.48331 .29408 Mdot
.45259 .38223 Mdot
.45582 .70223 Mdot
.27876 .65348 Mdot
.48929 .37454 Mdot
.37139 .48426 Mdot
.63382 .50803 Mdot
.55777 .56719 Mdot
.29554 .63759 Mdot
.30037 .30834 Mdot
.46082 .59641 Mdot
.39163 .25577 Mdot
.49961 .61214 Mdot
.73922 .6546 Mdot
.42029 .59425 Mdot
.84644 .57466 Mdot
.47524 .74932 Mdot
.29295 .31707 Mdot
.64322 .19544 Mdot
.42229 .76733 Mdot
.40974 .63243 Mdot
.45523 .76397 Mdot
.57274 .4563 Mdot
.71613 .70376 Mdot
.69841 .69864 Mdot
.73596 .64569 Mdot
.44483 .34263 Mdot
.38079 .64386 Mdot
.29724 .35245 Mdot
.4083 .72068 Mdot
.6801 .67955 Mdot
.30533 .34981 Mdot
.71015 .26981 Mdot
.51734 .73764 Mdot
.68868 .33709 Mdot
.29871 .40713 Mdot
.67556 .61508 Mdot
.41167 .29754 Mdot
.63177 .38497 Mdot
.27847 .3133 Mdot
.52435 .58741 Mdot
.47484 .74328 Mdot
.30653 .60854 Mdot
.53282 .71736 Mdot
.61445 .62266 Mdot
.29798 .53671 Mdot
.46943 .79127 Mdot
.72485 .30743 Mdot
.43199 .73835 Mdot
.45947 .59736 Mdot
.63299 .45246 Mdot
.56115 .55855 Mdot
.49128 .31716 Mdot
.35202 .59849 Mdot
.68705 .64562 Mdot
.70312 .6776 Mdot
.27571 .60279 Mdot
.66994 .64615 Mdot
.53772 .33758 Mdot
.40729 .63395 Mdot
.28983 .63933 Mdot
.57908 .45705 Mdot
.58567 .49006 Mdot
.31865 .59943 Mdot
.66229 .24314 Mdot
.54327 .44785 Mdot
.46488 .27414 Mdot
.67507 .64399 Mdot
.2835 .59356 Mdot
.30802 .42483 Mdot
.3547 .49851 Mdot
.79707 .64804 Mdot
.75009 .32283 Mdot
.76119 .64402 Mdot
.55783 .44163 Mdot
.44177 .73959 Mdot
.55081 .38031 Mdot
.54194 .63935 Mdot
.77938 .63265 Mdot
.25012 .64235 Mdot
.67711 .23271 Mdot
.51436 .52172 Mdot
.75818 .3115 Mdot
.2775 .62177 Mdot
.57834 .46913 Mdot
.34782 .6221 Mdot
.58679 .54804 Mdot
.5645 .30393 Mdot
.74049 .29701 Mdot
.39688 .64015 Mdot
.66006 .48782 Mdot
.42218 .76536 Mdot
.25733 .62967 Mdot
.69203 .67483 Mdot
.64805 .50234 Mdot
.38893 .45412 Mdot
.73753 .28118 Mdot
.47211 .58948 Mdot
.69122 .2853 Mdot
.68547 .62689 Mdot
.48826 .80174 Mdot
.66205 .66522 Mdot
.43467 .69018 Mdot
.71036 .32889 Mdot
.30266 .55716 Mdot
.81068 .635 Mdot
.42381 .62093 Mdot
.49732 .6373 Mdot
.7297 .275 Mdot
.78281 .66256 Mdot
.57519 .53347 Mdot
.58599 .46837 Mdot
.53385 .7106 Mdot
.52891 .61264 Mdot
.39745 .71148 Mdot
.63381 .53701 Mdot
.28402 .67924 Mdot
.70215 .32449 Mdot
.76919 .66651 Mdot
.66243 .21073 Mdot
.46681 .2844 Mdot
.60194 .40697 Mdot
.26028 .58032 Mdot
.44623 .52814 Mdot
.40208 .71819 Mdot
.76282 .31608 Mdot
.31724 .36011 Mdot
.26328 .6555 Mdot
.74178 .64404 Mdot
.3986 .43096 Mdot
.34193 .66425 Mdot
.46707 .77769 Mdot
.59637 .56946 Mdot
.26873 .62697 Mdot
.76354 .35667 Mdot
.58483 .33306 Mdot
.36474 .4494 Mdot
.67148 .67185 Mdot
.48798 .29402 Mdot
.38582 .49016 Mdot
.82962 .55914 Mdot
.36387 .65364 Mdot
.38256 .45185 Mdot
.25439 .58711 Mdot
.77902 .62986 Mdot
.74758 .6508 Mdot
.30268 .66136 Mdot
.65848 .55843 Mdot
.69808 .29051 Mdot
.398 .51639 Mdot
.5695 .54629 Mdot
.29642 .34889 Mdot
.31594 .36628 Mdot
.69966 .63863 Mdot
.51569 .4538 Mdot
.68383 .37958 Mdot
.46323 .77211 Mdot
.34395 .47577 Mdot
.6438 .3897 Mdot
.35601 .46873 Mdot
.23946 .61956 Mdot
.43601 .48356 Mdot
.51878 .73085 Mdot
.43191 .47472 Mdot
.71522 .26931 Mdot
.60751 .61361 Mdot
.77984 .63771 Mdot
.43685 .74371 Mdot
.6881 .67899 Mdot
.47794 .63584 Mdot
.47896 .63672 Mdot
.69877 .3444 Mdot
.44273 .78292 Mdot
.5775 .4984 Mdot
.35676 .5983 Mdot
.45746 .62094 Mdot
.34171 .4572 Mdot
.52732 .40965 Mdot
.38626 .55606 Mdot
.69339 .41824 Mdot
.42393 .46229 Mdot
.26512 .62587 Mdot
.64964 .56056 Mdot
.51243 .42901 Mdot
.42405 .26616 Mdot
.60557 .50865 Mdot
.57311 .35898 Mdot
.57653 .29452 Mdot
.54152 .53034 Mdot
.7871 .64561 Mdot
.39345 .53009 Mdot
.57663 .36007 Mdot
.40619 .72543 Mdot
.25905 .33091 Mdot
.76007 .31066 Mdot
.73829 .34707 Mdot
.31036 .64978 Mdot
.29887 .66822 Mdot
.5042 .82775 Mdot
.4028 .68525 Mdot
.84036 .55067 Mdot
.43733 .74395 Mdot
.24086 .36394 Mdot
.6084 .60528 Mdot
.56628 .48887 Mdot
.33537 .6193 Mdot
.41776 .27175 Mdot
.72368 .28739 Mdot
.54763 .54612 Mdot
.71103 .37277 Mdot
.3362 .63369 Mdot
.37247 .47841 Mdot
.69578 .26905 Mdot
.67363 .24308 Mdot
.6727 .25039 Mdot
.46487 .79163 Mdot
.48575 .45638 Mdot
.71717 .26162 Mdot
.5661 .40311 Mdot
.51972 .48369 Mdot
.31824 .31136 Mdot
.45026 .26457 Mdot
.83259 .58632 Mdot
.58721 .42398 Mdot
.53401 .61136 Mdot
.27453 .60184 Mdot
.74172 .27794 Mdot
.59245 .3025 Mdot
.5739 .56374 Mdot
.67392 .3466 Mdot
.66586 .42574 Mdot
.64608 .38117 Mdot
.69576 .35054 Mdot
.49595 .58689 Mdot
.46545 .77644 Mdot
.75259 .28032 Mdot
.76444 .62677 Mdot
.41773 .73093 Mdot
.24516 .61481 Mdot
.82757 .60193 Mdot
.32867 .66682 Mdot
.43101 .69823 Mdot
.29275 .62668 Mdot
.27825 .36315 Mdot
.40679 .57418 Mdot
.53165 .5891 Mdot
.38145 .39276 Mdot
.65124 .40199 Mdot
.61525 .59615 Mdot
.8038 .6024 Mdot
.40232 .56106 Mdot
.51194 .48271 Mdot
.58587 .35692 Mdot
.76284 .68187 Mdot
.518 .55871 Mdot
.46863 .44078 Mdot
.39335 .52679 Mdot
.35414 .64605 Mdot
.34888 .66008 Mdot
.32046 .41041 Mdot
.43521 .40648 Mdot
.72999 .30429 Mdot
.85198 .5435 Mdot
.70938 .34519 Mdot
.33251 .65609 Mdot
.50426 .80471 Mdot
.48325 .74987 Mdot
.56748 .38902 Mdot
.42681 .24694 Mdot
.47862 .56321 Mdot
.40272 .24391 Mdot
.45098 .66772 Mdot
.30803 .42531 Mdot
.45547 .63448 Mdot
.56561 .4003 Mdot
.3784 .60627 Mdot
.48155 .62924 Mdot
.46552 .44855 Mdot
.25351 .59848 Mdot
.24272 .65877 Mdot
.7799 .62585 Mdot
.60966 .61006 Mdot
.66028 .55025 Mdot
.51814 .46476 Mdot
.74705 .39093 Mdot
.63957 .52293 Mdot
.56949 .53916 Mdot
.32913 .44323 Mdot
.51359 .80833 Mdot
.6752 .37369 Mdot
.82556 .61378 Mdot
.69762 .35079 Mdot
.75666 .64928 Mdot
.66805 .63015 Mdot
.56891 .33668 Mdot
.42202 .71055 Mdot
.45518 .74907 Mdot
.55901 .32468 Mdot
.7567 .66891 Mdot
.57385 .5565 Mdot
.35887 .59292 Mdot
.45286 .39984 Mdot
.58303 .30628 Mdot
.62761 .38708 Mdot
.56328 .35312 Mdot
.34156 .41643 Mdot
.27393 .57304 Mdot
.58174 .40913 Mdot
.56179 .58823 Mdot
.34884 .34631 Mdot
.29217 .66757 Mdot
.43841 .68446 Mdot
.24629 .60767 Mdot
.76367 .68414 Mdot
.5102 .82015 Mdot
.49606 .62281 Mdot
.54432 .40494 Mdot
.69583 .32111 Mdot
.55208 .40278 Mdot
.29854 .67227 Mdot
.28718 .36864 Mdot
.46588 .63961 Mdot
.27469 .60857 Mdot
.53152 .50584 Mdot
.5393 .66023 Mdot
.372 .63153 Mdot
.2527 .60804 Mdot
.33098 .36723 Mdot
.73634 .32714 Mdot
.38615 .37814 Mdot
.51245 .59332 Mdot
.47818 .28643 Mdot
.43096 .53379 Mdot
.43431 .62007 Mdot
.59712 .36097 Mdot
.48415 .60686 Mdot
.66479 .25275 Mdot
.3125 .43793 Mdot
.54766 .6109 Mdot
.56922 .4249 Mdot
.56428 .39998 Mdot
.30014 .40836 Mdot
.25924 .63293 Mdot
.46187 .77114 Mdot
.40072 .36463 Mdot
.7543 .33043 Mdot
.5013 .51304 Mdot
.58043 .35605 Mdot
.40297 .4976 Mdot
.39145 .37957 Mdot
.62247 .53012 Mdot
.69515 .3489 Mdot
.55895 .57066 Mdot
.63738 .18871 Mdot
.74458 .67288 Mdot
.37879 .5182 Mdot
.3418 .62297 Mdot
.78822 .62563 Mdot
.38914 .62126 Mdot
.42609 .60185 Mdot
.40554 .53804 Mdot
.81692 .60753 Mdot
.54606 .5655 Mdot
.56412 .57732 Mdot
.24772 .66541 Mdot
.70137 .25606 Mdot
.52096 .60645 Mdot
.43415 .70556 Mdot
.60072 .41542 Mdot
.47268 .34483 Mdot
.37191 .49842 Mdot
.28021 .69695 Mdot
.44171 .49918 Mdot
.5118 .6178 Mdot
.85222 .56169 Mdot
.5536 .54335 Mdot
.39472 .54098 Mdot
.64142 .18878 Mdot
.64125 .18151 Mdot
.36792 .5005 Mdot
.76645 .31964 Mdot
.56842 .5739 Mdot
.30905 .67162 Mdot
.46879 .74399 Mdot
.53478 .39568 Mdot
.33252 .46045 Mdot
.74952 .33754 Mdot
.48574 .82339 Mdot
.4072 .73017 Mdot
.312 .6253 Mdot
.7642 .34029 Mdot
.51065 .49116 Mdot
.57421 .50291 Mdot
.49357 .79701 Mdot
.73187 .69951 Mdot
.79584 .64298 Mdot
.3237 .40384 Mdot
.70372 .65825 Mdot
.71499 .63373 Mdot
.39448 .64457 Mdot
.8319 .60062 Mdot
.66628 .44571 Mdot
.26113 .32599 Mdot
.77815 .6319 Mdot
.26078 .67344 Mdot
.69775 .67507 Mdot
.43708 .61708 Mdot
.56267 .54075 Mdot
.45406 .48223 Mdot
.29241 .67932 Mdot
.46114 .78405 Mdot
.54465 .49905 Mdot
.54045 .31654 Mdot
.25024 .62406 Mdot
.2525 .64931 Mdot
.27329 .34094 Mdot
.56809 .52456 Mdot
.65017 .22692 Mdot
.51076 .73283 Mdot
.54907 .34572 Mdot
.35516 .59636 Mdot
.61568 .36023 Mdot
.57565 .4971 Mdot
.49901 .37204 Mdot
.73289 .32586 Mdot
.57953 .50615 Mdot
.66082 .23266 Mdot
.81018 .64192 Mdot
.67013 .34016 Mdot
.54315 .64931 Mdot
.64308 .5229 Mdot
.83191 .58223 Mdot
.83601 .56493 Mdot
.65779 .221 Mdot
.73355 .63549 Mdot
.55609 .32184 Mdot
.55006 .51202 Mdot
.5294 .40322 Mdot
.4897 .44493 Mdot
.79 .62096 Mdot
.29648 .40815 Mdot
.64024 .38056 Mdot
.34528 .64042 Mdot
.75987 .67382 Mdot
.558 .4195 Mdot
.61029 .36496 Mdot
.4275 .50356 Mdot
.58302 .49222 Mdot
.64467 .67258 Mdot
.70686 .23913 Mdot
.30157 .66317 Mdot
.65622 .38003 Mdot
.26968 .6578 Mdot
.24729 .5883 Mdot
.73113 .65781 Mdot
.3118 .64099 Mdot
.72356 .43697 Mdot
.67228 .62262 Mdot
.73949 .35381 Mdot
.5811 .55038 Mdot
.24596 .67699 Mdot
.40579 .43833 Mdot
.71004 .3397 Mdot
.64569 .39101 Mdot
.64985 .20915 Mdot
.58524 .41043 Mdot
.41955 .46268 Mdot
.65675 .23996 Mdot
.34032 .64551 Mdot
.55812 .35482 Mdot
.69763 .26511 Mdot
.37363 .59261 Mdot
.74847 .32156 Mdot
.48785 .70926 Mdot
.56773 .45997 Mdot
.27202 .68843 Mdot
.56213 .37134 Mdot
.55956 .36994 Mdot
.67679 .37761 Mdot
.41733 .75915 Mdot
.3936 .56801 Mdot
.39843 .51989 Mdot
.68997 .67748 Mdot
.53652 .39293 Mdot
.49659 .59473 Mdot
.66574 .21136 Mdot
.45643 .39891 Mdot
.75533 .61368 Mdot
.78281 .64145 Mdot
.42383 .71111 Mdot
.56136 .52842 Mdot
.26275 .68271 Mdot
.32403 .39559 Mdot
.5939 .3255 Mdot
.70464 .26006 Mdot
.56075 .52689 Mdot
.41841 .25757 Mdot
.31742 .37653 Mdot
.53641 .69549 Mdot
.43492 .76462 Mdot
.46916 .5976 Mdot
.55493 .45521 Mdot
.48252 .2982 Mdot
.7583 .64226 Mdot
.84974 .56967 Mdot
.6499 .22471 Mdot
.43957 .76633 Mdot
.56458 .36476 Mdot
.39196 .4827 Mdot
.63745 .41493 Mdot
.66217 .20633 Mdot
.71814 .70322 Mdot
.2641 .6251 Mdot
.76058 .66569 Mdot
.42698 .76632 Mdot
.57032 .49021 Mdot
.56251 .34219 Mdot
.66408 .24645 Mdot
.32118 .61881 Mdot
.52505 .52052 Mdot
.4108 .49007 Mdot
.50709 .29159 Mdot
.4204 .63546 Mdot
.27955 .36898 Mdot
.43923 .78655 Mdot
.64829 .20923 Mdot
.71217 .64267 Mdot
.37118 .41033 Mdot
.64456 .19956 Mdot
.27603 .57795 Mdot
.4181 .63784 Mdot
.48416 .79995 Mdot
.57548 .3656 Mdot
.66464 .66375 Mdot
.44339 .40102 Mdot
.54729 .31451 Mdot
.38677 .62687 Mdot
.58778 .41472 Mdot
.68704 .39637 Mdot
.25023 .61408 Mdot
.72475 .64445 Mdot
.24902 .60151 Mdot
.8485 .56278 Mdot
.49398 .58353 Mdot
.28791 .63523 Mdot
.2968 .37114 Mdot
.66543 .62433 Mdot
.35009 .64485 Mdot
.68506 .33929 Mdot
.45168 .26695 Mdot
.29348 .63208 Mdot
.28362 .62903 Mdot
.37932 .58771 Mdot
.41494 .69037 Mdot
.70661 .31316 Mdot
.78241 .65822 Mdot
.66748 .55499 Mdot
.37831 .57233 Mdot
.54843 .38601 Mdot
.56731 .54289 Mdot
.66088 .36608 Mdot
.60335 .60308 Mdot
.76633 .30586 Mdot
.25782 .35096 Mdot
.37889 .65019 Mdot
.48778 .55512 Mdot
.43654 .24855 Mdot
.55207 .37557 Mdot
.66572 .63151 Mdot
.57289 .53479 Mdot
.38265 .51631 Mdot
.26935 .55456 Mdot
.43175 .63973 Mdot
.6913 .41064 Mdot
.65817 .56175 Mdot
.42576 .73977 Mdot
.31325 .40886 Mdot
.79083 .63349 Mdot
.24893 .55468 Mdot
.61632 .53534 Mdot
.64051 .5849 Mdot
.50992 .43847 Mdot
.43995 .26283 Mdot
.72954 .25533 Mdot
.68283 .3298 Mdot
.28181 .54758 Mdot
.36637 .65099 Mdot
.69076 .65361 Mdot
.67222 .37503 Mdot
.53032 .53595 Mdot
.78614 .61992 Mdot
.39633 .45674 Mdot
.6766 .35919 Mdot
.31094 .63693 Mdot
.46369 .58435 Mdot
.77051 .65277 Mdot
.67659 .40533 Mdot
.76473 .67397 Mdot
.34106 .40261 Mdot
.54921 .44608 Mdot
.73714 .69254 Mdot
.43057 .49474 Mdot
.58265 .56205 Mdot
.34925 .34475 Mdot
.47646 .56745 Mdot
.8191 .60198 Mdot
.27128 .54892 Mdot
.57526 .44636 Mdot
.29658 .64779 Mdot
.40912 .73402 Mdot
.69916 .32607 Mdot
.3481 .65466 Mdot
.77769 .66047 Mdot
.53764 .39657 Mdot
.66851 .4162 Mdot
.31053 .41796 Mdot
.45761 .2751 Mdot
.64162 .4547 Mdot
.37117 .45545 Mdot
.66208 .47235 Mdot
.597 .31089 Mdot
.48536 .44283 Mdot
.73182 .29315 Mdot
.57758 .29841 Mdot
.45833 .48257 Mdot
.57929 .47638 Mdot
.33841 .60581 Mdot
.7509 .29585 Mdot
.58854 .32358 Mdot
.28347 .68189 Mdot
.79523 .6415 Mdot
.7318 .6277 Mdot
.643 .19736 Mdot
.42249 .76388 Mdot
.48635 .47346 Mdot
.83552 .59641 Mdot
.50797 .51108 Mdot
.71597 .63249 Mdot
.58092 .55026 Mdot
.25461 .56469 Mdot
.71982 .26964 Mdot
.57889 .49599 Mdot
.44765 .4858 Mdot
.42255 .4201 Mdot
.27694 .61162 Mdot
.57528 .31228 Mdot
.55115 .39177 Mdot
.61168 .62664 Mdot
.42601 .25809 Mdot
.69847 .64026 Mdot
.38039 .57141 Mdot
.78703 .63333 Mdot
.79103 .6115 Mdot
.60587 .41895 Mdot
.55032 .65739 Mdot
.63981 .19811 Mdot
.45268 .46583 Mdot
.30429 .30938 Mdot
.25131 .60314 Mdot
.68493 .40176 Mdot
.74632 .63227 Mdot
.39795 .36905 Mdot
.41872 .28728 Mdot
.3914 .45503 Mdot
.74418 .33368 Mdot
.44158 .51875 Mdot
.51467 .72978 Mdot
.37581 .58941 Mdot
.28498 .68027 Mdot
.2821 .64923 Mdot
.42009 .76889 Mdot
.81883 .59995 Mdot
.49608 .62241 Mdot
.46079 .5931 Mdot
.44869 .47848 Mdot
.80299 .59755 Mdot
.4221 .74782 Mdot
.44969 .67461 Mdot
.33138 .44716 Mdot
.64809 .21864 Mdot
.2429 .61216 Mdot
.44545 .6143 Mdot
.52517 .57787 Mdot
.55099 .40616 Mdot
.39726 .71015 Mdot
.3884 .64356 Mdot
.26052 .60758 Mdot
.68088 .27147 Mdot
.53604 .59805 Mdot
.65825 .50143 Mdot
.74861 .66444 Mdot
.509 .57905 Mdot
.79319 .61333 Mdot
.34717 .48515 Mdot
.67595 .2564 Mdot
.5818 .35957 Mdot
.65994 .42806 Mdot
.42391 .40532 Mdot
.34885 .63429 Mdot
.69738 .34841 Mdot
.5281 .53536 Mdot
.52943 .63089 Mdot
.27254 .63973 Mdot
.80648 .63838 Mdot
.6025 .51412 Mdot
.51289 .80637 Mdot
.58254 .47579 Mdot
.4239 .27154 Mdot
.41918 .26497 Mdot
.42031 .6901 Mdot
.56923 .54802 Mdot
.40088 .61213 Mdot
.55307 .45436 Mdot
.32933 .43578 Mdot
.73396 .35321 Mdot
.69941 .23376 Mdot
.2757 .5862 Mdot
.79322 .66021 Mdot
.36776 .5143 Mdot
.27199 .58945 Mdot
.71166 .63828 Mdot
.54481 .63401 Mdot
.51125 .45836 Mdot
.5953 .41483 Mdot
.2822 .5303 Mdot
.68977 .22536 Mdot
.50883 .6192 Mdot
.57739 .43872 Mdot
.69063 .66455 Mdot
.43733 .62309 Mdot
.5273 .73436 Mdot
.44719 .7494 Mdot
.81334 .62918 Mdot
.77959 .63249 Mdot
.51311 .74439 Mdot
.56692 .57352 Mdot
.52539 .62596 Mdot
.69396 .26945 Mdot
.57995 .48446 Mdot
.69613 .33271 Mdot
.45517 .79478 Mdot
.33499 .42697 Mdot
.57268 .29612 Mdot
.58564 .33186 Mdot
.45783 .27003 Mdot
.37571 .4423 Mdot
.68499 .28965 Mdot
.60731 .50561 Mdot
.66321 .55925 Mdot
.6971 .67148 Mdot
.6665 .20869 Mdot
.37329 .64058 Mdot
.61775 .46072 Mdot
.63551 .40559 Mdot
.53464 .59592 Mdot
.54685 .34376 Mdot
.40154 .53109 Mdot
.64831 .51398 Mdot
.52597 .72152 Mdot
.29096 .65587 Mdot
.74999 .33021 Mdot
.41859 .40274 Mdot
.39235 .24627 Mdot
.40129 .70508 Mdot
.66081 .63646 Mdot
.27338 .64443 Mdot
.72307 .25285 Mdot
.44718 .67683 Mdot
.49228 .79159 Mdot
.41845 .69892 Mdot
.66106 .37736 Mdot
.49901 .8141 Mdot
.41549 .68471 Mdot
.84914 .57508 Mdot
.38346 .64951 Mdot
.37086 .42205 Mdot
.25146 .65331 Mdot
.59525 .30884 Mdot
.36586 .45544 Mdot
.63287 .53809 Mdot
.73329 .31807 Mdot
.55253 .37028 Mdot
.57221 .45338 Mdot
.68054 .28206 Mdot
.76703 .65739 Mdot
.74738 .67194 Mdot
.40434 .68972 Mdot
.30017 .6252 Mdot
.51626 .82093 Mdot
.68387 .65762 Mdot
.25869 .36892 Mdot
.6796 .3284 Mdot
.37867 .40454 Mdot
.52658 .53074 Mdot
.39717 .50911 Mdot
.70824 .27379 Mdot
.81131 .60126 Mdot
.58477 .56767 Mdot
.62513 .57958 Mdot
.593 .34607 Mdot
.63085 .41293 Mdot
.39434 .58673 Mdot
.66406 .34885 Mdot
.66331 .62414 Mdot
.57879 .49436 Mdot
.77704 .65101 Mdot
.34823 .63437 Mdot
.46332 .28369 Mdot
.6517 .21874 Mdot
.43925 .27156 Mdot
.7571 .68784 Mdot
.46329 .79242 Mdot
.69499 .67262 Mdot
.66973 .21336 Mdot
.38211 .61698 Mdot
.43369 .44286 Mdot
.63619 .1901 Mdot
.7571 .31163 Mdot
.52771 .62583 Mdot
.39503 .3991 Mdot
.8453 .58354 Mdot
.62286 .57346 Mdot
.66297 .38795 Mdot
.30557 .42234 Mdot
.73663 .67011 Mdot
.49966 .43062 Mdot
.38952 .38556 Mdot
.56508 .44829 Mdot
.27608 .56584 Mdot
.29371 .62607 Mdot
.67831 .61703 Mdot
.75575 .66755 Mdot
.29901 .39987 Mdot
.31263 .43824 Mdot
.33689 .40253 Mdot
.29471 .53622 Mdot
.72741 .32344 Mdot
.76579 .38794 Mdot
.28369 .39386 Mdot
.68503 .26732 Mdot
.42032 .23451 Mdot
.39509 .6299 Mdot
.32407 .43741 Mdot
.57007 .34389 Mdot
.69654 .63565 Mdot
.65488 .19586 Mdot
.33815 .44585 Mdot
.76393 .30224 Mdot
.75406 .34627 Mdot
.28697 .54376 Mdot
.37979 .53873 Mdot
.55384 .3851 Mdot
.5085 .60739 Mdot
.52831 .71972 Mdot
.68713 .67665 Mdot
.72705 .63435 Mdot
.63523 .57144 Mdot
.41133 .39404 Mdot
.38991 .50243 Mdot
.70265 .34029 Mdot
.5704 .48824 Mdot
.70892 .33582 Mdot
.3526 .43304 Mdot
.46236 .39405 Mdot
.63403 .18227 Mdot
.30537 .67253 Mdot
.52646 .41565 Mdot
.59824 .47972 Mdot
.6201 .4592 Mdot
.49175 .38254 Mdot
.44373 .66631 Mdot
.58307 .38584 Mdot
.72488 .67051 Mdot
.72802 .31715 Mdot
.37717 .55968 Mdot
.55419 .38023 Mdot
.4862 .75155 Mdot
.49516 .31825 Mdot
.49583 .43094 Mdot
.45772 .66508 Mdot
.7119 .66479 Mdot
.54617 .69676 Mdot
.40793 .72753 Mdot
.42012 .63255 Mdot
.54008 .30979 Mdot
.60406 .48348 Mdot
.71294 .65276 Mdot
.42203 .68931 Mdot
.40043 .70644 Mdot
.77578 .66259 Mdot
.39441 .44488 Mdot
.43667 .77222 Mdot
.68566 .61633 Mdot
.55938 .35207 Mdot
.39304 .49521 Mdot
.53279 .61577 Mdot
.28523 .36989 Mdot
.70422 .28466 Mdot
.65259 .53652 Mdot
.60501 .5039 Mdot
.28989 .35913 Mdot
.72562 .29135 Mdot
.46052 .6732 Mdot
.85047 .53761 Mdot
.54585 .63034 Mdot
.29832 .6467 Mdot
.34905 .36802 Mdot
.5554 .5298 Mdot
.32237 .36178 Mdot
.39406 .40348 Mdot
.41375 .30567 Mdot
.48708 .78873 Mdot
.56537 .53315 Mdot
.43441 .62764 Mdot
.48204 .61506 Mdot
.57362 .41407 Mdot
.31676 .35784 Mdot
.43125 .3606 Mdot
.61579 .51787 Mdot
.55606 .30681 Mdot
.62811 .53372 Mdot
.57478 .42556 Mdot
.4683 .77573 Mdot
.71411 .65643 Mdot
.74507 .6717 Mdot
.49414 .45647 Mdot
.71302 .2719 Mdot
.33999 .3258 Mdot
.68022 .33177 Mdot
.41926 .52544 Mdot
.45608 .77998 Mdot
.43586 .27173 Mdot
.6537 .19775 Mdot
.37955 .48569 Mdot
.69918 .43706 Mdot
.74174 .34767 Mdot
.67941 .34792 Mdot
.50262 .74855 Mdot
.2501 .67133 Mdot
.69845 .67339 Mdot
.56021 .39495 Mdot
.28114 .65471 Mdot
.6607 .54358 Mdot
.68188 .36834 Mdot
.54683 .47399 Mdot
.54115 .63139 Mdot
.28027 .37339 Mdot
.51055 .43578 Mdot
.62504 .67204 Mdot
.28733 .36921 Mdot
.37673 .44179 Mdot
.68466 .29115 Mdot
.31018 .31031 Mdot
.46086 .55115 Mdot
.38172 .48305 Mdot
.65153 .21273 Mdot
.63473 .67857 Mdot
.41811 .25593 Mdot
.25007 .34417 Mdot
.48416 .7908 Mdot
.71472 .62863 Mdot
.64862 .22292 Mdot
.45525 .74955 Mdot
.55406 .45318 Mdot
.28978 .7018 Mdot
.38816 .48387 Mdot
.25757 .59716 Mdot
.41927 .72983 Mdot
.63327 .42538 Mdot
.40291 .48709 Mdot
.65401 .18755 Mdot
.67998 .35987 Mdot
.49661 .46416 Mdot
.25818 .37118 Mdot
.77961 .64735 Mdot
.40799 .26253 Mdot
.44103 .77862 Mdot
.72995 .32665 Mdot
.52235 .73733 Mdot
.83872 .59299 Mdot
.51065 .58587 Mdot
.35984 .51278 Mdot
.62522 .41315 Mdot
.28241 .65894 Mdot
.55869 .51259 Mdot
.30703 .43213 Mdot
.29184 .6668 Mdot
.63194 .38484 Mdot
.54017 .56416 Mdot
.27288 .53353 Mdot
.36955 .50941 Mdot
.49516 .56036 Mdot
.54663 .63847 Mdot
.44726 .61368 Mdot
.46842 .59181 Mdot
.41739 .74172 Mdot
.48024 .55029 Mdot
.30504 .67468 Mdot
.43651 .73083 Mdot
.35201 .4199 Mdot
.69153 .62839 Mdot
.58141 .41431 Mdot
.61045 .59772 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3<ooooo`Co0000NOooool001cooooo00?o0000ooooooooool0
c?ooool4o`0007Wooooo000Looooo`03o`000?oooooooooo0<[ooooo0_l000000ooooooo0000o`00
0003o`0007Oooooo000Looooo`03o`000?oooooooooo0<[ooooo0_l00004ooooo`?o0000M_ooool0
01cooooo00?o0000ooooooooool0boooool4o`000004ooooool0003o0000o`0007Kooooo00001_oo
ooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003ooooooooo
o`3;ooooo`Co00000oooool2o`0007Gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`3=ooooo`;o
00000_ooool4o`0007Cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo
00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`3<ooooo`Co000000?oooooo`000?l00000
0ol0001cooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ
8B7ok^k^00Kooooo0ol0003<ooooo`Co000000Coooooo`000?l0003ooooo0_l0001cooooo`0000?o
ooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00Gooooo00?o
0000ooooooooool0eOooool2o`0007;ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooo
oooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3?ooooo`;o00000_ooool5
o`00077ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RH
oa0@4006ooooo`03o`000?oooooooooo0<oooooo0_l00002ooooo`Go0000LOooool00006ooooooo^
k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000oooo
ooooool0d?ooool2o`000003ooooool0003o000000?o000000?oooooo`000?l00000K_ooool001co
oooo00?o0000ooooooooool0d?ooool2o`0000Cooooo0_l000000ooooooo0000o`00001^ooooo`00
7?ooool00ol0003oooooooooo`3?ooooo`Go00001oooool2o`0006cooooo000Looooo`03o`000?oo
oooooooo0<oooooo1Ol00007ooooo`;o0000K?ooool001cooooo00?o0000ooooooooool0coooool2
o`0000_ooooo0_l0001[ooooo`007?ooool00ol0003oooooooooo`3?ooooo`;o00002oooool2o`00
00;ooooo0_l0001Wooooo`007?ooool00ol0003oooooooooo`3Cooooo`;o00000oooool2o`0000Go
oooo0ol0001Wooooo`007?ooool00ol0003oooooooooo`25ooooo`;o0000C?ooool2o`0000?ooooo
0_l00005ooooo`;o0000J?ooool001cooooo00?o0000ooooooooool0QOooool2o`0000Oooooo0_l0
0012ooooo`;o00003_ooool3o`0006Cooooo000Looooo`03o`000?oooooooooo08cooooo1Ol00011
ooooo`?o00000_ooool2o`0000Wooooo1Ol0001Rooooo`007?ooool00ol0003oooooooooo`1ooooo
o`;o00002oooool7o`00043ooooo0_l00002ooooo`;o00003?ooool2o`0006;ooooo000Looooo`03
o`000?oooooooooo07cooooo0_l000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l0
00000_l000000ooooooo0000o`000005o`0003kooooo0_l0001cooooo`007?ooool2o`0007_ooooo
1?l00009ooooo`;o000000?oooooo`000?l000000oooool2o`0000;ooooo0ol0000nooooo`;o0000
00?oooooo`000?l00000L?ooool001cooooo00?o0000ooooooooool0N_ooool2o`0001?ooooo0_l0
00000ooooooo0000o`000002o`000003ooooool0003o000003_ooooo0_l000000ooooooo0000o`00
000>ooooo`Co0000G_ooool001cooooo00?o0000ooooooooool0N_ooool3o`0000Oooooo0_l00000
0ooooooo0000o`000009ooooo`Oo0000>oooool2o`0000;ooooo0_l00006ooooo`;o00001Oooool4
o`0005kooooo000Looooo`03o`000?oooooooooo07[ooooo0ol00007ooooo`;o000000?oooooo`00
0?l000003?ooool5o`0003kooooo0_l00006ooooo`?o00000_ooool4o`00063ooooo000Looooo`03
o`000?oooooooooo087ooooo0_l00008ooooo`;o00000_ooool2o`0000Gooooo1Ol00016ooooo`;o
00000_ooool2o`0006;ooooo000Looooo`03o`000?oooooooooo087ooooo0_l000000ooooooo0000
o`000002o`0000?ooooo0_l00002ooooo`;o00001_ooool5o`0003oooooo0_l00002ooooo`;o0000
J?ooool001cooooo00?o0000ooooooooool0Q?ooool4o`0000Oooooo1?l00006ooooo`Co0000?_oo
ool2o`000004ooooool0003o0000o`0000;ooooo1Ol0001Qooooo`007?ooool00ol0003ooooooooo
o`24ooooo`Co00000_ooool3o`0000Cooooo0_l00006ooooo`Go0000>oooool2o`0000?ooooo0_l0
0002ooooo`Ko0000HOooool001cooooo00?o0000ooooooooool0Q?ooool4o`0000;ooooo0ol00004
ooooo`Co00001?ooool6o`0003[ooooo0_l00007ooooo`Co00000oooool2o`0005kooooo000Loooo
o`03o`000?oooooooooo08gooooo2?l00006ooooo`Co0000B_ooool2o`0000;ooooo0_l0001Joooo
o`007?ooool00ol0003oooooooooo`2<ooooo`_o00001?ooool5o`0003Wooooo0_l0000Aooooo`?o
00000_ooool2o`0005Kooooo000Looooo`03o`000?oooooooooo08_ooooo3Ol00003ooooo`Ko0000
>?ooool2o`0000;ooooo0_l00002ooooo`;o00002Oooool2o`0000?ooooo0_l0001Fooooo`007?oo
ool00ol0003oooooooooo`24ooooo`;o00000oooool8o`000003ooooool0003o000000Ko00000_oo
ool6o`0003Oooooo0_l00002ooooo`;o00000_ooool2o`0000Cooooo0_l0001Pooooo`007?ooool0
0ol0003oooooooooo`24ooooo`;o00000oooool2o`000003ooooool0003o000000Sooooo1?l00002
ooooo`Oo00004oooool3o`00023ooooo1?l00002ooooo`;o00001_ooool3o`0000Oooooo0_l0001F
ooooo`007?ooool00ol0003oooooooooo`26ooooo`Co00003Oooool<o`0000Wooooo0_l00007oooo
o`Co00008_ooool2o`0000;ooooo0_l00007ooooo`Co00001Oooool2o`0005Kooooo000Looooo`03
o`000?oooooooooo08;ooooo0_l00002ooooo`Co00003_ooool5o`000003ooooool0003o000000?o
00002?ooool4o`0000Cooooo1ol0000Pooooo`;o00003_ooool2o`000004ooooool0003o0000oooo
o`;o0000Eoooool001cooooo0_l00022ooooo`So00003oooool3o`0000?ooooo1Ol00008ooooo`Ko
00000_ooool2o`000003ooooool0003o000000;o00008?ooool2o`00017ooooo0_l000000ooooooo
0000o`00001Gooooo`007?ooool00ol0003oooooooooo`21ooooo`;o000000?oooooo`000?l00000
0_l0000@ooooo`_o00002?ooool7o`0000;ooooo0_l00007ooooo`;o0000:_ooool2o`0000Wooooo
0_l0001Cooooo`007?ooool00ol0003oooooooooo`23ooooo`Co00004_ooool;o`0000Oooooo2?l0
00000ooooooo0000o`000004ooooo`Go0000:Oooool3o`0000Wooooo0ol0001Booooo`007?ooool0
0ol0003oooooooooo`1Nooooo`Go00008?ooool3o`0001?ooooo1?l000000ooooooo0000o`000004
o`0000Oooooo2?l00007ooooo`Ko0000:?ooool2o`0000Wooooo1?l0001Booooo`007?ooool00ol0
003oooooooooo`1Gooooo`;o00001Oooool9o`0003Cooooo0ol000000ooooooo0000o`000003o`00
00Oooooo0ol00009ooooo`;o00000_ooool5o`0002;ooooo0_l0000>ooooo`?o0000E?ooool001co
oooo00?o0000ooooooooool0E_ooool3o`0000;ooooo0_l000001Ooooooo0000o`000?l0003ooooo
00Go0000=Oooool2o`000003ooooool0003o000000?o00001oooool5o`0000Oooooo0_l00004oooo
o`Co00008Oooool2o`0000kooooo1?l0001Cooooo`007?ooool00ol0003oooooooooo`1Fooooo`;o
00000_ooool3o`000003ooooool0003o000000So0000=?ooool8o`0000Kooooo1_l0000=ooooo`Co
000000?oooooo`000?l000009Oooool3o`0000Sooooo1Ol0001@ooooo`007?ooool00ol0003ooooo
ooooo`1Cooooo`;o00000_ooool2o`000005ooooool0003o0000o`000?ooool02ol00002ooooo`;o
0000;oooool8o`0000Kooooo0_l00005ooooo`;o00002oooool6o`0001[ooooo0_l00009ooooo`?o
00000oooool3o`0000?ooooo1?l0001@ooooo`007?ooool00ol0003oooooooooo`1Aooooo`Co0000
0_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000:o`000003ooooool0003o000001;ooooo
0_l0000Mooooo`Ko00001_ooool2o`0000Gooooo0ol00007ooooo`Oo000000?oooooo`000?l00000
6Oooool4o`0000Kooooo1?l00003ooooo`?o00001Oooool2o`00053ooooo000Looooo`03o`000?oo
oooooooo057ooooo0_l00007ooooo`?o000000?oooooo`000?l000003Ol0000Booooo`;o00007Ooo
ool6o`0000Kooooo0_l00006ooooo`;o00001oooool7o`000003ooooool0003o000001Cooooo0_l0
0004ooooo`?o000000?oooooo`000?l000000oooool5o`0000[ooooo0_l0001@ooooo`007?ooool0
0ol0003oooooooooo`1?ooooo`?o00002?ooool2o`0000;ooooo3ol0000@ooooo`;o00008?ooool5
o`0000Kooooo0_l0000>ooooo`;o00001?ooool3o`0001Kooooo0ol00007ooooo`;o00001?ooool4
o`0000?ooooo0ol0001Fooooo`007?ooool00ol0003oooooooooo`1?ooooo`?o00003?ooool?o`00
013ooooo0_l0000Gooooo`?o00001_ooool6o`0000Gooooo0_l0000>ooooo`;o00001?ooool5o`00
01Cooooo0ol00002ooooo`;o00003_ooool5o`0005Kooooo000Looooo`03o`000?oooooooooo04go
oooo0ol0000>oooooa3o000000?oooooo`000?l000008?ooool9o`0000Gooooo1_l00006ooooo`;o
00002?ooool2o`0000?ooooo0_l00004ooooo`Oo00005Oooool4o`0000;ooooo0_l0000:ooooo`Co
0000Eoooool001cooooo00?o0000ooooooooool0COooool3o`0000Gooooo0_l00008ooooo`oo0000
00?oooooo`000?l000007Oooool=o`000004ooooool0003o0000ooooo`Go00001oooool2o`0000So
oooo0_l00009ooooo`Oo00003oooool2o`0000?ooooo0ol00002ooooo`Go00002oooool2o`0000;o
oooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o00001Oooool2o`0000Oooooo
4_l000000ooooooo0000o`00000Joooooa7o00000_ooool4o`0000[ooooo0_l00003ooooo`Co0000
2_ooool5o`00013ooooo0_l00003ooooo`;o00000_ooool3o`000003ooooool0003o000000oooooo
0_l0001Cooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o00003OoooolCo`000003ooooool0
003o000001Kooooo0ol000000ooooooo0000o`00000?o`000003ooooool0003o000000?o00001Ooo
ool3o`0000;ooooo0ol00002ooooo`Co00001_ooool2o`0000;ooooo1_l0000@ooooo`;o00001_oo
ool2o`0000;ooooo0_l00007ooooo`?o00000_ooool2o`0000;ooooo0_l0001Booooo`007?ooool2
o`00057ooooo0_l0000;oooooa?o000000?oooooo`000?l000005OoooolKo`0000Kooooo0ol00003
ooooo`;o00003?ooool2o`0000Cooooo1?l0000=ooooo`;o000000?oooooo`000?l000000_l00003
ooooo`?o00000_ooool2o`0000Oooooo0ol000001?oooooo0000o`000?l00002ooooo`Co0000D?oo
ool001cooooo00?o0000ooooooooool0C?ooool2o`0000;ooooo0_l0000;oooooa?o00006?oooolK
o`0000Oooooo0_l00006ooooo`?o00003Oooool4o`0000kooooo0_l00003ooooo`;o00000oooool3
o`0000[ooooo2?l00002ooooo`Co0000D?ooool001cooooo00?o0000ooooooooool0B_ooool4o`00
00oooooo4ol0000Eooooo`;o000000?oooooo`000?l000006Ol00007ooooo`;o00001_ooool3o`00
00Cooooo1?l00005ooooo`Co00008Oooool2o`0000;ooooo1Ol000000ooooooo0000o`000003o`00
05?ooooo000Looooo`03o`000?oooooooooo04[ooooo1?l0000<ooooo`;o00001?ooool?o`0000Ko
oooo0_l0000>oooooago00002Oooool2o`0000Gooooo0_l00002ooooo`Oo00001?ooool6o`00017o
oooo0ol0000;ooooo`?o00000oooool2o`0000Cooooo1Ol0001Booooo`007?ooool00ol0003ooooo
ooooo`1<ooooo`;o00002Oooool2o`000003ooooool0003o000000Oooooo2_l00002ooooo`;o0000
0_ooool4o`0000Sooooo0_l00002ooooo`;o000000?oooooo`000?l000006_l00009ooooo`?o0000
2?ooool5o`0000?ooooo0_l000001?oooooo0000o`000?ooool3o`00017ooooo0ol0000;ooooo`;o
00003Oooool2o`0005;ooooo000Looooo`03o`000?oooooooooo04_ooooo1?l00008ooooo`;o0000
2_ooool5o`0000;ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00009ooooo`?o0000
0_oooolNo`0000[ooooo1?l00005ooooo`;o000000?oooooo`000?l000001Oooool6o`0000oooooo
0_l0000@ooooo`Oo00002Oooool2o`0005;ooooo000Looooo`03o`000?oooooooooo04_ooooo1ol0
0005ooooo`;o000000?oooooo`000?l000001oooool2o`000003ooooool0003o000000;o00000ooo
ool3o`0000kooooo0_l00004oooooago00003?ooool2o`0000Gooooo0_l000000ooooooo0000o`00
0007ooooo`Co00003oooool2o`0000Gooooo0_l00009ooooo`So000000?oooooo`000?l000001?oo
ool3o`0005;ooooo000Looooo`03o`000?oooooooooo04gooooo1Ol00005ooooo`Go000000?ooooo
o`000?l000002Oooool2o`0000Cooooo0_l0000>ooooo`;o00000_oooolNo`0000gooooo0_l00000
0ooooooo0000o`000003o`0000_ooooo1?l0000Fooooo`;o00000oooool3o`0000?ooooo2ol00004
ooooo`?o0000D_ooool001cooooo00?o0000ooooooooool0C_ooool4o`0000Gooooo1?l00002oooo
o`;o00002?ooool4o`0001Gooooo8?l0000@ooooo`Go00002_ooool5o`0001?ooooo0ol00004oooo
o`Co000000?oooooo`000?l000003Ol000000ooooooo0000o`000002o`0005;ooooo000Looooo`03
o`000?oooooooooo04oooooo1?l00004ooooo`;o00002_ooool2o`000003ooooool0003o000000?o
00003oooool2o`0000Cooooo7_l0000Booooo`;o00003?ooool3o`0001;ooooo0_l00002ooooo`?o
00001?ooool2o`0000;ooooo4?l000000ooooooo0000o`000002o`0005;ooooo000Looooo`03o`00
0?oooooooooo04oooooo1_l0000>ooooo`;o000000?oooooo`000?l000000ol0000?ooooo`?o0000
1?oooolHo`000003ooooool0003o000000?o00003_ooool5o`0000_ooooo1?l0000;ooooo`Co0000
00?oooooo`000?l000000_l00003ooooo`Co00000_ooool2o`000003ooooool0003o000000go0000
0_ooool5o`0005;ooooo000Looooo`03o`000?oooooooooo05;ooooo0ol0000Booooo`Go00003ooo
ool2o`0000;ooooo8?l0000>ooooo`Go00002Oooool5o`0000Wooooo0_l000000ooooooo0000o`00
0002o`000003ooooool0003o000000Oooooo0_l00004oooooa3o00000_ooool3o`0005Cooooo000L
ooooo`03o`000?oooooooooo05Cooooo0_l0000Dooooo`;o000000Coooooo`000?l0003o00002ooo
oolSo`0000kooooo1_l00008ooooo`Co00002_ooool3o`0000Wooooo0_l00008oooooaWo0000D_oo
ool001cooooo00?o0000ooooooooool0E?ooool3o`0001Kooooo1?l0000:ooooob7o00004?ooool6
o`0000?ooooo0_l00003ooooo`Co00002_ooool3o`0000;ooooo0ol00004ooooo`;o00002?oooolF
o`000003ooooool0003o000005;ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ
8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`1Eooooo`Go00004ooo
ool5o`0000Kooooo0_l00005oooooaco00004?ooool2o`0000;ooooo0_l00004ooooo`;o000000?o
ooooo`000?l000000_l0000Aooooo`?o00002oooool2o`000003ooooool0003o000001Go0000E?oo
ool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1Gooooo`Co00002oooool2o`0000Kooooo1?l00006ooooo`;o0000
1?oooolMo`0000oooooo0ol00002ooooo`;o000000?oooooo`000?l000000oooool5o`0001kooooo
5ol00002ooooo`;o0000E?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Ooo
ool5o`0000Kooooo00?o0000ooooooooool0Eoooool4o`0000;ooooo0_l00007ooooo`;o00002?oo
ool2o`0000_ooooo6ol0000@ooooo`Go00001Oooool7o`00027ooooo5ol000000ooooooo0000o`00
001Eooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04odA4A?oMgMgo
ooooo`0000Oooooo0ol0001Gooooo`Go000000?oooooo`000?l000002oooool3o`0000?ooooo0_l0
000;oooooa_o00004?ooool2o`0000Kooooo0_l000000ooooooo0000o`000004o`0001Oooooo0_l0
0009oooooaCo00000oooool2o`0005Gooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`1Hooooo`Co00002Ooo
ool2o`0000?ooooo0ol00003ooooo`?o00001?ooool2o`0000?ooooo6_l0000Booooo`;o00000ooo
ool5o`000004ooooool0003o0000o`0001Gooooo0_l00003ooooo`;o00001_ooool2o`000003oooo
ool0003o000000ko000000?oooooo`000?l00000Foooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo05Wooooo0_l0
0002ooooo`?o00000_ooool2o`000003ooooool0003o000000Wooooo0ol00004ooooo`;o00000ooo
ool@o`000003ooooool0003o000000Oo00005oooool5o`000003ooooool0003o000000Cooooo0_l0
0005ooooo`;o00002Oooool2o`0000_ooooo0_l000000ooooooo0000o`00000@o`0000;ooooo0_l0
001Hooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo
00?o0000ooooooooool0FOooool2o`000003ooooool0003o000000;o00000_ooool4o`0000_ooooo
0_l00002ooooo`;o00000_ooool2o`0000;ooooo6?l0000Cooooo`;o00001Oooool3o`0000Oooooo
0ol00004ooooo`;o00006?oooolCo`0000;ooooo1?l0001Fooooo`0000Koooooonk^k_lb<S;o0000
oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0FOooool2o`000003
ooooool0003o000000;o00001?ooool2o`0000_ooooo1_l00002oooooaWo00005Oooool3o`0000Go
oooo0_l00006ooooo`Ko000000Coooooo`000?l0003o00001_ooool6o`0000gooooo4ol000000ooo
oooo0000o`000003o`0005Kooooo000Looooo`03o`000?oooooooooo05Wooooo0_l00002ooooo`Ko
00002?ooool2o`0000?ooooo1Ol00006ooooo`;o000000Coooooo`000?l0003o00000oooool2o`00
00?ooooo2Ol0000Eooooo`;o00003_ooool6o`000004ooooool0003o0000o`0000Kooooo1_l00008
ooooo`;o00000_oooolCo`0000;ooooo1?l0001Gooooo`007?ooool00ol0003oooooooooo`1Moooo
o`Ko00002?ooool2o`0000;ooooo1Ol00009ooooo`?o00001_ooool8o`0001gooooo0_l00004oooo
o`;o00003_ooool2o`0000[ooooo0_l00006ooooo`;o000000?oooooo`000?l000004Ol00002oooo
o`Co0000F?ooool001cooooo00?o0000ooooooooool0G_ooool5o`0000cooooo0_l000001?oooooo
0000o`000?ooool2o`0000Kooooo0ol00006ooooo`So00007Oooool2o`0000Cooooo0_l00002oooo
o`;o00001?ooool2o`0000Cooooo0_l0000:ooooo`;o00002OoooolAo`0000Cooooo0ol0001Ioooo
o`007?ooool00ol0003oooooooooo`1Pooooo`Co00001Oooool2o`0000[ooooo0_l00005ooooo`Go
00001?ooool7o`0001cooooo0_l0000;ooooo`Co00000_ooool2o`0000gooooo0_l00008ooooo`;o
00000oooool3o`000003ooooool0003o000000So000000?oooooo`000?l000001?ooool2o`0005Wo
oooo000Looooo`03o`000?oooooooooo063ooooo1?l00005ooooo`;o00002?ooool2o`0000Oooooo
1Ol00004ooooo`Oo00004Oooool4o`0000;ooooo0_l00003ooooo`;o00003Oooool2o`00017ooooo
0_l00007ooooo`?o00000oooool4o`000003ooooool0003o000000;o000000?oooooo`000?l00000
0_l000000ooooooo0000o`00001Oooooo`007?ooool00ol0003oooooooooo`1Pooooo`Go00002_oo
ool2o`0000;ooooo0_l00009ooooo`;o00001_ooool8o`0000oooooo1?l00002ooooo`?o0000:ooo
ool4o`0000;ooooo1_l000000ooooooo0000o`000002o`0000?ooooo0_l000000ooooooo0000o`00
001Oooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o000000?oooooo`000?l000001?l00006
ooooo`;o00003?ooool3o`0000Sooooo1_l0000Dooooo`Co0000:oooool3o`0000?ooooo1_l00000
0ooooooo0000o`000002o`0000?ooooo1?l0001Pooooo`007?ooool00ol0003oooooooooo`1Roooo
o`Oo00005?ooool5o`0000Oooooo1?l0000Eooooo`?o00004oooool2o`00013ooooo1Ol00002oooo
o`?o00001Oooool4o`0000;ooooo1Ol00003ooooo`;o0000H?ooool001cooooo00?o0000oooooooo
ool0H_ooool7o`0000gooooo0ol00005ooooo`Co00001oooool2o`0000Cooooo0_l00003ooooo`;o
00001?ooool2o`0000Kooooo0_l0000=ooooo`;o00001Oooool2o`0000gooooo0_l000000ooooooo
0000o`000009o`0000Kooooo0ol00004ooooo`;o0000IOooool001cooooo00?o0000ooooooooool0
IOooool4o`000003ooooool0003o000000[ooooo0ol00003ooooo`;o00000_ooool2o`0000Oooooo
0_l00004ooooo`;o00000oooool2o`0000Cooooo1Ol0000@ooooo`Co00001?ooool2o`0000Kooooo
0_l00006ooooo`;o000000?oooooo`000?l000002ol00004ooooo`Co00000_ooool2o`0006Kooooo
000Looooo`03o`000?oooooooooo06Sooooo1?l00007ooooo`;o00001oooool2o`0001Gooooo0_l0
0004ooooo`Ko00003_ooool4o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`;o00001ooo
ool?o`0000Cooooo1?l00002ooooo`;o0000I_ooool001cooooo0_l0001Wooooo`Co00002Oooool2
o`0000Cooooo0_l00009ooooo`;o00003Oooool4o`0000;ooooo1_l0000>ooooo`;o00001Oooool2
o`0000oooooo4?l00007ooooo`;o0000Joooool001cooooo00?o0000ooooooooool0IOooool5o`00
00Wooooo1?l00002ooooo`Co00001oooool2o`000003ooooool0003o000000Sooooo1_l00002oooo
o`;o00002Oooool2o`0000[ooooo0_l00004ooooo`;o00003?oooolAo`0007Cooooo000Looooo`03
o`000?oooooooooo06Gooooo1Ol000000ooooooo0000o`000006ooooo`Co00001?ooool4o`0000So
oooo0_l000000ooooooo0000o`000005ooooo`Go00001?ooool2o`000003ooooool0003o000000?o
oooo1?l0000:ooooo`;o00001?ooool4o`0000Oooooo0_l000000ooooooo0000o`00000?o`0007Co
oooo000Looooo`03o`000?oooooooooo06Sooooo1Ol0000@ooooo`;o00002oooool2o`0000kooooo
0_l000000ooooooo0000o`000003ooooo`;o00004Oooool5o`0000?ooooo0_l000000ooooooo0000
o`00000Co`0007Cooooo000Looooo`03o`000?oooooooooo06Sooooo1Ol0000Hooooo`?o00005_oo
ool2o`0000Gooooo0_l0000>ooooo`;o00001_ooool2o`000003ooooool0003o000001?o0000M?oo
ool001cooooo00?o0000ooooooooool0JOooool4o`0001Sooooo0ol00007ooooo`;o00003Oooool2
o`0000Gooooo0_l0000Kooooo`;o000000?oooooo`000?l000003Ol0001eooooo`007?ooool00ol0
003oooooooooo`1/ooooo`;o00000_ooool2o`0001gooooo0_l0000Wooooo`;o000000?oooooo`00
0?l000001?oooolDo`0007Cooooo000Looooo`03o`000?oooooooooo06cooooo0_l00002ooooo`;o
0000:?ooool2o`0001;ooooo0_l00008ooooo`;o000000?oooooo`000?l000000_oooolCo`000003
ooooool0003o000007Cooooo000Looooo`03o`000?oooooooooo06cooooo0ol0000Jooooo`;o0000
3oooool2o`0001;ooooo0_l00008ooooo`?o00000oooool3o`000003ooooool0003o0000017o0000
M?ooool001cooooo00?o0000ooooooooool0K?ooool3o`0000Kooooo0_l0000Booooo`;o00000ooo
ool2o`0002Sooooo1Ol000001Ooooooo0000o`000?l0003ooooo01?o0000M?ooool001cooooo00?o
0000ooooooooool0KOooool4o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o00004?oo
ool5o`00013ooooo0_l0000Fooooo`;o00000_oooolFo`0007Cooooo000Looooo`03o`000?oooooo
oooo06gooooo1?l00004ooooo`;o000000?oooooo`000?l000001?l0000<ooooo`;o00000_ooool5
o`00013ooooo1?l0000Booooo`;o00001OoooolDo`0007Gooooo000Looooo`03o`000?oooooooooo
06gooooo1?l00004ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o00002Oooool2o`00
00;ooooo0_l0000Eooooo`;o00003Oooool4o`000003ooooool0003o000000Gooooo5_l0001coooo
o`007?ooool00ol0003oooooooooo`1_ooooo`;o00002Oooool2o`0000?ooooo0_l000000ooooooo
0000o`00000Nooooo`;o00004?ooool4o`0000;ooooo0_l00005oooooaGo0000Loooool001cooooo
00?o0000ooooooooool0Koooool4o`0000Oooooo1?l00004ooooo`;o00001?ooool2o`0001Sooooo
0_l0000Aooooo`;o000000?oooooo`000?l000000_l00004oooooa;o0000Moooool001cooooo00?o
0000ooooooooool0Koooool4o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l000001ooo
ool2o`0002gooooo0ol00005oooooa?o0000Moooool001cooooo0_l0001`ooooo`So00002?ooool2
o`0000_ooooo0_l0000Oooooo`;o00002?ooool3o`0000Gooooo5Ol0001eooooo`007?ooool00ol0
003oooooooooo`1aooooo`Go00001Oooool2o`0000[ooooo0_l00003ooooo`;o00007oooool2o`00
00Sooooo0_l00006oooooa;o000000?oooooo`000?l00000MOooool001cooooo00?o0000oooooooo
ool0L_ooool2o`0000Oooooo0_l0000:ooooo`;o00008?ooool2o`0000cooooo0ol00005oooooa;o
0000N?ooool001cooooo00?o0000ooooooooool0LOooool5o`0000Oooooo0_l0000Rooooo`;o0000
1_ooool2o`0000gooooo0_l00006oooooa3o0000NOooool001cooooo00?o0000ooooooooool0LOoo
ool5o`0000Oooooo0_l0000Pooooo`Co00003?ooool2o`000003ooooool0003o000000cooooo0ol0
00000ooooooo0000o`00000;o`0007Sooooo000Looooo`03o`000?oooooooooo077ooooo1Ol00003
ooooo`;o00000oooool2o`0001oooooo0_l0000>ooooo`;o000000?oooooo`000?l000003?ooool2
o`0000?ooooo1ol00003ooooo`;o0000N?ooool001cooooo00?o0000ooooooooool0Loooool3o`00
0003ooooool0003o000000;o00000oooool2o`0000cooooo0_l0000booooo`;o00000_ooool2o`00
0003ooooool0003o000000;o0000O_ooool001cooooo00?o0000ooooooooool0Loooool2o`0000;o
oooo0_l00005ooooo`;o00003?ooool2o`0001Gooooo0_l00002ooooo`;o00006oooool2o`0000Ko
oooo0ol0001jooooo`007?ooool00ol0003oooooooooo`1Jooooo`?o00000_ooool4o`00013ooooo
0ol0000>ooooo`;o00007Oooool2o`0000;ooooo0_l0000<ooooo`;o00002Oooool3o`0000Cooooo
0_l00003ooooo`?o0000N_ooool001cooooo00?o0000ooooooooool0F?ooool6o`000003ooooool0
003o000000Co00003_ooool3o`0000Kooooo0_l00006ooooo`;o00001oooool2o`0002?ooooo1Ol0
0009ooooo`?o000000Coooooo`000?l0003ooooo0_l00020ooooo`007?ooool00ol0003ooooooooo
o`1Hooooo`;o00000_ooool2o`000003ooooool0003o000000Co00003_ooool4o`0000Gooooo0_l0
00000ooooooo0000o`00000<ooooo`;o00006?ooool2o`0000?ooooo0_l00003ooooo`Co00003ooo
ool4o`00087ooooo000Looooo`03o`000?oooooooooo05Cooooo4ol0000=ooooo`?o00001Oooool2
o`000003ooooool0003o000000Oooooo0_l0000Mooooo`?o00000_ooool2o`0000?ooooo0_l00000
0ooooooo0000o`000003o`0000_ooooo1_l00019ooooo`;o0000=?ooool001cooooo00?o0000oooo
ooooool0E?oooolEo`0000_ooooo0ol000000ooooooo0000o`000006ooooo`;o00001_ooool2o`00
01kooooo0_l0000:ooooo`Go00002oooool2o`0000;ooooo1?l00004ooooo`;o0000?_ooool2o`00
0003ooooool0003o000003Cooooo000Looooo`03o`000?oooooooooo057ooooo0ol000001?oooooo
0000o`000?ooool=o`000003ooooool0003o000000?o00002Oooool3o`000003ooooool0003o0000
00;ooooo0_l00002ooooo`;o00009_ooool2o`0000Wooooo1?l0000Cooooo`;o00001?ooool2o`00
03kooooo0_l0000gooooo`007?ooool00ol0003oooooooooo`1Aooooo`Co00001?oooolCo`0000So
oooo1?l00004ooooo`;o0000<_ooool2o`000003ooooool0003o000000;o00003oooool2o`0000Oo
oooo0_l00002ooooo`;o0000=oooool2o`0000?ooooo0_l0000fooooo`007?ooool00ol0003ooooo
ooooo`1@ooooo`Go00000ooooolDo`0000Wooooo0ol0000fooooo`Co00000oooool2o`0000Cooooo
0_l00009ooooo`;o00000oooool3o`000003ooooool0003o000000;ooooo0_l0000gooooo`;o0000
0oooool4o`0003Cooooo000Looooo`;o0000DOooool3o`000003ooooool0003o000000;ooooo4ol0
0009ooooo`Co00006_ooool2o`0000Cooooo0_l0000Dooooo`;o00001Oooool2o`0000;ooooo1?l0
000>ooooo`Go00000oooool2o`0003Sooooo0_l00004ooooo`;o0000=?ooool001cooooo00?o0000
ooooooooool0C_ooool4o`0000;ooooo0_l00002oooooaCo00002?ooool4o`0001[ooooo0_l00004
ooooo`;o00007oooool2o`0001;ooooo0ol00003ooooo`;o0000>?ooool2o`0003[ooooo000Loooo
o`03o`000?oooooooooo04gooooo1Ol00002ooooo`;o00000_oooolFo`0000cooooo0_l0000Ooooo
o`;o00006_ooool2o`0001?ooooo0_l00007ooooo`;o0000<_ooool2o`0003kooooo000Looooo`03
o`000?oooooooooo04gooooo0_l00005ooooo`;o000000?oooooo`000?l000005Ol00008ooooo`?o
000000?oooooo`000?l000007oooool4o`0000Gooooo0_l0000=ooooo`;o00000_ooool2o`0001?o
oooo1?l00002ooooo`Go0000<_ooool3o`0003gooooo000Looooo`03o`000?oooooooooo04gooooo
0ol00004ooooo`;o000000?oooooo`000?l000005_l00007ooooo`?o00001_ooool2o`0001Oooooo
0_l00003ooooo`;o00001Oooool2o`0000gooooo0_l00004ooooo`;o00004_ooool9o`0003Cooooo
0_l00004ooooo`?o0000=_ooool001cooooo00?o0000ooooooooool0COooool4o`0000Gooooo1_l0
0002oooooa7o00001oooool2o`0000Oooooo0_l0000Gooooo`;o00004_ooool4o`0000Oooooo1?l0
000Dooooo`Go0000>?ooool2o`0000;ooooo0ol0000fooooo`007?ooool00ol0003oooooooooo`1;
ooooo`Ko00001OoooolHo`0000Sooooo0_l00004ooooo`;o00006Oooool2o`0001?ooooo1?l00000
0ooooooo0000o`000004ooooo`Go00000_ooool2o`0004cooooo0_l00002ooooo`;o0000=oooool0
01cooooo00?o0000ooooooooool0B_ooool5o`0000Oooooo6?l00007ooooo`Go00000_ooool2o`00
01Wooooo0_l0000Hooooo`?o00001Oooool3o`0000;ooooo0_l0000;ooooo`;o0000@oooool2o`00
03Oooooo000Looooo`03o`000?oooooooooo04[ooooo1_l00005oooooaWo00001oooool5o`0000Ko
oooo0_l0000`ooooo`Go00003Oooool5o`0000;ooooo0_l00012ooooo`?o0000=oooool001cooooo
00?o0000ooooooooool0C?ooool6o`0000?ooooo6Ol00006ooooo`?o00002Oooool2o`0002Gooooo
0_l0000:ooooo`Go00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`000004o`0004Kooooo
0ol0000gooooo`007?ooool00ol0003oooooooooo`1>ooooo`Go00000ooooolHo`0000Kooooo1?l0
000Zooooo`;o00000oooool2o`0000[ooooo0_l000000ooooooo0000o`000002ooooo`;o00001?oo
ool2o`000003ooooool0003o000000Co0000Aoooool2o`0003Oooooo000Looooo`03o`000?oooooo
oooo04[ooooo0_l00002ooooo`Go00000ooooolHo`0000Oooooo0ol0000Kooooo`;o00002?ooool2
o`0000?ooooo0_l0000Looooo`?o00000_ooool5o`0000;ooooo0_l0000looooo`;o00000oooool2
o`0003Sooooo000Looooo`03o`000?oooooooooo04[ooooo0_l000000ooooooo0000o`000002o`00
00Gooooo6?l00006ooooo`Go00000oooool2o`0001Gooooo0_l00008ooooo`;o00000oooool2o`00
00?ooooo0_l0000Gooooo`Co000000?oooooo`000?l000000ol00002ooooo`;o0000??ooool3o`00
00;ooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`18ooooo`Co000000?oooooo`000?l0
00000_l00004oooooa?o000000?oooooo`000?l000000ol00006ooooo`Go00000oooool2o`0001So
oooo0_l00005ooooo`;o00000oooool2o`0000?ooooo1?l00008ooooo`;o00002oooool4o`0000;o
oooo1?l0000hooooo`;o00001oooool2o`0003cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^
kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`18
ooooo`Co000000?oooooo`000?l000001_ooool2o`000003ooooool0003o000001?o00001?ooool2
o`0000?ooooo0_l0000=ooooo`;o00002oooool6o`0000_ooooo0_l00004ooooo`;o00002?ooool2
o`0000_ooooo1?l000000ooooooo0000o`000005o`0003Kooooo0_l00009ooooo`;o0000>_ooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RH
ob4Q8@06ooooo`03o`000?oooooooooo04Oooooo0_l000000ooooooo0000o`000004ooooo`;o0000
1_ooool2o`000003ooooool0003o000000ko000000?oooooo`000?l000000_ooool8o`0000gooooo
0_l0000:ooooo`Go00002?ooool2o`0000?ooooo0_l00005ooooo`;o00006?ooool:o`0003kooooo
0ol0000jooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`17ooooo`;o00001_ooool3o`0000Wooooo
4?l000001?oooooo0000o`000?ooool7o`0001_ooooo0ol000000ooooooo0000o`000007ooooo`;o
00002_ooool2o`0001Cooooo3ol0000booooo`;o00000oooool2o`0000Cooooo0_l0000kooooo`00
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ
8B401_ooool3o`0004Oooooo0_l00004ooooo`Co00001?ooool3o`0000Gooooo3_l00004ooooo`Co
00005?ooool2o`0000cooooo0_l0000Cooooo`;o00005?ooool?o`0003;ooooo0_l000000ooooooo
0000o`000002o`000004ooooool0003o0000o`0003gooooo00000ooooooo0000ooooo`02ooooo`03
o`000?oooooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo
04Wooooo0_l00002ooooo`?o00001Oooool3o`0000Sooooo4ol00004ooooo`;o00003_ooool2o`00
01cooooo0_l0000Iooooo`oo00009oooool3o`0000Sooooo0_l000000ooooooo0000o`000002o`00
0004ooooool0003o0000o`0003gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo
00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`17ooooo`Co000000?oooooo`00
0?l000000_l000000ooooooo0000o`000003ooooo`;o00002?oooolBo`0000Gooooo0_l0000Qoooo
o`;o00001Oooool2o`0000;ooooo0_l0000Iooooo`Wo000000?oooooo`000?l000001?l0000Uoooo
o`Co00003Oooool2o`00047ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00?ogMgM
oa0@4?nHV9P02?ooool00ol0003oooooooooo`17ooooo`Wo000000?oooooo`000?l000000oooool2
o`0000Sooooo0_l00002ooooo`go00003Oooool2o`0001[ooooo0_l00003ooooo`Co00001Oooool4
o`0000;ooooo0_l0000?ooooo`[o000000?oooooo`000?l000001Ol0000Tooooo`?o00001Oooool2
o`0000Oooooo0_l00011ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0B?ooool8o`0000Kooooo0_l0000@ooooo`Ko0000
4?ooool2o`0000gooooo0ol00009ooooo`;o00001?ooool2o`0000Oooooo1?l00002ooooo`;o0000
3ooooolBo`0000Oooooo0_l0000Hooooo`;o000000?oooooo`000?l000001_ooool3o`0000Sooooo
0ol0000nooooo`007?ooool00ol0003oooooooooo`18ooooo`?o000000?oooooo`000?l000000_l0
000Eooooo`;o00004Oooool2o`00013ooooo0_l000001?oooooo0000o`000?l00009ooooo`;o0000
1oooool2o`0000Gooooo0_l0000DoooooaCo00001Oooool5o`0001Gooooo0_l0000:ooooo`;o0000
2?ooool3o`0003kooooo000Looooo`03o`000?oooooooooo04Sooooo1?l0000:ooooo`;o00003Ooo
ool2o`0000;ooooo0_l0000=ooooo`;o000000?oooooo`000?l000002Oooool2o`000004ooooool0
003o0000o`0000Gooooo0_l0000?ooooo`;o00006ooooolDo`0000Kooooo1?l0000Oooooo`?o0000
B_ooool001cooooo00?o0000ooooooooool0BOooool3o`0000;ooooo0_l00002ooooo`;o00000_oo
ool2o`00017ooooo1_l0000<ooooo`;o00002Oooool2o`000004ooooool0003o0000o`0000Gooooo
0_l0000:ooooo`;o00000oooool2o`0001[ooooo4Ol000000ooooooo0000o`000002ooooo`;o0000
00?oooooo`000?l000001_ooool2o`0001_ooooo0ol0001:ooooo`007?ooool00ol0003ooooooooo
o`19ooooo`;o00000oooool2o`0000;ooooo1?l00005ooooo`Go00000_ooool2o`0000Oooooo1?l0
000;ooooo`;o00003Oooool3o`00017ooooo0_l00008ooooo`?o00001oooool2o`0000_ooooo0ol0
00000ooooooo0000o`00000?o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000;ooooo
0_l00009ooooo`;o00002Oooool2o`0000?ooooo1?l0001;ooooo`007?ooool00ol0003ooooooooo
o`16ooooo`Go00001Oooool6o`0000;ooooo0_l000000ooooooo0000o`000003o`0000;ooooo0_l0
000Fooooo`;o000000?oooooo`000?l000002_ooool2o`0000kooooo0_l0000<ooooo`?o00001?oo
ool2o`000003ooooool0003o000000cooooo5?l00002ooooo`;o00001?ooool4o`0000Gooooo0_l0
00001?oooooo0000o`000?ooool3o`0000Sooooo0_l00002ooooo`Go00001_ooool2o`0004?ooooo
000Looooo`03o`000?oooooooooo04Kooooo1Ol00005ooooo`;o00001_ooool2o`0000;ooooo0_l0
000;ooooo`;o00000_ooool3o`0000Gooooo0_l00006ooooo`;o00000_ooool2o`0000;ooooo0_l0
000Booooo`;o00002?ooool2o`0000?ooooo0_l00002ooooo`Co00003_oooolEo`000004ooooool0
003o0000o`0000Kooooo0_l00005ooooo`Ko000000?oooooo`000?l000000_ooool2o`0000Sooooo
0_l000001?oooooo0000o`000?l00005ooooo`?o0000@_ooool001cooooo00?o0000ooooooooool0
A_ooool6o`0000Cooooo0_l00008ooooo`Co00000oooool2o`0000Kooooo0_l00002ooooo`?o0000
1Oooool2o`0000[ooooo0_l00002ooooo`;o00002Oooool2o`0000Gooooo0ol00004ooooo`;o0000
0oooool2o`0000?ooooo0ol000001?oooooo0000o`000?l0000?oooooaSo00002?ooool2o`0000Co
oooo0ol000000ooooooo0000o`000002o`0000?ooooo0_l00008ooooo`;o000000Coooooo`000?l0
003o00001Oooool3o`0004;ooooo000Looooo`03o`000?oooooooooo04Oooooo1Ol00009ooooo`;o
00000oooool4o`0000?ooooo0_l00009ooooo`;o00003oooool2o`0000Gooooo0ol000001?oooooo
0000o`000?l00005ooooo`;o00000_ooool2o`000004ooooool0003o0000o`0000Cooooo0_l00008
ooooo`?o000000?oooooo`000?l000000_l0000>ooooo`?o000000?oooooo`000?l000004Ol00009
ooooo`?o00000_ooool2o`0000Gooooo0_l0000>ooooo`;o00001_ooool4o`0004?ooooo000Loooo
o`03o`000?oooooooooo04Wooooo0ol00002ooooo`;o00001Oooool2o`0000?ooooo1?l00004oooo
o`;o00002?ooool2o`0000Sooooo0_l00002ooooo`;o000000?oooooo`000?l000001Oooool2o`00
00;ooooo0ol00005ooooo`;o00000_ooool2o`000003ooooool0003o000000Kooooo0_l00008oooo
o`;o000000?oooooo`000?l000000_l0000?ooooo`go000000?oooooo`000?l000001Ol0000;oooo
o`;o00000_ooool3o`0000gooooo0_l00005ooooo`;o00000_ooool3o`000004ooooool0003o0000
o`0004Cooooo000Looooo`03o`000?oooooooooo04Wooooo0ol00002ooooo`;o00001Oooool2o`00
00Kooooo0_l00003ooooo`;o00001oooool2o`000004ooooool0003o0000o`0000Gooooo2?l0000I
ooooo`Co000000Coooooo`000?l0003ooooo0_l0000Nooooo`go000000?oooooo`000?l000001_l0
00001?oooooo0000o`000?l00002ooooo`;o00001oooool2o`0000;ooooo0_l000000ooooooo0000
o`000002o`0000Cooooo0_l00005ooooo`Oo00000_ooool2o`0004Cooooo000Looooo`03o`000?oo
oooooooo04[ooooo0_l00002ooooo`;o00001Oooool2o`000003ooooool0003o000000?ooooo0_l0
0002ooooo`;o00002?ooool2o`000004ooooool0003o0000o`0000Oooooo0ol000000ooooooo0000
o`00000Kooooo`;o000000?oooooo`000?l000003oooool2o`00013ooooo5_l000001?oooooo0000
o`000?l00002ooooo`;o00002oooool2o`000003ooooool0003o000000;o00000oooool3o`0000Co
oooo0_l000001?oooooo0000o`000?ooool2o`0004Sooooo000Looooo`;o0000COooool4o`0000So
oooo0_l00003ooooo`;o00000_ooool2o`00013ooooo0_l00002ooooo`Co0000<_ooool2o`00013o
oooo5Ol0000@ooooo`;o00002Oooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo
0000o`000004ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0B?ooool2o`0000;ooooo
1?l00002ooooo`;o00000oooool3o`000003ooooool0003o0000013ooooo0_l00003ooooo`Co0000
00?oooooo`000?l00000B?oooolDo`0000Sooooo0_l00005ooooo`;o00001_ooool2o`000003oooo
ool0003o000000Gooooo0_l000000ooooooo0000o`00001>ooooo`007?ooool00ol0003ooooooooo
o`18ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`Co000000Goooooo`000?l0003o
0000ooooo`02o`0000_ooooo0_l00003ooooo`;o00000oooool4o`0003Wooooo0_l0000@oooooaKo
00000oooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000004ooooo`Co
00001oooool2o`0000?ooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`19ooooo`Co0000
1oooool2o`0000;ooooo0_l00005ooooo`;o00001oooool2o`0000Cooooo0_l00002ooooo`;o0000
5?ooool:o`0001Wooooo0_l00002ooooo`;o00004?oooolFo`0000?ooooo0_l00005ooooo`;o0000
00?oooooo`000?l000001?ooool2o`0000Wooooo0_l00002ooooo`?o00000_ooool2o`0004Wooooo
000Looooo`03o`000?oooooooooo04Wooooo0_l0000Cooooo`?o00002_ooool2o`000003ooooool0
003o000001Kooooo3ol0000Fooooo`;o00005?oooolFo`0000Kooooo0_l00004ooooo`;o00002_oo
ool2o`0000Oooooo1?l000001?oooooo0000o`000?l00019ooooo`007?ooool00ol0003ooooooooo
o`19ooooo`;o00000_ooool2o`0000cooooo1Ol00007ooooo`;o00000_ooool2o`0001Kooooo2ol0
00000ooooooo0000o`000006o`0001Wooooo0_l0000Aoooooa?o00001oooool2o`0000Cooooo0_l0
000:ooooo`;o000000Goooooo`000?l0003o0000ooooo`06o`000003ooooool0003o000004[ooooo
000Looooo`03o`000?oooooooooo04[ooooo0_l000001?oooooo0000o`000?l0000;ooooo`Co0000
2?ooool2o`0001[ooooo1ol00002ooooo`;o000000Coooooo`000?l0003ooooo1Ol0000Iooooo`;o
00004OoooolCo`0001;ooooo0_l000000ooooooo0000o`000005ooooo`?o000000?oooooo`000?l0
00000oooool2o`0004cooooo000Looooo`03o`000?oooooooooo04[ooooo0_l00002ooooo`;o0000
00?oooooo`000?l000002_ooool6o`0000Gooooo0ol0000Fooooo`?o00000oooool2o`0000Oooooo
1ol0000/oooooa7o00000_ooool2o`0000Kooooo0ol00007ooooo`Go000000Goooooo`000?l0003o
0000ooooo`05o`0000Cooooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`1:ooooo`Co0000
0oooool2o`0000[ooooo1_l00005ooooo`?o00005Oooool4o`0000[ooooo3?l0000[ooooo`So0000
00?oooooo`000?l000000_ooool2o`0000;ooooo0_l00003ooooo`Ko00002Oooool2o`000003oooo
ool0003o000000;o00000_ooool4o`0000;ooooo0_l0001>ooooo`007?ooool00ol0003ooooooooo
o`1;ooooo`Co00002_ooool4o`0000;ooooo0_l00003ooooo`Co00006?ooool3o`0000[ooooo3_l0
000Dooooo`;o00005Oooool7o`0000cooooo2_l0000:ooooo`;o00002?ooool4o`0004kooooo000L
ooooo`03o`000?oooooooooo04gooooo0ol00002ooooo`;o00001?ooool5o`0000Oooooo1?l0000G
ooooo`Co00002OoooolAo`0001;ooooo0_l0000Fooooo`Ko00003?ooool2o`000003ooooool0003o
000000?ooooo0_l0000Aooooo`Go0000D?ooool001cooooo00?o0000ooooooooool0COooool7o`00
00Cooooo0_l00009ooooo`?o00006?ooool3o`0000;ooooo0_l00006oooooa;o00004Oooool2o`00
01Sooooo1_l000000ooooooo0000o`000002o`0001Sooooo0_l00007ooooo`Co0000DOooool001co
oooo00?o0000ooooooooool0Coooool3o`000003ooooool0003o000000;o00003?ooool3o`0001Oo
oooo1Ol000000ooooooo0000o`000002o`0000Cooooo4Ol0000>ooooo`;o00000_ooool2o`0001[o
oooo2_l00002ooooo`;o000000Coooooo`000?l0003o00003oooool2o`0000Gooooo1?l0001Coooo
o`007?ooool00ol0003oooooooooo`1?ooooo`;o000000?oooooo`000?l000001?l0000Uooooo`Go
000000?oooooo`000?l000000_l00002oooooaGo00003?ooool2o`0000;ooooo0_l0000MoooooaOo
00001Oooool5o`0000Cooooo0ol0001Dooooo`007?ooool00ol0003oooooooooo`1Booooo`So0000
8_ooool4o`0000?ooooo1?l00002oooooaGo00003?ooool2o`00027ooooo6?l00004ooooo`Go0000
00?oooooo`000?l000000_ooool2o`0005Cooooo000Looooo`03o`000?oooooooooo05;ooooo0_l0
00000ooooooo0000o`000003o`0000Gooooo0ol0000Jooooo`?o00001Oooool2o`0000;ooooo0_l0
00000ooooooo0000o`00000Ao`0000cooooo0_l00002ooooo`;o00008ooooolBo`0000Cooooo0_l0
0004ooooo`;o0000F?ooool001cooooo0_l0001Fooooo`go00006_ooool3o`0000Gooooo0_l00002
ooooo`;o000000?oooooo`000?l000003_l00002ooooo`?o00002_ooool2o`0000;ooooo0_l0000U
ooooo`co00001Oooool2o`0000;ooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1Foooo
o`co00006_ooool2o`000003ooooool0003o000000[ooooo5Ol00009ooooo`;o00000_ooool2o`00
02Wooooo4?l00002ooooo`;o0000GOooool001cooooo00?o0000ooooooooool0F?ooool8o`0001co
oooo1Ol00008oooooaOo00002Oooool2o`0000;ooooo0_l0000[oooooa;o0000GOooool001cooooo
00?o0000ooooooooool0FOooool3o`00023ooooo1?l00005ooooo`?o000000?oooooo`000?l00000
5Ol00007ooooo`;o000000?oooooo`000?l000000_l0000`ooooo`ko0000GOooool001cooooo00?o
0000ooooooooool0O?ooool3o`0000Kooooo0ol00003oooooaGo00001oooool7o`0003Gooooo1?l0
00000ooooooo0000o`00001Oooooo`007?ooool00ol0003oooooooooo`1kooooo`Co00003OoooolC
o`0000Sooooo1?l0002Nooooo`007?ooool00ol0003oooooooooo`1kooooo`;o00000_ooool2o`00
00_ooooo5?l00008ooooo`?o0000W_ooool001cooooo00?o0000ooooooooool0Ooooool4o`0000_o
oooo4_l00006ooooo`Co0000Woooool001cooooo00?o0000ooooooooool0O?ooool2o`0000;ooooo
0ol0000;oooooa3o00002?ooool3o`000:3ooooo000Looooo`03o`000?oooooooooo07cooooo0ol0
00001Ooooooo0000o`000?l0003ooooo00;o00002Oooool?o`0000Gooooo0_l000000ooooooo0000
o`000002ooooo`;o0000WOooool001cooooo00?o0000ooooooooool0O?ooool3o`0000;ooooo0_l0
00000ooooooo0000o`000004ooooo`;o00001Oooool<o`0000Cooooo1_l00003ooooo`;o0000WOoo
ool001cooooo00?o0000ooooooooool0O?ooool2o`0000?ooooo0_l000000ooooooo0000o`000004
ooooo`;o00001Oooool=o`000003ooooool0003o000000Ko000000?oooooo`000?l00000Woooool0
01cooooo00?o0000ooooooooool0O?ooool4o`000003ooooool0003o000000Kooooo0_l00009oooo
o`oo000000?oooooo`000?l000001?l0002Oooooo`007?ooool00ol0003oooooooooo`1nooooo`;o
00001?ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000001oooool>o`000003
ooooool0003o000000Co0000Woooool001cooooo00?o0000ooooooooool0O_ooool3o`0000?ooooo
0_l000001?oooooo0000o`000?ooool4o`0000Oooooo2ol00003ooooo`Go0000XOooool001cooooo
00?o0000ooooooooool0O_ooool3o`0000Cooooo0_l00003ooooo`;o00002Oooool3o`0000?ooooo
0_l000000ooooooo0000o`000003ooooo`Go0000XOooool001cooooo0_l00021ooooo`;o00000ooo
ool2o`0000Oooooo1?l00005ooooo`Co00001Oooool2o`0000;ooooo0_l0002Sooooo`007?ooool0
0ol0003oooooooooo`20ooooo`;o00003?ooool4o`0000Gooooo1Ol00004ooooo`;o00000_ooool2
o`000:?ooooo000Looooo`03o`000?oooooooooo083ooooo0_l0000Hooooo`Oo0000Z?ooool001co
oooo00?o0000ooooooooool0P?ooool3o`000003ooooool0003o000001Kooooo1Ol0002Xooooo`00
7?ooool00ol0003oooooooooo`21ooooo`Go00005oooool4o`000:Sooooo000Looooo`03o`000?oo
oooooooo08;ooooo0_l000000ooooooo0000o`000002o`000004ooooool0003o0000o`0000?ooooo
0_l0002gooooo`007?ooool00ol0003oooooooooo`22ooooo`Oo000000Coooooo`000?l0003o0000
0oooool2o`000;Oooooo000Looooo`03o`000?oooooooooo08;ooooo1Ol00003ooooo`;o00001_oo
ool3o`000;Cooooo000Looooo`03o`000?oooooooooo08[ooooo0_l00006ooooo`Co0000/oooool0
01cooooo00?o0000ooooooooool0Q_ooool2o`0000Cooooo0_l00005ooooo`?o0000/oooool001co
oooo00?o0000ooooooooool0Q_ooool2o`0000Cooooo0_l00002ooooo`;o000000Coooooo`000?l0
003o0000/oooool001cooooo00?o0000ooooooooool0Q_ooool2o`0000Cooooo0_l00002ooooo`Co
0000]Oooool001cooooo00?o0000ooooooooool0Roooool3o`0000Cooooo0_l0002eooooo`007?oo
ool00ol0003oooooooooo`2:ooooo`?o00002?ooool2o`0000?ooooo0_l0002]ooooo`0000Kooooo
onk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Ko
oooo00?o0000ooooooooool0R_ooool3o`0000Kooooo1?l00003ooooo`Co0000Zoooool00006oooo
oomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06
ooooo`03o`000?oooooooooo08[ooooo0ol00003ooooo`;o000000?oooooo`000?l000001oooool3
o`000:[ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo08cooooo0_l00002ooooo`;o00002?ooool2
o`000003ooooool0003o00000:[ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000S?ooool2o`0000cooooo0ol0002/
ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05olc<c?l0003o0000
o`000?o<c<`01_ooool00ol0003oooooooooo`2?ooooo`?o00001?ooool2o`0000?ooooo0_l00003
ooooo`;o000000?oooooo`000?l00000Y?ooool00003ooooool@413ooooo00;ooooo00?o410@oooo
ooooool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0Soooool3
o`0000Cooooo1?l00006ooooo`;o000000Coooooo`000?l0003ooooo0_l0002Qooooo`0000Kooooo
ogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003o
ooooooooo`2Eooooo`;o000000?oooooo`000?l000000_l00007ooooo`;o000000Coooooo`000?l0
003o0000X?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@
413oZJVY00Kooooo00?o0000ooooooooool0U?ooool3o`0000?ooooo1_l00007ooooo`?o0000Wooo
ool001cooooo00?o0000ooooooooool0U?ooool4o`0000Cooooo1?l00008ooooo`?o0000W_ooool0
01cooooo00?o0000ooooooooool0UOooool3o`0000Cooooo0_l00004ooooo`Co00000oooool2o`00
09kooooo000Looooo`03o`000?oooooooooo09[ooooo0_l00006ooooo`Co0000Xoooool001cooooo
00?o0000ooooooooool0V_ooool2o`0000Cooooo0_l0002Wooooo`007?ooool00ol0003ooooooooo
o`2Pooooo`;o0000Yoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o
0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?o
oooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool3o`000?ooooooB_oo
ool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooo
oe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0
oooooomBooooo`004_ooool00omEEEGoIVIVo`00003ooooooeCooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo002Uooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@oooooooo
ool05_ooool4o`000003oa0@4?oooooooooo00;ooooo0_l000000ol@413oooooooooo`03ooooo`;o
000000?o410@ooooooooool0S_ooool00:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko
00003?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0Soooool00:Kooooo00Go0000ooooooooooooooooo`00000Kooooo`03o`000?oooooooooo00;o
oooo1Ol00003ooooo`Go0000T?ooool00:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko
00003?ooool00ol0003oooooooooo`02ooooo`04odA4A?oMgMgoooooo`0000Cooooo00CoA4A4omgM
gOoooooo0000TOooool00:Kooooo00Go0000ohN7QoooooooZJVYo`00000Kooooo`03o`000?oooooo
oooo00;ooooo00CogMgMoeEEEOoooooo00001?ooool01?oMgMgoEEEEooooool0002Aooooo`00YOoo
ool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo01Wooooo00?o0000ooooooooool00ooo
ool00omgMgOoc<c<o`000005ooooo`03ogMgMoo<c<co0000097ooooo0036ooooo`03o`000?oooooo
oooo00?ooooo00?ok^k^odA4A?l000001Oooool00oo^k^koA4A4o`00002Aooooo`00a?ooool00omE
EEGoIVIVo`000006ooooo`03ogMgMol0003ooooo00Gooooo00?oMgMgo`000?ooool0T?ooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(150) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.33693 .52638 Mdot
.30318 .53436 Mdot
.6268 .66882 Mdot
.50822 .36088 Mdot
.70675 .41953 Mdot
.61665 .67376 Mdot
.44893 .68564 Mdot
.45605 .70741 Mdot
.61932 .61468 Mdot
.46941 .45 Mdot
.42058 .69618 Mdot
.45684 .40116 Mdot
.45064 .69662 Mdot
.44762 .36561 Mdot
.57039 .34105 Mdot
.36694 .31031 Mdot
.29743 .56604 Mdot
.689 .44615 Mdot
.36134 .3019 Mdot
.61912 .60994 Mdot
.78351 .41099 Mdot
.46751 .3736 Mdot
.32372 .56878 Mdot
.44842 .36456 Mdot
.36192 .3096 Mdot
.30776 .52574 Mdot
.33277 .51867 Mdot
.34998 .31496 Mdot
.49359 .39541 Mdot
.41579 .69061 Mdot
.34007 .31764 Mdot
.63192 .33519 Mdot
.65318 .49896 Mdot
.34893 .44942 Mdot
.44227 .73025 Mdot
.44903 .74497 Mdot
.61887 .63346 Mdot
.42179 .71966 Mdot
.44608 .66697 Mdot
.42892 .71832 Mdot
.42951 .72078 Mdot
.31312 .5291 Mdot
.43743 .73285 Mdot
.43287 .80064 Mdot
.45866 .35383 Mdot
.29916 .36182 Mdot
.60525 .5896 Mdot
.51714 .37934 Mdot
.31711 .57678 Mdot
.62026 .71102 Mdot
.61793 .39537 Mdot
.44096 .71687 Mdot
.63139 .49828 Mdot
.26835 .33203 Mdot
.45628 .69406 Mdot
.36079 .30535 Mdot
.5989 .67531 Mdot
.48307 .36044 Mdot
.52182 .38047 Mdot
.343 .43536 Mdot
.49527 .36745 Mdot
.71881 .41794 Mdot
.24549 .5337 Mdot
.62265 .6926 Mdot
.63089 .63213 Mdot
.42335 .72613 Mdot
.28237 .54749 Mdot
.46666 .70141 Mdot
.512 .36433 Mdot
.60713 .60444 Mdot
.465 .39575 Mdot
.42044 .69737 Mdot
.28542 .52455 Mdot
.46318 .38244 Mdot
.34131 .5465 Mdot
.45893 .65997 Mdot
.69363 .43595 Mdot
.30675 .59391 Mdot
.60969 .7059 Mdot
.44453 .31179 Mdot
.47108 .37987 Mdot
.25522 .6786 Mdot
.53705 .28067 Mdot
.31085 .51354 Mdot
.42817 .37551 Mdot
.21782 .64216 Mdot
.4118 .3655 Mdot
.35109 .32472 Mdot
.35497 .31369 Mdot
.54268 .35122 Mdot
.58973 .67237 Mdot
.32407 .56062 Mdot
.46437 .36788 Mdot
.51232 .35551 Mdot
.4499 .45082 Mdot
.48882 .39095 Mdot
.35743 .31027 Mdot
.64385 .47662 Mdot
.4279 .70883 Mdot
.61797 .49182 Mdot
.41371 .64604 Mdot
.63552 .48461 Mdot
.43035 .38863 Mdot
.61248 .64946 Mdot
.31375 .50389 Mdot
.65098 .48431 Mdot
.46059 .72043 Mdot
.45903 .36725 Mdot
.45423 .74693 Mdot
.32599 .56329 Mdot
.33956 .30488 Mdot
.72345 .43116 Mdot
.72838 .46843 Mdot
.28425 .534 Mdot
.35966 .36166 Mdot
.48369 .34798 Mdot
.48371 .37634 Mdot
.30674 .53333 Mdot
.62431 .61082 Mdot
.52404 .68733 Mdot
.3093 .55846 Mdot
.42481 .70443 Mdot
.29722 .56788 Mdot
.65721 .49564 Mdot
.62669 .6166 Mdot
.61324 .51956 Mdot
.63396 .47452 Mdot
.63396 .35592 Mdot
.50861 .38114 Mdot
.66281 .47291 Mdot
.61106 .64241 Mdot
.30914 .55464 Mdot
.44466 .70475 Mdot
.5058 .34742 Mdot
.31261 .51765 Mdot
.4574 .68763 Mdot
.72445 .4507 Mdot
.72416 .45267 Mdot
.29307 .52039 Mdot
.3638 .36934 Mdot
.43038 .73506 Mdot
.46328 .67905 Mdot
.61508 .39554 Mdot
.30271 .51417 Mdot
.75083 .41385 Mdot
.46263 .68459 Mdot
.6831 .66289 Mdot
.34323 .30025 Mdot
.64777 .36787 Mdot
.26577 .67825 Mdot
.61595 .3961 Mdot
.77901 .4174 Mdot
.72747 .41719 Mdot
.45815 .68839 Mdot
.45299 .3455 Mdot
.29125 .54047 Mdot
.30798 .51871 Mdot
.45297 .39766 Mdot
.6518 .49173 Mdot
.47881 .34974 Mdot
.61832 .4876 Mdot
.63249 .47373 Mdot
.45467 .36426 Mdot
.31403 .3851 Mdot
.32944 .52763 Mdot
.42448 .36011 Mdot
.61522 .62654 Mdot
.68275 .47669 Mdot
.43582 .73784 Mdot
.42988 .37354 Mdot
.42856 .34838 Mdot
.42482 .39611 Mdot
.4639 .67896 Mdot
.36425 .71453 Mdot
.5968 .69939 Mdot
.42574 .67777 Mdot
.41981 .64419 Mdot
.5984 .6467 Mdot
.52399 .37604 Mdot
.72887 .42758 Mdot
.6245 .51014 Mdot
.43649 .3538 Mdot
.61906 .39641 Mdot
.53073 .37423 Mdot
.75371 .45127 Mdot
.7575 .44454 Mdot
.24911 .66498 Mdot
.36102 .68529 Mdot
.49838 .34994 Mdot
.35183 .33381 Mdot
.63342 .38303 Mdot
.50491 .71421 Mdot
.44036 .70389 Mdot
.61292 .59069 Mdot
.62126 .60472 Mdot
.64474 .72306 Mdot
.41781 .41194 Mdot
.43536 .4018 Mdot
.48581 .3821 Mdot
.62552 .49396 Mdot
.24974 .52909 Mdot
.72731 .41636 Mdot
.29042 .55135 Mdot
.25793 .6799 Mdot
.46729 .29159 Mdot
.35068 .29006 Mdot
.67608 .7262 Mdot
.62717 .69786 Mdot
.64445 .4869 Mdot
.74301 .42145 Mdot
.48781 .35713 Mdot
.33365 .54365 Mdot
.62527 .38884 Mdot
.64114 .51436 Mdot
.79312 .34963 Mdot
.30486 .56376 Mdot
.51002 .28315 Mdot
.45379 .69154 Mdot
.58824 .65411 Mdot
.41197 .36551 Mdot
.44923 .37352 Mdot
.29227 .58299 Mdot
.49914 .3469 Mdot
.33228 .30202 Mdot
.34516 .30449 Mdot
.62118 .71243 Mdot
.39934 .64894 Mdot
.43216 .67252 Mdot
.60378 .58758 Mdot
.28492 .52895 Mdot
.29528 .36684 Mdot
.60628 .66069 Mdot
.77486 .42941 Mdot
.41934 .70388 Mdot
.73335 .44556 Mdot
.61089 .65994 Mdot
.70793 .41886 Mdot
.52431 .37896 Mdot
.59885 .63222 Mdot
.71497 .43357 Mdot
.55458 .38328 Mdot
.64748 .48256 Mdot
.73725 .39397 Mdot
.44739 .68227 Mdot
.30159 .58052 Mdot
.4362 .35338 Mdot
.62691 .50357 Mdot
.6274 .52451 Mdot
.5411 .33142 Mdot
.60422 .49142 Mdot
.64496 .50662 Mdot
.53902 .34201 Mdot
.68981 .45078 Mdot
.33531 .63723 Mdot
.33856 .31485 Mdot
.29482 .56355 Mdot
.50251 .3497 Mdot
.38247 .65691 Mdot
.4578 .68633 Mdot
.49297 .36027 Mdot
.24352 .67016 Mdot
.44496 .67985 Mdot
.47642 .36477 Mdot
.43629 .66513 Mdot
.31257 .51564 Mdot
.47029 .28758 Mdot
.28917 .51833 Mdot
.45676 .36283 Mdot
.4334 .66538 Mdot
.60793 .59386 Mdot
.30627 .52457 Mdot
.46392 .36996 Mdot
.49953 .37698 Mdot
.62665 .49577 Mdot
.34469 .30278 Mdot
.42947 .64913 Mdot
.45517 .40055 Mdot
.60719 .68999 Mdot
.48593 .39556 Mdot
.72056 .45591 Mdot
.71083 .66577 Mdot
.3012 .51413 Mdot
.60277 .49286 Mdot
.60896 .67028 Mdot
.5552 .42233 Mdot
.49399 .27909 Mdot
.45334 .35542 Mdot
.63599 .51401 Mdot
.52606 .26658 Mdot
.43325 .68236 Mdot
.33572 .30116 Mdot
.66984 .46624 Mdot
.60139 .67753 Mdot
.63299 .48645 Mdot
.45218 .39096 Mdot
.32891 .56331 Mdot
.36448 .30824 Mdot
.59388 .64871 Mdot
.30596 .56948 Mdot
.41968 .37975 Mdot
.4235 .64581 Mdot
.62319 .46938 Mdot
.43086 .68544 Mdot
.34751 .31863 Mdot
.52402 .37517 Mdot
.6063 .60688 Mdot
.31546 .52968 Mdot
.45706 .69975 Mdot
.28873 .52087 Mdot
.57517 .41493 Mdot
.51622 .28367 Mdot
.28507 .51639 Mdot
.70756 .45257 Mdot
.70333 .73674 Mdot
.4228 .69317 Mdot
.61072 .50538 Mdot
.58348 .62241 Mdot
.32788 .57084 Mdot
.6147 .65752 Mdot
.36968 .3818 Mdot
.59089 .67257 Mdot
.36219 .29935 Mdot
.59698 .60722 Mdot
.41912 .399 Mdot
.4281 .36509 Mdot
.63703 .66789 Mdot
.64798 .47693 Mdot
.45222 .38734 Mdot
.31442 .51849 Mdot
.62501 .32734 Mdot
.40483 .43464 Mdot
.4165 .4101 Mdot
.59961 .6738 Mdot
.36381 .3802 Mdot
.34284 .30848 Mdot
.34975 .31789 Mdot
.29454 .5429 Mdot
.61261 .50713 Mdot
.75187 .43573 Mdot
.76153 .42042 Mdot
.75827 .63779 Mdot
.50644 .24591 Mdot
.35775 .35679 Mdot
.30141 .52089 Mdot
.66569 .73055 Mdot
.33658 .51694 Mdot
.642 .5129 Mdot
.45587 .70803 Mdot
.36899 .72952 Mdot
.41046 .36839 Mdot
.66028 .45798 Mdot
.33158 .29863 Mdot
.30724 .57815 Mdot
.27742 .53832 Mdot
.45709 .70173 Mdot
.40784 .40651 Mdot
.46926 .44908 Mdot
.49057 .3529 Mdot
.45783 .70836 Mdot
.63275 .52195 Mdot
.53661 .35783 Mdot
.64439 .34664 Mdot
.45533 .81758 Mdot
.45589 .35725 Mdot
.36353 .47981 Mdot
.43364 .35895 Mdot
.63414 .36247 Mdot
.48052 .35636 Mdot
.31558 .52588 Mdot
.31226 .27708 Mdot
.48928 .33818 Mdot
.67911 .72453 Mdot
.46646 .29401 Mdot
.70468 .43976 Mdot
.45346 .37101 Mdot
.46506 .34887 Mdot
.75355 .42102 Mdot
.32442 .544 Mdot
.51635 .37109 Mdot
.34124 .63594 Mdot
.46896 .37048 Mdot
.43786 .73923 Mdot
.54692 .30708 Mdot
.6298 .33776 Mdot
.34592 .30815 Mdot
.32767 .56546 Mdot
.45397 .67314 Mdot
.42887 .72482 Mdot
.60392 .50651 Mdot
.45789 .68579 Mdot
.43173 .36431 Mdot
.54738 .30824 Mdot
.28081 .54084 Mdot
.64803 .4854 Mdot
.32139 .55998 Mdot
.64696 .59803 Mdot
.44427 .68483 Mdot
.6373 .49132 Mdot
.41958 .42002 Mdot
.43648 .69145 Mdot
.45636 .63646 Mdot
.33831 .30655 Mdot
.63067 .52289 Mdot
.33793 .53129 Mdot
.60437 .60481 Mdot
.63806 .51445 Mdot
.45679 .6943 Mdot
.45744 .35369 Mdot
.35595 .30262 Mdot
.45931 .68732 Mdot
.36794 .50648 Mdot
.33526 .31028 Mdot
.4716 .36994 Mdot
.32416 .52491 Mdot
.31417 .54958 Mdot
.42554 .35737 Mdot
.48467 .3454 Mdot
.61172 .68072 Mdot
.63141 .51745 Mdot
.62774 .5194 Mdot
.61962 .47813 Mdot
.5908 .66676 Mdot
.69427 .73891 Mdot
.46791 .70396 Mdot
.6282 .33715 Mdot
.36534 .68033 Mdot
.63165 .50255 Mdot
.61416 .68089 Mdot
.44193 .35649 Mdot
.43049 .39301 Mdot
.43253 .66471 Mdot
.75791 .70539 Mdot
.40862 .37167 Mdot
.28733 .55386 Mdot
.45029 .71815 Mdot
.43834 .40072 Mdot
.64219 .72068 Mdot
.70766 .42734 Mdot
.35571 .35718 Mdot
.44923 .71714 Mdot
.36733 .54226 Mdot
.44847 .71703 Mdot
.4614 .34938 Mdot
.46437 .39152 Mdot
.29511 .57907 Mdot
.70425 .44071 Mdot
.45597 .39964 Mdot
.47174 .36199 Mdot
.67158 .73254 Mdot
.33193 .50984 Mdot
.76168 .42162 Mdot
.49918 .3946 Mdot
.63611 .47766 Mdot
.69937 .4353 Mdot
.47299 .38285 Mdot
.47806 .39741 Mdot
.66533 .4816 Mdot
.42541 .66926 Mdot
.70721 .44942 Mdot
.6806 .72566 Mdot
.30038 .56294 Mdot
.44179 .64766 Mdot
.60175 .51487 Mdot
.4226 .69523 Mdot
.53119 .41468 Mdot
.64023 .48779 Mdot
.39742 .77679 Mdot
.67793 .19766 Mdot
.64404 .50419 Mdot
.60787 .68617 Mdot
.44063 .44993 Mdot
.46966 .39875 Mdot
.47183 .3694 Mdot
.74226 .44627 Mdot
.30901 .5418 Mdot
.36123 .68593 Mdot
.42909 .67203 Mdot
.44296 .37211 Mdot
.29809 .51375 Mdot
.23725 .65982 Mdot
.63143 .4898 Mdot
.72085 .4409 Mdot
.72486 .44751 Mdot
.45868 .38414 Mdot
.5167 .25695 Mdot
.30704 .52309 Mdot
.4634 .36973 Mdot
.46542 .38658 Mdot
.58306 .63195 Mdot
.32218 .51616 Mdot
.59873 .63417 Mdot
.34904 .29061 Mdot
.36265 .34531 Mdot
.37963 .66061 Mdot
.45121 .67933 Mdot
.61487 .51749 Mdot
.43178 .67363 Mdot
.58096 .6793 Mdot
.62801 .519 Mdot
.46298 .37016 Mdot
.28066 .54105 Mdot
.4632 .36914 Mdot
.46806 .36977 Mdot
.47083 .3525 Mdot
.35272 .35447 Mdot
.60871 .70237 Mdot
.72732 .43636 Mdot
.51378 .38713 Mdot
.59282 .6579 Mdot
.65281 .72109 Mdot
.46831 .4508 Mdot
.45963 .37556 Mdot
.48312 .37313 Mdot
.31124 .59507 Mdot
.34365 .29825 Mdot
.4382 .69357 Mdot
.29597 .57973 Mdot
.41294 .36312 Mdot
.60369 .58929 Mdot
.51741 .3689 Mdot
.28558 .51644 Mdot
.4646 .7162 Mdot
.24047 .52085 Mdot
.60503 .52146 Mdot
.60929 .51678 Mdot
.64113 .5104 Mdot
.61218 .48192 Mdot
.43784 .73737 Mdot
.61642 .68096 Mdot
.62667 .57047 Mdot
.39047 .34008 Mdot
.48564 .34498 Mdot
.45899 .39113 Mdot
.5853 .62153 Mdot
.6595 .48475 Mdot
.39049 .40712 Mdot
.34858 .28499 Mdot
.58687 .64431 Mdot
.64097 .47529 Mdot
.21658 .5906 Mdot
.31741 .56954 Mdot
.59654 .69745 Mdot
.41986 .71427 Mdot
.7122 .43428 Mdot
.82209 .58262 Mdot
.31723 .55962 Mdot
.25233 .52092 Mdot
.61051 .63207 Mdot
.54632 .32303 Mdot
.26326 .32071 Mdot
.6173 .66109 Mdot
.33239 .30864 Mdot
.29229 .53213 Mdot
.64381 .47905 Mdot
.52726 .27015 Mdot
.54323 .31473 Mdot
.60854 .61464 Mdot
.50094 .37708 Mdot
.63714 .63543 Mdot
.60407 .68205 Mdot
.61571 .51475 Mdot
.59947 .67303 Mdot
.43547 .67819 Mdot
.60709 .64429 Mdot
.36803 .51068 Mdot
.51137 .37127 Mdot
.2675 .33095 Mdot
.57806 .32246 Mdot
.48508 .34747 Mdot
.43303 .70237 Mdot
.43059 .64561 Mdot
.50111 .36214 Mdot
.73287 .40717 Mdot
.61044 .68578 Mdot
.63565 .71989 Mdot
.35561 .29862 Mdot
.59576 .60969 Mdot
.32988 .56267 Mdot
.41283 .6456 Mdot
.41717 .64465 Mdot
.63796 .5139 Mdot
.30752 .51489 Mdot
.46034 .65961 Mdot
.42534 .70546 Mdot
.6376 .46669 Mdot
.43164 .35452 Mdot
.33117 .53693 Mdot
.53756 .35518 Mdot
.68386 .46816 Mdot
.46954 .37164 Mdot
.59931 .6358 Mdot
.61701 .71098 Mdot
.57452 .33331 Mdot
.60505 .66293 Mdot
.61214 .51381 Mdot
.32771 .52734 Mdot
.35917 .30007 Mdot
.31156 .55429 Mdot
.50934 .35269 Mdot
.39089 .65237 Mdot
.31927 .5697 Mdot
.77448 .42962 Mdot
.49173 .36783 Mdot
.31191 .38095 Mdot
.50741 .39139 Mdot
.47218 .37088 Mdot
.63081 .6275 Mdot
.75273 .41971 Mdot
.69076 .46177 Mdot
.64619 .71763 Mdot
.72585 .41207 Mdot
.30166 .49388 Mdot
.62734 .61605 Mdot
.74247 .43308 Mdot
.7615 .63672 Mdot
.60191 .49307 Mdot
.73449 .43555 Mdot
.42783 .37454 Mdot
.45712 .68088 Mdot
.28525 .56207 Mdot
.44778 .38636 Mdot
.39044 .37518 Mdot
.37986 .31441 Mdot
.62941 .49406 Mdot
.47604 .37099 Mdot
.46581 .34809 Mdot
.29658 .51469 Mdot
.26613 .68043 Mdot
.61423 .69138 Mdot
.61379 .49637 Mdot
.31387 .56007 Mdot
.25398 .67815 Mdot
.6324 .6382 Mdot
.74296 .43843 Mdot
.44027 .66848 Mdot
.36422 .55545 Mdot
.62893 .49838 Mdot
.44829 .68381 Mdot
.62922 .71205 Mdot
.60732 .4016 Mdot
.36616 .32389 Mdot
.6204 .64525 Mdot
.61625 .3963 Mdot
.34427 .29139 Mdot
.64769 .72419 Mdot
.50565 .71218 Mdot
.32566 .56266 Mdot
.46077 .69176 Mdot
.7164 .44313 Mdot
.28308 .52589 Mdot
.32143 .56043 Mdot
.45023 .67815 Mdot
.2961 .28232 Mdot
.52427 .26804 Mdot
.46677 .67447 Mdot
.54571 .33354 Mdot
.61008 .39886 Mdot
.62592 .49988 Mdot
.72803 .43138 Mdot
.39928 .64902 Mdot
.31251 .52882 Mdot
.36802 .71503 Mdot
.62107 .3946 Mdot
.33685 .30198 Mdot
.71249 .43156 Mdot
.2419 .65883 Mdot
.47134 .74903 Mdot
.43959 .69054 Mdot
.67107 .73249 Mdot
.74462 .40682 Mdot
.42687 .36808 Mdot
.77248 .69466 Mdot
.43103 .3716 Mdot
.46534 .6928 Mdot
.33177 .29886 Mdot
.29752 .55472 Mdot
.46771 .69353 Mdot
.3515 .28943 Mdot
.46444 .40081 Mdot
.49861 .35288 Mdot
.60853 .70617 Mdot
.29641 .58326 Mdot
.59561 .49725 Mdot
.47988 .34681 Mdot
.47647 .36211 Mdot
.63228 .52344 Mdot
.63033 .34069 Mdot
.51547 .63569 Mdot
.65461 .49197 Mdot
.59579 .6303 Mdot
.64855 .48513 Mdot
.61284 .50076 Mdot
.33809 .54529 Mdot
.6602 .72916 Mdot
.61769 .52467 Mdot
.45703 .36055 Mdot
.46177 .36519 Mdot
.44759 .66747 Mdot
.52605 .26727 Mdot
.5437 .32121 Mdot
.60953 .69117 Mdot
.65271 .46382 Mdot
.48919 .38758 Mdot
.31121 .51428 Mdot
.74276 .44751 Mdot
.60544 .507 Mdot
.29801 .56345 Mdot
.50942 .38272 Mdot
.58383 .62907 Mdot
.6445 .50038 Mdot
.63064 .52584 Mdot
.71653 .43053 Mdot
.46261 .67363 Mdot
.30143 .59279 Mdot
.60567 .68381 Mdot
.35991 .32609 Mdot
.6125 .46894 Mdot
.58 .64775 Mdot
.62424 .49987 Mdot
.63704 .48155 Mdot
.30733 .51617 Mdot
.36889 .53694 Mdot
.64766 .51694 Mdot
.59249 .66567 Mdot
.4337 .81067 Mdot
.43484 .71819 Mdot
.52124 .3783 Mdot
.43814 .67215 Mdot
.32663 .56223 Mdot
.63542 .35471 Mdot
.7314 .44562 Mdot
.43757 .68796 Mdot
.64643 .50588 Mdot
.32081 .56448 Mdot
.29372 .5862 Mdot
.45355 .36268 Mdot
.46473 .374 Mdot
.60519 .58928 Mdot
.64098 .3741 Mdot
.43875 .66356 Mdot
.75088 .43599 Mdot
.62345 .67864 Mdot
.35691 .3017 Mdot
.28981 .54256 Mdot
.75589 .38969 Mdot
.5132 .38891 Mdot
.59392 .6621 Mdot
.30068 .53361 Mdot
.76028 .42055 Mdot
.72813 .43702 Mdot
.44605 .34912 Mdot
.77819 .41777 Mdot
.43794 .68259 Mdot
.31387 .52002 Mdot
.28192 .49395 Mdot
.51312 .38594 Mdot
.45945 .3734 Mdot
.33814 .29823 Mdot
.46889 .67896 Mdot
.42814 .37353 Mdot
.70852 .44327 Mdot
.28582 .53651 Mdot
.43705 .35891 Mdot
.75058 .40731 Mdot
.5984 .49065 Mdot
.64307 .49037 Mdot
.63763 .65894 Mdot
.75727 .40517 Mdot
.75313 .41 Mdot
.74846 .4059 Mdot
.36939 .73065 Mdot
.44028 .40042 Mdot
.58806 .51739 Mdot
.49834 .37859 Mdot
.60725 .40024 Mdot
.35978 .32886 Mdot
.43099 .70955 Mdot
.60562 .60849 Mdot
.4806 .3517 Mdot
.49658 .37889 Mdot
.31103 .58737 Mdot
.36714 .3074 Mdot
.42515 .36061 Mdot
.29336 .55234 Mdot
.27114 .50091 Mdot
.61841 .59453 Mdot
.26465 .67747 Mdot
.80306 .66112 Mdot
.53381 .3682 Mdot
.54938 .31902 Mdot
.32475 .54904 Mdot
.44369 .66789 Mdot
.54711 .33059 Mdot
.46367 .67679 Mdot
.31396 .54298 Mdot
.36964 .30858 Mdot
.36772 .50503 Mdot
.7168 .41883 Mdot
.46109 .34974 Mdot
.44678 .67719 Mdot
.47071 .34922 Mdot
.4463 .67455 Mdot
.3612 .38606 Mdot
.53444 .27563 Mdot
.48493 .34398 Mdot
.48915 .39131 Mdot
.78414 .40847 Mdot
.46209 .37497 Mdot
.67899 .73443 Mdot
.29779 .53812 Mdot
.66184 .46709 Mdot
.37251 .3178 Mdot
.40577 .43589 Mdot
.48089 .37388 Mdot
.38396 .32662 Mdot
.48616 .37697 Mdot
.74905 .71241 Mdot
.5276 .37683 Mdot
.43011 .35709 Mdot
.44152 .70805 Mdot
.42152 .70496 Mdot
.30057 .58886 Mdot
.63777 .48309 Mdot
.2454 .66224 Mdot
.4746 .36466 Mdot
.63207 .67542 Mdot
.69482 .47612 Mdot
.75557 .4129 Mdot
.2849 .54289 Mdot
.66939 .1894 Mdot
.43656 .73335 Mdot
.60919 .62238 Mdot
.33928 .3179 Mdot
.59671 .63181 Mdot
.61839 .69343 Mdot
.29638 .49154 Mdot
.72744 .43267 Mdot
.51831 .36446 Mdot
.34924 .4472 Mdot
.24659 .52216 Mdot
.5132 .38572 Mdot
.6271 .61062 Mdot
.66507 .48257 Mdot
.43105 .24393 Mdot
.69058 .44504 Mdot
.74062 .4118 Mdot
.45442 .68865 Mdot
.63306 .67444 Mdot
.61457 .49657 Mdot
.73926 .43834 Mdot
.61564 .59249 Mdot
.6022 .49716 Mdot
.66818 .73395 Mdot
.30822 .52263 Mdot
.36551 .3806 Mdot
.29414 .35583 Mdot
.42899 .68944 Mdot
.65192 .72425 Mdot
.28027 .53558 Mdot
.29559 .51251 Mdot
.62141 .49529 Mdot
.58916 .63543 Mdot
.28559 .50734 Mdot
.44407 .35086 Mdot
.64612 .48389 Mdot
.44431 .37856 Mdot
.6868 .45163 Mdot
.46986 .3656 Mdot
.60836 .59624 Mdot
.43692 .70466 Mdot
.60482 .67645 Mdot
.45299 .68611 Mdot
.62725 .33325 Mdot
.48665 .36512 Mdot
.45625 .37123 Mdot
.54684 .30878 Mdot
.33601 .53628 Mdot
.3507 .45093 Mdot
.59561 .66724 Mdot
.60257 .67546 Mdot
.37219 .31764 Mdot
.2941 .56638 Mdot
.6226 .5325 Mdot
.54569 .33529 Mdot
.48507 .37862 Mdot
.29908 .53921 Mdot
.35816 .33034 Mdot
.41317 .79491 Mdot
.53786 .284 Mdot
.33635 .54778 Mdot
.68247 .73849 Mdot
.47299 .38772 Mdot
.61113 .496 Mdot
.65545 .47018 Mdot
.51437 .25164 Mdot
.6849 .46148 Mdot
.30394 .56433 Mdot
.61935 .48892 Mdot
.28971 .53942 Mdot
.59207 .67598 Mdot
.45402 .73352 Mdot
.29617 .54696 Mdot
.48772 .37424 Mdot
.80383 .65952 Mdot
.45358 .67617 Mdot
.45082 .35301 Mdot
.46654 .70494 Mdot
.27724 .54739 Mdot
.30669 .55083 Mdot
.60221 .49754 Mdot
.33286 .30718 Mdot
.43727 .68485 Mdot
.46248 .34445 Mdot
.36439 .4854 Mdot
.36464 .30835 Mdot
.68341 .47329 Mdot
.49092 .38775 Mdot
.50288 .38901 Mdot
.68821 .73603 Mdot
.55685 .42226 Mdot
.38379 .65548 Mdot
.44552 .74408 Mdot
.36314 .71428 Mdot
.33356 .5237 Mdot
.6955 .45624 Mdot
.29761 .58986 Mdot
.61634 .51951 Mdot
.59962 .62424 Mdot
.46706 .35176 Mdot
.60561 .48526 Mdot
.46645 .67095 Mdot
.73713 .43025 Mdot
.53073 .37419 Mdot
.62438 .64798 Mdot
.61631 .48327 Mdot
.44259 .68687 Mdot
.3154 .53262 Mdot
.29657 .55809 Mdot
.66231 .73285 Mdot
.43809 .35757 Mdot
.46441 .37237 Mdot
.45211 .72922 Mdot
.77154 .4267 Mdot
.72603 .4114 Mdot
.6484 .47701 Mdot
.4572 .72631 Mdot
.53767 .28297 Mdot
.29075 .5817 Mdot
.45083 .35038 Mdot
.54755 .304 Mdot
.36164 .70127 Mdot
.22212 .57447 Mdot
.73146 .41285 Mdot
.49746 .27395 Mdot
.30478 .56421 Mdot
.44632 .70544 Mdot
.75749 .64106 Mdot
.34031 .29557 Mdot
.50591 .36584 Mdot
.48551 .27745 Mdot
.54001 .33425 Mdot
.34624 .32306 Mdot
.60308 .51824 Mdot
.52255 .29158 Mdot
.37177 .32065 Mdot
.36542 .3209 Mdot
.48005 .39097 Mdot
.48798 .38936 Mdot
.30265 .54406 Mdot
.41642 .40871 Mdot
.60522 .63603 Mdot
.3324 .31608 Mdot
.76723 .39625 Mdot
.33923 .31055 Mdot
.4457 .39636 Mdot
.21969 .5848 Mdot
.48879 .24133 Mdot
.29513 .5299 Mdot
.33013 .56872 Mdot
.42829 .68743 Mdot
.36387 .3052 Mdot
.5939 .66454 Mdot
.6637 .49077 Mdot
.59915 .61233 Mdot
.30288 .54193 Mdot
.62001 .59747 Mdot
.4219 .72304 Mdot
.62049 .64509 Mdot
.58888 .64129 Mdot
.43713 .70786 Mdot
.29725 .58221 Mdot
.50315 .39385 Mdot
.4364 .70735 Mdot
.63849 .52134 Mdot
.73997 .44099 Mdot
.25838 .51065 Mdot
.65207 .48264 Mdot
.41107 .37747 Mdot
.43181 .80656 Mdot
.6193 .63491 Mdot
.47286 .28573 Mdot
.3121 .5789 Mdot
.75509 .39726 Mdot
.29845 .54926 Mdot
.64334 .52144 Mdot
.72167 .41854 Mdot
.43094 .37913 Mdot
.77166 .39314 Mdot
.50967 .70263 Mdot
.48714 .33857 Mdot
.27216 .50019 Mdot
.59564 .61577 Mdot
.43194 .68856 Mdot
.47453 .64647 Mdot
.61424 .49448 Mdot
.32672 .56807 Mdot
.36544 .56639 Mdot
.62297 .5202 Mdot
.44394 .70438 Mdot
.32707 .40305 Mdot
.45658 .34778 Mdot
.43244 .67729 Mdot
.49394 .3865 Mdot
.36299 .36577 Mdot
.73847 .4512 Mdot
.62268 .47637 Mdot
.36693 .30347 Mdot
.63066 .63334 Mdot
.37178 .31484 Mdot
.3945 .38666 Mdot
.64291 .35922 Mdot
.4939 .378 Mdot
.47648 .28326 Mdot
.5797 .67657 Mdot
.28916 .52998 Mdot
.63554 .50619 Mdot
.62649 .49767 Mdot
.36142 .29691 Mdot
.855 .5708 Mdot
.74219 .42839 Mdot
.67844 .73701 Mdot
.48409 .36512 Mdot
.47157 .37917 Mdot
.29934 .59046 Mdot
.36457 .39006 Mdot
.64171 .47697 Mdot
.50255 .3703 Mdot
.49759 .24097 Mdot
.44914 .70995 Mdot
.43159 .38813 Mdot
.45565 .38288 Mdot
.40546 .64609 Mdot
.44325 .70778 Mdot
.57953 .66405 Mdot
.60057 .49594 Mdot
.63799 .65686 Mdot
.70371 .42389 Mdot
.50724 .28094 Mdot
.63359 .34581 Mdot
.53691 .28875 Mdot
.71299 .41806 Mdot
.34349 .30664 Mdot
.40537 .37555 Mdot
.50968 .37058 Mdot
.74287 .41395 Mdot
.41728 .68064 Mdot
.2986 .54159 Mdot
.3641 .37203 Mdot
.62484 .49719 Mdot
.36207 .32361 Mdot
.69744 .42937 Mdot
.29096 .53805 Mdot
.3158 .388 Mdot
.30777 .54165 Mdot
.44308 .69117 Mdot
.6489 .7237 Mdot
.71868 .41991 Mdot
.29794 .5495 Mdot
.62507 .61783 Mdot
.38895 .65395 Mdot
.42106 .39606 Mdot
.41973 .71889 Mdot
.30725 .49276 Mdot
.33368 .56007 Mdot
.33843 .52721 Mdot
.35422 .29581 Mdot
.47567 .2843 Mdot
.61289 .51651 Mdot
.45981 .72438 Mdot
.63073 .64037 Mdot
.64089 .37152 Mdot
.3342 .42032 Mdot
.526 .30604 Mdot
.44671 .38963 Mdot
.46809 .36504 Mdot
.46607 .38425 Mdot
.60875 .52496 Mdot
.40377 .3702 Mdot
.49387 .38105 Mdot
.4333 .6642 Mdot
.57958 .65969 Mdot
.48178 .36303 Mdot
.64273 .49372 Mdot
.65849 .45792 Mdot
.75502 .3971 Mdot
.3374 .34695 Mdot
.25412 .52485 Mdot
.29316 .54284 Mdot
.59418 .65082 Mdot
.63285 .62783 Mdot
.72335 .45141 Mdot
.45709 .70653 Mdot
.30992 .54186 Mdot
.7463 .71314 Mdot
.71106 .42555 Mdot
.45762 .3579 Mdot
.54652 .30757 Mdot
.49762 .24664 Mdot
.4553 .39838 Mdot
.47347 .35282 Mdot
.64911 .49796 Mdot
.59165 .66007 Mdot
.4229 .39949 Mdot
.31545 .38623 Mdot
.74638 .40742 Mdot
.74835 .43447 Mdot
.31937 .50796 Mdot
.4521 .34501 Mdot
.44609 .67789 Mdot
.52531 .26488 Mdot
.42718 .64915 Mdot
.22122 .64175 Mdot
.63776 .58865 Mdot
.51823 .36716 Mdot
.42165 .44616 Mdot
.41009 .36817 Mdot
.31392 .50399 Mdot
.36734 .52748 Mdot
.29829 .52372 Mdot
.45219 .7088 Mdot
.59199 .40872 Mdot
.42887 .72156 Mdot
.63865 .47552 Mdot
.31352 .57064 Mdot
.54065 .35988 Mdot
.60251 .67474 Mdot
.36839 .31534 Mdot
.7277 .424 Mdot
.53853 .34867 Mdot
.63359 .50449 Mdot
.50071 .27568 Mdot
.61476 .68033 Mdot
.28494 .57269 Mdot
.36893 .31664 Mdot
.64406 .71619 Mdot
.52491 .29451 Mdot
.63737 .57155 Mdot
.60517 .48489 Mdot
.71837 .41823 Mdot
.4767 .45017 Mdot
.70847 .43334 Mdot
.43871 .68441 Mdot
.48959 .36553 Mdot
.43138 .35617 Mdot
.47547 .37348 Mdot
.44057 .38484 Mdot
.45586 .69942 Mdot
.36179 .31557 Mdot
.65268 .50666 Mdot
.60829 .48538 Mdot
.33949 .31539 Mdot
.7321 .43046 Mdot
.43252 .71533 Mdot
.58059 .6433 Mdot
.63928 .51496 Mdot
.69879 .44253 Mdot
.46477 .33916 Mdot
.49676 .37263 Mdot
.62097 .47919 Mdot
.42926 .3766 Mdot
.35899 .3133 Mdot
.61566 .64262 Mdot
.35627 .32264 Mdot
.75194 .39705 Mdot
.72363 .42462 Mdot
.45827 .68415 Mdot
.29681 .54919 Mdot
.7166 .4502 Mdot
.62281 .67632 Mdot
.4149 .36622 Mdot
.48853 .38854 Mdot
.36825 .51211 Mdot
.62036 .39559 Mdot
.75255 .398 Mdot
.42644 .37011 Mdot
.31922 .51372 Mdot
.35798 .58386 Mdot
.50529 .36827 Mdot
.35314 .31316 Mdot
.33857 .54575 Mdot
.73939 .44001 Mdot
.45956 .7042 Mdot
.58408 .32755 Mdot
.46458 .68184 Mdot
.31643 .53262 Mdot
.6213 .48925 Mdot
.3001 .5817 Mdot
.61529 .49233 Mdot
.22325 .61513 Mdot
.49076 .38487 Mdot
.36649 .49928 Mdot
.66028 .49054 Mdot
.59661 .67315 Mdot
.58342 .6515 Mdot
.643 .50259 Mdot
.30629 .56726 Mdot
.61362 .51474 Mdot
.71282 .4399 Mdot
.36421 .71054 Mdot
.33694 .55621 Mdot
.58846 .64114 Mdot
.62087 .63697 Mdot
.45655 .72754 Mdot
.47523 .36857 Mdot
.45345 .34956 Mdot
.62155 .65041 Mdot
.42853 .64885 Mdot
.327 .55376 Mdot
.46344 .37187 Mdot
.65239 .49931 Mdot
.60921 .63751 Mdot
.49314 .72899 Mdot
.27601 .54805 Mdot
.36852 .30496 Mdot
.64231 .35628 Mdot
.44193 .74175 Mdot
.41332 .37254 Mdot
.35745 .31151 Mdot
.74833 .42005 Mdot
.49353 .27373 Mdot
.61355 .39617 Mdot
.42907 .73048 Mdot
.60977 .51665 Mdot
.45106 .39802 Mdot
.58724 .66709 Mdot
.41813 .36541 Mdot
.69658 .22404 Mdot
.62679 .47614 Mdot
.43796 .36501 Mdot
.64975 .47139 Mdot
.31113 .55495 Mdot
.47017 .3744 Mdot
.38106 .6593 Mdot
.59637 .65269 Mdot
.43921 .35717 Mdot
.78307 .41359 Mdot
.46694 .69921 Mdot
.63415 .50351 Mdot
.72772 .41157 Mdot
.33663 .31802 Mdot
.62499 .32797 Mdot
.58464 .62261 Mdot
.72918 .43887 Mdot
.47854 .36966 Mdot
.62319 .68086 Mdot
.42165 .69956 Mdot
.63755 .50617 Mdot
.47591 .33811 Mdot
.42706 .70511 Mdot
.44368 .71293 Mdot
.71472 .42705 Mdot
.29324 .36726 Mdot
.50973 .34924 Mdot
.44522 .36692 Mdot
.31558 .39372 Mdot
.33255 .59781 Mdot
.46356 .34989 Mdot
.449 .38412 Mdot
.44797 .68217 Mdot
.5898 .41159 Mdot
.49859 .27523 Mdot
.66247 .48437 Mdot
.43147 .69437 Mdot
.62424 .60162 Mdot
.61048 .62596 Mdot
.72517 .44379 Mdot
.30161 .53292 Mdot
.71289 .45358 Mdot
.6034 .64515 Mdot
.4543 .35992 Mdot
.46266 .70289 Mdot
.359 .34242 Mdot
.46777 .69875 Mdot
.62386 .66991 Mdot
.28766 .51606 Mdot
.41143 .39532 Mdot
.69282 .21927 Mdot
.50453 .63325 Mdot
.64846 .72673 Mdot
.75535 .41403 Mdot
.3161 .38722 Mdot
.48429 .3688 Mdot
.41518 .40246 Mdot
.44639 .35508 Mdot
.70622 .45877 Mdot
.59948 .60816 Mdot
.60215 .49734 Mdot
.61367 .49511 Mdot
.49966 .27847 Mdot
.44576 .71399 Mdot
.43109 .72752 Mdot
.63022 .48223 Mdot
.44172 .69473 Mdot
.44119 .36819 Mdot
.6166 .67217 Mdot
.21782 .60682 Mdot
.48632 .37795 Mdot
.63019 .4667 Mdot
.43031 .73645 Mdot
.2809 .51859 Mdot
.62422 .60224 Mdot
.4127 .44173 Mdot
.25233 .66834 Mdot
.43578 .69037 Mdot
.3384 .34698 Mdot
.59498 .6586 Mdot
.64035 .51367 Mdot
.62216 .68406 Mdot
.44213 .36331 Mdot
.51838 .36746 Mdot
.62876 .52482 Mdot
.48271 .37808 Mdot
.35147 .4586 Mdot
.33678 .29725 Mdot
.33361 .28308 Mdot
.50013 .37763 Mdot
.29605 .49535 Mdot
.42144 .68667 Mdot
.62877 .48331 Mdot
.5386 .34272 Mdot
.50886 .38264 Mdot
.33446 .52399 Mdot
.42849 .70407 Mdot
.27547 .67588 Mdot
.45268 .70627 Mdot
.59733 .6763 Mdot
.45437 .71068 Mdot
.41087 .36797 Mdot
.31661 .54614 Mdot
.60787 .65515 Mdot
.63166 .50074 Mdot
.61931 .62038 Mdot
.48237 .34718 Mdot
.48277 .74211 Mdot
.60835 .62312 Mdot
.33763 .29933 Mdot
.31512 .54729 Mdot
.7784 .39328 Mdot
.24651 .53334 Mdot
.44989 .36111 Mdot
.45257 .35385 Mdot
.64894 .47791 Mdot
.45838 .68891 Mdot
.28353 .57265 Mdot
.67272 .7347 Mdot
.75484 .39776 Mdot
.29805 .52936 Mdot
.75006 .44199 Mdot
.54606 .32393 Mdot
.28421 .53338 Mdot
.49958 .24203 Mdot
.45192 .67873 Mdot
.29902 .56147 Mdot
.69211 .48336 Mdot
.35007 .33339 Mdot
.7236 .43359 Mdot
.63378 .63621 Mdot
.5479 .32767 Mdot
.60356 .62948 Mdot
.3908 .65211 Mdot
.62092 .71253 Mdot
.43479 .68498 Mdot
.78031 .41915 Mdot
.33118 .2996 Mdot
.42296 .72062 Mdot
.36713 .67648 Mdot
.60033 .63851 Mdot
.6317 .48003 Mdot
.35628 .31984 Mdot
.62404 .52837 Mdot
.61499 .48744 Mdot
.4327 .73145 Mdot
.29669 .56094 Mdot
.29013 .56039 Mdot
.66053 .46814 Mdot
.29456 .5556 Mdot
.61577 .65566 Mdot
.54272 .29235 Mdot
.41933 .42039 Mdot
.42059 .68673 Mdot
.33839 .32051 Mdot
.45318 .39504 Mdot
.60033 .60402 Mdot
.61556 .66718 Mdot
.44922 .71177 Mdot
.2285 .54109 Mdot
.60977 .49519 Mdot
.27607 .53826 Mdot
.31669 .5617 Mdot
.30927 .55734 Mdot
.31147 .58226 Mdot
.60186 .40438 Mdot
.43295 .70286 Mdot
.30793 .56675 Mdot
.46268 .38979 Mdot
.45846 .38574 Mdot
.6357 .51768 Mdot
.69678 .4562 Mdot
.35193 .31613 Mdot
.61132 .51373 Mdot
.50192 .35991 Mdot
.59942 .67254 Mdot
.69286 .46899 Mdot
.60785 .51713 Mdot
.59271 .66374 Mdot
.59258 .6678 Mdot
.6048 .51366 Mdot
.69102 .46668 Mdot
.35285 .46088 Mdot
.36394 .33743 Mdot
.28484 .49626 Mdot
.58752 .6366 Mdot
.36911 .66815 Mdot
.36687 .4999 Mdot
.43146 .35944 Mdot
.65296 .47778 Mdot
.61152 .67803 Mdot
.33547 .56163 Mdot
.45786 .37624 Mdot
.61941 .49698 Mdot
.7177 .43717 Mdot
.63498 .49805 Mdot
.64993 .49353 Mdot
.33065 .52677 Mdot
.44036 .80495 Mdot
.29787 .5141 Mdot
.61388 .70538 Mdot
.62715 .50638 Mdot
.26613 .32859 Mdot
.5915 .62108 Mdot
.36533 .71447 Mdot
.33168 .30111 Mdot
.5078 .36866 Mdot
.59467 .64896 Mdot
.33036 .56161 Mdot
.41565 .68281 Mdot
.48846 .23852 Mdot
.29765 .55071 Mdot
.60156 .51492 Mdot
.64693 .4974 Mdot
.60685 .63549 Mdot
.32033 .53639 Mdot
.35671 .31127 Mdot
.3029 .55867 Mdot
.44076 .7268 Mdot
.42509 .37409 Mdot
.24659 .66299 Mdot
.61502 .49684 Mdot
.28869 .54929 Mdot
.63121 .64817 Mdot
.70802 .44341 Mdot
.42939 .36888 Mdot
.24623 .67175 Mdot
.48031 .37214 Mdot
.44613 .73014 Mdot
.64286 .46087 Mdot
.35443 .33211 Mdot
.47634 .35589 Mdot
.43281 .39453 Mdot
.44992 .65346 Mdot
.48285 .35645 Mdot
.50333 .39008 Mdot
.30605 .37235 Mdot
.29118 .52146 Mdot
.48113 .36388 Mdot
.62032 .65373 Mdot
.54377 .62118 Mdot
.44649 .37749 Mdot
.65029 .71747 Mdot
.5129 .25378 Mdot
.65691 .50416 Mdot
.68382 .48164 Mdot
.63579 .35574 Mdot
.44667 .35851 Mdot
.48905 .34507 Mdot
.42648 .37667 Mdot
.4327 .43336 Mdot
.60009 .64804 Mdot
.63673 .66768 Mdot
.71409 .44527 Mdot
.48114 .27826 Mdot
.72007 .42642 Mdot
.4217 .69745 Mdot
.34756 .28877 Mdot
.60242 .48856 Mdot
.29361 .54733 Mdot
.47575 .37518 Mdot
.63456 .65587 Mdot
.44057 .36275 Mdot
.35191 .30144 Mdot
.61412 .64787 Mdot
.60805 .67851 Mdot
.63423 .69415 Mdot
.7554 .40793 Mdot
.29303 .53539 Mdot
.43049 .35258 Mdot
.73982 .40698 Mdot
.62509 .52661 Mdot
.5798 .31539 Mdot
.29367 .53094 Mdot
.28739 .54349 Mdot
.29531 .57663 Mdot
.43513 .35023 Mdot
.42436 .35454 Mdot
.43139 .72176 Mdot
.36885 .51305 Mdot
.46561 .69154 Mdot
.595 .64383 Mdot
.58931 .67576 Mdot
.44212 .36104 Mdot
.76515 .4268 Mdot
.73054 .43059 Mdot
.62044 .62561 Mdot
.62832 .47313 Mdot
.70645 .44695 Mdot
.46403 .34497 Mdot
.59987 .63301 Mdot
.74235 .40503 Mdot
.22799 .54097 Mdot
.29375 .65543 Mdot
.70685 .44408 Mdot
.6118 .49782 Mdot
.33764 .42487 Mdot
.63908 .36704 Mdot
.73869 .45084 Mdot
.42091 .69011 Mdot
.51429 .38831 Mdot
.62361 .47536 Mdot
.70067 .44363 Mdot
.64314 .37866 Mdot
.60792 .64629 Mdot
.61009 .49964 Mdot
.73496 .46553 Mdot
.42146 .42064 Mdot
.70355 .4409 Mdot
.28733 .54639 Mdot
.27103 .52966 Mdot
.46466 .35504 Mdot
.33379 .30936 Mdot
.42617 .67261 Mdot
.63176 .62657 Mdot
.63613 .66032 Mdot
.36629 .55058 Mdot
.53732 .28659 Mdot
.61695 .64026 Mdot
.52646 .3723 Mdot
.69621 .44478 Mdot
.46447 .38996 Mdot
.66331 .46346 Mdot
.3565 .33422 Mdot
.68107 .48318 Mdot
.70736 .44364 Mdot
.41988 .68452 Mdot
.43727 .70423 Mdot
.45764 .69072 Mdot
.61385 .63755 Mdot
.54369 .33001 Mdot
.63448 .67367 Mdot
.29273 .36258 Mdot
.74066 .43143 Mdot
.69794 .73873 Mdot
.40673 .37117 Mdot
.50196 .35767 Mdot
.36367 .32704 Mdot
.65338 .49283 Mdot
.44617 .36183 Mdot
.42676 .70801 Mdot
.62467 .61779 Mdot
.49321 .732 Mdot
.3259 .52727 Mdot
.29558 .36486 Mdot
.60378 .6737 Mdot
.62415 .46935 Mdot
.73011 .4253 Mdot
.64262 .34095 Mdot
.71444 .45843 Mdot
.6068 .68546 Mdot
.51087 .35586 Mdot
.34011 .54544 Mdot
.75279 .70828 Mdot
.47114 .37309 Mdot
.6196 .63365 Mdot
.60681 .59004 Mdot
.34251 .32879 Mdot
.52557 .43554 Mdot
.50057 .72212 Mdot
.54242 .30359 Mdot
.75313 .40411 Mdot
.63627 .52174 Mdot
.52576 .26037 Mdot
.60273 .64378 Mdot
.61861 .61498 Mdot
.74024 .44886 Mdot
.28189 .51806 Mdot
.30542 .57566 Mdot
.35815 .47246 Mdot
.42781 .71408 Mdot
.50695 .37512 Mdot
.60169 .63388 Mdot
.28405 .52014 Mdot
.53568 .34323 Mdot
.4509 .69004 Mdot
.61272 .62183 Mdot
.48204 .37811 Mdot
.47223 .35675 Mdot
.71903 .42862 Mdot
.65744 .45789 Mdot
.65032 .5064 Mdot
.36457 .70809 Mdot
.53404 .32283 Mdot
.35185 .28976 Mdot
.50602 .36614 Mdot
.32955 .55122 Mdot
.61892 .51943 Mdot
.72779 .43312 Mdot
.41813 .36857 Mdot
.41421 .39862 Mdot
.33157 .56403 Mdot
.44994 .67789 Mdot
.62513 .50258 Mdot
.50678 .28359 Mdot
.4826 .3759 Mdot
.44509 .35672 Mdot
.35424 .29589 Mdot
.39741 .38196 Mdot
.60502 .60816 Mdot
.30842 .51261 Mdot
.7352 .40865 Mdot
.30779 .54819 Mdot
.66443 .73136 Mdot
.33502 .29774 Mdot
.52446 .37813 Mdot
.3297 .5184 Mdot
.31198 .53992 Mdot
.44636 .72947 Mdot
.43343 .69799 Mdot
.63386 .57625 Mdot
.44102 .38045 Mdot
.63116 .47479 Mdot
.30969 .5646 Mdot
.6333 .63341 Mdot
.71883 .42633 Mdot
.6542 .72965 Mdot
.4961 .37712 Mdot
.60227 .63887 Mdot
.63349 .50991 Mdot
.32816 .52636 Mdot
.59776 .66605 Mdot
.64095 .513 Mdot
.74382 .43702 Mdot
.47117 .40069 Mdot
.63019 .57292 Mdot
.62518 .48885 Mdot
.4434 .38342 Mdot
.32717 .27996 Mdot
.33458 .31265 Mdot
.66301 .48343 Mdot
.61385 .58992 Mdot
.6252 .49203 Mdot
.27338 .54882 Mdot
.33662 .32307 Mdot
.63007 .62912 Mdot
.36781 .50501 Mdot
.33233 .30076 Mdot
.61734 .49073 Mdot
.2885 .53396 Mdot
.6679 .73099 Mdot
.32191 .50081 Mdot
.63194 .37621 Mdot
.45395 .3792 Mdot
.60392 .62926 Mdot
.72175 .4342 Mdot
.43645 .72838 Mdot
.46023 .74696 Mdot
.37321 .66728 Mdot
.58616 .65208 Mdot
.47634 .37673 Mdot
.30176 .56245 Mdot
.43683 .69104 Mdot
.29994 .59108 Mdot
.62668 .67296 Mdot
.62043 .66511 Mdot
.36247 .32695 Mdot
.72088 .42504 Mdot
.40485 .37203 Mdot
.63435 .64035 Mdot
.61912 .71128 Mdot
.30912 .3751 Mdot
.74309 .40445 Mdot
.35725 .29613 Mdot
.66687 .47001 Mdot
.43522 .38949 Mdot
.31708 .39121 Mdot
.64788 .48977 Mdot
.32658 .52912 Mdot
.48306 .35148 Mdot
.49145 .81725 Mdot
.58954 .62316 Mdot
.54203 .30362 Mdot
.5094 .70316 Mdot
.43809 .71242 Mdot
.59863 .65673 Mdot
.46369 .37854 Mdot
.65298 .72937 Mdot
.72452 .44452 Mdot
.37276 .3223 Mdot
.62467 .48437 Mdot
.36089 .57482 Mdot
.46027 .70743 Mdot
.73995 .45978 Mdot
.43546 .72778 Mdot
.45767 .68504 Mdot
.22999 .54475 Mdot
.46262 .35553 Mdot
.606 .66952 Mdot
.62415 .65655 Mdot
.66235 .46605 Mdot
.60187 .7045 Mdot
.30602 .57853 Mdot
.48673 .81382 Mdot
.42454 .40196 Mdot
.49066 .3688 Mdot
.60261 .5176 Mdot
.63719 .47644 Mdot
.64887 .72463 Mdot
.48163 .35488 Mdot
.29241 .52397 Mdot
.63694 .6509 Mdot
.61058 .62797 Mdot
.33741 .30077 Mdot
.4367 .70389 Mdot
.71594 .45869 Mdot
.61547 .66187 Mdot
.58253 .32672 Mdot
.43747 .36347 Mdot
.41402 .68905 Mdot
.61451 .65965 Mdot
.8316 .61748 Mdot
.43605 .81237 Mdot
.29352 .51531 Mdot
.44248 .39914 Mdot
.27686 .55071 Mdot
.70573 .44046 Mdot
.62732 .68526 Mdot
.42669 .72491 Mdot
.62947 .50448 Mdot
.51944 .69609 Mdot
.6094 .6314 Mdot
.30198 .54193 Mdot
.45849 .35449 Mdot
.33037 .3407 Mdot
.48633 .37599 Mdot
.5877 .41243 Mdot
.7518 .39889 Mdot
.46135 .74695 Mdot
.4544 .72819 Mdot
.44146 .39904 Mdot
.74602 .40583 Mdot
.60582 .68748 Mdot
.61282 .64563 Mdot
.2529 .67531 Mdot
.64941 .49473 Mdot
.61743 .6926 Mdot
.44135 .38202 Mdot
.63315 .69593 Mdot
.33395 .42044 Mdot
.43953 .71162 Mdot
.48382 .39189 Mdot
.59961 .6285 Mdot
.31134 .49931 Mdot
.54555 .31105 Mdot
.44255 .37273 Mdot
.65257 .47077 Mdot
.43436 .6923 Mdot
.29174 .3585 Mdot
.60291 .60344 Mdot
.48326 .38664 Mdot
.42495 .69631 Mdot
.77808 .41905 Mdot
.47427 .75733 Mdot
.2929 .53434 Mdot
.62195 .63814 Mdot
.45893 .70662 Mdot
.62294 .51123 Mdot
.7279 .40942 Mdot
.61541 .68699 Mdot
.60141 .62424 Mdot
.34529 .30529 Mdot
.63925 .46746 Mdot
.74418 .44722 Mdot
.32512 .55614 Mdot
.44776 .68062 Mdot
.34794 .29938 Mdot
.58758 .32734 Mdot
.42108 .35683 Mdot
.45748 .68159 Mdot
.27197 .33532 Mdot
.51371 .36003 Mdot
.49839 .37716 Mdot
.33232 .34048 Mdot
.27304 .54408 Mdot
.32536 .5655 Mdot
.52549 .30104 Mdot
.35097 .31287 Mdot
.53771 .35637 Mdot
.29506 .54132 Mdot
.30445 .54033 Mdot
.53668 .35549 Mdot
.34738 .3037 Mdot
.36021 .47081 Mdot
.43868 .69532 Mdot
.4371 .71081 Mdot
.30996 .55599 Mdot
.36332 .32786 Mdot
.44296 .66768 Mdot
.31936 .59758 Mdot
.62181 .67104 Mdot
.5166 .25788 Mdot
.3117 .54714 Mdot
.54966 .30914 Mdot
.43922 .68405 Mdot
.59925 .31669 Mdot
.51102 .25244 Mdot
.48412 .34334 Mdot
.47101 .35489 Mdot
.75323 .41469 Mdot
.63453 .50126 Mdot
.60482 .51403 Mdot
.45814 .69146 Mdot
.4037 .37055 Mdot
.29948 .52326 Mdot
.41108 .36337 Mdot
.64187 .37174 Mdot
.60563 .31337 Mdot
.4446 .40276 Mdot
.30254 .53433 Mdot
.31003 .52695 Mdot
.58639 .67418 Mdot
.62435 .60779 Mdot
.531 .36474 Mdot
.43441 .69625 Mdot
.291 .55646 Mdot
.46473 .69679 Mdot
.60386 .6438 Mdot
.60654 .6729 Mdot
.62341 .52163 Mdot
.6096 .50151 Mdot
.60279 .65479 Mdot
.65022 .71804 Mdot
.58616 .32492 Mdot
.3689 .52059 Mdot
.28242 .34404 Mdot
.63105 .33614 Mdot
.36337 .36746 Mdot
.71983 .43654 Mdot
.69272 .46998 Mdot
.42523 .70203 Mdot
.42739 .39521 Mdot
.49134 .35248 Mdot
.63202 .48947 Mdot
.42805 .68591 Mdot
.73927 .42212 Mdot
.43908 .71234 Mdot
.72571 .41073 Mdot
.63094 .63466 Mdot
.47352 .37909 Mdot
.50078 .35082 Mdot
.44621 .72869 Mdot
.59241 .67954 Mdot
.59796 .6324 Mdot
.72298 .4372 Mdot
.63391 .34224 Mdot
.60568 .63675 Mdot
.31175 .54562 Mdot
.21231 .59552 Mdot
.64663 .49129 Mdot
.45942 .37642 Mdot
.6368 .353 Mdot
.3346 .32042 Mdot
.62301 .52685 Mdot
.6248 .50204 Mdot
.29464 .36995 Mdot
.44288 .35109 Mdot
.27066 .68 Mdot
.61019 .51854 Mdot
.29888 .58156 Mdot
.6045 .66595 Mdot
.61104 .52264 Mdot
.66787 .47321 Mdot
.68327 .45987 Mdot
.60757 .52226 Mdot
.30859 .57281 Mdot
.27883 .55785 Mdot
.35296 .32115 Mdot
.2731 .29996 Mdot
.7219 .41514 Mdot
.73578 .43004 Mdot
.60146 .61258 Mdot
.39195 .65296 Mdot
.40097 .33597 Mdot
.73577 .43593 Mdot
.2641 .50117 Mdot
.36559 .323 Mdot
.34413 .32248 Mdot
.34221 .31771 Mdot
.29152 .58337 Mdot
.5151 .34985 Mdot
.59971 .61037 Mdot
.30047 .54106 Mdot
.35672 .32303 Mdot
.41587 .35826 Mdot
.29517 .52721 Mdot
.45238 .68338 Mdot
.36359 .29203 Mdot
.29847 .55854 Mdot
.48883 .23714 Mdot
.44035 .67989 Mdot
.41913 .39571 Mdot
.71889 .70802 Mdot
.84389 .5971 Mdot
.44332 .71126 Mdot
.61436 .62299 Mdot
.5999 .63685 Mdot
.61503 .64352 Mdot
.32389 .56495 Mdot
.5828 .66617 Mdot
.32159 .53381 Mdot
.64605 .72556 Mdot
.49021 .27874 Mdot
.72018 .4191 Mdot
.60024 .70104 Mdot
.30865 .55645 Mdot
.3078 .38129 Mdot
.67688 .19615 Mdot
.47865 .38794 Mdot
.42599 .72599 Mdot
.72507 .44805 Mdot
.54545 .29889 Mdot
.74861 .41951 Mdot
.59474 .65745 Mdot
.50396 .28044 Mdot
.43945 .36208 Mdot
.28748 .66198 Mdot
.72256 .43198 Mdot
.30566 .54094 Mdot
.342 .30735 Mdot
.61472 .5878 Mdot
.72413 .44345 Mdot
.72495 .42441 Mdot
.44737 .36623 Mdot
.28505 .57338 Mdot
.59308 .6502 Mdot
.43092 .68329 Mdot
.63438 .71674 Mdot
.55491 .3727 Mdot
.43933 .35247 Mdot
.49978 .38143 Mdot
.54721 .31973 Mdot
.65415 .72808 Mdot
.43991 .70071 Mdot
.62954 .38877 Mdot
.6033 .60019 Mdot
.64337 .36494 Mdot
.31164 .50198 Mdot
.59846 .70031 Mdot
.64672 .48787 Mdot
.63622 .51782 Mdot
.4626 .37036 Mdot
.68609 .2088 Mdot
.5389 .42887 Mdot
.43901 .66763 Mdot
.64034 .48727 Mdot
.58259 .67133 Mdot
.31904 .57598 Mdot
.72891 .46938 Mdot
.35429 .31552 Mdot
.43238 .68036 Mdot
.60954 .64094 Mdot
.72611 .24774 Mdot
.75605 .41674 Mdot
.53877 .29938 Mdot
.46113 .38682 Mdot
.45899 .37091 Mdot
.45377 .69497 Mdot
.42145 .6739 Mdot
.29219 .35394 Mdot
.67275 .45756 Mdot
.23901 .66044 Mdot
.46508 .66732 Mdot
.74246 .26173 Mdot
.6335 .47598 Mdot
.3127 .52354 Mdot
.602 .50831 Mdot
.42121 .67611 Mdot
.47522 .34987 Mdot
.28112 .56508 Mdot
.6364 .50939 Mdot
.25098 .52452 Mdot
.33871 .31951 Mdot
.58254 .32463 Mdot
.46735 .36436 Mdot
.29079 .56824 Mdot
.29648 .53896 Mdot
.27899 .54248 Mdot
.64221 .50686 Mdot
.50235 .37082 Mdot
.48726 .38372 Mdot
.50123 .37941 Mdot
.29427 .35425 Mdot
.47168 .37688 Mdot
.34164 .54309 Mdot
.53271 .28165 Mdot
.50041 .8235 Mdot
.50063 .35121 Mdot
.45891 .70197 Mdot
.46343 .36738 Mdot
.76069 .40999 Mdot
.45892 .39989 Mdot
.33168 .31044 Mdot
.443 .69839 Mdot
.39472 .38602 Mdot
.76721 .39639 Mdot
.45197 .34697 Mdot
.7161 .41585 Mdot
.37419 .74474 Mdot
.62289 .3908 Mdot
.32759 .40405 Mdot
.30467 .55786 Mdot
.62869 .67454 Mdot
.43142 .66472 Mdot
.5978 .67617 Mdot
.36873 .33637 Mdot
.60412 .49004 Mdot
.6942 .73904 Mdot
.59119 .32517 Mdot
.47875 .3505 Mdot
.64829 .47853 Mdot
.28838 .52832 Mdot
.5918 .6196 Mdot
.36394 .38795 Mdot
.36469 .32594 Mdot
.72358 .45194 Mdot
.74705 .42855 Mdot
.61487 .46727 Mdot
.27799 .53092 Mdot
.33136 .41896 Mdot
.45254 .69526 Mdot
.61312 .63462 Mdot
.70254 .42272 Mdot
.27773 .49352 Mdot
.41706 .67978 Mdot
.64601 .72264 Mdot
.4587 .71022 Mdot
.50515 .35893 Mdot
.60598 .51795 Mdot
.3666 .48928 Mdot
.63389 .48429 Mdot
.41592 .3651 Mdot
.59939 .62658 Mdot
.64875 .49145 Mdot
.74634 .40928 Mdot
.46142 .69627 Mdot
.60133 .67352 Mdot
.45178 .35562 Mdot
.29233 .54001 Mdot
.42826 .23877 Mdot
.58234 .62252 Mdot
.33354 .30226 Mdot
.3336 .30142 Mdot
.36937 .5462 Mdot
.66301 .49147 Mdot
.45104 .7627 Mdot
.33903 .32745 Mdot
.37735 .66106 Mdot
.75275 .4425 Mdot
.67796 .73811 Mdot
.63382 .67163 Mdot
.609 .65307 Mdot
.46413 .3475 Mdot
.63749 .64903 Mdot
.52522 .37501 Mdot
.61628 .59001 Mdot
.36101 .7053 Mdot
.48651 .33847 Mdot
.61387 .65092 Mdot
.60835 .51412 Mdot
.43232 .37414 Mdot
.2947 .51942 Mdot
.63178 .68495 Mdot
.48291 .34319 Mdot
.677 .72415 Mdot
.44569 .7295 Mdot
.64155 .50885 Mdot
.54569 .3412 Mdot
.44054 .68995 Mdot
.31321 .57255 Mdot
.5045 .39399 Mdot
.7322 .44122 Mdot
.31494 .52959 Mdot
.59125 .5069 Mdot
.72274 .42322 Mdot
.5434 .29064 Mdot
.3186 .55227 Mdot
.64476 .4872 Mdot
.74438 .43477 Mdot
.68421 .47642 Mdot
.60904 .64988 Mdot
.60573 .59053 Mdot
.62124 .49224 Mdot
.44074 .35825 Mdot
.57783 .64802 Mdot
.44953 .71348 Mdot
.45029 .38134 Mdot
.60415 .6308 Mdot
.64219 .49529 Mdot
.48044 .38428 Mdot
.35091 .3139 Mdot
.31269 .38252 Mdot
.65611 .50663 Mdot
.72974 .41246 Mdot
.27957 .53425 Mdot
.48699 .38603 Mdot
.71412 .42006 Mdot
.58331 .68002 Mdot
.46303 .39175 Mdot
.28404 .54533 Mdot
.24588 .51641 Mdot
.63144 .62431 Mdot
.44683 .67591 Mdot
.62557 .65514 Mdot
.70578 .42174 Mdot
.67308 .19134 Mdot
.61314 .51863 Mdot
.36695 .33207 Mdot
.48791 .39629 Mdot
.6299 .67606 Mdot
.29523 .53506 Mdot
.22464 .64998 Mdot
.45987 .40032 Mdot
.45966 .39105 Mdot
.4554 .37352 Mdot
.63599 .71964 Mdot
.31472 .57725 Mdot
.45725 .37517 Mdot
.69221 .46184 Mdot
.49689 .38627 Mdot
.71154 .44198 Mdot
.70308 .7269 Mdot
.64047 .51555 Mdot
.26329 .32479 Mdot
.6372 .51008 Mdot
.61727 .65607 Mdot
.48907 .23654 Mdot
.54227 .34064 Mdot
.64659 .59759 Mdot
.31254 .57384 Mdot
.28455 .49679 Mdot
.60803 .6716 Mdot
.66733 .73189 Mdot
.35715 .31624 Mdot
.344 .3084 Mdot
.43183 .37008 Mdot
.59484 .65781 Mdot
.61846 .61018 Mdot
.60586 .49049 Mdot
.64762 .4794 Mdot
.41753 .39457 Mdot
.63256 .6474 Mdot
.47224 .37864 Mdot
.3511 .32996 Mdot
.41821 .67579 Mdot
.28824 .52134 Mdot
.42005 .71506 Mdot
.41486 .6937 Mdot
.36566 .37371 Mdot
.53319 .32374 Mdot
.42678 .71275 Mdot
.4259 .67865 Mdot
.63979 .71938 Mdot
.41379 .41237 Mdot
.70686 .43879 Mdot
.54035 .42934 Mdot
.59983 .68067 Mdot
.50038 .3692 Mdot
.31122 .58038 Mdot
.64084 .52302 Mdot
.21403 .63104 Mdot
.71419 .31816 Mdot
.36348 .30955 Mdot
.59043 .61727 Mdot
.62459 .48851 Mdot
.63122 .48235 Mdot
.63977 .36705 Mdot
.46943 .37759 Mdot
.63248 .628 Mdot
.42044 .41984 Mdot
.46375 .66525 Mdot
.65147 .72433 Mdot
.27597 .5341 Mdot
.46741 .36891 Mdot
.3279 .54586 Mdot
.45471 .67429 Mdot
.70981 .42845 Mdot
.75539 .41064 Mdot
.4611 .3458 Mdot
.331 .30169 Mdot
.37652 .66133 Mdot
.34644 .314 Mdot
.35182 .3031 Mdot
.62402 .49441 Mdot
.35502 .29448 Mdot
.48111 .388 Mdot
.48353 .33937 Mdot
.62628 .52645 Mdot
.4157 .70357 Mdot
.39124 .41023 Mdot
.61889 .48963 Mdot
.469 .40168 Mdot
.45691 .67548 Mdot
.3494 .31601 Mdot
.45353 .70585 Mdot
.65452 .72652 Mdot
.43386 .72142 Mdot
.73757 .40863 Mdot
.62624 .71435 Mdot
.28614 .34728 Mdot
.3003 .56119 Mdot
.43384 .70422 Mdot
.74266 .43867 Mdot
.45459 .70777 Mdot
.60615 .68288 Mdot
.45692 .65754 Mdot
.32603 .59958 Mdot
.58058 .32487 Mdot
.36564 .364 Mdot
.45903 .66335 Mdot
.62604 .61387 Mdot
.30999 .55715 Mdot
.38369 .65786 Mdot
.49436 .39693 Mdot
.7574 .41462 Mdot
.46014 .36956 Mdot
.46077 .69033 Mdot
.57899 .65692 Mdot
.32638 .40518 Mdot
.73583 .40997 Mdot
.2884 .3565 Mdot
.63391 .65586 Mdot
.51404 .3739 Mdot
.4541 .73343 Mdot
.44053 .75741 Mdot
.45207 .72843 Mdot
.49097 .27303 Mdot
.62377 .47597 Mdot
.67112 .45565 Mdot
.31677 .53619 Mdot
.64193 .47481 Mdot
.78871 .38627 Mdot
.365 .68032 Mdot
.30869 .51496 Mdot
.60024 .69649 Mdot
.43706 .35961 Mdot
.36105 .29737 Mdot
.61123 .51062 Mdot
.29036 .56221 Mdot
.35355 .29587 Mdot
.62871 .52114 Mdot
.53081 .27849 Mdot
.27713 .53888 Mdot
.60942 .69058 Mdot
.43938 .37989 Mdot
.43679 .73367 Mdot
.46766 .69486 Mdot
.60117 .51198 Mdot
.43177 .72629 Mdot
.46628 .4018 Mdot
.31633 .54941 Mdot
.35332 .32023 Mdot
.71223 .44406 Mdot
.36011 .47904 Mdot
.62766 .52921 Mdot
.68983 .43514 Mdot
.45132 .38851 Mdot
.6066 .6712 Mdot
.51831 .69951 Mdot
.44422 .39586 Mdot
.29772 .54258 Mdot
.49722 .39361 Mdot
.35396 .29493 Mdot
.34505 .31116 Mdot
.61285 .6345 Mdot
.54731 .31119 Mdot
.47301 .37779 Mdot
.43701 .67648 Mdot
.5546 .39851 Mdot
.41092 .37944 Mdot
.69275 .45874 Mdot
.33176 .31093 Mdot
.4668 .71433 Mdot
.36901 .53957 Mdot
.60647 .6681 Mdot
.30349 .5224 Mdot
.31022 .59653 Mdot
.31542 .57025 Mdot
.31777 .49554 Mdot
.33829 .32663 Mdot
.2563 .67873 Mdot
.33328 .41966 Mdot
.3557 .35792 Mdot
.33409 .56727 Mdot
.48674 .75387 Mdot
.30895 .51444 Mdot
.31315 .57281 Mdot
.218 .60911 Mdot
.3107 .57689 Mdot
.44222 .35922 Mdot
.50858 .38332 Mdot
.43506 .40298 Mdot
.63246 .71901 Mdot
.48732 .37654 Mdot
.6144 .52711 Mdot
.72379 .44969 Mdot
.28381 .51688 Mdot
.62825 .50287 Mdot
.54712 .29796 Mdot
.59618 .49664 Mdot
.44704 .36509 Mdot
.47104 .38317 Mdot
.34235 .31564 Mdot
.61379 .3117 Mdot
.63005 .71842 Mdot
.29166 .57483 Mdot
.40781 .37572 Mdot
.47282 .75778 Mdot
.43999 .3781 Mdot
.46836 .39899 Mdot
.5026 .34527 Mdot
.60599 .6696 Mdot
.29613 .58865 Mdot
.61173 .4899 Mdot
.36121 .48082 Mdot
.47883 .36916 Mdot
.60293 .5325 Mdot
.70247 .45222 Mdot
.46206 .37873 Mdot
.28957 .57746 Mdot
.35323 .29516 Mdot
.33331 .55602 Mdot
.31971 .54699 Mdot
.46318 .39151 Mdot
.28164 .52105 Mdot
.3278 .56285 Mdot
.34476 .30858 Mdot
.58817 .61954 Mdot
.36477 .71205 Mdot
.44066 .36565 Mdot
.73856 .41054 Mdot
.47732 .35372 Mdot
.70456 .43744 Mdot
.60925 .52259 Mdot
.62585 .49014 Mdot
.48325 .44932 Mdot
.62186 .61753 Mdot
.72279 .45359 Mdot
.62039 .71353 Mdot
.38973 .33151 Mdot
.25631 .51074 Mdot
.45312 .65497 Mdot
.60467 .5888 Mdot
.62635 .49136 Mdot
.59315 .40747 Mdot
.55273 .37862 Mdot
.4286 .72029 Mdot
.32632 .51827 Mdot
.39489 .41968 Mdot
.64851 .47662 Mdot
.60825 .69037 Mdot
.62327 .65865 Mdot
.36548 .67827 Mdot
.21826 .60708 Mdot
.49694 .3498 Mdot
.65001 .4777 Mdot
.32849 .28425 Mdot
.63532 .50146 Mdot
.60633 .49337 Mdot
.60522 .62131 Mdot
.48336 .382 Mdot
.53221 .27271 Mdot
.59926 .64109 Mdot
.73329 .42557 Mdot
.32724 .53075 Mdot
.71818 .41584 Mdot
.30263 .64885 Mdot
.29054 .35189 Mdot
.60072 .65203 Mdot
.64794 .50622 Mdot
.49645 .37036 Mdot
.28482 .57478 Mdot
.30234 .5909 Mdot
.29487 .51772 Mdot
.71547 .44757 Mdot
.63638 .65165 Mdot
.68175 .73593 Mdot
.45702 .35569 Mdot
.31061 .53828 Mdot
.69697 .42786 Mdot
.47416 .35714 Mdot
.43478 .70053 Mdot
.34965 .2963 Mdot
.30916 .54411 Mdot
.3669 .33054 Mdot
.31756 .53752 Mdot
.62125 .65716 Mdot
.47442 .34569 Mdot
.43328 .36368 Mdot
.62034 .39316 Mdot
.73995 .422 Mdot
.33409 .56029 Mdot
.53419 .32763 Mdot
.43445 .38918 Mdot
.63829 .36212 Mdot
.46486 .3823 Mdot
.36439 .36172 Mdot
.64681 .46842 Mdot
.62243 .52305 Mdot
.48995 .39638 Mdot
.44387 .37085 Mdot
.30232 .58994 Mdot
.33511 .41975 Mdot
.29232 .35131 Mdot
.45371 .67583 Mdot
.30577 .51324 Mdot
.59699 .64521 Mdot
.63005 .68954 Mdot
.58914 .67309 Mdot
.70473 .42145 Mdot
.35245 .31792 Mdot
.48756 .34943 Mdot
.44349 .66936 Mdot
.73595 .43947 Mdot
.30649 .5318 Mdot
.715 .4272 Mdot
.54115 .31891 Mdot
.74548 .41119 Mdot
.60069 .49711 Mdot
.42939 .80788 Mdot
.35009 .32961 Mdot
.73119 .41862 Mdot
.28472 .52617 Mdot
.55494 .42228 Mdot
.44558 .34296 Mdot
.30517 .37686 Mdot
.72158 .45239 Mdot
.59038 .69067 Mdot
.45018 .38732 Mdot
.47321 .28463 Mdot
.45656 .69751 Mdot
.73023 .40904 Mdot
.45747 .71336 Mdot
.3563 .30243 Mdot
.28854 .49655 Mdot
.30187 .54744 Mdot
.4475 .6514 Mdot
.48176 .39702 Mdot
.73197 .40839 Mdot
.60382 .6516 Mdot
.41698 .41351 Mdot
.64183 .72437 Mdot
.59613 .53168 Mdot
.6363 .37288 Mdot
.60243 .60852 Mdot
.39422 .39726 Mdot
.44169 .72499 Mdot
.40953 .36813 Mdot
.35837 .33328 Mdot
.43202 .38676 Mdot
.59414 .63993 Mdot
.60932 .65409 Mdot
.67583 .73716 Mdot
.43672 .35266 Mdot
.48868 .3426 Mdot
.35575 .58334 Mdot
.63559 .64541 Mdot
.31692 .5676 Mdot
.28892 .56385 Mdot
.6126 .62301 Mdot
.33698 .53923 Mdot
.72333 .4244 Mdot
.51988 .29023 Mdot
.44088 .72461 Mdot
.46111 .72218 Mdot
.6016 .65452 Mdot
.59454 .62575 Mdot
.60604 .67204 Mdot
.35615 .29945 Mdot
.31965 .5545 Mdot
.5242 .36497 Mdot
.45659 .36441 Mdot
.42666 .35282 Mdot
.27452 .54239 Mdot
.46582 .40076 Mdot
.45141 .33487 Mdot
.71119 .44991 Mdot
.61661 .6607 Mdot
.46457 .69148 Mdot
.42964 .24285 Mdot
.44109 .67368 Mdot
.48902 .38896 Mdot
.3617 .69789 Mdot
.32628 .51941 Mdot
.75056 .4176 Mdot
.33374 .31264 Mdot
.74954 .40894 Mdot
.41879 .67479 Mdot
.35597 .5804 Mdot
.53997 .28816 Mdot
.51889 .35854 Mdot
.54387 .32315 Mdot
.758 .63942 Mdot
.31564 .59542 Mdot
.44483 .68238 Mdot
.33951 .32304 Mdot
.59707 .49226 Mdot
.32538 .29847 Mdot
.46868 .34759 Mdot
.40809 .37338 Mdot
.4661 .28796 Mdot
.49623 .38958 Mdot
.29245 .51506 Mdot
.53537 .35526 Mdot
.65386 .49659 Mdot
.42727 .37141 Mdot
.27042 .6758 Mdot
.48575 .36855 Mdot
.49515 .34706 Mdot
.49911 .35781 Mdot
.43118 .38889 Mdot
.27392 .53138 Mdot
.34423 .32002 Mdot
.44421 .67386 Mdot
.52 .2888 Mdot
.44201 .72343 Mdot
.60036 .66062 Mdot
.65002 .51476 Mdot
.27723 .56056 Mdot
.75091 .4094 Mdot
.43192 .62997 Mdot
.47655 .2825 Mdot
.587 .67482 Mdot
.61027 .40119 Mdot
.72248 .45736 Mdot
.6048 .50242 Mdot
.71189 .41614 Mdot
.59937 .6282 Mdot
.43914 .70722 Mdot
.51174 .35682 Mdot
.31305 .56572 Mdot
.29453 .55699 Mdot
.43059 .37612 Mdot
.36989 .72716 Mdot
.46749 .69658 Mdot
.60249 .70247 Mdot
.50024 .35252 Mdot
.48311 .39207 Mdot
.3319 .54935 Mdot
.58396 .63649 Mdot
.539 .35513 Mdot
.72411 .43976 Mdot
.44591 .3819 Mdot
.65387 .48624 Mdot
.54192 .31962 Mdot
.44942 .67529 Mdot
.64428 .4939 Mdot
.49169 .36422 Mdot
.53156 .31758 Mdot
.37238 .3184 Mdot
.66297 .45963 Mdot
.62016 .59958 Mdot
.46193 .39109 Mdot
.43483 .36981 Mdot
.27682 .53935 Mdot
.43965 .72588 Mdot
.29376 .53509 Mdot
.3438 .59533 Mdot
.6261 .49038 Mdot
.44826 .73004 Mdot
.43258 .38925 Mdot
.46853 .67715 Mdot
.34641 .29655 Mdot
.45099 .36075 Mdot
.4464 .68283 Mdot
.32218 .54546 Mdot
.24158 .65891 Mdot
.39126 .41096 Mdot
.35298 .30183 Mdot
.47958 .35482 Mdot
.6339 .71671 Mdot
.63954 .52401 Mdot
.51794 .36775 Mdot
.29222 .55715 Mdot
.47109 .3568 Mdot
.44194 .66509 Mdot
.71323 .42446 Mdot
.29644 .54548 Mdot
.59576 .61128 Mdot
.62007 .6469 Mdot
.62638 .6104 Mdot
.60173 .49402 Mdot
.35378 .29421 Mdot
.27929 .53806 Mdot
.284 .55621 Mdot
.54163 .33251 Mdot
.61703 .65581 Mdot
.71623 .43603 Mdot
.42875 .36341 Mdot
.65337 .47986 Mdot
.44065 .74027 Mdot
.26209 .32384 Mdot
.5365 .28918 Mdot
.69716 .43306 Mdot
.55899 .38574 Mdot
.62583 .49588 Mdot
.49947 .37536 Mdot
.73204 .40865 Mdot
.60984 .62421 Mdot
.37174 .31058 Mdot
.74858 .44722 Mdot
.58563 .68741 Mdot
.58413 .65447 Mdot
.46653 .6753 Mdot
.61649 .59253 Mdot
.73891 .40564 Mdot
.61021 .51751 Mdot
.29525 .55194 Mdot
.46576 .37914 Mdot
.61418 .49996 Mdot
.61699 .67138 Mdot
.62269 .47877 Mdot
.50863 .36129 Mdot
.33254 .54331 Mdot
.60175 .67945 Mdot
.44487 .36065 Mdot
.34264 .32969 Mdot
.31229 .38137 Mdot
.5856 .62705 Mdot
.5197 .38045 Mdot
.73963 .46341 Mdot
.58757 .66457 Mdot
.59442 .63659 Mdot
.46156 .39193 Mdot
.75589 .42797 Mdot
.47326 .36785 Mdot
.4372 .70277 Mdot
.55098 .31775 Mdot
.44645 .72876 Mdot
.64282 .3632 Mdot
.43836 .38481 Mdot
.43098 .39885 Mdot
.25376 .51469 Mdot
.78092 .39814 Mdot
.63336 .33654 Mdot
.49156 .38246 Mdot
.32066 .57694 Mdot
.54994 .31054 Mdot
.57783 .32473 Mdot
.32222 .59899 Mdot
.7053 .43122 Mdot
.45819 .69277 Mdot
.4345 .35918 Mdot
.27688 .67294 Mdot
.71198 .4399 Mdot
.64056 .36503 Mdot
.42029 .3933 Mdot
.30257 .53745 Mdot
.48694 .34788 Mdot
.30077 .55312 Mdot
.489 .35918 Mdot
.32269 .39706 Mdot
.37644 .66293 Mdot
.49047 .27372 Mdot
.60873 .51347 Mdot
.44087 .75729 Mdot
.3644 .3632 Mdot
.72082 .42873 Mdot
.36113 .33261 Mdot
.63118 .49223 Mdot
.43931 .71261 Mdot
.43953 .64816 Mdot
.60725 .67294 Mdot
.43019 .68885 Mdot
.31505 .52216 Mdot
.57967 .66781 Mdot
.6369 .47486 Mdot
.35386 .28518 Mdot
.74966 .40539 Mdot
.44823 .73036 Mdot
.45542 .37822 Mdot
.41806 .35853 Mdot
.63626 .71985 Mdot
.70823 .7234 Mdot
.32862 .51189 Mdot
.28162 .3441 Mdot
.35582 .58104 Mdot
.73715 .42614 Mdot
.58333 .6318 Mdot
.48655 .35161 Mdot
.48226 .38039 Mdot
.58359 .6504 Mdot
.28441 .57481 Mdot
.73636 .44737 Mdot
.67167 .45526 Mdot
.44058 .66751 Mdot
.73628 .71906 Mdot
.29602 .54705 Mdot
.73512 .72072 Mdot
.67818 .735 Mdot
.21628 .60152 Mdot
.6341 .33976 Mdot
.44008 .69388 Mdot
.73599 .72032 Mdot
.30603 .53707 Mdot
.50752 .38062 Mdot
.63863 .48529 Mdot
.60502 .48836 Mdot
.32975 .54052 Mdot
.59687 .66324 Mdot
.75653 .42816 Mdot
.46067 .34748 Mdot
.68596 .46476 Mdot
.29958 .59115 Mdot
.6327 .63948 Mdot
.63155 .50765 Mdot
.46163 .68261 Mdot
.47623 .35611 Mdot
.71566 .44853 Mdot
.44133 .69486 Mdot
.63663 .51798 Mdot
.50661 .28079 Mdot
.50526 .39359 Mdot
.33184 .3047 Mdot
.45517 .69915 Mdot
.53907 .34994 Mdot
.44321 .37787 Mdot
.44183 .725 Mdot
.62362 .46899 Mdot
.44689 .76026 Mdot
.54129 .35525 Mdot
.36503 .6805 Mdot
.58436 .67731 Mdot
.61414 .59017 Mdot
.60159 .58416 Mdot
.62702 .71697 Mdot
.43577 .71864 Mdot
.61858 .50372 Mdot
.70087 .73728 Mdot
.44092 .72653 Mdot
.44957 .39744 Mdot
.43572 .35882 Mdot
.41962 .4204 Mdot
.63953 .51597 Mdot
.63348 .51486 Mdot
.3681 .50201 Mdot
.34994 .32595 Mdot
.63073 .5068 Mdot
.45853 .38343 Mdot
.28123 .56186 Mdot
.43985 .68209 Mdot
.79447 .34865 Mdot
.42586 .67121 Mdot
.36937 .30057 Mdot
.59251 .67765 Mdot
.58051 .67255 Mdot
.46375 .37796 Mdot
.51823 .6402 Mdot
.73729 .2568 Mdot
.43549 .35856 Mdot
.33377 .313 Mdot
.64334 .36575 Mdot
.42769 .37289 Mdot
.31224 .50954 Mdot
.6511 .49482 Mdot
.2791 .55393 Mdot
.44263 .69038 Mdot
.70543 .43222 Mdot
.78603 .40328 Mdot
.45761 .69195 Mdot
.48386 .37061 Mdot
.61651 .53034 Mdot
.45761 .37156 Mdot
.50828 .37296 Mdot
.53461 .31458 Mdot
.69823 .4377 Mdot
.60191 .67028 Mdot
.75009 .4081 Mdot
.31137 .57523 Mdot
.27443 .33695 Mdot
.71787 .43024 Mdot
.41523 .41301 Mdot
.54739 .32571 Mdot
.70206 .72552 Mdot
.29396 .55574 Mdot
.70509 .44016 Mdot
.45881 .69743 Mdot
.56797 .34351 Mdot
.41662 .40628 Mdot
.43204 .68179 Mdot
.50687 .36972 Mdot
.28617 .56457 Mdot
.36789 .55325 Mdot
.46792 .70566 Mdot
.28772 .53743 Mdot
.5389 .35194 Mdot
.35694 .30635 Mdot
.4479 .67334 Mdot
.61961 .32667 Mdot
.45411 .72832 Mdot
.36864 .38265 Mdot
.34427 .29939 Mdot
.29743 .54402 Mdot
.33352 .34393 Mdot
.35355 .58035 Mdot
.6272 .52042 Mdot
.51163 .3838 Mdot
.71808 .43368 Mdot
.54332 .32998 Mdot
.59657 .60811 Mdot
.3085 .49991 Mdot
.30954 .55176 Mdot
.43566 .74165 Mdot
.28824 .54027 Mdot
.33101 .52433 Mdot
.44482 .65181 Mdot
.31089 .51372 Mdot
.47984 .36977 Mdot
.2743 .29825 Mdot
.28898 .52613 Mdot
.45013 .69421 Mdot
.72224 .44611 Mdot
.29167 .51699 Mdot
.66966 .73365 Mdot
.4391 .38023 Mdot
.62741 .66984 Mdot
.75473 .43489 Mdot
.27341 .53753 Mdot
.72128 .43085 Mdot
.61415 .67606 Mdot
.70181 .45696 Mdot
.4446 .74462 Mdot
.46197 .7256 Mdot
.66731 .47356 Mdot
.3662 .67521 Mdot
.31122 .57636 Mdot
.57764 .66028 Mdot
.43386 .35226 Mdot
.50287 .35686 Mdot
.75766 .40053 Mdot
.33019 .56928 Mdot
.3721 .73719 Mdot
.62872 .5039 Mdot
.36282 .47845 Mdot
.46367 .68241 Mdot
.60173 .70165 Mdot
.54202 .28664 Mdot
.41982 .64537 Mdot
.6532 .49866 Mdot
.6273 .49403 Mdot
.45507 .3737 Mdot
.62732 .38898 Mdot
.72279 .41195 Mdot
.49489 .74589 Mdot
.36697 .3123 Mdot
.58641 .63902 Mdot
.49779 .36319 Mdot
.35952 .32267 Mdot
.48434 .38702 Mdot
.70095 .42475 Mdot
.42623 .69119 Mdot
.29773 .56053 Mdot
.70329 .43717 Mdot
.62017 .64618 Mdot
.49911 .24184 Mdot
.51904 .36765 Mdot
.52522 .37618 Mdot
.59247 .66591 Mdot
.30509 .57693 Mdot
.60528 .65947 Mdot
.44142 .72446 Mdot
.71695 .42759 Mdot
.35437 .29664 Mdot
.64059 .51493 Mdot
.63025 .67656 Mdot
.43377 .706 Mdot
.59014 .61567 Mdot
.46492 .66907 Mdot
.62811 .49081 Mdot
.52133 .3831 Mdot
.63674 .64319 Mdot
.63006 .48004 Mdot
.34805 .44779 Mdot
.50644 .28404 Mdot
.21903 .59221 Mdot
.59448 .66119 Mdot
.65185 .60022 Mdot
.44456 .69479 Mdot
.41794 .68776 Mdot
.36349 .37876 Mdot
.68777 .21149 Mdot
.53352 .35294 Mdot
.38384 .76107 Mdot
.44017 .72449 Mdot
.45066 .70481 Mdot
.60616 .66325 Mdot
.32302 .54477 Mdot
.24915 .52611 Mdot
.60358 .68622 Mdot
.63364 .35295 Mdot
.30672 .53204 Mdot
.43201 .40291 Mdot
.63576 .67145 Mdot
.34269 .3102 Mdot
.32605 .40619 Mdot
.70912 .45156 Mdot
.63241 .37878 Mdot
.45434 .65631 Mdot
.4478 .35371 Mdot
.25229 .67796 Mdot
.60996 .67087 Mdot
.62251 .48037 Mdot
.48391 .74228 Mdot
.41577 .35964 Mdot
.50045 .36709 Mdot
.46794 .36176 Mdot
.75897 .40393 Mdot
.3395 .43015 Mdot
.46388 .3496 Mdot
.49805 .2787 Mdot
.35678 .29223 Mdot
.60466 .59077 Mdot
.74676 .40773 Mdot
.60215 .40632 Mdot
.6592 .72109 Mdot
.36423 .48258 Mdot
.40708 .37166 Mdot
.42151 .68504 Mdot
.35024 .32534 Mdot
.4509 .68186 Mdot
.46381 .67716 Mdot
.74762 .71141 Mdot
.29115 .55908 Mdot
.36365 .30635 Mdot
.61589 .61678 Mdot
.25076 .51837 Mdot
.3596 .31962 Mdot
.27721 .33983 Mdot
.42081 .72223 Mdot
.67164 .18933 Mdot
.41739 .6962 Mdot
.61241 .48353 Mdot
.31561 .51972 Mdot
.31598 .58324 Mdot
.54184 .32341 Mdot
.31943 .5624 Mdot
.62847 .71643 Mdot
.27996 .53658 Mdot
.83221 .57003 Mdot
.32817 .59638 Mdot
.44602 .69955 Mdot
.46159 .723 Mdot
.34743 .31829 Mdot
.47869 .37283 Mdot
.53185 .27542 Mdot
.62963 .50393 Mdot
.50311 .39347 Mdot
.59947 .64028 Mdot
.67298 .73521 Mdot
.41444 .79581 Mdot
.3165 .51489 Mdot
.43332 .71035 Mdot
.50031 .36584 Mdot
.34608 .29881 Mdot
.50982 .38247 Mdot
.395 .65094 Mdot
.37011 .34191 Mdot
.4557 .36544 Mdot
.35075 .31779 Mdot
.59909 .68334 Mdot
.63775 .71604 Mdot
.21871 .60584 Mdot
.74239 .7147 Mdot
.47946 .38526 Mdot
.73827 .43132 Mdot
.70235 .42378 Mdot
.50862 .34515 Mdot
.57479 .56588 Mdot
.5408 .34999 Mdot
.45382 .37744 Mdot
.49647 .24004 Mdot
.61005 .6915 Mdot
.59749 .49725 Mdot
.61806 .66714 Mdot
.30862 .59665 Mdot
.60559 .51854 Mdot
.60127 .63255 Mdot
.51576 .25641 Mdot
.61987 .49537 Mdot
.45101 .7612 Mdot
.711 .44385 Mdot
.45234 .38218 Mdot
.36544 .40081 Mdot
.63671 .65098 Mdot
.44123 .70471 Mdot
.30437 .51744 Mdot
.44557 .67572 Mdot
.62892 .71265 Mdot
.63931 .35593 Mdot
.63443 .51706 Mdot
.42529 .67658 Mdot
.33057 .29916 Mdot
.73863 .43415 Mdot
.41816 .70896 Mdot
.35091 .29211 Mdot
.5038 .34271 Mdot
.71207 .23795 Mdot
.46792 .34347 Mdot
.67405 .73581 Mdot
.44311 .72893 Mdot
.59677 .49076 Mdot
.46726 .37869 Mdot
.63203 .65479 Mdot
.68447 .48072 Mdot
.45469 .37025 Mdot
.59987 .60842 Mdot
.43681 .36682 Mdot
.73372 .40868 Mdot
.27688 .54491 Mdot
.55133 .30706 Mdot
.73874 .39563 Mdot
.7049 .43454 Mdot
.47108 .28268 Mdot
.51543 .37841 Mdot
.52924 .66974 Mdot
.30001 .53595 Mdot
.49171 .38761 Mdot
.73338 .39571 Mdot
.32408 .53199 Mdot
.30629 .52323 Mdot
.37124 .3066 Mdot
.44091 .66345 Mdot
.59821 .66968 Mdot
.74668 .42236 Mdot
.65003 .72316 Mdot
.4481 .35481 Mdot
.36646 .32909 Mdot
.7085 .43987 Mdot
.43494 .69265 Mdot
.3605 .30443 Mdot
.4007 .78015 Mdot
.51826 .28735 Mdot
.4195 .71598 Mdot
.41008 .3755 Mdot
.33855 .34026 Mdot
.29175 .58242 Mdot
.25819 .67828 Mdot
.37623 .66433 Mdot
.6227 .65377 Mdot
.6291 .50832 Mdot
.26564 .32927 Mdot
.71447 .44755 Mdot
.24355 .53432 Mdot
.50643 .35924 Mdot
.48905 .35459 Mdot
.28134 .56414 Mdot
.51982 .3574 Mdot
.32226 .51669 Mdot
.66869 .73185 Mdot
.6844 .20596 Mdot
.29745 .55583 Mdot
.30644 .54666 Mdot
.37198 .29709 Mdot
.63409 .69536 Mdot
.3279 .53033 Mdot
.43249 .35989 Mdot
.62887 .71293 Mdot
.66286 .46139 Mdot
.73871 .44375 Mdot
.76674 .41433 Mdot
.32353 .51238 Mdot
.40797 .40215 Mdot
.33823 .29821 Mdot
.44074 .4501 Mdot
.56074 .38784 Mdot
.43501 .71923 Mdot
.42085 .36466 Mdot
.62836 .5002 Mdot
.61434 .67177 Mdot
.47372 .34196 Mdot
.45906 .38416 Mdot
.30096 .56409 Mdot
.70632 .4552 Mdot
.45298 .72124 Mdot
.62578 .48146 Mdot
.62802 .61135 Mdot
.72945 .43143 Mdot
.33633 .53538 Mdot
.36475 .36751 Mdot
.63867 .5221 Mdot
.64976 .4789 Mdot
.49821 .37852 Mdot
.46793 .39155 Mdot
.64906 .50863 Mdot
.45552 .68926 Mdot
.62366 .65516 Mdot
.61139 .49149 Mdot
.54257 .33689 Mdot
.52957 .26651 Mdot
.49415 .37651 Mdot
.28316 .53605 Mdot
.43648 .712 Mdot
.63314 .51646 Mdot
.69871 .73883 Mdot
.42722 .3651 Mdot
.416 .3983 Mdot
.6211 .44894 Mdot
.62365 .50188 Mdot
.24911 .52571 Mdot
.75368 .41473 Mdot
.34451 .29954 Mdot
.49541 .27666 Mdot
.47045 .40125 Mdot
.40971 .36915 Mdot
.607 .62411 Mdot
.4627 .69613 Mdot
.66296 .47287 Mdot
.61594 .66073 Mdot
.30456 .52257 Mdot
.45144 .45076 Mdot
.29225 .56818 Mdot
.28401 .5543 Mdot
.3071 .49741 Mdot
.45517 .67678 Mdot
.26451 .32674 Mdot
.64917 .51057 Mdot
.49689 .34912 Mdot
.42582 .70556 Mdot
.32914 .52906 Mdot
.44521 .39939 Mdot
.32602 .51904 Mdot
.33309 .56437 Mdot
.47488 .40138 Mdot
.35047 .314 Mdot
.48815 .27816 Mdot
.3967 .38592 Mdot
.75745 .41093 Mdot
.29463 .58122 Mdot
.41584 .40174 Mdot
.48103 .35059 Mdot
.47344 .38238 Mdot
.34619 .31897 Mdot
.70268 .42932 Mdot
.4814 .44992 Mdot
.50644 .36112 Mdot
.63163 .38943 Mdot
.44527 .39879 Mdot
.32898 .57171 Mdot
.46049 .74713 Mdot
.36951 .30022 Mdot
.58572 .67551 Mdot
.28385 .57298 Mdot
.70771 .45188 Mdot
.28751 .50216 Mdot
.3303 .31274 Mdot
.45211 .71095 Mdot
.30906 .54409 Mdot
.61142 .68646 Mdot
.43948 .70166 Mdot
.45445 .72815 Mdot
.34321 .31801 Mdot
.62413 .64412 Mdot
.70522 .45504 Mdot
.46246 .7139 Mdot
.3249 .30904 Mdot
.44535 .70092 Mdot
.22081 .56822 Mdot
.52731 .37707 Mdot
.49881 .27756 Mdot
.61465 .51026 Mdot
.65309 .46853 Mdot
.45166 .7261 Mdot
.72274 .44119 Mdot
.36139 .30525 Mdot
.29657 .5173 Mdot
.73252 .43946 Mdot
.32789 .40823 Mdot
.58083 .67246 Mdot
.36764 .55319 Mdot
.64421 .72304 Mdot
.32301 .56124 Mdot
.63431 .37584 Mdot
.70248 .4481 Mdot
.65883 .48365 Mdot
.54134 .30306 Mdot
.63412 .5076 Mdot
.4871 .34319 Mdot
.36295 .30702 Mdot
.47994 .36879 Mdot
.5891 .67542 Mdot
.75959 .40449 Mdot
.28592 .52923 Mdot
.76172 .44551 Mdot
.43556 .68344 Mdot
.53574 .35813 Mdot
.61546 .48461 Mdot
.35249 .3007 Mdot
.32488 .52115 Mdot
.3257 .56684 Mdot
.3365 .42123 Mdot
.58722 .66605 Mdot
.77167 .42622 Mdot
.49363 .37457 Mdot
.71167 .46814 Mdot
.45017 .72749 Mdot
.36491 .67748 Mdot
.62359 .68026 Mdot
.6687 .18899 Mdot
.61564 .65509 Mdot
.65924 .45845 Mdot
.3266 .55981 Mdot
.73183 .41354 Mdot
.48613 .37457 Mdot
.2765 .53056 Mdot
.24818 .52772 Mdot
.76373 .4249 Mdot
.75046 .41015 Mdot
.38183 .65733 Mdot
.42716 .71409 Mdot
.64055 .47859 Mdot
.44508 .3984 Mdot
.43622 .39816 Mdot
.43688 .3504 Mdot
.43013 .71071 Mdot
.35322 .3082 Mdot
.45613 .74774 Mdot
.33785 .32217 Mdot
.73234 .39593 Mdot
.59214 .63772 Mdot
.49395 .81909 Mdot
.27515 .54632 Mdot
.471 .45052 Mdot
.23599 .53408 Mdot
.50988 .28575 Mdot
.42717 .68347 Mdot
.62426 .46848 Mdot
.60322 .66676 Mdot
.47917 .64992 Mdot
.59426 .63261 Mdot
.77952 .31546 Mdot
.4177 .42066 Mdot
.45853 .75061 Mdot
.50425 .39204 Mdot
.6206 .62438 Mdot
.39427 .39124 Mdot
.61128 .49333 Mdot
.61582 .53016 Mdot
.34621 .33511 Mdot
.29497 .35657 Mdot
.75673 .40938 Mdot
.48725 .37445 Mdot
.28057 .55725 Mdot
.48534 .37618 Mdot
.4862 .37688 Mdot
.51142 .36876 Mdot
.44744 .651 Mdot
.52075 .38277 Mdot
.47918 .37154 Mdot
.68382 .7385 Mdot
.66354 .46508 Mdot
.61859 .5919 Mdot
.29965 .58977 Mdot
.73604 .43937 Mdot
.30944 .59615 Mdot
.54695 .30481 Mdot
.4193 .67832 Mdot
.33659 .42468 Mdot
.3467 .3058 Mdot
.31289 .50214 Mdot
.42196 .6797 Mdot
.74262 .44524 Mdot
.62926 .49685 Mdot
.21405 .62752 Mdot
.62056 .7136 Mdot
.64057 .4963 Mdot
.59188 .61835 Mdot
.40005 .37797 Mdot
.29402 .54962 Mdot
.63408 .50665 Mdot
.45977 .71135 Mdot
.6037 .62177 Mdot
.47587 .28176 Mdot
.46367 .35641 Mdot
.59315 .6556 Mdot
.61531 .50268 Mdot
.54366 .32946 Mdot
.54948 .31173 Mdot
.62071 .62346 Mdot
.45635 .66979 Mdot
.46005 .72227 Mdot
.72838 .44618 Mdot
.31766 .5764 Mdot
.3108 .57115 Mdot
.43609 .68492 Mdot
.48645 .65201 Mdot
.44485 .35896 Mdot
.45284 .35833 Mdot
.54165 .29401 Mdot
.47985 .39531 Mdot
.62829 .71836 Mdot
.63874 .49663 Mdot
.311 .56272 Mdot
.3633 .30774 Mdot
.36615 .32207 Mdot
.4876 .37162 Mdot
.63631 .34838 Mdot
.60061 .68048 Mdot
.33673 .30197 Mdot
.73087 .40898 Mdot
.3084 .37408 Mdot
.4381 .37755 Mdot
.71276 .40676 Mdot
.32322 .56712 Mdot
.47159 .76089 Mdot
.44233 .7056 Mdot
.61943 .61678 Mdot
.61766 .61681 Mdot
.76072 .6368 Mdot
.27594 .54976 Mdot
.64011 .49736 Mdot
.58241 .68377 Mdot
.60121 .50675 Mdot
.75003 .4119 Mdot
.56136 .42053 Mdot
.62899 .71699 Mdot
.61815 .59202 Mdot
.44459 .74734 Mdot
.41594 .36924 Mdot
.44777 .38298 Mdot
.36443 .68381 Mdot
.46658 .38229 Mdot
.71312 .43246 Mdot
.4236 .71483 Mdot
.30817 .54231 Mdot
.75838 .41758 Mdot
.42025 .69096 Mdot
.31331 .57203 Mdot
.34193 .3149 Mdot
.44151 .39859 Mdot
.30475 .52004 Mdot
.33577 .54197 Mdot
.44152 .35966 Mdot
.75758 .70525 Mdot
.30344 .56256 Mdot
.31042 .51767 Mdot
.30604 .37121 Mdot
.62896 .62017 Mdot
.68306 .47628 Mdot
.43647 .66461 Mdot
.47408 .36702 Mdot
.58904 .6473 Mdot
.74132 .41474 Mdot
.31165 .55203 Mdot
.47686 .38861 Mdot
.45115 .35413 Mdot
.73808 .43398 Mdot
.73073 .4071 Mdot
.72605 .44193 Mdot
.46824 .70301 Mdot
.34365 .30794 Mdot
.32306 .52288 Mdot
.42867 .6926 Mdot
.70742 .44907 Mdot
.74612 .40425 Mdot
.75748 .3907 Mdot
.44298 .36042 Mdot
.72989 .40674 Mdot
.2723 .33549 Mdot
.51038 .25425 Mdot
.60105 .50973 Mdot
.6321 .58158 Mdot
.63766 .63727 Mdot
.62521 .46168 Mdot
.46193 .69763 Mdot
.33724 .31879 Mdot
.74155 .44244 Mdot
.61273 .49792 Mdot
.4569 .35684 Mdot
.42804 .37633 Mdot
.73486 .43397 Mdot
.64118 .3547 Mdot
.30013 .5664 Mdot
.21942 .59731 Mdot
.73787 .43664 Mdot
.62754 .63247 Mdot
.61228 .69213 Mdot
.6105 .65088 Mdot
.49221 .37889 Mdot
.45292 .40397 Mdot
.55449 .37272 Mdot
.35771 .46158 Mdot
.43118 .71857 Mdot
.32859 .56152 Mdot
.30339 .37063 Mdot
.30738 .52428 Mdot
.58186 .6612 Mdot
.722 .44123 Mdot
.28585 .57085 Mdot
.4655 .71308 Mdot
.45853 .72244 Mdot
.63546 .63858 Mdot
.61749 .65402 Mdot
.60213 .65185 Mdot
.27457 .55167 Mdot
.33104 .54235 Mdot
.49272 .39755 Mdot
.285 .54342 Mdot
.66608 .72203 Mdot
.66794 .73183 Mdot
.63699 .64807 Mdot
.45004 .68965 Mdot
.31951 .54608 Mdot
.43519 .36839 Mdot
.46412 .2888 Mdot
.61509 .69325 Mdot
.71883 .45237 Mdot
.274 .29902 Mdot
.6902 .21527 Mdot
.3599 .33009 Mdot
.44563 .71743 Mdot
.61231 .5166 Mdot
.47312 .3621 Mdot
.62304 .65943 Mdot
.58905 .52058 Mdot
.64981 .49644 Mdot
.5305 .36794 Mdot
.38737 .33014 Mdot
.44289 .71346 Mdot
.54932 .30306 Mdot
.61352 .49316 Mdot
.35284 .2908 Mdot
.42265 .70961 Mdot
.63213 .67418 Mdot
.60279 .58663 Mdot
.36769 .49757 Mdot
.57463 .4156 Mdot
.62805 .52274 Mdot
.42899 .35478 Mdot
.60349 .6345 Mdot
.75763 .42146 Mdot
.6028 .63946 Mdot
.33485 .56552 Mdot
.63132 .62415 Mdot
.4399 .37291 Mdot
.32426 .52601 Mdot
.45716 .72446 Mdot
.56473 .35155 Mdot
.78363 .4121 Mdot
.63337 .65891 Mdot
.65949 .48895 Mdot
.35703 .32582 Mdot
.34876 .28294 Mdot
.65315 .46839 Mdot
.44729 .38119 Mdot
.4469 .68231 Mdot
.32122 .51711 Mdot
.43284 .69349 Mdot
.68363 .48235 Mdot
.22148 .55333 Mdot
.44278 .70695 Mdot
.4628 .40435 Mdot
.75736 .42676 Mdot
.6387 .35291 Mdot
.44387 .37267 Mdot
.46235 .70483 Mdot
.52708 .37457 Mdot
.29066 .57937 Mdot
.52129 .26103 Mdot
.51633 .2867 Mdot
.4415 .68131 Mdot
.63218 .47396 Mdot
.54791 .32656 Mdot
.68455 .47858 Mdot
.44197 .7238 Mdot
.5116 .24935 Mdot
.63989 .48928 Mdot
.72938 .42642 Mdot
.75871 .40509 Mdot
.72563 .43358 Mdot
.45502 .36305 Mdot
.33378 .33919 Mdot
.7023 .44387 Mdot
.43692 .64946 Mdot
.70962 .42943 Mdot
.64046 .46122 Mdot
.3696 .73232 Mdot
.73919 .40567 Mdot
.45876 .38104 Mdot
.33807 .32211 Mdot
.33775 .31869 Mdot
.62273 .67525 Mdot
.21676 .63908 Mdot
.68326 .73803 Mdot
.48802 .35199 Mdot
.2939 .36116 Mdot
.27831 .54246 Mdot
.66039 .49081 Mdot
.51457 .28601 Mdot
.3325 .30062 Mdot
.31323 .52504 Mdot
.54418 .3028 Mdot
.36903 .52637 Mdot
.60637 .50703 Mdot
.45176 .36286 Mdot
.28331 .5707 Mdot
.31074 .49919 Mdot
.63227 .33613 Mdot
.36461 .48533 Mdot
.31901 .55853 Mdot
.43926 .72597 Mdot
.46064 .6964 Mdot
.44541 .68164 Mdot
.61893 .6498 Mdot
.30767 .54834 Mdot
.49233 .33945 Mdot
.62208 .65565 Mdot
.50752 .36775 Mdot
.43909 .68209 Mdot
.51155 .28062 Mdot
.30651 .54566 Mdot
.44863 .37473 Mdot
.42265 .40567 Mdot
.59991 .6101 Mdot
.7372 .43434 Mdot
.2855 .3476 Mdot
.60779 .59273 Mdot
.46612 .67328 Mdot
.33459 .56795 Mdot
.6464 .46355 Mdot
.34552 .28878 Mdot
.48569 .38784 Mdot
.5134 .35791 Mdot
.3475 .28869 Mdot
.4142 .4179 Mdot
.64982 .48347 Mdot
.62003 .64623 Mdot
.62376 .61115 Mdot
.43077 .37141 Mdot
.30616 .55358 Mdot
.69482 .43495 Mdot
.68257 .45215 Mdot
.75596 .44118 Mdot
.54801 .31996 Mdot
.49852 .27874 Mdot
.44908 .39397 Mdot
.50618 .44323 Mdot
.61686 .68273 Mdot
.59987 .492 Mdot
.54269 .31805 Mdot
.72327 .4265 Mdot
.50837 .37892 Mdot
.3054 .59351 Mdot
.3121 .54743 Mdot
.59547 .66384 Mdot
.43702 .73387 Mdot
.63332 .52572 Mdot
.63789 .65262 Mdot
.43129 .37228 Mdot
.36631 .31647 Mdot
.43205 .72626 Mdot
.33887 .53819 Mdot
.7332 .42725 Mdot
.62134 .66461 Mdot
.725 .4185 Mdot
.28898 .53889 Mdot
.312 .55333 Mdot
.49946 .38812 Mdot
.77251 .42879 Mdot
.63433 .66608 Mdot
.49012 .37826 Mdot
.59468 .65063 Mdot
.63669 .7193 Mdot
.43914 .7418 Mdot
.49555 .38654 Mdot
.25095 .52247 Mdot
.44615 .67816 Mdot
.49611 .35667 Mdot
.34086 .31928 Mdot
.35985 .30424 Mdot
.62349 .62738 Mdot
.72122 .45453 Mdot
.72782 .42255 Mdot
.24291 .51945 Mdot
.32902 .42334 Mdot
.42633 .38567 Mdot
.63189 .6323 Mdot
.33255 .32929 Mdot
.44885 .70957 Mdot
.32519 .55839 Mdot
.44886 .8091 Mdot
.44998 .69635 Mdot
.43703 .36449 Mdot
.71724 .43084 Mdot
.33562 .55116 Mdot
.60131 .51364 Mdot
.58414 .31874 Mdot
.64609 .47114 Mdot
.76801 .43202 Mdot
.63094 .4809 Mdot
.38351 .75702 Mdot
.60123 .6485 Mdot
.32708 .52491 Mdot
.44657 .71876 Mdot
.4508 .71043 Mdot
.5861 .63073 Mdot
.32939 .4083 Mdot
.21755 .60295 Mdot
.2638 .31361 Mdot
.61521 .71091 Mdot
.7182 .43903 Mdot
.51848 .26095 Mdot
.61088 .65295 Mdot
.6019 .60147 Mdot
.39611 .64965 Mdot
.36419 .67957 Mdot
.32116 .54118 Mdot
.45566 .35215 Mdot
.31371 .38321 Mdot
.50648 .35585 Mdot
.57344 .41634 Mdot
.43627 .68886 Mdot
.32491 .5591 Mdot
.37008 .66659 Mdot
.44661 .38793 Mdot
.48637 .36022 Mdot
.66865 .72471 Mdot
.63187 .50122 Mdot
.71122 .71793 Mdot
.51362 .37507 Mdot
.61287 .63991 Mdot
.27004 .50063 Mdot
.60889 .50686 Mdot
.41447 .40265 Mdot
.43901 .72862 Mdot
.63451 .51646 Mdot
.60794 .50385 Mdot
.50873 .4412 Mdot
.3627 .57209 Mdot
.29817 .57716 Mdot
.71546 .41375 Mdot
.3609 .68601 Mdot
.4224 .71892 Mdot
.39619 .77489 Mdot
.43397 .36811 Mdot
.46379 .72111 Mdot
.67278 .4557 Mdot
.49559 .35495 Mdot
.35811 .31889 Mdot
.33618 .42227 Mdot
.42 .36169 Mdot
.3337 .32113 Mdot
.4464 .69476 Mdot
.66598 .43545 Mdot
.41771 .38093 Mdot
.59405 .65883 Mdot
.32351 .54407 Mdot
.35523 .58632 Mdot
.75098 .43021 Mdot
.37415 .66546 Mdot
.67826 .19811 Mdot
.32507 .55755 Mdot
.46079 .35787 Mdot
.44944 .70686 Mdot
.61657 .52154 Mdot
.61751 .51181 Mdot
.65593 .47654 Mdot
.31372 .54442 Mdot
.60994 .50636 Mdot
.24769 .51908 Mdot
.54541 .30313 Mdot
.46653 .4509 Mdot
.45667 .67999 Mdot
.71788 .437 Mdot
.69083 .46213 Mdot
.63816 .71902 Mdot
.44511 .3976 Mdot
.57376 .41644 Mdot
.31557 .49457 Mdot
.71502 .43502 Mdot
.48 .36621 Mdot
.64955 .48136 Mdot
.49338 .23562 Mdot
.69019 .43993 Mdot
.63522 .48043 Mdot
.36968 .31263 Mdot
.31169 .57562 Mdot
.63952 .50297 Mdot
.30855 .53904 Mdot
.48327 .36808 Mdot
.53905 .34748 Mdot
.30821 .58011 Mdot
.22756 .65017 Mdot
.64393 .51847 Mdot
.41878 .69276 Mdot
.53409 .36466 Mdot
.47764 .38616 Mdot
.43783 .40269 Mdot
.62061 .52069 Mdot
.26585 .67449 Mdot
.59255 .64488 Mdot
.7048 .73564 Mdot
.62453 .71693 Mdot
.39421 .65225 Mdot
.40375 .78576 Mdot
.44637 .38986 Mdot
.32958 .40702 Mdot
.4436 .40307 Mdot
.43887 .67 Mdot
.41261 .39386 Mdot
.47862 .37268 Mdot
.49852 .37756 Mdot
.59423 .65158 Mdot
.42689 .73332 Mdot
.37059 .30385 Mdot
.54336 .31866 Mdot
.73323 .45259 Mdot
.29484 .5338 Mdot
.46794 .36784 Mdot
.32909 .5047 Mdot
.62471 .62613 Mdot
.21208 .58822 Mdot
.45796 .37974 Mdot
.63201 .50069 Mdot
.46638 .71499 Mdot
.45283 .72745 Mdot
.62682 .63775 Mdot
.62893 .64335 Mdot
.47782 .3859 Mdot
.43246 .68351 Mdot
.42838 .39289 Mdot
.54734 .32738 Mdot
.61538 .50044 Mdot
.74719 .41631 Mdot
.50074 .34821 Mdot
.21813 .60074 Mdot
.78857 .3879 Mdot
.49266 .37773 Mdot
.28903 .56768 Mdot
.60139 .65667 Mdot
.57984 .65916 Mdot
.31256 .56914 Mdot
.57943 .65567 Mdot
.21159 .59271 Mdot
.33715 .34083 Mdot
.74568 .41001 Mdot
.31639 .28032 Mdot
.70573 .43285 Mdot
.63141 .51813 Mdot
.44243 .36107 Mdot
.51288 .71713 Mdot
.615 .71219 Mdot
.42965 .24257 Mdot
.43771 .69749 Mdot
.60389 .48944 Mdot
.35053 .30822 Mdot
.75704 .43218 Mdot
.6123 .67045 Mdot
.61482 .5288 Mdot
.51069 .37731 Mdot
.28257 .57087 Mdot
.3704 .32533 Mdot
.60713 .49223 Mdot
.62835 .51769 Mdot
.61617 .52784 Mdot
.42029 .69056 Mdot
.30387 .51343 Mdot
.38198 .65707 Mdot
.60311 .60995 Mdot
.50327 .3937 Mdot
.46416 .35869 Mdot
.32774 .56162 Mdot
.48986 .34719 Mdot
.44069 .67455 Mdot
.25591 .3186 Mdot
.72121 .44346 Mdot
.60841 .51833 Mdot
.30262 .64891 Mdot
.60569 .52342 Mdot
.36308 .30118 Mdot
.35426 .28818 Mdot
.30156 .59093 Mdot
.4263 .67308 Mdot
.40336 .3768 Mdot
.6195 .60006 Mdot
.73233 .42538 Mdot
.45937 .72541 Mdot
.36355 .31536 Mdot
.44839 .37816 Mdot
.71712 .43519 Mdot
.36939 .66944 Mdot
.70536 .46 Mdot
.4427 .72107 Mdot
.61409 .47678 Mdot
.45432 .2845 Mdot
.45373 .37229 Mdot
.63618 .49571 Mdot
.29482 .52191 Mdot
.4296 .71503 Mdot
.34116 .4307 Mdot
.60663 .50461 Mdot
.64911 .72425 Mdot
.44803 .72995 Mdot
.48601 .38831 Mdot
.29093 .50171 Mdot
.33693 .59384 Mdot
.31185 .51502 Mdot
.79904 .61825 Mdot
.65704 .73001 Mdot
.59953 .6527 Mdot
.45098 .69095 Mdot
.58719 .65068 Mdot
.75809 .42553 Mdot
.52611 .27097 Mdot
.63175 .65064 Mdot
.29435 .51305 Mdot
.59254 .63352 Mdot
.42811 .39367 Mdot
.41885 .68709 Mdot
.63504 .67608 Mdot
.45871 .34503 Mdot
.33927 .31303 Mdot
.63092 .51451 Mdot
.6967 .44298 Mdot
.54607 .311 Mdot
.4423 .35325 Mdot
.63278 .49298 Mdot
.45098 .37479 Mdot
.43958 .67524 Mdot
.56238 .3583 Mdot
.46585 .40183 Mdot
.61646 .71006 Mdot
.21321 .61869 Mdot
.62284 .61277 Mdot
.7451 .46066 Mdot
.50201 .35894 Mdot
.44915 .37016 Mdot
.35812 .30971 Mdot
.27974 .29282 Mdot
.46803 .68022 Mdot
.52181 .38316 Mdot
.57845 .66217 Mdot
.31314 .52949 Mdot
.28066 .56023 Mdot
.55661 .42171 Mdot
.63835 .49365 Mdot
.46372 .68071 Mdot
.44557 .36582 Mdot
.6025 .49807 Mdot
.52795 .29987 Mdot
.36373 .69908 Mdot
.66476 .73323 Mdot
.60302 .60331 Mdot
.295 .58497 Mdot
.5978 .68085 Mdot
.35789 .30752 Mdot
.61041 .50987 Mdot
.65649 .73188 Mdot
.42666 .64555 Mdot
.7325 .4238 Mdot
.50264 .37333 Mdot
.63646 .34396 Mdot
.60017 .68376 Mdot
.6239 .64744 Mdot
.42665 .39272 Mdot
.29066 .49083 Mdot
.77758 .38835 Mdot
.42567 .69954 Mdot
.31785 .59719 Mdot
.36548 .39029 Mdot
.71081 .30647 Mdot
.4577 .69835 Mdot
.35875 .3212 Mdot
.60829 .68944 Mdot
.72119 .66334 Mdot
.31111 .5255 Mdot
.73347 .42488 Mdot
.47274 .34454 Mdot
.28188 .53401 Mdot
.61384 .71085 Mdot
.31472 .51198 Mdot
.62969 .50661 Mdot
.41985 .68363 Mdot
.61193 .67611 Mdot
.42304 .72702 Mdot
.25176 .52216 Mdot
.71835 .44135 Mdot
.6175 .39395 Mdot
.34325 .32776 Mdot
.33503 .42138 Mdot
.34476 .31042 Mdot
.6696 .46626 Mdot
.34143 .31198 Mdot
.34963 .58907 Mdot
.44503 .37386 Mdot
.41226 .37795 Mdot
.58138 .67388 Mdot
.49302 .38127 Mdot
.43281 .36072 Mdot
.42361 .40534 Mdot
.50383 .36845 Mdot
.48755 .37677 Mdot
.47687 .39146 Mdot
.29601 .56954 Mdot
.49994 .39018 Mdot
.33463 .53908 Mdot
.32736 .50736 Mdot
.60231 .60986 Mdot
.76032 .4067 Mdot
.73391 .40699 Mdot
.53519 .34418 Mdot
.63617 .34523 Mdot
.31128 .37988 Mdot
.3098 .53139 Mdot
.45152 .72702 Mdot
.4627 .40075 Mdot
.77901 .39231 Mdot
.53538 .34521 Mdot
.62392 .6747 Mdot
.62823 .6305 Mdot
.45702 .34453 Mdot
.69333 .21954 Mdot
.51398 .37638 Mdot
.53737 .28905 Mdot
.45607 .36407 Mdot
.49267 .38861 Mdot
.62542 .6092 Mdot
.63504 .37568 Mdot
.33719 .29859 Mdot
.36587 .55516 Mdot
.735 .42087 Mdot
.63819 .50262 Mdot
.5392 .34696 Mdot
.36571 .37453 Mdot
.36815 .50356 Mdot
.35908 .31059 Mdot
.62037 .67192 Mdot
.31249 .5587 Mdot
.54019 .29568 Mdot
.42818 .69473 Mdot
.58763 .32224 Mdot
.21785 .56454 Mdot
.42505 .69317 Mdot
.73015 .42669 Mdot
.62306 .68611 Mdot
.48674 .36492 Mdot
.6082 .6302 Mdot
.4507 .38901 Mdot
.53782 .28021 Mdot
.74758 .41246 Mdot
.28932 .51542 Mdot
.43452 .72584 Mdot
.29468 .56453 Mdot
.21727 .59024 Mdot
.56198 .388 Mdot
.69082 .73179 Mdot
.63387 .6354 Mdot
.73114 .46344 Mdot
.3292 .53941 Mdot
.42712 .36567 Mdot
.26972 .33314 Mdot
.2943 .54593 Mdot
.28366 .57349 Mdot
.58354 .32766 Mdot
.64818 .36017 Mdot
.47328 .39128 Mdot
.28321 .53046 Mdot
.62332 .68715 Mdot
.74438 .40831 Mdot
.43156 .36427 Mdot
.61106 .51335 Mdot
.2832 .56686 Mdot
.59714 .67697 Mdot
.62949 .3825 Mdot
.61609 .64634 Mdot
.31944 .53258 Mdot
.62275 .61841 Mdot
.44876 .74642 Mdot
.63229 .6521 Mdot
.50534 .35044 Mdot
.44698 .36758 Mdot
.32934 .59658 Mdot
.31188 .5534 Mdot
.36278 .30088 Mdot
.49804 .35021 Mdot
.32813 .52928 Mdot
.60045 .69717 Mdot
.36453 .50156 Mdot
.36086 .30344 Mdot
.44807 .35539 Mdot
.70352 .4369 Mdot
.54704 .3358 Mdot
.57582 .33001 Mdot
.48013 .40033 Mdot
.72107 .43904 Mdot
.28259 .57384 Mdot
.44156 .36533 Mdot
.64231 .36859 Mdot
.57927 .67322 Mdot
.41187 .36305 Mdot
.61348 .52157 Mdot
.34319 .29427 Mdot
.61109 .31031 Mdot
.36252 .31567 Mdot
.31426 .5212 Mdot
.32268 .53158 Mdot
.5879 .68434 Mdot
.30058 .52206 Mdot
.61321 .51982 Mdot
.46441 .68619 Mdot
.2198 .57324 Mdot
.60167 .48916 Mdot
.65038 .50096 Mdot
.64928 .51053 Mdot
.62322 .48107 Mdot
.77973 .39672 Mdot
.66098 .72779 Mdot
.64456 .50685 Mdot
.33187 .53083 Mdot
.56478 .57409 Mdot
.64297 .46574 Mdot
.46363 .67989 Mdot
.60843 .5039 Mdot
.41198 .36325 Mdot
.35957 .31388 Mdot
.32515 .57571 Mdot
.42846 .6899 Mdot
.66995 .47296 Mdot
.43138 .36222 Mdot
.30437 .59176 Mdot
.47124 .36897 Mdot
.71785 .45389 Mdot
.30582 .54353 Mdot
.62021 .66205 Mdot
.74929 .41611 Mdot
.61859 .48765 Mdot
.73446 .43932 Mdot
.59962 .63784 Mdot
.46289 .70961 Mdot
.46146 .34556 Mdot
.69418 .45606 Mdot
.75996 .40703 Mdot
.42355 .35538 Mdot
.32472 .53862 Mdot
.66334 .49274 Mdot
.44476 .35433 Mdot
.35319 .31068 Mdot
.30955 .57228 Mdot
.26093 .67987 Mdot
.49057 .36544 Mdot
.35977 .29244 Mdot
.35902 .57495 Mdot
.60481 .49273 Mdot
.62076 .65491 Mdot
.47611 .38852 Mdot
.43578 .70171 Mdot
.43642 .68375 Mdot
.61736 .71254 Mdot
.2919 .57646 Mdot
.59194 .67613 Mdot
.42879 .35133 Mdot
.60914 .49816 Mdot
.45562 .38466 Mdot
.67166 .72346 Mdot
.23551 .66429 Mdot
.33661 .54329 Mdot
.60681 .60629 Mdot
.52425 .29934 Mdot
.44189 .66373 Mdot
.59869 .69957 Mdot
.36278 .56876 Mdot
.28463 .54756 Mdot
.3141 .56832 Mdot
.72875 .40959 Mdot
.61685 .65677 Mdot
.31923 .5776 Mdot
.32322 .57304 Mdot
.36083 .30704 Mdot
.4462 .34666 Mdot
.29084 .58198 Mdot
.63734 .72156 Mdot
.72944 .4214 Mdot
.5814 .63669 Mdot
.7885 .3909 Mdot
.42633 .70904 Mdot
.41197 .40127 Mdot
.4389 .39687 Mdot
.66689 .18663 Mdot
.5142 .3727 Mdot
.45947 .3621 Mdot
.3087 .59661 Mdot
.72605 .45668 Mdot
.72453 .41483 Mdot
.32853 .53829 Mdot
.33752 .54106 Mdot
.74479 .43239 Mdot
.45005 .30748 Mdot
.62207 .32571 Mdot
.53024 .31093 Mdot
.30282 .51241 Mdot
.2226 .56892 Mdot
.44119 .68825 Mdot
.27897 .54786 Mdot
.43917 .7555 Mdot
.63731 .66331 Mdot
.63376 .65776 Mdot
.44262 .72722 Mdot
.48558 .36328 Mdot
.62844 .61467 Mdot
.33849 .30183 Mdot
.44154 .75904 Mdot
.35215 .32554 Mdot
.76717 .69903 Mdot
.49156 .34699 Mdot
.51697 .63705 Mdot
.37681 .74491 Mdot
.35925 .29708 Mdot
.33313 .34157 Mdot
.73389 .43119 Mdot
.35411 .58849 Mdot
.44404 .67227 Mdot
.31482 .38505 Mdot
.45179 .3716 Mdot
.28726 .52204 Mdot
.42868 .7206 Mdot
.25217 .67189 Mdot
.33477 .29909 Mdot
.34983 .29988 Mdot
.26916 .33567 Mdot
.32065 .50797 Mdot
.61995 .65254 Mdot
.31877 .59851 Mdot
.33163 .56865 Mdot
.34169 .31845 Mdot
.6203 .69378 Mdot
.48675 .23777 Mdot
.29584 .51436 Mdot
.68577 .45905 Mdot
.29794 .53572 Mdot
.74543 .42839 Mdot
.31641 .58004 Mdot
.59761 .61568 Mdot
.49763 .36785 Mdot
.59948 .61194 Mdot
.71246 .45153 Mdot
.61831 .61084 Mdot
.43705 .67442 Mdot
.62635 .49025 Mdot
.44557 .67856 Mdot
.52396 .26629 Mdot
.34459 .43651 Mdot
.46291 .6936 Mdot
.54974 .4032 Mdot
.44564 .37726 Mdot
.31557 .58035 Mdot
.61804 .67218 Mdot
.58411 .62427 Mdot
.5472 .31353 Mdot
.3216 .55433 Mdot
.58302 .6628 Mdot
.32512 .30521 Mdot
.47905 .75797 Mdot
.34851 .29077 Mdot
.45646 .81492 Mdot
.32141 .52097 Mdot
.57979 .63645 Mdot
.53822 .29236 Mdot
.34014 .53859 Mdot
.63477 .67019 Mdot
.44963 .72232 Mdot
.43614 .70196 Mdot
.51469 .35721 Mdot
.4201 .7209 Mdot
.62342 .67359 Mdot
.22304 .54864 Mdot
.31243 .57938 Mdot
.22929 .6589 Mdot
.72427 .44079 Mdot
.60316 .68172 Mdot
.61338 .50245 Mdot
.25051 .52599 Mdot
.58779 .64503 Mdot
.68084 .20087 Mdot
.8551 .558 Mdot
.58683 .66969 Mdot
.3061 .54171 Mdot
.31557 .54787 Mdot
.36488 .32823 Mdot
.5462 .31837 Mdot
.61107 .67144 Mdot
.50638 .72592 Mdot
.49228 .2781 Mdot
.62976 .48882 Mdot
.68365 .73881 Mdot
.50048 .34187 Mdot
.34779 .30982 Mdot
.43177 .71546 Mdot
.48748 .35994 Mdot
.33372 .52618 Mdot
.51396 .3753 Mdot
.44515 .67529 Mdot
.6223 .71054 Mdot
.45066 .37272 Mdot
.73148 .4266 Mdot
.43733 .71347 Mdot
.43321 .70356 Mdot
.61297 .61421 Mdot
.29231 .57707 Mdot
.31831 .39185 Mdot
.61787 .65395 Mdot
.34159 .30611 Mdot
.62886 .49507 Mdot
.48097 .38991 Mdot
.28041 .52394 Mdot
.37 .53434 Mdot
.60446 .68318 Mdot
.4244 .35713 Mdot
.4549 .69581 Mdot
.5878 .6805 Mdot
.3617 .32278 Mdot
.63193 .66795 Mdot
.59842 .53442 Mdot
.62877 .61124 Mdot
.25597 .51148 Mdot
.65986 .49338 Mdot
.28846 .51922 Mdot
.64803 .49552 Mdot
.76246 .63647 Mdot
.72934 .42529 Mdot
.62631 .61358 Mdot
.2322 .65451 Mdot
.60372 .60642 Mdot
.50352 .36591 Mdot
.43671 .36697 Mdot
.595 .64092 Mdot
.71638 .44088 Mdot
.62973 .4603 Mdot
.71097 .45668 Mdot
.3094 .54551 Mdot
.33097 .30228 Mdot
.84203 .60045 Mdot
.60348 .59328 Mdot
.42811 .72562 Mdot
.3659 .49734 Mdot
.65213 .49655 Mdot
.43213 .6791 Mdot
.43372 .70803 Mdot
.72365 .4479 Mdot
.60313 .60091 Mdot
.27517 .54379 Mdot
.41579 .70249 Mdot
.33915 .53501 Mdot
.64152 .37357 Mdot
.61288 .48733 Mdot
.7029 .47123 Mdot
.64872 .4808 Mdot
.54418 .30587 Mdot
.42479 .6684 Mdot
.471 .37566 Mdot
.75224 .44098 Mdot
.43838 .72387 Mdot
.70134 .44416 Mdot
.36017 .3222 Mdot
.58182 .65715 Mdot
.29297 .37254 Mdot
.51294 .35417 Mdot
.49013 .35059 Mdot
.42872 .71638 Mdot
.34399 .35144 Mdot
.36484 .5653 Mdot
.30889 .57775 Mdot
.60159 .64899 Mdot
.58045 .32492 Mdot
.50968 .38179 Mdot
.43433 .36161 Mdot
.59863 .63179 Mdot
.6406 .49148 Mdot
.68713 .73704 Mdot
.44902 .35633 Mdot
.44584 .69108 Mdot
.35984 .31937 Mdot
.45103 .66896 Mdot
.40007 .37346 Mdot
.49994 .36247 Mdot
.34308 .30032 Mdot
.34542 .31579 Mdot
.44597 .67901 Mdot
.63278 .48018 Mdot
.61258 .52486 Mdot
.30527 .51435 Mdot
.47638 .34357 Mdot
.49059 .27919 Mdot
.44751 .36478 Mdot
.73302 .43157 Mdot
.57513 .32566 Mdot
.42017 .39382 Mdot
.53197 .37013 Mdot
.49316 .27605 Mdot
.48177 .36978 Mdot
.42629 .71412 Mdot
.31753 .54772 Mdot
.45449 .69984 Mdot
.41642 .69938 Mdot
.59345 .63009 Mdot
.70085 .4409 Mdot
.48226 .38514 Mdot
.74945 .43642 Mdot
.51816 .3504 Mdot
.68169 .48737 Mdot
.54194 .32933 Mdot
.53611 .2899 Mdot
.69205 .44075 Mdot
.44042 .37411 Mdot
.59895 .64405 Mdot
.61362 .58965 Mdot
.33761 .31922 Mdot
.48407 .34255 Mdot
.43264 .73476 Mdot
.46213 .70466 Mdot
.66801 .73356 Mdot
.60183 .58155 Mdot
.71934 .45394 Mdot
.61067 .45776 Mdot
.34157 .3145 Mdot
.50579 .37611 Mdot
.63268 .48228 Mdot
.59025 .65989 Mdot
.64735 .50075 Mdot
.663 .7302 Mdot
.44431 .67056 Mdot
.45024 .71387 Mdot
.49607 .34769 Mdot
.74283 .26204 Mdot
.29131 .54764 Mdot
.31597 .54946 Mdot
.4654 .6858 Mdot
.62297 .61266 Mdot
.62757 .50992 Mdot
.27993 .34061 Mdot
.36768 .51411 Mdot
.76072 .42121 Mdot
.46389 .38713 Mdot
.6367 .65309 Mdot
.32615 .5189 Mdot
.72322 .45293 Mdot
.46782 .40235 Mdot
.61656 .6965 Mdot
.46378 .37157 Mdot
.3343 .28397 Mdot
.32901 .54973 Mdot
.5435 .33249 Mdot
.29214 .5144 Mdot
.43693 .68743 Mdot
.42136 .67296 Mdot
.49828 .35852 Mdot
.29484 .3693 Mdot
.27647 .49803 Mdot
.41661 .68117 Mdot
.71301 .41603 Mdot
.62038 .4955 Mdot
.70151 .44282 Mdot
.59548 .65569 Mdot
.73023 .42547 Mdot
.58853 .64138 Mdot
.58706 .68754 Mdot
.2768 .55025 Mdot
.71692 .43485 Mdot
.41718 .40966 Mdot
.61133 .51099 Mdot
.73864 .40419 Mdot
.5179 .38275 Mdot
.36617 .30957 Mdot
.60557 .67383 Mdot
.74967 .43713 Mdot
.47569 .38943 Mdot
.29941 .65058 Mdot
.41786 .6894 Mdot
.43931 .67315 Mdot
.62997 .50736 Mdot
.61249 .68668 Mdot
.27422 .54155 Mdot
.52424 .2944 Mdot
.24935 .51897 Mdot
.43457 .35786 Mdot
.48684 .38209 Mdot
.25223 .514 Mdot
.27412 .54212 Mdot
.4963 .35902 Mdot
.44589 .45047 Mdot
.61316 .49885 Mdot
.434 .69286 Mdot
.30812 .54752 Mdot
.30784 .5568 Mdot
.62619 .65653 Mdot
.28569 .57281 Mdot
.76268 .44003 Mdot
.44013 .67145 Mdot
.60262 .5191 Mdot
.45252 .69339 Mdot
.60799 .55499 Mdot
.58602 .66422 Mdot
.24783 .66414 Mdot
.30027 .58066 Mdot
.35766 .30174 Mdot
.28683 .5767 Mdot
.72566 .44264 Mdot
.28395 .53185 Mdot
.27808 .54022 Mdot
.44831 .34668 Mdot
.62876 .48176 Mdot
.63554 .51413 Mdot
.54342 .31205 Mdot
.29211 .54593 Mdot
.49038 .37169 Mdot
.48336 .39824 Mdot
.49042 .34802 Mdot
.54413 .327 Mdot
.2961 .57269 Mdot
.36535 .37311 Mdot
.29886 .58912 Mdot
.33059 .54353 Mdot
.78916 .38464 Mdot
.61586 .51903 Mdot
.65055 .4914 Mdot
.49289 .7297 Mdot
.45338 .3527 Mdot
.57971 .65188 Mdot
.34352 .30641 Mdot
.61973 .48955 Mdot
.48139 .4018 Mdot
.75788 .41113 Mdot
.44527 .38659 Mdot
.63622 .48719 Mdot
.61805 .66867 Mdot
.35743 .30259 Mdot
.44365 .36055 Mdot
.64122 .49775 Mdot
.27863 .56021 Mdot
.30273 .56644 Mdot
.35989 .47116 Mdot
.73674 .4409 Mdot
.45416 .68331 Mdot
.34592 .30718 Mdot
.60017 .64773 Mdot
.58304 .63746 Mdot
.28735 .51945 Mdot
.62132 .62831 Mdot
.44749 .71586 Mdot
.45986 .35667 Mdot
.43949 .68249 Mdot
.75578 .41888 Mdot
.30542 .54469 Mdot
.35451 .30701 Mdot
.3678 .33191 Mdot
.32277 .53162 Mdot
.61201 .49799 Mdot
.70212 .4365 Mdot
.61102 .62118 Mdot
.33445 .54949 Mdot
.45116 .67709 Mdot
.62704 .64808 Mdot
.35269 .29931 Mdot
.79438 .35931 Mdot
.48859 .35999 Mdot
.50763 .35808 Mdot
.2565 .52301 Mdot
.40778 .37175 Mdot
.6035 .61002 Mdot
.27275 .53844 Mdot
.36313 .30515 Mdot
.51371 .25496 Mdot
.7181 .40702 Mdot
.63639 .5778 Mdot
.47442 .3665 Mdot
.44159 .40322 Mdot
.43341 .38926 Mdot
.2239 .64562 Mdot
.54487 .32928 Mdot
.65015 .71877 Mdot
.71001 .4686 Mdot
.41848 .71426 Mdot
.63402 .49129 Mdot
.59558 .62431 Mdot
.42162 .44604 Mdot
.48917 .35766 Mdot
.33537 .42998 Mdot
.36395 .31863 Mdot
.4558 .70496 Mdot
.36311 .3601 Mdot
.62133 .67018 Mdot
.70155 .73866 Mdot
.43559 .34888 Mdot
.36842 .54301 Mdot
.49318 .64804 Mdot
.63115 .4841 Mdot
.65089 .48548 Mdot
.72313 .4524 Mdot
.60729 .70299 Mdot
.6493 .47007 Mdot
.45393 .69655 Mdot
.5062 .37939 Mdot
.41701 .39434 Mdot
.27181 .67815 Mdot
.324 .51984 Mdot
.4208 .71389 Mdot
.64059 .59171 Mdot
.47183 .37982 Mdot
.28829 .55512 Mdot
.31058 .52535 Mdot
.7607 .41361 Mdot
.64476 .72138 Mdot
.59827 .7007 Mdot
.70393 .23181 Mdot
.66631 .48286 Mdot
.59023 .65642 Mdot
.65725 .48218 Mdot
.34228 .3042 Mdot
.53895 .3473 Mdot
.41832 .71177 Mdot
.50485 .36332 Mdot
.33286 .42177 Mdot
.31106 .51712 Mdot
.45126 .36526 Mdot
.733 .41779 Mdot
.27287 .29943 Mdot
.33737 .32418 Mdot
.45529 .45018 Mdot
.6232 .68753 Mdot
.4893 .37995 Mdot
.76609 .43581 Mdot
.60223 .49713 Mdot
.40689 .36981 Mdot
.61981 .65583 Mdot
.65926 .4947 Mdot
.72995 .41631 Mdot
.30953 .51306 Mdot
.63336 .49334 Mdot
.3636 .32123 Mdot
.46171 .39031 Mdot
.70893 .41894 Mdot
.34538 .30115 Mdot
.22098 .57956 Mdot
.64248 .47477 Mdot
.63346 .65035 Mdot
.3344 .55581 Mdot
.49219 .37703 Mdot
.62003 .49463 Mdot
.461 .3852 Mdot
.21633 .59962 Mdot
.50725 .36947 Mdot
.28432 .66086 Mdot
.32337 .54593 Mdot
.44368 .70421 Mdot
.35784 .31075 Mdot
.4615 .37269 Mdot
.66019 .48573 Mdot
.62597 .51205 Mdot
.42896 .36431 Mdot
.28919 .51799 Mdot
.29156 .52358 Mdot
.369 .52792 Mdot
.6287 .65713 Mdot
.5315 .31773 Mdot
.44044 .69843 Mdot
.63481 .4819 Mdot
.4158 .70542 Mdot
.43818 .40193 Mdot
.73761 .43821 Mdot
.27396 .67312 Mdot
.46899 .35429 Mdot
.32002 .5581 Mdot
.62298 .32935 Mdot
.28254 .54468 Mdot
.49061 .73145 Mdot
.42285 .71946 Mdot
.2984 .54661 Mdot
.47397 .36467 Mdot
.54371 .30078 Mdot
.41335 .39536 Mdot
.43057 .66625 Mdot
.60763 .52136 Mdot
.64324 .53103 Mdot
.63161 .68119 Mdot
.79371 .38839 Mdot
.45423 .72882 Mdot
.37492 .74344 Mdot
.36083 .30331 Mdot
.31608 .57291 Mdot
.45638 .68027 Mdot
.4314 .6995 Mdot
.61842 .6784 Mdot
.35983 .30567 Mdot
.4586 .37103 Mdot
.61684 .52245 Mdot
.46145 .71599 Mdot
.43019 .37789 Mdot
.3615 .29744 Mdot
.67569 .73473 Mdot
.36337 .5718 Mdot
.25645 .67993 Mdot
.44609 .40231 Mdot
.33362 .41923 Mdot
.52422 .68679 Mdot
.31515 .57951 Mdot
.48781 .37346 Mdot
.61829 .50613 Mdot
.62218 .62553 Mdot
.46904 .35784 Mdot
.60738 .60465 Mdot
.45902 .69324 Mdot
.29334 .65658 Mdot
.42703 .39863 Mdot
.44342 .75918 Mdot
.49638 .36509 Mdot
.35085 .33127 Mdot
.72013 .4258 Mdot
.45135 .67193 Mdot
.36639 .52348 Mdot
.48682 .38629 Mdot
.62266 .64809 Mdot
.63299 .68083 Mdot
.30335 .51732 Mdot
.36309 .48168 Mdot
.24026 .66063 Mdot
.61289 .50566 Mdot
.61668 .6305 Mdot
.61776 .49611 Mdot
.4662 .45022 Mdot
.41567 .7024 Mdot
.72973 .41584 Mdot
.6226 .61947 Mdot
.46815 .70301 Mdot
.36624 .30916 Mdot
.29229 .53396 Mdot
.24774 .53051 Mdot
.33458 .31002 Mdot
.58233 .6614 Mdot
.74355 .42429 Mdot
.53731 .35733 Mdot
.33153 .30661 Mdot
.74607 .41608 Mdot
.62597 .66651 Mdot
.29596 .55713 Mdot
.3166 .52708 Mdot
.31808 .54502 Mdot
.41277 .40196 Mdot
.37026 .531 Mdot
.60216 .40466 Mdot
.41075 .37412 Mdot
.22841 .54008 Mdot
.41683 .37407 Mdot
.44045 .673 Mdot
.32684 .55486 Mdot
.54383 .32973 Mdot
.34018 .29311 Mdot
.39433 .37677 Mdot
.4622 .34741 Mdot
.34728 .31942 Mdot
.4526 .35279 Mdot
.23229 .54036 Mdot
.36505 .56946 Mdot
.53294 .36814 Mdot
.4322 .67218 Mdot
.73409 .43649 Mdot
.33583 .56213 Mdot
.48223 .38245 Mdot
.22445 .55969 Mdot
.51607 .38494 Mdot
.28894 .65664 Mdot
.34846 .32151 Mdot
.63198 .71424 Mdot
.5007 .38374 Mdot
.63708 .64486 Mdot
.36179 .33438 Mdot
.2212 .573 Mdot
.4189 .68866 Mdot
.3395 .32653 Mdot
.64026 .66207 Mdot
.3653 .36199 Mdot
.61614 .50992 Mdot
.72667 .42223 Mdot
.656 .49991 Mdot
.44371 .6771 Mdot
.47906 .35462 Mdot
.45283 .38787 Mdot
.40479 .37434 Mdot
.46999 .45005 Mdot
.61352 .51685 Mdot
.69134 .44079 Mdot
.22066 .56747 Mdot
.43693 .37825 Mdot
.62408 .60305 Mdot
.30534 .57341 Mdot
.38915 .39423 Mdot
.41165 .41309 Mdot
.36792 .30356 Mdot
.29379 .54431 Mdot
.29158 .57639 Mdot
.77845 .39074 Mdot
.72329 .43279 Mdot
.49691 .35306 Mdot
.68772 .45714 Mdot
.34848 .30616 Mdot
.45084 .68641 Mdot
.41308 .38137 Mdot
.58564 .66445 Mdot
.54411 .29383 Mdot
.62743 .6643 Mdot
.48147 .34679 Mdot
.29945 .53486 Mdot
.43144 .66691 Mdot
.58153 .68109 Mdot
.64152 .7245 Mdot
.61055 .40095 Mdot
.59423 .6989 Mdot
.73673 .44397 Mdot
.72524 .44611 Mdot
.44991 .67184 Mdot
.46426 .36231 Mdot
.54659 .32453 Mdot
.31164 .27745 Mdot
.46408 .35139 Mdot
.48301 .36237 Mdot
.44397 .64862 Mdot
.4467 .7288 Mdot
.62451 .61966 Mdot
.49434 .35825 Mdot
.44097 .38525 Mdot
.2999 .54021 Mdot
.72709 .45549 Mdot
.59989 .62485 Mdot
.71911 .45309 Mdot
.60827 .63626 Mdot
.61196 .31061 Mdot
.61111 .49053 Mdot
.73229 .44354 Mdot
.45039 .73138 Mdot
.31753 .56094 Mdot
.61358 .51901 Mdot
.60262 .66281 Mdot
.61938 .63022 Mdot
.51313 .34819 Mdot
.32211 .51667 Mdot
.3085 .57807 Mdot
.7403 .43768 Mdot
.46345 .70054 Mdot
.33768 .30248 Mdot
.64906 .48135 Mdot
.6593 .59319 Mdot
.62251 .63942 Mdot
.21883 .56269 Mdot
.25392 .52351 Mdot
.47076 .3832 Mdot
.30181 .56522 Mdot
.45945 .37713 Mdot
.31178 .59718 Mdot
.33248 .51461 Mdot
.39964 .37389 Mdot
.35723 .46346 Mdot
.5887 .65706 Mdot
.81641 .64013 Mdot
.35428 .29155 Mdot
.46416 .72409 Mdot
.3442 .30535 Mdot
.69176 .73803 Mdot
.62551 .3315 Mdot
.43685 .37579 Mdot
.48539 .38204 Mdot
.74955 .27867 Mdot
.47924 .39499 Mdot
.64723 .49246 Mdot
.61571 .51057 Mdot
.29708 .56239 Mdot
.65378 .50256 Mdot
.54478 .30933 Mdot
.71273 .43688 Mdot
.60108 .65006 Mdot
.64203 .36599 Mdot
.74367 .4295 Mdot
.31525 .52002 Mdot
.33857 .29821 Mdot
.27278 .49654 Mdot
.6211 .59653 Mdot
.63658 .49863 Mdot
.45814 .69734 Mdot
.55069 .31814 Mdot
.62318 .66033 Mdot
.46597 .70709 Mdot
.475 .3981 Mdot
.66386 .72426 Mdot
.43437 .6719 Mdot
.82852 .62139 Mdot
.42826 .70506 Mdot
.46476 .68636 Mdot
.54068 .32016 Mdot
.7123 .43669 Mdot
.6616 .48668 Mdot
.68442 .47972 Mdot
.42152 .68712 Mdot
.72365 .72655 Mdot
.61387 .68501 Mdot
.53622 .27871 Mdot
.35482 .58836 Mdot
.60793 .50627 Mdot
.49244 .36435 Mdot
.4296 .71377 Mdot
.5196 .35254 Mdot
.66033 .4902 Mdot
.44391 .71314 Mdot
.36291 .33405 Mdot
.57717 .32062 Mdot
.61864 .50043 Mdot
.63248 .5173 Mdot
.73562 .44976 Mdot
.62849 .71629 Mdot
.30408 .57838 Mdot
.75767 .4053 Mdot
.5168 .28306 Mdot
.49768 .35076 Mdot
.44695 .67908 Mdot
.63384 .49387 Mdot
.43783 .6989 Mdot
.7194 .42101 Mdot
.7125 .41543 Mdot
.3115 .51445 Mdot
.36887 .53416 Mdot
.60088 .48574 Mdot
.48009 .2786 Mdot
.42119 .38378 Mdot
.3384 .43449 Mdot
.2877 .56663 Mdot
.33443 .34107 Mdot
.70931 .42544 Mdot
.74011 .44785 Mdot
.35433 .33267 Mdot
.49759 .39546 Mdot
.3523 .31928 Mdot
.4455 .40009 Mdot
.70982 .70427 Mdot
.35741 .30803 Mdot
.61193 .62245 Mdot
.44956 .40103 Mdot
.36043 .69635 Mdot
.34266 .32479 Mdot
.47489 .385 Mdot
.61225 .64929 Mdot
.41889 .35866 Mdot
.59715 .67464 Mdot
.49541 .37183 Mdot
.67499 .72391 Mdot
.60048 .64758 Mdot
.5968 .47091 Mdot
.55622 .3854 Mdot
.6456 .49859 Mdot
.72311 .41388 Mdot
.69586 .45568 Mdot
.62824 .38439 Mdot
.29704 .55486 Mdot
.28256 .29186 Mdot
.47506 .38429 Mdot
.6187 .68007 Mdot
.45984 .69613 Mdot
.3716 .32526 Mdot
.50959 .35695 Mdot
.33692 .30906 Mdot
.28965 .53528 Mdot
.61194 .68831 Mdot
.7138 .42696 Mdot
.60971 .5968 Mdot
.67889 .73746 Mdot
.58773 .66514 Mdot
.50463 .44212 Mdot
.36854 .31831 Mdot
.76463 .43741 Mdot
.34951 .44653 Mdot
.6499 .45639 Mdot
.29578 .52313 Mdot
.63186 .49186 Mdot
.70985 .44884 Mdot
.56549 .35122 Mdot
.3065 .57533 Mdot
.59887 .63201 Mdot
.46471 .37205 Mdot
.62906 .47876 Mdot
.68439 .48064 Mdot
.33464 .52612 Mdot
.70345 .42377 Mdot
.6052 .65648 Mdot
.62394 .49601 Mdot
.52884 .31284 Mdot
.36467 .38866 Mdot
.52828 .26723 Mdot
.46286 .37512 Mdot
.74433 .43232 Mdot
.32293 .51697 Mdot
.33629 .30984 Mdot
.44018 .7228 Mdot
.54618 .3163 Mdot
.4921 .36232 Mdot
.44912 .76182 Mdot
.2989 .53328 Mdot
.72174 .44041 Mdot
.42844 .71073 Mdot
.72518 .43179 Mdot
.64996 .49041 Mdot
.30772 .59559 Mdot
.65058 .48524 Mdot
.36304 .31847 Mdot
.45809 .68793 Mdot
.30755 .57746 Mdot
.67774 .73394 Mdot
.66259 .49356 Mdot
.59471 .64356 Mdot
.56602 .34831 Mdot
.29709 .51757 Mdot
.37932 .66128 Mdot
.60971 .59722 Mdot
.4232 .64918 Mdot
.5458 .33674 Mdot
.44179 .71648 Mdot
.47742 .38429 Mdot
.31363 .53681 Mdot
.43239 .66457 Mdot
.6358 .72146 Mdot
.4332 .403 Mdot
.61976 .47755 Mdot
.44109 .3736 Mdot
.21597 .63723 Mdot
.3684 .7223 Mdot
.33263 .59651 Mdot
.45857 .72652 Mdot
.4783 .34891 Mdot
.61163 .50383 Mdot
.47327 .3433 Mdot
.42039 .69511 Mdot
.4525 .65413 Mdot
.58676 .62228 Mdot
.4701 .37401 Mdot
.73064 .43205 Mdot
.58507 .64169 Mdot
.62787 .69069 Mdot
.62841 .62811 Mdot
.367 .52751 Mdot
.6064 .49897 Mdot
.61305 .50855 Mdot
.63009 .33555 Mdot
.43651 .69881 Mdot
.6458 .49733 Mdot
.44986 .38784 Mdot
.60269 .40358 Mdot
.3206 .54636 Mdot
.60882 .65915 Mdot
.48659 .34953 Mdot
.34831 .28954 Mdot
.63889 .50302 Mdot
.61703 .65427 Mdot
.27593 .54847 Mdot
.57894 .57394 Mdot
.46847 .3567 Mdot
.36236 .31066 Mdot
.32303 .52585 Mdot
.22034 .60514 Mdot
.5292 .30049 Mdot
.4577 .37593 Mdot
.43625 .68347 Mdot
.25183 .62089 Mdot
.4826 .39582 Mdot
.37321 .46948 Mdot
.6105 .52123 Mdot
.54928 .5625 Mdot
.26475 .60374 Mdot
.3499 .27851 Mdot
.45633 .59277 Mdot
.43315 .24279 Mdot
.493 .611 Mdot
.72215 .68715 Mdot
.41265 .59018 Mdot
.8396 .59884 Mdot
.42133 .73696 Mdot
.33678 .28009 Mdot
.66914 .20683 Mdot
.3822 .74491 Mdot
.39991 .62056 Mdot
.40815 .74722 Mdot
.581 .45529 Mdot
.68491 .7344 Mdot
.66493 .7273 Mdot
.7204 .679 Mdot
.50013 .34219 Mdot
.35908 .62818 Mdot
.32058 .30341 Mdot
.3776 .69002 Mdot
.64908 .7102 Mdot
.32954 .30345 Mdot
.73782 .29091 Mdot
.4731 .75279 Mdot
.72361 .35811 Mdot
.30732 .36852 Mdot
.6627 .65938 Mdot
.45794 .28322 Mdot
.65747 .40125 Mdot
.31438 .27581 Mdot
.51681 .58409 Mdot
.42123 .72913 Mdot
.27426 .56565 Mdot
.49679 .73557 Mdot
.60608 .62821 Mdot
.32188 .51305 Mdot
.42667 .78439 Mdot
.75481 .33249 Mdot
.39356 .70841 Mdot
.45501 .59365 Mdot
.65311 .4739 Mdot
.55268 .55389 Mdot
.53269 .33055 Mdot
.32054 .59303 Mdot
.66653 .68548 Mdot
.67913 .71161 Mdot
.25655 .55222 Mdot
.64412 .6869 Mdot
.56298 .36336 Mdot
.39662 .62154 Mdot
.26053 .60505 Mdot
.59006 .45572 Mdot
.58948 .47866 Mdot
.28652 .56513 Mdot
.68924 .2591 Mdot
.54253 .45095 Mdot
.51256 .27503 Mdot
.65191 .68547 Mdot
.26828 .54049 Mdot
.31431 .38805 Mdot
.36071 .48312 Mdot
.782 .67737 Mdot
.77779 .35387 Mdot
.74695 .67483 Mdot
.56192 .4452 Mdot
.4004 .70999 Mdot
.56496 .39809 Mdot
.52661 .63883 Mdot
.76691 .66247 Mdot
.22837 .60554 Mdot
.7034 .24993 Mdot
.50683 .51723 Mdot
.78431 .34113 Mdot
.25248 .58007 Mdot
.58647 .46397 Mdot
.31133 .60677 Mdot
.57704 .54646 Mdot
.60029 .32503 Mdot
.76826 .32283 Mdot
.38209 .62582 Mdot
.63975 .52857 Mdot
.38213 .74252 Mdot
.23596 .59045 Mdot
.66663 .70865 Mdot
.62365 .53101 Mdot
.38385 .43302 Mdot
.76453 .30546 Mdot
.46698 .58624 Mdot
.7205 .30508 Mdot
.66981 .66906 Mdot
.44894 .80072 Mdot
.6253 .69572 Mdot
.42512 .66372 Mdot
.74426 .35406 Mdot
.31248 .53211 Mdot
.79763 .66343 Mdot
.41788 .61247 Mdot
.4902 .64083 Mdot
.75675 .29828 Mdot
.76521 .69265 Mdot
.56626 .52781 Mdot
.59822 .4633 Mdot
.49988 .72868 Mdot
.51935 .61067 Mdot
.36934 .68147 Mdot
.61686 .55545 Mdot
.25659 .65115 Mdot
.73577 .34763 Mdot
.75085 .69698 Mdot
.68789 .22587 Mdot
.51355 .28541 Mdot
.6215 .42026 Mdot
.25782 .52538 Mdot
.43816 .52544 Mdot
.37211 .68794 Mdot
.78813 .34687 Mdot
.32933 .31733 Mdot
.2387 .6219 Mdot
.72691 .67675 Mdot
.39165 .40157 Mdot
.31006 .64223 Mdot
.42098 .76846 Mdot
.59152 .57133 Mdot
.24522 .58719 Mdot
.78416 .40015 Mdot
.61469 .35194 Mdot
.36503 .42482 Mdot
.63823 .70325 Mdot
.53389 .303 Mdot
.38472 .48005 Mdot
.82405 .58439 Mdot
.3359 .63491 Mdot
.37914 .42924 Mdot
.24784 .53437 Mdot
.76701 .65968 Mdot
.73179 .68268 Mdot
.27246 .63372 Mdot
.65059 .59379 Mdot
.72753 .31131 Mdot
.39413 .51374 Mdot
.56081 .542 Mdot
.32239 .29992 Mdot
.32515 .32338 Mdot
.68279 .67715 Mdot
.50771 .45722 Mdot
.71964 .39505 Mdot
.41606 .76022 Mdot
.3491 .4517 Mdot
.67061 .40414 Mdot
.35938 .44695 Mdot
.22368 .5774 Mdot
.42518 .47693 Mdot
.47636 .74785 Mdot
.42019 .46604 Mdot
.74263 .29095 Mdot
.60349 .61467 Mdot
.76653 .66758 Mdot
.39575 .71553 Mdot
.66022 .71133 Mdot
.47575 .63779 Mdot
.47662 .63908 Mdot
.73504 .36769 Mdot
.40066 .76726 Mdot
.57566 .48671 Mdot
.32751 .59481 Mdot
.45545 .61741 Mdot
.34568 .42999 Mdot
.52575 .42246 Mdot
.3782 .55917 Mdot
.70147 .43515 Mdot
.4113 .44957 Mdot
.24261 .5857 Mdot
.64324 .59327 Mdot
.5041 .43742 Mdot
.46995 .25576 Mdot
.59713 .49772 Mdot
.59704 .37727 Mdot
.6139 .31488 Mdot
.53455 .52451 Mdot
.77234 .6754 Mdot
.38919 .52975 Mdot
.60075 .3779 Mdot
.37416 .69522 Mdot
.28513 .292 Mdot
.78589 .34027 Mdot
.76925 .38292 Mdot
.27791 .62187 Mdot
.26948 .64084 Mdot
.4708 .82911 Mdot
.38407 .6582 Mdot
.83573 .57532 Mdot
.39605 .71588 Mdot
.25724 .3253 Mdot
.6067 .60976 Mdot
.5658 .48058 Mdot
.29576 .59702 Mdot
.46326 .25981 Mdot
.75179 .31078 Mdot
.53987 .5405 Mdot
.74614 .40343 Mdot
.2987 .61171 Mdot
.37355 .4623 Mdot
.72407 .28845 Mdot
.70057 .26009 Mdot
.70017 .26744 Mdot
.42232 .78337 Mdot
.47168 .45683 Mdot
.74421 .28304 Mdot
.57824 .41567 Mdot
.51246 .48211 Mdot
.36947 .2942 Mdot
.49846 .26069 Mdot
.82474 .61151 Mdot
.60275 .43263 Mdot
.52427 .60887 Mdot
.25612 .55092 Mdot
.76821 .30223 Mdot
.62891 .32348 Mdot
.56555 .56073 Mdot
.70828 .36503 Mdot
.68129 .4417 Mdot
.67432 .3965 Mdot
.73283 .37298 Mdot
.4898 .5839 Mdot
.41915 .76634 Mdot
.77826 .30528 Mdot
.75275 .65721 Mdot
.3837 .70038 Mdot
.22937 .57139 Mdot
.81816 .62794 Mdot
.29678 .64338 Mdot
.41471 .66679 Mdot
.26253 .58831 Mdot
.29665 .31912 Mdot
.39749 .57408 Mdot
.52366 .58554 Mdot
.39917 .35688 Mdot
.67661 .41437 Mdot
.61557 .61015 Mdot
.79494 .63009 Mdot
.39385 .56253 Mdot
.50345 .48139 Mdot
.61141 .37457 Mdot
.74122 .71213 Mdot
.51094 .55431 Mdot
.45039 .43853 Mdot
.38948 .5259 Mdot
.32286 .6277 Mdot
.31756 .63904 Mdot
.32741 .37578 Mdot
.42629 .38284 Mdot
.75922 .32968 Mdot
.8479 .56726 Mdot
.746 .37178 Mdot
.29947 .63302 Mdot
.467 .80733 Mdot
.42879 .7435 Mdot
.5832 .40402 Mdot
.47138 .23858 Mdot
.47243 .5597 Mdot
.44417 .23284 Mdot
.45517 .66365 Mdot
.31428 .38853 Mdot
.45653 .63116 Mdot
.5782 .41342 Mdot
.35756 .60209 Mdot
.47814 .63038 Mdot
.44818 .44515 Mdot
.24114 .54925 Mdot
.22035 .62406 Mdot
.76854 .65563 Mdot
.60651 .61452 Mdot
.65087 .58503 Mdot
.51058 .4662 Mdot
.74998 .4435 Mdot
.61651 .54357 Mdot
.56094 .53424 Mdot
.33404 .41151 Mdot
.47791 .81238 Mdot
.70978 .38865 Mdot
.8148 .64027 Mdot
.73486 .3738 Mdot
.74146 .68045 Mdot
.64876 .6744 Mdot
.59714 .35682 Mdot
.39617 .67764 Mdot
.40733 .72597 Mdot
.58919 .34663 Mdot
.73757 .69972 Mdot
.56523 .55339 Mdot
.33298 .59208 Mdot
.43841 .3882 Mdot
.61852 .32676 Mdot
.65238 .40334 Mdot
.58728 .37319 Mdot
.3466 .38412 Mdot
.2777 .51952 Mdot
.5965 .42093 Mdot
.55291 .58309 Mdot
.37097 .33233 Mdot
.26363 .63908 Mdot
.43438 .66269 Mdot
.23216 .56222 Mdot
.74168 .71427 Mdot
.47598 .82284 Mdot
.48975 .62299 Mdot
.54977 .41774 Mdot
.72916 .34301 Mdot
.56044 .41564 Mdot
.2693 .64534 Mdot
.30301 .32424 Mdot
.46687 .63944 Mdot
.25359 .56089 Mdot
.52529 .50123 Mdot
.51959 .66498 Mdot
.34685 .619 Mdot
.2371 .56227 Mdot
.33677 .33375 Mdot
.76683 .35703 Mdot
.41664 .34457 Mdot
.50536 .59051 Mdot
.52502 .29165 Mdot
.42355 .53191 Mdot
.43038 .61306 Mdot
.62222 .3788 Mdot
.47922 .60502 Mdot
.69251 .26926 Mdot
.31796 .40211 Mdot
.53723 .60705 Mdot
.5789 .43265 Mdot
.5766 .41318 Mdot
.30849 .36999 Mdot
.23702 .59463 Mdot
.4147 .75855 Mdot
.44703 .33604 Mdot
.78123 .36386 Mdot
.49293 .50937 Mdot
.60579 .37388 Mdot
.39834 .49117 Mdot
.42431 .34453 Mdot
.60203 .53832 Mdot
.73192 .37118 Mdot
.5504 .56597 Mdot
.66334 .19906 Mdot
.72405 .70419 Mdot
.37829 .51491 Mdot
.30353 .60435 Mdot
.77687 .65513 Mdot
.37175 .6122 Mdot
.41964 .5966 Mdot
.39927 .53843 Mdot
.80711 .63449 Mdot
.53792 .56049 Mdot
.55554 .57257 Mdot
.22432 .63191 Mdot
.72888 .27556 Mdot
.5126 .60439 Mdot
.4136 .67235 Mdot
.62014 .42707 Mdot
.50999 .36382 Mdot
.37399 .48789 Mdot
.25145 .66954 Mdot
.43187 .49493 Mdot
.50349 .61703 Mdot
.84666 .58543 Mdot
.54571 .53785 Mdot
.38903 .54226 Mdot
.66734 .19975 Mdot
.66709 .19238 Mdot
.37093 .48948 Mdot
.79101 .35135 Mdot
.56007 .56954 Mdot
.27867 .64608 Mdot
.41693 .72538 Mdot
.53912 .41163 Mdot
.3373 .43109 Mdot
.77747 .3723 Mdot
.45016 .82125 Mdot
.37396 .70033 Mdot
.27577 .59116 Mdot
.78811 .37738 Mdot
.50226 .48896 Mdot
.57062 .49158 Mdot
.45363 .79755 Mdot
.70442 .7315 Mdot
.78156 .67236 Mdot
.33035 .36901 Mdot
.68337 .69437 Mdot
.70046 .67019 Mdot
.37863 .62894 Mdot
.82253 .6263 Mdot
.67071 .4804 Mdot
.28873 .28741 Mdot
.7658 .66176 Mdot
.23576 .64181 Mdot
.67356 .70924 Mdot
.43341 .61069 Mdot
.55458 .53545 Mdot
.44162 .47764 Mdot
.26397 .65241 Mdot
.41721 .77391 Mdot
.53994 .49359 Mdot
.57284 .34093 Mdot
.23133 .58316 Mdot
.22969 .61388 Mdot
.29936 .29703 Mdot
.56059 .51739 Mdot
.67642 .24084 Mdot
.4649 .74775 Mdot
.57308 .36881 Mdot
.32609 .59304 Mdot
.64158 .38018 Mdot
.57408 .48597 Mdot
.49412 .39858 Mdot
.76382 .35488 Mdot
.57509 .49361 Mdot
.687 .24809 Mdot
.79624 .67035 Mdot
.70403 .35883 Mdot
.52534 .65059 Mdot
.62081 .54648 Mdot
.8245 .60734 Mdot
.83011 .58973 Mdot
.68348 .23564 Mdot
.71977 .66946 Mdot
.58685 .34423 Mdot
.54447 .50552 Mdot
.52973 .41777 Mdot
.47573 .44756 Mdot
.77935 .65032 Mdot
.30504 .36914 Mdot
.66777 .39667 Mdot
.31067 .62108 Mdot
.73978 .70441 Mdot
.56462 .42849 Mdot
.6349 .38398 Mdot
.41942 .49918 Mdot
.5848 .48061 Mdot
.59923 .68588 Mdot
.73331 .25849 Mdot
.27161 .63559 Mdot
.68605 .39429 Mdot
.24416 .6251 Mdot
.24066 .53731 Mdot
.71286 .69105 Mdot
.27774 .61177 Mdot
.70757 .47753 Mdot
.65675 .66753 Mdot
.7692 .39285 Mdot
.57194 .54789 Mdot
.22187 .64459 Mdot
.39567 .41291 Mdot
.74566 .36598 Mdot
.67251 .40505 Mdot
.67553 .22207 Mdot
.60063 .42216 Mdot
.4079 .4492 Mdot
.68356 .25527 Mdot
.30585 .62434 Mdot
.58099 .3755 Mdot
.72568 .28455 Mdot
.35372 .59253 Mdot
.77642 .35207 Mdot
.4476 .72114 Mdot
.57377 .45818 Mdot
.24492 .65934 Mdot
.58139 .38943 Mdot
.5787 .38852 Mdot
.71137 .39191 Mdot
.37825 .73443 Mdot
.38357 .56993 Mdot
.39438 .51801 Mdot
.66316 .71047 Mdot
.54235 .40935 Mdot
.49044 .59213 Mdot
.69121 .22705 Mdot
.44052 .39016 Mdot
.7451 .64507 Mdot
.76881 .6713 Mdot
.39797 .67791 Mdot
.55422 .52194 Mdot
.23689 .65204 Mdot
.33025 .36016 Mdot
.62587 .3453 Mdot
.73219 .28006 Mdot
.55374 .52029 Mdot
.46297 .24704 Mdot
.32383 .33636 Mdot
.50749 .71127 Mdot
.39266 .74355 Mdot
.46448 .59441 Mdot
.55693 .45555 Mdot
.52787 .30375 Mdot
.74429 .67334 Mdot
.84341 .59359 Mdot
.67605 .23845 Mdot
.39637 .74653 Mdot
.58595 .38344 Mdot
.38903 .47115 Mdot
.66192 .42847 Mdot
.68768 .22139 Mdot
.68754 .73427 Mdot
.24196 .58468 Mdot
.74226 .69642 Mdot
.38616 .74438 Mdot
.57022 .48096 Mdot
.58895 .36311 Mdot
.69129 .26268 Mdot
.28266 .58712 Mdot
.51798 .51573 Mdot
.40439 .48234 Mdot
.55183 .31033 Mdot
.41433 .62361 Mdot
.29609 .32582 Mdot
.39805 .77065 Mdot
.67401 .22189 Mdot
.69557 .67903 Mdot
.37693 .37661 Mdot
.67044 .21131 Mdot
.27543 .52388 Mdot
.41135 .62525 Mdot
.44418 .79783 Mdot
.59824 .38303 Mdot
.62985 .69636 Mdot
.43427 .38263 Mdot
.58027 .33784 Mdot
.36815 .61613 Mdot
.60351 .42567 Mdot
.71681 .40971 Mdot
.23354 .57037 Mdot
.70867 .67912 Mdot
.23628 .55394 Mdot
.84285 .58678 Mdot
.48788 .58037 Mdot
.25902 .59935 Mdot
.31031 .32644 Mdot
.6484 .66936 Mdot
.31744 .62598 Mdot
.71997 .35965 Mdot
.49974 .26337 Mdot
.26299 .59599 Mdot
.25612 .59048 Mdot
.36248 .58837 Mdot
.39725 .66171 Mdot
.73854 .33622 Mdot
.76552 .68834 Mdot
.65821 .59215 Mdot
.36544 .57577 Mdot
.56015 .40285 Mdot
.55881 .53817 Mdot
.69311 .3822 Mdot
.60258 .60293 Mdot
.79111 .33482 Mdot
.27889 .31054 Mdot
.35622 .63272 Mdot
.48122 .5515 Mdot
.48228 .24206 Mdot
.56795 .39413 Mdot
.64537 .67537 Mdot
.56418 .52932 Mdot
.38152 .51289 Mdot
.28572 .50484 Mdot
.42985 .62934 Mdot
.70814 .42449 Mdot
.65079 .5977 Mdot
.38821 .71061 Mdot
.32082 .37306 Mdot
.77813 .66297 Mdot
.25919 .50368 Mdot
.59834 .54167 Mdot
.63864 .62202 Mdot
.5008 .44475 Mdot
.48726 .2561 Mdot
.75562 .27722 Mdot
.71683 .34996 Mdot
.30379 .50744 Mdot
.33921 .63297 Mdot
.66927 .69168 Mdot
.706 .38943 Mdot
.52301 .53065 Mdot
.77575 .64945 Mdot
.38946 .43743 Mdot
.71171 .37669 Mdot
.27638 .60637 Mdot
.45857 .58074 Mdot
.75478 .68317 Mdot
.70106 .41521 Mdot
.74476 .70445 Mdot
.34665 .36943 Mdot
.55034 .44913 Mdot
.71182 .72449 Mdot
.42143 .48921 Mdot
.57452 .56056 Mdot
.37271 .33152 Mdot
.47042 .56396 Mdot
.80989 .62856 Mdot
.29073 .50196 Mdot
.58542 .44832 Mdot
.26625 .61684 Mdot
.37487 .70454 Mdot
.73304 .34876 Mdot
.31617 .63414 Mdot
.76047 .69073 Mdot
.54295 .4119 Mdot
.68815 .42696 Mdot
.31747 .38179 Mdot
.50504 .2731 Mdot
.65465 .48365 Mdot
.37042 .43294 Mdot
.64904 .51721 Mdot
.63223 .33207 Mdot
.47044 .44486 Mdot
.75997 .31775 Mdot
.61436 .3189 Mdot
.44576 .47852 Mdot
.58575 .46887 Mdot
.30078 .58821 Mdot
.77758 .32247 Mdot
.6206 .3432 Mdot
.256 .65402 Mdot
.78118 .6709 Mdot
.71922 .66202 Mdot
.66891 .20875 Mdot
.38242 .74077 Mdot
.47357 .47238 Mdot
.82649 .62175 Mdot
.49991 .50736 Mdot
.70174 .66886 Mdot
.57177 .54773 Mdot
.26159 .51115 Mdot
.74704 .29177 Mdot
.57813 .48428 Mdot
.43594 .48076 Mdot
.41054 .39233 Mdot
.25427 .56519 Mdot
.60915 .33251 Mdot
.56206 .40708 Mdot
.60186 .62736 Mdot
.4715 .24873 Mdot
.68109 .67886 Mdot
.36805 .57465 Mdot
.7744 .66294 Mdot
.78157 .64057 Mdot
.62715 .43029 Mdot
.52961 .65861 Mdot
.66577 .20897 Mdot
.43804 .45972 Mdot
.35494 .28189 Mdot
.23755 .55584 Mdot
.71078 .41381 Mdot
.73362 .6647 Mdot
.44052 .3385 Mdot
.46487 .27404 Mdot
.38571 .43453 Mdot
.77346 .36644 Mdot
.43319 .51587 Mdot
.47119 .74659 Mdot
.35755 .58997 Mdot
.25741 .65244 Mdot
.25453 .61626 Mdot
.38034 .74644 Mdot
.80987 .62646 Mdot
.48977 .6225 Mdot
.45612 .58945 Mdot
.43599 .47288 Mdot
.79463 .62512 Mdot
.38359 .72085 Mdot
.45083 .66695 Mdot
.33616 .41634 Mdot
.67402 .23174 Mdot
.22826 .56808 Mdot
.44241 .60908 Mdot
.51784 .57405 Mdot
.5582 .41834 Mdot
.36952 .68018 Mdot
.36995 .62812 Mdot
.24335 .56083 Mdot
.70971 .28955 Mdot
.52744 .59464 Mdot
.6354 .53788 Mdot
.73009 .69578 Mdot
.50234 .57559 Mdot
.78345 .64231 Mdot
.35329 .46387 Mdot
.70385 .27378 Mdot
.60653 .37712 Mdot
.6768 .44556 Mdot
.42276 .37424 Mdot
.31417 .61699 Mdot
.73422 .37135 Mdot
.52078 .53016 Mdot
.51708 .63098 Mdot
.24702 .60378 Mdot
.79293 .66719 Mdot
.59151 .504 Mdot
.47684 .81045 Mdot
.59071 .46835 Mdot
.46999 .26058 Mdot
.46446 .2539 Mdot
.40473 .66122 Mdot
.56058 .54378 Mdot
.38817 .60531 Mdot
.55462 .45508 Mdot
.33454 .40366 Mdot
.76584 .39021 Mdot
.72573 .2525 Mdot
.26781 .5317 Mdot
.7762 .68975 Mdot
.37007 .50779 Mdot
.26205 .53505 Mdot
.69596 .67497 Mdot
.53036 .63237 Mdot
.50212 .46094 Mdot
.6131 .42622 Mdot
.30789 .49451 Mdot
.71568 .24344 Mdot
.50078 .61867 Mdot
.58901 .44311 Mdot
.66713 .70048 Mdot
.43433 .61619 Mdot
.48623 .75084 Mdot
.40201 .7246 Mdot
.80102 .6572 Mdot
.76715 .66231 Mdot
.46685 .75664 Mdot
.55845 .56905 Mdot
.51436 .62574 Mdot
.72233 .28868 Mdot
.58421 .47448 Mdot
.73082 .35512 Mdot
.41377 .78395 Mdot
.34035 .39527 Mdot
.60987 .3166 Mdot
.61578 .35082 Mdot
.5058 .26838 Mdot
.37369 .4162 Mdot
.71482 .30906 Mdot
.60029 .49522 Mdot
.65479 .59622 Mdot
.67365 .70618 Mdot
.69195 .22447 Mdot
.34864 .62555 Mdot
.64128 .47048 Mdot
.66031 .4194 Mdot
.52621 .5925 Mdot
.57114 .36742 Mdot
.39612 .53085 Mdot
.62447 .54157 Mdot
.48794 .74026 Mdot
.26209 .62541 Mdot
.77789 .363 Mdot
.42324 .36923 Mdot
.43308 .23402 Mdot
.37534 .67522 Mdot
.63698 .6782 Mdot
.24747 .60965 Mdot
.74945 .27415 Mdot
.44769 .66571 Mdot
.45068 .79188 Mdot
.39771 .66792 Mdot
.69218 .39165 Mdot
.46274 .81504 Mdot
.40057 .65759 Mdot
.84226 .59906 Mdot
.36271 .63229 Mdot
.37235 .39047 Mdot
.22852 .6184 Mdot
.63079 .32992 Mdot
.36625 .43245 Mdot
.61641 .55609 Mdot
.76339 .34567 Mdot
.57008 .38974 Mdot
.58054 .45326 Mdot
.71 .30062 Mdot
.7505 .68794 Mdot
.72718 .70311 Mdot
.38434 .66176 Mdot
.26752 .58742 Mdot
.48274 .82455 Mdot
.6599 .6954 Mdot
.27504 .32827 Mdot
.71336 .34817 Mdot
.38797 .36894 Mdot
.51935 .52567 Mdot
.3937 .50488 Mdot
.73615 .29486 Mdot
.80238 .62835 Mdot
.57737 .56595 Mdot
.62583 .60283 Mdot
.62081 .36435 Mdot
.65537 .42644 Mdot
.38153 .58626 Mdot
.69747 .3669 Mdot
.64612 .66901 Mdot
.57867 .48287 Mdot
.76148 .6812 Mdot
.31337 .61686 Mdot
.51002 .2834 Mdot
.67747 .23236 Mdot
.4864 .26393 Mdot
.73401 .71815 Mdot
.42097 .78373 Mdot
.67086 .70706 Mdot
.69521 .22967 Mdot
.36204 .60926 Mdot
.41596 .42821 Mdot
.6622 .20032 Mdot
.7834 .34119 Mdot
.51645 .62538 Mdot
.41103 .35991 Mdot
.83747 .60793 Mdot
.62312 .59381 Mdot
.69261 .40027 Mdot
.31208 .385 Mdot
.71632 .70218 Mdot
.4874 .43757 Mdot
.41683 .34892 Mdot
.57121 .44989 Mdot
.28658 .51437 Mdot
.2632 .5876 Mdot
.66496 .66086 Mdot
.73687 .69842 Mdot
.30849 .36113 Mdot
.31808 .40245 Mdot
.34229 .3689 Mdot
.31938 .50955 Mdot
.75883 .35104 Mdot
.77082 .43972 Mdot
.29466 .35316 Mdot
.71353 .28563 Mdot
.46227 .2262 Mdot
.37977 .6184 Mdot
.32934 .40415 Mdot
.5969 .36357 Mdot
.68 .67498 Mdot
.6807 .20951 Mdot
.3427 .41681 Mdot
.7891 .3305 Mdot
.78002 .38483 Mdot
.31031 .50903 Mdot
.37603 .54045 Mdot
.56741 .40157 Mdot
.50114 .60569 Mdot
.49115 .73845 Mdot
.65977 .7095 Mdot
.71313 .66917 Mdot
.63335 .60038 Mdot
.43069 .35858 Mdot
.3881 .49616 Mdot
.73837 .36457 Mdot
.57093 .47918 Mdot
.74393 .36141 Mdot
.3551 .40379 Mdot
.44752 .39115 Mdot
.6599 .19221 Mdot
.27536 .64659 Mdot
.52376 .42697 Mdot
.61173 .47199 Mdot
.64372 .47103 Mdot
.47868 .40208 Mdot
.44825 .65634 Mdot
.60204 .40122 Mdot
.70398 .70381 Mdot
.75866 .34381 Mdot
.36823 .56426 Mdot
.56927 .39765 Mdot
.43207 .74744 Mdot
.53492 .33409 Mdot
.48236 .43712 Mdot
.46211 .6678 Mdot
.69118 .69964 Mdot
.51588 .71024 Mdot
.3753 .69741 Mdot
.41379 .62135 Mdot
.57489 .33364 Mdot
.61629 .47717 Mdot
.69432 .68838 Mdot
.40751 .66063 Mdot
.37399 .67655 Mdot
.7582 .6929 Mdot
.38751 .42102 Mdot
.39438 .75322 Mdot
.67281 .65863 Mdot
.58313 .37279 Mdot
.39043 .48727 Mdot
.52264 .61369 Mdot
.3009 .3261 Mdot
.73292 .30584 Mdot
.63865 .56679 Mdot
.60026 .49215 Mdot
.30912 .31148 Mdot
.75397 .31518 Mdot
.46037 .67805 Mdot
.84678 .56155 Mdot
.53214 .62811 Mdot
.26756 .61585 Mdot
.36039 .34399 Mdot
.54827 .52359 Mdot
.33216 .32279 Mdot
.40535 .36474 Mdot
.46075 .2916 Mdot
.44418 .78748 Mdot
.55764 .52718 Mdot
.43143 .61967 Mdot
.47773 .61382 Mdot
.58567 .42454 Mdot
.33074 .31525 Mdot
.47947 .34772 Mdot
.59645 .51549 Mdot
.59127 .3287 Mdot
.60853 .5472 Mdot
.58619 .43325 Mdot
.4215 .76653 Mdot
.6949 .69167 Mdot
.72482 .70302 Mdot
.48151 .4581 Mdot
.74063 .29343 Mdot
.37686 .31842 Mdot
.71427 .35155 Mdot
.41254 .52363 Mdot
.41181 .76745 Mdot
.48281 .26325 Mdot
.67949 .21119 Mdot
.37969 .47344 Mdot
.69109 .47028 Mdot
.77158 .38451 Mdot
.71437 .36689 Mdot
.45233 .75575 Mdot
.22606 .63865 Mdot
.67484 .70784 Mdot
.5727 .40916 Mdot
.25384 .62261 Mdot
.64977 .57786 Mdot
.71818 .3854 Mdot
.54478 .47133 Mdot
.52759 .63004 Mdot
.29559 .3309 Mdot
.50165 .44261 Mdot
.5842 .66967 Mdot
.30298 .32493 Mdot
.37453 .41555 Mdot
.71462 .31062 Mdot
.36168 .2871 Mdot
.45411 .5479 Mdot
.38117 .47036 Mdot
.67715 .22605 Mdot
.58786 .68213 Mdot
.46249 .2455 Mdot
.27194 .3054 Mdot
.44165 .78864 Mdot
.70115 .66532 Mdot
.67475 .23639 Mdot
.40733 .72667 Mdot
.55598 .4541 Mdot
.25977 .67626 Mdot
.38621 .47221 Mdot
.24516 .54675 Mdot
.38547 .6989 Mdot
.65836 .43949 Mdot
.39785 .47805 Mdot
.67983 .20082 Mdot
.71569 .3778 Mdot
.4848 .46503 Mdot
.27391 .33056 Mdot
.76463 .6774 Mdot
.45171 .25038 Mdot
.39865 .76175 Mdot
.76139 .35529 Mdot
.47963 .75304 Mdot
.82996 .61805 Mdot
.50383 .58269 Mdot
.36413 .50396 Mdot
.64941 .42656 Mdot
.25502 .62773 Mdot
.55331 .50513 Mdot
.31276 .39511 Mdot
.26332 .63815 Mdot
.65768 .40112 Mdot
.53226 .55917 Mdot
.29613 .49202 Mdot
.37185 .50166 Mdot
.4887 .55669 Mdot
.53104 .63697 Mdot
.44419 .60871 Mdot
.46351 .58847 Mdot
.38064 .71328 Mdot
.47356 .54677 Mdot
.2751 .64894 Mdot
.39993 .69838 Mdot
.35564 .38846 Mdot
.67619 .66916 Mdot
.59546 .42504 Mdot
.61065 .6063 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3E
ooooo`;o0000L_ooool001cooooo00?o0000ooooooooool0eOooool3o`00077ooooo00001_oooooo
k^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`3C
ooooo`Ko0000L?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0=?ooooo1ol0001_ooooo`0000?o
oooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o
0000ooooooooool0e?ooool3o`000004ooooool0003o0000o`0006kooooo00000ooooooo0000oooo
o`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000=?ooooo1?l0
00001?oooooo0000o`000?l0001^ooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooooooo
o`0<ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0doooool2o`0000Cooooo1?l0
001/ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0e?ooool4o`0000?ooooo0_l0001/ooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003ooooo
ooooo`3Dooooo`Co000000?oooooo`000?l000000ol0001[ooooo`0000Koooooonk^k_lb<S;o0000
oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3Foooo
o`;o000000Coooooo`000?l0003ooooo0_l0001[ooooo`007?ooool00ol0003oooooooooo`3Loooo
o`;o0000Joooool001cooooo00?o0000ooooooooool0g?ooool3o`0006[ooooo000Looooo`03o`00
0?oooooooooo0=Oooooo0ol00002ooooo`Co0000JOooool001cooooo00?o0000ooooooooool0T_oo
ool2o`0004?ooooo0ol00002ooooo`Co0000JOooool001cooooo00?o0000ooooooooool0T_ooool2
o`0004Cooooo0_l00002ooooo`Co0000JOooool001cooooo00?o0000ooooooooool0SOooool2o`00
04Sooooo0ol00004ooooo`;o000000?oooooo`000?l00000I_ooool001cooooo00?o0000oooooooo
ool0ROooool2o`0000;ooooo0_l0000<ooooo`Co0000>?ooool5o`0000Gooooo0_l0001Vooooo`00
7?ooool00ol0003oooooooooo`27ooooo`Co00002_ooool2o`0000?ooooo1_l0000gooooo`Go0000
2?ooool2o`0006?ooooo000Looooo`03o`000?oooooooooo08Oooooo1?l0000:ooooo`;o00000_oo
ool4o`000004ooooool0003o0000o`0003Oooooo0_l0000:ooooo`;o0000Hoooool001cooooo00?o
0000ooooooooool0R?ooool3o`0000Oooooo0_l00005ooooo`Co000000?oooooo`000?l000000ol0
000eooooo`;o00002oooool2o`0006;ooooo000Looooo`03o`000?oooooooooo08Sooooo0_l00008
ooooo`Go00001oooool2o`000003ooooool0003o000003Sooooo0_l00008ooooo`;o000000?ooooo
o`000?l00000Goooool001cooooo0_l0002@ooooo`;o00000_ooool4o`0000Oooooo0_l00002oooo
o`?o0000=_ooool2o`0000Cooooo0_l00005ooooo`;o0000Goooool001cooooo00?o0000oooooooo
ool0Soooool2o`0000;ooooo0_l0000=ooooo`?o0000=Oooool2o`0000Gooooo0_l00005ooooo`;o
0000Goooool001cooooo00?o0000ooooooooool0Toooool4o`0000Cooooo0_l00005ooooo`Co0000
=?ooool2o`0000cooooo1_l0001Kooooo`007?ooool00ol0003oooooooooo`2Cooooo`Co00001?oo
ool2o`000003ooooool0003o000000Cooooo1Ol0000cooooo`;o00000_ooool2o`0000Sooooo1?l0
001Kooooo`007?ooool00ol0003oooooooooo`2Cooooo`Co00000_ooool3o`0000;ooooo0ol00004
ooooo`Co0000<oooool3o`000003ooooool0003o000000_ooooo0_l0001Jooooo`007?ooool00ol0
003oooooooooo`2Iooooo`?o00000oooool2o`0000Gooooo1?l0000cooooo`;o000000?oooooo`00
0?l000002oooool2o`0005[ooooo000Looooo`03o`000?oooooooooo0:7ooooo0_l00003ooooo`Co
0000<oooool2o`000003ooooool0003o000006Oooooo000Looooo`03o`000?oooooooooo09cooooo
1ol00004ooooo`Co0000<_ooool2o`0000;ooooo0_l0001Vooooo`007?ooool00ol0003ooooooooo
o`1Rooooo`;o0000;oooool2o`0000Oooooo1_l000000ooooooo0000o`000002ooooo`Go0000=Ooo
ool2o`0000Kooooo0_l00005ooooo`;o0000Eoooool001cooooo00?o0000ooooooooool0H_ooool2
o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o00008oooool2o`0000?ooooo2Ol00002
ooooo`;o00001?ooool3o`0003gooooo0ol00004ooooo`Co0000EOooool001cooooo00?o0000oooo
ooooool0G?ooool2o`0000Cooooo0ol00002ooooo`Go00000_ooool4o`0001oooooo0_l00002oooo
oa7o00000oooool4o`0003gooooo0_l00002ooooo`Ko0000EOooool001cooooo00?o0000oooooooo
ool0G?ooool2o`0000Gooooo0_l00002ooooo`Co00000oooool4o`0001kooooo0ol00002ooooo`Co
00001oooool6o`0000?ooooo1?l0000gooooo`;o00000_ooool2o`0000Cooooo0_l0001Iooooo`00
7?ooool00ol0003oooooooooo`1Jooooo`;o00002oooool4o`0000;ooooo1?l000000ooooooo0000
o`00000Looooo`;o000000?oooooo`000?l000001?l00008ooooo`Ko00001?ooool3o`0003Kooooo
0_l000001?oooooo0000o`000?l0001Oooooo`007?ooool00ol0003oooooooooo`1Hooooo`Co0000
4?ooool8o`0001kooooo1Ol0000=ooooo`Go000000?oooooo`000?l000000ol0000dooooo`;o0000
0_ooool2o`0000?ooooo1Ol0001Hooooo`007?ooool00ol0003oooooooooo`1Gooooo`Co00004?oo
ool;o`0001cooooo1?l0000?ooooo`Co000000?oooooo`000?l000000ol0000dooooo`;o00001_oo
ool6o`0005Sooooo000Looooo`03o`000?oooooooooo05Gooooo1?l00005ooooo`;o00001_ooool2
o`000003ooooool0003o000000co00007Oooool2o`00017ooooo0_l00003ooooo`Co0000>oooool4
o`0000?ooooo0_l0001Eooooo`007?ooool2o`0005Kooooo0_l00007ooooo`;o00001OoooolBo`00
033ooooo0ol000000ooooooo0000o`000003o`0003?ooooo0_l0000=ooooo`;o0000EOooool001co
oooo00?o0000ooooooooool0EOooool2o`0000gooooo4ol0000`ooooo`[o0000<_ooool2o`00017o
oooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`1Eooooo`;o00003OoooolCo`0001Oooooo
0_l0000Gooooo`[o0000<_ooool2o`000003ooooool0003o000000;ooooo0_l00009ooooo`?o0000
00?oooooo`000?l00000C_ooool001cooooo00?o0000ooooooooool0EOooool4o`0000gooooo4Ol0
000Gooooo`;o00005oooool3o`0000?ooooo1?l0000Booooo`;o00007_ooool5o`0000;ooooo0_l0
0004ooooo`;o00000oooool2o`0000;ooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`1B
ooooo`;o00000oooool2o`0000Sooooo0_l00003oooooa7o00005_ooool2o`0001Wooooo0_l00003
ooooo`Co00004?ooool5o`0001kooooo0_l00003ooooo`;o00001Oooool2o`0005Oooooo000Loooo
o`03o`000?oooooooooo05;ooooo0_l0000=ooooo`;o00001Oooool?o`000003ooooool0003o0000
01?ooooo0_l0000Iooooo`Co000000?oooooo`000?l000000_l00008ooooo`;o00001?ooool7o`00
02?ooooo0_l00006ooooo`;o00001_ooool2o`0004kooooo000Looooo`03o`000?oooooooooo04oo
oooo0_l0000<ooooo`;o00002?oooolCo`0002oooooo2?l00008ooooo`?o00000oooool2o`000003
ooooool0003o000000;o00007_ooool2o`0000_ooooo1?l00004ooooo`;o0000C_ooool001cooooo
00?o0000ooooooooool0Coooool2o`000003ooooool0003o000000Wooooo0_l00008oooooa;o0000
<?ooool8o`0000Oooooo1Ol00007ooooo`;o00007_ooool2o`0000gooooo0_l000001?oooooo0000
o`000?ooool2o`0004kooooo000Looooo`03o`000?oooooooooo053ooooo1?l00008ooooo`Go0000
1OoooolAo`0003;ooooo1ol00007ooooo`Oo000000?oooooo`000?l000001Oooool2o`000003oooo
ool0003o000002_ooooo0_l000000ooooooo0000o`00001>ooooo`007?ooool00ol0003ooooooooo
o`1@ooooo`Go000000?oooooo`000?l000001?ooool7o`0000?ooooo4Ol00002ooooo`;o0000;_oo
ool7o`0000Oooooo1ol000000ooooooo0000o`000004ooooo`Ko0000O_ooool001cooooo00?o0000
ooooooooool0D_ooool6o`0000Cooooo0_l00003ooooo`;o00001Oooool?o`0000;ooooo1?l0000/
ooooo`Oo00001oooool7o`0000Oooooo1ol0000Uooooo`Co00002?ooool2o`0004[ooooo000Loooo
o`03o`000?oooooooooo05?ooooo1?l00005ooooo`;o00003?ooool=o`0000?ooooo0ol0000Boooo
o`;o00006?ooool7o`0000Oooooo0_l00009ooooo`;o00000oooool5o`0002Gooooo1?l00008oooo
o`;o0000B_ooool001cooooo00?o0000ooooooooool0E?ooool3o`0000kooooo0_l00003ooooo`;o
000000?oooooo`000?l000001ol00009ooooo`;o00002_ooool6o`0000Kooooo0_l000001?oooooo
0000o`000?l0000=ooooo`Ko00001oooool4o`0000Oooooo0_l00004ooooo`Co00008?ooool2o`00
00oooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`1Dooooo`Go00003?ooool2o`000003
ooooool0003o000000;o00001_ooool4o`0000Gooooo0_l00002ooooo`;o00002_ooool4o`0000Co
oooo0_l00002ooooo`Oo00003_ooool4o`0000Kooooo0_l000000ooooooo0000o`00000=ooooo`Co
000000?oooooo`000?l000007Oooool2o`0000gooooo0_l0001<ooooo`007?ooool00ol0003ooooo
ooooo`1Fooooo`Co00003_ooool4o`0000Gooooo0_l000000ooooooo0000o`000005ooooo`;o0000
1oooool4o`0000Gooooo0_l00002ooooo`go000000Coooooo`000?l0003o00002?ooool5o`0000Ko
oooo0ol00003ooooo`;o00002Oooool2o`000003ooooool0003o000000Co00006_ooool2o`0000So
oooo0_l00006ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0F?ooool3o`0000kooooo
0ol00005ooooo`Go00003_ooool4o`0000Gooooo5_l00007ooooo`?o00002?ooool2o`0000Cooooo
0ol00008ooooo`Oo000000?oooooo`000?l000006Oooool4o`0000Kooooo0ol00006ooooo`;o0000
Boooool001cooooo0_l0001Jooooo`;o00003oooool2o`0000Kooooo0_l0000@ooooo`;o000000Co
ooooo`000?l0003ooooo7Ol00003ooooo`Co00001_ooool2o`0000Kooooo0_l00006ooooo`;o0000
0_ooool5o`000003ooooool0003o000001Cooooo0ol00003ooooo`?o00001oooool2o`0000Kooooo
1?l00019ooooo`007?ooool00ol0003oooooooooo`1Kooooo`?o00003_ooool2o`0001Kooooo0_l0
00000ooooooo0000o`00000No`0000?ooooo1Ol00005ooooo`;o00003_ooool2o`0000Cooooo1?l0
000Fooooo`?o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000oooool3o`0000;ooooo0ol0
0019ooooo`007?ooool00ol0003oooooooooo`1Jooooo`Co00003_ooool2o`000004ooooool0003o
0000o`0000cooooo0_l00005ooooob;o00000oooool5o`0000Gooooo0_l00008ooooo`;o00001?oo
ool2o`0000Cooooo1Ol0000Eooooo`;o00001?ooool2o`0000;ooooo0_l00003ooooo`Co000000Co
ooooo`000?l0003o00000_ooool2o`0004[ooooo000Looooo`03o`000?oooooooooo05[ooooo1?l0
000:ooooo`;o00001Oooool5o`0000[ooooo0_l00002ooooobGo00000oooool4o`0000Gooooo0_l0
0009ooooo`;o00002_ooool7o`00013ooooo0_l00003ooooo`?o000000?oooooo`000?l000002?oo
ool3o`0000Oooooo0_l00019ooooo`007?ooool00ol0003oooooooooo`1Kooooo`Co000000?ooooo
o`000?l000001_ooool2o`0000Kooooo1Ol0000=ooooobGo00000oooool4o`0000Gooooo0_l00007
ooooo`;o00003?ooool7o`00013ooooo0_l00003ooooo`?o00001Oooool2o`0000Wooooo0_l00003
ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0Foooool4o`000003ooooool0003o0000
00oooooo1?l0000;ooooobco00001oooool2o`0000Oooooo1?l00006ooooo`;o00000_ooool5o`00
01?ooooo0_l00008ooooo`Co00002Oooool3o`0004gooooo000Looooo`03o`000?oooooooooo05co
oooo0_l000001?oooooo0000o`000?l00006ooooo`;o000000?oooooo`000?l000000_l00003oooo
o`?o00001Oooool2o`0000Cooooo;?l00007ooooo`;o000000?oooooo`000?l000001_ooool2o`00
00Kooooo0_l00004ooooo`Go00003_ooool2o`000003ooooool0003o000000;o00001Oooool5o`00
00Oooooo0_l000000ooooooo0000o`00001=ooooo`007?ooool00ol0003oooooooooo`1Kooooo`?o
000000Coooooo`000?l0003o00001_ooool2o`000003ooooool0003o000000;o00000oooool3o`00
00Gooooo0_l00003ooooobgo00002_ooool2o`0001Cooooo1Ol0000>ooooo`;o00000oooool2o`00
00Cooooo0ol00002ooooo`;o00001_ooool4o`0004kooooo000Looooo`03o`000?oooooooooo05_o
oooo0ol000000ooooooo0000o`000002o`000003ooooool0003o000000gooooo0_l00006ooooo`;o
000000?oooooo`000?l00000:ol00005ooooo`;o00001oooool4o`0000Cooooo1?l00006ooooo`Co
00006oooool3o`0000;ooooo0_l00008ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0
Goooool4o`000004ooooool0003o0000ooooo`;o00002_ooool2o`0000;ooooo0_l00002oooooc3o
00001Oooool2o`0000Oooooo1?l000000ooooooo0000o`000005o`0000Cooooo1_l0000Dooooo`Co
00000oooool3o`0000oooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`1Oooooo`Ko0000
0_ooool2o`0000Wooooo0ol00002ooooo`;o00000oooool^o`0000Kooooo0_l0000<ooooo`Go0000
0oooool2o`000005ooooool0003o0000o`000?ooool00_l0000Dooooo`Co00005Oooool2o`0004_o
oooo000Looooo`03o`000?oooooooooo063ooooo1Ol00008ooooo`;o00000oooool4o`0000Oooooo
0_l00003ooooobOo00001oooool2o`0000Wooooo0_l00002ooooo`;o00001Oooool6o`000003oooo
ool0003o000000kooooo0_l0000Gooooo`?o000000Coooooo`000?l0003ooooo0_l0001:ooooo`00
7?ooool00ol0003oooooooooo`1Rooooo`?o00002?ooool2o`0000?ooooo1?l00006ooooo`?o0000
1_oooolSo`0000Sooooo1?l00007ooooo`;o00000_ooool2o`0000Oooooo1?l0000Aooooo`;o0000
1_ooool2o`0000oooooo0ol000000ooooooo0000o`000003o`0004[ooooo000Looooo`03o`000?oo
oooooooo06;ooooo0ol0000;ooooo`Oo00001Oooool3o`0000Sooooo3_l000000ooooooo0000o`00
000:o`000004ooooool0003o0000o`0000_ooooo1_l000001?oooooo0000o`000?l0000<ooooo`Co
00005oooool5o`0000_ooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l0
00000_l00019ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool2o`00
0003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0H_ooool4o`0000[ooooo0_l000000ooo
oooo0000o`000002o`0000Gooooo0_l00004ooooo`;o000000?oooooo`000?l000007_l0000>oooo
o`Co000000Coooooo`000?l0003o00002_ooool6o`0001;ooooo0_l00003ooooo`?o00001oooool2
o`0000Cooooo0_l000000ooooooo0000o`000004o`000003ooooool0003o000000;o0000BOooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1Rooooo`Go00001?ooool2o`0000kooooo0ol00004ooooob7o00004_oo
ool2o`0000gooooo1?l0000=ooooo`Co00000_ooool4o`0000Cooooo0_l000000ooooooo0000o`00
0002ooooo`Co00000_ooool3o`0000;ooooo1_l0001>ooooo`0000?ooooooa0@4?ooool00_ooool0
0ol@413oooooooooo`09ooooo`Go00001_ooool00ol0003oooooooooo`1Rooooo`;o000000?ooooo
o`000?l000001?ooool2o`0000kooooo0ol00004oooooako00004?ooool2o`0000;ooooo0ol0000:
ooooo`Oo00003Oooool4o`0000;ooooo1?l00007ooooo`;o00000_ooool4o`0000;ooooo0ol00002
ooooo`;o00000_ooool4o`0004cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`0006Cooooo0_l000000ooooooo0000o`00000:
ooooo`;o00001_ooool3o`0000?ooooo6_l000001?oooooo0000o`000?l0000@ooooo`So00002Ooo
ool5o`0000_ooooo1?l00009ooooo`;o00004Oooool4o`0000Kooooo1?l0001;ooooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o
0000ooooooooool0I?ooool7o`0000Gooooo0_l000000ooooooo0000o`000006ooooo`;o00001?oo
ool7o`000003ooooool0003o0000013o00005?ooool2o`000004ooooool0003o0000ooooo`;o0000
0oooool2o`0000Cooooo1Ol0000;ooooo`Co00000_ooool3o`0001?ooooo2Ol00007ooooo`;o0000
Boooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00omgMgOoc<c<o`00
0007ooooo`03o`000?oooooooooo06Kooooo1Ol00005ooooo`;o00002Oooool2o`0000Cooooo0_l0
00000ooooooo0000o`000002o`0000Oooooo0_l00002ooooo`;o00005oooool2o`0000Gooooo0_l0
00000ooooooo0000o`000002ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Dooooo`?o0000
2oooool3o`0000;ooooo3?l00006ooooo`;o0000C?ooool00006oooooomgMgOoV9RHoooooonHV9So
MgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo06Oooooo1?l0000@ooooo`;o
00001?ooool5o`0002Gooooo1?l00004ooooo`;o000000?oooooo`000?l000000oooool4o`0002Go
oooo4Ol00006ooooo`;o0000C?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omg
MgOo0000ooooo`06ooooo`03o`000?oooooooooo06Wooooo0_l0000;ooooo`;o00000oooool4o`00
00?ooooo1?l0000Sooooo`Ko00000oooool2o`0000?ooooo0ol000001?oooooo0000o`000?l0000J
ooooo`;o00001_ooool2o`000003ooooool0003o000001;o00001?ooool2o`0004cooooo000Loooo
o`03o`000?oooooooooo06Wooooo0_l000000ooooooo0000o`000008ooooo`;o00001Oooool2o`00
00?ooooo1?l0000Rooooo`?o00001?ooool2o`000003ooooool0003o000000;ooooo1?l0000Noooo
o`;o00001_ooool2o`000003ooooool0003o000000Oo000000?oooooo`000?l000002?l00002oooo
o`Co0000C?ooool001cooooo00?o0000ooooooooool0J?ooool6o`0000Sooooo0_l00002ooooo`;o
000000?oooooo`000?l000001?ooool4o`00027ooooo0_l00005ooooo`Ko000000Coooooo`000?l0
003o00001Oooool2o`0000Kooooo0_l0000;ooooo`;o00003?ooool<o`000003ooooool0003o0000
00Ko00000oooool3o`0004gooooo000Looooo`03o`000?oooooooooo06Oooooo1Ol00007ooooo`;o
00001Oooool2o`000003ooooool0003o000000Gooooo0ol0000Pooooo`;o00001oooool5o`0000Go
oooo0_l00002ooooo`?o00001Oooool2o`0000_ooooo0_l0000;oooooaKo00000oooool3o`0004go
oooo000Looooo`03o`000?oooooooooo06Oooooo1Ol00007ooooo`;o0000<Oooool3o`0000Oooooo
0ol00007ooooo`;o00000_ooool4o`000004ooooool0003o0000ooooo`;o00001oooool4o`0000Wo
oooo0_l000000ooooooo0000o`00000@o`000003ooooool0003o000000Go0000D?ooool001cooooo
00?o0000ooooooooool0JOooool6o`0000Sooooo0_l0000:ooooo`;o00008Oooool2o`0000?ooooo
0ol00006ooooo`;o00002?ooool4o`000004ooooool0003o0000ooooo`Co00001Oooool6o`0000Oo
oooo0_l000000ooooooo0000o`00000Co`000003ooooool0003o000000?o0000Coooool001cooooo
00?o0000ooooooooool0JOooool6o`0000Cooooo2?l00008ooooo`;o00001?ooool2o`00023ooooo
0ol00006ooooo`;o00000_ooool2o`000003ooooool0003o000000?ooooo0_l00006ooooo`;o0000
2Oooool2o`0000[ooooo5Ol00002ooooo`Co0000Coooool001cooooo00?o0000ooooooooool0J_oo
ool4o`0000Gooooo1?l00002ooooo`?o00001?ooool2o`0000Oooooo0_l0000>ooooo`;o00003?oo
ool2o`0000oooooo0_l000000ooooooo0000o`000003ooooo`;o00004oooool2o`0000Gooooo6?l0
00001?oooooo0000o`000?l0001Aooooo`007?ooool00ol0003oooooooooo`1Zooooo`Co00003?oo
ool3o`0000?ooooo0_l0000=ooooo`;o00002?ooool4o`0000?ooooo0_l00005ooooo`;o0000:Ooo
ool2o`000003ooooool0003o000000Gooooo5ol000000ooooooo0000o`000003o`00053ooooo000L
ooooo`03o`000?oooooooooo07_ooooo0_l00005ooooo`;o00002oooool2o`0000[ooooo0_l00002
ooooo`Co00006Oooool2o`0001Cooooo0_l00006oooooaoo0000D?ooool001cooooo00?o0000oooo
ooooool0P_ooool2o`000003ooooool0003o000000Oooooo0_l00005ooooo`;o00002?ooool4o`00
013ooooo0_l00007ooooo`;o00006_oooolGo`000003ooooool0003o000000Co0000Doooool001co
oooo00?o0000ooooooooool0KOooool3o`000003ooooool0003o000000kooooo0_l00002ooooo`;o
00001oooool2o`0000Gooooo1_l00004ooooo`;o00003_ooool2o`0000;ooooo0_l00005ooooo`;o
00002_ooool2o`00013ooooo0_l00002oooooa[o0000Doooool001cooooo0_l0001^ooooo`?o0000
00?oooooo`000?l000003_ooool3o`0000Oooooo1ol00002ooooo`Oo00004Oooool2o`000003oooo
ool0003o000000Gooooo0_l00002ooooo`;o00002_ooool2o`0001;ooooo1?l00002oooooa?o0000
E_ooool001cooooo00?o0000ooooooooool0K_ooool2o`0001;ooooo0_l00007ooooo`Oo00000_oo
ool7o`00017ooooo0_l00002ooooo`?o00000oooool2o`000004ooooool0003o0000ooooo`;o0000
6?ooool3o`000003ooooool0003o000001;o00000oooool2o`0005Kooooo000Looooo`03o`000?oo
oooooooo06kooooo0_l0000Uooooo`;o00000_ooool2o`0000Kooooo0_l0000=ooooo`?o00001?oo
ool4o`000003ooooool0003o000000Gooooo0_l0000:ooooo`;o000000Goooooo`000?l0003o0000
ooooo`03o`0000?ooooo3_l0001Oooooo`007?ooool00ol0003oooooooooo`1^ooooo`Co00006Ooo
ool2o`0000Sooooo0_l00002ooooo`;o00001?ooool4o`0001Cooooo0_l0000:ooooo`;o00000_oo
ool4o`000003ooooool0003o000000?o000000?oooooo`000?l000000_l000001?oooooo0000o`00
0?ooool@o`0000?ooooo0ol0001Iooooo`007?ooool00ol0003oooooooooo`1_ooooo`?o00001?oo
ool2o`0001?ooooo0_l0000Booooo`;o00006_ooool2o`0000;ooooo0_l00006ooooo`Co000000?o
ooooo`000?l000001?l00002ooooo`;o00001?ooool5o`0000;ooooo0_l00007ooooo`Ko0000FOoo
ool001cooooo00?o0000ooooooooool0Koooool3o`0000Cooooo0_l0000=ooooo`;o00004oooool2
o`0000Kooooo0_l0000Gooooo`;o00000_ooool2o`0000?ooooo0_l00003ooooo`Wo000000?ooooo
o`000?l000000ol00003ooooo`Co00002oooool4o`0005_ooooo000Looooo`03o`000?oooooooooo
077ooooo0_l00002ooooo`;o000000?oooooo`000?l000002oooool2o`0001?ooooo0_l00006oooo
o`;o00005_ooool6o`0000?ooooo0ol000000ooooooo0000o`00000?o`0000;ooooo0_l000000ooo
oooo0000o`000004ooooo`;o00001?ooool4o`0005cooooo000Looooo`03o`000?oooooooooo077o
oooo0_l00002ooooo`;o000000?oooooo`000?l000000ol0000=ooooo`;o00002_ooool2o`0001Go
oooo0_l0000;ooooo`Ko00000oooool2o`0000;ooooo1Ol000000ooooooo0000o`000009o`0000;o
oooo0_l000000ooooooo0000o`000002ooooo`Co00001?ooool2o`0005kooooo000Looooo`03o`00
0?oooooooooo077ooooo0_l00005ooooo`Go00002Oooool2o`0000;ooooo0_l0000:ooooo`;o0000
5Oooool2o`0000_ooooo0_l00007oooooa3o000000?oooooo`000?l000000_l00002ooooo`;o0000
0_ooool2o`000003ooooool0003o000006Kooooo000Looooo`03o`000?oooooooooo077ooooo0ol0
0005ooooo`;o00000_ooool2o`0000Oooooo0_l00004ooooo`?o00009oooool2o`0000;ooooo1?l0
0006ooooo`oo00001oooool3o`000003ooooool0003o000000;ooooo0_l0001Uooooo`007?ooool0
0ol0003oooooooooo`1aooooo`Co00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000008
ooooo`Go00004Oooool2o`000003ooooool0003o000000oooooo2_l00005oooooaGo000000?ooooo
o`000?l000001?l00003ooooo`;o0000IOooool001cooooo00?o0000ooooooooool0LOooool4o`00
00_ooooo0_l00008ooooo`;o00005?ooool2o`000003ooooool0003o000000oooooo2?l00003oooo
oaWo000000?oooooo`000?l000001?l0001Zooooo`007?ooool00ol0003oooooooooo`1cooooo`Go
00000oooool2o`0000Sooooo0_l0000Hooooo`;o00005_ooool3o`0000Gooooo5_l00005ooooo`;o
0000KOooool001cooooo00?o0000ooooooooool0Foooool4o`0001Cooooo1Ol00003ooooo`;o0000
00?oooooo`000?l000001Oooool2o`0001Sooooo0_l0000Eooooo`?o00001OoooolHo`0000Cooooo
0_l0001]ooooo`007?ooool00ol0003oooooooooo`1Gooooo`?o000000?oooooo`000?l000001Ol0
00000ooooooo0000o`00000Iooooo`;o00002Oooool2o`00027ooooo0_l00008ooooo`?o00001Ooo
oolHo`0007?ooooo000Looooo`03o`000?oooooooooo05Gooooo3Ol000000ooooooo0000o`00000>
ooooo`?o00001?ooool2o`0000gooooo0_l0000Qooooo`;o00002Oooool2o`0000Gooooo6?l0001c
ooooo`007?ooool2o`0005?ooooo1_l000000ooooooo0000o`000002o`0000?ooooo0ol00002oooo
o`;o00003?ooool4o`0000?ooooo0_l00008ooooo`;o00008Oooool2o`0001Gooooo5Ol0001foooo
o`007?ooool00ol0003oooooooooo`1@ooooo`Oo00000_ooool4o`0000?ooooo1?l000000ooooooo
0000o`000002o`0000[ooooo1?l00005ooooo`;o00001_ooool2o`00027ooooo0_l0000Cooooo`;o
00000ooooolCo`0007Gooooo000Looooo`03o`000?oooooooooo053ooooo0_l00007ooooo`Co0000
0_ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000002_ooool3o`0000Kooooo
0_l0000Qooooo`;o00003?ooool2o`000003ooooool0003o000000[ooooo0_l00002oooooaCo0000
MOooool001cooooo00?o0000ooooooooool0D?ooool3o`0000Kooooo0_l00004ooooo`Oo000000Co
ooooo`000?l0003o00002_ooool2o`0002Kooooo0_l000000ooooooo0000o`00000<ooooo`;o0000
00?oooooo`000?l000002_ooool2o`000003ooooool0003o000001;o0000M_ooool001cooooo00?o
0000ooooooooool0C_ooool5o`0000Wooooo3_l0000:ooooo`;o00000_ooool2o`0000;ooooo0_l0
000Nooooo`;o00008OoooolBo`0007Sooooo000Looooo`03o`000?oooooooooo04cooooo1Ol00007
oooooaCo00002?ooool2o`000004ooooool0003o0000o`0000;ooooo0_l0000;ooooo`;o00005_oo
ool2o`000003ooooool0003o000001Sooooo4ol0001hooooo`007?ooool00ol0003oooooooooo`1;
ooooo`Ko00001OoooolFo`0000_ooooo0_l00003ooooo`;o00002oooool2o`0001Kooooo0_l00000
0ooooooo0000o`00000:ooooo`Co00001oooool2o`000003ooooool0003o0000017o0000N?ooool0
01cooooo00?o0000ooooooooool0B_ooool8o`0000Cooooo5?l00009ooooo`?o00001_ooool2o`00
03;ooooo1?l00007ooooo`?o00000_ooool?o`0007[ooooo000Looooo`03o`000?oooooooooo04[o
oooo2?l00004oooooaKo00001oooool3o`0000Gooooo0_l00005ooooo`;o00001oooool2o`0001So
oooo0_l00003ooooo`;o00000_ooool4o`0000[ooooo0_l00003ooooo`ko0000N_ooool001cooooo
00?o0000ooooooooool0COooool5o`0000Cooooo2Ol000000ooooooo0000o`00000:o`0000Oooooo
0ol00005ooooo`;o00001Oooool2o`0000Oooooo0_l0000Hooooo`;o00000oooool2o`0000;ooooo
0_l000000ooooooo0000o`000003o`0000cooooo3?l0001kooooo`007?ooool00ol0003ooooooooo
o`1=ooooo`;o00001?ooool<o`000003ooooool0003o000000[o00001oooool4o`0000Cooooo1?l0
0007ooooo`;o00007Oooool3o`0000Wooooo1Ol00008ooooo`Co00000_ooool6o`0000;ooooo0ol0
001jooooo`007?ooool00ol0003oooooooooo`19ooooo`Ko00000_oooolKo`0000Sooooo0ol00004
ooooo`Co00001oooool2o`0001gooooo0ol00008ooooo`Co00002_ooool4o`0000;ooooo1Ol00004
ooooo`;o0000N_ooool001cooooo00?o0000ooooooooool0BOooool6o`0000;ooooo0_l00002oooo
oaSo00001oooool2o`0000Sooooo0_l0000]ooooo`;o000000?oooooo`000?l000000_l0000;oooo
o`?o00002Oooool2o`0007cooooo000Looooo`03o`000?oooooooooo04Kooooo1_l00007oooooa[o
00001oooool4o`0000Kooooo0_l0000/ooooo`?o00000oooool2o`0000_ooooo0ol00005ooooo`;o
00000_ooool2o`0007cooooo000Looooo`03o`000?oooooooooo04Kooooo1?l00009oooooa[o0000
1oooool4o`0000?ooooo0_l0000_ooooo`;o00001?ooool2o`0000_ooooo0_l00003ooooo`;o0000
00?oooooo`000?l00000P?ooool001cooooo00?o0000ooooooooool0Aoooool2o`0000?ooooo0_l0
0007oooooaSo00001oooool2o`0000Gooooo0_l0000Cooooo`;o00001?ooool2o`0001[ooooo0_l0
0002ooooo`Co00002?ooool6o`00087ooooo000Looooo`;o0000A_ooool2o`0000Cooooo0ol00000
0ooooooo0000o`000004oooooaSo00001_ooool3o`0001[ooooo0_l00004ooooo`;o00007_ooool4
o`0000Sooooo0_l00002ooooo`;o0000POooool001cooooo00?o0000ooooooooool0A?ooool3o`00
00;ooooo1?l00002ooooo`?o00000oooool4o`000003ooooool0003o000000oo00002?ooool3o`00
02?ooooo0_l0000Eooooo`;o00000_ooool2o`0009?ooooo000Looooo`03o`000?oooooooooo04Co
oooo0_l00003ooooo`;o00001Oooool2o`0000?ooooo5ol00007ooooo`?o00008oooool4o`0000Go
oooo0_l0000<ooooo`;o00000_ooool2o`0000cooooo1Ol00022ooooo`007?ooool00ol0003ooooo
ooooo`15ooooo`;o00000_ooool2o`0000cooooo4Ol000001?oooooo0000o`000?l00007ooooo`;o
00000_ooool2o`0001gooooo0_l00003ooooo`;o00001Oooool2o`0000Gooooo0_l0000Gooooo`Go
0000Boooool2o`0003Gooooo000Looooo`03o`000?oooooooooo04?ooooo1?l000000ooooooo0000
o`000003o`0000;ooooo0_l00005oooooaGo00003?ooool2o`0000?ooooo0_l0000Hooooo`;o0000
4Oooool4o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l00000E_ooool2o`000003oooo
ool0003o000003Gooooo000Looooo`03o`000?oooooooooo04?ooooo0_l00003ooooo`Go00000_oo
ool2o`0000Cooooo5_l00008ooooo`?o00001_ooool2o`0001Oooooo0_l0000Dooooo`;o00000_oo
ool2o`0000?ooooo0_l000001?oooooo0000o`000?l0001Eooooo`;o0000>?ooool001cooooo00?o
0000ooooooooool0@oooool5o`0000Oooooo0_l00004ooooo`;o000000?oooooo`000?l000004Ol0
0007ooooo`Co00007oooool2o`0001Sooooo0_l000000ooooooo0000o`000003ooooo`?o00004_oo
ool2o`0004;ooooo0_l0000gooooo`007?ooool00ol0003oooooooooo`14ooooo`Ko00003_ooool7
o`000003ooooool0003o000000Wo00001oooool3o`0000Cooooo0_l0000fooooo`?o00002?ooool2
o`0000[ooooo0_l000001?oooooo0000o`000?l0000mooooo`;o00000oooool4o`0003Gooooo000L
ooooo`03o`000?oooooooooo04Cooooo0_l000001?oooooo0000o`000?l0000>ooooo`Ko000000?o
ooooo`000?l000002?l00008ooooo`Go00000oooool2o`0000;ooooo0_l0000Pooooo`;o00000ooo
ool2o`0000_ooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool2o`0000[ooooo1Ol0
000nooooo`?o00001?ooool2o`0003Gooooo000Looooo`03o`000?oooooooooo04Cooooo0ol0000A
oooooa3o00002Oooool5o`0000Oooooo0_l0000Pooooo`;o00000oooool2o`0000kooooo0_l00002
ooooo`;o00003oooool4o`0000;ooooo0_l0000kooooo`;o0000>oooool001cooooo00?o0000oooo
ooooool0A?ooool3o`0000Oooooo0_l00009ooooo`go00002Oooool3o`0001oooooo0_l00008oooo
o`;o00008oooool2o`0000Sooooo0ol00002ooooo`;o0000N?ooool001cooooo00?o0000oooooooo
ool0A?ooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`00000;ooooo`[o
00002_ooool4o`0001kooooo0_l00008ooooo`;o00000oooool2o`0000;ooooo0_l0000:ooooo`;o
00003_ooool2o`0000Sooooo0_l00004ooooo`;o0000=Oooool3o`0003oooooo000Looooo`03o`00
0?oooooooooo04Cooooo0_l000000ooooooo0000o`000002ooooo`?o00001?ooool3o`0000?ooooo
0_l000000ooooooo0000o`000002o`0000;ooooo1?l0000;ooooo`?o00001Oooool2o`0001[ooooo
0_l00005ooooo`;o00000oooool2o`0000;ooooo1?l00008ooooo`;o00003_ooool2o`0000;ooooo
0_l0000:ooooo`;o0000=Oooool3o`0000Cooooo0ol0000hooooo`007?ooool00ol0003ooooooooo
o`11ooooo`Co00001?ooool5o`000004ooooool0003o0000ooooo`?o000000?oooooo`000?l00000
0_l00002ooooo`Co000000?oooooo`000?l000002oooool6o`0000Cooooo0_l00008ooooo`;o0000
3?ooool2o`000004ooooool0003o0000o`0000[ooooo0_l00004ooooo`;o00006?ooool6o`0000Go
oooo0_l0000mooooo`;o00000_ooool3o`0003Sooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^
kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`11
ooooo`Co00001?ooool2o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o00001?ooool6
o`0000;ooooo2?l00002ooooo`Ko00003_ooool2o`0000cooooo0_l000000ooooooo0000o`000007
ooooo`;o00000_ooool2o`0000Gooooo0_l0000Gooooo`Wo00000_ooool4o`000003ooooool0003o
000000;o0000=_ooool2o`0000;ooooo0_l0000iooooo`0000KoooooogMgMonHV9SooooooiRHV?mg
MgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0
@Oooool5o`0000?ooooo0_l00007ooooo`;o00002?oooolBo`000003ooooool0003o000001Cooooo
0_l00009ooooo`;o000000?oooooo`000?l000001oooool2o`0000Wooooo0ol0000Fooooo`Wo0000
0oooool3o`000003ooooool0003o000000;o0000>_ooool2o`0003Wooooo00000ooooooo410@oooo
o`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo047ooooo1Ol00003ooooo`;o00001Oooool4o`0000Sooooo0_l00002ooooo`[o0000
0_ooool2o`0001Oooooo0_l0000<ooooo`;o00004oooool2o`0001Kooooo1?l000001?oooooo0000
o`000?l00002ooooo`;o00000_ooool5o`0003[ooooo0ol0000iooooo`0000?oooooo`000?ooool0
0_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0004?o
oooo0_l0000;ooooo`;o00004_ooool6o`0000Kooooo0_l0001>ooooo`;o00000oooool7o`0000;o
oooo1?l0000kooooo`?o0000>Oooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
2Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0@oooool5o`0000Go
oooo0_l00002ooooo`?o00000_ooool2o`0000Oooooo0_l0000?ooooo`;o00002?ooool2o`0001co
oooo0_l00005ooooo`;o00000_ooool2o`0001[ooooo1_l000000ooooooo0000o`000002o`0007oo
oooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qoooool0
2?ooool00ol0003oooooooooo`13ooooo`Go00001Oooool2o`0000;ooooo0ol00002ooooo`;o0000
1oooool4o`0000oooooo0_l00006ooooo`;o00004?ooool3o`0000Wooooo0_l00005ooooo`;o0000
0_ooool2o`0000;ooooo0_l00002ooooo`;o00004Oooool7o`000004ooooool0003o0000o`0003oo
oooo0_l00002ooooo`;o0000>oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool00ooM
gMgo410@oiRHV008ooooo`03o`000?oooooooooo04?ooooo0_l00008ooooo`;o00002?ooool2o`00
00Cooooo0_l00002ooooo`;o00003oooool2o`000003ooooool0003o000000gooooo0_l00003oooo
o`;o000000Coooooo`000?l0003o00003Oooool2o`0000Oooooo1?l00002ooooo`;o00004Oooool5
o`000003ooooool0003o000000Co0000?_ooool2o`0000;ooooo0_l0000kooooo`0000Koooooonk^
k_lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0
AOooool4o`0000[ooooo0_l00002ooooo`;o00001?ooool2o`0001Kooooo0_l0000=ooooo`;o0000
0_ooool3o`0000cooooo0_l00003ooooo`;o00001oooool3o`0001Cooooo3_l0000nooooo`;o0000
?oooool001cooooo00?o0000ooooooooool0@_ooool2o`000003ooooool0003o000000;o00001_oo
ool2o`0000;ooooo0_l0000=ooooo`;o00004?ooool2o`0000;ooooo0_l0000>ooooo`?o00001Ooo
ool2o`0000Gooooo0_l00006ooooo`?o00001?ooool2o`0001Cooooo3_l0000fooooo`;o00002?oo
ool2o`0003gooooo000Looooo`03o`000?oooooooooo04;ooooo0_l00003ooooo`;o000000?ooooo
o`000?l000000_ooool3o`0000;ooooo0_l00002ooooo`;o00002?ooool3o`0000Wooooo0_l00005
ooooo`;o00000_ooool2o`0000?ooooo0ol00003ooooo`;o00000oooool3o`0000Gooooo0_l0000=
ooooo`?o00002oooool2o`0000_ooooo1?l00002ooooo`_o000000?oooooo`000?l00000<_ooool2
o`0000Oooooo0ol0000mooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00001?ooool7o`00
00Kooooo0_l00007ooooo`?o00002_ooool2o`0000kooooo0ol00003ooooo`;o00000oooool2o`00
017ooooo0_l0000@ooooo`;o00002_oooolBo`000003ooooool0003o0000033ooooo0_l00009oooo
o`;o0000?_ooool001cooooo00?o0000ooooooooool0@_ooool4o`0000Kooooo0_l000000ooooooo
0000o`000002o`0000gooooo0_l000000ooooooo0000o`000002o`0000Oooooo0_l000001?oooooo
0000o`000?ooool2o`0000;ooooo0_l00008ooooo`?o00005_ooool2o`0000Kooooo0ol00003oooo
o`;o00003_oooolCo`0003;ooooo0_l00003ooooo`;o000000Coooooo`000?l0003o0000@?ooool0
01cooooo00?o0000ooooooooool0@_ooool2o`0000_ooooo1?l0000@ooooo`Co00001oooool2o`00
0004ooooool0003o0000ooooo`;o000000Coooooo`000?l0003o00002?ooool2o`0000Cooooo0ol0
0006ooooo`;o00001Oooool2o`0000Wooooo0ol00002ooooo`?o00003ooooolBo`0003;ooooo0_l0
00000ooooooo0000o`000002o`000004ooooool0003o0000o`00043ooooo000Looooo`03o`000?oo
oooooooo04;ooooo0_l000000ooooooo0000o`00000>ooooo`;o00001oooool2o`0000?ooooo0_l0
0005ooooo`;o00001?ooool4o`0000?ooooo0_l0000?ooooo`?o00001_ooool2o`0000Gooooo0_l0
0006ooooo`;o00000_ooool2o`0000;ooooo0ol0000?oooooa;o0000<_ooool2o`000003ooooool0
003o000000;o0000A?ooool001cooooo00?o0000ooooooooool0@_ooool2o`000003ooooool0003o
000000kooooo0_l00007ooooo`;o00000oooool2o`0000Cooooo1?l00003ooooo`Co00007?ooool2
o`0000kooooo0_l00002ooooo`;o00000oooool2o`0000kooooo5?l0000Vooooo`?o00003?ooool2
o`0004Gooooo000Looooo`03o`000?oooooooooo04;ooooo0ol000000ooooooo0000o`00000:oooo
o`;o000000?oooooo`000?l000003?ooool2o`0000Cooooo1?l0000Sooooo`;o00000_ooool2o`00
0003ooooool0003o000000_ooooo1ol0000>oooooaCo00009Oooool4o`0000cooooo0_l000000ooo
oooo0000o`000012ooooo`007?ooool00ol0003oooooooooo`13ooooo`Go000000?oooooo`000?l0
00001oooool4o`0000Oooooo0_l00002ooooo`Co0000;oooool2o`000003ooooool0003o000000;o
oooo0_l00008ooooo`Co00004?oooolDo`0002Gooooo0_l00006ooooo`?o00002?ooool2o`0004;o
oooo000Looooo`03o`000?oooooooooo04?ooooo1?l00002ooooo`;o00002Oooool5o`0000Cooooo
0_l00002ooooo`;o00007Oooool:o`0000cooooo0_l00003ooooo`;o00007?oooolDo`00027ooooo
0_l00002ooooo`;o00001_ooool3o`0004cooooo000Looooo`03o`000?oooooooooo04Cooooo0ol0
000=ooooo`Go00001_ooool2o`0001cooooo4Ol00008ooooo`;o00001?ooool2o`0001[ooooo5Ol0
000Qooooo`;o00002?ooool2o`0004oooooo000Looooo`;o0000A_ooool3o`000003ooooool0003o
000000Gooooo1?l00002ooooo`;o00001_ooool3o`0001[ooooo1Ol00006ooooo`[o00002?ooool6
o`0000Wooooo0_l0000?oooooaGo0000:oooool3o`0004kooooo000Looooo`03o`000?oooooooooo
04Gooooo1_l00004ooooo`Go00002?ooool4o`0001Wooooo1_l0000>ooooo`Co00001oooool4o`00
00_ooooo0_l0000?oooooaGo0000:Oooool2o`000003ooooool0003o000004kooooo000Looooo`03
o`000?oooooooooo04Oooooo0ol000000ooooooo0000o`000002ooooo`;o00002Oooool4o`0001[o
oooo2?l0000>ooooo`Go00005Oooool2o`0000kooooo5Ol0000:ooooo`;o00006?ooool2o`0000?o
oooo0_l000000ooooooo0000o`000005ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0
Aoooool7o`0000_ooooo1Ol0000Iooooo`Co00000_ooool6o`0000_ooooo1_l0000Dooooo`;o0000
3_oooolFo`0000Gooooo0ol000000ooooooo0000o`00000=ooooo`;o00002Oooool2o`0000;ooooo
0_l00009ooooo`?o0000A_ooool001cooooo00?o0000ooooooooool0BOooool6o`0000[ooooo0ol0
000Jooooo`Go00000_ooool2o`000004ooooool0003o0000o`0000?ooooo2?l00002ooooo`Co0000
4Oooool2o`00017ooooo4_l000001?oooooo0000o`000?l00005ooooo`?o00001?ooool2o`0000[o
oooo0_l00002ooooo`;o00002Oooool2o`000004ooooool0003o0000o`0000Cooooo1?l00016oooo
o`007?ooool00ol0003oooooooooo`19ooooo`;o000000Coooooo`000?l0003o00009Oooool5o`00
00Cooooo0_l00004ooooo`;o000000?oooooo`000?l000003Ol0000@ooooo`;o00004Oooool;o`00
0003ooooool0003o000000Oo00001Oooool2o`0000Kooooo0_l00004ooooo`;o000000Coooooo`00
0?l0003ooooo0_l00002ooooo`;o00002Oooool2o`000004ooooool0003o0000o`0000?ooooo0ol0
0018ooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o000000?oooooo`000?l000009?ooool4
o`0000Gooooo0_l00004ooooo`;o000000?oooooo`000?l000003_l0000Booooo`;o00003ooooolD
o`000005ooooool0003o0000o`000?ooool00_l00002ooooo`Co00001_ooool2o`000003ooooool0
003o000000?o00003Oooool3o`0000;ooooo0_l00002ooooo`?o0000B?ooool001cooooo00?o0000
ooooooooool0Boooool5o`0000Gooooo0ol0000Looooo`;o00003Oooool?o`000004ooooool0003o
0000o`0001;ooooo0_l0000>oooooaGo000000Coooooo`000?l0003o00001Oooool4o`0000Kooooo
0_l00002ooooo`Co00001_ooool2o`0000Kooooo0_l00002ooooo`;o00000oooool2o`0004Sooooo
000Looooo`03o`000?oooooooooo04cooooo1?l000000ooooooo0000o`000005o`0001_ooooo1Ol0
000;oooooa?o00008_oooolEo`000004ooooool0003o0000o`0000Sooooo0ol00002ooooo`;o0000
2?ooool2o`0000Cooooo0ol00004ooooo`Co000000?oooooo`000?l00000COooool001cooooo00?o
0000ooooooooool0C_ooool:o`0001_ooooo1Ol00005ooooo`?o00001?oooolCo`0002;ooooo5?l0
00000ooooooo0000o`000009ooooo`?o00000_ooool2o`0000;ooooo0_l00002ooooo`Co00000ooo
ool4o`0000Cooooo1?l000000ooooooo0000o`00001=ooooo`007?ooool00ol0003oooooooooo`1>
ooooo`Wo00007?ooool3o`0000Oooooo0ol00003oooooaCo00008_oooolDo`0000cooooo0_l00003
ooooo`;o00000_ooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2
o`000003ooooool0003o000005?ooooo000Looooo`03o`000?oooooooooo077ooooo1Ol0000=oooo
oa;o00009?ooool4o`000003ooooool0003o000000co00001?ooool2o`0000?ooooo0_l0000Coooo
o`;o00001Oooool2o`000003ooooool0003o000005?ooooo000Looooo`03o`000?oooooooooo077o
oooo1_l0000<oooooa;o00004Oooool3o`00013ooooo1?l00002ooooo`co00000_ooool2o`000003
ooooool0003o000000?ooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00003ooooo`;o
000000?oooooo`000?l00000Coooool001cooooo00?o0000ooooooooool0MOooool4o`0000[ooooo
4_l0000Aooooo`?o00004Oooool4o`0000?ooooo2_l00002ooooo`;o00001oooool2o`0000Kooooo
0_l00004ooooo`;o000000?oooooo`000?l000001oooool7o`000003ooooool0003o000004oooooo
000Looooo`03o`000?oooooooooo07Kooooo0ol0000:oooooa?o00009_ooool2o`0000?ooooo2ol0
0007ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00004ooooo`;o00000ooo
ool2o`0000Oooooo1ol0001@ooooo`007?ooool00ol0003oooooooooo`1aooooo`?o00000_ooool2
o`000003ooooool0003o000000?ooooo0_l00003oooooa?o00003oooool2o`0001Kooooo1?l00003
ooooo`So00001oooool2o`0000Gooooo0_l0000=ooooo`;o000000Goooooo`000?l0003o0000oooo
o`02o`0000?ooooo1?l0001@ooooo`007?ooool2o`0007;ooooo0ol00002ooooo`;o000000?ooooo
o`000?l000000oooool2o`0000Cooooo4_l0000?ooooo`;o00005_ooool5o`0000;ooooo0_l00002
ooooo`?o00002_ooool2o`0000Kooooo0_l0000=ooooo`?o000000?oooooo`000?l000000oooool2
o`0005;ooooo000Looooo`03o`000?oooooooooo07;ooooo0_l00002ooooo`;o000000?oooooo`00
0?l000002?oooolCo`0000cooooo0_l000000ooooooo0000o`00000Gooooo`Ko00002?ooool2o`00
00Oooooo0_l00006ooooo`;o00000_ooool9o`0000;ooooo1?l0001Iooooo`007?ooool00ol0003o
ooooooooo`1booooo`?o000000?oooooo`000?l000002ooooolCo`0000cooooo0_l0000Looooo`Ko
00001_ooool2o`0000Sooooo0ol00008ooooo`Wo00000_ooool4o`000004ooooool0003o0000o`00
05Gooooo000Looooo`03o`000?oooooooooo07;ooooo0ol00005ooooo`Ko00000ooooolCo`0000_o
oooo0_l000000ooooooo0000o`00000Looooo`Ko00001oooool2o`0000;ooooo1_l0000=ooooo`;o
00002Oooool3o`0005Gooooo000Looooo`03o`000?oooooooooo07;ooooo0ol00003ooooo`So0000
1?oooolBo`0000[ooooo0ol000000ooooooo0000o`00000Nooooo`So00000oooool2o`0000;ooooo
2?l0000Booooo`Go0000Eoooool001cooooo00?o0000ooooooooool0L_ooool4o`0000;ooooo0_l0
0003ooooo`;o00001OoooolBo`0000[ooooo0_l000000ooooooo0000o`00000Oooooo`go00002?oo
ool2o`0001;ooooo1Ol0001Gooooo`007?ooool00ol0003oooooooooo`1cooooo`?o00001oooool2
o`0000Kooooo3?l000000ooooooo0000o`000002o`0000gooooo0_l0000Rooooo`[o00004_ooool2
o`0000Kooooo1?l0001Jooooo`007?ooool00ol0003oooooooooo`1dooooo`;o00000oooool2o`00
00[ooooo4?l0000:ooooo`;o00009oooool<o`000004ooooool0003o0000o`0000[ooooo0ol00006
ooooo`;o0000G?ooool001cooooo00?o0000ooooooooool0M?ooool2o`0000?ooooo0_l00004oooo
o`Co000000?oooooo`000?l000003ol0000:ooooo`Co0000:?ooool@o`0000Gooooo1Ol00002oooo
o`;o00000_ooool2o`0005cooooo000Looooo`03o`000?oooooooooo07Cooooo0_l00009ooooo`Co
000000?oooooo`000?l000003ol00007ooooo`;o000000?oooooo`000?l000000_l0000Zooooo`ko
00001Oooool5o`0000;ooooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`1dooooo`;o0000
3oooool>o`0000Wooooo0_l000000ooooooo0000o`00000_ooooo`So00001Oooool2o`0000;ooooo
0_l0001Vooooo`007?ooool00ol0003oooooooooo`1dooooo`;o000000?oooooo`000?l000003_oo
ool;o`0000[ooooo1?l0000aooooo`ko00000_ooool2o`0006Kooooo000Looooo`03o`000?oooooo
oooo07Gooooo1?l0000<ooooo`Oo00001?ooool2o`0000[ooooo1?l0000dooooo`oo0000I_ooool0
01cooooo00?o0000ooooooooool0MOooool2o`000003ooooool0003o000000_ooooo0_l000000ooo
oooo0000o`000004o`0000_ooooo1Ol0000jooooo`_o0000I_ooool001cooooo00?o0000oooooooo
ool0M_ooool8o`0000[ooooo2?l00009ooooo`Co0000[?ooool001cooooo00?o0000ooooooooool0
M_ooool9o`0000;ooooo0_l00005ooooo`?o00000_ooool>o`0000;ooooo0_l0002Zooooo`007?oo
ool2o`0007Wooooo0_l00003ooooo`;o00000_ooool2o`0000Kooooo0_l00002ooooo`co000000Co
ooooo`000?l0003ooooo0_l0002Zooooo`007?ooool00ol0003oooooooooo`1looooo`;o00004ooo
ool2o`0000;ooooo1ol0002]ooooo`007?ooool00ol0003oooooooooo`1iooooo`;o000000?ooooo
o`000?l000003Oooool2o`0000;ooooo0_l00003ooooo`So0000[Oooool001cooooo00?o0000oooo
ooooool0NOooool2o`0000Sooooo0_l00006ooooo`Ko00000oooool6o`000:oooooo000Looooo`03
o`000?oooooooooo07Wooooo0_l00003ooooo`;o00000oooool2o`0000Oooooo1Ol00004ooooo`Go
0000[oooool001cooooo00?o0000ooooooooool0NOooool2o`0000?ooooo0_l00004ooooo`?o0000
1oooool3o`0000Cooooo0_l0002booooo`007?ooool00ol0003oooooooooo`1nooooo`;o00000_oo
ool5o`000<;ooooo000Looooo`03o`000?oooooooooo07kooooo0_l00002ooooo`;o000000?ooooo
o`000?l00000`_ooool001cooooo00?o0000ooooooooool0OOooool3o`0000Cooooo0_l00033oooo
o`007?ooool00ol0003oooooooooo`1mooooo`;o00001Oooool2o`000<?ooooo000Looooo`03o`00
0?oooooooooo07gooooo0ol00039ooooo`007?ooool00ol0003oooooooooo`1nooooo`;o00000ooo
ool6o`000<3ooooo000Looooo`03o`000?oooooooooo07oooooo0_l00002ooooo`Ko00001?ooool2
o`000;[ooooo000Looooo`03o`000?oooooooooo07oooooo0_l0000;ooooo`?o0000^_ooool00006
ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<
c006ooooo`03o`000?oooooooooo08cooooo0_l000000ooooooo0000o`00002hooooo`0000Kooooo
ogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Ko
oooo00?o0000ooooooooool0P_ooool3o`0000[ooooo0ol0002gooooo`0000?ooooooa0@4?ooool0
0_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`22ooooo`?o00001?ooool2o`0000;ooooo1Ol0002gooooo`0000?oooooo`000?ooool0
0_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`0008Wo
oooo0_l00002ooooo`?o0000^Oooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
2Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0ROooool4o`000;co
oooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go410@okZj^_oooooo
^[Zjoa0@4006ooooo`03o`000?oooooooooo08Sooooo1Ol000000ooooooo0000o`000004ooooo`;o
0000/oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o
000000Kooooo00?o0000ooooooooool0R?ooool4o`0000;ooooo0_l00004ooooo`;o000000?ooooo
o`000?l00000/?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`00
0?l@413oZJVY00Kooooo00?o0000ooooooooool0ROooool3o`0000Gooooo1?l00002ooooo`;o0000
00?oooooo`000?l00000[Oooool001cooooo00?o0000ooooooooool0T?ooool5o`0000Gooooo1Ol0
002Zooooo`007?ooool00ol0003oooooooooo`2>ooooo`Co00002_ooool3o`000:[ooooo000Loooo
o`03o`000?oooooooooo08kooooo0_l00007ooooo`Co00001?ooool2o`000:Sooooo000Looooo`03
o`000?oooooooooo09Oooooo1?l00004ooooo`;o0000Z?ooool001cooooo00?o0000ooooooooool0
UOooool2o`000;;ooooo000Looooo`03o`000?oooooooooo09Gooooo0_l0002booooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`004_ooool4o`000003oa0@4?oooooooooo
00?ooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool3o`000?oooooo
B_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3o
oooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000oooooooo
ool0oooooomBooooo`004_ooool00omEEEGoIVIVo`00003ooooooeCooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo002Uooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@oooo
ooooool05_ooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000002Olb<S;ogMgMoooooooo
ooook^k^oc8b<_l0003o<S8bonk^kP2@ooooo`00Y_ooool01Ol0003ooooooooooooooooo000000Wo
oooo1_l0000<ooooo`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9So
oooooiRHV?mgMgL0T?ooool00:Kooooo00Go0000ooooooooooooooooo`00000Kooooo`03o`000?oo
oooooooo00Oooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`2>ooooo`00Y_oo
ool01Ol0003ooooooooooooooooo000000Wooooo1_l0000<ooooo`03o`000?oooooooooo00Kooooo
00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo08kooooo002Vooooo`05o`00
0?n7QhOoooooojVYZOl000006oooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`00_ooool01Ol0003ooooooooooooooooo0000093ooooo002Uooooo`03oa0@4?l0003oMgMg
00;o000000?oV9RHooooooooool06Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00Go410@oooooooooooooooooa0@402@ooooo`00a_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`2@ooooo`00a?ooool00omE
EEGoIVIVo`000005ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^093ooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(156) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.33471 .53093 Mdot
.3108 .51242 Mdot
.58825 .69365 Mdot
.52223 .38924 Mdot
.73589 .44158 Mdot
.57694 .68641 Mdot
.42869 .69057 Mdot
.41344 .70819 Mdot
.6115 .64632 Mdot
.45463 .44215 Mdot
.40876 .66705 Mdot
.44355 .37861 Mdot
.41898 .69668 Mdot
.48242 .35476 Mdot
.59568 .36826 Mdot
.39755 .30151 Mdot
.28301 .52372 Mdot
.70016 .4616 Mdot
.39944 .29503 Mdot
.61301 .64079 Mdot
.79002 .46073 Mdot
.48119 .36915 Mdot
.29368 .55227 Mdot
.48425 .35518 Mdot
.39284 .29779 Mdot
.3191 .51244 Mdot
.33741 .52225 Mdot
.38029 .28808 Mdot
.47205 .39492 Mdot
.40707 .66129 Mdot
.37206 .28006 Mdot
.66419 .36072 Mdot
.63229 .53422 Mdot
.35735 .42511 Mdot
.3932 .71024 Mdot
.39535 .7328 Mdot
.60234 .66334 Mdot
.39052 .68407 Mdot
.44271 .67311 Mdot
.39567 .68717 Mdot
.39386 .68975 Mdot
.31793 .51986 Mdot
.38961 .70876 Mdot
.39389 .78957 Mdot
.50208 .35859 Mdot
.31596 .32291 Mdot
.60417 .60258 Mdot
.5104 .40223 Mdot
.28533 .55168 Mdot
.57115 .71852 Mdot
.63838 .41526 Mdot
.40116 .69729 Mdot
.62444 .51602 Mdot
.28918 .29502 Mdot
.42272 .70122 Mdot
.3957 .29594 Mdot
.56528 .67051 Mdot
.50659 .37714 Mdot
.51583 .40469 Mdot
.351 .40702 Mdot
.50301 .38633 Mdot
.74503 .44739 Mdot
.25613 .48268 Mdot
.57579 .70564 Mdot
.61143 .67164 Mdot
.38644 .69144 Mdot
.29081 .49941 Mdot
.42471 .71427 Mdot
.52121 .39262 Mdot
.6063 .62172 Mdot
.45299 .37696 Mdot
.4077 .66761 Mdot
.30939 .48968 Mdot
.46708 .36712 Mdot
.32496 .54861 Mdot
.45288 .6735 Mdot
.71323 .44997 Mdot
.27274 .56 Mdot
.56121 .70766 Mdot
.49845 .30976 Mdot
.47387 .37207 Mdot
.22931 .6501 Mdot
.58137 .30116 Mdot
.32945 .50385 Mdot
.45451 .34616 Mdot
.19969 .60816 Mdot
.44601 .33562 Mdot
.37193 .29214 Mdot
.38399 .29245 Mdot
.56313 .38015 Mdot
.56207 .66194 Mdot
.29849 .54713 Mdot
.488 .36672 Mdot
.5326 .38559 Mdot
.4374 .43879 Mdot
.4728 .38956 Mdot
.38871 .29411 Mdot
.65088 .50767 Mdot
.40328 .6798 Mdot
.62787 .50063 Mdot
.41436 .63165 Mdot
.63958 .51176 Mdot
.44001 .35566 Mdot
.58949 .66813 Mdot
.33628 .49394 Mdot
.64523 .52011 Mdot
.40908 .72136 Mdot
.48667 .3631 Mdot
.40093 .73914 Mdot
.29834 .55055 Mdot
.38409 .27618 Mdot
.73288 .46244 Mdot
.70701 .50574 Mdot
.30251 .49404 Mdot
.3699 .32995 Mdot
.52279 .36919 Mdot
.48414 .3802 Mdot
.31264 .51553 Mdot
.61612 .64612 Mdot
.49586 .69231 Mdot
.29302 .53081 Mdot
.4056 .67448 Mdot
.28156 .52491 Mdot
.63777 .53386 Mdot
.61547 .65405 Mdot
.59847 .51327 Mdot
.6489 .49942 Mdot
.66196 .38022 Mdot
.49924 .39862 Mdot
.66278 .51005 Mdot
.59306 .66193 Mdot
.29591 .52864 Mdot
.41131 .69396 Mdot
.53674 .37541 Mdot
.32706 .50962 Mdot
.42902 .69918 Mdot
.71287 .48141 Mdot
.71096 .48374 Mdot
.31724 .494 Mdot
.37426 .33778 Mdot
.38507 .70647 Mdot
.44031 .69756 Mdot
.63536 .4151 Mdot
.32575 .49794 Mdot
.76115 .46305 Mdot
.4342 .70167 Mdot
.66159 .69829 Mdot
.39049 .27837 Mdot
.67416 .39341 Mdot
.23909 .65107 Mdot
.63619 .41573 Mdot
.78148 .46973 Mdot
.74889 .45281 Mdot
.42847 .70028 Mdot
.50615 .35 Mdot
.30128 .5037 Mdot
.32454 .50696 Mdot
.4442 .37309 Mdot
.63757 .52776 Mdot
.51821 .3682 Mdot
.63132 .49849 Mdot
.64886 .49747 Mdot
.48872 .35986 Mdot
.32641 .34789 Mdot
.32844 .52845 Mdot
.46843 .33803 Mdot
.6039 .65332 Mdot
.67257 .5164 Mdot
.38676 .71361 Mdot
.45859 .34598 Mdot
.48183 .33549 Mdot
.42829 .36204 Mdot
.44081 .69777 Mdot
.33558 .68095 Mdot
.5515 .69359 Mdot
.42497 .66137 Mdot
.42271 .63227 Mdot
.58427 .65087 Mdot
.52271 .40244 Mdot
.73796 .46377 Mdot
.61106 .51643 Mdot
.48652 .34331 Mdot
.6394 .41636 Mdot
.53385 .40199 Mdot
.73489 .497 Mdot
.74168 .49275 Mdot
.22554 .63471 Mdot
.33824 .6536 Mdot
.52892 .3768 Mdot
.36689 .29938 Mdot
.65601 .4055 Mdot
.46813 .72612 Mdot
.41136 .68875 Mdot
.61097 .61073 Mdot
.61595 .6367 Mdot
.60233 .7399 Mdot
.41287 .38185 Mdot
.42997 .37153 Mdot
.47932 .38352 Mdot
.62813 .50843 Mdot
.26332 .47847 Mdot
.7496 .45182 Mdot
.29177 .50855 Mdot
.23165 .65183 Mdot
.51492 .29232 Mdot
.40254 .2797 Mdot
.6423 .75177 Mdot
.58071 .71324 Mdot
.63965 .51927 Mdot
.7498 .46699 Mdot
.51358 .37803 Mdot
.31879 .54347 Mdot
.64694 .40992 Mdot
.61477 .5358 Mdot
.81267 .38127 Mdot
.28753 .52934 Mdot
.55369 .29412 Mdot
.42426 .69774 Mdot
.57407 .64632 Mdot
.44626 .33564 Mdot
.47279 .35668 Mdot
.26867 .53703 Mdot
.53273 .37365 Mdot
.37839 .26892 Mdot
.38783 .28148 Mdot
.57207 .72024 Mdot
.39373 .62965 Mdot
.43192 .66492 Mdot
.6021 .59905 Mdot
.30641 .49188 Mdot
.31077 .32741 Mdot
.57924 .66803 Mdot
.77022 .48122 Mdot
.40179 .67054 Mdot
.7214 .48194 Mdot
.58203 .6725 Mdot
.73723 .44162 Mdot
.52073 .40425 Mdot
.5922 .64035 Mdot
.72799 .45811 Mdot
.56396 .4062 Mdot
.64582 .51642 Mdot
.76782 .4305 Mdot
.43151 .68769 Mdot
.27483 .54017 Mdot
.4867 .34297 Mdot
.61847 .51483 Mdot
.60319 .53235 Mdot
.57141 .3555 Mdot
.61753 .49018 Mdot
.62173 .53348 Mdot
.56483 .36897 Mdot
.69666 .4688 Mdot
.30814 .61382 Mdot
.37374 .27798 Mdot
.28388 .51966 Mdot
.53194 .37754 Mdot
.3696 .63288 Mdot
.43045 .6988 Mdot
.51188 .38226 Mdot
.2197 .63957 Mdot
.43322 .68435 Mdot
.49749 .37414 Mdot
.43948 .66426 Mdot
.32856 .5074 Mdot
.51732 .28832 Mdot
.31533 .48869 Mdot
.49177 .36124 Mdot
.43733 .66135 Mdot
.60716 .61018 Mdot
.31957 .51014 Mdot
.48488 .36654 Mdot
.49422 .39185 Mdot
.62648 .51043 Mdot
.38907 .28052 Mdot
.43401 .64175 Mdot
.44296 .37716 Mdot
.56286 .69016 Mdot
.46657 .3901 Mdot
.70698 .48632 Mdot
.69209 .69751 Mdot
.32503 .49653 Mdot
.61516 .48996 Mdot
.57405 .67622 Mdot
.55676 .43305 Mdot
.53888 .2852 Mdot
.49694 .35561 Mdot
.61228 .53019 Mdot
.5714 .28321 Mdot
.42679 .67211 Mdot
.38305 .27157 Mdot
.67274 .49817 Mdot
.56501 .67411 Mdot
.63709 .5107 Mdot
.45084 .36649 Mdot
.30098 .55299 Mdot
.39664 .29928 Mdot
.58073 .64757 Mdot
.28384 .53445 Mdot
.44109 .34601 Mdot
.42713 .63541 Mdot
.6459 .48648 Mdot
.42365 .67082 Mdot
.37543 .28662 Mdot
.52352 .4019 Mdot
.6055 .62359 Mdot
.31818 .52246 Mdot
.41894 .70487 Mdot
.31387 .49019 Mdot
.58518 .42889 Mdot
.55976 .29658 Mdot
.31256 .4836 Mdot
.70452 .47549 Mdot
.67234 .76359 Mdot
.41314 .66688 Mdot
.61145 .50214 Mdot
.58349 .6178 Mdot
.29682 .55718 Mdot
.58563 .67522 Mdot
.3791 .34956 Mdot
.56265 .66283 Mdot
.40238 .29412 Mdot
.59753 .61507 Mdot
.42154 .36423 Mdot
.46705 .34173 Mdot
.60026 .70055 Mdot
.65205 .51022 Mdot
.45528 .3637 Mdot
.32718 .51189 Mdot
.65812 .35242 Mdot
.4004 .41218 Mdot
.41266 .37903 Mdot
.56676 .66999 Mdot
.37319 .34775 Mdot
.38278 .28016 Mdot
.37733 .28848 Mdot
.30072 .508 Mdot
.61035 .50483 Mdot
.74136 .48393 Mdot
.76218 .47302 Mdot
.74484 .66632 Mdot
.55197 .25524 Mdot
.36776 .32479 Mdot
.3208 .5026 Mdot
.62805 .75214 Mdot
.34112 .52148 Mdot
.61611 .53547 Mdot
.41292 .70837 Mdot
.33748 .6964 Mdot
.44122 .33722 Mdot
.67319 .48267 Mdot
.37959 .26705 Mdot
.27902 .54298 Mdot
.29385 .49101 Mdot
.41772 .70599 Mdot
.4079 .37332 Mdot
.45441 .44112 Mdot
.52074 .37655 Mdot
.41364 .71068 Mdot
.60703 .53461 Mdot
.55306 .38821 Mdot
.67466 .37321 Mdot
.42001 .81232 Mdot
.49682 .35831 Mdot
.37061 .46749 Mdot
.47903 .34315 Mdot
.66072 .38628 Mdot
.51108 .37385 Mdot
.32149 .51996 Mdot
.35367 .24656 Mdot
.53434 .3597 Mdot
.64653 .75115 Mdot
.51438 .29495 Mdot
.71662 .45822 Mdot
.47873 .35936 Mdot
.51082 .35952 Mdot
.75559 .47166 Mdot
.31046 .53843 Mdot
.51765 .39816 Mdot
.31529 .6133 Mdot
.48622 .36992 Mdot
.38755 .71672 Mdot
.5853 .33093 Mdot
.66146 .36285 Mdot
.38475 .28302 Mdot
.29876 .55343 Mdot
.44163 .68582 Mdot
.39045 .69309 Mdot
.60674 .49736 Mdot
.43101 .69857 Mdot
.47149 .34357 Mdot
.58532 .33225 Mdot
.295 .49474 Mdot
.64279 .51965 Mdot
.29722 .5442 Mdot
.63521 .63866 Mdot
.42854 .68571 Mdot
.63245 .5176 Mdot
.41155 .39397 Mdot
.4213 .67943 Mdot
.45597 .63774 Mdot
.38151 .27554 Mdot
.60558 .53365 Mdot
.33168 .53556 Mdot
.60412 .61939 Mdot
.61307 .53271 Mdot
.42275 .70181 Mdot
.5014 .35766 Mdot
.39511 .29088 Mdot
.4299 .70076 Mdot
.36998 .50503 Mdot
.37524 .27396 Mdot
.48806 .37162 Mdot
.32723 .52366 Mdot
.30156 .53132 Mdot
.47184 .3376 Mdot
.52598 .36713 Mdot
.57005 .68618 Mdot
.60812 .52855 Mdot
.6053 .5267 Mdot
.63966 .4928 Mdot
.56698 .65817 Mdot
.66122 .76462 Mdot
.4244 .71662 Mdot
.65984 .36205 Mdot
.34416 .64961 Mdot
.62012 .51856 Mdot
.5718 .6887 Mdot
.4882 .34802 Mdot
.43526 .36021 Mdot
.43688 .65992 Mdot
.73573 .73291 Mdot
.43549 .33915 Mdot
.28832 .507 Mdot
.40354 .70835 Mdot
.43267 .37099 Mdot
.59919 .7373 Mdot
.73078 .44843 Mdot
.36574 .32442 Mdot
.40384 .70655 Mdot
.35796 .54561 Mdot
.40362 .70565 Mdot
.5081 .35769 Mdot
.45664 .37292 Mdot
.27256 .53391 Mdot
.71538 .45904 Mdot
.44419 .37652 Mdot
.49941 .3708 Mdot
.63486 .75522 Mdot
.34284 .50996 Mdot
.76123 .47429 Mdot
.47756 .3984 Mdot
.64717 .50475 Mdot
.71837 .45115 Mdot
.47087 .37431 Mdot
.45981 .38608 Mdot
.65584 .52312 Mdot
.42836 .65603 Mdot
.7075 .47084 Mdot
.64802 .7523 Mdot
.28656 .52444 Mdot
.44556 .64722 Mdot
.59707 .50276 Mdot
.41138 .66789 Mdot
.52145 .42591 Mdot
.63699 .51782 Mdot
.35866 .75397 Mdot
.703 .21268 Mdot
.62266 .53099 Mdot
.56497 .68721 Mdot
.4295 .43621 Mdot
.45339 .38216 Mdot
.48892 .37172 Mdot
.72602 .48847 Mdot
.30624 .52208 Mdot
.33835 .65417 Mdot
.43022 .66135 Mdot
.47087 .35245 Mdot
.32346 .49327 Mdot
.21534 .62784 Mdot
.63328 .51136 Mdot
.7217 .46804 Mdot
.71606 .47783 Mdot
.46262 .36475 Mdot
.56275 .27002 Mdot
.32096 .50993 Mdot
.48499 .36617 Mdot
.46272 .37027 Mdot
.58074 .62476 Mdot
.33293 .51361 Mdot
.59136 .64186 Mdot
.40098 .27867 Mdot
.37351 .31665 Mdot
.36544 .63521 Mdot
.43528 .6894 Mdot
.60091 .51314 Mdot
.43101 .66521 Mdot
.55083 .66471 Mdot
.60562 .52658 Mdot
.4842 .36591 Mdot
.29474 .49473 Mdot
.48574 .366 Mdot
.48685 .36928 Mdot
.51088 .36583 Mdot
.36302 .32067 Mdot
.56047 .7034 Mdot
.72819 .46946 Mdot
.50081 .40404 Mdot
.57432 .65308 Mdot
.61375 .74158 Mdot
.45367 .44276 Mdot
.47515 .36391 Mdot
.48833 .37945 Mdot
.27612 .56458 Mdot
.39223 .27792 Mdot
.41982 .68212 Mdot
.27253 .5352 Mdot
.44967 .3347 Mdot
.60258 .60096 Mdot
.52139 .39697 Mdot
.31299 .48404 Mdot
.41426 .72191 Mdot
.25524 .47257 Mdot
.59314 .51072 Mdot
.59951 .50832 Mdot
.61696 .53263 Mdot
.63194 .49013 Mdot
.38799 .71444 Mdot
.57355 .69104 Mdot
.61704 .59339 Mdot
.4209 .32201 Mdot
.5269 .36702 Mdot
.45424 .36992 Mdot
.58537 .61863 Mdot
.64853 .52514 Mdot
.39346 .37462 Mdot
.40281 .27357 Mdot
.57962 .63746 Mdot
.65105 .50453 Mdot
.20704 .54913 Mdot
.28918 .54641 Mdot
.55213 .69119 Mdot
.39386 .67829 Mdot
.72612 .45693 Mdot
.81283 .60776 Mdot
.29536 .53972 Mdot
.27033 .4727 Mdot
.59864 .65319 Mdot
.579 .34711 Mdot
.28589 .2851 Mdot
.58485 .67997 Mdot
.3735 .27147 Mdot
.30868 .5004 Mdot
.64836 .5106 Mdot
.5724 .28733 Mdot
.57961 .33722 Mdot
.60506 .63447 Mdot
.49542 .39278 Mdot
.61537 .67756 Mdot
.56402 .68018 Mdot
.60377 .5121 Mdot
.56724 .66934 Mdot
.43039 .6723 Mdot
.58999 .65867 Mdot
.36884 .51053 Mdot
.51243 .39578 Mdot
.28848 .29407 Mdot
.61038 .34988 Mdot
.52412 .36941 Mdot
.41106 .68051 Mdot
.43517 .63895 Mdot
.51474 .38692 Mdot
.75912 .44511 Mdot
.56708 .68918 Mdot
.59032 .73394 Mdot
.39841 .28857 Mdot
.59615 .61654 Mdot
.30224 .55331 Mdot
.41308 .63101 Mdot
.41923 .6317 Mdot
.61333 .53217 Mdot
.32712 .5027 Mdot
.45383 .67367 Mdot
.40509 .67546 Mdot
.65575 .49093 Mdot
.48123 .34036 Mdot
.32157 .53723 Mdot
.55577 .3854 Mdot
.67941 .50201 Mdot
.4848 .37038 Mdot
.59102 .64383 Mdot
.56784 .71667 Mdot
.60282 .36062 Mdot
.57714 .66797 Mdot
.60339 .50864 Mdot
.32751 .52739 Mdot
.39946 .29248 Mdot
.29695 .53101 Mdot
.53353 .38209 Mdot
.3816 .63079 Mdot
.2901 .5485 Mdot
.76965 .48144 Mdot
.50027 .38454 Mdot
.32506 .34342 Mdot
.48956 .40257 Mdot
.48695 .37208 Mdot
.61357 .66737 Mdot
.75633 .47011 Mdot
.68805 .4893 Mdot
.60534 .73694 Mdot
.75255 .44617 Mdot
.32981 .47225 Mdot
.61616 .65382 Mdot
.73671 .47779 Mdot
.74834 .66514 Mdot
.6142 .48951 Mdot
.73104 .47432 Mdot
.45538 .34559 Mdot
.43558 .69499 Mdot
.28067 .51012 Mdot
.45423 .36079 Mdot
.40671 .34274 Mdot
.41186 .30881 Mdot
.62857 .51197 Mdot
.48839 .37461 Mdot
.51197 .35936 Mdot
.3221 .49263 Mdot
.23923 .6534 Mdot
.56776 .69734 Mdot
.6218 .4996 Mdot
.2935 .53648 Mdot
.22823 .64946 Mdot
.60971 .6776 Mdot
.73199 .48248 Mdot
.43934 .67077 Mdot
.35007 .55688 Mdot
.62406 .51386 Mdot
.43027 .68918 Mdot
.5822 .72485 Mdot
.62611 .41993 Mdot
.38516 .30535 Mdot
.59646 .67367 Mdot
.63647 .41595 Mdot
.39685 .27497 Mdot
.6061 .74172 Mdot
.46949 .72409 Mdot
.29844 .54985 Mdot
.42666 .70437 Mdot
.71772 .46787 Mdot
.30671 .48854 Mdot
.29691 .54451 Mdot
.43612 .68776 Mdot
.33071 .25007 Mdot
.56959 .28423 Mdot
.44708 .69435 Mdot
.57418 .35894 Mdot
.62952 .41768 Mdot
.62217 .51195 Mdot
.73366 .46616 Mdot
.39364 .6297 Mdot
.31797 .51912 Mdot
.3393 .68124 Mdot
.64176 .41488 Mdot
.38376 .27289 Mdot
.72918 .45487 Mdot
.21977 .62721 Mdot
.42252 .75084 Mdot
.42271 .6826 Mdot
.63424 .75505 Mdot
.765 .45131 Mdot
.46219 .34235 Mdot
.75217 .7222 Mdot
.4621 .34569 Mdot
.42935 .70829 Mdot
.37972 .2673 Mdot
.29197 .51704 Mdot
.43097 .7102 Mdot
.40356 .27998 Mdot
.44849 .38164 Mdot
.52551 .3799 Mdot
.5601 .70723 Mdot
.27068 .53977 Mdot
.60463 .4881 Mdot
.52185 .36617 Mdot
.50131 .37377 Mdot
.60626 .53584 Mdot
.66145 .36565 Mdot
.50293 .63382 Mdot
.63902 .52939 Mdot
.59081 .63561 Mdot
.64331 .51965 Mdot
.61762 .50107 Mdot
.32223 .54647 Mdot
.62141 .74941 Mdot
.59789 .52332 Mdot
.4944 .36073 Mdot
.49071 .36481 Mdot
.44302 .67471 Mdot
.57136 .28394 Mdot
.57761 .34427 Mdot
.56414 .69315 Mdot
.66509 .49234 Mdot
.47625 .38825 Mdot
.32904 .5049 Mdot
.72579 .48976 Mdot
.60723 .49877 Mdot
.28524 .52257 Mdot
.49875 .39974 Mdot
.58222 .62326 Mdot
.62565 .52897 Mdot
.60446 .53699 Mdot
.73179 .45674 Mdot
.44487 .69229 Mdot
.26937 .55507 Mdot
.56439 .68321 Mdot
.37758 .30096 Mdot
.63631 .47967 Mdot
.57137 .63641 Mdot
.622 .51045 Mdot
.64338 .50977 Mdot
.32613 .50383 Mdot
.36114 .54061 Mdot
.61865 .54395 Mdot
.56879 .65866 Mdot
.39682 .80055 Mdot
.3981 .69215 Mdot
.51663 .40345 Mdot
.43571 .67147 Mdot
.29947 .55041 Mdot
.66375 .37937 Mdot
.72049 .48058 Mdot
.42454 .67942 Mdot
.62315 .53422 Mdot
.29394 .54645 Mdot
.26763 .54201 Mdot
.48984 .35872 Mdot
.4795 .36731 Mdot
.604 .60215 Mdot
.66542 .39826 Mdot
.44183 .66478 Mdot
.7403 .48381 Mdot
.58078 .69653 Mdot
.39652 .29134 Mdot
.29877 .50348 Mdot
.78075 .43042 Mdot
.49884 .40464 Mdot
.57216 .6572 Mdot
.31072 .50954 Mdot
.76076 .47321 Mdot
.72769 .47061 Mdot
.49809 .34765 Mdot
.78041 .47032 Mdot
.42886 .67784 Mdot
.32576 .51322 Mdot
.3109 .4611 Mdot
.50069 .40311 Mdot
.47812 .36366 Mdot
.38758 .27262 Mdot
.44475 .69925 Mdot
.45692 .34524 Mdot
.71456 .46393 Mdot
.30157 .49675 Mdot
.48199 .34545 Mdot
.76743 .45453 Mdot
.61218 .48611 Mdot
.63492 .5216 Mdot
.6047 .69525 Mdot
.77317 .45368 Mdot
.76624 .45903 Mdot
.76765 .45182 Mdot
.33767 .69763 Mdot
.43408 .37115 Mdot
.58261 .50331 Mdot
.49175 .3915 Mdot
.62623 .41869 Mdot
.37593 .30246 Mdot
.40397 .68295 Mdot
.60475 .62466 Mdot
.51692 .37068 Mdot
.49018 .39035 Mdot
.27718 .55586 Mdot
.40015 .30082 Mdot
.46867 .33856 Mdot
.29224 .51177 Mdot
.29903 .46267 Mdot
.61567 .62116 Mdot
.23812 .65012 Mdot
.78747 .68766 Mdot
.54262 .39781 Mdot
.58307 .34383 Mdot
.30731 .54135 Mdot
.44112 .67245 Mdot
.57654 .35579 Mdot
.44271 .69578 Mdot
.30675 .52779 Mdot
.40203 .30272 Mdot
.37022 .50313 Mdot
.74334 .44686 Mdot
.50757 .35777 Mdot
.43595 .68406 Mdot
.51409 .36324 Mdot
.43775 .68128 Mdot
.36982 .35348 Mdot
.57916 .29519 Mdot
.52749 .36567 Mdot
.47269 .38996 Mdot
.79201 .45743 Mdot
.47703 .36558 Mdot
.64355 .75848 Mdot
.3061 .50883 Mdot
.66741 .49958 Mdot
.39806 .30758 Mdot
.4011 .41395 Mdot
.48624 .37803 Mdot
.41234 .31542 Mdot
.485 .38217 Mdot
.7254 .73959 Mdot
.52727 .40332 Mdot
.47731 .34027 Mdot
.40811 .69238 Mdot
.40273 .67255 Mdot
.2701 .54943 Mdot
.64182 .51185 Mdot
.22253 .63129 Mdot
.49686 .37298 Mdot
.59119 .70207 Mdot
.68159 .51448 Mdot
.76479 .4635 Mdot
.29588 .49929 Mdot
.69445 .20279 Mdot
.38895 .70867 Mdot
.60247 .64284 Mdot
.37121 .27961 Mdot
.59088 .63781 Mdot
.57087 .70256 Mdot
.32512 .46636 Mdot
.73214 .4667 Mdot
.52761 .39386 Mdot
.35738 .42244 Mdot
.26237 .47336 Mdot
.50096 .40305 Mdot
.61807 .64737 Mdot
.65468 .52427 Mdot
.47385 .23962 Mdot
.70229 .46003 Mdot
.75882 .45531 Mdot
.42717 .69702 Mdot
.59272 .70216 Mdot
.62218 .50031 Mdot
.73006 .48003 Mdot
.61337 .61569 Mdot
.61184 .49169 Mdot
.63026 .75523 Mdot
.32167 .51075 Mdot
.37493 .34823 Mdot
.3121 .31679 Mdot
.42015 .67043 Mdot
.61178 .7433 Mdot
.29829 .49169 Mdot
.32226 .48961 Mdot
.62618 .50551 Mdot
.58424 .63319 Mdot
.31571 .47637 Mdot
.49513 .34716 Mdot
.64378 .51712 Mdot
.46288 .35483 Mdot
.69394 .47043 Mdot
.4935 .37008 Mdot
.60766 .61352 Mdot
.40999 .68567 Mdot
.5676 .67625 Mdot
.4292 .69453 Mdot
.65952 .35828 Mdot
.50157 .3807 Mdot
.47975 .36133 Mdot
.58469 .33258 Mdot
.32602 .53897 Mdot
.35903 .42737 Mdot
.56937 .66225 Mdot
.56712 .67365 Mdot
.39775 .30732 Mdot
.2814 .52087 Mdot
.5973 .53767 Mdot
.57341 .36104 Mdot
.48235 .38174 Mdot
.30564 .51065 Mdot
.37369 .30198 Mdot
.37443 .77857 Mdot
.58183 .30475 Mdot
.31881 .54754 Mdot
.64688 .76232 Mdot
.46546 .37659 Mdot
.62007 .4974 Mdot
.66135 .50444 Mdot
.56032 .26356 Mdot
.68502 .48886 Mdot
.28678 .52877 Mdot
.63077 .50015 Mdot
.30138 .50175 Mdot
.56083 .66639 Mdot
.40111 .7256 Mdot
.29788 .51164 Mdot
.48936 .3828 Mdot
.78839 .68603 Mdot
.43893 .68848 Mdot
.49759 .35268 Mdot
.42234 .71637 Mdot
.2867 .49598 Mdot
.29821 .52409 Mdot
.6116 .49188 Mdot
.37537 .27122 Mdot
.42696 .67798 Mdot
.51312 .35454 Mdot
.37106 .47534 Mdot
.39672 .29942 Mdot
.67535 .51117 Mdot
.47733 .38954 Mdot
.48582 .39845 Mdot
.65449 .76162 Mdot
.55911 .43307 Mdot
.37152 .63202 Mdot
.3923 .72881 Mdot
.33452 .68075 Mdot
.33434 .52711 Mdot
.69512 .47862 Mdot
.26807 .54894 Mdot
.59964 .51567 Mdot
.59601 .63424 Mdot
.50946 .36296 Mdot
.62367 .48769 Mdot
.44977 .69037 Mdot
.73708 .47221 Mdot
.53388 .40196 Mdot
.59762 .67906 Mdot
.63367 .4941 Mdot
.42644 .68464 Mdot
.31576 .52391 Mdot
.28887 .51796 Mdot
.62314 .75263 Mdot
.48417 .34571 Mdot
.48166 .367 Mdot
.40027 .71979 Mdot
.76802 .47897 Mdot
.75304 .44556 Mdot
.65211 .51056 Mdot
.4051 .72265 Mdot
.58177 .30365 Mdot
.26859 .53446 Mdot
.50012 .35136 Mdot
.58681 .32806 Mdot
.33549 .66805 Mdot
.21669 .52979 Mdot
.75426 .45076 Mdot
.54264 .28108 Mdot
.28716 .52954 Mdot
.41111 .69624 Mdot
.74376 .66951 Mdot
.3911 .27338 Mdot
.51389 .39069 Mdot
.53112 .28096 Mdot
.56933 .35886 Mdot
.37053 .28732 Mdot
.59481 .50662 Mdot
.56517 .30599 Mdot
.39443 .30821 Mdot
.38655 .30353 Mdot
.46693 .38359 Mdot
.47371 .38822 Mdot
.3026 .51655 Mdot
.4132 .377 Mdot
.59394 .65057 Mdot
.36698 .27442 Mdot
.78531 .44221 Mdot
.37845 .27737 Mdot
.44132 .36825 Mdot
.21137 .54205 Mdot
.53379 .24595 Mdot
.31171 .50199 Mdot
.30009 .55742 Mdot
.42113 .66886 Mdot
.39862 .29803 Mdot
.57044 .65894 Mdot
.64642 .53245 Mdot
.59944 .62222 Mdot
.30443 .51579 Mdot
.6168 .62672 Mdot
.38789 .68743 Mdot
.59661 .67365 Mdot
.58216 .6374 Mdot
.40732 .68769 Mdot
.27171 .53902 Mdot
.48279 .40101 Mdot
.40757 .68668 Mdot
.61037 .53967 Mdot
.72815 .48268 Mdot
.28136 .46631 Mdot
.64749 .51898 Mdot
.43325 .34334 Mdot
.39413 .79567 Mdot
.6018 .66506 Mdot
.51954 .28676 Mdot
.28122 .54842 Mdot
.77729 .44159 Mdot
.29683 .51499 Mdot
.61391 .54432 Mdot
.74563 .45003 Mdot
.45239 .34894 Mdot
.78969 .4377 Mdot
.47685 .71398 Mdot
.53283 .35963 Mdot
.30029 .46245 Mdot
.59574 .62247 Mdot
.42207 .67331 Mdot
.46734 .65351 Mdot
.62357 .499 Mdot
.29673 .5544 Mdot
.349 .56525 Mdot
.60246 .52272 Mdot
.41149 .69296 Mdot
.33745 .3684 Mdot
.50642 .35363 Mdot
.42925 .66825 Mdot
.48094 .39124 Mdot
.3736 .33443 Mdot
.7205 .49052 Mdot
.6424 .49362 Mdot
.40302 .29955 Mdot
.61066 .67259 Mdot
.3996 .30609 Mdot
.40612 .35189 Mdot
.67059 .38479 Mdot
.48919 .38816 Mdot
.52273 .28476 Mdot
.55183 .66148 Mdot
.30873 .49621 Mdot
.61744 .52415 Mdot
.62452 .51129 Mdot
.40382 .29182 Mdot
.84749 .5941 Mdot
.74169 .47326 Mdot
.64222 .76025 Mdot
.50042 .37908 Mdot
.47503 .37232 Mdot
.26874 .55071 Mdot
.37268 .35769 Mdot
.64978 .50703 Mdot
.50518 .391 Mdot
.54269 .24786 Mdot
.40888 .70205 Mdot
.44152 .35548 Mdot
.46285 .36255 Mdot
.40254 .62899 Mdot
.40868 .6941 Mdot
.56044 .64944 Mdot
.61112 .49004 Mdot
.60605 .69411 Mdot
.73064 .44349 Mdot
.55126 .29117 Mdot
.66383 .37089 Mdot
.5803 .30909 Mdot
.74158 .44374 Mdot
.3849 .28038 Mdot
.42736 .3418 Mdot
.51154 .39464 Mdot
.75768 .45891 Mdot
.4149 .65647 Mdot
.30349 .51127 Mdot
.37436 .34026 Mdot
.62482 .50957 Mdot
.38123 .30167 Mdot
.72165 .44519 Mdot
.30321 .50215 Mdot
.3277 .35108 Mdot
.30601 .52072 Mdot
.42269 .68665 Mdot
.60785 .74185 Mdot
.74328 .44921 Mdot
.29643 .51462 Mdot
.61383 .6544 Mdot
.37866 .63165 Mdot
.42572 .36102 Mdot
.38978 .6824 Mdot
.3338 .4738 Mdot
.30741 .55432 Mdot
.33518 .53233 Mdot
.39989 .28573 Mdot
.52202 .28577 Mdot
.60111 .51096 Mdot
.40787 .72369 Mdot
.60713 .67832 Mdot
.66584 .39586 Mdot
.34325 .38829 Mdot
.56676 .32143 Mdot
.44953 .36268 Mdot
.49356 .36888 Mdot
.46594 .36977 Mdot
.59287 .51689 Mdot
.42957 .33797 Mdot
.48613 .38913 Mdot
.43781 .66032 Mdot
.56326 .646 Mdot
.50236 .37722 Mdot
.63094 .5236 Mdot
.67215 .48256 Mdot
.77733 .44132 Mdot
.35139 .3074 Mdot
.27098 .47559 Mdot
.30014 .50669 Mdot
.57958 .6493 Mdot
.61504 .6687 Mdot
.71177 .4817 Mdot
.41454 .70878 Mdot
.30645 .52305 Mdot
.72235 .74028 Mdot
.73433 .44897 Mdot
.49735 .35993 Mdot
.5848 .33128 Mdot
.54329 .25355 Mdot
.44484 .37488 Mdot
.51199 .36764 Mdot
.63034 .53082 Mdot
.57222 .65367 Mdot
.424 .36531 Mdot
.32763 .34926 Mdot
.76528 .45288 Mdot
.73959 .48153 Mdot
.33737 .5025 Mdot
.50601 .34917 Mdot
.43515 .684 Mdot
.57071 .28114 Mdot
.43152 .64037 Mdot
.2028 .60766 Mdot
.62944 .62358 Mdot
.52445 .39581 Mdot
.41366 .42892 Mdot
.44089 .33704 Mdot
.33635 .49419 Mdot
.36293 .53074 Mdot
.31762 .50144 Mdot
.4108 .70479 Mdot
.60752 .42501 Mdot
.39296 .68998 Mdot
.64996 .50356 Mdot
.28653 .54313 Mdot
.55602 .38973 Mdot
.56761 .6731 Mdot
.39489 .30405 Mdot
.74168 .45975 Mdot
.56075 .37747 Mdot
.61842 .52136 Mdot
.54556 .28387 Mdot
.57246 .68884 Mdot
.27166 .52124 Mdot
.39441 .30485 Mdot
.60259 .73513 Mdot
.56721 .30961 Mdot
.62672 .6002 Mdot
.62351 .48719 Mdot
.74459 .44737 Mdot
.46163 .44406 Mdot
.72546 .45394 Mdot
.42787 .67951 Mdot
.50237 .38258 Mdot
.47944 .34076 Mdot
.48455 .37442 Mdot
.45232 .35592 Mdot
.41864 .70339 Mdot
.38747 .29901 Mdot
.62734 .53954 Mdot
.62603 .48956 Mdot
.3739 .27888 Mdot
.73561 .46856 Mdot
.39959 .68819 Mdot
.57413 .633 Mdot
.61342 .53444 Mdot
.71073 .45844 Mdot
.51852 .35079 Mdot
.49715 .38886 Mdot
.6396 .49482 Mdot
.45416 .34708 Mdot
.38696 .29607 Mdot
.59535 .6671 Mdot
.37684 .29588 Mdot
.77554 .44025 Mdot
.73997 .45717 Mdot
.43273 .69798 Mdot
.29625 .51338 Mdot
.71031 .47671 Mdot
.58107 .6944 Mdot
.44994 .33672 Mdot
.47487 .38821 Mdot
.3686 .5124 Mdot
.64087 .41573 Mdot
.77544 .44189 Mdot
.4594 .34299 Mdot
.33315 .50931 Mdot
.33564 .57691 Mdot
.51028 .39147 Mdot
.38357 .29066 Mdot
.32244 .54698 Mdot
.72868 .48146 Mdot
.41733 .71001 Mdot
.61499 .35417 Mdot
.43845 .7004 Mdot
.31609 .52494 Mdot
.63128 .50201 Mdot
.27342 .54027 Mdot
.62592 .49871 Mdot
.2078 .57735 Mdot
.48015 .3883 Mdot
.37057 .49524 Mdot
.64389 .53095 Mdot
.56556 .66729 Mdot
.57227 .64102 Mdot
.62324 .52907 Mdot
.28547 .53319 Mdot
.60305 .51042 Mdot
.72004 .46242 Mdot
.33629 .67691 Mdot
.31367 .55375 Mdot
.58193 .63687 Mdot
.60156 .66819 Mdot
.40431 .723 Mdot
.49153 .37385 Mdot
.50267 .35266 Mdot
.59413 .67819 Mdot
.43299 .6409 Mdot
.30577 .54573 Mdot
.48197 .36631 Mdot
.63145 .534 Mdot
.59502 .65629 Mdot
.45129 .73967 Mdot
.28479 .4959 Mdot
.40359 .30092 Mdot
.67059 .38198 Mdot
.38981 .72303 Mdot
.44125 .34018 Mdot
.38756 .29434 Mdot
.75376 .46836 Mdot
.53892 .27963 Mdot
.63365 .41553 Mdot
.38681 .69982 Mdot
.59982 .50856 Mdot
.44277 .37255 Mdot
.5644 .656 Mdot
.4552 .33739 Mdot
.72078 .24256 Mdot
.64457 .49644 Mdot
.47621 .34774 Mdot
.65788 .50365 Mdot
.2963 .5309 Mdot
.48112 .37098 Mdot
.36746 .63444 Mdot
.57953 .65284 Mdot
.48548 .34634 Mdot
.78812 .464 Mdot
.42642 .71309 Mdot
.61949 .52134 Mdot
.75382 .44684 Mdot
.36902 .27782 Mdot
.658 .35303 Mdot
.58465 .61894 Mdot
.7261 .47291 Mdot
.49136 .3761 Mdot
.57971 .69777 Mdot
.4071 .66959 Mdot
.61824 .52609 Mdot
.5263 .35489 Mdot
.40624 .67671 Mdot
.40492 .69774 Mdot
.73466 .45263 Mdot
.30855 .32766 Mdot
.53766 .37815 Mdot
.47917 .3532 Mdot
.3267 .35676 Mdot
.29926 .58007 Mdot
.50898 .35939 Mdot
.45783 .35996 Mdot
.43173 .68817 Mdot
.60449 .42725 Mdot
.54359 .28274 Mdot
.65087 .52585 Mdot
.41759 .675 Mdot
.61875 .63464 Mdot
.60162 .64761 Mdot
.71984 .47408 Mdot
.31153 .51013 Mdot
.70568 .47962 Mdot
.58773 .65508 Mdot
.49327 .35845 Mdot
.42047 .71197 Mdot
.36976 .3119 Mdot
.42754 .71332 Mdot
.58491 .69156 Mdot
.3149 .48548 Mdot
.41782 .35993 Mdot
.71714 .23718 Mdot
.49338 .6327 Mdot
.60661 .74367 Mdot
.76345 .46489 Mdot
.32812 .35036 Mdot
.49518 .37974 Mdot
.41577 .36843 Mdot
.49255 .35054 Mdot
.69841 .48468 Mdot
.60006 .61818 Mdot
.61168 .49174 Mdot
.62269 .49886 Mdot
.54424 .28633 Mdot
.40483 .70073 Mdot
.38961 .69781 Mdot
.64084 .50522 Mdot
.4194 .68643 Mdot
.47481 .35061 Mdot
.57773 .68539 Mdot
.20448 .56791 Mdot
.48394 .3825 Mdot
.65153 .48729 Mdot
.38436 .70819 Mdot
.30812 .48194 Mdot
.61857 .63541 Mdot
.40652 .42239 Mdot
.22801 .63875 Mdot
.42207 .67824 Mdot
.35211 .30768 Mdot
.57508 .65559 Mdot
.61468 .53446 Mdot
.57761 .69906 Mdot
.48131 .35027 Mdot
.52427 .39605 Mdot
.60381 .53401 Mdot
.48136 .37977 Mdot
.36045 .43716 Mdot
.38664 .27088 Mdot
.38783 .25976 Mdot
.49406 .39245 Mdot
.32548 .47082 Mdot
.41657 .66232 Mdot
.63929 .50469 Mdot
.56411 .36988 Mdot
.49818 .39941 Mdot
.33474 .52777 Mdot
.40789 .67726 Mdot
.24839 .64954 Mdot
.41268 .70389 Mdot
.56366 .67018 Mdot
.41042 .7083 Mdot
.44226 .33699 Mdot
.30508 .53211 Mdot
.58361 .66658 Mdot
.62195 .51759 Mdot
.60906 .65209 Mdot
.52287 .36776 Mdot
.4372 .74886 Mdot
.60167 .64262 Mdot
.38643 .27262 Mdot
.30368 .53115 Mdot
.79446 .43776 Mdot
.25749 .48225 Mdot
.48909 .35546 Mdot
.49797 .3543 Mdot
.65139 .51196 Mdot
.42801 .7008 Mdot
.27077 .52067 Mdot
.63569 .75705 Mdot
.77691 .44227 Mdot
.31327 .50464 Mdot
.73506 .48861 Mdot
.57843 .34802 Mdot
.30288 .49368 Mdot
.5448 .24944 Mdot
.43605 .68951 Mdot
.28719 .52224 Mdot
.67631 .52445 Mdot
.36584 .29784 Mdot
.7303 .46443 Mdot
.61194 .67664 Mdot
.57837 .35268 Mdot
.59629 .64308 Mdot
.38152 .63059 Mdot
.57176 .72016 Mdot
.42583 .67511 Mdot
.78192 .47118 Mdot
.37856 .26716 Mdot
.39048 .68556 Mdot
.34701 .64654 Mdot
.59021 .6471 Mdot
.64346 .50442 Mdot
.3791 .2949 Mdot
.59976 .53379 Mdot
.62951 .49571 Mdot
.38804 .70356 Mdot
.28667 .51974 Mdot
.28442 .51303 Mdot
.66574 .50158 Mdot
.29008 .51464 Mdot
.58741 .6753 Mdot
.5853 .3148 Mdot
.41131 .39448 Mdot
.41557 .6618 Mdot
.368 .28011 Mdot
.44691 .37062 Mdot
.60101 .61464 Mdot
.57989 .68145 Mdot
.40764 .7032 Mdot
.23422 .49266 Mdot
.61962 .49598 Mdot
.29245 .49018 Mdot
.29365 .54033 Mdot
.29387 .53018 Mdot
.27919 .55095 Mdot
.61959 .42198 Mdot
.41059 .68072 Mdot
.28649 .53448 Mdot
.45762 .37063 Mdot
.46042 .36562 Mdot
.61033 .53318 Mdot
.6959 .47851 Mdot
.38017 .29009 Mdot
.60315 .50793 Mdot
.51848 .38627 Mdot
.56757 .66896 Mdot
.68425 .50302 Mdot
.59855 .50771 Mdot
.57032 .65736 Mdot
.56724 .66036 Mdot
.60041 .50273 Mdot
.68477 .49873 Mdot
.36175 .44036 Mdot
.37676 .31153 Mdot
.31453 .4651 Mdot
.58267 .6325 Mdot
.35102 .63985 Mdot
.37077 .49612 Mdot
.47648 .34191 Mdot
.653 .51394 Mdot
.57102 .68388 Mdot
.30872 .55645 Mdot
.47338 .36273 Mdot
.62425 .50464 Mdot
.72497 .46275 Mdot
.62508 .51915 Mdot
.63472 .52822 Mdot
.32997 .5283 Mdot
.40227 .79614 Mdot
.32316 .49338 Mdot
.56517 .70969 Mdot
.61552 .5166 Mdot
.28746 .29201 Mdot
.59109 .62376 Mdot
.33668 .68082 Mdot
.37824 .26812 Mdot
.51212 .39287 Mdot
.58097 .64856 Mdot
.30321 .553 Mdot
.41155 .65676 Mdot
.53313 .24305 Mdot
.29531 .51498 Mdot
.59687 .50277 Mdot
.62944 .52892 Mdot
.59501 .65201 Mdot
.31434 .53072 Mdot
.38732 .29362 Mdot
.29079 .52434 Mdot
.39427 .70518 Mdot
.4532 .34432 Mdot
.22351 .63224 Mdot
.62228 .5008 Mdot
.29268 .50589 Mdot
.60324 .68434 Mdot
.7142 .46384 Mdot
.46384 .34384 Mdot
.22197 .6416 Mdot
.48852 .37749 Mdot
.39546 .71422 Mdot
.6617 .48453 Mdot
.36968 .3 Mdot
.50972 .37127 Mdot
.43523 .36242 Mdot
.4506 .6587 Mdot
.51206 .37509 Mdot
.48522 .39916 Mdot
.32081 .33403 Mdot
.31536 .49292 Mdot
.50086 .37699 Mdot
.59129 .67897 Mdot
.5345 .61489 Mdot
.46561 .35566 Mdot
.61112 .73836 Mdot
.55904 .26542 Mdot
.63222 .54042 Mdot
.67019 .52319 Mdot
.6639 .38038 Mdot
.48951 .35216 Mdot
.52867 .36838 Mdot
.45147 .34605 Mdot
.4212 .41453 Mdot
.58435 .65347 Mdot
.59996 .70024 Mdot
.71452 .4692 Mdot
.52702 .28052 Mdot
.73721 .45597 Mdot
.40878 .66848 Mdot
.40069 .27598 Mdot
.61783 .4875 Mdot
.2965 .50941 Mdot
.4822 .37471 Mdot
.60269 .69151 Mdot
.4808 .34901 Mdot
.39387 .28689 Mdot
.59133 .6689 Mdot
.56828 .6807 Mdot
.59077 .71577 Mdot
.76954 .45698 Mdot
.30638 .50278 Mdot
.48161 .33885 Mdot
.76274 .44915 Mdot
.60106 .53264 Mdot
.61433 .34266 Mdot
.31025 .50111 Mdot
.29674 .50179 Mdot
.27433 .53138 Mdot
.48894 .3411 Mdot
.47235 .33576 Mdot
.39386 .69212 Mdot
.36882 .51359 Mdot
.43055 .70775 Mdot
.58426 .6454 Mdot
.55925 .66451 Mdot
.48379 .34968 Mdot
.76069 .47938 Mdot
.73509 .46747 Mdot
.6072 .65808 Mdot
.64724 .49402 Mdot
.70977 .46721 Mdot
.51361 .35582 Mdot
.5926 .64204 Mdot
.76543 .44789 Mdot
.23373 .49264 Mdot
.26608 .62842 Mdot
.71299 .464 Mdot
.61918 .49881 Mdot
.34613 .39402 Mdot
.66484 .39142 Mdot
.72088 .49032 Mdot
.41355 .66392 Mdot
.50074 .4049 Mdot
.64344 .49326 Mdot
.71063 .46049 Mdot
.66698 .40272 Mdot
.58919 .661 Mdot
.61659 .49842 Mdot
.71288 .50402 Mdot
.41271 .39513 Mdot
.71484 .4589 Mdot
.29433 .5032 Mdot
.29176 .48288 Mdot
.50483 .36359 Mdot
.37447 .27264 Mdot
.42784 .65878 Mdot
.61472 .66698 Mdot
.60234 .69525 Mdot
.35421 .55274 Mdot
.581 .30713 Mdot
.59747 .66676 Mdot
.52969 .40022 Mdot
.70679 .4602 Mdot
.45832 .37172 Mdot
.67119 .49271 Mdot
.37033 .30332 Mdot
.66696 .52528 Mdot
.71368 .46376 Mdot
.41621 .66009 Mdot
.41043 .68579 Mdot
.42607 .70102 Mdot
.59737 .66143 Mdot
.57401 .35435 Mdot
.59483 .70255 Mdot
.30904 .32319 Mdot
.73725 .47548 Mdot
.66568 .76489 Mdot
.43315 .33873 Mdot
.52151 .38502 Mdot
.38078 .30474 Mdot
.63743 .52955 Mdot
.48579 .3529 Mdot
.40347 .67831 Mdot
.61357 .65409 Mdot
.45091 .74199 Mdot
.32636 .52645 Mdot
.31153 .32554 Mdot
.56901 .67346 Mdot
.64657 .48706 Mdot
.74076 .46278 Mdot
.67394 .36758 Mdot
.70249 .48754 Mdot
.56449 .68567 Mdot
.53096 .38566 Mdot
.32424 .54741 Mdot
.72997 .73568 Mdot
.48337 .37154 Mdot
.60263 .6643 Mdot
.60564 .60445 Mdot
.36361 .28886 Mdot
.51519 .44076 Mdot
.4615 .7337 Mdot
.58247 .32576 Mdot
.77165 .45107 Mdot
.60905 .53786 Mdot
.57124 .27635 Mdot
.58824 .6534 Mdot
.61097 .64586 Mdot
.72314 .4895 Mdot
.3092 .48234 Mdot
.27964 .53894 Mdot
.36656 .45653 Mdot
.39874 .68319 Mdot
.50364 .3952 Mdot
.59328 .64475 Mdot
.31047 .48566 Mdot
.5616 .37057 Mdot
.42498 .69434 Mdot
.60471 .64621 Mdot
.48087 .37926 Mdot
.50674 .36941 Mdot
.73456 .45701 Mdot
.67155 .48248 Mdot
.62562 .53766 Mdot
.33715 .67448 Mdot
.5695 .34305 Mdot
.40352 .28043 Mdot
.5136 .39089 Mdot
.30975 .54612 Mdot
.60074 .51782 Mdot
.73174 .46731 Mdot
.45174 .33898 Mdot
.4177 .36373 Mdot
.3034 .55545 Mdot
.43627 .6873 Mdot
.6193 .5127 Mdot
.5505 .29357 Mdot
.48403 .37932 Mdot
.49011 .3503 Mdot
.39983 .28579 Mdot
.41235 .34738 Mdot
.60441 .6237 Mdot
.32916 .50111 Mdot
.75937 .44834 Mdot
.30067 .52393 Mdot
.62623 .7523 Mdot
.3843 .26953 Mdot
.52159 .40377 Mdot
.33568 .5203 Mdot
.30866 .52421 Mdot
.39585 .7138 Mdot
.4151 .67867 Mdot
.6253 .60479 Mdot
.45843 .35389 Mdot
.64752 .49791 Mdot
.28865 .53486 Mdot
.61288 .67402 Mdot
.7369 .45498 Mdot
.6135 .74769 Mdot
.49165 .38948 Mdot
.59097 .64948 Mdot
.61366 .5245 Mdot
.32862 .52678 Mdot
.57138 .66316 Mdot
.6154 .53452 Mdot
.7338 .48177 Mdot
.45289 .38476 Mdot
.6211 .59853 Mdot
.63291 .50515 Mdot
.45579 .35661 Mdot
.37852 .25359 Mdot
.37245 .27434 Mdot
.65224 .52492 Mdot
.61165 .61057 Mdot
.62994 .50706 Mdot
.28113 .4958 Mdot
.3643 .28094 Mdot
.61221 .66847 Mdot
.3703 .5031 Mdot
.37932 .26851 Mdot
.62836 .49951 Mdot
.30527 .49777 Mdot
.63071 .75309 Mdot
.34169 .49331 Mdot
.65574 .39881 Mdot
.46724 .36047 Mdot
.59659 .6433 Mdot
.72923 .46347 Mdot
.39154 .70289 Mdot
.40782 .7434 Mdot
.35616 .63957 Mdot
.57406 .64313 Mdot
.48021 .37521 Mdot
.28743 .52546 Mdot
.42172 .67967 Mdot
.26881 .55186 Mdot
.58625 .69602 Mdot
.58451 .68545 Mdot
.37962 .30366 Mdot
.73882 .45541 Mdot
.42969 .33923 Mdot
.6104 .68041 Mdot
.56996 .71811 Mdot
.3234 .33719 Mdot
.76621 .44746 Mdot
.40152 .28834 Mdot
.66786 .50519 Mdot
.4425 .35772 Mdot
.32848 .3545 Mdot
.63762 .52393 Mdot
.32523 .52833 Mdot
.51848 .37176 Mdot
.45833 .8181 Mdot
.58876 .62371 Mdot
.58212 .32564 Mdot
.47641 .71458 Mdot
.40375 .69146 Mdot
.5782 .65779 Mdot
.47274 .36694 Mdot
.61198 .74708 Mdot
.7189 .47431 Mdot
.39465 .30949 Mdot
.63668 .50177 Mdot
.34122 .57105 Mdot
.41557 .71265 Mdot
.71825 .49969 Mdot
.39145 .70148 Mdot
.43168 .69797 Mdot
.23447 .49604 Mdot
.50304 .36238 Mdot
.57307 .67284 Mdot
.5923 .68442 Mdot
.66857 .49762 Mdot
.55446 .70184 Mdot
.27817 .54209 Mdot
.45279 .81419 Mdot
.4231 .36869 Mdot
.49835 .38401 Mdot
.59509 .5058 Mdot
.64865 .50392 Mdot
.6076 .74243 Mdot
.51353 .37349 Mdot
.3147 .49577 Mdot
.60763 .68954 Mdot
.60073 .64957 Mdot
.38526 .27298 Mdot
.4106 .68503 Mdot
.70304 .48851 Mdot
.58329 .67843 Mdot
.61363 .35353 Mdot
.47752 .34703 Mdot
.40579 .65936 Mdot
.58415 .6762 Mdot
.81985 .64184 Mdot
.39946 .80291 Mdot
.31972 .49019 Mdot
.43661 .37025 Mdot
.2834 .49813 Mdot
.71635 .45949 Mdot
.58292 .70457 Mdot
.38927 .69181 Mdot
.61785 .51761 Mdot
.48863 .70418 Mdot
.59843 .6514 Mdot
.30419 .51487 Mdot
.50132 .35884 Mdot
.34813 .29855 Mdot
.48626 .38209 Mdot
.60174 .42779 Mdot
.77458 .44299 Mdot
.40916 .74408 Mdot
.40232 .72131 Mdot
.4361 .36983 Mdot
.76651 .45062 Mdot
.56294 .68674 Mdot
.59202 .66606 Mdot
.2276 .64627 Mdot
.63329 .52877 Mdot
.5701 .7011 Mdot
.45651 .35482 Mdot
.58905 .71622 Mdot
.34301 .38836 Mdot
.4048 .69236 Mdot
.46852 .38668 Mdot
.59423 .63794 Mdot
.33586 .48577 Mdot
.58282 .33436 Mdot
.46977 .35233 Mdot
.65958 .50424 Mdot
.42012 .67734 Mdot
.30891 .31925 Mdot
.60306 .61648 Mdot
.47313 .38364 Mdot
.41243 .67016 Mdot
.77955 .4717 Mdot
.42736 .75886 Mdot
.30718 .50212 Mdot
.60157 .67012 Mdot
.41539 .71079 Mdot
.60957 .51575 Mdot
.7552 .44457 Mdot
.57045 .6948 Mdot
.59722 .63608 Mdot
.38716 .28182 Mdot
.65612 .49278 Mdot
.72709 .49025 Mdot
.30257 .54553 Mdot
.43314 .68726 Mdot
.39355 .28236 Mdot
.61873 .35357 Mdot
.4665 .33491 Mdot
.43498 .69575 Mdot
.29247 .29786 Mdot
.52827 .38983 Mdot
.49323 .39111 Mdot
.34967 .29843 Mdot
.28471 .49207 Mdot
.29667 .55149 Mdot
.56694 .31621 Mdot
.38277 .28858 Mdot
.55516 .38659 Mdot
.30232 .50769 Mdot
.30617 .51666 Mdot
.55471 .38582 Mdot
.3896 .28333 Mdot
.3681 .4547 Mdot
.41841 .6833 Mdot
.4048 .6895 Mdot
.29511 .5302 Mdot
.38003 .30491 Mdot
.44095 .67174 Mdot
.28345 .573 Mdot
.58252 .69017 Mdot
.56264 .27099 Mdot
.3027 .52751 Mdot
.58699 .33391 Mdot
.42835 .67998 Mdot
.63337 .342 Mdot
.55715 .26342 Mdot
.52756 .36462 Mdot
.50835 .36755 Mdot
.76148 .46507 Mdot
.62177 .52047 Mdot
.60005 .50309 Mdot
.4256 .70184 Mdot
.42917 .33821 Mdot
.3184 .50233 Mdot
.44662 .33437 Mdot
.66687 .39619 Mdot
.64033 .33831 Mdot
.43474 .37544 Mdot
.31064 .51176 Mdot
.31879 .51554 Mdot
.55856 .66133 Mdot
.61709 .64243 Mdot
.54202 .39509 Mdot
.41681 .67896 Mdot
.28791 .51169 Mdot
.42589 .71022 Mdot
.58876 .65467 Mdot
.571 .67547 Mdot
.60216 .52493 Mdot
.61483 .49895 Mdot
.5815 .66093 Mdot
.61089 .73869 Mdot
.61798 .35138 Mdot
.36662 .52316 Mdot
.30212 .30559 Mdot
.66309 .36151 Mdot
.37392 .33603 Mdot
.72628 .46376 Mdot
.68353 .50483 Mdot
.40788 .67345 Mdot
.43093 .36175 Mdot
.5217 .3766 Mdot
.63371 .5117 Mdot
.42192 .66793 Mdot
.74728 .46579 Mdot
.40411 .69236 Mdot
.75327 .44463 Mdot
.61024 .67385 Mdot
.47589 .37361 Mdot
.52944 .3784 Mdot
.39606 .71286 Mdot
.5584 .66958 Mdot
.59151 .63959 Mdot
.72627 .46673 Mdot
.66496 .36765 Mdot
.59376 .65167 Mdot
.30393 .52681 Mdot
.20211 .55516 Mdot
.6353 .52453 Mdot
.47385 .36382 Mdot
.66557 .37804 Mdot
.36495 .27814 Mdot
.59983 .531 Mdot
.61982 .51212 Mdot
.30947 .33034 Mdot
.49407 .34646 Mdot
.24354 .65342 Mdot
.59826 .51037 Mdot
.2729 .53931 Mdot
.5748 .66919 Mdot
.59538 .5153 Mdot
.6656 .51073 Mdot
.68531 .48574 Mdot
.59392 .51279 Mdot
.28289 .53979 Mdot
.27901 .50438 Mdot
.37605 .2923 Mdot
.30066 .26612 Mdot
.74865 .44674 Mdot
.73696 .47103 Mdot
.60119 .62477 Mdot
.38301 .63139 Mdot
.44214 .31972 Mdot
.73109 .47558 Mdot
.28998 .46054 Mdot
.38516 .30447 Mdot
.36986 .28543 Mdot
.37332 .28185 Mdot
.26804 .53708 Mdot
.54111 .37962 Mdot
.60012 .62069 Mdot
.30451 .51292 Mdot
.37687 .29644 Mdot
.45789 .33338 Mdot
.31378 .5005 Mdot
.43168 .69259 Mdot
.40943 .289 Mdot
.28928 .51998 Mdot
.53329 .24173 Mdot
.43176 .67939 Mdot
.42444 .3604 Mdot
.69387 .73593 Mdot
.83399 .62094 Mdot
.406 .69629 Mdot
.6051 .6491 Mdot
.59086 .64531 Mdot
.59447 .66701 Mdot
.2957 .54982 Mdot
.56174 .65271 Mdot
.3175 .52982 Mdot
.60363 .742 Mdot
.53539 .28369 Mdot
.74462 .44949 Mdot
.55338 .69689 Mdot
.29435 .52907 Mdot
.32086 .34312 Mdot
.70197 .21095 Mdot
.46895 .38099 Mdot
.38807 .69263 Mdot
.71558 .47858 Mdot
.58646 .32233 Mdot
.75444 .46794 Mdot
.57568 .65453 Mdot
.54811 .28963 Mdot
.48065 .34804 Mdot
.26022 .63528 Mdot
.7318 .46239 Mdot
.306 .51819 Mdot
.38341 .27911 Mdot
.61206 .60851 Mdot
.71986 .47295 Mdot
.74054 .458 Mdot
.48147 .35466 Mdot
.27121 .52202 Mdot
.57942 .64773 Mdot
.42504 .6699 Mdot
.58884 .73107 Mdot
.56776 .39836 Mdot
.49023 .34472 Mdot
.49013 .39346 Mdot
.58102 .34384 Mdot
.61381 .74662 Mdot
.41401 .68675 Mdot
.65121 .41041 Mdot
.60359 .61335 Mdot
.66989 .39013 Mdot
.3355 .48988 Mdot
.55228 .69528 Mdot
.63939 .52145 Mdot
.61055 .53385 Mdot
.48378 .36567 Mdot
.71075 .22542 Mdot
.53337 .43692 Mdot
.43936 .66903 Mdot
.63766 .51747 Mdot
.55798 .65687 Mdot
.28696 .553 Mdot
.70734 .50696 Mdot
.38196 .29215 Mdot
.42753 .67003 Mdot
.59318 .65917 Mdot
.75031 .2681 Mdot
.761 .46844 Mdot
.58023 .32022 Mdot
.46034 .36762 Mdot
.48145 .36322 Mdot
.42103 .69924 Mdot
.42312 .65513 Mdot
.31048 .31492 Mdot
.68093 .48155 Mdot
.21688 .62863 Mdot
.45158 .68563 Mdot
.76654 .28324 Mdot
.64757 .50098 Mdot
.32243 .5157 Mdot
.60396 .49694 Mdot
.42223 .65614 Mdot
.51607 .36632 Mdot
.27494 .51171 Mdot
.61534 .52708 Mdot
.26698 .47513 Mdot
.36919 .27986 Mdot
.61431 .3515 Mdot
.4942 .36833 Mdot
.27854 .51958 Mdot
.3049 .50793 Mdot
.29234 .4942 Mdot
.61988 .53117 Mdot
.5043 .39112 Mdot
.47872 .38524 Mdot
.49324 .39372 Mdot
.31261 .31526 Mdot
.47825 .37218 Mdot
.3273 .54626 Mdot
.57691 .3006 Mdot
.46879 .82513 Mdot
.52887 .37879 Mdot
.41846 .70804 Mdot
.48833 .36607 Mdot
.77123 .4606 Mdot
.44578 .37813 Mdot
.37112 .27171 Mdot
.41641 .68917 Mdot
.40671 .35126 Mdot
.78523 .44243 Mdot
.50411 .35024 Mdot
.74507 .4436 Mdot
.3399 .71353 Mdot
.64422 .41149 Mdot
.33791 .36955 Mdot
.292 .52569 Mdot
.58773 .69871 Mdot
.43573 .65875 Mdot
.56402 .6704 Mdot
.3825 .31418 Mdot
.61844 .48938 Mdot
.66112 .76472 Mdot
.62312 .35105 Mdot
.51735 .36881 Mdot
.6505 .51238 Mdot
.30935 .49459 Mdot
.59175 .6227 Mdot
.37235 .35548 Mdot
.38232 .30503 Mdot
.71139 .48249 Mdot
.74449 .47557 Mdot
.63889 .47953 Mdot
.29915 .48753 Mdot
.3407 .38618 Mdot
.42055 .6981 Mdot
.59862 .65822 Mdot
.73037 .44199 Mdot
.30608 .45867 Mdot
.41498 .65586 Mdot
.60413 .7401 Mdot
.41278 .71273 Mdot
.52234 .3869 Mdot
.59684 .50748 Mdot
.37223 .4811 Mdot
.63962 .5101 Mdot
.45245 .33649 Mdot
.59486 .63606 Mdot
.63611 .52596 Mdot
.76357 .45529 Mdot
.4238 .70722 Mdot
.56786 .67124 Mdot
.4957 .3546 Mdot
.30222 .50444 Mdot
.47037 .23425 Mdot
.58233 .61694 Mdot
.37979 .27003 Mdot
.38043 .26979 Mdot
.35903 .5488 Mdot
.64526 .53287 Mdot
.4014 .75402 Mdot
.36232 .28563 Mdot
.3625 .63524 Mdot
.73745 .4899 Mdot
.64136 .76094 Mdot
.59484 .70085 Mdot
.58549 .66658 Mdot
.51146 .3579 Mdot
.60912 .6885 Mdot
.52537 .40192 Mdot
.61369 .61295 Mdot
.33403 .6719 Mdot
.53253 .35928 Mdot
.58932 .67051 Mdot
.60158 .50579 Mdot
.46009 .3473 Mdot
.31877 .49487 Mdot
.58867 .70789 Mdot
.52695 .36398 Mdot
.64406 .75045 Mdot
.39544 .71309 Mdot
.61817 .5319 Mdot
.57077 .3682 Mdot
.4234 .68344 Mdot
.2853 .5443 Mdot
.48445 .40206 Mdot
.72477 .47719 Mdot
.31809 .5219 Mdot
.59291 .49369 Mdot
.74121 .45524 Mdot
.5862 .31332 Mdot
.30131 .53728 Mdot
.63941 .51973 Mdot
.73632 .48016 Mdot
.67381 .51592 Mdot
.58753 .66466 Mdot
.6048 .60412 Mdot
.62881 .50368 Mdot
.48563 .3478 Mdot
.56874 .63606 Mdot
.40655 .70458 Mdot
.46229 .35912 Mdot
.59601 .64491 Mdot
.62908 .52413 Mdot
.4736 .38051 Mdot
.38176 .28871 Mdot
.32555 .34511 Mdot
.63023 .54181 Mdot
.7539 .44918 Mdot
.29853 .49044 Mdot
.47623 .386 Mdot
.74091 .44621 Mdot
.55204 .66594 Mdot
.45568 .37241 Mdot
.29344 .49978 Mdot
.26333 .46904 Mdot
.61552 .66456 Mdot
.43697 .68305 Mdot
.5943 .68483 Mdot
.73364 .44287 Mdot
.69816 .20534 Mdot
.59927 .5125 Mdot
.38186 .31032 Mdot
.46725 .39178 Mdot
.58852 .70068 Mdot
.30762 .50476 Mdot
.20496 .61667 Mdot
.44602 .37902 Mdot
.45467 .37016 Mdot
.47607 .36086 Mdot
.59078 .73392 Mdot
.28366 .54964 Mdot
.47461 .36224 Mdot
.6888 .4894 Mdot
.48348 .39326 Mdot
.7172 .46402 Mdot
.67376 .75485 Mdot
.61385 .53619 Mdot
.28509 .28874 Mdot
.61523 .52837 Mdot
.588 .67714 Mdot
.53344 .24117 Mdot
.56815 .36732 Mdot
.63498 .63807 Mdot
.28424 .54466 Mdot
.31433 .46551 Mdot
.57267 .67612 Mdot
.62973 .75354 Mdot
.383 .29494 Mdot
.38349 .28125 Mdot
.46483 .34544 Mdot
.5755 .65489 Mdot
.61253 .64034 Mdot
.61977 .49077 Mdot
.64935 .51304 Mdot
.42404 .35909 Mdot
.60495 .68462 Mdot
.47602 .37272 Mdot
.36828 .29559 Mdot
.41814 .65422 Mdot
.31325 .49007 Mdot
.39334 .67907 Mdot
.40398 .66249 Mdot
.37588 .34198 Mdot
.56857 .34391 Mdot
.3994 .68143 Mdot
.42465 .66203 Mdot
.59604 .73544 Mdot
.40989 .3821 Mdot
.71867 .45832 Mdot
.53543 .43738 Mdot
.56199 .67526 Mdot
.50455 .38955 Mdot
.27992 .54888 Mdot
.6117 .54364 Mdot
.19761 .59581 Mdot
.7413 .3414 Mdot
.39446 .29896 Mdot
.59054 .61925 Mdot
.63306 .50441 Mdot
.64098 .50619 Mdot
.66558 .39154 Mdot
.47637 .37075 Mdot
.61467 .66867 Mdot
.41218 .39382 Mdot
.45218 .6826 Mdot
.61117 .74319 Mdot
.29503 .48793 Mdot
.4878 .36879 Mdot
.312 .54188 Mdot
.44094 .68754 Mdot
.731 .45062 Mdot
.76695 .46051 Mdot
.5111 .35483 Mdot
.37698 .26781 Mdot
.36141 .63533 Mdot
.37938 .28466 Mdot
.39235 .28741 Mdot
.62746 .50734 Mdot
.40153 .28559 Mdot
.47043 .38279 Mdot
.53014 .35947 Mdot
.60178 .53358 Mdot
.39855 .66841 Mdot
.3933 .37861 Mdot
.63 .50018 Mdot
.45087 .38475 Mdot
.44067 .69035 Mdot
.37898 .28776 Mdot
.41335 .70455 Mdot
.61469 .7457 Mdot
.39514 .69361 Mdot
.76037 .44975 Mdot
.57826 .7248 Mdot
.30547 .30858 Mdot
.2879 .52327 Mdot
.40961 .68238 Mdot
.73159 .4825 Mdot
.41252 .70682 Mdot
.56512 .68276 Mdot
.45333 .66872 Mdot
.29097 .57862 Mdot
.61219 .35195 Mdot
.37664 .33347 Mdot
.45072 .67809 Mdot
.61613 .65063 Mdot
.29425 .53084 Mdot
.37105 .63375 Mdot
.47167 .39639 Mdot
.76419 .46613 Mdot
.48388 .36397 Mdot
.42786 .7036 Mdot
.56442 .64363 Mdot
.3366 .37046 Mdot
.75848 .45027 Mdot
.30579 .31725 Mdot
.60197 .69115 Mdot
.51229 .39827 Mdot
.4012 .72561 Mdot
.38984 .74222 Mdot
.40037 .71903 Mdot
.53655 .27815 Mdot
.64318 .49403 Mdot
.68116 .47816 Mdot
.31325 .52714 Mdot
.65183 .50436 Mdot
.80462 .42703 Mdot
.34378 .64958 Mdot
.32753 .50373 Mdot
.55507 .69181 Mdot
.48132 .34569 Mdot
.40313 .29191 Mdot
.60617 .50588 Mdot
.28309 .51444 Mdot
.39943 .28523 Mdot
.60513 .52966 Mdot
.57533 .2969 Mdot
.29314 .49113 Mdot
.5643 .69252 Mdot
.4582 .35279 Mdot
.38891 .70922 Mdot
.43003 .71094 Mdot
.59958 .4996 Mdot
.39074 .69702 Mdot
.44904 .38359 Mdot
.30246 .53348 Mdot
.37704 .29227 Mdot
.71516 .46677 Mdot
.36804 .46587 Mdot
.60141 .53813 Mdot
.71026 .44866 Mdot
.45335 .36413 Mdot
.57221 .67448 Mdot
.48652 .70826 Mdot
.44102 .36712 Mdot
.30232 .51087 Mdot
.47645 .39643 Mdot
.40049 .28502 Mdot
.3814 .28283 Mdot
.59855 .65782 Mdot
.58424 .33516 Mdot
.4775 .37314 Mdot
.43223 .67304 Mdot
.56 .41658 Mdot
.43114 .34477 Mdot
.69141 .4834 Mdot
.3708 .27195 Mdot
.41739 .72234 Mdot
.36048 .5431 Mdot
.57429 .67242 Mdot
.32033 .50577 Mdot
.27513 .56549 Mdot
.28773 .5448 Mdot
.34023 .48315 Mdot
.36246 .28457 Mdot
.23028 .65038 Mdot
.34244 .38737 Mdot
.36574 .32513 Mdot
.3053 .55908 Mdot
.44246 .75921 Mdot
.32801 .50342 Mdot
.28512 .54445 Mdot
.20423 .57055 Mdot
.28155 .54531 Mdot
.48575 .3492 Mdot
.49725 .39957 Mdot
.42883 .37292 Mdot
.58618 .73177 Mdot
.48628 .38294 Mdot
.59512 .52395 Mdot
.71353 .47977 Mdot
.3113 .48298 Mdot
.61938 .51566 Mdot
.58812 .32186 Mdot
.60572 .48802 Mdot
.48265 .35424 Mdot
.46957 .37301 Mdot
.37545 .28145 Mdot
.64869 .33637 Mdot
.58305 .73008 Mdot
.27387 .52704 Mdot
.43055 .34196 Mdot
.42561 .75872 Mdot
.461 .35241 Mdot
.45239 .38172 Mdot
.53666 .37227 Mdot
.57301 .67288 Mdot
.26779 .54651 Mdot
.62532 .49462 Mdot
.36885 .46849 Mdot
.49221 .37623 Mdot
.58636 .52526 Mdot
.70285 .47227 Mdot
.47178 .36583 Mdot
.27081 .52876 Mdot
.39985 .28458 Mdot
.30993 .55154 Mdot
.30559 .53575 Mdot
.45602 .37229 Mdot
.3079 .4843 Mdot
.30013 .55183 Mdot
.38372 .28202 Mdot
.58827 .61938 Mdot
.33657 .67841 Mdot
.47751 .34974 Mdot
.75909 .45259 Mdot
.51287 .37039 Mdot
.71906 .45578 Mdot
.59455 .51408 Mdot
.63189 .50654 Mdot
.46795 .44474 Mdot
.61184 .65177 Mdot
.70956 .48422 Mdot
.57113 .72069 Mdot
.4222 .31792 Mdot
.2785 .46599 Mdot
.45237 .66263 Mdot
.60335 .60117 Mdot
.63081 .5077 Mdot
.60908 .42403 Mdot
.56273 .40316 Mdot
.39386 .68858 Mdot
.33375 .51826 Mdot
.39414 .39125 Mdot
.65254 .51013 Mdot
.5635 .69137 Mdot
.59042 .68473 Mdot
.34472 .6479 Mdot
.20482 .56819 Mdot
.5282 .37624 Mdot
.65199 .51229 Mdot
.38036 .25721 Mdot
.62167 .5213 Mdot
.61805 .49261 Mdot
.60061 .63753 Mdot
.47774 .38163 Mdot
.57716 .29152 Mdot
.58813 .64789 Mdot
.74119 .46548 Mdot
.32425 .53003 Mdot
.74633 .44492 Mdot
.27412 .62199 Mdot
.30918 .31293 Mdot
.58219 .65684 Mdot
.62402 .53567 Mdot
.49985 .38805 Mdot
.26999 .5235 Mdot
.27034 .5532 Mdot
.31964 .4936 Mdot
.71257 .47275 Mdot
.60668 .68974 Mdot
.64658 .76024 Mdot
.49914 .35839 Mdot
.30963 .52195 Mdot
.72225 .44376 Mdot
.50713 .37076 Mdot
.41312 .68134 Mdot
.39687 .2823 Mdot
.30439 .52337 Mdot
.38239 .30938 Mdot
.31239 .52864 Mdot
.58981 .68191 Mdot
.5195 .36219 Mdot
.47366 .34433 Mdot
.64122 .41344 Mdot
.74769 .46605 Mdot
.30775 .55473 Mdot
.56789 .34912 Mdot
.44234 .35722 Mdot
.66508 .38672 Mdot
.46799 .36828 Mdot
.37528 .33123 Mdot
.65895 .49762 Mdot
.60112 .52576 Mdot
.46859 .39312 Mdot
.47316 .35283 Mdot
.27061 .55196 Mdot
.34412 .38786 Mdot
.31123 .3124 Mdot
.43926 .68826 Mdot
.32767 .49965 Mdot
.58443 .64843 Mdot
.58563 .70963 Mdot
.56114 .66216 Mdot
.73294 .44213 Mdot
.3787 .2909 Mdot
.52329 .37229 Mdot
.44008 .67385 Mdot
.72773 .47853 Mdot
.31383 .51451 Mdot
.73463 .45295 Mdot
.5764 .34089 Mdot
.76144 .45725 Mdot
.61052 .49067 Mdot
.39207 .79653 Mdot
.36779 .29453 Mdot
.74854 .45694 Mdot
.30797 .4901 Mdot
.5564 .433 Mdot
.50285 .34368 Mdot
.319 .33835 Mdot
.71017 .48204 Mdot
.55089 .68086 Mdot
.45424 .36265 Mdot
.5198 .28555 Mdot
.42022 .70315 Mdot
.75671 .44562 Mdot
.40998 .71332 Mdot
.3955 .29112 Mdot
.31847 .46758 Mdot
.2996 .51737 Mdot
.4492 .65464 Mdot
.4625 .38827 Mdot
.75798 .44597 Mdot
.58399 .65993 Mdot
.41168 .38407 Mdot
.59814 .73965 Mdot
.58222 .52237 Mdot
.66076 .39639 Mdot
.60238 .62144 Mdot
.4006 .36275 Mdot
.39574 .70447 Mdot
.44008 .33696 Mdot
.37242 .30419 Mdot
.44352 .35427 Mdot
.58614 .64178 Mdot
.585 .66752 Mdot
.63895 .75966 Mdot
.48792 .34306 Mdot
.53081 .36544 Mdot
.33247 .57617 Mdot
.60893 .68497 Mdot
.29003 .54448 Mdot
.28121 .51413 Mdot
.60411 .64717 Mdot
.32476 .54175 Mdot
.74012 .45674 Mdot
.56259 .30378 Mdot
.39563 .70324 Mdot
.40946 .72319 Mdot
.58108 .65945 Mdot
.59165 .63056 Mdot
.57134 .67445 Mdot
.39805 .28953 Mdot
.30024 .53952 Mdot
.53395 .39473 Mdot
.48963 .36129 Mdot
.47659 .33643 Mdot
.28773 .49163 Mdot
.4494 .38224 Mdot
.50861 .33881 Mdot
.70854 .47361 Mdot
.5847 .67902 Mdot
.4297 .70705 Mdot
.47229 .23841 Mdot
.43618 .67596 Mdot
.47481 .38874 Mdot
.33627 .66492 Mdot
.33289 .51967 Mdot
.75727 .46699 Mdot
.37154 .27382 Mdot
.7654 .45632 Mdot
.41935 .65393 Mdot
.33309 .57423 Mdot
.58337 .30965 Mdot
.53505 .38921 Mdot
.57696 .34651 Mdot
.74443 .66791 Mdot
.27994 .56825 Mdot
.43088 .68536 Mdot
.36645 .28237 Mdot
.60954 .48621 Mdot
.37081 .2628 Mdot
.5142 .36067 Mdot
.43311 .34033 Mdot
.51356 .28783 Mdot
.47967 .39409 Mdot
.31902 .48894 Mdot
.55361 .38572 Mdot
.63461 .53287 Mdot
.45871 .34391 Mdot
.24367 .649 Mdot
.4962 .38069 Mdot
.53015 .3727 Mdot
.51926 .38389 Mdot
.44032 .35612 Mdot
.29429 .48529 Mdot
.37223 .28433 Mdot
.43738 .67888 Mdot
.56289 .3025 Mdot
.3968 .70337 Mdot
.57653 .66194 Mdot
.62138 .54398 Mdot
.2751 .50671 Mdot
.76565 .45746 Mdot
.43348 .62348 Mdot
.52277 .28389 Mdot
.55848 .66227 Mdot
.6294 .41984 Mdot
.70701 .48916 Mdot
.6106 .4959 Mdot
.74189 .44141 Mdot
.59418 .63745 Mdot
.4083 .68936 Mdot
.53052 .38667 Mdot
.28934 .5391 Mdot
.28895 .51538 Mdot
.45604 .34736 Mdot
.33875 .69374 Mdot
.42867 .71184 Mdot
.55507 .69983 Mdot
.52701 .38004 Mdot
.46788 .3863 Mdot
.31323 .54646 Mdot
.58008 .62901 Mdot
.5572 .38519 Mdot
.72375 .46965 Mdot
.45922 .35713 Mdot
.64433 .52362 Mdot
.57676 .34193 Mdot
.43833 .68447 Mdot
.63137 .52485 Mdot
.50536 .38325 Mdot
.56919 .33594 Mdot
.39736 .30772 Mdot
.67384 .48542 Mdot
.61654 .62957 Mdot
.45578 .37127 Mdot
.46782 .34692 Mdot
.29248 .49119 Mdot
.39436 .70314 Mdot
.30696 .50334 Mdot
.31494 .58212 Mdot
.63172 .50691 Mdot
.39691 .71644 Mdot
.44091 .35683 Mdot
.44614 .69741 Mdot
.39499 .27965 Mdot
.4902 .35618 Mdot
.43077 .68703 Mdot
.30795 .53736 Mdot
.21947 .62725 Mdot
.39315 .37958 Mdot
.3941 .28798 Mdot
.51262 .37237 Mdot
.58821 .7308 Mdot
.61056 .54345 Mdot
.52341 .39621 Mdot
.28787 .51321 Mdot
.50615 .36876 Mdot
.44219 .66837 Mdot
.73646 .44944 Mdot
.29927 .51113 Mdot
.59608 .61812 Mdot
.59525 .67449 Mdot
.61767 .6468 Mdot
.6134 .48986 Mdot
.401 .28446 Mdot
.29585 .49216 Mdot
.28486 .50516 Mdot
.57136 .35694 Mdot
.58803 .67674 Mdot
.72574 .46087 Mdot
.46957 .34148 Mdot
.65101 .51662 Mdot
.38916 .72015 Mdot
.28392 .28796 Mdot
.57983 .30935 Mdot
.71866 .44825 Mdot
.56943 .40756 Mdot
.62627 .50976 Mdot
.49593 .39135 Mdot
.75788 .44631 Mdot
.60206 .64528 Mdot
.403 .30461 Mdot
.73112 .49212 Mdot
.54911 .67514 Mdot
.57076 .6439 Mdot
.44616 .69517 Mdot
.61406 .61656 Mdot
.76323 .44694 Mdot
.5992 .50955 Mdot
.29335 .51331 Mdot
.47276 .36841 Mdot
.61913 .50174 Mdot
.57845 .68536 Mdot
.6407 .49589 Mdot
.52207 .38963 Mdot
.31793 .54275 Mdot
.56383 .67578 Mdot
.48617 .35161 Mdot
.36303 .28978 Mdot
.32536 .3439 Mdot
.58427 .62327 Mdot
.51277 .404 Mdot
.71734 .50331 Mdot
.56641 .6542 Mdot
.58754 .63938 Mdot
.45471 .37181 Mdot
.75104 .47868 Mdot
.49173 .3725 Mdot
.4117 .68493 Mdot
.58488 .34305 Mdot
.39617 .7132 Mdot
.66965 .38845 Mdot
.45087 .3549 Mdot
.42979 .36677 Mdot
.27413 .46845 Mdot
.79438 .44453 Mdot
.66549 .36222 Mdot
.48315 .38797 Mdot
.28773 .5553 Mdot
.58673 .33541 Mdot
.60936 .3521 Mdot
.28654 .57604 Mdot
.72587 .45037 Mdot
.42456 .70247 Mdot
.47956 .3438 Mdot
.24989 .64657 Mdot
.7197 .462 Mdot
.66684 .38979 Mdot
.42768 .3579 Mdot
.30808 .51333 Mdot
.5247 .37061 Mdot
.29452 .51927 Mdot
.51128 .37972 Mdot
.33347 .3614 Mdot
.36103 .63654 Mdot
.53602 .27869 Mdot
.60235 .50567 Mdot
.39011 .74226 Mdot
.37526 .33251 Mdot
.7349 .45846 Mdot
.37552 .30604 Mdot
.6307 .51254 Mdot
.40396 .69276 Mdot
.44402 .6469 Mdot
.57133 .67619 Mdot
.4211 .67149 Mdot
.32453 .51628 Mdot
.5581 .65253 Mdot
.64981 .5017 Mdot
.40741 .27807 Mdot
.76871 .45156 Mdot
.39682 .71671 Mdot
.46939 .36127 Mdot
.461 .33437 Mdot
.59112 .73419 Mdot
.68003 .75133 Mdot
.33961 .51147 Mdot
.30121 .30565 Mdot
.33279 .57463 Mdot
.74165 .46866 Mdot
.581 .6249 Mdot
.52016 .37364 Mdot
.47854 .38013 Mdot
.57321 .64019 Mdot
.26971 .52335 Mdot
.72144 .48571 Mdot
.68174 .47746 Mdot
.44009 .67 Mdot
.71075 .7459 Mdot
.29774 .51154 Mdot
.70931 .74749 Mdot
.64239 .7587 Mdot
.20423 .56185 Mdot
.66569 .36538 Mdot
.4199 .68432 Mdot
.71028 .7471 Mdot
.30932 .51666 Mdot
.4985 .39783 Mdot
.6395 .51461 Mdot
.62059 .48906 Mdot
.31718 .53959 Mdot
.57296 .66051 Mdot
.75135 .47909 Mdot
.50935 .35586 Mdot
.6832 .49528 Mdot
.26859 .55175 Mdot
.60932 .67882 Mdot
.61491 .52124 Mdot
.43568 .6995 Mdot
.50939 .37134 Mdot
.71165 .47408 Mdot
.41923 .68605 Mdot
.6107 .53443 Mdot
.55066 .29083 Mdot
.48562 .40235 Mdot
.37601 .26959 Mdot
.41851 .70252 Mdot
.56047 .37901 Mdot
.46319 .35402 Mdot
.39579 .70462 Mdot
.64632 .48633 Mdot
.39642 .74911 Mdot
.55947 .38501 Mdot
.34377 .64973 Mdot
.55478 .66345 Mdot
.61193 .61116 Mdot
.59886 .59356 Mdot
.5792 .7273 Mdot
.39804 .69334 Mdot
.61646 .50774 Mdot
.66939 .76396 Mdot
.3945 .70509 Mdot
.44247 .37124 Mdot
.48093 .34451 Mdot
.4115 .39453 Mdot
.61312 .53561 Mdot
.61052 .52833 Mdot
.37132 .49914 Mdot
.37031 .29197 Mdot
.61562 .52002 Mdot
.46354 .36437 Mdot
.27771 .50858 Mdot
.43008 .67995 Mdot
.81388 .38006 Mdot
.42815 .65766 Mdot
.40787 .29912 Mdot
.55986 .66805 Mdot
.55547 .65732 Mdot
.47356 .36693 Mdot
.50455 .63828 Mdot
.76148 .27787 Mdot
.48099 .34427 Mdot
.37126 .27396 Mdot
.66969 .39088 Mdot
.45728 .34477 Mdot
.33297 .50044 Mdot
.6342 .52987 Mdot
.28288 .50109 Mdot
.42333 .68589 Mdot
.72494 .4513 Mdot
.79635 .45037 Mdot
.425 .70154 Mdot
.49236 .37968 Mdot
.59496 .53007 Mdot
.4799 .36229 Mdot
.50748 .39496 Mdot
.57254 .33369 Mdot
.71535 .45297 Mdot
.57049 .66951 Mdot
.76645 .45542 Mdot
.28285 .5446 Mdot
.29484 .29925 Mdot
.73253 .45746 Mdot
.41066 .38317 Mdot
.57877 .35038 Mdot
.67288 .7536 Mdot
.28973 .51413 Mdot
.71637 .45884 Mdot
.42141 .70538 Mdot
.59225 .37076 Mdot
.41452 .37353 Mdot
.4265 .6704 Mdot
.50994 .39287 Mdot
.27907 .51299 Mdot
.35525 .5549 Mdot
.42327 .71773 Mdot
.30194 .49891 Mdot
.55912 .38142 Mdot
.39216 .29285 Mdot
.43922 .68128 Mdot
.65254 .35133 Mdot
.40206 .72111 Mdot
.37789 .35032 Mdot
.39173 .279 Mdot
.30095 .51131 Mdot
.34947 .30297 Mdot
.3296 .57377 Mdot
.60459 .52729 Mdot
.50038 .40136 Mdot
.7289 .46031 Mdot
.57374 .35423 Mdot
.59706 .61564 Mdot
.33405 .4849 Mdot
.2983 .52757 Mdot
.38569 .71835 Mdot
.29988 .50087 Mdot
.33215 .52644 Mdot
.44744 .65386 Mdot
.32934 .50407 Mdot
.49176 .37695 Mdot
.30224 .26459 Mdot
.31116 .49388 Mdot
.42107 .69521 Mdot
.71655 .47454 Mdot
.31777 .48989 Mdot
.63217 .75546 Mdot
.45754 .35282 Mdot
.58839 .69478 Mdot
.74445 .48423 Mdot
.28989 .4884 Mdot
.73274 .46053 Mdot
.57386 .68514 Mdot
.69801 .48002 Mdot
.39155 .72873 Mdot
.40995 .72655 Mdot
.66493 .51129 Mdot
.34617 .64541 Mdot
.28213 .54538 Mdot
.56102 .6458 Mdot
.48573 .34102 Mdot
.52326 .38473 Mdot
.77701 .44718 Mdot
.29999 .55782 Mdot
.33913 .70486 Mdot
.61837 .51663 Mdot
.37008 .46553 Mdot
.43722 .70041 Mdot
.55448 .69846 Mdot
.58548 .30878 Mdot
.42287 .63327 Mdot
.63254 .53401 Mdot
.62832 .51006 Mdot
.47565 .36064 Mdot
.64896 .41032 Mdot
.75103 .44403 Mdot
.45228 .75365 Mdot
.3959 .30212 Mdot
.58114 .63326 Mdot
.51076 .38582 Mdot
.37942 .29893 Mdot
.47348 .38458 Mdot
.72784 .44278 Mdot
.41744 .66845 Mdot
.28741 .52044 Mdot
.71869 .4549 Mdot
.59575 .6741 Mdot
.54431 .24913 Mdot
.52483 .39627 Mdot
.52437 .40266 Mdot
.56861 .65884 Mdot
.27871 .53975 Mdot
.57958 .6663 Mdot
.39594 .70369 Mdot
.73504 .45464 Mdot
.39928 .28633 Mdot
.61418 .53575 Mdot
.58874 .70129 Mdot
.40798 .68339 Mdot
.59024 .61751 Mdot
.45014 .68783 Mdot
.63167 .50895 Mdot
.5135 .4058 Mdot
.61125 .6838 Mdot
.64283 .50315 Mdot
.3564 .4229 Mdot
.55012 .2939 Mdot
.20879 .55077 Mdot
.57309 .65704 Mdot
.63901 .6415 Mdot
.41972 .68954 Mdot
.41156 .66088 Mdot
.37303 .34638 Mdot
.71235 .22844 Mdot
.55361 .38313 Mdot
.34689 .73335 Mdot
.3954 .70236 Mdot
.4129 .70082 Mdot
.57746 .66933 Mdot
.30895 .53773 Mdot
.26395 .47625 Mdot
.56187 .6837 Mdot
.66228 .37743 Mdot
.3137 .51486 Mdot
.42704 .372 Mdot
.59733 .70197 Mdot
.38106 .28038 Mdot
.3362 .37144 Mdot
.7061 .47482 Mdot
.65573 .40134 Mdot
.45259 .66529 Mdot
.49485 .35095 Mdot
.22671 .64904 Mdot
.57416 .67756 Mdot
.63924 .49704 Mdot
.43868 .74919 Mdot
.45692 .33394 Mdot
.50742 .38872 Mdot
.4981 .36839 Mdot
.77527 .45231 Mdot
.34775 .40036 Mdot
.50944 .35937 Mdot
.5427 .28607 Mdot
.40455 .28541 Mdot
.6039 .60349 Mdot
.76518 .45347 Mdot
.61964 .42373 Mdot
.6224 .74376 Mdot
.37107 .4714 Mdot
.43325 .33907 Mdot
.41782 .66141 Mdot
.37095 .29183 Mdot
.43276 .69053 Mdot
.44247 .69618 Mdot
.72401 .73866 Mdot
.28589 .51325 Mdot
.39741 .29822 Mdot
.60867 .64474 Mdot
.2691 .47073 Mdot
.38183 .29795 Mdot
.29728 .3018 Mdot
.38784 .68611 Mdot
.69667 .20303 Mdot
.40529 .66523 Mdot
.63081 .49134 Mdot
.32675 .51412 Mdot
.28198 .55616 Mdot
.57523 .34618 Mdot
.29446 .54369 Mdot
.58106 .72768 Mdot
.29741 .49194 Mdot
.82405 .59514 Mdot
.29326 .57698 Mdot
.41578 .69289 Mdot
.40986 .72425 Mdot
.37572 .28646 Mdot
.48682 .37649 Mdot
.57663 .2942 Mdot
.61846 .51747 Mdot
.48293 .40077 Mdot
.58873 .64753 Mdot
.63588 .75749 Mdot
.37574 .77987 Mdot
.33089 .50919 Mdot
.40404 .68566 Mdot
.509 .38813 Mdot
.39308 .28038 Mdot
.49942 .39983 Mdot
.38752 .63041 Mdot
.38298 .31837 Mdot
.48779 .36073 Mdot
.37794 .28935 Mdot
.56005 .67731 Mdot
.59358 .73226 Mdot
.20544 .56673 Mdot
.71791 .74176 Mdot
.47203 .38025 Mdot
.73628 .47389 Mdot
.72958 .44271 Mdot
.54087 .37283 Mdot
.56486 .56346 Mdot
.562 .3789 Mdot
.46969 .36016 Mdot
.54147 .24663 Mdot
.56441 .69387 Mdot
.60701 .4889 Mdot
.5816 .6841 Mdot
.27385 .56457 Mdot
.59608 .50787 Mdot
.59366 .64314 Mdot
.56185 .26913 Mdot
.62581 .5042 Mdot
.40093 .75233 Mdot
.71491 .46589 Mdot
.46218 .36057 Mdot
.37209 .3693 Mdot
.60735 .68947 Mdot
.41081 .69013 Mdot
.32419 .50251 Mdot
.43664 .68175 Mdot
.58177 .72511 Mdot
.66754 .38117 Mdot
.60992 .53129 Mdot
.42524 .66023 Mdot
.37799 .2665 Mdot
.73371 .47631 Mdot
.39687 .6732 Mdot
.40104 .28105 Mdot
.53981 .36908 Mdot
.73623 .25772 Mdot
.51726 .35659 Mdot
.63704 .75819 Mdot
.39428 .70979 Mdot
.6101 .4853 Mdot
.47399 .36939 Mdot
.60055 .68926 Mdot
.67124 .52199 Mdot
.48042 .3602 Mdot
.60038 .6188 Mdot
.47311 .34738 Mdot
.75874 .44742 Mdot
.28834 .4943 Mdot
.58915 .33235 Mdot
.76837 .43331 Mdot
.72233 .45311 Mdot
.51774 .28277 Mdot
.50936 .40095 Mdot
.50626 .66918 Mdot
.30861 .51002 Mdot
.47808 .39006 Mdot
.76478 .43116 Mdot
.32094 .52955 Mdot
.32061 .50925 Mdot
.40546 .30287 Mdot
.44279 .66603 Mdot
.56899 .66603 Mdot
.75065 .46968 Mdot
.60949 .74191 Mdot
.49397 .35163 Mdot
.38252 .3082 Mdot
.71825 .46023 Mdot
.42 .6781 Mdot
.39633 .29544 Mdot
.36166 .75859 Mdot
.56132 .30059 Mdot
.39208 .6797 Mdot
.43384 .34191 Mdot
.35427 .29936 Mdot
.26872 .536 Mdot
.23206 .65014 Mdot
.3605 .63759 Mdot
.5929 .68137 Mdot
.6138 .51942 Mdot
.28677 .29266 Mdot
.71222 .47219 Mdot
.25359 .48346 Mdot
.52295 .3875 Mdot
.51771 .37703 Mdot
.27591 .51081 Mdot
.53721 .38827 Mdot
.33257 .51429 Mdot
.63145 .75391 Mdot
.70914 .22221 Mdot
.29104 .51757 Mdot
.30153 .52177 Mdot
.41302 .29678 Mdot
.59043 .71648 Mdot
.32508 .52999 Mdot
.47707 .3427 Mdot
.5817 .72528 Mdot
.67254 .48872 Mdot
.7254 .48409 Mdot
.77238 .46643 Mdot
.33645 .50963 Mdot
.41025 .36781 Mdot
.38768 .27269 Mdot
.4296 .43643 Mdot
.57127 .40895 Mdot
.39731 .69298 Mdot
.45938 .3382 Mdot
.62212 .51431 Mdot
.5763 .6827 Mdot
.52215 .35818 Mdot
.4628 .36496 Mdot
.28588 .52572 Mdot
.70154 .47887 Mdot
.40293 .71365 Mdot
.6397 .50063 Mdot
.61843 .64864 Mdot
.73394 .46728 Mdot
.32706 .53833 Mdot
.37545 .33632 Mdot
.61022 .54064 Mdot
.65065 .51357 Mdot
.49173 .39139 Mdot
.45851 .37501 Mdot
.62341 .53833 Mdot
.42687 .69833 Mdot
.59274 .68315 Mdot
.62381 .49523 Mdot
.57018 .36262 Mdot
.57481 .28417 Mdot
.49093 .38792 Mdot
.30027 .49423 Mdot
.40363 .68967 Mdot
.60949 .52937 Mdot
.6666 .76504 Mdot
.46609 .34132 Mdot
.41946 .36337 Mdot
.64493 .4644 Mdot
.61986 .51101 Mdot
.26408 .47596 Mdot
.76168 .46528 Mdot
.39174 .27929 Mdot
.54044 .28317 Mdot
.45208 .385 Mdot
.43937 .33763 Mdot
.60049 .64206 Mdot
.42477 .70827 Mdot
.66291 .50999 Mdot
.58429 .67832 Mdot
.32055 .50699 Mdot
.43873 .43904 Mdot
.27928 .52061 Mdot
.28637 .50422 Mdot
.33357 .48036 Mdot
.43889 .69023 Mdot
.28604 .29042 Mdot
.62251 .53995 Mdot
.52897 .3755 Mdot
.40523 .67594 Mdot
.32704 .52951 Mdot
.43798 .37146 Mdot
.333 .51906 Mdot
.30496 .5567 Mdot
.45497 .38746 Mdot
.38145 .28832 Mdot
.53353 .28247 Mdot
.40913 .35093 Mdot
.76798 .46138 Mdot
.27096 .53612 Mdot
.41678 .36754 Mdot
.51843 .37003 Mdot
.47165 .37445 Mdot
.37435 .28564 Mdot
.72583 .44741 Mdot
.46618 .44492 Mdot
.52046 .38881 Mdot
.65322 .41127 Mdot
.43862 .37079 Mdot
.29777 .55857 Mdot
.40816 .74372 Mdot
.40829 .29887 Mdot
.55712 .66211 Mdot
.27074 .52112 Mdot
.70524 .47454 Mdot
.31794 .47282 Mdot
.36767 .27173 Mdot
.40932 .70596 Mdot
.30438 .52326 Mdot
.56756 .69069 Mdot
.41312 .68671 Mdot
.40237 .72132 Mdot
.37361 .28282 Mdot
.59968 .67619 Mdot
.70124 .47809 Mdot
.41271 .71869 Mdot
.36387 .26805 Mdot
.41451 .69273 Mdot
.21749 .52295 Mdot
.52666 .40344 Mdot
.54354 .28515 Mdot
.60786 .50845 Mdot
.66166 .5007 Mdot
.40045 .71648 Mdot
.72188 .4698 Mdot
.39631 .29634 Mdot
.32092 .49494 Mdot
.72654 .47595 Mdot
.33795 .37397 Mdot
.55579 .65733 Mdot
.35497 .55486 Mdot
.6016 .73968 Mdot
.29733 .54652 Mdot
.65817 .39885 Mdot
.70698 .46655 Mdot
.64936 .52362 Mdot
.58167 .32482 Mdot
.61577 .52364 Mdot
.5294 .36555 Mdot
.39614 .29792 Mdot
.49323 .37691 Mdot
.55937 .66409 Mdot
.77522 .45323 Mdot
.30697 .4929 Mdot
.74611 .49449 Mdot
.42721 .67534 Mdot
.55198 .38861 Mdot
.63205 .49432 Mdot
.39483 .28709 Mdot
.33073 .5209 Mdot
.29629 .5527 Mdot
.3453 .38977 Mdot
.56512 .65515 Mdot
.76847 .47853 Mdot
.4928 .3871 Mdot
.69603 .50196 Mdot
.39898 .71613 Mdot
.34422 .6472 Mdot
.5803 .69774 Mdot
.69375 .20227 Mdot
.5877 .67484 Mdot
.67234 .48347 Mdot
.30099 .54887 Mdot
.75382 .4518 Mdot
.48794 .3817 Mdot
.29774 .48635 Mdot
.26205 .47753 Mdot
.76053 .47762 Mdot
.76469 .45826 Mdot
.36872 .6331 Mdot
.39845 .68264 Mdot
.64771 .5084 Mdot
.4389 .37027 Mdot
.43377 .3674 Mdot
.4903 .34232 Mdot
.40258 .68298 Mdot
.38829 .28987 Mdot
.4032 .74136 Mdot
.36604 .28076 Mdot
.76399 .43098 Mdot
.58559 .63795 Mdot
.46126 .82017 Mdot
.28531 .49439 Mdot
.45617 .44308 Mdot
.24491 .4844 Mdot
.55323 .29653 Mdot
.42288 .66588 Mdot
.64693 .48616 Mdot
.57361 .66849 Mdot
.46965 .65854 Mdot
.58886 .63599 Mdot
.80192 .34211 Mdot
.41016 .39469 Mdot
.40662 .74582 Mdot
.48509 .40079 Mdot
.60789 .65713 Mdot
.40356 .35638 Mdot
.6223 .49612 Mdot
.59467 .52932 Mdot
.36227 .29721 Mdot
.31281 .31754 Mdot
.76898 .45921 Mdot
.4888 .38249 Mdot
.28128 .50413 Mdot
.48538 .38138 Mdot
.48512 .38217 Mdot
.51539 .39468 Mdot
.44918 .65407 Mdot
.51283 .40544 Mdot
.48889 .3767 Mdot
.64856 .76264 Mdot
.67006 .49581 Mdot
.61573 .61777 Mdot
.26921 .55 Mdot
.72786 .47852 Mdot
.27454 .56452 Mdot
.58606 .32869 Mdot
.41883 .65622 Mdot
.34519 .39359 Mdot
.3874 .28326 Mdot
.33621 .49085 Mdot
.42161 .65868 Mdot
.72682 .48782 Mdot
.62567 .51335 Mdot
.19806 .59183 Mdot
.5713 .72083 Mdot
.62758 .52333 Mdot
.59197 .62154 Mdot
.41842 .34383 Mdot
.29475 .51098 Mdot
.61654 .52302 Mdot
.41255 .71454 Mdot
.59956 .63634 Mdot
.52212 .28286 Mdot
.50276 .36361 Mdot
.57603 .65165 Mdot
.61642 .50435 Mdot
.57422 .35369 Mdot
.58591 .33646 Mdot
.6084 .65641 Mdot
.44514 .68406 Mdot
.40837 .72228 Mdot
.71871 .47886 Mdot
.28586 .55195 Mdot
.28494 .54073 Mdot
.42643 .67661 Mdot
.47428 .66052 Mdot
.48788 .35103 Mdot
.49381 .35663 Mdot
.58401 .31607 Mdot
.4628 .38596 Mdot
.58081 .7291 Mdot
.627 .52182 Mdot
.29045 .53501 Mdot
.39583 .29836 Mdot
.38638 .30456 Mdot
.49277 .38233 Mdot
.66611 .3737 Mdot
.56256 .67566 Mdot
.38363 .27278 Mdot
.75709 .44595 Mdot
.32288 .33607 Mdot
.46038 .35128 Mdot
.7462 .43317 Mdot
.29411 .55064 Mdot
.42472 .76114 Mdot
.41025 .69183 Mdot
.61069 .64861 Mdot
.60968 .6467 Mdot
.74751 .66525 Mdot
.28323 .49709 Mdot
.62643 .52349 Mdot
.54886 .67014 Mdot
.60467 .49554 Mdot
.76276 .4603 Mdot
.56553 .43208 Mdot
.58172 .7284 Mdot
.61538 .6175 Mdot
.39158 .73219 Mdot
.44817 .33863 Mdot
.45874 .35867 Mdot
.34239 .65252 Mdot
.46874 .36949 Mdot
.72851 .45601 Mdot
.39585 .68079 Mdot
.30558 .52146 Mdot
.76193 .46979 Mdot
.41227 .66397 Mdot
.28564 .54399 Mdot
.37594 .28089 Mdot
.43657 .3693 Mdot
.32251 .50528 Mdot
.32193 .54316 Mdot
.48483 .34885 Mdot
.7354 .73278 Mdot
.28794 .52715 Mdot
.32618 .50797 Mdot
.32104 .3329 Mdot
.61556 .65911 Mdot
.67307 .51579 Mdot
.43996 .66403 Mdot
.49326 .37294 Mdot
.57919 .64161 Mdot
.75622 .45895 Mdot
.29877 .52993 Mdot
.46716 .38004 Mdot
.49673 .35345 Mdot
.73369 .47578 Mdot
.75797 .44371 Mdot
.72204 .47308 Mdot
.42536 .71621 Mdot
.38374 .28082 Mdot
.32822 .52146 Mdot
.4178 .67141 Mdot
.70794 .47047 Mdot
.76791 .44852 Mdot
.78144 .43228 Mdot
.48508 .35015 Mdot
.75769 .44279 Mdot
.2928 .298 Mdot
.55663 .26513 Mdot
.60186 .49738 Mdot
.62487 .61126 Mdot
.61501 .67942 Mdot
.64897 .47924 Mdot
.42325 .70839 Mdot
.36875 .27856 Mdot
.72785 .48493 Mdot
.61979 .49957 Mdot
.49791 .35886 Mdot
.45337 .34648 Mdot
.73266 .47339 Mdot
.66976 .38035 Mdot
.28383 .52647 Mdot
.2079 .55673 Mdot
.73111 .47768 Mdot
.60861 .66989 Mdot
.56592 .69629 Mdot
.5876 .66687 Mdot
.48707 .38719 Mdot
.43925 .3802 Mdot
.5672 .39844 Mdot
.3657 .44223 Mdot
.39639 .68921 Mdot
.30158 .55158 Mdot
.31841 .33199 Mdot
.32014 .51112 Mdot
.56429 .64824 Mdot
.72163 .46925 Mdot
.27364 .51959 Mdot
.41634 .72059 Mdot
.40693 .72089 Mdot
.61233 .6795 Mdot
.58939 .6762 Mdot
.583 .65824 Mdot
.27998 .49847 Mdot
.31714 .54144 Mdot
.4699 .39569 Mdot
.29552 .49965 Mdot
.63112 .74649 Mdot
.63051 .75368 Mdot
.60904 .68758 Mdot
.42518 .69333 Mdot
.30618 .53507 Mdot
.46984 .34677 Mdot
.51185 .28836 Mdot
.56771 .69963 Mdot
.70914 .48071 Mdot
.3018 .26526 Mdot
.71465 .2327 Mdot
.37543 .30335 Mdot
.40232 .7028 Mdot
.60082 .51055 Mdot
.49985 .37168 Mdot
.58979 .68495 Mdot
.58163 .50673 Mdot
.63196 .53026 Mdot
.5388 .39754 Mdot
.41791 .31723 Mdot
.40428 .69719 Mdot
.58865 .32768 Mdot
.62409 .49775 Mdot
.40327 .28175 Mdot
.39974 .67621 Mdot
.59168 .70135 Mdot
.60085 .59721 Mdot
.37174 .49288 Mdot
.58435 .42936 Mdot
.60421 .53088 Mdot
.47804 .33873 Mdot
.59391 .64732 Mdot
.7575 .47387 Mdot
.59087 .6505 Mdot
.30675 .55846 Mdot
.6155 .66434 Mdot
.46784 .35072 Mdot
.32637 .52461 Mdot
.40535 .72111 Mdot
.58619 .37876 Mdot
.78952 .46205 Mdot
.59992 .69272 Mdot
.64475 .5291 Mdot
.37525 .29814 Mdot
.40337 .27165 Mdot
.66181 .50047 Mdot
.46092 .3575 Mdot
.43137 .68725 Mdot
.33165 .51431 Mdot
.41873 .67609 Mdot
.66961 .5241 Mdot
.22307 .50662 Mdot
.40925 .69309 Mdot
.4454 .38491 Mdot
.75303 .47826 Mdot
.66758 .37829 Mdot
.47069 .35311 Mdot
.41896 .71286 Mdot
.5284 .40183 Mdot
.27003 .53154 Mdot
.56701 .27583 Mdot
.55948 .29939 Mdot
.43122 .68157 Mdot
.64856 .49757 Mdot
.57883 .35146 Mdot
.67264 .51904 Mdot
.39656 .70366 Mdot
.55741 .26031 Mdot
.63509 .5187 Mdot
.73935 .46317 Mdot
.77415 .45386 Mdot
.73076 .46599 Mdot
.49039 .35994 Mdot
.35133 .29696 Mdot
.71117 .46152 Mdot
.44194 .64718 Mdot
.72998 .45133 Mdot
.66015 .48429 Mdot
.33761 .69949 Mdot
.76336 .44713 Mdot
.46705 .36378 Mdot
.36626 .28083 Mdot
.36925 .27888 Mdot
.58143 .69363 Mdot
.1991 .60477 Mdot
.64796 .76216 Mdot
.52049 .37461 Mdot
.31059 .32191 Mdot
.29173 .49373 Mdot
.64373 .53125 Mdot
.55782 .2982 Mdot
.37964 .26859 Mdot
.32134 .51743 Mdot
.58425 .32567 Mdot
.36489 .52933 Mdot
.60769 .49954 Mdot
.48847 .35738 Mdot
.27208 .51842 Mdot
.33553 .48526 Mdot
.6644 .36167 Mdot
.37123 .47528 Mdot
.29699 .54102 Mdot
.39415 .70284 Mdot
.42318 .7066 Mdot
.43168 .68561 Mdot
.59285 .67515 Mdot
.30051 .52387 Mdot
.53536 .36238 Mdot
.59132 .68186 Mdot
.51297 .39233 Mdot
.42973 .67902 Mdot
.55551 .29223 Mdot
.30237 .52136 Mdot
.47073 .35644 Mdot
.41925 .37315 Mdot
.60032 .62059 Mdot
.73307 .4754 Mdot
.30469 .30888 Mdot
.60693 .60864 Mdot
.4476 .69295 Mdot
.30571 .55977 Mdot
.66209 .48986 Mdot
.39898 .2742 Mdot
.47359 .38591 Mdot
.53064 .38791 Mdot
.40067 .27586 Mdot
.40841 .39021 Mdot
.64568 .51865 Mdot
.59563 .674 Mdot
.61564 .64618 Mdot
.4621 .34549 Mdot
.29585 .52495 Mdot
.71511 .4493 Mdot
.69081 .47151 Mdot
.74146 .48978 Mdot
.58158 .34435 Mdot
.54314 .28625 Mdot
.4458 .36764 Mdot
.49218 .44406 Mdot
.57328 .69284 Mdot
.61293 .48766 Mdot
.57797 .34051 Mdot
.73785 .4585 Mdot
.50112 .39753 Mdot
.27188 .55858 Mdot
.30259 .52807 Mdot
.57178 .65977 Mdot
.38894 .70963 Mdot
.60602 .53936 Mdot
.60781 .69131 Mdot
.46148 .34608 Mdot
.39146 .3029 Mdot
.39089 .69719 Mdot
.32718 .54177 Mdot
.73926 .46692 Mdot
.58552 .68609 Mdot
.74682 .45241 Mdot
.30144 .50081 Mdot
.29784 .53098 Mdot
.48369 .39577 Mdot
.76785 .48081 Mdot
.59778 .69771 Mdot
.48626 .38546 Mdot
.57995 .64971 Mdot
.59174 .734 Mdot
.38785 .72089 Mdot
.48217 .39242 Mdot
.26784 .47367 Mdot
.43495 .68426 Mdot
.51895 .3818 Mdot
.37094 .28129 Mdot
.39602 .29486 Mdot
.60824 .66248 Mdot
.70815 .48472 Mdot
.74334 .45849 Mdot
.25873 .4714 Mdot
.33838 .39045 Mdot
.44028 .35205 Mdot
.61219 .6723 Mdot
.35607 .28538 Mdot
.40904 .7015 Mdot
.30098 .54683 Mdot
.41173 .80254 Mdot
.41911 .69589 Mdot
.47607 .34699 Mdot
.7317 .4575 Mdot
.31571 .54969 Mdot
.59795 .50138 Mdot
.61778 .34552 Mdot
.65656 .50134 Mdot
.76019 .48418 Mdot
.64235 .50469 Mdot
.34682 .72837 Mdot
.58462 .65502 Mdot
.3291 .52506 Mdot
.40169 .7047 Mdot
.40917 .7042 Mdot
.58348 .62662 Mdot
.33945 .37437 Mdot
.20503 .56344 Mdot
.28785 .27875 Mdot
.56609 .71562 Mdot
.72306 .46456 Mdot
.5643 .27484 Mdot
.58649 .66853 Mdot
.60239 .61341 Mdot
.38919 .62965 Mdot
.34298 .64889 Mdot
.31064 .5342 Mdot
.50168 .35558 Mdot
.32644 .34597 Mdot
.5274 .38475 Mdot
.58265 .42983 Mdot
.42344 .67827 Mdot
.30025 .54699 Mdot
.35249 .63868 Mdot
.45158 .36127 Mdot
.50847 .37883 Mdot
.63356 .749 Mdot
.62148 .51804 Mdot
.68414 .74591 Mdot
.51056 .39857 Mdot
.5955 .66221 Mdot
.29759 .46203 Mdot
.60904 .50154 Mdot
.4151 .36865 Mdot
.39247 .70537 Mdot
.61022 .5308 Mdot
.61168 .49892 Mdot
.4949 .44273 Mdot
.34426 .56927 Mdot
.27535 .5339 Mdot
.74573 .44124 Mdot
.33797 .65423 Mdot
.39155 .68368 Mdot
.35751 .75146 Mdot
.4691 .34597 Mdot
.41245 .7247 Mdot
.68216 .47817 Mdot
.52096 .3804 Mdot
.38128 .2964 Mdot
.34495 .39085 Mdot
.46122 .33653 Mdot
.36354 .27836 Mdot
.41999 .69151 Mdot
.68616 .45113 Mdot
.43768 .34654 Mdot
.57441 .65489 Mdot
.30978 .53774 Mdot
.33159 .57814 Mdot
.74558 .47869 Mdot
.35769 .63822 Mdot
.70331 .21321 Mdot
.30151 .54626 Mdot
.4995 .36231 Mdot
.4111 .70061 Mdot
.59861 .51823 Mdot
.6073 .51173 Mdot
.6554 .51402 Mdot
.3055 .52825 Mdot
.61005 .5021 Mdot
.26487 .47105 Mdot
.58523 .32648 Mdot
.45204 .44247 Mdot
.4363 .69402 Mdot
.72522 .46273 Mdot
.68784 .49 Mdot
.59381 .73447 Mdot
.43972 .36937 Mdot
.58307 .42992 Mdot
.33914 .4807 Mdot
.72643 .45929 Mdot
.497 .37662 Mdot
.64793 .51623 Mdot
.5377 .24127 Mdot
.70657 .45372 Mdot
.64411 .50738 Mdot
.39875 .30408 Mdot
.2828 .54524 Mdot
.6214 .52607 Mdot
.3084 .52023 Mdot
.49577 .37898 Mdot
.56187 .37595 Mdot
.27831 .54567 Mdot
.20762 .61693 Mdot
.61483 .54212 Mdot
.40922 .66414 Mdot
.54552 .39482 Mdot
.47002 .37934 Mdot
.43072 .3733 Mdot
.60104 .52096 Mdot
.23956 .64711 Mdot
.5824 .64358 Mdot
.67422 .7627 Mdot
.5761 .72587 Mdot
.38627 .63123 Mdot
.36487 .76598 Mdot
.44906 .36269 Mdot
.33972 .37307 Mdot
.43391 .37549 Mdot
.43763 .67082 Mdot
.42007 .35827 Mdot
.48701 .37644 Mdot
.49293 .39132 Mdot
.57914 .64987 Mdot
.384 .70204 Mdot
.40674 .30136 Mdot
.57829 .34139 Mdot
.71598 .48878 Mdot
.30848 .50375 Mdot
.48954 .36906 Mdot
.3445 .50184 Mdot
.60968 .66225 Mdot
.20365 .54682 Mdot
.46851 .36307 Mdot
.62204 .51788 Mdot
.41672 .72246 Mdot
.40116 .71898 Mdot
.60531 .67366 Mdot
.60394 .6793 Mdot
.47038 .37935 Mdot
.42568 .67175 Mdot
.43391 .35954 Mdot
.57805 .35221 Mdot
.61909 .50306 Mdot
.75709 .46385 Mdot
.53239 .37559 Mdot
.206 .56084 Mdot
.80404 .42923 Mdot
.4886 .38718 Mdot
.27808 .51781 Mdot
.57963 .66066 Mdot
.56385 .64568 Mdot
.28699 .54103 Mdot
.56568 .64277 Mdot
.20214 .55198 Mdot
.35308 .29967 Mdot
.76263 .45588 Mdot
.36049 .2495 Mdot
.72448 .45201 Mdot
.60782 .52921 Mdot
.48397 .34991 Mdot
.47616 .72745 Mdot
.56581 .71669 Mdot
.47227 .23813 Mdot
.41638 .68308 Mdot
.61866 .48892 Mdot
.38698 .28735 Mdot
.74845 .48275 Mdot
.57575 .67976 Mdot
.59467 .52665 Mdot
.50527 .39804 Mdot
.27142 .5184 Mdot
.38935 .30928 Mdot
.61962 .49257 Mdot
.6064 .52556 Mdot
.59578 .52637 Mdot
.41258 .66377 Mdot
.32672 .49828 Mdot
.36895 .63293 Mdot
.60278 .62367 Mdot
.483 .40101 Mdot
.50044 .36509 Mdot
.30073 .55098 Mdot
.527 .37103 Mdot
.43541 .67619 Mdot
.27788 .28383 Mdot
.719 .47085 Mdot
.59769 .50912 Mdot
.27412 .62205 Mdot
.59209 .5133 Mdot
.40153 .29592 Mdot
.40622 .28107 Mdot
.26983 .55272 Mdot
.42774 .65919 Mdot
.42362 .34275 Mdot
.616 .62954 Mdot
.74119 .46457 Mdot
.40731 .72407 Mdot
.3895 .3004 Mdot
.46575 .35691 Mdot
.72696 .46081 Mdot
.35113 .64092 Mdot
.6971 .48658 Mdot
.39865 .70211 Mdot
.6365 .48746 Mdot
.50213 .28168 Mdot
.47701 .35962 Mdot
.62764 .51899 Mdot
.31738 .49677 Mdot
.39869 .68542 Mdot
.34925 .40131 Mdot
.61016 .49834 Mdot
.60801 .74227 Mdot
.39675 .71611 Mdot
.47336 .38635 Mdot
.32128 .47471 Mdot
.30496 .57868 Mdot
.32874 .50618 Mdot
.78742 .64432 Mdot
.61711 .74891 Mdot
.58118 .65604 Mdot
.42417 .69478 Mdot
.57576 .64273 Mdot
.75445 .47755 Mdot
.57121 .28782 Mdot
.60244 .68638 Mdot
.32113 .48892 Mdot
.58732 .63501 Mdot
.43293 .3603 Mdot
.41317 .661 Mdot
.59481 .70445 Mdot
.51027 .35289 Mdot
.3761 .27807 Mdot
.60942 .52537 Mdot
.70887 .45829 Mdot
.58327 .33451 Mdot
.49156 .34699 Mdot
.63012 .51441 Mdot
.47199 .35796 Mdot
.43438 .67535 Mdot
.58151 .38539 Mdot
.44875 .38342 Mdot
.56735 .71553 Mdot
.19851 .58177 Mdot
.61441 .64739 Mdot
.72314 .50245 Mdot
.51986 .38579 Mdot
.47744 .35631 Mdot
.38967 .29464 Mdot
.30925 .25964 Mdot
.44284 .70021 Mdot
.51419 .40598 Mdot
.56063 .64757 Mdot
.31761 .52007 Mdot
.27862 .50686 Mdot
.55882 .43266 Mdot
.63009 .51984 Mdot
.43899 .69912 Mdot
.48075 .35328 Mdot
.61153 .49232 Mdot
.56958 .31609 Mdot
.33817 .66601 Mdot
.62615 .75369 Mdot
.60316 .61645 Mdot
.26898 .54109 Mdot
.56068 .67411 Mdot
.39163 .29397 Mdot
.60659 .50473 Mdot
.61596 .75003 Mdot
.43071 .6368 Mdot
.74307 .46317 Mdot
.50149 .39227 Mdot
.66722 .36963 Mdot
.56055 .67846 Mdot
.59757 .67828 Mdot
.43285 .35892 Mdot
.31953 .46239 Mdot
.79557 .43065 Mdot
.4103 .6724 Mdot
.28197 .57162 Mdot
.37355 .35793 Mdot
.73749 .32862 Mdot
.42021 .70476 Mdot
.3799 .29768 Mdot
.56392 .69054 Mdot
.70365 .69418 Mdot
.32028 .51582 Mdot
.74204 .46493 Mdot
.5194 .36017 Mdot
.3006 .49215 Mdot
.56478 .71482 Mdot
.33228 .50471 Mdot
.61567 .51898 Mdot
.41672 .65957 Mdot
.57221 .6829 Mdot
.38563 .69225 Mdot
.26903 .47352 Mdot
.72043 .46688 Mdot
.63816 .41387 Mdot
.3648 .2883 Mdot
.34394 .38962 Mdot
.38197 .28241 Mdot
.67259 .4982 Mdot
.37858 .27969 Mdot
.32338 .57896 Mdot
.46981 .35405 Mdot
.43432 .34375 Mdot
.55514 .65898 Mdot
.48532 .38859 Mdot
.47648 .34316 Mdot
.42011 .37284 Mdot
.50871 .39084 Mdot
.48616 .38316 Mdot
.46449 .38162 Mdot
.27984 .5251 Mdot
.48204 .39692 Mdot
.32264 .54064 Mdot
.3419 .50501 Mdot
.6022 .62275 Mdot
.77384 .45631 Mdot
.75979 .44556 Mdot
.56066 .37185 Mdot
.66665 .37076 Mdot
.32462 .34226 Mdot
.31509 .51768 Mdot
.40017 .71715 Mdot
.44746 .38078 Mdot
.7953 .4363 Mdot
.56021 .37322 Mdot
.5828 .69446 Mdot
.61013 .6686 Mdot
.50962 .35159 Mdot
.71763 .23753 Mdot
.50971 .39933 Mdot
.58072 .30957 Mdot
.48983 .3609 Mdot
.47781 .39115 Mdot
.6174 .64481 Mdot
.65893 .39881 Mdot
.38635 .27187 Mdot
.35221 .55658 Mdot
.74722 .46194 Mdot
.62128 .52458 Mdot
.56228 .37529 Mdot
.37585 .34273 Mdot
.37097 .5012 Mdot
.38952 .29565 Mdot
.5808 .68923 Mdot
.29393 .53431 Mdot
.58234 .31718 Mdot
.41583 .67198 Mdot
.62031 .34858 Mdot
.21573 .51943 Mdot
.41505 .66854 Mdot
.73922 .46401 Mdot
.57783 .70137 Mdot
.5019 .3807 Mdot
.59839 .649 Mdot
.45241 .36421 Mdot
.58216 .30094 Mdot
.76111 .45984 Mdot
.31644 .4864 Mdot
.39225 .69863 Mdot
.28306 .52017 Mdot
.20774 .54865 Mdot
.5729 .409 Mdot
.65859 .75857 Mdot
.61242 .67599 Mdot
.71026 .50036 Mdot
.31764 .53845 Mdot
.46533 .3415 Mdot
.29046 .29596 Mdot
.298 .50933 Mdot
.27022 .52163 Mdot
.61439 .35433 Mdot
.67604 .38642 Mdot
.46228 .37887 Mdot
.30408 .49126 Mdot
.57781 .70232 Mdot
.76358 .45307 Mdot
.47138 .34345 Mdot
.60341 .50748 Mdot
.27506 .51414 Mdot
.56305 .67057 Mdot
.65219 .40445 Mdot
.59334 .66997 Mdot
.31727 .52766 Mdot
.61203 .65336 Mdot
.39521 .73431 Mdot
.60221 .6877 Mdot
.53315 .37883 Mdot
.47948 .35454 Mdot
.29478 .57771 Mdot
.29774 .53089 Mdot
.40155 .29553 Mdot
.5284 .37699 Mdot
.32615 .52922 Mdot
.55492 .69268 Mdot
.3687 .49843 Mdot
.39759 .29535 Mdot
.49338 .35185 Mdot
.71909 .45474 Mdot
.5743 .36187 Mdot
.60539 .35739 Mdot
.45886 .38957 Mdot
.7238 .46668 Mdot
.26922 .52172 Mdot
.47854 .35031 Mdot
.66798 .39335 Mdot
.55395 .65773 Mdot
.44809 .33437 Mdot
.59717 .51568 Mdot
.39426 .2755 Mdot
.64613 .33494 Mdot
.38813 .29965 Mdot
.32497 .51472 Mdot
.32036 .52852 Mdot
.55235 .67215 Mdot
.31967 .5026 Mdot
.59824 .51347 Mdot
.43399 .70372 Mdot
.21491 .52875 Mdot
.61664 .48735 Mdot
.62888 .53377 Mdot
.62262 .54 Mdot
.6389 .49817 Mdot
.79403 .44271 Mdot
.6228 .74876 Mdot
.62133 .53329 Mdot
.3275 .53231 Mdot
.55597 .5703 Mdot
.65897 .49185 Mdot
.43973 .69844 Mdot
.61194 .49932 Mdot
.4481 .33449 Mdot
.38684 .2967 Mdot
.29227 .55835 Mdot
.4196 .67004 Mdot
.66712 .51037 Mdot
.47342 .34273 Mdot
.27151 .55569 Mdot
.48929 .3713 Mdot
.70736 .48235 Mdot
.30391 .51961 Mdot
.5861 .68358 Mdot
.7582 .46477 Mdot
.63141 .49874 Mdot
.72732 .47729 Mdot
.59019 .64582 Mdot
.4161 .7163 Mdot
.51153 .35486 Mdot
.69451 .47831 Mdot
.77329 .45672 Mdot
.47075 .33562 Mdot
.3151 .53525 Mdot
.64464 .53413 Mdot
.49221 .3491 Mdot
.38592 .29027 Mdot
.28365 .54032 Mdot
.23442 .6522 Mdot
.50302 .3831 Mdot
.40635 .2876 Mdot
.33861 .57097 Mdot
.61714 .49124 Mdot
.59086 .68013 Mdot
.46676 .37942 Mdot
.41231 .68296 Mdot
.42739 .67651 Mdot
.56809 .71824 Mdot
.27278 .529 Mdot
.56064 .66644 Mdot
.4804 .33715 Mdot
.61692 .49701 Mdot
.46045 .36358 Mdot
.63769 .74883 Mdot
.21314 .63255 Mdot
.32194 .54444 Mdot
.60594 .62347 Mdot
.56594 .31405 Mdot
.44303 .6669 Mdot
.55267 .69447 Mdot
.34504 .56689 Mdot
.29199 .5014 Mdot
.28821 .54203 Mdot
.7556 .44529 Mdot
.58733 .67709 Mdot
.28633 .55447 Mdot
.29142 .5548 Mdot
.39419 .29635 Mdot
.50048 .34646 Mdot
.26847 .53488 Mdot
.59242 .73591 Mdot
.74504 .45858 Mdot
.5774 .6278 Mdot
.8031 .4333 Mdot
.40237 .6786 Mdot
.41399 .36687 Mdot
.4368 .36663 Mdot
.6918 .19958 Mdot
.51375 .39782 Mdot
.49406 .36303 Mdot
.27391 .56457 Mdot
.70932 .48983 Mdot
.74989 .44826 Mdot
.31821 .53714 Mdot
.32419 .54324 Mdot
.73898 .47822 Mdot
.50235 .30656 Mdot
.65531 .3506 Mdot
.56976 .32815 Mdot
.32672 .49628 Mdot
.21896 .52345 Mdot
.425 .68357 Mdot
.28807 .49712 Mdot
.38829 .73909 Mdot
.60249 .69782 Mdot
.60089 .69225 Mdot
.39489 .70758 Mdot
.5037 .3795 Mdot
.61748 .6528 Mdot
.38557 .27433 Mdot
.39107 .74477 Mdot
.37193 .29351 Mdot
.74613 .72663 Mdot
.52814 .37148 Mdot
.50405 .63506 Mdot
.34218 .71367 Mdot
.40204 .29046 Mdot
.34992 .2999 Mdot
.73527 .47048 Mdot
.32991 .57946 Mdot
.43838 .67721 Mdot
.3272 .34797 Mdot
.47698 .35824 Mdot
.31211 .48967 Mdot
.39365 .68894 Mdot
.22737 .64251 Mdot
.38327 .26992 Mdot
.39414 .28436 Mdot
.28925 .2983 Mdot
.338 .50307 Mdot
.59178 .67789 Mdot
.28285 .5735 Mdot
.30189 .55839 Mdot
.37229 .2816 Mdot
.57282 .70445 Mdot
.53126 .24186 Mdot
.32174 .4916 Mdot
.6873 .48409 Mdot
.30816 .50782 Mdot
.74362 .47473 Mdot
.28329 .55365 Mdot
.59752 .62424 Mdot
.50413 .38768 Mdot
.5998 .62211 Mdot
.70743 .47648 Mdot
.61223 .64094 Mdot
.43359 .67173 Mdot
.63189 .50705 Mdot
.43443 .68405 Mdot
.56937 .28228 Mdot
.35247 .40868 Mdot
.42673 .70703 Mdot
.55168 .4198 Mdot
.46543 .35511 Mdot
.28264 .55311 Mdot
.57881 .68695 Mdot
.58391 .61979 Mdot
.58332 .33748 Mdot
.30148 .54135 Mdot
.56419 .65008 Mdot
.36663 .26595 Mdot
.43335 .76095 Mdot
.40046 .2783 Mdot
.42072 .80996 Mdot
.32878 .51895 Mdot
.57559 .6271 Mdot
.58105 .31315 Mdot
.32817 .54258 Mdot
.59659 .70054 Mdot
.4007 .7108 Mdot
.41217 .68344 Mdot
.53265 .3875 Mdot
.38841 .68445 Mdot
.58282 .69329 Mdot
.2261 .50144 Mdot
.28117 .54917 Mdot
.20812 .62643 Mdot
.72272 .47067 Mdot
.56352 .67906 Mdot
.61588 .50257 Mdot
.26574 .47619 Mdot
.57987 .63883 Mdot
.70577 .21644 Mdot
.84838 .58153 Mdot
.56223 .65784 Mdot
.30549 .51902 Mdot
.30338 .5319 Mdot
.38138 .30644 Mdot
.58072 .34206 Mdot
.57437 .67902 Mdot
.46748 .7364 Mdot
.53737 .28366 Mdot
.634 .50925 Mdot
.64827 .76283 Mdot
.5384 .36758 Mdot
.38412 .28509 Mdot
.39919 .68762 Mdot
.50943 .37929 Mdot
.33257 .52926 Mdot
.51072 .39885 Mdot
.43677 .68099 Mdot
.57355 .71942 Mdot
.47476 .35753 Mdot
.73962 .46499 Mdot
.40266 .69142 Mdot
.41002 .68138 Mdot
.60785 .63879 Mdot
.27255 .52992 Mdot
.32963 .35536 Mdot
.58966 .67656 Mdot
.38438 .27845 Mdot
.62746 .51203 Mdot
.46852 .38367 Mdot
.30541 .48511 Mdot
.36317 .5377 Mdot
.5638 .68158 Mdot
.47063 .33683 Mdot
.4207 .7007 Mdot
.5548 .6679 Mdot
.38138 .30095 Mdot
.59409 .69733 Mdot
.58287 .52697 Mdot
.61898 .64882 Mdot
.27787 .46648 Mdot
.64129 .53329 Mdot
.31443 .48874 Mdot
.63177 .52844 Mdot
.74937 .66486 Mdot
.74059 .46216 Mdot
.61642 .65045 Mdot
.21136 .6218 Mdot
.60351 .62048 Mdot
.51172 .38961 Mdot
.47285 .34736 Mdot
.58602 .64339 Mdot
.72027 .46533 Mdot
.65293 .47943 Mdot
.70213 .48336 Mdot
.30332 .52431 Mdot
.37654 .26802 Mdot
.83179 .62434 Mdot
.60336 .60548 Mdot
.38952 .69336 Mdot
.37043 .49246 Mdot
.63345 .53177 Mdot
.42809 .66901 Mdot
.40616 .68459 Mdot
.71521 .47753 Mdot
.60339 .61397 Mdot
.28742 .49274 Mdot
.39935 .66778 Mdot
.32967 .53933 Mdot
.66612 .39783 Mdot
.62817 .49402 Mdot
.68914 .50631 Mdot
.64824 .51517 Mdot
.58334 .32868 Mdot
.42795 .65488 Mdot
.47969 .37163 Mdot
.73775 .48854 Mdot
.39514 .70002 Mdot
.71043 .46137 Mdot
.38033 .29935 Mdot
.56691 .64498 Mdot
.30723 .33271 Mdot
.5347 .38428 Mdot
.5234 .37453 Mdot
.39722 .68558 Mdot
.35579 .31489 Mdot
.34844 .56443 Mdot
.28011 .54427 Mdot
.5845 .65573 Mdot
.61204 .35201 Mdot
.49986 .39946 Mdot
.47693 .34439 Mdot
.59221 .63977 Mdot
.63279 .5206 Mdot
.65296 .7622 Mdot
.49309 .35293 Mdot
.42316 .68957 Mdot
.38223 .29811 Mdot
.44349 .67891 Mdot
.42165 .34041 Mdot
.51332 .38655 Mdot
.39036 .27826 Mdot
.37708 .28407 Mdot
.43417 .68474 Mdot
.6437 .50541 Mdot
.59503 .51937 Mdot
.32667 .50035 Mdot
.52251 .36112 Mdot
.53571 .28427 Mdot
.48334 .35453 Mdot
.73465 .47012 Mdot
.60619 .35325 Mdot
.42711 .35843 Mdot
.53883 .3993 Mdot
.53838 .28185 Mdot
.49262 .37821 Mdot
.39803 .68194 Mdot
.3042 .53386 Mdot
.41777 .70216 Mdot
.40206 .6664 Mdot
.5892 .63311 Mdot
.71353 .45758 Mdot
.47393 .38223 Mdot
.73873 .48368 Mdot
.54301 .38057 Mdot
.66521 .53008 Mdot
.57294 .35314 Mdot
.57933 .3099 Mdot
.70739 .45489 Mdot
.46655 .35132 Mdot
.58618 .64961 Mdot
.61141 .60999 Mdot
.36862 .27899 Mdot
.52811 .36364 Mdot
.38637 .70752 Mdot
.4189 .71257 Mdot
.63014 .75491 Mdot
.5982 .59087 Mdot
.70788 .48307 Mdot
.63452 .46935 Mdot
.37613 .28048 Mdot
.50136 .39502 Mdot
.64141 .50735 Mdot
.57144 .65243 Mdot
.62706 .53145 Mdot
.62473 .75104 Mdot
.43963 .67566 Mdot
.40655 .70561 Mdot
.53004 .37367 Mdot
.76689 .28359 Mdot
.29526 .50743 Mdot
.30228 .53313 Mdot
.43518 .70386 Mdot
.61455 .64735 Mdot
.61189 .51896 Mdot
.30016 .30246 Mdot
.36753 .51509 Mdot
.76058 .47391 Mdot
.46127 .36937 Mdot
.60633 .69091 Mdot
.33317 .51896 Mdot
.71033 .48359 Mdot
.4497 .38489 Mdot
.56847 .70355 Mdot
.48254 .36652 Mdot
.38859 .26093 Mdot
.31031 .54487 Mdot
.57284 .35727 Mdot
.31901 .48805 Mdot
.42482 .67851 Mdot
.4233 .65451 Mdot
.51772 .38391 Mdot
.30981 .32973 Mdot
.30542 .46231 Mdot
.4137 .65639 Mdot
.7428 .44194 Mdot
.62579 .50472 Mdot
.71186 .46003 Mdot
.5772 .65399 Mdot
.7406 .46302 Mdot
.58189 .63711 Mdot
.55005 .6756 Mdot
.28373 .49777 Mdot
.72727 .46041 Mdot
.41331 .37844 Mdot
.60583 .5062 Mdot
.764 .44487 Mdot
.50904 .40411 Mdot
.39734 .30076 Mdot
.56985 .67515 Mdot
.73831 .48439 Mdot
.46563 .37961 Mdot
.27117 .62357 Mdot
.41039 .66176 Mdot
.43567 .67358 Mdot
.61494 .51964 Mdot
.56831 .69186 Mdot
.28799 .49101 Mdot
.56655 .30924 Mdot
.26706 .47105 Mdot
.48086 .34341 Mdot
.48007 .3843 Mdot
.27224 .46774 Mdot
.28746 .49129 Mdot
.51572 .38324 Mdot
.43395 .43766 Mdot
.61939 .50036 Mdot
.41956 .67714 Mdot
.30131 .52395 Mdot
.29382 .52839 Mdot
.59406 .68617 Mdot
.27204 .52168 Mdot
.74916 .49066 Mdot
.43729 .67333 Mdot
.59372 .50735 Mdot
.42223 .69732 Mdot
.59132 .56126 Mdot
.56555 .65292 Mdot
.22449 .63363 Mdot
.27411 .5392 Mdot
.39695 .29203 Mdot
.26979 .5266 Mdot
.72119 .47341 Mdot
.30372 .49263 Mdot
.29321 .49239 Mdot
.50185 .34777 Mdot
.6407 .50351 Mdot
.61198 .52983 Mdot
.5807 .33456 Mdot
.29704 .50729 Mdot
.4943 .38426 Mdot
.46244 .39005 Mdot
.52641 .3721 Mdot
.57562 .35095 Mdot
.27755 .52791 Mdot
.37561 .34141 Mdot
.26906 .54869 Mdot
.3159 .54207 Mdot
.80535 .4248 Mdot
.59983 .51489 Mdot
.63718 .52683 Mdot
.45087 .74019 Mdot
.49962 .35428 Mdot
.56851 .63972 Mdot
.38514 .28037 Mdot
.63044 .50084 Mdot
.45934 .3919 Mdot
.7681 .46171 Mdot
.4526 .35965 Mdot
.63685 .51414 Mdot
.58071 .68494 Mdot
.39603 .29216 Mdot
.4854 .35067 Mdot
.62644 .52469 Mdot
.27673 .50653 Mdot
.28477 .52906 Mdot
.36787 .45511 Mdot
.72685 .48029 Mdot
.43227 .69404 Mdot
.38568 .28282 Mdot
.58458 .65335 Mdot
.5789 .62921 Mdot
.31346 .48793 Mdot
.60639 .66141 Mdot
.40407 .70383 Mdot
.50009 .36101 Mdot
.42963 .67969 Mdot
.7587 .47074 Mdot
.30285 .51975 Mdot
.39011 .29085 Mdot
.38286 .31085 Mdot
.32039 .52859 Mdot
.61922 .49906 Mdot
.71874 .45368 Mdot
.60404 .64374 Mdot
.31562 .548 Mdot
.43735 .6875 Mdot
.59964 .6813 Mdot
.39614 .28656 Mdot
.81295 .39272 Mdot
.5099 .3799 Mdot
.52545 .3869 Mdot
.27505 .47463 Mdot
.4342 .33916 Mdot
.60303 .62415 Mdot
.28848 .48857 Mdot
.39798 .29751 Mdot
.55986 .26693 Mdot
.75033 .43615 Mdot
.62757 .60813 Mdot
.49415 .37309 Mdot
.43257 .37506 Mdot
.4415 .35704 Mdot
.2048 .61191 Mdot
.57528 .35376 Mdot
.61063 .73914 Mdot
.6948 .50243 Mdot
.39269 .67787 Mdot
.63207 .51458 Mdot
.59299 .63034 Mdot
.41363 .42878 Mdot
.51357 .37901 Mdot
.34403 .39929 Mdot
.387 .30157 Mdot
.41501 .70646 Mdot
.37385 .32949 Mdot
.58255 .68919 Mdot
.67 .76512 Mdot
.49039 .34076 Mdot
.35891 .54614 Mdot
.48067 .65325 Mdot
.63914 .5074 Mdot
.64388 .52124 Mdot
.71079 .48285 Mdot
.55916 .70316 Mdot
.65877 .5014 Mdot
.41978 .70003 Mdot
.4983 .39662 Mdot
.42376 .35881 Mdot
.24477 .65161 Mdot
.3312 .51896 Mdot
.39488 .67838 Mdot
.63126 .62897 Mdot
.47424 .37256 Mdot
.28777 .50849 Mdot
.32025 .51518 Mdot
.76785 .4652 Mdot
.60264 .73879 Mdot
.55206 .69571 Mdot
.72807 .2511 Mdot
.65538 .52477 Mdot
.57379 .64968 Mdot
.65016 .52125 Mdot
.3865 .27862 Mdot
.56188 .37573 Mdot
.3947 .67555 Mdot
.51627 .38907 Mdot
.34194 .38957 Mdot
.32684 .50786 Mdot
.48532 .35744 Mdot
.74998 .45728 Mdot
.30044 .26569 Mdot
.36391 .28213 Mdot
.44204 .43921 Mdot
.57757 .70248 Mdot
.48389 .38535 Mdot
.75541 .48763 Mdot
.61188 .49169 Mdot
.43458 .33783 Mdot
.58965 .6797 Mdot
.63997 .53408 Mdot
.75059 .4536 Mdot
.32927 .50238 Mdot
.62981 .51514 Mdot
.38444 .30205 Mdot
.45655 .37054 Mdot
.738 .44221 Mdot
.39083 .28065 Mdot
.21406 .53579 Mdot
.65207 .50458 Mdot
.60431 .6872 Mdot
.3112 .55207 Mdot
.489 .38663 Mdot
.62648 .50395 Mdot
.46236 .36653 Mdot
.20467 .55964 Mdot
.51062 .39295 Mdot
.25738 .63392 Mdot
.30842 .53861 Mdot
.41158 .69257 Mdot
.38852 .29457 Mdot
.48 .36504 Mdot
.64786 .52652 Mdot
.60939 .51878 Mdot
.46881 .34188 Mdot
.31549 .48844 Mdot
.31439 .4947 Mdot
.36435 .53099 Mdot
.59598 .68848 Mdot
.56911 .33609 Mdot
.41605 .68639 Mdot
.64237 .50861 Mdot
.39728 .66974 Mdot
.43155 .37246 Mdot
.72951 .47873 Mdot
.24717 .64653 Mdot
.50797 .36591 Mdot
.29781 .54182 Mdot
.65564 .35413 Mdot
.29311 .49815 Mdot
.44771 .7414 Mdot
.39138 .68439 Mdot
.29906 .51357 Mdot
.49657 .37258 Mdot
.58442 .32352 Mdot
.41953 .35996 Mdot
.43442 .65905 Mdot
.59463 .51176 Mdot
.61476 .55407 Mdot
.58905 .7053 Mdot
.80806 .42924 Mdot
.40208 .72168 Mdot
.34072 .71199 Mdot
.39769 .29528 Mdot
.28664 .54755 Mdot
.43593 .69401 Mdot
.41324 .6773 Mdot
.57626 .69133 Mdot
.39466 .29522 Mdot
.48111 .36296 Mdot
.59837 .51965 Mdot
.41082 .71911 Mdot
.45333 .34806 Mdot
.40342 .29225 Mdot
.63937 .75785 Mdot
.34521 .5691 Mdot
.23029 .65169 Mdot
.43598 .37535 Mdot
.34279 .38697 Mdot
.4962 .69161 Mdot
.28279 .55196 Mdot
.49041 .38273 Mdot
.61362 .50893 Mdot
.60829 .65965 Mdot
.5039 .36802 Mdot
.60649 .62222 Mdot
.42454 .70351 Mdot
.2657 .62964 Mdot
.42746 .36546 Mdot
.39283 .74596 Mdot
.50703 .38597 Mdot
.36744 .29648 Mdot
.73785 .45549 Mdot
.44161 .68253 Mdot
.36342 .52658 Mdot
.47585 .38599 Mdot
.59628 .67767 Mdot
.59086 .70613 Mdot
.32395 .50149 Mdot
.37024 .46997 Mdot
.21801 .62896 Mdot
.61207 .50414 Mdot
.60271 .65846 Mdot
.62441 .50273 Mdot
.45168 .44165 Mdot
.39928 .66767 Mdot
.75095 .45294 Mdot
.61145 .65432 Mdot
.42527 .71616 Mdot
.39776 .30069 Mdot
.3072 .50134 Mdot
.26023 .47981 Mdot
.37477 .27339 Mdot
.56456 .64862 Mdot
.74697 .47001 Mdot
.55412 .38761 Mdot
.37425 .27014 Mdot
.75685 .46298 Mdot
.58857 .69159 Mdot
.28941 .51684 Mdot
.32089 .52159 Mdot
.30646 .53306 Mdot
.41419 .36772 Mdot
.36454 .53411 Mdot
.61988 .42225 Mdot
.4361 .34101 Mdot
.23447 .49167 Mdot
.44415 .34173 Mdot
.43637 .67482 Mdot
.30484 .54623 Mdot
.57423 .35405 Mdot
.39221 .27195 Mdot
.41135 .34347 Mdot
.51035 .35671 Mdot
.37452 .28668 Mdot
.49902 .35379 Mdot
.2385 .49113 Mdot
.34791 .5675 Mdot
.54163 .39781 Mdot
.43215 .66474 Mdot
.73001 .47476 Mdot
.30896 .55698 Mdot
.47655 .38099 Mdot
.2238 .51284 Mdot
.5053 .40417 Mdot
.26169 .62947 Mdot
.3732 .28843 Mdot
.58579 .72801 Mdot
.48884 .39496 Mdot
.61073 .68527 Mdot
.37556 .3078 Mdot
.21631 .52826 Mdot
.41218 .66191 Mdot
.36338 .28504 Mdot
.60656 .69874 Mdot
.37631 .3317 Mdot
.60876 .50946 Mdot
.74337 .45732 Mdot
.63365 .53668 Mdot
.43494 .68115 Mdot
.51263 .37195 Mdot
.45492 .3644 Mdot
.42759 .34092 Mdot
.45518 .44234 Mdot
.60103 .51167 Mdot
.70675 .45487 Mdot
.21758 .52213 Mdot
.45856 .35101 Mdot
.61826 .6364 Mdot
.28105 .537 Mdot
.39676 .36021 Mdot
.40814 .38292 Mdot
.40401 .30014 Mdot
.29917 .50803 Mdot
.27266 .52873 Mdot
.79545 .43406 Mdot
.73109 .46358 Mdot
.52424 .37943 Mdot
.68989 .48047 Mdot
.38791 .28499 Mdot
.42841 .69267 Mdot
.43189 .3464 Mdot
.56513 .65286 Mdot
.58632 .31678 Mdot
.59106 .69163 Mdot
.52277 .36694 Mdot
.30934 .50891 Mdot
.43495 .66041 Mdot
.54997 .66684 Mdot
.5977 .73962 Mdot
.62972 .41965 Mdot
.55001 .6923 Mdot
.72431 .48291 Mdot
.7176 .47653 Mdot
.44107 .68127 Mdot
.49577 .36614 Mdot
.57861 .34885 Mdot
.35275 .24674 Mdot
.50794 .36081 Mdot
.50383 .37774 Mdot
.44701 .64934 Mdot
.3963 .71352 Mdot
.61263 .65593 Mdot
.51559 .38189 Mdot
.45199 .35642 Mdot
.30505 .51196 Mdot
.71061 .48882 Mdot
.59596 .63503 Mdot
.70858 .48181 Mdot
.59526 .65423 Mdot
.64697 .33525 Mdot
.62433 .4945 Mdot
.72277 .47933 Mdot
.39842 .71997 Mdot
.29456 .54079 Mdot
.59909 .51309 Mdot
.57607 .66546 Mdot
.60432 .66112 Mdot
.54124 .37733 Mdot
.3325 .51419 Mdot
.27972 .54416 Mdot
.73107 .48025 Mdot
.4225 .7113 Mdot
.38421 .27378 Mdot
.64776 .51596 Mdot
.64614 .6329 Mdot
.60123 .67156 Mdot
.21732 .5172 Mdot
.27132 .47465 Mdot
.4694 .37281 Mdot
.28534 .52727 Mdot
.47287 .36389 Mdot
.27638 .56733 Mdot
.34001 .51693 Mdot
.42071 .34077 Mdot
.36543 .44454 Mdot
.57235 .64903 Mdot
.80272 .66552 Mdot
.40353 .28326 Mdot
.41259 .7272 Mdot
.38654 .28079 Mdot
.65835 .76365 Mdot
.65797 .35643 Mdot
.46177 .35005 Mdot
.47908 .38318 Mdot
.77351 .30169 Mdot
.46271 .38536 Mdot
.63431 .52579 Mdot
.60794 .50952 Mdot
.28569 .52103 Mdot
.63044 .53729 Mdot
.58276 .33235 Mdot
.72345 .45946 Mdot
.58359 .65591 Mdot
.66822 .39091 Mdot
.74132 .47501 Mdot
.32636 .5142 Mdot
.38804 .27302 Mdot
.30052 .45945 Mdot
.61768 .6263 Mdot
.62467 .52093 Mdot
.42113 .70465 Mdot
.58449 .34335 Mdot
.58939 .68558 Mdot
.4204 .71727 Mdot
.45729 .3846 Mdot
.62759 .74734 Mdot
.43367 .66695 Mdot
.81641 .64597 Mdot
.40686 .6777 Mdot
.43412 .70401 Mdot
.57557 .3421 Mdot
.72349 .45905 Mdot
.64808 .52793 Mdot
.67177 .52071 Mdot
.41632 .66262 Mdot
.69633 .75338 Mdot
.57003 .69177 Mdot
.5807 .29891 Mdot
.33093 .5795 Mdot
.60923 .50035 Mdot
.5056 .38369 Mdot
.39974 .68453 Mdot
.54208 .38325 Mdot
.64422 .53065 Mdot
.40484 .69814 Mdot
.37689 .30846 Mdot
.61008 .34817 Mdot
.62039 .50583 Mdot
.60875 .52949 Mdot
.71946 .48742 Mdot
.5811 .72759 Mdot
.27731 .54009 Mdot
.77332 .45393 Mdot
.56043 .2962 Mdot
.52752 .37745 Mdot
.43438 .68563 Mdot
.62931 .51586 Mdot
.41519 .68379 Mdot
.74255 .45073 Mdot
.74271 .44111 Mdot
.32903 .5053 Mdot
.3621 .53766 Mdot
.61828 .48502 Mdot
.52604 .28058 Mdot
.43807 .34936 Mdot
.34682 .40507 Mdot
.2782 .51595 Mdot
.35104 .29944 Mdot
.73338 .44781 Mdot
.72361 .48855 Mdot
.36932 .30035 Mdot
.47538 .3977 Mdot
.37735 .29108 Mdot
.43746 .37237 Mdot
.68476 .73301 Mdot
.39084 .29367 Mdot
.60399 .64592 Mdot
.43904 .37508 Mdot
.33525 .66353 Mdot
.36686 .28573 Mdot
.46943 .37668 Mdot
.58949 .66778 Mdot
.46216 .33476 Mdot
.56477 .66879 Mdot
.49728 .38778 Mdot
.64165 .74984 Mdot
.58482 .65358 Mdot
.61598 .47334 Mdot
.56568 .40753 Mdot
.6277 .5287 Mdot
.75009 .44625 Mdot
.69585 .47754 Mdot
.65063 .40607 Mdot
.29167 .51666 Mdot
.31279 .25859 Mdot
.47029 .37647 Mdot
.5758 .69276 Mdot
.42286 .70573 Mdot
.3911 .31005 Mdot
.52852 .38639 Mdot
.37791 .275 Mdot
.3048 .49951 Mdot
.56722 .69274 Mdot
.73435 .45193 Mdot
.60875 .61548 Mdot
.64267 .76069 Mdot
.56612 .65476 Mdot
.49025 .44277 Mdot
.39242 .30512 Mdot
.75277 .48884 Mdot
.35755 .42168 Mdot
.66759 .47941 Mdot
.31706 .49853 Mdot
.63118 .51294 Mdot
.70912 .47145 Mdot
.58714 .37838 Mdot
.28036 .53977 Mdot
.5923 .6402 Mdot
.48225 .36718 Mdot
.64353 .50102 Mdot
.67122 .5219 Mdot
.33327 .52964 Mdot
.7305 .44326 Mdot
.58151 .66452 Mdot
.62589 .50814 Mdot
.56813 .32966 Mdot
.37297 .35622 Mdot
.57353 .28455 Mdot
.47714 .36611 Mdot
.73873 .47796 Mdot
.33275 .51492 Mdot
.37662 .27467 Mdot
.39653 .70089 Mdot
.58148 .33991 Mdot
.50834 .38269 Mdot
.39911 .75205 Mdot
.31044 .50757 Mdot
.72245 .46832 Mdot
.40185 .68152 Mdot
.73258 .46427 Mdot
.63781 .52565 Mdot
.27326 .5627 Mdot
.64402 .52084 Mdot
.38621 .30075 Mdot
.42893 .69996 Mdot
.27961 .5427 Mdot
.64213 .75782 Mdot
.64345 .53457 Mdot
.58428 .64492 Mdot
.58863 .37552 Mdot
.32111 .4957 Mdot
.36494 .63568 Mdot
.60876 .61601 Mdot
.42712 .63813 Mdot
.57287 .36283 Mdot
.40173 .6979 Mdot
.4717 .37826 Mdot
.31176 .52426 Mdot
.43677 .65965 Mdot
.5904 .73517 Mdot
.4277 .37244 Mdot
.64012 .49238 Mdot
.46765 .35162 Mdot
.19861 .60271 Mdot
.33821 .68866 Mdot
.29923 .57906 Mdot
.40638 .72417 Mdot
.51879 .36722 Mdot
.61356 .50194 Mdot
.52077 .35927 Mdot
.40933 .66636 Mdot
.45215 .66109 Mdot
.58677 .62051 Mdot
.48164 .3709 Mdot
.73356 .46868 Mdot
.57932 .634 Mdot
.58257 .70872 Mdot
.61141 .66663 Mdot
.3626 .53081 Mdot
.6142 .49542 Mdot
.60903 .50607 Mdot
.66218 .36082 Mdot
.41502 .68234 Mdot
.62887 .52808 Mdot
.45343 .36288 Mdot
.62064 .42133 Mdot
.30645 .53633 Mdot
.58148 .66986 Mdot
.52264 .37192 Mdot
.40097 .27725 Mdot
.62114 .52548 Mdot
.58899 .67585 Mdot
.28434 .49616 Mdot
.5704 .57269 Mdot
.505 .36709 Mdot
.39237 .29836 Mdot
.32572 .52389 Mdot
.207 .56583 Mdot
.57072 .31723 Mdot
.47375 .3626 Mdot
.4275 .67617 Mdot
.2314 .5846 Mdot
.46412 .38809 Mdot
.37809 .45533 Mdot
.59609 .51324 Mdot
.54057 .55685 Mdot
.24349 .56213 Mdot
.40457 .26742 Mdot
.45228 .5883 Mdot
.47587 .2387 Mdot
.48613 .60835 Mdot
.701 .71636 Mdot
.40644 .58387 Mdot
.82951 .62284 Mdot
.37902 .7042 Mdot
.39197 .25969 Mdot
.69424 .22068 Mdot
.34688 .71357 Mdot
.39381 .60802 Mdot
.36724 .71647 Mdot
.59223 .45897 Mdot
.65086 .75977 Mdot
.62803 .7497 Mdot
.70052 .70896 Mdot
.53788 .36797 Mdot
.33836 .6091 Mdot
.36112 .26354 Mdot
.35578 .65828 Mdot
.61093 .73321 Mdot
.37382 .26756 Mdot
.76252 .314 Mdot
.42532 .75466 Mdot
.75358 .38493 Mdot
.32293 .3304 Mdot
.63762 .69866 Mdot
.50544 .28075 Mdot
.68187 .42215 Mdot
.35688 .24606 Mdot
.50986 .5796 Mdot
.38312 .69382 Mdot
.26857 .5112 Mdot
.45483 .74502 Mdot
.5982 .64484 Mdot
.33507 .50974 Mdot
.38447 .76995 Mdot
.78002 .35977 Mdot
.36902 .67167 Mdot
.45107 .58914 Mdot
.65694 .50903 Mdot
.54394 .54773 Mdot
.5657 .35265 Mdot
.28462 .5694 Mdot
.63837 .71827 Mdot
.64985 .74071 Mdot
.25934 .49746 Mdot
.60644 .71619 Mdot
.58079 .38968 Mdot
.38958 .60845 Mdot
.24013 .56416 Mdot
.60605 .46108 Mdot
.60439 .47558 Mdot
.27879 .51375 Mdot
.71453 .27784 Mdot
.53845 .45357 Mdot
.55722 .28727 Mdot
.61824 .71723 Mdot
.28133 .48848 Mdot
.32621 .35088 Mdot
.36843 .4716 Mdot
.764 .70494 Mdot
.79965 .38616 Mdot
.72922 .70316 Mdot
.56462 .44997 Mdot
.37654 .67182 Mdot
.57458 .41616 Mdot
.51283 .63523 Mdot
.75088 .69026 Mdot
.21382 .56605 Mdot
.72803 .26937 Mdot
.49913 .51126 Mdot
.80578 .37125 Mdot
.24142 .53121 Mdot
.60061 .46577 Mdot
.27634 .57788 Mdot
.56569 .54068 Mdot
.63255 .35014 Mdot
.79181 .34987 Mdot
.37056 .61005 Mdot
.61093 .54848 Mdot
.34722 .71071 Mdot
.22382 .54719 Mdot
.63533 .73668 Mdot
.59847 .5367 Mdot
.38474 .40874 Mdot
.788 .33088 Mdot
.46218 .58184 Mdot
.74653 .32767 Mdot
.64464 .70524 Mdot
.41015 .79407 Mdot
.5786 .71019 Mdot
.4292 .65188 Mdot
.77169 .38341 Mdot
.31529 .52073 Mdot
.78174 .69034 Mdot
.41506 .60368 Mdot
.48008 .64394 Mdot
.78055 .32298 Mdot
.74489 .72048 Mdot
.55909 .51813 Mdot
.61823 .4688 Mdot
.45951 .73925 Mdot
.51078 .60695 Mdot
.34848 .65085 Mdot
.59958 .56697 Mdot
.2338 .6204 Mdot
.764 .37507 Mdot
.72967 .72488 Mdot
.7122 .24324 Mdot
.55688 .29732 Mdot
.64085 .43813 Mdot
.27581 .47642 Mdot
.43128 .5217 Mdot
.35005 .65643 Mdot
.80866 .37807 Mdot
.36265 .27433 Mdot
.2203 .58539 Mdot
.70796 .70637 Mdot
.39632 .36786 Mdot
.28093 .6158 Mdot
.37664 .7485 Mdot
.58267 .57412 Mdot
.23271 .54201 Mdot
.79621 .44667 Mdot
.64239 .37416 Mdot
.37005 .39781 Mdot
.59579 .72416 Mdot
.57478 .32163 Mdot
.38656 .4706 Mdot
.81478 .60932 Mdot
.30863 .61192 Mdot
.3813 .40361 Mdot
.2586 .4829 Mdot
.75138 .68747 Mdot
.71224 .71162 Mdot
.2477 .60155 Mdot
.63877 .63347 Mdot
.75337 .3349 Mdot
.39049 .51254 Mdot
.55202 .53485 Mdot
.36571 .26214 Mdot
.35356 .27858 Mdot
.65887 .71059 Mdot
.49574 .45663 Mdot
.75422 .42436 Mdot
.37215 .73608 Mdot
.35773 .42797 Mdot
.69751 .42382 Mdot
.36603 .42415 Mdot
.21716 .53294 Mdot
.41839 .46781 Mdot
.42908 .75179 Mdot
.41393 .45405 Mdot
.76706 .31441 Mdot
.60201 .62912 Mdot
.74976 .69538 Mdot
.3684 .67795 Mdot
.62634 .7373 Mdot
.46991 .64078 Mdot
.47032 .64255 Mdot
.76476 .3979 Mdot
.36074 .74247 Mdot
.58033 .47867 Mdot
.2923 .5753 Mdot
.45337 .61466 Mdot
.35332 .40139 Mdot
.51383 .43081 Mdot
.36571 .55948 Mdot
.71978 .45203 Mdot
.40596 .43232 Mdot
.23097 .54053 Mdot
.633 .63189 Mdot
.48883 .43844 Mdot
.51579 .25592 Mdot
.60629 .48896 Mdot
.61874 .39804 Mdot
.64846 .33968 Mdot
.52785 .51718 Mdot
.75443 .7032 Mdot
.38322 .53047 Mdot
.62294 .39843 Mdot
.35047 .66263 Mdot
.31589 .25846 Mdot
.80718 .37025 Mdot
.79102 .42257 Mdot
.25183 .58755 Mdot
.24522 .60971 Mdot
.43835 .82653 Mdot
.37149 .63406 Mdot
.82744 .60002 Mdot
.36857 .67823 Mdot
.27817 .28968 Mdot
.60525 .62721 Mdot
.56811 .47508 Mdot
.26492 .55777 Mdot
.50923 .25867 Mdot
.7762 .33596 Mdot
.53229 .53318 Mdot
.76852 .44739 Mdot
.26636 .57865 Mdot
.37809 .44595 Mdot
.74959 .31023 Mdot
.72568 .2796 Mdot
.72563 .28715 Mdot
.38039 .76746 Mdot
.45741 .44994 Mdot
.76851 .30608 Mdot
.58913 .42967 Mdot
.50373 .47871 Mdot
.41271 .29298 Mdot
.54488 .26795 Mdot
.81356 .63612 Mdot
.62003 .44598 Mdot
.51573 .60488 Mdot
.25959 .49626 Mdot
.79135 .32749 Mdot
.66275 .34897 Mdot
.55577 .55644 Mdot
.73942 .39008 Mdot
.69729 .45641 Mdot
.70272 .41741 Mdot
.76335 .40359 Mdot
.48391 .5796 Mdot
.37499 .74515 Mdot
.8006 .33086 Mdot
.7372 .68534 Mdot
.36007 .66644 Mdot
.22425 .52518 Mdot
.80555 .65311 Mdot
.26863 .61554 Mdot
.41533 .64691 Mdot
.2465 .54003 Mdot
.32391 .27978 Mdot
.38788 .57061 Mdot
.5164 .58104 Mdot
.43074 .33015 Mdot
.70342 .43149 Mdot
.61074 .63713 Mdot
.78242 .65663 Mdot
.38385 .56124 Mdot
.49348 .47772 Mdot
.63534 .39524 Mdot
.71708 .73933 Mdot
.50409 .54854 Mdot
.43629 .42433 Mdot
.38421 .52639 Mdot
.29227 .6035 Mdot
.28819 .61352 Mdot
.34032 .3401 Mdot
.44364 .34976 Mdot
.78385 .35695 Mdot
.84053 .59129 Mdot
.77421 .40483 Mdot
.27003 .60432 Mdot
.43058 .80476 Mdot
.38113 .71678 Mdot
.59734 .4208 Mdot
.51538 .23936 Mdot
.46674 .55473 Mdot
.48597 .23017 Mdot
.44879 .67562 Mdot
.3261 .35136 Mdot
.45564 .63123 Mdot
.5894 .42795 Mdot
.33446 .58971 Mdot
.47212 .63151 Mdot
.4354 .43177 Mdot
.2441 .49843 Mdot
.20404 .58771 Mdot
.75349 .68344 Mdot
.60387 .63217 Mdot
.63935 .62237 Mdot
.50006 .46474 Mdot
.73415 .48975 Mdot
.5945 .54922 Mdot
.55319 .52608 Mdot
.34378 .37878 Mdot
.44313 .81147 Mdot
.74388 .41447 Mdot
.80111 .66577 Mdot
.76523 .40504 Mdot
.7228 .70896 Mdot
.61487 .70946 Mdot
.62222 .37996 Mdot
.38408 .64849 Mdot
.3745 .68756 Mdot
.61515 .37157 Mdot
.7154 .72756 Mdot
.55561 .54798 Mdot
.29927 .57565 Mdot
.44643 .35755 Mdot
.65136 .35136 Mdot
.67558 .42411 Mdot
.60792 .39521 Mdot
.35666 .35071 Mdot
.30458 .48028 Mdot
.61206 .43551 Mdot
.54471 .57873 Mdot
.38695 .31328 Mdot
.24035 .60708 Mdot
.43932 .66018 Mdot
.23009 .51427 Mdot
.71722 .74136 Mdot
.44273 .82118 Mdot
.48242 .62186 Mdot
.54939 .42953 Mdot
.75763 .36917 Mdot
.56487 .42849 Mdot
.24498 .61496 Mdot
.32932 .28317 Mdot
.46347 .64286 Mdot
.25157 .50747 Mdot
.51889 .49579 Mdot
.49875 .66691 Mdot
.32104 .60055 Mdot
.23468 .51345 Mdot
.35637 .29111 Mdot
.79054 .38929 Mdot
.46659 .32695 Mdot
.49863 .58632 Mdot
.56771 .30699 Mdot
.41689 .52919 Mdot
.42888 .60626 Mdot
.64575 .39989 Mdot
.47386 .60208 Mdot
.71828 .28868 Mdot
.32825 .3656 Mdot
.52896 .60223 Mdot
.58859 .4424 Mdot
.58733 .42766 Mdot
.32379 .33202 Mdot
.22355 .55228 Mdot
.3711 .73346 Mdot
.50444 .33736 Mdot
.8019 .39846 Mdot
.48454 .50383 Mdot
.62928 .3947 Mdot
.3964 .48537 Mdot
.47785 .33059 Mdot
.58384 .53384 Mdot
.76233 .40128 Mdot
.54168 .56061 Mdot
.68866 .21186 Mdot
.70006 .73209 Mdot
.37621 .51506 Mdot
.26938 .57108 Mdot
.76191 .68287 Mdot
.35501 .59895 Mdot
.41521 .58971 Mdot
.39201 .53845 Mdot
.79406 .66036 Mdot
.52991 .55433 Mdot
.54683 .56794 Mdot
.20668 .59665 Mdot
.75394 .29707 Mdot
.50495 .60066 Mdot
.41223 .64976 Mdot
.63997 .44395 Mdot
.52003 .39168 Mdot
.37788 .48004 Mdot
.22704 .6399 Mdot
.42471 .48915 Mdot
.49508 .61444 Mdot
.83789 .60927 Mdot
.53817 .53036 Mdot
.38085 .54329 Mdot
.69259 .21315 Mdot
.69229 .20554 Mdot
.37539 .48187 Mdot
.81077 .38335 Mdot
.55102 .56509 Mdot
.25292 .61671 Mdot
.38257 .68833 Mdot
.53431 .42484 Mdot
.34578 .40097 Mdot
.79839 .40889 Mdot
.41529 .81495 Mdot
.34892 .66704 Mdot
.25474 .54327 Mdot
.80592 .4153 Mdot
.49279 .48467 Mdot
.57233 .4828 Mdot
.41424 .79208 Mdot
.67445 .75903 Mdot
.76422 .7 Mdot
.3435 .33299 Mdot
.65714 .72549 Mdot
.67999 .70267 Mdot
.36592 .61193 Mdot
.81001 .65124 Mdot
.66096 .52172 Mdot
.32088 .2545 Mdot
.74987 .68955 Mdot
.21614 .60817 Mdot
.64368 .73806 Mdot
.43172 .60444 Mdot
.5469 .52763 Mdot
.43226 .46954 Mdot
.24007 .6226 Mdot
.37444 .7544 Mdot
.53533 .48826 Mdot
.59843 .36797 Mdot
.22204 .5388 Mdot
.21355 .57583 Mdot
.33294 .26053 Mdot
.55552 .50799 Mdot
.70133 .25745 Mdot
.4138 .74683 Mdot
.59174 .39294 Mdot
.29057 .57299 Mdot
.66494 .40395 Mdot
.57841 .4783 Mdot
.47085 .39752 Mdot
.78807 .38644 Mdot
.5775 .48364 Mdot
.71175 .26615 Mdot
.77959 .69722 Mdot
.73474 .38337 Mdot
.50835 .64833 Mdot
.59894 .55664 Mdot
.81368 .63189 Mdot
.82068 .61421 Mdot
.70791 .25274 Mdot
.70129 .70011 Mdot
.61311 .36962 Mdot
.53986 .4984 Mdot
.51926 .42788 Mdot
.46043 .4411 Mdot
.76501 .67805 Mdot
.32044 .33073 Mdot
.69474 .41788 Mdot
.27849 .59364 Mdot
.71689 .73201 Mdot
.56925 .4381 Mdot
.65736 .40658 Mdot
.4138 .49434 Mdot
.59642 .47585 Mdot
.55898 .68 Mdot
.75773 .2795 Mdot
.247 .6037 Mdot
.71716 .41566 Mdot
.22466 .58935 Mdot
.24892 .48658 Mdot
.69015 .72056 Mdot
.25154 .574 Mdot
.69025 .51536 Mdot
.62784 .7051 Mdot
.78816 .43712 Mdot
.56145 .54211 Mdot
.20307 .61079 Mdot
.39632 .38195 Mdot
.77353 .39774 Mdot
.69973 .42445 Mdot
.70021 .23741 Mdot
.61702 .43704 Mdot
.40331 .43155 Mdot
.70881 .2734 Mdot
.27446 .59588 Mdot
.59997 .39769 Mdot
.75106 .30625 Mdot
.32926 .58225 Mdot
.7986 .38394 Mdot
.40041 .70752 Mdot
.58152 .45992 Mdot
.22249 .6281 Mdot
.59783 .40906 Mdot
.59469 .40846 Mdot
.74603 .41822 Mdot
.34528 .70138 Mdot
.37121 .56795 Mdot
.39011 .51745 Mdot
.63047 .73739 Mdot
.53956 .42366 Mdot
.48441 .58824 Mdot
.71546 .24493 Mdot
.44539 .35999 Mdot
.7304 .67404 Mdot
.75151 .69911 Mdot
.38671 .64867 Mdot
.54818 .51317 Mdot
.21605 .61943 Mdot
.34421 .3228 Mdot
.65565 .36917 Mdot
.75716 .30204 Mdot
.54793 .51158 Mdot
.50757 .24623 Mdot
.3448 .29281 Mdot
.47178 .72286 Mdot
.35596 .71159 Mdot
.46004 .59043 Mdot
.55761 .45722 Mdot
.56889 .31992 Mdot
.7267 .70183 Mdot
.83383 .61751 Mdot
.70089 .25484 Mdot
.35842 .71531 Mdot
.60452 .40389 Mdot
.39002 .45919 Mdot
.68373 .44502 Mdot
.71207 .2386 Mdot
.65409 .76015 Mdot
.23074 .53933 Mdot
.72094 .72436 Mdot
.35038 .71286 Mdot
.57412 .47507 Mdot
.61161 .38636 Mdot
.71672 .28172 Mdot
.26089 .53847 Mdot
.51085 .50956 Mdot
.4017 .47439 Mdot
.58847 .33579 Mdot
.41225 .61295 Mdot
.32146 .28644 Mdot
.35878 .74641 Mdot
.69877 .23701 Mdot
.67307 .71113 Mdot
.38831 .34516 Mdot
.69543 .22547 Mdot
.30013 .48175 Mdot
.40872 .61375 Mdot
.4045 .78974 Mdot
.61911 .40299 Mdot
.58441 .71417 Mdot
.45063 .35211 Mdot
.60753 .36442 Mdot
.3502 .60137 Mdot
.62053 .44036 Mdot
.74836 .43813 Mdot
.22836 .52333 Mdot
.6876 .71003 Mdot
.23723 .50445 Mdot
.83388 .61085 Mdot
.48206 .57594 Mdot
.24019 .55633 Mdot
.33641 .28337 Mdot
.61548 .70602 Mdot
.2862 .60059 Mdot
.75032 .38599 Mdot
.54587 .27107 Mdot
.24407 .551 Mdot
.24056 .54435 Mdot
.34176 .58073 Mdot
.38941 .63826 Mdot
.76571 .36261 Mdot
.74578 .71621 Mdot
.64529 .6316 Mdot
.34717 .57213 Mdot
.56698 .41949 Mdot
.55061 .53056 Mdot
.72488 .4053 Mdot
.60284 .61562 Mdot
.81193 .36391 Mdot
.30571 .27483 Mdot
.33477 .61218 Mdot
.47505 .54641 Mdot
.52718 .24503 Mdot
.57958 .41324 Mdot
.60967 .70921 Mdot
.55696 .52021 Mdot
.37939 .51232 Mdot
.31605 .47417 Mdot
.43108 .62215 Mdot
.73341 .44633 Mdot
.63844 .63838 Mdot
.36198 .67475 Mdot
.33479 .33655 Mdot
.76209 .69069 Mdot
.28339 .4612 Mdot
.58098 .53778 Mdot
.62228 .66496 Mdot
.48624 .44435 Mdot
.53367 .26018 Mdot
.77915 .30037 Mdot
.74661 .37527 Mdot
.32924 .49147 Mdot
.3125 .61067 Mdot
.64111 .72314 Mdot
.73989 .41432 Mdot
.51584 .52392 Mdot
.76151 .67724 Mdot
.38891 .41482 Mdot
.74407 .40268 Mdot
.25108 .56622 Mdot
.45391 .57591 Mdot
.73585 .7112 Mdot
.73287 .43532 Mdot
.72212 .73205 Mdot
.3575 .33519 Mdot
.54885 .4524 Mdot
.68376 .75213 Mdot
.41554 .48254 Mdot
.56392 .55774 Mdot
.39001 .3139 Mdot
.46493 .55904 Mdot
.79737 .65412 Mdot
.32109 .47483 Mdot
.5984 .45472 Mdot
.24306 .58002 Mdot
.34885 .67077 Mdot
.7616 .37599 Mdot
.28612 .60846 Mdot
.74036 .71866 Mdot
.54012 .42531 Mdot
.71315 .44154 Mdot
.33037 .34513 Mdot
.55005 .28275 Mdot
.6475 .52138 Mdot
.37426 .40788 Mdot
.61995 .54529 Mdot
.66501 .35776 Mdot
.45509 .43685 Mdot
.78409 .34386 Mdot
.6484 .34375 Mdot
.43591 .47081 Mdot
.59906 .4687 Mdot
.27049 .54874 Mdot
.80023 .34986 Mdot
.65035 .36651 Mdot
.23305 .62358 Mdot
.76404 .69855 Mdot
.7017 .69313 Mdot
.69399 .22261 Mdot
.34776 .7086 Mdot
.46098 .46651 Mdot
.81436 .64645 Mdot
.49159 .50189 Mdot
.68162 .70132 Mdot
.56131 .5419 Mdot
.28569 .46743 Mdot
.77125 .31557 Mdot
.58455 .47705 Mdot
.42767 .47298 Mdot
.4193 .35659 Mdot
.25009 .51217 Mdot
.64016 .35664 Mdot
.56866 .42249 Mdot
.59618 .63931 Mdot
.51668 .24933 Mdot
.65665 .71222 Mdot
.35085 .5715 Mdot
.75835 .69068 Mdot
.76835 .66817 Mdot
.64818 .44766 Mdot
.51013 .65589 Mdot
.69094 .22241 Mdot
.4281 .44777 Mdot
.40883 .27495 Mdot
.23768 .50625 Mdot
.74218 .4387 Mdot
.71668 .69424 Mdot
.49834 .33589 Mdot
.51159 .27282 Mdot
.38611 .41081 Mdot
.79564 .40136 Mdot
.42634 .51202 Mdot
.42197 .74871 Mdot
.33479 .58113 Mdot
.23441 .62195 Mdot
.23401 .57893 Mdot
.34509 .71544 Mdot
.79754 .65198 Mdot
.4825 .62126 Mdot
.45193 .58483 Mdot
.42722 .46353 Mdot
.78248 .6516 Mdot
.35365 .68577 Mdot
.44473 .67645 Mdot
.34536 .3844 Mdot
.69881 .24742 Mdot
.22439 .52158 Mdot
.44073 .60418 Mdot
.51092 .56901 Mdot
.5614 .43029 Mdot
.34899 .64978 Mdot
.35369 .61031 Mdot
.24118 .51055 Mdot
.73591 .31048 Mdot
.51981 .59028 Mdot
.60878 .55561 Mdot
.7081 .72399 Mdot
.49604 .57084 Mdot
.77003 .66985 Mdot
.36234 .44429 Mdot
.72955 .29386 Mdot
.62956 .39762 Mdot
.69128 .46172 Mdot
.45059 .34356 Mdot
.28124 .59043 Mdot
.76442 .40202 Mdot
.51359 .52351 Mdot
.50544 .62847 Mdot
.2298 .56327 Mdot
.77653 .69439 Mdot
.5951 .49154 Mdot
.44167 .80945 Mdot
.60694 .46952 Mdot
.51633 .26064 Mdot
.50986 .25312 Mdot
.40066 .63916 Mdot
.55165 .53682 Mdot
.37716 .59526 Mdot
.55455 .45685 Mdot
.34486 .37054 Mdot
.78691 .43279 Mdot
.75014 .27301 Mdot
.28636 .48278 Mdot
.7566 .71726 Mdot
.3713 .50666 Mdot
.27648 .48358 Mdot
.67419 .70745 Mdot
.51807 .62788 Mdot
.48985 .45927 Mdot
.63184 .44225 Mdot
.33433 .4766 Mdot
.73997 .26341 Mdot
.49251 .61634 Mdot
.60314 .4515 Mdot
.63745 .73012 Mdot
.43351 .61012 Mdot
.44179 .75663 Mdot
.37045 .68633 Mdot
.78578 .68394 Mdot
.75114 .69009 Mdot
.41803 .75553 Mdot
.54945 .56447 Mdot
.50398 .62309 Mdot
.74796 .31033 Mdot
.59602 .47192 Mdot
.75998 .38277 Mdot
.37311 .76586 Mdot
.35059 .36233 Mdot
.64413 .34147 Mdot
.64374 .37312 Mdot
.55128 .27821 Mdot
.37777 .38712 Mdot
.74136 .33161 Mdot
.61129 .48951 Mdot
.64203 .63649 Mdot
.64433 .73547 Mdot
.71622 .24239 Mdot
.324 .60586 Mdot
.65499 .49802 Mdot
.68331 .43715 Mdot
.51866 .58812 Mdot
.5897 .39202 Mdot
.38989 .53092 Mdot
.60018 .55202 Mdot
.44379 .7482 Mdot
.23944 .59065 Mdot
.79929 .3973 Mdot
.45693 .3413 Mdot
.47469 .23007 Mdot
.35695 .64617 Mdot
.59691 .70702 Mdot
.2291 .57066 Mdot
.77334 .29682 Mdot
.4442 .67281 Mdot
.40967 .78542 Mdot
.38887 .64233 Mdot
.72446 .41375 Mdot
.42736 .81133 Mdot
.39469 .63595 Mdot
.83216 .62295 Mdot
.34375 .61253 Mdot
.38029 .35804 Mdot
.21191 .58111 Mdot
.66381 .3555 Mdot
.37095 .40704 Mdot
.59952 .56756 Mdot
.78777 .37549 Mdot
.58345 .40987 Mdot
.59142 .45743 Mdot
.73652 .32228 Mdot
.73082 .716 Mdot
.70361 .73097 Mdot
.37124 .63672 Mdot
.25066 .53801 Mdot
.45018 .82393 Mdot
.62881 .72535 Mdot
.2976 .29129 Mdot
.74314 .37307 Mdot
.40594 .33828 Mdot
.51219 .51905 Mdot
.39135 .50233 Mdot
.76097 .31806 Mdot
.78996 .65433 Mdot
.56734 .56398 Mdot
.61949 .6369 Mdot
.64685 .38592 Mdot
.67732 .44396 Mdot
.36768 .58074 Mdot
.7286 .39096 Mdot
.61226 .70536 Mdot
.58573 .47619 Mdot
.74279 .70915 Mdot
.2804 .59001 Mdot
.55366 .29435 Mdot
.70206 .24849 Mdot
.53277 .26774 Mdot
.70843 .74509 Mdot
.37927 .76749 Mdot
.64082 .73592 Mdot
.71943 .24815 Mdot
.34103 .59555 Mdot
.40849 .40498 Mdot
.68754 .21301 Mdot
.805 .37131 Mdot
.50604 .62249 Mdot
.44929 .33266 Mdot
.82656 .63196 Mdot
.61917 .6238 Mdot
.72528 .42113 Mdot
.32448 .34747 Mdot
.69207 .7306 Mdot
.47011 .4339 Mdot
.46499 .32934 Mdot
.57776 .45392 Mdot
.31455 .48318 Mdot
.24731 .53888 Mdot
.64017 .69947 Mdot
.71489 .72633 Mdot
.32554 .32298 Mdot
.32834 .36597 Mdot
.35367 .33407 Mdot
.33626 .50443 Mdot
.78392 .38145 Mdot
.75963 .49051 Mdot
.31329 .31421 Mdot
.73948 .30655 Mdot
.50392 .22593 Mdot
.36677 .60432 Mdot
.33969 .37002 Mdot
.62083 .38601 Mdot
.65599 .70901 Mdot
.7055 .22528 Mdot
.35111 .38605 Mdot
.81032 .35898 Mdot
.79836 .4256 Mdot
.33237 .49851 Mdot
.36754 .54307 Mdot
.57719 .41869 Mdot
.49391 .60236 Mdot
.44779 .74705 Mdot
.62614 .73585 Mdot
.69411 .70045 Mdot
.6251 .63713 Mdot
.4765 .34114 Mdot
.38776 .4916 Mdot
.76736 .39485 Mdot
.57529 .47383 Mdot
.77179 .392 Mdot
.36258 .37297 Mdot
.44813 .36432 Mdot
.68517 .20441 Mdot
.25009 .61698 Mdot
.51166 .43391 Mdot
.63532 .48179 Mdot
.65562 .49996 Mdot
.45724 .39039 Mdot
.44936 .66168 Mdot
.62026 .41916 Mdot
.67854 .73303 Mdot
.78372 .37297 Mdot
.35294 .56371 Mdot
.58058 .41581 Mdot
.38281 .72432 Mdot
.56574 .35787 Mdot
.46488 .43186 Mdot
.4493 .68553 Mdot
.66514 .72993 Mdot
.48098 .72001 Mdot
.35117 .66448 Mdot
.41128 .61089 Mdot
.60311 .36092 Mdot
.63808 .48938 Mdot
.67018 .71958 Mdot
.40502 .63986 Mdot
.35502 .64714 Mdot
.73775 .72083 Mdot
.38827 .39304 Mdot
.35609 .724 Mdot
.65023 .69633 Mdot
.60304 .39523 Mdot
.39053 .48022 Mdot
.51363 .60988 Mdot
.3265 .28563 Mdot
.75819 .32947 Mdot
.62615 .59457 Mdot
.61322 .48799 Mdot
.34144 .26939 Mdot
.77841 .34076 Mdot
.43956 .69519 Mdot
.8397 .58583 Mdot
.52094 .62327 Mdot
.2441 .57877 Mdot
.37091 .31417 Mdot
.54196 .51538 Mdot
.36076 .27924 Mdot
.43641 .33459 Mdot
.50908 .29086 Mdot
.40191 .77886 Mdot
.55091 .51833 Mdot
.43097 .61297 Mdot
.4725 .61175 Mdot
.59822 .43706 Mdot
.3661 .27323 Mdot
.52068 .36678 Mdot
.59163 .50265 Mdot
.6222 .35448 Mdot
.58937 .54983 Mdot
.59857 .44378 Mdot
.37677 .74614 Mdot
.67031 .72249 Mdot
.70109 .73097 Mdot
.46724 .45319 Mdot
.76518 .3169 Mdot
.40398 .31023 Mdot
.74429 .37668 Mdot
.40658 .52185 Mdot
.36951 .7448 Mdot
.52927 .2661 Mdot
.70427 .2268 Mdot
.38294 .46161 Mdot
.68233 .50548 Mdot
.79236 .42497 Mdot
.74563 .39281 Mdot
.40099 .74722 Mdot
.20756 .60425 Mdot
.64545 .737 Mdot
.58284 .42444 Mdot
.23292 .58677 Mdot
.63809 .61304 Mdot
.75176 .41346 Mdot
.54151 .46936 Mdot
.51578 .62601 Mdot
.31962 .29166 Mdot
.48691 .44259 Mdot
.56037 .65629 Mdot
.32906 .28389 Mdot
.37855 .38629 Mdot
.74125 .33328 Mdot
.41169 .28371 Mdot
.44795 .54328 Mdot
.38414 .45766 Mdot
.70173 .24179 Mdot
.55372 .66966 Mdot
.5069 .24467 Mdot
.29861 .2709 Mdot
.39967 .77931 Mdot
.68151 .69815 Mdot
.69962 .25249 Mdot
.37413 .68841 Mdot
.55636 .45616 Mdot
.23377 .64822 Mdot
.38788 .46041 Mdot
.24968 .49477 Mdot
.36268 .66498 Mdot
.6782 .4568 Mdot
.3966 .46868 Mdot
.7048 .21624 Mdot
.74814 .40469 Mdot
.47144 .4606 Mdot
.2958 .29343 Mdot
.74646 .70529 Mdot
.49604 .24805 Mdot
.35898 .73523 Mdot
.78607 .38673 Mdot
.4337 .75704 Mdot
.81815 .64252 Mdot
.49743 .57819 Mdot
.36777 .50174 Mdot
.67113 .44455 Mdot
.23359 .59303 Mdot
.54966 .49684 Mdot
.32376 .35772 Mdot
.24011 .60596 Mdot
.68213 .42203 Mdot
.52457 .55301 Mdot
.32499 .46681 Mdot
.37424 .49871 Mdot
.48254 .55157 Mdot
.51771 .63238 Mdot
.4423 .60398 Mdot
.45896 .58413 Mdot
.35277 .67863 Mdot
.46733 .54172 Mdot
.24979 .61966 Mdot
.38176 .66258 Mdot
.36423 .35589 Mdot
.65239 .70455 Mdot
.61079 .43865 Mdot
.6086 .62747 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0?ooooooB_ooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A006ooooo`03o`000?oooooooooo0?ooooooB_ooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0=gooooo0_l0
001Zooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7o
k^k^00Kooooo0ol0003Mooooo`Co0000J?ooool00003ooooool0003ooooo00;ooooo00?o0000oooo
ooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0=_ooooo1_l0001Xoooo
o`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0foooool6o`0006Sooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMg
M`_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0=cooooo0_l00002
ooooo`;o0000Ioooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`00
0?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0g?ooool3o`000004ooooool0003o0000o`0006Ko
oooo000Looooo`03o`000?oooooooooo0=cooooo0ol00002ooooo`;o0000I_ooool001cooooo00?o
0000ooooooooool0g_ooool2o`000003ooooool0003o000006Kooooo000Looooo`03o`000?oooooo
oooo0=gooooo0ol00003ooooo`;o0000I?ooool001cooooo00?o0000ooooooooool0X?ooool2o`00
03_ooooo0ol000000ooooooo0000o`000002o`0006Cooooo000Looooo`03o`000?oooooooooo09Ko
oooo0_l00002ooooo`;o00001?ooool2o`0003cooooo0_l000000ooooooo0000o`000003o`0006?o
oooo000Looooo`03o`000?oooooooooo09Kooooo0_l00002ooooo`;o0000B?ooool2o`0006?ooooo
000Looooo`03o`000?oooooooooo09Gooooo0_l00018ooooo`;o00000oooool2o`0006?ooooo000L
ooooo`03o`000?oooooooooo09Gooooo1?l0000;ooooo`;o0000>Oooool3o`0000;ooooo0ol0001R
ooooo`007?ooool00ol0003oooooooooo`2Fooooo`?o00002oooool2o`0000?ooooo1?l0000coooo
o`;o00000_ooool4o`00067ooooo000Looooo`03o`000?oooooooooo073ooooo0_l0000_ooooo`;o
00001?ooool6o`0003?ooooo0_l00002ooooo`Co0000HOooool001cooooo00?o0000ooooooooool0
Koooool3o`0002_ooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo
0000o`000003o`00033ooooo0ol00002ooooo`Co0000HOooool001cooooo0_l0001Yooooo`;o0000
1Oooool4o`0002[ooooo0_l00005ooooo`;o00001_ooool3o`00033ooooo0ol00004ooooo`;o0000
00?oooooo`000?l00000G_ooool001cooooo00?o0000ooooooooool0IOooool2o`000003ooooool0
003o000000Oooooo0_l00004ooooo`;o0000:Oooool2o`0000Wooooo0_l000000ooooooo0000o`00
000]ooooo`Go00001Oooool2o`0005kooooo000Looooo`03o`000?oooooooooo06?ooooo1?l0000@
ooooo`?o0000:?ooool4o`0000Oooooo0_l000000ooooooo0000o`00000]ooooo`Go00001oooool2
o`0005cooooo000Looooo`03o`000?oooooooooo067ooooo1?l00003ooooo`;o00003_ooool6o`00
02Cooooo1?l00004ooooo`;o00001Oooool2o`0002gooooo0_l00009ooooo`;o0000G?ooool001co
oooo00?o0000ooooooooool0G_ooool2o`000004ooooool0003o0000o`0000Cooooo0_l00008oooo
o`Go00000oooool4o`0002Cooooo1?l00004ooooo`;o00001Oooool3o`0003Wooooo0_l0001Joooo
o`007?ooool00ol0003oooooooooo`1Nooooo`;o00004_ooool8o`0000Kooooo0_l0000Vooooo`?o
00001_ooool3o`0002oooooo0_l00008ooooo`;o0000F_ooool001cooooo00?o0000ooooooooool0
G_ooool2o`0000_ooooo0_l00005ooooo`?o000000?oooooo`000?l000001?l00004ooooo`;o0000
9_ooool3o`0000;ooooo0_l00002ooooo`Co0000;_ooool2o`0000Cooooo0_l00005ooooo`;o0000
Eoooool001cooooo00?o0000ooooooooool0GOooool2o`0000cooooo0_l00005ooooo`co000000?o
ooooo`000?l000008Oooool2o`0000Wooooo0ol00003ooooo`;o0000;Oooool2o`0000Gooooo0_l0
0005ooooo`;o0000Eoooool001cooooo00?o0000ooooooooool0GOooool2o`000003ooooool0003o
0000013ooooo4Ol0000Oooooo`;o00002_ooool2o`0000?ooooo1Ol0000Zooooo`;o00003?ooool2
o`0005Oooooo000Looooo`03o`000?oooooooooo05[ooooo0_l00004ooooo`;o00000oooool2o`00
00Sooooo5?l0000Wooooo`?o00000_ooool2o`0000?ooooo1?l0000/ooooo`;o00000_ooool2o`00
00Sooooo1?l0001Cooooo`007?ooool00ol0003oooooooooo`1Jooooo`;o00002Oooool4o`0000Ko
oooo5?l0000Looooo`?o00000_ooool=o`0000Cooooo0ol0000/ooooo`?o000000?oooooo`000?l0
00002?ooool4o`0005?ooooo000Looooo`03o`000?oooooooooo05Oooooo1?l0000;ooooo`?o0000
00?oooooo`000?l000001?oooolDo`0001_ooooo0ol00002ooooo`go00001?ooool4o`0002cooooo
0_l0000>ooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0Eoooool4o`0000[ooooo1?l0
00000ooooooo0000o`000004oooooaCo00007oooool5o`0000;ooooo1Ol00002ooooo`;o00000_oo
ool4o`0002gooooo1?l0000;ooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0Eoooool5
o`000003ooooool0003o000000Gooooo0ol00009oooooa?o00007oooool5o`0000Kooooo1_l00003
ooooo`Co0000;?ooool4o`0005oooooo000Looooo`03o`000?oooooooooo05Oooooo2?l00005oooo
o`;o00001_ooool2o`0000;ooooo4Ol000000ooooooo0000o`00000Nooooo`?o00002Oooool5o`00
00Gooooo0_l0000_ooooo`;o0000G_ooool001cooooo00?o0000ooooooooool0FOooool5o`0000ko
oooo1?l00002ooooo`oo000000?oooooo`000?l000007oooool2o`0000[ooooo1Ol00003ooooo`?o
0000;oooool2o`0000Kooooo0_l00004ooooo`;o0000D?ooool001cooooo0_l0001Kooooo`Co0000
3oooool4o`000003ooooool0003o0000013o0000;?ooool5o`0000;ooooo1?l0000fooooo`;o0000
1?ooool4o`0004kooooo000Looooo`03o`000?oooooooooo05cooooo1?l0000>ooooo`?o00000_oo
ool@o`0002oooooo0ol00003ooooo`?o0000=oooool2o`0000?ooooo1?l0001>ooooo`007?ooool0
0ol0003oooooooooo`1Mooooo`?o00003_ooool3o`0000Cooooo3Ol0000Mooooo`;o00004_ooool4
o`0000;ooooo0_l0000aooooo`;o00000_ooool4o`0000;ooooo0_l0001Aooooo`007?ooool00ol0
003oooooooooo`1Nooooo`Co00003?ooool3o`0000Gooooo2ol000000ooooooo0000o`00000Joooo
o`?o00004oooool3o`000003ooooool0003o000000;o0000;oooool3o`000004ooooool0003o0000
o`0000Cooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`1Oooooo`Co00004Oooool2o`00
0003ooooool0003o000000Go000000Coooooo`000?l0003ooooo0_l0000Jooooo`;o00005?ooool2
o`0000;ooooo1Ol0000^ooooo`;o00000_ooool3o`0000;ooooo0_l0001Cooooo`007?ooool00ol0
003oooooooooo`1Qooooo`?o00003?ooool2o`0000;ooooo2Ol00005ooooo`;o0000<?ooool3o`00
00;ooooo1?l0000gooooo`Go0000D?ooool001cooooo00?o0000ooooooooool0H?ooool4o`0000co
oooo0_l00003ooooo`?o000000?oooooo`000?l000001oooool5o`0000Gooooo0_l0000Vooooo`Co
000000?oooooo`000?l000000_l0000fooooo`Ko0000D?ooool001cooooo00?o0000ooooooooool0
H?ooool5o`000003ooooool0003o000000Cooooo0_l00004ooooo`;o00001Oooool2o`0000Wooooo
0ol00005ooooo`;o00009_ooool9o`0002kooooo0_l00006ooooo`;o00001Oooool2o`0004gooooo
000Looooo`03o`000?oooooooooo067ooooo1?l000000ooooooo0000o`000004ooooo`;o00001?oo
ool4o`0000oooooo0_l0000]ooooo`;o000000?oooooo`000?l000001?l0000^ooooo`;o00003Ooo
ool2o`0004gooooo000Looooo`03o`000?oooooooooo067ooooo0_l0000@ooooo`?o00007Oooool3
o`0001oooooo0_l00002ooooo`Co0000;oooool2o`000003ooooool0003o000000cooooo0_l0001:
ooooo`007?ooool00ol0003oooooooooo`1Qooooo`;o000000Coooooo`000?l0003o00003Oooool5
o`0000oooooo0_l00009ooooo`?o000000?oooooo`000?l000007?ooool2o`0000?ooooo1?l0000^
ooooo`Go000000?oooooo`000?l000002?ooool3o`000003ooooool0003o000004Oooooo000Loooo
o`03o`000?oooooooooo063ooooo0ol000001?oooooo0000o`000?l00005ooooo`;o000000Cooooo
o`000?l0003o00000_ooool5o`0000oooooo1?l000001Ooooooo0000o`000?l0003ooooo00Go0000
00?oooooo`000?l000000_l0000Jooooo`?o000000?oooooo`000?l000000ol0000@ooooo`;o0000
7Oooool2o`0000;ooooo0ol00008ooooo`;o00000_ooool2o`0004Oooooo000Looooo`03o`000?oo
oooooooo063ooooo0_l00002ooooo`?o00000_ooool2o`000004ooooool0003o0000ooooo`?o0000
1?ooool3o`0000Oooooo0_l00006oooooa?o00000oooool4o`0001?ooooo2?l0000?ooooo`Go0000
7?ooool2o`0000;ooooo0_l00005ooooo`;o0000Coooool001cooooo00?o0000ooooooooool0I?oo
ool3o`0000;ooooo1?l00009ooooo`;o00002?ooool2o`0000?ooooo7_l0000Booooo`So00003ooo
ool5o`0001cooooo0_l00009ooooo`?o0000C_ooool001cooooo00?o0000ooooooooool0IOooool3
o`0000?ooooo0_l00009ooooo`;o00002?oooolNo`0000;ooooo0ol0000Booooo`Oo00002?ooool2
o`0000Cooooo0_l000000ooooooo0000o`000002o`0001cooooo0_l0000:ooooo`Co00001?ooool2
o`0004Kooooo000Looooo`03o`000?oooooooooo06Gooooo1Ol0000;ooooo`?o00000_ooool2o`00
00Cooooo3_l000000ooooooo0000o`00000Ao`0001?ooooo1ol00008ooooo`?o00000oooool2o`00
00?ooooo0_l0000Zooooo`;o00001?ooool2o`0004Kooooo000Looooo`;o0000Ioooool4o`0000Ko
oooo0_l00003ooooo`Co000000?oooooo`000?l000001Oooool3o`0000Gooooo1Ol000000ooooooo
0000o`00000Bo`0000;ooooo0_l0000>ooooo`Go00002?ooool2o`000004ooooool0003o0000o`00
00;ooooo0_l00005ooooo`Co0000:?ooool2o`000003ooooool0003o000004Oooooo000Looooo`03
o`000?oooooooooo06Kooooo0ol00007ooooo`;o00000_ooool5o`0000Oooooo0ol00008ooooo`?o
000000?oooooo`000?l000004ol000000ooooooo0000o`00000=ooooo`Ko00001oooool8o`000003
ooooool0003o000000Cooooo1Ol0000Xooooo`;o000000?oooooo`000?l00000Aoooool001cooooo
00?o0000ooooooooool0I_ooool3o`0000[ooooo1?l00008ooooo`?o00000_ooool2o`0000Gooooo
0ol000000ooooooo0000o`00000Eo`000003ooooool0003o000000_ooooo1_l00007ooooo`So0000
0oooool2o`0000;ooooo1_l0000Uooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0IOoo
ool4o`0000[ooooo1ol00003ooooo`Co00000ooooolXo`0000Sooooo1_l00007ooooo`;o000000?o
ooooo`000?l000000_l00004ooooo`;o00000oooool5o`0002Cooooo0ol00006ooooo`;o0000A?oo
ool001cooooo00?o0000ooooooooool0IOooool2o`0000;ooooo0_l00003ooooo`;o00001Oooool5
o`0000?ooooo0ol00004ooooobSo00002?ooool5o`0000Oooooo0ol0000?ooooo`Co00007oooool2
o`0000?ooooo0_l00007ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0Ioooool4o`00
00?ooooo0_l0000>ooooo`;o00001?ooool8o`0000;ooooo7_l00009ooooo`Co00001oooool4o`00
00oooooo0ol0000Oooooo`;o00003Oooool2o`0004?ooooo000Looooo`03o`000?oooooooooo06Oo
oooo0_l000000ooooooo0000o`000009ooooo`;o00001_ooool2o`0000?ooooo;?l00006ooooo`Co
00001_ooool3o`000003ooooool0003o000000_ooooo1ol000000ooooooo0000o`00000Iooooo`;o
00004?ooool2o`0004?ooooo000Looooo`03o`000?oooooooooo06Wooooo1Ol00007ooooo`;o0000
1_ooool2o`0000?ooooo:?l000001?oooooo0000o`000?l00004ooooo`Ko00001Oooool4o`0000;o
oooo0ol00009ooooo`Co000000?oooooo`000?l000000ol0000Iooooo`;o00003_ooool2o`0004Go
oooo000Looooo`03o`000?oooooooooo06Wooooo1Ol00004ooooo`;o00002?ooool2o`0000?ooooo
3_l000000ooooooo0000o`00000Lo`0000Cooooo0ol00006ooooo`Co00001?ooool3o`0000Oooooo
0_l00005ooooo`Go00005Oooool3o`0000?ooooo0_l00005ooooo`?o00001?ooool2o`0004Gooooo
000Looooo`03o`000?oooooooooo06[ooooo0ol00005ooooo`;o00002?ooool2o`0000?ooooo1_l0
00000ooooooo0000o`00000To`0000Cooooo0ol00006ooooo`;o00004?ooool2o`0000Cooooo1_l0
000Eooooo`?o00000oooool2o`0000Gooooo0ol00005ooooo`;o0000A?ooool001cooooo00?o0000
ooooooooool0K?ooool2o`0000kooooo0_l00004ooooo`?o00001_ooool6o`000003ooooool0003o
000001_o00000oooool3o`0000Kooooo0_l00009ooooo`;o00002oooool5o`0001Kooooo0_l00004
ooooo`;o00001Oooool2o`0000Kooooo1?l00012ooooo`007?ooool00ol0003oooooooooo`1/oooo
o`;o00003_ooool3o`0000;ooooo0ol00007ooooobCo000000?oooooo`000?l000000ol00006oooo
o`;o00002Oooool2o`0000_ooooo1Ol0000Cooooo`;o00001_ooool2o`0000;ooooo0_l00002oooo
o`;o00000oooool2o`0000;ooooo0ol00012ooooo`007?ooool00ol0003oooooooooo`1[ooooo`Go
00001oooool2o`0000Cooooo0_l00002ooooo`?o00002OoooolQo`0000;ooooo1?l00005ooooo`;o
00002?ooool2o`000003ooooool0003o000000Kooooo0_l00003ooooo`Oo00004Oooool2o`0000?o
oooo1Ol00002ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`;o0000@oooool001cooooo
00?o0000ooooooooool0J_ooool6o`0000Oooooo0_l00008ooooo`;o00002_oooolPo`0000?ooooo
1?l00005ooooo`;o00002?ooool2o`000003ooooool0003o000000Kooooo0_l00003ooooo`Oo0000
3oooool2o`000003ooooool0003o000000;ooooo0ol00009ooooo`?o000000?oooooo`000?l00000
Aoooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413o
ooooooooo`04ooooo`03o`000?oooooooooo06[ooooo1Ol0000;ooooo`Co00000oooool3o`0000go
oooo7?l00003ooooo`?o00001_ooool2o`000003ooooool0003o000001Kooooo1Ol0000@ooooo`;o
000000?oooooo`000?l000000_l00007ooooo`;o00001?ooool2o`0000Gooooo0_l00013ooooo`00
00KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo06cooooo0ol0000;ooooo`Co00000oooool3o`0000gooooo0_l000000ooo
oooo0000o`00000Io`0000gooooo0_l00002ooooo`Co00001Oooool4o`0000Kooooo1_l0000Eoooo
o`;o00001Oooool4o`0000_ooooo0_l00013ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413o
ooooooooo`09ooooo`Go00001_ooool00ol0003oooooooooo`1/ooooo`;o00001_ooool2o`0000_o
oooo0ol0000Aooooo`So000000?oooooo`000?l000003ol00005ooooo`?o00002?ooool5o`000003
ooooool0003o000000Ko000000Coooooo`000?l0003ooooo1_l0000Nooooo`Co00001oooool3o`00
04Kooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoo
oooo00001oooool3o`0006cooooo1Ol00003ooooo`;o00007oooool8o`000003ooooool0003o0000
00ko00001Oooool4o`0000Sooooo0_l00004ooooo`Ko00000oooool2o`000003ooooool0003o0000
00Co00005oooool2o`0000Cooooo1Ol00006ooooo`Co0000A_ooool00003ooooool0003ooooo00;o
oooo00?o0000ooooooooool02Oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo
06gooooo1?l00007ooooo`;o00001oooool2o`0001Kooooo1?l000000ooooooo0000o`00000<o`00
00Oooooo0_l0000<ooooo`;o00000_ooool2o`0000Wooooo0ol000001?oooooo0000o`000?l0000A
ooooo`;o00001?ooool3o`0000?ooooo0ol000000ooooooo0000o`000005ooooo`;o0000B?ooool0
0003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00omgMgOoc<c<o`000007oooo
o`03o`000?oooooooooo06gooooo1?l00004ooooo`Ko00001_ooool2o`0001_ooooo2ol0000:oooo
o`Go00001Oooool3o`000003ooooool0003o000000gooooo1_l0000Booooo`;o00001Oooool2o`00
00?ooooo0ol000000ooooooo0000o`000006ooooo`;o0000Aoooool00006oooooomgMgOoV9RHoooo
oonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo06kooooo0ol00004
ooooo`?o000000Coooooo`000?l0003o00000_ooool2o`0003Cooooo1?l00002ooooo`;o000000Co
ooooo`000?l0003o00003Oooool7o`0002cooooo0_l00017ooooo`0000Koooooonk^k_lb<S;o0000
oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0N_ooool3o`000004
ooooool0003o0000o`0000Cooooo0_l0000aooooo`Co00003_ooool8o`0001?ooooo0_l000000ooo
oooo0000o`000003ooooo`Go00004?ooool2o`0004Gooooo000Looooo`03o`000?oooooooooo07_o
oooo0_l00002ooooo`;o00001?ooool2o`0002_ooooo0_l00003ooooo`Co00003Oooool7o`0000oo
oooo1?l00003ooooo`;o000000?oooooo`000?l000000oooool5o`00013ooooo0_l00015ooooo`00
7?ooool00ol0003oooooooooo`1`ooooo`;o0000?Oooool2o`000003ooooool0003o000000;o0000
00?oooooo`000?l000000_l00003ooooo`;o00001_ooool8o`00013ooooo1?l00006ooooo`;o0000
1Oooool2o`0005Sooooo000Looooo`03o`000?oooooooooo073ooooo0_l000000ooooooo0000o`00
000;ooooo`;o00002?ooool2o`0001kooooo0ol00002ooooo`;o00000oooool3o`0000?ooooo0_l0
0002ooooo`;o00000_ooool2o`000003ooooool0003o000000Co00003Oooool4o`0000?ooooo0_l0
0007ooooo`;o00001oooool2o`0000[ooooo0_l00003ooooo`;o0000AOooool001cooooo00?o0000
ooooooooool0L?ooool5o`0000_ooooo0_l00008ooooo`;o00006Oooool3o`0000;ooooo1?l00007
ooooo`;o00000oooool4o`0000;ooooo1?l000001?oooooo0000o`000?l0000@ooooo`Co00000ooo
ool2o`00013ooooo0_l0000:ooooo`Oo0000AOooool001cooooo00?o0000ooooooooool0L?ooool3
o`00013ooooo0_l0000Nooooo`Go00001?ooool2o`000003ooooool0003o000000;ooooo0ol00003
ooooo`Go00000_ooool4o`00033ooooo1?l00002ooooo`;o00000_ooool7o`0004Cooooo000Loooo
o`03o`000?oooooooooo07oooooo0ol000000ooooooo0000o`000005ooooo`;o00001oooool4o`00
00_ooooo0ol0000:ooooo`Oo00000oooool5o`0002?ooooo0_l0000<ooooo`;o00000oooool4o`00
00;ooooo1?l000000ooooooo0000o`000004o`0004Cooooo000Looooo`03o`000?oooooooooo077o
oooo0_l0000<ooooo`?o00001_ooool4o`0000Cooooo0_l000000ooooooo0000o`000002o`0000_o
oooo0_l00005ooooo`;o00001_ooool5o`0000Wooooo0_l00002ooooo`Co00004oooool2o`0000Go
oooo0_l00007ooooo`;o00000oooool3o`0000?ooooo0ol00002ooooo`Co000000?oooooo`000?l0
00000_l00016ooooo`007?ooool00ol0003oooooooooo`1aooooo`;o00005Oooool6o`0000;ooooo
0_l00009ooooo`;o00003?ooool3o`0000Wooooo0_l00008ooooo`;o00000_ooool4o`0000Gooooo
0_l0000<ooooo`;o00003_ooool2o`000003ooooool0003o000000?o00001_ooool2o`0000;ooooo
1Ol00018ooooo`007?ooool00ol0003oooooooooo`1booooo`?o00005?ooool5o`000003ooooool0
003o000000?o00001_ooool5o`0000Gooooo0_l00004ooooo`;o00002Oooool2o`0000Cooooo0_l0
0006ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00000Fooooo`;o0000
0oooool8o`000003ooooool0003o000000Cooooo2?l00019ooooo`007?ooool00ol0003ooooooooo
o`1booooo`?o00000_ooool2o`0001Kooooo1ol00004ooooo`Go00001Oooool2o`0001Gooooo0_l0
0002ooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`;o00002?ooool6o`0000Sooooo
0_l000000ooooooo0000o`00000=o`0000;ooooo1Ol000000ooooooo0000o`000019ooooo`007?oo
ool00ol0003oooooooooo`1booooo`?o00000_ooool2o`0000kooooo0_l00009ooooo`Co00001?oo
ool4o`00027ooooo0_l00005ooooo`;o00001?ooool2o`000003ooooool0003o000000Gooooo1_l0
0007oooooaGo000000?oooooo`000?l000000oooool3o`0004Sooooo000Looooo`;o0000R?ooool2
o`0000Sooooo0_l0000Looooo`;o00000oooool2o`0000[ooooo0_l0000=ooooo`;o00002_ooool2
o`0000Kooooo6?l00004ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0M?ooool2o`00
0003ooooool0003o000000[ooooo0_l0000<ooooo`;o000000?oooooo`000?l000005Oooool2o`00
00;ooooo0_l00003ooooo`;o00000_ooool2o`0000Gooooo0ol0000Iooooo`;o00001OoooolHo`00
00Gooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o00004Oooool3o`000003
ooooool0003o000000;o00002?ooool2o`0000oooooo0_l00007ooooo`;o00003?ooool2o`0000?o
oooo0ol00005ooooo`;o00000_ooool2o`000003ooooool0003o000001Sooooo0_l00004ooooo`;o
000000?oooooo`000?l000003_l000000ooooooo0000o`000005o`0000?ooooo0_l0001:ooooo`00
7?ooool00ol0003oooooooooo`1Hooooo`Co00000_ooool5o`00013ooooo0_l00004ooooo`Co0000
6?ooool2o`0000Cooooo1?l0000Aooooo`?o00001_ooool2o`000004ooooool0003o0000o`0000;o
oooo0_l0000Fooooo`;o00000_oooolMo`0000?ooooo0_l0001:ooooo`007?ooool00ol0003ooooo
ooooo`1Hooooo`Co000000?oooooo`000?l000001?l000000ooooooo0000o`00000Cooooo`Co0000
2_ooool2o`0000cooooo0_l00004ooooo`;o00000_ooool2o`0001Sooooo0_l00002ooooo`;o0000
0_ooool2o`0000_ooooo0_l0000=ooooo`;o000000?oooooo`000?l000003ol000000ooooooo0000
o`000005o`0000?ooooo0ol0001:ooooo`007?ooool00ol0003oooooooooo`1Eooooo`Ko00000_oo
ool4o`000003ooooool0003o000000Co00003?ooool3o`0000gooooo0_l000000ooooooo0000o`00
0009ooooo`;o00002oooool2o`0001kooooo0_l0000=ooooo`;o00004_oooolGo`0000?ooooo0ol0
001:ooooo`007?ooool00ol0003oooooooooo`1Booooo`Wo00001oooool6o`0000cooooo0ol00003
ooooo`;o000000?oooooo`000?l000001Oooool2o`0000?ooooo0ol00006ooooo`;o00006?ooool2
o`00017ooooo1?l00002ooooo`;o00000oooool2o`0001;ooooo0_l00002oooooaOo000000?ooooo
o`000?l00000COooool001cooooo00?o0000ooooooooool0Coooool8o`0000cooooo2?l00009oooo
o`?o00000oooool2o`000003ooooool0003o000000Sooooo1Ol0000Pooooo`;o00002Oooool2o`00
00Gooooo1Ol000001?oooooo0000o`000?l00003ooooo`;o00004Oooool3o`000003ooooool0003o
000001?o00000oooool3o`0004gooooo000Looooo`03o`000?oooooooooo04oooooo2Ol0000;oooo
o`So00002Oooool3o`0000Sooooo0_l00006ooooo`;o0000;?ooool4o`000003ooooool0003o0000
00;ooooo0_l000001?oooooo0000o`000?ooool2o`0001Oooooo0_l00002ooooo`oo00000_ooool4
o`0000?ooooo0ol0001=ooooo`007?ooool00ol0003oooooooooo`1Aooooo`Oo00001oooool2o`00
00;ooooo1?l00002ooooo`;o00002_ooool4o`0000;ooooo0_l00002ooooo`;o00007?ooool2o`00
0003ooooool0003o000001?ooooo1ol00002ooooo`;o000000?oooooo`000?l000002?ooool3o`00
0004ooooool0003o0000o`0000?ooooo0_l00002ooooo`?o00000_oooolGo`000003ooooool0003o
0000057ooooo000Looooo`03o`000?oooooooooo04oooooo1Ol00005ooooo`Co000000?oooooo`00
0?l000001?l00005ooooo`Co00002?ooool4o`0000;ooooo0_l00006ooooo`;o00006?ooool2o`00
0003ooooool0003o000001Cooooo1Ol0000@ooooo`?o000000Coooooo`000?l0003o00000ooooolP
o`000003ooooool0003o0000057ooooo000Looooo`03o`000?oooooooooo04cooooo0_l000001?oo
oooo0000o`000?l00004ooooo`;o000000?oooooo`000?l000002_l00004ooooo`Co00002?ooool3
o`0000Gooooo0_l00004ooooo`;o00005oooool2o`0001Sooooo1?l00008ooooo`Go00001?ooool2
o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`00000Io`0000;ooooo0_l00000
0ooooooo0000o`00001Aooooo`007?ooool00ol0003oooooooooo`1<ooooo`Go00001OoooolAo`00
00;ooooo0_l0000Booooo`;o00001oooool2o`0001Cooooo0_l0000<ooooo`;o00003?ooool2o`00
00Oooooo2Ol000001?oooooo0000o`000?ooool4o`000003ooooool0003o000000;ooooo0_l00002
ooooo`?o000000?oooooo`000?l000003ol000000ooooooo0000o`000002o`0005Cooooo000Loooo
o`03o`000?oooooooooo04Sooooo1?l000000ooooooo0000o`000009oooooa?o00002_ooool2o`00
00?ooooo0_l0000:ooooo`;o00008_ooool2o`0001;ooooo0_l000000ooooooo0000o`00000Co`00
0003ooooool0003o000000;ooooo0ol000000ooooooo0000o`00000>o`000003ooooool0003o0000
00?o0000E?ooool001cooooo00?o0000ooooooooool0B?ooool4o`000003ooooool0003o000000[o
oooo5?l00008ooooo`;o00000oooool2o`0000Oooooo0_l0000hooooo`?o000000?oooooo`000?l0
00003Ol000000ooooooo0000o`000005o`0000;ooooo1?l00005ooooo`;o000000?oooooo`000?l0
00002_l000000ooooooo0000o`00001Dooooo`007?ooool00ol0003oooooooooo`18ooooo`;o0000
0_ooool3o`0000;ooooo0_l00004oooooaKo00001oooool4o`0000_ooooo0_l0000Pooooo`;o0000
1Oooool2o`000003ooooool0003o000000cooooo0_l000000ooooooo0000o`00000Bo`000003oooo
ool0003o000000;o000000Coooooo`000?l0003o00003_ooool6o`0005Sooooo000Looooo`;o0000
Aoooool4o`0000;ooooo0_l00003ooooo`;o00001?ooool>o`000003ooooool0003o000000;o0000
0_ooool2o`0000Kooooo1?l0000Tooooo`;o00001oooool2o`0000Gooooo0_l000000ooooooo0000
o`00000=oooooa_o00000_ooool2o`0000Kooooo0_l000000ooooooo0000o`000003ooooo`;o0000
G?ooool001cooooo00?o0000ooooooooool0A_ooool2o`000003ooooool0003o000000cooooo5ol0
0006ooooo`?o00001?ooool2o`0001gooooo1?l0000Kooooo`;o000000?oooooo`000?l000006Ol0
0002ooooo`?o00000_ooool2o`0000?ooooo1_l0001Pooooo`007?ooool00ol0003oooooooooo`15
ooooo`;o00000_ooool2o`0000?ooooo0_l00006oooooaOo00001oooool3o`0000Cooooo0_l0000M
ooooo`;o00005Oooool2o`0000Kooooo0_l000000ooooooo0000o`00000Io`0000;ooooo1ol00002
ooooo`Oo0000H?ooool001cooooo00?o0000ooooooooool0AOooool2o`0000;ooooo1?l000000ooo
oooo0000o`000006ooooo`go000000?oooooo`000?l000002?l00006ooooo`?o0000:oooool2o`00
00gooooo0_l00006ooooo`;o00000_oooolJo`000003ooooool0003o000000Co00001?ooool2o`00
06Gooooo000Looooo`03o`000?oooooooooo04Gooooo0_l00002ooooo`Co000000?oooooo`000?l0
00001?ooool?o`000003ooooool0003o000000So00001_ooool2o`0000;ooooo0_l000000ooooooo
0000o`00000:ooooo`;o00005Oooool2o`0000;ooooo0_l0000:ooooo`;o00003OoooolJo`000003
ooooool0003o000006oooooo000Looooo`03o`000?oooooooooo04?ooooo2?l00003ooooo`;o0000
1?oooolFo`000003ooooool0003o000000Oooooo1_l000000ooooooo0000o`00000:ooooo`;o0000
5Oooool2o`0000Sooooo0_l00002ooooo`Co00003OoooolFo`000004ooooool0003o0000ooooo`;o
000000?oooooo`000?l000000_l0001[ooooo`007?ooool00ol0003oooooooooo`12ooooo`?o0000
0_ooool2o`0000_ooooo6Ol00007ooooo`Co00000oooool2o`0002Kooooo0_l00003ooooo`;o0000
0_ooool2o`000003ooooool0003o000000?o00002Oooool4o`000003ooooool0003o000000ko0000
1Oooool2o`000003ooooool0003o000000;o0000Joooool001cooooo00?o0000ooooooooool0@_oo
ool6o`0000cooooo6Ol00006ooooo`;o00001_ooool2o`0000?ooooo0_l00006ooooo`;o00006Ooo
ool2o`0000[ooooo1Ol00005ooooo`;o00000ooooolGo`000004ooooool0003o0000o`00073ooooo
000Looooo`03o`000?oooooooooo04?ooooo1Ol0000<oooooaWo00001_ooool2o`0000Cooooo0_l0
0005ooooo`;o00001_ooool2o`0001Wooooo0ol0000:ooooo`;o00001oooool4o`000003ooooool0
003o000001[o0000Koooool001cooooo00?o0000ooooooooool0@_ooool5o`0000gooooo5ol00007
ooooo`?o00001?ooool2o`0000Wooooo0_l0000Mooooo`?o00002?ooool4o`0000Sooooo6Ol00002
ooooo`Go0000Koooool001cooooo00?o0000ooooooooool0@_ooool3o`0000Kooooo0_l00007oooo
o`Co000000?oooooo`000?l000004?l00007ooooo`?o00001?ooool4o`0000Oooooo0_l0000Uoooo
o`;o000000Coooooo`000?l0003o00002Oooool2o`000003ooooool0003o000001;o00000oooool2
o`0007?ooooo000Looooo`03o`000?oooooooooo04;ooooo0ol00006ooooo`;o00001_oooolBo`00
0003ooooool0003o000000?o00001oooool3o`0000Cooooo1?l0000/ooooo`Co00000_ooool3o`00
00Sooooo0_l000000ooooooo0000o`00000Ao`0000Cooooo0_l0001cooooo`007?ooool00ol0003o
ooooooooo`12ooooo`Co00001oooool3o`000003ooooool0003o000001Oo00002?ooool3o`0000Oo
oooo0_l0000[ooooo`;o00001?ooool3o`0000Oooooo0ol00002oooooa;o0000NOooool001cooooo
00?o0000ooooooooool0A?ooool2o`000003ooooool0003o000000?ooooo1?l000000ooooooo0000
o`00000Fo`0000Wooooo0_l00008ooooo`;o00005_ooool2o`0001Wooooo0_l00002ooooo`?o0000
0oooool2o`0000?ooooo3_l0001mooooo`007?ooool00ol0003oooooooooo`11ooooo`;o00001?oo
ool7o`000003ooooool0003o000000;ooooo5_l00008ooooo`Go00000_ooool2o`0001Cooooo0_l0
0004ooooo`;o00007Oooool3o`0000_ooooo2ol0001mooooo`007?ooool00ol0003oooooooooo`0n
ooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000;o00000oooool2
o`0000;ooooo0_l00002oooooa;o00002?ooool2o`000003ooooool0003o000000;ooooo0_l0000D
ooooo`;o00001oooool2o`0001Cooooo0_l00002ooooo`Co00003_ooool5o`00087ooooo000Loooo
o`;o0000?oooool4o`0000?ooooo0_l00005ooooo`;o00001Oooool3o`000003ooooool0003o0000
013o00002?ooool2o`0002Cooooo0_l00007ooooo`;o00002oooool2o`0000;ooooo0_l00009oooo
o`?o00001?ooool2o`000003ooooool0003o0000087ooooo000Looooo`03o`000?oooooooooo03ko
oooo1?l00003ooooo`;o00001Oooool2o`0000Gooooo0ol000000ooooooo0000o`00000<o`000003
ooooool0003o000000Oooooo1?l0000Vooooo`;o00001Oooool2o`0000Gooooo0_l0000Cooooo`Go
00000_ooool3o`0008?ooooo000Looooo`03o`000?oooooooooo03kooooo1?l00003ooooo`;o0000
0oooool2o`0000Sooooo4?l0000:ooooo`Co00008_ooool2o`0000?ooooo0_l0000<ooooo`?o0000
0_ooool2o`0000?ooooo0_l0000<ooooo`;o000000?oooooo`000?l000000_l00023ooooo`007?oo
ool00ol0003oooooooooo`0nooooo`Co00002?ooool2o`0000Kooooo4Ol0000;ooooo`Co000000?o
ooooo`000?l000007_ooool3o`0001;ooooo0_l00002ooooo`;o00000oooool4o`0000[ooooo0_l0
00000ooooooo0000o`000025ooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00001_ooool2
o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l000001?ooool7o`00017ooooo0_l00004
ooooo`;o00006?ooool2o`0001Oooooo0_l00005ooooo`?o00001_ooool2o`0008_ooooo000Loooo
o`03o`000?oooooooooo03oooooo1Ol00003ooooo`;o000000Goooooo`000?l0003o0000ooooo`02
o`0000Gooooo0ol0000Eooooo`Co00002?ooool2o`00037ooooo0_l000000ooooooo0000o`000003
ooooo`?o00001Oooool2o`0008_ooooo000Looooo`03o`000?oooooooooo03oooooo1Ol00006oooo
o`;o00000_ooool2o`0000Gooooo1_l0000Aooooo`Go00001?ooool2o`0002_ooooo0_l0000:oooo
o`?o00001?ooool2o`0000Sooooo0_l00028ooooo`007?ooool00ol0003oooooooooo`0oooooo`;o
00001_ooool2o`0000_ooooo1ol0000?ooooo`Ko00001Oooool2o`0000?ooooo0_l0000Qooooo`;o
00000oooool2o`0000[ooooo0_l000000ooooooo0000o`000003ooooo`;o00001oooool2o`0008So
oooo000Looooo`03o`000?oooooooooo03oooooo0_l000000ooooooo0000o`000003ooooo`;o0000
1Oooool2o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l00008ooooo`Wo0000
2_ooool2o`00027ooooo0_l0000Booooo`;o00000oooool2o`000003ooooool0003o000008kooooo
000Looooo`03o`000?oooooooooo043ooooo1?l00004ooooo`;o00000_ooool4o`0000?ooooo0_l0
00000ooooooo0000o`000009o`0000Kooooo1?l0000Uooooo`;o00001oooool2o`0000?ooooo0_l0
000=ooooo`;o00002_ooool2o`0008kooooo000Looooo`03o`000?oooooooooo03gooooo0_l00000
1?oooooo0000o`000?l00005ooooo`;o000000Coooooo`000?l0003o00001Oooool2o`000004oooo
ool0003o0000ooooo`So00001?ooool8o`0000Oooooo0_l0000Jooooo`Co00001Oooool2o`0000?o
oooo0_l00002ooooo`Co00001oooool2o`00067ooooo0_l0000gooooo`007?ooool00ol0003ooooo
ooooo`0mooooo`;o00000_ooool2o`0000Cooooo0_l00002ooooo`;o00004?ooool2o`0000Cooooo
2_l00007ooooo`;o00002_ooool2o`0000gooooo1Ol00005ooooo`;o00001oooool4o`0006[ooooo
0_l0000gooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00000oooool2o`000004ooooool0
003o0000o`0000Cooooo0_l0000Cooooo`;o00000_ooool2o`0001Oooooo0_l0000=ooooo`Co0000
2oooool2o`0000Gooooo0_l0001Vooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0?ooo
ool2o`0000?ooooo0ol000000ooooooo0000o`000002o`0000;ooooo0_l00007ooooo`?o00003ooo
ool2o`0001Sooooo0_l0000:ooooo`;o000000?oooooo`000?l000001_ooool2o`0000;ooooo0_l0
0005ooooo`;o00006?ooool2o`0004cooooo0_l0000jooooo`0000Koooooonk^k_lb<S;o0000oc8b
<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000oooooooo
ool0?Oooool2o`0000Kooooo0_l000000ooooooo0000o`000002o`0000_ooooo0ol0000?ooooo`;o
00006?ooool2o`0000[ooooo0_l000000ooooooo0000o`000006ooooo`;o00002Oooool2o`0001So
oooo0_l00004ooooo`;o0000A_ooool4o`0003Sooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMg
M`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0l
ooooo`Go00001oooool2o`0000_ooooo1?l0000Booooo`;o00002_ooool2o`0004Kooooo0_l00004
ooooo`;o000000?oooooo`000?l00000?_ooool2o`0000?ooooo1?l0000hooooo`0000?ooooooa0@
4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`0looooo`;o000000?oooooo`000?l000005?ooool2o`0001Cooooo0_l00003
ooooo`;o00001Oooool2o`0004Kooooo0ol00004ooooo`Co0000?_ooool3o`0003kooooo00000ooo
oooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@06
ooooo`?o0000?Oooool2o`0000kooooo0_l0000:ooooo`Co00002?ooool2o`0000Oooooo1?l0000T
ooooo`;o00001Oooool2o`000003ooooool0003o000000Kooooo0_l0000Fooooo`;o00001?ooool4
o`0003oooooo0_l0000nooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09oooo
o`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0mooooo`;o000000?ooooo
o`000?l000002?ooool2o`000003ooooool0003o000000Gooooo0_l00003ooooo`Co00002?ooool3
o`0000Kooooo0_l00003ooooo`;o00003_ooool2o`0000?ooooo0_l000001?oooooo0000o`000?l0
0008ooooo`;o00001Oooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o00005_oo
ool3o`0000Cooooo0_l00020ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09
ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0?Oooool5o`000003ooooool0003o
000000Gooooo1Ol00005ooooo`;o00000oooool2o`0000_ooooo0_l00002ooooo`;o00001oooool2
o`0000Kooooo0ol00005ooooo`;o00000oooool2o`000004ooooool0003o0000o`0000cooooo0_l0
0006ooooo`Co00006_ooool5o`0000;ooooo0ol0000jooooo`?o00001Oooool2o`0003_ooooo0000
1_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003ooooo
ooooo`0mooooo`Co00000_ooool2o`0000Gooooo1?l0000;ooooo`;o00001_ooool3o`0000Gooooo
1Ol000000ooooooo0000o`000002ooooo`Co00001?ooool3o`0000Cooooo0_l00005ooooo`;o0000
2oooool2o`0000;ooooo0_l00006ooooo`?o00007?ooool4o`0000;ooooo0ol0000jooooo`?o0000
1?ooool3o`0003_ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0
003o410@1_ooool00ol0003oooooooooo`0nooooo`?o00002oooool2o`0000Kooooo0_l00002oooo
o`Co00001?ooool5o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo1?l0000:
ooooo`?o00001?ooool3o`0000Gooooo0_l00004ooooo`;o00001Oooool2o`0000Cooooo0_l00005
ooooo`;o00004_ooool8o`000003ooooool0003o000000;ooooo0_l0000jooooo`;o00000_ooool2
o`0003cooooo000Looooo`03o`000?oooooooooo03oooooo0ol0000:ooooo`Co00001?ooool2o`00
00;ooooo1?l00004ooooo`;o000000?oooooo`000?l000007?ooool3o`0000Cooooo0_l00006oooo
o`;o00002_ooool3o`0000_ooooo0_l0000=ooooo`go00001Oooool2o`0003[ooooo0_l00002oooo
o`;o0000??ooool001cooooo00?o0000ooooooooool0?oooool5o`0000Cooooo0_l00003ooooo`?o
00001Oooool2o`0004;ooooo0_l000000ooooooo0000o`00000Kooooo`go0000AOooool2o`0003co
oooo000Looooo`03o`000?oooooooooo047ooooo0ol00004ooooo`Co000000?oooooo`000?l00000
1Oooool3o`00037ooooo0ol0000>ooooo`;o00001Oooool3o`0000;ooooo0_l0000Booooo`[o0000
00Coooooo`000?l0003o00000_ooool2o`000003ooooool0003o000003cooooo0ol0000looooo`00
7?ooool00ol0003oooooooooo`10ooooo`Oo000000?oooooo`000?l000000_l00008ooooo`;o0000
<_ooool3o`0001Gooooo0ol000001?oooooo0000o`000?l0000@ooooo`go000000?oooooo`000?l0
00000_ooool2o`000003ooooool0003o000003cooooo0_l0000mooooo`007?ooool00ol0003ooooo
ooooo`10ooooo`Oo00002_ooool4o`0002?ooooo1_l000001?oooooo0000o`000?ooool2o`0000co
oooo0_l0000>ooooo`;o00000_ooool3o`00013ooooo2?l000000ooooooo0000o`000005o`0000;o
oooo0_l0001nooooo`007?ooool00ol0003oooooooooo`12ooooo`Go00002Oooool5o`0001oooooo
2_l000001?oooooo0000o`000?ooool6o`0000Sooooo0_l00004ooooo`;o00001Oooool2o`000003
ooooool0003o000000;ooooo0_l0000Aooooo`_o00000_ooool2o`0000?ooooo1ol0000dooooo`;o
00000oooool2o`0003kooooo000Looooo`03o`000?oooooooooo04;ooooo0_l000001?oooooo0000
o`000?l00008ooooo`?o00007oooool9o`000003ooooool0003o000000Gooooo1ol0000<ooooo`;o
00001Oooool2o`000004ooooool0003o0000ooooo`?o00003ooooolDo`000003ooooool0003o0000
00Co0000=?ooool2o`0000?ooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`14ooooo`Co
00002Oooool2o`0001_ooooo2Ol00004ooooo`Oo00001Oooool5o`0000Cooooo0_l0000>ooooo`;o
000000?oooooo`000?l000004?ooool3o`000003ooooool0003o000000ko000000?oooooo`000?l0
00000ol0000eooooo`;o0000@oooool001cooooo00?o0000ooooooooool0A?ooool4o`0002Kooooo
1Ol00008ooooo`;o000000?oooooo`000?l000000_l00005ooooo`Go00001?ooool2o`000003oooo
ool0003o000000;o00002Oooool2o`0001;ooooo4ol00003ooooo`Co0000>?ooool2o`00047ooooo
000Looooo`03o`000?oooooooooo04Cooooo1?l00005ooooo`;o00007_ooool5o`0000Wooooo0_l0
000<ooooo`;o00002?ooool4o`000003ooooool0003o000001Sooooo5Ol00005ooooo`;o0000;_oo
ool2o`0000Oooooo0ol00011ooooo`007?ooool00ol0003oooooooooo`16ooooo`Wo00007Oooool6
o`0000Oooooo0ol00006ooooo`?o00001oooool3o`0000Wooooo0_l00007ooooo`;o00003ooooolE
o`0003Gooooo0_l00007ooooo`;o0000@_ooool001cooooo0_l00017ooooo`Wo00007?ooool7o`00
00Oooooo0ol00006ooooo`?o00000oooool2o`0000;ooooo0ol0000Booooo`;o00003ooooolEo`00
03?ooooo0_l00003ooooo`;o00000_ooool2o`0004Cooooo000Looooo`03o`000?oooooooooo04Oo
oooo1ol0000Looooo`Go00005?ooool7o`0000Cooooo0_l00004ooooo`;o00000_ooool2o`0000So
oooo0_l0000>oooooaGo0000<oooool2o`000003ooooool0003o000000;o000000Coooooo`000?l0
003o0000A?ooool001cooooo00?o0000ooooooooool0B_ooool3o`0001gooooo0_l00002ooooo`Co
00004?ooool7o`000003ooooool0003o000000;ooooo0ol00003ooooo`?o000000?oooooo`000?l0
00002?ooool2o`0000cooooo5_l0000dooooo`;o000000?oooooo`000?l000000_l000000ooooooo
0000o`000015ooooo`007?ooool00ol0003oooooooooo`1^ooooo`Co00003_ooool=o`000004oooo
ool0003o0000o`0000Cooooo0ol0000GoooooaOo0000=?ooool2o`0000;ooooo0_l00019ooooo`00
7?ooool00ol0003oooooooooo`1Yooooo`?o00000_ooool2o`0000;ooooo0_l00004ooooo`;o0000
1OoooolBo`0000Gooooo0_l0000GoooooaWo00009oooool3o`0000cooooo0_l00019ooooo`007?oo
ool00ol0003oooooooooo`1Yooooo`?o00000_ooool2o`000004ooooool0003o0000o`0000Cooooo
0_l00004oooooa3o000000?oooooo`000?l000003Oooool2o`0000oooooo6Ol0000Vooooo`Co0000
1?ooool2o`0000Sooooo0ol00016ooooo`007?ooool00ol0003oooooooooo`1Yooooo`?o00000_oo
ool2o`000003ooooool0003o000000[ooooo4Ol000001?oooooo0000o`000?l0000<ooooo`;o0000
00?oooooo`000?l000003?oooolGo`0002Sooooo0ol00005ooooo`;o00002?ooool3o`0004Kooooo
000Looooo`03o`000?oooooooooo06Wooooo0_l00003ooooo`;o00001?ooool2o`000003ooooool0
003o000000Cooooo5Ol0000?ooooo`;o00003?oooolGo`0002?ooooo0_l00003ooooo`;o00001_oo
ool2o`00057ooooo000Looooo`03o`000?oooooooooo06Wooooo0ol00006ooooo`Co000000?ooooo
o`000?l000000ooooolFo`0001gooooo5_l0000Tooooo`;o00002Oooool2o`0005?ooooo000Loooo
o`03o`000?oooooooooo06[ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l00006oooo
oaGo00007_ooool2o`000003ooooool0003o000000Go000000?oooooo`000?l000002_l0000^oooo
o`?o0000D_ooool001cooooo00?o0000ooooooooool0JOooool3o`0000?ooooo0_l00003ooooo`;o
00001OoooolCo`000003ooooool0003o000001kooooo0_l000000ooooooo0000o`00000Bo`0002_o
oooo0_l000001?oooooo0000o`000?l0001Booooo`007?ooool00ol0003oooooooooo`1Yooooo`?o
00000oooool2o`0000Cooooo0_l00003oooooaOo00007_ooool2o`0000;ooooo4_l0000Wooooo`;o
00000oooool2o`000003ooooool0003o000000Gooooo0ol0001;ooooo`007?ooool00ol0003ooooo
ooooo`1Zooooo`;o00000oooool2o`0000Cooooo0ol000000ooooooo0000o`00000Fo`0002;ooooo
4_l0000Wooooo`;o00000_ooool2o`0000Wooooo0ol0001;ooooo`007?ooool00ol0003ooooooooo
o`1Zooooo`;o00002_ooool2o`000003ooooool0003o000001Go00003Oooool2o`00013ooooo5Ol0
000/ooooo`;o000000Coooooo`000?l0003o00001?ooool4o`0004_ooooo000Looooo`03o`000?oo
oooooooo06[ooooo0_l0000=oooooaOo00003Oooool2o`00013ooooo3ol000000ooooooo0000o`00
0003o`0001cooooo0ol00002ooooo`;o00002Oooool2o`000004ooooool0003o0000o`0000;ooooo
1?l0001=ooooo`007?ooool00ol0003oooooooooo`1Zooooo`;o00003OoooolGo`0001oooooo0ol0
00000ooooooo0000o`00000>o`0000Sooooo0_l00002ooooo`;o00000_ooool2o`0000Gooooo0_l0
00001?oooooo0000o`000?ooool3o`0000;ooooo0_l00009ooooo`;o00000_ooool2o`0000;ooooo
0ol0001>ooooo`007?ooool2o`0006_ooooo1?l0000;oooooaKo00008Oooool3o`000005ooooool0
003o0000o`000?ooool02ol00008ooooo`?o000000?oooooo`000?l000000_ooool2o`0000Gooooo
0_l000000ooooooo0000o`000003o`0000Kooooo0_l00006ooooo`;o00000_ooool2o`0000?ooooo
0_l0001>ooooo`007?ooool00ol0003oooooooooo`1Zooooo`Co00002OoooolHo`0000cooooo0_l0
000Cooooo`Co000000?oooooo`000?l000002_l00007ooooo`;o00000_ooool2o`0000;ooooo0_l0
0007ooooo`?o00000_ooool4o`0000Kooooo0ol00005ooooo`?o000000?oooooo`000?l00000Dooo
ool001cooooo00?o0000ooooooooool0J_ooool2o`0000_ooooo5Ol0000>ooooo`?o00005Oooool>
o`0000?ooooo0ol00002ooooo`;o00001?ooool4o`0000Gooooo1?l00007ooooo`;o00001Oooool2
o`0000Cooooo1?l000000ooooooo0000o`00001Cooooo`007?ooool00ol0003oooooooooo`1]oooo
o`;o00002_oooolAo`00013ooooo0_l0000Fooooo`Co000000?oooooo`000?l000001ol00002oooo
o`Co00002?ooool2o`000004ooooool0003o0000o`0000?ooooo0_l00003ooooo`;o00000_ooool4
o`0000?ooooo0_l00002ooooo`Ko0000F?ooool001cooooo00?o0000ooooooooool0Joooool7o`00
00Sooooo4?l0000=ooooo`;o00006oooool2o`0000;ooooo1?l00006ooooo`Co00002oooool3o`00
00?ooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002oooo
o`Co0000F_ooool001cooooo00?o0000ooooooooool0Joooool8o`000003ooooool0003o000000;o
oooo1?l000000ooooooo0000o`00000:o`0000kooooo0_l0000Kooooo`?o00000_ooool5o`0000?o
oooo0_l00002ooooo`;o00002oooool2o`0000cooooo0_l00002ooooo`;o00001?ooool2o`0000;o
oooo0_l00002ooooo`;o0000EOooool001cooooo00?o0000ooooooooool0K?ooool2o`0000?ooooo
0_l000000ooooooo0000o`000002ooooo`Wo000000?oooooo`000?l000001?l0000?ooooo`?o0000
6_ooool5o`0000?ooooo0_l00003ooooo`;o00000_ooool2o`0000Gooooo0_l00008ooooo`;o0000
1?ooool2o`0000;ooooo0_l00008ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0005Go
oooo000Looooo`03o`000?oooooooooo07[ooooo0ol000000ooooooo0000o`000008o`0000gooooo
0_l000000ooooooo0000o`00000Kooooo`Co00004oooool2o`0000Sooooo0_l00004ooooo`;o0000
3_ooool4o`000003ooooool0003o000005Kooooo000Looooo`03o`000?oooooooooo073ooooo0_l0
0007ooooo`Co00000_ooool7o`0000kooooo0ol0000Oooooo`Go00000oooool2o`0000Sooooo0_l0
0002ooooo`;o00001?ooool2o`0000;ooooo0_l0000:ooooo`Ko000000Coooooo`000?l0003ooooo
0_l000000ooooooo0000o`000002o`0005Kooooo000Looooo`03o`000?oooooooooo06gooooo0_l0
00000ooooooo0000o`000007ooooo`Go000000?oooooo`000?l000000ol0000@ooooo`Go00007_oo
ool6o`000003ooooool0003o000000Sooooo0_l00008ooooo`;o00003_ooool6o`000003ooooool0
003o000000Cooooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`1]ooooo`;o00003?ooool4
o`0000?ooooo0_l0000Cooooo`;o00007oooool7o`0000cooooo0_l00007ooooo`;o00001oooool2
o`000004ooooool0003o0000o`0000;ooooo1?l00002ooooo`;o0000G?ooool001cooooo00?o0000
ooooooooool0KOooool2o`0000;ooooo0_l00002ooooo`;o00001?ooool4o`0001?ooooo0_l0000V
ooooo`So000000?oooooo`000?l000000oooool2o`000003ooooool0003o000000?o00001?ooool2
o`0000?ooooo2_l00002ooooo`So0000G?ooool001cooooo00?o0000ooooooooool0KOooool2o`00
00;ooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000001?ooooo1?l0000Voooo
o`Wo00000oooool8o`0000Wooooo1?l000000ooooooo0000o`000007ooooo`Co0000G_ooool001co
oooo00?o0000ooooooooool0MOooool2o`0000?ooooo0_l00002ooooo`?o00003Oooool3o`000003
ooooool0003o000000;o0000:?ooool8o`0000;ooooo2Ol0000Dooooo`Go0000Goooool001cooooo
00?o0000ooooooooool0LOooool2o`000003ooooool0003o000000;o00000oooool2o`000003oooo
ool0003o000000?o00002oooool6o`0002[ooooo2_l00007ooooo`;o00004Oooool2o`000003oooo
ool0003o000000?o0000Goooool001cooooo00?o0000ooooooooool0LOooool2o`000003ooooool0
003o000000?o00000_ooool3o`000003ooooool0003o000000Co00001oooool6o`0002oooooo2_l0
000?ooooo`;o00001_ooool3o`0006Cooooo000Looooo`;o0000L_ooool2o`0000Cooooo0_l00003
ooooo`Ko000000?oooooo`000?l000000ol00002ooooo`Ko0000<oooool=o`0000Wooooo0ol00007
ooooo`;o0000I?ooool001cooooo00?o0000ooooooooool0L?ooool3o`0000?ooooo0ol00004oooo
o`Co00001?ooool8o`0000;ooooo0_l0000cooooo`go00001_ooool5o`0000;ooooo0_l0001Yoooo
o`007?ooool00ol0003oooooooooo`1`ooooo`?o00000oooool2o`0000Kooooo0ol00003ooooo`Oo
000000Coooooo`000?l0003ooooo0_l0000fooooo`[o00001_ooool2o`000003ooooool0003o0000
00;ooooo0_l0001Yooooo`007?ooool00ol0003oooooooooo`1booooo`;o00004?ooool7o`000003
ooooool0003o000003_ooooo2ol00003ooooo`;o0000L?ooool001cooooo00?o0000ooooooooool0
L_ooool2o`0001;ooooo1Ol000000ooooooo0000o`00000mooooo`Wo00000oooool2o`00073ooooo
000Looooo`03o`000?oooooooooo07?ooooo1?l0000?ooooo`;o000000?oooooo`000?l00000@_oo
ool<o`00073ooooo000Looooo`03o`000?oooooooooo07?ooooo1ol0001Iooooo`Go0000LOooool0
01cooooo00?o0000ooooooooool0Moooool4o`000<kooooo000Looooo`03o`000?oooooooooo07Wo
oooo0_l0003>ooooo`007?ooool00ol0003oooooooooo`1fooooo`;o00001oooool2o`000<Sooooo
000Looooo`03o`000?oooooooooo07Kooooo0_l00006ooooo`?o0000b?ooool001cooooo00?o0000
ooooooooool0M_ooool2o`0000Kooooo0_l00039ooooo`007?ooool00ol0003oooooooooo`21oooo
o`;o0000a_ooool001cooooo00?o0000ooooooooool0O?ooool2o`0000;ooooo0ol00036ooooo`00
00Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0O?ooool2o`0000;ooooo1Ol00034ooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo
00?o0000ooooooooool0O?ooool2o`000003ooooool0003o000000Co0000a?ooool00003ooooool@
413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0O?ooool5o`000<Sooooo00000ooooooo0000ooooo`02ooooo`03o`000?oo
oooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000OOooool3o`0000;ooooo
0_l00035ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05olc<c?l0
003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`1nooooo`;o00000_ooool2o`0000Cooooo
0_l0002oooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj
^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`25ooooo`;o000000?oooooo`000?l00000
0_ooool2o`000;_ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oo
oooo^[Zjo`000006ooooo`03o`000?oooooooooo08Gooooo1?l00003ooooo`;o0000^oooool00006
ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o
0000ooooooooool0Poooool6o`0000?ooooo0_l000000ooooooo0000o`00002hooooo`007?ooool0
0ol0003oooooooooo`23ooooo`;o00002_ooool4o`000;Kooooo000Looooo`03o`000?oooooooooo
08cooooo0_l00003ooooo`?o0000]Oooool001cooooo00?o0000ooooooooool0S?ooool4o`0000;o
oooo0_l000000ooooooo0000o`00002booooo`007?ooool00ol0003oooooooooo`2;ooooo`;o0000
00?oooooo`000?l000001Oooool2o`000;;ooooo000Looooo`03o`000?oooooooooo08_ooooo0_l0
002looooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Booooo`Co000000?o410@ooooooooool00oooool00ol0003o
ooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`?o0000oooooom:ooooo`005?ooool0
0ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Co
oooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo
000Booooo`03oeEEEOmVIVKo00000?ooooooE?ooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00:Gooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0Fooooo`Co
000000Go410@ooooooooooooooooodA4A002o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`00
0?l@413oc<c<093ooooo002Vooooo`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo
00?o0000ooooooooool01_ooool02OmgMgOo<S8booooooooooooEEEEogMgMoooooooV9RHob4Q8@2@
ooooo`00Y_ooool01Ol0003ooooooooooooooooo000001_ooooo00?o0000ooooooooool01oooool0
1?l0003oooooooooool00003ooooo`03o`000?oooooooooo08kooooo002Vooooo`05o`000?oooooo
ooooooooool000002Oooool6o`0000cooooo00?o0000ooooooooool01_ooool02OmgMgOo<S8boooo
oooooooo0000oiRHV?ooooooV9RHob4Q8@2@ooooo`00Y_ooool01Ol0003oQhN7oooooonYZJWo0000
01_ooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000
oeEEEOl0003o410@olc<c02@ooooo`00YOooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooo
oooo01Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03oeEEEOn7QhOo
oooo09;ooooo0036ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ooM
gMgo410@oiRHV02Booooo`00a?ooool00omEEEGoIVIVo`000005ooooo`Co00001?ooool01?o<c<co
A4A4o`000?l@412@ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(162) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.3139 .52633 Mdot
.31244 .49761 Mdot
.54417 .69801 Mdot
.51047 .40272 Mdot
.75964 .47923 Mdot
.54219 .6819 Mdot
.39354 .68857 Mdot
.37344 .68384 Mdot
.58681 .68226 Mdot
.44539 .42644 Mdot
.40979 .65665 Mdot
.45461 .34595 Mdot
.38552 .68213 Mdot
.51705 .36725 Mdot
.61499 .3959 Mdot
.4202 .28681 Mdot
.29456 .47986 Mdot
.71788 .47959 Mdot
.4277 .28686 Mdot
.59119 .67796 Mdot
.78443 .51146 Mdot
.50023 .3655 Mdot
.27159 .51209 Mdot
.51757 .36892 Mdot
.41925 .28137 Mdot
.31466 .50494 Mdot
.32116 .52194 Mdot
.41983 .26671 Mdot
.46581 .36631 Mdot
.41047 .6502 Mdot
.42073 .25685 Mdot
.69294 .39013 Mdot
.60251 .54643 Mdot
.36937 .40086 Mdot
.36381 .67141 Mdot
.35069 .70134 Mdot
.57004 .68983 Mdot
.3844 .65238 Mdot
.41749 .68784 Mdot
.38676 .65774 Mdot
.38322 .65766 Mdot
.30732 .50786 Mdot
.36269 .6685 Mdot
.35641 .77326 Mdot
.52504 .38332 Mdot
.33923 .2874 Mdot
.59985 .62349 Mdot
.48968 .39819 Mdot
.26865 .50588 Mdot
.52461 .71223 Mdot
.65706 .43852 Mdot
.38098 .66678 Mdot
.61444 .52745 Mdot
.31408 .26201 Mdot
.38138 .68776 Mdot
.42312 .28374 Mdot
.54862 .66 Mdot
.50685 .3876 Mdot
.49551 .40508 Mdot
.36334 .37822 Mdot
.49467 .38571 Mdot
.76 .49037 Mdot
.28183 .43931 Mdot
.53127 .69944 Mdot
.5729 .70293 Mdot
.37531 .6541 Mdot
.31728 .47034 Mdot
.37393 .70032 Mdot
.50654 .40286 Mdot
.59746 .65216 Mdot
.46738 .34711 Mdot
.4088 .65604 Mdot
.33257 .47911 Mdot
.49393 .3534 Mdot
.29562 .53297 Mdot
.42622 .68994 Mdot
.73829 .47484 Mdot
.25572 .51076 Mdot
.52046 .69501 Mdot
.54736 .32615 Mdot
.49295 .35878 Mdot
.20777 .62019 Mdot
.61952 .32855 Mdot
.32961 .50477 Mdot
.50442 .34074 Mdot
.18689 .57379 Mdot
.49712 .32901 Mdot
.41016 .26048 Mdot
.41796 .27126 Mdot
.57503 .40773 Mdot
.55278 .65159 Mdot
.27715 .51061 Mdot
.50609 .37181 Mdot
.52838 .40777 Mdot
.43213 .42051 Mdot
.47118 .36294 Mdot
.41926 .27647 Mdot
.63558 .5432 Mdot
.39879 .65976 Mdot
.63147 .52401 Mdot
.41798 .62447 Mdot
.62404 .53866 Mdot
.47487 .33371 Mdot
.56029 .68086 Mdot
.34212 .49861 Mdot
.6194 .54745 Mdot
.36203 .69372 Mdot
.50972 .37101 Mdot
.353 .71357 Mdot
.27476 .51389 Mdot
.43189 .26698 Mdot
.73772 .49601 Mdot
.68559 .53942 Mdot
.32673 .47729 Mdot
.38739 .29584 Mdot
.53312 .397 Mdot
.48858 .36703 Mdot
.31001 .50086 Mdot
.59038 .68455 Mdot
.46537 .69455 Mdot
.29072 .49296 Mdot
.4036 .65866 Mdot
.29298 .4795 Mdot
.60649 .5513 Mdot
.58553 .69118 Mdot
.60409 .50479 Mdot
.6437 .53492 Mdot
.68688 .40809 Mdot
.48177 .38619 Mdot
.64321 .54899 Mdot
.56631 .6802 Mdot
.29343 .49389 Mdot
.38744 .67384 Mdot
.54351 .40499 Mdot
.32267 .50775 Mdot
.38459 .69259 Mdot
.70669 .50436 Mdot
.70333 .50682 Mdot
.3317 .48888 Mdot
.39001 .30542 Mdot
.36105 .66465 Mdot
.39269 .702 Mdot
.65402 .43799 Mdot
.33241 .4978 Mdot
.75154 .51171 Mdot
.386 .6993 Mdot
.63432 .728 Mdot
.43406 .27419 Mdot
.69713 .42286 Mdot
.2167 .62222 Mdot
.65478 .4387 Mdot
.76885 .5201 Mdot
.75596 .49745 Mdot
.3835 .69273 Mdot
.53848 .38091 Mdot
.31859 .48333 Mdot
.32351 .50449 Mdot
.46148 .34276 Mdot
.60916 .54604 Mdot
.52897 .39462 Mdot
.6351 .52573 Mdot
.64579 .53286 Mdot
.51457 .37303 Mdot
.3446 .31212 Mdot
.30817 .5213 Mdot
.52274 .34932 Mdot
.57733 .68344 Mdot
.64903 .55576 Mdot
.35679 .67176 Mdot
.50922 .34429 Mdot
.53336 .35721 Mdot
.45178 .33259 Mdot
.39314 .70248 Mdot
.31384 .64485 Mdot
.52076 .67669 Mdot
.42169 .66533 Mdot
.42577 .62803 Mdot
.57133 .66331 Mdot
.50449 .40934 Mdot
.73772 .50029 Mdot
.60897 .51605 Mdot
.53056 .36652 Mdot
.65791 .43973 Mdot
.52042 .41609 Mdot
.70853 .53117 Mdot
.71522 .52875 Mdot
.20679 .60319 Mdot
.32087 .62142 Mdot
.53176 .40272 Mdot
.39948 .26187 Mdot
.67608 .43125 Mdot
.42529 .73002 Mdot
.39278 .6717 Mdot
.60362 .63963 Mdot
.59558 .67529 Mdot
.55635 .7487 Mdot
.42076 .34853 Mdot
.44546 .33888 Mdot
.48205 .36345 Mdot
.62346 .5276 Mdot
.29177 .43796 Mdot
.75738 .49699 Mdot
.31144 .47714 Mdot
.20973 .62229 Mdot
.55877 .30469 Mdot
.44383 .28452 Mdot
.60605 .77153 Mdot
.53314 .71131 Mdot
.61632 .54255 Mdot
.74006 .50934 Mdot
.51257 .39384 Mdot
.29113 .52448 Mdot
.66644 .43433 Mdot
.59306 .53262 Mdot
.82777 .41236 Mdot
.29082 .48737 Mdot
.59268 .31368 Mdot
.38514 .68755 Mdot
.56964 .64943 Mdot
.49747 .32919 Mdot
.50936 .35826 Mdot
.27218 .4837 Mdot
.5401 .40332 Mdot
.43359 .25855 Mdot
.42987 .27296 Mdot
.52487 .71469 Mdot
.39386 .6154 Mdot
.42072 .67314 Mdot
.59754 .61729 Mdot
.32977 .4788 Mdot
.33232 .29107 Mdot
.5567 .67041 Mdot
.7486 .52772 Mdot
.40331 .65268 Mdot
.71059 .5078 Mdot
.55417 .67617 Mdot
.76047 .48002 Mdot
.50162 .40898 Mdot
.58127 .66124 Mdot
.74109 .48944 Mdot
.5671 .42551 Mdot
.62291 .5458 Mdot
.7854 .47453 Mdot
.3975 .68952 Mdot
.27365 .48886 Mdot
.53096 .36643 Mdot
.61366 .52172 Mdot
.59083 .52208 Mdot
.59437 .38172 Mdot
.63498 .5087 Mdot
.59723 .53573 Mdot
.58239 .39673 Mdot
.70908 .48537 Mdot
.28348 .58572 Mdot
.42371 .25776 Mdot
.29841 .47779 Mdot
.53492 .40453 Mdot
.36213 .61149 Mdot
.38537 .69373 Mdot
.50677 .39288 Mdot
.2005 .60787 Mdot
.40154 .68925 Mdot
.50186 .37938 Mdot
.42432 .67692 Mdot
.32585 .50689 Mdot
.56093 .30036 Mdot
.33559 .48235 Mdot
.51458 .37546 Mdot
.42618 .67234 Mdot
.60139 .63638 Mdot
.31701 .50409 Mdot
.50491 .36908 Mdot
.48344 .37924 Mdot
.62082 .52705 Mdot
.43144 .27389 Mdot
.43429 .64363 Mdot
.45551 .34488 Mdot
.53169 .6753 Mdot
.46606 .35966 Mdot
.69865 .50923 Mdot
.66944 .72532 Mdot
.3333 .49589 Mdot
.63344 .50662 Mdot
.54806 .67134 Mdot
.55371 .44213 Mdot
.58008 .30113 Mdot
.52468 .3792 Mdot
.59706 .52552 Mdot
.61183 .30782 Mdot
.4116 .67677 Mdot
.43487 .26401 Mdot
.66308 .53518 Mdot
.54539 .66256 Mdot
.62422 .53607 Mdot
.4776 .34253 Mdot
.27482 .51853 Mdot
.42111 .28531 Mdot
.5722 .65681 Mdot
.28504 .48784 Mdot
.48491 .33066 Mdot
.42956 .63306 Mdot
.65427 .51824 Mdot
.41193 .67335 Mdot
.41789 .26175 Mdot
.50565 .40961 Mdot
.59609 .65397 Mdot
.30496 .50962 Mdot
.37737 .68656 Mdot
.33376 .48284 Mdot
.59443 .44359 Mdot
.59841 .31771 Mdot
.33748 .47449 Mdot
.70843 .49445 Mdot
.6402 .7856 Mdot
.4126 .66081 Mdot
.62262 .51142 Mdot
.58495 .62684 Mdot
.27054 .51998 Mdot
.55346 .68157 Mdot
.39342 .31808 Mdot
.55269 .65259 Mdot
.43224 .28893 Mdot
.59472 .63605 Mdot
.44086 .33266 Mdot
.51939 .35043 Mdot
.55289 .71515 Mdot
.63366 .54556 Mdot
.48646 .34417 Mdot
.32048 .5095 Mdot
.68812 .38129 Mdot
.40427 .38682 Mdot
.42181 .34543 Mdot
.54992 .66068 Mdot
.38801 .31555 Mdot
.42813 .26749 Mdot
.41753 .26397 Mdot
.31459 .48542 Mdot
.61936 .51141 Mdot
.71973 .51987 Mdot
.74423 .51948 Mdot
.72787 .69277 Mdot
.59462 .27289 Mdot
.38684 .28928 Mdot
.32523 .49949 Mdot
.58841 .76722 Mdot
.32586 .52302 Mdot
.59379 .5332 Mdot
.37318 .68353 Mdot
.31299 .6592 Mdot
.48959 .32682 Mdot
.67698 .5086 Mdot
.4356 .25867 Mdot
.27366 .49322 Mdot
.32351 .46657 Mdot
.37616 .68618 Mdot
.41969 .33987 Mdot
.44524 .42511 Mdot
.52175 .39855 Mdot
.37137 .68628 Mdot
.59093 .52651 Mdot
.55794 .41383 Mdot
.70118 .40388 Mdot
.38592 .80294 Mdot
.52139 .3797 Mdot
.37905 .45888 Mdot
.5261 .36114 Mdot
.68435 .41359 Mdot
.51476 .3914 Mdot
.30842 .511 Mdot
.39978 .22448 Mdot
.55681 .39234 Mdot
.61128 .77214 Mdot
.55824 .30784 Mdot
.73535 .48271 Mdot
.51042 .3643 Mdot
.53207 .38817 Mdot
.73961 .51575 Mdot
.2887 .51371 Mdot
.49905 .40192 Mdot
.29127 .58601 Mdot
.50155 .36989 Mdot
.35485 .67576 Mdot
.61643 .35931 Mdot
.68986 .39172 Mdot
.42682 .27038 Mdot
.27342 .51725 Mdot
.40416 .69619 Mdot
.37789 .65707 Mdot
.6234 .50473 Mdot
.38577 .69415 Mdot
.52079 .35477 Mdot
.616 .36061 Mdot
.32247 .47075 Mdot
.61793 .54533 Mdot
.27908 .50683 Mdot
.61199 .681 Mdot
.39857 .68617 Mdot
.61544 .5354 Mdot
.41578 .3634 Mdot
.40315 .67691 Mdot
.45039 .64061 Mdot
.43091 .2643 Mdot
.59101 .52473 Mdot
.30799 .52771 Mdot
.59732 .64756 Mdot
.5951 .52848 Mdot
.38084 .68816 Mdot
.52561 .38264 Mdot
.42701 .28218 Mdot
.38372 .69447 Mdot
.36764 .50766 Mdot
.42787 .25782 Mdot
.50038 .37135 Mdot
.30942 .51758 Mdot
.29201 .50063 Mdot
.52569 .35216 Mdot
.53939 .39755 Mdot
.53861 .67594 Mdot
.59692 .52084 Mdot
.59727 .51718 Mdot
.64482 .52545 Mdot
.5587 .65212 Mdot
.62708 .78548 Mdot
.37266 .70222 Mdot
.68838 .39073 Mdot
.32851 .61897 Mdot
.61065 .52463 Mdot
.53797 .6796 Mdot
.52719 .3702 Mdot
.46359 .33357 Mdot
.42732 .67047 Mdot
.71171 .75782 Mdot
.47968 .32478 Mdot
.31088 .47313 Mdot
.3708 .67564 Mdot
.44929 .33891 Mdot
.55228 .74511 Mdot
.75152 .48299 Mdot
.38535 .28847 Mdot
.37274 .67428 Mdot
.3415 .54221 Mdot
.37355 .67344 Mdot
.53166 .38616 Mdot
.47673 .34731 Mdot
.27809 .48219 Mdot
.73374 .4827 Mdot
.45765 .34475 Mdot
.5076 .3813 Mdot
.5963 .77183 Mdot
.33573 .51505 Mdot
.74241 .52013 Mdot
.46684 .3719 Mdot
.63638 .53941 Mdot
.74179 .47824 Mdot
.48801 .35644 Mdot
.46423 .35369 Mdot
.62735 .55607 Mdot
.42623 .66067 Mdot
.71552 .49021 Mdot
.61285 .77338 Mdot
.29505 .48324 Mdot
.43958 .65485 Mdot
.6112 .49885 Mdot
.41103 .65982 Mdot
.5019 .42672 Mdot
.61683 .53945 Mdot
.32284 .72391 Mdot
.727 .22953 Mdot
.59976 .53481 Mdot
.53504 .67333 Mdot
.42608 .41697 Mdot
.46169 .34997 Mdot
.50065 .3721 Mdot
.70717 .5179 Mdot
.30207 .49865 Mdot
.32094 .62191 Mdot
.42351 .66826 Mdot
.5121 .35598 Mdot
.33537 .49159 Mdot
.19847 .59498 Mdot
.62217 .53316 Mdot
.72723 .49337 Mdot
.7123 .50102 Mdot
.49283 .34972 Mdot
.60466 .29166 Mdot
.31809 .5048 Mdot
.50538 .36921 Mdot
.48625 .35028 Mdot
.58209 .63258 Mdot
.32332 .51371 Mdot
.57998 .66196 Mdot
.44282 .28315 Mdot
.394 .28088 Mdot
.35649 .61228 Mdot
.39712 .6934 Mdot
.60637 .50636 Mdot
.4201 .67294 Mdot
.53988 .64824 Mdot
.59756 .51726 Mdot
.50534 .36854 Mdot
.32229 .47048 Mdot
.50591 .3699 Mdot
.50257 .37051 Mdot
.52411 .39015 Mdot
.38434 .28338 Mdot
.52185 .68962 Mdot
.72764 .49875 Mdot
.48013 .39158 Mdot
.56538 .65519 Mdot
.57116 .75463 Mdot
.44463 .42707 Mdot
.50363 .36067 Mdot
.49144 .37087 Mdot
.25545 .51849 Mdot
.43563 .27556 Mdot
.40043 .67693 Mdot
.27685 .48335 Mdot
.50256 .33097 Mdot
.59835 .62027 Mdot
.50428 .40485 Mdot
.33751 .47539 Mdot
.36444 .69894 Mdot
.2816 .43128 Mdot
.60024 .50103 Mdot
.60956 .50325 Mdot
.59649 .53132 Mdot
.64294 .51918 Mdot
.35696 .67323 Mdot
.53753 .68311 Mdot
.60701 .61765 Mdot
.4576 .31094 Mdot
.54062 .39789 Mdot
.47759 .34524 Mdot
.58622 .62952 Mdot
.61933 .55317 Mdot
.40466 .34213 Mdot
.44801 .28024 Mdot
.57855 .64597 Mdot
.63938 .54043 Mdot
.20538 .50652 Mdot
.27471 .50259 Mdot
.52278 .67403 Mdot
.39107 .65166 Mdot
.7416 .48733 Mdot
.79975 .63283 Mdot
.28266 .50152 Mdot
.30089 .43592 Mdot
.57485 .67897 Mdot
.60438 .37369 Mdot
.31196 .25347 Mdot
.55013 .68411 Mdot
.42753 .25497 Mdot
.32317 .48824 Mdot
.63046 .54401 Mdot
.61241 .31233 Mdot
.60903 .36379 Mdot
.59003 .66671 Mdot
.4836 .38069 Mdot
.57512 .70927 Mdot
.53974 .66653 Mdot
.60893 .50837 Mdot
.55076 .66053 Mdot
.4126 .67964 Mdot
.56752 .67498 Mdot
.36449 .51333 Mdot
.49428 .39564 Mdot
.31343 .26119 Mdot
.63692 .37971 Mdot
.53446 .39766 Mdot
.40024 .66747 Mdot
.43569 .6402 Mdot
.50488 .39601 Mdot
.76996 .49352 Mdot
.53497 .67651 Mdot
.54182 .73771 Mdot
.43232 .28443 Mdot
.59357 .63674 Mdot
.27535 .51986 Mdot
.41646 .62327 Mdot
.42291 .62638 Mdot
.59568 .52813 Mdot
.32907 .50276 Mdot
.42703 .69013 Mdot
.40272 .6588 Mdot
.65684 .52657 Mdot
.52973 .36124 Mdot
.29678 .5221 Mdot
.56355 .41208 Mdot
.66541 .5394 Mdot
.50039 .36859 Mdot
.57857 .66364 Mdot
.52264 .70851 Mdot
.6251 .38933 Mdot
.55597 .66839 Mdot
.61177 .50671 Mdot
.30779 .52005 Mdot
.42998 .28626 Mdot
.29135 .49646 Mdot
.53267 .40697 Mdot
.37822 .61289 Mdot
.27322 .50549 Mdot
.74781 .52779 Mdot
.49401 .38291 Mdot
.3441 .30759 Mdot
.47234 .38201 Mdot
.49937 .37033 Mdot
.57713 .70077 Mdot
.74161 .51484 Mdot
.68243 .51676 Mdot
.56024 .74775 Mdot
.76493 .49275 Mdot
.35096 .46506 Mdot
.58625 .69134 Mdot
.72188 .51141 Mdot
.73162 .69158 Mdot
.63297 .50549 Mdot
.72282 .50478 Mdot
.50606 .34138 Mdot
.39107 .6966 Mdot
.30371 .46889 Mdot
.48863 .34296 Mdot
.42744 .31703 Mdot
.44045 .30146 Mdot
.61991 .52945 Mdot
.49707 .37136 Mdot
.53343 .38863 Mdot
.33522 .49024 Mdot
.21659 .62469 Mdot
.53024 .68552 Mdot
.62988 .51864 Mdot
.28535 .49749 Mdot
.20685 .61937 Mdot
.56877 .70588 Mdot
.71527 .51345 Mdot
.41777 .68402 Mdot
.32995 .54906 Mdot
.61648 .5263 Mdot
.39545 .68925 Mdot
.53324 .72457 Mdot
.64384 .44144 Mdot
.40797 .27706 Mdot
.56028 .69143 Mdot
.65503 .43895 Mdot
.44165 .27755 Mdot
.56118 .75177 Mdot
.42706 .72835 Mdot
.27517 .51324 Mdot
.38 .69395 Mdot
.72579 .49081 Mdot
.33199 .47574 Mdot
.27873 .50682 Mdot
.39918 .69322 Mdot
.36798 .22416 Mdot
.60998 .30844 Mdot
.40203 .70432 Mdot
.59526 .38571 Mdot
.64765 .43975 Mdot
.61778 .52401 Mdot
.73345 .4995 Mdot
.39375 .61542 Mdot
.30805 .50749 Mdot
.31783 .64507 Mdot
.66049 .43857 Mdot
.43428 .26521 Mdot
.74514 .48756 Mdot
.20275 .59461 Mdot
.37415 .73862 Mdot
.40039 .67983 Mdot
.59556 .7715 Mdot
.76765 .5017 Mdot
.51545 .34649 Mdot
.72985 .74748 Mdot
.51226 .34713 Mdot
.37984 .69965 Mdot
.43564 .25898 Mdot
.30368 .48266 Mdot
.38037 .70262 Mdot
.44477 .2852 Mdot
.45696 .34888 Mdot
.52387 .40199 Mdot
.51985 .69419 Mdot
.27117 .48693 Mdot
.6243 .49672 Mdot
.53564 .39546 Mdot
.5056 .38278 Mdot
.58951 .52747 Mdot
.68932 .39436 Mdot
.49176 .62923 Mdot
.60926 .54867 Mdot
.58369 .65482 Mdot
.61825 .54575 Mdot
.62661 .5161 Mdot
.29323 .52947 Mdot
.58038 .76286 Mdot
.59445 .51147 Mdot
.51677 .37771 Mdot
.50968 .37433 Mdot
.41616 .6894 Mdot
.61173 .30857 Mdot
.60438 .37044 Mdot
.53056 .67916 Mdot
.66238 .52776 Mdot
.47489 .36409 Mdot
.32842 .50532 Mdot
.70601 .51948 Mdot
.62301 .50607 Mdot
.29636 .48087 Mdot
.48053 .38624 Mdot
.58332 .63219 Mdot
.60256 .53607 Mdot
.58767 .52785 Mdot
.74414 .49072 Mdot
.40067 .70197 Mdot
.25743 .5031 Mdot
.53761 .6692 Mdot
.40638 .26798 Mdot
.65278 .50737 Mdot
.57227 .63794 Mdot
.61922 .52338 Mdot
.62806 .54059 Mdot
.32744 .50305 Mdot
.34628 .53874 Mdot
.59152 .54627 Mdot
.55936 .65408 Mdot
.36109 .78602 Mdot
.38411 .66207 Mdot
.49669 .40479 Mdot
.41546 .68261 Mdot
.27537 .51466 Mdot
.68888 .40766 Mdot
.71153 .50576 Mdot
.40379 .67998 Mdot
.59702 .53744 Mdot
.27625 .50624 Mdot
.2671 .48795 Mdot
.51656 .37398 Mdot
.50165 .3642 Mdot
.59965 .6228 Mdot
.6868 .42591 Mdot
.42505 .67867 Mdot
.71909 .51921 Mdot
.53821 .6938 Mdot
.42798 .28352 Mdot
.31817 .48072 Mdot
.79454 .4747 Mdot
.47828 .3905 Mdot
.56182 .65623 Mdot
.31515 .496 Mdot
.74276 .51911 Mdot
.72609 .49941 Mdot
.53414 .37593 Mdot
.76714 .5205 Mdot
.40651 .6826 Mdot
.318 .50977 Mdot
.3399 .44201 Mdot
.48039 .39062 Mdot
.50532 .36339 Mdot
.43674 .26832 Mdot
.39711 .70586 Mdot
.50826 .34269 Mdot
.7283 .48602 Mdot
.32454 .47868 Mdot
.52602 .36466 Mdot
.76613 .50557 Mdot
.63249 .50111 Mdot
.61248 .53972 Mdot
.5586 .71447 Mdot
.77188 .50577 Mdot
.76033 .50965 Mdot
.76919 .50278 Mdot
.31294 .66036 Mdot
.4509 .33924 Mdot
.58963 .49307 Mdot
.48179 .37666 Mdot
.64409 .44029 Mdot
.40407 .26804 Mdot
.39622 .6621 Mdot
.59517 .65484 Mdot
.52442 .39485 Mdot
.48163 .3747 Mdot
.26123 .50687 Mdot
.42333 .28895 Mdot
.52269 .35001 Mdot
.3087 .47959 Mdot
.33084 .43921 Mdot
.60323 .65677 Mdot
.21591 .62112 Mdot
.76949 .71286 Mdot
.53562 .41793 Mdot
.6095 .37132 Mdot
.28493 .51323 Mdot
.41707 .68659 Mdot
.59858 .38251 Mdot
.39619 .70258 Mdot
.29658 .50274 Mdot
.42459 .29136 Mdot
.36854 .50571 Mdot
.75975 .4889 Mdot
.53107 .38592 Mdot
.40304 .69105 Mdot
.53067 .39099 Mdot
.40661 .69089 Mdot
.3843 .32104 Mdot
.61812 .32198 Mdot
.5428 .39715 Mdot
.47071 .36312 Mdot
.78858 .50776 Mdot
.50256 .36218 Mdot
.60633 .77696 Mdot
.31491 .49115 Mdot
.65739 .53824 Mdot
.41758 .29033 Mdot
.40472 .389 Mdot
.49212 .36913 Mdot
.44049 .30468 Mdot
.48673 .36785 Mdot
.7 .76392 Mdot
.51039 .41318 Mdot
.52743 .3584 Mdot
.38845 .6703 Mdot
.40306 .65486 Mdot
.26245 .4965 Mdot
.62495 .54053 Mdot
.20462 .59923 Mdot
.50297 .37894 Mdot
.54423 .7084 Mdot
.65947 .5538 Mdot
.75453 .51312 Mdot
.32045 .47511 Mdot
.71862 .21806 Mdot
.36229 .66814 Mdot
.58355 .67298 Mdot
.42013 .25591 Mdot
.58242 .6573 Mdot
.52911 .69305 Mdot
.34955 .45425 Mdot
.73229 .49898 Mdot
.51445 .40836 Mdot
.36925 .39751 Mdot
.29078 .4336 Mdot
.48064 .39079 Mdot
.59125 .68665 Mdot
.62568 .55626 Mdot
.51681 .24453 Mdot
.72128 .47871 Mdot
.75799 .50475 Mdot
.38638 .68995 Mdot
.54558 .70989 Mdot
.62933 .5193 Mdot
.71645 .50972 Mdot
.60395 .64824 Mdot
.63013 .50526 Mdot
.59065 .77031 Mdot
.31774 .50574 Mdot
.38955 .31625 Mdot
.33632 .28162 Mdot
.41134 .67003 Mdot
.56847 .75513 Mdot
.32598 .47125 Mdot
.33789 .48717 Mdot
.62577 .52477 Mdot
.58244 .64554 Mdot
.34172 .46624 Mdot
.53247 .37395 Mdot
.62084 .5447 Mdot
.50367 .34908 Mdot
.70507 .487 Mdot
.50471 .37629 Mdot
.6011 .64156 Mdot
.39548 .66905 Mdot
.545 .66608 Mdot
.38955 .69072 Mdot
.68871 .38712 Mdot
.49837 .38333 Mdot
.50875 .36518 Mdot
.6153 .36075 Mdot
.29987 .52648 Mdot
.37086 .4039 Mdot
.55747 .65716 Mdot
.54694 .66376 Mdot
.41732 .2899 Mdot
.29635 .47664 Mdot
.58285 .5262 Mdot
.59373 .38791 Mdot
.4859 .36536 Mdot
.31309 .49173 Mdot
.40288 .26662 Mdot
.33722 .75677 Mdot
.61944 .33226 Mdot
.28975 .52781 Mdot
.60985 .78081 Mdot
.48073 .35333 Mdot
.63116 .51606 Mdot
.64716 .54353 Mdot
.60256 .28391 Mdot
.68059 .51665 Mdot
.29118 .48635 Mdot
.63316 .52618 Mdot
.32032 .48215 Mdot
.54863 .65418 Mdot
.35614 .69354 Mdot
.31055 .48478 Mdot
.48829 .37201 Mdot
.77055 .7112 Mdot
.39968 .6958 Mdot
.52849 .37846 Mdot
.37141 .70008 Mdot
.31576 .46412 Mdot
.29836 .49269 Mdot
.62986 .50521 Mdot
.42964 .25677 Mdot
.4058 .68115 Mdot
.5403 .38672 Mdot
.37779 .46994 Mdot
.42107 .28542 Mdot
.65515 .55097 Mdot
.47429 .3654 Mdot
.47229 .37616 Mdot
.61916 .78189 Mdot
.55715 .44257 Mdot
.36471 .61129 Mdot
.35012 .69394 Mdot
.31274 .6447 Mdot
.31527 .52376 Mdot
.69823 .49738 Mdot
.26167 .49508 Mdot
.60312 .50663 Mdot
.58634 .65835 Mdot
.52632 .38857 Mdot
.64013 .51113 Mdot
.40798 .70307 Mdot
.72759 .50668 Mdot
.52048 .41609 Mdot
.55798 .69632 Mdot
.6404 .52451 Mdot
.39913 .68391 Mdot
.30289 .50839 Mdot
.30178 .48068 Mdot
.58216 .76582 Mdot
.52706 .36637 Mdot
.50298 .36616 Mdot
.3594 .68531 Mdot
.74689 .52563 Mdot
.76587 .49224 Mdot
.6334 .54582 Mdot
.35956 .69228 Mdot
.61953 .33114 Mdot
.27433 .4814 Mdot
.53183 .37924 Mdot
.61873 .35695 Mdot
.3158 .63341 Mdot
.2209 .48397 Mdot
.76075 .49849 Mdot
.58428 .29786 Mdot
.29053 .48721 Mdot
.38504 .67464 Mdot
.72655 .69582 Mdot
.43845 .27177 Mdot
.50036 .39587 Mdot
.57365 .29486 Mdot
.59115 .38541 Mdot
.41328 .25773 Mdot
.60604 .4992 Mdot
.60268 .32834 Mdot
.41349 .28735 Mdot
.4101 .27718 Mdot
.47319 .35624 Mdot
.47317 .36265 Mdot
.30678 .49211 Mdot
.42334 .34325 Mdot
.57487 .67246 Mdot
.41797 .2499 Mdot
.79202 .49107 Mdot
.42771 .26216 Mdot
.46327 .33938 Mdot
.21151 .49793 Mdot
.57658 .25888 Mdot
.32244 .49229 Mdot
.27223 .52258 Mdot
.41313 .66985 Mdot
.42412 .28686 Mdot
.55998 .65583 Mdot
.61397 .55725 Mdot
.59373 .64734 Mdot
.30788 .49343 Mdot
.60135 .66423 Mdot
.3798 .65228 Mdot
.56038 .69157 Mdot
.57973 .64834 Mdot
.39293 .66749 Mdot
.27259 .48662 Mdot
.4685 .37669 Mdot
.39395 .66724 Mdot
.58828 .53384 Mdot
.71318 .51172 Mdot
.31376 .4351 Mdot
.62211 .54838 Mdot
.47391 .32556 Mdot
.35773 .7801 Mdot
.56865 .69057 Mdot
.56289 .29893 Mdot
.26958 .50001 Mdot
.78571 .49156 Mdot
.30707 .48574 Mdot
.58871 .54322 Mdot
.7575 .49311 Mdot
.49921 .33964 Mdot
.79807 .4842 Mdot
.43739 .71964 Mdot
.55525 .39237 Mdot
.33185 .43947 Mdot
.5918 .64396 Mdot
.40907 .67373 Mdot
.45302 .66176 Mdot
.63122 .5197 Mdot
.27192 .51679 Mdot
.3283 .55484 Mdot
.59904 .51235 Mdot
.38852 .67358 Mdot
.35296 .33414 Mdot
.53487 .38334 Mdot
.4164 .67517 Mdot
.47503 .36836 Mdot
.38978 .30164 Mdot
.70239 .51888 Mdot
.64575 .52693 Mdot
.42822 .29099 Mdot
.57167 .70315 Mdot
.41996 .2909 Mdot
.42479 .32275 Mdot
.69481 .41417 Mdot
.48298 .37306 Mdot
.56577 .29722 Mdot
.54259 .64648 Mdot
.32678 .48458 Mdot
.60443 .52568 Mdot
.61925 .52578 Mdot
.43615 .28927 Mdot
.8368 .61798 Mdot
.72845 .51033 Mdot
.60445 .77793 Mdot
.4988 .38205 Mdot
.49333 .35975 Mdot
.26063 .49737 Mdot
.38639 .32548 Mdot
.63554 .54223 Mdot
.49244 .38862 Mdot
.58533 .26284 Mdot
.37859 .67537 Mdot
.47727 .33444 Mdot
.4955 .34978 Mdot
.40455 .61749 Mdot
.3868 .67155 Mdot
.55948 .64077 Mdot
.63031 .5034 Mdot
.56036 .7147 Mdot
.75488 .47831 Mdot
.59081 .31022 Mdot
.69071 .3997 Mdot
.6174 .33621 Mdot
.76142 .4847 Mdot
.42911 .26966 Mdot
.46464 .32249 Mdot
.49454 .39466 Mdot
.75326 .50713 Mdot
.41781 .65241 Mdot
.31207 .49001 Mdot
.38987 .30806 Mdot
.62113 .52534 Mdot
.40817 .27139 Mdot
.74769 .47504 Mdot
.32037 .4842 Mdot
.34535 .31542 Mdot
.30336 .49765 Mdot
.39634 .68148 Mdot
.56342 .75257 Mdot
.75728 .49103 Mdot
.3073 .48515 Mdot
.58393 .69064 Mdot
.3743 .61281 Mdot
.44898 .33141 Mdot
.38461 .65103 Mdot
.3528 .46854 Mdot
.27838 .525 Mdot
.3138 .52745 Mdot
.43625 .28487 Mdot
.56508 .29823 Mdot
.60835 .50566 Mdot
.36043 .69587 Mdot
.56587 .70446 Mdot
.68767 .42373 Mdot
.35698 .35602 Mdot
.60205 .34403 Mdot
.48052 .34075 Mdot
.50622 .37644 Mdot
.48976 .35258 Mdot
.5946 .50535 Mdot
.47009 .32158 Mdot
.48018 .37043 Mdot
.42732 .67147 Mdot
.56373 .63998 Mdot
.50266 .38373 Mdot
.60931 .53745 Mdot
.67627 .50872 Mdot
.78595 .49118 Mdot
.37943 .26747 Mdot
.30173 .43853 Mdot
.31568 .48407 Mdot
.57045 .6572 Mdot
.578 .7026 Mdot
.70581 .50437 Mdot
.37312 .68533 Mdot
.30114 .49942 Mdot
.69667 .76447 Mdot
.75323 .48561 Mdot
.51979 .38017 Mdot
.61585 .3595 Mdot
.5864 .26912 Mdot
.46027 .34394 Mdot
.52297 .39129 Mdot
.60286 .54149 Mdot
.56399 .65364 Mdot
.44322 .33369 Mdot
.3456 .31361 Mdot
.76616 .50344 Mdot
.72019 .51661 Mdot
.33621 .50778 Mdot
.53919 .38024 Mdot
.40275 .69045 Mdot
.61136 .30551 Mdot
.43316 .6406 Mdot
.18984 .57306 Mdot
.61217 .66443 Mdot
.50893 .40691 Mdot
.41398 .40767 Mdot
.48915 .32654 Mdot
.34195 .49897 Mdot
.35138 .5314 Mdot
.32485 .49658 Mdot
.37616 .6788 Mdot
.62315 .44357 Mdot
.38238 .65708 Mdot
.63971 .53922 Mdot
.27707 .49736 Mdot
.56165 .41498 Mdot
.54767 .6637 Mdot
.41609 .28541 Mdot
.74438 .49916 Mdot
.5736 .40571 Mdot
.60744 .52477 Mdot
.58656 .30146 Mdot
.53827 .68025 Mdot
.28852 .47101 Mdot
.41516 .28534 Mdot
.55656 .74505 Mdot
.60432 .33244 Mdot
.61462 .63267 Mdot
.64037 .51056 Mdot
.75982 .4901 Mdot
.45087 .42975 Mdot
.74412 .48452 Mdot
.4046 .68278 Mdot
.49743 .3844 Mdot
.52833 .36021 Mdot
.49555 .36796 Mdot
.49173 .34087 Mdot
.37866 .68522 Mdot
.41417 .27617 Mdot
.59756 .54755 Mdot
.6403 .51469 Mdot
.42329 .25825 Mdot
.73118 .5027 Mdot
.38881 .66122 Mdot
.57513 .63658 Mdot
.59373 .53038 Mdot
.73051 .48013 Mdot
.54907 .38435 Mdot
.48812 .38109 Mdot
.64278 .52774 Mdot
.50322 .34069 Mdot
.41651 .27507 Mdot
.56375 .6859 Mdot
.41048 .26551 Mdot
.78543 .48976 Mdot
.74683 .49604 Mdot
.38693 .69546 Mdot
.30844 .48425 Mdot
.71045 .49777 Mdot
.53965 .69219 Mdot
.50228 .33233 Mdot
.47398 .3633 Mdot
.36352 .51522 Mdot
.65948 .4393 Mdot
.78405 .49208 Mdot
.51244 .34414 Mdot
.32751 .51061 Mdot
.3108 .55946 Mdot
.4963 .39293 Mdot
.41933 .27049 Mdot
.29331 .53003 Mdot
.71453 .51058 Mdot
.37276 .68911 Mdot
.64096 .3833 Mdot
.38992 .70221 Mdot
.30209 .50933 Mdot
.63135 .52742 Mdot
.2726 .48842 Mdot
.63253 .52141 Mdot
.19873 .53853 Mdot
.47736 .36618 Mdot
.37162 .49657 Mdot
.61237 .55413 Mdot
.55153 .65777 Mdot
.57221 .64323 Mdot
.6017 .53402 Mdot
.28665 .48834 Mdot
.60998 .5071 Mdot
.73308 .48786 Mdot
.31528 .64124 Mdot
.28353 .52922 Mdot
.57992 .64753 Mdot
.56664 .69256 Mdot
.359 .69217 Mdot
.49935 .3742 Mdot
.5326 .3811 Mdot
.55632 .69216 Mdot
.43396 .64195 Mdot
.28135 .51562 Mdot
.50391 .36651 Mdot
.602 .54538 Mdot
.57116 .67806 Mdot
.40482 .73828 Mdot
.31414 .46251 Mdot
.42788 .2919 Mdot
.69537 .41152 Mdot
.35175 .68469 Mdot
.48864 .32826 Mdot
.41837 .27534 Mdot
.74138 .5123 Mdot
.58103 .29538 Mdot
.65221 .43819 Mdot
.36836 .66006 Mdot
.60959 .5036 Mdot
.46033 .34211 Mdot
.55847 .64842 Mdot
.50935 .33687 Mdot
.7435 .26282 Mdot
.64416 .53062 Mdot
.52007 .36008 Mdot
.64529 .54175 Mdot
.29132 .49582 Mdot
.49805 .36524 Mdot
.35921 .61217 Mdot
.56803 .66012 Mdot
.5272 .36751 Mdot
.78033 .51485 Mdot
.37563 .70088 Mdot
.6078 .52571 Mdot
.76487 .49399 Mdot
.41878 .25321 Mdot
.68792 .38188 Mdot
.5857 .62926 Mdot
.7228 .5004 Mdot
.49669 .37385 Mdot
.53685 .69401 Mdot
.40741 .65689 Mdot
.60287 .52768 Mdot
.55291 .38818 Mdot
.4021 .66063 Mdot
.38204 .66996 Mdot
.74982 .48903 Mdot
.32976 .29113 Mdot
.54212 .40676 Mdot
.51685 .36407 Mdot
.34347 .32095 Mdot
.26923 .54869 Mdot
.53041 .38728 Mdot
.49359 .34547 Mdot
.39706 .68993 Mdot
.61944 .44506 Mdot
.5849 .2998 Mdot
.62122 .55515 Mdot
.4064 .67047 Mdot
.59874 .67421 Mdot
.58003 .67662 Mdot
.719 .49786 Mdot
.31477 .49708 Mdot
.70466 .49976 Mdot
.56938 .67015 Mdot
.51888 .37683 Mdot
.37241 .69398 Mdot
.39334 .27404 Mdot
.37635 .70213 Mdot
.54348 .6933 Mdot
.33781 .47864 Mdot
.43862 .32931 Mdot
.74007 .25686 Mdot
.48272 .62947 Mdot
.56179 .75346 Mdot
.75199 .5138 Mdot
.34591 .31477 Mdot
.49447 .3771 Mdot
.43098 .33514 Mdot
.52728 .37445 Mdot
.69475 .5063 Mdot
.59553 .64274 Mdot
.62999 .50517 Mdot
.63096 .51893 Mdot
.58491 .30363 Mdot
.37894 .67128 Mdot
.37276 .65981 Mdot
.63162 .53655 Mdot
.39613 .67835 Mdot
.5165 .35937 Mdot
.54324 .68171 Mdot
.19786 .52803 Mdot
.48583 .36689 Mdot
.65724 .52039 Mdot
.35905 .66593 Mdot
.33565 .469 Mdot
.59821 .67496 Mdot
.40858 .39952 Mdot
.2083 .60779 Mdot
.40439 .67692 Mdot
.38006 .26765 Mdot
.56416 .65787 Mdot
.59416 .53127 Mdot
.53489 .69354 Mdot
.52099 .36543 Mdot
.50855 .40687 Mdot
.58976 .52423 Mdot
.48775 .36454 Mdot
.37252 .41665 Mdot
.43749 .26658 Mdot
.44398 .25871 Mdot
.48282 .37929 Mdot
.34897 .46144 Mdot
.41751 .66063 Mdot
.63142 .53522 Mdot
.5812 .39784 Mdot
.48037 .38564 Mdot
.31542 .52437 Mdot
.4021 .6625 Mdot
.2256 .62134 Mdot
.37739 .67993 Mdot
.54794 .65859 Mdot
.37271 .68126 Mdot
.49118 .32734 Mdot
.29209 .50429 Mdot
.55935 .67387 Mdot
.61215 .52585 Mdot
.58151 .68594 Mdot
.53495 .39649 Mdot
.3898 .74249 Mdot
.58332 .67213 Mdot
.43605 .26741 Mdot
.29266 .50236 Mdot
.80179 .48365 Mdot
.28368 .4392 Mdot
.5199 .3731 Mdot
.52692 .3794 Mdot
.63145 .54643 Mdot
.38298 .69265 Mdot
.28798 .47026 Mdot
.59701 .77349 Mdot
.78488 .49254 Mdot
.32027 .49574 Mdot
.71254 .52169 Mdot
.6035 .37452 Mdot
.32713 .47733 Mdot
.58749 .26502 Mdot
.39729 .69409 Mdot
.2973 .48225 Mdot
.64979 .56263 Mdot
.3998 .26045 Mdot
.73446 .49596 Mdot
.57142 .70682 Mdot
.6015 .37942 Mdot
.58091 .66778 Mdot
.37809 .61271 Mdot
.52466 .71448 Mdot
.4083 .67824 Mdot
.76854 .52122 Mdot
.43451 .25764 Mdot
.38347 .65309 Mdot
.33235 .61697 Mdot
.57602 .66595 Mdot
.6342 .53756 Mdot
.41288 .26706 Mdot
.58741 .5224 Mdot
.63699 .52246 Mdot
.36606 .66347 Mdot
.29941 .4801 Mdot
.30415 .47368 Mdot
.65399 .54088 Mdot
.30528 .47949 Mdot
.55429 .68341 Mdot
.62098 .3433 Mdot
.41545 .36406 Mdot
.41698 .65904 Mdot
.41635 .25325 Mdot
.46764 .34231 Mdot
.59694 .63866 Mdot
.54674 .68043 Mdot
.37718 .67489 Mdot
.25227 .4472 Mdot
.63216 .5148 Mdot
.32279 .46456 Mdot
.28167 .50052 Mdot
.29151 .49324 Mdot
.2663 .50191 Mdot
.63678 .44244 Mdot
.39997 .66713 Mdot
.2857 .49005 Mdot
.48066 .34723 Mdot
.48973 .3481 Mdot
.59364 .52701 Mdot
.69902 .49706 Mdot
.41792 .267 Mdot
.61226 .50623 Mdot
.50897 .39903 Mdot
.55126 .6605 Mdot
.66881 .53983 Mdot
.60928 .50221 Mdot
.56084 .65459 Mdot
.55751 .65399 Mdot
.61508 .5017 Mdot
.67224 .53358 Mdot
.37368 .42102 Mdot
.39866 .27651 Mdot
.34285 .4491 Mdot
.58197 .64316 Mdot
.33793 .61247 Mdot
.37148 .49768 Mdot
.52549 .35844 Mdot
.63092 .54851 Mdot
.54071 .67466 Mdot
.27856 .52806 Mdot
.50377 .35909 Mdot
.62589 .52285 Mdot
.73462 .49124 Mdot
.61158 .52951 Mdot
.60715 .5437 Mdot
.30986 .52212 Mdot
.36543 .78239 Mdot
.33512 .49155 Mdot
.52258 .69891 Mdot
.61084 .5198 Mdot
.31263 .25941 Mdot
.58876 .64102 Mdot
.31506 .64472 Mdot
.43382 .25794 Mdot
.49662 .39473 Mdot
.57162 .65792 Mdot
.27605 .52029 Mdot
.41501 .64965 Mdot
.57563 .25567 Mdot
.30665 .48433 Mdot
.61095 .49871 Mdot
.60385 .53935 Mdot
.57425 .67465 Mdot
.29651 .51161 Mdot
.41885 .27494 Mdot
.29638 .48665 Mdot
.36925 .66752 Mdot
.50386 .33889 Mdot
.20537 .60034 Mdot
.62887 .51959 Mdot
.3141 .47635 Mdot
.55997 .70531 Mdot
.72816 .48577 Mdot
.51534 .34828 Mdot
.20225 .61026 Mdot
.49379 .37121 Mdot
.36164 .67654 Mdot
.66658 .5152 Mdot
.40132 .26344 Mdot
.51643 .39013 Mdot
.46131 .33463 Mdot
.43695 .67174 Mdot
.5143 .39231 Mdot
.4714 .37639 Mdot
.3418 .29813 Mdot
.33192 .48656 Mdot
.50144 .38234 Mdot
.55418 .68984 Mdot
.52871 .60937 Mdot
.50505 .35157 Mdot
.56788 .75129 Mdot
.60137 .2857 Mdot
.60079 .55316 Mdot
.64314 .56096 Mdot
.68882 .40865 Mdot
.52379 .37293 Mdot
.54113 .39918 Mdot
.50028 .33806 Mdot
.42073 .38942 Mdot
.56945 .66553 Mdot
.55259 .71462 Mdot
.72225 .49063 Mdot
.57003 .29346 Mdot
.7472 .49343 Mdot
.4091 .65773 Mdot
.44434 .28122 Mdot
.63656 .5066 Mdot
.31224 .48215 Mdot
.49413 .36583 Mdot
.55717 .70998 Mdot
.52195 .36471 Mdot
.42932 .28032 Mdot
.56053 .68317 Mdot
.5417 .66993 Mdot
.54175 .72151 Mdot
.76545 .50833 Mdot
.32054 .48775 Mdot
.53113 .36038 Mdot
.76823 .49885 Mdot
.58921 .52158 Mdot
.6434 .37296 Mdot
.32289 .49024 Mdot
.31905 .47764 Mdot
.28199 .48046 Mdot
.53392 .36646 Mdot
.527 .35089 Mdot
.38124 .65887 Mdot
.36328 .51636 Mdot
.38099 .70034 Mdot
.57513 .65839 Mdot
.54847 .65203 Mdot
.523 .36747 Mdot
.73861 .52396 Mdot
.73231 .50148 Mdot
.57652 .68969 Mdot
.64841 .5285 Mdot
.72126 .48708 Mdot
.53933 .38766 Mdot
.5803 .66334 Mdot
.77153 .49796 Mdot
.25168 .44723 Mdot
.24347 .59882 Mdot
.72713 .48537 Mdot
.62951 .51622 Mdot
.35936 .36282 Mdot
.6875 .41932 Mdot
.70276 .51871 Mdot
.41465 .65891 Mdot
.47979 .39236 Mdot
.64676 .52674 Mdot
.72869 .48164 Mdot
.68782 .43025 Mdot
.56551 .67578 Mdot
.62865 .51393 Mdot
.69045 .53693 Mdot
.41645 .3648 Mdot
.73346 .48233 Mdot
.31686 .47621 Mdot
.32498 .45731 Mdot
.52115 .38592 Mdot
.4279 .25649 Mdot
.42469 .66395 Mdot
.57846 .7011 Mdot
.55595 .71254 Mdot
.33587 .547 Mdot
.61837 .33445 Mdot
.56509 .68771 Mdot
.51446 .41284 Mdot
.72552 .48004 Mdot
.4801 .34789 Mdot
.66674 .52695 Mdot
.39928 .26626 Mdot
.63856 .56196 Mdot
.72789 .48547 Mdot
.41801 .65791 Mdot
.39547 .66953 Mdot
.38224 .69091 Mdot
.56848 .68402 Mdot
.59705 .38069 Mdot
.54743 .71221 Mdot
.33131 .28714 Mdot
.72428 .50964 Mdot
.63238 .78626 Mdot
.47598 .32346 Mdot
.51343 .40116 Mdot
.40541 .27271 Mdot
.60813 .54729 Mdot
.52081 .36991 Mdot
.40013 .65904 Mdot
.58388 .69025 Mdot
.40472 .74032 Mdot
.30718 .51871 Mdot
.3336 .28944 Mdot
.54811 .66504 Mdot
.65423 .51916 Mdot
.7401 .50113 Mdot
.70137 .39826 Mdot
.69479 .51067 Mdot
.53585 .67154 Mdot
.52593 .40692 Mdot
.295 .53161 Mdot
.70531 .76036 Mdot
.4984 .3672 Mdot
.56965 .69076 Mdot
.60091 .62707 Mdot
.40494 .25393 Mdot
.49878 .43849 Mdot
.41697 .73562 Mdot
.61549 .35334 Mdot
.77312 .50272 Mdot
.58915 .53113 Mdot
.61218 .30044 Mdot
.5708 .66934 Mdot
.58672 .68152 Mdot
.70468 .51824 Mdot
.33612 .47037 Mdot
.27822 .48937 Mdot
.37722 .44347 Mdot
.39269 .65795 Mdot
.48778 .38857 Mdot
.57872 .66663 Mdot
.33543 .47559 Mdot
.57825 .39894 Mdot
.38876 .68677 Mdot
.58255 .67776 Mdot
.48814 .36417 Mdot
.51586 .38756 Mdot
.74492 .49267 Mdot
.67587 .50875 Mdot
.59684 .54349 Mdot
.31661 .63911 Mdot
.59812 .36752 Mdot
.44442 .28533 Mdot
.4999 .39565 Mdot
.2835 .51932 Mdot
.60218 .50834 Mdot
.73142 .49923 Mdot
.50425 .33503 Mdot
.4362 .3318 Mdot
.27515 .52299 Mdot
.39975 .69307 Mdot
.61601 .52175 Mdot
.58965 .31238 Mdot
.48958 .36704 Mdot
.52604 .37256 Mdot
.43614 .28483 Mdot
.43585 .32098 Mdot
.59546 .65336 Mdot
.33169 .50267 Mdot
.76661 .49739 Mdot
.29902 .49465 Mdot
.5861 .76669 Mdot
.43713 .26408 Mdot
.50282 .40936 Mdot
.31998 .51997 Mdot
.30055 .50217 Mdot
.36221 .6763 Mdot
.4026 .6703 Mdot
.61336 .63909 Mdot
.5006 .34522 Mdot
.64445 .53296 Mdot
.28588 .49212 Mdot
.57338 .7055 Mdot
.74824 .49241 Mdot
.57036 .75888 Mdot
.48338 .37587 Mdot
.57458 .66876 Mdot
.6028 .52244 Mdot
.30923 .52036 Mdot
.55777 .65957 Mdot
.59437 .53182 Mdot
.7168 .51364 Mdot
.45841 .35179 Mdot
.61082 .62779 Mdot
.62861 .53013 Mdot
.495 .34346 Mdot
.43532 .24417 Mdot
.42461 .25508 Mdot
.62297 .55535 Mdot
.60405 .63983 Mdot
.62554 .52851 Mdot
.31098 .45948 Mdot
.41122 .25053 Mdot
.57526 .70088 Mdot
.36862 .50566 Mdot
.43467 .25927 Mdot
.63283 .52385 Mdot
.32458 .48289 Mdot
.59156 .76886 Mdot
.34718 .49773 Mdot
.67694 .42472 Mdot
.50151 .35341 Mdot
.58087 .66827 Mdot
.73525 .49451 Mdot
.36951 .66444 Mdot
.35849 .72289 Mdot
.34444 .61348 Mdot
.57178 .64666 Mdot
.49263 .36399 Mdot
.29437 .48464 Mdot
.40301 .67748 Mdot
.25975 .49879 Mdot
.54163 .69813 Mdot
.54683 .68803 Mdot
.40553 .27111 Mdot
.74852 .49391 Mdot
.46987 .32221 Mdot
.56855 .70828 Mdot
.52383 .71121 Mdot
.3438 .30141 Mdot
.77253 .49763 Mdot
.43602 .28671 Mdot
.65247 .54491 Mdot
.47652 .3357 Mdot
.34564 .31893 Mdot
.61171 .5435 Mdot
.30511 .51911 Mdot
.52488 .39594 Mdot
.42618 .81444 Mdot
.58736 .63873 Mdot
.61522 .35311 Mdot
.43669 .72015 Mdot
.38792 .66615 Mdot
.56409 .66269 Mdot
.49849 .3582 Mdot
.56848 .75792 Mdot
.71816 .49783 Mdot
.41313 .28837 Mdot
.63365 .5318 Mdot
.31792 .5568 Mdot
.37032 .68993 Mdot
.69551 .53124 Mdot
.3708 .66332 Mdot
.3866 .69448 Mdot
.25185 .44999 Mdot
.5211 .3846 Mdot
.55045 .66802 Mdot
.55182 .69482 Mdot
.6602 .53518 Mdot
.51825 .68689 Mdot
.27402 .49199 Mdot
.4199 .80986 Mdot
.43961 .33604 Mdot
.49306 .38103 Mdot
.60697 .49897 Mdot
.63838 .53914 Mdot
.56308 .75291 Mdot
.51745 .39347 Mdot
.32908 .4889 Mdot
.56309 .71259 Mdot
.57829 .67763 Mdot
.43508 .26656 Mdot
.39619 .66935 Mdot
.69417 .51237 Mdot
.55024 .68141 Mdot
.63957 .3828 Mdot
.5216 .36109 Mdot
.40982 .64732 Mdot
.55209 .68076 Mdot
.80511 .66581 Mdot
.36398 .78911 Mdot
.33616 .48649 Mdot
.45504 .33922 Mdot
.31207 .463 Mdot
.73407 .48351 Mdot
.53688 .70368 Mdot
.37798 .65559 Mdot
.61081 .52216 Mdot
.45384 .7088 Mdot
.57603 .67726 Mdot
.30873 .49269 Mdot
.52408 .38295 Mdot
.38017 .25915 Mdot
.48745 .36901 Mdot
.6161 .4451 Mdot
.78253 .4936 Mdot
.35974 .72445 Mdot
.35923 .68861 Mdot
.45481 .33885 Mdot
.76955 .50122 Mdot
.53409 .67184 Mdot
.56284 .68199 Mdot
.20667 .61583 Mdot
.60589 .54277 Mdot
.52938 .69096 Mdot
.49766 .3438 Mdot
.53994 .7207 Mdot
.35675 .35607 Mdot
.38743 .66745 Mdot
.471 .35876 Mdot
.5835 .66068 Mdot
.34841 .48742 Mdot
.61297 .36193 Mdot
.51144 .35494 Mdot
.64594 .54286 Mdot
.40482 .67445 Mdot
.33207 .28362 Mdot
.59771 .64279 Mdot
.47777 .36 Mdot
.40941 .66232 Mdot
.76524 .52149 Mdot
.38141 .74896 Mdot
.3213 .4881 Mdot
.56552 .69391 Mdot
.37169 .68798 Mdot
.60884 .51457 Mdot
.76811 .4918 Mdot
.5334 .68454 Mdot
.5857 .66157 Mdot
.4292 .2724 Mdot
.6553 .52911 Mdot
.70642 .52055 Mdot
.27982 .51268 Mdot
.39854 .69062 Mdot
.43292 .27908 Mdot
.64535 .38254 Mdot
.52246 .34486 Mdot
.39004 .69643 Mdot
.31738 .26448 Mdot
.51834 .4071 Mdot
.48327 .37802 Mdot
.38203 .25876 Mdot
.31549 .45959 Mdot
.27346 .51357 Mdot
.60309 .33882 Mdot
.42077 .26933 Mdot
.56208 .41292 Mdot
.3152 .4868 Mdot
.30738 .49555 Mdot
.56188 .41241 Mdot
.42936 .2754 Mdot
.37849 .44101 Mdot
.39909 .67609 Mdot
.39029 .66613 Mdot
.29176 .49431 Mdot
.40482 .27222 Mdot
.41766 .68583 Mdot
.25722 .5332 Mdot
.54297 .68998 Mdot
.60451 .2927 Mdot
.29592 .49891 Mdot
.61698 .36277 Mdot
.40428 .68339 Mdot
.66362 .37065 Mdot
.59962 .28304 Mdot
.54406 .39646 Mdot
.51953 .3889 Mdot
.75004 .51329 Mdot
.60933 .52722 Mdot
.61456 .50152 Mdot
.38144 .691 Mdot
.46933 .32153 Mdot
.3243 .49785 Mdot
.49845 .32875 Mdot
.6887 .42423 Mdot
.67145 .36683 Mdot
.44752 .34233 Mdot
.31304 .4971 Mdot
.3117 .50628 Mdot
.54975 .64941 Mdot
.59326 .68154 Mdot
.53593 .4164 Mdot
.4027 .67218 Mdot
.30706 .4757 Mdot
.37652 .69791 Mdot
.57004 .67084 Mdot
.54734 .66819 Mdot
.59682 .51406 Mdot
.62733 .51282 Mdot
.56291 .66808 Mdot
.56756 .75144 Mdot
.64509 .38061 Mdot
.35785 .52527 Mdot
.32718 .27135 Mdot
.69172 .39071 Mdot
.38987 .30348 Mdot
.73387 .49287 Mdot
.667 .54233 Mdot
.40521 .66014 Mdot
.45581 .33309 Mdot
.52289 .39902 Mdot
.62196 .53368 Mdot
.41427 .66981 Mdot
.73967 .50715 Mdot
.38718 .66686 Mdot
.76695 .49122 Mdot
.57068 .70374 Mdot
.49225 .36039 Mdot
.53068 .40354 Mdot
.36314 .67542 Mdot
.54418 .65526 Mdot
.58151 .6598 Mdot
.73033 .49525 Mdot
.69247 .39685 Mdot
.57402 .67321 Mdot
.29686 .49952 Mdot
.19921 .51394 Mdot
.61009 .54181 Mdot
.50287 .35947 Mdot
.69102 .40679 Mdot
.41357 .24982 Mdot
.58976 .51927 Mdot
.61678 .52202 Mdot
.33021 .29363 Mdot
.53241 .37294 Mdot
.22067 .62505 Mdot
.60655 .50321 Mdot
.27315 .48732 Mdot
.55413 .66701 Mdot
.59874 .50496 Mdot
.64546 .5501 Mdot
.68361 .51102 Mdot
.5993 .50274 Mdot
.27921 .49162 Mdot
.30545 .46377 Mdot
.41322 .26373 Mdot
.33116 .23712 Mdot
.76238 .49168 Mdot
.72881 .50561 Mdot
.59338 .65218 Mdot
.38014 .61375 Mdot
.49558 .31759 Mdot
.72154 .50596 Mdot
.322 .4329 Mdot
.4085 .27642 Mdot
.41438 .25656 Mdot
.42044 .25853 Mdot
.27166 .48353 Mdot
.54573 .40787 Mdot
.59474 .6461 Mdot
.31068 .49191 Mdot
.40998 .26571 Mdot
.51351 .33621 Mdot
.3244 .49279 Mdot
.39221 .69211 Mdot
.44615 .29161 Mdot
.30012 .4824 Mdot
.57565 .25431 Mdot
.40601 .68563 Mdot
.44762 .33079 Mdot
.66648 .76002 Mdot
.82102 .64472 Mdot
.38384 .67025 Mdot
.58088 .68065 Mdot
.5775 .66493 Mdot
.56334 .68501 Mdot
.27416 .51104 Mdot
.55853 .6441 Mdot
.29878 .51377 Mdot
.55804 .75097 Mdot
.57715 .29875 Mdot
.7576 .49205 Mdot
.52031 .68087 Mdot
.29268 .49287 Mdot
.33974 .30676 Mdot
.72602 .22757 Mdot
.47791 .3565 Mdot
.37612 .65556 Mdot
.71118 .50176 Mdot
.62016 .35117 Mdot
.74228 .5123 Mdot
.56511 .65765 Mdot
.58802 .3079 Mdot
.52276 .3643 Mdot
.23771 .60638 Mdot
.73742 .49528 Mdot
.30584 .49624 Mdot
.42928 .26765 Mdot
.60459 .63708 Mdot
.72053 .49656 Mdot
.74605 .49705 Mdot
.51666 .36642 Mdot
.28749 .47142 Mdot
.57144 .65568 Mdot
.41327 .6737 Mdot
.5401 .7343 Mdot
.57436 .42065 Mdot
.53149 .36971 Mdot
.47892 .37581 Mdot
.60758 .37082 Mdot
.57083 .75822 Mdot
.39515 .67337 Mdot
.67056 .43537 Mdot
.59873 .6387 Mdot
.69305 .41907 Mdot
.34497 .49296 Mdot
.5204 .6788 Mdot
.61444 .54357 Mdot
.59314 .52783 Mdot
.50544 .36819 Mdot
.73422 .24384 Mdot
.52038 .44008 Mdot
.4195 .68226 Mdot
.61745 .53983 Mdot
.5517 .64586 Mdot
.26826 .50836 Mdot
.6854 .54106 Mdot
.41707 .26916 Mdot
.41397 .6756 Mdot
.56835 .6784 Mdot
.77252 .28974 Mdot
.74676 .51558 Mdot
.61514 .34715 Mdot
.48728 .34826 Mdot
.50729 .36644 Mdot
.38312 .68516 Mdot
.42356 .65647 Mdot
.33489 .27986 Mdot
.68392 .50476 Mdot
.19978 .59595 Mdot
.41425 .70023 Mdot
.78827 .30572 Mdot
.64105 .53609 Mdot
.31317 .50927 Mdot
.6209 .50181 Mdot
.42276 .65728 Mdot
.5289 .39299 Mdot
.29762 .46614 Mdot
.60097 .52576 Mdot
.29662 .43661 Mdot
.41786 .25415 Mdot
.64093 .38095 Mdot
.50725 .37703 Mdot
.29601 .47352 Mdot
.31552 .48947 Mdot
.32088 .46778 Mdot
.59871 .53253 Mdot
.49164 .38793 Mdot
.47969 .36385 Mdot
.48116 .37896 Mdot
.33726 .28027 Mdot
.49528 .36254 Mdot
.29878 .53262 Mdot
.61533 .3268 Mdot
.43798 .82252 Mdot
.52952 .40338 Mdot
.37461 .68852 Mdot
.50701 .37216 Mdot
.76373 .5118 Mdot
.45769 .34608 Mdot
.42448 .25261 Mdot
.39303 .67662 Mdot
.42581 .3224 Mdot
.7918 .49139 Mdot
.53645 .38021 Mdot
.7635 .48643 Mdot
.31193 .67629 Mdot
.66348 .43554 Mdot
.35332 .33539 Mdot
.29543 .48857 Mdot
.54186 .70193 Mdot
.42787 .66841 Mdot
.548 .65899 Mdot
.40154 .28285 Mdot
.63602 .50873 Mdot
.62695 .78554 Mdot
.6508 .37993 Mdot
.52725 .39442 Mdot
.63031 .54626 Mdot
.32838 .48366 Mdot
.5894 .64035 Mdot
.38633 .32324 Mdot
.40619 .27424 Mdot
.70481 .50529 Mdot
.72811 .51382 Mdot
.65455 .50756 Mdot
.32842 .46807 Mdot
.35471 .35331 Mdot
.38423 .68421 Mdot
.57126 .68287 Mdot
.75566 .47669 Mdot
.33586 .43692 Mdot
.41803 .6518 Mdot
.55868 .74966 Mdot
.3695 .68745 Mdot
.51265 .40219 Mdot
.60777 .50087 Mdot
.37748 .47796 Mdot
.62579 .53792 Mdot
.50586 .33406 Mdot
.58486 .65925 Mdot
.60949 .54343 Mdot
.76202 .50561 Mdot
.37697 .69327 Mdot
.54943 .66246 Mdot
.52497 .37806 Mdot
.31815 .48474 Mdot
.51282 .23858 Mdot
.58405 .62481 Mdot
.43412 .26047 Mdot
.43469 .26093 Mdot
.34266 .54474 Mdot
.6128 .55677 Mdot
.35523 .73347 Mdot
.40576 .25147 Mdot
.35265 .61159 Mdot
.71325 .52416 Mdot
.60333 .77824 Mdot
.54763 .71059 Mdot
.56001 .67576 Mdot
.53471 .38773 Mdot
.5651 .71293 Mdot
.50808 .41101 Mdot
.60486 .64459 Mdot
.31358 .63675 Mdot
.55526 .39205 Mdot
.55847 .68224 Mdot
.61324 .50402 Mdot
.50918 .34573 Mdot
.33159 .49071 Mdot
.541 .71202 Mdot
.54412 .39594 Mdot
.60845 .77101 Mdot
.36261 .67533 Mdot
.5975 .53161 Mdot
.58841 .39545 Mdot
.39969 .68077 Mdot
.2754 .49782 Mdot
.46903 .37858 Mdot
.71725 .50368 Mdot
.30545 .5092 Mdot
.60803 .49134 Mdot
.74973 .49514 Mdot
.62208 .34207 Mdot
.28639 .50483 Mdot
.61579 .54258 Mdot
.71949 .51341 Mdot
.65065 .55543 Mdot
.56219 .67655 Mdot
.60036 .62608 Mdot
.62863 .52612 Mdot
.52591 .36835 Mdot
.56993 .63564 Mdot
.37555 .67488 Mdot
.49872 .34901 Mdot
.57958 .66926 Mdot
.60821 .53612 Mdot
.48194 .35913 Mdot
.42009 .26831 Mdot
.34425 .30929 Mdot
.59921 .5532 Mdot
.76237 .49668 Mdot
.32675 .47033 Mdot
.47721 .36284 Mdot
.75905 .48687 Mdot
.54044 .64966 Mdot
.47622 .3467 Mdot
.31877 .4731 Mdot
.29211 .43046 Mdot
.58039 .69965 Mdot
.40453 .69123 Mdot
.55281 .69708 Mdot
.7573 .47934 Mdot
.7223 .22118 Mdot
.60562 .50488 Mdot
.40284 .27851 Mdot
.46501 .36123 Mdot
.54213 .7046 Mdot
.31901 .49025 Mdot
.19048 .58272 Mdot
.45698 .34668 Mdot
.47782 .34553 Mdot
.50751 .36178 Mdot
.54232 .73794 Mdot
.26965 .50259 Mdot
.50515 .36029 Mdot
.6829 .51678 Mdot
.47482 .37107 Mdot
.72987 .48743 Mdot
.6425 .7781 Mdot
.5924 .53237 Mdot
.31043 .2566 Mdot
.59973 .52657 Mdot
.55345 .68526 Mdot
.57574 .25375 Mdot
.58634 .39466 Mdot
.61197 .68039 Mdot
.27462 .49755 Mdot
.34273 .44959 Mdot
.54754 .67009 Mdot
.59027 .76885 Mdot
.41517 .27085 Mdot
.42761 .26854 Mdot
.51452 .34944 Mdot
.5648 .65775 Mdot
.59112 .67726 Mdot
.63594 .51092 Mdot
.62875 .54602 Mdot
.44796 .32999 Mdot
.56155 .70698 Mdot
.49342 .36055 Mdot
.40391 .26008 Mdot
.4209 .65251 Mdot
.33363 .4823 Mdot
.39013 .65173 Mdot
.40765 .64853 Mdot
.39103 .31012 Mdot
.59701 .36835 Mdot
.39482 .65748 Mdot
.42096 .66586 Mdot
.5484 .74198 Mdot
.41794 .34901 Mdot
.7366 .48391 Mdot
.52337 .44093 Mdot
.54245 .66153 Mdot
.49317 .38775 Mdot
.26853 .49988 Mdot
.58752 .54057 Mdot
.18671 .56033 Mdot
.76435 .36706 Mdot
.41951 .28317 Mdot
.5895 .63499 Mdot
.62945 .52994 Mdot
.63062 .53714 Mdot
.68823 .41958 Mdot
.49601 .36104 Mdot
.57763 .70238 Mdot
.41633 .36317 Mdot
.41778 .69779 Mdot
.56767 .75482 Mdot
.32566 .46484 Mdot
.50356 .37141 Mdot
.28726 .51764 Mdot
.40189 .69672 Mdot
.74998 .48508 Mdot
.75953 .51108 Mdot
.538 .38604 Mdot
.43268 .25643 Mdot
.35125 .6114 Mdot
.42235 .26516 Mdot
.42758 .279 Mdot
.62436 .5266 Mdot
.43829 .28586 Mdot
.47683 .35805 Mdot
.5525 .39241 Mdot
.58889 .52292 Mdot
.40117 .64867 Mdot
.40357 .34635 Mdot
.63283 .52556 Mdot
.45633 .35155 Mdot
.39864 .69818 Mdot
.41927 .26539 Mdot
.37684 .68097 Mdot
.57203 .75788 Mdot
.38075 .6606 Mdot
.76575 .49916 Mdot
.52967 .72252 Mdot
.33048 .27405 Mdot
.29654 .48354 Mdot
.39836 .66709 Mdot
.71505 .51326 Mdot
.37452 .68185 Mdot
.5384 .66929 Mdot
.43059 .68494 Mdot
.26246 .5437 Mdot
.63838 .38146 Mdot
.39236 .30135 Mdot
.42012 .69397 Mdot
.58792 .6886 Mdot
.29095 .49403 Mdot
.36407 .61254 Mdot
.46433 .36727 Mdot
.75162 .51493 Mdot
.50747 .36849 Mdot
.38103 .69458 Mdot
.56541 .63909 Mdot
.35194 .33615 Mdot
.76384 .49932 Mdot
.32891 .28166 Mdot
.5565 .7091 Mdot
.49257 .39668 Mdot
.35619 .69361 Mdot
.3457 .71343 Mdot
.36006 .68451 Mdot
.57905 .29324 Mdot
.64583 .52757 Mdot
.68678 .49959 Mdot
.29913 .50822 Mdot
.64012 .54051 Mdot
.81452 .46742 Mdot
.32804 .61888 Mdot
.32844 .5037 Mdot
.52475 .67514 Mdot
.52536 .36414 Mdot
.43512 .28886 Mdot
.61597 .50809 Mdot
.30237 .47359 Mdot
.43618 .28439 Mdot
.59437 .52013 Mdot
.61423 .3227 Mdot
.32294 .46601 Mdot
.53108 .67852 Mdot
.50156 .34489 Mdot
.36178 .66862 Mdot
.37931 .70238 Mdot
.61533 .49935 Mdot
.37446 .65981 Mdot
.45557 .35043 Mdot
.29015 .50298 Mdot
.41392 .26456 Mdot
.72557 .48865 Mdot
.37745 .45661 Mdot
.5851 .52792 Mdot
.73604 .47262 Mdot
.48362 .34317 Mdot
.54871 .66849 Mdot
.4504 .71307 Mdot
.46417 .33871 Mdot
.31221 .48864 Mdot
.46762 .36976 Mdot
.43751 .28506 Mdot
.4251 .26681 Mdot
.57151 .6825 Mdot
.61399 .36316 Mdot
.49372 .3618 Mdot
.41248 .68162 Mdot
.55956 .43173 Mdot
.46959 .32529 Mdot
.69051 .50564 Mdot
.42395 .2524 Mdot
.36598 .70228 Mdot
.34514 .54058 Mdot
.55127 .66885 Mdot
.3219 .50151 Mdot
.25445 .51964 Mdot
.2758 .49991 Mdot
.35321 .48401 Mdot
.40663 .25097 Mdot
.20863 .62058 Mdot
.35627 .35488 Mdot
.38516 .28936 Mdot
.27495 .52814 Mdot
.39776 .75419 Mdot
.32903 .50372 Mdot
.27518 .49787 Mdot
.19699 .53105 Mdot
.27271 .49681 Mdot
.52464 .36906 Mdot
.47957 .38492 Mdot
.4429 .33985 Mdot
.53734 .73353 Mdot
.48653 .36912 Mdot
.59136 .51121 Mdot
.70876 .50249 Mdot
.33705 .47277 Mdot
.6132 .52279 Mdot
.62181 .35125 Mdot
.62549 .49752 Mdot
.51771 .36738 Mdot
.48868 .35542 Mdot
.42235 .26051 Mdot
.68034 .36489 Mdot
.53416 .73025 Mdot
.28584 .47646 Mdot
.47008 .32379 Mdot
.37955 .74818 Mdot
.50464 .34717 Mdot
.46109 .3495 Mdot
.54672 .40281 Mdot
.5504 .66799 Mdot
.26352 .49233 Mdot
.63599 .51828 Mdot
.37758 .46034 Mdot
.49692 .37458 Mdot
.58223 .50982 Mdot
.7108 .49033 Mdot
.49913 .35743 Mdot
.28145 .47691 Mdot
.43714 .28454 Mdot
.28126 .52435 Mdot
.28901 .50742 Mdot
.47677 .34682 Mdot
.33463 .47182 Mdot
.27496 .51666 Mdot
.4271 .26902 Mdot
.58803 .63306 Mdot
.31534 .64257 Mdot
.51908 .3618 Mdot
.76154 .502 Mdot
.52045 .39254 Mdot
.73896 .48222 Mdot
.59889 .50385 Mdot
.62677 .5299 Mdot
.456 .43157 Mdot
.58379 .68734 Mdot
.70212 .50702 Mdot
.52409 .71485 Mdot
.46065 .30943 Mdot
.31051 .4335 Mdot
.43503 .67706 Mdot
.59898 .62104 Mdot
.62517 .52951 Mdot
.62502 .44293 Mdot
.56606 .42351 Mdot
.3842 .65706 Mdot
.31932 .51768 Mdot
.40176 .36102 Mdot
.63416 .54573 Mdot
.53129 .67688 Mdot
.55055 .69323 Mdot
.3294 .61767 Mdot
.19809 .52832 Mdot
.53148 .40215 Mdot
.63164 .54692 Mdot
.43734 .24976 Mdot
.60852 .52766 Mdot
.63376 .51107 Mdot
.58609 .66634 Mdot
.48331 .36192 Mdot
.61654 .3177 Mdot
.57476 .66463 Mdot
.73684 .50361 Mdot
.30333 .51944 Mdot
.76307 .4886 Mdot
.25088 .59196 Mdot
.33385 .27803 Mdot
.56623 .66596 Mdot
.59647 .53953 Mdot
.49077 .38333 Mdot
.28523 .47203 Mdot
.25955 .5009 Mdot
.33312 .48995 Mdot
.71651 .49391 Mdot
.56195 .71201 Mdot
.60973 .77912 Mdot
.52293 .3814 Mdot
.30302 .50169 Mdot
.74887 .47411 Mdot
.51462 .3879 Mdot
.39995 .66992 Mdot
.436 .28168 Mdot
.30034 .49769 Mdot
.40369 .27796 Mdot
.29749 .50844 Mdot
.55175 .69052 Mdot
.53787 .39298 Mdot
.52151 .35687 Mdot
.66019 .43709 Mdot
.73965 .50756 Mdot
.27847 .52565 Mdot
.59428 .37417 Mdot
.47681 .33546 Mdot
.6887 .4149 Mdot
.49329 .35414 Mdot
.39146 .29856 Mdot
.65232 .53578 Mdot
.59527 .51442 Mdot
.46477 .36291 Mdot
.51335 .35822 Mdot
.2607 .49957 Mdot
.35782 .3557 Mdot
.33635 .27764 Mdot
.40009 .69593 Mdot
.33194 .50074 Mdot
.57309 .66134 Mdot
.53803 .71129 Mdot
.5518 .65126 Mdot
.75731 .4782 Mdot
.41625 .26579 Mdot
.53001 .39834 Mdot
.41507 .68739 Mdot
.71698 .5068 Mdot
.31129 .50138 Mdot
.74947 .48929 Mdot
.60479 .3666 Mdot
.75786 .50716 Mdot
.62955 .50339 Mdot
.35596 .78061 Mdot
.40441 .25922 Mdot
.75096 .50065 Mdot
.33168 .47841 Mdot
.55318 .44204 Mdot
.54157 .3747 Mdot
.33881 .30199 Mdot
.70461 .50428 Mdot
.52875 .66284 Mdot
.48646 .34331 Mdot
.56321 .29761 Mdot
.37912 .6866 Mdot
.76788 .49353 Mdot
.36826 .68548 Mdot
.42717 .28257 Mdot
.34546 .45421 Mdot
.30541 .48969 Mdot
.43874 .66603 Mdot
.46454 .35607 Mdot
.76829 .49428 Mdot
.5645 .66992 Mdot
.4188 .35118 Mdot
.55114 .74659 Mdot
.57962 .50654 Mdot
.68233 .42329 Mdot
.59551 .64897 Mdot
.41539 .33045 Mdot
.37096 .66764 Mdot
.48791 .32605 Mdot
.40023 .2677 Mdot
.48139 .33507 Mdot
.57827 .6568 Mdot
.55911 .67588 Mdot
.60057 .77654 Mdot
.53158 .36725 Mdot
.54687 .39733 Mdot
.30648 .55772 Mdot
.5657 .71033 Mdot
.27683 .50125 Mdot
.30136 .47199 Mdot
.5816 .67817 Mdot
.29713 .52762 Mdot
.74742 .49577 Mdot
.60027 .32543 Mdot
.37205 .66671 Mdot
.36146 .69649 Mdot
.56388 .66672 Mdot
.58664 .6498 Mdot
.54834 .66774 Mdot
.4311 .28439 Mdot
.28399 .50558 Mdot
.5236 .41239 Mdot
.51333 .37367 Mdot
.5295 .35462 Mdot
.31834 .46167 Mdot
.45732 .34945 Mdot
.54976 .37028 Mdot
.71302 .49358 Mdot
.55061 .68327 Mdot
.3806 .69901 Mdot
.51517 .24311 Mdot
.41122 .68651 Mdot
.4734 .36358 Mdot
.31714 .63073 Mdot
.31722 .51831 Mdot
.74518 .51286 Mdot
.42386 .25397 Mdot
.76245 .50695 Mdot
.42174 .65287 Mdot
.30704 .55634 Mdot
.62012 .33758 Mdot
.52903 .41053 Mdot
.60288 .37266 Mdot
.72735 .69429 Mdot
.25621 .52499 Mdot
.3997 .68789 Mdot
.41295 .25278 Mdot
.62997 .4992 Mdot
.42705 .2468 Mdot
.53407 .39019 Mdot
.47529 .32417 Mdot
.55784 .2993 Mdot
.47163 .36952 Mdot
.33691 .4848 Mdot
.56034 .41233 Mdot
.60462 .54736 Mdot
.51112 .34388 Mdot
.22122 .62045 Mdot
.49428 .37827 Mdot
.53798 .40181 Mdot
.51204 .39934 Mdot
.4749 .33403 Mdot
.32617 .4617 Mdot
.41747 .25818 Mdot
.40886 .68922 Mdot
.60077 .32431 Mdot
.37267 .66744 Mdot
.56041 .66387 Mdot
.59314 .54855 Mdot
.3003 .46289 Mdot
.76139 .50811 Mdot
.43363 .62049 Mdot
.56589 .29626 Mdot
.54911 .65006 Mdot
.64727 .4418 Mdot
.69595 .5138 Mdot
.62702 .50725 Mdot
.76352 .48229 Mdot
.58379 .66011 Mdot
.39151 .66914 Mdot
.52438 .40707 Mdot
.28189 .4958 Mdot
.30418 .47899 Mdot
.50527 .3424 Mdot
.31487 .65658 Mdot
.37784 .70191 Mdot
.51983 .68457 Mdot
.52569 .40283 Mdot
.47093 .35818 Mdot
.28579 .52248 Mdot
.58098 .63679 Mdot
.56554 .41185 Mdot
.72596 .49605 Mdot
.49794 .34624 Mdot
.61639 .54906 Mdot
.60466 .36778 Mdot
.40367 .69306 Mdot
.6083 .53857 Mdot
.49959 .38721 Mdot
.60052 .35968 Mdot
.41671 .28976 Mdot
.67516 .51332 Mdot
.59979 .66756 Mdot
.47775 .34641 Mdot
.5152 .35237 Mdot
.32241 .46545 Mdot
.37127 .66602 Mdot
.32017 .4887 Mdot
.28569 .55658 Mdot
.62633 .52992 Mdot
.36049 .67963 Mdot
.4751 .33458 Mdot
.39942 .70559 Mdot
.43643 .27916 Mdot
.51973 .37412 Mdot
.39793 .6886 Mdot
.2885 .5107 Mdot
.20246 .59464 Mdot
.4032 .3474 Mdot
.42859 .28073 Mdot
.51784 .39263 Mdot
.53941 .7337 Mdot
.58688 .53946 Mdot
.50731 .40623 Mdot
.30572 .47667 Mdot
.51611 .38706 Mdot
.42171 .68297 Mdot
.75397 .48732 Mdot
.31136 .48583 Mdot
.59319 .63878 Mdot
.55911 .69077 Mdot
.59122 .68593 Mdot
.63221 .50513 Mdot
.43856 .28519 Mdot
.32432 .46943 Mdot
.30972 .46896 Mdot
.5937 .38334 Mdot
.55371 .68501 Mdot
.73716 .49023 Mdot
.52132 .3525 Mdot
.62694 .54911 Mdot
.35327 .68062 Mdot
.3092 .25592 Mdot
.61692 .33632 Mdot
.74387 .47605 Mdot
.57468 .42682 Mdot
.62144 .52661 Mdot
.48516 .3807 Mdot
.76786 .49465 Mdot
.58176 .6749 Mdot
.42501 .29304 Mdot
.7076 .52431 Mdot
.53141 .65688 Mdot
.56942 .64446 Mdot
.40049 .70433 Mdot
.60405 .64983 Mdot
.77092 .49644 Mdot
.6082 .50352 Mdot
.30763 .48155 Mdot
.49673 .3581 Mdot
.62662 .51758 Mdot
.54365 .68228 Mdot
.64231 .52914 Mdot
.50991 .40269 Mdot
.29084 .52322 Mdot
.54325 .66306 Mdot
.52237 .36999 Mdot
.40363 .25416 Mdot
.34431 .30809 Mdot
.58464 .63405 Mdot
.4921 .40187 Mdot
.69382 .53603 Mdot
.56073 .64873 Mdot
.58031 .65573 Mdot
.47581 .34605 Mdot
.73037 .5196 Mdot
.50098 .37449 Mdot
.3965 .67035 Mdot
.61154 .37101 Mdot
.36291 .67583 Mdot
.69312 .41744 Mdot
.49111 .33968 Mdot
.44965 .33563 Mdot
.30558 .43386 Mdot
.79837 .49246 Mdot
.69396 .39177 Mdot
.47953 .36776 Mdot
.26688 .51151 Mdot
.61623 .36416 Mdot
.63509 .38172 Mdot
.25919 .53858 Mdot
.74717 .48184 Mdot
.38066 .6904 Mdot
.52589 .36188 Mdot
.22726 .6183 Mdot
.73339 .48733 Mdot
.68989 .41817 Mdot
.45427 .33028 Mdot
.311 .49554 Mdot
.53373 .39838 Mdot
.30228 .48629 Mdot
.50865 .39201 Mdot
.34974 .32648 Mdot
.35072 .61226 Mdot
.57848 .29367 Mdot
.61384 .50464 Mdot
.34587 .71359 Mdot
.39133 .29994 Mdot
.74327 .49408 Mdot
.40111 .27062 Mdot
.62004 .5315 Mdot
.38672 .66693 Mdot
.43863 .65441 Mdot
.54689 .669 Mdot
.41057 .67163 Mdot
.31393 .51105 Mdot
.55454 .64252 Mdot
.64172 .53744 Mdot
.45021 .28529 Mdot
.77029 .50271 Mdot
.36022 .6799 Mdot
.5024 .35538 Mdot
.51691 .33954 Mdot
.5427 .73835 Mdot
.64984 .77487 Mdot
.33096 .51541 Mdot
.32609 .27137 Mdot
.30669 .55655 Mdot
.73332 .50649 Mdot
.58224 .63296 Mdot
.52453 .39737 Mdot
.48573 .36224 Mdot
.5732 .64323 Mdot
.28506 .47182 Mdot
.70708 .51266 Mdot
.68783 .49845 Mdot
.41887 .68371 Mdot
.68366 .76936 Mdot
.31061 .48459 Mdot
.68196 .77081 Mdot
.60489 .7768 Mdot
.19924 .52119 Mdot
.69361 .39482 Mdot
.3983 .67795 Mdot
.68305 .77046 Mdot
.3081 .49847 Mdot
.48186 .38527 Mdot
.62098 .53996 Mdot
.6375 .51009 Mdot
.29208 .52017 Mdot
.56021 .6594 Mdot
.73034 .52008 Mdot
.53511 .38588 Mdot
.67371 .52843 Mdot
.2597 .49859 Mdot
.56792 .70642 Mdot
.60636 .52144 Mdot
.38788 .69919 Mdot
.51605 .38986 Mdot
.71431 .49516 Mdot
.3965 .67804 Mdot
.5927 .52852 Mdot
.59029 .30973 Mdot
.46971 .37955 Mdot
.43104 .25655 Mdot
.37948 .68456 Mdot
.5725 .40703 Mdot
.50477 .34926 Mdot
.37084 .66778 Mdot
.65466 .5181 Mdot
.35055 .72526 Mdot
.56849 .41158 Mdot
.32801 .61901 Mdot
.54459 .64923 Mdot
.60414 .64089 Mdot
.59276 .60752 Mdot
.53051 .72554 Mdot
.38296 .6626 Mdot
.61956 .51777 Mdot
.63678 .78578 Mdot
.36949 .66756 Mdot
.46141 .34128 Mdot
.52617 .36336 Mdot
.4156 .3641 Mdot
.59263 .53131 Mdot
.5981 .52245 Mdot
.37091 .50141 Mdot
.40897 .25917 Mdot
.60777 .52128 Mdot
.49408 .35045 Mdot
.30211 .46575 Mdot
.40483 .68473 Mdot
.82898 .41089 Mdot
.42546 .6627 Mdot
.43601 .29454 Mdot
.54662 .65484 Mdot
.54866 .64513 Mdot
.49907 .35892 Mdot
.49245 .63348 Mdot
.78344 .30001 Mdot
.52641 .3633 Mdot
.42343 .25375 Mdot
.69268 .41974 Mdot
.50906 .34289 Mdot
.33469 .50412 Mdot
.60578 .54444 Mdot
.31044 .46464 Mdot
.39721 .68174 Mdot
.74596 .48209 Mdot
.79708 .49894 Mdot
.38156 .69021 Mdot
.49303 .37442 Mdot
.58665 .51689 Mdot
.50771 .36519 Mdot
.49096 .39154 Mdot
.60415 .35812 Mdot
.73834 .47812 Mdot
.55214 .66335 Mdot
.76436 .50625 Mdot
.27406 .4967 Mdot
.3199 .26571 Mdot
.74362 .49178 Mdot
.41823 .3502 Mdot
.6028 .37706 Mdot
.64164 .77698 Mdot
.30562 .47886 Mdot
.73463 .48305 Mdot
.37749 .68938 Mdot
.61037 .39807 Mdot
.42658 .33979 Mdot
.41323 .67521 Mdot
.49475 .39296 Mdot
.30062 .46964 Mdot
.33708 .54876 Mdot
.3714 .70228 Mdot
.32288 .48073 Mdot
.56971 .40905 Mdot
.42283 .27976 Mdot
.40728 .69195 Mdot
.68246 .37975 Mdot
.35924 .68818 Mdot
.39214 .31866 Mdot
.43442 .27578 Mdot
.31153 .48757 Mdot
.3795 .26324 Mdot
.30231 .55466 Mdot
.5963 .51736 Mdot
.48089 .3888 Mdot
.73898 .49179 Mdot
.59688 .38053 Mdot
.59431 .63638 Mdot
.3479 .486 Mdot
.29497 .49517 Mdot
.35235 .67725 Mdot
.32075 .48011 Mdot
.31313 .52219 Mdot
.43793 .66505 Mdot
.32934 .50487 Mdot
.49589 .37412 Mdot
.33309 .23582 Mdot
.32958 .48441 Mdot
.3873 .68347 Mdot
.71657 .49731 Mdot
.33557 .48504 Mdot
.59297 .77113 Mdot
.50086 .34436 Mdot
.54361 .69904 Mdot
.72173 .52163 Mdot
.32148 .4608 Mdot
.74001 .4944 Mdot
.54131 .67818 Mdot
.69927 .49886 Mdot
.34971 .69352 Mdot
.36064 .70156 Mdot
.64428 .55052 Mdot
.33149 .6159 Mdot
.27292 .49718 Mdot
.56204 .63816 Mdot
.53198 .36454 Mdot
.51597 .40227 Mdot
.78085 .49913 Mdot
.27199 .52295 Mdot
.31293 .66731 Mdot
.61192 .52224 Mdot
.37897 .45612 Mdot
.38886 .70116 Mdot
.52023 .68287 Mdot
.62218 .33726 Mdot
.42603 .62923 Mdot
.60277 .54646 Mdot
.62184 .52843 Mdot
.50749 .36136 Mdot
.66836 .43499 Mdot
.76635 .48965 Mdot
.40795 .75137 Mdot
.41819 .28549 Mdot
.58097 .64255 Mdot
.50222 .39242 Mdot
.40937 .26856 Mdot
.47694 .36064 Mdot
.75339 .47613 Mdot
.41246 .66602 Mdot
.29905 .48119 Mdot
.73938 .48134 Mdot
.55963 .69101 Mdot
.58699 .26457 Mdot
.50918 .40741 Mdot
.50661 .41075 Mdot
.55917 .65403 Mdot
.27673 .48984 Mdot
.55817 .66964 Mdot
.37183 .66719 Mdot
.74786 .491 Mdot
.43512 .28455 Mdot
.59289 .53217 Mdot
.54223 .70542 Mdot
.39711 .66606 Mdot
.58961 .6325 Mdot
.41036 .70169 Mdot
.62415 .53076 Mdot
.49263 .40401 Mdot
.56863 .71115 Mdot
.63531 .53642 Mdot
.36847 .39798 Mdot
.58922 .31262 Mdot
.20648 .50811 Mdot
.56235 .65701 Mdot
.61492 .6837 Mdot
.39299 .67989 Mdot
.41417 .654 Mdot
.38803 .31415 Mdot
.73568 .24719 Mdot
.56189 .41063 Mdot
.3148 .69822 Mdot
.37274 .66597 Mdot
.38055 .67834 Mdot
.55501 .66962 Mdot
.28863 .51186 Mdot
.2927 .43644 Mdot
.53564 .66832 Mdot
.6878 .40553 Mdot
.31092 .50145 Mdot
.44164 .33898 Mdot
.54985 .71389 Mdot
.42698 .26583 Mdot
.35146 .33711 Mdot
.71013 .49418 Mdot
.67649 .42718 Mdot
.43292 .68063 Mdot
.52839 .37601 Mdot
.20552 .61878 Mdot
.54701 .67242 Mdot
.64015 .52998 Mdot
.39154 .74337 Mdot
.51224 .33585 Mdot
.49631 .38997 Mdot
.50969 .38034 Mdot
.77493 .50475 Mdot
.36051 .3701 Mdot
.53089 .38748 Mdot
.58351 .30297 Mdot
.44213 .28759 Mdot
.59977 .62462 Mdot
.76542 .50403 Mdot
.63673 .44406 Mdot
.58244 .75926 Mdot
.3786 .46438 Mdot
.47603 .32366 Mdot
.41877 .66106 Mdot
.40964 .25961 Mdot
.3949 .69196 Mdot
.3957 .70266 Mdot
.69862 .76301 Mdot
.30485 .47497 Mdot
.42279 .28581 Mdot
.58586 .67914 Mdot
.29935 .43383 Mdot
.41173 .27036 Mdot
.32226 .26795 Mdot
.38062 .65154 Mdot
.72079 .21857 Mdot
.40792 .65195 Mdot
.64142 .51984 Mdot
.31781 .51096 Mdot
.26351 .50933 Mdot
.60156 .37198 Mdot
.27877 .50402 Mdot
.53219 .72678 Mdot
.32534 .47067 Mdot
.81227 .62042 Mdot
.26422 .54259 Mdot
.38912 .67751 Mdot
.36132 .69829 Mdot
.41823 .26199 Mdot
.49417 .36979 Mdot
.61578 .32032 Mdot
.61115 .52264 Mdot
.46874 .37652 Mdot
.57522 .6649 Mdot
.59718 .77389 Mdot
.33853 .75853 Mdot
.3259 .50939 Mdot
.3937 .66358 Mdot
.49827 .39121 Mdot
.43431 .27786 Mdot
.48094 .38682 Mdot
.38591 .61425 Mdot
.40023 .28747 Mdot
.51307 .37215 Mdot
.41717 .26474 Mdot
.5395 .6619 Mdot
.54539 .73796 Mdot
.199 .5266 Mdot
.69176 .7657 Mdot
.48114 .35811 Mdot
.72545 .50764 Mdot
.75465 .47698 Mdot
.5518 .40328 Mdot
.55318 .55822 Mdot
.57432 .40679 Mdot
.50382 .35561 Mdot
.58403 .26125 Mdot
.53028 .68007 Mdot
.6266 .49919 Mdot
.54606 .6842 Mdot
.2541 .51793 Mdot
.60654 .50059 Mdot
.57994 .66543 Mdot
.60386 .29046 Mdot
.62697 .52392 Mdot
.3545 .73116 Mdot
.72647 .48776 Mdot
.49709 .34906 Mdot
.38458 .33751 Mdot
.56279 .71233 Mdot
.39132 .67176 Mdot
.32739 .50111 Mdot
.40568 .69032 Mdot
.53283 .72458 Mdot
.69237 .41016 Mdot
.59514 .52485 Mdot
.42275 .66424 Mdot
.43418 .25661 Mdot
.72188 .50826 Mdot
.39694 .65074 Mdot
.44122 .28414 Mdot
.55409 .40036 Mdot
.75865 .27899 Mdot
.54222 .38938 Mdot
.59848 .7748 Mdot
.36487 .67152 Mdot
.63078 .4989 Mdot
.49634 .35908 Mdot
.55564 .70643 Mdot
.6448 .56021 Mdot
.51034 .3659 Mdot
.59555 .64387 Mdot
.51837 .35713 Mdot
.76718 .49618 Mdot
.31777 .46427 Mdot
.6195 .36191 Mdot
.78457 .4788 Mdot
.743 .48202 Mdot
.56164 .29415 Mdot
.48878 .39607 Mdot
.48481 .6651 Mdot
.31427 .49425 Mdot
.47428 .3661 Mdot
.78317 .47513 Mdot
.30086 .5166 Mdot
.31855 .50415 Mdot
.42961 .29423 Mdot
.42443 .68049 Mdot
.55448 .65946 Mdot
.73776 .51193 Mdot
.56555 .75325 Mdot
.52706 .37581 Mdot
.40443 .27696 Mdot
.73463 .48508 Mdot
.40409 .67481 Mdot
.42412 .28423 Mdot
.32514 .73011 Mdot
.59941 .32199 Mdot
.38847 .6512 Mdot
.47567 .32518 Mdot
.38677 .25905 Mdot
.27314 .48278 Mdot
.21029 .6205 Mdot
.35 .61296 Mdot
.55381 .69318 Mdot
.60765 .51931 Mdot
.3117 .25996 Mdot
.71697 .49318 Mdot
.2784 .43957 Mdot
.51292 .4028 Mdot
.51758 .39711 Mdot
.29904 .46613 Mdot
.53297 .41127 Mdot
.32235 .51404 Mdot
.59233 .76972 Mdot
.73274 .2403 Mdot
.30289 .48221 Mdot
.30137 .49404 Mdot
.44659 .2968 Mdot
.54139 .72193 Mdot
.3041 .52002 Mdot
.52519 .35924 Mdot
.53276 .72471 Mdot
.67131 .5196 Mdot
.71056 .51213 Mdot
.76021 .51669 Mdot
.32986 .51249 Mdot
.42472 .33444 Mdot
.43674 .26844 Mdot
.42615 .41726 Mdot
.57709 .42792 Mdot
.3828 .66189 Mdot
.51419 .34106 Mdot
.61542 .52473 Mdot
.54411 .67819 Mdot
.54542 .39129 Mdot
.49275 .34988 Mdot
.29367 .48355 Mdot
.70308 .49751 Mdot
.3656 .68034 Mdot
.63629 .53339 Mdot
.59091 .68794 Mdot
.73217 .5006 Mdot
.30131 .52676 Mdot
.39112 .30413 Mdot
.58767 .53501 Mdot
.62929 .54706 Mdot
.48187 .3766 Mdot
.47626 .34888 Mdot
.59529 .54221 Mdot
.38495 .69024 Mdot
.55276 .69432 Mdot
.63473 .51751 Mdot
.59024 .38954 Mdot
.61495 .30953 Mdot
.48434 .37473 Mdot
.32563 .47535 Mdot
.38969 .6652 Mdot
.59672 .52266 Mdot
.63345 .78648 Mdot
.51913 .34952 Mdot
.43874 .33178 Mdot
.66251 .4883 Mdot
.61787 .52172 Mdot
.29288 .43626 Mdot
.75003 .51352 Mdot
.4342 .27598 Mdot
.58187 .29943 Mdot
.45733 .35188 Mdot
.48655 .326 Mdot
.58316 .67063 Mdot
.37674 .69514 Mdot
.64338 .54897 Mdot
.55082 .68234 Mdot
.32084 .50249 Mdot
.43316 .42086 Mdot
.29558 .47479 Mdot
.31134 .46964 Mdot
.35056 .47948 Mdot
.39769 .6968 Mdot
.31126 .25804 Mdot
.59438 .54356 Mdot
.53328 .40229 Mdot
.40241 .65922 Mdot
.30623 .52105 Mdot
.45555 .34024 Mdot
.31779 .51793 Mdot
.27564 .52543 Mdot
.45792 .3542 Mdot
.42028 .26792 Mdot
.57562 .29702 Mdot
.42955 .32253 Mdot
.75974 .51198 Mdot
.27477 .48366 Mdot
.43275 .33448 Mdot
.52695 .39535 Mdot
.48842 .35699 Mdot
.41802 .26049 Mdot
.74915 .47928 Mdot
.45455 .43149 Mdot
.50859 .40113 Mdot
.6724 .43648 Mdot
.45706 .34 Mdot
.27041 .52224 Mdot
.35883 .72347 Mdot
.43691 .29475 Mdot
.54777 .64937 Mdot
.28764 .47059 Mdot
.70993 .49358 Mdot
.34417 .46201 Mdot
.41998 .24928 Mdot
.37472 .67835 Mdot
.30046 .49761 Mdot
.53427 .67839 Mdot
.39505 .6725 Mdot
.35925 .68866 Mdot
.41985 .25907 Mdot
.56086 .69636 Mdot
.70372 .49646 Mdot
.36524 .69364 Mdot
.41622 .24396 Mdot
.38915 .67626 Mdot
.22426 .47696 Mdot
.50952 .41285 Mdot
.58445 .30225 Mdot
.61451 .51051 Mdot
.65125 .53978 Mdot
.36224 .68165 Mdot
.72515 .49496 Mdot
.42335 .28439 Mdot
.33255 .49202 Mdot
.71933 .50344 Mdot
.35298 .34 Mdot
.54901 .64528 Mdot
.33672 .54869 Mdot
.55543 .7482 Mdot
.27726 .50908 Mdot
.67931 .42518 Mdot
.71975 .48568 Mdot
.62085 .55263 Mdot
.61506 .35216 Mdot
.60435 .52382 Mdot
.54512 .39732 Mdot
.42185 .28456 Mdot
.4966 .37542 Mdot
.54885 .65178 Mdot
.77405 .50569 Mdot
.32913 .48018 Mdot
.71892 .53201 Mdot
.40846 .67957 Mdot
.55598 .41397 Mdot
.63946 .52358 Mdot
.43003 .2812 Mdot
.31433 .51796 Mdot
.27262 .51459 Mdot
.35881 .35799 Mdot
.55948 .6483 Mdot
.74765 .52539 Mdot
.4863 .37634 Mdot
.67888 .536 Mdot
.36182 .6804 Mdot
.32887 .61701 Mdot
.53721 .69446 Mdot
.71792 .21744 Mdot
.55473 .68338 Mdot
.67564 .51029 Mdot
.27694 .51435 Mdot
.75937 .49931 Mdot
.48871 .37052 Mdot
.32802 .46564 Mdot
.29014 .43678 Mdot
.73954 .5225 Mdot
.75965 .5087 Mdot
.36094 .61144 Mdot
.39292 .65743 Mdot
.63243 .54228 Mdot
.45798 .33978 Mdot
.45429 .33689 Mdot
.53368 .36806 Mdot
.39553 .66091 Mdot
.42268 .27529 Mdot
.35467 .71785 Mdot
.41356 .25184 Mdot
.78271 .47477 Mdot
.58055 .65231 Mdot
.42949 .81686 Mdot
.31521 .46181 Mdot
.44658 .4278 Mdot
.26721 .43976 Mdot
.59181 .3159 Mdot
.41663 .66876 Mdot
.65519 .51796 Mdot
.55424 .66542 Mdot
.45268 .66761 Mdot
.58281 .65334 Mdot
.82064 .36865 Mdot
.41446 .36438 Mdot
.35794 .72539 Mdot
.47023 .3777 Mdot
.57757 .68942 Mdot
.42042 .32564 Mdot
.63325 .51694 Mdot
.58697 .51603 Mdot
.3969 .25882 Mdot
.33695 .28233 Mdot
.76279 .51025 Mdot
.48832 .37145 Mdot
.30748 .46539 Mdot
.4878 .36815 Mdot
.48679 .36796 Mdot
.49798 .39791 Mdot
.43906 .66521 Mdot
.49194 .40316 Mdot
.49488 .37161 Mdot
.61185 .78146 Mdot
.66303 .5322 Mdot
.60463 .65245 Mdot
.26148 .49676 Mdot
.71705 .50686 Mdot
.25454 .51804 Mdot
.61784 .35733 Mdot
.4208 .65544 Mdot
.35851 .36218 Mdot
.4281 .27311 Mdot
.34467 .49438 Mdot
.42172 .66021 Mdot
.70817 .51738 Mdot
.61752 .52753 Mdot
.18767 .55583 Mdot
.5242 .71509 Mdot
.60846 .53429 Mdot
.58981 .63916 Mdot
.44774 .32054 Mdot
.31027 .48143 Mdot
.6052 .52413 Mdot
.36804 .68903 Mdot
.58641 .66414 Mdot
.56543 .295 Mdot
.51934 .38436 Mdot
.56712 .6557 Mdot
.62288 .51653 Mdot
.59751 .37998 Mdot
.61508 .36493 Mdot
.57841 .68913 Mdot
.40886 .69701 Mdot
.36125 .69434 Mdot
.71249 .5031 Mdot
.26866 .50651 Mdot
.27901 .49383 Mdot
.40698 .6798 Mdot
.45607 .66832 Mdot
.52399 .37125 Mdot
.52135 .37718 Mdot
.61956 .3442 Mdot
.46721 .35484 Mdot
.53197 .72809 Mdot
.60966 .53283 Mdot
.28613 .49378 Mdot
.42118 .28436 Mdot
.40929 .27762 Mdot
.49066 .37522 Mdot
.69245 .40281 Mdot
.54251 .66218 Mdot
.43429 .26505 Mdot
.76774 .49404 Mdot
.34351 .30029 Mdot
.50531 .34651 Mdot
.77059 .47351 Mdot
.27295 .51068 Mdot
.37926 .75039 Mdot
.38945 .67198 Mdot
.58479 .68393 Mdot
.58528 .68158 Mdot
.73074 .6917 Mdot
.31231 .46212 Mdot
.60795 .53335 Mdot
.53452 .65223 Mdot
.62211 .50161 Mdot
.7557 .51011 Mdot
.56645 .44292 Mdot
.53284 .72787 Mdot
.60451 .65188 Mdot
.34871 .6989 Mdot
.49931 .33214 Mdot
.49588 .34602 Mdot
.32596 .62109 Mdot
.49241 .35474 Mdot
.74363 .48807 Mdot
.39177 .65452 Mdot
.30253 .49768 Mdot
.74652 .51692 Mdot
.41368 .65762 Mdot
.27585 .4977 Mdot
.42318 .26084 Mdot
.45598 .33866 Mdot
.3238 .50222 Mdot
.29394 .52667 Mdot
.52443 .36818 Mdot
.71138 .75769 Mdot
.293 .4862 Mdot
.32365 .50607 Mdot
.34232 .29709 Mdot
.58305 .69535 Mdot
.64992 .55527 Mdot
.42474 .67696 Mdot
.50116 .3758 Mdot
.57565 .64991 Mdot
.75244 .5064 Mdot
.29276 .49723 Mdot
.47768 .35511 Mdot
.527 .37833 Mdot
.72242 .50776 Mdot
.77066 .49151 Mdot
.72123 .49791 Mdot
.37351 .70272 Mdot
.42811 .26866 Mdot
.31167 .5168 Mdot
.40978 .66834 Mdot
.71625 .48994 Mdot
.77272 .49914 Mdot
.7943 .47731 Mdot
.52328 .36875 Mdot
.77139 .49029 Mdot
.31775 .26461 Mdot
.59913 .28481 Mdot
.6184 .50015 Mdot
.61227 .64823 Mdot
.57419 .71039 Mdot
.66142 .50798 Mdot
.37599 .69369 Mdot
.4181 .25326 Mdot
.7111 .51425 Mdot
.62907 .5171 Mdot
.52148 .3806 Mdot
.50262 .33981 Mdot
.72451 .50498 Mdot
.69484 .40982 Mdot
.29235 .4824 Mdot
.20394 .51498 Mdot
.71932 .50796 Mdot
.57119 .69962 Mdot
.52974 .68342 Mdot
.56055 .67809 Mdot
.48262 .37071 Mdot
.44807 .34632 Mdot
.57357 .42069 Mdot
.37681 .42387 Mdot
.3855 .65934 Mdot
.27587 .51757 Mdot
.33971 .29596 Mdot
.31635 .50504 Mdot
.56304 .64251 Mdot
.72574 .49434 Mdot
.29164 .47075 Mdot
.36606 .69917 Mdot
.36146 .69147 Mdot
.57093 .70901 Mdot
.55476 .68602 Mdot
.56544 .66779 Mdot
.30893 .46048 Mdot
.29092 .52152 Mdot
.46364 .36577 Mdot
.32003 .47502 Mdot
.5933 .76419 Mdot
.59121 .76922 Mdot
.56522 .71223 Mdot
.38985 .68653 Mdot
.28979 .50743 Mdot
.51672 .35408 Mdot
.55641 .29968 Mdot
.5288 .68791 Mdot
.70541 .50223 Mdot
.33255 .23639 Mdot
.73778 .2519 Mdot
.40302 .26843 Mdot
.37597 .67055 Mdot
.60852 .50525 Mdot
.50684 .38162 Mdot
.55007 .69278 Mdot
.5869 .49492 Mdot
.60417 .54262 Mdot
.52976 .41622 Mdot
.45196 .30782 Mdot
.38235 .66922 Mdot
.62052 .35717 Mdot
.63265 .51941 Mdot
.44322 .28563 Mdot
.39866 .65472 Mdot
.54476 .70814 Mdot
.59601 .61391 Mdot
.37345 .49331 Mdot
.59327 .44381 Mdot
.59272 .52099 Mdot
.529 .35778 Mdot
.57716 .6696 Mdot
.73948 .51831 Mdot
.57382 .66953 Mdot
.27629 .52855 Mdot
.58048 .69947 Mdot
.51161 .35297 Mdot
.30812 .5176 Mdot
.36067 .69053 Mdot
.60157 .40521 Mdot
.78311 .51278 Mdot
.554 .70843 Mdot
.61379 .55332 Mdot
.40726 .26508 Mdot
.44967 .27852 Mdot
.65161 .53954 Mdot
.49918 .34768 Mdot
.3979 .68919 Mdot
.32156 .5136 Mdot
.40565 .67229 Mdot
.64213 .56155 Mdot
.23567 .46074 Mdot
.38795 .67162 Mdot
.45046 .35101 Mdot
.7323 .52009 Mdot
.69302 .40744 Mdot
.51133 .35589 Mdot
.37128 .6934 Mdot
.51227 .41299 Mdot
.27812 .47928 Mdot
.60829 .29898 Mdot
.59768 .3203 Mdot
.4036 .68637 Mdot
.64549 .53288 Mdot
.60241 .3782 Mdot
.64761 .55801 Mdot
.37224 .66751 Mdot
.59982 .27965 Mdot
.61527 .53827 Mdot
.73892 .50068 Mdot
.77254 .50614 Mdot
.73271 .49752 Mdot
.5154 .37443 Mdot
.3848 .25716 Mdot
.72819 .48265 Mdot
.43711 .6548 Mdot
.74882 .48508 Mdot
.66557 .51529 Mdot
.31249 .66216 Mdot
.77082 .49669 Mdot
.49781 .35332 Mdot
.41378 .25206 Mdot
.41852 .25384 Mdot
.54031 .69183 Mdot
.18684 .57012 Mdot
.61118 .78095 Mdot
.52373 .39783 Mdot
.33338 .2861 Mdot
.32065 .46683 Mdot
.61212 .55425 Mdot
.59618 .31873 Mdot
.43493 .25964 Mdot
.31085 .50944 Mdot
.61714 .3538 Mdot
.35418 .5303 Mdot
.62289 .50696 Mdot
.51734 .37278 Mdot
.29082 .46924 Mdot
.34858 .48667 Mdot
.69299 .39108 Mdot
.37793 .46984 Mdot
.28184 .50398 Mdot
.37141 .6657 Mdot
.37711 .6921 Mdot
.39972 .68864 Mdot
.55732 .6888 Mdot
.29905 .49448 Mdot
.55534 .39475 Mdot
.55263 .69197 Mdot
.49789 .39534 Mdot
.40565 .68396 Mdot
.59482 .31238 Mdot
.30195 .4946 Mdot
.50816 .35627 Mdot
.43209 .33949 Mdot
.59488 .64615 Mdot
.72255 .50703 Mdot
.3295 .27429 Mdot
.60148 .63399 Mdot
.40349 .70377 Mdot
.27502 .52915 Mdot
.66235 .52433 Mdot
.44405 .27854 Mdot
.47553 .36133 Mdot
.52343 .40762 Mdot
.4444 .28111 Mdot
.41405 .35885 Mdot
.62086 .54693 Mdot
.55962 .69082 Mdot
.58996 .68437 Mdot
.51244 .3471 Mdot
.29702 .49129 Mdot
.74035 .47516 Mdot
.70105 .4886 Mdot
.71624 .52571 Mdot
.60787 .37147 Mdot
.5839 .30327 Mdot
.46976 .34067 Mdot
.47662 .43583 Mdot
.53626 .68454 Mdot
.63271 .50296 Mdot
.6063 .36664 Mdot
.74432 .49591 Mdot
.48402 .38732 Mdot
.25627 .50858 Mdot
.29534 .4992 Mdot
.56012 .65773 Mdot
.36145 .66901 Mdot
.58659 .53123 Mdot
.56294 .714 Mdot
.5114 .34668 Mdot
.41401 .28154 Mdot
.37442 .66 Mdot
.29973 .52923 Mdot
.73434 .50363 Mdot
.547 .68949 Mdot
.75548 .49593 Mdot
.32116 .48158 Mdot
.29157 .4972 Mdot
.47287 .37291 Mdot
.74578 .52698 Mdot
.55086 .7105 Mdot
.48386 .3695 Mdot
.57036 .6579 Mdot
.54339 .7385 Mdot
.35201 .68112 Mdot
.47471 .36975 Mdot
.29775 .43578 Mdot
.40238 .69044 Mdot
.51377 .39879 Mdot
.41864 .25616 Mdot
.42432 .28382 Mdot
.57478 .69385 Mdot
.70086 .50727 Mdot
.7467 .49904 Mdot
.28615 .431 Mdot
.35234 .35761 Mdot
.47871 .33254 Mdot
.57336 .70386 Mdot
.39762 .24905 Mdot
.37919 .67521 Mdot
.27823 .51246 Mdot
.37583 .79126 Mdot
.38634 .68192 Mdot
.52068 .35978 Mdot
.74325 .49128 Mdot
.28652 .5272 Mdot
.61284 .49888 Mdot
.6464 .37529 Mdot
.64676 .53914 Mdot
.7359 .52766 Mdot
.63317 .53714 Mdot
.31542 .6922 Mdot
.5684 .66702 Mdot
.31057 .51959 Mdot
.37382 .67134 Mdot
.37646 .67691 Mdot
.58352 .6372 Mdot
.3544 .34063 Mdot
.19953 .52292 Mdot
.31511 .24802 Mdot
.52164 .7066 Mdot
.73176 .49147 Mdot
.60583 .29732 Mdot
.55887 .67806 Mdot
.59802 .63795 Mdot
.38798 .61409 Mdot
.32717 .61819 Mdot
.29216 .51076 Mdot
.52837 .38207 Mdot
.345 .31023 Mdot
.52164 .40464 Mdot
.59089 .44391 Mdot
.40465 .67822 Mdot
.27784 .51197 Mdot
.33984 .61191 Mdot
.48485 .34145 Mdot
.5069 .38943 Mdot
.59586 .76679 Mdot
.61157 .52563 Mdot
.65488 .76965 Mdot
.49075 .39531 Mdot
.56709 .68276 Mdot
.32949 .43782 Mdot
.62192 .50907 Mdot
.43004 .33529 Mdot
.36786 .6668 Mdot
.59571 .52459 Mdot
.62571 .51015 Mdot
.4789 .43503 Mdot
.32203 .55644 Mdot
.28035 .48311 Mdot
.7658 .4839 Mdot
.32048 .62191 Mdot
.38564 .65291 Mdot
.322 .72064 Mdot
.51695 .35325 Mdot
.36255 .7011 Mdot
.68761 .4994 Mdot
.51749 .39981 Mdot
.41285 .2695 Mdot
.35842 .35912 Mdot
.51669 .34146 Mdot
.41161 .24883 Mdot
.39099 .68093 Mdot
.70675 .4703 Mdot
.47906 .32905 Mdot
.56429 .65668 Mdot
.28897 .5126 Mdot
.30557 .55903 Mdot
.72615 .5171 Mdot
.34643 .61278 Mdot
.7273 .23012 Mdot
.27887 .51241 Mdot
.5183 .38179 Mdot
.38049 .67659 Mdot
.59964 .50794 Mdot
.61122 .51122 Mdot
.63294 .54967 Mdot
.29583 .50193 Mdot
.62193 .51018 Mdot
.29401 .43258 Mdot
.61779 .35489 Mdot
.44336 .4265 Mdot
.3924 .69675 Mdot
.73473 .49138 Mdot
.68165 .51807 Mdot
.54576 .74002 Mdot
.46 .3395 Mdot
.59147 .44404 Mdot
.35399 .4806 Mdot
.73918 .48941 Mdot
.49864 .37875 Mdot
.62473 .54705 Mdot
.57983 .25469 Mdot
.72982 .47507 Mdot
.6312 .5397 Mdot
.41997 .28909 Mdot
.27339 .49736 Mdot
.6039 .53046 Mdot
.3044 .49957 Mdot
.49554 .3776 Mdot
.57561 .40428 Mdot
.27057 .49581 Mdot
.19293 .58296 Mdot
.58964 .54046 Mdot
.41134 .65474 Mdot
.5418 .41686 Mdot
.48083 .35663 Mdot
.44478 .34032 Mdot
.5995 .51049 Mdot
.2176 .61808 Mdot
.57572 .65483 Mdot
.64239 .78492 Mdot
.52784 .7227 Mdot
.38436 .61455 Mdot
.32799 .73985 Mdot
.47991 .34051 Mdot
.35478 .3393 Mdot
.44648 .34228 Mdot
.41696 .68306 Mdot
.44273 .3287 Mdot
.49433 .36996 Mdot
.48287 .37779 Mdot
.56984 .65725 Mdot
.36367 .6608 Mdot
.43244 .29459 Mdot
.60621 .36764 Mdot
.70134 .51538 Mdot
.32012 .49047 Mdot
.50403 .37292 Mdot
.34371 .50737 Mdot
.57611 .69458 Mdot
.20297 .50448 Mdot
.49976 .35461 Mdot
.6119 .52606 Mdot
.36558 .70183 Mdot
.36044 .68497 Mdot
.56638 .69975 Mdot
.56248 .70248 Mdot
.48109 .35686 Mdot
.41161 .67563 Mdot
.46225 .33284 Mdot
.60142 .37888 Mdot
.62531 .51813 Mdot
.74794 .51048 Mdot
.5375 .40406 Mdot
.20108 .51987 Mdot
.81336 .47034 Mdot
.48352 .37219 Mdot
.29684 .47208 Mdot
.56248 .66607 Mdot
.56429 .64019 Mdot
.27937 .49554 Mdot
.56667 .63937 Mdot
.20016 .5104 Mdot
.38524 .25942 Mdot
.76053 .50602 Mdot
.41096 .22911 Mdot
.74511 .48241 Mdot
.59615 .52131 Mdot
.52287 .36769 Mdot
.43506 .73111 Mdot
.52114 .70784 Mdot
.51511 .24281 Mdot
.39897 .67401 Mdot
.6364 .50849 Mdot
.42418 .27352 Mdot
.72576 .52204 Mdot
.54592 .67531 Mdot
.58893 .51344 Mdot
.48673 .39078 Mdot
.29014 .46893 Mdot
.40873 .28352 Mdot
.63471 .51229 Mdot
.59894 .51678 Mdot
.59012 .51351 Mdot
.41399 .65777 Mdot
.33263 .49873 Mdot
.36125 .61136 Mdot
.59466 .65212 Mdot
.46865 .3768 Mdot
.51557 .38246 Mdot
.27572 .51627 Mdot
.53605 .39963 Mdot
.41065 .68617 Mdot
.30269 .25253 Mdot
.72279 .4941 Mdot
.60713 .50223 Mdot
.25087 .59202 Mdot
.59666 .50256 Mdot
.42948 .28878 Mdot
.4471 .28674 Mdot
.25965 .50016 Mdot
.4244 .66439 Mdot
.45754 .32166 Mdot
.59945 .66728 Mdot
.73798 .50286 Mdot
.36 .69595 Mdot
.41448 .27865 Mdot
.50388 .35182 Mdot
.73769 .49095 Mdot
.338 .61334 Mdot
.69179 .50993 Mdot
.37506 .66756 Mdot
.64759 .51786 Mdot
.54803 .2908 Mdot
.50926 .36266 Mdot
.61251 .53178 Mdot
.32919 .49176 Mdot
.39071 .65912 Mdot
.36183 .37141 Mdot
.62523 .50847 Mdot
.56361 .75295 Mdot
.36069 .6792 Mdot
.47487 .36141 Mdot
.34535 .46637 Mdot
.2743 .54939 Mdot
.32709 .50609 Mdot
.7723 .6694 Mdot
.57487 .76097 Mdot
.56648 .66434 Mdot
.38818 .6862 Mdot
.573 .64781 Mdot
.73402 .52008 Mdot
.6112 .31252 Mdot
.55849 .70603 Mdot
.33791 .4859 Mdot
.58279 .65071 Mdot
.46012 .3329 Mdot
.41539 .65572 Mdot
.54717 .71398 Mdot
.53933 .38445 Mdot
.42557 .26012 Mdot
.60045 .51903 Mdot
.72897 .4793 Mdot
.61333 .36223 Mdot
.5302 .37196 Mdot
.61788 .53186 Mdot
.50758 .3576 Mdot
.41104 .68489 Mdot
.59492 .4108 Mdot
.45543 .35026 Mdot
.52258 .70693 Mdot
.1896 .54444 Mdot
.58828 .68491 Mdot
.69819 .53534 Mdot
.51072 .40009 Mdot
.51277 .36279 Mdot
.41944 .27755 Mdot
.34148 .23171 Mdot
.39448 .70532 Mdot
.49339 .40475 Mdot
.56095 .63927 Mdot
.30702 .50771 Mdot
.3038 .4652 Mdot
.55674 .44223 Mdot
.61247 .53443 Mdot
.39082 .70189 Mdot
.51766 .36554 Mdot
.6296 .50549 Mdot
.60579 .33947 Mdot
.31912 .63183 Mdot
.5858 .76771 Mdot
.59777 .64283 Mdot
.26882 .48757 Mdot
.54252 .65982 Mdot
.4215 .27942 Mdot
.61732 .50803 Mdot
.57328 .76135 Mdot
.43235 .63593 Mdot
.74071 .50273 Mdot
.48852 .38591 Mdot
.69437 .39915 Mdot
.53891 .66308 Mdot
.55837 .69572 Mdot
.46121 .33222 Mdot
.34603 .44691 Mdot
.80568 .47373 Mdot
.40681 .66174 Mdot
.25654 .53065 Mdot
.38716 .32575 Mdot
.76065 .35303 Mdot
.37769 .68772 Mdot
.41083 .26854 Mdot
.53211 .67623 Mdot
.68252 .72159 Mdot
.31191 .5077 Mdot
.73792 .50364 Mdot
.54028 .39212 Mdot
.32703 .47384 Mdot
.52091 .70515 Mdot
.33084 .50682 Mdot
.60877 .52075 Mdot
.41852 .65783 Mdot
.542 .6748 Mdot
.37376 .65434 Mdot
.29926 .43611 Mdot
.72814 .49161 Mdot
.65705 .43712 Mdot
.40671 .25421 Mdot
.35755 .35759 Mdot
.42577 .26729 Mdot
.66293 .53525 Mdot
.42601 .26313 Mdot
.29508 .5567 Mdot
.50982 .35518 Mdot
.47548 .32621 Mdot
.54743 .6462 Mdot
.48023 .36956 Mdot
.5244 .3589 Mdot
.43325 .33926 Mdot
.49552 .3915 Mdot
.48623 .36904 Mdot
.47356 .35408 Mdot
.29217 .47826 Mdot
.4709 .37288 Mdot
.29557 .52528 Mdot
.33863 .51062 Mdot
.59483 .65052 Mdot
.77004 .50843 Mdot
.7699 .49422 Mdot
.57658 .40036 Mdot
.69359 .40013 Mdot
.34391 .30641 Mdot
.30863 .50418 Mdot
.36155 .68223 Mdot
.45671 .34811 Mdot
.80315 .48149 Mdot
.57532 .4018 Mdot
.54058 .69376 Mdot
.57313 .69981 Mdot
.5401 .38333 Mdot
.74054 .25727 Mdot
.4896 .39505 Mdot
.61773 .33681 Mdot
.51389 .37387 Mdot
.47308 .36667 Mdot
.59216 .68392 Mdot
.68007 .42528 Mdot
.43658 .26693 Mdot
.33287 .54937 Mdot
.74432 .50399 Mdot
.60528 .5294 Mdot
.57641 .40362 Mdot
.39093 .31088 Mdot
.3699 .50363 Mdot
.41851 .2776 Mdot
.54259 .6876 Mdot
.28755 .49628 Mdot
.6178 .34481 Mdot
.40873 .66678 Mdot
.64837 .37788 Mdot
.22357 .47389 Mdot
.41167 .66376 Mdot
.73782 .50128 Mdot
.53394 .69603 Mdot
.49867 .38363 Mdot
.5777 .67508 Mdot
.48237 .34268 Mdot
.62026 .32851 Mdot
.75468 .50929 Mdot
.33795 .48071 Mdot
.37424 .66161 Mdot
.29764 .47749 Mdot
.20616 .50587 Mdot
.57943 .42811 Mdot
.62451 .78022 Mdot
.57216 .70669 Mdot
.68986 .53189 Mdot
.29313 .51976 Mdot
.51847 .34895 Mdot
.31539 .26283 Mdot
.31274 .48354 Mdot
.28673 .47077 Mdot
.64023 .38347 Mdot
.70034 .41664 Mdot
.47506 .35193 Mdot
.32915 .47616 Mdot
.53359 .69706 Mdot
.76457 .50331 Mdot
.52082 .35463 Mdot
.61284 .50627 Mdot
.29637 .46784 Mdot
.54718 .65853 Mdot
.67252 .42967 Mdot
.56082 .68586 Mdot
.3003 .51214 Mdot
.58301 .68883 Mdot
.35025 .70362 Mdot
.55778 .70677 Mdot
.53524 .40561 Mdot
.51569 .36455 Mdot
.26543 .54412 Mdot
.29163 .49705 Mdot
.42986 .28869 Mdot
.53089 .40252 Mdot
.30552 .52027 Mdot
.52408 .6761 Mdot
.36877 .50106 Mdot
.42548 .28533 Mdot
.52642 .37551 Mdot
.73977 .48144 Mdot
.59419 .38883 Mdot
.62895 .38648 Mdot
.45982 .35646 Mdot
.72957 .49362 Mdot
.28563 .47046 Mdot
.51924 .36292 Mdot
.6904 .42176 Mdot
.54677 .64478 Mdot
.50047 .32972 Mdot
.6004 .50576 Mdot
.43915 .27578 Mdot
.67779 .36342 Mdot
.41409 .27701 Mdot
.31586 .51034 Mdot
.30118 .51544 Mdot
.53684 .6546 Mdot
.32461 .49887 Mdot
.60365 .50477 Mdot
.38518 .70055 Mdot
.21944 .48326 Mdot
.63582 .50558 Mdot
.60037 .54259 Mdot
.59443 .54373 Mdot
.6387 .53102 Mdot
.79903 .49024 Mdot
.58226 .7629 Mdot
.59727 .53525 Mdot
.30518 .52311 Mdot
.54592 .56544 Mdot
.65811 .52833 Mdot
.39176 .70209 Mdot
.62553 .5106 Mdot
.50044 .32979 Mdot
.41588 .27508 Mdot
.26745 .51818 Mdot
.41156 .66922 Mdot
.64732 .54997 Mdot
.52281 .35621 Mdot
.25824 .50446 Mdot
.50129 .37246 Mdot
.70279 .50376 Mdot
.30401 .49506 Mdot
.54876 .6881 Mdot
.74786 .51166 Mdot
.63487 .52594 Mdot
.71815 .50527 Mdot
.57692 .66478 Mdot
.368 .69416 Mdot
.53839 .38624 Mdot
.69803 .49704 Mdot
.76915 .50872 Mdot
.52586 .34942 Mdot
.29348 .51543 Mdot
.61178 .55735 Mdot
.52851 .37352 Mdot
.421 .27289 Mdot
.27894 .49262 Mdot
.21225 .62295 Mdot
.49753 .38507 Mdot
.44286 .28942 Mdot
.31425 .5558 Mdot
.63408 .50926 Mdot
.55329 .69023 Mdot
.47813 .35473 Mdot
.3984 .67 Mdot
.40733 .68058 Mdot
.52239 .71054 Mdot
.28303 .47771 Mdot
.54844 .6541 Mdot
.53154 .35808 Mdot
.62999 .51334 Mdot
.49218 .34789 Mdot
.60102 .76798 Mdot
.19562 .59994 Mdot
.29352 .52768 Mdot
.59639 .65411 Mdot
.60238 .3364 Mdot
.42372 .68161 Mdot
.52119 .67789 Mdot
.32295 .55486 Mdot
.31688 .47282 Mdot
.27871 .49745 Mdot
.76759 .4928 Mdot
.55313 .68454 Mdot
.26689 .50969 Mdot
.26906 .5134 Mdot
.42153 .28239 Mdot
.53713 .37612 Mdot
.27388 .48173 Mdot
.54424 .74054 Mdot
.74736 .50007 Mdot
.57891 .63338 Mdot
.81124 .47578 Mdot
.39939 .65824 Mdot
.42967 .33378 Mdot
.45914 .33721 Mdot
.71596 .21445 Mdot
.49426 .39775 Mdot
.51375 .37727 Mdot
.25413 .51796 Mdot
.69665 .51525 Mdot
.76137 .49386 Mdot
.29433 .51933 Mdot
.29602 .52838 Mdot
.72263 .51313 Mdot
.54978 .32215 Mdot
.6855 .37925 Mdot
.60333 .35169 Mdot
.33444 .49662 Mdot
.22567 .47715 Mdot
.39988 .68222 Mdot
.31638 .46616 Mdot
.3451 .70819 Mdot
.55572 .71474 Mdot
.55511 .70896 Mdot
.36731 .66988 Mdot
.50158 .38515 Mdot
.58791 .69118 Mdot
.43421 .26747 Mdot
.3465 .7175 Mdot
.40893 .26101 Mdot
.72321 .7518 Mdot
.53692 .40036 Mdot
.49262 .63032 Mdot
.31408 .67615 Mdot
.43492 .28766 Mdot
.38153 .26007 Mdot
.72881 .50411 Mdot
.30355 .55952 Mdot
.41099 .6888 Mdot
.3454 .3123 Mdot
.5106 .36253 Mdot
.33356 .48115 Mdot
.38374 .65708 Mdot
.20706 .61176 Mdot
.43625 .26342 Mdot
.43173 .28005 Mdot
.31354 .26482 Mdot
.33626 .50849 Mdot
.55508 .68959 Mdot
.25679 .53365 Mdot
.27293 .52497 Mdot
.41979 .25749 Mdot
.52959 .69637 Mdot
.5737 .25404 Mdot
.33594 .48898 Mdot
.68664 .5077 Mdot
.31627 .49258 Mdot
.72828 .51264 Mdot
.26612 .50699 Mdot
.59198 .64795 Mdot
.49442 .38695 Mdot
.59395 .64757 Mdot
.70907 .49654 Mdot
.59054 .6777 Mdot
.41436 .68145 Mdot
.62624 .53013 Mdot
.40237 .68997 Mdot
.60997 .30638 Mdot
.36466 .38036 Mdot
.37843 .69613 Mdot
.546 .43235 Mdot
.50548 .35137 Mdot
.26625 .50604 Mdot
.54289 .68393 Mdot
.58509 .62964 Mdot
.6123 .36516 Mdot
.28276 .50814 Mdot
.56191 .64381 Mdot
.42068 .24514 Mdot
.38825 .75311 Mdot
.44251 .28265 Mdot
.38624 .80066 Mdot
.31427 .51549 Mdot
.5773 .63139 Mdot
.61741 .34045 Mdot
.30057 .53046 Mdot
.54928 .7119 Mdot
.36739 .67587 Mdot
.39794 .67011 Mdot
.52675 .40854 Mdot
.3821 .65112 Mdot
.54129 .69282 Mdot
.24055 .45567 Mdot
.26888 .50081 Mdot
.19192 .59319 Mdot
.72439 .49623 Mdot
.54034 .66537 Mdot
.62436 .51535 Mdot
.295 .437 Mdot
.57798 .64772 Mdot
.72961 .23384 Mdot
.83841 .60576 Mdot
.55555 .64851 Mdot
.30492 .49622 Mdot
.29187 .50264 Mdot
.40465 .27448 Mdot
.60804 .36896 Mdot
.54592 .67364 Mdot
.42426 .73846 Mdot
.57896 .29918 Mdot
.62466 .53284 Mdot
.61148 .78154 Mdot
.5538 .39911 Mdot
.42465 .27013 Mdot
.38904 .66063 Mdot
.50734 .39033 Mdot
.31221 .52418 Mdot
.49078 .39564 Mdot
.40647 .69003 Mdot
.52617 .71441 Mdot
.50989 .36026 Mdot
.73677 .5023 Mdot
.38744 .66525 Mdot
.39929 .66695 Mdot
.58903 .67297 Mdot
.28189 .47852 Mdot
.34669 .31993 Mdot
.55468 .68653 Mdot
.43031 .2683 Mdot
.61948 .52854 Mdot
.47434 .35724 Mdot
.3329 .47081 Mdot
.34965 .53671 Mdot
.5385 .66749 Mdot
.52516 .35039 Mdot
.38154 .68552 Mdot
.54193 .65238 Mdot
.40885 .27114 Mdot
.54757 .70667 Mdot
.578 .51093 Mdot
.59128 .68837 Mdot
.30985 .4337 Mdot
.60932 .55394 Mdot
.3352 .4818 Mdot
.60525 .54112 Mdot
.73271 .69129 Mdot
.74081 .50054 Mdot
.58826 .6886 Mdot
.19569 .58826 Mdot
.59653 .64859 Mdot
.49939 .39382 Mdot
.51822 .3569 Mdot
.57713 .65826 Mdot
.72988 .49028 Mdot
.66405 .50819 Mdot
.6989 .5036 Mdot
.29918 .49727 Mdot
.43215 .25611 Mdot
.8185 .64813 Mdot
.59946 .62715 Mdot
.37684 .65674 Mdot
.37247 .493 Mdot
.60433 .54529 Mdot
.41522 .67508 Mdot
.39552 .66495 Mdot
.71219 .50039 Mdot
.59847 .63946 Mdot
.31767 .4623 Mdot
.40227 .64877 Mdot
.3036 .52903 Mdot
.68762 .42563 Mdot
.63788 .52014 Mdot
.67095 .54322 Mdot
.62589 .54665 Mdot
.61536 .35649 Mdot
.42636 .65887 Mdot
.49662 .36388 Mdot
.71432 .52281 Mdot
.37487 .66417 Mdot
.7277 .48225 Mdot
.40956 .26944 Mdot
.56652 .64212 Mdot
.32727 .29567 Mdot
.5325 .40839 Mdot
.52745 .39915 Mdot
.3894 .6581 Mdot
.38043 .27564 Mdot
.32751 .55406 Mdot
.27302 .49499 Mdot
.56783 .66744 Mdot
.63819 .38152 Mdot
.48155 .38702 Mdot
.52359 .35972 Mdot
.58165 .66065 Mdot
.61264 .53727 Mdot
.61724 .78206 Mdot
.52508 .37573 Mdot
.39343 .68312 Mdot
.41183 .2708 Mdot
.41242 .69299 Mdot
.45499 .31987 Mdot
.50392 .39474 Mdot
.43406 .274 Mdot
.42129 .26276 Mdot
.40153 .69015 Mdot
.63321 .53827 Mdot
.59489 .5077 Mdot
.33076 .50084 Mdot
.54255 .39344 Mdot
.57735 .29943 Mdot
.51777 .36803 Mdot
.72902 .50341 Mdot
.63106 .38285 Mdot
.45301 .3304 Mdot
.52904 .41709 Mdot
.58017 .29754 Mdot
.49484 .37478 Mdot
.39308 .65674 Mdot
.29029 .50479 Mdot
.37975 .68363 Mdot
.40501 .64997 Mdot
.58447 .65039 Mdot
.73357 .48072 Mdot
.48002 .35991 Mdot
.71822 .51825 Mdot
.54774 .40852 Mdot
.6349 .56519 Mdot
.59669 .37923 Mdot
.61635 .3367 Mdot
.72994 .47622 Mdot
.51015 .35191 Mdot
.57288 .66417 Mdot
.60399 .63883 Mdot
.41773 .25332 Mdot
.54581 .39584 Mdot
.36133 .666 Mdot
.37146 .69306 Mdot
.59056 .77002 Mdot
.59083 .60341 Mdot
.70236 .5049 Mdot
.65402 .49348 Mdot
.42368 .26093 Mdot
.4862 .38665 Mdot
.62958 .53802 Mdot
.56436 .65196 Mdot
.60076 .5389 Mdot
.58439 .76524 Mdot
.41306 .6886 Mdot
.37449 .67569 Mdot
.53673 .40214 Mdot
.7886 .30609 Mdot
.31366 .47976 Mdot
.29044 .50257 Mdot
.38605 .70175 Mdot
.58841 .68494 Mdot
.60719 .5176 Mdot
.32553 .26859 Mdot
.36134 .51801 Mdot
.7421 .51959 Mdot
.48601 .34914 Mdot
.5613 .71257 Mdot
.31806 .51793 Mdot
.70315 .50642 Mdot
.45498 .35152 Mdot
.52713 .69281 Mdot
.50391 .36699 Mdot
.44467 .26081 Mdot
.28455 .51872 Mdot
.5948 .38381 Mdot
.33766 .48388 Mdot
.40471 .67966 Mdot
.42384 .65577 Mdot
.51061 .39807 Mdot
.33072 .2931 Mdot
.33587 .44146 Mdot
.41685 .6512 Mdot
.76358 .48336 Mdot
.62643 .52412 Mdot
.73017 .48179 Mdot
.56616 .65874 Mdot
.73971 .50124 Mdot
.57978 .64775 Mdot
.53201 .65745 Mdot
.31249 .46301 Mdot
.73829 .49083 Mdot
.42273 .34477 Mdot
.61548 .50791 Mdot
.77355 .49413 Mdot
.48797 .39872 Mdot
.42056 .28637 Mdot
.54708 .66698 Mdot
.71748 .51874 Mdot
.47697 .3541 Mdot
.24822 .5936 Mdot
.413 .65372 Mdot
.41334 .6844 Mdot
.6079 .52041 Mdot
.53398 .68011 Mdot
.3188 .46139 Mdot
.60368 .33188 Mdot
.29678 .43333 Mdot
.52704 .36273 Mdot
.48161 .36417 Mdot
.30321 .4325 Mdot
.31823 .46118 Mdot
.50941 .3963 Mdot
.42949 .41896 Mdot
.62811 .51717 Mdot
.40488 .67378 Mdot
.29913 .49523 Mdot
.29321 .49197 Mdot
.55192 .69783 Mdot
.2886 .47148 Mdot
.72297 .52944 Mdot
.41429 .68529 Mdot
.60405 .49903 Mdot
.38528 .68546 Mdot
.57316 .55976 Mdot
.56101 .64705 Mdot
.20601 .60193 Mdot
.2741 .48767 Mdot
.42779 .28404 Mdot
.28245 .47466 Mdot
.72055 .49765 Mdot
.32815 .47713 Mdot
.32236 .46712 Mdot
.53701 .37761 Mdot
.63347 .53562 Mdot
.59727 .52496 Mdot
.61099 .36147 Mdot
.31434 .48139 Mdot
.48984 .37713 Mdot
.4627 .35738 Mdot
.53408 .39975 Mdot
.59986 .37717 Mdot
.28802 .47892 Mdot
.39084 .30949 Mdot
.26245 .49523 Mdot
.28978 .52099 Mdot
.81567 .46447 Mdot
.60402 .50635 Mdot
.60953 .54503 Mdot
.40439 .73864 Mdot
.52818 .38036 Mdot
.56952 .63892 Mdot
.42925 .26989 Mdot
.63229 .52622 Mdot
.45832 .35882 Mdot
.75955 .51228 Mdot
.48803 .34166 Mdot
.62054 .53747 Mdot
.5451 .68402 Mdot
.42677 .28326 Mdot
.52293 .36916 Mdot
.60681 .53409 Mdot
.30213 .46373 Mdot
.29032 .48492 Mdot
.37829 .44156 Mdot
.71473 .50826 Mdot
.39086 .69327 Mdot
.4275 .27126 Mdot
.56963 .66566 Mdot
.58006 .63602 Mdot
.33552 .48035 Mdot
.57397 .69175 Mdot
.37552 .67249 Mdot
.52038 .38237 Mdot
.40494 .68426 Mdot
.74297 .51634 Mdot
.30366 .49413 Mdot
.42297 .27734 Mdot
.40331 .27975 Mdot
.30115 .51551 Mdot
.6293 .51637 Mdot
.74035 .48043 Mdot
.58377 .67502 Mdot
.28698 .52567 Mdot
.40001 .69402 Mdot
.55811 .69992 Mdot
.43175 .28214 Mdot
.82665 .4255 Mdot
.50715 .39081 Mdot
.51682 .40433 Mdot
.30688 .43952 Mdot
.47756 .32415 Mdot
.59455 .65291 Mdot
.32016 .4598 Mdot
.42392 .28617 Mdot
.6021 .28758 Mdot
.77169 .47899 Mdot
.61471 .64456 Mdot
.50138 .37656 Mdot
.44534 .34183 Mdot
.47577 .33496 Mdot
.19106 .57761 Mdot
.59837 .38018 Mdot
.5672 .75166 Mdot
.67768 .53693 Mdot
.38996 .65059 Mdot
.61838 .53361 Mdot
.58729 .65088 Mdot
.41396 .40749 Mdot
.51154 .39392 Mdot
.35722 .36835 Mdot
.41186 .27669 Mdot
.37529 .68388 Mdot
.39054 .29623 Mdot
.54357 .6892 Mdot
.63741 .78678 Mdot
.53512 .36701 Mdot
.34274 .54272 Mdot
.46506 .65675 Mdot
.62848 .53631 Mdot
.61758 .54717 Mdot
.70413 .50558 Mdot
.52103 .68909 Mdot
.64827 .53986 Mdot
.38211 .68431 Mdot
.48267 .38464 Mdot
.44774 .32978 Mdot
.22201 .62324 Mdot
.31625 .51695 Mdot
.39215 .65245 Mdot
.61178 .67068 Mdot
.49256 .35906 Mdot
.30943 .47357 Mdot
.3125 .50733 Mdot
.75617 .51509 Mdot
.55672 .74796 Mdot
.51997 .67929 Mdot
.75058 .272 Mdot
.62615 .55698 Mdot
.56729 .65197 Mdot
.62289 .55154 Mdot
.43139 .27039 Mdot
.57574 .40408 Mdot
.39331 .65065 Mdot
.50416 .39762 Mdot
.35569 .35722 Mdot
.32421 .50634 Mdot
.51567 .37007 Mdot
.75123 .50173 Mdot
.33094 .23675 Mdot
.41 .25073 Mdot
.43574 .42122 Mdot
.53338 .69703 Mdot
.48269 .36723 Mdot
.73017 .52886 Mdot
.63016 .5053 Mdot
.47865 .32373 Mdot
.55286 .68872 Mdot
.60799 .55352 Mdot
.75584 .49904 Mdot
.33072 .50363 Mdot
.61703 .53191 Mdot
.40981 .27441 Mdot
.47954 .34662 Mdot
.76057 .48108 Mdot
.43245 .27584 Mdot
.21614 .49067 Mdot
.64005 .54079 Mdot
.5601 .70823 Mdot
.28208 .52584 Mdot
.48429 .37244 Mdot
.62748 .52434 Mdot
.49047 .34968 Mdot
.20025 .51865 Mdot
.49526 .39353 Mdot
.23527 .60481 Mdot
.28765 .51205 Mdot
.38893 .6735 Mdot
.41875 .27636 Mdot
.50456 .36491 Mdot
.61803 .5537 Mdot
.60618 .5155 Mdot
.52044 .35196 Mdot
.33586 .48221 Mdot
.32995 .48762 Mdot
.35306 .5316 Mdot
.55195 .70143 Mdot
.60039 .35982 Mdot
.39578 .67517 Mdot
.62872 .53932 Mdot
.39907 .64872 Mdot
.44653 .33977 Mdot
.71751 .50805 Mdot
.22473 .61811 Mdot
.52116 .38842 Mdot
.2813 .50533 Mdot
.68534 .38268 Mdot
.31945 .47157 Mdot
.40081 .73887 Mdot
.38504 .65315 Mdot
.30899 .48703 Mdot
.50331 .37872 Mdot
.61795 .35172 Mdot
.441 .32959 Mdot
.42712 .66802 Mdot
.60111 .50222 Mdot
.58755 .55919 Mdot
.54183 .70975 Mdot
.8168 .46963 Mdot
.35888 .68893 Mdot
.31302 .67449 Mdot
.42564 .2854 Mdot
.27276 .50209 Mdot
.39227 .69642 Mdot
.40336 .66764 Mdot
.53884 .6856 Mdot
.42284 .28262 Mdot
.50745 .36617 Mdot
.59808 .50883 Mdot
.36427 .69249 Mdot
.5013 .34023 Mdot
.43522 .28915 Mdot
.60136 .77527 Mdot
.32333 .55662 Mdot
.2085 .62201 Mdot
.44907 .34242 Mdot
.35662 .35451 Mdot
.46598 .69369 Mdot
.26726 .50479 Mdot
.48894 .37302 Mdot
.61705 .51568 Mdot
.57643 .6917 Mdot
.51496 .38517 Mdot
.59731 .65291 Mdot
.37987 .69114 Mdot
.24306 .60017 Mdot
.44768 .33437 Mdot
.34775 .71978 Mdot
.49852 .38913 Mdot
.40237 .26027 Mdot
.74804 .49341 Mdot
.40753 .69415 Mdot
.35317 .52817 Mdot
.47697 .36263 Mdot
.55791 .69399 Mdot
.54329 .71213 Mdot
.32814 .50026 Mdot
.37828 .46239 Mdot
.2008 .59638 Mdot
.62098 .51271 Mdot
.57325 .68668 Mdot
.62785 .52214 Mdot
.44311 .42541 Mdot
.40224 .64864 Mdot
.75676 .4987 Mdot
.58201 .68928 Mdot
.37347 .70259 Mdot
.42102 .28674 Mdot
.322 .48755 Mdot
.28757 .43798 Mdot
.42778 .25712 Mdot
.56297 .64302 Mdot
.73496 .51042 Mdot
.55997 .41356 Mdot
.42903 .25508 Mdot
.74864 .50972 Mdot
.54555 .69666 Mdot
.303 .48035 Mdot
.30666 .51147 Mdot
.29167 .50621 Mdot
.42947 .33447 Mdot
.35242 .53402 Mdot
.63708 .44273 Mdot
.47984 .32591 Mdot
.2528 .44635 Mdot
.49219 .33081 Mdot
.41243 .6858 Mdot
.28053 .51526 Mdot
.59737 .38038 Mdot
.44033 .27177 Mdot
.43528 .31852 Mdot
.53507 .3867 Mdot
.41721 .26089 Mdot
.52829 .37979 Mdot
.2579 .44555 Mdot
.32692 .55623 Mdot
.53405 .4176 Mdot
.42099 .67308 Mdot
.72195 .50453 Mdot
.27861 .52875 Mdot
.48334 .36102 Mdot
.23463 .46624 Mdot
.48412 .39553 Mdot
.23949 .59992 Mdot
.41459 .2602 Mdot
.53683 .72972 Mdot
.47686 .37563 Mdot
.56773 .71179 Mdot
.39998 .27223 Mdot
.22106 .48249 Mdot
.41436 .65564 Mdot
.40743 .2517 Mdot
.56032 .71863 Mdot
.39225 .29935 Mdot
.61407 .51165 Mdot
.74815 .49807 Mdot
.60265 .55021 Mdot
.40553 .68881 Mdot
.51832 .39262 Mdot
.4852 .34414 Mdot
.46548 .32216 Mdot
.44581 .42675 Mdot
.60768 .50587 Mdot
.72932 .47598 Mdot
.22465 .47615 Mdot
.50388 .34496 Mdot
.59746 .67587 Mdot
.28122 .48807 Mdot
.41145 .3284 Mdot
.41605 .3501 Mdot
.42914 .29194 Mdot
.31421 .48391 Mdot
.28319 .47742 Mdot
.80424 .47839 Mdot
.73575 .49578 Mdot
.5228 .40118 Mdot
.69206 .50121 Mdot
.42685 .27406 Mdot
.39129 .6892 Mdot
.46971 .3263 Mdot
.56082 .64664 Mdot
.6215 .3456 Mdot
.54704 .69906 Mdot
.5358 .39613 Mdot
.31547 .49434 Mdot
.42612 .6699 Mdot
.53779 .64958 Mdot
.55063 .74636 Mdot
.64763 .44166 Mdot
.52029 .67511 Mdot
.71112 .51019 Mdot
.71467 .49999 Mdot
.40841 .69309 Mdot
.51096 .37852 Mdot
.60331 .37542 Mdot
.39841 .22435 Mdot
.52764 .38718 Mdot
.50353 .38512 Mdot
.43973 .65813 Mdot
.36269 .67624 Mdot
.58207 .69129 Mdot
.51059 .396 Mdot
.49078 .34072 Mdot
.31172 .4919 Mdot
.69829 .51394 Mdot
.58586 .65917 Mdot
.70399 .50344 Mdot
.57276 .67666 Mdot
.67864 .36374 Mdot
.63562 .51742 Mdot
.71397 .50513 Mdot
.35839 .68449 Mdot
.28147 .50169 Mdot
.60488 .50506 Mdot
.55756 .66566 Mdot
.57263 .68996 Mdot
.54806 .40641 Mdot
.32239 .51394 Mdot
.2729 .49471 Mdot
.71675 .51052 Mdot
.37382 .69544 Mdot
.43385 .26601 Mdot
.62483 .54679 Mdot
.62479 .67393 Mdot
.56451 .6946 Mdot
.22607 .47146 Mdot
.30217 .43791 Mdot
.48881 .35529 Mdot
.29211 .48416 Mdot
.50214 .35855 Mdot
.25441 .52268 Mdot
.3266 .51969 Mdot
.45311 .31973 Mdot
.37667 .42693 Mdot
.56697 .65011 Mdot
.78631 .69 Mdot
.44245 .28628 Mdot
.36202 .70461 Mdot
.42969 .27141 Mdot
.62369 .78424 Mdot
.6874 .38517 Mdot
.50776 .34755 Mdot
.4823 .36318 Mdot
.79471 .32559 Mdot
.46778 .35448 Mdot
.60864 .54171 Mdot
.61357 .51096 Mdot
.2979 .48019 Mdot
.60021 .54786 Mdot
.61363 .35993 Mdot
.73775 .48771 Mdot
.5674 .66666 Mdot
.6911 .41949 Mdot
.72668 .51162 Mdot
.31742 .51082 Mdot
.43672 .26893 Mdot
.33153 .43585 Mdot
.60212 .66414 Mdot
.60978 .53016 Mdot
.37798 .68853 Mdot
.61104 .37121 Mdot
.54948 .69286 Mdot
.3698 .69925 Mdot
.46312 .35218 Mdot
.58864 .76359 Mdot
.41936 .67642 Mdot
.80141 .67002 Mdot
.40149 .66181 Mdot
.38518 .70088 Mdot
.60357 .36768 Mdot
.7382 .4874 Mdot
.61745 .55485 Mdot
.64586 .55929 Mdot
.4172 .66065 Mdot
.66748 .77641 Mdot
.53506 .68112 Mdot
.61919 .32614 Mdot
.30489 .55992 Mdot
.62318 .50876 Mdot
.49939 .3875 Mdot
.39232 .65945 Mdot
.54428 .41 Mdot
.61275 .55417 Mdot
.38161 .67007 Mdot
.40043 .27345 Mdot
.63707 .3782 Mdot
.62314 .52031 Mdot
.59631 .52223 Mdot
.70449 .51436 Mdot
.53223 .7267 Mdot
.27541 .48971 Mdot
.77177 .50605 Mdot
.59916 .31755 Mdot
.52925 .40223 Mdot
.40068 .69078 Mdot
.61613 .53179 Mdot
.39814 .6732 Mdot
.75533 .49198 Mdot
.7642 .48233 Mdot
.32807 .5056 Mdot
.34829 .53663 Mdot
.63813 .5047 Mdot
.56914 .2933 Mdot
.47758 .33039 Mdot
.35962 .37535 Mdot
.29812 .47095 Mdot
.38307 .25945 Mdot
.75353 .48396 Mdot
.70577 .51714 Mdot
.40075 .26356 Mdot
.46594 .37029 Mdot
.4152 .26456 Mdot
.45392 .34071 Mdot
.65695 .75759 Mdot
.42113 .27856 Mdot
.58235 .67696 Mdot
.45308 .34276 Mdot
.31617 .62946 Mdot
.41101 .25428 Mdot
.48386 .35569 Mdot
.56056 .68061 Mdot
.51815 .3409 Mdot
.54981 .65832 Mdot
.48912 .38092 Mdot
.60565 .7699 Mdot
.56953 .66609 Mdot
.63876 .49152 Mdot
.56929 .42649 Mdot
.60346 .53769 Mdot
.76358 .49182 Mdot
.69999 .49563 Mdot
.67072 .43104 Mdot
.30394 .48216 Mdot
.34569 .23087 Mdot
.48479 .35619 Mdot
.53771 .68649 Mdot
.37765 .6911 Mdot
.40968 .28555 Mdot
.52174 .40587 Mdot
.42921 .2608 Mdot
.32303 .4839 Mdot
.53278 .68031 Mdot
.75042 .48823 Mdot
.60133 .6451 Mdot
.60494 .77841 Mdot
.56025 .64888 Mdot
.47463 .43389 Mdot
.41333 .28359 Mdot
.72716 .52904 Mdot
.36936 .39658 Mdot
.67516 .50467 Mdot
.3274 .49335 Mdot
.61977 .53208 Mdot
.71588 .49139 Mdot
.60275 .40486 Mdot
.27781 .49044 Mdot
.5814 .66118 Mdot
.50302 .36665 Mdot
.63834 .53498 Mdot
.64481 .56014 Mdot
.31283 .52478 Mdot
.75493 .47801 Mdot
.5602 .67042 Mdot
.62297 .52563 Mdot
.60144 .35282 Mdot
.38682 .32402 Mdot
.61374 .30969 Mdot
.50198 .36222 Mdot
.72274 .51275 Mdot
.32187 .51462 Mdot
.42859 .25945 Mdot
.37493 .66554 Mdot
.60964 .36702 Mdot
.503 .38983 Mdot
.35299 .73006 Mdot
.31696 .49466 Mdot
.72714 .49409 Mdot
.39649 .65948 Mdot
.7354 .49728 Mdot
.61068 .54483 Mdot
.25459 .51495 Mdot
.61795 .54701 Mdot
.41192 .27554 Mdot
.38388 .69296 Mdot
.27432 .49314 Mdot
.60472 .77605 Mdot
.61063 .55679 Mdot
.57547 .65796 Mdot
.60506 .40232 Mdot
.33196 .4929 Mdot
.35581 .61252 Mdot
.60121 .64587 Mdot
.42981 .63629 Mdot
.59253 .38978 Mdot
.38062 .6675 Mdot
.48351 .3574 Mdot
.30134 .50503 Mdot
.42752 .67009 Mdot
.54196 .73887 Mdot
.44203 .33938 Mdot
.64549 .52505 Mdot
.51063 .35293 Mdot
.18667 .5679 Mdot
.3153 .65184 Mdot
.26911 .54752 Mdot
.35947 .69535 Mdot
.53083 .39454 Mdot
.62387 .51315 Mdot
.54278 .39197 Mdot
.41053 .65668 Mdot
.43617 .67498 Mdot
.58681 .63306 Mdot
.49837 .36572 Mdot
.73035 .50151 Mdot
.57958 .64174 Mdot
.5357 .70785 Mdot
.57542 .69898 Mdot
.35093 .53146 Mdot
.62967 .51004 Mdot
.61742 .51068 Mdot
.69094 .38992 Mdot
.39943 .67231 Mdot
.60444 .53833 Mdot
.4852 .3429 Mdot
.63795 .44199 Mdot
.28875 .5086 Mdot
.55606 .67384 Mdot
.52965 .39791 Mdot
.44374 .28231 Mdot
.60438 .52985 Mdot
.55476 .68536 Mdot
.31365 .46234 Mdot
.55895 .57013 Mdot
.51707 .38609 Mdot
.41835 .281 Mdot
.30803 .51668 Mdot
.20063 .52545 Mdot
.60673 .34097 Mdot
.50417 .35945 Mdot
.4077 .68043 Mdot
.21792 .54607 Mdot
.46607 .35687 Mdot
.38585 .44234 Mdot
.60146 .50371 Mdot
.53199 .54933 Mdot
.23342 .51512 Mdot
.45309 .27434 Mdot
.44853 .583 Mdot
.51866 .24376 Mdot
.47936 .60406 Mdot
.67697 .74201 Mdot
.40213 .5763 Mdot
.81625 .64676 Mdot
.35675 .66135 Mdot
.44749 .26182 Mdot
.71836 .23666 Mdot
.31871 .67534 Mdot
.39105 .59633 Mdot
.33774 .67513 Mdot
.60648 .46766 Mdot
.615 .77976 Mdot
.5888 .76544 Mdot
.67744 .73531 Mdot
.55276 .39946 Mdot
.31892 .58628 Mdot
.4132 .23938 Mdot
.34156 .62782 Mdot
.56775 .74746 Mdot
.42962 .25316 Mdot
.78409 .33836 Mdot
.37816 .74382 Mdot
.77704 .4152 Mdot
.34496 .29489 Mdot
.60413 .72869 Mdot
.55091 .29012 Mdot
.70433 .44762 Mdot
.40458 .22507 Mdot
.50348 .57406 Mdot
.36952 .6546 Mdot
.29067 .46288 Mdot
.40983 .74409 Mdot
.58045 .67114 Mdot
.32864 .51189 Mdot
.34427 .74826 Mdot
.80048 .38794 Mdot
.35768 .63839 Mdot
.44744 .58387 Mdot
.63887 .54639 Mdot
.53555 .53916 Mdot
.59093 .3781 Mdot
.25874 .52861 Mdot
.60536 .74369 Mdot
.61721 .76434 Mdot
.28342 .45085 Mdot
.56054 .73228 Mdot
.59328 .41424 Mdot
.38608 .59598 Mdot
.22988 .51863 Mdot
.62573 .47479 Mdot
.62668 .487 Mdot
.29993 .46993 Mdot
.73782 .29882 Mdot
.52999 .45445 Mdot
.59737 .30808 Mdot
.57757 .73854 Mdot
.3133 .45428 Mdot
.34384 .31503 Mdot
.37663 .46479 Mdot
.74365 .73054 Mdot
.816 .41847 Mdot
.70871 .72883 Mdot
.56537 .45552 Mdot
.36972 .63986 Mdot
.58084 .43321 Mdot
.502 .62905 Mdot
.73194 .71594 Mdot
.20658 .52513 Mdot
.75075 .29058 Mdot
.49165 .5038 Mdot
.82278 .40111 Mdot
.24687 .47969 Mdot
.61968 .47634 Mdot
.25209 .53809 Mdot
.55637 .52992 Mdot
.66116 .37839 Mdot
.81125 .37723 Mdot
.36243 .59372 Mdot
.58625 .54785 Mdot
.31976 .67221 Mdot
.22137 .50145 Mdot
.60033 .75808 Mdot
.58431 .52538 Mdot
.39184 .38261 Mdot
.80792 .35676 Mdot
.4577 .57637 Mdot
.76898 .35224 Mdot
.61333 .73394 Mdot
.37263 .78201 Mdot
.53223 .70645 Mdot
.42802 .65549 Mdot
.79259 .41467 Mdot
.30572 .50606 Mdot
.7634 .71582 Mdot
.41403 .59575 Mdot
.46773 .64515 Mdot
.80098 .34842 Mdot
.72245 .7459 Mdot
.55512 .5073 Mdot
.64059 .48767 Mdot
.41479 .73984 Mdot
.50375 .60208 Mdot
.33356 .62072 Mdot
.58076 .57087 Mdot
.21637 .58822 Mdot
.78631 .40466 Mdot
.70637 .75002 Mdot
.73511 .26252 Mdot
.59537 .31764 Mdot
.6581 .46071 Mdot
.30781 .44138 Mdot
.42545 .51724 Mdot
.33457 .62546 Mdot
.82464 .40886 Mdot
.41206 .24627 Mdot
.2083 .54737 Mdot
.68593 .73266 Mdot
.40932 .33509 Mdot
.25683 .58544 Mdot
.33655 .71866 Mdot
.56961 .57464 Mdot
.23233 .4928 Mdot
.79886 .49466 Mdot
.66767 .39985 Mdot
.38032 .36935 Mdot
.54751 .73227 Mdot
.60971 .34668 Mdot
.3905 .46282 Mdot
.80177 .63422 Mdot
.28378 .58396 Mdot
.38936 .37641 Mdot
.28507 .4399 Mdot
.73277 .71321 Mdot
.68992 .7374 Mdot
.22954 .56658 Mdot
.61733 .67542 Mdot
.77533 .3603 Mdot
.38567 .51239 Mdot
.54465 .52482 Mdot
.42015 .24184 Mdot
.3972 .24443 Mdot
.63007 .73844 Mdot
.48204 .44988 Mdot
.77786 .46375 Mdot
.335 .70055 Mdot
.36985 .40452 Mdot
.72421 .44977 Mdot
.37639 .40053 Mdot
.22022 .48713 Mdot
.41587 .45788 Mdot
.38143 .74229 Mdot
.41309 .44017 Mdot
.78836 .339 Mdot
.59154 .65817 Mdot
.73021 .721 Mdot
.35527 .64219 Mdot
.58866 .75606 Mdot
.46015 .64333 Mdot
.45983 .64564 Mdot
.78612 .43133 Mdot
.32517 .70896 Mdot
.59031 .47798 Mdot
.26345 .54008 Mdot
.44983 .6121 Mdot
.36548 .37208 Mdot
.49424 .42804 Mdot
.35043 .55379 Mdot
.74226 .47969 Mdot
.40775 .41204 Mdot
.23123 .49161 Mdot
.61233 .67392 Mdot
.47245 .42828 Mdot
.55985 .26565 Mdot
.62582 .49864 Mdot
.63831 .42114 Mdot
.67976 .36823 Mdot
.52159 .50886 Mdot
.73401 .72883 Mdot
.37476 .53031 Mdot
.64309 .42158 Mdot
.33401 .63041 Mdot
.34945 .23076 Mdot
.82409 .39994 Mdot
.80458 .46323 Mdot
.23386 .54911 Mdot
.2269 .5763 Mdot
.40693 .82009 Mdot
.36465 .61288 Mdot
.81567 .62487 Mdot
.35546 .64236 Mdot
.30222 .25756 Mdot
.59416 .65835 Mdot
.5716 .4737 Mdot
.25239 .50637 Mdot
.55354 .26745 Mdot
.79675 .36204 Mdot
.52531 .52435 Mdot
.77428 .49801 Mdot
.24525 .53756 Mdot
.38637 .42977 Mdot
.7721 .33364 Mdot
.74867 .30105 Mdot
.74883 .30891 Mdot
.34054 .74426 Mdot
.44745 .43641 Mdot
.78993 .33017 Mdot
.59987 .44473 Mdot
.49368 .47272 Mdot
.44851 .29476 Mdot
.58797 .2848 Mdot
.79918 .66029 Mdot
.63809 .46505 Mdot
.50889 .60005 Mdot
.28403 .45001 Mdot
.8111 .35311 Mdot
.69307 .37828 Mdot
.54564 .5492 Mdot
.76462 .41979 Mdot
.71826 .47478 Mdot
.73023 .44488 Mdot
.78492 .43821 Mdot
.47848 .57416 Mdot
.33551 .71376 Mdot
.81961 .35646 Mdot
.71851 .71113 Mdot
.34576 .63436 Mdot
.23071 .47771 Mdot
.79 .67756 Mdot
.24619 .58437 Mdot
.42071 .64173 Mdot
.24766 .4872 Mdot
.35689 .24732 Mdot
.37909 .56407 Mdot
.50971 .57565 Mdot
.47506 .31843 Mdot
.73182 .45702 Mdot
.59178 .67308 Mdot
.76661 .68189 Mdot
.37342 .55634 Mdot
.48301 .47078 Mdot
.65723 .419 Mdot
.6911 .76342 Mdot
.49756 .54139 Mdot
.43202 .40197 Mdot
.37648 .52655 Mdot
.26641 .57319 Mdot
.26342 .5835 Mdot
.35998 .30554 Mdot
.48584 .33358 Mdot
.80394 .38487 Mdot
.82971 .61583 Mdot
.79354 .4406 Mdot
.24746 .57136 Mdot
.39547 .79722 Mdot
.35009 .67458 Mdot
.61096 .43894 Mdot
.55788 .24867 Mdot
.46161 .54849 Mdot
.52746 .23592 Mdot
.42037 .69155 Mdot
.34366 .31549 Mdot
.45076 .63232 Mdot
.6003 .44347 Mdot
.31086 .5696 Mdot
.46392 .63134 Mdot
.43095 .41156 Mdot
.26327 .45106 Mdot
.19366 .55063 Mdot
.7354 .70929 Mdot
.59075 .66324 Mdot
.62115 .663 Mdot
.48775 .45883 Mdot
.7112 .52263 Mdot
.57637 .54138 Mdot
.54734 .5154 Mdot
.35818 .34589 Mdot
.40952 .80586 Mdot
.7701 .44886 Mdot
.78468 .69032 Mdot
.7864 .44019 Mdot
.70144 .73463 Mdot
.57183 .73152 Mdot
.64412 .40554 Mdot
.38294 .62688 Mdot
.36115 .64881 Mdot
.63716 .39852 Mdot
.69099 .75231 Mdot
.54613 .53906 Mdot
.2689 .54361 Mdot
.48229 .33766 Mdot
.6812 .3797 Mdot
.69636 .44914 Mdot
.62587 .4186 Mdot
.37304 .31734 Mdot
.33424 .46428 Mdot
.6285 .45359 Mdot
.53612 .57399 Mdot
.4051 .28491 Mdot
.22305 .57305 Mdot
.42807 .67219 Mdot
.24118 .46641 Mdot
.69105 .7653 Mdot
.41054 .81534 Mdot
.47454 .61865 Mdot
.54274 .43846 Mdot
.78063 .39775 Mdot
.56573 .44036 Mdot
.2263 .58248 Mdot
.36279 .24928 Mdot
.45401 .64755 Mdot
.27021 .45765 Mdot
.51178 .4893 Mdot
.4778 .66573 Mdot
.29597 .57544 Mdot
.24675 .46488 Mdot
.39463 .25278 Mdot
.80797 .42222 Mdot
.52393 .33724 Mdot
.49261 .58105 Mdot
.6052 .33008 Mdot
.41082 .52582 Mdot
.42792 .60045 Mdot
.66706 .42425 Mdot
.46836 .59784 Mdot
.74177 .31036 Mdot
.34399 .33007 Mdot
.52246 .59768 Mdot
.59946 .45419 Mdot
.59745 .44297 Mdot
.34546 .2965 Mdot
.21929 .50764 Mdot
.33486 .69677 Mdot
.5476 .36834 Mdot
.81663 .43284 Mdot
.47652 .49631 Mdot
.65067 .41839 Mdot
.39601 .48124 Mdot
.53286 .349 Mdot
.57536 .51871 Mdot
.78412 .43526 Mdot
.53284 .55352 Mdot
.7131 .22683 Mdot
.67369 .75637 Mdot
.3704 .5168 Mdot
.24887 .52683 Mdot
.74403 .70886 Mdot
.33989 .58198 Mdot
.41242 .58234 Mdot
.38347 .53688 Mdot
.77799 .68519 Mdot
.52216 .54664 Mdot
.53757 .56198 Mdot
.19485 .56065 Mdot
.77636 .31998 Mdot
.49839 .59576 Mdot
.41723 .64267 Mdot
.65757 .46631 Mdot
.50572 .40146 Mdot
.38198 .47582 Mdot
.2072 .60892 Mdot
.42004 .48298 Mdot
.48743 .61005 Mdot
.82586 .63328 Mdot
.53146 .52121 Mdot
.37027 .54157 Mdot
.71691 .22862 Mdot
.71658 .22069 Mdot
.37969 .4786 Mdot
.82587 .41486 Mdot
.54114 .55906 Mdot
.23285 .5849 Mdot
.37251 .65093 Mdot
.51944 .43118 Mdot
.35874 .3705 Mdot
.81268 .44554 Mdot
.38166 .80481 Mdot
.33131 .6337 Mdot
.25428 .48895 Mdot
.81803 .4526 Mdot
.48323 .47761 Mdot
.5779 .4793 Mdot
.37627 .78088 Mdot
.64288 .7818 Mdot
.74435 .72571 Mdot
.36434 .29798 Mdot
.627 .75135 Mdot
.65523 .73061 Mdot
.35663 .59425 Mdot
.7946 .67553 Mdot
.63321 .55765 Mdot
.35561 .22755 Mdot
.731 .71523 Mdot
.202 .57363 Mdot
.61039 .76114 Mdot
.43035 .59886 Mdot
.54062 .51777 Mdot
.42696 .45956 Mdot
.22148 .59113 Mdot
.33496 .72617 Mdot
.53 .48295 Mdot
.61829 .39569 Mdot
.22287 .49223 Mdot
.20408 .53649 Mdot
.371 .23204 Mdot
.55311 .49868 Mdot
.72464 .27635 Mdot
.36444 .73014 Mdot
.60638 .41671 Mdot
.26216 .5363 Mdot
.68547 .43107 Mdot
.58706 .47715 Mdot
.46286 .36776 Mdot
.80616 .4188 Mdot
.58546 .48039 Mdot
.73474 .28638 Mdot
.76061 .72262 Mdot
.76015 .41223 Mdot
.49377 .64268 Mdot
.578 .55513 Mdot
.79956 .65609 Mdot
.80774 .63867 Mdot
.73084 .27194 Mdot
.67938 .7272 Mdot
.63517 .3969 Mdot
.53548 .49162 Mdot
.49975 .42755 Mdot
.44991 .42588 Mdot
.7477 .70412 Mdot
.34224 .29499 Mdot
.72059 .44469 Mdot
.25368 .55928 Mdot
.69192 .75654 Mdot
.57167 .44774 Mdot
.67726 .43249 Mdot
.41009 .48993 Mdot
.61607 .48239 Mdot
.5365 .66364 Mdot
.7799 .30169 Mdot
.22882 .56917 Mdot
.74611 .445 Mdot
.21155 .55195 Mdot
.2719 .44162 Mdot
.66437 .74613 Mdot
.23585 .5307 Mdot
.66769 .55366 Mdot
.59069 .73237 Mdot
.79716 .4836 Mdot
.55228 .53195 Mdot
.18962 .57644 Mdot
.40564 .34983 Mdot
.79328 .43181 Mdot
.72699 .45053 Mdot
.72362 .25477 Mdot
.63395 .45599 Mdot
.40569 .41109 Mdot
.73219 .29389 Mdot
.25071 .56151 Mdot
.61604 .42055 Mdot
.77354 .3295 Mdot
.30314 .56164 Mdot
.81534 .41588 Mdot
.37047 .67274 Mdot
.59062 .46547 Mdot
.20514 .59579 Mdot
.61236 .42965 Mdot
.60851 .42904 Mdot
.77203 .45401 Mdot
.32006 .66316 Mdot
.35784 .56095 Mdot
.38421 .51748 Mdot
.59407 .75737 Mdot
.52738 .43211 Mdot
.47878 .58315 Mdot
.73826 .26468 Mdot
.47827 .33785 Mdot
.71217 .70051 Mdot
.73153 .72472 Mdot
.38673 .62805 Mdot
.54392 .50407 Mdot
.20044 .58595 Mdot
.36722 .2866 Mdot
.68263 .39666 Mdot
.77935 .32536 Mdot
.54386 .50265 Mdot
.55077 .2546 Mdot
.37901 .25452 Mdot
.42999 .72734 Mdot
.32839 .67163 Mdot
.45566 .58554 Mdot
.55572 .45977 Mdot
.60445 .34307 Mdot
.70629 .72761 Mdot
.8211 .64142 Mdot
.72419 .27349 Mdot
.32968 .67526 Mdot
.62098 .42568 Mdot
.39449 .44765 Mdot
.70502 .46573 Mdot
.7351 .25768 Mdot
.61885 .78066 Mdot
.23153 .4904 Mdot
.6974 .74936 Mdot
.32237 .67398 Mdot
.58032 .47419 Mdot
.63104 .41121 Mdot
.74006 .30299 Mdot
.26482 .48253 Mdot
.50375 .50208 Mdot
.4018 .46719 Mdot
.61771 .36506 Mdot
.41243 .60455 Mdot
.35282 .25328 Mdot
.32321 .7141 Mdot
.72226 .25418 Mdot
.64638 .73845 Mdot
.40322 .31546 Mdot
.71937 .24176 Mdot
.33118 .46261 Mdot
.40876 .60457 Mdot
.36638 .776 Mdot
.63819 .42541 Mdot
.53602 .71508 Mdot
.49378 .33898 Mdot
.62979 .39256 Mdot
.33366 .58281 Mdot
.63788 .45981 Mdot
.76938 .48098 Mdot
.23593 .47505 Mdot
.66292 .73679 Mdot
.25291 .45673 Mdot
.82163 .63499 Mdot
.4767 .57036 Mdot
.23297 .50815 Mdot
.37165 .24827 Mdot
.57245 .7293 Mdot
.26064 .56896 Mdot
.77418 .41614 Mdot
.58868 .28838 Mdot
.23911 .50036 Mdot
.23915 .49325 Mdot
.31942 .56459 Mdot
.38941 .62112 Mdot
.78773 .39073 Mdot
.72381 .74171 Mdot
.62427 .67268 Mdot
.32621 .55957 Mdot
.56943 .43453 Mdot
.54395 .52039 Mdot
.75235 .43525 Mdot
.59777 .64141 Mdot
.82879 .39253 Mdot
.33623 .24452 Mdot
.31471 .58805 Mdot
.46942 .53994 Mdot
.57006 .25655 Mdot
.58812 .43162 Mdot
.56443 .72869 Mdot
.5524 .50937 Mdot
.37452 .51355 Mdot
.34266 .46312 Mdot
.43149 .61838 Mdot
.75462 .48259 Mdot
.61538 .68061 Mdot
.3467 .64009 Mdot
.35549 .30166 Mdot
.74325 .71654 Mdot
.31521 .43086 Mdot
.57088 .52401 Mdot
.58739 .70305 Mdot
.4713 .43481 Mdot
.57737 .27382 Mdot
.8 .32422 Mdot
.7708 .40393 Mdot
.33989 .49292 Mdot
.28783 .58325 Mdot
.60864 .7481 Mdot
.76691 .44786 Mdot
.50901 .51565 Mdot
.74425 .70332 Mdot
.3949 .39008 Mdot
.76923 .43467 Mdot
.23787 .51971 Mdot
.44974 .57007 Mdot
.71444 .7367 Mdot
.76081 .47075 Mdot
.69748 .75672 Mdot
.37621 .30029 Mdot
.54365 .45505 Mdot
.65387 .77553 Mdot
.41249 .47619 Mdot
.55267 .55106 Mdot
.40729 .28772 Mdot
.45998 .55286 Mdot
.78173 .67883 Mdot
.34521 .46649 Mdot
.61416 .46639 Mdot
.22813 .5395 Mdot
.33053 .63663 Mdot
.7842 .40559 Mdot
.2612 .5778 Mdot
.71805 .7441 Mdot
.52846 .43347 Mdot
.74194 .4681 Mdot
.34923 .30989 Mdot
.59109 .30158 Mdot
.62046 .54991 Mdot
.38332 .38142 Mdot
.59203 .5493 Mdot
.69421 .38737 Mdot
.4458 .41974 Mdot
.80417 .37063 Mdot
.67916 .37222 Mdot
.42992 .461 Mdot
.61823 .47799 Mdot
.26324 .49589 Mdot
.81895 .37719 Mdot
.67747 .39357 Mdot
.21534 .59175 Mdot
.74432 .7243 Mdot
.68047 .72075 Mdot
.71806 .23863 Mdot
.32085 .66996 Mdot
.4508 .45636 Mdot
.79932 .67058 Mdot
.48352 .4945 Mdot
.65724 .72932 Mdot
.55218 .53173 Mdot
.31857 .43827 Mdot
.79228 .34039 Mdot
.59738 .47821 Mdot
.42313 .46382 Mdot
.44262 .3276 Mdot
.26664 .46127 Mdot
.66815 .3841 Mdot
.57165 .43681 Mdot
.58335 .66402 Mdot
.56015 .25904 Mdot
.62734 .73979 Mdot
.33114 .56012 Mdot
.73945 .71648 Mdot
.75186 .69422 Mdot
.66567 .47038 Mdot
.49343 .64965 Mdot
.71514 .23807 Mdot
.42438 .43169 Mdot
.45328 .28316 Mdot
.25288 .45819 Mdot
.76536 .47911 Mdot
.6965 .72083 Mdot
.54407 .36535 Mdot
.55639 .28236 Mdot
.39284 .38514 Mdot
.81114 .43661 Mdot
.42083 .50761 Mdot
.37296 .73608 Mdot
.31014 .56259 Mdot
.21672 .59001 Mdot
.221 .53889 Mdot
.31649 .67769 Mdot
.78205 .67667 Mdot
.47471 .61797 Mdot
.44816 .57925 Mdot
.42306 .4522 Mdot
.76693 .67685 Mdot
.3333 .64837 Mdot
.41589 .69141 Mdot
.35922 .35214 Mdot
.72221 .26529 Mdot
.23229 .47421 Mdot
.43863 .59979 Mdot
.5044 .56273 Mdot
.56061 .44106 Mdot
.33435 .61996 Mdot
.33998 .59039 Mdot
.25583 .46128 Mdot
.75918 .33342 Mdot
.51303 .58526 Mdot
.58382 .5581 Mdot
.68364 .74891 Mdot
.4902 .56488 Mdot
.75342 .69586 Mdot
.37428 .42632 Mdot
.7528 .31595 Mdot
.6506 .42102 Mdot
.70816 .47885 Mdot
.50066 .33641 Mdot
.25557 .5558 Mdot
.78578 .43636 Mdot
.50671 .51534 Mdot
.49544 .62354 Mdot
.22129 .51976 Mdot
.75767 .72001 Mdot
.61162 .49148 Mdot
.40771 .80366 Mdot
.62893 .48282 Mdot
.56059 .2706 Mdot
.55373 .26185 Mdot
.40457 .62599 Mdot
.54397 .52697 Mdot
.36879 .58303 Mdot
.55164 .45912 Mdot
.35998 .33734 Mdot
.79819 .47754 Mdot
.77246 .29484 Mdot
.31962 .4533 Mdot
.73483 .74267 Mdot
.36834 .50908 Mdot
.30837 .44748 Mdot
.64805 .73517 Mdot
.50912 .62175 Mdot
.47667 .45159 Mdot
.64943 .46372 Mdot
.35222 .47331 Mdot
.76239 .28486 Mdot
.48474 .61213 Mdot
.61977 .4653 Mdot
.60371 .7533 Mdot
.43252 .60542 Mdot
.39655 .75154 Mdot
.35573 .64758 Mdot
.76803 .70931 Mdot
.73222 .71579 Mdot
.37089 .74188 Mdot
.53974 .55824 Mdot
.49508 .61835 Mdot
.77057 .33367 Mdot
.61462 .47905 Mdot
.78266 .41323 Mdot
.33453 .74087 Mdot
.36627 .32931 Mdot
.67499 .36994 Mdot
.66928 .399 Mdot
.593 .29735 Mdot
.38796 .35703 Mdot
.76422 .35636 Mdot
.63063 .50314 Mdot
.61962 .67824 Mdot
.61153 .75909 Mdot
.73906 .26215 Mdot
.30026 .58076 Mdot
.64924 .53511 Mdot
.70554 .45956 Mdot
.51191 .58303 Mdot
.60394 .416 Mdot
.38206 .53015 Mdot
.57939 .54788 Mdot
.39729 .7441 Mdot
.22371 .55319 Mdot
.81455 .43162 Mdot
.51047 .34095 Mdot
.51649 .23465 Mdot
.34484 .6188 Mdot
.54884 .71818 Mdot
.21876 .52915 Mdot
.79461 .32034 Mdot
.41893 .68801 Mdot
.37047 .77261 Mdot
.38922 .62416 Mdot
.753 .44425 Mdot
.39322 .8032 Mdot
.39622 .62097 Mdot
.81898 .64676 Mdot
.3268 .59004 Mdot
.39379 .32615 Mdot
.20164 .54267 Mdot
.69336 .385 Mdot
.38056 .38018 Mdot
.58093 .57172 Mdot
.8068 .40593 Mdot
.59366 .42946 Mdot
.60505 .46625 Mdot
.75976 .34609 Mdot
.70875 .74141 Mdot
.67772 .75533 Mdot
.3643 .61489 Mdot
.25356 .48414 Mdot
.41863 .81914 Mdot
.59287 .74771 Mdot
.32467 .25894 Mdot
.76757 .40138 Mdot
.42638 .31412 Mdot
.50525 .51109 Mdot
.38855 .5018 Mdot
.78253 .34261 Mdot
.7743 .67927 Mdot
.55529 .55911 Mdot
.59809 .67696 Mdot
.67056 .41103 Mdot
.69726 .46531 Mdot
.3544 .57039 Mdot
.75472 .42019 Mdot
.56783 .72718 Mdot
.59928 .47798 Mdot
.72163 .73468 Mdot
.25489 .5551 Mdot
.5926 .3139 Mdot
.72527 .26677 Mdot
.57639 .28143 Mdot
.68122 .76855 Mdot
.33963 .74408 Mdot
.60727 .7588 Mdot
.7421 .26842 Mdot
.32024 .57615 Mdot
.41131 .37756 Mdot
.712 .22789 Mdot
.82209 .40119 Mdot
.49728 .61761 Mdot
.50272 .32955 Mdot
.81256 .6558 Mdot
.60424 .66188 Mdot
.75469 .45235 Mdot
.34267 .31146 Mdot
.66519 .75517 Mdot
.4571 .41824 Mdot
.52199 .33838 Mdot
.5846 .46036 Mdot
.33874 .47542 Mdot
.24924 .48583 Mdot
.6076 .72939 Mdot
.69064 .75116 Mdot
.34942 .28786 Mdot
.34405 .33045 Mdot
.37311 .29892 Mdot
.33395 .50861 Mdot
.80306 .41281 Mdot
.73387 .53253 Mdot
.33828 .27935 Mdot
.76258 .32934 Mdot
.54456 .23344 Mdot
.35679 .58852 Mdot
.35502 .33611 Mdot
.64189 .4108 Mdot
.62679 .7371 Mdot
.72913 .24295 Mdot
.36447 .35481 Mdot
.8277 .38703 Mdot
.80964 .46658 Mdot
.33577 .50222 Mdot
.35423 .54113 Mdot
.58425 .43527 Mdot
.48751 .59764 Mdot
.4018 .74419 Mdot
.58858 .75495 Mdot
.67138 .72787 Mdot
.6027 .67879 Mdot
.52618 .35816 Mdot
.38756 .48951 Mdot
.78835 .42786 Mdot
.58199 .47349 Mdot
.79216 .42478 Mdot
.37588 .34136 Mdot
.47676 .34053 Mdot
.70955 .21881 Mdot
.23044 .58509 Mdot
.4928 .43041 Mdot
.65087 .51003 Mdot
.64759 .53744 Mdot
.45756 .3572 Mdot
.43343 .67586 Mdot
.63771 .43995 Mdot
.65015 .75784 Mdot
.80342 .40297 Mdot
.33353 .55473 Mdot
.58917 .43355 Mdot
.3466 .68465 Mdot
.58857 .38427 Mdot
.45309 .41457 Mdot
.41158 .69982 Mdot
.63565 .75549 Mdot
.44138 .72423 Mdot
.33452 .63194 Mdot
.41108 .60228 Mdot
.62536 .38958 Mdot
.64695 .52076 Mdot
.64219 .74601 Mdot
.4095 .62866 Mdot
.34226 .61912 Mdot
.71515 .74621 Mdot
.39639 .3635 Mdot
.32477 .68574 Mdot
.6206 .72691 Mdot
.62 .41859 Mdot
.39207 .47525 Mdot
.50639 .60491 Mdot
.35888 .25175 Mdot
.77978 .35465 Mdot
.61385 .62404 Mdot
.63288 .50347 Mdot
.38173 .23802 Mdot
.79887 .3672 Mdot
.39319 .70009 Mdot
.8291 .61066 Mdot
.51293 .6175 Mdot
.2292 .53777 Mdot
.39324 .27703 Mdot
.53681 .5067 Mdot
.40747 .24729 Mdot
.48287 .32308 Mdot
.5541 .30222 Mdot
.36159 .76315 Mdot
.54617 .50842 Mdot
.43051 .60816 Mdot
.46654 .60842 Mdot
.61197 .45202 Mdot
.41726 .24852 Mdot
.53352 .39522 Mdot
.60384 .49545 Mdot
.64896 .38313 Mdot
.57298 .54105 Mdot
.61303 .45753 Mdot
.3367 .71545 Mdot
.64208 .74861 Mdot
.67497 .75533 Mdot
.45566 .44142 Mdot
.78651 .34157 Mdot
.42474 .29672 Mdot
.76872 .40536 Mdot
.40067 .51994 Mdot
.3316 .71257 Mdot
.57307 .2789 Mdot
.72789 .24434 Mdot
.38895 .45086 Mdot
.66549 .54339 Mdot
.80503 .46635 Mdot
.77011 .42342 Mdot
.35369 .72458 Mdot
.1947 .56917 Mdot
.61265 .76058 Mdot
.59151 .44002 Mdot
.21885 .54866 Mdot
.62214 .6518 Mdot
.7762 .44905 Mdot
.53572 .46752 Mdot
.507 .62028 Mdot
.34977 .25827 Mdot
.47163 .43291 Mdot
.55474 .64636 Mdot
.36231 .2499 Mdot
.38874 .35602 Mdot
.76413 .35818 Mdot
.45229 .28957 Mdot
.4425 .53739 Mdot
.39018 .44555 Mdot
.72502 .2596 Mdot
.5398 .65309 Mdot
.54994 .25294 Mdot
.32844 .24123 Mdot
.3596 .76306 Mdot
.65745 .72652 Mdot
.72298 .27084 Mdot
.36015 .64928 Mdot
.55402 .45884 Mdot
.21211 .61862 Mdot
.39278 .44927 Mdot
.27122 .44807 Mdot
.34961 .63359 Mdot
.69562 .47597 Mdot
.39852 .46016 Mdot
.72869 .2335 Mdot
.77277 .43766 Mdot
.45972 .45049 Mdot
.32214 .26075 Mdot
.72576 .73085 Mdot
.53946 .25516 Mdot
.32487 .69951 Mdot
.80444 .41911 Mdot
.38774 .74932 Mdot
.80337 .66653 Mdot
.49155 .57259 Mdot
.36673 .50473 Mdot
.68986 .46626 Mdot
.21866 .55621 Mdot
.54701 .48987 Mdot
.34037 .32156 Mdot
.22294 .57171 Mdot
.70467 .44754 Mdot
.51718 .54529 Mdot
.34945 .4549 Mdot
.3737 .50034 Mdot
.47685 .54513 Mdot
.50793 .62577 Mdot
.44001 .59965 Mdot
.45469 .57871 Mdot
.33376 .64281 Mdot
.46174 .53528 Mdot
.23 .58823 Mdot
.37974 .63529 Mdot
.37908 .32322 Mdot
.62279 .73343 Mdot
.6273 .45614 Mdot
.59587 .66084 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0?ooooooB_ooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A006ooooo`03o`000?oooooooooo0?ooooooB_ooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0?ooooooB_oo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06
ooooo`?o0000oooooom:ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<oooo
o`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom:ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001_ooool00ol0003oooooooooo`3ooooood[ooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0>Gooooo
0_l0001Rooooo`007?ooool00ol0003oooooooooo`3Uooooo`?o0000HOooool001cooooo00?o0000
ooooooooool0hoooool6o`00063ooooo000Looooo`03o`000?oooooooooo07Cooooo0_l00008oooo
o`;o0000Hoooool6o`00063ooooo000Looooo`03o`000?oooooooooo073ooooo0_l00002ooooo`;o
00002?ooool4o`0006;ooooo0_l00002ooooo`;o0000Goooool001cooooo00?o0000ooooooooool0
K_ooool4o`0000kooooo1?l0001Oooooo`Co000000?oooooo`000?l00000Goooool001cooooo00?o
0000ooooooooool0Joooool5o`0000Gooooo0_l0000;ooooo`;o0000:Oooool2o`0003Cooooo1?l0
00001?oooooo0000o`000?l0001Nooooo`007?ooool00ol0003oooooooooo`1Xooooo`;o000000?o
ooooo`000?l000000_l00006ooooo`;o0000;Oooool2o`0000;ooooo0_l00003ooooo`;o0000=ooo
ool2o`000003ooooool0003o000005kooooo000Looooo`03o`000?oooooooooo06Sooooo0_l0000>
ooooo`;o00002?ooool2o`0001oooooo0ol00002ooooo`;o0000>_ooool4o`00067ooooo000Loooo
o`03o`000?oooooooooo06Oooooo0ol0000>ooooo`;o00002?ooool2o`000003ooooool0003o0000
01cooooo0ol0000nooooo`Co000000Coooooo`000?l0003o0000GOooool001cooooo00?o0000oooo
ooooool0Ioooool4o`0001;ooooo0_l00004ooooo`Co00000oooool2o`0001Sooooo0ol0000ooooo
o`;o000000?oooooo`000?l000000_l0001Looooo`007?ooool00ol0003oooooooooo`1Sooooo`;o
00001?ooool2o`0000Gooooo1?l000000ooooooo0000o`000006ooooo`;o00000_ooool8o`000003
ooooool0003o000001Sooooo0ol0000:ooooo`;o0000=_ooool4o`0005cooooo000Looooo`;o0000
I?ooool2o`0000_ooooo1?l000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l00000
1ol000000ooooooo0000o`00000Uooooo`;o0000>?ooool3o`0005_ooooo000Looooo`03o`000?oo
oooooooo05oooooo0_l000000ooooooo0000o`00000;ooooo`Go00000oooool2o`0000?ooooo0_l0
00000ooooooo0000o`00000;o`0001oooooo0_l00002ooooo`;o00001_ooool4o`0002cooooo0_l0
0003ooooo`;o0000Foooool001cooooo00?o0000ooooooooool0G_ooool6o`0000[ooooo0ol00006
ooooo`Co000000Coooooo`000?l0003ooooo3?l0000Pooooo`;o00000_ooool2o`0000Cooooo1_l0
000/ooooo`;o00000_ooool4o`0005[ooooo000Looooo`03o`000?oooooooooo05kooooo0_l00000
1Ooooooo0000o`000?l0003ooooo00?o00001_ooool2o`0000Sooooo1?l000000ooooooo0000o`00
000@o`0002?ooooo0_l000000ooooooo0000o`000005o`0002cooooo0_l000000ooooooo0000o`00
0002o`0005[ooooo000Looooo`03o`000?oooooooooo06;ooooo1_l0000@ooooo`Co000000?ooooo
o`000?l000004Ol0000Pooooo`Co00001?ooool5o`0002_ooooo0_l000000ooooooo0000o`000003
o`0005Wooooo000Looooo`03o`000?oooooooooo06;ooooo1?l0000Booooo`;o00001?ooool>o`00
00;ooooo0_l0000Pooooo`Co00001_ooool3o`0002[ooooo0ol000000ooooooo0000o`000003o`00
05Wooooo000Looooo`03o`000?oooooooooo06;ooooo1_l0000@ooooo`;o00001?ooool>o`0002Co
oooo1?l00007ooooo`;o0000:_ooool3o`0000?ooooo0_l0001Jooooo`007?ooool00ol0003ooooo
ooooo`1Uooooo`Co00005Oooool?o`0002Gooooo0_l00004ooooo`;o000000?oooooo`000?l00000
0_l0000Xooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00001Gooooo`00
7?ooool00ol0003oooooooooo`1Vooooo`Co00003_ooool2o`0000;ooooo4Ol00002ooooo`;o0000
9oooool2o`0000?ooooo0_l0000Xooooo`Go00001?ooool2o`0005Oooooo000Looooo`03o`000?oo
oooooooo06Oooooo1Ol0000<ooooo`;o00000_oooolEo`0002Gooooo0_l00007ooooo`;o00009ooo
ool2o`0000Wooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`1Wooooo`Go00004?ooool2
o`000003ooooool0003o0000013o00008?ooool2o`0000?ooooo0ol00006ooooo`;o0000<_ooool2
o`0005Cooooo000Looooo`03o`000?oooooooooo06Oooooo1Ol0000=ooooo`;o000000Coooooo`00
0?l0003ooooo4_l0000Pooooo`;o00001?ooool2o`0000;ooooo0_l00002ooooo`?o0000<_ooool2
o`0005?ooooo000Looooo`03o`000?oooooooooo06Sooooo1?l00002ooooo`;o00001?ooool2o`00
00?ooooo0ol00002oooooa;o0000:oooool2o`0000;ooooo0ol0000Yooooo`;o00001oooool2o`00
05?ooooo000Looooo`03o`000?oooooooooo06Oooooo1Ol00002ooooo`;o00001?ooool2o`0000?o
oooo0ol00002ooooo`;o000000?oooooo`000?l000003_l0000Mooooo`?o00002_ooool2o`0000?o
oooo0ol0000Xooooo`;o00000oooool2o`0000Gooooo0_l0001@ooooo`007?ooool00ol0003ooooo
ooooo`1Wooooo`Oo00005_ooool=o`0001gooooo0ol00002ooooo`So00001Oooool3o`0002Oooooo
0_l00004ooooo`;o00001Oooool2o`00053ooooo000Looooo`03o`000?oooooooooo06Oooooo0ol0
00001?oooooo0000o`000?l00005ooooo`;o00001Oooool3o`0000Wooooo1_l000001?oooooo0000
o`000?l0000Sooooo`Wo000000?oooooo`000?l000000_ooool2o`0002Oooooo0_l0000;ooooo`;o
0000D?ooool001cooooo0_l0001Xooooo`;o00000_ooool3o`0000;ooooo0_l000000ooooooo0000
o`000003o`0000;ooooo1?l00008ooooo`;o00000oooool4o`0002;ooooo1Ol000000ooooooo0000
o`000006o`0000;ooooo1?l0000Wooooo`;o000000?oooooo`000?l000002Oooool3o`0004cooooo
000Looooo`03o`000?oooooooooo06[ooooo1?l00002ooooo`;o00000oooool3o`0000?ooooo0ol0
000=ooooo`;o00008oooool5o`0000?ooooo1_l00004ooooo`?o00009oooool5o`0000Wooooo0ol0
001<ooooo`007?ooool00ol0003oooooooooo`1Zooooo`Co00000oooool2o`0000Sooooo0_l0000>
ooooo`;o00000_ooool2o`0001oooooo1?l00006ooooo`;o00001_ooool3o`0002Sooooo0_l0000=
ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0Joooool5o`000003ooooool0003o0000
00Sooooo0_l0000Booooo`Go00007_ooool2o`0000Oooooo1Ol00002ooooo`Co00009oooool4o`00
00_ooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`1/ooooo`Co00002oooool2o`0001Co
oooo0ol0000Wooooo`Go00000_ooool4o`0002Oooooo1?l0001Hooooo`007?ooool00ol0003ooooo
ooooo`1/ooooo`?o00002oooool3o`0000;ooooo0_l00006ooooo`;o0000<oooool3o`0000Cooooo
0_l0000/ooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0K?ooool3o`0000Kooooo0_l0
0003ooooo`Co000000?oooooo`000?l000001_ooool2o`000003ooooool0003o000000?ooooo0ol0
0005ooooo`;o00001?ooool2o`0001gooooo1Ol00003ooooo`;o0000:oooool2o`0000Gooooo0_l0
001?ooooo`007?ooool00ol0003oooooooooo`1[ooooo`Co00001_ooool9o`0000Sooooo1_l00002
ooooo`go00000_ooool2o`00013ooooo0_l0000=ooooo`?o00000oooool3o`00037ooooo0_l00004
ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0Joooool3o`0000Wooooo1ol00007oooo
o`Oo00000_ooool2o`000003ooooool0003o000000[o00004Oooool3o`0000gooooo0ol00003oooo
o`?o0000<_ooool2o`0000?ooooo1?l00017ooooo`007?ooool00ol0003oooooooooo`1^ooooo`;o
00000oooool2o`0000Gooooo1?l00004ooooo`;o000000?oooooo`000?l000001?ooool3o`0000Oo
oooo2ol0000>ooooo`;o00003oooool3o`0000;ooooo1?l0000/ooooo`;o00000oooool2o`0000?o
oooo1?l00017ooooo`007?ooool00ol0003oooooooooo`1/ooooo`Co00000oooool2o`0000gooooo
0ol00005ooooo`[o00000oooool;o`0001kooooo0ol000000ooooooo0000o`000002o`0002cooooo
0_l000000ooooooo0000o`000004ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0K?oo
ool2o`000003ooooool0003o0000013ooooo1?l000000ooooooo0000o`00000=o`000003ooooool0
003o000000_o00007Oooool3o`0000;ooooo0_l0000/ooooo`;o000000Coooooo`000?l0003o0000
1?ooool2o`0004[ooooo000Looooo`03o`000?oooooooooo06kooooo1Ol00006ooooo`;o00001_oo
ool2o`0000?ooooo3ol000000ooooooo0000o`000004o`0000?ooooo1_l000000ooooooo0000o`00
000Hooooo`;o00000_ooool4o`0002_ooooo0_l000001?oooooo0000o`000?l00002ooooo`;o0000
C?ooool001cooooo00?o0000ooooooooool0K_ooool5o`0000?ooooo0_l000000ooooooo0000o`00
000:ooooob?o00006?ooool3o`000003ooooool0003o000000;o0000<oooool5o`0004Wooooo000L
ooooo`03o`000?oooooooooo06oooooo0ol00004ooooo`;o00002?ooool2o`0000?ooooo1_l00000
0ooooooo0000o`00000Io`0001Wooooo0ol00002ooooo`?o0000<_ooool6o`0004Wooooo000Loooo
o`03o`000?oooooooooo077ooooo0_l0000<ooooo`?o00000oooool3o`0000Gooooo2Ol000000ooo
oooo0000o`00000?o`0001Sooooo2?l0000[ooooo`;o00001Oooool2o`0004gooooo000Looooo`;o
0000L_ooool2o`0000cooooo0ol000000ooooooo0000o`000002o`0000Oooooo2?l000000ooooooo
0000o`00000Bo`0001Oooooo1_l0000[ooooo`;o00002oooool2o`0004Oooooo000Looooo`03o`00
0?oooooooooo06oooooo1?l0000=ooooo`;o000000?oooooo`000?l000000_l00008ooooo`Ko0000
0_oooolDo`0001Gooooo0_l00002ooooo`Co0000:oooool2o`000003ooooool0003o000000Sooooo
0_l00002ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0Koooool6o`0000Gooooo0ol0
0007ooooo`;o00002OoooolKo`0001Kooooo0_l00002ooooo`Co0000:oooool5o`000003ooooool0
003o000000Sooooo1Ol00011ooooo`007?ooool00ol0003oooooooooo`1_ooooo`Ko00001Oooool3
o`0000Kooooo0_l0000<oooooa[o00005?ooool3o`0000;ooooo1?l0000/ooooo`;o00000oooool2
o`0000Sooooo0_l000000ooooooo0000o`000011ooooo`007?ooool00ol0003oooooooooo`1_oooo
o`Co00003?ooool2o`0000;ooooo0_l0000<oooooa[o00005?ooool3o`000003ooooool0003o0000
00?o0000;?ooool2o`0000;ooooo0_l00005ooooo`;o0000B?ooool001cooooo00?o0000oooooooo
ool0LOooool2o`0000[ooooo1?l00002ooooo`?o00003OoooolHo`0000;ooooo0_l0000Cooooo`Go
00004Oooool3o`0001gooooo0_l00005ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0
L?ooool2o`0000Kooooo0_l00003ooooo`;o00001?ooool3o`0000gooooo6Ol000001?oooooo0000
o`000?l0000>ooooo`Wo00003oooool5o`0001Wooooo0_l0000:ooooo`;o00001Oooool2o`00043o
oooo000Looooo`03o`000?oooooooooo073ooooo1Ol00003ooooo`;o00006OoooolIo`0000;ooooo
0ol0000=ooooo`Oo00003oooool7o`0001Wooooo0_l0000:ooooo`?o00001?ooool2o`00043ooooo
000Looooo`03o`000?oooooooooo077ooooo1?l0000OoooooaOo000000Coooooo`000?l0003ooooo
0_l0000<ooooo`;o000000?oooooo`000?l000000ol00008ooooo`?o00001?ooool2o`000003oooo
ool0003o000000;o00009_ooool2o`0004Kooooo000Looooo`03o`000?oooooooooo077ooooo0ol0
0007ooooo`;o00001Oooool2o`00013ooooo6_l0000>ooooo`Oo00002?ooool6o`0000;ooooo0_l0
0008ooooo`;o00009Oooool4o`00047ooooo000Looooo`03o`000?oooooooooo07;ooooo0ol00003
ooooo`Go00001Oooool2o`00013ooooo6Ol0000?ooooo`Ko00002Oooool7o`000003ooooool0003o
000000Cooooo1_l0000Uooooo`Co0000@Oooool001cooooo00?o0000ooooooooool0Loooool2o`00
00?ooooo0ol000000ooooooo0000o`00000Gooooo`?o000000?oooooo`000?l000004ol000000ooo
oooo0000o`00000:ooooo`Oo00001oooool9o`0000?ooooo0_l00002ooooo`Go00008oooool2o`00
04Kooooo000Looooo`03o`000?oooooooooo07cooooo0_l00002ooooo`;o00005?oooolHo`000003
ooooool0003o000000[ooooo1_l00008ooooo`;o000000?oooooo`000?l000000ol00004ooooo`;o
00001?ooool5o`00023ooooo0ol00006ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0
O?ooool3o`000003ooooool0003o000000?ooooo0_l0000AoooooaKo00000_ooool2o`0000[ooooo
1?l00007ooooo`Co00004?ooool5o`0001cooooo0_l00002ooooo`;o00001oooool2o`0003kooooo
00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@oooooooo
ool01?ooool00ol0003oooooooooo`1mooooo`;o000000?oooooo`000?l000000oooool2o`00017o
oooo5ol000001?oooooo0000o`000?l00009ooooo`?o00002?ooool4o`0000gooooo0_l00002oooo
o`Co00007?ooool2o`0000_ooooo0_l0000nooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5
ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07Cooooo0_l0000R
oooooa_o00001_ooool4o`0000Oooooo0ol00002ooooo`Co00002oooool8o`0002Wooooo0_l0000n
ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`Go00001_ooool00ol0
003oooooooooo`1dooooo`;o00002oooool2o`0001Oooooo6Ol00005ooooo`Go00001Oooool5o`00
00Cooooo0_l00008ooooo`?o00000_ooool8o`0001Sooooo0_l0000<ooooo`;o0000?oooool00003
ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?m4A4CogMgMooooool00007oooo
o`?o0000M?ooool2o`000003ooooool0003o000000Sooooo0_l00006ooooo`;o00004?oooolGo`00
00Gooooo1?l00006ooooo`?o00001oooool2o`0000Sooooo0ol00005ooooo`Go00005?ooool2o`00
00;ooooo0_l00005ooooo`;o00001?ooool3o`0003oooooo00000ooooooo0000ooooo`02ooooo`03
o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`1doooo
o`Go00004?ooool2o`00017ooooo5_l00005ooooo`?o00001_ooool3o`0000[ooooo0_l0000=oooo
o`?o000000?oooooo`000?l000005?ooool3o`0000;ooooo0ol00003ooooo`?o00000oooool2o`00
043ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oMgMgolc<c?l0
00001oooool00ol0003oooooooooo`1dooooo`?o00003?ooool2o`0001Oooooo5?l00005ooooo`Co
00001oooool2o`0000_ooooo0_l0000<ooooo`Co000000?oooooo`000?l000005?ooool3o`0000;o
oooo0ol00004ooooo`;o00001?ooool2o`0003oooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMg
M`cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`20ooooo`Go00000oooool2o`00
01Gooooo3?l000000ooooooo0000o`000002o`0000;ooooo1ol00004ooooo`;o00002_ooool2o`00
00;ooooo0_l00007ooooo`;o00000oooool5o`0001?ooooo0_l0000Cooooo`?o0000?_ooool00006
ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooo
oooo083ooooo0ol00005ooooo`;o00001Oooool2o`0000oooooo1Ol000000ooooooo0000o`000003
o`0000;ooooo0_l00002ooooo`Ko00001_ooool2o`0000[ooooo0_l00002ooooo`;o00001oooool2
o`0000?ooooo1Ol0000Cooooo`;o00001?ooool3o`0000;ooooo0_l000000ooooooo0000o`000005
ooooo`?o0000?_ooool001cooooo00?o0000ooooooooool0MOooool2o`00013ooooo0_l00006oooo
o`Co00003oooool5o`000003ooooool0003o000000Co00000oooool4o`0000Sooooo0_l000001?oo
oooo0000o`000?l00003ooooo`Co00001_ooool2o`0000Wooooo1ol0000Fooooo`Co00000_ooool2
o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`00000oooooo`007?ooool00ol0
003oooooooooo`1eooooo`?o00003oooool5o`000003ooooool0003o000000;ooooo0_l0000Boooo
o`;o000000?oooooo`000?l000001?l00009ooooo`;o00001oooool3o`000003ooooool0003o0000
00Co00000_ooool3o`000003ooooool0003o000000;o00002?ooool3o`000003ooooool0003o0000
00oooooo0_l00002ooooo`;o000000?oooooo`000?l000001oooool3o`000003ooooool0003o0000
04;ooooo000Looooo`03o`000?oooooooooo07Kooooo0ol0000?ooooo`Co000000?oooooo`000?l0
00009Oooool2o`000003ooooool0003o000000_ooooo0_l00006ooooo`?o000000?oooooo`000?l0
00000_l000001?oooooo0000o`000?ooool9o`00013ooooo0_l00002ooooo`?o00001_ooool2o`00
0003ooooool0003o000000;o0000A?ooool001cooooo00?o0000ooooooooool0M_ooool3o`0001?o
oooo1?l0000?ooooo`;o00004oooool6o`0000cooooo0_l00004ooooo`;o00001oooool2o`000003
ooooool0003o000000Co000000?oooooo`000?l000005Oooool2o`0000Cooooo1?l00003ooooo`;o
00001?ooool2o`0003kooooo000Looooo`03o`000?oooooooooo05Wooooo1?l00006ooooo`;o0000
4Oooool3o`000003ooooool0003o0000013ooooo1Ol00005ooooo`;o00001?ooool5o`0001?ooooo
1_l00003ooooo`;o00000oooool3o`000003ooooool0003o000000Cooooo0_l00008ooooo`So0000
7_ooool2o`0000_ooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`1Hooooo`oo00004ooo
ool2o`0000[ooooo0_l00007ooooo`?o00000oooool3o`0000Cooooo0ol00006ooooo`;o000000?o
ooooo`000?l000001?ooool2o`0000;ooooo0_l00004ooooo`Oo00000oooool3o`00017ooooo1?l0
00001?oooooo0000o`000?l0000Nooooo`Co00001Oooool2o`0004;ooooo000Looooo`03o`000?oo
oooooooo05Sooooo0_l000000ooooooo0000o`000007o`000004ooooool0003o0000ooooo`?o0000
6oooool2o`0000Kooooo1?l00003ooooo`Go00002oooool2o`000003ooooool0003o000000Cooooo
0_l00002ooooo`;o000000Goooooo`000?l0003o0000ooooo`05o`0001Cooooo2?l0000Gooooo`;o
00000oooool2o`0000?ooooo1Ol00004ooooo`?o0000@_ooool001cooooo00?o0000ooooooooool0
Doooool2o`0000;ooooo3ol000000ooooooo0000o`000002o`0001Oooooo0_l0000:ooooo`;o0000
1Oooool5o`0000Cooooo0_l00005ooooo`;o00001_ooool2o`0000Kooooo0ol00002ooooo`Co0000
1Oooool2o`0000Kooooo3_l0000Hooooo`;o00000oooool3o`0000;ooooo0ol00006ooooo`;o0000
@oooool001cooooo00?o0000ooooooooool0Doooool:o`000003ooooool0003o000000;o00000_oo
ool2o`000003ooooool0003o000000Co00002_ooool2o`000003ooooool0003o000000Kooooo0_l0
000<ooooo`;o00003?ooool2o`0000Gooooo0ol00005ooooo`;o000000?oooooo`000?l000001?l0
0006ooooo`Co00000oooool2o`0000;ooooo0_l00002ooooo`[o00008_ooool2o`0000;ooooo1Ol0
0019ooooo`007?ooool00ol0003oooooooooo`1>ooooo`Co00000oooool2o`0000Wooooo0_l00007
ooooo`Co00002_ooool2o`000004ooooool0003o0000o`0001?ooooo0_l0000Dooooo`;o00002?oo
ool6o`0000Kooooo1Ol00003ooooo`Go00000_ooool6o`0001Gooooo0_l000000ooooooo0000o`00
0004ooooo`Co00002oooool2o`0000Cooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`1>
ooooo`Co00000_ooool2o`0000[ooooo0_l0000:ooooo`?o00002?ooool2o`0000;ooooo0ol0000h
ooooo`;o00001?ooool5o`0000?ooooo1Ol00002ooooo`;o00004Oooool2o`000003ooooool0003o
000000?ooooo0_l000000ooooooo0000o`000004ooooo`Co00000_ooool5o`0000[ooooo0_l00013
ooooo`007?ooool2o`0004oooooo0_l00002ooooo`Co00000_ooool3o`0000Gooooo0_l0000:oooo
o`?o00003?ooool3o`0000Sooooo0_l0000:ooooo`;o00000oooool4o`0001_ooooo0_l0000;oooo
o`;o00006Oooool2o`000003ooooool0003o000000Cooooo0ol00007ooooo`;o00000_ooool5o`00
00cooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o00000_ooool2o`0000;o
oooo0_l00004ooooo`?o00001oooool4o`0000Kooooo1?l0000;ooooo`;o00002Oooool2o`0000[o
oooo0_l00003ooooo`Co00003Oooool2o`0000?ooooo0_l00005ooooo`;o00002Oooool2o`0000;o
oooo0_l00003ooooo`;o00007Oooool3o`0000Oooooo0_l00004ooooo`;o00003Oooool2o`00047o
oooo000Looooo`03o`000?oooooooooo04[ooooo0_l00002ooooo`;o00001?ooool2o`0000cooooo
1_l00004ooooo`Co00001oooool2o`0000[ooooo0_l0000:ooooo`;o00005oooool2o`0000?ooooo
0_l00005ooooo`;o00002Oooool2o`0000;ooooo0_l00003ooooo`Co00007_ooool2o`0000_ooooo
0_l0001@ooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00000oooool3o`0000;ooooo0ol0
000;ooooo`Oo00001_ooool2o`0000Oooooo0_l00005ooooo`;o00000oooool2o`0000;ooooo0ol0
0005ooooo`;o00002_ooool2o`0001;ooooo1?l00007ooooo`;o00001oooool2o`0000?ooooo1Ol0
0005ooooo`;o00003Oooool2o`0000Oooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`19
ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00001_ooool2o`000003ooooool0
003o000000_o000000?oooooo`000?l000000_l00007ooooo`;o00000_ooool2o`000003ooooool0
003o000000Kooooo1?l0000Aooooo`;o00004_ooool4o`0000Oooooo0_l0000?ooooo`;o00000_oo
ool2o`000003ooooool0003o000000gooooo0_l0000Fooooo`;o00001oooool2o`000003ooooool0
003o000004;ooooo000Looooo`03o`000?oooooooooo04Wooooo1Ol0000=oooooaGo00001oooool2
o`0000;ooooo0_l00002ooooo`;o00001Oooool2o`0002;ooooo0_l0000@ooooo`;o00000oooool2
o`000003ooooool0003o000000;o00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000008
ooooo`;o000000?oooooo`000?l000000_l0000Fooooo`;o00001oooool5o`0004;ooooo000Loooo
o`03o`000?oooooooooo04Wooooo1?l0000<oooooaSo00001_ooool2o`0000Kooooo0_l0000Hoooo
o`;o00003oooool2o`00013ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l00003oooo
o`;o00001Oooool4o`0000Kooooo0_l000000ooooooo0000o`000003o`0000Wooooo0_l00004oooo
o`;o00003Oooool5o`0004;ooooo000Looooo`03o`000?oooooooooo04Gooooo0ol0000Aoooooa?o
00000oooool2o`0000Kooooo0_l0000Pooooo`;o00000_ooool2o`0001Oooooo0_l000000ooooooo
0000o`00000Iooooo`;o00003?ooool2o`0000Oooooo1_l00002ooooo`;o000000?oooooo`000?l0
00002_ooool5o`0004;ooooo000Looooo`03o`000?oooooooooo04Gooooo1_l0000=oooooaCo0000
0oooool2o`0000Oooooo0_l00002ooooo`;o00001?ooool2o`0001Wooooo0_l0000Gooooo`;o0000
00?oooooo`000?l000000_l00009ooooo`?o00005Oooool2o`0000Kooooo0_l000000ooooooo0000
o`000009o`0000;ooooo0_l00002ooooo`?o000000?oooooo`000?l000000_ooool4o`0004?ooooo
000Looooo`03o`000?oooooooooo04Gooooo1_l000000ooooooo0000o`000009oooooaGo00000_oo
ool2o`0000Oooooo0ol00002ooooo`;o00001?ooool2o`0001Gooooo0_l0000Mooooo`;o000000?o
ooooo`000?l000001?l00003ooooo`Go00005Oooool2o`0000;ooooo0_l000000ooooooo0000o`00
0004o`000003ooooool0003o000000_o000000Goooooo`000?l0003o0000ooooo`05o`000003oooo
ool0003o000004?ooooo000Looooo`03o`000?oooooooooo04Cooooo0_l000000ooooooo0000o`00
0003ooooo`;o00001?ooool2o`000003ooooool0003o000001Go00000_ooool3o`0000Kooooo0ol0
0003ooooo`;o00001_ooool2o`0001;ooooo0_l0000=ooooo`;o00003_ooool9o`0000?ooooo0ol0
0002ooooo`;o00005oooool2o`000003ooooool0003o000001;o00000_ooool2o`000003ooooool0
003o000000?o0000A_ooool001cooooo00?o0000ooooooooool0A?ooool2o`0000Oooooo1?l00000
1?oooooo0000o`000?ooool5o`000003ooooool0003o000000oo000000?oooooo`000?l000000_l0
000<ooooo`;o00001_ooool2o`00027ooooo0_l0000@ooooo`;o00002?ooool2o`0000?ooooo0_l0
000Hooooo`;o000000?oooooo`000?l000004?l00007ooooo`Co0000A_ooool001cooooo00?o0000
ooooooooool0A?ooool2o`0000Oooooo1?l00002oooooaWo000000?oooooo`000?l000000_l00009
ooooo`;o00009_ooool2o`0002Cooooo0_l00002ooooo`;o00001Oooool2o`0000_ooooo1Ol00000
0ooooooo0000o`00000?o`0000Sooooo1?l00016ooooo`007?ooool00ol0003oooooooooo`13oooo
o`Oo00000oooool4o`000003ooooool0003o000001So000000Coooooo`000?l0003o00002_ooool2
o`0000Gooooo0_l0000Oooooo`;o00001_ooool2o`0000;ooooo0_l0000Booooo`?o00000oooool2
o`0000;ooooo0_l00005ooooo`;o00002ooooolIo`0000;ooooo1?l000000ooooooo0000o`000017
ooooo`007?ooool00ol0003oooooooooo`13ooooo`Wo00001Oooool3o`000003ooooool0003o0000
01Oo00001oooool3o`0000Wooooo0_l0000Fooooo`;o00003oooool2o`0000;ooooo0_l0000;oooo
o`?o00000_ooool5o`0000Oooooo0_l00003ooooo`;o00003OoooolIo`000003ooooool0003o0000
00?o000000?oooooo`000?l00000Aoooool001cooooo00?o0000ooooooooool0@Oooool2o`0000Go
oooo1?l00005oooooako00001_ooool3o`0001oooooo1?l0000Eooooo`;o00002Oooool3o`0000;o
oooo0_l000000ooooooo0000o`000002ooooo`?o00001oooool2o`0000Wooooo0_l000000ooooooo
0000o`00000Ko`0000Cooooo0_l00017ooooo`007?ooool2o`0004;ooooo0_l000000ooooooo0000
o`000004ooooo`;o00001OoooolNo`0000Gooooo1?l00002ooooo`;o00006oooool2o`0001Oooooo
0_l0000=ooooo`go00003ooooolQo`0000?ooooo0_l00018ooooo`007?ooool00ol0003ooooooooo
o`0nooooo`;o00001?ooool2o`0000Cooooo0_l00004oooooago00001_ooool5o`0000;ooooo0_l0
000Pooooo`;o00000_ooool2o`0000_ooooo0_l0000?ooooo`oo00002ooooolTo`0000?ooooo0_l0
0018ooooo`007?ooool00ol0003oooooooooo`0nooooo`?o00000oooool2o`0000Sooooo7Ol00000
0ooooooo0000o`000005ooooo`?o00003oooool2o`0001Gooooo0_l00002ooooo`;o00002Oooool4
o`0000;ooooo0_l00006ooooo`;o00000_ooool@o`0000?ooooo1Ol00003oooooaSo000000?ooooo
o`000?l000001ol00002ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0?Oooool4o`00
00?ooooo0_l00002ooooo`;o00001?oooolPo`0000Kooooo0_l0000?ooooo`;o00006Oooool2o`00
00Cooooo0_l00003ooooo`;o000000?oooooo`000?l000000ol00005ooooo`?o00000_oooolAo`00
00;ooooo1_l00002ooooob;o00000_ooool2o`0004_ooooo000Looooo`03o`000?oooooooooo03go
oooo1?l00007ooooo`;o00001OoooolMo`0000Oooooo1Ol00002ooooo`;o00009?ooool2o`0000Co
oooo0_l00006ooooo`Co00001_ooool3o`000003ooooool0003o0000013o00000_ooool2o`0000;o
oooo0_l00002ooooo`Co000000?oooooo`000?l000000_l000000ooooooo0000o`00000Do`0000?o
oooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`0mooooo`Co00001oooool2o`0000Gooooo
0_l00002oooooaSo00001oooool6o`0000;ooooo0_l0000:ooooo`;o00006Oooool3o`0000[ooooo
0_l0000;oooooa?o00001_ooool3o`000003ooooool0003o000000;o00000_ooool=o`000003oooo
ool0003o000000So00001?ooool3o`0004cooooo000Looooo`03o`000?oooooooooo03gooooo1?l0
0003ooooo`;o000000?oooooo`000?l000000ol00003ooooo`;o00000_oooolHo`0000Oooooo0_l0
00000ooooooo0000o`000002ooooo`;o00000oooool2o`0000Kooooo0_l0000Iooooo`?o00002?oo
ool4o`0000Oooooo0_l00002oooooago000000Coooooo`000?l0003o00000_ooool6o`000003oooo
ool0003o000000ko000000?oooooo`000?l000000_ooool2o`0004gooooo000Looooo`03o`000?oo
oooooooo03gooooo0ol00004ooooo`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o0000
0_oooolEo`0000[ooooo0_l00005ooooo`;o00000oooool2o`0002Wooooo0_l000001?oooooo0000
o`000?l00008ooooo`;o00000_oooolIo`0000;ooooo0_l00002ooooo`;o00001?ooool@o`0000Go
oooo0ol0001Aooooo`007?ooool00ol0003oooooooooo`0mooooo`Co00003_ooool3o`0000;ooooo
5?l00009ooooo`;o00001?ooool2o`0000Wooooo0_l0000Sooooo`Co00000_ooool2o`0000Oooooo
0_l00002oooooaKo00000_ooool3o`0000gooooo2?l00002ooooo`;o000000?oooooo`000?l00000
1?ooool3o`00057ooooo000Looooo`03o`000?oooooooooo03gooooo1?l00002ooooo`;o00002?oo
ool2o`000003ooooool0003o000000?ooooo4?l0000:ooooo`Co00001?ooool2o`0000Wooooo0_l0
000Sooooo`;o00001?ooool2o`0000Oooooo0_l00002oooooaoo00002Oooool?o`0005Sooooo000L
ooooo`03o`000?oooooooooo03cooooo0ol00004ooooo`;o00001?ooool2o`0000;ooooo0_l00000
0ooooooo0000o`000004ooooo`ko00002_ooool3o`0000Gooooo1?l0000cooooo`;o000000Cooooo
o`000?l0003o00001ooooolOo`0000?ooooo1?l00002ooooo`;o000000?oooooo`000?l000001_l0
00001?oooooo0000o`000?l0001Hooooo`007?ooool00ol0003oooooooooo`0looooo`;o00002ooo
ool2o`0000Gooooo0_l0000:ooooo`Co00003_ooool3o`0000Gooooo1?l0000Hooooo`;o00007?oo
ool3o`0000Sooooo5ol000001Ooooooo0000o`000?l0003ooooo00;o00000oooool5o`000003oooo
ool0003o000000;ooooo0_l00003ooooo`;o0000G?ooool001cooooo00?o0000ooooooooool0?Ooo
ool4o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`Oo00002Oooool2o`0000oooooo1?l0
0008ooooo`;o00004Oooool2o`0000Cooooo0_l0000Woooooa_o000000?oooooo`000?l000000_l0
00000ooooooo0000o`000003o`0006Sooooo000Looooo`03o`000?oooooooooo03gooooo1?l00003
ooooo`Go00000oooool8o`0001Sooooo1Ol00004ooooo`;o00000_ooool2o`00017ooooo0_l00007
ooooo`;o00001oooool2o`0000[ooooo0_l00002ooooo`;o00001_ooool3o`0000;ooooo7?l00000
0ooooooo0000o`000006o`0006Wooooo000Looooo`03o`000?oooooooooo03[ooooo0_l00002oooo
o`;o00001_ooool2o`0000[ooooo1?l0000Eooooo`?o000000?oooooo`000?l000001?ooool2o`00
01kooooo0_l00007ooooo`;o00002_ooool2o`0000;ooooo0_l00006ooooo`?o00000_oooolHo`00
0003ooooool0003o000000;o00000oooool2o`0006cooooo000Looooo`03o`000?oooooooooo03[o
oooo0_l00002ooooo`Co000000?oooooo`000?l000003Oooool4o`0001?ooooo1Ol0000Yooooo`;o
00002oooool4o`00013ooooo0_l000000ooooooo0000o`00000Eo`0000;ooooo1?l0001aooooo`00
7?ooool2o`0003cooooo0_l00003ooooo`;o000000?oooooo`000?l000000oooool2o`0000[ooooo
0ol0000@ooooo`Go00009_ooool2o`0000?ooooo0_l0000;ooooo`Co000000?oooooo`000?l00000
0_ooool2o`000003ooooool0003o000000Kooooo0_l000000ooooooo0000o`00000Co`000003oooo
ool0003o000007Kooooo000Looooo`03o`000?oooooooooo03_ooooo0_l00004ooooo`Ko000000?o
ooooo`000?l000002_ooool3o`00013ooooo1Ol00002ooooo`;o00008_ooool2o`0001Gooooo0_l0
0002ooooo`;o000000?oooooo`000?l000002oooool?o`000005ooooool0003o0000o`000?ooool0
0ol000000ooooooo0000o`00001booooo`007?ooool00ol0003oooooooooo`0iooooo`;o00001_oo
ool6o`0000Sooooo0_l00008ooooo`;o000000?oooooo`000?l000003Ol00003ooooo`;o00001_oo
ool2o`0001[ooooo0_l0000Eooooo`;o00003Oooool2o`0000Gooooo2ol00005ooooo`Go000000?o
ooooo`000?l00000L_ooool001cooooo00?o0000ooooooooool0>Oooool2o`0000Sooooo0_l0000:
ooooo`;o00002?ooool2o`000003ooooool0003o000000go00002oooool2o`0003Cooooo0_l00002
ooooo`?o00000oooool7o`0000Kooooo2Ol00002ooooo`Co0000Moooool001cooooo00?o0000oooo
ooooool0>Oooool2o`000003ooooool0003o0000013ooooo0ol0000>ooooo`Co00000oooool4o`00
00Oooooo0_l0000]ooooo`;o00002Oooool3o`0000;ooooo0ol00003ooooo`;o00000_ooool3o`00
00gooooo1ol0001hooooo`007?ooool00ol0003oooooooooo`0looooo`;o00002Oooool2o`0000Go
oooo0_l0000?ooooo`Co000000?oooooo`000?l000002oooool2o`0000Cooooo0_l0000Rooooo`;o
00000oooool2o`0000Wooooo0_l000000ooooooo0000o`00000Jooooo`Oo0000N?ooool001cooooo
00?o0000ooooooooool0>Oooool2o`000003ooooool0003o000000Wooooo0_l00008ooooo`;o0000
3_ooool2o`000003ooooool0003o0000017ooooo0_l0000Rooooo`;o00004Oooool2o`0001[ooooo
0_l0001mooooo`007?ooool00ol0003oooooooooo`0iooooo`;o000000?oooooo`000?l000001ooo
ool4o`0000Cooooo0_l00002ooooo`;o00003_ooool2o`0000cooooo0_l0000Mooooo`;o00001ooo
ool2o`0000?ooooo0_l0000Dooooo`;o00001Oooool2o`0008kooooo000Looooo`03o`000?oooooo
oooo03Wooooo0ol00002ooooo`;o00001Oooool2o`0000Kooooo0_l00004ooooo`;o00001oooool2
o`00017ooooo0_l0000Mooooo`;o00001oooool3o`0000;ooooo0_l00002ooooo`Co00001_ooool2
o`0000Kooooo0_l000000ooooooo0000o`000002ooooo`;o0000S_ooool001cooooo00?o0000oooo
ooooool0>Oooool3o`0000;ooooo0_l00005ooooo`?o00002Oooool4o`0000Oooooo0_l00006oooo
o`;o00006Oooool2o`0000oooooo0ol00005ooooo`;o00001_ooool4o`0000Kooooo0_l00009oooo
o`;o0000T_ooool001cooooo00?o0000ooooooooool0>_ooool2o`0000[ooooo0_l00009ooooo`;o
00002oooool2o`0000Cooooo0_l00005ooooo`;o00004_ooool2o`0000gooooo1Ol00009ooooo`;o
0000Zoooool001cooooo00?o0000ooooooooool0>_ooool3o`0000Wooooo1?l00002ooooo`;o0000
1?ooool2o`0000Cooooo1?l00002ooooo`;o00002Oooool4o`0000Oooooo0_l0000<ooooo`;o0000
2_ooool2o`0000Sooooo0_l00002ooooo`;o00001Oooool2o`000:Cooooo000Looooo`03o`000?oo
oooooooo03[ooooo1Ol00007ooooo`Co00000_ooool2o`0000;ooooo1?l00004ooooo`Go00001_oo
ool3o`0000?ooooo0_l00009ooooo`;o00003?ooool2o`0000[ooooo1?l00006ooooo`;o00002Ooo
ool2o`000:Cooooo000Looooo`03o`000?oooooooooo03cooooo0ol00004ooooo`?o000000?ooooo
o`000?l000001oooool2o`0000Kooooo0_l000000ooooooo0000o`000006ooooo`Go00000oooool2
o`0000?ooooo0_l0000Nooooo`;o00004Oooool2o`000:Cooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003ooooo
ooooo`0kooooo`?o00001?ooool4o`000003ooooool0003o000000Cooooo0ol0000Fooooo`;o0000
0oooool2o`0000?ooooo1?l0003Eooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o
8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0>oooool6o`00
0003ooooool0003o000000Wooooo0ol0000Pooooo`Co00001_ooool3o`0000Kooooo0_l0000Ioooo
o`;o0000ZOooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool0??ooool5o`0000Wooooo0ol0000]oooo
o`?o00001_ooool2o`0000;ooooo0ol000000ooooooo0000o`000007ooooo`;o00001Oooool2o`00
0003ooooool0003o000000;ooooo0_l00002ooooo`;o0000XOooool00003ooooool0003ooooo00;o
oooo00?o0000ooooooooool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0000loooo
o`;o000000?oooooo`000?l000002Oooool3o`0003Gooooo0_l00003ooooo`?o000000?oooooo`00
0?l000001oooool2o`0000Gooooo0_l00003ooooo`Co00000_ooool2o`0001Cooooo0_l0002;oooo
o`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`01_ooool00ol0003oooooooooo`0oooooo`;o00002?ooool3o`0003Gooooo0ol00005oooo
o`;o00003Oooool2o`0000Kooooo0ol0000Iooooo`;o0000Coooool2o`0003[ooooo00000ooooooo
410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003o
ooooooooo`0mooooo`;o000000?oooooo`000?l000001oooool3o`0003Gooooo0ol00004ooooo`?o
00002Oooool2o`0000;ooooo0_l00007ooooo`;o00001Oooool2o`0001?ooooo0_l0001>ooooo`;o
0000>_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008oooo
o`03o`000?oooooooooo03gooooo1Ol0000Xooooo`_o000000Coooooo`000?l0003o00003oooool2
o`0000Cooooo0_l00004ooooo`;o00001?ooool3o`0000_ooooo0_l0000Cooooo`;o0000B_ooool2
o`0003kooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@
1_ooool00ol0003oooooooooo`0nooooo`Co00009_ooool=o`000003ooooool0003o000000Ko0000
4?ooool2o`0000[ooooo0ol0000Qooooo`;o0000BOooool3o`0003gooooo000Looooo`03o`000?oo
oooooooo03oooooo2Ol0000Oooooo`Wo00000oooool2o`0000;ooooo1ol00002ooooo`;o00001_oo
ool2o`0000cooooo0_l00005ooooo`?o00000oooool2o`0001Wooooo0_l000000ooooooo0000o`00
0017ooooo`Co0000>oooool001cooooo00?o0000ooooooooool0?oooool9o`0001cooooo2_l0000=
ooooo`Co000000?oooooo`000?l000001_ooool3o`0000_ooooo0_l00005ooooo`?o000000?ooooo
o`000?l000000_l0000Iooooo`Go0000@Oooool2o`0000Kooooo0_l0000kooooo`007?ooool00ol0
003oooooooooo`0oooooo`Wo00007?ooool9o`0000kooooo1?l00005ooooo`;o00000oooool2o`00
01;ooooo0_l00002ooooo`?o00005_ooool2o`0000?ooooo0_l00003ooooo`;o0000?_ooool3o`00
04;ooooo000Looooo`03o`000?oooooooooo043ooooo1_l0000Sooooo`Co00003?ooool4o`0000?o
oooo0_l00002ooooo`Go00005?ooool2o`0000;ooooo0_l0000Gooooo`;o00000oooool2o`0000;o
oooo0ol0000oooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0Hoooool2o`0000Cooooo
1?l0000<ooooo`?o00001?ooool3o`0000?ooooo0ol0000@ooooo`;o000000Coooooo`000?l0003o
oooo1?l0000Gooooo`?o00000_ooool2o`0000;ooooo0_l00024ooooo`007?ooool00ol0003ooooo
ooooo`1Sooooo`?o00000_ooool3o`0000;ooooo0ol0000Aooooo`;o00001?ooool3o`0000Gooooo
0_l00002ooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`;o00005oooool6o`0000;o
oooo0_l00002ooooo`;o0000>_ooool3o`0000Gooooo0_l0000oooooo`007?ooool00ol0003ooooo
ooooo`1Rooooo`Co00000_ooool3o`0000;ooooo0ol00008ooooo`;o00003_ooool3o`0000Cooooo
0_l00002ooooo`;o00001oooool2o`0001Oooooo2_l000001Ooooooo0000o`000?l0003ooooo00;o
0000>_ooool3o`0000Cooooo0ol0000oooooo`007?ooool00ol0003oooooooooo`1Rooooo`?o0000
0oooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool2o`0000kooooo
1?l0000Voooooa?o0000?_ooool2o`0000;ooooo0_l00010ooooo`007?ooool00ol0003ooooooooo
o`1Sooooo`;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00003_oo
ool3o`0000;ooooo0ol00003ooooo`;o000000?oooooo`000?l000002Oooool2o`00017ooooo4_l0
00000ooooooo0000o`00000nooooo`;o00000_ooool2o`00043ooooo000Looooo`03o`000?oooooo
oooo06;ooooo1?l00003ooooo`;o00001Oooool2o`0001;ooooo0ol00002ooooo`;o00001?ooool2
o`000003ooooool0003o000000;o00001oooool2o`0000gooooo5ol000000ooooooo0000o`000011
ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0H_ooool4o`0000?ooooo0_l00005oooo
o`Co00002_ooool7o`0000_ooooo1_l00007ooooo`;o00003?ooool@o`000003ooooool0003o0000
00So0000?oooool4o`00043ooooo000Looooo`;o0000I?ooool2o`0000Cooooo0_l00005ooooo`Co
000000Coooooo`000?l0003ooooo3ol00009ooooo`;o00002oooool2o`0000_ooooo6ol000000ooo
oooo0000o`00000mooooo`?o0000@Oooool001cooooo00?o0000ooooooooool0Hoooool2o`0000oo
oooo5Ol000001?oooooo0000o`000?l0000MoooooaWo00000oooool2o`0003cooooo0_l00013oooo
o`007?ooool00ol0003oooooooooo`1Sooooo`;o00003ooooolEo`000004ooooool0003o0000o`00
00Kooooo0_l0000DoooooaWo0000?_ooool2o`0000;ooooo0_l00013ooooo`007?ooool00ol0003o
ooooooooo`1Rooooo`?o00002ooooolIo`0000;ooooo0_l00002ooooo`;o00000_ooool2o`0001Co
oooo6Ol0000nooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0H_ooool4o`0000[ooooo
6Ol00002ooooo`;o00000_ooool2o`0000Wooooo0_l0000<ooooo`;o000000?oooooo`000?l00000
5Ol000001?oooooo0000o`000?ooool2o`0003Sooooo0_l00017ooooo`007?ooool00ol0003ooooo
ooooo`1Rooooo`Co00002ooooolCo`000003ooooool0003o000000;o00000_ooool2o`0000;ooooo
0_l00006ooooo`;o000000?oooooo`000?l000003?ooool2o`000003ooooool0003o0000017o0000
00Goooooo`000?l0003o0000ooooo`02o`000003ooooool0003o000003Wooooo0ol00015ooooo`00
7?ooool00ol0003oooooooooo`1Rooooo`Co00002ooooolHo`0000;ooooo0_l00002ooooo`?o0000
1Oooool2o`00017ooooo5?l000000ooooooo0000o`000002ooooo`;o0000<_ooool2o`0000Oooooo
1?l00015ooooo`007?ooool00ol0003oooooooooo`1Tooooo`Go00001ooooolIo`000003ooooool0
003o000000Cooooo0_l0000Dooooo`;o00000_oooolDo`000003ooooool0003o000000;ooooo0_l0
0002ooooo`;o0000;_ooool2o`0000Oooooo0ol00016ooooo`007?ooool00ol0003oooooooooo`1R
ooooo`Oo000000?oooooo`000?l000000_oooolNo`0001Wooooo7?l00002ooooo`Ko0000;?ooool2
o`0000?ooooo0_l00002ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0H_ooool4o`00
0004ooooool0003o0000ooooo`;o00000_oooolJo`000004ooooool0003o0000o`0001Wooooo7Ol0
00000ooooooo0000o`000002o`0002kooooo0_l000000ooooooo0000o`000002o`000004ooooool0
003o0000o`0004Wooooo000Looooo`03o`000?oooooooooo06?ooooo0_l0000:oooooaWo000000?o
ooooo`000?l000006_oooolJo`000004ooooool0003o0000ooooo`Co0000;_ooool2o`000003oooo
ool0003o000000;o000000?oooooo`000?l00000B_ooool001cooooo00?o0000ooooooooool0I_oo
ool2o`0000Gooooo7_l0000Jooooo`;o000000?oooooo`000?l000005Ol00004ooooo`?o0000;ooo
ool2o`0000;ooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`1Vooooo`;o00001Oooool6
o`000003ooooool0003o0000013o00000_ooool2o`0001_ooooo6_l00005ooooo`;o0000<oooool2
o`0004kooooo000Looooo`03o`000?oooooooooo06?ooooo0_l0000<oooooaSo00007?ooool5o`00
00;ooooo4_l0000[ooooo`?o00003oooool3o`0004_ooooo000Looooo`03o`000?oooooooooo06?o
oooo0_l00009oooooa_o00002_ooool3o`0000oooooo6?l0000[ooooo`Co00001?ooool3o`0000So
oooo0ol0001;ooooo`007?ooool00ol0003oooooooooo`1Sooooo`;o00001?ooool2o`0000?ooooo
6Ol0000<ooooo`?o00003ooooolAo`000004ooooool0003o0000ooooo`;o0000;?ooool2o`0000Ko
oooo0ol0001Fooooo`007?ooool2o`0006Cooooo0_l000001?oooooo0000o`000?ooool2o`0000?o
oooo0_l000000ooooooo0000o`00000Co`00023ooooo5Ol0000Yooooo`;o0000Hoooool001cooooo
00?o0000ooooooooool0I_ooool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000
o`00000Bo`00023ooooo0_l00002ooooo`Go00000_ooool=o`0002Oooooo0_l00008ooooo`?o0000
F?ooool001cooooo00?o0000ooooooooool0K?ooool4o`0000;ooooo2?l000000ooooooo0000o`00
0006o`0002;ooooo0ol000000ooooooo0000o`000005o`000003ooooool0003o000000Oo000000?o
ooooo`000?l00000<Oooool3o`0005Sooooo000Looooo`03o`000?oooooooooo06Kooooo0_l00004
ooooo`;o00003_ooool4o`00013ooooo0_l0000Dooooo`;o000000?oooooo`000?l000003_l0000]
ooooo`;o00000oooool2o`000003ooooool0003o000000Kooooo0_l0001Aooooo`007?ooool00ol0
003oooooooooo`1Uooooo`Ko00000_ooool4o`0001kooooo0ol0000Doooooa?o0000;Oooool2o`00
00;ooooo0ol000000ooooooo0000o`000006ooooo`;o0000DOooool001cooooo00?o0000oooooooo
ool0IOooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000000_l0000Nooooo`;o
00005Oooool3o`000003ooooool0003o000000_o0000<oooool6o`0000Cooooo1?l0001Aooooo`00
7?ooool00ol0003oooooooooo`1Uooooo`;o00000oooool2o`000003ooooool0003o000000;o0000
6Oooool2o`0001[ooooo0ol000000ooooooo0000o`000003ooooo`Go0000=_ooool6o`0000;ooooo
1?l0001Cooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o00000oooool2o`000003ooooool0
003o000000Co00005oooool2o`0001cooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo
0_l0000Uooooo`?o00000_ooool2o`0000Wooooo0_l00007ooooo`?o0000E?ooool001cooooo00?o
0000ooooooooool0IOooool2o`0000;ooooo0_l00003ooooo`Go00006Oooool2o`0001[ooooo0ol0
00000ooooooo0000o`00000Tooooo`;o00000_ooool2o`000004ooooool0003o0000o`0000;ooooo
0_l00009ooooo`?o00000_ooool2o`0000?ooooo0_l0001Dooooo`007?ooool00ol0003ooooooooo
o`1Uooooo`;o00000_ooool2o`0000?ooooo1Ol0000Dooooo`?o00000_ooool2o`0001_ooooo1?l0
0007ooooo`Co00002?ooool4o`0000;ooooo0_l00002ooooo`;o00001_ooool2o`0000;ooooo0_l0
00000ooooooo0000o`000007ooooo`;o00001_ooool3o`000003ooooool0003o000005Wooooo000L
ooooo`03o`000?oooooooooo06Kooooo0_l00007ooooo`;o00000_ooool2o`00017ooooo1_l0000M
ooooo`Co000000?oooooo`000?l000000_ooool6o`0000Cooooo0_l00002ooooo`Co00000_ooool2
o`0000;ooooo0_l00005ooooo`?o00000_ooool2o`000003ooooool0003o000000;o00001Oooool2
o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0005Wooooo000Looooo`03o`000?oooooo
oooo06Kooooo0_l00007ooooo`?o000000?oooooo`000?l000003oooool4o`0000;ooooo0_l0000N
ooooo`Ko00000_ooool2o`0000;ooooo0_l00004ooooo`;o00001Oooool2o`0000;ooooo0_l00006
ooooo`Co00001Oooool2o`000003ooooool0003o000000?ooooo0_l00005ooooo`?o00001?ooool2
o`0005Wooooo000Looooo`03o`000?oooooooooo073ooooo0_l00003ooooo`?o00001_ooool4o`00
00;ooooo1?l0000Sooooo`Co00002Oooool2o`0000Wooooo0_l00002ooooo`Co00000oooool3o`00
00?ooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`00
0?l00000H?ooool001cooooo00?o0000ooooooooool0Ioooool4o`0000[ooooo0ol00006ooooo`Co
000000Coooooo`000?l0003ooooo0_l0000Tooooo`Co00002?ooool2o`0000kooooo0ol00003oooo
o`;o00001?ooool2o`0000;ooooo0_l00002ooooo`;o00001?ooool4o`000003ooooool0003o0000
063ooooo000Looooo`03o`000?oooooooooo06Oooooo1_l00008ooooo`Go000000?oooooo`000?l0
00002?l0000Xooooo`Ko00003_ooool2o`0000Gooooo0_l0000>ooooo`;o00002?ooool2o`000003
ooooool0003o000000;o00000_ooool2o`0005cooooo000Looooo`03o`000?oooooooooo06_ooooo
0ol00009ooooo`?o000000?oooooo`000?l000001_l0000/ooooo`Go000000?oooooo`000?l00000
1_ooool2o`0000;ooooo0ol00009ooooo`;o00001Oooool2o`0000oooooo2?l0001Looooo`007?oo
ool2o`0006gooooo0_l00009ooooo`Go00001Oooool2o`0002cooooo1Ol000000ooooooo0000o`00
0006ooooo`;o00000oooool2o`0000Cooooo0_l00003ooooo`;o00001Oooool2o`0000Cooooo0_l0
00000ooooooo0000o`000002o`000004ooooool0003o0000ooooo`Ko0000G_ooool001cooooo00?o
0000ooooooooool0Moooool5o`000003ooooool0003o000000;ooooo0_l0000^ooooo`Ko00002Ooo
ool2o`0000Kooooo0_l00003ooooo`;o00002oooool2o`000003ooooool0003o000000;o000000?o
ooooo`000?l000000oooool2o`00063ooooo000Looooo`03o`000?oooooooooo06[ooooo0_l0000>
ooooo`;o000000?oooooo`000?l00000=?ooool5o`0000?ooooo1?l000000ooooooo0000o`000009
ooooo`;o00001Oooool4o`000004ooooool0003o0000o`0000?ooooo1?l00006ooooo`;o0000H?oo
ool001cooooo00?o0000ooooooooool0J_ooool2o`0004Wooooo0ol000000ooooooo0000o`00000:
o`0000Kooooo0_l00002ooooo`;o000000?oooooo`000?l000001_l00003ooooo`So0000I?ooool0
01cooooo00?o0000ooooooooool0J_ooool2o`0000Gooooo0ol00011ooooo`So00000_ooool6o`00
00[ooooo0_l00004ooooo`;o00001_ooool8o`0006Cooooo000Looooo`03o`000?oooooooooo077o
oooo0ol00012ooooo`[o00000_ooool2o`000003ooooool0003o000001Kooooo1Ol0001Wooooo`00
7?ooool00ol0003oooooooooo`2iooooo`[o00000_ooool2o`0000[ooooo0_l00006ooooo`?o0000
00?oooooo`000?l000000ol0001Wooooo`007?ooool00ol0003oooooooooo`1eooooo`;o0000A?oo
ool:o`0000cooooo0_l00006ooooo`?o0000KOooool001cooooo00?o0000ooooooooool0L?ooool2
o`000003ooooool0003o000000;o0000AOooool9o`0000[ooooo1?l00007ooooo`;o0000KOooool0
01cooooo00?o0000ooooooooool0L?ooool2o`000003ooooool0003o000004Wooooo1ol00008oooo
o`Ko00000_ooool2o`0007;ooooo000Looooo`03o`000?oooooooooo073ooooo0_l00003ooooo`?o
0000Aoooool:o`0000Cooooo0_l00006ooooo`;o0000L_ooool001cooooo00?o0000ooooooooool0
L?ooool2o`000003ooooool0003o000000?o0000B_ooool7o`0000Cooooo0_l0001jooooo`007?oo
ool00ol0003oooooooooo`1booooo`?o0000D_ooool8o`0007[ooooo000Looooo`03o`000?oooooo
oooo07;ooooo0_l00002ooooo`;o0000D?ooool6o`0007_ooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`1booooo`;o00000_ooool2o`000=7ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Go
oooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1moooo
o`;o0000b_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool0N_ooool2o`000003ooooool0003o0000
0<[ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P06ooooo`?o0000N_ooool4o`0000?ooooo0_l00036ooooo`0000?oooooo`000?oo
ool00_ooool00ol0003oooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0
003oooooooooo`1hooooo`Ko00000oooool2o`000<Kooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00Wooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo
07Sooooo0_l00007ooooo`;o00000_ooool2o`000<;ooooo00001_ooooooMgMgoiRHV?ooooooV9RH
ogMgM`_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo08Gooooo0_l0
0032ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT01_ooool00ol0003oooooooooo`22ooooo`;o00000oooool2o`000<3ooooo000Looooo`03o`00
0?oooooooooo08;ooooo1?l000001?oooooo0000o`000?l0002oooooo`007?ooool00ol0003ooooo
ooooo`20ooooo`;o00000_ooool2o`0000;ooooo0_l0002oooooo`007?ooool00ol0003ooooooooo
o`20ooooo`;o00002Oooool2o`000;cooooo000Looooo`03o`000?oooooooooo08_ooooo0_l0002l
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000
oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001;ooooo1?l0
00000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo
00Gooooo0ol0003ooooood[ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo
00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000D
ooooo`03o`000?oooooooooo0?ooooooD_ooool001;ooooo00?oEEEEofIVI_l00000oooooomDoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00YOooool01?l@413o0000o`000?oo
ool2o`000003oa0@4?oooooooooo01Kooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?l@
413oc<c<0oooool5o`00093ooooo002Vooooo`05o`000?ooooooooooooooool000002Oooool6o`00
00cooooo00?o0000ooooooooool00_ooool01OmEEEGoMgMgoooooonHV9So8B4Q00?ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A02@ooooo`00Y_ooool01Ol0003ooooooooooooooooo000001_ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00?oV9RHob4Q8Oo^k^h0
TOooool00:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00003?ooool00ol0003ooooo
ooooo`02ooooo`05o`000?nHV9SooooooiRHV?lQ8B401Oooool00onHV9So8B4Qonk^kP2@ooooo`00
Y_ooool01Ol0003oQhN7oooooonYZJWo000001_ooooo00?o0000ooooooooool00_ooool01Ol0003o
EEEEo`000?l@413oc<c<00Kooooo00?oMgMgofIVI_ooool0Soooool00:Gooooo00?o410@o`000?mg
MgL00_l000000onHV9Soooooooooo`0Iooooo`03o`000?oooooooooo00;ooooo00?oEEEEohN7Qooo
ool02Oooool00ol0003oooooooooo`2>ooooo`00a_ooool00ol0003oooooooooo`02ooooo`03omgM
gOl@413oV9RH00Gooooo00Go0000okZj^_ooooooV9RHoa0@402@ooooo`00a?ooool00omEEEGoIVIV
o`000005ooooo`04olc<c?m4A4Co0000oa0@40?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c02@oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(168) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.28824 .49908 Mdot
.3084 .47798 Mdot
.51068 .68507 Mdot
.49614 .38552 Mdot
.76854 .52833 Mdot
.52249 .66987 Mdot
.35651 .66674 Mdot
.35457 .64907 Mdot
.54412 .70693 Mdot
.44435 .40503 Mdot
.39857 .66304 Mdot
.48444 .32428 Mdot
.36157 .65768 Mdot
.53063 .38688 Mdot
.62937 .42294 Mdot
.44841 .26368 Mdot
.32093 .4542 Mdot
.73864 .50863 Mdot
.45399 .27127 Mdot
.55017 .70659 Mdot
.76504 .55952 Mdot
.52309 .37005 Mdot
.2741 .46088 Mdot
.52929 .38734 Mdot
.4521 .26025 Mdot
.30192 .48342 Mdot
.29559 .50053 Mdot
.46565 .25872 Mdot
.48788 .33725 Mdot
.40384 .65519 Mdot
.47249 .25522 Mdot
.71738 .42299 Mdot
.5843 .53693 Mdot
.38553 .37683 Mdot
.35921 .63648 Mdot
.32126 .65579 Mdot
.52872 .69897 Mdot
.38732 .64176 Mdot
.372 .68695 Mdot
.38526 .64782 Mdot
.38339 .6451 Mdot
.2962 .47917 Mdot
.36009 .63423 Mdot
.32108 .75199 Mdot
.52183 .39553 Mdot
.36736 .25704 Mdot
.58932 .65233 Mdot
.48512 .36801 Mdot
.27852 .4543 Mdot
.48832 .694 Mdot
.67278 .46495 Mdot
.3757 .64896 Mdot
.60707 .53555 Mdot
.34156 .23331 Mdot
.35389 .65648 Mdot
.45282 .26507 Mdot
.54445 .65857 Mdot
.50498 .37584 Mdot
.48505 .37826 Mdot
.38027 .34985 Mdot
.49883 .36419 Mdot
.75655 .53966 Mdot
.31689 .40783 Mdot
.50121 .68079 Mdot
.52515 .71294 Mdot
.37946 .63645 Mdot
.33819 .46392 Mdot
.3371 .66072 Mdot
.49351 .3826 Mdot
.5725 .68882 Mdot
.50725 .33493 Mdot
.39854 .66196 Mdot
.33623 .48195 Mdot
.53078 .36356 Mdot
.27244 .49419 Mdot
.38057 .69282 Mdot
.7579 .51449 Mdot
.26205 .45605 Mdot
.49523 .67403 Mdot
.58424 .35585 Mdot
.52545 .36296 Mdot
.19079 .58957 Mdot
.65121 .36084 Mdot
.3112 .49546 Mdot
.54828 .36912 Mdot
.1794 .53954 Mdot
.54913 .3532 Mdot
.46151 .24609 Mdot
.46031 .25727 Mdot
.58219 .43046 Mdot
.55112 .65538 Mdot
.27951 .46141 Mdot
.51971 .37518 Mdot
.50995 .40762 Mdot
.43511 .398 Mdot
.49921 .34042 Mdot
.45656 .25933 Mdot
.60396 .56199 Mdot
.39026 .65982 Mdot
.61765 .5493 Mdot
.41744 .62328 Mdot
.60045 .5486 Mdot
.52488 .33746 Mdot
.53126 .68327 Mdot
.32735 .49915 Mdot
.59202 .55071 Mdot
.33649 .64907 Mdot
.52243 .379 Mdot
.3166 .67351 Mdot
.27433 .46359 Mdot
.47315 .2705 Mdot
.73693 .53079 Mdot
.65952 .57251 Mdot
.3352 .47631 Mdot
.41585 .26233 Mdot
.51982 .40682 Mdot
.51404 .35738 Mdot
.30411 .4775 Mdot
.54664 .71089 Mdot
.43205 .69347 Mdot
.30616 .45896 Mdot
.39348 .66226 Mdot
.3202 .45265 Mdot
.58317 .54513 Mdot
.53945 .7128 Mdot
.61976 .51569 Mdot
.61588 .56379 Mdot
.70795 .43932 Mdot
.48852 .35371 Mdot
.6085 .57247 Mdot
.53412 .68817 Mdot
.30623 .46139 Mdot
.37157 .657 Mdot
.53037 .42002 Mdot
.30382 .49188 Mdot
.34969 .6616 Mdot
.70665 .52474 Mdot
.70133 .52622 Mdot
.32742 .48713 Mdot
.41475 .27335 Mdot
.36024 .63121 Mdot
.34466 .67509 Mdot
.66982 .46405 Mdot
.31902 .49301 Mdot
.72789 .54866 Mdot
.34367 .66748 Mdot
.60307 .75195 Mdot
.46857 .2743 Mdot
.71586 .45568 Mdot
.19882 .5924 Mdot
.67046 .46486 Mdot
.74011 .56225 Mdot
.7457 .54179 Mdot
.34915 .66091 Mdot
.53825 .40928 Mdot
.32542 .47564 Mdot
.30662 .49053 Mdot
.49929 .32847 Mdot
.58822 .54111 Mdot
.516 .40116 Mdot
.61803 .55273 Mdot
.61953 .56378 Mdot
.52312 .3839 Mdot
.36779 .27968 Mdot
.28593 .49008 Mdot
.55287 .38606 Mdot
.53679 .70042 Mdot
.61302 .58158 Mdot
.35005 .63338 Mdot
.54826 .37469 Mdot
.55499 .39545 Mdot
.48639 .31783 Mdot
.34467 .67597 Mdot
.29862 .60797 Mdot
.50781 .65761 Mdot
.39572 .67549 Mdot
.42297 .6285 Mdot
.55032 .68065 Mdot
.48909 .38798 Mdot
.73168 .53364 Mdot
.61629 .52684 Mdot
.54274 .39929 Mdot
.67344 .46626 Mdot
.4996 .40698 Mdot
.68297 .55871 Mdot
.68943 .55554 Mdot
.1932 .57123 Mdot
.30834 .589 Mdot
.51565 .40798 Mdot
.44862 .23743 Mdot
.69295 .46009 Mdot
.37872 .72316 Mdot
.37546 .66075 Mdot
.58534 .67712 Mdot
.55585 .70688 Mdot
.50859 .7477 Mdot
.43743 .31844 Mdot
.47179 .31656 Mdot
.51183 .3507 Mdot
.60989 .54396 Mdot
.32708 .41057 Mdot
.74716 .54231 Mdot
.32939 .46554 Mdot
.19228 .59198 Mdot
.59686 .32609 Mdot
.47626 .28752 Mdot
.56834 .78528 Mdot
.49518 .69458 Mdot
.59421 .54384 Mdot
.72225 .54146 Mdot
.50398 .38382 Mdot
.27395 .48154 Mdot
.68284 .46185 Mdot
.59044 .52182 Mdot
.83875 .44242 Mdot
.31223 .45601 Mdot
.62627 .33952 Mdot
.35531 .65928 Mdot
.5619 .66752 Mdot
.54933 .35362 Mdot
.53516 .37963 Mdot
.30141 .44117 Mdot
.52621 .41659 Mdot
.48101 .26871 Mdot
.46656 .26987 Mdot
.48733 .69704 Mdot
.39661 .60708 Mdot
.38529 .681 Mdot
.58815 .64129 Mdot
.33502 .47984 Mdot
.35843 .25931 Mdot
.53899 .67282 Mdot
.71684 .56176 Mdot
.39795 .65562 Mdot
.70561 .52914 Mdot
.53292 .67462 Mdot
.76845 .52938 Mdot
.48732 .38593 Mdot
.55573 .68725 Mdot
.7466 .52846 Mdot
.56602 .44077 Mdot
.59481 .55242 Mdot
.79101 .52132 Mdot
.35675 .67074 Mdot
.29913 .44527 Mdot
.54326 .39947 Mdot
.61261 .53335 Mdot
.59743 .51433 Mdot
.61211 .40717 Mdot
.63479 .5423 Mdot
.59059 .52602 Mdot
.59426 .42187 Mdot
.72599 .50956 Mdot
.26372 .55306 Mdot
.47425 .25911 Mdot
.32451 .45577 Mdot
.51895 .41218 Mdot
.36032 .59322 Mdot
.34882 .66293 Mdot
.50048 .37689 Mdot
.1864 .57595 Mdot
.3587 .67437 Mdot
.5097 .36972 Mdot
.38578 .68481 Mdot
.3068 .49394 Mdot
.59943 .32109 Mdot
.33555 .48568 Mdot
.52075 .38372 Mdot
.39166 .68261 Mdot
.5858 .67226 Mdot
.30369 .48489 Mdot
.52188 .37434 Mdot
.49684 .35301 Mdot
.60941 .54137 Mdot
.46684 .27161 Mdot
.42467 .64914 Mdot
.48677 .32444 Mdot
.52047 .65886 Mdot
.49425 .33574 Mdot
.6943 .52933 Mdot
.64404 .7491 Mdot
.32174 .49235 Mdot
.63587 .53952 Mdot
.53503 .66608 Mdot
.54532 .44802 Mdot
.61659 .3247 Mdot
.52521 .3949 Mdot
.60159 .51973 Mdot
.64654 .33842 Mdot
.37514 .67725 Mdot
.478 .27193 Mdot
.63712 .57098 Mdot
.5411 .65764 Mdot
.60258 .54747 Mdot
.52544 .34496 Mdot
.26962 .46821 Mdot
.4502 .26375 Mdot
.55657 .67644 Mdot
.30849 .45209 Mdot
.53781 .34494 Mdot
.42508 .63501 Mdot
.64185 .55466 Mdot
.37972 .67573 Mdot
.46775 .25509 Mdot
.48976 .38899 Mdot
.57021 .68993 Mdot
.29359 .47856 Mdot
.35355 .65306 Mdot
.33399 .48487 Mdot
.60431 .45927 Mdot
.63145 .3447 Mdot
.34388 .47937 Mdot
.71833 .51644 Mdot
.60761 .80298 Mdot
.39564 .66824 Mdot
.62614 .53578 Mdot
.58021 .64977 Mdot
.26561 .46823 Mdot
.52799 .67795 Mdot
.41485 .28735 Mdot
.55058 .65614 Mdot
.45734 .27758 Mdot
.58247 .6686 Mdot
.46557 .31099 Mdot
.54929 .38541 Mdot
.50656 .70982 Mdot
.60123 .56185 Mdot
.53211 .35396 Mdot
.30127 .49116 Mdot
.71394 .41354 Mdot
.41597 .36022 Mdot
.43921 .31553 Mdot
.54498 .66018 Mdot
.41038 .28452 Mdot
.47013 .26704 Mdot
.46595 .25545 Mdot
.32187 .47401 Mdot
.62463 .53362 Mdot
.69848 .54464 Mdot
.71633 .55213 Mdot
.7081 .71696 Mdot
.63329 .29735 Mdot
.41796 .2549 Mdot
.31203 .48905 Mdot
.5476 .77575 Mdot
.30008 .50487 Mdot
.59045 .5226 Mdot
.35474 .64875 Mdot
.29571 .6203 Mdot
.54331 .34556 Mdot
.67342 .53435 Mdot
.48254 .27022 Mdot
.29539 .4479 Mdot
.3443 .46395 Mdot
.35337 .65206 Mdot
.43799 .31039 Mdot
.44452 .40331 Mdot
.50656 .39436 Mdot
.35065 .64899 Mdot
.59437 .51687 Mdot
.55371 .43162 Mdot
.72293 .43809 Mdot
.35314 .78953 Mdot
.5218 .39122 Mdot
.38697 .45451 Mdot
.54404 .39453 Mdot
.70435 .44411 Mdot
.50746 .38568 Mdot
.2939 .48215 Mdot
.44931 .21182 Mdot
.56139 .42073 Mdot
.5745 .78734 Mdot
.59586 .32993 Mdot
.74987 .52021 Mdot
.52959 .38041 Mdot
.52454 .40376 Mdot
.71551 .54674 Mdot
.28232 .46977 Mdot
.48914 .37702 Mdot
.27119 .55398 Mdot
.51926 .37075 Mdot
.345 .63471 Mdot
.64067 .39039 Mdot
.71411 .42403 Mdot
.46682 .26638 Mdot
.27 .46641 Mdot
.35544 .68063 Mdot
.38045 .64074 Mdot
.63223 .53114 Mdot
.34856 .66351 Mdot
.54607 .38872 Mdot
.63983 .39147 Mdot
.33988 .46756 Mdot
.59288 .54766 Mdot
.28522 .45898 Mdot
.574 .71599 Mdot
.36026 .67025 Mdot
.59954 .53847 Mdot
.42937 .33375 Mdot
.37167 .67091 Mdot
.43967 .64243 Mdot
.47465 .26883 Mdot
.59584 .51591 Mdot
.28301 .49623 Mdot
.57581 .68407 Mdot
.59651 .52035 Mdot
.35326 .65625 Mdot
.52294 .39613 Mdot
.4566 .26851 Mdot
.34745 .66224 Mdot
.35901 .50865 Mdot
.47724 .26334 Mdot
.51714 .36932 Mdot
.28926 .4879 Mdot
.29798 .46397 Mdot
.5526 .38918 Mdot
.52777 .41373 Mdot
.52521 .66329 Mdot
.60507 .51744 Mdot
.60733 .51594 Mdot
.62546 .55882 Mdot
.55499 .66097 Mdot
.59247 .80136 Mdot
.33477 .66218 Mdot
.71281 .42279 Mdot
.31752 .58875 Mdot
.6087 .53129 Mdot
.52168 .66562 Mdot
.53594 .39726 Mdot
.50764 .32714 Mdot
.39485 .68137 Mdot
.68643 .77998 Mdot
.53333 .33604 Mdot
.33318 .46183 Mdot
.361 .64366 Mdot
.47872 .31872 Mdot
.50413 .74246 Mdot
.75973 .52991 Mdot
.41676 .25423 Mdot
.36339 .64478 Mdot
.32114 .52872 Mdot
.36467 .64515 Mdot
.52568 .40308 Mdot
.52043 .34457 Mdot
.30798 .44363 Mdot
.74876 .51929 Mdot
.49088 .32595 Mdot
.51103 .37585 Mdot
.55666 .78202 Mdot
.31411 .50576 Mdot
.71448 .55206 Mdot
.48451 .34005 Mdot
.60697 .56039 Mdot
.75781 .51981 Mdot
.5233 .35711 Mdot
.49627 .33332 Mdot
.59233 .56527 Mdot
.40485 .67189 Mdot
.72876 .51533 Mdot
.57623 .78871 Mdot
.31819 .45678 Mdot
.42201 .66444 Mdot
.62854 .51766 Mdot
.396 .66681 Mdot
.48411 .40982 Mdot
.5966 .54175 Mdot
.29178 .68758 Mdot
.74975 .24794 Mdot
.59344 .52665 Mdot
.52464 .65934 Mdot
.43081 .39392 Mdot
.49467 .33043 Mdot
.51651 .36948 Mdot
.69176 .54043 Mdot
.30394 .47011 Mdot
.3084 .58942 Mdot
.39366 .6787 Mdot
.5391 .38207 Mdot
.32753 .49096 Mdot
.18691 .56205 Mdot
.6041 .5443 Mdot
.73406 .5235 Mdot
.71505 .52301 Mdot
.53292 .36173 Mdot
.64156 .32007 Mdot
.30359 .48619 Mdot
.52199 .3748 Mdot
.52705 .35481 Mdot
.57726 .65684 Mdot
.3011 .49638 Mdot
.55454 .68684 Mdot
.47479 .28603 Mdot
.42979 .24676 Mdot
.35308 .59201 Mdot
.35324 .67239 Mdot
.62072 .51884 Mdot
.38498 .68056 Mdot
.54277 .64311 Mdot
.60757 .51622 Mdot
.52265 .37485 Mdot
.34007 .46722 Mdot
.52157 .37525 Mdot
.51917 .37172 Mdot
.51494 .3951 Mdot
.41778 .24932 Mdot
.50018 .66893 Mdot
.72824 .52742 Mdot
.48246 .35678 Mdot
.55592 .66951 Mdot
.52618 .75934 Mdot
.44363 .40586 Mdot
.52967 .37397 Mdot
.51213 .35999 Mdot
.2551 .46511 Mdot
.46873 .27617 Mdot
.3709 .6687 Mdot
.30617 .44358 Mdot
.55241 .35867 Mdot
.58888 .64642 Mdot
.49096 .38298 Mdot
.34294 .48054 Mdot
.33314 .65495 Mdot
.31558 .3999 Mdot
.61873 .50987 Mdot
.62493 .51979 Mdot
.59455 .52289 Mdot
.62992 .55417 Mdot
.34947 .63425 Mdot
.5186 .66794 Mdot
.59427 .64565 Mdot
.50085 .31115 Mdot
.52924 .41501 Mdot
.52317 .34529 Mdot
.58041 .65452 Mdot
.58808 .55589 Mdot
.42254 .31167 Mdot
.4844 .28894 Mdot
.5678 .67108 Mdot
.60841 .56361 Mdot
.21145 .46352 Mdot
.28699 .454 Mdot
.51209 .65544 Mdot
.39168 .64595 Mdot
.7493 .52737 Mdot
.78299 .65763 Mdot
.29306 .45806 Mdot
.33534 .41229 Mdot
.53877 .6948 Mdot
.62442 .40077 Mdot
.34006 .22601 Mdot
.5246 .67723 Mdot
.47844 .26061 Mdot
.3227 .48146 Mdot
.60015 .55805 Mdot
.64658 .34316 Mdot
.63235 .39232 Mdot
.55669 .69722 Mdot
.49547 .35345 Mdot
.52513 .72084 Mdot
.53419 .65675 Mdot
.62157 .52266 Mdot
.5456 .6608 Mdot
.37297 .67935 Mdot
.53865 .68549 Mdot
.35361 .51279 Mdot
.49026 .36939 Mdot
.34091 .23259 Mdot
.65815 .41129 Mdot
.52125 .40859 Mdot
.38227 .66489 Mdot
.42772 .64415 Mdot
.49696 .3767 Mdot
.76193 .54424 Mdot
.52198 .66168 Mdot
.49437 .72962 Mdot
.4593 .27536 Mdot
.58148 .66896 Mdot
.26867 .46974 Mdot
.41639 .62133 Mdot
.42098 .62631 Mdot
.59739 .52047 Mdot
.3119 .49379 Mdot
.38151 .69326 Mdot
.39291 .66187 Mdot
.63664 .56287 Mdot
.54735 .3965 Mdot
.27872 .48245 Mdot
.56354 .43209 Mdot
.6376 .57462 Mdot
.51998 .36973 Mdot
.55259 .68687 Mdot
.4886 .68944 Mdot
.64215 .41843 Mdot
.54058 .6708 Mdot
.62456 .52426 Mdot
.28646 .48865 Mdot
.45627 .27357 Mdot
.30248 .46122 Mdot
.51509 .41119 Mdot
.38029 .59996 Mdot
.28253 .45552 Mdot
.71608 .56156 Mdot
.50108 .3627 Mdot
.36811 .27537 Mdot
.48256 .34763 Mdot
.51762 .3684 Mdot
.52898 .7145 Mdot
.71768 .54677 Mdot
.67169 .54363 Mdot
.51252 .74849 Mdot
.75811 .54272 Mdot
.36239 .46785 Mdot
.54009 .71343 Mdot
.70908 .53588 Mdot
.71209 .71586 Mdot
.63663 .53827 Mdot
.71821 .52955 Mdot
.54874 .37059 Mdot
.34826 .66935 Mdot
.3331 .45227 Mdot
.53485 .35584 Mdot
.44766 .29399 Mdot
.46593 .29239 Mdot
.60672 .54109 Mdot
.51523 .36583 Mdot
.52579 .40534 Mdot
.32866 .49006 Mdot
.19837 .59501 Mdot
.51113 .66693 Mdot
.62238 .5454 Mdot
.29868 .45768 Mdot
.19009 .58863 Mdot
.52108 .71241 Mdot
.7022 .53639 Mdot
.37473 .68506 Mdot
.30724 .52954 Mdot
.60886 .53715 Mdot
.3564 .66878 Mdot
.48959 .71108 Mdot
.65921 .46617 Mdot
.44684 .24973 Mdot
.52321 .69169 Mdot
.67067 .46514 Mdot
.47443 .2826 Mdot
.51406 .75257 Mdot
.38056 .72205 Mdot
.27531 .46313 Mdot
.34657 .65916 Mdot
.73576 .52096 Mdot
.33915 .4786 Mdot
.28498 .45882 Mdot
.35423 .6742 Mdot
.40646 .20464 Mdot
.64469 .3387 Mdot
.34961 .68538 Mdot
.61154 .41118 Mdot
.66316 .46499 Mdot
.61156 .5378 Mdot
.73043 .53096 Mdot
.39651 .60707 Mdot
.29685 .4795 Mdot
.30311 .6086 Mdot
.6762 .4654 Mdot
.47655 .27188 Mdot
.75098 .52954 Mdot
.19107 .56174 Mdot
.33069 .71415 Mdot
.36738 .66952 Mdot
.55581 .78148 Mdot
.7511 .54977 Mdot
.55029 .3802 Mdot
.70607 .77037 Mdot
.54768 .37886 Mdot
.34063 .66352 Mdot
.48237 .27042 Mdot
.32168 .46342 Mdot
.33823 .66683 Mdot
.47781 .2886 Mdot
.48673 .32659 Mdot
.50715 .39906 Mdot
.49517 .67319 Mdot
.29808 .44277 Mdot
.63838 .52437 Mdot
.52399 .40919 Mdot
.50847 .3737 Mdot
.59209 .51665 Mdot
.71314 .42649 Mdot
.48323 .62258 Mdot
.58641 .54399 Mdot
.56235 .68366 Mdot
.59272 .54829 Mdot
.62346 .54164 Mdot
.27223 .4886 Mdot
.53797 .76967 Mdot
.60738 .51082 Mdot
.52003 .3861 Mdot
.51904 .37855 Mdot
.3698 .68681 Mdot
.64636 .33918 Mdot
.62569 .39755 Mdot
.51647 .66146 Mdot
.6416 .56415 Mdot
.50327 .34374 Mdot
.30984 .49493 Mdot
.68931 .54253 Mdot
.63093 .53198 Mdot
.32098 .45631 Mdot
.48732 .35297 Mdot
.57805 .657 Mdot
.5939 .52893 Mdot
.58984 .51588 Mdot
.74676 .53103 Mdot
.34946 .68187 Mdot
.2707 .44892 Mdot
.53017 .65768 Mdot
.4526 .24535 Mdot
.6505 .54206 Mdot
.56983 .6568 Mdot
.61263 .539 Mdot
.60114 .55363 Mdot
.31039 .49276 Mdot
.32728 .52784 Mdot
.57756 .53153 Mdot
.55429 .66328 Mdot
.327 .76736 Mdot
.38109 .64898 Mdot
.486 .37861 Mdot
.37358 .68275 Mdot
.27389 .46455 Mdot
.71 .43935 Mdot
.7088 .52735 Mdot
.36808 .6724 Mdot
.58876 .527 Mdot
.2839 .4573 Mdot
.29304 .44153 Mdot
.52345 .386 Mdot
.52514 .37165 Mdot
.58934 .65113 Mdot
.70458 .45667 Mdot
.38544 .68611 Mdot
.6986 .54375 Mdot
.51053 .67773 Mdot
.45626 .27003 Mdot
.32803 .47345 Mdot
.79851 .51968 Mdot
.48167 .35556 Mdot
.55383 .66732 Mdot
.31105 .47943 Mdot
.7154 .55119 Mdot
.72662 .52707 Mdot
.53699 .40505 Mdot
.73794 .562 Mdot
.3667 .6758 Mdot
.29971 .48921 Mdot
.36386 .43229 Mdot
.48341 .35595 Mdot
.52782 .37542 Mdot
.47618 .27501 Mdot
.34575 .68302 Mdot
.54903 .37299 Mdot
.74195 .51888 Mdot
.3328 .47602 Mdot
.54036 .39561 Mdot
.74621 .55152 Mdot
.64011 .534 Mdot
.59456 .5378 Mdot
.51057 .71318 Mdot
.75247 .55363 Mdot
.73702 .55145 Mdot
.75177 .55097 Mdot
.29546 .6213 Mdot
.48151 .31976 Mdot
.60594 .49586 Mdot
.49811 .35128 Mdot
.65957 .46504 Mdot
.45007 .24349 Mdot
.38715 .65923 Mdot
.56891 .6903 Mdot
.5113 .39614 Mdot
.50003 .3509 Mdot
.27144 .45264 Mdot
.44939 .26795 Mdot
.55219 .38656 Mdot
.32621 .46539 Mdot
.35818 .42683 Mdot
.57377 .69541 Mdot
.19822 .59117 Mdot
.74944 .73663 Mdot
.51492 .42004 Mdot
.62994 .39969 Mdot
.28115 .46685 Mdot
.37244 .68599 Mdot
.61581 .40843 Mdot
.34642 .67868 Mdot
.29739 .46829 Mdot
.4491 .27071 Mdot
.36054 .50709 Mdot
.75811 .53844 Mdot
.52522 .40241 Mdot
.35824 .6767 Mdot
.52066 .4025 Mdot
.36087 .6799 Mdot
.40576 .29028 Mdot
.65082 .35398 Mdot
.53284 .41659 Mdot
.49834 .34005 Mdot
.77277 .55689 Mdot
.52763 .37281 Mdot
.56815 .78973 Mdot
.31589 .47707 Mdot
.62884 .57224 Mdot
.44416 .26399 Mdot
.41616 .36268 Mdot
.51444 .36092 Mdot
.46581 .29438 Mdot
.51167 .35538 Mdot
.67356 .78524 Mdot
.49193 .39613 Mdot
.54806 .39383 Mdot
.37591 .6568 Mdot
.39618 .65796 Mdot
.28151 .44533 Mdot
.59953 .5506 Mdot
.19197 .56683 Mdot
.51076 .37096 Mdot
.50378 .69628 Mdot
.62577 .58458 Mdot
.72913 .55111 Mdot
.33466 .47023 Mdot
.74183 .23497 Mdot
.35984 .63381 Mdot
.54765 .69767 Mdot
.47253 .25394 Mdot
.55961 .68493 Mdot
.50439 .67362 Mdot
.36649 .45173 Mdot
.73046 .53001 Mdot
.49646 .3942 Mdot
.38543 .37274 Mdot
.32554 .40551 Mdot
.4835 .3562 Mdot
.54688 .71297 Mdot
.59096 .56407 Mdot
.5585 .25857 Mdot
.74229 .50955 Mdot
.73923 .54714 Mdot
.3531 .66146 Mdot
.50396 .69884 Mdot
.62143 .54539 Mdot
.70747 .53269 Mdot
.57992 .6872 Mdot
.63532 .53611 Mdot
.55007 .77887 Mdot
.30264 .48645 Mdot
.41164 .28528 Mdot
.3652 .25185 Mdot
.38363 .67359 Mdot
.52294 .75862 Mdot
.3409 .47024 Mdot
.33325 .48982 Mdot
.61384 .54517 Mdot
.56967 .6736 Mdot
.35485 .46902 Mdot
.53703 .40319 Mdot
.59462 .54974 Mdot
.54081 .37248 Mdot
.72053 .50986 Mdot
.51441 .37316 Mdot
.58244 .67865 Mdot
.37921 .66183 Mdot
.53864 .6597 Mdot
.35319 .66442 Mdot
.71369 .41933 Mdot
.50356 .36622 Mdot
.52781 .3787 Mdot
.63913 .39139 Mdot
.27774 .48907 Mdot
.38675 .38066 Mdot
.5512 .66416 Mdot
.54139 .65973 Mdot
.44424 .26346 Mdot
.32418 .45316 Mdot
.58554 .51237 Mdot
.60928 .41324 Mdot
.51345 .35467 Mdot
.31472 .47587 Mdot
.44976 .24199 Mdot
.30278 .72988 Mdot
.6506 .36454 Mdot
.27101 .48478 Mdot
.57213 .79393 Mdot
.51939 .34908 Mdot
.62567 .54482 Mdot
.61459 .57129 Mdot
.64017 .311 Mdot
.67 .54428 Mdot
.31339 .4557 Mdot
.61639 .55159 Mdot
.32735 .47603 Mdot
.54695 .6541 Mdot
.33182 .64766 Mdot
.32143 .47038 Mdot
.50857 .35672 Mdot
.75059 .73496 Mdot
.35262 .6762 Mdot
.52931 .39912 Mdot
.33599 .65913 Mdot
.34252 .45659 Mdot
.3094 .46449 Mdot
.63522 .53588 Mdot
.47909 .26417 Mdot
.3676 .67455 Mdot
.53602 .41188 Mdot
.38242 .46895 Mdot
.45009 .26376 Mdot
.62132 .58067 Mdot
.5012 .34336 Mdot
.48779 .34452 Mdot
.58322 .79703 Mdot
.55053 .44946 Mdot
.36343 .59389 Mdot
.32609 .64747 Mdot
.29738 .60773 Mdot
.2901 .49768 Mdot
.70604 .51668 Mdot
.28178 .44415 Mdot
.61792 .51584 Mdot
.5607 .68842 Mdot
.51816 .39726 Mdot
.63563 .54719 Mdot
.35461 .689 Mdot
.71842 .53336 Mdot
.49966 .40704 Mdot
.51844 .69379 Mdot
.6226 .55585 Mdot
.36263 .66983 Mdot
.29383 .47618 Mdot
.32318 .46061 Mdot
.54009 .77262 Mdot
.53956 .39682 Mdot
.52384 .37275 Mdot
.3422 .64215 Mdot
.716 .55913 Mdot
.75955 .54243 Mdot
.60089 .56179 Mdot
.33595 .6471 Mdot
.65085 .36344 Mdot
.30499 .44078 Mdot
.53169 .40283 Mdot
.64359 .38886 Mdot
.30184 .59832 Mdot
.23562 .43815 Mdot
.74779 .545 Mdot
.62135 .32232 Mdot
.31223 .4557 Mdot
.36987 .65522 Mdot
.70662 .71983 Mdot
.47493 .27771 Mdot
.49417 .37347 Mdot
.6118 .31688 Mdot
.60763 .41064 Mdot
.46596 .24784 Mdot
.6245 .51379 Mdot
.63447 .35598 Mdot
.44314 .25909 Mdot
.44867 .25126 Mdot
.5084 .34153 Mdot
.50237 .34206 Mdot
.31248 .47095 Mdot
.4412 .31369 Mdot
.54371 .69015 Mdot
.47383 .24756 Mdot
.78693 .54085 Mdot
.47422 .26549 Mdot
.50447 .32901 Mdot
.22041 .45337 Mdot
.61615 .2791 Mdot
.31803 .48333 Mdot
.26445 .47173 Mdot
.38483 .67451 Mdot
.45131 .26756 Mdot
.55338 .66534 Mdot
.58302 .55656 Mdot
.57387 .6821 Mdot
.31136 .47243 Mdot
.56753 .70089 Mdot
.3845 .63857 Mdot
.52315 .6919 Mdot
.56634 .67451 Mdot
.3804 .6592 Mdot
.29976 .44329 Mdot
.48266 .34331 Mdot
.38095 .65988 Mdot
.58533 .52 Mdot
.70276 .53395 Mdot
.3461 .41667 Mdot
.59263 .5538 Mdot
.52613 .33204 Mdot
.32318 .76009 Mdot
.52753 .69831 Mdot
.60138 .31967 Mdot
.28539 .45004 Mdot
.77977 .54326 Mdot
.31943 .46801 Mdot
.57785 .52741 Mdot
.75172 .54012 Mdot
.54579 .36462 Mdot
.79704 .53116 Mdot
.39236 .71648 Mdot
.5587 .42047 Mdot
.35884 .42739 Mdot
.57546 .67736 Mdot
.37786 .67402 Mdot
.4317 .66758 Mdot
.62199 .54694 Mdot
.26948 .46542 Mdot
.30645 .53415 Mdot
.6115 .51506 Mdot
.37223 .65784 Mdot
.37361 .30204 Mdot
.53163 .40634 Mdot
.37987 .67958 Mdot
.49915 .34439 Mdot
.4158 .26898 Mdot
.68714 .54189 Mdot
.62489 .56014 Mdot
.45246 .27422 Mdot
.52415 .71212 Mdot
.44553 .26608 Mdot
.44487 .29752 Mdot
.71458 .447 Mdot
.50297 .35185 Mdot
.60421 .31811 Mdot
.5457 .64357 Mdot
.32827 .48163 Mdot
.60559 .52579 Mdot
.61022 .5396 Mdot
.46239 .28213 Mdot
.82297 .64244 Mdot
.71437 .5371 Mdot
.56585 .7899 Mdot
.50513 .36641 Mdot
.5249 .36344 Mdot
.27894 .4454 Mdot
.40688 .2949 Mdot
.60446 .56133 Mdot
.49466 .36387 Mdot
.62446 .28481 Mdot
.36598 .65006 Mdot
.52799 .34033 Mdot
.53492 .36454 Mdot
.40654 .61201 Mdot
.37394 .65582 Mdot
.56167 .65063 Mdot
.63694 .53462 Mdot
.51169 .71473 Mdot
.76612 .52614 Mdot
.6251 .33582 Mdot
.71347 .43198 Mdot
.64797 .36797 Mdot
.76434 .53457 Mdot
.46893 .26844 Mdot
.51405 .32352 Mdot
.49119 .36893 Mdot
.73333 .5462 Mdot
.40648 .66108 Mdot
.31625 .47426 Mdot
.4139 .27632 Mdot
.61124 .54125 Mdot
.45174 .24797 Mdot
.76388 .51937 Mdot
.32522 .47739 Mdot
.36801 .2829 Mdot
.30543 .4707 Mdot
.36466 .66657 Mdot
.51668 .75424 Mdot
.75398 .53873 Mdot
.32012 .46789 Mdot
.53811 .71121 Mdot
.37541 .59846 Mdot
.4814 .31551 Mdot
.38833 .64079 Mdot
.36165 .47249 Mdot
.26637 .47671 Mdot
.28797 .50012 Mdot
.46366 .28011 Mdot
.60342 .31913 Mdot
.62268 .52037 Mdot
.33333 .65053 Mdot
.51942 .70854 Mdot
.70578 .45473 Mdot
.37557 .32506 Mdot
.6315 .37095 Mdot
.52966 .3474 Mdot
.51506 .3747 Mdot
.52805 .35877 Mdot
.6108 .50765 Mdot
.52214 .32688 Mdot
.50306 .34908 Mdot
.39379 .68223 Mdot
.5643 .65284 Mdot
.50584 .37048 Mdot
.59559 .53414 Mdot
.67257 .53489 Mdot
.78033 .54273 Mdot
.41814 .23653 Mdot
.33639 .41576 Mdot
.32365 .47402 Mdot
.55568 .67534 Mdot
.52928 .7169 Mdot
.70594 .52452 Mdot
.35273 .64958 Mdot
.30282 .4697 Mdot
.66994 .78557 Mdot
.75781 .53287 Mdot
.51993 .38945 Mdot
.64006 .39039 Mdot
.62574 .29188 Mdot
.49631 .32777 Mdot
.51309 .39409 Mdot
.58864 .53251 Mdot
.5567 .667 Mdot
.46947 .31285 Mdot
.36862 .28122 Mdot
.74794 .55026 Mdot
.70202 .54104 Mdot
.31725 .50155 Mdot
.54001 .4093 Mdot
.35845 .6761 Mdot
.64637 .33597 Mdot
.42562 .64485 Mdot
.1823 .53867 Mdot
.57948 .70313 Mdot
.49309 .38826 Mdot
.42209 .38368 Mdot
.54291 .34492 Mdot
.32698 .49928 Mdot
.33382 .5238 Mdot
.31492 .48728 Mdot
.3612 .64917 Mdot
.6381 .46514 Mdot
.38326 .64405 Mdot
.60942 .5632 Mdot
.29439 .45212 Mdot
.55982 .43351 Mdot
.54185 .66032 Mdot
.44648 .25925 Mdot
.73657 .53631 Mdot
.58086 .42895 Mdot
.60751 .52833 Mdot
.62282 .32646 Mdot
.52136 .66625 Mdot
.32176 .44227 Mdot
.44584 .25854 Mdot
.50839 .74434 Mdot
.63564 .36039 Mdot
.59656 .66988 Mdot
.63644 .54668 Mdot
.75673 .5394 Mdot
.44789 .40927 Mdot
.75363 .52671 Mdot
.3656 .67422 Mdot
.50189 .36575 Mdot
.54706 .39528 Mdot
.51786 .36474 Mdot
.53899 .35815 Mdot
.35568 .6533 Mdot
.4531 .25433 Mdot
.58051 .53557 Mdot
.63214 .5501 Mdot
.47368 .25902 Mdot
.72531 .5321 Mdot
.3841 .65219 Mdot
.57194 .65725 Mdot
.59329 .52076 Mdot
.7487 .51545 Mdot
.55313 .41445 Mdot
.49873 .3574 Mdot
.62142 .55908 Mdot
.54762 .36833 Mdot
.45586 .25633 Mdot
.52889 .69031 Mdot
.45854 .24824 Mdot
.78088 .54117 Mdot
.74187 .53584 Mdot
.34772 .66527 Mdot
.32141 .46833 Mdot
.71695 .51971 Mdot
.51281 .6768 Mdot
.55169 .36002 Mdot
.50283 .34285 Mdot
.35183 .51405 Mdot
.67507 .46601 Mdot
.77752 .54429 Mdot
.55034 .37675 Mdot
.30651 .4976 Mdot
.28729 .53114 Mdot
.49375 .36907 Mdot
.46202 .2586 Mdot
.27198 .48932 Mdot
.70507 .5331 Mdot
.34827 .65155 Mdot
.66227 .41441 Mdot
.34299 .67307 Mdot
.29255 .47622 Mdot
.61413 .55069 Mdot
.29847 .44445 Mdot
.6209 .54875 Mdot
.19585 .49961 Mdot
.5043 .34612 Mdot
.36658 .49923 Mdot
.58426 .55213 Mdot
.54734 .65935 Mdot
.56703 .66297 Mdot
.59555 .52725 Mdot
.30897 .4535 Mdot
.62307 .52287 Mdot
.7434 .52281 Mdot
.3006 .60501 Mdot
.26653 .48379 Mdot
.56708 .67384 Mdot
.52512 .69814 Mdot
.33557 .64687 Mdot
.51363 .36781 Mdot
.53092 .40377 Mdot
.52095 .689 Mdot
.42541 .64674 Mdot
.27662 .46747 Mdot
.52396 .37366 Mdot
.58481 .53551 Mdot
.53776 .69093 Mdot
.35807 .72475 Mdot
.34237 .45336 Mdot
.45177 .27445 Mdot
.71563 .44455 Mdot
.33473 .6394 Mdot
.54199 .34605 Mdot
.45697 .25825 Mdot
.71976 .54447 Mdot
.61867 .319 Mdot
.66797 .46403 Mdot
.37013 .63441 Mdot
.62475 .52008 Mdot
.49751 .3273 Mdot
.55685 .6574 Mdot
.55404 .36877 Mdot
.76448 .28439 Mdot
.62007 .56153 Mdot
.5401 .39003 Mdot
.61338 .56897 Mdot
.30319 .46086 Mdot
.52214 .36781 Mdot
.35663 .59283 Mdot
.55226 .67562 Mdot
.53857 .39706 Mdot
.75754 .56146 Mdot
.33747 .66221 Mdot
.60669 .52893 Mdot
.75659 .54373 Mdot
.47283 .25066 Mdot
.71366 .41408 Mdot
.58019 .65385 Mdot
.72364 .52604 Mdot
.51241 .36507 Mdot
.50945 .67732 Mdot
.39707 .66239 Mdot
.60307 .52492 Mdot
.55716 .41763 Mdot
.39095 .66303 Mdot
.3734 .65116 Mdot
.75191 .53319 Mdot
.3554 .25905 Mdot
.52752 .41965 Mdot
.53374 .38677 Mdot
.36506 .28794 Mdot
.25105 .50768 Mdot
.52332 .40178 Mdot
.53689 .3614 Mdot
.35623 .67053 Mdot
.63427 .46588 Mdot
.62157 .32445 Mdot
.5878 .55916 Mdot
.38079 .67065 Mdot
.55953 .70758 Mdot
.54294 .69756 Mdot
.72419 .52228 Mdot
.3098 .47961 Mdot
.7098 .52007 Mdot
.54344 .6838 Mdot
.52235 .38844 Mdot
.34286 .65457 Mdot
.43312 .2419 Mdot
.33669 .66389 Mdot
.51405 .68019 Mdot
.34017 .48409 Mdot
.4626 .30801 Mdot
.76137 .27793 Mdot
.47342 .62362 Mdot
.51494 .75435 Mdot
.72649 .5505 Mdot
.36874 .28235 Mdot
.50753 .36255 Mdot
.45106 .30874 Mdot
.53197 .39759 Mdot
.69356 .52639 Mdot
.57845 .67759 Mdot
.63532 .53594 Mdot
.62264 .54632 Mdot
.62072 .32823 Mdot
.37021 .64895 Mdot
.37466 .63801 Mdot
.60619 .55476 Mdot
.3683 .6655 Mdot
.53839 .38654 Mdot
.52324 .67041 Mdot
.19766 .48804 Mdot
.51186 .3545 Mdot
.64275 .55688 Mdot
.35672 .63104 Mdot
.34815 .47182 Mdot
.55863 .70791 Mdot
.41849 .37454 Mdot
.19366 .57629 Mdot
.37201 .67192 Mdot
.41889 .23663 Mdot
.55318 .67067 Mdot
.59272 .52157 Mdot
.50842 .6761 Mdot
.53542 .39082 Mdot
.49284 .38795 Mdot
.59479 .51493 Mdot
.51588 .3567 Mdot
.38793 .39697 Mdot
.47829 .27503 Mdot
.49 .27453 Mdot
.49626 .35247 Mdot
.36318 .46301 Mdot
.3985 .66981 Mdot
.60713 .55395 Mdot
.59259 .42284 Mdot
.48771 .35254 Mdot
.29006 .49836 Mdot
.38874 .66399 Mdot
.20742 .59206 Mdot
.3608 .6505 Mdot
.54456 .65693 Mdot
.35685 .64736 Mdot
.54466 .34735 Mdot
.29387 .4661 Mdot
.53678 .67745 Mdot
.60796 .53301 Mdot
.53809 .70575 Mdot
.52248 .40872 Mdot
.34491 .72393 Mdot
.54815 .69687 Mdot
.4763 .2741 Mdot
.29627 .46539 Mdot
.80094 .52944 Mdot
.31886 .40847 Mdot
.52681 .38962 Mdot
.52703 .39742 Mdot
.59903 .56046 Mdot
.34905 .66049 Mdot
.32166 .44123 Mdot
.55735 .78361 Mdot
.77808 .5446 Mdot
.31325 .48341 Mdot
.69208 .54591 Mdot
.62331 .40139 Mdot
.33533 .47663 Mdot
.62655 .28753 Mdot
.3527 .67294 Mdot
.32012 .45794 Mdot
.61398 .5882 Mdot
.44984 .23695 Mdot
.73527 .52908 Mdot
.52284 .71549 Mdot
.61963 .40588 Mdot
.5502 .69182 Mdot
.38009 .59975 Mdot
.48725 .69675 Mdot
.3718 .67546 Mdot
.73939 .56299 Mdot
.48231 .26885 Mdot
.38632 .64169 Mdot
.32229 .58826 Mdot
.54961 .68647 Mdot
.60702 .55757 Mdot
.45969 .25108 Mdot
.59315 .51264 Mdot
.62243 .55241 Mdot
.36615 .63432 Mdot
.32307 .4583 Mdot
.33018 .45714 Mdot
.62354 .57284 Mdot
.32532 .4626 Mdot
.52688 .68011 Mdot
.64971 .37598 Mdot
.42894 .33446 Mdot
.39997 .66817 Mdot
.4709 .24827 Mdot
.5107 .33405 Mdot
.58205 .67314 Mdot
.52611 .67189 Mdot
.36563 .64875 Mdot
.28242 .4079 Mdot
.62744 .54472 Mdot
.34584 .46142 Mdot
.29371 .45684 Mdot
.30618 .45967 Mdot
.28051 .45037 Mdot
.65216 .46619 Mdot
.38259 .66454 Mdot
.30675 .4538 Mdot
.52461 .34862 Mdot
.53167 .35805 Mdot
.59673 .51865 Mdot
.70716 .5165 Mdot
.46398 .25661 Mdot
.62517 .52434 Mdot
.49751 .38175 Mdot
.54593 .66122 Mdot
.64133 .57498 Mdot
.6253 .51879 Mdot
.55472 .66507 Mdot
.55319 .66152 Mdot
.62962 .52303 Mdot
.64848 .56886 Mdot
.38869 .40273 Mdot
.43794 .24498 Mdot
.36406 .44338 Mdot
.57134 .67068 Mdot
.3292 .58625 Mdot
.36597 .50029 Mdot
.54626 .39299 Mdot
.59745 .56141 Mdot
.52786 .66353 Mdot
.26433 .4806 Mdot
.53134 .37422 Mdot
.61592 .54462 Mdot
.74093 .52602 Mdot
.60413 .53345 Mdot
.58892 .53715 Mdot
.28651 .4921 Mdot
.33039 .76404 Mdot
.32738 .49079 Mdot
.49453 .67833 Mdot
.61367 .53017 Mdot
.34019 .23105 Mdot
.57621 .67228 Mdot
.30001 .608 Mdot
.48159 .26854 Mdot
.49255 .37037 Mdot
.55538 .67687 Mdot
.26871 .47043 Mdot
.40685 .65622 Mdot
.61508 .27547 Mdot
.32081 .46689 Mdot
.62843 .51734 Mdot
.59128 .5316 Mdot
.54172 .69117 Mdot
.28787 .47384 Mdot
.45766 .25868 Mdot
.31523 .45983 Mdot
.36652 .63898 Mdot
.54936 .36743 Mdot
.19246 .56806 Mdot
.62089 .54524 Mdot
.33102 .46687 Mdot
.51499 .70435 Mdot
.74209 .51862 Mdot
.54859 .38143 Mdot
.18756 .57858 Mdot
.51333 .36242 Mdot
.35245 .63817 Mdot
.65711 .54912 Mdot
.44998 .23943 Mdot
.5096 .38722 Mdot
.50306 .32561 Mdot
.40531 .68249 Mdot
.50641 .38537 Mdot
.48646 .34421 Mdot
.36771 .2666 Mdot
.32967 .4859 Mdot
.50646 .36906 Mdot
.52183 .68533 Mdot
.52434 .60591 Mdot
.53932 .3745 Mdot
.52175 .75506 Mdot
.63901 .31289 Mdot
.57886 .54406 Mdot
.60651 .58283 Mdot
.70973 .4403 Mdot
.53041 .39372 Mdot
.5293 .41588 Mdot
.54761 .36438 Mdot
.43034 .36176 Mdot
.54766 .68066 Mdot
.50657 .709 Mdot
.7335 .51895 Mdot
.60873 .31476 Mdot
.74526 .53453 Mdot
.39722 .66397 Mdot
.47782 .28641 Mdot
.63755 .54163 Mdot
.32465 .47005 Mdot
.51923 .36355 Mdot
.51136 .70713 Mdot
.53693 .39172 Mdot
.45963 .27048 Mdot
.52962 .68532 Mdot
.53297 .66046 Mdot
.49661 .71047 Mdot
.74326 .55294 Mdot
.32168 .47954 Mdot
.54966 .39663 Mdot
.75439 .54817 Mdot
.59576 .51316 Mdot
.66716 .40558 Mdot
.32049 .48244 Mdot
.33149 .47147 Mdot
.31215 .44514 Mdot
.54654 .40088 Mdot
.55485 .38876 Mdot
.38164 .64458 Mdot
.35121 .51483 Mdot
.34049 .66487 Mdot
.55604 .6801 Mdot
.5478 .65226 Mdot
.53506 .39281 Mdot
.70965 .55469 Mdot
.72741 .53178 Mdot
.53256 .70451 Mdot
.62596 .56235 Mdot
.73597 .5159 Mdot
.53385 .41138 Mdot
.55353 .68809 Mdot
.75878 .54823 Mdot
.28166 .40787 Mdot
.22659 .56753 Mdot
.74174 .51778 Mdot
.6247 .54374 Mdot
.37724 .33256 Mdot
.70632 .45042 Mdot
.68761 .54161 Mdot
.39888 .66723 Mdot
.48165 .35757 Mdot
.62603 .56049 Mdot
.74606 .51572 Mdot
.70498 .46103 Mdot
.53722 .68425 Mdot
.62659 .54164 Mdot
.66506 .56882 Mdot
.42974 .3352 Mdot
.74889 .51884 Mdot
.33213 .46874 Mdot
.35036 .45199 Mdot
.51616 .39146 Mdot
.47799 .26232 Mdot
.39989 .67482 Mdot
.53 .7159 Mdot
.50956 .70905 Mdot
.31438 .53037 Mdot
.64923 .36647 Mdot
.52809 .69292 Mdot
.49528 .39882 Mdot
.74506 .51281 Mdot
.52352 .34811 Mdot
.64721 .56283 Mdot
.44571 .23954 Mdot
.60211 .58094 Mdot
.74218 .51826 Mdot
.40172 .66743 Mdot
.37864 .66202 Mdot
.35067 .65886 Mdot
.53229 .69307 Mdot
.61503 .40643 Mdot
.50419 .70268 Mdot
.35805 .25583 Mdot
.71279 .53484 Mdot
.59861 .8027 Mdot
.52941 .33241 Mdot
.49899 .38699 Mdot
.44793 .24632 Mdot
.58679 .54169 Mdot
.53079 .39063 Mdot
.39143 .66036 Mdot
.53823 .71087 Mdot
.35856 .72693 Mdot
.28705 .48707 Mdot
.3603 .25809 Mdot
.54085 .6616 Mdot
.64093 .55564 Mdot
.73188 .53539 Mdot
.7241 .43248 Mdot
.68889 .53202 Mdot
.52681 .65843 Mdot
.50766 .40469 Mdot
.27229 .49214 Mdot
.67945 .78217 Mdot
.52031 .36787 Mdot
.52785 .69935 Mdot
.58919 .65846 Mdot
.45915 .23791 Mdot
.48308 .42465 Mdot
.37028 .72623 Mdot
.6417 .38437 Mdot
.75626 .55203 Mdot
.5886 .51866 Mdot
.64769 .33081 Mdot
.54467 .68446 Mdot
.54435 .70633 Mdot
.68956 .54088 Mdot
.34714 .4737 Mdot
.30273 .44831 Mdot
.38937 .43325 Mdot
.38828 .65277 Mdot
.49125 .36008 Mdot
.55014 .68919 Mdot
.34123 .48019 Mdot
.5889 .42382 Mdot
.35712 .66192 Mdot
.5436 .70043 Mdot
.51656 .35716 Mdot
.51131 .38619 Mdot
.74489 .53274 Mdot
.67213 .53514 Mdot
.58315 .53119 Mdot
.30231 .60335 Mdot
.62119 .39331 Mdot
.47714 .28837 Mdot
.49403 .37303 Mdot
.27399 .472 Mdot
.61621 .51591 Mdot
.7297 .52972 Mdot
.55183 .36404 Mdot
.45856 .30839 Mdot
.26591 .47322 Mdot
.35459 .67465 Mdot
.6133 .53558 Mdot
.62348 .33767 Mdot
.51484 .35844 Mdot
.5327 .39615 Mdot
.46351 .27997 Mdot
.45905 .30157 Mdot
.57024 .68905 Mdot
.31424 .49561 Mdot
.75435 .54667 Mdot
.30748 .46594 Mdot
.54485 .77459 Mdot
.4799 .27378 Mdot
.48797 .38703 Mdot
.29522 .49805 Mdot
.29955 .47068 Mdot
.35327 .63831 Mdot
.37959 .66789 Mdot
.59305 .67809 Mdot
.54226 .36829 Mdot
.61822 .56306 Mdot
.30485 .45506 Mdot
.52479 .71583 Mdot
.74707 .5345 Mdot
.52562 .76263 Mdot
.50039 .35257 Mdot
.54666 .68727 Mdot
.60827 .52333 Mdot
.28717 .49004 Mdot
.54941 .66634 Mdot
.59232 .52203 Mdot
.70302 .537 Mdot
.48727 .32841 Mdot
.59527 .66235 Mdot
.61003 .5494 Mdot
.53956 .36221 Mdot
.48855 .25533 Mdot
.47626 .25797 Mdot
.58901 .56075 Mdot
.58552 .6775 Mdot
.60999 .54611 Mdot
.34167 .44706 Mdot
.46798 .24188 Mdot
.52746 .71303 Mdot
.36065 .50704 Mdot
.48138 .26994 Mdot
.61859 .55018 Mdot
.32857 .47932 Mdot
.55127 .77806 Mdot
.33444 .5003 Mdot
.69502 .45367 Mdot
.53559 .37151 Mdot
.5498 .69214 Mdot
.73745 .52853 Mdot
.36893 .63771 Mdot
.31789 .68885 Mdot
.33748 .58906 Mdot
.56468 .66637 Mdot
.52025 .36222 Mdot
.31656 .45712 Mdot
.37094 .67098 Mdot
.27696 .4461 Mdot
.50917 .68376 Mdot
.51996 .67787 Mdot
.44932 .24582 Mdot
.74544 .53556 Mdot
.52163 .32706 Mdot
.52011 .71464 Mdot
.48819 .69271 Mdot
.36915 .26972 Mdot
.76017 .54815 Mdot
.46288 .28075 Mdot
.62023 .57499 Mdot
.52659 .34027 Mdot
.3677 .28626 Mdot
.59136 .54059 Mdot
.28554 .48583 Mdot
.51083 .39684 Mdot
.39492 .80654 Mdot
.57713 .66859 Mdot
.64152 .38406 Mdot
.39147 .71675 Mdot
.37979 .65453 Mdot
.54865 .67405 Mdot
.52944 .36897 Mdot
.52328 .76103 Mdot
.72357 .5219 Mdot
.44216 .25969 Mdot
.61141 .55442 Mdot
.29452 .53143 Mdot
.34597 .65056 Mdot
.67244 .56061 Mdot
.3707 .63822 Mdot
.34854 .66434 Mdot
.28187 .4101 Mdot
.51725 .39125 Mdot
.539 .66569 Mdot
.5169 .68755 Mdot
.63379 .57072 Mdot
.49806 .66625 Mdot
.29684 .44738 Mdot
.38806 .80122 Mdot
.46266 .31221 Mdot
.50235 .36146 Mdot
.62534 .51439 Mdot
.60842 .56203 Mdot
.51633 .7544 Mdot
.5076 .38889 Mdot
.32566 .48553 Mdot
.51447 .71464 Mdot
.54135 .69683 Mdot
.47614 .273 Mdot
.37903 .66251 Mdot
.68652 .53442 Mdot
.52682 .67525 Mdot
.66073 .41395 Mdot
.5403 .39143 Mdot
.40553 .65121 Mdot
.52811 .67623 Mdot
.78753 .68933 Mdot
.33005 .77129 Mdot
.33259 .4884 Mdot
.48923 .32236 Mdot
.34093 .45236 Mdot
.74825 .52012 Mdot
.50206 .68733 Mdot
.38138 .63979 Mdot
.61125 .53078 Mdot
.41429 .70821 Mdot
.54055 .69459 Mdot
.31241 .47278 Mdot
.5213 .39443 Mdot
.42139 .23063 Mdot
.51106 .35604 Mdot
.63066 .46531 Mdot
.77449 .54607 Mdot
.31854 .6914 Mdot
.33907 .64412 Mdot
.48898 .32207 Mdot
.75357 .55009 Mdot
.52506 .65769 Mdot
.53144 .68645 Mdot
.19057 .58481 Mdot
.58907 .53542 Mdot
.50621 .67168 Mdot
.54138 .36496 Mdot
.49568 .70859 Mdot
.37535 .32508 Mdot
.37838 .6548 Mdot
.503 .33974 Mdot
.55726 .68843 Mdot
.34439 .49207 Mdot
.63659 .39177 Mdot
.53977 .38125 Mdot
.61356 .57011 Mdot
.37524 .67134 Mdot
.35967 .25298 Mdot
.57964 .67862 Mdot
.51062 .34625 Mdot
.39221 .66787 Mdot
.7354 .56213 Mdot
.33884 .72876 Mdot
.32177 .4802 Mdot
.52361 .69825 Mdot
.34892 .6502 Mdot
.61738 .52599 Mdot
.76209 .5424 Mdot
.51446 .66723 Mdot
.55778 .69056 Mdot
.4666 .26909 Mdot
.63269 .56483 Mdot
.68861 .544 Mdot
.27903 .46413 Mdot
.35622 .67227 Mdot
.46327 .2741 Mdot
.6675 .41375 Mdot
.55649 .38201 Mdot
.34798 .66834 Mdot
.34514 .2356 Mdot
.50021 .397 Mdot
.49801 .3527 Mdot
.4241 .23048 Mdot
.34433 .4504 Mdot
.27381 .46284 Mdot
.63347 .36617 Mdot
.464 .26003 Mdot
.56104 .43239 Mdot
.32057 .47527 Mdot
.30892 .47298 Mdot
.56091 .43208 Mdot
.46406 .26976 Mdot
.39066 .42974 Mdot
.3716 .66733 Mdot
.38083 .65644 Mdot
.30507 .46039 Mdot
.4477 .24575 Mdot
.37348 .68597 Mdot
.24726 .48495 Mdot
.51647 .67675 Mdot
.64133 .3212 Mdot
.30152 .46569 Mdot
.64003 .39375 Mdot
.36492 .67419 Mdot
.68966 .40223 Mdot
.63761 .30961 Mdot
.53527 .41726 Mdot
.51259 .3902 Mdot
.72531 .5492 Mdot
.60569 .53076 Mdot
.62937 .5225 Mdot
.35028 .65834 Mdot
.52111 .32631 Mdot
.3132 .48753 Mdot
.55021 .35375 Mdot
.70675 .45542 Mdot
.6984 .39834 Mdot
.47379 .31913 Mdot
.30914 .47823 Mdot
.29947 .48172 Mdot
.54996 .65113 Mdot
.55069 .71039 Mdot
.51539 .41916 Mdot
.37734 .66878 Mdot
.32942 .46104 Mdot
.34078 .66007 Mdot
.5431 .68485 Mdot
.53768 .66315 Mdot
.60851 .51401 Mdot
.62707 .53998 Mdot
.54325 .67669 Mdot
.52137 .75505 Mdot
.66756 .4121 Mdot
.34255 .52047 Mdot
.3559 .24229 Mdot
.71611 .42336 Mdot
.41527 .2711 Mdot
.73863 .52671 Mdot
.63827 .57706 Mdot
.39284 .6644 Mdot
.49379 .32088 Mdot
.50726 .39589 Mdot
.60355 .54427 Mdot
.38553 .67514 Mdot
.72458 .53956 Mdot
.37881 .65431 Mdot
.76168 .54167 Mdot
.52324 .71187 Mdot
.52354 .36217 Mdot
.51408 .40733 Mdot
.35508 .63829 Mdot
.54329 .65141 Mdot
.55707 .68631 Mdot
.73392 .52643 Mdot
.71575 .42955 Mdot
.54273 .68995 Mdot
.30117 .46668 Mdot
.20319 .47251 Mdot
.59188 .53763 Mdot
.5305 .37332 Mdot
.71228 .43897 Mdot
.47048 .24358 Mdot
.59765 .51219 Mdot
.61327 .53637 Mdot
.35544 .26128 Mdot
.53794 .40302 Mdot
.20225 .59565 Mdot
.6227 .51709 Mdot
.29982 .44403 Mdot
.54121 .66824 Mdot
.61518 .51083 Mdot
.61053 .57493 Mdot
.67797 .53479 Mdot
.61692 .51006 Mdot
.30129 .45027 Mdot
.33659 .44812 Mdot
.46241 .25051 Mdot
.36322 .21322 Mdot
.75707 .54131 Mdot
.72042 .53311 Mdot
.56978 .68696 Mdot
.38264 .60137 Mdot
.54975 .33956 Mdot
.71587 .53022 Mdot
.35205 .41618 Mdot
.4479 .24977 Mdot
.46754 .24831 Mdot
.47145 .25611 Mdot
.30094 .4408 Mdot
.53274 .42273 Mdot
.57541 .68126 Mdot
.31381 .474 Mdot
.4579 .2478 Mdot
.55711 .37005 Mdot
.3187 .48491 Mdot
.3527 .66743 Mdot
.47911 .29272 Mdot
.32093 .4603 Mdot
.61501 .27398 Mdot
.36398 .67677 Mdot
.47895 .31435 Mdot
.63761 .78023 Mdot
.80499 .66865 Mdot
.37406 .65286 Mdot
.54056 .70127 Mdot
.55107 .68693 Mdot
.52939 .68924 Mdot
.27698 .46079 Mdot
.55935 .65336 Mdot
.28693 .47706 Mdot
.51059 .75053 Mdot
.61432 .32166 Mdot
.753 .53956 Mdot
.50441 .66111 Mdot
.30706 .46033 Mdot
.36347 .27404 Mdot
.74884 .24577 Mdot
.5138 .3463 Mdot
.37972 .63817 Mdot
.71329 .5234 Mdot
.64677 .38365 Mdot
.72039 .54487 Mdot
.55368 .6713 Mdot
.62282 .33304 Mdot
.53801 .39251 Mdot
.22054 .57607 Mdot
.73766 .53016 Mdot
.30771 .47205 Mdot
.47075 .26818 Mdot
.58745 .67415 Mdot
.72662 .52214 Mdot
.74017 .53599 Mdot
.5312 .38652 Mdot
.32074 .4419 Mdot
.55735 .67485 Mdot
.37995 .67681 Mdot
.49324 .72482 Mdot
.57761 .43915 Mdot
.54036 .40128 Mdot
.49618 .34874 Mdot
.62839 .39872 Mdot
.52615 .76225 Mdot
.37401 .66322 Mdot
.68673 .46341 Mdot
.58296 .67402 Mdot
.71197 .45136 Mdot
.33557 .49633 Mdot
.50593 .65936 Mdot
.59261 .54309 Mdot
.59545 .51885 Mdot
.52306 .375 Mdot
.75627 .26376 Mdot
.50227 .43345 Mdot
.37741 .68523 Mdot
.59657 .54262 Mdot
.55317 .6496 Mdot
.27558 .45631 Mdot
.65881 .57422 Mdot
.46147 .25603 Mdot
.37786 .67826 Mdot
.5363 .68868 Mdot
.79255 .31226 Mdot
.72096 .54967 Mdot
.64314 .37819 Mdot
.52953 .35554 Mdot
.52579 .37708 Mdot
.35742 .65669 Mdot
.40672 .66748 Mdot
.36382 .25022 Mdot
.68384 .5267 Mdot
.188 .56311 Mdot
.36114 .69154 Mdot
.80755 .32873 Mdot
.61272 .56259 Mdot
.29753 .48478 Mdot
.63307 .52713 Mdot
.40533 .6682 Mdot
.51702 .40071 Mdot
.33068 .44449 Mdot
.60432 .5226 Mdot
.33156 .41122 Mdot
.47163 .25035 Mdot
.66269 .41243 Mdot
.51501 .3757 Mdot
.32583 .45022 Mdot
.31784 .47681 Mdot
.34209 .46389 Mdot
.59504 .52478 Mdot
.4947 .36289 Mdot
.50915 .34827 Mdot
.4951 .35099 Mdot
.36656 .25081 Mdot
.52338 .36532 Mdot
.27477 .4955 Mdot
.6475 .35815 Mdot
.40779 .81581 Mdot
.51282 .40605 Mdot
.34993 .65232 Mdot
.51984 .37608 Mdot
.73874 .55444 Mdot
.49004 .32635 Mdot
.47735 .25575 Mdot
.36967 .66243 Mdot
.44599 .29761 Mdot
.78648 .54128 Mdot
.53594 .40771 Mdot
.76409 .53657 Mdot
.29135 .63566 Mdot
.67968 .46273 Mdot
.37386 .30334 Mdot
.31283 .46013 Mdot
.50636 .6877 Mdot
.3979 .67947 Mdot
.54444 .65728 Mdot
.43643 .25021 Mdot
.63531 .54308 Mdot
.59231 .80139 Mdot
.67414 .41131 Mdot
.51418 .39911 Mdot
.59844 .55936 Mdot
.33002 .48208 Mdot
.57704 .6718 Mdot
.40724 .29258 Mdot
.44752 .24747 Mdot
.70412 .52514 Mdot
.71011 .54045 Mdot
.65188 .54218 Mdot
.34509 .468 Mdot
.37364 .32194 Mdot
.35883 .65726 Mdot
.53433 .69465 Mdot
.76784 .52424 Mdot
.36152 .42448 Mdot
.40706 .66033 Mdot
.51109 .74957 Mdot
.3482 .64854 Mdot
.49789 .38701 Mdot
.62493 .51653 Mdot
.37923 .47909 Mdot
.60192 .54993 Mdot
.55337 .36394 Mdot
.55918 .68818 Mdot
.59029 .53868 Mdot
.74203 .54976 Mdot
.34589 .65684 Mdot
.54367 .661 Mdot
.52654 .39519 Mdot
.32374 .47623 Mdot
.5544 .25191 Mdot
.57987 .64621 Mdot
.48007 .27003 Mdot
.48018 .27064 Mdot
.32306 .5313 Mdot
.58277 .5553 Mdot
.31546 .70284 Mdot
.4611 .23736 Mdot
.34802 .59018 Mdot
.69085 .54928 Mdot
.56452 .78978 Mdot
.50499 .70091 Mdot
.53529 .67932 Mdot
.52801 .40662 Mdot
.51583 .7166 Mdot
.49093 .39212 Mdot
.58309 .6833 Mdot
.29905 .60089 Mdot
.55892 .42033 Mdot
.52949 .68277 Mdot
.62708 .52348 Mdot
.54704 .37559 Mdot
.32563 .48814 Mdot
.50011 .69867 Mdot
.53566 .41711 Mdot
.57126 .7856 Mdot
.35459 .63798 Mdot
.59504 .52363 Mdot
.60129 .4205 Mdot
.36612 .6692 Mdot
.2926 .45145 Mdot
.48172 .34462 Mdot
.71574 .52681 Mdot
.29418 .47864 Mdot
.62811 .50779 Mdot
.74466 .53695 Mdot
.65106 .37496 Mdot
.29094 .46251 Mdot
.59395 .54338 Mdot
.70514 .53737 Mdot
.61491 .58215 Mdot
.53533 .6818 Mdot
.58913 .65667 Mdot
.61393 .54801 Mdot
.53668 .39578 Mdot
.56934 .65207 Mdot
.36465 .64738 Mdot
.53778 .36774 Mdot
.54834 .69185 Mdot
.5965 .53267 Mdot
.51557 .35056 Mdot
.46447 .2592 Mdot
.36795 .27698 Mdot
.57793 .54333 Mdot
.75119 .54468 Mdot
.34213 .46973 Mdot
.5074 .34574 Mdot
.75999 .53643 Mdot
.5427 .64452 Mdot
.52041 .34401 Mdot
.33602 .46734 Mdot
.32647 .40268 Mdot
.53197 .71613 Mdot
.35916 .67819 Mdot
.51558 .69024 Mdot
.76687 .52804 Mdot
.74534 .2386 Mdot
.62096 .51722 Mdot
.44083 .24787 Mdot
.49109 .33526 Mdot
.50472 .69074 Mdot
.31828 .47993 Mdot
.18134 .54893 Mdot
.48829 .326 Mdot
.52317 .34556 Mdot
.53058 .3777 Mdot
.49478 .73011 Mdot
.28288 .45192 Mdot
.53084 .37553 Mdot
.67213 .54345 Mdot
.49611 .34472 Mdot
.74169 .52074 Mdot
.61038 .7966 Mdot
.59016 .5213 Mdot
.33788 .22858 Mdot
.60266 .52195 Mdot
.52509 .68093 Mdot
.61505 .27338 Mdot
.59929 .41984 Mdot
.57408 .71555 Mdot
.29223 .45087 Mdot
.3638 .44417 Mdot
.53598 .66473 Mdot
.54972 .77762 Mdot
.45853 .25429 Mdot
.46891 .26677 Mdot
.547 .38176 Mdot
.55349 .67112 Mdot
.55047 .70606 Mdot
.63319 .5447 Mdot
.59773 .55782 Mdot
.47996 .31424 Mdot
.51546 .70746 Mdot
.52424 .36354 Mdot
.45512 .24005 Mdot
.40823 .66242 Mdot
.33434 .48449 Mdot
.39109 .64531 Mdot
.40342 .65201 Mdot
.41441 .27865 Mdot
.61983 .39401 Mdot
.38971 .65415 Mdot
.39453 .67577 Mdot
.50002 .73751 Mdot
.43447 .31887 Mdot
.74949 .52184 Mdot
.50544 .43551 Mdot
.53961 .65459 Mdot
.49595 .36398 Mdot
.28457 .44951 Mdot
.57903 .52449 Mdot
.18138 .5251 Mdot
.78322 .39421 Mdot
.45073 .26118 Mdot
.58032 .66446 Mdot
.61068 .55006 Mdot
.60517 .55414 Mdot
.70701 .45084 Mdot
.52535 .36631 Mdot
.52903 .71639 Mdot
.42993 .33348 Mdot
.3658 .69258 Mdot
.52194 .75802 Mdot
.34682 .46296 Mdot
.51878 .37263 Mdot
.27761 .47215 Mdot
.35349 .67888 Mdot
.75652 .53059 Mdot
.73502 .552 Mdot
.53327 .40987 Mdot
.48157 .26656 Mdot
.34619 .58956 Mdot
.46859 .26119 Mdot
.45973 .26844 Mdot
.61131 .5445 Mdot
.46652 .28281 Mdot
.51124 .34524 Mdot
.55356 .41935 Mdot
.59459 .51373 Mdot
.39965 .64996 Mdot
.42081 .31593 Mdot
.61684 .55104 Mdot
.48371 .32711 Mdot
.35043 .67696 Mdot
.46631 .25787 Mdot
.35945 .65041 Mdot
.5276 .76245 Mdot
.38033 .64545 Mdot
.75151 .54757 Mdot
.48767 .70764 Mdot
.35947 .24491 Mdot
.31853 .45813 Mdot
.38222 .66324 Mdot
.70226 .53613 Mdot
.35727 .64896 Mdot
.53084 .65813 Mdot
.38909 .69137 Mdot
.24717 .50013 Mdot
.65956 .4128 Mdot
.41824 .26854 Mdot
.37062 .69205 Mdot
.54268 .71242 Mdot
.30504 .45968 Mdot
.36282 .59474 Mdot
.48478 .33675 Mdot
.72546 .55127 Mdot
.52382 .37703 Mdot
.34629 .66033 Mdot
.56562 .65305 Mdot
.37236 .30394 Mdot
.7495 .54691 Mdot
.35619 .25095 Mdot
.51127 .70564 Mdot
.4883 .36895 Mdot
.3318 .64773 Mdot
.31169 .67273 Mdot
.34364 .64195 Mdot
.61719 .31634 Mdot
.62433 .56058 Mdot
.69133 .52021 Mdot
.29239 .47337 Mdot
.60898 .56429 Mdot
.81841 .50671 Mdot
.31694 .58855 Mdot
.31077 .49391 Mdot
.51373 .65655 Mdot
.54032 .395 Mdot
.46109 .28081 Mdot
.62583 .52878 Mdot
.32939 .45557 Mdot
.46368 .2798 Mdot
.60276 .51526 Mdot
.64703 .35388 Mdot
.34458 .46306 Mdot
.51742 .66112 Mdot
.54317 .36906 Mdot
.35886 .63382 Mdot
.3379 .66589 Mdot
.63116 .5212 Mdot
.37606 .63949 Mdot
.48317 .32634 Mdot
.29456 .46403 Mdot
.46243 .25151 Mdot
.73758 .51931 Mdot
.38633 .45156 Mdot
.58702 .51455 Mdot
.75726 .51095 Mdot
.53058 .35099 Mdot
.53793 .66452 Mdot
.40945 .71192 Mdot
.50638 .32956 Mdot
.31776 .47374 Mdot
.48746 .3396 Mdot
.46552 .2816 Mdot
.46881 .26411 Mdot
.5347 .69459 Mdot
.63708 .39323 Mdot
.52322 .36376 Mdot
.37161 .68023 Mdot
.55375 .44262 Mdot
.52018 .32843 Mdot
.68983 .52644 Mdot
.47708 .25513 Mdot
.3312 .65945 Mdot
.32586 .52883 Mdot
.53853 .66697 Mdot
.30812 .48749 Mdot
.25328 .46669 Mdot
.29085 .45283 Mdot
.35217 .48946 Mdot
.4624 .23791 Mdot
.19152 .59005 Mdot
.375 .32378 Mdot
.4162 .25521 Mdot
.26214 .47961 Mdot
.35483 .73982 Mdot
.31124 .49436 Mdot
.29237 .45136 Mdot
.19602 .4915 Mdot
.29132 .44949 Mdot
.53491 .39449 Mdot
.48757 .35179 Mdot
.46702 .31571 Mdot
.49113 .723 Mdot
.5102 .35509 Mdot
.60389 .50855 Mdot
.71047 .52348 Mdot
.34537 .47704 Mdot
.61138 .5332 Mdot
.64839 .38412 Mdot
.63874 .526 Mdot
.53098 .38754 Mdot
.52479 .35784 Mdot
.47191 .25966 Mdot
.70773 .3964 Mdot
.48901 .71821 Mdot
.31706 .44485 Mdot
.52138 .32804 Mdot
.33706 .72727 Mdot
.54314 .37283 Mdot
.49392 .32982 Mdot
.53656 .42131 Mdot
.539 .66562 Mdot
.28579 .44287 Mdot
.62599 .54947 Mdot
.38541 .45677 Mdot
.51179 .36521 Mdot
.59212 .50304 Mdot
.72421 .51373 Mdot
.53051 .36956 Mdot
.31352 .44208 Mdot
.46508 .28095 Mdot
.26854 .4769 Mdot
.28916 .46583 Mdot
.5209 .34458 Mdot
.34471 .47514 Mdot
.27155 .46635 Mdot
.46817 .26638 Mdot
.58029 .66081 Mdot
.30054 .60617 Mdot
.53764 .38904 Mdot
.74472 .54742 Mdot
.51027 .39173 Mdot
.75269 .52186 Mdot
.61593 .51033 Mdot
.60927 .54765 Mdot
.45154 .41162 Mdot
.53933 .70853 Mdot
.70017 .5261 Mdot
.48662 .69719 Mdot
.50634 .31219 Mdot
.34328 .41339 Mdot
.39904 .68685 Mdot
.58918 .64797 Mdot
.60885 .54607 Mdot
.64005 .46485 Mdot
.5648 .43934 Mdot
.38427 .64535 Mdot
.29577 .49585 Mdot
.41681 .33158 Mdot
.60152 .56239 Mdot
.51893 .65986 Mdot
.51757 .68521 Mdot
.3186 .58794 Mdot
.1978 .48832 Mdot
.51551 .40737 Mdot
.59889 .56096 Mdot
.48826 .26342 Mdot
.60498 .53014 Mdot
.63193 .54325 Mdot
.55427 .69452 Mdot
.51436 .35205 Mdot
.64988 .34938 Mdot
.55029 .68448 Mdot
.72721 .53557 Mdot
.28429 .48479 Mdot
.76129 .53857 Mdot
.23389 .55968 Mdot
.36287 .24858 Mdot
.54625 .67817 Mdot
.58639 .52804 Mdot
.49839 .36025 Mdot
.31865 .44085 Mdot
.27496 .4476 Mdot
.32741 .48862 Mdot
.72629 .51838 Mdot
.51386 .7131 Mdot
.57206 .7925 Mdot
.52165 .39304 Mdot
.30091 .47225 Mdot
.76523 .51868 Mdot
.5102 .3849 Mdot
.37926 .66572 Mdot
.46421 .27833 Mdot
.30452 .46832 Mdot
.44206 .24802 Mdot
.29151 .4724 Mdot
.52026 .68385 Mdot
.52839 .41096 Mdot
.54451 .39009 Mdot
.67614 .46389 Mdot
.72407 .53987 Mdot
.26594 .47754 Mdot
.61497 .39962 Mdot
.52705 .34044 Mdot
.70833 .44637 Mdot
.52965 .36292 Mdot
.41852 .26526 Mdot
.62445 .56868 Mdot
.60671 .51297 Mdot
.48922 .33557 Mdot
.53753 .38349 Mdot
.27728 .44694 Mdot
.3764 .32482 Mdot
.36593 .24853 Mdot
.35279 .67668 Mdot
.31568 .49455 Mdot
.55269 .6807 Mdot
.49844 .69644 Mdot
.55058 .65429 Mdot
.76777 .52658 Mdot
.46358 .25448 Mdot
.51524 .40375 Mdot
.37014 .68496 Mdot
.71152 .52983 Mdot
.30405 .4788 Mdot
.75142 .53317 Mdot
.62754 .39385 Mdot
.7371 .54858 Mdot
.63655 .5341 Mdot
.32169 .7604 Mdot
.45612 .24007 Mdot
.73875 .54088 Mdot
.33634 .48083 Mdot
.54451 .44777 Mdot
.54893 .40768 Mdot
.36347 .26962 Mdot
.70507 .52414 Mdot
.52455 .64885 Mdot
.53279 .35378 Mdot
.60189 .31824 Mdot
.35437 .65424 Mdot
.75994 .54389 Mdot
.34948 .64667 Mdot
.45642 .26882 Mdot
.36382 .45165 Mdot
.31472 .46869 Mdot
.4126 .6767 Mdot
.49477 .33396 Mdot
.75948 .54463 Mdot
.54204 .67934 Mdot
.43487 .32103 Mdot
.50318 .74345 Mdot
.58975 .49995 Mdot
.70057 .45324 Mdot
.57361 .6848 Mdot
.43464 .30173 Mdot
.36771 .64049 Mdot
.54171 .34345 Mdot
.44593 .24078 Mdot
.53278 .34478 Mdot
.5585 .68126 Mdot
.53488 .67863 Mdot
.56134 .7874 Mdot
.54306 .4002 Mdot
.53983 .41907 Mdot
.28248 .52765 Mdot
.51723 .7144 Mdot
.2901 .45421 Mdot
.32996 .45327 Mdot
.54274 .69998 Mdot
.27553 .48863 Mdot
.74255 .53601 Mdot
.63233 .35252 Mdot
.36927 .64102 Mdot
.33349 .65141 Mdot
.54481 .67662 Mdot
.56805 .68079 Mdot
.53848 .66366 Mdot
.45818 .2739 Mdot
.2891 .46129 Mdot
.5036 .40657 Mdot
.52172 .38246 Mdot
.55364 .39239 Mdot
.3451 .45505 Mdot
.48701 .32701 Mdot
.5645 .40669 Mdot
.72353 .51685 Mdot
.52547 .67697 Mdot
.34162 .66348 Mdot
.55689 .25696 Mdot
.36746 .68156 Mdot
.50179 .34238 Mdot
.30359 .59623 Mdot
.29382 .49463 Mdot
.72196 .54666 Mdot
.47625 .25631 Mdot
.74135 .55078 Mdot
.40853 .66305 Mdot
.28277 .52642 Mdot
.65024 .37004 Mdot
.50967 .40999 Mdot
.62348 .39939 Mdot
.70751 .71839 Mdot
.25106 .47341 Mdot
.35901 .67201 Mdot
.46839 .24477 Mdot
.64018 .53061 Mdot
.4817 .25248 Mdot
.52545 .4063 Mdot
.52836 .33233 Mdot
.59696 .31967 Mdot
.49338 .34204 Mdot
.3345 .48786 Mdot
.55859 .43181 Mdot
.58485 .53928 Mdot
.54975 .37579 Mdot
.20335 .59088 Mdot
.50616 .36233 Mdot
.52401 .41394 Mdot
.49927 .38466 Mdot
.5248 .33766 Mdot
.34935 .4592 Mdot
.46931 .25259 Mdot
.36373 .68098 Mdot
.633 .35159 Mdot
.36915 .64188 Mdot
.54637 .67162 Mdot
.57707 .53484 Mdot
.33373 .44304 Mdot
.73939 .55099 Mdot
.4303 .61897 Mdot
.60448 .31708 Mdot
.54917 .65117 Mdot
.66256 .46701 Mdot
.68667 .53604 Mdot
.63204 .53564 Mdot
.76846 .53218 Mdot
.55789 .68818 Mdot
.37816 .6588 Mdot
.50605 .40327 Mdot
.29896 .45439 Mdot
.32547 .46135 Mdot
.54747 .37074 Mdot
.29822 .61808 Mdot
.3376 .66453 Mdot
.5014 .66425 Mdot
.50879 .40166 Mdot
.50345 .33962 Mdot
.27255 .47657 Mdot
.57504 .66211 Mdot
.56661 .43219 Mdot
.73051 .52465 Mdot
.53961 .36613 Mdot
.58957 .54983 Mdot
.62697 .39498 Mdot
.35727 .67838 Mdot
.59408 .53401 Mdot
.50068 .36836 Mdot
.62638 .38581 Mdot
.44387 .26292 Mdot
.66741 .54217 Mdot
.56402 .70292 Mdot
.52233 .34556 Mdot
.54466 .38378 Mdot
.34487 .46221 Mdot
.36923 .64003 Mdot
.32049 .47985 Mdot
.2635 .52041 Mdot
.60902 .54725 Mdot
.3486 .63929 Mdot
.52492 .33817 Mdot
.34736 .68462 Mdot
.46611 .2778 Mdot
.52568 .38942 Mdot
.35776 .67072 Mdot
.28541 .46761 Mdot
.19079 .56176 Mdot
.42028 .31704 Mdot
.45883 .26981 Mdot
.50852 .38913 Mdot
.49275 .72383 Mdot
.57944 .5233 Mdot
.49228 .38638 Mdot
.32811 .46077 Mdot
.51188 .38639 Mdot
.37936 .68677 Mdot
.75625 .53443 Mdot
.32055 .47165 Mdot
.58002 .67153 Mdot
.52323 .69015 Mdot
.54709 .71242 Mdot
.63654 .53745 Mdot
.46713 .2828 Mdot
.34195 .46742 Mdot
.33637 .45727 Mdot
.61088 .4087 Mdot
.5254 .68094 Mdot
.74355 .52675 Mdot
.54872 .38769 Mdot
.59445 .55832 Mdot
.33959 .63676 Mdot
.33649 .22797 Mdot
.64749 .36795 Mdot
.76073 .5187 Mdot
.57704 .44329 Mdot
.61006 .54184 Mdot
.49678 .35478 Mdot
.75863 .54488 Mdot
.54515 .6977 Mdot
.44864 .27226 Mdot
.68664 .54926 Mdot
.52938 .64596 Mdot
.56495 .6621 Mdot
.34848 .68414 Mdot
.579 .68883 Mdot
.75978 .54688 Mdot
.62376 .51877 Mdot
.32395 .46592 Mdot
.52851 .36709 Mdot
.6219 .54252 Mdot
.52299 .67111 Mdot
.61974 .55961 Mdot
.49579 .38502 Mdot
.27475 .47998 Mdot
.53942 .65625 Mdot
.53205 .39222 Mdot
.45734 .23688 Mdot
.36825 .27587 Mdot
.57811 .6605 Mdot
.48438 .37278 Mdot
.66844 .56714 Mdot
.55824 .65965 Mdot
.56016 .682 Mdot
.52051 .34354 Mdot
.70603 .5473 Mdot
.51423 .36949 Mdot
.37792 .66317 Mdot
.63194 .39994 Mdot
.35444 .6384 Mdot
.7123 .4498 Mdot
.53937 .35711 Mdot
.48081 .31762 Mdot
.33913 .41183 Mdot
.79282 .54059 Mdot
.71811 .42478 Mdot
.50515 .34822 Mdot
.27133 .45875 Mdot
.63883 .39483 Mdot
.65555 .41289 Mdot
.24626 .49268 Mdot
.75822 .52636 Mdot
.35065 .65739 Mdot
.54309 .39466 Mdot
.20939 .58895 Mdot
.74411 .52259 Mdot
.70891 .44982 Mdot
.49236 .31882 Mdot
.31003 .47589 Mdot
.51993 .40804 Mdot
.31747 .46439 Mdot
.50261 .37892 Mdot
.371 .29405 Mdot
.34556 .5901 Mdot
.61657 .31666 Mdot
.62714 .52446 Mdot
.31177 .67297 Mdot
.41782 .26694 Mdot
.74229 .53266 Mdot
.44497 .24277 Mdot
.60477 .54172 Mdot
.37855 .65397 Mdot
.4215 .66401 Mdot
.53673 .6634 Mdot
.38125 .67395 Mdot
.29658 .48664 Mdot
.55713 .64871 Mdot
.61236 .56382 Mdot
.48766 .29274 Mdot
.75307 .55125 Mdot
.3481 .63931 Mdot
.53424 .37267 Mdot
.55701 .375 Mdot
.49506 .73075 Mdot
.61863 .79392 Mdot
.30834 .50305 Mdot
.35457 .24217 Mdot
.28245 .52651 Mdot
.72185 .53605 Mdot
.57722 .6575 Mdot
.50961 .39695 Mdot
.51627 .35462 Mdot
.56755 .66378 Mdot
.3186 .44055 Mdot
.69743 .53351 Mdot
.69337 .51885 Mdot
.37593 .68562 Mdot
.65555 .78938 Mdot
.32165 .47031 Mdot
.65364 .79066 Mdot
.56645 .78912 Mdot
.20102 .48033 Mdot
.71725 .42776 Mdot
.3692 .66723 Mdot
.65484 .79038 Mdot
.30595 .47485 Mdot
.48944 .35336 Mdot
.59802 .54624 Mdot
.63481 .5452 Mdot
.27773 .47744 Mdot
.55051 .66837 Mdot
.70562 .54781 Mdot
.52992 .40683 Mdot
.65361 .563 Mdot
.27706 .44596 Mdot
.52024 .71226 Mdot
.61051 .5264 Mdot
.34462 .66879 Mdot
.50956 .38677 Mdot
.72314 .51847 Mdot
.36873 .66573 Mdot
.59437 .519 Mdot
.62468 .33525 Mdot
.48169 .3454 Mdot
.48025 .26531 Mdot
.3568 .65364 Mdot
.57872 .4298 Mdot
.54131 .37361 Mdot
.36751 .64045 Mdot
.64237 .55449 Mdot
.31231 .69089 Mdot
.57114 .43238 Mdot
.31691 .58864 Mdot
.54611 .64712 Mdot
.58493 .67882 Mdot
.58238 .62399 Mdot
.48728 .71157 Mdot
.38013 .64844 Mdot
.61855 .53777 Mdot
.60368 .80278 Mdot
.36668 .6392 Mdot
.50004 .32798 Mdot
.5418 .39536 Mdot
.42907 .3345 Mdot
.5914 .52074 Mdot
.60523 .51909 Mdot
.36431 .5035 Mdot
.46099 .24431 Mdot
.61114 .52768 Mdot
.53331 .36319 Mdot
.33371 .44763 Mdot
.36408 .67529 Mdot
.84002 .44069 Mdot
.40194 .67378 Mdot
.46083 .28465 Mdot
.54523 .65301 Mdot
.55114 .64671 Mdot
.52908 .36959 Mdot
.48333 .62643 Mdot
.80303 .3228 Mdot
.54209 .39549 Mdot
.47605 .25572 Mdot
.7115 .45192 Mdot
.54932 .37366 Mdot
.31669 .49848 Mdot
.58763 .53694 Mdot
.3392 .45308 Mdot
.36455 .6674 Mdot
.7572 .52583 Mdot
.78777 .54772 Mdot
.35119 .65793 Mdot
.5094 .36131 Mdot
.59484 .50923 Mdot
.52726 .37764 Mdot
.49111 .36434 Mdot
.63011 .38533 Mdot
.75562 .51778 Mdot
.54388 .66399 Mdot
.74382 .55121 Mdot
.29261 .4501 Mdot
.34797 .23685 Mdot
.74523 .53141 Mdot
.43451 .32005 Mdot
.62169 .40379 Mdot
.60946 .79557 Mdot
.32602 .4624 Mdot
.74908 .52008 Mdot
.35045 .6546 Mdot
.62387 .42437 Mdot
.4453 .31113 Mdot
.37799 .67756 Mdot
.49267 .36801 Mdot
.33094 .45041 Mdot
.3163 .53246 Mdot
.33409 .66174 Mdot
.32998 .47665 Mdot
.57381 .43091 Mdot
.45595 .26354 Mdot
.36063 .68105 Mdot
.70849 .41139 Mdot
.33947 .64384 Mdot
.41355 .28793 Mdot
.46743 .27501 Mdot
.31872 .47266 Mdot
.41948 .23345 Mdot
.27778 .52277 Mdot
.60625 .51526 Mdot
.48539 .35468 Mdot
.7427 .52875 Mdot
.61492 .40625 Mdot
.58207 .66884 Mdot
.34489 .49085 Mdot
.30541 .46315 Mdot
.3409 .63443 Mdot
.32967 .47476 Mdot
.28881 .49461 Mdot
.41259 .67577 Mdot
.31091 .49533 Mdot
.51161 .36422 Mdot
.36539 .21221 Mdot
.33008 .48325 Mdot
.36048 .65956 Mdot
.72284 .52089 Mdot
.33338 .48721 Mdot
.55274 .78027 Mdot
.54316 .36821 Mdot
.50955 .68577 Mdot
.69852 .5472 Mdot
.34718 .45562 Mdot
.74011 .53097 Mdot
.52514 .66656 Mdot
.70577 .51809 Mdot
.32603 .64706 Mdot
.3285 .65702 Mdot
.60918 .57445 Mdot
.32118 .58712 Mdot
.29113 .44981 Mdot
.56408 .64951 Mdot
.54633 .39908 Mdot
.50027 .39052 Mdot
.76811 .55069 Mdot
.26401 .47208 Mdot
.29421 .62739 Mdot
.61152 .53185 Mdot
.38765 .45067 Mdot
.34337 .67127 Mdot
.50298 .6628 Mdot
.65223 .37013 Mdot
.42299 .63006 Mdot
.58442 .53711 Mdot
.60841 .54266 Mdot
.53099 .37771 Mdot
.68462 .46275 Mdot
.76292 .54006 Mdot
.36439 .73968 Mdot
.44796 .26118 Mdot
.57136 .66924 Mdot
.49799 .37273 Mdot
.45522 .24813 Mdot
.50911 .34542 Mdot
.76674 .52288 Mdot
.38926 .67183 Mdot
.32182 .45869 Mdot
.75381 .52137 Mdot
.52327 .69079 Mdot
.62608 .28697 Mdot
.49305 .38896 Mdot
.48997 .39086 Mdot
.55421 .66307 Mdot
.30107 .44767 Mdot
.54022 .67358 Mdot
.36872 .64104 Mdot
.74851 .53336 Mdot
.46219 .27868 Mdot
.59075 .52144 Mdot
.50426 .69171 Mdot
.38311 .66182 Mdot
.58135 .66082 Mdot
.35723 .68967 Mdot
.60717 .54548 Mdot
.48354 .37531 Mdot
.5192 .71759 Mdot
.6086 .55794 Mdot
.38477 .37327 Mdot
.623 .33783 Mdot
.21203 .46497 Mdot
.55335 .66842 Mdot
.5777 .71797 Mdot
.36585 .66329 Mdot
.40318 .66163 Mdot
.41073 .283 Mdot
.75754 .26741 Mdot
.56153 .43108 Mdot
.28953 .65748 Mdot
.37039 .64128 Mdot
.36403 .65255 Mdot
.53914 .67079 Mdot
.28422 .46846 Mdot
.32779 .40933 Mdot
.52891 .65602 Mdot
.7094 .43704 Mdot
.30384 .47853 Mdot
.46514 .31466 Mdot
.50508 .70625 Mdot
.47079 .26563 Mdot
.37179 .30484 Mdot
.72021 .51659 Mdot
.69411 .45606 Mdot
.3943 .68921 Mdot
.53149 .3989 Mdot
.18899 .58792 Mdot
.53354 .66609 Mdot
.61729 .55863 Mdot
.34672 .72558 Mdot
.5565 .3691 Mdot
.49616 .36739 Mdot
.51316 .37813 Mdot
.75687 .55373 Mdot
.37792 .34062 Mdot
.52372 .40235 Mdot
.6195 .32728 Mdot
.47254 .28739 Mdot
.58907 .65407 Mdot
.74671 .55031 Mdot
.65203 .4678 Mdot
.54063 .76755 Mdot
.38498 .4619 Mdot
.52942 .33257 Mdot
.39872 .67063 Mdot
.46146 .24518 Mdot
.35364 .66956 Mdot
.34609 .67834 Mdot
.67214 .78432 Mdot
.32941 .45877 Mdot
.45103 .2656 Mdot
.54489 .70399 Mdot
.33371 .40922 Mdot
.456 .25073 Mdot
.35046 .23893 Mdot
.38541 .63853 Mdot
.74391 .2357 Mdot
.40111 .65646 Mdot
.62792 .55395 Mdot
.29873 .48982 Mdot
.27095 .45555 Mdot
.62255 .39842 Mdot
.28831 .45698 Mdot
.4882 .71354 Mdot
.3412 .46928 Mdot
.79674 .64587 Mdot
.24863 .4986 Mdot
.36775 .65941 Mdot
.33172 .6533 Mdot
.4679 .25561 Mdot
.51509 .363 Mdot
.64883 .35186 Mdot
.61087 .53123 Mdot
.48307 .34327 Mdot
.55022 .68505 Mdot
.55752 .78399 Mdot
.304 .73213 Mdot
.30544 .4956 Mdot
.38469 .65794 Mdot
.49645 .36942 Mdot
.46537 .27533 Mdot
.48719 .35351 Mdot
.38854 .60348 Mdot
.43216 .25342 Mdot
.52309 .38235 Mdot
.46511 .25525 Mdot
.53661 .65324 Mdot
.49739 .73152 Mdot
.19916 .48628 Mdot
.66455 .78642 Mdot
.51568 .34969 Mdot
.71602 .53331 Mdot
.76699 .52436 Mdot
.54612 .4238 Mdot
.54209 .5486 Mdot
.58151 .42975 Mdot
.53479 .37405 Mdot
.62318 .28285 Mdot
.5155 .66211 Mdot
.63824 .52838 Mdot
.52266 .67426 Mdot
.25428 .46462 Mdot
.62414 .51526 Mdot
.55165 .68932 Mdot
.64092 .31861 Mdot
.61533 .54585 Mdot
.31488 .69962 Mdot
.73902 .51915 Mdot
.53662 .36601 Mdot
.40351 .30725 Mdot
.51435 .71412 Mdot
.37504 .65959 Mdot
.31183 .49153 Mdot
.3606 .67876 Mdot
.48929 .711 Mdot
.7129 .44257 Mdot
.60028 .51827 Mdot
.39783 .67476 Mdot
.48264 .26789 Mdot
.71308 .53263 Mdot
.39573 .64966 Mdot
.4718 .28499 Mdot
.55177 .4235 Mdot
.77909 .30138 Mdot
.537 .41378 Mdot
.559 .78522 Mdot
.36018 .63718 Mdot
.64085 .5307 Mdot
.52739 .36671 Mdot
.51174 .702 Mdot
.60816 .58309 Mdot
.52793 .38021 Mdot
.57761 .67896 Mdot
.54198 .38803 Mdot
.75628 .54599 Mdot
.34355 .45819 Mdot
.64275 .3937 Mdot
.78803 .52758 Mdot
.7554 .52402 Mdot
.60105 .31427 Mdot
.48602 .36582 Mdot
.46639 .6575 Mdot
.31251 .47794 Mdot
.50045 .34344 Mdot
.78884 .52267 Mdot
.28542 .48071 Mdot
.30432 .4862 Mdot
.45275 .27779 Mdot
.38371 .68682 Mdot
.54818 .66331 Mdot
.718 .54255 Mdot
.51925 .75577 Mdot
.53049 .39742 Mdot
.44357 .24791 Mdot
.74704 .52162 Mdot
.37452 .67096 Mdot
.45315 .26632 Mdot
.29296 .69546 Mdot
.63187 .34902 Mdot
.39048 .64363 Mdot
.52856 .33326 Mdot
.43089 .23126 Mdot
.30294 .44107 Mdot
.19306 .59008 Mdot
.34468 .59044 Mdot
.51907 .68777 Mdot
.61304 .52697 Mdot
.33902 .23146 Mdot
.72741 .51804 Mdot
.3132 .40682 Mdot
.49774 .38776 Mdot
.50484 .38981 Mdot
.33162 .44557 Mdot
.51376 .41385 Mdot
.30008 .49581 Mdot
.55211 .77897 Mdot
.75498 .25991 Mdot
.32191 .46249 Mdot
.30885 .46751 Mdot
.47897 .29554 Mdot
.4962 .71079 Mdot
.2842 .48582 Mdot
.54516 .39324 Mdot
.48919 .71115 Mdot
.65821 .55293 Mdot
.70046 .5337 Mdot
.73218 .55648 Mdot
.30824 .50047 Mdot
.44393 .30667 Mdot
.47609 .27506 Mdot
.43081 .39426 Mdot
.58044 .44458 Mdot
.38054 .64785 Mdot
.55403 .37514 Mdot
.61011 .53577 Mdot
.5268 .66837 Mdot
.5413 .41595 Mdot
.53273 .36167 Mdot
.3172 .45589 Mdot
.71054 .51779 Mdot
.35287 .64231 Mdot
.61173 .5573 Mdot
.54607 .71374 Mdot
.72841 .53107 Mdot
.27851 .4904 Mdot
.41617 .27184 Mdot
.58378 .52047 Mdot
.59726 .55898 Mdot
.49824 .35133 Mdot
.51855 .34421 Mdot
.58318 .52939 Mdot
.35233 .66049 Mdot
.51773 .68786 Mdot
.62609 .54813 Mdot
.60523 .41474 Mdot
.64929 .34073 Mdot
.50242 .35323 Mdot
.33669 .4738 Mdot
.38143 .65547 Mdot
.6037 .51814 Mdot
.59983 .803 Mdot
.54997 .38462 Mdot
.46234 .30947 Mdot
.67151 .51508 Mdot
.61391 .53733 Mdot
.32794 .4092 Mdot
.72512 .54938 Mdot
.46705 .27483 Mdot
.61868 .32336 Mdot
.48524 .32772 Mdot
.54034 .34233 Mdot
.54918 .69564 Mdot
.34379 .65806 Mdot
.60869 .57259 Mdot
.52629 .67642 Mdot
.30673 .48716 Mdot
.43588 .39839 Mdot
.32491 .45099 Mdot
.33667 .4592 Mdot
.35222 .48553 Mdot
.35082 .67511 Mdot
.33871 .22982 Mdot
.58146 .53008 Mdot
.51768 .40935 Mdot
.39241 .66209 Mdot
.28487 .4884 Mdot
.48967 .32307 Mdot
.29445 .4948 Mdot
.26441 .4764 Mdot
.48461 .32883 Mdot
.46493 .25936 Mdot
.61323 .31955 Mdot
.45041 .29929 Mdot
.73453 .55273 Mdot
.30402 .44257 Mdot
.4534 .30884 Mdot
.51324 .39901 Mdot
.52318 .35759 Mdot
.46861 .25466 Mdot
.76185 .52512 Mdot
.45043 .41151 Mdot
.49585 .38271 Mdot
.68837 .46476 Mdot
.49268 .32411 Mdot
.2636 .47068 Mdot
.31804 .68977 Mdot
.46205 .28566 Mdot
.54849 .64958 Mdot
.32123 .44128 Mdot
.7206 .51604 Mdot
.35966 .46359 Mdot
.47574 .24904 Mdot
.36085 .64786 Mdot
.30464 .46838 Mdot
.51999 .66263 Mdot
.37503 .66285 Mdot
.33903 .64416 Mdot
.47076 .25584 Mdot
.51967 .6962 Mdot
.71209 .51705 Mdot
.33886 .65031 Mdot
.47526 .24172 Mdot
.36922 .6591 Mdot
.24192 .43166 Mdot
.49133 .39517 Mdot
.62059 .32677 Mdot
.62322 .52927 Mdot
.62092 .57087 Mdot
.34851 .6413 Mdot
.73115 .52348 Mdot
.45249 .26558 Mdot
.32505 .48952 Mdot
.71765 .52711 Mdot
.37308 .30794 Mdot
.55135 .64709 Mdot
.31582 .53224 Mdot
.5076 .74684 Mdot
.2813 .46007 Mdot
.69725 .45455 Mdot
.73587 .51408 Mdot
.58913 .55647 Mdot
.64166 .38308 Mdot
.60742 .52518 Mdot
.53659 .41825 Mdot
.4513 .26407 Mdot
.51071 .36479 Mdot
.5482 .65236 Mdot
.75511 .55418 Mdot
.33339 .48058 Mdot
.69058 .55986 Mdot
.37033 .67606 Mdot
.54995 .43083 Mdot
.62284 .55471 Mdot
.45935 .27143 Mdot
.29211 .49205 Mdot
.27218 .46352 Mdot
.37713 .32736 Mdot
.55765 .65817 Mdot
.71678 .55917 Mdot
.50237 .35512 Mdot
.65431 .57019 Mdot
.34927 .64037 Mdot
.31794 .58725 Mdot
.50934 .67792 Mdot
.74115 .23426 Mdot
.52709 .68047 Mdot
.67057 .53748 Mdot
.27525 .46479 Mdot
.74588 .54472 Mdot
.51049 .35721 Mdot
.34715 .46497 Mdot
.32531 .40862 Mdot
.71098 .55345 Mdot
.73727 .5505 Mdot
.35881 .59279 Mdot
.38874 .6525 Mdot
.60251 .55869 Mdot
.49448 .32474 Mdot
.48894 .32105 Mdot
.5446 .40162 Mdot
.38776 .65776 Mdot
.4599 .26272 Mdot
.31641 .68047 Mdot
.46945 .24481 Mdot
.78863 .52225 Mdot
.56328 .67904 Mdot
.39855 .8093 Mdot
.34329 .45323 Mdot
.44497 .40678 Mdot
.30036 .40404 Mdot
.62495 .34144 Mdot
.38819 .67582 Mdot
.64301 .55433 Mdot
.54271 .66726 Mdot
.42799 .6738 Mdot
.56327 .68166 Mdot
.8358 .3947 Mdot
.42795 .33485 Mdot
.31727 .69241 Mdot
.4838 .34431 Mdot
.53342 .7052 Mdot
.44007 .29861 Mdot
.62588 .54677 Mdot
.59567 .50892 Mdot
.44622 .2345 Mdot
.3658 .25251 Mdot
.7389 .553 Mdot
.5092 .35677 Mdot
.33709 .45159 Mdot
.51224 .35647 Mdot
.5116 .35543 Mdot
.49114 .37337 Mdot
.41365 .67584 Mdot
.48346 .37389 Mdot
.51361 .3635 Mdot
.57449 .79501 Mdot
.63903 .56831 Mdot
.57781 .69161 Mdot
.28029 .44523 Mdot
.7115 .52991 Mdot
.25461 .46469 Mdot
.64263 .38895 Mdot
.40567 .66583 Mdot
.3765 .33178 Mdot
.46525 .26811 Mdot
.33392 .49729 Mdot
.40151 .67086 Mdot
.69303 .53977 Mdot
.60794 .53842 Mdot
.18293 .5201 Mdot
.4866 .69751 Mdot
.59842 .53203 Mdot
.57806 .67039 Mdot
.48162 .30962 Mdot
.32482 .46796 Mdot
.6074 .52606 Mdot
.34549 .64874 Mdot
.55616 .69302 Mdot
.60428 .31567 Mdot
.51614 .3894 Mdot
.55603 .67137 Mdot
.6213 .53932 Mdot
.61571 .4058 Mdot
.63747 .39522 Mdot
.53416 .7057 Mdot
.35842 .6852 Mdot
.33533 .64936 Mdot
.71274 .52503 Mdot
.27786 .45483 Mdot
.29911 .45139 Mdot
.36942 .67494 Mdot
.43163 .67308 Mdot
.53219 .3939 Mdot
.52414 .39115 Mdot
.64812 .37655 Mdot
.5005 .33599 Mdot
.48773 .71508 Mdot
.60025 .53258 Mdot
.3032 .45617 Mdot
.45098 .26332 Mdot
.44758 .25072 Mdot
.5069 .35895 Mdot
.71453 .43539 Mdot
.53935 .6551 Mdot
.47669 .27183 Mdot
.75923 .54432 Mdot
.3691 .26869 Mdot
.54416 .37319 Mdot
.77988 .52161 Mdot
.27652 .46005 Mdot
.33723 .72983 Mdot
.37433 .65814 Mdot
.5417 .7067 Mdot
.54314 .70534 Mdot
.71116 .71597 Mdot
.34144 .45144 Mdot
.59918 .53123 Mdot
.53472 .64388 Mdot
.6339 .5277 Mdot
.7327 .54947 Mdot
.5643 .45235 Mdot
.48842 .71501 Mdot
.57808 .69101 Mdot
.32128 .65271 Mdot
.5497 .35796 Mdot
.53825 .36393 Mdot
.31441 .58982 Mdot
.52842 .36197 Mdot
.74957 .52901 Mdot
.39011 .64901 Mdot
.30516 .47005 Mdot
.7199 .55075 Mdot
.3997 .66557 Mdot
.29307 .45164 Mdot
.47234 .26081 Mdot
.49126 .32286 Mdot
.30854 .48941 Mdot
.27414 .48565 Mdot
.53559 .39425 Mdot
.68609 .77985 Mdot
.31442 .45699 Mdot
.30564 .49163 Mdot
.36854 .26574 Mdot
.53566 .71441 Mdot
.61409 .58164 Mdot
.38622 .68501 Mdot
.51299 .36949 Mdot
.56363 .6728 Mdot
.73335 .54528 Mdot
.30219 .46261 Mdot
.51474 .346 Mdot
.5281 .39747 Mdot
.71406 .53231 Mdot
.76472 .54255 Mdot
.72559 .52345 Mdot
.33476 .66313 Mdot
.46913 .26727 Mdot
.29117 .48905 Mdot
.38497 .67172 Mdot
.72964 .51544 Mdot
.75897 .54935 Mdot
.79717 .52326 Mdot
.53405 .39312 Mdot
.76668 .54146 Mdot
.34556 .23574 Mdot
.63705 .31152 Mdot
.63277 .5241 Mdot
.5875 .68837 Mdot
.52409 .72116 Mdot
.65784 .54157 Mdot
.34497 .65654 Mdot
.47227 .24999 Mdot
.69843 .53623 Mdot
.62357 .54395 Mdot
.52107 .39135 Mdot
.54798 .3674 Mdot
.71889 .53046 Mdot
.71543 .44277 Mdot
.31751 .45413 Mdot
.20741 .47276 Mdot
.71174 .53159 Mdot
.52477 .7083 Mdot
.51234 .66489 Mdot
.53347 .68142 Mdot
.50509 .35127 Mdot
.47267 .32115 Mdot
.57643 .43902 Mdot
.39098 .40647 Mdot
.38364 .64814 Mdot
.27123 .46758 Mdot
.36588 .26446 Mdot
.3026 .48489 Mdot
.56265 .65506 Mdot
.73214 .52337 Mdot
.32431 .44435 Mdot
.33391 .65576 Mdot
.33821 .64707 Mdot
.52176 .71726 Mdot
.52506 .68265 Mdot
.54431 .67873 Mdot
.34006 .44687 Mdot
.27608 .47819 Mdot
.48499 .33571 Mdot
.33456 .46989 Mdot
.5538 .77508 Mdot
.55082 .77822 Mdot
.51618 .71597 Mdot
.35766 .66276 Mdot
.28948 .46639 Mdot
.54394 .3857 Mdot
.59569 .32004 Mdot
.50805 .66866 Mdot
.70791 .52245 Mdot
.3648 .21267 Mdot
.75936 .27253 Mdot
.44864 .24282 Mdot
.36891 .64612 Mdot
.62304 .52025 Mdot
.51028 .37501 Mdot
.5177 .68445 Mdot
.60193 .49576 Mdot
.58833 .53416 Mdot
.50848 .41437 Mdot
.48967 .30555 Mdot
.37428 .65117 Mdot
.6453 .38954 Mdot
.62304 .54778 Mdot
.47493 .28751 Mdot
.39381 .65493 Mdot
.50423 .69629 Mdot
.5865 .63523 Mdot
.36989 .49582 Mdot
.60277 .45917 Mdot
.6003 .51477 Mdot
.55012 .39424 Mdot
.54703 .69004 Mdot
.71341 .54917 Mdot
.54568 .68718 Mdot
.26269 .48057 Mdot
.53211 .71603 Mdot
.54186 .38107 Mdot
.28847 .4869 Mdot
.33852 .64604 Mdot
.61357 .42978 Mdot
.76253 .56033 Mdot
.50993 .70303 Mdot
.58548 .55221 Mdot
.45561 .24512 Mdot
.48753 .28912 Mdot
.62147 .57089 Mdot
.53922 .36779 Mdot
.35719 .67095 Mdot
.2996 .49485 Mdot
.37825 .67096 Mdot
.60556 .58282 Mdot
.26017 .41786 Mdot
.37427 .6568 Mdot
.47399 .32427 Mdot
.70699 .54845 Mdot
.71411 .44005 Mdot
.53873 .3813 Mdot
.34285 .65345 Mdot
.49346 .3973 Mdot
.30967 .44161 Mdot
.64423 .32868 Mdot
.63029 .34696 Mdot
.36215 .67491 Mdot
.61924 .56362 Mdot
.6209 .40485 Mdot
.61122 .58271 Mdot
.36877 .64154 Mdot
.63797 .30579 Mdot
.59684 .53939 Mdot
.73183 .5345 Mdot
.75297 .55405 Mdot
.73244 .52922 Mdot
.52226 .38471 Mdot
.42838 .22973 Mdot
.74482 .51625 Mdot
.41991 .66474 Mdot
.75585 .52991 Mdot
.65597 .54963 Mdot
.29464 .62288 Mdot
.7594 .54707 Mdot
.53343 .36768 Mdot
.46952 .24515 Mdot
.4723 .25082 Mdot
.51351 .6768 Mdot
.17997 .53565 Mdot
.57371 .79442 Mdot
.50864 .39624 Mdot
.36076 .25522 Mdot
.34289 .46282 Mdot
.58406 .55209 Mdot
.62896 .34512 Mdot
.48132 .2703 Mdot
.29635 .48301 Mdot
.6431 .38536 Mdot
.33758 .52366 Mdot
.63014 .5326 Mdot
.52519 .38692 Mdot
.32438 .44236 Mdot
.34515 .49145 Mdot
.71727 .42393 Mdot
.38258 .46879 Mdot
.28999 .45889 Mdot
.3696 .64 Mdot
.34722 .65608 Mdot
.35837 .6724 Mdot
.52399 .68705 Mdot
.30767 .46588 Mdot
.55734 .42158 Mdot
.5195 .68579 Mdot
.49296 .3716 Mdot
.36509 .67569 Mdot
.62873 .33877 Mdot
.3084 .46822 Mdot
.53649 .37834 Mdot
.45177 .31202 Mdot
.57544 .68138 Mdot
.71508 .53162 Mdot
.35823 .24498 Mdot
.58711 .66907 Mdot
.35084 .68598 Mdot
.26155 .48097 Mdot
.64458 .5607 Mdot
.47796 .28502 Mdot
.50681 .34404 Mdot
.50491 .40272 Mdot
.47795 .28642 Mdot
.42861 .329 Mdot
.59305 .55155 Mdot
.52341 .69062 Mdot
.54628 .7105 Mdot
.54783 .37897 Mdot
.31048 .46278 Mdot
.75909 .51588 Mdot
.71518 .51031 Mdot
.69198 .55155 Mdot
.62841 .39943 Mdot
.61981 .32765 Mdot
.5149 .33566 Mdot
.46641 .41787 Mdot
.51658 .66849 Mdot
.63864 .5359 Mdot
.62885 .39431 Mdot
.7406 .53434 Mdot
.48941 .35623 Mdot
.26467 .45361 Mdot
.30094 .46546 Mdot
.55193 .66701 Mdot
.35817 .63388 Mdot
.58609 .51734 Mdot
.51384 .71601 Mdot
.54757 .37792 Mdot
.44807 .25571 Mdot
.37592 .63958 Mdot
.27623 .49201 Mdot
.72584 .53436 Mdot
.51889 .67924 Mdot
.74718 .54064 Mdot
.32832 .47617 Mdot
.30173 .46178 Mdot
.49171 .34382 Mdot
.71448 .56008 Mdot
.50711 .70305 Mdot
.50745 .35245 Mdot
.55502 .67584 Mdot
.49563 .73123 Mdot
.33779 .63673 Mdot
.49733 .34437 Mdot
.33249 .41076 Mdot
.3582 .67575 Mdot
.50093 .38634 Mdot
.47121 .2525 Mdot
.45359 .26637 Mdot
.52946 .70638 Mdot
.6988 .52639 Mdot
.73804 .53752 Mdot
.32038 .40115 Mdot
.37104 .32618 Mdot
.53032 .34053 Mdot
.52525 .71424 Mdot
.44979 .22943 Mdot
.36649 .6505 Mdot
.27821 .46342 Mdot
.34151 .77571 Mdot
.36202 .65831 Mdot
.54089 .39056 Mdot
.74562 .53088 Mdot
.2695 .48249 Mdot
.62969 .51895 Mdot
.67008 .40745 Mdot
.61625 .56814 Mdot
.70594 .55787 Mdot
.60669 .55645 Mdot
.29147 .6508 Mdot
.54594 .68078 Mdot
.28855 .49041 Mdot
.36677 .64457 Mdot
.36321 .64881 Mdot
.57617 .66434 Mdot
.37446 .30875 Mdot
.20078 .48217 Mdot
.34437 .22154 Mdot
.48881 .68718 Mdot
.7389 .52463 Mdot
.64211 .32648 Mdot
.53285 .67991 Mdot
.58306 .67274 Mdot
.39058 .60393 Mdot
.31586 .58775 Mdot
.28687 .4702 Mdot
.52594 .39918 Mdot
.36858 .27796 Mdot
.50408 .39857 Mdot
.59948 .45871 Mdot
.37049 .67256 Mdot
.27848 .46285 Mdot
.33157 .58635 Mdot
.53297 .3518 Mdot
.50342 .37623 Mdot
.55665 .77797 Mdot
.60799 .53242 Mdot
.62435 .78913 Mdot
.48802 .36671 Mdot
.53262 .69085 Mdot
.35729 .4246 Mdot
.62791 .53362 Mdot
.44988 .30857 Mdot
.36602 .63748 Mdot
.60111 .51845 Mdot
.62878 .53695 Mdot
.46806 .41692 Mdot
.29922 .53291 Mdot
.3091 .44575 Mdot
.7686 .53427 Mdot
.30786 .58933 Mdot
.3877 .64306 Mdot
.29157 .68345 Mdot
.5449 .3855 Mdot
.33006 .65695 Mdot
.6924 .51986 Mdot
.50274 .39047 Mdot
.45771 .25162 Mdot
.37666 .3285 Mdot
.55532 .37674 Mdot
.46934 .24129 Mdot
.36423 .6619 Mdot
.72843 .49747 Mdot
.5316 .33852 Mdot
.55429 .66984 Mdot
.28358 .46919 Mdot
.28182 .52869 Mdot
.70536 .54325 Mdot
.34003 .58913 Mdot
.75002 .2486 Mdot
.27869 .46357 Mdot
.51757 .38803 Mdot
.3658 .65198 Mdot
.61437 .51328 Mdot
.62111 .52668 Mdot
.59868 .56415 Mdot
.29801 .46732 Mdot
.62693 .53443 Mdot
.32859 .40567 Mdot
.64336 .38662 Mdot
.44277 .40515 Mdot
.34865 .67059 Mdot
.74085 .52618 Mdot
.66982 .54591 Mdot
.4976 .73408 Mdot
.49837 .32624 Mdot
.60031 .45893 Mdot
.35503 .48665 Mdot
.74561 .52736 Mdot
.50851 .36644 Mdot
.59477 .55493 Mdot
.6189 .27502 Mdot
.75137 .51049 Mdot
.60356 .556 Mdot
.44669 .26487 Mdot
.29136 .45015 Mdot
.60067 .52669 Mdot
.30362 .47238 Mdot
.50772 .36354 Mdot
.58406 .42795 Mdot
.29025 .44787 Mdot
.18365 .54917 Mdot
.5807 .52524 Mdot
.40099 .6614 Mdot
.52421 .42436 Mdot
.51662 .34932 Mdot
.47006 .31686 Mdot
.61288 .51453 Mdot
.20031 .58808 Mdot
.55944 .67748 Mdot
.6101 .80257 Mdot
.48623 .70745 Mdot
.38704 .60333 Mdot
.29471 .7081 Mdot
.52919 .34669 Mdot
.37497 .30746 Mdot
.47205 .31861 Mdot
.37461 .684 Mdot
.47004 .31012 Mdot
.515 .36314 Mdot
.49789 .35232 Mdot
.55545 .67489 Mdot
.36474 .63098 Mdot
.45606 .28097 Mdot
.62839 .39526 Mdot
.68989 .53715 Mdot
.3186 .48081 Mdot
.51748 .3729 Mdot
.32686 .50505 Mdot
.53016 .70817 Mdot
.20967 .46191 Mdot
.53347 .36991 Mdot
.60767 .53283 Mdot
.33133 .65875 Mdot
.34355 .6424 Mdot
.5213 .70423 Mdot
.51775 .70354 Mdot
.51668 .3496 Mdot
.37663 .67668 Mdot
.50562 .32577 Mdot
.61974 .40533 Mdot
.62072 .54192 Mdot
.72621 .54603 Mdot
.52255 .41449 Mdot
.20319 .47857 Mdot
.81662 .51039 Mdot
.50437 .35221 Mdot
.32719 .44961 Mdot
.54499 .67494 Mdot
.56449 .65348 Mdot
.29779 .45256 Mdot
.56616 .6543 Mdot
.20516 .46862 Mdot
.42854 .23117 Mdot
.74033 .54927 Mdot
.46556 .22184 Mdot
.75636 .52559 Mdot
.604 .51708 Mdot
.53474 .39269 Mdot
.39067 .72615 Mdot
.48769 .68863 Mdot
.55681 .25663 Mdot
.37409 .66657 Mdot
.63573 .54316 Mdot
.46242 .2641 Mdot
.70113 .5487 Mdot
.53033 .66748 Mdot
.59953 .50848 Mdot
.48858 .36055 Mdot
.324 .44159 Mdot
.44221 .2538 Mdot
.63122 .5448 Mdot
.60911 .51718 Mdot
.60105 .50914 Mdot
.39972 .66584 Mdot
.31818 .49374 Mdot
.35919 .59282 Mdot
.57066 .6875 Mdot
.48274 .34341 Mdot
.51532 .38519 Mdot
.27243 .46622 Mdot
.52234 .41103 Mdot
.36723 .68093 Mdot
.32904 .22497 Mdot
.73051 .52165 Mdot
.62368 .51692 Mdot
.23388 .55975 Mdot
.6145 .50771 Mdot
.45458 .27434 Mdot
.48181 .29124 Mdot
.27571 .44706 Mdot
.39913 .67519 Mdot
.50155 .31765 Mdot
.56388 .70254 Mdot
.72871 .53558 Mdot
.33294 .65051 Mdot
.45102 .25518 Mdot
.53843 .37345 Mdot
.74299 .5275 Mdot
.32931 .58698 Mdot
.68677 .53164 Mdot
.37079 .64403 Mdot
.6357 .5543 Mdot
.58943 .30964 Mdot
.53062 .37937 Mdot
.60218 .53489 Mdot
.32294 .4873 Mdot
.38651 .65214 Mdot
.37911 .3422 Mdot
.63008 .53537 Mdot
.51695 .75466 Mdot
.34916 .63916 Mdot
.50586 .34346 Mdot
.35746 .46931 Mdot
.25465 .50931 Mdot
.30827 .4944 Mdot
.75402 .69332 Mdot
.53118 .76617 Mdot
.54784 .67726 Mdot
.35761 .66123 Mdot
.56434 .66856 Mdot
.70825 .54902 Mdot
.64538 .34311 Mdot
.51374 .70387 Mdot
.33431 .48909 Mdot
.56554 .67915 Mdot
.5018 .32407 Mdot
.4024 .66414 Mdot
.50329 .70461 Mdot
.53633 .41068 Mdot
.4744 .2629 Mdot
.60923 .51968 Mdot
.74819 .51393 Mdot
.63681 .39215 Mdot
.53691 .4006 Mdot
.60375 .53981 Mdot
.53484 .37788 Mdot
.36837 .68063 Mdot
.60549 .43396 Mdot
.48305 .32621 Mdot
.48944 .68758 Mdot
.18642 .50732 Mdot
.54439 .70986 Mdot
.67248 .56547 Mdot
.49789 .38377 Mdot
.53246 .38282 Mdot
.4557 .25966 Mdot
.37491 .20916 Mdot
.34424 .68024 Mdot
.48373 .37662 Mdot
.56311 .65004 Mdot
.29621 .47883 Mdot
.33499 .44843 Mdot
.54987 .44907 Mdot
.59958 .53555 Mdot
.34367 .67346 Mdot
.53281 .38754 Mdot
.63485 .53594 Mdot
.63605 .36764 Mdot
.30579 .59747 Mdot
.54443 .77528 Mdot
.57965 .6787 Mdot
.29517 .44203 Mdot
.5404 .65344 Mdot
.45536 .26208 Mdot
.62652 .52972 Mdot
.5293 .76593 Mdot
.42669 .63865 Mdot
.7303 .53681 Mdot
.49426 .35944 Mdot
.71715 .43218 Mdot
.53538 .65384 Mdot
.51907 .69362 Mdot
.50408 .32471 Mdot
.36689 .43996 Mdot
.80877 .51604 Mdot
.39166 .6662 Mdot
.24804 .48137 Mdot
.40756 .29519 Mdot
.78007 .37888 Mdot
.35242 .65385 Mdot
.45664 .24944 Mdot
.52008 .65978 Mdot
.65887 .74546 Mdot
.29833 .48275 Mdot
.72776 .53612 Mdot
.5321 .41314 Mdot
.33881 .47337 Mdot
.489 .68549 Mdot
.31143 .49764 Mdot
.612 .52848 Mdot
.40208 .66753 Mdot
.52857 .66444 Mdot
.37765 .63525 Mdot
.3339 .4118 Mdot
.73646 .52278 Mdot
.673 .46356 Mdot
.46111 .23966 Mdot
.37597 .32679 Mdot
.46881 .26481 Mdot
.6369 .57104 Mdot
.47241 .26419 Mdot
.27157 .52278 Mdot
.53856 .37974 Mdot
.52802 .33373 Mdot
.54967 .64672 Mdot
.50401 .34903 Mdot
.54483 .39263 Mdot
.45325 .31214 Mdot
.49437 .36768 Mdot
.51004 .3548 Mdot
.51078 .34179 Mdot
.32052 .45106 Mdot
.48913 .34257 Mdot
.27585 .48498 Mdot
.3193 .50458 Mdot
.57197 .68606 Mdot
.74833 .55471 Mdot
.7611 .54485 Mdot
.58645 .42501 Mdot
.7162 .43299 Mdot
.36814 .27426 Mdot
.30026 .47803 Mdot
.34725 .6413 Mdot
.48679 .3262 Mdot
.80329 .52643 Mdot
.58444 .42613 Mdot
.5121 .67882 Mdot
.52616 .71017 Mdot
.53857 .41082 Mdot
.76181 .2784 Mdot
.48738 .36568 Mdot
.64815 .36865 Mdot
.52187 .38308 Mdot
.49823 .34257 Mdot
.54867 .7115 Mdot
.69797 .45479 Mdot
.47717 .27438 Mdot
.311 .53116 Mdot
.7309 .53951 Mdot
.60219 .52763 Mdot
.58527 .42746 Mdot
.41413 .27949 Mdot
.36262 .50536 Mdot
.45501 .25872 Mdot
.51816 .67451 Mdot
.30102 .45852 Mdot
.64629 .37666 Mdot
.38641 .67022 Mdot
.67179 .40961 Mdot
.24188 .42927 Mdot
.39163 .66992 Mdot
.73053 .53438 Mdot
.50576 .67829 Mdot
.50345 .36652 Mdot
.54295 .69445 Mdot
.52991 .3497 Mdot
.65191 .36093 Mdot
.7326 .5484 Mdot
.33851 .48588 Mdot
.37463 .6403 Mdot
.32434 .45492 Mdot
.21241 .46269 Mdot
.58369 .44512 Mdot
.58962 .79666 Mdot
.52347 .71595 Mdot
.66707 .56274 Mdot
.27862 .47771 Mdot
.55005 .38378 Mdot
.343 .23407 Mdot
.32334 .47139 Mdot
.32042 .4408 Mdot
.66138 .41454 Mdot
.72001 .45041 Mdot
.51461 .34318 Mdot
.33743 .47698 Mdot
.50471 .67922 Mdot
.74644 .54953 Mdot
.54623 .38866 Mdot
.62546 .52488 Mdot
.32904 .4452 Mdot
.54406 .65625 Mdot
.68973 .45795 Mdot
.5277 .68771 Mdot
.28913 .47694 Mdot
.53803 .70911 Mdot
.31952 .65887 Mdot
.51299 .70406 Mdot
.5189 .413 Mdot
.53246 .38564 Mdot
.24914 .50089 Mdot
.30192 .46174 Mdot
.455 .27472 Mdot
.51469 .40696 Mdot
.2849 .48713 Mdot
.51232 .65726 Mdot
.36195 .50343 Mdot
.45329 .26819 Mdot
.5302 .3967 Mdot
.75398 .52168 Mdot
.60942 .41417 Mdot
.64725 .41642 Mdot
.48617 .33054 Mdot
.73528 .52492 Mdot
.31965 .43978 Mdot
.5366 .38915 Mdot
.70886 .45339 Mdot
.5498 .64507 Mdot
.55143 .35611 Mdot
.6162 .51278 Mdot
.47208 .27968 Mdot
.70528 .39488 Mdot
.45224 .25447 Mdot
.29814 .48775 Mdot
.28655 .48001 Mdot
.53654 .64663 Mdot
.31231 .48827 Mdot
.61941 .51527 Mdot
.34219 .66799 Mdot
.23413 .43781 Mdot
.63805 .54028 Mdot
.5862 .53202 Mdot
.58137 .53025 Mdot
.61537 .55811 Mdot
.79472 .53792 Mdot
.54031 .77036 Mdot
.59109 .52575 Mdot
.28293 .48954 Mdot
.53528 .55758 Mdot
.63641 .56457 Mdot
.3441 .67443 Mdot
.62828 .53715 Mdot
.55138 .35618 Mdot
.45539 .25569 Mdot
.26528 .46528 Mdot
.38479 .67324 Mdot
.61254 .57601 Mdot
.54623 .3905 Mdot
.2705 .45008 Mdot
.51649 .37011 Mdot
.70416 .52317 Mdot
.30848 .47006 Mdot
.5208 .67946 Mdot
.72507 .54691 Mdot
.61769 .55268 Mdot
.71437 .5286 Mdot
.55098 .68634 Mdot
.34013 .65216 Mdot
.53363 .41029 Mdot
.70613 .51637 Mdot
.74708 .5546 Mdot
.55523 .38727 Mdot
.28287 .4745 Mdot
.58191 .55531 Mdot
.53395 .39889 Mdot
.46097 .26063 Mdot
.30017 .45066 Mdot
.19451 .59286 Mdot
.50132 .36606 Mdot
.47342 .28889 Mdot
.29024 .52883 Mdot
.63381 .54211 Mdot
.52114 .6849 Mdot
.51553 .34645 Mdot
.37878 .66452 Mdot
.36887 .67556 Mdot
.48733 .69186 Mdot
.31431 .44383 Mdot
.54685 .65388 Mdot
.55234 .39536 Mdot
.62784 .54218 Mdot
.53386 .36062 Mdot
.56274 .78073 Mdot
.18329 .56733 Mdot
.27335 .4866 Mdot
.57031 .69019 Mdot
.63311 .36363 Mdot
.38234 .68705 Mdot
.5075 .65864 Mdot
.29996 .5318 Mdot
.33558 .46583 Mdot
.29549 .45317 Mdot
.7605 .5432 Mdot
.52552 .68007 Mdot
.27317 .45705 Mdot
.27098 .4612 Mdot
.4528 .26288 Mdot
.54086 .40683 Mdot
.30433 .44076 Mdot
.49622 .73397 Mdot
.73714 .53852 Mdot
.57523 .65581 Mdot
.81308 .51736 Mdot
.3916 .65891 Mdot
.44968 .30739 Mdot
.49781 .32476 Mdot
.7392 .23095 Mdot
.48874 .37091 Mdot
.51855 .38275 Mdot
.25429 .46465 Mdot
.68579 .53792 Mdot
.75358 .54251 Mdot
.27962 .47815 Mdot
.27448 .48884 Mdot
.70753 .53792 Mdot
.58686 .34977 Mdot
.71161 .41123 Mdot
.63111 .37881 Mdot
.32189 .4935 Mdot
.24358 .4316 Mdot
.36457 .66985 Mdot
.34168 .45944 Mdot
.31335 .66511 Mdot
.50855 .71135 Mdot
.51042 .70442 Mdot
.36327 .6384 Mdot
.50384 .36937 Mdot
.54182 .7144 Mdot
.47463 .27258 Mdot
.31106 .67894 Mdot
.45993 .24509 Mdot
.6989 .77447 Mdot
.52317 .41223 Mdot
.48401 .62352 Mdot
.29368 .63526 Mdot
.46113 .27998 Mdot
.42313 .23129 Mdot
.7223 .53196 Mdot
.2799 .52846 Mdot
.36576 .68251 Mdot
.36864 .27995 Mdot
.53147 .38072 Mdot
.33521 .48379 Mdot
.38401 .64503 Mdot
.19171 .58046 Mdot
.47963 .27281 Mdot
.46153 .27298 Mdot
.34053 .23564 Mdot
.31706 .50203 Mdot
.52241 .68586 Mdot
.24671 .48567 Mdot
.26308 .47489 Mdot
.47144 .25464 Mdot
.50227 .67706 Mdot
.61318 .2734 Mdot
.3303 .48974 Mdot
.68391 .5298 Mdot
.31493 .47879 Mdot
.71159 .53932 Mdot
.27535 .45437 Mdot
.57239 .68187 Mdot
.49753 .36456 Mdot
.57381 .68247 Mdot
.71699 .51832 Mdot
.54974 .706 Mdot
.37333 .68142 Mdot
.60878 .54723 Mdot
.35853 .67549 Mdot
.64494 .3366 Mdot
.3814 .35233 Mdot
.34356 .65978 Mdot
.53221 .43801 Mdot
.53976 .37487 Mdot
.2764 .45362 Mdot
.52122 .67187 Mdot
.57977 .65411 Mdot
.63479 .39462 Mdot
.28576 .46196 Mdot
.5614 .65559 Mdot
.47822 .24642 Mdot
.34573 .73573 Mdot
.47437 .28552 Mdot
.35309 .78722 Mdot
.29364 .4901 Mdot
.57484 .65174 Mdot
.64705 .3722 Mdot
.27654 .49398 Mdot
.50552 .70355 Mdot
.35848 .64109 Mdot
.37855 .6642 Mdot
.50798 .4066 Mdot
.38668 .63918 Mdot
.51326 .67834 Mdot
.26707 .41385 Mdot
.28397 .45033 Mdot
.18093 .56005 Mdot
.72935 .52395 Mdot
.53552 .65622 Mdot
.62317 .53959 Mdot
.33008 .41093 Mdot
.5662 .67245 Mdot
.75216 .25279 Mdot
.82514 .63083 Mdot
.55469 .65501 Mdot
.30747 .4713 Mdot
.29564 .46502 Mdot
.44577 .2468 Mdot
.62952 .39704 Mdot
.53189 .6662 Mdot
.37918 .73092 Mdot
.61594 .32248 Mdot
.60554 .54664 Mdot
.57404 .79498 Mdot
.55187 .42281 Mdot
.46569 .26417 Mdot
.38464 .65195 Mdot
.503 .37696 Mdot
.28744 .4958 Mdot
.48781 .36697 Mdot
.36136 .67933 Mdot
.48851 .69676 Mdot
.5334 .38017 Mdot
.72874 .53459 Mdot
.38033 .65365 Mdot
.38263 .66391 Mdot
.55134 .70156 Mdot
.31307 .44362 Mdot
.36865 .28734 Mdot
.52462 .68301 Mdot
.47092 .26932 Mdot
.60751 .54048 Mdot
.50896 .34271 Mdot
.34472 .47322 Mdot
.33168 .52739 Mdot
.53226 .65687 Mdot
.5538 .38771 Mdot
.35651 .6556 Mdot
.54278 .64759 Mdot
.4526 .24847 Mdot
.50665 .6963 Mdot
.58558 .50184 Mdot
.54632 .71429 Mdot
.34275 .41339 Mdot
.58288 .54995 Mdot
.33574 .48513 Mdot
.59024 .53364 Mdot
.71324 .7156 Mdot
.73297 .53533 Mdot
.54302 .71264 Mdot
.18542 .55482 Mdot
.57452 .68492 Mdot
.49509 .3716 Mdot
.54212 .38785 Mdot
.55681 .68158 Mdot
.73897 .52279 Mdot
.66037 .54054 Mdot
.70079 .5224 Mdot
.30461 .46725 Mdot
.48134 .26588 Mdot
.80218 .67194 Mdot
.58834 .65786 Mdot
.37979 .6396 Mdot
.36894 .49569 Mdot
.5862 .53679 Mdot
.37918 .67883 Mdot
.38399 .66011 Mdot
.71567 .52241 Mdot
.58235 .67486 Mdot
.34446 .4555 Mdot
.4002 .65044 Mdot
.2792 .49449 Mdot
.70544 .45656 Mdot
.62525 .55185 Mdot
.64254 .57777 Mdot
.59566 .55565 Mdot
.64059 .38736 Mdot
.40679 .67016 Mdot
.52275 .36653 Mdot
.69249 .54755 Mdot
.37333 .64225 Mdot
.7448 .51568 Mdot
.45468 .24856 Mdot
.56466 .65726 Mdot
.35169 .26274 Mdot
.51433 .41181 Mdot
.51191 .40121 Mdot
.38645 .6502 Mdot
.41643 .24298 Mdot
.30531 .53308 Mdot
.29325 .44857 Mdot
.54537 .68058 Mdot
.65932 .41284 Mdot
.48758 .35396 Mdot
.5433 .39254 Mdot
.5564 .68708 Mdot
.59688 .53666 Mdot
.58092 .79675 Mdot
.5288 .39522 Mdot
.36225 .66462 Mdot
.45573 .25093 Mdot
.36416 .68582 Mdot
.49658 .3147 Mdot
.49723 .37522 Mdot
.46875 .27426 Mdot
.46974 .25949 Mdot
.35793 .67481 Mdot
.60583 .55707 Mdot
.60986 .50915 Mdot
.31463 .4938 Mdot
.53469 .41525 Mdot
.61436 .3224 Mdot
.53036 .38758 Mdot
.72328 .53154 Mdot
.65045 .41357 Mdot
.48983 .31794 Mdot
.50747 .41446 Mdot
.61742 .32103 Mdot
.51025 .36307 Mdot
.38929 .65203 Mdot
.29258 .46515 Mdot
.35794 .65349 Mdot
.40088 .6529 Mdot
.56654 .67999 Mdot
.75038 .51757 Mdot
.51317 .34858 Mdot
.69898 .54246 Mdot
.53603 .4243 Mdot
.59909 .58214 Mdot
.61522 .40494 Mdot
.64688 .36817 Mdot
.75083 .51163 Mdot
.54203 .37939 Mdot
.55002 .68258 Mdot
.58605 .67621 Mdot
.47194 .24967 Mdot
.53874 .41799 Mdot
.35991 .63212 Mdot
.34331 .65327 Mdot
.54998 .77862 Mdot
.57928 .61713 Mdot
.70258 .52414 Mdot
.66124 .52404 Mdot
.47263 .26139 Mdot
.49178 .35781 Mdot
.6039 .55363 Mdot
.55811 .66578 Mdot
.58995 .52967 Mdot
.54285 .77291 Mdot
.36762 .68405 Mdot
.36328 .64678 Mdot
.52225 .41285 Mdot
.80786 .32912 Mdot
.32751 .46939 Mdot
.29515 .464 Mdot
.34162 .66982 Mdot
.54449 .70997 Mdot
.61427 .52577 Mdot
.35434 .23984 Mdot
.34816 .51572 Mdot
.71457 .55141 Mdot
.52776 .3544 Mdot
.51318 .71318 Mdot
.29465 .49502 Mdot
.70161 .52578 Mdot
.48138 .32647 Mdot
.5029 .67286 Mdot
.52348 .3736 Mdot
.48953 .27621 Mdot
.27515 .47186 Mdot
.61177 .40926 Mdot
.33573 .48777 Mdot
.36873 .67306 Mdot
.40759 .66673 Mdot
.49924 .38278 Mdot
.35614 .26088 Mdot
.36135 .43096 Mdot
.40681 .65903 Mdot
.76745 .53338 Mdot
.61483 .54551 Mdot
.74701 .51661 Mdot
.55299 .67303 Mdot
.73155 .53527 Mdot
.56684 .67396 Mdot
.52991 .64661 Mdot
.34118 .45271 Mdot
.74347 .52776 Mdot
.44028 .31497 Mdot
.62571 .52824 Mdot
.76475 .54541 Mdot
.48347 .3672 Mdot
.449 .26378 Mdot
.53871 .66206 Mdot
.69797 .54287 Mdot
.51484 .34523 Mdot
.23137 .56156 Mdot
.40272 .66079 Mdot
.37056 .68219 Mdot
.61207 .52756 Mdot
.51843 .66374 Mdot
.34547 .45494 Mdot
.63505 .35966 Mdot
.33129 .4076 Mdot
.54324 .39571 Mdot
.51072 .35025 Mdot
.33697 .40928 Mdot
.34524 .45429 Mdot
.49972 .38089 Mdot
.43325 .39618 Mdot
.62304 .54332 Mdot
.37611 .67108 Mdot
.30688 .46628 Mdot
.30829 .46027 Mdot
.51458 .69021 Mdot
.32161 .44274 Mdot
.69485 .557 Mdot
.37082 .68331 Mdot
.62295 .51195 Mdot
.35772 .65856 Mdot
.55783 .54941 Mdot
.5593 .65825 Mdot
.19274 .56982 Mdot
.30047 .44478 Mdot
.45578 .27003 Mdot
.31537 .44103 Mdot
.72545 .52291 Mdot
.336 .47716 Mdot
.34332 .46396 Mdot
.53916 .40739 Mdot
.60806 .55594 Mdot
.60237 .51958 Mdot
.63496 .39071 Mdot
.32605 .47113 Mdot
.50426 .3582 Mdot
.49048 .33281 Mdot
.51969 .40895 Mdot
.61895 .40335 Mdot
.31735 .4484 Mdot
.4144 .27794 Mdot
.28252 .44446 Mdot
.27588 .47693 Mdot
.82008 .50303 Mdot
.61882 .51654 Mdot
.58914 .54036 Mdot
.35773 .72499 Mdot
.52728 .39887 Mdot
.5679 .6559 Mdot
.46884 .26863 Mdot
.61586 .55094 Mdot
.48182 .33059 Mdot
.73417 .55286 Mdot
.53536 .3549 Mdot
.59972 .54436 Mdot
.52234 .67342 Mdot
.45563 .26863 Mdot
.53335 .39277 Mdot
.59802 .53065 Mdot
.33457 .44544 Mdot
.31417 .45417 Mdot
.39044 .43051 Mdot
.70807 .5307 Mdot
.35117 .66701 Mdot
.46649 .26721 Mdot
.54759 .6809 Mdot
.57487 .6604 Mdot
.33704 .48451 Mdot
.52985 .70394 Mdot
.36681 .64647 Mdot
.51854 .39026 Mdot
.36451 .67518 Mdot
.71746 .5487 Mdot
.3094 .46937 Mdot
.45826 .26331 Mdot
.44032 .24882 Mdot
.28647 .48005 Mdot
.62444 .54369 Mdot
.75523 .52112 Mdot
.54623 .69937 Mdot
.2708 .48085 Mdot
.35408 .67545 Mdot
.5159 .69704 Mdot
.46002 .27367 Mdot
.83599 .45717 Mdot
.50246 .37684 Mdot
.49996 .39303 Mdot
.34084 .41938 Mdot
.53103 .33399 Mdot
.56998 .68821 Mdot
.34688 .45353 Mdot
.45161 .26698 Mdot
.63955 .31512 Mdot
.77733 .52929 Mdot
.59162 .68456 Mdot
.51233 .36962 Mdot
.4703 .31784 Mdot
.52577 .33907 Mdot
.18273 .54349 Mdot
.61643 .40612 Mdot
.52098 .75509 Mdot
.65255 .57136 Mdot
.39176 .64418 Mdot
.60218 .54071 Mdot
.56745 .68227 Mdot
.4221 .38347 Mdot
.50318 .3827 Mdot
.37494 .33834 Mdot
.45065 .25255 Mdot
.35549 .65039 Mdot
.41867 .26253 Mdot
.51741 .67648 Mdot
.60441 .8037 Mdot
.54738 .40169 Mdot
.32288 .52964 Mdot
.44717 .65706 Mdot
.60459 .55171 Mdot
.59142 .54902 Mdot
.70328 .52524 Mdot
.49969 .66835 Mdot
.61748 .56948 Mdot
.35807 .65557 Mdot
.49074 .3538 Mdot
.47959 .314 Mdot
.20374 .59385 Mdot
.29399 .49281 Mdot
.39176 .64747 Mdot
.57647 .70818 Mdot
.52493 .36252 Mdot
.33227 .46112 Mdot
.29891 .48302 Mdot
.72943 .55342 Mdot
.50889 .74716 Mdot
.50507 .65976 Mdot
.77123 .29417 Mdot
.59125 .5653 Mdot
.55915 .66812 Mdot
.59083 .55704 Mdot
.46989 .27083 Mdot
.58428 .4278 Mdot
.39368 .64673 Mdot
.49538 .37717 Mdot
.37424 .32617 Mdot
.30584 .49226 Mdot
.5268 .3853 Mdot
.7377 .54168 Mdot
.36297 .21288 Mdot
.46654 .24087 Mdot
.43791 .39871 Mdot
.50457 .67912 Mdot
.50872 .35132 Mdot
.70076 .55776 Mdot
.63531 .53616 Mdot
.53238 .3345 Mdot
.52214 .68329 Mdot
.58249 .54865 Mdot
.74381 .54264 Mdot
.3128 .49555 Mdot
.60345 .53904 Mdot
.45082 .25026 Mdot
.52405 .34743 Mdot
.76746 .53057 Mdot
.46582 .27302 Mdot
.22781 .44527 Mdot
.60876 .5644 Mdot
.51397 .70755 Mdot
.26791 .47901 Mdot
.50478 .35291 Mdot
.61514 .54642 Mdot
.531 .35911 Mdot
.20277 .47739 Mdot
.49257 .36871 Mdot
.2185 .57444 Mdot
.2836 .46789 Mdot
.37242 .65815 Mdot
.45631 .25879 Mdot
.52591 .37451 Mdot
.58715 .55548 Mdot
.61523 .5237 Mdot
.54856 .38693 Mdot
.33583 .48575 Mdot
.32743 .48532 Mdot
.33609 .5244 Mdot
.51196 .69373 Mdot
.62622 .38591 Mdot
.37198 .66431 Mdot
.60241 .55351 Mdot
.39844 .64923 Mdot
.47334 .31752 Mdot
.71032 .53122 Mdot
.20703 .58863 Mdot
.51409 .39181 Mdot
.28824 .4593 Mdot
.71098 .41455 Mdot
.33781 .46645 Mdot
.3542 .7239 Mdot
.38719 .64282 Mdot
.3186 .4703 Mdot
.51116 .37135 Mdot
.64447 .38357 Mdot
.46657 .30946 Mdot
.39754 .67903 Mdot
.61877 .51138 Mdot
.56786 .54889 Mdot
.50165 .6964 Mdot
.8198 .50894 Mdot
.33844 .64419 Mdot
.29291 .63385 Mdot
.45336 .26839 Mdot
.286 .45277 Mdot
.34889 .67025 Mdot
.3831 .66722 Mdot
.51754 .67059 Mdot
.45349 .26434 Mdot
.52614 .37727 Mdot
.6125 .51236 Mdot
.3393 .64908 Mdot
.5469 .36677 Mdot
.46114 .28106 Mdot
.56237 .78664 Mdot
.30081 .53366 Mdot
.19119 .59159 Mdot
.47652 .32 Mdot
.37537 .32343 Mdot
.4331 .69253 Mdot
.27851 .45293 Mdot
.50799 .35732 Mdot
.61975 .53465 Mdot
.53158 .70605 Mdot
.51267 .38487 Mdot
.57184 .68947 Mdot
.34953 .65727 Mdot
.22607 .56906 Mdot
.47761 .31589 Mdot
.31134 .68252 Mdot
.49834 .36852 Mdot
.45315 .2389 Mdot
.74577 .535 Mdot
.35932 .68246 Mdot
.33617 .52177 Mdot
.50733 .34549 Mdot
.52022 .69181 Mdot
.50155 .70009 Mdot
.31314 .49159 Mdot
.38537 .45948 Mdot
.18889 .56359 Mdot
.62418 .53558 Mdot
.5325 .69934 Mdot
.61767 .54582 Mdot
.44282 .40375 Mdot
.40027 .65028 Mdot
.74481 .54295 Mdot
.53695 .70872 Mdot
.33485 .66296 Mdot
.44906 .26442 Mdot
.32272 .48032 Mdot
.3228 .40882 Mdot
.47756 .2627 Mdot
.56235 .65555 Mdot
.71806 .53999 Mdot
.55759 .43235 Mdot
.47952 .26219 Mdot
.72743 .54579 Mdot
.51247 .68466 Mdot
.32384 .46139 Mdot
.29268 .48115 Mdot
.29156 .46694 Mdot
.44933 .30783 Mdot
.33529 .52611 Mdot
.65245 .46652 Mdot
.53326 .33698 Mdot
.28307 .40726 Mdot
.54454 .35143 Mdot
.36889 .68218 Mdot
.27653 .4668 Mdot
.61543 .40617 Mdot
.47693 .27943 Mdot
.45807 .29963 Mdot
.52921 .40687 Mdot
.4677 .2539 Mdot
.52789 .39896 Mdot
.28946 .40725 Mdot
.30506 .53486 Mdot
.51282 .41853 Mdot
.38559 .6811 Mdot
.71803 .52897 Mdot
.26392 .48151 Mdot
.5152 .35209 Mdot
.25778 .42221 Mdot
.4828 .36187 Mdot
.22289 .56887 Mdot
.46589 .25062 Mdot
.49113 .71827 Mdot
.49398 .34715 Mdot
.51826 .71753 Mdot
.44255 .24299 Mdot
.23632 .43684 Mdot
.40191 .66365 Mdot
.46311 .23904 Mdot
.51048 .719 Mdot
.41891 .26617 Mdot
.62211 .52963 Mdot
.74012 .53778 Mdot
.58179 .54147 Mdot
.36152 .67786 Mdot
.50885 .38961 Mdot
.53114 .35272 Mdot
.51542 .32395 Mdot
.4446 .40543 Mdot
.62206 .51988 Mdot
.75048 .5111 Mdot
.24263 .43094 Mdot
.54465 .37131 Mdot
.55743 .70827 Mdot
.30599 .44956 Mdot
.43092 .2993 Mdot
.43237 .31993 Mdot
.45299 .27585 Mdot
.32337 .47279 Mdot
.31456 .44372 Mdot
.80567 .52226 Mdot
.73617 .52963 Mdot
.50626 .39721 Mdot
.6957 .52101 Mdot
.46362 .26696 Mdot
.35522 .66506 Mdot
.52 .32903 Mdot
.55941 .65768 Mdot
.64961 .37839 Mdot
.51134 .68787 Mdot
.52378 .40954 Mdot
.31285 .47894 Mdot
.39425 .68067 Mdot
.53981 .64318 Mdot
.50265 .74301 Mdot
.66293 .46692 Mdot
.50822 .65629 Mdot
.70314 .53177 Mdot
.71823 .52265 Mdot
.36076 .68262 Mdot
.51558 .37951 Mdot
.62278 .40225 Mdot
.44737 .21116 Mdot
.52065 .39866 Mdot
.50506 .37158 Mdot
.41983 .66824 Mdot
.35384 .63852 Mdot
.53615 .71037 Mdot
.50083 .38215 Mdot
.53833 .35719 Mdot
.31413 .47484 Mdot
.68869 .53577 Mdot
.55976 .68879 Mdot
.70549 .52318 Mdot
.53951 .6913 Mdot
.70611 .39521 Mdot
.62666 .5487 Mdot
.71143 .52736 Mdot
.34191 .64125 Mdot
.29235 .45735 Mdot
.62026 .51661 Mdot
.54365 .67036 Mdot
.52994 .70134 Mdot
.53746 .42354 Mdot
.30016 .49577 Mdot
.29339 .44834 Mdot
.70669 .53361 Mdot
.34205 .65653 Mdot
.47553 .27181 Mdot
.595 .55481 Mdot
.59263 .71061 Mdot
.52264 .69792 Mdot
.2456 .42699 Mdot
.3367 .41523 Mdot
.52502 .35798 Mdot
.31583 .45506 Mdot
.53104 .37261 Mdot
.25109 .47053 Mdot
.30185 .50289 Mdot
.49283 .31321 Mdot
.3907 .41059 Mdot
.56039 .66605 Mdot
.76742 .71346 Mdot
.47342 .28709 Mdot
.32701 .66147 Mdot
.46782 .26938 Mdot
.58852 .79979 Mdot
.71269 .41723 Mdot
.54468 .37563 Mdot
.51231 .35097 Mdot
.81308 .34989 Mdot
.50178 .33644 Mdot
.59131 .53641 Mdot
.62244 .52875 Mdot
.32233 .45713 Mdot
.58193 .53714 Mdot
.63789 .39009 Mdot
.74653 .52535 Mdot
.54596 .67966 Mdot
.70991 .45136 Mdot
.71181 .53771 Mdot
.29863 .48939 Mdot
.47565 .2752 Mdot
.35868 .42223 Mdot
.56835 .70109 Mdot
.60292 .53197 Mdot
.35164 .65447 Mdot
.63141 .4 Mdot
.51737 .68405 Mdot
.33591 .65743 Mdot
.49558 .33213 Mdot
.54815 .77306 Mdot
.38109 .68203 Mdot
.78359 .69354 Mdot
.38934 .66326 Mdot
.34193 .66831 Mdot
.62604 .3946 Mdot
.74711 .52539 Mdot
.58613 .5562 Mdot
.60928 .58288 Mdot
.3983 .66972 Mdot
.63782 .79559 Mdot
.5184 .66511 Mdot
.65124 .35835 Mdot
.2813 .52937 Mdot
.62881 .53423 Mdot
.5003 .36834 Mdot
.38714 .65377 Mdot
.52959 .42263 Mdot
.58442 .55242 Mdot
.37304 .65082 Mdot
.44217 .24392 Mdot
.65866 .41003 Mdot
.61739 .54154 Mdot
.60356 .51764 Mdot
.69359 .53555 Mdot
.48824 .71345 Mdot
.30002 .4468 Mdot
.75212 .55378 Mdot
.63226 .34475 Mdot
.5129 .40506 Mdot
.35699 .67434 Mdot
.6033 .53819 Mdot
.37489 .66561 Mdot
.75171 .53824 Mdot
.76893 .53231 Mdot
.30937 .49485 Mdot
.32986 .52689 Mdot
.64043 .53983 Mdot
.60794 .31443 Mdot
.52952 .33814 Mdot
.37695 .34634 Mdot
.32866 .44962 Mdot
.42542 .23097 Mdot
.75983 .53183 Mdot
.69153 .53934 Mdot
.44922 .23902 Mdot
.4846 .3389 Mdot
.46356 .25294 Mdot
.48636 .32209 Mdot
.6274 .77799 Mdot
.45592 .26157 Mdot
.54404 .69968 Mdot
.4836 .32232 Mdot
.30256 .59498 Mdot
.4656 .24369 Mdot
.52022 .35251 Mdot
.53155 .68332 Mdot
.55676 .37681 Mdot
.54593 .65829 Mdot
.49966 .35821 Mdot
.56806 .78385 Mdot
.54716 .68111 Mdot
.65054 .52263 Mdot
.56909 .44185 Mdot
.59273 .5304 Mdot
.75798 .54169 Mdot
.70926 .51554 Mdot
.6877 .45907 Mdot
.32228 .46332 Mdot
.37979 .20868 Mdot
.52062 .35353 Mdot
.51606 .67081 Mdot
.3486 .65571 Mdot
.44145 .25565 Mdot
.5038 .39964 Mdot
.47625 .26627 Mdot
.32682 .47891 Mdot
.51737 .66333 Mdot
.75317 .53301 Mdot
.58014 .68284 Mdot
.56641 .79046 Mdot
.55787 .65938 Mdot
.46505 .41518 Mdot
.44581 .25622 Mdot
.6983 .5573 Mdot
.38551 .37162 Mdot
.67481 .52976 Mdot
.32009 .48714 Mdot
.60412 .54162 Mdot
.72807 .51631 Mdot
.61493 .42958 Mdot
.30144 .44868 Mdot
.55585 .6873 Mdot
.52336 .37273 Mdot
.6117 .55977 Mdot
.60816 .58303 Mdot
.28778 .49684 Mdot
.76639 .52577 Mdot
.54022 .67588 Mdot
.61166 .543 Mdot
.62909 .37933 Mdot
.40755 .2934 Mdot
.64814 .34071 Mdot
.5273 .37223 Mdot
.70805 .53754 Mdot
.2994 .4958 Mdot
.47678 .26513 Mdot
.37237 .64301 Mdot
.63169 .39561 Mdot
.50052 .37202 Mdot
.31379 .6979 Mdot
.31308 .48028 Mdot
.73327 .52394 Mdot
.38927 .65744 Mdot
.73416 .53045 Mdot
.58986 .54109 Mdot
.25719 .46101 Mdot
.59169 .54917 Mdot
.45173 .25233 Mdot
.34905 .66132 Mdot
.29604 .44821 Mdot
.56631 .78845 Mdot
.5817 .55399 Mdot
.55654 .68001 Mdot
.61767 .4276 Mdot
.32376 .48969 Mdot
.35222 .59199 Mdot
.5795 .68369 Mdot
.42476 .63918 Mdot
.60745 .41502 Mdot
.37484 .64895 Mdot
.51845 .35219 Mdot
.29664 .4729 Mdot
.39549 .68106 Mdot
.49439 .73105 Mdot
.46568 .31506 Mdot
.62646 .55888 Mdot
.54132 .38013 Mdot
.18017 .53329 Mdot
.29944 .61411 Mdot
.25108 .50609 Mdot
.33305 .64984 Mdot
.51834 .40338 Mdot
.62512 .53784 Mdot
.53608 .41495 Mdot
.39893 .66336 Mdot
.40187 .68525 Mdot
.57964 .66018 Mdot
.52183 .36807 Mdot
.72634 .5308 Mdot
.57138 .66725 Mdot
.49873 .69152 Mdot
.52812 .71144 Mdot
.33322 .52371 Mdot
.63084 .5396 Mdot
.6244 .53172 Mdot
.71548 .42245 Mdot
.37625 .66632 Mdot
.59258 .53137 Mdot
.53211 .35246 Mdot
.65335 .46589 Mdot
.28778 .46641 Mdot
.53566 .67461 Mdot
.515 .40314 Mdot
.47657 .28643 Mdot
.60144 .52694 Mdot
.52556 .68211 Mdot
.34215 .45275 Mdot
.54618 .5635 Mdot
.51329 .38726 Mdot
.45178 .25931 Mdot
.28916 .48612 Mdot
.20108 .48476 Mdot
.63669 .3694 Mdot
.53118 .37461 Mdot
.36918 .6758 Mdot
.21155 .50646 Mdot
.49677 .33532 Mdot
.39604 .43101 Mdot
.61821 .51259 Mdot
.52406 .53954 Mdot
.23609 .46567 Mdot
.49388 .28824 Mdot
.44496 .57696 Mdot
.56015 .25783 Mdot
.47335 .5984 Mdot
.65105 .76406 Mdot
.39967 .56881 Mdot
.7999 .67065 Mdot
.35507 .62739 Mdot
.4919 .27762 Mdot
.7412 .25439 Mdot
.29896 .63402 Mdot
.39086 .58691 Mdot
.32251 .63191 Mdot
.62347 .48344 Mdot
.57831 .79435 Mdot
.5482 .77452 Mdot
.65225 .75801 Mdot
.54969 .42251 Mdot
.30142 .55928 Mdot
.47139 .23444 Mdot
.33385 .59951 Mdot
.5211 .7517 Mdot
.48083 .26094 Mdot
.80249 .36337 Mdot
.33505 .72164 Mdot
.7939 .44681 Mdot
.37199 .26409 Mdot
.56576 .74928 Mdot
.592 .30902 Mdot
.72447 .47825 Mdot
.45601 .21457 Mdot
.4975 .56742 Mdot
.37283 .63183 Mdot
.32664 .43625 Mdot
.36477 .73266 Mdot
.54725 .69393 Mdot
.30719 .49923 Mdot
.30774 .72003 Mdot
.81641 .4162 Mdot
.35827 .61284 Mdot
.44393 .57789 Mdot
.60526 .56707 Mdot
.52833 .52857 Mdot
.61018 .40338 Mdot
.25089 .47817 Mdot
.56924 .762 Mdot
.58225 .78219 Mdot
.31975 .41999 Mdot
.51137 .73367 Mdot
.60323 .43661 Mdot
.38563 .58567 Mdot
.23094 .4709 Mdot
.64317 .49863 Mdot
.64321 .51399 Mdot
.33038 .45013 Mdot
.75879 .3215 Mdot
.51667 .45085 Mdot
.63215 .33532 Mdot
.5321 .74873 Mdot
.34487 .44168 Mdot
.36645 .28233 Mdot
.38323 .46275 Mdot
.72137 .75409 Mdot
.8274 .45019 Mdot
.68615 .75174 Mdot
.56369 .46124 Mdot
.37462 .62054 Mdot
.58517 .44888 Mdot
.49457 .6219 Mdot
.71071 .73937 Mdot
.20672 .48353 Mdot
.77129 .31313 Mdot
.48479 .49464 Mdot
.83565 .4301 Mdot
.27091 .43187 Mdot
.6383 .49813 Mdot
.24141 .49233 Mdot
.55157 .51676 Mdot
.68587 .40948 Mdot
.82669 .40431 Mdot
.35816 .57797 Mdot
.57283 .5323 Mdot
.30088 .63123 Mdot
.22955 .45449 Mdot
.56306 .77272 Mdot
.58774 .51266 Mdot
.40546 .35589 Mdot
.82436 .38263 Mdot
.45351 .57003 Mdot
.78773 .37795 Mdot
.57796 .75518 Mdot
.33695 .76503 Mdot
.49718 .68872 Mdot
.41133 .66659 Mdot
.80749 .44626 Mdot
.2973 .47679 Mdot
.74298 .73976 Mdot
.41333 .58948 Mdot
.45441 .64318 Mdot
.81806 .37403 Mdot
.69851 .76876 Mdot
.5544 .49872 Mdot
.65321 .51752 Mdot
.36898 .7298 Mdot
.49798 .59675 Mdot
.32383 .59168 Mdot
.56217 .56597 Mdot
.20428 .55531 Mdot
.80287 .43497 Mdot
.68156 .77234 Mdot
.75635 .28333 Mdot
.62829 .34388 Mdot
.67129 .48718 Mdot
.34174 .42217 Mdot
.42057 .5121 Mdot
.32498 .59578 Mdot
.83639 .43871 Mdot
.47079 .24004 Mdot
.20269 .50874 Mdot
.66183 .75558 Mdot
.42812 .30519 Mdot
.23962 .55228 Mdot
.30342 .68035 Mdot
.55464 .57034 Mdot
.24565 .44348 Mdot
.79215 .54281 Mdot
.68981 .42867 Mdot
.39634 .34121 Mdot
.49953 .72604 Mdot
.63825 .37594 Mdot
.39518 .45818 Mdot
.78516 .65888 Mdot
.2639 .55119 Mdot
.40385 .34895 Mdot
.32042 .40978 Mdot
.71181 .73673 Mdot
.6657 .75996 Mdot
.2184 .53025 Mdot
.58245 .71198 Mdot
.79335 .38669 Mdot
.37897 .51169 Mdot
.5395 .51377 Mdot
.47926 .24321 Mdot
.44954 .22622 Mdot
.598 .76067 Mdot
.47088 .4362 Mdot
.78926 .50717 Mdot
.30804 .65611 Mdot
.38592 .38141 Mdot
.74769 .48319 Mdot
.39133 .37665 Mdot
.23371 .4411 Mdot
.41693 .44826 Mdot
.33751 .72083 Mdot
.41712 .4254 Mdot
.80647 .36415 Mdot
.564 .6913 Mdot
.7085 .74428 Mdot
.35481 .61462 Mdot
.54862 .76727 Mdot
.44762 .64327 Mdot
.44637 .64604 Mdot
.79993 .46566 Mdot
.29652 .66826 Mdot
.60483 .48512 Mdot
.24873 .49489 Mdot
.44465 .60889 Mdot
.38245 .34328 Mdot
.47899 .40951 Mdot
.3346 .54137 Mdot
.75707 .52154 Mdot
.41634 .38944 Mdot
.24485 .44271 Mdot
.57609 .71074 Mdot
.46408 .40745 Mdot
.60066 .28372 Mdot
.63816 .52733 Mdot
.65528 .44672 Mdot
.70693 .39978 Mdot
.51565 .49972 Mdot
.7116 .75221 Mdot
.36411 .52663 Mdot
.66053 .44749 Mdot
.32399 .59952 Mdot
.38417 .20881 Mdot
.83697 .42871 Mdot
.81088 .50314 Mdot
.22444 .50868 Mdot
.21493 .54179 Mdot
.37645 .81 Mdot
.36359 .59522 Mdot
.80026 .64994 Mdot
.35514 .61482 Mdot
.32806 .22919 Mdot
.5657 .69277 Mdot
.57568 .47589 Mdot
.26213 .45181 Mdot
.59469 .28492 Mdot
.8135 .38843 Mdot
.51927 .51412 Mdot
.76172 .54874 Mdot
.2366 .49198 Mdot
.3979 .41393 Mdot
.79149 .35802 Mdot
.76929 .32395 Mdot
.76945 .33215 Mdot
.3045 .71461 Mdot
.4441 .41794 Mdot
.80839 .35479 Mdot
.61129 .46141 Mdot
.48398 .46313 Mdot
.48321 .2962 Mdot
.62679 .30936 Mdot
.78175 .68394 Mdot
.65312 .49015 Mdot
.50312 .59503 Mdot
.32032 .41947 Mdot
.82753 .37866 Mdot
.71911 .41102 Mdot
.53667 .53858 Mdot
.78271 .45198 Mdot
.74115 .50488 Mdot
.75304 .47898 Mdot
.79822 .47395 Mdot
.47351 .56753 Mdot
.30382 .6735 Mdot
.83537 .38171 Mdot
.69739 .73436 Mdot
.33971 .60548 Mdot
.24973 .43145 Mdot
.7717 .70115 Mdot
.2305 .55112 Mdot
.41577 .64705 Mdot
.26859 .43707 Mdot
.39268 .22254 Mdot
.37198 .55517 Mdot
.50329 .56921 Mdot
.52928 .32823 Mdot
.75588 .4923 Mdot
.55344 .70332 Mdot
.74792 .70577 Mdot
.36406 .54789 Mdot
.47376 .46017 Mdot
.67626 .44588 Mdot
.66402 .78426 Mdot
.49165 .53274 Mdot
.43872 .37494 Mdot
.36631 .52363 Mdot
.2482 .53809 Mdot
.24543 .55002 Mdot
.38567 .27479 Mdot
.53773 .34802 Mdot
.81967 .41277 Mdot
.81555 .64094 Mdot
.80504 .47677 Mdot
.23274 .53573 Mdot
.36167 .78507 Mdot
.33967 .632 Mdot
.62437 .45902 Mdot
.59781 .26562 Mdot
.45706 .54116 Mdot
.56778 .24999 Mdot
.37247 .69084 Mdot
.36616 .28274 Mdot
.44224 .63228 Mdot
.61174 .46052 Mdot
.2891 .54138 Mdot
.45437 .62876 Mdot
.43595 .3869 Mdot
.29648 .41295 Mdot
.18907 .51378 Mdot
.71486 .73302 Mdot
.55972 .69492 Mdot
.59101 .702 Mdot
.47673 .44722 Mdot
.69042 .54705 Mdot
.568 .52535 Mdot
.54384 .50541 Mdot
.37772 .31461 Mdot
.37711 .79587 Mdot
.78559 .48721 Mdot
.76574 .71382 Mdot
.79922 .47635 Mdot
.67817 .75739 Mdot
.52373 .73968 Mdot
.66286 .43348 Mdot
.38793 .61499 Mdot
.36359 .62169 Mdot
.65531 .4271 Mdot
.66508 .77389 Mdot
.53864 .52766 Mdot
.25164 .50051 Mdot
.53274 .34737 Mdot
.70721 .41121 Mdot
.71453 .47852 Mdot
.64125 .44345 Mdot
.39597 .28635 Mdot
.35158 .4654 Mdot
.64381 .47605 Mdot
.52704 .56775 Mdot
.4381 .25316 Mdot
.21205 .53803 Mdot
.39395 .68291 Mdot
.2664 .42214 Mdot
.66381 .78601 Mdot
.37941 .80562 Mdot
.46711 .6136 Mdot
.52846 .4411 Mdot
.79823 .4273 Mdot
.56301 .45031 Mdot
.21361 .54901 Mdot
.39984 .22393 Mdot
.43989 .65013 Mdot
.3055 .42052 Mdot
.50423 .48121 Mdot
.45791 .66099 Mdot
.27475 .54353 Mdot
.2742 .42124 Mdot
.44435 .23014 Mdot
.81984 .45478 Mdot
.5633 .37447 Mdot
.4871 .57482 Mdot
.63685 .35839 Mdot
.40517 .52173 Mdot
.42611 .59561 Mdot
.68541 .45177 Mdot
.46294 .59248 Mdot
.76267 .3337 Mdot
.36465 .29694 Mdot
.51646 .59343 Mdot
.61179 .46892 Mdot
.60817 .45949 Mdot
.37217 .26555 Mdot
.22489 .46175 Mdot
.30951 .65164 Mdot
.56292 .40543 Mdot
.82592 .46655 Mdot
.46963 .48703 Mdot
.66924 .44504 Mdot
.39537 .47938 Mdot
.56151 .38893 Mdot
.57904 .50624 Mdot
.79786 .47035 Mdot
.52455 .5442 Mdot
.73642 .24362 Mdot
.64582 .77701 Mdot
.35999 .51563 Mdot
.24411 .47681 Mdot
.72371 .73289 Mdot
.32703 .56161 Mdot
.41068 .57523 Mdot
.37457 .53256 Mdot
.75923 .70886 Mdot
.51503 .53705 Mdot
.52816 .55363 Mdot
.18873 .5249 Mdot
.79598 .34372 Mdot
.49263 .5901 Mdot
.41303 .64745 Mdot
.67051 .49282 Mdot
.49381 .38084 Mdot
.38412 .47546 Mdot
.19241 .57742 Mdot
.41728 .47748 Mdot
.48085 .60418 Mdot
.81067 .65766 Mdot
.52586 .51101 Mdot
.35838 .53547 Mdot
.74007 .24585 Mdot
.73985 .23754 Mdot
.38106 .47932 Mdot
.83672 .44536 Mdot
.53157 .55022 Mdot
.21894 .55183 Mdot
.37721 .63171 Mdot
.49925 .42297 Mdot
.37627 .34088 Mdot
.82083 .48137 Mdot
.34928 .79088 Mdot
.32025 .60142 Mdot
.27676 .43857 Mdot
.82455 .4888 Mdot
.47462 .4675 Mdot
.58591 .48135 Mdot
.34015 .76453 Mdot
.61072 .79987 Mdot
.72248 .74938 Mdot
.39195 .26714 Mdot
.59427 .77195 Mdot
.62751 .75405 Mdot
.35096 .57673 Mdot
.77645 .69909 Mdot
.59728 .57201 Mdot
.39143 .20651 Mdot
.70982 .73864 Mdot
.19363 .53888 Mdot
.57468 .77806 Mdot
.42821 .59398 Mdot
.53588 .50785 Mdot
.42574 .44917 Mdot
.20827 .55882 Mdot
.30088 .69058 Mdot
.52336 .47699 Mdot
.63325 .42311 Mdot
.23489 .44516 Mdot
.20124 .49665 Mdot
.41098 .21116 Mdot
.55218 .49203 Mdot
.74614 .29718 Mdot
.32195 .70048 Mdot
.61851 .43991 Mdot
.24932 .48922 Mdot
.70245 .46142 Mdot
.59968 .48316 Mdot
.48228 .33647 Mdot
.81875 .45087 Mdot
.59781 .48495 Mdot
.75567 .30831 Mdot
.73969 .74635 Mdot
.77913 .44359 Mdot
.48336 .63469 Mdot
.56293 .54253 Mdot
.78229 .67982 Mdot
.7914 .66297 Mdot
.752 .29284 Mdot
.65507 .75064 Mdot
.65313 .4256 Mdot
.53046 .48514 Mdot
.48265 .4103 Mdot
.44794 .40421 Mdot
.72787 .72835 Mdot
.36894 .2639 Mdot
.74324 .47772 Mdot
.23864 .52089 Mdot
.66557 .77789 Mdot
.57231 .45707 Mdot
.6939 .4615 Mdot
.40729 .48635 Mdot
.6356 .50325 Mdot
.53251 .65309 Mdot
.79964 .3246 Mdot
.21747 .53334 Mdot
.76713 .48082 Mdot
.2048 .51383 Mdot
.30614 .40675 Mdot
.63661 .76767 Mdot
.23138 .4845 Mdot
.63573 .58635 Mdot
.54844 .74861 Mdot
.79652 .53065 Mdot
.54656 .51942 Mdot
.18155 .54228 Mdot
.42226 .31955 Mdot
.80588 .46626 Mdot
.75061 .48441 Mdot
.7456 .27393 Mdot
.64907 .47963 Mdot
.41474 .38848 Mdot
.75336 .3162 Mdot
.23616 .52365 Mdot
.62989 .44414 Mdot
.79301 .35368 Mdot
.27986 .53059 Mdot
.82718 .44726 Mdot
.36329 .64229 Mdot
.60236 .47524 Mdot
.19311 .56312 Mdot
.62569 .4514 Mdot
.62107 .45036 Mdot
.78661 .49396 Mdot
.30308 .62364 Mdot
.3453 .54889 Mdot
.3764 .51622 Mdot
.55539 .7701 Mdot
.50769 .42821 Mdot
.47371 .57695 Mdot
.75933 .28589 Mdot
.52837 .34344 Mdot
.6912 .72433 Mdot
.70947 .74804 Mdot
.39172 .61773 Mdot
.54098 .49607 Mdot
.1904 .55232 Mdot
.39802 .25534 Mdot
.70604 .4274 Mdot
.79863 .34945 Mdot
.54092 .49489 Mdot
.59136 .27112 Mdot
.42063 .22762 Mdot
.38395 .72178 Mdot
.31125 .63001 Mdot
.4515 .57971 Mdot
.55091 .46213 Mdot
.63404 .37072 Mdot
.68376 .75057 Mdot
.80524 .6655 Mdot
.74574 .29405 Mdot
.31191 .6327 Mdot
.63558 .44903 Mdot
.40169 .43748 Mdot
.72644 .49342 Mdot
.75652 .27828 Mdot
.58289 .79596 Mdot
.24574 .44162 Mdot
.67227 .77138 Mdot
.30353 .63247 Mdot
.58867 .47842 Mdot
.6474 .43756 Mdot
.76098 .32592 Mdot
.29379 .43711 Mdot
.49684 .49312 Mdot
.40358 .46179 Mdot
.63997 .39607 Mdot
.4125 .59877 Mdot
.38734 .22753 Mdot
.29373 .67498 Mdot
.74431 .27316 Mdot
.61693 .76101 Mdot
.42434 .28539 Mdot
.74198 .25983 Mdot
.35137 .46242 Mdot
.40916 .59828 Mdot
.33026 .75699 Mdot
.65483 .45051 Mdot
.49544 .70015 Mdot
.542 .35929 Mdot
.6473 .42157 Mdot
.31916 .56043 Mdot
.65271 .48434 Mdot
.77403 .5314 Mdot
.25726 .42894 Mdot
.63584 .75937 Mdot
.28321 .41561 Mdot
.80613 .65939 Mdot
.47181 .56356 Mdot
.23907 .458 Mdot
.41147 .22313 Mdot
.52411 .7379 Mdot
.24354 .53294 Mdot
.79131 .44786 Mdot
.62708 .31339 Mdot
.25026 .44854 Mdot
.25401 .44259 Mdot
.29779 .5396 Mdot
.39316 .61158 Mdot
.8048 .41945 Mdot
.70021 .76471 Mdot
.59222 .70966 Mdot
.30486 .53764 Mdot
.56842 .44714 Mdot
.53928 .5099 Mdot
.77185 .46968 Mdot
.58065 .67696 Mdot
.84189 .42022 Mdot
.36895 .21995 Mdot
.29669 .55977 Mdot
.46451 .53226 Mdot
.60991 .27557 Mdot
.59522 .44906 Mdot
.51511 .73239 Mdot
.55076 .50034 Mdot
.3657 .51305 Mdot
.35786 .465 Mdot
.42866 .61644 Mdot
.76194 .53093 Mdot
.57873 .7158 Mdot
.34129 .60991 Mdot
.38187 .27099 Mdot
.72216 .74038 Mdot
.34681 .4117 Mdot
.57109 .51012 Mdot
.53882 .72364 Mdot
.46258 .41623 Mdot
.61744 .29533 Mdot
.81808 .3483 Mdot
.78908 .43425 Mdot
.32988 .49444 Mdot
.26767 .55076 Mdot
.57333 .7665 Mdot
.78324 .48579 Mdot
.5026 .50629 Mdot
.72444 .72749 Mdot
.40749 .36442 Mdot
.78569 .46942 Mdot
.23819 .46971 Mdot
.44595 .56345 Mdot
.69121 .75955 Mdot
.77475 .51685 Mdot
.67149 .77836 Mdot
.40344 .26835 Mdot
.53389 .45527 Mdot
.62302 .79459 Mdot
.41135 .4708 Mdot
.5428 .53982 Mdot
.43801 .25631 Mdot
.45554 .54566 Mdot
.7633 .70247 Mdot
.35727 .46946 Mdot
.63163 .48519 Mdot
.22192 .49738 Mdot
.31899 .60357 Mdot
.80093 .43602 Mdot
.2437 .54342 Mdot
.69415 .76692 Mdot
.50919 .43013 Mdot
.76344 .5084 Mdot
.37329 .27815 Mdot
.62722 .3276 Mdot
.59079 .5537 Mdot
.39807 .35445 Mdot
.57587 .53544 Mdot
.719 .4204 Mdot
.44615 .39621 Mdot
.82031 .39738 Mdot
.70598 .40376 Mdot
.42802 .45069 Mdot
.6372 .49937 Mdot
.28283 .44514 Mdot
.83384 .40398 Mdot
.70122 .4237 Mdot
.20285 .55921 Mdot
.72256 .748 Mdot
.65668 .74475 Mdot
.74084 .25643 Mdot
.30264 .62925 Mdot
.4453 .44328 Mdot
.78145 .69412 Mdot
.47616 .48508 Mdot
.6299 .75287 Mdot
.54651 .51922 Mdot
.34988 .42252 Mdot
.81012 .36567 Mdot
.61462 .48876 Mdot
.42215 .45487 Mdot
.4701 .3095 Mdot
.30109 .42242 Mdot
.6926 .41454 Mdot
.57167 .44926 Mdot
.55446 .6909 Mdot
.60063 .27677 Mdot
.59482 .7617 Mdot
.31095 .54008 Mdot
.71829 .74019 Mdot
.73269 .71856 Mdot
.67857 .49621 Mdot
.48128 .64075 Mdot
.73806 .25556 Mdot
.4269 .41285 Mdot
.49316 .29323 Mdot
.28311 .41674 Mdot
.77273 .52874 Mdot
.67398 .74432 Mdot
.56059 .40322 Mdot
.59741 .30113 Mdot
.40611 .35877 Mdot
.82061 .47126 Mdot
.4163 .50303 Mdot
.32926 .71064 Mdot
.28721 .53409 Mdot
.20431 .55733 Mdot
.216 .49763 Mdot
.29593 .63638 Mdot
.76372 .70033 Mdot
.46735 .61289 Mdot
.44458 .57301 Mdot
.4234 .44021 Mdot
.74837 .70075 Mdot
.32174 .61307 Mdot
.36824 .68768 Mdot
.3781 .32126 Mdot
.74399 .28501 Mdot
.25274 .42857 Mdot
.43546 .59537 Mdot
.49829 .55517 Mdot
.55549 .44943 Mdot
.32484 .5913 Mdot
.32916 .56864 Mdot
.28694 .41953 Mdot
.77929 .35766 Mdot
.50658 .57975 Mdot
.56594 .54686 Mdot
.65756 .77046 Mdot
.48481 .55767 Mdot
.73418 .72019 Mdot
.38893 .40984 Mdot
.7733 .33945 Mdot
.66884 .44745 Mdot
.7286 .50444 Mdot
.54873 .36316 Mdot
.24038 .51644 Mdot
.7991 .4717 Mdot
.50023 .50603 Mdot
.48804 .61728 Mdot
.22229 .47493 Mdot
.73676 .74396 Mdot
.63114 .51052 Mdot
.37498 .79341 Mdot
.64564 .50949 Mdot
.60153 .28909 Mdot
.5946 .27901 Mdot
.40707 .62198 Mdot
.53844 .51587 Mdot
.36369 .57005 Mdot
.5454 .4606 Mdot
.38038 .30607 Mdot
.80038 .5227 Mdot
.79249 .31756 Mdot
.34893 .44369 Mdot
.71147 .76579 Mdot
.35947 .50971 Mdot
.34237 .43001 Mdot
.61902 .75814 Mdot
.50342 .61586 Mdot
.46657 .43788 Mdot
.66289 .48992 Mdot
.35802 .47873 Mdot
.78272 .30737 Mdot
.47788 .60623 Mdot
.63685 .48593 Mdot
.56746 .76979 Mdot
.43002 .60148 Mdot
.35313 .73654 Mdot
.35551 .61842 Mdot
.74809 .73323 Mdot
.71101 .73923 Mdot
.32862 .71727 Mdot
.5304 .54932 Mdot
.48812 .61232 Mdot
.79005 .35801 Mdot
.63408 .4989 Mdot
.79898 .4446 Mdot
.29977 .70982 Mdot
.38743 .2984 Mdot
.70186 .40139 Mdot
.69165 .42798 Mdot
.6299 .32387 Mdot
.40455 .32775 Mdot
.78322 .38248 Mdot
.63735 .53461 Mdot
.58497 .71412 Mdot
.57621 .77658 Mdot
.76018 .28334 Mdot
.27953 .5499 Mdot
.62153 .56688 Mdot
.72703 .4885 Mdot
.50545 .57735 Mdot
.61566 .43907 Mdot
.37303 .52688 Mdot
.56725 .53228 Mdot
.35221 .72847 Mdot
.21536 .5145 Mdot
.82424 .46534 Mdot
.5518 .3732 Mdot
.55747 .24787 Mdot
.33818 .59351 Mdot
.50266 .71059 Mdot
.21677 .48638 Mdot
.81319 .34424 Mdot
.37329 .68798 Mdot
.33339 .75396 Mdot
.39348 .61466 Mdot
.77267 .48047 Mdot
.36042 .79087 Mdot
.39968 .6139 Mdot
.80275 .67063 Mdot
.31212 .56455 Mdot
.41379 .29575 Mdot
.19764 .50393 Mdot
.71852 .41789 Mdot
.39573 .35304 Mdot
.56234 .56731 Mdot
.82085 .4362 Mdot
.60281 .44843 Mdot
.62137 .48151 Mdot
.77948 .3713 Mdot
.68497 .76405 Mdot
.65034 .77616 Mdot
.36345 .5968 Mdot
.27834 .43529 Mdot
.38798 .81044 Mdot
.5538 .76198 Mdot
.35466 .23171 Mdot
.78627 .4315 Mdot
.44635 .29097 Mdot
.49866 .50191 Mdot
.38378 .50188 Mdot
.8008 .36785 Mdot
.75578 .70299 Mdot
.54374 .54954 Mdot
.55764 .70937 Mdot
.69124 .43928 Mdot
.71644 .49182 Mdot
.34287 .55587 Mdot
.77403 .45257 Mdot
.51859 .73304 Mdot
.617 .48959 Mdot
.69864 .75769 Mdot
.23993 .51552 Mdot
.62616 .33971 Mdot
.74682 .28685 Mdot
.61624 .30329 Mdot
.65296 .78853 Mdot
.30379 .71429 Mdot
.57127 .77533 Mdot
.76297 .29008 Mdot
.30088 .55064 Mdot
.42321 .34944 Mdot
.73534 .24463 Mdot
.83503 .43024 Mdot
.4905 .6116 Mdot
.55305 .35713 Mdot
.79561 .67943 Mdot
.57171 .7 Mdot
.7742 .49075 Mdot
.3658 .2788 Mdot
.63663 .77578 Mdot
.45509 .39331 Mdot
.56122 .37537 Mdot
.59237 .46943 Mdot
.34395 .48076 Mdot
.27153 .43616 Mdot
.57034 .75054 Mdot
.66484 .77279 Mdot
.37855 .25812 Mdot
.36468 .29733 Mdot
.40072 .2672 Mdot
.31427 .50074 Mdot
.81682 .44405 Mdot
.70239 .56281 Mdot
.36789 .25012 Mdot
.78261 .35335 Mdot
.58365 .24854 Mdot
.35015 .57187 Mdot
.37552 .30426 Mdot
.65994 .43793 Mdot
.59415 .75936 Mdot
.75137 .26224 Mdot
.38283 .32468 Mdot
.84132 .41423 Mdot
.81443 .50649 Mdot
.31863 .4979 Mdot
.33784 .5321 Mdot
.5898 .45096 Mdot
.48178 .59179 Mdot
.35663 .73016 Mdot
.54854 .76637 Mdot
.64607 .75136 Mdot
.56241 .71244 Mdot
.54716 .39313 Mdot
.38562 .48953 Mdot
.80221 .46159 Mdot
.59108 .47849 Mdot
.80585 .45799 Mdot
.39494 .31132 Mdot
.52549 .34328 Mdot
.73301 .23502 Mdot
.21684 .55206 Mdot
.47801 .4125 Mdot
.64645 .54553 Mdot
.61816 .56756 Mdot
.48174 .32966 Mdot
.39772 .68597 Mdot
.65322 .46382 Mdot
.61995 .77824 Mdot
.81816 .4329 Mdot
.31292 .53625 Mdot
.59663 .45066 Mdot
.32897 .63899 Mdot
.60547 .4095 Mdot
.4529 .38843 Mdot
.35887 .68905 Mdot
.60391 .77599 Mdot
.39783 .72078 Mdot
.32456 .60083 Mdot
.41108 .59608 Mdot
.64241 .41868 Mdot
.63207 .55658 Mdot
.61179 .76764 Mdot
.41074 .62667 Mdot
.33483 .59298 Mdot
.691 .7689 Mdot
.41158 .33445 Mdot
.30292 .64252 Mdot
.58635 .75033 Mdot
.63449 .44285 Mdot
.39332 .47296 Mdot
.50061 .59969 Mdot
.39471 .22601 Mdot
.79764 .38064 Mdot
.59807 .65709 Mdot
.63829 .53646 Mdot
.42598 .21685 Mdot
.8154 .39383 Mdot
.34606 .67365 Mdot
.81505 .63615 Mdot
.50773 .6121 Mdot
.22328 .49501 Mdot
.43119 .24387 Mdot
.53263 .49814 Mdot
.46441 .23638 Mdot
.53717 .33719 Mdot
.59339 .323 Mdot
.32415 .74098 Mdot
.54336 .49969 Mdot
.42821 .60456 Mdot
.46033 .60366 Mdot
.62669 .47067 Mdot
.47394 .24593 Mdot
.5214 .40675 Mdot
.62369 .50854 Mdot
.6715 .41416 Mdot
.5648 .5254 Mdot
.62869 .47608 Mdot
.30435 .6758 Mdot
.61153 .76994 Mdot
.64733 .77609 Mdot
.44999 .42442 Mdot
.80459 .36684 Mdot
.44693 .27481 Mdot
.78713 .43586 Mdot
.39452 .51721 Mdot
.30098 .67217 Mdot
.61327 .29994 Mdot
.75012 .26353 Mdot
.39676 .4423 Mdot
.63614 .57788 Mdot
.81052 .50695 Mdot
.78722 .4562 Mdot
.31456 .69042 Mdot
.18743 .5343 Mdot
.57735 .77806 Mdot
.60006 .45593 Mdot
.2119 .50946 Mdot
.59596 .69198 Mdot
.79025 .48756 Mdot
.52704 .46412 Mdot
.501 .61436 Mdot
.38343 .23186 Mdot
.46299 .41372 Mdot
.55523 .65241 Mdot
.39916 .22442 Mdot
.40537 .32664 Mdot
.78309 .38447 Mdot
.49095 .29604 Mdot
.43795 .53054 Mdot
.39881 .43503 Mdot
.74677 .27918 Mdot
.54069 .64673 Mdot
.59047 .26933 Mdot
.36019 .2166 Mdot
.32241 .74048 Mdot
.6303 .75041 Mdot
.74463 .29109 Mdot
.36227 .62139 Mdot
.54851 .46098 Mdot
.19507 .58819 Mdot
.40005 .43979 Mdot
.30604 .4124 Mdot
.34541 .6063 Mdot
.71377 .49992 Mdot
.40226 .45356 Mdot
.75129 .25232 Mdot
.78837 .47317 Mdot
.45266 .43581 Mdot
.3514 .23298 Mdot
.70312 .75398 Mdot
.58054 .27093 Mdot
.29877 .65688 Mdot
.81722 .45124 Mdot
.34452 .73118 Mdot
.78573 .69006 Mdot
.48609 .56583 Mdot
.35869 .50645 Mdot
.70705 .49186 Mdot
.21047 .5184 Mdot
.5441 .48469 Mdot
.36173 .28816 Mdot
.21213 .53647 Mdot
.72488 .47822 Mdot
.51036 .53585 Mdot
.36618 .45278 Mdot
.36774 .50235 Mdot
.47181 .53743 Mdot
.50185 .61927 Mdot
.43667 .59528 Mdot
.45069 .57247 Mdot
.32284 .60903 Mdot
.45696 .52773 Mdot
.21603 .55569 Mdot
.38587 .62214 Mdot
.40044 .29247 Mdot
.58934 .75593 Mdot
.64278 .47842 Mdot
.56517 .69568 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0?ooooooB_ooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A006ooooo`03o`000?oooooooooo0?ooooooB_ooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0?ooooooB_oo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06
ooooo`?o0000oooooom:ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<oooo
o`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0P?ooool2o`000<Oooooo00000ooooooo
410@ooooo`02ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`1fooooo`Oo00000oooool2o`000<Oooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMg
M`_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo07?ooooo0_l00000
0ooooooo0000o`000005o`0000Gooooo0_l0000:ooooo`;o0000^Oooool00006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0
L_ooool3o`0000gooooo0_l0000:ooooo`Co0000]oooool001cooooo00?o0000ooooooooool0LOoo
ool4o`0001;ooooo0_l00007ooooo`;o0000]oooool001cooooo00?o0000ooooooooool0K?ooool2
o`0000?ooooo0_l000000ooooooo0000o`00000Aooooo`;o0000`?ooool001cooooo00?o0000oooo
ooooool0K?ooool2o`0000Kooooo0_l00006ooooo`Co00000_ooool2o`0000oooooo0_l0002doooo
o`007?ooool00ol0003oooooooooo`1Wooooo`;o00000_ooool2o`0000gooooo1_l00002ooooo`;o
000000?oooooo`000?l000001oooool2o`0000?ooooo0_l0002dooooo`007?ooool00ol0003ooooo
ooooo`1Wooooo`;o000000Coooooo`000?l0003o00003Oooool4o`0000Oooooo1?l00004ooooo`?o
0000^Oooool001cooooo00?o0000ooooooooool0Ioooool2o`000005ooooool0003o0000o`000?oo
ool00ol00008ooooo`;o00002_ooool5o`0000?ooooo0ol0001Looooo`;o0000Foooool001cooooo
00?o0000ooooooooool0J_ooool7o`0000Sooooo0_l00009ooooo`Ko00000oooool3o`000003oooo
ool0003o000000Co0000Doooool6o`0005Wooooo000Looooo`03o`000?oooooooooo06_ooooo1_l0
000Cooooo`;o00001oooool:o`0005?ooooo0_l000001?oooooo0000o`000?l0001Iooooo`007?oo
ool00ol0003oooooooooo`1^ooooo`Co00004_ooool2o`0000?ooooo0_l000000ooooooo0000o`00
000;o`0005Cooooo0ol0001Iooooo`007?ooool00ol0003oooooooooo`1_ooooo`Co00004Oooool2
o`0000;ooooo4_l0001Aooooo`Ko0000F?ooool001cooooo00?o0000ooooooooool0LOooool4o`00
00oooooo0_l00002ooooo`;o000000?oooooo`000?l000003Ol0000Gooooo`;o00001oooool2o`00
02oooooo1ol0001Gooooo`007?ooool2o`00077ooooo1_l0000>ooooo`;o00000_oooolBo`0001Ko
oooo0ol00002ooooo`;o00000oooool2o`0003Cooooo0_l0001Gooooo`007?ooool00ol0003ooooo
ooooo`1`ooooo`Ko00002?ooool2o`0000?ooooo0ol00003oooooaCo00004oooool2o`0000?ooooo
0_l0000fooooo`;o000000Coooooo`000?l0003o0000E_ooool001cooooo00?o0000ooooooooool0
LOooool5o`000003ooooool0003o000000Gooooo0_l00003ooooo`?o00000ooooolDo`0001Cooooo
0ol0000hooooo`?o00000_ooool2o`0005Kooooo000Looooo`03o`000?oooooooooo073ooooo0ol0
00001?oooooo0000o`000?ooool2o`0001;ooooo3ol0000Gooooo`?o0000>?ooool3o`0000;ooooo
0_l0001Fooooo`007?ooool00ol0003oooooooooo`1_ooooo`So00003?ooool3o`0000Kooooo3_l0
00000ooooooo0000o`00001@ooooo`;o000000?oooooo`000?l000000_l0001Eooooo`007?ooool0
0ol0003oooooooooo`1_ooooo`;o00000_ooool4o`0000Gooooo1?l00003ooooo`?o00001_oooolA
o`00027ooooo0_l0000`ooooo`Co0000EOooool001cooooo00?o0000ooooooooool0L_ooool5o`00
00Gooooo1Ol00002ooooo`?o00001oooool>o`00027ooooo1?l0000booooo`;o0000EOooool001co
oooo00?o0000ooooooooool0L_ooool4o`0000;ooooo0_l00005ooooo`;o00000_ooool3o`0000So
oooo3Ol0000Nooooo`;o000000?oooooo`000?l000001Oooool3o`0002Sooooo0_l00003ooooo`;o
0000E?ooool001cooooo00?o0000ooooooooool0L_ooool4o`0000;ooooo1?l00007ooooo`;o0000
2?ooool=o`000003ooooool0003o000001cooooo0_l000001?oooooo0000o`000?ooool2o`000003
ooooool0003o000000?o00009oooool2o`0000?ooooo0_l0001Dooooo`007?ooool00ol0003ooooo
ooooo`1booooo`Ko00000_ooool2o`0000Oooooo0_l00008ooooo`go000000Coooooo`000?l0003o
00007oooool4o`000003ooooool0003o000000?o0000:?ooool2o`000003ooooool0003o000000;o
0000Doooool001cooooo00?o0000ooooooooool0Loooool5o`0000[ooooo0ol0000:ooooo`[o0000
0oooool2o`0001oooooo0_l00005ooooo`;o000000?oooooo`000?l000009_ooool2o`000003oooo
ool0003o000000;o0000Doooool001cooooo00?o0000ooooooooool0Loooool3o`0000cooooo0_l0
0002ooooo`;o00002?ooool:o`0002?ooooo1?l00006ooooo`;o00009Oooool2o`0000;ooooo1Ol0
001Booooo`007?ooool00ol0003oooooooooo`1booooo`Co00001oooool2o`0000?ooooo0ol00000
0ooooooo0000o`00000:ooooo`;o00000_ooool9o`0001kooooo1Ol00005ooooo`?o00009?ooool3
o`000003ooooool0003o000000?o0000D_ooool001cooooo00?o0000ooooooooool0L_ooool4o`00
00Oooooo0_l000001?oooooo0000o`000?ooool2o`0000Sooooo0_l00005ooooo`_o00008Oooool2
o`0000Gooooo0ol0000Tooooo`?o00000oooool2o`0005?ooooo000Looooo`03o`000?oooooooooo
07Gooooo0_l00007ooooo`Go00002_ooool3o`0000Cooooo0_l00002ooooo`Ko00009oooool4o`00
02Gooooo1?l00002ooooo`;o000000?oooooo`000?l00000D?ooool001cooooo00?o0000oooooooo
ool0Loooool4o`0000?ooooo0_l00002ooooo`Oo00001_ooool5o`0000Cooooo0_l00002ooooo`Ko
00009oooool2o`0000?ooooo0_l0000Rooooo`Co00001Oooool2o`00053ooooo000Looooo`;o0000
M?ooool2o`0000Gooooo0_l00007ooooo`;o00000oooool2o`000003ooooool0003o000000Ko0000
1_ooool2o`000003ooooool0003o0000023ooooo0_l00003ooooo`;o00001Oooool2o`0002?ooooo
0_l00008ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0MOooool3o`00013ooooo0ol0
0004ooooo`Co0000:oooool2o`0000?ooooo0ol0000cooooo`;o0000C_ooool001cooooo00?o0000
ooooooooool0MOooool5o`0000Gooooo0_l00006ooooo`Co000000?oooooo`000?l000000_l0000;
ooooo`;o00009oooool2o`0000Gooooo0_l0000]ooooo`;o0000COooool001cooooo00?o0000oooo
ooooool0MOooool5o`0000Gooooo0_l00006ooooo`;o00000_ooool<o`0000;ooooo1?l0000Ooooo
o`?o00002Oooool2o`000003ooooool0003o000002Gooooo0_l00006ooooo`;o0000COooool001co
oooo00?o0000ooooooooool0MOooool3o`0000Gooooo0_l00007ooooo`;o00000oooool<o`000005
ooooool0003o0000o`000?ooool00_l000000ooooooo0000o`000002o`0001Wooooo0ol00009oooo
o`;o000000Coooooo`000?l0003o00009?ooool2o`0000?ooooo0_l00005ooooo`;o0000BOooool0
01cooooo00?o0000ooooooooool0Moooool2o`0000Cooooo0_l00006ooooo`?o00000oooool6o`00
00;ooooo2?l000000ooooooo0000o`000005o`0001cooooo2?l000001?oooooo0000o`000?ooool3
o`0002?ooooo0_l00004ooooo`;o00001Oooool2o`0004Wooooo000Looooo`03o`000?oooooooooo
07Oooooo0_l0000<ooooo`;o00000_ooool4o`0000Kooooo3_l0000Mooooo`Wo00001Oooool3o`00
02;ooooo0_l0000;ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0M_ooool3o`0000co
oooo0_l00002ooooo`?o00002Oooool<o`0001cooooo1Ol000000ooooooo0000o`000003o`0000Co
oooo0ol0000Tooooo`;o00002Oooool2o`000003ooooool0003o000004Kooooo000Looooo`03o`00
0?oooooooooo07Gooooo1_l0000?ooooo`;o00002_ooool2o`000003ooooool0003o000000Oo0000
00?oooooo`000?l000000ol0000Eooooo`Co00000oooool4o`000003ooooool0003o000000;ooooo
0_l0000Tooooo`;o000000?oooooo`000?l000002?ooool3o`0004Kooooo000Looooo`03o`000?oo
oooooooo07Gooooo1_l00005ooooo`;o00001Oooool2o`0000gooooo0_l000000ooooooo0000o`00
000?o`0001Cooooo0_l00005ooooo`Ko00000_ooool2o`0002Cooooo0_l000000ooooooo0000o`00
0008ooooo`Go0000A?ooool001cooooo00?o0000ooooooooool0M_ooool3o`0000Oooooo0_l00002
ooooo`;o000000?oooooo`000?l000004?ooool:o`0000;ooooo1Ol0000Dooooo`;o00001Oooool5
o`0000?ooooo1?l0000Uooooo`;o00002_ooool3o`0004Cooooo000Looooo`03o`000?oooooooooo
07Oooooo0_l00009ooooo`Co000000Coooooo`000?l0003o00003oooool7o`000004ooooool0003o
0000o`0000?ooooo1?l0000Cooooo`;o00001oooool2o`000003ooooool0003o000000?ooooo0_l0
000Sooooo`Co0000DOooool001cooooo00?o0000ooooooooool0M_ooool3o`0000Wooooo0_l00003
ooooo`?o00003oooool<o`0000;ooooo1_l0000Jooooo`;o000000?oooooo`000?l000000_ooool2
o`0002Cooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`1fooooo`?o00001?ooool2o`00
01[ooooo3?l00002ooooo`Ko00000_ooool2o`0001Kooooo0ol00004ooooo`?o00009_ooool2o`00
053ooooo000Looooo`03o`000?oooooooooo07Kooooo1?l00003ooooo`;o00006_oooolBo`000004
ooooool0003o0000ooooo`;o00005_ooool5o`0000;ooooo0ol0000Vooooo`;o00001_ooool2o`00
00?ooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`1gooooo`?o00007ooooolFo`0001Wo
oooo1?l00002ooooo`;o0000;oooool2o`0000?ooooo0_l00013ooooo`007?ooool2o`0007Sooooo
0ol00005ooooo`;o00001Oooool2o`00017ooooo0_l00002oooooa;o00003?ooool2o`0000cooooo
0_l00004ooooo`;o0000;oooool2o`0000;ooooo1?l00011ooooo`007?ooool00ol0003ooooooooo
o`1hooooo`;o00000oooool4o`0000Gooooo0_l0000BoooooaOo00002_ooool2o`0000cooooo0ol0
0002ooooo`Co0000:?ooool2o`0000;ooooo1?l00002ooooo`Co0000@Oooool001cooooo00?o0000
ooooooooool0N?ooool2o`0000?ooooo1Ol0000GoooooaWo00002?ooool2o`0000kooooo0_l00002
ooooo`Co0000:?ooool2o`0000;ooooo0_l00003ooooo`;o0000A?ooool001cooooo00?o0000oooo
ooooool0O_ooool4o`000003ooooool0003o000001Cooooo5Ol000001?oooooo0000o`000?l00008
ooooo`;o00003_ooool3o`0000;ooooo0ol0000Wooooo`;o00000_ooool2o`0000Cooooo0_l00014
ooooo`007?ooool00ol0003oooooooooo`20ooooo`;o000000?oooooo`000?l000000oooool2o`00
00oooooo6Ol0000Hooooo`?o00000_ooool3o`0002Oooooo0_l00002ooooo`;o0000B_ooool001co
oooo00?o0000ooooooooool0POooool4o`0000?ooooo0_l0000?oooooaWo00006?ooool3o`0000?o
oooo0_l0000_ooooo`Co0000A?ooool001cooooo00?o0000ooooooooool0POooool2o`0001Kooooo
6_l0000Gooooo`?o000000?oooooo`000?l000000_l0000^ooooo`Go0000A?ooool001cooooo00?o
0000ooooooooool0NOooool2o`0001kooooo6_l0000Fooooo`Co000000?oooooo`000?l000000_l0
000Wooooo`;o00001Oooool4o`0004Gooooo000Looooo`03o`000?oooooooooo07Wooooo0_l00009
ooooo`;o00001Oooool2o`0000cooooo7?l0000Dooooo`?o00000_ooool4o`0002Oooooo0_l0000;
ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0NOooool4o`0000Oooooo0_l00005oooo
o`;o00003?oooolLo`0001Oooooo1_l0000Zooooo`;o00002?ooool2o`000003ooooool0003o0000
03kooooo000Looooo`03o`000?oooooooooo07Wooooo1?l0000Loooooa[o00005_ooool2o`000003
ooooool0003o000000?o0000:Oooool4o`000003ooooool0003o000000Sooooo0_l000000ooooooo
0000o`00000kooooo`007?ooool00ol0003oooooooooo`1jooooo`;o00002Oooool2o`0001Gooooo
1_l000000ooooooo0000o`00000>o`0001Kooooo0_l00002ooooo`Co0000:Oooool3o`0000;ooooo
0_l00007ooooo`;o00000_ooool2o`0003_ooooo000Looooo`03o`000?oooooooooo08Gooooo0_l0
0003ooooo`;o00003ooooolHo`0001Gooooo0ol000000ooooooo0000o`000003o`0002[ooooo0_l0
00000ooooooo0000o`000008ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0Poooool2
o`0000Gooooo0_l00003ooooo`;o00002_oooolJo`0001?ooooo2?l0000^ooooo`;o00001?ooool2
o`0004?ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o
410@ooooooooool01?ooool00ol0003oooooooooo`23ooooo`;o00000oooool2o`0000Gooooo0ol0
0009ooooo`?o000000?oooooo`000?l000004Ol000000ooooooo0000o`00000Aooooo`[o0000=?oo
ool3o`0004;ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0N_ooool2o`0000cooooo0ol00002ooooo`;o0000
00?oooooo`000?l000002_oooolGo`0001?ooooo2Ol0000Booooo`?o00005oooool2o`0000Sooooo
0_l00005ooooo`;o0000>oooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Ooo
ool5o`0000Kooooo00?o0000ooooooooool0Hoooool2o`0001Gooooo0_l0000<ooooo`Co000000?o
ooooo`000?l000003OoooolGo`00017ooooo2_l0000Aooooo`Go00005oooool2o`0000[ooooo0_l0
0003ooooo`;o0000>oooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool0
1?m4A4CogMgMooooool00007ooooo`?o0000Hoooool5o`0001?ooooo0_l0000=ooooo`;o000000?o
ooooo`000?l000003_ooool2o`000003ooooool0003o000000ko00000_ooool2o`00013ooooo1ol0
000Aooooo`;o000000?oooooo`000?l000000ol0000Sooooo`;o0000@?ooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool02Oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oo
oooooooo05kooooo0_l00004ooooo`Go00004_ooool2o`0000oooooo1?l0000@oooooa3o00000_oo
ool3o`0000gooooo1ol0000<ooooo`;o00001Oooool2o`0000;ooooo1?l0000Uooooo`Co0000??oo
ool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00omgMgOoc<c<o`000007
ooooo`03o`000?oooooooooo05Sooooo1?l00002ooooo`ko00003oooool2o`0000oooooo1?l00003
ooooo`;o00000oooool2o`0000Gooooo3ol000000ooooooo0000o`000002ooooo`?o00002oooool7
o`0000gooooo0ol00003ooooo`;o00001Oooool2o`0002Gooooo1?l0000looooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0F?oo
ool4o`0000Cooooo3?l000000ooooooo0000o`00000<ooooo`;o00004?ooool4o`0000;ooooo0_l0
0003ooooo`?o00001?ooool?o`000003ooooool0003o000000?ooooo0_l0000;ooooo`Go00003?oo
ool7o`0000;ooooo0_l00005ooooo`?o000000?oooooo`000?l00000HOooool00006ooooooo^k^ko
<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo05?ooooo
0_l00003ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000
o`000006o`0000cooooo0_l000000ooooooo0000o`000007ooooo`;o00001_ooool2o`0000;ooooo
0_l00003ooooo`?o00001_ooool<o`0000?ooooo0_l0000?ooooo`Co00002_ooool:o`0000Cooooo
0_l00003ooooo`Ko00007_ooool2o`0000Gooooo0_l0000jooooo`007?ooool00ol0003ooooooooo
o`1Aooooo`Co00000oooool2o`0000?ooooo0_l0000;ooooo`Oo00003Oooool2o`0000Oooooo0_l0
0004ooooo`;o00001?ooool3o`0000_ooooo3Ol00002ooooo`?o00003_ooool3o`0000Wooooo2ol0
0005ooooo`;o00001?ooool5o`0001gooooo0ol00005ooooo`;o0000>_ooool001cooooo00?o0000
ooooooooool0DOooool2o`0000;ooooo0_l000001?oooooo0000o`000?l00005ooooo`;o00000_oo
ool2o`0000Cooooo1ol0000Looooo`;o00001?ooool3o`0000gooooo0ol000000ooooooo0000o`00
0005o`0000;ooooo1Ol0000:ooooo`?o00002oooool3o`0001Cooooo1?l0000Jooooo`;o000000?o
ooooo`000?l000001oooool2o`0003Wooooo000Looooo`03o`000?oooooooooo053ooooo0_l00000
0ooooooo0000o`000002o`0000;ooooo0_l00003ooooo`Co00000_ooool2o`0000Gooooo0_l00000
0ooooooo0000o`000004o`0001[ooooo0_l00009ooooo`;o00000oooool2o`0000?ooooo0ol00000
0ooooooo0000o`00000<o`0000Oooooo1_l00005ooooo`Go00000_ooool2o`00013ooooo0_l00002
ooooo`Co00006_ooool2o`0000[ooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`1<oooo
o`;o00000_ooool2o`000003ooooool0003o000000Wooooo0_l0000;ooooo`;o000000?oooooo`00
0?l000001?l0000@ooooo`;o00002?ooool2o`0000Wooooo0_l00003ooooo`;o00001oooool6o`00
0004ooooool0003o0000o`0000Wooooo1Ol00006ooooo`Oo00001?ooool3o`0000[ooooo0_l00000
0ooooooo0000o`000005o`0001Sooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`1;oooo
o`Oo00006Oooool2o`0000Cooooo0ol00007ooooo`Co00001Oooool2o`0001_ooooo0ol0000;oooo
o`;o00000_ooool2o`0000;ooooo1_l00007ooooo`?o00002Oooool3o`0000Wooooo0ol00003oooo
o`Go00006?ooool2o`0000[ooooo0ol0000kooooo`007?ooool00ol0003oooooooooo`1;ooooo`Oo
00000_ooool2o`0001Gooooo0_l00005ooooo`;o00001oooool4o`00023ooooo1Ol0000;ooooo`co
00001_ooool2o`000003ooooool0003o000000kooooo0_l00006ooooo`;o00001_ooool5o`0001?o
oooo0_l00008ooooo`;o00000oooool3o`0003_ooooo000Looooo`03o`000?oooooooooo04Wooooo
1_l00005ooooo`;o000000?oooooo`000?l000000oooool2o`0000Sooooo0_l0000:ooooo`;o0000
1oooool2o`000003ooooool0003o000000oooooo0_l00004ooooo`;o00002?ooool3o`0000kooooo
2?l00008ooooo`?o00004Oooool2o`0000gooooo1_l0000Cooooo`?o000000Coooooo`000?l0003o
00000oooool3o`00043ooooo000Looooo`03o`000?oooooooooo04Sooooo0ol00009ooooo`Go0000
0oooool2o`0000Kooooo1?l0000;ooooo`;o00002Oooool3o`0000Gooooo0_l00007ooooo`;o0000
0oooool3o`0000Wooooo0_l00007ooooo`;o00002Oooool2o`000004ooooool0003o0000o`0000Ko
oooo0_l00002ooooo`?o00002?ooool2o`0000;ooooo0_l00008ooooo`;o00000oooool4o`000003
ooooool0003o000001?ooooo0ol000001?oooooo0000o`000?l00004ooooo`;o00000oooool2o`00
03_ooooo000Looooo`03o`000?oooooooooo04Sooooo0ol000001?oooooo0000o`000?ooool2o`00
00Gooooo0_l000000ooooooo0000o`00000=o`000004ooooool0003o0000ooooo`;o00001Oooool2
o`0000Sooooo1?l00005ooooo`;o00001Oooool2o`0000Gooooo0_l0000Booooo`?o00001Oooool2
o`0000;ooooo1_l0000:ooooo`?o00000oooool2o`0000?ooooo0_l00002ooooo`;o00002?ooool2
o`0000?ooooo1ol0000Sooooo`?o0000>_ooool001cooooo00?o0000ooooooooool0A_ooool5o`00
0004ooooool0003o0000ooooo`;o00001OoooolEo`000003ooooool0003o000000;o00000_ooool3
o`0000Sooooo0_l0000>ooooo`;o00006Oooool2o`0000Kooooo0_l00002ooooo`?o000000?ooooo
o`000?l000000_l0000=ooooo`?o000000?oooooo`000?l000001oooool4o`0000Oooooo1_l0000B
ooooo`;o00001Oooool4o`0000;ooooo0_l00004ooooo`?o0000>_ooool001cooooo00?o0000oooo
ooooool0A_ooool2o`000004ooooool0003o0000ooooo`Co00001?oooolAo`000003ooooool0003o
000000Go000000?oooooo`000?l000000_ooool2o`00013ooooo0_l000000ooooooo0000o`00000>
ooooo`;o00005?ooool6o`0000;ooooo0ol000001?oooooo0000o`000?l00002ooooo`Co00001ooo
ool6o`0000;ooooo2Ol00007ooooo`Ko00004_ooool2o`0000;ooooo1ol00002ooooo`;o000000Co
ooooo`000?l0003ooooo0_l0000kooooo`007?ooool2o`0004oooooo0_l000001?oooooo0000o`00
0?ooool>o`000003ooooool0003o000000_o00000_ooool3o`0000Gooooo0_l00008ooooo`;o0000
00?oooooo`000?l000003_ooool2o`0000_ooooo0_l00007ooooo`_o00000_ooool8o`0000Cooooo
0ol00002ooooo`;o00001?ooool6o`0000Cooooo0_l00005ooooo`Ko00004?ooool4o`000004oooo
ool0003o0000o`0000Kooooo0_l000000ooooooo0000o`00000nooooo`007?ooool00ol0003ooooo
ooooo`14ooooo`;o000000?oooooo`000?l000002?oooolOo`0000;ooooo0ol00005ooooo`;o0000
0oooool2o`0000Cooooo1?l0000Kooooo`;o00001?ooool2o`0000Oooooo0ol00006ooooo`Co0000
1_ooool3o`0000Sooooo0_l00008ooooo`;o000000?oooooo`000?l000002?l0000@ooooo`Co0000
2_ooool2o`000003ooooool0003o000003kooooo000Looooo`03o`000?oooooooooo04Cooooo0_l0
00001?oooooo0000o`000?ooool2o`0000Gooooo7_l00004ooooo`;o00001?ooool3o`000003oooo
ool0003o000000;o00001?ooool2o`0002?ooooo0_l0000:ooooo`;o00001oooool2o`0001_ooooo
2?l000000ooooooo0000o`00000Eooooo`;o00001?ooool2o`0000;ooooo0_l00004ooooo`;o0000
>oooool001cooooo00?o0000ooooooooool0AOooool2o`0000?ooooo0_l00004ooooo`?o000000?o
ooooo`000?l000006_l00009ooooo`;o00000_ooool4o`0001Gooooo0_l0000Eooooo`?o00000ooo
ool2o`000003ooooool0003o000000Oooooo1_l00002ooooo`;o00004Oooool9o`0001Wooooo0_l0
0003ooooo`?o00002?ooool2o`0003_ooooo000Looooo`03o`000?oooooooooo043ooooo0ol00002
ooooo`;o00002?ooool3o`0000;ooooo7?l000001?oooooo0000o`000?l00005ooooo`;o00001?oo
ool2o`0001Gooooo0_l000000ooooooo0000o`00000<ooooo`;o00001?ooool4o`0000;ooooo0_l0
000:ooooo`Ko00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool>o`0001kooooo0_l0
0016ooooo`007?ooool00ol0003oooooooooo`10ooooo`?o00001_ooool2o`0000Cooooo0_l00000
0ooooooo0000o`00000Lo`000004ooooool0003o0000o`0000Gooooo0_l0000Kooooo`;o000000?o
ooooo`000?l000003?ooool2o`0000Kooooo0_l0000Hooooo`Go00000_ooool>o`0002;ooooo1?l0
0004ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0?oooool4o`0000Cooooo1Ol00002
ooooo`?o000000?oooooo`000?l000008?l00004ooooo`?o00001oooool2o`0001;ooooo0_l0000U
ooooo`;o00001?ooool2o`0000?ooooo1Ol00003ooooo`[o00007Oooool2o`0000;ooooo0_l00002
ooooo`Go00001?ooool2o`0003oooooo000Looooo`03o`000?oooooooooo03kooooo1?l00005oooo
o`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo7Ol000000ooooooo0000o`000002o`00
00Cooooo0ol000000ooooooo0000o`000004ooooo`;o0000>Oooool2o`0000Cooooo0_l00003oooo
o`;o0000;Oooool2o`0000;ooooo0ol000001?oooooo0000o`000?l00005ooooo`;o0000@?ooool0
01cooooo00?o0000ooooooooool0?_ooool4o`0000?ooooo0_l00005ooooo`Co00000_oooolMo`00
00?ooooo0_l00005ooooo`;o000000?oooooo`000?l00000:?ooool2o`0000oooooo0_l00007oooo
o`;o00001_ooool2o`0000?ooooo0_l0000]ooooo`;o000000?oooooo`000?l000000ol00003oooo
o`;o0000@?ooool001cooooo00?o0000ooooooooool0?_ooool2o`0000Gooooo0_l00005ooooo`Co
000000?oooooo`000?l000006ol00003ooooo`;o00001?ooool4o`0000;ooooo0_l00005ooooo`;o
00008?ooool2o`0000oooooo0_l00002ooooo`?o00000_ooool2o`0000Kooooo0_l00003ooooo`Co
00004oooool2o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l000003Oooool4o`0004Go
oooo000Looooo`03o`000?oooooooooo03kooooo0_l0000=ooooo`?o000000?oooooo`000?l00000
6ol00003ooooo`;o00001?ooool3o`0000?ooooo0_l00005ooooo`;o00006_ooool2o`0001Wooooo
0ol000000ooooooo0000o`000005ooooo`?o00001?ooool4o`0001?ooooo0_l00002ooooo`;o0000
1?ooool5o`0000;ooooo1?l0000>ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0?Ooo
ool4o`0000;ooooo0_l00002ooooo`;o00000oooool3o`0000;ooooo4?l000000ooooooo0000o`00
000:o`000003ooooool0003o0000013ooooo0_l0000Dooooo`;o00001oooool2o`0000Oooooo0_l0
0002ooooo`;o00003?ooool2o`000003ooooool0003o000000?o00000oooool7o`0000?ooooo0_l0
000Mooooo`?o00000oooool4o`0000;ooooo0_l0000:ooooo`;o0000@?ooool001cooooo00?o0000
ooooooooool0?Oooool4o`0000;ooooo0_l00002ooooo`;o00000oooool3o`0000Cooooo6_l00002
ooooo`?o00002?ooool2o`0000Gooooo0_l0000Booooo`Co00004?ooool2o`0000;ooooo0_l0000?
ooooo`;o000000Coooooo`000?l0003ooooo0ol00002ooooo`Co00000oooool2o`0000Cooooo0_l0
000@ooooo`;o00001_ooool2o`0000Wooooo1?l00009ooooo`;o0000?oooool001cooooo00?o0000
ooooooooool0??ooool3o`0000[ooooo1_l00006oooooaKo000000Coooooo`000?l0003ooooo0ol0
0008ooooo`;o00006Oooool2o`0001Wooooo0_l0000Booooo`?o00002Oooool2o`0000;ooooo1?l0
000:ooooo`;o000000Coooooo`000?l0003ooooo0_l00008ooooo`;o00001?ooool2o`000003oooo
ool0003o000000;o00002Oooool2o`0003oooooo000Looooo`03o`000?oooooooooo03cooooo0_l0
0007ooooo`;o00000_ooool6o`0000Kooooo5_l000000ooooooo0000o`000006ooooo`;o00009?oo
ool2o`0000;ooooo0_l0000<ooooo`;o00000_ooool2o`0000kooooo0_l0000>ooooo`;o00000_oo
ool4o`0000[ooooo0_l000001?oooooo0000o`000?ooool2o`0000Sooooo0_l00004ooooo`;o0000
0_ooool2o`0004_ooooo000Looooo`03o`000?oooooooooo03kooooo0_l00002ooooo`Go00001_oo
ool2o`0000Kooooo5_l00009ooooo`;o00009?ooool2o`0000;ooooo0_l00009ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0000kooooo0ol00009ooooo`?o00001oooool2o`000003ooooool0
003o000000gooooo0ol0000Aooooo`;o0000Boooool001cooooo0_l0000mooooo`Co00000_ooool4
o`0000Oooooo0ol00008oooooa?o00002?ooool3o`0000?ooooo0_l0000Sooooo`;o00001?ooool2
o`0000?ooooo0_l000000ooooooo0000o`000004o`0000Sooooo1?l00003ooooo`;o00001oooool5
o`0000[ooooo0_l00009ooooo`;o00000oooool2o`0005kooooo000Looooo`03o`000?oooooooooo
03cooooo0ol0000>ooooo`?o00002_oooolAo`0000Oooooo1?l00003ooooo`;o00002?ooool2o`00
01Wooooo0_l00004ooooo`;o00001oooool4o`0000Wooooo1Ol0000;ooooo`?o00005oooool2o`00
00?ooooo0_l00002ooooo`;o00005Oooool2o`000003ooooool0003o0000043ooooo000Looooo`03
o`000?oooooooooo03Wooooo0_l00002ooooo`;o00000_ooool2o`0000_ooooo0_l0000>ooooo`[o
00002Oooool5o`0000gooooo0_l0000Jooooo`;o00002Oooool2o`000003ooooool0003o000000Wo
oooo0_l00003ooooo`;o00001?ooool3o`0000;ooooo0_l000000ooooooo0000o`00000Looooo`;o
00000_ooool2o`0000kooooo0_l00004ooooo`Ko0000@?ooool001cooooo00?o0000ooooooooool0
>Oooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o00001oooool3o`00017ooooo
0_l00002ooooo`;o00002Oooool3o`0002_ooooo0_l00006ooooo`;o000000?oooooo`000?l00000
0ol00007ooooo`Co00000oooool>o`0000?ooooo0_l0000Eooooo`Go00000_ooool3o`000003oooo
ool0003o000000Co00001oooool2o`0000Cooooo1Ol00011ooooo`007?ooool00ol0003ooooooooo
o`0jooooo`;o00000_ooool5o`0000;ooooo0_l00008ooooo`;o00007_ooool6o`0000;ooooo0_l0
000<ooooo`;o00007_ooool4o`0000;ooooo0_l00009ooooo`;o00000_oooolAo`0000;ooooo0ol0
000Eooooo`Go000000?oooooo`000?l000002Ol0000?ooooo`?o0000@Oooool001cooooo00?o0000
ooooooooool0>_ooool2o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`;o00008Oooool8
o`0000;ooooo0_l00003ooooo`;o00001oooool2o`0001kooooo0_l00004ooooo`;o00000_ooool2
o`0000Wooooo3ol00004ooooo`;o00001oooool2o`0000[ooooo2ol000000ooooooo0000o`000005
o`0000?ooooo0_l00009ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0>?ooool2o`00
00Oooooo0ol00006ooooo`;o00001_ooool2o`0001Wooooo0ol000000ooooooo0000o`000004oooo
o`;o00000oooool2o`0002gooooo0_l000001?oooooo0000o`000?l00009oooooa7o00001Oooool2
o`0000Cooooo0_l00005ooooo`;o00000_oooolFo`000003ooooool0003o000000Kooooo0_l00000
1?oooooo0000o`000?l00013ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00001oooool2
o`0000Oooooo0_l00006ooooo`;o000000?oooooo`000?l000000_l0000@ooooo`;o000000?ooooo
o`000?l000004_ooool2o`0002cooooo0_l00008ooooo`co00000_ooool5o`0000Gooooo0_l0000;
oooooa[o00000oooool<o`0004?ooooo000Looooo`03o`000?oooooooooo03Oooooo0_l000000ooo
oooo0000o`00000=ooooo`?o00002Oooool5o`0000oooooo1Ol00005ooooo`;o00002oooool2o`00
03;ooooo0ol000000ooooooo0000o`00000Do`0000;ooooo0_l000000ooooooo0000o`000007oooo
oaco00000_ooool:o`0004Gooooo000Looooo`03o`000?oooooooooo03Oooooo0_l000000ooooooo
0000o`00000=ooooo`;o00003?ooool3o`000003ooooool0003o000000?ooooo0_l00003ooooo`Oo
00001oooool4o`0001[ooooo0_l0000Eooooo`;o000000?oooooo`000?l000001oooool3o`000003
ooooool0003o000001Co00001Oooool2o`0000Gooooo8Ol000000ooooooo0000o`000002ooooo`?o
0000A_ooool001cooooo00?o0000ooooooooool0@oooool2o`0001;ooooo5Ol00007ooooo`Go0000
4oooool2o`0000Cooooo1?l0000Cooooo`;o000000?oooooo`000?l000001ooooolJo`0000Wooooo
0_l000000ooooooo0000o`000004o`000003ooooool0003o000001So000000Coooooo`000?l0003o
oooo0ol00017ooooo`007?ooool00ol0003oooooooooo`0gooooo`Co00002?ooool2o`0000?ooooo
0_l000000ooooooo0000o`00000:ooooo`;o000000?oooooo`000?l000002ol00003ooooo`;o0000
1Oooool2o`0000?ooooo0_l0000Cooooo`;o00001_ooool2o`0000Oooooo0_l0000Foooooa[o0000
2OoooolSo`0000Gooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`0gooooo`Ko00001?oo
ool4o`0000?ooooo0_l000000ooooooo0000o`000002o`0000_ooooo0_l000000ooooooo0000o`00
0005o`0000gooooo0_l0000Sooooo`;o00001?ooool2o`0000Cooooo1?l00005ooooo`;o00002_oo
oolGo`0000Sooooo1?l000000ooooooo0000o`00000Ko`0000Kooooo0_l00019ooooo`007?ooool0
0ol0003oooooooooo`0gooooo`?o000000?oooooo`000?l000001?ooool3o`0000Wooooo0_l0000;
ooooo`;o000000?oooooo`000?l000001Ol00005ooooo`;o00009_ooool2o`0000?ooooo0_l0000:
ooooo`Ko00000oooool4o`0000[ooooo5Ol00004ooooo`?o000000?oooooo`000?l000000ooooolL
o`0000?ooooo1_l00019ooooo`007?ooool00ol0003oooooooooo`0gooooo`?o00002?ooool2o`00
00Oooooo0_l00009ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo0_l00006oooo
o`;o00009_ooool2o`0001?ooooo0ol00004ooooo`;o00001?ooool2o`0000?ooooo5_l00002oooo
o`Wo00000_oooolLo`0000;ooooo1ol00019ooooo`007?ooool00ol0003oooooooooo`0gooooo`?o
00004Oooool2o`0000Wooooo0_l0000Kooooo`;o00006oooool2o`0001Gooooo0_l0000:ooooo`?o
00000_oooolEo`000003ooooool0003o000000;o00000oooool4o`0000?ooooo2?l000000ooooooo
0000o`00000@o`000003ooooool0003o000000Go0000B_ooool001cooooo0_l0000hooooo`?o0000
2?ooool2o`0000?ooooo0_l00003ooooo`;o00001?ooool3o`0000;ooooo0_l00005ooooo`;o0000
3?ooool2o`0000Gooooo0_l0000Kooooo`;o00005oooool2o`000004ooooool0003o0000o`0000;o
oooo0_l000001?oooooo0000o`000?l00002oooooaCo000000Coooooo`000?l0003ooooo0ol00002
ooooo`;o00000ooooolOo`0000;ooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`0goooo
o`Go00001_ooool3o`0000;ooooo0_l000000ooooooo0000o`000002o`0000Cooooo1?l000000ooo
oooo0000o`000005ooooo`;o00003?ooool2o`0003[ooooo0ol000001?oooooo0000o`000?l00002
ooooo`;o00000_ooool2o`0000;ooooo4ol00005ooooo`?o00001oooool4o`000003ooooool0003o
000001Ko0000DOooool001cooooo00?o0000ooooooooool0>Oooool3o`0000?ooooo0_l000001?oo
oooo0000o`000?l00005ooooo`;o00001_ooool4o`0001Kooooo0_l00007ooooo`;o00009oooool2
o`0000Sooooo0_l0000?oooooaKo00000oooool2o`0000Sooooo1Ol00002ooooo`Co000000?ooooo
o`000?l000002_l00003ooooo`;o0000D?ooool001cooooo00?o0000ooooooooool0=oooool4o`00
00?ooooo1_l00004ooooo`;o00004oooool3o`0000Cooooo0_l00006ooooo`;o00001oooool2o`00
02?ooooo0_l00002ooooo`;o00002_ooool2o`0000gooooo5_l0000;ooooo`go00000oooool4o`00
0003ooooool0003o000000?ooooo1Ol0001@ooooo`007?ooool00ol0003oooooooooo`0gooooo`Ko
000000?oooooo`000?l000000_l00005ooooo`?o00004oooool3o`0000Cooooo0_l000000ooooooo
0000o`00000Tooooo`;o00002oooool2o`0000kooooo0_l00002ooooo`;o00002oooool?o`000004
ooooool0003o0000ooooo`;o000000?oooooo`000?l000000_ooool4o`000004ooooool0003o0000
ooooo`;o000000?oooooo`000?l000001Ol00004ooooo`Co00000oooool5o`0005;ooooo000Loooo
o`03o`000?oooooooooo03Wooooo1?l0000:ooooo`;o00006Oooool2o`0000?ooooo0_l0000Toooo
o`;o00001oooool2o`0000;ooooo0_l0000Booooo`;o00000oooool2o`0000Oooooo5?l000000ooo
oooo0000o`000002ooooo`Co00001oooool2o`0000?ooooo0_l00004ooooo`Co00000oooool2o`00
05Gooooo000Looooo`03o`000?oooooooooo03Sooooo1Ol00008ooooo`?o00006_ooool2o`0000?o
oooo0_l0000Eooooo`;o00005_ooool2o`0000;ooooo0_l00002ooooo`Co00001Oooool2o`0000[o
oooo0_l00007ooooo`go000000?oooooo`000?l000001Ol00003ooooo`Go0000L?ooool001cooooo
00?o0000ooooooooool0>?ooool2o`000003ooooool0003o000000Sooooo0ol0000Oooooo`;o0000
1Oooool2o`0000;ooooo0_l0000:ooooo`;o00003oooool3o`0000Cooooo0_l00006ooooo`Co0000
1Oooool2o`0000Oooooo0_l000000ooooooo0000o`000009ooooo`;o000000?oooooo`000?l00000
2ol000000ooooooo0000o`000006o`0007;ooooo000Looooo`03o`000?oooooooooo03_ooooo0_l0
0006ooooo`;o0000:Oooool2o`0000;ooooo0_l0000>ooooo`;o00002Oooool5o`0000Sooooo0_l0
000Dooooo`;o00003?ooool2o`0000;ooooo3Ol000000ooooooo0000o`000002o`0007Gooooo000L
ooooo`03o`000?oooooooooo03Wooooo1?l00006ooooo`?o0000:?ooool2o`000003ooooool0003o
000000oooooo0_l00008ooooo`?o00001oooool2o`0000;ooooo0_l00004ooooo`;o00008?ooool3
o`000004ooooool0003o0000o`0000;ooooo1?l00003ooooo`;o0000MOooool001cooooo00?o0000
ooooooooool0>Oooool4o`0000Oooooo0_l0000Xooooo`;o000000?oooooo`000?l000006Oooool5
o`0000Gooooo0_l00008ooooo`?o00007Oooool2o`000003ooooool0003o000000?o00000oooool4
o`0007[ooooo000Looooo`03o`000?oooooooooo03[ooooo0ol0001Booooo`;o00004?ooool2o`00
01cooooo2_l00020ooooo`007?ooool00ol0003oooooooooo`0jooooo`;o000000?oooooo`000?l0
00009?ooool7o`00013ooooo0ol00012ooooo`Oo000000?oooooo`000?l000000_ooool2o`0007co
oooo000Looooo`03o`000?oooooooooo03[ooooo2?l0000Nooooo`oo00002oooool3o`0000Kooooo
0_l0000Gooooo`;o00009_ooool2o`0000Gooooo0_l0001looooo`0000Koooooonk^k_lb<S;o0000
oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000oooo
ooooool0>_ooool8o`0001kooooo2?l000000ooooooo0000o`000009o`0000oooooo0_l00002oooo
o`;o00002_ooool2o`0000Cooooo0_l000000ooooooo0000o`000006ooooo`;o00007_ooool2o`00
08?ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOo
oooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0jooooo`So00007Oooool2o`0000Cooooo0ol0
00001?oooooo0000o`000?l00003ooooo`Go00003_ooool2o`0000?ooooo0_l000000ooooooo0000
o`000007ooooo`;o00001?ooool2o`0000?ooooo1?l00002ooooo`;o0000Xoooool00003ooooool@
413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0?Oooool3o`0001kooooo1?l00004ooooo`;o000000?oooooo`000?l00000
1oooool2o`0000;ooooo1?l00007ooooo`?o00000oooool2o`000003ooooool0003o000000[ooooo
0_l00006ooooo`Co0000Yoooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0001Mooooo`Go00000_ooool4o`000003oooo
ool0003o000000_ooooo1_l00005ooooo`?o00001?ooool2o`0000cooooo0_l00007ooooo`;o0000
Z?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oEEEEo`00
0?l@413oc<c<00Kooooo00?o0000ooooooooool0GOooool3o`0000Cooooo1?l00003ooooo`?o0000
2oooool4o`0000[ooooo0ol00008ooooo`;o00000oooool3o`0000gooooo0_l0002Pooooo`0000?o
oooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o
0000ooooooooool0GOooool4o`0000Cooooo0_l00004ooooo`?o00003Oooool4o`0000Sooooo0_l0
0004ooooo`;o00000oooool2o`0000?ooooo0ol0000=ooooo`;o0000X?ooool00006oooooomgMgOo
V9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo05gooooo
1?l00004ooooo`;o00001?ooool2o`0000oooooo0ol000000ooooooo0000o`00000;ooooo`;o0000
3?ooool3o`0000?ooooo0_l0002Vooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`04
olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0G_ooool2o`0000Gooooo0_l00004oooo
o`;o00000oooool3o`0000Oooooo2?l0000Booooo`;o00001Oooool3o`000003ooooool0003o0000
00;o0000Y_ooool001cooooo00?o0000ooooooooool0GOooool3o`0000Gooooo0_l00009ooooo`?o
00001oooool6o`0000Oooooo0ol0000:ooooo`;o00001Oooool2o`0000;ooooo0ol0000Fooooo`;o
0000Soooool001cooooo00?o0000ooooooooool0G?ooool3o`00017ooooo1?l00002ooooo`;o0000
1?ooool2o`0000;ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00004Oooool6o`0001Oo
oooo0_l0002?ooooo`007?ooool00ol0003oooooooooo`1Looooo`;o000000?oooooo`000?l00000
4Oooool2o`0000;ooooo0_l00002ooooo`;o00001?ooool2o`0000;ooooo0_l0000@ooooo`;o0000
00?oooooo`000?l000000_ooool4o`0001Sooooo0_l0002>ooooo`007?ooool00ol0003ooooooooo
o`1Looooo`;o000000?oooooo`000?l000003oooool2o`0000Sooooo0_l00006ooooo`Go00003ooo
ool2o`000003ooooool0003o000001kooooo0_l0002>ooooo`007?ooool00ol0003oooooooooo`1L
ooooo`Oo00003Oooool5o`0000gooooo0_l000001?oooooo0000o`000?l00008ooooo`;o00001ooo
ool2o`0006gooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`1Kooooo`Wo000000?ooooo
o`000?l000001?ooool2o`000003ooooool0003o000000Wo00003Oooool2o`0000Cooooo0_l00002
ooooo`;o0000M_ooool2o`0003oooooo000Looooo`03o`000?oooooooooo05_ooooo1_l000001?oo
oooo0000o`000?ooool2o`0000?ooooo1_l000000ooooooo0000o`000007o`0000cooooo0_l00004
ooooo`;o00002oooool2o`00023ooooo0_l00018ooooo`;o0000@_ooool001cooooo00?o0000oooo
ooooool0Foooool3o`0000Wooooo5Ol0000:ooooo`?o00004?ooool2o`00023ooooo0_l00018oooo
o`;o0000@_ooool001cooooo00?o0000ooooooooool0Goooool2o`0000Kooooo5_l00009ooooo`?o
00000_ooool2o`000003ooooool0003o000000;o00001oooool2o`00017ooooo0ol0000<ooooo`;o
0000B?ooool2o`000003ooooool0003o000003oooooo000Looooo`03o`000?oooooooooo05oooooo
0_l00009oooooaCo00002Oooool2o`0000;ooooo1ol00007ooooo`;o00003Oooool9o`0000Sooooo
1_l00010ooooo`;o00001?ooool2o`000003ooooool0003o000003oooooo000Looooo`03o`000?oo
oooooooo06Kooooo6_l00002ooooo`?o000000Coooooo`000?l0003o00001?ooool2o`0001Sooooo
3_l00004ooooo`;o000000Coooooo`000?l0003o0000@?ooool2o`0004Sooooo000Looooo`;o0000
G?ooool2o`0000Cooooo0_l00002ooooob3o000000?oooooo`000?l000000oooool2o`0001[ooooo
0_l00003ooooo`oo000000?oooooo`000?l00000@_ooool2o`0004Oooooo000Looooo`03o`000?oo
oooooooo05_ooooo0_l00004ooooo`;o00000_ooool2o`000003ooooool0003o000001So00002Ooo
ool2o`0001Kooooo0_l00004oooooa;o000000?oooooo`000?l00000@_ooool2o`0004Oooooo000L
ooooo`03o`000?oooooooooo05[ooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo7_l0
000<ooooo`;o00001?ooool2o`0000_ooooo7ol0000kooooo`;o00001oooool2o`0004?ooooo000L
ooooo`03o`000?oooooooooo05[ooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo7_l0
000<ooooo`;o000000Coooooo`000?l0003ooooo0_l0000:ooooob3o0000>oooool2o`0000Gooooo
1?l00013ooooo`007?ooool00ol0003oooooooooo`1Rooooo`;o00000_oooolMo`0000;ooooo0_l0
000:ooooo`;o00003?oooolLo`0000?ooooo0_l0000mooooo`;o00000oooool2o`0004Gooooo000L
ooooo`03o`000?oooooooooo05gooooo0_l00003ooooo`;o00001OoooolKo`000004ooooool0003o
0000ooooo`;o00005?oooolMo`0000?ooooo0_l0000mooooo`;o00000oooool2o`0004Gooooo000L
ooooo`03o`000?oooooooooo05gooooo0_l0000;oooooa[o000000Coooooo`000?l0003ooooo0_l0
000Doooooaoo000000?oooooo`000?l00000@?ooool4o`0004Gooooo000Looooo`03o`000?oooooo
oooo05kooooo0ol000001?oooooo0000o`000?l00006oooooa;o000000?oooooo`000?l000000_l0
0005ooooo`?o00004oooool6o`000003ooooool0003o000000?o00000_oooolBo`000003ooooool0
003o0000043ooooo1?l00015ooooo`007?ooool00ol0003oooooooooo`1Looooo`Go000000Cooooo
o`000?l0003o00001ooooolIo`0000;ooooo0ol0000Cooooob3o0000A?ooool2o`0004Kooooo000L
ooooo`03o`000?oooooooooo05cooooo0_l000000ooooooo0000o`000004o`0000Oooooo5?l00002
ooooo`?o00006?oooolIo`000003ooooool0003o000000Ko0000>oooool2o`0000?ooooo0_l00018
ooooo`007?ooool00ol0003oooooooooo`1Kooooo`;o00000_ooool6o`0000Oooooo5_l0000Koooo
oaoo000000?oooooo`000?l00000>oooool2o`0000?ooooo0_l00018ooooo`007?ooool00ol0003o
ooooooooo`1Kooooo`;o00001?ooool2o`0000[ooooo5Ol0000Iooooo`;o00000_ooool2o`000003
ooooool0003o000001[o0000??ooool2o`0004gooooo000Looooo`03o`000?oooooooooo05_ooooo
0_l00007ooooo`;o00001ooooolDo`0001[ooooo0_l000000ooooooo0000o`00000Do`000003oooo
ool0003o000000Oo0000??ooool4o`0004_ooooo000Looooo`03o`000?oooooooooo05_ooooo0_l0
00000ooooooo0000o`000002ooooo`Co00002OoooolAo`0000Wooooo0_l0000@ooooo`;o000000?o
ooooo`000?l000007Ol000000ooooooo0000o`00000kooooo`?o0000Boooool001cooooo00?o0000
ooooooooool0Foooool2o`000003ooooool0003o000000;ooooo1?l0000<ooooo`Go000000Cooooo
o`000?l0003ooooo0_l0000<ooooo`;o00004?ooool7o`000003ooooool0003o000001Go00001?oo
ool2o`00037ooooo0_l00007ooooo`?o0000C?ooool001cooooo00?o0000ooooooooool0Foooool2
o`0000Gooooo0_l0000Dooooo`;o00003oooool2o`0000oooooo7?l000000ooooooo0000o`00000h
ooooo`;o00001oooool3o`0004cooooo000Looooo`;o0000Hoooool5o`0003?ooooo6Ol00002oooo
o`?o00001?ooool2o`00037ooooo0_l00003ooooo`;o000000Coooooo`000?l0003o0000Coooool0
01cooooo00?o0000ooooooooool0Hoooool4o`0003Kooooo5Ol000000ooooooo0000o`000005o`00
00;ooooo0_l0000aooooo`;o000000?oooooo`000?l000000_l000001?oooooo0000o`000?l0001?
ooooo`007?ooool00ol0003oooooooooo`1Looooo`;o00001Oooool2o`0001kooooo0_l0000Eoooo
o`?o00000ooooolEo`0000;ooooo0ol0000eooooo`;o000000?oooooo`000?l000000_l0001Coooo
o`007?ooool00ol0003oooooooooo`1Looooo`Co00001oooool2o`0001[ooooo0_l0000Eoooooa[o
00000oooool2o`0000Cooooo0_l0000`ooooo`;o00000_ooool2o`0005Cooooo000Looooo`03o`00
0?oooooooooo05kooooo0ol00006ooooo`?o00005oooool2o`0001Sooooo6_l00002ooooo`Go0000
00?oooooo`000?l00000=?ooool4o`0005;ooooo000Looooo`03o`000?oooooooooo05oooooo0_l0
0006ooooo`?o00004Oooool3o`0000?ooooo0_l0000Hooooo`;o00001Oooool>o`0000?ooooo0_l0
0002ooooo`Go00009_ooool4o`0000oooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`1O
ooooo`?o00001Oooool2o`0001;ooooo0ol0000Mooooo`?o00001?ooool9o`0000cooooo0ol0000X
ooooo`Co00001?ooool3o`0005cooooo000Looooo`03o`000?oooooooooo063ooooo0_l00007oooo
o`?o00002oooool4o`0000;ooooo0_l0000Looooo`?o00001?ooool2o`000003ooooool0003o0000
00;o00000_ooool2o`0000_ooooo0_l0000Xooooo`;o00001_ooool3o`0005cooooo000Looooo`03
o`000?oooooooooo06Wooooo2_l00002ooooo`[o00007Oooool2o`000003ooooool0003o000000Go
oooo0ol00002ooooo`;o0000<?ooool2o`0006[ooooo000Looooo`03o`000?oooooooooo05oooooo
0_l00009ooooo`Wo000000Coooooo`000?l0003o00001?ooool2o`0001oooooo1Ol0000looooo`;o
00002Oooool3o`0005kooooo000Looooo`03o`000?oooooooooo05oooooo0_l00009ooooo`Co0000
00?oooooo`000?l000001Ol000000ooooooo0000o`00000Tooooo`?o00001?ooool2o`00047ooooo
1?l0001Nooooo`007?ooool00ol0003oooooooooo`1Oooooo`;o00002oooool3o`000004ooooool0
003o0000ooooo`;o00000_ooool2o`0002Cooooo0ol00002ooooo`Go0000>?ooool2o`0000?ooooo
0_l000000ooooooo0000o`000006ooooo`?o0000Eoooool001cooooo00?o0000ooooooooool0KOoo
ool4o`0002cooooo1?l000001?oooooo0000o`000?ooool3o`0003Oooooo0_l00002ooooo`?o0000
2Oooool3o`0005Oooooo000Looooo`03o`000?oooooooooo06Gooooo0ol00007ooooo`?o000000?o
ooooo`000?l00000:_ooool2o`0000Gooooo0_l0000kooooo`;o000000Coooooo`000?l0003o0000
1Oooool4o`0005Oooooo000Looooo`03o`000?oooooooooo06Gooooo0ol00008ooooo`;o000000?o
ooooo`000?l00000:oooool3o`0000?ooooo0_l0000Zooooo`;o00000oooool2o`0000Wooooo0ol0
00001?oooooo0000o`000?l00003ooooo`Co0000FOooool001cooooo00?o0000ooooooooool0X?oo
ool4o`0002kooooo0_l00003ooooo`;o00002Oooool3o`0000;ooooo0_l00003ooooo`;o0000Fooo
ool001cooooo0_l0002Rooooo`Co00001?ooool2o`0000?ooooo0_l00004ooooo`?o00001?ooool2
o`0000cooooo0_l00002ooooo`?o000000Coooooo`000?l0003o00001_ooool2o`0000Oooooo0_l0
0002ooooo`;o00000oooool2o`0005_ooooo000Looooo`03o`000?oooooooooo06Gooooo0_l00002
ooooo`;o0000=oooool6o`000003ooooool0003o000000?ooooo0_l00004ooooo`?o00001?ooool2
o`0000?ooooo0_l00006ooooo`?o00000_ooool3o`000003ooooool0003o000000Oooooo0ol00004
ooooo`Co00000_ooool2o`00063ooooo000Looooo`03o`000?oooooooooo06Gooooo0_l000001?oo
oooo0000o`000?l0000hooooo`Go00004?ooool2o`0000;ooooo0_l00002ooooo`;o00001_ooool3
o`0000Sooooo0_l00003ooooo`;o000000?oooooo`000?l000001?ooool4o`0000;ooooo0_l0001P
ooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o000000?oooooo`000?l00000>_ooool5o`00
00oooooo0_l00002ooooo`Co00001Oooool2o`0000Cooooo0_l00003ooooo`;o000000Coooooo`00
0?l0003o00000_ooool2o`0000?ooooo1?l0001Xooooo`007?ooool00ol0003oooooooooo`1Uoooo
o`;o0000?oooool4o`0000Kooooo0_l00003ooooo`;o00001_ooool3o`0000Gooooo0_l00004oooo
o`;o00000oooool2o`0000;ooooo0_l00007ooooo`Co0000J?ooool001cooooo00?o0000oooooooo
ool0J?ooool5o`0003Wooooo1Ol00003ooooo`Co00000oooool3o`0000Gooooo0_l00006ooooo`;o
00002Oooool2o`0000Wooooo0_l00003ooooo`;o000000?oooooo`000?l00000I?ooool001cooooo
00?o0000ooooooooool0I_ooool7o`0003_ooooo2?l00005ooooo`?o00002oooool2o`0000Kooooo
0_l00003ooooo`;o00002Oooool7o`000003ooooool0003o000006Cooooo000Looooo`03o`000?oo
oooooooo06Kooooo0ol00012ooooo`Go000000?oooooo`000?l000001?l00006ooooo`;o00001?oo
ool2o`0000Kooooo0_l00005ooooo`Co000000Coooooo`000?l0003ooooo0_l000000ooooooo0000
o`000002o`000003ooooool0003o000006Gooooo000Looooo`03o`000?oooooooooo06Oooooo0_l0
0002ooooo`;o0000?oooool9o`000003ooooool0003o000000Gooooo0_l000001?oooooo0000o`00
0?ooool2o`0000Kooooo0_l00005ooooo`Co000000Coooooo`000?l0003ooooo0_l00003ooooo`;o
000000?oooooo`000?l00000IOooool001cooooo00?o0000ooooooooool0Joooool2o`00043ooooo
1_l00003ooooo`Co00001_ooool2o`0000Cooooo1?l000001?oooooo0000o`000?ooool3o`0000?o
oooo1?l00007ooooo`;o0000J?ooool001cooooo00?o0000ooooooooool0[oooool6o`0000;ooooo
1?l0000;ooooo`Co000000Coooooo`000?l0003ooooo0ol00003ooooo`Co000000?oooooo`000?l0
00000_l0001/ooooo`007?ooool00ol0003oooooooooo`1booooo`;o0000??ooool7o`0000;ooooo
0_l0000@ooooo`;o00001oooool2o`000003ooooool0003o000000Co0000K?ooool001cooooo00?o
0000ooooooooool0Koooool2o`000003ooooool0003o000003gooooo2?l0000Kooooo`Go0000L?oo
ool001cooooo00?o0000ooooooooool0K_ooool5o`00043ooooo1_l0000>ooooo`;o00001oooool3
o`000003ooooool0003o000000;o0000LOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Ooo
ool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo06kooooo
1Ol00003ooooo`;o0000??ooool6o`0000_ooooo1?l00007ooooo`?o0000M_ooool00006oooooomg
MgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06oooo
o`03o`000?oooooooooo07Kooooo0ol0000mooooo`So00001?ooool2o`000003ooooool0003o0000
00;o00000_ooool2o`0007cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wo
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo07Oooooo0_l0000noooo
o`Oo00001?ooool3o`0000;ooooo0_l00002ooooo`;o0000O?ooool00003ooooool0003ooooo00;o
oooo00?o0000ooooooooool02Oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0001joooo
o`;o0000?oooool:o`0008Cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wo
oooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo07Sooooo1?l000000ooo
oooo0000o`00000nooooo`Oo0000QOooool00003ooooool@413ooooo00;ooooo00?o410@oooooooo
ool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0N?ooool2o`00
00?ooooo0ol00039ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooookZj^_l000001_ooool00ol0003oooooooooo`1gooooo`;o000000?oooooo`000?l000000_oo
ool2o`000<Wooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@06ooooo`03o`000?oooooooooo07Oooooo0_l000000ooooooo0000o`000005ooooo`;o
0000a_ooool001cooooo00?o0000ooooooooool0POooool2o`000<Kooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`00
0?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom:
ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool001Co
oooo00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o0000ooooooooool0
oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooo
oooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`004_ooool00omEEEGo
IVIVo`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Uoooo
o`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05_ooool4o`000008oa0@4?oooooo
ooooonk^k_lb<S;o0000oa0@4?o<c<`3ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0T?ooool00:Ko
oooo00Go0000ooooooooooooooooo`000009ooooo`Ko00003?ooool00ol0003oooooooooo`02oooo
o`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OlQ8B7oV9RHoooooonHV9So8B4Q093ooooo002V
ooooo`05o`000?ooooooooooooooool000006oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000093ooooo002Vooooo`05o`00
0?ooooooooooooooool000002Oooool6o`0000cooooo00?o0000ooooooooool00_ooool01Ol0003o
V9RHoooooonHV9So8B4Q00?ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P2@ooooo`00Y_ooool01Ol0
003oQhN7oooooonYZJWo000001_ooooo00?o0000ooooooooool00_ooool01Ol0003oEEEEo`000?l@
413oc<c<00?ooooo00Goc<c<o`000?l0003o0000olc<c02@ooooo`00YOooool00ol@413o0000ogMg
M`02o`000003oiRHV?oooooooooo01Wooooo00?o0000ooooooooool00_ooool00omEEEGoQhN7oooo
o`05ooooo`05oa0@4?nj^[[ooooookZj^_l@4100T?ooool00<Kooooo00?o0000ooooooooool00_oo
ool00ooMgMgo410@oiRHV005ooooo`05o`000?nj^[[ooooookZj^_l00000T?ooool00<Cooooo00?o
EEEEofIVI_l000001Oooool01?o<c<coA4A4o`000?l@4103ooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT0T?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(174) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.27803 .45026 Mdot
.30865 .44844 Mdot
.49527 .66818 Mdot
.51031 .35532 Mdot
.75753 .57971 Mdot
.51683 .66513 Mdot
.33498 .63282 Mdot
.35077 .62728 Mdot
.49659 .70845 Mdot
.45275 .37988 Mdot
.36497 .66532 Mdot
.52472 .32024 Mdot
.34663 .63579 Mdot
.52994 .39251 Mdot
.64026 .44957 Mdot
.49098 .24563 Mdot
.33903 .44812 Mdot
.75123 .55133 Mdot
.49081 .2535 Mdot
.50112 .7125 Mdot
.73056 .59879 Mdot
.54077 .38249 Mdot
.30304 .41664 Mdot
.52909 .39087 Mdot
.49698 .24773 Mdot
.30012 .44535 Mdot
.282 .45577 Mdot
.50885 .26288 Mdot
.52793 .33027 Mdot
.37757 .66267 Mdot
.51635 .26889 Mdot
.73627 .45874 Mdot
.5865 .5259 Mdot
.40594 .35348 Mdot
.36249 .62449 Mdot
.31025 .6087 Mdot
.49316 .68981 Mdot
.37718 .64714 Mdot
.32496 .65707 Mdot
.369 .65048 Mdot
.37067 .64808 Mdot
.30137 .43948 Mdot
.36429 .62309 Mdot
.28838 .72626 Mdot
.51957 .38279 Mdot
.39827 .23292 Mdot
.56894 .688 Mdot
.51064 .33969 Mdot
.31227 .41583 Mdot
.46656 .67122 Mdot
.68468 .49407 Mdot
.36226 .64478 Mdot
.60237 .5445 Mdot
.37022 .20904 Mdot
.34379 .62841 Mdot
.49417 .24996 Mdot
.53767 .675 Mdot
.52538 .36046 Mdot
.50431 .34551 Mdot
.40167 .32319 Mdot
.52898 .35139 Mdot
.73409 .58277 Mdot
.35281 .38812 Mdot
.4897 .66145 Mdot
.48151 .70165 Mdot
.37592 .63964 Mdot
.33929 .46572 Mdot
.32624 .61698 Mdot
.50999 .35224 Mdot
.52923 .71413 Mdot
.55475 .35398 Mdot
.36585 .66482 Mdot
.32119 .47291 Mdot
.54992 .3904 Mdot
.27036 .44233 Mdot
.3295 .67031 Mdot
.76086 .56502 Mdot
.29168 .40876 Mdot
.4864 .65545 Mdot
.60866 .39093 Mdot
.54773 .38469 Mdot
.17852 .55879 Mdot
.67619 .39638 Mdot
.29533 .46072 Mdot
.55801 .40699 Mdot
.17733 .50577 Mdot
.57328 .39586 Mdot
.51405 .25266 Mdot
.50593 .25591 Mdot
.58611 .44954 Mdot
.54322 .67645 Mdot
.30782 .42019 Mdot
.53511 .37819 Mdot
.5038 .38042 Mdot
.4467 .37294 Mdot
.54461 .34747 Mdot
.50146 .25221 Mdot
.57761 .55601 Mdot
.35933 .65927 Mdot
.59292 .55987 Mdot
.41069 .62368 Mdot
.58743 .54441 Mdot
.56705 .37193 Mdot
.50958 .68017 Mdot
.30557 .47714 Mdot
.58106 .53893 Mdot
.33498 .6117 Mdot
.53338 .38161 Mdot
.29492 .62495 Mdot
.30098 .41827 Mdot
.507 .27498 Mdot
.72995 .56718 Mdot
.62565 .60017 Mdot
.32545 .46941 Mdot
.45306 .2368 Mdot
.50998 .38777 Mdot
.54653 .3708 Mdot
.30729 .44472 Mdot
.49631 .71402 Mdot
.3954 .68827 Mdot
.32765 .43997 Mdot
.36038 .66221 Mdot
.34025 .44667 Mdot
.57939 .52952 Mdot
.49037 .71091 Mdot
.62573 .54544 Mdot
.5836 .56935 Mdot
.72427 .4736 Mdot
.52292 .33723 Mdot
.57562 .57273 Mdot
.50591 .68575 Mdot
.32526 .44111 Mdot
.35154 .64432 Mdot
.50984 .4094 Mdot
.29324 .45245 Mdot
.33663 .62575 Mdot
.71089 .54912 Mdot
.70416 .54813 Mdot
.31092 .46885 Mdot
.44833 .2469 Mdot
.3661 .62048 Mdot
.31908 .62861 Mdot
.68179 .49288 Mdot
.30171 .46544 Mdot
.70327 .57298 Mdot
.32597 .62386 Mdot
.5693 .77033 Mdot
.50067 .27088 Mdot
.7292 .49179 Mdot
.18572 .56218 Mdot
.68233 .49375 Mdot
.70375 .58987 Mdot
.72348 .57738 Mdot
.33703 .62511 Mdot
.52062 .40974 Mdot
.31951 .46173 Mdot
.29591 .45328 Mdot
.54742 .34077 Mdot
.58644 .53074 Mdot
.51199 .38063 Mdot
.59039 .56197 Mdot
.58568 .5728 Mdot
.52961 .38274 Mdot
.39468 .25228 Mdot
.28411 .44048 Mdot
.54996 .41573 Mdot
.49552 .69663 Mdot
.57764 .58835 Mdot
.35631 .61391 Mdot
.55325 .40859 Mdot
.54718 .42079 Mdot
.52803 .31867 Mdot
.31822 .62918 Mdot
.28935 .5709 Mdot
.50763 .64784 Mdot
.35124 .66925 Mdot
.41363 .62918 Mdot
.51986 .69339 Mdot
.50203 .35434 Mdot
.72284 .56523 Mdot
.61347 .55045 Mdot
.5288 .41007 Mdot
.68514 .49545 Mdot
.49749 .37489 Mdot
.65554 .58361 Mdot
.66376 .57852 Mdot
.18441 .53935 Mdot
.30033 .55639 Mdot
.50692 .38552 Mdot
.50452 .23349 Mdot
.706 .49153 Mdot
.3331 .70481 Mdot
.34919 .64829 Mdot
.54973 .71227 Mdot
.50528 .71675 Mdot
.46245 .7362 Mdot
.46012 .29226 Mdot
.49875 .30282 Mdot
.54985 .3662 Mdot
.59539 .55041 Mdot
.36051 .39458 Mdot
.72407 .57855 Mdot
.33196 .46052 Mdot
.17957 .56146 Mdot
.62831 .35354 Mdot
.50449 .28715 Mdot
.52987 .79293 Mdot
.47363 .67179 Mdot
.5884 .53677 Mdot
.70663 .56535 Mdot
.51808 .36148 Mdot
.28297 .42941 Mdot
.69551 .492 Mdot
.60433 .52425 Mdot
.8458 .47152 Mdot
.33319 .44303 Mdot
.65412 .36972 Mdot
.34193 .63028 Mdot
.53822 .69373 Mdot
.57316 .39627 Mdot
.53741 .39773 Mdot
.33813 .42374 Mdot
.50859 .4025 Mdot
.51647 .28264 Mdot
.50207 .26718 Mdot
.46347 .6741 Mdot
.39651 .60407 Mdot
.33744 .66375 Mdot
.57189 .67174 Mdot
.32174 .47083 Mdot
.38741 .233 Mdot
.52239 .67986 Mdot
.68413 .58409 Mdot
.3709 .66123 Mdot
.70563 .55153 Mdot
.51803 .67601 Mdot
.75637 .58068 Mdot
.50171 .35216 Mdot
.51635 .70156 Mdot
.73932 .57151 Mdot
.56101 .45201 Mdot
.58104 .54233 Mdot
.78606 .56851 Mdot
.33094 .63436 Mdot
.33446 .42585 Mdot
.5292 .41076 Mdot
.60619 .54913 Mdot
.61342 .52554 Mdot
.62653 .43148 Mdot
.61049 .57102 Mdot
.60068 .5262 Mdot
.60335 .44386 Mdot
.74086 .54702 Mdot
.2508 .51681 Mdot
.51541 .27233 Mdot
.33918 .45155 Mdot
.50624 .392 Mdot
.3632 .57981 Mdot
.33465 .62552 Mdot
.52108 .35583 Mdot
.17705 .54403 Mdot
.32825 .63756 Mdot
.53377 .36564 Mdot
.33606 .66692 Mdot
.29364 .45624 Mdot
.63198 .34803 Mdot
.31864 .47459 Mdot
.52884 .37959 Mdot
.34247 .66992 Mdot
.55325 .70877 Mdot
.29951 .44735 Mdot
.53682 .38094 Mdot
.53393 .34692 Mdot
.59767 .54886 Mdot
.50112 .26804 Mdot
.4057 .65281 Mdot
.52898 .32312 Mdot
.52189 .65591 Mdot
.53845 .33796 Mdot
.69306 .55005 Mdot
.61703 .76885 Mdot
.30388 .46737 Mdot
.61379 .57009 Mdot
.52644 .67257 Mdot
.53182 .44789 Mdot
.64762 .35359 Mdot
.52146 .38631 Mdot
.61309 .53336 Mdot
.67482 .373 Mdot
.33302 .65267 Mdot
.51084 .28074 Mdot
.59912 .59241 Mdot
.5368 .67185 Mdot
.58945 .54555 Mdot
.5623 .37803 Mdot
.29188 .4189 Mdot
.49266 .24721 Mdot
.52683 .69561 Mdot
.33531 .43813 Mdot
.57028 .38554 Mdot
.41329 .63641 Mdot
.60882 .58246 Mdot
.33714 .65641 Mdot
.5128 .26376 Mdot
.50192 .35541 Mdot
.52626 .71344 Mdot
.30046 .4376 Mdot
.34665 .62733 Mdot
.31753 .47286 Mdot
.61475 .47699 Mdot
.65885 .37582 Mdot
.32998 .47715 Mdot
.72981 .54843 Mdot
.57515 .81588 Mdot
.35746 .666 Mdot
.60941 .56217 Mdot
.56376 .68349 Mdot
.28735 .41759 Mdot
.51275 .67428 Mdot
.44419 .26047 Mdot
.5424 .67683 Mdot
.48944 .2597 Mdot
.5525 .70482 Mdot
.48934 .29456 Mdot
.54583 .41238 Mdot
.47162 .68924 Mdot
.57637 .55379 Mdot
.55924 .38871 Mdot
.29241 .45031 Mdot
.73459 .44859 Mdot
.43507 .33463 Mdot
.46231 .2895 Mdot
.53652 .67662 Mdot
.44023 .25795 Mdot
.50678 .27051 Mdot
.51125 .26189 Mdot
.31899 .45838 Mdot
.61067 .56016 Mdot
.68196 .56442 Mdot
.69041 .57337 Mdot
.68617 .73861 Mdot
.66709 .32723 Mdot
.45756 .23079 Mdot
.30013 .45657 Mdot
.506 .77704 Mdot
.28289 .46333 Mdot
.60366 .52459 Mdot
.35114 .62733 Mdot
.28521 .58125 Mdot
.57407 .38763 Mdot
.66335 .55944 Mdot
.51779 .28457 Mdot
.33025 .42498 Mdot
.34519 .46718 Mdot
.34742 .6269 Mdot
.46217 .28407 Mdot
.4535 .37775 Mdot
.51154 .36865 Mdot
.34824 .62334 Mdot
.60998 .52458 Mdot
.54062 .43932 Mdot
.73869 .47515 Mdot
.32189 .77263 Mdot
.52311 .38154 Mdot
.39258 .45379 Mdot
.53267 .40992 Mdot
.71986 .47773 Mdot
.51904 .36568 Mdot
.2968 .43983 Mdot
.50042 .2095 Mdot
.55325 .43766 Mdot
.53686 .79646 Mdot
.62642 .35794 Mdot
.75033 .5676 Mdot
.53487 .39088 Mdot
.51447 .38958 Mdot
.695 .56783 Mdot
.30229 .42624 Mdot
.50951 .34679 Mdot
.25746 .51787 Mdot
.53838 .37771 Mdot
.35086 .61027 Mdot
.65919 .42298 Mdot
.73305 .45931 Mdot
.5046 .26647 Mdot
.29392 .41794 Mdot
.3205 .63905 Mdot
.37336 .64432 Mdot
.61882 .56281 Mdot
.33386 .62552 Mdot
.53917 .41039 Mdot
.65802 .42374 Mdot
.33724 .46871 Mdot
.58426 .53776 Mdot
.31441 .42325 Mdot
.52537 .73447 Mdot
.33311 .63696 Mdot
.59642 .53868 Mdot
.45028 .30739 Mdot
.33716 .64722 Mdot
.42558 .64071 Mdot
.50953 .27613 Mdot
.61157 .52525 Mdot
.27681 .44556 Mdot
.53544 .71286 Mdot
.60993 .52897 Mdot
.34367 .62778 Mdot
.51958 .38406 Mdot
.49494 .25493 Mdot
.33445 .62425 Mdot
.34497 .50227 Mdot
.51562 .2768 Mdot
.53845 .37506 Mdot
.28819 .44081 Mdot
.31868 .43534 Mdot
.54746 .41649 Mdot
.5109 .40126 Mdot
.524 .66308 Mdot
.6165 .5353 Mdot
.61875 .53651 Mdot
.5916 .57372 Mdot
.54073 .6842 Mdot
.55788 .81245 Mdot
.32236 .6163 Mdot
.73206 .45786 Mdot
.31105 .55932 Mdot
.60675 .54465 Mdot
.52026 .66176 Mdot
.5244 .40046 Mdot
.55704 .34834 Mdot
.34609 .6715 Mdot
.66048 .79926 Mdot
.57329 .37464 Mdot
.33768 .46167 Mdot
.35937 .63154 Mdot
.51198 .31024 Mdot
.45869 .7286 Mdot
.74702 .57879 Mdot
.45625 .2303 Mdot
.35995 .63402 Mdot
.30126 .50326 Mdot
.36045 .63523 Mdot
.51546 .39024 Mdot
.55955 .37324 Mdot
.34101 .43107 Mdot
.75042 .56627 Mdot
.53535 .32888 Mdot
.52956 .36752 Mdot
.5166 .78604 Mdot
.29241 .47295 Mdot
.68891 .57307 Mdot
.52155 .32761 Mdot
.57999 .55693 Mdot
.75607 .57104 Mdot
.55158 .38137 Mdot
.54205 .3395 Mdot
.56954 .55335 Mdot
.36483 .67252 Mdot
.73972 .5535 Mdot
.5388 .79807 Mdot
.33511 .44777 Mdot
.39352 .66876 Mdot
.62955 .55049 Mdot
.35905 .66561 Mdot
.48468 .3779 Mdot
.59173 .53769 Mdot
.26743 .64647 Mdot
.77105 .26759 Mdot
.60245 .52888 Mdot
.52532 .6596 Mdot
.4439 .36891 Mdot
.54019 .33584 Mdot
.53798 .37426 Mdot
.67926 .56044 Mdot
.31508 .44227 Mdot
.30043 .55678 Mdot
.34659 .66914 Mdot
.53728 .40227 Mdot
.30896 .47141 Mdot
.18038 .52922 Mdot
.5931 .54524 Mdot
.73611 .56194 Mdot
.72105 .55108 Mdot
.55285 .39205 Mdot
.67268 .3536 Mdot
.29822 .44817 Mdot
.53651 .38107 Mdot
.55551 .38434 Mdot
.5577 .69162 Mdot
.28838 .45475 Mdot
.51609 .7004 Mdot
.50239 .28435 Mdot
.47554 .22664 Mdot
.35467 .57575 Mdot
.32734 .63261 Mdot
.62346 .54864 Mdot
.33748 .66321 Mdot
.5433 .65651 Mdot
.61868 .53694 Mdot
.53676 .38192 Mdot
.33776 .46858 Mdot
.53596 .38053 Mdot
.53756 .37758 Mdot
.51628 .37661 Mdot
.45867 .22657 Mdot
.49538 .65242 Mdot
.72732 .56038 Mdot
.51257 .33259 Mdot
.53316 .69094 Mdot
.48046 .75494 Mdot
.45183 .381 Mdot
.5402 .39084 Mdot
.54342 .36875 Mdot
.27677 .41371 Mdot
.49956 .27166 Mdot
.33898 .64594 Mdot
.33986 .42962 Mdot
.57195 .40121 Mdot
.57086 .67961 Mdot
.50721 .35117 Mdot
.32839 .47721 Mdot
.32637 .61208 Mdot
.35129 .37828 Mdot
.62901 .5387 Mdot
.62531 .55105 Mdot
.60653 .52829 Mdot
.59762 .57426 Mdot
.35546 .61401 Mdot
.51554 .66136 Mdot
.57486 .67853 Mdot
.55008 .32909 Mdot
.51131 .40384 Mdot
.56068 .37612 Mdot
.56132 .6898 Mdot
.57405 .54119 Mdot
.4469 .28445 Mdot
.51884 .29719 Mdot
.53864 .69988 Mdot
.57935 .56209 Mdot
.22517 .42104 Mdot
.31956 .42207 Mdot
.513 .64841 Mdot
.3761 .65171 Mdot
.74232 .57213 Mdot
.76258 .68188 Mdot
.32103 .42898 Mdot
.36627 .39913 Mdot
.5014 .69384 Mdot
.64052 .4278 Mdot
.36899 .20277 Mdot
.51151 .6714 Mdot
.51843 .27694 Mdot
.31206 .46179 Mdot
.57885 .54979 Mdot
.67425 .37772 Mdot
.65071 .42206 Mdot
.51023 .7092 Mdot
.53207 .34523 Mdot
.47735 .71053 Mdot
.53334 .66531 Mdot
.6202 .55205 Mdot
.53624 .67749 Mdot
.33027 .65181 Mdot
.51034 .68738 Mdot
.3377 .50378 Mdot
.51587 .34411 Mdot
.3695 .20835 Mdot
.6741 .44417 Mdot
.50962 .39049 Mdot
.34828 .65506 Mdot
.41183 .64604 Mdot
.51789 .35231 Mdot
.73499 .58815 Mdot
.52259 .65934 Mdot
.45271 .71066 Mdot
.49251 .26049 Mdot
.55133 .70478 Mdot
.28941 .41954 Mdot
.41051 .62137 Mdot
.41261 .62694 Mdot
.61036 .52982 Mdot
.29674 .45981 Mdot
.33024 .67144 Mdot
.36014 .66171 Mdot
.5999 .58537 Mdot
.53549 .41418 Mdot
.28643 .4313 Mdot
.55679 .44526 Mdot
.5995 .59601 Mdot
.53955 .37863 Mdot
.51506 .69894 Mdot
.46975 .66711 Mdot
.65442 .44772 Mdot
.52492 .67994 Mdot
.62049 .55443 Mdot
.28575 .43969 Mdot
.49117 .25664 Mdot
.32377 .43803 Mdot
.50461 .38809 Mdot
.38321 .59302 Mdot
.31486 .41945 Mdot
.68357 .58382 Mdot
.53231 .35405 Mdot
.39582 .2486 Mdot
.51597 .32873 Mdot
.53944 .37568 Mdot
.48304 .70573 Mdot
.69681 .56825 Mdot
.65368 .57039 Mdot
.46599 .73849 Mdot
.73248 .58527 Mdot
.3615 .47328 Mdot
.49044 .71198 Mdot
.70152 .5572 Mdot
.69036 .7377 Mdot
.61557 .56971 Mdot
.71704 .55622 Mdot
.55724 .40781 Mdot
.32747 .62774 Mdot
.34727 .45345 Mdot
.55936 .39189 Mdot
.47426 .26892 Mdot
.49076 .27903 Mdot
.5971 .54617 Mdot
.54027 .3727 Mdot
.51406 .39201 Mdot
.31031 .47176 Mdot
.18491 .56491 Mdot
.5088 .65612 Mdot
.59836 .56276 Mdot
.32505 .43339 Mdot
.17802 .55775 Mdot
.47924 .69863 Mdot
.69463 .5561 Mdot
.32758 .65759 Mdot
.28782 .49781 Mdot
.60147 .54676 Mdot
.33279 .6334 Mdot
.45682 .68822 Mdot
.67073 .49399 Mdot
.49907 .23934 Mdot
.49752 .68043 Mdot
.68249 .49405 Mdot
.50203 .28145 Mdot
.46772 .7434 Mdot
.33457 .70415 Mdot
.30236 .41854 Mdot
.33702 .62252 Mdot
.74024 .56161 Mdot
.32605 .47342 Mdot
.31434 .42298 Mdot
.32609 .63431 Mdot
.44481 .19133 Mdot
.67303 .37298 Mdot
.3134 .64076 Mdot
.62469 .43532 Mdot
.6749 .49319 Mdot
.6017 .5496 Mdot
.72503 .56333 Mdot
.39644 .60404 Mdot
.30139 .44004 Mdot
.29443 .5721 Mdot
.68812 .49486 Mdot
.50934 .27916 Mdot
.74103 .57428 Mdot
.18431 .52906 Mdot
.29427 .67993 Mdot
.33671 .64296 Mdot
.51562 .78524 Mdot
.72035 .58506 Mdot
.55098 .41184 Mdot
.68131 .79074 Mdot
.54912 .40921 Mdot
.32729 .62026 Mdot
.51746 .28452 Mdot
.32998 .45393 Mdot
.32167 .62047 Mdot
.50703 .28975 Mdot
.52841 .32405 Mdot
.50828 .3716 Mdot
.48676 .65482 Mdot
.33509 .42284 Mdot
.63028 .55989 Mdot
.51078 .39344 Mdot
.52963 .36431 Mdot
.60787 .52228 Mdot
.73168 .46165 Mdot
.47738 .61509 Mdot
.58293 .5307 Mdot
.52366 .70423 Mdot
.58362 .53799 Mdot
.60222 .56225 Mdot
.27476 .43608 Mdot
.49463 .76859 Mdot
.62172 .53226 Mdot
.52659 .37878 Mdot
.53215 .37728 Mdot
.3236 .65514 Mdot
.67455 .37373 Mdot
.6428 .42502 Mdot
.51699 .65545 Mdot
.60526 .58924 Mdot
.54691 .35369 Mdot
.29478 .45921 Mdot
.67473 .56295 Mdot
.61691 .56294 Mdot
.33691 .44945 Mdot
.52149 .33572 Mdot
.55811 .69202 Mdot
.60075 .53022 Mdot
.60537 .5197 Mdot
.73644 .57302 Mdot
.31599 .63661 Mdot
.30647 .40801 Mdot
.53017 .66273 Mdot
.50799 .24354 Mdot
.6284 .57525 Mdot
.55284 .68911 Mdot
.60091 .55106 Mdot
.58314 .54786 Mdot
.29657 .45788 Mdot
.30766 .50537 Mdot
.58361 .51894 Mdot
.53823 .68543 Mdot
.29486 .74509 Mdot
.3649 .64858 Mdot
.50508 .34605 Mdot
.32803 .65454 Mdot
.29973 .41858 Mdot
.72617 .47408 Mdot
.71046 .55153 Mdot
.33418 .64446 Mdot
.59824 .5251 Mdot
.31461 .4214 Mdot
.33229 .41827 Mdot
.52801 .3833 Mdot
.54034 .38509 Mdot
.56951 .68644 Mdot
.71788 .49048 Mdot
.33532 .66772 Mdot
.68301 .56345 Mdot
.50073 .66283 Mdot
.49359 .25505 Mdot
.32343 .4628 Mdot
.79412 .56406 Mdot
.51181 .33134 Mdot
.53424 .68799 Mdot
.3083 .45113 Mdot
.69049 .57229 Mdot
.72646 .55926 Mdot
.52162 .40581 Mdot
.70191 .58883 Mdot
.33048 .64466 Mdot
.2933 .44795 Mdot
.38167 .42889 Mdot
.51431 .33312 Mdot
.53834 .38853 Mdot
.50682 .27974 Mdot
.31286 .6364 Mdot
.55549 .40876 Mdot
.74627 .56282 Mdot
.32405 .46747 Mdot
.52852 .40576 Mdot
.71466 .58322 Mdot
.62273 .568 Mdot
.5936 .53443 Mdot
.47203 .69452 Mdot
.71897 .58829 Mdot
.70774 .57888 Mdot
.72014 .58619 Mdot
.28482 .58207 Mdot
.51817 .31407 Mdot
.62408 .51507 Mdot
.53647 .34827 Mdot
.67124 .49288 Mdot
.50626 .24002 Mdot
.35722 .657 Mdot
.52475 .71288 Mdot
.51324 .37389 Mdot
.53886 .35076 Mdot
.30534 .41056 Mdot
.48893 .24819 Mdot
.54872 .41529 Mdot
.33019 .45815 Mdot
.37923 .42155 Mdot
.52724 .71919 Mdot
.18533 .56087 Mdot
.72766 .75875 Mdot
.50007 .3977 Mdot
.64598 .4283 Mdot
.3042 .424 Mdot
.32566 .65645 Mdot
.62985 .43325 Mdot
.31688 .63196 Mdot
.31392 .43634 Mdot
.4868 .24931 Mdot
.3471 .50155 Mdot
.7367 .58294 Mdot
.51573 .38931 Mdot
.32569 .63836 Mdot
.51347 .38523 Mdot
.324 .64213 Mdot
.43399 .26375 Mdot
.67687 .38938 Mdot
.51307 .4087 Mdot
.54367 .34612 Mdot
.74235 .5995 Mdot
.54039 .38826 Mdot
.52942 .79655 Mdot
.3129 .45446 Mdot
.59034 .58826 Mdot
.48638 .24277 Mdot
.43503 .33717 Mdot
.54394 .37176 Mdot
.49046 .28064 Mdot
.54657 .36729 Mdot
.64657 .80344 Mdot
.4988 .36266 Mdot
.53807 .41393 Mdot
.35374 .64773 Mdot
.36688 .66177 Mdot
.32015 .41263 Mdot
.58513 .54482 Mdot
.18417 .53455 Mdot
.53342 .367 Mdot
.48049 .67494 Mdot
.58848 .60033 Mdot
.70187 .57548 Mdot
.33097 .46635 Mdot
.76381 .25319 Mdot
.36438 .62256 Mdot
.50362 .70267 Mdot
.51718 .26824 Mdot
.52071 .70303 Mdot
.4981 .65681 Mdot
.37503 .45522 Mdot
.72614 .56293 Mdot
.50392 .36156 Mdot
.40598 .34874 Mdot
.35944 .38765 Mdot
.51435 .3333 Mdot
.4954 .71617 Mdot
.56944 .55126 Mdot
.59735 .28119 Mdot
.75324 .55363 Mdot
.71342 .5767 Mdot
.3387 .62861 Mdot
.47848 .67726 Mdot
.59786 .56185 Mdot
.70365 .55449 Mdot
.53812 .71696 Mdot
.61643 .56768 Mdot
.50902 .78065 Mdot
.29748 .44774 Mdot
.44135 .25863 Mdot
.39656 .22824 Mdot
.34194 .65915 Mdot
.47691 .75293 Mdot
.33566 .47065 Mdot
.31453 .47537 Mdot
.59551 .55463 Mdot
.53765 .70271 Mdot
.35215 .47356 Mdot
.52251 .40484 Mdot
.58334 .54048 Mdot
.5482 .40179 Mdot
.73535 .54439 Mdot
.53385 .37158 Mdot
.54559 .71241 Mdot
.34963 .65167 Mdot
.5339 .67148 Mdot
.33575 .62944 Mdot
.73348 .45448 Mdot
.53212 .3577 Mdot
.53565 .38858 Mdot
.65738 .42343 Mdot
.27895 .43719 Mdot
.40681 .35794 Mdot
.53594 .68394 Mdot
.53524 .67369 Mdot
.48681 .24252 Mdot
.34168 .44962 Mdot
.60033 .51375 Mdot
.62174 .43711 Mdot
.54819 .3694 Mdot
.31363 .45308 Mdot
.50621 .2387 Mdot
.27217 .69835 Mdot
.67497 .39997 Mdot
.27718 .43203 Mdot
.53377 .80123 Mdot
.55571 .37444 Mdot
.60097 .56551 Mdot
.57961 .57621 Mdot
.6724 .34347 Mdot
.65116 .57182 Mdot
.33402 .4437 Mdot
.59051 .55972 Mdot
.32037 .46335 Mdot
.54197 .67232 Mdot
.32938 .60802 Mdot
.3225 .45662 Mdot
.54335 .36336 Mdot
.72888 .7571 Mdot
.32317 .63427 Mdot
.51963 .39197 Mdot
.32641 .61564 Mdot
.34985 .46085 Mdot
.32347 .44492 Mdot
.61656 .56748 Mdot
.517 .27897 Mdot
.332 .64491 Mdot
.51755 .4086 Mdot
.38294 .47078 Mdot
.49255 .24711 Mdot
.584 .59267 Mdot
.54509 .35091 Mdot
.52583 .33322 Mdot
.54687 .8069 Mdot
.5394 .45169 Mdot
.36641 .58141 Mdot
.32103 .60437 Mdot
.28797 .57054 Mdot
.28024 .44956 Mdot
.71684 .54355 Mdot
.32093 .412 Mdot
.6245 .54474 Mdot
.51875 .70598 Mdot
.5163 .38045 Mdot
.60754 .5742 Mdot
.31387 .64748 Mdot
.71284 .55867 Mdot
.49749 .37496 Mdot
.49293 .67924 Mdot
.59119 .56872 Mdot
.3345 .63889 Mdot
.30327 .43655 Mdot
.33362 .45362 Mdot
.49724 .77181 Mdot
.52728 .40514 Mdot
.53893 .38344 Mdot
.34612 .61259 Mdot
.68484 .58103 Mdot
.73395 .58597 Mdot
.57625 .55347 Mdot
.33569 .61045 Mdot
.6754 .39892 Mdot
.34055 .42584 Mdot
.51868 .39726 Mdot
.66251 .42247 Mdot
.29318 .56288 Mdot
.2613 .39492 Mdot
.72194 .58036 Mdot
.65292 .35222 Mdot
.3335 .44287 Mdot
.35274 .64259 Mdot
.68459 .74128 Mdot
.50368 .27916 Mdot
.5174 .3489 Mdot
.64488 .34504 Mdot
.62067 .43454 Mdot
.51602 .25795 Mdot
.63011 .54519 Mdot
.66063 .38728 Mdot
.48854 .23957 Mdot
.49993 .24165 Mdot
.55272 .35895 Mdot
.54714 .35216 Mdot
.31786 .4496 Mdot
.46453 .2879 Mdot
.50792 .69433 Mdot
.52194 .26519 Mdot
.76988 .58935 Mdot
.51133 .27462 Mdot
.55351 .34674 Mdot
.23827 .40962 Mdot
.65154 .30531 Mdot
.30798 .45869 Mdot
.28284 .41993 Mdot
.34216 .66055 Mdot
.49099 .24965 Mdot
.53589 .68634 Mdot
.56979 .54033 Mdot
.53473 .71058 Mdot
.3158 .44914 Mdot
.51829 .7195 Mdot
.37819 .64359 Mdot
.4973 .68054 Mdot
.53437 .70137 Mdot
.35312 .65196 Mdot
.33595 .42454 Mdot
.51741 .32692 Mdot
.35265 .6526 Mdot
.59903 .51864 Mdot
.69791 .55393 Mdot
.37304 .40674 Mdot
.57867 .5416 Mdot
.57065 .36699 Mdot
.29084 .73618 Mdot
.49325 .6885 Mdot
.63418 .34665 Mdot
.32103 .4186 Mdot
.75881 .59188 Mdot
.324 .45419 Mdot
.5865 .51682 Mdot
.72972 .58019 Mdot
.55977 .40349 Mdot
.78728 .57737 Mdot
.34509 .70198 Mdot
.54847 .43572 Mdot
.37953 .42234 Mdot
.53948 .70834 Mdot
.33736 .65399 Mdot
.40445 .66815 Mdot
.59683 .56302 Mdot
.29423 .41713 Mdot
.28784 .50269 Mdot
.62156 .53981 Mdot
.35091 .64501 Mdot
.39856 .27383 Mdot
.51696 .39955 Mdot
.33419 .65817 Mdot
.54224 .34847 Mdot
.45091 .24271 Mdot
.67304 .56266 Mdot
.59058 .57425 Mdot
.48745 .25366 Mdot
.48134 .70012 Mdot
.4864 .24475 Mdot
.47102 .27191 Mdot
.72901 .48292 Mdot
.5412 .35486 Mdot
.63727 .34532 Mdot
.54512 .65882 Mdot
.31534 .46644 Mdot
.61003 .5396 Mdot
.59959 .54894 Mdot
.49062 .26701 Mdot
.80603 .66758 Mdot
.70483 .5598 Mdot
.52678 .79596 Mdot
.53338 .35972 Mdot
.54706 .38414 Mdot
.31743 .41083 Mdot
.43415 .26817 Mdot
.57824 .55571 Mdot
.52461 .34651 Mdot
.65913 .31236 Mdot
.35663 .63847 Mdot
.56716 .37634 Mdot
.55149 .39459 Mdot
.40394 .61059 Mdot
.35392 .64594 Mdot
.55188 .67839 Mdot
.6193 .56724 Mdot
.47182 .69678 Mdot
.75721 .57779 Mdot
.65358 .36596 Mdot
.73093 .46727 Mdot
.67188 .40278 Mdot
.74647 .58359 Mdot
.50487 .26954 Mdot
.56378 .35054 Mdot
.51724 .34475 Mdot
.71001 .57329 Mdot
.37589 .66702 Mdot
.31596 .45383 Mdot
.44644 .24982 Mdot
.59835 .55058 Mdot
.50533 .24358 Mdot
.7618 .57076 Mdot
.31757 .46226 Mdot
.39443 .2552 Mdot
.3151 .44368 Mdot
.33866 .6399 Mdot
.47026 .74606 Mdot
.73296 .58084 Mdot
.32446 .45466 Mdot
.49038 .70836 Mdot
.37864 .5901 Mdot
.51691 .31114 Mdot
.37885 .6464 Mdot
.35776 .4775 Mdot
.28033 .42418 Mdot
.27715 .4514 Mdot
.4929 .26737 Mdot
.63626 .34628 Mdot
.62329 .55068 Mdot
.32954 .6103 Mdot
.48064 .69345 Mdot
.71929 .48883 Mdot
.39869 .29686 Mdot
.65584 .40095 Mdot
.56306 .38305 Mdot
.53299 .37238 Mdot
.55269 .38663 Mdot
.62533 .53172 Mdot
.56954 .35918 Mdot
.54312 .35446 Mdot
.34474 .67129 Mdot
.55215 .68234 Mdot
.53052 .36085 Mdot
.59741 .53377 Mdot
.66184 .56038 Mdot
.75988 .59148 Mdot
.46114 .21762 Mdot
.3665 .4041 Mdot
.32007 .45972 Mdot
.52744 .6943 Mdot
.48194 .70856 Mdot
.71037 .54873 Mdot
.34916 .6256 Mdot
.31501 .44122 Mdot
.64266 .80347 Mdot
.74237 .57964 Mdot
.52377 .37901 Mdot
.65859 .42278 Mdot
.66037 .32029 Mdot
.54321 .33658 Mdot
.51599 .37451 Mdot
.59346 .52741 Mdot
.53596 .68982 Mdot
.49471 .29873 Mdot
.39537 .25381 Mdot
.7172 .58346 Mdot
.68927 .56058 Mdot
.29606 .47079 Mdot
.52197 .41184 Mdot
.32641 .63819 Mdot
.67497 .3705 Mdot
.40921 .64756 Mdot
.18032 .50462 Mdot
.53227 .72746 Mdot
.50542 .35568 Mdot
.43803 .35869 Mdot
.57421 .3869 Mdot
.30516 .47694 Mdot
.31411 .50452 Mdot
.30308 .45807 Mdot
.3549 .63406 Mdot
.65035 .49049 Mdot
.37174 .64741 Mdot
.58013 .56257 Mdot
.32663 .42695 Mdot
.55088 .44422 Mdot
.53492 .67443 Mdot
.49211 .24238 Mdot
.72312 .56934 Mdot
.58451 .44832 Mdot
.60884 .54243 Mdot
.65341 .35653 Mdot
.51947 .66195 Mdot
.35011 .43837 Mdot
.4919 .24158 Mdot
.46221 .73226 Mdot
.6613 .39184 Mdot
.56623 .70727 Mdot
.60866 .57445 Mdot
.73452 .58275 Mdot
.45443 .38457 Mdot
.74601 .57383 Mdot
.33144 .64302 Mdot
.53093 .35551 Mdot
.53577 .41342 Mdot
.54254 .37602 Mdot
.56019 .39619 Mdot
.34774 .62948 Mdot
.50202 .247 Mdot
.58418 .52243 Mdot
.60221 .57346 Mdot
.51497 .27177 Mdot
.71995 .56082 Mdot
.36326 .65193 Mdot
.55387 .69038 Mdot
.60744 .52627 Mdot
.7536 .56255 Mdot
.53827 .42797 Mdot
.53326 .35015 Mdot
.58881 .57011 Mdot
.55801 .40622 Mdot
.50297 .25054 Mdot
.50158 .68339 Mdot
.51059 .25059 Mdot
.76153 .59032 Mdot
.7274 .57233 Mdot
.33141 .62556 Mdot
.32464 .45578 Mdot
.72604 .5499 Mdot
.50322 .66364 Mdot
.57001 .40223 Mdot
.54708 .35293 Mdot
.33542 .50416 Mdot
.68686 .49536 Mdot
.75522 .59259 Mdot
.55381 .41092 Mdot
.29101 .45929 Mdot
.27121 .49314 Mdot
.52006 .34704 Mdot
.50628 .25839 Mdot
.27395 .43685 Mdot
.70099 .55392 Mdot
.34473 .62193 Mdot
.67856 .44714 Mdot
.31984 .62655 Mdot
.30244 .43577 Mdot
.5906 .55729 Mdot
.33446 .42463 Mdot
.59477 .5628 Mdot
.19913 .46116 Mdot
.54632 .35555 Mdot
.35562 .49709 Mdot
.57451 .53601 Mdot
.53835 .67758 Mdot
.54568 .69335 Mdot
.60348 .53093 Mdot
.33423 .43928 Mdot
.62096 .55277 Mdot
.74342 .56643 Mdot
.29172 .56857 Mdot
.27401 .4305 Mdot
.53553 .70136 Mdot
.49228 .68683 Mdot
.33527 .61008 Mdot
.53775 .37063 Mdot
.5177 .39684 Mdot
.49892 .67691 Mdot
.40791 .64979 Mdot
.29971 .42162 Mdot
.53826 .3836 Mdot
.58797 .52567 Mdot
.50471 .69039 Mdot
.3157 .7 Mdot
.35283 .45732 Mdot
.4867 .25321 Mdot
.73049 .48059 Mdot
.33747 .60551 Mdot
.57265 .38792 Mdot
.50255 .25234 Mdot
.70117 .5669 Mdot
.65107 .34841 Mdot
.67992 .49268 Mdot
.3706 .62995 Mdot
.62491 .55124 Mdot
.54507 .33784 Mdot
.54465 .68243 Mdot
.56472 .40911 Mdot
.78354 .30696 Mdot
.58689 .57109 Mdot
.53174 .40426 Mdot
.57992 .57262 Mdot
.32445 .43845 Mdot
.54213 .38133 Mdot
.35901 .57801 Mdot
.5255 .69192 Mdot
.52642 .40393 Mdot
.72119 .59685 Mdot
.32529 .61786 Mdot
.60795 .54184 Mdot
.73024 .58491 Mdot
.5194 .26651 Mdot
.73426 .44912 Mdot
.56157 .6889 Mdot
.72532 .55703 Mdot
.53931 .36909 Mdot
.50017 .6619 Mdot
.36397 .6642 Mdot
.60955 .53688 Mdot
.54566 .43297 Mdot
.35723 .66097 Mdot
.35881 .64406 Mdot
.73757 .57688 Mdot
.38384 .23222 Mdot
.50808 .40658 Mdot
.53112 .39632 Mdot
.39059 .25935 Mdot
.24658 .46214 Mdot
.51531 .38709 Mdot
.55575 .39549 Mdot
.33089 .63387 Mdot
.64663 .49067 Mdot
.65263 .35432 Mdot
.57113 .54444 Mdot
.3421 .65553 Mdot
.50803 .71983 Mdot
.50071 .69891 Mdot
.7296 .55537 Mdot
.30756 .45014 Mdot
.71855 .54724 Mdot
.51389 .69 Mdot
.52559 .38203 Mdot
.33832 .61817 Mdot
.48179 .22498 Mdot
.32289 .61821 Mdot
.50161 .66661 Mdot
.32396 .47726 Mdot
.48579 .29 Mdot
.78082 .30003 Mdot
.4665 .61628 Mdot
.46868 .74559 Mdot
.70031 .57406 Mdot
.39534 .25483 Mdot
.53842 .36271 Mdot
.47424 .2853 Mdot
.52182 .39507 Mdot
.69485 .54762 Mdot
.54215 .70993 Mdot
.61659 .56756 Mdot
.59772 .56338 Mdot
.65086 .35777 Mdot
.35975 .64103 Mdot
.37161 .63728 Mdot
.58422 .55255 Mdot
.34121 .64297 Mdot
.5331 .40184 Mdot
.51682 .666 Mdot
.20383 .44847 Mdot
.54732 .36731 Mdot
.6088 .5844 Mdot
.36356 .61807 Mdot
.34217 .47402 Mdot
.50713 .71952 Mdot
.43595 .34938 Mdot
.18377 .54479 Mdot
.33633 .64782 Mdot
.46212 .21777 Mdot
.5307 .68967 Mdot
.60632 .52611 Mdot
.50021 .66046 Mdot
.52841 .39858 Mdot
.50544 .35534 Mdot
.61098 .5235 Mdot
.54805 .37291 Mdot
.40658 .37796 Mdot
.50936 .28213 Mdot
.52807 .29309 Mdot
.53361 .34607 Mdot
.36517 .46872 Mdot
.35907 .66842 Mdot
.5853 .55287 Mdot
.6011 .44458 Mdot
.52228 .33599 Mdot
.27968 .45019 Mdot
.35426 .65994 Mdot
.19401 .56209 Mdot
.35343 .63395 Mdot
.53895 .67357 Mdot
.35365 .629 Mdot
.5739 .38962 Mdot
.31408 .43283 Mdot
.51732 .68079 Mdot
.60496 .54452 Mdot
.4933 .70282 Mdot
.5102 .39163 Mdot
.30538 .6954 Mdot
.50443 .70241 Mdot
.50757 .27959 Mdot
.31627 .43448 Mdot
.79232 .57428 Mdot
.35439 .38949 Mdot
.52633 .38789 Mdot
.52012 .38889 Mdot
.57633 .55094 Mdot
.33741 .6249 Mdot
.35052 .43692 Mdot
.51736 .78768 Mdot
.75583 .59279 Mdot
.30538 .45458 Mdot
.67434 .5664 Mdot
.63928 .42813 Mdot
.32522 .46965 Mdot
.66105 .31558 Mdot
.32648 .63252 Mdot
.33483 .44985 Mdot
.57944 .59862 Mdot
.50615 .23428 Mdot
.73078 .56543 Mdot
.47869 .70313 Mdot
.63437 .43152 Mdot
.50927 .70031 Mdot
.38303 .59276 Mdot
.46358 .67384 Mdot
.33299 .64892 Mdot
.70293 .59038 Mdot
.51814 .28379 Mdot
.37653 .64688 Mdot
.31664 .56053 Mdot
.51401 .69642 Mdot
.58209 .55482 Mdot
.50964 .253 Mdot
.60966 .52024 Mdot
.59311 .56627 Mdot
.36804 .62707 Mdot
.33589 .45212 Mdot
.34061 .45656 Mdot
.5855 .58499 Mdot
.3326 .45625 Mdot
.51031 .67483 Mdot
.67192 .41135 Mdot
.4498 .30811 Mdot
.3621 .66845 Mdot
.5193 .26307 Mdot
.55811 .35684 Mdot
.54879 .70829 Mdot
.5171 .66906 Mdot
.3578 .63782 Mdot
.3212 .37836 Mdot
.60237 .56697 Mdot
.34882 .46566 Mdot
.32252 .42894 Mdot
.32697 .44034 Mdot
.31653 .41505 Mdot
.66375 .49325 Mdot
.34883 .65522 Mdot
.33285 .43778 Mdot
.55907 .37923 Mdot
.5554 .38984 Mdot
.61108 .52811 Mdot
.71823 .54382 Mdot
.50906 .26006 Mdot
.62081 .55474 Mdot
.51451 .35446 Mdot
.53601 .67802 Mdot
.6037 .59814 Mdot
.62645 .55028 Mdot
.53679 .68707 Mdot
.5393 .68335 Mdot
.62522 .55544 Mdot
.61264 .59556 Mdot
.4066 .38533 Mdot
.48851 .22916 Mdot
.37759 .44465 Mdot
.54163 .70152 Mdot
.32486 .56137 Mdot
.3546 .49772 Mdot
.53627 .41187 Mdot
.57483 .55102 Mdot
.52513 .6653 Mdot
.27471 .42725 Mdot
.54061 .39287 Mdot
.59667 .55635 Mdot
.73845 .56738 Mdot
.60306 .54095 Mdot
.58999 .52965 Mdot
.28265 .44241 Mdot
.29746 .74174 Mdot
.30891 .47116 Mdot
.48325 .65845 Mdot
.60949 .54908 Mdot
.36877 .20698 Mdot
.54411 .70513 Mdot
.29093 .57109 Mdot
.51733 .28305 Mdot
.51781 .34645 Mdot
.52583 .69498 Mdot
.28878 .42003 Mdot
.38022 .66372 Mdot
.65051 .30123 Mdot
.32587 .45476 Mdot
.62976 .55014 Mdot
.59634 .52918 Mdot
.50611 .69352 Mdot
.302 .4317 Mdot
.50282 .25323 Mdot
.33076 .44742 Mdot
.36571 .63184 Mdot
.56051 .40692 Mdot
.18437 .5359 Mdot
.59771 .56127 Mdot
.33174 .46226 Mdot
.48117 .68709 Mdot
.74657 .56264 Mdot
.54805 .41069 Mdot
.17757 .54687 Mdot
.54206 .37029 Mdot
.3568 .61977 Mdot
.6317 .58052 Mdot
.50662 .23681 Mdot
.51926 .36835 Mdot
.55248 .34285 Mdot
.35874 .67854 Mdot
.51856 .36453 Mdot
.52373 .33159 Mdot
.39698 .24099 Mdot
.31336 .46998 Mdot
.53216 .36155 Mdot
.5028 .6749 Mdot
.51889 .60398 Mdot
.54504 .40099 Mdot
.4752 .74879 Mdot
.67122 .34554 Mdot
.57562 .52796 Mdot
.57313 .58618 Mdot
.72572 .475 Mdot
.52432 .39273 Mdot
.51095 .40468 Mdot
.56165 .40425 Mdot
.44901 .33527 Mdot
.51867 .69135 Mdot
.47221 .68833 Mdot
.7404 .55891 Mdot
.64231 .34242 Mdot
.73129 .57382 Mdot
.36278 .665 Mdot
.50707 .28827 Mdot
.61364 .57218 Mdot
.32471 .45889 Mdot
.54418 .37767 Mdot
.47675 .68822 Mdot
.52849 .40053 Mdot
.49609 .25901 Mdot
.50685 .68035 Mdot
.53037 .66743 Mdot
.46338 .68798 Mdot
.71114 .58276 Mdot
.31331 .46017 Mdot
.53861 .41649 Mdot
.72471 .58608 Mdot
.61234 .52303 Mdot
.68561 .44008 Mdot
.30997 .46036 Mdot
.32766 .46454 Mdot
.34277 .43572 Mdot
.53225 .41506 Mdot
.55085 .4183 Mdot
.37003 .64691 Mdot
.33468 .50457 Mdot
.32578 .62078 Mdot
.52313 .69739 Mdot
.54348 .67089 Mdot
.52668 .3983 Mdot
.68267 .57561 Mdot
.72186 .5619 Mdot
.49064 .69755 Mdot
.59042 .57714 Mdot
.7447 .55759 Mdot
.51618 .40579 Mdot
.51436 .70041 Mdot
.72902 .58868 Mdot
.32038 .37812 Mdot
.21556 .53537 Mdot
.74703 .56173 Mdot
.60118 .56418 Mdot
.3997 .30477 Mdot
.72047 .48463 Mdot
.67381 .56225 Mdot
.36174 .66741 Mdot
.51104 .33225 Mdot
.59123 .57556 Mdot
.75159 .56165 Mdot
.71788 .4948 Mdot
.51098 .68546 Mdot
.60426 .56492 Mdot
.63294 .59706 Mdot
.45049 .30887 Mdot
.75091 .56592 Mdot
.3307 .46386 Mdot
.36043 .45761 Mdot
.51998 .37609 Mdot
.51698 .27713 Mdot
.35617 .67156 Mdot
.48292 .70792 Mdot
.47416 .6895 Mdot
.29475 .50177 Mdot
.67333 .40158 Mdot
.49866 .68473 Mdot
.49961 .36577 Mdot
.75316 .5583 Mdot
.55885 .37796 Mdot
.61224 .59045 Mdot
.50075 .23241 Mdot
.56992 .58074 Mdot
.74693 .56235 Mdot
.3648 .66894 Mdot
.34916 .65125 Mdot
.33989 .6259 Mdot
.50038 .68786 Mdot
.62972 .43117 Mdot
.47537 .68105 Mdot
.3875 .2301 Mdot
.70605 .55775 Mdot
.565 .81453 Mdot
.57257 .36887 Mdot
.51172 .35794 Mdot
.50227 .23914 Mdot
.58495 .52989 Mdot
.52695 .39295 Mdot
.35998 .66021 Mdot
.49064 .70809 Mdot
.31644 .70288 Mdot
.28761 .43886 Mdot
.38984 .23238 Mdot
.53329 .67448 Mdot
.60722 .58271 Mdot
.72091 .56611 Mdot
.74075 .46951 Mdot
.68422 .5526 Mdot
.52726 .66057 Mdot
.50439 .37587 Mdot
.27193 .44002 Mdot
.65301 .80096 Mdot
.54121 .37907 Mdot
.49242 .68954 Mdot
.56562 .69542 Mdot
.51638 .24492 Mdot
.47803 .39896 Mdot
.32621 .70565 Mdot
.66203 .41743 Mdot
.72378 .58942 Mdot
.60346 .52055 Mdot
.67688 .36538 Mdot
.51376 .69138 Mdot
.49707 .70806 Mdot
.67654 .56111 Mdot
.33917 .47518 Mdot
.33483 .43108 Mdot
.40144 .42582 Mdot
.36566 .65471 Mdot
.52298 .34193 Mdot
.51168 .69856 Mdot
.32663 .47581 Mdot
.596 .44517 Mdot
.34022 .63237 Mdot
.49955 .70194 Mdot
.54806 .37384 Mdot
.52124 .3696 Mdot
.73311 .5728 Mdot
.66109 .56083 Mdot
.58985 .52241 Mdot
.2937 .56739 Mdot
.64006 .41991 Mdot
.50592 .2888 Mdot
.51756 .34864 Mdot
.29279 .42294 Mdot
.62345 .54388 Mdot
.7259 .56235 Mdot
.56634 .40539 Mdot
.48134 .28793 Mdot
.28309 .42131 Mdot
.32584 .63483 Mdot
.60433 .55053 Mdot
.65152 .36737 Mdot
.54615 .372 Mdot
.52319 .39575 Mdot
.49287 .26714 Mdot
.48241 .28167 Mdot
.52685 .71289 Mdot
.29716 .46322 Mdot
.72572 .5852 Mdot
.32109 .44383 Mdot
.50279 .77511 Mdot
.51228 .28345 Mdot
.50161 .35328 Mdot
.28332 .45296 Mdot
.31249 .43885 Mdot
.35733 .62066 Mdot
.34387 .65359 Mdot
.55833 .71421 Mdot
.5534 .40185 Mdot
.58522 .57083 Mdot
.33067 .43696 Mdot
.47973 .70466 Mdot
.73261 .57486 Mdot
.48033 .758 Mdot
.53813 .35153 Mdot
.51194 .6947 Mdot
.61334 .54123 Mdot
.28492 .44119 Mdot
.53306 .6841 Mdot
.60563 .52597 Mdot
.69476 .55671 Mdot
.5289 .32553 Mdot
.56887 .69973 Mdot
.59041 .55301 Mdot
.55689 .39803 Mdot
.53152 .2797 Mdot
.51793 .27374 Mdot
.57059 .54656 Mdot
.54971 .71259 Mdot
.59342 .55145 Mdot
.35789 .45017 Mdot
.52066 .25554 Mdot
.48289 .70317 Mdot
.34726 .50155 Mdot
.51631 .28346 Mdot
.59253 .56116 Mdot
.31775 .46564 Mdot
.51038 .78041 Mdot
.31258 .4833 Mdot
.70905 .48543 Mdot
.54541 .39685 Mdot
.50877 .70022 Mdot
.73304 .56653 Mdot
.36793 .63238 Mdot
.28911 .64414 Mdot
.33554 .56701 Mdot
.54101 .69462 Mdot
.54576 .3788 Mdot
.33402 .44681 Mdot
.33677 .64657 Mdot
.315 .40995 Mdot
.49513 .66643 Mdot
.50793 .66876 Mdot
.5043 .24039 Mdot
.73023 .57437 Mdot
.56912 .35912 Mdot
.47742 .70062 Mdot
.46723 .67006 Mdot
.39806 .24392 Mdot
.73052 .58941 Mdot
.49186 .26682 Mdot
.58261 .58482 Mdot
.56636 .37549 Mdot
.39366 .25822 Mdot
.58911 .53299 Mdot
.28789 .43712 Mdot
.51239 .37383 Mdot
.3645 .79466 Mdot
.548 .70272 Mdot
.66195 .41706 Mdot
.34419 .70197 Mdot
.35807 .64992 Mdot
.52539 .68825 Mdot
.54445 .39001 Mdot
.47762 .75553 Mdot
.7295 .5548 Mdot
.48701 .23926 Mdot
.5864 .55673 Mdot
.27719 .4954 Mdot
.34397 .61946 Mdot
.64354 .58822 Mdot
.36882 .63428 Mdot
.33298 .6258 Mdot
.32107 .38039 Mdot
.52079 .37697 Mdot
.52871 .67554 Mdot
.49764 .67339 Mdot
.59549 .59012 Mdot
.49355 .65027 Mdot
.33159 .42574 Mdot
.3572 .7885 Mdot
.48578 .29358 Mdot
.53437 .3556 Mdot
.63023 .54616 Mdot
.58006 .56026 Mdot
.46995 .7461 Mdot
.51656 .36711 Mdot
.31068 .46641 Mdot
.47376 .69776 Mdot
.50054 .69714 Mdot
.50816 .27906 Mdot
.34883 .65169 Mdot
.67935 .55487 Mdot
.51451 .67171 Mdot
.6768 .44662 Mdot
.53097 .40471 Mdot
.38321 .65913 Mdot
.51432 .67328 Mdot
.76725 .71223 Mdot
.29799 .74999 Mdot
.31456 .47393 Mdot
.53347 .32511 Mdot
.35261 .45596 Mdot
.74931 .56675 Mdot
.48591 .66686 Mdot
.37497 .64402 Mdot
.60811 .54694 Mdot
.36972 .69961 Mdot
.50233 .695 Mdot
.31587 .45013 Mdot
.52023 .38184 Mdot
.46594 .21409 Mdot
.54573 .36668 Mdot
.64309 .48944 Mdot
.75004 .59326 Mdot
.28877 .6476 Mdot
.34183 .61101 Mdot
.53311 .32466 Mdot
.72251 .58672 Mdot
.52593 .65847 Mdot
.50649 .68253 Mdot
.17912 .55368 Mdot
.59146 .52902 Mdot
.50118 .65629 Mdot
.55577 .40019 Mdot
.46381 .68589 Mdot
.39847 .29685 Mdot
.35712 .64898 Mdot
.54902 .35207 Mdot
.51633 .70344 Mdot
.32692 .48478 Mdot
.65482 .42294 Mdot
.53861 .4028 Mdot
.57953 .57404 Mdot
.33841 .6506 Mdot
.38989 .2281 Mdot
.54263 .71121 Mdot
.55176 .36327 Mdot
.35428 .66376 Mdot
.6997 .58816 Mdot
.30107 .70016 Mdot
.31271 .46049 Mdot
.49144 .68599 Mdot
.34617 .6221 Mdot
.61463 .5512 Mdot
.73659 .5872 Mdot
.51214 .65832 Mdot
.5151 .70521 Mdot
.50262 .26699 Mdot
.59529 .58433 Mdot
.67263 .5648 Mdot
.30504 .42121 Mdot
.32911 .63466 Mdot
.49661 .26461 Mdot
.68481 .44699 Mdot
.55741 .4175 Mdot
.32836 .62706 Mdot
.37436 .21144 Mdot
.50495 .36488 Mdot
.53544 .34839 Mdot
.46974 .21468 Mdot
.35704 .4544 Mdot
.30109 .41757 Mdot
.65839 .39687 Mdot
.50677 .26136 Mdot
.55282 .44422 Mdot
.31695 .45779 Mdot
.31417 .44729 Mdot
.5526 .44395 Mdot
.50017 .26412 Mdot
.40337 .421 Mdot
.34068 .64626 Mdot
.35647 .65141 Mdot
.32575 .43978 Mdot
.5022 .23861 Mdot
.32633 .65731 Mdot
.25405 .43367 Mdot
.50612 .66591 Mdot
.67231 .35475 Mdot
.31866 .43885 Mdot
.65749 .42599 Mdot
.33118 .64241 Mdot
.71096 .43621 Mdot
.67024 .34168 Mdot
.51452 .4116 Mdot
.51882 .37235 Mdot
.70067 .57256 Mdot
.60598 .54153 Mdot
.62558 .55492 Mdot
.34017 .62544 Mdot
.56891 .35799 Mdot
.30193 .4567 Mdot
.5739 .3965 Mdot
.72014 .48972 Mdot
.72065 .43238 Mdot
.50256 .30594 Mdot
.3087 .44912 Mdot
.30057 .44288 Mdot
.54521 .67105 Mdot
.49964 .71632 Mdot
.50074 .39702 Mdot
.34182 .65179 Mdot
.33622 .4586 Mdot
.33085 .61887 Mdot
.51275 .69041 Mdot
.53033 .6729 Mdot
.62064 .5362 Mdot
.60605 .56461 Mdot
.52059 .68556 Mdot
.47483 .74863 Mdot
.68511 .44559 Mdot
.32431 .50564 Mdot
.38682 .21873 Mdot
.73503 .45895 Mdot
.44963 .24474 Mdot
.73599 .5664 Mdot
.60029 .59869 Mdot
.35792 .6627 Mdot
.54081 .32974 Mdot
.51083 .37008 Mdot
.59292 .54474 Mdot
.34222 .66139 Mdot
.71068 .5648 Mdot
.35787 .64911 Mdot
.73675 .5866 Mdot
.4809 .69927 Mdot
.54745 .38247 Mdot
.50645 .38368 Mdot
.35865 .62239 Mdot
.54153 .667 Mdot
.51795 .70199 Mdot
.7327 .56332 Mdot
.73353 .4652 Mdot
.50771 .69346 Mdot
.31746 .43889 Mdot
.21376 .43152 Mdot
.59182 .53221 Mdot
.54107 .3918 Mdot
.72838 .47419 Mdot
.5215 .25905 Mdot
.61429 .52402 Mdot
.60358 .55076 Mdot
.38355 .23408 Mdot
.52327 .40591 Mdot
.18852 .56568 Mdot
.62632 .54773 Mdot
.3356 .42527 Mdot
.5275 .6789 Mdot
.62629 .538 Mdot
.57575 .57725 Mdot
.66876 .5579 Mdot
.62779 .5381 Mdot
.33253 .43129 Mdot
.35348 .45023 Mdot
.51191 .25568 Mdot
.39593 .19446 Mdot
.73295 .58392 Mdot
.71495 .55916 Mdot
.52771 .71126 Mdot
.38532 .5949 Mdot
.5833 .38152 Mdot
.71412 .55583 Mdot
.37733 .40657 Mdot
.50019 .24041 Mdot
.51683 .25971 Mdot
.51495 .2683 Mdot
.33803 .42306 Mdot
.51131 .41459 Mdot
.53678 .71084 Mdot
.31516 .45169 Mdot
.5104 .24975 Mdot
.56753 .41046 Mdot
.30702 .46008 Mdot
.33226 .63008 Mdot
.5092 .29404 Mdot
.33286 .45185 Mdot
.65041 .29958 Mdot
.3284 .64295 Mdot
.51152 .30771 Mdot
.60805 .79659 Mdot
.78597 .69258 Mdot
.35726 .64517 Mdot
.49721 .70038 Mdot
.51425 .69782 Mdot
.50286 .68298 Mdot
.30606 .41817 Mdot
.54887 .68007 Mdot
.29794 .43273 Mdot
.46442 .74001 Mdot
.64617 .35022 Mdot
.7313 .58068 Mdot
.50313 .64852 Mdot
.3267 .44135 Mdot
.39076 .24655 Mdot
.77026 .26521 Mdot
.55413 .367 Mdot
.37505 .64179 Mdot
.71886 .55068 Mdot
.66713 .41826 Mdot
.70126 .56741 Mdot
.53033 .69041 Mdot
.65183 .36282 Mdot
.52868 .40204 Mdot
.20876 .54496 Mdot
.73122 .56735 Mdot
.31465 .44599 Mdot
.50653 .27156 Mdot
.55381 .71061 Mdot
.73169 .55671 Mdot
.72602 .57135 Mdot
.53044 .39319 Mdot
.34968 .43738 Mdot
.52873 .69526 Mdot
.33645 .65707 Mdot
.45331 .70466 Mdot
.57899 .45473 Mdot
.52581 .40804 Mdot
.53592 .34527 Mdot
.64488 .42692 Mdot
.48085 .75783 Mdot
.34593 .64755 Mdot
.69927 .494 Mdot
.54908 .70926 Mdot
.72575 .48681 Mdot
.31504 .48141 Mdot
.50521 .64812 Mdot
.58797 .53512 Mdot
.61008 .52704 Mdot
.53682 .38244 Mdot
.77667 .28481 Mdot
.48915 .41234 Mdot
.32926 .66008 Mdot
.59096 .53808 Mdot
.54773 .67139 Mdot
.30811 .41495 Mdot
.62449 .60157 Mdot
.50768 .25688 Mdot
.33385 .65569 Mdot
.50631 .68774 Mdot
.81027 .33528 Mdot
.69661 .57164 Mdot
.66515 .41171 Mdot
.55634 .387 Mdot
.53622 .38596 Mdot
.3455 .63179 Mdot
.37104 .67081 Mdot
.39518 .22664 Mdot
.68275 .54822 Mdot
.18119 .53039 Mdot
.31634 .65447 Mdot
.8243 .35191 Mdot
.58232 .56505 Mdot
.29623 .4436 Mdot
.62359 .56001 Mdot
.36862 .67076 Mdot
.51292 .38122 Mdot
.35327 .44448 Mdot
.61205 .53713 Mdot
.36371 .39672 Mdot
.51864 .2652 Mdot
.67933 .44552 Mdot
.53215 .37232 Mdot
.34536 .44807 Mdot
.31405 .45602 Mdot
.34304 .46661 Mdot
.60525 .52949 Mdot
.52527 .34629 Mdot
.54927 .3621 Mdot
.53321 .34428 Mdot
.39828 .22762 Mdot
.54475 .38266 Mdot
.27117 .44405 Mdot
.6731 .39278 Mdot
.37817 .80524 Mdot
.50657 .38149 Mdot
.3451 .62369 Mdot
.53447 .37833 Mdot
.70644 .58196 Mdot
.53389 .328 Mdot
.52025 .27363 Mdot
.34498 .64367 Mdot
.47192 .2723 Mdot
.76906 .58975 Mdot
.51953 .406 Mdot
.74425 .58471 Mdot
.2784 .594 Mdot
.69214 .49253 Mdot
.39872 .2751 Mdot
.32941 .44576 Mdot
.4896 .66852 Mdot
.3501 .67245 Mdot
.53863 .67383 Mdot
.48427 .23125 Mdot
.61033 .57175 Mdot
.5577 .81245 Mdot
.69274 .44498 Mdot
.5126 .37795 Mdot
.57693 .54967 Mdot
.31615 .46808 Mdot
.5452 .70517 Mdot
.43502 .26591 Mdot
.50116 .23918 Mdot
.70797 .54846 Mdot
.69722 .56096 Mdot
.63008 .5753 Mdot
.34233 .4704 Mdot
.39703 .29346 Mdot
.34574 .63322 Mdot
.49971 .6905 Mdot
.76087 .57577 Mdot
.38242 .41789 Mdot
.37719 .66662 Mdot
.4648 .73913 Mdot
.34695 .62084 Mdot
.51073 .35719 Mdot
.62821 .54806 Mdot
.37546 .48117 Mdot
.58685 .54636 Mdot
.56818 .40559 Mdot
.5178 .70472 Mdot
.58984 .53138 Mdot
.713 .57987 Mdot
.33872 .62121 Mdot
.53514 .67623 Mdot
.52172 .38804 Mdot
.31784 .46066 Mdot
.59351 .2739 Mdot
.56502 .67817 Mdot
.51451 .28223 Mdot
.51432 .28256 Mdot
.30395 .50692 Mdot
.5706 .53891 Mdot
.28363 .66398 Mdot
.51805 .24625 Mdot
.34837 .57204 Mdot
.67004 .57066 Mdot
.52529 .79543 Mdot
.47749 .67952 Mdot
.51501 .68073 Mdot
.51447 .39537 Mdot
.47362 .70069 Mdot
.50073 .35859 Mdot
.54379 .71572 Mdot
.29003 .56473 Mdot
.54886 .43579 Mdot
.50926 .67849 Mdot
.62301 .55481 Mdot
.55122 .40779 Mdot
.30902 .46796 Mdot
.47549 .67602 Mdot
.51488 .41188 Mdot
.53321 .79412 Mdot
.35846 .62169 Mdot
.60624 .52902 Mdot
.61148 .44323 Mdot
.33653 .64174 Mdot
.32589 .42517 Mdot
.51542 .3265 Mdot
.71776 .55367 Mdot
.30074 .43799 Mdot
.63609 .53975 Mdot
.72807 .5745 Mdot
.67345 .41066 Mdot
.31557 .42919 Mdot
.58862 .53633 Mdot
.69631 .55729 Mdot
.5792 .5905 Mdot
.51263 .68237 Mdot
.56658 .69337 Mdot
.59293 .55589 Mdot
.52577 .40103 Mdot
.55579 .68345 Mdot
.35856 .63647 Mdot
.55047 .39792 Mdot
.50834 .69895 Mdot
.59934 .53392 Mdot
.5524 .37066 Mdot
.50768 .26165 Mdot
.39534 .24996 Mdot
.57507 .52731 Mdot
.72491 .58223 Mdot
.33747 .47088 Mdot
.54931 .35921 Mdot
.74035 .58281 Mdot
.543 .65824 Mdot
.55993 .37293 Mdot
.33457 .46608 Mdot
.36018 .38433 Mdot
.48402 .70942 Mdot
.32474 .63986 Mdot
.4944 .67479 Mdot
.75603 .57941 Mdot
.7671 .2573 Mdot
.62511 .54726 Mdot
.4918 .23289 Mdot
.53357 .33352 Mdot
.48579 .67046 Mdot
.31119 .45743 Mdot
.17757 .51541 Mdot
.53111 .32566 Mdot
.56049 .37627 Mdot
.53745 .39204 Mdot
.45291 .71129 Mdot
.31762 .41774 Mdot
.53933 .39232 Mdot
.65434 .57 Mdot
.53847 .34444 Mdot
.74436 .56418 Mdot
.57799 .81044 Mdot
.60445 .52373 Mdot
.3662 .2047 Mdot
.61178 .5353 Mdot
.50859 .67411 Mdot
.65044 .29893 Mdot
.60946 .44246 Mdot
.52542 .73416 Mdot
.32602 .42451 Mdot
.37694 .44576 Mdot
.52809 .67251 Mdot
.50857 .77943 Mdot
.5066 .25288 Mdot
.50597 .26903 Mdot
.54595 .40935 Mdot
.53041 .69017 Mdot
.5016 .71222 Mdot
.60714 .57123 Mdot
.57787 .54802 Mdot
.51357 .30871 Mdot
.47905 .69042 Mdot
.54665 .38343 Mdot
.51256 .24297 Mdot
.37704 .66804 Mdot
.31807 .47291 Mdot
.37631 .65102 Mdot
.38014 .65978 Mdot
.44623 .25202 Mdot
.63855 .42026 Mdot
.36518 .65624 Mdot
.34984 .66854 Mdot
.4558 .72132 Mdot
.45723 .29242 Mdot
.74845 .56863 Mdot
.49119 .41587 Mdot
.53794 .6679 Mdot
.52599 .34786 Mdot
.32071 .41767 Mdot
.58938 .51604 Mdot
.18159 .49035 Mdot
.79791 .42208 Mdot
.49501 .24675 Mdot
.554 .70044 Mdot
.59003 .5539 Mdot
.58439 .55135 Mdot
.72104 .48521 Mdot
.54484 .38503 Mdot
.48205 .70785 Mdot
.45085 .30713 Mdot
.31895 .65895 Mdot
.4758 .75193 Mdot
.3485 .46704 Mdot
.53665 .37707 Mdot
.29611 .4247 Mdot
.32101 .63643 Mdot
.74386 .57763 Mdot
.70573 .57849 Mdot
.51646 .40404 Mdot
.51837 .28218 Mdot
.34612 .57078 Mdot
.50941 .26699 Mdot
.49758 .25843 Mdot
.59533 .55197 Mdot
.49364 .27193 Mdot
.55293 .36371 Mdot
.53899 .43122 Mdot
.61105 .52239 Mdot
.3785 .65717 Mdot
.44447 .28873 Mdot
.59112 .55986 Mdot
.52281 .32067 Mdot
.32108 .63332 Mdot
.5099 .26331 Mdot
.35269 .63258 Mdot
.48244 .75854 Mdot
.36827 .64653 Mdot
.72258 .58402 Mdot
.45705 .68455 Mdot
.39078 .22152 Mdot
.33392 .44883 Mdot
.34984 .65453 Mdot
.69498 .55586 Mdot
.35259 .62998 Mdot
.53046 .66372 Mdot
.33783 .67526 Mdot
.24601 .45285 Mdot
.67557 .44554 Mdot
.45381 .24208 Mdot
.32234 .66182 Mdot
.49272 .71273 Mdot
.32646 .43945 Mdot
.36598 .58208 Mdot
.52265 .32641 Mdot
.69873 .5744 Mdot
.53551 .38341 Mdot
.33568 .62271 Mdot
.55283 .68318 Mdot
.39708 .27549 Mdot
.72147 .58242 Mdot
.386 .22578 Mdot
.47784 .68667 Mdot
.51387 .34246 Mdot
.32931 .60804 Mdot
.29048 .62515 Mdot
.34753 .61377 Mdot
.65022 .34545 Mdot
.59003 .57412 Mdot
.69708 .54267 Mdot
.30553 .43441 Mdot
.5794 .56341 Mdot
.8169 .54447 Mdot
.31036 .55895 Mdot
.296 .45907 Mdot
.51473 .65012 Mdot
.52885 .40555 Mdot
.49035 .2649 Mdot
.6166 .55843 Mdot
.34182 .45476 Mdot
.49312 .26727 Mdot
.61655 .53149 Mdot
.67326 .38843 Mdot
.34623 .46659 Mdot
.51818 .65577 Mdot
.55345 .40278 Mdot
.36374 .62195 Mdot
.32223 .61984 Mdot
.62808 .55457 Mdot
.3718 .64015 Mdot
.52189 .31967 Mdot
.31657 .43262 Mdot
.51128 .25614 Mdot
.743 .56123 Mdot
.39313 .4502 Mdot
.60201 .51639 Mdot
.7629 .56015 Mdot
.56081 .38595 Mdot
.52923 .67395 Mdot
.36408 .7021 Mdot
.55534 .34909 Mdot
.31716 .45493 Mdot
.52677 .33084 Mdot
.49345 .27012 Mdot
.50768 .26812 Mdot
.49992 .69073 Mdot
.6548 .42452 Mdot
.54596 .38233 Mdot
.32887 .65109 Mdot
.54256 .44759 Mdot
.56769 .35988 Mdot
.69025 .5478 Mdot
.52037 .27306 Mdot
.32068 .61278 Mdot
.30636 .5057 Mdot
.52734 .67596 Mdot
.29923 .45225 Mdot
.27326 .41492 Mdot
.32347 .42449 Mdot
.33809 .48691 Mdot
.51883 .24783 Mdot
.17913 .55935 Mdot
.39824 .29548 Mdot
.45533 .23108 Mdot
.27342 .42604 Mdot
.31516 .71755 Mdot
.29599 .4598 Mdot
.32579 .42493 Mdot
.20131 .45239 Mdot
.32628 .42292 Mdot
.52537 .39833 Mdot
.52243 .33558 Mdot
.49149 .29897 Mdot
.45224 .70234 Mdot
.54577 .36533 Mdot
.62023 .52679 Mdot
.71597 .54972 Mdot
.33371 .4767 Mdot
.60594 .54789 Mdot
.66861 .41916 Mdot
.629 .56131 Mdot
.52953 .39297 Mdot
.55176 .38305 Mdot
.51304 .27031 Mdot
.73022 .43055 Mdot
.45256 .69634 Mdot
.34591 .4388 Mdot
.56866 .36009 Mdot
.29958 .69798 Mdot
.54987 .4038 Mdot
.53919 .33456 Mdot
.5148 .41664 Mdot
.52878 .67551 Mdot
.32539 .41411 Mdot
.59764 .56804 Mdot
.39025 .45707 Mdot
.53884 .36829 Mdot
.60997 .51197 Mdot
.73677 .54959 Mdot
.54444 .39126 Mdot
.34529 .43337 Mdot
.49351 .26934 Mdot
.28237 .42465 Mdot
.31119 .42917 Mdot
.55982 .37366 Mdot
.33487 .47529 Mdot
.29567 .41852 Mdot
.50565 .26806 Mdot
.55686 .69685 Mdot
.29162 .56958 Mdot
.53084 .40113 Mdot
.71721 .57983 Mdot
.51609 .37087 Mdot
.75055 .57015 Mdot
.62703 .53787 Mdot
.59175 .55149 Mdot
.45679 .38695 Mdot
.49256 .70649 Mdot
.70309 .54763 Mdot
.46259 .67428 Mdot
.55632 .33395 Mdot
.37165 .40197 Mdot
.34977 .67841 Mdot
.57057 .68192 Mdot
.59309 .55037 Mdot
.65224 .49044 Mdot
.55897 .45057 Mdot
.37103 .64861 Mdot
.28526 .45116 Mdot
.43848 .30499 Mdot
.57616 .5546 Mdot
.52025 .65569 Mdot
.5001 .67214 Mdot
.31226 .55898 Mdot
.20391 .44873 Mdot
.50725 .38489 Mdot
.57587 .55136 Mdot
.52824 .28527 Mdot
.60617 .54063 Mdot
.60721 .56965 Mdot
.50999 .70528 Mdot
.55064 .36983 Mdot
.67662 .38457 Mdot
.51624 .69571 Mdot
.71735 .56352 Mdot
.28812 .43565 Mdot
.73941 .58465 Mdot
.22337 .52611 Mdot
.3943 .22512 Mdot
.52041 .68878 Mdot
.59528 .52361 Mdot
.53113 .35022 Mdot
.34892 .43487 Mdot
.31221 .40964 Mdot
.31006 .46978 Mdot
.73508 .55424 Mdot
.47419 .69568 Mdot
.53376 .80003 Mdot
.52155 .38166 Mdot
.31145 .44046 Mdot
.76361 .56988 Mdot
.52155 .36808 Mdot
.34575 .65268 Mdot
.49459 .26732 Mdot
.31724 .44217 Mdot
.49349 .23403 Mdot
.306 .43342 Mdot
.50312 .67286 Mdot
.5126 .39943 Mdot
.53616 .40921 Mdot
.68831 .49333 Mdot
.70991 .56482 Mdot
.27911 .4248 Mdot
.6319 .42466 Mdot
.56652 .37589 Mdot
.72316 .48093 Mdot
.54989 .38914 Mdot
.45524 .2391 Mdot
.58683 .58156 Mdot
.62021 .53355 Mdot
.53046 .33122 Mdot
.53505 .4007 Mdot
.31505 .41073 Mdot
.39953 .29671 Mdot
.39785 .22562 Mdot
.32279 .63465 Mdot
.29868 .46358 Mdot
.52094 .69523 Mdot
.47562 .67375 Mdot
.54368 .67496 Mdot
.75847 .57811 Mdot
.51018 .25872 Mdot
.50961 .38175 Mdot
.32471 .65354 Mdot
.71049 .55407 Mdot
.3059 .44507 Mdot
.73724 .57662 Mdot
.64578 .42203 Mdot
.71041 .57667 Mdot
.61943 .56672 Mdot
.2896 .73637 Mdot
.51345 .24404 Mdot
.71944 .57274 Mdot
.32198 .47236 Mdot
.5307 .44727 Mdot
.53249 .42066 Mdot
.39153 .24271 Mdot
.70981 .54817 Mdot
.52721 .65018 Mdot
.5598 .38925 Mdot
.63501 .3452 Mdot
.34612 .62841 Mdot
.73306 .58696 Mdot
.34923 .62138 Mdot
.49457 .25483 Mdot
.37257 .45574 Mdot
.32124 .45074 Mdot
.3716 .67752 Mdot
.53962 .33778 Mdot
.73208 .58708 Mdot
.51758 .68614 Mdot
.45725 .29466 Mdot
.45785 .72949 Mdot
.60769 .50793 Mdot
.71448 .48617 Mdot
.53275 .71219 Mdot
.46083 .27467 Mdot
.36562 .63415 Mdot
.57434 .38517 Mdot
.50099 .23358 Mdot
.56692 .38316 Mdot
.52333 .69997 Mdot
.51545 .67999 Mdot
.52178 .79236 Mdot
.52866 .41082 Mdot
.51808 .41786 Mdot
.26743 .48793 Mdot
.47569 .69886 Mdot
.32183 .42462 Mdot
.34447 .45299 Mdot
.49921 .70084 Mdot
.27749 .43649 Mdot
.72767 .57282 Mdot
.65879 .38345 Mdot
.3663 .63584 Mdot
.32916 .61079 Mdot
.52129 .68676 Mdot
.53027 .70637 Mdot
.53027 .67387 Mdot
.49253 .25864 Mdot
.31539 .42726 Mdot
.5005 .37508 Mdot
.53025 .38082 Mdot
.54694 .4185 Mdot
.3535 .45979 Mdot
.5288 .32458 Mdot
.56018 .43148 Mdot
.73399 .55159 Mdot
.51226 .67182 Mdot
.32825 .62086 Mdot
.59587 .27943 Mdot
.32576 .64854 Mdot
.54634 .35147 Mdot
.29511 .56138 Mdot
.28509 .44896 Mdot
.70058 .56935 Mdot
.51892 .27293 Mdot
.7116 .58027 Mdot
.37693 .66847 Mdot
.26768 .48644 Mdot
.67366 .40546 Mdot
.50211 .38244 Mdot
.64011 .42625 Mdot
.68554 .73994 Mdot
.26561 .42084 Mdot
.33075 .63672 Mdot
.51939 .25803 Mdot
.62586 .56548 Mdot
.52608 .27477 Mdot
.51327 .39237 Mdot
.57194 .36838 Mdot
.63001 .34644 Mdot
.53573 .33973 Mdot
.31658 .47512 Mdot
.54877 .4424 Mdot
.58523 .52731 Mdot
.5539 .41016 Mdot
.19025 .56079 Mdot
.53742 .36082 Mdot
.50836 .39792 Mdot
.51385 .35699 Mdot
.5669 .37208 Mdot
.35384 .46481 Mdot
.51554 .26418 Mdot
.32439 .64514 Mdot
.6596 .38273 Mdot
.36567 .63648 Mdot
.52672 .68506 Mdot
.58033 .52106 Mdot
.35625 .44383 Mdot
.70993 .57949 Mdot
.42356 .61704 Mdot
.63776 .3443 Mdot
.54477 .67056 Mdot
.674 .49518 Mdot
.67803 .55642 Mdot
.61403 .56584 Mdot
.7535 .58299 Mdot
.51695 .70375 Mdot
.35252 .65002 Mdot
.50437 .37328 Mdot
.32791 .43192 Mdot
.33397 .45575 Mdot
.55585 .4068 Mdot
.28824 .5796 Mdot
.32322 .61902 Mdot
.49872 .64931 Mdot
.50734 .37463 Mdot
.54949 .35253 Mdot
.28673 .42531 Mdot
.55204 .69626 Mdot
.56177 .44641 Mdot
.73207 .56036 Mdot
.55327 .39909 Mdot
.5804 .53639 Mdot
.64486 .42295 Mdot
.32355 .63869 Mdot
.59642 .53248 Mdot
.52783 .35431 Mdot
.64742 .41398 Mdot
.48678 .24202 Mdot
.64962 .5706 Mdot
.51407 .71889 Mdot
.55999 .37549 Mdot
.54156 .40773 Mdot
.34724 .46602 Mdot
.3669 .63496 Mdot
.31237 .45928 Mdot
.25365 .47743 Mdot
.59204 .55108 Mdot
.35317 .61687 Mdot
.56666 .37262 Mdot
.31269 .63885 Mdot
.49641 .26921 Mdot
.52607 .38643 Mdot
.33145 .63517 Mdot
.30676 .42722 Mdot
.18405 .52907 Mdot
.44377 .28986 Mdot
.49588 .25787 Mdot
.517 .36809 Mdot
.45327 .70343 Mdot
.59032 .5157 Mdot
.50605 .35399 Mdot
.33585 .45745 Mdot
.52146 .37021 Mdot
.33007 .66324 Mdot
.73948 .57974 Mdot
.32067 .45646 Mdot
.548 .70634 Mdot
.49905 .67929 Mdot
.49584 .71579 Mdot
.61627 .5691 Mdot
.49415 .27257 Mdot
.33957 .4692 Mdot
.34419 .45986 Mdot
.62476 .43284 Mdot
.50876 .67433 Mdot
.7393 .56907 Mdot
.54337 .41254 Mdot
.57578 .54663 Mdot
.34489 .60709 Mdot
.36457 .20406 Mdot
.67144 .40263 Mdot
.7596 .57025 Mdot
.57811 .45743 Mdot
.59743 .54969 Mdot
.53272 .34717 Mdot
.73107 .58672 Mdot
.50201 .70076 Mdot
.48536 .25007 Mdot
.66586 .57156 Mdot
.532 .65071 Mdot
.54514 .69157 Mdot
.31369 .63879 Mdot
.53621 .7176 Mdot
.73093 .58849 Mdot
.62548 .54967 Mdot
.32846 .45668 Mdot
.54564 .3887 Mdot
.60067 .56119 Mdot
.51602 .66629 Mdot
.58751 .56895 Mdot
.51036 .35483 Mdot
.28529 .42834 Mdot
.53686 .66931 Mdot
.52611 .39462 Mdot
.51473 .24184 Mdot
.39589 .24905 Mdot
.55556 .69588 Mdot
.50694 .34184 Mdot
.63718 .5952 Mdot
.54354 .68544 Mdot
.52354 .70167 Mdot
.56033 .37277 Mdot
.6863 .56721 Mdot
.53672 .37138 Mdot
.34767 .65088 Mdot
.64775 .42913 Mdot
.35813 .62185 Mdot
.7263 .48532 Mdot
.56138 .39601 Mdot
.51608 .31181 Mdot
.369 .3993 Mdot
.77758 .58781 Mdot
.7366 .46069 Mdot
.54574 .3571 Mdot
.30172 .41404 Mdot
.65598 .42659 Mdot
.67074 .44517 Mdot
.24881 .44344 Mdot
.74964 .57588 Mdot
.34123 .6256 Mdot
.5316 .40886 Mdot
.19634 .55893 Mdot
.74411 .56661 Mdot
.72304 .48461 Mdot
.5388 .32673 Mdot
.31158 .44915 Mdot
.50926 .3889 Mdot
.32702 .45126 Mdot
.52111 .35857 Mdot
.39647 .26596 Mdot
.34549 .57102 Mdot
.64954 .34566 Mdot
.62203 .55561 Mdot
.29045 .62539 Mdot
.45386 .24067 Mdot
.73143 .57123 Mdot
.49945 .23398 Mdot
.59584 .54461 Mdot
.35812 .64878 Mdot
.3931 .66852 Mdot
.52964 .67229 Mdot
.33975 .65714 Mdot
.2938 .44424 Mdot
.55037 .67302 Mdot
.58157 .56605 Mdot
.52544 .303 Mdot
.72118 .58713 Mdot
.35272 .61641 Mdot
.54349 .39576 Mdot
.56342 .41372 Mdot
.45297 .71212 Mdot
.58704 .8086 Mdot
.28922 .46606 Mdot
.38524 .2184 Mdot
.26744 .48651 Mdot
.71267 .56149 Mdot
.55721 .69236 Mdot
.51154 .37279 Mdot
.54986 .37287 Mdot
.54528 .69426 Mdot
.34902 .43444 Mdot
.69255 .55358 Mdot
.70051 .54155 Mdot
.32809 .65914 Mdot
.62702 .80596 Mdot
.32268 .45675 Mdot
.62493 .80704 Mdot
.5275 .79551 Mdot
.20932 .43984 Mdot
.73526 .46363 Mdot
.33978 .6441 Mdot
.62623 .80685 Mdot
.31091 .44542 Mdot
.52444 .33807 Mdot
.5884 .54118 Mdot
.60823 .57258 Mdot
.29074 .42766 Mdot
.53166 .68624 Mdot
.6854 .56775 Mdot
.51556 .39779 Mdot
.62037 .59168 Mdot
.31517 .40992 Mdot
.47879 .69797 Mdot
.61176 .54464 Mdot
.32544 .62508 Mdot
.5196 .36815 Mdot
.73241 .55251 Mdot
.34114 .6434 Mdot
.60915 .52613 Mdot
.65325 .36533 Mdot
.51513 .32681 Mdot
.51756 .28055 Mdot
.34807 .63063 Mdot
.5815 .44866 Mdot
.54753 .40248 Mdot
.36551 .63396 Mdot
.60949 .58259 Mdot
.28389 .64778 Mdot
.56911 .44801 Mdot
.31033 .55902 Mdot
.54478 .6637 Mdot
.54825 .71338 Mdot
.56775 .64301 Mdot
.45445 .68876 Mdot
.36496 .64769 Mdot
.60394 .55628 Mdot
.57075 .81527 Mdot
.36569 .63217 Mdot
.54856 .34141 Mdot
.52993 .40752 Mdot
.44992 .30815 Mdot
.60591 .52455 Mdot
.61539 .53646 Mdot
.35227 .49981 Mdot
.51477 .25126 Mdot
.61087 .54573 Mdot
.55175 .39274 Mdot
.35216 .44879 Mdot
.3298 .64225 Mdot
.84726 .46948 Mdot
.35961 .67206 Mdot
.48807 .26728 Mdot
.54173 .67001 Mdot
.54787 .66643 Mdot
.54374 .38969 Mdot
.47732 .61851 Mdot
.82014 .34584 Mdot
.5301 .4079 Mdot
.51909 .27243 Mdot
.72521 .48727 Mdot
.55522 .40921 Mdot
.29712 .46753 Mdot
.58915 .52853 Mdot
.35059 .45634 Mdot
.33774 .63993 Mdot
.74947 .57504 Mdot
.7679 .59421 Mdot
.34102 .6262 Mdot
.5407 .36519 Mdot
.612 .51905 Mdot
.53632 .38785 Mdot
.52015 .34313 Mdot
.65102 .41455 Mdot
.75645 .56819 Mdot
.53257 .67835 Mdot
.71308 .58177 Mdot
.32681 .4243 Mdot
.37771 .21292 Mdot
.73495 .57237 Mdot
.45707 .29362 Mdot
.637 .43001 Mdot
.57695 .80944 Mdot
.33314 .45668 Mdot
.74991 .56712 Mdot
.34345 .62474 Mdot
.63459 .4499 Mdot
.46874 .28613 Mdot
.3345 .65551 Mdot
.51955 .34576 Mdot
.34788 .45064 Mdot
.29714 .50491 Mdot
.32201 .61567 Mdot
.32147 .46561 Mdot
.57354 .44792 Mdot
.49795 .25272 Mdot
.32287 .64286 Mdot
.72963 .44583 Mdot
.3425 .61115 Mdot
.44267 .2611 Mdot
.49931 .2698 Mdot
.3187 .45539 Mdot
.46316 .21568 Mdot
.26416 .4812 Mdot
.61858 .53492 Mdot
.5178 .33441 Mdot
.73641 .5697 Mdot
.62968 .43098 Mdot
.55195 .70489 Mdot
.32789 .48436 Mdot
.32311 .44115 Mdot
.34656 .60651 Mdot
.32319 .46457 Mdot
.28193 .44594 Mdot
.37233 .67699 Mdot
.29523 .46038 Mdot
.53957 .36807 Mdot
.39825 .19378 Mdot
.31536 .46877 Mdot
.34424 .63508 Mdot
.72994 .55383 Mdot
.31583 .47382 Mdot
.51209 .78296 Mdot
.55423 .40254 Mdot
.49382 .6682 Mdot
.67943 .56719 Mdot
.35472 .46096 Mdot
.73197 .56918 Mdot
.52119 .66502 Mdot
.71568 .54443 Mdot
.32109 .60413 Mdot
.31894 .61036 Mdot
.57519 .57567 Mdot
.31523 .55915 Mdot
.32591 .42297 Mdot
.55396 .67811 Mdot
.53283 .41408 Mdot
.51001 .36062 Mdot
.73855 .59434 Mdot
.28202 .42014 Mdot
.28277 .58713 Mdot
.60722 .54758 Mdot
.39463 .44875 Mdot
.32192 .62571 Mdot
.50111 .6489 Mdot
.67554 .40602 Mdot
.41309 .63104 Mdot
.58647 .52607 Mdot
.59614 .54845 Mdot
.53758 .39256 Mdot
.6972 .4931 Mdot
.7395 .58627 Mdot
.3235 .71968 Mdot
.49228 .24435 Mdot
.54294 .70049 Mdot
.52195 .35215 Mdot
.5082 .24717 Mdot
.55097 .36114 Mdot
.76112 .57444 Mdot
.34819 .66315 Mdot
.3349 .4515 Mdot
.75179 .57032 Mdot
.49844 .67979 Mdot
.66061 .3149 Mdot
.50485 .35619 Mdot
.50078 .35718 Mdot
.5384 .68522 Mdot
.33419 .42923 Mdot
.52229 .6813 Mdot
.36592 .63542 Mdot
.73493 .57516 Mdot
.4927 .26517 Mdot
.60491 .52435 Mdot
.48459 .67115 Mdot
.35178 .65487 Mdot
.55766 .6971 Mdot
.31485 .64956 Mdot
.59308 .54857 Mdot
.50446 .34299 Mdot
.47525 .70355 Mdot
.58236 .5563 Mdot
.40539 .34936 Mdot
.65098 .36741 Mdot
.22536 .42232 Mdot
.53296 .68836 Mdot
.5306 .73765 Mdot
.34257 .64043 Mdot
.37139 .66663 Mdot
.44101 .25646 Mdot
.7777 .28873 Mdot
.55358 .44367 Mdot
.27244 .614 Mdot
.36687 .63699 Mdot
.35306 .63731 Mdot
.52425 .67876 Mdot
.30504 .42676 Mdot
.36108 .39317 Mdot
.52952 .66009 Mdot
.72609 .47158 Mdot
.30609 .44482 Mdot
.48893 .29707 Mdot
.47318 .68497 Mdot
.50827 .27084 Mdot
.39641 .27629 Mdot
.73136 .54952 Mdot
.70777 .48768 Mdot
.34387 .67708 Mdot
.52073 .39482 Mdot
.17711 .55695 Mdot
.52571 .67139 Mdot
.5866 .56559 Mdot
.30694 .6979 Mdot
.56753 .40974 Mdot
.52387 .34895 Mdot
.52908 .37014 Mdot
.72336 .59085 Mdot
.39975 .3132 Mdot
.51507 .38783 Mdot
.64987 .35661 Mdot
.49927 .28263 Mdot
.56792 .69024 Mdot
.71616 .58277 Mdot
.66345 .4949 Mdot
.4975 .76768 Mdot
.38793 .46315 Mdot
.57249 .36906 Mdot
.35858 .66893 Mdot
.51457 .25215 Mdot
.3305 .63164 Mdot
.31696 .63152 Mdot
.64509 .80247 Mdot
.33853 .45713 Mdot
.49211 .24863 Mdot
.49866 .70626 Mdot
.36541 .39464 Mdot
.50703 .2489 Mdot
.38056 .21504 Mdot
.37886 .64368 Mdot
.76577 .25411 Mdot
.37337 .66312 Mdot
.59614 .57241 Mdot
.29216 .44785 Mdot
.30321 .41202 Mdot
.63959 .42509 Mdot
.31835 .42463 Mdot
.45422 .69092 Mdot
.33692 .47023 Mdot
.77745 .67134 Mdot
.24792 .45051 Mdot
.34739 .64154 Mdot
.32553 .6105 Mdot
.51256 .26417 Mdot
.54254 .37256 Mdot
.67527 .38682 Mdot
.60757 .54674 Mdot
.51816 .32735 Mdot
.51566 .69601 Mdot
.51754 .78808 Mdot
.27321 .7011 Mdot
.29168 .45677 Mdot
.35706 .65474 Mdot
.52275 .34977 Mdot
.49748 .2675 Mdot
.52103 .33577 Mdot
.39036 .59823 Mdot
.47664 .23139 Mdot
.53087 .38263 Mdot
.51078 .26082 Mdot
.53656 .66395 Mdot
.4546 .71341 Mdot
.2058 .44636 Mdot
.63683 .80384 Mdot
.55308 .37047 Mdot
.71074 .55784 Mdot
.75991 .57595 Mdot
.52758 .42829 Mdot
.5341 .5356 Mdot
.58528 .44896 Mdot
.54247 .39658 Mdot
.65795 .3101 Mdot
.51571 .65537 Mdot
.62636 .56303 Mdot
.51295 .66813 Mdot
.276 .41334 Mdot
.6288 .54658 Mdot
.51224 .69977 Mdot
.67228 .35198 Mdot
.59535 .55629 Mdot
.28371 .65959 Mdot
.7441 .56175 Mdot
.55128 .39645 Mdot
.42853 .28049 Mdot
.47395 .69709 Mdot
.35025 .64771 Mdot
.29825 .45808 Mdot
.32494 .64123 Mdot
.45659 .68812 Mdot
.72822 .47802 Mdot
.61347 .53125 Mdot
.35405 .67028 Mdot
.51907 .28365 Mdot
.70888 .55639 Mdot
.37546 .65594 Mdot
.49839 .27989 Mdot
.53635 .43266 Mdot
.79735 .32452 Mdot
.51743 .41094 Mdot
.51919 .78968 Mdot
.36271 .62575 Mdot
.62645 .56575 Mdot
.54545 .38739 Mdot
.48115 .68335 Mdot
.57433 .58756 Mdot
.53444 .38878 Mdot
.54042 .71046 Mdot
.53497 .40602 Mdot
.72801 .58595 Mdot
.34937 .46258 Mdot
.66027 .42677 Mdot
.77934 .57652 Mdot
.75014 .57301 Mdot
.635 .341 Mdot
.51308 .33934 Mdot
.45248 .64647 Mdot
.3105 .45189 Mdot
.54427 .34997 Mdot
.78313 .57077 Mdot
.29305 .43378 Mdot
.29859 .44866 Mdot
.48537 .256 Mdot
.33354 .66687 Mdot
.53522 .68112 Mdot
.70178 .56489 Mdot
.47284 .74856 Mdot
.52139 .39318 Mdot
.49571 .23531 Mdot
.74704 .5673 Mdot
.33843 .64983 Mdot
.49357 .2507 Mdot
.26689 .65602 Mdot
.65873 .38001 Mdot
.37757 .64937 Mdot
.57158 .36951 Mdot
.47967 .21749 Mdot
.33913 .42469 Mdot
.18059 .55946 Mdot
.34453 .57098 Mdot
.4989 .67485 Mdot
.61222 .54735 Mdot
.36733 .20721 Mdot
.73629 .55466 Mdot
.34977 .38584 Mdot
.51 .35756 Mdot
.51391 .36479 Mdot
.35282 .44592 Mdot
.5023 .38972 Mdot
.28813 .45361 Mdot
.51136 .78154 Mdot
.77561 .28066 Mdot
.33106 .45367 Mdot
.32002 .44549 Mdot
.50895 .29578 Mdot
.46283 .6883 Mdot
.28705 .43629 Mdot
.53476 .41078 Mdot
.45643 .68828 Mdot
.63061 .58362 Mdot
.69582 .5536 Mdot
.69986 .58142 Mdot
.29039 .46322 Mdot
.46831 .28132 Mdot
.50669 .27965 Mdot
.44381 .36929 Mdot
.58298 .45924 Mdot
.36582 .64772 Mdot
.55932 .41318 Mdot
.60314 .54751 Mdot
.52047 .66742 Mdot
.52011 .41707 Mdot
.55279 .39185 Mdot
.33556 .44655 Mdot
.72117 .54596 Mdot
.35459 .62265 Mdot
.58414 .55866 Mdot
.4944 .71635 Mdot
.72341 .56218 Mdot
.27842 .43865 Mdot
.4504 .24534 Mdot
.59685 .51762 Mdot
.57667 .5487 Mdot
.53658 .34845 Mdot
.55866 .37123 Mdot
.59129 .52161 Mdot
.33923 .62773 Mdot
.49793 .67408 Mdot
.59867 .56743 Mdot
.61693 .43832 Mdot
.67715 .37577 Mdot
.53976 .35438 Mdot
.32896 .46941 Mdot
.35791 .65147 Mdot
.6153 .53442 Mdot
.56641 .81497 Mdot
.54726 .41278 Mdot
.48544 .29107 Mdot
.67464 .54096 Mdot
.60288 .5517 Mdot
.3612 .39305 Mdot
.70033 .57265 Mdot
.49913 .2693 Mdot
.65004 .35268 Mdot
.5255 .3228 Mdot
.57408 .3838 Mdot
.50586 .70223 Mdot
.33572 .6201 Mdot
.57568 .57302 Mdot
.51319 .67207 Mdot
.29888 .45099 Mdot
.44729 .37328 Mdot
.34414 .44829 Mdot
.34251 .46175 Mdot
.33927 .48446 Mdot
.32319 .6324 Mdot
.36709 .20581 Mdot
.58918 .52055 Mdot
.50721 .38837 Mdot
.35946 .66149 Mdot
.28499 .43853 Mdot
.53401 .32598 Mdot
.28533 .44948 Mdot
.2786 .42363 Mdot
.52409 .32255 Mdot
.50789 .26227 Mdot
.64564 .34795 Mdot
.47512 .27542 Mdot
.70471 .57892 Mdot
.33902 .42696 Mdot
.47634 .28617 Mdot
.51213 .37706 Mdot
.55111 .38139 Mdot
.51372 .26456 Mdot
.75399 .57641 Mdot
.45587 .38698 Mdot
.51218 .35369 Mdot
.70078 .49552 Mdot
.53852 .33014 Mdot
.28283 .41897 Mdot
.28893 .64541 Mdot
.48867 .26927 Mdot
.54522 .66827 Mdot
.35025 .43677 Mdot
.73211 .54936 Mdot
.361 .46992 Mdot
.52265 .2679 Mdot
.35587 .63335 Mdot
.31723 .44229 Mdot
.52061 .65849 Mdot
.34675 .64833 Mdot
.34177 .61101 Mdot
.51458 .26745 Mdot
.49135 .68196 Mdot
.72337 .54604 Mdot
.3373 .61376 Mdot
.52589 .2611 Mdot
.34831 .64275 Mdot
.27097 .39002 Mdot
.49898 .36165 Mdot
.65109 .35635 Mdot
.61429 .5572 Mdot
.58357 .58088 Mdot
.35215 .61795 Mdot
.73387 .56016 Mdot
.49349 .24987 Mdot
.30782 .46835 Mdot
.71929 .55454 Mdot
.39754 .27949 Mdot
.54784 .66705 Mdot
.29661 .50446 Mdot
.46156 .73488 Mdot
.31046 .42084 Mdot
.71106 .48677 Mdot
.7461 .55594 Mdot
.57424 .54222 Mdot
.66237 .41613 Mdot
.6114 .54114 Mdot
.51508 .41363 Mdot
.49347 .24828 Mdot
.53854 .36689 Mdot
.54364 .67127 Mdot
.72128 .59015 Mdot
.31987 .46994 Mdot
.66211 .58339 Mdot
.33179 .64789 Mdot
.53436 .43638 Mdot
.59201 .56818 Mdot
.4952 .25903 Mdot
.28619 .44576 Mdot
.29876 .41719 Mdot
.40002 .2994 Mdot
.54446 .6837 Mdot
.68546 .58114 Mdot
.53846 .35462 Mdot
.61961 .59762 Mdot
.3533 .61819 Mdot
.31143 .55816 Mdot
.49965 .66221 Mdot
.76316 .25239 Mdot
.51011 .67521 Mdot
.65722 .56399 Mdot
.30091 .41942 Mdot
.72076 .57906 Mdot
.54448 .36611 Mdot
.34716 .46863 Mdot
.35925 .39153 Mdot
.68479 .57431 Mdot
.70877 .57823 Mdot
.36152 .57888 Mdot
.36634 .65482 Mdot
.57932 .55198 Mdot
.54106 .33262 Mdot
.53327 .32411 Mdot
.52972 .41328 Mdot
.35942 .65677 Mdot
.50178 .25695 Mdot
.2913 .63326 Mdot
.5201 .25901 Mdot
.78316 .57035 Mdot
.52812 .70213 Mdot
.36837 .79786 Mdot
.3537 .45735 Mdot
.45271 .38192 Mdot
.33828 .37911 Mdot
.65241 .37126 Mdot
.34391 .66385 Mdot
.61031 .58277 Mdot
.52909 .6795 Mdot
.39636 .67454 Mdot
.52588 .7037 Mdot
.84763 .42012 Mdot
.4488 .30848 Mdot
.28742 .64918 Mdot
.51919 .32861 Mdot
.49078 .69888 Mdot
.46663 .27195 Mdot
.59955 .56657 Mdot
.61288 .51951 Mdot
.50131 .22876 Mdot
.39717 .22889 Mdot
.70779 .58087 Mdot
.54382 .36426 Mdot
.35053 .45413 Mdot
.54615 .36829 Mdot
.5465 .36721 Mdot
.51417 .34646 Mdot
.37389 .67709 Mdot
.50522 .34199 Mdot
.54131 .37065 Mdot
.53653 .80282 Mdot
.60162 .59128 Mdot
.53355 .71884 Mdot
.31897 .41167 Mdot
.71039 .55411 Mdot
.2764 .41339 Mdot
.66155 .42224 Mdot
.37104 .66962 Mdot
.39904 .30389 Mdot
.50223 .26509 Mdot
.31293 .48086 Mdot
.36163 .67046 Mdot
.68122 .55973 Mdot
.6 .5463 Mdot
.18372 .48491 Mdot
.46237 .67457 Mdot
.60129 .53528 Mdot
.54719 .70461 Mdot
.51615 .30764 Mdot
.32686 .45818 Mdot
.61066 .54146 Mdot
.34501 .61839 Mdot
.51224 .70563 Mdot
.63785 .34281 Mdot
.52168 .37525 Mdot
.53142 .69217 Mdot
.60341 .55945 Mdot
.6306 .43068 Mdot
.65453 .42651 Mdot
.49095 .69992 Mdot
.31832 .64506 Mdot
.33315 .61107 Mdot
.71664 .5515 Mdot
.3113 .41568 Mdot
.33034 .43029 Mdot
.33242 .64665 Mdot
.40169 .67274 Mdot
.52481 .39493 Mdot
.52408 .38459 Mdot
.67025 .41154 Mdot
.54755 .34685 Mdot
.453 .6927 Mdot
.602 .53704 Mdot
.32885 .43627 Mdot
.49371 .24771 Mdot
.49921 .24042 Mdot
.54036 .36141 Mdot
.73122 .47096 Mdot
.53748 .66817 Mdot
.50951 .2793 Mdot
.73204 .58677 Mdot
.3982 .24304 Mdot
.55047 .40471 Mdot
.77458 .57216 Mdot
.30626 .41749 Mdot
.29988 .70122 Mdot
.35149 .64681 Mdot
.4951 .70646 Mdot
.49678 .70622 Mdot
.6894 .73777 Mdot
.35387 .45503 Mdot
.60249 .53562 Mdot
.53716 .6523 Mdot
.62364 .56079 Mdot
.70619 .57549 Mdot
.55934 .45976 Mdot
.45366 .6926 Mdot
.53414 .71857 Mdot
.31173 .60671 Mdot
.56976 .40017 Mdot
.55436 .39733 Mdot
.30749 .55919 Mdot
.55009 .38768 Mdot
.74066 .57326 Mdot
.37144 .65341 Mdot
.31568 .44325 Mdot
.69469 .57246 Mdot
.36404 .6671 Mdot
.32609 .42565 Mdot
.51266 .27114 Mdot
.53661 .32781 Mdot
.29784 .45383 Mdot
.27909 .43326 Mdot
.52595 .39919 Mdot
.66012 .79912 Mdot
.33319 .44518 Mdot
.29454 .45348 Mdot
.39812 .24043 Mdot
.48717 .71001 Mdot
.57848 .58918 Mdot
.33637 .66744 Mdot
.536 .36981 Mdot
.53419 .69852 Mdot
.71095 .57263 Mdot
.32219 .43831 Mdot
.55495 .36789 Mdot
.52048 .39023 Mdot
.71014 .55652 Mdot
.73955 .5884 Mdot
.72952 .55682 Mdot
.32154 .61675 Mdot
.50581 .26943 Mdot
.28828 .44281 Mdot
.34451 .65965 Mdot
.7404 .55411 Mdot
.7284 .58942 Mdot
.79125 .56873 Mdot
.52609 .39711 Mdot
.74276 .58851 Mdot
.37486 .21162 Mdot
.66957 .3438 Mdot
.62639 .55751 Mdot
.54691 .72051 Mdot
.47655 .71034 Mdot
.63814 .57359 Mdot
.33827 .6204 Mdot
.51935 .26554 Mdot
.69074 .55605 Mdot
.6003 .56326 Mdot
.5227 .38063 Mdot
.55912 .40624 Mdot
.71665 .55702 Mdot
.73061 .47873 Mdot
.33749 .44573 Mdot
.21806 .43097 Mdot
.70879 .55526 Mdot
.48388 .69631 Mdot
.5111 .65547 Mdot
.51227 .68064 Mdot
.54364 .35761 Mdot
.50097 .3064 Mdot
.57716 .45425 Mdot
.40795 .38995 Mdot
.36749 .64976 Mdot
.29419 .41914 Mdot
.39527 .23882 Mdot
.29895 .44666 Mdot
.54964 .684 Mdot
.73477 .5607 Mdot
.35012 .44196 Mdot
.32679 .61291 Mdot
.33892 .61194 Mdot
.47706 .70455 Mdot
.50707 .67523 Mdot
.51907 .68758 Mdot
.3569 .4497 Mdot
.28843 .42751 Mdot
.52322 .32617 Mdot
.33123 .46613 Mdot
.51318 .77882 Mdot
.50987 .78037 Mdot
.47418 .70013 Mdot
.33963 .63298 Mdot
.31088 .42962 Mdot
.53904 .40752 Mdot
.62875 .34685 Mdot
.50464 .65545 Mdot
.71428 .54811 Mdot
.39763 .19413 Mdot
.77918 .29423 Mdot
.50443 .23799 Mdot
.36209 .63898 Mdot
.62364 .55072 Mdot
.52976 .36658 Mdot
.50084 .6717 Mdot
.62034 .51219 Mdot
.59188 .52789 Mdot
.4989 .38658 Mdot
.53154 .31363 Mdot
.35921 .64468 Mdot
.66402 .42364 Mdot
.59679 .56443 Mdot
.50253 .28557 Mdot
.36776 .65886 Mdot
.48086 .6751 Mdot
.57158 .66192 Mdot
.36053 .49494 Mdot
.61298 .47644 Mdot
.6153 .52867 Mdot
.54068 .41599 Mdot
.50947 .69677 Mdot
.69072 .56991 Mdot
.51159 .6939 Mdot
.27314 .42699 Mdot
.48415 .7094 Mdot
.54091 .40459 Mdot
.28865 .43961 Mdot
.33998 .61162 Mdot
.62358 .45311 Mdot
.72717 .59828 Mdot
.47909 .68355 Mdot
.57544 .53643 Mdot
.51041 .24632 Mdot
.52479 .30048 Mdot
.58401 .58134 Mdot
.55145 .39921 Mdot
.33093 .63481 Mdot
.28851 .45245 Mdot
.34033 .65333 Mdot
.57249 .58564 Mdot
.29613 .38172 Mdot
.35297 .64644 Mdot
.50347 .30912 Mdot
.68596 .5685 Mdot
.72987 .47567 Mdot
.53768 .40183 Mdot
.33937 .61775 Mdot
.49923 .36405 Mdot
.34311 .4301 Mdot
.67395 .36281 Mdot
.65733 .37767 Mdot
.32928 .64049 Mdot
.58558 .57237 Mdot
.63592 .43083 Mdot
.5765 .5889 Mdot
.36564 .63588 Mdot
.6708 .33729 Mdot
.59385 .5369 Mdot
.72193 .5657 Mdot
.71923 .58887 Mdot
.72851 .56377 Mdot
.52861 .38165 Mdot
.476 .21554 Mdot
.75032 .56164 Mdot
.39057 .66933 Mdot
.7441 .57688 Mdot
.62989 .58107 Mdot
.28373 .58333 Mdot
.73042 .58837 Mdot
.54773 .39388 Mdot
.51997 .25933 Mdot
.51889 .26614 Mdot
.50377 .66408 Mdot
.17855 .50163 Mdot
.53562 .8021 Mdot
.51147 .37153 Mdot
.39084 .23014 Mdot
.34479 .466 Mdot
.57438 .53591 Mdot
.65614 .37563 Mdot
.51604 .28355 Mdot
.29736 .44182 Mdot
.66307 .41885 Mdot
.31872 .5062 Mdot
.61562 .56308 Mdot
.52792 .38563 Mdot
.35161 .43977 Mdot
.32807 .48486 Mdot
.73599 .4597 Mdot
.38315 .47059 Mdot
.31815 .42692 Mdot
.36716 .63523 Mdot
.34031 .62212 Mdot
.33005 .6364 Mdot
.50246 .67753 Mdot
.32125 .44397 Mdot
.5461 .43544 Mdot
.50093 .67372 Mdot
.51739 .34723 Mdot
.32988 .64326 Mdot
.65686 .36958 Mdot
.31906 .44534 Mdot
.53919 .3991 Mdot
.47447 .2887 Mdot
.53674 .71094 Mdot
.71185 .55644 Mdot
.38928 .22135 Mdot
.55666 .70614 Mdot
.31364 .64201 Mdot
.27169 .42721 Mdot
.60951 .58791 Mdot
.50733 .2875 Mdot
.54982 .35796 Mdot
.50403 .37188 Mdot
.50729 .28843 Mdot
.45014 .30249 Mdot
.58088 .54033 Mdot
.49867 .67976 Mdot
.49625 .71339 Mdot
.5492 .40937 Mdot
.3257 .44511 Mdot
.76069 .56688 Mdot
.72973 .54222 Mdot
.66923 .5732 Mdot
.64466 .4276 Mdot
.65008 .35703 Mdot
.56105 .36234 Mdot
.46703 .39235 Mdot
.51325 .66047 Mdot
.61966 .56878 Mdot
.64682 .42287 Mdot
.72827 .57092 Mdot
.52285 .33892 Mdot
.29629 .40828 Mdot
.31866 .4383 Mdot
.53362 .6864 Mdot
.36325 .62155 Mdot
.60032 .51751 Mdot
.47261 .69917 Mdot
.54977 .40886 Mdot
.49618 .24258 Mdot
.37166 .64013 Mdot
.27519 .44023 Mdot
.71775 .56219 Mdot
.50599 .66898 Mdot
.72572 .5777 Mdot
.32086 .46415 Mdot
.32285 .43762 Mdot
.5324 .33805 Mdot
.68295 .58205 Mdot
.47721 .68235 Mdot
.54516 .36107 Mdot
.52664 .6941 Mdot
.45329 .71278 Mdot
.34257 .60577 Mdot
.54013 .346 Mdot
.36441 .39637 Mdot
.32664 .63785 Mdot
.51383 .35928 Mdot
.51703 .26612 Mdot
.49394 .2511 Mdot
.48776 .69727 Mdot
.70127 .54751 Mdot
.72274 .57075 Mdot
.35535 .38094 Mdot
.39417 .29749 Mdot
.56843 .37797 Mdot
.48087 .70316 Mdot
.50591 .22748 Mdot
.35642 .63898 Mdot
.30495 .42034 Mdot
.30897 .7564 Mdot
.34621 .6363 Mdot
.53209 .40526 Mdot
.73585 .57233 Mdot
.27791 .42969 Mdot
.62918 .55211 Mdot
.68868 .44167 Mdot
.58189 .57422 Mdot
.6772 .5792 Mdot
.58294 .55391 Mdot
.27587 .60739 Mdot
.51781 .69009 Mdot
.28542 .44229 Mdot
.36218 .63649 Mdot
.35641 .63586 Mdot
.55095 .69865 Mdot
.39893 .28046 Mdot
.20855 .4418 Mdot
.37438 .19954 Mdot
.47137 .66513 Mdot
.73855 .56552 Mdot
.67228 .36027 Mdot
.51342 .67918 Mdot
.55009 .70832 Mdot
.39203 .5991 Mdot
.30904 .55788 Mdot
.30513 .42934 Mdot
.51836 .38819 Mdot
.39588 .25092 Mdot
.5066 .36848 Mdot
.60917 .47506 Mdot
.33504 .64663 Mdot
.30569 .4202 Mdot
.32779 .56236 Mdot
.56158 .38851 Mdot
.52394 .35883 Mdot
.51663 .78248 Mdot
.6055 .54434 Mdot
.59331 .80447 Mdot
.51495 .3413 Mdot
.50267 .68652 Mdot
.37931 .41829 Mdot
.61288 .56235 Mdot
.47321 .28476 Mdot
.36618 .63001 Mdot
.61377 .53215 Mdot
.61014 .56454 Mdot
.4687 .39072 Mdot
.28124 .49868 Mdot
.34046 .43394 Mdot
.75155 .58455 Mdot
.29979 .55651 Mdot
.3761 .6483 Mdot
.2682 .64159 Mdot
.54033 .40838 Mdot
.321 .61103 Mdot
.69867 .54236 Mdot
.51189 .36299 Mdot
.50779 .25107 Mdot
.39947 .30052 Mdot
.55971 .41445 Mdot
.52187 .25621 Mdot
.34339 .63879 Mdot
.74574 .53553 Mdot
.57059 .37671 Mdot
.53204 .68995 Mdot
.30383 .42671 Mdot
.2669 .48913 Mdot
.69005 .56291 Mdot
.33878 .56806 Mdot
.77129 .26832 Mdot
.30526 .42072 Mdot
.52368 .37624 Mdot
.35449 .63873 Mdot
.62432 .54015 Mdot
.61566 .55459 Mdot
.57369 .55488 Mdot
.31529 .43651 Mdot
.61134 .56212 Mdot
.36178 .38869 Mdot
.66295 .42018 Mdot
.45131 .38025 Mdot
.32642 .62861 Mdot
.73821 .56743 Mdot
.64968 .57367 Mdot
.45426 .71664 Mdot
.54647 .33826 Mdot
.61015 .4755 Mdot
.34292 .48594 Mdot
.73992 .57039 Mdot
.53576 .36406 Mdot
.57883 .54394 Mdot
.65397 .30107 Mdot
.75901 .55821 Mdot
.58209 .55114 Mdot
.48842 .24475 Mdot
.32585 .42336 Mdot
.60698 .53533 Mdot
.31251 .44272 Mdot
.53771 .36298 Mdot
.58893 .44792 Mdot
.32657 .42106 Mdot
.17975 .51558 Mdot
.59127 .51768 Mdot
.36901 .66569 Mdot
.5046 .40951 Mdot
.5539 .37137 Mdot
.49606 .30177 Mdot
.62265 .54038 Mdot
.18778 .55774 Mdot
.52731 .6984 Mdot
.5779 .81575 Mdot
.45579 .68434 Mdot
.38913 .59781 Mdot
.26657 .6717 Mdot
.56333 .38221 Mdot
.39956 .27925 Mdot
.49954 .30435 Mdot
.32804 .65656 Mdot
.49527 .29728 Mdot
.54238 .37244 Mdot
.53554 .34816 Mdot
.52776 .69386 Mdot
.36903 .62294 Mdot
.48612 .26032 Mdot
.64607 .42364 Mdot
.68048 .5573 Mdot
.31053 .45807 Mdot
.53576 .37543 Mdot
.30397 .48191 Mdot
.4872 .69966 Mdot
.22369 .41986 Mdot
.54567 .39442 Mdot
.60501 .54417 Mdot
.32136 .61255 Mdot
.34723 .61391 Mdot
.48494 .69009 Mdot
.48349 .68759 Mdot
.55373 .37154 Mdot
.3343 .65382 Mdot
.55534 .34542 Mdot
.63466 .43102 Mdot
.60075 .55987 Mdot
.70471 .57025 Mdot
.50717 .39721 Mdot
.212 .43766 Mdot
.81437 .54892 Mdot
.54232 .35681 Mdot
.34664 .44818 Mdot
.52297 .68592 Mdot
.55184 .68317 Mdot
.32857 .42992 Mdot
.55237 .68489 Mdot
.21693 .42728 Mdot
.47618 .21657 Mdot
.71215 .57867 Mdot
.5205 .22998 Mdot
.74914 .57447 Mdot
.61618 .53404 Mdot
.52667 .3979 Mdot
.34587 .71145 Mdot
.46916 .66647 Mdot
.5958 .27908 Mdot
.34251 .6483 Mdot
.61067 .57203 Mdot
.50275 .26046 Mdot
.68046 .5687 Mdot
.52295 .66967 Mdot
.61674 .52261 Mdot
.51936 .33947 Mdot
.35175 .43855 Mdot
.49076 .23674 Mdot
.60534 .56995 Mdot
.61881 .53913 Mdot
.61793 .52463 Mdot
.36383 .66723 Mdot
.30075 .46521 Mdot
.36195 .57906 Mdot
.52823 .71216 Mdot
.51753 .32705 Mdot
.52469 .37328 Mdot
.29671 .41886 Mdot
.5088 .39364 Mdot
.32613 .64788 Mdot
.35591 .20131 Mdot
.73534 .55877 Mdot
.62708 .54795 Mdot
.22335 .52619 Mdot
.62762 .53417 Mdot
.48922 .25546 Mdot
.51412 .29602 Mdot
.31327 .40977 Mdot
.35505 .67127 Mdot
.55145 .33552 Mdot
.51407 .71849 Mdot
.71844 .5643 Mdot
.32903 .61004 Mdot
.49948 .24518 Mdot
.54544 .39993 Mdot
.73808 .56923 Mdot
.32509 .56205 Mdot
.68213 .55235 Mdot
.36508 .6393 Mdot
.60278 .57854 Mdot
.62486 .33587 Mdot
.53609 .39214 Mdot
.60099 .53959 Mdot
.3077 .46512 Mdot
.36505 .65335 Mdot
.40078 .31495 Mdot
.61266 .56458 Mdot
.47056 .7466 Mdot
.35373 .61732 Mdot
.5494 .35669 Mdot
.3549 .47443 Mdot
.24901 .46371 Mdot
.2942 .45765 Mdot
.73294 .71575 Mdot
.48679 .76327 Mdot
.52195 .68949 Mdot
.34115 .63272 Mdot
.53873 .69599 Mdot
.68647 .5692 Mdot
.67312 .37746 Mdot
.48081 .68605 Mdot
.31585 .47575 Mdot
.52959 .70377 Mdot
.55116 .3405 Mdot
.36839 .6676 Mdot
.47312 .68279 Mdot
.51839 .40824 Mdot
.51317 .27387 Mdot
.6169 .54069 Mdot
.75444 .56077 Mdot
.6549 .42339 Mdot
.52348 .40323 Mdot
.59737 .54278 Mdot
.53877 .39729 Mdot
.32693 .64857 Mdot
.61463 .45559 Mdot
.52166 .31946 Mdot
.47189 .66544 Mdot
.1888 .47078 Mdot
.49524 .71145 Mdot
.64202 .59299 Mdot
.5133 .35559 Mdot
.5339 .39456 Mdot
.50051 .25136 Mdot
.40859 .19203 Mdot
.31404 .63271 Mdot
.50389 .34396 Mdot
.55308 .67836 Mdot
.30175 .43931 Mdot
.35218 .45008 Mdot
.53833 .45104 Mdot
.59896 .53759 Mdot
.31998 .62714 Mdot
.53017 .39522 Mdot
.61617 .56738 Mdot
.6607 .39902 Mdot
.29769 .56299 Mdot
.50236 .77554 Mdot
.54259 .71126 Mdot
.33351 .42018 Mdot
.53904 .66736 Mdot
.49852 .25166 Mdot
.61607 .55936 Mdot
.48468 .7624 Mdot
.41356 .64025 Mdot
.71812 .5658 Mdot
.52696 .34498 Mdot
.73431 .46815 Mdot
.53543 .6635 Mdot
.49348 .67942 Mdot
.55375 .34317 Mdot
.38148 .43946 Mdot
.80536 .55702 Mdot
.35519 .66272 Mdot
.25703 .42942 Mdot
.43479 .26842 Mdot
.79567 .40545 Mdot
.34527 .62643 Mdot
.50845 .24914 Mdot
.52145 .65637 Mdot
.63368 .76571 Mdot
.29881 .44284 Mdot
.71712 .56409 Mdot
.51412 .40517 Mdot
.33089 .4708 Mdot
.47257 .66368 Mdot
.29419 .46279 Mdot
.61048 .54689 Mdot
.36514 .66916 Mdot
.5247 .66643 Mdot
.37529 .63675 Mdot
.36532 .39813 Mdot
.73877 .56305 Mdot
.68513 .49269 Mdot
.51747 .24864 Mdot
.39894 .29868 Mdot
.50721 .26834 Mdot
.59887 .59232 Mdot
.51056 .27225 Mdot
.2596 .48065 Mdot
.53912 .4014 Mdot
.57101 .36976 Mdot
.54702 .66548 Mdot
.54409 .35573 Mdot
.53477 .41025 Mdot
.47583 .28926 Mdot
.52169 .34723 Mdot
.54585 .36504 Mdot
.55457 .36175 Mdot
.342 .44587 Mdot
.52869 .33413 Mdot
.28125 .43283 Mdot
.29686 .47547 Mdot
.53037 .71207 Mdot
.71435 .58667 Mdot
.73366 .5881 Mdot
.59253 .44592 Mdot
.73326 .46881 Mdot
.39604 .24763 Mdot
.305 .44171 Mdot
.35107 .61677 Mdot
.52862 .32395 Mdot
.79609 .57027 Mdot
.58967 .44661 Mdot
.50116 .66451 Mdot
.48364 .6992 Mdot
.52013 .411 Mdot
.78122 .30055 Mdot
.51482 .34036 Mdot
.67194 .40351 Mdot
.52981 .38105 Mdot
.54239 .34688 Mdot
.4975 .716 Mdot
.71172 .48716 Mdot
.50831 .28065 Mdot
.29162 .50116 Mdot
.71539 .56757 Mdot
.60692 .53709 Mdot
.59061 .44767 Mdot
.44566 .25286 Mdot
.34997 .50082 Mdot
.50057 .25033 Mdot
.50933 .66547 Mdot
.32562 .43568 Mdot
.66849 .41111 Mdot
.34694 .66032 Mdot
.69031 .44352 Mdot
.27128 .38826 Mdot
.35191 .66425 Mdot
.72115 .56486 Mdot
.4962 .66085 Mdot
.53179 .35758 Mdot
.5035 .69668 Mdot
.56143 .38463 Mdot
.67683 .39661 Mdot
.7072 .5746 Mdot
.32157 .47701 Mdot
.37035 .63974 Mdot
.33997 .45088 Mdot
.22648 .42002 Mdot
.58737 .46031 Mdot
.55436 .80793 Mdot
.47884 .704 Mdot
.63694 .5913 Mdot
.29125 .42822 Mdot
.54797 .41261 Mdot
.37191 .20987 Mdot
.32257 .45845 Mdot
.34998 .43573 Mdot
.67749 .44717 Mdot
.73398 .48729 Mdot
.55671 .3665 Mdot
.32639 .47139 Mdot
.49451 .66119 Mdot
.71664 .58213 Mdot
.53942 .41052 Mdot
.62047 .55528 Mdot
.35176 .4446 Mdot
.53919 .67259 Mdot
.70313 .48888 Mdot
.50361 .68065 Mdot
.2995 .43403 Mdot
.49146 .70616 Mdot
.30644 .61084 Mdot
.4802 .68588 Mdot
.50575 .39278 Mdot
.5316 .39469 Mdot
.24736 .45343 Mdot
.32298 .43776 Mdot
.48933 .25599 Mdot
.50705 .38387 Mdot
.2862 .4376 Mdot
.51295 .64991 Mdot
.34904 .49911 Mdot
.49235 .25158 Mdot
.52186 .39276 Mdot
.75159 .57063 Mdot
.62163 .43802 Mdot
.66046 .44687 Mdot
.52652 .32519 Mdot
.73542 .5634 Mdot
.34997 .43394 Mdot
.53019 .39988 Mdot
.72245 .48817 Mdot
.54758 .66341 Mdot
.57313 .39879 Mdot
.62569 .54068 Mdot
.49996 .27658 Mdot
.72788 .42896 Mdot
.50116 .24616 Mdot
.29369 .44597 Mdot
.2945 .43405 Mdot
.53814 .65671 Mdot
.30085 .45633 Mdot
.62582 .54484 Mdot
.3242 .62325 Mdot
.25942 .39477 Mdot
.61521 .57164 Mdot
.59185 .52523 Mdot
.58896 .52056 Mdot
.58577 .5631 Mdot
.78125 .58478 Mdot
.49733 .76996 Mdot
.60137 .5265 Mdot
.28264 .43843 Mdot
.52621 .54639 Mdot
.59935 .58659 Mdot
.31932 .6279 Mdot
.60957 .56428 Mdot
.57303 .39884 Mdot
.50302 .24984 Mdot
.28951 .41553 Mdot
.34314 .66004 Mdot
.5767 .58003 Mdot
.53792 .41106 Mdot
.30562 .4086 Mdot
.53746 .37423 Mdot
.70968 .54722 Mdot
.31711 .44599 Mdot
.50719 .67031 Mdot
.70282 .57055 Mdot
.59025 .56158 Mdot
.71452 .5543 Mdot
.51477 .69738 Mdot
.33754 .61535 Mdot
.51652 .40476 Mdot
.71714 .54336 Mdot
.71326 .58592 Mdot
.55228 .41813 Mdot
.29779 .42897 Mdot
.56987 .53877 Mdot
.52214 .39832 Mdot
.50407 .25771 Mdot
.33155 .43066 Mdot
.18156 .56249 Mdot
.53016 .35482 Mdot
.50039 .2848 Mdot
.27356 .491 Mdot
.60973 .57036 Mdot
.50275 .67416 Mdot
.55518 .36897 Mdot
.34668 .65194 Mdot
.33162 .64644 Mdot
.46677 .66936 Mdot
.34487 .43595 Mdot
.54206 .67202 Mdot
.54326 .41843 Mdot
.6047 .56613 Mdot
.55442 .39269 Mdot
.52365 .78722 Mdot
.17593 .53478 Mdot
.27751 .43413 Mdot
.52622 .71367 Mdot
.65835 .39431 Mdot
.33224 .66589 Mdot
.50714 .64841 Mdot
.28174 .49765 Mdot
.33565 .46511 Mdot
.32659 .42841 Mdot
.73417 .5869 Mdot
.50958 .67385 Mdot
.30499 .41398 Mdot
.29939 .41529 Mdot
.49575 .24916 Mdot
.52386 .41153 Mdot
.34015 .42535 Mdot
.45319 .71625 Mdot
.72096 .57066 Mdot
.55711 .68987 Mdot
.80912 .55753 Mdot
.36142 .65974 Mdot
.4732 .28353 Mdot
.54593 .33671 Mdot
.76126 .24877 Mdot
.51315 .34365 Mdot
.52859 .37671 Mdot
.276 .41336 Mdot
.67531 .55856 Mdot
.72891 .58253 Mdot
.29166 .42892 Mdot
.27645 .43659 Mdot
.69781 .55824 Mdot
.61318 .38333 Mdot
.73268 .44599 Mdot
.65391 .4085 Mdot
.30332 .46828 Mdot
.27327 .39007 Mdot
.33525 .64057 Mdot
.3466 .46326 Mdot
.29564 .61676 Mdot
.47189 .69165 Mdot
.47826 .68512 Mdot
.36396 .62894 Mdot
.5299 .35832 Mdot
.49109 .71413 Mdot
.50694 .27726 Mdot
.28717 .63247 Mdot
.51356 .2506 Mdot
.67373 .79446 Mdot
.50859 .39544 Mdot
.47822 .61599 Mdot
.28114 .5937 Mdot
.49088 .26444 Mdot
.46833 .21496 Mdot
.71789 .55917 Mdot
.26542 .48859 Mdot
.32416 .64795 Mdot
.3956 .25268 Mdot
.53528 .39325 Mdot
.31924 .47318 Mdot
.3712 .64831 Mdot
.18106 .54912 Mdot
.51237 .28278 Mdot
.49595 .26217 Mdot
.36875 .21082 Mdot
.29574 .4711 Mdot
.50266 .67565 Mdot
.25309 .43468 Mdot
.27854 .42223 Mdot
.51587 .26756 Mdot
.49343 .65884 Mdot
.64873 .29879 Mdot
.31189 .47292 Mdot
.68039 .55084 Mdot
.31068 .45421 Mdot
.69979 .56048 Mdot
.30894 .41375 Mdot
.53343 .70966 Mdot
.52733 .34983 Mdot
.53443 .71079 Mdot
.72714 .54902 Mdot
.50108 .71166 Mdot
.32873 .65334 Mdot
.59198 .55086 Mdot
.32707 .63796 Mdot
.67354 .37094 Mdot
.40271 .32593 Mdot
.33387 .62055 Mdot
.51321 .43075 Mdot
.545 .40148 Mdot
.31049 .41402 Mdot
.51411 .66561 Mdot
.56113 .68912 Mdot
.65217 .42508 Mdot
.31229 .42502 Mdot
.54851 .68386 Mdot
.526 .26761 Mdot
.30712 .71037 Mdot
.50183 .28347 Mdot
.32152 .77017 Mdot
.28884 .44511 Mdot
.55941 .68465 Mdot
.67022 .40681 Mdot
.27374 .44242 Mdot
.47567 .6823 Mdot
.35943 .62774 Mdot
.34689 .65166 Mdot
.50326 .37778 Mdot
.37921 .64459 Mdot
.50241 .66492 Mdot
.30453 .37987 Mdot
.31965 .41767 Mdot
.17506 .52714 Mdot
.73197 .55932 Mdot
.53446 .66594 Mdot
.60399 .56122 Mdot
.36268 .39593 Mdot
.53626 .69986 Mdot
.77319 .27293 Mdot
.80864 .65677 Mdot
.54528 .67852 Mdot
.31534 .44555 Mdot
.31626 .43384 Mdot
.49923 .23699 Mdot
.64649 .42567 Mdot
.52481 .67013 Mdot
.33544 .71362 Mdot
.64755 .35132 Mdot
.59141 .54767 Mdot
.53601 .80268 Mdot
.53641 .43227 Mdot
.50522 .26451 Mdot
.36388 .65218 Mdot
.52303 .35854 Mdot
.28009 .44633 Mdot
.51452 .34124 Mdot
.32476 .64217 Mdot
.46497 .67377 Mdot
.53638 .3956 Mdot
.71959 .56389 Mdot
.35934 .64997 Mdot
.34943 .65506 Mdot
.5043 .7088 Mdot
.34425 .4349 Mdot
.3946 .25938 Mdot
.50651 .67516 Mdot
.50589 .27209 Mdot
.59793 .54665 Mdot
.55249 .36002 Mdot
.33683 .4741 Mdot
.31256 .50703 Mdot
.53196 .66375 Mdot
.55004 .41705 Mdot
.34603 .63072 Mdot
.5425 .66214 Mdot
.50574 .24461 Mdot
.48276 .67598 Mdot
.60204 .50658 Mdot
.4943 .71705 Mdot
.37128 .4019 Mdot
.57516 .53356 Mdot
.31907 .4744 Mdot
.59381 .5292 Mdot
.69156 .73748 Mdot
.72175 .56675 Mdot
.49284 .71318 Mdot
.18034 .52153 Mdot
.53364 .71272 Mdot
.51971 .34905 Mdot
.53525 .40614 Mdot
.52215 .69889 Mdot
.74054 .56439 Mdot
.64204 .57174 Mdot
.70685 .54551 Mdot
.31841 .44189 Mdot
.5185 .28168 Mdot
.78289 .69566 Mdot
.56527 .69468 Mdot
.37402 .64324 Mdot
.3594 .49481 Mdot
.58814 .52734 Mdot
.33432 .65721 Mdot
.35406 .65511 Mdot
.72229 .55098 Mdot
.54789 .70967 Mdot
.35255 .46013 Mdot
.37849 .65777 Mdot
.27543 .44312 Mdot
.71874 .49056 Mdot
.59536 .56868 Mdot
.60511 .60116 Mdot
.57867 .54508 Mdot
.66005 .42 Mdot
.3689 .67225 Mdot
.54346 .382 Mdot
.67321 .56829 Mdot
.36815 .64025 Mdot
.75076 .56107 Mdot
.50747 .24677 Mdot
.54918 .68726 Mdot
.37896 .23479 Mdot
.5038 .38809 Mdot
.50959 .37713 Mdot
.3672 .65236 Mdot
.45814 .22192 Mdot
.28662 .50106 Mdot
.32828 .42378 Mdot
.51776 .68952 Mdot
.67527 .44556 Mdot
.52139 .33633 Mdot
.53315 .40852 Mdot
.5169 .70196 Mdot
.59615 .53585 Mdot
.54414 .8061 Mdot
.52253 .39088 Mdot
.33975 .6374 Mdot
.50668 .24869 Mdot
.32095 .64971 Mdot
.54484 .32829 Mdot
.5193 .35216 Mdot
.50084 .27107 Mdot
.51141 .26781 Mdot
.32745 .63718 Mdot
.58208 .55356 Mdot
.62403 .53262 Mdot
.29844 .46208 Mdot
.51501 .40951 Mdot
.64602 .35096 Mdot
.52928 .39221 Mdot
.71911 .55942 Mdot
.66451 .44501 Mdot
.53449 .32297 Mdot
.49826 .38621 Mdot
.64939 .35019 Mdot
.53971 .3663 Mdot
.36734 .65482 Mdot
.31418 .43149 Mdot
.34885 .6317 Mdot
.37659 .66023 Mdot
.52968 .70491 Mdot
.75304 .56546 Mdot
.55223 .36725 Mdot
.68471 .56211 Mdot
.51472 .41927 Mdot
.56822 .58133 Mdot
.6304 .42977 Mdot
.67082 .40269 Mdot
.7579 .55934 Mdot
.54266 .40438 Mdot
.51792 .69434 Mdot
.55106 .71181 Mdot
.51928 .26502 Mdot
.51697 .41566 Mdot
.36539 .6211 Mdot
.33999 .61803 Mdot
.50891 .78039 Mdot
.56386 .6314 Mdot
.70722 .54727 Mdot
.65604 .55399 Mdot
.51254 .27164 Mdot
.52494 .34182 Mdot
.58434 .55003 Mdot
.53782 .68989 Mdot
.59692 .52725 Mdot
.5004 .77299 Mdot
.32393 .65066 Mdot
.35829 .63513 Mdot
.50772 .39528 Mdot
.82459 .35231 Mdot
.32713 .46074 Mdot
.31696 .43308 Mdot
.32194 .62389 Mdot
.49526 .71162 Mdot
.61376 .54811 Mdot
.38525 .21646 Mdot
.33078 .50408 Mdot
.68958 .57241 Mdot
.55626 .3849 Mdot
.47371 .69552 Mdot
.28527 .4498 Mdot
.70484 .54796 Mdot
.51821 .31761 Mdot
.49686 .65583 Mdot
.53811 .38298 Mdot
.52722 .29384 Mdot
.29405 .42337 Mdot
.62551 .43348 Mdot
.31787 .47603 Mdot
.33384 .64529 Mdot
.37279 .67067 Mdot
.51533 .35626 Mdot
.38443 .23385 Mdot
.3802 .42734 Mdot
.3779 .66575 Mdot
.75114 .58366 Mdot
.5955 .5557 Mdot
.75153 .56297 Mdot
.52834 .69093 Mdot
.72081 .56586 Mdot
.53525 .7013 Mdot
.53233 .65173 Mdot
.35248 .45638 Mdot
.73809 .5696 Mdot
.46343 .28907 Mdot
.6171 .55799 Mdot
.73761 .59002 Mdot
.50909 .33822 Mdot
.49149 .24619 Mdot
.53182 .67304 Mdot
.68325 .5626 Mdot
.55552 .36767 Mdot
.22082 .52842 Mdot
.37154 .66604 Mdot
.32679 .65149 Mdot
.61133 .5466 Mdot
.51838 .65836 Mdot
.35391 .45976 Mdot
.66081 .39097 Mdot
.36374 .39189 Mdot
.53112 .40933 Mdot
.54936 .36464 Mdot
.36776 .39541 Mdot
.35432 .45899 Mdot
.51725 .35604 Mdot
.44554 .37113 Mdot
.60051 .56254 Mdot
.3391 .65135 Mdot
.32046 .44345 Mdot
.3273 .44228 Mdot
.49374 .67428 Mdot
.34977 .43889 Mdot
.66786 .57932 Mdot
.32607 .65255 Mdot
.63036 .5426 Mdot
.34389 .6324 Mdot
.54987 .53297 Mdot
.54528 .68497 Mdot
.18427 .53781 Mdot
.33562 .42645 Mdot
.49319 .25459 Mdot
.34688 .43318 Mdot
.72997 .55645 Mdot
.32517 .47039 Mdot
.3442 .46695 Mdot
.52221 .40979 Mdot
.58389 .55474 Mdot
.61357 .53401 Mdot
.65367 .42137 Mdot
.32449 .46036 Mdot
.53833 .35771 Mdot
.53313 .33158 Mdot
.50856 .38953 Mdot
.63455 .42894 Mdot
.34315 .44209 Mdot
.44645 .25133 Mdot
.32153 .41278 Mdot
.28957 .42664 Mdot
.81924 .54009 Mdot
.62447 .54582 Mdot
.58769 .53114 Mdot
.31547 .7002 Mdot
.51909 .38951 Mdot
.55231 .68742 Mdot
.50467 .26949 Mdot
.59092 .55894 Mdot
.5185 .32005 Mdot
.70432 .57889 Mdot
.56054 .39194 Mdot
.59112 .54151 Mdot
.51351 .66737 Mdot
.49405 .25389 Mdot
.52612 .39623 Mdot
.60223 .5344 Mdot
.35465 .44671 Mdot
.33592 .4434 Mdot
.40299 .42205 Mdot
.70631 .55341 Mdot
.33183 .62876 Mdot
.50379 .26631 Mdot
.51841 .69144 Mdot
.55336 .69465 Mdot
.32065 .47505 Mdot
.48959 .69507 Mdot
.3606 .63761 Mdot
.52234 .37776 Mdot
.33009 .64254 Mdot
.69462 .57004 Mdot
.31826 .44654 Mdot
.50002 .25524 Mdot
.49066 .2329 Mdot
.29441 .43402 Mdot
.60107 .56393 Mdot
.753 .57082 Mdot
.50179 .70303 Mdot
.28068 .42836 Mdot
.32474 .63489 Mdot
.48832 .68077 Mdot
.49424 .26063 Mdot
.84096 .48791 Mdot
.52274 .35793 Mdot
.50781 .36196 Mdot
.36899 .40985 Mdot
.57283 .37142 Mdot
.52713 .71219 Mdot
.35634 .45853 Mdot
.49167 .24966 Mdot
.67147 .34807 Mdot
.76615 .58016 Mdot
.55383 .71889 Mdot
.5355 .36897 Mdot
.49659 .30259 Mdot
.56664 .37395 Mdot
.17991 .50965 Mdot
.63121 .43111 Mdot
.47444 .74851 Mdot
.61729 .59837 Mdot
.37798 .6501 Mdot
.59588 .54177 Mdot
.52871 .70688 Mdot
.43808 .35847 Mdot
.51842 .36029 Mdot
.39708 .31056 Mdot
.50098 .24399 Mdot
.35021 .62856 Mdot
.4563 .23674 Mdot
.50708 .66631 Mdot
.5716 .81616 Mdot
.53295 .41633 Mdot
.30333 .5051 Mdot
.42832 .65247 Mdot
.58634 .54952 Mdot
.58222 .53737 Mdot
.70701 .54821 Mdot
.49497 .65194 Mdot
.582 .57666 Mdot
.34693 .6322 Mdot
.52601 .33956 Mdot
.51278 .30818 Mdot
.19021 .56385 Mdot
.28667 .44747 Mdot
.37451 .6529 Mdot
.52816 .72966 Mdot
.54785 .38405 Mdot
.33775 .46073 Mdot
.29886 .44333 Mdot
.70008 .57767 Mdot
.4627 .7357 Mdot
.50416 .64795 Mdot
.7898 .31723 Mdot
.56888 .55295 Mdot
.53613 .69232 Mdot
.57482 .54351 Mdot
.50405 .27135 Mdot
.58924 .44783 Mdot
.37686 .65281 Mdot
.51592 .35115 Mdot
.39729 .29784 Mdot
.29422 .45415 Mdot
.52984 .3876 Mdot
.71783 .57253 Mdot
.39562 .19413 Mdot
.52025 .25362 Mdot
.44904 .37335 Mdot
.49444 .66107 Mdot
.54703 .36246 Mdot
.67274 .57936 Mdot
.61637 .56771 Mdot
.57347 .37252 Mdot
.50477 .6737 Mdot
.57587 .53229 Mdot
.72124 .57668 Mdot
.29629 .46201 Mdot
.59799 .54219 Mdot
.50277 .24341 Mdot
.55967 .37813 Mdot
.75405 .58156 Mdot
.49938 .26727 Mdot
.24943 .40132 Mdot
.57922 .56334 Mdot
.47807 .6898 Mdot
.27967 .42634 Mdot
.54225 .35749 Mdot
.59477 .55635 Mdot
.55406 .38956 Mdot
.21192 .43653 Mdot
.51896 .3459 Mdot
.20714 .54324 Mdot
.30513 .42608 Mdot
.35066 .64523 Mdot
.50162 .25177 Mdot
.53835 .38609 Mdot
.57379 .54037 Mdot
.61598 .54827 Mdot
.54376 .41217 Mdot
.31889 .47486 Mdot
.31202 .46777 Mdot
.31702 .50619 Mdot
.48883 .67598 Mdot
.64724 .41404 Mdot
.34395 .646 Mdot
.5838 .54879 Mdot
.37823 .65615 Mdot
.50147 .30459 Mdot
.70786 .55454 Mdot
.19411 .55857 Mdot
.51845 .37439 Mdot
.31654 .42574 Mdot
.73163 .44928 Mdot
.33658 .46698 Mdot
.31256 .69779 Mdot
.37598 .64798 Mdot
.32114 .45445 Mdot
.53335 .36752 Mdot
.66493 .41751 Mdot
.49058 .29409 Mdot
.35007 .67201 Mdot
.62813 .54043 Mdot
.56041 .53101 Mdot
.47861 .67437 Mdot
.81769 .54671 Mdot
.34092 .61062 Mdot
.28046 .59251 Mdot
.49226 .25172 Mdot
.31965 .42064 Mdot
.32694 .62859 Mdot
.34669 .65651 Mdot
.5122 .66249 Mdot
.49533 .25029 Mdot
.5362 .38641 Mdot
.62383 .53792 Mdot
.33886 .6135 Mdot
.55872 .40509 Mdot
.49024 .26511 Mdot
.52298 .79207 Mdot
.28269 .50009 Mdot
.17859 .56099 Mdot
.50786 .30886 Mdot
.39864 .29517 Mdot
.39702 .68731 Mdot
.31308 .41506 Mdot
.54243 .36265 Mdot
.60724 .55638 Mdot
.48922 .69844 Mdot
.52322 .37042 Mdot
.52818 .71414 Mdot
.34068 .62452 Mdot
.21487 .53707 Mdot
.5091 .30731 Mdot
.28598 .63694 Mdot
.5254 .35151 Mdot
.5105 .23969 Mdot
.73111 .57432 Mdot
.321 .64315 Mdot
.31644 .50371 Mdot
.54939 .35904 Mdot
.49586 .6786 Mdot
.47546 .67776 Mdot
.29897 .45921 Mdot
.38913 .46053 Mdot
.18193 .53095 Mdot
.60842 .56059 Mdot
.49446 .6926 Mdot
.59609 .55845 Mdot
.45183 .37854 Mdot
.37874 .65763 Mdot
.72168 .57745 Mdot
.491 .705 Mdot
.32179 .61672 Mdot
.49109 .24649 Mdot
.31312 .46133 Mdot
.35739 .39108 Mdot
.51632 .27686 Mdot
.54911 .68438 Mdot
.70471 .56295 Mdot
.54715 .44214 Mdot
.51861 .27855 Mdot
.70594 .5705 Mdot
.49695 .66875 Mdot
.33314 .45454 Mdot
.29711 .43847 Mdot
.31174 .43137 Mdot
.47283 .28386 Mdot
.31649 .50746 Mdot
.664 .49362 Mdot
.57267 .37565 Mdot
.32175 .37791 Mdot
.57056 .39341 Mdot
.32598 .65015 Mdot
.30025 .42121 Mdot
.63021 .43099 Mdot
.50575 .28239 Mdot
.48169 .27919 Mdot
.51507 .39698 Mdot
.51353 .26313 Mdot
.51924 .39022 Mdot
.32842 .37967 Mdot
.28667 .50296 Mdot
.49935 .39427 Mdot
.33764 .66407 Mdot
.71753 .55581 Mdot
.27352 .42804 Mdot
.5511 .3708 Mdot
.29325 .38472 Mdot
.51091 .33512 Mdot
.21198 .53704 Mdot
.51428 .25943 Mdot
.45437 .69641 Mdot
.53433 .3421 Mdot
.47469 .70299 Mdot
.49593 .23173 Mdot
.26252 .39388 Mdot
.36821 .66717 Mdot
.51895 .24953 Mdot
.46878 .70144 Mdot
.45538 .23988 Mdot
.61322 .55662 Mdot
.72393 .5721 Mdot
.58099 .52635 Mdot
.32623 .64151 Mdot
.51683 .3686 Mdot
.5597 .38727 Mdot
.5649 .35191 Mdot
.45284 .38033 Mdot
.62336 .55003 Mdot
.758 .55857 Mdot
.27205 .38953 Mdot
.55261 .40462 Mdot
.50595 .71903 Mdot
.33591 .43454 Mdot
.45777 .27198 Mdot
.45505 .29334 Mdot
.48684 .25495 Mdot
.32117 .45903 Mdot
.34508 .43598 Mdot
.80016 .56495 Mdot
.73082 .56622 Mdot
.50916 .36984 Mdot
.70205 .54325 Mdot
.50173 .26276 Mdot
.3361 .63129 Mdot
.56738 .36044 Mdot
.54579 .68453 Mdot
.67126 .41377 Mdot
.49348 .67072 Mdot
.51046 .39356 Mdot
.30961 .4525 Mdot
.34577 .67057 Mdot
.54141 .6549 Mdot
.45743 .72881 Mdot
.67439 .49511 Mdot
.50831 .6471 Mdot
.70056 .55236 Mdot
.7244 .55225 Mdot
.32158 .64424 Mdot
.52947 .37302 Mdot
.6385 .42882 Mdot
.49778 .20789 Mdot
.51647 .38312 Mdot
.52902 .36001 Mdot
.38828 .67193 Mdot
.35763 .62135 Mdot
.48963 .70613 Mdot
.51714 .3576 Mdot
.56057 .39527 Mdot
.31444 .45224 Mdot
.68048 .55604 Mdot
.51774 .70553 Mdot
.71107 .54771 Mdot
.50507 .69196 Mdot
.72868 .4293 Mdot
.59869 .56824 Mdot
.71301 .55248 Mdot
.34618 .61185 Mdot
.32114 .42808 Mdot
.62522 .54648 Mdot
.52674 .68215 Mdot
.4916 .69265 Mdot
.51614 .41979 Mdot
.28821 .45361 Mdot
.32853 .42373 Mdot
.7019 .55484 Mdot
.33553 .61834 Mdot
.50837 .27802 Mdot
.57905 .54404 Mdot
.55089 .73688 Mdot
.49127 .68513 Mdot
.27666 .38681 Mdot
.3668 .40344 Mdot
.55176 .38331 Mdot
.33577 .44511 Mdot
.54194 .39231 Mdot
.26765 .41829 Mdot
.28501 .46202 Mdot
.53887 .32289 Mdot
.40717 .39546 Mdot
.53876 .69168 Mdot
.74629 .73572 Mdot
.50048 .28348 Mdot
.31416 .61304 Mdot
.50337 .26851 Mdot
.5532 .81041 Mdot
.73288 .45221 Mdot
.5488 .40575 Mdot
.55001 .3669 Mdot
.82861 .3742 Mdot
.54884 .34867 Mdot
.59237 .53124 Mdot
.61435 .55644 Mdot
.33673 .45088 Mdot
.58438 .52414 Mdot
.65662 .42176 Mdot
.74277 .56961 Mdot
.51888 .68943 Mdot
.72374 .48639 Mdot
.70184 .5594 Mdot
.29249 .44748 Mdot
.50614 .2792 Mdot
.38091 .4149 Mdot
.51909 .72013 Mdot
.60371 .53931 Mdot
.34427 .62584 Mdot
.64723 .42903 Mdot
.50093 .67123 Mdot
.3278 .61488 Mdot
.54123 .33793 Mdot
.50649 .77497 Mdot
.33346 .66073 Mdot
.76314 .71633 Mdot
.35544 .66006 Mdot
.32366 .62326 Mdot
.64414 .42232 Mdot
.74311 .56991 Mdot
.57243 .54079 Mdot
.5751 .58792 Mdot
.35893 .66827 Mdot
.60793 .81093 Mdot
.51761 .65932 Mdot
.67661 .39386 Mdot
.26648 .48989 Mdot
.61288 .56321 Mdot
.52749 .35382 Mdot
.36365 .65452 Mdot
.50878 .41173 Mdot
.5744 .53633 Mdot
.35901 .64368 Mdot
.49512 .23194 Mdot
.67489 .4432 Mdot
.60004 .55655 Mdot
.61557 .53398 Mdot
.6861 .55563 Mdot
.45431 .69082 Mdot
.33408 .42773 Mdot
.71854 .58819 Mdot
.6597 .37607 Mdot
.50731 .38077 Mdot
.32743 .63629 Mdot
.59871 .54173 Mdot
.34382 .6488 Mdot
.7317 .57928 Mdot
.75391 .58315 Mdot
.29454 .45878 Mdot
.31031 .50566 Mdot
.61794 .57227 Mdot
.6416 .34198 Mdot
.56951 .37522 Mdot
.39862 .31922 Mdot
.3474 .44888 Mdot
.47163 .21542 Mdot
.74505 .58005 Mdot
.68007 .55937 Mdot
.50551 .23562 Mdot
.52192 .32718 Mdot
.51117 .25804 Mdot
.52871 .3215 Mdot
.59699 .79427 Mdot
.49933 .25212 Mdot
.50021 .7016 Mdot
.523 .31817 Mdot
.29389 .56009 Mdot
.51813 .25488 Mdot
.55361 .37667 Mdot
.50965 .68042 Mdot
.56163 .41479 Mdot
.53857 .67575 Mdot
.53376 .35149 Mdot
.52963 .79167 Mdot
.51802 .69124 Mdot
.64514 .55621 Mdot
.56589 .45381 Mdot
.59852 .52987 Mdot
.73334 .58465 Mdot
.72113 .54388 Mdot
.70089 .48975 Mdot
.33037 .45432 Mdot
.41402 .19208 Mdot
.55302 .37745 Mdot
.51077 .6617 Mdot
.34143 .62329 Mdot
.48871 .23684 Mdot
.50558 .36878 Mdot
.51279 .27691 Mdot
.31704 .46411 Mdot
.51736 .65739 Mdot
.7387 .57741 Mdot
.54061 .71423 Mdot
.52739 .79661 Mdot
.54359 .68495 Mdot
.46691 .38906 Mdot
.49346 .24073 Mdot
.67084 .57911 Mdot
.40608 .34745 Mdot
.66892 .55402 Mdot
.3061 .46255 Mdot
.59572 .54396 Mdot
.73835 .55384 Mdot
.625 .45314 Mdot
.33377 .43032 Mdot
.51637 .70168 Mdot
.53874 .38283 Mdot
.58287 .56091 Mdot
.57432 .58746 Mdot
.27949 .44761 Mdot
.75786 .57743 Mdot
.52016 .68266 Mdot
.59684 .55169 Mdot
.6519 .40844 Mdot
.43516 .26668 Mdot
.67606 .37556 Mdot
.54073 .38783 Mdot
.69869 .55805 Mdot
.28769 .4532 Mdot
.51405 .27702 Mdot
.36692 .63995 Mdot
.64897 .42501 Mdot
.5249 .3547 Mdot
.28323 .65725 Mdot
.30833 .45315 Mdot
.73498 .56167 Mdot
.36098 .65759 Mdot
.72838 .56535 Mdot
.58765 .53203 Mdot
.2824 .4108 Mdot
.58225 .53768 Mdot
.5022 .24498 Mdot
.33653 .62516 Mdot
.3305 .42571 Mdot
.52737 .79491 Mdot
.57079 .53728 Mdot
.52346 .69771 Mdot
.62796 .45177 Mdot
.3068 .46734 Mdot
.35365 .57538 Mdot
.53949 .71448 Mdot
.41139 .64143 Mdot
.61927 .43871 Mdot
.36186 .64418 Mdot
.55288 .37455 Mdot
.30858 .43729 Mdot
.34686 .67175 Mdot
.45234 .71244 Mdot
.48965 .29771 Mdot
.59231 .57465 Mdot
.54125 .40394 Mdot
.17915 .49911 Mdot
.2899 .57633 Mdot
.24712 .46001 Mdot
.32964 .60981 Mdot
.51159 .38398 Mdot
.60675 .56222 Mdot
.51617 .41075 Mdot
.36509 .66567 Mdot
.35362 .67885 Mdot
.55688 .69602 Mdot
.54177 .38094 Mdot
.72219 .56085 Mdot
.54479 .69893 Mdot
.47953 .66948 Mdot
.48417 .70183 Mdot
.31337 .50413 Mdot
.6093 .56714 Mdot
.6125 .55914 Mdot
.73461 .45791 Mdot
.34371 .65015 Mdot
.59755 .53015 Mdot
.5605 .38803 Mdot
.66494 .49309 Mdot
.30966 .42837 Mdot
.51929 .67822 Mdot
.50992 .3811 Mdot
.50503 .28677 Mdot
.60714 .53614 Mdot
.50782 .67522 Mdot
.35322 .45661 Mdot
.53488 .55188 Mdot
.52167 .37185 Mdot
.49734 .24715 Mdot
.28985 .4395 Mdot
.20811 .44446 Mdot
.66105 .40093 Mdot
.54022 .39271 Mdot
.33154 .64681 Mdot
.21227 .46671 Mdot
.54243 .34127 Mdot
.40736 .42169 Mdot
.62699 .54149 Mdot
.5177 .52807 Mdot
.2522 .41702 Mdot
.53547 .30475 Mdot
.44133 .57035 Mdot
.59884 .28038 Mdot
.46817 .59183 Mdot
.62402 .78243 Mdot
.39823 .56193 Mdot
.78053 .69442 Mdot
.36277 .61329 Mdot
.53095 .29626 Mdot
.76258 .27355 Mdot
.28737 .59279 Mdot
.39162 .58022 Mdot
.31946 .59427 Mdot
.63781 .50738 Mdot
.54103 .80336 Mdot
.50664 .77623 Mdot
.62581 .77702 Mdot
.53278 .43032 Mdot
.28725 .52758 Mdot
.52575 .25072 Mdot
.33259 .57462 Mdot
.47413 .74504 Mdot
.52074 .27907 Mdot
.81771 .38854 Mdot
.2977 .69044 Mdot
.80469 .47864 Mdot
.40241 .23968 Mdot
.52429 .76035 Mdot
.62734 .33516 Mdot
.73966 .51434 Mdot
.50962 .216 Mdot
.49184 .55952 Mdot
.37385 .62918 Mdot
.35537 .43166 Mdot
.32262 .71161 Mdot
.50585 .6995 Mdot
.29043 .46129 Mdot
.27626 .68618 Mdot
.82815 .44397 Mdot
.36521 .59898 Mdot
.44032 .57136 Mdot
.57602 .56332 Mdot
.52309 .51705 Mdot
.6257 .42768 Mdot
.26215 .42531 Mdot
.53053 .77301 Mdot
.54606 .79419 Mdot
.355 .40518 Mdot
.46517 .72017 Mdot
.61205 .45749 Mdot
.38673 .57828 Mdot
.24393 .42335 Mdot
.65176 .52941 Mdot
.64419 .54872 Mdot
.34784 .45011 Mdot
.7772 .34538 Mdot
.50216 .4394 Mdot
.66106 .36714 Mdot
.48463 .7466 Mdot
.36427 .44414 Mdot
.39278 .25442 Mdot
.38596 .46442 Mdot
.69768 .77541 Mdot
.83422 .4809 Mdot
.66225 .77174 Mdot
.55978 .46633 Mdot
.37966 .61712 Mdot
.58933 .46338 Mdot
.49026 .61586 Mdot
.6878 .76035 Mdot
.21404 .44222 Mdot
.78943 .33659 Mdot
.47898 .48387 Mdot
.8446 .45829 Mdot
.31084 .39624 Mdot
.64785 .52915 Mdot
.24465 .44423 Mdot
.5507 .50657 Mdot
.70599 .44302 Mdot
.8384 .43082 Mdot
.35754 .56417 Mdot
.57641 .51869 Mdot
.28992 .59062 Mdot
.24877 .40868 Mdot
.52408 .78047 Mdot
.60328 .51567 Mdot
.4254 .33035 Mdot
.83741 .40812 Mdot
.44967 .56285 Mdot
.80277 .40417 Mdot
.53988 .76922 Mdot
.30336 .74388 Mdot
.47982 .66691 Mdot
.37791 .67089 Mdot
.81692 .47753 Mdot
.30468 .43915 Mdot
.72089 .76191 Mdot
.41185 .58442 Mdot
.44195 .63755 Mdot
.83185 .39946 Mdot
.67356 .78895 Mdot
.55482 .49377 Mdot
.65193 .54977 Mdot
.32578 .70945 Mdot
.49273 .59115 Mdot
.31879 .56403 Mdot
.5479 .55185 Mdot
.19767 .52248 Mdot
.81428 .46515 Mdot
.65588 .79171 Mdot
.7757 .3053 Mdot
.65562 .37431 Mdot
.68036 .5158 Mdot
.36912 .41381 Mdot
.41643 .50652 Mdot
.32056 .56797 Mdot
.84414 .4677 Mdot
.52354 .25645 Mdot
.20358 .47034 Mdot
.63652 .77505 Mdot
.45369 .27798 Mdot
.22947 .51726 Mdot
.27972 .63575 Mdot
.54092 .55919 Mdot
.27365 .39858 Mdot
.7758 .58976 Mdot
.70802 .46042 Mdot
.41778 .31508 Mdot
.45782 .70694 Mdot
.66122 .40787 Mdot
.39881 .4563 Mdot
.76498 .68305 Mdot
.25103 .51471 Mdot
.42443 .32316 Mdot
.35562 .39159 Mdot
.6891 .75783 Mdot
.64035 .77921 Mdot
.21419 .49326 Mdot
.53644 .73493 Mdot
.80754 .4134 Mdot
.37044 .50822 Mdot
.53591 .50406 Mdot
.52826 .26527 Mdot
.50555 .22445 Mdot
.5638 .77744 Mdot
.46641 .41653 Mdot
.79043 .55082 Mdot
.29318 .60958 Mdot
.40608 .35886 Mdot
.76188 .52246 Mdot
.41096 .35312 Mdot
.2581 .3973 Mdot
.42073 .43989 Mdot
.29952 .68982 Mdot
.42549 .41063 Mdot
.82142 .38938 Mdot
.5196 .71025 Mdot
.68521 .76508 Mdot
.36193 .59904 Mdot
.50674 .77024 Mdot
.43408 .6394 Mdot
.43163 .64231 Mdot
.80725 .49981 Mdot
.27694 .62353 Mdot
.62124 .50207 Mdot
.24985 .44566 Mdot
.43846 .60438 Mdot
.40394 .31635 Mdot
.48081 .37797 Mdot
.31983 .52164 Mdot
.75384 .57202 Mdot
.43156 .36565 Mdot
.27275 .39802 Mdot
.52767 .73138 Mdot
.46912 .37923 Mdot
.63708 .30866 Mdot
.6273 .56217 Mdot
.66845 .47494 Mdot
.72921 .43401 Mdot
.50986 .48983 Mdot
.68778 .77315 Mdot
.35259 .51821 Mdot
.67406 .47615 Mdot
.31959 .57076 Mdot
.41903 .1926 Mdot
.84598 .45665 Mdot
.81082 .54169 Mdot
.22355 .46758 Mdot
.20939 .50679 Mdot
.34694 .79647 Mdot
.36683 .5828 Mdot
.78134 .67508 Mdot
.36229 .59947 Mdot
.35458 .20485 Mdot
.52031 .71244 Mdot
.58049 .48113 Mdot
.29383 .40629 Mdot
.6314 .30952 Mdot
.82661 .41465 Mdot
.51401 .50355 Mdot
.73184 .59054 Mdot
.24027 .44507 Mdot
.41228 .39879 Mdot
.80769 .3828 Mdot
.7873 .3478 Mdot
.7873 .35633 Mdot
.27394 .67935 Mdot
.44852 .39607 Mdot
.82388 .3795 Mdot
.62299 .4811 Mdot
.47677 .44975 Mdot
.51697 .30076 Mdot
.66033 .33985 Mdot
.76142 .70686 Mdot
.66169 .51915 Mdot
.49768 .58969 Mdot
.35541 .40465 Mdot
.84073 .4038 Mdot
.7397 .44644 Mdot
.53039 .52619 Mdot
.79399 .48508 Mdot
.75485 .54787 Mdot
.76635 .51772 Mdot
.80444 .5095 Mdot
.469 .55988 Mdot
.28251 .62771 Mdot
.84803 .40643 Mdot
.67453 .75485 Mdot
.34198 .58209 Mdot
.28177 .3904 Mdot
.75089 .72367 Mdot
.22162 .51657 Mdot
.3977 .65315 Mdot
.3074 .39915 Mdot
.42933 .20489 Mdot
.36734 .54522 Mdot
.49725 .56145 Mdot
.57403 .36366 Mdot
.76828 .5342 Mdot
.50509 .71191 Mdot
.72672 .728 Mdot
.35666 .53689 Mdot
.46793 .4465 Mdot
.69123 .47588 Mdot
.6364 .80178 Mdot
.48656 .5229 Mdot
.45584 .3474 Mdot
.35487 .51618 Mdot
.23873 .50007 Mdot
.23485 .51427 Mdot
.4157 .24994 Mdot
.56792 .38842 Mdot
.83135 .44015 Mdot
.79803 .66654 Mdot
.81008 .51233 Mdot
.22583 .49845 Mdot
.32946 .76893 Mdot
.34557 .60385 Mdot
.6364 .48193 Mdot
.63423 .28926 Mdot
.45323 .53297 Mdot
.60562 .27194 Mdot
.32391 .66179 Mdot
.3924 .25474 Mdot
.43145 .62945 Mdot
.62334 .48041 Mdot
.27303 .50555 Mdot
.44518 .62336 Mdot
.45065 .36047 Mdot
.33622 .38788 Mdot
.19022 .47748 Mdot
.69247 .75439 Mdot
.51379 .70972 Mdot
.54852 .73053 Mdot
.47036 .43063 Mdot
.67161 .56807 Mdot
.57262 .5133 Mdot
.5416 .4976 Mdot
.40177 .28664 Mdot
.3459 .78189 Mdot
.79182 .52624 Mdot
.74458 .73607 Mdot
.80495 .51224 Mdot
.65367 .7771 Mdot
.47524 .73323 Mdot
.67758 .46372 Mdot
.38942 .61278 Mdot
.3705 .61221 Mdot
.66932 .45735 Mdot
.63838 .79216 Mdot
.534 .51588 Mdot
.24958 .45237 Mdot
.56498 .38531 Mdot
.72837 .44552 Mdot
.72878 .51271 Mdot
.6535 .4702 Mdot
.4246 .26038 Mdot
.35137 .47002 Mdot
.65523 .50268 Mdot
.51805 .55893 Mdot
.48536 .23365 Mdot
.20739 .50271 Mdot
.34469 .6719 Mdot
.30482 .38683 Mdot
.63606 .8034 Mdot
.34928 .79219 Mdot
.46059 .60685 Mdot
.51007 .43221 Mdot
.81073 .45695 Mdot
.5573 .45784 Mdot
.20705 .51508 Mdot
.438 .20641 Mdot
.42252 .64828 Mdot
.34467 .40048 Mdot
.49679 .4707 Mdot
.4405 .65216 Mdot
.26075 .50624 Mdot
.31452 .38857 Mdot
.49908 .22392 Mdot
.82666 .48655 Mdot
.57315 .41366 Mdot
.482 .56745 Mdot
.66278 .39023 Mdot
.39997 .51669 Mdot
.42294 .59121 Mdot
.69981 .48221 Mdot
.45791 .58596 Mdot
.78075 .35817 Mdot
.38937 .2678 Mdot
.50986 .58894 Mdot
.62476 .48839 Mdot
.61917 .47837 Mdot
.40233 .24095 Mdot
.24079 .41612 Mdot
.29631 .60591 Mdot
.55756 .43049 Mdot
.83044 .49908 Mdot
.46458 .47645 Mdot
.68375 .47466 Mdot
.39287 .47875 Mdot
.5611 .42193 Mdot
.59207 .50536 Mdot
.80469 .50533 Mdot
.51777 .53277 Mdot
.75842 .26189 Mdot
.6172 .79391 Mdot
.34655 .50813 Mdot
.25561 .42566 Mdot
.7015 .75477 Mdot
.31709 .53803 Mdot
.40921 .56887 Mdot
.36615 .52518 Mdot
.73808 .73113 Mdot
.50911 .52609 Mdot
.5202 .54272 Mdot
.18826 .48963 Mdot
.81272 .36785 Mdot
.48733 .58378 Mdot
.39456 .6543 Mdot
.67908 .52115 Mdot
.5116 .35151 Mdot
.38227 .47689 Mdot
.18236 .54592 Mdot
.41564 .47289 Mdot
.47568 .59755 Mdot
.79238 .68226 Mdot
.52105 .50086 Mdot
.3472 .5243 Mdot
.76187 .2645 Mdot
.7619 .25576 Mdot
.37755 .48115 Mdot
.84344 .47496 Mdot
.52382 .53851 Mdot
.21129 .51804 Mdot
.37693 .63231 Mdot
.48919 .39657 Mdot
.39817 .31333 Mdot
.82366 .51608 Mdot
.31839 .77364 Mdot
.31501 .57105 Mdot
.31702 .40446 Mdot
.82611 .5236 Mdot
.46878 .45497 Mdot
.59673 .48932 Mdot
.30613 .74381 Mdot
.57845 .8134 Mdot
.69908 .77085 Mdot
.42432 .24303 Mdot
.55994 .78709 Mdot
.59802 .77299 Mdot
.349 .56051 Mdot
.75575 .72172 Mdot
.5696 .56529 Mdot
.42718 .19125 Mdot
.68694 .75958 Mdot
.19067 .50458 Mdot
.53752 .78886 Mdot
.42496 .58929 Mdot
.53223 .49886 Mdot
.42803 .43941 Mdot
.2006 .52631 Mdot
.27457 .64886 Mdot
.51482 .46874 Mdot
.64432 .45041 Mdot
.25846 .40032 Mdot
.20502 .45716 Mdot
.45116 .19741 Mdot
.55098 .48809 Mdot
.76552 .31947 Mdot
.28897 .66047 Mdot
.62879 .46316 Mdot
.25352 .43832 Mdot
.71531 .49466 Mdot
.61514 .49744 Mdot
.51814 .32333 Mdot
.8263 .48223 Mdot
.61363 .49826 Mdot
.77429 .33149 Mdot
.71726 .76823 Mdot
.79169 .47602 Mdot
.4771 .62545 Mdot
.55802 .52536 Mdot
.76203 .70283 Mdot
.77171 .68699 Mdot
.77112 .31503 Mdot
.62932 .77041 Mdot
.66685 .45576 Mdot
.5243 .47811 Mdot
.4834 .37848 Mdot
.45623 .37834 Mdot
.70603 .7505 Mdot
.39893 .23896 Mdot
.75779 .51587 Mdot
.23319 .48029 Mdot
.63853 .79594 Mdot
.57156 .46572 Mdot
.70678 .49308 Mdot
.4043 .48346 Mdot
.64354 .53604 Mdot
.53321 .66025 Mdot
.81686 .34785 Mdot
.2129 .49691 Mdot
.77764 .51951 Mdot
.20456 .47584 Mdot
.34378 .38378 Mdot
.6077 .78519 Mdot
.23838 .43764 Mdot
.59878 .60692 Mdot
.50303 .75328 Mdot
.78697 .57701 Mdot
.54411 .5086 Mdot
.179 .50844 Mdot
.44534 .29247 Mdot
.81243 .50024 Mdot
.76434 .52409 Mdot
.76589 .29449 Mdot
.65953 .50719 Mdot
.43028 .36476 Mdot
.77205 .33985 Mdot
.2306 .48386 Mdot
.64129 .46912 Mdot
.80938 .37825 Mdot
.26532 .49121 Mdot
.83447 .47769 Mdot
.36167 .63221 Mdot
.6157 .49084 Mdot
.18594 .53063 Mdot
.63723 .47505 Mdot
.63226 .47319 Mdot
.79155 .53442 Mdot
.29334 .58473 Mdot
.33481 .53244 Mdot
.36715 .51163 Mdot
.51481 .77517 Mdot
.49339 .40581 Mdot
.46905 .56977 Mdot
.77846 .3082 Mdot
.56517 .37909 Mdot
.66822 .74525 Mdot
.68592 .76888 Mdot
.39194 .6168 Mdot
.53732 .48943 Mdot
.18541 .519 Mdot
.4335 .23228 Mdot
.72476 .46128 Mdot
.81495 .37384 Mdot
.53713 .48842 Mdot
.62821 .29476 Mdot
.46496 .21179 Mdot
.33785 .70494 Mdot
.30345 .59088 Mdot
.44752 .57312 Mdot
.54309 .46261 Mdot
.65831 .40145 Mdot
.65988 .77056 Mdot
.78635 .68963 Mdot
.76524 .31607 Mdot
.30411 .59291 Mdot
.64759 .47458 Mdot
.41042 .42906 Mdot
.74385 .53049 Mdot
.77612 .30002 Mdot
.54644 .8059 Mdot
.27431 .39728 Mdot
.64624 .79024 Mdot
.2929 .59173 Mdot
.5997 .48798 Mdot
.6601 .46566 Mdot
.77925 .35001 Mdot
.3342 .41451 Mdot
.49057 .48256 Mdot
.40549 .4588 Mdot
.65674 .42805 Mdot
.41073 .59486 Mdot
.42311 .20892 Mdot
.27234 .6314 Mdot
.76471 .29358 Mdot
.5858 .77882 Mdot
.4547 .25789 Mdot
.76307 .27933 Mdot
.35339 .46772 Mdot
.40783 .59424 Mdot
.29658 .73347 Mdot
.66777 .47835 Mdot
.46973 .67706 Mdot
.56149 .39873 Mdot
.66018 .45134 Mdot
.30757 .53419 Mdot
.66213 .51273 Mdot
.76064 .58239 Mdot
.29249 .38975 Mdot
.60733 .77781 Mdot
.32363 .38635 Mdot
.78749 .6839 Mdot
.46741 .55574 Mdot
.25931 .40977 Mdot
.45274 .20691 Mdot
.47552 .7312 Mdot
.23545 .49423 Mdot
.80222 .47994 Mdot
.66013 .3443 Mdot
.27844 .40214 Mdot
.28584 .39849 Mdot
.28071 .50591 Mdot
.39346 .60921 Mdot
.81728 .44805 Mdot
.67552 .78506 Mdot
.55026 .73611 Mdot
.28692 .506 Mdot
.56516 .45735 Mdot
.53589 .50084 Mdot
.78261 .50594 Mdot
.54474 .71052 Mdot
.8515 .44684 Mdot
.40252 .20114 Mdot
.2824 .52705 Mdot
.46045 .52364 Mdot
.64575 .30084 Mdot
.60297 .46601 Mdot
.46815 .72007 Mdot
.55036 .49451 Mdot
.35398 .50764 Mdot
.35824 .47123 Mdot
.42245 .61441 Mdot
.74788 .58042 Mdot
.53163 .7364 Mdot
.34501 .58666 Mdot
.41223 .24656 Mdot
.69935 .76201 Mdot
.37443 .40006 Mdot
.57973 .50451 Mdot
.4873 .72231 Mdot
.46455 .39096 Mdot
.6528 .32308 Mdot
.83342 .37228 Mdot
.80179 .46505 Mdot
.30953 .47576 Mdot
.25437 .5142 Mdot
.53564 .77832 Mdot
.79007 .52474 Mdot
.4968 .49577 Mdot
.70261 .74951 Mdot
.42657 .33926 Mdot
.7944 .50487 Mdot
.25272 .42028 Mdot
.44258 .55606 Mdot
.6668 .77959 Mdot
.77318 .56692 Mdot
.6448 .79681 Mdot
.43712 .24326 Mdot
.5205 .44986 Mdot
.59185 .80947 Mdot
.411 .46689 Mdot
.53636 .5268 Mdot
.48365 .23531 Mdot
.45176 .53759 Mdot
.74234 .72482 Mdot
.35457 .4745 Mdot
.64437 .51174 Mdot
.22439 .45483 Mdot
.3136 .57244 Mdot
.8124 .46638 Mdot
.23418 .5067 Mdot
.66922 .78698 Mdot
.49411 .40907 Mdot
.7691 .5563 Mdot
.40118 .25191 Mdot
.65758 .3586 Mdot
.57771 .54037 Mdot
.4185 .32883 Mdot
.57827 .52135 Mdot
.73821 .45629 Mdot
.45743 .36916 Mdot
.83269 .42374 Mdot
.72792 .43798 Mdot
.42971 .44081 Mdot
.64658 .53082 Mdot
.32153 .41349 Mdot
.84519 .43012 Mdot
.72057 .45691 Mdot
.19569 .52677 Mdot
.69925 .7695 Mdot
.63126 .76506 Mdot
.76214 .27566 Mdot
.29222 .58916 Mdot
.44514 .42883 Mdot
.76094 .71688 Mdot
.47059 .47415 Mdot
.60079 .77199 Mdot
.54406 .50845 Mdot
.37461 .41508 Mdot
.82478 .39096 Mdot
.63114 .51093 Mdot
.42391 .44686 Mdot
.49532 .2969 Mdot
.34129 .40105 Mdot
.7127 .44764 Mdot
.57011 .45989 Mdot
.51257 .70289 Mdot
.63704 .30124 Mdot
.56014 .77802 Mdot
.29333 .51089 Mdot
.6954 .76161 Mdot
.71133 .74091 Mdot
.68793 .524 Mdot
.47427 .63069 Mdot
.75952 .27454 Mdot
.43568 .39233 Mdot
.53521 .30786 Mdot
.32377 .38747 Mdot
.76164 .57987 Mdot
.64992 .76457 Mdot
.55391 .42842 Mdot
.63346 .32706 Mdot
.42578 .33333 Mdot
.82485 .50495 Mdot
.41215 .4983 Mdot
.29321 .67511 Mdot
.27119 .49662 Mdot
.19734 .52472 Mdot
.21876 .45615 Mdot
.28356 .59463 Mdot
.74282 .7227 Mdot
.46091 .60615 Mdot
.44107 .56618 Mdot
.42771 .42869 Mdot
.7272 .72299 Mdot
.31775 .58079 Mdot
.32219 .65478 Mdot
.40154 .29332 Mdot
.76392 .30621 Mdot
.28629 .38864 Mdot
.43142 .59048 Mdot
.49276 .54618 Mdot
.54655 .45398 Mdot
.32001 .56408 Mdot
.32153 .54537 Mdot
.32836 .39185 Mdot
.79612 .38259 Mdot
.50023 .57318 Mdot
.55938 .52904 Mdot
.63061 .78855 Mdot
.48001 .54931 Mdot
.71278 .74256 Mdot
.40589 .39473 Mdot
.79088 .3638 Mdot
.68306 .47685 Mdot
.74469 .5431 Mdot
.56396 .40385 Mdot
.23558 .47466 Mdot
.80557 .50683 Mdot
.49445 .49551 Mdot
.48289 .61059 Mdot
.23293 .42977 Mdot
.71426 .76594 Mdot
.63656 .54418 Mdot
.34352 .77912 Mdot
.6493 .54263 Mdot
.63789 .3145 Mdot
.63133 .3032 Mdot
.40242 .62296 Mdot
.53465 .50576 Mdot
.3619 .55789 Mdot
.5356 .45921 Mdot
.40532 .27852 Mdot
.79467 .56705 Mdot
.8101 .34077 Mdot
.36557 .4469 Mdot
.68702 .78648 Mdot
.34566 .50327 Mdot
.36725 .42596 Mdot
.58821 .77638 Mdot
.49967 .61116 Mdot
.46291 .41916 Mdot
.6714 .51871 Mdot
.34926 .48166 Mdot
.80078 .33054 Mdot
.47249 .59957 Mdot
.64863 .51352 Mdot
.52907 .77947 Mdot
.42604 .59752 Mdot
.31328 .71315 Mdot
.3631 .60386 Mdot
.72635 .75547 Mdot
.68811 .76023 Mdot
.29272 .68381 Mdot
.52283 .53764 Mdot
.48301 .60585 Mdot
.80633 .38279 Mdot
.64429 .52996 Mdot
.80954 .47597 Mdot
.27048 .67349 Mdot
.41351 .27165 Mdot
.72398 .43543 Mdot
.71006 .45991 Mdot
.66103 .35556 Mdot
.42705 .30128 Mdot
.79839 .40926 Mdot
.61967 .56739 Mdot
.54021 .73731 Mdot
.53932 .78802 Mdot
.7794 .3056 Mdot
.26476 .51392 Mdot
.58557 .57752 Mdot
.74398 .52533 Mdot
.49922 .57049 Mdot
.62569 .46188 Mdot
.36351 .52003 Mdot
.56855 .51797 Mdot
.3116 .70298 Mdot
.2141 .47544 Mdot
.82907 .49792 Mdot
.55816 .41115 Mdot
.59619 .26947 Mdot
.33722 .57116 Mdot
.46822 .68907 Mdot
.22306 .44354 Mdot
.82901 .36816 Mdot
.32542 .65925 Mdot
.29891 .73037 Mdot
.39343 .61315 Mdot
.7821 .51888 Mdot
.32904 .77487 Mdot
.39795 .61307 Mdot
.78354 .69443 Mdot
.30051 .53566 Mdot
.44108 .26868 Mdot
.19987 .46564 Mdot
.73819 .45362 Mdot
.41636 .32729 Mdot
.54769 .55362 Mdot
.83038 .46577 Mdot
.61185 .46731 Mdot
.63597 .50449 Mdot
.79556 .39723 Mdot
.6601 .78379 Mdot
.6222 .79337 Mdot
.367 .58435 Mdot
.31921 .40265 Mdot
.3582 .79805 Mdot
.51252 .76759 Mdot
.38625 .20972 Mdot
.79941 .46228 Mdot
.47407 .26544 Mdot
.49277 .49139 Mdot
.37654 .5004 Mdot
.81576 .39325 Mdot
.7347 .72525 Mdot
.53552 .53637 Mdot
.50566 .72011 Mdot
.70803 .47048 Mdot
.73332 .52576 Mdot
.33409 .53818 Mdot
.78618 .48635 Mdot
.47089 .7224 Mdot
.63316 .51287 Mdot
.6744 .77802 Mdot
.23538 .47359 Mdot
.65396 .36987 Mdot
.76648 .30835 Mdot
.65115 .3315 Mdot
.62426 .805 Mdot
.2734 .67897 Mdot
.5337 .78563 Mdot
.78183 .31276 Mdot
.28506 .51871 Mdot
.4429 .32333 Mdot
.75735 .26287 Mdot
.84401 .45848 Mdot
.48553 .60541 Mdot
.57392 .39995 Mdot
.77579 .70272 Mdot
.52305 .72123 Mdot
.78196 .53175 Mdot
.39259 .25115 Mdot
.60721 .7925 Mdot
.46682 .36401 Mdot
.56935 .41423 Mdot
.60239 .48176 Mdot
.32949 .47797 Mdot
.31113 .39981 Mdot
.53005 .76294 Mdot
.63824 .79112 Mdot
.41086 .2354 Mdot
.38938 .26817 Mdot
.43431 .24245 Mdot
.29432 .46769 Mdot
.82562 .4747 Mdot
.67146 .58523 Mdot
.39991 .22729 Mdot
.79947 .37801 Mdot
.62015 .27062 Mdot
.347 .55562 Mdot
.40041 .2762 Mdot
.67401 .46743 Mdot
.55922 .77586 Mdot
.77202 .28276 Mdot
.40591 .29728 Mdot
.85147 .44043 Mdot
.8133 .54491 Mdot
.29879 .46876 Mdot
.32129 .51428 Mdot
.59575 .4661 Mdot
.47679 .58499 Mdot
.31536 .70629 Mdot
.5066 .76946 Mdot
.61924 .7709 Mdot
.51045 .72565 Mdot
.53732 .41284 Mdot
.38066 .48952 Mdot
.80991 .49503 Mdot
.60314 .48906 Mdot
.81369 .49079 Mdot
.41944 .28467 Mdot
.56354 .37701 Mdot
.75529 .25271 Mdot
.20939 .51839 Mdot
.47861 .38241 Mdot
.62064 .57763 Mdot
.58321 .57526 Mdot
.51852 .31952 Mdot
.34818 .67686 Mdot
.66504 .49097 Mdot
.58881 .79427 Mdot
.82832 .46224 Mdot
.29452 .50752 Mdot
.60484 .46765 Mdot
.32852 .60169 Mdot
.61861 .43341 Mdot
.46647 .35884 Mdot
.3161 .6498 Mdot
.57097 .79149 Mdot
.35217 .70784 Mdot
.32045 .57207 Mdot
.40959 .59181 Mdot
.65471 .44798 Mdot
.59814 .57752 Mdot
.57992 .78445 Mdot
.40371 .62881 Mdot
.33281 .56938 Mdot
.66586 .78879 Mdot
.43316 .30805 Mdot
.29058 .59932 Mdot
.54899 .7668 Mdot
.64619 .46869 Mdot
.39266 .47258 Mdot
.49544 .5945 Mdot
.43175 .20785 Mdot
.81187 .40684 Mdot
.57383 .69372 Mdot
.61883 .56905 Mdot
.4712 .20487 Mdot
.82817 .42022 Mdot
.32158 .62857 Mdot
.79754 .66217 Mdot
.50364 .60807 Mdot
.2264 .4518 Mdot
.47846 .2254 Mdot
.52811 .49006 Mdot
.52049 .24764 Mdot
.57517 .37723 Mdot
.62589 .35025 Mdot
.29014 .71315 Mdot
.5407 .49284 Mdot
.42398 .6011 Mdot
.4546 .5975 Mdot
.63956 .49406 Mdot
.5229 .26407 Mdot
.51088 .38906 Mdot
.63286 .53897 Mdot
.68936 .44746 Mdot
.56769 .51288 Mdot
.64168 .50035 Mdot
.2822 .63018 Mdot
.57961 .78648 Mdot
.61892 .79315 Mdot
.45186 .40371 Mdot
.81944 .3922 Mdot
.48223 .25111 Mdot
.79983 .46696 Mdot
.38825 .51299 Mdot
.28019 .62684 Mdot
.64869 .32748 Mdot
.77075 .28399 Mdot
.40513 .43619 Mdot
.59799 .59833 Mdot
.80961 .54613 Mdot
.79747 .48955 Mdot
.28586 .64684 Mdot
.18569 .49983 Mdot
.54059 .78958 Mdot
.60944 .47288 Mdot
.21194 .47007 Mdot
.55711 .72445 Mdot
.79562 .52622 Mdot
.51576 .4566 Mdot
.49691 .60929 Mdot
.41858 .21259 Mdot
.46578 .38761 Mdot
.54726 .67609 Mdot
.43717 .20677 Mdot
.42796 .30011 Mdot
.79818 .41144 Mdot
.53187 .30802 Mdot
.43421 .52312 Mdot
.40863 .4264 Mdot
.76675 .30015 Mdot
.54129 .65976 Mdot
.62734 .29286 Mdot
.39274 .19718 Mdot
.28868 .71234 Mdot
.60128 .76986 Mdot
.76431 .31283 Mdot
.36938 .61113 Mdot
.53964 .46069 Mdot
.1828 .55756 Mdot
.40851 .43234 Mdot
.34439 .39036 Mdot
.34899 .58555 Mdot
.73068 .53271 Mdot
.40664 .44905 Mdot
.77237 .27236 Mdot
.79615 .50914 Mdot
.45205 .41817 Mdot
.38222 .21025 Mdot
.67915 .7745 Mdot
.61793 .29439 Mdot
.28255 .61177 Mdot
.82486 .48274 Mdot
.30574 .70442 Mdot
.7654 .71293 Mdot
.48111 .5579 Mdot
.34443 .50041 Mdot
.72275 .52349 Mdot
.20893 .48043 Mdot
.53983 .48041 Mdot
.38694 .25904 Mdot
.20769 .50093 Mdot
.7401 .51439 Mdot
.50461 .5251 Mdot
.37412 .45668 Mdot
.35676 .49959 Mdot
.46754 .52866 Mdot
.4983 .61429 Mdot
.43252 .59033 Mdot
.44693 .56549 Mdot
.3189 .57803 Mdot
.45305 .51935 Mdot
.20804 .52253 Mdot
.38736 .62173 Mdot
.42802 .2661 Mdot
.55325 .77223 Mdot
.65419 .50519 Mdot
.51823 .71411 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo07kooooo0_l00000
0ooooooo0000o`000003o`000003ooooool0003o000000Cooooo0_l0002jooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo
00?o0000ooooooooool0OOooool3o`000003ooooool0003o000000?o000000?oooooo`000?l00000
1?ooool2o`000;[ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?o
V9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`1fooooo`;o00001?ooool3o`00013ooooo0_l0
002hooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7o
k^k^00Kooooo0ol0001`ooooo`;o00000_ooool4o`0000Cooooo0_l000000ooooooo0000o`00000>
ooooo`;o0000^?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00omg
MgOoIVIVooooo`05ooooo`03o`000?oooooooooo06oooooo0ol000001?oooooo0000o`000?l00009
ooooo`;o00001oooool2o`0000_ooooo0_l0002booooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Koooool2o`00
00;ooooo1?l0000?ooooo`Oo00000_ooool2o`0000Cooooo0_l00007ooooo`;o0000ZOooool00006
oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o
0000ooooooooool0M?ooool8o`0000[ooooo1ol00002ooooo`;o00000_ooool2o`0000Wooooo0ol0
002Xooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`01_ooool00ol0003oooooooooo`1dooooo`So00002?ooool2o`0000gooooo1?l00008ooooo`;o
0000Z?ooool001cooooo00?o0000ooooooooool0Moooool4o`0000Wooooo0_l0000<ooooo`So0000
2?ooool2o`000:Gooooo000Looooo`03o`000?oooooooooo07Wooooo1?l0000Eooooo`?o00000_oo
ool3o`0000Sooooo0_l0002Uooooo`007?ooool00ol0003oooooooooo`1jooooo`?o00005?ooool2
o`0000_ooooo1?l0002Wooooo`007?ooool00ol0003oooooooooo`1jooooo`Ko00004Oooool2o`00
00Cooooo1?l00003ooooo`Go0000Y_ooool001cooooo00?o0000ooooooooool0N_ooool6o`00013o
oooo0ol00004ooooo`Ko00000_ooool4o`0000;ooooo0_l0002Rooooo`007?ooool00ol0003ooooo
ooooo`1iooooo`Oo00002Oooool2o`0000Gooooo0ol00004ooooo`;o000000?oooooo`000?l00000
1_l00003ooooo`;o0000X_ooool001cooooo00?o0000ooooooooool0Moooool6o`000003ooooool0
003o000000;ooooo0_l00005ooooo`;o00001?ooool3o`0000Gooooo3?l0002Vooooo`007?ooool0
0ol0003oooooooooo`1gooooo`Co00000_ooool4o`000003ooooool0003o000000_ooooo0ol00007
ooooo`_o0000YOooool001cooooo00?o0000ooooooooool0Noooool6o`0000Gooooo0_l000000ooo
oooo0000o`000004ooooo`?o00002?ooool;o`000:Cooooo000Looooo`03o`000?oooooooooo07_o
oooo1_l00005ooooo`;o000000Coooooo`000?l0003o00000_ooool4o`0000Sooooo3Ol0002Roooo
o`007?ooool00ol0003oooooooooo`1kooooo`Go00000_ooool2o`0000Kooooo0_l00002ooooo`?o
00002Oooool=o`0004cooooo0_l0001Dooooo`007?ooool2o`0007cooooo1_l000001?oooooo0000
o`000?l00008ooooo`?o00002Oooool@o`0004[ooooo0ol0001Cooooo`007?ooool00ol0003ooooo
ooooo`1looooo`Go00000_ooool2o`0000Sooooo0_l0000:oooooa3o0000BOooool5o`0005;ooooo
000Looooo`03o`000?oooooooooo07cooooo0ol0000<ooooo`Co000000?oooooo`000?l000002?oo
ool>o`0004[ooooo1Ol0001Booooo`007?ooool00ol0003oooooooooo`1jooooo`Co00002?ooool2
o`0000?ooooo1?l000000ooooooo0000o`000008ooooo`oo0000Boooool3o`0005;ooooo000Loooo
o`03o`000?oooooooooo07[ooooo1?l00008ooooo`;o000000Coooooo`000?l0003ooooo0ol0000;
ooooo`oo0000BOooool4o`0005?ooooo000Looooo`03o`000?oooooooooo07_ooooo1?l00008oooo
o`Go00002_ooool2o`0000?ooooo3ol00018ooooo`Oo0000D?ooool001cooooo00?o0000oooooooo
ool0Noooool4o`0000Sooooo1ol00008ooooo`;o00000oooool?o`0001Cooooo0_l00006ooooo`;o
0000;_ooool3o`00053ooooo000Looooo`03o`000?oooooooooo07_ooooo0_l000000ooooooo0000
o`000003ooooo`;o00001?ooool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000
o`000002o`0000?ooooo3Ol0000Eooooo`?o000000?oooooo`000?l000000oooool2o`0002cooooo
0_l000000ooooooo0000o`00001@ooooo`007?ooool00ol0003oooooooooo`1mooooo`?o00000ooo
ool2o`0000cooooo2?l00004ooooo`co00005?ooool2o`0000;ooooo0_l0000`ooooo`?o000000?o
ooooo`000?l00000D?ooool001cooooo00?o0000ooooooooool0OOooool5o`0000kooooo1?l00003
ooooo`Co000000?oooooo`000?l000003Ol0000Cooooo`;o0000<oooool3o`0005?ooooo000Loooo
o`03o`000?oooooooooo07gooooo1Ol00005ooooo`;o00001oooool2o`0000;ooooo0_l00003oooo
o`;o000000?oooooo`000?l000002Ol00002ooooo`;o00004oooool3o`0003?ooooo0_l000001?oo
oooo0000o`000?l0001?ooooo`007?ooool00ol0003oooooooooo`1nooooo`;o00001Oooool4o`00
00Cooooo0_l00003ooooo`Wo000000?oooooo`000?l000002Ol000000ooooooo0000o`00000Doooo
o`?o0000=_ooool3o`0004oooooo000Looooo`03o`000?oooooooooo07oooooo0_l00004ooooo`;o
00001_ooool2o`0000?ooooo2Ol00004ooooo`So000000?oooooo`000?l000008?ooool2o`0002_o
oooo1?l0001>ooooo`007?ooool00ol0003oooooooooo`1oooooo`;o00002oooool3o`0000;ooooo
1?l000000ooooooo0000o`000004o`0000Cooooo0ol0000Wooooo`;o0000;Oooool2o`0004kooooo
000Looooo`03o`000?oooooooooo07gooooo1?l0000;ooooo`?o000000?oooooo`000?l000000_l0
0006ooooo`Co00000oooool3o`0000?ooooo0ol0000Kooooo`;o000000?oooooo`000?l00000:ooo
ool2o`0000;ooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`1looooo`Ko00002oooool2
o`000004ooooool0003o0000o`0000Oooooo1Ol00003ooooo`Wo00006_ooool2o`000003ooooool0
003o000002_ooooo0_l00002ooooo`;o0000C_ooool001cooooo0_l0001mooooo`Ko00001Oooool2
o`0001;ooooo1?l00003ooooo`Wo00008?ooool2o`000003ooooool0003o000000?o00008_ooool2
o`000003ooooool0003o000000;o0000COooool001cooooo00?o0000ooooooooool0O_ooool2o`00
00Oooooo0_l00005ooooo`;o00003?ooool5o`0000?ooooo0_l000001?oooooo0000o`000?ooool2
o`0001gooooo1?l000000ooooooo0000o`000003o`0002;ooooo0_l000000ooooooo0000o`000002
o`0004gooooo000Looooo`03o`000?oooooooooo07kooooo0_l0000;ooooo`;o000000Coooooo`00
0?l0003o00003?ooool4o`000003ooooool0003o000000;o000000Coooooo`000?l0003ooooo0_l0
000Mooooo`;o00001Oooool2o`0002;ooooo0_l00002ooooo`Go0000C?ooool001cooooo00?o0000
ooooooooool0OOooool2o`0000[ooooo1?l000001?oooooo0000o`000?l0000>ooooo`Oo00000ooo
ool3o`0001gooooo1?l00003ooooo`Co00008?ooool3o`000003ooooool0003o000000?o0000C?oo
ool001cooooo00?o0000ooooooooool0OOooool3o`0000Wooooo0_l00003ooooo`?o00003oooool6
o`0000?ooooo0_l0000Nooooo`Co00001Oooool2o`00023ooooo0ol00002ooooo`?o0000COooool0
01cooooo00?o0000ooooooooool0O_ooool3o`0000?ooooo0_l0000Nooooo`?o00000_ooool2o`00
023ooooo0_l00005ooooo`?o00007oooool5o`000003ooooool0003o000004gooooo000Looooo`03
o`000?oooooooooo07kooooo0ol00003ooooo`;o00007oooool5o`00027ooooo0_l00006ooooo`;o
00008?ooool4o`0000Cooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`1nooooo`?o0000
1Oooool2o`0001gooooo2?l0000Sooooo`;o000000?oooooo`000?l000008?ooool2o`0000Kooooo
0_l0001:ooooo`007?ooool00ol0003oooooooooo`1oooooo`;o00001Oooool2o`0000Cooooo0_l0
000Gooooo`So00008oooool2o`000003ooooool0003o000002[ooooo0_l00018ooooo`007?ooool0
0ol0003oooooooooo`1oooooo`;o00000oooool2o`0000Kooooo0_l0000Fooooo`go00006Oooool2
o`0000?ooooo0_l00004ooooo`;o0000:?ooool2o`0004Sooooo000Looooo`03o`000?oooooooooo
08Cooooo1?l0000Jooooo`oo00006Oooool2o`0000?ooooo0ol00003ooooo`;o00008Oooool2o`00
00Kooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`26ooooo`?o000000?oooooo`000?l0
00000_ooool2o`0001;ooooo3?l000000ooooooo0000o`000002o`0001Gooooo0_l00006ooooo`;o
00009_ooool2o`0000Kooooo0_l000000ooooooo0000o`000014ooooo`007?ooool00ol0003ooooo
ooooo`27ooooo`;o000000?oooooo`000?l000000_ooool2o`0001;ooooo4Ol0000Dooooo`?o0000
3?ooool2o`0002Gooooo0_l00004ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0Qooo
ool2o`000003ooooool0003o000001Kooooo3ol0000Fooooo`;o000000?oooooo`000?l000001ooo
ool2o`000003ooooool0003o000001oooooo0_l00004ooooo`;o00001?ooool2o`0004Cooooo000L
ooooo`03o`000?oooooooooo08Oooooo0_l0000Goooooa;o00006?ooool5o`0000Cooooo0_l00000
1?oooooo0000o`000?l0000Nooooo`;o00002_ooool2o`0004Cooooo000Looooo`03o`000?oooooo
oooo083ooooo0_l0000>ooooo`;o00003_oooolCo`0001Gooooo2Ol00002ooooo`;o000000Cooooo
o`000?l0003o00008?ooool2o`000003ooooool0003o000000Sooooo0ol00010ooooo`007?ooool2
o`00087ooooo0_l00008ooooo`;o00001?ooool2o`0000kooooo5Ol0000Cooooo`Go000000?ooooo
o`000?l000000_l00004ooooo`;o00008Oooool2o`000003ooooool0003o000000Sooooo0ol00010
ooooo`007?ooool00ol0003oooooooooo`20ooooo`Co00001_ooool2o`0001?ooooo5ol0000Boooo
o`Co00000_ooool4o`0000Cooooo0ol0000Pooooo`;o00003Oooool2o`0003oooooo000Looooo`03
o`000?oooooooooo083ooooo1?l0000KoooooaOo00004_ooool2o`0000Gooooo0ol000000ooooooo
0000o`000002ooooo`;o00008oooool2o`0000[ooooo0_l0000oooooo`007?ooool00ol0003ooooo
ooooo`20ooooo`;o00002Oooool2o`0000Oooooo0_l00009oooooaGo000000?oooooo`000?l00000
4Oooool2o`0000Gooooo1_l00002ooooo`;o00008Oooool4o`0004_ooooo000Looooo`03o`000?oo
oooooooo083ooooo0_l00009ooooo`;o00000_ooool2o`0000?ooooo0_l00008oooooaKo000000?o
ooooo`000?l000004Oooool2o`0000Kooooo1?l00003ooooo`;o00008Oooool2o`0004gooooo000L
ooooo`03o`000?oooooooooo08Sooooo0_l00005ooooo`;o00000oooool2o`0000Sooooo5_l00000
0ooooooo0000o`000002o`0001Oooooo0ol00004ooooo`?o00008oooool2o`0004[ooooo000Loooo
o`03o`000?oooooooooo08Sooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o0000
00Sooooo5Ol00003ooooo`?o00005oooool5o`0000?ooooo0_l0000Sooooo`;o00001Oooool2o`00
00?ooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`2<ooooo`?o00000_ooool2o`0000go
oooo6Ol0000Gooooo`Go00000_ooool2o`0002_ooooo0_l00003ooooo`Co0000??ooool001cooooo
00?o0000ooooooooool0SOooool3o`0000kooooo6ol0000Gooooo`Co00000oooool3o`0002_ooooo
0_l00002ooooo`Co0000??ooool001cooooo00?o0000ooooooooool0I?ooool3o`0000Oooooo0_l0
000@ooooo`;o00002oooool5o`0000Kooooo1?l00002oooooa_o00006?ooool3o`0000?ooooo0ol0
000Vooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o0000?_ooool001cooooo00?o0000
ooooooooool0G?ooool2o`000003ooooool0003o000000?ooooo1Ol000000ooooooo0000o`000002
ooooo`Co00003_ooool2o`0000gooooo0ol00003ooooo`;o000000?oooooo`000?l000000_l00004
oooooaWo000000?oooooo`000?l000005_ooool2o`0000?ooooo0ol0000Vooooo`;o000000?ooooo
o`000?l000000oooool2o`0003oooooo000Looooo`03o`000?oooooooooo05cooooo0_l000000ooo
oooo0000o`000004ooooo`Co000000?oooooo`000?l000000_l00002ooooo`?o00007?ooool3o`00
00?ooooo0_l000000ooooooo0000o`000005oooooaOo000000Coooooo`000?l0003ooooo0_l00007
ooooo`;o00003Oooool2o`0000Cooooo0_l0000Uooooo`;o000000Coooooo`000?l0003o00000ooo
ool2o`0003oooooo000Looooo`03o`000?oooooooooo05Kooooo0_l00004ooooo`;o000000?ooooo
o`000?l000001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o
000000gooooo0_l0000=ooooo`Co000000?oooooo`000?l000000_ooool2o`0000Cooooo6ol0000:
ooooo`;o00003Oooool3o`0000?ooooo0_l0000Uooooo`;o000000Coooooo`000?l0003o0000A?oo
ool001cooooo00?o0000ooooooooool0E?ooool9o`0000;ooooo0_l000001?oooooo0000o`000?oo
ool2o`0000;ooooo0_l000000ooooooo0000o`000006o`0000cooooo0ol0000=ooooo`Ko00002?oo
oolKo`0000Wooooo0_l0000?ooooo`;o00000_ooool3o`0002cooooo1?l0000oooooo`0000Kooooo
onk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo
00?o0000ooooooooool0D_ooool5o`000003ooooool0003o000000?o00001Oooool2o`0000?ooooo
0_l00003ooooo`;o000000?oooooo`000?l000000ol0000=ooooo`;o00001oooool2o`0000Oooooo
0ol00009oooooa[o00002Oooool2o`0000oooooo0_l00002ooooo`?o0000:oooool5o`0003oooooo
00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0DOooool3o`0000gooooo0_l00004ooooo`;o00001oooool6o`0000[o
oooo0ol00007ooooo`;o00000_ooool2o`0000Cooooo0_l00005ooooo`;o000000?oooooo`000?l0
00005Ol000001?oooooo0000o`000?l0000Iooooo`?o00000_ooool3o`0002_ooooo0ol00011oooo
o`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`Go00001_ooool00ol0003o
ooooooooo`1@ooooo`?o00000_ooool2o`0000;ooooo0_l00005ooooo`?o00003_ooool7o`0000So
oooo1?l0000:ooooo`;o00002?ooool2o`000004ooooool0003o0000oooooa_o00006Oooool3o`00
00;ooooo0ol0000Uooooo`;o00002Oooool2o`0003gooooo00000ooooooo0000ooooo`02ooooo`03
o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`0004gooooo0_l000000ooo
oooo0000o`000003ooooo`Ko00001Oooool3o`000003ooooool0003o000000Gooooo0ol00005oooo
o`Go00002_ooool2o`0001Cooooo0_l00005oooooa[o00006?ooool4o`000003ooooool0003o0000
00;o00009Oooool2o`0000Wooooo0_l0000mooooo`0000?oooooo`000?ooool00_ooool00ol0003o
ooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0COooool2o`00
0003ooooool0003o000000Gooooo0_l00003ooooo`;o00001Oooool3o`0000Gooooo0ol00002oooo
o`;o000000?oooooo`000?l000000_l0000Hooooo`;o00003?ooool2o`0000;ooooo5ol0000Ioooo
o`Co000000?oooooo`000?l000000_l0000Uooooo`Co00002_ooool2o`000003ooooool0003o0000
03Oooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oMgMgolc<c?l0
00001oooool00ol0003oooooooooo`1=ooooo`;o00003?ooool4o`000004ooooool0003o0000oooo
o`;o00002oooool2o`000003ooooool0003o000000Co00005_ooool2o`0000cooooo0_l000000ooo
oooo0000o`00000Eo`0001Wooooo1Ol000000ooooooo0000o`000002o`0002Gooooo1?l000000ooo
oooo0000o`000006ooooo`?o000000?oooooo`000?l00000=oooool00006oooooomgMgOoV9RHoooo
oonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo04[ooooo0_l00000
0ooooooo0000o`000002ooooo`;o00001Oooool2o`000003ooooool0003o000000[o00003Oooool5
o`0000gooooo0_l0000Cooooo`Co000000?oooooo`000?l000005Ol0000Iooooo`Wo00009_ooool3
o`0000;ooooo0_l00006ooooo`;o0000>oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Ooo
ool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo04[ooooo0_l00005ooooo`;o00000_oo
ool7o`0000;ooooo2_l000000ooooooo0000o`000009ooooo`Ko00003?ooool2o`0001?ooooo0_l0
0005oooooaKo00005_ooool4o`0000;ooooo1Ol0000Vooooo`;o000000?oooooo`000?l000001Ooo
ool2o`0003kooooo000Looooo`03o`000?oooooooooo04_ooooo0_l000000ooooooo0000o`000003
ooooo`Go00000_oooolAo`0000Wooooo1_l0000Eooooo`;o00000oooool2o`0000Kooooo0_l00004
ooooo`Go000000?oooooo`000?l000003_l0000Fooooo`Co000000?oooooo`000?l000000ol0000Z
ooooo`;o00001Oooool2o`0003kooooo000Looooo`03o`000?oooooooooo04Gooooo0ol00003oooo
o`;o000000?oooooo`000?l000000oooool2o`0000?ooooo4ol0000<ooooo`?o00001Oooool4o`00
00cooooo0_l00002ooooo`?o00001_ooool2o`0000Gooooo1?l00002ooooo`[o00006Oooool2o`00
00?ooooo1_l0000booooo`;o00001Oooool2o`0003Oooooo000Looooo`03o`000?oooooooooo04Go
oooo0ol00004ooooo`Co00000oooool2o`0000;ooooo5Ol0000;ooooo`?o00001Oooool4o`00013o
oooo0_l0000>ooooo`?o00000oooool2o`0000?ooooo0_l00002ooooo`;o00005Oooool2o`000003
ooooool0003o000000Wo0000:?ooool2o`0000Sooooo1?l00003ooooo`;o0000=oooool001cooooo
00?o0000ooooooooool0@oooool4o`0000Gooooo0_l000000ooooooo0000o`000002o`0000;ooooo
6?l00007ooooo`;o00000_ooool2o`0000Gooooo1?l0000Xooooo`;o00001Oooool2o`0001?ooooo
1?l000000ooooooo0000o`000008o`0002Wooooo0_l0000:ooooo`;o0000??ooool001cooooo00?o
0000ooooooooool0@oooool2o`0000?ooooo0_l00005ooooo`Co00000_oooolIo`0000Kooooo0_l0
0002ooooo`;o00001Oooool5o`0000?ooooo0_l00004ooooo`;o00001_ooool2o`0000cooooo0_l0
0003ooooo`Go00000oooool3o`0001Cooooo3_l0000Dooooo`;o00008_ooool4o`0003Sooooo000L
ooooo`03o`000?oooooooooo04;ooooo0ol00003ooooo`;o00001Oooool3o`0000?ooooo7Ol00006
ooooo`;o00001oooool3o`0000?ooooo0_l00004ooooo`;o00001_ooool2o`0000_ooooo0ol00003
ooooo`Oo000000?oooooo`000?l000000_l0000Aooooo`co000000?oooooo`000?l000004_ooool2
o`000003ooooool0003o000002;ooooo1?l0000hooooo`007?ooool00ol0003oooooooooo`11oooo
o`?o00002oooool2o`0000Cooooo7Ol0000>ooooo`?o00007oooool2o`0000Kooooo1ol000000ooo
oooo0000o`00000Aooooo`Oo00005oooool2o`000003ooooool0003o000000?o0000G_ooool001co
oooo00?o0000ooooooooool0@?ooool3o`0000Oooooo0_l00003ooooo`;o00001?ooool7o`000003
ooooool0003o000000co000000?oooooo`000?l000000ol00007ooooo`;o00001_ooool2o`0000?o
oooo1?l0000Fooooo`;o00002Oooool8o`0001?ooooo1?l0000Booooo`;o00001_ooool2o`0000;o
oooo1?l0000Oooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0@?ooool4o`0000Kooooo
0_l00003ooooo`;o00000oooool8o`000003ooooool0003o000000co000000?oooooo`000?l00000
0ol00007ooooo`;o00002oooool5o`0001Gooooo0_l0000;ooooo`Ko00004?ooool6o`0000oooooo
0_l00002ooooo`?o00001?ooool2o`0000Gooooo0_l0000Oooooo`;o00001Oooool2o`0003Kooooo
000Looooo`03o`000?oooooooooo03oooooo1Ol000000ooooooo0000o`000003ooooo`Go00001Ooo
oolNo`000003ooooool0003o000000;ooooo0_l0000?ooooo`;o00009?ooool7o`0000Sooooo2?l0
000?ooooo`_o00000oooool2o`0000Gooooo1Ol0000Kooooo`;o00001_ooool2o`0003Kooooo000L
ooooo`03o`000?oooooooooo03oooooo0ol00003ooooo`;o00000oooool5o`0000Gooooo7_l00000
0ooooooo0000o`000002ooooo`;o00000oooool2o`0000;ooooo0_l00004ooooo`;o00003?ooool2
o`0001?ooooo0_l000001?oooooo0000o`000?oooolCo`0000oooooo3_l00005ooooo`;o00000ooo
ool5o`0001Sooooo0_l000000ooooooo0000o`000006ooooo`;o0000=_ooool001cooooo0_l0000o
ooooo`?o00001Oooool2o`0000Gooooo0_l00007oooooaoo00001oooool2o`0000;ooooo0_l00004
ooooo`;o00003?ooool2o`000003ooooool0003o000000cooooo0_l00002ooooo`Go00001?ooool2
o`000003ooooool0003o000000Oo00002_ooool8o`000003ooooool0003o000000;o00000oooool6
o`0000Kooooo0_l00004ooooo`?o00006Oooool2o`0000Wooooo0_l0000fooooo`007?ooool00ol0
003oooooooooo`0nooooo`;o00001Oooool3o`0000Cooooo0ol00007oooooago00000oooool2o`00
00Cooooo0_l0000Gooooo`Co00003?ooool2o`0000Cooooo0_l000000ooooooo0000o`000002oooo
o`Co00000_ooool2o`0000[ooooo0_l000000ooooooo0000o`000007o`0000?ooooo0_l0000Eoooo
o`Co0000Foooool001cooooo00?o0000ooooooooool0?oooool2o`0000;ooooo1?l00005ooooo`?o
00002OoooolKo`0000;ooooo0ol00003ooooo`Oo00004oooool2o`0000gooooo0_l00008ooooo`;o
000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00002Oooool3o`000003ooooool0003o0000
00cooooo0ol0000>ooooo`;o00000_ooool4o`0001Kooooo0_l00008ooooo`?o0000>?ooool001co
oooo00?o0000ooooooooool0?Oooool4o`0000;ooooo0_l00008ooooo`;o00002Oooool2o`000003
ooooool0003o000001Ko00000_ooool3o`0000?ooooo0_l000000ooooooo0000o`000002o`0002;o
oooo0_l00004ooooo`Co00000oooool6o`000003ooooool0003o000000?o00001_ooool2o`0000;o
oooo0_l0000<ooooo`?o00002_ooool3o`000003ooooool0003o000000Ko00005_ooool2o`0000So
oooo0ol0000hooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00003Oooool3o`0000Wooooo
1ol000000ooooooo0000o`00000?o`0000Wooooo0ol0000]ooooo`Go00000oooool2o`000003oooo
ool0003o000000?ooooo1?l00009ooooo`?o00003_ooool2o`0000Sooooo0ol00003ooooo`Go0000
4oooool2o`0000Oooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00000_oo
ool2o`0000;ooooo0_l00005ooooo`?o00002OoooolIo`0000Wooooo0_l00006ooooo`;o0000:Ooo
ool2o`0000?ooooo0_l00002ooooo`;o00001?ooool9o`0000?ooooo0_l00009ooooo`;o00000_oo
ool3o`00013ooooo0ol0000Cooooo`?o000000Coooooo`000?l0003o00000_ooool3o`0000;ooooo
0_l0000iooooo`007?ooool00ol0003oooooooooo`0jooooo`;o000000Goooooo`000?l0003o0000
ooooo`02o`0000;ooooo0_l0000CoooooaOo000000Coooooo`000?l0003o00001?ooool2o`0000Oo
oooo0_l0000Jooooo`;o00000oooool2o`0000gooooo0_l00002ooooo`;o00001_ooool7o`0000So
oooo1Ol000000ooooooo0000o`000002ooooo`;o00002Oooool2o`0000Kooooo1Ol0000Aooooo`?o
000000Coooooo`000?l0003o00000oooool2o`0000;ooooo0ol0000hooooo`007?ooool00ol0003o
ooooooooo`0jooooo`;o00000_ooool2o`000003ooooool0003o000000Kooooo0_l0000@oooooa[o
00001?ooool2o`000003ooooool0003o000000Gooooo0_l0000@ooooo`;o00001oooool2o`0000?o
oooo0_l0000Mooooo`;o00001_ooool2o`000003ooooool0003o000000?o00004?ooool2o`0000?o
oooo2?l0000Pooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0?oooool2o`000003oooo
ool0003o000000Gooooo0_l0000@oooooa;o00000_ooool5o`0000Cooooo0_l00002ooooo`;o0000
1Oooool2o`0000kooooo1?l0000[ooooo`Co00001?ooool3o`0000;ooooo0_l00004ooooo`Co0000
00Coooooo`000?l0003ooooo0_l00008ooooo`Co000000?oooooo`000?l000003oooool2o`0000Co
oooo0_l00003ooooo`;o00001?ooool3o`0003Sooooo000Looooo`03o`000?oooooooooo03[ooooo
0_l00003ooooo`;o000000?oooooo`000?l000001?ooool3o`0000Cooooo0_l0000<ooooo`oo0000
0oooool3o`0000Kooooo0_l00002ooooo`;o00005Oooool2o`0001;ooooo0_l0000Iooooo`Go0000
1?ooool2o`0000;ooooo0_l00004ooooo`Co000000Coooooo`000?l0003ooooo0_l00007ooooo`So
00003oooool2o`0000;ooooo1?l000000ooooooo0000o`000002o`000004ooooool0003o0000oooo
o`;o0000>Oooool001cooooo00?o0000ooooooooool0>_ooool2o`0000Cooooo0_l00006ooooo`;o
00001Oooool5o`0000_ooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00001Oooool4o`00
00Cooooo0ol00003ooooo`;o00007_ooool2o`0000Wooooo0_l00003ooooo`;o00002oooool2o`00
00Gooooo0_l00003ooooo`Co00000_ooool2o`0000Sooooo0_l00009ooooo`;o00001?ooool6o`00
01Gooooo0ol00002ooooo`Oo0000??ooool001cooooo00?o0000ooooooooool0>?ooool2o`0000Ko
oooo0_l00005ooooo`;o00002?ooool4o`0000[ooooo0_l000001Ooooooo0000o`000?l0003ooooo
00?o000000?oooooo`000?l000001?l00006ooooo`?o00001oooool2o`0001Kooooo0_l00002oooo
o`;o00003_ooool2o`0000_ooooo0_l00005ooooo`;o00001Oooool2o`0000;ooooo0_l0000Coooo
o`;o000000?oooooo`000?l000001_l0000Aooooo`Co00002?ooool5o`0003cooooo000Looooo`03
o`000?oooooooooo03Sooooo0_l0000=ooooo`;o00002_ooool2o`00017ooooo0ol000000ooooooo
0000o`000002o`0000[ooooo0_l00006ooooo`;o00005_ooool2o`00017ooooo0_l00002ooooo`;o
00003Oooool4o`0000Gooooo0_l00004ooooo`;o00004_ooool9o`000003ooooool0003o000000oo
oooo1Ol00008ooooo`;o00000_ooool2o`0003[ooooo000Looooo`03o`000?oooooooooo03Oooooo
1?l0000Gooooo`Go00004oooool2o`0000cooooo0_l0000Rooooo`;o00001?ooool2o`0000Cooooo
0_l000000ooooooo0000o`000002ooooo`;o00003Oooool4o`0000;ooooo0_l000000ooooooo0000
o`000004ooooo`Go00000_ooool2o`0000?ooooo5?l0000Booooo`;o00000oooool2o`0000?ooooo
0_l00002ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0=oooool4o`0000Oooooo0_l0
0005ooooo`;o00001oooool6o`0001Wooooo0_l0000Yooooo`Co00000_ooool2o`0000Cooooo0_l0
0002ooooo`;o000000Coooooo`000?l0003o00004_ooool2o`0000Kooooo1_l00002oooooa3o0000
00Goooooo`000?l0003o0000ooooo`02o`0001Sooooo0ol00013ooooo`007?ooool00ol0003ooooo
ooooo`11ooooo`?o00000_ooool2o`000003ooooool0003o000000Wooooo2?l0000Cooooo`Co0000
3oooool2o`0001Wooooo0ol0000<ooooo`;o000000Coooooo`000?l0003o00004_ooool2o`0000Ko
oooo0_l00006ooooo`Go000000?oooooo`000?l000000_l000000ooooooo0000o`000003o`000003
ooooool0003o000001cooooo0_l00004ooooo`;o0000?_ooool001cooooo0_l0000gooooo`;o0000
00?oooooo`000?l000001Oooool3o`0000?ooooo0_l00002ooooo`;o00002?ooool2o`0000;ooooo
1_l0000>ooooo`Ko00001Oooool2o`0000Wooooo0_l0000Qooooo`;o00000_ooool5o`0001Kooooo
0_l00007ooooo`;o0000<oooool4o`0000?ooooo0ol0000mooooo`007?ooool00ol0003ooooooooo
o`0fooooo`Ko00001?ooool2o`0000Sooooo0_l0000<ooooo`So00000_ooool3o`0000?ooooo2_l0
0005ooooo`;o0000:_ooool4o`0000;ooooo0ol0000=ooooo`;o00002oooool2o`0000?ooooo1?l0
0002ooooo`;o0000:oooool2o`0000;ooooo1?l00002ooooo`Co0000?Oooool001cooooo00?o0000
ooooooooool0=_ooool3o`000003ooooool0003o000000Cooooo0_l00006ooooo`;o00001oooool2
o`0000;ooooo7?l0000Cooooo`;o00007Oooool2o`0000Gooooo0_l00003ooooo`;o00002?ooool2
o`0000;ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00003ooooo`;o00001?ooool3
o`0002Kooooo0_l00002ooooo`;o00000_ooool2o`0000Cooooo0_l0000oooooo`007?ooool00ol0
003oooooooooo`0fooooo`?o00001oooool2o`0000Kooooo0_l00007ooooo`;o00000_ooool6o`00
0004ooooool0003o0000ooooo`Wo00001Oooool4o`0000Cooooo0_l0000=ooooo`;o00009?ooool2
o`000003ooooool0003o000000;o00003?ooool2o`000003ooooool0003o000000;o00001Oooool4
o`0000Cooooo0ol0000Vooooo`;o00000oooool5o`0004Gooooo000Looooo`03o`000?oooooooooo
03Kooooo0ol0000Fooooo`;o000000?oooooo`000?l000002?ooool2o`0000oooooo0_l00005oooo
o`?o00000oooool2o`00037ooooo0_l00006ooooo`?o00001oooool2o`000003ooooool0003o0000
00;ooooo0_l000001?oooooo0000o`000?l00002ooooo`?o00000_ooool2o`0001Cooooo0_l0000D
ooooo`Ko0000A?ooool001cooooo00?o0000ooooooooool0=_ooool3o`0000Oooooo0_l00002oooo
o`;o000000?oooooo`000?l000000_l00003ooooo`?o000000?oooooo`000?l000004Oooool2o`00
00Wooooo0_l00002ooooo`;o00001?ooool2o`0000;ooooo0_l0000Vooooo`;o00000_ooool2o`00
00Wooooo0ol00003ooooo`?o000000?oooooo`000?l000000ol00002ooooo`?o000000?oooooo`00
0?l000000_ooool3o`0000;ooooo0_l00004ooooo`;o00003_ooool2o`000004ooooool0003o0000
o`0000?ooooo0_l0000>ooooo`?o00000oooool2o`0003oooooo000Looooo`03o`000?oooooooooo
03Kooooo1Ol00005ooooo`?o000000Coooooo`000?l0003ooooo1?l00003ooooo`Co00001oooool2
o`0000[ooooo0_l00008ooooo`Go00002_ooool2o`0000oooooo0_l0000Eooooo`;o00000_ooool2
o`0000Wooooo1?l000000ooooooo0000o`000009o`0000;ooooo0_l0000:ooooo`;o000000Cooooo
o`000?l0003ooooo0_l0000Aooooo`?o00000oooool2o`000003ooooool0003o000000;ooooo0ol0
000<ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0=oooool4o`0000;ooooo0_l00000
1?oooooo0000o`000?l0000=ooooo`;o00001oooool2o`0000Wooooo0_l00009ooooo`;o000000?o
ooooo`000?l000005Oooool2o`0000Cooooo0_l00009ooooo`;o00006OoooolBo`0000cooooo0_l0
00001?oooooo0000o`000?ooool2o`0000cooooo0_l0000;ooooo`?o00000_ooool3o`0004gooooo
000Looooo`03o`000?oooooooooo03Oooooo0_l00003ooooo`?o000000?oooooo`000?l000000ooo
ool2o`0001gooooo0_l00007ooooo`;o00001?ooool2o`0001Cooooo0_l00007ooooo`;o00001_oo
ool2o`0000Cooooo1?l00005ooooo`;o00001_ooool2o`0000Gooooo3ol0000Booooo`;o000000?o
ooooo`000?l000002Oooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o00001ooo
ool4o`0000Sooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0eooooo`Go00000_ooool3
o`0000Gooooo0ol0000Aooooo`Co00004Oooool2o`0000Cooooo0_l0000Mooooo`Co00002_ooool6
o`0000?ooooo0ol00005ooooo`?o00000ooooolAo`0000Oooooo0ol0000:ooooo`;o00003?ooool2
o`0000;ooooo0_l00004ooooo`;o00001oooool4o`0000Sooooo0_l0000nooooo`007?ooool00ol0
003oooooooooo`0eooooo`Ko000000?oooooo`000?l000001_ooool2o`0001;ooooo1?l0000=oooo
o`;o0000:Oooool2o`0000kooooo0_l00004ooooo`;o00001_ooool2o`0000?ooooo4_l00004oooo
o`Go00006?ooool2o`0000;ooooo0_l0000:ooooo`;o0000COooool001cooooo00?o0000oooooooo
ool0=Oooool6o`0000Oooooo0_l0000Jooooo`Co00001oooool2o`0002Cooooo0_l0000Cooooo`;o
00001?ooool2o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l0
00003_l00003ooooo`?o00006_ooool2o`0000;ooooo0_l00006ooooo`;o00000_ooool2o`000003
ooooool0003o000004[ooooo000Looooo`03o`000?oooooooooo03Gooooo0_l000000ooooooo0000
o`000007ooooo`?o00006_ooool4o`000003ooooool0003o000000Cooooo0_l00005ooooo`;o0000
7Oooool2o`0001?ooooo1?l00002ooooo`;o00000oooool2o`0000Cooooo5_l00002ooooo`;o0000
7oooool2o`0000Kooooo0_l00005ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0>?oo
ool2o`0000Oooooo0ol0000Oooooo`;o00001?ooool2o`0000Gooooo0_l0000Mooooo`;o00005Ooo
ool2o`0000;ooooo0_l00009oooooa[o00002?ooool2o`0000Oooooo0_l0000Rooooo`Co0000@Ooo
ool001cooooo00?o0000ooooooooool0=_ooool4o`0000Kooooo0_l0001Sooooo`;o00003_oooolH
o`0000;ooooo0_l00006ooooo`;o00001_ooool3o`0000?ooooo0ol000000ooooooo0000o`000002
o`000003ooooool0003o000001Cooooo1?l00011ooooo`007?ooool00ol0003oooooooooo`0foooo
o`Co00001_ooool2o`0002?ooooo0_l0000=ooooo`;o00009_ooool2o`0000Oooooo1?l0000=oooo
oa3o000000?oooooo`000?l000001?l00002ooooo`;o00002ooooolDo`000003ooooool0003o0000
013ooooo1Ol00011ooooo`007?ooool2o`0003Oooooo1?l0000[ooooo`;o00003Oooool2o`0002;o
oooo0_l00002ooooo`;o00002Oooool2o`0000gooooo4?l000000ooooooo0000o`000002o`0000;o
oooo0_l000000ooooooo0000o`000007oooooaKo00000_ooool2o`0000[ooooo0_l00004ooooo`Go
0000@Oooool001cooooo00?o0000ooooooooool0=_ooool3o`0005oooooo0_l0000@ooooo`;o0000
0_ooool2o`0000Gooooo5_l00002ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0000;o
oooo0ol000000ooooooo0000o`00000@o`000004ooooool0003o0000o`0000[ooooo0_l00006oooo
o`;o0000@_ooool001cooooo00?o0000ooooooooool0=_ooool2o`0002Kooooo0_l0000=ooooo`;o
00007Oooool2o`0000Kooooo0_l0000Dooooo`;o00000_ooool2o`0000Gooooo5_l00003ooooo`;o
000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000001Wo00000oooool2o`0000[o
oooo0_l00015ooooo`007?ooool00ol0003oooooooooo`0fooooo`So00007_ooool9o`0000Sooooo
0_l00003ooooo`;o00006?ooool2o`0000Kooooo0ol00002ooooo`;o000000?oooooo`000?l00000
1oooool2o`0000Gooooo0_l00009oooooaCo00000oooool2o`0000?ooooo1?l000000ooooooo0000
o`00000No`0000[ooooo0ol00014ooooo`007?ooool00ol0003oooooooooo`0fooooo`So00007_oo
ool3o`000003ooooool0003o000000?o000000Coooooo`000?l0003o00001Oooool2o`0000;ooooo
0_l0000:ooooo`;o00003_ooool2o`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l00000
0_l00005ooooo`;o00001Oooool2o`0000Wooooo5?l00008ooooo`_o000000?oooooo`000?l00000
5Ol0000=ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0=_ooool7o`0001gooooo1Ol0
0004ooooo`Ko00001Oooool4o`0000cooooo0_l0000<ooooo`Co00003_ooool2o`0001Gooooo5_l0
0007ooooo`?o00000_ooool7o`000003ooooool0003o000001Co00002Oooool4o`0004Oooooo000L
ooooo`03o`000?oooooooooo03Sooooo1?l0000Nooooo`Co00001_ooool2o`0000;ooooo1?l00004
ooooo`;o00003oooool2o`0000Wooooo0ol0000:ooooo`;o00006_ooool2o`0000;ooooo4Ol00008
ooooo`;o00000_ooool7o`000003ooooool0003o000001Go00000_ooool2o`0000?ooooo1_l00017
ooooo`007?ooool00ol0003oooooooooo`1Jooooo`Co00001?ooool4o`0000;ooooo1ol0000Boooo
o`;o00002?ooool3o`0000Oooooo0_l00002ooooo`;o00000oooool2o`0001Oooooo4Ol00005oooo
o`Ko000000?oooooo`000?l000008?l000001Ooooooo0000o`000?l0003ooooo00Ko0000B?ooool0
01cooooo00?o0000ooooooooool0F_ooool4o`0000Cooooo1?l00002ooooo`Wo00006_ooool5o`00
00Gooooo0_l00007ooooo`?o00005_ooool@o`000005ooooool0003o0000o`000?ooool01ol00000
0ooooooo0000o`000002o`0000;ooooo7?l00002ooooo`;o000000Coooooo`000?l0003ooooo0ol0
0018ooooo`007?ooool00ol0003oooooooooo`1Jooooo`;o00002?ooool2o`0000;ooooo0_l00005
ooooo`Go00001_ooool2o`0001;ooooo0_l0000?ooooo`;o00005_ooool=o`0000;ooooo1Ol00000
1?oooooo0000o`000?ooool2o`0000?ooooo1?l00002ooooo`Co000000?oooooo`000?l000005?l0
0004ooooo`;o000000?oooooo`000?l000000_l00019ooooo`007?ooool00ol0003oooooooooo`1I
ooooo`?o00001oooool3o`0000_ooooo1?l00005ooooo`?o0000>?ooool9o`000004ooooool0003o
0000o`0000Cooooo0_l000000ooooooo0000o`000009ooooo`Ko000000?oooooo`000?l000000ooo
oolGo`0000;ooooo0_l000000ooooooo0000o`00001;ooooo`007?ooool00ol0003oooooooooo`1H
ooooo`Ko00001Oooool2o`0000Kooooo0_l00005ooooo`?o00001_ooool2o`0000Gooooo0_l0000C
ooooo`;o00000_ooool2o`0001Sooooo0_l000000ooooooo0000o`000003o`000004ooooool0003o
0000ooooo`?o00001Oooool2o`0000Kooooo3?l00003oooooaOo00000oooool2o`0004gooooo000L
ooooo`03o`000?oooooooooo05Sooooo0ol000000ooooooo0000o`00000=ooooo`Go00000oooool2
o`0000gooooo0_l0000=ooooo`;o00001?ooool2o`0000;ooooo0_l0000Iooooo`Ko00000_ooool6
o`0000Gooooo0_l00006ooooo`Co000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l00002
oooooa;o00001?ooool3o`0004gooooo000Looooo`03o`000?oooooooooo05Sooooo1Ol00002oooo
o`;o00002oooool4o`0000Oooooo0_l0000=ooooo`Go00001_ooool2o`0000Wooooo1?l00002oooo
o`;o00004_ooool4o`0000;ooooo2Ol00008ooooo`;o00001oooool2o`0000Oooooo1?l000000ooo
oooo0000o`000009o`0000Gooooo1ol0001>ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5
ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0Eooo
ool6o`0000;ooooo0_l00003ooooo`;o00004Oooool4o`0000Kooooo0_l00003ooooo`Go00002Ooo
ool2o`0000Kooooo1?l00002ooooo`;o00004oooool>o`000003ooooool0003o000000?ooooo1?l0
000Aooooo`?o00000oooool9o`000003ooooool0003o000000So0000Coooool00006oooooomgMgOo
V9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03
o`000?oooooooooo05Oooooo1_l00002ooooo`;o00000oooool2o`0001?ooooo0_l00006ooooo`?o
00004?ooool2o`0000Oooooo0_l0000Kooooo`;o00000oooool3o`000004ooooool0003o0000oooo
o`;o00000_ooool5o`0001Oooooo0_l00004ooooo`;o00000_ooool5o`000003ooooool0003o0000
057ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo05Sooooo0_l000000ooooooo0000o`00000Eoooo
o`?o00001?ooool5o`0000Cooooo0_l00003ooooo`;o00001oooool2o`0000Cooooo0ol00004oooo
o`;o00006Oooool2o`000004ooooool0003o0000ooooo`Co000000?oooooo`000?l000001?l00000
1?oooooo0000o`000?l0000Iooooo`Ko000000?oooooo`000?l00000F_ooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0
001Kooooo`;o00002_ooool2o`0000Wooooo0ol00006ooooo`?o00002?ooool3o`0000Oooooo0_l0
0004ooooo`?o00007oooool2o`000004ooooool0003o0000ooooo`Go00000_ooool4o`0001oooooo
1?l000000ooooooo0000o`00001Jooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooooooo
o`09ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`1Mooooo`;o0000
1_ooool4o`000003ooooool0003o000000?o00000oooool2o`0000Wooooo0_l00007ooooo`;o0000
0oooool2o`0000Gooooo0_l00005ooooo`?o00002Oooool2o`0001[ooooo0_l00004ooooo`;o0000
P?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7oooo
o`08ooooo`03o`000?oooooooooo05Kooooo0_l00004ooooo`?o00000_ooool3o`000003ooooool0
003o000000;o000000?oooooo`000?l000000ol00003ooooo`;o00002?ooool3o`0000cooooo0_l0
0005ooooo`;o00001Oooool3o`0000;ooooo1?l00003ooooo`;o00006?ooool2o`0008Sooooo0000
1_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003ooooo
ooooo`1Fooooo`Co00000_ooool2o`0000;ooooo4?l00004ooooo`?o00001?ooool3o`000003oooo
ool0003o0000017ooooo0_l00005ooooo`;o00000oooool4o`0001gooooo0_l00028ooooo`0000Ko
ooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000oooo
ooooool0EOooool2o`000003ooooool0003o000000Kooooo5ol00004ooooo`Ko00001?ooool2o`00
013ooooo1_l000001?oooooo0000o`000?l0002Xooooo`007?ooool00ol0003oooooooooo`1Eoooo
o`;o00001Oooool2o`0000Cooooo0_l000000ooooooo0000o`00000=o`0000Cooooo0_l00002oooo
o`Co00001Oooool3o`0000cooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o000000?ooooo
o`000?l00000ZOooool001cooooo00?o0000ooooooooool0G?ooool2o`0000Oooooo4?l00003oooo
o`Ko00001?ooool2o`0000;ooooo0_l0000<ooooo`;o000000Coooooo`000?l0003o0000[oooool0
01cooooo00?o0000ooooooooool0E_ooool2o`0000Cooooo0_l00007oooooa7o00001?ooool2o`00
00?ooooo0_l000000ooooooo0000o`000009ooooo`;o0000^_ooool001cooooo00?o0000oooooooo
ool0E_ooool4o`000004ooooool0003o0000o`0000Kooooo4_l00009ooooo`;o000000?oooooo`00
0?l000002Oooool2o`0000Sooooo0_l0002`ooooo`007?ooool00ol0003oooooooooo`1Gooooo`?o
000000?oooooo`000?l000001ooooolDo`0000Oooooo0_l000001?oooooo0000o`000?l00003oooo
o`;o00003?ooool3o`000;3ooooo000Looooo`03o`000?oooooooooo05Gooooo0_l000000ooooooo
0000o`000003o`0000Gooooo5ol00006ooooo`;o000000Coooooo`000?l0003o00000oooool2o`00
00cooooo0_l0000Kooooo`;o0000U?ooool001cooooo00?o0000ooooooooool0EOooool8o`0000Go
oooo5ol0000:ooooo`;o0000;_ooool2o`0009Cooooo000Looooo`03o`000?oooooooooo05Oooooo
1?l00007oooooaKo00002oooool2o`0000Cooooo0_l000000ooooooo0000o`00002kooooo`007?oo
ool00ol0003oooooooooo`1Cooooo`;o00003OoooolGo`0000Wooooo0ol000000ooooooo0000o`00
0003o`000003ooooool0003o000002Oooooo0_l0002Booooo`007?ooool00ol0003oooooooooo`1C
ooooo`;o00001Oooool2o`0000Kooooo5ol00009ooooo`;o00000_ooool4o`0000Gooooo0_l0000T
ooooo`;o0000T_ooool001cooooo00?o0000ooooooooool0Doooool4o`000003ooooool0003o0000
00;o00001_oooolGo`0000Sooooo0ol00002ooooo`;o00001oooool2o`0000gooooo1ol0002Toooo
o`007?ooool2o`0005Kooooo0_l000000ooooooo0000o`000002o`0000Kooooo5ol00007ooooo`?o
00000oooool3o`0000;ooooo0_l0000@ooooo`So00000_ooool6o`0009cooooo000Looooo`03o`00
0?oooooooooo06?ooooo5_l00003ooooo`?o000000?oooooo`000?l000001Oooool2o`0000;ooooo
0_l0000=ooooo`;o000000?oooooo`000?l000003ol0002Kooooo`007?ooool00ol0003ooooooooo
o`1Cooooo`;o00000oooool2o`0000Wooooo5_l00003ooooo`?o00006_ooool3o`000003ooooool0
003o000000[o00000_ooool4o`0005Cooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`1C
ooooo`;o00000oooool4o`0000Sooooo5ol0000Nooooo`So000000?oooooo`000?l000002ol00007
ooooo`;o0000Boooool2o`0004Cooooo000Looooo`03o`000?oooooooooo05Sooooo1?l00009oooo
oaKo00006_ooool3o`0000?ooooo5Ol00006ooooo`;o0000Aoooool2o`0004Sooooo000Looooo`03
o`000?oooooooooo05Sooooo0_l0000=oooooa?o00001_ooool2o`0001?ooooo1ol000000ooooooo
0000o`00000Ao`0004oooooo0_l000000ooooooo0000o`000015ooooo`007?ooool00ol0003ooooo
ooooo`1Woooooa;o00000_ooool3o`0000;ooooo0_l0000Boooooaco0000BOooool2o`0000Cooooo
0_l000000ooooooo0000o`000015ooooo`007?ooool00ol0003oooooooooo`1Cooooo`?o00004Ooo
ool3o`0000;ooooo3Ol000000ooooooo0000o`000002o`000003ooooool0003o000001;ooooo7_l0
0005ooooo`;o0000@Oooool2o`0004kooooo000Looooo`03o`000?oooooooooo05?ooooo0ol00006
ooooo`;o00002_ooool@o`0000;ooooo0_l000000ooooooo0000o`000002o`00017ooooo7ol00005
ooooo`;o0000@_ooool2o`0004gooooo000Looooo`03o`000?oooooooooo05Gooooo0_l00005oooo
o`;o00003?ooool9o`0000;ooooo0ol00005ooooo`;o00004oooool2o`000003ooooool0003o0000
01_o00000_ooool5o`00047ooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`1Eooooo`;o
00001Oooool2o`00013ooooo1Ol00002ooooo`;o00007ooooolSo`0003_ooooo0ol00007ooooo`;o
0000BOooool001cooooo00?o0000ooooooooool0E_ooool2o`0000?ooooo0_l0000cooooo`Go0000
00?oooooo`000?l000008?l0000looooo`?o00001Oooool4o`0004Wooooo000Looooo`03o`000?oo
oooooooo05Kooooo0_l00003ooooo`;o000000?oooooo`000?l000007Oooool2o`00017ooooo2ol0
00000ooooooo0000o`00000Io`00043ooooo0_l00003ooooo`;o0000Boooool001cooooo00?o0000
ooooooooool0GOooool3o`0001gooooo0_l0000@ooooobSo0000@?ooool2o`0000;ooooo0ol0001;
ooooo`007?ooool00ol0003oooooooooo`1Mooooo`Co0000;_ooool3o`0000Cooooo6Ol000000ooo
oooo0000o`000007o`00047ooooo0ol0001<ooooo`007?ooool00ol0003oooooooooo`1Eooooo`;o
00001oooool6o`0002_ooooo0ol00004oooooago000000Coooooo`000?l0003ooooo0_l00011oooo
o`?o0000C?ooool001cooooo0_l0001Fooooo`;o00001oooool7o`0000Oooooo0_l00005ooooo`?o
00006Oooool3o`0000?ooooo7_l00002ooooo`;o0000T_ooool001cooooo00?o0000ooooooooool0
EOooool2o`0000Oooooo1ol00003ooooo`Ko00001Oooool3o`0001Wooooo0_l00004oooooago0000
0oooool2o`0003gooooo0_l00002ooooo`;o0000Coooool001cooooo00?o0000ooooooooool0H?oo
ool5o`000003ooooool0003o000000Co00000oooool2o`0001kooooo1?l00003oooooaCo000000?o
ooooo`000?l000001_l000000ooooooo0000o`00000nooooo`;o00000_ooool2o`0004oooooo000L
ooooo`03o`000?oooooooooo063ooooo0_l000001?oooooo0000o`000?ooool2o`0000Oooooo0_l0
000Nooooo`Co00001?ooool@o`000003ooooool0003o000000Wo000000?oooooo`000?l00000?_oo
ool2o`0005?ooooo000Looooo`03o`000?oooooooooo05[ooooo0ol00003ooooo`Co000000Gooooo
o`000?l0003o0000ooooo`02o`0000;ooooo0_l0000Pooooo`?o00001OoooolMo`00047ooooo0_l0
001Booooo`007?ooool00ol0003oooooooooo`1Jooooo`?o00001Oooool5o`0000;ooooo0_l00002
ooooo`;o00008?ooool3o`0000[ooooo1_l00003ooooo`co000000?oooooo`000?l00000=_ooool2
o`0000Oooooo1?l0001Booooo`007?ooool00ol0003oooooooooo`1Sooooo`Co0000:?ooool3o`00
0004ooooool0003o0000o`0000Oooooo3?l000000ooooooo0000o`000006o`0003Sooooo0_l00007
ooooo`?o0000Doooool001cooooo00?o0000ooooooooool0IOooool2o`0002Wooooo0_l000000ooo
oooo0000o`000002o`0000Cooooo0_l00003ooooo`Wo000000?oooooo`000?l000000_ooool4o`00
03Kooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l0001Eooooo`007?ooool00ol0003o
ooooooooo`1Jooooo`;o0000=?ooool2o`0000?ooooo0_l00004ooooo`;o00001Oooool2o`0000;o
oooo0_l00009ooooo`;o0000=Oooool2o`000003ooooool0003o000000;o000000?oooooo`000?l0
00000_l0001Eooooo`007?ooool00ol0003oooooooooo`1Jooooo`;o0000=Oooool2o`0000oooooo
0_l00004ooooo`?o00001_ooool2o`0003Gooooo0_l000000ooooooo0000o`000002o`0005[ooooo
000Looooo`03o`000?oooooooooo05gooooo0_l0000booooo`?o00000oooool2o`0000oooooo0ol0
0003ooooo`;o0000>?ooool2o`0000;ooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`1M
ooooo`;o0000<oooool3o`0000;ooooo0_l0000>ooooo`Go00000_ooool2o`0003cooooo0_l00000
0ooooooo0000o`00001Hooooo`007?ooool00ol0003oooooooooo`1Jooooo`Go0000<oooool4o`00
0003ooooool0003o000000kooooo1ol000000ooooooo0000o`00000Zooooo`Co00003oooool3o`00
05Sooooo000Looooo`03o`000?oooooooooo05[ooooo1Ol0000cooooo`Co00004oooool2o`000004
ooooool0003o0000ooooo`;o0000:_ooool4o`0000Cooooo0_l00009ooooo`;o0000FOooool001co
oooo00?o0000ooooooooool0G?ooool6o`00037ooooo1Ol0000mooooo`;o00001?ooool2o`0000Ko
oooo0ol0001Sooooo`007?ooool00ol0003oooooooooo`1Looooo`;o000000Coooooo`000?l0003o
0000<_ooool4o`0000;ooooo0_l0000iooooo`;o00003Oooool2o`0006?ooooo000Looooo`;o0000
G_ooool2o`0003Gooooo1Ol000000ooooooo0000o`000014ooooo`Co0000IOooool001cooooo00?o
0000ooooooooool0GOooool2o`0003Oooooo0ol00007ooooo`;o0000>oooool2o`000003ooooool0
003o000000;o0000IOooool001cooooo00?o0000ooooooooool0HOooool2o`0003Cooooo0ol00006
ooooo`;o0000=Oooool2o`0000Cooooo0_l000000ooooooo0000o`000006ooooo`?o0000G_ooool0
01cooooo00?o0000ooooooooool0HOooool2o`0003Cooooo1?l0000<ooooo`;o0000;_ooool2o`00
00;ooooo0ol00002ooooo`;o00001_ooool3o`0005kooooo000Looooo`03o`000?oooooooooo09So
oooo1?l0000;ooooo`?o0000<Oooool6o`0000Gooooo0_l000000ooooooo0000o`00001Nooooo`00
7?ooool00ol0003oooooooooo`2Jooooo`;o00003?ooool2o`0000Gooooo0_l0000Hooooo`?o0000
0oooool2o`0000[ooooo0_l000001?oooooo0000o`000?l00003ooooo`Co0000HOooool001cooooo
00?o0000ooooooooool0Ioooool2o`0003Cooooo0ol000000ooooooo0000o`000002o`0000Oooooo
0_l000000ooooooo0000o`00000?ooooo`;o00000oooool2o`0000;ooooo0ol00003ooooo`;o0000
2_ooool2o`0000;ooooo0_l00003ooooo`?o0000H_ooool001cooooo00?o0000ooooooooool0IOoo
ool4o`0003Cooooo2?l00007ooooo`;o00000_ooool2o`0000?ooooo0_l00007ooooo`Co00000ooo
ool2o`0000;ooooo0_l00008ooooo`;o00001_ooool2o`0000;ooooo0_l00004ooooo`;o0000H_oo
ool001cooooo00?o0000ooooooooool0I?ooool5o`0003Gooooo1ol00004ooooo`;o00001Oooool4
o`000003ooooool0003o000000Oooooo0ol00004ooooo`;o00000_ooool4o`0000Kooooo0_l00004
ooooo`;o000000Coooooo`000?l0003ooooo0_l0001Xooooo`007?ooool00ol0003oooooooooo`1T
ooooo`;o000000?oooooo`000?l000000oooool2o`00037ooooo1_l00004ooooo`?o00001_ooool3
o`0000Kooooo0_l00004ooooo`;o00001?ooool2o`0000;ooooo0_l00004ooooo`;o00001?ooool4
o`000004ooooool0003o0000ooooo`;o0000J?ooool001cooooo00?o0000ooooooooool0K?ooool3
o`0003;ooooo1?l000000ooooooo0000o`000004o`0000Kooooo0ol00006ooooo`;o00001?ooool2
o`0000Cooooo0_l00003ooooo`;o00000oooool2o`0000;ooooo1?l0001`ooooo`007?ooool00ol0
003oooooooooo`1]ooooo`;o0000<_ooool9o`0000oooooo0_l00007ooooo`;o00000oooool2o`00
00?ooooo0_l00005ooooo`Co000000?oooooo`000?l00000Koooool001cooooo00?o0000oooooooo
ool0Xoooool5o`0000;ooooo0ol00005ooooo`;o00001?ooool3o`0000Oooooo0_l00003ooooo`;o
00002_ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l00000K?ooool001cooooo
00?o0000ooooooooool0L?ooool2o`0003;ooooo1?l00002ooooo`Co00001?ooool2o`0000;ooooo
1?l0000?ooooo`;o000000?oooooo`000?l000000_l00004ooooo`Go000000Coooooo`000?l0003o
0000K?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q
8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo06kooooo1?l0000cooooo`_o00001_ooool2
o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0ol000001?oooooo0000o`00
0?ooool4o`000004ooooool0003o0000ooooo`;o000000Coooooo`000?l0003ooooo0_l0001]oooo
o`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonH
V9So8B4Q00Kooooo00?o0000ooooooooool0KOooool3o`0000?ooooo0_l0000aooooo`Oo000000?o
ooooo`000?l000002oooool2o`000004ooooool0003o0000ooooo`?o000000Coooooo`000?l0003o
00001?ooool4o`000003ooooool0003o000000Cooooo0_l0001`ooooo`0000?ooooooa0@4?ooool0
0_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`1]ooooo`;o00000_ooool5o`00037ooooo1_l0000Eooooo`;o00002?ooool4o`0000?o
oooo0_l0001dooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05oc8b
<_nHV9SooooooiRHV?lb<S801_ooool3o`00077ooooo0_l000000ooooooo0000o`00000dooooo`Co
00007Oooool7o`000003ooooool0003o000007Cooooo00000ooooooo0000ooooo`02ooooo`03o`00
0?oooooooooo00Wooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo07Oo
oooo0_l0000aooooo`Ko00003Oooool2o`0000Sooooo0ol000000ooooooo0000o`000005o`0007Oo
oooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go410@okZj^_oooooo
^[Zjoa0@4006ooooo`03o`000?oooooooooo07Oooooo0_l0000dooooo`Go00001_ooool2o`000003
ooooool0003o000000;o00002?ooool3o`000003ooooool0003o000007cooooo00001_ooooooMgMg
oiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooo
oooo0:kooooo1Ol00005ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`0000?ooooo0_l0
0020ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT01_ooool00ol0003oooooooooo`2`ooooo`?o000000?oooooo`000?l000001?l00008ooooo`;o
0000QOooool001cooooo00?o0000ooooooooool0]?ooool6o`0008oooooo000Looooo`03o`000?oo
oooooooo0;Kooooo0_l0002Aooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Booooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3o
oooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom:oooo
o`005?ooool00ol0003oooooooooo`05ooooo`?o0000oooooom:ooooo`005?ooool00ol0003ooooo
ooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000
ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Booooo`03
oeEEEOmVIVKo00000?ooooooE?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0:Gooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0Fooooo`Co000000?o410@
ooooooooool00_ooool00ol0003ok^k^ooooo`05ooooo`;o000000?o410@ooooooooool0S_ooool0
0:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00003?ooool00ol0003oooooooooo`04
ooooo`03oeEEEOnYZJWooooo00Kooooo00?o0000ooooooooool0Soooool00:Kooooo00Go0000oooo
ooooooooooooo`00000Kooooo`03o`000?oooooooooo00Cooooo00?oZJVYoeEEEOooool00oooool5
o`00093ooooo002Vooooo`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo00?o0000
ooooooooool01Oooool00olQ8B7oooooooooo`02ooooo`04odA4A?oMgMgoooooo`00097ooooo002V
ooooo`05o`000?n7QhOoooooojVYZOl000006oooool00ol0003oooooooooo`05ooooo`03oeEEEOo<
c<cooooo00;ooooo00CogMgMoeEEEOoooooo0000TOooool00:Gooooo00?o410@o`000?mgMgL00_l0
00000onHV9Soooooooooo`0Iooooo`03o`000?oooooooooo00Gooooo00?oZJVYogMgMoooool00ooo
ool00omgMgOoc<c<o`00002Aooooo`00a_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
oooooooooolb<S801?ooool00oo^k^koA4A4o`00002Aooooo`00a?ooool00omEEEGoIVIVo`000004
ooooo`Go00001Oooool00omgMgOo0000ooooo`2@ooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(180) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.29565 .39761 Mdot
.32241 .41625 Mdot
.49228 .66319 Mdot
.54882 .34555 Mdot
.72812 .62421 Mdot
.50918 .67761 Mdot
.32835 .6054 Mdot
.3413 .61972 Mdot
.45784 .68972 Mdot
.47126 .35415 Mdot
.31935 .64566 Mdot
.56908 .3384 Mdot
.33111 .61833 Mdot
.5362 .38264 Mdot
.64843 .47636 Mdot
.54344 .24486 Mdot
.33848 .44374 Mdot
.7465 .60129 Mdot
.53875 .24846 Mdot
.458 .69563 Mdot
.68838 .62243 Mdot
.54799 .39308 Mdot
.34443 .39615 Mdot
.53744 .38138 Mdot
.54776 .25237 Mdot
.32043 .40784 Mdot
.29496 .40282 Mdot
.54748 .2738 Mdot
.57183 .35214 Mdot
.33371 .6547 Mdot
.54987 .28544 Mdot
.74853 .4966 Mdot
.6001 .53311 Mdot
.43063 .33175 Mdot
.35084 .62701 Mdot
.31461 .57165 Mdot
.47365 .67525 Mdot
.34497 .64665 Mdot
.30044 .60748 Mdot
.33317 .64326 Mdot
.33691 .64342 Mdot
.3266 .407 Mdot
.35357 .62678 Mdot
.2588 .69701 Mdot
.54071 .3687 Mdot
.43066 .21525 Mdot
.53428 .72116 Mdot
.55214 .33579 Mdot
.35079 .40245 Mdot
.45943 .65188 Mdot
.69211 .52555 Mdot
.33165 .6356 Mdot
.5948 .55761 Mdot
.39917 .1892 Mdot
.33655 .61445 Mdot
.54401 .25031 Mdot
.51406 .70018 Mdot
.55867 .36937 Mdot
.54368 .33275 Mdot
.42711 .29967 Mdot
.56548 .36964 Mdot
.70114 .61217 Mdot
.38561 .37745 Mdot
.49007 .65456 Mdot
.45267 .67772 Mdot
.34933 .64237 Mdot
.32542 .45093 Mdot
.33333 .58962 Mdot
.54962 .34328 Mdot
.47822 .71471 Mdot
.57963 .39706 Mdot
.32036 .64618 Mdot
.3085 .43946 Mdot
.54535 .4046 Mdot
.29274 .3906 Mdot
.29397 .62399 Mdot
.74472 .61542 Mdot
.33633 .38086 Mdot
.48703 .64755 Mdot
.62381 .42456 Mdot
.54866 .40126 Mdot
.17091 .52817 Mdot
.69458 .43431 Mdot
.30191 .4111 Mdot
.5425 .4204 Mdot
.18028 .4724 Mdot
.5681 .42842 Mdot
.55726 .27453 Mdot
.54981 .26719 Mdot
.58807 .46602 Mdot
.51649 .70468 Mdot
.34565 .40304 Mdot
.55006 .38632 Mdot
.53078 .35334 Mdot
.46725 .34811 Mdot
.57717 .38424 Mdot
.54882 .25985 Mdot
.57237 .54172 Mdot
.31826 .6367 Mdot
.57747 .55361 Mdot
.39879 .62183 Mdot
.58974 .54315 Mdot
.57613 .41405 Mdot
.49361 .68107 Mdot
.29638 .43154 Mdot
.58897 .53461 Mdot
.3432 .59583 Mdot
.54671 .3847 Mdot
.28874 .57806 Mdot
.34211 .39575 Mdot
.53873 .27652 Mdot
.71357 .60326 Mdot
.58658 .61736 Mdot
.31317 .44025 Mdot
.4939 .22274 Mdot
.53061 .36142 Mdot
.55989 .39809 Mdot
.32525 .41393 Mdot
.45347 .6947 Mdot
.35485 .67652 Mdot
.33915 .43082 Mdot
.3171 .63912 Mdot
.34088 .44368 Mdot
.59196 .52844 Mdot
.45153 .68933 Mdot
.607 .57554 Mdot
.56533 .55563 Mdot
.73444 .51034 Mdot
.5662 .35167 Mdot
.5582 .55598 Mdot
.48601 .68119 Mdot
.33699 .42903 Mdot
.32573 .62454 Mdot
.51146 .37762 Mdot
.30828 .40532 Mdot
.33512 .60575 Mdot
.71534 .5827 Mdot
.70874 .578 Mdot
.30495 .42739 Mdot
.48695 .23046 Mdot
.35734 .62508 Mdot
.32095 .58807 Mdot
.68923 .52408 Mdot
.30244 .41729 Mdot
.68492 .59124 Mdot
.32999 .59284 Mdot
.53407 .78324 Mdot
.53689 .26711 Mdot
.73588 .53046 Mdot
.17694 .53176 Mdot
.68967 .52498 Mdot
.66982 .60495 Mdot
.69783 .60242 Mdot
.33586 .60605 Mdot
.51758 .38229 Mdot
.31519 .43035 Mdot
.3097 .40732 Mdot
.58289 .38097 Mdot
.59744 .53579 Mdot
.53766 .36012 Mdot
.57467 .55303 Mdot
.56388 .56093 Mdot
.54481 .38056 Mdot
.42382 .23076 Mdot
.3109 .39422 Mdot
.53121 .41573 Mdot
.46839 .68069 Mdot
.55131 .57934 Mdot
.35448 .61401 Mdot
.53738 .41552 Mdot
.5277 .41706 Mdot
.57261 .34066 Mdot
.31933 .58793 Mdot
.28568 .53423 Mdot
.50874 .65307 Mdot
.30735 .6359 Mdot
.39996 .62635 Mdot
.48614 .69518 Mdot
.53984 .33636 Mdot
.71082 .598 Mdot
.59386 .56927 Mdot
.52102 .38837 Mdot
.69243 .52697 Mdot
.52701 .34585 Mdot
.62227 .60529 Mdot
.63462 .59923 Mdot
.18057 .50751 Mdot
.29643 .52362 Mdot
.53002 .35814 Mdot
.55891 .24938 Mdot
.71404 .52595 Mdot
.2929 .67626 Mdot
.32105 .62275 Mdot
.49997 .72957 Mdot
.45874 .70202 Mdot
.42138 .71481 Mdot
.48962 .27002 Mdot
.52496 .29048 Mdot
.56551 .39966 Mdot
.5869 .55268 Mdot
.38923 .3868 Mdot
.69703 .60324 Mdot
.32349 .44122 Mdot
.17135 .53098 Mdot
.65313 .38462 Mdot
.53234 .28172 Mdot
.49055 .79435 Mdot
.46786 .6545 Mdot
.59588 .54103 Mdot
.69709 .58813 Mdot
.55344 .35935 Mdot
.31811 .3884 Mdot
.70372 .52473 Mdot
.61331 .54744 Mdot
.84938 .49954 Mdot
.33892 .43713 Mdot
.67635 .4024 Mdot
.33394 .61286 Mdot
.49822 .71016 Mdot
.56774 .42854 Mdot
.53357 .39167 Mdot
.3604 .4264 Mdot
.51641 .37052 Mdot
.54643 .29361 Mdot
.5402 .26714 Mdot
.45385 .65347 Mdot
.39145 .60315 Mdot
.3026 .62045 Mdot
.5451 .70528 Mdot
.31 .43819 Mdot
.41799 .2124 Mdot
.50076 .69121 Mdot
.6544 .6003 Mdot
.3269 .64863 Mdot
.7083 .581 Mdot
.50184 .68572 Mdot
.72593 .6242 Mdot
.53972 .33464 Mdot
.47641 .69674 Mdot
.71575 .61095 Mdot
.55153 .45811 Mdot
.58732 .53606 Mdot
.77204 .61361 Mdot
.32512 .60122 Mdot
.35621 .42644 Mdot
.52069 .3893 Mdot
.59171 .56232 Mdot
.6171 .55585 Mdot
.63832 .45595 Mdot
.57606 .57856 Mdot
.61009 .54613 Mdot
.61069 .46475 Mdot
.74106 .59581 Mdot
.24555 .47858 Mdot
.54723 .28584 Mdot
.33566 .44506 Mdot
.52395 .36153 Mdot
.36696 .57234 Mdot
.33428 .60337 Mdot
.55795 .36046 Mdot
.17262 .51252 Mdot
.32118 .59889 Mdot
.55897 .38183 Mdot
.29964 .62274 Mdot
.3048 .40742 Mdot
.65821 .37902 Mdot
.30602 .43889 Mdot
.54699 .37904 Mdot
.30157 .62996 Mdot
.50529 .72959 Mdot
.31816 .40797 Mdot
.54814 .38852 Mdot
.57077 .37311 Mdot
.58909 .55438 Mdot
.53899 .26635 Mdot
.37997 .64999 Mdot
.57362 .34638 Mdot
.51819 .67363 Mdot
.57808 .37125 Mdot
.69449 .57477 Mdot
.5893 .78449 Mdot
.30212 .42007 Mdot
.57873 .58069 Mdot
.5095 .6906 Mdot
.51694 .43689 Mdot
.67293 .38599 Mdot
.53885 .37187 Mdot
.61024 .56106 Mdot
.69663 .41038 Mdot
.30936 .60957 Mdot
.5397 .2846 Mdot
.56302 .59578 Mdot
.51625 .69725 Mdot
.58941 .5455 Mdot
.56547 .4137 Mdot
.33353 .38886 Mdot
.5442 .24737 Mdot
.48829 .70172 Mdot
.34492 .43601 Mdot
.56965 .4219 Mdot
.39662 .63321 Mdot
.57121 .58906 Mdot
.30826 .61462 Mdot
.54975 .27909 Mdot
.53956 .33696 Mdot
.47634 .71207 Mdot
.32767 .40551 Mdot
.33907 .61651 Mdot
.30628 .43644 Mdot
.62487 .49822 Mdot
.68041 .40928 Mdot
.31274 .45048 Mdot
.73162 .5925 Mdot
.54298 .82441 Mdot
.31288 .63859 Mdot
.58224 .5714 Mdot
.53075 .71712 Mdot
.32922 .38459 Mdot
.50005 .68018 Mdot
.47946 .24147 Mdot
.51555 .70451 Mdot
.53397 .25014 Mdot
.50561 .72661 Mdot
.51705 .27661 Mdot
.52986 .40928 Mdot
.45391 .66568 Mdot
.57329 .53957 Mdot
.55317 .41515 Mdot
.30962 .40386 Mdot
.74901 .48569 Mdot
.46066 .31229 Mdot
.49255 .26731 Mdot
.5119 .70042 Mdot
.47539 .23929 Mdot
.54134 .27438 Mdot
.54978 .27636 Mdot
.31792 .42846 Mdot
.58435 .57126 Mdot
.6685 .58275 Mdot
.67002 .5897 Mdot
.66256 .75736 Mdot
.69509 .36094 Mdot
.50008 .21874 Mdot
.30977 .4114 Mdot
.46378 .77068 Mdot
.28981 .40952 Mdot
.61272 .54719 Mdot
.34144 .62002 Mdot
.28097 .54256 Mdot
.57355 .4252 Mdot
.64725 .58235 Mdot
.54815 .29675 Mdot
.35456 .42348 Mdot
.33058 .45716 Mdot
.33986 .61693 Mdot
.49396 .26197 Mdot
.4728 .35198 Mdot
.54464 .35449 Mdot
.34331 .61569 Mdot
.61606 .55226 Mdot
.52313 .43206 Mdot
.74708 .51444 Mdot
.29243 .75276 Mdot
.54314 .37255 Mdot
.39412 .45472 Mdot
.52295 .39285 Mdot
.7297 .51379 Mdot
.55217 .36256 Mdot
.32318 .40317 Mdot
.55225 .21778 Mdot
.53622 .44017 Mdot
.4985 .79982 Mdot
.65019 .38923 Mdot
.73078 .61512 Mdot
.5389 .38757 Mdot
.53232 .36575 Mdot
.68114 .58618 Mdot
.33794 .40207 Mdot
.55067 .33937 Mdot
.25132 .47916 Mdot
.55137 .38997 Mdot
.35338 .60597 Mdot
.67242 .45634 Mdot
.74548 .49685 Mdot
.54238 .27001 Mdot
.33591 .38972 Mdot
.31389 .59382 Mdot
.34284 .64342 Mdot
.58675 .58024 Mdot
.33386 .60246 Mdot
.52649 .40068 Mdot
.67108 .45668 Mdot
.32229 .45079 Mdot
.5921 .53722 Mdot
.34734 .41079 Mdot
.47338 .73285 Mdot
.32393 .60404 Mdot
.59846 .5504 Mdot
.4773 .28549 Mdot
.31641 .61023 Mdot
.41031 .63406 Mdot
.5397 .28002 Mdot
.61637 .55409 Mdot
.29824 .39398 Mdot
.48385 .71856 Mdot
.61261 .55562 Mdot
.33706 .61413 Mdot
.53978 .36908 Mdot
.54183 .25344 Mdot
.33515 .60271 Mdot
.32935 .48595 Mdot
.54587 .28836 Mdot
.55357 .38966 Mdot
.31467 .39703 Mdot
.33934 .42094 Mdot
.529 .41358 Mdot
.5191 .37047 Mdot
.51527 .68187 Mdot
.61004 .56498 Mdot
.61003 .56724 Mdot
.56597 .566 Mdot
.50789 .70754 Mdot
.52355 .81867 Mdot
.32976 .58499 Mdot
.7449 .49519 Mdot
.30873 .53065 Mdot
.59631 .56147 Mdot
.51372 .67811 Mdot
.52754 .37833 Mdot
.5853 .3935 Mdot
.30314 .63439 Mdot
.63429 .81546 Mdot
.58152 .41839 Mdot
.32648 .44711 Mdot
.34212 .6283 Mdot
.54583 .31174 Mdot
.4195 .70545 Mdot
.71608 .61873 Mdot
.49852 .21815 Mdot
.34009 .62989 Mdot
.28843 .46634 Mdot
.33926 .6308 Mdot
.53242 .36681 Mdot
.56656 .41011 Mdot
.3559 .43374 Mdot
.7323 .61443 Mdot
.57845 .35932 Mdot
.55571 .37681 Mdot
.47585 .78332 Mdot
.29063 .42285 Mdot
.66857 .58948 Mdot
.56547 .34092 Mdot
.57364 .5433 Mdot
.73394 .61891 Mdot
.55333 .40526 Mdot
.57986 .37577 Mdot
.56689 .53614 Mdot
.31665 .65107 Mdot
.73505 .6024 Mdot
.50078 .80191 Mdot
.33615 .44026 Mdot
.356 .66369 Mdot
.6063 .58002 Mdot
.31427 .63994 Mdot
.50895 .34638 Mdot
.59738 .54512 Mdot
.25137 .60222 Mdot
.79071 .28814 Mdot
.60909 .54956 Mdot
.51831 .67945 Mdot
.46547 .34447 Mdot
.5802 .37095 Mdot
.55406 .38898 Mdot
.66849 .57992 Mdot
.33135 .42022 Mdot
.29658 .52401 Mdot
.30432 .63202 Mdot
.53008 .39338 Mdot
.30193 .42766 Mdot
.17887 .4966 Mdot
.59099 .54897 Mdot
.72382 .60516 Mdot
.72333 .59003 Mdot
.54622 .4085 Mdot
.69744 .39046 Mdot
.31649 .40716 Mdot
.54795 .38818 Mdot
.55344 .41009 Mdot
.51853 .72119 Mdot
.30168 .4044 Mdot
.4771 .6958 Mdot
.53068 .27648 Mdot
.52458 .22067 Mdot
.35904 .56542 Mdot
.32485 .59695 Mdot
.60186 .576 Mdot
.30301 .61998 Mdot
.53087 .68472 Mdot
.60958 .5674 Mdot
.54727 .38853 Mdot
.32279 .4512 Mdot
.54828 .38753 Mdot
.55123 .38902 Mdot
.54322 .36292 Mdot
.50174 .21568 Mdot
.49731 .65007 Mdot
.7193 .5991 Mdot
.55396 .33243 Mdot
.49673 .70477 Mdot
.43621 .74035 Mdot
.4699 .35541 Mdot
.54031 .3931 Mdot
.56038 .39418 Mdot
.31765 .37562 Mdot
.53561 .26621 Mdot
.31838 .61156 Mdot
.35635 .43208 Mdot
.56404 .43021 Mdot
.54063 .7136 Mdot
.54716 .33936 Mdot
.31149 .4492 Mdot
.33481 .5864 Mdot
.3856 .36444 Mdot
.61713 .57247 Mdot
.60133 .57836 Mdot
.61151 .55238 Mdot
.56808 .57098 Mdot
.35388 .61339 Mdot
.5109 .67381 Mdot
.54528 .71194 Mdot
.5895 .36963 Mdot
.51704 .37281 Mdot
.56523 .41197 Mdot
.52396 .72121 Mdot
.58017 .53062 Mdot
.47755 .26247 Mdot
.55104 .30772 Mdot
.49426 .71358 Mdot
.56848 .54677 Mdot
.24639 .38022 Mdot
.35097 .41391 Mdot
.5132 .65755 Mdot
.33999 .64834 Mdot
.71772 .61309 Mdot
.73858 .70518 Mdot
.34627 .42005 Mdot
.3921 .39294 Mdot
.47511 .68238 Mdot
.65346 .45516 Mdot
.39789 .18379 Mdot
.50135 .67731 Mdot
.54941 .29202 Mdot
.31139 .42401 Mdot
.57965 .53791 Mdot
.69546 .41498 Mdot
.66484 .45265 Mdot
.46691 .69809 Mdot
.57036 .3697 Mdot
.44207 .6852 Mdot
.51931 .68944 Mdot
.59618 .57557 Mdot
.51092 .70074 Mdot
.30865 .60705 Mdot
.48684 .68518 Mdot
.32155 .48356 Mdot
.55806 .34624 Mdot
.39834 .18854 Mdot
.68462 .47852 Mdot
.52798 .3626 Mdot
.31492 .62365 Mdot
.39084 .64226 Mdot
.55668 .35384 Mdot
.69804 .61613 Mdot
.5168 .67768 Mdot
.41994 .6849 Mdot
.53649 .25324 Mdot
.50421 .72582 Mdot
.33077 .38744 Mdot
.39953 .6197 Mdot
.39967 .62449 Mdot
.61209 .55656 Mdot
.30387 .41094 Mdot
.29385 .6258 Mdot
.31719 .63857 Mdot
.56474 .58648 Mdot
.52225 .39932 Mdot
.32057 .39163 Mdot
.54369 .44988 Mdot
.5628 .601 Mdot
.55093 .39138 Mdot
.4778 .69424 Mdot
.46493 .65009 Mdot
.6625 .47756 Mdot
.50206 .6933 Mdot
.59424 .57703 Mdot
.31329 .3949 Mdot
.53736 .25026 Mdot
.33917 .42644 Mdot
.52594 .35798 Mdot
.38218 .5912 Mdot
.35008 .40791 Mdot
.65399 .60011 Mdot
.56604 .37557 Mdot
.42559 .22784 Mdot
.55831 .3339 Mdot
.55337 .39088 Mdot
.45027 .68181 Mdot
.68284 .58687 Mdot
.62588 .59455 Mdot
.42408 .71806 Mdot
.69799 .61261 Mdot
.34978 .47067 Mdot
.45079 .69044 Mdot
.69998 .58153 Mdot
.66689 .75673 Mdot
.58024 .58196 Mdot
.71575 .59087 Mdot
.54134 .41988 Mdot
.32867 .59584 Mdot
.34178 .45096 Mdot
.55127 .41614 Mdot
.51315 .24862 Mdot
.52431 .26303 Mdot
.59146 .55309 Mdot
.55605 .39135 Mdot
.5299 .36644 Mdot
.30244 .4291 Mdot
.17569 .53461 Mdot
.50898 .66344 Mdot
.57697 .56076 Mdot
.34409 .42544 Mdot
.17066 .52708 Mdot
.45352 .67462 Mdot
.69219 .57897 Mdot
.30171 .60928 Mdot
.27937 .45573 Mdot
.59231 .55736 Mdot
.32681 .60307 Mdot
.43679 .66314 Mdot
.67767 .52411 Mdot
.55355 .24993 Mdot
.48493 .67249 Mdot
.68981 .52529 Mdot
.53149 .27386 Mdot
.42516 .72426 Mdot
.29391 .67575 Mdot
.34301 .39711 Mdot
.33784 .60508 Mdot
.72732 .6077 Mdot
.31147 .44396 Mdot
.34748 .41052 Mdot
.3229 .59598 Mdot
.48203 .18373 Mdot
.69491 .41003 Mdot
.30448 .59123 Mdot
.6355 .45937 Mdot
.682 .52366 Mdot
.58969 .55832 Mdot
.71453 .59882 Mdot
.39139 .60312 Mdot
.32612 .40722 Mdot
.29122 .53669 Mdot
.69564 .52672 Mdot
.53818 .28128 Mdot
.71441 .61315 Mdot
.18254 .4965 Mdot
.26658 .63799 Mdot
.32012 .60878 Mdot
.47475 .7822 Mdot
.68826 .60541 Mdot
.53393 .41461 Mdot
.65597 .8084 Mdot
.53386 .41109 Mdot
.33302 .59279 Mdot
.54769 .29629 Mdot
.32782 .43731 Mdot
.32795 .58673 Mdot
.53479 .28718 Mdot
.57299 .3466 Mdot
.54009 .35268 Mdot
.48748 .64723 Mdot
.35925 .42433 Mdot
.59948 .58582 Mdot
.52624 .36492 Mdot
.55799 .37605 Mdot
.61656 .54862 Mdot
.74371 .49913 Mdot
.47338 .60822 Mdot
.59448 .53233 Mdot
.48011 .70416 Mdot
.59146 .53669 Mdot
.57896 .56434 Mdot
.30318 .38748 Mdot
.4514 .75878 Mdot
.61642 .56601 Mdot
.54657 .37602 Mdot
.54995 .38264 Mdot
.3012 .60537 Mdot
.69627 .41106 Mdot
.65649 .45316 Mdot
.51514 .66957 Mdot
.56756 .59515 Mdot
.57448 .39068 Mdot
.30286 .40976 Mdot
.66005 .58252 Mdot
.58563 .57865 Mdot
.33591 .44237 Mdot
.56513 .34814 Mdot
.51874 .72163 Mdot
.60728 .54917 Mdot
.61683 .54437 Mdot
.71191 .60951 Mdot
.31069 .59044 Mdot
.35008 .39046 Mdot
.51927 .6852 Mdot
.55764 .26177 Mdot
.59018 .5953 Mdot
.51497 .7174 Mdot
.58806 .55798 Mdot
.58487 .54 Mdot
.30564 .40979 Mdot
.29357 .47114 Mdot
.60075 .52584 Mdot
.50504 .70628 Mdot
.26518 .72004 Mdot
.3308 .63914 Mdot
.54479 .33393 Mdot
.30471 .60741 Mdot
.34096 .39495 Mdot
.736 .51125 Mdot
.71334 .58399 Mdot
.31763 .60656 Mdot
.60937 .5433 Mdot
.34868 .40943 Mdot
.36081 .41783 Mdot
.54384 .37879 Mdot
.54554 .3928 Mdot
.53576 .7198 Mdot
.72557 .52695 Mdot
.29873 .6232 Mdot
.67073 .58194 Mdot
.50088 .66331 Mdot
.54054 .252 Mdot
.31626 .43416 Mdot
.78256 .60674 Mdot
.55276 .33045 Mdot
.50005 .70435 Mdot
.31957 .41679 Mdot
.67119 .58879 Mdot
.71985 .59803 Mdot
.52148 .37895 Mdot
.66878 .60376 Mdot
.31563 .60338 Mdot
.31268 .4034 Mdot
.39275 .43008 Mdot
.55639 .33521 Mdot
.54185 .39083 Mdot
.5357 .2783 Mdot
.30702 .5887 Mdot
.53924 .41827 Mdot
.73171 .61107 Mdot
.3134 .43757 Mdot
.52419 .3853 Mdot
.68509 .60185 Mdot
.58692 .5866 Mdot
.60072 .54551 Mdot
.44999 .66978 Mdot
.68446 .60741 Mdot
.68304 .59642 Mdot
.68714 .6062 Mdot
.28051 .54319 Mdot
.55879 .32339 Mdot
.63151 .54709 Mdot
.57166 .37687 Mdot
.67833 .52307 Mdot
.55809 .25749 Mdot
.31846 .63369 Mdot
.47551 .71059 Mdot
.54315 .35865 Mdot
.57166 .38126 Mdot
.34849 .39237 Mdot
.5398 .24407 Mdot
.5305 .41415 Mdot
.3244 .43878 Mdot
.39359 .42158 Mdot
.47408 .71699 Mdot
.17679 .53038 Mdot
.70446 .77897 Mdot
.51406 .36299 Mdot
.65836 .45727 Mdot
.34071 .40241 Mdot
.30147 .60734 Mdot
.64133 .45805 Mdot
.31531 .58864 Mdot
.33623 .41711 Mdot
.53689 .24259 Mdot
.33167 .48635 Mdot
.70314 .61405 Mdot
.53337 .36674 Mdot
.31904 .59679 Mdot
.5352 .36324 Mdot
.31398 .59748 Mdot
.4671 .24415 Mdot
.69635 .42723 Mdot
.51398 .37824 Mdot
.57736 .38238 Mdot
.70004 .62897 Mdot
.54273 .39311 Mdot
.49011 .79737 Mdot
.31869 .42192 Mdot
.5586 .58464 Mdot
.5393 .23862 Mdot
.4605 .31474 Mdot
.55816 .39531 Mdot
.52314 .26416 Mdot
.56286 .39703 Mdot
.61957 .81834 Mdot
.53387 .339 Mdot
.52401 .40198 Mdot
.32393 .62745 Mdot
.32273 .64532 Mdot
.35718 .40422 Mdot
.58848 .54098 Mdot
.18132 .50236 Mdot
.55784 .38172 Mdot
.47432 .65899 Mdot
.55589 .60239 Mdot
.68066 .59249 Mdot
.31866 .44313 Mdot
.78434 .27242 Mdot
.35412 .62641 Mdot
.46751 .689 Mdot
.5511 .28607 Mdot
.47862 .70106 Mdot
.49978 .65594 Mdot
.3734 .45924 Mdot
.71574 .5994 Mdot
.54014 .34282 Mdot
.4309 .32661 Mdot
.39064 .37731 Mdot
.55645 .33541 Mdot
.45162 .69672 Mdot
.5682 .53467 Mdot
.63166 .31125 Mdot
.74658 .60403 Mdot
.69051 .59702 Mdot
.33381 .60891 Mdot
.4704 .6599 Mdot
.57749 .55951 Mdot
.70418 .58144 Mdot
.48558 .724 Mdot
.58196 .58129 Mdot
.46735 .77528 Mdot
.31633 .40642 Mdot
.47655 .23988 Mdot
.42928 .21088 Mdot
.30847 .61996 Mdot
.43292 .73728 Mdot
.32004 .45055 Mdot
.30304 .43628 Mdot
.58304 .55407 Mdot
.49182 .71437 Mdot
.33729 .46606 Mdot
.5228 .37862 Mdot
.59009 .53757 Mdot
.53693 .40604 Mdot
.73862 .59172 Mdot
.55474 .38342 Mdot
.49486 .72661 Mdot
.31839 .62398 Mdot
.51482 .69513 Mdot
.33165 .60566 Mdot
.7469 .49179 Mdot
.56377 .37731 Mdot
.54111 .38795 Mdot
.67056 .45618 Mdot
.30779 .38965 Mdot
.43115 .33657 Mdot
.50483 .70382 Mdot
.51372 .6976 Mdot
.53995 .23892 Mdot
.33962 .4459 Mdot
.61568 .53408 Mdot
.63214 .46067 Mdot
.56176 .39941 Mdot
.32039 .42209 Mdot
.5586 .25631 Mdot
.24625 .66292 Mdot
.69279 .43779 Mdot
.30929 .3862 Mdot
.4953 .80315 Mdot
.5618 .4079 Mdot
.57588 .56557 Mdot
.55834 .56193 Mdot
.69848 .37947 Mdot
.62156 .59617 Mdot
.33879 .4381 Mdot
.57675 .55163 Mdot
.31422 .43186 Mdot
.51913 .70069 Mdot
.33891 .58655 Mdot
.32131 .43097 Mdot
.5647 .3924 Mdot
.70571 .77737 Mdot
.32093 .59316 Mdot
.53346 .37118 Mdot
.33388 .58891 Mdot
.33833 .45652 Mdot
.33261 .42862 Mdot
.58218 .58127 Mdot
.54724 .29151 Mdot
.31617 .60477 Mdot
.51675 .37998 Mdot
.37843 .4714 Mdot
.54415 .2472 Mdot
.55406 .58844 Mdot
.5754 .38728 Mdot
.56949 .35217 Mdot
.51068 .81186 Mdot
.52503 .44546 Mdot
.3698 .57477 Mdot
.33044 .57547 Mdot
.28418 .53352 Mdot
.29865 .39779 Mdot
.72439 .58181 Mdot
.35799 .40386 Mdot
.6065 .57458 Mdot
.47526 .70154 Mdot
.5406 .36433 Mdot
.57231 .57871 Mdot
.29958 .59563 Mdot
.70957 .58925 Mdot
.52698 .3459 Mdot
.48228 .66871 Mdot
.56949 .56015 Mdot
.32283 .60583 Mdot
.33028 .40764 Mdot
.33038 .44062 Mdot
.45434 .76273 Mdot
.52426 .38351 Mdot
.54654 .39107 Mdot
.34928 .60478 Mdot
.65725 .59714 Mdot
.69878 .61407 Mdot
.57348 .53928 Mdot
.34425 .59542 Mdot
.69339 .43679 Mdot
.3602 .42922 Mdot
.52812 .37203 Mdot
.67582 .4569 Mdot
.28945 .52783 Mdot
.29782 .35755 Mdot
.6936 .60294 Mdot
.67868 .38575 Mdot
.33922 .43736 Mdot
.3279 .62553 Mdot
.66094 .75982 Mdot
.53396 .2745 Mdot
.55755 .35117 Mdot
.67205 .37724 Mdot
.63155 .45811 Mdot
.55579 .27976 Mdot
.61192 .57705 Mdot
.68115 .42089 Mdot
.54267 .23868 Mdot
.55314 .25237 Mdot
.57405 .39862 Mdot
.57572 .38986 Mdot
.3257 .42484 Mdot
.49525 .26575 Mdot
.47843 .68691 Mdot
.55784 .28937 Mdot
.74105 .63243 Mdot
.54201 .28168 Mdot
.5837 .39049 Mdot
.26484 .36855 Mdot
.68183 .33614 Mdot
.3121 .41903 Mdot
.32326 .38308 Mdot
.3075 .62106 Mdot
.54112 .24682 Mdot
.50263 .70489 Mdot
.57493 .52818 Mdot
.48471 .71665 Mdot
.3252 .42285 Mdot
.46671 .71144 Mdot
.34888 .64532 Mdot
.48467 .67241 Mdot
.49006 .71096 Mdot
.32007 .62779 Mdot
.35831 .4261 Mdot
.56015 .33438 Mdot
.31927 .62745 Mdot
.61321 .53841 Mdot
.69812 .57845 Mdot
.39452 .40301 Mdot
.58552 .53366 Mdot
.58415 .41246 Mdot
.26124 .70917 Mdot
.47497 .67449 Mdot
.66079 .37766 Mdot
.35401 .41144 Mdot
.72334 .63139 Mdot
.32429 .43171 Mdot
.60394 .52645 Mdot
.69973 .60771 Mdot
.54562 .42081 Mdot
.76967 .62162 Mdot
.3015 .67581 Mdot
.53044 .43429 Mdot
.39352 .42249 Mdot
.48987 .71906 Mdot
.31047 .61345 Mdot
.37235 .66212 Mdot
.57619 .55953 Mdot
.3365 .38937 Mdot
.27866 .46201 Mdot
.60878 .57068 Mdot
.3248 .62399 Mdot
.42637 .25095 Mdot
.52475 .37196 Mdot
.30513 .61378 Mdot
.57507 .38293 Mdot
.49066 .22723 Mdot
.65801 .58249 Mdot
.56515 .56584 Mdot
.53519 .24545 Mdot
.45395 .67641 Mdot
.5388 .2398 Mdot
.50815 .25078 Mdot
.73681 .52124 Mdot
.57039 .38637 Mdot
.66426 .37648 Mdot
.53083 .68818 Mdot
.3092 .42951 Mdot
.60287 .56201 Mdot
.58964 .55619 Mdot
.53108 .25501 Mdot
.78615 .69317 Mdot
.7012 .58469 Mdot
.48715 .79593 Mdot
.56303 .37976 Mdot
.54888 .40043 Mdot
.35674 .40057 Mdot
.4665 .248 Mdot
.57322 .54175 Mdot
.56435 .36037 Mdot
.6885 .34418 Mdot
.33389 .62854 Mdot
.57272 .41604 Mdot
.54354 .40746 Mdot
.39621 .60933 Mdot
.32556 .6273 Mdot
.52225 .70985 Mdot
.58435 .58344 Mdot
.44793 .67148 Mdot
.72932 .62305 Mdot
.67649 .39879 Mdot
.74173 .50497 Mdot
.6893 .44002 Mdot
.71189 .62081 Mdot
.54065 .27163 Mdot
.58956 .39712 Mdot
.55899 .34854 Mdot
.69122 .59366 Mdot
.33012 .65621 Mdot
.32078 .42434 Mdot
.48422 .23276 Mdot
.5877 .55549 Mdot
.55587 .2592 Mdot
.74102 .61977 Mdot
.31377 .42898 Mdot
.42319 .23327 Mdot
.33004 .42068 Mdot
.32378 .61036 Mdot
.42719 .72793 Mdot
.70179 .61034 Mdot
.32411 .43228 Mdot
.45351 .68685 Mdot
.37877 .58767 Mdot
.55509 .31883 Mdot
.34748 .64717 Mdot
.34357 .47149 Mdot
.31805 .38387 Mdot
.29369 .3983 Mdot
.53296 .25714 Mdot
.663 .37735 Mdot
.59986 .57696 Mdot
.33856 .58863 Mdot
.45963 .67149 Mdot
.72709 .5255 Mdot
.42532 .27295 Mdot
.67501 .43315 Mdot
.56218 .41614 Mdot
.55383 .38253 Mdot
.54993 .40722 Mdot
.62028 .56599 Mdot
.58906 .40595 Mdot
.57171 .38789 Mdot
.30231 .63313 Mdot
.51946 .71268 Mdot
.56086 .37628 Mdot
.603 .54878 Mdot
.64439 .58362 Mdot
.72506 .63159 Mdot
.50457 .20907 Mdot
.3905 .39984 Mdot
.31721 .42989 Mdot
.48981 .70161 Mdot
.44713 .68423 Mdot
.715 .58209 Mdot
.34195 .61772 Mdot
.33229 .41982 Mdot
.61543 .81804 Mdot
.71058 .61619 Mdot
.54518 .3726 Mdot
.67191 .45595 Mdot
.68938 .35295 Mdot
.582 .37402 Mdot
.5445 .36182 Mdot
.60483 .54085 Mdot
.49967 .70652 Mdot
.52141 .28369 Mdot
.42439 .23227 Mdot
.687 .60295 Mdot
.68136 .58037 Mdot
.29448 .42127 Mdot
.51662 .3851 Mdot
.31967 .59729 Mdot
.69711 .40791 Mdot
.38685 .6444 Mdot
.18341 .47099 Mdot
.47978 .72982 Mdot
.54371 .34049 Mdot
.46155 .33518 Mdot
.57415 .42498 Mdot
.29624 .43107 Mdot
.29885 .47279 Mdot
.31006 .41448 Mdot
.33717 .62565 Mdot
.65792 .51901 Mdot
.33861 .64381 Mdot
.56865 .54744 Mdot
.35084 .42263 Mdot
.53527 .44474 Mdot
.51287 .69788 Mdot
.54651 .2444 Mdot
.70641 .59944 Mdot
.58573 .46473 Mdot
.59945 .56228 Mdot
.67825 .38996 Mdot
.51307 .67758 Mdot
.35706 .44393 Mdot
.54676 .24377 Mdot
.42177 .71005 Mdot
.68138 .42557 Mdot
.52337 .7343 Mdot
.57291 .57988 Mdot
.7015 .61244 Mdot
.47122 .35868 Mdot
.71975 .61597 Mdot
.31772 .60355 Mdot
.56446 .37464 Mdot
.52282 .39906 Mdot
.55416 .39441 Mdot
.54949 .41838 Mdot
.33767 .61828 Mdot
.55192 .25772 Mdot
.59992 .52885 Mdot
.57051 .57371 Mdot
.54702 .28506 Mdot
.71356 .59471 Mdot
.3268 .63851 Mdot
.51516 .71866 Mdot
.6135 .55158 Mdot
.73937 .61258 Mdot
.51987 .41623 Mdot
.56869 .37445 Mdot
.56736 .55985 Mdot
.54281 .42004 Mdot
.55079 .26081 Mdot
.48554 .67693 Mdot
.55593 .2696 Mdot
.72804 .63149 Mdot
.70613 .60316 Mdot
.33253 .59965 Mdot
.32319 .43277 Mdot
.72777 .5917 Mdot
.50177 .66568 Mdot
.56055 .42951 Mdot
.57513 .39033 Mdot
.31911 .4827 Mdot
.69425 .52707 Mdot
.71793 .63029 Mdot
.53662 .41732 Mdot
.29974 .40861 Mdot
.26731 .44887 Mdot
.56052 .35388 Mdot
.54854 .26875 Mdot
.30156 .38769 Mdot
.70185 .57957 Mdot
.3424 .61178 Mdot
.68956 .48163 Mdot
.32321 .58758 Mdot
.33041 .40658 Mdot
.57898 .55046 Mdot
.35729 .42548 Mdot
.5756 .55736 Mdot
.20833 .42341 Mdot
.57276 .39138 Mdot
.34156 .48637 Mdot
.58335 .52802 Mdot
.51215 .70232 Mdot
.50478 .71565 Mdot
.60799 .55185 Mdot
.34307 .43607 Mdot
.5961 .5765 Mdot
.72493 .61144 Mdot
.28818 .53272 Mdot
.30607 .384 Mdot
.49096 .71189 Mdot
.47578 .6729 Mdot
.34401 .59468 Mdot
.55683 .388 Mdot
.5279 .37116 Mdot
.48861 .6712 Mdot
.38422 .64672 Mdot
.33934 .39705 Mdot
.54619 .39034 Mdot
.6015 .53443 Mdot
.48061 .6827 Mdot
.28013 .66621 Mdot
.34429 .45618 Mdot
.53461 .24458 Mdot
.73849 .51911 Mdot
.34693 .59195 Mdot
.57132 .42443 Mdot
.54954 .26125 Mdot
.68955 .58708 Mdot
.67759 .38165 Mdot
.68728 .52368 Mdot
.35273 .63365 Mdot
.60082 .57822 Mdot
.58271 .37668 Mdot
.51254 .70926 Mdot
.55073 .42904 Mdot
.80047 .33016 Mdot
.56571 .5597 Mdot
.52651 .38816 Mdot
.56093 .5575 Mdot
.33909 .42723 Mdot
.54951 .39453 Mdot
.36319 .56952 Mdot
.49082 .69898 Mdot
.52502 .38194 Mdot
.6814 .61659 Mdot
.33216 .58912 Mdot
.59969 .56134 Mdot
.69634 .61083 Mdot
.55439 .2877 Mdot
.74861 .48623 Mdot
.52481 .72066 Mdot
.72124 .59617 Mdot
.55857 .38953 Mdot
.50106 .66221 Mdot
.31899 .64393 Mdot
.60535 .56029 Mdot
.52728 .42891 Mdot
.31556 .63516 Mdot
.32992 .63201 Mdot
.70902 .61177 Mdot
.4138 .2108 Mdot
.51263 .37396 Mdot
.53312 .38473 Mdot
.41855 .23609 Mdot
.25536 .41566 Mdot
.53493 .36559 Mdot
.54625 .41294 Mdot
.32551 .60108 Mdot
.65444 .51896 Mdot
.67793 .3877 Mdot
.57453 .53117 Mdot
.31152 .61812 Mdot
.45907 .70641 Mdot
.46947 .68492 Mdot
.7258 .59762 Mdot
.32016 .41582 Mdot
.72401 .58583 Mdot
.48618 .68908 Mdot
.54385 .37563 Mdot
.3416 .60394 Mdot
.53369 .22258 Mdot
.32983 .58675 Mdot
.49871 .66641 Mdot
.30829 .44567 Mdot
.51523 .27071 Mdot
.79823 .32283 Mdot
.4618 .60834 Mdot
.42586 .72703 Mdot
.68052 .59118 Mdot
.42423 .23316 Mdot
.56314 .3869 Mdot
.50614 .26334 Mdot
.53163 .37427 Mdot
.69836 .57362 Mdot
.4917 .72216 Mdot
.58216 .58135 Mdot
.57625 .56069 Mdot
.67534 .39058 Mdot
.33319 .6323 Mdot
.34665 .63911 Mdot
.58094 .54273 Mdot
.32207 .61341 Mdot
.52886 .38844 Mdot
.50857 .67821 Mdot
.21595 .40983 Mdot
.56319 .39777 Mdot
.5709 .59143 Mdot
.3572 .62241 Mdot
.32534 .45919 Mdot
.45857 .70566 Mdot
.46055 .32642 Mdot
.1788 .51331 Mdot
.31549 .60969 Mdot
.50581 .20943 Mdot
.49615 .70224 Mdot
.61307 .55056 Mdot
.50149 .66099 Mdot
.53038 .38234 Mdot
.54384 .34029 Mdot
.61738 .55219 Mdot
.55873 .40018 Mdot
.42868 .35997 Mdot
.53796 .28374 Mdot
.56556 .31465 Mdot
.57101 .37217 Mdot
.35589 .46904 Mdot
.31303 .64218 Mdot
.58108 .54385 Mdot
.60801 .46512 Mdot
.56583 .3496 Mdot
.29751 .39805 Mdot
.31433 .63146 Mdot
.18518 .53178 Mdot
.33645 .62441 Mdot
.51609 .69994 Mdot
.34125 .62263 Mdot
.57222 .42597 Mdot
.33945 .4159 Mdot
.4971 .6875 Mdot
.59573 .55991 Mdot
.46056 .68361 Mdot
.52741 .36359 Mdot
.27304 .65865 Mdot
.46826 .68929 Mdot
.53634 .27918 Mdot
.33905 .41852 Mdot
.77689 .61736 Mdot
.3864 .37948 Mdot
.53935 .37775 Mdot
.53624 .37096 Mdot
.5759 .53755 Mdot
.33622 .60645 Mdot
.35856 .44308 Mdot
.47673 .78513 Mdot
.71867 .63068 Mdot
.31468 .41537 Mdot
.65656 .58536 Mdot
.65219 .45512 Mdot
.31288 .44023 Mdot
.69013 .34777 Mdot
.32448 .596 Mdot
.33427 .44061 Mdot
.55031 .5967 Mdot
.55984 .25166 Mdot
.71611 .60323 Mdot
.44894 .67821 Mdot
.64637 .45717 Mdot
.47313 .69096 Mdot
.38206 .59089 Mdot
.45412 .6533 Mdot
.31286 .60745 Mdot
.66874 .60546 Mdot
.54866 .2966 Mdot
.34443 .64619 Mdot
.31532 .53417 Mdot
.47977 .69228 Mdot
.57729 .54288 Mdot
.55396 .27011 Mdot
.61902 .54833 Mdot
.57219 .55914 Mdot
.3531 .63074 Mdot
.33307 .44225 Mdot
.33256 .44792 Mdot
.5565 .57671 Mdot
.32754 .44047 Mdot
.4981 .67844 Mdot
.68752 .44897 Mdot
.47675 .28621 Mdot
.31551 .64515 Mdot
.55589 .28589 Mdot
.57998 .40111 Mdot
.49989 .72625 Mdot
.50661 .68056 Mdot
.33518 .62951 Mdot
.36201 .35979 Mdot
.57534 .56811 Mdot
.33538 .45888 Mdot
.347 .42109 Mdot
.33849 .43034 Mdot
.35364 .40452 Mdot
.6707 .52283 Mdot
.31506 .62425 Mdot
.34379 .43406 Mdot
.56062 .41215 Mdot
.54953 .411 Mdot
.61388 .55593 Mdot
.72542 .58268 Mdot
.54936 .27288 Mdot
.5942 .57744 Mdot
.553 .35035 Mdot
.51029 .70089 Mdot
.56621 .60591 Mdot
.60318 .57851 Mdot
.50264 .70592 Mdot
.50758 .70612 Mdot
.59736 .58072 Mdot
.5731 .60687 Mdot
.42748 .3692 Mdot
.54268 .23031 Mdot
.38179 .44932 Mdot
.49581 .71689 Mdot
.32481 .53834 Mdot
.34033 .48647 Mdot
.52394 .39847 Mdot
.57425 .53692 Mdot
.51451 .68451 Mdot
.30908 .3825 Mdot
.53866 .39394 Mdot
.58184 .55567 Mdot
.7196 .6088 Mdot
.5986 .55714 Mdot
.60097 .53886 Mdot
.3076 .39435 Mdot
.26715 .71636 Mdot
.30209 .42742 Mdot
.48331 .6482 Mdot
.59317 .56528 Mdot
.39752 .18732 Mdot
.49601 .72082 Mdot
.28739 .53483 Mdot
.54758 .29503 Mdot
.55884 .35034 Mdot
.48809 .7006 Mdot
.32994 .3873 Mdot
.33699 .65704 Mdot
.68103 .33167 Mdot
.32476 .43366 Mdot
.60685 .57988 Mdot
.60577 .54475 Mdot
.47822 .68525 Mdot
.3335 .4045 Mdot
.54927 .26206 Mdot
.33384 .43614 Mdot
.34657 .63281 Mdot
.54545 .42337 Mdot
.18124 .50382 Mdot
.57789 .55891 Mdot
.32199 .44173 Mdot
.46587 .66755 Mdot
.73219 .61109 Mdot
.53232 .41071 Mdot
.17251 .51553 Mdot
.55864 .39293 Mdot
.35117 .62066 Mdot
.59258 .60099 Mdot
.55948 .2548 Mdot
.55047 .36368 Mdot
.58526 .38617 Mdot
.30991 .6518 Mdot
.5525 .36147 Mdot
.56779 .3478 Mdot
.42804 .22166 Mdot
.30546 .43034 Mdot
.56113 .37863 Mdot
.49309 .67258 Mdot
.51054 .60143 Mdot
.53506 .40177 Mdot
.43136 .7322 Mdot
.69716 .38167 Mdot
.58868 .52459 Mdot
.54932 .57486 Mdot
.73541 .51213 Mdot
.53448 .37651 Mdot
.51607 .37339 Mdot
.54761 .42333 Mdot
.47511 .31292 Mdot
.48751 .69333 Mdot
.4553 .66516 Mdot
.73034 .6064 Mdot
.67004 .37428 Mdot
.70725 .60626 Mdot
.31758 .64328 Mdot
.53496 .28594 Mdot
.57755 .58217 Mdot
.32035 .4337 Mdot
.55337 .39648 Mdot
.46027 .66656 Mdot
.52864 .3829 Mdot
.54053 .25652 Mdot
.4917 .67901 Mdot
.51604 .68969 Mdot
.44526 .66333 Mdot
.68249 .60034 Mdot
.31347 .42432 Mdot
.52306 .40445 Mdot
.691 .60837 Mdot
.61845 .55289 Mdot
.69827 .47612 Mdot
.31159 .42149 Mdot
.31762 .43894 Mdot
.35296 .43825 Mdot
.51966 .39627 Mdot
.53155 .41885 Mdot
.33717 .64253 Mdot
.31839 .48271 Mdot
.33144 .5913 Mdot
.48417 .6996 Mdot
.52137 .70024 Mdot
.53016 .38038 Mdot
.659 .5922 Mdot
.71384 .5963 Mdot
.464 .67876 Mdot
.56304 .56911 Mdot
.73564 .60716 Mdot
.51837 .37669 Mdot
.47602 .69452 Mdot
.69259 .61276 Mdot
.36133 .35933 Mdot
.21027 .50274 Mdot
.73363 .6107 Mdot
.57698 .56469 Mdot
.42587 .28089 Mdot
.72892 .52126 Mdot
.6594 .58208 Mdot
.31564 .64401 Mdot
.55175 .33022 Mdot
.5645 .56781 Mdot
.73824 .61162 Mdot
.7251 .53141 Mdot
.48913 .6847 Mdot
.57773 .56832 Mdot
.59396 .61615 Mdot
.47737 .287 Mdot
.7332 .61437 Mdot
.32012 .44149 Mdot
.35306 .46058 Mdot
.54555 .36698 Mdot
.54749 .29028 Mdot
.30984 .6425 Mdot
.44838 .68387 Mdot
.45645 .66655 Mdot
.28374 .46266 Mdot
.69092 .43912 Mdot
.4823 .67575 Mdot
.53373 .34158 Mdot
.74278 .60891 Mdot
.56156 .4115 Mdot
.57245 .60077 Mdot
.55635 .24482 Mdot
.54975 .56613 Mdot
.73286 .61106 Mdot
.31776 .64814 Mdot
.3185 .62338 Mdot
.33669 .60969 Mdot
.48059 .67854 Mdot
.64178 .456 Mdot
.4643 .66133 Mdot
.41844 .21002 Mdot
.70414 .58453 Mdot
.53167 .82168 Mdot
.5849 .41415 Mdot
.54924 .34892 Mdot
.55592 .2531 Mdot
.59663 .53384 Mdot
.53502 .37946 Mdot
.31804 .63771 Mdot
.45391 .6867 Mdot
.28058 .6702 Mdot
.31586 .39579 Mdot
.42098 .21254 Mdot
.51184 .69679 Mdot
.57003 .58821 Mdot
.70837 .59706 Mdot
.75027 .50845 Mdot
.68133 .57424 Mdot
.51887 .68147 Mdot
.534 .35143 Mdot
.2965 .38923 Mdot
.62643 .81652 Mdot
.55112 .39329 Mdot
.47336 .67466 Mdot
.52632 .72631 Mdot
.56287 .27083 Mdot
.48961 .3677 Mdot
.28781 .67578 Mdot
.67671 .45197 Mdot
.68773 .61056 Mdot
.61511 .54362 Mdot
.69963 .40301 Mdot
.48471 .68965 Mdot
.4585 .68962 Mdot
.66411 .58084 Mdot
.32181 .45727 Mdot
.35159 .43063 Mdot
.4123 .4213 Mdot
.32674 .64165 Mdot
.56485 .35522 Mdot
.47627 .69164 Mdot
.31077 .44651 Mdot
.60167 .46494 Mdot
.33126 .61119 Mdot
.46565 .68614 Mdot
.55797 .40034 Mdot
.55054 .36658 Mdot
.70967 .60718 Mdot
.64297 .58429 Mdot
.60477 .53403 Mdot
.29027 .53216 Mdot
.65564 .4474 Mdot
.53367 .28494 Mdot
.55779 .35124 Mdot
.3325 .39214 Mdot
.60636 .57364 Mdot
.71622 .59906 Mdot
.55386 .42848 Mdot
.51198 .26722 Mdot
.32293 .38408 Mdot
.32236 .59582 Mdot
.58967 .561 Mdot
.67406 .39964 Mdot
.55877 .39787 Mdot
.53146 .37593 Mdot
.53306 .25699 Mdot
.51562 .26179 Mdot
.47713 .71215 Mdot
.30109 .41386 Mdot
.69255 .6083 Mdot
.33255 .42613 Mdot
.46028 .76771 Mdot
.54121 .28879 Mdot
.53942 .33528 Mdot
.29866 .40135 Mdot
.33331 .41676 Mdot
.35081 .62176 Mdot
.31396 .61884 Mdot
.51077 .73619 Mdot
.54097 .41253 Mdot
.56508 .55826 Mdot
.34344 .43191 Mdot
.44853 .67985 Mdot
.70718 .60755 Mdot
.43632 .74367 Mdot
.57078 .38095 Mdot
.48034 .68993 Mdot
.60275 .56531 Mdot
.3111 .39505 Mdot
.5028 .7017 Mdot
.61284 .54991 Mdot
.69187 .57938 Mdot
.57331 .34872 Mdot
.52899 .72978 Mdot
.5828 .54879 Mdot
.54577 .41518 Mdot
.5678 .30665 Mdot
.54966 .28964 Mdot
.57258 .5322 Mdot
.49989 .72978 Mdot
.58527 .55113 Mdot
.35569 .45484 Mdot
.561 .28269 Mdot
.4524 .67944 Mdot
.33185 .48643 Mdot
.54618 .29405 Mdot
.57618 .55414 Mdot
.31109 .43103 Mdot
.4688 .77558 Mdot
.29829 .44375 Mdot
.71808 .52009 Mdot
.53763 .40035 Mdot
.47293 .69058 Mdot
.71645 .60509 Mdot
.34799 .63426 Mdot
.274 .59492 Mdot
.33827 .54845 Mdot
.4998 .71277 Mdot
.55299 .39842 Mdot
.33624 .43899 Mdot
.31683 .60965 Mdot
.35571 .39816 Mdot
.4935 .66195 Mdot
.50102 .67268 Mdot
.55668 .25598 Mdot
.70591 .60573 Mdot
.58868 .40584 Mdot
.45 .67571 Mdot
.46075 .65131 Mdot
.42881 .22441 Mdot
.69328 .61413 Mdot
.53234 .25596 Mdot
.55503 .57524 Mdot
.57247 .41516 Mdot
.422 .23577 Mdot
.59843 .5398 Mdot
.31769 .39522 Mdot
.54252 .35776 Mdot
.33508 .77921 Mdot
.50121 .72233 Mdot
.67673 .45158 Mdot
.30079 .67553 Mdot
.32458 .63256 Mdot
.49434 .69726 Mdot
.54267 .39799 Mdot
.4337 .74031 Mdot
.72626 .59722 Mdot
.54051 .23683 Mdot
.57783 .54685 Mdot
.27156 .45173 Mdot
.34371 .60928 Mdot
.60666 .60984 Mdot
.34695 .63586 Mdot
.33318 .60152 Mdot
.36211 .36219 Mdot
.54529 .36827 Mdot
.50821 .69407 Mdot
.49025 .66813 Mdot
.56129 .59047 Mdot
.49551 .64703 Mdot
.35464 .42477 Mdot
.32754 .77221 Mdot
.51416 .27425 Mdot
.56624 .37906 Mdot
.61109 .57769 Mdot
.57063 .54563 Mdot
.42692 .72791 Mdot
.54964 .35986 Mdot
.30668 .42536 Mdot
.449 .67267 Mdot
.47119 .68376 Mdot
.53703 .27962 Mdot
.31795 .62314 Mdot
.67312 .57571 Mdot
.50304 .68006 Mdot
.68758 .48099 Mdot
.52589 .38753 Mdot
.34319 .65578 Mdot
.50178 .68091 Mdot
.74442 .73427 Mdot
.26826 .72591 Mdot
.30381 .4349 Mdot
.5775 .35345 Mdot
.34524 .45529 Mdot
.73061 .61428 Mdot
.48441 .65618 Mdot
.34489 .64406 Mdot
.5946 .56338 Mdot
.32341 .6808 Mdot
.47448 .68361 Mdot
.3243 .42318 Mdot
.5417 .36919 Mdot
.51031 .20744 Mdot
.56301 .39598 Mdot
.65122 .51743 Mdot
.71066 .62831 Mdot
.27219 .59857 Mdot
.34799 .60049 Mdot
.57728 .35263 Mdot
.68868 .60772 Mdot
.51928 .67852 Mdot
.4896 .67995 Mdot
.17251 .52274 Mdot
.60248 .54 Mdot
.50265 .65758 Mdot
.54367 .41463 Mdot
.44723 .66182 Mdot
.4251 .27291 Mdot
.32479 .6313 Mdot
.57701 .39127 Mdot
.47506 .69797 Mdot
.3082 .45572 Mdot
.66833 .45487 Mdot
.53031 .3952 Mdot
.55973 .55914 Mdot
.31392 .61256 Mdot
.42155 .20902 Mdot
.49178 .7234 Mdot
.56945 .4 Mdot
.31186 .63385 Mdot
.66717 .60306 Mdot
.26934 .66465 Mdot
.31289 .42394 Mdot
.47587 .67189 Mdot
.34308 .6131 Mdot
.59378 .57057 Mdot
.7001 .61659 Mdot
.51056 .66851 Mdot
.473 .69827 Mdot
.5407 .26775 Mdot
.56224 .58192 Mdot
.65566 .58436 Mdot
.34318 .40134 Mdot
.32402 .59929 Mdot
.53777 .25961 Mdot
.69675 .48205 Mdot
.5397 .42619 Mdot
.32974 .59665 Mdot
.404 .19175 Mdot
.53998 .34579 Mdot
.57095 .3758 Mdot
.51524 .20904 Mdot
.35142 .45686 Mdot
.34248 .39527 Mdot
.67801 .42978 Mdot
.54702 .27061 Mdot
.53782 .44612 Mdot
.31751 .42656 Mdot
.32622 .42086 Mdot
.53741 .4457 Mdot
.54082 .26347 Mdot
.41562 .41509 Mdot
.31883 .61336 Mdot
.32239 .63121 Mdot
.33846 .42899 Mdot
.55607 .25258 Mdot
.30116 .60832 Mdot
.27696 .38497 Mdot
.50192 .66939 Mdot
.69693 .39163 Mdot
.33611 .42227 Mdot
.66991 .45859 Mdot
.31818 .60308 Mdot
.72684 .47216 Mdot
.69675 .37738 Mdot
.5126 .38198 Mdot
.54751 .3644 Mdot
.68257 .59033 Mdot
.59918 .55966 Mdot
.59814 .58062 Mdot
.33722 .6099 Mdot
.5893 .40477 Mdot
.31072 .41298 Mdot
.56885 .42912 Mdot
.72774 .5266 Mdot
.7373 .46843 Mdot
.52942 .29717 Mdot
.32175 .41651 Mdot
.323 .40744 Mdot
.52251 .70119 Mdot
.45468 .69873 Mdot
.51516 .36278 Mdot
.31451 .61617 Mdot
.32792 .44458 Mdot
.33658 .59612 Mdot
.48513 .68843 Mdot
.51148 .69368 Mdot
.61156 .56827 Mdot
.57881 .56986 Mdot
.49428 .69221 Mdot
.43104 .73194 Mdot
.69721 .48086 Mdot
.30805 .4787 Mdot
.41863 .20047 Mdot
.74736 .4967 Mdot
.48884 .22877 Mdot
.71877 .60692 Mdot
.56373 .60507 Mdot
.31499 .63683 Mdot
.5826 .36521 Mdot
.54324 .35448 Mdot
.59141 .54866 Mdot
.3069 .62174 Mdot
.70125 .59021 Mdot
.32511 .63213 Mdot
.70067 .61633 Mdot
.4544 .67562 Mdot
.55047 .40072 Mdot
.53108 .35686 Mdot
.35004 .62359 Mdot
.52302 .6957 Mdot
.4772 .69825 Mdot
.71983 .6036 Mdot
.74455 .50319 Mdot
.47919 .68633 Mdot
.33554 .42122 Mdot
.23084 .3918 Mdot
.60102 .54231 Mdot
.53977 .39424 Mdot
.73792 .51183 Mdot
.56003 .28561 Mdot
.61871 .5553 Mdot
.58921 .56036 Mdot
.41324 .21227 Mdot
.52213 .37999 Mdot
.17909 .53542 Mdot
.60542 .57705 Mdot
.35743 .42654 Mdot
.50447 .69487 Mdot
.615 .57143 Mdot
.55542 .56225 Mdot
.65596 .57954 Mdot
.61644 .57189 Mdot
.34999 .42942 Mdot
.351 .45252 Mdot
.55399 .27422 Mdot
.42869 .18073 Mdot
.69931 .61206 Mdot
.71101 .59084 Mdot
.47881 .71173 Mdot
.38372 .59333 Mdot
.59126 .42292 Mdot
.71347 .58877 Mdot
.39809 .40233 Mdot
.55394 .25192 Mdot
.55541 .28158 Mdot
.54879 .28356 Mdot
.36092 .42579 Mdot
.50858 .38413 Mdot
.48617 .71841 Mdot
.32247 .42298 Mdot
.55625 .26883 Mdot
.55471 .43224 Mdot
.31028 .41869 Mdot
.32936 .6018 Mdot
.53687 .29356 Mdot
.33137 .43939 Mdot
.68101 .32988 Mdot
.31618 .60098 Mdot
.54366 .30876 Mdot
.57837 .80904 Mdot
.76413 .71627 Mdot
.32808 .63063 Mdot
.46565 .6839 Mdot
.47848 .69312 Mdot
.48679 .67758 Mdot
.34581 .39996 Mdot
.51819 .70985 Mdot
.32997 .40138 Mdot
.42261 .71967 Mdot
.67222 .38249 Mdot
.70059 .6091 Mdot
.50499 .65091 Mdot
.33743 .43045 Mdot
.42015 .22476 Mdot
.79006 .28556 Mdot
.56759 .40362 Mdot
.34671 .64303 Mdot
.72209 .58867 Mdot
.68131 .45445 Mdot
.68906 .58741 Mdot
.49521 .70226 Mdot
.67528 .39548 Mdot
.52735 .38365 Mdot
.20222 .51369 Mdot
.71426 .60416 Mdot
.32766 .42093 Mdot
.54052 .27452 Mdot
.50548 .73116 Mdot
.726 .59966 Mdot
.70626 .60195 Mdot
.53572 .38332 Mdot
.35745 .44301 Mdot
.48994 .70312 Mdot
.30732 .61457 Mdot
.42332 .67837 Mdot
.57873 .468 Mdot
.52135 .38377 Mdot
.57286 .37413 Mdot
.6578 .45561 Mdot
.43679 .74361 Mdot
.32008 .61912 Mdot
.7072 .5273 Mdot
.49998 .7271 Mdot
.73327 .52467 Mdot
.30059 .44317 Mdot
.50672 .65179 Mdot
.5964 .53972 Mdot
.61423 .55431 Mdot
.54683 .38863 Mdot
.7952 .30663 Mdot
.49297 .38074 Mdot
.30063 .61215 Mdot
.59672 .54449 Mdot
.52419 .70247 Mdot
.34884 .39864 Mdot
.5857 .6185 Mdot
.55036 .26973 Mdot
.30711 .61195 Mdot
.48421 .68248 Mdot
.82559 .3585 Mdot
.6789 .5889 Mdot
.68106 .44735 Mdot
.55217 .41152 Mdot
.54358 .38826 Mdot
.33431 .61675 Mdot
.32341 .65497 Mdot
.4279 .2092 Mdot
.68212 .57118 Mdot
.17942 .49783 Mdot
.29615 .60226 Mdot
.83847 .37495 Mdot
.56796 .55066 Mdot
.31922 .40403 Mdot
.59208 .58232 Mdot
.32089 .65296 Mdot
.53785 .36122 Mdot
.35536 .4491 Mdot
.6062 .56238 Mdot
.39095 .3897 Mdot
.55415 .28622 Mdot
.69057 .48031 Mdot
.55351 .38143 Mdot
.34462 .44701 Mdot
.31778 .42346 Mdot
.32849 .455 Mdot
.60995 .55224 Mdot
.56497 .36124 Mdot
.56891 .39742 Mdot
.57157 .37044 Mdot
.43128 .21078 Mdot
.5493 .39765 Mdot
.29253 .39191 Mdot
.69228 .42991 Mdot
.34915 .79107 Mdot
.53267 .35587 Mdot
.34128 .61327 Mdot
.54979 .38561 Mdot
.67888 .59836 Mdot
.57739 .35688 Mdot
.55266 .29228 Mdot
.3231 .61747 Mdot
.50905 .2512 Mdot
.73965 .63263 Mdot
.5202 .37816 Mdot
.70881 .62006 Mdot
.27262 .55312 Mdot
.70016 .52485 Mdot
.42649 .25216 Mdot
.33462 .43438 Mdot
.48726 .65971 Mdot
.30546 .63849 Mdot
.51568 .69994 Mdot
.53689 .22852 Mdot
.57543 .57897 Mdot
.52335 .81864 Mdot
.706 .48078 Mdot
.53997 .35963 Mdot
.57768 .537 Mdot
.30839 .43133 Mdot
.49714 .72168 Mdot
.46788 .24602 Mdot
.55517 .25207 Mdot
.71258 .58043 Mdot
.69109 .5826 Mdot
.59202 .59617 Mdot
.32646 .45684 Mdot
.42382 .2694 Mdot
.33308 .61717 Mdot
.47752 .67947 Mdot
.73568 .62306 Mdot
.39796 .41602 Mdot
.33185 .6569 Mdot
.42302 .71867 Mdot
.34442 .61281 Mdot
.54858 .34721 Mdot
.60706 .57809 Mdot
.36614 .47878 Mdot
.58768 .54318 Mdot
.55671 .4301 Mdot
.47535 .69997 Mdot
.5999 .53968 Mdot
.68683 .59886 Mdot
.33976 .60652 Mdot
.5114 .69922 Mdot
.53756 .37258 Mdot
.31528 .42841 Mdot
.62845 .3035 Mdot
.53526 .71275 Mdot
.5439 .29078 Mdot
.54366 .2908 Mdot
.29066 .47174 Mdot
.57667 .52776 Mdot
.26149 .61891 Mdot
.56349 .2733 Mdot
.35262 .55868 Mdot
.64757 .59021 Mdot
.48552 .79494 Mdot
.46776 .66109 Mdot
.49594 .68561 Mdot
.52712 .36831 Mdot
.44636 .67498 Mdot
.53743 .33797 Mdot
.49211 .72763 Mdot
.28619 .52871 Mdot
.53085 .43469 Mdot
.49469 .6798 Mdot
.59583 .57904 Mdot
.53619 .41275 Mdot
.30455 .42501 Mdot
.46778 .65801 Mdot
.5126 .38242 Mdot
.49429 .79655 Mdot
.35055 .62312 Mdot
.6108 .5527 Mdot
.62038 .46509 Mdot
.32115 .60841 Mdot
.35208 .42094 Mdot
.55741 .33127 Mdot
.71877 .59001 Mdot
.32751 .4059 Mdot
.62391 .57371 Mdot
.70418 .60429 Mdot
.68916 .44861 Mdot
.34343 .41568 Mdot
.59628 .54104 Mdot
.69334 .58013 Mdot
.55177 .58323 Mdot
.4931 .68448 Mdot
.5285 .72501 Mdot
.58103 .5521 Mdot
.52741 .38005 Mdot
.52221 .71482 Mdot
.33693 .62965 Mdot
.54072 .40723 Mdot
.47398 .68959 Mdot
.60374 .55052 Mdot
.56286 .40379 Mdot
.54745 .27183 Mdot
.42486 .2289 Mdot
.58835 .52385 Mdot
.69427 .60576 Mdot
.3216 .45251 Mdot
.57152 .39603 Mdot
.70639 .6165 Mdot
.52978 .68686 Mdot
.56722 .41025 Mdot
.32149 .44652 Mdot
.39181 .37291 Mdot
.44804 .68569 Mdot
.31683 .59681 Mdot
.48661 .66687 Mdot
.72647 .62341 Mdot
.78737 .27697 Mdot
.60467 .5762 Mdot
.5471 .2363 Mdot
.57595 .36205 Mdot
.48255 .65851 Mdot
.31497 .42143 Mdot
.17874 .48233 Mdot
.57537 .35151 Mdot
.56488 .41192 Mdot
.53854 .3905 Mdot
.41987 .68555 Mdot
.35263 .40809 Mdot
.53877 .39249 Mdot
.62703 .59408 Mdot
.5749 .37636 Mdot
.72831 .61098 Mdot
.54587 .81983 Mdot
.61372 .5471 Mdot
.39453 .18509 Mdot
.60783 .56118 Mdot
.49755 .67658 Mdot
.68105 .32917 Mdot
.61803 .46416 Mdot
.4734 .73253 Mdot
.35273 .42057 Mdot
.38062 .45053 Mdot
.51051 .69178 Mdot
.46674 .77392 Mdot
.552 .26641 Mdot
.54171 .27277 Mdot
.53149 .4076 Mdot
.49549 .70222 Mdot
.45855 .69563 Mdot
.57425 .57584 Mdot
.58013 .5364 Mdot
.54779 .31221 Mdot
.4608 .66887 Mdot
.54934 .3999 Mdot
.56105 .26588 Mdot
.33132 .65771 Mdot
.30658 .43693 Mdot
.34082 .64811 Mdot
.33838 .65468 Mdot
.48357 .23457 Mdot
.65405 .44737 Mdot
.3252 .64166 Mdot
.30665 .63394 Mdot
.41877 .69678 Mdot
.48665 .27017 Mdot
.72764 .61487 Mdot
.49288 .38506 Mdot
.52009 .69448 Mdot
.56492 .36327 Mdot
.3544 .41019 Mdot
.60673 .52813 Mdot
.1867 .45619 Mdot
.80854 .45007 Mdot
.54664 .24969 Mdot
.509 .7249 Mdot
.58185 .54873 Mdot
.58213 .54243 Mdot
.72933 .522 Mdot
.54726 .39797 Mdot
.44777 .68354 Mdot
.47789 .28523 Mdot
.2946 .60713 Mdot
.43191 .7359 Mdot
.33458 .45955 Mdot
.5514 .38792 Mdot
.33453 .39589 Mdot
.31682 .59286 Mdot
.71382 .61635 Mdot
.6815 .59555 Mdot
.52012 .37514 Mdot
.54901 .29566 Mdot
.35018 .55646 Mdot
.54529 .27621 Mdot
.54216 .25797 Mdot
.58543 .55309 Mdot
.53087 .26043 Mdot
.56984 .40113 Mdot
.52085 .42096 Mdot
.61828 .55136 Mdot
.33835 .65242 Mdot
.47417 .26661 Mdot
.57685 .55218 Mdot
.56685 .33638 Mdot
.31947 .59145 Mdot
.54794 .27528 Mdot
.33736 .6233 Mdot
.43832 .7448 Mdot
.33564 .64122 Mdot
.69094 .60573 Mdot
.43925 .6604 Mdot
.42321 .20379 Mdot
.33453 .43948 Mdot
.31615 .62505 Mdot
.69283 .57891 Mdot
.33977 .6222 Mdot
.51876 .68632 Mdot
.29676 .63414 Mdot
.25857 .40567 Mdot
.68623 .47991 Mdot
.49423 .22696 Mdot
.29483 .61093 Mdot
.45186 .69206 Mdot
.33909 .4295 Mdot
.36949 .57546 Mdot
.56677 .34145 Mdot
.67838 .59107 Mdot
.54565 .38724 Mdot
.33696 .60355 Mdot
.51946 .71352 Mdot
.42469 .25224 Mdot
.69143 .60407 Mdot
.41707 .20607 Mdot
.46271 .66596 Mdot
.55652 .34222 Mdot
.33883 .58649 Mdot
.28277 .57842 Mdot
.34931 .60688 Mdot
.67731 .37855 Mdot
.56499 .56532 Mdot
.70375 .57093 Mdot
.33337 .40879 Mdot
.56741 .54787 Mdot
.81058 .58057 Mdot
.30788 .53 Mdot
.30399 .41017 Mdot
.51459 .66108 Mdot
.52448 .38556 Mdot
.53198 .2536 Mdot
.5888 .5757 Mdot
.33513 .44827 Mdot
.53322 .25728 Mdot
.61359 .56269 Mdot
.69311 .42549 Mdot
.33197 .4576 Mdot
.51582 .67092 Mdot
.54056 .41303 Mdot
.35415 .6258 Mdot
.32873 .58701 Mdot
.60099 .58172 Mdot
.34445 .64074 Mdot
.56568 .3342 Mdot
.34089 .41806 Mdot
.55327 .27376 Mdot
.73022 .60893 Mdot
.396 .45088 Mdot
.61601 .53827 Mdot
.75092 .61127 Mdot
.55687 .41579 Mdot
.50993 .69353 Mdot
.31822 .68172 Mdot
.58351 .39345 Mdot
.32032 .42575 Mdot
.57071 .35118 Mdot
.53182 .25919 Mdot
.54341 .27451 Mdot
.47742 .67972 Mdot
.6678 .45638 Mdot
.55003 .39901 Mdot
.30848 .60572 Mdot
.5269 .44274 Mdot
.58664 .40639 Mdot
.6922 .57264 Mdot
.55298 .29209 Mdot
.32891 .58113 Mdot
.29253 .47107 Mdot
.50706 .69324 Mdot
.31331 .40934 Mdot
.31263 .37477 Mdot
.35138 .41891 Mdot
.31892 .46652 Mdot
.56335 .27531 Mdot
.17135 .52875 Mdot
.42494 .27154 Mdot
.49733 .21861 Mdot
.308 .38126 Mdot
.27986 .68892 Mdot
.30327 .41057 Mdot
.35224 .42072 Mdot
.21245 .41412 Mdot
.35417 .41943 Mdot
.52977 .37894 Mdot
.56603 .34948 Mdot
.51838 .2822 Mdot
.42335 .67616 Mdot
.56418 .39549 Mdot
.6203 .5604 Mdot
.7204 .58645 Mdot
.31593 .45328 Mdot
.59279 .56174 Mdot
.68254 .45575 Mdot
.59702 .58618 Mdot
.53567 .38229 Mdot
.55211 .40566 Mdot
.54585 .28209 Mdot
.74701 .46659 Mdot
.42689 .67056 Mdot
.35288 .44213 Mdot
.58747 .40668 Mdot
.26838 .66173 Mdot
.5372 .40911 Mdot
.57997 .36879 Mdot
.50928 .3879 Mdot
.50828 .6941 Mdot
.35921 .40867 Mdot
.57266 .56481 Mdot
.39032 .45859 Mdot
.55903 .38881 Mdot
.62274 .5387 Mdot
.73605 .5975 Mdot
.54153 .3981 Mdot
.3572 .43751 Mdot
.53235 .25878 Mdot
.32023 .38545 Mdot
.34102 .41159 Mdot
.56643 .41047 Mdot
.31745 .45319 Mdot
.33729 .39153 Mdot
.5421 .27198 Mdot
.51428 .72423 Mdot
.2881 .53362 Mdot
.52877 .38566 Mdot
.69043 .60047 Mdot
.54709 .36062 Mdot
.72843 .61648 Mdot
.61589 .57154 Mdot
.58466 .54957 Mdot
.47271 .36074 Mdot
.45666 .68613 Mdot
.70789 .57709 Mdot
.45254 .65352 Mdot
.59238 .3774 Mdot
.3953 .39668 Mdot
.30359 .64536 Mdot
.5392 .71578 Mdot
.58616 .55049 Mdot
.65967 .51908 Mdot
.54835 .45581 Mdot
.33686 .64387 Mdot
.30218 .40085 Mdot
.46583 .28285 Mdot
.57234 .54007 Mdot
.51727 .67247 Mdot
.49322 .66894 Mdot
.31004 .53083 Mdot
.21596 .41009 Mdot
.53082 .35804 Mdot
.57506 .53762 Mdot
.56398 .30837 Mdot
.60019 .55943 Mdot
.57546 .57464 Mdot
.46941 .69487 Mdot
.56262 .4019 Mdot
.69679 .42232 Mdot
.48174 .69355 Mdot
.70832 .59398 Mdot
.31919 .39479 Mdot
.7043 .61692 Mdot
.21908 .49208 Mdot
.42704 .20771 Mdot
.49104 .6935 Mdot
.60814 .53962 Mdot
.56738 .3717 Mdot
.35884 .44063 Mdot
.35394 .39613 Mdot
.30377 .42735 Mdot
.73082 .60013 Mdot
.45124 .67117 Mdot
.49514 .80201 Mdot
.54237 .37073 Mdot
.33135 .41637 Mdot
.74404 .61923 Mdot
.55172 .36653 Mdot
.31557 .6202 Mdot
.53447 .25862 Mdot
.33239 .42214 Mdot
.54921 .23898 Mdot
.33449 .4088 Mdot
.49491 .67152 Mdot
.52197 .36974 Mdot
.52524 .39643 Mdot
.69602 .52523 Mdot
.70057 .58975 Mdot
.31619 .38347 Mdot
.64596 .45016 Mdot
.57234 .41543 Mdot
.73196 .51791 Mdot
.54625 .40432 Mdot
.49635 .22476 Mdot
.5586 .5725 Mdot
.6138 .56649 Mdot
.57391 .35632 Mdot
.5304 .39006 Mdot
.35541 .39906 Mdot
.4262 .27292 Mdot
.431 .20898 Mdot
.32023 .59308 Mdot
.30191 .41461 Mdot
.48491 .69686 Mdot
.46926 .6565 Mdot
.51813 .70377 Mdot
.73068 .62368 Mdot
.55095 .27369 Mdot
.53507 .35848 Mdot
.30349 .60483 Mdot
.71158 .5855 Mdot
.32417 .41279 Mdot
.709 .61143 Mdot
.66028 .4511 Mdot
.68783 .59583 Mdot
.58472 .5832 Mdot
.26022 .7093 Mdot
.56118 .26757 Mdot
.69979 .59826 Mdot
.3093 .43965 Mdot
.51583 .43552 Mdot
.51717 .40191 Mdot
.42156 .22166 Mdot
.71472 .58134 Mdot
.52317 .66841 Mdot
.55334 .41587 Mdot
.66198 .37626 Mdot
.3378 .61656 Mdot
.6973 .61411 Mdot
.34535 .61517 Mdot
.54155 .25298 Mdot
.36993 .45979 Mdot
.32615 .4282 Mdot
.32295 .66043 Mdot
.57897 .37221 Mdot
.69636 .61352 Mdot
.49206 .69009 Mdot
.48618 .27243 Mdot
.41858 .70652 Mdot
.62188 .53199 Mdot
.72318 .52173 Mdot
.48218 .71609 Mdot
.49545 .25327 Mdot
.34425 .63401 Mdot
.57541 .42433 Mdot
.55644 .24637 Mdot
.56705 .41874 Mdot
.48249 .7012 Mdot
.49689 .68563 Mdot
.48164 .79097 Mdot
.52043 .38881 Mdot
.51039 .39045 Mdot
.26567 .4425 Mdot
.44991 .67393 Mdot
.35039 .41779 Mdot
.33931 .44919 Mdot
.46653 .68525 Mdot
.30651 .38855 Mdot
.70577 .6035 Mdot
.67963 .41663 Mdot
.34317 .63531 Mdot
.33802 .58856 Mdot
.4935 .69331 Mdot
.48387 .71064 Mdot
.5106 .69426 Mdot
.53755 .25247 Mdot
.3449 .41441 Mdot
.53038 .34799 Mdot
.54667 .38109 Mdot
.52777 .41447 Mdot
.34323 .45799 Mdot
.5733 .34762 Mdot
.54468 .44078 Mdot
.73235 .59754 Mdot
.50152 .67821 Mdot
.33351 .59416 Mdot
.63038 .30941 Mdot
.30887 .60218 Mdot
.57574 .38871 Mdot
.29139 .52695 Mdot
.30404 .39926 Mdot
.68607 .58837 Mdot
.55119 .29039 Mdot
.6852 .59865 Mdot
.33109 .65791 Mdot
.2663 .44059 Mdot
.69043 .44329 Mdot
.52779 .35324 Mdot
.65359 .45353 Mdot
.66192 .7586 Mdot
.29926 .37601 Mdot
.32304 .60143 Mdot
.55854 .28327 Mdot
.59133 .58709 Mdot
.56032 .29869 Mdot
.52905 .36599 Mdot
.58454 .41371 Mdot
.6566 .37748 Mdot
.57541 .36987 Mdot
.30448 .43773 Mdot
.53211 .44142 Mdot
.59823 .53269 Mdot
.5371 .41705 Mdot
.18163 .53039 Mdot
.56419 .38511 Mdot
.52031 .3668 Mdot
.55148 .35103 Mdot
.57583 .41402 Mdot
.34214 .46133 Mdot
.55166 .28239 Mdot
.31125 .59935 Mdot
.68051 .41615 Mdot
.34199 .63526 Mdot
.49818 .69698 Mdot
.59708 .52458 Mdot
.35881 .45021 Mdot
.68449 .59751 Mdot
.41471 .61286 Mdot
.665 .37554 Mdot
.52258 .70056 Mdot
.68082 .52552 Mdot
.6701 .57705 Mdot
.58194 .57801 Mdot
.72064 .62417 Mdot
.47532 .69866 Mdot
.32133 .62667 Mdot
.53536 .35009 Mdot
.34687 .42676 Mdot
.32884 .4416 Mdot
.5406 .41779 Mdot
.28441 .54188 Mdot
.3299 .58758 Mdot
.50126 .64905 Mdot
.53754 .3533 Mdot
.57699 .39197 Mdot
.32489 .38887 Mdot
.5091 .72133 Mdot
.55092 .45404 Mdot
.72264 .60195 Mdot
.54225 .41117 Mdot
.58958 .5328 Mdot
.65912 .45174 Mdot
.31706 .59545 Mdot
.60354 .54709 Mdot
.56331 .36968 Mdot
.66433 .4437 Mdot
.54 .23857 Mdot
.62007 .5955 Mdot
.46403 .70864 Mdot
.56499 .4113 Mdot
.52934 .40164 Mdot
.33334 .45799 Mdot
.34456 .63521 Mdot
.31383 .42315 Mdot
.25691 .43164 Mdot
.58514 .54972 Mdot
.35065 .61436 Mdot
.57513 .41412 Mdot
.30504 .58986 Mdot
.53476 .26158 Mdot
.54052 .37717 Mdot
.32468 .60191 Mdot
.33992 .40654 Mdot
.1823 .4965 Mdot
.47324 .26771 Mdot
.54099 .25579 Mdot
.54944 .36081 Mdot
.42391 .67709 Mdot
.60761 .52857 Mdot
.54496 .34001 Mdot
.32864 .44387 Mdot
.55022 .36705 Mdot
.2987 .61572 Mdot
.7079 .61429 Mdot
.32054 .42921 Mdot
.49971 .72447 Mdot
.48695 .67277 Mdot
.45213 .69644 Mdot
.58106 .58213 Mdot
.5309 .26123 Mdot
.32415 .45344 Mdot
.33284 .45204 Mdot
.63614 .45704 Mdot
.49749 .67685 Mdot
.71843 .60999 Mdot
.52809 .40672 Mdot
.57881 .53459 Mdot
.35179 .59881 Mdot
.3926 .18439 Mdot
.68891 .43974 Mdot
.73879 .61909 Mdot
.57786 .46971 Mdot
.58824 .55439 Mdot
.5699 .37185 Mdot
.69575 .61259 Mdot
.46836 .68678 Mdot
.53484 .24167 Mdot
.64155 .59223 Mdot
.52591 .67127 Mdot
.50561 .71434 Mdot
.30627 .59034 Mdot
.48347 .72295 Mdot
.6943 .61369 Mdot
.60274 .5777 Mdot
.32454 .43668 Mdot
.54431 .39926 Mdot
.57913 .56193 Mdot
.50784 .67773 Mdot
.56761 .55762 Mdot
.54904 .34531 Mdot
.32151 .38945 Mdot
.51834 .6951 Mdot
.53331 .3789 Mdot
.56307 .26685 Mdot
.4256 .22825 Mdot
.51326 .72299 Mdot
.54727 .3328 Mdot
.59878 .61519 Mdot
.5091 .71008 Mdot
.48163 .70245 Mdot
.5678 .41043 Mdot
.67128 .58476 Mdot
.5559 .38693 Mdot
.31806 .62172 Mdot
.65973 .45859 Mdot
.35022 .62294 Mdot
.73401 .5232 Mdot
.5508 .41955 Mdot
.554 .31843 Mdot
.39414 .39312 Mdot
.75301 .63152 Mdot
.7484 .49871 Mdot
.57119 .39176 Mdot
.34434 .3928 Mdot
.66827 .45869 Mdot
.68071 .47878 Mdot
.26591 .3951 Mdot
.72176 .6188 Mdot
.33766 .61106 Mdot
.5231 .39082 Mdot
.18799 .52859 Mdot
.72539 .6119 Mdot
.73122 .52177 Mdot
.58168 .36035 Mdot
.3232 .41905 Mdot
.52908 .36152 Mdot
.32849 .43373 Mdot
.55696 .36212 Mdot
.42447 .24335 Mdot
.34963 .55647 Mdot
.6766 .37864 Mdot
.59439 .57883 Mdot
.28266 .57861 Mdot
.49448 .22585 Mdot
.71011 .60553 Mdot
.55508 .24514 Mdot
.59253 .55146 Mdot
.32553 .63232 Mdot
.35543 .66356 Mdot
.5116 .69278 Mdot
.30898 .61697 Mdot
.31662 .40238 Mdot
.52506 .70495 Mdot
.56671 .55123 Mdot
.56522 .3211 Mdot
.68725 .60743 Mdot
.35067 .61352 Mdot
.53717 .39768 Mdot
.54818 .43048 Mdot
.41957 .68645 Mdot
.55573 .8191 Mdot
.29284 .4142 Mdot
.41675 .1998 Mdot
.26609 .4407 Mdot
.70659 .5903 Mdot
.51747 .72147 Mdot
.54239 .35646 Mdot
.55945 .40223 Mdot
.50377 .7158 Mdot
.3593 .44031 Mdot
.69144 .57689 Mdot
.70818 .57168 Mdot
.3007 .6107 Mdot
.59867 .81899 Mdot
.32128 .43118 Mdot
.59642 .81983 Mdot
.48795 .79578 Mdot
.22388 .40047 Mdot
.74649 .50172 Mdot
.32042 .61206 Mdot
.5978 .81976 Mdot
.32646 .41739 Mdot
.5673 .35461 Mdot
.5932 .54315 Mdot
.57378 .57787 Mdot
.32775 .39313 Mdot
.49995 .70153 Mdot
.66965 .5852 Mdot
.52557 .37021 Mdot
.58 .60649 Mdot
.35583 .39823 Mdot
.45371 .67401 Mdot
.59856 .56551 Mdot
.32888 .59273 Mdot
.55079 .36403 Mdot
.73042 .59734 Mdot
.32165 .61339 Mdot
.61446 .55283 Mdot
.67627 .39813 Mdot
.55702 .33113 Mdot
.54787 .29336 Mdot
.33676 .61889 Mdot
.58152 .46428 Mdot
.53611 .4056 Mdot
.34434 .63385 Mdot
.57168 .58971 Mdot
.26717 .59999 Mdot
.56244 .4589 Mdot
.30786 .53005 Mdot
.52754 .69366 Mdot
.49794 .72932 Mdot
.54865 .66526 Mdot
.43344 .6638 Mdot
.33154 .63894 Mdot
.58437 .56246 Mdot
.5381 .82323 Mdot
.34623 .63299 Mdot
.58335 .38234 Mdot
.52337 .388 Mdot
.47686 .28626 Mdot
.61396 .54896 Mdot
.60838 .56469 Mdot
.3376 .48725 Mdot
.55856 .2743 Mdot
.59703 .56529 Mdot
.54496 .40732 Mdot
.35082 .45099 Mdot
.31766 .6018 Mdot
.85107 .49718 Mdot
.31219 .64598 Mdot
.52856 .25303 Mdot
.52084 .69859 Mdot
.52791 .69759 Mdot
.54269 .39714 Mdot
.4735 .6116 Mdot
.83475 .36887 Mdot
.52316 .38845 Mdot
.55159 .29033 Mdot
.73271 .52504 Mdot
.53876 .41817 Mdot
.29753 .41799 Mdot
.60091 .53733 Mdot
.3427 .45438 Mdot
.32333 .60941 Mdot
.72239 .61833 Mdot
.73632 .63532 Mdot
.33704 .61105 Mdot
.56213 .39029 Mdot
.62111 .54885 Mdot
.54193 .38856 Mdot
.56211 .35174 Mdot
.66752 .44536 Mdot
.73707 .61712 Mdot
.5079 .69852 Mdot
.68509 .60027 Mdot
.35333 .42091 Mdot
.40798 .1936 Mdot
.71148 .60829 Mdot
.48623 .27138 Mdot
.6494 .45633 Mdot
.54471 .81879 Mdot
.32753 .44112 Mdot
.73085 .61471 Mdot
.33955 .61255 Mdot
.64289 .47552 Mdot
.50018 .26401 Mdot
.30762 .61227 Mdot
.56058 .35239 Mdot
.3449 .44975 Mdot
.28533 .46731 Mdot
.32956 .58423 Mdot
.31308 .43414 Mdot
.56936 .4607 Mdot
.54574 .25588 Mdot
.31229 .59722 Mdot
.74479 .48244 Mdot
.34826 .60104 Mdot
.47757 .24197 Mdot
.53658 .26507 Mdot
.32062 .4272 Mdot
.50694 .20797 Mdot
.26505 .43432 Mdot
.61144 .56635 Mdot
.56104 .34134 Mdot
.71547 .6084 Mdot
.64178 .45581 Mdot
.50493 .7263 Mdot
.30906 .45595 Mdot
.33598 .42707 Mdot
.3531 .59933 Mdot
.31484 .43498 Mdot
.30367 .39604 Mdot
.32388 .66052 Mdot
.30213 .41079 Mdot
.55945 .38962 Mdot
.43114 .18044 Mdot
.30744 .43114 Mdot
.33063 .61579 Mdot
.72748 .59687 Mdot
.3047 .43589 Mdot
.47085 .7787 Mdot
.54132 .41387 Mdot
.49105 .66225 Mdot
.66259 .58527 Mdot
.34443 .45941 Mdot
.71274 .60526 Mdot
.51214 .6813 Mdot
.72288 .58199 Mdot
.33049 .57533 Mdot
.32744 .57795 Mdot
.55606 .55992 Mdot
.31344 .53224 Mdot
.35392 .41923 Mdot
.52441 .7103 Mdot
.52055 .39615 Mdot
.54676 .3484 Mdot
.69734 .62271 Mdot
.32222 .38265 Mdot
.27793 .54731 Mdot
.59362 .5628 Mdot
.39808 .44897 Mdot
.32568 .58918 Mdot
.50331 .65005 Mdot
.69215 .44426 Mdot
.39859 .6282 Mdot
.59997 .53318 Mdot
.58898 .55282 Mdot
.53812 .39074 Mdot
.70526 .52607 Mdot
.70326 .61793 Mdot
.28664 .69297 Mdot
.54551 .24557 Mdot
.49759 .7173 Mdot
.56006 .35966 Mdot
.5561 .26468 Mdot
.5709 .39839 Mdot
.73711 .62222 Mdot
.3088 .62776 Mdot
.33296 .44116 Mdot
.72966 .61708 Mdot
.48612 .67269 Mdot
.68976 .34702 Mdot
.54294 .34026 Mdot
.53777 .33711 Mdot
.50534 .7063 Mdot
.35294 .42887 Mdot
.49931 .69175 Mdot
.34327 .63486 Mdot
.70861 .60926 Mdot
.53404 .25576 Mdot
.61356 .54798 Mdot
.48105 .65819 Mdot
.31691 .62716 Mdot
.51516 .72476 Mdot
.2988 .59766 Mdot
.58783 .54993 Mdot
.54379 .33112 Mdot
.44551 .67783 Mdot
.57599 .54404 Mdot
.43033 .3273 Mdot
.6735 .39958 Mdot
.24627 .38133 Mdot
.49884 .70348 Mdot
.47877 .7394 Mdot
.32498 .61454 Mdot
.32505 .65231 Mdot
.47661 .23806 Mdot
.79595 .31081 Mdot
.53868 .44616 Mdot
.26395 .57048 Mdot
.34253 .63626 Mdot
.33301 .62488 Mdot
.5028 .69221 Mdot
.33921 .40476 Mdot
.39013 .38486 Mdot
.52052 .68217 Mdot
.73648 .50858 Mdot
.3245 .41288 Mdot
.5163 .27907 Mdot
.45903 .66306 Mdot
.54212 .27634 Mdot
.42394 .25288 Mdot
.73198 .5943 Mdot
.71641 .52225 Mdot
.30002 .63987 Mdot
.53148 .373 Mdot
.16999 .52623 Mdot
.51007 .68928 Mdot
.56985 .55359 Mdot
.27397 .66216 Mdot
.55483 .43183 Mdot
.56281 .36069 Mdot
.55366 .37686 Mdot
.68638 .61162 Mdot
.42546 .28935 Mdot
.53419 .36564 Mdot
.67457 .38929 Mdot
.52891 .27189 Mdot
.53189 .72286 Mdot
.68676 .60205 Mdot
.67019 .52445 Mdot
.45419 .75874 Mdot
.38599 .46449 Mdot
.58467 .4143 Mdot
.31248 .64216 Mdot
.55792 .27471 Mdot
.32721 .60021 Mdot
.31576 .58848 Mdot
.61803 .8173 Mdot
.33066 .44623 Mdot
.54285 .24746 Mdot
.46111 .68894 Mdot
.39291 .38686 Mdot
.55444 .26458 Mdot
.4113 .19593 Mdot
.34959 .64563 Mdot
.78619 .27349 Mdot
.32853 .65179 Mdot
.56884 .56793 Mdot
.31176 .40262 Mdot
.34631 .39219 Mdot
.65348 .45227 Mdot
.34847 .41511 Mdot
.43193 .66563 Mdot
.32136 .45151 Mdot
.75452 .69645 Mdot
.26165 .40263 Mdot
.32617 .61978 Mdot
.3344 .58439 Mdot
.54932 .27896 Mdot
.55699 .39388 Mdot
.69521 .42431 Mdot
.59456 .56286 Mdot
.56118 .33582 Mdot
.48112 .69327 Mdot
.47694 .78556 Mdot
.2469 .66618 Mdot
.30263 .40695 Mdot
.32014 .63283 Mdot
.56161 .35949 Mdot
.53664 .26196 Mdot
.56467 .34747 Mdot
.38761 .59692 Mdot
.52583 .22415 Mdot
.54522 .38196 Mdot
.55009 .27533 Mdot
.52214 .68992 Mdot
.42064 .6877 Mdot
.2185 .40742 Mdot
.6092 .81787 Mdot
.5635 .40428 Mdot
.70845 .58752 Mdot
.73426 .623 Mdot
.51202 .40836 Mdot
.52995 .52249 Mdot
.58686 .46539 Mdot
.53603 .39671 Mdot
.68751 .34165 Mdot
.51425 .66837 Mdot
.59306 .5859 Mdot
.50459 .67638 Mdot
.31675 .375 Mdot
.60913 .57743 Mdot
.47536 .69263 Mdot
.6973 .38872 Mdot
.58147 .55445 Mdot
.26284 .61344 Mdot
.73071 .60968 Mdot
.5422 .40774 Mdot
.45839 .25931 Mdot
.44978 .67218 Mdot
.32209 .62376 Mdot
.30681 .41079 Mdot
.31559 .59764 Mdot
.43655 .66309 Mdot
.73699 .51588 Mdot
.61235 .56008 Mdot
.30888 .63945 Mdot
.54996 .29763 Mdot
.70813 .5857 Mdot
.33579 .64985 Mdot
.52973 .26928 Mdot
.5187 .42044 Mdot
.81327 .34809 Mdot
.51481 .38238 Mdot
.47875 .78762 Mdot
.34986 .62783 Mdot
.59181 .58761 Mdot
.54541 .39891 Mdot
.46895 .66504 Mdot
.54955 .57734 Mdot
.54064 .38672 Mdot
.48967 .7211 Mdot
.52657 .39293 Mdot
.69376 .61012 Mdot
.33701 .45733 Mdot
.67242 .46015 Mdot
.76008 .62289 Mdot
.72509 .61774 Mdot
.66298 .37215 Mdot
.55536 .33869 Mdot
.44484 .63438 Mdot
.31997 .41898 Mdot
.57548 .38586 Mdot
.76759 .61673 Mdot
.32528 .39775 Mdot
.3163 .40762 Mdot
.53169 .24487 Mdot
.29826 .62136 Mdot
.50694 .70196 Mdot
.69247 .58608 Mdot
.42934 .73142 Mdot
.53312 .37336 Mdot
.55157 .24245 Mdot
.72758 .61363 Mdot
.31463 .61226 Mdot
.54301 .25 Mdot
.2485 .61294 Mdot
.67984 .41327 Mdot
.34366 .64797 Mdot
.58327 .4145 Mdot
.52942 .21521 Mdot
.36023 .42765 Mdot
.17265 .52885 Mdot
.34869 .55607 Mdot
.49016 .66988 Mdot
.59612 .56703 Mdot
.3958 .18734 Mdot
.73134 .60115 Mdot
.38376 .37405 Mdot
.54779 .34652 Mdot
.54853 .35545 Mdot
.35379 .4497 Mdot
.52249 .35811 Mdot
.30256 .40353 Mdot
.46996 .77706 Mdot
.79442 .30221 Mdot
.32873 .43825 Mdot
.33051 .42565 Mdot
.53645 .29474 Mdot
.44436 .66352 Mdot
.31758 .3943 Mdot
.52352 .3959 Mdot
.43626 .66322 Mdot
.59104 .60321 Mdot
.69567 .57772 Mdot
.67291 .59677 Mdot
.29591 .41178 Mdot
.50145 .25928 Mdot
.53567 .27811 Mdot
.46527 .34485 Mdot
.58493 .47265 Mdot
.33231 .63971 Mdot
.54258 .42549 Mdot
.59215 .55911 Mdot
.51001 .68242 Mdot
.51202 .39012 Mdot
.5463 .40837 Mdot
.33742 .44032 Mdot
.72671 .58597 Mdot
.34754 .62063 Mdot
.5748 .54666 Mdot
.45081 .69658 Mdot
.71466 .5974 Mdot
.30601 .39013 Mdot
.48966 .22931 Mdot
.61216 .53574 Mdot
.5782 .53628 Mdot
.57163 .37712 Mdot
.56756 .40865 Mdot
.60629 .5347 Mdot
.33483 .60935 Mdot
.48996 .66877 Mdot
.57352 .56514 Mdot
.627 .46114 Mdot
.69848 .41354 Mdot
.5699 .38459 Mdot
.31548 .44331 Mdot
.32324 .63279 Mdot
.61028 .56348 Mdot
.53327 .8223 Mdot
.5307 .41109 Mdot
.51458 .27166 Mdot
.67489 .56632 Mdot
.58809 .55998 Mdot
.39026 .38471 Mdot
.6821 .5903 Mdot
.53676 .26464 Mdot
.67564 .3856 Mdot
.56997 .3418 Mdot
.57602 .4236 Mdot
.46932 .68999 Mdot
.33894 .60252 Mdot
.55806 .55638 Mdot
.50193 .67916 Mdot
.31427 .40864 Mdot
.46775 .34837 Mdot
.34324 .44649 Mdot
.33014 .45163 Mdot
.32015 .46502 Mdot
.32241 .59251 Mdot
.39556 .18614 Mdot
.60522 .53213 Mdot
.52786 .35986 Mdot
.31683 .63777 Mdot
.31355 .39388 Mdot
.57782 .3549 Mdot
.30379 .39971 Mdot
.3162 .38254 Mdot
.56838 .33979 Mdot
.54721 .27237 Mdot
.67218 .38019 Mdot
.51143 .2542 Mdot
.68006 .59557 Mdot
.35817 .42949 Mdot
.50791 .26447 Mdot
.54027 .35884 Mdot
.55308 .40475 Mdot
.54996 .28053 Mdot
.72642 .62104 Mdot
.47174 .36097 Mdot
.55114 .34692 Mdot
.70852 .52909 Mdot
.58072 .36369 Mdot
.32356 .38246 Mdot
.27327 .59626 Mdot
.52806 .25468 Mdot
.52465 .69853 Mdot
.35844 .44283 Mdot
.73267 .59458 Mdot
.35008 .46836 Mdot
.5576 .29151 Mdot
.3384 .62616 Mdot
.33228 .42217 Mdot
.51609 .67567 Mdot
.3198 .62016 Mdot
.34796 .60045 Mdot
.54891 .28278 Mdot
.4791 .66933 Mdot
.72843 .58714 Mdot
.34388 .59963 Mdot
.5638 .29023 Mdot
.32551 .6209 Mdot
.31111 .35602 Mdot
.53446 .33848 Mdot
.6759 .38928 Mdot
.58851 .57301 Mdot
.55739 .56987 Mdot
.34932 .61454 Mdot
.72414 .60297 Mdot
.54343 .24953 Mdot
.30356 .4242 Mdot
.71938 .59152 Mdot
.42503 .25604 Mdot
.52746 .69824 Mdot
.28493 .4666 Mdot
.42082 .71312 Mdot
.34673 .40563 Mdot
.71979 .5218 Mdot
.73848 .60593 Mdot
.57984 .5313 Mdot
.67738 .45081 Mdot
.60192 .56378 Mdot
.51145 .38447 Mdot
.54434 .24876 Mdot
.56 .38814 Mdot
.52117 .70064 Mdot
.68512 .61007 Mdot
.30933 .43587 Mdot
.63034 .60399 Mdot
.31321 .60598 Mdot
.51736 .42363 Mdot
.57025 .56022 Mdot
.53973 .25552 Mdot
.30814 .39804 Mdot
.34062 .39302 Mdot
.42653 .27561 Mdot
.51131 .70979 Mdot
.65785 .59719 Mdot
.56903 .38328 Mdot
.58004 .61252 Mdot
.34988 .61578 Mdot
.30896 .52967 Mdot
.50052 .66209 Mdot
.78374 .27154 Mdot
.4977 .67851 Mdot
.63509 .58839 Mdot
.3415 .39657 Mdot
.69404 .60164 Mdot
.56292 .39455 Mdot
.33252 .45961 Mdot
.3893 .38259 Mdot
.66262 .59078 Mdot
.68469 .59628 Mdot
.36543 .57099 Mdot
.32729 .6423 Mdot
.57793 .53956 Mdot
.58202 .36842 Mdot
.57749 .35222 Mdot
.51932 .39205 Mdot
.32012 .63595 Mdot
.54642 .26253 Mdot
.28098 .58476 Mdot
.55864 .28454 Mdot
.76782 .61632 Mdot
.48484 .70637 Mdot
.33905 .78279 Mdot
.34523 .45669 Mdot
.47046 .35622 Mdot
.37545 .36385 Mdot
.6743 .40346 Mdot
.30597 .62495 Mdot
.57225 .59051 Mdot
.5048 .69642 Mdot
.35869 .6673 Mdot
.48216 .70558 Mdot
.85622 .44472 Mdot
.47573 .28657 Mdot
.27018 .60062 Mdot
.56257 .33837 Mdot
.46271 .67968 Mdot
.503 .25076 Mdot
.57451 .56518 Mdot
.62135 .54988 Mdot
.55687 .24122 Mdot
.4299 .21158 Mdot
.68115 .59789 Mdot
.56417 .39321 Mdot
.3446 .45312 Mdot
.56181 .39697 Mdot
.56289 .39693 Mdot
.5557 .34522 Mdot
.32574 .66167 Mdot
.5448 .33119 Mdot
.55807 .39216 Mdot
.49859 .80551 Mdot
.56482 .59568 Mdot
.48062 .72189 Mdot
.3571 .40242 Mdot
.71144 .58546 Mdot
.31725 .37523 Mdot
.67494 .45638 Mdot
.32375 .65411 Mdot
.42525 .27993 Mdot
.54163 .26646 Mdot
.29936 .44082 Mdot
.31441 .6464 Mdot
.67182 .57912 Mdot
.59228 .55587 Mdot
.18945 .45033 Mdot
.45209 .6537 Mdot
.60338 .55288 Mdot
.4995 .72285 Mdot
.5518 .31441 Mdot
.32224 .43558 Mdot
.60125 .56333 Mdot
.34494 .60915 Mdot
.47069 .69666 Mdot
.66545 .37412 Mdot
.54683 .36887 Mdot
.49441 .7039 Mdot
.58159 .56358 Mdot
.64282 .45567 Mdot
.66692 .45816 Mdot
.46175 .68043 Mdot
.30602 .59611 Mdot
.34186 .59343 Mdot
.71964 .588 Mdot
.35031 .40159 Mdot
.34971 .42732 Mdot
.31473 .60584 Mdot
.36711 .66573 Mdot
.53268 .37753 Mdot
.54127 .37449 Mdot
.68586 .44873 Mdot
.57948 .38617 Mdot
.42945 .66726 Mdot
.60206 .55442 Mdot
.3432 .43008 Mdot
.54489 .24874 Mdot
.5532 .25085 Mdot
.56493 .38866 Mdot
.74114 .50898 Mdot
.51962 .69445 Mdot
.53833 .2816 Mdot
.69656 .61329 Mdot
.4291 .2237 Mdot
.53721 .41031 Mdot
.75649 .62025 Mdot
.34637 .39959 Mdot
.26834 .66595 Mdot
.32353 .62492 Mdot
.45849 .68731 Mdot
.45985 .68797 Mdot
.66589 .75674 Mdot
.34742 .45547 Mdot
.60357 .55402 Mdot
.52855 .67602 Mdot
.59166 .58281 Mdot
.68509 .59367 Mdot
.55156 .4637 Mdot
.4303 .66709 Mdot
.48124 .72212 Mdot
.31725 .57112 Mdot
.56067 .42827 Mdot
.54412 .41188 Mdot
.30468 .52902 Mdot
.54752 .40435 Mdot
.71503 .61251 Mdot
.33331 .64617 Mdot
.33069 .42107 Mdot
.67581 .58916 Mdot
.31771 .64596 Mdot
.35175 .4214 Mdot
.54503 .28196 Mdot
.57971 .35954 Mdot
.31071 .40881 Mdot
.3108 .38783 Mdot
.52915 .37976 Mdot
.63392 .81531 Mdot
.33709 .43777 Mdot
.30835 .40656 Mdot
.4294 .22148 Mdot
.44991 .68719 Mdot
.55162 .58088 Mdot
.2995 .6235 Mdot
.55683 .38571 Mdot
.4917 .70922 Mdot
.69282 .59369 Mdot
.33819 .42516 Mdot
.56733 .40467 Mdot
.5353 .37168 Mdot
.70917 .58655 Mdot
.70184 .61924 Mdot
.72435 .59844 Mdot
.32885 .58443 Mdot
.54136 .27275 Mdot
.31294 .39795 Mdot
.30939 .62236 Mdot
.73507 .60312 Mdot
.69155 .61299 Mdot
.77777 .61227 Mdot
.53106 .37944 Mdot
.70489 .62132 Mdot
.40459 .19197 Mdot
.69588 .37963 Mdot
.59676 .58259 Mdot
.49556 .73383 Mdot
.44155 .68486 Mdot
.60292 .5974 Mdot
.34012 .60559 Mdot
.55474 .28716 Mdot
.68721 .57796 Mdot
.57734 .56309 Mdot
.54361 .37179 Mdot
.54401 .42134 Mdot
.71463 .59099 Mdot
.73895 .51715 Mdot
.33938 .44166 Mdot
.23573 .39055 Mdot
.70896 .58507 Mdot
.45983 .67476 Mdot
.51087 .66461 Mdot
.4946 .6834 Mdot
.56959 .3902 Mdot
.52759 .29604 Mdot
.57596 .46689 Mdot
.42774 .3748 Mdot
.33229 .64176 Mdot
.3357 .3908 Mdot
.42643 .21939 Mdot
.31842 .40727 Mdot
.5157 .71274 Mdot
.7242 .60377 Mdot
.35428 .44605 Mdot
.33497 .58742 Mdot
.34592 .59938 Mdot
.44631 .67913 Mdot
.49574 .67603 Mdot
.49147 .69191 Mdot
.355 .45404 Mdot
.32552 .39132 Mdot
.56745 .34207 Mdot
.31898 .44326 Mdot
.47162 .77513 Mdot
.46824 .77534 Mdot
.44735 .67462 Mdot
.33043 .6106 Mdot
.34046 .41153 Mdot
.52788 .39862 Mdot
.65522 .37795 Mdot
.50564 .65935 Mdot
.71956 .58415 Mdot
.4305 .18067 Mdot
.79702 .31666 Mdot
.55772 .25405 Mdot
.33671 .63371 Mdot
.60013 .57719 Mdot
.55646 .37682 Mdot
.49413 .66916 Mdot
.62989 .54283 Mdot
.60342 .53968 Mdot
.52164 .35437 Mdot
.57589 .33898 Mdot
.32963 .63256 Mdot
.67701 .45843 Mdot
.57509 .56072 Mdot
.53053 .27775 Mdot
.32551 .64492 Mdot
.47461 .65924 Mdot
.54838 .6929 Mdot
.34776 .48673 Mdot
.62304 .49709 Mdot
.61545 .55972 Mdot
.5246 .40621 Mdot
.47684 .68921 Mdot
.67387 .58694 Mdot
.48095 .68928 Mdot
.30709 .38165 Mdot
.44816 .6857 Mdot
.53054 .39895 Mdot
.31622 .39681 Mdot
.34668 .59983 Mdot
.63208 .47657 Mdot
.68574 .62041 Mdot
.46661 .66436 Mdot
.58432 .52882 Mdot
.558 .2664 Mdot
.5629 .31779 Mdot
.55735 .5707 Mdot
.54074 .40893 Mdot
.32474 .60129 Mdot
.30401 .4029 Mdot
.31251 .61547 Mdot
.54914 .57391 Mdot
.33952 .35656 Mdot
.32463 .62641 Mdot
.5318 .30125 Mdot
.66962 .58577 Mdot
.73891 .51373 Mdot
.53055 .39359 Mdot
.34241 .60442 Mdot
.53389 .3402 Mdot
.3584 .43378 Mdot
.69725 .40003 Mdot
.67863 .41066 Mdot
.31914 .60065 Mdot
.56414 .56035 Mdot
.6481 .45685 Mdot
.55054 .58002 Mdot
.34256 .63493 Mdot
.69772 .3725 Mdot
.59899 .54702 Mdot
.70962 .59757 Mdot
.68425 .60801 Mdot
.71641 .60119 Mdot
.5454 .37924 Mdot
.52378 .21192 Mdot
.73703 .61146 Mdot
.35135 .66391 Mdot
.71478 .61619 Mdot
.5905 .60072 Mdot
.27922 .54406 Mdot
.69395 .61329 Mdot
.54127 .40252 Mdot
.55836 .28462 Mdot
.55397 .28695 Mdot
.50179 .66639 Mdot
.18219 .46803 Mdot
.49749 .80455 Mdot
.54306 .35582 Mdot
.42243 .21096 Mdot
.33053 .45609 Mdot
.58323 .52789 Mdot
.67762 .40841 Mdot
.5458 .29377 Mdot
.32178 .40434 Mdot
.67731 .45367 Mdot
.30312 .47683 Mdot
.58484 .57758 Mdot
.54182 .37909 Mdot
.35739 .44555 Mdot
.30919 .45666 Mdot
.74807 .49759 Mdot
.37873 .47124 Mdot
.3466 .41653 Mdot
.34452 .63551 Mdot
.33992 .6084 Mdot
.32299 .60062 Mdot
.49082 .67399 Mdot
.33249 .42631 Mdot
.52795 .43198 Mdot
.49263 .67052 Mdot
.55818 .35019 Mdot
.31671 .60227 Mdot
.67923 .40291 Mdot
.33023 .42475 Mdot
.53289 .39386 Mdot
.50512 .26673 Mdot
.48608 .71844 Mdot
.71081 .58759 Mdot
.42144 .20326 Mdot
.51037 .72999 Mdot
.30383 .59206 Mdot
.30489 .38135 Mdot
.57083 .59616 Mdot
.53531 .28561 Mdot
.57293 .39573 Mdot
.53571 .34903 Mdot
.53519 .28637 Mdot
.47772 .28044 Mdot
.5882 .53507 Mdot
.48632 .67282 Mdot
.45387 .69406 Mdot
.53384 .41127 Mdot
.33345 .43074 Mdot
.74298 .6168 Mdot
.73543 .58657 Mdot
.64463 .5928 Mdot
.65737 .4562 Mdot
.67469 .38973 Mdot
.57788 .40616 Mdot
.48117 .36392 Mdot
.51005 .67128 Mdot
.58383 .58479 Mdot
.66097 .45223 Mdot
.70829 .60331 Mdot
.56575 .35297 Mdot
.34105 .38351 Mdot
.33661 .42205 Mdot
.50106 .70316 Mdot
.35412 .62539 Mdot
.61454 .53826 Mdot
.44667 .67353 Mdot
.53453 .41164 Mdot
.54987 .24881 Mdot
.34431 .64066 Mdot
.3006 .39008 Mdot
.71013 .59378 Mdot
.49968 .67128 Mdot
.69917 .60398 Mdot
.31382 .43271 Mdot
.33912 .42547 Mdot
.5737 .36491 Mdot
.65451 .59843 Mdot
.46539 .66288 Mdot
.56753 .39328 Mdot
.48943 .70087 Mdot
.41962 .68715 Mdot
.35058 .59578 Mdot
.57517 .37929 Mdot
.39159 .38921 Mdot
.32013 .59735 Mdot
.55068 .35238 Mdot
.55204 .28491 Mdot
.54313 .25059 Mdot
.46208 .67718 Mdot
.70604 .57603 Mdot
.70456 .59964 Mdot
.38854 .36819 Mdot
.42076 .27298 Mdot
.57294 .41756 Mdot
.45078 .67881 Mdot
.56042 .24327 Mdot
.33327 .62847 Mdot
.34372 .40068 Mdot
.27865 .73404 Mdot
.33043 .61795 Mdot
.52588 .38912 Mdot
.71221 .60888 Mdot
.31179 .3854 Mdot
.60441 .58082 Mdot
.70168 .47775 Mdot
.5609 .56057 Mdot
.6499 .5967 Mdot
.57878 .54276 Mdot
.26864 .56464 Mdot
.48828 .69209 Mdot
.31059 .39589 Mdot
.33922 .63276 Mdot
.33628 .62759 Mdot
.50646 .72197 Mdot
.42647 .25718 Mdot
.22254 .40253 Mdot
.40433 .18172 Mdot
.46756 .64919 Mdot
.72173 .60819 Mdot
.69605 .39726 Mdot
.49658 .68361 Mdot
.50147 .7272 Mdot
.38894 .5978 Mdot
.30622 .5284 Mdot
.3373 .40619 Mdot
.53593 .36889 Mdot
.42534 .22987 Mdot
.54004 .34943 Mdot
.61892 .49438 Mdot
.316 .60811 Mdot
.34429 .40123 Mdot
.3283 .54049 Mdot
.55585 .41722 Mdot
.55873 .3665 Mdot
.47575 .78004 Mdot
.59611 .56031 Mdot
.56246 .81566 Mdot
.55783 .34296 Mdot
.48334 .67937 Mdot
.39502 .41731 Mdot
.58388 .57473 Mdot
.50529 .26275 Mdot
.34871 .632 Mdot
.61167 .56088 Mdot
.58085 .57368 Mdot
.48368 .36182 Mdot
.27416 .45601 Mdot
.35277 .43581 Mdot
.7171 .62402 Mdot
.29587 .52359 Mdot
.34279 .64667 Mdot
.25339 .59686 Mdot
.52822 .40064 Mdot
.32955 .58024 Mdot
.70575 .57136 Mdot
.54754 .35203 Mdot
.5538 .26679 Mdot
.42589 .27663 Mdot
.54296 .42681 Mdot
.56175 .28406 Mdot
.32684 .61523 Mdot
.74987 .58112 Mdot
.57657 .41839 Mdot
.49681 .70344 Mdot
.33851 .40367 Mdot
.26491 .44401 Mdot
.68009 .582 Mdot
.34224 .55097 Mdot
.7909 .28892 Mdot
.34366 .40121 Mdot
.54702 .37167 Mdot
.33243 .62656 Mdot
.61093 .57214 Mdot
.59137 .57296 Mdot
.56981 .53912 Mdot
.33672 .4184 Mdot
.58326 .57317 Mdot
.39212 .37878 Mdot
.67685 .4549 Mdot
.46963 .35473 Mdot
.32732 .59493 Mdot
.71937 .60867 Mdot
.61862 .5979 Mdot
.41903 .69139 Mdot
.58348 .37799 Mdot
.62001 .49516 Mdot
.3242 .46927 Mdot
.71748 .61091 Mdot
.56104 .384 Mdot
.58431 .53483 Mdot
.68423 .33166 Mdot
.74836 .60938 Mdot
.58117 .5404 Mdot
.5412 .24186 Mdot
.3536 .41956 Mdot
.6057 .55737 Mdot
.32976 .41804 Mdot
.56266 .38616 Mdot
.59189 .46547 Mdot
.35562 .41774 Mdot
.18091 .48233 Mdot
.608 .53136 Mdot
.32297 .64966 Mdot
.50808 .37548 Mdot
.56325 .40529 Mdot
.52235 .2876 Mdot
.60915 .57152 Mdot
.17979 .52713 Mdot
.48655 .70352 Mdot
.54601 .82468 Mdot
.43768 .66022 Mdot
.38659 .59653 Mdot
.24495 .63145 Mdot
.56321 .41598 Mdot
.42721 .25615 Mdot
.52577 .29267 Mdot
.3029 .60882 Mdot
.52211 .28248 Mdot
.55703 .39368 Mdot
.57113 .37576 Mdot
.49041 .70168 Mdot
.35762 .62754 Mdot
.53026 .2477 Mdot
.66001 .45276 Mdot
.67286 .57734 Mdot
.31403 .42107 Mdot
.55246 .38661 Mdot
.29336 .43732 Mdot
.45919 .67845 Mdot
.24496 .37944 Mdot
.53949 .40001 Mdot
.5961 .55984 Mdot
.32965 .58163 Mdot
.34905 .60679 Mdot
.46675 .67117 Mdot
.4677 .66887 Mdot
.56296 .40523 Mdot
.30902 .61115 Mdot
.58583 .38998 Mdot
.64681 .45674 Mdot
.58018 .56104 Mdot
.68953 .59005 Mdot
.52007 .36576 Mdot
.22732 .39794 Mdot
.8072 .5857 Mdot
.56953 .38854 Mdot
.34578 .44775 Mdot
.49524 .69429 Mdot
.51851 .7131 Mdot
.3491 .42589 Mdot
.51769 .71444 Mdot
.23546 .3873 Mdot
.52425 .21289 Mdot
.68733 .59777 Mdot
.57025 .25619 Mdot
.72256 .6179 Mdot
.61106 .56396 Mdot
.53051 .38027 Mdot
.30401 .68753 Mdot
.46441 .64948 Mdot
.63033 .30903 Mdot
.31782 .61568 Mdot
.5754 .57947 Mdot
.54491 .26523 Mdot
.66254 .58638 Mdot
.50985 .68601 Mdot
.62136 .55502 Mdot
.56255 .34811 Mdot
.35845 .44485 Mdot
.5457 .23857 Mdot
.57436 .57324 Mdot
.60755 .56857 Mdot
.62049 .55766 Mdot
.31747 .64586 Mdot
.30199 .41672 Mdot
.36582 .57126 Mdot
.47865 .71269 Mdot
.56032 .33467 Mdot
.54951 .37208 Mdot
.3381 .39263 Mdot
.52457 .36386 Mdot
.30976 .60201 Mdot
.38242 .18142 Mdot
.72664 .60314 Mdot
.60598 .57754 Mdot
.21904 .49217 Mdot
.62017 .56844 Mdot
.53608 .24789 Mdot
.54271 .30106 Mdot
.35464 .39693 Mdot
.30917 .64126 Mdot
.58818 .37776 Mdot
.46426 .70829 Mdot
.70836 .59494 Mdot
.33813 .58786 Mdot
.55102 .25385 Mdot
.53585 .40167 Mdot
.7173 .60927 Mdot
.32522 .53908 Mdot
.67877 .57365 Mdot
.3387 .63617 Mdot
.56774 .57944 Mdot
.65374 .36721 Mdot
.53811 .3891 Mdot
.5992 .55494 Mdot
.30616 .42194 Mdot
.32724 .64066 Mdot
.42643 .29122 Mdot
.58216 .57599 Mdot
.42742 .72863 Mdot
.35071 .61528 Mdot
.57371 .39466 Mdot
.34068 .46807 Mdot
.25723 .41675 Mdot
.30389 .40849 Mdot
.7093 .73631 Mdot
.44297 .75109 Mdot
.4912 .69505 Mdot
.33137 .61225 Mdot
.49693 .71165 Mdot
.66952 .58633 Mdot
.69441 .4145 Mdot
.46638 .66671 Mdot
.30369 .43773 Mdot
.48497 .70852 Mdot
.58566 .38304 Mdot
.32164 .65044 Mdot
.46057 .66162 Mdot
.51755 .37991 Mdot
.54412 .28372 Mdot
.60506 .56782 Mdot
.74185 .6112 Mdot
.66826 .45533 Mdot
.52473 .37833 Mdot
.59481 .55245 Mdot
.53431 .39296 Mdot
.30963 .60295 Mdot
.6232 .47723 Mdot
.56537 .33368 Mdot
.46813 .64955 Mdot
.19635 .43495 Mdot
.45451 .69168 Mdot
.6045 .61388 Mdot
.55148 .34948 Mdot
.53541 .38731 Mdot
.54859 .25828 Mdot
.44197 .18019 Mdot
.31107 .58748 Mdot
.54305 .33124 Mdot
.52339 .71022 Mdot
.32697 .40729 Mdot
.34977 .45174 Mdot
.52384 .44419 Mdot
.60037 .55234 Mdot
.32306 .58795 Mdot
.53384 .38347 Mdot
.58197 .58087 Mdot
.67982 .43268 Mdot
.29428 .52915 Mdot
.45988 .76799 Mdot
.49172 .7234 Mdot
.36047 .42115 Mdot
.52117 .69462 Mdot
.54682 .25605 Mdot
.58779 .57573 Mdot
.44083 .7496 Mdot
.39534 .63678 Mdot
.70643 .59523 Mdot
.5668 .36284 Mdot
.74457 .50645 Mdot
.52177 .68883 Mdot
.48257 .66918 Mdot
.58601 .38709 Mdot
.38798 .44314 Mdot
.79619 .59611 Mdot
.31297 .6339 Mdot
.28285 .38113 Mdot
.46717 .24822 Mdot
.80755 .43221 Mdot
.33912 .61495 Mdot
.55526 .2663 Mdot
.51771 .67392 Mdot
.60772 .78219 Mdot
.32186 .4059 Mdot
.70748 .59403 Mdot
.51766 .37521 Mdot
.31617 .4461 Mdot
.46946 .6485 Mdot
.29921 .41257 Mdot
.59572 .56538 Mdot
.318 .64863 Mdot
.5134 .68506 Mdot
.35093 .64033 Mdot
.39171 .3916 Mdot
.7246 .60737 Mdot
.69277 .52425 Mdot
.56193 .27485 Mdot
.42547 .27477 Mdot
.54297 .27402 Mdot
.56288 .59551 Mdot
.54282 .27977 Mdot
.26141 .43436 Mdot
.53138 .39496 Mdot
.5824 .41461 Mdot
.52795 .69637 Mdot
.57134 .38953 Mdot
.52381 .39552 Mdot
.50628 .2674 Mdot
.56175 .35641 Mdot
.56446 .39546 Mdot
.57287 .40153 Mdot
.34329 .44409 Mdot
.57176 .3568 Mdot
.3137 .38887 Mdot
.29203 .42698 Mdot
.4804 .71425 Mdot
.68174 .60442 Mdot
.69696 .61522 Mdot
.59683 .46477 Mdot
.74347 .50701 Mdot
.42598 .22706 Mdot
.32677 .41098 Mdot
.34943 .61247 Mdot
.57319 .34676 Mdot
.78254 .61245 Mdot
.59285 .46465 Mdot
.49996 .66472 Mdot
.45677 .67654 Mdot
.51631 .38335 Mdot
.79859 .32339 Mdot
.55769 .34203 Mdot
.6892 .4408 Mdot
.54635 .38059 Mdot
.5761 .38186 Mdot
.45322 .69736 Mdot
.72036 .52231 Mdot
.53694 .28107 Mdot
.28156 .46105 Mdot
.7022 .59409 Mdot
.60403 .55833 Mdot
.59422 .46568 Mdot
.48275 .23524 Mdot
.33495 .48708 Mdot
.54917 .25783 Mdot
.50419 .67163 Mdot
.34222 .42709 Mdot
.68428 .44782 Mdot
.31009 .62473 Mdot
.70338 .47945 Mdot
.31139 .35472 Mdot
.31019 .63204 Mdot
.70997 .59682 Mdot
.49728 .65843 Mdot
.56368 .37681 Mdot
.47346 .68527 Mdot
.55875 .41576 Mdot
.69516 .43468 Mdot
.68706 .59343 Mdot
.30682 .44357 Mdot
.34324 .63982 Mdot
.33682 .44547 Mdot
.24818 .37909 Mdot
.591 .47476 Mdot
.5193 .81417 Mdot
.44831 .67901 Mdot
.59843 .61157 Mdot
.32784 .39379 Mdot
.53129 .41174 Mdot
.40115 .19012 Mdot
.31965 .43156 Mdot
.35902 .44189 Mdot
.68833 .48154 Mdot
.74061 .52684 Mdot
.5701 .40531 Mdot
.31266 .44254 Mdot
.49537 .65756 Mdot
.68776 .6018 Mdot
.52657 .40104 Mdot
.59353 .57743 Mdot
.35379 .44839 Mdot
.51707 .6993 Mdot
.71168 .52276 Mdot
.48925 .67676 Mdot
.32999 .40325 Mdot
.45614 .68532 Mdot
.30812 .57108 Mdot
.46591 .66634 Mdot
.52285 .36189 Mdot
.53469 .38488 Mdot
.25976 .40588 Mdot
.33905 .42563 Mdot
.53589 .24825 Mdot
.53147 .35737 Mdot
.31558 .39429 Mdot
.51307 .6594 Mdot
.33352 .48511 Mdot
.54138 .24909 Mdot
.53365 .37379 Mdot
.72912 .61715 Mdot
.63187 .46151 Mdot
.66905 .47809 Mdot
.57109 .34537 Mdot
.72171 .60535 Mdot
.36052 .44027 Mdot
.5297 .38456 Mdot
.73006 .52544 Mdot
.5297 .69418 Mdot
.56675 .42974 Mdot
.61172 .57296 Mdot
.5329 .26899 Mdot
.74484 .46496 Mdot
.55174 .25627 Mdot
.31488 .40294 Mdot
.32631 .39904 Mdot
.5275 .68276 Mdot
.31045 .41192 Mdot
.60766 .57529 Mdot
.32883 .59063 Mdot
.29516 .35712 Mdot
.57903 .5831 Mdot
.6048 .53781 Mdot
.60505 .53195 Mdot
.57156 .55085 Mdot
.75904 .62898 Mdot
.45424 .76093 Mdot
.61023 .5469 Mdot
.31105 .3924 Mdot
.52005 .53316 Mdot
.56419 .5878 Mdot
.32178 .58786 Mdot
.58074 .57298 Mdot
.56656 .4297 Mdot
.55119 .26049 Mdot
.33212 .38464 Mdot
.30839 .62149 Mdot
.55425 .56635 Mdot
.52539 .39976 Mdot
.3493 .39054 Mdot
.55393 .38838 Mdot
.71512 .58061 Mdot
.32875 .42317 Mdot
.49945 .67307 Mdot
.68721 .58965 Mdot
.57496 .55262 Mdot
.71523 .58824 Mdot
.47922 .69329 Mdot
.34296 .60105 Mdot
.5195 .37585 Mdot
.72473 .58178 Mdot
.68143 .60346 Mdot
.53319 .42041 Mdot
.33281 .39953 Mdot
.57573 .52735 Mdot
.52884 .37533 Mdot
.54753 .26576 Mdot
.35002 .42839 Mdot
.17299 .53206 Mdot
.56444 .37324 Mdot
.52888 .27465 Mdot
.26976 .44608 Mdot
.57618 .57742 Mdot
.49363 .67207 Mdot
.56648 .40532 Mdot
.31665 .62092 Mdot
.31451 .60509 Mdot
.46041 .65072 Mdot
.3545 .43945 Mdot
.51943 .7005 Mdot
.52509 .41056 Mdot
.57697 .56964 Mdot
.54698 .41056 Mdot
.48358 .78706 Mdot
.17341 .50272 Mdot
.3082 .38741 Mdot
.47616 .71219 Mdot
.6783 .42718 Mdot
.29814 .61966 Mdot
.50829 .6534 Mdot
.27477 .45469 Mdot
.32288 .44701 Mdot
.34947 .42359 Mdot
.69831 .61481 Mdot
.49837 .67723 Mdot
.34703 .39543 Mdot
.34193 .39201 Mdot
.54591 .25167 Mdot
.5178 .38582 Mdot
.36034 .42866 Mdot
.41818 .69107 Mdot
.70329 .5985 Mdot
.51903 .71975 Mdot
.79991 .59582 Mdot
.31953 .63901 Mdot
.50576 .26153 Mdot
.58385 .37615 Mdot
.78193 .26763 Mdot
.55556 .34204 Mdot
.54887 .37797 Mdot
.31674 .37501 Mdot
.66454 .57904 Mdot
.6972 .60853 Mdot
.32774 .39444 Mdot
.30505 .38827 Mdot
.6944 .5811 Mdot
.63089 .41706 Mdot
.74763 .48282 Mdot
.67167 .4402 Mdot
.30107 .42067 Mdot
.31416 .35671 Mdot
.32165 .60688 Mdot
.33357 .4558 Mdot
.29175 .57236 Mdot
.45223 .66753 Mdot
.46443 .6651 Mdot
.34788 .63026 Mdot
.56225 .37456 Mdot
.44981 .69295 Mdot
.53729 .2774 Mdot
.27619 .58473 Mdot
.55803 .27268 Mdot
.64813 .8116 Mdot
.52279 .36508 Mdot
.47433 .60919 Mdot
.27567 .55294 Mdot
.53274 .25381 Mdot
.51347 .20886 Mdot
.71358 .59276 Mdot
.26387 .44344 Mdot
.3083 .60083 Mdot
.42478 .23133 Mdot
.53692 .38848 Mdot
.30715 .43812 Mdot
.33729 .64385 Mdot
.17528 .51789 Mdot
.54135 .28837 Mdot
.53861 .25773 Mdot
.39734 .19053 Mdot
.29405 .42154 Mdot
.49241 .67295 Mdot
.27526 .38601 Mdot
.31686 .38173 Mdot
.5501 .28432 Mdot
.49447 .65474 Mdot
.67948 .32895 Mdot
.3026 .43154 Mdot
.67739 .57265 Mdot
.31783 .41992 Mdot
.69486 .58293 Mdot
.34996 .39811 Mdot
.48427 .71508 Mdot
.56509 .3664 Mdot
.48435 .71654 Mdot
.72923 .59158 Mdot
.45859 .69484 Mdot
.30628 .60709 Mdot
.58532 .54959 Mdot
.32028 .59777 Mdot
.69568 .4081 Mdot
.42814 .30255 Mdot
.33755 .60053 Mdot
.50267 .40689 Mdot
.5348 .402 Mdot
.35085 .39946 Mdot
.50708 .67564 Mdot
.52416 .72068 Mdot
.66518 .45606 Mdot
.34491 .41029 Mdot
.51475 .71214 Mdot
.56184 .29418 Mdot
.2735 .67848 Mdot
.53049 .27507 Mdot
.29183 .75008 Mdot
.31133 .3993 Mdot
.52515 .71695 Mdot
.68687 .44384 Mdot
.29701 .39118 Mdot
.46372 .66227 Mdot
.34569 .62667 Mdot
.317 .62108 Mdot
.5318 .35153 Mdot
.34931 .64629 Mdot
.5004 .66592 Mdot
.34757 .3572 Mdot
.3538 .40946 Mdot
.17402 .49467 Mdot
.72366 .60138 Mdot
.51949 .69065 Mdot
.58047 .56538 Mdot
.39043 .38863 Mdot
.49239 .71161 Mdot
.7925 .29393 Mdot
.78911 .68329 Mdot
.51639 .70712 Mdot
.32839 .42144 Mdot
.33963 .41826 Mdot
.55439 .24799 Mdot
.65972 .45486 Mdot
.51058 .68777 Mdot
.29573 .6878 Mdot
.67338 .3838 Mdot
.5881 .54806 Mdot
.49799 .80521 Mdot
.51871 .41999 Mdot
.54402 .26998 Mdot
.32713 .63918 Mdot
.5583 .36496 Mdot
.30137 .39554 Mdot
.55734 .34228 Mdot
.31451 .59801 Mdot
.45609 .6534 Mdot
.53515 .39013 Mdot
.70981 .59552 Mdot
.32534 .63394 Mdot
.31549 .62478 Mdot
.46292 .69415 Mdot
.35496 .43827 Mdot
.4229 .23701 Mdot
.49542 .67555 Mdot
.53977 .27395 Mdot
.59127 .55401 Mdot
.57297 .39907 Mdot
.31973 .45419 Mdot
.29791 .47511 Mdot
.51958 .68715 Mdot
.53085 .41679 Mdot
.33559 .6171 Mdot
.52708 .69122 Mdot
.55567 .26034 Mdot
.47597 .66062 Mdot
.61775 .52661 Mdot
.45039 .69736 Mdot
.39504 .3966 Mdot
.58538 .52716 Mdot
.30638 .43906 Mdot
.60413 .54243 Mdot
.66812 .75659 Mdot
.7083 .59778 Mdot
.45165 .69258 Mdot
.18035 .48848 Mdot
.48253 .71708 Mdot
.55946 .35454 Mdot
.52663 .39334 Mdot
.48233 .69961 Mdot
.72456 .60901 Mdot
.60894 .59677 Mdot
.71308 .57777 Mdot
.33318 .4231 Mdot
.54916 .29543 Mdot
.76079 .71905 Mdot
.52618 .72574 Mdot
.34444 .64323 Mdot
.34624 .48612 Mdot
.60071 .53559 Mdot
.30604 .61323 Mdot
.31805 .62966 Mdot
.72428 .59058 Mdot
.49841 .72652 Mdot
.34191 .45764 Mdot
.33782 .65272 Mdot
.29863 .39197 Mdot
.72635 .5272 Mdot
.57129 .56353 Mdot
.56786 .61058 Mdot
.58338 .53523 Mdot
.6741 .45381 Mdot
.32079 .65434 Mdot
.5494 .39611 Mdot
.65352 .58726 Mdot
.34059 .63868 Mdot
.73801 .61105 Mdot
.55584 .26367 Mdot
.5127 .71458 Mdot
.40769 .21179 Mdot
.52521 .35762 Mdot
.53816 .35644 Mdot
.33002 .64229 Mdot
.50113 .21191 Mdot
.27797 .45972 Mdot
.35457 .42145 Mdot
.48882 .69179 Mdot
.68589 .47988 Mdot
.56494 .34851 Mdot
.52408 .39243 Mdot
.47649 .69742 Mdot
.60082 .5489 Mdot
.50751 .81054 Mdot
.53549 .37412 Mdot
.32651 .61121 Mdot
.55432 .26405 Mdot
.30412 .6003 Mdot
.58598 .36645 Mdot
.55792 .35574 Mdot
.53689 .2674 Mdot
.54618 .27904 Mdot
.32113 .59797 Mdot
.57859 .54201 Mdot
.61821 .56672 Mdot
.30308 .41328 Mdot
.51451 .37992 Mdot
.6719 .38317 Mdot
.53629 .38185 Mdot
.71436 .59365 Mdot
.67373 .47732 Mdot
.57867 .35221 Mdot
.52118 .35389 Mdot
.67551 .38307 Mdot
.56089 .38943 Mdot
.32824 .64319 Mdot
.34068 .41543 Mdot
.33614 .61981 Mdot
.33359 .65262 Mdot
.48432 .70928 Mdot
.73599 .61471 Mdot
.56601 .40219 Mdot
.67415 .58084 Mdot
.50756 .39113 Mdot
.54839 .56674 Mdot
.64288 .45476 Mdot
.68832 .43965 Mdot
.74641 .61033 Mdot
.53178 .4009 Mdot
.48408 .69414 Mdot
.5017 .73017 Mdot
.5549 .28682 Mdot
.51117 .3875 Mdot
.35624 .62553 Mdot
.34255 .6051 Mdot
.46721 .77498 Mdot
.54551 .64652 Mdot
.71246 .57918 Mdot
.6405 .58069 Mdot
.54465 .28201 Mdot
.56646 .35806 Mdot
.58332 .54192 Mdot
.50097 .70804 Mdot
.60735 .54385 Mdot
.45763 .76485 Mdot
.30557 .60248 Mdot
.33808 .62887 Mdot
.52226 .36459 Mdot
.83873 .37535 Mdot
.32018 .43664 Mdot
.34066 .41858 Mdot
.32655 .58846 Mdot
.4544 .69186 Mdot
.59615 .56862 Mdot
.41688 .1982 Mdot
.31406 .48013 Mdot
.67002 .58891 Mdot
.55357 .41104 Mdot
.45089 .67092 Mdot
.30344 .3999 Mdot
.70955 .57827 Mdot
.56026 .32713 Mdot
.49854 .65418 Mdot
.54669 .39011 Mdot
.56438 .31437 Mdot
.33351 .39342 Mdot
.63678 .45773 Mdot
.30486 .43966 Mdot
.31671 .60651 Mdot
.32547 .65623 Mdot
.55304 .35253 Mdot
.41433 .21231 Mdot
.392 .42857 Mdot
.33311 .65682 Mdot
.71723 .62336 Mdot
.58206 .55441 Mdot
.7369 .61266 Mdot
.49345 .70085 Mdot
.70857 .59692 Mdot
.49078 .71163 Mdot
.52581 .67289 Mdot
.34473 .45546 Mdot
.71689 .60942 Mdot
.4938 .2669 Mdot
.5894 .57591 Mdot
.6991 .61909 Mdot
.54977 .3326 Mdot
.54365 .24564 Mdot
.51223 .69482 Mdot
.67183 .58125 Mdot
.56798 .40502 Mdot
.21631 .49484 Mdot
.32544 .65206 Mdot
.3068 .60467 Mdot
.59639 .566 Mdot
.51469 .67377 Mdot
.34376 .45821 Mdot
.68099 .42457 Mdot
.39255 .38313 Mdot
.52255 .39056 Mdot
.56664 .39856 Mdot
.39445 .38789 Mdot
.34463 .45798 Mdot
.55473 .35508 Mdot
.46656 .34646 Mdot
.578 .56278 Mdot
.31359 .61345 Mdot
.33262 .42545 Mdot
.33682 .43134 Mdot
.48646 .66611 Mdot
.35635 .4441 Mdot
.63902 .59897 Mdot
.30534 .60493 Mdot
.61473 .5755 Mdot
.33294 .61518 Mdot
.54967 .51967 Mdot
.51095 .71095 Mdot
.18076 .50585 Mdot
.35639 .4275 Mdot
.54043 .25136 Mdot
.35865 .43813 Mdot
.72502 .59848 Mdot
.31243 .44074 Mdot
.32953 .4562 Mdot
.51835 .3831 Mdot
.57852 .54389 Mdot
.60986 .56184 Mdot
.66777 .45297 Mdot
.31887 .43396 Mdot
.56687 .38491 Mdot
.57604 .35968 Mdot
.52799 .36137 Mdot
.64735 .45471 Mdot
.34763 .44261 Mdot
.48396 .23402 Mdot
.35785 .40507 Mdot
.3273 .39171 Mdot
.81369 .57561 Mdot
.60543 .57511 Mdot
.59827 .53729 Mdot
.27995 .66643 Mdot
.53523 .36999 Mdot
.51572 .71606 Mdot
.54055 .27135 Mdot
.57761 .55152 Mdot
.56133 .33003 Mdot
.67968 .59546 Mdot
.55235 .41737 Mdot
.59388 .54597 Mdot
.50548 .67633 Mdot
.54162 .25199 Mdot
.53186 .37928 Mdot
.60453 .55309 Mdot
.35502 .4511 Mdot
.34025 .43953 Mdot
.41495 .41646 Mdot
.7077 .58247 Mdot
.33019 .60098 Mdot
.54193 .26893 Mdot
.48727 .69318 Mdot
.51153 .7212 Mdot
.30708 .44095 Mdot
.46575 .67663 Mdot
.33704 .63191 Mdot
.5454 .37047 Mdot
.31752 .60217 Mdot
.67828 .58744 Mdot
.32875 .42436 Mdot
.54604 .25951 Mdot
.54559 .23524 Mdot
.32626 .39896 Mdot
.57714 .56438 Mdot
.73054 .61783 Mdot
.46604 .68819 Mdot
.31614 .38634 Mdot
.32179 .59467 Mdot
.47758 .66673 Mdot
.53799 .25512 Mdot
.84221 .51766 Mdot
.55837 .36417 Mdot
.54401 .34691 Mdot
.38995 .40768 Mdot
.58335 .41608 Mdot
.47778 .7119 Mdot
.34736 .45887 Mdot
.54181 .24751 Mdot
.69708 .38447 Mdot
.73975 .62649 Mdot
.50436 .73696 Mdot
.55727 .38487 Mdot
.52283 .28879 Mdot
.57405 .41468 Mdot
.18218 .47619 Mdot
.64332 .45617 Mdot
.43071 .73171 Mdot
.57796 .61234 Mdot
.34357 .64855 Mdot
.59528 .55074 Mdot
.48233 .70974 Mdot
.46163 .33496 Mdot
.5542 .35921 Mdot
.42297 .28643 Mdot
.5527 .25484 Mdot
.33982 .61981 Mdot
.49789 .22308 Mdot
.50222 .6704 Mdot
.5391 .82417 Mdot
.51949 .39815 Mdot
.29007 .4693 Mdot
.41017 .64277 Mdot
.58455 .54371 Mdot
.59062 .535 Mdot
.71171 .5797 Mdot
.4969 .64938 Mdot
.55931 .56369 Mdot
.33465 .6182 Mdot
.56813 .35794 Mdot
.54608 .31071 Mdot
.18109 .53354 Mdot
.30699 .39917 Mdot
.33722 .64789 Mdot
.47574 .72929 Mdot
.54926 .40133 Mdot
.32718 .44674 Mdot
.32144 .40612 Mdot
.67651 .59357 Mdot
.42165 .71424 Mdot
.50588 .65095 Mdot
.80609 .34085 Mdot
.56647 .53556 Mdot
.49775 .70779 Mdot
.57979 .53231 Mdot
.53896 .27136 Mdot
.59232 .46547 Mdot
.33999 .64931 Mdot
.55545 .35039 Mdot
.42384 .27372 Mdot
.30741 .40665 Mdot
.54054 .38156 Mdot
.6987 .59723 Mdot
.42833 .18038 Mdot
.56163 .28099 Mdot
.46958 .34826 Mdot
.49532 .65741 Mdot
.56731 .39553 Mdot
.64466 .59787 Mdot
.58191 .58126 Mdot
.58332 .41695 Mdot
.49539 .67329 Mdot
.58686 .527 Mdot
.6969 .60076 Mdot
.3015 .41252 Mdot
.59558 .55289 Mdot
.55423 .25643 Mdot
.56227 .41214 Mdot
.72231 .6237 Mdot
.53822 .26398 Mdot
.28093 .36128 Mdot
.56733 .54775 Mdot
.46032 .6681 Mdot
.31605 .38462 Mdot
.56896 .38881 Mdot
.58123 .55394 Mdot
.54879 .40939 Mdot
.22753 .39687 Mdot
.56003 .35165 Mdot
.20094 .51202 Mdot
.33978 .40448 Mdot
.32447 .62375 Mdot
.54916 .25981 Mdot
.54401 .39063 Mdot
.58027 .53003 Mdot
.59722 .57041 Mdot
.52855 .40691 Mdot
.30603 .43932 Mdot
.30639 .42755 Mdot
.30164 .47609 Mdot
.4813 .66398 Mdot
.66415 .4437 Mdot
.32054 .61674 Mdot
.58426 .54097 Mdot
.33887 .65175 Mdot
.52789 .29473 Mdot
.70851 .58407 Mdot
.18585 .52817 Mdot
.54594 .36459 Mdot
.34668 .41438 Mdot
.74616 .48617 Mdot
.32261 .44906 Mdot
.27801 .66267 Mdot
.3429 .64645 Mdot
.32265 .42911 Mdot
.55744 .38176 Mdot
.67941 .45301 Mdot
.51823 .27665 Mdot
.30559 .63798 Mdot
.6145 .57355 Mdot
.56495 .51878 Mdot
.47252 .65794 Mdot
.81091 .58278 Mdot
.34776 .59958 Mdot
.27499 .55186 Mdot
.54122 .24907 Mdot
.35197 .41263 Mdot
.3277 .59549 Mdot
.31301 .62275 Mdot
.50802 .67188 Mdot
.54488 .25174 Mdot
.54318 .38828 Mdot
.61266 .57062 Mdot
.34488 .60061 Mdot
.54398 .42034 Mdot
.53177 .25362 Mdot
.48295 .79115 Mdot
.27504 .45795 Mdot
.17056 .53051 Mdot
.53832 .30571 Mdot
.42536 .2713 Mdot
.35721 .67582 Mdot
.35172 .40232 Mdot
.56487 .39126 Mdot
.5857 .56587 Mdot
.46198 .67865 Mdot
.55082 .36942 Mdot
.47738 .71393 Mdot
.33827 .61011 Mdot
.20935 .50462 Mdot
.53947 .30556 Mdot
.27336 .58882 Mdot
.56302 .36452 Mdot
.56105 .26126 Mdot
.70661 .60631 Mdot
.31035 .59633 Mdot
.30071 .4729 Mdot
.57172 .39601 Mdot
.48499 .67025 Mdot
.4666 .65917 Mdot
.30627 .41171 Mdot
.38794 .46208 Mdot
.18 .49843 Mdot
.58293 .56938 Mdot
.47183 .67767 Mdot
.57976 .55582 Mdot
.47076 .35298 Mdot
.33826 .65278 Mdot
.69641 .60134 Mdot
.45685 .68418 Mdot
.3291 .58466 Mdot
.54306 .24539 Mdot
.31233 .42471 Mdot
.38809 .38186 Mdot
.54674 .2893 Mdot
.51487 .71277 Mdot
.69778 .58605 Mdot
.53016 .44 Mdot
.54944 .29329 Mdot
.69051 .59058 Mdot
.49324 .66468 Mdot
.32932 .44046 Mdot
.3246 .40291 Mdot
.3395 .41315 Mdot
.50524 .26185 Mdot
.30144 .47733 Mdot
.67091 .52322 Mdot
.57996 .41898 Mdot
.36241 .35937 Mdot
.56499 .42555 Mdot
.30751 .60332 Mdot
.34003 .39725 Mdot
.64233 .4559 Mdot
.53408 .27902 Mdot
.51622 .25928 Mdot
.526 .3695 Mdot
.55069 .2797 Mdot
.53472 .37033 Mdot
.36779 .36287 Mdot
.27774 .46212 Mdot
.51609 .36027 Mdot
.30248 .62086 Mdot
.7166 .591 Mdot
.30703 .38239 Mdot
.56197 .40269 Mdot
.33712 .3587 Mdot
.55188 .33237 Mdot
.20661 .50487 Mdot
.55353 .27875 Mdot
.42898 .67031 Mdot
.57332 .37007 Mdot
.44545 .67722 Mdot
.55169 .23916 Mdot
.29957 .35701 Mdot
.32162 .64998 Mdot
.56262 .27676 Mdot
.44118 .6747 Mdot
.49644 .22537 Mdot
.5884 .57173 Mdot
.70392 .60084 Mdot
.59498 .5282 Mdot
.31627 .59865 Mdot
.54904 .36078 Mdot
.55459 .41521 Mdot
.58971 .39854 Mdot
.47119 .35459 Mdot
.6005 .57666 Mdot
.74712 .60962 Mdot
.31251 .35594 Mdot
.539 .41289 Mdot
.45797 .70459 Mdot
.34892 .43384 Mdot
.49265 .25103 Mdot
.48424 .27108 Mdot
.53384 .24561 Mdot
.31839 .43056 Mdot
.35463 .43959 Mdot
.78861 .60592 Mdot
.71524 .60351 Mdot
.5418 .35267 Mdot
.70894 .5736 Mdot
.54276 .26487 Mdot
.33021 .60639 Mdot
.58586 .40685 Mdot
.51177 .71104 Mdot
.68634 .45126 Mdot
.48888 .66365 Mdot
.5259 .36478 Mdot
.31892 .4184 Mdot
.30323 .63303 Mdot
.53027 .68185 Mdot
.41836 .7057 Mdot
.68123 .52549 Mdot
.50935 .65266 Mdot
.7025 .57852 Mdot
.72481 .59264 Mdot
.30983 .59726 Mdot
.55183 .37813 Mdot
.65122 .45557 Mdot
.54889 .21463 Mdot
.53876 .36541 Mdot
.56074 .37408 Mdot
.34713 .665 Mdot
.35038 .62232 Mdot
.45484 .68449 Mdot
.55408 .35584 Mdot
.55037 .41846 Mdot
.3216 .42251 Mdot
.67386 .5764 Mdot
.47479 .70047 Mdot
.71633 .5818 Mdot
.47921 .68374 Mdot
.7456 .4653 Mdot
.57292 .56588 Mdot
.71534 .58623 Mdot
.34978 .60415 Mdot
.34714 .41964 Mdot
.60553 .57584 Mdot
.50096 .69573 Mdot
.46968 .67614 Mdot
.50806 .39228 Mdot
.30263 .40356 Mdot
.35474 .42158 Mdot
.70214 .58058 Mdot
.34 .60127 Mdot
.53778 .27942 Mdot
.58449 .53503 Mdot
.50265 .7498 Mdot
.4765 .67125 Mdot
.31813 .35509 Mdot
.39098 .3989 Mdot
.55192 .4057 Mdot
.33871 .44009 Mdot
.53962 .39529 Mdot
.30337 .37492 Mdot
.29253 .409 Mdot
.58234 .35615 Mdot
.42587 .38209 Mdot
.5002 .70961 Mdot
.72316 .7565 Mdot
.52944 .27367 Mdot
.32041 .57647 Mdot
.54026 .26931 Mdot
.51812 .8161 Mdot
.74678 .48935 Mdot
.5354 .40885 Mdot
.56497 .40011 Mdot
.84133 .39825 Mdot
.57928 .38867 Mdot
.60198 .54233 Mdot
.58914 .57267 Mdot
.33463 .44264 Mdot
.59917 .53004 Mdot
.67037 .45433 Mdot
.72084 .61235 Mdot
.48954 .6926 Mdot
.73154 .5238 Mdot
.69837 .58291 Mdot
.31241 .40268 Mdot
.53557 .27727 Mdot
.3978 .4125 Mdot
.46707 .71252 Mdot
.60054 .55691 Mdot
.3391 .61385 Mdot
.65929 .45834 Mdot
.49457 .66892 Mdot
.33543 .58997 Mdot
.58003 .37369 Mdot
.46407 .76885 Mdot
.30259 .61515 Mdot
.74021 .73812 Mdot
.31494 .63277 Mdot
.32836 .59004 Mdot
.65865 .45092 Mdot
.72083 .61267 Mdot
.57824 .52965 Mdot
.54993 .5781 Mdot
.313 .64192 Mdot
.57827 .82253 Mdot
.51361 .67398 Mdot
.69541 .43179 Mdot
.26436 .44498 Mdot
.58326 .57529 Mdot
.56336 .36893 Mdot
.32521 .63963 Mdot
.50908 .37979 Mdot
.58305 .52812 Mdot
.33038 .63213 Mdot
.55088 .2386 Mdot
.6856 .47779 Mdot
.58271 .55874 Mdot
.61083 .56343 Mdot
.68155 .57655 Mdot
.43209 .66553 Mdot
.35427 .42767 Mdot
.68417 .60715 Mdot
.68126 .40974 Mdot
.53381 .35615 Mdot
.32187 .59779 Mdot
.59626 .55348 Mdot
.31797 .61713 Mdot
.70212 .60868 Mdot
.72104 .62444 Mdot
.30308 .40937 Mdot
.29579 .47254 Mdot
.58089 .58598 Mdot
.66943 .37374 Mdot
.57644 .41706 Mdot
.42411 .29538 Mdot
.34594 .44853 Mdot
.51782 .21025 Mdot
.71286 .61814 Mdot
.67056 .57897 Mdot
.5591 .25257 Mdot
.56591 .34108 Mdot
.55205 .27462 Mdot
.5734 .34439 Mdot
.56638 .80635 Mdot
.54724 .25725 Mdot
.46641 .68628 Mdot
.56687 .33416 Mdot
.28999 .52542 Mdot
.5592 .28005 Mdot
.55811 .4069 Mdot
.49343 .68127 Mdot
.54554 .42927 Mdot
.51395 .70136 Mdot
.56831 .37593 Mdot
.49026 .79315 Mdot
.48725 .69279 Mdot
.62238 .58558 Mdot
.55898 .46186 Mdot
.60647 .54713 Mdot
.69915 .6128 Mdot
.72771 .58406 Mdot
.70936 .52329 Mdot
.32774 .4378 Mdot
.44777 .18091 Mdot
.55719 .40637 Mdot
.50766 .67017 Mdot
.33964 .61007 Mdot
.54282 .23662 Mdot
.53887 .34864 Mdot
.54255 .28467 Mdot
.31194 .42948 Mdot
.51453 .67197 Mdot
.70944 .61278 Mdot
.48876 .72391 Mdot
.48784 .79671 Mdot
.50954 .70986 Mdot
.48254 .36056 Mdot
.54869 .24494 Mdot
.64262 .59807 Mdot
.43106 .32522 Mdot
.65899 .57655 Mdot
.30756 .41915 Mdot
.59312 .55116 Mdot
.73366 .60188 Mdot
.63345 .47688 Mdot
.35167 .42944 Mdot
.47634 .69684 Mdot
.54702 .39081 Mdot
.57193 .54749 Mdot
.54958 .57717 Mdot
.29957 .39616 Mdot
.73045 .62308 Mdot
.49686 .6906 Mdot
.58618 .55441 Mdot
.66984 .43953 Mdot
.4679 .24669 Mdot
.69747 .41317 Mdot
.54325 .39348 Mdot
.6957 .58121 Mdot
.30253 .4031 Mdot
.54392 .28643 Mdot
.33968 .63778 Mdot
.66225 .45496 Mdot
.56124 .36558 Mdot
.26317 .61076 Mdot
.31763 .4175 Mdot
.72329 .60433 Mdot
.32077 .63786 Mdot
.71453 .60163 Mdot
.59776 .53774 Mdot
.32549 .37673 Mdot
.5905 .53518 Mdot
.55307 .25678 Mdot
.33556 .60547 Mdot
.35404 .42416 Mdot
.4878 .79521 Mdot
.57764 .52694 Mdot
.48417 .70004 Mdot
.63636 .4761 Mdot
.30379 .42255 Mdot
.35807 .56456 Mdot
.48748 .72318 Mdot
.39211 .63851 Mdot
.62938 .4618 Mdot
.33185 .63507 Mdot
.55955 .40567 Mdot
.33267 .41267 Mdot
.30355 .63526 Mdot
.41884 .68688 Mdot
.51688 .28005 Mdot
.56562 .56755 Mdot
.53109 .39896 Mdot
.18315 .4654 Mdot
.28628 .53933 Mdot
.25672 .41309 Mdot
.33882 .58837 Mdot
.53487 .36109 Mdot
.58097 .56886 Mdot
.51423 .38171 Mdot
.31929 .646 Mdot
.30612 .64846 Mdot
.51473 .72371 Mdot
.54971 .3941 Mdot
.71524 .59616 Mdot
.50024 .71786 Mdot
.4763 .65476 Mdot
.45466 .6788 Mdot
.29818 .47196 Mdot
.57842 .57471 Mdot
.58603 .57241 Mdot
.7472 .49555 Mdot
.31674 .61735 Mdot
.60576 .54649 Mdot
.55491 .41615 Mdot
.67193 .52277 Mdot
.3408 .4098 Mdot
.5006 .68792 Mdot
.53581 .35845 Mdot
.53293 .28203 Mdot
.60502 .55796 Mdot
.49624 .67663 Mdot
.34534 .456 Mdot
.52819 .53727 Mdot
.54918 .36782 Mdot
.54839 .25249 Mdot
.31744 .39762 Mdot
.22139 .40521 Mdot
.67978 .43476 Mdot
.53867 .39349 Mdot
.31411 .60522 Mdot
.2199 .42753 Mdot
.57919 .37752 Mdot
.41898 .41498 Mdot
.61219 .57391 Mdot
.51328 .51617 Mdot
.28131 .37258 Mdot
.57846 .33231 Mdot
.43797 .56294 Mdot
.63306 .3103 Mdot
.46362 .5844 Mdot
.59657 .79704 Mdot
.3973 .55569 Mdot
.75827 .71781 Mdot
.35941 .61616 Mdot
.57071 .31994 Mdot
.78229 .29381 Mdot
.28301 .55312 Mdot
.39137 .57578 Mdot
.32673 .56571 Mdot
.64387 .53867 Mdot
.50376 .80732 Mdot
.46435 .77011 Mdot
.59887 .79223 Mdot
.51551 .41445 Mdot
.27801 .49126 Mdot
.56773 .28197 Mdot
.337 .55456 Mdot
.4305 .72761 Mdot
.55232 .29613 Mdot
.82972 .41355 Mdot
.26772 .65187 Mdot
.81009 .51033 Mdot
.43432 .22184 Mdot
.48045 .76156 Mdot
.65639 .36644 Mdot
.74618 .5548 Mdot
.56204 .23052 Mdot
.48681 .55014 Mdot
.35644 .63381 Mdot
.36699 .43839 Mdot
.28541 .68268 Mdot
.47197 .68831 Mdot
.29753 .41007 Mdot
.25091 .6477 Mdot
.83597 .47122 Mdot
.36772 .59749 Mdot
.43694 .56405 Mdot
.56491 .54656 Mdot
.5191 .50578 Mdot
.63842 .45231 Mdot
.29204 .37831 Mdot
.48992 .77658 Mdot
.50898 .80061 Mdot
.38171 .40179 Mdot
.42723 .69513 Mdot
.62041 .47846 Mdot
.38703 .57363 Mdot
.26839 .37863 Mdot
.64992 .56128 Mdot
.62676 .58022 Mdot
.34532 .44944 Mdot
.79282 .37002 Mdot
.49432 .41781 Mdot
.68401 .40165 Mdot
.43936 .73216 Mdot
.36743 .45016 Mdot
.42146 .23219 Mdot
.38347 .46586 Mdot
.67302 .79423 Mdot
.83695 .51085 Mdot
.63757 .78858 Mdot
.55396 .46974 Mdot
.37024 .62212 Mdot
.59411 .47782 Mdot
.48666 .61113 Mdot
.66367 .77862 Mdot
.22824 .40207 Mdot
.80503 .36055 Mdot
.47504 .47187 Mdot
.85006 .48539 Mdot
.35522 .37853 Mdot
.64542 .56226 Mdot
.26079 .39715 Mdot
.55174 .50084 Mdot
.72083 .47863 Mdot
.84657 .45663 Mdot
.35985 .55366 Mdot
.59196 .5193 Mdot
.28611 .55185 Mdot
.27879 .36677 Mdot
.48394 .78123 Mdot
.61708 .5384 Mdot
.45097 .30794 Mdot
.84726 .43313 Mdot
.44642 .55486 Mdot
.81426 .43048 Mdot
.49955 .77618 Mdot
.27239 .7194 Mdot
.47771 .65295 Mdot
.33195 .66012 Mdot
.82154 .5083 Mdot
.32886 .40984 Mdot
.69747 .78202 Mdot
.40938 .57967 Mdot
.43196 .62819 Mdot
.84251 .42453 Mdot
.64805 .80627 Mdot
.55493 .49163 Mdot
.63749 .57892 Mdot
.28772 .68056 Mdot
.48726 .58473 Mdot
.31849 .53834 Mdot
.54225 .53488 Mdot
.19603 .48977 Mdot
.82099 .49496 Mdot
.62977 .8079 Mdot
.79295 .32806 Mdot
.67721 .40704 Mdot
.68562 .54611 Mdot
.38833 .41322 Mdot
.41269 .50041 Mdot
.32139 .54267 Mdot
.84835 .49561 Mdot
.56318 .2855 Mdot
.21077 .43246 Mdot
.61062 .79093 Mdot
.48642 .25636 Mdot
.22623 .48145 Mdot
.267 .58891 Mdot
.53258 .5436 Mdot
.3153 .36361 Mdot
.74971 .6329 Mdot
.72125 .49476 Mdot
.44403 .29274 Mdot
.42691 .68005 Mdot
.67841 .44202 Mdot
.40004 .45587 Mdot
.74129 .70638 Mdot
.24602 .4761 Mdot
.45036 .30086 Mdot
.38664 .38247 Mdot
.66512 .77624 Mdot
.6145 .79501 Mdot
.21659 .45613 Mdot
.48428 .74001 Mdot
.81806 .4401 Mdot
.36156 .50074 Mdot
.53309 .49592 Mdot
.5652 .29441 Mdot
.5599 .23917 Mdot
.52838 .78881 Mdot
.47146 .39286 Mdot
.78327 .59295 Mdot
.2894 .56714 Mdot
.43041 .33766 Mdot
.76475 .56407 Mdot
.43528 .33112 Mdot
.29321 .35877 Mdot
.4258 .43308 Mdot
.26923 .65099 Mdot
.43781 .39653 Mdot
.83323 .41435 Mdot
.47322 .70508 Mdot
.66082 .78313 Mdot
.36535 .59724 Mdot
.46382 .76437 Mdot
.42158 .63117 Mdot
.41764 .6341 Mdot
.80891 .53343 Mdot
.26722 .57836 Mdot
.63253 .52922 Mdot
.26605 .397 Mdot
.43256 .59837 Mdot
.42958 .2929 Mdot
.50402 .34684 Mdot
.3081 .4946 Mdot
.73033 .61878 Mdot
.45354 .34244 Mdot
.31404 .36286 Mdot
.47537 .73085 Mdot
.48945 .35053 Mdot
.66817 .33888 Mdot
.59457 .58588 Mdot
.67732 .50558 Mdot
.74579 .47021 Mdot
.5044 .47878 Mdot
.66299 .79139 Mdot
.34246 .50448 Mdot
.68311 .50737 Mdot
.32087 .54479 Mdot
.45325 .18194 Mdot
.85154 .48349 Mdot
.80517 .57864 Mdot
.23073 .42669 Mdot
.20985 .47172 Mdot
.31851 .77989 Mdot
.37025 .57647 Mdot
.75903 .69997 Mdot
.36559 .59786 Mdot
.38089 .18441 Mdot
.47239 .70714 Mdot
.58662 .48961 Mdot
.33914 .38011 Mdot
.66266 .33969 Mdot
.83626 .44048 Mdot
.50958 .49254 Mdot
.69367 .61574 Mdot
.25551 .39935 Mdot
.4294 .38506 Mdot
.82067 .4077 Mdot
.80257 .37218 Mdot
.80225 .38103 Mdot
.24996 .63963 Mdot
.46146 .37274 Mdot
.83643 .40396 Mdot
.63307 .50475 Mdot
.47411 .43349 Mdot
.54938 .30869 Mdot
.68798 .37447 Mdot
.73834 .72876 Mdot
.66422 .54934 Mdot
.49178 .58338 Mdot
.38221 .40099 Mdot
.85079 .42837 Mdot
.7539 .48364 Mdot
.52695 .51438 Mdot
.79916 .51828 Mdot
.75162 .59734 Mdot
.76928 .55793 Mdot
.80474 .54438 Mdot
.46513 .55129 Mdot
.27236 .58133 Mdot
.85765 .43043 Mdot
.65044 .77235 Mdot
.34897 .56697 Mdot
.32494 .35991 Mdot
.72776 .74482 Mdot
.2192 .48156 Mdot
.36888 .65242 Mdot
.3523 .38059 Mdot
.46578 .19399 Mdot
.36543 .53532 Mdot
.49175 .55201 Mdot
.59063 .40997 Mdot
.76803 .57766 Mdot
.46137 .69733 Mdot
.70334 .74825 Mdot
.35227 .52438 Mdot
.46693 .43085 Mdot
.70163 .50861 Mdot
.60879 .81589 Mdot
.48265 .51206 Mdot
.48206 .32385 Mdot
.34469 .50339 Mdot
.23774 .46041 Mdot
.23165 .47738 Mdot
.4481 .23253 Mdot
.56442 .42159 Mdot
.83925 .46692 Mdot
.7773 .69246 Mdot
.8095 .54703 Mdot
.22635 .46042 Mdot
.29914 .74941 Mdot
.35305 .59557 Mdot
.64518 .50872 Mdot
.66616 .31839 Mdot
.45022 .52403 Mdot
.6396 .30088 Mdot
.29589 .61137 Mdot
.421 .23238 Mdot
.42071 .62305 Mdot
.63332 .50408 Mdot
.2662 .46429 Mdot
.43777 .6157 Mdot
.47487 .33601 Mdot
.3737 .37475 Mdot
.19669 .44179 Mdot
.66871 .77313 Mdot
.46926 .70086 Mdot
.49805 .74314 Mdot
.47135 .41041 Mdot
.65163 .58746 Mdot
.5855 .51264 Mdot
.53863 .49132 Mdot
.42916 .2635 Mdot
.31612 .76445 Mdot
.79033 .56465 Mdot
.72141 .75681 Mdot
.80476 .54739 Mdot
.62851 .79357 Mdot
.43211 .71315 Mdot
.68757 .4963 Mdot
.38133 .61492 Mdot
.36575 .61525 Mdot
.67858 .48927 Mdot
.6114 .80701 Mdot
.53113 .50566 Mdot
.26263 .40407 Mdot
.56281 .41832 Mdot
.74363 .48202 Mdot
.73608 .55159 Mdot
.6617 .49903 Mdot
.45694 .24142 Mdot
.33732 .46331 Mdot
.66078 .53226 Mdot
.51075 .54743 Mdot
.53833 .23109 Mdot
.20874 .46738 Mdot
.30208 .63385 Mdot
.34916 .36508 Mdot
.60838 .81738 Mdot
.32032 .77552 Mdot
.45552 .59915 Mdot
.50049 .40817 Mdot
.81872 .48637 Mdot
.54838 .46102 Mdot
.20612 .48117 Mdot
.47597 .19615 Mdot
.40382 .64101 Mdot
.37684 .39412 Mdot
.49088 .45737 Mdot
.42708 .63981 Mdot
.25579 .46499 Mdot
.35774 .37032 Mdot
.55451 .2339 Mdot
.82902 .51748 Mdot
.56401 .43773 Mdot
.47747 .55895 Mdot
.68294 .42442 Mdot
.39543 .51059 Mdot
.41878 .5862 Mdot
.70956 .51552 Mdot
.45356 .57858 Mdot
.79583 .38331 Mdot
.41679 .2437 Mdot
.50239 .58267 Mdot
.63517 .51325 Mdot
.62928 .50091 Mdot
.43406 .22289 Mdot
.26662 .37337 Mdot
.29379 .56483 Mdot
.54106 .4376 Mdot
.83058 .53064 Mdot
.46186 .46489 Mdot
.69369 .50685 Mdot
.38794 .47708 Mdot
.54499 .434 Mdot
.60874 .51894 Mdot
.80565 .53973 Mdot
.51298 .5207 Mdot
.7789 .28131 Mdot
.58843 .80704 Mdot
.33269 .49236 Mdot
.28268 .3785 Mdot
.67784 .7742 Mdot
.31063 .5114 Mdot
.40763 .56284 Mdot
.35957 .51524 Mdot
.7148 .75171 Mdot
.50471 .51433 Mdot
.51446 .53018 Mdot
.19305 .45485 Mdot
.82655 .39204 Mdot
.48219 .57645 Mdot
.36372 .65383 Mdot
.68397 .5506 Mdot
.55141 .34488 Mdot
.37597 .47615 Mdot
.17722 .51449 Mdot
.41415 .46895 Mdot
.47106 .59053 Mdot
.77114 .70684 Mdot
.51652 .4904 Mdot
.33784 .50845 Mdot
.78209 .28424 Mdot
.78246 .27504 Mdot
.36889 .47899 Mdot
.84662 .50354 Mdot
.51848 .52585 Mdot
.20943 .48411 Mdot
.35662 .63711 Mdot
.50304 .36216 Mdot
.4239 .28935 Mdot
.82168 .54964 Mdot
.28928 .75359 Mdot
.31525 .54317 Mdot
.35864 .39248 Mdot
.82303 .55716 Mdot
.46688 .44067 Mdot
.60986 .50417 Mdot
.27479 .7196 Mdot
.54647 .8226 Mdot
.67459 .78986 Mdot
.45908 .2267 Mdot
.52456 .79691 Mdot
.56772 .78741 Mdot
.35057 .54678 Mdot
.7327 .74312 Mdot
.55872 .54576 Mdot
.46214 .18156 Mdot
.66285 .7778 Mdot
.193 .47058 Mdot
.49906 .79334 Mdot
.42099 .58398 Mdot
.52843 .49057 Mdot
.43269 .43083 Mdot
.19795 .49401 Mdot
.25763 .60329 Mdot
.50647 .45686 Mdot
.65234 .47801 Mdot
.29358 .36103 Mdot
.21505 .41851 Mdot
.49041 .19011 Mdot
.54868 .48571 Mdot
.78256 .34282 Mdot
.26731 .61318 Mdot
.6371 .48765 Mdot
.27405 .38897 Mdot
.72271 .53079 Mdot
.62795 .52167 Mdot
.56098 .33235 Mdot
.8294 .51282 Mdot
.62678 .52219 Mdot
.79038 .3555 Mdot
.69364 .788 Mdot
.79837 .50875 Mdot
.47383 .61822 Mdot
.56246 .51463 Mdot
.73892 .72485 Mdot
.74877 .71038 Mdot
.788 .33813 Mdot
.60294 .78636 Mdot
.67586 .48736 Mdot
.51679 .46852 Mdot
.50704 .34694 Mdot
.4755 .35215 Mdot
.68261 .77028 Mdot
.43054 .22046 Mdot
.762 .55676 Mdot
.2369 .43881 Mdot
.61132 .81058 Mdot
.57025 .47384 Mdot
.71462 .52767 Mdot
.40041 .4804 Mdot
.63564 .5704 Mdot
.52266 .68436 Mdot
.83152 .37115 Mdot
.21478 .46034 Mdot
.77888 .5587 Mdot
.21067 .43822 Mdot
.37949 .37055 Mdot
.57837 .79867 Mdot
.25636 .39255 Mdot
.56426 .61608 Mdot
.45702 .7452 Mdot
.76944 .62138 Mdot
.54298 .50105 Mdot
.18151 .475 Mdot
.47443 .27024 Mdot
.81357 .53356 Mdot
.76662 .56574 Mdot
.7843 .31609 Mdot
.66417 .53718 Mdot
.45243 .34166 Mdot
.78805 .36437 Mdot
.23366 .44321 Mdot
.64957 .49619 Mdot
.82265 .40291 Mdot
.26307 .44665 Mdot
.8377 .50738 Mdot
.34298 .63046 Mdot
.62772 .51382 Mdot
.18372 .49823 Mdot
.64583 .50165 Mdot
.64098 .49875 Mdot
.78847 .57391 Mdot
.29016 .5477 Mdot
.32735 .51221 Mdot
.35828 .50324 Mdot
.47287 .77223 Mdot
.50091 .37111 Mdot
.46496 .56165 Mdot
.79545 .33124 Mdot
.56802 .41592 Mdot
.64385 .76293 Mdot
.66134 .78699 Mdot
.3821 .61933 Mdot
.53262 .48308 Mdot
.18548 .48589 Mdot
.47092 .21758 Mdot
.73744 .49759 Mdot
.8283 .39823 Mdot
.53226 .48212 Mdot
.66022 .32424 Mdot
.50885 .20527 Mdot
.29644 .67759 Mdot
.30281 .5555 Mdot
.44386 .56566 Mdot
.53211 .4587 Mdot
.67718 .43442 Mdot
.63521 .78736 Mdot
.76455 .71354 Mdot
.78246 .33915 Mdot
.30396 .55733 Mdot
.65596 .50258 Mdot
.41948 .42295 Mdot
.74935 .57442 Mdot
.79369 .32254 Mdot
.51012 .81091 Mdot
.31607 .36283 Mdot
.61985 .80581 Mdot
.28965 .55346 Mdot
.61247 .50404 Mdot
.66852 .49559 Mdot
.79466 .37481 Mdot
.36421 .41371 Mdot
.48579 .47033 Mdot
.40612 .45713 Mdot
.66855 .4603 Mdot
.40672 .59126 Mdot
.45891 .19712 Mdot
.26031 .58605 Mdot
.78323 .31506 Mdot
.55392 .79196 Mdot
.49243 .23961 Mdot
.78245 .29993 Mdot
.34068 .46294 Mdot
.40409 .59084 Mdot
.26585 .70639 Mdot
.67637 .50873 Mdot
.46048 .65667 Mdot
.54941 .42068 Mdot
.6685 .48205 Mdot
.29951 .50367 Mdot
.66594 .543 Mdot
.73045 .62678 Mdot
.33718 .36345 Mdot
.57823 .79206 Mdot
.36452 .37009 Mdot
.76583 .70826 Mdot
.46369 .547 Mdot
.29319 .3677 Mdot
.49371 .19867 Mdot
.43259 .71058 Mdot
.23594 .45413 Mdot
.80761 .51191 Mdot
.68715 .37911 Mdot
.32161 .36835 Mdot
.3308 .36887 Mdot
.2725 .46505 Mdot
.38668 .6097 Mdot
.82555 .47625 Mdot
.65018 .80254 Mdot
.50161 .74883 Mdot
.27751 .46598 Mdot
.55881 .46434 Mdot
.53276 .49308 Mdot
.78557 .54263 Mdot
.49442 .72466 Mdot
.85774 .47249 Mdot
.4363 .1879 Mdot
.27342 .48998 Mdot
.45738 .51422 Mdot
.67663 .33102 Mdot
.61099 .48391 Mdot
.42967 .69515 Mdot
.54933 .49103 Mdot
.34155 .49505 Mdot
.34605 .46775 Mdot
.41411 .61039 Mdot
.7157 .62 Mdot
.47957 .73867 Mdot
.35259 .57348 Mdot
.44451 .22941 Mdot
.67527 .78118 Mdot
.39813 .39397 Mdot
.59357 .5099 Mdot
.44299 .70155 Mdot
.47918 .36309 Mdot
.68235 .35544 Mdot
.84603 .39598 Mdot
.80937 .49585 Mdot
.2995 .43228 Mdot
.24901 .47516 Mdot
.49669 .78346 Mdot
.78904 .56317 Mdot
.49206 .48408 Mdot
.6792 .7691 Mdot
.45168 .31671 Mdot
.79635 .54014 Mdot
.28097 .37487 Mdot
.43971 .548 Mdot
.64171 .79659 Mdot
.758 .61579 Mdot
.61791 .81193 Mdot
.47424 .22684 Mdot
.50794 .43509 Mdot
.56094 .82026 Mdot
.41018 .46399 Mdot
.53349 .51498 Mdot
.53582 .23088 Mdot
.44879 .52877 Mdot
.71909 .74559 Mdot
.34023 .46794 Mdot
.64885 .54356 Mdot
.23523 .41301 Mdot
.31375 .54384 Mdot
.81907 .49645 Mdot
.23235 .46874 Mdot
.64371 .80409 Mdot
.49941 .37495 Mdot
.76004 .60574 Mdot
.43118 .23194 Mdot
.68208 .39284 Mdot
.58511 .53235 Mdot
.44404 .30627 Mdot
.59474 .52297 Mdot
.75081 .49413 Mdot
.47996 .34335 Mdot
.84155 .44962 Mdot
.74415 .47429 Mdot
.43389 .43208 Mdot
.64297 .56443 Mdot
.35742 .4059 Mdot
.85312 .45536 Mdot
.73432 .4925 Mdot
.19337 .49437 Mdot
.67481 .78854 Mdot
.60507 .78152 Mdot
.78175 .296 Mdot
.28885 .55116 Mdot
.45037 .41414 Mdot
.73795 .73858 Mdot
.46747 .46197 Mdot
.57087 .78664 Mdot
.54291 .50092 Mdot
.3923 .41401 Mdot
.83634 .41592 Mdot
.63788 .54267 Mdot
.42707 .44021 Mdot
.5222 .28211 Mdot
.3746 .39471 Mdot
.72758 .48288 Mdot
.56673 .46846 Mdot
.47293 .69488 Mdot
.66843 .33106 Mdot
.52419 .78882 Mdot
.28224 .47355 Mdot
.67128 .78048 Mdot
.68814 .76096 Mdot
.69477 .55418 Mdot
.4714 .62251 Mdot
.77931 .29465 Mdot
.45103 .37122 Mdot
.57876 .33565 Mdot
.36468 .37155 Mdot
.73352 .62571 Mdot
.62501 .7814 Mdot
.53607 .43216 Mdot
.66354 .35806 Mdot
.45121 .31088 Mdot
.82443 .53756 Mdot
.40823 .49307 Mdot
.26671 .63146 Mdot
.26643 .45325 Mdot
.19528 .49219 Mdot
.2291 .41545 Mdot
.27836 .55392 Mdot
.71957 .7435 Mdot
.45586 .59847 Mdot
.43797 .55854 Mdot
.43513 .41833 Mdot
.7037 .74326 Mdot
.32092 .55304 Mdot
.30052 .60441 Mdot
.4285 .2699 Mdot
.78179 .3285 Mdot
.33008 .36004 Mdot
.42707 .58473 Mdot
.48818 .53573 Mdot
.53323 .45167 Mdot
.31996 .5389 Mdot
.31747 .52091 Mdot
.36788 .37852 Mdot
.8096 .40775 Mdot
.49418 .56491 Mdot
.56388 .51726 Mdot
.6033 .80304 Mdot
.47604 .53979 Mdot
.68958 .76266 Mdot
.42497 .38145 Mdot
.80544 .38857 Mdot
.6927 .50884 Mdot
.74645 .59108 Mdot
.55081 .42553 Mdot
.2406 .43219 Mdot
.80622 .54133 Mdot
.4898 .48383 Mdot
.47885 .60433 Mdot
.25287 .38658 Mdot
.69053 .78574 Mdot
.62054 .5771 Mdot
.31357 .76137 Mdot
.63883 .57412 Mdot
.66871 .34506 Mdot
.66288 .33304 Mdot
.38996 .62319 Mdot
.53179 .49718 Mdot
.36275 .54793 Mdot
.52359 .452 Mdot
.43348 .25633 Mdot
.78211 .60962 Mdot
.82523 .36416 Mdot
.36708 .45247 Mdot
.66188 .80453 Mdot
.3304 .48726 Mdot
.38116 .42994 Mdot
.5566 .78995 Mdot
.49539 .60783 Mdot
.46772 .39731 Mdot
.67533 .54852 Mdot
.33165 .46975 Mdot
.81644 .35407 Mdot
.46784 .59246 Mdot
.65243 .54512 Mdot
.48946 .78225 Mdot
.42096 .59264 Mdot
.27827 .683 Mdot
.36478 .60378 Mdot
.70311 .77579 Mdot
.66399 .77853 Mdot
.26471 .64333 Mdot
.51756 .52512 Mdot
.47861 .59957 Mdot
.81936 .40772 Mdot
.64067 .5643 Mdot
.81499 .50709 Mdot
.248 .63296 Mdot
.44303 .25111 Mdot
.74045 .47156 Mdot
.72346 .49433 Mdot
.6861 .39065 Mdot
.45456 .27934 Mdot
.80979 .43617 Mdot
.58456 .58386 Mdot
.48921 .74461 Mdot
.50106 .79318 Mdot
.79652 .32857 Mdot
.25811 .47395 Mdot
.56054 .5666 Mdot
.74992 .56779 Mdot
.49332 .56192 Mdot
.63407 .48568 Mdot
.35555 .50986 Mdot
.57982 .51406 Mdot
.27705 .66954 Mdot
.21981 .43663 Mdot
.82945 .52955 Mdot
.54146 .42281 Mdot
.63103 .29855 Mdot
.34141 .5534 Mdot
.4502 .66484 Mdot
.2374 .40175 Mdot
.8421 .39184 Mdot
.29888 .6094 Mdot
.26756 .70282 Mdot
.38508 .61448 Mdot
.78297 .55743 Mdot
.29938 .75571 Mdot
.38948 .61337 Mdot
.76149 .71793 Mdot
.29269 .50306 Mdot
.47422 .2484 Mdot
.20813 .42796 Mdot
.75133 .49127 Mdot
.44194 .30466 Mdot
.54141 .53661 Mdot
.83576 .49467 Mdot
.62078 .48766 Mdot
.64295 .53486 Mdot
.80805 .42335 Mdot
.63464 .80042 Mdot
.5939 .80685 Mdot
.37044 .57838 Mdot
.36048 .3911 Mdot
.32937 .78236 Mdot
.46947 .76398 Mdot
.41842 .19278 Mdot
.8075 .49308 Mdot
.51428 .24586 Mdot
.48808 .47962 Mdot
.36783 .49484 Mdot
.82742 .41853 Mdot
.71135 .74572 Mdot
.53139 .52306 Mdot
.45715 .70553 Mdot
.71987 .50453 Mdot
.74131 .56753 Mdot
.32853 .51808 Mdot
.79166 .52072 Mdot
.43104 .69849 Mdot
.63877 .54553 Mdot
.64941 .79544 Mdot
.24072 .43105 Mdot
.67615 .40251 Mdot
.78403 .33086 Mdot
.6803 .36435 Mdot
.59575 .81785 Mdot
.24956 .63923 Mdot
.49469 .78925 Mdot
.79847 .3361 Mdot
.27539 .48086 Mdot
.46903 .30137 Mdot
.77783 .28228 Mdot
.84947 .48566 Mdot
.48098 .59945 Mdot
.56763 .43081 Mdot
.75325 .72544 Mdot
.47015 .71621 Mdot
.78027 .57242 Mdot
.42162 .22924 Mdot
.57757 .80522 Mdot
.49211 .33738 Mdot
.55726 .43583 Mdot
.61341 .49869 Mdot
.31204 .45078 Mdot
.35515 .38339 Mdot
.48706 .76642 Mdot
.61132 .80603 Mdot
.44428 .21985 Mdot
.41678 .24405 Mdot
.47099 .22607 Mdot
.29541 .41738 Mdot
.83003 .50467 Mdot
.64002 .60393 Mdot
.43312 .21087 Mdot
.81311 .40284 Mdot
.65299 .29892 Mdot
.34732 .54099 Mdot
.42827 .25345 Mdot
.68349 .4993 Mdot
.52293 .78675 Mdot
.79085 .30417 Mdot
.43283 .27432 Mdot
.85831 .46569 Mdot
.80695 .58165 Mdot
.29781 .4197 Mdot
.30745 .48703 Mdot
.60281 .482 Mdot
.47219 .57754 Mdot
.27973 .67454 Mdot
.4636 .76357 Mdot
.59178 .78641 Mdot
.45929 .71427 Mdot
.52411 .40036 Mdot
.37287 .48633 Mdot
.81213 .52799 Mdot
.61598 .50664 Mdot
.81629 .5231 Mdot
.44821 .26347 Mdot
.56786 .41402 Mdot
.77614 .27158 Mdot
.20762 .48465 Mdot
.49932 .35118 Mdot
.58169 .5927 Mdot
.56089 .56256 Mdot
.56125 .32952 Mdot
.30295 .64241 Mdot
.67228 .52067 Mdot
.55748 .80589 Mdot
.83437 .49095 Mdot
.28327 .46979 Mdot
.61322 .48591 Mdot
.33884 .57979 Mdot
.6296 .45682 Mdot
.49279 .33296 Mdot
.29976 .59824 Mdot
.53753 .80206 Mdot
.3087 .68484 Mdot
.32217 .54635 Mdot
.40613 .58798 Mdot
.66277 .47785 Mdot
.56598 .57473 Mdot
.5474 .79655 Mdot
.38865 .62865 Mdot
.33577 .54952 Mdot
.6402 .80568 Mdot
.46021 .28596 Mdot
.28677 .55904 Mdot
.50941 .7765 Mdot
.6544 .49648 Mdot
.38913 .47185 Mdot
.48984 .58866 Mdot
.46874 .19679 Mdot
.82256 .43293 Mdot
.5377 .72555 Mdot
.58304 .58429 Mdot
.5157 .20126 Mdot
.83741 .44619 Mdot
.3239 .58986 Mdot
.77672 .68853 Mdot
.49855 .60494 Mdot
.23826 .40951 Mdot
.52891 .22109 Mdot
.52281 .48151 Mdot
.56472 .27641 Mdot
.58206 .42036 Mdot
.65151 .38151 Mdot
.26015 .68066 Mdot
.5368 .4869 Mdot
.4184 .59668 Mdot
.44968 .5903 Mdot
.64764 .52228 Mdot
.55938 .28951 Mdot
.53022 .3627 Mdot
.62104 .5729 Mdot
.70193 .48286 Mdot
.57754 .5101 Mdot
.64885 .52967 Mdot
.27132 .58353 Mdot
.54713 .79832 Mdot
.59034 .80644 Mdot
.46214 .38107 Mdot
.83106 .41735 Mdot
.53053 .23966 Mdot
.80729 .49805 Mdot
.3824 .50704 Mdot
.27 .58088 Mdot
.67825 .35976 Mdot
.78955 .30537 Mdot
.41232 .4325 Mdot
.56204 .60353 Mdot
.80304 .58359 Mdot
.80169 .52276 Mdot
.26951 .59852 Mdot
.18914 .46579 Mdot
.50255 .79494 Mdot
.61887 .49231 Mdot
.21885 .43114 Mdot
.50892 .74285 Mdot
.79377 .5641 Mdot
.5054 .44257 Mdot
.49239 .60526 Mdot
.45387 .20015 Mdot
.48198 .35937 Mdot
.52005 .70628 Mdot
.47502 .19637 Mdot
.4556 .27816 Mdot
.80944 .43854 Mdot
.57529 .33302 Mdot
.43119 .5151 Mdot
.41867 .42028 Mdot
.78477 .32211 Mdot
.52783 .68815 Mdot
.65945 .32228 Mdot
.42542 .18276 Mdot
.259 .67959 Mdot
.5714 .78479 Mdot
.78179 .33565 Mdot
.36548 .61375 Mdot
.52799 .4553 Mdot
.17508 .52685 Mdot
.4167 .42722 Mdot
.37912 .3795 Mdot
.35572 .57405 Mdot
.73882 .57558 Mdot
.40998 .44646 Mdot
.79174 .29326 Mdot
.79722 .54474 Mdot
.4587 .39901 Mdot
.41359 .19234 Mdot
.65431 .79218 Mdot
.65032 .32414 Mdot
.27553 .56816 Mdot
.82799 .51348 Mdot
.27261 .67062 Mdot
.74251 .73488 Mdot
.47685 .54884 Mdot
.3283 .48391 Mdot
.73201 .56216 Mdot
.21394 .44266 Mdot
.5337 .47539 Mdot
.41466 .23504 Mdot
.20931 .46538 Mdot
.74657 .55487 Mdot
.50018 .51338 Mdot
.37139 .46056 Mdot
.34342 .489 Mdot
.46423 .51899 Mdot
.49452 .61107 Mdot
.42814 .58449 Mdot
.44367 .55767 Mdot
.32169 .55106 Mdot
.45009 .51027 Mdot
.20556 .48937 Mdot
.37481 .62598 Mdot
.45995 .24633 Mdot
.51556 .78244 Mdot
.65937 .53507 Mdot
.46985 .70711 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo07Sooooo
0_l0000=ooooo`?o00000_ooool4o`0000;ooooo0_l0002eooooo`007?ooool00ol0003ooooooooo
o`1hooooo`;o00000_ooool6o`0000Cooooo1?l00002ooooo`Go000000?oooooo`000?l000001Ooo
ool2o`000:kooooo000Looooo`03o`000?oooooooooo07Sooooo0_l00002ooooo`Ko00001?ooool2
o`0000Oooooo0_l00008ooooo`;o0000[_ooool001cooooo00?o0000ooooooooool0O?ooool5o`00
00Wooooo0_l0000@ooooo`;o0000Zoooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2
ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo07gooooo2Ol00004ooooo`;o00004?ooool2
o`000:_ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1oooooo`Oo00003_ooool5o`000;3ooooo
00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00ol0003oooooooooo`22ooooo`Co00002oooool2o`000003ooooool0003o000000?o00001?oo
ool2o`000:[ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RH
ob4Q8Oo^k^h01_ooool3o`0008Cooooo0_l0000:ooooo`?o00002_ooool2o`0000Gooooo0_l0002S
ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo
00Gooooo00?o0000ooooooooool0Q?ooool4o`0000Sooooo0_l0000@ooooo`Co0000Xoooool00003
ooooool@413ooooo00;ooooo00?o410@ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo08Cooooo1_l0000Fooooo`Ko0000Xoooool00006oooooomgMgOoV9RHoooooonH
V9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0POooool:
o`0001Cooooo2Ol0002Qooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`21ooooo`Ko000000Coooooo`000?l0003o
00005?ooool4o`000003ooooool0003o000000Co00001Oooool2o`0009Sooooo000Looooo`03o`00
0?oooooooooo08Cooooo0ol000000ooooooo0000o`00000;ooooo`;o00001oooool3o`0000Kooooo
0ol00005ooooo`?o0000Uoooool001cooooo00?o0000ooooooooool0Qoooool3o`0000?ooooo0_l0
0006ooooo`;o00001oooool3o`0000Kooooo0ol00006ooooo`;o0000Uoooool001cooooo00?o0000
ooooooooool0QOooool6o`0000;ooooo0_l0000>ooooo`Co00001_ooool5o`0009gooooo000Loooo
o`03o`000?oooooooooo08Gooooo1_l00006ooooo`;o00000_ooool3o`0000Cooooo1?l00007oooo
o`;o000000?oooooo`000?l00000WOooool001cooooo00?o0000ooooooooool0QOooool4o`0000Co
oooo0_l00002ooooo`;o00000_ooool3o`0000;ooooo1_l0000;ooooo`Co00001?ooool2o`0009Co
oooo000Looooo`03o`000?oooooooooo08Gooooo1Ol00003ooooo`?o00002_ooool3o`0000gooooo
1Ol000001?oooooo0000o`000?ooool2o`0009Cooooo000Looooo`03o`000?oooooooooo08?ooooo
1ol00004ooooo`;o00002Oooool3o`0000kooooo2?l0002Gooooo`007?ooool00ol0003ooooooooo
o`23ooooo`Go00003oooool4o`000003ooooool0003o000000_ooooo2?l000000ooooooo0000o`00
002Eooooo`007?ooool00ol0003oooooooooo`2Aooooo`;o00001?ooool3o`0000;ooooo0_l0000;
ooooo`_o0000UOooool001cooooo00?o0000ooooooooool0Q?ooool4o`0000Wooooo0_l000001?oo
oooo0000o`000?ooool3o`0000Wooooo0_l00004ooooo`_o0000UOooool001cooooo00?o0000oooo
ooooool0Q?ooool4o`0000[ooooo1_l0000;ooooo`;o00000oooool<o`0009Gooooo000Looooo`;o
0000Qoooool3o`0000?ooooo0_l00004ooooo`Ko00001?ooool2o`0000;ooooo1Ol00003ooooo`co
0000UOooool001cooooo00?o0000ooooooooool0Q_ooool3o`0000?ooooo0_l0000>ooooo`?o0000
00?oooooo`000?l000000_l00004ooooo`co0000UOooool001cooooo00?o0000ooooooooool0Q_oo
ool5o`0000oooooo0_l000000ooooooo0000o`000003ooooo`;o00001?ooool<o`000003ooooool0
003o000009;ooooo000Looooo`03o`000?oooooooooo08Kooooo1Ol00006ooooo`;o00001oooool2
o`0000?ooooo1?l000000ooooooo0000o`000003ooooo`_o000000?oooooo`000?l00000T_ooool0
01cooooo00?o0000ooooooooool0R?ooool2o`0000Cooooo0_l000000ooooooo0000o`000004oooo
o`;o00001?ooool6o`000003ooooool0003o000000ko0000UOooool001cooooo00?o0000oooooooo
ool0R?ooool2o`0000Cooooo0_l00006ooooo`?o00000oooool=o`000003ooooool0003o000000Wo
0000AOooool2o`0004gooooo000Looooo`03o`000?oooooooooo08Kooooo0ol0000=ooooo`;o0000
0_ooool5o`000003ooooool0003o000000Co00000_ooool=o`0004Gooooo0_l0001=ooooo`007?oo
ool00ol0003oooooooooo`25ooooo`Co00003Oooool2o`0000;ooooo0ol00006ooooo`?o00000_oo
ool=o`0004?ooooo0_l000001?oooooo0000o`000?l0001;ooooo`007?ooool00ol0003ooooooooo
o`25ooooo`Ko00003oooool2o`0000Oooooo1?l000000ooooooo0000o`00000<o`0004;ooooo1_l0
001;ooooo`007?ooool00ol0003oooooooooo`26ooooo`Go00001Oooool2o`00017ooooo1?l00000
0ooooooo0000o`00000<o`0004Cooooo1?l0001;ooooo`007?ooool00ol0003oooooooooo`26oooo
o`?o00001oooool2o`0000;ooooo0_l000000ooooooo0000o`00000;ooooo`Co000000?oooooo`00
0?l000003?l00012ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0Qoooool2o`0000Wo
oooo1?l000000ooooooo0000o`00000<ooooo`?o000000?oooooo`000?l000003?l00012ooooo`?o
000000?oooooo`000?l00000B_ooool001cooooo00?o0000ooooooooool0Q_ooool2o`0000[ooooo
0_l00003ooooo`;o00003Oooool2o`0000;ooooo2ol00015ooooo`;o000000?oooooo`000?l00000
B_ooool001cooooo00?o0000ooooooooool0Q_ooool3o`0000kooooo0_l0000=ooooo`?o000000?o
ooooo`000?l000002Ol00018ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0Q_ooool4
o`0000;ooooo0_l0000Iooooo`oo0000@oooool3o`000004ooooool0003o0000o`0004Wooooo000L
ooooo`03o`000?oooooooooo08Kooooo1?l00002ooooo`;o00006Oooool6o`000003ooooool0003o
000000;o000000Coooooo`000?l0003o00004oooool2o`0002kooooo0ol000001?oooooo0000o`00
0?l00019ooooo`007?ooool2o`0008Sooooo0_l00006ooooo`;o00001?ooool2o`00017ooooo0ol0
0002ooooo`Oo00005Oooool2o`000003ooooool0003o000000;ooooo0_l0000Xooooo`;o0000COoo
ool001cooooo00?o0000ooooooooool0Qoooool2o`0000?ooooo0_l000000ooooooo0000o`000004
ooooo`;o00004_ooool2o`0000;ooooo0_l00003ooooo`;o00005?ooool2o`0000;ooooo0_l00002
ooooo`;o0000:?ooool2o`000004ooooool0003o0000o`0004Wooooo000Looooo`03o`000?oooooo
oooo08Oooooo0_l00003ooooo`;o00007Oooool2o`0000;ooooo0_l00004ooooo`;o00004Oooool2
o`0003?ooooo0ol00019ooooo`007?ooool00ol0003oooooooooo`2<ooooo`;o000000?oooooo`00
0?l000006_ooool6o`0000;ooooo1?l0000Booooo`?o0000<Oooool4o`0004Sooooo000Looooo`03
o`000?oooooooooo08oooooo0_l000000ooooooo0000o`000003ooooo`;o00005?ooool4o`0000;o
oooo0_l0000Dooooo`?o0000<oooool2o`0004Sooooo000Looooo`03o`000?oooooooooo08oooooo
0_l000000ooooooo0000o`000003ooooo`;o00005Oooool3o`0000?ooooo0_l0000Cooooo`;o0000
<?ooool2o`0000;ooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`2?ooooo`;o000000?o
ooooo`000?l000006oooool9o`0001gooooo0_l0000Tooooo`;o00000_ooool2o`0004Sooooo000L
ooooo`03o`000?oooooooooo0;3ooooo2?l0000Jooooo`;o000000?oooooo`000?l000009?ooool2
o`000004ooooool0003o0000o`0004Sooooo000Looooo`03o`000?oooooooooo08Sooooo0_l0000?
ooooo`;o00005oooool4o`0001Wooooo0_l000001?oooooo0000o`000?l0000Vooooo`;o000000?o
ooooo`000?l000000_l00017ooooo`007?ooool00ol0003oooooooooo`28ooooo`;o00002?ooool2
o`0000Gooooo0_l0000Gooooo`;o00006oooool2o`0000;ooooo0_l00004ooooo`;o00007oooool2
o`0000;ooooo1?l00017ooooo`007?ooool00ol0003oooooooooo`28ooooo`Co00001_ooool2o`00
01Wooooo2?l00003ooooo`;o00006oooool2o`000003ooooool0003o000000;o00007_ooool3o`00
0003ooooool0003o000000;o0000Aoooool001cooooo00?o0000ooooooooool0R?ooool4o`0000Ko
oooo0_l00008ooooo`;o00003Oooool;o`000004ooooool0003o0000o`0001[ooooo0ol000000ooo
oooo0000o`000002o`0001oooooo0_l00002ooooo`?o0000Aoooool001cooooo00?o0000oooooooo
ool0R?ooool2o`0000Sooooo0_l00002ooooo`;o00001?ooool2o`0000cooooo4?l0000Jooooo`;o
00001?ooool2o`0001kooooo1?l00002ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0
R?ooool2o`0000Gooooo0_l00005ooooo`;o00001?ooool2o`0000cooooo4?l0000Iooooo`Co0000
0oooool4o`0001cooooo1?l00002ooooo`Co0000AOooool001cooooo00?o0000ooooooooool0Sooo
ool3o`000003ooooool0003o000000?ooooo0_l0000@ooooo`oo00006_ooool4o`0000Gooooo0_l0
000Looooo`;o00001_ooool2o`0004Gooooo000Looooo`03o`000?oooooooooo093ooooo0_l00000
1?oooooo0000o`000?l00002ooooo`;o00001_ooool4o`0000?ooooo0_l00003ooooo`go00007?oo
ool2o`0000Gooooo0_l0000Looooo`;o0000COooool001cooooo0_l0002Dooooo`Co00001?ooool2
o`0000?ooooo1?l00003oooooa;o00007?ooool2o`0000Gooooo0_l0000Vooooo`;o0000@oooool0
01cooooo00?o0000ooooooooool0U?ooool5o`0000;ooooo0_l000000ooooooo0000o`000006oooo
oaCo00008_ooool2o`0002Kooooo0ol00012ooooo`007?ooool00ol0003oooooooooo`1Looooo`Co
000000?oooooo`000?l000000ol00005ooooo`;o0000:?ooool4o`0000Gooooo0_l00006oooooaGo
00007oooool4o`0001oooooo0_l00006ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0
G?ooool4o`000003ooooool0003o000000Ko000000?oooooo`000?l000000ol00003ooooo`;o0000
5?ooool2o`0000_ooooo0_l00002ooooo`;o00002ooooolEo`0001Wooooo0_l00003ooooo`?o0000
8Oooool2o`0000Wooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o00000_oo
ool3o`0000?ooooo0ol000001Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`000?l00000
0oooool4o`0001;ooooo0_l0000;ooooo`Ko00001Oooool2o`000003ooooool0003o000001Ko0000
6Oooool2o`0000?ooooo0_l00003ooooo`;o00008_ooool2o`0000Cooooo0_l0000oooooo`007?oo
ool00ol0003oooooooooo`1Hooooo`;o00000_ooool2o`0000Cooooo0ol00005ooooo`;o00000_oo
ool2o`0000;ooooo1_l00002ooooo`;o00006Oooool6o`0000Gooooo0_l000000ooooooo0000o`00
000Ao`000003ooooool0003o000000;o00007_ooool2o`0000?ooooo0_l0000Looooo`;o00001?oo
ool2o`0000Cooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`1Booooo`;o00000oooool2
o`0000?ooooo0_l00005ooooo`Co000000?oooooo`000?l000000_l00002ooooo`;o00001_ooool2
o`0000;ooooo0_l0000;ooooo`;o00004?ooool4o`0000Sooooo3?l000000ooooooo0000o`000002
o`000003ooooool0003o000000Co00005?ooool2o`0000Kooooo0_l0000Qooooo`;o00002_ooool2
o`000003ooooool0003o000003cooooo000Looooo`03o`000?oooooooooo05;ooooo0_l00003oooo
o`;o00000oooool2o`0000Oooooo0_l000000ooooooo0000o`000006ooooo`;o000000?oooooo`00
0?l000000oooool4o`0000_ooooo0_l00006ooooo`;o00002_ooool2o`0000;ooooo0_l00003oooo
o`go000000?oooooo`000?l000002_l0000Cooooo`;o000000?oooooo`000?l000002Oooool2o`00
01gooooo0_l000000ooooooo0000o`000007ooooo`?o0000??ooool001cooooo00?o0000oooooooo
ool0Doooool2o`0000?ooooo0_l00005ooooo`;o000000Coooooo`000?l0003o00002oooool2o`00
0004ooooool0003o0000ooooo`Go000000?oooooo`000?l000002Oooool2o`0000Kooooo0_l00000
0ooooooo0000o`00000:oooooa?o000000?oooooo`000?l000001ol000000ooooooo0000o`00000F
ooooo`Co00001?ooool2o`000003ooooool0003o000001gooooo0_l000000ooooooo0000o`000007
ooooo`;o000000?oooooo`000?l00000>_ooool001cooooo00?o0000ooooooooool0Doooool2o`00
00?ooooo0_l000000ooooooo0000o`000004o`000005ooooool0003o0000o`000?ooool00_l00008
ooooo`;o00000_ooool4o`000003ooooool0003o000000?o00002Oooool2o`0000Wooooo0_l0000:
ooooo`;o000000?oooooo`000?l000007?l0000Booooo`Wo00000_ooool2o`000003ooooool0003o
000001gooooo0_l0000=ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0C?ooool3o`00
00Cooooo0_l00003ooooo`;o000000?oooooo`000?l000001Ol000001?oooooo0000o`000?ooool2
o`0000;ooooo0_l00003ooooo`?o00000_ooool2o`000004ooooool0003o0000ooooo`Co00002?oo
ool2o`0000[ooooo0_l00008ooooo`;o00001?oooolMo`00017ooooo1_l000001Ooooooo0000o`00
0?l0003ooooo00;o000000Coooooo`000?l0003o00008?ooool2o`0004Kooooo000Looooo`03o`00
0?oooooooooo04cooooo0ol00009ooooo`;o00001Oooool>o`0000;ooooo0ol00005ooooo`;o0000
00?oooooo`000?l000000_l00008ooooo`?o00002Oooool2o`0000Sooooo0_l00003oooooa_o0000
5?ooool4o`0000;ooooo1?l000001?oooooo0000o`000?ooool3o`0001kooooo1?l00016ooooo`00
7?ooool00ol0003oooooooooo`19ooooo`;o00000oooool2o`0000Kooooo0_l00006ooooo`co0000
00?oooooo`000?l000000oooool2o`0000Sooooo1?l00009ooooo`?o00004_ooool2o`0000?ooooo
7?l0000Cooooo`;o00001?ooool5o`0000Cooooo0_l0000Nooooo`;o0000B?ooool001cooooo00?o
0000ooooooooool0BOooool2o`0000?ooooo0_l00005ooooo`?o00000ooooolAo`0000;ooooo0_l0
000;ooooo`?o00002_ooool2o`0001;ooooo0_l00004oooooa_o00004_ooool2o`0000Kooooo1_l0
0002ooooo`;o00008Oooool2o`0004Gooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo
0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`17ooooo`Co0000
1Oooool2o`0000?ooooo0_l00004oooooaGo000000?oooooo`000?l000002?ooool5o`0001Gooooo
0_l0000:oooooaco00004_ooool2o`0000Kooooo1_l00002ooooo`;o00008Oooool2o`0000Gooooo
0_l00003ooooo`;o0000>Oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`16ooooo`?o00001oooool5o`0000Ko
oooo6?l00003ooooo`?o00000oooool4o`0000[ooooo0_l00009ooooo`;o00002_ooool2o`0000;o
oooo6Ol0000Jooooo`Co00000oooool2o`0002Sooooo0_l00003ooooo`?o0000>?ooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo00?o0000ooooooooool0
A_ooool2o`0000Oooooo1_l00007oooooaKo00001?ooool3o`0000;ooooo1?l0000;ooooo`;o0000
1Oooool2o`000003ooooool0003o000000oooooo5_l000000ooooooo0000o`00000Iooooo`?o0000
1?ooool3o`0002Sooooo0_l00002ooooo`Co0000>?ooool00003ooooool0003ooooo00;ooooo00?o
0000ooooooooool02Oooool01?m4A4CogMgMooooool00007ooooo`?o0000AOooool3o`000003oooo
ool0003o000000Cooooo1?l00009oooooaKo00001_ooool2o`000003ooooool0003o000000?o0000
4Oooool2o`000003ooooool0003o000000kooooo5ol000000ooooooo0000o`00000Iooooo`Go0000
0_ooool3o`0002?ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l0000jooooo`0000?o
ooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo
00?o0000ooooooooool0A?ooool4o`000003ooooool0003o000000Gooooo1?l00008oooooaOo0000
1Oooool2o`0000;ooooo1?l0000Toooooa[o00006Oooool5o`0000?ooooo0_l0000Sooooo`;o0000
00?oooooo`000?l000000oooool2o`0003_ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oo
oooooooo00[ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`13ooooo`?o00001?oo
ool2o`0000Cooooo1?l00007ooooo`;o000000?oooooo`000?l000004ol00008ooooo`;o00008_oo
ool3o`000004ooooool0003o0000oooooa7o000000Coooooo`000?l0003ooooo0ol0000Iooooo`Co
00000oooool3o`0002;ooooo0_l000001?oooooo0000o`000?l00003ooooo`;o0000>oooool00006
oooooomgMgOoV9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooo
oooo04;ooooo0ol00005ooooo`;o00003_oooolIo`0000Sooooo1?l0000Fooooo`;o00002?ooool3
o`000003ooooool0003o000000;ooooo4?l00003ooooo`Co00006_ooool3o`0000?ooooo0ol0000R
ooooo`;o000000Coooooo`000?l0003o0000@?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^
3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo047ooooo0ol00003ooooo`Co0000
1?ooool3o`0000Sooooo2_l00002ooooo`Co000000?oooooo`000?l000001?l00002ooooo`;o0000
1Oooool5o`0000Cooooo0ol00009ooooo`;o00001?ooool2o`0000gooooo0_l000000ooooooo0000
o`00000Eo`0001_ooooo0_l00003ooooo`?o0000:Oooool3o`0003cooooo000Looooo`03o`000?oo
oooooooo047ooooo0ol00003ooooo`Co00001?ooool3o`0000Wooooo6_l00005ooooo`Ko00000ooo
ool3o`0000Cooooo0_l00003ooooo`;o00003?ooool2o`0000Gooooo0ol000000ooooooo0000o`00
000Bo`0000gooooo0_l0000>ooooo`;o00000oooool3o`0002Sooooo1Ol0000kooooo`007?ooool0
0ol0003oooooooooo`12ooooo`;o00003?ooool2o`0000[ooooo5ol00009ooooo`Co00000_ooool4
o`0000Cooooo0_l0000Aooooo`;o00001_ooool2o`000003ooooool0003o000001;o00003Oooool2
o`0000kooooo0_l0000^ooooo`Go0000>oooool001cooooo00?o0000ooooooooool0@?ooool2o`00
01Wooooo6?l00009ooooo`;o00001?ooool5o`0001gooooo0ol00002ooooo`;o000000?oooooo`00
0?l000000ol00003ooooo`Oo000000?oooooo`000?l000002Oooool2o`00013ooooo0ol00002oooo
o`?o00008_ooool2o`0000Wooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`10ooooo`;o
00000_ooool2o`000003ooooool0003o000001;ooooo0_l000000ooooooo0000o`00000Do`0000So
oooo0_l00006ooooo`?o00007Oooool2o`0000Kooooo1Ol00003ooooo`Go00000oooool2o`0000Wo
oooo0_l0000@ooooo`?o000000?oooooo`000?l000000_l0000Rooooo`;o00002Oooool2o`0003Wo
oooo000Looooo`03o`000?oooooooooo043ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o
oooo0_l0000?oooooaWo00001?ooool2o`0000;ooooo0_l00006ooooo`;o00000oooool2o`0000Wo
oooo0_l0000Booooo`;o00000_ooool=o`0001oooooo1?l000001?oooooo0000o`000?l0000Uoooo
o`;o00002_ooool4o`0003Cooooo000Looooo`03o`000?oooooooooo047ooooo1?l00005ooooo`;o
00001?ooool2o`0000_ooooo5_l00005ooooo`;o00000_ooool2o`0000Cooooo0_l00003ooooo`Co
00002Oooool4o`0000kooooo1_l000000ooooooo0000o`000008o`00023ooooo1?l00002ooooo`?o
00008_ooool2o`000003ooooool0003o000000;o00001_ooool6o`0003Cooooo000Looooo`03o`00
0?oooooooooo03cooooo0_l00003ooooo`Go00001?ooool2o`0000Cooooo1?l00009oooooaKo0000
3oooool2o`0000?ooooo1?l0000;ooooo`;o00002Oooool2o`000003ooooool0003o000000Ko0000
00Coooooo`000?l0003ooooo0ol0000Tooooo`Co00000_ooool3o`0002;ooooo0ol00002ooooo`;o
00001_ooool2o`0003Sooooo000Looooo`03o`000?oooooooooo03cooooo0_l00003ooooo`;o0000
00?oooooo`000?l000000oooool2o`0000Kooooo0ol00008ooooo`;o000000?oooooo`000?l00000
3Ol000000ooooooo0000o`000004o`0001;ooooo0_l0000Hooooo`;o000000?oooooo`000?l00000
0_ooool6o`0000?ooooo1?l0000Qooooo`Go000000?oooooo`000?l000000_l0000Sooooo`;o0000
00?oooooo`000?l00000@Oooool001cooooo00?o0000ooooooooool0??ooool2o`0000?ooooo0ol0
0004ooooo`?o00002?ooool2o`0000Oooooo6Ol00005ooooo`;o00002oooool2o`0000_ooooo0_l0
000:ooooo`;o00001Oooool8o`0000Cooooo0_l0000Qooooo`;o000000Coooooo`000?l0003ooooo
0ol0000Tooooo`;o000000?oooooo`000?l000001?ooool2o`0003_ooooo000Looooo`03o`000?oo
oooooooo03cooooo0_l00004ooooo`;o00001?ooool2o`0000Sooooo1?l00007oooooaKo00001ooo
ool2o`0000Gooooo0_l0000Aooooo`;o00002_ooool2o`0000Cooooo2Ol0000Uooooo`?o00000_oo
ool6o`0002gooooo0_l00004ooooo`;o0000=Oooool001cooooo00?o0000ooooooooool0D_ooool4
o`0000Oooooo0_l000000ooooooo0000o`00000Ao`0000Gooooo0_l00004ooooo`;o000000?ooooo
o`000?l000008oooool3o`000004ooooool0003o0000o`0002Cooooo0_l000001?oooooo0000o`00
0?l00002ooooo`Ko0000;Oooool2o`0000Cooooo0_l0000eooooo`007?ooool2o`0003_ooooo0_l0
000Fooooo`Co00002ooooolBo`000003ooooool0003o000000;ooooo0_l00003ooooo`?o00009_oo
ool2o`000003ooooool0003o000000;ooooo0_l0000Mooooo`Wo00000oooool6o`0002Gooooo0_l0
0009ooooo`;o0000>Oooool001cooooo00?o0000ooooooooool0>_ooool3o`0000cooooo0_l00008
ooooo`Go00002?ooool:o`000003ooooool0003o000000Ko000000?oooooo`000?l000000_ooool2
o`0000;ooooo0ol0000Wooooo`Go00000_ooool4o`0001_ooooo4Ol0000Vooooo`;o00002Oooool2
o`000003ooooool0003o000003Kooooo000Looooo`03o`000?oooooooooo03Wooooo1?l00006oooo
o`;o00001?ooool2o`0000Sooooo1_l00007oooooa;o00002Oooool7o`0001[ooooo0_l00003oooo
o`;o00001Oooool3o`0000?ooooo0ol0000Hoooooa?o0000<oooool4o`0003Kooooo000Looooo`03
o`000?oooooooooo03Wooooo0_l00007ooooo`?o000000?oooooo`000?l000000_ooool2o`0000Wo
oooo1Ol00007ooooo`;o00000_ooool<o`0000?ooooo1?l00003ooooo`;o000000?oooooo`000?l0
00000_l0000Jooooo`;o00000oooool2o`0000Kooooo0_l00003ooooo`?o000000?oooooo`000?l0
00000ol0000Aooooo`Wo000000?oooooo`000?l000002?l0000cooooo`;o0000>?ooool001cooooo
00?o0000ooooooooool0@_ooool2o`0000;ooooo0_l00002ooooo`;o00001oooool2o`0000;ooooo
0ol0000<ooooo`_o00000oooool4o`0000;ooooo0_l00005ooooo`;o00003oooool4o`0001Sooooo
0ol000000ooooooo0000o`000003o`0000;ooooo0ol000000ooooooo0000o`000003o`000003oooo
ool0003o000000;o000000?oooooo`000?l000000ol00008ooooo`Co00005Oooool2o`0005Wooooo
000Looooo`03o`000?oooooooooo03Oooooo1Ol00004ooooo`;o00003Oooool2o`0000;ooooo2Ol0
0008ooooo`;o00001?ooool5o`0000[ooooo0ol00005ooooo`;o00003oooool4o`0001Wooooo0_l0
00000ooooooo0000o`000003oooooa7o00009_ooool3o`0001cooooo0_l00004ooooo`;o0000=?oo
ool001cooooo00?o0000ooooooooool0=oooool6o`0000?ooooo0_l00006ooooo`;o00001Oooool2
o`0000Cooooo2?l00007ooooo`ko00001oooool2o`0000Sooooo0_l0000Eooooo`;o00002?ooool2
o`0000[ooooo0_l00002ooooo`;o000000Goooooo`000?l0003o0000ooooo`04o`0000?ooooo0_l0
0002ooooo`;o00009?ooool5o`0001cooooo0_l00004ooooo`;o0000=?ooool001cooooo00?o0000
ooooooooool0=oooool3o`000003ooooool0003o000000?ooooo0_l00006ooooo`;o00001_ooool2
o`0000Kooooo0_l000000ooooooo0000o`000003o`0000Kooooo1?l000000ooooooo0000o`000005
o`0000Gooooo0_l00002ooooo`;o00001_ooool2o`0001;ooooo0_l000000ooooooo0000o`000008
ooooo`;o00002_ooool2o`0000;ooooo0ol000000ooooooo0000o`000002o`0002cooooo0_l00002
ooooo`Co00007?ooool2o`0000Gooooo0_l0000dooooo`007?ooool00ol0003oooooooooo`0goooo
o`;o00001oooool2o`0000[ooooo0ol000000ooooooo0000o`000006ooooo`;o000000?oooooo`00
0?l000001?l0000;ooooo`;o00002?ooool3o`000004ooooool0003o0000o`0001[ooooo0_l0000A
ooooo`;o00002Oooool2o`0000?ooooo1?l00009ooooo`;o000000?oooooo`000?l000001Ol0000>
ooooo`;o00001oooool2o`0000?ooooo0ol0000Hooooo`;o00000_ooool2o`0000Gooooo0_l0000d
ooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00003oooool2o`0000;ooooo1?l0000=oooo
o`Oo00003oooool5o`0000;ooooo0_l0000Oooooo`;o00000oooool2o`0000Sooooo0_l0000@oooo
o`?o00001oooool3o`000003ooooool0003o000000Ko000000Coooooo`000?l0003ooooo3Ol00003
ooooo`;o00001_ooool2o`0001Sooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0foooo
o`?o00001_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000;ooooo1?l00006oooo
o`;o00001_ooool8o`0000gooooo0ol00008ooooo`;o00006oooool2o`0000?ooooo0_l00004oooo
o`;o000000?oooooo`000?l000004_ooool2o`000003ooooool0003o000000Cooooo0_l00008oooo
o`;o000000?oooooo`000?l000003ol00002ooooo`;o000000?oooooo`000?l000000oooool3o`00
05Sooooo000Looooo`03o`000?oooooooooo03Kooooo1Ol00004ooooo`?o000000Coooooo`000?l0
003ooooo0_l0000>ooooo`;o00003?ooool;o`0000Kooooo0_l00007ooooo`;o00006oooool3o`00
00Sooooo0_l000000ooooooo0000o`000003ooooo`;o00004?ooool2o`000003ooooool0003o0000
00Gooooo0_l00009ooooo`;o00001Oooool2o`000003ooooool0003o000000?o00001Oooool2o`00
00?ooooo1Ol0000Cooooo`;o00002?ooool3o`0003Kooooo000Looooo`03o`000?oooooooooo03Oo
oooo1?l00004ooooo`?o00007_ooool2o`0000?ooooo2_l00006ooooo`;o00009?ooool3o`0000go
oooo0_l000000ooooooo0000o`00000Cooooo`;o000000?oooooo`000?l000000_ooool3o`0000_o
oooo0ol0000Dooooo`Co00004oooool2o`0000Sooooo0ol0000fooooo`007?ooool00ol0003ooooo
ooooo`0gooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo0_l0000@ooooo`Co0000
1oooool2o`0000Kooooo1ol0000cooooo`Co00000_ooool2o`000003ooooool0003o000000;ooooo
0ol00009ooooo`;o00002?ooool3o`0000?ooooo0_l0000;ooooo`?o00004?ooool2o`0000;ooooo
0ol0000Iooooo`;o0000??ooool001cooooo00?o0000ooooooooool0=Oooool2o`0000Cooooo1?l0
0004ooooo`;o00004?ooool4o`0000Oooooo0_l00006ooooo`;o000000?oooooo`000?l000001ooo
ool2o`0000_ooooo0_l0000Oooooo`Co00000_ooool5o`0000;ooooo0ol00009ooooo`;o00002?oo
ool3o`0000gooooo0_l0000?ooooo`?o00000_ooool2o`000003ooooool0003o000000;o00004?oo
ool2o`0000?ooooo0_l00002ooooo`?o00000_ooool2o`0003Oooooo000Looooo`03o`000?oooooo
oooo03Gooooo1Ol000000ooooooo0000o`000002o`0000Cooooo0_l0000Kooooo`;o00002Oooool2
o`0000Oooooo0_l0000;ooooo`;o00009_ooool2o`0001Sooooo1_l00003ooooo`;o000000?ooooo
o`000?l000000_l00002ooooo`;o00001Oooool2o`0000Sooooo0ol00003ooooo`Ko00004?ooool3
o`000004ooooool0003o0000o`0000?ooooo0_l00002ooooo`?o0000=_ooool001cooooo0_l0000g
ooooo`Co0000>?ooool2o`0000kooooo0_l0000Uooooo`;o00000_ooool4o`0001;ooooo0_l00002
ooooo`Co000000?oooooo`000?l000001ol00005ooooo`Co00003_ooool5o`00017ooooo0ol00000
0ooooooo0000o`000008ooooo`?o0000=_ooool001cooooo00?o0000ooooooooool0=Oooool4o`00
00Kooooo1?l0000Hooooo`;o000000?oooooo`000?l000003?ooool2o`0000?ooooo0ol0000>oooo
o`;o0000:Oooool4o`00017ooooo0ol00004ooooo`?o00000_ooool2o`000003ooooool0003o0000
00;o00001Oooool2o`0000[ooooo0_l00005ooooo`Co00006Oooool2o`0000?ooooo0ol0000goooo
o`007?ooool00ol0003oooooooooo`0eooooo`Co00001_ooool4o`0001Sooooo0_l000000ooooooo
0000o`00000<ooooo`;o00000oooool2o`0000Gooooo0_l0000[ooooo`;o00000_ooool2o`0001Oo
oooo1?l00004ooooo`;o00001Oooool2o`0000Gooooo1?l00002ooooo`;o00001_ooool2o`0000Go
oooo0ol0000Eooooo`;o00000oooool4o`000003ooooool0003o000003Sooooo000Looooo`03o`00
0?oooooooooo03Oooooo0_l0000aooooo`;o00001?ooool2o`0000Kooooo0_l00003ooooo`;o0000
3oooool2o`0001Gooooo0_l00002ooooo`;o00003Oooool2o`0000?ooooo0_l00005ooooo`;o0000
2?ooool2o`0000Sooooo1?l000000ooooooo0000o`000003o`0000Wooooo1ol0000>ooooo`;o0000
00?oooooo`000?l000001?l00003ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0=?oo
ool4o`0000Kooooo0_l0000Qooooo`;o00001?ooool2o`000003ooooool0003o000000Cooooo0_l0
000;ooooo`;o00003oooool2o`000003ooooool0003o000000Kooooo0_l00004ooooo`;o00005ooo
ool4o`000003ooooool0003o000000Wooooo0_l000001?oooooo0000o`000?ooool2o`0000Sooooo
0_l00003ooooo`;o000000?oooooo`000?l000001oooool6o`000003ooooool0003o000000kooooo
0_l000000ooooooo0000o`000002ooooo`Oo0000>oooool001cooooo00?o0000ooooooooool0=?oo
ool4o`0000Kooooo0_l0000Qooooo`;o00001?ooool2o`0000Sooooo0_l0000Eooooo`;o00001ooo
ool2o`0000Kooooo0_l00004ooooo`?o000000?oooooo`000?l000000_ooool2o`000003ooooool0
003o000000Oooooo0_l00004ooooo`?o00003?ooool2o`000003ooooool0003o000001Kooooo0_l0
0004ooooo`Go000000?oooooo`000?l000004_ooool2o`0000Cooooo0ol0000mooooo`007?ooool0
0ol0003oooooooooo`0dooooo`Co0000;oooool2o`0000Sooooo0_l0000Eooooo`;o00002Oooool2
o`0000_ooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000oooool2
o`0000;ooooo0ol00007ooooo`;o00000oooool2o`0000cooooo1?l0000?ooooo`Co00000oooool4
o`000003ooooool0003o000000oooooo0_l00007ooooo`;o00000oooool2o`0003Wooooo000Loooo
o`03o`000?oooooooooo03Cooooo0ol0000/ooooo`;o00000_ooool2o`0002[ooooo0_l0000>oooo
o`;o00000oooool3o`0000Cooooo0_l00003ooooo`;o00001oooool2o`0000?ooooo0_l00004oooo
o`;o00001Oooool5o`0000;ooooo1Ol00008ooooo`_o00003oooool2o`000004ooooool0003o0000
o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0003Wooooo000Looooo`03o`000?oooooooooo
03Cooooo0_l0000Tooooo`Go00001?ooool2o`0000[ooooo0_l0000Mooooo`;o00004oooool4o`00
0004ooooool0003o0000o`00013ooooo1ol00006ooooo`;o00001Oooool2o`0000Gooooo6?l0000?
ooooo`;o00000_ooool2o`0000;ooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`0doooo
o`Oo00007_ooool9o`0000gooooo0_l0000Mooooo`;o00005?ooool3o`00013ooooo3Ol000000ooo
oooo0000o`000003ooooo`;o00002_ooool@o`0000;ooooo1?l000000ooooooo0000o`00000Eoooo
o`;o00001?ooool2o`0003gooooo000Looooo`03o`000?oooooooooo03Cooooo1ol0000Nooooo`Go
000000?oooooo`000?l000000ol0000Zooooo`;o00004oooool2o`00017ooooo3_l000001?oooooo
0000o`000?l00002ooooo`;o00000oooool2o`0000;ooooo0_l00008ooooo`?o00000_ooool4o`00
0003ooooool0003o000000Ko00005Oooool2o`0000Cooooo0_l0000mooooo`007?ooool00ol0003o
ooooooooo`0dooooo`Ko00007oooool4o`0000?ooooo1Ol0000>ooooo`;o00009_ooool2o`0000Ko
oooo1?l00005ooooo`;o00001_oooolDo`0000Gooooo1?l000001?oooooo0000o`000?l0000Boooo
o`?o000000?oooooo`000?l000005_ooool3o`0000Cooooo0_l0000mooooo`007?ooool00ol0003o
ooooooooo`0eooooo`Co00008?ooool4o`0000Kooooo1Ol0000;ooooo`;o00009_ooool2o`0000So
oooo0_l000000ooooooo0000o`000002ooooo`;o00001_oooolEo`0000Cooooo0_l00003ooooo`Co
0000;Oooool3o`0000;ooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`1Iooooo`Co0000
1oooool5o`0000Cooooo0_l0000Xooooo`;o00003oooool2o`0000;ooooo0_l00006oooooaGo0000
1?ooool2o`0000Gooooo0_l0000Yooooo`;o000000?oooooo`000?l000001?ooool2o`0003oooooo
000Looooo`03o`000?oooooooooo05Oooooo1?l00007ooooo`Oo00001?ooool2o`0002Sooooo0_l0
000@ooooo`;o00002_oooolBo`0000;ooooo1?l00002ooooo`;o00001?ooool2o`0002Cooooo0_l0
0002ooooo`;o000000?oooooo`000?l00000AOooool001cooooo00?o0000ooooooooool0Eoooool3
o`000003ooooool0003o000000Gooooo1Ol00007ooooo`;o00000_ooool2o`0001Oooooo0_l00006
ooooo`;o00003Oooool2o`0000Gooooo0_l00007oooooaGo00000_ooool5o`000004ooooool0003o
0000o`0000?ooooo0_l00004ooooo`;o00007_ooool2o`0000;ooooo0_l000001?oooooo0000o`00
0?l00014ooooo`007?ooool2o`0005Sooooo0_l000001?oooooo0000o`000?l00008ooooo`;o0000
0_ooool4o`000003ooooool0003o000000;ooooo0_l0000Gooooo`;o00001_ooool2o`0000;ooooo
0_l000000ooooooo0000o`000006ooooo`;o00003_oooolFo`000004ooooool0003o0000ooooo`;o
00000_ooool2o`0000;ooooo0_l00002ooooo`Go00009Oooool3o`0000;ooooo0_l00010ooooo`00
7?ooool00ol0003oooooooooo`1Eooooo`Oo00002Oooool2o`0000;ooooo1?l00004ooooo`;o0000
8?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0001Kooooo5?l0000<ooooo`;o0000
0_ooool4o`0000;ooooo0_l0000;ooooo`;o00006_ooool2o`00043ooooo000Looooo`03o`000?oo
oooooooo05Gooooo1ol00003ooooo`;o00001?ooool2o`0000?ooooo0ol000001?oooooo0000o`00
0?ooool2o`0000[ooooo0_l0000>ooooo`;o00001?ooool2o`0000Oooooo0_l0000DoooooaKo0000
5_ooool2o`0000_ooooo0_l00002ooooo`;o00000oooool2o`0001;ooooo0_l0000oooooo`007?oo
ool00ol0003oooooooooo`1Iooooo`;o00001?ooool2o`0000Wooooo0_l00002ooooo`?o00003?oo
ool2o`0000cooooo1?l00008ooooo`;o00006?oooolGo`0002Oooooo0_l00003ooooo`Co000000?o
ooooo`000?l000000_l0000;ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0FOooool2
o`0001Cooooo0_l0000@ooooo`;o00002?ooool3o`0000Gooooo0_l00002ooooo`;o00000oooool2
o`0001?ooooo5ol00006ooooo`?o00006Oooool2o`0000[ooooo0_l000000ooooooo0000o`000003
o`0004_ooooo000Looooo`03o`000?oooooooooo05Cooooo0_l00006ooooo`;o00002?ooool2o`00
00Wooooo0_l0000>ooooo`;o00001oooool4o`0000Gooooo0_l00007ooooo`?o00004?oooolIo`00
00Cooooo1Ol00006ooooo`;o00004Oooool2o`0000Wooooo0_l00005ooooo`Co0000BOooool001co
oooo00?o0000ooooooooool0E?ooool4o`0000;ooooo1?l00008ooooo`;o00001_ooool2o`000004
ooooool0003o0000o`0001Kooooo1?l0000?ooooo`;o00003oooool>o`000003ooooool0003o0000
00Wo00001?ooool3o`0000Sooooo0_l0000Dooooo`;o000000?oooooo`000?l000000oooool2o`00
00Kooooo0ol00019ooooo`007?ooool00ol0003oooooooooo`1Booooo`;o00000_ooool2o`0000;o
oooo0ol00003ooooo`Go00002Oooool2o`0000;ooooo0ol0000iooooo`;o000000?oooooo`000?l0
00003Ol000000ooooooo0000o`000005o`0000?ooooo0_l0000;ooooo`Co000000?oooooo`000?l0
00000_ooool3o`0000Wooooo0_l000000ooooooo0000o`000008ooooo`;o0000COooool001cooooo
00?o0000ooooooooool0D_ooool2o`0000Oooooo0_l00003ooooo`Go00000oooool2o`0000Gooooo
0ol000001?oooooo0000o`000?l00004ooooo`?o0000<_oooolAo`000003ooooool0003o000000Ko
00000_ooool3o`0000Wooooo1Ol000000ooooooo0000o`000005o`0000Sooooo0_l00002ooooo`;o
00002?ooool4o`0000Kooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o0000
0oooool4o`0000Sooooo0_l000001?oooooo0000o`000?l00005ooooo`?o00000_ooool3o`0000?o
oooo0ol0000Cooooo`;o00001?ooool2o`000003ooooool0003o000001Cooooo1?l000000ooooooo
0000o`00000Co`0000;ooooo0ol00004ooooo`;o00000_ooool@o`0000Kooooo0_l00002ooooo`;o
00001?ooool2o`0000Cooooo0_l00004ooooo`Co0000@oooool001cooooo00?o0000ooooooooool0
Doooool4o`000003ooooool0003o000000;o00002?ooool2o`000004ooooool0003o0000ooooo`;o
00002Oooool2o`0000[ooooo0_l0000=ooooo`;o00001?ooool2o`000003ooooool0003o000001Co
oooo5_l000000ooooooo0000o`000002o`000004ooooool0003o0000o`0000?ooooo6Ol00006oooo
o`;o00001?ooool2o`0000[ooooo0ol00014ooooo`007?ooool00ol0003oooooooooo`1Dooooo`Ko
00003Oooool5o`0001Gooooo0_l00002ooooo`Co00002_ooool2o`0000Kooooo0ol000000ooooooo
0000o`00000>ooooo`;o000000?oooooo`000?l000003ol00005ooooo`;o00000_ooool4o`000003
ooooool0003o000000Wo000000?oooooo`000?l000003?l00005ooooo`;o00003oooool5o`0004?o
oooo000Looooo`03o`000?oooooooooo057ooooo0_l000000ooooooo0000o`000004o`0000Oooooo
0_l000000ooooooo0000o`000006o`0000_ooooo0_l00007ooooo`;o00000_ooool5o`0000[ooooo
0_l00006ooooo`?o000000?oooooo`000?l000003_ooool2o`000003ooooool0003o000000;o0000
0_ooool9o`0000Gooooo0_l00005ooooob3o00005?ooool5o`0004?ooooo000Looooo`03o`000?oo
oooooooo057ooooo1_l00008ooooo`go00002oooool3o`0000Kooooo0_l00002ooooo`;o00002?oo
ool2o`0000Gooooo0_l00004ooooo`;o00004oooool2o`000003ooooool0003o000000?o000000?o
ooooo`000?l000001_l00005ooooo`;o00000oooool2o`0000;ooooo7_l00002ooooo`;o00004Ooo
ool2o`0004Gooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^
k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`1Cooooo`Co00002?ooool@o`0000Wo
oooo0ol00005ooooo`;o00000oooool2o`0000Oooooo0_l00004ooooo`?o00001?ooool2o`0001?o
oooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000gooooo0_l000000ooooooo
0000o`000004o`000003ooooool0003o000000_o000000?oooooo`000?l000003?l000000ooooooo
0000o`00000:ooooo`;o0000C?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q
8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo04oooooo0_l00004
ooooo`;o00001ooooolCo`0000;ooooo0_l00004ooooo`?o00002?ooool3o`0000gooooo0_l0000I
ooooo`;o00000_ooool5o`000004ooooool0003o0000ooooo`?o000000?oooooo`000?l000000_l0
0002ooooo`Co00000oooool4o`000003ooooool0003o000000?ooooo6?l000000ooooooo0000o`00
0009ooooo`;o00000_ooool3o`0004Oooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooo
oooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo04oooooo0_l0
0002ooooo`Co00001_oooolDo`0000;ooooo0ol00004ooooo`?o00001oooool2o`0000?ooooo0_l0
0005ooooo`;o00001_ooool2o`0001Gooooo0_l00002ooooo`Go00001?ooool3o`000003ooooool0
003o000000;o000000?oooooo`000?l000003Ol00003oooooaSo000000?oooooo`000?l000003Ooo
ool3o`0004Oooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000
oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000C_ooool4o`000003ooooool0003o000000;o00001Ooo
oolEo`0000;ooooo0ol00005ooooo`;o00003?ooool2o`0000Gooooo0_l00006ooooo`;o00002?oo
ool2o`0000gooooo1?l000000ooooooo0000o`000004ooooo`?o00001_ooool2o`0000?ooooo1_l0
00000ooooooo0000o`000002ooooo`;o00000_oooolDo`0000;ooooo0_l0001Hooooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_oo
ool00ol0003oooooooooo`1>ooooo`Co00000_ooool2o`0000Kooooo5Ol00002ooooo`;o00001_oo
ool2o`0001_ooooo0_l00002ooooo`Co00000_ooool2o`0000gooooo1ol000001?oooooo0000o`00
0?ooool3o`0000Oooooo0_l000001?oooooo0000o`000?ooool2o`0000Oooooo0ol00002oooooaCo
000000?oooooo`000?l000000_ooool2o`0000Oooooo0_l0001;ooooo`0000?ooooooa0@4?ooool0
0_ooool00ol@413oooooooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0
G?oooolEo`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l000004oooool2o`0000;ooooo
1?l00002ooooo`Co00004oooool5o`000003ooooool0003o000000_ooooo0_l000001?oooooo0000
o`000?ooool2o`0000Oooooo0ol00002oooooaOo00000_ooool2o`0000Gooooo1?l0001;ooooo`00
00KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000oooo
ooooool0D_ooool2o`0000Sooooo5?l0000:ooooo`;o000000?oooooo`000?l000001?ooool2o`00
00gooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o000001Kooooo1_l00004oooo
o`Co00005ooooolHo`0000Oooooo0ol0001=ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<
ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0COooool2o`0000?ooooo0ol0
0007oooooaGo00000_ooool2o`0000?ooooo1Ol00006ooooo`;o00001Oooool2o`0000[ooooo0_l0
0002ooooo`;o000000?oooooo`000?l000005_ooool2o`000004ooooool0003o0000o`0000Cooooo
1?l0000HoooooaWo00000oooool5o`0004gooooo000Looooo`03o`000?oooooooooo04gooooo0_l0
0002ooooo`Co00002?oooolHo`0000?ooooo1Ol00006ooooo`;o00001Oooool2o`0000[ooooo0_l0
000Looooo`;o00001?ooool9o`0001Oooooo0_l000000ooooooo0000o`00000Ao`0000;ooooo0_l0
0002ooooo`Go0000C_ooool001cooooo00?o0000ooooooooool0DOooool2o`0000[ooooo4ol00000
0ooooooo0000o`000005ooooo`;o00001?ooool2o`0001Kooooo0_l0000Looooo`;o00001?ooool5
o`0001_ooooo0ol00002oooooa7o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`00001>
ooooo`007?ooool00ol0003oooooooooo`1LoooooaKo00000oooool2o`000004ooooool0003o0000
ooooo`;o000000?oooooo`000?l000001Oooool2o`0000kooooo0_l00014ooooo`?o000000?ooooo
o`000?l000003ol00002ooooo`?o000000?oooooo`000?l00000DOooool001cooooo00?o0000oooo
ooooool0G?oooolFo`0000?ooooo0ol00003ooooo`;o000000?oooooo`000?l000001Oooool2o`00
00;ooooo0_l0000:ooooo`;o0000AOooool2o`000003ooooool0003o000000Cooooo2Ol00005oooo
o`;o0000E?ooool001cooooo00?o0000ooooooooool0G?ooool4o`000003ooooool0003o000000oo
00001?ooool2o`0000?ooooo0_l000000ooooooo0000o`000005ooooo`;o00000_ooool2o`0005Go
oooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000?o00001Oooool2o`0005Co
oooo000Looooo`03o`000?oooooooooo04cooooo0ol00004ooooo`;o00002?oooolEo`0000Wooooo
1?l00003ooooo`Go00001_ooool2o`00057ooooo0_l000000ooooooo0000o`000006o`000005oooo
ool0003o0000o`000?ooool01Ol0001Dooooo`007?ooool00ol0003oooooooooo`1<ooooo`?o0000
1?ooool2o`0000Sooooo5Ol0000;ooooo`;o00000oooool4o`0000Oooooo0_l0001Hooooo`So0000
00Coooooo`000?l0003o0000E_ooool001cooooo00?o0000ooooooooool0COooool2o`0000Cooooo
0_l00009oooooaCo00002_ooool3o`0000Sooooo0_l0001Rooooo`;o0000G?ooool001cooooo00?o
0000ooooooooool0COooool2o`0000?ooooo0ol00009oooooa;o00002oooool3o`000003ooooool0
003o000000;o00001?ooool2o`000<3ooooo000Looooo`03o`000?oooooooooo05;ooooo0_l0000;
oooooa7o00002_ooool3o`0000;ooooo1?l0000Zooooo`;o0000V_ooool001cooooo00?o0000oooo
ooooool0C_ooool2o`0000oooooo2Ol000000ooooooo0000o`000005o`0000Wooooo0ol0000Goooo
o`Co00000_ooool8o`0000cooooo0_l0002Jooooo`007?ooool2o`0004oooooo0_l00003ooooo`?o
00002_ooool?o`0000Gooooo0_l00002ooooo`?o00005_ooool6o`0000;ooooo2ol0002Uooooo`00
7?ooool00ol0003oooooooooo`1Cooooo`?o00002oooool=o`0000Cooooo1?l00002ooooo`;o0000
5Oooool7o`000003ooooool0003o000000;ooooo2Ol0002Uooooo`007?ooool00ol0003ooooooooo
o`1Eooooo`;o00003Oooool:o`0000Cooooo0_l0000KoooooaKo0000Y?ooool001cooooo00?o0000
ooooooooool0Doooool4o`0000kooooo1ol0000Nooooo`?o000000?oooooo`000?l000000_ooool@
o`000003ooooool0003o00000:Cooooo000Looooo`03o`000?oooooooooo04cooooo0_l00005oooo
o`Ko00003?ooool5o`0000?ooooo1Ol00003ooooo`;o00004_oooolLo`000:Cooooo000Looooo`03
o`000?oooooooooo04cooooo0_l00005ooooo`Ko00005?ooool6o`000004ooooool0003o0000o`00
017ooooo1?l000000ooooooo0000o`00000Bo`000003ooooool0003o000000[ooooo0_l0002Ioooo
o`007?ooool00ol0003oooooooooo`1<ooooo`;o00001Oooool6o`0001Sooooo0_l000000ooooooo
0000o`00000Aooooo`Co00000oooool8o`000003ooooool0003o0000013o00001Oooool2o`0009Wo
oooo000Looooo`03o`000?oooooooooo05Gooooo1?l0000^ooooo`?o00000oooool9o`000003oooo
ool0003o0000013o0000X?ooool001cooooo00?o0000ooooooooool0Eoooool2o`000003ooooool0
003o000000Co00004?ooool2o`0001Cooooo0_l00004oooooako0000Woooool001cooooo00?o0000
ooooooooool0D?ooool2o`0000?ooooo1?l000000ooooooo0000o`000004o`00013ooooo0_l0000D
ooooo`?o00000ooooolKo`000003ooooool0003o000009oooooo000Looooo`03o`000?oooooooooo
053ooooo0ol00002ooooo`Oo000000?oooooo`000?l000001Oooool3o`0001oooooo0ol00004oooo
oa[o000000?oooooo`000?l00000Doooool2o`0004[ooooo000Looooo`03o`000?oooooooooo057o
oooo0_l00004ooooo`Co00001_ooool2o`000004ooooool0003o0000o`0001kooooo0_l00005oooo
oaGo000000?oooooo`000?l000001ol0001Booooo`;o0000B_ooool001cooooo00?o0000oooooooo
ool0Eoooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`00027ooooo0ol00005oooooaGo
000000?oooooo`000?l000001ol0001=ooooo`;o0000Coooool001cooooo00?o0000ooooooooool0
Eoooool2o`0000?ooooo0_l000000ooooooo0000o`00000Sooooo`?o00001ooooolMo`0000?ooooo
0_l00018ooooo`?o0000C_ooool001cooooo00?o0000ooooooooool0FOooool2o`0002Wooooo0_l0
00001?oooooo0000o`000?l00004oooooaco00001?ooool2o`0004Wooooo0_l000000ooooooo0000
o`00001;ooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00001oooool2o`0002Wooooo0_l0
00001?oooooo0000o`000?l00004oooooaco0000Aoooool2o`0000Wooooo0_l0001;ooooo`007?oo
ool2o`00057ooooo0_l0000booooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`00
000Io`0004Oooooo1?l0001Dooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o0000=oooool2
o`0000?ooooo0_l00002oooooaCo0000@oooool2o`0000Gooooo0_l0001Dooooo`007?ooool00ol0
003oooooooooo`1Cooooo`;o0000;oooool3o`0000[ooooo6?l00004ooooo`;o0000?Oooool3o`00
00Kooooo1?l0001@ooooo`007?ooool00ol0003oooooooooo`1Aooooo`Co0000;oooool3o`0000;o
oooo0_l00006oooooaSo00001?ooool2o`0003kooooo1?l00004ooooo`Co0000D?ooool001cooooo
00?o0000ooooooooool0DOooool2o`0003;ooooo0_l00002ooooo`;o00001_ooool5o`000003oooo
ool0003o0000013o000000?oooooo`000?l000000ol00010ooooo`;o00001?ooool2o`0005;ooooo
000Looooo`03o`000?oooooooooo05?ooooo0_l0000`ooooo`;o00000_ooool2o`0000Kooooo0_l0
00000ooooooo0000o`00000<o`000003ooooool0003o000000[o0000AOooool3o`0005;ooooo000L
ooooo`03o`000?oooooooooo05;ooooo1_l0000]ooooo`?o00003Oooool=o`000003ooooool0003o
000000So0000AOooool4o`0005?ooooo000Looooo`03o`000?oooooooooo05;ooooo0_l000001?oo
oooo0000o`000?l0000^ooooo`;o00004?oooolDo`0004Kooooo1?l0001Cooooo`007?ooool00ol0
003oooooooooo`1Cooooo`;o0000<Oooool2o`00013ooooo5Ol0000oooooo`;o00000oooool2o`00
05Kooooo000Looooo`03o`000?oooooooooo05?ooooo0_l0000aooooo`Co00003Oooool?o`000005
ooooool0003o0000o`000?ooool00_l0000oooooo`;o00000oooool2o`0005Kooooo000Looooo`03
o`000?oooooooooo08Oooooo0ol000000ooooooo0000o`000009ooooo`Co00000_ooool8o`0000Co
oooo0_l00012ooooo`;o0000Foooool001cooooo00?o0000ooooooooool0Eoooool2o`0002oooooo
1Ol00009ooooo`?o00001?ooool7o`0000;ooooo0_l00015ooooo`?o0000FOooool001cooooo00?o
0000ooooooooool0Eoooool2o`00033ooooo0_l0000=ooooo`;o00000oooool2o`000003ooooool0
003o000000;o00000_ooool2o`0003_ooooo0_l00007ooooo`Co0000FOooool001cooooo00?o0000
ooooooooool0ROooool3o`0000cooooo1?l00004ooooo`Co0000?oooool2o`0000Oooooo0ol0001J
ooooo`007?ooool00ol0003oooooooooo`29ooooo`Co00001?ooool2o`0000Gooooo1Ol000000ooo
oooo0000o`000002ooooo`;o0000?Oooool2o`0000?ooooo0_l000001?oooooo0000o`000?l0001M
ooooo`007?ooool00ol0003oooooooooo`2:ooooo`?o00001?ooool2o`0000Sooooo0_l000000ooo
oooo0000o`000002ooooo`;o0000?Oooool4o`000004ooooool0003o0000ooooo`?o0000GOooool0
01cooooo0_l0001Looooo`Co0000;?ooool3o`00017ooooo0ol0000oooooo`Co000000?oooooo`00
0?l00000HOooool001cooooo00?o0000ooooooooool0F_ooool5o`0002cooooo0ol0000Aooooo`?o
0000@_ooool2o`0006?ooooo000Looooo`03o`000?oooooooooo05[ooooo0ol000000ooooooo0000
o`00001cooooo`Co00003Oooool2o`000003ooooool0003o0000063ooooo000Looooo`03o`000?oo
oooooooo05kooooo0_l0000_ooooo`?o0000@Oooool4o`00013ooooo0_l0001Pooooo`007?ooool0
0ol0003oooooooooo`1Rooooo`;o0000:oooool3o`000003ooooool0003o000000?ooooo0_l0000c
ooooo`;o00001?ooool2o`0000Oooooo0_l0001[ooooo`007?ooool00ol0003oooooooooo`1Roooo
o`?o0000:oooool7o`000003ooooool0003o000000;o0000<Oooool2o`0000gooooo0_l0001[oooo
o`007?ooool00ol0003oooooooooo`1Sooooo`;o0000;?ooool6o`0000?ooooo0_l0000mooooo`;o
0000K_ooool001cooooo00?o0000ooooooooool0Ioooool2o`0002Wooooo0ol000000ooooooo0000
o`00000gooooo`;o00002?ooool3o`0006gooooo000Looooo`03o`000?oooooooooo06Cooooo0_l0
00000ooooooo0000o`00000Zooooo`Go0000=oooool2o`0000Cooooo0_l000000ooooooo0000o`00
0002o`0000Gooooo0_l0001Vooooo`007?ooool00ol0003oooooooooo`1Tooooo`;o0000;_ooool3
o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l00000<?ooool3o`000003ooooool0003o
000000Oooooo0_l0001Vooooo`007?ooool00ol0003oooooooooo`1Tooooo`;o00000oooool2o`00
02[ooooo2?l00002ooooo`;o000000?oooooo`000?l000007Oooool3o`0000?ooooo0_l0000;oooo
o`Ko00001Oooool4o`0006Kooooo000Looooo`03o`000?oooooooooo06Cooooo0_l000000ooooooo
0000o`000003o`0002[ooooo1ol000000ooooooo0000o`000004ooooo`;o00001?ooool2o`0000[o
oooo0_l00004ooooo`;o00000oooool3o`0000?ooooo0_l0000:ooooo`;o000000?oooooo`000?l0
00000_l00005ooooo`;o0000J?ooool001cooooo00?o0000ooooooooool0Ioooool2o`000003oooo
ool0003o000002_ooooo1_l000000ooooooo0000o`000004ooooo`Co00000_ooool2o`0000Wooooo
0ol00004ooooo`;o00000_ooool2o`0000Wooooo0_l00006ooooo`;o00002?ooool3o`0006Wooooo
000Looooo`03o`000?oooooooooo06kooooo0_l0000Wooooo`Co00000_ooool2o`0000Oooooo1?l0
0007ooooo`;o00000_ooool3o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l000001_oo
ool2o`0000Kooooo0ol000000ooooooo0000o`000004ooooo`?o0000JOooool00006ooooooo^k^ko
<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03
o`000?oooooooooo06kooooo0_l0000Yooooo`So00001_ooool3o`0000Kooooo0ol00005ooooo`;o
00001Oooool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000001?ooool2o`000004
ooooool0003o0000ooooo`;o0000L?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo09[ooooo1ol0
0006ooooo`;o00001Oooool4o`0000Kooooo0_l00004ooooo`?o00000oooool2o`0000;ooooo0_l0
0003ooooo`Ko00001?ooool2o`00073ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooo
oooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo09[ooooo1ol0
00000ooooooo0000o`000003ooooo`;o00001Oooool2o`0000Sooooo0_l00004ooooo`;o00001?oo
ool2o`0000Cooooo0_l000000ooooooo0000o`000002o`0007Sooooo00000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000WOoo
ool4o`000003ooooool0003o000000Oooooo0_l000000ooooooo0000o`000008ooooo`;o00001_oo
ool2o`0000Sooooo0_l00003ooooo`;o0000N?ooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool02Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0WOoo
ool4o`0000[ooooo0_l00004ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0ol0
00001?oooooo0000o`000?ooool2o`000003ooooool0003o000000Cooooo1Ol00002ooooo`;o0000
M?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol@413o^[Zjoooo
oonj^[[o410@00Kooooo00?o0000ooooooooool0W_ooool4o`0000oooooo0_l000000ooooooo0000
o`000002ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o000000Coooooo`000?l0003o
oooo0_l000000ooooooo0000o`000007o`0007Cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMg
M`_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0:3ooooo1?l0000D
ooooo`;o000000?oooooo`000?l000001_ooool4o`0000;ooooo0_l00004ooooo`Co0000M_ooool0
0006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo
00?o0000ooooooooool0XOooool3o`000003ooooool0003o000000cooooo0_l0000=ooooo`Go0000
0oooool2o`0000?ooooo0_l0001hooooo`007?ooool00ol0003oooooooooo`2Uooooo`?o00001Ooo
ool2o`0000;ooooo1?l00009ooooo`?o000000?oooooo`000?l000000ol000000ooooooo0000o`00
0002o`0007gooooo000Looooo`03o`000?oooooooooo0:Kooooo0_l000000ooooooo0000o`000002
ooooo`?o000000Coooooo`000?l0003o00002_ooool3o`000003ooooool0003o000000?o000000?o
ooooo`000?l00000Ooooool001cooooo00?o0000ooooooooool0ZOooool7o`0000;ooooo0_l00004
ooooo`;o00001?ooool2o`0008Wooooo000Looooo`03o`000?oooooooooo0:Wooooo1ol00008oooo
o`;o0000Soooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000B
ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooood[ooooo000Doooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003o
ooooooooo`05ooooo`?o0000oooooom:ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo
000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomB
ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Booooo`03oeEEEOmVIVKo00000?oo
ooooE?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Gooooo00Co410@o`00
0?l0003ooooo0_l000000ol@413oooooooooo`0Fooooo`Co000000So410@ooooooooooooc<c<ob4Q
8Ol0003o8B4Qolc<c0?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP2@ooooo`00Y_ooool01Ol0003o
oooooooooooooooo000000Wooooo1_l0000<ooooo`03o`000?oooooooooo00;ooooo00Go8B4QoiRH
V?ooooooV9RHob4Q8@03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0T?ooool00:Kooooo00Go0000
ooooooooooooooooo`00000Kooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`000003ooooo`05oa0@4?ooooooooooooooool@4100T?ooool00:Kooooo00Go0000oooooooooooo
ooooo`000009ooooo`Ko00003?ooool00ol0003oooooooooo`02ooooo`05oc8b<_nHV9SooooooiRH
V?lb<S800oooool01Ol0003ooooooooooooooooo0000093ooooo002Vooooo`05o`000?n7QhOooooo
ojVYZOl000006oooool00ol0003oooooooooo`02ooooo`05olc<c?l0003o0000o`000?o<c<`00ooo
ool01Ol0003ooooooooooooooooo0000093ooooo002Uooooo`03oa0@4?l0003oMgMg00;o000000?o
V9RHooooooooool06Oooool00ol0003oooooooooo`02ooooo`05oa0@4?nj^[[ooooookZj^_l@4100
0oooool01Ol@413ooooooooooooooooo410@093ooooo0036ooooo`03o`000?oooooooooo00;ooooo
00Go0000okZj^_oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0T?ooool00<Co
oooo00?oEEEEofIVI_l000001?ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP2@ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(186) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.33767 .35814 Mdot
.34597 .39179 Mdot
.48531 .67491 Mdot
.5879 .37058 Mdot
.68595 .65396 Mdot
.48599 .69919 Mdot
.32238 .58889 Mdot
.31431 .60793 Mdot
.43662 .66475 Mdot
.49902 .33231 Mdot
.2863 .60171 Mdot
.60215 .3819 Mdot
.31188 .5967 Mdot
.55938 .37673 Mdot
.65306 .50383 Mdot
.59528 .26332 Mdot
.3314 .42019 Mdot
.72425 .64996 Mdot
.59074 .26135 Mdot
.43191 .66854 Mdot
.65024 .63192 Mdot
.5543 .39282 Mdot
.3735 .39641 Mdot
.56076 .37795 Mdot
.59432 .27465 Mdot
.35178 .38627 Mdot
.33446 .36061 Mdot
.58166 .28747 Mdot
.59566 .39755 Mdot
.28947 .62351 Mdot
.57892 .29881 Mdot
.75356 .53533 Mdot
.60612 .55986 Mdot
.45927 .31304 Mdot
.31658 .61941 Mdot
.32776 .54804 Mdot
.46359 .66906 Mdot
.30066 .6263 Mdot
.30492 .56179 Mdot
.29381 .61151 Mdot
.29578 .61573 Mdot
.35555 .39193 Mdot
.31983 .62087 Mdot
.23296 .66516 Mdot
.57117 .37728 Mdot
.46306 .20366 Mdot
.48772 .74082 Mdot
.59313 .3636 Mdot
.37244 .40581 Mdot
.46088 .6434 Mdot
.69443 .55916 Mdot
.29855 .60498 Mdot
.58173 .56842 Mdot
.42764 .17354 Mdot
.31702 .60089 Mdot
.5935 .26878 Mdot
.47255 .71533 Mdot
.57594 .39868 Mdot
.5864 .34889 Mdot
.45598 .2807 Mdot
.57882 .40599 Mdot
.66945 .62847 Mdot
.41424 .37315 Mdot
.48796 .66438 Mdot
.4409 .65598 Mdot
.30639 .62692 Mdot
.31945 .41204 Mdot
.33681 .58376 Mdot
.58929 .36921 Mdot
.43659 .69257 Mdot
.57133 .43088 Mdot
.28639 .60291 Mdot
.31865 .39186 Mdot
.54451 .39204 Mdot
.33619 .35222 Mdot
.28524 .57074 Mdot
.71273 .65893 Mdot
.37806 .37547 Mdot
.48623 .65367 Mdot
.6335 .45527 Mdot
.54805 .39525 Mdot
.1679 .49768 Mdot
.70617 .47413 Mdot
.33699 .37016 Mdot
.53253 .40169 Mdot
.18764 .43945 Mdot
.54939 .43707 Mdot
.58815 .30016 Mdot
.58664 .28687 Mdot
.58889 .48144 Mdot
.47158 .71972 Mdot
.36884 .4041 Mdot
.5601 .39433 Mdot
.57406 .3549 Mdot
.49586 .32715 Mdot
.57614 .42383 Mdot
.59053 .2814 Mdot
.58488 .54045 Mdot
.29278 .59271 Mdot
.57845 .55073 Mdot
.38392 .61541 Mdot
.59302 .55808 Mdot
.5608 .43474 Mdot
.47396 .68895 Mdot
.31617 .37986 Mdot
.59935 .5525 Mdot
.33635 .59613 Mdot
.56053 .38992 Mdot
.2943 .53888 Mdot
.37239 .39504 Mdot
.57513 .27802 Mdot
.68882 .63482 Mdot
.55036 .62365 Mdot
.3208 .39499 Mdot
.53554 .2187 Mdot
.57211 .36158 Mdot
.5546 .40891 Mdot
.34916 .39374 Mdot
.42803 .66665 Mdot
.31239 .65648 Mdot
.34092 .4146 Mdot
.29024 .5938 Mdot
.33279 .4226 Mdot
.60432 .54953 Mdot
.43021 .6622 Mdot
.57201 .5875 Mdot
.56814 .54258 Mdot
.73745 .54888 Mdot
.59252 .39318 Mdot
.561 .53873 Mdot
.46931 .68253 Mdot
.34133 .4117 Mdot
.30526 .59313 Mdot
.54528 .35106 Mdot
.34626 .37304 Mdot
.32396 .59584 Mdot
.70937 .62634 Mdot
.70706 .61856 Mdot
.32671 .38079 Mdot
.52698 .22353 Mdot
.32532 .62171 Mdot
.33153 .57029 Mdot
.69161 .55735 Mdot
.33321 .37344 Mdot
.67388 .61151 Mdot
.33307 .58281 Mdot
.49819 .79068 Mdot
.57989 .2714 Mdot
.73435 .57055 Mdot
.17292 .50136 Mdot
.69199 .55829 Mdot
.64169 .61571 Mdot
.67636 .62293 Mdot
.32392 .5967 Mdot
.54938 .3571 Mdot
.33069 .39001 Mdot
.34601 .37534 Mdot
.58548 .42439 Mdot
.60262 .56099 Mdot
.5763 .36946 Mdot
.5771 .54827 Mdot
.56331 .54438 Mdot
.56326 .38692 Mdot
.45389 .21494 Mdot
.3542 .3691 Mdot
.53021 .38935 Mdot
.45495 .6676 Mdot
.53783 .55934 Mdot
.33006 .61366 Mdot
.53327 .3934 Mdot
.52761 .38825 Mdot
.60318 .387 Mdot
.33057 .56855 Mdot
.28703 .49822 Mdot
.50027 .67159 Mdot
.2875 .58531 Mdot
.38404 .61869 Mdot
.45726 .68739 Mdot
.58368 .3486 Mdot
.69217 .63139 Mdot
.57022 .57247 Mdot
.54698 .36271 Mdot
.69462 .5606 Mdot
.5726 .34427 Mdot
.58222 .61914 Mdot
.598 .61513 Mdot
.18138 .47582 Mdot
.29674 .49074 Mdot
.57239 .35814 Mdot
.60182 .28256 Mdot
.71568 .56235 Mdot
.26011 .63956 Mdot
.30541 .58755 Mdot
.44766 .72289 Mdot
.42765 .67334 Mdot
.38747 .68697 Mdot
.52478 .25582 Mdot
.5583 .27794 Mdot
.55675 .41597 Mdot
.58373 .55885 Mdot
.41324 .38489 Mdot
.67471 .62273 Mdot
.32558 .40274 Mdot
.16782 .50061 Mdot
.67154 .4172 Mdot
.56781 .27465 Mdot
.45064 .78969 Mdot
.46843 .6504 Mdot
.59736 .56364 Mdot
.68937 .61784 Mdot
.5814 .38758 Mdot
.36246 .37153 Mdot
.70603 .55978 Mdot
.60202 .5776 Mdot
.84974 .52679 Mdot
.33612 .41711 Mdot
.6928 .43656 Mdot
.31739 .59766 Mdot
.45422 .70539 Mdot
.54901 .43682 Mdot
.55125 .37565 Mdot
.35958 .43003 Mdot
.55543 .35108 Mdot
.57388 .30081 Mdot
.58188 .27512 Mdot
.4538 .64187 Mdot
.38161 .6007 Mdot
.29761 .57029 Mdot
.50674 .73194 Mdot
.32066 .3916 Mdot
.44929 .19716 Mdot
.46967 .69933 Mdot
.62432 .61392 Mdot
.28783 .6108 Mdot
.705 .62088 Mdot
.47492 .69805 Mdot
.68341 .65233 Mdot
.58315 .34607 Mdot
.44845 .68019 Mdot
.68294 .63844 Mdot
.53906 .45597 Mdot
.5976 .55182 Mdot
.75077 .65533 Mdot
.32495 .58353 Mdot
.3557 .4276 Mdot
.54596 .36289 Mdot
.57627 .56725 Mdot
.59696 .58489 Mdot
.64796 .48084 Mdot
.55505 .56543 Mdot
.60084 .5752 Mdot
.61704 .48597 Mdot
.72155 .64542 Mdot
.24796 .43962 Mdot
.57699 .29566 Mdot
.32898 .41817 Mdot
.56657 .35367 Mdot
.36731 .57082 Mdot
.32576 .59395 Mdot
.58223 .39322 Mdot
.17266 .48131 Mdot
.32569 .5784 Mdot
.56638 .40381 Mdot
.29257 .57105 Mdot
.34208 .37089 Mdot
.67823 .41211 Mdot
.31755 .39012 Mdot
.56494 .38925 Mdot
.28823 .57768 Mdot
.45244 .72729 Mdot
.35048 .38407 Mdot
.55791 .3923 Mdot
.57925 .41301 Mdot
.5831 .56167 Mdot
.58172 .27333 Mdot
.34884 .63934 Mdot
.60045 .3934 Mdot
.49518 .70082 Mdot
.58688 .416 Mdot
.69604 .60857 Mdot
.56131 .79587 Mdot
.33074 .37463 Mdot
.55425 .56879 Mdot
.47598 .70679 Mdot
.51114 .41288 Mdot
.69229 .42045 Mdot
.56833 .37634 Mdot
.58574 .5832 Mdot
.71169 .44943 Mdot
.31092 .571 Mdot
.57212 .28469 Mdot
.53708 .58433 Mdot
.47642 .71558 Mdot
.59087 .55867 Mdot
.54865 .42184 Mdot
.37227 .38344 Mdot
.59483 .26639 Mdot
.45313 .69164 Mdot
.34077 .42229 Mdot
.55157 .43303 Mdot
.3774 .62432 Mdot
.5446 .57624 Mdot
.30657 .57172 Mdot
.58085 .29374 Mdot
.58353 .34906 Mdot
.43664 .68927 Mdot
.35727 .39217 Mdot
.31617 .6043 Mdot
.31978 .38823 Mdot
.63195 .52388 Mdot
.69609 .44428 Mdot
.31289 .40527 Mdot
.71483 .64097 Mdot
.51158 .82895 Mdot
.28853 .5908 Mdot
.56441 .5641 Mdot
.48335 .73669 Mdot
.3719 .37639 Mdot
.47833 .69387 Mdot
.51729 .23158 Mdot
.47093 .71879 Mdot
.58581 .25757 Mdot
.45313 .72464 Mdot
.55588 .26323 Mdot
.53429 .3824 Mdot
.45008 .65058 Mdot
.58635 .53985 Mdot
.54046 .40774 Mdot
.34819 .37358 Mdot
.75624 .52379 Mdot
.49152 .29491 Mdot
.52868 .25366 Mdot
.47067 .71356 Mdot
.51274 .22916 Mdot
.57789 .27999 Mdot
.58194 .29199 Mdot
.33376 .39167 Mdot
.56533 .56559 Mdot
.65711 .6015 Mdot
.65418 .60562 Mdot
.63763 .77285 Mdot
.71692 .39739 Mdot
.5426 .21677 Mdot
.343 .37722 Mdot
.42152 .75584 Mdot
.32394 .36241 Mdot
.6018 .57715 Mdot
.31412 .60819 Mdot
.2825 .50486 Mdot
.55592 .43982 Mdot
.62422 .60222 Mdot
.5756 .30612 Mdot
.35645 .42481 Mdot
.31978 .42329 Mdot
.31609 .60529 Mdot
.53136 .2495 Mdot
.50139 .33046 Mdot
.58174 .37363 Mdot
.31908 .60777 Mdot
.59955 .58214 Mdot
.51697 .40587 Mdot
.74794 .55446 Mdot
.26522 .73056 Mdot
.56897 .38201 Mdot
.39109 .45381 Mdot
.54441 .36653 Mdot
.73232 .55185 Mdot
.5787 .38787 Mdot
.35666 .38658 Mdot
.60196 .23673 Mdot
.52301 .42429 Mdot
.45973 .79756 Mdot
.66743 .42165 Mdot
.69397 .65129 Mdot
.55647 .38081 Mdot
.57069 .36609 Mdot
.67324 .60759 Mdot
.36547 .39891 Mdot
.59148 .36635 Mdot
.25318 .43938 Mdot
.55758 .39656 Mdot
.33609 .60772 Mdot
.6805 .49066 Mdot
.75079 .53533 Mdot
.58115 .27915 Mdot
.37305 .38549 Mdot
.32405 .56777 Mdot
.3 .62187 Mdot
.55768 .5735 Mdot
.3264 .59307 Mdot
.5397 .37344 Mdot
.67915 .49053 Mdot
.31796 .40987 Mdot
.59901 .55774 Mdot
.36266 .41152 Mdot
.42667 .71104 Mdot
.32236 .58385 Mdot
.58967 .5695 Mdot
.5094 .26989 Mdot
.31438 .57851 Mdot
.39617 .62284 Mdot
.57363 .28076 Mdot
.59795 .5835 Mdot
.34231 .35779 Mdot
.43883 .69948 Mdot
.593 .58242 Mdot
.3175 .60124 Mdot
.57065 .37631 Mdot
.59089 .26883 Mdot
.32658 .59451 Mdot
.31751 .4583 Mdot
.57522 .29587 Mdot
.55838 .39927 Mdot
.35575 .37465 Mdot
.34923 .4104 Mdot
.53065 .3857 Mdot
.55832 .3536 Mdot
.48698 .70595 Mdot
.58221 .58459 Mdot
.58037 .58555 Mdot
.56104 .54885 Mdot
.46291 .71328 Mdot
.48954 .82043 Mdot
.33818 .57633 Mdot
.75065 .53351 Mdot
.30985 .50288 Mdot
.57843 .57127 Mdot
.48871 .70242 Mdot
.55903 .36549 Mdot
.58127 .43262 Mdot
.28581 .58216 Mdot
.60807 .82844 Mdot
.56745 .44293 Mdot
.32257 .4098 Mdot
.3082 .61274 Mdot
.57888 .3229 Mdot
.38806 .67723 Mdot
.67642 .64154 Mdot
.54074 .21583 Mdot
.30596 .6114 Mdot
.28823 .42129 Mdot
.30496 .61094 Mdot
.56996 .36664 Mdot
.55108 .42123 Mdot
.35055 .43088 Mdot
.6964 .65197 Mdot
.59568 .40735 Mdot
.56911 .39871 Mdot
.43428 .77338 Mdot
.3166 .37167 Mdot
.65219 .60531 Mdot
.59871 .38216 Mdot
.58531 .54251 Mdot
.69553 .65505 Mdot
.54715 .40328 Mdot
.58542 .41995 Mdot
.57898 .53224 Mdot
.28148 .60673 Mdot
.70954 .64847 Mdot
.46251 .80029 Mdot
.33233 .4157 Mdot
.31198 .64619 Mdot
.56923 .59015 Mdot
.28813 .59283 Mdot
.55006 .33049 Mdot
.59419 .56662 Mdot
.24447 .55718 Mdot
.80853 .30931 Mdot
.59654 .57708 Mdot
.49112 .70608 Mdot
.49457 .32399 Mdot
.58922 .41674 Mdot
.55903 .39977 Mdot
.65916 .59996 Mdot
.3464 .40248 Mdot
.29694 .49121 Mdot
.28878 .5805 Mdot
.5481 .37282 Mdot
.32423 .37916 Mdot
.18195 .46432 Mdot
.5885 .56162 Mdot
.69518 .64298 Mdot
.70949 .63608 Mdot
.54184 .39504 Mdot
.71539 .42946 Mdot
.35019 .38201 Mdot
.55813 .39201 Mdot
.54397 .40557 Mdot
.46693 .73143 Mdot
.34099 .36655 Mdot
.44986 .68031 Mdot
.56952 .27029 Mdot
.57327 .22638 Mdot
.36197 .56172 Mdot
.32818 .58064 Mdot
.56789 .58333 Mdot
.29845 .57008 Mdot
.49901 .7143 Mdot
.57983 .58528 Mdot
.55769 .39123 Mdot
.31793 .4106 Mdot
.55872 .39231 Mdot
.55828 .39623 Mdot
.57593 .37754 Mdot
.54434 .21446 Mdot
.49402 .66279 Mdot
.6974 .63786 Mdot
.59471 .36112 Mdot
.45674 .70115 Mdot
.3963 .71591 Mdot
.49714 .33341 Mdot
.55248 .38332 Mdot
.55755 .40847 Mdot
.36605 .35828 Mdot
.57964 .26954 Mdot
.31409 .58105 Mdot
.35204 .43045 Mdot
.54518 .4347 Mdot
.49845 .73763 Mdot
.58909 .36204 Mdot
.31299 .40324 Mdot
.33993 .5827 Mdot
.41832 .35627 Mdot
.58406 .59298 Mdot
.56636 .5847 Mdot
.59545 .5801 Mdot
.5582 .55394 Mdot
.33001 .61301 Mdot
.49001 .69729 Mdot
.50538 .73677 Mdot
.60028 .41903 Mdot
.55494 .35271 Mdot
.54907 .42056 Mdot
.47333 .73551 Mdot
.59469 .53962 Mdot
.51237 .24871 Mdot
.58311 .32405 Mdot
.44931 .70394 Mdot
.57791 .54012 Mdot
.2747 .34282 Mdot
.36172 .41639 Mdot
.50117 .67948 Mdot
.29579 .62302 Mdot
.68251 .64058 Mdot
.71109 .72701 Mdot
.35358 .41601 Mdot
.41256 .39233 Mdot
.45961 .67355 Mdot
.6632 .48322 Mdot
.4261 .16875 Mdot
.48134 .69329 Mdot
.57679 .30334 Mdot
.33387 .38396 Mdot
.59244 .54497 Mdot
.70997 .45391 Mdot
.67467 .4845 Mdot
.43853 .67413 Mdot
.58157 .41042 Mdot
.42258 .65688 Mdot
.48461 .71344 Mdot
.565 .57778 Mdot
.46973 .71282 Mdot
.31228 .56934 Mdot
.46639 .68465 Mdot
.31053 .45152 Mdot
.59173 .38128 Mdot
.42667 .17287 Mdot
.68901 .51348 Mdot
.56976 .35917 Mdot
.30233 .58194 Mdot
.36626 .63208 Mdot
.58638 .38697 Mdot
.66307 .62916 Mdot
.49127 .70381 Mdot
.39581 .65755 Mdot
.58741 .2625 Mdot
.45189 .72255 Mdot
.37166 .38049 Mdot
.3856 .6135 Mdot
.38422 .61733 Mdot
.5916 .58255 Mdot
.3388 .37174 Mdot
.28385 .57215 Mdot
.29073 .59342 Mdot
.54263 .57021 Mdot
.53832 .36952 Mdot
.36273 .3764 Mdot
.52896 .44126 Mdot
.53495 .59307 Mdot
.55636 .39624 Mdot
.45183 .6802 Mdot
.46641 .64466 Mdot
.66606 .5078 Mdot
.46873 .70133 Mdot
.5631 .57707 Mdot
.35582 .37188 Mdot
.58911 .26124 Mdot
.34447 .4127 Mdot
.56913 .35321 Mdot
.3757 .59039 Mdot
.36699 .41058 Mdot
.62386 .61384 Mdot
.57483 .40909 Mdot
.45612 .21293 Mdot
.59768 .36787 Mdot
.55737 .39922 Mdot
.43504 .6569 Mdot
.675 .60863 Mdot
.58696 .61059 Mdot
.38925 .69037 Mdot
.66609 .62699 Mdot
.33401 .45383 Mdot
.42852 .66278 Mdot
.69792 .61669 Mdot
.64202 .7726 Mdot
.55379 .57097 Mdot
.70277 .63175 Mdot
.53232 .40033 Mdot
.3302 .58353 Mdot
.32982 .42893 Mdot
.53893 .40598 Mdot
.55927 .24301 Mdot
.5711 .25726 Mdot
.58502 .56359 Mdot
.55783 .40263 Mdot
.56929 .36364 Mdot
.32338 .38052 Mdot
.17129 .50431 Mdot
.49568 .68587 Mdot
.57199 .55395 Mdot
.34806 .41661 Mdot
.16786 .49654 Mdot
.4441 .65509 Mdot
.69121 .61008 Mdot
.30519 .56356 Mdot
.28563 .40794 Mdot
.58126 .56592 Mdot
.32391 .58622 Mdot
.4285 .64194 Mdot
.67974 .556 Mdot
.59851 .27839 Mdot
.47489 .67673 Mdot
.6921 .55862 Mdot
.57176 .26954 Mdot
.38885 .69721 Mdot
.26085 .63892 Mdot
.37195 .39693 Mdot
.3254 .59823 Mdot
.6962 .64616 Mdot
.31681 .39771 Mdot
.36299 .41138 Mdot
.32831 .57818 Mdot
.51811 .18166 Mdot
.7101 .44879 Mdot
.31573 .55689 Mdot
.64434 .48357 Mdot
.68423 .55605 Mdot
.57963 .56367 Mdot
.69413 .63434 Mdot
.38155 .60069 Mdot
.35513 .39158 Mdot
.29275 .50252 Mdot
.69792 .56076 Mdot
.57213 .27998 Mdot
.67981 .63809 Mdot
.18539 .46424 Mdot
.25007 .5902 Mdot
.31725 .5819 Mdot
.43305 .77179 Mdot
.6634 .6192 Mdot
.53228 .39013 Mdot
.63031 .82311 Mdot
.53482 .38683 Mdot
.33414 .58569 Mdot
.57502 .30499 Mdot
.33071 .40557 Mdot
.33633 .57616 Mdot
.56761 .28155 Mdot
.59992 .39319 Mdot
.58084 .36614 Mdot
.4866 .65348 Mdot
.35983 .42825 Mdot
.56203 .59027 Mdot
.56753 .35854 Mdot
.57055 .40092 Mdot
.60354 .57995 Mdot
.74871 .53762 Mdot
.46922 .60214 Mdot
.60356 .55554 Mdot
.44529 .68635 Mdot
.59913 .55671 Mdot
.57 .55725 Mdot
.35023 .35741 Mdot
.40964 .7391 Mdot
.58769 .58937 Mdot
.56718 .38775 Mdot
.56291 .39353 Mdot
.30684 .56145 Mdot
.71126 .45006 Mdot
.66677 .4822 Mdot
.49579 .69527 Mdot
.53991 .58466 Mdot
.56972 .42317 Mdot
.33876 .37033 Mdot
.64413 .60094 Mdot
.55872 .57144 Mdot
.33077 .41665 Mdot
.59424 .38916 Mdot
.46711 .73195 Mdot
.59563 .57581 Mdot
.60771 .57711 Mdot
.68118 .63506 Mdot
.32273 .56224 Mdot
.38105 .39164 Mdot
.48762 .71071 Mdot
.5946 .29203 Mdot
.55228 .59503 Mdot
.46384 .72542 Mdot
.57952 .56191 Mdot
.59375 .55186 Mdot
.34109 .37272 Mdot
.29075 .42774 Mdot
.61071 .55207 Mdot
.46168 .70997 Mdot
.23841 .69303 Mdot
.29559 .60603 Mdot
.58753 .35196 Mdot
.30882 .56561 Mdot
.37229 .39363 Mdot
.7386 .55013 Mdot
.70679 .62598 Mdot
.31814 .57849 Mdot
.60312 .57285 Mdot
.3647 .41122 Mdot
.36614 .42358 Mdot
.56441 .38532 Mdot
.55393 .38973 Mdot
.49006 .74053 Mdot
.72586 .56521 Mdot
.29117 .57121 Mdot
.66109 .60174 Mdot
.49072 .68149 Mdot
.59081 .26621 Mdot
.32799 .39271 Mdot
.76497 .64652 Mdot
.59383 .35709 Mdot
.45939 .70418 Mdot
.34428 .3891 Mdot
.65665 .60532 Mdot
.69891 .63782 Mdot
.55513 .35942 Mdot
.64124 .61485 Mdot
.31969 .57506 Mdot
.35062 .37637 Mdot
.39606 .43243 Mdot
.59617 .3675 Mdot
.55461 .38489 Mdot
.57219 .27572 Mdot
.31944 .55751 Mdot
.53235 .39729 Mdot
.69826 .65019 Mdot
.32327 .39286 Mdot
.55159 .36445 Mdot
.66348 .61628 Mdot
.55416 .58138 Mdot
.59516 .56975 Mdot
.44315 .65047 Mdot
.65714 .61869 Mdot
.6665 .61293 Mdot
.66134 .61913 Mdot
.28202 .50531 Mdot
.59819 .35387 Mdot
.62209 .58088 Mdot
.5772 .41546 Mdot
.68051 .55504 Mdot
.59713 .28937 Mdot
.2954 .59058 Mdot
.43689 .68759 Mdot
.57883 .375 Mdot
.57414 .41706 Mdot
.37869 .39354 Mdot
.59282 .25887 Mdot
.53098 .38733 Mdot
.32797 .40251 Mdot
.40002 .42404 Mdot
.43207 .69251 Mdot
.17302 .49994 Mdot
.68007 .79705 Mdot
.55557 .34502 Mdot
.66717 .4867 Mdot
.36669 .40107 Mdot
.30605 .56254 Mdot
.65048 .48338 Mdot
.3274 .56529 Mdot
.35123 .40579 Mdot
.59075 .25469 Mdot
.31974 .46012 Mdot
.6695 .63056 Mdot
.57037 .36771 Mdot
.32615 .57501 Mdot
.57351 .3683 Mdot
.32241 .5703 Mdot
.50264 .23249 Mdot
.70907 .46684 Mdot
.54817 .3527 Mdot
.57774 .42309 Mdot
.65674 .64139 Mdot
.55303 .38629 Mdot
.45041 .79237 Mdot
.33965 .39006 Mdot
.53987 .56656 Mdot
.59386 .25351 Mdot
.49134 .29719 Mdot
.55579 .40605 Mdot
.56927 .25706 Mdot
.55693 .41212 Mdot
.59274 .82986 Mdot
.57876 .34461 Mdot
.53715 .37248 Mdot
.30237 .59247 Mdot
.28801 .6039 Mdot
.37525 .40953 Mdot
.59437 .55591 Mdot
.18313 .47039 Mdot
.56597 .40258 Mdot
.4743 .65921 Mdot
.53053 .59457 Mdot
.6671 .61029 Mdot
.32158 .4004 Mdot
.80326 .29241 Mdot
.32066 .62098 Mdot
.44703 .67044 Mdot
.57961 .3009 Mdot
.44658 .68367 Mdot
.49402 .67257 Mdot
.36337 .45574 Mdot
.69444 .63541 Mdot
.58357 .35669 Mdot
.45977 .30779 Mdot
.4184 .37247 Mdot
.59614 .36781 Mdot
.42457 .66771 Mdot
.58093 .5322 Mdot
.65977 .34728 Mdot
.72254 .65196 Mdot
.67452 .61669 Mdot
.32082 .59587 Mdot
.4702 .6573 Mdot
.57334 .55371 Mdot
.70142 .61891 Mdot
.43751 .70571 Mdot
.55501 .57133 Mdot
.42519 .76189 Mdot
.35065 .38152 Mdot
.51405 .22983 Mdot
.46204 .19946 Mdot
.30264 .57377 Mdot
.39374 .71216 Mdot
.31695 .4085 Mdot
.31773 .38639 Mdot
.58106 .55555 Mdot
.4471 .7024 Mdot
.32251 .43927 Mdot
.55612 .3607 Mdot
.59785 .55582 Mdot
.54025 .38477 Mdot
.72211 .64141 Mdot
.56357 .39945 Mdot
.44366 .71534 Mdot
.30342 .58542 Mdot
.47675 .71329 Mdot
.32305 .59233 Mdot
.75315 .53008 Mdot
.57234 .40736 Mdot
.5567 .38357 Mdot
.67882 .48987 Mdot
.35356 .36299 Mdot
.45944 .31797 Mdot
.46317 .70858 Mdot
.47408 .71372 Mdot
.59439 .25447 Mdot
.33081 .42285 Mdot
.61532 .56834 Mdot
.64059 .48442 Mdot
.55465 .41156 Mdot
.34028 .39187 Mdot
.59808 .28885 Mdot
.22579 .62418 Mdot
.70384 .47755 Mdot
.35624 .36176 Mdot
.4566 .79967 Mdot
.54921 .41475 Mdot
.56723 .55579 Mdot
.55692 .54334 Mdot
.718 .41799 Mdot
.58119 .61073 Mdot
.33536 .41742 Mdot
.5798 .54916 Mdot
.32882 .39 Mdot
.4765 .71981 Mdot
.34176 .58491 Mdot
.33319 .39605 Mdot
.56154 .41284 Mdot
.68129 .79553 Mdot
.32908 .57436 Mdot
.56713 .36959 Mdot
.33757 .58378 Mdot
.32537 .4304 Mdot
.3398 .40701 Mdot
.55512 .57145 Mdot
.57514 .30016 Mdot
.31899 .57621 Mdot
.55023 .35551 Mdot
.37022 .46652 Mdot
.59486 .26618 Mdot
.5346 .57161 Mdot
.57269 .42302 Mdot
.59413 .39605 Mdot
.47458 .81202 Mdot
.51517 .42664 Mdot
.36933 .57368 Mdot
.34101 .5645 Mdot
.28551 .49703 Mdot
.34117 .3604 Mdot
.7173 .62992 Mdot
.37616 .40936 Mdot
.57213 .58648 Mdot
.44329 .68157 Mdot
.57428 .37511 Mdot
.55315 .56369 Mdot
.3091 .55534 Mdot
.69981 .627 Mdot
.57257 .34428 Mdot
.47557 .67221 Mdot
.56779 .54808 Mdot
.3206 .58359 Mdot
.35688 .3958 Mdot
.32921 .40982 Mdot
.41251 .7442 Mdot
.55312 .36387 Mdot
.55552 .39071 Mdot
.33336 .60552 Mdot
.62999 .61082 Mdot
.66549 .62816 Mdot
.58658 .5398 Mdot
.3375 .59609 Mdot
.70459 .47659 Mdot
.35722 .43192 Mdot
.56422 .36385 Mdot
.68351 .49228 Mdot
.29038 .493 Mdot
.34331 .32975 Mdot
.67158 .6207 Mdot
.69818 .42147 Mdot
.33612 .41753 Mdot
.30508 .59591 Mdot
.63603 .77512 Mdot
.57332 .27203 Mdot
.5885 .38551 Mdot
.69324 .41211 Mdot
.64037 .48199 Mdot
.58497 .30206 Mdot
.57573 .59222 Mdot
.69585 .45618 Mdot
.59644 .25669 Mdot
.59702 .2803 Mdot
.56451 .42533 Mdot
.5713 .42424 Mdot
.34015 .39838 Mdot
.53219 .25254 Mdot
.45876 .67797 Mdot
.58616 .31216 Mdot
.70053 .66688 Mdot
.57475 .28533 Mdot
.58054 .43028 Mdot
.2993 .33261 Mdot
.70637 .37035 Mdot
.33844 .38254 Mdot
.36826 .37068 Mdot
.30127 .57326 Mdot
.59307 .26259 Mdot
.46089 .70697 Mdot
.58998 .53285 Mdot
.44053 .69855 Mdot
.34163 .39715 Mdot
.42899 .6842 Mdot
.30488 .62863 Mdot
.47476 .67646 Mdot
.44791 .69861 Mdot
.30088 .58867 Mdot
.35754 .42911 Mdot
.59858 .37018 Mdot
.30087 .58775 Mdot
.6103 .57104 Mdot
.69816 .61356 Mdot
.40969 .40411 Mdot
.59793 .54795 Mdot
.57236 .44181 Mdot
.23491 .68003 Mdot
.46526 .6697 Mdot
.68132 .41099 Mdot
.36616 .41566 Mdot
.67822 .65571 Mdot
.33381 .3995 Mdot
.61233 .5542 Mdot
.67264 .62578 Mdot
.5337 .40454 Mdot
.7454 .6623 Mdot
.26599 .63981 Mdot
.52055 .41227 Mdot
.39963 .42495 Mdot
.44296 .70424 Mdot
.30883 .57347 Mdot
.33574 .64821 Mdot
.57255 .55274 Mdot
.37364 .38541 Mdot
.28217 .41587 Mdot
.57658 .58621 Mdot
.30548 .59192 Mdot
.4557 .23393 Mdot
.56249 .3602 Mdot
.30504 .56843 Mdot
.57537 .42125 Mdot
.53156 .22166 Mdot
.64092 .60103 Mdot
.56061 .54819 Mdot
.58843 .2553 Mdot
.44328 .65619 Mdot
.59318 .25419 Mdot
.55188 .24335 Mdot
.73678 .56108 Mdot
.5697 .41726 Mdot
.68528 .41025 Mdot
.4969 .71733 Mdot
.32778 .38504 Mdot
.58015 .57754 Mdot
.58163 .56286 Mdot
.58125 .2581 Mdot
.76372 .71881 Mdot
.69657 .61918 Mdot
.44716 .78997 Mdot
.57008 .40746 Mdot
.54872 .3952 Mdot
.37802 .40578 Mdot
.50158 .23574 Mdot
.58578 .54124 Mdot
.58525 .39901 Mdot
.71198 .37899 Mdot
.3046 .60386 Mdot
.55588 .43207 Mdot
.54172 .39096 Mdot
.385 .60518 Mdot
.30297 .59413 Mdot
.47464 .72711 Mdot
.55441 .57542 Mdot
.43974 .65011 Mdot
.68781 .65411 Mdot
.69345 .43317 Mdot
.74548 .54381 Mdot
.70025 .47906 Mdot
.67149 .63988 Mdot
.57925 .27785 Mdot
.5861 .43625 Mdot
.59077 .38443 Mdot
.67851 .61593 Mdot
.28672 .62225 Mdot
.33855 .39307 Mdot
.52361 .22498 Mdot
.58162 .56067 Mdot
.5948 .28851 Mdot
.70481 .65964 Mdot
.33106 .38822 Mdot
.453 .21698 Mdot
.34547 .40133 Mdot
.31693 .58627 Mdot
.39002 .70134 Mdot
.67181 .62803 Mdot
.33326 .39955 Mdot
.43442 .66127 Mdot
.3736 .5873 Mdot
.59359 .34353 Mdot
.30294 .62888 Mdot
.32796 .45041 Mdot
.36414 .36731 Mdot
.3349 .35731 Mdot
.58272 .26139 Mdot
.68376 .4109 Mdot
.56601 .5822 Mdot
.33976 .58712 Mdot
.45342 .65752 Mdot
.72747 .56392 Mdot
.45444 .25444 Mdot
.68917 .46727 Mdot
.54485 .41925 Mdot
.56401 .39817 Mdot
.54431 .39959 Mdot
.59205 .59159 Mdot
.58217 .44086 Mdot
.56955 .41921 Mdot
.2862 .58077 Mdot
.47016 .72653 Mdot
.57157 .40406 Mdot
.59323 .57283 Mdot
.61898 .60352 Mdot
.68007 .65703 Mdot
.54708 .20924 Mdot
.40735 .40164 Mdot
.33218 .39155 Mdot
.45421 .69289 Mdot
.42939 .6574 Mdot
.70954 .62566 Mdot
.31645 .60759 Mdot
.34714 .40326 Mdot
.58836 .82914 Mdot
.67392 .63633 Mdot
.56943 .38461 Mdot
.68015 .49012 Mdot
.71226 .38847 Mdot
.58914 .41948 Mdot
.57702 .37848 Mdot
.60252 .56897 Mdot
.45766 .7049 Mdot
.55725 .2701 Mdot
.45441 .21646 Mdot
.66455 .61758 Mdot
.67823 .6048 Mdot
.32228 .3713 Mdot
.54613 .35771 Mdot
.32616 .57594 Mdot
.71247 .447 Mdot
.35998 .63434 Mdot
.19087 .43787 Mdot
.43169 .70927 Mdot
.58655 .35904 Mdot
.49146 .31582 Mdot
.55674 .44026 Mdot
.31641 .37944 Mdot
.29443 .43029 Mdot
.34078 .37881 Mdot
.30794 .60613 Mdot
.66008 .54955 Mdot
.29669 .61788 Mdot
.5775 .54062 Mdot
.35443 .42126 Mdot
.52208 .43027 Mdot
.47319 .71318 Mdot
.59727 .26594 Mdot
.68717 .62841 Mdot
.58534 .47956 Mdot
.57857 .57452 Mdot
.69687 .42534 Mdot
.48866 .70161 Mdot
.34585 .43769 Mdot
.59766 .26555 Mdot
.38909 .68185 Mdot
.69563 .46115 Mdot
.47163 .74479 Mdot
.55234 .56516 Mdot
.66952 .6288 Mdot
.49779 .33612 Mdot
.68165 .64312 Mdot
.32083 .57738 Mdot
.57469 .40709 Mdot
.53892 .3698 Mdot
.55487 .4008 Mdot
.53679 .40576 Mdot
.31415 .60357 Mdot
.5933 .28355 Mdot
.60872 .55521 Mdot
.55702 .55774 Mdot
.5771 .29477 Mdot
.6976 .63224 Mdot
.29463 .60156 Mdot
.46376 .72654 Mdot
.598 .58051 Mdot
.70689 .65532 Mdot
.52354 .3831 Mdot
.57709 .41145 Mdot
.56656 .54635 Mdot
.53289 .40152 Mdot
.59088 .28435 Mdot
.47223 .67994 Mdot
.58934 .29548 Mdot
.68343 .65888 Mdot
.68301 .6291 Mdot
.32833 .59003 Mdot
.33247 .39877 Mdot
.71193 .63911 Mdot
.48987 .68447 Mdot
.54205 .43042 Mdot
.57048 .42376 Mdot
.3086 .44944 Mdot
.69647 .56094 Mdot
.67275 .65109 Mdot
.5317 .39465 Mdot
.33665 .3671 Mdot
.27708 .40195 Mdot
.58798 .39065 Mdot
.58503 .28617 Mdot
.34858 .35622 Mdot
.70076 .61638 Mdot
.32196 .60519 Mdot
.69448 .51728 Mdot
.3331 .57207 Mdot
.35783 .39536 Mdot
.58234 .55038 Mdot
.35713 .42806 Mdot
.57398 .55122 Mdot
.22302 .38664 Mdot
.56793 .4215 Mdot
.32893 .46571 Mdot
.59796 .54056 Mdot
.46964 .7147 Mdot
.45528 .71438 Mdot
.59334 .57764 Mdot
.33942 .42062 Mdot
.56419 .57829 Mdot
.69038 .64564 Mdot
.28945 .49753 Mdot
.35411 .35722 Mdot
.448 .70002 Mdot
.46711 .66949 Mdot
.338 .5952 Mdot
.56062 .40298 Mdot
.5648 .36328 Mdot
.47821 .67882 Mdot
.35566 .63644 Mdot
.36984 .39498 Mdot
.55602 .39017 Mdot
.60597 .56179 Mdot
.46408 .67839 Mdot
.25289 .62492 Mdot
.32994 .43565 Mdot
.58811 .25407 Mdot
.73873 .5591 Mdot
.34252 .59278 Mdot
.55332 .43695 Mdot
.59001 .2831 Mdot
.68238 .61241 Mdot
.69793 .41736 Mdot
.68965 .55672 Mdot
.31492 .62433 Mdot
.56606 .58413 Mdot
.58816 .42153 Mdot
.46532 .71837 Mdot
.53393 .4193 Mdot
.81508 .35371 Mdot
.5655 .54505 Mdot
.55058 .3677 Mdot
.56326 .54044 Mdot
.34378 .41297 Mdot
.55352 .39495 Mdot
.3646 .56732 Mdot
.45704 .69279 Mdot
.55479 .36412 Mdot
.6463 .62474 Mdot
.3368 .58232 Mdot
.57955 .57438 Mdot
.66618 .62524 Mdot
.58226 .30645 Mdot
.75578 .52433 Mdot
.47451 .73565 Mdot
.70188 .638 Mdot
.56013 .4053 Mdot
.49147 .68048 Mdot
.28742 .5997 Mdot
.58309 .57906 Mdot
.52083 .40251 Mdot
.29282 .5896 Mdot
.30062 .60117 Mdot
.67658 .63347 Mdot
.4445 .19459 Mdot
.54893 .34986 Mdot
.55658 .37363 Mdot
.44774 .21818 Mdot
.27641 .3718 Mdot
.57175 .36904 Mdot
.53883 .39802 Mdot
.32517 .58384 Mdot
.65671 .5496 Mdot
.69702 .42314 Mdot
.58902 .53477 Mdot
.30553 .57622 Mdot
.4251 .67729 Mdot
.45247 .67016 Mdot
.70443 .64147 Mdot
.34534 .38932 Mdot
.71377 .63336 Mdot
.46255 .68541 Mdot
.56684 .38422 Mdot
.32809 .60106 Mdot
.58554 .23258 Mdot
.33744 .5782 Mdot
.48748 .68278 Mdot
.31363 .39788 Mdot
.55636 .25828 Mdot
.81344 .34603 Mdot
.45848 .60068 Mdot
.38898 .70031 Mdot
.6681 .60965 Mdot
.45416 .21721 Mdot
.56472 .40952 Mdot
.54649 .25153 Mdot
.56408 .3686 Mdot
.70072 .60984 Mdot
.44267 .70827 Mdot
.55504 .57153 Mdot
.57162 .55337 Mdot
.69377 .42523 Mdot
.30154 .60493 Mdot
.30533 .62272 Mdot
.58987 .54911 Mdot
.31381 .58543 Mdot
.55161 .37009 Mdot
.48512 .69918 Mdot
.23389 .37257 Mdot
.55661 .41272 Mdot
.54335 .57983 Mdot
.3265 .62011 Mdot
.31556 .4213 Mdot
.42508 .67649 Mdot
.49112 .30795 Mdot
.17838 .48205 Mdot
.31444 .57733 Mdot
.54852 .20991 Mdot
.45802 .69928 Mdot
.59867 .57964 Mdot
.49246 .67947 Mdot
.55725 .36991 Mdot
.58669 .35898 Mdot
.60084 .58269 Mdot
.55275 .40813 Mdot
.45458 .34385 Mdot
.57113 .28191 Mdot
.60273 .34768 Mdot
.5801 .41261 Mdot
.34093 .45615 Mdot
.28572 .59438 Mdot
.58898 .5497 Mdot
.6139 .48585 Mdot
.59369 .39103 Mdot
.33972 .35973 Mdot
.29544 .58595 Mdot
.18089 .50123 Mdot
.30866 .60476 Mdot
.4744 .71687 Mdot
.31191 .60912 Mdot
.55425 .4391 Mdot
.35384 .40804 Mdot
.47063 .69459 Mdot
.57977 .57012 Mdot
.44466 .66347 Mdot
.569 .35911 Mdot
.24932 .6151 Mdot
.44752 .67108 Mdot
.57207 .2768 Mdot
.35127 .40897 Mdot
.75559 .65743 Mdot
.41422 .3757 Mdot
.56411 .37919 Mdot
.56823 .37279 Mdot
.58936 .5408 Mdot
.3237 .59722 Mdot
.34769 .43841 Mdot
.43538 .77558 Mdot
.67338 .65193 Mdot
.34285 .3836 Mdot
.63667 .60278 Mdot
.66197 .48286 Mdot
.32065 .39482 Mdot
.71325 .38287 Mdot
.3288 .57967 Mdot
.33108 .41393 Mdot
.52888 .58489 Mdot
.60123 .28566 Mdot
.69084 .63674 Mdot
.43624 .65428 Mdot
.65565 .48359 Mdot
.45063 .6753 Mdot
.37569 .59008 Mdot
.45416 .64187 Mdot
.31484 .57377 Mdot
.63996 .61614 Mdot
.57615 .30667 Mdot
.30034 .62546 Mdot
.31735 .50933 Mdot
.45518 .681 Mdot
.58806 .5456 Mdot
.58767 .29356 Mdot
.60595 .58088 Mdot
.57034 .54957 Mdot
.31708 .62284 Mdot
.32928 .4136 Mdot
.32546 .41697 Mdot
.54401 .55696 Mdot
.32799 .40666 Mdot
.47861 .69135 Mdot
.69675 .48783 Mdot
.50877 .27058 Mdot
.28479 .59904 Mdot
.58397 .30691 Mdot
.56992 .43281 Mdot
.44793 .71921 Mdot
.48198 .69923 Mdot
.3043 .60573 Mdot
.40027 .35069 Mdot
.56465 .55693 Mdot
.32242 .42973 Mdot
.35306 .41719 Mdot
.34098 .41375 Mdot
.37247 .4088 Mdot
.67266 .55427 Mdot
.30188 .58234 Mdot
.34146 .42033 Mdot
.54585 .41513 Mdot
.54155 .40089 Mdot
.59376 .58337 Mdot
.71747 .63096 Mdot
.58328 .28941 Mdot
.56274 .5773 Mdot
.5871 .37999 Mdot
.46915 .71231 Mdot
.53631 .6016 Mdot
.56758 .58642 Mdot
.46019 .70748 Mdot
.46362 .7123 Mdot
.5628 .58328 Mdot
.54055 .60498 Mdot
.45187 .35496 Mdot
.59689 .24691 Mdot
.37761 .45047 Mdot
.44834 .70735 Mdot
.32805 .51761 Mdot
.32778 .46514 Mdot
.54012 .3703 Mdot
.58775 .53878 Mdot
.48438 .70705 Mdot
.35727 .35848 Mdot
.55136 .38146 Mdot
.57917 .55509 Mdot
.68804 .64081 Mdot
.58331 .57186 Mdot
.60202 .56562 Mdot
.35142 .36603 Mdot
.23999 .68878 Mdot
.32456 .37907 Mdot
.48336 .65268 Mdot
.57381 .56991 Mdot
.42571 .1717 Mdot
.44626 .71031 Mdot
.28877 .49938 Mdot
.5748 .30356 Mdot
.58959 .386 Mdot
.45391 .69096 Mdot
.37123 .3798 Mdot
.29105 .62866 Mdot
.70596 .36559 Mdot
.3324 .40078 Mdot
.56977 .59047 Mdot
.59917 .57216 Mdot
.45997 .67724 Mdot
.36115 .39705 Mdot
.58939 .28324 Mdot
.33436 .41141 Mdot
.30894 .61928 Mdot
.53233 .40738 Mdot
.18276 .47192 Mdot
.57408 .55371 Mdot
.3245 .40139 Mdot
.46261 .65976 Mdot
.69883 .6505 Mdot
.53437 .38539 Mdot
.17192 .48447 Mdot
.55764 .40611 Mdot
.32075 .61602 Mdot
.55316 .60369 Mdot
.59945 .28831 Mdot
.57739 .38653 Mdot
.58532 .42837 Mdot
.27752 .60447 Mdot
.57958 .38766 Mdot
.59595 .39085 Mdot
.4595 .20837 Mdot
.32453 .38309 Mdot
.56993 .40513 Mdot
.48008 .68339 Mdot
.49978 .59623 Mdot
.5431 .38042 Mdot
.39306 .70628 Mdot
.71647 .42029 Mdot
.60331 .54251 Mdot
.53897 .55402 Mdot
.73783 .551 Mdot
.56343 .37274 Mdot
.55353 .35216 Mdot
.53339 .40918 Mdot
.507 .29626 Mdot
.45975 .688 Mdot
.45202 .65113 Mdot
.70069 .6476 Mdot
.69174 .40897 Mdot
.68068 .63067 Mdot
.28721 .59821 Mdot
.56813 .28054 Mdot
.55244 .56989 Mdot
.33051 .39612 Mdot
.55306 .40017 Mdot
.4574 .65528 Mdot
.55599 .36819 Mdot
.58871 .26961 Mdot
.47458 .68646 Mdot
.48172 .7112 Mdot
.44071 .64414 Mdot
.66184 .61452 Mdot
.33485 .38593 Mdot
.53453 .37346 Mdot
.66326 .62165 Mdot
.60114 .58365 Mdot
.70458 .51371 Mdot
.33613 .38308 Mdot
.32451 .39642 Mdot
.34507 .43058 Mdot
.53921 .366 Mdot
.52829 .39276 Mdot
.29636 .61533 Mdot
.30807 .44921 Mdot
.3348 .58314 Mdot
.45208 .68733 Mdot
.47899 .72116 Mdot
.55867 .36907 Mdot
.63574 .60694 Mdot
.69623 .63306 Mdot
.45219 .66364 Mdot
.55612 .55031 Mdot
.70633 .65083 Mdot
.55405 .35559 Mdot
.45005 .67896 Mdot
.66059 .62456 Mdot
.39977 .35008 Mdot
.21037 .47018 Mdot
.70088 .65124 Mdot
.56861 .55608 Mdot
.45482 .26218 Mdot
.72988 .55973 Mdot
.64342 .60071 Mdot
.28569 .59788 Mdot
.59296 .3556 Mdot
.55844 .5496 Mdot
.70605 .65422 Mdot
.72479 .56991 Mdot
.46824 .68648 Mdot
.56561 .55876 Mdot
.55606 .62393 Mdot
.50936 .27135 Mdot
.6976 .65252 Mdot
.32374 .39979 Mdot
.33748 .4464 Mdot
.57364 .38241 Mdot
.57571 .2995 Mdot
.2837 .59299 Mdot
.43115 .65754 Mdot
.45273 .65274 Mdot
.28599 .4165 Mdot
.70186 .47856 Mdot
.47061 .67641 Mdot
.57907 .34766 Mdot
.71413 .65481 Mdot
.54674 .41594 Mdot
.54039 .59547 Mdot
.60247 .27561 Mdot
.5445 .54576 Mdot
.69965 .65091 Mdot
.28383 .60368 Mdot
.30397 .58529 Mdot
.32114 .59901 Mdot
.46718 .67644 Mdot
.6514 .48157 Mdot
.46376 .65432 Mdot
.45003 .19529 Mdot
.69917 .62088 Mdot
.49893 .82465 Mdot
.57311 .44324 Mdot
.58643 .37435 Mdot
.59813 .28362 Mdot
.60369 .5586 Mdot
.56136 .37441 Mdot
.29183 .59335 Mdot
.43499 .66133 Mdot
.25235 .63047 Mdot
.3572 .37493 Mdot
.45268 .19822 Mdot
.47312 .7118 Mdot
.54447 .57447 Mdot
.69123 .62927 Mdot
.75231 .54821 Mdot
.68098 .60106 Mdot
.49007 .7079 Mdot
.577 .3571 Mdot
.34171 .35365 Mdot
.59992 .82879 Mdot
.55491 .39679 Mdot
.46377 .66854 Mdot
.47579 .74048 Mdot
.59471 .30309 Mdot
.51838 .34171 Mdot
.25664 .63845 Mdot
.68578 .48784 Mdot
.65761 .62138 Mdot
.60705 .57582 Mdot
.71554 .44237 Mdot
.46107 .68432 Mdot
.43739 .66498 Mdot
.65171 .5999 Mdot
.31427 .41708 Mdot
.34949 .42565 Mdot
.42018 .4194 Mdot
.29227 .60389 Mdot
.58931 .39534 Mdot
.45282 .67796 Mdot
.31447 .39996 Mdot
.60637 .48467 Mdot
.31807 .59428 Mdot
.44768 .66794 Mdot
.55233 .40724 Mdot
.57531 .38818 Mdot
.68171 .63274 Mdot
.61639 .6042 Mdot
.60827 .56296 Mdot
.2915 .49765 Mdot
.6678 .47652 Mdot
.56743 .27833 Mdot
.58856 .38582 Mdot
.36941 .38601 Mdot
.57255 .58578 Mdot
.69517 .63566 Mdot
.53644 .42183 Mdot
.55331 .25508 Mdot
.36771 .37155 Mdot
.32818 .57756 Mdot
.57702 .56472 Mdot
.69082 .43338 Mdot
.55429 .40748 Mdot
.56272 .36898 Mdot
.58287 .2614 Mdot
.55988 .25227 Mdot
.43724 .68983 Mdot
.33441 .37073 Mdot
.66492 .62232 Mdot
.34183 .406 Mdot
.41812 .75141 Mdot
.57183 .29025 Mdot
.58305 .34658 Mdot
.33955 .36247 Mdot
.35025 .4029 Mdot
.31969 .61643 Mdot
.306 .579 Mdot
.45686 .73785 Mdot
.53697 .39302 Mdot
.56605 .54382 Mdot
.34283 .419 Mdot
.43453 .65508 Mdot
.67926 .63092 Mdot
.39618 .71978 Mdot
.57377 .41604 Mdot
.45768 .68062 Mdot
.5769 .5787 Mdot
.35401 .36987 Mdot
.46314 .7056 Mdot
.59915 .5791 Mdot
.69062 .61014 Mdot
.59882 .39538 Mdot
.47946 .7443 Mdot
.58546 .55334 Mdot
.53721 .39946 Mdot
.6027 .33964 Mdot
.57742 .30177 Mdot
.5867 .53389 Mdot
.44757 .72306 Mdot
.58442 .55667 Mdot
.34184 .4441 Mdot
.59008 .31019 Mdot
.43936 .65658 Mdot
.31993 .46033 Mdot
.57357 .30085 Mdot
.57713 .55 Mdot
.32765 .38726 Mdot
.42658 .76271 Mdot
.30843 .3914 Mdot
.72061 .55662 Mdot
.54554 .38187 Mdot
.45079 .675 Mdot
.68926 .63746 Mdot
.30949 .62122 Mdot
.27232 .54831 Mdot
.34423 .5345 Mdot
.45362 .70826 Mdot
.55155 .40015 Mdot
.3333 .41519 Mdot
.31507 .57874 Mdot
.37917 .40295 Mdot
.4868 .67466 Mdot
.48463 .68986 Mdot
.59704 .28684 Mdot
.68013 .62954 Mdot
.58158 .44066 Mdot
.43934 .65342 Mdot
.46231 .64357 Mdot
.46005 .21101 Mdot
.66007 .62572 Mdot
.5824 .25994 Mdot
.54381 .55519 Mdot
.55575 .43119 Mdot
.45154 .21888 Mdot
.5997 .56514 Mdot
.35879 .37633 Mdot
.5792 .37357 Mdot
.30696 .76052 Mdot
.44965 .71625 Mdot
.68592 .48747 Mdot
.26554 .6393 Mdot
.29848 .59567 Mdot
.46067 .69548 Mdot
.54916 .38688 Mdot
.39407 .71571 Mdot
.70526 .64154 Mdot
.59515 .25277 Mdot
.58488 .54781 Mdot
.28009 .40441 Mdot
.32495 .60503 Mdot
.56613 .62005 Mdot
.30754 .6212 Mdot
.32699 .59185 Mdot
.40021 .35378 Mdot
.57264 .38274 Mdot
.47241 .70733 Mdot
.48109 .67765 Mdot
.53826 .57519 Mdot
.49276 .65738 Mdot
.35566 .42548 Mdot
.29945 .75277 Mdot
.55345 .26065 Mdot
.57239 .41058 Mdot
.57454 .59207 Mdot
.58081 .5412 Mdot
.38979 .70131 Mdot
.57986 .38348 Mdot
.32966 .38089 Mdot
.4402 .65133 Mdot
.45506 .67099 Mdot
.57224 .27771 Mdot
.30396 .58467 Mdot
.66846 .59916 Mdot
.48016 .69621 Mdot
.69227 .51631 Mdot
.55074 .36688 Mdot
.29669 .63241 Mdot
.47874 .69562 Mdot
.71921 .75513 Mdot
.24134 .69995 Mdot
.31942 .38573 Mdot
.59888 .40188 Mdot
.33098 .43575 Mdot
.69431 .6508 Mdot
.48362 .66289 Mdot
.30151 .62429 Mdot
.57606 .57042 Mdot
.28161 .65154 Mdot
.45813 .67351 Mdot
.34098 .39633 Mdot
.57106 .37871 Mdot
.55341 .20932 Mdot
.55777 .41196 Mdot
.6538 .54808 Mdot
.66645 .6452 Mdot
.26933 .55117 Mdot
.33591 .6023 Mdot
.59925 .40106 Mdot
.66148 .62041 Mdot
.49254 .70591 Mdot
.47257 .68512 Mdot
.17041 .49203 Mdot
.60187 .56723 Mdot
.495 .67607 Mdot
.53666 .39707 Mdot
.4436 .64428 Mdot
.45421 .25436 Mdot
.29953 .59521 Mdot
.57164 .42607 Mdot
.4462 .67975 Mdot
.30707 .4095 Mdot
.67716 .48787 Mdot
.54665 .37366 Mdot
.56069 .54124 Mdot
.31131 .57673 Mdot
.45366 .19541 Mdot
.44226 .70959 Mdot
.55935 .42058 Mdot
.29204 .58614 Mdot
.63968 .61438 Mdot
.24482 .6235 Mdot
.33482 .38525 Mdot
.46792 .66903 Mdot
.32124 .60634 Mdot
.56897 .57306 Mdot
.66462 .63042 Mdot
.4935 .69211 Mdot
.44408 .6784 Mdot
.58174 .27601 Mdot
.54433 .56382 Mdot
.63594 .60226 Mdot
.36896 .40145 Mdot
.32617 .58135 Mdot
.58537 .26846 Mdot
.70254 .51886 Mdot
.52826 .40671 Mdot
.32988 .58511 Mdot
.43342 .17659 Mdot
.58271 .35941 Mdot
.57751 .41431 Mdot
.55929 .21223 Mdot
.33661 .44224 Mdot
.37295 .39468 Mdot
.69224 .46456 Mdot
.58312 .28523 Mdot
.52383 .43346 Mdot
.33518 .39053 Mdot
.34373 .39749 Mdot
.52354 .43269 Mdot
.58455 .274 Mdot
.42611 .412 Mdot
.31269 .5821 Mdot
.29882 .59264 Mdot
.34203 .41314 Mdot
.5985 .2833 Mdot
.30525 .56268 Mdot
.3137 .34461 Mdot
.48749 .6879 Mdot
.71473 .43062 Mdot
.3466 .40804 Mdot
.67748 .49192 Mdot
.32143 .57766 Mdot
.7365 .5098 Mdot
.7167 .41567 Mdot
.54386 .35394 Mdot
.57602 .38343 Mdot
.67166 .61007 Mdot
.58103 .57329 Mdot
.56329 .58387 Mdot
.32117 .5996 Mdot
.58295 .44032 Mdot
.3424 .37881 Mdot
.55012 .43839 Mdot
.72782 .5652 Mdot
.7477 .50579 Mdot
.56055 .2877 Mdot
.34547 .39122 Mdot
.35338 .38863 Mdot
.47958 .72247 Mdot
.4261 .66989 Mdot
.55691 .3458 Mdot
.30846 .57862 Mdot
.32506 .40952 Mdot
.33256 .59157 Mdot
.4624 .68427 Mdot
.47514 .70991 Mdot
.581 .58716 Mdot
.56456 .56054 Mdot
.46495 .69373 Mdot
.39281 .70597 Mdot
.70312 .51784 Mdot
.30061 .4401 Mdot
.45079 .18728 Mdot
.7525 .53533 Mdot
.52932 .22254 Mdot
.68923 .63969 Mdot
.53483 .59978 Mdot
.29112 .59054 Mdot
.59564 .4134 Mdot
.58126 .37183 Mdot
.58894 .56192 Mdot
.30025 .57331 Mdot
.69188 .62171 Mdot
.29899 .59599 Mdot
.66536 .63057 Mdot
.44435 .65611 Mdot
.54901 .39751 Mdot
.57347 .3583 Mdot
.31772 .617 Mdot
.4837 .71968 Mdot
.44783 .68142 Mdot
.69336 .63965 Mdot
.74846 .54208 Mdot
.45988 .67842 Mdot
.34728 .40704 Mdot
.25419 .35432 Mdot
.59859 .56821 Mdot
.55146 .3828 Mdot
.74015 .55106 Mdot
.58883 .31162 Mdot
.59915 .58524 Mdot
.57752 .56399 Mdot
.44373 .1957 Mdot
.55469 .3605 Mdot
.17435 .50507 Mdot
.56989 .58721 Mdot
.35655 .42868 Mdot
.46912 .70422 Mdot
.58226 .59111 Mdot
.55326 .54325 Mdot
.63969 .59934 Mdot
.58363 .59223 Mdot
.3492 .42368 Mdot
.33717 .43856 Mdot
.58574 .29615 Mdot
.46121 .17175 Mdot
.66787 .6274 Mdot
.69938 .62869 Mdot
.43887 .69057 Mdot
.37655 .59234 Mdot
.58408 .45151 Mdot
.70299 .62911 Mdot
.41351 .40255 Mdot
.59769 .28066 Mdot
.58411 .30302 Mdot
.57881 .29594 Mdot
.36065 .42963 Mdot
.53702 .35376 Mdot
.44065 .70103 Mdot
.34039 .39435 Mdot
.58995 .29535 Mdot
.53683 .42719 Mdot
.33759 .38073 Mdot
.32565 .58809 Mdot
.56721 .28972 Mdot
.33064 .41025 Mdot
.70606 .36368 Mdot
.32187 .5746 Mdot
.57518 .31612 Mdot
.54909 .81761 Mdot
.7397 .73943 Mdot
.3011 .59847 Mdot
.44959 .66699 Mdot
.45338 .68028 Mdot
.47268 .68144 Mdot
.37158 .4013 Mdot
.4701 .72384 Mdot
.36162 .39181 Mdot
.38745 .69219 Mdot
.69233 .41707 Mdot
.67199 .62681 Mdot
.49875 .66737 Mdot
.34038 .41271 Mdot
.45044 .20843 Mdot
.80807 .30655 Mdot
.55559 .41977 Mdot
.30347 .62523 Mdot
.70966 .63459 Mdot
.68948 .49151 Mdot
.68162 .61224 Mdot
.45734 .69835 Mdot
.69276 .42978 Mdot
.5547 .36709 Mdot
.20068 .48246 Mdot
.68845 .63556 Mdot
.34427 .399 Mdot
.57737 .27909 Mdot
.45242 .729 Mdot
.70262 .64248 Mdot
.6844 .62891 Mdot
.55869 .37631 Mdot
.34651 .43741 Mdot
.45314 .69378 Mdot
.30598 .57079 Mdot
.40272 .65176 Mdot
.57683 .47959 Mdot
.55104 .3612 Mdot
.58002 .41516 Mdot
.6672 .48492 Mdot
.39661 .71975 Mdot
.30821 .58523 Mdot
.70901 .56286 Mdot
.44791 .72022 Mdot
.73301 .56408 Mdot
.31071 .39128 Mdot
.4995 .66914 Mdot
.59876 .56364 Mdot
.59573 .58267 Mdot
.5575 .3907 Mdot
.81167 .32895 Mdot
.51768 .3506 Mdot
.30208 .56424 Mdot
.59454 .56573 Mdot
.48075 .72427 Mdot
.37436 .40121 Mdot
.54985 .62495 Mdot
.58554 .28897 Mdot
.30767 .56968 Mdot
.46698 .68144 Mdot
.83843 .38165 Mdot
.66776 .60804 Mdot
.6911 .4844 Mdot
.54243 .40464 Mdot
.55702 .38664 Mdot
.31425 .59952 Mdot
.28312 .61583 Mdot
.46068 .19756 Mdot
.68281 .59934 Mdot
.18224 .4656 Mdot
.30191 .55693 Mdot
.85012 .39772 Mdot
.57416 .54185 Mdot
.35396 .3832 Mdot
.55908 .58031 Mdot
.2825 .61142 Mdot
.5757 .3704 Mdot
.3428 .43976 Mdot
.58157 .58056 Mdot
.41323 .38836 Mdot
.5822 .30498 Mdot
.69566 .51627 Mdot
.56478 .39755 Mdot
.33356 .42856 Mdot
.33794 .38966 Mdot
.3193 .41901 Mdot
.5944 .57906 Mdot
.58492 .40014 Mdot
.5608 .41914 Mdot
.58185 .41179 Mdot
.46421 .19996 Mdot
.55101 .39515 Mdot
.33548 .35291 Mdot
.70481 .46893 Mdot
.32102 .77355 Mdot
.57497 .3594 Mdot
.32004 .60491 Mdot
.56058 .39387 Mdot
.65911 .61228 Mdot
.5965 .40477 Mdot
.58025 .30799 Mdot
.31056 .5878 Mdot
.55302 .24379 Mdot
.69832 .66637 Mdot
.5548 .35781 Mdot
.66951 .63758 Mdot
.27357 .51357 Mdot
.70262 .55946 Mdot
.45581 .23506 Mdot
.33607 .41144 Mdot
.48424 .66854 Mdot
.28412 .5868 Mdot
.47406 .71653 Mdot
.59089 .24058 Mdot
.55437 .56553 Mdot
.48931 .82037 Mdot
.713 .51798 Mdot
.57736 .37189 Mdot
.59122 .54217 Mdot
.32567 .38557 Mdot
.44671 .71202 Mdot
.50338 .23413 Mdot
.59828 .28198 Mdot
.7088 .62292 Mdot
.68746 .61136 Mdot
.55301 .59712 Mdot
.31726 .41938 Mdot
.45293 .25076 Mdot
.31347 .59839 Mdot
.46385 .67429 Mdot
.69594 .65841 Mdot
.40705 .41712 Mdot
.28765 .62446 Mdot
.38808 .69108 Mdot
.32237 .60724 Mdot
.58704 .37196 Mdot
.57079 .58931 Mdot
.35516 .46988 Mdot
.59216 .55599 Mdot
.53872 .42685 Mdot
.44468 .68082 Mdot
.6006 .56581 Mdot
.66861 .61559 Mdot
.32499 .60061 Mdot
.4711 .71255 Mdot
.56743 .37503 Mdot
.3324 .38924 Mdot
.6575 .3393 Mdot
.49095 .73589 Mdot
.57308 .29538 Mdot
.57291 .29509 Mdot
.28834 .42831 Mdot
.59184 .53401 Mdot
.25088 .57111 Mdot
.5944 .30537 Mdot
.35746 .55132 Mdot
.62008 .60745 Mdot
.44538 .78846 Mdot
.46728 .65649 Mdot
.47152 .69282 Mdot
.56661 .3613 Mdot
.43535 .65147 Mdot
.58184 .34768 Mdot
.44137 .71449 Mdot
.28726 .49286 Mdot
.52067 .41311 Mdot
.47565 .68933 Mdot
.56265 .58023 Mdot
.53467 .38997 Mdot
.32845 .37916 Mdot
.46777 .65365 Mdot
.54351 .3542 Mdot
.45483 .79306 Mdot
.31854 .61704 Mdot
.59458 .57981 Mdot
.62789 .48761 Mdot
.31794 .58286 Mdot
.35637 .42154 Mdot
.59733 .36334 Mdot
.70581 .63329 Mdot
.35688 .39223 Mdot
.59182 .59711 Mdot
.68022 .6279 Mdot
.69838 .48793 Mdot
.35613 .41121 Mdot
.59751 .56407 Mdot
.69184 .61155 Mdot
.53579 .56431 Mdot
.4708 .68988 Mdot
.479 .74074 Mdot
.58197 .55286 Mdot
.55764 .36595 Mdot
.47264 .73002 Mdot
.30485 .60777 Mdot
.54091 .38833 Mdot
.4526 .67541 Mdot
.5919 .5741 Mdot
.55247 .41441 Mdot
.58269 .2864 Mdot
.45521 .21362 Mdot
.60318 .54142 Mdot
.6693 .6221 Mdot
.31652 .41138 Mdot
.56377 .42165 Mdot
.67022 .63384 Mdot
.49659 .71605 Mdot
.55169 .42212 Mdot
.32044 .40495 Mdot
.42079 .36665 Mdot
.42927 .65864 Mdot
.32478 .5728 Mdot
.47962 .67405 Mdot
.68426 .6522 Mdot
.80598 .29733 Mdot
.56976 .58597 Mdot
.59972 .25767 Mdot
.59163 .40827 Mdot
.48174 .66442 Mdot
.33814 .38617 Mdot
.18453 .44956 Mdot
.59852 .39907 Mdot
.54875 .42009 Mdot
.55408 .3808 Mdot
.39548 .65815 Mdot
.36845 .4119 Mdot
.55256 .38138 Mdot
.58858 .61044 Mdot
.57999 .41792 Mdot
.6944 .64796 Mdot
.5143 .82504 Mdot
.60267 .57756 Mdot
.42219 .16944 Mdot
.58381 .58141 Mdot
.47974 .68978 Mdot
.70615 .36291 Mdot
.62545 .48649 Mdot
.42672 .71061 Mdot
.35707 .42193 Mdot
.3758 .45122 Mdot
.47584 .70817 Mdot
.4245 .76025 Mdot
.58835 .28904 Mdot
.57909 .27966 Mdot
.53641 .38213 Mdot
.45756 .69861 Mdot
.43247 .66869 Mdot
.55678 .56191 Mdot
.59332 .5443 Mdot
.58139 .32589 Mdot
.45661 .65697 Mdot
.54925 .39562 Mdot
.59519 .29809 Mdot
.28704 .62494 Mdot
.31955 .3888 Mdot
.29654 .62361 Mdot
.29263 .62738 Mdot
.5227 .22639 Mdot
.66625 .4761 Mdot
.29169 .60252 Mdot
.28876 .58325 Mdot
.39007 .66874 Mdot
.52143 .25582 Mdot
.69053 .64884 Mdot
.51546 .3541 Mdot
.4817 .71701 Mdot
.58333 .40153 Mdot
.36768 .41458 Mdot
.61317 .55749 Mdot
.19621 .42256 Mdot
.81533 .47791 Mdot
.59511 .27111 Mdot
.45669 .72616 Mdot
.58515 .55238 Mdot
.5906 .55015 Mdot
.7301 .56059 Mdot
.55026 .39263 Mdot
.4307 .65712 Mdot
.51004 .26966 Mdot
.29703 .55948 Mdot
.39301 .71053 Mdot
.32159 .42959 Mdot
.55919 .39625 Mdot
.36793 .39084 Mdot
.32673 .57002 Mdot
.67652 .63883 Mdot
.66533 .61196 Mdot
.55671 .35663 Mdot
.5764 .30617 Mdot
.35542 .54787 Mdot
.57911 .28591 Mdot
.58869 .27251 Mdot
.58281 .55755 Mdot
.57959 .26144 Mdot
.55897 .42144 Mdot
.52102 .38928 Mdot
.60249 .58255 Mdot
.29323 .62513 Mdot
.50806 .25213 Mdot
.57935 .54951 Mdot
.60176 .37797 Mdot
.32915 .57162 Mdot
.5812 .28889 Mdot
.30983 .6053 Mdot
.39792 .72124 Mdot
.29624 .61273 Mdot
.66591 .62051 Mdot
.43331 .64062 Mdot
.45586 .19144 Mdot
.33207 .41363 Mdot
.30165 .58372 Mdot
.69196 .61044 Mdot
.31156 .60742 Mdot
.48638 .7111 Mdot
.28058 .58017 Mdot
.2834 .36239 Mdot
.69077 .51506 Mdot
.53576 .22225 Mdot
.29501 .56198 Mdot
.42839 .66426 Mdot
.34195 .41396 Mdot
.36892 .57459 Mdot
.59919 .38374 Mdot
.66515 .60884 Mdot
.5583 .38902 Mdot
.32641 .59672 Mdot
.46986 .72704 Mdot
.45387 .23473 Mdot
.66817 .62003 Mdot
.4487 .19157 Mdot
.46046 .65663 Mdot
.59317 .37565 Mdot
.34176 .58482 Mdot
.28552 .53714 Mdot
.33153 .6069 Mdot
.69826 .41434 Mdot
.5609 .54774 Mdot
.706 .60947 Mdot
.35738 .39919 Mdot
.57604 .53989 Mdot
.79979 .6152 Mdot
.30889 .50185 Mdot
.33945 .37148 Mdot
.50041 .68486 Mdot
.55155 .36482 Mdot
.58268 .25799 Mdot
.56256 .57194 Mdot
.32688 .42001 Mdot
.58296 .26177 Mdot
.58739 .58615 Mdot
.70628 .4644 Mdot
.32053 .42513 Mdot
.49537 .69702 Mdot
.53644 .39317 Mdot
.32103 .62066 Mdot
.33666 .57726 Mdot
.56473 .58744 Mdot
.30257 .62159 Mdot
.60194 .3745 Mdot
.35261 .41032 Mdot
.58543 .29497 Mdot
.6984 .64846 Mdot
.39413 .45042 Mdot
.61239 .57222 Mdot
.72402 .65689 Mdot
.54179 .4125 Mdot
.47407 .70859 Mdot
.27782 .65144 Mdot
.5786 .4319 Mdot
.33718 .39308 Mdot
.59557 .39595 Mdot
.58095 .26158 Mdot
.5789 .28258 Mdot
.46359 .67433 Mdot
.6762 .48911 Mdot
.55011 .39629 Mdot
.31293 .5686 Mdot
.51672 .42327 Mdot
.57798 .44016 Mdot
.69419 .60555 Mdot
.5806 .30826 Mdot
.33886 .5708 Mdot
.28996 .42758 Mdot
.47221 .70592 Mdot
.34676 .37977 Mdot
.36165 .35381 Mdot
.35728 .42 Mdot
.30925 .42775 Mdot
.59376 .30676 Mdot
.1682 .49828 Mdot
.45407 .25302 Mdot
.53938 .21593 Mdot
.35659 .35658 Mdot
.24955 .65547 Mdot
.33854 .37108 Mdot
.35663 .42158 Mdot
.22923 .3771 Mdot
.35879 .42262 Mdot
.5596 .36816 Mdot
.59389 .39108 Mdot
.55478 .26781 Mdot
.40362 .65014 Mdot
.55885 .41315 Mdot
.59634 .58886 Mdot
.71023 .63218 Mdot
.31294 .4099 Mdot
.57712 .56803 Mdot
.69038 .49301 Mdot
.56039 .58876 Mdot
.55945 .37602 Mdot
.54635 .40184 Mdot
.57729 .29085 Mdot
.75708 .50367 Mdot
.41071 .64574 Mdot
.34257 .43274 Mdot
.57927 .44064 Mdot
.24473 .61976 Mdot
.53787 .38744 Mdot
.59043 .41512 Mdot
.53515 .35637 Mdot
.47243 .70741 Mdot
.37286 .41447 Mdot
.56607 .55299 Mdot
.38576 .45708 Mdot
.56092 .40562 Mdot
.61816 .57422 Mdot
.71492 .64598 Mdot
.54882 .38549 Mdot
.34893 .43388 Mdot
.58164 .26183 Mdot
.36524 .37072 Mdot
.35857 .40713 Mdot
.55082 .42125 Mdot
.31385 .41043 Mdot
.37258 .38808 Mdot
.57978 .27975 Mdot
.46208 .73028 Mdot
.28942 .49841 Mdot
.55381 .36918 Mdot
.67089 .61799 Mdot
.57854 .38091 Mdot
.69033 .65011 Mdot
.58321 .59171 Mdot
.58552 .55548 Mdot
.49892 .33778 Mdot
.4384 .66224 Mdot
.70686 .6173 Mdot
.45222 .64126 Mdot
.59945 .42561 Mdot
.41358 .39644 Mdot
.27783 .59354 Mdot
.49589 .73885 Mdot
.58532 .55731 Mdot
.66182 .54972 Mdot
.535 .45123 Mdot
.29554 .61604 Mdot
.34358 .36507 Mdot
.49761 .26703 Mdot
.58525 .53934 Mdot
.49533 .69924 Mdot
.48245 .68058 Mdot
.31122 .50361 Mdot
.23385 .37281 Mdot
.57304 .35903 Mdot
.58848 .54005 Mdot
.59911 .3385 Mdot
.58156 .57416 Mdot
.55845 .56158 Mdot
.44372 .67432 Mdot
.55353 .41344 Mdot
.71023 .46174 Mdot
.45556 .68308 Mdot
.69439 .62829 Mdot
.36003 .37747 Mdot
.66808 .6329 Mdot
.22067 .45809 Mdot
.45986 .19599 Mdot
.46186 .69121 Mdot
.60583 .56962 Mdot
.57835 .40887 Mdot
.34863 .43706 Mdot
.37946 .4 Mdot
.32591 .37993 Mdot
.70694 .64536 Mdot
.44378 .65196 Mdot
.45628 .7985 Mdot
.5701 .38024 Mdot
.34975 .40082 Mdot
.70957 .66067 Mdot
.5757 .38951 Mdot
.30552 .58117 Mdot
.58359 .26407 Mdot
.34517 .4043 Mdot
.60058 .26278 Mdot
.35789 .4002 Mdot
.48186 .68403 Mdot
.56151 .35621 Mdot
.54272 .37019 Mdot
.69847 .55934 Mdot
.69161 .62101 Mdot
.36282 .36536 Mdot
.65713 .4771 Mdot
.55553 .43121 Mdot
.73331 .55667 Mdot
.54499 .39317 Mdot
.53837 .22099 Mdot
.54921 .55278 Mdot
.5846 .58792 Mdot
.5942 .4025 Mdot
.55106 .37209 Mdot
.3783 .4039 Mdot
.45537 .25457 Mdot
.46409 .19831 Mdot
.32879 .57361 Mdot
.33461 .37177 Mdot
.45498 .6869 Mdot
.46948 .65319 Mdot
.47361 .7206 Mdot
.68923 .65549 Mdot
.58389 .29192 Mdot
.57592 .3648 Mdot
.30919 .56333 Mdot
.70423 .62589 Mdot
.34962 .39217 Mdot
.67687 .63334 Mdot
.671 .48144 Mdot
.67285 .61481 Mdot
.55472 .57536 Mdot
.23406 .68017 Mdot
.59455 .29937 Mdot
.68259 .62319 Mdot
.31898 .39245 Mdot
.51076 .41085 Mdot
.53207 .36855 Mdot
.45232 .20621 Mdot
.70985 .62491 Mdot
.50205 .69648 Mdot
.54006 .40833 Mdot
.6829 .40977 Mdot
.31565 .60304 Mdot
.66404 .62747 Mdot
.32091 .60911 Mdot
.59095 .26815 Mdot
.35829 .45539 Mdot
.3375 .4001 Mdot
.28098 .62282 Mdot
.58709 .41709 Mdot
.66365 .62672 Mdot
.46541 .69098 Mdot
.52054 .25783 Mdot
.3868 .67845 Mdot
.62193 .56701 Mdot
.72478 .55923 Mdot
.43888 .69627 Mdot
.53474 .24321 Mdot
.30619 .61778 Mdot
.55848 .44101 Mdot
.60184 .27743 Mdot
.54909 .4274 Mdot
.44948 .68667 Mdot
.47206 .69366 Mdot
.44101 .78323 Mdot
.54621 .3624 Mdot
.53444 .35844 Mdot
.27812 .39522 Mdot
.44043 .65251 Mdot
.35775 .4185 Mdot
.32894 .42501 Mdot
.44931 .66817 Mdot
.35286 .36104 Mdot
.68236 .62891 Mdot
.69473 .45136 Mdot
.30464 .61737 Mdot
.33954 .5868 Mdot
.46353 .69339 Mdot
.44352 .69339 Mdot
.47403 .70952 Mdot
.58864 .26312 Mdot
.35805 .41179 Mdot
.57498 .34976 Mdot
.56329 .38926 Mdot
.52941 .38571 Mdot
.32862 .43626 Mdot
.59949 .39435 Mdot
.52847 .43 Mdot
.71098 .64466 Mdot
.48073 .69396 Mdot
.33317 .58712 Mdot
.65876 .34545 Mdot
.3154 .56742 Mdot
.57201 .42388 Mdot
.29221 .4927 Mdot
.34612 .36588 Mdot
.67772 .61085 Mdot
.57872 .30436 Mdot
.6669 .6148 Mdot
.28683 .62499 Mdot
.27962 .39298 Mdot
.7006 .48283 Mdot
.57161 .35134 Mdot
.66385 .48174 Mdot
.637 .77401 Mdot
.34727 .34592 Mdot
.32423 .58161 Mdot
.58716 .30799 Mdot
.55653 .58531 Mdot
.59083 .3238 Mdot
.56919 .36244 Mdot
.57261 .44273 Mdot
.67681 .41065 Mdot
.58533 .41375 Mdot
.31749 .38835 Mdot
.52025 .42382 Mdot
.60535 .55843 Mdot
.5321 .39469 Mdot
.17756 .49992 Mdot
.56668 .41015 Mdot
.56132 .35291 Mdot
.58614 .37889 Mdot
.56042 .43439 Mdot
.32696 .4383 Mdot
.58119 .29882 Mdot
.31914 .56851 Mdot
.69561 .45112 Mdot
.30376 .61615 Mdot
.46323 .69897 Mdot
.60909 .54875 Mdot
.3464 .44329 Mdot
.66722 .61399 Mdot
.40615 .60555 Mdot
.68626 .40946 Mdot
.48001 .72217 Mdot
.68287 .55772 Mdot
.66327 .59896 Mdot
.55795 .56839 Mdot
.67769 .64826 Mdot
.44582 .68023 Mdot
.30221 .58945 Mdot
.57831 .35759 Mdot
.3489 .41969 Mdot
.32774 .40871 Mdot
.53328 .39771 Mdot
.28604 .50536 Mdot
.33704 .57905 Mdot
.49694 .66345 Mdot
.57909 .36337 Mdot
.5712 .42629 Mdot
.36711 .37788 Mdot
.45722 .72296 Mdot
.53705 .45068 Mdot
.69732 .64114 Mdot
.53848 .3928 Mdot
.60075 .55166 Mdot
.66971 .48167 Mdot
.32566 .57213 Mdot
.59528 .57241 Mdot
.57776 .40373 Mdot
.67706 .47539 Mdot
.59449 .25415 Mdot
.57934 .60977 Mdot
.42824 .68075 Mdot
.54911 .41989 Mdot
.54043 .37614 Mdot
.32128 .42686 Mdot
.30578 .6187 Mdot
.33604 .38578 Mdot
.27274 .38639 Mdot
.58558 .55601 Mdot
.32604 .61201 Mdot
.55947 .43367 Mdot
.31682 .55651 Mdot
.58211 .26619 Mdot
.56488 .38048 Mdot
.32427 .58347 Mdot
.36259 .40354 Mdot
.18517 .46424 Mdot
.5069 .25308 Mdot
.58931 .26962 Mdot
.57911 .38376 Mdot
.404 .65073 Mdot
.61348 .55841 Mdot
.58751 .36008 Mdot
.32593 .40984 Mdot
.57487 .38805 Mdot
.29694 .56597 Mdot
.67336 .63368 Mdot
.33434 .39458 Mdot
.44795 .71712 Mdot
.47609 .67859 Mdot
.42531 .66762 Mdot
.55398 .57169 Mdot
.57931 .26196 Mdot
.31749 .41393 Mdot
.32353 .42078 Mdot
.64546 .48152 Mdot
.4795 .6899 Mdot
.68598 .64024 Mdot
.53544 .37897 Mdot
.59271 .54147 Mdot
.34058 .60157 Mdot
.41994 .16864 Mdot
.69996 .47865 Mdot
.70198 .6581 Mdot
.57625 .48064 Mdot
.58278 .56082 Mdot
.57964 .41149 Mdot
.66389 .6259 Mdot
.44979 .67012 Mdot
.58921 .25202 Mdot
.6102 .6097 Mdot
.50256 .7003 Mdot
.45674 .71448 Mdot
.31801 .55792 Mdot
.43638 .70331 Mdot
.66147 .62592 Mdot
.56764 .58539 Mdot
.32978 .40177 Mdot
.54853 .38911 Mdot
.57226 .55607 Mdot
.48503 .69835 Mdot
.56836 .54537 Mdot
.58811 .37059 Mdot
.36448 .37546 Mdot
.4797 .71607 Mdot
.56115 .37217 Mdot
.59659 .30023 Mdot
.4561 .21329 Mdot
.46124 .72834 Mdot
.58948 .3536 Mdot
.55994 .62408 Mdot
.46212 .71562 Mdot
.44781 .68662 Mdot
.5522 .42292 Mdot
.65992 .60333 Mdot
.56114 .40167 Mdot
.3052 .58422 Mdot
.66801 .48844 Mdot
.31834 .61673 Mdot
.73395 .56266 Mdot
.53663 .408 Mdot
.59217 .34181 Mdot
.41434 .39214 Mdot
.71924 .66975 Mdot
.75296 .53758 Mdot
.56649 .41988 Mdot
.37585 .39255 Mdot
.67593 .49146 Mdot
.68459 .51294 Mdot
.29605 .35258 Mdot
.68161 .64591 Mdot
.32037 .6005 Mdot
.54627 .36556 Mdot
.18426 .49794 Mdot
.69047 .64612 Mdot
.7318 .56068 Mdot
.59792 .40948 Mdot
.344 .39369 Mdot
.5709 .35974 Mdot
.33391 .40475 Mdot
.58065 .39303 Mdot
.45384 .22648 Mdot
.355 .54771 Mdot
.69754 .41429 Mdot
.56193 .57865 Mdot
.28536 .53724 Mdot
.53611 .22141 Mdot
.68376 .6327 Mdot
.60161 .27495 Mdot
.58684 .56407 Mdot
.29898 .59653 Mdot
.31121 .64585 Mdot
.47591 .70954 Mdot
.3053 .57319 Mdot
.35368 .37975 Mdot
.48048 .72619 Mdot
.57267 .54119 Mdot
.60325 .35632 Mdot
.66021 .61974 Mdot
.32683 .61151 Mdot
.54769 .38069 Mdot
.53192 .4188 Mdot
.39475 .65901 Mdot
.52489 .82545 Mdot
.32518 .36614 Mdot
.44859 .1862 Mdot
.27934 .39316 Mdot
.69658 .6256 Mdot
.46574 .73077 Mdot
.57992 .3724 Mdot
.55177 .40975 Mdot
.45448 .71354 Mdot
.34918 .43727 Mdot
.69153 .60827 Mdot
.70938 .61211 Mdot
.30316 .56353 Mdot
.57066 .8283 Mdot
.333 .3961 Mdot
.56831 .82891 Mdot
.448 .79011 Mdot
.24454 .36293 Mdot
.75055 .54065 Mdot
.31446 .58329 Mdot
.56976 .82897 Mdot
.34677 .39639 Mdot
.59115 .39664 Mdot
.5944 .56163 Mdot
.55463 .56363 Mdot
.36609 .3836 Mdot
.46121 .7027 Mdot
.65715 .60309 Mdot
.56422 .36039 Mdot
.54481 .60648 Mdot
.37921 .40306 Mdot
.44475 .65493 Mdot
.57516 .57497 Mdot
.33279 .58169 Mdot
.57723 .38709 Mdot
.7092 .6437 Mdot
.31369 .58499 Mdot
.59752 .58178 Mdot
.69332 .43249 Mdot
.59704 .36272 Mdot
.57519 .30246 Mdot
.3133 .60285 Mdot
.57938 .4777 Mdot
.54024 .38384 Mdot
.30635 .61779 Mdot
.54452 .57744 Mdot
.26279 .55273 Mdot
.5513 .46315 Mdot
.30888 .5019 Mdot
.48988 .72072 Mdot
.44592 .72094 Mdot
.5233 .6902 Mdot
.42318 .64176 Mdot
.29603 .60672 Mdot
.57412 .56046 Mdot
.50615 .82713 Mdot
.30852 .61908 Mdot
.58512 .42541 Mdot
.5488 .36473 Mdot
.50889 .27062 Mdot
.60104 .57897 Mdot
.58105 .5832 Mdot
.32548 .46455 Mdot
.58931 .30147 Mdot
.57495 .57347 Mdot
.54227 .39268 Mdot
.33733 .43725 Mdot
.32215 .57653 Mdot
.85168 .52411 Mdot
.28248 .59815 Mdot
.57886 .25449 Mdot
.47959 .71986 Mdot
.48779 .7235 Mdot
.54984 .3868 Mdot
.46975 .60593 Mdot
.84688 .39171 Mdot
.54829 .36471 Mdot
.57915 .30485 Mdot
.73245 .56439 Mdot
.53219 .39688 Mdot
.32812 .3703 Mdot
.60334 .56429 Mdot
.32924 .43267 Mdot
.31766 .5855 Mdot
.68257 .6462 Mdot
.69309 .66648 Mdot
.32012 .5999 Mdot
.56155 .40936 Mdot
.60753 .58208 Mdot
.5564 .38466 Mdot
.59022 .39017 Mdot
.67947 .47805 Mdot
.70086 .65617 Mdot
.46896 .709 Mdot
.66509 .6155 Mdot
.35726 .42259 Mdot
.43819 .17893 Mdot
.68207 .63442 Mdot
.52076 .25689 Mdot
.65886 .48342 Mdot
.51294 .82391 Mdot
.32747 .407 Mdot
.69434 .65115 Mdot
.31983 .60299 Mdot
.64819 .50194 Mdot
.53865 .25154 Mdot
.30778 .57029 Mdot
.58903 .38943 Mdot
.33257 .43091 Mdot
.28551 .42243 Mdot
.33834 .57524 Mdot
.32613 .39043 Mdot
.56107 .46861 Mdot
.5915 .27514 Mdot
.32121 .56838 Mdot
.75297 .52019 Mdot
.33568 .60275 Mdot
.51505 .23174 Mdot
.58102 .27002 Mdot
.33607 .39393 Mdot
.54966 .20889 Mdot
.28083 .38685 Mdot
.58239 .58623 Mdot
.59596 .37905 Mdot
.68515 .63751 Mdot
.65146 .4814 Mdot
.45252 .7237 Mdot
.30744 .41015 Mdot
.34248 .40989 Mdot
.34133 .60229 Mdot
.32644 .39211 Mdot
.34718 .36352 Mdot
.28152 .62355 Mdot
.3374 .3702 Mdot
.56049 .40629 Mdot
.46378 .17191 Mdot
.32522 .3848 Mdot
.31388 .59532 Mdot
.70675 .64206 Mdot
.31918 .38695 Mdot
.42885 .76675 Mdot
.53616 .39449 Mdot
.4851 .67323 Mdot
.6462 .60255 Mdot
.32933 .4385 Mdot
.68615 .63467 Mdot
.48512 .70358 Mdot
.71595 .62974 Mdot
.34108 .56435 Mdot
.33854 .56516 Mdot
.5556 .54145 Mdot
.31499 .50652 Mdot
.35876 .42231 Mdot
.47714 .72882 Mdot
.53997 .36655 Mdot
.58567 .37099 Mdot
.65812 .63459 Mdot
.36765 .36946 Mdot
.2793 .5088 Mdot
.57634 .56926 Mdot
.39699 .44854 Mdot
.33383 .57601 Mdot
.49797 .66562 Mdot
.70202 .48429 Mdot
.38165 .62028 Mdot
.60599 .55987 Mdot
.58441 .561 Mdot
.55376 .38036 Mdot
.70734 .56134 Mdot
.66642 .63308 Mdot
.25482 .66125 Mdot
.59628 .26612 Mdot
.44929 .70906 Mdot
.58364 .39477 Mdot
.59197 .29244 Mdot
.56165 .42172 Mdot
.69822 .65883 Mdot
.29576 .57913 Mdot
.33004 .41286 Mdot
.69138 .65131 Mdot
.47558 .67784 Mdot
.71296 .38206 Mdot
.5861 .3578 Mdot
.58198 .34696 Mdot
.46187 .71027 Mdot
.35169 .42598 Mdot
.46835 .6982 Mdot
.30496 .61724 Mdot
.67873 .63246 Mdot
.58423 .26161 Mdot
.60168 .5781 Mdot
.48081 .66318 Mdot
.30021 .58535 Mdot
.4629 .73147 Mdot
.30745 .55586 Mdot
.58644 .55878 Mdot
.58605 .34673 Mdot
.43227 .65292 Mdot
.58625 .54492 Mdot
.45919 .3085 Mdot
.69024 .43319 Mdot
.27436 .34375 Mdot
.45912 .70258 Mdot
.4303 .72171 Mdot
.31358 .58886 Mdot
.28506 .61368 Mdot
.51427 .22829 Mdot
.81211 .33336 Mdot
.52441 .43392 Mdot
.26361 .52806 Mdot
.3036 .61723 Mdot
.30714 .60125 Mdot
.4701 .70159 Mdot
.36383 .4018 Mdot
.415 .38228 Mdot
.49091 .70934 Mdot
.73978 .54727 Mdot
.34969 .39255 Mdot
.55384 .26479 Mdot
.45758 .65217 Mdot
.57711 .28188 Mdot
.45306 .23515 Mdot
.71358 .64237 Mdot
.71858 .55872 Mdot
.27914 .58623 Mdot
.565 .36796 Mdot
.16738 .49565 Mdot
.47743 .70653 Mdot
.57317 .54488 Mdot
.24912 .61978 Mdot
.53696 .42682 Mdot
.5842 .39795 Mdot
.56841 .39644 Mdot
.65518 .62144 Mdot
.45422 .27038 Mdot
.57148 .36819 Mdot
.69325 .42386 Mdot
.57081 .26622 Mdot
.48404 .7409 Mdot
.66521 .61706 Mdot
.67196 .55583 Mdot
.41215 .73958 Mdot
.37999 .46189 Mdot
.57271 .44316 Mdot
.28545 .59402 Mdot
.58861 .30104 Mdot
.32634 .58505 Mdot
.32782 .56559 Mdot
.59111 .82872 Mdot
.32533 .41367 Mdot
.59404 .26505 Mdot
.44067 .66619 Mdot
.41639 .38442 Mdot
.59087 .29073 Mdot
.44215 .18159 Mdot
.30561 .62939 Mdot
.80499 .2936 Mdot
.28725 .61574 Mdot
.56126 .5521 Mdot
.35046 .37506 Mdot
.37747 .39254 Mdot
.66414 .48053 Mdot
.35925 .41529 Mdot
.42008 .64261 Mdot
.317 .41016 Mdot
.72817 .72065 Mdot
.28824 .35921 Mdot
.30937 .59183 Mdot
.34129 .58037 Mdot
.58061 .29308 Mdot
.55634 .40427 Mdot
.70843 .46358 Mdot
.57655 .57017 Mdot
.59871 .37285 Mdot
.45533 .68247 Mdot
.43564 .7761 Mdot
.22582 .62796 Mdot
.34041 .36871 Mdot
.29677 .59137 Mdot
.58449 .39606 Mdot
.58313 .26845 Mdot
.5944 .38818 Mdot
.37951 .59534 Mdot
.57558 .22985 Mdot
.56229 .38765 Mdot
.5826 .29178 Mdot
.48683 .71554 Mdot
.39558 .65993 Mdot
.23717 .37 Mdot
.58178 .8283 Mdot
.55253 .41535 Mdot
.70031 .62527 Mdot
.69401 .65747 Mdot
.52223 .37419 Mdot
.5288 .51156 Mdot
.58708 .48049 Mdot
.54805 .37933 Mdot
.71123 .37628 Mdot
.49598 .69363 Mdot
.55811 .58526 Mdot
.484 .69517 Mdot
.36537 .35698 Mdot
.57287 .59044 Mdot
.45113 .67767 Mdot
.71554 .42767 Mdot
.58011 .5542 Mdot
.25387 .56555 Mdot
.6983 .64905 Mdot
.54106 .38993 Mdot
.49127 .24527 Mdot
.44143 .65157 Mdot
.30488 .58902 Mdot
.34131 .37421 Mdot
.32349 .57206 Mdot
.42815 .64187 Mdot
.73824 .55534 Mdot
.58846 .58426 Mdot
.28552 .58935 Mdot
.57784 .30963 Mdot
.70136 .62388 Mdot
.29234 .62026 Mdot
.57314 .26544 Mdot
.51966 .38878 Mdot
.82673 .37183 Mdot
.54628 .35523 Mdot
.43771 .77885 Mdot
.31498 .6193 Mdot
.55659 .5863 Mdot
.54907 .39043 Mdot
.46699 .66038 Mdot
.5377 .55685 Mdot
.55756 .3828 Mdot
.4417 .70573 Mdot
.54656 .3695 Mdot
.6643 .62372 Mdot
.32418 .42987 Mdot
.67938 .49418 Mdot
.73211 .66449 Mdot
.68566 .648 Mdot
.68478 .40607 Mdot
.59429 .37061 Mdot
.44313 .62312 Mdot
.34269 .39032 Mdot
.57367 .42266 Mdot
.7442 .65887 Mdot
.36155 .38498 Mdot
.34974 .38202 Mdot
.58485 .25158 Mdot
.29202 .56976 Mdot
.46592 .70972 Mdot
.68623 .61383 Mdot
.39137 .70533 Mdot
.56536 .37001 Mdot
.60082 .26889 Mdot
.69137 .64832 Mdot
.31188 .57737 Mdot
.59311 .26743 Mdot
.23899 .56816 Mdot
.69518 .44804 Mdot
.29903 .62615 Mdot
.57056 .4422 Mdot
.57795 .22335 Mdot
.35842 .43093 Mdot
.1694 .49838 Mdot
.35424 .54693 Mdot
.47997 .67897 Mdot
.57302 .5734 Mdot
.42368 .17148 Mdot
.70652 .64608 Mdot
.41386 .36891 Mdot
.58698 .37034 Mdot
.58244 .37916 Mdot
.34093 .43887 Mdot
.56596 .34945 Mdot
.34236 .36683 Mdot
.42783 .7647 Mdot
.81121 .32429 Mdot
.33033 .40692 Mdot
.34141 .40371 Mdot
.56656 .29038 Mdot
.43953 .64381 Mdot
.35917 .37555 Mdot
.54212 .36864 Mdot
.42766 .6419 Mdot
.55228 .60604 Mdot
.69582 .61143 Mdot
.65237 .61011 Mdot
.33044 .36615 Mdot
.54124 .24821 Mdot
.57228 .27559 Mdot
.49427 .32432 Mdot
.58652 .48587 Mdot
.29581 .60803 Mdot
.52998 .40775 Mdot
.57953 .56638 Mdot
.48273 .70276 Mdot
.53666 .35865 Mdot
.54197 .39509 Mdot
.333 .41706 Mdot
.71593 .63425 Mdot
.31752 .61361 Mdot
.58307 .54512 Mdot
.42385 .66741 Mdot
.69571 .63399 Mdot
.35182 .36172 Mdot
.53025 .22317 Mdot
.61175 .56821 Mdot
.59185 .54215 Mdot
.57701 .41553 Mdot
.55275 .42177 Mdot
.60875 .56441 Mdot
.32075 .59706 Mdot
.48052 .67793 Mdot
.56629 .55381 Mdot
.63508 .48443 Mdot
.71304 .45288 Mdot
.57065 .41619 Mdot
.31964 .39906 Mdot
.29785 .59439 Mdot
.58365 .58418 Mdot
.50076 .8255 Mdot
.53331 .38458 Mdot
.55513 .25878 Mdot
.67431 .59347 Mdot
.57762 .56272 Mdot
.41519 .38206 Mdot
.67104 .60987 Mdot
.58142 .26999 Mdot
.69514 .42065 Mdot
.6009 .38634 Mdot
.55935 .44107 Mdot
.44791 .67212 Mdot
.32791 .59824 Mdot
.56052 .53902 Mdot
.48022 .69483 Mdot
.34784 .38042 Mdot
.49638 .32739 Mdot
.3328 .42685 Mdot
.32203 .41757 Mdot
.31035 .42618 Mdot
.33021 .57533 Mdot
.4234 .17044 Mdot
.60989 .56123 Mdot
.57038 .35703 Mdot
.29123 .59252 Mdot
.35647 .37139 Mdot
.59817 .40328 Mdot
.34569 .36592 Mdot
.36312 .36447 Mdot
.60106 .38303 Mdot
.58225 .28637 Mdot
.69278 .41493 Mdot
.55567 .24622 Mdot
.66341 .61141 Mdot
.35516 .43072 Mdot
.54856 .25254 Mdot
.5779 .37163 Mdot
.54739 .40273 Mdot
.58052 .29508 Mdot
.68524 .65073 Mdot
.49774 .33804 Mdot
.58826 .37464 Mdot
.71 .5649 Mdot
.59477 .41165 Mdot
.36866 .3702 Mdot
.27118 .54933 Mdot
.57786 .25513 Mdot
.48347 .72242 Mdot
.3476 .43815 Mdot
.71401 .6428 Mdot
.33412 .45166 Mdot
.58597 .31372 Mdot
.30797 .60773 Mdot
.3451 .4042 Mdot
.49225 .70172 Mdot
.30721 .5853 Mdot
.33592 .60226 Mdot
.57914 .29548 Mdot
.47253 .67009 Mdot
.71642 .63572 Mdot
.3333 .60005 Mdot
.59363 .31904 Mdot
.30826 .59153 Mdot
.35847 .33365 Mdot
.57916 .34464 Mdot
.69462 .42415 Mdot
.56501 .57002 Mdot
.55002 .55012 Mdot
.32464 .61141 Mdot
.69766 .64247 Mdot
.59353 .26747 Mdot
.32841 .37799 Mdot
.70492 .63459 Mdot
.45422 .23836 Mdot
.48689 .72369 Mdot
.28546 .42152 Mdot
.38734 .68519 Mdot
.36711 .40688 Mdot
.7218 .55871 Mdot
.71078 .6516 Mdot
.59427 .53985 Mdot
.68674 .4869 Mdot
.57806 .57735 Mdot
.5405 .35492 Mdot
.59435 .26779 Mdot
.56193 .40651 Mdot
.47852 .72125 Mdot
.6553 .62022 Mdot
.32225 .38939 Mdot
.59189 .61901 Mdot
.31618 .57357 Mdot
.51675 .39335 Mdot
.56824 .54868 Mdot
.58879 .26796 Mdot
.35028 .36895 Mdot
.37346 .39141 Mdot
.45566 .2572 Mdot
.464 .71751 Mdot
.6308 .61074 Mdot
.57101 .41487 Mdot
.54517 .61522 Mdot
.32399 .61244 Mdot
.30993 .50195 Mdot
.49119 .68 Mdot
.80271 .29146 Mdot
.47833 .69106 Mdot
.60207 .60725 Mdot
.37144 .39562 Mdot
.67337 .62041 Mdot
.55878 .41146 Mdot
.32006 .42761 Mdot
.41544 .37947 Mdot
.6422 .6059 Mdot
.66871 .61355 Mdot
.36625 .56916 Mdot
.29202 .60495 Mdot
.59066 .5444 Mdot
.59285 .41554 Mdot
.59966 .4008 Mdot
.54254 .36342 Mdot
.29424 .5935 Mdot
.5878 .28015 Mdot
.28241 .54114 Mdot
.58726 .30914 Mdot
.74464 .65849 Mdot
.44719 .69132 Mdot
.31093 .7645 Mdot
.33067 .43692 Mdot
.49757 .33408 Mdot
.41033 .35609 Mdot
.69058 .43706 Mdot
.2965 .57525 Mdot
.54449 .57899 Mdot
.46819 .70519 Mdot
.31619 .64988 Mdot
.44577 .68877 Mdot
.86186 .46878 Mdot
.50769 .27091 Mdot
.26634 .55295 Mdot
.59838 .377 Mdot
.45015 .66316 Mdot
.5449 .24245 Mdot
.56683 .55455 Mdot
.60688 .58286 Mdot
.60436 .27197 Mdot
.46263 .20025 Mdot
.66257 .61286 Mdot
.5606 .41248 Mdot
.33114 .43338 Mdot
.55636 .41089 Mdot
.55703 .41212 Mdot
.59118 .37787 Mdot
.28236 .6263 Mdot
.58704 .34818 Mdot
.55799 .40527 Mdot
.46051 .80303 Mdot
.53816 .58462 Mdot
.43469 .7004 Mdot
.37673 .40771 Mdot
.70415 .62577 Mdot
.36576 .35757 Mdot
.68282 .49153 Mdot
.28364 .61498 Mdot
.4542 .26115 Mdot
.58303 .27649 Mdot
.31149 .38862 Mdot
.28334 .59978 Mdot
.66462 .60065 Mdot
.58268 .56537 Mdot
.19976 .41628 Mdot
.45163 .64118 Mdot
.58934 .57473 Mdot
.44814 .71526 Mdot
.58749 .33376 Mdot
.32973 .39889 Mdot
.57822 .57657 Mdot
.32598 .60576 Mdot
.44336 .67599 Mdot
.68701 .40818 Mdot
.57261 .3849 Mdot
.45565 .69838 Mdot
.572 .55878 Mdot
.65252 .48148 Mdot
.67483 .49051 Mdot
.44854 .66287 Mdot
.31565 .56131 Mdot
.33759 .59328 Mdot
.70826 .63265 Mdot
.37291 .40482 Mdot
.35046 .42244 Mdot
.31727 .57511 Mdot
.32813 .65041 Mdot
.56196 .37096 Mdot
.56707 .38043 Mdot
.69524 .48716 Mdot
.57742 .4263 Mdot
.41574 .64341 Mdot
.58716 .57415 Mdot
.34403 .41793 Mdot
.59466 .26838 Mdot
.59785 .27895 Mdot
.56449 .41201 Mdot
.74389 .54816 Mdot
.4813 .71665 Mdot
.57213 .28043 Mdot
.66406 .62667 Mdot
.46045 .21049 Mdot
.53696 .38849 Mdot
.72772 .66282 Mdot
.37217 .40112 Mdot
.24371 .62526 Mdot
.30434 .59094 Mdot
.43934 .66386 Mdot
.44023 .66495 Mdot
.64101 .77252 Mdot
.33296 .4378 Mdot
.5883 .57529 Mdot
.50203 .70583 Mdot
.55863 .58051 Mdot
.67178 .61262 Mdot
.54097 .46217 Mdot
.41705 .64332 Mdot
.43505 .70103 Mdot
.33038 .54924 Mdot
.54226 .42926 Mdot
.53867 .39501 Mdot
.30553 .49951 Mdot
.54536 .39493 Mdot
.68091 .63837 Mdot
.29235 .6143 Mdot
.3454 .40215 Mdot
.66307 .60705 Mdot
.28528 .60114 Mdot
.35585 .42147 Mdot
.57678 .28962 Mdot
.59658 .40815 Mdot
.3456 .37697 Mdot
.35687 .36433 Mdot
.55869 .36774 Mdot
.60768 .82826 Mdot
.33467 .41551 Mdot
.3455 .37372 Mdot
.46103 .20867 Mdot
.43017 .66024 Mdot
.5371 .56126 Mdot
.29183 .57158 Mdot
.56242 .40245 Mdot
.4502 .69897 Mdot
.68007 .617 Mdot
.34505 .41126 Mdot
.55473 .41986 Mdot
.56742 .37194 Mdot
.70156 .62508 Mdot
.6642 .63331 Mdot
.7023 .64096 Mdot
.33782 .5747 Mdot
.57892 .27922 Mdot
.35403 .3736 Mdot
.30111 .57574 Mdot
.70895 .64882 Mdot
.65935 .62421 Mdot
.75799 .65282 Mdot
.5598 .36978 Mdot
.66545 .6365 Mdot
.43413 .17688 Mdot
.7156 .41807 Mdot
.56175 .58475 Mdot
.44357 .72432 Mdot
.4222 .65652 Mdot
.56123 .60431 Mdot
.3259 .60057 Mdot
.58266 .30647 Mdot
.68626 .60655 Mdot
.57022 .55543 Mdot
.56964 .38227 Mdot
.53267 .40385 Mdot
.70184 .63107 Mdot
.73965 .55704 Mdot
.33318 .41981 Mdot
.26005 .35266 Mdot
.70248 .62398 Mdot
.45111 .65914 Mdot
.49615 .68805 Mdot
.47259 .69076 Mdot
.56644 .41761 Mdot
.55932 .28546 Mdot
.57266 .47739 Mdot
.45071 .36164 Mdot
.29442 .60946 Mdot
.37217 .3865 Mdot
.45796 .20587 Mdot
.35115 .38402 Mdot
.46622 .72317 Mdot
.69693 .64277 Mdot
.34236 .43671 Mdot
.33917 .58373 Mdot
.33513 .60066 Mdot
.43233 .65392 Mdot
.47914 .68796 Mdot
.46349 .69107 Mdot
.34126 .44298 Mdot
.36612 .38053 Mdot
.59923 .38482 Mdot
.32166 .40066 Mdot
.42922 .76327 Mdot
.42603 .76226 Mdot
.43688 .6516 Mdot
.31837 .59321 Mdot
.35833 .40666 Mdot
.5423 .37329 Mdot
.67521 .41109 Mdot
.49589 .67952 Mdot
.71157 .63015 Mdot
.46313 .17202 Mdot
.81272 .33954 Mdot
.59866 .28619 Mdot
.30183 .6096 Mdot
.56607 .58264 Mdot
.56936 .39955 Mdot
.48289 .68149 Mdot
.6231 .57727 Mdot
.60275 .56741 Mdot
.56583 .34561 Mdot
.60626 .38638 Mdot
.3001 .60115 Mdot
.68422 .49403 Mdot
.5709 .55253 Mdot
.56867 .27086 Mdot
.2895 .60573 Mdot
.47458 .65969 Mdot
.51456 .7214 Mdot
.33535 .46933 Mdot
.63037 .52219 Mdot
.59175 .58602 Mdot
.53401 .37595 Mdot
.45544 .67748 Mdot
.66203 .6053 Mdot
.45868 .68094 Mdot
.3556 .35618 Mdot
.42939 .65868 Mdot
.54347 .3754 Mdot
.35693 .37599 Mdot
.33539 .60135 Mdot
.63827 .50116 Mdot
.64862 .62915 Mdot
.46502 .65826 Mdot
.59868 .54231 Mdot
.59247 .29551 Mdot
.60094 .34978 Mdot
.54934 .55093 Mdot
.53957 .38974 Mdot
.32479 .5832 Mdot
.34403 .36785 Mdot
.30819 .5763 Mdot
.53937 .55296 Mdot
.38325 .34401 Mdot
.30343 .59273 Mdot
.5614 .29351 Mdot
.65667 .60338 Mdot
.74051 .55329 Mdot
.54817 .3733 Mdot
.32825 .60181 Mdot
.5791 .34621 Mdot
.35246 .43303 Mdot
.71371 .43913 Mdot
.6942 .44512 Mdot
.32377 .57744 Mdot
.56391 .54424 Mdot
.65743 .48365 Mdot
.53678 .56016 Mdot
.30438 .61657 Mdot
.71819 .41034 Mdot
.59298 .56885 Mdot
.69169 .63037 Mdot
.65631 .61891 Mdot
.69312 .63642 Mdot
.56441 .38736 Mdot
.57006 .2178 Mdot
.70458 .65346 Mdot
.30584 .64423 Mdot
.67745 .63948 Mdot
.55161 .60243 Mdot
.28068 .50584 Mdot
.66147 .62551 Mdot
.54513 .386 Mdot
.58692 .30887 Mdot
.58192 .30531 Mdot
.48942 .68514 Mdot
.19016 .43492 Mdot
.45919 .80176 Mdot
.58049 .37273 Mdot
.45447 .19735 Mdot
.32021 .42219 Mdot
.59788 .54033 Mdot
.69341 .44266 Mdot
.57341 .30017 Mdot
.3551 .3859 Mdot
.68583 .4897 Mdot
.29715 .43619 Mdot
.55943 .57014 Mdot
.56374 .38287 Mdot
.34585 .43904 Mdot
.30712 .41109 Mdot
.75293 .53635 Mdot
.37062 .46645 Mdot
.35698 .41442 Mdot
.30558 .61881 Mdot
.32349 .60155 Mdot
.32486 .58114 Mdot
.47782 .68264 Mdot
.34165 .406 Mdot
.51995 .40741 Mdot
.48112 .68141 Mdot
.58938 .3852 Mdot
.32124 .57575 Mdot
.69566 .43781 Mdot
.34206 .40307 Mdot
.54909 .37553 Mdot
.54432 .25395 Mdot
.44056 .70098 Mdot
.70211 .62682 Mdot
.45389 .19047 Mdot
.45734 .73194 Mdot
.31472 .55683 Mdot
.35348 .35419 Mdot
.5413 .58743 Mdot
.5685 .28059 Mdot
.56519 .42312 Mdot
.57882 .35706 Mdot
.56817 .28117 Mdot
.51031 .26509 Mdot
.59867 .55202 Mdot
.47563 .6781 Mdot
.42892 .66625 Mdot
.53467 .38698 Mdot
.33844 .40872 Mdot
.70935 .65899 Mdot
.72289 .63598 Mdot
.61444 .60986 Mdot
.66659 .48535 Mdot
.69329 .42429 Mdot
.56561 .4327 Mdot
.50828 .33965 Mdot
.49126 .69459 Mdot
.55333 .57679 Mdot
.67126 .48276 Mdot
.68462 .63078 Mdot
.59138 .39402 Mdot
.38034 .38072 Mdot
.347 .40842 Mdot
.46092 .7046 Mdot
.32121 .6204 Mdot
.61135 .57153 Mdot
.43678 .6507 Mdot
.53472 .3878 Mdot
.59713 .27362 Mdot
.3025 .62141 Mdot
.34657 .35705 Mdot
.69598 .6295 Mdot
.48483 .6877 Mdot
.67604 .62425 Mdot
.32785 .39011 Mdot
.34525 .41223 Mdot
.58769 .40915 Mdot
.62544 .61237 Mdot
.46438 .6563 Mdot
.56278 .41627 Mdot
.45456 .69222 Mdot
.39454 .65963 Mdot
.34208 .59797 Mdot
.57798 .41993 Mdot
.41405 .38762 Mdot
.32631 .57642 Mdot
.58503 .37918 Mdot
.58066 .30124 Mdot
.59293 .26806 Mdot
.45149 .66166 Mdot
.70596 .61544 Mdot
.68542 .62705 Mdot
.41968 .36088 Mdot
.44967 .25365 Mdot
.55587 .43336 Mdot
.43797 .65541 Mdot
.60551 .27694 Mdot
.30445 .60315 Mdot
.3698 .40113 Mdot
.25111 .70951 Mdot
.31199 .59584 Mdot
.54938 .36747 Mdot
.68206 .63514 Mdot
.35866 .36327 Mdot
.5675 .58935 Mdot
.70833 .5152 Mdot
.56097 .54253 Mdot
.61998 .61188 Mdot
.58897 .54698 Mdot
.2691 .52349 Mdot
.46133 .68827 Mdot
.35323 .36994 Mdot
.30364 .61191 Mdot
.30615 .60604 Mdot
.45455 .72096 Mdot
.45577 .23974 Mdot
.24262 .36498 Mdot
.43366 .16805 Mdot
.46901 .6452 Mdot
.69045 .64227 Mdot
.71301 .4362 Mdot
.47357 .69255 Mdot
.44925 .72161 Mdot
.38067 .59602 Mdot
.30697 .49947 Mdot
.36162 .40122 Mdot
.56965 .37159 Mdot
.45565 .21463 Mdot
.58183 .36302 Mdot
.62674 .5182 Mdot
.31605 .5773 Mdot
.36968 .40193 Mdot
.33214 .52136 Mdot
.54037 .41205 Mdot
.57811 .3973 Mdot
.4338 .76994 Mdot
.5795 .57064 Mdot
.53195 .82287 Mdot
.5934 .37772 Mdot
.46882 .67931 Mdot
.40328 .41928 Mdot
.56179 .56751 Mdot
.54552 .25104 Mdot
.31145 .62067 Mdot
.58717 .58411 Mdot
.56166 .56457 Mdot
.51231 .33791 Mdot
.28063 .40909 Mdot
.34669 .4292 Mdot
.67428 .64556 Mdot
.29619 .49054 Mdot
.2987 .62431 Mdot
.24783 .55194 Mdot
.54071 .37468 Mdot
.33951 .57031 Mdot
.70749 .61072 Mdot
.5841 .37522 Mdot
.58927 .29137 Mdot
.45495 .25808 Mdot
.52966 .40972 Mdot
.59096 .312 Mdot
.31342 .59107 Mdot
.73935 .62882 Mdot
.56054 .43792 Mdot
.45769 .70055 Mdot
.36446 .40055 Mdot
.27667 .39706 Mdot
.67511 .60512 Mdot
.34828 .53869 Mdot
.80867 .31014 Mdot
.36935 .40158 Mdot
.57059 .3865 Mdot
.30563 .60133 Mdot
.5776 .5886 Mdot
.56597 .57236 Mdot
.58242 .53652 Mdot
.35029 .40685 Mdot
.56306 .56602 Mdot
.41913 .37419 Mdot
.68504 .49074 Mdot
.49701 .33283 Mdot
.33051 .58165 Mdot
.68797 .64059 Mdot
.57752 .61135 Mdot
.39227 .66361 Mdot
.58822 .42265 Mdot
.62772 .51935 Mdot
.31209 .43375 Mdot
.68436 .63977 Mdot
.56571 .40652 Mdot
.59662 .5476 Mdot
.7089 .36555 Mdot
.72154 .65558 Mdot
.59194 .54836 Mdot
.59453 .25835 Mdot
.35832 .4222 Mdot
.58621 .57825 Mdot
.34762 .39997 Mdot
.565 .40879 Mdot
.5939 .48234 Mdot
.36124 .42219 Mdot
.18658 .44951 Mdot
.61212 .56178 Mdot
.2854 .60894 Mdot
.54179 .34863 Mdot
.55173 .41544 Mdot
.55673 .2739 Mdot
.57632 .58693 Mdot
.17639 .4966 Mdot
.45057 .69105 Mdot
.51487 .82961 Mdot
.43097 .64027 Mdot
.37852 .59513 Mdot
.23113 .58839 Mdot
.54583 .42046 Mdot
.45657 .23894 Mdot
.55853 .28078 Mdot
.30648 .56447 Mdot
.55844 .26942 Mdot
.5565 .40428 Mdot
.57765 .41448 Mdot
.45455 .69344 Mdot
.32438 .62328 Mdot
.58231 .25236 Mdot
.6702 .48294 Mdot
.66722 .60002 Mdot
.33792 .38513 Mdot
.56047 .39736 Mdot
.3087 .38445 Mdot
.44744 .66037 Mdot
.27306 .34232 Mdot
.54664 .38344 Mdot
.57994 .57044 Mdot
.33921 .57219 Mdot
.33137 .60674 Mdot
.46075 .66214 Mdot
.46321 .66162 Mdot
.5516 .41508 Mdot
.30953 .57125 Mdot
.58391 .43079 Mdot
.6562 .48328 Mdot
.57362 .55636 Mdot
.67997 .61359 Mdot
.56151 .35208 Mdot
.24891 .36023 Mdot
.79537 .62083 Mdot
.56756 .41702 Mdot
.3341 .4302 Mdot
.46375 .69533 Mdot
.46899 .72593 Mdot
.35102 .42125 Mdot
.46764 .72601 Mdot
.26036 .34987 Mdot
.57088 .21893 Mdot
.6703 .61536 Mdot
.60727 .29536 Mdot
.68305 .64615 Mdot
.58391 .58496 Mdot
.55891 .36943 Mdot
.26791 .65635 Mdot
.46604 .64383 Mdot
.65875 .34504 Mdot
.31026 .58185 Mdot
.5539 .566 Mdot
.58541 .27986 Mdot
.64531 .60322 Mdot
.47981 .70461 Mdot
.60227 .58617 Mdot
.59283 .38717 Mdot
.34718 .43947 Mdot
.59844 .25918 Mdot
.5593 .55972 Mdot
.57709 .58417 Mdot
.59894 .58736 Mdot
.28524 .60089 Mdot
.33324 .37282 Mdot
.36653 .56949 Mdot
.43813 .69119 Mdot
.59859 .37069 Mdot
.57093 .38967 Mdot
.37228 .38966 Mdot
.56643 .35599 Mdot
.31624 .56825 Mdot
.40811 .16524 Mdot
.69982 .64417 Mdot
.57012 .58804 Mdot
.22063 .45819 Mdot
.59018 .59273 Mdot
.58859 .25807 Mdot
.57083 .30399 Mdot
.37934 .40122 Mdot
.28427 .59129 Mdot
.59409 .42429 Mdot
.42864 .68047 Mdot
.69344 .62865 Mdot
.34021 .58608 Mdot
.5951 .27943 Mdot
.54355 .38093 Mdot
.68575 .63916 Mdot
.32866 .51857 Mdot
.67774 .59967 Mdot
.30107 .61316 Mdot
.54998 .56252 Mdot
.67566 .40126 Mdot
.55506 .38009 Mdot
.5856 .57169 Mdot
.33221 .37868 Mdot
.29318 .60357 Mdot
.45521 .27232 Mdot
.55994 .56712 Mdot
.39011 .70213 Mdot
.32523 .6126 Mdot
.56655 .42363 Mdot
.32527 .44438 Mdot
.27826 .37234 Mdot
.34057 .37059 Mdot
.68331 .75459 Mdot
.40192 .72896 Mdot
.46064 .69186 Mdot
.31716 .59484 Mdot
.45235 .70502 Mdot
.65608 .60367 Mdot
.70904 .45323 Mdot
.4636 .65963 Mdot
.31697 .38793 Mdot
.44576 .69279 Mdot
.58768 .42671 Mdot
.2843 .6088 Mdot
.45999 .65211 Mdot
.55105 .35617 Mdot
.57555 .28984 Mdot
.57576 .58172 Mdot
.71125 .65566 Mdot
.67696 .48828 Mdot
.55748 .36255 Mdot
.58663 .56667 Mdot
.5505 .37669 Mdot
.31555 .56855 Mdot
.63011 .50029 Mdot
.60192 .37356 Mdot
.46949 .64585 Mdot
.20887 .39975 Mdot
.43149 .66477 Mdot
.56478 .624 Mdot
.58703 .37747 Mdot
.55554 .37672 Mdot
.59137 .28008 Mdot
.47494 .17336 Mdot
.32417 .56039 Mdot
.58537 .34587 Mdot
.4759 .7281 Mdot
.35551 .39242 Mdot
.3361 .4369 Mdot
.51448 .42446 Mdot
.58845 .57194 Mdot
.33287 .57227 Mdot
.55787 .37413 Mdot
.55538 .57089 Mdot
.69341 .46822 Mdot
.29524 .49589 Mdot
.41777 .7516 Mdot
.44222 .70954 Mdot
.36344 .42609 Mdot
.48264 .71781 Mdot
.59188 .27647 Mdot
.56219 .57117 Mdot
.40001 .727 Mdot
.37445 .6272 Mdot
.69161 .62732 Mdot
.58467 .40281 Mdot
.74765 .54564 Mdot
.48727 .7146 Mdot
.47546 .67274 Mdot
.58583 .42918 Mdot
.38632 .44507 Mdot
.78198 .63313 Mdot
.29259 .5869 Mdot
.32331 .34281 Mdot
.50233 .23596 Mdot
.81573 .45895 Mdot
.31757 .60363 Mdot
.5905 .29268 Mdot
.49464 .70095 Mdot
.58141 .79468 Mdot
.35397 .38675 Mdot
.69368 .6277 Mdot
.55421 .35433 Mdot
.31785 .40208 Mdot
.4709 .64556 Mdot
.3335 .36868 Mdot
.57448 .57231 Mdot
.28364 .60441 Mdot
.48312 .70666 Mdot
.30904 .62688 Mdot
.41291 .39067 Mdot
.69376 .64421 Mdot
.69523 .55796 Mdot
.59231 .30515 Mdot
.45455 .25621 Mdot
.57895 .28179 Mdot
.5371 .58385 Mdot
.57592 .28481 Mdot
.27676 .38787 Mdot
.5474 .37452 Mdot
.56925 .44152 Mdot
.48859 .72272 Mdot
.56815 .41933 Mdot
.54264 .36864 Mdot
.54562 .25453 Mdot
.58682 .3938 Mdot
.55906 .41346 Mdot
.56177 .42508 Mdot
.33408 .4252 Mdot
.59238 .40153 Mdot
.35884 .36778 Mdot
.31522 .37513 Mdot
.43859 .69357 Mdot
.65687 .61631 Mdot
.66276 .62808 Mdot
.60037 .48354 Mdot
.74651 .54616 Mdot
.45664 .21238 Mdot
.35236 .394 Mdot
.32666 .61025 Mdot
.59995 .39348 Mdot
.76348 .65186 Mdot
.59501 .48201 Mdot
.4893 .68221 Mdot
.44633 .65805 Mdot
.5473 .35654 Mdot
.81374 .34662 Mdot
.59385 .37664 Mdot
.7 .47987 Mdot
.5636 .38878 Mdot
.57691 .42188 Mdot
.42571 .66857 Mdot
.7222 .55936 Mdot
.57137 .27849 Mdot
.28497 .41448 Mdot
.68909 .62376 Mdot
.58432 .57722 Mdot
.59706 .48335 Mdot
.52168 .22682 Mdot
.32296 .46288 Mdot
.59191 .28046 Mdot
.4873 .69136 Mdot
.34569 .41568 Mdot
.69398 .4858 Mdot
.29937 .57776 Mdot
.71014 .51674 Mdot
.35844 .33241 Mdot
.29275 .58354 Mdot
.69275 .63042 Mdot
.49122 .67385 Mdot
.57266 .40709 Mdot
.45586 .67334 Mdot
.54265 .41464 Mdot
.70665 .47464 Mdot
.67437 .61346 Mdot
.31432 .39493 Mdot
.30209 .61986 Mdot
.32941 .41966 Mdot
.27708 .34175 Mdot
.59484 .48998 Mdot
.48445 .81573 Mdot
.43489 .65452 Mdot
.55911 .61962 Mdot
.36569 .38423 Mdot
.5331 .38559 Mdot
.42999 .17466 Mdot
.33199 .39452 Mdot
.34845 .43804 Mdot
.6931 .51696 Mdot
.73909 .56746 Mdot
.55691 .42335 Mdot
.31862 .39689 Mdot
.49041 .67149 Mdot
.66661 .61734 Mdot
.53944 .37373 Mdot
.56251 .57674 Mdot
.34123 .43793 Mdot
.47568 .71736 Mdot
.71395 .5587 Mdot
.47488 .68313 Mdot
.36025 .39307 Mdot
.43853 .66157 Mdot
.31964 .54308 Mdot
.46336 .65908 Mdot
.56543 .35267 Mdot
.55713 .37543 Mdot
.28481 .36232 Mdot
.34507 .41224 Mdot
.5883 .25814 Mdot
.57368 .35923 Mdot
.35775 .37362 Mdot
.50029 .68207 Mdot
.32112 .4597 Mdot
.59249 .26478 Mdot
.56523 .37078 Mdot
.69071 .65093 Mdot
.64017 .48525 Mdot
.67256 .50981 Mdot
.59945 .39071 Mdot
.69319 .64151 Mdot
.35042 .43828 Mdot
.55519 .36981 Mdot
.73007 .56435 Mdot
.49192 .72206 Mdot
.54788 .43691 Mdot
.57791 .58964 Mdot
.57601 .2681 Mdot
.75514 .50204 Mdot
.59408 .28224 Mdot
.35233 .37834 Mdot
.36124 .38686 Mdot
.49689 .71217 Mdot
.34304 .37809 Mdot
.5727 .58787 Mdot
.33446 .58025 Mdot
.33971 .32848 Mdot
.55235 .57172 Mdot
.60531 .56652 Mdot
.60991 .56096 Mdot
.57679 .54473 Mdot
.729 .66854 Mdot
.41232 .74212 Mdot
.60017 .57579 Mdot
.35516 .36798 Mdot
.51689 .52018 Mdot
.54147 .57193 Mdot
.33211 .57092 Mdot
.5623 .56402 Mdot
.54769 .4367 Mdot
.59128 .28464 Mdot
.37392 .37825 Mdot
.30136 .57434 Mdot
.54922 .54654 Mdot
.53987 .37207 Mdot
.3805 .39153 Mdot
.55947 .3995 Mdot
.71071 .62459 Mdot
.3428 .40096 Mdot
.48343 .6889 Mdot
.67795 .61204 Mdot
.57766 .54829 Mdot
.70474 .62991 Mdot
.45384 .68094 Mdot
.33147 .60047 Mdot
.55571 .3563 Mdot
.7176 .62996 Mdot
.65744 .61572 Mdot
.52807 .39551 Mdot
.36451 .39299 Mdot
.59096 .53287 Mdot
.56196 .36586 Mdot
.58629 .28334 Mdot
.34994 .42321 Mdot
.16917 .50172 Mdot
.5757 .40648 Mdot
.56914 .26774 Mdot
.28084 .39827 Mdot
.55616 .56444 Mdot
.48074 .68344 Mdot
.55374 .41915 Mdot
.30532 .58253 Mdot
.31769 .57458 Mdot
.46212 .64289 Mdot
.34539 .43253 Mdot
.4769 .71994 Mdot
.53085 .38006 Mdot
.56395 .5591 Mdot
.54067 .39715 Mdot
.44269 .78014 Mdot
.17541 .47097 Mdot
.35481 .36171 Mdot
.43642 .68925 Mdot
.69272 .46191 Mdot
.2932 .5685 Mdot
.49991 .67196 Mdot
.28184 .4074 Mdot
.32082 .40631 Mdot
.35284 .42052 Mdot
.66441 .62837 Mdot
.47969 .69084 Mdot
.37559 .39662 Mdot
.37496 .39081 Mdot
.5938 .27202 Mdot
.54669 .35881 Mdot
.3578 .43161 Mdot
.39136 .66347 Mdot
.68556 .62581 Mdot
.46767 .73076 Mdot
.78591 .63215 Mdot
.29143 .59546 Mdot
.5464 .25022 Mdot
.58986 .42156 Mdot
.80105 .28729 Mdot
.59281 .3745 Mdot
.56623 .3912 Mdot
.36536 .35698 Mdot
.65361 .59885 Mdot
.66933 .6247 Mdot
.36518 .38468 Mdot
.35168 .35956 Mdot
.69222 .61271 Mdot
.6429 .44897 Mdot
.75551 .52071 Mdot
.68477 .47389 Mdot
.32941 .37416 Mdot
.36177 .33565 Mdot
.31941 .58286 Mdot
.32238 .42503 Mdot
.29792 .53549 Mdot
.4471 .65062 Mdot
.46255 .65724 Mdot
.3116 .6191 Mdot
.57357 .40483 Mdot
.42551 .66437 Mdot
.57375 .27687 Mdot
.27658 .54073 Mdot
.58957 .29981 Mdot
.62232 .82571 Mdot
.56433 .35467 Mdot
.47022 .60336 Mdot
.27685 .5138 Mdot
.58342 .25889 Mdot
.55721 .21154 Mdot
.69945 .63132 Mdot
.27582 .39667 Mdot
.31575 .56622 Mdot
.45491 .21575 Mdot
.55517 .37862 Mdot
.31892 .39007 Mdot
.29583 .61649 Mdot
.17404 .48693 Mdot
.57207 .29009 Mdot
.58696 .26821 Mdot
.42546 .17439 Mdot
.32159 .37138 Mdot
.47943 .68313 Mdot
.31102 .34526 Mdot
.36388 .36421 Mdot
.57945 .29824 Mdot
.49091 .6674 Mdot
.70471 .3627 Mdot
.32143 .38252 Mdot
.67608 .59858 Mdot
.3409 .38845 Mdot
.69124 .6139 Mdot
.37547 .40101 Mdot
.44107 .69698 Mdot
.58103 .40379 Mdot
.44031 .69818 Mdot
.71339 .63953 Mdot
.43314 .66817 Mdot
.31032 .567 Mdot
.58576 .55614 Mdot
.32611 .57683 Mdot
.71108 .44696 Mdot
.45709 .28362 Mdot
.32914 .59582 Mdot
.51442 .37366 Mdot
.54277 .38038 Mdot
.37503 .40286 Mdot
.48614 .69637 Mdot
.47364 .73526 Mdot
.67388 .48791 Mdot
.36184 .40942 Mdot
.46552 .72191 Mdot
.59168 .32078 Mdot
.24556 .64155 Mdot
.5702 .26935 Mdot
.26446 .72762 Mdot
.35211 .37284 Mdot
.47578 .73339 Mdot
.69727 .48236 Mdot
.34178 .35519 Mdot
.46294 .6547 Mdot
.31178 .61541 Mdot
.30533 .58294 Mdot
.5753 .35452 Mdot
.30512 .62966 Mdot
.48888 .68371 Mdot
.38932 .34617 Mdot
.36796 .41366 Mdot
.1775 .46257 Mdot
.69879 .64161 Mdot
.48388 .71431 Mdot
.56977 .55893 Mdot
.41333 .38706 Mdot
.44921 .7011 Mdot
.80988 .31549 Mdot
.76693 .70994 Mdot
.46985 .72083 Mdot
.34414 .39993 Mdot
.35178 .40936 Mdot
.59993 .27729 Mdot
.66923 .48486 Mdot
.47897 .70611 Mdot
.26163 .6556 Mdot
.69324 .41852 Mdot
.58816 .55834 Mdot
.45982 .80256 Mdot
.51995 .38815 Mdot
.58197 .28116 Mdot
.29424 .60236 Mdot
.57906 .39601 Mdot
.34514 .36119 Mdot
.59354 .37652 Mdot
.32251 .57118 Mdot
.4565 .64292 Mdot
.55318 .37696 Mdot
.69397 .62991 Mdot
.29765 .59721 Mdot
.30161 .58299 Mdot
.43801 .66975 Mdot
.34662 .43234 Mdot
.45246 .22028 Mdot
.47932 .6874 Mdot
.5773 .27795 Mdot
.58412 .56372 Mdot
.56319 .42427 Mdot
.31458 .41245 Mdot
.29324 .43327 Mdot
.48646 .71223 Mdot
.52933 .39017 Mdot
.31441 .60097 Mdot
.49097 .71882 Mdot
.59403 .28914 Mdot
.47575 .66213 Mdot
.62119 .56032 Mdot
.42284 .66795 Mdot
.41337 .3964 Mdot
.59994 .54184 Mdot
.31764 .39044 Mdot
.60047 .56978 Mdot
.64327 .77256 Mdot
.69043 .62943 Mdot
.42775 .66458 Mdot
.1849 .45585 Mdot
.43862 .69735 Mdot
.58704 .39025 Mdot
.54624 .36971 Mdot
.45074 .68584 Mdot
.69216 .64465 Mdot
.56684 .60643 Mdot
.71069 .62075 Mdot
.34466 .40548 Mdot
.57655 .30615 Mdot
.73611 .74183 Mdot
.47569 .74 Mdot
.30142 .62326 Mdot
.33356 .46791 Mdot
.60463 .56258 Mdot
.30604 .5691 Mdot
.29858 .58766 Mdot
.70981 .63688 Mdot
.44659 .7182 Mdot
.32756 .43477 Mdot
.29277 .62495 Mdot
.34353 .35678 Mdot
.72649 .5656 Mdot
.5663 .55126 Mdot
.53729 .60925 Mdot
.59588 .54693 Mdot
.68282 .48882 Mdot
.28187 .6132 Mdot
.55225 .39505 Mdot
.63076 .60442 Mdot
.3007 .61656 Mdot
.70616 .65383 Mdot
.59233 .2915 Mdot
.46246 .72132 Mdot
.43713 .1941 Mdot
.56856 .35205 Mdot
.57828 .367 Mdot
.29315 .60768 Mdot
.54335 .2109 Mdot
.28249 .4131 Mdot
.35777 .42388 Mdot
.46194 .68865 Mdot
.69039 .51497 Mdot
.5939 .38938 Mdot
.5455 .36714 Mdot
.44794 .68053 Mdot
.59192 .57119 Mdot
.47093 .81012 Mdot
.56567 .3731 Mdot
.31685 .58942 Mdot
.59108 .29026 Mdot
.31213 .56183 Mdot
.59832 .41547 Mdot
.58557 .38977 Mdot
.5797 .27155 Mdot
.57849 .28888 Mdot
.32633 .57778 Mdot
.58952 .54647 Mdot
.58913 .59079 Mdot
.3365 .37217 Mdot
.54779 .35379 Mdot
.69185 .41764 Mdot
.56 .37665 Mdot
.69919 .6323 Mdot
.67729 .51011 Mdot
.60058 .40138 Mdot
.56549 .34478 Mdot
.69556 .41827 Mdot
.56146 .40779 Mdot
.29182 .60667 Mdot
.35489 .40884 Mdot
.3123 .60256 Mdot
.28999 .62111 Mdot
.44475 .69279 Mdot
.70099 .65439 Mdot
.55542 .41744 Mdot
.66701 .60238 Mdot
.53052 .35827 Mdot
.54271 .54609 Mdot
.65281 .48067 Mdot
.69946 .47837 Mdot
.71823 .65611 Mdot
.54232 .37747 Mdot
.45675 .68525 Mdot
.44914 .72496 Mdot
.58284 .30641 Mdot
.53783 .35663 Mdot
.32373 .62144 Mdot
.32776 .60223 Mdot
.42503 .76153 Mdot
.52411 .6636 Mdot
.70947 .62176 Mdot
.61451 .60224 Mdot
.5765 .28914 Mdot
.58815 .39882 Mdot
.5915 .55112 Mdot
.45758 .70691 Mdot
.60116 .57227 Mdot
.41555 .74746 Mdot
.31237 .56428 Mdot
.30587 .60868 Mdot
.56406 .35378 Mdot
.85034 .39811 Mdot
.32794 .3971 Mdot
.35201 .41039 Mdot
.33469 .57629 Mdot
.43123 .66486 Mdot
.57153 .57416 Mdot
.44876 .18486 Mdot
.30482 .44423 Mdot
.65481 .60518 Mdot
.5434 .40618 Mdot
.44355 .65162 Mdot
.34527 .36572 Mdot
.70757 .61925 Mdot
.59961 .36057 Mdot
.49387 .66937 Mdot
.55631 .39076 Mdot
.60159 .34634 Mdot
.36909 .38788 Mdot
.64598 .48225 Mdot
.31616 .39016 Mdot
.31778 .57748 Mdot
.28383 .61892 Mdot
.5858 .38198 Mdot
.44502 .19598 Mdot
.39576 .43119 Mdot
.28849 .62538 Mdot
.67468 .64517 Mdot
.5804 .55471 Mdot
.70354 .65394 Mdot
.45717 .69593 Mdot
.69154 .62939 Mdot
.44803 .69969 Mdot
.50153 .70215 Mdot
.33048 .43544 Mdot
.68528 .63889 Mdot
.53023 .2534 Mdot
.56255 .57253 Mdot
.66186 .63187 Mdot
.59151 .35646 Mdot
.59521 .26426 Mdot
.47489 .7111 Mdot
.66323 .60178 Mdot
.55506 .42074 Mdot
.21756 .46126 Mdot
.28537 .61366 Mdot
.31214 .56645 Mdot
.57409 .57319 Mdot
.49262 .69924 Mdot
.32903 .43692 Mdot
.69537 .45998 Mdot
.41791 .37976 Mdot
.54615 .36497 Mdot
.5583 .41691 Mdot
.41722 .38547 Mdot
.32986 .43748 Mdot
.5848 .38594 Mdot
.49542 .32573 Mdot
.57088 .55573 Mdot
.31041 .5767 Mdot
.34244 .40582 Mdot
.33942 .41245 Mdot
.47999 .67335 Mdot
.34507 .43719 Mdot
.60413 .61491 Mdot
.31075 .56514 Mdot
.57956 .59313 Mdot
.31509 .59754 Mdot
.55437 .51285 Mdot
.46295 .71775 Mdot
.1819 .47407 Mdot
.35514 .42826 Mdot
.591 .26557 Mdot
.34966 .43544 Mdot
.70286 .6414 Mdot
.31995 .39506 Mdot
.31949 .42127 Mdot
.5494 .35811 Mdot
.58785 .54719 Mdot
.58472 .58324 Mdot
.67726 .48584 Mdot
.32959 .39477 Mdot
.56846 .41301 Mdot
.59345 .40645 Mdot
.57009 .3583 Mdot
.65729 .4815 Mdot
.33798 .42826 Mdot
.5232 .22598 Mdot
.37501 .41054 Mdot
.36681 .38205 Mdot
.80378 .60978 Mdot
.57095 .58592 Mdot
.60185 .5629 Mdot
.25271 .62525 Mdot
.56864 .3712 Mdot
.465 .72523 Mdot
.57937 .27759 Mdot
.58048 .54977 Mdot
.60025 .36543 Mdot
.663 .61123 Mdot
.53862 .40803 Mdot
.59224 .56344 Mdot
.48459 .69576 Mdot
.59145 .26746 Mdot
.56028 .37062 Mdot
.58978 .57572 Mdot
.34196 .44089 Mdot
.33511 .41957 Mdot
.42489 .41364 Mdot
.70347 .62155 Mdot
.32656 .58847 Mdot
.5816 .27807 Mdot
.45973 .68774 Mdot
.45969 .72514 Mdot
.31655 .3925 Mdot
.45563 .66391 Mdot
.30324 .60903 Mdot
.57107 .38391 Mdot
.3218 .57655 Mdot
.6681 .60716 Mdot
.34179 .40139 Mdot
.5895 .27795 Mdot
.5989 .25515 Mdot
.36127 .38676 Mdot
.56898 .55601 Mdot
.69193 .6523 Mdot
.44628 .66908 Mdot
.36175 .36793 Mdot
.32865 .57626 Mdot
.47308 .66735 Mdot
.58787 .26563 Mdot
.83992 .54675 Mdot
.57967 .39566 Mdot
.58509 .36597 Mdot
.40294 .41029 Mdot
.57047 .44316 Mdot
.43793 .69005 Mdot
.33216 .44054 Mdot
.5934 .26394 Mdot
.71598 .42323 Mdot
.70025 .6627 Mdot
.4507 .734 Mdot
.56324 .40273 Mdot
.55683 .27525 Mdot
.55787 .43274 Mdot
.18883 .44323 Mdot
.6529 .48204 Mdot
.39255 .7057 Mdot
.54378 .61439 Mdot
.29878 .62654 Mdot
.58836 .56654 Mdot
.44295 .69158 Mdot
.49159 .31564 Mdot
.58175 .38835 Mdot
.45172 .26719 Mdot
.5954 .28203 Mdot
.31357 .60647 Mdot
.54023 .22001 Mdot
.48697 .68897 Mdot
.50734 .82817 Mdot
.5374 .36697 Mdot
.28854 .42515 Mdot
.39397 .62914 Mdot
.59047 .55307 Mdot
.59992 .55459 Mdot
.70858 .62181 Mdot
.49373 .66155 Mdot
.5568 .54483 Mdot
.31315 .6004 Mdot
.58921 .40001 Mdot
.5787 .32183 Mdot
.17653 .50312 Mdot
.3488 .36855 Mdot
.29401 .61979 Mdot
.42891 .7071 Mdot
.54818 .39609 Mdot
.32318 .41028 Mdot
.35359 .38644 Mdot
.66027 .60931 Mdot
.38787 .68634 Mdot
.49924 .66765 Mdot
.81996 .3647 Mdot
.5785 .53155 Mdot
.45545 .7037 Mdot
.59403 .54064 Mdot
.57845 .2758 Mdot
.59447 .4825 Mdot
.29543 .62385 Mdot
.58806 .38267 Mdot
.45289 .25492 Mdot
.34468 .37289 Mdot
.56154 .3819 Mdot
.68252 .62214 Mdot
.46079 .17135 Mdot
.59086 .3094 Mdot
.49852 .32731 Mdot
.49045 .67128 Mdot
.56098 .41672 Mdot
.61222 .61366 Mdot
.55501 .57126 Mdot
.57037 .44364 Mdot
.48093 .68576 Mdot
.6013 .54324 Mdot
.67714 .62182 Mdot
.33566 .37047 Mdot
.58645 .56757 Mdot
.59532 .28486 Mdot
.54669 .41703 Mdot
.67969 .64925 Mdot
.5828 .27125 Mdot
.32098 .32824 Mdot
.57605 .53977 Mdot
.45657 .65622 Mdot
.36233 .36633 Mdot
.56698 .41649 Mdot
.58046 .55376 Mdot
.54231 .39907 Mdot
.24936 .35925 Mdot
.58927 .38832 Mdot
.19965 .48086 Mdot
.36436 .40201 Mdot
.30559 .59147 Mdot
.59072 .28178 Mdot
.55527 .38753 Mdot
.59488 .53923 Mdot
.57013 .57599 Mdot
.53552 .37944 Mdot
.3172 .39048 Mdot
.32757 .3819 Mdot
.29608 .43493 Mdot
.47809 .66835 Mdot
.67689 .47535 Mdot
.31041 .58491 Mdot
.59268 .55166 Mdot
.29384 .625 Mdot
.55988 .28423 Mdot
.70289 .62306 Mdot
.18216 .49758 Mdot
.57544 .38165 Mdot
.35899 .41332 Mdot
.75357 .52414 Mdot
.31928 .40826 Mdot
.25219 .62009 Mdot
.29888 .62424 Mdot
.3353 .39677 Mdot
.56578 .40215 Mdot
.68801 .48964 Mdot
.55725 .26362 Mdot
.28463 .58635 Mdot
.58047 .5919 Mdot
.57717 .51861 Mdot
.47254 .65682 Mdot
.79977 .61734 Mdot
.33648 .60151 Mdot
.27612 .51269 Mdot
.5924 .26459 Mdot
.3636 .41583 Mdot
.33018 .58237 Mdot
.30233 .57961 Mdot
.48953 .69395 Mdot
.59326 .27093 Mdot
.55691 .38615 Mdot
.58042 .5891 Mdot
.33328 .60118 Mdot
.53324 .40273 Mdot
.58242 .2578 Mdot
.44239 .78388 Mdot
.28058 .41129 Mdot
.16715 .50012 Mdot
.56804 .3051 Mdot
.45452 .25287 Mdot
.31537 .65643 Mdot
.37317 .406 Mdot
.56251 .4127 Mdot
.57109 .56349 Mdot
.45022 .66224 Mdot
.57328 .38996 Mdot
.43636 .6914 Mdot
.32141 .60068 Mdot
.20916 .47224 Mdot
.56916 .30618 Mdot
.27265 .54375 Mdot
.58142 .40067 Mdot
.59742 .29469 Mdot
.68009 .6302 Mdot
.31979 .56576 Mdot
.29584 .43059 Mdot
.56393 .42186 Mdot
.47645 .67533 Mdot
.46647 .65397 Mdot
.34025 .37413 Mdot
.38243 .45988 Mdot
.18267 .46623 Mdot
.56666 .56332 Mdot
.46028 .66882 Mdot
.57793 .55352 Mdot
.49874 .33132 Mdot
.29306 .62539 Mdot
.67604 .62172 Mdot
.44025 .66147 Mdot
.33789 .57523 Mdot
.59488 .26341 Mdot
.33386 .38507 Mdot
.41475 .37865 Mdot
.57551 .29775 Mdot
.46538 .72239 Mdot
.69188 .61741 Mdot
.51922 .4206 Mdot
.57675 .3045 Mdot
.68051 .61441 Mdot
.48503 .67693 Mdot
.32883 .40857 Mdot
.35759 .38775 Mdot
.35637 .40669 Mdot
.54565 .2504 Mdot
.29578 .43656 Mdot
.67283 .55466 Mdot
.56506 .44178 Mdot
.40059 .35015 Mdot
.54651 .43128 Mdot
.31354 .56656 Mdot
.37008 .3956 Mdot
.65198 .48159 Mdot
.57062 .27459 Mdot
.5613 .25082 Mdot
.56499 .36057 Mdot
.58129 .29542 Mdot
.56821 .37073 Mdot
.40447 .35481 Mdot
.28129 .41611 Mdot
.55869 .34505 Mdot
.29713 .57055 Mdot
.70329 .63239 Mdot
.3554 .35673 Mdot
.55267 .41296 Mdot
.38153 .34616 Mdot
.59314 .35871 Mdot
.20643 .47278 Mdot
.58362 .29854 Mdot
.41373 .64545 Mdot
.58345 .41268 Mdot
.43264 .65254 Mdot
.60217 .26535 Mdot
.34543 .32989 Mdot
.28458 .60826 Mdot
.59268 .30716 Mdot
.42861 .64994 Mdot
.53845 .2215 Mdot
.5662 .56915 Mdot
.68362 .62686 Mdot
.60617 .55157 Mdot
.32341 .5734 Mdot
.57901 .38327 Mdot
.54109 .40951 Mdot
.5857 .43709 Mdot
.49883 .33268 Mdot
.5666 .58257 Mdot
.71966 .65571 Mdot
.35993 .33414 Mdot
.53585 .39196 Mdot
.42514 .67536 Mdot
.34526 .42484 Mdot
.53167 .24117 Mdot
.51859 .25654 Mdot
.58703 .25411 Mdot
.33223 .39292 Mdot
.3454 .43272 Mdot
.77184 .64432 Mdot
.68988 .63615 Mdot
.5816 .3684 Mdot
.70946 .61454 Mdot
.5846 .27704 Mdot
.32203 .5912 Mdot
.57656 .44001 Mdot
.46351 .71853 Mdot
.69514 .48973 Mdot
.48293 .67298 Mdot
.56727 .35806 Mdot
.34265 .38902 Mdot
.28702 .58101 Mdot
.50018 .71166 Mdot
.38678 .67763 Mdot
.68329 .55774 Mdot
.50075 .67115 Mdot
.70185 .61585 Mdot
.7084 .63841 Mdot
.31889 .56579 Mdot
.56689 .39473 Mdot
.66088 .48308 Mdot
.59819 .23114 Mdot
.573 .37343 Mdot
.57321 .40304 Mdot
.30075 .64312 Mdot
.3189 .61647 Mdot
.43784 .66047 Mdot
.58404 .38588 Mdot
.53711 .40671 Mdot
.34042 .39328 Mdot
.66925 .59982 Mdot
.44376 .68068 Mdot
.71084 .6263 Mdot
.46206 .67756 Mdot
.75583 .50237 Mdot
.56532 .55381 Mdot
.70658 .62878 Mdot
.33436 .6053 Mdot
.3544 .41658 Mdot
.57062 .58648 Mdot
.46605 .70119 Mdot
.45959 .66652 Mdot
.53023 .35924 Mdot
.34241 .36691 Mdot
.35781 .42408 Mdot
.70037 .61725 Mdot
.32932 .59873 Mdot
.57284 .27835 Mdot
.59663 .54795 Mdot
.4524 .74807 Mdot
.46891 .66916 Mdot
.36534 .33552 Mdot
.40832 .40035 Mdot
.54623 .4016 Mdot
.33387 .41826 Mdot
.55059 .38277 Mdot
.35209 .3476 Mdot
.32796 .36281 Mdot
.60117 .40617 Mdot
.44705 .37104 Mdot
.45599 .70698 Mdot
.69821 .77555 Mdot
.57018 .26767 Mdot
.33401 .55742 Mdot
.58053 .27625 Mdot
.48328 .8172 Mdot
.75354 .5275 Mdot
.53727 .38597 Mdot
.55609 .41549 Mdot
.85125 .42183 Mdot
.57556 .42727 Mdot
.59918 .56867 Mdot
.56555 .57031 Mdot
.32987 .41547 Mdot
.60756 .55611 Mdot
.67922 .48806 Mdot
.68574 .64274 Mdot
.46171 .68955 Mdot
.73168 .56288 Mdot
.69505 .61627 Mdot
.35088 .37573 Mdot
.57273 .27505 Mdot
.40856 .41343 Mdot
.42871 .68537 Mdot
.58412 .57361 Mdot
.31853 .60312 Mdot
.66768 .48805 Mdot
.48332 .68164 Mdot
.33728 .58601 Mdot
.58711 .41859 Mdot
.42163 .75391 Mdot
.30206 .56684 Mdot
.71497 .75862 Mdot
.29458 .58737 Mdot
.33473 .57941 Mdot
.66955 .48074 Mdot
.68544 .64283 Mdot
.59306 .53694 Mdot
.53751 .55779 Mdot
.2859 .59409 Mdot
.54928 .83025 Mdot
.49172 .69888 Mdot
.70739 .47157 Mdot
.27568 .39826 Mdot
.56102 .56745 Mdot
.57834 .40341 Mdot
.29319 .60087 Mdot
.54063 .35135 Mdot
.59768 .54036 Mdot
.30067 .60173 Mdot
.60178 .26394 Mdot
.69016 .51302 Mdot
.57685 .55724 Mdot
.58414 .58457 Mdot
.68044 .60267 Mdot
.42037 .64258 Mdot
.35347 .42654 Mdot
.65706 .61847 Mdot
.69688 .44497 Mdot
.57576 .3611 Mdot
.32671 .57836 Mdot
.5861 .56842 Mdot
.30908 .58249 Mdot
.67378 .62763 Mdot
.678 .64875 Mdot
.33923 .37033 Mdot
.29211 .42973 Mdot
.55124 .57645 Mdot
.69121 .40836 Mdot
.56061 .43694 Mdot
.45287 .2762 Mdot
.33387 .43093 Mdot
.56253 .21416 Mdot
.67425 .63889 Mdot
.66282 .60015 Mdot
.6003 .28595 Mdot
.59888 .38268 Mdot
.58422 .29393 Mdot
.6015 .39133 Mdot
.53613 .81451 Mdot
.59138 .27782 Mdot
.44831 .66853 Mdot
.60268 .37527 Mdot
.29069 .49067 Mdot
.58823 .30629 Mdot
.54819 .40996 Mdot
.4737 .68888 Mdot
.53032 .41495 Mdot
.47169 .71583 Mdot
.57583 .4116 Mdot
.45023 .78845 Mdot
.46005 .68759 Mdot
.58435 .6033 Mdot
.54849 .46422 Mdot
.5972 .57418 Mdot
.66702 .6277 Mdot
.7183 .63261 Mdot
.71164 .55897 Mdot
.33028 .40569 Mdot
.48102 .17486 Mdot
.54813 .40863 Mdot
.49052 .69225 Mdot
.32199 .60199 Mdot
.59689 .25455 Mdot
.58121 .36073 Mdot
.57413 .28853 Mdot
.32953 .38701 Mdot
.49378 .69748 Mdot
.67601 .63415 Mdot
.43988 .70783 Mdot
.44796 .79096 Mdot
.4626 .71592 Mdot
.51116 .33705 Mdot
.59823 .2686 Mdot
.60935 .614 Mdot
.45997 .30638 Mdot
.64641 .59739 Mdot
.33544 .37854 Mdot
.5873 .56455 Mdot
.7084 .64758 Mdot
.63949 .50174 Mdot
.35038 .42515 Mdot
.44831 .68017 Mdot
.55584 .39127 Mdot
.58012 .54322 Mdot
.53783 .55664 Mdot
.34297 .36008 Mdot
.68916 .65496 Mdot
.46785 .69552 Mdot
.58197 .55877 Mdot
.68332 .47263 Mdot
.50333 .23471 Mdot
.71213 .45238 Mdot
.55286 .38699 Mdot
.69353 .6136 Mdot
.34259 .36658 Mdot
.57452 .29179 Mdot
.30056 .61511 Mdot
.67153 .48584 Mdot
.57982 .39948 Mdot
.255 .56297 Mdot
.34276 .38737 Mdot
.69553 .64235 Mdot
.29289 .59552 Mdot
.69124 .63515 Mdot
.60119 .56297 Mdot
.37151 .36453 Mdot
.59975 .55459 Mdot
.59448 .284 Mdot
.32433 .59615 Mdot
.35564 .42469 Mdot
.44779 .78952 Mdot
.59297 .5342 Mdot
.45169 .68749 Mdot
.64221 .5014 Mdot
.32995 .37724 Mdot
.36141 .56037 Mdot
.43921 .70615 Mdot
.36932 .62909 Mdot
.63751 .48531 Mdot
.29902 .6049 Mdot
.54961 .4112 Mdot
.3536 .40043 Mdot
.28539 .58308 Mdot
.39368 .65954 Mdot
.55403 .26568 Mdot
.55951 .54983 Mdot
.54375 .3758 Mdot
.19148 .43219 Mdot
.28786 .5035 Mdot
.27883 .36923 Mdot
.34013 .58692 Mdot
.57473 .36671 Mdot
.56645 .56148 Mdot
.5461 .35456 Mdot
.28602 .60204 Mdot
.27741 .59831 Mdot
.46262 .73025 Mdot
.55392 .39514 Mdot
.69739 .63392 Mdot
.45071 .71161 Mdot
.47677 .65615 Mdot
.44229 .65772 Mdot
.29411 .42914 Mdot
.55968 .56359 Mdot
.56477 .56768 Mdot
.75262 .5341 Mdot
.30839 .58134 Mdot
.59737 .57341 Mdot
.54062 .41038 Mdot
.67393 .55429 Mdot
.36008 .40602 Mdot
.47234 .69787 Mdot
.5763 .36573 Mdot
.56808 .27538 Mdot
.58521 .57792 Mdot
.47898 .68876 Mdot
.33092 .43643 Mdot
.52613 .52356 Mdot
.57401 .3872 Mdot
.59455 .27542 Mdot
.35727 .37769 Mdot
.2408 .36758 Mdot
.69302 .47047 Mdot
.55173 .38141 Mdot
.31732 .5742 Mdot
.2341 .38919 Mdot
.58343 .42082 Mdot
.42958 .41097 Mdot
.57783 .59051 Mdot
.51035 .50432 Mdot
.32156 .33661 Mdot
.61088 .37865 Mdot
.43532 .55464 Mdot
.6612 .34611 Mdot
.45968 .57608 Mdot
.5693 .80778 Mdot
.39631 .5499 Mdot
.73337 .74049 Mdot
.33341 .61705 Mdot
.60756 .35847 Mdot
.80012 .31486 Mdot
.28487 .5156 Mdot
.38903 .57229 Mdot
.33784 .54914 Mdot
.64102 .57125 Mdot
.46643 .80622 Mdot
.42199 .7554 Mdot
.57197 .80352 Mdot
.52106 .38134 Mdot
.27572 .45137 Mdot
.59814 .3154 Mdot
.34455 .54122 Mdot
.39306 .70104 Mdot
.5803 .3113 Mdot
.83869 .43827 Mdot
.24685 .60703 Mdot
.8107 .54179 Mdot
.46643 .2105 Mdot
.43547 .75187 Mdot
.67866 .40044 Mdot
.74215 .59673 Mdot
.60991 .25983 Mdot
.48303 .53927 Mdot
.31941 .62647 Mdot
.35936 .4403 Mdot
.25408 .64767 Mdot
.4519 .67338 Mdot
.33335 .36626 Mdot
.23296 .60536 Mdot
.84022 .49777 Mdot
.35721 .60131 Mdot
.43428 .55585 Mdot
.57405 .53728 Mdot
.51606 .49483 Mdot
.64882 .47766 Mdot
.33732 .34387 Mdot
.44772 .77215 Mdot
.47162 .80154 Mdot
.39807 .40586 Mdot
.40003 .6659 Mdot
.62754 .50109 Mdot
.38522 .57046 Mdot
.30294 .34005 Mdot
.64015 .58863 Mdot
.59245 .60147 Mdot
.33301 .43105 Mdot
.80556 .39508 Mdot
.50092 .38918 Mdot
.70061 .43792 Mdot
.40014 .70645 Mdot
.35706 .44829 Mdot
.45117 .21546 Mdot
.37688 .46289 Mdot
.64763 .81034 Mdot
.83595 .54013 Mdot
.61241 .80198 Mdot
.54574 .46965 Mdot
.34474 .62151 Mdot
.59947 .49394 Mdot
.48132 .60737 Mdot
.63859 .79392 Mdot
.24905 .36386 Mdot
.81794 .38471 Mdot
.47346 .45889 Mdot
.85221 .51168 Mdot
.39119 .3762 Mdot
.63282 .5899 Mdot
.28879 .35498 Mdot
.55289 .49854 Mdot
.72948 .51608 Mdot
.85145 .48173 Mdot
.36286 .54719 Mdot
.60694 .53911 Mdot
.28828 .51549 Mdot
.31817 .33206 Mdot
.44242 .77452 Mdot
.61307 .57282 Mdot
.48118 .29027 Mdot
.85402 .45754 Mdot
.44385 .54593 Mdot
.82222 .45651 Mdot
.4579 .77562 Mdot
.24459 .69264 Mdot
.47839 .65516 Mdot
.28678 .62821 Mdot
.82186 .53854 Mdot
.35432 .39549 Mdot
.67294 .79979 Mdot
.40605 .57431 Mdot
.42616 .61732 Mdot
.85008 .44902 Mdot
.62229 .82044 Mdot
.55409 .49112 Mdot
.61055 .60138 Mdot
.256 .64504 Mdot
.48154 .57661 Mdot
.32168 .51505 Mdot
.54389 .5221 Mdot
.19924 .45725 Mdot
.82361 .52423 Mdot
.60361 .82073 Mdot
.80791 .35134 Mdot
.69317 .44123 Mdot
.68771 .57862 Mdot
.39828 .41683 Mdot
.40946 .49346 Mdot
.32578 .52074 Mdot
.8493 .52275 Mdot
.59265 .31448 Mdot
.22378 .39533 Mdot
.58461 .80304 Mdot
.52339 .2445 Mdot
.22939 .44558 Mdot
.26499 .54374 Mdot
.53104 .52833 Mdot
.36395 .34379 Mdot
.71381 .67021 Mdot
.72823 .53125 Mdot
.47397 .27546 Mdot
.40663 .65255 Mdot
.69016 .47794 Mdot
.39789 .45444 Mdot
.71422 .72836 Mdot
.24887 .4367 Mdot
.48065 .28353 Mdot
.41328 .37962 Mdot
.64013 .79167 Mdot
.58859 .80713 Mdot
.22511 .41921 Mdot
.43443 .7251 Mdot
.82499 .46644 Mdot
.35465 .48928 Mdot
.52977 .48824 Mdot
.59589 .32394 Mdot
.60687 .27173 Mdot
.49233 .79485 Mdot
.48767 .36896 Mdot
.76924 .63257 Mdot
.29395 .53038 Mdot
.45866 .31915 Mdot
.75779 .60521 Mdot
.46381 .31219 Mdot
.33749 .32923 Mdot
.43082 .42804 Mdot
.2484 .6056 Mdot
.4539 .38419 Mdot
.84198 .43902 Mdot
.43872 .68224 Mdot
.63559 .79819 Mdot
.35465 .60148 Mdot
.42104 .74877 Mdot
.41213 .61965 Mdot
.40632 .62212 Mdot
.80557 .5665 Mdot
.26674 .53513 Mdot
.6331 .56258 Mdot
.29568 .354 Mdot
.42773 .59085 Mdot
.45848 .2743 Mdot
.54321 .32914 Mdot
.30181 .46045 Mdot
.69108 .65256 Mdot
.48161 .32229 Mdot
.36262 .34228 Mdot
.42838 .70901 Mdot
.52263 .32963 Mdot
.69314 .37297 Mdot
.55904 .58648 Mdot
.68068 .53811 Mdot
.75559 .50747 Mdot
.50013 .46546 Mdot
.63747 .80673 Mdot
.33537 .48637 Mdot
.68666 .54053 Mdot
.32584 .52273 Mdot
.48684 .17657 Mdot
.85384 .50953 Mdot
.79457 .6141 Mdot
.24556 .38684 Mdot
.21587 .43675 Mdot
.29145 .7606 Mdot
.36939 .57578 Mdot
.7336 .72417 Mdot
.35456 .60206 Mdot
.4065 .16774 Mdot
.43649 .68313 Mdot
.59397 .50213 Mdot
.38019 .3756 Mdot
.6877 .37376 Mdot
.84256 .46587 Mdot
.50572 .48068 Mdot
.65913 .62701 Mdot
.28154 .35763 Mdot
.44944 .37352 Mdot
.83052 .43236 Mdot
.81499 .39682 Mdot
.81423 .40598 Mdot
.23398 .59629 Mdot
.4833 .35076 Mdot
.84606 .42812 Mdot
.63847 .53309 Mdot
.47788 .41544 Mdot
.58157 .32322 Mdot
.70908 .41189 Mdot
.71268 .74929 Mdot
.66311 .57864 Mdot
.48551 .57487 Mdot
.39901 .40485 Mdot
.85792 .4524 Mdot
.76108 .52186 Mdot
.52488 .50399 Mdot
.79904 .55126 Mdot
.73301 .64598 Mdot
.76338 .59768 Mdot
.79978 .57846 Mdot
.46213 .54157 Mdot
.27244 .53793 Mdot
.86449 .45392 Mdot
.6255 .78651 Mdot
.35492 .56085 Mdot
.37202 .34382 Mdot
.7025 .76431 Mdot
.22274 .44665 Mdot
.33195 .64169 Mdot
.3887 .37891 Mdot
.50138 .18911 Mdot
.36589 .52662 Mdot
.48759 .54083 Mdot
.58377 .4437 Mdot
.75773 .61988 Mdot
.43382 .67081 Mdot
.678 .76615 Mdot
.35122 .51159 Mdot
.47185 .41442 Mdot
.70601 .54364 Mdot
.58135 .82638 Mdot
.48004 .50037 Mdot
.51512 .30678 Mdot
.33727 .48605 Mdot
.24455 .42048 Mdot
.23524 .44032 Mdot
.48135 .22181 Mdot
.54619 .42682 Mdot
.84364 .49299 Mdot
.75373 .71827 Mdot
.80395 .58081 Mdot
.23364 .42235 Mdot
.27117 .72723 Mdot
.34423 .5983 Mdot
.64899 .53859 Mdot
.69273 .3519 Mdot
.44822 .51433 Mdot
.66825 .33545 Mdot
.29618 .56254 Mdot
.45065 .21549 Mdot
.412 .61359 Mdot
.63871 .53233 Mdot
.27012 .41995 Mdot
.43328 .6066 Mdot
.50665 .31712 Mdot
.40558 .37057 Mdot
.20822 .40661 Mdot
.64385 .78895 Mdot
.43838 .6771 Mdot
.44566 .73717 Mdot
.48184 .38881 Mdot
.62778 .60484 Mdot
.60111 .5262 Mdot
.53478 .48527 Mdot
.45865 .2462 Mdot
.2882 .74407 Mdot
.78244 .60178 Mdot
.69644 .77576 Mdot
.79932 .58167 Mdot
.60312 .80653 Mdot
.39808 .68449 Mdot
.69199 .53058 Mdot
.36396 .6133 Mdot
.34248 .61674 Mdot
.68224 .52249 Mdot
.58455 .81826 Mdot
.52903 .49704 Mdot
.28901 .36019 Mdot
.54498 .42181 Mdot
.75198 .51971 Mdot
.73351 .59316 Mdot
.66529 .52975 Mdot
.49104 .22966 Mdot
.32273 .43613 Mdot
.66109 .56297 Mdot
.5064 .53414 Mdot
.59296 .24442 Mdot
.21564 .43216 Mdot
.28541 .58132 Mdot
.39041 .35663 Mdot
.58091 .82775 Mdot
.29287 .756 Mdot
.45154 .59113 Mdot
.51166 .37541 Mdot
.82258 .51523 Mdot
.53668 .45753 Mdot
.2105 .44735 Mdot
.51308 .19214 Mdot
.38517 .62885 Mdot
.39826 .39704 Mdot
.4886 .44103 Mdot
.41889 .62555 Mdot
.26048 .42208 Mdot
.39531 .36473 Mdot
.60489 .2606 Mdot
.82733 .54778 Mdot
.54543 .44202 Mdot
.47364 .54909 Mdot
.69716 .46042 Mdot
.39181 .50333 Mdot
.41465 .57999 Mdot
.71312 .551 Mdot
.44987 .57031 Mdot
.80777 .40873 Mdot
.44555 .22485 Mdot
.49477 .57348 Mdot
.63939 .54329 Mdot
.63557 .52792 Mdot
.46603 .21134 Mdot
.30122 .33622 Mdot
.29937 .52994 Mdot
.52634 .4233 Mdot
.82679 .56147 Mdot
.46158 .45301 Mdot
.69783 .54134 Mdot
.38159 .47236 Mdot
.52934 .42095 Mdot
.61834 .54701 Mdot
.80142 .57344 Mdot
.5101 .50862 Mdot
.79765 .3016 Mdot
.56 .81636 Mdot
.32236 .46799 Mdot
.3233 .34099 Mdot
.65299 .79094 Mdot
.30773 .48187 Mdot
.40609 .55666 Mdot
.3561 .50376 Mdot
.68962 .7703 Mdot
.50161 .50209 Mdot
.51138 .51758 Mdot
.20271 .42051 Mdot
.83745 .41607 Mdot
.47738 .56769 Mdot
.32403 .64184 Mdot
.68634 .58262 Mdot
.58944 .37297 Mdot
.36715 .46991 Mdot
.17661 .48333 Mdot
.41193 .46464 Mdot
.46661 .58275 Mdot
.74724 .73109 Mdot
.51224 .47927 Mdot
.33223 .48907 Mdot
.80055 .3048 Mdot
.80138 .29513 Mdot
.35851 .47081 Mdot
.84648 .53132 Mdot
.51568 .51359 Mdot
.21303 .45027 Mdot
.3178 .62853 Mdot
.54014 .33936 Mdot
.45265 .27019 Mdot
.81534 .58231 Mdot
.26236 .73134 Mdot
.31937 .51862 Mdot
.38523 .39608 Mdot
.81568 .58979 Mdot
.46974 .42576 Mdot
.61993 .5275 Mdot
.24667 .69301 Mdot
.5152 .82771 Mdot
.64927 .80615 Mdot
.4946 .21748 Mdot
.48905 .80153 Mdot
.53728 .79737 Mdot
.35463 .53635 Mdot
.70746 .76299 Mdot
.56676 .53245 Mdot
.49626 .17722 Mdot
.6378 .793 Mdot
.20014 .43693 Mdot
.45973 .79175 Mdot
.41715 .57756 Mdot
.52411 .48178 Mdot
.4386 .42405 Mdot
.20016 .46181 Mdot
.25102 .55709 Mdot
.50138 .43965 Mdot
.65642 .50625 Mdot
.3384 .33125 Mdot
.23105 .38099 Mdot
.52845 .18875 Mdot
.54493 .48332 Mdot
.79715 .36688 Mdot
.25885 .56423 Mdot
.64234 .51434 Mdot
.30865 .34733 Mdot
.72278 .56886 Mdot
.63181 .55349 Mdot
.59974 .36827 Mdot
.82849 .5428 Mdot
.63067 .55419 Mdot
.80383 .38 Mdot
.66908 .80542 Mdot
.79991 .54127 Mdot
.47084 .61342 Mdot
.57171 .51365 Mdot
.7131 .74552 Mdot
.72279 .73273 Mdot
.80248 .36181 Mdot
.57635 .79834 Mdot
.67937 .52018 Mdot
.50995 .45546 Mdot
.54757 .33006 Mdot
.50451 .3306 Mdot
.65788 .78745 Mdot
.46239 .20815 Mdot
.75656 .5975 Mdot
.24902 .39772 Mdot
.58422 .82161 Mdot
.56752 .48089 Mdot
.7159 .56426 Mdot
.39576 .47567 Mdot
.61255 .59659 Mdot
.49123 .71195 Mdot
.84361 .39429 Mdot
.22262 .42395 Mdot
.77249 .59706 Mdot
.2226 .40121 Mdot
.41157 .36471 Mdot
.54932 .80808 Mdot
.28443 .35193 Mdot
.53494 .61707 Mdot
.41412 .72395 Mdot
.74516 .66215 Mdot
.5418 .49579 Mdot
.18838 .44204 Mdot
.5079 .25542 Mdot
.80996 .56628 Mdot
.75924 .60675 Mdot
.80062 .33842 Mdot
.66415 .5679 Mdot
.48054 .32162 Mdot
.80126 .38947 Mdot
.2446 .40285 Mdot
.65377 .52537 Mdot
.83284 .42738 Mdot
.27368 .40036 Mdot
.83724 .53639 Mdot
.30733 .61472 Mdot
.63344 .54356 Mdot
.18615 .46608 Mdot
.6501 .53091 Mdot
.64571 .52725 Mdot
.77875 .61173 Mdot
.29242 .51296 Mdot
.32346 .48934 Mdot
.35176 .49069 Mdot
.4301 .76066 Mdot
.53349 .34416 Mdot
.46158 .55245 Mdot
.81008 .35473 Mdot
.55057 .4264 Mdot
.61838 .77703 Mdot
.63595 .80213 Mdot
.36267 .61694 Mdot
.52718 .47551 Mdot
.19019 .45314 Mdot
.50857 .21025 Mdot
.74346 .53545 Mdot
.8387 .42242 Mdot
.52663 .4744 Mdot
.68648 .35811 Mdot
.55151 .20693 Mdot
.26244 .64182 Mdot
.30827 .52516 Mdot
.44087 .55722 Mdot
.52144 .44729 Mdot
.69085 .4693 Mdot
.61003 .80068 Mdot
.74011 .73694 Mdot
.79728 .36295 Mdot
.31015 .52749 Mdot
.65953 .53273 Mdot
.42723 .41933 Mdot
.74121 .62047 Mdot
.80907 .34558 Mdot
.47387 .81105 Mdot
.36459 .34332 Mdot
.59352 .81787 Mdot
.29245 .51817 Mdot
.62192 .52831 Mdot
.67214 .52719 Mdot
.8071 .39997 Mdot
.37291 .42026 Mdot
.48341 .45641 Mdot
.4044 .45486 Mdot
.67571 .49306 Mdot
.40137 .58635 Mdot
.49399 .19142 Mdot
.25762 .54146 Mdot
.79969 .3373 Mdot
.5221 .80041 Mdot
.53286 .23221 Mdot
.79987 .32131 Mdot
.32551 .43867 Mdot
.3987 .58624 Mdot
.23865 .67684 Mdot
.67957 .54104 Mdot
.46094 .64796 Mdot
.53544 .40774 Mdot
.67191 .51359 Mdot
.2962 .46899 Mdot
.66563 .57331 Mdot
.68784 .65725 Mdot
.38181 .35227 Mdot
.54917 .80207 Mdot
.40028 .36448 Mdot
.74141 .73216 Mdot
.46089 .53714 Mdot
.33869 .33645 Mdot
.5338 .19727 Mdot
.39932 .68156 Mdot
.24429 .41394 Mdot
.8081 .54371 Mdot
.70761 .4166 Mdot
.36983 .35242 Mdot
.37697 .35717 Mdot
.2755 .42024 Mdot
.37328 .60735 Mdot
.83004 .50395 Mdot
.62453 .81686 Mdot
.45098 .7463 Mdot
.27964 .42091 Mdot
.54922 .46661 Mdot
.52896 .48541 Mdot
.78178 .57888 Mdot
.44377 .71285 Mdot
.86087 .49742 Mdot
.46978 .17994 Mdot
.2717 .44999 Mdot
.45544 .50409 Mdot
.70186 .36489 Mdot
.61872 .50453 Mdot
.40266 .66562 Mdot
.5471 .48856 Mdot
.33155 .47546 Mdot
.33006 .44811 Mdot
.40588 .60348 Mdot
.67508 .64182 Mdot
.43089 .721 Mdot
.35581 .57123 Mdot
.4774 .21886 Mdot
.65018 .79762 Mdot
.41759 .39239 Mdot
.60809 .52799 Mdot
.41279 .67096 Mdot
.50595 .33918 Mdot
.70567 .39088 Mdot
.85594 .41911 Mdot
.81243 .5264 Mdot
.31843 .3815 Mdot
.25181 .43511 Mdot
.45628 .78172 Mdot
.78146 .60039 Mdot
.48888 .47114 Mdot
.65448 .786 Mdot
.48175 .29858 Mdot
.79246 .57487 Mdot
.32091 .33814 Mdot
.43759 .53905 Mdot
.61629 .81027 Mdot
.73178 .65969 Mdot
.59111 .82358 Mdot
.51245 .21842 Mdot
.50545 .41019 Mdot
.53059 .82706 Mdot
.40792 .46059 Mdot
.53239 .50557 Mdot
.59035 .24228 Mdot
.44675 .51917 Mdot
.69373 .76445 Mdot
.32489 .44387 Mdot
.64529 .57501 Mdot
.2541 .3731 Mdot
.31785 .51864 Mdot
.82158 .52596 Mdot
.23762 .43058 Mdot
.61799 .81794 Mdot
.52949 .34626 Mdot
.73897 .65148 Mdot
.46196 .2183 Mdot
.70017 .42899 Mdot
.59822 .54636 Mdot
.47377 .28825 Mdot
.60824 .5454 Mdot
.75615 .53288 Mdot
.51175 .32354 Mdot
.84708 .47488 Mdot
.75359 .51172 Mdot
.4395 .42504 Mdot
.62782 .59175 Mdot
.37395 .41126 Mdot
.85792 .47996 Mdot
.74161 .52987 Mdot
.19585 .46214 Mdot
.64951 .80488 Mdot
.57856 .79394 Mdot
.79946 .31714 Mdot
.2913 .51578 Mdot
.46071 .40032 Mdot
.71267 .7589 Mdot
.46715 .4492 Mdot
.54077 .79685 Mdot
.54168 .49565 Mdot
.40208 .41651 Mdot
.84483 .44053 Mdot
.6324 .57594 Mdot
.43011 .43499 Mdot
.55871 .26917 Mdot
.39599 .39824 Mdot
.73615 .52011 Mdot
.56059 .47443 Mdot
.44696 .67681 Mdot
.69396 .36491 Mdot
.48748 .79418 Mdot
.28131 .42997 Mdot
.64618 .79654 Mdot
.66336 .77842 Mdot
.69831 .58912 Mdot
.46921 .61769 Mdot
.79719 .31561 Mdot
.47335 .35156 Mdot
.60975 .38304 Mdot
.39993 .36648 Mdot
.69196 .65862 Mdot
.59958 .79455 Mdot
.52428 .41267 Mdot
.68737 .39247 Mdot
.48138 .29306 Mdot
.81974 .56949 Mdot
.40456 .48689 Mdot
.25229 .58282 Mdot
.27437 .40707 Mdot
.19806 .45984 Mdot
.24672 .37628 Mdot
.27976 .51505 Mdot
.69414 .7624 Mdot
.4519 .59044 Mdot
.4355 .55007 Mdot
.44467 .41001 Mdot
.67806 .76117 Mdot
.32844 .53144 Mdot
.30669 .56042 Mdot
.45787 .25211 Mdot
.79738 .35154 Mdot
.37616 .34579 Mdot
.42315 .57788 Mdot
.48503 .52426 Mdot
.5211 .43862 Mdot
.32332 .51623 Mdot
.3166 .49581 Mdot
.40003 .37592 Mdot
.81978 .43293 Mdot
.48893 .55415 Mdot
.57488 .51667 Mdot
.57624 .81383 Mdot
.47315 .52915 Mdot
.66481 .78021 Mdot
.44642 .37054 Mdot
.81695 .41351 Mdot
.69665 .54309 Mdot
.73073 .64077 Mdot
.53448 .41497 Mdot
.25471 .39041 Mdot
.8017 .57509 Mdot
.48678 .4709 Mdot
.47383 .59847 Mdot
.28155 .34743 Mdot
.6658 .80313 Mdot
.58545 .59746 Mdot
.28559 .74069 Mdot
.61556 .59855 Mdot
.69329 .37936 Mdot
.68837 .36697 Mdot
.37168 .61811 Mdot
.52859 .48913 Mdot
.36518 .54063 Mdot
.51389 .43535 Mdot
.46341 .24045 Mdot
.76372 .64932 Mdot
.83777 .38747 Mdot
.35606 .44967 Mdot
.63631 .81969 Mdot
.3188 .4605 Mdot
.38277 .43517 Mdot
.52495 .79886 Mdot
.48816 .60424 Mdot
.48252 .37513 Mdot
.67655 .57911 Mdot
.31775 .43911 Mdot
.82958 .3777 Mdot
.46358 .58464 Mdot
.64924 .57585 Mdot
.44847 .77781 Mdot
.41605 .58608 Mdot
.24867 .64763 Mdot
.34973 .60722 Mdot
.67858 .79391 Mdot
.63892 .79385 Mdot
.24669 .59708 Mdot
.51475 .5129 Mdot
.4735 .59313 Mdot
.82926 .43241 Mdot
.62427 .59211 Mdot
.81589 .53783 Mdot
.23373 .58931 Mdot
.47431 .23707 Mdot
.75041 .50891 Mdot
.7305 .53099 Mdot
.70457 .42786 Mdot
.48587 .26346 Mdot
.8175 .46295 Mdot
.55424 .57608 Mdot
.43862 .73393 Mdot
.46193 .79228 Mdot
.81133 .35197 Mdot
.26045 .43214 Mdot
.55586 .54749 Mdot
.7435 .61197 Mdot
.48834 .55105 Mdot
.6397 .51155 Mdot
.35065 .49676 Mdot
.5956 .52375 Mdot
.24978 .62964 Mdot
.23206 .39833 Mdot
.82586 .56046 Mdot
.53071 .4037 Mdot
.66036 .33374 Mdot
.34803 .54137 Mdot
.44598 .64781 Mdot
.25943 .3624 Mdot
.85247 .41505 Mdot
.30174 .56202 Mdot
.23998 .67255 Mdot
.36906 .61193 Mdot
.77669 .59508 Mdot
.27186 .73404 Mdot
.37519 .60992 Mdot
.73685 .74083 Mdot
.28992 .4669 Mdot
.51044 .23672 Mdot
.22194 .39117 Mdot
.75722 .52987 Mdot
.47153 .28658 Mdot
.54255 .52313 Mdot
.83747 .52295 Mdot
.62808 .51103 Mdot
.6413 .56762 Mdot
.81699 .44947 Mdot
.60899 .81366 Mdot
.5659 .81658 Mdot
.36919 .57817 Mdot
.38746 .39427 Mdot
.30181 .76367 Mdot
.42605 .75028 Mdot
.45065 .18061 Mdot
.81103 .52368 Mdot
.56145 .24154 Mdot
.48524 .4664 Mdot
.3602 .48512 Mdot
.83599 .44347 Mdot
.68593 .76408 Mdot
.53051 .51221 Mdot
.42384 .67617 Mdot
.72536 .54078 Mdot
.73597 .61305 Mdot
.32638 .49673 Mdot
.7912 .55513 Mdot
.40248 .66873 Mdot
.63198 .57832 Mdot
.62395 .80967 Mdot
.25515 .38929 Mdot
.69259 .43662 Mdot
.79931 .35409 Mdot
.70312 .4003 Mdot
.56755 .82696 Mdot
.23371 .59593 Mdot
.45463 .78639 Mdot
.81269 .35983 Mdot
.27407 .43922 Mdot
.50034 .28499 Mdot
.79656 .30258 Mdot
.85162 .51202 Mdot
.47569 .59322 Mdot
.54868 .43869 Mdot
.72822 .74727 Mdot
.42936 .69023 Mdot
.77097 .61155 Mdot
.45161 .21287 Mdot
.5483 .81406 Mdot
.52687 .31944 Mdot
.53872 .43385 Mdot
.62232 .52184 Mdot
.3123 .4053 Mdot
.38914 .38308 Mdot
.44255 .76023 Mdot
.58454 .81732 Mdot
.47777 .21061 Mdot
.44554 .22518 Mdot
.50867 .21746 Mdot
.32617 .36899 Mdot
.83048 .53404 Mdot
.60428 .61896 Mdot
.4662 .20056 Mdot
.82359 .4276 Mdot
.68106 .33227 Mdot
.35054 .52881 Mdot
.45774 .23666 Mdot
.6875 .53287 Mdot
.48573 .79206 Mdot
.80766 .32617 Mdot
.46237 .25706 Mdot
.86206 .49025 Mdot
.79584 .61684 Mdot
.32722 .37134 Mdot
.3002 .45067 Mdot
.61013 .50041 Mdot
.46792 .56895 Mdot
.25092 .63637 Mdot
.42077 .74776 Mdot
.56409 .79775 Mdot
.42129 .68547 Mdot
.53859 .37149 Mdot
.36437 .47805 Mdot
.80955 .56047 Mdot
.62467 .53277 Mdot
.8143 .55491 Mdot
.47964 .24865 Mdot
.55095 .42501 Mdot
.79539 .29136 Mdot
.21121 .45101 Mdot
.53625 .33123 Mdot
.5486 .58677 Mdot
.5594 .54413 Mdot
.60022 .36468 Mdot
.27944 .5899 Mdot
.67452 .55226 Mdot
.52646 .8134 Mdot
.83668 .51903 Mdot
.28316 .42541 Mdot
.62107 .50728 Mdot
.34565 .57634 Mdot
.63842 .48068 Mdot
.52756 .31582 Mdot
.30844 .55683 Mdot
.50425 .80782 Mdot
.27119 .65367 Mdot
.3276 .52492 Mdot
.40139 .58314 Mdot
.66631 .50816 Mdot
.55334 .55671 Mdot
.51514 .80394 Mdot
.36798 .62247 Mdot
.34214 .53469 Mdot
.61437 .81929 Mdot
.49156 .2698 Mdot
.28966 .52234 Mdot
.46886 .77933 Mdot
.65826 .5262 Mdot
.38327 .46804 Mdot
.48361 .58107 Mdot
.50497 .19193 Mdot
.82994 .45868 Mdot
.49254 .74492 Mdot
.55329 .57561 Mdot
.55856 .20507 Mdot
.84327 .47166 Mdot
.33246 .57475 Mdot
.75293 .71477 Mdot
.49052 .60089 Mdot
.25842 .36938 Mdot
.579 .22874 Mdot
.51718 .47087 Mdot
.59509 .30862 Mdot
.5682 .44458 Mdot
.67043 .41445 Mdot
.23494 .64444 Mdot
.53209 .48053 Mdot
.41281 .59035 Mdot
.44568 .58229 Mdot
.64945 .55345 Mdot
.58807 .31411 Mdot
.57144 .362 Mdot
.58842 .59543 Mdot
.70832 .51977 Mdot
.5915 .51819 Mdot
.64905 .56141 Mdot
.27096 .53959 Mdot
.51492 .80552 Mdot
.56209 .81594 Mdot
.48176 .35929 Mdot
.8396 .44217 Mdot
.58492 .24675 Mdot
.81011 .52897 Mdot
.37779 .49926 Mdot
.26974 .5374 Mdot
.70158 .39523 Mdot
.80634 .32736 Mdot
.41673 .43052 Mdot
.53393 .59705 Mdot
.79147 .61938 Mdot
.80064 .55575 Mdot
.26604 .55134 Mdot
.19723 .43217 Mdot
.46375 .79438 Mdot
.62659 .51581 Mdot
.23224 .39292 Mdot
.4566 .74382 Mdot
.78589 .60074 Mdot
.50201 .42061 Mdot
.48547 .60079 Mdot
.48866 .19388 Mdot
.51075 .33618 Mdot
.47392 .72349 Mdot
.51203 .19222 Mdot
.48704 .2624 Mdot
.81698 .46551 Mdot
.60843 .37863 Mdot
.42904 .50658 Mdot
.42731 .41676 Mdot
.80064 .34481 Mdot
.49374 .71681 Mdot
.68589 .35617 Mdot
.45795 .17308 Mdot
.23412 .64316 Mdot
.54129 .79524 Mdot
.79688 .35919 Mdot
.3433 .61549 Mdot
.51758 .44109 Mdot
.17204 .49631 Mdot
.42306 .42432 Mdot
.40824 .37649 Mdot
.35771 .57295 Mdot
.73168 .62366 Mdot
.41057 .44443 Mdot
.8092 .31475 Mdot
.79254 .57969 Mdot
.47318 .38015 Mdot
.44502 .1791 Mdot
.62887 .80677 Mdot
.67663 .35874 Mdot
.27666 .52741 Mdot
.82703 .54361 Mdot
.24611 .6312 Mdot
.71724 .75561 Mdot
.47356 .53851 Mdot
.31607 .45519 Mdot
.72998 .60568 Mdot
.225 .40535 Mdot
.5264 .46747 Mdot
.44361 .2162 Mdot
.21654 .42994 Mdot
.7425 .59678 Mdot
.49706 .50104 Mdot
.36027 .45624 Mdot
.33153 .46963 Mdot
.46213 .50853 Mdot
.48772 .6082 Mdot
.42425 .57757 Mdot
.44105 .54893 Mdot
.32856 .52968 Mdot
.44823 .50059 Mdot
.20833 .45629 Mdot
.34971 .62349 Mdot
.49415 .23395 Mdot
.47674 .78655 Mdot
.65916 .5657 Mdot
.43428 .68168 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0POooool2o`000<Kooooo000Looooo`03o`000?oooooooooo083ooooo0ol0
0002ooooo`Ko0000__ooool001cooooo00?o0000ooooooooool0P?ooool2o`0000?ooooo1_l00007
ooooo`?o0000]?ooool001cooooo00?o0000ooooooooool0QOooool5o`0000Oooooo1?l00002oooo
o`?o0000[oooool001cooooo00?o0000ooooooooool0Q_ooool5o`0000Kooooo0_l00004ooooo`Go
000000?oooooo`000?l00000Z_ooool001cooooo00?o0000ooooooooool0ROooool8o`0000Cooooo
0_l00003ooooo`;o000000?oooooo`000?l00000Z_ooool001cooooo00?o0000ooooooooool0Rooo
ool6o`0000Cooooo0_l0000>ooooo`;o0000X_ooool001cooooo00?o0000ooooooooool0S?ooool5
o`0001Cooooo0_l0002Rooooo`007?ooool00ol0003oooooooooo`2>ooooo`Co00003Oooool2o`00
00Oooooo0_l0002Oooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5
o`0000Kooooo00?o0000ooooooooool0S_ooool4o`0000Wooooo1ol000000ooooooo0000o`000003
ooooo`;o0000Woooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo08[ooooo2_l00007ooooo`Co0000
00Coooooo`000?l0003ooooo0_l0002Tooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooo
ooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0R_ooool;o`0001Gooooo
0_l0002Mooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ
8B7ok^k^00Kooooo0ol0002>ooooo`So00005?ooool2o`0009gooooo00000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`2?
ooooo`Oo00007?ooool2o`0009Gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo
00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2?ooooo`Ko00006Oooool3o`00
0003ooooool0003o000009Gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000
okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo08oooooo0_l000000ooooooo0000o`00
0002o`000003ooooool0003o000000Sooooo0_l0000:ooooo`Oo0000UOooool00006ooooooo^k^ko
<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000oooooooo
ool0Soooool7o`000003ooooool0003o000000Sooooo0_l0000:ooooo`So0000U?ooool001cooooo
00?o0000ooooooooool0S?ooool8o`0000Wooooo0_l00002ooooo`Co00001_ooool4o`0000Cooooo
1?l0002Booooo`007?ooool00ol0003oooooooooo`2<ooooo`So00000oooool2o`0000Cooooo0_l0
0002ooooo`Co00001Oooool4o`0000Oooooo0ol0002Aooooo`007?ooool00ol0003oooooooooo`2?
ooooo`;o00001_ooool4o`0000cooooo1ol00008ooooo`Co0000Soooool001cooooo00?o0000oooo
ooooool0SOooool2o`000003ooooool0003o000000Oooooo0_l0000;ooooo`Ko00002_ooool4o`00
08oooooo000Looooo`03o`000?oooooooooo08gooooo0_l000000ooooooo0000o`00000:ooooo`;o
00001Oooool2o`000003ooooool0003o000000kooooo1?l0002?ooooo`007?ooool00ol0003ooooo
ooooo`2@ooooo`;o00002_ooool2o`0000;ooooo0_l000001?oooooo0000o`000?l00003ooooo`;o
00003?ooool5o`0000?ooooo0_l00028ooooo`007?ooool00ol0003oooooooooo`2?ooooo`Co0000
2_ooool9o`0000?ooooo0_l0000?ooooo`;o00000oooool3o`0008Oooooo000Looooo`03o`000?oo
oooooooo08oooooo1?l00003ooooo`;o00001Oooool7o`0001cooooo0_l00027ooooo`007?ooool0
0ol0003oooooooooo`2@ooooo`Go000000?oooooo`000?l000004Oooool2o`0000;ooooo0_l00003
ooooo`?o00001oooool2o`0008_ooooo000Looooo`03o`000?oooooooooo097ooooo1?l00007oooo
o`;o00002?ooool2o`000005ooooool0003o0000o`000?ooool02?l00007ooooo`?o0000R_ooool0
01cooooo00?o0000ooooooooool0TOooool2o`0000Gooooo0_l00002ooooo`;o00001Oooool2o`00
0003ooooool0003o000000;ooooo1?l000000ooooooo0000o`000002o`0000Oooooo0_l000001?oo
oooo0000o`000?l00029ooooo`007?ooool2o`00093ooooo1?l00005ooooo`;o00001oooool4o`00
00Cooooo1ol00002ooooo`?o00001?ooool7o`0008Wooooo000Looooo`03o`000?oooooooooo08ko
oooo1Ol0000>ooooo`;o00001Oooool=o`0000?ooooo2Ol00028ooooo`007?ooool00ol0003ooooo
ooooo`2>ooooo`Ko00003Oooool2o`0000;ooooo1_l00002ooooo`Ko00000_ooool<o`0008Sooooo
000Looooo`03o`000?oooooooooo093ooooo1?l0000Aooooo`Co00001oooool3o`0000;ooooo3ol0
0025ooooo`007?ooool00ol0003oooooooooo`2@ooooo`;o00002?ooool2o`0001Cooooo0ol00005
ooooo`co0000QOooool001cooooo00?o0000ooooooooool0Soooool3o`0000Sooooo0_l00002oooo
o`;o00000_ooool2o`0000cooooo0ol00002ooooo`go0000Qoooool001cooooo00?o0000oooooooo
ool0Soooool3o`0000[ooooo1?l00002ooooo`;o00003?ooool4o`000003ooooool0003o000000_o
0000Qoooool001cooooo00?o0000ooooooooool0Soooool3o`0000[ooooo0_l00003ooooo`?o0000
3Oooool3o`000003ooooool0003o000000co0000Q_ooool001cooooo00?o0000ooooooooool0Sooo
ool4o`0000?ooooo0_l00009ooooo`?o00003Oooool2o`0000;ooooo3_l00026ooooo`007?ooool0
0ol0003oooooooooo`2?ooooo`Co00000oooool2o`0001Wooooo0ol000000ooooooo0000o`00000<
o`0008Kooooo000Looooo`03o`000?oooooooooo093ooooo0_l0000Pooooo`;o000000?oooooo`00
0?l000002ol00027ooooo`007?ooool00ol0003oooooooooo`2@ooooo`?o00001Oooool2o`0000Go
oooo0_l0000Aooooo`;o000000?oooooo`000?l000002ol00027ooooo`007?ooool00ol0003ooooo
ooooo`2Aooooo`;o00000_ooool5o`0000Gooooo0_l0000Aooooo`;o00000_ooool<o`0003kooooo
0_l00017ooooo`007?ooool00ol0003oooooooooo`2Eooooo`?o000000?oooooo`000?l000005ooo
ool?o`0003kooooo1?l00016ooooo`007?ooool00ol0003oooooooooo`2Iooooo`;o000000?ooooo
o`000?l000005Oooool=o`000003ooooool0003o000003cooooo1Ol00015ooooo`007?ooool00ol0
003oooooooooo`2Iooooo`;o000000?oooooo`000?l000000oooool2o`00013ooooo0_l000000ooo
oooo0000o`000008o`000003ooooool0003o000003gooooo1?l00015ooooo`007?ooool2o`0009[o
oooo0_l000000ooooooo0000o`000003ooooo`;o00004oooool:o`0003oooooo0_l000000ooooooo
0000o`000015ooooo`007?ooool00ol0003oooooooooo`2fooooo`[o0000?oooool2o`0004Sooooo
000Looooo`03o`000?oooooooooo09;ooooo0_l0000@ooooo`;o00003oooool:o`00043ooooo0ol0
00000ooooooo0000o`000014ooooo`007?ooool00ol0003oooooooooo`2Aooooo`?o00002?ooool2
o`0000Kooooo0_l0000?ooooo`_o0000@?ooool2o`000003ooooool0003o000004Cooooo000Loooo
o`03o`000?oooooooooo097ooooo1?l00007ooooo`;o00006_ooool8o`0004?ooooo0_l00014oooo
o`007?ooool00ol0003oooooooooo`2Aooooo`Co00001oooool2o`0000[ooooo0_l0000=ooooo`[o
0000?_ooool3o`000003ooooool0003o000004Cooooo000Looooo`03o`000?oooooooooo097ooooo
0_l00009ooooo`;o00000oooool2o`0000Cooooo0ol0000=ooooo`;o00000_ooool6o`0003kooooo
0ol000000ooooooo0000o`000014ooooo`007?ooool00ol0003oooooooooo`2Aooooo`;o00001Ooo
ool3o`0000Kooooo0_l00004ooooo`;o00003oooool3o`000004ooooool0003o0000o`00047ooooo
0_l00017ooooo`007?ooool00ol0003oooooooooo`2Hooooo`?o00000_ooool2o`0000?ooooo0_l0
000Dooooo`So0000@?ooool2o`000004ooooool0003o0000o`0004?ooooo000Looooo`03o`000?oo
oooooooo06Gooooo0_l00003ooooo`?o0000<?ooool3o`0000;ooooo0_l00009ooooo`;o00002_oo
ool7o`0004;ooooo1?l00013ooooo`007?ooool00ol0003oooooooooo`1Tooooo`?o00000oooool4
o`0000?ooooo0_l0000Zooooo`Go00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002
o`0002Sooooo0_l0000Wooooo`Co0000@oooool001cooooo00?o0000ooooooooool0G_ooool2o`00
00Cooooo0_l00004ooooo`Co00000oooool4o`0002Wooooo1?l00004ooooo`;o00000_ooool2o`00
00;ooooo0ol0000:ooooo`;o00005_ooool4o`0000;ooooo0_l0000Yooooo`;o0000@oooool001co
oooo00?o0000ooooooooool0G_ooool2o`0000Gooooo0_l00003ooooo`;o00001Oooool4o`0002Wo
oooo0_l00002ooooo`?o00005_ooool2o`0000;ooooo0_l0000Booooo`Co0000:Oooool2o`0000;o
oooo0_l00013ooooo`007?ooool00ol0003oooooooooo`1Nooooo`?o00001?ooool2o`0000?ooooo
0_l00006ooooo`;o0000:_ooool2o`000003ooooool0003o000000Co00001Oooool2o`00017ooooo
0ol0000@ooooo`;o0000;?ooool2o`0000;ooooo0_l00013ooooo`007?ooool00ol0003ooooooooo
o`1Eooooo`?o00001oooool2o`000004ooooool0003o0000ooooo`;o00000oooool2o`0000Kooooo
1Ol00002ooooo`;o00005Oooool2o`0000oooooo0_l00002ooooo`;o00000oooool4o`0000Kooooo
1_l00003ooooo`;o000000?oooooo`000?l000004?ooool2o`0002cooooo0_l00002ooooo`;o0000
@oooool001cooooo00?o0000ooooooooool0EOooool5o`0000Oooooo0ol000000ooooooo0000o`00
0003ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000009o`0001?ooooo0_l0
000Fooooo`Co00001Oooool>o`000003ooooool0003o0000013ooooo0ol0000[ooooo`;o000000?o
ooooo`000?l000000_l00012ooooo`007?ooool2o`0005;ooooo0_l00005ooooo`;o00001oooool2
o`0000[ooooo1?l00005ooooo`Co000000Coooooo`000?l0003ooooo0_l0000Iooooo`;o00002Ooo
ool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000001Ol000000ooooooo0000o`00
0004o`0000;ooooo0ol0000@ooooo`?o0000;_ooool4o`0004;ooooo000Looooo`03o`000?oooooo
oooo057ooooo0_l00006ooooo`;o000000?oooooo`000?l000002oooool4o`0000Gooooo1?l00002
ooooo`;o00001?ooool2o`0001Kooooo0_l000000ooooooo0000o`000009ooooo`;o00001Oooool>
o`000003ooooool0003o000000;o000000?oooooo`000?l000007?ooool2o`00023ooooo0_l00002
ooooo`Co0000@_ooool001cooooo00?o0000ooooooooool0Coooool4o`0000Kooooo1Ol0000;oooo
o`go00000_ooool2o`000004ooooool0003o0000ooooo`So00002Oooool2o`0000Gooooo0_l0000<
ooooo`;o00001?oooolHo`0001Wooooo1?l0000Pooooo`?o000000?oooooo`000?l000000_l00012
ooooo`007?ooool00ol0003oooooooooo`1=ooooo`Co00001oooool4o`0000gooooo2Ol000000ooo
oooo0000o`000002ooooo`;o00000_ooool2o`0000?ooooo1_l00009ooooo`;o00002?ooool2o`00
00Wooooo0_l00002oooooaOo000000?oooooo`000?l000000_l0000Dooooo`;o000000?oooooo`00
0?l000008_ooool3o`000004ooooool0003o0000o`0004?ooooo000Looooo`03o`000?oooooooooo
04cooooo0ol00002ooooo`;o00001Oooool4o`0000[ooooo3ol00002ooooo`;o00003?ooool2o`00
00Sooooo0_l00008ooooo`;o00003Oooool5o`000003ooooool0003o0000017o000000?oooooo`00
0?l000005?ooool2o`000003ooooool0003o000000Cooooo0ol0000Kooooo`Co000000?oooooo`00
0?l00000@oooool001cooooo00?o0000ooooooooool0Boooool4o`0000;ooooo0_l00005ooooo`?o
00002oooool>o`000003ooooool0003o000000Kooooo0ol00002ooooo`;o000000?oooooo`000?l0
00002?ooool2o`0001[ooooo5_l0000Mooooo`Ko00006oooool4o`0000Cooooo0_l00010ooooo`00
7?ooool00ol0003oooooooooo`1;ooooo`Co000000?oooooo`000?l000001Oooool2o`0000gooooo
4Ol00006ooooo`?o00000_ooool5o`0001Cooooo0_l0000<oooooaSo00006oooool8o`0001_ooooo
0_l00006ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0BOooool4o`0000?ooooo0_l0
0004ooooo`?o00002_oooolCo`0000Sooooo1?l000000ooooooo0000o`000002o`0000Kooooo0_l0
000<ooooo`;o00003?oooolHo`0001_ooooo0_l00004ooooo`;o00006oooool2o`0000Sooooo0_l0
000nooooo`007?ooool00ol0003oooooooooo`18ooooo`?o00001?ooool2o`0000Gooooo0ol0000:
oooooa?o000000Coooooo`000?l0003o00001_ooool2o`000004ooooool0003o0000o`0000Oooooo
0ol00009ooooo`;o00001oooool3o`000003ooooool0003o000000;ooooo6?l0000Jooooo`?o0000
0oooool2o`0002Gooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`17ooooo`?o00000_oo
ool2o`000003ooooool0003o000001;ooooo0_l00002oooooa?o000000Coooooo`000?l0003ooooo
0_l000000ooooooo0000o`000003o`0000Sooooo0_l00009ooooo`;o00001oooool3o`000003oooo
ool0003o000000;ooooo6ol0000Gooooo`?o00001?ooool2o`0002Gooooo0_l0000mooooo`007?oo
ool00ol0003oooooooooo`17ooooo`;o00000oooool2o`0001Gooooo5ol000001?oooooo0000o`00
0?ooool2o`000003ooooool0003o000000?o00004?ooool2o`0000gooooo0_l00002oooooaco0000
6?ooool2o`0000Cooooo0_l0000Looooo`;o00001oooool2o`000003ooooool0003o000003[ooooo
000Looooo`03o`000?oooooooooo04Oooooo0_l0000Hoooooa3o00000_ooool4o`000004ooooool0
003o0000ooooo`;o00001_ooool3o`0000[ooooo0_l00004ooooo`;o00003Oooool3o`000003oooo
ool0003o000001Wo00006Oooool2o`0000Cooooo0ol0000Kooooo`;o00000oooool2o`0000Gooooo
0_l0000jooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00001Oooool2o`0000Oooooo1Ol0
0007oooooaOo00000oooool2o`0000Gooooo1?l0000:ooooo`;o00005?oooolNo`00023ooooo0_l0
000Pooooo`;o00001?ooool2o`0003_ooooo000Looooo`03o`000?oooooooooo04Gooooo0_l00000
0ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000001?ooool5o`0000Oooooo3Ol00000
0ooooooo0000o`000007o`0000[ooooo1?l0000Cooooo`;o00001?ooool2o`0000Cooooo0_l00000
0ooooooo0000o`00000Io`0001kooooo0_l000000ooooooo0000o`00000Jooooo`;o00002_ooool2
o`0003_ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o
410@ooooooooool01?ooool00ol0003oooooooooo`14ooooo`;o00000_ooool2o`0000Gooooo0_l0
0006ooooo`;o00001ooooolJo`0000Sooooo1?l0000Cooooo`;o00001?ooool2o`0000?ooooo0ol0
00000ooooooo0000o`00000Ho`0001Wooooo0_l00004ooooo`;o000000?oooooo`000?l000006_oo
ool2o`0000gooooo0_l0000hooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q
1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Cooooo0ol000000ooooooo0000
o`00000<ooooo`?o00001ooooolLo`0000;ooooo0_l00002ooooo`Co00007_ooool2o`0000;ooooo
3ol000000ooooooo0000o`000008o`0001Wooooo0_l00003ooooo`;o00008?ooool2o`000003oooo
ool0003o000000Oooooo0ol0000hooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`09ooooo`Go00001_ooool00ol0003oooooooooo`10ooooo`;o00000oooool2o`000003ooooool0
003o000000?ooooo0_l00007ooooo`Co00002?oooolJo`000004ooooool0003o0000o`0000?ooooo
0_l0000SoooooaWo00007oooool2o`0000?ooooo0_l0000Kooooo`;o000000?oooooo`000?l00000
1oooool4o`0003Oooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Co
A4A4omgMgOoooooo00001oooool3o`00043ooooo0_l00003ooooo`;o000000?oooooo`000?l00000
0_ooool3o`0000Kooooo1Ol00008oooooaSo00000oooool2o`0000;ooooo1?l0000=ooooo`;o0000
4Oooool2o`0000;ooooo6?l0000Gooooo`?o00001_ooool2o`0000;ooooo0_l0000Kooooo`;o0000
3?ooool2o`0003Oooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Co
gMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`15ooooo`;o00001Oooool2o`0000Oooooo
1?l00009oooooaOo00001Oooool2o`000003ooooool0003o000000;o00003Oooool2o`00013ooooo
0ol00002oooooa?o000000?oooooo`000?l000000_l0000Gooooo`Go00001?ooool2o`0002;ooooo
0_l00012ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03ogMgMoo<
c<co000000Oooooo00?o0000ooooooooool0@?ooool2o`0000?ooooo0_l0000>ooooo`Ko00001Ooo
ool6o`000003ooooool0003o0000013o00001Oooool2o`000003ooooool0003o0000027ooooo0ol0
00000ooooooo0000o`00000Go`0001[ooooo1?l0000Tooooo`Co0000@_ooool00006oooooomgMgOo
V9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo043ooooo
0_l0000Cooooo`Ko00001OoooolIo`0000Kooooo0_l00006ooooo`?o00000oooool2o`00017ooooo
1?l000001?oooooo0000o`000?oooolHo`0001Sooooo1ol00004ooooo`Co00007?ooool2o`0004Co
oooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0
003oooooooooo`1<ooooo`;o00002Oooool4o`0000Gooooo6?l00007ooooo`Co00000oooool4o`00
00?ooooo0_l00007ooooo`?o00001oooool4o`000003ooooool0003o000001[o00005Oooool;o`00
00;ooooo1?l0000Oooooo`;o00002Oooool2o`0003Kooooo000Looooo`03o`000?oooooooooo03go
oooo0_l0000=ooooo`;o00002_ooool3o`0000Oooooo5Ol00007ooooo`Go00000oooool3o`0000go
oooo0ol00009ooooo`;o000000?oooooo`000?l000001Ol000000ooooooo0000o`00000Bo`0001Go
oooo0_l00005ooooo`Co000000Coooooo`000?l0003ooooo0_l0000Oooooo`;o00001?ooool2o`00
00?ooooo0_l0000fooooo`007?ooool00ol0003oooooooooo`0mooooo`?o00001Oooool2o`0000Go
oooo0_l00006ooooo`So00001_oooolBo`000003ooooool0003o000000Oooooo1?l00003ooooo`Co
00005_ooool2o`0000Cooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000oo
000000?oooooo`000?l000005?ooool3o`0000Gooooo1?l000001?oooooo0000o`000?ooool2o`00
02Gooooo0_l00003ooooo`?o0000=Oooool001cooooo00?o0000ooooooooool0??ooool4o`0000Go
oooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool2o`000003ooooool0003o000000Ko
00001ooooolDo`0000Oooooo0ol00004ooooo`Co00000_ooool2o`0001;ooooo0_l00002ooooo`Wo
000000?oooooo`000?l000004_l0000Dooooo`;o00001_ooool4o`0000Cooooo0_l0000Vooooo`;o
00000_ooool3o`0003Gooooo000Looooo`03o`000?oooooooooo03cooooo0_l00007ooooo`;o0000
00?oooooo`000?l000001oooool2o`0000Gooooo1Ol00004ooooo`;o000000?oooooo`000?l00000
3ol00009ooooo`;o00001_ooool2o`0000?ooooo0_l00008ooooo`;o00003?ooool6o`0000;ooooo
0_l000000ooooooo0000o`00000Ao`0001cooooo1_l00002ooooo`;o00008Oooool2o`000003oooo
ool0003o000000;o0000>_ooool001cooooo00?o0000ooooooooool0@oooool2o`0000Cooooo0_l0
000=ooooo`Ko00000oooool2o`000003ooooool0003o000000ko00002_ooool2o`0000Cooooo0_l0
0002ooooo`;o000000?oooooo`000?l000002?ooool2o`0000gooooo1_l000000ooooooo0000o`00
0004o`0000;ooooo2_l00002ooooo`;o00007?ooool6o`000004ooooool0003o0000o`00027ooooo
0_l000000ooooooo0000o`000002ooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0>ooo
ool3o`0000Cooooo0ol00004ooooo`;o00001_ooool2o`0000Gooooo1_l00004ooooo`;o000000?o
ooooo`000?l000003?l0000:ooooo`;o00001Oooool2o`0000;ooooo0_l0000Looooo`Co000000?o
ooooo`000?l000004?l0000Oooooo`?o000000?oooooo`000?l000000_ooool3o`0001oooooo0_l0
0002ooooo`;o00000oooool2o`0003Sooooo000Looooo`03o`000?oooooooooo03[ooooo1Ol00003
ooooo`;o00002Oooool3o`000003ooooool0003o000000Wooooo0ol00003ooooo`;o000000?ooooo
o`000?l000002ol00007ooooo`;o00000_ooool2o`0000Wooooo0_l0000Iooooo`;o000000Cooooo
o`000?l0003o00000_ooool<o`000003ooooool0003o000000?o00007oooool3o`0000Gooooo0_l0
000Pooooo`;o00000_ooool2o`0003gooooo000Looooo`03o`000?oooooooooo03Wooooo0ol00000
0ooooooo0000o`000003ooooo`;o00001Oooool2o`0000;ooooo1?l00004ooooo`;o00001Oooool4
o`0000?ooooo3Ol000000ooooooo0000o`000006ooooo`;o00003Oooool2o`0001Gooooo0_l00002
ooooo`;o000000?oooooo`000?l000001Oooool7o`0000Cooooo1Ol0000Pooooo`Go00000_ooool2
o`0002Oooooo0ol0000iooooo`007?ooool00ol0003oooooooooo`0iooooo`?o00003Oooool2o`00
00;ooooo1?l00004ooooo`;o00001oooool2o`0000?ooooo3Ol000000ooooooo0000o`00000Xoooo
o`;o00000_ooool2o`0000?ooooo1_l00003ooooo`oo00008Oooool5o`0000;ooooo0ol0000Voooo
o`Co0000>?ooool001cooooo00?o0000ooooooooool0>Oooool3o`0000_ooooo0_l0000Fooooo`;o
00001Oooool9o`0000_ooooo0_l00006ooooo`;o00005oooool2o`0000Oooooo0_l00002ooooo`;o
00000oooool2o`0000?ooooo2_l0000Qooooo`Co00001?ooool2o`0002Gooooo1Ol0000hooooo`00
7?ooool00ol0003oooooooooo`0hooooo`?o00001_ooool2o`0000;ooooo1?l0000Fooooo`Co0000
0oooool3o`000004ooooool0003o0000o`0000?ooooo0_l00008ooooo`;o000000?oooooo`000?l0
00000oooool2o`00013ooooo0_l0000@ooooo`;o00003Oooool3o`0000;ooooo0_l0000Aooooo`;o
00003oooool3o`0000;ooooo0ol0000Pooooo`;o00001?ooool2o`0000;ooooo0_l0000gooooo`00
7?ooool2o`0003Wooooo0ol00006ooooo`;o00000_ooool2o`0000kooooo0ol00006ooooo`Go0000
1?ooool4o`0000Gooooo0_l00004ooooo`?o00000oooool3o`0001Gooooo0_l0000@ooooo`;o0000
0_ooool3o`0000gooooo0_l0000Aooooo`;o00003oooool2o`0000?ooooo0ol0000Pooooo`;o0000
2?ooool2o`000003ooooool0003o000003Cooooo000Looooo`03o`000?oooooooooo03[ooooo0_l0
0005ooooo`;o00004_ooool3o`0000Kooooo0_l000000ooooooo0000o`000002o`0000;ooooo1?l0
0005ooooo`?o00000oooool3o`0000;ooooo1ol0000@ooooo`;o00003_ooool2o`0000Kooooo0ol0
000=ooooo`;o00003_ooool2o`0001;ooooo0_l00003ooooo`?o0000;Oooool4o`0003;ooooo000L
ooooo`03o`000?oooooooooo03Sooooo1?l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l0
000Mooooo`;o00001?ooool4o`0000Cooooo0ol00006ooooo`?o000000?oooooo`000?l000000_l0
000@ooooo`;o00001Oooool2o`0000Oooooo0_l00007ooooo`;o00007Oooool2o`0001;ooooo0_l0
0003ooooo`?o00008Oooool2o`000003ooooool0003o000000Kooooo0_l000000ooooooo0000o`00
000booooo`007?ooool00ol0003oooooooooo`0hooooo`;o00000oooool2o`000004ooooool0003o
0000ooooo`?o00006?ooool2o`0000?ooooo1?l00004ooooo`;o00001?ooool3o`0000Cooooo1?l0
0005ooooo`;o00004oooool2o`000003ooooool0003o0000013ooooo0_l0000aooooo`?o00000_oo
ool2o`00023ooooo1?l000000ooooooo0000o`000006ooooo`;o0000=Oooool001cooooo00?o0000
ooooooooool0=_ooool5o`000004ooooool0003o0000o`0000Cooooo0_l0000Iooooo`;o00001?oo
ool4o`0000oooooo0ol00007ooooo`?o00004_ooool2o`0001Cooooo1Ol0000/ooooo`Co000000Co
ooooo`000?l0003o00008?ooool3o`00047ooooo000Looooo`03o`000?oooooooooo03Kooooo1Ol0
00000ooooooo0000o`00000Looooo`;o00002Oooool6o`0000[ooooo1_l00007ooooo`;o00005_oo
ool2o`0000?ooooo0_l00006ooooo`;o00000oooool5o`0002_ooooo0ol00003ooooo`?o00008Ooo
ool4o`0000Cooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`0eooooo`;o000000Cooooo
o`000?l0003o00001_ooool2o`0001Oooooo1?l00007ooooo`Ko00001Oooool3o`000004ooooool0
003o0000o`0000;ooooo0_l0000Oooooo`;o00000oooool2o`0000?ooooo0_l000000ooooooo0000
o`000005ooooo`?o000000?oooooo`000?l00000:?ooool3o`0000;ooooo1?l0000Qooooo`Co0000
1?ooool2o`0000Cooooo0_l0000cooooo`007?ooool00ol0003oooooooooo`0eooooo`Go00001Ooo
ool4o`0001Wooooo0_l0000:ooooo`?o00001Oooool3o`000003ooooool0003o000000;ooooo0_l0
000Pooooo`?o00001oooool2o`0000Sooooo0_l00002ooooo`;o00009_ooool5o`0000;ooooo0ol0
000Zooooo`;o00001?ooool2o`0003?ooooo000Looooo`03o`000?oooooooooo03Oooooo0ol00005
ooooo`?o00009_ooool2o`0000kooooo0_l00003ooooo`;o00007?ooool2o`0000[ooooo0_l00009
ooooo`;o00007_ooool2o`000004ooooool0003o0000ooooo`Go00001?ooool3o`0002[ooooo0ol0
000hooooo`007?ooool00ol0003oooooooooo`0gooooo`;o0000;oooool2o`0000Wooooo0_l00008
ooooo`;o00009?ooool2o`0000;ooooo0_l00009ooooo`;o00000_ooool6o`0001?ooooo0_l00000
1?oooooo0000o`000?ooool2o`000005ooooool0003o0000o`000?ooool00_l000000ooooooo0000
o`000003o`00027ooooo0_l00008ooooo`;o00000_ooool2o`0003Cooooo000Looooo`03o`000?oo
oooooooo03Cooooo1?l00005ooooo`;o00008Oooool2o`00017ooooo0_l0000/ooooo`Co000000Co
ooooo`000?l0003ooooo0_l00002ooooo`;o00001_ooool;o`0000cooooo3?l000001?oooooo0000
o`000?ooool2o`000003ooooool0003o000000;o00008_ooool2o`0000[ooooo1?l0000dooooo`00
7?ooool00ol0003oooooooooo`0dooooo`Co00001Oooool2o`00027ooooo0_l00007ooooo`?o0000
1Oooool2o`0002kooooo0_l00003ooooo`Ko000000?oooooo`000?l000001_ooool4o`0000;ooooo
2?l000000ooooooo0000o`000003o`0000;ooooo3ol00003ooooo`Go0000;oooool2o`0003Kooooo
000Looooo`03o`000?oooooooooo03Cooooo0ol0000^ooooo`;o000000?oooooo`000?l000000_l0
0003ooooo`Co00003Oooool2o`0002Kooooo1?l00002ooooo`;o00002oooool2o`0000;ooooo1?l0
00000ooooooo0000o`000004o`000003ooooool0003o000000?o000000Goooooo`000?l0003o0000
ooooo`0=o`0006Oooooo000Looooo`03o`000?oooooooooo03Cooooo0ol0000Tooooo`Co00001_oo
ool2o`000003ooooool0003o000000Gooooo0_l0000?ooooo`;o00009_ooool2o`0000Cooooo1?l0
000;ooooo`;o00002Oooool2o`0000_ooooo3?l0000cooooo`;o0000<oooool001cooooo00?o0000
ooooooooool0<oooool3o`0002Cooooo1Ol0000@ooooo`;o00004?ooool2o`00027ooooo0_l00006
ooooo`;o00000_ooool2o`0000_ooooo1?l0000Fooooo`Wo0000;_ooool2o`0000Cooooo0_l0000c
ooooo`007?ooool00ol0003oooooooooo`0cooooo`Oo00007oooool5o`0000Gooooo0_l000000ooo
oooo0000o`000006ooooo`;o00004Oooool2o`00027ooooo0_l00002ooooo`;o00000_ooool2o`00
00;ooooo0_l0000=ooooo`;o00005oooool6o`0002oooooo0ol00004ooooo`;o0000<oooool001co
oooo0_l0000dooooo`Oo00007oooool5o`0000;ooooo1Ol000000ooooooo0000o`000006ooooo`;o
00001oooool2o`0001Gooooo0_l00008ooooo`;o00001?ooool2o`0000Sooooo0_l00002ooooo`;o
00000_ooool2o`00013ooooo0_l00004ooooo`?o000000Coooooo`000?l0003o0000?_ooool2o`00
00Gooooo0_l0000cooooo`007?ooool00ol0003oooooooooo`0cooooo`Ko00007oooool5o`0000?o
oooo0ol0000=ooooo`;o00001Oooool2o`0000?ooooo0_l0000@ooooo`Co00001_ooool2o`0000Co
oooo0ol000000ooooooo0000o`000003ooooo`;o00005?ooool2o`0000?ooooo0_l000001?oooooo
0000o`000?ooool3o`000003ooooool0003o000000Co00007oooool3o`0001Kooooo0_l0000moooo
o`007?ooool00ol0003oooooooooo`0dooooo`Co00007oooool6o`0000Cooooo1?l0000;ooooo`;o
00002_ooool2o`0000[ooooo0_l00006ooooo`;o00003Oooool2o`000003ooooool0003o000000?o
oooo1?l0000Booooo`;o00001_ooool3o`0000Oooooo1?l00002ooooo`;o00006?ooool5o`0001Ko
oooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0eooooo`;o00008?ooool4o`0000Sooooo
0_l0000Sooooo`;o00002?ooool2o`0000kooooo0_l00005ooooo`;o00006oooool4o`0000Oooooo
0_l00002ooooo`Go00004Oooool2o`0000;ooooo1Ol0000Nooooo`;o0000=Oooool001cooooo00?o
0000ooooooooool0EOooool4o`0000;ooooo0_l00006ooooo`;o00002Oooool2o`0002;ooooo0_l0
000>ooooo`Co00000_ooool3o`0000Gooooo0_l00004ooooo`;o00004?ooool2o`0000;ooooo0_l0
0007ooooo`Go000000Coooooo`000?l0003o00000oooool2o`0000Sooooo0_l00003ooooo`?o0000
7_ooool3o`0003Gooooo000Looooo`03o`000?oooooooooo05Gooooo2?l00008ooooo`;o00001ooo
ool2o`0001kooooo0_l0000Cooooo`?o00000_ooool3o`0000Gooooo0_l00004ooooo`?o00003ooo
ool2o`0000;ooooo0ol00007ooooo`;o00000oooool5o`000003ooooool0003o000000;o00001?oo
ool2o`0000Kooooo0_l0000Dooooo`;o00002?ooool2o`0003Kooooo000Looooo`03o`000?oooooo
oooo05Oooooo1_l00007ooooo`Go00009?ooool3o`0001;ooooo1?l0000Aooooo`?o00000_ooool2
o`0000[ooooo0_l00003ooooo`;o00002_ooool2o`000003ooooool0003o000000So00000oooool4
o`0000?ooooo0ol0000Dooooo`;o00000oooool2o`0003_ooooo000Looooo`03o`000?oooooooooo
05Cooooo0_l00004ooooo`?o00001oooool6o`0002?ooooo0_l0000Cooooo`Co00001_ooool3o`00
00Wooooo0_l00002ooooo`;o00002?ooool5o`0000kooooo0ol00004ooooo`Ko00001Oooool2o`00
00?ooooo1Ol0000Gooooo`;o00000_ooool2o`0003Oooooo000Looooo`03o`000?oooooooooo05Co
oooo0_l00004ooooo`;o00001?ooool2o`0000Cooooo1?l0000`ooooo`;o00002oooool2o`0000?o
oooo0ol0000?ooooo`?o00001Oooool2o`000003ooooool0003o000000Kooooo0ol00006ooooo`;o
00005Oooool4o`0000oooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00000_ooool3o`00
03Kooooo000Looooo`03o`000?oooooooooo05;ooooo0_l00002ooooo`;o00002?ooool3o`0000Co
oooo0_l00005ooooo`;o00000oooool2o`00027ooooo0_l00002ooooo`;o00002oooool4o`0001?o
oooo0ol000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000_l000001?oooooo
0000o`000?ooool3o`0000?ooooo0_l0000Hooooo`?o00003oooool3o`000004ooooool0003o0000
o`0000Kooooo0ol0000fooooo`007?ooool00ol0003oooooooooo`1Booooo`;o00000_ooool2o`00
00Cooooo1?l000000ooooooo0000o`000004ooooo`;o00001Oooool2o`0000?ooooo0_l0000Qoooo
o`;o00004Oooool2o`0000Wooooo0_l00002ooooo`?o00001oooool2o`0000;ooooo0_l00003oooo
o`Ko000000?oooooo`000?l000000_l000000ooooooo0000o`000004ooooo`;o00002_ooool2o`00
00;ooooo0_l00002ooooo`?o00003oooool2o`0000[ooooo0ol0000gooooo`007?ooool00ol0003o
ooooooooo`1Cooooo`;o00001oooool4o`0000Oooooo0_l00002ooooo`?o0000<oooool2o`00017o
oooo0_l00002ooooo`Oo00002?ooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool4o`00
00Kooooo0ol0000:ooooo`;o00000_ooool7o`0001Kooooo0_l00003ooooo`;o0000>?ooool001co
oooo00?o0000ooooooooool0Doooool4o`0000;ooooo0_l000001?oooooo0000o`000?l0000<oooo
o`Ko00008Oooool2o`0000;ooooo0_l00009ooooo`;o00003oooool2o`0000?ooooo2?l00008oooo
o`;o00000oooool2o`000003ooooool0003o000000Sooooo0_l000000ooooooo0000o`00000@oooo
o`Ko00004Oooool4o`000003ooooool0003o000000;o0000>oooool001cooooo00?o0000oooooooo
ool0D?ooool2o`0000;ooooo1ol000000ooooooo0000o`00000>ooooo`Go00000_ooool2o`0001Go
oooo0_l00006ooooo`;o00000_ooool2o`000003ooooool0003o000000;o00005?ooool4o`000003
ooooool0003o000000_o00003?ooool2o`0000Sooooo1?l00002ooooo`;o00001oooool2o`0000Go
oooo1?l0000=ooooo`;o00000_ooool5o`0000?ooooo0_l0000kooooo`007?ooool00ol0003ooooo
ooooo`1@ooooo`[o00002_ooool2o`0000Kooooo0ol00004ooooo`;o00005Oooool2o`0000Kooooo
0_l00005ooooo`Co00004ooooolCo`0000Oooooo1?l0000;ooooo`Co000000Goooooo`000?l0003o
0000ooooo`02o`0000Cooooo0_l00004ooooo`Co00003_ooool2o`000004ooooool0003o0000o`00
00?ooooo0_l000000ooooooo0000o`00000kooooo`007?ooool00ol0003oooooooooo`1Booooo`;o
000000?oooooo`000?l000003Oooool2o`000003ooooool0003o000000Kooooo1Ol0000Hooooo`;o
00007ooooolGo`000003ooooool0003o000000?ooooo1?l00003ooooo`;o00002oooool2o`0000;o
oooo0_l00008ooooo`Go00004_ooool2o`0000Cooooo0_l00002ooooo`;o0000>_ooool001cooooo
0_l0001Eooooo`?o00004?ooool5o`0000?ooooo1Ol00009ooooo`;o00002oooool4o`0000Sooooo
0_l00003ooooo`;o00004?ooool:o`000003ooooool0003o000000[o000000?oooooo`000?l00000
2_ooool4o`0000oooooo0_l00006ooooo`Oo00005_ooool2o`0000;ooooo0_l0000jooooo`007?oo
ool00ol0003oooooooooo`1=ooooo`;o00000oooool5o`00017ooooo1?l00004ooooo`;o00002ooo
ool2o`0000_ooooo1?l00004ooooo`;o00000_ooool2o`0000?ooooo0_l0000>ooooo`;o00000_oo
oolFo`0000Cooooo0_l00004ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0000_ooooo
0_l00004ooooo`Ko000000?oooooo`000?l000003Oooool2o`0004Oooooo000Looooo`03o`000?oo
oooooooo04cooooo1?l00002ooooo`?o00002Oooool7o`0000_ooooo0_l0000>ooooo`;o00001ooo
ool4o`0000Gooooo0_l00007ooooo`;o00003_oooolJo`0000Cooooo0_l00004ooooo`;o00001Ooo
ool9o`0000Oooooo0_l00002ooooo`Oo00003?ooool2o`000003ooooool0003o000000?ooooo0_l0
0012ooooo`007?ooool00ol0003oooooooooo`1<ooooo`Co00003Oooool;o`000003ooooool0003o
000000Oooooo0_l0000<ooooo`;o00001oooool4o`0001kooooo1?l000000ooooooo0000o`00000C
o`000003ooooool0003o000000kooooo6?l000000ooooooo0000o`00000<ooooo`;o000000?ooooo
o`000?l000000oooool2o`0004;ooooo000Looooo`03o`000?oooooooooo04oooooo0_l0000;oooo
o`co000000?oooooo`000?l000001Oooool4o`0003Oooooo0_l00002oooooaKo000000?oooooo`00
0?l000000_ooool2o`0000?ooooo0_l00002ooooo`;o00001Oooool2o`000003ooooool0003o0000
00oo00005Oooool2o`0000?ooooo0ol0000nooooo`007?ooool00ol0003oooooooooo`1?ooooo`?o
00002_ooool=o`000004ooooool0003o0000o`0000?ooooo1?l0000foooooa_o00001Oooool2o`00
00?ooooo0_l000001?oooooo0000o`000?l00009ooooo`?o000000?oooooo`000?l000000ol00000
0ooooooo0000o`000004o`0001Cooooo0ol00003ooooo`?o0000?_ooool001cooooo00?o0000oooo
ooooool0B_ooool2o`0000?ooooo0ol0000:oooooa7o00001_ooool2o`0001oooooo0_l000000ooo
oooo0000o`00000Aooooo`Go000000?oooooo`000?l000001?l000000ooooooo0000o`00000?o`00
00Gooooo0_l00003ooooo`Co00003Oooool;o`0001Cooooo0ol000000ooooooo0000o`000011oooo
o`007?ooool00ol0003oooooooooo`1:ooooo`;o00000_ooool2o`0000Sooooo5Ol00003ooooo`;o
000000Coooooo`000?l0003o00000oooool4o`00017ooooo0_l00004ooooo`;o000000?oooooo`00
0?l000004Oooool4o`0000;ooooo6?l00004ooooo`?o00001Oooool2o`00017ooooo0ol000001?oo
oooo0000o`000?l0000Hooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0C_ooool2o`00
00Sooooo5Ol00003ooooo`;o00000_ooool2o`0000?ooooo1?l00003ooooo`;o00003?ooool2o`00
00[ooooo0_l000000ooooooo0000o`00000;ooooo`Go000000?oooooo`000?l000005Ol00005oooo
o`Go00000oooool2o`0001;ooooo0_l000000ooooooo0000o`00000Aooooo`;o000000?oooooo`00
0?l00000A_ooool001cooooo00?o0000ooooooooool0F_ooool2o`000003ooooool0003o000000go
000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00002_ooool2o`0000;ooooo1?l0000:oooo
o`;o00001Oooool3o`000003ooooool0003o000000cooooo7_l000000ooooooo0000o`000002oooo
o`?o00000oooool2o`0000Kooooo0_l0000Looooo`;o00000_ooool5o`0004Kooooo000Looooo`03
o`000?oooooooooo05Oooooo6?l00005ooooo`;o00003Oooool5o`0000[ooooo0_l00005ooooo`;o
00004_oooolGo`0000;ooooo0ol000000ooooooo0000o`000008ooooo`;o00000_ooool2o`0000;o
oooo0_l0000Looooo`;o00000_ooool5o`0004Kooooo000Looooo`03o`000?oooooooooo04kooooo
0_l00007oooooaKo00004_ooool2o`0000;ooooo0_l00008ooooo`;o00001?ooool3o`0000?ooooo
0_l0000=ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`00000Bo`0000;ooooo
0_l0000@ooooo`;o000000?oooooo`000?l000008Oooool5o`0000;ooooo0_l00012ooooo`007?oo
ool00ol0003oooooooooo`1>ooooo`;o00001ooooolFo`0000Wooooo0_l00006ooooo`?o00000_oo
ool2o`0000Sooooo0_l00004ooooo`?o00004_ooool2o`000003ooooool0003o000000?o000000?o
ooooo`000?l000004Ol0000Gooooo`;o0000:?ooool2o`0004;ooooo000Looooo`03o`000?oooooo
oooo04Oooooo0ol00004ooooo`;o00001ooooolFo`0000Wooooo0_l00006ooooo`?o000000Cooooo
o`000?l0003o00000_ooool2o`0000Kooooo0_l0000Kooooo`Co000000?oooooo`000?l000003ol0
0008ooooo`Co00004Oooool2o`0002Cooooo0_l00012ooooo`0000Koooooonk^k_lb<S;o0000oc8b
<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000oooooooo
ool0Aoooool3o`0000Cooooo0_l00007oooooaOo00002?ooool3o`0000Wooooo0_l00003ooooo`;o
00001_ooool2o`0000Gooooo0ol0000Aooooo`;o00001_ooool>o`0000Oooooo1ol00009ooooo`;o
00001_ooool2o`0000Wooooo0_l0000Iooooo`;o0000@_ooool00006oooooomgMgOoV9RHoooooonH
V9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooo
oooo04Sooooo0_l00002ooooo`;o00002OoooolGo`0000Wooooo0ol0000Looooo`?o00001_ooool2
o`0000Sooooo1Ol00002ooooo`;o00001Oooool8o`0000Cooooo0_l00002ooooo`?o00001?ooool2
o`0000Oooooo0_l0000Aooooo`;o000000?oooooo`000?l000002?ooool3o`0004oooooo00000ooo
oooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo04Sooooo0_l00002ooooo`;o00002?ooool;o`000003ooooool0003o
000000[o00002Oooool3o`0001cooooo0_l00007ooooo`;o00002?ooool5o`0000;ooooo0_l00008
ooooo`Co00001Oooool3o`0000Kooooo4?l0000Aooooo`;o00000oooool4o`000003ooooool0003o
000000?o0000COooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0
003oV9RHoooooonHV9So8B4Q00Kooooo0ol0001FoooooaSo000000Coooooo`000?l0003o00001_oo
ool2o`0000Kooooo0_l0000?ooooo`;o00000_ooool3o`0000;ooooo1?l0000<ooooo`;o00000ooo
ool2o`0000Wooooo0_l000000ooooooo0000o`000004ooooo`Ko00000_oooolAo`0001Kooooo1?l0
0004ooooo`?o0000C?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool0
1Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0B?ooool2o`0000?ooooo0_l0
0007oooooaOo00000_ooool3o`0000Kooooo0ol00005ooooo`;o00001oooool2o`0000Kooooo0_l0
0002ooooo`;o00000oooool4o`0000cooooo2?l000001?oooooo0000o`000?l00004ooooo`;o0000
00?oooooo`000?l000001?oooolDo`000003ooooool0003o000000?o000000?oooooo`000?l00000
2Oooool2o`0000Oooooo0_l00006ooooo`?o0000C?ooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo04Sooooo0_l0
0002ooooo`?o00001ooooolEo`0000?ooooo0_l00006ooooo`;o000000?oooooo`000?l000001Ooo
ool2o`0000Oooooo0_l0000:ooooo`;o00000_ooool4o`0000kooooo1?l000001?oooooo0000o`00
0?ooool3o`0000[ooooo3ol000000ooooooo0000o`00000>o`0000;ooooo0_l00005ooooo`;o0000
1oooool3o`0005Cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nH
V9P02?ooool00ol0003oooooooooo`1<ooooo`;o00002_oooolCo`0000?ooooo0_l00004ooooo`Co
00008Oooool4o`0000kooooo0_l0000;ooooo`Go00000oooool=o`0000?ooooo5Ol00009ooooo`;o
00000oooool2o`0000;ooooo1?l00006ooooo`;o0000A_ooool00006ooooooo^k^ko<S8bo`000?lb
<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo04gooooo0_l00009
ooooo`go000000Coooooo`000?l0003o00000oooool2o`0000Cooooo1_l000001?oooooo0000o`00
0?l00006ooooo`;o00004Oooool2o`0001Kooooo0_l00009ooooo`Go000000?oooooo`000?l00000
2ol000001Ooooooo0000o`000?l0003ooooo01Go00001_ooool2o`000003ooooool0003o000000Oo
oooo1?l00003ooooo`Go0000A_ooool001cooooo00?o0000ooooooooool0COooool2o`0000Wooooo
3_l000000ooooooo0000o`000002o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000
o`000002ooooo`?o00001_ooool2o`0000?ooooo0_l0000<ooooo`;o00004oooool2o`000003oooo
ool0003o000000oooooo1ol00002ooooo`;o00000oooool3o`0000;ooooo5?l00006ooooo`;o0000
4Oooool4o`0004Oooooo000Looooo`03o`000?oooooooooo04cooooo1?l00008oooooa3o000000Co
ooooo`000?l0003ooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0ol00007ooooo`;o
00000oooool2o`0000cooooo0_l0000Cooooo`;o00001_ooool4o`0000?ooooo0_l000000ooooooo
0000o`000003ooooo`;o00002Oooool2o`0000?ooooo2_l000000ooooooo0000o`000007o`0000So
oooo0_l00003ooooo`;o00002Oooool5o`0004Oooooo000Looooo`03o`000?oooooooooo04Kooooo
0_l00004ooooo`Co00002?ooool@o`0000Cooooo1?l00004ooooo`;o000000Coooooo`000?l0003o
00000oooool2o`000003ooooool0003o000000;o00002?ooool2o`00027ooooo1ol00003ooooo`;o
000000?oooooo`000?l000004?ooool2o`000003ooooool0003o000001;o00001Oooool2o`000003
ooooool0003o000000?ooooo0_l00009ooooo`Co0000B?ooool001cooooo00?o0000ooooooooool0
A_ooool2o`0000?ooooo1Ol00008oooooa3o00001_ooool2o`0000Cooooo1Ol00004ooooo`;o0000
00?oooooo`000?l000000_ooool2o`0000Kooooo0_l0000Qooooo`Oo00006?ooool2o`0000;ooooo
4ol00005ooooo`;o0000GOooool001cooooo00?o0000ooooooooool0A_ooool2o`0000?ooooo1Ol0
0008ooooo`_o000000?oooooo`000?l000003_ooool4o`000004ooooool0003o0000ooooo`;o0000
1_ooool2o`0004Wooooo0_l000000ooooooo0000o`00000Co`0000Gooooo0_l0001Kooooo`007?oo
ool00ol0003oooooooooo`1<ooooo`Co00002oooool7o`0000;ooooo0_l0000;ooooo`Go00000ooo
ool2o`000003ooooool0003o0000057ooooo0_l00002oooooaGo00001?ooool2o`0000Sooooo0_l0
0002ooooo`?o0000C?ooool001cooooo00?o0000ooooooooool0C_ooool2o`0000gooooo0_l0000A
ooooo`Go0000F_ooool2o`000003ooooool0003o000001Go00003Oooool2o`0000;ooooo0ol0001<
ooooo`007?ooool00ol0003oooooooooo`1>ooooo`Oo00006Oooool4o`0001Kooooo0_l00018oooo
oaOo0000H?ooool001cooooo00?o0000ooooooooool0B?ooool2o`0000;ooooo0_l00002ooooo`Go
00002Oooool2o`0000Kooooo1?l00004ooooo`;o00004oooool8o`0000Cooooo1Ol0000nooooo`;o
00000_ooool@o`000004ooooool0003o0000ooooo`;o0000GOooool001cooooo00?o0000oooooooo
ool0B?ooool3o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000002_ooool6o`00
00;ooooo1?l0000Hooooo`co000000?oooooo`000?l000001_l0000kooooo`;o000000?oooooo`00
0?l000003ol000001?oooooo0000o`000?ooool2o`0000Wooooo1?l0001@ooooo`007?ooool00ol0
003oooooooooo`19ooooo`;o00000_ooool4o`0000oooooo1?l00005ooooo`;o00005oooool3o`00
00Kooooo1?l00003ooooo`Go0000?_oooolAo`000004ooooool0003o0000ooooo`;o00002?ooool5
o`00053ooooo000Looooo`;o0000C_ooool4o`0000Kooooo0ol00009ooooo`;o00000_ooool4o`00
01Cooooo0ol00005ooooo`oo00000oooool2o`0003cooooo3_l00002ooooo`;o00000oooool2o`00
00Cooooo1?l0001Cooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00000_ooool2o`000004
ooooool0003o0000ooooo`?o00002Oooool2o`0000;ooooo0_l0000Fooooo`?o00001Oooool@o`00
0003ooooool0003o000000;o0000>ooooolBo`0000?ooooo0_l00002ooooo`Ko0000Doooool001co
oooo00?o0000ooooooooool0COooool2o`0000;ooooo1Ol0000<ooooo`?o00005oooool3o`0000Ko
oooo2_l000000ooooooo0000o`00000<o`0003_ooooo4?l00005ooooo`Ko0000EOooool001cooooo
00?o0000ooooooooool0Coooool2o`0000;ooooo0_l0000=ooooo`?o00005oooool3o`0000Kooooo
5?l00003ooooo`?o0000>_ooool@o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o0000
EOooool001cooooo00?o0000ooooooooool0B?ooool2o`0000Gooooo0_l0000Zooooo`Co00001ooo
oolJo`0000Kooooo0_l0000hooooo`Go00001?ooool3o`0000;ooooo0_l0001Iooooo`007?ooool0
0ol0003oooooooooo`18ooooo`;o0000<Oooool6o`0000Gooooo3_l00002ooooo`[o00001_ooool2
o`0003Gooooo1Ol00007ooooo`?o00000_ooool2o`0005Wooooo000Looooo`03o`000?oooooooooo
07_ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00000_oooolKo`0003cooooo1Ol00002
ooooo`Co000000?oooooo`000?l00000G_ooool001cooooo00?o0000ooooooooool0B_ooool2o`00
02oooooo0_l00002ooooo`;o000000?oooooo`000?l000000ooooolJo`0004?ooooo1?l000000ooo
oooo0000o`00001Nooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o0000;_ooool2o`0000[o
oooo0ol00002oooooaKo0000Z?ooool001cooooo00?o0000ooooooooool0B?ooool4o`0002kooooo
0_l0000:ooooo`?o00000_oooolFo`000:Sooooo000Looooo`03o`000?oooooooooo04Sooooo0ol0
000_ooooo`?o000000?oooooo`000?l000001ooooolJo`000:Sooooo000Looooo`03o`000?oooooo
oooo07[ooooo0ol000000ooooooo0000o`000005oooooaco0000Z?ooool001cooooo00?o0000oooo
ooooool0B_ooool2o`0002kooooo0_l00002ooooo`;o00001Oooool2o`000003ooooool0003o0000
00;o000000?oooooo`000?l000004_l0002Xooooo`007?ooool00ol0003oooooooooo`1:ooooo`Co
0000;?ooool3o`0000_ooooo5ol00007ooooo`;o0000XOooool001cooooo00?o0000ooooooooool0
B_ooool4o`0002cooooo0ol0000;oooooaOo00001oooool2o`000:7ooooo000Looooo`03o`000?oo
oooooooo04[ooooo1?l0000]ooooo`;o00003_oooolFo`000:Sooooo000Looooo`;o0000C?ooool2
o`0002kooooo0ol0000;oooooaSo0000Z?ooool001cooooo00?o0000ooooooooool0Boooool2o`00
02kooooo0ol0000;ooooo`ko000000?oooooo`000?l000001ol0002Xooooo`007?ooool00ol0003o
ooooooooo`1kooooo`Go00002?oooolFo`000003ooooool0003o00000:Sooooo000Looooo`03o`00
0?oooooooooo04kooooo0_l0000[ooooo`Go00001ooooolGo`000003ooooool0003o000005Cooooo
0_l0001Booooo`007?ooool00ol0003oooooooooo`1>ooooo`;o0000;?ooool2o`0000Wooooo0ol0
0002oooooaGo0000E?ooool2o`0005;ooooo000Looooo`03o`000?oooooooooo07cooooo0ol0000=
oooooaGo0000D?ooool2o`0005Kooooo000Looooo`03o`000?oooooooooo07cooooo0ol0000=oooo
o`Co00000_ooool>o`00057ooooo0_l000000ooooooo0000o`00001Cooooo`007?ooool00ol0003o
ooooooooo`1mooooo`?o00002?ooool2o`0000?ooooo4Ol00005ooooo`;o0000A?ooool2o`0000Ko
oooo0_l000000ooooooo0000o`00001Cooooo`007?ooool00ol0003oooooooooo`1nooooo`;o0000
0oooool2o`0000?ooooo0ol000000ooooooo0000o`00000@o`0000Gooooo0_l00014ooooo`?o0000
GOooool001cooooo00?o0000ooooooooool0D_ooool4o`0002Sooooo0ol00002ooooo`;o00001?oo
ool2o`000003ooooool0003o000000co0000BOooool3o`0000Cooooo0_l0001Mooooo`007?ooool0
0ol0003oooooooooo`1Booooo`Co0000:?ooool3o`0000kooooo2_l00008ooooo`;o0000@?ooool3
o`000003ooooool0003o000000Cooooo1?l0001Hooooo`007?ooool00ol0003oooooooooo`1Boooo
o`;o000000?oooooo`000?l00000=?ooool2o`0000;ooooo2_l00003ooooo`;o00000oooool2o`00
04Cooooo0_l00004ooooo`Co0000F?ooool001cooooo00?o0000ooooooooool0EOooool2o`0002[o
oooo0_l00008ooooo`So00000oooool5o`000003ooooool0003o000000Co0000Boooool2o`0005[o
oooo000Looooo`03o`000?oooooooooo05Wooooo0_l0000Vooooo`?o00002Oooool2o`0000;ooooo
0_l00004ooooo`_o0000B?ooool5o`0005[ooooo000Looooo`03o`000?oooooooooo05Wooooo0ol0
000Vooooo`;o00003Oooool2o`0000;ooooo2Ol0001<ooooo`Co0000Foooool001cooooo00?o0000
ooooooooool0F_ooool2o`0002Kooooo1Ol00008ooooo`Co00000_ooool2o`000003ooooool0003o
000000;ooooo0_l00016ooooo`;o00000oooool2o`0005kooooo000Looooo`;o0000Q?ooool6o`00
00Kooooo0_l0001Cooooo`;o00000oooool2o`0005kooooo000Looooo`03o`000?oooooooooo05ko
oooo0_l0000Tooooo`Go000000?oooooo`000?l00000F?ooool2o`0006?ooooo000Looooo`03o`00
0?oooooooooo05_ooooo0_l000000ooooooo0000o`00000Tooooo`?o00000oooool2o`0004kooooo
0_l00009ooooo`?o0000HOooool001cooooo00?o0000ooooooooool0Foooool2o`0000?ooooo0_l0
000Sooooo`Go00000_ooool2o`0004cooooo0_l00008ooooo`Co0000HOooool001cooooo00?o0000
ooooooooool0Foooool2o`000003ooooool0003o000000;o00009?ooool4o`0000;ooooo0_l0001:
ooooo`;o00001?ooool2o`0000;ooooo1?l0001Sooooo`007?ooool00ol0003oooooooooo`1Noooo
o`;o000000?oooooo`000?l000008oooool4o`0004kooooo0_l000001?oooooo0000o`000?ooool6
o`0006Gooooo000Looooo`03o`000?oooooooooo067ooooo0_l0000Tooooo`?o0000C_ooool2o`00
0004ooooool0003o0000ooooo`Co0000Ioooool001cooooo00?o0000ooooooooool0ROooool2o`00
00?ooooo0_l0000kooooo`Co00003Oooool2o`0006_ooooo000Looooo`03o`000?oooooooooo06Go
oooo0_l0000Rooooo`Oo000000?oooooo`000?l00000>?ooool4o`0000gooooo1Ol0001Xooooo`00
7?ooool00ol0003oooooooooo`1Uooooo`;o00008_ooool7o`000003ooooool0003o000003;ooooo
0_l00004ooooo`;o00001oooool2o`0000Sooooo0ol0001Xooooo`007?ooool00ol0003ooooooooo
o`2:ooooo`So00000oooool2o`0002kooooo0_l0000=ooooo`;o0000Loooool001cooooo00?o0000
ooooooooool0S?ooool2o`0000;ooooo0_l00003ooooo`;o0000?Oooool2o`0007?ooooo000Loooo
o`03o`000?oooooooooo08cooooo0_l00002ooooo`;o00001Oooool2o`0002kooooo0_l00008oooo
o`?o0000MOooool001cooooo00?o0000ooooooooool0SOooool5o`0000Gooooo0_l00005ooooo`;o
00009oooool2o`0000Cooooo0_l000000ooooooo0000o`000002o`0007Gooooo00001_ooooook^k^
oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`2=ooooo`So00001Oooool3o`000003ooooool0003o000001Sooooo0_l00005
ooooo`;o00002_ooool4o`000003ooooool0003o000000Oooooo0_l0001^ooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo
00?o0000ooooooooool0Soooool6o`0000Gooooo1?l0000=ooooo`?o00001Oooool2o`0000?ooooo
0ol00004ooooo`;o00002_ooool6o`0000Sooooo0ol0001]ooooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`2@ooooo`Co00002?ooool2o`0000Sooooo0ol00002ooooo`?o00001Oooool2o`0000;ooooo
1?l00007ooooo`;o00001oooool2o`000004ooooool0003o0000o`0000Kooooo1Ol0001]ooooo`00
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb
<S801_ooool3o`00093ooooo1?l000000ooooooo0000o`000004ooooo`;o00002Oooool3o`0000Ko
oooo0_l00002ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000Kooooo0ol00006oooo
o`;o00001oooool2o`000003ooooool0003o0000073ooooo00000ooooooo0000ooooo`02ooooo`03
o`000?oooooooooo00Wooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo
097ooooo1_l00004ooooo`;o00001_ooool3o`0000Wooooo0_l00005ooooo`;o00000_ooool2o`00
00Cooooo0_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000000_ooool2o`00
00?ooooo1?l0001aooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05
oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`2Dooooo`;o00002_ooool2o`00
0004ooooool0003o0000o`0000Wooooo0_l00004ooooo`;o00001?ooool2o`0000?ooooo0_l00005
ooooo`?o000000?oooooo`000?l000000_ooool2o`0000Gooooo0_l0001aooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003ooooo
ooooo`2Eooooo`?o00002?ooool2o`0000gooooo0_l00004ooooo`;o00001?ooool2o`0000Oooooo
0_l000000ooooooo0000o`000006ooooo`;o0000N?ooool00006ooooooo^k^ko<S8bo`000?lb<S;o
k^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0UOooool3o`00
00;ooooo0_l0000;ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l00002oooo
o`;o00002Oooool4o`0000Wooooo0_l0001hooooo`007?ooool00ol0003oooooooooo`2Iooooo`?o
00002oooool2o`000003ooooool0003o000000;ooooo0ol000000ooooooo0000o`000002o`000004
ooooool0003o0000ooooo`;o000000?oooooo`000?l000000oooool2o`000003ooooool0003o0000
00;o0000P?ooool001cooooo00?o0000ooooooooool0VOooool4o`0001;ooooo0_l000000ooooooo
0000o`000002o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo1Ol00002oooo
o`;o0000O?ooool001cooooo00?o0000ooooooooool0Voooool2o`000003ooooool0003o000000?o
oooo0_l00004ooooo`;o00003oooool4o`0000;ooooo0_l00002ooooo`Co000000?oooooo`000?l0
00000_l0001looooo`007?ooool00ol0003oooooooooo`2Nooooo`So000000?oooooo`000?l00000
0_l0000:ooooo`?o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o00000_ooool2o`000003
ooooool0003o000007kooooo000Looooo`03o`000?oooooooooo09oooooo1ol000000ooooooo0000
o`000002o`0000Cooooo0_l00004ooooo`?o000000?oooooo`000?l000001_l000000ooooooo0000
o`000002ooooo`;o0000POooool001cooooo00?o0000ooooooooool0X_ooool3o`0000[ooooo0_l0
0004ooooo`;o00001?ooool6o`0008Sooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o
0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Booooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooo
od[ooooo000Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`00
5?ooool00ol0003oooooooooo`05ooooo`?o0000oooooom:ooooo`005?ooool00ol0003ooooooooo
o`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000oooo
ooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Booooo`03oeEE
EOmVIVKo00000?ooooooE?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Go
oooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0Fooooo`Co000000So410@oooo
ooooooooc<c<ob4Q8Ol0003o8B4Qolc<c0?ooooo00Gok^k^oc8b<_l0003o410@olc<c02@ooooo`00
Y_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l0000<ooooo`03o`000?oooooooooo00;o
oooo00Go8B4QoiRHV?ooooooV9RHob4Q8@03ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40T?ooool0
0:Kooooo00Go0000ooooooooooooooooo`00000Kooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000T?ooool00:Kooooo00Go
0000ooooooooooooooooo`000009ooooo`Ko00003?ooool00ol0003oooooooooo`02ooooo`05oc8b
<_nHV9SooooooiRHV?lb<S800oooool01Ol0003oV9RHoooooonHV9So8B4Q093ooooo002Vooooo`05
o`000?n7QhOoooooojVYZOl000006oooool00ol0003oooooooooo`02ooooo`05olc<c?l0003o0000
o`000?o<c<`00oooool01Ol0003oEEEEo`000?l@413oc<c<093ooooo002Uooooo`03oa0@4?l0003o
MgMg00;o000000?oV9RHooooooooool06Oooool00ol0003oooooooooo`02ooooo`05oa0@4?nj^[[o
oooookZj^_l@41000oooool00omEEEGoQhN7ooooo`2Booooo`00a_ooool00ol0003oooooooooo`02
ooooo`05o`000?nj^[[ooooookZj^_l000000oooool00ooMgMgo410@oiRHV02Booooo`00a?ooool0
0omEEEGoIVIVo`000004ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01?ooool01?o<c<coA4A4o`00
0?l@412@ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(192) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.38879 .34223 Mdot
.3689 .3767 Mdot
.46151 .69515 Mdot
.60044 .41604 Mdot
.64131 .66458 Mdot
.44455 .71233 Mdot
.30572 .57354 Mdot
.28606 .57598 Mdot
.43066 .64778 Mdot
.53368 .31771 Mdot
.28249 .54946 Mdot
.60423 .43066 Mdot
.29655 .56696 Mdot
.58581 .39032 Mdot
.65426 .53179 Mdot
.63657 .29876 Mdot
.34027 .38132 Mdot
.68818 .68944 Mdot
.6359 .29281 Mdot
.42323 .64593 Mdot
.61873 .63584 Mdot
.572 .38954 Mdot
.37892 .40085 Mdot
.58496 .39239 Mdot
.62858 .30832 Mdot
.37542 .37887 Mdot
.38566 .34214 Mdot
.61646 .30255 Mdot
.58731 .43579 Mdot
.26327 .57396 Mdot
.60959 .30848 Mdot
.75125 .574 Mdot
.58951 .58952 Mdot
.49101 .2991 Mdot
.27833 .58758 Mdot
.33901 .53886 Mdot
.45064 .6751 Mdot
.2666 .58318 Mdot
.32109 .53962 Mdot
.27667 .56227 Mdot
.27321 .56762 Mdot
.37207 .38529 Mdot
.27925 .59178 Mdot
.21124 .63204 Mdot
.58702 .40361 Mdot
.49515 .19755 Mdot
.435 .7435 Mdot
.6098 .41348 Mdot
.37234 .40594 Mdot
.45987 .64924 Mdot
.69018 .5942 Mdot
.28504 .56062 Mdot
.56669 .57368 Mdot
.45519 .16198 Mdot
.29294 .57391 Mdot
.63221 .30254 Mdot
.42539 .70845 Mdot
.57186 .41707 Mdot
.61544 .39414 Mdot
.48674 .26732 Mdot
.56844 .42398 Mdot
.64517 .64119 Mdot
.43821 .37372 Mdot
.47013 .68528 Mdot
.43977 .64586 Mdot
.26905 .58772 Mdot
.34133 .36652 Mdot
.31931 .58129 Mdot
.60246 .41597 Mdot
.414 .66264 Mdot
.55296 .43286 Mdot
.28159 .55025 Mdot
.35728 .3519 Mdot
.5708 .37858 Mdot
.38878 .33498 Mdot
.29861 .53013 Mdot
.66762 .68913 Mdot
.40176 .38303 Mdot
.47414 .67164 Mdot
.63943 .48437 Mdot
.56878 .38357 Mdot
.16923 .46731 Mdot
.71087 .51488 Mdot
.38314 .35317 Mdot
.55529 .37399 Mdot
.19904 .40712 Mdot
.538 .41934 Mdot
.61372 .32228 Mdot
.61861 .30822 Mdot
.58927 .4971 Mdot
.42218 .71033 Mdot
.37037 .40252 Mdot
.57139 .39666 Mdot
.60626 .39261 Mdot
.53051 .31298 Mdot
.55891 .43236 Mdot
.62306 .30913 Mdot
.59349 .56164 Mdot
.29383 .54903 Mdot
.58305 .56407 Mdot
.36839 .60403 Mdot
.58196 .57981 Mdot
.54509 .42632 Mdot
.44373 .6956 Mdot
.36165 .34295 Mdot
.59051 .58193 Mdot
.30765 .58754 Mdot
.5751 .39584 Mdot
.307 .50855 Mdot
.37929 .39927 Mdot
.6197 .28887 Mdot
.65891 .65891 Mdot
.51999 .62242 Mdot
.35682 .35526 Mdot
.5762 .22255 Mdot
.60073 .39649 Mdot
.55828 .39745 Mdot
.36815 .38078 Mdot
.41964 .64193 Mdot
.27344 .62674 Mdot
.34865 .38472 Mdot
.29124 .54781 Mdot
.33889 .38459 Mdot
.59756 .58209 Mdot
.42435 .64128 Mdot
.54473 .57658 Mdot
.58157 .54958 Mdot
.73284 .58786 Mdot
.5869 .43083 Mdot
.57589 .54006 Mdot
.4456 .68805 Mdot
.3511 .3833 Mdot
.29945 .559 Mdot
.59161 .35422 Mdot
.385 .36425 Mdot
.29972 .57787 Mdot
.68465 .67071 Mdot
.68885 .66451 Mdot
.37076 .3515 Mdot
.56652 .2245 Mdot
.28337 .59676 Mdot
.32937 .56785 Mdot
.6877 .59201 Mdot
.37903 .35215 Mdot
.66366 .63954 Mdot
.3171 .57886 Mdot
.46234 .79278 Mdot
.62602 .28996 Mdot
.72451 .61039 Mdot
.17339 .471 Mdot
.68796 .59302 Mdot
.61565 .62467 Mdot
.65797 .64571 Mdot
.2989 .57822 Mdot
.59481 .36605 Mdot
.36605 .36077 Mdot
.38296 .36574 Mdot
.56711 .44359 Mdot
.58489 .58815 Mdot
.59553 .40517 Mdot
.58395 .56123 Mdot
.57653 .54632 Mdot
.57783 .39809 Mdot
.48442 .20449 Mdot
.39123 .36698 Mdot
.56295 .36518 Mdot
.44525 .66582 Mdot
.53954 .53992 Mdot
.29071 .59409 Mdot
.56286 .36935 Mdot
.56094 .3631 Mdot
.60212 .43424 Mdot
.3305 .56585 Mdot
.29293 .46305 Mdot
.47485 .69638 Mdot
.29512 .54093 Mdot
.36779 .60634 Mdot
.43424 .6781 Mdot
.61418 .39211 Mdot
.66484 .66122 Mdot
.55868 .56489 Mdot
.59179 .36823 Mdot
.69021 .59571 Mdot
.60976 .37688 Mdot
.54233 .62099 Mdot
.55622 .62057 Mdot
.18667 .44448 Mdot
.30131 .45737 Mdot
.6035 .39436 Mdot
.62854 .32151 Mdot
.70943 .5999 Mdot
.23587 .59691 Mdot
.30487 .55673 Mdot
.40522 .69425 Mdot
.41555 .64579 Mdot
.36064 .65661 Mdot
.56217 .25188 Mdot
.60206 .27464 Mdot
.55341 .40437 Mdot
.57752 .57287 Mdot
.43126 .38702 Mdot
.65643 .64424 Mdot
.35281 .36394 Mdot
.16859 .4703 Mdot
.68389 .45025 Mdot
.61468 .27919 Mdot
.41059 .77904 Mdot
.4631 .66063 Mdot
.57849 .5854 Mdot
.67464 .65494 Mdot
.58271 .41796 Mdot
.3934 .37408 Mdot
.70096 .59617 Mdot
.57061 .59466 Mdot
.84709 .55337 Mdot
.34493 .38211 Mdot
.70333 .47159 Mdot
.29623 .57261 Mdot
.41985 .6842 Mdot
.53787 .41873 Mdot
.5849 .37994 Mdot
.34797 .41564 Mdot
.59962 .36676 Mdot
.6063 .30505 Mdot
.6245 .29485 Mdot
.45497 .6432 Mdot
.36894 .5936 Mdot
.31222 .53911 Mdot
.46073 .74526 Mdot
.35915 .35317 Mdot
.48063 .18703 Mdot
.43374 .69607 Mdot
.58947 .62428 Mdot
.27441 .55848 Mdot
.68512 .66553 Mdot
.43778 .70087 Mdot
.63988 .66148 Mdot
.61493 .38828 Mdot
.43259 .66563 Mdot
.65057 .65469 Mdot
.52888 .44218 Mdot
.59031 .58016 Mdot
.72388 .69259 Mdot
.31198 .57353 Mdot
.34619 .40973 Mdot
.5912 .36702 Mdot
.56617 .56861 Mdot
.56188 .59449 Mdot
.65452 .50744 Mdot
.55533 .5514 Mdot
.57109 .59264 Mdot
.62183 .50925 Mdot
.68592 .68614 Mdot
.25764 .40093 Mdot
.60988 .30295 Mdot
.34092 .37786 Mdot
.60411 .38365 Mdot
.36187 .5706 Mdot
.30232 .57861 Mdot
.57877 .42143 Mdot
.17717 .45043 Mdot
.31791 .57103 Mdot
.56535 .40783 Mdot
.30738 .53528 Mdot
.38537 .35871 Mdot
.69219 .44618 Mdot
.35749 .35013 Mdot
.57609 .40076 Mdot
.30009 .53662 Mdot
.40668 .70199 Mdot
.37689 .37635 Mdot
.57287 .39351 Mdot
.56524 .42849 Mdot
.57427 .57316 Mdot
.62557 .29342 Mdot
.31305 .62026 Mdot
.59442 .43735 Mdot
.45188 .7199 Mdot
.57051 .43908 Mdot
.68601 .65111 Mdot
.53363 .8029 Mdot
.37674 .35079 Mdot
.55174 .55293 Mdot
.43278 .70691 Mdot
.52561 .38226 Mdot
.70577 .45617 Mdot
.58727 .40017 Mdot
.55505 .58357 Mdot
.71964 .4896 Mdot
.3199 .55409 Mdot
.61364 .2901 Mdot
.52385 .5633 Mdot
.42753 .71262 Mdot
.58042 .57839 Mdot
.54638 .40101 Mdot
.39026 .38932 Mdot
.63437 .3014 Mdot
.4284 .67583 Mdot
.34245 .38993 Mdot
.5407 .41598 Mdot
.35684 .61055 Mdot
.53674 .55397 Mdot
.31709 .54963 Mdot
.61265 .30601 Mdot
.61386 .39262 Mdot
.41611 .66036 Mdot
.37266 .38679 Mdot
.28966 .57519 Mdot
.36092 .35049 Mdot
.63344 .55388 Mdot
.70568 .48022 Mdot
.34151 .35824 Mdot
.67936 .681 Mdot
.48101 .82968 Mdot
.29226 .5449 Mdot
.56468 .55699 Mdot
.42884 .73657 Mdot
.39595 .38267 Mdot
.44278 .70226 Mdot
.55521 .22949 Mdot
.42234 .70908 Mdot
.63551 .28427 Mdot
.40815 .69938 Mdot
.60219 .26451 Mdot
.57164 .36426 Mdot
.44906 .64861 Mdot
.59476 .56234 Mdot
.5552 .38298 Mdot
.38518 .36637 Mdot
.75639 .56209 Mdot
.52635 .2841 Mdot
.56673 .25066 Mdot
.42532 .7054 Mdot
.55025 .22653 Mdot
.61982 .29339 Mdot
.61401 .30604 Mdot
.36575 .36468 Mdot
.56398 .55831 Mdot
.64851 .62285 Mdot
.64175 .62302 Mdot
.61147 .78484 Mdot
.73218 .43556 Mdot
.58391 .22281 Mdot
.38051 .36433 Mdot
.38098 .73112 Mdot
.37559 .33556 Mdot
.57069 .59428 Mdot
.28578 .57599 Mdot
.289 .46872 Mdot
.54063 .42817 Mdot
.59277 .61725 Mdot
.60595 .31451 Mdot
.34789 .40799 Mdot
.3322 .37655 Mdot
.28879 .57579 Mdot
.57008 .24775 Mdot
.53677 .31656 Mdot
.59445 .41221 Mdot
.28754 .58036 Mdot
.56554 .59501 Mdot
.53704 .37382 Mdot
.741 .59441 Mdot
.24071 .70656 Mdot
.58244 .4031 Mdot
.3848 .44806 Mdot
.58827 .3672 Mdot
.72736 .59054 Mdot
.58082 .41557 Mdot
.37723 .38301 Mdot
.64807 .26598 Mdot
.52907 .39409 Mdot
.42079 .78996 Mdot
.67872 .45453 Mdot
.65004 .66936 Mdot
.58224 .38842 Mdot
.59665 .39765 Mdot
.66506 .63684 Mdot
.37145 .39682 Mdot
.60632 .41497 Mdot
.2628 .39974 Mdot
.56925 .39441 Mdot
.29931 .59422 Mdot
.68306 .52475 Mdot
.74875 .57386 Mdot
.62165 .29665 Mdot
.38904 .39135 Mdot
.3282 .56158 Mdot
.26953 .57701 Mdot
.55036 .55755 Mdot
.30344 .57877 Mdot
.5813 .36522 Mdot
.68188 .52417 Mdot
.34215 .36389 Mdot
.58524 .58432 Mdot
.36004 .40367 Mdot
.39447 .67594 Mdot
.31076 .57154 Mdot
.56831 .58099 Mdot
.54473 .26256 Mdot
.31458 .56163 Mdot
.38431 .60887 Mdot
.61719 .28897 Mdot
.56351 .59448 Mdot
.39182 .34546 Mdot
.41183 .66865 Mdot
.56044 .58966 Mdot
.29267 .57455 Mdot
.58777 .40266 Mdot
.63125 .29996 Mdot
.30222 .57955 Mdot
.31395 .42104 Mdot
.6089 .30111 Mdot
.56703 .39616 Mdot
.38716 .37326 Mdot
.35442 .39038 Mdot
.56607 .36317 Mdot
.60059 .37359 Mdot
.44116 .71715 Mdot
.55216 .58163 Mdot
.5505 .5809 Mdot
.57189 .54678 Mdot
.4206 .69738 Mdot
.45617 .81822 Mdot
.32725 .57699 Mdot
.74907 .57193 Mdot
.31419 .47641 Mdot
.56265 .57161 Mdot
.44487 .7164 Mdot
.59436 .38437 Mdot
.56185 .44571 Mdot
.29531 .53784 Mdot
.58195 .83791 Mdot
.54869 .44223 Mdot
.34512 .36652 Mdot
.28019 .57416 Mdot
.60955 .34509 Mdot
.36345 .6482 Mdot
.64179 .65121 Mdot
.5818 .22136 Mdot
.28071 .57103 Mdot
.3037 .37344 Mdot
.28093 .56984 Mdot
.59599 .39719 Mdot
.54764 .40285 Mdot
.34157 .40769 Mdot
.65184 .6719 Mdot
.58311 .44139 Mdot
.56977 .40893 Mdot
.39266 .75572 Mdot
.36497 .33769 Mdot
.63876 .62171 Mdot
.59984 .4299 Mdot
.59239 .56369 Mdot
.64945 .67313 Mdot
.56118 .38659 Mdot
.56773 .44025 Mdot
.59333 .54848 Mdot
.27383 .55239 Mdot
.66796 .68142 Mdot
.4241 .79346 Mdot
.3446 .37811 Mdot
.27068 .61482 Mdot
.54135 .57775 Mdot
.29054 .54576 Mdot
.59207 .33181 Mdot
.57361 .58399 Mdot
.24712 .51333 Mdot
.8244 .33093 Mdot
.5664 .58984 Mdot
.44479 .72052 Mdot
.52931 .31013 Mdot
.57257 .44184 Mdot
.56669 .39707 Mdot
.65265 .62332 Mdot
.36001 .38293 Mdot
.30152 .45799 Mdot
.29922 .53883 Mdot
.58566 .37477 Mdot
.36984 .34828 Mdot
.1893 .4325 Mdot
.57628 .57771 Mdot
.65708 .66684 Mdot
.67659 .676 Mdot
.56731 .37707 Mdot
.72627 .46995 Mdot
.37861 .37468 Mdot
.57314 .39367 Mdot
.55822 .38495 Mdot
.41513 .71748 Mdot
.38741 .35382 Mdot
.4336 .66709 Mdot
.61794 .2781 Mdot
.61984 .24156 Mdot
.36012 .562 Mdot
.31662 .57439 Mdot
.54627 .56993 Mdot
.31297 .53977 Mdot
.45102 .73098 Mdot
.55038 .58022 Mdot
.57375 .39293 Mdot
.34151 .3645 Mdot
.57294 .39445 Mdot
.5696 .39512 Mdot
.58829 .40851 Mdot
.58564 .2211 Mdot
.47524 .68454 Mdot
.6632 .66734 Mdot
.61284 .41201 Mdot
.42441 .68408 Mdot
.36325 .68397 Mdot
.53129 .31837 Mdot
.57978 .38452 Mdot
.55946 .40008 Mdot
.40534 .36093 Mdot
.62695 .28833 Mdot
.31219 .56254 Mdot
.34268 .40877 Mdot
.53666 .41335 Mdot
.44916 .74676 Mdot
.60829 .41014 Mdot
.34329 .35657 Mdot
.32288 .58225 Mdot
.44875 .35285 Mdot
.54785 .59061 Mdot
.54424 .57023 Mdot
.56354 .59039 Mdot
.56635 .54702 Mdot
.29097 .59359 Mdot
.4492 .71419 Mdot
.45915 .74844 Mdot
.58659 .45218 Mdot
.59905 .36816 Mdot
.5475 .40034 Mdot
.41988 .72766 Mdot
.5995 .56911 Mdot
.54877 .24381 Mdot
.61323 .35152 Mdot
.41736 .67889 Mdot
.58971 .55586 Mdot
.30955 .31037 Mdot
.3558 .40659 Mdot
.47073 .70508 Mdot
.26676 .57627 Mdot
.64836 .65512 Mdot
.6804 .74679 Mdot
.35196 .39848 Mdot
.42648 .39502 Mdot
.44498 .67373 Mdot
.66923 .51268 Mdot
.45331 .15764 Mdot
.44515 .70485 Mdot
.60728 .31205 Mdot
.37224 .36016 Mdot
.59403 .57147 Mdot
.71749 .49381 Mdot
.67995 .51709 Mdot
.42746 .654 Mdot
.56812 .4298 Mdot
.41663 .63373 Mdot
.43454 .71947 Mdot
.55057 .56426 Mdot
.4252 .70398 Mdot
.32169 .55437 Mdot
.44222 .68621 Mdot
.30988 .40966 Mdot
.59436 .42476 Mdot
.45406 .16126 Mdot
.68716 .54886 Mdot
.6019 .39242 Mdot
.30851 .55116 Mdot
.33913 .61602 Mdot
.58646 .42233 Mdot
.63682 .63713 Mdot
.44634 .71918 Mdot
.37779 .63234 Mdot
.63386 .29068 Mdot
.40823 .69634 Mdot
.39239 .38654 Mdot
.37121 .60257 Mdot
.36837 .60537 Mdot
.55935 .58851 Mdot
.38324 .35623 Mdot
.29654 .53021 Mdot
.29188 .54795 Mdot
.53912 .54836 Mdot
.58293 .36168 Mdot
.38934 .3792 Mdot
.52402 .41823 Mdot
.51746 .57532 Mdot
.56936 .39294 Mdot
.43515 .66904 Mdot
.46314 .65252 Mdot
.66552 .53831 Mdot
.43184 .69612 Mdot
.55027 .5627 Mdot
.38959 .37072 Mdot
.63527 .29114 Mdot
.35121 .38708 Mdot
.60542 .38589 Mdot
.36456 .58642 Mdot
.36448 .40579 Mdot
.58882 .6242 Mdot
.56426 .42065 Mdot
.48698 .20344 Mdot
.61004 .41879 Mdot
.56694 .39502 Mdot
.43243 .64187 Mdot
.66638 .63882 Mdot
.54609 .61203 Mdot
.36184 .65959 Mdot
.64241 .63842 Mdot
.32539 .4228 Mdot
.42206 .6403 Mdot
.68237 .65889 Mdot
.61589 .78504 Mdot
.54935 .55403 Mdot
.67342 .67008 Mdot
.55632 .37294 Mdot
.31449 .57746 Mdot
.33279 .38892 Mdot
.55603 .38064 Mdot
.60644 .25102 Mdot
.6236 .27061 Mdot
.57287 .57533 Mdot
.56419 .39693 Mdot
.59826 .39473 Mdot
.36848 .34844 Mdot
.1713 .47401 Mdot
.46181 .70877 Mdot
.57666 .55964 Mdot
.34932 .39329 Mdot
.16942 .46616 Mdot
.44266 .64762 Mdot
.68125 .6504 Mdot
.32053 .54157 Mdot
.30797 .3611 Mdot
.56918 .57263 Mdot
.30882 .57381 Mdot
.4285 .62745 Mdot
.6764 .58914 Mdot
.62837 .31536 Mdot
.45339 .68965 Mdot
.68804 .59336 Mdot
.62059 .27975 Mdot
.35975 .6659 Mdot
.23662 .59592 Mdot
.37738 .40014 Mdot
.29819 .58022 Mdot
.65557 .66899 Mdot
.35157 .35419 Mdot
.36043 .40378 Mdot
.31948 .57245 Mdot
.55295 .18445 Mdot
.71825 .48852 Mdot
.32947 .5437 Mdot
.65024 .50955 Mdot
.68073 .58979 Mdot
.57105 .57062 Mdot
.66362 .66355 Mdot
.36887 .59359 Mdot
.3722 .38474 Mdot
.29843 .46959 Mdot
.69327 .59628 Mdot
.61673 .28674 Mdot
.64796 .65202 Mdot
.19254 .43243 Mdot
.24692 .54055 Mdot
.31181 .56598 Mdot
.39142 .75355 Mdot
.64591 .63421 Mdot
.5645 .36681 Mdot
.60447 .83461 Mdot
.56912 .36687 Mdot
.31528 .58105 Mdot
.60593 .31227 Mdot
.3527 .36984 Mdot
.32626 .5757 Mdot
.61203 .28322 Mdot
.59386 .43694 Mdot
.60022 .4077 Mdot
.47445 .67142 Mdot
.34868 .41432 Mdot
.53719 .57379 Mdot
.60168 .38951 Mdot
.5686 .41162 Mdot
.57057 .5969 Mdot
.74628 .57618 Mdot
.46365 .59558 Mdot
.59096 .58608 Mdot
.42586 .6656 Mdot
.58628 .58398 Mdot
.57309 .55936 Mdot
.39641 .35101 Mdot
.37215 .70932 Mdot
.55234 .59008 Mdot
.57759 .40288 Mdot
.57235 .3997 Mdot
.32257 .54132 Mdot
.71916 .49013 Mdot
.6731 .51269 Mdot
.4559 .71611 Mdot
.52618 .56327 Mdot
.55457 .42396 Mdot
.38407 .35503 Mdot
.62738 .61736 Mdot
.55334 .55678 Mdot
.34308 .37774 Mdot
.59087 .4304 Mdot
.41521 .71825 Mdot
.56663 .58847 Mdot
.57736 .59826 Mdot
.65195 .65227 Mdot
.33136 .55527 Mdot
.39129 .39845 Mdot
.43878 .72053 Mdot
.61982 .32241 Mdot
.52833 .57827 Mdot
.41467 .70804 Mdot
.57288 .57008 Mdot
.5885 .57715 Mdot
.38365 .35919 Mdot
.30296 .37989 Mdot
.60143 .58553 Mdot
.42186 .69396 Mdot
.21518 .66501 Mdot
.2828 .55917 Mdot
.61441 .39874 Mdot
.32195 .54746 Mdot
.38053 .39815 Mdot
.73351 .58935 Mdot
.68238 .66944 Mdot
.31516 .56528 Mdot
.57506 .59342 Mdot
.36202 .40479 Mdot
.35537 .41551 Mdot
.57925 .39892 Mdot
.57458 .38815 Mdot
.43807 .74462 Mdot
.71794 .60406 Mdot
.30576 .53433 Mdot
.65462 .62538 Mdot
.46068 .70326 Mdot
.63294 .29758 Mdot
.36252 .36 Mdot
.74252 .68294 Mdot
.61503 .40774 Mdot
.42414 .68822 Mdot
.37078 .37353 Mdot
.6457 .62437 Mdot
.6645 .6687 Mdot
.5969 .37581 Mdot
.61536 .62418 Mdot
.31892 .56483 Mdot
.38362 .37072 Mdot
.39178 .43101 Mdot
.609 .41796 Mdot
.5787 .38747 Mdot
.6189 .28405 Mdot
.33132 .54707 Mdot
.55884 .37113 Mdot
.65466 .67266 Mdot
.35997 .35602 Mdot
.5925 .37475 Mdot
.64842 .63332 Mdot
.53974 .56146 Mdot
.57123 .5858 Mdot
.44368 .6435 Mdot
.63777 .63004 Mdot
.65481 .63435 Mdot
.64321 .63282 Mdot
.28857 .46904 Mdot
.6201 .40583 Mdot
.59748 .60552 Mdot
.56266 .42742 Mdot
.67719 .58829 Mdot
.62229 .32295 Mdot
.29743 .54973 Mdot
.41739 .65943 Mdot
.59179 .41016 Mdot
.55977 .42452 Mdot
.38678 .39993 Mdot
.63821 .29201 Mdot
.56523 .36436 Mdot
.35414 .36575 Mdot
.39849 .42473 Mdot
.40942 .6608 Mdot
.17373 .46957 Mdot
.65454 .81284 Mdot
.59964 .35898 Mdot
.67191 .51707 Mdot
.37054 .39909 Mdot
.32155 .54152 Mdot
.65648 .5102 Mdot
.33192 .56141 Mdot
.3586 .38954 Mdot
.63908 .28521 Mdot
.31546 .4243 Mdot
.64339 .64175 Mdot
.5952 .3982 Mdot
.32191 .56857 Mdot
.59558 .40173 Mdot
.32505 .56266 Mdot
.53869 .22813 Mdot
.71483 .5075 Mdot
.59405 .35954 Mdot
.56038 .43372 Mdot
.62109 .64328 Mdot
.57737 .38605 Mdot
.41067 .7817 Mdot
.36881 .36954 Mdot
.53834 .54527 Mdot
.64115 .28624 Mdot
.52625 .28616 Mdot
.56091 .39677 Mdot
.62134 .26896 Mdot
.55643 .40191 Mdot
.56614 .83778 Mdot
.61295 .38282 Mdot
.58012 .36201 Mdot
.2996 .55603 Mdot
.28172 .55195 Mdot
.37256 .41006 Mdot
.58479 .57985 Mdot
.18931 .4388 Mdot
.56615 .40678 Mdot
.46364 .67382 Mdot
.51351 .57834 Mdot
.65725 .6337 Mdot
.35273 .35927 Mdot
.82045 .31297 Mdot
.27973 .59256 Mdot
.43788 .65974 Mdot
.60935 .31203 Mdot
.42874 .66546 Mdot
.46947 .69605 Mdot
.35216 .44188 Mdot
.66288 .66405 Mdot
.6092 .40176 Mdot
.49162 .29397 Mdot
.44254 .37197 Mdot
.60874 .4182 Mdot
.41452 .6411 Mdot
.59468 .54985 Mdot
.68001 .38735 Mdot
.68466 .69003 Mdot
.66099 .64233 Mdot
.29857 .57503 Mdot
.46188 .66975 Mdot
.57776 .56086 Mdot
.68359 .66253 Mdot
.40689 .67325 Mdot
.55015 .55488 Mdot
.38404 .7395 Mdot
.3792 .37475 Mdot
.55168 .22733 Mdot
.49435 .19337 Mdot
.31368 .54674 Mdot
.36146 .68025 Mdot
.34248 .36231 Mdot
.35994 .34801 Mdot
.57999 .56918 Mdot
.41677 .67592 Mdot
.32295 .39524 Mdot
.59652 .37797 Mdot
.58652 .58255 Mdot
.57436 .37116 Mdot
.68895 .68407 Mdot
.56781 .40249 Mdot
.40635 .68492 Mdot
.30622 .55386 Mdot
.42916 .71157 Mdot
.3026 .57557 Mdot
.75213 .56848 Mdot
.56451 .41677 Mdot
.58 .3895 Mdot
.68181 .52345 Mdot
.39585 .36051 Mdot
.49102 .30393 Mdot
.42369 .6946 Mdot
.4273 .70906 Mdot
.64105 .28792 Mdot
.33782 .38348 Mdot
.59424 .59733 Mdot
.64629 .50985 Mdot
.55621 .39929 Mdot
.36742 .37118 Mdot
.62304 .32356 Mdot
.21151 .58271 Mdot
.70798 .51819 Mdot
.39796 .36088 Mdot
.41781 .79104 Mdot
.55208 .39614 Mdot
.5721 .55595 Mdot
.5711 .54025 Mdot
.7306 .45811 Mdot
.54156 .61007 Mdot
.34435 .38176 Mdot
.5849 .56416 Mdot
.36524 .35905 Mdot
.42524 .7155 Mdot
.32291 .58428 Mdot
.3618 .36663 Mdot
.55714 .40682 Mdot
.65569 .81143 Mdot
.32406 .56978 Mdot
.59287 .39572 Mdot
.31994 .58168 Mdot
.32974 .38741 Mdot
.35452 .37897 Mdot
.55015 .555 Mdot
.60715 .30549 Mdot
.31746 .56498 Mdot
.59566 .36537 Mdot
.36228 .45463 Mdot
.63452 .30122 Mdot
.52931 .55 Mdot
.55661 .4274 Mdot
.58673 .4337 Mdot
.43889 .80784 Mdot
.52096 .39771 Mdot
.36299 .57314 Mdot
.34031 .56666 Mdot
.29148 .4613 Mdot
.39023 .34753 Mdot
.69041 .67553 Mdot
.3735 .41047 Mdot
.54559 .57563 Mdot
.42731 .66144 Mdot
.58984 .40586 Mdot
.55469 .54938 Mdot
.32571 .53648 Mdot
.67513 .66617 Mdot
.60974 .37686 Mdot
.45695 .68673 Mdot
.57756 .55242 Mdot
.31059 .56989 Mdot
.3692 .38871 Mdot
.34838 .37137 Mdot
.37416 .7156 Mdot
.59346 .37625 Mdot
.57394 .39027 Mdot
.29771 .5909 Mdot
.59908 .6223 Mdot
.64065 .63834 Mdot
.59493 .5625 Mdot
.30863 .5883 Mdot
.70889 .51726 Mdot
.34568 .41513 Mdot
.59684 .38934 Mdot
.68532 .52729 Mdot
.2957 .45822 Mdot
.39223 .31414 Mdot
.65463 .64101 Mdot
.71136 .4585 Mdot
.34457 .38243 Mdot
.29651 .56031 Mdot
.60996 .78693 Mdot
.62133 .2829 Mdot
.58899 .42364 Mdot
.7083 .44854 Mdot
.64646 .50746 Mdot
.61172 .32059 Mdot
.54368 .58438 Mdot
.70438 .49278 Mdot
.64098 .29235 Mdot
.62652 .31541 Mdot
.55059 .42011 Mdot
.55525 .42679 Mdot
.36182 .3746 Mdot
.57092 .25035 Mdot
.44158 .67515 Mdot
.61219 .33552 Mdot
.65133 .68688 Mdot
.61485 .29331 Mdot
.56101 .44285 Mdot
.34019 .30401 Mdot
.72464 .40681 Mdot
.37481 .36373 Mdot
.3979 .37537 Mdot
.31319 .54498 Mdot
.63608 .29613 Mdot
.42328 .69132 Mdot
.60045 .55759 Mdot
.41396 .66879 Mdot
.36323 .3754 Mdot
.41091 .65341 Mdot
.26743 .58903 Mdot
.4535 .68938 Mdot
.41987 .67448 Mdot
.30274 .55279 Mdot
.3468 .41288 Mdot
.60912 .421 Mdot
.30354 .55238 Mdot
.58517 .59678 Mdot
.68485 .65662 Mdot
.41737 .40709 Mdot
.59405 .57798 Mdot
.55324 .44559 Mdot
.21234 .64994 Mdot
.45144 .67698 Mdot
.6958 .44559 Mdot
.36003 .40912 Mdot
.63352 .66106 Mdot
.35906 .36911 Mdot
.60146 .58751 Mdot
.65135 .64309 Mdot
.55375 .3765 Mdot
.71592 .69839 Mdot
.23998 .59701 Mdot
.53591 .38044 Mdot
.39781 .42544 Mdot
.41239 .67447 Mdot
.31712 .55329 Mdot
.29686 .62479 Mdot
.57787 .55955 Mdot
.38963 .39145 Mdot
.29984 .36912 Mdot
.54805 .57856 Mdot
.3007 .55865 Mdot
.48559 .22263 Mdot
.59904 .38516 Mdot
.31807 .54552 Mdot
.55913 .42928 Mdot
.57172 .22408 Mdot
.62172 .61703 Mdot
.57197 .54607 Mdot
.63757 .2839 Mdot
.4416 .6478 Mdot
.64059 .2866 Mdot
.59642 .24846 Mdot
.72883 .60087 Mdot
.55662 .41879 Mdot
.70029 .44547 Mdot
.44768 .73166 Mdot
.36873 .35505 Mdot
.55665 .57487 Mdot
.57254 .57218 Mdot
.63259 .28062 Mdot
.73931 .74387 Mdot
.67941 .65991 Mdot
.40712 .77808 Mdot
.5637 .41404 Mdot
.56898 .38425 Mdot
.37726 .40924 Mdot
.53737 .23086 Mdot
.59348 .56303 Mdot
.57705 .42729 Mdot
.72913 .4158 Mdot
.28802 .56459 Mdot
.54343 .41897 Mdot
.57053 .37537 Mdot
.37227 .59663 Mdot
.29797 .55749 Mdot
.42224 .72039 Mdot
.54575 .5572 Mdot
.44114 .64102 Mdot
.6429 .66606 Mdot
.70448 .46844 Mdot
.74167 .58275 Mdot
.70414 .51942 Mdot
.63779 .64676 Mdot
.62184 .2936 Mdot
.56821 .45387 Mdot
.59132 .42525 Mdot
.66591 .64563 Mdot
.2628 .57113 Mdot
.36595 .37014 Mdot
.56267 .22499 Mdot
.57487 .57164 Mdot
.62132 .31961 Mdot
.65698 .6839 Mdot
.36768 .36004 Mdot
.48331 .20606 Mdot
.36071 .38139 Mdot
.30753 .56743 Mdot
.36001 .66971 Mdot
.64834 .64291 Mdot
.35884 .36862 Mdot
.4298 .64404 Mdot
.36297 .58441 Mdot
.62175 .39091 Mdot
.26633 .58817 Mdot
.3217 .41394 Mdot
.39795 .37028 Mdot
.38703 .33914 Mdot
.63243 .28504 Mdot
.6985 .44587 Mdot
.54645 .56788 Mdot
.31896 .58467 Mdot
.44931 .65758 Mdot
.71974 .60285 Mdot
.48452 .24176 Mdot
.69716 .50362 Mdot
.54714 .39513 Mdot
.56886 .40252 Mdot
.56384 .3817 Mdot
.55379 .59497 Mdot
.56425 .4546 Mdot
.55577 .42017 Mdot
.29648 .53725 Mdot
.4187 .71532 Mdot
.5667 .41428 Mdot
.5673 .58516 Mdot
.5841 .61721 Mdot
.63474 .66342 Mdot
.58804 .21669 Mdot
.4157 .40544 Mdot
.3653 .36312 Mdot
.42833 .67753 Mdot
.42542 .63797 Mdot
.6854 .6704 Mdot
.28689 .57773 Mdot
.35956 .38408 Mdot
.56159 .83662 Mdot
.64326 .64689 Mdot
.58042 .40447 Mdot
.68293 .52413 Mdot
.72863 .42587 Mdot
.57188 .44357 Mdot
.58792 .40996 Mdot
.57764 .59131 Mdot
.42251 .68704 Mdot
.60249 .26934 Mdot
.48485 .20605 Mdot
.64878 .63454 Mdot
.67169 .63899 Mdot
.37134 .34112 Mdot
.59237 .36233 Mdot
.32089 .56932 Mdot
.72068 .48731 Mdot
.32958 .61753 Mdot
.20254 .40531 Mdot
.39979 .67505 Mdot
.60917 .40597 Mdot
.52627 .30273 Mdot
.54095 .42938 Mdot
.36208 .34281 Mdot
.30543 .38217 Mdot
.37857 .36345 Mdot
.28635 .56895 Mdot
.65719 .58066 Mdot
.2715 .57038 Mdot
.58914 .55594 Mdot
.34884 .40301 Mdot
.5248 .40151 Mdot
.4271 .7078 Mdot
.6357 .30308 Mdot
.66347 .65627 Mdot
.58418 .49379 Mdot
.55928 .57264 Mdot
.70932 .46185 Mdot
.44533 .71586 Mdot
.3357 .41042 Mdot
.63612 .30303 Mdot
.36366 .65203 Mdot
.7036 .49833 Mdot
.41843 .73708 Mdot
.55274 .54979 Mdot
.64496 .64132 Mdot
.53175 .32068 Mdot
.64558 .65572 Mdot
.31686 .56705 Mdot
.56552 .4195 Mdot
.58323 .36248 Mdot
.56516 .39294 Mdot
.55487 .3791 Mdot
.28991 .57283 Mdot
.623 .31397 Mdot
.59662 .58776 Mdot
.56282 .54818 Mdot
.61038 .30231 Mdot
.66843 .66609 Mdot
.28689 .55553 Mdot
.4142 .70916 Mdot
.56524 .59283 Mdot
.66088 .68282 Mdot
.55943 .35807 Mdot
.56442 .42479 Mdot
.57778 .55032 Mdot
.55575 .37403 Mdot
.62162 .31165 Mdot
.44935 .6894 Mdot
.61584 .3189 Mdot
.63726 .66748 Mdot
.6591 .65272 Mdot
.30728 .57903 Mdot
.35922 .36748 Mdot
.677 .67868 Mdot
.45786 .70517 Mdot
.53742 .40605 Mdot
.55488 .4254 Mdot
.30903 .40644 Mdot
.6919 .59628 Mdot
.63165 .65553 Mdot
.56041 .36921 Mdot
.38448 .35019 Mdot
.30044 .35728 Mdot
.58488 .42556 Mdot
.61843 .30574 Mdot
.39591 .34829 Mdot
.68497 .66027 Mdot
.29056 .58117 Mdot
.69287 .55363 Mdot
.3285 .57027 Mdot
.37009 .38917 Mdot
.58508 .56707 Mdot
.34689 .41153 Mdot
.57992 .56016 Mdot
.24274 .35122 Mdot
.55396 .42025 Mdot
.32256 .43634 Mdot
.6007 .5717 Mdot
.424 .70511 Mdot
.41495 .69123 Mdot
.56366 .58727 Mdot
.34326 .38741 Mdot
.5496 .56409 Mdot
.65082 .66347 Mdot
.29511 .46302 Mdot
.39869 .3534 Mdot
.419 .6753 Mdot
.45288 .67836 Mdot
.30994 .58814 Mdot
.56454 .40032 Mdot
.59741 .38964 Mdot
.45395 .69377 Mdot
.32303 .61877 Mdot
.37772 .39744 Mdot
.57445 .39068 Mdot
.58761 .59035 Mdot
.44518 .68094 Mdot
.2356 .57744 Mdot
.32868 .39637 Mdot
.63768 .28213 Mdot
.73108 .59902 Mdot
.31686 .58921 Mdot
.54023 .42244 Mdot
.62193 .3097 Mdot
.67228 .64734 Mdot
.71192 .45452 Mdot
.68588 .59113 Mdot
.27473 .59106 Mdot
.54461 .56953 Mdot
.57044 .4441 Mdot
.41913 .7033 Mdot
.54058 .3903 Mdot
.82722 .37752 Mdot
.57783 .54863 Mdot
.58995 .37521 Mdot
.57863 .54376 Mdot
.35079 .38656 Mdot
.57007 .38936 Mdot
.3604 .56748 Mdot
.43034 .68035 Mdot
.59384 .37838 Mdot
.61769 .63082 Mdot
.32054 .58049 Mdot
.55974 .57342 Mdot
.64405 .63798 Mdot
.60918 .32279 Mdot
.75584 .56263 Mdot
.42083 .72876 Mdot
.66711 .6714 Mdot
.56264 .40075 Mdot
.46198 .7028 Mdot
.28477 .54908 Mdot
.55624 .57806 Mdot
.5435 .37092 Mdot
.29652 .54726 Mdot
.2898 .55973 Mdot
.64866 .64808 Mdot
.4752 .18332 Mdot
.59468 .35725 Mdot
.5878 .38558 Mdot
.47761 .20547 Mdot
.30846 .33325 Mdot
.59444 .40031 Mdot
.56333 .37575 Mdot
.31174 .57384 Mdot
.65356 .58078 Mdot
.70991 .45981 Mdot
.59906 .55916 Mdot
.31375 .55138 Mdot
.41005 .64756 Mdot
.44191 .66476 Mdot
.6668 .67466 Mdot
.37085 .37469 Mdot
.68371 .67652 Mdot
.43922 .68267 Mdot
.58038 .4014 Mdot
.29693 .58396 Mdot
.63445 .2536 Mdot
.3248 .57816 Mdot
.45722 .70274 Mdot
.34833 .35261 Mdot
.60342 .26138 Mdot
.82628 .36953 Mdot
.45459 .59322 Mdot
.35915 .66879 Mdot
.65872 .63415 Mdot
.48453 .20665 Mdot
.56053 .40831 Mdot
.58912 .25275 Mdot
.59307 .39185 Mdot
.68925 .65449 Mdot
.40965 .67782 Mdot
.55001 .55501 Mdot
.57679 .55897 Mdot
.70629 .46098 Mdot
.28611 .56284 Mdot
.27112 .58175 Mdot
.58934 .57232 Mdot
.30799 .56409 Mdot
.58873 .37769 Mdot
.44391 .71154 Mdot
.25712 .33718 Mdot
.55588 .402 Mdot
.53281 .55747 Mdot
.28486 .59629 Mdot
.33066 .37317 Mdot
.41047 .64703 Mdot
.52628 .29587 Mdot
.18262 .45103 Mdot
.31566 .5611 Mdot
.58965 .21776 Mdot
.42655 .68438 Mdot
.56629 .59294 Mdot
.46349 .7023 Mdot
.59072 .38459 Mdot
.60929 .40599 Mdot
.56637 .59631 Mdot
.55842 .3951 Mdot
.48437 .33093 Mdot
.61471 .28705 Mdot
.62644 .39885 Mdot
.56602 .42934 Mdot
.33017 .43 Mdot
.28765 .54494 Mdot
.58844 .57199 Mdot
.6185 .50851 Mdot
.58919 .4308 Mdot
.38962 .3456 Mdot
.30137 .547 Mdot
.18116 .47076 Mdot
.28786 .56862 Mdot
.42554 .71133 Mdot
.28435 .57463 Mdot
.53996 .4259 Mdot
.3576 .39348 Mdot
.43767 .69495 Mdot
.56428 .57243 Mdot
.43983 .65395 Mdot
.60171 .39155 Mdot
.2365 .56621 Mdot
.43783 .6605 Mdot
.61834 .28461 Mdot
.35613 .39152 Mdot
.72955 .69366 Mdot
.43693 .37671 Mdot
.58425 .3966 Mdot
.59036 .39846 Mdot
.59586 .56571 Mdot
.29831 .57827 Mdot
.33654 .4128 Mdot
.39391 .75852 Mdot
.63168 .65637 Mdot
.37513 .36878 Mdot
.61349 .61772 Mdot
.66814 .51201 Mdot
.35686 .35503 Mdot
.72998 .41989 Mdot
.31807 .574 Mdot
.34562 .37579 Mdot
.51649 .5651 Mdot
.62666 .32372 Mdot
.65878 .66111 Mdot
.43505 .64115 Mdot
.66162 .51113 Mdot
.4374 .66555 Mdot
.36466 .58618 Mdot
.45525 .64344 Mdot
.31909 .55981 Mdot
.61269 .62495 Mdot
.6061 .31595 Mdot
.26705 .58186 Mdot
.32248 .48666 Mdot
.43708 .6729 Mdot
.59148 .56837 Mdot
.61581 .31491 Mdot
.57269 .59905 Mdot
.57845 .55566 Mdot
.27669 .59135 Mdot
.34514 .37413 Mdot
.34031 .37444 Mdot
.5483 .54059 Mdot
.35059 .36827 Mdot
.44476 .70124 Mdot
.69882 .52754 Mdot
.54406 .26313 Mdot
.28361 .54688 Mdot
.61027 .32556 Mdot
.5513 .43314 Mdot
.40727 .69061 Mdot
.44162 .70867 Mdot
.28603 .5655 Mdot
.43458 .34933 Mdot
.56954 .5541 Mdot
.32879 .38469 Mdot
.35094 .39876 Mdot
.34934 .38422 Mdot
.3705 .40794 Mdot
.66947 .58653 Mdot
.30804 .55089 Mdot
.34422 .38902 Mdot
.55074 .39317 Mdot
.5618 .37981 Mdot
.56046 .59089 Mdot
.68986 .67629 Mdot
.61594 .30581 Mdot
.5498 .56266 Mdot
.59242 .41994 Mdot
.42515 .70307 Mdot
.51477 .58863 Mdot
.54334 .57263 Mdot
.42252 .69092 Mdot
.42165 .69745 Mdot
.54362 .56704 Mdot
.51646 .59348 Mdot
.4799 .34335 Mdot
.64427 .27897 Mdot
.36842 .44227 Mdot
.41448 .68054 Mdot
.33403 .49999 Mdot
.32155 .435 Mdot
.58371 .36406 Mdot
.59622 .56247 Mdot
.43842 .71544 Mdot
.39998 .35717 Mdot
.58109 .38258 Mdot
.57974 .56739 Mdot
.65283 .65968 Mdot
.56357 .57597 Mdot
.58006 .58958 Mdot
.39263 .36218 Mdot
.21654 .66009 Mdot
.37013 .3485 Mdot
.47262 .66989 Mdot
.56256 .56721 Mdot
.45293 .16013 Mdot
.41116 .68156 Mdot
.29458 .46484 Mdot
.60616 .31 Mdot
.58934 .42487 Mdot
.42942 .6763 Mdot
.39264 .38581 Mdot
.26055 .58205 Mdot
.72473 .40186 Mdot
.35745 .36854 Mdot
.54145 .57847 Mdot
.57203 .59004 Mdot
.44295 .67606 Mdot
.37043 .39263 Mdot
.62161 .30905 Mdot
.3491 .37663 Mdot
.27509 .5807 Mdot
.55001 .37812 Mdot
.18869 .44041 Mdot
.57827 .56162 Mdot
.35345 .36223 Mdot
.45555 .66824 Mdot
.65502 .67335 Mdot
.56975 .3658 Mdot
.1758 .45375 Mdot
.56134 .39865 Mdot
.2826 .58838 Mdot
.52463 .59222 Mdot
.62418 .32444 Mdot
.58125 .41369 Mdot
.56672 .44652 Mdot
.27165 .54997 Mdot
.58148 .41632 Mdot
.59129 .43267 Mdot
.49098 .20054 Mdot
.36782 .35106 Mdot
.5654 .41278 Mdot
.45165 .69818 Mdot
.48883 .58746 Mdot
.57853 .37251 Mdot
.36203 .6743 Mdot
.72883 .46056 Mdot
.60297 .57476 Mdot
.54321 .53647 Mdot
.73256 .59021 Mdot
.58958 .39318 Mdot
.59832 .36566 Mdot
.54917 .38007 Mdot
.5433 .28685 Mdot
.43554 .68097 Mdot
.45042 .65065 Mdot
.65882 .67379 Mdot
.70733 .44527 Mdot
.65548 .65093 Mdot
.28582 .54811 Mdot
.61308 .28299 Mdot
.54904 .55265 Mdot
.36072 .36422 Mdot
.56537 .39078 Mdot
.45345 .6594 Mdot
.59152 .38212 Mdot
.63007 .29823 Mdot
.44595 .6949 Mdot
.43372 .71537 Mdot
.4436 .63696 Mdot
.64752 .63155 Mdot
.37095 .36237 Mdot
.5774 .35979 Mdot
.64356 .63492 Mdot
.56613 .59706 Mdot
.70393 .55171 Mdot
.37369 .36181 Mdot
.35763 .35923 Mdot
.33869 .40195 Mdot
.58513 .3605 Mdot
.55843 .36628 Mdot
.27385 .56752 Mdot
.30871 .40602 Mdot
.31817 .57994 Mdot
.43057 .67265 Mdot
.42701 .71941 Mdot
.59166 .38586 Mdot
.61002 .61995 Mdot
.66653 .66507 Mdot
.44571 .66103 Mdot
.56657 .54363 Mdot
.66274 .68011 Mdot
.59787 .3704 Mdot
.43462 .66667 Mdot
.63757 .63414 Mdot
.43434 .34863 Mdot
.21565 .43789 Mdot
.65666 .67563 Mdot
.57289 .55742 Mdot
.48496 .24927 Mdot
.72298 .59869 Mdot
.62625 .61714 Mdot
.28511 .54686 Mdot
.61545 .40571 Mdot
.56928 .54498 Mdot
.66045 .68151 Mdot
.71587 .609 Mdot
.44205 .68889 Mdot
.5691 .55588 Mdot
.52385 .62321 Mdot
.5447 .26391 Mdot
.65266 .67331 Mdot
.3544 .36064 Mdot
.32815 .41497 Mdot
.58322 .4082 Mdot
.60765 .3053 Mdot
.28689 .5428 Mdot
.42749 .63933 Mdot
.45043 .65268 Mdot
.30381 .36906 Mdot
.70584 .51904 Mdot
.45086 .68593 Mdot
.61222 .38762 Mdot
.67075 .68766 Mdot
.55038 .39461 Mdot
.52031 .57835 Mdot
.63266 .31599 Mdot
.55333 .53402 Mdot
.6556 .67434 Mdot
.27879 .55004 Mdot
.30649 .55435 Mdot
.29566 .57676 Mdot
.44857 .68288 Mdot
.6579 .5086 Mdot
.45878 .66342 Mdot
.48161 .18565 Mdot
.68009 .6625 Mdot
.467 .8238 Mdot
.55446 .44814 Mdot
.59657 .41675 Mdot
.62549 .31918 Mdot
.58814 .5877 Mdot
.58792 .39162 Mdot
.29268 .5487 Mdot
.43044 .64452 Mdot
.23292 .58506 Mdot
.38756 .37457 Mdot
.48441 .18908 Mdot
.42792 .70689 Mdot
.53796 .55228 Mdot
.66608 .65997 Mdot
.74681 .58769 Mdot
.67628 .63839 Mdot
.44269 .72088 Mdot
.60591 .39748 Mdot
.39294 .34021 Mdot
.57359 .83749 Mdot
.56869 .3915 Mdot
.45108 .67494 Mdot
.42133 .73471 Mdot
.61824 .3338 Mdot
.55844 .32859 Mdot
.23354 .59564 Mdot
.68876 .52386 Mdot
.63624 .63142 Mdot
.5774 .59726 Mdot
.72429 .48307 Mdot
.43903 .68067 Mdot
.43144 .64854 Mdot
.64077 .61908 Mdot
.33299 .36884 Mdot
.34377 .40167 Mdot
.42354 .41857 Mdot
.28364 .55521 Mdot
.58282 .42907 Mdot
.4373 .66902 Mdot
.34757 .3544 Mdot
.61028 .50579 Mdot
.2997 .57171 Mdot
.43989 .6591 Mdot
.55905 .39412 Mdot
.57908 .4122 Mdot
.65456 .65221 Mdot
.57995 .61709 Mdot
.58921 .59195 Mdot
.29699 .46377 Mdot
.67598 .50755 Mdot
.61317 .28101 Mdot
.58878 .42384 Mdot
.38557 .39054 Mdot
.54636 .57522 Mdot
.66328 .66477 Mdot
.54023 .39369 Mdot
.59872 .25768 Mdot
.39682 .37611 Mdot
.32012 .57186 Mdot
.56909 .56858 Mdot
.70181 .46801 Mdot
.55936 .3962 Mdot
.59252 .39056 Mdot
.6325 .2852 Mdot
.60819 .25847 Mdot
.41634 .66107 Mdot
.38123 .35115 Mdot
.64508 .63626 Mdot
.3559 .3804 Mdot
.37837 .72504 Mdot
.61007 .29388 Mdot
.61471 .38895 Mdot
.38842 .34838 Mdot
.36067 .38692 Mdot
.2817 .58778 Mdot
.31212 .55347 Mdot
.40691 .71812 Mdot
.56631 .37162 Mdot
.57908 .54842 Mdot
.34572 .38953 Mdot
.43262 .64036 Mdot
.65384 .64976 Mdot
.36233 .68805 Mdot
.55994 .42331 Mdot
.43912 .67534 Mdot
.55449 .57286 Mdot
.39049 .36761 Mdot
.4256 .69277 Mdot
.56701 .59308 Mdot
.68074 .65021 Mdot
.59145 .43731 Mdot
.42621 .74175 Mdot
.58369 .57141 Mdot
.56097 .37533 Mdot
.6291 .38769 Mdot
.60803 .31063 Mdot
.59795 .55622 Mdot
.40508 .69439 Mdot
.58004 .57242 Mdot
.33112 .41495 Mdot
.61501 .33737 Mdot
.43771 .64503 Mdot
.31559 .42464 Mdot
.60612 .30476 Mdot
.58284 .56243 Mdot
.36705 .35627 Mdot
.38524 .74085 Mdot
.34617 .34678 Mdot
.71548 .59432 Mdot
.57868 .37589 Mdot
.43771 .66556 Mdot
.65682 .65986 Mdot
.27391 .58327 Mdot
.28126 .5079 Mdot
.35052 .5259 Mdot
.4176 .68549 Mdot
.56509 .3892 Mdot
.34546 .37848 Mdot
.31447 .56241 Mdot
.38036 .40751 Mdot
.46275 .69556 Mdot
.44991 .70569 Mdot
.62331 .32075 Mdot
.65599 .65025 Mdot
.56347 .45381 Mdot
.43917 .64296 Mdot
.46075 .64987 Mdot
.49135 .20309 Mdot
.63593 .6343 Mdot
.63279 .28349 Mdot
.54897 .53944 Mdot
.54368 .41782 Mdot
.4816 .20733 Mdot
.57862 .58771 Mdot
.38707 .37701 Mdot
.5932 .40986 Mdot
.28058 .7389 Mdot
.41009 .68901 Mdot
.68901 .52354 Mdot
.23983 .59623 Mdot
.2946 .55487 Mdot
.43092 .68523 Mdot
.57632 .38183 Mdot
.36106 .68391 Mdot
.66761 .67536 Mdot
.64207 .28628 Mdot
.58825 .56737 Mdot
.30299 .35894 Mdot
.292 .58379 Mdot
.53062 .61897 Mdot
.27311 .58167 Mdot
.3049 .57872 Mdot
.43358 .35332 Mdot
.58263 .40728 Mdot
.43027 .70346 Mdot
.45667 .69505 Mdot
.53113 .5531 Mdot
.477 .67721 Mdot
.34711 .40779 Mdot
.27338 .73054 Mdot
.5991 .26185 Mdot
.5621 .41837 Mdot
.54313 .58346 Mdot
.59067 .55898 Mdot
.35977 .6697 Mdot
.58508 .41474 Mdot
.37257 .35423 Mdot
.44109 .64218 Mdot
.44325 .66773 Mdot
.61804 .28538 Mdot
.30698 .55406 Mdot
.664 .62831 Mdot
.44233 .70532 Mdot
.69053 .55226 Mdot
.59055 .37498 Mdot
.26135 .58998 Mdot
.44182 .7036 Mdot
.69194 .77454 Mdot
.21775 .67292 Mdot
.36203 .3487 Mdot
.58859 .44083 Mdot
.32913 .39723 Mdot
.65065 .66939 Mdot
.46796 .68234 Mdot
.26839 .58113 Mdot
.56276 .56933 Mdot
.24871 .61459 Mdot
.44389 .67216 Mdot
.36377 .37432 Mdot
.58573 .4041 Mdot
.59476 .21852 Mdot
.55679 .40261 Mdot
.65062 .57936 Mdot
.62931 .64849 Mdot
.27763 .50963 Mdot
.30188 .59065 Mdot
.5893 .44067 Mdot
.6423 .63333 Mdot
.44628 .72145 Mdot
.44571 .69239 Mdot
.17279 .46153 Mdot
.57854 .59013 Mdot
.46789 .69995 Mdot
.56267 .37365 Mdot
.44609 .63888 Mdot
.48429 .24164 Mdot
.29561 .55537 Mdot
.55484 .42883 Mdot
.43106 .66324 Mdot
.33201 .36081 Mdot
.68103 .52102 Mdot
.58444 .37346 Mdot
.57585 .542 Mdot
.31562 .55772 Mdot
.48571 .18694 Mdot
.40854 .6788 Mdot
.55071 .41008 Mdot
.29847 .54463 Mdot
.61308 .62393 Mdot
.22901 .57758 Mdot
.37151 .36193 Mdot
.45374 .6787 Mdot
.28941 .58133 Mdot
.55759 .56417 Mdot
.63767 .63845 Mdot
.45572 .71267 Mdot
.43011 .66068 Mdot
.62387 .29528 Mdot
.54505 .54472 Mdot
.61249 .61743 Mdot
.37211 .40088 Mdot
.31488 .57337 Mdot
.62975 .29378 Mdot
.7015 .55632 Mdot
.54718 .37615 Mdot
.31271 .57802 Mdot
.46197 .16544 Mdot
.60677 .404 Mdot
.5634 .42708 Mdot
.60146 .22318 Mdot
.32886 .40897 Mdot
.38003 .39933 Mdot
.70015 .50138 Mdot
.61834 .30284 Mdot
.52422 .40608 Mdot
.3672 .3654 Mdot
.36347 .37765 Mdot
.52442 .40498 Mdot
.62606 .29719 Mdot
.43336 .41074 Mdot
.311 .56161 Mdot
.29777 .55339 Mdot
.35014 .3849 Mdot
.62586 .31928 Mdot
.32094 .54081 Mdot
.36092 .3167 Mdot
.45351 .70651 Mdot
.72544 .47107 Mdot
.35553 .38632 Mdot
.67983 .52495 Mdot
.31681 .56764 Mdot
.73956 .54783 Mdot
.72975 .45565 Mdot
.59036 .3555 Mdot
.58326 .41101 Mdot
.66209 .63698 Mdot
.56135 .57438 Mdot
.54335 .56778 Mdot
.29512 .57707 Mdot
.56504 .45478 Mdot
.37903 .36497 Mdot
.53792 .42166 Mdot
.71972 .60425 Mdot
.75119 .54361 Mdot
.60194 .28286 Mdot
.36926 .37591 Mdot
.37404 .38156 Mdot
.42738 .72118 Mdot
.41545 .643 Mdot
.60072 .36165 Mdot
.31324 .55579 Mdot
.34666 .36805 Mdot
.30882 .58278 Mdot
.43994 .68201 Mdot
.4303 .70788 Mdot
.5498 .5829 Mdot
.5673 .55573 Mdot
.43483 .68882 Mdot
.36185 .67401 Mdot
.70217 .55541 Mdot
.30626 .39315 Mdot
.48302 .17892 Mdot
.75029 .57395 Mdot
.56919 .22425 Mdot
.65475 .66031 Mdot
.51447 .58593 Mdot
.29449 .54658 Mdot
.58106 .44508 Mdot
.59573 .41091 Mdot
.57613 .57817 Mdot
.31263 .54391 Mdot
.67352 .65836 Mdot
.29452 .55543 Mdot
.63843 .63895 Mdot
.44247 .64857 Mdot
.56694 .38549 Mdot
.60376 .39555 Mdot
.28046 .5865 Mdot
.43174 .72287 Mdot
.43126 .66559 Mdot
.65818 .66404 Mdot
.74489 .58097 Mdot
.44213 .67657 Mdot
.35652 .38639 Mdot
.2834 .32003 Mdot
.57495 .5881 Mdot
.5801 .38318 Mdot
.73463 .59054 Mdot
.61418 .33785 Mdot
.56343 .59644 Mdot
.57003 .56883 Mdot
.47424 .18403 Mdot
.59616 .37613 Mdot
.17413 .47472 Mdot
.54388 .57483 Mdot
.34626 .41153 Mdot
.43019 .69812 Mdot
.54798 .5876 Mdot
.56634 .53744 Mdot
.62042 .61605 Mdot
.54807 .58961 Mdot
.34487 .39968 Mdot
.33073 .40488 Mdot
.6139 .31476 Mdot
.49321 .16711 Mdot
.64422 .63977 Mdot
.67321 .66645 Mdot
.41745 .66249 Mdot
.36498 .58779 Mdot
.57005 .46659 Mdot
.67601 .66908 Mdot
.42239 .40494 Mdot
.62669 .31636 Mdot
.61107 .32074 Mdot
.61065 .30535 Mdot
.3489 .41628 Mdot
.5835 .34811 Mdot
.4125 .67068 Mdot
.36532 .37266 Mdot
.61617 .31958 Mdot
.53635 .40057 Mdot
.37604 .36169 Mdot
.30765 .57606 Mdot
.6071 .28924 Mdot
.34865 .37275 Mdot
.72502 .39987 Mdot
.32036 .56572 Mdot
.60484 .32894 Mdot
.52019 .82217 Mdot
.71318 .76165 Mdot
.29276 .55849 Mdot
.44183 .66039 Mdot
.43624 .67068 Mdot
.4485 .69058 Mdot
.37431 .40252 Mdot
.4195 .71256 Mdot
.37539 .38973 Mdot
.35941 .66135 Mdot
.70648 .45302 Mdot
.64967 .64276 Mdot
.47615 .69088 Mdot
.35002 .38297 Mdot
.48113 .19732 Mdot
.82417 .32801 Mdot
.55017 .40597 Mdot
.26854 .58362 Mdot
.67801 .67534 Mdot
.69116 .52854 Mdot
.67166 .64665 Mdot
.42673 .68328 Mdot
.70436 .46501 Mdot
.59185 .37996 Mdot
.20391 .4512 Mdot
.6579 .65872 Mdot
.36235 .37897 Mdot
.62018 .29219 Mdot
.40606 .70404 Mdot
.66429 .67346 Mdot
.66055 .65391 Mdot
.58607 .38934 Mdot
.33621 .41068 Mdot
.42696 .67692 Mdot
.31736 .54836 Mdot
.38877 .62802 Mdot
.57373 .48993 Mdot
.5944 .37222 Mdot
.56485 .43084 Mdot
.67256 .51538 Mdot
.36275 .68798 Mdot
.30747 .55854 Mdot
.70319 .59973 Mdot
.40672 .69158 Mdot
.72471 .60358 Mdot
.34919 .34732 Mdot
.4757 .69323 Mdot
.57939 .58644 Mdot
.56228 .59214 Mdot
.57417 .39256 Mdot
.82596 .35162 Mdot
.55751 .335 Mdot
.31809 .53894 Mdot
.5747 .584 Mdot
.4282 .72386 Mdot
.37666 .40424 Mdot
.51964 .62427 Mdot
.61707 .30834 Mdot
.31902 .54946 Mdot
.44493 .68531 Mdot
.84876 .40469 Mdot
.65925 .6331 Mdot
.69455 .52231 Mdot
.5586 .38288 Mdot
.5775 .39079 Mdot
.29397 .57056 Mdot
.26625 .56242 Mdot
.49305 .19119 Mdot
.67847 .63761 Mdot
.18935 .43381 Mdot
.31901 .53183 Mdot
.85919 .42017 Mdot
.58626 .55418 Mdot
.37889 .3789 Mdot
.54427 .56283 Mdot
.27002 .55755 Mdot
.59447 .40506 Mdot
.33304 .41031 Mdot
.55447 .57774 Mdot
.42939 .39067 Mdot
.60955 .3208 Mdot
.69412 .55293 Mdot
.5695 .40322 Mdot
.3347 .39109 Mdot
.36869 .36763 Mdot
.33535 .37226 Mdot
.56346 .58893 Mdot
.5761 .42756 Mdot
.55216 .41031 Mdot
.56775 .43096 Mdot
.4966 .19454 Mdot
.56947 .38669 Mdot
.38806 .33518 Mdot
.71057 .50902 Mdot
.29416 .75288 Mdot
.60345 .3978 Mdot
.29008 .57922 Mdot
.57183 .39708 Mdot
.64523 .6289 Mdot
.58492 .44052 Mdot
.60777 .32239 Mdot
.30529 .56189 Mdot
.59797 .24919 Mdot
.64908 .68504 Mdot
.59747 .37378 Mdot
.63732 .64412 Mdot
.28054 .47545 Mdot
.6978 .5955 Mdot
.48572 .22372 Mdot
.34969 .37813 Mdot
.46505 .68856 Mdot
.29113 .53952 Mdot
.42555 .71077 Mdot
.64073 .26644 Mdot
.55457 .55109 Mdot
.45591 .81813 Mdot
.71318 .55603 Mdot
.59384 .40735 Mdot
.59569 .5683 Mdot
.36698 .3536 Mdot
.41047 .68329 Mdot
.53946 .22966 Mdot
.62632 .31797 Mdot
.68698 .66838 Mdot
.67753 .6499 Mdot
.52766 .58174 Mdot
.33354 .37181 Mdot
.48295 .23788 Mdot
.29501 .56925 Mdot
.44759 .67842 Mdot
.64849 .6761 Mdot
.40868 .41839 Mdot
.26163 .57457 Mdot
.36037 .6603 Mdot
.28923 .58301 Mdot
.59883 .41617 Mdot
.5428 .5777 Mdot
.3472 .45294 Mdot
.58374 .57815 Mdot
.53784 .40045 Mdot
.42903 .66234 Mdot
.57869 .58864 Mdot
.65534 .63699 Mdot
.29566 .58105 Mdot
.42621 .70523 Mdot
.58825 .39862 Mdot
.36733 .36195 Mdot
.67891 .37953 Mdot
.43819 .74103 Mdot
.60803 .29875 Mdot
.60808 .29839 Mdot
.30023 .38093 Mdot
.60116 .56045 Mdot
.25256 .52438 Mdot
.61814 .33618 Mdot
.359 .54946 Mdot
.58482 .61979 Mdot
.40517 .77589 Mdot
.46029 .66748 Mdot
.43948 .69502 Mdot
.59933 .39046 Mdot
.43526 .63871 Mdot
.61361 .38971 Mdot
.40509 .68298 Mdot
.29288 .45724 Mdot
.53538 .38135 Mdot
.44447 .69734 Mdot
.5466 .56456 Mdot
.5668 .36828 Mdot
.37282 .35198 Mdot
.46172 .66441 Mdot
.59005 .35534 Mdot
.41521 .78389 Mdot
.28078 .58728 Mdot
.56309 .58947 Mdot
.633 .51176 Mdot
.31098 .56706 Mdot
.34961 .40517 Mdot
.61326 .41492 Mdot
.67497 .6727 Mdot
.37241 .38653 Mdot
.55074 .59941 Mdot
.65753 .65004 Mdot
.70035 .52809 Mdot
.35622 .39783 Mdot
.57815 .58567 Mdot
.68092 .65189 Mdot
.5346 .54367 Mdot
.44117 .69295 Mdot
.42444 .73739 Mdot
.58278 .56833 Mdot
.59357 .3829 Mdot
.42013 .72139 Mdot
.28408 .56743 Mdot
.57217 .37339 Mdot
.43875 .66755 Mdot
.56534 .58442 Mdot
.55334 .39914 Mdot
.61747 .30306 Mdot
.48594 .20374 Mdot
.60377 .57358 Mdot
.65068 .63946 Mdot
.3397 .3646 Mdot
.55167 .41562 Mdot
.6413 .64322 Mdot
.4475 .73063 Mdot
.54719 .40424 Mdot
.34811 .3615 Mdot
.44743 .36464 Mdot
.42478 .63859 Mdot
.32358 .566 Mdot
.45829 .6911 Mdot
.64074 .66203 Mdot
.8228 .31822 Mdot
.54484 .5735 Mdot
.64203 .2959 Mdot
.5784 .43854 Mdot
.46583 .68323 Mdot
.3717 .36576 Mdot
.19434 .41742 Mdot
.58941 .43899 Mdot
.54776 .39964 Mdot
.58201 .38563 Mdot
.3772 .63278 Mdot
.36485 .40767 Mdot
.58137 .38401 Mdot
.54749 .61246 Mdot
.5638 .43271 Mdot
.65258 .66799 Mdot
.48358 .8263 Mdot
.57128 .59514 Mdot
.44883 .15766 Mdot
.5551 .58046 Mdot
.4466 .70154 Mdot
.72519 .39907 Mdot
.63056 .51048 Mdot
.3947 .67549 Mdot
.34973 .40616 Mdot
.36626 .44232 Mdot
.43182 .70758 Mdot
.38341 .73733 Mdot
.61815 .31201 Mdot
.6206 .29459 Mdot
.57357 .36604 Mdot
.42671 .68362 Mdot
.42378 .64645 Mdot
.55983 .55034 Mdot
.595 .57169 Mdot
.6126 .35307 Mdot
.4522 .66023 Mdot
.56871 .38497 Mdot
.61871 .32883 Mdot
.26096 .57503 Mdot
.36029 .35068 Mdot
.26667 .57743 Mdot
.26216 .5808 Mdot
.56157 .22603 Mdot
.67455 .50677 Mdot
.28468 .55387 Mdot
.29759 .54054 Mdot
.36777 .64111 Mdot
.55837 .2514 Mdot
.64856 .66504 Mdot
.55412 .33681 Mdot
.43037 .71891 Mdot
.57404 .42673 Mdot
.36223 .4092 Mdot
.59973 .59014 Mdot
.2101 .38957 Mdot
.81826 .50542 Mdot
.63124 .30609 Mdot
.40982 .70322 Mdot
.58447 .57061 Mdot
.58872 .57357 Mdot
.72295 .59962 Mdot
.57153 .38498 Mdot
.42712 .63876 Mdot
.54541 .26241 Mdot
.31416 .53003 Mdot
.36105 .67862 Mdot
.32848 .384 Mdot
.56968 .39617 Mdot
.38012 .39353 Mdot
.32726 .56489 Mdot
.64398 .64982 Mdot
.65403 .63307 Mdot
.59879 .375 Mdot
.60635 .31553 Mdot
.3583 .54487 Mdot
.61648 .29866 Mdot
.62819 .30057 Mdot
.57859 .5716 Mdot
.63034 .28194 Mdot
.55004 .41055 Mdot
.55254 .36111 Mdot
.56804 .59747 Mdot
.264 .57795 Mdot
.54386 .24627 Mdot
.58442 .56403 Mdot
.6065 .42787 Mdot
.32688 .56758 Mdot
.61543 .30293 Mdot
.28752 .57004 Mdot
.36375 .68948 Mdot
.27645 .56483 Mdot
.64797 .63642 Mdot
.43493 .62915 Mdot
.48837 .18414 Mdot
.3463 .37634 Mdot
.30698 .55133 Mdot
.68166 .65101 Mdot
.28576 .57308 Mdot
.4374 .71969 Mdot
.29083 .53323 Mdot
.31893 .32579 Mdot
.68897 .55075 Mdot
.57637 .22575 Mdot
.31184 .53048 Mdot
.42123 .64099 Mdot
.34946 .38535 Mdot
.36214 .57419 Mdot
.59922 .4311 Mdot
.65587 .6316 Mdot
.57564 .39299 Mdot
.30012 .58039 Mdot
.41833 .71553 Mdot
.48367 .22287 Mdot
.65119 .63802 Mdot
.48029 .182 Mdot
.45551 .66383 Mdot
.59979 .42296 Mdot
.32299 .58423 Mdot
.29576 .50278 Mdot
.29526 .5905 Mdot
.7128 .45167 Mdot
.57247 .54608 Mdot
.6938 .65541 Mdot
.36635 .3912 Mdot
.5887 .5542 Mdot
.78496 .6484 Mdot
.31314 .47485 Mdot
.38374 .35664 Mdot
.46671 .70975 Mdot
.59224 .37489 Mdot
.63353 .28184 Mdot
.55575 .55911 Mdot
.33835 .37807 Mdot
.63235 .28559 Mdot
.55418 .58726 Mdot
.71268 .50431 Mdot
.3312 .3788 Mdot
.45441 .71719 Mdot
.56575 .37133 Mdot
.28013 .59255 Mdot
.32531 .57685 Mdot
.54097 .57199 Mdot
.27082 .57845 Mdot
.60927 .42534 Mdot
.35552 .39371 Mdot
.61422 .31321 Mdot
.656 .67204 Mdot
.38833 .44551 Mdot
.58725 .59825 Mdot
.68555 .6934 Mdot
.55157 .38742 Mdot
.43048 .70597 Mdot
.24607 .61415 Mdot
.55878 .44194 Mdot
.36558 .3688 Mdot
.58811 .43489 Mdot
.63122 .28341 Mdot
.61854 .29629 Mdot
.44737 .67819 Mdot
.67966 .52192 Mdot
.56829 .38614 Mdot
.3225 .55439 Mdot
.52447 .39297 Mdot
.55901 .44948 Mdot
.68606 .64751 Mdot
.60797 .3232 Mdot
.33301 .57257 Mdot
.30224 .37985 Mdot
.43103 .70244 Mdot
.37947 .36984 Mdot
.40459 .35281 Mdot
.35102 .40489 Mdot
.32034 .37939 Mdot
.61771 .33715 Mdot
.16941 .46793 Mdot
.48413 .24031 Mdot
.5803 .22105 Mdot
.40039 .35416 Mdot
.225 .61897 Mdot
.38352 .35544 Mdot
.34972 .40545 Mdot
.25111 .34173 Mdot
.35025 .40843 Mdot
.59256 .38651 Mdot
.58934 .43099 Mdot
.59956 .26695 Mdot
.39044 .62692 Mdot
.55618 .40443 Mdot
.55891 .59644 Mdot
.68061 .67438 Mdot
.33767 .36222 Mdot
.56563 .56958 Mdot
.69163 .53024 Mdot
.53741 .57126 Mdot
.58639 .39011 Mdot
.56228 .38496 Mdot
.61272 .29975 Mdot
.7608 .5411 Mdot
.40205 .62455 Mdot
.33626 .40216 Mdot
.56069 .45146 Mdot
.23031 .57295 Mdot
.57099 .36995 Mdot
.57439 .44188 Mdot
.58125 .34863 Mdot
.43023 .70354 Mdot
.36716 .41213 Mdot
.57306 .55344 Mdot
.37869 .4502 Mdot
.56259 .40181 Mdot
.59455 .60132 Mdot
.67625 .68347 Mdot
.57743 .38099 Mdot
.33913 .40907 Mdot
.63157 .2843 Mdot
.39589 .37426 Mdot
.36003 .39753 Mdot
.54754 .40262 Mdot
.3381 .36293 Mdot
.38616 .39353 Mdot
.62082 .29546 Mdot
.41184 .7119 Mdot
.29513 .46397 Mdot
.59016 .37997 Mdot
.65608 .63966 Mdot
.58658 .41242 Mdot
.64751 .66552 Mdot
.54815 .58884 Mdot
.58165 .57267 Mdot
.53295 .32217 Mdot
.43403 .64785 Mdot
.68962 .66337 Mdot
.45391 .64155 Mdot
.58586 .45601 Mdot
.42529 .39909 Mdot
.28011 .54098 Mdot
.44574 .74648 Mdot
.5797 .57344 Mdot
.65899 .58091 Mdot
.52591 .43426 Mdot
.27281 .5678 Mdot
.38951 .35464 Mdot
.53209 .25862 Mdot
.59441 .56095 Mdot
.453 .71881 Mdot
.45537 .69819 Mdot
.31559 .47778 Mdot
.25703 .3374 Mdot
.60306 .39581 Mdot
.59591 .56434 Mdot
.62663 .38551 Mdot
.56062 .57509 Mdot
.56183 .5511 Mdot
.43254 .65846 Mdot
.55441 .39949 Mdot
.71665 .5022 Mdot
.43597 .67429 Mdot
.66952 .66233 Mdot
.38667 .37895 Mdot
.63966 .64146 Mdot
.22786 .42469 Mdot
.4923 .18951 Mdot
.43465 .68456 Mdot
.58066 .59371 Mdot
.56659 .42494 Mdot
.33769 .41217 Mdot
.38258 .40532 Mdot
.37068 .35028 Mdot
.66694 .67817 Mdot
.4436 .64506 Mdot
.41734 .78978 Mdot
.58416 .40369 Mdot
.36225 .38528 Mdot
.66289 .68814 Mdot
.57824 .41311 Mdot
.3103 .55405 Mdot
.63147 .28824 Mdot
.35819 .38274 Mdot
.63943 .30236 Mdot
.36567 .39224 Mdot
.45235 .69999 Mdot
.60096 .38043 Mdot
.58503 .36708 Mdot
.69394 .59489 Mdot
.6739 .65789 Mdot
.3987 .36776 Mdot
.66501 .50549 Mdot
.54355 .41765 Mdot
.7269 .59581 Mdot
.56996 .37952 Mdot
.57932 .22539 Mdot
.55694 .54093 Mdot
.55137 .58644 Mdot
.58357 .43729 Mdot
.5872 .37801 Mdot
.37869 .40809 Mdot
.48549 .24208 Mdot
.49655 .19296 Mdot
.32468 .569 Mdot
.38078 .35218 Mdot
.43296 .67548 Mdot
.46302 .66462 Mdot
.42302 .71312 Mdot
.6436 .66834 Mdot
.61487 .30848 Mdot
.59936 .40221 Mdot
.32322 .5456 Mdot
.68003 .66816 Mdot
.36964 .38032 Mdot
.6491 .64829 Mdot
.67752 .51314 Mdot
.66047 .64014 Mdot
.54605 .55733 Mdot
.21162 .65012 Mdot
.61807 .32936 Mdot
.66401 .65126 Mdot
.35717 .35246 Mdot
.5265 .38012 Mdot
.57636 .35466 Mdot
.4834 .196 Mdot
.68636 .67004 Mdot
.46191 .71952 Mdot
.55454 .38298 Mdot
.69774 .44472 Mdot
.29066 .57389 Mdot
.63946 .63719 Mdot
.28722 .58306 Mdot
.63172 .29945 Mdot
.34654 .43897 Mdot
.35967 .37293 Mdot
.25895 .57029 Mdot
.57033 .44002 Mdot
.63963 .63672 Mdot
.43707 .68807 Mdot
.55726 .253 Mdot
.36169 .64928 Mdot
.605 .59753 Mdot
.71855 .59757 Mdot
.41392 .66633 Mdot
.57438 .24347 Mdot
.27518 .57686 Mdot
.54178 .43176 Mdot
.63119 .31712 Mdot
.54269 .40703 Mdot
.42905 .66973 Mdot
.43919 .69594 Mdot
.40016 .76874 Mdot
.59154 .367 Mdot
.58045 .34967 Mdot
.30438 .35146 Mdot
.44081 .64315 Mdot
.35225 .40431 Mdot
.33526 .3843 Mdot
.44091 .66073 Mdot
.39641 .35762 Mdot
.65867 .65211 Mdot
.70381 .48723 Mdot
.27499 .57525 Mdot
.31904 .58437 Mdot
.43418 .68723 Mdot
.41978 .66778 Mdot
.42987 .70648 Mdot
.63398 .29249 Mdot
.35674 .40012 Mdot
.60945 .38715 Mdot
.57592 .39884 Mdot
.56471 .36249 Mdot
.32768 .39612 Mdot
.59271 .43729 Mdot
.52913 .40252 Mdot
.67203 .68084 Mdot
.44427 .70465 Mdot
.31329 .5811 Mdot
.67926 .38565 Mdot
.32453 .55563 Mdot
.55588 .42735 Mdot
.29734 .45839 Mdot
.3904 .35768 Mdot
.66817 .64244 Mdot
.608 .31575 Mdot
.65393 .63536 Mdot
.26081 .57501 Mdot
.30699 .34943 Mdot
.70368 .52329 Mdot
.60726 .38604 Mdot
.67038 .51146 Mdot
.6109 .78593 Mdot
.39808 .33469 Mdot
.31376 .57204 Mdot
.6125 .33094 Mdot
.53785 .5661 Mdot
.61917 .35836 Mdot
.59919 .39392 Mdot
.55376 .44699 Mdot
.69084 .44476 Mdot
.56989 .436 Mdot
.35865 .34904 Mdot
.52741 .39309 Mdot
.58998 .58843 Mdot
.56076 .36946 Mdot
.17813 .46951 Mdot
.5606 .41106 Mdot
.60223 .37647 Mdot
.5927 .41853 Mdot
.545 .42559 Mdot
.32571 .39727 Mdot
.61076 .31143 Mdot
.32548 .55946 Mdot
.70462 .48721 Mdot
.27576 .57332 Mdot
.43012 .6894 Mdot
.60269 .58214 Mdot
.33437 .41734 Mdot
.65492 .63533 Mdot
.39941 .59566 Mdot
.70151 .44487 Mdot
.42782 .72136 Mdot
.67932 .59128 Mdot
.65893 .62522 Mdot
.55564 .55464 Mdot
.63794 .65583 Mdot
.43041 .66311 Mdot
.30249 .55438 Mdot
.60606 .399 Mdot
.34737 .39624 Mdot
.34866 .36949 Mdot
.55932 .37191 Mdot
.29232 .47042 Mdot
.32362 .57864 Mdot
.47694 .68562 Mdot
.60177 .40442 Mdot
.55447 .42853 Mdot
.3911 .38252 Mdot
.41152 .70011 Mdot
.52727 .43402 Mdot
.66037 .66823 Mdot
.5675 .37281 Mdot
.59226 .58233 Mdot
.67617 .513 Mdot
.32468 .56596 Mdot
.56903 .58682 Mdot
.56913 .42158 Mdot
.68526 .50889 Mdot
.64123 .28758 Mdot
.54024 .60815 Mdot
.41203 .65076 Mdot
.54803 .39984 Mdot
.57995 .36738 Mdot
.33025 .381 Mdot
.27429 .57751 Mdot
.37143 .36345 Mdot
.30039 .345 Mdot
.58113 .57299 Mdot
.28815 .58976 Mdot
.54475 .42395 Mdot
.33021 .54399 Mdot
.62976 .28843 Mdot
.58326 .39792 Mdot
.31178 .57297 Mdot
.36574 .39783 Mdot
.19233 .43243 Mdot
.54254 .24698 Mdot
.63025 .2989 Mdot
.58445 .41415 Mdot
.39084 .62731 Mdot
.59938 .59084 Mdot
.60891 .40757 Mdot
.34681 .36893 Mdot
.57905 .41166 Mdot
.31335 .53533 Mdot
.64495 .64558 Mdot
.36343 .3669 Mdot
.40845 .68866 Mdot
.45279 .69186 Mdot
.41558 .64128 Mdot
.54889 .55457 Mdot
.62995 .28208 Mdot
.33828 .36716 Mdot
.3361 .37657 Mdot
.6518 .50773 Mdot
.44637 .70137 Mdot
.65167 .65778 Mdot
.57488 .36351 Mdot
.59702 .56901 Mdot
.30692 .59332 Mdot
.44624 .15666 Mdot
.70395 .51895 Mdot
.65432 .68063 Mdot
.57348 .4907 Mdot
.57508 .57268 Mdot
.56618 .42807 Mdot
.64064 .63662 Mdot
.44005 .66217 Mdot
.63877 .28048 Mdot
.57036 .61936 Mdot
.4605 .72257 Mdot
.41585 .6926 Mdot
.3304 .54668 Mdot
.40727 .67084 Mdot
.63755 .63512 Mdot
.54425 .57163 Mdot
.35561 .36679 Mdot
.57429 .38187 Mdot
.57542 .561 Mdot
.44437 .71099 Mdot
.57983 .55142 Mdot
.60056 .4162 Mdot
.39132 .37901 Mdot
.42924 .71625 Mdot
.58971 .39033 Mdot
.61966 .33262 Mdot
.48692 .20375 Mdot
.4119 .70897 Mdot
.6146 .40173 Mdot
.52648 .62373 Mdot
.41871 .69828 Mdot
.42776 .66806 Mdot
.54678 .40548 Mdot
.65188 .62541 Mdot
.56564 .40041 Mdot
.30773 .5551 Mdot
.6721 .51895 Mdot
.2809 .58682 Mdot
.7259 .6022 Mdot
.55268 .38062 Mdot
.62141 .38761 Mdot
.42852 .39439 Mdot
.67705 .69995 Mdot
.75015 .57635 Mdot
.5537 .417 Mdot
.38479 .39846 Mdot
.67853 .52409 Mdot
.6825 .54732 Mdot
.33673 .31914 Mdot
.64325 .65698 Mdot
.29403 .57681 Mdot
.58968 .36892 Mdot
.18526 .4673 Mdot
.65051 .66373 Mdot
.72445 .5999 Mdot
.58489 .44449 Mdot
.36677 .37585 Mdot
.60185 .39412 Mdot
.3546 .37214 Mdot
.57783 .41986 Mdot
.48362 .2151 Mdot
.35802 .54463 Mdot
.71212 .45148 Mdot
.54785 .56313 Mdot
.29559 .50281 Mdot
.57679 .22512 Mdot
.65651 .65399 Mdot
.6324 .31482 Mdot
.57301 .57703 Mdot
.29394 .55574 Mdot
.26992 .61414 Mdot
.431 .70847 Mdot
.31547 .54921 Mdot
.38179 .37619 Mdot
.42763 .72525 Mdot
.58571 .55251 Mdot
.6227 .4096 Mdot
.64119 .63227 Mdot
.28905 .59004 Mdot
.5803 .3779 Mdot
.53956 .38938 Mdot
.37603 .63342 Mdot
.49489 .82793 Mdot
.37597 .33947 Mdot
.48045 .17733 Mdot
.30658 .34962 Mdot
.67377 .66313 Mdot
.41427 .71561 Mdot
.59453 .40999 Mdot
.55683 .39523 Mdot
.4149 .68993 Mdot
.33797 .41289 Mdot
.68253 .649 Mdot
.69521 .6587 Mdot
.31914 .53941 Mdot
.54319 .83398 Mdot
.36169 .36648 Mdot
.54074 .83434 Mdot
.40798 .77853 Mdot
.27092 .32789 Mdot
.74718 .57951 Mdot
.31013 .56386 Mdot
.54225 .83453 Mdot
.3652 .38 Mdot
.58369 .4314 Mdot
.57884 .58243 Mdot
.55629 .55014 Mdot
.38537 .38703 Mdot
.42631 .68922 Mdot
.64771 .62363 Mdot
.59946 .38726 Mdot
.51872 .59583 Mdot
.38033 .40759 Mdot
.44324 .648 Mdot
.55772 .56995 Mdot
.31806 .57799 Mdot
.58072 .41377 Mdot
.67063 .67916 Mdot
.3084 .5638 Mdot
.56415 .59314 Mdot
.70446 .46776 Mdot
.6135 .41426 Mdot
.60665 .30886 Mdot
.29051 .57163 Mdot
.57598 .48931 Mdot
.57497 .37076 Mdot
.27523 .577 Mdot
.53574 .55513 Mdot
.26931 .50969 Mdot
.53948 .45792 Mdot
.31314 .4749 Mdot
.43847 .729 Mdot
.40498 .69144 Mdot
.48938 .71289 Mdot
.42156 .62451 Mdot
.28229 .55994 Mdot
.5727 .56483 Mdot
.47506 .82723 Mdot
.27508 .58015 Mdot
.56663 .444 Mdot
.59121 .37149 Mdot
.54418 .26318 Mdot
.56872 .59455 Mdot
.55244 .57941 Mdot
.31977 .43298 Mdot
.6142 .32538 Mdot
.55921 .56927 Mdot
.56942 .3766 Mdot
.33147 .40348 Mdot
.31835 .5674 Mdot
.84934 .55034 Mdot
.28246 .54505 Mdot
.63145 .27469 Mdot
.42773 .71891 Mdot
.43572 .72947 Mdot
.57649 .38258 Mdot
.46425 .60029 Mdot
.85641 .41425 Mdot
.59102 .37087 Mdot
.60807 .31691 Mdot
.72412 .60385 Mdot
.55904 .3708 Mdot
.37684 .34519 Mdot
.58258 .58989 Mdot
.32999 .39245 Mdot
.30836 .56783 Mdot
.64385 .6578 Mdot
.64407 .68186 Mdot
.29449 .57626 Mdot
.55983 .40461 Mdot
.57398 .6006 Mdot
.57907 .38948 Mdot
.58698 .42734 Mdot
.6865 .51231 Mdot
.654 .67842 Mdot
.42708 .7008 Mdot
.65115 .63422 Mdot
.34945 .40689 Mdot
.46772 .16832 Mdot
.65336 .65289 Mdot
.55756 .25222 Mdot
.66489 .51168 Mdot
.48204 .82505 Mdot
.35006 .36807 Mdot
.65045 .6696 Mdot
.29164 .57776 Mdot
.65019 .52914 Mdot
.57885 .25081 Mdot
.31868 .55001 Mdot
.58654 .42593 Mdot
.33262 .39285 Mdot
.30019 .3751 Mdot
.32845 .57614 Mdot
.36353 .35695 Mdot
.55032 .46974 Mdot
.62721 .30572 Mdot
.32642 .56052 Mdot
.75413 .55823 Mdot
.30134 .59078 Mdot
.55269 .2292 Mdot
.62732 .29025 Mdot
.36455 .36819 Mdot
.59074 .21705 Mdot
.31052 .34434 Mdot
.55119 .58317 Mdot
.59933 .42676 Mdot
.65336 .65627 Mdot
.65799 .50845 Mdot
.40815 .69798 Mdot
.33191 .36145 Mdot
.35289 .38334 Mdot
.30751 .59414 Mdot
.36228 .35827 Mdot
.39216 .35607 Mdot
.25876 .57142 Mdot
.38335 .3536 Mdot
.56196 .40166 Mdot
.49582 .16778 Mdot
.36721 .35274 Mdot
.29817 .5682 Mdot
.66894 .6767 Mdot
.36111 .3493 Mdot
.38737 .74636 Mdot
.56445 .37188 Mdot
.46255 .69353 Mdot
.63008 .6185 Mdot
.3268 .3992 Mdot
.6568 .65649 Mdot
.4412 .71407 Mdot
.68899 .67509 Mdot
.3405 .56648 Mdot
.33768 .56734 Mdot
.5695 .53781 Mdot
.31968 .48256 Mdot
.35038 .40814 Mdot
.42412 .72444 Mdot
.58576 .36178 Mdot
.59884 .41441 Mdot
.62666 .63834 Mdot
.39847 .37385 Mdot
.28612 .47177 Mdot
.56408 .56924 Mdot
.39175 .44422 Mdot
.32491 .57403 Mdot
.47654 .68854 Mdot
.70482 .52486 Mdot
.36392 .6076 Mdot
.58936 .58947 Mdot
.57544 .57412 Mdot
.58232 .38508 Mdot
.70191 .59793 Mdot
.63755 .64039 Mdot
.22864 .62649 Mdot
.63516 .30239 Mdot
.41408 .68262 Mdot
.57858 .42356 Mdot
.61831 .31951 Mdot
.5508 .41345 Mdot
.65035 .67817 Mdot
.3064 .54325 Mdot
.34611 .37416 Mdot
.64774 .66716 Mdot
.45302 .69097 Mdot
.72978 .41903 Mdot
.60982 .40441 Mdot
.614 .38881 Mdot
.4218 .69435 Mdot
.34472 .40424 Mdot
.43375 .69424 Mdot
.27522 .57536 Mdot
.65188 .6496 Mdot
.63298 .28669 Mdot
.56995 .59463 Mdot
.46586 .68147 Mdot
.30524 .55066 Mdot
.41208 .71397 Mdot
.32431 .53567 Mdot
.57856 .575 Mdot
.61622 .39102 Mdot
.43077 .63738 Mdot
.59114 .56635 Mdot
.49101 .29465 Mdot
.70126 .4677 Mdot
.30908 .3111 Mdot
.42504 .68709 Mdot
.393 .68808 Mdot
.30461 .56524 Mdot
.26969 .56057 Mdot
.55201 .226 Mdot
.82605 .35625 Mdot
.52436 .40683 Mdot
.27042 .48814 Mdot
.27475 .5743 Mdot
.29123 .56512 Mdot
.43249 .69769 Mdot
.36795 .39754 Mdot
.43442 .38388 Mdot
.44284 .72238 Mdot
.73543 .58633 Mdot
.36934 .3806 Mdot
.59887 .26467 Mdot
.45464 .6565 Mdot
.6182 .29375 Mdot
.48283 .22305 Mdot
.67686 .68107 Mdot
.71301 .59634 Mdot
.28638 .5362 Mdot
.59377 .39252 Mdot
.16913 .46526 Mdot
.43387 .70829 Mdot
.58364 .55548 Mdot
.23437 .57175 Mdot
.53671 .40012 Mdot
.57686 .42572 Mdot
.57122 .40717 Mdot
.6328 .63056 Mdot
.48448 .25709 Mdot
.59509 .39959 Mdot
.70605 .45958 Mdot
.62064 .27673 Mdot
.43027 .74115 Mdot
.65005 .63484 Mdot
.66872 .58797 Mdot
.3743 .70995 Mdot
.37254 .45308 Mdot
.554 .44763 Mdot
.28766 .54456 Mdot
.61375 .32395 Mdot
.31095 .57531 Mdot
.33185 .56189 Mdot
.56446 .8365 Mdot
.34316 .37148 Mdot
.63493 .29942 Mdot
.43456 .6519 Mdot
.43475 .38581 Mdot
.61845 .3166 Mdot
.4726 .17154 Mdot
.26741 .59048 Mdot
.82204 .31425 Mdot
.26898 .56356 Mdot
.57004 .54865 Mdot
.3847 .36955 Mdot
.38645 .39881 Mdot
.67108 .5104 Mdot
.35506 .4036 Mdot
.41702 .62408 Mdot
.34111 .36376 Mdot
.6989 .74333 Mdot
.32567 .32345 Mdot
.3012 .5624 Mdot
.32609 .58157 Mdot
.61288 .30517 Mdot
.5625 .39619 Mdot
.71475 .50383 Mdot
.56319 .56969 Mdot
.60715 .42318 Mdot
.43622 .67376 Mdot
.39421 .75918 Mdot
.21063 .58712 Mdot
.38591 .35525 Mdot
.2976 .5512 Mdot
.57837 .42503 Mdot
.62897 .29135 Mdot
.59165 .43009 Mdot
.36788 .58964 Mdot
.62352 .24616 Mdot
.57714 .39718 Mdot
.6144 .30671 Mdot
.43606 .72286 Mdot
.37695 .63402 Mdot
.26129 .33459 Mdot
.55476 .83512 Mdot
.55263 .39987 Mdot
.67711 .66562 Mdot
.64716 .67385 Mdot
.56142 .35193 Mdot
.52872 .50248 Mdot
.5867 .49543 Mdot
.58131 .37773 Mdot
.72867 .41295 Mdot
.45712 .71497 Mdot
.53891 .5666 Mdot
.44571 .70829 Mdot
.40547 .35884 Mdot
.54326 .58049 Mdot
.43625 .66717 Mdot
.72672 .46814 Mdot
.58089 .56765 Mdot
.25702 .51956 Mdot
.6555 .6722 Mdot
.57104 .37424 Mdot
.52551 .23839 Mdot
.44194 .64316 Mdot
.30339 .55682 Mdot
.3825 .36051 Mdot
.32375 .56467 Mdot
.42805 .6272 Mdot
.73168 .59496 Mdot
.55612 .58683 Mdot
.2908 .54197 Mdot
.60619 .32196 Mdot
.67926 .66552 Mdot
.26734 .57091 Mdot
.62335 .27843 Mdot
.55117 .36035 Mdot
.83766 .3955 Mdot
.59245 .35986 Mdot
.39646 .76288 Mdot
.2776 .58601 Mdot
.53707 .56724 Mdot
.57323 .38292 Mdot
.45817 .67128 Mdot
.54043 .53821 Mdot
.5807 .39027 Mdot
.41045 .67507 Mdot
.58723 .37131 Mdot
.64306 .63624 Mdot
.32953 .38604 Mdot
.68085 .52771 Mdot
.69688 .69967 Mdot
.64494 .66071 Mdot
.70037 .44155 Mdot
.60502 .41968 Mdot
.44461 .6162 Mdot
.36933 .37269 Mdot
.5574 .42829 Mdot
.71486 .69599 Mdot
.38117 .38563 Mdot
.37845 .37428 Mdot
.63617 .27652 Mdot
.30713 .53397 Mdot
.42471 .69811 Mdot
.67489 .65084 Mdot
.36049 .67348 Mdot
.59216 .39399 Mdot
.63557 .3088 Mdot
.64968 .66553 Mdot
.3152 .55861 Mdot
.63297 .30091 Mdot
.23911 .52348 Mdot
.70448 .48384 Mdot
.26597 .58202 Mdot
.55152 .44429 Mdot
.62397 .24004 Mdot
.34687 .41533 Mdot
.17055 .46802 Mdot
.35764 .54353 Mdot
.45495 .69535 Mdot
.55865 .56757 Mdot
.4506 .15966 Mdot
.66595 .67815 Mdot
.43991 .36885 Mdot
.60008 .41521 Mdot
.59026 .41527 Mdot
.33239 .40787 Mdot
.60537 .37758 Mdot
.388 .35534 Mdot
.38639 .74359 Mdot
.82586 .34673 Mdot
.35136 .37038 Mdot
.35768 .37869 Mdot
.6062 .28942 Mdot
.44258 .63595 Mdot
.38798 .37647 Mdot
.5858 .36556 Mdot
.4274 .62695 Mdot
.52339 .59577 Mdot
.68426 .65363 Mdot
.63644 .62399 Mdot
.38042 .34377 Mdot
.58225 .24888 Mdot
.61904 .28406 Mdot
.52892 .31037 Mdot
.58799 .50032 Mdot
.28092 .56069 Mdot
.54769 .37765 Mdot
.56815 .57123 Mdot
.43995 .71139 Mdot
.58307 .35194 Mdot
.56731 .37721 Mdot
.3437 .37964 Mdot
.68563 .67779 Mdot
.28268 .58347 Mdot
.58944 .56392 Mdot
.41367 .6407 Mdot
.66523 .66484 Mdot
.39553 .35774 Mdot
.57018 .22504 Mdot
.58932 .596 Mdot
.59602 .56882 Mdot
.56249 .42722 Mdot
.54779 .40495 Mdot
.5885 .59285 Mdot
.29737 .57551 Mdot
.45608 .69491 Mdot
.57269 .55407 Mdot
.64063 .5092 Mdot
.72042 .49348 Mdot
.55772 .41928 Mdot
.35267 .35692 Mdot
.29561 .55366 Mdot
.55324 .58255 Mdot
.46909 .82489 Mdot
.56939 .3645 Mdot
.60159 .26122 Mdot
.6713 .62697 Mdot
.57141 .56859 Mdot
.43472 .38361 Mdot
.66157 .63641 Mdot
.6275 .29068 Mdot
.70857 .45701 Mdot
.59949 .43328 Mdot
.54226 .4325 Mdot
.43745 .66137 Mdot
.2995 .58237 Mdot
.57538 .53988 Mdot
.44332 .70463 Mdot
.37923 .37135 Mdot
.5311 .31325 Mdot
.3356 .3888 Mdot
.33808 .37267 Mdot
.32245 .37763 Mdot
.32362 .57126 Mdot
.45026 .15871 Mdot
.59266 .59175 Mdot
.60365 .39136 Mdot
.29296 .5478 Mdot
.39032 .37062 Mdot
.58728 .44104 Mdot
.39016 .35735 Mdot
.39957 .36696 Mdot
.60205 .43116 Mdot
.61735 .30254 Mdot
.70734 .45111 Mdot
.60172 .25201 Mdot
.65191 .63145 Mdot
.34458 .41208 Mdot
.59198 .25415 Mdot
.5943 .40773 Mdot
.56174 .38648 Mdot
.61188 .30671 Mdot
.64255 .66181 Mdot
.53147 .32226 Mdot
.5974 .41856 Mdot
.70373 .60202 Mdot
.58044 .4433 Mdot
.39857 .37497 Mdot
.27989 .5085 Mdot
.63055 .27447 Mdot
.43115 .72488 Mdot
.3366 .41243 Mdot
.67713 .68148 Mdot
.32558 .41987 Mdot
.61233 .3376 Mdot
.28476 .57012 Mdot
.35825 .38261 Mdot
.44847 .7186 Mdot
.30725 .55757 Mdot
.30191 .59064 Mdot
.61103 .30533 Mdot
.45634 .68295 Mdot
.68513 .67881 Mdot
.30144 .58748 Mdot
.6199 .35335 Mdot
.30139 .5612 Mdot
.4058 .32427 Mdot
.61316 .3832 Mdot
.70735 .46018 Mdot
.55935 .55962 Mdot
.55961 .53981 Mdot
.28764 .58813 Mdot
.65966 .66901 Mdot
.63311 .30132 Mdot
.37343 .35113 Mdot
.67297 .67267 Mdot
.48409 .22639 Mdot
.43467 .72888 Mdot
.30059 .37416 Mdot
.36091 .65502 Mdot
.36711 .40325 Mdot
.71601 .59668 Mdot
.66759 .68375 Mdot
.59911 .56901 Mdot
.68992 .52327 Mdot
.55621 .57319 Mdot
.58727 .35258 Mdot
.63323 .30233 Mdot
.56215 .40345 Mdot
.42658 .719 Mdot
.63395 .62996 Mdot
.36194 .35307 Mdot
.55061 .62297 Mdot
.31955 .56103 Mdot
.54471 .36318 Mdot
.57749 .55318 Mdot
.63115 .29695 Mdot
.38981 .36395 Mdot
.38369 .39673 Mdot
.48581 .24467 Mdot
.41881 .70139 Mdot
.6004 .62222 Mdot
.55856 .41886 Mdot
.51748 .60935 Mdot
.28665 .58835 Mdot
.31411 .47537 Mdot
.46213 .70227 Mdot
.81996 .31197 Mdot
.4448 .70082 Mdot
.56081 .61484 Mdot
.37817 .39897 Mdot
.65693 .64251 Mdot
.55747 .40324 Mdot
.32908 .381 Mdot
.43627 .38081 Mdot
.62147 .61964 Mdot
.65693 .63633 Mdot
.3614 .56908 Mdot
.2825 .55571 Mdot
.59368 .56961 Mdot
.57713 .44425 Mdot
.58983 .44086 Mdot
.58892 .36289 Mdot
.29411 .55053 Mdot
.62289 .30508 Mdot
.2928 .50523 Mdot
.61266 .33261 Mdot
.7155 .69567 Mdot
.42413 .66991 Mdot
.28441 .74318 Mdot
.32831 .39831 Mdot
.53172 .31897 Mdot
.44181 .35425 Mdot
.70108 .47156 Mdot
.30901 .54146 Mdot
.53449 .55665 Mdot
.429 .69769 Mdot
.27541 .62053 Mdot
.42466 .66727 Mdot
.86461 .49221 Mdot
.5429 .26332 Mdot
.27384 .51053 Mdot
.60349 .42618 Mdot
.44439 .65881 Mdot
.58715 .24554 Mdot
.5726 .55495 Mdot
.57272 .60061 Mdot
.63615 .31367 Mdot
.49493 .19429 Mdot
.64975 .63142 Mdot
.55717 .40566 Mdot
.33053 .39463 Mdot
.55723 .40052 Mdot
.55646 .402 Mdot
.59661 .42271 Mdot
.25736 .57562 Mdot
.61613 .39363 Mdot
.5621 .39847 Mdot
.42233 .79554 Mdot
.52463 .56349 Mdot
.40738 .66787 Mdot
.375 .40972 Mdot
.68006 .66806 Mdot
.40547 .35981 Mdot
.68491 .52636 Mdot
.26744 .56157 Mdot
.48433 .24817 Mdot
.62395 .29708 Mdot
.35164 .34604 Mdot
.28189 .54654 Mdot
.65963 .62703 Mdot
.57021 .57373 Mdot
.21444 .383 Mdot
.45343 .64107 Mdot
.56324 .58226 Mdot
.40963 .6871 Mdot
.6191 .37186 Mdot
.35805 .3651 Mdot
.55705 .57299 Mdot
.29207 .58519 Mdot
.43109 .65892 Mdot
.70253 .44379 Mdot
.58084 .40807 Mdot
.42556 .68166 Mdot
.57336 .56209 Mdot
.65907 .50867 Mdot
.67784 .52286 Mdot
.44322 .6571 Mdot
.32784 .54925 Mdot
.3114 .58685 Mdot
.67804 .67373 Mdot
.37334 .40558 Mdot
.34622 .39993 Mdot
.31824 .5628 Mdot
.28823 .62489 Mdot
.5908 .39066 Mdot
.58354 .40038 Mdot
.69756 .52642 Mdot
.55909 .43589 Mdot
.41027 .62391 Mdot
.56252 .58 Mdot
.34695 .39005 Mdot
.63296 .30317 Mdot
.62771 .31515 Mdot
.55857 .40943 Mdot
.73893 .58753 Mdot
.43011 .71824 Mdot
.61643 .28705 Mdot
.64018 .63696 Mdot
.49182 .20275 Mdot
.56967 .36953 Mdot
.69035 .69796 Mdot
.3749 .4028 Mdot
.22739 .58007 Mdot
.30149 .55711 Mdot
.43432 .64953 Mdot
.43475 .65086 Mdot
.61487 .78486 Mdot
.329 .40099 Mdot
.56213 .58148 Mdot
.45767 .72631 Mdot
.54374 .56279 Mdot
.66077 .63836 Mdot
.53094 .45173 Mdot
.41229 .62407 Mdot
.40736 .6685 Mdot
.34016 .54202 Mdot
.53832 .40456 Mdot
.56583 .37405 Mdot
.30976 .47084 Mdot
.56843 .38064 Mdot
.64878 .653 Mdot
.27313 .56428 Mdot
.36002 .38177 Mdot
.65424 .62927 Mdot
.2823 .54844 Mdot
.34939 .40459 Mdot
.61321 .29839 Mdot
.5838 .44262 Mdot
.38147 .36659 Mdot
.39637 .36393 Mdot
.59267 .38519 Mdot
.58156 .8377 Mdot
.34573 .37978 Mdot
.38419 .36404 Mdot
.49258 .20133 Mdot
.4252 .64017 Mdot
.5377 .54132 Mdot
.30642 .53507 Mdot
.56535 .40233 Mdot
.42133 .67675 Mdot
.66671 .64738 Mdot
.35251 .38674 Mdot
.54984 .40524 Mdot
.59093 .39717 Mdot
.67835 .66629 Mdot
.63476 .63932 Mdot
.66511 .67266 Mdot
.32866 .57535 Mdot
.62081 .29411 Mdot
.38731 .37106 Mdot
.31178 .54639 Mdot
.66703 .68115 Mdot
.63623 .63335 Mdot
.73322 .68956 Mdot
.59136 .38759 Mdot
.63364 .64128 Mdot
.46281 .1658 Mdot
.72837 .45819 Mdot
.54163 .56779 Mdot
.40179 .69403 Mdot
.41621 .63341 Mdot
.52911 .59439 Mdot
.29618 .58182 Mdot
.60944 .32334 Mdot
.6789 .64544 Mdot
.57443 .55866 Mdot
.58234 .40392 Mdot
.55352 .37555 Mdot
.6732 .66914 Mdot
.73247 .59693 Mdot
.34137 .38219 Mdot
.29069 .31841 Mdot
.68013 .66623 Mdot
.44682 .65679 Mdot
.4608 .71072 Mdot
.4416 .69511 Mdot
.55491 .41509 Mdot
.60148 .28018 Mdot
.56777 .48569 Mdot
.47737 .35088 Mdot
.27897 .56079 Mdot
.38731 .39202 Mdot
.48954 .19775 Mdot
.37717 .37692 Mdot
.41716 .70801 Mdot
.65879 .66843 Mdot
.3342 .40648 Mdot
.32138 .58242 Mdot
.30233 .58914 Mdot
.43047 .63804 Mdot
.44759 .70002 Mdot
.43579 .68616 Mdot
.33102 .41313 Mdot
.3881 .3846 Mdot
.59847 .43183 Mdot
.35254 .35951 Mdot
.38749 .74228 Mdot
.38476 .74015 Mdot
.43706 .63991 Mdot
.30079 .57154 Mdot
.36025 .39699 Mdot
.58276 .36812 Mdot
.68897 .44503 Mdot
.4662 .70359 Mdot
.68373 .67386 Mdot
.49518 .16775 Mdot
.82615 .36274 Mdot
.62463 .32184 Mdot
.28144 .56632 Mdot
.54604 .56827 Mdot
.56923 .40958 Mdot
.45497 .69913 Mdot
.60104 .60369 Mdot
.57924 .5908 Mdot
.60618 .37196 Mdot
.6066 .43468 Mdot
.28967 .5593 Mdot
.68548 .52917 Mdot
.57685 .55781 Mdot
.61685 .27765 Mdot
.28071 .55431 Mdot
.46358 .67446 Mdot
.47222 .73909 Mdot
.32852 .44407 Mdot
.6324 .55176 Mdot
.55724 .59088 Mdot
.57548 .36063 Mdot
.43947 .67145 Mdot
.65385 .62773 Mdot
.43967 .67656 Mdot
.39999 .35297 Mdot
.42491 .6387 Mdot
.58188 .37054 Mdot
.38651 .37536 Mdot
.30202 .58973 Mdot
.64148 .52724 Mdot
.61827 .63392 Mdot
.45802 .66834 Mdot
.59961 .57373 Mdot
.61737 .32295 Mdot
.62413 .40146 Mdot
.55824 .53991 Mdot
.57041 .37261 Mdot
.31227 .57325 Mdot
.38823 .35783 Mdot
.31486 .55426 Mdot
.54416 .53591 Mdot
.42314 .34201 Mdot
.2996 .5571 Mdot
.60046 .28878 Mdot
.64679 .62347 Mdot
.73428 .59302 Mdot
.58536 .37509 Mdot
.29637 .58454 Mdot
.61267 .38549 Mdot
.34187 .41169 Mdot
.72303 .47955 Mdot
.70382 .4806 Mdot
.31806 .56908 Mdot
.57711 .54677 Mdot
.66339 .51154 Mdot
.53783 .5405 Mdot
.27561 .57423 Mdot
.73188 .44984 Mdot
.57072 .58367 Mdot
.66543 .66059 Mdot
.63642 .62973 Mdot
.66088 .66307 Mdot
.57758 .39956 Mdot
.61408 .2318 Mdot
.65932 .67994 Mdot
.26536 .6101 Mdot
.64439 .65075 Mdot
.52419 .59004 Mdot
.28733 .46915 Mdot
.63789 .63499 Mdot
.57567 .37707 Mdot
.61236 .33182 Mdot
.60931 .32087 Mdot
.45701 .70548 Mdot
.20225 .40242 Mdot
.42075 .79389 Mdot
.59454 .41066 Mdot
.48647 .18892 Mdot
.33332 .37573 Mdot
.60085 .57143 Mdot
.70327 .47785 Mdot
.60615 .30358 Mdot
.37705 .38143 Mdot
.68824 .52564 Mdot
.30504 .38858 Mdot
.55533 .55636 Mdot
.58118 .39739 Mdot
.33512 .41193 Mdot
.3309 .36222 Mdot
.75042 .57505 Mdot
.36271 .45468 Mdot
.35456 .4008 Mdot
.27412 .57748 Mdot
.29417 .58025 Mdot
.31452 .57228 Mdot
.4508 .69573 Mdot
.35585 .38023 Mdot
.53915 .37532 Mdot
.45386 .69783 Mdot
.58981 .42433 Mdot
.31882 .56625 Mdot
.70597 .47357 Mdot
.35838 .37899 Mdot
.58422 .37724 Mdot
.58614 .25393 Mdot
.41246 .6706 Mdot
.67726 .66746 Mdot
.48632 .18267 Mdot
.40829 .71054 Mdot
.32893 .5429 Mdot
.39963 .34895 Mdot
.52549 .56672 Mdot
.6134 .2834 Mdot
.55178 .41865 Mdot
.60666 .39886 Mdot
.61275 .2835 Mdot
.54568 .25821 Mdot
.59064 .58111 Mdot
.45286 .69117 Mdot
.42089 .64242 Mdot
.5689 .36682 Mdot
.35271 .37864 Mdot
.66288 .68685 Mdot
.69329 .68095 Mdot
.57605 .62035 Mdot
.67182 .51562 Mdot
.706 .45999 Mdot
.54861 .42869 Mdot
.54483 .32495 Mdot
.452 .71342 Mdot
.54355 .55763 Mdot
.67729 .51447 Mdot
.65905 .65443 Mdot
.58542 .43025 Mdot
.39992 .38843 Mdot
.35534 .38694 Mdot
.42486 .68997 Mdot
.28039 .59246 Mdot
.58628 .59747 Mdot
.43736 .63926 Mdot
.56838 .36724 Mdot
.63056 .31006 Mdot
.27092 .57818 Mdot
.39449 .34786 Mdot
.66967 .66399 Mdot
.45163 .70454 Mdot
.65647 .64571 Mdot
.36466 .35827 Mdot
.3518 .38756 Mdot
.57405 .4355 Mdot
.59153 .6233 Mdot
.45844 .66593 Mdot
.55487 .41032 Mdot
.42903 .67757 Mdot
.37562 .63386 Mdot
.3115 .59203 Mdot
.56154 .43154 Mdot
.43066 .3897 Mdot
.32044 .5698 Mdot
.59181 .41764 Mdot
.60981 .31383 Mdot
.63247 .30136 Mdot
.44618 .65914 Mdot
.69012 .66141 Mdot
.66316 .65448 Mdot
.44879 .35813 Mdot
.47966 .23997 Mdot
.54295 .42047 Mdot
.43659 .64319 Mdot
.63439 .31886 Mdot
.28873 .56402 Mdot
.37297 .40124 Mdot
.22686 .6836 Mdot
.29745 .56666 Mdot
.58964 .37364 Mdot
.65271 .65304 Mdot
.39804 .36389 Mdot
.54094 .57572 Mdot
.70808 .55327 Mdot
.57582 .54325 Mdot
.58364 .62257 Mdot
.59078 .57011 Mdot
.27615 .48469 Mdot
.43638 .6827 Mdot
.39008 .36715 Mdot
.27962 .56949 Mdot
.28609 .56733 Mdot
.41076 .69642 Mdot
.48574 .22809 Mdot
.26838 .32978 Mdot
.46202 .15822 Mdot
.46473 .65411 Mdot
.65348 .66213 Mdot
.72285 .4765 Mdot
.44088 .69691 Mdot
.40692 .69374 Mdot
.3692 .58999 Mdot
.31105 .47135 Mdot
.36694 .39559 Mdot
.59169 .39941 Mdot
.48633 .20482 Mdot
.60334 .40639 Mdot
.62998 .54657 Mdot
.31596 .56266 Mdot
.3724 .40167 Mdot
.3385 .50601 Mdot
.55144 .38582 Mdot
.57356 .41902 Mdot
.39192 .75163 Mdot
.56365 .57234 Mdot
.5022 .82605 Mdot
.59822 .42452 Mdot
.44766 .68602 Mdot
.40325 .42057 Mdot
.56 .55615 Mdot
.58781 .25208 Mdot
.27511 .58422 Mdot
.55535 .58553 Mdot
.56255 .55469 Mdot
.55015 .32427 Mdot
.30142 .36304 Mdot
.34031 .4021 Mdot
.63667 .65222 Mdot
.30081 .45699 Mdot
.26716 .57941 Mdot
.25158 .50866 Mdot
.58105 .36696 Mdot
.33385 .57252 Mdot
.69436 .65696 Mdot
.59452 .41502 Mdot
.61744 .31508 Mdot
.48507 .24536 Mdot
.54566 .37927 Mdot
.61598 .34081 Mdot
.3024 .56597 Mdot
.71732 .6728 Mdot
.5438 .42963 Mdot
.42546 .68465 Mdot
.36936 .39715 Mdot
.30193 .35319 Mdot
.66824 .63676 Mdot
.35392 .53198 Mdot
.82447 .33181 Mdot
.37234 .40123 Mdot
.57917 .40634 Mdot
.29086 .5639 Mdot
.54702 .58174 Mdot
.55711 .56159 Mdot
.59421 .55586 Mdot
.3575 .38924 Mdot
.56229 .55643 Mdot
.44245 .37381 Mdot
.6872 .52635 Mdot
.5312 .31787 Mdot
.31671 .57659 Mdot
.65296 .65955 Mdot
.53893 .60961 Mdot
.37173 .63694 Mdot
.57047 .44498 Mdot
.63064 .54807 Mdot
.31868 .38665 Mdot
.65067 .65629 Mdot
.56313 .4082 Mdot
.59374 .57672 Mdot
.72752 .40173 Mdot
.68197 .69174 Mdot
.59092 .5735 Mdot
.63926 .29283 Mdot
.35021 .40762 Mdot
.55859 .58074 Mdot
.36239 .38276 Mdot
.56118 .40833 Mdot
.59561 .50005 Mdot
.35186 .41047 Mdot
.19635 .41731 Mdot
.59497 .5928 Mdot
.27475 .55563 Mdot
.5886 .348 Mdot
.55231 .39915 Mdot
.60089 .27153 Mdot
.54743 .57907 Mdot
.17766 .46613 Mdot
.42692 .67298 Mdot
.48456 .83072 Mdot
.43187 .62752 Mdot
.36663 .58964 Mdot
.2262 .54364 Mdot
.54651 .39706 Mdot
.4866 .22756 Mdot
.60167 .27647 Mdot
.32101 .54383 Mdot
.60433 .26942 Mdot
.56254 .39635 Mdot
.56342 .42737 Mdot
.42819 .67815 Mdot
.28219 .59746 Mdot
.63438 .27536 Mdot
.67619 .51434 Mdot
.66248 .62819 Mdot
.37252 .3649 Mdot
.56888 .39801 Mdot
.35008 .3423 Mdot
.44338 .65439 Mdot
.30753 .30992 Mdot
.57808 .37777 Mdot
.56399 .57267 Mdot
.33194 .574 Mdot
.29521 .59028 Mdot
.45281 .66838 Mdot
.45487 .66997 Mdot
.55255 .39875 Mdot
.319 .55265 Mdot
.56499 .44701 Mdot
.66227 .51094 Mdot
.57608 .56253 Mdot
.6691 .64591 Mdot
.60256 .37565 Mdot
.27644 .32531 Mdot
.77948 .65429 Mdot
.55569 .41597 Mdot
.33378 .39317 Mdot
.43297 .68831 Mdot
.41799 .71348 Mdot
.34727 .39958 Mdot
.41702 .71223 Mdot
.29137 .3161 Mdot
.61524 .23318 Mdot
.65741 .63829 Mdot
.6303 .33643 Mdot
.6443 .65811 Mdot
.55288 .58342 Mdot
.59144 .38634 Mdot
.23884 .62026 Mdot
.4631 .65135 Mdot
.67931 .38524 Mdot
.31087 .5591 Mdot
.55373 .55111 Mdot
.62242 .30206 Mdot
.62819 .61868 Mdot
.43663 .7097 Mdot
.56574 .59926 Mdot
.59106 .42827 Mdot
.33576 .4135 Mdot
.64056 .29682 Mdot
.56394 .55074 Mdot
.54976 .57704 Mdot
.56193 .59751 Mdot
.28247 .54825 Mdot
.37937 .3517 Mdot
.36157 .56938 Mdot
.41635 .66249 Mdot
.60874 .42143 Mdot
.57685 .40772 Mdot
.38441 .39477 Mdot
.60293 .38599 Mdot
.32439 .55715 Mdot
.43277 .1526 Mdot
.66031 .6716 Mdot
.54335 .57586 Mdot
.22779 .4248 Mdot
.55187 .59462 Mdot
.63666 .28727 Mdot
.60377 .30676 Mdot
.38167 .40622 Mdot
.28844 .54224 Mdot
.57801 .45121 Mdot
.41267 .65072 Mdot
.66843 .66164 Mdot
.3203 .58428 Mdot
.62601 .31282 Mdot
.57839 .37326 Mdot
.65241 .65724 Mdot
.3348 .50135 Mdot
.67337 .6349 Mdot
.27769 .56836 Mdot
.55206 .54698 Mdot
.691 .43653 Mdot
.58269 .38654 Mdot
.56451 .57795 Mdot
.37546 .35511 Mdot
.28434 .55569 Mdot
.48556 .25912 Mdot
.55877 .5549 Mdot
.35992 .67047 Mdot
.28727 .58953 Mdot
.55242 .42071 Mdot
.32207 .4037 Mdot
.31072 .33355 Mdot
.38488 .35701 Mdot
.65511 .77023 Mdot
.36636 .69773 Mdot
.43341 .68359 Mdot
.29903 .57108 Mdot
.4188 .68227 Mdot
.64572 .62326 Mdot
.71673 .49286 Mdot
.45631 .66877 Mdot
.35837 .34845 Mdot
.42202 .66939 Mdot
.56965 .44753 Mdot
.27413 .55511 Mdot
.4567 .65874 Mdot
.59605 .36717 Mdot
.6125 .29723 Mdot
.55122 .57395 Mdot
.66651 .68621 Mdot
.68068 .52135 Mdot
.59578 .38074 Mdot
.57017 .57755 Mdot
.58395 .37949 Mdot
.32386 .55681 Mdot
.63427 .52536 Mdot
.60993 .42463 Mdot
.46489 .65513 Mdot
.22581 .3656 Mdot
.42466 .64365 Mdot
.52985 .62414 Mdot
.59439 .41872 Mdot
.58533 .38573 Mdot
.62411 .3092 Mdot
.50711 .17131 Mdot
.33293 .55385 Mdot
.61621 .38942 Mdot
.42316 .72257 Mdot
.37162 .38555 Mdot
.33104 .40221 Mdot
.5216 .39498 Mdot
.5653 .58056 Mdot
.32817 .57029 Mdot
.58766 .38739 Mdot
.55089 .5548 Mdot
.70057 .50592 Mdot
.30031 .4629 Mdot
.37808 .72524 Mdot
.40853 .67873 Mdot
.35221 .41562 Mdot
.43103 .72042 Mdot
.62651 .30714 Mdot
.55642 .55843 Mdot
.36483 .69563 Mdot
.35196 .61257 Mdot
.66817 .65979 Mdot
.57441 .42878 Mdot
.74315 .58483 Mdot
.4368 .72263 Mdot
.45653 .68711 Mdot
.56735 .44767 Mdot
.37866 .43994 Mdot
.76328 .66782 Mdot
.29838 .54549 Mdot
.37324 .31875 Mdot
.53821 .23115 Mdot
.82036 .48542 Mdot
.29055 .57607 Mdot
.61747 .31786 Mdot
.45126 .71968 Mdot
.55518 .8031 Mdot
.37587 .38098 Mdot
.66949 .66158 Mdot
.59832 .36918 Mdot
.34875 .35778 Mdot
.46591 .65525 Mdot
.38164 .3486 Mdot
.56027 .56851 Mdot
.27799 .55063 Mdot
.43772 .71404 Mdot
.27045 .58958 Mdot
.42779 .39318 Mdot
.65487 .66592 Mdot
.69106 .59309 Mdot
.61638 .33351 Mdot
.48465 .24349 Mdot
.6191 .29583 Mdot
.52417 .5627 Mdot
.61574 .2943 Mdot
.30506 .34571 Mdot
.58419 .37475 Mdot
.55005 .44212 Mdot
.43674 .72951 Mdot
.55484 .41854 Mdot
.58605 .36619 Mdot
.58788 .2547 Mdot
.58176 .42602 Mdot
.556 .40484 Mdot
.54913 .41694 Mdot
.33737 .38799 Mdot
.5822 .43517 Mdot
.3945 .36851 Mdot
.3622 .33932 Mdot
.41533 .66433 Mdot
.63917 .62902 Mdot
.63736 .6366 Mdot
.60348 .50347 Mdot
.74195 .58538 Mdot
.48757 .20312 Mdot
.36898 .38381 Mdot
.28967 .58896 Mdot
.59373 .43711 Mdot
.7399 .68789 Mdot
.59683 .5002 Mdot
.45905 .70317 Mdot
.44332 .65163 Mdot
.59333 .36266 Mdot
.82652 .37015 Mdot
.5995 .42403 Mdot
.7037 .52027 Mdot
.57635 .39905 Mdot
.56011 .43174 Mdot
.41562 .64202 Mdot
.71619 .59742 Mdot
.61698 .28493 Mdot
.30372 .36731 Mdot
.66936 .6569 Mdot
.55835 .57836 Mdot
.59963 .5023 Mdot
.56041 .22617 Mdot
.31781 .42942 Mdot
.62406 .31009 Mdot
.45092 .70856 Mdot
.34923 .39024 Mdot
.69676 .52465 Mdot
.30975 .54581 Mdot
.71005 .55476 Mdot
.40568 .32268 Mdot
.30096 .54354 Mdot
.66623 .66149 Mdot
.46654 .69646 Mdot
.56482 .41703 Mdot
.44235 .66976 Mdot
.5501 .38975 Mdot
.71123 .51547 Mdot
.66295 .64083 Mdot
.35097 .3512 Mdot
.27191 .57597 Mdot
.33982 .37946 Mdot
.31256 .30959 Mdot
.59884 .50777 Mdot
.45011 .81316 Mdot
.43331 .64028 Mdot
.52591 .61736 Mdot
.38452 .38734 Mdot
.56854 .3648 Mdot
.45793 .16327 Mdot
.36267 .36465 Mdot
.33718 .41305 Mdot
.69141 .55305 Mdot
.72947 .60762 Mdot
.54812 .41045 Mdot
.35373 .35482 Mdot
.46751 .69378 Mdot
.65158 .636 Mdot
.58092 .36508 Mdot
.55026 .56217 Mdot
.33301 .40702 Mdot
.426 .71294 Mdot
.70864 .59585 Mdot
.44861 .69344 Mdot
.37343 .38957 Mdot
.43451 .64756 Mdot
.33321 .52803 Mdot
.45645 .66815 Mdot
.60403 .38112 Mdot
.58654 .38708 Mdot
.32078 .32573 Mdot
.35175 .38739 Mdot
.6365 .28709 Mdot
.60312 .39654 Mdot
.38899 .37364 Mdot
.4683 .70729 Mdot
.31644 .42409 Mdot
.63446 .29783 Mdot
.59149 .39425 Mdot
.64735 .66634 Mdot
.64573 .5106 Mdot
.67122 .54176 Mdot
.59476 .43532 Mdot
.6565 .66445 Mdot
.33847 .41507 Mdot
.59016 .382 Mdot
.72197 .60357 Mdot
.44079 .73149 Mdot
.5372 .41807 Mdot
.5465 .58302 Mdot
.62517 .28317 Mdot
.75907 .53952 Mdot
.62398 .31394 Mdot
.38253 .37382 Mdot
.37941 .38652 Mdot
.44885 .72829 Mdot
.37981 .36503 Mdot
.54483 .57746 Mdot
.32065 .57803 Mdot
.38839 .31148 Mdot
.54738 .55374 Mdot
.58271 .59203 Mdot
.59291 .59161 Mdot
.58607 .55846 Mdot
.6919 .70189 Mdot
.37419 .71304 Mdot
.57004 .59238 Mdot
.39261 .36646 Mdot
.51606 .5081 Mdot
.53676 .54981 Mdot
.32907 .56871 Mdot
.56338 .55505 Mdot
.53717 .41764 Mdot
.62162 .31234 Mdot
.39613 .38508 Mdot
.31266 .54576 Mdot
.56003 .53715 Mdot
.58235 .36469 Mdot
.39074 .39831 Mdot
.56696 .39749 Mdot
.68751 .6701 Mdot
.36034 .37858 Mdot
.44975 .70416 Mdot
.66772 .64326 Mdot
.58429 .56173 Mdot
.67692 .67044 Mdot
.43614 .67147 Mdot
.29969 .58633 Mdot
.59847 .37335 Mdot
.69073 .67563 Mdot
.64041 .62916 Mdot
.55615 .36797 Mdot
.37617 .3924 Mdot
.60107 .55835 Mdot
.5948 .388 Mdot
.62053 .30539 Mdot
.3455 .40004 Mdot
.1697 .47141 Mdot
.56638 .42043 Mdot
.6183 .27618 Mdot
.30663 .35352 Mdot
.55725 .55143 Mdot
.45205 .69873 Mdot
.55008 .40378 Mdot
.30913 .55446 Mdot
.31884 .56296 Mdot
.46081 .64898 Mdot
.33781 .40434 Mdot
.42549 .71605 Mdot
.57001 .36012 Mdot
.56775 .5545 Mdot
.56501 .37693 Mdot
.40135 .76601 Mdot
.18186 .43949 Mdot
.39719 .35982 Mdot
.4159 .66022 Mdot
.70098 .49847 Mdot
.30881 .53401 Mdot
.47434 .69679 Mdot
.30367 .36129 Mdot
.34715 .36272 Mdot
.34859 .40086 Mdot
.63915 .6377 Mdot
.4458 .70204 Mdot
.38065 .40192 Mdot
.38567 .39664 Mdot
.63005 .30572 Mdot
.59278 .36431 Mdot
.3462 .41538 Mdot
.37058 .63689 Mdot
.66442 .65437 Mdot
.41584 .71741 Mdot
.76764 .66632 Mdot
.29071 .54958 Mdot
.58903 .25176 Mdot
.57251 .44571 Mdot
.81851 .30757 Mdot
.60051 .42194 Mdot
.57469 .40284 Mdot
.40546 .35884 Mdot
.6442 .61954 Mdot
.64837 .64015 Mdot
.38376 .38746 Mdot
.3964 .3549 Mdot
.68057 .65303 Mdot
.65062 .47971 Mdot
.75641 .55885 Mdot
.69211 .50962 Mdot
.37603 .34924 Mdot
.40838 .32784 Mdot
.31115 .56848 Mdot
.33218 .37994 Mdot
.30993 .50677 Mdot
.44669 .6464 Mdot
.45677 .66592 Mdot
.27634 .58281 Mdot
.56679 .41707 Mdot
.41756 .63931 Mdot
.61953 .28653 Mdot
.28563 .5025 Mdot
.61453 .3237 Mdot
.59645 .83646 Mdot
.60276 .38215 Mdot
.46447 .59712 Mdot
.28388 .47628 Mdot
.6337 .28341 Mdot
.59912 .22189 Mdot
.67085 .66736 Mdot
.30101 .35299 Mdot
.3255 .5548 Mdot
.48545 .20558 Mdot
.58383 .3861 Mdot
.35878 .35102 Mdot
.27248 .56844 Mdot
.17736 .45624 Mdot
.61032 .29399 Mdot
.63042 .29522 Mdot
.4527 .16241 Mdot
.37066 .34064 Mdot
.45144 .69745 Mdot
.35737 .31646 Mdot
.40022 .36696 Mdot
.61005 .30846 Mdot
.47044 .68949 Mdot
.72383 .39889 Mdot
.3657 .34815 Mdot
.67199 .63279 Mdot
.3705 .36985 Mdot
.67907 .65354 Mdot
.3777 .40481 Mdot
.41542 .66811 Mdot
.57104 .42547 Mdot
.41401 .66841 Mdot
.6785 .67959 Mdot
.42484 .64672 Mdot
.32206 .55029 Mdot
.58106 .5732 Mdot
.31988 .57001 Mdot
.7194 .4869 Mdot
.48805 .27025 Mdot
.30256 .5822 Mdot
.54996 .34941 Mdot
.57841 .37211 Mdot
.37629 .40567 Mdot
.44655 .71074 Mdot
.42017 .72767 Mdot
.67791 .52011 Mdot
.36091 .40151 Mdot
.41729 .70618 Mdot
.61881 .35426 Mdot
.22408 .6009 Mdot
.61897 .27815 Mdot
.23991 .70337 Mdot
.38722 .36888 Mdot
.42221 .72754 Mdot
.70055 .52234 Mdot
.39241 .34204 Mdot
.45808 .66345 Mdot
.2792 .57962 Mdot
.3088 .55465 Mdot
.60698 .3933 Mdot
.26703 .59054 Mdot
.45762 .70412 Mdot
.42702 .34474 Mdot
.36315 .40867 Mdot
.18538 .43074 Mdot
.66132 .66976 Mdot
.43343 .71932 Mdot
.57184 .55995 Mdot
.4302 .38928 Mdot
.41917 .67705 Mdot
.82523 .33748 Mdot
.74268 .736 Mdot
.42056 .70952 Mdot
.36153 .37934 Mdot
.35598 .39226 Mdot
.62988 .31564 Mdot
.67456 .5159 Mdot
.43513 .70967 Mdot
.23419 .61908 Mdot
.7071 .45457 Mdot
.57968 .57613 Mdot
.42152 .79487 Mdot
.55193 .35998 Mdot
.62059 .29891 Mdot
.28594 .55574 Mdot
.57477 .41957 Mdot
.39211 .35169 Mdot
.59935 .42377 Mdot
.32422 .56341 Mdot
.45676 .64614 Mdot
.58466 .38293 Mdot
.66767 .66239 Mdot
.29259 .55517 Mdot
.30747 .55093 Mdot
.4295 .6515 Mdot
.33857 .40525 Mdot
.48248 .20891 Mdot
.44813 .69987 Mdot
.62088 .29137 Mdot
.57242 .57458 Mdot
.55021 .4176 Mdot
.33713 .36487 Mdot
.30273 .38567 Mdot
.43691 .72043 Mdot
.56146 .36519 Mdot
.29254 .57153 Mdot
.44004 .72849 Mdot
.62067 .31918 Mdot
.46299 .67747 Mdot
.60793 .59324 Mdot
.412 .64078 Mdot
.42508 .39911 Mdot
.60093 .57356 Mdot
.35735 .35039 Mdot
.57503 .5902 Mdot
.61714 .78514 Mdot
.66528 .6593 Mdot
.42033 .64067 Mdot
.19358 .42382 Mdot
.41298 .66701 Mdot
.58442 .42451 Mdot
.58695 .37105 Mdot
.43057 .67057 Mdot
.65309 .66456 Mdot
.53204 .59903 Mdot
.69059 .66739 Mdot
.35708 .3829 Mdot
.60643 .31568 Mdot
.70936 .76352 Mdot
.42119 .73406 Mdot
.26911 .57977 Mdot
.3267 .44144 Mdot
.58547 .58996 Mdot
.31835 .54717 Mdot
.30228 .55045 Mdot
.67629 .67655 Mdot
.40688 .68902 Mdot
.328 .39367 Mdot
.26391 .57747 Mdot
.39288 .34523 Mdot
.71841 .60454 Mdot
.57434 .55275 Mdot
.51336 .60032 Mdot
.59399 .57569 Mdot
.68578 .52379 Mdot
.2678 .55932 Mdot
.56977 .388 Mdot
.60283 .61864 Mdot
.27432 .57134 Mdot
.6608 .68141 Mdot
.61887 .31912 Mdot
.41566 .70289 Mdot
.46649 .18094 Mdot
.6056 .38376 Mdot
.59841 .40573 Mdot
.28025 .55842 Mdot
.58421 .2173 Mdot
.3016 .36645 Mdot
.34908 .40849 Mdot
.43651 .6835 Mdot
.68857 .55058 Mdot
.59046 .4302 Mdot
.58832 .36884 Mdot
.43194 .66529 Mdot
.56791 .58345 Mdot
.43464 .80526 Mdot
.5896 .39582 Mdot
.30441 .56856 Mdot
.61877 .31647 Mdot
.3256 .54687 Mdot
.58418 .44846 Mdot
.58376 .42291 Mdot
.62585 .28985 Mdot
.61438 .29983 Mdot
.31892 .57091 Mdot
.59145 .57019 Mdot
.55238 .5923 Mdot
.38172 .35434 Mdot
.59373 .36027 Mdot
.70587 .45345 Mdot
.58594 .39102 Mdot
.66972 .66745 Mdot
.67553 .54295 Mdot
.59067 .44183 Mdot
.6061 .37037 Mdot
.70944 .45486 Mdot
.56103 .40354 Mdot
.28073 .55671 Mdot
.35737 .39506 Mdot
.29065 .57053 Mdot
.26547 .57091 Mdot
.42119 .66848 Mdot
.65496 .67739 Mdot
.55189 .40415 Mdot
.66123 .62947 Mdot
.57566 .34635 Mdot
.55065 .53326 Mdot
.65957 .50796 Mdot
.70353 .51858 Mdot
.67659 .69066 Mdot
.58005 .37019 Mdot
.43535 .67658 Mdot
.40539 .69742 Mdot
.60957 .32348 Mdot
.58437 .35135 Mdot
.28204 .59536 Mdot
.29574 .58438 Mdot
.38389 .73902 Mdot
.49797 .68221 Mdot
.6886 .66777 Mdot
.57747 .61532 Mdot
.61337 .29777 Mdot
.57971 .42988 Mdot
.5882 .57488 Mdot
.42114 .68821 Mdot
.57363 .5917 Mdot
.37648 .71985 Mdot
.32467 .54979 Mdot
.28339 .56897 Mdot
.603 .38077 Mdot
.85938 .42056 Mdot
.35879 .3625 Mdot
.35527 .39315 Mdot
.32513 .57479 Mdot
.42431 .64349 Mdot
.55735 .56668 Mdot
.48066 .17621 Mdot
.30791 .39893 Mdot
.64296 .62319 Mdot
.5575 .38478 Mdot
.44355 .64464 Mdot
.39007 .35678 Mdot
.6888 .66524 Mdot
.6171 .4132 Mdot
.47139 .69242 Mdot
.57399 .3912 Mdot
.62609 .39703 Mdot
.3836 .39194 Mdot
.65219 .50849 Mdot
.35617 .34924 Mdot
.31606 .56443 Mdot
.26389 .56618 Mdot
.59005 .41958 Mdot
.47574 .18467 Mdot
.39156 .43004 Mdot
.26141 .57625 Mdot
.63734 .65223 Mdot
.58054 .56819 Mdot
.65791 .67932 Mdot
.42828 .68197 Mdot
.66623 .66026 Mdot
.41924 .67515 Mdot
.45843 .7236 Mdot
.32907 .39652 Mdot
.65225 .65678 Mdot
.56857 .2507 Mdot
.55505 .55948 Mdot
.63317 .63782 Mdot
.61397 .40595 Mdot
.63593 .29964 Mdot
.4294 .70833 Mdot
.65748 .62676 Mdot
.54928 .40625 Mdot
.22421 .42836 Mdot
.26991 .56066 Mdot
.32337 .55167 Mdot
.55922 .56843 Mdot
.4503 .71728 Mdot
.32751 .39716 Mdot
.70353 .49694 Mdot
.43858 .38058 Mdot
.59001 .36846 Mdot
.55315 .40646 Mdot
.43509 .38672 Mdot
.3276 .39838 Mdot
.58626 .42038 Mdot
.53014 .31172 Mdot
.57469 .55945 Mdot
.31535 .55678 Mdot
.35621 .3809 Mdot
.34995 .38186 Mdot
.459 .69076 Mdot
.33543 .4092 Mdot
.56285 .62199 Mdot
.32329 .54905 Mdot
.54515 .58774 Mdot
.29607 .57037 Mdot
.56126 .51256 Mdot
.41801 .7006 Mdot
.18749 .44264 Mdot
.34556 .40978 Mdot
.63341 .29716 Mdot
.33899 .4114 Mdot
.66532 .6733 Mdot
.35625 .3546 Mdot
.33361 .3745 Mdot
.59465 .36721 Mdot
.5901 .56936 Mdot
.55444 .58271 Mdot
.68188 .51913 Mdot
.36147 .36262 Mdot
.55891 .41466 Mdot
.58104 .43897 Mdot
.60264 .39208 Mdot
.66394 .50951 Mdot
.33683 .39386 Mdot
.56215 .22579 Mdot
.37172 .4106 Mdot
.38724 .38616 Mdot
.78985 .64269 Mdot
.54546 .57422 Mdot
.58244 .5884 Mdot
.2353 .57793 Mdot
.5918 .39813 Mdot
.4155 .70889 Mdot
.62205 .29357 Mdot
.58472 .56512 Mdot
.61416 .41767 Mdot
.65149 .63109 Mdot
.55397 .38184 Mdot
.57587 .5814 Mdot
.44575 .70914 Mdot
.63234 .29936 Mdot
.59081 .38859 Mdot
.5627 .58307 Mdot
.33216 .41105 Mdot
.34241 .38331 Mdot
.43132 .41248 Mdot
.68315 .66527 Mdot
.30767 .57699 Mdot
.62249 .29648 Mdot
.4357 .68083 Mdot
.41212 .70418 Mdot
.35492 .3509 Mdot
.44799 .66443 Mdot
.28239 .56704 Mdot
.58127 .40604 Mdot
.31817 .56719 Mdot
.66002 .63286 Mdot
.35971 .37782 Mdot
.62478 .30558 Mdot
.64294 .2921 Mdot
.37951 .38648 Mdot
.57319 .55774 Mdot
.64763 .66822 Mdot
.43816 .65838 Mdot
.39598 .37004 Mdot
.32181 .57108 Mdot
.45828 .68084 Mdot
.63224 .29394 Mdot
.83448 .57527 Mdot
.57528 .42008 Mdot
.60264 .41079 Mdot
.40678 .41342 Mdot
.55168 .44543 Mdot
.41688 .66161 Mdot
.32726 .40368 Mdot
.63535 .29776 Mdot
.72789 .46358 Mdot
.65118 .6829 Mdot
.40352 .70964 Mdot
.56534 .40348 Mdot
.60072 .27241 Mdot
.54425 .42153 Mdot
.19965 .41083 Mdot
.6593 .50925 Mdot
.36164 .67377 Mdot
.51672 .60805 Mdot
.2656 .58245 Mdot
.57095 .57903 Mdot
.42045 .66632 Mdot
.52643 .30259 Mdot
.58231 .41863 Mdot
.48193 .2536 Mdot
.62475 .31516 Mdot
.28712 .57426 Mdot
.58141 .22508 Mdot
.45234 .70686 Mdot
.47642 .82838 Mdot
.5829 .35907 Mdot
.30201 .37746 Mdot
.3803 .61325 Mdot
.58593 .57524 Mdot
.58878 .58355 Mdot
.68769 .66755 Mdot
.4757 .68291 Mdot
.57064 .54114 Mdot
.29293 .57003 Mdot
.57993 .43148 Mdot
.60905 .34295 Mdot
.17657 .47272 Mdot
.38961 .36241 Mdot
.26851 .57119 Mdot
.39833 .67235 Mdot
.56804 .38405 Mdot
.34503 .36731 Mdot
.37599 .38049 Mdot
.64883 .6284 Mdot
.36125 .65602 Mdot
.47635 .6913 Mdot
.83127 .38863 Mdot
.59312 .54734 Mdot
.42181 .68433 Mdot
.59837 .56947 Mdot
.62278 .2913 Mdot
.59634 .50044 Mdot
.26597 .57723 Mdot
.59093 .42199 Mdot
.48295 .2419 Mdot
.38464 .36266 Mdot
.58177 .39459 Mdot
.66489 .651 Mdot
.49274 .16664 Mdot
.61554 .33724 Mdot
.53364 .31349 Mdot
.46768 .69357 Mdot
.55403 .40884 Mdot
.57253 .62273 Mdot
.55022 .55483 Mdot
.5517 .44594 Mdot
.45041 .70027 Mdot
.60074 .57523 Mdot
.65972 .64615 Mdot
.38216 .35214 Mdot
.56915 .57763 Mdot
.6233 .31729 Mdot
.5495 .39534 Mdot
.63899 .65747 Mdot
.62727 .29319 Mdot
.36694 .30481 Mdot
.58878 .55411 Mdot
.45242 .65948 Mdot
.39764 .36859 Mdot
.55586 .41494 Mdot
.5814 .56767 Mdot
.56376 .3795 Mdot
.2771 .32445 Mdot
.58749 .42563 Mdot
.20308 .44968 Mdot
.36816 .39806 Mdot
.30115 .55857 Mdot
.6229 .30961 Mdot
.57658 .38902 Mdot
.59989 .56879 Mdot
.55489 .56652 Mdot
.57465 .36384 Mdot
.35691 .35011 Mdot
.3707 .35296 Mdot
.30465 .38723 Mdot
.46102 .68491 Mdot
.68513 .5088 Mdot
.30806 .56058 Mdot
.58821 .57616 Mdot
.26438 .57805 Mdot
.60253 .27937 Mdot
.68131 .66591 Mdot
.18317 .46701 Mdot
.58455 .40972 Mdot
.35621 .40205 Mdot
.75383 .56234 Mdot
.34449 .36323 Mdot
.23704 .57124 Mdot
.26729 .57943 Mdot
.36186 .36903 Mdot
.56641 .40636 Mdot
.69026 .52632 Mdot
.60408 .26531 Mdot
.29187 .5396 Mdot
.54645 .58712 Mdot
.59061 .53155 Mdot
.46365 .67035 Mdot
.78464 .65044 Mdot
.30294 .59055 Mdot
.28312 .47499 Mdot
.63454 .29756 Mdot
.35763 .4076 Mdot
.3157 .57685 Mdot
.31014 .54998 Mdot
.45096 .71178 Mdot
.63061 .30429 Mdot
.5779 .39052 Mdot
.54822 .58431 Mdot
.30046 .5881 Mdot
.55498 .37503 Mdot
.63344 .28142 Mdot
.4016 .76995 Mdot
.30031 .36508 Mdot
.16804 .46981 Mdot
.6018 .30603 Mdot
.48459 .24026 Mdot
.27632 .6275 Mdot
.37285 .40651 Mdot
.55751 .40773 Mdot
.56846 .56291 Mdot
.44488 .65829 Mdot
.57724 .41052 Mdot
.4145 .6617 Mdot
.29423 .57787 Mdot
.21414 .44004 Mdot
.60233 .30851 Mdot
.28132 .50408 Mdot
.57303 .42426 Mdot
.62091 .32799 Mdot
.65535 .65033 Mdot
.32786 .55735 Mdot
.30671 .38234 Mdot
.55165 .41602 Mdot
.4554 .68993 Mdot
.46072 .66421 Mdot
.38225 .35946 Mdot
.37509 .45195 Mdot
.18964 .43446 Mdot
.56671 .55879 Mdot
.44839 .67182 Mdot
.58059 .56538 Mdot
.53347 .31685 Mdot
.26373 .57823 Mdot
.6587 .64517 Mdot
.43658 .6489 Mdot
.32818 .57585 Mdot
.63633 .2985 Mdot
.37134 .36087 Mdot
.43599 .38002 Mdot
.60815 .30308 Mdot
.41696 .70647 Mdot
.67702 .65621 Mdot
.52864 .3894 Mdot
.60696 .31362 Mdot
.66908 .64676 Mdot
.45987 .69676 Mdot
.3493 .37021 Mdot
.37668 .38441 Mdot
.35941 .39516 Mdot
.58799 .25164 Mdot
.30357 .38915 Mdot
.66962 .58694 Mdot
.54628 .43848 Mdot
.43502 .34859 Mdot
.53924 .40949 Mdot
.32409 .55314 Mdot
.37733 .398 Mdot
.65847 .5087 Mdot
.61781 .28173 Mdot
.61003 .25815 Mdot
.5995 .38823 Mdot
.61208 .30805 Mdot
.59212 .39744 Mdot
.43702 .35379 Mdot
.29873 .36951 Mdot
.60195 .36271 Mdot
.31172 .53884 Mdot
.6733 .67071 Mdot
.39963 .35359 Mdot
.55453 .3983 Mdot
.42107 .34507 Mdot
.61346 .40908 Mdot
.2113 .44079 Mdot
.61207 .31446 Mdot
.40673 .62488 Mdot
.56869 .43333 Mdot
.43139 .63741 Mdot
.63867 .30597 Mdot
.39423 .31507 Mdot
.2749 .55464 Mdot
.61684 .33644 Mdot
.42703 .633 Mdot
.5794 .22586 Mdot
.56082 .56019 Mdot
.66171 .65286 Mdot
.59733 .58431 Mdot
.32233 .56568 Mdot
.5848 .41384 Mdot
.55387 .38475 Mdot
.56786 .45428 Mdot
.53341 .31799 Mdot
.54637 .56853 Mdot
.67896 .69111 Mdot
.40695 .32541 Mdot
.56622 .37024 Mdot
.41119 .6463 Mdot
.34232 .39658 Mdot
.57085 .24113 Mdot
.55517 .25163 Mdot
.63705 .2813 Mdot
.36412 .36395 Mdot
.33772 .40456 Mdot
.75063 .67983 Mdot
.65854 .66013 Mdot
.59877 .40955 Mdot
.69379 .66125 Mdot
.62404 .29929 Mdot
.3034 .57416 Mdot
.55728 .44774 Mdot
.41791 .7017 Mdot
.69692 .52875 Mdot
.46123 .69217 Mdot
.60195 .38887 Mdot
.37044 .37189 Mdot
.29716 .53795 Mdot
.45325 .72974 Mdot
.36184 .6486 Mdot
.67972 .59136 Mdot
.47551 .69583 Mdot
.68627 .66034 Mdot
.67344 .6765 Mdot
.32738 .55676 Mdot
.57211 .40474 Mdot
.667 .5119 Mdot
.64438 .25684 Mdot
.59094 .40378 Mdot
.56794 .4158 Mdot
.26159 .60678 Mdot
.28131 .58711 Mdot
.43423 .64634 Mdot
.58583 .41964 Mdot
.55419 .37998 Mdot
.36625 .3721 Mdot
.66459 .62929 Mdot
.42833 .66142 Mdot
.6862 .67121 Mdot
.44426 .67841 Mdot
.75973 .53982 Mdot
.57199 .55316 Mdot
.67969 .67084 Mdot
.29873 .59146 Mdot
.35196 .39968 Mdot
.54484 .57453 Mdot
.43034 .69329 Mdot
.44929 .66983 Mdot
.57529 .34686 Mdot
.38797 .35546 Mdot
.349 .4087 Mdot
.68399 .66074 Mdot
.29988 .58375 Mdot
.61816 .28645 Mdot
.59342 .57696 Mdot
.40376 .73047 Mdot
.45436 .67953 Mdot
.41094 .32848 Mdot
.41734 .40415 Mdot
.56248 .3847 Mdot
.34302 .38128 Mdot
.57994 .38214 Mdot
.40151 .33938 Mdot
.37946 .33892 Mdot
.58974 .44499 Mdot
.47106 .36225 Mdot
.42003 .68682 Mdot
.67162 .79268 Mdot
.61947 .27708 Mdot
.33959 .5561 Mdot
.62333 .29404 Mdot
.44899 .81428 Mdot
.75308 .56581 Mdot
.5716 .3687 Mdot
.55358 .40341 Mdot
.85843 .44506 Mdot
.55725 .43445 Mdot
.57498 .58876 Mdot
.55928 .56016 Mdot
.34374 .37608 Mdot
.59455 .58797 Mdot
.68282 .52187 Mdot
.64939 .65858 Mdot
.43572 .68367 Mdot
.7238 .60219 Mdot
.68037 .65705 Mdot
.38427 .37046 Mdot
.61965 .28421 Mdot
.41209 .41516 Mdot
.40992 .65413 Mdot
.562 .57716 Mdot
.29121 .57663 Mdot
.67192 .51849 Mdot
.45514 .69951 Mdot
.31773 .58279 Mdot
.56983 .44105 Mdot
.38114 .72872 Mdot
.31696 .54111 Mdot
.68776 .77751 Mdot
.29964 .54723 Mdot
.32175 .57749 Mdot
.67635 .51207 Mdot
.64907 .65838 Mdot
.6005 .56506 Mdot
.53978 .53886 Mdot
.28797 .54491 Mdot
.52091 .83425 Mdot
.44969 .71644 Mdot
.71248 .51232 Mdot
.30023 .35434 Mdot
.55942 .55569 Mdot
.56962 .4221 Mdot
.28693 .55398 Mdot
.58747 .34939 Mdot
.60069 .57139 Mdot
.28921 .56012 Mdot
.63937 .30426 Mdot
.6884 .54869 Mdot
.57684 .56617 Mdot
.55326 .58329 Mdot
.67512 .63933 Mdot
.41746 .62412 Mdot
.34537 .40655 Mdot
.63783 .62992 Mdot
.70636 .48114 Mdot
.60239 .39984 Mdot
.31846 .57161 Mdot
.56813 .57754 Mdot
.31011 .55821 Mdot
.65094 .64445 Mdot
.63785 .65629 Mdot
.38433 .35549 Mdot
.30336 .38188 Mdot
.54222 .5563 Mdot
.70689 .4446 Mdot
.54419 .42859 Mdot
.48337 .2626 Mdot
.33323 .39381 Mdot
.60527 .22605 Mdot
.64153 .64824 Mdot
.65788 .62567 Mdot
.62582 .32319 Mdot
.59963 .43031 Mdot
.61409 .31063 Mdot
.59701 .43664 Mdot
.5063 .81848 Mdot
.6255 .3076 Mdot
.43999 .65998 Mdot
.60954 .42609 Mdot
.29585 .4557 Mdot
.61329 .33005 Mdot
.55566 .39187 Mdot
.44363 .69532 Mdot
.54165 .38489 Mdot
.42457 .70788 Mdot
.5635 .42328 Mdot
.41003 .77762 Mdot
.43603 .6811 Mdot
.54419 .60216 Mdot
.53737 .45773 Mdot
.569 .58916 Mdot
.64292 .63926 Mdot
.68966 .67764 Mdot
.7064 .59591 Mdot
.35241 .36955 Mdot
.51338 .17365 Mdot
.55675 .39092 Mdot
.4529 .71138 Mdot
.29324 .57914 Mdot
.64223 .28987 Mdot
.60496 .40417 Mdot
.61255 .29485 Mdot
.36811 .35785 Mdot
.45253 .71678 Mdot
.64743 .64778 Mdot
.40771 .676 Mdot
.40804 .77939 Mdot
.41885 .69895 Mdot
.54866 .32338 Mdot
.63434 .30655 Mdot
.56898 .62241 Mdot
.49182 .29259 Mdot
.63307 .6159 Mdot
.37709 .35805 Mdot
.57267 .57756 Mdot
.66712 .68017 Mdot
.64249 .52803 Mdot
.34451 .40214 Mdot
.43248 .66549 Mdot
.57351 .39081 Mdot
.58901 .56004 Mdot
.54069 .53807 Mdot
.3914 .34869 Mdot
.64377 .66786 Mdot
.43534 .69255 Mdot
.57702 .5714 Mdot
.69122 .50784 Mdot
.53938 .23016 Mdot
.71965 .49274 Mdot
.57675 .38608 Mdot
.68112 .6544 Mdot
.38824 .35529 Mdot
.61081 .29753 Mdot
.27568 .56985 Mdot
.67642 .51748 Mdot
.5727 .42199 Mdot
.25873 .51741 Mdot
.37189 .37103 Mdot
.65786 .66695 Mdot
.29159 .55067 Mdot
.66056 .66113 Mdot
.5818 .58798 Mdot
.40482 .36962 Mdot
.58868 .58342 Mdot
.62325 .31568 Mdot
.29961 .57834 Mdot
.3475 .40708 Mdot
.4077 .77784 Mdot
.60177 .56142 Mdot
.43017 .67234 Mdot
.64495 .52792 Mdot
.37486 .35198 Mdot
.36016 .56065 Mdot
.40813 .67424 Mdot
.34407 .61396 Mdot
.64303 .51032 Mdot
.2853 .56091 Mdot
.55505 .39408 Mdot
.36372 .38869 Mdot
.2944 .53813 Mdot
.37448 .63385 Mdot
.59896 .26531 Mdot
.57007 .54597 Mdot
.58174 .37107 Mdot
.20399 .39959 Mdot
.29394 .46903 Mdot
.31199 .33112 Mdot
.31949 .58473 Mdot
.59732 .40212 Mdot
.56797 .55791 Mdot
.59229 .35892 Mdot
.28206 .54946 Mdot
.27636 .54463 Mdot
.41222 .71227 Mdot
.56997 .38985 Mdot
.6667 .66632 Mdot
.41351 .68572 Mdot
.46679 .67167 Mdot
.44025 .64813 Mdot
.30572 .38095 Mdot
.56159 .55285 Mdot
.56174 .55845 Mdot
.75071 .57265 Mdot
.31105 .55702 Mdot
.5697 .589 Mdot
.55297 .38488 Mdot
.67073 .58671 Mdot
.36194 .39788 Mdot
.43634 .69813 Mdot
.59872 .40309 Mdot
.61478 .27987 Mdot
.55824 .57956 Mdot
.44689 .70027 Mdot
.32871 .39795 Mdot
.52722 .51256 Mdot
.57942 .41039 Mdot
.6282 .30915 Mdot
.38515 .3772 Mdot
.26585 .33218 Mdot
.69976 .50833 Mdot
.5812 .38301 Mdot
.31914 .56244 Mdot
.2542 .35234 Mdot
.56567 .43877 Mdot
.43779 .40907 Mdot
.54589 .58386 Mdot
.50863 .49243 Mdot
.36964 .31249 Mdot
.6169 .43078 Mdot
.43343 .54528 Mdot
.68164 .38593 Mdot
.45617 .56664 Mdot
.54203 .81449 Mdot
.39536 .54378 Mdot
.7063 .76201 Mdot
.29304 .59866 Mdot
.62527 .41196 Mdot
.81591 .33649 Mdot
.2918 .48078 Mdot
.3852 .56774 Mdot
.34492 .54499 Mdot
.63205 .59936 Mdot
.42918 .80038 Mdot
.38137 .73067 Mdot
.545 .81075 Mdot
.55708 .35593 Mdot
.28188 .40933 Mdot
.6228 .35211 Mdot
.35119 .53459 Mdot
.36331 .66922 Mdot
.60775 .32717 Mdot
.84459 .46262 Mdot
.23735 .55803 Mdot
.80708 .57285 Mdot
.49826 .20467 Mdot
.39197 .7294 Mdot
.69448 .43591 Mdot
.72851 .63761 Mdot
.6469 .30323 Mdot
.4809 .5272 Mdot
.27727 .59693 Mdot
.34604 .4244 Mdot
.22941 .60858 Mdot
.43951 .66585 Mdot
.38262 .34638 Mdot
.2236 .56008 Mdot
.84117 .52369 Mdot
.33251 .59682 Mdot
.43236 .54658 Mdot
.58855 .55016 Mdot
.51364 .48327 Mdot
.65611 .50465 Mdot
.38937 .32704 Mdot
.4048 .75917 Mdot
.4342 .7973 Mdot
.40302 .41064 Mdot
.38132 .63814 Mdot
.63192 .52601 Mdot
.38155 .56655 Mdot
.34579 .31058 Mdot
.62559 .61035 Mdot
.55105 .60433 Mdot
.33275 .39333 Mdot
.81539 .42035 Mdot
.52582 .36241 Mdot
.71073 .47501 Mdot
.36941 .67392 Mdot
.34391 .43084 Mdot
.48145 .20405 Mdot
.36913 .45307 Mdot
.6215 .82359 Mdot
.83163 .56882 Mdot
.58674 .8119 Mdot
.53648 .4631 Mdot
.30693 .60697 Mdot
.60478 .51331 Mdot
.4734 .60319 Mdot
.61263 .80602 Mdot
.27607 .3284 Mdot
.82808 .40891 Mdot
.47456 .44559 Mdot
.85133 .53728 Mdot
.41371 .3825 Mdot
.61244 .61075 Mdot
.32673 .32031 Mdot
.55329 .49836 Mdot
.73128 .55418 Mdot
.85323 .50631 Mdot
.36461 .54403 Mdot
.6083 .57176 Mdot
.29515 .48188 Mdot
.36429 .30738 Mdot
.40025 .75978 Mdot
.58778 .59883 Mdot
.51467 .27889 Mdot
.85785 .48151 Mdot
.44217 .53585 Mdot
.82682 .48238 Mdot
.41524 .76695 Mdot
.22052 .66455 Mdot
.46831 .67128 Mdot
.25862 .5797 Mdot
.81836 .56829 Mdot
.36839 .38639 Mdot
.64739 .81512 Mdot
.40289 .56738 Mdot
.4247 .60643 Mdot
.85473 .47308 Mdot
.59629 .83129 Mdot
.55191 .49119 Mdot
.57173 .61352 Mdot
.23137 .60493 Mdot
.47616 .56641 Mdot
.32768 .49468 Mdot
.55039 .51651 Mdot
.20704 .42505 Mdot
.82245 .55299 Mdot
.57746 .82996 Mdot
.8205 .37495 Mdot
.70316 .47634 Mdot
.68343 .61472 Mdot
.39806 .41907 Mdot
.40691 .48544 Mdot
.33277 .5028 Mdot
.84722 .54918 Mdot
.61782 .34588 Mdot
.24206 .35943 Mdot
.5584 .81128 Mdot
.56124 .2421 Mdot
.23851 .41033 Mdot
.2722 .50255 Mdot
.53399 .51742 Mdot
.41005 .33909 Mdot
.66897 .69782 Mdot
.72819 .56871 Mdot
.50643 .26468 Mdot
.39413 .62852 Mdot
.6955 .51554 Mdot
.39283 .44946 Mdot
.68412 .74845 Mdot
.25916 .39758 Mdot
.51395 .27264 Mdot
.43404 .38146 Mdot
.61418 .80394 Mdot
.5624 .81548 Mdot
.23921 .383 Mdot
.39492 .69245 Mdot
.82856 .49255 Mdot
.35153 .47474 Mdot
.5261 .47948 Mdot
.62321 .36259 Mdot
.63817 .31479 Mdot
.45637 .79564 Mdot
.51524 .34894 Mdot
.74967 .66935 Mdot
.30384 .49955 Mdot
.49021 .30512 Mdot
.7429 .64417 Mdot
.49577 .29827 Mdot
.38623 .31145 Mdot
.43403 .42433 Mdot
.23954 .55599 Mdot
.47385 .37407 Mdot
.84774 .46324 Mdot
.42256 .65793 Mdot
.60961 .81002 Mdot
.32821 .59687 Mdot
.38091 .72209 Mdot
.4067 .60683 Mdot
.3986 .60824 Mdot
.79781 .59899 Mdot
.27398 .49524 Mdot
.62336 .59391 Mdot
.33616 .32012 Mdot
.42461 .58218 Mdot
.48914 .26151 Mdot
.58563 .32555 Mdot
.30286 .41988 Mdot
.64671 .66764 Mdot
.51457 .30763 Mdot
.40923 .33671 Mdot
.39694 .67406 Mdot
.56286 .3197 Mdot
.71159 .40942 Mdot
.53846 .5682 Mdot
.67841 .57177 Mdot
.75887 .5451 Mdot
.49876 .44984 Mdot
.61128 .81898 Mdot
.33322 .46542 Mdot
.68431 .57494 Mdot
.33333 .50516 Mdot
.51952 .17601 Mdot
.85312 .53488 Mdot
.77963 .64795 Mdot
.26735 .34873 Mdot
.22711 .40257 Mdot
.26617 .73889 Mdot
.3622 .57532 Mdot
.70548 .74711 Mdot
.32784 .5972 Mdot
.43116 .15475 Mdot
.41978 .65664 Mdot
.60142 .52035 Mdot
.40355 .38332 Mdot
.70608 .41028 Mdot
.8457 .49078 Mdot
.50343 .46701 Mdot
.63366 .63457 Mdot
.31708 .32218 Mdot
.47267 .36417 Mdot
.83725 .45688 Mdot
.82451 .42145 Mdot
.82317 .43087 Mdot
.22731 .55058 Mdot
.51334 .33353 Mdot
.85283 .45183 Mdot
.63749 .5645 Mdot
.48916 .39753 Mdot
.61173 .34847 Mdot
.72329 .45117 Mdot
.68476 .76812 Mdot
.66062 .60837 Mdot
.47991 .56398 Mdot
.40459 .40969 Mdot
.86221 .47602 Mdot
.76145 .55995 Mdot
.52335 .4944 Mdot
.7941 .58406 Mdot
.70259 .68759 Mdot
.75001 .63569 Mdot
.79006 .61183 Mdot
.46023 .53071 Mdot
.28058 .49888 Mdot
.86856 .47674 Mdot
.59964 .79718 Mdot
.35443 .5617 Mdot
.41533 .34089 Mdot
.67528 .78192 Mdot
.2319 .41231 Mdot
.29076 .61794 Mdot
.40953 .38595 Mdot
.53595 .18954 Mdot
.36798 .51926 Mdot
.48534 .52837 Mdot
.56708 .45895 Mdot
.73982 .65925 Mdot
.42417 .64861 Mdot
.65083 .78148 Mdot
.35315 .49956 Mdot
.48313 .39878 Mdot
.7036 .58003 Mdot
.55435 .83323 Mdot
.47902 .4879 Mdot
.55293 .29729 Mdot
.33478 .46566 Mdot
.25854 .38109 Mdot
.2451 .40387 Mdot
.51447 .21735 Mdot
.54199 .40359 Mdot
.84481 .51846 Mdot
.72796 .74326 Mdot
.79385 .61379 Mdot
.24706 .38504 Mdot
.24609 .703 Mdot
.31382 .59327 Mdot
.64692 .57015 Mdot
.71316 .38838 Mdot
.44727 .50384 Mdot
.69016 .37416 Mdot
.3131 .53191 Mdot
.48089 .20391 Mdot
.40651 .60206 Mdot
.63784 .56361 Mdot
.28502 .37521 Mdot
.43107 .59746 Mdot
.54369 .30588 Mdot
.43118 .37264 Mdot
.22426 .3724 Mdot
.61789 .80165 Mdot
.42545 .65525 Mdot
.39961 .71173 Mdot
.50286 .36863 Mdot
.59772 .6189 Mdot
.60974 .55346 Mdot
.53035 .47785 Mdot
.48893 .2349 Mdot
.2626 .72118 Mdot
.76905 .6373 Mdot
.66985 .79275 Mdot
.78913 .61513 Mdot
.57729 .81592 Mdot
.37333 .65364 Mdot
.6902 .56595 Mdot
.33965 .60398 Mdot
.30484 .60321 Mdot
.67996 .55629 Mdot
.55782 .82578 Mdot
.52674 .48845 Mdot
.32659 .32418 Mdot
.54518 .39738 Mdot
.75328 .55771 Mdot
.72088 .63459 Mdot
.66366 .56161 Mdot
.52555 .22466 Mdot
.3248 .39177 Mdot
.65787 .59334 Mdot
.50484 .52062 Mdot
.64209 .27294 Mdot
.22771 .39772 Mdot
.29537 .53706 Mdot
.42427 .3588 Mdot
.55387 .8345 Mdot
.26734 .73396 Mdot
.44814 .58263 Mdot
.54542 .35035 Mdot
.82274 .54357 Mdot
.52735 .44378 Mdot
.21995 .41417 Mdot
.54908 .19368 Mdot
.36747 .6133 Mdot
.40739 .40334 Mdot
.49194 .42299 Mdot
.41627 .61202 Mdot
.27446 .37937 Mdot
.42459 .36799 Mdot
.64327 .30238 Mdot
.82203 .57755 Mdot
.53396 .42407 Mdot
.47107 .53777 Mdot
.70505 .49788 Mdot
.38962 .4949 Mdot
.41133 .57233 Mdot
.70958 .58782 Mdot
.44689 .56086 Mdot
.81666 .43425 Mdot
.47503 .2111 Mdot
.48853 .56078 Mdot
.63626 .57523 Mdot
.63585 .55868 Mdot
.49776 .20528 Mdot
.34306 .30721 Mdot
.30961 .50153 Mdot
.53209 .39355 Mdot
.81935 .59181 Mdot
.46348 .44157 Mdot
.69549 .57718 Mdot
.3755 .4635 Mdot
.53596 .39136 Mdot
.61266 .582 Mdot
.79248 .60654 Mdot
.50852 .49667 Mdot
.81456 .32256 Mdot
.53188 .82167 Mdot
.31794 .43638 Mdot
.37288 .31714 Mdot
.627 .80475 Mdot
.30923 .45008 Mdot
.4046 .54967 Mdot
.35593 .49155 Mdot
.66268 .78668 Mdot
.49994 .48916 Mdot
.51015 .50534 Mdot
.21684 .38691 Mdot
.84556 .43987 Mdot
.47315 .55681 Mdot
.28168 .6151 Mdot
.68245 .61925 Mdot
.59943 .41879 Mdot
.3596 .4572 Mdot
.18064 .45241 Mdot
.40869 .45875 Mdot
.46223 .57361 Mdot
.72121 .75452 Mdot
.50924 .46607 Mdot
.33118 .46769 Mdot
.8171 .32597 Mdot
.81853 .31584 Mdot
.35086 .45525 Mdot
.84325 .55852 Mdot
.51442 .5019 Mdot
.22183 .41715 Mdot
.27569 .59787 Mdot
.58602 .33667 Mdot
.48291 .25669 Mdot
.80513 .61408 Mdot
.23811 .7074 Mdot
.32647 .49791 Mdot
.39246 .40272 Mdot
.80458 .62142 Mdot
.47739 .41162 Mdot
.62244 .55894 Mdot
.22234 .665 Mdot
.48475 .82896 Mdot
.62318 .81955 Mdot
.52972 .21432 Mdot
.45372 .80119 Mdot
.5073 .80275 Mdot
.35873 .53013 Mdot
.68028 .78108 Mdot
.58184 .53915 Mdot
.52931 .17762 Mdot
.61187 .805 Mdot
.21184 .40382 Mdot
.42009 .78429 Mdot
.41418 .56972 Mdot
.52012 .47058 Mdot
.44398 .41922 Mdot
.207 .42982 Mdot
.25479 .5129 Mdot
.50385 .41797 Mdot
.65689 .53487 Mdot
.38778 .31393 Mdot
.25246 .34508 Mdot
.56523 .19271 Mdot
.53969 .47922 Mdot
.80901 .39127 Mdot
.26312 .51821 Mdot
.64358 .54298 Mdot
.35432 .31743 Mdot
.71429 .60768 Mdot
.62497 .58673 Mdot
.61158 .41983 Mdot
.824 .57222 Mdot
.62336 .58757 Mdot
.81454 .4048 Mdot
.64365 .82032 Mdot
.79677 .57351 Mdot
.4657 .61003 Mdot
.58318 .52275 Mdot
.68489 .7645 Mdot
.69415 .7536 Mdot
.81447 .38585 Mdot
.54984 .80623 Mdot
.67703 .55346 Mdot
.50749 .43753 Mdot
.58984 .32946 Mdot
.54059 .3172 Mdot
.63188 .80178 Mdot
.49408 .20132 Mdot
.74299 .63644 Mdot
.26873 .35804 Mdot
.55742 .82896 Mdot
.56311 .48668 Mdot
.70921 .60197 Mdot
.39121 .4683 Mdot
.57551 .611 Mdot
.44213 .72423 Mdot
.85303 .41716 Mdot
.23592 .38822 Mdot
.75958 .63386 Mdot
.23983 .36527 Mdot
.4398 .36442 Mdot
.52048 .8134 Mdot
.32133 .31788 Mdot
.5105 .61248 Mdot
.37858 .69112 Mdot
.71563 .69831 Mdot
.53974 .49098 Mdot
.1994 .40966 Mdot
.54352 .2492 Mdot
.80214 .59837 Mdot
.7441 .64552 Mdot
.81469 .36121 Mdot
.66113 .59848 Mdot
.51338 .30699 Mdot
.81153 .41481 Mdot
.26266 .36362 Mdot
.65293 .55612 Mdot
.84003 .45166 Mdot
.29695 .35641 Mdot
.83346 .56482 Mdot
.27824 .57504 Mdot
.63015 .57657 Mdot
.19291 .43434 Mdot
.64896 .56207 Mdot
.64519 .55791 Mdot
.76346 .64757 Mdot
.29899 .4807 Mdot
.32363 .46506 Mdot
.3492 .47557 Mdot
.38808 .73934 Mdot
.57918 .33727 Mdot
.45916 .54192 Mdot
.82227 .37852 Mdot
.54388 .40741 Mdot
.59203 .78726 Mdot
.60989 .8141 Mdot
.33662 .60635 Mdot
.522 .46411 Mdot
.19917 .42094 Mdot
.5455 .20939 Mdot
.74209 .57358 Mdot
.84624 .44632 Mdot
.5214 .46263 Mdot
.70626 .39497 Mdot
.59243 .21556 Mdot
.23696 .60007 Mdot
.31736 .50049 Mdot
.4387 .54765 Mdot
.51752 .42569 Mdot
.69823 .50639 Mdot
.5844 .81045 Mdot
.71352 .7594 Mdot
.80944 .38708 Mdot
.32012 .50404 Mdot
.65796 .56415 Mdot
.43198 .41719 Mdot
.72214 .66402 Mdot
.82211 .36896 Mdot
.43799 .80679 Mdot
.41053 .33858 Mdot
.56714 .82626 Mdot
.29961 .48622 Mdot
.62397 .5599 Mdot
.67026 .55975 Mdot
.8166 .42529 Mdot
.36352 .41652 Mdot
.48449 .44142 Mdot
.40035 .45028 Mdot
.67776 .52555 Mdot
.39625 .57927 Mdot
.52812 .19108 Mdot
.26371 .4993 Mdot
.81389 .36001 Mdot
.49074 .80429 Mdot
.57267 .23363 Mdot
.8152 .34324 Mdot
.32479 .39667 Mdot
.39325 .57952 Mdot
.21555 .64599 Mdot
.67715 .57452 Mdot
.45866 .65468 Mdot
.55204 .37985 Mdot
.67022 .54558 Mdot
.29871 .43039 Mdot
.6628 .60395 Mdot
.64164 .6688 Mdot
.41897 .35374 Mdot
.52037 .80786 Mdot
.42933 .36664 Mdot
.71476 .75514 Mdot
.4592 .52625 Mdot
.38936 .31961 Mdot
.57276 .20195 Mdot
.37564 .65098 Mdot
.2598 .37447 Mdot
.80425 .57511 Mdot
.72117 .45579 Mdot
.41036 .35305 Mdot
.41336 .36097 Mdot
.29054 .37458 Mdot
.35527 .5993 Mdot
.83087 .5311 Mdot
.59847 .82796 Mdot
.40265 .72733 Mdot
.29464 .37455 Mdot
.53869 .46105 Mdot
.52494 .47619 Mdot
.77206 .61428 Mdot
.4078 .68259 Mdot
.8611 .52163 Mdot
.50274 .177 Mdot
.27833 .40836 Mdot
.45468 .49328 Mdot
.72086 .40122 Mdot
.62398 .52907 Mdot
.38488 .63772 Mdot
.54344 .48563 Mdot
.32705 .45035 Mdot
.32342 .41217 Mdot
.39926 .59399 Mdot
.64023 .6505 Mdot
.39373 .6873 Mdot
.3493 .57301 Mdot
.50999 .21445 Mdot
.62413 .81111 Mdot
.43193 .39387 Mdot
.61393 .55749 Mdot
.39654 .64135 Mdot
.54183 .32426 Mdot
.72238 .42832 Mdot
.86319 .44192 Mdot
.81131 .5565 Mdot
.36344 .34536 Mdot
.2624 .39531 Mdot
.41514 .77296 Mdot
.76828 .63605 Mdot
.48802 .45694 Mdot
.62847 .79993 Mdot
.51546 .28657 Mdot
.78338 .60897 Mdot
.36922 .31363 Mdot
.43625 .52914 Mdot
.59039 .82057 Mdot
.69686 .69654 Mdot
.56455 .83154 Mdot
.55021 .217 Mdot
.52097 .3811 Mdot
.50104 .82995 Mdot
.40418 .45522 Mdot
.53175 .49801 Mdot
.64032 .26837 Mdot
.44575 .50872 Mdot
.66644 .78117 Mdot
.32208 .40278 Mdot
.63754 .60212 Mdot
.28032 .33592 Mdot
.32506 .49734 Mdot
.82026 .55496 Mdot
.24934 .39302 Mdot
.59195 .82844 Mdot
.57426 .33671 Mdot
.70929 .69102 Mdot
.49283 .2102 Mdot
.71178 .46617 Mdot
.5956 .57717 Mdot
.50645 .27633 Mdot
.60463 .57863 Mdot
.75419 .57157 Mdot
.54964 .3125 Mdot
.84947 .49964 Mdot
.75625 .54951 Mdot
.44478 .4199 Mdot
.6029 .6116 Mdot
.37028 .41049 Mdot
.85972 .50403 Mdot
.74166 .56765 Mdot
.20276 .43028 Mdot
.62343 .8183 Mdot
.55214 .80222 Mdot
.8151 .33885 Mdot
.29817 .48327 Mdot
.47577 .38825 Mdot
.68539 .77756 Mdot
.46957 .43668 Mdot
.51112 .80254 Mdot
.53957 .49078 Mdot
.40296 .41849 Mdot
.8504 .46466 Mdot
.61735 .6031 Mdot
.43172 .43063 Mdot
.60476 .2694 Mdot
.40414 .40483 Mdot
.73796 .55782 Mdot
.55229 .47622 Mdot
.43361 .66266 Mdot
.71312 .40137 Mdot
.45073 .79416 Mdot
.2925 .38391 Mdot
.62011 .80957 Mdot
.63716 .79307 Mdot
.69251 .6296 Mdot
.46483 .61533 Mdot
.81304 .33719 Mdot
.50245 .33559 Mdot
.61309 .43346 Mdot
.42792 .36908 Mdot
.64494 .67322 Mdot
.57389 .80391 Mdot
.5387 .38146 Mdot
.70474 .42879 Mdot
.51494 .28147 Mdot
.81122 .60079 Mdot
.40132 .47921 Mdot
.25173 .53364 Mdot
.29499 .36224 Mdot
.20535 .42781 Mdot
.27098 .3393 Mdot
.28677 .4784 Mdot
.6667 .77915 Mdot
.44847 .58191 Mdot
.43381 .54054 Mdot
.45518 .40387 Mdot
.65046 .77642 Mdot
.33772 .51678 Mdot
.32291 .54014 Mdot
.48815 .24031 Mdot
.81052 .37496 Mdot
.41737 .34426 Mdot
.42037 .56965 Mdot
.48361 .512 Mdot
.51988 .41297 Mdot
.32944 .49663 Mdot
.31905 .47063 Mdot
.42274 .3803 Mdot
.8267 .4579 Mdot
.48551 .54152 Mdot
.58779 .52798 Mdot
.54921 .82077 Mdot
.47168 .51752 Mdot
.63864 .79502 Mdot
.47059 .36191 Mdot
.82535 .43832 Mdot
.69412 .57872 Mdot
.70151 .68419 Mdot
.54479 .38576 Mdot
.27706 .35057 Mdot
.79249 .6082 Mdot
.48608 .45682 Mdot
.46759 .59158 Mdot
.31797 .31428 Mdot
.64017 .81792 Mdot
.5459 .59585 Mdot
.26003 .71757 Mdot
.5798 .61321 Mdot
.71133 .41584 Mdot
.70731 .40357 Mdot
.34995 .60664 Mdot
.52511 .48006 Mdot
.36759 .5359 Mdot
.51546 .40979 Mdot
.49409 .23072 Mdot
.74059 .68564 Mdot
.84774 .41066 Mdot
.34305 .43168 Mdot
.61034 .83182 Mdot
.31481 .4246 Mdot
.37432 .43159 Mdot
.49382 .80312 Mdot
.47866 .59893 Mdot
.50777 .35573 Mdot
.67351 .61272 Mdot
.31971 .39396 Mdot
.84017 .40128 Mdot
.45946 .57572 Mdot
.64275 .60329 Mdot
.40653 .76563 Mdot
.41235 .57808 Mdot
.22528 .60872 Mdot
.31831 .59977 Mdot
.65284 .80972 Mdot
.61295 .806 Mdot
.24084 .54793 Mdot
.51342 .50117 Mdot
.46767 .58537 Mdot
.83602 .45697 Mdot
.59646 .61162 Mdot
.81276 .56815 Mdot
.22883 .54391 Mdot
.50632 .23008 Mdot
.75355 .54668 Mdot
.7305 .5685 Mdot
.71622 .46618 Mdot
.51937 .25453 Mdot
.82167 .48943 Mdot
.54495 .55759 Mdot
.39557 .70485 Mdot
.42245 .78554 Mdot
.82371 .37568 Mdot
.27158 .39027 Mdot
.56807 .54193 Mdot
.72686 .65417 Mdot
.48528 .53848 Mdot
.64155 .53951 Mdot
.34955 .48228 Mdot
.60647 .54837 Mdot
.23108 .58443 Mdot
.25021 .36128 Mdot
.81854 .59091 Mdot
.55195 .37457 Mdot
.68251 .37338 Mdot
.35385 .53533 Mdot
.44684 .64332 Mdot
.28871 .32655 Mdot
.86016 .43794 Mdot
.31855 .53664 Mdot
.21673 .64074 Mdot
.34779 .60273 Mdot
.76426 .63135 Mdot
.24698 .71036 Mdot
.35733 .60088 Mdot
.71012 .76267 Mdot
.29327 .42739 Mdot
.54729 .23286 Mdot
.24083 .35565 Mdot
.75588 .56847 Mdot
.50395 .27458 Mdot
.54874 .51677 Mdot
.83578 .55059 Mdot
.63175 .5378 Mdot
.63323 .59659 Mdot
.82251 .47532 Mdot
.58301 .82344 Mdot
.53816 .82236 Mdot
.36095 .57788 Mdot
.39655 .4014 Mdot
.2759 .74227 Mdot
.3848 .72494 Mdot
.4827 .17295 Mdot
.81038 .55381 Mdot
.6092 .25085 Mdot
.48498 .45213 Mdot
.35575 .47161 Mdot
.84139 .46809 Mdot
.65856 .78004 Mdot
.53081 .50348 Mdot
.40905 .64648 Mdot
.72376 .57817 Mdot
.71913 .6572 Mdot
.32789 .47509 Mdot
.78544 .58934 Mdot
.38366 .64014 Mdot
.61571 .6045 Mdot
.59798 .82061 Mdot
.27786 .34954 Mdot
.70311 .47158 Mdot
.81211 .37768 Mdot
.71926 .43813 Mdot
.53993 .8324 Mdot
.22711 .55029 Mdot
.41422 .77714 Mdot
.82436 .38381 Mdot
.28259 .39562 Mdot
.53533 .27581 Mdot
.81344 .32356 Mdot
.85074 .53769 Mdot
.46952 .58552 Mdot
.537 .4211 Mdot
.70106 .76787 Mdot
.40784 .65803 Mdot
.75537 .64846 Mdot
.4821 .20182 Mdot
.51934 .81884 Mdot
.56686 .31093 Mdot
.53335 .4099 Mdot
.62574 .55114 Mdot
.34086 .35812 Mdot
.40701 .39032 Mdot
.39825 .743 Mdot
.55784 .82488 Mdot
.51066 .20739 Mdot
.47501 .21141 Mdot
.54587 .21564 Mdot
.37573 .34251 Mdot
.82739 .56287 Mdot
.56324 .62578 Mdot
.49864 .19571 Mdot
.83088 .45229 Mdot
.70313 .3694 Mdot
.35524 .51993 Mdot
.48782 .22576 Mdot
.68553 .56753 Mdot
.44836 .79187 Mdot
.82233 .34861 Mdot
.4931 .24592 Mdot
.86293 .51408 Mdot
.78056 .65043 Mdot
.37567 .34523 Mdot
.30282 .40652 Mdot
.61618 .52255 Mdot
.46423 .55869 Mdot
.22968 .59337 Mdot
.38076 .72077 Mdot
.53668 .80481 Mdot
.40093 .65266 Mdot
.58183 .36302 Mdot
.35832 .46507 Mdot
.80272 .59242 Mdot
.62522 .56562 Mdot
.80822 .58626 Mdot
.51241 .24093 Mdot
.54494 .40635 Mdot
.81294 .31187 Mdot
.21992 .418 Mdot
.57904 .32493 Mdot
.53143 .5661 Mdot
.57356 .54284 Mdot
.61469 .41702 Mdot
.28468 .53862 Mdot
.67142 .58482 Mdot
.49592 .81671 Mdot
.8356 .54648 Mdot
.2963 .37868 Mdot
.62597 .53259 Mdot
.33435 .57962 Mdot
.64461 .50596 Mdot
.5672 .30723 Mdot
.32506 .53767 Mdot
.47136 .80908 Mdot
.24135 .6168 Mdot
.33543 .50847 Mdot
.39675 .57636 Mdot
.6657 .53875 Mdot
.55936 .54549 Mdot
.48319 .80683 Mdot
.34327 .60966 Mdot
.34888 .52575 Mdot
.58832 .82947 Mdot
.52563 .26069 Mdot
.29731 .48955 Mdot
.42755 .77518 Mdot
.65709 .55718 Mdot
.37685 .45968 Mdot
.47755 .57117 Mdot
.54015 .19257 Mdot
.83402 .48419 Mdot
.44296 .75006 Mdot
.54467 .55675 Mdot
.59945 .21547 Mdot
.84596 .49663 Mdot
.32546 .57214 Mdot
.72685 .74016 Mdot
.48077 .5944 Mdot
.28627 .33245 Mdot
.62688 .24637 Mdot
.51308 .45689 Mdot
.61896 .34081 Mdot
.54979 .44509 Mdot
.68303 .44787 Mdot
.21498 .60576 Mdot
.52705 .47163 Mdot
.40853 .58214 Mdot
.44249 .57341 Mdot
.64517 .58454 Mdot
.61406 .34058 Mdot
.60018 .39602 Mdot
.54903 .59574 Mdot
.70789 .55744 Mdot
.60316 .53899 Mdot
.64382 .59158 Mdot
.27902 .50012 Mdot
.48304 .80825 Mdot
.53411 .82144 Mdot
.51031 .34147 Mdot
.84506 .46659 Mdot
.63655 .27061 Mdot
.80866 .55947 Mdot
.37533 .4899 Mdot
.27747 .49788 Mdot
.71829 .43263 Mdot
.82097 .34981 Mdot
.41707 .42868 Mdot
.515 .58171 Mdot
.77554 .65339 Mdot
.79491 .58844 Mdot
.27347 .50915 Mdot
.20975 .39914 Mdot
.42464 .78817 Mdot
.63013 .54354 Mdot
.25147 .35609 Mdot
.40637 .72636 Mdot
.77279 .63587 Mdot
.51183 .39405 Mdot
.47683 .59468 Mdot
.52252 .19304 Mdot
.54815 .32263 Mdot
.42233 .71616 Mdot
.54794 .19362 Mdot
.52065 .25362 Mdot
.82092 .49217 Mdot
.61399 .4301 Mdot
.42771 .49725 Mdot
.43302 .41484 Mdot
.81418 .36793 Mdot
.44373 .72919 Mdot
.70585 .3931 Mdot
.49 .1677 Mdot
.21455 .60425 Mdot
.5116 .8011 Mdot
.80938 .38309 Mdot
.30628 .60282 Mdot
.51613 .41723 Mdot
.1735 .46588 Mdot
.42573 .42238 Mdot
.43066 .379 Mdot
.35019 .5747 Mdot
.71071 .66986 Mdot
.40772 .44087 Mdot
.82463 .33668 Mdot
.78272 .61384 Mdot
.49584 .36327 Mdot
.47589 .1701 Mdot
.60286 .81812 Mdot
.69597 .39639 Mdot
.2843 .48995 Mdot
.82245 .5732 Mdot
.22746 .58719 Mdot
.68992 .7748 Mdot
.47161 .52698 Mdot
.31319 .41611 Mdot
.71546 .64986 Mdot
.24157 .36904 Mdot
.52049 .45422 Mdot
.47326 .20233 Mdot
.22897 .39528 Mdot
.72885 .63762 Mdot
.49551 .48811 Mdot
.34888 .44088 Mdot
.32551 .44276 Mdot
.46132 .49733 Mdot
.47821 .60429 Mdot
.42147 .56929 Mdot
.43931 .53905 Mdot
.33742 .51464 Mdot
.44744 .49026 Mdot
.21609 .42366 Mdot
.31424 .60946 Mdot
.529 .22862 Mdot
.4374 .78457 Mdot
.65567 .59574 Mdot
.41839 .65422 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`0008[ooooo0_l0002nooooo`007?ooool00ol0003oooooooooo`28ooooo`?o00000_ooool2
o`000;[ooooo000Looooo`03o`000?oooooooooo08Sooooo0_l00003ooooo`Co000000?oooooo`00
0?l00000]Oooool001cooooo00?o0000ooooooooool0S_ooool6o`000;Gooooo000Looooo`03o`00
0?oooooooooo08oooooo1_l0002dooooo`007?ooool00ol0003oooooooooo`2Aooooo`Go00001Ooo
ool4o`000:[ooooo000Looooo`03o`000?oooooooooo09Cooooo1Ol00002ooooo`Co00000_ooool2
o`000:Kooooo000Looooo`03o`000?oooooooooo09Kooooo1Ol00006ooooo`Co0000Y?ooool001co
oooo00?o0000ooooooooool0V?ooool3o`0000Gooooo0_l000000ooooooo0000o`000002o`000003
ooooool0003o000009oooooo000Looooo`03o`000?oooooooooo09Cooooo0_l00002ooooo`?o0000
1Oooool2o`0000?ooooo0_l000000ooooooo0000o`00002Oooooo`007?ooool00ol0003ooooooooo
o`2Dooooo`Wo00004oooool2o`0009Oooooo000Looooo`03o`000?oooooooooo09Kooooo1ol0000C
ooooo`;o0000Uoooool001cooooo00?o0000ooooooooool0Uoooool7o`0000cooooo0_l0002Moooo
o`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000
ooooooooool0V_ooool6o`0000Kooooo2ol00003ooooo`;o0000Toooool00006oooooomgMgOoV9RH
oooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`00
0?oooooooooo09Wooooo0_l000000ooooooo0000o`000002o`0000Kooooo1?l00002ooooo`Go0000
0oooool2o`0009?ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?o
V9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`2Iooooo`Oo0000ZOooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06ooooo`?o0000U_ooool2
o`000003ooooool0003o000000Co00005oooool2o`00097ooooo00000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`2Foooo
o`[o00005_ooool2o`00097ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Gooooo`Go00000_ooool2o`0000;o
oooo0_l0002Uooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001_ooool00ol0003oooooooooo`2Gooooo`Oo00001?ooool2o`0000Wooooo0_l0002J
ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
1_ooool00ol0003oooooooooo`2Gooooo`Co000000?oooooo`000?l000001?ooool2o`0000Cooooo
0_l00003ooooo`;o0000V_ooool001cooooo00?o0000ooooooooool0VOooool2o`0000Oooooo0ol0
0003ooooo`;o00001?ooool3o`0000Wooooo1ol00028ooooo`007?ooool00ol0003oooooooooo`2S
ooooo`;o00002Oooool3o`0000Sooooo2?l00028ooooo`007?ooool00ol0003oooooooooo`2Ioooo
o`?o00002oooool2o`0000_ooooo2?l00003ooooo`?o0000Qoooool001cooooo00?o0000oooooooo
ool0VOooool4o`0000[ooooo0_l00006ooooo`go00000oooool4o`0008Kooooo000Looooo`03o`00
0?oooooooooo09Wooooo1_l00002ooooo`;o00001Oooool2o`000003ooooool0003o000000;ooooo
3?l00006ooooo`;o0000Q_ooool001cooooo00?o0000ooooooooool0V_ooool2o`000003ooooool0
003o000000;ooooo0_l00005ooooo`;o000000Coooooo`000?l0003ooooo1Ol00003ooooo`;o0000
3?ooool2o`0008?ooooo000Looooo`03o`000?oooooooooo09_ooooo0_l0000>ooooo`;o000000?o
ooooo`000?l000001_ooool2o`0000cooooo0_l00023ooooo`007?ooool00ol0003oooooooooo`2H
ooooo`Go00002_ooool2o`0001kooooo0_l00020ooooo`007?ooool00ol0003oooooooooo`2Hoooo
o`Go00001_ooool2o`0000;ooooo0_l0000:ooooo`;o000000?oooooo`000?l000003_ooool3o`00
083ooooo000Looooo`03o`000?oooooooooo09Wooooo1Ol00005ooooo`;o00002Oooool2o`0000?o
oooo0_l000001?oooooo0000o`000?l00002ooooo`;o00002Oooool3o`00083ooooo000Looooo`03
o`000?oooooooooo09[ooooo1?l0000>ooooo`Co00001Oooool8o`000003ooooool0003o000000Oo
oooo0ol0001oooooo`007?ooool2o`0009_ooooo0_l0000@ooooo`?o00000_oooolCo`0000Cooooo
0_l0001oooooo`007?ooool00ol0003oooooooooo`2Iooooo`;o00002_ooool2o`0000[ooooo2Ol0
00000ooooooo0000o`000002o`000003ooooool0003o000000;o00001_ooool2o`0007gooooo000L
ooooo`03o`000?oooooooooo09Wooooo0ol00009ooooo`;o00001_ooool2o`0000;ooooo0_l00008
ooooo`Ko000000?oooooo`000?l000001_ooool2o`0000;ooooo0_l0001iooooo`007?ooool00ol0
003oooooooooo`2Iooooo`Co00002_ooool4o`0000;ooooo0_l0000@ooooo`Go00002_ooool2o`00
07Wooooo000Looooo`03o`000?oooooooooo09Wooooo1?l00004ooooo`;o00001?ooool4o`0000;o
oooo0_l0000@ooooo`?o0000Qoooool001cooooo00?o0000ooooooooool0VOooool3o`0000Gooooo
0_l0000:ooooo`;o00004?ooool3o`0000[ooooo0_l000000ooooooo0000o`00001hooooo`007?oo
ool00ol0003oooooooooo`2Jooooo`?o00008_ooool4o`0000?ooooo0ol00002ooooo`?o000000?o
ooooo`000?l00000N?ooool001cooooo00?o0000ooooooooool0Voooool2o`0000Kooooo0_l0000J
ooooo`Co00000oooool3o`0000;ooooo1?l0001jooooo`007?ooool00ol0003oooooooooo`2Poooo
o`Go00001Oooool2o`0001?ooooo0ol00003ooooo`?o000000?oooooo`000?l000001?l0001joooo
o`007?ooool00ol0003oooooooooo`2Pooooo`Go00001Oooool2o`0001Cooooo0_l00002ooooo`_o
0000N_ooool001cooooo00?o0000ooooooooool0Xoooool3o`0001[ooooo0_l000000ooooooo0000
o`00000:o`0007[ooooo000Looooo`03o`000?oooooooooo0:Cooooo0_l000000ooooooo0000o`00
000Gooooo`;o000000?oooooo`000?l000002_l0001jooooo`007?ooool00ol0003oooooooooo`2T
ooooo`;o000000?oooooo`000?l000001?ooool2o`00013ooooo4?l0001jooooo`007?ooool00ol0
003oooooooooo`2Tooooo`;o00001oooool2o`00013ooooo1?l000000ooooooo0000o`000009o`00
07[ooooo000Looooo`03o`000?oooooooooo09cooooo0_l0000Sooooo`ko0000N_ooool001cooooo
00?o0000ooooooooool0W?ooool3o`0000Sooooo0_l00007ooooo`;o00004?ooool=o`0007[ooooo
000Looooo`;o0000WOooool3o`0000Sooooo0_l00007ooooo`;o00004?ooool=o`0007[ooooo000L
ooooo`03o`000?oooooooooo06_ooooo0_l0000_ooooo`;o00002Oooool2o`0001Sooooo3ol0001i
ooooo`007?ooool00ol0003oooooooooo`1[ooooo`?o00001Oooool2o`0002Kooooo0ol00005oooo
o`;o00000_ooool2o`0000Cooooo0_l00005ooooo`;o00002_ooool@o`0003Kooooo0_l00011oooo
o`007?ooool00ol0003oooooooooo`1Pooooo`Co00002?ooool3o`0000Cooooo0_l0000Vooooo`;o
00001_ooool2o`0000?ooooo0_l00003ooooo`;o00001Oooool2o`0000[ooooo3_l0000hooooo`;o
0000@Oooool001cooooo00?o0000ooooooooool0H?ooool4o`0000Wooooo0_l00005ooooo`;o0000
1?ooool2o`0002cooooo1?l00003ooooo`;o00000oooool2o`0000[ooooo3Ol0000gooooo`;o0000
00?oooooo`000?l00000@?ooool001cooooo00?o0000ooooooooool0Foooool2o`0000Cooooo0_l0
00000ooooooo0000o`00000:ooooo`Ko00001?ooool4o`0002[ooooo1Ol00002ooooo`;o00004?oo
ool=o`0003Kooooo1Ol00010ooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o000000?ooooo
o`000?l000001oooool3o`0000;ooooo0ol00003ooooo`Go000000Coooooo`000?l0003o00000ooo
ool3o`0002_ooooo1Ol00005ooooo`;o00003?ooool=o`0003Sooooo0ol00010ooooo`007?ooool0
0ol0003oooooooooo`1Hooooo`;o000000?oooooo`000?l000001_ooool5o`000004ooooool0003o
0000o`0000?ooooo0_l00004ooooo`?o00000oooool2o`0000?ooooo0_l0000Wooooo`Oo00000ooo
ool2o`0000cooooo2ol0000iooooo`Co0000@?ooool001cooooo00?o0000ooooooooool0E_ooool2
o`0000_ooooo1Ol0000Hooooo`;o00009oooool2o`000003ooooool0003o000000?o00001oooool4
o`0000Gooooo2Ol0000jooooo`Co0000@Oooool001cooooo00?o0000ooooooooool0E?ooool4o`00
00;ooooo0_l00008ooooo`Co00004oooool2o`0000?ooooo1?l0000Xooooo`Go000000?oooooo`00
0?l000001?ooool4o`0000Gooooo2Ol0000jooooo`Ko0000?oooool001cooooo00?o0000oooooooo
ool0Doooool5o`000004ooooool0003o0000o`0000Kooooo0_l0000Gooooo`;o00001?ooool3o`00
01Kooooo0_l0000Fooooo`;o00002?ooool3o`0000;ooooo1ol00010ooooo`;o0000?oooool001co
oooo00?o0000ooooooooool0DOooool4o`0000Cooooo0_l00005ooooo`Co00004_ooool2o`0000;o
oooo0ol000000ooooooo0000o`00000Jooooo`;o00001oooool2o`0000cooooo0_l00009ooooo`?o
00001?ooool5o`00043ooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`1@ooooo`?o0000
1?ooool2o`0000Oooooo0ol0000@ooooo`;o000000?oooooo`000?l000000_ooool3o`000004oooo
ool0003o0000ooooo`?o00006oooool2o`0000;ooooo0_l0000;ooooo`?o00001?ooool3o`000003
ooooool0003o000000Kooooo1Ol000000ooooooo0000o`00000iooooo`?o000000?oooooo`000?l0
0000?oooool001cooooo00?o0000ooooooooool0C_ooool4o`0000;ooooo0_l000000ooooooo0000
o`00000Iooooo`co000000?oooooo`000?l000001?l0000Jooooo`;o000000?oooooo`000?l00000
3?ooool2o`0000Gooooo0ol000000ooooooo0000o`000006ooooo`Co00000_ooool2o`0003Wooooo
0ol000000ooooooo0000o`00000oooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o00001?oo
ool2o`0000_ooooo0_l0000;ooooo`;o00000_ooool2o`000003ooooool0003o000000Oo000000?o
ooooo`000?l000002?l0000?ooooo`;o00002?ooool2o`0001kooooo1Ol0000nooooo`;o0000@_oo
ool001cooooo00?o0000ooooooooool0C_ooool2o`0000kooooo1Ol0000:ooooo`?o00000_ooool2
o`0000;ooooo2?l00006ooooo`Go00003oooool2o`0001gooooo0_l00009ooooo`;o000000?ooooo
o`000?l00000?_ooool2o`000003ooooool0003o000003oooooo000Looooo`;o0000Coooool2o`00
00?ooooo0_l000001?oooooo0000o`000?l00005ooooo`Co00002ooooolCo`0000Gooooo0_l00002
ooooo`?o00002oooool2o`0000_ooooo0_l00007ooooo`Co00001_ooool6o`0000Gooooo1Ol00010
ooooo`?o0000?oooool001cooooo00?o0000ooooooooool0Boooool2o`0000;ooooo0_l00002oooo
o`;o000000Coooooo`000?l0003o00001Oooool4o`0000_ooooo6Ol00003ooooo`?o00000_ooool2
o`0000Oooooo0_l0000;ooooo`;o00001oooool4o`0000;ooooo0_l00004ooooo`Co00001_ooool2
o`000004ooooool0003o0000o`0003kooooo0ol0000oooooo`007?ooool00ol0003oooooooooo`1;
ooooo`;o000000Coooooo`000?l0003o00003?ooool5o`0000[ooooo6_l00003ooooo`Oo00004Ooo
ool2o`0000kooooo1?l00002ooooo`;o000000?oooooo`000?l000000_l00005ooooo`Ko0000?ooo
ool3o`0003kooooo000Looooo`03o`000?oooooooooo04_ooooo0_l000000ooooooo0000o`000004
ooooo`;o00001oooool4o`0000[ooooo5ol00004ooooo`;o00001?ooool4o`00017ooooo0_l0000=
ooooo`Co000000?oooooo`000?l000002_l00004ooooo`;o0000?_ooool2o`0000;ooooo0_l0000n
ooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o000000?oooooo`000?l000001?ooool2o`00
00Kooooo1_l00006oooooa[o000000Coooooo`000?l0003ooooo0_l00006ooooo`;o00001Oooool2
o`0000Kooooo0_l00008ooooo`;o00001?oooolEo`0000?ooooo1?l0000looooo`;o00000_ooool2
o`0003kooooo000Looooo`03o`000?oooooooooo04Kooooo0_l00002ooooo`;o00000_ooool2o`00
00;ooooo0_l00008ooooo`Ko00001_oooolJo`000003ooooool0003o000000Kooooo0_l000000ooo
oooo0000o`000005ooooo`?o00001Oooool2o`0000Sooooo0_l00004oooooaGo00001Oooool2o`00
03cooooo0_l00002ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0A_ooool2o`0000;o
oooo0ol00005ooooo`;o00002_ooool3o`0000Oooooo6?l00006ooooo`Co000000Coooooo`000?l0
003ooooo0_l00006ooooo`;o00002?ooool2o`0000oooooo4?l0000Pooooo`;o00008_ooool4o`00
043ooooo000Looooo`03o`000?oooooooooo04Gooooo0_l00004ooooo`;o00004?ooool4o`0000Oo
oooo6_l00004ooooo`Co000000Coooooo`000?l0003o00004_ooool2o`0000_ooooo0_l00002oooo
oa;o00000_ooool2o`0001[ooooo0_l0000Rooooo`Ko0000?_ooool001cooooo00?o0000oooooooo
ool0AOooool2o`0000[ooooo0_l00006ooooo`So00001ooooolJo`0000Kooooo0_l000001?oooooo
0000o`000?l00008ooooo`;o00004oooool4o`000003ooooool0003o0000017o00000_ooool2o`00
01?ooooo1?l0000Uooooo`;o00000_ooool4o`0003kooooo000Looooo`03o`000?oooooooooo057o
oooo0_l00006ooooo`So00001?ooool2o`000003ooooool0003o000001Ko00002?ooool6o`0000So
oooo0_l0000Cooooo`;o000000?oooooo`000?l000005?l0000Fooooo`Co00009Oooool3o`000003
ooooool0003o000000;o0000?_ooool001cooooo00?o0000ooooooooool0D?ooool2o`0000?ooooo
0_l00006ooooo`Go00000_oooolKo`0000Oooooo1ol0000Hooooo`Co000000?oooooo`000?l00000
6?l0000Eooooo`;o0000:Oooool2o`000003ooooool0003o000000;o0000?_ooool001cooooo00?o
0000ooooooooool0@_ooool2o`0000Kooooo0_l00004ooooo`;o00000oooool2o`0000Cooooo0_l0
00000ooooooo0000o`000002o`0000;ooooo0_l000000ooooooo0000o`00000@o`000003ooooool0
003o000000Go00000_ooool2o`000003ooooool0003o000000Go00006?ooool4o`000003ooooool0
003o000001Wo00005?ooool2o`0002Sooooo0_l00003ooooo`;o0000?oooool001cooooo00?o0000
ooooooooool0@_ooool3o`0000Gooooo0_l000000ooooooo0000o`00000<ooooo`;o00000_ooool3
o`0000;ooooo0_l000000ooooooo0000o`00000Lo`0000?ooooo1?l0000Kooooo`;o00000ooooolI
o`000003ooooool0003o000000?o00003_ooool3o`0002Oooooo1?l000000ooooooo0000o`00000o
ooooo`007?ooool00ol0003oooooooooo`11ooooo`Co00001?ooool2o`0000;ooooo0_l00006oooo
o`;o00002?ooool2o`0000?ooooo0_l000000ooooooo0000o`00000Jo`0000Gooooo1?l0000;oooo
o`;o00003oooool2o`000003ooooool0003o000001ko00003_ooool3o`0000Sooooo0_l0000Moooo
o`Co00000oooool2o`0003gooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46
ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`11ooooo`;o00001_ooool2
o`0000;ooooo0_l00006ooooo`;o00002?ooool3o`0000;ooooo6Ol000000ooooooo0000o`000002
o`0000Gooooo1?l0000<ooooo`;o00002Oooool2o`0000?ooooo1ol000000ooooooo0000o`000002
o`000003ooooool0003o000000go000000?oooooo`000?l000000_l0000Iooooo`;o000000?ooooo
o`000?l000007Oooool2o`0000Gooooo0_l0000mooooo`0000KoooooogMgMonHV9SooooooiRHV?mg
MgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Oooooo0_l0
0004ooooo`;o00000oooool2o`0000Cooooo0_l00006ooooo`;o00000_oooolIo`0000[ooooo1?l0
000Gooooo`;o00000_oooolMo`000003ooooool0003o000000;ooooo0_l0000Dooooo`;o000000Co
ooooo`000?l0003o00007oooool2o`0000Oooooo0_l0000kooooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`09ooooo`Go00001_ooool00ol0003oooooooooo`0oooooo`?o00001?oo
ool3o`0000Oooooo1?l00004ooooo`;o00001_ooool2o`0000?ooooo1Ol000000ooooooo0000o`00
000@o`0000Wooooo0ol0000@ooooo`Co00002?ooool3o`0000?ooooo6?l000000ooooooo0000o`00
0002ooooo`;o00005?ooool2o`0000;ooooo0_l00003ooooo`?o00008_ooool2o`0003_ooooo0000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001ooo
ool3o`0003kooooo1?l00004ooooo`;o00002?ooool4o`0000cooooo0_l00003oooooa[o00000_oo
ool2o`0000?ooooo0_l0000Aooooo`Co00002?oooolQo`000004ooooool0003o0000o`0001[ooooo
1ol0000Rooooo`;o0000>_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Ooo
ool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo03kooooo0_l000000ooooooo0000
o`000003ooooo`;o00001?ooool2o`0000;ooooo0_l0000?ooooo`;o00000_oooolFo`000005oooo
ool0003o0000o`000?ooool01ol00009ooooo`;o00005OoooolRo`0001Wooooo2Ol0000Jooooo`;o
00001_ooool2o`000003ooooool0003o000003Oooooo00000ooooooo410@ooooo`02ooooo`03oa0@
4?oooooooooo00[ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0mooooo`?o0000
00?oooooo`000?l000002Oooool2o`0000Wooooo0ol00005ooooo`Co00000_oooolFo`0000Gooooo
0_l000000ooooooo0000o`000002o`0000?ooooo0_l00004ooooo`;o00005Oooool2o`0000;ooooo
7Ol0000Jooooo`?o00000oooool2o`0001_ooooo0_l00002ooooo`;o00001Oooool2o`0003Oooooo
00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l000001oooool00ol0003o
ooooooooo`0mooooo`;o00002Oooool4o`0000_ooooo0ol00005ooooo`Co00000_oooolEo`0000Go
oooo0ol00002ooooo`;o00000_ooool4o`0000_ooooo0_l0000;ooooo`;o000000?oooooo`000?l0
00008?l0000Iooooo`?o00000oooool2o`0001oooooo0_l00005ooooo`;o0000=oooool00006oooo
ooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo
03gooooo0_l00005ooooo`;o00000_ooool4o`0001Gooooo0_l00002ooooo`go00000_ooool4o`00
00Oooooo1Ol00004ooooo`?o00003?ooool2o`0000_ooooo0ol00002ooooo`Co000000?oooooo`00
0?l000001ol000000ooooooo0000o`00000?o`0001Wooooo0_l00005ooooo`;o00006Oooool2o`00
00[ooooo1?l0000eooooo`007?ooool00ol0003oooooooooo`0kooooo`?o00001_ooool2o`0001co
oooo0_l000000ooooooo0000o`000005o`000003ooooool0003o000000Go00002oooool5o`0000;o
oooo0_l000000ooooooo0000o`00000Eooooo`;o00000_ooool4o`0000?ooooo7?l0000Looooo`;o
00001?ooool2o`0001Wooooo0_l0000;ooooo`?o0000=Oooool001cooooo00?o0000ooooooooool0
>oooool4o`0000Gooooo0_l0000Iooooo`;o000000?oooooo`000?l000000_ooool2o`000003oooo
ool0003o000000?ooooo0_l00002ooooo`;o00002_ooool5o`0000?ooooo0_l000001?oooooo0000
o`000?ooool3o`00017ooooo0_l00002ooooo`Co00000ooooolKo`0001gooooo0_l00004ooooo`;o
00006_ooool2o`000003ooooool0003o000000Oooooo1?l0000dooooo`007?ooool00ol0003ooooo
ooooo`0kooooo`Co00000oooool2o`0000;ooooo0_l0000Gooooo`;o000000Goooooo`000?l0003o
0000ooooo`02o`0000Gooooo0_l0000?ooooo`?o00001_ooool4o`000004ooooool0003o0000o`00
00gooooo0_l0000<oooooa_o00009?ooool2o`0001[ooooo0_l000000ooooooo0000o`000009oooo
o`;o0000=?ooool001cooooo00?o0000ooooooooool0>oooool2o`0000;ooooo1Ol00002ooooo`;o
00005?ooool2o`0000Gooooo0_l000000ooooooo0000o`000005ooooo`;o00003_ooool3o`0000Oo
oooo1?l0000Aooooo`;o00001_ooool2o`0000Cooooo1Ol000000ooooooo0000o`00000Bo`0002Go
oooo0_l0000Jooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0>Oooool2o`0000?ooooo
1?l00003ooooo`;o00005Oooool3o`0000Gooooo0_l00002ooooo`;o00000_ooool2o`0000gooooo
1?l00005ooooo`;o00000_ooool2o`0001[ooooo0_l00006oooooa;o000000?oooooo`000?l00000
1_l0000Jooooo`;o00001?ooool4o`0001[ooooo0_l000000ooooooo0000o`00000oooooo`007?oo
ool00ol0003oooooooooo`0iooooo`Co000000?oooooo`000?l000000_l00003ooooo`;o00005_oo
ool2o`0000Gooooo0_l00002ooooo`;o00000_ooool2o`0000Sooooo0_l00003ooooo`?o00001_oo
ool2o`0000;ooooo0_l0000Nooooo`;o00000_oooolBo`000005ooooool0003o0000o`000?ooool0
1?l0000Jooooo`;o00000oooool3o`0001oooooo0_l0000oooooo`007?ooool00ol0003ooooooooo
o`0jooooo`?o00009oooool3o`0000Gooooo0_l00008ooooo`;o00007Oooool2o`00013ooooo0ol0
0002ooooo`;o000000?oooooo`000?l000005?l0000Hooooo`?o00001_ooool2o`0000;ooooo0_l0
000Iooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0=oooool2o`000004ooooool0003o
0000o`0000Gooooo0_l0000Pooooo`?o00001_ooool2o`0000Sooooo0_l0000Looooo`;o00002_oo
ool2o`0000Cooooo0_l00005ooooo`;o000000?oooooo`000?l000004?l0000Jooooo`?o00001_oo
ool2o`0000;ooooo0_l0000Iooooo`;o000000?oooooo`000?l000001Oooool2o`0000?ooooo0_l0
000cooooo`007?ooool00ol0003oooooooooo`0gooooo`Go00001Oooool3o`0002;ooooo0_l00005
ooooo`Co00000_ooool3o`000003ooooool0003o000000Sooooo0_l0000@ooooo`;o00001Oooool2
o`0000Gooooo0_l00005ooooo`;o00001?ooool3o`000003ooooool0003o000000_o00008Oooool2
o`0000Cooooo0_l0000Pooooo`;o00001Oooool2o`0000?ooooo0ol0000booooo`007?ooool00ol0
003oooooooooo`0iooooo`?o00001Oooool2o`0002?ooooo0ol00005ooooo`?o00000_ooool3o`00
00Cooooo1?l00003ooooo`;o00004?ooool2o`000003ooooool0003o000000;ooooo0_l0000<oooo
o`;o00001?ooool@o`0001kooooo2?l0000[ooooo`;o00000_ooool4o`0003;ooooo000Looooo`03
o`000?oooooooooo03Wooooo0_l0000/ooooo`;o00004?ooool5o`0001Sooooo0_l0000@ooooo`;o
00001Oooool?o`0001cooooo2_l0000[ooooo`;o00000_ooool2o`0003Cooooo000Looooo`;o0000
=oooool4o`0000Cooooo0ol0000Pooooo`;o00001?ooool2o`0000gooooo1Ol000000ooooooo0000
o`000002o`0001[ooooo0_l00002ooooo`;o00002Oooool2o`0000Gooooo1ol000000ooooooo0000
o`000003o`0001gooooo0_l00006ooooo`Co000000Coooooo`000?l0003ooooo0_l0000Nooooo`;o
000000?oooooo`000?l000000_ooool2o`0003Kooooo000Looooo`03o`000?oooooooooo03Gooooo
1Ol00004ooooo`?o00006oooool2o`0000?ooooo0_l00004ooooo`;o00001?ooool3o`0000;ooooo
1ol00005ooooo`Co00006?ooool2o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`0000Oooooo
1Ol000001?oooooo0000o`000?ooool2o`0001cooooo0ol00005ooooo`Go000000?oooooo`000?l0
00000ol0000Nooooo`;o000000?oooooo`000?l000000_ooool2o`0003Kooooo000Looooo`03o`00
0?oooooooooo03Gooooo0ol0000Sooooo`Go00003Oooool3o`000003ooooool0003o000000Co0000
2Oooool3o`0001Oooooo0ol00006ooooo`Co00001?ooool2o`0000Kooooo1?l00004ooooo`;o0000
7?ooool2o`0000Kooooo1?l000001?oooooo0000o`000?ooool3o`0001gooooo0_l000000ooooooo
0000o`00000kooooo`007?ooool00ol0003oooooooooo`0dooooo`Co00008oooool5o`00017ooooo
0_l00004ooooo`;o00002?ooool2o`0001Oooooo0ol00006ooooo`;o00001_ooool2o`0000Oooooo
0_l00005ooooo`;o00009?ooool4o`000004ooooool0003o0000ooooo`?o00007Oooool2o`000003
ooooool0003o000003_ooooo000Looooo`03o`000?oooooooooo03Cooooo0_l0000Uooooo`Go0000
5_ooool3o`0002gooooo0_l00002ooooo`?o00001oooool2o`0002cooooo0ol00004ooooo`;o0000
9?ooool3o`0003Oooooo000Looooo`03o`000?oooooooooo03?ooooo1ol0000Qooooo`Go00001Ooo
ool2o`000004ooooool0003o0000o`0000Kooooo0_l00003ooooo`;o0000:?ooool4o`0000;ooooo
0_l00002ooooo`;o00002Oooool2o`0002Wooooo1ol00002ooooo`;o00009?ooool3o`0003Oooooo
000Looooo`03o`000?oooooooooo03?ooooo1ol0000Pooooo`Go00000_ooool2o`000005ooooool0
003o0000o`000?ooool00ol00006ooooo`;o00002?ooool2o`0002?ooooo1?l000000ooooooo0000
o`000008ooooo`;o00001?ooool2o`0002Wooooo1ol000000ooooooo0000o`00000Sooooo`Co0000
>?ooool001cooooo00?o0000ooooooooool0<oooool6o`00023ooooo1_l00002ooooo`;o000000?o
ooooo`000?l000002_ooool2o`0000Wooooo0_l0000Xooooo`Co00001_ooool2o`0002oooooo1?l0
0004ooooo`;o00008oooool2o`0000?ooooo0_l0000eooooo`007?ooool00ol0003oooooooooo`0c
ooooo`Go00007oooool4o`0000Kooooo0ol00003ooooo`;o00001Oooool4o`0003Gooooo0_l00007
ooooo`;o0000;_ooool5o`0000;ooooo0_l0000Nooooo`;o00002Oooool6o`00037ooooo000Loooo
o`03o`000?oooooooooo03Gooooo0_l0000Pooooo`Co00001oooool3o`0000;ooooo0_l00005oooo
o`;o00003oooool2o`0002Kooooo1?l000000ooooooo0000o`000002ooooo`;o00007_ooool2o`00
00oooooo1?l00002ooooo`;o00007_ooool2o`0000_ooooo1?l0000aooooo`007?ooool00ol0003o
ooooooooo`1Iooooo`Ko00001?ooool3o`0000Sooooo0_l0000?ooooo`;o00008_ooool2o`0000;o
oooo1?l000000ooooooo0000o`00000Rooooo`;o00003oooool3o`0000?ooooo0_l0000Pooooo`;o
00002?ooool2o`0003Cooooo000Looooo`03o`000?oooooooooo05Kooooo0_l00003ooooo`Go0000
1?ooool2o`0000Sooooo0_l0000@ooooo`;o00008Oooool2o`0000Sooooo0_l00006ooooo`;o0000
5Oooool2o`0001?ooooo0ol00003ooooo`;o00007_ooool6o`0000Kooooo0_l0000dooooo`007?oo
ool00ol0003oooooooooo`1Dooooo`Co00001Oooool3o`0000Gooooo0_l0000Iooooo`;o00005_oo
ool2o`0000?ooooo1?l00006ooooo`;o00001?ooool2o`0000Cooooo1_l0000Cooooo`;o00004ooo
ool2o`0000?ooooo0_l0000Oooooo`;o00000_ooool2o`0003cooooo000Looooo`03o`000?oooooo
oooo05Cooooo0_l00003ooooo`;o00000_ooool2o`0000Kooooo0_l00009ooooo`;o00001?ooool2
o`0001Kooooo0_l00008ooooo`;o00000oooool6o`0000Cooooo0_l00003ooooo`;o00000_ooool2
o`000003ooooool0003o000000;ooooo0_l0000Xooooo`;o00000oooool2o`0001oooooo1?l00004
ooooo`;o00001?ooool2o`0003;ooooo000Looooo`03o`000?oooooooooo05Gooooo0_l00002oooo
o`;o00003?ooool2o`0000Oooooo0_l00004ooooo`;o00000oooool2o`00017ooooo1?l0000?oooo
o`;o00000oooool2o`0000Cooooo0_l00002ooooo`;o00001Oooool2o`000004ooooool0003o0000
o`0002Cooooo0_l00002ooooo`?o00007oooool4o`0000Cooooo0_l00004ooooo`;o0000<_ooool0
01cooooo00?o0000ooooooooool0EOooool3o`0000kooooo0ol0000Booooo`;o00002_ooool2o`00
00Oooooo1?l0000=ooooo`;o00000oooool2o`000003ooooool0003o000000Gooooo0_l00008oooo
o`Co00008_ooool3o`0000;ooooo0ol0000Wooooo`;o0000>?ooool001cooooo0_l0001Cooooo`;o
00000_ooool3o`0000Kooooo1_l000000ooooooo0000o`000003o`0000Cooooo0_l0000Fooooo`;o
00002Oooool2o`0000gooooo1?l00004ooooo`;o00001Oooool2o`0000Wooooo1Ol0000Pooooo`?o
0000;?ooool3o`0003Oooooo000Looooo`03o`000?oooooooooo05;ooooo0_l000000ooooooo0000
o`000004o`000004ooooool0003o0000ooooo`Oo00000_ooool3o`0000Cooooo0_l0000Mooooo`;o
00004oooool2o`0000?ooooo0ol0000@ooooo`;o000000?oooooo`000?l000000_l0000?ooooo`;o
00003?ooool3o`0000;ooooo0ol0000Yooooo`;o000000?oooooo`000?l00000=?ooool001cooooo
00?o0000ooooooooool0EOooool2o`000003ooooool0003o000000Co00000oooool2o`000003oooo
ool0003o000000;ooooo1?l0000Rooooo`;o00004_ooool2o`0000Cooooo0ol0000Dooooo`Go0000
2_ooool8o`000004ooooool0003o0000o`0000?ooooo1Ol00002ooooo`?o00007oooool2o`0000Wo
oooo1?l0000dooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o00001?ooool6o`000003oooo
ool0003o000000?ooooo0ol00006ooooo`?o00008Oooool2o`0001?ooooo1?l0000Iooooo`;o0000
00Coooooo`000?l0003ooooo0ol000001?oooooo0000o`000?ooool>o`000003ooooool0003o0000
00Go000000Coooooo`000?l0003o00008?ooool2o`0000Wooooo0_l0000fooooo`007?ooool00ol0
003oooooooooo`1=ooooo`Co00000oooool5o`0000Oooooo0_l00007ooooo`;o00008_ooool2o`00
00[ooooo0_l00009ooooo`;o000000?oooooo`000?l000002_ooool2o`0000cooooo0_l00002oooo
o`?o000000?oooooo`000?l000003ol000000ooooooo0000o`000002o`000004ooooool0003o0000
ooooo`?o0000;_ooool2o`0003?ooooo000Looooo`03o`000?oooooooooo04gooooo1?l0000Ioooo
o`;o0000;Oooool2o`0000cooooo0_l00005ooooo`?o00000_ooool2o`0000cooooo0_l00007oooo
o`;o00002?ooool9o`000003ooooool0003o000000;ooooo1?l0000^ooooo`;o0000<oooool001co
oooo00?o0000ooooooooool0D?ooool4o`0001Kooooo0_l00004ooooo`;o00000_ooool2o`0001oo
oooo0_l0000Cooooo`;o00000_ooool3o`0000oooooo0_l0000Dooooo`Ko00000_ooool2o`000003
ooooool0003o000000;o0000:_ooool2o`0003Sooooo000Looooo`03o`000?oooooooooo04[ooooo
0_l00004ooooo`Co00007?ooool2o`0000;ooooo0_l0000Oooooo`;o00002Oooool2o`0000Sooooo
0_l0000>ooooo`;o00001?ooool2o`0000;ooooo0_l0000@ooooo`ko0000:oooool2o`0000?ooooo
0_l0000cooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o00000_ooool2o`0001kooooo0_l0
000Qooooo`;o00003Oooool2o`0001Sooooo0_l00008ooooo`;o00000oooool3o`0000cooooo2ol0
000Zooooo`;o00001Oooool2o`0003?ooooo000Looooo`03o`000?oooooooooo04kooooo0_l0000I
ooooo`;o00000oooool2o`0001[ooooo0_l00005ooooo`;o00000_ooool2o`000003ooooool0003o
000000;o00007oooool2o`0000[ooooo1Ol000000ooooooo0000o`000002o`0000Oooooo2ol0000Z
ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0GOooool2o`0000?ooooo1?l00003oooo
o`;o00001?ooool4o`0001Oooooo0_l00006ooooo`;o000000Coooooo`000?l0003ooooo1?l0000O
ooooo`?o00002Oooool3o`0000?ooooo1_l00006ooooo`Wo0000:?ooool2o`0003gooooo000Loooo
o`03o`000?oooooooooo04kooooo0_l0000;ooooo`Co000000?oooooo`000?l000001_l00006oooo
o`Go00007oooool2o`0001_ooooo0ol0000:ooooo`;o00002_ooool2o`0000Oooooo0ol00009oooo
o`;o0000:oooool2o`0000Gooooo0_l0000fooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o
00002Oooool?o`0000;ooooo0_l00002ooooo`?o00000oooool2o`0001Kooooo0_l00007ooooo`;o
00000oooool2o`00013ooooo2ol0000Booooo`;o00001oooool4o`0003_ooooo0_l0000fooooo`00
7?ooool00ol0003oooooooooo`1<ooooo`;o00002Oooool9o`000003ooooool0003o000000Go0000
0_ooool2o`0000Sooooo0_l0000Cooooo`Go00000oooool2o`0000;ooooo0_l00003ooooo`;o0000
3oooool@o`0000Gooooo0_l00007ooooo`;o00000_ooool2o`0000Gooooo1?l0000Kooooo`;o0000
7?ooool2o`0003Kooooo000Looooo`03o`000?oooooooooo04Kooooo0ol00003ooooo`;o00002?oo
oolDo`000004ooooool0003o0000o`0000;ooooo1Ol00008ooooo`;o00002_ooool4o`0000Cooooo
0_l00007ooooo`;o00003_oooolAo`0000Gooooo0_l00007ooooo`;o00000_ooool2o`0000Oooooo
1?l0000Fooooo`;o000000?oooooo`000?l000004_ooool2o`00043ooooo000Looooo`03o`000?oo
oooooooo04Kooooo0ol00002ooooo`;o00002OoooolDo`000004ooooool0003o0000o`0000;ooooo
1Ol00008ooooo`;o00002_ooool4o`0001gooooo1Ol000000ooooooo0000o`000008o`0000?ooooo
0_l0000:ooooo`;o00000_ooool2o`0000Oooooo1_l0000@ooooo`;o00000_ooool5o`0001;ooooo
0_l00003ooooo`;o0000>oooool001cooooo0_l00017ooooo`;o00000oooool2o`0000Sooooo5Ol0
0007ooooo`;o00003Oooool2o`0000Oooooo1?l0000Kooooo`;o000000?oooooo`000?l000000ooo
ool?o`0000;ooooo0_l00004ooooo`Co00002oooool2o`0000;ooooo1?l0000>ooooo`;o00000ooo
ool4o`0001Oooooo0_l000001?oooooo0000o`000?l0000gooooo`007?ooool00ol0003ooooooooo
o`16ooooo`;o00003OoooolEo`0000Oooooo0_l0000=ooooo`;o00009_ooool5o`000003ooooool0
003o000000oo00000_ooool3o`0000?ooooo0_l000000ooooooo0000o`00000<ooooo`;o000000?o
ooooo`000?l000000ol000001?oooooo0000o`000?l00006ooooo`;o00001_ooool2o`0000oooooo
0_l00002ooooo`;o00000oooool2o`000004ooooool0003o0000o`0003Oooooo000Looooo`03o`00
0?oooooooooo04[ooooo0_l00009oooooaGo000000?oooooo`000?l00000:Oooool2o`00017ooooo
5ol00002ooooo`;o00001_ooool2o`0000Cooooo1?l00004ooooo`?o00000_ooool9o`0000Cooooo
0_l0000Gooooo`?o000000?oooooo`000?l000001_ooool2o`0003Sooooo000Looooo`03o`000?oo
oooooooo04Gooooo0_l00002ooooo`?o00001ooooolGo`000003ooooool0003o000002Kooooo0_l0
00000ooooooo0000o`00000AoooooaSo00000oooool5o`0000;ooooo0_l000000ooooooo0000o`00
0004o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`Ko00001_ooool2o`0000?ooooo1Ol0
000=ooooo`?o000000?oooooo`000?l000001Oooool2o`0003Wooooo000Looooo`03o`000?oooooo
oooo04Gooooo0_l00002ooooo`;o00002?oooolGo`0000Gooooo1?l0000Jooooo`;o00001?ooool2
o`0000Kooooo0_l00009ooooo`Go000000?oooooo`000?l000005?l00002ooooo`Go00000_ooool2
o`000004ooooool0003o0000o`0000?ooooo1?l0000:ooooo`;o00002?ooool2o`0000?ooooo1Ol0
000=ooooo`;o00001?ooool2o`0000?ooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`19
ooooo`;o00001oooool;o`000003ooooool0003o000000[o000000?oooooo`000?l000000_ooool4
o`0000Gooooo0_l0000Cooooo`;o00002?ooool3o`000003ooooool0003o000000Oooooo4?l00000
0ooooooo0000o`00000;o`0000Gooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o
000000;o00001_ooool2o`0001?ooooo0ol0000Eooooo`Co0000??ooool001cooooo00?o0000oooo
ooooool0BOooool2o`0000Oooooo6ol00004ooooo`?o00001?ooool3o`0000Cooooo0_l00004oooo
o`;o00002Oooool2o`0000Gooooo0ol0000:ooooo`;o000000?oooooo`000?l000006?l00006oooo
o`;o00000_ooool2o`0000Gooooo0_l00007ooooo`?o00002oooool2o`0000;ooooo0_l00002oooo
o`?o00004?ooool4o`0000;ooooo0ol0000looooo`007?ooool00ol0003oooooooooo`18ooooo`?o
00001OoooolMo`0000Cooooo0ol00005ooooo`;o00001?ooool2o`000003ooooool0003o000000?o
00002Oooool2o`0000Gooooo0_l0000>ooooo`;o00000_ooool5o`000003ooooool0003o000000ko
000000?oooooo`000?l000002_ooool2o`0000Wooooo1?l0000<ooooo`;o00000_ooool2o`000003
ooooool0003o000000;o00004?ooool8o`0003gooooo000Looooo`03o`000?oooooooooo04Oooooo
1?l00005oooooa_o00000oooool2o`0000;ooooo0_l0000>ooooo`?o00001oooool2o`0000?ooooo
0ol00003ooooo`;o00002oooool2o`0000Gooooo6Ol00007ooooo`;o000000?oooooo`000?l00000
2?ooool4o`00017ooooo1_l0000<ooooo`Go00000oooool3o`000003ooooool0003o000003cooooo
000Looooo`03o`000?oooooooooo04Oooooo1?l00005oooooa[o00001?ooool2o`0000;ooooo0_l0
0009ooooo`;o00000oooool2o`0000Sooooo0_l00003ooooo`?o00003oooool4o`000004ooooool0
003o0000oooooaSo00001_ooool4o`0000_ooooo1?l00002ooooo`;o00001oooool2o`0000Cooooo
1Ol0000=ooooo`Go00000oooool2o`0000;ooooo0_l0000looooo`007?ooool00ol0003ooooooooo
o`16ooooo`Go00001OoooolKo`0000Oooooo0_l00008ooooo`?o00000oooool2o`0000[ooooo0_l0
000Cooooo`Co000000?oooooo`000?l000000_oooolDo`000003ooooool0003o000000;o00001?oo
ool2o`0000Gooooo1?l0000:ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Gooooo1?l0
000Eooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0@Oooool2o`0000?ooooo1?l00006
oooooaSo000000?oooooo`000?l000001oooool2o`0000Sooooo0ol00002ooooo`;o00000oooool2
o`0000Kooooo0_l0000Dooooo`;o00000_ooool2o`0000?ooooo5Ol000000ooooooo0000o`000009
ooooo`Ko00000_ooool2o`0000Wooooo0_l0000:ooooo`Co00003Oooool2o`0004Wooooo000Loooo
o`03o`000?oooooooooo047ooooo0_l00003ooooo`Co00001ooooolFo`0000_ooooo0ol0000<oooo
o`;o00000oooool2o`0000Kooooo0_l00004ooooo`?o00001?ooool2o`0000Kooooo0_l00008oooo
oaGo00001Oooool2o`0000Gooooo0_l00005ooooo`?o00002oooool2o`0000Gooooo1ol0000=oooo
o`;o00000oooool2o`0004Cooooo000Looooo`03o`000?oooooooooo047ooooo0_l00003ooooo`;o
00002OoooolDo`0000kooooo0ol0000Nooooo`?o00001?ooool2o`0000Kooooo0_l00002ooooo`;o
00001?oooolEo`0000Gooooo0_l0000<ooooo`So00001_ooool2o`0000?ooooo2Ol0000:ooooo`;o
000000?oooooo`000?l000000oooool2o`000003ooooool0003o0000047ooooo00001_ooooook^k^
oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool0
0ol0003oooooooooo`17ooooo`;o00002?oooolDo`0000kooooo0ol00008ooooo`;o00004?ooool2
o`0000;ooooo0_l0000=ooooo`?o000000?oooooo`000?l000001OoooolCo`000003ooooool0003o
000000?ooooo0_l00004ooooo`;o00000oooool2o`0000Cooooo1ol00006ooooo`;o000000?ooooo
o`000?l000000ol0000>ooooo`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o0000@Ooo
ool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMgMooooooo
V9RHob4Q8@06ooooo`03o`000?oooooooooo04Oooooo1Ol0000:ooooo`ko00000oooool3o`0000[o
oooo0ol00007ooooo`;o00004?ooool2o`000005ooooool0003o0000o`000?ooool00ol0000:oooo
o`Ko00001?oooolAo`0000?ooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l00002
ooooo`?o00001Oooool2o`000003ooooool0003o000000Wo000000?oooooo`000?l000001Ol0000B
ooooo`;o00000oooool2o`00047ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo
00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo04Sooooo1?l0000:
ooooo`Oo00001oooool2o`000004ooooool0003o0000o`0000Kooooo0_l00003ooooo`;o00001ooo
ool2o`0000Sooooo0_l00009ooooo`;o00000_ooool3o`0000Wooooo2?l00003oooooa7o00000_oo
ool2o`0000Oooooo0_l00005ooooo`Co00001oooool@o`000003ooooool0003o0000013ooooo1?l0
0016ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9So
oooooiRHV?lQ8B401_ooool3o`0004Gooooo0_l00002ooooo`;o00002oooool4o`000003ooooool0
003o000000;ooooo0ol00002ooooo`;o00001oooool2o`000003ooooool0003o000000?ooooo0_l0
0009ooooo`;o00001_ooool2o`0000Wooooo0_l000000ooooooo0000o`000002o`0000Wooooo0_l0
0004ooooo`;o00000_ooool4o`0000;ooooo1ol000000ooooooo0000o`000002o`0000;ooooo0_l0
0002ooooo`;o00000oooool5o`0000Cooooo0_l0000;ooooo`Go000000?oooooo`000?l000001?l0
000Cooooo`Co000000?oooooo`000?l00000@oooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool02Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0@_oo
ool2o`000003ooooool0003o000000;o00005_ooool3o`0000Sooooo2?l00002ooooo`?o00002Ooo
ool2o`0000Cooooo0_l0000>ooooo`Co00004oooool4o`0000Gooooo0ol00004ooooo`Co00000ooo
ool3o`0000Cooooo1?l00005ooooo`;o00002oooool:o`0001?ooooo0_l00004ooooo`;o0000@ooo
ool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08
ooooo`03o`000?oooooooooo04;ooooo0_l000000ooooooo0000o`000002o`0000Sooooo0_l0000=
ooooo`Co00001_ooool6o`0000;ooooo1?l00003ooooo`;o00000oooool4o`0000Cooooo0_l0000@
ooooo`;o00002_ooool2o`0000Gooooo0ol000000ooooooo0000o`00000=ooooo`?o00000oooool2
o`0000gooooo0ol0000>ooooo`Oo00004?ooool2o`000003ooooool0003o000004Wooooo00001_oo
ooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003ooooooooo
o`15ooooo`Co00002?ooool3o`0000cooooo1?l00008ooooo`;o000000?oooooo`000?l000000ol0
0005ooooo`;o00000oooool4o`000003ooooool0003o000000oooooo0_l0000<ooooo`Co00001Ooo
ool5o`0000Oooooo0_l00005ooooo`Co000000?oooooo`000?l000000_ooool2o`0000[ooooo0_l0
0002ooooo`;o00002oooool3o`000004ooooool0003o0000o`00013ooooo1Ol00019ooooo`0000Ko
ooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000oooo
ooooool0C?ooool3o`0000?ooooo1?l00002ooooo`;o00004_ooool2o`000004ooooool0003o0000
o`0000;ooooo0_l00002ooooo`;o00002Oooool2o`0000kooooo0ol0000<ooooo`;o00002?ooool4
o`0000;ooooo0_l00002ooooo`Go00000oooool4o`000003ooooool0003o000000;ooooo0_l00000
0ooooooo0000o`00000;ooooo`;o000000?oooooo`000?l000003?ooool2o`0000gooooo0_l00000
1?oooooo0000o`000?ooool3o`0000;ooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`15
ooooo`;o00001?ooool4o`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l000002?ooool4
o`000003ooooool0003o000000;o00001_ooool2o`0000;ooooo0_l0000Cooooo`;o00001?ooool2
o`0001;ooooo1?l00007ooooo`;o00000_ooool6o`000003ooooool0003o000000?o000000Cooooo
o`000?l0003ooooo1_l0000>ooooo`;o00006oooool2o`000004ooooool0003o0000ooooo`?o0000
0_ooool2o`0004Gooooo000Looooo`03o`000?oooooooooo04Gooooo0_l000000ooooooo0000o`00
0003o`0000Wooooo0_l00003ooooo`;o00001Oooool2o`000003ooooool0003o000000;o000000?o
ooooo`000?l000008Oooool2o`0001Sooooo1?l000000ooooooo0000o`000003ooooo`_o000000?o
ooooo`000?l000001_l000000ooooooo0000o`000003o`000004ooooool0003o0000o`0000_ooooo
0_l0000Vooooo`;o0000AOooool001cooooo00?o0000ooooooooool0B?ooool4o`0000[ooooo0_l0
0002ooooo`;o000000?oooooo`000?l000000oooool2o`0001_ooooo2?l0000Nooooo`Go00000_oo
ool2o`000003ooooool0003o000000So000000?oooooo`000?l000000_l000001?oooooo0000o`00
0?ooool6o`0000?ooooo1ol00008ooooo`;o00009_ooool2o`0004Gooooo000Looooo`03o`000?oo
oooooooo04Oooooo0_l0000<ooooo`?o00000_ooool2o`000003ooooool0003o000001cooooo0_l0
0002ooooo`co00006_ooool5o`0000Gooooo0_l00002ooooo`Go00000_ooool4o`000003ooooool0
003o000000;ooooo0ol00005ooooo`[o000000?oooooo`000?l00000LOooool001cooooo00?o0000
ooooooooool0Aoooool2o`0000cooooo0ol0000Sooooo`?o00002Oooool5o`0002Oooooo0_l0000@
ooooo`;o00000oooool>o`0000Gooooo0_l0001Zooooo`007?ooool00ol0003oooooooooo`11oooo
o`;o0000<oooool3o`0000?ooooo0_l00005ooooo`?o000000Coooooo`000?l0003ooooo0_l0000i
ooooo`;o00000oooool>o`0000Gooooo0_l0000Dooooo`?o0000Doooool001cooooo00?o0000oooo
ooooool0@Oooool2o`0003;ooooo1?l0000:ooooo`?o000000Coooooo`000?l0003o00000_ooool2
o`0003Oooooo0_l00003ooooo`oo00003Oooool2o`0000Kooooo1?l000000ooooooo0000o`000004
o`00053ooooo000Looooo`03o`000?oooooooooo07Gooooo0_l000001?oooooo0000o`000?l00009
ooooo`_o0000=_ooool2o`000003ooooool0003o0000017o00002oooool2o`000003ooooool0003o
000000?ooooo1?l00004ooooo`?o0000D?ooool001cooooo00?o0000ooooooooool0@oooool2o`00
02oooooo0_l00002ooooo`?o00000_ooool2o`0000?ooooo3Ol000000ooooooo0000o`00000doooo
oaGo00003_ooool2o`0001;ooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`12ooooo`?o
0000;oooool2o`0000Oooooo0_l00002ooooo`ko000000Coooooo`000?l0003o0000<oooool2o`00
00;ooooo3_l000000ooooooo0000o`00000Cooooo`;o00003Oooool2o`0004[ooooo000Looooo`03
o`000?oooooooooo04;ooooo0_l0000^ooooo`;o00003Oooool4o`000003ooooool0003o000000So
000000Coooooo`000?l0003o0000=OoooolDo`00017ooooo0_l00002ooooo`Co00000oooool4o`00
04cooooo000Looooo`;o0000@_ooool2o`0002oooooo0_l00002ooooo`;o00001_ooool2o`000004
ooooool0003o0000o`0000;ooooo2ol000001?oooooo0000o`000?l0000doooooaCo00002?ooool2
o`0000_ooooo1?l00003ooooo`Co0000C?ooool001cooooo00?o0000ooooooooool0@Oooool2o`00
02oooooo0_l00002ooooo`;o00001_ooool2o`000003ooooool0003o000000_o000000?oooooo`00
0?l000001Ol0000cooooo`go000000?oooooo`000?l000001ol00005ooooo`;o000000?oooooo`00
0?l000003_ooool5o`0004cooooo000Looooo`03o`000?oooooooooo077ooooo0ol00002ooooo`;o
00002OoooolEo`0003?ooooo5ol00006ooooo`Co00003_ooool3o`0004kooooo000Looooo`03o`00
0?oooooooooo04?ooooo0_l0000/ooooo`?o00003OoooolDo`0003Cooooo5ol00006ooooo`;o0000
1Oooool2o`0005[ooooo000Looooo`03o`000?oooooooooo04;ooooo1Ol0000Zooooo`?o00003Ooo
ool5o`000003ooooool0003o000000co0000=OoooolFo`0000Oooooo0_l00004ooooo`;o0000F_oo
ool001cooooo00?o0000ooooooooool0@_ooool5o`0002[ooooo0_l0000>oooooaCo0000=OoooolE
o`0000Sooooo0_l0000;ooooo`Co0000DOooool001cooooo00?o0000ooooooooool0LOooool3o`00
00gooooo5ol0000coooooaCo00001?ooool2o`0000_ooooo0_l00002ooooo`Co0000DOooool001co
oooo00?o0000ooooooooool0@oooool2o`0002cooooo1Ol00007oooooa_o0000=OoooolAo`0000Go
oooo1?l00009ooooo`;o0000Eoooool001cooooo00?o0000ooooooooool0@oooool2o`0002cooooo
1Ol00006oooooaGo00000_ooool6o`0003Gooooo4Ol00006ooooo`;o0000H_ooool001cooooo00?o
0000ooooooooool0L_ooool2o`0000Sooooo1?l000000ooooooo0000o`00000?o`000003ooooool0
003o000000;ooooo0_l0000foooooa3o00004Oooool2o`0005Oooooo000Looooo`03o`000?oooooo
oooo04Kooooo0_l0000Zooooo`;o00003?oooolCo`000004ooooool0003o0000ooooo`;o00001Ooo
ool2o`0002gooooo4_l0000>ooooo`;o000000?oooooo`000?l00000Eoooool001cooooo00?o0000
ooooooooool0A_ooool2o`0002[ooooo0_l0000<oooooaWo00001Oooool2o`0002gooooo4_l00000
0ooooooo0000o`00000;ooooo`;o0000F_ooool001cooooo00?o0000ooooooooool0L_ooool2o`00
00Sooooo0_l00002oooooaWo0000=_ooool9o`0000?ooooo0ol00002ooooo`;o00002?ooool2o`00
0003ooooool0003o000005[ooooo000Looooo`03o`000?oooooooooo07;ooooo0_l00003ooooo`;o
00000oooool3o`000003ooooool0003o000001Oo0000=oooool2o`0000;ooooo2_l00002ooooo`;o
000000?oooooo`000?l000000_ooool2o`000004ooooool0003o0000ooooo`;o0000F_ooool001co
oooo00?o0000ooooooooool0Loooool2o`0000;ooooo0_l00004oooooaco0000?oooool5o`0000Ko
oooo2?l0001Nooooo`007?ooool00ol0003oooooooooo`1cooooo`;o00002_oooolJo`0003gooooo
0_l00003ooooo`?o000000?oooooo`000?l000000oooool3o`0000;ooooo0_l0001Nooooo`007?oo
ool2o`0007Cooooo0_l0000;oooooaSo0000?_ooool4o`0000;ooooo1Ol00004ooooo`;o0000H_oo
ool001cooooo00?o0000ooooooooool0B_ooool4o`0002oooooo0_l000000ooooooo0000o`00000E
o`00047ooooo0_l00003ooooo`Co0000J?ooool001cooooo00?o0000ooooooooool0B_ooool4o`00
02oooooo0_l000000ooooooo0000o`000009o`000003ooooool0003o000000Wo0000/_ooool001co
oooo00?o0000ooooooooool0B_ooool2o`000003ooooool0003o000002Kooooo0ol00007oooooaOo
0000/oooool001cooooo00?o0000ooooooooool0COooool2o`0002Kooooo0ol00006oooooaSo0000
1Oooool2o`000:cooooo000Looooo`03o`000?oooooooooo07Kooooo0_l00006ooooo`;o00000_oo
oolAo`0000Sooooo0_l0002/ooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o00008oooool3
o`0000Oooooo0_l000000ooooooo0000o`00000?o`000;Gooooo000Looooo`03o`000?oooooooooo
057ooooo0ol0000Sooooo`?o00001_ooool2o`000003ooooool0003o000000oo0000]Oooool001co
oooo00?o0000ooooooooool0D_ooool2o`0002?ooooo1?l00005ooooo`;o00000oooool:o`0000;o
oooo0ol0002eooooo`007?ooool00ol0003oooooooooo`1gooooo`Co000000Coooooo`000?l0003o
oooo0ol00003ooooo`ko0000]_ooool001cooooo00?o0000ooooooooool0EOooool2o`00027ooooo
0_l00002ooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo2?l0002hooooo`007?oo
ool00ol0003oooooooooo`1Cooooo`Co00008Oooool2o`0000Gooooo0_l00004ooooo`;o00001?oo
ool2o`000004ooooool0003o0000o`0005cooooo0_l0001Jooooo`007?ooool00ol0003ooooooooo
o`1Cooooo`;o00000_ooool2o`00023ooooo0_l00009ooooo`Ko00003?ooool2o`0005Gooooo0_l0
001Jooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00000_ooool2o`00023ooooo0ol00008
ooooo`Ko000000?oooooo`000?l000002Oooool2o`00053ooooo0_l0001Oooooo`007?ooool00ol0
003oooooooooo`1Fooooo`;o000000?oooooo`000?l000007_ooool3o`0000;ooooo0_l00007oooo
o`Ko00001Oooool2o`0004_ooooo0_l00007ooooo`?o000000?oooooo`000?l00000Foooool001co
oooo00?o0000ooooooooool0E_ooool2o`000003ooooool0003o000001oooooo0_l00002ooooo`;o
00002_ooool6o`0000;ooooo0_l00015ooooo`;o00001?ooool4o`0000Kooooo0_l000000ooooooo
0000o`00001Kooooo`007?ooool2o`0007_ooooo0_l0000@ooooo`Co000000?oooooo`000?l00000
A_ooool3o`0000Gooooo0_l0001Vooooo`007?ooool00ol0003oooooooooo`1Looooo`;o00007Ooo
ool3o`0000kooooo0_l00003ooooo`;o0000Aoooool2o`0000;ooooo0_l00006ooooo`;o0000HOoo
ool001cooooo00?o0000ooooooooool0G?ooool2o`0001gooooo0ol0001Pooooo`;o00001?ooool4
o`00067ooooo000Looooo`03o`000?oooooooooo07cooooo1_l0001Rooooo`;o0000Hoooool001co
oooo00?o0000ooooooooool0O?ooool6o`00063ooooo1?l0001Sooooo`007?ooool00ol0003ooooo
ooooo`1mooooo`Go0000FOooool2o`0000Gooooo1?l0001Sooooo`007?ooool00ol0003ooooooooo
o`1nooooo`Co000000?oooooo`000?l00000E_ooool2o`0000?ooooo0_l0001Wooooo`007?ooool0
0ol0003oooooooooo`1nooooo`?o00000_ooool2o`0004cooooo0_l00008ooooo`;o00000oooool2
o`0006Oooooo000Looooo`03o`000?oooooooooo07oooooo0ol000000ooooooo0000o`000002oooo
o`;o0000B?ooool2o`0000Wooooo0ol0001Zooooo`007?ooool00ol0003oooooooooo`20ooooo`Go
00000_ooool2o`0004Kooooo0_l00004ooooo`;o00001?ooool4o`0006[ooooo000Looooo`03o`00
0?oooooooooo087ooooo1?l0001:ooooo`Go000000Coooooo`000?l0003ooooo1_l0001[ooooo`00
7?ooool00ol0003oooooooooo`21ooooo`Ko00000oooool2o`0003Oooooo1?l00009ooooo`Co0000
00Coooooo`000?l0003ooooo0ol0001^ooooo`007?ooool00ol0003oooooooooo`23ooooo`Go0000
0_ooool2o`00037ooooo0_l00003ooooo`Go00003?ooool2o`0007Cooooo000Looooo`03o`000?oo
oooooooo08Cooooo1?l0000eooooo`;o00000oooool3o`0000kooooo0_l0001dooooo`0000Kooooo
onk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Ko
oooo00?o0000ooooooooool0Q?ooool4o`0000Kooooo0ol000000ooooooo0000o`00000gooooo`;o
00002Oooool2o`00077ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44oooo
o`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`25ooooo`?o000000?ooooo
o`000?l000000oooool6o`0002_ooooo0_l0000:ooooo`?o00002?ooool2o`00077ooooo00000ooo
oooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo08Gooooo0_l000001?oooooo0000o`000?l00005ooooo`;o0000;Ooo
ool2o`0000Oooooo0_l00002ooooo`;o0000Noooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool02Oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol00028ooooo`;o00001_oo
ool2o`0000_ooooo0_l00002ooooo`?o00001_ooool2o`0000Cooooo0ol0000Booooo`;o000000Co
ooooo`000?l0003o0000O_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Ooo
ool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0ROooool4o`0000?ooooo
0_l00007ooooo`;o000000Coooooo`000?l0003o00000_ooool3o`0000Kooooo0ol00002ooooo`Co
00001?ooool2o`0000[ooooo1?l000001?oooooo0000o`000?l0001nooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0
003oooooooooo`29ooooo`Co00002?ooool2o`0000;ooooo0_l000000ooooooo0000o`000007oooo
o`;o00001?ooool2o`0000;ooooo0_l00006ooooo`;o00002_ooool7o`0000Kooooo0_l0001goooo
o`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l000001_oo
ool00ol0003oooooooooo`2;ooooo`;o00002?ooool2o`0000;ooooo0_l0000:ooooo`;o00001_oo
ool2o`0000?ooooo0_l00006ooooo`?o00001Oooool2o`0000;ooooo0ol00007ooooo`?o0000M_oo
ool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Ko
oooo00?o0000ooooooooool0S_ooool2o`0001Gooooo0_l00005ooooo`?o00000oooool3o`0000?o
oooo1Ol00005ooooo`;o00000oooool2o`0000Kooooo1?l0001fooooo`007?ooool00ol0003ooooo
ooooo`2>ooooo`Co00002oooool2o`0000;ooooo0_l00002ooooo`;o00001Oooool2o`0000Gooooo
0_l00003ooooo`;o00001_ooool5o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l00000
N?ooool001cooooo00?o0000ooooooooool0T?ooool2o`0000_ooooo0_l00002ooooo`;o00000_oo
ool2o`0000;ooooo0ol00003ooooo`;o00002oooool6o`000003ooooool0003o000000;ooooo0_l0
0003ooooo`?o0000N_ooool001cooooo00?o0000ooooooooool0U?ooool3o`0000;ooooo0_l0000:
ooooo`;o00000_ooool4o`0000;ooooo1?l00007ooooo`Ko00001_ooool3o`0000Cooooo0_l0001j
ooooo`007?ooool00ol0003oooooooooo`2Dooooo`Oo00000_ooool4o`0000[ooooo0_l00004oooo
o`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000;o00001Oooool2o`00
087ooooo000Looooo`03o`000?oooooooooo09Oooooo1Ol000000ooooooo0000o`000002o`00013o
oooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000001?l00028ooooo`00
7?ooool00ol0003oooooooooo`2Hooooo`Co00000oooool2o`0000Cooooo0_l00005ooooo`?o0000
00Goooooo`000?l0003o0000ooooo`02o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`00
0004ooooool0003o0000o`0008Gooooo000Looooo`03o`000?oooooooooo0:Gooooo0_l00005oooo
o`?o000000Coooooo`000?l0003ooooo0ol000000ooooooo0000o`000005ooooo`;o000000Cooooo
o`000?l0003o0000QOooool001cooooo00?o0000ooooooooool0/?ooool2o`000005ooooool0003o
0000o`000?ooool01?l00003ooooo`;o0000ROooool001cooooo00?o0000ooooooooool0]?ooool2
o`0000?ooooo0_l0002>ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooo
oom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o
0000ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Co
oooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo
000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomB
ooooo`004_ooool00omEEEGoIVIVo`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo002Uooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05_oo
ool4o`000007oa0@4?oooooooooooa0@4?l0003oA4A4olc<c004ooooo`Go0000T?ooool00:Kooooo
00Go0000ooooooooooooooooo`000009ooooo`Ko00003?ooool00ol0003oooooooooo`04ooooo`03
oiRHV?l@413ogMgM00?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A02@ooooo`00Y_ooool01Ol0003o
oooooooooooooooo000001_ooooo00?o0000ooooooooool01Oooool00on7QhOoEEEEooooo`03oooo
o`03oiRHV?lQ8B7ok^k^097ooooo002Vooooo`05o`000?ooooooooooooooool000002Oooool6o`00
00cooooo00?o0000ooooooooool00_ooool01Oo<c<co8B4Qo`000?mEEEGo000000Gooooo00?oV9RH
ob4Q8Oo^k^h0T?ooool00:Kooooo00Go0000ohN7QoooooooZJVYo`00000Kooooo`03o`000?oooooo
oooo00;ooooo00Go8B4QohN7QoooooooV9RHo`000006ooooo`03ogMgMomVIVKooooo08oooooo002U
ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool06Oooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`2>ooooo`00a_ooool0
0ol0003oooooooooo`02ooooo`05ob4Q8OnHV9SoooooogMgMomEEED00oooool01Ol0003o^[Zjoooo
oonHV9So410@093ooooo0034ooooo`03oeEEEOmVIVKo000000Cooooo00Goc<c<oa0@4?l0003o<S8b
onk^kP03ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0T?ooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(198) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.43102 .34755 Mdot
.38777 .36382 Mdot
.41822 .70702 Mdot
.58417 .44344 Mdot
.60678 .66349 Mdot
.39599 .70378 Mdot
.28681 .54515 Mdot
.27718 .53157 Mdot
.42791 .64355 Mdot
.57293 .31228 Mdot
.29992 .51497 Mdot
.58355 .45727 Mdot
.29133 .53575 Mdot
.59719 .41664 Mdot
.65104 .56002 Mdot
.66148 .34254 Mdot
.37361 .34532 Mdot
.64263 .71647 Mdot
.66581 .33663 Mdot
.42345 .63531 Mdot
.59061 .63886 Mdot
.59661 .40058 Mdot
.37182 .38872 Mdot
.59535 .41628 Mdot
.65221 .34257 Mdot
.38706 .37054 Mdot
.42946 .34644 Mdot
.65405 .32405 Mdot
.5673 .44321 Mdot
.26362 .51913 Mdot
.64754 .32193 Mdot
.74224 .61172 Mdot
.55546 .60083 Mdot
.52507 .29126 Mdot
.2598 .53621 Mdot
.34076 .54091 Mdot
.42303 .68465 Mdot
.25686 .52791 Mdot
.32835 .53677 Mdot
.28667 .51816 Mdot
.27828 .51973 Mdot
.3795 .37239 Mdot
.25638 .54125 Mdot
.19415 .59865 Mdot
.58664 .42212 Mdot
.52644 .19667 Mdot
.38349 .7292 Mdot
.59455 .4512 Mdot
.36476 .38804 Mdot
.44489 .66463 Mdot
.67836 .62958 Mdot
.29332 .52383 Mdot
.55464 .57452 Mdot
.4818 .15416 Mdot
.28216 .53552 Mdot
.65736 .34142 Mdot
.38801 .68205 Mdot
.57232 .41172 Mdot
.61199 .44459 Mdot
.51849 .26014 Mdot
.5658 .41268 Mdot
.62739 .65721 Mdot
.45662 .37762 Mdot
.43239 .70417 Mdot
.4344 .65069 Mdot
.25393 .53354 Mdot
.38708 .33584 Mdot
.28703 .55963 Mdot
.58579 .44561 Mdot
.40805 .64066 Mdot
.55221 .41077 Mdot
.29875 .51473 Mdot
.4077 .3377 Mdot
.60585 .39462 Mdot
.43447 .3378 Mdot
.31833 .51029 Mdot
.61674 .7012 Mdot
.40464 .38783 Mdot
.44452 .6916 Mdot
.64142 .51329 Mdot
.60146 .39468 Mdot
.17475 .43708 Mdot
.7084 .55593 Mdot
.41761 .35699 Mdot
.60082 .37229 Mdot
.2145 .37563 Mdot
.55378 .3902 Mdot
.64007 .34326 Mdot
.65042 .33119 Mdot
.58949 .51437 Mdot
.38502 .68111 Mdot
.3653 .38362 Mdot
.59026 .40218 Mdot
.6047 .43692 Mdot
.56925 .30755 Mdot
.55572 .41317 Mdot
.65062 .33709 Mdot
.58339 .59132 Mdot
.30733 .52445 Mdot
.57233 .58688 Mdot
.35335 .58929 Mdot
.55694 .59036 Mdot
.55282 .39973 Mdot
.40528 .69177 Mdot
.41443 .33269 Mdot
.56234 .59856 Mdot
.27469 .55398 Mdot
.59132 .40604 Mdot
.3217 .48736 Mdot
.37307 .3878 Mdot
.66362 .31686 Mdot
.62565 .67639 Mdot
.49478 .61619 Mdot
.40512 .33986 Mdot
.61468 .23282 Mdot
.59694 .4347 Mdot
.58726 .38883 Mdot
.3831 .36594 Mdot
.42125 .62919 Mdot
.24364 .58974 Mdot
.37389 .35328 Mdot
.30679 .52136 Mdot
.36966 .34682 Mdot
.56996 .60385 Mdot
.42534 .63225 Mdot
.5394 .55752 Mdot
.58457 .57616 Mdot
.72103 .62603 Mdot
.56861 .43823 Mdot
.58612 .56331 Mdot
.41141 .68908 Mdot
.37621 .35402 Mdot
.30115 .53496 Mdot
.62549 .38795 Mdot
.40723 .3672 Mdot
.27991 .54208 Mdot
.64382 .70382 Mdot
.65328 .70325 Mdot
.41386 .34752 Mdot
.60446 .2323 Mdot
.25473 .54924 Mdot
.3079 .56137 Mdot
.67645 .62709 Mdot
.41661 .3537 Mdot
.64421 .6746 Mdot
.28747 .55669 Mdot
.4271 .78983 Mdot
.66508 .32466 Mdot
.7066 .64869 Mdot
.17823 .44062 Mdot
.67652 .62816 Mdot
.58793 .63279 Mdot
.63507 .67193 Mdot
.27922 .5416 Mdot
.61948 .40892 Mdot
.4036 .35133 Mdot
.40454 .36711 Mdot
.55312 .43171 Mdot
.55253 .5964 Mdot
.58842 .43255 Mdot
.57601 .58645 Mdot
.58352 .57055 Mdot
.58967 .40972 Mdot
.51467 .19878 Mdot
.40801 .37245 Mdot
.6095 .37268 Mdot
.42581 .6728 Mdot
.55148 .53315 Mdot
.26083 .54943 Mdot
.60787 .37665 Mdot
.60916 .36843 Mdot
.58064 .45792 Mdot
.31067 .56115 Mdot
.30345 .42866 Mdot
.43255 .71372 Mdot
.31337 .51915 Mdot
.35222 .59081 Mdot
.41258 .671 Mdot
.61207 .44256 Mdot
.62863 .6832 Mdot
.55968 .56565 Mdot
.61706 .40862 Mdot
.6781 .63118 Mdot
.61883 .43016 Mdot
.5105 .61287 Mdot
.51987 .61366 Mdot
.19618 .41363 Mdot
.31027 .42407 Mdot
.60101 .43572 Mdot
.64581 .35734 Mdot
.69505 .63691 Mdot
.22112 .55082 Mdot
.30513 .53824 Mdot
.38331 .65771 Mdot
.41557 .62953 Mdot
.3393 .62622 Mdot
.59927 .2567 Mdot
.64949 .2882 Mdot
.57877 .38792 Mdot
.56046 .58418 Mdot
.44184 .39082 Mdot
.63495 .66985 Mdot
.39599 .34264 Mdot
.17356 .44007 Mdot
.69048 .48392 Mdot
.66415 .30285 Mdot
.37078 .76231 Mdot
.4409 .67875 Mdot
.55046 .58957 Mdot
.64321 .68985 Mdot
.57471 .42365 Mdot
.40146 .37906 Mdot
.68804 .63243 Mdot
.53853 .58819 Mdot
.84158 .57948 Mdot
.375 .34897 Mdot
.70796 .50706 Mdot
.28471 .53753 Mdot
.40138 .66021 Mdot
.55421 .38966 Mdot
.60602 .41163 Mdot
.34526 .38111 Mdot
.62062 .41373 Mdot
.64752 .31618 Mdot
.66142 .32697 Mdot
.44474 .65461 Mdot
.35591 .58216 Mdot
.32335 .53179 Mdot
.41202 .74541 Mdot
.40805 .3402 Mdot
.51218 .18158 Mdot
.40039 .68165 Mdot
.54881 .62679 Mdot
.28804 .51443 Mdot
.64774 .70181 Mdot
.39886 .6887 Mdot
.60745 .66026 Mdot
.61527 .44086 Mdot
.41976 .66012 Mdot
.62228 .6663 Mdot
.53042 .41814 Mdot
.56344 .59771 Mdot
.69327 .72475 Mdot
.28931 .55032 Mdot
.34799 .37295 Mdot
.61777 .40658 Mdot
.55944 .57297 Mdot
.53352 .58166 Mdot
.65715 .53537 Mdot
.56554 .55522 Mdot
.5404 .58718 Mdot
.62352 .53495 Mdot
.63996 .71302 Mdot
.27383 .36362 Mdot
.65076 .31777 Mdot
.37703 .3434 Mdot
.61009 .43043 Mdot
.35205 .56602 Mdot
.28006 .54439 Mdot
.57107 .42189 Mdot
.18617 .41978 Mdot
.29478 .5544 Mdot
.57939 .4005 Mdot
.32276 .52342 Mdot
.41314 .36339 Mdot
.70024 .48079 Mdot
.40879 .33641 Mdot
.58727 .40862 Mdot
.31833 .51901 Mdot
.37976 .66461 Mdot
.3904 .36992 Mdot
.5932 .40287 Mdot
.56146 .41294 Mdot
.5585 .58125 Mdot
.66265 .32701 Mdot
.27666 .5901 Mdot
.57289 .45256 Mdot
.39797 .71641 Mdot
.55681 .42864 Mdot
.65822 .69363 Mdot
.50594 .80564 Mdot
.41699 .3509 Mdot
.56153 .55291 Mdot
.39256 .68767 Mdot
.56319 .36141 Mdot
.71276 .49255 Mdot
.58936 .42126 Mdot
.53881 .56823 Mdot
.72042 .53003 Mdot
.31306 .5491 Mdot
.6598 .31121 Mdot
.52494 .54211 Mdot
.38634 .68741 Mdot
.5571 .58845 Mdot
.5774 .38109 Mdot
.38938 .38731 Mdot
.65879 .34268 Mdot
.41131 .66311 Mdot
.36618 .3529 Mdot
.55921 .38826 Mdot
.33585 .59245 Mdot
.54571 .54065 Mdot
.31674 .54468 Mdot
.65036 .32285 Mdot
.61143 .44261 Mdot
.41107 .6407 Mdot
.37835 .37396 Mdot
.27957 .53352 Mdot
.41096 .33937 Mdot
.62812 .5855 Mdot
.7092 .51669 Mdot
.39156 .33053 Mdot
.63174 .70478 Mdot
.45127 .8268 Mdot
.30935 .52006 Mdot
.56959 .56802 Mdot
.37808 .71619 Mdot
.39792 .3861 Mdot
.40033 .69486 Mdot
.59229 .23441 Mdot
.38595 .68013 Mdot
.67226 .32707 Mdot
.38264 .66322 Mdot
.64833 .27958 Mdot
.61417 .38177 Mdot
.43843 .65899 Mdot
.58387 .59234 Mdot
.59751 .37897 Mdot
.40508 .3688 Mdot
.74998 .59955 Mdot
.56318 .28107 Mdot
.6042 .25652 Mdot
.39012 .67946 Mdot
.58698 .23071 Mdot
.66105 .32077 Mdot
.65088 .32423 Mdot
.39975 .35367 Mdot
.56823 .56808 Mdot
.63997 .65011 Mdot
.63306 .64516 Mdot
.58377 .79311 Mdot
.74062 .47449 Mdot
.62277 .23509 Mdot
.40481 .36469 Mdot
.34571 .69599 Mdot
.42564 .33305 Mdot
.53887 .58798 Mdot
.27703 .5314 Mdot
.29991 .43419 Mdot
.54867 .39945 Mdot
.55223 .62195 Mdot
.64219 .32517 Mdot
.35013 .37239 Mdot
.371 .33784 Mdot
.27854 .53323 Mdot
.60789 .25463 Mdot
.57652 .31198 Mdot
.58338 .43443 Mdot
.2725 .53511 Mdot
.53521 .58452 Mdot
.58154 .35886 Mdot
.72678 .63329 Mdot
.21927 .68112 Mdot
.58627 .41665 Mdot
.37858 .43639 Mdot
.61691 .40387 Mdot
.71515 .6286 Mdot
.5756 .41996 Mdot
.38335 .3749 Mdot
.68717 .30555 Mdot
.56297 .36961 Mdot
.38227 .77739 Mdot
.68445 .48733 Mdot
.61099 .67238 Mdot
.59844 .41203 Mdot
.59386 .43105 Mdot
.64715 .67397 Mdot
.37011 .38014 Mdot
.59 .44896 Mdot
.27937 .36142 Mdot
.59199 .39911 Mdot
.26581 .55463 Mdot
.67991 .55846 Mdot
.73984 .61158 Mdot
.65955 .32527 Mdot
.38704 .38804 Mdot
.31113 .55824 Mdot
.2655 .5239 Mdot
.55798 .55434 Mdot
.2803 .54532 Mdot
.61676 .39413 Mdot
.67904 .55752 Mdot
.38937 .33466 Mdot
.55587 .59507 Mdot
.35856 .37672 Mdot
.3795 .64108 Mdot
.29082 .54861 Mdot
.54828 .57794 Mdot
.58095 .26343 Mdot
.30275 .54825 Mdot
.37562 .59386 Mdot
.66241 .31417 Mdot
.53446 .58273 Mdot
.42982 .35252 Mdot
.40339 .64306 Mdot
.53636 .57622 Mdot
.28133 .53556 Mdot
.58755 .42265 Mdot
.65899 .33829 Mdot
.27896 .54468 Mdot
.32192 .37616 Mdot
.65132 .31532 Mdot
.59011 .39733 Mdot
.39881 .37474 Mdot
.36955 .3617 Mdot
.61186 .37412 Mdot
.61602 .4211 Mdot
.39124 .70414 Mdot
.53907 .56508 Mdot
.53883 .56353 Mdot
.58041 .56758 Mdot
.39322 .66963 Mdot
.42372 .81243 Mdot
.29816 .56375 Mdot
.74064 .60958 Mdot
.32189 .4514 Mdot
.5549 .57056 Mdot
.39407 .70713 Mdot
.60397 .4232 Mdot
.54957 .4312 Mdot
.31471 .5163 Mdot
.55551 .84403 Mdot
.54414 .4199 Mdot
.38961 .3385 Mdot
.27622 .52723 Mdot
.63408 .38284 Mdot
.34379 .61987 Mdot
.61651 .65676 Mdot
.62052 .23312 Mdot
.28043 .52558 Mdot
.3352 .33095 Mdot
.28198 .52497 Mdot
.59394 .43016 Mdot
.5766 .38296 Mdot
.34792 .3676 Mdot
.6106 .67516 Mdot
.56343 .44487 Mdot
.57916 .40551 Mdot
.35273 .72934 Mdot
.41771 .32905 Mdot
.62912 .64197 Mdot
.57911 .45211 Mdot
.58045 .59201 Mdot
.60803 .67428 Mdot
.59773 .38744 Mdot
.55495 .42773 Mdot
.59336 .58012 Mdot
.2905 .51023 Mdot
.61958 .69526 Mdot
.38612 .78194 Mdot
.37876 .346 Mdot
.24159 .57365 Mdot
.53532 .55708 Mdot
.30783 .51929 Mdot
.62862 .3419 Mdot
.5488 .58446 Mdot
.25911 .47233 Mdot
.83816 .35292 Mdot
.53981 .58136 Mdot
.39197 .71037 Mdot
.56788 .30485 Mdot
.55652 .43396 Mdot
.58926 .39727 Mdot
.64312 .65326 Mdot
.37896 .36068 Mdot
.31044 .42489 Mdot
.31674 .52057 Mdot
.61059 .40876 Mdot
.41655 .34403 Mdot
.20064 .40134 Mdot
.55531 .58429 Mdot
.61813 .67711 Mdot
.63076 .69973 Mdot
.60627 .3892 Mdot
.72998 .50999 Mdot
.39299 .37001 Mdot
.59308 .40322 Mdot
.5984 .38353 Mdot
.3762 .6836 Mdot
.4192 .35998 Mdot
.41931 .66226 Mdot
.66723 .30484 Mdot
.66285 .2644 Mdot
.35252 .55996 Mdot
.29096 .55453 Mdot
.54645 .55601 Mdot
.32344 .53315 Mdot
.39767 .72631 Mdot
.53942 .56306 Mdot
.59378 .40369 Mdot
.38847 .33461 Mdot
.59236 .40324 Mdot
.5914 .39973 Mdot
.58336 .42535 Mdot
.62451 .23388 Mdot
.43852 .70408 Mdot
.62264 .68321 Mdot
.59902 .45258 Mdot
.40404 .66458 Mdot
.33752 .64884 Mdot
.57014 .31236 Mdot
.60165 .40794 Mdot
.58526 .39103 Mdot
.42662 .37149 Mdot
.6664 .32395 Mdot
.30096 .54665 Mdot
.34743 .3695 Mdot
.55789 .38488 Mdot
.39849 .74126 Mdot
.59445 .44811 Mdot
.39389 .33058 Mdot
.28955 .56299 Mdot
.47757 .35315 Mdot
.52821 .57069 Mdot
.54452 .55431 Mdot
.53761 .57928 Mdot
.57623 .56225 Mdot
.26133 .549 Mdot
.39836 .70962 Mdot
.41116 .74773 Mdot
.56551 .46126 Mdot
.61942 .41472 Mdot
.57887 .38145 Mdot
.37399 .69823 Mdot
.58257 .5986 Mdot
.58518 .24642 Mdot
.63445 .39695 Mdot
.40281 .65451 Mdot
.58545 .58558 Mdot
.35022 .28443 Mdot
.35469 .3766 Mdot
.42421 .71845 Mdot
.26426 .52212 Mdot
.62009 .66412 Mdot
.64701 .76383 Mdot
.36033 .36642 Mdot
.43194 .39759 Mdot
.42059 .67876 Mdot
.67096 .54316 Mdot
.47937 .14996 Mdot
.40032 .69911 Mdot
.64428 .32354 Mdot
.40611 .35585 Mdot
.57467 .5971 Mdot
.7179 .53421 Mdot
.68004 .55028 Mdot
.42287 .64572 Mdot
.56161 .41715 Mdot
.41873 .62051 Mdot
.38616 .69998 Mdot
.55463 .55802 Mdot
.39106 .67827 Mdot
.31397 .55031 Mdot
.41092 .68462 Mdot
.32354 .36174 Mdot
.57608 .44198 Mdot
.48048 .15335 Mdot
.67891 .5835 Mdot
.60122 .43351 Mdot
.31216 .53858 Mdot
.30902 .59362 Mdot
.57357 .43114 Mdot
.62023 .64797 Mdot
.3936 .71067 Mdot
.36436 .60967 Mdot
.66672 .33285 Mdot
.38467 .66087 Mdot
.39286 .38663 Mdot
.35761 .58852 Mdot
.35316 .5902 Mdot
.53674 .57457 Mdot
.41452 .36 Mdot
.31665 .50879 Mdot
.30704 .522 Mdot
.55074 .53908 Mdot
.61921 .39133 Mdot
.39418 .38005 Mdot
.54003 .3897 Mdot
.512 .55282 Mdot
.59329 .39875 Mdot
.41879 .66533 Mdot
.44551 .66963 Mdot
.65993 .56823 Mdot
.39955 .67966 Mdot
.55538 .55707 Mdot
.4028 .3745 Mdot
.66688 .33444 Mdot
.37224 .35681 Mdot
.60926 .43257 Mdot
.35104 .57708 Mdot
.35953 .38193 Mdot
.54804 .62653 Mdot
.56749 .40598 Mdot
.51742 .19886 Mdot
.59275 .45449 Mdot
.59111 .39685 Mdot
.43189 .63995 Mdot
.64705 .67613 Mdot
.51513 .59935 Mdot
.34042 .62865 Mdot
.62647 .65362 Mdot
.3289 .38116 Mdot
.42357 .62959 Mdot
.64891 .69707 Mdot
.58817 .79386 Mdot
.55862 .55128 Mdot
.63082 .69427 Mdot
.60203 .37249 Mdot
.28693 .55393 Mdot
.36126 .34703 Mdot
.59905 .37829 Mdot
.65113 .26934 Mdot
.67192 .30085 Mdot
.55569 .58042 Mdot
.58897 .39464 Mdot
.59663 .43171 Mdot
.41584 .34325 Mdot
.17561 .44366 Mdot
.41199 .71653 Mdot
.57305 .58022 Mdot
.36498 .36028 Mdot
.17515 .43593 Mdot
.43513 .65454 Mdot
.65355 .69172 Mdot
.32688 .53915 Mdot
.34575 .32267 Mdot
.55677 .57651 Mdot
.28771 .5478 Mdot
.43063 .62127 Mdot
.66675 .62276 Mdot
.64804 .34947 Mdot
.41503 .69708 Mdot
.67653 .62853 Mdot
.66851 .30917 Mdot
.33692 .6336 Mdot
.22217 .54928 Mdot
.37126 .38702 Mdot
.27675 .54202 Mdot
.61537 .6765 Mdot
.40207 .33491 Mdot
.35867 .37711 Mdot
.29439 .55623 Mdot
.58656 .19156 Mdot
.71928 .52869 Mdot
.33087 .54351 Mdot
.6523 .53685 Mdot
.6705 .62403 Mdot
.55959 .57776 Mdot
.62581 .68258 Mdot
.35582 .58216 Mdot
.38005 .37209 Mdot
.30809 .43784 Mdot
.68084 .63201 Mdot
.66318 .31172 Mdot
.62211 .66288 Mdot
.2038 .40121 Mdot
.25846 .49449 Mdot
.29703 .54762 Mdot
.35167 .72633 Mdot
.63282 .65535 Mdot
.60971 .37607 Mdot
.578 .8431 Mdot
.61194 .38169 Mdot
.28442 .55618 Mdot
.64348 .32272 Mdot
.39045 .34633 Mdot
.29813 .56255 Mdot
.66081 .30375 Mdot
.57247 .45158 Mdot
.58887 .43898 Mdot
.44494 .69138 Mdot
.34639 .38003 Mdot
.53445 .55329 Mdot
.60347 .43179 Mdot
.57654 .40569 Mdot
.53676 .58977 Mdot
.73682 .61403 Mdot
.45716 .5879 Mdot
.5596 .60056 Mdot
.41621 .6532 Mdot
.55702 .59584 Mdot
.57159 .5768 Mdot
.42764 .36061 Mdot
.34239 .67178 Mdot
.53143 .57207 Mdot
.58571 .411 Mdot
.58769 .40418 Mdot
.32835 .5394 Mdot
.71987 .53058 Mdot
.67491 .54423 Mdot
.40268 .717 Mdot
.52797 .54281 Mdot
.5602 .40211 Mdot
.4162 .35931 Mdot
.6118 .63253 Mdot
.56128 .55686 Mdot
.3783 .34475 Mdot
.57146 .44236 Mdot
.37578 .68443 Mdot
.54106 .58066 Mdot
.53986 .59589 Mdot
.62528 .66721 Mdot
.32125 .55458 Mdot
.38477 .39432 Mdot
.38807 .70484 Mdot
.64197 .34955 Mdot
.52175 .55439 Mdot
.38191 .67415 Mdot
.56096 .5793 Mdot
.5643 .59518 Mdot
.41168 .36291 Mdot
.33118 .33555 Mdot
.57329 .60785 Mdot
.39623 .66841 Mdot
.19582 .63671 Mdot
.29334 .52116 Mdot
.608 .44644 Mdot
.3221 .54492 Mdot
.37465 .38793 Mdot
.72121 .62764 Mdot
.64174 .70161 Mdot
.29902 .55009 Mdot
.54219 .59098 Mdot
.35879 .37921 Mdot
.34958 .38599 Mdot
.58916 .41158 Mdot
.59808 .40312 Mdot
.38633 .73246 Mdot
.70199 .64191 Mdot
.32244 .52113 Mdot
.64401 .65649 Mdot
.41348 .71199 Mdot
.66119 .33812 Mdot
.40326 .3479 Mdot
.71637 .7155 Mdot
.60389 .45164 Mdot
.40122 .66696 Mdot
.3917 .36328 Mdot
.63706 .64931 Mdot
.62286 .68496 Mdot
.61261 .41996 Mdot
.58752 .63249 Mdot
.30109 .55298 Mdot
.3997 .37076 Mdot
.3833 .42106 Mdot
.59183 .45312 Mdot
.59898 .40768 Mdot
.66565 .31163 Mdot
.32931 .54705 Mdot
.60463 .37364 Mdot
.61205 .67739 Mdot
.40584 .34293 Mdot
.61202 .41548 Mdot
.63557 .65727 Mdot
.54583 .54664 Mdot
.54595 .58323 Mdot
.438 .65068 Mdot
.62476 .64559 Mdot
.64019 .66358 Mdot
.63066 .65199 Mdot
.29953 .43444 Mdot
.61125 .45387 Mdot
.56055 .61615 Mdot
.56126 .40992 Mdot
.66753 .62201 Mdot
.64277 .35297 Mdot
.30872 .5281 Mdot
.4127 .64105 Mdot
.58355 .43025 Mdot
.5624 .40523 Mdot
.379 .39307 Mdot
.6674 .33763 Mdot
.61099 .37441 Mdot
.39495 .34487 Mdot
.39058 .41732 Mdot
.40435 .63586 Mdot
.17883 .4392 Mdot
.628 .82628 Mdot
.62559 .40277 Mdot
.67217 .54798 Mdot
.36787 .38108 Mdot
.32757 .53937 Mdot
.65853 .538 Mdot
.31544 .55982 Mdot
.37155 .36431 Mdot
.67318 .33059 Mdot
.32206 .38101 Mdot
.6251 .65558 Mdot
.59297 .42962 Mdot
.29956 .55675 Mdot
.59068 .43127 Mdot
.30724 .55683 Mdot
.57435 .23032 Mdot
.71341 .5487 Mdot
.62348 .39936 Mdot
.55551 .41541 Mdot
.59211 .64348 Mdot
.60015 .40566 Mdot
.37123 .76529 Mdot
.3955 .35917 Mdot
.55026 .53645 Mdot
.6735 .33292 Mdot
.56321 .28292 Mdot
.58853 .39121 Mdot
.6702 .29728 Mdot
.58252 .38916 Mdot
.53937 .8421 Mdot
.61718 .43645 Mdot
.61833 .38882 Mdot
.3041 .5336 Mdot
.29795 .51594 Mdot
.36337 .39191 Mdot
.55896 .59293 Mdot
.19959 .40779 Mdot
.58048 .40079 Mdot
.43332 .69214 Mdot
.50632 .55714 Mdot
.64253 .66538 Mdot
.39995 .33946 Mdot
.83587 .33402 Mdot
.25602 .54239 Mdot
.42583 .66103 Mdot
.6452 .32522 Mdot
.4179 .65606 Mdot
.42627 .71176 Mdot
.34711 .41832 Mdot
.62482 .68198 Mdot
.60058 .44427 Mdot
.5255 .28632 Mdot
.46254 .3748 Mdot
.59144 .45303 Mdot
.41519 .62526 Mdot
.59356 .58225 Mdot
.69113 .42895 Mdot
.63748 .71471 Mdot
.63999 .67356 Mdot
.28272 .54015 Mdot
.43434 .68763 Mdot
.57238 .58159 Mdot
.64788 .69952 Mdot
.39661 .64265 Mdot
.55902 .55256 Mdot
.34665 .70701 Mdot
.39316 .37047 Mdot
.58852 .23171 Mdot
.52601 .19244 Mdot
.31848 .54057 Mdot
.33616 .64567 Mdot
.39059 .3339 Mdot
.41155 .3364 Mdot
.56534 .58561 Mdot
.40394 .65209 Mdot
.34649 .34874 Mdot
.61059 .42127 Mdot
.5583 .59548 Mdot
.61152 .39255 Mdot
.64466 .71359 Mdot
.58463 .40042 Mdot
.38999 .65099 Mdot
.30858 .53801 Mdot
.38784 .68791 Mdot
.28353 .54344 Mdot
.74444 .60605 Mdot
.57108 .4042 Mdot
.59729 .40979 Mdot
.67925 .55681 Mdot
.41811 .36943 Mdot
.52522 .29592 Mdot
.39679 .6705 Mdot
.38859 .68409 Mdot
.67216 .33476 Mdot
.36998 .34544 Mdot
.55784 .60882 Mdot
.64821 .53676 Mdot
.58485 .3877 Mdot
.39339 .35906 Mdot
.64288 .35466 Mdot
.20375 .53976 Mdot
.70496 .55896 Mdot
.4195 .37036 Mdot
.37948 .77762 Mdot
.58577 .38263 Mdot
.57418 .5744 Mdot
.58258 .56038 Mdot
.73612 .49836 Mdot
.51276 .59606 Mdot
.37507 .34836 Mdot
.57365 .5882 Mdot
.40494 .34943 Mdot
.38329 .68827 Mdot
.28852 .56421 Mdot
.39673 .35164 Mdot
.5783 .39216 Mdot
.62905 .82498 Mdot
.30063 .55874 Mdot
.59405 .42622 Mdot
.28726 .56036 Mdot
.35977 .34479 Mdot
.38182 .3536 Mdot
.55896 .55263 Mdot
.64783 .31726 Mdot
.30027 .55185 Mdot
.62022 .4088 Mdot
.35844 .43719 Mdot
.65896 .3427 Mdot
.53703 .53504 Mdot
.55829 .4067 Mdot
.56734 .44051 Mdot
.4039 .7997 Mdot
.54969 .37202 Mdot
.35276 .56775 Mdot
.32291 .56449 Mdot
.30221 .4263 Mdot
.42702 .35441 Mdot
.64943 .70959 Mdot
.36404 .39296 Mdot
.54099 .55736 Mdot
.4192 .65154 Mdot
.58583 .42617 Mdot
.56584 .55325 Mdot
.33278 .5338 Mdot
.63546 .69437 Mdot
.61882 .43014 Mdot
.41951 .69789 Mdot
.57995 .57697 Mdot
.29242 .54789 Mdot
.37548 .3725 Mdot
.38706 .34402 Mdot
.34304 .67827 Mdot
.61101 .41742 Mdot
.59616 .40309 Mdot
.26673 .55008 Mdot
.56114 .62801 Mdot
.62444 .6519 Mdot
.58388 .59251 Mdot
.27497 .55537 Mdot
.70604 .55812 Mdot
.34431 .37888 Mdot
.60049 .42796 Mdot
.68107 .56161 Mdot
.30585 .42364 Mdot
.43877 .31016 Mdot
.63593 .66699 Mdot
.71784 .49626 Mdot
.37453 .34895 Mdot
.29869 .53318 Mdot
.58246 .79505 Mdot
.66743 .31306 Mdot
.57391 .43504 Mdot
.71658 .48582 Mdot
.64877 .53458 Mdot
.64051 .33873 Mdot
.53084 .56313 Mdot
.70686 .53021 Mdot
.6687 .3396 Mdot
.64735 .34747 Mdot
.56173 .39627 Mdot
.55808 .40537 Mdot
.38842 .35657 Mdot
.60879 .25713 Mdot
.41791 .67657 Mdot
.63587 .3655 Mdot
.60415 .68901 Mdot
.65897 .31516 Mdot
.55036 .42676 Mdot
.3858 .28475 Mdot
.73618 .44442 Mdot
.40328 .3604 Mdot
.40439 .38158 Mdot
.32 .5391 Mdot
.66327 .33991 Mdot
.39875 .66807 Mdot
.593 .59168 Mdot
.40521 .6449 Mdot
.38788 .35825 Mdot
.40812 .63192 Mdot
.25157 .53504 Mdot
.4153 .69698 Mdot
.40716 .65374 Mdot
.30834 .53454 Mdot
.34628 .377 Mdot
.59106 .45508 Mdot
.30905 .53501 Mdot
.54718 .60123 Mdot
.65344 .69718 Mdot
.41663 .40714 Mdot
.56896 .59976 Mdot
.54505 .42677 Mdot
.194 .61965 Mdot
.42233 .6867 Mdot
.70428 .48063 Mdot
.35521 .38212 Mdot
.60055 .65755 Mdot
.39344 .35093 Mdot
.57225 .60876 Mdot
.63174 .66415 Mdot
.59872 .37271 Mdot
.68269 .72915 Mdot
.22459 .54991 Mdot
.57835 .36275 Mdot
.38982 .41773 Mdot
.40119 .64736 Mdot
.31287 .54646 Mdot
.26229 .59094 Mdot
.57373 .58134 Mdot
.38753 .38843 Mdot
.33169 .32774 Mdot
.53965 .56062 Mdot
.30191 .5358 Mdot
.5152 .21652 Mdot
.60538 .42761 Mdot
.32169 .54214 Mdot
.55811 .40992 Mdot
.60996 .23316 Mdot
.60115 .63038 Mdot
.58084 .56699 Mdot
.67347 .32806 Mdot
.4344 .65402 Mdot
.67289 .33306 Mdot
.63876 .26281 Mdot
.71339 .63942 Mdot
.56646 .39861 Mdot
.70895 .48128 Mdot
.39407 .72445 Mdot
.40971 .34896 Mdot
.54829 .56653 Mdot
.5587 .57945 Mdot
.6734 .32055 Mdot
.71354 .76763 Mdot
.64471 .69559 Mdot
.36744 .76011 Mdot
.5734 .40198 Mdot
.60089 .39517 Mdot
.36753 .3945 Mdot
.57292 .23262 Mdot
.58207 .59214 Mdot
.56676 .42481 Mdot
.73958 .45358 Mdot
.29069 .52807 Mdot
.55833 .3919 Mdot
.60801 .3917 Mdot
.36006 .58441 Mdot
.30207 .53303 Mdot
.37866 .6909 Mdot
.5536 .54976 Mdot
.43788 .64674 Mdot
.60728 .66552 Mdot
.70948 .50421 Mdot
.7306 .62096 Mdot
.70096 .55985 Mdot
.61494 .65232 Mdot
.66153 .3231 Mdot
.55196 .44774 Mdot
.57405 .43888 Mdot
.64171 .67909 Mdot
.26584 .5172 Mdot
.39415 .35721 Mdot
.60035 .23185 Mdot
.56032 .58147 Mdot
.64355 .34692 Mdot
.60918 .68875 Mdot
.40479 .35216 Mdot
.51343 .19982 Mdot
.38078 .36019 Mdot
.29404 .54454 Mdot
.33654 .63677 Mdot
.62916 .66091 Mdot
.39387 .35046 Mdot
.42919 .63951 Mdot
.34919 .57572 Mdot
.62139 .44423 Mdot
.25157 .53374 Mdot
.33107 .3676 Mdot
.40997 .37748 Mdot
.43227 .34316 Mdot
.67036 .3257 Mdot
.70707 .48131 Mdot
.54826 .55547 Mdot
.28478 .56135 Mdot
.43341 .66886 Mdot
.70406 .6408 Mdot
.51495 .23483 Mdot
.69886 .54144 Mdot
.58323 .37841 Mdot
.58476 .40154 Mdot
.60241 .38833 Mdot
.52847 .57806 Mdot
.54934 .44613 Mdot
.56457 .39909 Mdot
.31571 .51665 Mdot
.37974 .68346 Mdot
.57377 .40513 Mdot
.54417 .57923 Mdot
.54243 .61839 Mdot
.60068 .65978 Mdot
.62674 .23013 Mdot
.41471 .40574 Mdot
.40117 .35229 Mdot
.41019 .66422 Mdot
.42664 .62992 Mdot
.64497 .70424 Mdot
.27542 .53309 Mdot
.37761 .36113 Mdot
.53471 .84042 Mdot
.62114 .65689 Mdot
.58481 .41473 Mdot
.68001 .55783 Mdot
.73821 .46406 Mdot
.55564 .43572 Mdot
.5822 .4255 Mdot
.54533 .59185 Mdot
.40109 .66462 Mdot
.64939 .28397 Mdot
.51506 .20044 Mdot
.63518 .65824 Mdot
.65177 .67933 Mdot
.4218 .33769 Mdot
.62124 .40183 Mdot
.29814 .55622 Mdot
.7218 .5276 Mdot
.29548 .5925 Mdot
.21825 .37372 Mdot
.38699 .64153 Mdot
.59781 .44659 Mdot
.56434 .29789 Mdot
.54797 .40087 Mdot
.41478 .33287 Mdot
.33335 .33726 Mdot
.40494 .36283 Mdot
.28542 .52858 Mdot
.64935 .61164 Mdot
.27389 .52074 Mdot
.58496 .58539 Mdot
.35485 .36821 Mdot
.5527 .37463 Mdot
.38935 .68288 Mdot
.65811 .34535 Mdot
.6314 .68053 Mdot
.58285 .50852 Mdot
.55208 .56804 Mdot
.71524 .49901 Mdot
.39466 .70717 Mdot
.34237 .36769 Mdot
.65833 .34567 Mdot
.34362 .62288 Mdot
.7054 .53647 Mdot
.37102 .71098 Mdot
.56389 .5518 Mdot
.62706 .65703 Mdot
.57068 .31446 Mdot
.61723 .66138 Mdot
.29798 .55211 Mdot
.56881 .40663 Mdot
.61884 .39272 Mdot
.59265 .3942 Mdot
.59874 .37588 Mdot
.28237 .53281 Mdot
.64723 .34189 Mdot
.5654 .6056 Mdot
.57294 .55978 Mdot
.65143 .31774 Mdot
.62846 .68812 Mdot
.29841 .52254 Mdot
.38085 .67489 Mdot
.53669 .58247 Mdot
.61263 .69034 Mdot
.60855 .36102 Mdot
.56403 .40902 Mdot
.58167 .57519 Mdot
.60117 .3728 Mdot
.64852 .33786 Mdot
.41262 .6935 Mdot
.64251 .34022 Mdot
.60099 .6641 Mdot
.63061 .67508 Mdot
.28168 .54855 Mdot
.39513 .35006 Mdot
.62987 .70144 Mdot
.40994 .71113 Mdot
.56526 .37929 Mdot
.55906 .40372 Mdot
.32431 .35825 Mdot
.67957 .63191 Mdot
.60129 .65371 Mdot
.60649 .37368 Mdot
.42127 .35477 Mdot
.33637 .31941 Mdot
.57096 .4319 Mdot
.65225 .32883 Mdot
.42986 .35709 Mdot
.65109 .69922 Mdot
.27285 .53755 Mdot
.6846 .58942 Mdot
.30504 .56184 Mdot
.37537 .37356 Mdot
.57088 .58932 Mdot
.34715 .37549 Mdot
.57423 .58342 Mdot
.26686 .31781 Mdot
.56351 .39812 Mdot
.3249 .40048 Mdot
.58182 .60064 Mdot
.38963 .67816 Mdot
.39352 .66104 Mdot
.54025 .5772 Mdot
.36903 .35161 Mdot
.55386 .55701 Mdot
.6158 .66979 Mdot
.30532 .42918 Mdot
.42701 .36397 Mdot
.40603 .65356 Mdot
.42235 .68884 Mdot
.27605 .55636 Mdot
.58602 .39623 Mdot
.60053 .42857 Mdot
.4125 .70043 Mdot
.28744 .59172 Mdot
.37338 .38534 Mdot
.59583 .4038 Mdot
.55298 .59961 Mdot
.41598 .68418 Mdot
.23015 .52614 Mdot
.35083 .35128 Mdot
.67474 .32592 Mdot
.71609 .63764 Mdot
.28103 .56284 Mdot
.55308 .39351 Mdot
.64998 .33634 Mdot
.64648 .68466 Mdot
.71915 .4925 Mdot
.67493 .626 Mdot
.25441 .53922 Mdot
.54539 .55439 Mdot
.55469 .43516 Mdot
.38816 .67289 Mdot
.57995 .37135 Mdot
.83693 .40144 Mdot
.58286 .57359 Mdot
.61098 .41351 Mdot
.58621 .56886 Mdot
.37268 .3561 Mdot
.59653 .39832 Mdot
.35107 .56394 Mdot
.40935 .66834 Mdot
.60925 .41928 Mdot
.59006 .63621 Mdot
.28857 .56022 Mdot
.55156 .56861 Mdot
.62857 .65508 Mdot
.6386 .33997 Mdot
.74933 .60011 Mdot
.37426 .70035 Mdot
.62355 .68857 Mdot
.5853 .39447 Mdot
.41502 .71253 Mdot
.30196 .51668 Mdot
.54491 .56717 Mdot
.59058 .36025 Mdot
.31005 .52552 Mdot
.29637 .52734 Mdot
.62572 .66259 Mdot
.50619 .17655 Mdot
.62497 .39606 Mdot
.6014 .41735 Mdot
.50747 .19707 Mdot
.34985 .30273 Mdot
.59124 .42948 Mdot
.60556 .38302 Mdot
.28889 .55022 Mdot
.64573 .61134 Mdot
.71618 .49716 Mdot
.59048 .59233 Mdot
.3137 .54284 Mdot
.40851 .62727 Mdot
.4247 .66896 Mdot
.62139 .68975 Mdot
.39045 .36409 Mdot
.63949 .70582 Mdot
.41187 .67945 Mdot
.58731 .41367 Mdot
.27241 .54359 Mdot
.67822 .28378 Mdot
.29437 .56255 Mdot
.41055 .70899 Mdot
.39981 .33131 Mdot
.64945 .27755 Mdot
.83674 .3932 Mdot
.44996 .58502 Mdot
.33569 .63596 Mdot
.64347 .66708 Mdot
.51469 .20089 Mdot
.57803 .39595 Mdot
.6302 .26404 Mdot
.597 .4253 Mdot
.65987 .69671 Mdot
.39719 .6475 Mdot
.55882 .5525 Mdot
.57376 .58011 Mdot
.71244 .49735 Mdot
.2916 .52573 Mdot
.26147 .52791 Mdot
.56938 .59421 Mdot
.29793 .54382 Mdot
.60857 .41409 Mdot
.39598 .70256 Mdot
.28498 .30433 Mdot
.58219 .38873 Mdot
.53914 .5411 Mdot
.25589 .54915 Mdot
.37186 .33486 Mdot
.40913 .62716 Mdot
.56391 .2917 Mdot
.19125 .42037 Mdot
.3037 .54892 Mdot
.62844 .2316 Mdot
.40493 .66698 Mdot
.53725 .58342 Mdot
.41689 .71305 Mdot
.60276 .41988 Mdot
.59793 .44669 Mdot
.53472 .58623 Mdot
.5894 .38803 Mdot
.51792 .3226 Mdot
.66179 .30979 Mdot
.62349 .45013 Mdot
.56114 .41449 Mdot
.32973 .39367 Mdot
.30635 .51615 Mdot
.56886 .59344 Mdot
.62017 .53404 Mdot
.57006 .44077 Mdot
.42847 .35188 Mdot
.31265 .52966 Mdot
.18616 .44018 Mdot
.28635 .52962 Mdot
.38613 .68466 Mdot
.278 .52976 Mdot
.54997 .39683 Mdot
.36716 .3665 Mdot
.40287 .68509 Mdot
.55483 .57215 Mdot
.42999 .6581 Mdot
.60179 .4329 Mdot
.23655 .51501 Mdot
.42538 .66161 Mdot
.66507 .31154 Mdot
.3688 .36388 Mdot
.70016 .72538 Mdot
.45347 .38078 Mdot
.59177 .41668 Mdot
.59134 .42425 Mdot
.58181 .59484 Mdot
.27895 .54117 Mdot
.34084 .37087 Mdot
.35385 .73317 Mdot
.60086 .65419 Mdot
.3981 .36368 Mdot
.58549 .62871 Mdot
.67005 .54225 Mdot
.40533 .33972 Mdot
.74 .45782 Mdot
.29215 .55561 Mdot
.38136 .34514 Mdot
.51523 .54362 Mdot
.64442 .35863 Mdot
.62384 .67689 Mdot
.43408 .64176 Mdot
.66358 .53976 Mdot
.42203 .665 Mdot
.35123 .57693 Mdot
.4448 .65504 Mdot
.30634 .55119 Mdot
.58265 .63248 Mdot
.64139 .32702 Mdot
.25858 .52662 Mdot
.33026 .46622 Mdot
.41722 .67023 Mdot
.57512 .59414 Mdot
.64508 .33491 Mdot
.53641 .5929 Mdot
.57771 .58007 Mdot
.25531 .54002 Mdot
.38263 .34372 Mdot
.3797 .34066 Mdot
.56315 .54151 Mdot
.39092 .34372 Mdot
.40203 .69627 Mdot
.69376 .56633 Mdot
.58029 .26386 Mdot
.30224 .51418 Mdot
.63763 .34535 Mdot
.55113 .41026 Mdot
.38752 .65579 Mdot
.39599 .6981 Mdot
.28891 .52687 Mdot
.46476 .35334 Mdot
.5743 .57087 Mdot
.36106 .34247 Mdot
.35971 .36595 Mdot
.37466 .3534 Mdot
.36258 .38847 Mdot
.66076 .61915 Mdot
.31225 .53806 Mdot
.36781 .35338 Mdot
.58784 .37995 Mdot
.60303 .38447 Mdot
.5354 .57732 Mdot
.6483 .70968 Mdot
.6516 .32612 Mdot
.55496 .55658 Mdot
.57758 .43627 Mdot
.39167 .67756 Mdot
.50258 .56886 Mdot
.54186 .55442 Mdot
.39859 .66707 Mdot
.39375 .6706 Mdot
.54633 .55256 Mdot
.50184 .57478 Mdot
.5122 .33538 Mdot
.68036 .32464 Mdot
.36152 .42466 Mdot
.39981 .65307 Mdot
.3418 .48615 Mdot
.32429 .39815 Mdot
.61799 .39525 Mdot
.58509 .59311 Mdot
.39047 .7001 Mdot
.42457 .36799 Mdot
.6034 .40865 Mdot
.56694 .58497 Mdot
.62026 .67025 Mdot
.55094 .57241 Mdot
.5481 .59296 Mdot
.41408 .36942 Mdot
.19719 .63107 Mdot
.41646 .34443 Mdot
.44398 .68977 Mdot
.55929 .56951 Mdot
.47914 .15217 Mdot
.39661 .65115 Mdot
.30484 .43117 Mdot
.64479 .3207 Mdot
.57336 .43637 Mdot
.41151 .66452 Mdot
.39347 .38629 Mdot
.25276 .52643 Mdot
.73681 .43943 Mdot
.39351 .34929 Mdot
.53469 .55765 Mdot
.54304 .58637 Mdot
.418 .67864 Mdot
.3726 .37637 Mdot
.65039 .33537 Mdot
.38224 .34809 Mdot
.26515 .52905 Mdot
.59493 .37049 Mdot
.19873 .40944 Mdot
.57187 .58225 Mdot
.39775 .34203 Mdot
.43062 .6825 Mdot
.61183 .67801 Mdot
.61268 .38131 Mdot
.18415 .42321 Mdot
.58692 .39237 Mdot
.26139 .53907 Mdot
.50958 .57077 Mdot
.6431 .35719 Mdot
.57714 .41937 Mdot
.55194 .43557 Mdot
.28911 .50736 Mdot
.57533 .42117 Mdot
.57112 .44478 Mdot
.52182 .19784 Mdot
.41314 .34502 Mdot
.57488 .40305 Mdot
.40832 .70109 Mdot
.47962 .57476 Mdot
.61133 .39882 Mdot
.33804 .64066 Mdot
.73404 .50071 Mdot
.58226 .60335 Mdot
.55529 .53289 Mdot
.72008 .62852 Mdot
.59534 .42177 Mdot
.62089 .41134 Mdot
.59356 .37117 Mdot
.58177 .2864 Mdot
.41134 .67442 Mdot
.43817 .6621 Mdot
.61441 .68129 Mdot
.71606 .48246 Mdot
.62911 .67071 Mdot
.30336 .51694 Mdot
.66185 .30457 Mdot
.55896 .55017 Mdot
.39879 .34924 Mdot
.59461 .39363 Mdot
.4349 .6731 Mdot
.60517 .41946 Mdot
.66002 .33567 Mdot
.40687 .69363 Mdot
.3878 .69553 Mdot
.44093 .64241 Mdot
.63566 .65542 Mdot
.40355 .35643 Mdot
.61838 .3828 Mdot
.62994 .65334 Mdot
.53404 .58675 Mdot
.69609 .58954 Mdot
.40492 .35824 Mdot
.40215 .34337 Mdot
.35217 .36041 Mdot
.62047 .39214 Mdot
.60625 .3689 Mdot
.27893 .51997 Mdot
.32421 .35783 Mdot
.28724 .55803 Mdot
.41439 .66318 Mdot
.38188 .69342 Mdot
.60182 .42142 Mdot
.57876 .6292 Mdot
.6273 .68591 Mdot
.4291 .66932 Mdot
.5777 .55947 Mdot
.61506 .68939 Mdot
.61733 .41604 Mdot
.42004 .66299 Mdot
.62274 .64736 Mdot
.46482 .35261 Mdot
.22586 .40641 Mdot
.61156 .68048 Mdot
.57328 .57584 Mdot
.51573 .24227 Mdot
.70844 .6368 Mdot
.60974 .63197 Mdot
.30354 .51547 Mdot
.60546 .45083 Mdot
.5794 .56336 Mdot
.61259 .68865 Mdot
.69859 .6469 Mdot
.40902 .68607 Mdot
.57269 .5715 Mdot
.49733 .61692 Mdot
.58103 .26472 Mdot
.61024 .67653 Mdot
.39956 .34174 Mdot
.33438 .37094 Mdot
.58217 .41925 Mdot
.64821 .31756 Mdot
.30658 .51378 Mdot
.42823 .63293 Mdot
.43703 .6645 Mdot
.33722 .32786 Mdot
.7027 .55962 Mdot
.41595 .69245 Mdot
.61336 .43853 Mdot
.62039 .70239 Mdot
.58615 .38049 Mdot
.51358 .55501 Mdot
.64985 .35471 Mdot
.56725 .53863 Mdot
.61155 .67895 Mdot
.29652 .51223 Mdot
.30815 .53845 Mdot
.27974 .5386 Mdot
.41661 .68846 Mdot
.66035 .53673 Mdot
.43593 .67987 Mdot
.51337 .18069 Mdot
.64364 .69715 Mdot
.43593 .81917 Mdot
.54474 .43103 Mdot
.58157 .43936 Mdot
.64528 .35094 Mdot
.55559 .59892 Mdot
.59637 .41942 Mdot
.30694 .52322 Mdot
.42945 .64052 Mdot
.22375 .53603 Mdot
.39764 .37586 Mdot
.51606 .18478 Mdot
.39035 .68295 Mdot
.54788 .54046 Mdot
.63072 .68413 Mdot
.73416 .62627 Mdot
.65628 .68067 Mdot
.39043 .7088 Mdot
.60062 .43933 Mdot
.43508 .34621 Mdot
.54699 .84268 Mdot
.59447 .39752 Mdot
.4234 .68489 Mdot
.37317 .70894 Mdot
.63857 .36726 Mdot
.60269 .32794 Mdot
.21967 .54968 Mdot
.68542 .55955 Mdot
.62204 .64492 Mdot
.54059 .59522 Mdot
.72599 .52331 Mdot
.41311 .67799 Mdot
.42799 .64495 Mdot
.63301 .64198 Mdot
.37714 .33298 Mdot
.3544 .36349 Mdot
.42191 .41611 Mdot
.2969 .5196 Mdot
.56791 .43243 Mdot
.4198 .66752 Mdot
.39854 .3321 Mdot
.6122 .52986 Mdot
.28686 .53979 Mdot
.42719 .66263 Mdot
.59048 .38825 Mdot
.578 .41644 Mdot
.6274 .67003 Mdot
.53843 .61646 Mdot
.55362 .60173 Mdot
.30688 .43058 Mdot
.67951 .54012 Mdot
.66232 .30301 Mdot
.57371 .43495 Mdot
.38438 .38549 Mdot
.54188 .55784 Mdot
.62461 .68257 Mdot
.57759 .37314 Mdot
.64296 .27203 Mdot
.40258 .38187 Mdot
.29534 .55653 Mdot
.56074 .57554 Mdot
.707 .50306 Mdot
.58869 .38941 Mdot
.59789 .42429 Mdot
.67028 .32596 Mdot
.65477 .27759 Mdot
.41095 .64141 Mdot
.41866 .35398 Mdot
.63076 .65543 Mdot
.38071 .35561 Mdot
.34482 .68863 Mdot
.6559 .31057 Mdot
.61463 .44109 Mdot
.42519 .35474 Mdot
.37484 .36408 Mdot
.26151 .53802 Mdot
.31091 .5425 Mdot
.37041 .68108 Mdot
.60874 .38302 Mdot
.58378 .57399 Mdot
.36787 .35475 Mdot
.43235 .63856 Mdot
.62873 .66864 Mdot
.33568 .65253 Mdot
.56362 .40421 Mdot
.4166 .67422 Mdot
.54905 .56411 Mdot
.40683 .37258 Mdot
.39898 .67124 Mdot
.53758 .58414 Mdot
.65312 .69134 Mdot
.57037 .44936 Mdot
.37638 .72167 Mdot
.56562 .58942 Mdot
.60438 .37969 Mdot
.6324 .44111 Mdot
.64553 .32263 Mdot
.59175 .5896 Mdot
.38308 .65776 Mdot
.56226 .58642 Mdot
.33613 .37189 Mdot
.63689 .37134 Mdot
.43362 .64789 Mdot
.32205 .38153 Mdot
.64755 .31578 Mdot
.57389 .58618 Mdot
.40798 .34868 Mdot
.34741 .70884 Mdot
.39944 .32518 Mdot
.70255 .63169 Mdot
.60881 .40198 Mdot
.42217 .66533 Mdot
.62326 .67444 Mdot
.26164 .53032 Mdot
.29653 .47501 Mdot
.35515 .52203 Mdot
.3991 .65903 Mdot
.59598 .39273 Mdot
.37881 .34681 Mdot
.30185 .54847 Mdot
.37056 .39518 Mdot
.41925 .70804 Mdot
.40325 .70439 Mdot
.64386 .35072 Mdot
.63005 .67111 Mdot
.54893 .4444 Mdot
.43565 .64739 Mdot
.44516 .66576 Mdot
.52202 .20035 Mdot
.62041 .64597 Mdot
.67158 .32424 Mdot
.56368 .54092 Mdot
.55959 .39106 Mdot
.51159 .20035 Mdot
.54873 .59081 Mdot
.39479 .37717 Mdot
.58434 .43179 Mdot
.25634 .7146 Mdot
.39113 .65606 Mdot
.68574 .55934 Mdot
.22482 .54885 Mdot
.30299 .5288 Mdot
.40645 .67214 Mdot
.60374 .40282 Mdot
.33503 .64888 Mdot
.62179 .6909 Mdot
.67406 .33331 Mdot
.57316 .59168 Mdot
.33945 .32077 Mdot
.27062 .54039 Mdot
.50307 .61015 Mdot
.26284 .5288 Mdot
.28092 .54644 Mdot
.462 .35828 Mdot
.58283 .41826 Mdot
.39378 .68267 Mdot
.41394 .70344 Mdot
.53874 .53774 Mdot
.44447 .69727 Mdot
.34999 .37164 Mdot
.24972 .70579 Mdot
.64394 .27572 Mdot
.56912 .40258 Mdot
.53126 .56214 Mdot
.58346 .58828 Mdot
.33626 .63674 Mdot
.57778 .42432 Mdot
.41192 .35118 Mdot
.43721 .64799 Mdot
.42352 .67249 Mdot
.66453 .31191 Mdot
.30861 .5387 Mdot
.65077 .66663 Mdot
.39825 .69647 Mdot
.68223 .58761 Mdot
.61132 .41387 Mdot
.24618 .53611 Mdot
.39898 .69474 Mdot
.66311 .79217 Mdot
.19796 .64543 Mdot
.41269 .3387 Mdot
.56766 .45004 Mdot
.35044 .35209 Mdot
.61143 .67284 Mdot
.43199 .70098 Mdot
.26033 .52621 Mdot
.55726 .57014 Mdot
.22602 .57332 Mdot
.42102 .67653 Mdot
.38918 .358 Mdot
.586 .42078 Mdot
.63369 .23363 Mdot
.58202 .3898 Mdot
.64277 .60971 Mdot
.60208 .64888 Mdot
.29312 .47528 Mdot
.2692 .55258 Mdot
.56824 .4506 Mdot
.62931 .65135 Mdot
.39283 .71272 Mdot
.40848 .69186 Mdot
.17947 .43122 Mdot
.54678 .59198 Mdot
.42273 .71383 Mdot
.60605 .38034 Mdot
.44169 .64588 Mdot
.51471 .23465 Mdot
.30303 .52995 Mdot
.5562 .40731 Mdot
.42033 .65673 Mdot
.37965 .32742 Mdot
.67948 .55428 Mdot
.61149 .40641 Mdot
.58534 .56551 Mdot
.30745 .5473 Mdot
.51762 .18331 Mdot
.39561 .64754 Mdot
.5718 .38913 Mdot
.31292 .52524 Mdot
.58352 .63198 Mdot
.2232 .52868 Mdot
.40415 .35661 Mdot
.42272 .68971 Mdot
.27219 .53693 Mdot
.55979 .56452 Mdot
.62058 .64923 Mdot
.40431 .71443 Mdot
.42114 .65375 Mdot
.661 .32662 Mdot
.55859 .54182 Mdot
.58369 .62833 Mdot
.36746 .38363 Mdot
.29096 .55271 Mdot
.66328 .33174 Mdot
.69339 .59356 Mdot
.59281 .36669 Mdot
.28545 .55268 Mdot
.48976 .15836 Mdot
.59645 .44368 Mdot
.56185 .41008 Mdot
.64106 .23994 Mdot
.33928 .36382 Mdot
.37349 .3884 Mdot
.70192 .53942 Mdot
.65434 .32639 Mdot
.54885 .3783 Mdot
.39942 .35531 Mdot
.38549 .35992 Mdot
.54992 .37735 Mdot
.66001 .33048 Mdot
.43591 .40967 Mdot
.30162 .54531 Mdot
.30575 .53062 Mdot
.37425 .35442 Mdot
.64539 .35148 Mdot
.32761 .53831 Mdot
.41228 .30346 Mdot
.40564 .70822 Mdot
.72899 .51106 Mdot
.37422 .35952 Mdot
.67687 .55766 Mdot
.29737 .55228 Mdot
.73589 .58565 Mdot
.73572 .49577 Mdot
.62453 .3892 Mdot
.57984 .42025 Mdot
.64456 .67192 Mdot
.55144 .57018 Mdot
.54556 .5526 Mdot
.27919 .5383 Mdot
.54981 .44691 Mdot
.40351 .36415 Mdot
.55167 .39233 Mdot
.70363 .64223 Mdot
.74809 .58111 Mdot
.64938 .29467 Mdot
.38872 .36359 Mdot
.38368 .37134 Mdot
.38115 .69555 Mdot
.41604 .62732 Mdot
.62445 .40769 Mdot
.30876 .54448 Mdot
.38912 .34062 Mdot
.27887 .55171 Mdot
.41263 .67979 Mdot
.39078 .68603 Mdot
.53645 .56446 Mdot
.57188 .56973 Mdot
.40581 .67851 Mdot
.33788 .64041 Mdot
.69411 .59278 Mdot
.32846 .34593 Mdot
.51492 .17507 Mdot
.74132 .61167 Mdot
.60728 .2327 Mdot
.6213 .6725 Mdot
.50358 .56558 Mdot
.30947 .52327 Mdot
.56167 .44739 Mdot
.58478 .4353 Mdot
.55484 .58429 Mdot
.32057 .53766 Mdot
.63943 .69029 Mdot
.30249 .52907 Mdot
.62125 .65009 Mdot
.43448 .65539 Mdot
.59949 .39337 Mdot
.60027 .43656 Mdot
.26216 .5362 Mdot
.38299 .7011 Mdot
.41915 .65874 Mdot
.62112 .67721 Mdot
.73415 .61911 Mdot
.41727 .67821 Mdot
.37439 .36035 Mdot
.31828 .29001 Mdot
.54631 .58777 Mdot
.60283 .40779 Mdot
.7219 .62896 Mdot
.63651 .37165 Mdot
.53298 .58451 Mdot
.56091 .57643 Mdot
.50507 .17689 Mdot
.61204 .41961 Mdot
.1783 .44424 Mdot
.54033 .55597 Mdot
.34683 .37503 Mdot
.39744 .67917 Mdot
.5309 .56768 Mdot
.57953 .55317 Mdot
.59888 .62949 Mdot
.5292 .5697 Mdot
.35676 .36248 Mdot
.3442 .35983 Mdot
.64471 .33279 Mdot
.52476 .16664 Mdot
.62748 .65584 Mdot
.6331 .69283 Mdot
.4113 .64336 Mdot
.35133 .57803 Mdot
.55546 .46737 Mdot
.63435 .69622 Mdot
.42359 .40553 Mdot
.64695 .34878 Mdot
.64026 .33835 Mdot
.64977 .32043 Mdot
.34548 .38256 Mdot
.6235 .36808 Mdot
.40304 .64496 Mdot
.39131 .35824 Mdot
.64217 .34149 Mdot
.5686 .37521 Mdot
.40585 .35992 Mdot
.28491 .54766 Mdot
.65477 .30398 Mdot
.38581 .34516 Mdot
.73732 .43741 Mdot
.30096 .55449 Mdot
.63463 .34634 Mdot
.4919 .82286 Mdot
.6852 .78238 Mdot
.29885 .52918 Mdot
.4274 .66553 Mdot
.41825 .66768 Mdot
.41133 .69341 Mdot
.36783 .38662 Mdot
.38201 .68122 Mdot
.37729 .37822 Mdot
.33721 .62989 Mdot
.714 .48972 Mdot
.63051 .66228 Mdot
.43648 .70957 Mdot
.37618 .35302 Mdot
.5118 .19095 Mdot
.8382 .34985 Mdot
.57537 .38642 Mdot
.25781 .5287 Mdot
.6327 .70065 Mdot
.68614 .56474 Mdot
.64636 .68386 Mdot
.40574 .66645 Mdot
.70992 .50081 Mdot
.60724 .41855 Mdot
.2121 .42009 Mdot
.625 .67528 Mdot
.38378 .35986 Mdot
.66189 .32018 Mdot
.37801 .66601 Mdot
.61961 .68657 Mdot
.63085 .67689 Mdot
.59805 .41664 Mdot
.34245 .36817 Mdot
.4099 .66235 Mdot
.3182 .54419 Mdot
.38052 .6078 Mdot
.57008 .49903 Mdot
.61464 .41498 Mdot
.5596 .4151 Mdot
.67344 .54659 Mdot
.33616 .65245 Mdot
.30395 .54114 Mdot
.68921 .63629 Mdot
.38639 .6563 Mdot
.70863 .64189 Mdot
.40233 .32769 Mdot
.43489 .7114 Mdot
.55015 .59085 Mdot
.5355 .57977 Mdot
.59415 .40405 Mdot
.83795 .37456 Mdot
.60285 .33414 Mdot
.32684 .53479 Mdot
.54942 .58548 Mdot
.38048 .69926 Mdot
.36863 .38979 Mdot
.49417 .61892 Mdot
.65001 .32961 Mdot
.31782 .54586 Mdot
.4129 .68677 Mdot
.8565 .42754 Mdot
.64448 .66683 Mdot
.6912 .56008 Mdot
.59993 .38275 Mdot
.59597 .40732 Mdot
.28634 .53506 Mdot
.27663 .51308 Mdot
.52488 .18992 Mdot
.65858 .68049 Mdot
.20046 .40268 Mdot
.33102 .52539 Mdot
.86572 .44235 Mdot
.58428 .58249 Mdot
.38832 .3731 Mdot
.54957 .55136 Mdot
.28407 .51143 Mdot
.58807 .43127 Mdot
.34085 .36673 Mdot
.54421 .56562 Mdot
.43771 .39396 Mdot
.63978 .33711 Mdot
.6859 .58898 Mdot
.58423 .4025 Mdot
.36067 .34954 Mdot
.3975 .35791 Mdot
.37743 .33632 Mdot
.53875 .57817 Mdot
.56622 .42401 Mdot
.57245 .39024 Mdot
.56072 .41775 Mdot
.5282 .19427 Mdot
.5988 .39666 Mdot
.43396 .33789 Mdot
.70933 .54977 Mdot
.2689 .7292 Mdot
.59812 .43755 Mdot
.27488 .53596 Mdot
.58993 .40279 Mdot
.63476 .6518 Mdot
.56482 .44576 Mdot
.63839 .33812 Mdot
.29966 .54082 Mdot
.64078 .26407 Mdot
.60283 .68563 Mdot
.61452 .41885 Mdot
.61622 .65094 Mdot
.29247 .43951 Mdot
.68525 .6315 Mdot
.51533 .21762 Mdot
.38098 .34952 Mdot
.42523 .7046 Mdot
.31116 .51453 Mdot
.38651 .68418 Mdot
.68281 .30447 Mdot
.56498 .55432 Mdot
.42344 .81231 Mdot
.70617 .59388 Mdot
.5863 .43148 Mdot
.5793 .59626 Mdot
.41047 .34646 Mdot
.39499 .65195 Mdot
.5752 .23182 Mdot
.64604 .35032 Mdot
.64839 .70416 Mdot
.64995 .68927 Mdot
.51879 .55741 Mdot
.37595 .33514 Mdot
.51312 .23062 Mdot
.28818 .53538 Mdot
.41901 .68463 Mdot
.60545 .67577 Mdot
.40326 .4145 Mdot
.2614 .51921 Mdot
.33853 .62911 Mdot
.27028 .53808 Mdot
.58305 .44167 Mdot
.53668 .55749 Mdot
.34535 .4307 Mdot
.55959 .59142 Mdot
.57036 .37579 Mdot
.41971 .65397 Mdot
.54803 .59134 Mdot
.63915 .66572 Mdot
.27498 .54079 Mdot
.39069 .68011 Mdot
.59076 .4219 Mdot
.40287 .35318 Mdot
.69104 .42185 Mdot
.38572 .72799 Mdot
.65219 .31249 Mdot
.65242 .31225 Mdot
.32706 .33642 Mdot
.5916 .59402 Mdot
.26601 .48203 Mdot
.63835 .37147 Mdot
.35597 .54837 Mdot
.54318 .62108 Mdot
.3654 .75708 Mdot
.43446 .6848 Mdot
.40363 .68702 Mdot
.60097 .43055 Mdot
.43473 .63911 Mdot
.61315 .44075 Mdot
.38971 .64898 Mdot
.30346 .42187 Mdot
.57734 .36309 Mdot
.40445 .69357 Mdot
.55074 .55431 Mdot
.61024 .38033 Mdot
.41422 .34937 Mdot
.43748 .68223 Mdot
.62452 .38863 Mdot
.37586 .76917 Mdot
.26152 .53706 Mdot
.53807 .57823 Mdot
.63458 .53773 Mdot
.29558 .54729 Mdot
.35317 .37078 Mdot
.59845 .4546 Mdot
.63089 .69677 Mdot
.3785 .37356 Mdot
.52355 .58229 Mdot
.63143 .6727 Mdot
.69514 .56732 Mdot
.36233 .36891 Mdot
.55005 .58941 Mdot
.65217 .69249 Mdot
.54537 .53277 Mdot
.40583 .68756 Mdot
.37491 .71458 Mdot
.56793 .58786 Mdot
.60508 .42172 Mdot
.37691 .69059 Mdot
.28614 .52616 Mdot
.60964 .39201 Mdot
.4214 .66791 Mdot
.5437 .577 Mdot
.58365 .38517 Mdot
.65397 .3256 Mdot
.51631 .19871 Mdot
.5843 .603 Mdot
.63376 .66236 Mdot
.38682 .33356 Mdot
.56695 .39329 Mdot
.62165 .65403 Mdot
.39381 .72324 Mdot
.575 .38343 Mdot
.39545 .33743 Mdot
.47152 .36604 Mdot
.42604 .63004 Mdot
.30313 .55708 Mdot
.41754 .7021 Mdot
.60794 .66121 Mdot
.83772 .33953 Mdot
.54231 .55596 Mdot
.66663 .34373 Mdot
.56059 .43601 Mdot
.42933 .70081 Mdot
.40027 .35918 Mdot
.2082 .38601 Mdot
.56849 .4489 Mdot
.57973 .38122 Mdot
.60084 .4109 Mdot
.36348 .60992 Mdot
.35875 .38401 Mdot
.6022 .40959 Mdot
.51593 .60021 Mdot
.55784 .41638 Mdot
.61383 .67342 Mdot
.4537 .82383 Mdot
.53855 .58903 Mdot
.47439 .14939 Mdot
.54187 .56697 Mdot
.40297 .69841 Mdot
.73757 .43659 Mdot
.63223 .53641 Mdot
.37996 .64082 Mdot
.35238 .37186 Mdot
.35943 .42393 Mdot
.39168 .68726 Mdot
.34653 .7041 Mdot
.64757 .33437 Mdot
.66054 .32254 Mdot
.61428 .38614 Mdot
.4055 .66665 Mdot
.42376 .63622 Mdot
.56975 .55863 Mdot
.57546 .5978 Mdot
.63369 .39929 Mdot
.43357 .67312 Mdot
.60022 .39515 Mdot
.63974 .35898 Mdot
.26021 .51962 Mdot
.41046 .33905 Mdot
.26305 .52279 Mdot
.25559 .52504 Mdot
.59915 .23257 Mdot
.67825 .53899 Mdot
.29853 .5197 Mdot
.31495 .52089 Mdot
.35 .61493 Mdot
.59521 .25548 Mdot
.61284 .66868 Mdot
.59939 .33483 Mdot
.38405 .69575 Mdot
.56593 .42108 Mdot
.35635 .3837 Mdot
.56834 .60894 Mdot
.22785 .35773 Mdot
.81763 .53262 Mdot
.65447 .3435 Mdot
.38153 .66727 Mdot
.56696 .58986 Mdot
.56766 .59418 Mdot
.70811 .63775 Mdot
.60053 .3984 Mdot
.42797 .63204 Mdot
.58165 .26341 Mdot
.32921 .52092 Mdot
.33602 .64428 Mdot
.36133 .34185 Mdot
.59048 .40017 Mdot
.37749 .38439 Mdot
.3077 .55905 Mdot
.6198 .65835 Mdot
.6402 .662 Mdot
.61407 .42084 Mdot
.64175 .32672 Mdot
.35688 .54402 Mdot
.65655 .32111 Mdot
.65786 .33553 Mdot
.56227 .58487 Mdot
.67163 .32029 Mdot
.57095 .38896 Mdot
.60177 .35854 Mdot
.53482 .58838 Mdot
.26041 .52225 Mdot
.57994 .24786 Mdot
.57341 .58782 Mdot
.58661 .45737 Mdot
.30529 .55981 Mdot
.65344 .32325 Mdot
.28462 .52991 Mdot
.33703 .65373 Mdot
.28404 .51953 Mdot
.63337 .65837 Mdot
.43585 .62728 Mdot
.52071 .18168 Mdot
.38121 .34597 Mdot
.31142 .53739 Mdot
.65358 .69232 Mdot
.28055 .52977 Mdot
.38768 .70278 Mdot
.3115 .50772 Mdot
.36305 .29875 Mdot
.68066 .5858 Mdot
.61486 .23594 Mdot
.32771 .5203 Mdot
.42277 .62956 Mdot
.37354 .35427 Mdot
.35122 .5686 Mdot
.5783 .45236 Mdot
.64241 .66257 Mdot
.59388 .40585 Mdot
.27725 .54345 Mdot
.37938 .68347 Mdot
.51323 .21615 Mdot
.63513 .66227 Mdot
.51209 .177 Mdot
.43344 .67843 Mdot
.58087 .44695 Mdot
.28863 .56424 Mdot
.30981 .4755 Mdot
.26591 .54829 Mdot
.72053 .48992 Mdot
.58115 .56743 Mdot
.66464 .69798 Mdot
.37219 .37197 Mdot
.58603 .58364 Mdot
.76649 .67998 Mdot
.32084 .44916 Mdot
.41436 .36069 Mdot
.41719 .71996 Mdot
.61183 .41535 Mdot
.67307 .32272 Mdot
.56253 .56074 Mdot
.37517 .34196 Mdot
.66997 .32624 Mdot
.53494 .57045 Mdot
.7121 .54493 Mdot
.36832 .33892 Mdot
.40092 .71648 Mdot
.60859 .38203 Mdot
.25625 .54252 Mdot
.29609 .56236 Mdot
.54009 .55296 Mdot
.26482 .52546 Mdot
.59037 .45804 Mdot
.36632 .36512 Mdot
.64587 .33128 Mdot
.61341 .67805 Mdot
.38189 .43455 Mdot
.549 .60405 Mdot
.63858 .71767 Mdot
.59234 .37795 Mdot
.39215 .68473 Mdot
.22409 .57291 Mdot
.5497 .42446 Mdot
.39548 .35608 Mdot
.56813 .44325 Mdot
.67103 .32276 Mdot
.65881 .3216 Mdot
.41904 .68427 Mdot
.67787 .55471 Mdot
.59912 .39513 Mdot
.31454 .55077 Mdot
.55702 .36861 Mdot
.54683 .43522 Mdot
.66036 .69073 Mdot
.63802 .33957 Mdot
.30893 .56526 Mdot
.33024 .33554 Mdot
.39483 .68266 Mdot
.39859 .36748 Mdot
.4328 .36362 Mdot
.35394 .3715 Mdot
.35528 .33642 Mdot
.6381 .37293 Mdot
.17481 .43769 Mdot
.51448 .23332 Mdot
.61897 .23243 Mdot
.4277 .36504 Mdot
.20671 .58109 Mdot
.41549 .3594 Mdot
.35297 .37114 Mdot
.27754 .30866 Mdot
.35082 .37453 Mdot
.60143 .42263 Mdot
.5701 .4411 Mdot
.64516 .28021 Mdot
.38302 .60724 Mdot
.58009 .39017 Mdot
.53041 .582 Mdot
.63631 .70241 Mdot
.38588 .33089 Mdot
.55825 .5727 Mdot
.68613 .56649 Mdot
.53672 .55155 Mdot
.59743 .41724 Mdot
.59937 .38796 Mdot
.65436 .31789 Mdot
.75812 .57806 Mdot
.39972 .60704 Mdot
.35059 .35936 Mdot
.54749 .43913 Mdot
.22655 .5234 Mdot
.61135 .38722 Mdot
.55749 .43585 Mdot
.62244 .36708 Mdot
.39371 .6827 Mdot
.35835 .39001 Mdot
.57667 .57381 Mdot
.373 .43698 Mdot
.58433 .39487 Mdot
.55732 .61159 Mdot
.6275 .70383 Mdot
.60451 .40373 Mdot
.34557 .36759 Mdot
.67055 .32406 Mdot
.40333 .38017 Mdot
.36389 .37149 Mdot
.57674 .38276 Mdot
.38605 .33157 Mdot
.38292 .38797 Mdot
.66006 .32346 Mdot
.37747 .67631 Mdot
.30532 .4303 Mdot
.60682 .41696 Mdot
.63799 .66781 Mdot
.57994 .42492 Mdot
.61166 .66813 Mdot
.52992 .56894 Mdot
.56302 .58795 Mdot
.57209 .316 Mdot
.4299 .64683 Mdot
.65497 .70281 Mdot
.44489 .65207 Mdot
.56596 .46523 Mdot
.42865 .40081 Mdot
.30073 .50661 Mdot
.39446 .73911 Mdot
.56111 .58636 Mdot
.65115 .61209 Mdot
.53194 .4081 Mdot
.27775 .51966 Mdot
.41958 .36191 Mdot
.56756 .25758 Mdot
.58482 .59133 Mdot
.39917 .71648 Mdot
.41118 .70443 Mdot
.32324 .45352 Mdot
.28484 .30453 Mdot
.59946 .43615 Mdot
.58307 .59409 Mdot
.63056 .43937 Mdot
.55035 .56976 Mdot
.57098 .56113 Mdot
.42357 .6544 Mdot
.58384 .38626 Mdot
.7159 .54323 Mdot
.41582 .67011 Mdot
.63223 .68815 Mdot
.39247 .37823 Mdot
.62103 .652 Mdot
.2402 .39225 Mdot
.52426 .18806 Mdot
.40859 .67575 Mdot
.54531 .59565 Mdot
.56454 .41145 Mdot
.34201 .37047 Mdot
.37308 .39487 Mdot
.41499 .34638 Mdot
.61983 .69196 Mdot
.4371 .65236 Mdot
.37883 .77616 Mdot
.58606 .41884 Mdot
.37699 .36422 Mdot
.61271 .69692 Mdot
.57706 .41606 Mdot
.30968 .54132 Mdot
.6679 .32823 Mdot
.37874 .35907 Mdot
.66032 .34801 Mdot
.37099 .37218 Mdot
.40793 .70286 Mdot
.61059 .42645 Mdot
.61633 .40038 Mdot
.68177 .63058 Mdot
.64019 .69043 Mdot
.41342 .3757 Mdot
.66862 .53554 Mdot
.55967 .39087 Mdot
.71309 .63412 Mdot
.60505 .39427 Mdot
.61798 .23637 Mdot
.57122 .54893 Mdot
.53405 .56817 Mdot
.56421 .44051 Mdot
.60803 .41279 Mdot
.36902 .39449 Mdot
.51598 .2354 Mdot
.52828 .19275 Mdot
.30187 .5589 Mdot
.41741 .35475 Mdot
.41368 .66775 Mdot
.43839 .68291 Mdot
.38362 .68429 Mdot
.60641 .66761 Mdot
.64941 .3273 Mdot
.59188 .43576 Mdot
.32489 .54359 Mdot
.63961 .69934 Mdot
.38394 .36686 Mdot
.62594 .66312 Mdot
.67925 .54588 Mdot
.64114 .67223 Mdot
.55384 .55011 Mdot
.19337 .61991 Mdot
.63935 .35929 Mdot
.63579 .67967 Mdot
.4073 .33806 Mdot
.56522 .36007 Mdot
.61936 .37335 Mdot
.51432 .19064 Mdot
.6465 .70462 Mdot
.40933 .72433 Mdot
.59704 .37825 Mdot
.70644 .48014 Mdot
.28143 .53379 Mdot
.62364 .65034 Mdot
.2693 .53695 Mdot
.65948 .33836 Mdot
.3418 .4123 Mdot
.38968 .35377 Mdot
.26243 .5157 Mdot
.55619 .42952 Mdot
.62415 .65032 Mdot
.40729 .68041 Mdot
.59399 .25675 Mdot
.34144 .62054 Mdot
.57391 .61553 Mdot
.70453 .63529 Mdot
.4063 .64318 Mdot
.61261 .25183 Mdot
.26954 .52655 Mdot
.54676 .4039 Mdot
.64865 .35453 Mdot
.569 .38246 Mdot
.41555 .65947 Mdot
.40287 .68726 Mdot
.36007 .74725 Mdot
.61787 .4069 Mdot
.62199 .36835 Mdot
.34294 .31574 Mdot
.43652 .64884 Mdot
.35489 .37182 Mdot
.3674 .34464 Mdot
.42672 .66491 Mdot
.42132 .36744 Mdot
.63073 .67446 Mdot
.70693 .52383 Mdot
.27124 .52546 Mdot
.28501 .56123 Mdot
.40659 .67687 Mdot
.41073 .64904 Mdot
.39152 .68454 Mdot
.66531 .33479 Mdot
.36028 .37118 Mdot
.61139 .43625 Mdot
.58884 .40781 Mdot
.61145 .37186 Mdot
.35018 .35076 Mdot
.57144 .4507 Mdot
.55787 .37541 Mdot
.62378 .69834 Mdot
.39983 .69805 Mdot
.28298 .55454 Mdot
.69053 .42749 Mdot
.31467 .55261 Mdot
.55795 .40627 Mdot
.30719 .42423 Mdot
.4171 .36505 Mdot
.64619 .6794 Mdot
.64225 .3284 Mdot
.63895 .66346 Mdot
.26006 .5196 Mdot
.34676 .31462 Mdot
.6996 .56349 Mdot
.6105 .43403 Mdot
.67252 .54235 Mdot
.5833 .79415 Mdot
.44071 .33958 Mdot
.2916 .55129 Mdot
.63687 .35702 Mdot
.54098 .54819 Mdot
.63586 .40966 Mdot
.59787 .43222 Mdot
.54476 .42901 Mdot
.69889 .47947 Mdot
.55844 .42487 Mdot
.41012 .33632 Mdot
.56113 .36879 Mdot
.55678 .60075 Mdot
.60661 .37431 Mdot
.18325 .43903 Mdot
.57554 .39734 Mdot
.6146 .42453 Mdot
.5786 .43579 Mdot
.55338 .39892 Mdot
.34738 .35109 Mdot
.6461 .32589 Mdot
.31082 .55555 Mdot
.70765 .52401 Mdot
.27402 .52466 Mdot
.40334 .67385 Mdot
.57699 .6069 Mdot
.33662 .37639 Mdot
.63978 .66435 Mdot
.39556 .5841 Mdot
.71024 .48096 Mdot
.38132 .69609 Mdot
.6691 .62536 Mdot
.64759 .65977 Mdot
.56439 .55769 Mdot
.60887 .6564 Mdot
.42005 .65596 Mdot
.30672 .53518 Mdot
.59959 .4403 Mdot
.36118 .36136 Mdot
.3889 .34302 Mdot
.60466 .37483 Mdot
.30287 .43697 Mdot
.29286 .56185 Mdot
.43987 .70522 Mdot
.592 .43916 Mdot
.55625 .40681 Mdot
.39386 .38323 Mdot
.38493 .66559 Mdot
.5332 .40763 Mdot
.61955 .68059 Mdot
.60869 .38565 Mdot
.56372 .60012 Mdot
.67794 .54537 Mdot
.30419 .55783 Mdot
.54383 .58178 Mdot
.56785 .4116 Mdot
.68736 .54397 Mdot
.67253 .33446 Mdot
.51259 .59305 Mdot
.41014 .63082 Mdot
.57975 .3815 Mdot
.61509 .39523 Mdot
.36565 .34017 Mdot
.2682 .52654 Mdot
.4026 .35754 Mdot
.33874 .31064 Mdot
.5624 .58756 Mdot
.26295 .54339 Mdot
.55462 .39709 Mdot
.33114 .54396 Mdot
.66726 .32677 Mdot
.59056 .41593 Mdot
.28979 .54995 Mdot
.36615 .3764 Mdot
.2036 .40121 Mdot
.57854 .24829 Mdot
.65955 .33639 Mdot
.57793 .42323 Mdot
.38356 .60756 Mdot
.56751 .60904 Mdot
.59657 .44729 Mdot
.38841 .3413 Mdot
.57847 .41614 Mdot
.32595 .5275 Mdot
.62388 .65817 Mdot
.3969 .35314 Mdot
.38992 .6548 Mdot
.41305 .69815 Mdot
.41648 .62605 Mdot
.55791 .55117 Mdot
.67139 .32006 Mdot
.38388 .33448 Mdot
.3747 .33966 Mdot
.65426 .53536 Mdot
.4029 .69805 Mdot
.62077 .66834 Mdot
.61586 .38468 Mdot
.58001 .59732 Mdot
.27141 .55873 Mdot
.47144 .14817 Mdot
.7009 .55935 Mdot
.60791 .68343 Mdot
.5702 .49979 Mdot
.55939 .58189 Mdot
.5621 .41354 Mdot
.62547 .65122 Mdot
.4254 .66517 Mdot
.67634 .32459 Mdot
.53015 .61535 Mdot
.40793 .72589 Mdot
.39327 .66269 Mdot
.32896 .54645 Mdot
.39822 .64109 Mdot
.62221 .64776 Mdot
.54341 .55481 Mdot
.39451 .3467 Mdot
.60354 .40045 Mdot
.57109 .57942 Mdot
.39658 .70262 Mdot
.58209 .57721 Mdot
.58419 .44366 Mdot
.39584 .38111 Mdot
.38498 .69224 Mdot
.59766 .42106 Mdot
.63932 .36638 Mdot
.51733 .19913 Mdot
.37939 .67345 Mdot
.6065 .44814 Mdot
.49907 .61746 Mdot
.39138 .66885 Mdot
.4159 .65694 Mdot
.57356 .38388 Mdot
.64174 .65443 Mdot
.58612 .39738 Mdot
.30772 .53976 Mdot
.67167 .5498 Mdot
.26205 .53671 Mdot
.71019 .64058 Mdot
.59649 .37475 Mdot
.62302 .44146 Mdot
.43485 .39696 Mdot
.62792 .71803 Mdot
.74055 .61418 Mdot
.56674 .39548 Mdot
.37807 .39086 Mdot
.67597 .55648 Mdot
.67445 .58094 Mdot
.38494 .29762 Mdot
.61402 .66 Mdot
.27913 .53739 Mdot
.61601 .40732 Mdot
.19096 .43679 Mdot
.61535 .6696 Mdot
.70946 .63816 Mdot
.56458 .45059 Mdot
.3882 .3615 Mdot
.59982 .43436 Mdot
.38891 .34924 Mdot
.57168 .41958 Mdot
.51343 .20864 Mdot
.35668 .54384 Mdot
.71989 .48957 Mdot
.55281 .55489 Mdot
.30965 .47547 Mdot
.6153 .23545 Mdot
.62755 .67258 Mdot
.65012 .35313 Mdot
.55415 .58093 Mdot
.30195 .52875 Mdot
.24111 .57265 Mdot
.39071 .68716 Mdot
.31658 .54318 Mdot
.39288 .37315 Mdot
.37959 .70049 Mdot
.58524 .58074 Mdot
.61354 .4569 Mdot
.62846 .64978 Mdot
.26319 .54418 Mdot
.60736 .40538 Mdot
.57933 .37019 Mdot
.36179 .61026 Mdot
.46565 .82663 Mdot
.4253 .33857 Mdot
.51197 .17283 Mdot
.3462 .31471 Mdot
.63611 .69214 Mdot
.3768 .68123 Mdot
.58483 .43344 Mdot
.58879 .3865 Mdot
.39437 .66003 Mdot
.34159 .37146 Mdot
.65579 .69119 Mdot
.6646 .70068 Mdot
.32724 .53585 Mdot
.51592 .83579 Mdot
.39685 .35146 Mdot
.5134 .83591 Mdot
.36829 .76089 Mdot
.30243 .29615 Mdot
.73678 .61755 Mdot
.29884 .54548 Mdot
.51495 .83622 Mdot
.38329 .36294 Mdot
.56685 .43523 Mdot
.55301 .58858 Mdot
.56691 .55522 Mdot
.38646 .3829 Mdot
.40166 .66978 Mdot
.63905 .65017 Mdot
.60382 .42898 Mdot
.50272 .57738 Mdot
.37051 .39523 Mdot
.43526 .6553 Mdot
.55388 .56606 Mdot
.28883 .55714 Mdot
.57696 .41886 Mdot
.62302 .69601 Mdot
.29838 .54406 Mdot
.53581 .58194 Mdot
.70957 .50353 Mdot
.59903 .45436 Mdot
.64567 .31997 Mdot
.28394 .53281 Mdot
.57211 .49946 Mdot
.61189 .39287 Mdot
.26941 .52667 Mdot
.54399 .54076 Mdot
.2842 .47255 Mdot
.53342 .44063 Mdot
.32084 .44922 Mdot
.38562 .71391 Mdot
.38482 .65534 Mdot
.44764 .7265 Mdot
.42456 .61489 Mdot
.29247 .52117 Mdot
.56606 .57788 Mdot
.44482 .82364 Mdot
.26575 .52865 Mdot
.55271 .43189 Mdot
.61439 .4113 Mdot
.58043 .26393 Mdot
.53747 .58661 Mdot
.54139 .56443 Mdot
.32321 .39458 Mdot
.63904 .34878 Mdot
.55547 .56713 Mdot
.607 .39138 Mdot
.34608 .35869 Mdot
.29835 .55344 Mdot
.8442 .57606 Mdot
.30196 .51182 Mdot
.67582 .3118 Mdot
.38258 .69349 Mdot
.38358 .71214 Mdot
.60312 .40336 Mdot
.45712 .59356 Mdot
.86347 .43661 Mdot
.61484 .41056 Mdot
.64156 .33004 Mdot
.70799 .64212 Mdot
.6049 .37356 Mdot
.42242 .34564 Mdot
.54955 .59524 Mdot
.35556 .34872 Mdot
.29387 .54537 Mdot
.61404 .66075 Mdot
.59955 .67926 Mdot
.27993 .53754 Mdot
.58123 .3935 Mdot
.53643 .59534 Mdot
.59724 .40873 Mdot
.57078 .4356 Mdot
.68736 .54778 Mdot
.60827 .68088 Mdot
.39421 .67773 Mdot
.63734 .66029 Mdot
.35166 .37238 Mdot
.49663 .16195 Mdot
.62592 .66889 Mdot
.59433 .25608 Mdot
.66681 .54109 Mdot
.45199 .82242 Mdot
.39085 .34319 Mdot
.61113 .67281 Mdot
.27719 .53618 Mdot
.64795 .55693 Mdot
.61774 .25936 Mdot
.317 .54606 Mdot
.57146 .43403 Mdot
.35736 .35004 Mdot
.3297 .33207 Mdot
.30027 .56419 Mdot
.40625 .34649 Mdot
.54091 .46172 Mdot
.65388 .33874 Mdot
.31038 .55673 Mdot
.74862 .59564 Mdot
.26879 .55234 Mdot
.58958 .23363 Mdot
.66527 .32621 Mdot
.39587 .35486 Mdot
.62948 .23115 Mdot
.35209 .31148 Mdot
.53702 .56548 Mdot
.57945 .44917 Mdot
.62329 .66977 Mdot
.66049 .53661 Mdot
.38356 .6621 Mdot
.37927 .32779 Mdot
.37674 .35534 Mdot
.27151 .55994 Mdot
.40469 .34643 Mdot
.4198 .36446 Mdot
.26104 .51669 Mdot
.41729 .35752 Mdot
.58434 .3942 Mdot
.52743 .16787 Mdot
.41135 .34593 Mdot
.2904 .53741 Mdot
.62245 .69294 Mdot
.41177 .3385 Mdot
.34855 .71631 Mdot
.60773 .38095 Mdot
.42009 .70655 Mdot
.61636 .63431 Mdot
.34662 .35301 Mdot
.62584 .6735 Mdot
.39286 .70169 Mdot
.64758 .70859 Mdot
.32327 .56442 Mdot
.31891 .56431 Mdot
.582 .5563 Mdot
.32733 .46052 Mdot
.35108 .37432 Mdot
.37778 .69691 Mdot
.61988 .39455 Mdot
.58407 .4407 Mdot
.6037 .64216 Mdot
.40648 .38053 Mdot
.29735 .43689 Mdot
.55792 .57127 Mdot
.38536 .43405 Mdot
.29804 .56095 Mdot
.438 .7077 Mdot
.70038 .56506 Mdot
.34645 .59125 Mdot
.55534 .60068 Mdot
.55816 .58254 Mdot
.60134 .41106 Mdot
.68848 .63434 Mdot
.61917 .64982 Mdot
.20876 .59025 Mdot
.65836 .34428 Mdot
.39838 .65406 Mdot
.5697 .42343 Mdot
.64266 .3436 Mdot
.56857 .39131 Mdot
.60552 .67823 Mdot
.3178 .53126 Mdot
.38312 .34439 Mdot
.6107 .66931 Mdot
.41385 .69771 Mdot
.73989 .45693 Mdot
.59944 .4462 Mdot
.61409 .44049 Mdot
.39593 .66862 Mdot
.35221 .36644 Mdot
.40165 .68057 Mdot
.27127 .52565 Mdot
.62729 .66647 Mdot
.66946 .32807 Mdot
.53815 .58764 Mdot
.43053 .69941 Mdot
.31137 .53553 Mdot
.37635 .67855 Mdot
.3323 .53223 Mdot
.55902 .58568 Mdot
.61468 .44342 Mdot
.43118 .63356 Mdot
.57672 .59298 Mdot
.5249 .28696 Mdot
.70652 .50261 Mdot
.34971 .28497 Mdot
.40243 .66715 Mdot
.37286 .6501 Mdot
.29566 .54143 Mdot
.28177 .51331 Mdot
.58889 .23055 Mdot
.83767 .37939 Mdot
.54848 .37893 Mdot
.2834 .45103 Mdot
.27216 .52477 Mdot
.29146 .53088 Mdot
.39875 .68128 Mdot
.36759 .37793 Mdot
.44717 .38761 Mdot
.39006 .71047 Mdot
.72384 .62451 Mdot
.38357 .3668 Mdot
.64398 .27796 Mdot
.43748 .6707 Mdot
.66025 .31926 Mdot
.51237 .21606 Mdot
.62878 .7027 Mdot
.69954 .63356 Mdot
.30732 .50731 Mdot
.59667 .42625 Mdot
.17503 .43504 Mdot
.39216 .68979 Mdot
.58135 .58243 Mdot
.2315 .52089 Mdot
.56937 .37507 Mdot
.56768 .42332 Mdot
.58099 .4061 Mdot
.61722 .64169 Mdot
.51553 .2498 Mdot
.59196 .42997 Mdot
.71244 .49592 Mdot
.66957 .30582 Mdot
.37945 .72328 Mdot
.63607 .65959 Mdot
.66 .62049 Mdot
.34448 .67211 Mdot
.36769 .43836 Mdot
.54467 .43006 Mdot
.30652 .51586 Mdot
.63942 .346 Mdot
.28712 .55012 Mdot
.31504 .56 Mdot
.53765 .84064 Mdot
.384 .34053 Mdot
.66036 .34161 Mdot
.42809 .65088 Mdot
.44672 .38918 Mdot
.6445 .33987 Mdot
.50254 .16572 Mdot
.25025 .53705 Mdot
.83728 .33533 Mdot
.27835 .51505 Mdot
.57812 .56731 Mdot
.40145 .37073 Mdot
.37946 .39205 Mdot
.67358 .54156 Mdot
.35652 .37315 Mdot
.41971 .61253 Mdot
.38859 .33387 Mdot
.66739 .7639 Mdot
.37156 .29839 Mdot
.29799 .5377 Mdot
.29317 .56501 Mdot
.65096 .32242 Mdot
.58932 .39264 Mdot
.71398 .54471 Mdot
.55709 .57059 Mdot
.58826 .45477 Mdot
.41628 .66999 Mdot
.35413 .73409 Mdot
.20164 .54493 Mdot
.41695 .36056 Mdot
.30755 .52916 Mdot
.56869 .42439 Mdot
.6649 .32888 Mdot
.57215 .44299 Mdot
.35512 .57939 Mdot
.66751 .27103 Mdot
.59036 .40869 Mdot
.65053 .32522 Mdot
.38551 .70476 Mdot
.36301 .61077 Mdot
.29015 .30195 Mdot
.52776 .83816 Mdot
.58257 .38499 Mdot
.63806 .69594 Mdot
.60583 .67346 Mdot
.60942 .35517 Mdot
.52856 .49413 Mdot
.5862 .51143 Mdot
.60761 .4064 Mdot
.73943 .45065 Mdot
.40435 .71722 Mdot
.54194 .54886 Mdot
.39892 .70206 Mdot
.42851 .36974 Mdot
.53425 .55971 Mdot
.42048 .66504 Mdot
.73072 .50819 Mdot
.56735 .58606 Mdot
.2711 .47865 Mdot
.61295 .67774 Mdot
.60884 .39135 Mdot
.55997 .23817 Mdot
.43717 .64946 Mdot
.3046 .53712 Mdot
.40978 .36327 Mdot
.3044 .55672 Mdot
.43028 .62075 Mdot
.71785 .6335 Mdot
.53642 .57123 Mdot
.31 .51641 Mdot
.63811 .33606 Mdot
.64057 .69767 Mdot
.2699 .51914 Mdot
.6704 .31013 Mdot
.60012 .35678 Mdot
.84589 .41921 Mdot
.62281 .39854 Mdot
.3563 .73925 Mdot
.261 .53444 Mdot
.53929 .54871 Mdot
.60251 .39961 Mdot
.43058 .68681 Mdot
.55215 .53228 Mdot
.59668 .41082 Mdot
.3993 .64612 Mdot
.61366 .40741 Mdot
.62861 .65341 Mdot
.36069 .34371 Mdot
.67677 .56059 Mdot
.65545 .72717 Mdot
.6129 .66318 Mdot
.70958 .47768 Mdot
.58676 .4504 Mdot
.44339 .61357 Mdot
.39225 .36157 Mdot
.55797 .40803 Mdot
.68133 .72733 Mdot
.38389 .3794 Mdot
.39337 .36963 Mdot
.67727 .31736 Mdot
.32335 .52167 Mdot
.39491 .67376 Mdot
.64656 .68811 Mdot
.33637 .63995 Mdot
.59514 .42491 Mdot
.65474 .35022 Mdot
.61338 .66985 Mdot
.30631 .54739 Mdot
.65873 .34085 Mdot
.24935 .48083 Mdot
.70781 .5203 Mdot
.2576 .5266 Mdot
.54468 .42409 Mdot
.66625 .26386 Mdot
.34482 .37996 Mdot
.17594 .43775 Mdot
.35669 .54283 Mdot
.41236 .70225 Mdot
.55687 .56625 Mdot
.4765 .15142 Mdot
.61889 .691 Mdot
.46116 .37245 Mdot
.5843 .44259 Mdot
.57952 .43089 Mdot
.34254 .36359 Mdot
.61557 .42755 Mdot
.41797 .36183 Mdot
.34799 .71255 Mdot
.83823 .36946 Mdot
.38935 .34564 Mdot
.383 .35585 Mdot
.6538 .30326 Mdot
.44052 .64068 Mdot
.39585 .37739 Mdot
.61748 .39936 Mdot
.42976 .62013 Mdot
.50663 .57598 Mdot
.65476 .69508 Mdot
.62477 .64133 Mdot
.42538 .34622 Mdot
.62167 .25858 Mdot
.66572 .31179 Mdot
.56743 .30498 Mdot
.58935 .51743 Mdot
.2911 .52041 Mdot
.59287 .36819 Mdot
.5577 .57529 Mdot
.39347 .69835 Mdot
.62277 .37516 Mdot
.60618 .38932 Mdot
.37681 .34648 Mdot
.64156 .70785 Mdot
.26661 .53473 Mdot
.57764 .59075 Mdot
.41419 .62445 Mdot
.62623 .68453 Mdot
.42052 .36724 Mdot
.60832 .23369 Mdot
.55202 .60419 Mdot
.57916 .59672 Mdot
.56135 .4096 Mdot
.57474 .38424 Mdot
.55244 .60163 Mdot
.28178 .53944 Mdot
.41354 .70287 Mdot
.57599 .57385 Mdot
.64248 .53561 Mdot
.72062 .53424 Mdot
.56652 .39966 Mdot
.40152 .33776 Mdot
.30446 .52893 Mdot
.53879 .56636 Mdot
.43827 .82054 Mdot
.61301 .37945 Mdot
.64713 .27642 Mdot
.65717 .66803 Mdot
.56177 .57762 Mdot
.44765 .38732 Mdot
.64448 .67115 Mdot
.66502 .32677 Mdot
.71537 .49409 Mdot
.57811 .4544 Mdot
.54651 .40495 Mdot
.42466 .66188 Mdot
.275 .54422 Mdot
.5858 .5628 Mdot
.39922 .69704 Mdot
.39688 .36827 Mdot
.56993 .3079 Mdot
.36356 .34817 Mdot
.37945 .33814 Mdot
.35898 .33568 Mdot
.29899 .55898 Mdot
.47605 .15052 Mdot
.55805 .60451 Mdot
.60352 .4342 Mdot
.30775 .52282 Mdot
.40335 .37483 Mdot
.5666 .4489 Mdot
.41727 .36467 Mdot
.41507 .37532 Mdot
.58109 .45546 Mdot
.65431 .32504 Mdot
.71518 .48809 Mdot
.64581 .26821 Mdot
.63932 .65909 Mdot
.34563 .37443 Mdot
.6339 .26621 Mdot
.58623 .43218 Mdot
.59791 .388 Mdot
.64959 .32267 Mdot
.60988 .6622 Mdot
.57036 .31577 Mdot
.5809 .44138 Mdot
.6891 .6388 Mdot
.56139 .44445 Mdot
.40553 .38142 Mdot
.29524 .47504 Mdot
.67541 .31081 Mdot
.38186 .70291 Mdot
.34117 .37044 Mdot
.629 .70322 Mdot
.33013 .37686 Mdot
.63576 .36973 Mdot
.28353 .52782 Mdot
.3789 .35903 Mdot
.39544 .71221 Mdot
.30492 .54052 Mdot
.26923 .55258 Mdot
.64997 .32077 Mdot
.42168 .69462 Mdot
.64044 .708 Mdot
.27133 .54943 Mdot
.63763 .4022 Mdot
.29942 .53744 Mdot
.4487 .32526 Mdot
.61708 .43681 Mdot
.71361 .49684 Mdot
.56496 .56456 Mdot
.57374 .55013 Mdot
.2642 .5415 Mdot
.61843 .6802 Mdot
.65848 .34133 Mdot
.41529 .34901 Mdot
.62881 .69489 Mdot
.51372 .21971 Mdot
.38298 .71059 Mdot
.33063 .33139 Mdot
.33982 .62498 Mdot
.36281 .38172 Mdot
.70234 .63416 Mdot
.61853 .69685 Mdot
.58223 .59835 Mdot
.68667 .5594 Mdot
.54972 .56567 Mdot
.62426 .38053 Mdot
.65781 .3423 Mdot
.58275 .39522 Mdot
.3819 .69268 Mdot
.61925 .64227 Mdot
.40921 .34224 Mdot
.51579 .61626 Mdot
.30516 .5521 Mdot
.59257 .35495 Mdot
.57932 .57761 Mdot
.66123 .33576 Mdot
.41033 .36951 Mdot
.37828 .38894 Mdot
.51644 .238 Mdot
.38927 .67121 Mdot
.56305 .62832 Mdot
.56736 .39996 Mdot
.49646 .59741 Mdot
.2635 .54116 Mdot
.32173 .45013 Mdot
.41542 .71225 Mdot
.83546 .33297 Mdot
.40231 .69604 Mdot
.52398 .60646 Mdot
.37258 .38677 Mdot
.63665 .6698 Mdot
.58172 .39069 Mdot
.36437 .33981 Mdot
.45073 .3846 Mdot
.59999 .63158 Mdot
.64077 .66679 Mdot
.35191 .56496 Mdot
.29587 .51893 Mdot
.57603 .59603 Mdot
.55901 .4421 Mdot
.56866 .45137 Mdot
.61992 .39906 Mdot
.30638 .52574 Mdot
.65356 .33333 Mdot
.30769 .47707 Mdot
.63659 .36031 Mdot
.68221 .72711 Mdot
.4127 .65455 Mdot
.25985 .7191 Mdot
.34874 .35271 Mdot
.57065 .31298 Mdot
.47002 .35679 Mdot
.70584 .50641 Mdot
.32029 .53198 Mdot
.54171 .54112 Mdot
.39722 .6777 Mdot
.24485 .58188 Mdot
.41454 .6532 Mdot
.86457 .51524 Mdot
.5791 .26383 Mdot
.28925 .47479 Mdot
.58359 .45326 Mdot
.42974 .66645 Mdot
.62731 .25708 Mdot
.57525 .57431 Mdot
.53556 .59437 Mdot
.65283 .35544 Mdot
.52652 .1935 Mdot
.63763 .65731 Mdot
.57938 .3916 Mdot
.35401 .35057 Mdot
.58415 .38917 Mdot
.58244 .38922 Mdot
.57849 .44311 Mdot
.25539 .52046 Mdot
.61298 .4448 Mdot
.5872 .3931 Mdot
.38465 .78356 Mdot
.52588 .54248 Mdot
.39963 .63905 Mdot
.3655 .39334 Mdot
.63972 .69932 Mdot
.42769 .37058 Mdot
.68102 .5606 Mdot
.27858 .51303 Mdot
.51503 .24105 Mdot
.65971 .3281 Mdot
.40515 .32831 Mdot
.30087 .51246 Mdot
.64752 .6621 Mdot
.55612 .57767 Mdot
.23303 .3509 Mdot
.44484 .65128 Mdot
.54458 .57409 Mdot
.39194 .6543 Mdot
.62972 .42659 Mdot
.39702 .34762 Mdot
.5504 .56632 Mdot
.26916 .5415 Mdot
.42254 .65332 Mdot
.71142 .48014 Mdot
.58187 .41643 Mdot
.40617 .66416 Mdot
.56902 .57777 Mdot
.66156 .53699 Mdot
.67577 .55513 Mdot
.43011 .66403 Mdot
.32458 .54811 Mdot
.27781 .55659 Mdot
.63366 .69993 Mdot
.36564 .38848 Mdot
.35696 .36362 Mdot
.3028 .5517 Mdot
.25502 .58923 Mdot
.59755 .4224 Mdot
.5886 .41701 Mdot
.69285 .56488 Mdot
.55346 .41728 Mdot
.41066 .6096 Mdot
.54641 .57264 Mdot
.36772 .35602 Mdot
.65713 .34273 Mdot
.6479 .3485 Mdot
.57645 .39466 Mdot
.72671 .62599 Mdot
.38426 .69487 Mdot
.66286 .31167 Mdot
.6247 .65091 Mdot
.52254 .20023 Mdot
.61116 .38516 Mdot
.64544 .72342 Mdot
.36808 .38729 Mdot
.22055 .53198 Mdot
.30369 .5357 Mdot
.42919 .64859 Mdot
.42875 .65017 Mdot
.58714 .79355 Mdot
.34666 .35539 Mdot
.54476 .57285 Mdot
.40481 .72709 Mdot
.54908 .55085 Mdot
.64259 .67156 Mdot
.52867 .43113 Mdot
.41337 .61054 Mdot
.39935 .63948 Mdot
.33995 .54423 Mdot
.56755 .3785 Mdot
.60755 .38471 Mdot
.31763 .44318 Mdot
.60397 .39309 Mdot
.62208 .66399 Mdot
.28166 .51744 Mdot
.38021 .35988 Mdot
.64212 .65937 Mdot
.30032 .51413 Mdot
.35359 .37007 Mdot
.65545 .31734 Mdot
.56387 .44715 Mdot
.40289 .36679 Mdot
.41519 .3721 Mdot
.60267 .42207 Mdot
.5551 .84379 Mdot
.37767 .34789 Mdot
.407 .36662 Mdot
.52343 .19924 Mdot
.42622 .63192 Mdot
.5493 .53293 Mdot
.32237 .52246 Mdot
.58437 .39782 Mdot
.40685 .65661 Mdot
.64114 .68053 Mdot
.37297 .35753 Mdot
.57585 .38577 Mdot
.59246 .4245 Mdot
.63898 .69726 Mdot
.61619 .64715 Mdot
.62087 .68707 Mdot
.30119 .56399 Mdot
.6609 .32239 Mdot
.40116 .37342 Mdot
.3181 .53882 Mdot
.6188 .69423 Mdot
.62123 .64581 Mdot
.70489 .72183 Mdot
.60019 .42196 Mdot
.61319 .64728 Mdot
.49076 .15884 Mdot
.73401 .49826 Mdot
.54401 .55106 Mdot
.38002 .65621 Mdot
.41823 .62002 Mdot
.51193 .57306 Mdot
.27436 .54164 Mdot
.63839 .34105 Mdot
.65446 .68735 Mdot
.5729 .57779 Mdot
.58558 .4168 Mdot
.59886 .37174 Mdot
.63124 .69375 Mdot
.71803 .63555 Mdot
.37329 .34666 Mdot
.32737 .28904 Mdot
.64109 .69864 Mdot
.43237 .66647 Mdot
.40998 .71718 Mdot
.40457 .68928 Mdot
.56932 .39498 Mdot
.64899 .29228 Mdot
.56188 .49092 Mdot
.50804 .34317 Mdot
.28983 .5189 Mdot
.385 .38754 Mdot
.5206 .19468 Mdot
.38987 .37051 Mdot
.38358 .67562 Mdot
.61821 .67922 Mdot
.34499 .3627 Mdot
.28809 .56193 Mdot
.2704 .55143 Mdot
.43084 .63403 Mdot
.40441 .6984 Mdot
.40802 .67794 Mdot
.33739 .36953 Mdot
.39022 .38286 Mdot
.57745 .45209 Mdot
.39968 .33948 Mdot
.349 .71094 Mdot
.34711 .7079 Mdot
.43594 .64239 Mdot
.28741 .54056 Mdot
.36449 .37126 Mdot
.61517 .39912 Mdot
.69673 .47962 Mdot
.41935 .71543 Mdot
.64073 .70453 Mdot
.52679 .16771 Mdot
.83722 .38614 Mdot
.64406 .35377 Mdot
.28606 .52354 Mdot
.54761 .55523 Mdot
.57849 .40529 Mdot
.4104 .70467 Mdot
.56616 .61693 Mdot
.54667 .59292 Mdot
.62015 .42333 Mdot
.58575 .46242 Mdot
.29671 .52702 Mdot
.68055 .56345 Mdot
.57489 .57974 Mdot
.66632 .30337 Mdot
.29583 .51657 Mdot
.43287 .69265 Mdot
.42553 .7437 Mdot
.3294 .41351 Mdot
.62758 .58323 Mdot
.53359 .57536 Mdot
.61722 .38173 Mdot
.41926 .67162 Mdot
.64244 .65781 Mdot
.41606 .67571 Mdot
.42845 .3637 Mdot
.42614 .63026 Mdot
.61329 .40075 Mdot
.39627 .37569 Mdot
.26977 .55174 Mdot
.6404 .55451 Mdot
.5903 .63785 Mdot
.4323 .68411 Mdot
.57876 .60123 Mdot
.64095 .34791 Mdot
.61897 .45207 Mdot
.57264 .54913 Mdot
.60969 .38909 Mdot
.28972 .55047 Mdot
.4156 .36417 Mdot
.311 .54508 Mdot
.55637 .53312 Mdot
.45717 .34766 Mdot
.3031 .53416 Mdot
.64718 .29811 Mdot
.63835 .64946 Mdot
.72085 .63158 Mdot
.61028 .40872 Mdot
.2716 .54364 Mdot
.61517 .43771 Mdot
.34458 .37195 Mdot
.72527 .51957 Mdot
.70748 .5166 Mdot
.29665 .55382 Mdot
.58359 .57131 Mdot
.6653 .54058 Mdot
.54936 .53236 Mdot
.27285 .52515 Mdot
.73859 .48986 Mdot
.54739 .58162 Mdot
.62964 .68364 Mdot
.62291 .64425 Mdot
.62399 .67966 Mdot
.58843 .40989 Mdot
.65517 .25192 Mdot
.61202 .68613 Mdot
.23872 .56644 Mdot
.61958 .65898 Mdot
.51046 .56791 Mdot
.29841 .43427 Mdot
.62274 .64801 Mdot
.60757 .39935 Mdot
.63662 .35854 Mdot
.63967 .33702 Mdot
.40906 .71062 Mdot
.21834 .37087 Mdot
.38281 .78143 Mdot
.58442 .43378 Mdot
.51823 .18539 Mdot
.37278 .33776 Mdot
.58223 .60056 Mdot
.70723 .51354 Mdot
.64822 .3148 Mdot
.38478 .37361 Mdot
.68435 .56105 Mdot
.32942 .34223 Mdot
.56334 .55853 Mdot
.59069 .41336 Mdot
.34075 .36936 Mdot
.37765 .32789 Mdot
.74116 .61281 Mdot
.35882 .43736 Mdot
.3589 .37025 Mdot
.26812 .52644 Mdot
.27527 .53928 Mdot
.29177 .55201 Mdot
.40913 .6988 Mdot
.38088 .35546 Mdot
.58397 .36079 Mdot
.41017 .70286 Mdot
.57389 .43648 Mdot
.29968 .55341 Mdot
.7102 .5098 Mdot
.38285 .35661 Mdot
.60829 .40922 Mdot
.62657 .26405 Mdot
.40305 .64487 Mdot
.63692 .69673 Mdot
.51867 .17962 Mdot
.37581 .67307 Mdot
.33117 .54265 Mdot
.43193 .35862 Mdot
.52541 .54497 Mdot
.66204 .30524 Mdot
.56396 .39554 Mdot
.60026 .44069 Mdot
.66145 .30468 Mdot
.58176 .25945 Mdot
.56305 .59835 Mdot
.4136 .69773 Mdot
.42227 .63051 Mdot
.61185 .38136 Mdot
.38162 .35202 Mdot
.61313 .69573 Mdot
.65181 .71403 Mdot
.53471 .61841 Mdot
.67261 .5466 Mdot
.71232 .49631 Mdot
.55294 .40401 Mdot
.58649 .32134 Mdot
.40095 .71161 Mdot
.55126 .54801 Mdot
.67851 .54707 Mdot
.62922 .67543 Mdot
.5683 .43617 Mdot
.39929 .39161 Mdot
.3735 .35983 Mdot
.40046 .66876 Mdot
.25646 .5425 Mdot
.5481 .60265 Mdot
.43632 .64185 Mdot
.61142 .38118 Mdot
.65162 .3464 Mdot
.26518 .52533 Mdot
.42929 .35624 Mdot
.6312 .68875 Mdot
.40515 .7052 Mdot
.63388 .67034 Mdot
.40545 .34838 Mdot
.37188 .35761 Mdot
.56044 .42856 Mdot
.55113 .62655 Mdot
.43409 .68223 Mdot
.57396 .39214 Mdot
.4105 .665 Mdot
.36118 .61054 Mdot
.27541 .5608 Mdot
.55761 .41365 Mdot
.43981 .39307 Mdot
.29737 .55603 Mdot
.57874 .43418 Mdot
.64417 .32764 Mdot
.65828 .3407 Mdot
.43056 .66813 Mdot
.65678 .7017 Mdot
.63255 .67976 Mdot
.47573 .35896 Mdot
.50984 .23179 Mdot
.55661 .39298 Mdot
.43395 .6451 Mdot
.64987 .35958 Mdot
.29157 .5284 Mdot
.36773 .38457 Mdot
.20624 .65682 Mdot
.29196 .53632 Mdot
.61224 .41181 Mdot
.62528 .66822 Mdot
.4167 .37258 Mdot
.53678 .55554 Mdot
.70061 .5912 Mdot
.58469 .56686 Mdot
.54226 .62339 Mdot
.57277 .59442 Mdot
.28878 .44845 Mdot
.41058 .67646 Mdot
.40707 .37203 Mdot
.28145 .52404 Mdot
.28711 .52772 Mdot
.3868 .66227 Mdot
.51552 .22187 Mdot
.29917 .29774 Mdot
.48924 .15186 Mdot
.44588 .67183 Mdot
.61893 .67194 Mdot
.72559 .5164 Mdot
.40299 .68959 Mdot
.38517 .65815 Mdot
.35692 .57967 Mdot
.31876 .44424 Mdot
.36853 .37572 Mdot
.59098 .42604 Mdot
.51666 .19988 Mdot
.59187 .44166 Mdot
.62645 .57752 Mdot
.3021 .54977 Mdot
.3671 .38448 Mdot
.34608 .4949 Mdot
.5931 .37692 Mdot
.57097 .41441 Mdot
.35206 .72393 Mdot
.55464 .57158 Mdot
.47319 .82549 Mdot
.57912 .44622 Mdot
.41394 .68977 Mdot
.39623 .41523 Mdot
.5674 .56297 Mdot
.62851 .26303 Mdot
.26136 .53168 Mdot
.53716 .56978 Mdot
.56981 .56446 Mdot
.59264 .32196 Mdot
.33606 .32351 Mdot
.35275 .36152 Mdot
.60971 .65411 Mdot
.30988 .42345 Mdot
.26133 .52433 Mdot
.26425 .46828 Mdot
.61558 .39592 Mdot
.31007 .56566 Mdot
.66449 .69926 Mdot
.58161 .43594 Mdot
.64531 .33694 Mdot
.51569 .23849 Mdot
.59038 .36776 Mdot
.63712 .37859 Mdot
.29423 .53988 Mdot
.68777 .71004 Mdot
.54948 .40259 Mdot
.4042 .66603 Mdot
.36868 .37876 Mdot
.33931 .31669 Mdot
.64997 .67584 Mdot
.35645 .52967 Mdot
.83815 .35384 Mdot
.36735 .38407 Mdot
.58305 .41392 Mdot
.29264 .5301 Mdot
.53579 .56222 Mdot
.56214 .56345 Mdot
.58895 .58758 Mdot
.37157 .36321 Mdot
.56865 .5654 Mdot
.46149 .37662 Mdot
.68315 .56136 Mdot
.57005 .31192 Mdot
.28908 .55545 Mdot
.62047 .67035 Mdot
.51122 .59535 Mdot
.35554 .61233 Mdot
.55445 .43643 Mdot
.62673 .5792 Mdot
.34835 .34128 Mdot
.62111 .66683 Mdot
.57865 .39843 Mdot
.56967 .59906 Mdot
.73957 .43922 Mdot
.63358 .71418 Mdot
.56975 .5958 Mdot
.66725 .3392 Mdot
.35136 .37365 Mdot
.54359 .56978 Mdot
.3797 .36255 Mdot
.57815 .39659 Mdot
.59675 .52015 Mdot
.35032 .3779 Mdot
.21022 .38584 Mdot
.56053 .60682 Mdot
.29005 .5129 Mdot
.62561 .37243 Mdot
.58306 .38437 Mdot
.64757 .28479 Mdot
.53875 .56054 Mdot
.18342 .43574 Mdot
.41242 .65954 Mdot
.45505 .82824 Mdot
.43349 .62334 Mdot
.35336 .57934 Mdot
.23113 .49871 Mdot
.58118 .37895 Mdot
.51638 .22161 Mdot
.64914 .28945 Mdot
.32519 .54149 Mdot
.6518 .28524 Mdot
.58917 .39274 Mdot
.56162 .4104 Mdot
.40972 .66451 Mdot
.25356 .54977 Mdot
.67703 .31463 Mdot
.67746 .54664 Mdot
.64954 .66555 Mdot
.40139 .35932 Mdot
.58875 .39991 Mdot
.40429 .32391 Mdot
.43178 .66173 Mdot
.34772 .28376 Mdot
.60725 .40274 Mdot
.55447 .57195 Mdot
.30643 .56533 Mdot
.26607 .54805 Mdot
.42871 .68077 Mdot
.42904 .6836 Mdot
.58358 .38436 Mdot
.31426 .54769 Mdot
.55083 .43506 Mdot
.66431 .53976 Mdot
.56989 .58039 Mdot
.64444 .68167 Mdot
.61545 .4241 Mdot
.3094 .29408 Mdot
.75988 .68591 Mdot
.56886 .39606 Mdot
.35799 .35075 Mdot
.40533 .67623 Mdot
.38046 .68123 Mdot
.35766 .36406 Mdot
.38067 .67948 Mdot
.32812 .2872 Mdot
.65655 .2537 Mdot
.6399 .66832 Mdot
.64535 .38004 Mdot
.61423 .66123 Mdot
.53777 .56667 Mdot
.60133 .42145 Mdot
.21753 .58152 Mdot
.44609 .66821 Mdot
.69065 .4271 Mdot
.30436 .54413 Mdot
.56422 .55357 Mdot
.65577 .33031 Mdot
.61294 .63352 Mdot
.3926 .69361 Mdot
.53224 .58859 Mdot
.57236 .44086 Mdot
.33987 .37153 Mdot
.66487 .34389 Mdot
.57281 .56292 Mdot
.54215 .56142 Mdot
.53135 .58468 Mdot
.30057 .51415 Mdot
.41721 .35348 Mdot
.35203 .56516 Mdot
.4103 .64245 Mdot
.59051 .45502 Mdot
.58148 .412 Mdot
.38038 .38789 Mdot
.60734 .43084 Mdot
.31274 .55351 Mdot
.45636 .14329 Mdot
.61708 .68172 Mdot
.5389 .55645 Mdot
.24012 .39236 Mdot
.52754 .57677 Mdot
.67052 .33134 Mdot
.64489 .31587 Mdot
.37202 .395 Mdot
.30804 .51463 Mdot
.5589 .45233 Mdot
.4109 .63123 Mdot
.63167 .68688 Mdot
.28609 .56218 Mdot
.64863 .34408 Mdot
.61076 .39936 Mdot
.62178 .66901 Mdot
.34258 .48808 Mdot
.65553 .67662 Mdot
.28117 .52241 Mdot
.5645 .54932 Mdot
.69997 .47218 Mdot
.60011 .41195 Mdot
.54942 .57371 Mdot
.4122 .35393 Mdot
.2969 .52047 Mdot
.51674 .25198 Mdot
.567 .56089 Mdot
.33629 .63739 Mdot
.26269 .54264 Mdot
.56218 .39778 Mdot
.33866 .35623 Mdot
.35272 .30333 Mdot
.41458 .36166 Mdot
.6249 .78296 Mdot
.33844 .66115 Mdot
.40867 .67381 Mdot
.28736 .53906 Mdot
.40187 .65799 Mdot
.63743 .64853 Mdot
.71739 .53302 Mdot
.43082 .68344 Mdot
.41016 .33558 Mdot
.41158 .65217 Mdot
.55359 .43944 Mdot
.28962 .51217 Mdot
.43748 .67406 Mdot
.61909 .41122 Mdot
.65576 .3157 Mdot
.54603 .56164 Mdot
.61665 .69797 Mdot
.67904 .55447 Mdot
.60781 .42252 Mdot
.55233 .57846 Mdot
.60633 .41031 Mdot
.31272 .553 Mdot
.63413 .55241 Mdot
.59133 .45813 Mdot
.44546 .67305 Mdot
.24672 .33292 Mdot
.42515 .63461 Mdot
.50135 .61782 Mdot
.5793 .43792 Mdot
.60103 .41469 Mdot
.65077 .33834 Mdot
.53872 .17362 Mdot
.32423 .55369 Mdot
.61571 .4424 Mdot
.37797 .69396 Mdot
.37913 .3722 Mdot
.34702 .35725 Mdot
.55195 .37002 Mdot
.54722 .57512 Mdot
.30465 .56165 Mdot
.59986 .41785 Mdot
.55979 .55322 Mdot
.70125 .5449 Mdot
.30957 .43054 Mdot
.3445 .68889 Mdot
.39563 .64749 Mdot
.3477 .38402 Mdot
.38367 .69783 Mdot
.65269 .3392 Mdot
.5634 .56095 Mdot
.33713 .65936 Mdot
.32845 .59322 Mdot
.63282 .68615 Mdot
.56478 .4232 Mdot
.7314 .62324 Mdot
.38604 .70518 Mdot
.41894 .69785 Mdot
.55208 .43776 Mdot
.37095 .42582 Mdot
.74084 .69984 Mdot
.3123 .52585 Mdot
.42426 .31047 Mdot
.57384 .23299 Mdot
.82153 .51171 Mdot
.27883 .53457 Mdot
.6435 .34051 Mdot
.39742 .71562 Mdot
.52856 .80736 Mdot
.38482 .37238 Mdot
.63275 .68791 Mdot
.61841 .41517 Mdot
.39814 .3354 Mdot
.4462 .6733 Mdot
.42138 .35168 Mdot
.55686 .56783 Mdot
.29547 .51198 Mdot
.39078 .69823 Mdot
.25311 .5363 Mdot
.43447 .39607 Mdot
.61714 .67469 Mdot
.67941 .62849 Mdot
.6378 .36519 Mdot
.51517 .23655 Mdot
.65929 .32187 Mdot
.52561 .54181 Mdot
.65888 .31694 Mdot
.34476 .31171 Mdot
.6104 .40726 Mdot
.54493 .42045 Mdot
.38431 .71306 Mdot
.56579 .39728 Mdot
.61713 .40042 Mdot
.62882 .2653 Mdot
.56938 .42885 Mdot
.57964 .39021 Mdot
.56409 .39284 Mdot
.36565 .34836 Mdot
.56392 .43675 Mdot
.40878 .37498 Mdot
.4155 .32909 Mdot
.40852 .64293 Mdot
.62716 .64629 Mdot
.62122 .64823 Mdot
.60525 .52611 Mdot
.73012 .6238 Mdot
.51806 .19882 Mdot
.38011 .36876 Mdot
.26443 .54343 Mdot
.57233 .45161 Mdot
.71296 .71997 Mdot
.59797 .52079 Mdot
.41195 .71076 Mdot
.43328 .65902 Mdot
.62131 .40328 Mdot
.83691 .39385 Mdot
.58029 .44736 Mdot
.70032 .56065 Mdot
.58871 .40834 Mdot
.55678 .41306 Mdot
.41641 .62666 Mdot
.70229 .63493 Mdot
.66413 .31036 Mdot
.3378 .32663 Mdot
.63625 .68636 Mdot
.54583 .56889 Mdot
.60121 .52406 Mdot
.59791 .23243 Mdot
.32246 .38889 Mdot
.65011 .33911 Mdot
.40257 .70726 Mdot
.36824 .35777 Mdot
.69258 .56299 Mdot
.31764 .53655 Mdot
.70274 .59263 Mdot
.44901 .32301 Mdot
.31485 .52652 Mdot
.6297 .68467 Mdot
.42272 .71083 Mdot
.57091 .40464 Mdot
.42176 .67323 Mdot
.58978 .3778 Mdot
.70862 .55655 Mdot
.64271 .67466 Mdot
.40283 .33215 Mdot
.26827 .52441 Mdot
.37507 .34377 Mdot
.35381 .28423 Mdot
.6015 .52986 Mdot
.41662 .80682 Mdot
.43293 .63912 Mdot
.50026 .60807 Mdot
.38555 .38261 Mdot
.61245 .37877 Mdot
.48498 .15573 Mdot
.39893 .35111 Mdot
.34101 .37142 Mdot
.68311 .58857 Mdot
.71218 .64612 Mdot
.56976 .38774 Mdot
.40346 .33707 Mdot
.42511 .7094 Mdot
.63671 .66171 Mdot
.61677 .39358 Mdot
.55571 .55682 Mdot
.34371 .36282 Mdot
.38533 .6865 Mdot
.69547 .63269 Mdot
.40942 .69529 Mdot
.37637 .37659 Mdot
.43034 .64704 Mdot
.34104 .52428 Mdot
.43131 .68297 Mdot
.61201 .42896 Mdot
.59999 .4165 Mdot
.36545 .2991 Mdot
.37205 .35744 Mdot
.67059 .33103 Mdot
.59891 .4366 Mdot
.39934 .37619 Mdot
.42025 .71899 Mdot
.32284 .38075 Mdot
.66137 .33987 Mdot
.59477 .42426 Mdot
.61096 .6685 Mdot
.64752 .53739 Mdot
.66468 .5731 Mdot
.57344 .451 Mdot
.61952 .67574 Mdot
.34042 .37463 Mdot
.605 .41804 Mdot
.706 .6417 Mdot
.38748 .71877 Mdot
.55414 .38898 Mdot
.53417 .56299 Mdot
.66886 .31694 Mdot
.75658 .57659 Mdot
.64745 .34293 Mdot
.39585 .37205 Mdot
.38185 .37897 Mdot
.3951 .722 Mdot
.40375 .36471 Mdot
.53856 .55817 Mdot
.29071 .55926 Mdot
.43536 .30603 Mdot
.55679 .54927 Mdot
.54798 .59639 Mdot
.55845 .60464 Mdot
.58038 .58583 Mdot
.64834 .7271 Mdot
.34365 .67544 Mdot
.53998 .58617 Mdot
.40956 .37265 Mdot
.51618 .49669 Mdot
.5474 .53827 Mdot
.30688 .56157 Mdot
.57014 .56554 Mdot
.55451 .3886 Mdot
.64805 .3386 Mdot
.39695 .38775 Mdot
.31905 .53923 Mdot
.57442 .54756 Mdot
.61731 .3946 Mdot
.38428 .39394 Mdot
.58894 .3977 Mdot
.64807 .70528 Mdot
.38376 .35792 Mdot
.40389 .70322 Mdot
.64516 .67944 Mdot
.57574 .58686 Mdot
.63451 .6976 Mdot
.4177 .66818 Mdot
.27146 .54729 Mdot
.61527 .4193 Mdot
.64985 .70981 Mdot
.62884 .64747 Mdot
.60384 .36812 Mdot
.37593 .38065 Mdot
.5931 .59241 Mdot
.6007 .42553 Mdot
.65292 .33092 Mdot
.3566 .36322 Mdot
.17448 .44114 Mdot
.56817 .40799 Mdot
.66777 .30319 Mdot
.34556 .31742 Mdot
.56719 .55701 Mdot
.40834 .7018 Mdot
.57743 .38509 Mdot
.30885 .54058 Mdot
.30289 .55224 Mdot
.44565 .66466 Mdot
.3493 .36217 Mdot
.38308 .68897 Mdot
.61496 .37506 Mdot
.57301 .56939 Mdot
.60568 .3862 Mdot
.36079 .74436 Mdot
.19244 .40855 Mdot
.41988 .36937 Mdot
.41093 .64043 Mdot
.70316 .5361 Mdot
.3242 .52294 Mdot
.43175 .71393 Mdot
.33973 .32245 Mdot
.39395 .3375 Mdot
.35682 .3661 Mdot
.62295 .65026 Mdot
.40218 .69791 Mdot
.37251 .39084 Mdot
.38026 .38999 Mdot
.65446 .3419 Mdot
.62006 .40482 Mdot
.34444 .37955 Mdot
.354 .61217 Mdot
.63368 .68105 Mdot
.37668 .68393 Mdot
.74576 .69803 Mdot
.30521 .52214 Mdot
.62999 .26314 Mdot
.55568 .43935 Mdot
.83431 .32837 Mdot
.5818 .44706 Mdot
.58535 .40784 Mdot
.42849 .36974 Mdot
.63723 .64486 Mdot
.63126 .66021 Mdot
.38483 .38224 Mdot
.42388 .365 Mdot
.651 .69298 Mdot
.65425 .51013 Mdot
.75069 .59626 Mdot
.69301 .54675 Mdot
.4182 .34901 Mdot
.44974 .33032 Mdot
.2941 .5479 Mdot
.36841 .34014 Mdot
.32374 .48643 Mdot
.43819 .65532 Mdot
.43296 .68113 Mdot
.26366 .53113 Mdot
.57128 .40665 Mdot
.41924 .62569 Mdot
.66474 .31458 Mdot
.29977 .471 Mdot
.63976 .34633 Mdot
.57004 .84412 Mdot
.61034 .42867 Mdot
.45765 .58972 Mdot
.29544 .44132 Mdot
.67205 .32476 Mdot
.63851 .23807 Mdot
.63002 .69091 Mdot
.33814 .31646 Mdot
.31649 .55244 Mdot
.51571 .20024 Mdot
.60059 .41311 Mdot
.40925 .33816 Mdot
.27682 .51992 Mdot
.18518 .42574 Mdot
.65604 .31091 Mdot
.66235 .33363 Mdot
.47903 .15419 Mdot
.42142 .33662 Mdot
.40854 .70044 Mdot
.40855 .3019 Mdot
.41571 .37549 Mdot
.64777 .32233 Mdot
.43049 .70744 Mdot
.73627 .43645 Mdot
.41508 .34105 Mdot
.6554 .67424 Mdot
.3956 .36073 Mdot
.64899 .69238 Mdot
.36921 .39103 Mdot
.4068 .64565 Mdot
.56556 .4167 Mdot
.40543 .64468 Mdot
.63112 .70319 Mdot
.42451 .63735 Mdot
.31903 .5475 Mdot
.56216 .58755 Mdot
.2968 .55566 Mdot
.72059 .52711 Mdot
.52014 .26316 Mdot
.2764 .54632 Mdot
.59671 .34528 Mdot
.6116 .39831 Mdot
.36783 .39072 Mdot
.39821 .70462 Mdot
.37417 .69842 Mdot
.6769 .55252 Mdot
.36055 .37539 Mdot
.38494 .67407 Mdot
.63676 .40332 Mdot
.20981 .55843 Mdot
.66814 .30589 Mdot
.21853 .67771 Mdot
.40345 .37181 Mdot
.37548 .69962 Mdot
.69675 .56212 Mdot
.4332 .34844 Mdot
.43543 .67954 Mdot
.26904 .53015 Mdot
.30854 .54041 Mdot
.60479 .43784 Mdot
.24993 .5371 Mdot
.41024 .71023 Mdot
.45951 .34998 Mdot
.35717 .38381 Mdot
.19711 .39964 Mdot
.61922 .68202 Mdot
.3856 .69882 Mdot
.57043 .57586 Mdot
.4394 .39278 Mdot
.40517 .65486 Mdot
.83837 .35979 Mdot
.71697 .76066 Mdot
.38469 .67908 Mdot
.3832 .35944 Mdot
.36796 .36433 Mdot
.6485 .35143 Mdot
.67524 .54763 Mdot
.39187 .69208 Mdot
.21401 .58039 Mdot
.71435 .49135 Mdot
.55862 .58705 Mdot
.38374 .78265 Mdot
.60096 .35696 Mdot
.65774 .32582 Mdot
.29773 .52185 Mdot
.57086 .41605 Mdot
.42409 .3601 Mdot
.58025 .447 Mdot
.30587 .55656 Mdot
.44443 .65919 Mdot
.60337 .41279 Mdot
.63039 .68633 Mdot
.30175 .52726 Mdot
.312 .5376 Mdot
.42532 .6456 Mdot
.34881 .3634 Mdot
.51246 .20223 Mdot
.40486 .69884 Mdot
.6626 .32025 Mdot
.55624 .57986 Mdot
.56409 .39391 Mdot
.38397 .33238 Mdot
.32799 .34004 Mdot
.38703 .70303 Mdot
.60867 .37105 Mdot
.28476 .53433 Mdot
.38686 .7147 Mdot
.64353 .34564 Mdot
.43051 .69483 Mdot
.58067 .61439 Mdot
.41208 .62352 Mdot
.42837 .40084 Mdot
.58053 .60178 Mdot
.40857 .33652 Mdot
.5447 .58902 Mdot
.58941 .79411 Mdot
.6305 .68316 Mdot
.42206 .62862 Mdot
.20638 .39242 Mdot
.40515 .64288 Mdot
.57141 .43058 Mdot
.6138 .40683 Mdot
.41572 .66168 Mdot
.61677 .67244 Mdot
.51145 .57963 Mdot
.65383 .70548 Mdot
.3783 .35829 Mdot
.64169 .32698 Mdot
.6811 .78376 Mdot
.37321 .70794 Mdot
.26226 .52551 Mdot
.32785 .40923 Mdot
.55158 .5977 Mdot
.32004 .54369 Mdot
.31029 .53282 Mdot
.63016 .69973 Mdot
.38814 .65434 Mdot
.35264 .349 Mdot
.26085 .5218 Mdot
.43065 .3526 Mdot
.70229 .64244 Mdot
.57791 .57462 Mdot
.49639 .58544 Mdot
.5708 .59883 Mdot
.68272 .55848 Mdot
.28049 .51169 Mdot
.59768 .39749 Mdot
.56674 .62657 Mdot
.27509 .52273 Mdot
.61293 .68887 Mdot
.64301 .34363 Mdot
.38608 .67037 Mdot
.49567 .1725 Mdot
.61105 .43158 Mdot
.58925 .43608 Mdot
.29254 .51861 Mdot
.62287 .22977 Mdot
.33514 .32592 Mdot
.35022 .37374 Mdot
.41011 .67711 Mdot
.68025 .58554 Mdot
.5712 .44172 Mdot
.61573 .40584 Mdot
.41966 .65921 Mdot
.54595 .57881 Mdot
.39895 .79623 Mdot
.59321 .42259 Mdot
.29184 .54235 Mdot
.64465 .34006 Mdot
.32529 .54535 Mdot
.56365 .45469 Mdot
.5721 .42858 Mdot
.6651 .32436 Mdot
.65503 .31972 Mdot
.29542 .55521 Mdot
.57332 .59489 Mdot
.52964 .5744 Mdot
.41569 .35734 Mdot
.62294 .40028 Mdot
.71333 .48998 Mdot
.59661 .417 Mdot
.62879 .68982 Mdot
.66844 .57516 Mdot
.5693 .45332 Mdot
.62122 .42145 Mdot
.71663 .49222 Mdot
.58245 .39418 Mdot
.29412 .51803 Mdot
.3655 .36755 Mdot
.28522 .5325 Mdot
.26833 .51827 Mdot
.41145 .65078 Mdot
.6094 .68059 Mdot
.57814 .38664 Mdot
.64794 .66575 Mdot
.61939 .35824 Mdot
.56391 .5357 Mdot
.66227 .53649 Mdot
.7006 .55893 Mdot
.62678 .70946 Mdot
.61325 .39843 Mdot
.41407 .67109 Mdot
.38148 .66029 Mdot
.63835 .34138 Mdot
.62342 .3753 Mdot
.25503 .54689 Mdot
.27152 .54313 Mdot
.34662 .70636 Mdot
.46493 .69868 Mdot
.65093 .70474 Mdot
.53659 .6135 Mdot
.65591 .31703 Mdot
.56615 .42976 Mdot
.56602 .59419 Mdot
.39959 .66404 Mdot
.54269 .58874 Mdot
.3443 .68275 Mdot
.32158 .54774 Mdot
.28423 .52627 Mdot
.61159 .42808 Mdot
.86587 .44273 Mdot
.39969 .34653 Mdot
.36683 .36449 Mdot
.29764 .5614 Mdot
.4249 .63417 Mdot
.55703 .56491 Mdot
.51213 .17189 Mdot
.32717 .35079 Mdot
.63451 .64628 Mdot
.59817 .38263 Mdot
.4373 .65187 Mdot
.41778 .36414 Mdot
.65275 .70362 Mdot
.60433 .45607 Mdot
.43013 .70992 Mdot
.59534 .40343 Mdot
.62384 .44879 Mdot
.38165 .38534 Mdot
.65451 .53608 Mdot
.40812 .33459 Mdot
.30026 .55051 Mdot
.27122 .51452 Mdot
.57674 .43326 Mdot
.50681 .1779 Mdot
.38288 .42003 Mdot
.25951 .52067 Mdot
.61055 .65444 Mdot
.56662 .58588 Mdot
.61111 .68453 Mdot
.40734 .66721 Mdot
.63064 .68435 Mdot
.4063 .65366 Mdot
.40551 .72531 Mdot
.35102 .35153 Mdot
.62201 .6687 Mdot
.60619 .25694 Mdot
.56173 .56028 Mdot
.61481 .64531 Mdot
.60354 .44995 Mdot
.6606 .3427 Mdot
.39006 .68552 Mdot
.64579 .65996 Mdot
.57452 .38597 Mdot
.23599 .39622 Mdot
.28192 .51347 Mdot
.31845 .5491 Mdot
.55633 .56693 Mdot
.39761 .71287 Mdot
.34909 .35154 Mdot
.70556 .53482 Mdot
.45359 .3839 Mdot
.61643 .4071 Mdot
.57668 .3888 Mdot
.44673 .38988 Mdot
.34808 .35253 Mdot
.57463 .4294 Mdot
.56883 .30639 Mdot
.57227 .57832 Mdot
.3084 .54666 Mdot
.38027 .35619 Mdot
.37731 .35221 Mdot
.41835 .70238 Mdot
.34328 .36617 Mdot
.52429 .61679 Mdot
.32135 .54671 Mdot
.52886 .56681 Mdot
.28722 .53659 Mdot
.56813 .51907 Mdot
.38931 .67004 Mdot
.19724 .41174 Mdot
.3477 .37256 Mdot
.66161 .33826 Mdot
.34343 .3701 Mdot
.62069 .68756 Mdot
.40529 .33893 Mdot
.37408 .33701 Mdot
.61861 .4101 Mdot
.57288 .59367 Mdot
.5393 .56735 Mdot
.68093 .55281 Mdot
.4005 .3488 Mdot
.57167 .39765 Mdot
.56217 .43957 Mdot
.60211 .43386 Mdot
.66643 .53891 Mdot
.35947 .35265 Mdot
.59977 .23248 Mdot
.36252 .3918 Mdot
.38858 .38341 Mdot
.77233 .67417 Mdot
.54213 .55674 Mdot
.55063 .59443 Mdot
.22958 .52678 Mdot
.59197 .42578 Mdot
.38189 .67541 Mdot
.66161 .3233 Mdot
.57255 .5884 Mdot
.59863 .45684 Mdot
.63914 .65848 Mdot
.59706 .37687 Mdot
.55212 .58533 Mdot
.3985 .7027 Mdot
.6597 .33894 Mdot
.59923 .42177 Mdot
.54353 .57401 Mdot
.3397 .36736 Mdot
.37271 .34813 Mdot
.43295 .41112 Mdot
.64546 .70045 Mdot
.28395 .54803 Mdot
.65988 .32605 Mdot
.4115 .67451 Mdot
.38267 .66929 Mdot
.40641 .33498 Mdot
.42826 .67391 Mdot
.28577 .52463 Mdot
.58365 .41625 Mdot
.29846 .55321 Mdot
.64524 .66738 Mdot
.38445 .35688 Mdot
.65352 .33586 Mdot
.67025 .34018 Mdot
.38195 .37901 Mdot
.57315 .57628 Mdot
.60989 .66988 Mdot
.42669 .66018 Mdot
.40832 .37673 Mdot
.29746 .55756 Mdot
.4245 .69457 Mdot
.66371 .3345 Mdot
.82611 .60323 Mdot
.57064 .41696 Mdot
.58852 .44313 Mdot
.40148 .41065 Mdot
.54427 .42577 Mdot
.41119 .64225 Mdot
.34278 .35756 Mdot
.66176 .34062 Mdot
.73263 .50369 Mdot
.60497 .68417 Mdot
.37257 .67074 Mdot
.58334 .39835 Mdot
.64744 .28543 Mdot
.5565 .39454 Mdot
.21455 .37931 Mdot
.66166 .53754 Mdot
.33768 .64021 Mdot
.49628 .59567 Mdot
.25683 .52702 Mdot
.55127 .57956 Mdot
.41203 .64857 Mdot
.56452 .29779 Mdot
.57413 .42367 Mdot
.51275 .24587 Mdot
.64684 .34512 Mdot
.2797 .5313 Mdot
.62019 .23663 Mdot
.40454 .7074 Mdot
.44636 .82495 Mdot
.62068 .38771 Mdot
.33109 .33379 Mdot
.3696 .59661 Mdot
.56377 .59244 Mdot
.55949 .59778 Mdot
.64986 .70414 Mdot
.43987 .7027 Mdot
.58187 .5609 Mdot
.28661 .53408 Mdot
.56524 .4313 Mdot
.63408 .37811 Mdot
.18109 .4422 Mdot
.4118 .36829 Mdot
.27059 .51986 Mdot
.38613 .63934 Mdot
.60093 .39402 Mdot
.38883 .33895 Mdot
.38538 .37212 Mdot
.63824 .65452 Mdot
.34013 .6258 Mdot
.43654 .70994 Mdot
.84 .41265 Mdot
.59387 .57879 Mdot
.40243 .66219 Mdot
.58104 .59825 Mdot
.66327 .32225 Mdot
.59756 .52086 Mdot
.26276 .52233 Mdot
.57574 .43602 Mdot
.51332 .23455 Mdot
.40868 .36591 Mdot
.59311 .41325 Mdot
.63677 .68035 Mdot
.52423 .16606 Mdot
.63712 .3715 Mdot
.57288 .30862 Mdot
.4254 .70931 Mdot
.57492 .39073 Mdot
.53189 .61999 Mdot
.55911 .55259 Mdot
.54407 .4265 Mdot
.40634 .70125 Mdot
.57892 .60259 Mdot
.63616 .67386 Mdot
.41814 .35545 Mdot
.55181 .57758 Mdot
.64536 .34612 Mdot
.58484 .38023 Mdot
.60902 .65765 Mdot
.66316 .32864 Mdot
.41484 .29258 Mdot
.58616 .5836 Mdot
.43419 .67255 Mdot
.4115 .37606 Mdot
.56995 .39555 Mdot
.56765 .58652 Mdot
.60386 .38674 Mdot
.31027 .29339 Mdot
.57206 .43485 Mdot
.21141 .41863 Mdot
.36731 .37848 Mdot
.30213 .53612 Mdot
.65024 .33735 Mdot
.59747 .40572 Mdot
.58325 .59864 Mdot
.55572 .56271 Mdot
.61564 .3848 Mdot
.40835 .33593 Mdot
.41244 .34873 Mdot
.32964 .34116 Mdot
.42387 .69952 Mdot
.68727 .54384 Mdot
.30189 .54252 Mdot
.56488 .59461 Mdot
.26066 .52237 Mdot
.65037 .29244 Mdot
.64277 .69937 Mdot
.18887 .43653 Mdot
.58123 .42133 Mdot
.35834 .37255 Mdot
.74747 .5998 Mdot
.39163 .33589 Mdot
.23471 .51954 Mdot
.2614 .52441 Mdot
.39431 .35316 Mdot
.58091 .40084 Mdot
.68601 .56236 Mdot
.65086 .28141 Mdot
.3117 .51521 Mdot
.5303 .56666 Mdot
.59736 .55782 Mdot
.43547 .68882 Mdot
.76593 .6819 Mdot
.26995 .5532 Mdot
.29474 .43969 Mdot
.66161 .33972 Mdot
.35488 .37888 Mdot
.28819 .55469 Mdot
.31394 .53932 Mdot
.40097 .70951 Mdot
.65563 .34127 Mdot
.59624 .4077 Mdot
.53408 .56485 Mdot
.27034 .54932 Mdot
.60019 .37281 Mdot
.67331 .32214 Mdot
.36148 .74913 Mdot
.33383 .32488 Mdot
.17309 .43959 Mdot
.64386 .3137 Mdot
.51495 .23339 Mdot
.24588 .59091 Mdot
.36491 .38893 Mdot
.57761 .39291 Mdot
.56601 .57358 Mdot
.43032 .66641 Mdot
.57912 .41378 Mdot
.40894 .64038 Mdot
.27796 .53801 Mdot
.22398 .40863 Mdot
.64308 .31645 Mdot
.29576 .47098 Mdot
.56709 .4179 Mdot
.64086 .35963 Mdot
.62948 .67043 Mdot
.31551 .55537 Mdot
.33497 .33739 Mdot
.56654 .39356 Mdot
.41622 .69889 Mdot
.43684 .68164 Mdot
.41069 .36233 Mdot
.36991 .43784 Mdot
.20063 .40334 Mdot
.56914 .5708 Mdot
.42376 .68025 Mdot
.56938 .58525 Mdot
.57268 .3115 Mdot
.25986 .52248 Mdot
.63605 .67247 Mdot
.43086 .65026 Mdot
.30017 .5639 Mdot
.66157 .34212 Mdot
.40513 .35568 Mdot
.45074 .38398 Mdot
.64972 .31622 Mdot
.38452 .67412 Mdot
.64482 .69211 Mdot
.56477 .36639 Mdot
.64318 .32498 Mdot
.64381 .68208 Mdot
.41575 .70708 Mdot
.38857 .34396 Mdot
.38186 .37551 Mdot
.366 .36919 Mdot
.6287 .26271 Mdot
.32729 .3428 Mdot
.66087 .61958 Mdot
.54492 .41392 Mdot
.46551 .35237 Mdot
.56394 .38252 Mdot
.31729 .55061 Mdot
.37274 .38545 Mdot
.66093 .53691 Mdot
.6659 .30829 Mdot
.65686 .2783 Mdot
.60302 .42952 Mdot
.6488 .32404 Mdot
.59258 .42592 Mdot
.46532 .35775 Mdot
.33004 .32801 Mdot
.62431 .40983 Mdot
.32322 .53107 Mdot
.6303 .6944 Mdot
.42757 .36435 Mdot
.58499 .38578 Mdot
.45359 .35193 Mdot
.60123 .45131 Mdot
.22099 .40948 Mdot
.64442 .33059 Mdot
.40597 .609 Mdot
.55961 .42104 Mdot
.4317 .63411 Mdot
.65811 .35028 Mdot
.44041 .31168 Mdot
.29062 .51236 Mdot
.63773 .37095 Mdot
.42863 .62612 Mdot
.61807 .23685 Mdot
.5653 .5662 Mdot
.63262 .67784 Mdot
.56827 .60463 Mdot
.30239 .55603 Mdot
.57828 .42346 Mdot
.59568 .37861 Mdot
.55169 .44811 Mdot
.57261 .31247 Mdot
.54767 .55562 Mdot
.62963 .71157 Mdot
.44928 .32688 Mdot
.60922 .38156 Mdot
.41016 .62709 Mdot
.3591 .35823 Mdot
.60877 .2489 Mdot
.59181 .25504 Mdot
.67501 .32444 Mdot
.40002 .35186 Mdot
.34904 .36233 Mdot
.72582 .71201 Mdot
.62442 .67633 Mdot
.58703 .4382 Mdot
.66151 .70232 Mdot
.65812 .3299 Mdot
.28531 .54351 Mdot
.54641 .43183 Mdot
.38848 .67081 Mdot
.69164 .56682 Mdot
.41955 .70482 Mdot
.60422 .43164 Mdot
.39339 .36197 Mdot
.31599 .51797 Mdot
.40003 .72684 Mdot
.3417 .62003 Mdot
.66944 .6255 Mdot
.43359 .71339 Mdot
.65267 .6999 Mdot
.62719 .6971 Mdot
.31579 .55471 Mdot
.5833 .40585 Mdot
.66891 .54185 Mdot
.68533 .29084 Mdot
.58767 .4267 Mdot
.57265 .40715 Mdot
.237 .56147 Mdot
.26197 .53718 Mdot
.43082 .64569 Mdot
.5749 .42837 Mdot
.59796 .37584 Mdot
.39213 .35867 Mdot
.65078 .6678 Mdot
.41978 .65254 Mdot
.64561 .7051 Mdot
.41716 .68166 Mdot
.75722 .57686 Mdot
.57632 .57261 Mdot
.63744 .7002 Mdot
.26685 .55128 Mdot
.35909 .36742 Mdot
.5414 .55633 Mdot
.40082 .67642 Mdot
.42557 .67938 Mdot
.61918 .35882 Mdot
.41784 .36194 Mdot
.35004 .3739 Mdot
.64957 .69893 Mdot
.2738 .54539 Mdot
.66408 .31301 Mdot
.56916 .59891 Mdot
.36308 .69667 Mdot
.4226 .69076 Mdot
.4515 .33126 Mdot
.41724 .40493 Mdot
.59962 .38807 Mdot
.37491 .34716 Mdot
.60371 .40716 Mdot
.44115 .34634 Mdot
.42774 .33989 Mdot
.5684 .45596 Mdot
.49841 .35615 Mdot
.39983 .66206 Mdot
.64363 .80767 Mdot
.66868 .30522 Mdot
.32866 .55756 Mdot
.66167 .32505 Mdot
.41556 .8077 Mdot
.74596 .60334 Mdot
.61225 .38672 Mdot
.57978 .38754 Mdot
.86284 .46805 Mdot
.55341 .41475 Mdot
.5458 .58815 Mdot
.56457 .56479 Mdot
.38015 .34406 Mdot
.56256 .60419 Mdot
.68074 .55567 Mdot
.61829 .66624 Mdot
.40965 .67636 Mdot
.70816 .64043 Mdot
.6479 .69498 Mdot
.4003 .37101 Mdot
.66597 .31259 Mdot
.40811 .41255 Mdot
.4068 .63174 Mdot
.54899 .57144 Mdot
.27839 .53529 Mdot
.67167 .54931 Mdot
.41035 .70507 Mdot
.28495 .5592 Mdot
.55551 .43043 Mdot
.34636 .69293 Mdot
.32496 .53717 Mdot
.65894 .79455 Mdot
.31167 .52826 Mdot
.29214 .55993 Mdot
.67844 .54454 Mdot
.61817 .66583 Mdot
.58707 .59667 Mdot
.5515 .53236 Mdot
.30663 .51641 Mdot
.49301 .83445 Mdot
.39756 .71171 Mdot
.71038 .55352 Mdot
.33678 .31733 Mdot
.56718 .56208 Mdot
.56755 .41249 Mdot
.29969 .52168 Mdot
.62497 .3743 Mdot
.58208 .60046 Mdot
.29573 .52705 Mdot
.65933 .34944 Mdot
.68018 .58361 Mdot
.56669 .58203 Mdot
.53809 .56685 Mdot
.65475 .68113 Mdot
.42031 .61276 Mdot
.35039 .36913 Mdot
.62489 .64558 Mdot
.70973 .51785 Mdot
.59566 .43767 Mdot
.29452 .55507 Mdot
.55146 .57668 Mdot
.3051 .54309 Mdot
.63039 .66409 Mdot
.60847 .65657 Mdot
.41587 .3599 Mdot
.33072 .33705 Mdot
.5505 .54609 Mdot
.71571 .48173 Mdot
.55048 .40165 Mdot
.51461 .25501 Mdot
.35695 .351 Mdot
.6454 .2438 Mdot
.6183 .65567 Mdot
.64655 .65932 Mdot
.64415 .35699 Mdot
.57884 .45219 Mdot
.64765 .32849 Mdot
.57531 .45462 Mdot
.4771 .81854 Mdot
.65218 .33846 Mdot
.42673 .66344 Mdot
.59056 .45877 Mdot
.30597 .42063 Mdot
.63738 .35611 Mdot
.59142 .38393 Mdot
.40542 .6915 Mdot
.58393 .36861 Mdot
.38797 .6809 Mdot
.56501 .40693 Mdot
.37005 .76055 Mdot
.41147 .67504 Mdot
.51782 .58438 Mdot
.53197 .4402 Mdot
.54192 .58319 Mdot
.62647 .6544 Mdot
.64749 .71029 Mdot
.69329 .63257 Mdot
.39059 .34593 Mdot
.54504 .17708 Mdot
.59266 .38459 Mdot
.40267 .71101 Mdot
.27615 .53798 Mdot
.67143 .33746 Mdot
.59472 .44213 Mdot
.65703 .31389 Mdot
.4069 .35077 Mdot
.39965 .71449 Mdot
.62475 .66124 Mdot
.39617 .64506 Mdot
.36847 .76188 Mdot
.39101 .66942 Mdot
.59075 .32082 Mdot
.65523 .34702 Mdot
.52893 .6187 Mdot
.52566 .285 Mdot
.62167 .63459 Mdot
.40986 .35767 Mdot
.55349 .58075 Mdot
.61917 .6935 Mdot
.64118 .55545 Mdot
.35418 .36443 Mdot
.4198 .65991 Mdot
.59564 .40276 Mdot
.58115 .58827 Mdot
.55245 .53236 Mdot
.42659 .35624 Mdot
.60688 .66734 Mdot
.40349 .68124 Mdot
.56164 .58339 Mdot
.69275 .54458 Mdot
.57512 .23226 Mdot
.71997 .53343 Mdot
.60009 .40496 Mdot
.65066 .69401 Mdot
.41816 .36191 Mdot
.65465 .31422 Mdot
.27783 .52241 Mdot
.67647 .54963 Mdot
.56854 .4157 Mdot
.27293 .47709 Mdot
.39472 .36257 Mdot
.61864 .67787 Mdot
.3049 .52365 Mdot
.62524 .67874 Mdot
.55051 .59368 Mdot
.41832 .37836 Mdot
.5595 .59765 Mdot
.64615 .34406 Mdot
.27935 .54218 Mdot
.35076 .37119 Mdot
.36794 .76003 Mdot
.5915 .59484 Mdot
.4144 .66253 Mdot
.64344 .5554 Mdot
.41504 .35073 Mdot
.35302 .55893 Mdot
.39746 .64403 Mdot
.31635 .59311 Mdot
.6448 .53688 Mdot
.29318 .52419 Mdot
.5891 .38432 Mdot
.37381 .36793 Mdot
.31397 .51585 Mdot
.35958 .61042 Mdot
.64417 .27854 Mdot
.57963 .56508 Mdot
.61287 .40115 Mdot
.22045 .36801 Mdot
.30427 .43582 Mdot
.35436 .30166 Mdot
.28519 .56182 Mdot
.59109 .4334 Mdot
.57048 .57154 Mdot
.62333 .39688 Mdot
.29957 .51461 Mdot
.29589 .50657 Mdot
.37749 .6769 Mdot
.59608 .39838 Mdot
.62655 .68644 Mdot
.39611 .65581 Mdot
.4375 .69083 Mdot
.43342 .65326 Mdot
.33437 .33635 Mdot
.57007 .56221 Mdot
.567 .56611 Mdot
.74205 .61032 Mdot
.30667 .54327 Mdot
.54247 .58369 Mdot
.59488 .3778 Mdot
.66188 .61951 Mdot
.36432 .37333 Mdot
.40011 .68558 Mdot
.59106 .43538 Mdot
.66416 .30358 Mdot
.54457 .56915 Mdot
.40382 .69787 Mdot
.34943 .35253 Mdot
.5292 .50355 Mdot
.57962 .41588 Mdot
.65155 .34291 Mdot
.39358 .37602 Mdot
.29586 .29978 Mdot
.69995 .5476 Mdot
.60305 .40896 Mdot
.30354 .5523 Mdot
.27949 .31782 Mdot
.55491 .42453 Mdot
.44186 .40807 Mdot
.53293 .56349 Mdot
.50794 .47962 Mdot
.41946 .30189 Mdot
.60078 .46677 Mdot
.43254 .5348 Mdot
.69312 .42743 Mdot
.45333 .55554 Mdot
.51497 .81721 Mdot
.39475 .53685 Mdot
.67762 .78203 Mdot
.2596 .55618 Mdot
.61652 .45895 Mdot
.82956 .35866 Mdot
.30259 .44863 Mdot
.38106 .56113 Mdot
.343 .54647 Mdot
.62113 .62327 Mdot
.39238 .79015 Mdot
.34613 .69541 Mdot
.51807 .81391 Mdot
.60583 .35653 Mdot
.29676 .36714 Mdot
.63982 .40088 Mdot
.35339 .53328 Mdot
.34058 .63649 Mdot
.6362 .34584 Mdot
.84754 .48666 Mdot
.24082 .50797 Mdot
.7996 .6033 Mdot
.52928 .20425 Mdot
.35496 .69372 Mdot
.70398 .47178 Mdot
.70669 .67539 Mdot
.66618 .35267 Mdot
.48073 .51445 Mdot
.25113 .54779 Mdot
.34023 .39149 Mdot
.21221 .56737 Mdot
.42284 .66741 Mdot
.424 .34998 Mdot
.22388 .5132 Mdot
.83891 .54914 Mdot
.29779 .57815 Mdot
.43143 .53619 Mdot
.5889 .57973 Mdot
.51237 .47013 Mdot
.65939 .53307 Mdot
.43659 .32644 Mdot
.36278 .73698 Mdot
.39719 .78838 Mdot
.39692 .4081 Mdot
.3687 .61406 Mdot
.63189 .55318 Mdot
.37707 .56054 Mdot
.39376 .29235 Mdot
.60975 .6281 Mdot
.52087 .58907 Mdot
.35701 .35045 Mdot
.82211 .44565 Mdot
.56644 .34775 Mdot
.71443 .51257 Mdot
.34696 .64035 Mdot
.33853 .39974 Mdot
.51158 .19715 Mdot
.36452 .43736 Mdot
.59481 .83381 Mdot
.82424 .59691 Mdot
.56057 .81816 Mdot
.53068 .44817 Mdot
.26809 .57343 Mdot
.60782 .53711 Mdot
.46387 .59661 Mdot
.58581 .8149 Mdot
.30867 .29658 Mdot
.83543 .43314 Mdot
.4783 .433 Mdot
.84761 .56231 Mdot
.4208 .38906 Mdot
.58474 .62477 Mdot
.37251 .29606 Mdot
.55286 .49897 Mdot
.72611 .59206 Mdot
.85202 .5305 Mdot
.36356 .54215 Mdot
.5921 .60315 Mdot
.30561 .45099 Mdot
.41295 .29457 Mdot
.35913 .73638 Mdot
.54946 .6049 Mdot
.54994 .27449 Mdot
.85879 .50516 Mdot
.44157 .52473 Mdot
.82811 .50809 Mdot
.37304 .75018 Mdot
.20058 .63596 Mdot
.43914 .69071 Mdot
.25308 .52408 Mdot
.81132 .59758 Mdot
.3774 .37014 Mdot
.62086 .82797 Mdot
.40075 .55878 Mdot
.42501 .59723 Mdot
.8565 .49682 Mdot
.56979 .83887 Mdot
.54863 .48999 Mdot
.53217 .60876 Mdot
.21478 .56239 Mdot
.47226 .55346 Mdot
.3359 .47753 Mdot
.5581 .51767 Mdot
.21936 .39361 Mdot
.81784 .58117 Mdot
.55106 .83562 Mdot
.83059 .39876 Mdot
.70728 .51192 Mdot
.66914 .65405 Mdot
.38999 .41249 Mdot
.40534 .47619 Mdot
.34116 .48932 Mdot
.84223 .5751 Mdot
.63782 .38922 Mdot
.26497 .3254 Mdot
.53205 .81556 Mdot
.59845 .24749 Mdot
.25303 .37629 Mdot
.28633 .46623 Mdot
.53891 .51035 Mdot
.44762 .34586 Mdot
.61844 .71084 Mdot
.7211 .60586 Mdot
.53995 .26027 Mdot
.38824 .60881 Mdot
.69411 .5539 Mdot
.38722 .43955 Mdot
.65151 .76605 Mdot
.27607 .35993 Mdot
.54878 .26856 Mdot
.44778 .38562 Mdot
.58734 .81297 Mdot
.53627 .82 Mdot
.25827 .34829 Mdot
.37327 .65374 Mdot
.82882 .51842 Mdot
.3526 .45884 Mdot
.52317 .46751 Mdot
.63751 .41541 Mdot
.65402 .35814 Mdot
.42098 .7915 Mdot
.55211 .3369 Mdot
.72569 .70266 Mdot
.31631 .475 Mdot
.5244 .29707 Mdot
.72139 .67996 Mdot
.53003 .29063 Mdot
.43362 .30549 Mdot
.43388 .42055 Mdot
.2443 .50608 Mdot
.49778 .3664 Mdot
.85058 .48717 Mdot
.41799 .6442 Mdot
.58285 .81859 Mdot
.29131 .57606 Mdot
.34785 .6849 Mdot
.40463 .59429 Mdot
.39451 .59434 Mdot
.78599 .63096 Mdot
.2874 .45912 Mdot
.60799 .61801 Mdot
.38444 .29832 Mdot
.42269 .57269 Mdot
.5206 .25488 Mdot
.62598 .32937 Mdot
.31343 .37535 Mdot
.60953 .66883 Mdot
.55089 .30044 Mdot
.44807 .34275 Mdot
.38352 .6403 Mdot
.60581 .31968 Mdot
.72307 .4471 Mdot
.54024 .54975 Mdot
.67005 .60551 Mdot
.75557 .58226 Mdot
.5023 .43264 Mdot
.5845 .82797 Mdot
.33615 .44299 Mdot
.67545 .60952 Mdot
.3419 .4925 Mdot
.55138 .18018 Mdot
.84957 .55967 Mdot
.76078 .68002 Mdot
.29529 .31353 Mdot
.24303 .36952 Mdot
.24298 .71498 Mdot
.35092 .56941 Mdot
.67543 .76826 Mdot
.2908 .57609 Mdot
.45481 .14516 Mdot
.41631 .64082 Mdot
.6055 .54513 Mdot
.40688 .38827 Mdot
.71731 .44799 Mdot
.84582 .51532 Mdot
.50393 .45124 Mdot
.61709 .64417 Mdot
.36048 .29548 Mdot
.49965 .35752 Mdot
.84093 .48111 Mdot
.8311 .44613 Mdot
.82908 .45578 Mdot
.23091 .50421 Mdot
.54975 .32334 Mdot
.85675 .47534 Mdot
.63025 .59567 Mdot
.50831 .38223 Mdot
.6345 .39076 Mdot
.73047 .49066 Mdot
.65497 .78495 Mdot
.65269 .64209 Mdot
.47614 .55056 Mdot
.39905 .40769 Mdot
.86368 .49919 Mdot
.75533 .59733 Mdot
.522 .48377 Mdot
.78473 .61652 Mdot
.66489 .72063 Mdot
.73027 .67121 Mdot
.77613 .64432 Mdot
.45972 .51876 Mdot
.29417 .4651 Mdot
.86996 .49917 Mdot
.57302 .80422 Mdot
.34507 .56082 Mdot
.4508 .34773 Mdot
.64645 .79734 Mdot
.24616 .37916 Mdot
.25615 .5811 Mdot
.4136 .39096 Mdot
.5694 .1947 Mdot
.37048 .51341 Mdot
.48524 .51541 Mdot
.55067 .45459 Mdot
.716 .69459 Mdot
.42339 .63829 Mdot
.62195 .79402 Mdot
.35725 .48923 Mdot
.50057 .38571 Mdot
.69405 .61659 Mdot
.52741 .8363 Mdot
.47963 .47486 Mdot
.59361 .29759 Mdot
.33744 .44368 Mdot
.2789 .34369 Mdot
.26064 .36866 Mdot
.54706 .21841 Mdot
.5716 .37991 Mdot
.84284 .54347 Mdot
.70062 .76678 Mdot
.77973 .64589 Mdot
.26599 .34929 Mdot
.22427 .67712 Mdot
.27701 .5637 Mdot
.63951 .60082 Mdot
.72677 .42662 Mdot
.44745 .49263 Mdot
.70394 .41521 Mdot
.32765 .52285 Mdot
.51101 .19679 Mdot
.40412 .59019 Mdot
.63076 .5948 Mdot
.3105 .33325 Mdot
.42984 .58866 Mdot
.58423 .30403 Mdot
.44895 .37835 Mdot
.24432 .33962 Mdot
.59099 .81113 Mdot
.42108 .64483 Mdot
.36819 .67226 Mdot
.53457 .35354 Mdot
.55912 .62506 Mdot
.60503 .58751 Mdot
.52652 .46649 Mdot
.51921 .2294 Mdot
.23971 .69611 Mdot
.75081 .67094 Mdot
.64184 .80756 Mdot
.77471 .64763 Mdot
.55129 .82155 Mdot
.35566 .62482 Mdot
.68174 .6012 Mdot
.30895 .5854 Mdot
.26671 .56803 Mdot
.67178 .58979 Mdot
.53126 .82953 Mdot
.52438 .47827 Mdot
.37286 .29922 Mdot
.57972 .37829 Mdot
.74791 .59511 Mdot
.69917 .67341 Mdot
.65658 .59321 Mdot
.55971 .22579 Mdot
.35128 .34657 Mdot
.6501 .62409 Mdot
.50552 .50773 Mdot
.68199 .31495 Mdot
.24439 .36448 Mdot
.31495 .51554 Mdot
.44909 .36727 Mdot
.52687 .83746 Mdot
.24408 .70964 Mdot
.44473 .57296 Mdot
.59125 .344 Mdot
.81934 .57131 Mdot
.52865 .42041 Mdot
.23402 .38205 Mdot
.58387 .20019 Mdot
.35116 .59546 Mdot
.4037 .40337 Mdot
.50252 .40586 Mdot
.41705 .60094 Mdot
.29693 .33883 Mdot
.44385 .37565 Mdot
.6633 .3504 Mdot
.81333 .60686 Mdot
.5458 .39452 Mdot
.47016 .52527 Mdot
.7067 .53624 Mdot
.389 .48578 Mdot
.40927 .56316 Mdot
.69853 .62466 Mdot
.44473 .55005 Mdot
.82226 .4597 Mdot
.50464 .20175 Mdot
.48536 .54572 Mdot
.62723 .60545 Mdot
.62956 .59023 Mdot
.52873 .20463 Mdot
.38982 .28843 Mdot
.32202 .4798 Mdot
.5675 .36956 Mdot
.80865 .62158 Mdot
.46673 .43131 Mdot
.68631 .61301 Mdot
.37198 .45066 Mdot
.57381 .36957 Mdot
.5933 .60986 Mdot
.77941 .63891 Mdot
.50802 .48407 Mdot
.82956 .34413 Mdot
.50425 .82319 Mdot
.32188 .39928 Mdot
.42356 .30843 Mdot
.59995 .81548 Mdot
.31598 .41676 Mdot
.40371 .54147 Mdot
.35857 .47997 Mdot
.63415 .80063 Mdot
.49981 .47531 Mdot
.51002 .49328 Mdot
.23505 .3545 Mdot
.85074 .46344 Mdot
.47053 .54403 Mdot
.24913 .57536 Mdot
.66763 .66001 Mdot
.58215 .44381 Mdot
.35656 .43953 Mdot
.18911 .42179 Mdot
.40508 .45053 Mdot
.45838 .56274 Mdot
.69371 .77657 Mdot
.50909 .4501 Mdot
.33483 .44536 Mdot
.83169 .34768 Mdot
.83388 .33706 Mdot
.34888 .43471 Mdot
.83706 .58531 Mdot
.51401 .49026 Mdot
.23537 .38497 Mdot
.24953 .54884 Mdot
.6251 .34726 Mdot
.51388 .24911 Mdot
.79128 .64514 Mdot
.21686 .68211 Mdot
.33545 .48116 Mdot
.38465 .39808 Mdot
.78992 .65225 Mdot
.48964 .39986 Mdot
.61561 .59188 Mdot
.20218 .6364 Mdot
.45513 .82655 Mdot
.59632 .82998 Mdot
.56408 .21689 Mdot
.41901 .7962 Mdot
.47775 .80382 Mdot
.36098 .52704 Mdot
.65147 .79715 Mdot
.59038 .5648 Mdot
.56147 .1826 Mdot
.58507 .81375 Mdot
.22775 .37184 Mdot
.38068 .77123 Mdot
.41234 .56055 Mdot
.51824 .45551 Mdot
.44704 .41542 Mdot
.21849 .39847 Mdot
.26804 .47235 Mdot
.5176 .39597 Mdot
.65275 .56356 Mdot
.43522 .30891 Mdot
.27864 .3115 Mdot
.60061 .20148 Mdot
.53441 .47066 Mdot
.81802 .4161 Mdot
.27833 .47896 Mdot
.63965 .57257 Mdot
.40551 .3018 Mdot
.69744 .64543 Mdot
.61162 .61364 Mdot
.59443 .45636 Mdot
.81614 .60117 Mdot
.60899 .61407 Mdot
.82229 .4297 Mdot
.61742 .83271 Mdot
.78921 .60544 Mdot
.45753 .60682 Mdot
.59168 .54302 Mdot
.65473 .78144 Mdot
.66352 .7725 Mdot
.82368 .41009 Mdot
.52308 .80998 Mdot
.66914 .58647 Mdot
.51365 .4165 Mdot
.62795 .33706 Mdot
.58099 .31341 Mdot
.60473 .81303 Mdot
.52499 .19985 Mdot
.72246 .67262 Mdot
.29516 .32118 Mdot
.53072 .83255 Mdot
.55761 .48966 Mdot
.69426 .63908 Mdot
.38789 .45819 Mdot
.53565 .60779 Mdot
.38912 .7118 Mdot
.85987 .43983 Mdot
.25409 .35388 Mdot
.741 .66856 Mdot
.26172 .33108 Mdot
.4633 .36812 Mdot
.49203 .81462 Mdot
.3654 .29278 Mdot
.49045 .6033 Mdot
.35414 .65371 Mdot
.6823 .72907 Mdot
.53703 .48473 Mdot
.21448 .37815 Mdot
.57956 .25056 Mdot
.79046 .6299 Mdot
.72253 .6811 Mdot
.82635 .38446 Mdot
.65319 .63041 Mdot
.54954 .29977 Mdot
.81875 .44034 Mdot
.28701 .32688 Mdot
.64665 .58712 Mdot
.84423 .47568 Mdot
.33187 .31851 Mdot
.82665 .59263 Mdot
.27377 .52687 Mdot
.61989 .60663 Mdot
.20382 .40317 Mdot
.64226 .59309 Mdot
.63905 .58883 Mdot
.74333 .681 Mdot
.3089 .45095 Mdot
.32847 .44025 Mdot
.35081 .45935 Mdot
.34986 .70707 Mdot
.62123 .34469 Mdot
.45803 .53017 Mdot
.83198 .40246 Mdot
.56958 .38336 Mdot
.56458 .79365 Mdot
.58312 .82282 Mdot
.30416 .58601 Mdot
.52034 .44753 Mdot
.21239 .38944 Mdot
.58128 .21431 Mdot
.73353 .61121 Mdot
.85082 .46998 Mdot
.52008 .44555 Mdot
.71885 .43341 Mdot
.63105 .23003 Mdot
.22083 .55491 Mdot
.32848 .48144 Mdot
.43756 .53693 Mdot
.52881 .39926 Mdot
.69912 .54498 Mdot
.55824 .81652 Mdot
.68544 .78034 Mdot
.81879 .41167 Mdot
.33152 .48682 Mdot
.65091 .59548 Mdot
.43262 .41483 Mdot
.69538 .70171 Mdot
.83274 .39257 Mdot
.40276 .79847 Mdot
.44824 .34517 Mdot
.54078 .83094 Mdot
.31002 .45763 Mdot
.61698 .59263 Mdot
.66279 .59211 Mdot
.82292 .45059 Mdot
.3543 .39232 Mdot
.48957 .42687 Mdot
.3952 .44186 Mdot
.6747 .55772 Mdot
.3924 .57021 Mdot
.56121 .19563 Mdot
.27708 .46125 Mdot
.8257 .38321 Mdot
.46005 .80382 Mdot
.61084 .24249 Mdot
.82832 .36571 Mdot
.34705 .35035 Mdot
.38886 .57068 Mdot
.19697 .61489 Mdot
.66869 .60814 Mdot
.44119 .67051 Mdot
.59625 .3736 Mdot
.66347 .57706 Mdot
.30843 .38915 Mdot
.65456 .63736 Mdot
.60439 .66691 Mdot
.44635 .36337 Mdot
.49183 .80944 Mdot
.45029 .37321 Mdot
.68654 .77656 Mdot
.45892 .5143 Mdot
.43722 .31629 Mdot
.6097 .21186 Mdot
.35918 .6229 Mdot
.28162 .33725 Mdot
.79646 .60593 Mdot
.72771 .49525 Mdot
.43808 .36373 Mdot
.43517 .37129 Mdot
.31753 .33218 Mdot
.33463 .58501 Mdot
.82833 .55773 Mdot
.57198 .83568 Mdot
.36329 .692 Mdot
.32269 .33185 Mdot
.53245 .44544 Mdot
.5221 .46316 Mdot
.75702 .64864 Mdot
.39284 .64992 Mdot
.85849 .5454 Mdot
.53506 .17869 Mdot
.29346 .36693 Mdot
.45511 .48188 Mdot
.73311 .4389 Mdot
.62426 .55693 Mdot
.37384 .61408 Mdot
.53902 .47996 Mdot
.3292 .42173 Mdot
.33335 .36601 Mdot
.39538 .58269 Mdot
.61526 .65538 Mdot
.37409 .64948 Mdot
.33309 .56884 Mdot
.542 .21532 Mdot
.59711 .82162 Mdot
.4395 .3963 Mdot
.60722 .5913 Mdot
.3909 .61788 Mdot
.58274 .31994 Mdot
.73222 .46651 Mdot
.86779 .46426 Mdot
.80641 .58599 Mdot
.41505 .3366 Mdot
.27993 .35701 Mdot
.37404 .75709 Mdot
.75016 .66982 Mdot
.49044 .44208 Mdot
.60137 .81075 Mdot
.55119 .28168 Mdot
.76965 .6422 Mdot
.41936 .30305 Mdot
.43599 .51823 Mdot
.56413 .8273 Mdot
.65523 .72495 Mdot
.53793 .83583 Mdot
.58693 .22197 Mdot
.55673 .36044 Mdot
.47219 .82915 Mdot
.3998 .44701 Mdot
.53081 .49019 Mdot
.68245 .30729 Mdot
.44587 .49748 Mdot
.63745 .79546 Mdot
.33941 .35532 Mdot
.62893 .62695 Mdot
.31317 .30263 Mdot
.3342 .48002 Mdot
.81543 .58344 Mdot
.26685 .35696 Mdot
.56554 .8355 Mdot
.61785 .34163 Mdot
.67423 .72369 Mdot
.52325 .20742 Mdot
.71684 .50394 Mdot
.57132 .60051 Mdot
.54072 .27111 Mdot
.5821 .60595 Mdot
.74568 .60921 Mdot
.59117 .3111 Mdot
.84882 .52404 Mdot
.75231 .58679 Mdot
.44786 .41585 Mdot
.56748 .62227 Mdot
.36139 .39066 Mdot
.85861 .52773 Mdot
.73457 .6051 Mdot
.21422 .39894 Mdot
.59653 .82876 Mdot
.5254 .80629 Mdot
.82859 .36113 Mdot
.30839 .45366 Mdot
.4953 .3789 Mdot
.65646 .79432 Mdot
.47444 .42563 Mdot
.48184 .80388 Mdot
.53682 .48446 Mdot
.39605 .41367 Mdot
.85306 .48851 Mdot
.59552 .62201 Mdot
.43063 .42591 Mdot
.65234 .28552 Mdot
.39903 .40414 Mdot
.73276 .59535 Mdot
.54403 .47167 Mdot
.42201 .65892 Mdot
.72538 .43925 Mdot
.41448 .78912 Mdot
.31631 .3397 Mdot
.59313 .81953 Mdot
.6096 .80469 Mdot
.67365 .67238 Mdot
.45664 .6144 Mdot
.82677 .3594 Mdot
.53729 .32541 Mdot
.59477 .46639 Mdot
.44718 .37586 Mdot
.60447 .67197 Mdot
.54759 .80931 Mdot
.5816 .36472 Mdot
.71508 .466 Mdot
.55039 .27694 Mdot
.79928 .63141 Mdot
.39904 .47003 Mdot
.26514 .48937 Mdot
.32759 .32259 Mdot
.21721 .39643 Mdot
.30112 .3055 Mdot
.29806 .44448 Mdot
.63755 .79344 Mdot
.44505 .57218 Mdot
.43312 .52995 Mdot
.46504 .4003 Mdot
.62107 .78874 Mdot
.34576 .50926 Mdot
.32924 .53796 Mdot
.51869 .23439 Mdot
.82099 .3989 Mdot
.45062 .35168 Mdot
.41876 .56025 Mdot
.48388 .49922 Mdot
.53895 .3853 Mdot
.33766 .48051 Mdot
.32541 .44598 Mdot
.43382 .38651 Mdot
.83038 .48286 Mdot
.48463 .52784 Mdot
.59549 .5518 Mdot
.52249 .82386 Mdot
.47178 .50515 Mdot
.61115 .80688 Mdot
.49799 .35595 Mdot
.83071 .46315 Mdot
.68475 .61439 Mdot
.66385 .71833 Mdot
.58688 .37136 Mdot
.30673 .31426 Mdot
.77916 .64054 Mdot
.48854 .44225 Mdot
.46085 .58273 Mdot
.36085 .28908 Mdot
.61364 .83011 Mdot
.52294 .57609 Mdot
.2373 .69235 Mdot
.53895 .61247 Mdot
.72236 .45344 Mdot
.71913 .44154 Mdot
.32552 .58903 Mdot
.52238 .46799 Mdot
.36816 .53276 Mdot
.53548 .38345 Mdot
.52447 .22686 Mdot
.71395 .71798 Mdot
.85503 .43363 Mdot
.33798 .40058 Mdot
.58381 .84091 Mdot
.32147 .38148 Mdot
.36473 .415 Mdot
.4633 .80301 Mdot
.46865 .59081 Mdot
.54253 .34249 Mdot
.66205 .65034 Mdot
.34427 .34699 Mdot
.84802 .42477 Mdot
.45558 .56519 Mdot
.63622 .62989 Mdot
.36521 .74552 Mdot
.41012 .56865 Mdot
.20881 .5681 Mdot
.2793 .57235 Mdot
.62602 .82308 Mdot
.58612 .81491 Mdot
.24855 .50005 Mdot
.51299 .48938 Mdot
.46175 .57524 Mdot
.8397 .48128 Mdot
.55791 .61956 Mdot
.8059 .59794 Mdot
.23428 .49848 Mdot
.53818 .22876 Mdot
.75005 .58404 Mdot
.7234 .60571 Mdot
.72106 .50512 Mdot
.55379 .25237 Mdot
.82239 .51576 Mdot
.55265 .54925 Mdot
.36776 .66505 Mdot
.38326 .77333 Mdot
.83366 .39954 Mdot
.29088 .35003 Mdot
.57954 .55932 Mdot
.70247 .69186 Mdot
.48458 .52499 Mdot
.63836 .56862 Mdot
.35211 .46754 Mdot
.60443 .5819 Mdot
.22227 .5359 Mdot
.27357 .32628 Mdot
.80797 .62074 Mdot
.59784 .36953 Mdot
.69578 .41554 Mdot
.35555 .53394 Mdot
.4399 .65164 Mdot
.32485 .29551 Mdot
.86514 .46049 Mdot
.32827 .53182 Mdot
.19822 .60862 Mdot
.32233 .58624 Mdot
.74644 .66576 Mdot
.22509 .68501 Mdot
.33748 .5862 Mdot
.68188 .78303 Mdot
.3042 .3857 Mdot
.58371 .236 Mdot
.26415 .32204 Mdot
.74805 .60606 Mdot
.53784 .26919 Mdot
.55623 .51701 Mdot
.83094 .57765 Mdot
.62988 .56709 Mdot
.62276 .62159 Mdot
.82464 .50111 Mdot
.55681 .82957 Mdot
.51087 .82433 Mdot
.34826 .57131 Mdot
.3898 .39906 Mdot
.252 .71839 Mdot
.35047 .68806 Mdot
.51412 .1695 Mdot
.80587 .58333 Mdot
.65424 .27043 Mdot
.48807 .43757 Mdot
.35561 .45597 Mdot
.84376 .49237 Mdot
.62947 .79335 Mdot
.53098 .49583 Mdot
.40748 .62589 Mdot
.7151 .61526 Mdot
.69333 .69621 Mdot
.33316 .45367 Mdot
.77503 .62288 Mdot
.3718 .61563 Mdot
.59213 .62235 Mdot
.57154 .82807 Mdot
.30794 .3134 Mdot
.70776 .507 Mdot
.82222 .40167 Mdot
.72854 .47685 Mdot
.5126 .834 Mdot
.23074 .50401 Mdot
.37385 .76139 Mdot
.83357 .40786 Mdot
.30118 .35273 Mdot
.57222 .27465 Mdot
.82839 .3452 Mdot
.84699 .56279 Mdot
.46332 .57522 Mdot
.55127 .39164 Mdot
.67232 .78692 Mdot
.40348 .63292 Mdot
.73443 .68263 Mdot
.51243 .19536 Mdot
.4909 .81964 Mdot
.60943 .31151 Mdot
.55722 .38155 Mdot
.62128 .5832 Mdot
.39099 .33002 Mdot
.40803 .39378 Mdot
.35699 .71354 Mdot
.53131 .82867 Mdot
.54277 .2093 Mdot
.50461 .20206 Mdot
.58207 .22005 Mdot
.42429 .34231 Mdot
.82105 .59111 Mdot
.52468 .62159 Mdot
.53021 .19606 Mdot
.83505 .47687 Mdot
.71799 .40898 Mdot
.35966 .51451 Mdot
.51757 .22024 Mdot
.67702 .60214 Mdot
.41149 .78648 Mdot
.83471 .37137 Mdot
.52421 .241 Mdot
.86098 .53751 Mdot
.7615 .68224 Mdot
.42186 .34502 Mdot
.31817 .35944 Mdot
.61801 .5491 Mdot
.46175 .54677 Mdot
.21726 .54771 Mdot
.34807 .68335 Mdot
.50921 .80765 Mdot
.39579 .62611 Mdot
.61819 .39194 Mdot
.35676 .44865 Mdot
.792 .62386 Mdot
.61663 .5977 Mdot
.79848 .617 Mdot
.54553 .23949 Mdot
.57139 .38329 Mdot
.82878 .33305 Mdot
.23333 .386 Mdot
.62124 .32704 Mdot
.53308 .54629 Mdot
.5835 .56502 Mdot
.59958 .45679 Mdot
.30557 .50829 Mdot
.66263 .61769 Mdot
.46611 .81599 Mdot
.8313 .57336 Mdot
.32307 .33493 Mdot
.62557 .56108 Mdot
.3054 .56909 Mdot
.64704 .53302 Mdot
.60962 .30797 Mdot
.33179 .53523 Mdot
.4393 .80609 Mdot
.22003 .57679 Mdot
.34386 .49741 Mdot
.39325 .56754 Mdot
.66003 .56876 Mdot
.57135 .55451 Mdot
.45205 .80543 Mdot
.31489 .59005 Mdot
.35388 .52185 Mdot
.56192 .83619 Mdot
.56074 .25869 Mdot
.30845 .46069 Mdot
.3861 .76395 Mdot
.65054 .58831 Mdot
.37267 .44678 Mdot
.4728 .5584 Mdot
.57419 .19805 Mdot
.8349 .50941 Mdot
.3929 .7417 Mdot
.55272 .54852 Mdot
.638 .23153 Mdot
.84558 .52124 Mdot
.30017 .5606 Mdot
.69916 .76395 Mdot
.47122 .58498 Mdot
.32128 .30005 Mdot
.67042 .27228 Mdot
.51376 .43872 Mdot
.63857 .38047 Mdot
.54338 .42434 Mdot
.68972 .48181 Mdot
.20077 .56611 Mdot
.52354 .45794 Mdot
.40589 .57248 Mdot
.43992 .56338 Mdot
.6374 .61373 Mdot
.63629 .37684 Mdot
.59688 .43402 Mdot
.525 .57701 Mdot
.70027 .59506 Mdot
.60544 .57013 Mdot
.63638 .61975 Mdot
.29282 .46585 Mdot
.45197 .80673 Mdot
.5066 .82313 Mdot
.5463 .33046 Mdot
.84757 .49068 Mdot
.67975 .30898 Mdot
.80336 .58934 Mdot
.3753 .47983 Mdot
.29103 .46292 Mdot
.72815 .47099 Mdot
.83332 .37261 Mdot
.41324 .42412 Mdot
.50618 .56042 Mdot
.75568 .68541 Mdot
.78481 .62077 Mdot
.2886 .47328 Mdot
.22633 .36724 Mdot
.38589 .77674 Mdot
.62726 .57396 Mdot
.27581 .32144 Mdot
.36613 .69147 Mdot
.75501 .66927 Mdot
.53882 .37103 Mdot
.46795 .58569 Mdot
.55536 .19726 Mdot
.59005 .32002 Mdot
.38132 .68665 Mdot
.58264 .19999 Mdot
.55515 .25166 Mdot
.82139 .51864 Mdot
.59618 .46472 Mdot
.42726 .48716 Mdot
.43448 .41294 Mdot
.8252 .39146 Mdot
.39004 .71862 Mdot
.71861 .43166 Mdot
.52149 .16645 Mdot
.20075 .56435 Mdot
.48233 .80257 Mdot
.8191 .40749 Mdot
.26792 .56829 Mdot
.53201 .39054 Mdot
.17931 .43555 Mdot
.42395 .41911 Mdot
.44476 .38423 Mdot
.33366 .56986 Mdot
.68014 .7088 Mdot
.4024 .43387 Mdot
.83787 .35895 Mdot
.76827 .64699 Mdot
.52671 .35046 Mdot
.50632 .1652 Mdot
.57629 .82605 Mdot
.70772 .43532 Mdot
.29656 .45661 Mdot
.81445 .60233 Mdot
.21769 .54055 Mdot
.66099 .79217 Mdot
.47137 .51458 Mdot
.32336 .36932 Mdot
.69093 .68997 Mdot
.26301 .33447 Mdot
.52081 .43432 Mdot
.50301 .19285 Mdot
.24602 .36185 Mdot
.70704 .67535 Mdot
.49556 .47438 Mdot
.34413 .41581 Mdot
.32715 .41075 Mdot
.46184 .48554 Mdot
.4674 .59771 Mdot
.41987 .55985 Mdot
.43858 .52812 Mdot
.34551 .50629 Mdot
.44767 .47932 Mdot
.22853 .39205 Mdot
.27558 .57943 Mdot
.56365 .22963 Mdot
.3985 .77693 Mdot
.64811 .62606 Mdot
.41608 .63792 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2@ooooo`;o0000]oooool001co
oooo00?o0000ooooooooool0T?ooool2o`000;Oooooo000Looooo`03o`000?oooooooooo093ooooo
0_l00003ooooo`Go0000[oooool001cooooo0_l0002Fooooo`Go000000?oooooo`000?l00000[?oo
ool001cooooo00?o0000ooooooooool0Uoooool6o`000:cooooo000Looooo`03o`000?oooooooooo
09Sooooo1_l0002[ooooo`007?ooool00ol0003oooooooooo`2Kooooo`Go0000ZOooool001cooooo
00?o0000ooooooooool0W_ooool5o`0000Cooooo0_l0002Pooooo`007?ooool00ol0003ooooooooo
o`2Oooooo`Co00000oooool4o`0009oooooo000Looooo`03o`000?oooooooooo0:?ooooo0_l00000
0ooooooo0000o`000002o`0009oooooo000Looooo`03o`000?oooooooooo09gooooo0_l00004oooo
o`;o00001_ooool2o`0009cooooo000Looooo`03o`000?oooooooooo09gooooo0_l000000ooooooo
0000o`000003o`0000Kooooo1?l0002Jooooo`007?ooool00ol0003oooooooooo`2Pooooo`Oo0000
0oooool2o`000003ooooool0003o000000;o0000V?ooool001cooooo00?o0000ooooooooool0Xooo
ool4o`0000?ooooo0_l00003ooooo`;o00000_ooool2o`0009Cooooo000Looooo`03o`000?oooooo
oooo0:?ooooo1?l0000<ooooo`;o0000U?ooool001cooooo00?o0000ooooooooool0Xoooool6o`00
0:3ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool0
0ol0003oooooooooo`2Pooooo`Go00000_ooool3o`00017ooooo0_l0002<ooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo
00?o0000ooooooooool0X?ooool:o`0000Wooooo1?l00004ooooo`;o0000S?ooool00003ooooool@
413ooooo00;ooooo00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oo
oooooooo0:7ooooo2Ol00007ooooo`[o0000S_ooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool02oooool00onHV9So8B4Qonk^kP06ooooo`?o0000X?ooool9o`0000Sooooo0_l00004
ooooo`Go00000oooool2o`0008Sooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`2Pooooo`[o00004?ooool2o`00
00?ooooo0_l00028ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0=ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0Xoooool2o`000003ooooool0003o000000;o
0000Woooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So
410@00Kooooo00?o0000ooooooooool0Xoooool2o`000003ooooool0003o000000Gooooo0_l0000C
ooooo`;o0000QOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`00
0?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0[?ooool3o`0000[ooooo0_l00007ooooo`;o0000
QOooool001cooooo00?o0000ooooooooool0Xoooool3o`0000Kooooo1?l00003ooooo`;o00001?oo
ool2o`0008kooooo000Looooo`03o`000?oooooooooo0:?ooooo0ol00008ooooo`;o00000oooool2
o`0000Cooooo0_l0002>ooooo`007?ooool00ol0003oooooooooo`2Sooooo`?o00004oooool4o`00
08cooooo000Looooo`03o`000?oooooooooo0:Cooooo0_l000000ooooooo0000o`000009ooooo`;o
00001oooool2o`0008cooooo000Looooo`03o`000?oooooooooo0:?ooooo1_l00002ooooo`;o0000
1Oooool3o`0000;ooooo0_l00002ooooo`?o00002Oooool4o`0007kooooo000Looooo`03o`000?oo
oooooooo0:;ooooo1Ol00004ooooo`;o00001_ooool2o`000004ooooool0003o0000o`0000;ooooo
4_l0001looooo`007?ooool00ol0003oooooooooo`2Rooooo`Go00003oooool3o`000003ooooool0
003o0000017o0000O?ooool001cooooo00?o0000ooooooooool0Xoooool4o`0000Kooooo0_l00003
ooooo`;o00001_ooool2o`000003ooooool0003o000000Gooooo1Ol00003ooooo`;o0000Noooool0
01cooooo00?o0000ooooooooool0Y?ooool2o`000003ooooool0003o000000Cooooo0_l00003oooo
o`;o00003oooool2o`0000Oooooo0_l0001kooooo`007?ooool00ol0003oooooooooo`2Sooooo`?o
000000?oooooo`000?l000006_ooool2o`0000Wooooo0_l0001iooooo`007?ooool00ol0003ooooo
ooooo`2Sooooo`;o00004oooool4o`0000?ooooo0_l000000ooooooo0000o`00000:ooooo`;o0000
NOooool001cooooo0_l0002Tooooo`?o00002_ooool3o`0000Gooooo1?l00003ooooo`;o000000Co
ooooo`000?l0003o00003?ooool2o`0007Kooooo000Looooo`03o`000?oooooooooo0:?ooooo1?l0
0009ooooo`?o00001Oooool2o`0000;ooooo1?l00002ooooo`?o00003?ooool2o`0007Kooooo000L
ooooo`03o`000?oooooooooo0:?ooooo1?l0000>ooooo`;o00001Oooool8o`0000Cooooo0_l00007
ooooo`;o0000M_ooool001cooooo00?o0000ooooooooool0YOooool2o`0000Gooooo0_l00004oooo
o`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo1ol000000ooooooo0000o`000003o`00
07oooooo000Looooo`03o`000?oooooooooo0:Gooooo0_l00005ooooo`;o00001?ooool2o`0000Co
oooo0ol0000:ooooo`Ko000000?oooooo`000?l000001_ooool3o`0007;ooooo000Looooo`03o`00
0?oooooooooo0:Gooooo0_l0000Aooooo`?o00003Oooool6o`0000Kooooo0ol0001booooo`007?oo
ool00ol0003oooooooooo`2[ooooo`;o000000?oooooo`000?l000006?ooool4o`0000;ooooo1Ol0
001fooooo`007?ooool00ol0003oooooooooo`2[ooooo`Go00007Oooool6o`0000;ooooo0ol0001a
ooooo`007?ooool00ol0003oooooooooo`2/ooooo`;o000000?oooooo`000?l000001Oooool2o`00
01Gooooo0ol00005ooooo`?o0000LOooool001cooooo00?o0000ooooooooool0[oooool2o`0000Go
oooo0_l0000Eooooo`Oo0000MOooool001cooooo00?o0000ooooooooool0[oooool2o`0000;ooooo
0_l0000Hooooo`Oo0000MOooool001cooooo00?o0000ooooooooool0KOooool4o`0000Wooooo0_l0
000[ooooo`;o00001_ooool2o`0000;ooooo0_l0000Iooooo`Co00001oooool2o`0006kooooo000L
ooooo`03o`000?oooooooooo06Oooooo0_l00004ooooo`Ko00001oooool3o`0002[ooooo0_l0000@
ooooo`;o00005?ooool3o`0000Oooooo0_l0001^ooooo`007?ooool00ol0003oooooooooo`1Toooo
o`;o000000?oooooo`000?l000002?ooool2o`0000Sooooo0ol0000Yooooo`?o00002Oooool2o`00
00Cooooo0_l0000Dooooo`;o00002_ooool2o`0006cooooo000Looooo`03o`000?oooooooooo067o
oooo0_l000000ooooooo0000o`000002o`0000Wooooo1?l00007ooooo`;o00001?ooool3o`0002;o
oooo0ol00009ooooo`;o00006_ooool2o`0000[ooooo0_l0001/ooooo`007?ooool00ol0003ooooo
ooooo`1Mooooo`Ko00000oooool2o`0000Wooooo1_l00002ooooo`;o00001oooool3o`0002;ooooo
0_l0000;ooooo`;o00001oooool2o`0000oooooo0ol00005ooooo`;o0000LOooool001cooooo0_l0
001Mooooo`Oo00000_ooool2o`0000Sooooo0_l000000ooooooo0000o`000003o`0000;ooooo0_l0
000/ooooo`;o00001_ooool2o`0000?ooooo0_l00007ooooo`;o00003oooool2o`0000Kooooo0_l0
001aooooo`007?ooool00ol0003oooooooooo`1Iooooo`Go00001?ooool2o`000003ooooool0003o
000000Oooooo0ol000000ooooooo0000o`000003o`0000Wooooo1ol0000Xooooo`;o00002Oooool2
o`0001Gooooo1ol00002ooooo`;o0000KOooool001cooooo00?o0000ooooooooool0FOooool4o`00
0003ooooool0003o000000;ooooo0_l0000:ooooo`?o00003oooool7o`0000;ooooo0ol0000Yoooo
o`;o00000oooool2o`0001Gooooo1ol00002ooooo`?o0000K?ooool001cooooo00?o0000oooooooo
ool0E_ooool2o`0000Kooooo0_l0000:ooooo`;o00006_ooool2o`000003ooooool0003o000000;o
0000:?ooool3o`0000[ooooo0_l0000=ooooo`co0000K?ooool001cooooo00?o0000ooooooooool0
E_ooool3o`0000?ooooo0_l00002ooooo`;o00002?ooool4o`000003ooooool0003o000001Gooooo
0_l00002ooooo`?o0000:?ooool6o`000003ooooool0003o000000Cooooo0_l00009ooooo`;o0000
00?oooooo`000?l000002Ol0001^ooooo`007?ooool00ol0003oooooooooo`1Gooooo`;o00000ooo
ool2o`0000;ooooo0_l00008ooooo`Oo00006Oooool3o`0002Sooooo1_l000000ooooooo0000o`00
0004ooooo`;o00002Oooool:o`000003ooooool0003o000000;o0000KOooool001cooooo00?o0000
ooooooooool0Doooool2o`0000;ooooo0_l00007ooooo`;o00001_ooool7o`0001_ooooo0_l0000Y
ooooo`?o00000_ooool4o`0000?ooooo0_l0000:ooooo`oo0000KOooool001cooooo00?o0000oooo
ooooool0D_ooool3o`000004ooooool0003o0000o`0000?ooooo0_l00009ooooo`So00007oooool2
o`0001Cooooo0_l0000Dooooo`Go00000_ooool2o`0000[ooooo3Ol0001_ooooo`007?ooool00ol0
003oooooooooo`1Booooo`;o000000Coooooo`000?l0003o00001?ooool2o`0000Wooooo2?l0000?
ooooo`Co00003?ooool2o`0001Cooooo0_l00005ooooo`;o00000_ooool2o`0000[ooooo1?l0000>
ooooo`ko0000K_ooool001cooooo00?o0000ooooooooool0D_ooool2o`000003ooooool0003o0000
00?ooooo0_l0000;ooooo`Go00002oooool3o`0000Cooooo1?l000001?oooooo0000o`000?l00004
ooooo`;o00000_ooool2o`0001_ooooo0_l00002ooooo`;o00003oooool2o`0000Cooooo1?l00003
ooooo`ko0000<?ooool2o`0003cooooo000Looooo`03o`000?oooooooooo057ooooo0_l00007oooo
o`;o00001oooool9o`0000_ooooo2ol000001?oooooo0000o`000?l00004ooooo`;o00000_ooool3
o`0001gooooo0_l0000@ooooo`;o00001?ooool4o`0000?ooooo3?l0000booooo`;o0000??ooool0
01cooooo00?o0000ooooooooool0C?ooool2o`0000?ooooo0ol0000=ooooo`[o00002_ooool@o`00
00;ooooo0_l00005ooooo`?o00004_ooool2o`0000Wooooo0_l0000?ooooo`?o00002oooool<o`00
033ooooo0_l000000ooooooo0000o`00000kooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o
00001?ooool2o`0000Cooooo0_l00007ooooo`;o00000_ooool6o`0000Gooooo0ol00002oooooaKo
00006?ooool2o`0000_ooooo0_l0000=ooooo`?o00001_ooool2o`000003ooooool0003o000000co
0000<?ooool5o`0003_ooooo000Looooo`03o`000?oooooooooo04cooooo0_l0000:ooooo`;o0000
0oooool2o`0000Cooooo0_l00002ooooo`Co00000_ooool2o`000003ooooool0003o000001_o0000
8oooool2o`0001?ooooo0_l000001?oooooo0000o`000?ooool=o`0003?ooooo0ol0000kooooo`00
7?ooool00ol0003oooooooooo`1<ooooo`;o00002Oooool2o`0000Cooooo0_l00004ooooo`;o0000
0_ooool2o`0000Cooooo0_l00002oooooaco000000?oooooo`000?l000004Oooool2o`0000Wooooo
0_l0000>ooooo`;o00001oooool5o`000003ooooool0003o000000_o0000<_ooool4o`0003_ooooo
000Looooo`03o`000?oooooooooo05Oooooo0_l0000>ooooo`;o00000oooool4o`000003ooooool0
003o0000023o00003_ooool2o`0000Wooooo0_l00006ooooo`;o00001_ooool4o`0000Kooooo4Ol0
000booooo`?o0000?Oooool001cooooo0_l00019ooooo`;o00001_ooool2o`000003ooooool0003o
000000Kooooo0_l0000:ooooo`;o00000ooooolXo`0001?ooooo0_l0000;ooooo`;o00002?ooool2
o`0000Oooooo0_l000000ooooooo0000o`00000:o`0003?ooooo1Ol0000kooooo`007?ooool00ol0
003oooooooooo`18ooooo`;o00001Oooool3o`000003ooooool0003o000000Kooooo0_l000000ooo
oooo0000o`000007ooooo`;o00001?ooool=o`000003ooooool0003o000000ko00001?ooool6o`00
00;ooooo0_l0000>ooooo`;o000000?oooooo`000?l000008?ooool;o`0003Gooooo0_l0000koooo
o`007?ooool00ol0003oooooooooo`19ooooo`;o00001?ooool2o`0000;ooooo0_l00002ooooo`;o
00001Oooool2o`0000[ooooo8?l00005ooooo`?o000000?oooooo`000?l000001?l00005ooooo`;o
00002_ooool2o`00017ooooo1ol00007ooooo`Oo00000oooool2o`0003Gooooo0_l0000kooooo`00
7?ooool00ol0003oooooooooo`16ooooo`;o000000?oooooo`000?l000002?ooool2o`000004oooo
ool0003o0000o`0000_ooooo1?l00002ooooo`Ko000000Coooooo`000?l0003ooooo5ol00007oooo
o`Oo00001Oooool3o`0001?ooooo0_l00003ooooo`;o00000_ooool7o`000003ooooool0003o0000
00Cooooo2?l0000fooooo`Ko0000>_ooool001cooooo00?o0000ooooooooool0A_ooool2o`0000Co
oooo0_l00008ooooo`?o00002oooool4o`0000Cooooo7ol00007ooooo`?o00000_ooool2o`0000Ko
oooo0_l0000@ooooo`Go00000_ooool6o`0000;ooooo1?l000000ooooooo0000o`000004ooooo`So
0000=_ooool6o`0003[ooooo000Looooo`03o`000?oooooooooo04cooooo0_l00007ooooo`Co0000
3?ooool2o`0000;ooooo9_l00006ooooo`;o00006_ooool5o`0000;ooooo1_l00004ooooo`;o0000
1oooool3o`0003_ooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`14ooooo`Co00001?oo
ool2o`0000?ooooo0_l00002ooooo`;o00001Oooool3o`0000Kooooo0_l000000ooooooo0000o`00
000Vo`0000?ooooo1?l00007ooooo`;o00004Oooool5o`0000?ooooo1_l000000ooooooo0000o`00
0002o`0000;ooooo0ol00002ooooo`?o0000>oooool2o`000003ooooool0003o000003_ooooo000L
ooooo`03o`000?oooooooooo04?ooooo1Ol00003ooooo`;o00001?ooool2o`0000Wooooo0ol00006
ooooo`;o000000?oooooo`000?l000007ol000000ooooooo0000o`000002ooooo`;o00000_ooool3
o`0000Wooooo0_l0000;ooooo`;o00000_oooolFo`000004ooooool0003o0000o`0000;ooooo0ol0
000mooooo`?o0000>oooool001cooooo00?o0000ooooooooool0@_ooool3o`000003ooooool0003o
000000?ooooo0_l0000Eooooo`;o00001OoooolPo`000003ooooool0003o000000?ooooo0_l00000
0ooooooo0000o`00000Gooooo`;o00000_oooolJo`0000;ooooo0ol0000mooooo`?o0000>oooool0
01cooooo00?o0000ooooooooool0@_ooool3o`0000Wooooo0_l0000Booooo`;o000000Coooooo`00
0?l0003ooooo7_l00006ooooo`So00006oooool4o`0000;ooooo0_l000000ooooooo0000o`00000?
o`000004ooooool0003o0000o`0003kooooo0ol0000kooooo`007?ooool00ol0003oooooooooo`12
ooooo`;o00002?ooool4o`0001Gooooo5_l000000ooooooo0000o`000008o`0000Kooooo2?l00009
ooooo`;o00003oooool5o`000003ooooool0003o000001?o000000?oooooo`000?l000001?l0000l
ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0@_ooool2o`0000Cooooo0_l00002oooo
o`;o00005oooool4o`0000?ooooo0ol000000ooooooo0000o`00000@o`0000_ooooo1Ol0000;oooo
o`;o00000_ooool2o`0000Oooooo0_l00002ooooo`;o000000?oooooo`000?l000005_l000000ooo
oooo0000o`000004o`0003Sooooo0ol000000ooooooo0000o`00000kooooo`007?ooool00ol0003o
ooooooooo`10ooooo`?o00001Oooool3o`0001Cooooo0_l0000;oooooaKo00001oooool2o`0000;o
oooo1Ol0000=ooooo`Co00001oooool3o`0000Cooooo6?l000000ooooooo0000o`00000looooo`?o
000000?oooooo`000?l00000>oooool001cooooo00?o0000ooooooooool0@?ooool3o`0000Gooooo
0ol0000Dooooo`?o00000oooool2o`0000Oooooo0_l000000ooooooo0000o`00000?o`000003oooo
ool0003o000000;o00000_ooool2o`000003ooooool0003o000000;o00003oooool2o`0000Sooooo
1Ol00002ooooo`Co000000?oooooo`000?l000004_l000001?oooooo0000o`000?l0000oooooo`;o
0000>oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@
413oooooooooo`04ooooo`03o`000?oooooooooo03oooooo1?l000001?oooooo0000o`000?ooool2
o`000003ooooool0003o000001Cooooo0_l00003ooooo`Co00000_ooool2o`0000;ooooo3Ol00002
ooooo`Wo00000oooool5o`0001[ooooo0_l000001?oooooo0000o`000?oooolJo`000004ooooool0
003o0000o`0003_ooooo0_l000001?oooooo0000o`000?l0000kooooo`0000KoooooogMgMonHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
03oooooo0_l00002ooooo`?o000000?oooooo`000?l000000ol0000Iooooo`Co00000_ooool2o`00
00;ooooo0_l000000ooooooo0000o`000007o`0000?ooooo0_l000000ooooooo0000o`000006oooo
o`Co00005oooool2o`0000Sooooo6ol000000ooooooo0000o`00000looooo`;o000000Coooooo`00
0?l0003o0000>oooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool5o`00
00Kooooo00?o0000ooooooooool0??ooool2o`0000Cooooo0ol00004ooooo`;o00006_ooool3o`00
00;ooooo0_l00008ooooo`?o00000_ooool4o`0000cooooo1?l0000>ooooo`;o00001oooool2o`00
00;ooooo0_l00004oooooa_o000000?oooooo`000?l00000>oooool2o`000004ooooool0003o0000
o`0003cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgM
gOoooooo00001oooool3o`0003cooooo1Ol000001?oooooo0000o`000?l0000Pooooo`?o00000_oo
ool2o`0000gooooo1?l0000:ooooo`Co00002?ooool2o`0000Kooooo0_l0000;ooooo`;o00001?oo
oolKo`000003ooooool0003o000000;o0000>Oooool2o`000003ooooool0003o000000;o0000>ooo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?oMgMgoEEEEooooool0
0007ooooo`03o`000?oooooooooo03gooooo1?l00005ooooo`;o00007_ooool2o`0000;ooooo0_l0
000Booooo`?o00000_ooool6o`0000[ooooo0_l0000:ooooo`;o00003OoooolKo`0000;ooooo0ol0
000iooooo`;o000000?oooooo`000?l000000_l0000kooooo`0000?ooooooa0@4?ooool00_ooool0
0ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0>oooool4
o`0000Gooooo1?l0000Oooooo`;o00005?ooool4o`0000;ooooo1Ol00004ooooo`;o00004Oooool2
o`0000Sooooo0_l00003oooooa_o00007?ooool2o`0001oooooo0_l00003ooooo`;o0000??ooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oo
oooooooo03_ooooo1?l00005ooooo`?o00008?ooool2o`0000;ooooo0_l0000>ooooo`So000000?o
ooooo`000?l000000oooool5o`0001_ooooo0_l00004ooooo`Wo000000?oooooo`000?l000003_l0
0002ooooo`;o00006?ooool2o`0001oooooo1?l000000ooooooo0000o`00000looooo`0000Kooooo
onk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0
??ooool2o`0002Wooooo0_l00002ooooo`;o00001_ooool2o`0000Kooooo2?l00006ooooo`?o0000
00?oooooo`000?l000007_oooolLo`0000;ooooo0_l0000Aooooo`;o000000?oooooo`000?l00000
8oooool4o`0000?ooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`0looooo`;o00000ooo
ool2o`00023ooooo0_l00002ooooo`;o00000oooool3o`0000Cooooo0_l00006ooooo`Ko00001?oo
ool2o`0000;ooooo0_l00002ooooo`?o00004oooool2o`0000Cooooo0_l00002ooooo`;o000000?o
ooooo`000?l000005_l00003ooooo`;o00004Oooool2o`000003ooooool0003o000002?ooooo0_l0
0005ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0>Oooool3o`0000Gooooo0_l0000M
ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo0ol0000:ooooo`Co00002?ooool3
o`000003ooooool0003o000000?ooooo0_l0000Cooooo`;o00000oooool3o`0000;ooooo0_l00000
0ooooooo0000o`00000Fo`0003kooooo0_l00007ooooo`;o0000>?ooool001cooooo00?o0000oooo
ooooool0>?ooool4o`0000Gooooo0_l0000Looooo`Co00001?ooool2o`0000Sooooo0ol00005oooo
o`;o00001oooool2o`0000;ooooo0_l000000ooooooo0000o`00000Mooooo`;o00000ooooolKo`00
01Gooooo0_l0000`ooooo`?o0000=oooool001cooooo00?o0000ooooooooool0>?ooool2o`0002Co
oooo1Ol0000>ooooo`?o000000?oooooo`000?l000002oooool2o`0000Cooooo0_l0000<ooooo`;o
00000oooool2o`00013ooooo6ol000000ooooooo0000o`00000Booooo`;o00002Oooool2o`0002Ko
oooo1?l0000eooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00009?ooool5o`0000Wooooo
0_l00007ooooo`;o00004Oooool2o`0000cooooo0_l00003ooooo`;o00004?oooolJo`0000;ooooo
0_l0000Booooo`;o00002Oooool2o`0001gooooo0_l00009ooooo`;o0000=Oooool001cooooo00?o
0000ooooooooool0=oooool2o`0002Kooooo1?l00009ooooo`;o00002oooool2o`0000Cooooo0_l0
000Cooooo`;o00000_ooool2o`0000Gooooo0_l00007ooooo`;o00000ooooolJo`0001Kooooo0_l0
0007ooooo`;o00007oooool2o`0000?ooooo0_l00004ooooo`;o0000=Oooool001cooooo00?o0000
ooooooooool0=Oooool7o`00027ooooo1?l0000=ooooo`;o000000?oooooo`000?l000000_ooool6
o`0000Cooooo0_l0000Cooooo`;o00000_ooool2o`0000Gooooo0_l00004ooooo`;o000000?ooooo
o`000?l000001?oooolIo`0001_ooooo0_l00002ooooo`;o00000oooool3o`0001kooooo0_l00004
ooooo`;o000000?oooooo`000?l00000<_ooool001cooooo00?o0000ooooooooool0=Oooool7o`00
01oooooo1ol00005ooooo`;o00001Oooool>o`0001oooooo0_l00006ooooo`Co00000_ooool2o`00
00?ooooo6Ol00002ooooo`;o00005oooool2o`0000Cooooo1_l0000Uooooo`Co0000<_ooool001co
oooo00?o0000ooooooooool0=Oooool6o`00023ooooo0ol00002ooooo`;o000000?oooooo`000?l0
00000_ooool4o`0000Gooooo1_l00004ooooo`;o000000?oooooo`000?l000007?ooool3o`0000Go
oooo0_l00004ooooo`?o00000_oooolHo`000003ooooool0003o000000?o00006_ooool8o`0001So
oooo0_l0000;ooooo`Co0000<_ooool001cooooo00?o0000ooooooooool0=Oooool4o`0002?ooooo
0ol00004ooooo`Go000000Coooooo`000?l0003o00004Oooool2o`0001cooooo0ol00007ooooo`;o
00000_ooool3o`0000?ooooo0_l000000ooooooo0000o`00000=o`000003ooooool0003o000000Go
000000?oooooo`000?l000006_ooool2o`0000?ooooo0_l0000Iooooo`?o000000?oooooo`000?l0
00002Oooool2o`0003;ooooo000Looooo`03o`000?oooooooooo03Gooooo0ol0000Rooooo`;o0000
00?oooooo`000?l000000_l00003ooooo`Co000000Coooooo`000?l0003o00001?ooool2o`0000?o
oooo0_l00007ooooo`;o00009Oooool2o`0000;ooooo0_l00004ooooo`?o000000?oooooo`000?l0
00005?l0000Looooo`Co00000_ooool2o`0001[ooooo0_l000000ooooooo0000o`00000mooooo`00
7?ooool2o`0005Wooooo1?l00003ooooo`Co000000Coooooo`000?l0003o00002Oooool2o`0000?o
oooo0_l00007ooooo`Co00007_ooool4o`000003ooooool0003o000000;ooooo0_l00004oooooaCo
00000_ooool4o`0001cooooo1?l00003ooooo`;o00006Oooool2o`00043ooooo000Looooo`03o`00
0?oooooooooo05Sooooo0_l00006ooooo`?o00000_ooool2o`000003ooooool0003o000000_ooooo
0_l00009ooooo`;o00007_ooool4o`000003ooooool0003o000000Sooooo0_l000000ooooooo0000
o`00000Eo`0001kooooo0_l00003ooooo`;o00006Oooool2o`00043ooooo000Looooo`03o`000?oo
oooooooo05gooooo0_l000001?oooooo0000o`000?l00002ooooo`;o000000?oooooo`000?l00000
1_ooool2o`0000Sooooo0_l0000Yooooo`?o00001oooool2o`0000;ooooo4ol0000Qooooo`;o0000
0oooool3o`0001[ooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`1Fooooo`;o00000_oo
ool2o`000004ooooool0003o0000ooooo`?o00001?ooool2o`0000Gooooo1?l00008ooooo`;o0000
:_ooool2o`0000Cooooo0_l00006ooooo`?o00000_ooool:o`000003ooooool0003o000002Oooooo
0_l0000Hooooo`Co00002_ooool2o`0003;ooooo000Looooo`03o`000?oooooooooo05Kooooo0_l0
0002ooooo`?o00000oooool2o`0000Gooooo0_l00005ooooo`?o0000=Oooool2o`0000Cooooo0_l0
0006ooooo`;o00001?ooool2o`0000;ooooo0_l00004ooooo`;o00009_ooool2o`0001Wooooo0_l0
00000ooooooo0000o`000005ooooo`;o00000_ooool3o`00037ooooo000Looooo`03o`000?oooooo
oooo05Wooooo1Ol0000:ooooo`;o00001Oooool2o`0003Gooooo0ol00008ooooo`;o000000?ooooo
o`000?l000001?ooool2o`000003ooooool0003o000000;o00008oooool2o`0000Cooooo1?l0000L
ooooo`;o00001Oooool2o`0000?ooooo0_l0000aooooo`007?ooool00ol0003oooooooooo`1Boooo
o`;o00001Oooool7o`0000Sooooo0_l00005ooooo`;o00003Oooool2o`0002?ooooo0_l000001Ooo
oooo0000o`000?l0003ooooo00;o00001Oooool2o`000003ooooool0003o000000Oooooo1?l0000S
ooooo`;o00000oooool3o`0002Gooooo0_l000000ooooooo0000o`00000cooooo`007?ooool00ol0
003oooooooooo`1@ooooo`Go00001?ooool7o`0001kooooo0_l0000Sooooo`;o00001Oooool2o`00
0003ooooool0003o0000037ooooo0ol00006ooooo`;o00009_ooool2o`000003ooooool0003o0000
03?ooooo000Looooo`03o`000?oooooooooo053ooooo0_l000000ooooooo0000o`000002o`0000;o
oooo1_l000000ooooooo0000o`000003o`0001_ooooo0_l0000Fooooo`;o00000oooool4o`0000co
oooo0_l0000aooooo`?o00001_ooool2o`0000;ooooo0_l0000Looooo`;o000000?oooooo`000?l0
00000_ooool2o`0003Gooooo000Looooo`03o`000?oooooooooo05Cooooo1Ol000000ooooooo0000
o`000003o`000003ooooool0003o000000Go00000_ooool2o`0000Kooooo0_l00003ooooo`;o0000
2?ooool2o`0000cooooo0_l00008ooooo`;o00000oooool6o`0000Cooooo0_l00002ooooo`;o0000
<_ooool2o`000004ooooool0003o0000o`0000Cooooo0_l00002ooooo`;o00007?ooool2o`000003
ooooool0003o000000;ooooo0_l0000eooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o0000
1?ooool3o`000003ooooool0003o000000cooooo1ol00005ooooo`;o00000oooool2o`0001Kooooo
1?l0000?ooooo`;o00001?ooool2o`0000;ooooo0_l0000_ooooo`;o000000?oooooo`000?l00000
1_l0000Sooooo`;o000000?oooooo`000?l00000>_ooool001cooooo00?o0000ooooooooool0COoo
ool2o`0000Cooooo0_l0000@ooooo`So00003_ooool2o`0001?ooooo1?l0000=ooooo`;o00000ooo
ool2o`0000?ooooo0_l0000_ooooo`;o00000_ooool7o`0002?ooooo0_l000000ooooooo0000o`00
000jooooo`007?ooool00ol0003oooooooooo`1Booooo`;o00004Oooool2o`000004ooooool0003o
0000ooooo`?o00000_ooool2o`0000Wooooo0_l0000:ooooo`;o00002Oooool2o`0000gooooo1?l0
00000ooooooo0000o`000003ooooo`;o0000;_ooool3o`0000Oooooo0ol0000Wooooo`Co0000=_oo
ool001cooooo00?o0000ooooooooool0D_ooool2o`00017ooooo0_l000001?oooooo0000o`000?oo
ool3o`0000;ooooo0_l0000Eooooo`;o00001Oooool2o`0001?ooooo0_l00004ooooo`;o00000ooo
ool2o`000003ooooool0003o000000;o00009_ooool2o`0000Oooooo1?l000001?oooooo0000o`00
0?ooool2o`00023ooooo1Ol0000fooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00006Ooo
ool4o`0001oooooo0_l0000Booooo`?o00000oooool3o`0000?ooooo0_l000000ooooooo0000o`00
0002o`0002oooooo1?l000000ooooooo0000o`000003o`00023ooooo0ol0000hooooo`007?ooool0
0ol0003oooooooooo`17ooooo`?o00001_ooool2o`0001[ooooo0ol0000Nooooo`;o00004oooool4
o`0000;ooooo0ol0000iooooo`?o00000_ooool4o`0002Gooooo0_l0000eooooo`007?ooool2o`00
04Sooooo0ol00003ooooo`;o00007Oooool2o`0001oooooo0_l0000:ooooo`;o00002Oooool2o`00
00?ooooo0_l00005ooooo`;o00000oooool3o`0002_ooooo1?l00004ooooo`;o00006oooool2o`00
00Sooooo0_l000000ooooooo0000o`000002o`00033ooooo000Looooo`03o`000?oooooooooo04Oo
oooo0_l00004ooooo`;o0000B_ooool2o`0000gooooo0_l00006ooooo`;o00000oooool3o`0002[o
oooo1Ol00003ooooo`?o00006oooool2o`0000_ooooo1?l0000`ooooo`007?ooool00ol0003ooooo
ooooo`17ooooo`;o00000_ooool3o`0000cooooo2Ol0000:ooooo`;o00009_ooool2o`0000Wooooo
0_l00006ooooo`;o0000=oooool7o`0000;ooooo0_l0000Mooooo`;o00002?ooool2o`0003Cooooo
000Looooo`03o`000?oooooooooo04_ooooo0ol0000<ooooo`co00001oooool2o`0002Kooooo0_l0
0009ooooo`;o00002Oooool2o`0000gooooo0_l0000Eooooo`;o00003_ooool4o`000004ooooool0
003o0000ooooo`?o00007Oooool4o`0000Kooooo0_l0000dooooo`007?ooool00ol0003ooooooooo
o`15ooooo`;o00003oooool<o`000004ooooool0003o0000o`0000Oooooo0_l00006ooooo`;o0000
=?ooool2o`0000gooooo0ol0000@ooooo`;o00000_ooool2o`0000oooooo1?l00003ooooo`?o0000
6oooool2o`0000;ooooo0_l0000looooo`007?ooool00ol0003oooooooooo`15ooooo`;o00000_oo
ool2o`0000Kooooo5?l0000<ooooo`;o00000_ooool2o`0001[ooooo0_l00002ooooo`;o000000?o
ooooo`000?l000000_l0000Eooooo`;o00002?ooool3o`0000oooooo0_l0000Cooooo`Co00000_oo
ool2o`0001gooooo0_l00006ooooo`;o00001?ooool2o`0003;ooooo000Looooo`03o`000?oooooo
oooo04Wooooo0_l00006oooooaGo000000?oooooo`000?l000002?ooool2o`0001Oooooo0_l00005
ooooo`?o000000Coooooo`000?l0003ooooo1?l0000Eooooo`?o000000?oooooo`000?l000001Ooo
ool4o`0002;ooooo0ol00003ooooo`;o00007Oooool4o`0000Cooooo0_l00004ooooo`;o0000<_oo
ool001cooooo00?o0000ooooooooool0A_ooool5o`0000Cooooo6_l00006ooooo`?o00006?ooool2
o`0000Kooooo0_l0000Nooooo`;o000000?oooooo`000?l000001Oooool4o`0002;ooooo0ol00003
ooooo`;o00007Oooool4o`0000Cooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`16oooo
o`?o00001OoooolLo`000003ooooool0003o000000;ooooo0ol0000Jooooo`;o00001oooool2o`00
00?ooooo0_l0000Rooooo`Go00007oooool2o`0000Cooooo0_l0000Uooooo`?o0000=oooool001co
oooo00?o0000ooooooooool0AOooool4o`0000Gooooo5ol000000ooooooo0000o`000002o`000003
ooooool0003o000000Gooooo0_l0000Gooooo`?o00001oooool2o`0000?ooooo0_l0000Tooooo`?o
00007oooool2o`0000;ooooo0ol0000Wooooo`;o000000?oooooo`000?l00000=?ooool001cooooo
00?o0000ooooooooool0A?ooool5o`0000Oooooo6_l00006ooooo`Co00005Oooool4o`0000Cooooo
0_l00007ooooo`;o00004oooool3o`0000kooooo0_l000000ooooooo0000o`00000Mooooo`;o0000
0_ooool3o`0001gooooo0_l00009ooooo`Co0000=?ooool001cooooo00?o0000ooooooooool0A?oo
ool2o`0000Sooooo7?l00005ooooo`?o00000_ooool2o`0001?ooooo0_l00006ooooo`;o00006?oo
ool:o`0000_ooooo0_l000001?oooooo0000o`000?ooool3o`0000Cooooo1ol000000ooooooo0000
o`00000:ooooo`?o000000Coooooo`000?l0003o00007_ooool2o`0000Wooooo0_l0000fooooo`00
7?ooool00ol0003oooooooooo`14ooooo`?o00001OoooolNo`0000Gooooo0ol00002ooooo`;o0000
1_ooool2o`0000[ooooo1?l0000Oooooo`_o00003?ooool2o`0000;ooooo0ol000001?oooooo0000
o`000?ooool:o`0000[ooooo0ol000001?oooooo0000o`000?l0000/ooooo`;o0000<oooool001co
oooo00?o0000ooooooooool0?_ooool2o`0000?ooooo1?l00005oooooago00000_ooool2o`0000oo
oooo0_l000000ooooooo0000o`000007ooooo`Co00006oooool2o`0000;ooooo1_l000000ooooooo
0000o`000002o`0000cooooo0_l00006ooooo`;o00000_ooool=o`0000Cooooo1Ol0000`ooooo`;o
0000<oooool001cooooo00?o0000ooooooooool0?_ooool2o`0000?ooooo0_l0000:oooooa_o0000
00?oooooo`000?l000000oooool4o`0000_ooooo0_l0000Dooooo`;o00003Oooool2o`000005oooo
ool0003o0000o`000?ooool01_l000001?oooooo0000o`000?l00007ooooo`;o00005_ooool>o`00
00;ooooo0ol0000Wooooo`;o0000>Oooool001cooooo00?o0000ooooooooool0?_ooool2o`0000?o
oooo0_l00009oooooaco000000Coooooo`000?l0003o00000_ooool4o`0001kooooo0_l000000ooo
oooo0000o`000003ooooo`;o00002?ooool2o`000003ooooool0003o000000;o00000oooool3o`00
00Kooooo0_l00003ooooo`;o00000oooool2o`0001?ooooo3?l00002ooooo`?o00009oooool2o`00
00?ooooo0_l0000dooooo`007?ooool2o`0004Cooooo1?l00006oooooaco00000oooool2o`0000;o
oooo0_l0000Kooooo`;o00000oooool2o`0000?ooooo0_l000000ooooooo0000o`00000=oooooa3o
00002?ooool2o`0000;ooooo0_l0000?ooooo`Wo000000Coooooo`000?l0003ooooo0ol0000Woooo
o`;o00001?ooool2o`0003Cooooo000Looooo`03o`000?oooooooooo04Cooooo0ol00006oooooa_o
00002?ooool2o`0001_ooooo0_l00007ooooo`?o00002_ooool2o`0000Gooooo4?l00004ooooo`;o
00001Oooool2o`0000;ooooo0ol0000:ooooo`Go00000oooool2o`0000?ooooo0ol0000Wooooo`;o
0000>_ooool001cooooo00?o0000ooooooooool0A?ooool2o`0000_ooooo5ol0000Xooooo`;o0000
1?ooool2o`0000Wooooo1?l000000ooooooo0000o`000002oooooa7o00000oooool2o`0000Oooooo
2_l00007ooooo`?o00000oooool2o`0000;ooooo0ol0001Tooooo`007?ooool00ol0003ooooooooo
o`10ooooo`;o00000_ooool2o`0000_ooooo6?l00006ooooo`;o00003Oooool2o`0000Cooooo0ol0
0009ooooo`;o00001?ooool2o`0000Wooooo1ol00002oooooa7o00000oooool2o`0000Oooooo0_l0
0003ooooo`Ko00001Oooool8o`000003ooooool0003o000000;o00009Oooool2o`0000Gooooo0_l0
000gooooo`007?ooool00ol0003oooooooooo`10ooooo`Co00001Oooool2o`0000Wooooo4Ol00002
ooooo`;o00000oooool2o`000003ooooool0003o000000Kooooo0ol00004ooooo`;o000000?ooooo
o`000?l000001?l00004ooooo`;o00001?ooool2o`0000?ooooo0_l00009ooooo`;o00000_ooool2
o`0000;ooooo5?l000000ooooooo0000o`000007ooooo`;o00001oooool2o`0000Gooooo3Ol0000U
ooooo`;o00001?ooool3o`0003Oooooo000Looooo`03o`000?oooooooooo03kooooo0_l00002oooo
o`;o00001Oooool3o`0000[ooooo3Ol000001?oooooo0000o`000?l00005ooooo`Go00001_ooool3
o`0000Oooooo0ol00007ooooo`;o00000oooool3o`0000gooooo0_l00007oooooaGo00002Oooool2
o`0000Oooooo0_l00006ooooo`[o0000;Oooool3o`0003Oooooo000Looooo`03o`000?oooooooooo
03kooooo1Ol00007ooooo`;o00001oooool2o`000003ooooool0003o000000;ooooo2Ol000001Ooo
oooo0000o`000?l0003ooooo00;o00001?ooool3o`0000_ooooo0_l00003ooooo`;o00003Oooool2
o`0000gooooo1Ol00004oooooaKo00002oooool2o`000003ooooool0003o000000;ooooo0_l00000
0ooooooo0000o`000006ooooo`Oo0000Ioooool001cooooo00?o0000ooooooooool0@?ooool3o`00
00Sooooo0_l00006ooooo`;o00000_ooool2o`0000Kooooo0_l00007ooooo`?o00000_ooool4o`00
00[ooooo0ol00002ooooo`?o00000oooool2o`0000Gooooo0_l0000@ooooo`;o000000?oooooo`00
0?l000001?ooool<o`000003ooooool0003o000000Ko00001?ooool2o`0000Kooooo0_l000000ooo
oooo0000o`000005ooooo`;o00002?ooool3o`0002Kooooo0_l00011ooooo`007?ooool00ol0003o
ooooooooo`15ooooo`?o00000oooool4o`0000Cooooo0_l00002ooooo`;o00004?ooool2o`0000;o
oooo0ol0000;ooooo`?o00000_ooool2o`0000Cooooo0_l00005ooooo`;o00000oooool3o`0000?o
oooo0_l00005ooooo`;o000000Coooooo`000?l0003o00000ooooolDo`0000Gooooo0_l00005oooo
o`;o00000_ooool2o`0000Kooooo0ol0000_ooooo`;o00000_ooool2o`0000;ooooo0_l0000ioooo
o`007?ooool00ol0003oooooooooo`14ooooo`Co00000oooool4o`0000Cooooo0_l00006ooooo`Co
00003oooool2o`0001gooooo0_l00003ooooo`?o00000oooool2o`0000Gooooo1_l000000ooooooo
0000o`00000Do`000003ooooool0003o000000Wooooo0_l0000:ooooo`?o00006oooool2o`0001Ko
oooo0_l00002ooooo`;o0000>Oooool001cooooo00?o0000ooooooooool0?oooool2o`000003oooo
ool0003o000000;o00001_ooool2o`000003ooooool0003o000000Gooooo0_l00003ooooo`Co0000
3oooool4o`0002kooooo1?l00002oooooaWo00000_ooool2o`0000Gooooo0_l0000:ooooo`;o0000
00?oooooo`000?l000005_ooool2o`000003ooooool0003o000001;ooooo0_l00002ooooo`;o0000
0_ooool2o`0003Wooooo000Looooo`03o`000?oooooooooo03oooooo0_l000001?oooooo0000o`00
0?l00007ooooo`;o000000?oooooo`000?l000001Oooool2o`00017ooooo0_l00004ooooo`Co0000
2_ooool2o`0000oooooo0_l00002ooooo`;o000000?oooooo`000?l000002oooool6o`000003oooo
ool0003o000001Co00000_ooool2o`0000?ooooo1?l0000=ooooo`Co00005?ooool5o`0000kooooo
0_l000001?oooooo0000o`000?l00006ooooo`;o0000>Oooool001cooooo00?o0000ooooooooool0
Goooool4o`0000;ooooo0_l00002ooooo`?o00001?ooool3o`0000[ooooo0_l0000?ooooo`;o0000
00?oooooo`000?l000001?l00006ooooo`;o00001Oooool4o`000003ooooool0003o000001Co0000
0_ooool2o`0000?ooooo1?l00004ooooo`;o00001_ooool2o`000004ooooool0003o0000o`0000oo
oooo0_l00003ooooo`Co00003_ooool2o`000003ooooool0003o000000Gooooo0_l0000kooooo`00
7?ooool00ol0003oooooooooo`10ooooo`;o00002Oooool3o`000003ooooool0003o000000;o0000
0oooool2o`0000Oooooo2Ol00002ooooo`;o000000?oooooo`000?l000000ol0000>ooooo`;o0000
1_ooool2o`0000Oooooo0_l000000ooooooo0000o`000007ooooo`;o00001_ooool2o`0000;ooooo
5Ol00003ooooo`;o00001Oooool3o`000003ooooool0003o000000Co00001?ooool2o`000003oooo
ool0003o000000;o000000?oooooo`000?l000000_l00009ooooo`;o00001?ooool2o`0000kooooo
0ol00003ooooo`;o00000oooool2o`0003_ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGo
oooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`10oooo
o`;o00002Oooool3o`000003ooooool0003o000000;o00000oooool2o`0000;ooooo1?l00003oooo
o`Co000000?oooooo`000?l000000ol00002ooooo`Go00001?ooool2o`0000Cooooo0_l00002oooo
o`;o00001_ooool2o`0000Oooooo0_l000000ooooooo0000o`00000=ooooo`Co00000_oooolFo`00
00;ooooo0_l000001?oooooo0000o`000?l00002ooooo`;o000000Goooooo`000?l0003o0000oooo
o`03o`000003ooooool0003o000000;o00000_ooool:o`0000Cooooo0_l0000Gooooo`;o00001?oo
ool4o`0003kooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEE
EOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1Jooooo`Co00000oooool4o`0000;o
oooo1?l00003ooooo`;o00001?ooool4o`0000Cooooo0_l00002ooooo`;o00001?ooool2o`0000Wo
oooo1?l00008ooooo`?o00000_ooool3o`0000Gooooo5Ol00002ooooo`;o000000Coooooo`000?l0
003o00000_ooool2o`0000;ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00001oooool7
o`0000Cooooo1?l00003ooooo`Go00005?ooool3o`0003kooooo00000ooooooo410@ooooo`02oooo
o`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo03_ooooo0_l0000aooooo`;o00001?ooool2o`00013ooooo0_l0000;ooooo`?o00001oooool3
o`0000;ooooo1?l00004oooooaCo00001oooool2o`0000;ooooo0_l00005ooooo`;o00003_ooool2
o`0000Sooooo0_l00003ooooo`Go00003_ooool4o`0000;ooooo0_l0000oooooo`0000?oooooo`00
0?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3
o`0003_ooooo0_l00017ooooo`;o00003_ooool2o`0000Kooooo0_l00006ooooo`;o00002?ooool>
o`000003ooooool0003o000000Kooooo0_l00005ooooo`;o00002_ooool4o`0001?ooooo0ol0000>
ooooo`Oo00000_ooool2o`0003kooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo08Cooooo0_l0000F
ooooo`;o00002?ooool2o`0000Kooooo3_l000000ooooooo0000o`000007ooooo`Co00000_ooool2
o`0000Sooooo1_l0000:ooooo`?o00000_ooool2o`000004ooooool0003o0000o`0000cooooo1Ol0
0003ooooo`;o00000_ooool2o`0003kooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooo
oooo00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`0mooooo`;o0000=?ooool2
o`0000?ooooo1?l00002ooooo`Ko00003Oooool2o`0000cooooo0_l00005ooooo`;o000000Cooooo
o`000?l0003o00000oooool<o`0000_ooooo1?l00003ooooo`;o00001_ooool5o`0000cooooo0ol0
0002ooooo`Ko00003?ooool4o`0000?ooooo0_l00013ooooo`0000KoooooogMgMonHV9SooooooiRH
V?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0?Oooool2o`00033ooooo
1_l00003ooooo`Co00000_ooool9o`0000[ooooo0_l0000<ooooo`?o00001oooool4o`0000Cooooo
0ol000000ooooooo0000o`000003o`0000?ooooo0_l0000>ooooo`Go00000oooool2o`000003oooo
ool0003o0000013ooooo0_l000001?oooooo0000o`000?l0000Dooooo`;o0000@oooool00006oooo
ooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooo
oooo03cooooo0_l0000`ooooo`[o00002oooool5o`0000Cooooo0_l00003ooooo`;o00003Oooool4
o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Cooooo1?l0
0002ooooo`;o00000oooool3o`0000Kooooo0_l000000ooooooo0000o`000002o`0000Wooooo0_l0
0007ooooo`;o00001?ooool5o`0005[ooooo000Looooo`03o`000?oooooooooo03cooooo0_l0000`
ooooo`;o00001?ooool4o`0000?ooooo0_l00009ooooo`;o00001?ooool2o`0000?ooooo0_l0000:
ooooo`Co000000?oooooo`000?l000002_l00004ooooo`Co000000?oooooo`000?l000000_l00007
ooooo`?o00001_ooool2o`0000Kooooo0_l00006ooooo`;o000000?oooooo`000?l000001?ooool2
o`0000Kooooo0ol0000<ooooo`;o00000oooool2o`0004Oooooo000Looooo`03o`000?oooooooooo
03_ooooo0_l0000^ooooo`?o00003Oooool2o`0000Oooooo0_l00002ooooo`;o00004oooool4o`00
00?ooooo0_l000000ooooooo0000o`000006o`000003ooooool0003o000000Co00002?ooool2o`00
00;ooooo0_l00003ooooo`;o00000_ooool2o`0000Kooooo1?l00007ooooo`;o00002_ooool4o`00
00gooooo0_l00003ooooo`;o000000?oooooo`000?l00000A?ooool001cooooo00?o0000oooooooo
ool0>oooool2o`0002kooooo0ol00002ooooo`?o00003oooool4o`0000;ooooo0ol0000Looooo`Co
000000Goooooo`000?l0003o0000ooooo`04o`000003ooooool0003o000000?ooooo0_l000001?oo
oooo0000o`000?l00006ooooo`?o00000_ooool2o`0000;ooooo0_l00002ooooo`Go00001oooool2
o`0000Kooooo1_l0000;ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o0000A?ooool0
01cooooo00?o0000ooooooooool0J_ooool4o`0000;ooooo0ol0000:ooooo`;o00000_ooool5o`00
0003ooooool0003o000000?o00008?ooool5o`000003ooooool0003o000000?o00000oooool2o`00
0003ooooool0003o000000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000001?ooool2o`00
00Cooooo1Ol00005ooooo`;o00001Oooool7o`0000_ooooo0_l00003ooooo`;o0000B_ooool001co
oooo00?o0000ooooooooool0??ooool2o`0002cooooo0ol0000@ooooo`;o00000_ooool8o`000003
ooooool0003o000002;ooooo0ol00002ooooo`?o00000_ooool4o`0000?ooooo0_l000000ooooooo
0000o`000005ooooo`Co00000_ooool3o`0000Cooooo1_l00009ooooo`Go000000?oooooo`000?l0
00003_ooool4o`0004[ooooo000Looooo`03o`000?oooooooooo03cooooo0_l0000/ooooo`?o0000
4_ooool;o`0002Wooooo0_l00003ooooo`Go00000_ooool2o`000003ooooool0003o000000;o0000
1Oooool2o`0000?ooooo0_l00006ooooo`[o00000_ooool6o`00017ooooo1?l000000ooooooo0000
o`000017ooooo`007?ooool00ol0003oooooooooo`0looooo`Co0000:Oooool4o`0001;ooooo1?l0
0003ooooo`Co0000;oooool5o`000004ooooool0003o0000ooooo`Ko00002Oooool2o`0000Kooooo
4Ol0000Fooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0??ooool4o`0002Wooooo1_l0
000:ooooo`?o00000_ooool7o`000003ooooool0003o000000?o0000<Oooool2o`0000Sooooo0_l0
0009ooooo`;o00002Oooool;o`0001;ooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`1Z
ooooo`;o000000?oooooo`000?l000002Oooool4o`000003ooooool0003o000000Ko000000?ooooo
o`000?l000001Ol0000_ooooo`?o000000?oooooo`000?l000000oooool7o`0000Cooooo0_l0000:
ooooo`_o00003oooool2o`000003ooooool0003o000004kooooo000Looooo`03o`000?oooooooooo
03gooooo0_l0000Zooooo`?o00003?ooool4o`000003ooooool0003o000000oo0000;oooool2o`00
0003ooooool0003o000000;ooooo2Ol00003ooooo`;o00003Oooool7o`00013ooooo1Ol00002oooo
o`;o0000B_ooool001cooooo00?o0000ooooooooool0?Oooool2o`0002[ooooo0ol0000:ooooo`;o
00000ooooolCo`0003;ooooo0_l000000ooooooo0000o`000009o`00017ooooo0_l000000ooooooo
0000o`000002o`0000cooooo0_l00002ooooo`Go00000_ooool2o`0004[ooooo000Looooo`;o0000
J_ooool3o`0000Wooooo0ol00003ooooo`Ko000000?oooooo`000?l000002ol0000aooooo`;o0000
00?oooooo`000?l000002Ol00005ooooo`;o00002_ooool2o`000003ooooool0003o000000kooooo
0_l00002ooooo`Co00000oooool2o`0004[ooooo000Looooo`03o`000?oooooooooo06Wooooo0ol0
0003ooooo`;o00001?ooool3o`000003ooooool0003o000001Co0000<?ooool@o`0000Cooooo0_l0
00000ooooooo0000o`00000Uooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0?oooool2
o`0002Wooooo0_l00003ooooo`;o00001OoooolIo`00033ooooo4?l00007ooooo`;o0000LOooool0
01cooooo00?o0000ooooooooool0?oooool2o`0002Wooooo0_l0000<oooooaOo0000<?ooool2o`00
0003ooooool0003o000000go00001?ooool2o`0007;ooooo000Looooo`03o`000?oooooooooo06[o
oooo0_l00008ooooo`;o00000_oooolGo`00033ooooo4_l00004ooooo`;o0000L_ooool001cooooo
00?o0000ooooooooool0M?ooool2o`000003ooooool0003o000001?o000000?oooooo`000?l00000
<?oooolEo`0001_ooooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`1eoooooa[o0000<_oo
oolCo`0001Gooooo0_l00002ooooo`Ko0000E_ooool001cooooo00?o0000ooooooooool0Joooool3
o`0000Kooooo6ol0000booooo`oo000000?oooooo`000?l000001?ooool2o`0000Kooooo0_l00006
ooooo`Co00000_ooool2o`000004ooooool0003o0000o`0000Cooooo0_l0001@ooooo`007?ooool0
0ol0003oooooooooo`15ooooo`;o00009?ooool3o`0000Kooooo2?l000000ooooooo0000o`00000=
o`000003ooooool0003o000003;ooooo4_l00004ooooo`;o00001_ooool2o`000003ooooool0003o
000000?ooooo0_l0000>ooooo`;o0000D?ooool001cooooo00?o0000ooooooooool0@oooool4o`00
02Gooooo0_l00009oooooa7o000000?oooooo`000?l000000_l0000boooooaGo00003_ooool2o`00
00?ooooo0_l0000:ooooo`Co0000D_ooool001cooooo00?o0000ooooooooool0@oooool3o`0002Ko
oooo0ol00006oooooaSo0000<_oooolEo`0001?ooooo0_l00002ooooo`;o000000?oooooo`000?l0
00000oooool4o`0005;ooooo000Looooo`03o`000?oooooooooo04?ooooo1?l0000Uooooo`?o0000
1_oooolHo`0003?ooooo4?l000000ooooooo0000o`00000Dooooo`;o00000_ooool2o`000003oooo
ool0003o000000;ooooo1Ol0001Booooo`007?ooool00ol0003oooooooooo`15ooooo`;o00009Ooo
ool4o`0000Kooooo6?l0000booooo`go000000?oooooo`000?l000000ol0000Oooooo`?o0000E?oo
ool001cooooo00?o0000ooooooooool0BOooool2o`00027ooooo1?l00002ooooo`?o00000_oooolH
o`00037ooooo5Ol00008ooooo`;o000000?oooooo`000?l00000Ioooool001cooooo00?o0000oooo
ooooool0BOooool2o`0002;ooooo0_l000000ooooooo0000o`000003o`0000;ooooo6?l0000doooo
oa;o00002?ooool2o`000003ooooool0003o000000?ooooo0_l0001Rooooo`007?ooool00ol0003o
ooooooooo`1:ooooo`;o00008Oooool2o`000003ooooool0003o000000;o00000_oooolDo`0000?o
oooo0_l00004ooooo`;o0000;_oooolCo`0000Oooooo0_l00006ooooo`;o00001oooool2o`0005Wo
oooo000Looooo`;o0000Boooool2o`0002Kooooo0_l00002oooooaGo00000_ooool2o`0000Cooooo
0_l0000^oooooa?o00001oooool3o`0000gooooo0ol0001Iooooo`007?ooool00ol0003ooooooooo
o`1]ooooo`;o00001ooooolGo`0003Sooooo4Ol00008ooooo`;o00002?ooool2o`0000?ooooo0_l0
001Jooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00007_ooool3o`0000Gooooo0_l00000
0ooooooo0000o`00000Co`0003Wooooo3ol0000Cooooo`;o0000Goooool001cooooo00?o0000oooo
ooooool0C?ooool3o`0001kooooo0ol00005ooooo`;o00000_oooolDo`0003Sooooo0_l000000ooo
oooo0000o`000002ooooo`Oo00001_ooool2o`000003ooooool0003o000006_ooooo000Looooo`03
o`000?oooooooooo04cooooo0_l0000Oooooo`Go00000oooool2o`0000;ooooo4ol0000iooooo`;o
000000?oooooo`000?l000002?l00007ooooo`;o000000?oooooo`000?l000002_ooool2o`0005oo
oooo000Looooo`03o`000?oooooooooo04_ooooo0_l00003ooooo`;o00006oooool2o`000003oooo
ool0003o000000Cooooo5_l0000mooooo`Wo00004oooool2o`000003ooooool0003o000005oooooo
000Looooo`03o`000?oooooooooo04_ooooo0_l000000ooooooo0000o`000003o`0001[ooooo0_l0
0007ooooo`?o000000?oooooo`000?l000003?l00010ooooo`;o000000?oooooo`000?l000000_l0
0005ooooo`;o00003_ooool3o`0006;ooooo000Looooo`03o`000?oooooooooo04kooooo0_l00000
0ooooooo0000o`00000Tooooo`So00001Oooool4o`00043ooooo0_l00002ooooo`Co00001?ooool2
o`000003ooooool0003o000000Sooooo0_l000000ooooooo0000o`00001Sooooo`007?ooool00ol0
003oooooooooo`1_ooooo`;o00001_ooool3o`0000;ooooo0ol000001?oooooo0000o`000?l0000;
ooooo`;o0000?_ooool2o`000003ooooool0003o000000Cooooo0_l00004ooooo`;o000000Cooooo
o`000?l0003o0000I_ooool001cooooo00?o0000ooooooooool0E?ooool2o`0001Wooooo0_l00008
ooooo`[o00002oooool2o`0003oooooo1?l00007ooooo`;o000000Coooooo`000?l0003ooooo0_l0
001Wooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o00006Oooool2o`0000Sooooo0ol00002
ooooo`Co0000COooool4o`0000Oooooo0_l0001]ooooo`007?ooool00ol0003oooooooooo`1_oooo
o`;o00002Oooool2o`000<gooooo000Looooo`03o`000?oooooooooo06oooooo1Ol00008ooooo`;o
0000boooool001cooooo00?o0000ooooooooool0L?ooool4o`0000Sooooo1?l00039ooooo`007?oo
ool00ol0003oooooooooo`1`ooooo`?o00002Oooool4o`0000Kooooo0_l00031ooooo`007?ooool0
0ol0003oooooooooo`1aooooo`Co00003Oooool2o`0000;ooooo0_l00031ooooo`007?ooool2o`00
07;ooooo1_l0000;ooooo`;o0000aOooool001cooooo00?o0000ooooooooool0L_ooool2o`000003
ooooool0003o00000=;ooooo000Looooo`03o`000?oooooooooo07?ooooo0_l000000ooooooo0000
o`00003Aooooo`007?ooool00ol0003oooooooooo`1cooooo`Go0000KOooool2o`0006;ooooo000L
ooooo`03o`000?oooooooooo07Cooooo1?l0001]ooooo`;o0000H_ooool001cooooo00?o0000oooo
ooooool0M?ooool4o`0000;ooooo0_l0001Booooo`Co00000oooool2o`0000Sooooo0ol0001Woooo
o`007?ooool00ol0003oooooooooo`1eooooo`?o00000_ooool2o`0005;ooooo1?l00003ooooo`;o
000000?oooooo`000?l000001Oooool3o`0000;ooooo0_l0001Sooooo`007?ooool00ol0003ooooo
ooooo`1fooooo`Co0000F_ooool2o`0000;ooooo0_l0000:ooooo`;o0000Hoooool001cooooo00?o
0000ooooooooool0N?ooool3o`0005Wooooo0_l0001cooooo`007?ooool00ol0003oooooooooo`1g
ooooo`Go00000_ooool2o`0005_ooooo0_l000000ooooooo0000o`00001Yooooo`007?ooool00ol0
003oooooooooo`1gooooo`Go00000_ooool2o`00057ooooo0_l00005ooooo`;o000000Coooooo`00
0?l0003ooooo0_l0001Yooooo`007?ooool00ol0003oooooooooo`1iooooo`?o0000Boooool2o`00
00Sooooo0_l00005ooooo`Go0000K?ooool001cooooo00?o0000ooooooooool0NOooool2o`0000;o
oooo0_l00003ooooo`;o0000@oooool2o`0000Sooooo0_l00004ooooo`Ko0000K?ooool001cooooo
00?o0000ooooooooool0O?ooool3o`0000?ooooo0ol00002ooooo`;o0000?Oooool2o`0000oooooo
0_l0001`ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co
8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0O?ooool2o`0000Gooooo1_l0000[oooo
o`;o00001?ooool4o`0000Sooooo0_l000000ooooooo0000o`000002o`0000Cooooo1Ol0001coooo
o`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonH
V9So8B4Q00Kooooo00?o0000ooooooooool0O_ooool2o`0000Cooooo0ol0000]ooooo`;o00000ooo
ool5o`0000Sooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000Ko0000Looo
ool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool0O_ooool3o`0000?ooooo0_l0000cooooo`;o00003ooo
ool3o`000003ooooool0003o000000;o0000Moooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool02Oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0001oooooo`;o00004_oo
ool2o`0000Cooooo0_l0000_ooooo`;o0000OOooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool02Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0Q?oo
ool2o`0000Gooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00000_ooool4o`0000Kooooo
0_l00004ooooo`;o00003Oooool2o`0000[ooooo0ol00024ooooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooo
ooooo`23ooooo`?o00001Oooool2o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`Co0000
00?oooooo`000?l000000oooool3o`0000?ooooo0ol00004ooooo`;o00001_ooool2o`0000[ooooo
0ol00008ooooo`;o0000N_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o
^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0Poooool2o`000003ooooool0003o0000
01Cooooo0_l00004ooooo`;o00000_ooool4o`0000Cooooo0_l0000;ooooo`?o00000_ooool3o`00
00[ooooo0_l0001jooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o
0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`26ooooo`;o00003?ooool2o`0000Kooooo0_l0
0007ooooo`?o000000?oooooo`000?l000003oooool4o`000003ooooool0003o000000;o0000Q_oo
ool001cooooo00?o0000ooooooooool0R_ooool2o`0000Sooooo0_l000000ooooooo0000o`000003
ooooo`;o00001_ooool3o`0000;ooooo0_l00007ooooo`;o00001_ooool3o`0000;ooooo0_l00028
ooooo`007?ooool00ol0003oooooooooo`2:ooooo`?o00002_ooool2o`0000?ooooo0_l00006oooo
o`;o00001?ooool2o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`;o000000Coooooo`00
0?l0003o0000ROooool001cooooo00?o0000ooooooooool0Roooool7o`0000[ooooo0_l00002oooo
o`Co00000_ooool2o`0000;ooooo0_l00003ooooo`;o00002Oooool2o`000004ooooool0003o0000
o`0000Sooooo0ol0001nooooo`007?ooool00ol0003oooooooooo`2=ooooo`Go00000_ooool4o`00
00Cooooo0_l00002ooooo`Co00000_ooool2o`0000_ooooo0_l000001Ooooooo0000o`000?l0003o
oooo00;o00002_ooool5o`0007kooooo000Looooo`03o`000?oooooooooo08oooooo0ol00002oooo
o`Co00004Oooool2o`000003ooooool0003o000000?ooooo1?l000001Ooooooo0000o`000?l0003o
oooo00;o00000_ooool2o`0000Cooooo1_l0001oooooo`007?ooool00ol0003oooooooooo`2Foooo
o`;o00001?ooool2o`0000Gooooo0_l00004ooooo`;o000000?oooooo`000?l000000oooool2o`00
00[ooooo0ol00004ooooo`?o0000P_ooool001cooooo00?o0000ooooooooool0W?ooool2o`0000Go
oooo0ol000000ooooooo0000o`000004o`0000;ooooo0_l00002ooooo`Go00001Oooool2o`0000Ko
oooo0_l00022ooooo`007?ooool00ol0003oooooooooo`2Sooooo`?o000000?oooooo`000?l00000
1?l00002ooooo`;o00000_ooool5o`00097ooooo000Looooo`03o`000?oooooooooo0:Sooooo1Ol0
00001?oooooo0000o`000?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0008gooooo
000Looooo`03o`000?oooooooooo0:_ooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo
0_l000000ooooooo0000o`000002o`0008gooooo000Looooo`03o`000?oooooooooo0;7ooooo0_l0
0002ooooo`;o0000T_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooo
ooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB_ooool001Cooooo00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o
0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Doooo
o`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`00
4_ooool00omEEEGoIVIVo`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo002Uooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05_ooool4o`00
0007oa0@4?oooooooooooa0@4?l0003oA4A4olc<c004ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0
T?ooool00:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00003?ooool00ol0003ooooo
ooooo`04ooooo`03oiRHV?l@413ogMgM00?ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@2@ooooo`00
Y_ooool01Ol0003ooooooooooooooooo000001_ooooo00?o0000ooooooooool01Oooool00on7QhOo
EEEEooooo`02ooooo`05o`000?ooooooooooooooool00000T?ooool00:Kooooo00Go0000oooooooo
ooooooooo`000009ooooo`Ko00003?ooool00ol0003oooooooooo`02ooooo`05olc<c?lQ8B7o0000
oeEEEOl000000oooool01Olb<S;oV9RHoooooonHV9So<S8b093ooooo002Vooooo`05o`000?n7QhOo
ooooojVYZOl000006oooool00ol0003oooooooooo`02ooooo`05ob4Q8On7QhOooooooiRHV?l00000
0oooool01Oo<c<co0000o`000?l0003oc<c<093ooooo002Uooooo`03oa0@4?l0003oMgMg00;o0000
00?oV9RHooooooooool06Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol@413o^[Zjoooooonj^[[o410@093ooooo0036ooooo`03o`000?oooooooooo00;o
oooo00Go8B4QoiRHV?ooooooMgMgoeEEE@03ooooo`05o`000?nj^[[ooooookZj^_l00000T?ooool0
0<Cooooo00?oEEEEofIVI_l000001?ooool01Oo<c<co410@o`000?lb<S;ok^k^00?ooooo00GoZJVY
oa0@4?l0003o410@ojVYZ@2@ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(204) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.45522 .36182 Mdot
.40637 .34854 Mdot
.367 .69729 Mdot
.57146 .43759 Mdot
.58529 .66296 Mdot
.35568 .67353 Mdot
.28018 .50615 Mdot
.28963 .49572 Mdot
.41466 .65133 Mdot
.61385 .3175 Mdot
.31541 .50412 Mdot
.56365 .45313 Mdot
.29199 .50892 Mdot
.59529 .43373 Mdot
.64299 .58767 Mdot
.67446 .38371 Mdot
.41938 .33062 Mdot
.59139 .72859 Mdot
.68006 .38125 Mdot
.41743 .63908 Mdot
.56156 .64153 Mdot
.60972 .42563 Mdot
.37313 .35665 Mdot
.59559 .43143 Mdot
.67227 .3755 Mdot
.3983 .35182 Mdot
.45471 .36064 Mdot
.68825 .35848 Mdot
.56553 .42367 Mdot
.28653 .47942 Mdot
.68796 .35015 Mdot
.727 .64783 Mdot
.52501 .58882 Mdot
.56012 .29023 Mdot
.26948 .48407 Mdot
.33141 .53956 Mdot
.38166 .68359 Mdot
.27297 .47912 Mdot
.317 .5347 Mdot
.30632 .49818 Mdot
.29972 .49201 Mdot
.39245 .34832 Mdot
.2605 .48612 Mdot
.18174 .56569 Mdot
.59031 .42478 Mdot
.55691 .20028 Mdot
.33862 .69876 Mdot
.5718 .4565 Mdot
.36903 .35172 Mdot
.41126 .68002 Mdot
.65893 .66379 Mdot
.30492 .50718 Mdot
.54584 .57639 Mdot
.50732 .14982 Mdot
.28829 .50077 Mdot
.67405 .37871 Mdot
.36875 .64995 Mdot
.5968 .40478 Mdot
.58731 .46934 Mdot
.55004 .25908 Mdot
.59295 .39961 Mdot
.60768 .68029 Mdot
.46828 .38317 Mdot
.38211 .70541 Mdot
.4129 .66271 Mdot
.26445 .48067 Mdot
.43529 .33278 Mdot
.26584 .51322 Mdot
.57094 .44163 Mdot
.40634 .63309 Mdot
.58353 .39002 Mdot
.31498 .50318 Mdot
.44728 .34737 Mdot
.61574 .43172 Mdot
.4671 .35195 Mdot
.32939 .50727 Mdot
.57063 .69429 Mdot
.39759 .37592 Mdot
.39874 .70158 Mdot
.63969 .54239 Mdot
.6153 .42748 Mdot
.18447 .40678 Mdot
.69858 .59625 Mdot
.43157 .36439 Mdot
.6356 .4028 Mdot
.23365 .34546 Mdot
.59816 .37814 Mdot
.66969 .36593 Mdot
.68168 .36165 Mdot
.58908 .5357 Mdot
.36751 .64711 Mdot
.37292 .34777 Mdot
.60817 .4194 Mdot
.58321 .45503 Mdot
.60949 .31212 Mdot
.58529 .39311 Mdot
.67674 .36764 Mdot
.55448 .60974 Mdot
.3118 .51722 Mdot
.54644 .59787 Mdot
.3399 .57184 Mdot
.5339 .58365 Mdot
.59155 .38329 Mdot
.36831 .67263 Mdot
.45544 .3441 Mdot
.53043 .5922 Mdot
.2636 .5021 Mdot
.60475 .42225 Mdot
.33578 .47398 Mdot
.37449 .35644 Mdot
.69648 .35974 Mdot
.59267 .68565 Mdot
.47422 .60629 Mdot
.44369 .34821 Mdot
.65092 .24879 Mdot
.58111 .44394 Mdot
.61966 .40839 Mdot
.40162 .34684 Mdot
.41869 .6298 Mdot
.22409 .54861 Mdot
.41207 .33514 Mdot
.31426 .51463 Mdot
.41489 .32896 Mdot
.5339 .60338 Mdot
.41981 .6356 Mdot
.54892 .55311 Mdot
.56666 .60416 Mdot
.70258 .66231 Mdot
.57053 .42039 Mdot
.57795 .59598 Mdot
.37265 .67652 Mdot
.41278 .33696 Mdot
.29709 .51763 Mdot
.6299 .4383 Mdot
.4143 .36331 Mdot
.28018 .50023 Mdot
.59418 .71952 Mdot
.60637 .72716 Mdot
.43984 .35726 Mdot
.64067 .24586 Mdot
.25135 .49342 Mdot
.27722 .53171 Mdot
.65777 .66117 Mdot
.43418 .3622 Mdot
.60796 .70475 Mdot
.26874 .51164 Mdot
.39298 .7823 Mdot
.69015 .3691 Mdot
.68166 .68383 Mdot
.18737 .41016 Mdot
.65756 .66226 Mdot
.55584 .63656 Mdot
.60213 .69443 Mdot
.28024 .49962 Mdot
.60795 .45282 Mdot
.42912 .3534 Mdot
.41238 .36144 Mdot
.56709 .40675 Mdot
.52676 .58365 Mdot
.58118 .43266 Mdot
.5497 .6013 Mdot
.56994 .60049 Mdot
.60141 .42202 Mdot
.54483 .19759 Mdot
.41043 .36677 Mdot
.6376 .40953 Mdot
.39095 .67676 Mdot
.56404 .5425 Mdot
.25736 .49317 Mdot
.63361 .41487 Mdot
.64077 .40134 Mdot
.56198 .4516 Mdot
.27989 .53411 Mdot
.31846 .39552 Mdot
.38126 .71278 Mdot
.31995 .51712 Mdot
.33827 .57265 Mdot
.38717 .66385 Mdot
.58743 .46771 Mdot
.59008 .69192 Mdot
.55574 .57977 Mdot
.60689 .45038 Mdot
.65824 .66542 Mdot
.59698 .46532 Mdot
.48775 .59792 Mdot
.49467 .59727 Mdot
.20985 .38335 Mdot
.32432 .39118 Mdot
.58201 .44965 Mdot
.65972 .39538 Mdot
.6733 .67177 Mdot
.21668 .50392 Mdot
.29567 .52134 Mdot
.38038 .62867 Mdot
.4149 .62625 Mdot
.32199 .59596 Mdot
.63448 .26867 Mdot
.69285 .31466 Mdot
.61808 .39842 Mdot
.54088 .58509 Mdot
.44322 .39274 Mdot
.60353 .69347 Mdot
.43604 .34466 Mdot
.18263 .40973 Mdot
.69115 .51703 Mdot
.70446 .34226 Mdot
.33237 .73973 Mdot
.39968 .69034 Mdot
.53101 .57757 Mdot
.59849 .71054 Mdot
.58687 .41347 Mdot
.39929 .3668 Mdot
.66758 .66701 Mdot
.52482 .56867 Mdot
.83329 .60515 Mdot
.41727 .33366 Mdot
.70656 .54223 Mdot
.28735 .50332 Mdot
.39152 .64511 Mdot
.59894 .37807 Mdot
.60078 .44088 Mdot
.36166 .33694 Mdot
.60594 .4565 Mdot
.69109 .3444 Mdot
.68707 .36821 Mdot
.41772 .67036 Mdot
.34383 .56742 Mdot
.31621 .52989 Mdot
.36473 .73367 Mdot
.44495 .34978 Mdot
.54395 .18076 Mdot
.37451 .66048 Mdot
.51142 .61709 Mdot
.30913 .49588 Mdot
.59925 .72171 Mdot
.3683 .66432 Mdot
.58855 .66188 Mdot
.59102 .46955 Mdot
.39831 .66176 Mdot
.5978 .67857 Mdot
.55235 .39402 Mdot
.5317 .59273 Mdot
.6605 .75141 Mdot
.27587 .50986 Mdot
.37154 .33109 Mdot
.60861 .45001 Mdot
.54967 .58142 Mdot
.52659 .5617 Mdot
.65568 .56432 Mdot
.5673 .57782 Mdot
.52701 .56897 Mdot
.62082 .56273 Mdot
.58829 .72331 Mdot
.2956 .32864 Mdot
.69188 .34906 Mdot
.42359 .33175 Mdot
.58967 .45661 Mdot
.33998 .55585 Mdot
.27761 .50107 Mdot
.58693 .40942 Mdot
.19908 .38973 Mdot
.27459 .51625 Mdot
.60904 .4065 Mdot
.32377 .52335 Mdot
.42183 .36519 Mdot
.70213 .51489 Mdot
.44905 .34647 Mdot
.60228 .41892 Mdot
.32355 .51876 Mdot
.37343 .63194 Mdot
.40063 .35349 Mdot
.60761 .42295 Mdot
.59005 .39655 Mdot
.54222 .58227 Mdot
.68735 .36928 Mdot
.24864 .54901 Mdot
.56108 .43868 Mdot
.35013 .689 Mdot
.57293 .40526 Mdot
.61566 .72456 Mdot
.47826 .80415 Mdot
.43794 .36086 Mdot
.56607 .57304 Mdot
.36653 .65797 Mdot
.61389 .36203 Mdot
.71333 .52875 Mdot
.59114 .42735 Mdot
.54318 .55816 Mdot
.71437 .56987 Mdot
.2905 .53092 Mdot
.69909 .34996 Mdot
.53591 .53111 Mdot
.36361 .65274 Mdot
.5355 .58299 Mdot
.62251 .39213 Mdot
.38584 .36602 Mdot
.67346 .38156 Mdot
.39311 .65662 Mdot
.40656 .33017 Mdot
.60542 .38062 Mdot
.31456 .56943 Mdot
.55948 .54663 Mdot
.29717 .53205 Mdot
.68823 .35374 Mdot
.58674 .4671 Mdot
.40817 .63569 Mdot
.39013 .34858 Mdot
.28914 .49822 Mdot
.4475 .35029 Mdot
.61701 .61449 Mdot
.70651 .55291 Mdot
.44155 .3305 Mdot
.58232 .70944 Mdot
.42224 .8204 Mdot
.31683 .51528 Mdot
.5604 .589 Mdot
.33873 .67803 Mdot
.39263 .37039 Mdot
.36411 .67026 Mdot
.62822 .24518 Mdot
.36887 .64704 Mdot
.69059 .37691 Mdot
.37743 .63231 Mdot
.68964 .30445 Mdot
.63019 .42617 Mdot
.40963 .67266 Mdot
.55457 .61056 Mdot
.62953 .40982 Mdot
.41133 .36275 Mdot
.73768 .63564 Mdot
.60019 .28568 Mdot
.6395 .26963 Mdot
.37189 .64969 Mdot
.62264 .24064 Mdot
.6926 .36195 Mdot
.68732 .35556 Mdot
.4243 .35202 Mdot
.55939 .58803 Mdot
.62023 .68508 Mdot
.61804 .67532 Mdot
.55484 .79752 Mdot
.74206 .51372 Mdot
.6589 .25297 Mdot
.41465 .36031 Mdot
.31971 .65358 Mdot
.46313 .34645 Mdot
.52524 .5687 Mdot
.2897 .49556 Mdot
.31528 .40126 Mdot
.58689 .38116 Mdot
.51451 .61187 Mdot
.68361 .34829 Mdot
.37395 .33164 Mdot
.42204 .32393 Mdot
.28884 .49727 Mdot
.64322 .26862 Mdot
.61771 .31821 Mdot
.57892 .42875 Mdot
.28251 .49285 Mdot
.52546 .56448 Mdot
.63113 .36923 Mdot
.70641 .66985 Mdot
.20104 .65452 Mdot
.59511 .42142 Mdot
.37649 .41974 Mdot
.61003 .44784 Mdot
.69611 .66483 Mdot
.59059 .41204 Mdot
.39178 .35227 Mdot
.71648 .35408 Mdot
.61286 .36905 Mdot
.34479 .7601 Mdot
.68443 .51985 Mdot
.58365 .67048 Mdot
.59939 .43285 Mdot
.58279 .43794 Mdot
.61144 .70672 Mdot
.37893 .3477 Mdot
.57094 .44953 Mdot
.30192 .32564 Mdot
.61096 .41991 Mdot
.25653 .49889 Mdot
.67093 .59089 Mdot
.72466 .64765 Mdot
.68818 .36493 Mdot
.38378 .36517 Mdot
.28233 .53307 Mdot
.28563 .48332 Mdot
.56308 .57191 Mdot
.27669 .50155 Mdot
.61847 .44129 Mdot
.67045 .58976 Mdot
.43755 .33318 Mdot
.52963 .58528 Mdot
.37582 .33866 Mdot
.37885 .6149 Mdot
.27819 .5105 Mdot
.53988 .57017 Mdot
.61661 .27145 Mdot
.28414 .52152 Mdot
.3703 .57899 Mdot
.69822 .35572 Mdot
.52641 .5629 Mdot
.44902 .36602 Mdot
.4027 .63173 Mdot
.53373 .56049 Mdot
.28789 .50006 Mdot
.58986 .42612 Mdot
.67693 .37675 Mdot
.27653 .50048 Mdot
.34395 .33013 Mdot
.69359 .34699 Mdot
.61251 .41691 Mdot
.40121 .36211 Mdot
.39976 .33662 Mdot
.63695 .41353 Mdot
.59862 .45668 Mdot
.35318 .67036 Mdot
.54552 .55713 Mdot
.54615 .55615 Mdot
.56912 .59694 Mdot
.38065 .64508 Mdot
.39235 .80331 Mdot
.26904 .5251 Mdot
.72592 .64567 Mdot
.33273 .42766 Mdot
.54926 .5757 Mdot
.35267 .6755 Mdot
.59076 .4451 Mdot
.56433 .40552 Mdot
.32292 .51411 Mdot
.52875 .84664 Mdot
.56814 .39463 Mdot
.43552 .33699 Mdot
.29285 .49372 Mdot
.6388 .43627 Mdot
.32768 .59208 Mdot
.59982 .66873 Mdot
.65669 .25045 Mdot
.29708 .49684 Mdot
.3808 .30034 Mdot
.29837 .49796 Mdot
.58356 .43754 Mdot
.62076 .39275 Mdot
.37676 .32763 Mdot
.58134 .67148 Mdot
.5625 .42259 Mdot
.60445 .40859 Mdot
.31716 .6937 Mdot
.45971 .34 Mdot
.61672 .66978 Mdot
.56432 .44323 Mdot
.55042 .60738 Mdot
.57919 .6692 Mdot
.62187 .41877 Mdot
.57217 .40383 Mdot
.57526 .60999 Mdot
.31268 .49325 Mdot
.57588 .69074 Mdot
.34918 .76598 Mdot
.42281 .33457 Mdot
.2261 .52743 Mdot
.54538 .54885 Mdot
.31651 .5134 Mdot
.66528 .35792 Mdot
.53442 .57329 Mdot
.27933 .43583 Mdot
.84996 .3753 Mdot
.53178 .56509 Mdot
.34977 .67771 Mdot
.60779 .30926 Mdot
.56797 .4097 Mdot
.61253 .41594 Mdot
.62077 .68988 Mdot
.40613 .34174 Mdot
.32441 .39224 Mdot
.3212 .52031 Mdot
.60422 .44413 Mdot
.4459 .356 Mdot
.21611 .37095 Mdot
.53792 .57958 Mdot
.58685 .67838 Mdot
.58235 .70359 Mdot
.62081 .42846 Mdot
.72657 .54944 Mdot
.40191 .35518 Mdot
.6073 .42297 Mdot
.62551 .41571 Mdot
.35852 .64388 Mdot
.43043 .36669 Mdot
.39651 .66308 Mdot
.70535 .3471 Mdot
.70088 .29254 Mdot
.34181 .55193 Mdot
.27259 .51313 Mdot
.55493 .56035 Mdot
.31486 .53076 Mdot
.34783 .70176 Mdot
.54689 .55657 Mdot
.60689 .42396 Mdot
.43695 .33255 Mdot
.60727 .42219 Mdot
.61038 .41955 Mdot
.5873 .42293 Mdot
.66061 .25213 Mdot
.38937 .70869 Mdot
.58595 .68579 Mdot
.57437 .46268 Mdot
.3894 .651 Mdot
.31841 .61365 Mdot
.61084 .31683 Mdot
.60347 .43424 Mdot
.61754 .40764 Mdot
.42993 .37597 Mdot
.6912 .36946 Mdot
.2847 .51943 Mdot
.37441 .32861 Mdot
.60512 .37746 Mdot
.35066 .72268 Mdot
.57333 .45321 Mdot
.44313 .33198 Mdot
.26477 .51801 Mdot
.50587 .3561 Mdot
.53046 .55221 Mdot
.55399 .55667 Mdot
.53195 .56278 Mdot
.56987 .59072 Mdot
.25828 .49273 Mdot
.35348 .68144 Mdot
.36468 .73597 Mdot
.5531 .44676 Mdot
.60449 .45604 Mdot
.62288 .39384 Mdot
.34626 .65619 Mdot
.54991 .61223 Mdot
.62053 .25541 Mdot
.63021 .45039 Mdot
.39633 .64166 Mdot
.56107 .60877 Mdot
.39599 .26692 Mdot
.37316 .33661 Mdot
.37102 .7117 Mdot
.28556 .48151 Mdot
.59783 .67551 Mdot
.61147 .77761 Mdot
.38837 .33354 Mdot
.42816 .39519 Mdot
.38354 .6771 Mdot
.66781 .5743 Mdot
.50439 .14564 Mdot
.36093 .67346 Mdot
.68558 .3486 Mdot
.42467 .35705 Mdot
.54123 .60368 Mdot
.71164 .57409 Mdot
.67427 .58333 Mdot
.41048 .65067 Mdot
.5865 .39922 Mdot
.42001 .61712 Mdot
.35363 .66284 Mdot
.55895 .57168 Mdot
.37329 .64955 Mdot
.29041 .53215 Mdot
.37561 .67268 Mdot
.35345 .3174 Mdot
.56968 .4293 Mdot
.50582 .14889 Mdot
.66476 .61641 Mdot
.58329 .44833 Mdot
.2998 .52633 Mdot
.27755 .56191 Mdot
.57918 .4183 Mdot
.60709 .66701 Mdot
.35048 .67917 Mdot
.35517 .5891 Mdot
.68323 .3784 Mdot
.38051 .63185 Mdot
.38866 .36764 Mdot
.34597 .57223 Mdot
.33961 .57244 Mdot
.53559 .55985 Mdot
.42584 .36428 Mdot
.32923 .50495 Mdot
.31388 .51537 Mdot
.56364 .54976 Mdot
.62277 .43962 Mdot
.3937 .3629 Mdot
.57939 .37264 Mdot
.51762 .53474 Mdot
.61131 .42114 Mdot
.3939 .66506 Mdot
.40883 .6845 Mdot
.64968 .59674 Mdot
.37583 .65818 Mdot
.55998 .57196 Mdot
.40452 .36463 Mdot
.68201 .38009 Mdot
.40702 .33583 Mdot
.58799 .45714 Mdot
.33738 .56307 Mdot
.37109 .34299 Mdot
.51086 .61661 Mdot
.59955 .39736 Mdot
.54759 .19878 Mdot
.56938 .45818 Mdot
.61299 .41777 Mdot
.41955 .64868 Mdot
.61006 .7077 Mdot
.49776 .57807 Mdot
.3233 .59816 Mdot
.6093 .67724 Mdot
.34792 .33481 Mdot
.41987 .63122 Mdot
.60216 .71984 Mdot
.5592 .79893 Mdot
.56511 .56954 Mdot
.58432 .69957 Mdot
.6358 .40401 Mdot
.27121 .50974 Mdot
.40741 .32395 Mdot
.63039 .41035 Mdot
.69085 .2946 Mdot
.70934 .3437 Mdot
.54137 .57895 Mdot
.61486 .41412 Mdot
.58283 .44156 Mdot
.44629 .35514 Mdot
.18408 .41313 Mdot
.36002 .70068 Mdot
.55252 .59679 Mdot
.39832 .33322 Mdot
.18512 .40565 Mdot
.41053 .66698 Mdot
.61011 .72063 Mdot
.31251 .53571 Mdot
.39571 .29938 Mdot
.54526 .57924 Mdot
.2778 .50768 Mdot
.42726 .6218 Mdot
.64992 .65613 Mdot
.66566 .38228 Mdot
.36943 .68594 Mdot
.65747 .66263 Mdot
.70357 .35391 Mdot
.3187 .60133 Mdot
.21835 .50186 Mdot
.37378 .35453 Mdot
.27799 .49808 Mdot
.58492 .67587 Mdot
.44613 .34179 Mdot
.37547 .33897 Mdot
.27282 .51685 Mdot
.61886 .20275 Mdot
.71359 .56823 Mdot
.31527 .53939 Mdot
.65024 .56512 Mdot
.653 .65771 Mdot
.5457 .58266 Mdot
.58857 .68857 Mdot
.34369 .56739 Mdot
.39305 .34848 Mdot
.32174 .40754 Mdot
.66061 .66635 Mdot
.70002 .35324 Mdot
.60013 .67718 Mdot
.21925 .37087 Mdot
.28293 .457 Mdot
.28189 .51598 Mdot
.31675 .68969 Mdot
.61244 .68429 Mdot
.63461 .41524 Mdot
.55101 .84836 Mdot
.62966 .42456 Mdot
.26764 .50924 Mdot
.68569 .34708 Mdot
.42926 .34293 Mdot
.26979 .52407 Mdot
.70238 .34114 Mdot
.56138 .43704 Mdot
.57585 .43775 Mdot
.39934 .70153 Mdot
.36341 .33612 Mdot
.54591 .54557 Mdot
.58524 .44987 Mdot
.60379 .40586 Mdot
.52221 .56891 Mdot
.72113 .65002 Mdot
.45048 .57743 Mdot
.52748 .5914 Mdot
.40227 .65221 Mdot
.52965 .58662 Mdot
.55432 .59444 Mdot
.43959 .37077 Mdot
.32187 .63211 Mdot
.53281 .55507 Mdot
.60002 .4183 Mdot
.60628 .41744 Mdot
.31419 .53643 Mdot
.71383 .57038 Mdot
.67148 .57635 Mdot
.35271 .69332 Mdot
.54035 .53339 Mdot
.59718 .38942 Mdot
.42799 .36484 Mdot
.5992 .64881 Mdot
.56352 .57627 Mdot
.42351 .3335 Mdot
.56775 .42607 Mdot
.35757 .64438 Mdot
.5333 .56549 Mdot
.51946 .57521 Mdot
.59918 .6821 Mdot
.29572 .53958 Mdot
.37941 .37007 Mdot
.35113 .66879 Mdot
.66443 .37774 Mdot
.53009 .53819 Mdot
.36991 .64004 Mdot
.54518 .58447 Mdot
.53413 .59235 Mdot
.42109 .36403 Mdot
.37426 .30165 Mdot
.53609 .60964 Mdot
.38297 .64689 Mdot
.1805 .60841 Mdot
.30721 .50533 Mdot
.58306 .46676 Mdot
.30241 .53585 Mdot
.37543 .3575 Mdot
.70232 .66403 Mdot
.59245 .71594 Mdot
.2805 .51852 Mdot
.52496 .57269 Mdot
.37328 .34044 Mdot
.36074 .34343 Mdot
.5997 .42229 Mdot
.60749 .42831 Mdot
.34043 .70492 Mdot
.67882 .67709 Mdot
.32546 .52146 Mdot
.61958 .6931 Mdot
.36206 .69753 Mdot
.67763 .37857 Mdot
.43318 .35157 Mdot
.68738 .74376 Mdot
.57882 .46717 Mdot
.38644 .65026 Mdot
.40881 .3507 Mdot
.6187 .68216 Mdot
.58492 .68697 Mdot
.59694 .45257 Mdot
.55503 .63617 Mdot
.27895 .52139 Mdot
.40547 .36021 Mdot
.37835 .40196 Mdot
.56958 .4558 Mdot
.60341 .43134 Mdot
.70097 .35507 Mdot
.31124 .5405 Mdot
.63559 .40781 Mdot
.58129 .67363 Mdot
.44054 .35035 Mdot
.59972 .44928 Mdot
.61296 .68787 Mdot
.5576 .55198 Mdot
.53399 .57028 Mdot
.41519 .66436 Mdot
.61198 .66963 Mdot
.61184 .69568 Mdot
.61303 .67989 Mdot
.31494 .40148 Mdot
.58695 .47688 Mdot
.52209 .60836 Mdot
.59235 .39459 Mdot
.65078 .65537 Mdot
.66174 .38477 Mdot
.30893 .51981 Mdot
.40902 .63749 Mdot
.58294 .42594 Mdot
.59661 .3929 Mdot
.37587 .3656 Mdot
.67978 .38365 Mdot
.63645 .41344 Mdot
.43295 .34509 Mdot
.38432 .4 Mdot
.40524 .62501 Mdot
.18827 .40879 Mdot
.60061 .83723 Mdot
.61773 .4524 Mdot
.66726 .57897 Mdot
.37676 .34715 Mdot
.31316 .53614 Mdot
.65648 .56684 Mdot
.28586 .53746 Mdot
.39774 .33914 Mdot
.68803 .38103 Mdot
.34166 .33548 Mdot
.60719 .67707 Mdot
.58398 .43615 Mdot
.27504 .52163 Mdot
.58242 .43449 Mdot
.28003 .52885 Mdot
.6092 .23807 Mdot
.70502 .58926 Mdot
.61836 .44891 Mdot
.58335 .39459 Mdot
.56412 .6448 Mdot
.60533 .43162 Mdot
.33311 .74338 Mdot
.41555 .3514 Mdot
.5634 .54589 Mdot
.68618 .38363 Mdot
.60042 .28744 Mdot
.61781 .41146 Mdot
.70926 .33733 Mdot
.61847 .40328 Mdot
.51242 .84282 Mdot
.59374 .46813 Mdot
.6248 .43651 Mdot
.30032 .51916 Mdot
.3136 .50382 Mdot
.36577 .35523 Mdot
.53294 .58661 Mdot
.21411 .37742 Mdot
.60893 .40786 Mdot
.38602 .69688 Mdot
.5092 .53799 Mdot
.61259 .69852 Mdot
.44135 .34507 Mdot
.84971 .35547 Mdot
.25898 .48708 Mdot
.40031 .66714 Mdot
.68491 .35109 Mdot
.40074 .65638 Mdot
.37426 .70755 Mdot
.35113 .38902 Mdot
.5883 .68728 Mdot
.57776 .45634 Mdot
.56021 .28547 Mdot
.47765 .37964 Mdot
.56945 .45533 Mdot
.41628 .62072 Mdot
.5744 .61121 Mdot
.69271 .46965 Mdot
.58567 .72293 Mdot
.60476 .70033 Mdot
.28384 .50195 Mdot
.38923 .69399 Mdot
.55087 .59654 Mdot
.60006 .72036 Mdot
.39741 .62617 Mdot
.56472 .57107 Mdot
.31709 .66555 Mdot
.40153 .35557 Mdot
.62429 .24186 Mdot
.55685 .196 Mdot
.30216 .53148 Mdot
.31701 .61089 Mdot
.43886 .33325 Mdot
.45069 .34766 Mdot
.54265 .59054 Mdot
.39864 .64057 Mdot
.39028 .31659 Mdot
.59502 .45126 Mdot
.53061 .58741 Mdot
.61831 .43606 Mdot
.59376 .72764 Mdot
.60947 .41237 Mdot
.38842 .6285 Mdot
.29808 .52372 Mdot
.36409 .65422 Mdot
.28066 .50314 Mdot
.73054 .64221 Mdot
.60309 .39964 Mdot
.60142 .43051 Mdot
.67092 .58914 Mdot
.42108 .3712 Mdot
.56064 .29477 Mdot
.38171 .64892 Mdot
.36747 .65193 Mdot
.68382 .38465 Mdot
.4163 .32835 Mdot
.52238 .59853 Mdot
.64594 .56457 Mdot
.62018 .40485 Mdot
.41477 .34999 Mdot
.66059 .38818 Mdot
.20302 .49644 Mdot
.69441 .59879 Mdot
.42181 .37237 Mdot
.34219 .75963 Mdot
.62425 .40201 Mdot
.55843 .59562 Mdot
.57667 .59292 Mdot
.73448 .53855 Mdot
.4976 .57416 Mdot
.41792 .33337 Mdot
.54634 .59951 Mdot
.43218 .35329 Mdot
.36101 .6513 Mdot
.26332 .51848 Mdot
.42548 .34922 Mdot
.61486 .40058 Mdot
.60155 .83605 Mdot
.27398 .52358 Mdot
.58698 .4355 Mdot
.26535 .51393 Mdot
.40763 .32177 Mdot
.41637 .34036 Mdot
.56465 .57109 Mdot
.69092 .34574 Mdot
.27952 .52024 Mdot
.60855 .45337 Mdot
.36059 .4163 Mdot
.67349 .38173 Mdot
.54973 .53205 Mdot
.59237 .39065 Mdot
.56794 .42128 Mdot
.36997 .78791 Mdot
.59639 .36386 Mdot
.34075 .55707 Mdot
.29339 .54567 Mdot
.31757 .3925 Mdot
.44407 .36694 Mdot
.60028 .72845 Mdot
.36577 .35697 Mdot
.5502 .55482 Mdot
.4046 .65332 Mdot
.58667 .42618 Mdot
.56866 .57626 Mdot
.32552 .53294 Mdot
.58841 .7045 Mdot
.59698 .4653 Mdot
.37143 .69075 Mdot
.5611 .60138 Mdot
.27955 .51175 Mdot
.39023 .34595 Mdot
.4301 .33948 Mdot
.32145 .63743 Mdot
.59786 .4494 Mdot
.60746 .42625 Mdot
.26189 .49471 Mdot
.52144 .62179 Mdot
.6088 .67408 Mdot
.55449 .61064 Mdot
.26236 .50306 Mdot
.69569 .59814 Mdot
.36287 .33445 Mdot
.58635 .44384 Mdot
.67096 .59431 Mdot
.32073 .38992 Mdot
.48057 .31528 Mdot
.60627 .69322 Mdot
.71756 .53373 Mdot
.41694 .33333 Mdot
.2979 .51529 Mdot
.55383 .79937 Mdot
.70062 .35824 Mdot
.57545 .42179 Mdot
.71832 .52313 Mdot
.64687 .56264 Mdot
.67343 .36055 Mdot
.53792 .54947 Mdot
.70289 .56793 Mdot
.67891 .38672 Mdot
.66726 .37851 Mdot
.60219 .38736 Mdot
.59314 .38973 Mdot
.41566 .34581 Mdot
.64422 .27124 Mdot
.38439 .67298 Mdot
.65149 .40782 Mdot
.56705 .67768 Mdot
.69643 .35402 Mdot
.56888 .40168 Mdot
.43326 .27645 Mdot
.74083 .48274 Mdot
.41766 .35705 Mdot
.39977 .37048 Mdot
.30489 .53189 Mdot
.67693 .38224 Mdot
.38446 .64887 Mdot
.56881 .61589 Mdot
.40316 .63503 Mdot
.41332 .34615 Mdot
.40899 .62349 Mdot
.26019 .4814 Mdot
.36964 .68611 Mdot
.39863 .64481 Mdot
.30185 .52221 Mdot
.36617 .33335 Mdot
.56824 .45723 Mdot
.30178 .52285 Mdot
.51993 .584 Mdot
.6079 .7236 Mdot
.40906 .39847 Mdot
.53415 .59902 Mdot
.56362 .40083 Mdot
.17997 .58962 Mdot
.38006 .68457 Mdot
.70637 .51554 Mdot
.36793 .34119 Mdot
.57773 .65565 Mdot
.42493 .34681 Mdot
.53459 .60936 Mdot
.60546 .68787 Mdot
.63471 .40191 Mdot
.64771 .75426 Mdot
.22048 .50183 Mdot
.62826 .37241 Mdot
.38369 .40021 Mdot
.39982 .63403 Mdot
.29243 .52979 Mdot
.23822 .54918 Mdot
.55213 .59772 Mdot
.38392 .36587 Mdot
.37648 .29673 Mdot
.54812 .55549 Mdot
.29657 .51836 Mdot
.5444 .2151 Mdot
.58858 .4494 Mdot
.30377 .53438 Mdot
.58989 .39241 Mdot
.64621 .24801 Mdot
.58088 .64131 Mdot
.56998 .59685 Mdot
.69048 .37858 Mdot
.41043 .66613 Mdot
.68572 .38337 Mdot
.67703 .28394 Mdot
.69124 .67542 Mdot
.60404 .39265 Mdot
.71117 .51708 Mdot
.34563 .69708 Mdot
.43542 .35582 Mdot
.54934 .56745 Mdot
.5438 .58205 Mdot
.69694 .37113 Mdot
.68701 .78936 Mdot
.5977 .71502 Mdot
.32929 .73621 Mdot
.60601 .40075 Mdot
.6148 .42722 Mdot
.36748 .36092 Mdot
.60774 .23996 Mdot
.55234 .6089 Mdot
.58217 .40836 Mdot
.74309 .4918 Mdot
.2997 .5069 Mdot
.60216 .38222 Mdot
.61865 .43203 Mdot
.34963 .56985 Mdot
.29979 .51769 Mdot
.35569 .65077 Mdot
.56265 .56375 Mdot
.41809 .65946 Mdot
.5844 .66434 Mdot
.70833 .53963 Mdot
.71332 .65709 Mdot
.69022 .59882 Mdot
.6002 .66444 Mdot
.69063 .3646 Mdot
.55248 .42424 Mdot
.57182 .42504 Mdot
.60273 .70435 Mdot
.28965 .47985 Mdot
.41741 .34975 Mdot
.63651 .24448 Mdot
.54304 .58427 Mdot
.66705 .37456 Mdot
.57173 .67938 Mdot
.4287 .35452 Mdot
.54345 .19809 Mdot
.40763 .34261 Mdot
.28367 .51258 Mdot
.31807 .60379 Mdot
.60625 .68392 Mdot
.4257 .34688 Mdot
.41838 .6471 Mdot
.33479 .56179 Mdot
.599 .47747 Mdot
.26122 .48052 Mdot
.35899 .32228 Mdot
.4077 .371 Mdot
.46068 .35754 Mdot
.69093 .37429 Mdot
.70921 .51672 Mdot
.55656 .56222 Mdot
.26312 .51308 Mdot
.39888 .67849 Mdot
.68128 .67614 Mdot
.54473 .23329 Mdot
.69374 .57965 Mdot
.62654 .39537 Mdot
.60848 .41302 Mdot
.6213 .42409 Mdot
.52543 .55648 Mdot
.55177 .42185 Mdot
.6024 .3913 Mdot
.32334 .51494 Mdot
.36178 .64557 Mdot
.60352 .40272 Mdot
.53665 .56692 Mdot
.50871 .60456 Mdot
.57768 .65685 Mdot
.6627 .24872 Mdot
.40681 .39645 Mdot
.42668 .35235 Mdot
.39187 .65645 Mdot
.42151 .6328 Mdot
.5954 .72087 Mdot
.28692 .49462 Mdot
.40488 .34114 Mdot
.50757 .84054 Mdot
.60356 .67362 Mdot
.59666 .41901 Mdot
.67126 .59032 Mdot
.74069 .50274 Mdot
.56565 .41107 Mdot
.58712 .42171 Mdot
.52621 .57526 Mdot
.38813 .64834 Mdot
.69172 .3098 Mdot
.54504 .19929 Mdot
.61203 .68818 Mdot
.61368 .71261 Mdot
.45658 .35141 Mdot
.61431 .4499 Mdot
.27472 .52008 Mdot
.71593 .56738 Mdot
.26365 .55631 Mdot
.23768 .34352 Mdot
.3877 .61896 Mdot
.5755 .45536 Mdot
.60329 .30193 Mdot
.58512 .38189 Mdot
.45555 .34443 Mdot
.37699 .30357 Mdot
.41631 .35942 Mdot
.29666 .50217 Mdot
.6362 .64215 Mdot
.29558 .48869 Mdot
.56055 .60836 Mdot
.38222 .33148 Mdot
.60006 .36701 Mdot
.36884 .65161 Mdot
.67123 .38432 Mdot
.59362 .69367 Mdot
.58154 .5258 Mdot
.54991 .57194 Mdot
.71455 .5358 Mdot
.35295 .67593 Mdot
.37124 .32523 Mdot
.67104 .38494 Mdot
.32747 .59438 Mdot
.70052 .57505 Mdot
.33625 .66958 Mdot
.56818 .57355 Mdot
.60759 .67987 Mdot
.61159 .31892 Mdot
.59751 .67159 Mdot
.27812 .51815 Mdot
.59986 .39884 Mdot
.62114 .44089 Mdot
.61542 .41796 Mdot
.63243 .40685 Mdot
.29112 .50049 Mdot
.67215 .37019 Mdot
.52926 .6008 Mdot
.56934 .58677 Mdot
.69217 .34968 Mdot
.58668 .69403 Mdot
.30863 .50993 Mdot
.36844 .63998 Mdot
.52837 .56405 Mdot
.57364 .68261 Mdot
.64542 .38552 Mdot
.59491 .39621 Mdot
.56425 .6019 Mdot
.63534 .40393 Mdot
.67578 .36656 Mdot
.37049 .68091 Mdot
.67277 .36396 Mdot
.5768 .65922 Mdot
.59681 .69071 Mdot
.27397 .50368 Mdot
.42673 .34752 Mdot
.58124 .70444 Mdot
.35962 .69347 Mdot
.6142 .37915 Mdot
.59516 .38945 Mdot
.35625 .31488 Mdot
.65941 .66622 Mdot
.5795 .65415 Mdot
.63597 .40919 Mdot
.4375 .365 Mdot
.38358 .29268 Mdot
.57745 .41695 Mdot
.68392 .36119 Mdot
.44497 .36939 Mdot
.60415 .72292 Mdot
.2802 .49385 Mdot
.6698 .62355 Mdot
.27463 .5294 Mdot
.38901 .34653 Mdot
.54333 .59708 Mdot
.36835 .33248 Mdot
.55079 .59877 Mdot
.29456 .28719 Mdot
.60229 .38988 Mdot
.33708 .36075 Mdot
.54817 .61265 Mdot
.3726 .64832 Mdot
.38658 .63897 Mdot
.53598 .56325 Mdot
.41009 .33124 Mdot
.55918 .57018 Mdot
.5901 .6735 Mdot
.31997 .39651 Mdot
.43639 .37215 Mdot
.39835 .64367 Mdot
.37884 .68623 Mdot
.26215 .5043 Mdot
.61328 .41174 Mdot
.58598 .44427 Mdot
.36601 .68604 Mdot
.25678 .55314 Mdot
.37622 .35409 Mdot
.60682 .42622 Mdot
.52456 .58624 Mdot
.37791 .67708 Mdot
.23779 .4759 Mdot
.39342 .3203 Mdot
.69303 .37724 Mdot
.6945 .67385 Mdot
.25963 .51211 Mdot
.59563 .37973 Mdot
.6773 .36625 Mdot
.60469 .71137 Mdot
.71959 .53033 Mdot
.65659 .65997 Mdot
.26014 .48445 Mdot
.55465 .55778 Mdot
.56537 .41031 Mdot
.37565 .64321 Mdot
.62815 .38378 Mdot
.84382 .4257 Mdot
.5668 .60186 Mdot
.60065 .44708 Mdot
.57409 .60046 Mdot
.4081 .33577 Mdot
.61175 .42445 Mdot
.33896 .55441 Mdot
.38829 .65885 Mdot
.59568 .44863 Mdot
.56023 .63966 Mdot
.2662 .51473 Mdot
.5492 .57153 Mdot
.60979 .68017 Mdot
.67183 .36052 Mdot
.7369 .63622 Mdot
.34499 .65836 Mdot
.583 .68969 Mdot
.6147 .40989 Mdot
.36325 .69941 Mdot
.31516 .50695 Mdot
.54733 .56401 Mdot
.63681 .37597 Mdot
.31231 .51952 Mdot
.30309 .51144 Mdot
.60276 .68091 Mdot
.53675 .17429 Mdot
.62249 .4464 Mdot
.59485 .43892 Mdot
.53751 .19342 Mdot
.39881 .28375 Mdot
.58402 .43412 Mdot
.62696 .42136 Mdot
.27579 .5095 Mdot
.63302 .64129 Mdot
.71579 .5342 Mdot
.56453 .61489 Mdot
.29625 .52914 Mdot
.41067 .61854 Mdot
.39348 .67286 Mdot
.58069 .68838 Mdot
.40726 .35031 Mdot
.58914 .7171 Mdot
.37999 .66964 Mdot
.59776 .42121 Mdot
.27307 .49562 Mdot
.71515 .32043 Mdot
.26782 .52118 Mdot
.36078 .69193 Mdot
.44671 .3363 Mdot
.69043 .30276 Mdot
.84451 .41724 Mdot
.44481 .57461 Mdot
.31706 .60297 Mdot
.61226 .70024 Mdot
.54463 .19956 Mdot
.61216 .40249 Mdot
.6677 .2827 Mdot
.58791 .43832 Mdot
.61721 .72734 Mdot
.39635 .631 Mdot
.56463 .57087 Mdot
.55318 .5974 Mdot
.71218 .5334 Mdot
.30237 .50685 Mdot
.27829 .48213 Mdot
.53814 .59692 Mdot
.28609 .51605 Mdot
.59927 .44496 Mdot
.35654 .67248 Mdot
.31674 .27491 Mdot
.61868 .40262 Mdot
.5538 .54063 Mdot
.25261 .49325 Mdot
.42435 .32225 Mdot
.41119 .61883 Mdot
.60212 .29593 Mdot
.20398 .39028 Mdot
.28408 .52259 Mdot
.66442 .25064 Mdot
.38788 .65368 Mdot
.52796 .5649 Mdot
.36478 .70151 Mdot
.59278 .44183 Mdot
.5755 .45559 Mdot
.52364 .56533 Mdot
.62065 .41019 Mdot
.55443 .32024 Mdot
.70066 .34971 Mdot
.60269 .48328 Mdot
.58854 .39726 Mdot
.34255 .3508 Mdot
.31801 .50914 Mdot
.53845 .59618 Mdot
.61753 .56196 Mdot
.56868 .42356 Mdot
.44814 .36531 Mdot
.30978 .52289 Mdot
.19571 .40982 Mdot
.2961 .5033 Mdot
.36557 .65053 Mdot
.29188 .49598 Mdot
.59 .38007 Mdot
.3926 .33765 Mdot
.37256 .66539 Mdot
.54792 .57602 Mdot
.40476 .66744 Mdot
.58387 .4486 Mdot
.2504 .46688 Mdot
.39965 .66728 Mdot
.70081 .3545 Mdot
.3967 .33727 Mdot
.66875 .75219 Mdot
.46281 .38605 Mdot
.59518 .42757 Mdot
.58859 .43133 Mdot
.55058 .60978 Mdot
.28053 .4993 Mdot
.36699 .32681 Mdot
.31777 .69895 Mdot
.57871 .65413 Mdot
.41134 .35509 Mdot
.55107 .63275 Mdot
.66719 .57323 Mdot
.44395 .34821 Mdot
.74305 .49612 Mdot
.27225 .51465 Mdot
.42541 .33595 Mdot
.52267 .52799 Mdot
.65857 .39716 Mdot
.59115 .68389 Mdot
.41947 .65176 Mdot
.6613 .56933 Mdot
.39544 .66754 Mdot
.33768 .56301 Mdot
.41749 .67081 Mdot
.28378 .52578 Mdot
.5472 .63409 Mdot
.68221 .34932 Mdot
.27605 .47957 Mdot
.34034 .44838 Mdot
.38937 .66747 Mdot
.54329 .60282 Mdot
.67752 .36047 Mdot
.51943 .57116 Mdot
.55648 .60083 Mdot
.26045 .48508 Mdot
.42747 .33599 Mdot
.42758 .33171 Mdot
.57152 .56159 Mdot
.43259 .3421 Mdot
.36375 .67293 Mdot
.68164 .60268 Mdot
.616 .27175 Mdot
.31726 .50467 Mdot
.66708 .36737 Mdot
.58271 .3893 Mdot
.3846 .63035 Mdot
.35981 .6689 Mdot
.30001 .50485 Mdot
.49081 .36033 Mdot
.56152 .59403 Mdot
.41033 .32112 Mdot
.38845 .33294 Mdot
.41248 .33569 Mdot
.36738 .35086 Mdot
.64541 .65166 Mdot
.30046 .52617 Mdot
.40745 .33142 Mdot
.62669 .40164 Mdot
.62516 .42084 Mdot
.53194 .56046 Mdot
.59873 .72759 Mdot
.68606 .35804 Mdot
.56004 .57116 Mdot
.57548 .42562 Mdot
.37412 .64955 Mdot
.5006 .54743 Mdot
.55188 .55371 Mdot
.38512 .64799 Mdot
.38021 .64626 Mdot
.55601 .55746 Mdot
.49746 .55304 Mdot
.54805 .33224 Mdot
.69821 .37837 Mdot
.36196 .4003 Mdot
.39573 .63785 Mdot
.35026 .47607 Mdot
.33714 .35748 Mdot
.61794 .44305 Mdot
.55594 .61177 Mdot
.35577 .66591 Mdot
.43023 .3732 Mdot
.60305 .43644 Mdot
.54421 .59202 Mdot
.59351 .67784 Mdot
.54578 .5718 Mdot
.52693 .57799 Mdot
.41767 .36889 Mdot
.18208 .60208 Mdot
.44538 .35629 Mdot
.39869 .70002 Mdot
.55243 .58037 Mdot
.50428 .14763 Mdot
.39423 .63367 Mdot
.31947 .39879 Mdot
.68767 .34626 Mdot
.57397 .42247 Mdot
.39207 .65792 Mdot
.38928 .36773 Mdot
.26873 .47654 Mdot
.74206 .47777 Mdot
.42698 .34615 Mdot
.54456 .54868 Mdot
.52945 .57006 Mdot
.38269 .67467 Mdot
.38445 .34658 Mdot
.67821 .36559 Mdot
.42318 .33821 Mdot
.28129 .48529 Mdot
.63498 .39507 Mdot
.21301 .37908 Mdot
.54996 .59622 Mdot
.43754 .34543 Mdot
.38845 .68764 Mdot
.58067 .67373 Mdot
.63025 .42459 Mdot
.19655 .39319 Mdot
.61664 .4104 Mdot
.26849 .48607 Mdot
.50841 .54851 Mdot
.65902 .39351 Mdot
.59161 .41319 Mdot
.56265 .41024 Mdot
.3125 .48889 Mdot
.58938 .41249 Mdot
.5656 .42819 Mdot
.55214 .1996 Mdot
.44239 .35539 Mdot
.60584 .40278 Mdot
.36341 .68261 Mdot
.47406 .55901 Mdot
.61272 .43959 Mdot
.31968 .60719 Mdot
.7321 .54062 Mdot
.54803 .61459 Mdot
.56709 .5452 Mdot
.70097 .66492 Mdot
.59085 .43442 Mdot
.60753 .45532 Mdot
.63413 .39507 Mdot
.62026 .29491 Mdot
.38396 .66531 Mdot
.40725 .67527 Mdot
.58087 .67731 Mdot
.71836 .51973 Mdot
.59899 .68752 Mdot
.31571 .50805 Mdot
.70266 .34295 Mdot
.56587 .56869 Mdot
.42934 .34949 Mdot
.61599 .41976 Mdot
.39696 .68287 Mdot
.59384 .44429 Mdot
.67925 .37505 Mdot
.3676 .67555 Mdot
.35803 .6602 Mdot
.42311 .65516 Mdot
.61428 .68673 Mdot
.42269 .35563 Mdot
.63071 .42977 Mdot
.61175 .68024 Mdot
.5227 .56529 Mdot
.68142 .62542 Mdot
.42109 .35728 Mdot
.43809 .34858 Mdot
.38761 .32581 Mdot
.62273 .44101 Mdot
.63953 .40044 Mdot
.30011 .49279 Mdot
.35634 .31458 Mdot
.26739 .51232 Mdot
.39409 .65949 Mdot
.35623 .65449 Mdot
.59138 .44164 Mdot
.54118 .62996 Mdot
.58735 .69173 Mdot
.39563 .67628 Mdot
.57309 .59011 Mdot
.57616 .68332 Mdot
.60238 .45483 Mdot
.39619 .6643 Mdot
.6096 .6691 Mdot
.49122 .35956 Mdot
.2408 .37603 Mdot
.5788 .67472 Mdot
.55645 .59558 Mdot
.54597 .24093 Mdot
.68698 .67258 Mdot
.59626 .64717 Mdot
.31696 .5067 Mdot
.58039 .46808 Mdot
.57149 .59378 Mdot
.57462 .68106 Mdot
.67385 .6819 Mdot
.37388 .67196 Mdot
.55975 .59312 Mdot
.47602 .60666 Mdot
.61682 .27279 Mdot
.58005 .67188 Mdot
.43871 .34631 Mdot
.36035 .32533 Mdot
.59261 .41822 Mdot
.69091 .34641 Mdot
.31997 .50684 Mdot
.42121 .63768 Mdot
.40477 .67667 Mdot
.38409 .29915 Mdot
.69198 .59902 Mdot
.37284 .68328 Mdot
.5892 .46587 Mdot
.57284 .6974 Mdot
.62593 .4005 Mdot
.51917 .53636 Mdot
.66234 .39274 Mdot
.57494 .56054 Mdot
.57979 .67398 Mdot
.31577 .49953 Mdot
.2973 .5236 Mdot
.28396 .49923 Mdot
.37565 .68087 Mdot
.65873 .56592 Mdot
.39434 .68881 Mdot
.54536 .18033 Mdot
.59592 .71488 Mdot
.4058 .81115 Mdot
.55985 .40498 Mdot
.5737 .43117 Mdot
.66389 .3828 Mdot
.52651 .58749 Mdot
.59287 .43426 Mdot
.31273 .51618 Mdot
.41777 .64846 Mdot
.22582 .48682 Mdot
.39949 .36213 Mdot
.54773 .1851 Mdot
.36929 .65249 Mdot
.56122 .54862 Mdot
.59089 .69459 Mdot
.71556 .66256 Mdot
.61854 .71545 Mdot
.34979 .67476 Mdot
.58003 .452 Mdot
.46083 .36066 Mdot
.52013 .8443 Mdot
.61245 .4218 Mdot
.38178 .68408 Mdot
.33889 .6676 Mdot
.65152 .41207 Mdot
.64648 .33875 Mdot
.2157 .50299 Mdot
.67571 .59366 Mdot
.6099 .66657 Mdot
.52047 .57505 Mdot
.7206 .56302 Mdot
.3816 .66967 Mdot
.41364 .65295 Mdot
.61938 .67197 Mdot
.42988 .32394 Mdot
.38667 .32865 Mdot
.41567 .40836 Mdot
.3103 .50658 Mdot
.57569 .41516 Mdot
.39249 .66765 Mdot
.44538 .3364 Mdot
.61032 .55755 Mdot
.28586 .50551 Mdot
.3998 .6694 Mdot
.62057 .41153 Mdot
.59438 .41261 Mdot
.59844 .68539 Mdot
.50666 .60117 Mdot
.52337 .58841 Mdot
.32118 .39852 Mdot
.67777 .57382 Mdot
.70344 .3412 Mdot
.57547 .42156 Mdot
.38331 .36101 Mdot
.55072 .55619 Mdot
.58776 .68739 Mdot
.62604 .3838 Mdot
.68276 .29441 Mdot
.39808 .36964 Mdot
.273 .51778 Mdot
.54821 .58344 Mdot
.70617 .53779 Mdot
.61939 .41042 Mdot
.58879 .43876 Mdot
.69067 .37447 Mdot
.69566 .30508 Mdot
.40786 .63636 Mdot
.43574 .36337 Mdot
.61102 .68245 Mdot
.4133 .34052 Mdot
.32098 .64646 Mdot
.69775 .34571 Mdot
.59031 .4691 Mdot
.44176 .36664 Mdot
.39979 .34099 Mdot
.26958 .4858 Mdot
.29464 .52691 Mdot
.35414 .63989 Mdot
.62754 .42383 Mdot
.56747 .60259 Mdot
.40608 .33216 Mdot
.42075 .64707 Mdot
.60028 .68637 Mdot
.31588 .61642 Mdot
.59821 .3933 Mdot
.38589 .66997 Mdot
.55161 .56763 Mdot
.4094 .36609 Mdot
.3822 .65142 Mdot
.52758 .56553 Mdot
.60971 .72011 Mdot
.56186 .43257 Mdot
.33557 .68513 Mdot
.53967 .5918 Mdot
.63002 .41646 Mdot
.61467 .48105 Mdot
.68675 .34886 Mdot
.56784 .61424 Mdot
.38015 .62856 Mdot
.54008 .58755 Mdot
.36148 .32641 Mdot
.64823 .41913 Mdot
.41458 .65914 Mdot
.3414 .33611 Mdot
.69121 .34401 Mdot
.54824 .5992 Mdot
.43478 .35467 Mdot
.31725 .66765 Mdot
.44988 .32866 Mdot
.68259 .66718 Mdot
.60966 .43869 Mdot
.39523 .66792 Mdot
.59259 .68238 Mdot
.27645 .48322 Mdot
.31454 .44971 Mdot
.35627 .52054 Mdot
.39113 .64218 Mdot
.61686 .42067 Mdot
.42216 .33509 Mdot
.28347 .52074 Mdot
.36933 .36349 Mdot
.36776 .69909 Mdot
.3589 .68066 Mdot
.6638 .38132 Mdot
.59931 .68869 Mdot
.55275 .41968 Mdot
.41619 .65944 Mdot
.41078 .68109 Mdot
.55213 .20206 Mdot
.60795 .66575 Mdot
.6928 .37369 Mdot
.57204 .56121 Mdot
.60399 .38261 Mdot
.54152 .19788 Mdot
.52904 .57693 Mdot
.39659 .36123 Mdot
.58162 .42768 Mdot
.23455 .68789 Mdot
.38749 .63327 Mdot
.67608 .59356 Mdot
.22117 .50049 Mdot
.30493 .51653 Mdot
.38426 .65902 Mdot
.60827 .43387 Mdot
.3154 .61338 Mdot
.58023 .68946 Mdot
.68625 .38432 Mdot
.54304 .59998 Mdot
.38771 .29505 Mdot
.27529 .49313 Mdot
.48289 .59574 Mdot
.27907 .48349 Mdot
.27582 .50235 Mdot
.48512 .36591 Mdot
.5935 .41848 Mdot
.37115 .65517 Mdot
.36518 .69001 Mdot
.55236 .53643 Mdot
.39751 .7058 Mdot
.37457 .33111 Mdot
.22878 .67882 Mdot
.68439 .29853 Mdot
.60308 .39707 Mdot
.53887 .54913 Mdot
.55657 .60853 Mdot
.31772 .60372 Mdot
.58738 .41654 Mdot
.43398 .35827 Mdot
.41672 .66079 Mdot
.39005 .67468 Mdot
.70039 .35455 Mdot
.2973 .52402 Mdot
.61959 .70365 Mdot
.36203 .66962 Mdot
.66763 .62128 Mdot
.60052 .44764 Mdot
.25254 .48199 Mdot
.36367 .66893 Mdot
.63329 .80773 Mdot
.18204 .61781 Mdot
.4492 .35037 Mdot
.56024 .43124 Mdot
.39242 .32053 Mdot
.58377 .67106 Mdot
.38194 .70277 Mdot
.27834 .48059 Mdot
.55083 .57823 Mdot
.21309 .53019 Mdot
.38558 .67575 Mdot
.41421 .34687 Mdot
.59147 .42327 Mdot
.6696 .25382 Mdot
.61787 .40317 Mdot
.63043 .63911 Mdot
.58158 .65215 Mdot
.31177 .44884 Mdot
.26118 .49785 Mdot
.56012 .43236 Mdot
.61247 .67821 Mdot
.34901 .68105 Mdot
.36953 .67578 Mdot
.19051 .40104 Mdot
.52695 .57636 Mdot
.37022 .70678 Mdot
.6297 .41851 Mdot
.42122 .65977 Mdot
.54448 .23306 Mdot
.30372 .51705 Mdot
.59007 .38966 Mdot
.4011 .65923 Mdot
.435 .32063 Mdot
.6721 .58683 Mdot
.60638 .44376 Mdot
.57558 .59764 Mdot
.28782 .52549 Mdot
.54948 .18428 Mdot
.39487 .62982 Mdot
.61389 .39217 Mdot
.31434 .5211 Mdot
.54844 .63411 Mdot
.22828 .48005 Mdot
.42277 .35609 Mdot
.37859 .6872 Mdot
.28033 .49318 Mdot
.5567 .57957 Mdot
.60691 .66825 Mdot
.35468 .69183 Mdot
.40368 .65711 Mdot
.68728 .36752 Mdot
.5684 .55909 Mdot
.54817 .63163 Mdot
.37419 .34906 Mdot
.27421 .51216 Mdot
.68321 .37428 Mdot
.67853 .62898 Mdot
.63613 .38734 Mdot
.27169 .50809 Mdot
.51652 .15483 Mdot
.57638 .45102 Mdot
.59263 .39512 Mdot
.6772 .26171 Mdot
.37121 .32151 Mdot
.3744 .35731 Mdot
.69688 .57805 Mdot
.68633 .36093 Mdot
.59459 .36786 Mdot
.4221 .35247 Mdot
.41015 .34538 Mdot
.59613 .36765 Mdot
.6836 .37018 Mdot
.43255 .40569 Mdot
.28635 .51976 Mdot
.30453 .51903 Mdot
.41107 .33593 Mdot
.66346 .38385 Mdot
.31439 .53548 Mdot
.46028 .30377 Mdot
.3581 .68655 Mdot
.72542 .55043 Mdot
.4051 .33833 Mdot
.66831 .58926 Mdot
.27765 .51763 Mdot
.72546 .62247 Mdot
.73454 .5359 Mdot
.62825 .43925 Mdot
.59154 .41623 Mdot
.61004 .70371 Mdot
.54786 .57179 Mdot
.55539 .55656 Mdot
.28391 .49875 Mdot
.55155 .42287 Mdot
.41418 .35911 Mdot
.59451 .37829 Mdot
.68041 .67749 Mdot
.73898 .6176 Mdot
.69418 .32206 Mdot
.40708 .34902 Mdot
.39574 .35025 Mdot
.35404 .65599 Mdot
.41607 .62388 Mdot
.61327 .45531 Mdot
.29123 .52577 Mdot
.43398 .33857 Mdot
.26886 .50339 Mdot
.37996 .6706 Mdot
.3671 .65513 Mdot
.54343 .55435 Mdot
.56064 .59162 Mdot
.37883 .66325 Mdot
.3195 .60697 Mdot
.67929 .62831 Mdot
.36743 .30715 Mdot
.54662 .17554 Mdot
.7261 .64776 Mdot
.64353 .24692 Mdot
.59264 .67967 Mdot
.50309 .54462 Mdot
.31417 .51797 Mdot
.55931 .42517 Mdot
.57831 .43073 Mdot
.53766 .57907 Mdot
.30698 .53161 Mdot
.59418 .70674 Mdot
.30438 .51633 Mdot
.60713 .66954 Mdot
.40948 .6675 Mdot
.61637 .42475 Mdot
.58127 .4494 Mdot
.27187 .48566 Mdot
.35088 .6622 Mdot
.39914 .66001 Mdot
.58909 .68116 Mdot
.71728 .65518 Mdot
.3828 .67367 Mdot
.40416 .33884 Mdot
.358 .26523 Mdot
.5302 .57323 Mdot
.60376 .4354 Mdot
.70264 .66543 Mdot
.64786 .41958 Mdot
.52375 .56317 Mdot
.54755 .58381 Mdot
.53546 .17427 Mdot
.59687 .45177 Mdot
.18678 .41364 Mdot
.55018 .55308 Mdot
.36852 .33203 Mdot
.37543 .65585 Mdot
.53532 .55224 Mdot
.57846 .58545 Mdot
.57645 .63965 Mdot
.53215 .55228 Mdot
.38976 .32948 Mdot
.37982 .32143 Mdot
.67916 .35801 Mdot
.5558 .17002 Mdot
.60861 .6796 Mdot
.58703 .70116 Mdot
.4073 .6387 Mdot
.3377 .56376 Mdot
.54599 .45379 Mdot
.5867 .70452 Mdot
.41683 .39928 Mdot
.66605 .3803 Mdot
.67366 .35989 Mdot
.68984 .35084 Mdot
.36065 .33858 Mdot
.64547 .4086 Mdot
.40183 .63329 Mdot
.41487 .34833 Mdot
.67164 .3653 Mdot
.61782 .37827 Mdot
.41947 .3586 Mdot
.27667 .5055 Mdot
.69853 .33679 Mdot
.42831 .33923 Mdot
.74281 .47573 Mdot
.27762 .52186 Mdot
.66525 .36694 Mdot
.46389 .81975 Mdot
.65647 .80118 Mdot
.30238 .51405 Mdot
.39769 .67192 Mdot
.39181 .66641 Mdot
.36989 .67963 Mdot
.37195 .3521 Mdot
.36515 .64528 Mdot
.38501 .35061 Mdot
.31923 .59841 Mdot
.71507 .5263 Mdot
.60607 .68585 Mdot
.38642 .71175 Mdot
.41392 .33648 Mdot
.54261 .18929 Mdot
.85035 .37208 Mdot
.61763 .39391 Mdot
.27354 .48001 Mdot
.58393 .70631 Mdot
.67474 .59893 Mdot
.60497 .71091 Mdot
.38858 .65404 Mdot
.70922 .53622 Mdot
.59528 .44606 Mdot
.22495 .38969 Mdot
.59308 .68454 Mdot
.40944 .3443 Mdot
.6933 .3621 Mdot
.37058 .63222 Mdot
.5815 .68485 Mdot
.5957 .69164 Mdot
.59531 .43471 Mdot
.3709 .32559 Mdot
.39323 .65469 Mdot
.29889 .53284 Mdot
.37769 .59073 Mdot
.56656 .50694 Mdot
.60146 .45159 Mdot
.58706 .39648 Mdot
.66907 .57807 Mdot
.31646 .6164 Mdot
.29182 .52101 Mdot
.66758 .67091 Mdot
.38346 .62988 Mdot
.68566 .67748 Mdot
.45036 .33304 Mdot
.38431 .71231 Mdot
.52981 .57813 Mdot
.52983 .56179 Mdot
.60657 .42452 Mdot
.84759 .39786 Mdot
.64681 .34462 Mdot
.31716 .53291 Mdot
.53388 .57436 Mdot
.35064 .65913 Mdot
.37041 .35592 Mdot
.47287 .61027 Mdot
.6829 .35977 Mdot
.29725 .5333 Mdot
.37486 .67617 Mdot
.86165 .45053 Mdot
.61335 .70087 Mdot
.6809 .59601 Mdot
.62639 .41633 Mdot
.60365 .42793 Mdot
.29058 .50435 Mdot
.30112 .48527 Mdot
.55596 .19316 Mdot
.62152 .71627 Mdot
.21574 .37229 Mdot
.33018 .52583 Mdot
.86958 .46442 Mdot
.56165 .60675 Mdot
.3963 .35424 Mdot
.55898 .56041 Mdot
.30751 .48986 Mdot
.58228 .43157 Mdot
.37051 .32398 Mdot
.54828 .56287 Mdot
.43669 .39434 Mdot
.67446 .35813 Mdot
.67105 .62333 Mdot
.60759 .41287 Mdot
.40487 .32501 Mdot
.41801 .35222 Mdot
.4282 .32681 Mdot
.53388 .56286 Mdot
.58263 .40738 Mdot
.61347 .39347 Mdot
.58541 .39906 Mdot
.55889 .19861 Mdot
.61333 .42594 Mdot
.46657 .3521 Mdot
.70091 .59014 Mdot
.24564 .70283 Mdot
.57997 .44755 Mdot
.28355 .49489 Mdot
.60761 .41931 Mdot
.61587 .68306 Mdot
.5624 .42434 Mdot
.67313 .35824 Mdot
.29 .51721 Mdot
.67938 .28576 Mdot
.56736 .67424 Mdot
.59883 .45379 Mdot
.60193 .66487 Mdot
.30875 .40588 Mdot
.66506 .66597 Mdot
.54449 .21623 Mdot
.42088 .338 Mdot
.37415 .70104 Mdot
.32203 .51031 Mdot
.36618 .65045 Mdot
.71401 .35251 Mdot
.5675 .57667 Mdot
.39204 .80316 Mdot
.69205 .63047 Mdot
.582 .4297 Mdot
.54674 .60804 Mdot
.439 .35481 Mdot
.39249 .63305 Mdot
.61016 .23958 Mdot
.66456 .38226 Mdot
.59967 .72384 Mdot
.60662 .71647 Mdot
.52535 .5386 Mdot
.42765 .32494 Mdot
.5427 .2286 Mdot
.29106 .50606 Mdot
.37914 .6802 Mdot
.57541 .66821 Mdot
.39556 .4014 Mdot
.2841 .47787 Mdot
.32091 .59809 Mdot
.27744 .49214 Mdot
.57229 .43462 Mdot
.54656 .55034 Mdot
.35048 .40559 Mdot
.53446 .58652 Mdot
.61941 .38025 Mdot
.40296 .65608 Mdot
.52821 .57678 Mdot
.60953 .69582 Mdot
.27809 .49641 Mdot
.37171 .65063 Mdot
.59061 .42932 Mdot
.42641 .3538 Mdot
.69312 .46364 Mdot
.34007 .69794 Mdot
.6951 .34464 Mdot
.69531 .34457 Mdot
.36818 .30074 Mdot
.56551 .61635 Mdot
.28856 .44721 Mdot
.64892 .4196 Mdot
.34936 .54384 Mdot
.50836 .60855 Mdot
.32731 .73194 Mdot
.39071 .69186 Mdot
.37131 .66753 Mdot
.58488 .44603 Mdot
.42172 .64868 Mdot
.58872 .46734 Mdot
.38884 .62671 Mdot
.31883 .38744 Mdot
.62739 .37217 Mdot
.36669 .67319 Mdot
.55876 .56441 Mdot
.6306 .4217 Mdot
.43779 .35853 Mdot
.39476 .6915 Mdot
.62873 .43864 Mdot
.33771 .74922 Mdot
.27046 .48549 Mdot
.53328 .56251 Mdot
.6317 .56502 Mdot
.28153 .51454 Mdot
.37816 .3321 Mdot
.57397 .46435 Mdot
.58329 .70127 Mdot
.39065 .34843 Mdot
.51763 .55744 Mdot
.59906 .69076 Mdot
.68272 .60399 Mdot
.38686 .33605 Mdot
.53093 .57715 Mdot
.60804 .71998 Mdot
.55772 .53644 Mdot
.37164 .67005 Mdot
.33737 .67502 Mdot
.54246 .59373 Mdot
.59217 .44548 Mdot
.35438 .6499 Mdot
.29934 .5021 Mdot
.61852 .43387 Mdot
.39284 .66932 Mdot
.53847 .56554 Mdot
.62171 .40168 Mdot
.68694 .35984 Mdot
.54649 .19819 Mdot
.55092 .61605 Mdot
.60813 .68908 Mdot
.43648 .33048 Mdot
.60803 .3901 Mdot
.60556 .67253 Mdot
.34555 .6952 Mdot
.61963 .3915 Mdot
.44006 .3401 Mdot
.49349 .36969 Mdot
.42111 .63275 Mdot
.27684 .52502 Mdot
.36803 .69234 Mdot
.58855 .66275 Mdot
.85099 .36123 Mdot
.5517 .55533 Mdot
.67588 .38926 Mdot
.56922 .41286 Mdot
.37901 .70092 Mdot
.41767 .35455 Mdot
.22599 .3557 Mdot
.56143 .43051 Mdot
.62341 .39452 Mdot
.60065 .43488 Mdot
.35393 .58909 Mdot
.3686 .34436 Mdot
.60203 .43564 Mdot
.49795 .57909 Mdot
.58462 .39635 Mdot
.58567 .67333 Mdot
.42449 .81772 Mdot
.52412 .56927 Mdot
.49897 .1445 Mdot
.54622 .56077 Mdot
.36259 .67542 Mdot
.74315 .4749 Mdot
.6295 .56383 Mdot
.37957 .61483 Mdot
.37638 .33236 Mdot
.36034 .39884 Mdot
.36649 .65687 Mdot
.31787 .66228 Mdot
.67848 .36214 Mdot
.69089 .36321 Mdot
.62581 .43135 Mdot
.38834 .65396 Mdot
.41723 .64045 Mdot
.56791 .58359 Mdot
.54178 .60488 Mdot
.62816 .45211 Mdot
.39584 .68216 Mdot
.61476 .42656 Mdot
.65691 .39523 Mdot
.28254 .47726 Mdot
.44754 .34978 Mdot
.28381 .48093 Mdot
.27338 .47711 Mdot
.63529 .24491 Mdot
.67684 .5724 Mdot
.31106 .50773 Mdot
.31966 .52002 Mdot
.33552 .58982 Mdot
.63036 .26652 Mdot
.58817 .67039 Mdot
.64374 .345 Mdot
.35574 .65783 Mdot
.58521 .40496 Mdot
.36725 .3431 Mdot
.53084 .60637 Mdot
.24914 .32752 Mdot
.81343 .55965 Mdot
.67188 .37872 Mdot
.37412 .63469 Mdot
.54017 .59328 Mdot
.53702 .5952 Mdot
.68635 .67348 Mdot
.61186 .42857 Mdot
.42143 .63631 Mdot
.61732 .27157 Mdot
.33164 .52193 Mdot
.31694 .60975 Mdot
.41097 .3209 Mdot
.60996 .41873 Mdot
.37949 .35563 Mdot
.27872 .53028 Mdot
.60168 .67298 Mdot
.61297 .69484 Mdot
.59739 .4546 Mdot
.68255 .34935 Mdot
.35148 .54056 Mdot
.69123 .35807 Mdot
.67898 .37286 Mdot
.54137 .58716 Mdot
.69636 .36973 Mdot
.6135 .39125 Mdot
.64341 .37806 Mdot
.52193 .56692 Mdot
.28113 .47877 Mdot
.61516 .25574 Mdot
.54648 .59917 Mdot
.56504 .45587 Mdot
.2761 .52831 Mdot
.68875 .35712 Mdot
.295 .50181 Mdot
.31739 .61751 Mdot
.30387 .49709 Mdot
.61075 .6867 Mdot
.42796 .63237 Mdot
.55272 .18381 Mdot
.42461 .33634 Mdot
.30066 .52535 Mdot
.60989 .72098 Mdot
.2932 .49818 Mdot
.35239 .66647 Mdot
.3269 .50201 Mdot
.41294 .28453 Mdot
.66626 .61912 Mdot
.65102 .25195 Mdot
.33075 .52127 Mdot
.41942 .63088 Mdot
.41074 .33542 Mdot
.3385 .55745 Mdot
.56381 .44289 Mdot
.61439 .6969 Mdot
.60496 .425 Mdot
.27672 .49893 Mdot
.36145 .64539 Mdot
.54249 .21412 Mdot
.60912 .69036 Mdot
.54362 .17646 Mdot
.39275 .68635 Mdot
.56797 .43851 Mdot
.26336 .51859 Mdot
.32519 .45488 Mdot
.26311 .49306 Mdot
.7214 .52795 Mdot
.56995 .59731 Mdot
.62394 .72981 Mdot
.38909 .34369 Mdot
.56316 .60834 Mdot
.74488 .70974 Mdot
.33183 .42462 Mdot
.42513 .36453 Mdot
.36382 .70813 Mdot
.5997 .44901 Mdot
.69491 .37309 Mdot
.56147 .57978 Mdot
.4231 .3295 Mdot
.6903 .37451 Mdot
.53759 .5565 Mdot
.70458 .58524 Mdot
.41909 .32312 Mdot
.35181 .69129 Mdot
.62851 .42259 Mdot
.25913 .48719 Mdot
.26886 .52232 Mdot
.55106 .5507 Mdot
.2838 .48349 Mdot
.56758 .46036 Mdot
.39375 .33641 Mdot
.68059 .35762 Mdot
.5821 .67503 Mdot
.37898 .41828 Mdot
.51911 .5879 Mdot
.5871 .72681 Mdot
.62936 .40391 Mdot
.36878 .65531 Mdot
.21156 .53002 Mdot
.57025 .39949 Mdot
.41941 .35018 Mdot
.56579 .42435 Mdot
.6939 .37182 Mdot
.69134 .36071 Mdot
.37937 .67996 Mdot
.67036 .58675 Mdot
.61473 .42543 Mdot
.29062 .53282 Mdot
.60624 .36474 Mdot
.55844 .40938 Mdot
.61974 .7237 Mdot
.6719 .35965 Mdot
.27643 .53535 Mdot
.37292 .3013 Mdot
.37157 .65613 Mdot
.40764 .35747 Mdot
.44374 .37393 Mdot
.37805 .33289 Mdot
.40637 .31398 Mdot
.64787 .42208 Mdot
.18441 .40737 Mdot
.54418 .23166 Mdot
.65516 .24939 Mdot
.4364 .373 Mdot
.19483 .54292 Mdot
.42726 .3645 Mdot
.37761 .33222 Mdot
.30763 .27871 Mdot
.37238 .33331 Mdot
.59039 .44187 Mdot
.5684 .42388 Mdot
.68651 .30368 Mdot
.38091 .5908 Mdot
.617 .40128 Mdot
.52383 .56002 Mdot
.58692 .71142 Mdot
.43743 .3274 Mdot
.54924 .58 Mdot
.67421 .60065 Mdot
.54873 .54637 Mdot
.59478 .43432 Mdot
.62145 .42088 Mdot
.69316 .35264 Mdot
.74947 .61389 Mdot
.40125 .59439 Mdot
.387 .32439 Mdot
.55579 .41349 Mdot
.23446 .47456 Mdot
.6238 .43061 Mdot
.56706 .41166 Mdot
.64588 .40592 Mdot
.3711 .65513 Mdot
.36357 .35048 Mdot
.56096 .5973 Mdot
.37209 .41925 Mdot
.61428 .40904 Mdot
.52117 .60144 Mdot
.57869 .70473 Mdot
.60755 .43512 Mdot
.37449 .32657 Mdot
.69246 .37286 Mdot
.39981 .36873 Mdot
.38485 .33843 Mdot
.62098 .39275 Mdot
.43714 .32813 Mdot
.38086 .36236 Mdot
.68994 .36367 Mdot
.36417 .63931 Mdot
.31991 .39786 Mdot
.59638 .44474 Mdot
.6072 .6957 Mdot
.5875 .41888 Mdot
.58739 .66912 Mdot
.53342 .55231 Mdot
.53927 .58874 Mdot
.61324 .32073 Mdot
.41325 .65605 Mdot
.60881 .72819 Mdot
.41953 .66765 Mdot
.55233 .45332 Mdot
.42326 .39661 Mdot
.32094 .4954 Mdot
.34695 .71807 Mdot
.53945 .58633 Mdot
.63777 .64286 Mdot
.55985 .38548 Mdot
.29935 .49148 Mdot
.42927 .36784 Mdot
.60257 .26302 Mdot
.5565 .61078 Mdot
.35079 .68996 Mdot
.36313 .68824 Mdot
.33389 .43063 Mdot
.31657 .27507 Mdot
.58116 .44809 Mdot
.55261 .6106 Mdot
.61182 .4792 Mdot
.54769 .5705 Mdot
.56691 .58616 Mdot
.40421 .65972 Mdot
.62096 .40269 Mdot
.70838 .58369 Mdot
.38899 .6661 Mdot
.58929 .69802 Mdot
.3942 .36049 Mdot
.60611 .67061 Mdot
.25731 .36138 Mdot
.55553 .19115 Mdot
.38198 .66377 Mdot
.52314 .57811 Mdot
.59328 .39791 Mdot
.36843 .327 Mdot
.37118 .3645 Mdot
.44202 .35715 Mdot
.57813 .68859 Mdot
.4134 .66573 Mdot
.34138 .75786 Mdot
.59318 .42224 Mdot
.40073 .34233 Mdot
.56996 .68874 Mdot
.59447 .41149 Mdot
.29505 .52561 Mdot
.68765 .3749 Mdot
.40802 .34085 Mdot
.67046 .38954 Mdot
.38819 .34308 Mdot
.36214 .68375 Mdot
.59208 .45452 Mdot
.61241 .44554 Mdot
.66191 .66492 Mdot
.59489 .70764 Mdot
.41204 .37197 Mdot
.66773 .5667 Mdot
.60421 .38255 Mdot
.69246 .67029 Mdot
.61599 .43069 Mdot
.65412 .25313 Mdot
.57445 .57561 Mdot
.53842 .55465 Mdot
.56677 .41891 Mdot
.60011 .44369 Mdot
.36849 .36176 Mdot
.54582 .23415 Mdot
.55909 .19714 Mdot
.27457 .52476 Mdot
.43372 .36314 Mdot
.39018 .66236 Mdot
.39534 .69251 Mdot
.36421 .64853 Mdot
.58182 .66472 Mdot
.68466 .35703 Mdot
.57881 .43845 Mdot
.30673 .5369 Mdot
.59081 .71217 Mdot
.40094 .34784 Mdot
.60253 .68135 Mdot
.67524 .57908 Mdot
.60667 .70089 Mdot
.56266 .56433 Mdot
.17938 .58997 Mdot
.6566 .3957 Mdot
.59736 .69824 Mdot
.44672 .34756 Mdot
.61597 .36183 Mdot
.63979 .41678 Mdot
.54532 .18991 Mdot
.59719 .72251 Mdot
.35675 .7071 Mdot
.63009 .40848 Mdot
.70869 .51551 Mdot
.28972 .49985 Mdot
.60903 .67221 Mdot
.27777 .49108 Mdot
.67697 .37728 Mdot
.3474 .37929 Mdot
.41975 .34548 Mdot
.28677 .47648 Mdot
.57164 .40577 Mdot
.60942 .6727 Mdot
.37773 .6661 Mdot
.62917 .26751 Mdot
.32469 .59202 Mdot
.53416 .616 Mdot
.68348 .67083 Mdot
.40444 .63423 Mdot
.64808 .267 Mdot
.2877 .48773 Mdot
.5818 .38354 Mdot
.66212 .39164 Mdot
.6168 .38522 Mdot
.39736 .65741 Mdot
.37087 .66698 Mdot
.32238 .7184 Mdot
.60844 .45027 Mdot
.64479 .40857 Mdot
.39197 .29249 Mdot
.41561 .66162 Mdot
.37849 .33355 Mdot
.41468 .32628 Mdot
.3978 .67094 Mdot
.42665 .37152 Mdot
.59733 .69063 Mdot
.70376 .56053 Mdot
.29002 .48869 Mdot
.26335 .51311 Mdot
.38042 .66274 Mdot
.40332 .64357 Mdot
.36864 .65464 Mdot
.68133 .379 Mdot
.38304 .33615 Mdot
.58783 .46217 Mdot
.60309 .42027 Mdot
.63882 .40942 Mdot
.39308 .31967 Mdot
.56141 .43504 Mdot
.60649 .37044 Mdot
.5769 .69599 Mdot
.36153 .67222 Mdot
.26845 .50736 Mdot
.6921 .46847 Mdot
.2895 .53367 Mdot
.59238 .39017 Mdot
.32181 .39087 Mdot
.42394 .36829 Mdot
.60718 .70865 Mdot
.68165 .35144 Mdot
.61099 .69449 Mdot
.28238 .47715 Mdot
.39661 .2932 Mdot
.68806 .60173 Mdot
.58809 .45956 Mdot
.66971 .57398 Mdot
.55453 .79854 Mdot
.47178 .35295 Mdot
.27582 .51203 Mdot
.65737 .3894 Mdot
.55335 .54815 Mdot
.62551 .46038 Mdot
.58287 .44337 Mdot
.5615 .40298 Mdot
.70081 .51347 Mdot
.57749 .403 Mdot
.44991 .34697 Mdot
.61098 .36719 Mdot
.52579 .58959 Mdot
.63544 .41029 Mdot
.19289 .40868 Mdot
.61015 .40058 Mdot
.59573 .45755 Mdot
.57629 .42598 Mdot
.59265 .38312 Mdot
.38969 .31833 Mdot
.68472 .35261 Mdot
.28396 .53161 Mdot
.70435 .56088 Mdot
.29306 .49075 Mdot
.38185 .65737 Mdot
.54048 .61227 Mdot
.35845 .33027 Mdot
.61098 .69571 Mdot
.39381 .57266 Mdot
.71256 .51704 Mdot
.35373 .65657 Mdot
.65141 .65909 Mdot
.6207 .69734 Mdot
.56495 .57905 Mdot
.59157 .66102 Mdot
.40157 .65826 Mdot
.30013 .52142 Mdot
.57911 .45157 Mdot
.39446 .3315 Mdot
.43211 .34022 Mdot
.63456 .40971 Mdot
.31753 .40522 Mdot
.26747 .51944 Mdot
.39093 .71017 Mdot
.57689 .4415 Mdot
.59046 .38939 Mdot
.39121 .36528 Mdot
.37844 .63538 Mdot
.56186 .38487 Mdot
.58554 .6812 Mdot
.6248 .42681 Mdot
.53013 .59427 Mdot
.67412 .57824 Mdot
.27686 .52632 Mdot
.53408 .56793 Mdot
.59497 .40071 Mdot
.68316 .57938 Mdot
.68429 .38458 Mdot
.49912 .57041 Mdot
.41074 .62372 Mdot
.6232 .39476 Mdot
.61661 .44114 Mdot
.41607 .32238 Mdot
.28638 .48662 Mdot
.42086 .35544 Mdot
.38639 .28656 Mdot
.53922 .58799 Mdot
.26559 .48889 Mdot
.59515 .38272 Mdot
.31546 .53969 Mdot
.68883 .37293 Mdot
.59583 .42583 Mdot
.27643 .51011 Mdot
.38073 .34283 Mdot
.21905 .37086 Mdot
.61372 .2559 Mdot
.67858 .37533 Mdot
.58844 .41599 Mdot
.3816 .59117 Mdot
.53005 .60577 Mdot
.57466 .45467 Mdot
.43304 .33858 Mdot
.59476 .41293 Mdot
.32328 .52699 Mdot
.60473 .67717 Mdot
.42369 .34995 Mdot
.38698 .63139 Mdot
.36775 .68483 Mdot
.41688 .62262 Mdot
.56473 .56892 Mdot
.69644 .36936 Mdot
.43393 .32938 Mdot
.42422 .3276 Mdot
.65261 .56398 Mdot
.36281 .67509 Mdot
.59529 .6777 Mdot
.62785 .43066 Mdot
.54714 .60929 Mdot
.25681 .50421 Mdot
.49572 .14302 Mdot
.6903 .59833 Mdot
.57357 .67424 Mdot
.56702 .50801 Mdot
.54217 .58338 Mdot
.58995 .39737 Mdot
.6099 .6746 Mdot
.39691 .67021 Mdot
.69523 .37671 Mdot
.50141 .59919 Mdot
.35558 .70802 Mdot
.38535 .64002 Mdot
.31103 .54008 Mdot
.39945 .62583 Mdot
.60899 .66889 Mdot
.55295 .55576 Mdot
.43055 .34569 Mdot
.61033 .43254 Mdot
.5517 .59475 Mdot
.35676 .67306 Mdot
.56302 .60312 Mdot
.57134 .43786 Mdot
.39393 .36479 Mdot
.3591 .65545 Mdot
.5915 .43666 Mdot
.65235 .41063 Mdot
.54747 .199 Mdot
.36796 .63816 Mdot
.58148 .46667 Mdot
.47722 .60697 Mdot
.38026 .64291 Mdot
.39937 .6554 Mdot
.61859 .3904 Mdot
.61906 .69023 Mdot
.61229 .41251 Mdot
.29553 .52369 Mdot
.66609 .58045 Mdot
.27129 .48575 Mdot
.68763 .67633 Mdot
.63268 .4031 Mdot
.60107 .4766 Mdot
.43217 .39556 Mdot
.57694 .72013 Mdot
.72475 .65026 Mdot
.60636 .39117 Mdot
.37619 .36263 Mdot
.66785 .58788 Mdot
.66093 .61285 Mdot
.43554 .29014 Mdot
.59582 .66781 Mdot
.28486 .49854 Mdot
.60734 .4487 Mdot
.20121 .4066 Mdot
.58984 .67303 Mdot
.6876 .67396 Mdot
.55842 .43035 Mdot
.40942 .34774 Mdot
.58226 .44721 Mdot
.42507 .34317 Mdot
.58935 .40849 Mdot
.543 .20673 Mdot
.35128 .54045 Mdot
.72088 .52752 Mdot
.55979 .56745 Mdot
.32506 .45478 Mdot
.65148 .25157 Mdot
.59666 .68642 Mdot
.66344 .39008 Mdot
.54013 .57733 Mdot
.30443 .51584 Mdot
.22605 .52615 Mdot
.36615 .65595 Mdot
.29827 .53129 Mdot
.39884 .35717 Mdot
.34909 .65998 Mdot
.56406 .60665 Mdot
.5902 .4817 Mdot
.61272 .67624 Mdot
.26502 .48937 Mdot
.60654 .43891 Mdot
.62788 .38193 Mdot
.35156 .58898 Mdot
.43697 .82176 Mdot
.45864 .35262 Mdot
.54315 .17256 Mdot
.39592 .29302 Mdot
.59006 .70401 Mdot
.36056 .64247 Mdot
.58011 .42934 Mdot
.62184 .40834 Mdot
.38775 .63891 Mdot
.36715 .32755 Mdot
.61328 .72173 Mdot
.62337 .73151 Mdot
.31655 .53374 Mdot
.48864 .83394 Mdot
.42575 .34922 Mdot
.48609 .83381 Mdot
.3301 .73738 Mdot
.33817 .26864 Mdot
.72026 .6536 Mdot
.28486 .51723 Mdot
.48765 .83426 Mdot
.40536 .34544 Mdot
.57268 .41661 Mdot
.53322 .57924 Mdot
.56821 .57877 Mdot
.38646 .36013 Mdot
.38445 .65278 Mdot
.61957 .68446 Mdot
.587 .44844 Mdot
.49731 .55535 Mdot
.36928 .36353 Mdot
.41007 .66776 Mdot
.55239 .5734 Mdot
.2691 .51291 Mdot
.592 .41276 Mdot
.57783 .69383 Mdot
.28606 .51652 Mdot
.52815 .56324 Mdot
.7085 .53895 Mdot
.57444 .46471 Mdot
.68852 .34639 Mdot
.29182 .50185 Mdot
.56849 .50854 Mdot
.61808 .43665 Mdot
.28748 .48768 Mdot
.55812 .54509 Mdot
.30366 .44242 Mdot
.54187 .41536 Mdot
.33183 .4247 Mdot
.34441 .67817 Mdot
.38241 .62806 Mdot
.40238 .72836 Mdot
.424 .61148 Mdot
.30677 .5047 Mdot
.54948 .58949 Mdot
.41535 .81649 Mdot
.28228 .48558 Mdot
.56657 .40682 Mdot
.60374 .44926 Mdot
.61614 .27186 Mdot
.52537 .56706 Mdot
.54767 .55944 Mdot
.3372 .35255 Mdot
.66446 .37404 Mdot
.55233 .57545 Mdot
.61884 .4308 Mdot
.38268 .32175 Mdot
.27708 .51895 Mdot
.83626 .60141 Mdot
.31891 .50216 Mdot
.70504 .36196 Mdot
.35662 .65495 Mdot
.34406 .67487 Mdot
.60773 .4335 Mdot
.44945 .58444 Mdot
.86784 .45887 Mdot
.6045 .44929 Mdot
.68035 .35237 Mdot
.68494 .67766 Mdot
.63571 .40788 Mdot
.44881 .35892 Mdot
.52597 .58065 Mdot
.4004 .32157 Mdot
.28275 .51258 Mdot
.59526 .66814 Mdot
.56668 .66858 Mdot
.28522 .4992 Mdot
.6149 .40462 Mdot
.51754 .57342 Mdot
.60238 .42995 Mdot
.5738 .41988 Mdot
.68181 .5831 Mdot
.57535 .67263 Mdot
.37521 .65185 Mdot
.61209 .69131 Mdot
.37526 .33233 Mdot
.52473 .15925 Mdot
.59837 .68337 Mdot
.62949 .26692 Mdot
.66423 .57134 Mdot
.42264 .81614 Mdot
.43313 .34177 Mdot
.58349 .6708 Mdot
.28492 .49675 Mdot
.64074 .58436 Mdot
.65372 .27534 Mdot
.29632 .53282 Mdot
.57556 .4191 Mdot
.40125 .32334 Mdot
.37288 .29887 Mdot
.27004 .52715 Mdot
.43652 .35249 Mdot
.53844 .4426 Mdot
.67574 .37242 Mdot
.28274 .53172 Mdot
.73714 .63181 Mdot
.26113 .49744 Mdot
.62542 .24388 Mdot
.68881 .37071 Mdot
.4211 .34995 Mdot
.66541 .25039 Mdot
.40267 .29268 Mdot
.5434 .55538 Mdot
.56608 .43992 Mdot
.59603 .68081 Mdot
.65891 .56584 Mdot
.37895 .632 Mdot
.43453 .32075 Mdot
.41155 .33791 Mdot
.25582 .50552 Mdot
.43574 .35159 Mdot
.42736 .36927 Mdot
.28488 .47611 Mdot
.43073 .3645 Mdot
.61484 .40864 Mdot
.55847 .17193 Mdot
.44018 .35497 Mdot
.28983 .50833 Mdot
.57938 .69133 Mdot
.44884 .34982 Mdot
.31626 .67675 Mdot
.62943 .42056 Mdot
.36876 .69853 Mdot
.60516 .65328 Mdot
.38749 .31897 Mdot
.59493 .68482 Mdot
.35573 .66922 Mdot
.59788 .7262 Mdot
.29391 .54586 Mdot
.28812 .54284 Mdot
.57876 .58892 Mdot
.33756 .44045 Mdot
.37281 .33329 Mdot
.3504 .65593 Mdot
.61986 .44322 Mdot
.57328 .43459 Mdot
.58552 .64962 Mdot
.40223 .37092 Mdot
.31301 .40384 Mdot
.55025 .57927 Mdot
.38202 .41848 Mdot
.27089 .5228 Mdot
.38846 .71109 Mdot
.68847 .60337 Mdot
.33009 .5715 Mdot
.52505 .58861 Mdot
.54096 .58222 Mdot
.60057 .4355 Mdot
.66745 .66891 Mdot
.60533 .66719 Mdot
.19514 .55364 Mdot
.67213 .38317 Mdot
.39404 .63751 Mdot
.58489 .40936 Mdot
.66992 .36862 Mdot
.61042 .39041 Mdot
.57405 .66976 Mdot
.31161 .52686 Mdot
.42725 .33678 Mdot
.58553 .66885 Mdot
.36843 .68527 Mdot
.74303 .49521 Mdot
.57634 .45679 Mdot
.58975 .46809 Mdot
.38267 .64678 Mdot
.38186 .32908 Mdot
.37581 .66086 Mdot
.28992 .4888 Mdot
.60097 .68403 Mdot
.6884 .37592 Mdot
.525 .56811 Mdot
.38049 .70065 Mdot
.30271 .52456 Mdot
.36175 .64035 Mdot
.32625 .5316 Mdot
.53882 .58395 Mdot
.59034 .47102 Mdot
.42269 .63973 Mdot
.54574 .60404 Mdot
.55962 .28604 Mdot
.70577 .53719 Mdot
.39554 .26729 Mdot
.3868 .6515 Mdot
.36786 .61933 Mdot
.28764 .51364 Mdot
.3051 .4898 Mdot
.62465 .24085 Mdot
.84686 .40288 Mdot
.59404 .36813 Mdot
.30084 .41738 Mdot
.29137 .48916 Mdot
.2972 .50826 Mdot
.37422 .65866 Mdot
.3799 .34472 Mdot
.45166 .39074 Mdot
.34869 .67644 Mdot
.70576 .66076 Mdot
.40083 .34759 Mdot
.68481 .30085 Mdot
.40057 .68229 Mdot
.6936 .35968 Mdot
.54165 .21375 Mdot
.58003 .7047 Mdot
.67895 .66878 Mdot
.32492 .49989 Mdot
.58707 .43848 Mdot
.18517 .40479 Mdot
.36465 .65925 Mdot
.55817 .60465 Mdot
.24164 .47141 Mdot
.61856 .37875 Mdot
.58401 .40785 Mdot
.60412 .41087 Mdot
.60527 .65963 Mdot
.54626 .24839 Mdot
.58363 .43521 Mdot
.71243 .53197 Mdot
.706 .3499 Mdot
.33701 .68836 Mdot
.61169 .68981 Mdot
.64451 .65307 Mdot
.3244 .63228 Mdot
.36798 .41981 Mdot
.56056 .40401 Mdot
.31834 .50894 Mdot
.66704 .36966 Mdot
.27512 .50814 Mdot
.28527 .53722 Mdot
.51057 .84114 Mdot
.43062 .33466 Mdot
.67469 .38166 Mdot
.40912 .6594 Mdot
.45055 .39181 Mdot
.67346 .36527 Mdot
.53181 .16374 Mdot
.25694 .48277 Mdot
.85093 .3568 Mdot
.30184 .48843 Mdot
.56742 .59507 Mdot
.40688 .36139 Mdot
.37656 .36469 Mdot
.67109 .57355 Mdot
.3783 .33525 Mdot
.42083 .6074 Mdot
.43748 .33192 Mdot
.6346 .78171 Mdot
.42214 .28699 Mdot
.29262 .51524 Mdot
.26543 .52247 Mdot
.68874 .35391 Mdot
.61666 .41331 Mdot
.70635 .58515 Mdot
.55037 .57815 Mdot
.5671 .45427 Mdot
.38925 .66642 Mdot
.31793 .70021 Mdot
.19941 .50246 Mdot
.42762 .36587 Mdot
.30714 .51954 Mdot
.58351 .40937 Mdot
.68625 .37292 Mdot
.56745 .4272 Mdot
.34294 .56535 Mdot
.70568 .3017 Mdot
.60237 .42232 Mdot
.6865 .35615 Mdot
.34975 .66721 Mdot
.35328 .58963 Mdot
.32301 .27292 Mdot
.50053 .83747 Mdot
.62152 .40036 Mdot
.59035 .70828 Mdot
.57729 .6672 Mdot
.64835 .37416 Mdot
.52807 .48433 Mdot
.58545 .53083 Mdot
.60568 .43969 Mdot
.7433 .48885 Mdot
.35375 .69495 Mdot
.55384 .54965 Mdot
.3582 .67463 Mdot
.43375 .37579 Mdot
.54342 .54971 Mdot
.39475 .66632 Mdot
.72759 .5477 Mdot
.54357 .5927 Mdot
.29285 .44512 Mdot
.58188 .67452 Mdot
.61906 .43263 Mdot
.59397 .24346 Mdot
.41554 .66265 Mdot
.29664 .52065 Mdot
.41941 .36296 Mdot
.27795 .52607 Mdot
.42726 .62094 Mdot
.69739 .66991 Mdot
.53838 .55788 Mdot
.31995 .51181 Mdot
.67453 .35581 Mdot
.59232 .71204 Mdot
.29283 .48434 Mdot
.70375 .3566 Mdot
.64311 .37433 Mdot
.85135 .44297 Mdot
.61842 .44798 Mdot
.31938 .70739 Mdot
.27227 .48422 Mdot
.55188 .54682 Mdot
.61095 .43112 Mdot
.38627 .69093 Mdot
.56439 .54185 Mdot
.60048 .4303 Mdot
.39882 .6314 Mdot
.6063 .44647 Mdot
.61083 .67908 Mdot
.40921 .32167 Mdot
.66723 .59209 Mdot
.61004 .74627 Mdot
.59236 .66805 Mdot
.71222 .51378 Mdot
.56874 .44795 Mdot
.43642 .61369 Mdot
.41114 .35028 Mdot
.59118 .39121 Mdot
.64588 .75268 Mdot
.38756 .35563 Mdot
.40251 .35518 Mdot
.70154 .36987 Mdot
.32581 .52199 Mdot
.37848 .64957 Mdot
.60311 .71305 Mdot
.31768 .60631 Mdot
.58816 .43601 Mdot
.66675 .38851 Mdot
.58784 .67137 Mdot
.28702 .52452 Mdot
.6748 .37929 Mdot
.26954 .44238 Mdot
.70491 .55665 Mdot
.27487 .47897 Mdot
.56547 .39822 Mdot
.70368 .29269 Mdot
.36231 .33563 Mdot
.18557 .4074 Mdot
.35151 .5397 Mdot
.36487 .68742 Mdot
.55376 .57678 Mdot
.50138 .14662 Mdot
.57805 .68728 Mdot
.47701 .37804 Mdot
.57206 .43679 Mdot
.58152 .42263 Mdot
.37487 .32283 Mdot
.59501 .46053 Mdot
.42763 .36702 Mdot
.31671 .672 Mdot
.84834 .39255 Mdot
.42962 .34192 Mdot
.41406 .34208 Mdot
.69796 .33517 Mdot
.42402 .65286 Mdot
.39706 .36207 Mdot
.61363 .44602 Mdot
.42708 .61991 Mdot
.50234 .55336 Mdot
.61033 .72339 Mdot
.6136 .6661 Mdot
.45096 .35991 Mdot
.65788 .27552 Mdot
.70089 .35534 Mdot
.60731 .30927 Mdot
.58969 .53958 Mdot
.30674 .50318 Mdot
.6355 .38979 Mdot
.54679 .58001 Mdot
.35853 .66693 Mdot
.63943 .42118 Mdot
.62068 .42849 Mdot
.42092 .33349 Mdot
.5906 .72037 Mdot
.27744 .48839 Mdot
.5481 .60416 Mdot
.41579 .61905 Mdot
.58754 .68999 Mdot
.42583 .37107 Mdot
.64455 .24815 Mdot
.52086 .58976 Mdot
.5464 .60814 Mdot
.59266 .39446 Mdot
.61891 .39181 Mdot
.52275 .58751 Mdot
.28417 .50104 Mdot
.36523 .68913 Mdot
.56036 .59678 Mdot
.64002 .56286 Mdot
.71396 .57446 Mdot
.60339 .39326 Mdot
.4437 .34442 Mdot
.30559 .51753 Mdot
.54448 .55738 Mdot
.40835 .81271 Mdot
.6322 .42237 Mdot
.68787 .30057 Mdot
.62553 .70668 Mdot
.54704 .58499 Mdot
.45244 .39056 Mdot
.61048 .70324 Mdot
.68824 .37102 Mdot
.71561 .53093 Mdot
.56264 .44529 Mdot
.58088 .38416 Mdot
.39908 .66698 Mdot
.27427 .49767 Mdot
.578 .59549 Mdot
.36203 .67091 Mdot
.40584 .35673 Mdot
.61026 .31263 Mdot
.40856 .32598 Mdot
.4288 .32955 Mdot
.41102 .3155 Mdot
.27289 .52225 Mdot
.50083 .14573 Mdot
.52431 .59395 Mdot
.58392 .45158 Mdot
.31357 .51647 Mdot
.40466 .3652 Mdot
.56064 .42916 Mdot
.42444 .36817 Mdot
.4137 .37271 Mdot
.56347 .44894 Mdot
.68747 .35966 Mdot
.71653 .525 Mdot
.68529 .29156 Mdot
.61431 .69237 Mdot
.36807 .33114 Mdot
.67204 .28575 Mdot
.58138 .43001 Mdot
.62135 .41939 Mdot
.68814 .35283 Mdot
.59 .66488 Mdot
.61135 .32004 Mdot
.57181 .43249 Mdot
.6667 .67346 Mdot
.56171 .4214 Mdot
.40087 .37105 Mdot
.31349 .44929 Mdot
.70553 .36036 Mdot
.34883 .66354 Mdot
.36768 .32663 Mdot
.58014 .70543 Mdot
.35177 .33027 Mdot
.64876 .41596 Mdot
.29648 .50026 Mdot
.40815 .34093 Mdot
.35063 .6822 Mdot
.29302 .52169 Mdot
.2612 .49787 Mdot
.68969 .35136 Mdot
.37493 .69013 Mdot
.58948 .71958 Mdot
.26595 .49748 Mdot
.63073 .45556 Mdot
.29351 .51649 Mdot
.48579 .33349 Mdot
.59358 .46829 Mdot
.7134 .5332 Mdot
.56007 .58376 Mdot
.57563 .57866 Mdot
.26859 .489 Mdot
.58496 .67989 Mdot
.67438 .37964 Mdot
.43901 .35888 Mdot
.58254 .69805 Mdot
.54282 .2178 Mdot
.34448 .67262 Mdot
.37433 .29876 Mdot
.32269 .59511 Mdot
.37325 .34474 Mdot
.68161 .66957 Mdot
.57415 .69121 Mdot
.54957 .61181 Mdot
.67693 .59391 Mdot
.55069 .56876 Mdot
.63539 .42957 Mdot
.67349 .3802 Mdot
.61381 .40742 Mdot
.35684 .65383 Mdot
.60766 .66191 Mdot
.44328 .35165 Mdot
.49062 .60183 Mdot
.28226 .525 Mdot
.63894 .36858 Mdot
.56001 .60113 Mdot
.67951 .37625 Mdot
.41471 .36659 Mdot
.3773 .36069 Mdot
.54646 .23686 Mdot
.37753 .64284 Mdot
.52327 .62277 Mdot
.60377 .39415 Mdot
.48239 .58064 Mdot
.26831 .48837 Mdot
.33256 .42603 Mdot
.36364 .6995 Mdot
.84942 .35438 Mdot
.36403 .67302 Mdot
.50098 .58658 Mdot
.37481 .35507 Mdot
.60481 .69518 Mdot
.61716 .40343 Mdot
.4151 .32138 Mdot
.45767 .38878 Mdot
.57884 .64145 Mdot
.61011 .69781 Mdot
.33995 .55515 Mdot
.31029 .50528 Mdot
.54323 .60459 Mdot
.56224 .41817 Mdot
.55979 .43366 Mdot
.61538 .44741 Mdot
.30998 .51728 Mdot
.68033 .36661 Mdot
.32376 .45618 Mdot
.65509 .39654 Mdot
.64698 .7526 Mdot
.40002 .65037 Mdot
.23761 .69253 Mdot
.39013 .31993 Mdot
.61144 .31753 Mdot
.49555 .36206 Mdot
.70469 .54101 Mdot
.31274 .52875 Mdot
.55622 .54323 Mdot
.37648 .65454 Mdot
.22639 .5382 Mdot
.40167 .65074 Mdot
.86174 .53818 Mdot
.6148 .27148 Mdot
.3084 .44687 Mdot
.56577 .44836 Mdot
.39835 .67422 Mdot
.66391 .27549 Mdot
.55937 .59642 Mdot
.51768 .5722 Mdot
.66292 .39578 Mdot
.55726 .19722 Mdot
.61432 .68965 Mdot
.6157 .40141 Mdot
.39744 .32169 Mdot
.61886 .4051 Mdot
.6184 .40324 Mdot
.56961 .43231 Mdot
.27606 .47472 Mdot
.58846 .47051 Mdot
.61606 .41118 Mdot
.34801 .76734 Mdot
.53731 .53194 Mdot
.40127 .62482 Mdot
.36661 .35832 Mdot
.59091 .71226 Mdot
.43203 .37591 Mdot
.67125 .5933 Mdot
.30274 .48687 Mdot
.54517 .23954 Mdot
.68571 .36771 Mdot
.45181 .33492 Mdot
.31786 .50221 Mdot
.61922 .6991 Mdot
.54394 .57878 Mdot
.25507 .32059 Mdot
.42001 .66675 Mdot
.54151 .56533 Mdot
.38888 .63254 Mdot
.6116 .47034 Mdot
.43054 .34765 Mdot
.55049 .56967 Mdot
.27292 .49249 Mdot
.40458 .65787 Mdot
.71389 .5165 Mdot
.59496 .41665 Mdot
.39052 .65265 Mdot
.55161 .59235 Mdot
.65994 .5664 Mdot
.66815 .58653 Mdot
.40046 .67241 Mdot
.30385 .5387 Mdot
.26313 .50546 Mdot
.58495 .7066 Mdot
.36922 .35267 Mdot
.38879 .33018 Mdot
.28105 .52258 Mdot
.23299 .54716 Mdot
.59037 .4373 Mdot
.59484 .42416 Mdot
.68114 .60106 Mdot
.57988 .39509 Mdot
.41241 .60033 Mdot
.54351 .56695 Mdot
.40466 .33271 Mdot
.673 .38012 Mdot
.66646 .38058 Mdot
.61239 .40009 Mdot
.70819 .66235 Mdot
.35659 .65717 Mdot
.69993 .35293 Mdot
.60952 .67366 Mdot
.55266 .20215 Mdot
.62581 .42821 Mdot
.5962 .73759 Mdot
.37157 .3529 Mdot
.22384 .48398 Mdot
.29771 .51963 Mdot
.41149 .65761 Mdot
.41004 .65903 Mdot
.55816 .79846 Mdot
.38577 .32027 Mdot
.54262 .56524 Mdot
.35307 .70742 Mdot
.55876 .55935 Mdot
.60845 .70183 Mdot
.54243 .40655 Mdot
.41506 .60243 Mdot
.40095 .62505 Mdot
.32889 .54135 Mdot
.61651 .38046 Mdot
.62557 .4248 Mdot
.3292 .41644 Mdot
.61698 .42891 Mdot
.59932 .67754 Mdot
.3034 .49343 Mdot
.40775 .34212 Mdot
.61627 .69446 Mdot
.31628 .50354 Mdot
.37925 .33188 Mdot
.69387 .35307 Mdot
.56075 .42556 Mdot
.41145 .36011 Mdot
.41639 .37099 Mdot
.59111 .44296 Mdot
.52832 .84635 Mdot
.42027 .33488 Mdot
.41462 .36284 Mdot
.55363 .20157 Mdot
.42046 .63547 Mdot
.56185 .54026 Mdot
.32426 .52253 Mdot
.61177 .41078 Mdot
.39639 .64706 Mdot
.60128 .70437 Mdot
.40669 .33662 Mdot
.61833 .39396 Mdot
.58841 .43273 Mdot
.59083 .71012 Mdot
.60293 .66236 Mdot
.5821 .68624 Mdot
.27076 .52771 Mdot
.69111 .36338 Mdot
.40421 .36285 Mdot
.30378 .53044 Mdot
.57594 .68948 Mdot
.60881 .66644 Mdot
.67422 .74928 Mdot
.59079 .44006 Mdot
.59929 .65966 Mdot
.5177 .15542 Mdot
.73249 .53816 Mdot
.5547 .55359 Mdot
.37688 .62604 Mdot
.41964 .61628 Mdot
.51013 .55027 Mdot
.27668 .49628 Mdot
.6709 .36176 Mdot
.61314 .71865 Mdot
.55448 .59591 Mdot
.59494 .42074 Mdot
.63541 .40038 Mdot
.58494 .69967 Mdot
.69701 .67194 Mdot
.41803 .33121 Mdot
.36952 .26585 Mdot
.59257 .71321 Mdot
.40003 .67584 Mdot
.3582 .69964 Mdot
.36991 .6701 Mdot
.6084 .39317 Mdot
.69329 .31908 Mdot
.55578 .4914 Mdot
.54303 .33987 Mdot
.3073 .50106 Mdot
.38259 .36335 Mdot
.55124 .19612 Mdot
.39975 .35354 Mdot
.37038 .64209 Mdot
.58545 .67923 Mdot
.37821 .32344 Mdot
.26466 .51596 Mdot
.26323 .498 Mdot
.4223 .64027 Mdot
.36329 .6768 Mdot
.37999 .6649 Mdot
.36463 .32471 Mdot
.38902 .36259 Mdot
.56356 .44188 Mdot
.44118 .34491 Mdot
.31806 .66997 Mdot
.31725 .66656 Mdot
.42009 .65325 Mdot
.28526 .50609 Mdot
.38546 .33866 Mdot
.61321 .44365 Mdot
.69839 .51345 Mdot
.36662 .70566 Mdot
.59067 .7172 Mdot
.55784 .17161 Mdot
.84573 .40992 Mdot
.66147 .38722 Mdot
.30168 .50096 Mdot
.55611 .56119 Mdot
.60454 .40775 Mdot
.36256 .68772 Mdot
.52639 .61236 Mdot
.52611 .57695 Mdot
.60067 .46204 Mdot
.56487 .4626 Mdot
.30358 .51153 Mdot
.66989 .59599 Mdot
.55439 .59831 Mdot
.70541 .34446 Mdot
.31204 .5031 Mdot
.38532 .697 Mdot
.37882 .73692 Mdot
.33886 .37952 Mdot
.61672 .61241 Mdot
.53219 .55825 Mdot
.63126 .4279 Mdot
.38893 .67041 Mdot
.61751 .69342 Mdot
.38447 .67063 Mdot
.43831 .37264 Mdot
.42109 .63309 Mdot
.61147 .44264 Mdot
.39878 .36113 Mdot
.26246 .49776 Mdot
.63408 .58199 Mdot
.5609 .64078 Mdot
.38908 .69 Mdot
.54427 .61024 Mdot
.66568 .37401 Mdot
.59645 .48179 Mdot
.57532 .5768 Mdot
.6215 .43125 Mdot
.27589 .51024 Mdot
.42325 .36703 Mdot
.29224 .52781 Mdot
.56793 .54629 Mdot
.48477 .3569 Mdot
.29911 .51875 Mdot
.69255 .32454 Mdot
.61947 .68321 Mdot
.70089 .66808 Mdot
.60418 .44378 Mdot
.27242 .49506 Mdot
.59129 .4671 Mdot
.36946 .32904 Mdot
.7204 .55899 Mdot
.70504 .55242 Mdot
.27598 .51761 Mdot
.56941 .60096 Mdot
.66284 .5705 Mdot
.56173 .53955 Mdot
.29171 .48994 Mdot
.73816 .53028 Mdot
.53621 .57065 Mdot
.59047 .69321 Mdot
.61092 .66687 Mdot
.58929 .68522 Mdot
.6012 .42074 Mdot
.69231 .27683 Mdot
.57574 .67869 Mdot
.22626 .51829 Mdot
.60108 .67302 Mdot
.51082 .54607 Mdot
.31403 .40104 Mdot
.60932 .66958 Mdot
.61176 .43605 Mdot
.65626 .39262 Mdot
.67448 .35796 Mdot
.35917 .69214 Mdot
.2381 .34072 Mdot
.34592 .76461 Mdot
.57973 .4292 Mdot
.54987 .18646 Mdot
.42362 .32497 Mdot
.54875 .61296 Mdot
.70514 .54898 Mdot
.69191 .34359 Mdot
.39388 .35232 Mdot
.6742 .59475 Mdot
.37004 .30521 Mdot
.56367 .57892 Mdot
.59812 .42477 Mdot
.36822 .32569 Mdot
.43299 .31994 Mdot
.72568 .6489 Mdot
.3609 .41659 Mdot
.38317 .3348 Mdot
.28637 .48651 Mdot
.28002 .49612 Mdot
.27521 .5125 Mdot
.36531 .68157 Mdot
.41357 .34056 Mdot
.63258 .37317 Mdot
.36335 .68587 Mdot
.57405 .42296 Mdot
.27777 .52017 Mdot
.70821 .54566 Mdot
.41305 .34231 Mdot
.60334 .44196 Mdot
.66372 .2818 Mdot
.40186 .6332 Mdot
.58895 .70757 Mdot
.5509 .18116 Mdot
.36436 .63622 Mdot
.31613 .53908 Mdot
.44626 .37071 Mdot
.53674 .53366 Mdot
.70255 .34396 Mdot
.60428 .38884 Mdot
.57922 .45272 Mdot
.70242 .34281 Mdot
.61706 .26754 Mdot
.53099 .59269 Mdot
.36829 .68503 Mdot
.41873 .63203 Mdot
.62997 .42411 Mdot
.41831 .33954 Mdot
.57092 .68777 Mdot
.60325 .73351 Mdot
.50349 .60386 Mdot
.66823 .57785 Mdot
.71225 .53233 Mdot
.58899 .38587 Mdot
.62951 .32974 Mdot
.35387 .68579 Mdot
.56143 .55944 Mdot
.67402 .57995 Mdot
.59566 .68929 Mdot
.57235 .41847 Mdot
.39195 .37629 Mdot
.40432 .33804 Mdot
.38475 .65092 Mdot
.25939 .48717 Mdot
.51949 .58594 Mdot
.4207 .65272 Mdot
.63005 .42359 Mdot
.66897 .38032 Mdot
.28429 .48369 Mdot
.44501 .3687 Mdot
.58818 .69723 Mdot
.3594 .6832 Mdot
.60243 .69254 Mdot
.43377 .35304 Mdot
.40589 .336 Mdot
.5756 .40695 Mdot
.5132 .6173 Mdot
.39156 .68966 Mdot
.61298 .39608 Mdot
.39135 .65735 Mdot
.35071 .58905 Mdot
.25767 .50758 Mdot
.58667 .39432 Mdot
.43977 .3942 Mdot
.27446 .51927 Mdot
.57793 .42476 Mdot
.68283 .35249 Mdot
.67481 .3787 Mdot
.39755 .67615 Mdot
.61153 .72877 Mdot
.59493 .69464 Mdot
.50159 .3623 Mdot
.53957 .22892 Mdot
.59975 .38166 Mdot
.41691 .65591 Mdot
.65977 .40175 Mdot
.29981 .50784 Mdot
.37352 .35005 Mdot
.18941 .62948 Mdot
.29164 .50957 Mdot
.60246 .44742 Mdot
.59845 .68244 Mdot
.41722 .37214 Mdot
.54734 .54913 Mdot
.68614 .62758 Mdot
.57395 .59851 Mdot
.50715 .61159 Mdot
.54076 .60047 Mdot
.30553 .4154 Mdot
.38203 .66616 Mdot
.41005 .36593 Mdot
.2989 .4971 Mdot
.29831 .50345 Mdot
.38147 .63442 Mdot
.54456 .22049 Mdot
.33412 .26975 Mdot
.51535 .1488 Mdot
.40811 .68641 Mdot
.59124 .67716 Mdot
.7212 .55567 Mdot
.36911 .66882 Mdot
.38183 .63032 Mdot
.34545 .56588 Mdot
.3301 .41802 Mdot
.38286 .34376 Mdot
.587 .43193 Mdot
.54672 .19943 Mdot
.57556 .44383 Mdot
.61635 .60708 Mdot
.28241 .52135 Mdot
.37323 .3496 Mdot
.35313 .48804 Mdot
.63028 .4032 Mdot
.59377 .405 Mdot
.31744 .68647 Mdot
.54828 .57567 Mdot
.44465 .82122 Mdot
.56761 .43615 Mdot
.37347 .67938 Mdot
.38915 .39968 Mdot
.56295 .58459 Mdot
.66575 .28132 Mdot
.27498 .48352 Mdot
.54037 .55764 Mdot
.56344 .58721 Mdot
.63605 .3317 Mdot
.38299 .29561 Mdot
.38708 .32671 Mdot
.59329 .66048 Mdot
.32404 .39034 Mdot
.28083 .48046 Mdot
.28422 .43265 Mdot
.61609 .44206 Mdot
.2775 .53666 Mdot
.62345 .73057 Mdot
.57704 .42844 Mdot
.67597 .36272 Mdot
.5457 .23715 Mdot
.63458 .38728 Mdot
.64363 .43085 Mdot
.28872 .51213 Mdot
.65403 .7396 Mdot
.58594 .3835 Mdot
.38835 .65228 Mdot
.37961 .34591 Mdot
.38742 .29172 Mdot
.61343 .70964 Mdot
.3553 .52765 Mdot
.84985 .37627 Mdot
.37373 .34939 Mdot
.59722 .41677 Mdot
.29856 .5092 Mdot
.54394 .55254 Mdot
.55908 .58104 Mdot
.56479 .61179 Mdot
.39908 .3386 Mdot
.56189 .58689 Mdot
.4753 .38136 Mdot
.67298 .59469 Mdot
.6107 .31639 Mdot
.27078 .51215 Mdot
.59359 .67809 Mdot
.49662 .57357 Mdot
.343 .58912 Mdot
.56404 .41143 Mdot
.61638 .60869 Mdot
.3963 .31337 Mdot
.59663 .67753 Mdot
.61053 .40457 Mdot
.53514 .59933 Mdot
.74481 .47739 Mdot
.58193 .71957 Mdot
.53708 .59776 Mdot
.6787 .38508 Mdot
.37374 .33296 Mdot
.54465 .56326 Mdot
.40416 .34308 Mdot
.61178 .40297 Mdot
.59622 .5449 Mdot
.36846 .33562 Mdot
.22806 .35552 Mdot
.52498 .59816 Mdot
.31126 .49585 Mdot
.6427 .4178 Mdot
.62213 .40043 Mdot
.69001 .3098 Mdot
.54741 .55443 Mdot
.19366 .40549 Mdot
.39623 .65463 Mdot
.42623 .82227 Mdot
.42811 .62577 Mdot
.34043 .565 Mdot
.24634 .45546 Mdot
.62547 .39387 Mdot
.54542 .2205 Mdot
.69278 .3159 Mdot
.30839 .53611 Mdot
.69448 .31248 Mdot
.61656 .41321 Mdot
.59222 .39515 Mdot
.39148 .65624 Mdot
.24972 .49408 Mdot
.70355 .36637 Mdot
.67313 .57927 Mdot
.61903 .70239 Mdot
.41805 .35535 Mdot
.61015 .4167 Mdot
.45359 .32889 Mdot
.40319 .67153 Mdot
.39303 .26568 Mdot
.60878 .43746 Mdot
.54789 .57557 Mdot
.27387 .53321 Mdot
.26349 .49305 Mdot
.38775 .685 Mdot
.38662 .68739 Mdot
.62229 .40097 Mdot
.29263 .53135 Mdot
.56212 .4096 Mdot
.66206 .56952 Mdot
.55002 .59385 Mdot
.60404 .70813 Mdot
.5966 .45808 Mdot
.34691 .26748 Mdot
.73714 .71543 Mdot
.60743 .39332 Mdot
.40133 .32409 Mdot
.38055 .66107 Mdot
.3639 .64436 Mdot
.3889 .33081 Mdot
.36529 .64319 Mdot
.37018 .26444 Mdot
.69382 .27904 Mdot
.6083 .69788 Mdot
.64928 .43255 Mdot
.59507 .66852 Mdot
.54333 .55659 Mdot
.59129 .44109 Mdot
.20394 .54175 Mdot
.41023 .68342 Mdot
.69225 .46813 Mdot
.28896 .52196 Mdot
.56742 .57545 Mdot
.6832 .36593 Mdot
.60071 .65028 Mdot
.36182 .66259 Mdot
.51985 .56562 Mdot
.5694 .42539 Mdot
.36551 .3269 Mdot
.67492 .38808 Mdot
.56679 .58855 Mdot
.54973 .55894 Mdot
.52235 .56232 Mdot
.31639 .5037 Mdot
.43497 .36239 Mdot
.3401 .55529 Mdot
.40709 .63689 Mdot
.56801 .45666 Mdot
.59876 .41422 Mdot
.37918 .36079 Mdot
.58778 .45377 Mdot
.28709 .53242 Mdot
.47911 .13696 Mdot
.58284 .67971 Mdot
.54889 .55184 Mdot
.25721 .3615 Mdot
.52551 .55522 Mdot
.68597 .37999 Mdot
.68949 .34165 Mdot
.37041 .36408 Mdot
.32016 .50864 Mdot
.5539 .43127 Mdot
.41113 .62475 Mdot
.58973 .69685 Mdot
.26329 .51474 Mdot
.67044 .37442 Mdot
.61216 .43931 Mdot
.59553 .67897 Mdot
.35083 .47872 Mdot
.61958 .71245 Mdot
.29996 .49609 Mdot
.56977 .57143 Mdot
.70242 .50714 Mdot
.59958 .43466 Mdot
.54398 .57044 Mdot
.43056 .35991 Mdot
.30959 .50731 Mdot
.54767 .25079 Mdot
.56433 .5831 Mdot
.31773 .60424 Mdot
.26611 .4884 Mdot
.60153 .38858 Mdot
.37596 .31684 Mdot
.40218 .28534 Mdot
.42451 .36515 Mdot
.59281 .79262 Mdot
.31836 .62354 Mdot
.3836 .66236 Mdot
.28683 .50585 Mdot
.39333 .64374 Mdot
.61932 .68159 Mdot
.71138 .57271 Mdot
.38816 .68849 Mdot
.45054 .34617 Mdot
.40136 .6472 Mdot
.56051 .41451 Mdot
.31132 .49481 Mdot
.39858 .68506 Mdot
.6063 .45372 Mdot
.69501 .35157 Mdot
.5522 .56375 Mdot
.57219 .69114 Mdot
.6716 .58688 Mdot
.59284 .449 Mdot
.54135 .57473 Mdot
.60201 .44047 Mdot
.28742 .53219 Mdot
.62847 .58031 Mdot
.56837 .46142 Mdot
.40706 .68734 Mdot
.27095 .30244 Mdot
.41872 .63886 Mdot
.4789 .60692 Mdot
.57445 .42823 Mdot
.59719 .43706 Mdot
.67569 .36912 Mdot
.56977 .18049 Mdot
.30036 .54098 Mdot
.59151 .47118 Mdot
.35289 .6532 Mdot
.39247 .34798 Mdot
.38478 .32145 Mdot
.59959 .36338 Mdot
.5418 .56839 Mdot
.27449 .52894 Mdot
.59428 .43743 Mdot
.56483 .57221 Mdot
.69478 .58404 Mdot
.32337 .39905 Mdot
.32056 .64675 Mdot
.39491 .62979 Mdot
.36104 .34078 Mdot
.35383 .65944 Mdot
.6752 .37179 Mdot
.56187 .58052 Mdot
.31695 .62204 Mdot
.3036 .56796 Mdot
.591 .69771 Mdot
.58264 .40577 Mdot
.71354 .65946 Mdot
.34977 .66792 Mdot
.37113 .69019 Mdot
.56081 .41256 Mdot
.36936 .40453 Mdot
.71516 .7289 Mdot
.31336 .521 Mdot
.46942 .31498 Mdot
.60874 .24044 Mdot
.81927 .53786 Mdot
.28766 .49779 Mdot
.67273 .3652 Mdot
.35014 .68765 Mdot
.50156 .80747 Mdot
.39516 .35157 Mdot
.5898 .69844 Mdot
.60358 .45535 Mdot
.44315 .33978 Mdot
.40777 .68768 Mdot
.44089 .36341 Mdot
.55249 .57719 Mdot
.31529 .49861 Mdot
.35736 .6647 Mdot
.26112 .48231 Mdot
.43186 .39484 Mdot
.58774 .6766 Mdot
.66022 .66272 Mdot
.65241 .40783 Mdot
.54504 .23507 Mdot
.69122 .36143 Mdot
.53681 .53122 Mdot
.69506 .35588 Mdot
.39391 .28983 Mdot
.60544 .44309 Mdot
.56861 .39521 Mdot
.34405 .67642 Mdot
.60444 .39136 Mdot
.61256 .44638 Mdot
.6663 .28352 Mdot
.57965 .41337 Mdot
.61679 .40083 Mdot
.60626 .3874 Mdot
.41021 .32737 Mdot
.5701 .4157 Mdot
.40888 .36875 Mdot
.45819 .33948 Mdot
.40586 .63585 Mdot
.61347 .67227 Mdot
.60791 .66821 Mdot
.60389 .55311 Mdot
.71213 .66005 Mdot
.54824 .199 Mdot
.39687 .3466 Mdot
.26685 .48992 Mdot
.5613 .43696 Mdot
.68348 .74768 Mdot
.59723 .54597 Mdot
.36116 .69496 Mdot
.40614 .67006 Mdot
.61326 .45087 Mdot
.84462 .41791 Mdot
.56747 .43847 Mdot
.68941 .59936 Mdot
.60261 .42036 Mdot
.58638 .39351 Mdot
.41659 .62333 Mdot
.68132 .67032 Mdot
.70118 .35224 Mdot
.38507 .29857 Mdot
.59336 .70148 Mdot
.54634 .56542 Mdot
.60006 .55045 Mdot
.63402 .2445 Mdot
.33856 .34518 Mdot
.67493 .36938 Mdot
.35695 .68279 Mdot
.40327 .33391 Mdot
.68138 .59918 Mdot
.30594 .52914 Mdot
.68838 .62911 Mdot
.48677 .33058 Mdot
.31433 .52285 Mdot
.58984 .69375 Mdot
.37065 .70424 Mdot
.60264 .39971 Mdot
.38864 .6738 Mdot
.62875 .40109 Mdot
.69866 .59685 Mdot
.60642 .70348 Mdot
.44821 .33882 Mdot
.28801 .48574 Mdot
.42178 .33064 Mdot
.39993 .26765 Mdot
.60042 .55732 Mdot
.38422 .79691 Mdot
.4207 .64801 Mdot
.48138 .5936 Mdot
.38604 .35927 Mdot
.63272 .42099 Mdot
.51095 .15171 Mdot
.42711 .3504 Mdot
.36666 .32728 Mdot
.66842 .62242 Mdot
.68826 .68161 Mdot
.61363 .38939 Mdot
.44542 .34492 Mdot
.37334 .70483 Mdot
.61062 .69153 Mdot
.61907 .44075 Mdot
.56031 .57208 Mdot
.37676 .32293 Mdot
.3637 .65131 Mdot
.67505 .66766 Mdot
.36775 .67921 Mdot
.38627 .34898 Mdot
.41334 .65651 Mdot
.34102 .52545 Mdot
.38879 .68846 Mdot
.5917 .45774 Mdot
.59545 .43688 Mdot
.41566 .2857 Mdot
.4062 .33602 Mdot
.68629 .37972 Mdot
.58074 .44777 Mdot
.40028 .36345 Mdot
.36689 .70949 Mdot
.34251 .33504 Mdot
.67628 .38056 Mdot
.58872 .43522 Mdot
.58638 .66869 Mdot
.64509 .56509 Mdot
.65314 .60253 Mdot
.56218 .43714 Mdot
.58894 .67909 Mdot
.36336 .32957 Mdot
.5949 .44335 Mdot
.683 .67713 Mdot
.34329 .68548 Mdot
.59913 .37761 Mdot
.54188 .55167 Mdot
.6981 .36401 Mdot
.7481 .61256 Mdot
.67126 .37183 Mdot
.40167 .35836 Mdot
.38676 .354 Mdot
.34654 .69426 Mdot
.41387 .35958 Mdot
.54803 .55266 Mdot
.26819 .51563 Mdot
.47813 .30998 Mdot
.56489 .56612 Mdot
.52414 .5805 Mdot
.52448 .59433 Mdot
.55448 .60517 Mdot
.60054 .74269 Mdot
.32275 .63504 Mdot
.52761 .56803 Mdot
.41148 .36787 Mdot
.51695 .48481 Mdot
.56108 .54551 Mdot
.27623 .53089 Mdot
.56282 .58807 Mdot
.59971 .37762 Mdot
.67509 .36695 Mdot
.39125 .37128 Mdot
.30405 .53128 Mdot
.57725 .57633 Mdot
.61824 .44207 Mdot
.37917 .36937 Mdot
.61214 .41581 Mdot
.59904 .72432 Mdot
.41183 .34344 Mdot
.35992 .6802 Mdot
.60601 .70785 Mdot
.54914 .60116 Mdot
.58639 .70565 Mdot
.39121 .66631 Mdot
.26831 .49648 Mdot
.59906 .45481 Mdot
.60082 .72894 Mdot
.61416 .67466 Mdot
.63936 .39738 Mdot
.38172 .35149 Mdot
.56865 .6163 Mdot
.58811 .44268 Mdot
.68228 .36377 Mdot
.38889 .32977 Mdot
.18338 .41073 Mdot
.59839 .39895 Mdot
.70622 .34496 Mdot
.39538 .29508 Mdot
.56727 .58051 Mdot
.36298 .68321 Mdot
.61956 .3951 Mdot
.29533 .52477 Mdot
.28065 .52287 Mdot
.412 .68021 Mdot
.3831 .32527 Mdot
.36034 .65169 Mdot
.63694 .41707 Mdot
.56176 .59229 Mdot
.62377 .42488 Mdot
.32281 .7148 Mdot
.20691 .37822 Mdot
.42314 .37198 Mdot
.40819 .63528 Mdot
.69869 .57433 Mdot
.32554 .5231 Mdot
.38031 .71249 Mdot
.38805 .29645 Mdot
.43898 .33909 Mdot
.3861 .33135 Mdot
.6085 .67143 Mdot
.36262 .6743 Mdot
.37254 .35947 Mdot
.37803 .36291 Mdot
.67317 .37666 Mdot
.61107 .45105 Mdot
.36238 .33513 Mdot
.34089 .58865 Mdot
.59492 .69643 Mdot
.35875 .64435 Mdot
.72069 .72702 Mdot
.3127 .51419 Mdot
.66739 .28181 Mdot
.56227 .41466 Mdot
.84863 .34959 Mdot
.56834 .4395 Mdot
.60287 .41646 Mdot
.43373 .37579 Mdot
.62093 .67754 Mdot
.6081 .68569 Mdot
.38584 .35848 Mdot
.43184 .3713 Mdot
.60636 .7193 Mdot
.65389 .54053 Mdot
.73911 .63232 Mdot
.68704 .58367 Mdot
.44124 .36034 Mdot
.48514 .33976 Mdot
.28022 .51327 Mdot
.41855 .32402 Mdot
.33711 .47313 Mdot
.41204 .66917 Mdot
.39104 .68816 Mdot
.27785 .48498 Mdot
.60119 .40105 Mdot
.41894 .62417 Mdot
.69862 .358 Mdot
.31648 .4458 Mdot
.66684 .37043 Mdot
.5432 .84842 Mdot
.59075 .4557 Mdot
.45056 .57963 Mdot
.31125 .40854 Mdot
.69258 .37449 Mdot
.67455 .25931 Mdot
.58593 .69702 Mdot
.38586 .29105 Mdot
.29137 .53505 Mdot
.54571 .19936 Mdot
.59858 .43578 Mdot
.44774 .34847 Mdot
.2985 .49082 Mdot
.19716 .39571 Mdot
.69771 .34623 Mdot
.68145 .37521 Mdot
.50429 .14947 Mdot
.45724 .35023 Mdot
.36393 .6823 Mdot
.45718 .30087 Mdot
.41409 .37318 Mdot
.6878 .35076 Mdot
.37959 .70676 Mdot
.74185 .47484 Mdot
.44822 .35313 Mdot
.62055 .71082 Mdot
.41366 .35209 Mdot
.6041 .71737 Mdot
.37022 .35774 Mdot
.40375 .63709 Mdot
.58905 .40194 Mdot
.40337 .63499 Mdot
.58209 .70738 Mdot
.41714 .64234 Mdot
.29732 .53488 Mdot
.53909 .58774 Mdot
.27446 .51854 Mdot
.71491 .56671 Mdot
.55212 .26229 Mdot
.27289 .49944 Mdot
.64181 .35687 Mdot
.61322 .43957 Mdot
.36942 .35654 Mdot
.35626 .67632 Mdot
.34628 .65642 Mdot
.67025 .58445 Mdot
.37856 .33895 Mdot
.37252 .64183 Mdot
.62928 .45612 Mdot
.20319 .51548 Mdot
.70531 .34915 Mdot
.20045 .65093 Mdot
.40745 .36341 Mdot
.34649 .65791 Mdot
.68562 .59962 Mdot
.45672 .36278 Mdot
.39403 .68827 Mdot
.28421 .48866 Mdot
.29532 .52449 Mdot
.58281 .45584 Mdot
.2565 .4828 Mdot
.36013 .69286 Mdot
.48627 .35857 Mdot
.36771 .34351 Mdot
.21285 .36927 Mdot
.58432 .68172 Mdot
.35422 .66146 Mdot
.55428 .5931 Mdot
.43928 .39398 Mdot
.39705 .64406 Mdot
.84942 .38248 Mdot
.69037 .78316 Mdot
.36877 .64538 Mdot
.4097 .34375 Mdot
.39568 .337 Mdot
.66416 .38598 Mdot
.6705 .57953 Mdot
.36271 .66077 Mdot
.20117 .54092 Mdot
.71512 .52798 Mdot
.53744 .58392 Mdot
.34699 .76615 Mdot
.6435 .37491 Mdot
.68738 .36371 Mdot
.30886 .50894 Mdot
.5922 .40584 Mdot
.4359 .36892 Mdot
.56765 .438 Mdot
.27913 .5274 Mdot
.41439 .67497 Mdot
.59927 .43865 Mdot
.58921 .69525 Mdot
.3059 .51502 Mdot
.30081 .52582 Mdot
.41176 .65213 Mdot
.38146 .3257 Mdot
.54227 .20001 Mdot
.3632 .67757 Mdot
.69343 .36279 Mdot
.54213 .57942 Mdot
.60551 .38802 Mdot
.43525 .32758 Mdot
.36871 .30336 Mdot
.35186 .66629 Mdot
.63871 .40615 Mdot
.29063 .50283 Mdot
.34474 .67981 Mdot
.66821 .37247 Mdot
.38192 .69718 Mdot
.54246 .62001 Mdot
.41414 .61664 Mdot
.4229 .39656 Mdot
.54624 .6122 Mdot
.44883 .34651 Mdot
.5282 .57288 Mdot
.56043 .79938 Mdot
.59137 .69392 Mdot
.41939 .62931 Mdot
.22317 .3621 Mdot
.40385 .63298 Mdot
.57889 .41623 Mdot
.60677 .44632 Mdot
.39572 .65951 Mdot
.58904 .67541 Mdot
.50597 .55609 Mdot
.60685 .72904 Mdot
.40876 .34023 Mdot
.68238 .34954 Mdot
.65205 .80203 Mdot
.33946 .66642 Mdot
.28097 .48165 Mdot
.33798 .37328 Mdot
.52522 .58387 Mdot
.30095 .53394 Mdot
.30496 .52275 Mdot
.58179 .70299 Mdot
.38566 .62973 Mdot
.39709 .32007 Mdot
.28191 .47886 Mdot
.44988 .3662 Mdot
.67897 .67762 Mdot
.56132 .59866 Mdot
.48726 .56587 Mdot
.53637 .60044 Mdot
.67358 .59177 Mdot
.3048 .48727 Mdot
.61254 .42522 Mdot
.52654 .6223 Mdot
.29527 .49077 Mdot
.57478 .68145 Mdot
.66994 .369 Mdot
.37608 .63979 Mdot
.52423 .16823 Mdot
.58972 .45845 Mdot
.57812 .43575 Mdot
.30885 .50274 Mdot
.65895 .24752 Mdot
.38152 .29694 Mdot
.37268 .33253 Mdot
.38135 .66622 Mdot
.6659 .61877 Mdot
.56822 .42527 Mdot
.60823 .44769 Mdot
.39896 .6609 Mdot
.53801 .56819 Mdot
.36439 .78357 Mdot
.5901 .43249 Mdot
.28514 .51029 Mdot
.67332 .36563 Mdot
.30628 .53788 Mdot
.55519 .4358 Mdot
.5811 .41512 Mdot
.69042 .36884 Mdot
.692 .35522 Mdot
.2742 .51719 Mdot
.54102 .60124 Mdot
.52929 .55521 Mdot
.42939 .36358 Mdot
.61709 .44952 Mdot
.71435 .52638 Mdot
.59498 .43325 Mdot
.5858 .69525 Mdot
.65617 .60539 Mdot
.5589 .43674 Mdot
.60251 .46178 Mdot
.71719 .52941 Mdot
.6146 .40644 Mdot
.31008 .50331 Mdot
.39038 .33721 Mdot
.2927 .50293 Mdot
.29164 .48247 Mdot
.40232 .64581 Mdot
.57664 .67325 Mdot
.61874 .3969 Mdot
.61733 .70192 Mdot
.65111 .38405 Mdot
.573 .55452 Mdot
.66081 .56611 Mdot
.69013 .59785 Mdot
.57712 .71011 Mdot
.6134 .44131 Mdot
.38759 .66527 Mdot
.37745 .6296 Mdot
.67062 .36218 Mdot
.63954 .42169 Mdot
.25381 .49102 Mdot
.27291 .49481 Mdot
.31725 .66482 Mdot
.42468 .70792 Mdot
.60291 .72632 Mdot
.50642 .59669 Mdot
.69422 .35316 Mdot
.57735 .4118 Mdot
.53593 .59355 Mdot
.38786 .64655 Mdot
.52717 .57141 Mdot
.32191 .64118 Mdot
.3 .53674 Mdot
.29831 .50044 Mdot
.59186 .45668 Mdot
.8697 .46479 Mdot
.43307 .34878 Mdot
.3948 .33639 Mdot
.27036 .52282 Mdot
.41875 .63815 Mdot
.55491 .57659 Mdot
.54325 .17173 Mdot
.36354 .31015 Mdot
.61849 .67736 Mdot
.62631 .41457 Mdot
.41387 .66534 Mdot
.42543 .36814 Mdot
.60559 .72698 Mdot
.57966 .47236 Mdot
.37888 .70847 Mdot
.60714 .42553 Mdot
.60305 .48249 Mdot
.38153 .35904 Mdot
.65274 .56467 Mdot
.45009 .34415 Mdot
.28074 .51983 Mdot
.29581 .48208 Mdot
.57816 .4225 Mdot
.53757 .17568 Mdot
.37784 .40053 Mdot
.28109 .47735 Mdot
.59444 .66142 Mdot
.54325 .59191 Mdot
.57592 .67686 Mdot
.38854 .65611 Mdot
.59069 .6946 Mdot
.39838 .64399 Mdot
.3536 .70558 Mdot
.39346 .32055 Mdot
.59591 .6791 Mdot
.64156 .27048 Mdot
.56133 .57896 Mdot
.6016 .65987 Mdot
.57848 .46507 Mdot
.67401 .38315 Mdot
.36717 .65415 Mdot
.61899 .69677 Mdot
.61755 .39276 Mdot
.25249 .36561 Mdot
.30515 .49007 Mdot
.2956 .53517 Mdot
.55293 .57635 Mdot
.35147 .68455 Mdot
.39131 .31949 Mdot
.70101 .57315 Mdot
.46196 .38832 Mdot
.60767 .449 Mdot
.61653 .3968 Mdot
.45036 .39231 Mdot
.3895 .31948 Mdot
.58132 .41766 Mdot
.60894 .31093 Mdot
.55355 .5955 Mdot
.28901 .52613 Mdot
.41237 .34049 Mdot
.41555 .33683 Mdot
.36848 .69335 Mdot
.37342 .3247 Mdot
.49679 .60143 Mdot
.3004 .53613 Mdot
.53361 .55038 Mdot
.2894 .5054 Mdot
.57322 .5331 Mdot
.37838 .642 Mdot
.21119 .38143 Mdot
.37166 .33071 Mdot
.67764 .37909 Mdot
.37012 .32729 Mdot
.58164 .68638 Mdot
.44474 .34756 Mdot
.42511 .32521 Mdot
.60673 .45265 Mdot
.54135 .60031 Mdot
.54427 .55824 Mdot
.6741 .58591 Mdot
.43068 .35034 Mdot
.60796 .39687 Mdot
.56682 .41663 Mdot
.58346 .44966 Mdot
.66452 .56928 Mdot
.40114 .32599 Mdot
.63593 .24496 Mdot
.36521 .35456 Mdot
.38755 .36198 Mdot
.75166 .70406 Mdot
.55129 .55569 Mdot
.52723 .58087 Mdot
.23681 .47659 Mdot
.58728 .4329 Mdot
.36903 .64096 Mdot
.69047 .36486 Mdot
.54531 .5985 Mdot
.57433 .46722 Mdot
.61459 .69182 Mdot
.63129 .40674 Mdot
.5354 .57677 Mdot
.35759 .6748 Mdot
.67654 .37808 Mdot
.59094 .43885 Mdot
.54113 .5642 Mdot
.36882 .32391 Mdot
.41635 .33168 Mdot
.42883 .40626 Mdot
.59695 .7187 Mdot
.27579 .50499 Mdot
.68753 .36598 Mdot
.38394 .66553 Mdot
.374 .63679 Mdot
.44877 .34389 Mdot
.39141 .67951 Mdot
.30057 .50119 Mdot
.59527 .41845 Mdot
.27734 .51897 Mdot
.61371 .70171 Mdot
.41344 .34343 Mdot
.67815 .36907 Mdot
.67922 .38852 Mdot
.38677 .35409 Mdot
.55596 .59567 Mdot
.58428 .66842 Mdot
.40138 .66707 Mdot
.40698 .36954 Mdot
.27326 .52018 Mdot
.37703 .69245 Mdot
.68116 .37724 Mdot
.81496 .63069 Mdot
.59128 .40617 Mdot
.5735 .44172 Mdot
.39328 .39663 Mdot
.56364 .39982 Mdot
.40769 .63745 Mdot
.37985 .3195 Mdot
.6759 .38173 Mdot
.73022 .54341 Mdot
.57025 .67356 Mdot
.36187 .63305 Mdot
.61124 .40988 Mdot
.69004 .31045 Mdot
.59862 .3825 Mdot
.23328 .34904 Mdot
.65988 .56691 Mdot
.31927 .60676 Mdot
.48296 .57843 Mdot
.27362 .4787 Mdot
.53989 .5738 Mdot
.40414 .64426 Mdot
.60348 .30187 Mdot
.58661 .41302 Mdot
.54324 .24388 Mdot
.66923 .37445 Mdot
.29134 .49781 Mdot
.65632 .25392 Mdot
.35791 .68471 Mdot
.41704 .81796 Mdot
.62711 .43637 Mdot
.3745 .30049 Mdot
.36237 .58033 Mdot
.53597 .59077 Mdot
.52947 .58959 Mdot
.60157 .72504 Mdot
.39111 .70836 Mdot
.57563 .59317 Mdot
.29169 .50442 Mdot
.57554 .41237 Mdot
.64205 .42981 Mdot
.19009 .41168 Mdot
.41682 .36687 Mdot
.29319 .48541 Mdot
.38705 .61672 Mdot
.61584 .42659 Mdot
.43476 .33687 Mdot
.39573 .35175 Mdot
.61655 .68799 Mdot
.32304 .59583 Mdot
.38645 .71205 Mdot
.8458 .43682 Mdot
.57665 .6093 Mdot
.39054 .64764 Mdot
.54803 .6107 Mdot
.69182 .36528 Mdot
.59691 .54596 Mdot
.28378 .48049 Mdot
.57512 .424 Mdot
.54312 .23261 Mdot
.41644 .36359 Mdot
.59825 .42742 Mdot
.59764 .69961 Mdot
.55523 .16932 Mdot
.64824 .41945 Mdot
.61351 .31408 Mdot
.37365 .70497 Mdot
.61441 .39621 Mdot
.50099 .60607 Mdot
.56476 .57117 Mdot
.56283 .40051 Mdot
.36232 .68086 Mdot
.5441 .61124 Mdot
.60158 .69638 Mdot
.43366 .36387 Mdot
.54185 .57396 Mdot
.6681 .37472 Mdot
.62581 .39898 Mdot
.59153 .66183 Mdot
.68597 .37126 Mdot
.46104 .29108 Mdot
.56337 .60839 Mdot
.39671 .68204 Mdot
.41017 .37105 Mdot
.60839 .39408 Mdot
.5434 .59312 Mdot
.62302 .42388 Mdot
.34799 .26702 Mdot
.57498 .42023 Mdot
.22442 .38827 Mdot
.37914 .34493 Mdot
.29633 .51859 Mdot
.67646 .36757 Mdot
.60513 .42884 Mdot
.55081 .61284 Mdot
.55596 .57453 Mdot
.62763 .43069 Mdot
.44918 .34577 Mdot
.43743 .35718 Mdot
.3707 .30464 Mdot
.37371 .69586 Mdot
.68313 .57923 Mdot
.28928 .51947 Mdot
.53488 .5926 Mdot
.28133 .47901 Mdot
.69471 .32006 Mdot
.59418 .71537 Mdot
.1991 .40633 Mdot
.59078 .41824 Mdot
.38025 .33586 Mdot
.73507 .63597 Mdot
.43838 .3359 Mdot
.24639 .46998 Mdot
.28087 .48055 Mdot
.42253 .34826 Mdot
.60891 .40837 Mdot
.67532 .59655 Mdot
.69267 .30767 Mdot
.32184 .51141 Mdot
.53532 .55125 Mdot
.59137 .59115 Mdot
.38973 .69562 Mdot
.74413 .71151 Mdot
.26107 .49868 Mdot
.31069 .40652 Mdot
.67648 .38061 Mdot
.37086 .3383 Mdot
.27108 .51107 Mdot
.30018 .52784 Mdot
.3549 .6836 Mdot
.67388 .37696 Mdot
.60331 .42839 Mdot
.54066 .55274 Mdot
.26535 .49675 Mdot
.63507 .40325 Mdot
.69554 .37266 Mdot
.32358 .72111 Mdot
.37981 .29564 Mdot
.18223 .40928 Mdot
.68924 .33861 Mdot
.54464 .23186 Mdot
.22571 .54992 Mdot
.36844 .3527 Mdot
.61406 .4003 Mdot
.55314 .58836 Mdot
.39876 .67454 Mdot
.59693 .4125 Mdot
.40698 .63353 Mdot
.28341 .49774 Mdot
.23864 .3782 Mdot
.68807 .34067 Mdot
.3132 .44441 Mdot
.58872 .40387 Mdot
.65686 .39724 Mdot
.59943 .68782 Mdot
.28854 .53552 Mdot
.37924 .30437 Mdot
.60757 .38989 Mdot
.36892 .68844 Mdot
.3944 .6907 Mdot
.42082 .36311 Mdot
.3697 .41964 Mdot
.2158 .37296 Mdot
.55772 .59009 Mdot
.38444 .68089 Mdot
.54566 .59454 Mdot
.61352 .3167 Mdot
.28034 .47849 Mdot
.60247 .69569 Mdot
.41111 .66041 Mdot
.27016 .52683 Mdot
.6748 .38329 Mdot
.42441 .35634 Mdot
.45788 .38835 Mdot
.69238 .34644 Mdot
.37216 .64159 Mdot
.5993 .7133 Mdot
.61516 .36743 Mdot
.6842 .34899 Mdot
.60315 .70767 Mdot
.36503 .69507 Mdot
.43111 .34058 Mdot
.39034 .35172 Mdot
.38876 .3384 Mdot
.66593 .28107 Mdot
.3668 .30493 Mdot
.64543 .65214 Mdot
.57324 .3902 Mdot
.49214 .3591 Mdot
.61235 .38063 Mdot
.29344 .53491 Mdot
.37574 .35382 Mdot
.6593 .56619 Mdot
.70308 .35092 Mdot
.69777 .3068 Mdot
.58632 .44783 Mdot
.68691 .35336 Mdot
.58718 .43366 Mdot
.48944 .36441 Mdot
.37409 .2963 Mdot
.61179 .45661 Mdot
.31683 .52938 Mdot
.58388 .69916 Mdot
.43677 .37259 Mdot
.62164 .4036 Mdot
.47828 .36245 Mdot
.57628 .46376 Mdot
.23542 .3791 Mdot
.68076 .3556 Mdot
.40778 .59809 Mdot
.58173 .40074 Mdot
.42277 .64074 Mdot
.66798 .39106 Mdot
.48178 .31716 Mdot
.31191 .4957 Mdot
.64891 .4186 Mdot
.4242 .6281 Mdot
.6542 .25363 Mdot
.55895 .58489 Mdot
.59629 .69398 Mdot
.53212 .60253 Mdot
.27724 .52388 Mdot
.58834 .41644 Mdot
.62955 .40772 Mdot
.55203 .42467 Mdot
.61353 .31759 Mdot
.55603 .56159 Mdot
.57916 .71437 Mdot
.48581 .33545 Mdot
.62912 .42253 Mdot
.41201 .61942 Mdot
.39588 .32868 Mdot
.64421 .26324 Mdot
.62694 .2653 Mdot
.69445 .37596 Mdot
.42666 .35143 Mdot
.38269 .32522 Mdot
.69816 .74045 Mdot
.59193 .68431 Mdot
.57594 .43512 Mdot
.61852 .73148 Mdot
.68386 .36785 Mdot
.28133 .50464 Mdot
.5608 .4059 Mdot
.37735 .64191 Mdot
.67942 .60256 Mdot
.3686 .69657 Mdot
.58568 .45067 Mdot
.41117 .35118 Mdot
.32256 .51674 Mdot
.34947 .70396 Mdot
.32501 .59168 Mdot
.65168 .65925 Mdot
.38252 .71313 Mdot
.60611 .72456 Mdot
.58002 .69792 Mdot
.28921 .53546 Mdot
.6045 .41334 Mdot
.66615 .57257 Mdot
.71964 .33118 Mdot
.58628 .42856 Mdot
.60125 .40264 Mdot
.22679 .51207 Mdot
.27078 .48585 Mdot
.41465 .65521 Mdot
.58244 .41702 Mdot
.63227 .40607 Mdot
.41471 .34901 Mdot
.61891 .70453 Mdot
.40406 .65479 Mdot
.59597 .72203 Mdot
.38004 .67625 Mdot
.74871 .61277 Mdot
.56168 .59646 Mdot
.58846 .71064 Mdot
.26076 .4958 Mdot
.38638 .33334 Mdot
.55086 .55456 Mdot
.37891 .65691 Mdot
.38606 .68171 Mdot
.65071 .38522 Mdot
.42739 .36701 Mdot
.37236 .33256 Mdot
.60232 .72149 Mdot
.27209 .49729 Mdot
.69956 .35561 Mdot
.53468 .59865 Mdot
.33731 .65254 Mdot
.37789 .68792 Mdot
.48648 .34055 Mdot
.40957 .39661 Mdot
.62135 .42124 Mdot
.41888 .33259 Mdot
.60444 .43601 Mdot
.46743 .36011 Mdot
.45951 .35412 Mdot
.55711 .44006 Mdot
.52964 .35306 Mdot
.3894 .64522 Mdot
.61451 .82043 Mdot
.70593 .34849 Mdot
.30488 .54507 Mdot
.68889 .36659 Mdot
.38324 .79762 Mdot
.73272 .63951 Mdot
.62456 .4307 Mdot
.61879 .39924 Mdot
.86452 .49086 Mdot
.58182 .39327 Mdot
.52958 .57311 Mdot
.55963 .5836 Mdot
.42548 .33439 Mdot
.52746 .59711 Mdot
.67279 .58851 Mdot
.59486 .67447 Mdot
.38182 .66522 Mdot
.6856 .67606 Mdot
.60169 .71776 Mdot
.4057 .36078 Mdot
.70046 .35656 Mdot
.40032 .40094 Mdot
.40813 .62234 Mdot
.54567 .56943 Mdot
.28663 .49756 Mdot
.66626 .58002 Mdot
.36233 .68803 Mdot
.26501 .51145 Mdot
.57026 .40632 Mdot
.32137 .65041 Mdot
.31229 .53373 Mdot
.62912 .80948 Mdot
.31057 .52168 Mdot
.26845 .51724 Mdot
.67496 .57763 Mdot
.59507 .6742 Mdot
.55716 .61481 Mdot
.56381 .54142 Mdot
.31797 .50958 Mdot
.46541 .83105 Mdot
.35198 .68315 Mdot
.70106 .59401 Mdot
.38408 .2912 Mdot
.56352 .58393 Mdot
.59399 .40098 Mdot
.31003 .51013 Mdot
.64095 .42076 Mdot
.54856 .61277 Mdot
.30309 .51082 Mdot
.6691 .39075 Mdot
.66588 .61675 Mdot
.54647 .59107 Mdot
.54352 .55697 Mdot
.61641 .71502 Mdot
.42123 .6078 Mdot
.37744 .32976 Mdot
.61209 .66975 Mdot
.70683 .55432 Mdot
.57901 .44463 Mdot
.27389 .51638 Mdot
.54244 .57336 Mdot
.29042 .52236 Mdot
.60465 .68642 Mdot
.59092 .66077 Mdot
.42716 .36496 Mdot
.37329 .30244 Mdot
.56145 .55674 Mdot
.71812 .51893 Mdot
.58778 .38318 Mdot
.54565 .2534 Mdot
.4001 .32363 Mdot
.6818 .2664 Mdot
.60191 .66996 Mdot
.62004 .6966 Mdot
.65944 .39372 Mdot
.56415 .44311 Mdot
.68328 .35652 Mdot
.5612 .44336 Mdot
.4484 .81476 Mdot
.67577 .3705 Mdot
.39894 .66974 Mdot
.56784 .46156 Mdot
.321 .38628 Mdot
.65814 .38769 Mdot
.62441 .40907 Mdot
.36856 .67256 Mdot
.63113 .38351 Mdot
.36961 .64905 Mdot
.59718 .39585 Mdot
.33155 .73744 Mdot
.38349 .66591 Mdot
.50992 .55997 Mdot
.54066 .41529 Mdot
.53156 .56743 Mdot
.60882 .67771 Mdot
.5976 .72739 Mdot
.67286 .6674 Mdot
.4298 .34284 Mdot
.57607 .18492 Mdot
.62401 .41101 Mdot
.35513 .6867 Mdot
.28216 .49637 Mdot
.6814 .38684 Mdot
.57642 .44755 Mdot
.69653 .35067 Mdot
.43156 .35512 Mdot
.35183 .68795 Mdot
.60313 .67938 Mdot
.39624 .62805 Mdot
.33035 .73862 Mdot
.3797 .643 Mdot
.63394 .33021 Mdot
.66916 .38416 Mdot
.49939 .60414 Mdot
.56029 .2842 Mdot
.61181 .65761 Mdot
.42436 .36031 Mdot
.53994 .57654 Mdot
.57667 .68922 Mdot
.63462 .58293 Mdot
.38557 .32903 Mdot
.39848 .66162 Mdot
.60775 .42555 Mdot
.55364 .60666 Mdot
.56469 .54221 Mdot
.44191 .36803 Mdot
.58259 .66494 Mdot
.37586 .66312 Mdot
.54222 .58614 Mdot
.68753 .58138 Mdot
.61009 .23997 Mdot
.71351 .57351 Mdot
.60596 .43123 Mdot
.60549 .71958 Mdot
.42776 .36715 Mdot
.69548 .34883 Mdot
.2977 .4931 Mdot
.67096 .5817 Mdot
.59148 .40368 Mdot
.2943 .44395 Mdot
.41103 .3523 Mdot
.58673 .67911 Mdot
.31117 .51506 Mdot
.59074 .68616 Mdot
.52775 .58028 Mdot
.41396 .37626 Mdot
.52958 .58952 Mdot
.67006 .37236 Mdot
.27967 .49989 Mdot
.37568 .33118 Mdot
.32971 .73625 Mdot
.56496 .61668 Mdot
.39461 .65898 Mdot
.6368 .58276 Mdot
.43665 .35976 Mdot
.34279 .55126 Mdot
.39785 .62806 Mdot
.28654 .56404 Mdot
.64231 .56431 Mdot
.30455 .50731 Mdot
.62373 .40694 Mdot
.39461 .34242 Mdot
.32278 .51323 Mdot
.34851 .5886 Mdot
.68512 .30152 Mdot
.57034 .59495 Mdot
.61107 .44242 Mdot
.24058 .33785 Mdot
.31873 .4042 Mdot
.40377 .28435 Mdot
.26298 .51374 Mdot
.5806 .43612 Mdot
.55807 .59145 Mdot
.6204 .44659 Mdot
.3155 .50356 Mdot
.31764 .49237 Mdot
.36384 .63974 Mdot
.61168 .42401 Mdot
.58649 .69129 Mdot
.39138 .63704 Mdot
.39077 .69841 Mdot
.41036 .66491 Mdot
.3786 .30344 Mdot
.5654 .5861 Mdot
.56017 .58607 Mdot
.72714 .64644 Mdot
.29115 .52374 Mdot
.53147 .56807 Mdot
.63008 .406 Mdot
.64631 .65217 Mdot
.38306 .33983 Mdot
.37126 .66313 Mdot
.57891 .43723 Mdot
.70421 .34326 Mdot
.54558 .56414 Mdot
.36337 .67584 Mdot
.391 .32021 Mdot
.53038 .49534 Mdot
.59519 .41401 Mdot
.67188 .37537 Mdot
.3968 .35964 Mdot
.33003 .27127 Mdot
.69282 .58661 Mdot
.60272 .43622 Mdot
.28101 .52352 Mdot
.309 .28657 Mdot
.57497 .40117 Mdot
.44017 .40543 Mdot
.54015 .55112 Mdot
.50899 .46541 Mdot
.46582 .30309 Mdot
.57865 .48186 Mdot
.43275 .52329 Mdot
.69516 .46818 Mdot
.45175 .54293 Mdot
.48788 .81599 Mdot
.39476 .52875 Mdot
.64811 .79999 Mdot
.24984 .50054 Mdot
.59456 .4858 Mdot
.84111 .38148 Mdot
.31704 .41904 Mdot
.37795 .55234 Mdot
.33272 .54303 Mdot
.61062 .64644 Mdot
.35675 .77604 Mdot
.32035 .65291 Mdot
.49102 .81305 Mdot
.64608 .3757 Mdot
.31995 .32736 Mdot
.63373 .4551 Mdot
.3507 .53166 Mdot
.32309 .60438 Mdot
.6662 .36716 Mdot
.84747 .51059 Mdot
.25856 .46257 Mdot
.7885 .63313 Mdot
.55948 .20842 Mdot
.33021 .65009 Mdot
.70671 .50733 Mdot
.67834 .7086 Mdot
.67191 .3991 Mdot
.48249 .50143 Mdot
.24892 .49207 Mdot
.35121 .34813 Mdot
.20271 .52552 Mdot
.39386 .67014 Mdot
.44541 .36297 Mdot
.23417 .46709 Mdot
.83356 .5743 Mdot
.26428 .54026 Mdot
.43159 .52477 Mdot
.5695 .6081 Mdot
.51365 .45458 Mdot
.65846 .56248 Mdot
.47499 .33693 Mdot
.32437 .70495 Mdot
.36136 .7753 Mdot
.38882 .39185 Mdot
.36142 .59322 Mdot
.62614 .58134 Mdot
.37317 .55211 Mdot
.44262 .28661 Mdot
.59592 .64441 Mdot
.50975 .56455 Mdot
.40058 .32336 Mdot
.82563 .47112 Mdot
.61382 .35005 Mdot
.71158 .54965 Mdot
.33099 .60856 Mdot
.34688 .35975 Mdot
.5418 .19494 Mdot
.36537 .41783 Mdot
.56712 .84114 Mdot
.81389 .62454 Mdot
.53379 .8207 Mdot
.53526 .42538 Mdot
.2456 .52395 Mdot
.60589 .56577 Mdot
.45424 .58746 Mdot
.55791 .8205 Mdot
.34603 .26942 Mdot
.83971 .45746 Mdot
.48414 .42241 Mdot
.8411 .58697 Mdot
.41478 .38539 Mdot
.5493 .62968 Mdot
.4226 .28486 Mdot
.55117 .49859 Mdot
.71427 .62859 Mdot
.8479 .55448 Mdot
.35993 .53827 Mdot
.5634 .6212 Mdot
.31955 .42279 Mdot
.45975 .29311 Mdot
.32167 .70363 Mdot
.51887 .58909 Mdot
.58546 .27706 Mdot
.85683 .52865 Mdot
.44229 .51268 Mdot
.8261 .53367 Mdot
.33279 .7252 Mdot
.18488 .60721 Mdot
.39256 .69913 Mdot
.27065 .47545 Mdot
.80103 .62619 Mdot
.39391 .34576 Mdot
.59346 .8382 Mdot
.39992 .54908 Mdot
.42428 .58942 Mdot
.85536 .52041 Mdot
.54253 .84318 Mdot
.54453 .485 Mdot
.50563 .58978 Mdot
.20647 .51906 Mdot
.47096 .53887 Mdot
.34544 .46408 Mdot
.56499 .52577 Mdot
.23595 .36335 Mdot
.80989 .60884 Mdot
.52404 .83769 Mdot
.83798 .42306 Mdot
.70536 .54722 Mdot
.64305 .69329 Mdot
.38301 .39396 Mdot
.40515 .46604 Mdot
.34963 .4803 Mdot
.83442 .60061 Mdot
.63754 .44413 Mdot
.29175 .29404 Mdot
.5054 .81591 Mdot
.63388 .25937 Mdot
.27233 .34423 Mdot
.30449 .43559 Mdot
.54293 .50589 Mdot
.47509 .35782 Mdot
.57035 .70689 Mdot
.7071 .64165 Mdot
.57365 .26228 Mdot
.38746 .59323 Mdot
.68559 .59107 Mdot
.3844 .42526 Mdot
.6171 .78067 Mdot
.29863 .32477 Mdot
.58376 .27118 Mdot
.45313 .38938 Mdot
.55934 .81874 Mdot
.5098 .82072 Mdot
.28159 .31584 Mdot
.3678 .62194 Mdot
.82579 .54412 Mdot
.35736 .4429 Mdot
.52343 .45118 Mdot
.6255 .46483 Mdot
.66196 .40109 Mdot
.38669 .78293 Mdot
.59483 .33566 Mdot
.69822 .73211 Mdot
.33027 .45619 Mdot
.55986 .29584 Mdot
.69459 .71189 Mdot
.56532 .29 Mdot
.47679 .30924 Mdot
.42992 .41423 Mdot
.26408 .46171 Mdot
.5264 .3621 Mdot
.85045 .51099 Mdot
.40958 .64525 Mdot
.5551 .82388 Mdot
.25984 .53421 Mdot
.32543 .64269 Mdot
.4046 .58322 Mdot
.39343 .58178 Mdot
.77057 .66203 Mdot
.30479 .42751 Mdot
.59157 .63661 Mdot
.43524 .29077 Mdot
.42142 .5626 Mdot
.55194 .25432 Mdot
.66922 .34284 Mdot
.33564 .33101 Mdot
.58465 .66765 Mdot
.58866 .30154 Mdot
.47749 .3544 Mdot
.38403 .61607 Mdot
.64929 .33133 Mdot
.72738 .48491 Mdot
.55228 .54854 Mdot
.65561 .63819 Mdot
.74636 .6182 Mdot
.51214 .41631 Mdot
.55675 .83383 Mdot
.34388 .42006 Mdot
.66032 .64307 Mdot
.34998 .48471 Mdot
.58236 .18867 Mdot
.8433 .58409 Mdot
.73859 .71008 Mdot
.32819 .28241 Mdot
.26319 .3383 Mdot
.22213 .68916 Mdot
.33799 .55794 Mdot
.64436 .78689 Mdot
.25948 .53398 Mdot
.47768 .13863 Mdot
.4112 .64046 Mdot
.60239 .57561 Mdot
.39979 .37756 Mdot
.72153 .48555 Mdot
.84292 .53974 Mdot
.50889 .4345 Mdot
.60458 .6612 Mdot
.40945 .28041 Mdot
.53084 .354 Mdot
.84149 .50524 Mdot
.83462 .47091 Mdot
.83188 .48079 Mdot
.24523 .45948 Mdot
.58979 .32248 Mdot
.85782 .49883 Mdot
.61831 .62391 Mdot
.53593 .37179 Mdot
.63393 .44478 Mdot
.73047 .53002 Mdot
.624 .7995 Mdot
.63339 .67948 Mdot
.47534 .53567 Mdot
.39072 .39234 Mdot
.86234 .52221 Mdot
.74361 .63314 Mdot
.52146 .47099 Mdot
.77151 .64808 Mdot
.62255 .74467 Mdot
.70522 .7036 Mdot
.75842 .67565 Mdot
.46082 .50614 Mdot
.311 .43662 Mdot
.8687 .52148 Mdot
.5452 .80763 Mdot
.33062 .55164 Mdot
.47751 .3589 Mdot
.61645 .81046 Mdot
.26499 .34784 Mdot
.2351 .53598 Mdot
.4067 .38337 Mdot
.6017 .20426 Mdot
.37236 .50835 Mdot
.48714 .50237 Mdot
.54743 .43323 Mdot
.68767 .72534 Mdot
.41603 .64299 Mdot
.59163 .80361 Mdot
.36231 .48123 Mdot
.52447 .37686 Mdot
.67772 .65181 Mdot
.50024 .83564 Mdot
.48195 .46169 Mdot
.63436 .30861 Mdot
.3449 .42119 Mdot
.30462 .30937 Mdot
.2811 .33555 Mdot
.5788 .22447 Mdot
.61976 .3854 Mdot
.83784 .56821 Mdot
.67243 .78813 Mdot
.76203 .67685 Mdot
.28963 .31599 Mdot
.20587 .64993 Mdot
.25642 .51124 Mdot
.62747 .62977 Mdot
.73289 .46556 Mdot
.44876 .48087 Mdot
.70861 .45671 Mdot
.32881 .52338 Mdot
.54124 .1944 Mdot
.40358 .57913 Mdot
.61888 .62317 Mdot
.34519 .29676 Mdot
.42766 .57959 Mdot
.62524 .31276 Mdot
.45719 .38434 Mdot
.26788 .30888 Mdot
.56283 .81739 Mdot
.41035 .64848 Mdot
.35583 .63267 Mdot
.57501 .34683 Mdot
.51943 .61798 Mdot
.58889 .61639 Mdot
.52619 .44987 Mdot
.5488 .22909 Mdot
.21976 .66916 Mdot
.72841 .70229 Mdot
.61268 .8201 Mdot
.75655 .67889 Mdot
.52467 .82348 Mdot
.3433 .59856 Mdot
.66683 .63519 Mdot
.2751 .5538 Mdot
.24701 .51582 Mdot
.65811 .62178 Mdot
.50439 .82952 Mdot
.52357 .46461 Mdot
.42373 .28827 Mdot
.62523 .39165 Mdot
.73652 .63131 Mdot
.67029 .70745 Mdot
.64404 .62371 Mdot
.59313 .2322 Mdot
.39735 .31798 Mdot
.63566 .65624 Mdot
.50743 .49551 Mdot
.70659 .36806 Mdot
.26523 .33309 Mdot
.32364 .51323 Mdot
.46379 .37647 Mdot
.49966 .8367 Mdot
.22334 .68333 Mdot
.4416 .56184 Mdot
.63726 .35417 Mdot
.81253 .59856 Mdot
.54873 .39636 Mdot
.25238 .35153 Mdot
.61725 .21106 Mdot
.33675 .57567 Mdot
.39481 .38976 Mdot
.52085 .39248 Mdot
.418 .59268 Mdot
.32662 .30267 Mdot
.45103 .3823 Mdot
.67091 .39463 Mdot
.80165 .63545 Mdot
.58574 .37718 Mdot
.47131 .51223 Mdot
.70169 .57494 Mdot
.3902 .47649 Mdot
.40826 .55308 Mdot
.68046 .65999 Mdot
.44376 .53793 Mdot
.82462 .48525 Mdot
.53428 .19678 Mdot
.48603 .53024 Mdot
.61541 .63227 Mdot
.61801 .61891 Mdot
.55889 .20857 Mdot
.438 .28136 Mdot
.33522 .46383 Mdot
.61749 .3722 Mdot
.79495 .65069 Mdot
.47028 .42272 Mdot
.67038 .64777 Mdot
.37244 .43568 Mdot
.62342 .3768 Mdot
.56435 .6254 Mdot
.76253 .67026 Mdot
.50886 .47038 Mdot
.84273 .36632 Mdot
.47676 .82081 Mdot
.33511 .35914 Mdot
.46893 .31224 Mdot
.57174 .82332 Mdot
.32912 .38255 Mdot
.4038 .53225 Mdot
.36334 .46997 Mdot
.60436 .81207 Mdot
.50184 .46055 Mdot
.51086 .48058 Mdot
.25685 .32393 Mdot
.85294 .48702 Mdot
.47035 .53002 Mdot
.23149 .52854 Mdot
.63969 .7 Mdot
.57044 .43611 Mdot
.35931 .41902 Mdot
.20166 .39173 Mdot
.40251 .43979 Mdot
.45587 .54985 Mdot
.66548 .79654 Mdot
.51433 .43235 Mdot
.34292 .42284 Mdot
.84439 .36996 Mdot
.84758 .35877 Mdot
.35327 .41145 Mdot
.8282 .61146 Mdot
.51439 .4776 Mdot
.25332 .35443 Mdot
.24642 .49327 Mdot
.66012 .36475 Mdot
.54455 .24737 Mdot
.77432 .67518 Mdot
.19874 .65574 Mdot
.34523 .46867 Mdot
.37822 .37414 Mdot
.77217 .682 Mdot
.50588 .39179 Mdot
.60193 .61987 Mdot
.18632 .60757 Mdot
.42617 .82059 Mdot
.56855 .83745 Mdot
.5975 .22458 Mdot
.38528 .78709 Mdot
.44877 .80067 Mdot
.36081 .52427 Mdot
.62161 .81098 Mdot
.58114 .59758 Mdot
.59254 .19171 Mdot
.55716 .81919 Mdot
.24751 .34143 Mdot
.34237 .7529 Mdot
.41147 .55045 Mdot
.52195 .43683 Mdot
.44646 .41125 Mdot
.23429 .36827 Mdot
.28868 .43755 Mdot
.54448 .37977 Mdot
.6439 .59154 Mdot
.47786 .31363 Mdot
.30866 .28113 Mdot
.63437 .21444 Mdot
.53173 .45547 Mdot
.82401 .4412 Mdot
.29966 .44788 Mdot
.6301 .60149 Mdot
.45472 .30009 Mdot
.67312 .68041 Mdot
.59676 .63492 Mdot
.57072 .46221 Mdot
.80526 .62947 Mdot
.59279 .63434 Mdot
.82701 .4549 Mdot
.59032 .8425 Mdot
.77779 .63651 Mdot
.44745 .60176 Mdot
.59145 .57322 Mdot
.62334 .79604 Mdot
.63169 .78895 Mdot
.83011 .43478 Mdot
.49609 .80963 Mdot
.6559 .61779 Mdot
.53151 .39778 Mdot
.66783 .35126 Mdot
.62266 .32079 Mdot
.57634 .82148 Mdot
.55519 .20276 Mdot
.6962 .70526 Mdot
.32714 .2886 Mdot
.50373 .83239 Mdot
.55168 .48792 Mdot
.67181 .67388 Mdot
.38711 .44622 Mdot
.5085 .58858 Mdot
.34748 .67743 Mdot
.86398 .4625 Mdot
.27647 .32169 Mdot
.71763 .70068 Mdot
.28748 .29945 Mdot
.48202 .37391 Mdot
.46387 .81188 Mdot
.41424 .27928 Mdot
.47491 .58991 Mdot
.33979 .6189 Mdot
.64722 .75416 Mdot
.53399 .475 Mdot
.23333 .34791 Mdot
.61472 .2583 Mdot
.77536 .66059 Mdot
.6958 .71286 Mdot
.83549 .40836 Mdot
.63709 .66428 Mdot
.58712 .3007 Mdot
.82269 .46601 Mdot
.31666 .29386 Mdot
.63521 .61665 Mdot
.84534 .49967 Mdot
.37743 .29021 Mdot
.81691 .61994 Mdot
.29125 .49148 Mdot
.60708 .63175 Mdot
.21897 .37283 Mdot
.63054 .62242 Mdot
.62765 .61801 Mdot
.71918 .71172 Mdot
.32222 .42372 Mdot
.33779 .41501 Mdot
.356 .44326 Mdot
.32 .66521 Mdot
.65925 .35973 Mdot
.45859 .51748 Mdot
.8389 .42681 Mdot
.61665 .3864 Mdot
.53608 .79578 Mdot
.55538 .8283 Mdot
.27016 .55224 Mdot
.52631 .42704 Mdot
.22966 .35911 Mdot
.61598 .22436 Mdot
.71855 .64709 Mdot
.85244 .49364 Mdot
.52681 .42483 Mdot
.72397 .4721 Mdot
.66687 .2495 Mdot
.21472 .50878 Mdot
.3401 .46752 Mdot
.43757 .52512 Mdot
.5594 .37942 Mdot
.69289 .58356 Mdot
.53145 .81884 Mdot
.65658 .79931 Mdot
.82523 .43656 Mdot
.34251 .47542 Mdot
.63864 .62561 Mdot
.42842 .40928 Mdot
.66369 .73264 Mdot
.84072 .41665 Mdot
.36862 .78649 Mdot
.47621 .35692 Mdot
.51395 .83192 Mdot
.32336 .43237 Mdot
.60351 .62048 Mdot
.64986 .62305 Mdot
.82605 .47605 Mdot
.35955 .35231 Mdot
.49873 .41448 Mdot
.39202 .42932 Mdot
.66618 .58869 Mdot
.39027 .55995 Mdot
.59319 .20461 Mdot
.29583 .4275 Mdot
.835 .40708 Mdot
.4303 .79915 Mdot
.64666 .25743 Mdot
.8392 .38885 Mdot
.38982 .31776 Mdot
.3863 .56039 Mdot
.18294 .58396 Mdot
.65411 .64081 Mdot
.40397 .68389 Mdot
.63341 .40114 Mdot
.65151 .60679 Mdot
.32627 .34778 Mdot
.63639 .67333 Mdot
.57975 .66291 Mdot
.46245 .37394 Mdot
.46358 .80693 Mdot
.46182 .38075 Mdot
.65752 .79592 Mdot
.46015 .50175 Mdot
.4789 .32299 Mdot
.64506 .22641 Mdot
.3481 .59784 Mdot
.30879 .30331 Mdot
.78495 .63618 Mdot
.72707 .53428 Mdot
.45075 .3744 Mdot
.44129 .37901 Mdot
.35523 .29625 Mdot
.31168 .5638 Mdot
.82256 .58387 Mdot
.54456 .84019 Mdot
.34002 .64827 Mdot
.36278 .29678 Mdot
.53822 .42155 Mdot
.52338 .44583 Mdot
.73734 .68144 Mdot
.39141 .62974 Mdot
.8532 .56889 Mdot
.56656 .18515 Mdot
.31633 .32795 Mdot
.45666 .47016 Mdot
.73833 .47727 Mdot
.61807 .58606 Mdot
.36875 .59424 Mdot
.53535 .46896 Mdot
.33852 .39108 Mdot
.36271 .32133 Mdot
.39356 .57137 Mdot
.59941 .66664 Mdot
.36976 .61929 Mdot
.30885 .55291 Mdot
.57307 .22122 Mdot
.56912 .82912 Mdot
.4385 .39638 Mdot
.59113 .61914 Mdot
.39192 .60147 Mdot
.62528 .32744 Mdot
.73495 .50494 Mdot
.86974 .48644 Mdot
.79793 .61476 Mdot
.45277 .34885 Mdot
.30334 .32144 Mdot
.33445 .73428 Mdot
.72779 .70131 Mdot
.49639 .42812 Mdot
.57293 .81861 Mdot
.58738 .28413 Mdot
.75177 .67422 Mdot
.46575 .3046 Mdot
.43687 .5065 Mdot
.53708 .83052 Mdot
.60927 .74434 Mdot
.51091 .83641 Mdot
.62233 .23246 Mdot
.60579 .35801 Mdot
.44386 .82473 Mdot
.39693 .43561 Mdot
.52942 .48027 Mdot
.71212 .35686 Mdot
.44715 .48566 Mdot
.60717 .80724 Mdot
.37751 .31667 Mdot
.61863 .6536 Mdot
.35194 .27465 Mdot
.34424 .46694 Mdot
.80718 .61139 Mdot
.28932 .32322 Mdot
.5383 .83921 Mdot
.65816 .35477 Mdot
.63619 .74901 Mdot
.55307 .2092 Mdot
.71514 .54124 Mdot
.53629 .60216 Mdot
.57529 .27266 Mdot
.547 .61596 Mdot
.73107 .64534 Mdot
.63332 .32109 Mdot
.84521 .54828 Mdot
.7424 .62288 Mdot
.44749 .41159 Mdot
.52674 .61844 Mdot
.36502 .35245 Mdot
.85467 .55124 Mdot
.72089 .64108 Mdot
.22994 .36871 Mdot
.56873 .83625 Mdot
.49834 .80618 Mdot
.83991 .38407 Mdot
.32187 .42692 Mdot
.51954 .37299 Mdot
.62651 .8089 Mdot
.48055 .41676 Mdot
.45304 .80103 Mdot
.53378 .47461 Mdot
.38874 .39783 Mdot
.85278 .51223 Mdot
.56882 .63353 Mdot
.42648 .41849 Mdot
.69509 .31308 Mdot
.39048 .38843 Mdot
.72089 .6316 Mdot
.53895 .4577 Mdot
.40011 .66259 Mdot
.7303 .47752 Mdot
.37949 .77951 Mdot
.35192 .30143 Mdot
.56514 .82642 Mdot
.58059 .81332 Mdot
.64253 .71063 Mdot
.44537 .61308 Mdot
.83833 .38232 Mdot
.57605 .32307 Mdot
.57301 .47618 Mdot
.45579 .38255 Mdot
.57657 .66557 Mdot
.52062 .81076 Mdot
.6303 .37684 Mdot
.71882 .50313 Mdot
.58612 .27949 Mdot
.78423 .66126 Mdot
.39855 .45963 Mdot
.28936 .45454 Mdot
.37123 .29169 Mdot
.23334 .3662 Mdot
.33627 .27609 Mdot
.31335 .41282 Mdot
.60705 .80522 Mdot
.44198 .56097 Mdot
.4336 .51837 Mdot
.47256 .39861 Mdot
.58998 .79804 Mdot
.35067 .50681 Mdot
.31693 .53577 Mdot
.54857 .23388 Mdot
.82878 .4233 Mdot
.4749 .36308 Mdot
.41794 .54996 Mdot
.48578 .48625 Mdot
.57906 .3696 Mdot
.34691 .4682 Mdot
.33542 .42162 Mdot
.43311 .38814 Mdot
.83077 .50777 Mdot
.48638 .51427 Mdot
.59196 .58432 Mdot
.49564 .82313 Mdot
.47354 .49244 Mdot
.58224 .8158 Mdot
.52917 .35299 Mdot
.83293 .48802 Mdot
.66863 .64904 Mdot
.62083 .74269 Mdot
.6315 .3897 Mdot
.34271 .28291 Mdot
.76206 .67182 Mdot
.49421 .42864 Mdot
.45463 .57113 Mdot
.40861 .27426 Mdot
.58622 .83956 Mdot
.52147 .55211 Mdot
.21763 .66532 Mdot
.5084 .59543 Mdot
.72635 .49103 Mdot
.72372 .47956 Mdot
.2983 .56387 Mdot
.52276 .45177 Mdot
.36709 .52868 Mdot
.57432 .36796 Mdot
.55429 .22813 Mdot
.68461 .74595 Mdot
.85964 .4567 Mdot
.34633 .36099 Mdot
.55658 .84691 Mdot
.34091 .33612 Mdot
.36326 .38799 Mdot
.43367 .79868 Mdot
.4597 .5794 Mdot
.58424 .33907 Mdot
.63781 .69005 Mdot
.38855 .31447 Mdot
.85313 .44834 Mdot
.45285 .55263 Mdot
.62435 .65958 Mdot
.32631 .71714 Mdot
.409 .55846 Mdot
.19954 .52704 Mdot
.25326 .52379 Mdot
.59827 .83389 Mdot
.55822 .82056 Mdot
.27067 .45854 Mdot
.51341 .47656 Mdot
.45691 .56285 Mdot
.84024 .50546 Mdot
.51913 .61114 Mdot
.79562 .62697 Mdot
.25059 .45532 Mdot
.56953 .23313 Mdot
.74053 .62033 Mdot
.70951 .64149 Mdot
.71878 .54343 Mdot
.58802 .25625 Mdot
.81969 .5419 Mdot
.56209 .56222 Mdot
.35779 .6275 Mdot
.34509 .75596 Mdot
.84083 .42383 Mdot
.31721 .31319 Mdot
.57465 .59123 Mdot
.67257 .72367 Mdot
.48641 .5116 Mdot
.62949 .59737 Mdot
.35761 .45373 Mdot
.58967 .61253 Mdot
.22422 .4872 Mdot
.30127 .2943 Mdot
.79435 .64994 Mdot
.63654 .39585 Mdot
.69926 .45771 Mdot
.35293 .5319 Mdot
.41576 .66623 Mdot
.36711 .27069 Mdot
.86743 .48288 Mdot
.32186 .53075 Mdot
.18448 .57669 Mdot
.29294 .56056 Mdot
.72401 .69785 Mdot
.20637 .65831 Mdot
.31628 .56546 Mdot
.65286 .80144 Mdot
.32305 .34466 Mdot
.61928 .24498 Mdot
.29115 .2911 Mdot
.73422 .64217 Mdot
.57204 .27048 Mdot
.56314 .52378 Mdot
.82316 .60411 Mdot
.62156 .59633 Mdot
.61234 .64564 Mdot
.82343 .52683 Mdot
.52987 .83213 Mdot
.48363 .82248 Mdot
.33382 .55869 Mdot
.38251 .37816 Mdot
.23037 .69229 Mdot
.32744 .64521 Mdot
.54532 .17005 Mdot
.79777 .6121 Mdot
.69403 .29688 Mdot
.49463 .42447 Mdot
.35948 .43977 Mdot
.84309 .5165 Mdot
.59897 .80394 Mdot
.53059 .48689 Mdot
.41 .61642 Mdot
.69945 .65092 Mdot
.66169 .72823 Mdot
.34186 .43307 Mdot
.76023 .65553 Mdot
.36595 .595 Mdot
.56227 .63201 Mdot
.54422 .83221 Mdot
.34436 .28227 Mdot
.70638 .54211 Mdot
.82964 .42614 Mdot
.7307 .51552 Mdot
.48531 .83191 Mdot
.24504 .45935 Mdot
.33489 .73951 Mdot
.83986 .43227 Mdot
.32888 .31352 Mdot
.6089 .28115 Mdot
.84147 .36748 Mdot
.84044 .58752 Mdot
.45837 .56261 Mdot
.59431 .37766 Mdot
.64273 .80391 Mdot
.40545 .62126 Mdot
.7091 .71362 Mdot
.54285 .19359 Mdot
.46277 .8166 Mdot
.65254 .32427 Mdot
.60506 .37466 Mdot
.60991 .61255 Mdot
.44146 .32964 Mdot
.40028 .38294 Mdot
.32416 .6723 Mdot
.50447 .82869 Mdot
.57389 .2159 Mdot
.53424 .19707 Mdot
.61713 .22986 Mdot
.45408 .35611 Mdot
.81158 .61886 Mdot
.49536 .60844 Mdot
.56078 .20111 Mdot
.83604 .50138 Mdot
.72476 .44972 Mdot
.36201 .51109 Mdot
.54662 .21952 Mdot
.66238 .63555 Mdot
.37591 .77642 Mdot
.84478 .3946 Mdot
.55494 .24177 Mdot
.85627 .56078 Mdot
.73922 .71205 Mdot
.44899 .35828 Mdot
.34782 .31573 Mdot
.61347 .57844 Mdot
.46108 .53347 Mdot
.21407 .50136 Mdot
.32612 .6413 Mdot
.48169 .8063 Mdot
.39879 .61039 Mdot
.62157 .43978 Mdot
.35991 .43076 Mdot
.77783 .65451 Mdot
.60262 .62433 Mdot
.7853 .64713 Mdot
.57832 .24362 Mdot
.6178 .38797 Mdot
.843 .3548 Mdot
.25112 .35554 Mdot
.66486 .33962 Mdot
.54701 .53971 Mdot
.57408 .59675 Mdot
.57515 .46816 Mdot
.32337 .50029 Mdot
.64729 .65027 Mdot
.43697 .81145 Mdot
.82399 .59966 Mdot
.36268 .29894 Mdot
.61855 .59035 Mdot
.27197 .53575 Mdot
.64522 .56103 Mdot
.65233 .32096 Mdot
.323 .53396 Mdot
.40837 .79916 Mdot
.20708 .53552 Mdot
.35119 .4914 Mdot
.39125 .55752 Mdot
.64967 .59732 Mdot
.57166 .58131 Mdot
.42193 .7999 Mdot
.28381 .56079 Mdot
.35505 .52063 Mdot
.53475 .83949 Mdot
.59561 .26307 Mdot
.32225 .43572 Mdot
.34609 .74633 Mdot
.63876 .61813 Mdot
.37268 .43115 Mdot
.47075 .54355 Mdot
.60703 .20791 Mdot
.83264 .53451 Mdot
.34639 .72092 Mdot
.56237 .56156 Mdot
.67358 .25232 Mdot
.8422 .54572 Mdot
.27225 .52422 Mdot
.67056 .78548 Mdot
.46352 .5719 Mdot
.36278 .27375 Mdot
.70817 .30391 Mdot
.5229 .41914 Mdot
.64353 .43347 Mdot
.56388 .3984 Mdot
.69039 .51511 Mdot
.19276 .52636 Mdot
.52577 .43907 Mdot
.40475 .56215 Mdot
.43797 .55202 Mdot
.62553 .64209 Mdot
.64424 .42821 Mdot
.58148 .4434 Mdot
.52291 .55378 Mdot
.68572 .63118 Mdot
.59496 .60295 Mdot
.62475 .64808 Mdot
.30998 .43712 Mdot
.42191 .80113 Mdot
.4792 .82096 Mdot
.58705 .32856 Mdot
.84707 .51464 Mdot
.70919 .35921 Mdot
.7944 .61846 Mdot
.37755 .47005 Mdot
.30816 .43302 Mdot
.7309 .50934 Mdot
.84333 .39592 Mdot
.40732 .41391 Mdot
.50813 .54042 Mdot
.73252 .71517 Mdot
.77093 .65223 Mdot
.30759 .4448 Mdot
.24666 .33688 Mdot
.34811 .76036 Mdot
.61777 .60356 Mdot
.30438 .2899 Mdot
.34332 .64812 Mdot
.73322 .70055 Mdot
.58103 .36023 Mdot
.46036 .57337 Mdot
.58713 .20586 Mdot
.63309 .32929 Mdot
.36082 .64883 Mdot
.61597 .21072 Mdot
.58943 .25572 Mdot
.8184 .54491 Mdot
.5739 .4752 Mdot
.42787 .47634 Mdot
.43071 .40807 Mdot
.83365 .41559 Mdot
.34481 .6867 Mdot
.72385 .47052 Mdot
.5526 .16905 Mdot
.19318 .52434 Mdot
.45352 .79981 Mdot
.82599 .4322 Mdot
.24772 .51624 Mdot
.56731 .37267 Mdot
.18949 .40526 Mdot
.41817 .41144 Mdot
.44925 .38829 Mdot
.30975 .55373 Mdot
.64436 .73869 Mdot
.39758 .422 Mdot
.84904 .38162 Mdot
.74977 .67883 Mdot
.56486 .34431 Mdot
.53612 .16415 Mdot
.5488 .83072 Mdot
.71144 .47418 Mdot
.31238 .42697 Mdot
.80343 .63077 Mdot
.21736 .49336 Mdot
.63105 .80744 Mdot
.47289 .50174 Mdot
.34912 .32359 Mdot
.65952 .72317 Mdot
.28848 .30247 Mdot
.53228 .41225 Mdot
.53295 .18812 Mdot
.26721 .33032 Mdot
.67873 .70854 Mdot
.49773 .45988 Mdot
.34899 .38485 Mdot
.33738 .37539 Mdot
.46362 .47343 Mdot
.4569 .58819 Mdot
.41907 .54953 Mdot
.43913 .51621 Mdot
.35123 .50307 Mdot
.44883 .46796 Mdot
.24542 .36174 Mdot
.24854 .53381 Mdot
.59758 .23609 Mdot
.36053 .7639 Mdot
.63381 .6584 Mdot
.41209 .63682 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo09Sooooo0_l0002_ooooo`007?ooool0
0ol0003oooooooooo`2Gooooo`?o0000[oooool001cooooo00?o0000ooooooooool0Uoooool2o`00
00Cooooo0ol0002Yooooo`007?ooool00ol0003oooooooooo`2Mooooo`Go0000Yoooool001cooooo
00?o0000ooooooooool0Woooool4o`000003ooooool0003o00000:?ooooo000Looooo`;o0000XOoo
ool6o`000:?ooooo000Looooo`03o`000?oooooooooo0:;ooooo1?l0002Sooooo`007?ooool00ol0
003oooooooooo`2Tooooo`;o000000?oooooo`000?l00000X?ooool001cooooo00?o0000oooooooo
ool0Yoooool2o`000:3ooooo000Looooo`03o`000?oooooooooo0:Wooooo0ol0002Mooooo`007?oo
ool00ol0003oooooooooo`2Wooooo`Go00001?ooool2o`0009Oooooo000Looooo`03o`000?oooooo
oooo0:Oooooo0_l00004ooooo`;o000000?oooooo`000?l000000_l0002Eooooo`007?ooool00ol0
003oooooooooo`2Zooooo`Go00000_ooool3o`0009Gooooo000Looooo`03o`000?oooooooooo0:[o
oooo1_l0002Iooooo`007?ooool00ol0003oooooooooo`2[ooooo`Ko00001?ooool2o`0009;ooooo
000Looooo`03o`000?oooooooooo0:gooooo1Ol00003ooooo`;o0000T_ooool001cooooo00?o0000
ooooooooool0[_ooool4o`0000;ooooo0_l000000ooooooo0000o`00002@ooooo`007?ooool00ol0
003oooooooooo`2Yooooo`;o000000?oooooo`000?l000000ol00003ooooo`;o000000?oooooo`00
0?l000000_l0002>ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5
o`0000Kooooo00?o0000ooooooooool0ZOooool6o`0000;ooooo0_l00006ooooo`;o00000_ooool2
o`0008[ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`2Zooooo`Wo00002_ooool2o`0008[ooooo
00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00ol0003oooooooooo`2Zooooo`[o0000UOooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool02oooool00onHV9So8B4Qonk^kP06ooooo`?o0000Z_ooool:o`00017ooooo0_l00022
ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo
00Gooooo00?o0000ooooooooool0/?ooool4o`0000Oooooo1?l000000ooooooo0000o`000003oooo
o`;o0000P_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool03Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo0:gooooo0_l000000ooooooo0000o`000002o`0000Oo
oooo1?l000001?oooooo0000o`000?l00026ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;
ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`2]ooooo`;o000000?o
ooooo`000?l000000_l0000=ooooo`;o000000Coooooo`000?l0003o0000P_ooool00006ooooooo^
k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000oooo
ooooool0[?ooool3o`0001Gooooo0ol00003ooooo`;o0000OOooool001cooooo00?o0000oooooooo
ool0[?ooool3o`0000Sooooo0_l0000Aooooo`;o0000OOooool001cooooo00?o0000ooooooooool0
[Oooool3o`0000Kooooo0ol0002@ooooo`007?ooool00ol0003oooooooooo`2]ooooo`?o00001_oo
ool4o`0000Cooooo0_l00004ooooo`;o0000Poooool001cooooo00?o0000ooooooooool0^?ooool2
o`0000Cooooo0_l00004ooooo`;o00002?ooool2o`0007Wooooo000Looooo`03o`000?oooooooooo
0:cooooo1_l0000Cooooo`;o00001oooool2o`0007Wooooo000Looooo`03o`000?oooooooooo0:co
oooo1_l00003ooooo`;o00001_ooool2o`0000Kooooo0ol00021ooooo`007?ooool00ol0003ooooo
ooooo`2]ooooo`?o00001Oooool2o`0000Kooooo0ol00006ooooo`;o0000POooool001cooooo00?o
0000ooooooooool0[Oooool3o`0000kooooo0_l00002ooooo`;o0000QOooool001cooooo00?o0000
ooooooooool0[Oooool5o`00013ooooo0_l00002ooooo`?o0000P?ooool001cooooo00?o0000oooo
ooooool0[Oooool5o`0000Kooooo0_l00003ooooo`;o00000oooool2o`000003ooooool0003o0000
00Oo0000Noooool001cooooo00?o0000ooooooooool0[Oooool3o`0000Sooooo0_l00003ooooo`;o
00001_ooool@o`0007Cooooo000Looooo`;o0000[_ooool3o`0001gooooo3?l0001`ooooo`007?oo
ool00ol0003oooooooooo`2]ooooo`Go00005?ooool2o`0000Sooooo2Ol0001`ooooo`007?ooool0
0ol0003oooooooooo`2]ooooo`;o000000?oooooo`000?l000002Oooool3o`0000Kooooo1?l00006
ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`00077ooooo000Looooo`03o`000?oooooo
oooo0:oooooo0_l0000:ooooo`?o00001_ooool2o`0000Cooooo0_l00002ooooo`;o00001oooool2
o`00073ooooo000Looooo`03o`000?oooooooooo07Gooooo0_l0000hooooo`?o00001Oooool2o`00
00Gooooo1?l00008ooooo`;o000000?oooooo`000?l000002?ooool3o`0006oooooo000Looooo`03
o`000?oooooooooo06gooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00001Oooool4o`00
033ooooo0_l00005ooooo`;o00001Oooool4o`0000?ooooo0_l000001?oooooo0000o`000?l00002
ooooo`Co00001oooool4o`0006gooooo000Looooo`03o`000?oooooooooo06Wooooo0ol000000ooo
oooo0000o`000002ooooo`;o000000?oooooo`000?l000001_ooool4o`0003Kooooo0_l0000=oooo
o`;o000000?oooooo`000?l000001ol00009ooooo`;o0000KOooool001cooooo00?o0000oooooooo
ool0IOooool7o`000003ooooool0003o000000?ooooo1?l00010ooooo`?o000000?oooooo`000?l0
00002?ooool3o`0000?ooooo1Ol0001jooooo`007?ooool00ol0003oooooooooo`1Sooooo`Ko0000
00?oooooo`000?l000000oooool2o`000003ooooool0003o000000gooooo0_l00006ooooo`;o0000
;?ooool2o`000003ooooool0003o000000Sooooo0ol00006ooooo`;o00000_ooool5o`0000Oooooo
0_l0001Zooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o000000?oooooo`000?l000001Ooo
ool2o`0000?ooooo0_l0000@ooooo`Co00001?ooool2o`0002oooooo0ol0000Dooooo`Go00001ooo
ool3o`0006Wooooo000Looooo`03o`000?oooooooooo063ooooo0ol00004ooooo`;o00000oooool2
o`0001?ooooo1?l00006ooooo`;o0000;_ooool2o`0000Gooooo0_l0000@ooooo`?o00001oooool2
o`0006Wooooo000Looooo`03o`000?oooooooooo067ooooo0_l00004ooooo`;o00000oooool2o`00
013ooooo1ol000000ooooooo0000o`000003ooooo`;o00009Oooool2o`0000Oooooo0_l00002oooo
o`;o000000?oooooo`000?l000004?ooool7o`0006kooooo000Looooo`03o`000?oooooooooo05co
oooo0_l00003ooooo`;o00001?ooool2o`00017ooooo0_l00002ooooo`?o000000?oooooo`000?l0
00001?l00004ooooo`;o00009?ooool2o`0000Oooooo0_l00002ooooo`;o00005?ooool6o`0006ko
oooo000Looooo`03o`000?oooooooooo05_ooooo0ol000000ooooooo0000o`000002o`0000Cooooo
0_l0000<ooooo`Wo00001oooool3o`0000;ooooo1?l00004ooooo`;o00007_ooool4o`0000Wooooo
0_l0000Jooooo`;o0000K?ooool001cooooo00?o0000ooooooooool0Foooool2o`000004ooooool0
003o0000o`0000;ooooo0_l0000@ooooo`co00002Oooool2o`0000Kooooo0_l0000Nooooo`Co0000
4?ooool2o`0001;ooooo1Ol000001?oooooo0000o`000?l0001Vooooo`007?ooool00ol0003ooooo
ooooo`1Kooooo`;o000000?oooooo`000?l000000oooool2o`0000Oooooo0_l00002ooooo`Co0000
0_ooool;o`00017ooooo0_l0000Nooooo`;o00003?ooool2o`0000Cooooo0_l0000Booooo`Wo0000
I_ooool001cooooo0_l0001Kooooo`;o00004?ooool2o`000003ooooool0003o000000_o000000?o
ooooo`000?l000004Oooool3o`0001oooooo0_l00007ooooo`;o00000oooool2o`0001Wooooo1Ol0
00000ooooooo0000o`00001Vooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o00001?ooool2
o`0000Gooooo0_l00003ooooo`;o00001oooool2o`000003ooooool0003o000000Oo00000_ooool2
o`00017ooooo1_l0000Uooooo`;o00000oooool2o`0001Wooooo0ol00003ooooo`?o0000IOooool0
01cooooo00?o0000ooooooooool0E?ooool2o`0000Cooooo0_l00005ooooo`;o00000oooool2o`00
00_ooooo1_l0000Iooooo`Co0000:_ooool2o`0001Wooooo1_l000000ooooooo0000o`00001Uoooo
o`007?ooool00ol0003oooooooooo`1Cooooo`;o00002_ooool2o`00017ooooo1?l0000Qooooo`?o
00009oooool3o`0000Kooooo0_l0000@ooooo`Go0000J?ooool001cooooo00?o0000ooooooooool0
Doooool2o`0000[ooooo0_l00002ooooo`;o00000_ooool2o`0000Wooooo0_l00009ooooo`;o0000
00?oooooo`000?l000004oooool5o`0002Oooooo0ol00003ooooo`;o000000?oooooo`000?l00000
4?ooool4o`0006Wooooo000Looooo`03o`000?oooooooooo05Sooooo1?l00007ooooo`;o00000_oo
ool2o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`?o000000?oooooo`000?l000000ol0
00000ooooooo0000o`000002o`00017ooooo1Ol0000Xooooo`Co000000?oooooo`000?l000005?oo
ool3o`0006Wooooo000Looooo`03o`000?oooooooooo05Sooooo1?l0000Aooooo`Go00001?ooool9
o`0000?ooooo0_l00005ooooo`;o00002_ooool2o`000004ooooool0003o0000o`0002Sooooo1?l0
000Fooooo`?o0000JOooool001cooooo00?o0000ooooooooool0Coooool2o`0000Gooooo0_l00002
ooooo`;o00000oooool2o`0000kooooo1Ol000000ooooooo0000o`000009o`000003ooooool0003o
000000Go000000Coooooo`000?l0003o00003?ooool3o`0001Gooooo0_l00005ooooo`;o00000ooo
ool2o`0000Gooooo1Ol00002ooooo`;o00001?ooool2o`0000_ooooo0ol00005ooooo`;o0000H_oo
ool001cooooo00?o0000ooooooooool0Coooool3o`0000Cooooo0_l00002ooooo`;o000000?ooooo
o`000?l000000_l0000=ooooo`;o000000?oooooo`000?l000006Ol0000<ooooo`;o00005_ooool2
o`0000Gooooo0_l00003ooooo`;o00001Oooool2o`000003ooooool0003o000000;ooooo0_l00004
ooooo`;o00002oooool3o`0000Gooooo0_l0001Rooooo`007?ooool00ol0003oooooooooo`1=oooo
o`;o000000?oooooo`000?l000002_ooool4o`0000?ooooo0ol00008ooooo`;o000000?oooooo`00
0?l000002Ol000000ooooooo0000o`00000=o`0000;ooooo1?l0000Yooooo`;o00002_ooool2o`00
0003ooooool0003o000000Cooooo0_l0000;ooooo`;o0000J_ooool001cooooo00?o0000oooooooo
ool0COooool2o`0000Cooooo0_l00007ooooo`;o00001Oooool3o`0000?ooooo0_l000001?oooooo
0000o`000?ooool@o`000003ooooool0003o0000013o00002?ooool2o`0001;ooooo0_l0000;oooo
o`;o00002_ooool6o`0000;ooooo0_l0000Eooooo`;o0000HOooool001cooooo00?o0000oooooooo
ool0D_ooool3o`0000?ooooo0_l0000?ooooobGo000000?oooooo`000?l000002Oooool2o`0001;o
oooo0_l0000Iooooo`Co00000_ooool2o`0000kooooo0_l00005ooooo`;o0000HOooool001cooooo
00?o0000ooooooooool0B_ooool4o`0000Cooooo0_l00004ooooo`;o00004Oooool4o`0000;ooooo
8?l00006ooooo`;o000000?oooooo`000?l000008Oooool2o`0001gooooo0_l000000ooooooo0000
o`000002ooooo`;o0000I?ooool001cooooo00?o0000ooooooooool0B_ooool5o`0000?ooooo0_l0
000Gooooo`;o00001?oooolOo`000004ooooool0003o0000o`0000?ooooo0_l000000ooooooo0000
o`00000Aooooo`;o00002oooool2o`000003ooooool0003o000000oooooo0_l00004ooooo`;o0000
1_ooool2o`000003ooooool0003o000000Co0000I?ooool001cooooo00?o0000ooooooooool0BOoo
ool3o`000003ooooool0003o000000Kooooo0_l0000>ooooo`;o00002_oooolSo`0000Kooooo0_l0
000Aooooo`;o00001Oooool2o`0000Cooooo0_l0000Booooo`;o00001?ooool4o`0000Cooooo2Ol0
001Tooooo`007?ooool00ol0003oooooooooo`18ooooo`?o00001oooool2o`000003ooooool0003o
000000kooooo0ol00002ooooo`;o00001Oooool2o`000003ooooool0003o000001co000000?ooooo
o`000?l000007oooool2o`000003ooooool0003o000001Cooooo0ol00006ooooo`;o00000oooool:
o`0006Cooooo000Looooo`;o0000BOooool2o`0000Sooooo0_l0000Booooo`;o00000_ooool6o`00
00;ooooo8ol0000Rooooo`;o00002oooool2o`0000Oooooo0_l0000;ooooo`[o0000;?ooool2o`00
03Oooooo000Looooo`03o`000?oooooooooo04Sooooo0_l00004ooooo`;o00006_ooool6o`000003
ooooool0003o0000023o000000Coooooo`000?l0003o00004Oooool3o`0001Wooooo0_l0000?oooo
o`;o00000_ooool=o`0002[ooooo0_l0000gooooo`007?ooool00ol0003oooooooooo`16ooooo`;o
00001_ooool3o`0001Wooooo0_l00005ooooobSo000000?oooooo`000?l000001Oooool2o`0000Go
oooo0ol0000Pooooo`Co00000oooool2o`000003ooooool0003o000000co000000Coooooo`000?l0
003o00009oooool5o`0003Kooooo000Looooo`03o`000?oooooooooo04Kooooo0ol00005ooooo`?o
00006?ooool3o`000003ooooool0003o000000Cooooo2Ol000000ooooooo0000o`00000Go`000004
ooooool0003o0000ooooo`Co00000oooool2o`0001Kooooo0_l00006ooooo`;o00002?ooool4o`00
00?ooooo5Ol0000Wooooo`Go0000=_ooool001cooooo00?o0000ooooooooool0AOooool4o`0000?o
oooo0_l00002ooooo`;o00005oooool3o`000003ooooool0003o000000Cooooo8ol000000ooooooo
0000o`000008o`0000Kooooo0_l0000@ooooo`;o00001_ooool2o`000003ooooool0003o000000co
oooo4ol0000Zooooo`Co0000=_ooool001cooooo00?o0000ooooooooool0AOooool2o`000005oooo
ool0003o0000o`000?ooool01_l0000Hooooo`;o000000?oooooo`000?l000001OoooolPo`0000?o
oooo2_l00006ooooo`;o00005Oooool5o`000003ooooool0003o000000gooooo0_l000000ooooooo
0000o`00000;o`0002_ooooo0_l000000ooooooo0000o`00000fooooo`007?ooool00ol0003ooooo
ooooo`11ooooo`;o00001?ooool4o`0000?ooooo0_l0000Toooooaco00002_ooool3o`0001[ooooo
0_l00004ooooo`Wo00000oooool2o`000003ooooool0003o000000Gooooo4Ol0000Zooooo`;o0000
>Oooool001cooooo00?o0000ooooooooool0@Oooool5o`000004ooooool0003o0000o`0002gooooo
0ol000000ooooooo0000o`00000Bo`0000kooooo0_l0000;ooooo`;o00002oooool3o`0000?ooooo
2_l000001Ooooooo0000o`000?l0003ooooo00;o00001_ooool@o`0002[ooooo1?l0000gooooo`00
7?ooool00ol0003oooooooooo`12ooooo`Co00009?ooool2o`0000_ooooo0ol000000ooooooo0000
o`00000Do`000003ooooool0003o000000Gooooo0_l00002ooooo`;o00001_ooool2o`0000?ooooo
0_l00009ooooo`;o000000?oooooo`000?l000001oooool2o`0000;ooooo0_l000000ooooooo0000
o`000002o`000003ooooool0003o000000;o00000oooool>o`0002cooooo1?l0000gooooo`007?oo
ool00ol0003oooooooooo`10ooooo`Go00001Oooool3o`0001gooooo0_l0000;ooooo`Co000000?o
ooooo`000?l000000_l00003ooooo`;o00000oooool6o`000004ooooool0003o0000ooooo`?o0000
0_ooool4o`0000[ooooo1?l0000<ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000
o`000004o`0000;ooooo3?l00003ooooo`go0000;oooool2o`0003Oooooo000Looooo`03o`000?oo
oooooooo043ooooo1?l00005ooooo`Co00007Oooool2o`000003ooooool0003o000000[ooooo0_l0
00000ooooooo0000o`000002o`0000?ooooo0_l00003ooooo`?o000000?oooooo`000?l000001?oo
ool3o`0000;ooooo0_l0000>ooooo`;o00001?ooool2o`0000?ooooo0_l00006oooooaKo00001?oo
ool=o`0002cooooo0_l000000ooooooo0000o`00000gooooo`007?ooool00ol0003oooooooooo`10
ooooo`?o00001_ooool2o`0001cooooo0_l000001?oooooo0000o`000?ooool3o`0000kooooo1?l0
000:ooooo`;o000000?oooooo`000?l000001Ol000000ooooooo0000o`00000Dooooo`;o00000ooo
ool3o`0000Cooooo3_l000001?oooooo0000o`000?l00005ooooo`;o000000?oooooo`000?l00000
2Ol0000^ooooo`?o000000?oooooo`000?l00000=oooool001cooooo00?o0000ooooooooool0@?oo
ool2o`0002;ooooo1Ol00005ooooo`;o00003_ooool4o`000003ooooool0003o000000[ooooo1ol0
000Looooo`?o00001?ooool:o`0000;ooooo2?l000000ooooooo0000o`00000=o`0002oooooo0ol0
00000ooooooo0000o`00000gooooo`007?ooool00ol0003oooooooooo`0mooooo`Co00001?ooool2
o`0001gooooo1?l00006ooooo`;o00000_ooool2o`0000Oooooo1?l00004ooooo`;o00001?ooool2
o`0000?ooooo1ol0000Mooooo`;o00000_ooool2o`0000;ooooo3_l000000ooooooo0000o`000002
o`000003ooooool0003o000000co0000<Oooool2o`0003[ooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003ooooooooo
o`0looooo`Go00001?ooool2o`0001cooooo1Ol00002ooooo`;o00000_ooool2o`0000;ooooo0_l0
0005ooooo`Ko00002_ooool;o`0000gooooo0_l00002ooooo`;o00002Oooool2o`0000Cooooo0_l0
00000ooooooo0000o`00000Bo`0000Cooooo2_l0000booooo`;o000000?oooooo`000?l00000=ooo
ool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0looooo`Co00008oooool5o`0000;ooooo0_l0000=ooooo`Go0000
0_ooool3o`0000?ooooo2?l000000ooooooo0000o`00000@ooooo`;o00000_ooool2o`0000Oooooo
1?l00003ooooo`;o00000_oooolDo`0000Cooooo1ol0000fooooo`Co0000=oooool00003ooooool@
413ooooo00;ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo00?o0000ooooooooool0??oo
ool2o`0002Kooooo0ol0000:ooooo`;o00001_ooool5o`0000;ooooo0ol000000ooooooo0000o`00
0007o`0000Wooooo0_l0000Aooooo`;o00000oooool2o`0000?ooooo1?l00002oooooaGo00000ooo
ool7o`0003Kooooo0ol0000hooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09
ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0000jooooo`;o00009_ooool5o`0000[ooooo0ol0
0003ooooo`Wo000000Coooooo`000?l0003ooooo0_l0000@ooooo`;o00004Oooool2o`0000Sooooo
6ol00004ooooo`?o000000?oooooo`000?l00000=oooool2o`0003Sooooo00000ooooooo0000oooo
o`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003ooooo
ooooo`0hooooo`Oo00008_ooool5o`0000Sooooo0_l00002ooooo`Co000000?oooooo`000?l00000
1?ooool3o`0000Sooooo1Ol0000Uoooooako00000oooool2o`0003[ooooo0_l0000hooooo`0000?o
oooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o
0000ooooooooool0=oooool9o`00027ooooo1_l00007ooooo`;o00001?ooool2o`0000gooooo0_l0
0002ooooo`Ko00007oooool2o`0000Cooooo8?l0000iooooo`?o0000>oooool00006oooooomgMgOo
V9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo03Oooooo
2Ol0000Qooooo`;o00000_ooool2o`0000Sooooo0_l0000Booooo`?o000000Coooooo`000?l0003o
00000oooool3o`0001Wooooo0_l000000ooooooo0000o`000004ooooob3o0000>Oooool3o`000003
ooooool0003o000003Sooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`00
0?ooool01_ooool00ol0003oooooooooo`0hooooo`Ko00008_ooool4o`0000Kooooo0_l00003oooo
o`;o00004?ooool2o`000003ooooool0003o000000;ooooo0_l00003ooooo`?o00003_ooool2o`00
00Wooooo0_l000000ooooooo0000o`000003oooooaco00000oooool2o`0003Wooooo0_l00002oooo
o`;o0000>?ooool001cooooo00?o0000ooooooooool0>?ooool3o`0002?ooooo1_l00003ooooo`Go
00001Oooool4o`0000;ooooo0ol00007ooooo`;o00001?ooool3o`0000kooooo0_l00004ooooo`;o
00000oooool2o`0000Oooooo0_l00003ooooob3o0000>_ooool6o`0003Sooooo000Looooo`03o`00
0?oooooooooo05kooooo0_l00003ooooo`;o00000_ooool4o`000003ooooool0003o000000?ooooo
2Ol0000=ooooo`;o00003oooool2o`0000Wooooo0_l000000ooooooo0000o`000003ooooo`;o0000
0oooool2o`000003ooooool0003o000001co0000??ooool4o`0003Sooooo000Looooo`03o`000?oo
oooooooo06?ooooo1?l000001Ooooooo0000o`000?l0003ooooo00;o00000oooool2o`000003oooo
ool0003o000000?o00001?ooool2o`0001Kooooo0_l00003ooooo`;o000000?oooooo`000?l00000
1oooool3o`0000;ooooo0_l00002ooooo`?o000000?oooooo`000?l000006Ol000000ooooooo0000
o`00000hooooo`;o000000Coooooo`000?l0003o0000>_ooool001cooooo00?o0000ooooooooool0
G?ooool2o`000004ooooool0003o0000ooooo`Go000000?oooooo`000?l000000_ooool2o`0000_o
oooo0_l00002ooooo`;o00005_ooool2o`0000?ooooo0_l000000ooooooo0000o`000008ooooo`;o
000000?oooooo`000?l000000ooooolMo`0000?ooooo0_l0000hooooo`Oo0000>Oooool001cooooo
00?o0000ooooooooool0G?ooool2o`000004ooooool0003o0000ooooo`;o000000Coooooo`000?l0
003ooooo0ol00006ooooo`;o00001_ooool2o`000003ooooool0003o000001oooooo0_l00008oooo
o`;o000000?oooooo`000?l000001_oooolMo`0003_ooooo0_l000001?oooooo0000o`000?l0000i
ooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o00001Oooool2o`0000?ooooo0_l00002oooo
o`Co00001?ooool2o`0000;ooooo0_l00005ooooo`;o00007oooool2o`0000Cooooo0_l00009oooo
ob?o0000=oooool2o`0000?ooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`1Gooooo`Co
00001?ooool4o`0000;ooooo0_l00004ooooo`;o00002?ooool2o`0000Kooooo0_l0000Sooooo`?o
000000?oooooo`000?l000001_oooolLo`0000;ooooo1Ol0000gooooo`Co000000?oooooo`000?l0
00000_l0000hooooo`007?ooool00ol0003oooooooooo`1Gooooo`;o000000?oooooo`000?l00000
0oooool4o`0000;ooooo0_l0000:ooooo`;o00000_ooool2o`0000Kooooo1?l0000Qooooo`;o0000
0_ooool3o`0000Sooooo6_l000000ooooooo0000o`00000jooooo`Co00000oooool2o`0003Sooooo
000Looooo`03o`000?oooooooooo05Cooooo0_l00004ooooo`;o00000oooool2o`0000Wooooo0_l0
0004ooooo`?o00003?ooool2o`0002Kooooo0_l00002ooooo`;o00001?oooolJo`0003gooooo0_l0
0007ooooo`;o0000=_ooool001cooooo00?o0000ooooooooool0E?ooool2o`0000Gooooo0ol00000
0ooooooo0000o`000004o`0000Gooooo0_l00004ooooo`;o00002?ooool2o`0002[ooooo0_l00003
ooooo`;o00001_oooolEo`0000;ooooo0ol0000kooooo`;o00001oooool2o`0003Kooooo000Loooo
o`03o`000?oooooooooo05[ooooo2ol00006ooooo`;o00003Oooool2o`0002[ooooo0_l00008oooo
o`;o000000?oooooo`000?l000004ol00002ooooo`?o0000A?ooool2o`0003Kooooo000Looooo`;o
0000Foooool2o`0000;ooooo1_l00007ooooo`;o0000>Oooool3o`0000Oooooo0_l000000ooooooo
0000o`00000Fo`0001gooooo0_l0000Wooooo`;o000000?oooooo`000?l00000<oooool001cooooo
00?o0000ooooooooool0C?ooool4o`0000[ooooo0_l00006ooooo`;o00000_ooool2o`0000Sooooo
0_l0000aooooo`;o000000?oooooo`000?l000000ol00003ooooo`Co000000?oooooo`000?l00000
4_l000000ooooooo0000o`000002o`0001cooooo0_l0000Oooooo`;o00002Oooool2o`0003?ooooo
000Looooo`03o`000?oooooooooo04cooooo1?l00004ooooo`;o00000_ooool4o`0000Wooooo1Ol0
0006ooooo`;o0000<Oooool2o`0000Cooooo1?l000000ooooooo0000o`000002o`000003ooooool0
003o0000013o00001?ooool3o`0001?ooooo0_l000000ooooooo0000o`00000Uooooo`;o00000_oo
ool2o`0000Cooooo0_l0000dooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00001?ooool4
o`0000;ooooo0_l0000;ooooo`;o000000?oooooo`000?l000005?ooool2o`0001Wooooo0_l00003
ooooo`?o00002_ooool2o`0000Oooooo4Ol00002ooooo`Co00005?ooool2o`000003ooooool0003o
000002Wooooo0_l00004ooooo`;o000000?oooooo`000?l00000<Oooool001cooooo00?o0000oooo
ooooool0C?ooool2o`0000;ooooo1?l0000Eooooo`;o000000?oooooo`000?l000004?ooool2o`00
01Wooooo0_l00003ooooo`?o00001Oooool2o`0000cooooo1Ol00002ooooo`Oo00001Oooool2o`00
01Cooooo0_l0000fooooo`Co0000<?ooool001cooooo00?o0000ooooooooool0B?ooool2o`0000Co
oooo1?l0000Gooooo`Go00004_ooool2o`0000cooooo0_l0000Booooo`;o00000_ooool2o`0000co
oooo3Ol00006ooooo`;o00005?ooool2o`0000_ooooo0_l0000Kooooo`;o00003?ooool4o`00033o
oooo000Looooo`03o`000?oooooooooo04Sooooo0_l00002ooooo`Co00006oooool4o`0000?ooooo
0_l00003ooooo`;o00001oooool2o`0000cooooo0_l000000ooooooo0000o`00000?ooooo`;o0000
0_ooool2o`0000;ooooo0_l0000;ooooo`Wo00000oooool2o`0001Sooooo0ol00007ooooo`;o0000
00?oooooo`000?l000006oooool3o`000003ooooool0003o000003cooooo000Looooo`03o`000?oo
oooooooo04_ooooo0ol0000Kooooo`Ko00000oooool2o`0000?ooooo0_l0000Hooooo`Co00003Ooo
ool2o`0000;ooooo0_l00002ooooo`;o00002oooool8o`0000Cooooo0_l0000Hooooo`?o00000ooo
ool2o`0000;ooooo0_l0000Oooooo`;o000000?oooooo`000?l00000??ooool001cooooo00?o0000
ooooooooool0B?ooool5o`0000Oooooo1ol0000>ooooo`Oo00002oooool2o`0000[ooooo0_l0000:
ooooo`;o00003_ooool2o`0000Gooooo0_l0000:ooooo`So000000?oooooo`000?l000008_ooool2
o`0000;ooooo0_l00003ooooo`Co00006Oooool2o`0003kooooo000Looooo`03o`000?oooooooooo
04Kooooo1_l00008ooooo`So00004?ooool4o`0000_ooooo0_l0000:ooooo`;o00006_ooool2o`00
00?ooooo1?l0000:ooooo`?o00000_ooool2o`0000;ooooo0_l00002ooooo`;o00008_ooool4o`00
0003ooooool0003o000000;o00006Oooool2o`0003kooooo000Looooo`03o`000?oooooooooo04Ko
oooo0_l00006ooooo`Ko000000?oooooo`000?l000001ol0000@ooooo`;o00000_ooool2o`0001[o
oooo0_l0000Booooo`?o00000oooool2o`0000kooooo0_l00002ooooo`Ko000000Coooooo`000?l0
003o00008Oooool4o`0000;ooooo0ol0000Jooooo`;o00002_ooool2o`00037ooooo000Looooo`03
o`000?oooooooooo04Gooooo0_l00007oooooa;o00003_ooool2o`0000;ooooo0_l0000Iooooo`?o
00002_ooool2o`0000Kooooo1?l00002ooooo`;o00000oooool2o`0000Wooooo0_l00002ooooo`Ko
00000_ooool2o`00027ooooo0ol00003ooooo`;o00006Oooool4o`0000[ooooo0ol0000`ooooo`00
7?ooool00ol0003oooooooooo`15ooooo`?o00002?oooolAo`000003ooooool0003o000000[ooooo
0ol0000Looooo`;o00002oooool2o`0000Sooooo0_l00002ooooo`?o00000_ooool4o`0000cooooo
0_l0000Xooooo`?o00001?ooool2o`0001Sooooo0_l000000ooooooo0000o`000004ooooo`;o0000
1?ooool2o`00033ooooo000Looooo`03o`000?oooooooooo04Gooooo0ol00005oooooaSo00002Ooo
ool3o`0002Gooooo0_l0000Aooooo`;o00001?ooool4o`0003Gooooo0_l00004ooooo`;o00006ooo
ool2o`0000Cooooo0_l00002ooooo`;o0000<_ooool001cooooo00?o0000ooooooooool0@oooool2
o`0000Oooooo6ol00007ooooo`;o00009_ooool2o`0000Wooooo0_l00006ooooo`;o00001_ooool2
o`0003Gooooo0_l00004ooooo`;o00008Oooool2o`0000;ooooo0_l0000booooo`007?ooool00ol0
003oooooooooo`0nooooo`;o00000oooool2o`0000Oooooo6ol0000jooooo`;o00001_ooool2o`00
00Cooooo0_l0000mooooo`;o00008Oooool4o`0003Cooooo000Looooo`;o0000?oooool2o`0000;o
oooo1?l00007ooooo`;o000000?oooooo`000?l000005_l0000Zooooo`;o00000_ooool2o`000003
ooooool0003o000001Cooooo0_l0000mooooo`;o00007?ooool2o`000003ooooool0003o000000;o
oooo0_l0000dooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00000oooool4o`0000Oooooo
0_l000000ooooooo0000o`00000Go`0000Gooooo0_l0000Rooooo`;o00000_ooool2o`000004oooo
ool0003o0000o`0004[ooooo0_l00003ooooo`Co00007Oooool2o`000003ooooool0003o000003So
oooo000Looooo`03o`000?oooooooooo03gooooo0_l00003ooooo`?o00002_oooolJo`0000Gooooo
0_l0000Jooooo`;o00001_ooool2o`0000Kooooo0_l0000Aooooo`;o00001Oooool2o`0002[ooooo
1?l00002ooooo`;o00000oooool4o`0001_ooooo0_l000001?oooooo0000o`000?l0000iooooo`00
7?ooool00ol0003oooooooooo`12ooooo`;o00002ooooolJo`0000Gooooo0_l00002ooooo`;o0000
00?oooooo`000?l000004oooool2o`0000Kooooo0_l0000Iooooo`;o00001Oooool3o`0002Wooooo
1?l00006ooooo`;o00007_ooool2o`000003ooooool0003o000000?o0000=oooool001cooooo00?o
0000ooooooooool0@_ooool2o`0000;ooooo0_l00008oooooaOo00002oooool2o`000003ooooool0
003o000001Gooooo0_l00007ooooo`;o00000oooool2o`0001Wooooo0_l0000Xooooo`?o00000_oo
ool2o`0000Cooooo0_l000000ooooooo0000o`00000Pooooo`Co0000=_ooool001cooooo00?o0000
ooooooooool0?_ooool2o`0000Kooooo0_l00005ooooo`;o000000?oooooo`000?l000005Ol0000T
ooooo`?o00001oooool2o`0000?ooooo0_l00010ooooo`[o00001?ooool2o`000003ooooool0003o
000001oooooo1Ol0000fooooo`007?ooool00ol0003oooooooooo`0nooooo`?o00001Oooool2o`00
00Gooooo0_l00003oooooaGo00008_ooool4o`0000Cooooo0_l00007ooooo`;o0000?oooool4o`00
0003ooooool0003o000000Ko00000_ooool2o`0002;ooooo0ol000000ooooooo0000o`00000eoooo
o`007?ooool00ol0003oooooooooo`0oooooo`;o00001Oooool2o`0000[ooooo6?l00006ooooo`;o
00005oooool2o`0000Kooooo0_l00018ooooo`;o00002?ooool3o`0002[ooooo1_l0000aooooo`00
7?ooool00ol0003oooooooooo`0kooooo`;o000000?oooooo`000?l000001_ooool2o`0000Cooooo
0_l000000ooooooo0000o`000002oooooa7o000000?oooooo`000?l000000ol000000ooooooo0000
o`000003ooooo`?o00005Oooool4o`0002Oooooo0ol00003ooooo`;o0000:Oooool4o`0002cooooo
1?l0000aooooo`007?ooool00ol0003oooooooooo`0kooooo`Go00001_ooool3o`0000?ooooo0_l0
00000ooooooo0000o`000003oooooa?o000000Coooooo`000?l0003ooooo0_l00003ooooo`?o0000
00?oooooo`000?l000001_ooool2o`0000[ooooo1?l0000Jooooo`;o00002oooool3o`0000?ooooo
0_l0000Yooooo`Go00007oooool2o`0000Sooooo0_l0000eooooo`007?ooool00ol0003ooooooooo
o`0mooooo`;o00000_ooool3o`0000;ooooo0ol0000;oooooaCo00001_ooool4o`0000;ooooo0_l0
0006ooooo`;o000000?oooooo`000?l000005?ooool2o`0000?ooooo0_l0000:ooooo`;o00000_oo
ool3o`0000;ooooo0_l00009ooooo`;o0000:?ooool7o`000003ooooool0003o000001[ooooo0_l0
0008ooooo`;o0000=Oooool001cooooo00?o0000ooooooooool0@?ooool4o`0000Wooooo0_l00002
ooooo`;o00000_oooolCo`0000Kooooo0ol0000>ooooo`;o00004Oooool2o`000003ooooool0003o
000000;o000000?oooooo`000?l000002?ooool2o`0000Cooooo1?l000000ooooooo0000o`000005
ooooo`;o00000_ooool4o`0002Kooooo1ol000000ooooooo0000o`00000Kooooo`Co0000??ooool0
01cooooo00?o0000ooooooooool0@?ooool2o`0000Cooooo0_l000000ooooooo0000o`000002oooo
o`;o00000_ooool2o`0000;ooooo4ol00009ooooo`;o00006Oooool2o`0000Cooooo0_l000000ooo
oooo0000o`000002o`0000Wooooo2?l000001?oooooo0000o`000?l00002ooooo`?o00000oooool2
o`0000Cooooo0_l0000Sooooo`Ko000000?oooooo`000?l000000ol0000Iooooo`;o000000?ooooo
o`000?l000000_l00007ooooo`;o0000<oooool001cooooo00?o0000ooooooooool0?_ooool3o`00
00Gooooo0_l000000ooooooo0000o`000007ooooo`;o00000_ooool2o`000004ooooool0003o0000
ooooo`Wo00000_ooool3o`0000Cooooo0_l000000ooooooo0000o`00000Iooooo`;o00001oooool2
o`0000[ooooo0ol000000ooooooo0000o`000003o`0000Cooooo2?l00006ooooo`;o00004oooool2
o`0000kooooo1Ol00004ooooo`?o00006Oooool2o`0000Kooooo0_l00004ooooo`;o0000<oooool0
01cooooo00?o0000ooooooooool0??ooool5o`00017ooooo0_l00006ooooo`Ko000000?oooooo`00
0?l000000_l00002ooooo`?o00001?ooool2o`0001oooooo0_l00004ooooo`;o00002Oooool3o`00
00_ooooo2?l00006ooooo`Co00003?ooool2o`0000?ooooo0_l0000>ooooo`Oo000000Coooooo`00
0?l0003o00006_ooool4o`0000Cooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`0loooo
o`;o00002_ooool2o`00013ooooo1?l000000ooooooo0000o`000007ooooo`;o00001?ooool2o`00
01oooooo0_l00004ooooo`;o00002?ooool5o`0000[ooooo2Ol00007ooooo`;o00003?ooool2o`00
01?ooooo0ol00002ooooo`;o000000?oooooo`000?l000006oooool4o`0000Cooooo0_l0000ioooo
o`007?ooool2o`0004Kooooo1ol000000ooooooo0000o`00000=ooooo`;o000000?oooooo`000?l0
00007Oooool2o`0000;ooooo1?l0000:ooooo`;o00003Oooool5o`0000Kooooo3Ol00007ooooo`?o
00008?ooool4o`0000?ooooo0ol0000Sooooo`?o0000>?ooool001cooooo00?o0000ooooooooool0
??ooool2o`0000Oooooo0ol00002ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`Co
00002Oooool2o`0000Gooooo0_l000001?oooooo0000o`000?l00007ooooo`Co00001Oooool2o`00
0003ooooool0003o000000?o00001Oooool2o`0000;ooooo0ol0000<ooooo`Ko00000_ooool2o`00
0003ooooool0003o000000[o00002_ooool3o`0001oooooo1?l00003ooooo`;o00009Oooool2o`00
0003ooooool0003o000003Gooooo000Looooo`03o`000?oooooooooo03cooooo0_l0000Booooo`So
00002Oooool2o`0000Gooooo1_l00007ooooo`Co00002?ooool2o`0000Sooooo0_l00002ooooo`;o
00003Oooool5o`0000?ooooo3ol000000ooooooo0000o`000007ooooo`?o00007oooool3o`0000;o
oooo0_l0000Xooooo`Co0000=Oooool001cooooo00?o0000ooooooooool0D_ooool2o`0001Gooooo
1?l0000=ooooo`?o00001?ooool2o`0001?ooooo0_l00006ooooo`;o000000?oooooo`000?l00000
5Ol00007ooooo`;o000000?oooooo`000?l000007Oooool3o`0000;ooooo0_l0000Looooo`;o0000
2_ooool2o`0003Oooooo000Looooo`03o`000?oooooooooo05Kooooo1?l000000ooooooo0000o`00
000<ooooo`?o00003_ooool3o`0000?ooooo0ol00002ooooo`;o00001Oooool2o`0000?ooooo0_l0
0003ooooo`;o00002_oooolGo`0000Wooooo0_l000001?oooooo0000o`000?l00004ooooo`Co0000
0_ooool2o`0000gooooo0_l00003ooooo`;o00007?ooool2o`0000cooooo0_l0000eooooo`007?oo
ool00ol0003oooooooooo`0gooooo`;o00007Oooool9o`0000?ooooo0ol00004ooooo`Go00004_oo
ool2o`0000?ooooo0_l00005ooooo`;o00000oooool2o`0000Sooooo0_l00005ooooo`;o000000?o
ooooo`000?l000004_l00008ooooo`;o00000_ooool3o`000004ooooool0003o0000ooooo`Wo0000
3?ooool2o`0000?ooooo0_l0000Zooooo`;o0000=Oooool001cooooo00?o0000ooooooooool0=ooo
ool2o`00023ooooo0_l00002ooooo`Co000000Coooooo`000?l0003o00001Oooool4o`0002gooooo
0_l00005ooooo`;o000000?oooooo`000?l000003ol0000;ooooo`;o00001_ooool2o`0000;ooooo
2_l0000:ooooo`;o000000Coooooo`000?l0003o00009Oooool2o`0000?ooooo0_l0000fooooo`00
7?ooool00ol0003oooooooooo`1Oooooo`;o000000?oooooo`000?l000000oooool2o`000003oooo
ool0003o000000Co00003?ooool2o`0001;ooooo0_l000000ooooooo0000o`000009ooooo`;o0000
1?ooool=o`000003ooooool0003o000000?o00006_ooool6o`000003ooooool0003o000000Oooooo
1_l0000Uooooo`;o00000oooool2o`0003Kooooo000Looooo`03o`000?oooooooooo06Oooooo0_l0
00000ooooooo0000o`000004o`0000cooooo0_l0000?ooooo`;o000000?oooooo`000?l000000ol0
0009ooooo`;o00001?oooolEo`0000?ooooo0_l00002ooooo`;o00004_ooool6o`0000Gooooo0ol0
00001?oooooo0000o`000?l0000Uooooo`;o0000??ooool001cooooo00?o0000ooooooooool0>?oo
ool2o`00033ooooo0_l0000Qooooo`Co000000?oooooo`000?l000001Oooool2o`0000?ooooo0_l0
0004oooooaKo00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000@ooooo`Go00001Ooo
ool3o`000004ooooool0003o0000o`0002Gooooo0_l0000looooo`007?ooool00ol0003ooooooooo
o`0hooooo`;o0000>?ooool2o`000003ooooool0003o000000Gooooo0_l000000ooooooo0000o`00
0006ooooo`;o00001_ooool2o`000003ooooool0003o000000Gooooo0_l00003ooooo`;o00001_oo
oolDo`0000Wooooo0_l00003ooooo`Co00002Oooool<o`0006Sooooo000Looooo`03o`000?oooooo
oooo03Sooooo0_l0000hooooo`;o000000?oooooo`000?l000001Oooool2o`000004ooooool0003o
0000o`0000Gooooo0_l00005ooooo`?o000000?oooooo`000?l000001Oooool2o`0000?ooooo0_l0
0005oooooa?o00001Oooool2o`0000Wooooo1_l00007ooooo`_o00000_ooool2o`0002?ooooo0_l0
0005ooooo`;o0000>Oooool001cooooo00?o0000ooooooooool0>?ooool2o`0004Kooooo0_l0000<
ooooo`Co00003Oooool2o`0000Cooooo2ol00002ooooo`Go000000?oooooo`000?l000000oooool2
o`0000Kooooo0_l00003ooooo`Go00001_ooool4o`000003ooooool0003o000000Co000000Cooooo
o`000?l0003o00008oooool2o`0000Cooooo0ol0000iooooo`007?ooool00ol0003oooooooooo`0g
ooooo`;o0000<?ooool9o`0000Gooooo0ol0000<ooooo`;o00002?ooool3o`0000Cooooo0_l00006
ooooo`Co00000_oooolEo`0000;ooooo0_l00007ooooo`;o00001_ooool2o`0000Kooooo1?l00002
ooooo`Co000000?oooooo`000?l000000_l0000Yooooo`;o0000>_ooool00006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`00
0?oooooooooo03Oooooo0_l0000]oooooa3o000000?oooooo`000?l000000ol00008ooooo`Co0000
2Oooool2o`0000Cooooo1?l00005ooooo`?o00000_oooolEo`0000;ooooo0_l00007ooooo`;o0000
1_ooool2o`0000Kooooo1Ol000000ooooooo0000o`000003ooooo`?o0000I_ooool00006oooooomg
MgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06oooo
o`03o`000?oooooooooo06Gooooo1?l00009ooooo`Co00001?ooool2o`0000?ooooo0_l00003oooo
o`;o00004oooool2o`0000;ooooo0_l00002ooooo`;o00001?oooolCo`0000cooooo0_l000000ooo
oooo0000o`000002ooooo`Co00001?ooool6o`0000Cooooo0ol0001Wooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`1Tooooo`Go00000oooool3o`0000Cooooo0_l0000:ooooo`Go00005Oooool:o`00
00?ooooo5Ol0000;ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Gooooo2ol0000Soooo
o`;o00000_ooool2o`0003oooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wo
oooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000=oooool2o`0002[ooooo1?l00005oooo
o`?o00003Oooool2o`0000?ooooo1?l00009ooooo`;o00002oooool8o`0000?ooooo5Ol00002oooo
o`;o00001_ooool2o`0000;ooooo0_l00005ooooo`;o00001Oooool9o`0002Cooooo0_l00002oooo
o`;o000000Coooooo`000?l0003o0000>oooool00003ooooool0003ooooo00;ooooo00?o0000oooo
ooooool02Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0=oooool2
o`0002[ooooo1?l0000Eooooo`;o00001Oooool2o`0000Wooooo0_l00006ooooo`?o00000oooool7
o`0000?ooooo4Ol00006ooooo`;o00001_ooool2o`0000;ooooo0_l00005ooooo`?o00001?ooool7
o`0002[ooooo0_l000001?oooooo0000o`000?l0000kooooo`0000?ooooooa0@4?ooool00_ooool0
0ol@413oooooooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0=oooool4
o`0002Sooooo1?l000000ooooooo0000o`00000Kooooo`;o00003oooool4o`0000?ooooo1_l00003
oooooa7o000000?oooooo`000?l000002_ooool2o`0000[ooooo0ol00007ooooo`;o00009oooool2
o`0000?ooooo0_l000000ooooooo0000o`00000looooo`0000KoooooogMgMonHV9SooooooiRHV?mg
MgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0=oooool4o`0002Sooooo0ol0
0002ooooo`;o00005?ooool2o`0000Gooooo0ol0000>ooooo`Co00000oooool2o`0000;ooooo2?l0
00000ooooooo0000o`00000>o`0000;ooooo0_l00004ooooo`Go00002Oooool2o`0001gooooo0_l0
000>ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`0003kooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`1Soooo
o`?o00004Oooool3o`0000Cooooo0_l00006ooooo`;o00000_ooool2o`000003ooooool0003o0000
00Oooooo0_l00009ooooo`So00000oooool7o`000003ooooool0003o000000?o00000oooool2o`00
00Cooooo0_l000000ooooooo0000o`00000<ooooo`;o00006_ooool3o`0000gooooo0_l000000ooo
oooo0000o`000005ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0=oooool2o`0002[o
oooo0ol00005ooooo`;o00002_ooool5o`0000Gooooo1_l00003ooooo`;o000000?oooooo`000?l0
00004oooool7o`000003ooooool0003o000000;ooooo1Ol000001?oooooo0000o`000?l00005oooo
o`;o00001oooool2o`000004ooooool0003o0000ooooo`?o00000oooool6o`0001Gooooo0_l00000
1?oooooo0000o`000?l0000<ooooo`?o00000oooool2o`0004?ooooo000Looooo`03o`000?oooooo
oooo03Oooooo0_l0000Zooooo`;o00001_ooool2o`0000Oooooo0_l00003ooooo`?o00001?ooool9
o`0001Wooooo1ol000000ooooooo0000o`000005o`0000;ooooo1?l00005ooooo`;o00000_ooool2
o`0000?ooooo0_l000001?oooooo0000o`000?ooool3o`0000?ooooo1_l0000Eooooo`Go00003Ooo
ool2o`0000Cooooo1?l00011ooooo`007?ooool00ol0003oooooooooo`1Sooooo`?o00003_ooool2
o`0000Wooooo1ol000000ooooooo0000o`00000Mooooo`?o00000oooool2o`0000Gooooo0_l00007
ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool4o`000004ooooool0003o
0000ooooo`?o00004?ooool2o`0000?ooooo0_l0000Fooooo`?o0000@Oooool001cooooo00?o0000
ooooooooool0I?ooool2o`0000[ooooo0_l00005ooooo`?o000000?oooooo`000?l000003?l0000M
ooooo`?o00002oooool2o`0000[ooooo0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o
000000?o00001?ooool3o`0000;ooooo0ol0000;ooooo`;o00000oooool2o`00013ooooo0ol00003
ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0>_ooool2o`0003Cooooo0_l00005oooo
o`Wo00000oooool6o`0002?ooooo0_l000000ooooooo0000o`000003ooooo`;o00004_ooool2o`00
00;ooooo0_l0000;ooooo`Ko00001Oooool2o`0001Wooooo1Ol000000ooooooo0000o`000012oooo
o`007?ooool00ol0003oooooooooo`0jooooo`;o0000:Oooool3o`0000Sooooo1?l000000ooooooo
0000o`00000;o`0000;ooooo1Ol0000Sooooo`Go00000_ooool4o`0000Kooooo0_l00002ooooo`;o
000000?oooooo`000?l000000_ooool2o`0000oooooo1_l00005ooooo`Co00000oooool5o`0000co
oooo0_l00003ooooo`?o000000?oooooo`000?l00000@_ooool001cooooo00?o0000ooooooooool0
IOooool3o`0000Sooooo6Ol0000Uooooo`Wo00001Oooool4o`000004ooooool0003o0000ooooo`;o
00003Oooool4o`0000oooooo0_l00003ooooo`Go00002Oooool5o`0000?ooooo0_l00016ooooo`00
7?ooool00ol0003oooooooooo`1Uooooo`;o00002?ooool2o`000003ooooool0003o000001Co0000
:Oooool3o`0000?ooooo0_l00003ooooo`Co00002Oooool2o`0000Kooooo1_l0000Cooooo`Co0000
2oooool4o`0000Cooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`1Uooooo`?o00001ooo
oolIo`0002[ooooo0ol00002ooooo`Co00003?ooool6o`0000Cooooo1?l0000=ooooo`?o000000Co
ooooo`000?l0003ooooo1?l0001Looooo`007?ooool00ol0003oooooooooo`1Uooooo`Co00001ooo
oolHo`0002[ooooo0ol00003ooooo`?o00000oooool2o`0000?ooooo0_l00002ooooo`;o000000Co
ooooo`000?l0003o00001?ooool4o`0000gooooo0ol000000ooooooo0000o`000005o`0005cooooo
000Looooo`03o`000?oooooooooo06Cooooo1Ol00002ooooo`?o00000_oooolGo`0002cooooo0_l0
0005ooooo`;o00000_ooool3o`0000;ooooo0_l00002ooooo`;o00003?ooool3o`0000kooooo1_l0
000;ooooo`;o00000_ooool2o`0004cooooo000Looooo`;o0000?_ooool4o`0002?ooooo0ol00000
0ooooooo0000o`000004o`000003ooooool0003o0000013o000000?oooooo`000?l000001?l0000a
ooooo`?o00000_ooool3o`0000Kooooo0_l00005ooooo`;o00001Oooool5o`0000Gooooo0_l00005
ooooo`Co00003Oooool2o`0000;ooooo0_l000000ooooooo0000o`000019ooooo`007?ooool00ol0
003oooooooooo`0mooooo`Co00008oooool3o`000003ooooool0003o000000;o00000_oooolJo`00
033ooooo0ol00004ooooo`Co00000_ooool2o`0000Oooooo1?l00006ooooo`;o00001Oooool2o`00
00Cooooo1Ol00009ooooo`;o00000_ooool4o`0000?ooooo0_l00019ooooo`007?ooool00ol0003o
ooooooooo`0mooooo`Co00008oooool2o`0000Kooooo7?l0000`ooooo`;o00001oooool6o`0000?o
oooo0ol000000ooooooo0000o`000002o`0001;ooooo1?l0000;ooooo`;o00001?ooool2o`0004ko
oooo000Looooo`03o`000?oooooooooo03oooooo0_l0000[oooooa_o0000<Oooool2o`000003oooo
ool0003o000000So00000_ooool2o`000004ooooool0003o0000o`0000;ooooo1Ol00005ooooo`;o
00001_ooool2o`000003ooooool0003o0000013ooooo1?l000000ooooooo0000o`00001<ooooo`00
7?ooool00ol0003oooooooooo`1Sooooo`?o00002?oooolIo`00037ooooo3?l00003ooooo`;o0000
0_ooool2o`0000?ooooo1Ol00004ooooo`;o00000oooool9o`0000oooooo1?l000000ooooooo0000
o`00001<ooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00007_ooool3o`0000Cooooo0ol0
00000ooooooo0000o`00000Go`00033ooooo3ol00005ooooo`;o00001Oooool7o`000003ooooool0
003o000000;ooooo1_l000000ooooooo0000o`00001Rooooo`007?ooool00ol0003oooooooooo`13
ooooo`?o00007Oooool3o`0000?ooooo1?l000000ooooooo0000o`00000Go`0002gooooo0_l00000
0ooooooo0000o`00000>o`0000_ooooo2_l000000ooooooo0000o`000005o`00013ooooo0_l0001C
ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00007Oooool5o`000004ooooool0003o0000
oooooa[o0000;_oooolCo`0000Cooooo0_l00008ooooo`co000000?oooooo`000?l000003?ooool2
o`0000;ooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`1Sooooo`;o000000?oooooo`00
0?l000000_oooolKo`00033ooooo4_l00004ooooo`;o00002?ooool<o`0000oooooo0_l000001?oo
oooo0000o`000?l00002ooooo`;o0000Coooool001cooooo00?o0000ooooooooool0Aoooool2o`00
01[ooooo0_l00005oooooa_o0000;ooooolDo`0000;ooooo0_l0000;ooooo`So00004Oooool6o`00
00;ooooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`15ooooo`Co00008OoooolFo`0000;o
oooo0_l0000`ooooo`Go000000?oooooo`000?l000003?l00002ooooo`;o00002oooool7o`0000ko
oooo0_l00002ooooo`Co00000oooool2o`00053ooooo000Looooo`03o`000?oooooooooo04Gooooo
0_l0000Looooo`;o00001?ooool2o`000003ooooool0003o000001Ko0000<ooooolAo`0000oooooo
0_l000000ooooooo0000o`000002o`0000kooooo0_l00009ooooo`;o0000D?ooool001cooooo00?o
0000ooooooooool0A?ooool2o`0000;ooooo0_l0000Iooooo`;o00001?ooool=o`000003ooooool0
003o000000[o0000<_oooolCo`0001;ooooo0_l0001]ooooo`007?ooool00ol0003oooooooooo`14
ooooo`;o000000?oooooo`000?l000000_l0000Hooooo`;o00001Oooool2o`0000;ooooo2ol00000
0ooooooo0000o`000007o`0003;ooooo4ol00003ooooo`;o0000O?ooool001cooooo00?o0000oooo
ooooool0Aoooool4o`0001Sooooo0_l00008ooooo`co000000?oooooo`000?l000001?l0000foooo
o`Co000000?oooooo`000?l000002ol00003ooooo`Co0000N_ooool001cooooo00?o0000oooooooo
ool0Hoooool2o`0000Gooooo4ol0000ioooooa;o00001Oooool2o`0001Sooooo0_l0001Pooooo`00
7?ooool2o`0006Cooooo0ol00004ooooo`Go00000_ooool?o`0003Kooooo0_l000000ooooooo0000
o`00000=o`0000Cooooo0_l0000Gooooo`Oo0000GOooool001cooooo00?o0000ooooooooool0C?oo
ool2o`0001Kooooo1?l00003ooooo`Go000000?oooooo`000?l000001ol00002ooooo`Co0000>?oo
ool?o`0000Gooooo0_l0000Cooooo`;o00000_ooool2o`0000;ooooo0ol00004ooooo`;o0000Eooo
ool001cooooo00?o0000ooooooooool0C?ooool2o`0001Kooooo1?l00003ooooo`;o000000?ooooo
o`000?l000002_l00003ooooo`;o00001oooool2o`0002gooooo0_l000000ooooooo0000o`000005
o`000003ooooool0003o000000Oo00003Oooool2o`0000Kooooo0_l000000ooooooo0000o`000006
ooooo`;o00001Oooool2o`0005Oooooo000Looooo`03o`000?oooooooooo06Cooooo0_l00009oooo
oa3o00001oooool2o`0002gooooo0_l000000ooooooo0000o`00000;o`000004ooooool0003o0000
o`0000Cooooo0_l00007ooooo`;o000000?oooooo`000?l000000oooool2o`0000cooooo1?l0001I
ooooo`007?ooool00ol0003oooooooooo`1cooooo`[o0000>oooool@o`0000Gooooo0_l0000:oooo
o`;o00000oooool2o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`Co0000FOooool001co
oooo00?o0000ooooooooool0IOooool3o`0000gooooo0_l000000ooooooo0000o`000002o`0003co
oooo0_l000000ooooooo0000o`000006o`000003ooooool0003o000000;o00005_ooool2o`0000?o
oooo0_l000000ooooooo0000o`000002ooooo`Ko0000FOooool001cooooo00?o0000ooooooooool0
IOooool3o`0000Gooooo0_l00019ooooo`?o000000?oooooo`000?l000002_l0000Rooooo`Co0000
Foooool001cooooo00?o0000ooooooooool0IOooool2o`0000Kooooo0ol00018ooooo`go000000?o
ooooo`000?l000002_ooool2o`0000?ooooo0_l0001`ooooo`007?ooool00ol0003oooooooooo`1U
ooooo`;o000000?oooooo`000?l000000oooool3o`0004[ooooo0ol000000ooooooo0000o`000008
o`0000[ooooo0_l00003ooooo`;o00000oooool2o`0006_ooooo000Looooo`03o`000?oooooooooo
06Sooooo0_l0000Eooooo`;o0000>_ooool>o`0000[ooooo0_l00007ooooo`;o00001oooool3o`00
067ooooo000Looooo`03o`000?oooooooooo06Oooooo0_l0000Fooooo`;o0000>_ooool>o`0000[o
oooo0ol00009ooooo`;o00001?ooool3o`00067ooooo000Looooo`03o`000?oooooooooo06Oooooo
1?l00008ooooo`;o0000Boooool2o`0000?ooooo1?l0000;ooooo`;o00002Oooool2o`0006Sooooo
000Looooo`03o`000?oooooooooo06Oooooo1?l00008ooooo`;o00000_ooool2o`0004Gooooo1?l0
000<ooooo`;o0000NOooool001cooooo00?o0000ooooooooool0Ioooool4o`0000cooooo0_l00015
ooooo`;o00003_ooool2o`000003ooooool0003o000000cooooo0_l0001Xooooo`007?ooool00ol0
003oooooooooo`1Xooooo`?o0000E?ooool2o`000003ooooool0003o000000;ooooo0_l00009oooo
o`;o00002?ooool2o`0000;ooooo0_l0001Xooooo`007?ooool00ol0003oooooooooo`1Xooooo`;o
00000oooool2o`00053ooooo0_l000000ooooooo0000o`000002ooooo`;o00004_ooool3o`0006co
oooo000Looooo`;o0000Joooool2o`000003ooooool0003o000005?ooooo0_l00007ooooo`;o0000
1_ooool2o`0000;ooooo0_l000001?oooooo0000o`000?l0001/ooooo`007?ooool00ol0003ooooo
ooooo`1Zooooo`?o0000G_ooool2o`000004ooooool0003o0000o`0000;ooooo1_l0001`ooooo`00
7?ooool00ol0003oooooooooo`1[ooooo`?o0000H?ooool3o`0000Cooooo0_l0001booooo`007?oo
ool00ol0003oooooooooo`1[ooooo`Co0000f_ooool001cooooo00?o0000ooooooooool0Joooool4
o`000=[ooooo000Looooo`03o`000?oooooooooo06gooooo0ol000000ooooooo0000o`00003Foooo
o`007?ooool00ol0003oooooooooo`1]ooooo`?o000000?oooooo`000?l00000e_ooool001cooooo
00?o0000ooooooooool0KOooool2o`000=[ooooo000Looooo`03o`000?oooooooooo073ooooo1?l0
003Eooooo`007?ooool00ol0003oooooooooo`1`ooooo`Co00000_ooool2o`0004_ooooo0_l00024
ooooo`007?ooool00ol0003oooooooooo`1fooooo`Co0000BOooool4o`0000?ooooo0_l0001moooo
o`007?ooool00ol0003oooooooooo`1cooooo`;o00000oooool6o`0004Oooooo0_l00003ooooo`;o
00004?ooool2o`0006_ooooo000Looooo`03o`000?oooooooooo07?ooooo0ol00003ooooo`Go0000
D?ooool2o`0000Kooooo0ol00003ooooo`;o0000Joooool001cooooo00?o0000ooooooooool0M?oo
ool2o`0000?ooooo0_l0001>ooooo`;o00000oooool2o`0000Kooooo0ol00002ooooo`;o0000K?oo
ool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o
8B4Qolc<c006ooooo`03o`000?oooooooooo0;gooooo0_l0000:ooooo`;o00004?ooool2o`0006co
oooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B401_ooool00ol0003oooooooooo`1iooooo`;o0000;oooool2o`0000Cooooo0_l0000;
ooooo`;o00002?ooool2o`0000Wooooo1?l0001cooooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`1i
ooooo`;o00001_ooool2o`0000;ooooo0_l000001?oooooo0000o`000?l00003ooooo`Co00006?oo
ool2o`0000Cooooo1?l00008ooooo`;o00002Oooool2o`0000Kooooo1ol0001cooooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_oo
ool3o`0007cooooo0_l00003ooooo`;o00000_ooool2o`000004ooooool0003o0000o`0000?ooooo
1?l0000Nooooo`Co00002?ooool2o`0000Wooooo0_l00006ooooo`Co0000M_ooool00003ooooool0
003ooooo00;ooooo00?o0000ooooooooool02Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo
00?o0000ooooooooool0O?ooool2o`0000Oooooo0_l00008ooooo`;o00001oooool3o`0000?ooooo
0_l0000Looooo`;o000000?oooooo`000?l000000_l0000:ooooo`;o000000Coooooo`000?l0003o
0000M_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol@413o^[Zj
oooooonj^[[o410@00Kooooo00?o0000ooooooooool0Toooool2o`0000?ooooo0ol00002ooooo`Co
00003?ooool2o`00013ooooo1?l00005ooooo`Co000000?oooooo`000?l00000N_ooool00006oooo
oomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000
ooooooooool0P?ooool3o`0000Oooooo0_l00007ooooo`;o00001oooool5o`0000Cooooo0_l00006
ooooo`;o00004_ooool2o`000003ooooool0003o000000Ko0000OOooool00006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0
P?ooool3o`0000Oooooo0_l00002ooooo`;o00000oooool2o`0000Kooooo0ol00002ooooo`;o0000
0oooool2o`0001;ooooo0_l00006ooooo`;o000000?oooooo`000?l000000_l00021ooooo`007?oo
ool00ol0003oooooooooo`23ooooo`Go00001_ooool2o`0000?ooooo0_l00006ooooo`;o00000ooo
ool2o`0000Oooooo0_l00006ooooo`Co000000Coooooo`000?l0003ooooo0_l0002>ooooo`007?oo
ool00ol0003oooooooooo`23ooooo`Ko000000Coooooo`000?l0003ooooo0_l00004ooooo`;o0000
0_ooool3o`0000Sooooo0_l00005ooooo`?o00001Oooool4o`000004ooooool0003o0000o`0000[o
oooo0ol00023ooooo`007?ooool00ol0003oooooooooo`25ooooo`Co000000?oooooo`000?l00000
0ol00004ooooo`;o00000_ooool4o`0000;ooooo0_l00003ooooo`;o00000oooool2o`000003oooo
ool0003o000000Gooooo0ol00002ooooo`?o00002_ooool3o`0008?ooooo000Looooo`03o`000?oo
oooooooo08cooooo0_l0000;ooooo`;o00000_ooool2o`0000Sooooo0_l00008ooooo`;o000000?o
ooooo`000?l000000_l0002Aooooo`007?ooool00ol0003oooooooooo`2Cooooo`;o00002oooool2
o`0000Wooooo0_l000001?oooooo0000o`000?ooool2o`000004ooooool0003o0000o`0009;ooooo
000Looooo`03o`000?oooooooooo09?ooooo0_l00005ooooo`?o00000oooool2o`000003ooooool0
003o000000?ooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000;ooooo0_l0
0008ooooo`;o0000R?ooool001cooooo00?o0000ooooooooool0V_ooool3o`0000;ooooo1_l00000
0ooooooo0000o`000002o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`0000Sooooo0ol00027
ooooo`007?ooool00ol0003oooooooooo`2Oooooo`Go00000_ooool2o`0000;ooooo1Ol00006oooo
o`;o00001?ooool7o`0008Oooooo000Looooo`03o`000?oooooooooo0:7ooooo1?l00005ooooo`Go
00001Oooool2o`0000Gooooo1?l0002:ooooo`007?ooool00ol0003oooooooooo`2Rooooo`Go0000
00?oooooo`000?l000000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`;o0000
Roooool001cooooo00?o0000ooooooooool0YOooool2o`000003ooooool0003o000000?ooooo1_l0
002Fooooo`007?ooool2o`000:kooooo1?l0002Hooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001;ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood[o
oooo000Dooooo`03o`000?oooooooooo00Gooooo0ol0003ooooood[ooooo000Dooooo`03o`000?oo
oooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0
003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001;ooooo
00?oEEEEofIVI_l00000oooooomDooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00YOooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo01Gooooo1Ol00003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2o`000003oa0@4?oooooooooo08kooooo002Voooo
o`05o`000?ooooooooooooooool000002Oooool6o`0000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4
A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`2?ooooo`00Y_oo
ool01Ol0003ooooooooooooooooo000001Wooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooo
oooooooooooo410@00?ooooo1Ol0002@ooooo`00Y_ooool01Ol0003ooooooooooooooooo000000Wo
oooo1_l0000;ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`04odA4A?oMgMgoooooo`00097ooooo002Vooooo`05o`000?n7QhOoooooojVYZOl000006oooool0
0omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01?oMgMgoEEEEoooo
ool0002Aooooo`00YOooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo01[ooooo00Go
0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00;ooooo00?oMgMgolc<c?l00000
TOooool00<?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01?ooool00oo^k^koA4A4o`00002Aooooo`00`oooool01OnHV9So410@o`000?lQ8B7oc<c<00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03ogMgMol0003ooooo093ooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(210) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.46241 .37252 Mdot
.43053 .33379 Mdot
.32353 .66434 Mdot
.58808 .41923 Mdot
.56985 .67165 Mdot
.3356 .63373 Mdot
.29005 .47144 Mdot
.30295 .4789 Mdot
.38328 .66015 Mdot
.65334 .33315 Mdot
.31434 .50163 Mdot
.5676 .42868 Mdot
.29212 .48398 Mdot
.59786 .43737 Mdot
.63062 .6132 Mdot
.68076 .42425 Mdot
.45875 .33796 Mdot
.5419 .72429 Mdot
.68547 .42356 Mdot
.39606 .64859 Mdot
.52856 .63888 Mdot
.60679 .44694 Mdot
.39465 .31668 Mdot
.60038 .43669 Mdot
.68982 .41155 Mdot
.42003 .32868 Mdot
.4624 .37175 Mdot
.71156 .40346 Mdot
.59653 .40808 Mdot
.31237 .46369 Mdot
.71889 .39328 Mdot
.70659 .68138 Mdot
.51623 .56697 Mdot
.59494 .29602 Mdot
.29887 .4518 Mdot
.31557 .52708 Mdot
.33908 .6617 Mdot
.30379 .45153 Mdot
.29438 .51534 Mdot
.31143 .49201 Mdot
.31197 .48412 Mdot
.41849 .32346 Mdot
.2884 .44488 Mdot
.17407 .53338 Mdot
.60732 .42882 Mdot
.58641 .20818 Mdot
.30546 .65473 Mdot
.569 .43643 Mdot
.39529 .31155 Mdot
.3622 .68056 Mdot
.63242 .69486 Mdot
.30153 .49534 Mdot
.5371 .58082 Mdot
.53214 .14887 Mdot
.29811 .47911 Mdot
.68652 .41678 Mdot
.36243 .6269 Mdot
.6279 .4214 Mdot
.56815 .46418 Mdot
.58109 .264 Mdot
.63155 .41382 Mdot
.57632 .70406 Mdot
.47217 .38703 Mdot
.33135 .68479 Mdot
.37386 .66858 Mdot
.29485 .4449 Mdot
.46931 .34841 Mdot
.27383 .46201 Mdot
.58324 .42156 Mdot
.3942 .63751 Mdot
.6313 .39727 Mdot
.31471 .50099 Mdot
.46474 .36187 Mdot
.60141 .45612 Mdot
.48643 .36726 Mdot
.32729 .507 Mdot
.53888 .67839 Mdot
.40016 .34456 Mdot
.34645 .69202 Mdot
.63362 .57123 Mdot
.60541 .45319 Mdot
.19816 .37672 Mdot
.68162 .63378 Mdot
.43338 .35777 Mdot
.63818 .44958 Mdot
.25628 .31701 Mdot
.6465 .39611 Mdot
.69915 .39852 Mdot
.70716 .40192 Mdot
.58587 .56423 Mdot
.36362 .62384 Mdot
.40217 .3105 Mdot
.61336 .44213 Mdot
.57531 .44101 Mdot
.64835 .32629 Mdot
.63148 .40144 Mdot
.69973 .40498 Mdot
.52008 .60658 Mdot
.29878 .50359 Mdot
.52058 .58988 Mdot
.32871 .55246 Mdot
.52575 .57143 Mdot
.63986 .3969 Mdot
.3427 .6419 Mdot
.47753 .36136 Mdot
.51703 .57279 Mdot
.28219 .45522 Mdot
.61032 .44059 Mdot
.34622 .46836 Mdot
.39596 .31703 Mdot
.71247 .41056 Mdot
.56361 .69109 Mdot
.45787 .59242 Mdot
.46014 .36065 Mdot
.68443 .26946 Mdot
.58623 .42887 Mdot
.62655 .44419 Mdot
.42819 .32984 Mdot
.40382 .63698 Mdot
.21394 .50603 Mdot
.44885 .33498 Mdot
.30384 .50454 Mdot
.45644 .33405 Mdot
.50968 .58435 Mdot
.40022 .64517 Mdot
.55492 .56944 Mdot
.53431 .61514 Mdot
.67858 .69543 Mdot
.60345 .40958 Mdot
.55261 .6193 Mdot
.34084 .64823 Mdot
.44785 .33622 Mdot
.28636 .49017 Mdot
.60495 .47305 Mdot
.42104 .34359 Mdot
.29518 .47038 Mdot
.54471 .71527 Mdot
.55481 .7342 Mdot
.44621 .36113 Mdot
.67461 .26434 Mdot
.27251 .444 Mdot
.26387 .48087 Mdot
.63214 .69236 Mdot
.43703 .35886 Mdot
.56132 .71744 Mdot
.27754 .46339 Mdot
.3604 .77063 Mdot
.70048 .41668 Mdot
.65111 .71418 Mdot
.20072 .37987 Mdot
.63155 .69342 Mdot
.52007 .63154 Mdot
.56269 .70478 Mdot
.2957 .47029 Mdot
.58322 .46333 Mdot
.44184 .35237 Mdot
.42137 .34149 Mdot
.61068 .39879 Mdot
.52187 .56438 Mdot
.59761 .42416 Mdot
.51973 .59509 Mdot
.53967 .61591 Mdot
.61064 .43746 Mdot
.57457 .20069 Mdot
.41547 .34346 Mdot
.63214 .45689 Mdot
.34887 .66375 Mdot
.56773 .56717 Mdot
.28112 .44653 Mdot
.625 .45864 Mdot
.64304 .44882 Mdot
.56788 .42633 Mdot
.26353 .48437 Mdot
.3384 .36359 Mdot
.3308 .69315 Mdot
.3078 .50966 Mdot
.32654 .5524 Mdot
.35769 .65119 Mdot
.56856 .46158 Mdot
.55733 .69079 Mdot
.53891 .59268 Mdot
.58363 .45986 Mdot
.63115 .69645 Mdot
.5741 .46681 Mdot
.47405 .57808 Mdot
.48121 .57528 Mdot
.22765 .3539 Mdot
.34376 .35893 Mdot
.58034 .43422 Mdot
.66197 .4411 Mdot
.64515 .70266 Mdot
.22241 .45769 Mdot
.28221 .48939 Mdot
.38287 .61714 Mdot
.40415 .63089 Mdot
.30786 .5652 Mdot
.66756 .28629 Mdot
.72761 .34857 Mdot
.63786 .43378 Mdot
.5282 .57894 Mdot
.43607 .38651 Mdot
.56424 .70593 Mdot
.45718 .35491 Mdot
.19574 .37952 Mdot
.68594 .54897 Mdot
.73204 .39114 Mdot
.29666 .71174 Mdot
.34891 .68229 Mdot
.52899 .56584 Mdot
.55166 .71134 Mdot
.61743 .41895 Mdot
.40676 .33627 Mdot
.64048 .69797 Mdot
.53157 .55563 Mdot
.82245 .63032 Mdot
.45446 .3381 Mdot
.69914 .57616 Mdot
.29546 .47856 Mdot
.37764 .64112 Mdot
.64705 .39659 Mdot
.59106 .44675 Mdot
.3994 .29897 Mdot
.58086 .4649 Mdot
.72418 .38807 Mdot
.70087 .41342 Mdot
.37369 .67641 Mdot
.33395 .55065 Mdot
.29527 .51227 Mdot
.32128 .71227 Mdot
.45968 .36195 Mdot
.57518 .18443 Mdot
.35645 .63866 Mdot
.48538 .59718 Mdot
.31576 .49238 Mdot
.54844 .72221 Mdot
.35051 .63612 Mdot
.5736 .67415 Mdot
.57007 .46771 Mdot
.36412 .65873 Mdot
.57188 .6939 Mdot
.59497 .38418 Mdot
.51734 .57407 Mdot
.62657 .77252 Mdot
.28423 .46798 Mdot
.41422 .30172 Mdot
.58478 .46149 Mdot
.5348 .58685 Mdot
.53651 .55341 Mdot
.64973 .59328 Mdot
.54849 .60282 Mdot
.53325 .55786 Mdot
.6124 .5911 Mdot
.53978 .71534 Mdot
.3219 .29714 Mdot
.72103 .39468 Mdot
.46125 .34142 Mdot
.57542 .44779 Mdot
.3286 .54083 Mdot
.29322 .46778 Mdot
.62084 .4162 Mdot
.21612 .36022 Mdot
.27681 .46946 Mdot
.62753 .4338 Mdot
.30843 .51493 Mdot
.42494 .34982 Mdot
.69811 .54818 Mdot
.46767 .36185 Mdot
.61402 .4365 Mdot
.31094 .51272 Mdot
.37584 .61562 Mdot
.42031 .33086 Mdot
.60954 .44358 Mdot
.63254 .40855 Mdot
.53103 .5792 Mdot
.69977 .41483 Mdot
.23454 .50151 Mdot
.57922 .41493 Mdot
.31908 .64547 Mdot
.61721 .40168 Mdot
.56526 .73959 Mdot
.45063 .7985 Mdot
.44143 .36133 Mdot
.55076 .59915 Mdot
.3551 .63062 Mdot
.6603 .38339 Mdot
.7075 .56409 Mdot
.60458 .43078 Mdot
.54974 .56809 Mdot
.70215 .60829 Mdot
.27177 .48911 Mdot
.7229 .40041 Mdot
.54767 .53152 Mdot
.35738 .62482 Mdot
.52711 .57275 Mdot
.64609 .42884 Mdot
.39713 .32973 Mdot
.68293 .42055 Mdot
.36694 .65098 Mdot
.44851 .32915 Mdot
.64953 .40375 Mdot
.29277 .53979 Mdot
.56343 .5712 Mdot
.27533 .4957 Mdot
.71608 .39788 Mdot
.56833 .46002 Mdot
.39324 .64159 Mdot
.41621 .32189 Mdot
.30064 .47936 Mdot
.46189 .36359 Mdot
.60136 .64024 Mdot
.69763 .588 Mdot
.47635 .34802 Mdot
.54105 .69665 Mdot
.39389 .81061 Mdot
.30601 .50666 Mdot
.5346 .60138 Mdot
.31758 .6307 Mdot
.39935 .33671 Mdot
.34316 .63697 Mdot
.66224 .26116 Mdot
.36448 .62487 Mdot
.69332 .42535 Mdot
.37906 .61893 Mdot
.72393 .33545 Mdot
.61231 .46509 Mdot
.36441 .67411 Mdot
.51985 .60728 Mdot
.6283 .45192 Mdot
.4194 .34149 Mdot
.72011 .66964 Mdot
.63579 .297 Mdot
.67241 .28837 Mdot
.36435 .62925 Mdot
.65661 .25572 Mdot
.70876 .41057 Mdot
.71415 .39932 Mdot
.44022 .34844 Mdot
.53467 .5999 Mdot
.58314 .71562 Mdot
.58749 .70746 Mdot
.52448 .79806 Mdot
.73659 .55242 Mdot
.69189 .27538 Mdot
.42417 .3425 Mdot
.30453 .61032 Mdot
.48521 .36336 Mdot
.53192 .55605 Mdot
.30312 .4789 Mdot
.33507 .36995 Mdot
.6373 .39147 Mdot
.49043 .58977 Mdot
.71882 .38779 Mdot
.41629 .30374 Mdot
.46618 .33507 Mdot
.30133 .47881 Mdot
.67602 .28812 Mdot
.65725 .33504 Mdot
.60132 .42048 Mdot
.30194 .47038 Mdot
.53428 .55402 Mdot
.67014 .39574 Mdot
.68091 .70297 Mdot
.18607 .627 Mdot
.61129 .43147 Mdot
.38032 .40042 Mdot
.58667 .46127 Mdot
.67132 .69775 Mdot
.61988 .42127 Mdot
.4139 .3243 Mdot
.73124 .40975 Mdot
.65843 .39215 Mdot
.30932 .73865 Mdot
.67858 .5509 Mdot
.565 .67418 Mdot
.59892 .44089 Mdot
.59251 .42767 Mdot
.56326 .7222 Mdot
.40749 .31378 Mdot
.57495 .42857 Mdot
.32931 .29361 Mdot
.6128 .44498 Mdot
.27675 .449 Mdot
.65637 .62116 Mdot
.70419 .68117 Mdot
.70461 .41064 Mdot
.39619 .32805 Mdot
.26574 .48499 Mdot
.30985 .46695 Mdot
.54904 .59632 Mdot
.29233 .46691 Mdot
.59449 .46502 Mdot
.65635 .61993 Mdot
.47072 .34946 Mdot
.52219 .56794 Mdot
.41273 .30794 Mdot
.38322 .60162 Mdot
.28495 .47012 Mdot
.53997 .57153 Mdot
.65052 .28533 Mdot
.27671 .47844 Mdot
.36844 .56545 Mdot
.71726 .40698 Mdot
.5359 .55401 Mdot
.45197 .37122 Mdot
.39322 .63417 Mdot
.54371 .55991 Mdot
.29858 .4786 Mdot
.60582 .42905 Mdot
.68964 .41588 Mdot
.29316 .46651 Mdot
.37997 .29134 Mdot
.72322 .39319 Mdot
.616 .4447 Mdot
.41215 .33454 Mdot
.43648 .32606 Mdot
.62803 .45969 Mdot
.57687 .45635 Mdot
.33641 .62996 Mdot
.55125 .56965 Mdot
.55208 .56943 Mdot
.53987 .61335 Mdot
.3727 .63313 Mdot
.36215 .79094 Mdot
.26478 .4704 Mdot
.70591 .67927 Mdot
.34678 .40571 Mdot
.53894 .5842 Mdot
.33178 .63376 Mdot
.58628 .43897 Mdot
.60819 .39641 Mdot
.3142 .51031 Mdot
.50132 .84585 Mdot
.61543 .39095 Mdot
.46535 .35155 Mdot
.30627 .48057 Mdot
.6151 .47723 Mdot
.31456 .564 Mdot
.57963 .68981 Mdot
.68988 .27233 Mdot
.30578 .48526 Mdot
.4352 .28829 Mdot
.30562 .48677 Mdot
.59299 .4282 Mdot
.64477 .42897 Mdot
.42178 .30433 Mdot
.56192 .67243 Mdot
.59455 .40564 Mdot
.62508 .43141 Mdot
.28997 .64963 Mdot
.48615 .35814 Mdot
.59017 .70183 Mdot
.57715 .41982 Mdot
.51752 .60055 Mdot
.56014 .66923 Mdot
.61532 .45385 Mdot
.61711 .40019 Mdot
.54557 .62536 Mdot
.3208 .49262 Mdot
.54667 .67849 Mdot
.31414 .74616 Mdot
.45823 .34257 Mdot
.22273 .47976 Mdot
.55477 .56095 Mdot
.30737 .50575 Mdot
.70343 .38697 Mdot
.53436 .56732 Mdot
.30496 .4047 Mdot
.85984 .39813 Mdot
.53977 .56069 Mdot
.32776 .63422 Mdot
.64631 .32287 Mdot
.60982 .40116 Mdot
.61706 .44415 Mdot
.58081 .71913 Mdot
.43757 .33236 Mdot
.34369 .36024 Mdot
.3065 .51181 Mdot
.58849 .45261 Mdot
.45467 .36476 Mdot
.2355 .34169 Mdot
.53108 .57372 Mdot
.56521 .68177 Mdot
.54401 .69142 Mdot
.60536 .45899 Mdot
.71619 .58798 Mdot
.41964 .33229 Mdot
.60952 .4433 Mdot
.62032 .45403 Mdot
.3585 .615 Mdot
.43106 .35813 Mdot
.36219 .65823 Mdot
.72884 .39854 Mdot
.7331 .3241 Mdot
.3315 .53878 Mdot
.27872 .46678 Mdot
.55265 .58193 Mdot
.29323 .51158 Mdot
.31025 .66082 Mdot
.55211 .5706 Mdot
.60847 .44345 Mdot
.47082 .34873 Mdot
.61034 .44286 Mdot
.61317 .44425 Mdot
.60903 .4252 Mdot
.69355 .27481 Mdot
.33785 .69349 Mdot
.55924 .68396 Mdot
.56519 .44557 Mdot
.37109 .64415 Mdot
.30453 .57891 Mdot
.65026 .33154 Mdot
.59763 .44563 Mdot
.62705 .44191 Mdot
.42579 .36395 Mdot
.70036 .4178 Mdot
.279 .47788 Mdot
.4188 .30281 Mdot
.65089 .39958 Mdot
.30879 .69275 Mdot
.57268 .43357 Mdot
.47649 .34969 Mdot
.26857 .46338 Mdot
.53516 .36116 Mdot
.54315 .54977 Mdot
.55483 .57821 Mdot
.54126 .55958 Mdot
.54371 .6109 Mdot
.28258 .44684 Mdot
.3271 .63948 Mdot
.32185 .71518 Mdot
.56365 .42086 Mdot
.58005 .46264 Mdot
.64431 .43142 Mdot
.3395 .61627 Mdot
.51517 .60403 Mdot
.65432 .26962 Mdot
.60247 .48233 Mdot
.38269 .64131 Mdot
.52649 .61249 Mdot
.44538 .25991 Mdot
.41176 .30523 Mdot
.32269 .68558 Mdot
.31078 .46512 Mdot
.57414 .69242 Mdot
.57507 .78756 Mdot
.4288 .31647 Mdot
.42066 .38166 Mdot
.34482 .65791 Mdot
.65988 .6049 Mdot
.52873 .14456 Mdot
.33871 .63695 Mdot
.71926 .38961 Mdot
.43491 .3496 Mdot
.51357 .58894 Mdot
.69891 .61272 Mdot
.6626 .61528 Mdot
.38113 .65764 Mdot
.62928 .40803 Mdot
.4125 .61961 Mdot
.34226 .62506 Mdot
.54647 .59235 Mdot
.36522 .63029 Mdot
.27084 .48993 Mdot
.34535 .64784 Mdot
.3977 .28398 Mdot
.59516 .41377 Mdot
.53048 .14781 Mdot
.64521 .64644 Mdot
.58217 .43372 Mdot
.28078 .49536 Mdot
.25394 .51905 Mdot
.61057 .41529 Mdot
.58528 .69415 Mdot
.32703 .63585 Mdot
.3504 .57073 Mdot
.68946 .42218 Mdot
.38137 .62057 Mdot
.39808 .33241 Mdot
.33689 .55505 Mdot
.32834 .55279 Mdot
.5454 .56141 Mdot
.4288 .3528 Mdot
.32852 .50529 Mdot
.30275 .50451 Mdot
.56432 .57678 Mdot
.59806 .46802 Mdot
.4053 .33048 Mdot
.63019 .37828 Mdot
.52836 .52488 Mdot
.6115 .44598 Mdot
.35938 .65751 Mdot
.35916 .68285 Mdot
.63505 .6227 Mdot
.35906 .63822 Mdot
.54682 .59358 Mdot
.41268 .3383 Mdot
.68735 .42338 Mdot
.44385 .33145 Mdot
.5746 .44697 Mdot
.32466 .54482 Mdot
.4046 .30686 Mdot
.48513 .59657 Mdot
.6353 .41746 Mdot
.57722 .20299 Mdot
.56645 .43715 Mdot
.6151 .44562 Mdot
.38919 .65942 Mdot
.56159 .72148 Mdot
.49487 .55416 Mdot
.30968 .56754 Mdot
.57967 .70341 Mdot
.38332 .29456 Mdot
.40347 .63938 Mdot
.55104 .72283 Mdot
.52888 .80031 Mdot
.55238 .59631 Mdot
.54797 .68982 Mdot
.6369 .451 Mdot
.28121 .46432 Mdot
.45448 .32696 Mdot
.62804 .45294 Mdot
.72445 .32452 Mdot
.73387 .39459 Mdot
.53332 .57694 Mdot
.61903 .44521 Mdot
.58895 .42912 Mdot
.4559 .36469 Mdot
.19677 .38271 Mdot
.31779 .66418 Mdot
.52438 .59572 Mdot
.43835 .32409 Mdot
.19904 .37565 Mdot
.3691 .67048 Mdot
.559 .7314 Mdot
.28845 .51225 Mdot
.44981 .297 Mdot
.53462 .58134 Mdot
.28751 .46924 Mdot
.41487 .62666 Mdot
.62595 .68745 Mdot
.67916 .41909 Mdot
.33162 .65366 Mdot
.63134 .69378 Mdot
.72167 .40746 Mdot
.30428 .56863 Mdot
.2251 .45524 Mdot
.39702 .31535 Mdot
.29585 .46738 Mdot
.56427 .67833 Mdot
.46968 .35795 Mdot
.41215 .3078 Mdot
.27509 .46849 Mdot
.6499 .21743 Mdot
.70167 .60644 Mdot
.2906 .51652 Mdot
.6435 .59306 Mdot
.62849 .68902 Mdot
.53219 .58303 Mdot
.55887 .68786 Mdot
.33376 .55059 Mdot
.41887 .32394 Mdot
.3397 .37843 Mdot
.63328 .69722 Mdot
.72032 .40509 Mdot
.57421 .69571 Mdot
.23869 .34167 Mdot
.31228 .43171 Mdot
.28134 .4744 Mdot
.29079 .64488 Mdot
.57694 .70983 Mdot
.62515 .45957 Mdot
.52335 .8505 Mdot
.6133 .4636 Mdot
.27905 .4615 Mdot
.72032 .3878 Mdot
.454 .3501 Mdot
.26619 .47027 Mdot
.73172 .38883 Mdot
.58105 .41394 Mdot
.59042 .42213 Mdot
.34705 .69233 Mdot
.40196 .29927 Mdot
.55597 .55771 Mdot
.581 .43675 Mdot
.62788 .42856 Mdot
.52905 .55331 Mdot
.70005 .68342 Mdot
.44504 .56423 Mdot
.51579 .57036 Mdot
.37504 .65449 Mdot
.52115 .5686 Mdot
.52712 .59671 Mdot
.43735 .36776 Mdot
.30909 .5944 Mdot
.54441 .55436 Mdot
.61476 .43412 Mdot
.61556 .43924 Mdot
.29018 .51402 Mdot
.70157 .60881 Mdot
.66263 .60788 Mdot
.31772 .65149 Mdot
.55246 .53751 Mdot
.64028 .40752 Mdot
.43009 .35493 Mdot
.58581 .67035 Mdot
.54625 .59901 Mdot
.45974 .34245 Mdot
.59646 .41081 Mdot
.35719 .61481 Mdot
.54033 .56245 Mdot
.52268 .55448 Mdot
.56993 .69683 Mdot
.27047 .50013 Mdot
.38981 .33141 Mdot
.33611 .62766 Mdot
.68452 .41096 Mdot
.54425 .53621 Mdot
.3695 .62016 Mdot
.53059 .58312 Mdot
.519 .57572 Mdot
.42535 .34866 Mdot
.42815 .28485 Mdot
.5068 .59183 Mdot
.37242 .63638 Mdot
.16905 .58027 Mdot
.30537 .49634 Mdot
.56652 .45653 Mdot
.27768 .50312 Mdot
.39581 .31816 Mdot
.67792 .69715 Mdot
.5452 .71059 Mdot
.27797 .47441 Mdot
.52912 .55764 Mdot
.40886 .30691 Mdot
.39375 .30271 Mdot
.61038 .43608 Mdot
.60392 .4463 Mdot
.30432 .66378 Mdot
.64962 .7079 Mdot
.31172 .51505 Mdot
.57765 .72061 Mdot
.3206 .66142 Mdot
.6877 .41862 Mdot
.44679 .35494 Mdot
.65651 .76758 Mdot
.56452 .45453 Mdot
.37069 .6414 Mdot
.43019 .33605 Mdot
.58356 .71275 Mdot
.5576 .6834 Mdot
.58006 .45105 Mdot
.51903 .63073 Mdot
.2742 .47477 Mdot
.41734 .33649 Mdot
.38258 .3763 Mdot
.56851 .43447 Mdot
.60062 .44404 Mdot
.71915 .40769 Mdot
.28501 .51395 Mdot
.63283 .45422 Mdot
.56106 .67348 Mdot
.45452 .35944 Mdot
.58328 .45154 Mdot
.57491 .71233 Mdot
.55945 .57718 Mdot
.53663 .56546 Mdot
.37496 .67074 Mdot
.58688 .6993 Mdot
.56908 .71575 Mdot
.58044 .70769 Mdot
.33477 .37015 Mdot
.56639 .47637 Mdot
.49833 .58525 Mdot
.63487 .4086 Mdot
.62704 .68665 Mdot
.67457 .42235 Mdot
.29342 .50198 Mdot
.3923 .64407 Mdot
.60515 .42275 Mdot
.63774 .41056 Mdot
.38993 .32552 Mdot
.68282 .42655 Mdot
.62786 .4593 Mdot
.45424 .35309 Mdot
.3868 .37464 Mdot
.39967 .6263 Mdot
.20189 .37857 Mdot
.5725 .84576 Mdot
.59011 .47344 Mdot
.65766 .609 Mdot
.40608 .31208 Mdot
.28907 .51303 Mdot
.65006 .59568 Mdot
.26457 .49111 Mdot
.43237 .32519 Mdot
.68881 .42828 Mdot
.37489 .29558 Mdot
.5784 .70177 Mdot
.59443 .42804 Mdot
.27172 .47236 Mdot
.59591 .426 Mdot
.26788 .48014 Mdot
.64268 .25095 Mdot
.68951 .62803 Mdot
.5915 .47096 Mdot
.62955 .40121 Mdot
.53335 .64257 Mdot
.60041 .44602 Mdot
.2975 .7165 Mdot
.43474 .34148 Mdot
.56603 .57163 Mdot
.68602 .43009 Mdot
.63621 .29887 Mdot
.6225 .44544 Mdot
.73741 .38477 Mdot
.63234 .43871 Mdot
.48485 .83992 Mdot
.57182 .46795 Mdot
.60134 .46771 Mdot
.28672 .49373 Mdot
.3128 .50029 Mdot
.38953 .31326 Mdot
.52291 .57183 Mdot
.23264 .34806 Mdot
.62604 .43486 Mdot
.33597 .67833 Mdot
.51864 .52503 Mdot
.56815 .71813 Mdot
.46138 .35821 Mdot
.86195 .37719 Mdot
.28622 .44424 Mdot
.3614 .66399 Mdot
.71723 .39216 Mdot
.37013 .65671 Mdot
.32519 .68206 Mdot
.36459 .35687 Mdot
.55968 .68705 Mdot
.57189 .43947 Mdot
.5946 .29127 Mdot
.48733 .38486 Mdot
.56885 .43389 Mdot
.4087 .62361 Mdot
.544 .62549 Mdot
.68525 .50751 Mdot
.53803 .71323 Mdot
.56118 .71107 Mdot
.29525 .47466 Mdot
.33924 .67795 Mdot
.52376 .59386 Mdot
.54914 .7214 Mdot
.39452 .62434 Mdot
.55096 .59705 Mdot
.29852 .62022 Mdot
.41893 .33217 Mdot
.65828 .25721 Mdot
.58666 .20403 Mdot
.27964 .50028 Mdot
.30275 .5762 Mdot
.47171 .34993 Mdot
.46831 .36305 Mdot
.52469 .58294 Mdot
.3846 .64186 Mdot
.44077 .30904 Mdot
.58104 .44808 Mdot
.52104 .56991 Mdot
.5979 .46135 Mdot
.54374 .72465 Mdot
.62109 .43895 Mdot
.38794 .6216 Mdot
.28147 .49253 Mdot
.35657 .62622 Mdot
.2929 .47149 Mdot
.71143 .67598 Mdot
.63397 .42265 Mdot
.60147 .44176 Mdot
.65703 .61951 Mdot
.42007 .35291 Mdot
.59588 .3006 Mdot
.37005 .63681 Mdot
.36028 .62727 Mdot
.68395 .43004 Mdot
.45809 .33463 Mdot
.50592 .57478 Mdot
.63881 .59186 Mdot
.63083 .44138 Mdot
.43576 .34064 Mdot
.66996 .42828 Mdot
.2096 .45385 Mdot
.67685 .6355 Mdot
.41995 .35433 Mdot
.30693 .73758 Mdot
.63535 .44143 Mdot
.52895 .60178 Mdot
.55186 .61682 Mdot
.726 .57739 Mdot
.49631 .55074 Mdot
.45524 .33843 Mdot
.51922 .59051 Mdot
.44403 .35462 Mdot
.35649 .62198 Mdot
.26711 .46259 Mdot
.44417 .34886 Mdot
.63477 .43352 Mdot
.57332 .84472 Mdot
.2692 .4728 Mdot
.59544 .43045 Mdot
.27279 .46197 Mdot
.45641 .32589 Mdot
.44791 .34037 Mdot
.55089 .59702 Mdot
.72317 .38972 Mdot
.27567 .4745 Mdot
.58342 .46457 Mdot
.36879 .39421 Mdot
.68274 .42082 Mdot
.55996 .54265 Mdot
.63719 .40476 Mdot
.60059 .40828 Mdot
.33762 .7728 Mdot
.64633 .37837 Mdot
.32973 .542 Mdot
.26661 .50474 Mdot
.33802 .35994 Mdot
.44519 .3686 Mdot
.549 .73048 Mdot
.38817 .31486 Mdot
.55448 .57251 Mdot
.37508 .65692 Mdot
.60539 .42619 Mdot
.55091 .60287 Mdot
.30798 .52067 Mdot
.54793 .69653 Mdot
.57411 .46679 Mdot
.32953 .66023 Mdot
.52906 .60789 Mdot
.28448 .47153 Mdot
.41895 .32119 Mdot
.45856 .34965 Mdot
.30846 .59827 Mdot
.58302 .44969 Mdot
.60605 .44519 Mdot
.28575 .4504 Mdot
.49118 .60294 Mdot
.58165 .70089 Mdot
.51975 .60726 Mdot
.28021 .45478 Mdot
.67831 .63509 Mdot
.40255 .29806 Mdot
.58707 .43361 Mdot
.6551 .6244 Mdot
.34098 .35712 Mdot
.51767 .32631 Mdot
.56624 .70889 Mdot
.71058 .57021 Mdot
.45447 .3377 Mdot
.28892 .49067 Mdot
.52382 .7999 Mdot
.71602 .41096 Mdot
.60583 .41417 Mdot
.71323 .55981 Mdot
.64024 .59032 Mdot
.70593 .39457 Mdot
.54988 .5542 Mdot
.69222 .60502 Mdot
.6796 .4301 Mdot
.68458 .41332 Mdot
.64381 .40938 Mdot
.63812 .40447 Mdot
.44128 .34077 Mdot
.67699 .29101 Mdot
.34844 .65546 Mdot
.64524 .45738 Mdot
.5404 .66568 Mdot
.71818 .4039 Mdot
.61453 .39655 Mdot
.47947 .27996 Mdot
.73826 .52085 Mdot
.42998 .34406 Mdot
.40467 .33962 Mdot
.28196 .50321 Mdot
.68334 .42311 Mdot
.37129 .63893 Mdot
.53438 .62397 Mdot
.39099 .63844 Mdot
.43909 .33892 Mdot
.4028 .62532 Mdot
.28972 .44179 Mdot
.3316 .65401 Mdot
.38067 .64557 Mdot
.2853 .49599 Mdot
.40698 .29919 Mdot
.56665 .43537 Mdot
.28475 .4961 Mdot
.51594 .56116 Mdot
.55657 .73217 Mdot
.40472 .37855 Mdot
.5134 .58061 Mdot
.60897 .39291 Mdot
.17018 .56001 Mdot
.33761 .66123 Mdot
.70237 .54963 Mdot
.403 .30434 Mdot
.56095 .65968 Mdot
.44656 .34799 Mdot
.50605 .5909 Mdot
.56929 .70559 Mdot
.63873 .44821 Mdot
.61196 .77347 Mdot
.22761 .45455 Mdot
.66661 .39991 Mdot
.38635 .3748 Mdot
.39 .63528 Mdot
.27364 .48992 Mdot
.22592 .50374 Mdot
.52346 .59569 Mdot
.39581 .32877 Mdot
.43051 .28163 Mdot
.55324 .57092 Mdot
.28539 .48974 Mdot
.57317 .21811 Mdot
.58197 .43976 Mdot
.27966 .50356 Mdot
.63483 .4045 Mdot
.67991 .26765 Mdot
.56241 .65104 Mdot
.54105 .61402 Mdot
.69186 .42706 Mdot
.36957 .66982 Mdot
.68597 .42956 Mdot
.71042 .31022 Mdot
.66352 .70751 Mdot
.64036 .41659 Mdot
.70705 .55213 Mdot
.31113 .65365 Mdot
.44339 .35751 Mdot
.54529 .58005 Mdot
.53187 .58078 Mdot
.70045 .42333 Mdot
.66009 .8086 Mdot
.54899 .71425 Mdot
.29408 .70663 Mdot
.63333 .42618 Mdot
.6056 .45258 Mdot
.38664 .31899 Mdot
.64119 .25253 Mdot
.51853 .60374 Mdot
.61997 .41131 Mdot
.73959 .52968 Mdot
.29755 .49147 Mdot
.64697 .40362 Mdot
.60162 .4591 Mdot
.3417 .55416 Mdot
.28778 .49296 Mdot
.35167 .61826 Mdot
.55447 .59084 Mdot
.38029 .66828 Mdot
.56828 .67157 Mdot
.70112 .57384 Mdot
.69065 .69028 Mdot
.67258 .63465 Mdot
.58222 .68674 Mdot
.70538 .41211 Mdot
.58144 .40284 Mdot
.60056 .41309 Mdot
.55773 .71146 Mdot
.31393 .46663 Mdot
.43799 .34271 Mdot
.67054 .26212 Mdot
.52982 .58081 Mdot
.68924 .40759 Mdot
.54673 .6692 Mdot
.44033 .35225 Mdot
.57316 .20059 Mdot
.43806 .33376 Mdot
.28539 .47575 Mdot
.30368 .57052 Mdot
.57271 .70464 Mdot
.44699 .34856 Mdot
.3898 .65733 Mdot
.32074 .54282 Mdot
.57511 .48638 Mdot
.29125 .44204 Mdot
.40423 .28905 Mdot
.41049 .34506 Mdot
.47316 .3709 Mdot
.69574 .42277 Mdot
.70513 .55136 Mdot
.55199 .58475 Mdot
.27185 .46002 Mdot
.3519 .67131 Mdot
.65256 .70726 Mdot
.574 .23685 Mdot
.68173 .61678 Mdot
.64381 .43525 Mdot
.62039 .43848 Mdot
.60966 .45677 Mdot
.53679 .5486 Mdot
.58219 .40116 Mdot
.64098 .41379 Mdot
.31403 .5109 Mdot
.36102 .61826 Mdot
.63102 .4257 Mdot
.541 .56661 Mdot
.49005 .58091 Mdot
.56117 .66057 Mdot
.69561 .27155 Mdot
.40288 .37518 Mdot
.44143 .35033 Mdot
.36663 .64991 Mdot
.40339 .64198 Mdot
.54533 .71786 Mdot
.30266 .47585 Mdot
.43702 .33124 Mdot
.47992 .83701 Mdot
.57868 .69664 Mdot
.61397 .43152 Mdot
.6569 .62073 Mdot
.73619 .5409 Mdot
.60652 .4006 Mdot
.61033 .42441 Mdot
.52802 .56003 Mdot
.37322 .64128 Mdot
.72614 .34233 Mdot
.57465 .20241 Mdot
.57393 .71185 Mdot
.56385 .72837 Mdot
.47216 .36662 Mdot
.58837 .46758 Mdot
.27305 .47126 Mdot
.70395 .60573 Mdot
.24392 .51029 Mdot
.26061 .31514 Mdot
.3902 .61021 Mdot
.57174 .43711 Mdot
.64087 .31429 Mdot
.63565 .39091 Mdot
.47735 .36162 Mdot
.43106 .28861 Mdot
.42637 .34346 Mdot
.30049 .48767 Mdot
.61675 .67179 Mdot
.31223 .47963 Mdot
.52612 .61172 Mdot
.42443 .31053 Mdot
.64989 .38377 Mdot
.36125 .62815 Mdot
.67878 .42434 Mdot
.55818 .69518 Mdot
.57961 .54893 Mdot
.54209 .58308 Mdot
.70743 .57151 Mdot
.33158 .63429 Mdot
.41782 .2988 Mdot
.67796 .42535 Mdot
.31451 .56587 Mdot
.68874 .61285 Mdot
.31965 .62356 Mdot
.55232 .60089 Mdot
.57657 .70376 Mdot
.65128 .33394 Mdot
.57655 .68972 Mdot
.27702 .47269 Mdot
.63411 .4191 Mdot
.59628 .46739 Mdot
.61494 .44794 Mdot
.63256 .45135 Mdot
.29951 .48193 Mdot
.6958 .4049 Mdot
.50891 .57945 Mdot
.54517 .60862 Mdot
.72066 .39568 Mdot
.55359 .68845 Mdot
.30237 .49889 Mdot
.36855 .61898 Mdot
.53727 .55664 Mdot
.54828 .67218 Mdot
.66489 .42217 Mdot
.63479 .41232 Mdot
.5322 .61151 Mdot
.63676 .45071 Mdot
.70058 .40309 Mdot
.33609 .64989 Mdot
.70228 .39812 Mdot
.56019 .66164 Mdot
.56215 .69745 Mdot
.28885 .46467 Mdot
.44697 .34944 Mdot
.54271 .69136 Mdot
.32161 .65511 Mdot
.65485 .40651 Mdot
.63928 .40585 Mdot
.4024 .28338 Mdot
.63208 .69715 Mdot
.56347 .66001 Mdot
.63166 .4556 Mdot
.43856 .3631 Mdot
.4376 .28201 Mdot
.61072 .41298 Mdot
.70802 .40317 Mdot
.44478 .37042 Mdot
.55284 .728 Mdot
.30006 .46819 Mdot
.64931 .65488 Mdot
.26431 .47746 Mdot
.4173 .32046 Mdot
.51974 .58648 Mdot
.40999 .30007 Mdot
.52196 .59469 Mdot
.32501 .26003 Mdot
.64202 .41218 Mdot
.3599 .32073 Mdot
.51364 .60293 Mdot
.36578 .62885 Mdot
.38 .63187 Mdot
.5436 .56407 Mdot
.45056 .33198 Mdot
.54766 .59182 Mdot
.57034 .68287 Mdot
.33953 .36493 Mdot
.43373 .36628 Mdot
.38163 .64438 Mdot
.33597 .66174 Mdot
.27894 .45521 Mdot
.6218 .4419 Mdot
.58661 .4335 Mdot
.33004 .65118 Mdot
.2396 .50625 Mdot
.39945 .3161 Mdot
.60606 .44458 Mdot
.51815 .56462 Mdot
.34233 .65309 Mdot
.25836 .43085 Mdot
.44294 .31462 Mdot
.69398 .42719 Mdot
.66737 .70635 Mdot
.26972 .45734 Mdot
.64422 .39618 Mdot
.70128 .40382 Mdot
.55552 .71837 Mdot
.71313 .56735 Mdot
.63137 .69122 Mdot
.2886 .44361 Mdot
.55435 .57981 Mdot
.6068 .39996 Mdot
.37114 .62741 Mdot
.65738 .41759 Mdot
.84827 .45044 Mdot
.5352 .61393 Mdot
.58539 .45095 Mdot
.54552 .61917 Mdot
.44488 .33227 Mdot
.60812 .44818 Mdot
.32698 .53938 Mdot
.36294 .64872 Mdot
.58351 .44684 Mdot
.52627 .63667 Mdot
.27269 .46291 Mdot
.54214 .58212 Mdot
.57787 .7056 Mdot
.70528 .39349 Mdot
.7192 .6702 Mdot
.33687 .61731 Mdot
.55402 .68298 Mdot
.62404 .44158 Mdot
.32025 .66441 Mdot
.31166 .50248 Mdot
.54709 .57598 Mdot
.66996 .40539 Mdot
.2971 .50473 Mdot
.29573 .49515 Mdot
.57286 .7 Mdot
.56706 .17607 Mdot
.59542 .47298 Mdot
.5925 .43912 Mdot
.56748 .19403 Mdot
.45096 .27994 Mdot
.5965 .42726 Mdot
.61494 .4594 Mdot
.28454 .46782 Mdot
.6141 .67063 Mdot
.70886 .57021 Mdot
.52807 .61956 Mdot
.27626 .49292 Mdot
.40635 .61895 Mdot
.35318 .66284 Mdot
.55311 .68026 Mdot
.42932 .33479 Mdot
.54249 .70919 Mdot
.34967 .6493 Mdot
.61157 .43375 Mdot
.2947 .46122 Mdot
.74442 .36066 Mdot
.26762 .46722 Mdot
.32319 .65394 Mdot
.47586 .35403 Mdot
.72453 .33371 Mdot
.84997 .44185 Mdot
.44025 .56209 Mdot
.3024 .56949 Mdot
.56698 .71883 Mdot
.57422 .20251 Mdot
.63223 .433 Mdot
.70093 .30712 Mdot
.59267 .43238 Mdot
.56725 .74294 Mdot
.39043 .6294 Mdot
.55103 .59685 Mdot
.52423 .59666 Mdot
.70564 .56843 Mdot
.29972 .49342 Mdot
.30667 .45923 Mdot
.51733 .58177 Mdot
.28291 .47858 Mdot
.58723 .448 Mdot
.33708 .63338 Mdot
.35118 .24976 Mdot
.63314 .43827 Mdot
.56229 .55896 Mdot
.27441 .44434 Mdot
.46905 .33444 Mdot
.40661 .6195 Mdot
.63894 .30799 Mdot
.22094 .3608 Mdot
.27566 .47896 Mdot
.69718 .27387 Mdot
.36787 .64489 Mdot
.53648 .55672 Mdot
.32017 .66805 Mdot
.5896 .43886 Mdot
.57153 .43739 Mdot
.53215 .55277 Mdot
.62471 .44639 Mdot
.59224 .32503 Mdot
.72386 .40078 Mdot
.58084 .49755 Mdot
.63139 .40794 Mdot
.36906 .30899 Mdot
.31271 .50528 Mdot
.51809 .58152 Mdot
.60907 .59076 Mdot
.5994 .41005 Mdot
.45131 .37035 Mdot
.29188 .5037 Mdot
.20968 .37958 Mdot
.29912 .48752 Mdot
.36023 .6248 Mdot
.30374 .48089 Mdot
.64012 .39257 Mdot
.42903 .32087 Mdot
.35109 .64025 Mdot
.53816 .58293 Mdot
.36418 .66735 Mdot
.58205 .43439 Mdot
.27793 .42689 Mdot
.36089 .66361 Mdot
.71959 .40697 Mdot
.4331 .3239 Mdot
.63607 .77396 Mdot
.46325 .3885 Mdot
.60459 .43463 Mdot
.59998 .4302 Mdot
.5167 .60266 Mdot
.29608 .4705 Mdot
.41234 .29643 Mdot
.28904 .6562 Mdot
.56216 .65932 Mdot
.42733 .33887 Mdot
.51375 .62495 Mdot
.65958 .60375 Mdot
.4604 .36081 Mdot
.73911 .53405 Mdot
.27694 .46716 Mdot
.45888 .34508 Mdot
.53236 .52079 Mdot
.65944 .44421 Mdot
.56407 .68876 Mdot
.38643 .66249 Mdot
.65472 .59881 Mdot
.35834 .66049 Mdot
.3251 .5449 Mdot
.37317 .67667 Mdot
.27254 .48051 Mdot
.50996 .62446 Mdot
.71763 .38804 Mdot
.30629 .45496 Mdot
.352 .43408 Mdot
.35529 .65557 Mdot
.51523 .58988 Mdot
.70733 .39744 Mdot
.52519 .55216 Mdot
.52506 .60242 Mdot
.28873 .44423 Mdot
.46036 .3465 Mdot
.46449 .34401 Mdot
.56313 .59237 Mdot
.45741 .35198 Mdot
.34052 .63863 Mdot
.66307 .63604 Mdot
.64995 .28552 Mdot
.31574 .5031 Mdot
.69651 .39887 Mdot
.63092 .396 Mdot
.38459 .62137 Mdot
.34211 .633 Mdot
.29991 .49115 Mdot
.51409 .36836 Mdot
.53256 .60454 Mdot
.45909 .32697 Mdot
.42938 .31635 Mdot
.44873 .33551 Mdot
.3945 .31039 Mdot
.62291 .68272 Mdot
.28141 .49598 Mdot
.44818 .33025 Mdot
.63647 .44275 Mdot
.61454 .45773 Mdot
.54217 .55796 Mdot
.54773 .72833 Mdot
.71153 .40126 Mdot
.54743 .59322 Mdot
.60257 .4162 Mdot
.36566 .63098 Mdot
.50727 .53061 Mdot
.55585 .57325 Mdot
.3724 .63881 Mdot
.37155 .63366 Mdot
.55513 .58104 Mdot
.50227 .53428 Mdot
.5866 .3359 Mdot
.69593 .43096 Mdot
.37118 .37259 Mdot
.38523 .63684 Mdot
.3576 .47018 Mdot
.36101 .31704 Mdot
.59339 .46578 Mdot
.52057 .60952 Mdot
.34176 .62845 Mdot
.42748 .36223 Mdot
.5954 .44641 Mdot
.52423 .58508 Mdot
.57005 .68896 Mdot
.5407 .57854 Mdot
.52633 .56198 Mdot
.41912 .34918 Mdot
.17103 .57329 Mdot
.4538 .36452 Mdot
.34641 .69045 Mdot
.53682 .58946 Mdot
.52876 .14642 Mdot
.38743 .63108 Mdot
.33883 .3676 Mdot
.72157 .38819 Mdot
.60429 .41335 Mdot
.36525 .65108 Mdot
.39845 .33272 Mdot
.3001 .44516 Mdot
.74002 .51595 Mdot
.4487 .34933 Mdot
.55429 .55991 Mdot
.53416 .56076 Mdot
.3463 .6553 Mdot
.41332 .31719 Mdot
.70219 .40373 Mdot
.45504 .34462 Mdot
.30649 .46469 Mdot
.6476 .43812 Mdot
.23133 .3497 Mdot
.52358 .59275 Mdot
.45756 .35606 Mdot
.34071 .67115 Mdot
.56031 .67294 Mdot
.61363 .46404 Mdot
.21306 .36365 Mdot
.62362 .44361 Mdot
.29709 .45209 Mdot
.51806 .53338 Mdot
.66341 .43779 Mdot
.61921 .42298 Mdot
.60385 .39836 Mdot
.32381 .48812 Mdot
.6191 .4205 Mdot
.59284 .41057 Mdot
.58168 .2057 Mdot
.45101 .36217 Mdot
.63117 .42781 Mdot
.33165 .64613 Mdot
.47342 .54188 Mdot
.59361 .4581 Mdot
.30584 .57392 Mdot
.72326 .57934 Mdot
.51279 .60465 Mdot
.56849 .5721 Mdot
.67632 .69802 Mdot
.59688 .43353 Mdot
.58218 .46541 Mdot
.64721 .43785 Mdot
.65673 .31124 Mdot
.35514 .64958 Mdot
.36047 .67462 Mdot
.55925 .67494 Mdot
.71384 .55641 Mdot
.56573 .69863 Mdot
.31127 .50327 Mdot
.73057 .39164 Mdot
.55362 .59622 Mdot
.44648 .35176 Mdot
.61309 .44948 Mdot
.34832 .67353 Mdot
.58737 .44175 Mdot
.69209 .41537 Mdot
.33976 .64345 Mdot
.34768 .62617 Mdot
.38757 .66636 Mdot
.57678 .71258 Mdot
.43513 .3478 Mdot
.61028 .46781 Mdot
.57924 .70701 Mdot
.53126 .55188 Mdot
.66042 .65854 Mdot
.43219 .3468 Mdot
.45436 .35736 Mdot
.43385 .31292 Mdot
.59737 .46899 Mdot
.64323 .4475 Mdot
.31155 .48482 Mdot
.40259 .28322 Mdot
.27586 .46272 Mdot
.36444 .65376 Mdot
.34985 .62119 Mdot
.58968 .43725 Mdot
.50407 .61752 Mdot
.55571 .6879 Mdot
.35175 .66712 Mdot
.54814 .613 Mdot
.55123 .67422 Mdot
.57927 .45878 Mdot
.36113 .65883 Mdot
.58559 .69752 Mdot
.51492 .36767 Mdot
.26019 .34715 Mdot
.5577 .6717 Mdot
.52741 .5995 Mdot
.57567 .24499 Mdot
.65967 .70457 Mdot
.58304 .66659 Mdot
.31372 .50364 Mdot
.56486 .4569 Mdot
.54434 .61371 Mdot
.55016 .67198 Mdot
.64297 .71197 Mdot
.34537 .64587 Mdot
.53144 .60221 Mdot
.45933 .59235 Mdot
.6508 .28679 Mdot
.56026 .6714 Mdot
.45756 .35705 Mdot
.40484 .2915 Mdot
.61461 .42735 Mdot
.72273 .3906 Mdot
.31677 .50561 Mdot
.39962 .64792 Mdot
.35748 .67405 Mdot
.43844 .28933 Mdot
.67432 .63523 Mdot
.33507 .6538 Mdot
.56988 .46015 Mdot
.53939 .68185 Mdot
.63758 .44112 Mdot
.53056 .5272 Mdot
.66589 .43697 Mdot
.56658 .59249 Mdot
.55918 .67222 Mdot
.31848 .50002 Mdot
.28113 .49168 Mdot
.29763 .47423 Mdot
.33817 .65415 Mdot
.65277 .59526 Mdot
.3445 .67694 Mdot
.57665 .18451 Mdot
.54791 .71257 Mdot
.37676 .79991 Mdot
.60294 .3937 Mdot
.59626 .41744 Mdot
.67784 .41947 Mdot
.51851 .56666 Mdot
.59718 .43533 Mdot
.30076 .50394 Mdot
.38812 .65855 Mdot
.23935 .44004 Mdot
.41076 .33341 Mdot
.57862 .18993 Mdot
.36085 .62912 Mdot
.56347 .57449 Mdot
.55587 .69272 Mdot
.69191 .6957 Mdot
.56915 .73475 Mdot
.33023 .63176 Mdot
.57711 .43556 Mdot
.47137 .37271 Mdot
.49265 .8424 Mdot
.61083 .44738 Mdot
.33882 .66224 Mdot
.32401 .62256 Mdot
.64186 .462 Mdot
.68784 .36278 Mdot
.22168 .45704 Mdot
.65984 .62538 Mdot
.58742 .69545 Mdot
.5239 .55484 Mdot
.70873 .60152 Mdot
.35024 .65068 Mdot
.38102 .6613 Mdot
.59071 .70526 Mdot
.47197 .33805 Mdot
.43095 .31335 Mdot
.41077 .39257 Mdot
.3071 .49896 Mdot
.61117 .41038 Mdot
.35664 .65824 Mdot
.4745 .3539 Mdot
.60227 .58734 Mdot
.2929 .47735 Mdot
.3594 .66525 Mdot
.62314 .44742 Mdot
.62028 .42512 Mdot
.56703 .69725 Mdot
.49046 .57691 Mdot
.51528 .56592 Mdot
.34026 .36749 Mdot
.66946 .60731 Mdot
.73224 .38923 Mdot
.60604 .41405 Mdot
.39905 .32432 Mdot
.55385 .57433 Mdot
.55924 .68653 Mdot
.65633 .41718 Mdot
.71678 .32237 Mdot
.40383 .33801 Mdot
.27427 .46904 Mdot
.53266 .586 Mdot
.6994 .57131 Mdot
.62407 .44573 Mdot
.5923 .43334 Mdot
.69549 .42279 Mdot
.72922 .33781 Mdot
.39254 .64226 Mdot
.43783 .36081 Mdot
.57712 .70777 Mdot
.44518 .33794 Mdot
.30723 .60493 Mdot
.72597 .39378 Mdot
.56978 .46636 Mdot
.44248 .36694 Mdot
.43252 .32721 Mdot
.29821 .45299 Mdot
.27698 .49027 Mdot
.35449 .60975 Mdot
.6128 .46157 Mdot
.53585 .61497 Mdot
.4464 .32962 Mdot
.39158 .65809 Mdot
.56729 .69961 Mdot
.30153 .58052 Mdot
.63807 .41234 Mdot
.35165 .6545 Mdot
.54602 .58262 Mdot
.41521 .34233 Mdot
.36793 .63889 Mdot
.53579 .55668 Mdot
.55857 .73056 Mdot
.58563 .41108 Mdot
.31013 .63776 Mdot
.52226 .58057 Mdot
.62158 .4576 Mdot
.59168 .50227 Mdot
.71944 .39078 Mdot
.53291 .62208 Mdot
.38275 .61689 Mdot
.52588 .57913 Mdot
.40579 .29273 Mdot
.6334 .46832 Mdot
.37744 .66662 Mdot
.37429 .2961 Mdot
.72442 .38764 Mdot
.52038 .59228 Mdot
.44429 .35679 Mdot
.29812 .62204 Mdot
.48495 .34699 Mdot
.65656 .6992 Mdot
.59397 .45447 Mdot
.35795 .6606 Mdot
.56607 .68976 Mdot
.3051 .4584 Mdot
.33308 .43172 Mdot
.35416 .5169 Mdot
.38003 .63826 Mdot
.61224 .45079 Mdot
.45726 .3424 Mdot
.27715 .47751 Mdot
.38638 .32209 Mdot
.32297 .66692 Mdot
.33109 .64155 Mdot
.67971 .41678 Mdot
.56502 .69939 Mdot
.5852 .39982 Mdot
.37862 .66754 Mdot
.36162 .68115 Mdot
.58152 .20808 Mdot
.5866 .69356 Mdot
.69681 .42338 Mdot
.56378 .5922 Mdot
.64775 .40531 Mdot
.57125 .19961 Mdot
.52838 .56359 Mdot
.40915 .33111 Mdot
.603 .42239 Mdot
.21553 .65914 Mdot
.3842 .62631 Mdot
.66024 .62542 Mdot
.22898 .45304 Mdot
.29266 .49774 Mdot
.36132 .64559 Mdot
.59835 .45015 Mdot
.30086 .57781 Mdot
.55192 .68048 Mdot
.68555 .43091 Mdot
.51724 .58757 Mdot
.44165 .28707 Mdot
.29788 .46258 Mdot
.47037 .5769 Mdot
.30634 .46107 Mdot
.29115 .46619 Mdot
.50415 .3739 Mdot
.61442 .42833 Mdot
.35965 .63245 Mdot
.32672 .65477 Mdot
.56214 .55153 Mdot
.34557 .69549 Mdot
.41728 .30403 Mdot
.21084 .65 Mdot
.71861 .32725 Mdot
.63633 .42022 Mdot
.5506 .55475 Mdot
.52234 .60779 Mdot
.30326 .57034 Mdot
.61512 .42145 Mdot
.43959 .35696 Mdot
.37833 .66876 Mdot
.34998 .66145 Mdot
.71931 .40684 Mdot
.28079 .49182 Mdot
.57302 .72753 Mdot
.34272 .63503 Mdot
.64743 .65214 Mdot
.58486 .4512 Mdot
.27901 .43781 Mdot
.34417 .63574 Mdot
.60315 .82082 Mdot
.16983 .59019 Mdot
.46377 .3643 Mdot
.58524 .40952 Mdot
.44174 .31393 Mdot
.56491 .67461 Mdot
.33145 .68155 Mdot
.30752 .45801 Mdot
.53768 .58693 Mdot
.20919 .48655 Mdot
.34684 .65859 Mdot
.43893 .33974 Mdot
.60907 .42913 Mdot
.70208 .27809 Mdot
.63235 .43816 Mdot
.6122 .66794 Mdot
.56628 .66019 Mdot
.3311 .42984 Mdot
.28308 .45144 Mdot
.58415 .41023 Mdot
.58122 .70621 Mdot
.32438 .63692 Mdot
.3403 .64516 Mdot
.20554 .37126 Mdot
.5276 .56127 Mdot
.32234 .67844 Mdot
.61925 .45904 Mdot
.38315 .66951 Mdot
.57374 .23654 Mdot
.29116 .49672 Mdot
.63611 .40202 Mdot
.36746 .65914 Mdot
.47795 .33572 Mdot
.6591 .61779 Mdot
.58908 .45458 Mdot
.54858 .6187 Mdot
.27468 .48338 Mdot
.58047 .18979 Mdot
.3905 .62707 Mdot
.64343 .42397 Mdot
.29793 .50685 Mdot
.51124 .62507 Mdot
.2444 .43429 Mdot
.43468 .34794 Mdot
.33527 .66245 Mdot
.30062 .46807 Mdot
.53956 .59361 Mdot
.58436 .69508 Mdot
.31983 .65068 Mdot
.37074 .65943 Mdot
.70164 .4128 Mdot
.56215 .58903 Mdot
.51064 .62236 Mdot
.40214 .31192 Mdot
.28079 .46754 Mdot
.69383 .41734 Mdot
.65752 .66169 Mdot
.65748 .42516 Mdot
.28323 .46394 Mdot
.54244 .15477 Mdot
.5763 .43277 Mdot
.63464 .40933 Mdot
.70947 .28739 Mdot
.4198 .29688 Mdot
.39513 .31764 Mdot
.68488 .61554 Mdot
.70867 .40478 Mdot
.64513 .38187 Mdot
.43822 .34681 Mdot
.43734 .33626 Mdot
.6465 .38247 Mdot
.69823 .413 Mdot
.42601 .39467 Mdot
.27936 .47942 Mdot
.2901 .49785 Mdot
.4473 .33454 Mdot
.67636 .42126 Mdot
.29079 .51367 Mdot
.50165 .3144 Mdot
.32569 .64671 Mdot
.71492 .58888 Mdot
.4398 .33066 Mdot
.65453 .6188 Mdot
.27728 .47217 Mdot
.70925 .65722 Mdot
.72648 .57476 Mdot
.60297 .47244 Mdot
.61641 .42504 Mdot
.56345 .71889 Mdot
.54144 .5808 Mdot
.55548 .57963 Mdot
.29801 .47405 Mdot
.58113 .40182 Mdot
.42513 .34187 Mdot
.64401 .39375 Mdot
.65125 .7084 Mdot
.72421 .65233 Mdot
.72964 .35848 Mdot
.43062 .33442 Mdot
.41942 .32641 Mdot
.34695 .62081 Mdot
.40646 .62794 Mdot
.58607 .47168 Mdot
.2761 .48647 Mdot
.46247 .35174 Mdot
.28559 .45992 Mdot
.34878 .64997 Mdot
.35767 .62918 Mdot
.55181 .56478 Mdot
.53311 .6026 Mdot
.35535 .64396 Mdot
.30561 .57368 Mdot
.65827 .66112 Mdot
.41931 .28452 Mdot
.57787 .18026 Mdot
.70566 .68131 Mdot
.67735 .26598 Mdot
.56822 .68879 Mdot
.51089 .52906 Mdot
.30062 .50561 Mdot
.58931 .40537 Mdot
.59901 .42084 Mdot
.53136 .57324 Mdot
.28415 .50507 Mdot
.55073 .70409 Mdot
.29236 .4972 Mdot
.58367 .69629 Mdot
.36788 .67026 Mdot
.60817 .45263 Mdot
.58032 .43353 Mdot
.30033 .45523 Mdot
.3405 .62287 Mdot
.36585 .65817 Mdot
.56495 .68546 Mdot
.69507 .68843 Mdot
.34721 .65463 Mdot
.4385 .33007 Mdot
.40171 .24697 Mdot
.53201 .56302 Mdot
.59649 .44655 Mdot
.67793 .69856 Mdot
.63272 .46861 Mdot
.53319 .55165 Mdot
.5321 .58542 Mdot
.56561 .17571 Mdot
.58077 .45039 Mdot
.19957 .38313 Mdot
.5555 .5708 Mdot
.41047 .29998 Mdot
.361 .63636 Mdot
.54723 .55432 Mdot
.55743 .61333 Mdot
.55434 .64678 Mdot
.54464 .55137 Mdot
.43356 .31637 Mdot
.42855 .30389 Mdot
.71011 .39585 Mdot
.5866 .17737 Mdot
.57743 .70443 Mdot
.54888 .69273 Mdot
.39036 .64466 Mdot
.32519 .54546 Mdot
.55176 .43026 Mdot
.54671 .69521 Mdot
.41097 .38202 Mdot
.68186 .41569 Mdot
.70668 .39396 Mdot
.71899 .39549 Mdot
.39713 .29952 Mdot
.63935 .45772 Mdot
.39158 .63563 Mdot
.43775 .34048 Mdot
.70052 .39898 Mdot
.65723 .40675 Mdot
.42959 .34574 Mdot
.28887 .46773 Mdot
.73136 .38085 Mdot
.45755 .34846 Mdot
.74098 .51392 Mdot
.27299 .47419 Mdot
.69609 .39739 Mdot
.43597 .81281 Mdot
.62755 .81739 Mdot
.29274 .49496 Mdot
.35628 .66545 Mdot
.35729 .65679 Mdot
.33695 .64835 Mdot
.39755 .3129 Mdot
.36336 .62063 Mdot
.40983 .31909 Mdot
.30468 .56632 Mdot
.70956 .56213 Mdot
.57117 .7053 Mdot
.33536 .6951 Mdot
.44926 .33692 Mdot
.57305 .19199 Mdot
.86061 .39473 Mdot
.64268 .42855 Mdot
.30412 .45296 Mdot
.54375 .69486 Mdot
.65727 .63016 Mdot
.55596 .71835 Mdot
.36779 .64568 Mdot
.70245 .57051 Mdot
.58585 .44456 Mdot
.24251 .36024 Mdot
.56469 .69111 Mdot
.4379 .33552 Mdot
.7088 .4112 Mdot
.37321 .61386 Mdot
.55644 .67906 Mdot
.56084 .69661 Mdot
.59682 .43777 Mdot
.41728 .29872 Mdot
.3689 .64969 Mdot
.27614 .49781 Mdot
.37854 .57735 Mdot
.56294 .51362 Mdot
.58139 .45502 Mdot
.63107 .40599 Mdot
.65972 .60874 Mdot
.30224 .58066 Mdot
.28052 .48526 Mdot
.63921 .70152 Mdot
.38427 .6202 Mdot
.65697 .70886 Mdot
.48215 .35158 Mdot
.33347 .69444 Mdot
.52787 .56489 Mdot
.53966 .55671 Mdot
.60787 .44345 Mdot
.85506 .42174 Mdot
.68838 .36873 Mdot
.29529 .51456 Mdot
.53317 .56726 Mdot
.34217 .62072 Mdot
.39299 .31521 Mdot
.4553 .59811 Mdot
.70929 .40078 Mdot
.27471 .49661 Mdot
.34195 .64981 Mdot
.86402 .47386 Mdot
.56758 .72029 Mdot
.66413 .62938 Mdot
.62003 .45511 Mdot
.60422 .44253 Mdot
.29581 .48203 Mdot
.31856 .48037 Mdot
.58603 .20093 Mdot
.57299 .73743 Mdot
.23495 .34301 Mdot
.3174 .51938 Mdot
.87078 .48676 Mdot
.52781 .6118 Mdot
.41585 .3281 Mdot
.55438 .58627 Mdot
.31947 .48698 Mdot
.59892 .42466 Mdot
.4178 .29762 Mdot
.54826 .57631 Mdot
.42927 .385 Mdot
.70849 .39254 Mdot
.65048 .65485 Mdot
.62057 .43756 Mdot
.45151 .32591 Mdot
.43562 .34355 Mdot
.46869 .3401 Mdot
.54282 .56171 Mdot
.62098 .41102 Mdot
.64204 .42519 Mdot
.62887 .40695 Mdot
.5885 .20726 Mdot
.6067 .45048 Mdot
.48561 .36746 Mdot
.68528 .62843 Mdot
.22475 .67409 Mdot
.5818 .43098 Mdot
.30087 .47233 Mdot
.61348 .44157 Mdot
.58054 .71151 Mdot
.59311 .40657 Mdot
.7078 .39177 Mdot
.28338 .48279 Mdot
.71289 .31257 Mdot
.5416 .66379 Mdot
.57912 .45392 Mdot
.58318 .68858 Mdot
.32914 .37442 Mdot
.63813 .69691 Mdot
.57319 .21928 Mdot
.45358 .3429 Mdot
.32606 .6738 Mdot
.31634 .50809 Mdot
.36063 .62522 Mdot
.73026 .40783 Mdot
.54951 .60231 Mdot
.36181 .79076 Mdot
.67152 .66431 Mdot
.60086 .42362 Mdot
.51433 .59742 Mdot
.44772 .35971 Mdot
.38697 .62925 Mdot
.64372 .25253 Mdot
.67877 .41871 Mdot
.5487 .72492 Mdot
.55572 .72432 Mdot
.53872 .5334 Mdot
.4696 .33813 Mdot
.57177 .23144 Mdot
.29442 .48272 Mdot
.34026 .65661 Mdot
.55543 .66554 Mdot
.39466 .37883 Mdot
.31178 .45995 Mdot
.30673 .56663 Mdot
.29988 .46452 Mdot
.59185 .41812 Mdot
.55509 .56391 Mdot
.36231 .37914 Mdot
.52379 .57329 Mdot
.65646 .41025 Mdot
.37146 .65809 Mdot
.52801 .56271 Mdot
.56718 .71354 Mdot
.29711 .46688 Mdot
.36354 .62977 Mdot
.60238 .43118 Mdot
.43964 .35038 Mdot
.68556 .50255 Mdot
.3069 .65373 Mdot
.72566 .39085 Mdot
.72581 .39086 Mdot
.42083 .27997 Mdot
.52936 .62144 Mdot
.31457 .42075 Mdot
.63389 .46883 Mdot
.34223 .53464 Mdot
.4873 .58613 Mdot
.29243 .70079 Mdot
.34092 .677 Mdot
.3486 .64068 Mdot
.58478 .43351 Mdot
.39099 .66001 Mdot
.56931 .46209 Mdot
.38939 .61983 Mdot
.33971 .35407 Mdot
.66616 .39955 Mdot
.34154 .64103 Mdot
.55146 .58828 Mdot
.61665 .46212 Mdot
.44279 .36012 Mdot
.34437 .67978 Mdot
.60369 .47238 Mdot
.30186 .72447 Mdot
.29916 .45368 Mdot
.54255 .56084 Mdot
.62355 .59245 Mdot
.28268 .47375 Mdot
.42 .30733 Mdot
.56393 .44769 Mdot
.54607 .69026 Mdot
.4168 .32221 Mdot
.52837 .543 Mdot
.56335 .69987 Mdot
.66388 .63763 Mdot
.42519 .31595 Mdot
.52928 .56556 Mdot
.55677 .72884 Mdot
.56544 .55515 Mdot
.34635 .64269 Mdot
.31789 .62799 Mdot
.52203 .58414 Mdot
.58606 .44079 Mdot
.35087 .61683 Mdot
.30232 .48962 Mdot
.59987 .46013 Mdot
.35556 .65972 Mdot
.54297 .56777 Mdot
.635 .43949 Mdot
.70992 .40404 Mdot
.57618 .20196 Mdot
.51449 .60819 Mdot
.57036 .70874 Mdot
.47228 .34674 Mdot
.64366 .41711 Mdot
.58067 .69746 Mdot
.31212 .65113 Mdot
.64577 .42669 Mdot
.46568 .35531 Mdot
.51432 .3747 Mdot
.40316 .64183 Mdot
.26951 .47562 Mdot
.3268 .65933 Mdot
.57325 .6747 Mdot
.86257 .38321 Mdot
.55479 .57462 Mdot
.67594 .43341 Mdot
.60837 .40403 Mdot
.32952 .67727 Mdot
.43276 .34365 Mdot
.24735 .32693 Mdot
.58702 .40957 Mdot
.64373 .43261 Mdot
.59682 .44311 Mdot
.3487 .5704 Mdot
.40103 .30652 Mdot
.59614 .44493 Mdot
.49464 .55502 Mdot
.6298 .4038 Mdot
.56605 .67781 Mdot
.39608 .80819 Mdot
.53061 .55527 Mdot
.52293 .14275 Mdot
.54904 .57299 Mdot
.33772 .63958 Mdot
.74141 .51309 Mdot
.62142 .59147 Mdot
.38386 .60186 Mdot
.41808 .30598 Mdot
.37018 .37044 Mdot
.35596 .62985 Mdot
.30036 .61734 Mdot
.70596 .40001 Mdot
.70701 .41074 Mdot
.60532 .46517 Mdot
.36777 .64544 Mdot
.39479 .65006 Mdot
.54542 .60602 Mdot
.51304 .59043 Mdot
.59982 .48234 Mdot
.34788 .67203 Mdot
.60625 .45217 Mdot
.66047 .4407 Mdot
.31123 .45805 Mdot
.46247 .36336 Mdot
.31016 .46305 Mdot
.3046 .45002 Mdot
.66932 .2623 Mdot
.66901 .60561 Mdot
.30683 .49989 Mdot
.30484 .51052 Mdot
.32427 .56508 Mdot
.66362 .28314 Mdot
.5698 .67891 Mdot
.68537 .36866 Mdot
.34735 .62312 Mdot
.62405 .41152 Mdot
.40074 .30515 Mdot
.50564 .58587 Mdot
.27357 .29949 Mdot
.80574 .58654 Mdot
.68586 .41569 Mdot
.37527 .61862 Mdot
.52131 .5817 Mdot
.51815 .57983 Mdot
.65876 .70533 Mdot
.60396 .45057 Mdot
.40079 .64636 Mdot
.65121 .28561 Mdot
.32085 .51748 Mdot
.30263 .57522 Mdot
.45979 .32719 Mdot
.61405 .4434 Mdot
.40073 .31868 Mdot
.26593 .48052 Mdot
.57807 .69457 Mdot
.57047 .7164 Mdot
.57827 .45306 Mdot
.71772 .38832 Mdot
.34522 .53244 Mdot
.71258 .40523 Mdot
.69443 .41261 Mdot
.52678 .58026 Mdot
.70175 .4214 Mdot
.6442 .42256 Mdot
.67232 .40858 Mdot
.52982 .55206 Mdot
.30989 .45866 Mdot
.64895 .26893 Mdot
.51956 .59049 Mdot
.56613 .43224 Mdot
.26611 .47747 Mdot
.71298 .40225 Mdot
.29998 .48612 Mdot
.3034 .58185 Mdot
.31049 .48967 Mdot
.57386 .71004 Mdot
.40852 .64181 Mdot
.58372 .1905 Mdot
.45792 .34473 Mdot
.28214 .49587 Mdot
.55876 .73153 Mdot
.30243 .48305 Mdot
.33891 .62659 Mdot
.3278 .50295 Mdot
.46331 .28579 Mdot
.64632 .64961 Mdot
.68437 .27274 Mdot
.31975 .51693 Mdot
.40346 .63875 Mdot
.44747 .3341 Mdot
.32627 .54132 Mdot
.57713 .41932 Mdot
.57056 .71888 Mdot
.60734 .44223 Mdot
.29452 .46629 Mdot
.36089 .61788 Mdot
.57137 .21645 Mdot
.57025 .71033 Mdot
.5748 .18018 Mdot
.34412 .67335 Mdot
.58478 .41779 Mdot
.26704 .46267 Mdot
.34061 .44094 Mdot
.28792 .45067 Mdot
.71529 .5654 Mdot
.54084 .61423 Mdot
.57694 .74858 Mdot
.4202 .31973 Mdot
.52885 .61426 Mdot
.72068 .73729 Mdot
.34626 .40156 Mdot
.42806 .35232 Mdot
.31777 .67648 Mdot
.58352 .45133 Mdot
.69796 .42414 Mdot
.54217 .59872 Mdot
.46266 .33961 Mdot
.69535 .42258 Mdot
.54774 .56053 Mdot
.68995 .62402 Mdot
.46448 .33289 Mdot
.31853 .6488 Mdot
.61458 .46138 Mdot
.28635 .44441 Mdot
.26722 .46861 Mdot
.55715 .5692 Mdot
.30877 .46545 Mdot
.56384 .43882 Mdot
.43119 .32143 Mdot
.71083 .39649 Mdot
.56147 .675 Mdot
.38221 .39875 Mdot
.51178 .56432 Mdot
.53859 .7191 Mdot
.6346 .44681 Mdot
.35838 .63064 Mdot
.20779 .48671 Mdot
.6166 .39581 Mdot
.43893 .34434 Mdot
.59621 .40862 Mdot
.69876 .42216 Mdot
.70982 .40836 Mdot
.34054 .6566 Mdot
.65748 .61713 Mdot
.60734 .45149 Mdot
.27052 .49062 Mdot
.65459 .38393 Mdot
.59911 .39576 Mdot
.57036 .74188 Mdot
.70613 .39255 Mdot
.2605 .48368 Mdot
.42661 .28358 Mdot
.35909 .63344 Mdot
.42185 .33691 Mdot
.44035 .3721 Mdot
.41928 .30753 Mdot
.4576 .3176 Mdot
.63138 .47054 Mdot
.19801 .37727 Mdot
.57338 .23502 Mdot
.68847 .27093 Mdot
.43329 .36679 Mdot
.1889 .50511 Mdot
.42974 .35411 Mdot
.41938 .30693 Mdot
.34044 .25274 Mdot
.41341 .30329 Mdot
.58937 .43639 Mdot
.5989 .41002 Mdot
.72103 .33368 Mdot
.38207 .57809 Mdot
.63438 .43576 Mdot
.53432 .54973 Mdot
.54351 .70193 Mdot
.47548 .34398 Mdot
.53567 .5859 Mdot
.65634 .63173 Mdot
.55757 .56156 Mdot
.59721 .43712 Mdot
.61283 .45491 Mdot
.71844 .40006 Mdot
.73565 .64813 Mdot
.40185 .58592 Mdot
.43409 .31168 Mdot
.59342 .39703 Mdot
.25383 .42988 Mdot
.60449 .46308 Mdot
.6074 .40185 Mdot
.6422 .45477 Mdot
.35966 .63239 Mdot
.39126 .30886 Mdot
.53045 .60545 Mdot
.37707 .39932 Mdot
.625 .4405 Mdot
.5026 .57737 Mdot
.5405 .69033 Mdot
.59706 .45016 Mdot
.42025 .30199 Mdot
.69746 .42227 Mdot
.40581 .33806 Mdot
.42129 .315 Mdot
.64485 .42906 Mdot
.47469 .34464 Mdot
.39613 .32431 Mdot
.7063 .41058 Mdot
.36559 .61528 Mdot
.33931 .36654 Mdot
.5872 .44479 Mdot
.56543 .71112 Mdot
.61317 .42309 Mdot
.56952 .67734 Mdot
.54571 .55258 Mdot
.52452 .57887 Mdot
.65317 .33633 Mdot
.37834 .66369 Mdot
.55734 .73723 Mdot
.37715 .67502 Mdot
.55784 .42867 Mdot
.41607 .38103 Mdot
.32617 .49641 Mdot
.30632 .68484 Mdot
.52653 .57803 Mdot
.61803 .67269 Mdot
.60761 .38063 Mdot
.31219 .48356 Mdot
.42936 .35783 Mdot
.63645 .27419 Mdot
.52144 .60934 Mdot
.31882 .64686 Mdot
.32697 .65152 Mdot
.34751 .40984 Mdot
.35098 .24989 Mdot
.5817 .43216 Mdot
.5181 .60533 Mdot
.58789 .49825 Mdot
.54237 .57992 Mdot
.54277 .60635 Mdot
.36906 .66162 Mdot
.6336 .43994 Mdot
.69397 .62267 Mdot
.35632 .65427 Mdot
.55243 .69292 Mdot
.40782 .32925 Mdot
.58231 .69645 Mdot
.27863 .33267 Mdot
.58579 .19878 Mdot
.35593 .6469 Mdot
.52398 .55835 Mdot
.63296 .41253 Mdot
.41373 .29757 Mdot
.38714 .32347 Mdot
.44901 .36258 Mdot
.55047 .67853 Mdot
.37241 .6711 Mdot
.30599 .73537 Mdot
.6103 .43015 Mdot
.43207 .32823 Mdot
.54094 .67402 Mdot
.62136 .42439 Mdot
.2782 .49006 Mdot
.69426 .4212 Mdot
.44016 .33369 Mdot
.67305 .43289 Mdot
.42 .31889 Mdot
.33007 .64637 Mdot
.57772 .44781 Mdot
.58918 .46201 Mdot
.63513 .69585 Mdot
.55075 .7055 Mdot
.41313 .34849 Mdot
.6617 .59773 Mdot
.6479 .40536 Mdot
.66611 .70285 Mdot
.60241 .45574 Mdot
.6873 .2746 Mdot
.55749 .60535 Mdot
.54882 .55968 Mdot
.60141 .40613 Mdot
.58848 .44801 Mdot
.38688 .32007 Mdot
.57512 .23803 Mdot
.5888 .20591 Mdot
.26843 .47394 Mdot
.43608 .35896 Mdot
.36021 .65261 Mdot
.34468 .68115 Mdot
.36071 .62228 Mdot
.56511 .66929 Mdot
.71219 .39901 Mdot
.59108 .42455 Mdot
.28145 .50782 Mdot
.54586 .70575 Mdot
.42651 .32953 Mdot
.57239 .69994 Mdot
.66521 .61163 Mdot
.56225 .71356 Mdot
.55407 .59124 Mdot
.16959 .56046 Mdot
.6598 .44153 Mdot
.55721 .70118 Mdot
.46393 .36178 Mdot
.66184 .38379 Mdot
.62688 .46392 Mdot
.57575 .19361 Mdot
.54667 .72127 Mdot
.31353 .67152 Mdot
.62996 .45116 Mdot
.7047 .55008 Mdot
.2995 .48038 Mdot
.58312 .69966 Mdot
.3008 .46439 Mdot
.68903 .41658 Mdot
.36346 .34349 Mdot
.44456 .34392 Mdot
.31379 .46031 Mdot
.61574 .40112 Mdot
.58304 .70028 Mdot
.35222 .64497 Mdot
.66248 .28391 Mdot
.31086 .56282 Mdot
.50247 .59835 Mdot
.65644 .70265 Mdot
.39228 .63809 Mdot
.68076 .28748 Mdot
.30833 .47265 Mdot
.63229 .39011 Mdot
.66687 .43502 Mdot
.65092 .41627 Mdot
.36775 .65486 Mdot
.34895 .63996 Mdot
.28921 .6822 Mdot
.58456 .46153 Mdot
.63878 .45763 Mdot
.44558 .2868 Mdot
.37692 .66887 Mdot
.4192 .30814 Mdot
.45847 .33243 Mdot
.35709 .66482 Mdot
.42493 .35801 Mdot
.5625 .69797 Mdot
.69418 .5964 Mdot
.30896 .47538 Mdot
.27201 .46021 Mdot
.35639 .64493 Mdot
.3839 .64739 Mdot
.35886 .63008 Mdot
.68824 .4216 Mdot
.42148 .31278 Mdot
.5707 .45309 Mdot
.61252 .43801 Mdot
.63297 .45741 Mdot
.44279 .31384 Mdot
.58292 .41261 Mdot
.65397 .39123 Mdot
.54416 .68277 Mdot
.34012 .63649 Mdot
.28149 .46123 Mdot
.68447 .50651 Mdot
.26932 .49042 Mdot
.63746 .40429 Mdot
.34174 .35834 Mdot
.4244 .35342 Mdot
.55873 .71918 Mdot
.71597 .39017 Mdot
.56912 .71428 Mdot
.31116 .4578 Mdot
.44997 .29011 Mdot
.6697 .63684 Mdot
.57249 .44971 Mdot
.66178 .60514 Mdot
.52436 .79913 Mdot
.4921 .36722 Mdot
.28195 .46863 Mdot
.66708 .42992 Mdot
.55952 .56881 Mdot
.59707 .48762 Mdot
.58717 .43004 Mdot
.60575 .39324 Mdot
.69676 .54667 Mdot
.622 .40355 Mdot
.4681 .3624 Mdot
.65767 .38899 Mdot
.51616 .56795 Mdot
.63037 .45615 Mdot
.20683 .37849 Mdot
.63407 .42962 Mdot
.57567 .45421 Mdot
.60274 .41703 Mdot
.64068 .39754 Mdot
.43961 .30995 Mdot
.71609 .39384 Mdot
.26776 .4848 Mdot
.69462 .59689 Mdot
.30902 .47919 Mdot
.36203 .64256 Mdot
.5082 .59698 Mdot
.39964 .29366 Mdot
.56838 .71492 Mdot
.39337 .5619 Mdot
.70844 .5524 Mdot
.34633 .621 Mdot
.62645 .69045 Mdot
.57665 .72412 Mdot
.54546 .60158 Mdot
.57677 .67639 Mdot
.36859 .65877 Mdot
.2846 .49402 Mdot
.57711 .43467 Mdot
.43642 .32075 Mdot
.4592 .35115 Mdot
.6305 .45512 Mdot
.33651 .37495 Mdot
.26905 .46599 Mdot
.33957 .69605 Mdot
.58686 .42472 Mdot
.63649 .40206 Mdot
.40153 .33117 Mdot
.37776 .62262 Mdot
.61034 .38091 Mdot
.56252 .68165 Mdot
.6085 .46143 Mdot
.51508 .57422 Mdot
.66446 .61048 Mdot
.26832 .47648 Mdot
.53868 .56443 Mdot
.63115 .41649 Mdot
.67259 .61444 Mdot
.68427 .4302 Mdot
.49957 .5472 Mdot
.4036 .62615 Mdot
.64338 .43286 Mdot
.59359 .46302 Mdot
.46266 .33078 Mdot
.30829 .47049 Mdot
.43405 .34631 Mdot
.43973 .27706 Mdot
.52509 .5785 Mdot
.29283 .45088 Mdot
.64253 .39902 Mdot
.29075 .51683 Mdot
.69646 .41985 Mdot
.60651 .4344 Mdot
.28431 .46852 Mdot
.41361 .31311 Mdot
.23849 .34166 Mdot
.6475 .26883 Mdot
.69163 .41524 Mdot
.6159 .42204 Mdot
.3828 .57858 Mdot
.50554 .58488 Mdot
.57196 .43583 Mdot
.46175 .35117 Mdot
.62004 .42569 Mdot
.3063 .51632 Mdot
.57682 .69985 Mdot
.44213 .34764 Mdot
.38519 .62394 Mdot
.33174 .6513 Mdot
.40776 .62642 Mdot
.5525 .59566 Mdot
.7022 .42102 Mdot
.47119 .34493 Mdot
.46508 .33902 Mdot
.64639 .59245 Mdot
.33812 .6395 Mdot
.57115 .69085 Mdot
.60733 .46633 Mdot
.51415 .59893 Mdot
.27325 .4519 Mdot
.51939 .14094 Mdot
.67279 .63422 Mdot
.5508 .6675 Mdot
.56373 .51546 Mdot
.53014 .57958 Mdot
.63197 .40924 Mdot
.582 .70201 Mdot
.35714 .66359 Mdot
.69528 .42797 Mdot
.48682 .57559 Mdot
.31258 .67243 Mdot
.37876 .63216 Mdot
.2849 .51349 Mdot
.39588 .62519 Mdot
.58532 .69694 Mdot
.55501 .57632 Mdot
.45175 .35168 Mdot
.59988 .45137 Mdot
.52557 .59402 Mdot
.33671 .63396 Mdot
.53054 .61099 Mdot
.58771 .41931 Mdot
.40392 .3319 Mdot
.35184 .62366 Mdot
.59461 .43501 Mdot
.64379 .46052 Mdot
.57709 .20316 Mdot
.36903 .61708 Mdot
.56589 .45535 Mdot
.4603 .59237 Mdot
.3741 .63105 Mdot
.37055 .65493 Mdot
.6466 .42457 Mdot
.57883 .71833 Mdot
.62089 .44164 Mdot
.28006 .48987 Mdot
.65593 .61 Mdot
.2998 .45469 Mdot
.6594 .70801 Mdot
.63656 .44838 Mdot
.57652 .48675 Mdot
.42476 .38405 Mdot
.53282 .70589 Mdot
.70375 .68371 Mdot
.64224 .41698 Mdot
.39233 .32276 Mdot
.65465 .61737 Mdot
.6423 .64191 Mdot
.48237 .29666 Mdot
.57753 .68538 Mdot
.29859 .47499 Mdot
.58482 .45902 Mdot
.216 .37668 Mdot
.57036 .6823 Mdot
.65997 .70589 Mdot
.58406 .40827 Mdot
.43406 .33603 Mdot
.58308 .43204 Mdot
.45081 .34732 Mdot
.62253 .41765 Mdot
.57223 .2091 Mdot
.34499 .53234 Mdot
.71489 .56485 Mdot
.54988 .59102 Mdot
.34052 .44078 Mdot
.68484 .27244 Mdot
.56528 .6957 Mdot
.66919 .43245 Mdot
.53407 .57496 Mdot
.29283 .49716 Mdot
.22322 .47824 Mdot
.35651 .62897 Mdot
.27653 .49624 Mdot
.41505 .33085 Mdot
.34036 .6203 Mdot
.53044 .61413 Mdot
.56978 .48629 Mdot
.58279 .70509 Mdot
.29198 .45059 Mdot
.59338 .45146 Mdot
.65915 .41448 Mdot
.34542 .56968 Mdot
.40878 .8133 Mdot
.47398 .36764 Mdot
.57389 .17627 Mdot
.44933 .28958 Mdot
.54929 .69772 Mdot
.36148 .61511 Mdot
.60096 .42179 Mdot
.62722 .44561 Mdot
.38062 .63258 Mdot
.41203 .2969 Mdot
.56247 .73524 Mdot
.57633 .74964 Mdot
.29419 .5145 Mdot
.4612 .82848 Mdot
.44436 .34906 Mdot
.45866 .82811 Mdot
.29474 .70828 Mdot
.37717 .24629 Mdot
.69843 .68692 Mdot
.28128 .47739 Mdot
.46022 .8287 Mdot
.43306 .33247 Mdot
.60802 .40891 Mdot
.52889 .56879 Mdot
.54879 .60394 Mdot
.40211 .32507 Mdot
.36746 .64159 Mdot
.58289 .71481 Mdot
.58268 .4373 Mdot
.50163 .53598 Mdot
.38631 .32213 Mdot
.3682 .67078 Mdot
.54202 .58639 Mdot
.27657 .46419 Mdot
.61968 .42304 Mdot
.5465 .68172 Mdot
.28244 .47859 Mdot
.53742 .55593 Mdot
.70138 .57316 Mdot
.56392 .44846 Mdot
.72182 .38894 Mdot
.29858 .48288 Mdot
.56503 .51693 Mdot
.59732 .46151 Mdot
.30824 .47239 Mdot
.56339 .56843 Mdot
.32503 .41875 Mdot
.57136 .3966 Mdot
.34626 .40167 Mdot
.32298 .63242 Mdot
.38449 .61763 Mdot
.35702 .71903 Mdot
.41674 .61149 Mdot
.30562 .4958 Mdot
.52859 .5896 Mdot
.38681 .8061 Mdot
.3068 .46584 Mdot
.61008 .39852 Mdot
.58376 .45571 Mdot
.65009 .28567 Mdot
.53294 .55533 Mdot
.5505 .57368 Mdot
.36281 .31171 Mdot
.68887 .40567 Mdot
.54046 .58728 Mdot
.6028 .45853 Mdot
.43113 .30643 Mdot
.2756 .47235 Mdot
.82578 .6263 Mdot
.31946 .50263 Mdot
.7157 .41638 Mdot
.34991 .62176 Mdot
.32501 .62962 Mdot
.59867 .4494 Mdot
.4425 .57212 Mdot
.86953 .48142 Mdot
.58385 .45651 Mdot
.7149 .39029 Mdot
.65613 .70895 Mdot
.6328 .45436 Mdot
.45602 .36785 Mdot
.52373 .56223 Mdot
.45015 .32129 Mdot
.28505 .4748 Mdot
.577 .68512 Mdot
.5418 .66008 Mdot
.29819 .47556 Mdot
.63016 .43718 Mdot
.52153 .5527 Mdot
.60207 .44236 Mdot
.6063 .41175 Mdot
.6699 .61761 Mdot
.55385 .66789 Mdot
.36436 .63348 Mdot
.57185 .71368 Mdot
.41702 .30506 Mdot
.55208 .16015 Mdot
.56852 .69643 Mdot
.66279 .28336 Mdot
.65721 .60128 Mdot
.39416 .80646 Mdot
.45819 .35223 Mdot
.56471 .67419 Mdot
.30005 .4745 Mdot
.62911 .60999 Mdot
.68638 .29702 Mdot
.2743 .49541 Mdot
.60803 .4127 Mdot
.44992 .32301 Mdot
.42659 .28135 Mdot
.26352 .47254 Mdot
.44831 .35746 Mdot
.55082 .41946 Mdot
.69426 .40985 Mdot
.267 .48413 Mdot
.72022 .66595 Mdot
.2833 .45121 Mdot
.65941 .25936 Mdot
.69862 .41743 Mdot
.44037 .34564 Mdot
.69812 .27375 Mdot
.4554 .2922 Mdot
.55134 .56577 Mdot
.58187 .41796 Mdot
.5692 .69293 Mdot
.65299 .59522 Mdot
.38034 .61976 Mdot
.47751 .33577 Mdot
.44596 .33563 Mdot
.27102 .45221 Mdot
.44876 .3567 Mdot
.42676 .35706 Mdot
.31295 .45851 Mdot
.43257 .3571 Mdot
.62553 .44061 Mdot
.58935 .18004 Mdot
.4488 .36057 Mdot
.2918 .4817 Mdot
.54973 .68107 Mdot
.4639 .36386 Mdot
.29436 .63079 Mdot
.61707 .46049 Mdot
.32384 .66693 Mdot
.59013 .67908 Mdot
.43717 .30868 Mdot
.56553 .69323 Mdot
.33912 .6306 Mdot
.54709 .72608 Mdot
.267 .50528 Mdot
.26369 .49833 Mdot
.55638 .61567 Mdot
.34998 .42336 Mdot
.41387 .30359 Mdot
.34364 .6185 Mdot
.59442 .4679 Mdot
.59247 .41878 Mdot
.57154 .66141 Mdot
.40636 .3416 Mdot
.33292 .37264 Mdot
.53666 .58672 Mdot
.38455 .39939 Mdot
.26807 .47024 Mdot
.33724 .69561 Mdot
.6698 .63849 Mdot
.3152 .54812 Mdot
.51644 .56681 Mdot
.53049 .57787 Mdot
.59619 .44334 Mdot
.63972 .69969 Mdot
.58403 .69314 Mdot
.1874 .51739 Mdot
.6805 .42262 Mdot
.38464 .63528 Mdot
.62012 .41441 Mdot
.69652 .40183 Mdot
.64409 .41928 Mdot
.55293 .66535 Mdot
.29137 .50692 Mdot
.45938 .34673 Mdot
.5677 .67524 Mdot
.33169 .65225 Mdot
.73918 .53312 Mdot
.57085 .43928 Mdot
.5697 .46424 Mdot
.37239 .63607 Mdot
.4259 .30935 Mdot
.35656 .63996 Mdot
.30882 .47538 Mdot
.56946 .69944 Mdot
.69346 .42286 Mdot
.53204 .55552 Mdot
.33068 .67806 Mdot
.28432 .49766 Mdot
.36328 .61439 Mdot
.30953 .52044 Mdot
.52807 .57644 Mdot
.5694 .4695 Mdot
.39914 .65049 Mdot
.51574 .59292 Mdot
.59404 .29178 Mdot
.69912 .57058 Mdot
.445 .26017 Mdot
.36961 .64254 Mdot
.37185 .60045 Mdot
.28588 .47998 Mdot
.31773 .48555 Mdot
.65865 .2563 Mdot
.85383 .42697 Mdot
.64465 .38187 Mdot
.32211 .38669 Mdot
.30937 .47685 Mdot
.29502 .4892 Mdot
.35804 .63725 Mdot
.41113 .31318 Mdot
.44725 .38836 Mdot
.328 .63264 Mdot
.68217 .6939 Mdot
.42668 .32939 Mdot
.71919 .32995 Mdot
.35114 .67579 Mdot
.71153 .40875 Mdot
.57057 .21577 Mdot
.54162 .69089 Mdot
.65219 .70039 Mdot
.32709 .50129 Mdot
.59244 .43168 Mdot
.19924 .37484 Mdot
.35305 .63005 Mdot
.52523 .60686 Mdot
.2647 .42798 Mdot
.65722 .40772 Mdot
.62109 .41256 Mdot
.62271 .43289 Mdot
.58825 .68614 Mdot
.57646 .25264 Mdot
.59534 .42735 Mdot
.70612 .56706 Mdot
.7268 .40271 Mdot
.3096 .64144 Mdot
.57253 .71256 Mdot
.62168 .68429 Mdot
.31235 .59499 Mdot
.374 .39965 Mdot
.60426 .39341 Mdot
.31322 .50544 Mdot
.69432 .40151 Mdot
.2855 .46687 Mdot
.26438 .4905 Mdot
.48291 .83797 Mdot
.46407 .34776 Mdot
.68324 .42123 Mdot
.37278 .66442 Mdot
.44573 .38876 Mdot
.70119 .40008 Mdot
.56053 .16543 Mdot
.28514 .4404 Mdot
.86298 .37852 Mdot
.31651 .48289 Mdot
.53855 .61091 Mdot
.41734 .33801 Mdot
.39111 .32483 Mdot
.66322 .60512 Mdot
.41776 .30862 Mdot
.4158 .60533 Mdot
.47181 .34833 Mdot
.60144 .79616 Mdot
.47129 .29098 Mdot
.28643 .4853 Mdot
.26482 .4664 Mdot
.71604 .39847 Mdot
.62016 .44604 Mdot
.69168 .62406 Mdot
.53754 .58642 Mdot
.56855 .43152 Mdot
.35613 .65471 Mdot
.28884 .65782 Mdot
.20404 .46046 Mdot
.4291 .35519 Mdot
.29197 .50035 Mdot
.61961 .41319 Mdot
.69586 .41802 Mdot
.59525 .41122 Mdot
.33271 .54878 Mdot
.73719 .33563 Mdot
.61028 .43848 Mdot
.71341 .39939 Mdot
.33616 .62577 Mdot
.34786 .57065 Mdot
.35872 .24842 Mdot
.47299 .83318 Mdot
.63647 .43812 Mdot
.5474 .70177 Mdot
.55837 .66651 Mdot
.67935 .40227 Mdot
.52818 .47148 Mdot
.58296 .557 Mdot
.59257 .45106 Mdot
.74011 .52673 Mdot
.31739 .65394 Mdot
.55898 .57107 Mdot
.33616 .63609 Mdot
.42942 .36667 Mdot
.55329 .55986 Mdot
.35888 .65908 Mdot
.71746 .58629 Mdot
.52339 .58475 Mdot
.31747 .41927 Mdot
.56141 .67453 Mdot
.60113 .45986 Mdot
.62685 .25404 Mdot
.37629 .6696 Mdot
.28333 .49023 Mdot
.42502 .34679 Mdot
.26917 .47697 Mdot
.4154 .62541 Mdot
.67139 .70281 Mdot
.54786 .56267 Mdot
.31248 .50767 Mdot
.71028 .39 Mdot
.54694 .70698 Mdot
.31355 .474 Mdot
.71946 .41048 Mdot
.67545 .40272 Mdot
.85413 .46723 Mdot
.59187 .47024 Mdot
.28843 .66721 Mdot
.30131 .4547 Mdot
.55934 .56555 Mdot
.60132 .45114 Mdot
.33794 .67256 Mdot
.56818 .56641 Mdot
.6017 .44079 Mdot
.39142 .63149 Mdot
.58666 .45639 Mdot
.57941 .70564 Mdot
.45775 .32667 Mdot
.65249 .62116 Mdot
.56265 .75583 Mdot
.5747 .68206 Mdot
.70841 .54913 Mdot
.57524 .42604 Mdot
.42485 .61348 Mdot
.43258 .33778 Mdot
.63621 .40435 Mdot
.60959 .77185 Mdot
.40709 .32304 Mdot
.42012 .3327 Mdot
.70581 .42317 Mdot
.312 .51548 Mdot
.3679 .6346 Mdot
.55355 .71791 Mdot
.30337 .57254 Mdot
.59502 .43172 Mdot
.67233 .43039 Mdot
.56907 .67911 Mdot
.27521 .48223 Mdot
.68604 .41796 Mdot
.29667 .40988 Mdot
.69574 .59202 Mdot
.30553 .45327 Mdot
.61166 .39213 Mdot
.7354 .32462 Mdot
.40106 .29847 Mdot
.19924 .37729 Mdot
.34539 .53181 Mdot
.32842 .65183 Mdot
.54014 .58936 Mdot
.52562 .14508 Mdot
.55125 .6777 Mdot
.48681 .38384 Mdot
.58936 .41913 Mdot
.60809 .41989 Mdot
.42286 .3005 Mdot
.57391 .45742 Mdot
.42835 .35587 Mdot
.29625 .62616 Mdot
.85633 .41621 Mdot
.4554 .35007 Mdot
.44431 .33896 Mdot
.73153 .37818 Mdot
.38991 .66455 Mdot
.40879 .33186 Mdot
.58959 .46364 Mdot
.4159 .62392 Mdot
.5088 .53539 Mdot
.55924 .73414 Mdot
.59023 .69685 Mdot
.458 .36962 Mdot
.69053 .29799 Mdot
.71885 .40796 Mdot
.64583 .32274 Mdot
.58597 .56936 Mdot
.3071 .49519 Mdot
.65427 .4294 Mdot
.53464 .58326 Mdot
.34288 .63089 Mdot
.62312 .467 Mdot
.6053 .45888 Mdot
.45763 .34066 Mdot
.5421 .7136 Mdot
.30243 .46267 Mdot
.51714 .59553 Mdot
.40936 .62114 Mdot
.55713 .68737 Mdot
.42436 .35695 Mdot
.6783 .26744 Mdot
.51191 .56634 Mdot
.51403 .5972 Mdot
.63509 .40873 Mdot
.64523 .4267 Mdot
.51554 .56492 Mdot
.29619 .47486 Mdot
.32734 .65383 Mdot
.53008 .60452 Mdot
.63273 .59007 Mdot
.70108 .61322 Mdot
.63968 .41666 Mdot
.46436 .3589 Mdot
.29238 .49854 Mdot
.5507 .56877 Mdot
.37948 .80171 Mdot
.617 .46365 Mdot
.72203 .33047 Mdot
.58016 .73282 Mdot
.53098 .5853 Mdot
.44831 .38854 Mdot
.56404 .71902 Mdot
.69819 .41736 Mdot
.70928 .56687 Mdot
.57397 .42082 Mdot
.63127 .39004 Mdot
.36078 .66297 Mdot
.29397 .46322 Mdot
.55283 .61906 Mdot
.34155 .63593 Mdot
.42119 .33545 Mdot
.64917 .32704 Mdot
.45374 .32863 Mdot
.46718 .34289 Mdot
.46184 .32188 Mdot
.26984 .47124 Mdot
.52498 .14417 Mdot
.51128 .57112 Mdot
.57892 .43761 Mdot
.30138 .50465 Mdot
.41234 .33876 Mdot
.58744 .40837 Mdot
.4249 .3538 Mdot
.41387 .35005 Mdot
.57112 .42448 Mdot
.71021 .40424 Mdot
.71118 .56123 Mdot
.719 .31991 Mdot
.57316 .71608 Mdot
.41059 .29924 Mdot
.70555 .31106 Mdot
.60043 .42321 Mdot
.61443 .45386 Mdot
.71687 .39671 Mdot
.57378 .67752 Mdot
.6512 .33505 Mdot
.59368 .41678 Mdot
.63741 .70382 Mdot
.59472 .40448 Mdot
.40521 .34082 Mdot
.33232 .4309 Mdot
.71741 .41499 Mdot
.33784 .62264 Mdot
.4132 .29685 Mdot
.54132 .69158 Mdot
.39056 .2917 Mdot
.63614 .46565 Mdot
.30227 .48672 Mdot
.4402 .33381 Mdot
.32462 .63875 Mdot
.28046 .48667 Mdot
.28308 .45146 Mdot
.71855 .39604 Mdot
.33167 .66233 Mdot
.54164 .71189 Mdot
.28809 .45507 Mdot
.60302 .48685 Mdot
.28566 .48635 Mdot
.51832 .3452 Mdot
.5717 .46805 Mdot
.70681 .56856 Mdot
.53834 .59887 Mdot
.55718 .60794 Mdot
.29566 .45374 Mdot
.56279 .68042 Mdot
.68549 .41821 Mdot
.44396 .36119 Mdot
.54766 .68761 Mdot
.57151 .22032 Mdot
.32705 .62799 Mdot
.42825 .28221 Mdot
.30865 .56471 Mdot
.40513 .30893 Mdot
.65482 .70133 Mdot
.5445 .67791 Mdot
.51505 .60335 Mdot
.66094 .62604 Mdot
.54481 .58225 Mdot
.61451 .47066 Mdot
.68454 .41856 Mdot
.62685 .4387 Mdot
.35083 .62112 Mdot
.58866 .68979 Mdot
.45588 .36153 Mdot
.47479 .58201 Mdot
.2725 .47903 Mdot
.67619 .39491 Mdot
.52808 .60658 Mdot
.69083 .41697 Mdot
.41868 .34587 Mdot
.39465 .32134 Mdot
.57589 .24097 Mdot
.37251 .62867 Mdot
.49218 .60439 Mdot
.63903 .41791 Mdot
.47627 .56079 Mdot
.29576 .45317 Mdot
.34674 .40354 Mdot
.32043 .66477 Mdot
.86177 .37605 Mdot
.34057 .63889 Mdot
.49408 .56152 Mdot
.39741 .31614 Mdot
.56407 .70823 Mdot
.63191 .43786 Mdot
.46267 .32963 Mdot
.45549 .38932 Mdot
.55904 .64971 Mdot
.56653 .71526 Mdot
.32856 .54033 Mdot
.30825 .49852 Mdot
.51403 .59136 Mdot
.59761 .40296 Mdot
.58266 .41101 Mdot
.59012 .4666 Mdot
.29679 .50222 Mdot
.7016 .40644 Mdot
.33958 .44258 Mdot
.65795 .44293 Mdot
.61089 .77194 Mdot
.37586 .65139 Mdot
.21804 .66383 Mdot
.43955 .31156 Mdot
.65095 .33245 Mdot
.51983 .36843 Mdot
.69761 .57438 Mdot
.29167 .5088 Mdot
.56312 .56462 Mdot
.36261 .63634 Mdot
.21888 .49284 Mdot
.37624 .65279 Mdot
.85607 .56134 Mdot
.64878 .285 Mdot
.32865 .4262 Mdot
.57307 .42503 Mdot
.35491 .66766 Mdot
.6966 .29913 Mdot
.52936 .60323 Mdot
.5225 .55194 Mdot
.6634 .44213 Mdot
.58697 .20536 Mdot
.5749 .71439 Mdot
.63398 .4349 Mdot
.44689 .31906 Mdot
.63028 .44063 Mdot
.63237 .43863 Mdot
.5923 .41525 Mdot
.30718 .4498 Mdot
.56851 .46705 Mdot
.62262 .4438 Mdot
.31324 .74743 Mdot
.54926 .53348 Mdot
.39764 .62478 Mdot
.38785 .3163 Mdot
.54589 .70592 Mdot
.42778 .3655 Mdot
.65575 .62353 Mdot
.31841 .48224 Mdot
.57476 .24336 Mdot
.70122 .41181 Mdot
.48201 .35351 Mdot
.31839 .50243 Mdot
.57416 .72426 Mdot
.53449 .57968 Mdot
.28015 .29259 Mdot
.37818 .67447 Mdot
.54416 .57074 Mdot
.38543 .62638 Mdot
.58455 .48728 Mdot
.44947 .35216 Mdot
.54405 .58253 Mdot
.29682 .45978 Mdot
.37062 .6606 Mdot
.70983 .55216 Mdot
.61639 .42845 Mdot
.36989 .64618 Mdot
.52738 .59297 Mdot
.65398 .59591 Mdot
.65547 .61621 Mdot
.35755 .66792 Mdot
.27758 .50622 Mdot
.27886 .45648 Mdot
.54435 .69584 Mdot
.39468 .31231 Mdot
.43201 .31577 Mdot
.27416 .4768 Mdot
.22196 .50238 Mdot
.59389 .43422 Mdot
.60828 .43265 Mdot
.66296 .6343 Mdot
.62674 .39895 Mdot
.41101 .59413 Mdot
.54361 .57363 Mdot
.4446 .32871 Mdot
.68449 .41822 Mdot
.68164 .41634 Mdot
.63496 .43103 Mdot
.68433 .69552 Mdot
.34849 .62323 Mdot
.72057 .40467 Mdot
.58242 .70106 Mdot
.58204 .20838 Mdot
.60774 .4632 Mdot
.54526 .73804 Mdot
.39655 .31329 Mdot
.23771 .43818 Mdot
.28484 .49112 Mdot
.37584 .66417 Mdot
.3737 .66463 Mdot
.52782 .79963 Mdot
.43493 .30816 Mdot
.54459 .57181 Mdot
.31132 .67078 Mdot
.55501 .58536 Mdot
.56314 .71605 Mdot
.57628 .3908 Mdot
.41293 .59713 Mdot
.39729 .62496 Mdot
.31097 .52682 Mdot
.65492 .40937 Mdot
.61081 .46072 Mdot
.34481 .39064 Mdot
.60422 .45561 Mdot
.57349 .69503 Mdot
.31341 .48704 Mdot
.43868 .33376 Mdot
.57367 .71895 Mdot
.31571 .50201 Mdot
.42123 .30814 Mdot
.71823 .40109 Mdot
.59047 .40637 Mdot
.42198 .34031 Mdot
.41685 .35011 Mdot
.58836 .43783 Mdot
.50088 .8455 Mdot
.45593 .34097 Mdot
.42166 .34352 Mdot
.58305 .2082 Mdot
.40074 .64517 Mdot
.56718 .563 Mdot
.30951 .51484 Mdot
.62286 .43978 Mdot
.37765 .64601 Mdot
.5567 .70987 Mdot
.44281 .33141 Mdot
.64279 .42908 Mdot
.59846 .43063 Mdot
.54685 .70388 Mdot
.58518 .68716 Mdot
.55591 .68033 Mdot
.26345 .47346 Mdot
.70686 .4111 Mdot
.41392 .33699 Mdot
.28166 .50136 Mdot
.54754 .67768 Mdot
.58676 .69474 Mdot
.64204 .77177 Mdot
.59116 .43569 Mdot
.58375 .68183 Mdot
.54378 .15548 Mdot
.72408 .57689 Mdot
.55712 .57619 Mdot
.38069 .61234 Mdot
.4125 .61825 Mdot
.52024 .53512 Mdot
.29643 .46528 Mdot
.70361 .3944 Mdot
.56243 .73251 Mdot
.52605 .59744 Mdot
.61202 .43095 Mdot
.64101 .44637 Mdot
.54835 .6903 Mdot
.6705 .70476 Mdot
.45715 .33737 Mdot
.41616 .25049 Mdot
.54656 .70825 Mdot
.35466 .67015 Mdot
.31727 .66196 Mdot
.34567 .64133 Mdot
.64106 .42078 Mdot
.72858 .35433 Mdot
.54968 .48551 Mdot
.58158 .34283 Mdot
.30965 .4946 Mdot
.39667 .32594 Mdot
.58108 .20196 Mdot
.41952 .33026 Mdot
.36856 .6222 Mdot
.56354 .68063 Mdot
.42584 .30359 Mdot
.2704 .46238 Mdot
.28523 .45295 Mdot
.39843 .65102 Mdot
.33677 .64109 Mdot
.35415 .64602 Mdot
.41059 .2937 Mdot
.40199 .32807 Mdot
.57798 .41839 Mdot
.46139 .35806 Mdot
.29835 .62406 Mdot
.29843 .62109 Mdot
.38586 .66403 Mdot
.29213 .47679 Mdot
.42167 .31556 Mdot
.59059 .46141 Mdot
.69407 .54639 Mdot
.31999 .67467 Mdot
.54348 .71047 Mdot
.58872 .17954 Mdot
.85199 .43428 Mdot
.67139 .4268 Mdot
.30521 .49061 Mdot
.55253 .58371 Mdot
.62596 .4308 Mdot
.32709 .65062 Mdot
.49895 .59106 Mdot
.52665 .56072 Mdot
.5766 .46593 Mdot
.56088 .44049 Mdot
.29603 .49559 Mdot
.65359 .62572 Mdot
.52431 .59842 Mdot
.73102 .39471 Mdot
.31188 .49897 Mdot
.33538 .6779 Mdot
.33468 .7207 Mdot
.35686 .34435 Mdot
.60117 .63823 Mdot
.54298 .55642 Mdot
.61204 .46692 Mdot
.35266 .65734 Mdot
.57545 .71925 Mdot
.35049 .65379 Mdot
.43521 .36793 Mdot
.40289 .64227 Mdot
.59083 .45896 Mdot
.41109 .33244 Mdot
.28456 .4523 Mdot
.62282 .60818 Mdot
.52745 .63796 Mdot
.34022 .67393 Mdot
.51168 .5975 Mdot
.68936 .40621 Mdot
.57476 .49086 Mdot
.55784 .60649 Mdot
.60298 .46139 Mdot
.28385 .4681 Mdot
.4247 .35207 Mdot
.27505 .48856 Mdot
.56855 .57387 Mdot
.50747 .36727 Mdot
.28643 .49242 Mdot
.72866 .36122 Mdot
.58355 .71394 Mdot
.6755 .7012 Mdot
.58879 .45233 Mdot
.29467 .46034 Mdot
.57071 .46403 Mdot
.41345 .29927 Mdot
.70903 .59719 Mdot
.69643 .58717 Mdot
.27628 .47102 Mdot
.53882 .61575 Mdot
.65604 .6002 Mdot
.56725 .56184 Mdot
.30896 .47765 Mdot
.73088 .5694 Mdot
.53756 .56793 Mdot
.55663 .69172 Mdot
.58791 .69623 Mdot
.56191 .68726 Mdot
.61204 .43658 Mdot
.72474 .30527 Mdot
.5524 .67146 Mdot
.22694 .46906 Mdot
.57769 .69406 Mdot
.52159 .53213 Mdot
.33405 .36951 Mdot
.58509 .69774 Mdot
.59667 .4549 Mdot
.6628 .43599 Mdot
.70863 .39235 Mdot
.32216 .65329 Mdot
.26128 .31243 Mdot
.31094 .74397 Mdot
.60103 .42139 Mdot
.58066 .19205 Mdot
.4666 .33662 Mdot
.51396 .60369 Mdot
.69698 .58329 Mdot
.72498 .38753 Mdot
.41566 .32575 Mdot
.65802 .62589 Mdot
.42284 .28488 Mdot
.54447 .60041 Mdot
.6077 .43596 Mdot
.41436 .29678 Mdot
.47691 .33453 Mdot
.70499 .68241 Mdot
.36898 .39463 Mdot
.42269 .31247 Mdot
.30836 .47039 Mdot
.29834 .46892 Mdot
.28107 .4684 Mdot
.33338 .64653 Mdot
.44538 .33818 Mdot
.66895 .40132 Mdot
.32891 .64925 Mdot
.60394 .41368 Mdot
.27475 .47336 Mdot
.70015 .58033 Mdot
.44317 .33815 Mdot
.59031 .45019 Mdot
.69682 .30543 Mdot
.39166 .63554 Mdot
.54676 .6998 Mdot
.58218 .18726 Mdot
.36656 .61294 Mdot
.29189 .51702 Mdot
.44559 .37189 Mdot
.54936 .53531 Mdot
.72976 .39314 Mdot
.64348 .41273 Mdot
.57599 .43595 Mdot
.73053 .39135 Mdot
.65086 .28136 Mdot
.51696 .57355 Mdot
.33181 .65192 Mdot
.40223 .64011 Mdot
.61394 .46349 Mdot
.45019 .34161 Mdot
.54257 .67379 Mdot
.55139 .73805 Mdot
.48583 .581 Mdot
.659 .60828 Mdot
.70589 .56737 Mdot
.6369 .39757 Mdot
.67023 .3501 Mdot
.32378 .64385 Mdot
.55672 .58696 Mdot
.66372 .61206 Mdot
.56257 .69569 Mdot
.60637 .40978 Mdot
.39605 .34332 Mdot
.43936 .32997 Mdot
.36939 .64057 Mdot
.28667 .44459 Mdot
.5138 .56272 Mdot
.38679 .66374 Mdot
.61449 .46318 Mdot
.68288 .41683 Mdot
.30891 .46609 Mdot
.44527 .37009 Mdot
.55229 .6915 Mdot
.32917 .64418 Mdot
.56412 .70427 Mdot
.44548 .3557 Mdot
.44266 .33061 Mdot
.61777 .40489 Mdot
.48669 .59727 Mdot
.34212 .67555 Mdot
.63934 .42756 Mdot
.36555 .65013 Mdot
.34426 .56951 Mdot
.27159 .4541 Mdot
.63198 .40366 Mdot
.43239 .38632 Mdot
.27369 .47071 Mdot
.60476 .4178 Mdot
.71561 .39228 Mdot
.68676 .41717 Mdot
.35293 .66851 Mdot
.56037 .7399 Mdot
.55821 .69693 Mdot
.52781 .36709 Mdot
.56874 .23088 Mdot
.64589 .40125 Mdot
.38142 .66505 Mdot
.65637 .45106 Mdot
.2967 .49171 Mdot
.40069 .3122 Mdot
.1762 .6018 Mdot
.29137 .48368 Mdot
.58528 .45308 Mdot
.56927 .69618 Mdot
.41675 .35152 Mdot
.55595 .56339 Mdot
.66523 .66118 Mdot
.54593 .61801 Mdot
.48458 .59035 Mdot
.51574 .58601 Mdot
.32601 .38508 Mdot
.35366 .64857 Mdot
.41582 .34262 Mdot
.30676 .48661 Mdot
.3002 .48943 Mdot
.38024 .62384 Mdot
.5732 .22364 Mdot
.37218 .2467 Mdot
.54063 .14899 Mdot
.35815 .68404 Mdot
.56918 .68613 Mdot
.71019 .5938 Mdot
.34657 .6398 Mdot
.38308 .61973 Mdot
.33615 .55006 Mdot
.34538 .39278 Mdot
.41465 .31506 Mdot
.59916 .42902 Mdot
.57631 .20326 Mdot
.58354 .42554 Mdot
.60114 .63318 Mdot
.27604 .47705 Mdot
.40083 .31178 Mdot
.35797 .48439 Mdot
.63568 .44681 Mdot
.62696 .4189 Mdot
.29241 .641 Mdot
.53858 .58316 Mdot
.41651 .81335 Mdot
.58701 .41616 Mdot
.3386 .6511 Mdot
.39016 .3752 Mdot
.5398 .60215 Mdot
.69883 .30534 Mdot
.30391 .45708 Mdot
.54894 .56464 Mdot
.53848 .60369 Mdot
.67684 .35359 Mdot
.43714 .28475 Mdot
.43273 .31289 Mdot
.57846 .67744 Mdot
.34365 .35788 Mdot
.30893 .46016 Mdot
.30882 .40202 Mdot
.59284 .46316 Mdot
.2602 .48558 Mdot
.57632 .74896 Mdot
.60086 .41878 Mdot
.70466 .39881 Mdot
.57515 .24106 Mdot
.65673 .42487 Mdot
.62273 .47549 Mdot
.28775 .48095 Mdot
.61807 .7618 Mdot
.63563 .39304 Mdot
.36943 .64428 Mdot
.40977 .31345 Mdot
.44117 .28322 Mdot
.56432 .72605 Mdot
.35187 .5227 Mdot
.85961 .39915 Mdot
.40145 .3119 Mdot
.61639 .43061 Mdot
.2948 .49065 Mdot
.55283 .56346 Mdot
.53978 .59672 Mdot
.52944 .6179 Mdot
.43408 .32607 Mdot
.53731 .60204 Mdot
.48347 .38628 Mdot
.65685 .62541 Mdot
.65007 .33104 Mdot
.27853 .46507 Mdot
.56992 .68916 Mdot
.49539 .55045 Mdot
.33376 .56728 Mdot
.60462 .39988 Mdot
.60105 .63469 Mdot
.448 .31094 Mdot
.57202 .69219 Mdot
.62974 .43346 Mdot
.51368 .58146 Mdot
.74284 .51541 Mdot
.53655 .70731 Mdot
.51608 .58156 Mdot
.6809 .42787 Mdot
.41506 .30411 Mdot
.5467 .57281 Mdot
.43445 .33108 Mdot
.63163 .43311 Mdot
.5906 .57549 Mdot
.40777 .30157 Mdot
.24948 .32677 Mdot
.50825 .5752 Mdot
.31755 .49384 Mdot
.62859 .46587 Mdot
.63657 .43857 Mdot
.72466 .34183 Mdot
.55356 .56915 Mdot
.20814 .37554 Mdot
.37011 .65195 Mdot
.39797 .81283 Mdot
.41302 .63231 Mdot
.32919 .54753 Mdot
.27168 .41703 Mdot
.64519 .43263 Mdot
.57404 .22392 Mdot
.72772 .35011 Mdot
.28356 .50887 Mdot
.72871 .34636 Mdot
.62026 .44588 Mdot
.63444 .40902 Mdot
.36669 .64947 Mdot
.26986 .44391 Mdot
.71091 .42007 Mdot
.66313 .61112 Mdot
.5727 .72628 Mdot
.43215 .34408 Mdot
.61628 .44237 Mdot
.48802 .34718 Mdot
.36014 .66917 Mdot
.44215 .25762 Mdot
.59499 .45281 Mdot
.5385 .5827 Mdot
.26067 .48028 Mdot
.28832 .45099 Mdot
.34153 .66811 Mdot
.33969 .66942 Mdot
.63598 .4392 Mdot
.27262 .49112 Mdot
.60361 .39769 Mdot
.65549 .59914 Mdot
.52547 .59186 Mdot
.55671 .71546 Mdot
.57556 .45581 Mdot
.38808 .24663 Mdot
.71179 .74253 Mdot
.64066 .42016 Mdot
.44935 .32338 Mdot
.35805 .64393 Mdot
.36306 .61896 Mdot
.4316 .31605 Mdot
.36462 .61911 Mdot
.41658 .24938 Mdot
.72628 .30788 Mdot
.56504 .71349 Mdot
.62925 .47829 Mdot
.57667 .6852 Mdot
.55068 .56684 Mdot
.5902 .4368 Mdot
.19747 .50189 Mdot
.36085 .68271 Mdot
.68465 .50622 Mdot
.2784 .48267 Mdot
.55029 .60155 Mdot
.7028 .40788 Mdot
.58706 .67302 Mdot
.34865 .63024 Mdot
.52831 .54951 Mdot
.59842 .41152 Mdot
.41055 .29546 Mdot
.67656 .43136 Mdot
.54119 .60735 Mdot
.55162 .57546 Mdot
.53207 .54985 Mdot
.31568 .50214 Mdot
.43766 .35964 Mdot
.32878 .54048 Mdot
.39171 .64255 Mdot
.56701 .43462 Mdot
.61912 .4303 Mdot
.39606 .32217 Mdot
.57769 .44315 Mdot
.26882 .48761 Mdot
.50127 .13348 Mdot
.56058 .6781 Mdot
.55557 .5681 Mdot
.27852 .3328 Mdot
.53724 .54775 Mdot
.68883 .42584 Mdot
.72462 .38342 Mdot
.38683 .3229 Mdot
.31546 .50652 Mdot
.57776 .40796 Mdot
.40309 .62769 Mdot
.55353 .69268 Mdot
.27046 .46089 Mdot
.69053 .40913 Mdot
.59377 .45736 Mdot
.57033 .69165 Mdot
.3577 .47348 Mdot
.57086 .73349 Mdot
.30844 .48672 Mdot
.55532 .60027 Mdot
.69849 .54108 Mdot
.597 .44189 Mdot
.54112 .57592 Mdot
.43572 .35471 Mdot
.30574 .49872 Mdot
.57805 .25534 Mdot
.54208 .60282 Mdot
.3033 .57079 Mdot
.29361 .45112 Mdot
.64274 .41017 Mdot
.42688 .298 Mdot
.45413 .28318 Mdot
.42711 .35212 Mdot
.55953 .79915 Mdot
.30469 .587 Mdot
.35786 .64726 Mdot
.29294 .47837 Mdot
.37961 .64113 Mdot
.58447 .71278 Mdot
.6989 .61119 Mdot
.34013 .67173 Mdot
.46968 .36203 Mdot
.37955 .64946 Mdot
.5986 .39976 Mdot
.31847 .4931 Mdot
.34877 .67678 Mdot
.58193 .46233 Mdot
.71992 .40004 Mdot
.5491 .58097 Mdot
.54237 .67679 Mdot
.6586 .61766 Mdot
.58285 .44409 Mdot
.53679 .57511 Mdot
.59152 .44777 Mdot
.26918 .48767 Mdot
.6174 .60701 Mdot
.56343 .44062 Mdot
.35689 .68423 Mdot
.29794 .27468 Mdot
.39704 .64868 Mdot
.46182 .59179 Mdot
.59957 .41663 Mdot
.59445 .44059 Mdot
.69796 .40592 Mdot
.59999 .19147 Mdot
.27346 .50495 Mdot
.56999 .47073 Mdot
.34755 .61821 Mdot
.41885 .32337 Mdot
.43335 .30804 Mdot
.64916 .37938 Mdot
.54197 .57261 Mdot
.26462 .47698 Mdot
.59395 .43787 Mdot
.55024 .59781 Mdot
.6813 .6214 Mdot
.34196 .36842 Mdot
.30667 .60512 Mdot
.39054 .62706 Mdot
.39606 .30106 Mdot
.34478 .62295 Mdot
.69485 .40875 Mdot
.54192 .59943 Mdot
.30295 .58545 Mdot
.27851 .53407 Mdot
.5537 .69426 Mdot
.62236 .40987 Mdot
.69041 .69265 Mdot
.33565 .62632 Mdot
.32972 .65939 Mdot
.60026 .39878 Mdot
.37607 .37906 Mdot
.68704 .7547 Mdot
.2969 .50606 Mdot
.50761 .32726 Mdot
.64225 .25313 Mdot
.8135 .56401 Mdot
.30041 .47777 Mdot
.70101 .39954 Mdot
.32004 .644 Mdot
.47411 .8035 Mdot
.41756 .32641 Mdot
.55246 .69359 Mdot
.57977 .46081 Mdot
.46892 .35597 Mdot
.35763 .68491 Mdot
.44341 .36471 Mdot
.53923 .58822 Mdot
.31879 .49893 Mdot
.34384 .62867 Mdot
.29057 .44313 Mdot
.42439 .38316 Mdot
.56685 .68183 Mdot
.63411 .6938 Mdot
.64602 .45748 Mdot
.57439 .23876 Mdot
.70903 .40904 Mdot
.54854 .53224 Mdot
.71588 .40531 Mdot
.44716 .2848 Mdot
.58954 .45314 Mdot
.61579 .39164 Mdot
.32389 .63087 Mdot
.64156 .41558 Mdot
.58883 .46281 Mdot
.69958 .30768 Mdot
.61472 .41255 Mdot
.63486 .43518 Mdot
.64527 .41264 Mdot
.45395 .33032 Mdot
.60682 .40643 Mdot
.4129 .34399 Mdot
.48489 .35776 Mdot
.39184 .64077 Mdot
.58615 .70236 Mdot
.58504 .69568 Mdot
.59639 .58359 Mdot
.68884 .69324 Mdot
.57785 .20349 Mdot
.42418 .32621 Mdot
.29346 .45253 Mdot
.58105 .41386 Mdot
.65237 .77091 Mdot
.59131 .57662 Mdot
.32157 .65777 Mdot
.36332 .67013 Mdot
.58732 .46736 Mdot
.85 .44252 Mdot
.58448 .41753 Mdot
.67162 .63497 Mdot
.61243 .43763 Mdot
.63207 .40269 Mdot
.40712 .62733 Mdot
.65428 .70199 Mdot
.72184 .40442 Mdot
.43935 .28932 Mdot
.55283 .69888 Mdot
.54571 .57573 Mdot
.59311 .58127 Mdot
.66806 .26165 Mdot
.36707 .30428 Mdot
.69747 .40573 Mdot
.32814 .64246 Mdot
.44222 .328 Mdot
.66367 .63256 Mdot
.2844 .50281 Mdot
.66759 .66282 Mdot
.52017 .34193 Mdot
.29665 .50755 Mdot
.55583 .6913 Mdot
.32298 .67538 Mdot
.63383 .42232 Mdot
.34992 .65963 Mdot
.63766 .4437 Mdot
.68159 .63435 Mdot
.56082 .71499 Mdot
.47485 .35634 Mdot
.30977 .47126 Mdot
.46067 .33951 Mdot
.44924 .262 Mdot
.59213 .58846 Mdot
.35311 .78382 Mdot
.39071 .65906 Mdot
.46985 .57486 Mdot
.40253 .32429 Mdot
.61862 .46289 Mdot
.53616 .15112 Mdot
.44391 .3503 Mdot
.41168 .29642 Mdot
.6481 .65347 Mdot
.65886 .71274 Mdot
.64596 .42026 Mdot
.46555 .35971 Mdot
.32479 .67793 Mdot
.5706 .71237 Mdot
.59505 .46523 Mdot
.54693 .59397 Mdot
.42469 .30211 Mdot
.35854 .62388 Mdot
.64833 .69907 Mdot
.33648 .6463 Mdot
.41249 .31933 Mdot
.37809 .66409 Mdot
.33457 .5216 Mdot
.34059 .67221 Mdot
.57479 .45069 Mdot
.59456 .43874 Mdot
.46574 .28798 Mdot
.44292 .33085 Mdot
.68921 .42573 Mdot
.58189 .43161 Mdot
.41019 .3346 Mdot
.31977 .68011 Mdot
.37617 .29514 Mdot
.68499 .42045 Mdot
.59588 .43191 Mdot
.56868 .67604 Mdot
.63778 .5922 Mdot
.63711 .62931 Mdot
.58162 .41434 Mdot
.56643 .68447 Mdot
.40637 .29557 Mdot
.58836 .44223 Mdot
.65417 .70831 Mdot
.31669 .63907 Mdot
.64734 .39615 Mdot
.5518 .56036 Mdot
.70879 .41597 Mdot
.73435 .64699 Mdot
.69374 .40637 Mdot
.41619 .33324 Mdot
.40802 .32178 Mdot
.31336 .65018 Mdot
.42437 .34176 Mdot
.55476 .56802 Mdot
.27325 .46471 Mdot
.51625 .32057 Mdot
.55457 .59383 Mdot
.52278 .56038 Mdot
.51109 .57153 Mdot
.52183 .60324 Mdot
.55066 .74657 Mdot
.31015 .5967 Mdot
.53435 .558 Mdot
.41543 .34488 Mdot
.51874 .47152 Mdot
.56487 .57029 Mdot
.264 .47965 Mdot
.53732 .60345 Mdot
.6477 .39653 Mdot
.69998 .40307 Mdot
.39789 .33722 Mdot
.28142 .50203 Mdot
.56031 .60678 Mdot
.59402 .46536 Mdot
.39005 .33056 Mdot
.61721 .4437 Mdot
.54814 .72492 Mdot
.44091 .33734 Mdot
.33207 .6417 Mdot
.55829 .7174 Mdot
.51948 .59438 Mdot
.54589 .69599 Mdot
.35709 .65624 Mdot
.29073 .45683 Mdot
.57824 .45492 Mdot
.54946 .73143 Mdot
.58498 .70474 Mdot
.64695 .44281 Mdot
.40626 .31738 Mdot
.53414 .62412 Mdot
.58838 .43463 Mdot
.70497 .40476 Mdot
.43244 .31571 Mdot
.19639 .38045 Mdot
.63362 .41791 Mdot
.7311 .39565 Mdot
.44903 .29174 Mdot
.54669 .60416 Mdot
.33092 .6464 Mdot
.64186 .43134 Mdot
.27904 .49003 Mdot
.27368 .47669 Mdot
.36302 .6811 Mdot
.42961 .30872 Mdot
.35565 .62182 Mdot
.62482 .46243 Mdot
.53375 .60408 Mdot
.60987 .45935 Mdot
.28994 .67716 Mdot
.2253 .3488 Mdot
.42133 .35518 Mdot
.39357 .64107 Mdot
.68737 .61179 Mdot
.31113 .51588 Mdot
.32995 .69223 Mdot
.44206 .28884 Mdot
.46589 .35427 Mdot
.42837 .31388 Mdot
.58332 .69874 Mdot
.33875 .63879 Mdot
.39182 .31875 Mdot
.39354 .32361 Mdot
.68872 .41357 Mdot
.58582 .46514 Mdot
.4015 .2982 Mdot
.33096 .56613 Mdot
.55691 .69759 Mdot
.35858 .61546 Mdot
.6932 .75298 Mdot
.30259 .50324 Mdot
.70053 .30616 Mdot
.60027 .40087 Mdot
.86143 .37103 Mdot
.58392 .41869 Mdot
.61669 .43552 Mdot
.42941 .36666 Mdot
.58847 .71067 Mdot
.57269 .70717 Mdot
.40308 .32368 Mdot
.42997 .36226 Mdot
.55511 .72655 Mdot
.6489 .57031 Mdot
.72217 .66644 Mdot
.67451 .61961 Mdot
.4457 .36342 Mdot
.51539 .35154 Mdot
.28333 .47238 Mdot
.46335 .33322 Mdot
.34741 .46715 Mdot
.36896 .67289 Mdot
.34229 .6737 Mdot
.30487 .46108 Mdot
.63227 .4222 Mdot
.40788 .62919 Mdot
.71519 .40977 Mdot
.33432 .42671 Mdot
.69349 .40232 Mdot
.51565 .84948 Mdot
.57645 .44777 Mdot
.44462 .56657 Mdot
.33107 .37789 Mdot
.69603 .42408 Mdot
.70688 .28461 Mdot
.55092 .68945 Mdot
.43967 .28158 Mdot
.26969 .49301 Mdot
.57532 .20276 Mdot
.59582 .4414 Mdot
.46408 .36268 Mdot
.3122 .48265 Mdot
.21331 .36614 Mdot
.72552 .39448 Mdot
.69244 .41714 Mdot
.52891 .14815 Mdot
.47412 .36591 Mdot
.33215 .64622 Mdot
.49949 .31082 Mdot
.41389 .35069 Mdot
.71839 .39391 Mdot
.32926 .6847 Mdot
.74011 .51312 Mdot
.45996 .36521 Mdot
.5724 .73301 Mdot
.43252 .34009 Mdot
.55311 .72243 Mdot
.39133 .31666 Mdot
.38976 .64123 Mdot
.62817 .41244 Mdot
.39113 .6385 Mdot
.54186 .69454 Mdot
.39315 .65194 Mdot
.2739 .49773 Mdot
.52522 .57827 Mdot
.27441 .47039 Mdot
.70311 .60489 Mdot
.58363 .26749 Mdot
.29179 .46242 Mdot
.68294 .38068 Mdot
.59372 .45859 Mdot
.39164 .31542 Mdot
.3334 .63638 Mdot
.3394 .61643 Mdot
.65831 .61496 Mdot
.41504 .31011 Mdot
.37008 .6237 Mdot
.60124 .48642 Mdot
.20427 .47272 Mdot
.72705 .4014 Mdot
.18574 .62327 Mdot
.41595 .33944 Mdot
.33886 .61756 Mdot
.66774 .63423 Mdot
.46398 .37336 Mdot
.34435 .6762 Mdot
.30581 .46994 Mdot
.27926 .48991 Mdot
.5744 .44171 Mdot
.28452 .44017 Mdot
.32227 .65465 Mdot
.50874 .36819 Mdot
.40086 .30561 Mdot
.23238 .34 Mdot
.56122 .68055 Mdot
.34368 .62454 Mdot
.52813 .59615 Mdot
.43189 .38588 Mdot
.38075 .64386 Mdot
.85845 .40568 Mdot
.66323 .80304 Mdot
.36553 .62354 Mdot
.43873 .33565 Mdot
.43241 .32306 Mdot
.67397 .42534 Mdot
.66053 .61052 Mdot
.35069 .62965 Mdot
.19512 .50148 Mdot
.70933 .5638 Mdot
.52738 .5751 Mdot
.31214 .74591 Mdot
.6753 .40355 Mdot
.70585 .40867 Mdot
.30352 .49873 Mdot
.62576 .4182 Mdot
.43498 .36401 Mdot
.58514 .41727 Mdot
.26862 .47853 Mdot
.36728 .67838 Mdot
.59304 .44372 Mdot
.55434 .69137 Mdot
.2949 .49829 Mdot
.28193 .4962 Mdot
.38052 .65965 Mdot
.42773 .30751 Mdot
.57184 .20195 Mdot
.33603 .64167 Mdot
.70807 .41205 Mdot
.53326 .57796 Mdot
.64453 .41282 Mdot
.47366 .34356 Mdot
.42135 .28247 Mdot
.33861 .62617 Mdot
.63626 .45424 Mdot
.29721 .48183 Mdot
.32201 .63398 Mdot
.69197 .40548 Mdot
.33266 .67538 Mdot
.50658 .60665 Mdot
.40895 .61723 Mdot
.41574 .38082 Mdot
.51234 .60091 Mdot
.46738 .36181 Mdot
.53111 .56087 Mdot
.5301 .80099 Mdot
.55666 .69293 Mdot
.40457 .63654 Mdot
.24379 .33311 Mdot
.39291 .63626 Mdot
.61206 .41374 Mdot
.58687 .45677 Mdot
.36504 .65505 Mdot
.56851 .6827 Mdot
.51326 .53819 Mdot
.55522 .73642 Mdot
.44144 .33414 Mdot
.71753 .38842 Mdot
.6228 .81772 Mdot
.32538 .6218 Mdot
.30835 .46132 Mdot
.35743 .3361 Mdot
.52076 .56311 Mdot
.27723 .50045 Mdot
.28749 .49922 Mdot
.54391 .69054 Mdot
.38559 .62132 Mdot
.4471 .31751 Mdot
.31024 .45936 Mdot
.45294 .37182 Mdot
.64964 .70839 Mdot
.53026 .60656 Mdot
.48689 .54569 Mdot
.51343 .58306 Mdot
.65853 .62288 Mdot
.31955 .48356 Mdot
.60738 .44933 Mdot
.49471 .60403 Mdot
.31025 .48064 Mdot
.55023 .67229 Mdot
.69616 .40229 Mdot
.37361 .62484 Mdot
.55227 .16815 Mdot
.57378 .44982 Mdot
.59363 .42284 Mdot
.30934 .49653 Mdot
.69211 .26965 Mdot
.43576 .2852 Mdot
.41433 .30318 Mdot
.35336 .64804 Mdot
.64602 .64918 Mdot
.59755 .41067 Mdot
.5859 .45922 Mdot
.36508 .65865 Mdot
.54065 .56864 Mdot
.33143 .7675 Mdot
.59888 .43205 Mdot
.28812 .47706 Mdot
.70076 .40042 Mdot
.28055 .50802 Mdot
.5756 .41142 Mdot
.61392 .41495 Mdot
.70078 .4166 Mdot
.71564 .40236 Mdot
.27561 .46961 Mdot
.51525 .58678 Mdot
.54111 .55112 Mdot
.43209 .35544 Mdot
.59044 .47016 Mdot
.70885 .56203 Mdot
.59836 .43688 Mdot
.55208 .68836 Mdot
.63929 .63293 Mdot
.57898 .41283 Mdot
.57772 .46763 Mdot
.71105 .56577 Mdot
.62806 .43851 Mdot
.30988 .49765 Mdot
.42744 .31905 Mdot
.29799 .48398 Mdot
.31382 .47112 Mdot
.3813 .64884 Mdot
.5554 .66921 Mdot
.63969 .43271 Mdot
.57094 .72466 Mdot
.67018 .41926 Mdot
.56811 .58576 Mdot
.65502 .59581 Mdot
.67274 .63375 Mdot
.53674 .69479 Mdot
.59226 .45997 Mdot
.35651 .65253 Mdot
.38026 .61632 Mdot
.70307 .39473 Mdot
.62289 .46742 Mdot
.27718 .44361 Mdot
.29519 .46075 Mdot
.29891 .61957 Mdot
.37995 .70631 Mdot
.55145 .73034 Mdot
.49331 .57153 Mdot
.71824 .40145 Mdot
.6148 .40958 Mdot
.51895 .578 Mdot
.37487 .63975 Mdot
.53167 .55914 Mdot
.3089 .60109 Mdot
.27515 .5015 Mdot
.30325 .48812 Mdot
.57575 .44977 Mdot
.87086 .48712 Mdot
.45 .35418 Mdot
.43215 .32223 Mdot
.26772 .4699 Mdot
.39763 .64788 Mdot
.54085 .59047 Mdot
.57391 .1755 Mdot
.41381 .28402 Mdot
.58649 .70928 Mdot
.62189 .45366 Mdot
.37312 .67097 Mdot
.42577 .35465 Mdot
.55401 .73335 Mdot
.5636 .46378 Mdot
.32863 .68633 Mdot
.60681 .44451 Mdot
.5808 .49668 Mdot
.39931 .32196 Mdot
.64638 .59309 Mdot
.47131 .36051 Mdot
.27674 .47513 Mdot
.3167 .47378 Mdot
.60679 .41684 Mdot
.5681 .17759 Mdot
.38231 .37423 Mdot
.31034 .45704 Mdot
.57902 .67912 Mdot
.52386 .5841 Mdot
.55323 .67059 Mdot
.36573 .64706 Mdot
.55574 .69252 Mdot
.38134 .64468 Mdot
.31215 .66828 Mdot
.44287 .31482 Mdot
.57044 .69213 Mdot
.6744 .28968 Mdot
.54268 .59821 Mdot
.58557 .68399 Mdot
.56543 .45111 Mdot
.68124 .42322 Mdot
.35848 .62857 Mdot
.57501 .72259 Mdot
.64387 .42705 Mdot
.27325 .33694 Mdot
.31755 .48577 Mdot
.27257 .49652 Mdot
.54006 .58831 Mdot
.32329 .64145 Mdot
.44094 .31222 Mdot
.68959 .61079 Mdot
.46171 .39 Mdot
.58479 .4596 Mdot
.63931 .43098 Mdot
.44547 .38908 Mdot
.43904 .31068 Mdot
.612 .41677 Mdot
.64765 .32491 Mdot
.52589 .59628 Mdot
.27469 .48472 Mdot
.44439 .33717 Mdot
.45031 .33832 Mdot
.32643 .66079 Mdot
.42037 .30025 Mdot
.48089 .57975 Mdot
.27574 .50142 Mdot
.54641 .55105 Mdot
.29437 .48095 Mdot
.57472 .55683 Mdot
.37358 .62867 Mdot
.22922 .352 Mdot
.4146 .30163 Mdot
.68709 .41929 Mdot
.41532 .29893 Mdot
.55542 .68 Mdot
.46192 .36095 Mdot
.46752 .33741 Mdot
.58253 .46174 Mdot
.51615 .58638 Mdot
.5501 .5693 Mdot
.66139 .61762 Mdot
.44643 .3529 Mdot
.63751 .42425 Mdot
.60316 .40482 Mdot
.58079 .4352 Mdot
.65807 .59946 Mdot
.44759 .32404 Mdot
.66995 .26247 Mdot
.38956 .31257 Mdot
.4014 .32698 Mdot
.72836 .73192 Mdot
.5544 .5745 Mdot
.52428 .56356 Mdot
.25682 .43131 Mdot
.59817 .42967 Mdot
.36836 .62023 Mdot
.70508 .41227 Mdot
.51955 .589 Mdot
.56251 .45215 Mdot
.57376 .71594 Mdot
.63225 .45051 Mdot
.53203 .56991 Mdot
.33563 .63586 Mdot
.68799 .41733 Mdot
.59236 .43532 Mdot
.54487 .56976 Mdot
.41594 .2963 Mdot
.45537 .33645 Mdot
.42237 .39395 Mdot
.54682 .71674 Mdot
.28881 .46673 Mdot
.70335 .41131 Mdot
.35493 .64971 Mdot
.37396 .62045 Mdot
.47016 .36 Mdot
.34702 .66624 Mdot
.30413 .49001 Mdot
.61453 .4299 Mdot
.27573 .47253 Mdot
.56747 .72118 Mdot
.4423 .33866 Mdot
.69853 .40763 Mdot
.67824 .43284 Mdot
.40795 .32184 Mdot
.52702 .59898 Mdot
.56651 .67372 Mdot
.36216 .66471 Mdot
.41094 .34345 Mdot
.27206 .47033 Mdot
.33156 .66646 Mdot
.69016 .41934 Mdot
.80124 .65744 Mdot
.62519 .41766 Mdot
.58473 .42285 Mdot
.39312 .3718 Mdot
.60926 .39225 Mdot
.39159 .64346 Mdot
.42955 .3028 Mdot
.68357 .42189 Mdot
.7209 .58204 Mdot
.54611 .66498 Mdot
.36485 .60878 Mdot
.62387 .43857 Mdot
.72474 .3426 Mdot
.64479 .40132 Mdot
.25553 .3205 Mdot
.6538 .59636 Mdot
.30532 .57343 Mdot
.47772 .55846 Mdot
.30448 .45178 Mdot
.53689 .57317 Mdot
.38366 .64847 Mdot
.64105 .31428 Mdot
.61771 .41842 Mdot
.57314 .24737 Mdot
.69014 .40849 Mdot
.30191 .48128 Mdot
.68938 .27587 Mdot
.32708 .64476 Mdot
.38858 .80771 Mdot
.60338 .46954 Mdot
.42847 .28397 Mdot
.35924 .5655 Mdot
.52121 .57673 Mdot
.51865 .57018 Mdot
.55032 .72787 Mdot
.33953 .6942 Mdot
.55027 .61636 Mdot
.29621 .48318 Mdot
.61333 .40847 Mdot
.62135 .47415 Mdot
.20338 .38126 Mdot
.41993 .34724 Mdot
.31314 .47533 Mdot
.38982 .60729 Mdot
.60635 .45319 Mdot
.46489 .35116 Mdot
.41787 .32686 Mdot
.57791 .71505 Mdot
.30915 .56546 Mdot
.33543 .69546 Mdot
.84899 .46147 Mdot
.54801 .62594 Mdot
.37482 .64247 Mdot
.51428 .60101 Mdot
.7049 .4137 Mdot
.59103 .57664 Mdot
.31037 .46259 Mdot
.60374 .41509 Mdot
.57238 .2357 Mdot
.42229 .34502 Mdot
.60482 .4374 Mdot
.55665 .70237 Mdot
.58598 .1765 Mdot
.63323 .46858 Mdot
.65259 .32951 Mdot
.32499 .67832 Mdot
.63949 .42883 Mdot
.48223 .58444 Mdot
.55093 .59714 Mdot
.60811 .39228 Mdot
.33266 .64385 Mdot
.51116 .59836 Mdot
.56113 .70512 Mdot
.43563 .35931 Mdot
.53763 .57532 Mdot
.68943 .4083 Mdot
.6393 .43946 Mdot
.57639 .67692 Mdot
.69748 .41599 Mdot
.50321 .29905 Mdot
.52906 .6145 Mdot
.34851 .6726 Mdot
.41232 .34661 Mdot
.64022 .42173 Mdot
.52297 .58477 Mdot
.61053 .45809 Mdot
.38938 .24644 Mdot
.6068 .4129 Mdot
.24205 .35888 Mdot
.41025 .31275 Mdot
.28505 .48953 Mdot
.69973 .40471 Mdot
.60328 .44437 Mdot
.51568 .60539 Mdot
.54288 .59064 Mdot
.60714 .46619 Mdot
.46859 .36141 Mdot
.44356 .35932 Mdot
.42376 .28491 Mdot
.32801 .66757 Mdot
.67262 .61428 Mdot
.28086 .4823 Mdot
.51919 .57655 Mdot
.30988 .45908 Mdot
.72982 .35603 Mdot
.54658 .71154 Mdot
.21378 .37641 Mdot
.61436 .42568 Mdot
.41911 .31039 Mdot
.71734 .66999 Mdot
.46875 .35191 Mdot
.27189 .42799 Mdot
.3089 .46027 Mdot
.44327 .34648 Mdot
.62549 .43526 Mdot
.65855 .62803 Mdot
.72682 .34008 Mdot
.31516 .50854 Mdot
.54751 .55341 Mdot
.57356 .61994 Mdot
.33932 .67992 Mdot
.71978 .7389 Mdot
.28239 .45176 Mdot
.33075 .37543 Mdot
.685 .42062 Mdot
.40824 .30435 Mdot
.2798 .46482 Mdot
.28006 .49639 Mdot
.32619 .64224 Mdot
.68857 .41435 Mdot
.60373 .44245 Mdot
.55078 .56018 Mdot
.28816 .45424 Mdot
.63738 .44989 Mdot
.69851 .42411 Mdot
.28989 .68596 Mdot
.43396 .2827 Mdot
.1954 .3791 Mdot
.72552 .3791 Mdot
.57384 .23535 Mdot
.21507 .50731 Mdot
.39395 .31209 Mdot
.63497 .43262 Mdot
.53118 .59313 Mdot
.3549 .66822 Mdot
.62074 .4274 Mdot
.39423 .63833 Mdot
.29858 .47316 Mdot
.25772 .34927 Mdot
.72425 .38126 Mdot
.33193 .42402 Mdot
.62638 .41368 Mdot
.6583 .4443 Mdot
.56574 .69921 Mdot
.2675 .4912 Mdot
.4334 .29101 Mdot
.64371 .41652 Mdot
.32966 .65578 Mdot
.34421 .67876 Mdot
.42594 .348 Mdot
.37528 .3996 Mdot
.23493 .34367 Mdot
.53223 .5988 Mdot
.34234 .6617 Mdot
.52288 .58764 Mdot
.65291 .33223 Mdot
.30957 .45775 Mdot
.56216 .7058 Mdot
.37369 .66615 Mdot
.26388 .47237 Mdot
.68139 .4237 Mdot
.43552 .34927 Mdot
.45581 .3891 Mdot
.72322 .39164 Mdot
.36999 .62322 Mdot
.55083 .71431 Mdot
.66033 .39081 Mdot
.71852 .38907 Mdot
.55631 .71418 Mdot
.32358 .66042 Mdot
.45804 .35061 Mdot
.41322 .32311 Mdot
.42493 .31811 Mdot
.69898 .30512 Mdot
.41888 .28243 Mdot
.6228 .68326 Mdot
.62205 .39038 Mdot
.51631 .36708 Mdot
.65283 .40783 Mdot
.27118 .49452 Mdot
.39929 .31569 Mdot
.65333 .59561 Mdot
.72413 .40331 Mdot
.73105 .34036 Mdot
.58319 .43616 Mdot
.71611 .39642 Mdot
.59736 .42989 Mdot
.51071 .37174 Mdot
.4279 .27968 Mdot
.58477 .47152 Mdot
.29627 .51252 Mdot
.54792 .68925 Mdot
.43384 .36682 Mdot
.63274 .4412 Mdot
.49607 .37286 Mdot
.56529 .44811 Mdot
.25425 .35016 Mdot
.71274 .39431 Mdot
.40733 .59089 Mdot
.62601 .40526 Mdot
.39843 .65159 Mdot
.67033 .43502 Mdot
.51845 .32823 Mdot
.31822 .49418 Mdot
.63445 .46802 Mdot
.40858 .63569 Mdot
.68735 .27514 Mdot
.53684 .59813 Mdot
.55945 .69811 Mdot
.50926 .58259 Mdot
.2708 .47514 Mdot
.6155 .42225 Mdot
.63057 .45018 Mdot
.58049 .40309 Mdot
.65303 .33314 Mdot
.55221 .58385 Mdot
.5366 .70023 Mdot
.51772 .34717 Mdot
.61497 .46177 Mdot
.40699 .62057 Mdot
.44035 .32106 Mdot
.67714 .2828 Mdot
.66039 .28114 Mdot
.69554 .42675 Mdot
.44245 .35015 Mdot
.42924 .30834 Mdot
.66838 .76497 Mdot
.5642 .68977 Mdot
.59331 .42092 Mdot
.56945 .74712 Mdot
.70081 .41055 Mdot
.29185 .47243 Mdot
.60381 .39473 Mdot
.37302 .62773 Mdot
.66094 .63526 Mdot
.3248 .66457 Mdot
.58029 .438 Mdot
.43159 .33795 Mdot
.31141 .51128 Mdot
.3103 .66455 Mdot
.31123 .56266 Mdot
.62667 .6906 Mdot
.33192 .69431 Mdot
.55468 .73145 Mdot
.54575 .68575 Mdot
.26798 .49167 Mdot
.62007 .43498 Mdot
.65877 .60287 Mdot
.74602 .37615 Mdot
.60274 .42692 Mdot
.63079 .42359 Mdot
.23047 .46235 Mdot
.2993 .45424 Mdot
.38004 .66362 Mdot
.6129 .41738 Mdot
.63331 .4506 Mdot
.43683 .34045 Mdot
.57193 .72762 Mdot
.37328 .65788 Mdot
.54571 .71971 Mdot
.34386 .65426 Mdot
.73497 .64713 Mdot
.53154 .60582 Mdot
.54496 .70233 Mdot
.28383 .45009 Mdot
.427 .31474 Mdot
.55492 .57297 Mdot
.36138 .63988 Mdot
.34257 .66376 Mdot
.66843 .42155 Mdot
.42816 .35567 Mdot
.41399 .30296 Mdot
.55114 .72474 Mdot
.29283 .46083 Mdot
.71791 .40762 Mdot
.51402 .58067 Mdot
.32871 .61152 Mdot
.33448 .66253 Mdot
.51661 .35192 Mdot
.40503 .37637 Mdot
.61244 .45505 Mdot
.4567 .33873 Mdot
.59594 .44757 Mdot
.48166 .37295 Mdot
.47398 .3687 Mdot
.574 .41479 Mdot
.56548 .35431 Mdot
.37674 .63979 Mdot
.58492 .83073 Mdot
.72798 .40066 Mdot
.2767 .51222 Mdot
.70289 .41301 Mdot
.35219 .7844 Mdot
.71423 .67339 Mdot
.60492 .46376 Mdot
.63707 .43514 Mdot
.86339 .51388 Mdot
.62886 .39887 Mdot
.53174 .56235 Mdot
.5382 .59833 Mdot
.46043 .3443 Mdot
.5109 .57527 Mdot
.65907 .61957 Mdot
.57312 .68872 Mdot
.35448 .64774 Mdot
.65727 .70758 Mdot
.55082 .72031 Mdot
.41699 .33692 Mdot
.71745 .40916 Mdot
.39802 .37913 Mdot
.40314 .62346 Mdot
.54247 .57719 Mdot
.30015 .47659 Mdot
.65628 .60965 Mdot
.32674 .65079 Mdot
.27487 .46064 Mdot
.6141 .40056 Mdot
.30712 .60794 Mdot
.28896 .51096 Mdot
.5989 .82195 Mdot
.29349 .50397 Mdot
.27185 .4656 Mdot
.66548 .61016 Mdot
.57342 .68878 Mdot
.52049 .61287 Mdot
.56802 .56557 Mdot
.31228 .50542 Mdot
.43793 .82407 Mdot
.32474 .64033 Mdot
.68453 .63212 Mdot
.43801 .28073 Mdot
.54077 .60241 Mdot
.63064 .41586 Mdot
.3036 .49996 Mdot
.62475 .46744 Mdot
.51389 .60336 Mdot
.29631 .49503 Mdot
.67119 .43468 Mdot
.64617 .64699 Mdot
.52601 .58704 Mdot
.55057 .5674 Mdot
.56661 .73266 Mdot
.41595 .60596 Mdot
.42103 .30582 Mdot
.58689 .69945 Mdot
.69772 .58967 Mdot
.58451 .42803 Mdot
.27624 .46903 Mdot
.53833 .5757 Mdot
.27864 .48421 Mdot
.56982 .70415 Mdot
.57629 .67562 Mdot
.42932 .35426 Mdot
.427 .28486 Mdot
.55864 .5844 Mdot
.71371 .55556 Mdot
.63712 .39409 Mdot
.57619 .25762 Mdot
.44872 .32244 Mdot
.71404 .29278 Mdot
.58016 .69259 Mdot
.57615 .72328 Mdot
.66344 .43819 Mdot
.57715 .41965 Mdot
.7124 .39734 Mdot
.57481 .41852 Mdot
.42021 .80721 Mdot
.69646 .40758 Mdot
.35864 .66484 Mdot
.56308 .44051 Mdot
.34167 .35281 Mdot
.66935 .42687 Mdot
.62728 .44785 Mdot
.34286 .64204 Mdot
.6592 .41766 Mdot
.36358 .62695 Mdot
.6358 .41395 Mdot
.29589 .70861 Mdot
.35441 .6496 Mdot
.51777 .54169 Mdot
.56954 .39662 Mdot
.53763 .56162 Mdot
.57899 .70339 Mdot
.5468 .72721 Mdot
.64605 .69866 Mdot
.45448 .35044 Mdot
.60596 .19709 Mdot
.62498 .44918 Mdot
.32383 .64538 Mdot
.29909 .47133 Mdot
.68094 .43145 Mdot
.57992 .42932 Mdot
.72128 .39983 Mdot
.44151 .35453 Mdot
.32091 .6451 Mdot
.57423 .69973 Mdot
.39251 .62586 Mdot
.29499 .70993 Mdot
.37371 .63066 Mdot
.6746 .35161 Mdot
.67817 .42347 Mdot
.48185 .58239 Mdot
.59456 .29001 Mdot
.5936 .68691 Mdot
.43117 .34995 Mdot
.53463 .57442 Mdot
.54851 .67797 Mdot
.62319 .60906 Mdot
.42956 .31254 Mdot
.36431 .65877 Mdot
.60679 .44508 Mdot
.52054 .60343 Mdot
.56821 .56703 Mdot
.44177 .36776 Mdot
.56596 .67014 Mdot
.35443 .64146 Mdot
.52798 .5807 Mdot
.67579 .6175 Mdot
.64365 .2529 Mdot
.7008 .6122 Mdot
.60084 .44641 Mdot
.55421 .72591 Mdot
.42838 .35607 Mdot
.72248 .39686 Mdot
.30966 .48355 Mdot
.66011 .61267 Mdot
.62743 .41587 Mdot
.31839 .41814 Mdot
.43021 .33804 Mdot
.56475 .682 Mdot
.30017 .50241 Mdot
.56209 .68918 Mdot
.52505 .5638 Mdot
.41217 .35353 Mdot
.51877 .57021 Mdot
.69276 .40634 Mdot
.29522 .46974 Mdot
.41831 .30496 Mdot
.2944 .70674 Mdot
.52857 .62117 Mdot
.36515 .65381 Mdot
.62544 .60871 Mdot
.44067 .35974 Mdot
.33299 .53864 Mdot
.39337 .62688 Mdot
.26123 .5239 Mdot
.6349 .59134 Mdot
.30107 .49512 Mdot
.62943 .44561 Mdot
.42637 .32354 Mdot
.31478 .50983 Mdot
.34119 .56857 Mdot
.71954 .3308 Mdot
.54232 .61335 Mdot
.59094 .45841 Mdot
.26404 .30964 Mdot
.33761 .37393 Mdot
.4554 .28258 Mdot
.27113 .46023 Mdot
.59401 .42505 Mdot
.53136 .59971 Mdot
.59373 .47112 Mdot
.31491 .50149 Mdot
.32535 .49285 Mdot
.3652 .61539 Mdot
.60856 .44788 Mdot
.55547 .68684 Mdot
.38364 .63297 Mdot
.33963 .68342 Mdot
.3703 .66893 Mdot
.43279 .28967 Mdot
.54118 .60504 Mdot
.53665 .59995 Mdot
.70703 .68003 Mdot
.27772 .48541 Mdot
.53703 .56184 Mdot
.63257 .44911 Mdot
.62364 .68328 Mdot
.41847 .31399 Mdot
.35276 .63771 Mdot
.5924 .42409 Mdot
.7312 .39257 Mdot
.54639 .57425 Mdot
.3377 .64044 Mdot
.44035 .3125 Mdot
.5311 .48535 Mdot
.61906 .42686 Mdot
.68985 .41117 Mdot
.41082 .33042 Mdot
.36721 .24755 Mdot
.67872 .62367 Mdot
.5956 .44595 Mdot
.27325 .47732 Mdot
.34176 .25944 Mdot
.62065 .40026 Mdot
.4336 .39702 Mdot
.55091 .55801 Mdot
.513 .45023 Mdot
.50637 .31329 Mdot
.56198 .47952 Mdot
.43429 .51106 Mdot
.68813 .50631 Mdot
.45217 .52919 Mdot
.46045 .81077 Mdot
.39556 .51977 Mdot
.61834 .81535 Mdot
.2664 .44778 Mdot
.57488 .49561 Mdot
.85074 .40491 Mdot
.33507 .39148 Mdot
.37647 .54251 Mdot
.31708 .52958 Mdot
.59525 .67313 Mdot
.32284 .75846 Mdot
.30541 .60982 Mdot
.46362 .80816 Mdot
.67652 .40459 Mdot
.35005 .29257 Mdot
.60681 .48823 Mdot
.34572 .52594 Mdot
.30987 .57272 Mdot
.69632 .39816 Mdot
.84432 .53466 Mdot
.28881 .4264 Mdot
.77418 .66196 Mdot
.58855 .21671 Mdot
.31892 .60843 Mdot
.70296 .54192 Mdot
.64521 .73613 Mdot
.66639 .44755 Mdot
.48598 .48874 Mdot
.2696 .44253 Mdot
.37993 .30534 Mdot
.20073 .48374 Mdot
.35551 .66112 Mdot
.44936 .3675 Mdot
.25459 .42454 Mdot
.82514 .59924 Mdot
.24925 .48721 Mdot
.43305 .51259 Mdot
.53672 .61989 Mdot
.51979 .4383 Mdot
.65325 .59209 Mdot
.50518 .35155 Mdot
.29285 .66345 Mdot
.32722 .7585 Mdot
.39028 .364 Mdot
.35968 .57575 Mdot
.61479 .60822 Mdot
.37086 .54241 Mdot
.48786 .29307 Mdot
.58258 .66356 Mdot
.51595 .54474 Mdot
.44934 .32261 Mdot
.82579 .49706 Mdot
.6593 .36867 Mdot
.70255 .58544 Mdot
.3202 .5788 Mdot
.36931 .31775 Mdot
.57176 .19698 Mdot
.37217 .39675 Mdot
.53868 .84549 Mdot
.80087 .65142 Mdot
.50602 .81979 Mdot
.55641 .40493 Mdot
.24446 .46859 Mdot
.59597 .59595 Mdot
.4461 .57466 Mdot
.52896 .82285 Mdot
.38716 .24806 Mdot
.84091 .48219 Mdot
.49035 .4142 Mdot
.83177 .61143 Mdot
.4097 .36414 Mdot
.51153 .62093 Mdot
.47145 .2885 Mdot
.54807 .49491 Mdot
.69626 .66289 Mdot
.84085 .57849 Mdot
.35594 .5311 Mdot
.52695 .62336 Mdot
.33683 .39667 Mdot
.50215 .30145 Mdot
.29108 .66187 Mdot
.51056 .56533 Mdot
.61991 .28593 Mdot
.85195 .5522 Mdot
.44442 .50011 Mdot
.82077 .55919 Mdot
.29645 .69254 Mdot
.17325 .57853 Mdot
.34102 .68541 Mdot
.30222 .44583 Mdot
.78768 .65401 Mdot
.4224 .32384 Mdot
.56529 .84586 Mdot
.40005 .53881 Mdot
.42071 .58133 Mdot
.85125 .54409 Mdot
.51459 .84407 Mdot
.54119 .47383 Mdot
.497 .56401 Mdot
.20641 .47573 Mdot
.47282 .52396 Mdot
.35535 .4549 Mdot
.56906 .54177 Mdot
.25649 .33472 Mdot
.79881 .63586 Mdot
.49631 .83615 Mdot
.84275 .44799 Mdot
.6974 .58139 Mdot
.60633 .72551 Mdot
.38618 .3657 Mdot
.40679 .45558 Mdot
.35648 .4756 Mdot
.824 .62566 Mdot
.61183 .48204 Mdot
.32144 .26615 Mdot
.47812 .81236 Mdot
.66728 .2765 Mdot
.29575 .31479 Mdot
.32536 .4099 Mdot
.54412 .50214 Mdot
.49386 .37026 Mdot
.53243 .68951 Mdot
.68705 .67494 Mdot
.60664 .27016 Mdot
.38882 .58182 Mdot
.67036 .62626 Mdot
.38645 .40838 Mdot
.58197 .79184 Mdot
.32573 .29323 Mdot
.61776 .27989 Mdot
.44929 .38792 Mdot
.53029 .82124 Mdot
.48264 .81767 Mdot
.30835 .28645 Mdot
.37182 .60283 Mdot
.81946 .56965 Mdot
.3652 .42841 Mdot
.53069 .43257 Mdot
.59832 .49192 Mdot
.65842 .45027 Mdot
.35396 .7704 Mdot
.63781 .34681 Mdot
.66816 .75748 Mdot
.34416 .44343 Mdot
.59518 .30159 Mdot
.6637 .73937 Mdot
.60029 .29634 Mdot
.51514 .31982 Mdot
.42452 .40275 Mdot
.29531 .42827 Mdot
.56057 .36212 Mdot
.84729 .53494 Mdot
.38572 .65209 Mdot
.52631 .82592 Mdot
.25009 .47908 Mdot
.31335 .60259 Mdot
.40392 .57358 Mdot
.3933 .57106 Mdot
.75201 .6918 Mdot
.32537 .39962 Mdot
.57651 .65385 Mdot
.48216 .29738 Mdot
.42012 .55156 Mdot
.58267 .25961 Mdot
.71056 .37341 Mdot
.36874 .29286 Mdot
.56722 .67367 Mdot
.6258 .31075 Mdot
.49895 .36709 Mdot
.38743 .60515 Mdot
.68988 .35573 Mdot
.7244 .5222 Mdot
.55879 .56808 Mdot
.6354 .66872 Mdot
.73187 .65253 Mdot
.52847 .40449 Mdot
.528 .83656 Mdot
.35587 .39739 Mdot
.63907 .67427 Mdot
.35591 .48101 Mdot
.61224 .20143 Mdot
.83417 .60836 Mdot
.71366 .73773 Mdot
.3651 .25652 Mdot
.28701 .30958 Mdot
.2038 .66172 Mdot
.32548 .54145 Mdot
.61291 .80254 Mdot
.24995 .47885 Mdot
.50001 .13498 Mdot
.39102 .64805 Mdot
.58996 .60597 Mdot
.40089 .34707 Mdot
.71845 .52246 Mdot
.83696 .56425 Mdot
.51936 .42025 Mdot
.58696 .68729 Mdot
.45978 .27973 Mdot
.56692 .35499 Mdot
.83888 .52957 Mdot
.83494 .49609 Mdot
.8314 .50612 Mdot
.27053 .42004 Mdot
.63008 .33166 Mdot
.85596 .52253 Mdot
.60243 .64978 Mdot
.57238 .36818 Mdot
.60753 .48045 Mdot
.72353 .56853 Mdot
.59259 .81141 Mdot
.60016 .71416 Mdot
.47772 .52083 Mdot
.39153 .36515 Mdot
.85813 .54549 Mdot
.72673 .66712 Mdot
.52399 .4553 Mdot
.75479 .67841 Mdot
.57821 .75995 Mdot
.67597 .73226 Mdot
.73738 .70533 Mdot
.46358 .49332 Mdot
.33019 .41285 Mdot
.86472 .54401 Mdot
.51613 .80728 Mdot
.31356 .53402 Mdot
.49667 .37053 Mdot
.58588 .82105 Mdot
.28789 .31892 Mdot
.22767 .48726 Mdot
.40388 .35754 Mdot
.63273 .21753 Mdot
.37357 .50306 Mdot
.49071 .48976 Mdot
.56793 .40915 Mdot
.65616 .75115 Mdot
.39186 .65225 Mdot
.56012 .81044 Mdot
.36727 .47547 Mdot
.55569 .3731 Mdot
.65528 .68435 Mdot
.47274 .83136 Mdot
.48573 .44901 Mdot
.6723 .32922 Mdot
.35656 .39898 Mdot
.33463 .27909 Mdot
.30569 .3054 Mdot
.60967 .23517 Mdot
.65191 .41801 Mdot
.82978 .59287 Mdot
.64387 .80669 Mdot
.74117 .70624 Mdot
.317 .28603 Mdot
.191 .62171 Mdot
.26673 .45589 Mdot
.61053 .65727 Mdot
.73123 .50435 Mdot
.45123 .4689 Mdot
.7039 .49676 Mdot
.31599 .51757 Mdot
.57124 .19625 Mdot
.40295 .56922 Mdot
.60297 .64909 Mdot
.38766 .26859 Mdot
.42432 .56939 Mdot
.66401 .3315 Mdot
.45511 .38598 Mdot
.29428 .28083 Mdot
.53359 .82042 Mdot
.38315 .65551 Mdot
.3576 .60529 Mdot
.61971 .35267 Mdot
.49123 .59757 Mdot
.56869 .63647 Mdot
.53394 .43045 Mdot
.57783 .23372 Mdot
.203 .64066 Mdot
.70263 .73088 Mdot
.58304 .83015 Mdot
.73507 .70843 Mdot
.4972 .82182 Mdot
.33527 .57502 Mdot
.64613 .66666 Mdot
.25236 .50781 Mdot
.25161 .46031 Mdot
.63898 .65132 Mdot
.47704 .8258 Mdot
.52701 .44767 Mdot
.47272 .29282 Mdot
.64764 .42926 Mdot
.71966 .66549 Mdot
.63631 .73507 Mdot
.62623 .65201 Mdot
.62544 .24334 Mdot
.44786 .31583 Mdot
.61263 .68808 Mdot
.51038 .48317 Mdot
.71221 .42255 Mdot
.28961 .30427 Mdot
.3159 .5102 Mdot
.4664 .3821 Mdot
.47214 .83233 Mdot
.20533 .65532 Mdot
.4394 .54894 Mdot
.67914 .3775 Mdot
.80251 .62527 Mdot
.58901 .38481 Mdot
.27462 .32309 Mdot
.64928 .22574 Mdot
.32472 .55413 Mdot
.39451 .3624 Mdot
.54713 .38477 Mdot
.41551 .58545 Mdot
.36213 .27237 Mdot
.44655 .3815 Mdot
.66895 .44099 Mdot
.78707 .66326 Mdot
.63719 .38652 Mdot
.47434 .49919 Mdot
.68976 .61287 Mdot
.39283 .46758 Mdot
.40806 .5424 Mdot
.65639 .69237 Mdot
.44437 .52486 Mdot
.82353 .51108 Mdot
.56396 .19616 Mdot
.49011 .51597 Mdot
.5997 .65807 Mdot
.60219 .64462 Mdot
.58794 .21668 Mdot
.48384 .28641 Mdot
.34743 .45425 Mdot
.66019 .39796 Mdot
.77862 .67883 Mdot
.47245 .4153 Mdot
.64827 .67989 Mdot
.37705 .42025 Mdot
.6613 .40578 Mdot
.52925 .62765 Mdot
.74241 .70009 Mdot
.51227 .45552 Mdot
.8541 .389 Mdot
.44912 .81458 Mdot
.35852 .31932 Mdot
.50775 .32405 Mdot
.54244 .82799 Mdot
.34875 .34849 Mdot
.40475 .52222 Mdot
.3693 .46204 Mdot
.57381 .82089 Mdot
.50654 .44595 Mdot
.51332 .46675 Mdot
.28182 .2957 Mdot
.85214 .5109 Mdot
.47276 .516 Mdot
.2276 .47902 Mdot
.60073 .73106 Mdot
.58908 .41775 Mdot
.36763 .39771 Mdot
.21842 .36223 Mdot
.4026 .42708 Mdot
.4556 .53561 Mdot
.63701 .81394 Mdot
.52665 .41709 Mdot
.35492 .4009 Mdot
.85523 .39275 Mdot
.85959 .3808 Mdot
.36382 .38709 Mdot
.81666 .63719 Mdot
.51688 .46333 Mdot
.27525 .32595 Mdot
.2654 .4428 Mdot
.69513 .3923 Mdot
.57467 .25125 Mdot
.75454 .70396 Mdot
.1838 .62852 Mdot
.35465 .46093 Mdot
.38702 .33624 Mdot
.75172 .71039 Mdot
.52585 .38783 Mdot
.58587 .64264 Mdot
.17457 .57877 Mdot
.39785 .81117 Mdot
.53975 .84201 Mdot
.62969 .23664 Mdot
.35306 .7743 Mdot
.42027 .79342 Mdot
.35892 .51948 Mdot
.59121 .82234 Mdot
.55703 .62189 Mdot
.62255 .2048 Mdot
.52822 .82136 Mdot
.27081 .3131 Mdot
.30627 .72982 Mdot
.41137 .53961 Mdot
.53423 .41896 Mdot
.44165 .40397 Mdot
.25424 .33954 Mdot
.31319 .40861 Mdot
.58474 .37378 Mdot
.63067 .61712 Mdot
.51547 .32477 Mdot
.34161 .25481 Mdot
.66654 .23114 Mdot
.53745 .43518 Mdot
.82679 .46721 Mdot
.32271 .42516 Mdot
.61551 .62789 Mdot
.4976 .30981 Mdot
.64249 .71056 Mdot
.58202 .65466 Mdot
.56393 .44294 Mdot
.7915 .657 Mdot
.57752 .6524 Mdot
.82848 .48074 Mdot
.56264 .84966 Mdot
.76278 .66651 Mdot
.43662 .59411 Mdot
.57838 .60575 Mdot
.59153 .80792 Mdot
.59947 .80249 Mdot
.83349 .46032 Mdot
.46868 .80521 Mdot
.63737 .6467 Mdot
.56159 .3862 Mdot
.70805 .38132 Mdot
.66245 .33912 Mdot
.54688 .82681 Mdot
.58452 .20996 Mdot
.66548 .73358 Mdot
.3636 .26139 Mdot
.47631 .82855 Mdot
.54611 .47938 Mdot
.64285 .70448 Mdot
.38957 .43373 Mdot
.5006 .56283 Mdot
.32616 .633 Mdot
.86529 .48544 Mdot
.30235 .29234 Mdot
.69043 .72959 Mdot
.31633 .27111 Mdot
.496 .3802 Mdot
.43592 .80517 Mdot
.46376 .27981 Mdot
.46495 .57249 Mdot
.3336 .58935 Mdot
.61136 .77331 Mdot
.53402 .45936 Mdot
.25571 .3194 Mdot
.6485 .27142 Mdot
.75722 .69006 Mdot
.66511 .74025 Mdot
.84229 .43306 Mdot
.61068 .69742 Mdot
.62408 .30969 Mdot
.82324 .49222 Mdot
.35033 .26558 Mdot
.61867 .64384 Mdot
.84336 .52388 Mdot
.43107 .27589 Mdot
.80443 .64663 Mdot
.30742 .4782 Mdot
.59224 .65557 Mdot
.23815 .34361 Mdot
.61386 .64966 Mdot
.61147 .64477 Mdot
.69176 .7393 Mdot
.33886 .39842 Mdot
.35165 .39023 Mdot
.36413 .42879 Mdot
.302 .6197 Mdot
.69804 .38619 Mdot
.4609 .50439 Mdot
.84316 .45175 Mdot
.64982 .41787 Mdot
.5063 .79374 Mdot
.52662 .83057 Mdot
.24917 .5049 Mdot
.54354 .40888 Mdot
.2507 .33033 Mdot
.64908 .23876 Mdot
.69799 .68048 Mdot
.85106 .51755 Mdot
.54511 .40691 Mdot
.72127 .51019 Mdot
.69949 .27302 Mdot
.21848 .46297 Mdot
.35076 .45948 Mdot
.43902 .51257 Mdot
.60664 .376 Mdot
.67978 .62062 Mdot
.50369 .81763 Mdot
.62752 .81566 Mdot
.8285 .46244 Mdot
.35136 .46992 Mdot
.62108 .65367 Mdot
.42234 .39709 Mdot
.62917 .75661 Mdot
.84631 .44136 Mdot
.33606 .77116 Mdot
.49588 .36936 Mdot
.48648 .82921 Mdot
.33945 .40999 Mdot
.58769 .64355 Mdot
.63156 .65178 Mdot
.82581 .50192 Mdot
.38603 .30936 Mdot
.51089 .40614 Mdot
.39282 .41417 Mdot
.65276 .61764 Mdot
.38958 .54937 Mdot
.62399 .21736 Mdot
.31823 .39789 Mdot
.84197 .43177 Mdot
.40124 .79053 Mdot
.67983 .27739 Mdot
.84811 .41266 Mdot
.43993 .3096 Mdot
.38546 .54973 Mdot
.17346 .55346 Mdot
.63361 .6714 Mdot
.354 .6795 Mdot
.63914 .44663 Mdot
.63495 .63391 Mdot
.35263 .3094 Mdot
.606 .70775 Mdot
.5632 .66638 Mdot
.46553 .3804 Mdot
.4356 .80036 Mdot
.46224 .38474 Mdot
.62825 .81259 Mdot
.46294 .48902 Mdot
.51414 .33521 Mdot
.67826 .24503 Mdot
.34183 .57585 Mdot
.34019 .27369 Mdot
.77019 .66534 Mdot
.71944 .57262 Mdot
.44901 .37635 Mdot
.43464 .37363 Mdot
.40247 .2704 Mdot
.28731 .53367 Mdot
.8136 .60964 Mdot
.51635 .84133 Mdot
.33395 .60913 Mdot
.41352 .27369 Mdot
.56261 .4013 Mdot
.53243 .42712 Mdot
.7138 .71188 Mdot
.38871 .62481 Mdot
.84523 .59228 Mdot
.59682 .19567 Mdot
.34557 .29365 Mdot
.4592 .45841 Mdot
.73622 .51549 Mdot
.6054 .61352 Mdot
.3686 .57836 Mdot
.53628 .45126 Mdot
.35485 .35964 Mdot
.40969 .29053 Mdot
.39308 .56058 Mdot
.58056 .68781 Mdot
.37389 .60141 Mdot
.28181 .52243 Mdot
.60325 .23154 Mdot
.54004 .83355 Mdot
.43122 .38778 Mdot
.57234 .63921 Mdot
.3942 .59167 Mdot
.66582 .34669 Mdot
.7307 .54281 Mdot
.86899 .50883 Mdot
.78607 .64279 Mdot
.4696 .3643 Mdot
.33153 .2897 Mdot
.29797 .70506 Mdot
.70198 .73002 Mdot
.50533 .4172 Mdot
.54344 .82335 Mdot
.62254 .29326 Mdot
.73026 .7044 Mdot
.5061 .31512 Mdot
.43913 .49423 Mdot
.50908 .8303 Mdot
.56108 .75348 Mdot
.48334 .83332 Mdot
.65612 .24775 Mdot
.65379 .37557 Mdot
.41586 .81677 Mdot
.39735 .42193 Mdot
.52958 .46643 Mdot
.72519 .41299 Mdot
.44966 .47358 Mdot
.57606 .81642 Mdot
.42854 .29918 Mdot
.59986 .68392 Mdot
.39542 .25342 Mdot
.35413 .45867 Mdot
.79582 .63863 Mdot
.31581 .29272 Mdot
.51019 .83947 Mdot
.6987 .38085 Mdot
.59714 .7671 Mdot
.58201 .21535 Mdot
.70703 .57729 Mdot
.512 .58447 Mdot
.60913 .28037 Mdot
.51146 .60516 Mdot
.71137 .67899 Mdot
.67293 .34212 Mdot
.83861 .57258 Mdot
.72708 .65726 Mdot
.44298 .40448 Mdot
.49637 .59884 Mdot
.39107 .31082 Mdot
.84794 .57476 Mdot
.70163 .67467 Mdot
.24977 .33986 Mdot
.53986 .84082 Mdot
.47089 .80195 Mdot
.84931 .40766 Mdot
.33848 .40249 Mdot
.54952 .37109 Mdot
.59611 .82101 Mdot
.48615 .41046 Mdot
.42467 .79402 Mdot
.53389 .45885 Mdot
.38994 .37252 Mdot
.84949 .53609 Mdot
.53849 .63729 Mdot
.42166 .40641 Mdot
.72928 .34728 Mdot
.39166 .35945 Mdot
.70321 .66566 Mdot
.54353 .43609 Mdot
.36453 .66069 Mdot
.72777 .51538 Mdot
.34604 .76588 Mdot
.39773 .27314 Mdot
.53604 .83017 Mdot
.55045 .81903 Mdot
.60322 .73882 Mdot
.43159 .61106 Mdot
.84802 .40589 Mdot
.61586 .32983 Mdot
.55951 .46664 Mdot
.45326 .38405 Mdot
.55797 .66503 Mdot
.4928 .80828 Mdot
.66513 .40661 Mdot
.71557 .53961 Mdot
.62081 .28845 Mdot
.76642 .69001 Mdot
.40024 .44882 Mdot
.31649 .43096 Mdot
.42396 .27388 Mdot
.25352 .33746 Mdot
.37516 .25212 Mdot
.33252 .38332 Mdot
.5757 .81436 Mdot
.4399 .54802 Mdot
.43535 .50614 Mdot
.47629 .39766 Mdot
.55783 .80439 Mdot
.35123 .50534 Mdot
.29398 .51586 Mdot
.57785 .23851 Mdot
.83368 .44879 Mdot
.49094 .37396 Mdot
.41778 .53881 Mdot
.48917 .47329 Mdot
.62933 .37531 Mdot
.35605 .46031 Mdot
.34925 .39831 Mdot
.42523 .37698 Mdot
.82781 .53283 Mdot
.49025 .50128 Mdot
.57593 .61487 Mdot
.46837 .81859 Mdot
.47686 .47976 Mdot
.5523 .82186 Mdot
.56491 .3543 Mdot
.83185 .51315 Mdot
.64633 .68106 Mdot
.57532 .75767 Mdot
.65253 .42825 Mdot
.38387 .25826 Mdot
.74172 .70157 Mdot
.50249 .41798 Mdot
.4505 .55689 Mdot
.45809 .27223 Mdot
.55803 .84633 Mdot
.53391 .54228 Mdot
.20124 .63682 Mdot
.49599 .56987 Mdot
.72317 .52803 Mdot
.72079 .51697 Mdot
.27182 .52772 Mdot
.52982 .43336 Mdot
.36543 .5226 Mdot
.62353 .37181 Mdot
.58332 .23434 Mdot
.65354 .76942 Mdot
.86141 .48015 Mdot
.36827 .31928 Mdot
.52873 .84981 Mdot
.37366 .29616 Mdot
.37327 .35545 Mdot
.40466 .79036 Mdot
.45327 .56479 Mdot
.62784 .34749 Mdot
.6009 .72318 Mdot
.43982 .30608 Mdot
.85547 .47238 Mdot
.45209 .53859 Mdot
.60183 .69228 Mdot
.29227 .68051 Mdot
.40846 .54775 Mdot
.19719 .48615 Mdot
.25211 .46742 Mdot
.56971 .84219 Mdot
.52925 .82297 Mdot
.30193 .42807 Mdot
.51605 .46218 Mdot
.45448 .54819 Mdot
.83759 .52986 Mdot
.49447 .58842 Mdot
.78215 .65521 Mdot
.27731 .41772 Mdot
.60005 .24228 Mdot
.7255 .65487 Mdot
.68962 .67482 Mdot
.70994 .58048 Mdot
.62123 .26567 Mdot
.81354 .568 Mdot
.55516 .58949 Mdot
.36072 .60222 Mdot
.30904 .73397 Mdot
.8455 .44866 Mdot
.34897 .28133 Mdot
.5497 .61466 Mdot
.63911 .74922 Mdot
.4902 .49878 Mdot
.61547 .62373 Mdot
.36529 .44215 Mdot
.56951 .63408 Mdot
.23724 .4407 Mdot
.33227 .26616 Mdot
.77808 .67815 Mdot
.64738 .43977 Mdot
.69287 .49766 Mdot
.34837 .52606 Mdot
.37433 .67242 Mdot
.41436 .25409 Mdot
.86697 .5055 Mdot
.30288 .51714 Mdot
.17553 .54521 Mdot
.26626 .52196 Mdot
.69789 .72703 Mdot
.19092 .63049 Mdot
.29399 .53717 Mdot
.62363 .81725 Mdot
.34984 .30713 Mdot
.65319 .25925 Mdot
.32093 .26356 Mdot
.7153 .67594 Mdot
.6056 .27789 Mdot
.56715 .5379 Mdot
.81242 .63012 Mdot
.60762 .62295 Mdot
.59664 .67272 Mdot
.81879 .55248 Mdot
.50209 .83115 Mdot
.45614 .81672 Mdot
.31909 .54024 Mdot
.38852 .34281 Mdot
.21129 .66432 Mdot
.31584 .60463 Mdot
.57591 .17446 Mdot
.78622 .64016 Mdot
.72743 .32785 Mdot
.50369 .41454 Mdot
.36688 .42456 Mdot
.83929 .54073 Mdot
.56741 .81184 Mdot
.53027 .47484 Mdot
.40638 .61578 Mdot
.67769 .68389 Mdot
.62675 .75278 Mdot
.35349 .41416 Mdot
.74175 .68658 Mdot
.3654 .57831 Mdot
.5276 .63156 Mdot
.51594 .83296 Mdot
.38606 .25799 Mdot
.69899 .57599 Mdot
.83414 .45161 Mdot
.72592 .55357 Mdot
.45787 .82617 Mdot
.27026 .4199 Mdot
.29865 .71197 Mdot
.84341 .4572 Mdot
.36368 .28042 Mdot
.64392 .29404 Mdot
.85277 .39027 Mdot
.83107 .61203 Mdot
.45598 .54778 Mdot
.64405 .3929 Mdot
.61286 .81842 Mdot
.40246 .62119 Mdot
.68029 .74103 Mdot
.57293 .19613 Mdot
.43482 .8097 Mdot
.69207 .34892 Mdot
.65192 .39594 Mdot
.59428 .63773 Mdot
.47698 .34716 Mdot
.39912 .35402 Mdot
.30441 .6256 Mdot
.47715 .825 Mdot
.60391 .22668 Mdot
.56391 .19642 Mdot
.65063 .24433 Mdot
.46479 .36908 Mdot
.79925 .6459 Mdot
.47584 .58904 Mdot
.59028 .2102 Mdot
.83376 .52609 Mdot
.72263 .49026 Mdot
.36243 .50714 Mdot
.57517 .2233 Mdot
.64195 .66657 Mdot
.34191 .76217 Mdot
.85275 .41846 Mdot
.58486 .24796 Mdot
.84888 .58401 Mdot
.71427 .73949 Mdot
.45667 .36769 Mdot
.38966 .28169 Mdot
.6017 .60693 Mdot
.46263 .51962 Mdot
.22045 .45586 Mdot
.31444 .6017 Mdot
.45414 .80081 Mdot
.39998 .60484 Mdot
.59712 .46699 Mdot
.36741 .41309 Mdot
.76051 .68404 Mdot
.58717 .64689 Mdot
.76914 .67618 Mdot
.61027 .25297 Mdot
.64872 .42069 Mdot
.85559 .37691 Mdot
.27287 .32709 Mdot
.70684 .36821 Mdot
.55821 .55164 Mdot
.54671 .61716 Mdot
.56246 .45411 Mdot
.32529 .50151 Mdot
.62508 .68122 Mdot
.40858 .80315 Mdot
.81372 .62551 Mdot
.4136 .27532 Mdot
.60525 .61751 Mdot
.25749 .48217 Mdot
.6387 .58865 Mdot
.69138 .34539 Mdot
.30369 .51954 Mdot
.37841 .78854 Mdot
.20194 .49401 Mdot
.35549 .48867 Mdot
.39066 .5471 Mdot
.63492 .62331 Mdot
.551 .60758 Mdot
.39268 .79051 Mdot
.2586 .51905 Mdot
.35271 .51714 Mdot
.50674 .83931 Mdot
.62942 .27324 Mdot
.33854 .41423 Mdot
.30863 .72289 Mdot
.62184 .6456 Mdot
.37721 .41465 Mdot
.47222 .52821 Mdot
.63852 .22157 Mdot
.82718 .55962 Mdot
.30586 .68897 Mdot
.55586 .58912 Mdot
.70583 .27704 Mdot
.83577 .57025 Mdot
.26756 .47202 Mdot
.64156 .80411 Mdot
.45907 .55634 Mdot
.40954 .25539 Mdot
.73921 .33874 Mdot
.54206 .4036 Mdot
.62172 .47729 Mdot
.60979 .39139 Mdot
.6851 .54712 Mdot
.19071 .48702 Mdot
.53776 .41986 Mdot
.40418 .55157 Mdot
.43714 .53935 Mdot
.60756 .67098 Mdot
.62456 .47384 Mdot
.58692 .42884 Mdot
.53496 .54456 Mdot
.6648 .66458 Mdot
.57685 .62853 Mdot
.6058 .6781 Mdot
.32945 .41327 Mdot
.39277 .7917 Mdot
.45162 .81488 Mdot
.62847 .33735 Mdot
.84349 .53871 Mdot
.72083 .41525 Mdot
.78204 .64678 Mdot
.38145 .46138 Mdot
.32805 .40742 Mdot
.72668 .5471 Mdot
.85123 .41987 Mdot
.40431 .3974 Mdot
.51762 .52688 Mdot
.70661 .74231 Mdot
.75364 .68244 Mdot
.32796 .42311 Mdot
.27034 .30865 Mdot
.31236 .73967 Mdot
.60288 .6299 Mdot
.33618 .2623 Mdot
.33879 .60982 Mdot
.70814 .72927 Mdot
.63004 .36751 Mdot
.4555 .55842 Mdot
.61773 .21828 Mdot
.67366 .35048 Mdot
.35799 .62004 Mdot
.64796 .22526 Mdot
.62267 .26528 Mdot
.81195 .57118 Mdot
.56015 .46545 Mdot
.42959 .46512 Mdot
.42448 .39654 Mdot
.83951 .44061 Mdot
.31704 .64074 Mdot
.72119 .50877 Mdot
.58332 .1755 Mdot
.19165 .48475 Mdot
.42507 .79285 Mdot
.82977 .45799 Mdot
.25211 .4606 Mdot
.61582 .37325 Mdot
.20376 .37526 Mdot
.41315 .39676 Mdot
.44399 .38539 Mdot
.28308 .52377 Mdot
.60621 .76012 Mdot
.39693 .40581 Mdot
.85818 .40479 Mdot
.72771 .70875 Mdot
.60753 .34832 Mdot
.56545 .16662 Mdot
.52033 .83208 Mdot
.70722 .51174 Mdot
.33122 .40053 Mdot
.78947 .65844 Mdot
.22688 .44772 Mdot
.60075 .82023 Mdot
.47614 .48898 Mdot
.38952 .28691 Mdot
.6241 .74848 Mdot
.3172 .27379 Mdot
.55822 .39595 Mdot
.56293 .18786 Mdot
.29192 .3014 Mdot
.64565 .73608 Mdot
.50242 .44573 Mdot
.36361 .3512 Mdot
.35653 .33897 Mdot
.46654 .46136 Mdot
.44831 .57497 Mdot
.41893 .53832 Mdot
.44103 .50368 Mdot
.35275 .50179 Mdot
.45092 .4564 Mdot
.26633 .33325 Mdot
.24101 .48036 Mdot
.63035 .24745 Mdot
.32455 .74637 Mdot
.61023 .69074 Mdot
.39461 .6444 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`2Oooooo`;o0000Z?ooool001cooooo00?o0000ooooooooool0Woooool2o`000:Sooooo000L
ooooo`03o`000?oooooooooo0:Gooooo0_l0002Rooooo`007?ooool00ol0003oooooooooo`2Uoooo
o`Go0000Woooool001cooooo00?o0000ooooooooool0Y_ooool4o`0009oooooo000Looooo`03o`00
0?oooooooooo0:Oooooo1?l000000ooooooo0000o`00002Kooooo`007?ooool2o`000:Wooooo1_l0
002Kooooo`007?ooool00ol0003oooooooooo`2Zooooo`Go0000V_ooool001cooooo00?o0000oooo
ooooool0[?ooool3o`0009[ooooo000Looooo`03o`000?oooooooooo0;3ooooo0_l0002Gooooo`00
7?ooool00ol0003oooooooooo`2`ooooo`Co0000UOooool001cooooo00?o0000ooooooooool0/?oo
ool6o`0009?ooooo000Looooo`03o`000?oooooooooo0;3ooooo0_l00002ooooo`;o0000Toooool0
01cooooo00?o0000ooooooooool0]oooool2o`00093ooooo000Looooo`03o`000?oooooooooo0;Co
oooo1Ol000001?oooooo0000o`000?l0002<ooooo`007?ooool00ol0003oooooooooo`2dooooo`[o
0000Roooool001cooooo00?o0000ooooooooool0]oooool3o`000004ooooool0003o0000o`0008_o
oooo000Looooo`03o`000?oooooooooo0;Oooooo1?l0002>ooooo`007?ooool00ol0003ooooooooo
o`2cooooo`;o00000oooool4o`0008gooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo
0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`2cooooo`;o000000?oooooo`000?l00000
1?l00003ooooo`;o0000R?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0;?ooooo2?l00003oooo
o`?o0000R?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00onHV9So
8B4Qonk^kP07ooooo`03o`000?oooooooooo0;?ooooo1Ol00003ooooo`;o000000Coooooo`000?l0
003ooooo0_l00026ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03
oiRHV?lQ8B7ok^k^00Kooooo0ol0002fooooo`Oo00001?ooool4o`0008Cooooo00000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooo
ooooo`2fooooo`Oo00001_ooool2o`000003ooooool0003o0000087ooooo00000ooooooo410@oooo
o`02ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`2fooooo`Oo00002Oooool2o`00087ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo
00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0;Kooooo0_l000000ooooooo
0000o`000003o`0008_ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;Wooooo1Ol0002;ooooo`007?ooool00ol0
003oooooooooo`2fooooo`;o000000?oooooo`000?l000000_l00008ooooo`Co000000?oooooo`00
0?l000000oooool2o`0007Sooooo000Looooo`03o`000?oooooooooo0;Kooooo0_l00003ooooo`;o
00002?ooool4o`000003ooooool0003o000000;o000000?oooooo`000?l00000N?ooool001cooooo
00?o0000ooooooooool0]_ooool3o`0001?ooooo0_l0001kooooo`007?ooool00ol0003ooooooooo
o`2fooooo`?o00001oooool2o`0000gooooo0_l0001hooooo`007?ooool00ol0003oooooooooo`30
ooooo`;o00003Oooool2o`0007Sooooo000Looooo`03o`000?oooooooooo0;Gooooo1Ol00006oooo
o`;o00004oooool2o`0007;ooooo000Looooo`03o`000?oooooooooo0;Gooooo1ol00004ooooo`Co
00001Oooool2o`0000[ooooo0_l0001booooo`007?ooool00ol0003oooooooooo`2fooooo`Ko0000
1_ooool2o`0000Gooooo0_l00004ooooo`;o0000N?ooool001cooooo00?o0000ooooooooool0]ooo
ool3o`0000Gooooo0_l0000>ooooo`;o0000N?ooool001cooooo00?o0000ooooooooool0]oooool2
o`0000Kooooo0_l00006ooooo`;o00001oooool2o`0000Oooooo0_l0001^ooooo`007?ooool00ol0
003oooooooooo`1aooooo`;o000000?oooooo`000?l000000ol000001?oooooo0000o`000?l00002
ooooo`;o0000=Oooool3o`000003ooooool0003o000000_ooooo1?l00005ooooo`?o00001_ooool2
o`0006kooooo000Looooo`;o0000Koooool2o`000004ooooool0003o0000ooooo`Go000000Cooooo
o`000?l0003o00000_ooool2o`0000;ooooo0ol0000`ooooo`?o000000?oooooo`000?l000003Ooo
ool2o`0000;ooooo0_l00002ooooo`;o0000M_ooool001cooooo00?o0000ooooooooool0Joooool2
o`000003ooooool0003o000000Kooooo0_l00005ooooo`;o00000_ooool5o`00037ooooo0ol00008
ooooo`;o00001?ooool2o`0000;ooooo0ol0001jooooo`007?ooool00ol0003oooooooooo`1[oooo
o`;o00001_ooool2o`0000Cooooo0ol000000ooooooo0000o`000002ooooo`Co00001oooool2o`00
02Wooooo0ol00008ooooo`;o00001?ooool2o`0000;ooooo0ol00002ooooo`?o0000MOooool001co
oooo00?o0000ooooooooool0I_ooool2o`0000?ooooo0_l00005ooooo`?o00001?ooool3o`00013o
oooo0ol0000Xooooo`Co00005Oooool7o`0007;ooooo000Looooo`03o`000?oooooooooo06Gooooo
0ol000000ooooooo0000o`000002o`0000Gooooo0_l0000Iooooo`?o0000:Oooool2o`0001Gooooo
2Ol0001`ooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o000000Coooooo`000?l0003o0000
0oooool2o`0001kooooo0_l0000Yooooo`?o00002_ooool2o`0000kooooo1Ol0001^ooooo`007?oo
ool00ol0003oooooooooo`1Uooooo`;o000000?oooooo`000?l000001?ooool2o`0000[ooooo0_l0
0003ooooo`;o0000>Oooool2o`0000Gooooo0_l00003ooooo`;o00001oooool4o`0000Gooooo1ol0
001Zooooo`007?ooool00ol0003oooooooooo`1Sooooo`;o00001_ooool2o`0000Gooooo0_l00006
ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o000000?oooooo`000?l000002Oooool2
o`0002kooooo0_l00006ooooo`;o00001?ooool4o`0000Sooooo1_l0001Xooooo`007?ooool00ol0
003oooooooooo`1Mooooo`;o00001?ooool2o`0000Kooooo0_l00005ooooo`;o00002Oooool2o`00
00Cooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000Cooooo0_l0000foooo
o`Co00000_ooool2o`0000Cooooo0_l00004ooooo`So0000I_ooool001cooooo00?o0000oooooooo
ool0GOooool2o`0000[ooooo0_l0000Hooooo`Oo000000?oooooo`000?l000000_ooool2o`000004
ooooool0003o0000o`0000?ooooo0_l0000Wooooo`;o00000_ooool2o`0000Cooooo0_l00008oooo
o`;o00000_ooool6o`000004ooooool0003o0000o`0006Kooooo000Looooo`03o`000?oooooooooo
05cooooo0_l0000;ooooo`;o00000oooool2o`0000;ooooo0_l00007ooooo`;o00000_ooool2o`00
00?ooooo2_l000000ooooooo0000o`000004o`0000?ooooo0_l0000Wooooo`?o000000?oooooo`00
0?l000002Oooool2o`000004ooooool0003o0000o`0000;ooooo0ol00005ooooo`;o0000Ioooool0
01cooooo00?o0000ooooooooool0G?ooool2o`0000Gooooo0_l00009ooooo`;o00000_ooool2o`00
00Oooooo1_l00002ooooo`oo000000?oooooo`000?l00000;Oooool2o`0000;ooooo0_l00007oooo
o`?o000000?oooooo`000?l000000_l000000ooooooo0000o`000008ooooo`;o0000IOooool001co
oooo00?o0000ooooooooool0H?ooool2o`000003ooooool0003o000001Kooooo1ol000000ooooooo
0000o`00000;o`0000?ooooo1?l00002ooooo`;o0000:oooool2o`0000Oooooo0ol000000ooooooo
0000o`000006o`0000Oooooo0ol0001Tooooo`007?ooool00ol0003oooooooooo`1Nooooo`Co0000
1_ooool2o`0000kooooo0_l000000ooooooo0000o`000003ooooo`?o00001Oooool:o`0000;ooooo
0ol00002ooooo`;o00008_ooool2o`0000Oooooo0_l00008ooooo`;o00001Oooool4o`0000Sooooo
0_l0001Tooooo`007?ooool00ol0003oooooooooo`1Gooooo`;o00001Oooool2o`0000?ooooo0_l0
00000ooooooo0000o`000002o`0000?ooooo0ol00004ooooo`Wo000000?oooooo`000?l000001?l0
0005ooooo`;o00000oooool4o`0000?ooooo0ol00003ooooo`;o00008?ooool2o`0000Oooooo0_l0
0005ooooo`;o00002?ooool3o`0000[ooooo0_l0001Sooooo`007?ooool00ol0003oooooooooo`1G
ooooo`?o00002Oooool6o`0000Cooooo0ol00004ooooo`Co000000?oooooo`000?l000000oooool;
o`0000Gooooo0_l00006ooooo`;o000000?oooooo`000?l000000_l0000Pooooo`Co00001Oooool2
o`0000?ooooo1?l0000<ooooo`Co00001Oooool2o`0006?ooooo000Looooo`;o0000E_ooool2o`00
0004ooooool0003o0000ooooo`;o00002?ooool2o`0000oooooo0_l00005ooooo`co00001Oooool2
o`0000Wooooo0_l00004ooooo`?o00006oooool4o`0000[ooooo0_l0000>ooooo`Go0000JOooool0
01cooooo00?o0000ooooooooool0EOooool2o`0000?ooooo0ol0000Gooooo`;o00001_ooool>o`00
01Gooooo0ol0000Looooo`;o00002oooool2o`00017ooooo0_l0001Yooooo`007?ooool00ol0003o
ooooooooo`1Jooooo`;o00001?ooool2o`0000cooooo0_l00004ooooo`;o00000_ooool2o`0000;o
oooo3_l000000ooooooo0000o`00001Booooo`?o00001_ooool2o`0005oooooo000Looooo`03o`00
0?oooooooooo05;ooooo1?l00004ooooo`;o00001?ooool2o`0000cooooo0ol00003ooooo`;o0000
0_oooolEo`000003ooooool0003o000000kooooo0_l0000Wooooo`;o00000oooool2o`00017ooooo
0ol000000ooooooo0000o`000003ooooo`;o0000Goooool001cooooo00?o0000ooooooooool0DOoo
ool5o`0000Cooooo0_l0000Cooooo`;o000000?oooooo`000?l000000_l00004oooooaKo00003_oo
ool2o`000003ooooool0003o000002Cooooo0_l00003ooooo`;o00001?ooool2o`0000gooooo1Ol0
0002ooooo`;o0000Goooool001cooooo00?o0000ooooooooool0D?ooool3o`000003ooooool0003o
000000Kooooo0_l0000Dooooo`;o00001_oooolFo`0000oooooo1?l0000Yooooo`;o00001?ooool2
o`0000gooooo0_l000000ooooooo0000o`00001Sooooo`007?ooool00ol0003oooooooooo`1?oooo
o`Co00001oooool4o`0001?ooooo1Ol00004oooooa7o000000?oooooo`000?l000000_l000000ooo
oooo0000o`00000<ooooo`Co000000?oooooo`000?l000009_ooool2o`0001Sooooo0_l0001Qoooo
o`007?ooool00ol0003oooooooooo`1?ooooo`;o00001?ooool2o`0000?ooooo0_l0000Eooooo`;o
000000?oooooo`000?l000001?oooolFo`000004ooooool0003o0000o`00013ooooo0_l0000Xoooo
o`;o00005Oooool3o`00067ooooo000Looooo`03o`000?oooooooooo04oooooo0_l00004ooooo`?o
00006Oooool2o`0000Oooooo4ol000000ooooooo0000o`000004o`0000gooooo0_l000000ooooooo
0000o`00000Gooooo`;o00003oooool3o`0001Cooooo0_l000000ooooooo0000o`000003o`0005co
oooo000Looooo`03o`000?oooooooooo04gooooo0_l00006ooooo`?o00008_oooolJo`0000gooooo
0_l000001?oooooo0000o`000?l0000Fooooo`;o00004?ooool2o`0000Kooooo0_l0000=ooooo`Oo
0000G?ooool001cooooo00?o0000ooooooooool0COooool3o`0000Gooooo0_l0000Toooooa[o0000
3?ooool2o`0000;ooooo0_l0000Mooooo`;o00000oooool2o`0000Cooooo0ol00002ooooo`;o0000
00?oooooo`000?l000003Oooool4o`0005oooooo000Looooo`03o`000?oooooooooo04_ooooo0_l0
00000ooooooo0000o`000002o`000003ooooool0003o000000;ooooo0_l0000Roooooako00002_oo
ool2o`0001oooooo0_l00003ooooo`;o00001?ooool7o`00013ooooo1?l0001Oooooo`007?ooool0
0ol0003oooooooooo`1;ooooo`;o00000_ooool3o`000003ooooool0003o000000Co00005oooool2
o`0000Sooooo0_l00002ooooo`Wo000000?oooooo`000?l000003ol0000:ooooo`;o00005_ooool2
o`0000_ooooo0_l00006ooooo`Co00004_ooool5o`000003ooooool0003o000005_ooooo000Loooo
o`03o`000?oooooooooo04Sooooo1?l000000ooooooo0000o`000002o`0000Cooooo0_l0000Ioooo
o`;o00002?ooool2o`0000;ooooo6ol0000Rooooo`;o00002oooool2o`0000Kooooo0_l000000ooo
oooo0000o`00000Cooooo`Ko0000Foooool001cooooo00?o0000ooooooooool0B?ooool4o`000003
ooooool0003o000000;o00007oooool4o`0000Kooooo0_l000000ooooooo0000o`00000Jo`0000co
oooo0_l0000Booooo`;o00006?ooool2o`0000;ooooo0_l0000?ooooo`Ko0000Foooool001cooooo
00?o0000ooooooooool0BOooool3o`0000Gooooo0_l0000Mooooo`Co00001_ooool2o`000004oooo
ool0003o0000o`0000;ooooo5ol000001?oooooo0000o`000?l00007ooooo`?o00004_ooool2o`00
00gooooo0_l000000ooooooo0000o`000007ooooo`;o000000?oooooo`000?l000001?ooool2o`00
00Wooooo0ol0001Nooooo`007?ooool2o`0004Kooooo1Ol00005ooooo`Co00006oooool2o`0000ko
oooo0_l00002oooooaOo000000Coooooo`000?l0003o00001oooool3o`0001_ooooo0_l00004oooo
o`;o000000?oooooo`000?l000001oooool5o`0000Cooooo0_l0000:ooooo`;o0000G_ooool001co
oooo00?o0000ooooooooool0AOooool5o`0000Gooooo0ol0000Iooooo`;o000000?oooooo`000?l0
00000_ooool2o`0000[ooooo0_l00002oooooaWo00001Oooool2o`0000;ooooo0_l0000Looooo`;o
00000_ooool2o`0000kooooo1?l00003ooooo`;o00002_ooool2o`0005kooooo000Looooo`03o`00
0?oooooooooo04Kooooo0ol0000Rooooo`;o00001Oooool3o`000003ooooool0003o000000Kooooo
0_l00002oooooaWo00001Oooool2o`0000;ooooo0_l0000>ooooo`;o00004?ooool2o`0000oooooo
0ol00002ooooo`;o00002oooool2o`0005kooooo000Looooo`03o`000?oooooooooo04;ooooo0_l0
0007ooooo`;o00007Oooool4o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo
0_l00002ooooo`;o00001?oooolCo`0000;ooooo0_l0000Hooooo`;o00009_ooool2o`0000_ooooo
0_l0001Nooooo`007?ooool00ol0003oooooooooo`12ooooo`Co00001Oooool2o`0001gooooo1?l0
0002ooooo`;o00002Oooool3o`000003ooooool0003o000000Gooooo4ol000000ooooooo0000o`00
000>ooooo`;o00001_ooool2o`0002Sooooo0_l0000;ooooo`;o00000oooool2o`0005Wooooo000L
ooooo`03o`000?oooooooooo04;ooooo1?l00005ooooo`;o00007Oooool4o`0000cooooo1?l00003
ooooo`;o00001?oooolBo`000003ooooool0003o000000kooooo0_l00006ooooo`;o0000:?ooool2
o`0000_ooooo0_l00003ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0@_ooool2o`00
02Kooooo0ol0000=ooooo`?o00001?ooool2o`0000Cooooo4Ol00002ooooo`Ko000000?oooooo`00
0?l000001?l000000ooooooo0000o`00000<ooooo`;o00004Oooool2o`0000Oooooo0_l00007oooo
o`?o00001?ooool2o`0006Gooooo000Looooo`03o`000?oooooooooo03oooooo0_l0000Xooooo`Co
00002?ooool2o`0000Cooooo0ol0000:ooooo`go000000?oooooo`000?l000000_ooool6o`000003
ooooool0003o000000Co000000?oooooo`000?l000001Oooool2o`0000Gooooo0_l0000?ooooo`Co
00001oooool2o`0000Oooooo0ol00004ooooo`;o0000<?ooool2o`0003?ooooo000Looooo`03o`00
0?oooooooooo03gooooo1Ol0000Uooooo`Go00002Oooool2o`000003ooooool0003o000000Co0000
00?oooooo`000?l000002?ooool?o`000004ooooool0003o0000ooooo`Wo00002_ooool4o`0000Oo
oooo0_l00008ooooo`;o000000?oooooo`000?l000000_l00006ooooo`;o00004?ooool2o`0002oo
oooo0_l0000cooooo`007?ooool00ol0003oooooooooo`0mooooo`Oo00008oooool6o`0000Sooooo
0_l000000ooooooo0000o`000003o`0000;ooooo0ol00004ooooo`;o000000?oooooo`000?l00000
0oooool2o`0000?ooooo1?l00002ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`000003
ooooool0003o000000cooooo0_l00007ooooo`;o00001Oooool2o`000003ooooool0003o000000?o
oooo0_l00003ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Sooooo0_l00005ooooo`;o
00000oooool2o`00027ooooo1?l0000cooooo`007?ooool00ol0003oooooooooo`0looooo`So0000
9?ooool2o`000003ooooool0003o000000Gooooo0_l00002ooooo`;o000000Coooooo`000?l0003o
oooo1_l000000ooooooo0000o`000003o`0000Gooooo0ol00003ooooo`;o00002?ooool2o`0002;o
oooo0ol00005ooooo`;o00000oooool3o`0000Sooooo0ol00003ooooo`;o000000?oooooo`000?l0
00000oooool5o`0000?ooooo0_l0000Qooooo`Co0000<oooool001cooooo00?o0000ooooooooool0
??ooool6o`0002Kooooo0_l00008ooooo`;o00000_ooool2o`0000Cooooo1?l00002ooooo`Ko0000
1Oooool4o`000003ooooool0003o000000;o00001?ooool5o`0000oooooo0_l0000<ooooo`?o0000
0oooool2o`0000[ooooo1ol00005ooooo`;o00000oooool2o`000003ooooool0003o000000?ooooo
1ol0000Uooooo`?o0000<oooool001cooooo00?o0000ooooooooool0??ooool3o`0002Kooooo1Ol0
0008ooooo`;o00003_ooool2o`0000;ooooo4_l000000ooooooo0000o`000002o`0000[ooooo0_l0
0005ooooo`;o00000oooool2o`0000Oooooo0ol0000<ooooo`;o000000?oooooo`000?l000001Ol0
000:ooooo`Co00000oooool4o`0000;ooooo0_l0000Vooooo`;o0000<oooool001cooooo00?o0000
ooooooooool0IOooool3o`0000Cooooo1?l00002ooooo`;o00005?ooool=o`000004ooooool0003o
0000ooooo`;o00003?ooool2o`0000[ooooo0_l00002ooooo`;o00002oooool4o`000003ooooool0
003o000000;o00001Oooool3o`0000[ooooo3Ol0000Uooooo`?o0000=Oooool00006ooooooo^k^ko
<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`00
0?oooooooooo06Wooooo0_l000000ooooooo0000o`000002o`0001;ooooo0_l000000ooooooo0000
o`000006ooooo`So00008_ooool2o`0000Oooooo2?l000000ooooooo0000o`000004o`0000;ooooo
1?l00009ooooo`;o000000?oooooo`000?l000002Ol0000Uooooo`?o0000=Oooool00006oooooomg
MgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`1Yooooo`Go00001_ooool3o`0000_ooooo0_l000000ooooooo0000o`000004o`0002Oo
oooo0_l000001?oooooo0000o`000?l00005ooooo`[o00000_ooool;o`0000;ooooo1?l00004oooo
o`;o000000?oooooo`000?l000002_l0000Uooooo`Co0000<oooool00003ooooool@413ooooo00;o
oooo00?o410@ooooooooool02Oooool5o`0000Kooooo00?o0000ooooooooool0I?ooool4o`0000;o
oooo0_l00002ooooo`Co00000_ooool7o`0000Gooooo1?l000000ooooooo0000o`000004o`0000co
oooo0_l0000Iooooo`;o000000Coooooo`000?l0003o00000_ooool2o`000003ooooool0003o0000
01?o000000?oooooo`000?l000001Ol00004ooooo`oo00009_ooool3o`0003?ooooo00000ooooooo
0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`00
067ooooo0_l000000ooooooo0000o`000006o`000003ooooool0003o000000?o00000_ooool7o`00
00Gooooo0_l00004ooooo`;o00003oooool2o`0001[ooooo0_l00004ooooo`?o00000_oooolDo`00
0003ooooool0003o000000Ko00000_ooool>o`0002Sooooo0_l0000dooooo`0000?oooooo`000?oo
ool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000oooo
ooooool0Goooool4o`0000Gooooo1?l000001?oooooo0000o`000?ooool2o`0000Kooooo0_l00003
ooooo`;o00001_ooool3o`0000Cooooo0_l0000Dooooo`;o00001?ooool2o`0000;ooooo0_l00003
ooooo`Co00001?ooool2o`000003ooooool0003o000001?o00000_ooool2o`000003ooooool0003o
000000?o000000?oooooo`000?l000003Ol0000Uooooo`Go0000=?ooool00003ooooool@413ooooo
00;ooooo00?o410@ooooooooool02_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo
05oooooo0_l000000ooooooo0000o`000003ooooo`;o00001?ooool2o`0000_ooooo0_l000000ooo
oooo0000o`000006ooooo`;o00001Oooool2o`0001Cooooo0_l00004ooooo`;o00000_ooool3o`00
00;ooooo0_l00002ooooo`;o000000?oooooo`000?l000008?l00002ooooo`oo00009Oooool5o`00
03Cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l000001oooool0
0ol0003oooooooooo`1Mooooo`;o00000oooool2o`0000;ooooo0ol00002ooooo`Co00002oooool2
o`0001kooooo0_l0000Aooooo`;o00001_oooolJo`000003ooooool0003o000000Co000000?ooooo
o`000?l000000_oooolAo`0002Cooooo0_l0000gooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^
k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0GOooool2o`0000Oooooo2ol0
0003ooooo`;o000000?oooooo`000?l000000oooool2o`0001Sooooo0_l00002ooooo`Co00000_oo
ool2o`0001Gooooo6Ol000001?oooooo0000o`000?l00007oooooa7o00009?ooool2o`0003Oooooo
000Looooo`03o`000?oooooooooo05Gooooo0ol0000<ooooo`So00000oooool2o`0000?ooooo0_l0
00000ooooooo0000o`000003ooooo`;o00006?ooool2o`0000Cooooo0_l000001?oooooo0000o`00
0?l00005ooooo`;o00003_oooolMo`0000Gooooo2ol000000ooooooo0000o`000003o`0002Kooooo
1?l0000eooooo`007?ooool00ol0003oooooooooo`1Dooooo`Co00002_ooool6o`0000oooooo0_l0
000Vooooo`?o00000oooool4o`000004ooooool0003o0000o`0000;ooooo0_l00002ooooo`;o0000
0_oooolMo`000003ooooool0003o0000013o0000:_ooool3o`0003Gooooo000Looooo`03o`000?oo
oooooooo04oooooo0_l00003ooooo`;o00003?ooool3o`0000;ooooo0ol00004ooooo`;o00000ooo
ool2o`0000;ooooo0_l00004ooooo`;o00009_ooool2o`0000?ooooo0ol00002ooooo`;o00000_oo
ool2o`000003ooooool0003o000001Wo000000?oooooo`000?l000004_l0000[ooooo`?o0000=Ooo
ool001cooooo00?o0000ooooooooool0Coooool2o`000004ooooool0003o0000ooooo`Co000000?o
ooooo`000?l000002Oooool6o`0000?ooooo0_l00003ooooo`;o00002?ooool4o`0002Sooooo0_l0
000:ooooo`Co000000?oooooo`000?l000003?l000000ooooooo0000o`000005o`0000;ooooo4Ol0
00000ooooooo0000o`00000/ooooo`;o0000=Oooool001cooooo00?o0000ooooooooool0Coooool5
o`000003ooooool0003o000000;o000000?oooooo`000?l000001?l00003ooooo`So00002?ooool2
o`0000[ooooo0_l0000Xooooo`?o00000oooool4o`0000;ooooo7ol000000ooooooo0000o`000009
o`0003;ooooo0_l0000eooooo`007?ooool00ol0003oooooooooo`1?ooooo`?o00002_ooool4o`00
00;ooooo0ol00003ooooo`;o00001Oooool2o`0000;ooooo0_l00006ooooo`;o0000:oooool4o`00
00?ooooo1?l000000ooooooo0000o`00000Mo`0000;ooooo2ol0000^ooooo`;o0000>Oooool001co
oooo00?o0000ooooooooool0C?ooool2o`0000;ooooo0_l0000@ooooo`;o00001?ooool2o`0000Go
oooo0_l0000:ooooo`;o0000:oooool7o`0000Gooooo7?l00004ooooo`Oo0000<oooool2o`000003
ooooool0003o000003Kooooo000Looooo`03o`000?oooooooooo04[ooooo1?l00009ooooo`Co0000
B_ooool2o`0000Cooooo1?l00004oooooako00000oooool4o`0003Wooooo0_l0000fooooo`007?oo
ool00ol0003oooooooooo`19ooooo`?o00001_ooool4o`000003ooooool0003o000000Co00003_oo
ool2o`0000Kooooo0_l0000`ooooo`;o00002oooool3o`000003ooooool0003o000001Wo000000?o
ooooo`000?l000001?l0000eooooo`Go0000=oooool001cooooo00?o0000ooooooooool0BOooool2
o`0000Oooooo1_l000000ooooooo0000o`000005o`0000_ooooo0ol00005ooooo`;o0000:_ooool4
o`0000oooooo1?l000000ooooooo0000o`00000Go`0000;ooooo1_l0000eooooo`Go0000=oooool0
01cooooo00?o0000ooooooooool0A_ooool2o`0000_ooooo3Ol0000<ooooo`;o00004?ooool2o`00
01[ooooo0_l00003ooooo`Co00001?ooool2o`0000[ooooo0ol000000ooooooo0000o`00000Fo`00
00?ooooo0_l000000ooooooo0000o`00000dooooo`;o000000Coooooo`000?l0003o0000>?ooool0
01cooooo0_l00017ooooo`;o00002oooool?o`0001cooooo0_l0000Jooooo`;o00001oooool2o`00
00;ooooo0_l000000ooooooo0000o`000007oooooa?o000000?oooooo`000?l000001_l00002oooo
o`?o000000?oooooo`000?l00000=?ooool2o`000003ooooool0003o000000;o0000=oooool001co
oooo00?o0000ooooooooool0@?ooool2o`0000?ooooo1?l0000;ooooo`ko00002oooool2o`000003
ooooool0003o000000kooooo0_l0000Qooooo`;o000000?oooooo`000?l000000_ooool2o`0000Oo
oooo7?l00002ooooo`?o0000=oooool2o`000003ooooool0003o000000;o0000=oooool001cooooo
00?o0000ooooooooool0@?ooool2o`0000;ooooo1Ol0000:oooooa7o00002Oooool5o`0000kooooo
0_l0000=ooooo`Co00004?ooool2o`000003ooooool0003o000000_ooooo7Ol0000jooooo`;o0000
0_ooool2o`0003Wooooo000Looooo`03o`000?oooooooooo03oooooo0_l00003ooooo`?o00001ooo
ool2o`0000?ooooo4Ol0000:ooooo`Co00001_ooool2o`0001Gooooo1?l000000ooooooo0000o`00
000Dooooo`;o00002?oooolLo`0003[ooooo0ol000000ooooooo0000o`000002o`0003Oooooo000L
ooooo`03o`000?oooooooooo03oooooo0_l00002ooooo`;o00000_ooool2o`0000Gooooo0_l00003
oooooa7o00002_ooool4o`0000;ooooo0_l00002ooooo`;o00006_ooool2o`0000kooooo0_l00004
ooooo`;o00001oooool5o`000003ooooool0003o000000oo00000oooool2o`0003[ooooo1?l00003
ooooo`;o0000=oooool001cooooo00?o0000ooooooooool0@oooool2o`0000;ooooo0_l00005oooo
o`;o00000_oooolBo`0000Wooooo0_l00005ooooo`;o00001_ooool2o`0000[ooooo0_l0000Ioooo
o`?o00000_ooool2o`0000Sooooo7Ol0000jooooo`;o00001oooool2o`0003Gooooo000Looooo`03
o`000?oooooooooo04Kooooo0_l00004ooooo`Co00000_oooolBo`0000Wooooo1Ol0000:ooooo`;o
00002_ooool2o`0000Gooooo0_l0000Booooo`;o00000oooool2o`0000Sooooo0_l000000ooooooo
0000o`00000?o`000003ooooool0003o000000Co0000??ooool2o`0000Oooooo0_l0000eooooo`00
7?ooool00ol0003oooooooooo`0oooooo`;o00001Oooool2o`0000Cooooo0_l00004oooooa?o0000
2?ooool5o`0001cooooo0ol0000:ooooo`;o00002?ooool2o`000003ooooool0003o000000;ooooo
0_l00007ooooo`?o00000_ooool9o`000003ooooool0003o000000Ko0000A_ooool2o`000003oooo
ool0003o000003;ooooo000Looooo`03o`000?oooooooooo03oooooo0_l0000Aoooooa?o00002ooo
ool2o`0000;ooooo0_l0000Hooooo`;o00002oooool2o`0000Sooooo0_l000000ooooooo0000o`00
0002ooooo`;o00001_ooool2o`0000Cooooo2Ol000000ooooooo0000o`000003o`0004Wooooo0_l0
00000ooooooo0000o`00000booooo`007?ooool00ol0003oooooooooo`0oooooo`;o00001?ooool3
o`0000?ooooo1Ol000000ooooooo0000o`00000Ao`0000cooooo0_l00002ooooo`;o00008Oooool2
o`0000oooooo0_l00004ooooo`;o00000oooool3o`0000kooooo1?l000000ooooooo0000o`000019
ooooo`;o0000<oooool001cooooo00?o0000ooooooooool0AOooool3o`0000?ooooo6ol0000:oooo
o`;o00009Oooool2o`0000Wooooo0_l0000:ooooo`;o00000oooool2o`0000[ooooo1_l000001?oo
oooo0000o`000?ooool2o`0003kooooo0_l00002ooooo`;o00001Oooool2o`000003ooooool0003o
0000033ooooo000Looooo`03o`000?oooooooooo03_ooooo1Ol0000@oooooaKo00002_ooool3o`00
02oooooo0_l00005ooooo`;o00001?ooool2o`0000Cooooo1?l00006ooooo`Ko0000A?ooool2o`00
00;ooooo0_l00006ooooo`Co0000<?ooool001cooooo00?o0000ooooooooool0>_ooool8o`0000Co
oooo0_l00005ooooo`;o00000_oooolFo`0000Wooooo0ol0000Pooooo`;o00000_ooool2o`000003
ooooool0003o000000gooooo0_l00004ooooo`;o00001?ooool4o`000003ooooool0003o000000;o
oooo1Ol0001Booooo`Co0000<?ooool001cooooo00?o0000ooooooooool0>_ooool2o`0000Cooooo
0_l00004ooooo`;o00001Oooool2o`0000?ooooo5Ol00009ooooo`;o00008Oooool2o`0000;ooooo
0_l000000ooooooo0000o`000002o`0001Wooooo0_l000000ooooooo0000o`000002ooooo`Go0000
9?ooool2o`0001oooooo0_l0000=ooooo`;o0000<?ooool001cooooo00?o0000ooooooooool0?_oo
ool2o`0000?ooooo0_l0000=oooooaKo00008oooool2o`0000Kooooo0_l00007ooooo`;o00004?oo
ool2o`0000Oooooo0_l00006ooooo`;o00009_ooool2o`0001oooooo0_l0000oooooo`007?ooool0
0ol0003oooooooooo`0nooooo`;o00000oooool2o`0000gooooo5_l0000Sooooo`;o00001_ooool2
o`0000Kooooo0_l0000Aooooo`;o00001oooool6o`00023ooooo0_l00002ooooo`;o00009Oooool2
o`000003ooooool0003o000003cooooo000Looooo`;o0000?Oooool2o`0000[ooooo0_l00008oooo
oaOo00001_ooool2o`0001cooooo0_l00007ooooo`;o00000oooool2o`0001cooooo1?l0000Poooo
o`;o00000_ooool2o`0002Gooooo0_l000000ooooooo0000o`00000looooo`007?ooool00ol0003o
ooooooooo`0looooo`;o00001_ooool6o`0000?ooooo0_l00004oooooaKo00001_ooool2o`0000Go
oooo0_l0000Dooooo`?o00000oooool2o`0000;ooooo0_l00003ooooo`;o00004?ooool2o`0000go
oooo0_l0000Mooooo`;o00003Oooool2o`0001cooooo0_l0000oooooo`007?ooool00ol0003ooooo
ooooo`0jooooo`;o00001_ooool6o`0000;ooooo0_l000001?oooooo0000o`000?l00003oooooa?o
000000?oooooo`000?l000001Oooool2o`0000;ooooo0_l00002ooooo`;o00004_ooool4o`0000Co
oooo0_l0000Iooooo`;o00003Oooool2o`0001gooooo0ol0000<ooooo`;o00007_ooool2o`0000[o
oooo0_l0000aooooo`007?ooool00ol0003oooooooooo`0jooooo`;o00001_ooool2o`0000Kooooo
1_l00003ooooo`;o000000?oooooo`000?l000003Ol00002ooooo`;o00001Oooool2o`0000;ooooo
0_l0000Eooooo`?o0000Coooool3o`0000Sooooo0_l0000Pooooo`Co00001Oooool2o`0000?ooooo
0_l0000aooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00002?ooool?o`0002Cooooo1?l0
000Vooooo`;o0000;Oooool2o`0000;ooooo0_l00005ooooo`;o00006Oooool4o`0000Gooooo0_l0
0002ooooo`?o0000<Oooool001cooooo00?o0000ooooooooool0E_ooool2o`000003ooooool0003o
000000_o00002Oooool2o`0001Sooooo1?l00009ooooo`;o00000oooool2o`0001Kooooo0ol0000/
ooooo`;o00000_ooool2o`000003ooooool0003o000000Co00006oooool2o`0000Wooooo0_l0000b
ooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00005?ooool3o`0000Wooooo0ol000000ooo
oooo0000o`000005o`0000Wooooo1?l0000:ooooo`;o00005?ooool2o`000003ooooool0003o0000
00?ooooo0_l0000Fooooo`?o0000<?ooool2o`000003ooooool0003o000000Co00008_ooool2o`00
03Kooooo000Looooo`03o`000?oooooooooo03Wooooo0_l0000Dooooo`?o000000?oooooo`000?l0
00000oooool2o`0000Gooooo1ol00003ooooo`;o00001?ooool6o`0000Sooooo0_l000000ooooooo
0000o`00000Aooooo`;o00000_ooool2o`00013ooooo0_l0000kooooo`Co00000_ooool2o`0002?o
oooo0ol0000eooooo`007?ooool00ol0003oooooooooo`1Aooooo`Co00000oooool2o`0000Kooooo
0ol00006ooooo`;o00000_ooool4o`0000;ooooo0_l0000;ooooo`;o00002oooool2o`0000Oooooo
0ol0000<ooooo`;o000000Coooooo`000?l0003o0000>oooool4o`0000;ooooo0_l0000Mooooo`;o
000000?oooooo`000?l000000_ooool2o`0003Gooooo000Looooo`03o`000?oooooooooo057ooooo
0_l00002ooooo`;o000000?oooooo`000?l000001oooool4o`0000Sooooo0_l0000Nooooo`Co0000
1Oooool2o`0000[ooooo1Ol000001?oooooo0000o`000?l0000looooo`;o00001?ooool2o`0001co
oooo1Ol0000iooooo`007?ooool00ol0003oooooooooo`1Eooooo`;o00002_ooool4o`0000Oooooo
0_l00002ooooo`;o00007Oooool2o`0000Gooooo0_l00009ooooo`Oo000000?oooooo`000?l00000
0oooool2o`0003Oooooo0_l00003ooooo`?o00007Oooool3o`0003[ooooo000Looooo`03o`000?oo
oooooooo03Gooooo0_l0000Pooooo`;o000000?oooooo`000?l000001_ooool2o`0000Oooooo0ol0
0002ooooo`;o00007_ooool2o`0000gooooo1Ol000001?oooooo0000o`000?l00003ooooo`;o0000
00Coooooo`000?l0003o0000>oooool2o`0001_ooooo0_l000000ooooooo0000o`000003o`0003So
oooo000Looooo`03o`000?oooooooooo03Gooooo0_l0000Pooooo`;o000000?oooooo`000?l00000
0_l00004ooooo`;o00001?ooool2o`000003ooooool0003o0000017ooooo0_l00004ooooo`;o0000
2Oooool3o`0000gooooo0_l000000ooooooo0000o`000003o`0000Cooooo1ol00002ooooo`;o0000
=_ooool2o`0001_ooooo0_l00003ooooo`Co0000=oooool001cooooo00?o0000ooooooooool0Fooo
ool3o`0000Kooooo1_l0000Dooooo`;o00000_ooool4o`0000Cooooo0_l00003ooooo`;o00001Ooo
ool2o`0000Oooooo0_l00002ooooo`?o00001oooool2o`000003ooooool0003o000000;ooooo0ol0
000Xooooo`Co00000_ooool2o`0000Cooooo0_l0000Pooooo`Go0000=oooool001cooooo00?o0000
ooooooooool0Foooool2o`0000Oooooo1Ol0000<ooooo`Co00002?ooool3o`0000Kooooo0_l0000:
ooooo`;o00003?ooool2o`0000;ooooo1?l00006ooooo`;o000000?oooooo`000?l00000:?ooool4
o`0000;ooooo0_l00003ooooo`?o00008?ooool2o`0000;ooooo0_l00002ooooo`;o0000<_ooool0
01cooooo00?o0000ooooooooool0=Oooool2o`0002cooooo1_l0000<ooooo`Co00000_ooool2o`00
00Cooooo0_l00008ooooo`;o00000oooool2o`0000Sooooo0_l00003ooooo`;o00000oooool2o`00
00;ooooo1Ol00005ooooo`;o00009oooool2o`000004ooooool0003o0000o`0000Oooooo1?l0000U
ooooo`Ko0000<_ooool001cooooo0_l0000fooooo`;o0000;?ooool2o`000003ooooool0003o0000
00?o00003_ooool4o`0000Cooooo0_l00008ooooo`;o00000oooool2o`0000Sooooo0_l000000ooo
oooo0000o`000002o`0000Oooooo2?l00008ooooo`;o00007oooool4o`000003ooooool0003o0000
00Co00001?ooool2o`0002Wooooo0_l0000dooooo`007?ooool00ol0003oooooooooo`0eooooo`;o
0000;oooool7o`0000cooooo1?l00003ooooo`;o00000oooool2o`0000Cooooo0_l00003ooooo`;o
00002oooool2o`0000Oooooo2ol000001?oooooo0000o`000?l00003ooooo`;o00007oooool4o`00
00;ooooo1_l00003ooooo`;o000000?oooooo`000?l000006Oooool2o`0000Wooooo0_l0000foooo
o`007?ooool00ol0003oooooooooo`0eooooo`;o0000;oooool3o`000004ooooool0003o0000o`00
01?ooooo0_l00003ooooo`;o00002?ooool4o`0000[ooooo0_l00007ooooo`_o000000?oooooo`00
0?l000000_l000001?oooooo0000o`000?ooool2o`0002Gooooo1Ol00002ooooo`;o000000?ooooo
o`000?l000006Oooool2o`0000Wooooo0_l0000fooooo`007?ooool00ol0003oooooooooo`0doooo
o`;o0000=?ooool2o`0002?ooooo1?l00004ooooo`;o00001?ooool2o`0000Oooooo4?l000001?oo
oooo0000o`000?ooool2o`0002Sooooo0_l0000Qooooo`Co0000?_ooool001cooooo00?o0000oooo
ooooool0<oooool3o`0002_ooooo0_l0000Iooooo`;o00003Oooool2o`0000?ooooo0_l00005oooo
o`;o00001?ooool4o`0000;ooooo4ol0000/ooooo`Co00008Oooool4o`0000Oooooo0_l0000eoooo
o`007?ooool00ol0003oooooooooo`0cooooo`;o0000:_ooool5o`0000;ooooo1?l00007ooooo`;o
000000?oooooo`000?l000001_ooool2o`0000gooooo1_l00006ooooo`;o00001?ooool4o`000003
ooooool0003o000001?o00001?ooool2o`0002Gooooo1Ol0000Mooooo`;o00001_ooool2o`0000Co
oooo0_l0000eooooo`007?ooool00ol0003oooooooooo`1Oooooo`Go00000_ooool8o`0000?ooooo
0_l000000ooooooo0000o`000009ooooo`;o00001Oooool2o`0000Gooooo1?l0000=ooooo`;o0000
0_oooolEo`0000Cooooo0_l0000Tooooo`So000000?oooooo`000?l000006?ooool4o`0000Cooooo
0_l0000kooooo`007?ooool00ol0003oooooooooo`1Oooooo`Co00001_ooool7o`0000cooooo0_l0
00000ooooooo0000o`000005ooooo`;o00001?ooool2o`0000Gooooo0_l00007ooooo`?o00000ooo
oolEo`0000Cooooo0_l0000=ooooo`;o00000oooool2o`0000kooooo2_l000000ooooooo0000o`00
000Hooooo`Co00001?ooool3o`0003[ooooo000Looooo`03o`000?oooooooooo03Cooooo0_l0000Y
ooooo`Co00001_ooool7o`000003ooooool0003o000000Wooooo0_l000000ooooooo0000o`00000;
ooooo`Co00000oooool4o`0000;ooooo1_l00002oooooaKo00001Oooool2o`0000cooooo0_l00003
ooooo`;o00003_ooool6o`000003ooooool0003o000000;o00006_ooool2o`0000Kooooo0ol00000
0ooooooo0000o`00000gooooo`007?ooool00ol0003oooooooooo`0dooooo`?o00009oooool4o`00
00;ooooo0_l00003ooooo`Co00001?ooool5o`000003ooooool0003o000000;o00001?ooool2o`00
00cooooo0ol00005ooooo`?o000000?oooooo`000?l000000ol000000ooooooo0000o`00000Fo`00
00Gooooo0_l0000Qooooo`Go00000oooool3o`0002?ooooo0_l000000ooooooo0000o`00000goooo
o`007?ooool00ol0003oooooooooo`0cooooo`Co00009oooool3o`0000?ooooo0_l0000=ooooo`?o
000000?oooooo`000?l000001?l00008ooooo`;o00003_ooool9o`000004ooooool0003o0000oooo
oaCo00001_ooool3o`00023ooooo1_l00002ooooo`?o00008oooool2o`0003[ooooo000Looooo`03
o`000?oooooooooo03?ooooo0_l0000Yooooo`?o00006_ooool2o`0000Sooooo0_l0000?ooooo`Oo
00000ooooolDo`0000Wooooo0ol0000Oooooo`?o000000Coooooo`000?l0003ooooo0ol0000Woooo
o`;o0000=oooool001cooooo00?o0000ooooooooool0Goooool2o`0001kooooo0_l00002ooooo`;o
00005?ooool4o`000003ooooool0003o000001Co000000?oooooo`000?l000001oooool4o`0001co
oooo1?l00003ooooo`?o00006_ooool2o`0000cooooo0_l0000gooooo`007?ooool00ol0003ooooo
ooooo`0cooooo`;o0000:_ooool2o`0000Sooooo0_l0000Dooooo`Ko00004_ooool2o`000003oooo
ool0003o000001_o00001_ooool2o`000003ooooool0003o000000?o00001Oooool4o`00013ooooo
1?l00002ooooo`?o00006oooool2o`0004Gooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGo
oooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0coooo
o`;o0000=?ooool2o`00017ooooo0_l00003ooooo`?o00001_ooool2o`0000Gooooo0ol00003oooo
o`;o000000?oooooo`000?l000001?l000000ooooooo0000o`00000Co`0000Oooooo0_l00003oooo
o`?o000000Goooooo`000?l0003o0000ooooo`08o`0000cooooo0ol00002ooooo`?o00009?ooool2
o`0000?ooooo0_l0000hooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?oo
ool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0HOooool3o`0001Sooooo
0_l00004ooooo`;o00001_ooool2o`0000Gooooo0ol00006ooooo`;o00001OoooolAo`000004oooo
ool0003o0000o`0000Sooooo0_l00006ooooo`?o000000?oooooo`000?l000001ol0000;ooooo`;o
00000oooool2o`0002Gooooo0_l00003ooooo`;o0000>?ooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool0H?ooool4o`00017ooooo0_l0000;ooooo`;o00003?ooool2o`0000Sooooo6Ol0000;ooooo`;o
00003oooool6o`0000Wooooo0_l00003ooooo`;o00008oooool2o`0003oooooo00000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o
0000=_ooool2o`0002Sooooo1?l0000=ooooo`;o00000_ooool3o`000003ooooool0003o000001Go
oooo0_l0000:ooooo`Go000000?oooooo`000?l000003ol0000Nooooo`Co00003Oooool2o`0002Co
oooo0_l0000oooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`00
0?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0fooooo`;o0000:?ooool5o`0000_o
oooo0ol00002ooooo`?o000000Coooooo`000?l0003o00000_ooool2o`0000?ooooo0_l0000Goooo
o`?o00000_oooolBo`0000Gooooo0_l00002ooooo`;o00005?ooool6o`0000Gooooo0_l000000ooo
oooo0000o`000002o`0006Gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wo
oooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`1Pooooo`;o000000Coooooo`000?l0
003o00000oooool2o`0000Gooooo0_l000000ooooooo0000o`000005ooooo`?o000000?oooooo`00
0?l000000oooool2o`0001Oooooo0ol00002oooooa?o00001?ooool2o`0000;ooooo0_l00002oooo
o`;o00000_ooool5o`0000Sooooo1ol00005ooooo`;o000000Coooooo`000?l0003o00008Oooool2
o`0000Gooooo0_l0000looooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@
413oV9RH00Sooooo00?o0000ooooooooool0Goooool3o`0000;ooooo0_l000000ooooooo0000o`00
0003o`0000?ooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000000Oooooo0_l0
0002ooooo`;o00006OoooolAo`0000cooooo0_l00002ooooo`Oo00001_ooool7o`0000?ooooo0ol0
00001?oooooo0000o`000?l0000Rooooo`;o00001?ooool3o`0003cooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`1Ooooo
o`;o00001_ooool2o`000003ooooool0003o000000?ooooo2ol000000ooooooo0000o`000003oooo
o`;o00000_ooool6o`0001_ooooo3_l00004ooooo`;o00002?ooool2o`0000Kooooo0_l00006oooo
o`Go000000?oooooo`000?l000000_ooool3o`000004ooooool0003o0000o`0002Sooooo0_l0000m
ooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o00002_oooolAo`0000Gooooo1?l00002oooo
o`;o00006?ooool2o`0000?ooooo0_l000000ooooooo0000o`000009o`0000Cooooo0_l00008oooo
o`;o00001_ooool2o`0000Gooooo1Ol000000ooooooo0000o`000006o`0000;ooooo0_l0001Woooo
o`007?ooool00ol0003oooooooooo`0jooooo`;o00008Oooool3o`0000Kooooo0_l00002oooooa?o
00000_ooool5o`0001cooooo1?l00004ooooo`;o000000?oooooo`000?l000001_l00004ooooo`;o
00002?ooool2o`0000Kooooo0_l00005ooooo`Go000000?oooooo`000?l000001?l0001]ooooo`00
7?ooool00ol0003oooooooooo`0iooooo`?o00008Oooool3o`0000Cooooo1?l00002oooooa_o0000
7Oooool3o`0000;ooooo2?l000001?oooooo0000o`000?l00004ooooo`;o00002Oooool4o`0000Co
oooo0_l00004ooooo`Co00000oooool9o`0006Wooooo000Looooo`03o`000?oooooooooo03Wooooo
0_l0000Rooooo`Co00000ooooolQo`0001gooooo0ol00002ooooo`Go000000Coooooo`000?l0003o
00004_ooool4o`0000Cooooo0_l00005ooooo`Co000000Coooooo`000?l0003ooooo0_l000000ooo
oooo0000o`000002o`00027ooooo0_l000000ooooooo0000o`000002ooooo`;o0000?oooool001co
oooo00?o0000ooooooooool0>?ooool4o`00023ooooo1Ol00002oooooaGo000000?oooooo`000?l0
00002_l0000Pooooo`;o000000?oooooo`000?l000000oooool3o`0000Sooooo0_l00006ooooo`;o
00000_ooool2o`0000Gooooo0_l00004ooooo`Oo00000oooool3o`0002?ooooo0_l000001?oooooo
0000o`000?ooool3o`0003oooooo000Looooo`03o`000?oooooooooo03Sooooo1?l0000Pooooo`;o
00001OoooolKo`0000;ooooo1?l0000Qooooo`;o000000?oooooo`000?l000002oooool2o`000003
ooooool0003o000000Gooooo0ol00008ooooo`Co00000oooool8o`000004ooooool0003o0000o`00
02Oooooo0_l000000ooooooo0000o`000010ooooo`007?ooool00ol0003oooooooooo`0nooooo`;o
00009Oooool;o`000003ooooool0003o000000_o000000?oooooo`000?l000000ol0000Qooooo`Go
000000?oooooo`000?l000002?ooool2o`0000Sooooo0_l00009ooooo`Co00000oooool<o`0002?o
oooo0_l00003ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0?_ooool2o`00027ooooo
1?l000000ooooooo0000o`00000Fo`000003ooooool0003o000000;o00009?ooool3o`000003oooo
ool0003o000000Sooooo0ol00005ooooo`Go00004Oooool8o`00027ooooo0_l000001?oooooo0000
o`000?l00003ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0?_ooool2o`0001_ooooo
0_l00004oooooago000000?oooooo`000?l000000_l0000Uooooo`?o00002oooool2o`0000?ooooo
1ol0000;ooooo`;o00001Oooool4o`0002Cooooo0_l000000ooooooo0000o`000018ooooo`007?oo
ool00ol0003oooooooooo`0nooooo`;o00006oooool2o`0000Cooooo8_l0000Vooooo`;o00004?oo
ool2o`0000?ooooo0_l000000ooooooo0000o`000003o`0000?ooooo1Ol0000/ooooo`;o00000_oo
ool3o`0004Kooooo000Looooo`03o`000?oooooooooo05[ooooo0ol00007oooooaco0000<?ooool4
o`0000Oooooo0_l00003ooooo`;o000000?oooooo`000?l000000ol00003ooooo`;o000000?ooooo
o`000?l000006oooool2o`0000gooooo0_l00004ooooo`?o0000A_ooool001cooooo0_l00012oooo
o`;o00005oooool2o`0000Kooooo7_l0000`ooooo`Go00000oooool2o`000003ooooool0003o0000
00?ooooo0_l00002ooooo`;o00000_ooool3o`000003ooooool0003o000000?o00005_ooool2o`00
0004ooooool0003o0000o`0000gooooo0_l00004ooooo`;o0000Aoooool001cooooo00?o0000oooo
ooooool0?oooool4o`0001gooooo6?l000000ooooooo0000o`000005o`0003?ooooo0_l00002oooo
o`Co00000_ooool2o`0000Oooooo1Ol000001?oooooo0000o`000?ooool3o`0001Gooooo1Ol0000>
ooooo`Co00000_ooool2o`0004Oooooo000Looooo`03o`000?oooooooooo03oooooo0_l0000Ioooo
o`;o00001?oooolMo`0003[ooooo1?l00002ooooo`Co00000_ooool2o`000003ooooool0003o0000
00Oooooo0ol000000ooooooo0000o`00000>ooooo`;o00000oooool2o`00013ooooo1Ol000000ooo
oooo0000o`000017ooooo`007?ooool00ol0003oooooooooo`0oooooo`;o000000?oooooo`000?l0
00005_ooool3o`0000Cooooo7?l0000_ooooo`;o00001?ooool6o`0000Oooooo0_l00002ooooo`;o
00003Oooool4o`0000gooooo0_l00003ooooo`;o00003_ooool2o`0000?ooooo0_l000000ooooooo
0000o`000017ooooo`007?ooool00ol0003oooooooooo`0oooooo`Ko00005_ooool2o`0000;ooooo
7_l0000_ooooo`Co000000?oooooo`000?l000001Ol000000ooooooo0000o`00000Gooooo`Ko0000
1_ooool2o`0001Sooooo0_l00002ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0@Ooo
ool4o`0001Gooooo0ol00002ooooo`Co000000?oooooo`000?l000005ol0000_ooooo`Wo00001?oo
ool3o`0000Oooooo0_l00008ooooo`?o00001?ooool4o`0000Kooooo0_l000000ooooooo0000o`00
0003ooooo`Co00002_ooool4o`0000Cooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`1J
ooooo`;o00001Oooool9o`000003ooooool0003o000000oo0000<?ooool:o`0000Cooooo0ol00005
ooooo`Co00001Oooool5o`00017ooooo0_l00002ooooo`Go00002_ooool4o`00057ooooo000Loooo
o`03o`000?oooooooooo04Gooooo0_l0000Jooooo`?o00000_ooool2o`0000;ooooo4Ol0000aoooo
o`go00000_ooool2o`000003ooooool0003o000000;ooooo1Ol00003ooooo`Co00005_ooool4o`00
067ooooo000Looooo`03o`000?oooooooooo04Gooooo0_l0000Cooooo`;o00001_oooolGo`0003?o
oooo3_l000001?oooooo0000o`000?ooool2o`0000Gooooo0_l00003ooooo`Co00003Oooool3o`00
00;ooooo0_l000000ooooooo0000o`000002o`0000oooooo0_l0001Aooooo`007?ooool00ol0003o
ooooooooo`1Jooooo`?o00001_oooolFo`0003;ooooo3ol00002ooooo`;o00000oooool2o`0000co
oooo0_l0000:ooooo`?o000000?oooooo`000?l000001_l0000:ooooo`;o00000oooool2o`000003
ooooool0003o000004kooooo000Looooo`03o`000?oooooooooo05[ooooo0ol00007oooooa;o0000
=OoooolCo`0000?ooooo0_l00004ooooo`;o00001Oooool3o`0000kooooo1_l0000<ooooo`;o0000
1_ooool2o`0004kooooo000Looooo`03o`000?oooooooooo05[ooooo0_l00004ooooo`;o00000ooo
ool5o`000003ooooool0003o000000Oo0000=ooooolBo`0000;ooooo0_l00005ooooo`Co00001?oo
ool2o`000003ooooool0003o000000Gooooo0_l00006ooooo`Co00002Oooool2o`0000;ooooo1?l0
001Dooooo`007?ooool00ol0003oooooooooo`1Jooooo`;o00001?ooool2o`0000?ooooo1Ol00000
0ooooooo0000o`000003ooooo`?o0000=_ooool2o`0000?ooooo4ol00002ooooo`;o000000?ooooo
o`000?l000000_l00007ooooo`;o00001Oooool2o`0000Cooooo1Ol0000:ooooo`;o00001?ooool2
o`0005Cooooo000Looooo`03o`000?oooooooooo05gooooo0_l000001?oooooo0000o`000?l00004
ooooo`;o00001?ooool2o`0003[ooooo0_l000000ooooooo0000o`00000Ao`000003ooooool0003o
000000?o00000oooool4o`0000Gooooo0_l00009ooooo`Go00003oooool4o`000003ooooool0003o
000005;ooooo000Looooo`03o`000?oooooooooo05gooooo0_l00002ooooo`;o00001?ooool8o`00
03cooooo4_l00003ooooo`Co00001?ooool5o`0000Cooooo0_l00006ooooo`Ko00004Oooool4o`00
0003ooooool0003o000005;ooooo000Looooo`03o`000?oooooooooo06Sooooo1ol0000loooooa?o
00001Oooool2o`0000Cooooo2?l00005ooooo`Wo0000J_ooool001cooooo0_l0001Looooo`;o0000
3_ooool2o`0003kooooo4ol00005ooooo`;o00001?ooool:o`0000?ooooo1?l0000Cooooo`;o0000
F_ooool001cooooo00?o0000ooooooooool0Foooool4o`0004cooooo4ol0000=ooooo`Wo000000?o
ooooo`000?l000001?l0000>ooooo`;o00000_ooool2o`0000;ooooo0_l0001Fooooo`007?ooool0
0ol0003oooooooooo`1Looooo`?o00006Oooool2o`0002oooooo5Ol00003ooooo`;o00002?ooool=
o`000003ooooool0003o000000kooooo0_l000001?oooooo0000o`000?l00002ooooo`;o0000E_oo
ool001cooooo00?o0000ooooooooool0G?ooool2o`0001[ooooo0_l0000_oooooaGo00000oooool2
o`0000[ooooo2_l0000Booooo`Ko000000?oooooo`000?l00000Eoooool001cooooo00?o0000oooo
ooooool0G?ooool3o`0000Kooooo0_l00014oooooa;o00000_ooool2o`0000cooooo1ol0000@oooo
o`;o00000oooool4o`0000?ooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o
00001_ooool2o`0004Cooooo4Ol00003ooooo`;o00003?ooool2o`000003ooooool0003o000000;o
00004?ooool2o`0006?ooooo000Looooo`03o`000?oooooooooo05gooooo0_l00006ooooo`;o0000
2Oooool2o`0003Wooooo4Ol0002=ooooo`007?ooool00ol0003oooooooooo`1Qooooo`;o00001_oo
ool2o`0000Gooooo0_l0000ioooooa3o00001?ooool2o`0008Sooooo000Looooo`03o`000?oooooo
oooo05kooooo0_l000000ooooooo0000o`000006ooooo`;o0000@Oooool>o`0000Gooooo1?l00026
ooooo`007?ooool00ol0003oooooooooo`1Nooooo`Co0000B_ooool>o`0000Oooooo0_l0000Ioooo
o`;o000000Coooooo`000?l0003ooooo0_l0001Uooooo`007?ooool00ol0003oooooooooo`1Poooo
o`;o0000C?ooool:o`000003ooooool0003o000000Cooooo0_l0000Gooooo`;o00000_ooool2o`00
0003ooooool0003o000000?o00001Oooool2o`0005kooooo000Looooo`03o`000?oooooooooo063o
oooo0ol0001<ooooo`Wo000000?oooooo`000?l000001?ooool2o`0000[ooooo0_l00007ooooo`;o
00000_ooool2o`0000Kooooo0_l00007ooooo`;o0000G_ooool001cooooo00?o0000ooooooooool0
H?ooool3o`0004[ooooo2ol00008ooooo`;o00002Oooool2o`000003ooooool0003o000000Cooooo
0_l0000>ooooo`Co0000HOooool001cooooo00?o0000ooooooooool0H?ooool4o`0004Wooooo2ol0
0008ooooo`;o00003?ooool2o`0000Cooooo0_l00003ooooo`;o00000_ooool2o`0000Gooooo1?l0
001Qooooo`007?ooool00ol0003oooooooooo`1Qooooo`?o0000C_ooool5o`0001gooooo0_l00003
ooooo`;o00000_ooool2o`0000?ooooo1?l0001Sooooo`007?ooool00ol0003oooooooooo`1Qoooo
o`?o00000_ooool2o`0004Oooooo0_l00003ooooo`?o0000:oooool3o`0006Cooooo000Looooo`;o
0000Hoooool2o`0000;ooooo0_l00017ooooo`;o00001?ooool5o`0000gooooo0_l00003ooooo`;o
00000oooool2o`0007Kooooo000Looooo`03o`000?oooooooooo0;;ooooo0_l00003ooooo`?o0000
3Oooool3o`0000;ooooo0_l00003ooooo`;o00002_ooool2o`0006[ooooo000Looooo`03o`000?oo
oooooooo0;;ooooo0ol0000Cooooo`?o00002_ooool2o`0000Cooooo1?l0001Zooooo`007?ooool0
0ol0003oooooooooo`1Uooooo`Co0000B_ooool2o`0000;ooooo0ol00007ooooo`;o00001_ooool2
o`0000[ooooo0_l00004ooooo`;o0000K?ooool001cooooo00?o0000ooooooooool0IOooool4o`00
00;ooooo0_l0001:ooooo`?o00001oooool2o`0000;ooooo0_l00022ooooo`007?ooool00ol0003o
ooooooooo`1[ooooo`Co0000E_ooool2o`0000kooooo0_l0001booooo`007?ooool00ol0003ooooo
ooooo`1Xooooo`;o00000oooool2o`0004oooooo0_l0000@ooooo`?o00000_ooool2o`0007;ooooo
000Looooo`03o`000?oooooooooo06Sooooo1?l00003ooooo`Co0000Boooool2o`0000;ooooo0ol0
0003ooooo`;o00000oooool2o`000004ooooool0003o0000o`0007Kooooo000Looooo`03o`000?oo
oooooooo06Wooooo0ol00003ooooo`Co0000Coooool3o`0000?ooooo0_l000000ooooooo0000o`00
0002o`000003ooooool0003o000007Oooooo000Looooo`03o`000?oooooooooo06oooooo0_l0001B
ooooo`;o00001_ooool2o`0007cooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0Koooool2o`000=Sooooo000Looooo`03o`000?oooooooooo06oooooo
0_l00016ooooo`;o0000T?ooool001cooooo00?o0000ooooooooool0L_ooool2o`0000?ooooo0_l0
0003ooooo`;o000000Coooooo`000?l0003o0000=Oooool2o`00093ooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0
003oooooooooo`1booooo`;o00000oooool2o`0000?ooooo0_l000001?oooooo0000o`000?l00003
ooooo`?o00006Oooool2o`0001Kooooo0_l0002>ooooo`0000KoooooogMgMonHV9SooooooiRHV?mg
MgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0
O?ooool2o`0000Oooooo0ol0000Iooooo`;o00005_ooool2o`0000Gooooo0_l00027ooooo`0000?o
oooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`1gooooo`;o00004Oooool2o`0000?ooooo0_l0000Eooooo`Co0000
2?ooool2o`0000cooooo0_l00027ooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooooooo
o`09ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`0007Oooooo0ol00007ooooo`;o0000
1oooool2o`0000?ooooo0ol00003ooooo`?o00003_ooool4o`0000Sooooo0_l0000;ooooo`;o0000
0_ooool2o`0000oooooo0_l0001cooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooooooo
o`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`1hooooo`Ko0000
0oooool2o`0000Oooooo0_l00004ooooo`;o00000_ooool4o`00013ooooo0_l00007ooooo`;o0000
3?ooool2o`0000;ooooo0_l00008ooooo`;o00001Oooool2o`0007?ooooo00000ooooooo410@oooo
o`02ooooo`03oa0@4?oooooooooo00Wooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`00
0?oooooooooo07[ooooo1Ol00006ooooo`;o00000_ooool3o`0000Oooooo0ol00006ooooo`;o0000
1_ooool2o`0000_ooooo0_l00009ooooo`;o00003oooool2o`0000Cooooo0_l0001dooooo`0000Ko
ooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0
003oooooooooo`1jooooo`Ko00001Oooool2o`0000;ooooo0ol00006ooooo`?o00000oooool2o`00
00;ooooo0_l00006ooooo`;o00003?ooool2o`000003ooooool0003o000000Gooooo0ol00009oooo
o`;o00002Oooool2o`0007Cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoZJVY
oa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo07cooooo1?l000001?oooooo0000o`00
0?ooool2o`0000Cooooo0_l00002ooooo`?o000000?oooooo`000?l000001?ooool2o`0001Sooooo
0_l000000ooooooo0000o`000002o`0000Cooooo0_l00006ooooo`;o000000Coooooo`000?l0003o
oooo0_l0001looooo`007?ooool00ol0003oooooooooo`21ooooo`Go00002?ooool4o`0000;ooooo
0_l00003ooooo`;o00001Oooool2o`0000gooooo0_l00006ooooo`;o00002_ooool7o`000003oooo
ool0003o000007cooooo000Looooo`03o`000?oooooooooo08?ooooo0_l0000;ooooo`;o00000_oo
ool2o`0000?ooooo0_l00003ooooo`Go00001Oooool4o`0000?ooooo0ol00005ooooo`;o00000_oo
ool2o`000003ooooool0003o000000;o000000?oooooo`000?l000000_ooool3o`0007oooooo000L
ooooo`03o`000?oooooooooo08_ooooo0_l0000:ooooo`;o00001Oooool2o`000003ooooool0003o
000000Gooooo1?l000001?oooooo0000o`000?ooool2o`0000Gooooo0_l00002ooooo`Oo0000Qooo
ool001cooooo00?o0000ooooooooool0Roooool2o`0000Cooooo0_l00004ooooo`;o00003_ooool3
o`0000;ooooo1?l0000<ooooo`;o0000Roooool001cooooo00?o0000ooooooooool0TOooool3o`00
00;ooooo0ol000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000000oooool2o`00
0003ooooool0003o000000Co00002_ooool2o`0008gooooo000Looooo`03o`000?oooooooooo09;o
oooo0_l00002ooooo`Ko00000oooool2o`000003ooooool0003o000000Go000000?oooooo`000?l0
00000_l0000<ooooo`;o0000SOooool001cooooo00?o0000ooooooooool0U_ooool5o`0000;ooooo
0_l00005ooooo`?o000000?oooooo`000?l000000_ooool2o`0009_ooooo000Looooo`03o`000?oo
oooooooo09Sooooo1?l000000ooooooo0000o`000002ooooo`?o00001?ooool2o`0009oooooo000L
ooooo`03o`000?oooooooooo09Wooooo1Ol00003ooooo`Go00001_ooool2o`0000Oooooo0_l0002B
ooooo`007?ooool00ol0003oooooooooo`2Looooo`;o000000?oooooo`000?l000000_ooool3o`00
00Gooooo0ol00003ooooo`;o000000?oooooo`000?l000000_l0002Aooooo`007?ooool00ol0003o
ooooooooo`2Oooooo`;o00000_ooool3o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`Oo
0000TOooool001cooooo0_l0002Uooooo`Ko00002Oooool2o`0009Cooooo000Looooo`03o`000?oo
oooooooo0:Kooooo0_l0002Qooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0
003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Booooo`Co000000?o410@ooooooooool00ooo
ool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`?o0000oooooom:oooo
o`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?oooooo
D_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3o
oooooe;ooooo000Booooo`03oeEEEOmVIVKo00000?ooooooE?ooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00:Gooooo00Co410@o`000?l0003ooooo0_l000000ol@413ooooooooo
o`0Eooooo`Go00001?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^j@oooo
o`00Y_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l00009ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0T?oo
ool00:Kooooo00Go0000ooooooooooooooooo`00000Iooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@093ooooo002Vooooo`05o`000?oo
ooooooooooooool000002Oooool6o`0000_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool00000T?ooool00:Kooooo00Go0000ohN7Qooooooo
ZJVYo`00000Kooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo0000093ooooo002Uooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHoooooooo
ool06_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooo
oooooooooa0@402@ooooo`00`oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg093ooooo0033ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0T?oo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(216) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.4574 .3695 Mdot
.45804 .32488 Mdot
.29888 .61719 Mdot
.62935 .42372 Mdot
.55095 .68993 Mdot
.33235 .60269 Mdot
.30424 .44909 Mdot
.30341 .46414 Mdot
.33691 .65443 Mdot
.68858 .35777 Mdot
.2989 .48473 Mdot
.60386 .41436 Mdot
.2938 .45445 Mdot
.6135 .4406 Mdot
.6143 .63649 Mdot
.67619 .46555 Mdot
.47918 .35315 Mdot
.50118 .70368 Mdot
.68013 .46606 Mdot
.35815 .65166 Mdot
.4951 .6262 Mdot
.60309 .45195 Mdot
.43735 .28573 Mdot
.61459 .4425 Mdot
.69883 .45382 Mdot
.45334 .31212 Mdot
.4577 .36899 Mdot
.71969 .4539 Mdot
.64115 .42261 Mdot
.32166 .46367 Mdot
.73479 .44518 Mdot
.68193 .71158 Mdot
.5269 .55637 Mdot
.62846 .3082 Mdot
.32362 .44351 Mdot
.29772 .50295 Mdot
.31097 .62252 Mdot
.32609 .44572 Mdot
.27498 .4743 Mdot
.30082 .47773 Mdot
.30592 .4747 Mdot
.45573 .30904 Mdot
.32144 .42707 Mdot
.17075 .50189 Mdot
.62415 .44515 Mdot
.61504 .21986 Mdot
.28892 .60462 Mdot
.59971 .41918 Mdot
.44139 .28354 Mdot
.31227 .65772 Mdot
.60008 .72022 Mdot
.29 .46871 Mdot
.52529 .585 Mdot
.55667 .15113 Mdot
.30031 .45995 Mdot
.68945 .4592 Mdot
.35575 .61826 Mdot
.63812 .45445 Mdot
.57022 .44145 Mdot
.611 .27461 Mdot
.64968 .44927 Mdot
.53359 .71642 Mdot
.46817 .3855 Mdot
.29167 .6456 Mdot
.32557 .65459 Mdot
.32536 .43232 Mdot
.48129 .36348 Mdot
.30444 .42789 Mdot
.62465 .42102 Mdot
.36455 .64245 Mdot
.66833 .43195 Mdot
.29965 .48476 Mdot
.46573 .36501 Mdot
.59166 .45205 Mdot
.4954 .37762 Mdot
.31612 .49832 Mdot
.5174 .66489 Mdot
.42366 .30642 Mdot
.2998 .66307 Mdot
.62315 .59889 Mdot
.59552 .45357 Mdot
.2158 .34704 Mdot
.65816 .66755 Mdot
.44153 .33464 Mdot
.61261 .47989 Mdot
.282 .29077 Mdot
.67931 .43411 Mdot
.72029 .44234 Mdot
.71987 .45002 Mdot
.57414 .59717 Mdot
.35901 .61651 Mdot
.44994 .28803 Mdot
.60931 .4558 Mdot
.60126 .42488 Mdot
.6835 .34881 Mdot
.66431 .43673 Mdot
.71318 .44973 Mdot
.49729 .58466 Mdot
.28305 .46919 Mdot
.51196 .57352 Mdot
.32037 .53218 Mdot
.52904 .56833 Mdot
.67395 .434 Mdot
.3313 .61259 Mdot
.48379 .37311 Mdot
.524 .56036 Mdot
.31335 .43181 Mdot
.61086 .45255 Mdot
.3512 .46777 Mdot
.43869 .28674 Mdot
.71186 .46155 Mdot
.53541 .69646 Mdot
.44628 .5751 Mdot
.4599 .36037 Mdot
.71484 .29395 Mdot
.61934 .42719 Mdot
.61036 .46791 Mdot
.4592 .32162 Mdot
.37395 .64439 Mdot
.21244 .46342 Mdot
.47242 .34434 Mdot
.28649 .47544 Mdot
.48036 .35011 Mdot
.50809 .56311 Mdot
.36482 .65016 Mdot
.54261 .59436 Mdot
.50146 .60453 Mdot
.65006 .72439 Mdot
.64359 .42917 Mdot
.51928 .62546 Mdot
.32434 .61474 Mdot
.47048 .34385 Mdot
.28654 .44958 Mdot
.58046 .47253 Mdot
.44307 .31754 Mdot
.30676 .4539 Mdot
.50808 .69552 Mdot
.50627 .72309 Mdot
.44841 .34767 Mdot
.7059 .28699 Mdot
.30969 .41277 Mdot
.28095 .42864 Mdot
.60055 .71807 Mdot
.44326 .33779 Mdot
.51663 .70976 Mdot
.30619 .43252 Mdot
.32953 .75531 Mdot
.69807 .46302 Mdot
.61649 .73841 Mdot
.21812 .35 Mdot
.59955 .71895 Mdot
.48687 .6138 Mdot
.52583 .70259 Mdot
.30704 .45434 Mdot
.58002 .44439 Mdot
.45212 .34076 Mdot
.44495 .31692 Mdot
.65549 .42375 Mdot
.53269 .56059 Mdot
.62767 .43465 Mdot
.5068 .57617 Mdot
.50503 .6102 Mdot
.61451 .45162 Mdot
.60418 .20816 Mdot
.43834 .31301 Mdot
.60341 .48045 Mdot
.31421 .63076 Mdot
.55448 .59937 Mdot
.31624 .42242 Mdot
.598 .47562 Mdot
.61683 .48257 Mdot
.60571 .41318 Mdot
.27753 .43065 Mdot
.36337 .33312 Mdot
.28937 .65791 Mdot
.28873 .48299 Mdot
.31757 .53116 Mdot
.32973 .62939 Mdot
.57306 .43856 Mdot
.53169 .68971 Mdot
.51626 .59242 Mdot
.5846 .44089 Mdot
.59812 .72151 Mdot
.57134 .44625 Mdot
.46978 .55614 Mdot
.47956 .55235 Mdot
.24931 .32572 Mdot
.36889 .32796 Mdot
.61136 .42491 Mdot
.64124 .48288 Mdot
.61232 .7278 Mdot
.23796 .41344 Mdot
.28583 .4447 Mdot
.37557 .61961 Mdot
.37953 .63804 Mdot
.29707 .53277 Mdot
.69773 .30829 Mdot
.75309 .38603 Mdot
.6264 .46901 Mdot
.52424 .57456 Mdot
.43148 .36745 Mdot
.52581 .70496 Mdot
.46119 .3558 Mdot
.21275 .3496 Mdot
.67479 .57868 Mdot
.745 .446 Mdot
.26495 .67887 Mdot
.30304 .65113 Mdot
.53443 .5689 Mdot
.51523 .69647 Mdot
.63809 .44624 Mdot
.43565 .30369 Mdot
.60828 .72333 Mdot
.54217 .56408 Mdot
.80896 .65511 Mdot
.47483 .35001 Mdot
.68598 .60838 Mdot
.2997 .45688 Mdot
.34881 .63747 Mdot
.67926 .43472 Mdot
.60166 .43908 Mdot
.45264 .27929 Mdot
.57708 .44546 Mdot
.74245 .43989 Mdot
.70265 .45953 Mdot
.32323 .66141 Mdot
.327 .53279 Mdot
.27647 .47206 Mdot
.28322 .68314 Mdot
.45877 .36076 Mdot
.60586 .1924 Mdot
.34131 .62112 Mdot
.47256 .57167 Mdot
.30552 .48187 Mdot
.50662 .70442 Mdot
.3409 .61513 Mdot
.55233 .695 Mdot
.56824 .44635 Mdot
.32605 .63918 Mdot
.53831 .70624 Mdot
.64645 .39869 Mdot
.52317 .56136 Mdot
.59208 .7883 Mdot
.30541 .44167 Mdot
.46587 .29501 Mdot
.58289 .443 Mdot
.51989 .58524 Mdot
.54567 .56643 Mdot
.63943 .62088 Mdot
.51709 .60917 Mdot
.54193 .56828 Mdot
.59838 .61756 Mdot
.50419 .69339 Mdot
.35169 .27001 Mdot
.73473 .44765 Mdot
.47854 .35583 Mdot
.59418 .4288 Mdot
.31894 .5222 Mdot
.30836 .45093 Mdot
.64248 .44634 Mdot
.23696 .33175 Mdot
.3013 .43425 Mdot
.62218 .46255 Mdot
.2883 .48745 Mdot
.44142 .324 Mdot
.688 .58 Mdot
.46975 .36732 Mdot
.61586 .45419 Mdot
.29161 .48827 Mdot
.37168 .61431 Mdot
.45201 .31295 Mdot
.60731 .45305 Mdot
.65683 .44444 Mdot
.52489 .57772 Mdot
.70024 .46061 Mdot
.23424 .45205 Mdot
.62422 .4137 Mdot
.30895 .60008 Mdot
.65671 .43046 Mdot
.51244 .73696 Mdot
.42276 .78866 Mdot
.44463 .3428 Mdot
.52026 .60893 Mdot
.34829 .61518 Mdot
.69693 .42029 Mdot
.69568 .59777 Mdot
.62161 .44376 Mdot
.54078 .58964 Mdot
.68387 .6447 Mdot
.27957 .43803 Mdot
.7301 .45452 Mdot
.55436 .5422 Mdot
.35434 .61295 Mdot
.52851 .57042 Mdot
.63828 .4684 Mdot
.43097 .29431 Mdot
.68228 .46227 Mdot
.33421 .63644 Mdot
.4768 .34176 Mdot
.67364 .44306 Mdot
.27376 .50095 Mdot
.54742 .60117 Mdot
.2756 .44455 Mdot
.72846 .44964 Mdot
.57454 .43675 Mdot
.36064 .64532 Mdot
.45492 .30604 Mdot
.30147 .46235 Mdot
.46095 .36361 Mdot
.5817 .66368 Mdot
.68302 .62155 Mdot
.49116 .36557 Mdot
.51496 .67823 Mdot
.36627 .79757 Mdot
.28773 .47907 Mdot
.50793 .59294 Mdot
.31479 .58982 Mdot
.42813 .29988 Mdot
.3359 .61016 Mdot
.694 .28145 Mdot
.35873 .6179 Mdot
.68363 .47003 Mdot
.3719 .62021 Mdot
.75062 .36984 Mdot
.58855 .46989 Mdot
.31618 .65258 Mdot
.49664 .58523 Mdot
.60464 .47384 Mdot
.4433 .31518 Mdot
.69813 .70103 Mdot
.66859 .31417 Mdot
.70218 .31145 Mdot
.35439 .62103 Mdot
.68852 .27506 Mdot
.71002 .45997 Mdot
.72582 .45049 Mdot
.45406 .33814 Mdot
.50896 .59193 Mdot
.53303 .72974 Mdot
.54141 .72756 Mdot
.4927 .79465 Mdot
.72477 .58959 Mdot
.72144 .30146 Mdot
.4464 .32 Mdot
.29789 .57053 Mdot
.49536 .37535 Mdot
.5422 .56493 Mdot
.30352 .46429 Mdot
.35939 .34019 Mdot
.67651 .42682 Mdot
.48285 .56378 Mdot
.73955 .43801 Mdot
.46671 .2986 Mdot
.48964 .35502 Mdot
.30243 .46268 Mdot
.70553 .31186 Mdot
.69225 .36086 Mdot
.63251 .43563 Mdot
.31006 .45956 Mdot
.54427 .56507 Mdot
.70011 .43439 Mdot
.65145 .73148 Mdot
.17441 .59873 Mdot
.62151 .44981 Mdot
.39006 .3802 Mdot
.58363 .4441 Mdot
.64197 .72622 Mdot
.63583 .44947 Mdot
.45124 .30443 Mdot
.72891 .46487 Mdot
.69153 .43072 Mdot
.27664 .7138 Mdot
.66719 .58002 Mdot
.54657 .68795 Mdot
.60974 .44284 Mdot
.62263 .43199 Mdot
.51504 .71565 Mdot
.45307 .29443 Mdot
.61285 .4182 Mdot
.36029 .26641 Mdot
.60595 .45642 Mdot
.31228 .42085 Mdot
.63743 .64828 Mdot
.67941 .71127 Mdot
.70798 .45819 Mdot
.43115 .29282 Mdot
.27896 .43211 Mdot
.31764 .46413 Mdot
.51967 .60537 Mdot
.30881 .44967 Mdot
.58147 .45397 Mdot
.63784 .6471 Mdot
.48218 .36466 Mdot
.5304 .56286 Mdot
.4614 .29714 Mdot
.38371 .59816 Mdot
.30386 .44321 Mdot
.53342 .58379 Mdot
.68183 .30405 Mdot
.29352 .43663 Mdot
.36863 .5537 Mdot
.71826 .46005 Mdot
.54511 .56661 Mdot
.4481 .36049 Mdot
.36686 .63922 Mdot
.5446 .57869 Mdot
.30098 .46022 Mdot
.62371 .44401 Mdot
.69261 .45898 Mdot
.30943 .45032 Mdot
.42616 .26471 Mdot
.73755 .44644 Mdot
.60657 .4591 Mdot
.44203 .30658 Mdot
.46866 .32968 Mdot
.59903 .47908 Mdot
.58524 .43523 Mdot
.33573 .60093 Mdot
.5403 .59188 Mdot
.54095 .59232 Mdot
.50615 .60826 Mdot
.35461 .62876 Mdot
.33331 .7756 Mdot
.29034 .42393 Mdot
.68153 .70955 Mdot
.36395 .38554 Mdot
.52316 .58851 Mdot
.32901 .59997 Mdot
.60883 .43175 Mdot
.65518 .41965 Mdot
.29616 .48981 Mdot
.47306 .84163 Mdot
.66218 .41733 Mdot
.47368 .36143 Mdot
.30418 .46787 Mdot
.58574 .48633 Mdot
.30474 .53524 Mdot
.54613 .71105 Mdot
.71976 .29789 Mdot
.30011 .46946 Mdot
.48609 .29855 Mdot
.29885 .46994 Mdot
.62218 .43264 Mdot
.63697 .46834 Mdot
.47051 .30426 Mdot
.54488 .68316 Mdot
.64127 .41909 Mdot
.62446 .45942 Mdot
.27425 .60144 Mdot
.4995 .37274 Mdot
.54754 .72554 Mdot
.61998 .4152 Mdot
.50053 .57833 Mdot
.54378 .67833 Mdot
.59699 .4627 Mdot
.65807 .42889 Mdot
.51131 .62474 Mdot
.3115 .48648 Mdot
.52761 .67136 Mdot
.28171 .72322 Mdot
.47427 .3539 Mdot
.23069 .43288 Mdot
.54911 .58784 Mdot
.28945 .47996 Mdot
.73174 .43087 Mdot
.53508 .57547 Mdot
.33275 .3786 Mdot
.86816 .42106 Mdot
.54234 .57645 Mdot
.32514 .59741 Mdot
.6813 .3445 Mdot
.6534 .42576 Mdot
.60731 .4598 Mdot
.52968 .73041 Mdot
.46475 .33242 Mdot
.36859 .32942 Mdot
.28678 .48318 Mdot
.59405 .44029 Mdot
.45298 .35799 Mdot
.25854 .31396 Mdot
.52905 .57515 Mdot
.54239 .69327 Mdot
.52065 .67705 Mdot
.5893 .45714 Mdot
.69972 .62415 Mdot
.45037 .31262 Mdot
.60764 .45292 Mdot
.59888 .46785 Mdot
.36096 .60489 Mdot
.43975 .33344 Mdot
.32547 .63731 Mdot
.73638 .45406 Mdot
.75913 .35778 Mdot
.3227 .52177 Mdot
.30453 .43541 Mdot
.53113 .60087 Mdot
.27533 .46956 Mdot
.29025 .61085 Mdot
.54001 .59319 Mdot
.60737 .45207 Mdot
.48294 .36435 Mdot
.60822 .45346 Mdot
.60683 .45646 Mdot
.62859 .44446 Mdot
.72306 .30114 Mdot
.29385 .66103 Mdot
.53733 .68835 Mdot
.58657 .4236 Mdot
.34257 .63505 Mdot
.29488 .54407 Mdot
.68567 .35518 Mdot
.60389 .4437 Mdot
.61283 .46706 Mdot
.43242 .3348 Mdot
.69655 .46424 Mdot
.29514 .43875 Mdot
.46921 .30059 Mdot
.67936 .43856 Mdot
.27527 .6527 Mdot
.60652 .41923 Mdot
.49003 .36657 Mdot
.2989 .4236 Mdot
.56698 .36815 Mdot
.5503 .567 Mdot
.53543 .6005 Mdot
.54382 .5766 Mdot
.51014 .61017 Mdot
.31705 .42408 Mdot
.32133 .59998 Mdot
.28403 .68715 Mdot
.60228 .40856 Mdot
.5793 .44243 Mdot
.63349 .4704 Mdot
.34494 .59314 Mdot
.49615 .58 Mdot
.68585 .28838 Mdot
.57732 .48425 Mdot
.35196 .64069 Mdot
.49715 .59486 Mdot
.49526 .26509 Mdot
.46201 .29468 Mdot
.2861 .64401 Mdot
.31956 .46387 Mdot
.54071 .70759 Mdot
.53858 .79326 Mdot
.46889 .31792 Mdot
.42206 .35494 Mdot
.31736 .62352 Mdot
.64675 .63437 Mdot
.5528 .14652 Mdot
.33264 .60688 Mdot
.73827 .44057 Mdot
.44903 .33257 Mdot
.50758 .56847 Mdot
.68015 .64921 Mdot
.64552 .64483 Mdot
.33715 .65125 Mdot
.6558 .44259 Mdot
.39608 .62428 Mdot
.34395 .60181 Mdot
.51961 .60041 Mdot
.35373 .62226 Mdot
.27809 .43818 Mdot
.32717 .61792 Mdot
.45234 .26745 Mdot
.63667 .42588 Mdot
.55487 .1499 Mdot
.62133 .67257 Mdot
.61262 .42614 Mdot
.27941 .44674 Mdot
.24478 .46909 Mdot
.64046 .43884 Mdot
.54759 .71788 Mdot
.32348 .59784 Mdot
.34979 .5551 Mdot
.68433 .46579 Mdot
.37209 .62308 Mdot
.43 .29648 Mdot
.33122 .53773 Mdot
.31994 .53232 Mdot
.54413 .58119 Mdot
.44202 .32857 Mdot
.31809 .49776 Mdot
.28549 .47421 Mdot
.54449 .60562 Mdot
.58063 .46071 Mdot
.43871 .29977 Mdot
.67566 .40736 Mdot
.53756 .52276 Mdot
.60465 .45567 Mdot
.32464 .63459 Mdot
.30956 .65844 Mdot
.61669 .64578 Mdot
.34287 .62282 Mdot
.51915 .60143 Mdot
.43966 .30858 Mdot
.68154 .46641 Mdot
.47075 .33842 Mdot
.59442 .4279 Mdot
.31419 .52351 Mdot
.45446 .28844 Mdot
.47266 .57109 Mdot
.64651 .45428 Mdot
.60656 .21145 Mdot
.59601 .41867 Mdot
.60541 .45867 Mdot
.34285 .65727 Mdot
.51439 .71329 Mdot
.50353 .53655 Mdot
.29954 .5359 Mdot
.53619 .71926 Mdot
.43085 .26781 Mdot
.37201 .64627 Mdot
.50786 .70675 Mdot
.49723 .79798 Mdot
.52278 .60871 Mdot
.52535 .67966 Mdot
.61066 .47995 Mdot
.30742 .43694 Mdot
.48416 .34525 Mdot
.60368 .47428 Mdot
.75157 .35746 Mdot
.74354 .45074 Mdot
.52727 .57915 Mdot
.60645 .46196 Mdot
.61999 .42959 Mdot
.45415 .3591 Mdot
.21345 .35255 Mdot
.29462 .61538 Mdot
.50873 .58002 Mdot
.47167 .3308 Mdot
.21691 .34606 Mdot
.32115 .65267 Mdot
.5097 .72243 Mdot
.27199 .46673 Mdot
.49427 .31478 Mdot
.52423 .58257 Mdot
.30537 .44566 Mdot
.39349 .63216 Mdot
.59527 .71362 Mdot
.68186 .45975 Mdot
.31353 .61194 Mdot
.59919 .71925 Mdot
.72145 .46148 Mdot
.29347 .53438 Mdot
.24194 .411 Mdot
.44103 .28658 Mdot
.30964 .45322 Mdot
.54401 .69041 Mdot
.47448 .36706 Mdot
.46096 .29646 Mdot
.30095 .43217 Mdot
.67943 .23536 Mdot
.68371 .64267 Mdot
.27173 .47274 Mdot
.63272 .61956 Mdot
.59755 .71504 Mdot
.52227 .58072 Mdot
.53458 .68991 Mdot
.32675 .53265 Mdot
.45571 .30958 Mdot
.362 .35038 Mdot
.60031 .72227 Mdot
.72274 .45891 Mdot
.5384 .70946 Mdot
.26182 .31407 Mdot
.33816 .41845 Mdot
.29898 .44047 Mdot
.27659 .59679 Mdot
.52977 .72041 Mdot
.59746 .47645 Mdot
.49496 .8496 Mdot
.58982 .46922 Mdot
.30826 .43314 Mdot
.74036 .43854 Mdot
.46299 .35217 Mdot
.29191 .4249 Mdot
.74664 .44243 Mdot
.62639 .41447 Mdot
.62811 .42756 Mdot
.3002 .6638 Mdot
.45529 .28155 Mdot
.55209 .58591 Mdot
.60901 .42666 Mdot
.62894 .45929 Mdot
.54086 .55862 Mdot
.67465 .71325 Mdot
.44189 .54869 Mdot
.5247 .558 Mdot
.33594 .6447 Mdot
.52952 .56212 Mdot
.509 .58296 Mdot
.43797 .34526 Mdot
.30246 .55963 Mdot
.54867 .57357 Mdot
.61869 .45392 Mdot
.6128 .45658 Mdot
.27235 .4698 Mdot
.68325 .64523 Mdot
.64835 .63796 Mdot
.30337 .60404 Mdot
.55763 .55516 Mdot
.66241 .44593 Mdot
.44137 .33073 Mdot
.56278 .69716 Mdot
.51623 .60406 Mdot
.47592 .355 Mdot
.63949 .4247 Mdot
.36018 .60391 Mdot
.54113 .5783 Mdot
.53536 .55293 Mdot
.53511 .70587 Mdot
.26851 .44589 Mdot
.42181 .29344 Mdot
.33698 .59925 Mdot
.69605 .4521 Mdot
.5529 .54781 Mdot
.36509 .61609 Mdot
.52178 .57902 Mdot
.52311 .56365 Mdot
.4426 .32366 Mdot
.48212 .28976 Mdot
.50008 .5661 Mdot
.35104 .63089 Mdot
.16143 .55235 Mdot
.29231 .4734 Mdot
.57681 .43307 Mdot
.27086 .45182 Mdot
.43777 .28721 Mdot
.64909 .72599 Mdot
.51116 .69143 Mdot
.29781 .43689 Mdot
.53994 .56335 Mdot
.45849 .29269 Mdot
.44418 .27773 Mdot
.61608 .45088 Mdot
.60362 .44922 Mdot
.28314 .61403 Mdot
.6161 .73282 Mdot
.29218 .49066 Mdot
.52642 .72875 Mdot
.29888 .61316 Mdot
.68766 .46154 Mdot
.45374 .3465 Mdot
.62436 .78696 Mdot
.57704 .4309 Mdot
.34504 .63305 Mdot
.45606 .3249 Mdot
.53448 .72815 Mdot
.53663 .68638 Mdot
.59378 .43315 Mdot
.48615 .6125 Mdot
.29527 .43331 Mdot
.44526 .31151 Mdot
.39674 .34693 Mdot
.60085 .4179 Mdot
.60608 .4455 Mdot
.71869 .4614 Mdot
.26903 .46656 Mdot
.60558 .47908 Mdot
.54386 .68315 Mdot
.4556 .35464 Mdot
.59425 .43572 Mdot
.52687 .71984 Mdot
.53955 .60306 Mdot
.5373 .57699 Mdot
.32578 .6573 Mdot
.54542 .72223 Mdot
.52157 .71612 Mdot
.53379 .72246 Mdot
.3591 .34041 Mdot
.56055 .45801 Mdot
.49586 .55963 Mdot
.65799 .44537 Mdot
.59674 .71293 Mdot
.67302 .46321 Mdot
.2807 .46218 Mdot
.35793 .64691 Mdot
.63067 .43994 Mdot
.65718 .44816 Mdot
.42572 .28889 Mdot
.67494 .4685 Mdot
.59918 .47864 Mdot
.46047 .35295 Mdot
.40035 .34434 Mdot
.37983 .63261 Mdot
.21959 .34884 Mdot
.54428 .85153 Mdot
.574 .46228 Mdot
.6431 .63746 Mdot
.45286 .29238 Mdot
.27203 .46797 Mdot
.63945 .6232 Mdot
.27226 .43592 Mdot
.46603 .32533 Mdot
.67772 .4717 Mdot
.41804 .26661 Mdot
.53657 .71708 Mdot
.62272 .43381 Mdot
.29533 .43027 Mdot
.62532 .43417 Mdot
.28545 .43022 Mdot
.67431 .26814 Mdot
.6678 .6634 Mdot
.5761 .45944 Mdot
.66352 .43574 Mdot
.50118 .63313 Mdot
.60369 .44609 Mdot
.26559 .6851 Mdot
.45549 .33083 Mdot
.54969 .60256 Mdot
.67364 .47303 Mdot
.66916 .31626 Mdot
.60736 .46519 Mdot
.75386 .4363 Mdot
.6186 .46878 Mdot
.45662 .83343 Mdot
.56904 .44712 Mdot
.58217 .4632 Mdot
.28364 .45103 Mdot
.29767 .48259 Mdot
.43291 .28145 Mdot
.52777 .56556 Mdot
.25498 .32009 Mdot
.62035 .46229 Mdot
.29743 .63864 Mdot
.52853 .51862 Mdot
.51957 .7168 Mdot
.46298 .3602 Mdot
.87283 .39865 Mdot
.32019 .42434 Mdot
.32031 .64082 Mdot
.73497 .44312 Mdot
.33109 .64256 Mdot
.2891 .63954 Mdot
.38744 .32426 Mdot
.53565 .69037 Mdot
.59971 .42226 Mdot
.6277 .30331 Mdot
.49141 .38815 Mdot
.60174 .41772 Mdot
.3899 .62953 Mdot
.50931 .62345 Mdot
.66985 .54087 Mdot
.50367 .69097 Mdot
.52077 .70506 Mdot
.30303 .45553 Mdot
.29957 .63987 Mdot
.51015 .57832 Mdot
.50749 .70397 Mdot
.37776 .62975 Mdot
.52116 .60777 Mdot
.29044 .57695 Mdot
.44984 .31186 Mdot
.69017 .27683 Mdot
.61562 .21586 Mdot
.27431 .44998 Mdot
.29256 .54086 Mdot
.48311 .36533 Mdot
.47006 .36841 Mdot
.52023 .57264 Mdot
.35295 .64213 Mdot
.48279 .3235 Mdot
.59736 .43229 Mdot
.52852 .56267 Mdot
.58559 .45301 Mdot
.50227 .70489 Mdot
.61374 .4612 Mdot
.37559 .62581 Mdot
.28261 .44522 Mdot
.3528 .61336 Mdot
.30505 .45208 Mdot
.68792 .70672 Mdot
.63842 .45906 Mdot
.60887 .44536 Mdot
.63864 .64693 Mdot
.43548 .32213 Mdot
.62985 .313 Mdot
.34941 .62964 Mdot
.35418 .617 Mdot
.67202 .47259 Mdot
.4815 .35154 Mdot
.51113 .55483 Mdot
.62766 .61803 Mdot
.61516 .46946 Mdot
.45695 .33186 Mdot
.66078 .47007 Mdot
.2233 .41256 Mdot
.65276 .66807 Mdot
.43442 .32303 Mdot
.27448 .71213 Mdot
.61743 .47252 Mdot
.50533 .58784 Mdot
.51759 .62271 Mdot
.71104 .61483 Mdot
.50573 .53429 Mdot
.47526 .35072 Mdot
.51048 .57301 Mdot
.45196 .34363 Mdot
.35567 .60996 Mdot
.29794 .42191 Mdot
.45675 .34255 Mdot
.62532 .46692 Mdot
.54498 .85061 Mdot
.29284 .42832 Mdot
.62034 .43572 Mdot
.30362 .42682 Mdot
.48674 .34541 Mdot
.46688 .34495 Mdot
.5211 .60767 Mdot
.74049 .44189 Mdot
.29655 .43461 Mdot
.57864 .44599 Mdot
.38249 .37179 Mdot
.68183 .4625 Mdot
.56147 .56803 Mdot
.6638 .44214 Mdot
.64341 .42594 Mdot
.30718 .75484 Mdot
.68745 .41175 Mdot
.3206 .52364 Mdot
.26253 .44865 Mdot
.36367 .32906 Mdot
.44308 .35174 Mdot
.50339 .71456 Mdot
.43015 .28173 Mdot
.53987 .59626 Mdot
.33382 .64641 Mdot
.62685 .44213 Mdot
.51942 .61168 Mdot
.28691 .49141 Mdot
.52128 .68355 Mdot
.57136 .44623 Mdot
.30636 .61599 Mdot
.50117 .59291 Mdot
.30251 .44313 Mdot
.45767 .30881 Mdot
.46777 .35578 Mdot
.30224 .56261 Mdot
.59624 .43456 Mdot
.60512 .45063 Mdot
.31759 .43086 Mdot
.47514 .57651 Mdot
.53964 .71935 Mdot
.49659 .58516 Mdot
.3124 .42933 Mdot
.65437 .66806 Mdot
.45633 .28119 Mdot
.61459 .43004 Mdot
.63518 .65109 Mdot
.36681 .32598 Mdot
.55083 .3405 Mdot
.52476 .70889 Mdot
.69735 .60475 Mdot
.4752 .3499 Mdot
.28701 .4526 Mdot
.49243 .79662 Mdot
.71322 .46346 Mdot
.6402 .43456 Mdot
.70177 .59477 Mdot
.62944 .61675 Mdot
.72717 .44101 Mdot
.55131 .57751 Mdot
.67559 .64055 Mdot
.66812 .47222 Mdot
.69297 .4548 Mdot
.66259 .4484 Mdot
.66467 .44208 Mdot
.46126 .33821 Mdot
.70638 .3151 Mdot
.32145 .62478 Mdot
.61512 .49021 Mdot
.52001 .65733 Mdot
.7224 .45718 Mdot
.65914 .42344 Mdot
.52145 .29503 Mdot
.72846 .55778 Mdot
.44973 .32618 Mdot
.43113 .30432 Mdot
.27341 .45376 Mdot
.67934 .46501 Mdot
.34783 .63185 Mdot
.49888 .61345 Mdot
.36099 .64213 Mdot
.46092 .33538 Mdot
.38329 .63175 Mdot
.32315 .42406 Mdot
.31322 .61218 Mdot
.34706 .6425 Mdot
.28114 .45015 Mdot
.46024 .28596 Mdot
.59773 .41776 Mdot
.28079 .4498 Mdot
.52847 .55213 Mdot
.50789 .72161 Mdot
.41202 .34937 Mdot
.51422 .56307 Mdot
.65708 .41611 Mdot
.16448 .53087 Mdot
.31053 .62127 Mdot
.69255 .5822 Mdot
.45415 .28559 Mdot
.54612 .67028 Mdot
.45923 .34487 Mdot
.50014 .56509 Mdot
.52861 .71011 Mdot
.614 .47937 Mdot
.57605 .78691 Mdot
.24528 .41005 Mdot
.6933 .43899 Mdot
.39997 .34459 Mdot
.36311 .63914 Mdot
.28009 .43956 Mdot
.2248 .45761 Mdot
.50831 .57927 Mdot
.43022 .29308 Mdot
.48468 .28752 Mdot
.54041 .59424 Mdot
.28659 .44838 Mdot
.60155 .22532 Mdot
.60647 .42875 Mdot
.27179 .45299 Mdot
.66272 .4412 Mdot
.71071 .29131 Mdot
.54677 .66218 Mdot
.50684 .60998 Mdot
.68111 .47129 Mdot
.32179 .65242 Mdot
.67418 .47243 Mdot
.73865 .34027 Mdot
.63172 .73435 Mdot
.65077 .45475 Mdot
.69707 .58563 Mdot
.29532 .60393 Mdot
.44917 .3437 Mdot
.52866 .59313 Mdot
.52394 .57937 Mdot
.69043 .47006 Mdot
.63306 .82513 Mdot
.5117 .6971 Mdot
.26312 .67205 Mdot
.63367 .4611 Mdot
.59626 .45341 Mdot
.42575 .2838 Mdot
.67282 .26946 Mdot
.49854 .5813 Mdot
.64796 .44142 Mdot
.72919 .56646 Mdot
.29044 .46282 Mdot
.6719 .44256 Mdot
.58835 .45398 Mdot
.33732 .53886 Mdot
.28468 .45199 Mdot
.35434 .60309 Mdot
.52716 .60738 Mdot
.33138 .65898 Mdot
.54989 .68861 Mdot
.68809 .60627 Mdot
.66363 .71961 Mdot
.64846 .66622 Mdot
.55032 .71084 Mdot
.70647 .46013 Mdot
.63228 .40725 Mdot
.6395 .42978 Mdot
.51866 .70209 Mdot
.32061 .46676 Mdot
.45707 .3347 Mdot
.7021 .28399 Mdot
.52334 .57717 Mdot
.70396 .44891 Mdot
.52873 .66479 Mdot
.45103 .33905 Mdot
.60279 .20757 Mdot
.46407 .33327 Mdot
.29902 .44513 Mdot
.29301 .53591 Mdot
.53106 .71314 Mdot
.45907 .3454 Mdot
.34487 .656 Mdot
.30869 .51948 Mdot
.56175 .47763 Mdot
.32405 .4256 Mdot
.46053 .27597 Mdot
.43265 .31092 Mdot
.47275 .37552 Mdot
.68775 .46818 Mdot
.69525 .58446 Mdot
.52862 .60182 Mdot
.30398 .4248 Mdot
.31043 .64028 Mdot
.61955 .73269 Mdot
.60229 .24532 Mdot
.66298 .65171 Mdot
.62891 .47322 Mdot
.61412 .46047 Mdot
.59247 .45927 Mdot
.54718 .56054 Mdot
.63367 .4065 Mdot
.65503 .45211 Mdot
.29581 .49003 Mdot
.3608 .60956 Mdot
.63356 .45932 Mdot
.5379 .58203 Mdot
.48817 .55638 Mdot
.54619 .67133 Mdot
.72519 .29796 Mdot
.41183 .34443 Mdot
.45345 .33987 Mdot
.33505 .63553 Mdot
.37033 .64824 Mdot
.50703 .6984 Mdot
.30591 .46254 Mdot
.46516 .33157 Mdot
.45181 .82997 Mdot
.54051 .71431 Mdot
.62169 .45205 Mdot
.63807 .64804 Mdot
.72515 .57765 Mdot
.65182 .42308 Mdot
.62975 .44495 Mdot
.53838 .56446 Mdot
.34641 .63466 Mdot
.75215 .37829 Mdot
.60412 .20992 Mdot
.5267 .71855 Mdot
.51385 .72303 Mdot
.47352 .37282 Mdot
.57738 .45249 Mdot
.29725 .43111 Mdot
.6859 .642 Mdot
.23984 .45977 Mdot
.28656 .28908 Mdot
.38443 .61106 Mdot
.60185 .42087 Mdot
.67524 .33383 Mdot
.6757 .42562 Mdot
.48338 .37319 Mdot
.48307 .29627 Mdot
.4474 .32242 Mdot
.29465 .46499 Mdot
.59055 .69893 Mdot
.30931 .47278 Mdot
.49736 .59379 Mdot
.46888 .31016 Mdot
.6886 .41946 Mdot
.35394 .61828 Mdot
.6744 .46544 Mdot
.52948 .69271 Mdot
.57295 .57952 Mdot
.52503 .59136 Mdot
.6942 .60531 Mdot
.32848 .60014 Mdot
.46996 .29615 Mdot
.67212 .46663 Mdot
.30495 .53694 Mdot
.67065 .64876 Mdot
.31985 .58605 Mdot
.52133 .61166 Mdot
.53397 .71648 Mdot
.68679 .35814 Mdot
.54416 .70822 Mdot
.29881 .43544 Mdot
.64359 .45554 Mdot
.58031 .45836 Mdot
.60266 .45942 Mdot
.6076 .47692 Mdot
.29852 .46228 Mdot
.71138 .44797 Mdot
.51111 .55952 Mdot
.51215 .60995 Mdot
.73348 .44874 Mdot
.5306 .68461 Mdot
.28833 .47097 Mdot
.36513 .61424 Mdot
.5443 .5707 Mdot
.53036 .66841 Mdot
.66351 .46322 Mdot
.65321 .449 Mdot
.5014 .59916 Mdot
.61079 .47965 Mdot
.7159 .44806 Mdot
.31977 .61235 Mdot
.72215 .44333 Mdot
.54502 .67142 Mdot
.53049 .69787 Mdot
.30957 .44508 Mdot
.45833 .34553 Mdot
.51927 .67598 Mdot
.30443 .60825 Mdot
.67483 .44653 Mdot
.66376 .44388 Mdot
.45841 .26997 Mdot
.59897 .72215 Mdot
.54849 .67282 Mdot
.60395 .47913 Mdot
.44131 .34149 Mdot
.4894 .29178 Mdot
.64294 .43715 Mdot
.71867 .45182 Mdot
.44186 .35294 Mdot
.50665 .71384 Mdot
.31077 .45717 Mdot
.624 .68238 Mdot
.28442 .42685 Mdot
.4568 .30675 Mdot
.51444 .57083 Mdot
.46275 .28951 Mdot
.50843 .57751 Mdot
.35729 .23696 Mdot
.65782 .45075 Mdot
.39219 .28604 Mdot
.496 .57828 Mdot
.35552 .62164 Mdot
.35986 .63185 Mdot
.54119 .58203 Mdot
.47649 .3447 Mdot
.52078 .6014 Mdot
.54485 .6987 Mdot
.36413 .33466 Mdot
.43644 .34186 Mdot
.34874 .64222 Mdot
.30913 .62076 Mdot
.3114 .42842 Mdot
.61064 .46301 Mdot
.61454 .42962 Mdot
.3145 .6093 Mdot
.23737 .45602 Mdot
.44342 .28853 Mdot
.60585 .45041 Mdot
.52963 .5567 Mdot
.32057 .61874 Mdot
.29071 .39408 Mdot
.48193 .32953 Mdot
.68257 .47197 Mdot
.63619 .73372 Mdot
.3031 .421 Mdot
.67762 .43385 Mdot
.71525 .44921 Mdot
.51301 .70541 Mdot
.7003 .60241 Mdot
.60004 .71705 Mdot
.32194 .42559 Mdot
.53385 .60107 Mdot
.65241 .42263 Mdot
.35976 .62348 Mdot
.66235 .4584 Mdot
.85031 .4761 Mdot
.50256 .60427 Mdot
.59545 .43697 Mdot
.50932 .61862 Mdot
.47103 .3397 Mdot
.60173 .45357 Mdot
.31661 .52023 Mdot
.3344 .63199 Mdot
.59954 .43345 Mdot
.49251 .62248 Mdot
.30293 .42719 Mdot
.52579 .59096 Mdot
.53341 .71884 Mdot
.72789 .43944 Mdot
.69707 .70155 Mdot
.34197 .59236 Mdot
.53447 .6823 Mdot
.6118 .46464 Mdot
.29642 .61613 Mdot
.29533 .48255 Mdot
.53276 .59271 Mdot
.69085 .44476 Mdot
.28131 .468 Mdot
.28688 .46201 Mdot
.53445 .7106 Mdot
.59726 .18193 Mdot
.57656 .46513 Mdot
.61051 .43681 Mdot
.59742 .19919 Mdot
.49921 .29339 Mdot
.62407 .43527 Mdot
.5929 .46664 Mdot
.30564 .44194 Mdot
.58819 .69789 Mdot
.69577 .60433 Mdot
.49521 .60339 Mdot
.27893 .44297 Mdot
.39133 .62435 Mdot
.31702 .63329 Mdot
.535 .6797 Mdot
.45633 .32372 Mdot
.50971 .68884 Mdot
.32789 .6221 Mdot
.61887 .45101 Mdot
.31441 .44851 Mdot
.76565 .40162 Mdot
.29549 .42466 Mdot
.30672 .608 Mdot
.48576 .36885 Mdot
.75121 .3679 Mdot
.85312 .46733 Mdot
.43738 .54733 Mdot
.29143 .53442 Mdot
.51857 .71617 Mdot
.60369 .20987 Mdot
.62484 .46499 Mdot
.72938 .33578 Mdot
.6176 .43417 Mdot
.51528 .74244 Mdot
.36964 .63393 Mdot
.52129 .6077 Mdot
.50781 .58049 Mdot
.69314 .60172 Mdot
.29023 .46597 Mdot
.32161 .45623 Mdot
.51656 .56637 Mdot
.29575 .44311 Mdot
.59933 .4368 Mdot
.33387 .60355 Mdot
.38738 .22947 Mdot
.61946 .469 Mdot
.55528 .59068 Mdot
.31158 .4145 Mdot
.49334 .3553 Mdot
.39116 .62498 Mdot
.67267 .32662 Mdot
.24183 .33241 Mdot
.29243 .43581 Mdot
.72651 .30063 Mdot
.34029 .63326 Mdot
.54392 .57012 Mdot
.29383 .62015 Mdot
.60999 .43435 Mdot
.60137 .42093 Mdot
.54333 .56142 Mdot
.60744 .46756 Mdot
.62958 .33764 Mdot
.73044 .45516 Mdot
.56604 .49907 Mdot
.65697 .44335 Mdot
.40664 .27534 Mdot
.29553 .48519 Mdot
.5174 .56671 Mdot
.59467 .61752 Mdot
.64147 .42647 Mdot
.44779 .35917 Mdot
.27867 .46153 Mdot
.22793 .35003 Mdot
.29408 .46338 Mdot
.35621 .61523 Mdot
.30217 .46573 Mdot
.67758 .42888 Mdot
.46653 .32067 Mdot
.33742 .61805 Mdot
.52394 .58709 Mdot
.31957 .64593 Mdot
.61185 .42637 Mdot
.31351 .39836 Mdot
.32033 .6401 Mdot
.71994 .46071 Mdot
.46757 .32575 Mdot
.60268 .79078 Mdot
.45586 .38277 Mdot
.61729 .44532 Mdot
.62153 .43955 Mdot
.49826 .57943 Mdot
.30699 .45477 Mdot
.46621 .28876 Mdot
.27118 .6082 Mdot
.54737 .67101 Mdot
.45168 .32231 Mdot
.48343 .60397 Mdot
.64684 .6332 Mdot
.46019 .36068 Mdot
.7284 .57076 Mdot
.30325 .43363 Mdot
.47254 .35498 Mdot
.53991 .51922 Mdot
.63644 .48523 Mdot
.53718 .69575 Mdot
.33918 .65811 Mdot
.6435 .62724 Mdot
.32151 .63569 Mdot
.31478 .52382 Mdot
.32271 .6613 Mdot
.28895 .43365 Mdot
.48084 .60249 Mdot
.73871 .4379 Mdot
.32476 .45098 Mdot
.36446 .42442 Mdot
.32454 .63013 Mdot
.50806 .57014 Mdot
.72501 .44504 Mdot
.53787 .55322 Mdot
.50311 .58497 Mdot
.32185 .42651 Mdot
.47274 .35643 Mdot
.47966 .35869 Mdot
.53585 .61527 Mdot
.46428 .35538 Mdot
.33266 .60914 Mdot
.63875 .66495 Mdot
.68129 .30416 Mdot
.3001 .48687 Mdot
.71848 .44169 Mdot
.66922 .43034 Mdot
.37347 .6248 Mdot
.3384 .60701 Mdot
.29186 .46541 Mdot
.53675 .37612 Mdot
.505 .59343 Mdot
.48855 .34731 Mdot
.46944 .31848 Mdot
.47186 .34441 Mdot
.44107 .28242 Mdot
.59358 .70944 Mdot
.27919 .44754 Mdot
.47566 .34193 Mdot
.61699 .47414 Mdot
.59383 .46484 Mdot
.5454 .57575 Mdot
.50335 .71112 Mdot
.72237 .45145 Mdot
.51982 .6019 Mdot
.63728 .43365 Mdot
.35325 .62299 Mdot
.51762 .52047 Mdot
.54015 .59775 Mdot
.34851 .63249 Mdot
.35344 .62845 Mdot
.53344 .60244 Mdot
.51231 .52234 Mdot
.6258 .34796 Mdot
.68095 .47608 Mdot
.38894 .34306 Mdot
.35791 .63851 Mdot
.36211 .46702 Mdot
.3944 .2827 Mdot
.5805 .45388 Mdot
.49549 .58786 Mdot
.34144 .60381 Mdot
.4346 .33428 Mdot
.60266 .4423 Mdot
.51828 .57338 Mdot
.54066 .70184 Mdot
.52807 .58781 Mdot
.53647 .56403 Mdot
.43732 .31893 Mdot
.16401 .54477 Mdot
.45231 .35701 Mdot
.29989 .66084 Mdot
.51834 .58862 Mdot
.55298 .14833 Mdot
.36563 .63448 Mdot
.36305 .33769 Mdot
.74079 .4394 Mdot
.64053 .43278 Mdot
.33328 .63522 Mdot
.43017 .29686 Mdot
.3282 .43602 Mdot
.73058 .55321 Mdot
.45967 .34721 Mdot
.54965 .58666 Mdot
.54027 .57169 Mdot
.32056 .62303 Mdot
.45583 .30138 Mdot
.71572 .44956 Mdot
.46917 .35191 Mdot
.31723 .46034 Mdot
.62926 .4769 Mdot
.25348 .32165 Mdot
.51108 .57747 Mdot
.46041 .35634 Mdot
.30444 .63247 Mdot
.54336 .68184 Mdot
.58972 .46996 Mdot
.23346 .33505 Mdot
.60961 .46527 Mdot
.32262 .44259 Mdot
.53022 .52754 Mdot
.64517 .47995 Mdot
.63345 .45018 Mdot
.65156 .4191 Mdot
.3173 .48569 Mdot
.63661 .44843 Mdot
.63731 .42159 Mdot
.61064 .21575 Mdot
.45131 .35285 Mdot
.63091 .46086 Mdot
.31996 .607 Mdot
.47785 .52577 Mdot
.5884 .44738 Mdot
.29585 .53999 Mdot
.70798 .61647 Mdot
.49403 .57964 Mdot
.55196 .60372 Mdot
.64725 .72674 Mdot
.61735 .43825 Mdot
.57718 .44658 Mdot
.62918 .47655 Mdot
.68958 .3339 Mdot
.33014 .62648 Mdot
.31328 .65008 Mdot
.54193 .68239 Mdot
.70285 .59144 Mdot
.53167 .70227 Mdot
.29456 .48258 Mdot
.74355 .44652 Mdot
.524 .60986 Mdot
.45609 .34549 Mdot
.60066 .45839 Mdot
.30716 .64014 Mdot
.60636 .43381 Mdot
.69486 .45901 Mdot
.32797 .6113 Mdot
.34697 .6065 Mdot
.33975 .66157 Mdot
.52814 .72189 Mdot
.45067 .33237 Mdot
.58598 .47099 Mdot
.53324 .72099 Mdot
.54284 .55941 Mdot
.634 .68768 Mdot
.44923 .32909 Mdot
.45713 .354 Mdot
.47509 .32081 Mdot
.57975 .46132 Mdot
.61797 .4817 Mdot
.3051 .47464 Mdot
.45862 .26996 Mdot
.30557 .43037 Mdot
.33046 .63625 Mdot
.35151 .60427 Mdot
.61164 .43375 Mdot
.47906 .59267 Mdot
.53243 .68661 Mdot
.31306 .63591 Mdot
.51343 .61623 Mdot
.53367 .67294 Mdot
.58382 .43802 Mdot
.32437 .63684 Mdot
.54541 .72033 Mdot
.53809 .3755 Mdot
.28356 .32042 Mdot
.5409 .67786 Mdot
.50662 .58496 Mdot
.60414 .2542 Mdot
.62807 .73133 Mdot
.56216 .69205 Mdot
.29728 .48523 Mdot
.57504 .43308 Mdot
.50968 .61299 Mdot
.5327 .67013 Mdot
.6077 .7355 Mdot
.3291 .61681 Mdot
.50602 .59049 Mdot
.44775 .57455 Mdot
.68211 .30567 Mdot
.54355 .68041 Mdot
.45952 .35654 Mdot
.46084 .27835 Mdot
.6269 .44999 Mdot
.7395 .44294 Mdot
.30074 .48931 Mdot
.36227 .65216 Mdot
.31182 .64727 Mdot
.48814 .30173 Mdot
.65015 .66721 Mdot
.31568 .61416 Mdot
.57552 .43726 Mdot
.51785 .66751 Mdot
.61902 .47373 Mdot
.54047 .52691 Mdot
.64835 .47932 Mdot
.54035 .61701 Mdot
.54234 .67994 Mdot
.3049 .48782 Mdot
.28326 .44455 Mdot
.30437 .45766 Mdot
.31724 .61642 Mdot
.6423 .62343 Mdot
.30315 .64174 Mdot
.6073 .19296 Mdot
.51201 .69483 Mdot
.34873 .78551 Mdot
.65279 .41348 Mdot
.63425 .4295 Mdot
.68034 .45993 Mdot
.52915 .55834 Mdot
.61551 .43922 Mdot
.28419 .47162 Mdot
.34225 .65606 Mdot
.26397 .39823 Mdot
.4416 .30508 Mdot
.60895 .199 Mdot
.3528 .61861 Mdot
.54501 .60365 Mdot
.52948 .68918 Mdot
.66415 .72494 Mdot
.51654 .73464 Mdot
.32885 .59766 Mdot
.60817 .4231 Mdot
.46942 .37539 Mdot
.4643 .8369 Mdot
.60293 .45563 Mdot
.31036 .62283 Mdot
.32559 .58784 Mdot
.61058 .49183 Mdot
.72164 .39825 Mdot
.23723 .41305 Mdot
.63916 .65347 Mdot
.54874 .71992 Mdot
.53632 .55453 Mdot
.69089 .63776 Mdot
.32684 .62333 Mdot
.33442 .65388 Mdot
.54644 .72795 Mdot
.49386 .35842 Mdot
.47245 .31838 Mdot
.41324 .36983 Mdot
.29228 .47625 Mdot
.64576 .43525 Mdot
.32272 .63289 Mdot
.48385 .36839 Mdot
.58733 .61522 Mdot
.29989 .45373 Mdot
.31833 .64026 Mdot
.60576 .46673 Mdot
.63102 .4523 Mdot
.53329 .70302 Mdot
.49083 .55324 Mdot
.52642 .5549 Mdot
.36431 .33764 Mdot
.65487 .63932 Mdot
.74669 .44308 Mdot
.64037 .43462 Mdot
.43706 .29234 Mdot
.53798 .5971 Mdot
.53569 .68965 Mdot
.66198 .45792 Mdot
.74475 .3542 Mdot
.43152 .30291 Mdot
.29995 .43153 Mdot
.52001 .58254 Mdot
.68693 .60328 Mdot
.60773 .46668 Mdot
.61647 .43427 Mdot
.68756 .46814 Mdot
.75497 .37329 Mdot
.35952 .6456 Mdot
.44237 .33941 Mdot
.53132 .71941 Mdot
.46674 .34178 Mdot
.30138 .56747 Mdot
.73876 .4481 Mdot
.56923 .44452 Mdot
.44173 .34752 Mdot
.46463 .32597 Mdot
.32241 .44426 Mdot
.28203 .44145 Mdot
.36054 .59716 Mdot
.59072 .4667 Mdot
.50261 .6058 Mdot
.47448 .34 Mdot
.34603 .65738 Mdot
.53179 .70451 Mdot
.29161 .54442 Mdot
.65507 .44998 Mdot
.32388 .62666 Mdot
.52703 .5951 Mdot
.43894 .31227 Mdot
.34625 .62958 Mdot
.54366 .56947 Mdot
.50961 .72107 Mdot
.63166 .41618 Mdot
.30215 .59139 Mdot
.52122 .56906 Mdot
.59695 .47161 Mdot
.5744 .51133 Mdot
.73737 .44219 Mdot
.49793 .61002 Mdot
.37563 .61925 Mdot
.52339 .57218 Mdot
.46145 .28004 Mdot
.6017 .49135 Mdot
.32922 .65563 Mdot
.41709 .26686 Mdot
.74296 .43933 Mdot
.50969 .57486 Mdot
.45041 .34444 Mdot
.28982 .57829 Mdot
.50452 .3657 Mdot
.62579 .72628 Mdot
.59267 .44556 Mdot
.32122 .63546 Mdot
.53772 .69829 Mdot
.32145 .45423 Mdot
.35088 .42122 Mdot
.35135 .50956 Mdot
.35306 .63696 Mdot
.59903 .45814 Mdot
.47345 .35314 Mdot
.29461 .43681 Mdot
.42354 .28591 Mdot
.29657 .61967 Mdot
.32309 .60401 Mdot
.68532 .45744 Mdot
.53079 .70189 Mdot
.63693 .40751 Mdot
.32995 .65724 Mdot
.3117 .658 Mdot
.61027 .21806 Mdot
.5493 .71817 Mdot
.6879 .46908 Mdot
.53675 .61549 Mdot
.67045 .44453 Mdot
.60096 .20589 Mdot
.53597 .56706 Mdot
.44186 .30286 Mdot
.63068 .43803 Mdot
.19962 .6287 Mdot
.36827 .6291 Mdot
.63952 .65363 Mdot
.24741 .4087 Mdot
.28331 .45936 Mdot
.33667 .62892 Mdot
.59841 .44653 Mdot
.29059 .54168 Mdot
.53363 .67844 Mdot
.67239 .47384 Mdot
.51152 .56999 Mdot
.49098 .30016 Mdot
.3146 .45228 Mdot
.46588 .55586 Mdot
.31999 .45786 Mdot
.30904 .4481 Mdot
.52062 .38134 Mdot
.62565 .4505 Mdot
.34889 .61975 Mdot
.30897 .6102 Mdot
.55966 .58167 Mdot
.29915 .66746 Mdot
.46741 .29986 Mdot
.19621 .61967 Mdot
.7463 .35985 Mdot
.64311 .45747 Mdot
.5513 .57866 Mdot
.49765 .58727 Mdot
.29251 .53557 Mdot
.63435 .44646 Mdot
.44667 .33943 Mdot
.3294 .65803 Mdot
.3167 .6298 Mdot
.71985 .46052 Mdot
.28293 .44439 Mdot
.5213 .73077 Mdot
.33725 .6087 Mdot
.6226 .67914 Mdot
.59503 .43672 Mdot
.31589 .41108 Mdot
.33762 .61022 Mdot
.57305 .83097 Mdot
.16136 .56263 Mdot
.46319 .36556 Mdot
.63217 .41479 Mdot
.48127 .32814 Mdot
.54631 .68821 Mdot
.29314 .64102 Mdot
.323 .45533 Mdot
.52063 .5884 Mdot
.21364 .4436 Mdot
.31776 .62546 Mdot
.46018 .33535 Mdot
.624 .44678 Mdot
.73085 .30567 Mdot
.61917 .46842 Mdot
.587 .69509 Mdot
.55092 .67524 Mdot
.3499 .41824 Mdot
.31558 .4293 Mdot
.63088 .41443 Mdot
.53544 .72226 Mdot
.32047 .59664 Mdot
.32679 .61264 Mdot
.22458 .34212 Mdot
.53749 .56497 Mdot
.28896 .63371 Mdot
.59493 .47053 Mdot
.3342 .66163 Mdot
.60204 .24493 Mdot
.2833 .45722 Mdot
.66633 .43883 Mdot
.32748 .64209 Mdot
.50289 .35747 Mdot
.64123 .64599 Mdot
.5918 .44188 Mdot
.51325 .62115 Mdot
.28755 .43641 Mdot
.61076 .19952 Mdot
.37205 .63178 Mdot
.64275 .46278 Mdot
.28077 .47044 Mdot
.4816 .60349 Mdot
.27136 .39431 Mdot
.45021 .33193 Mdot
.3081 .62104 Mdot
.31118 .45754 Mdot
.51569 .5936 Mdot
.54609 .71792 Mdot
.30612 .60415 Mdot
.32911 .64481 Mdot
.70383 .4592 Mdot
.53585 .61248 Mdot
.48197 .59986 Mdot
.44904 .28863 Mdot
.30479 .4379 Mdot
.69314 .46181 Mdot
.63121 .69047 Mdot
.65232 .46629 Mdot
.30834 .43892 Mdot
.56795 .15812 Mdot
.61044 .42113 Mdot
.65697 .44604 Mdot
.73752 .31605 Mdot
.47217 .29616 Mdot
.43733 .28652 Mdot
.66633 .65104 Mdot
.71696 .45388 Mdot
.68567 .41616 Mdot
.45386 .33559 Mdot
.46156 .33292 Mdot
.68649 .41717 Mdot
.70192 .45792 Mdot
.42381 .37495 Mdot
.2939 .43947 Mdot
.28186 .45634 Mdot
.4714 .34279 Mdot
.67641 .46189 Mdot
.27289 .46982 Mdot
.53622 .33079 Mdot
.31472 .60379 Mdot
.69832 .62494 Mdot
.46788 .33431 Mdot
.63654 .64544 Mdot
.2994 .43556 Mdot
.68799 .68919 Mdot
.71192 .61233 Mdot
.57998 .47024 Mdot
.63015 .44974 Mdot
.51675 .7128 Mdot
.52657 .58962 Mdot
.53473 .6019 Mdot
.30471 .45793 Mdot
.63242 .40629 Mdot
.44765 .32075 Mdot
.67938 .43094 Mdot
.61783 .73347 Mdot
.70467 .68469 Mdot
.75448 .39866 Mdot
.45763 .32509 Mdot
.45446 .31089 Mdot
.34964 .60188 Mdot
.38435 .63468 Mdot
.57323 .45713 Mdot
.2853 .43877 Mdot
.4701 .35923 Mdot
.3122 .43906 Mdot
.32682 .62179 Mdot
.35101 .61622 Mdot
.54455 .58865 Mdot
.50646 .59241 Mdot
.33569 .62344 Mdot
.29557 .53966 Mdot
.63193 .69 Mdot
.47613 .28343 Mdot
.60874 .18914 Mdot
.68095 .71147 Mdot
.70841 .28914 Mdot
.53964 .69996 Mdot
.52154 .52005 Mdot
.28325 .47256 Mdot
.63758 .4149 Mdot
.63164 .43401 Mdot
.5295 .57522 Mdot
.27346 .45673 Mdot
.51906 .69055 Mdot
.28354 .45879 Mdot
.54463 .71818 Mdot
.32034 .65153 Mdot
.59646 .45553 Mdot
.61208 .42455 Mdot
.32159 .44793 Mdot
.34382 .59898 Mdot
.32743 .64019 Mdot
.53984 .69495 Mdot
.66859 .71793 Mdot
.32162 .62332 Mdot
.46726 .33281 Mdot
.44824 .23657 Mdot
.53771 .57064 Mdot
.60262 .44322 Mdot
.64887 .72732 Mdot
.601 .4911 Mdot
.54426 .56113 Mdot
.52033 .58167 Mdot
.5956 .18121 Mdot
.59477 .43329 Mdot
.21644 .35297 Mdot
.54187 .59577 Mdot
.46325 .28992 Mdot
.34557 .62313 Mdot
.54998 .57565 Mdot
.52547 .62507 Mdot
.53383 .65165 Mdot
.55033 .57016 Mdot
.47301 .32292 Mdot
.47553 .30981 Mdot
.72787 .44451 Mdot
.61687 .1886 Mdot
.53401 .71772 Mdot
.52433 .68219 Mdot
.35566 .64672 Mdot
.31497 .52435 Mdot
.57927 .41234 Mdot
.52103 .68167 Mdot
.41533 .35476 Mdot
.68804 .45685 Mdot
.72809 .44065 Mdot
.73266 .44795 Mdot
.44987 .27797 Mdot
.60896 .48665 Mdot
.36396 .64006 Mdot
.45866 .3341 Mdot
.72056 .44344 Mdot
.67677 .44683 Mdot
.4481 .32621 Mdot
.30705 .44647 Mdot
.75198 .43027 Mdot
.46788 .35474 Mdot
.73171 .55132 Mdot
.29482 .43201 Mdot
.71959 .43991 Mdot
.40824 .80216 Mdot
.59872 .83071 Mdot
.28547 .45849 Mdot
.31659 .63793 Mdot
.32434 .63249 Mdot
.32169 .61207 Mdot
.44324 .28568 Mdot
.36096 .61322 Mdot
.45156 .29867 Mdot
.29358 .53238 Mdot
.69796 .59627 Mdot
.5298 .71191 Mdot
.29211 .66243 Mdot
.47112 .34533 Mdot
.60327 .19907 Mdot
.86937 .41739 Mdot
.63573 .46742 Mdot
.32518 .44757 Mdot
.51856 .67892 Mdot
.63522 .65744 Mdot
.51326 .70572 Mdot
.33951 .63369 Mdot
.68984 .6031 Mdot
.60284 .434 Mdot
.26423 .33232 Mdot
.53602 .69758 Mdot
.46258 .33343 Mdot
.70926 .46065 Mdot
.37097 .61078 Mdot
.53837 .68267 Mdot
.53025 .6961 Mdot
.61288 .43986 Mdot
.46957 .29555 Mdot
.33639 .63708 Mdot
.27422 .44658 Mdot
.37962 .56756 Mdot
.55932 .51968 Mdot
.58982 .43621 Mdot
.65906 .44126 Mdot
.64522 .63786 Mdot
.29242 .5448 Mdot
.28903 .44193 Mdot
.60587 .72623 Mdot
.37439 .62363 Mdot
.62414 .73468 Mdot
.49722 .3685 Mdot
.29095 .66081 Mdot
.53478 .56722 Mdot
.54524 .5727 Mdot
.60732 .45155 Mdot
.8604 .44624 Mdot
.72263 .40553 Mdot
.27591 .47432 Mdot
.53474 .57414 Mdot
.34619 .59851 Mdot
.43621 .28405 Mdot
.44183 .58275 Mdot
.72207 .44982 Mdot
.27435 .44494 Mdot
.32346 .61649 Mdot
.86371 .4979 Mdot
.51836 .71813 Mdot
.64175 .65868 Mdot
.59788 .46824 Mdot
.60814 .44803 Mdot
.29691 .45815 Mdot
.31414 .47893 Mdot
.61525 .21259 Mdot
.51976 .74041 Mdot
.25784 .31522 Mdot
.29993 .49864 Mdot
.86937 .50978 Mdot
.4983 .59537 Mdot
.45016 .30754 Mdot
.52949 .60474 Mdot
.31238 .48275 Mdot
.62738 .43601 Mdot
.47033 .29497 Mdot
.53306 .59394 Mdot
.42712 .36297 Mdot
.73029 .43977 Mdot
.62505 .6825 Mdot
.61528 .46021 Mdot
.48211 .34256 Mdot
.45452 .33214 Mdot
.48816 .35894 Mdot
.54276 .57949 Mdot
.6487 .44166 Mdot
.63981 .4639 Mdot
.65685 .44133 Mdot
.61717 .21966 Mdot
.59886 .45328 Mdot
.49392 .3776 Mdot
.66327 .66326 Mdot
.20674 .6435 Mdot
.61535 .42453 Mdot
.30778 .45959 Mdot
.60997 .45568 Mdot
.53184 .72487 Mdot
.63975 .41871 Mdot
.73059 .43853 Mdot
.2921 .44451 Mdot
.74108 .34308 Mdot
.52164 .65684 Mdot
.5899 .43433 Mdot
.54979 .71273 Mdot
.35362 .34494 Mdot
.60592 .72228 Mdot
.60154 .22656 Mdot
.46945 .35037 Mdot
.29408 .62865 Mdot
.29961 .49043 Mdot
.35612 .61583 Mdot
.72958 .46302 Mdot
.51817 .60987 Mdot
.33295 .7754 Mdot
.64538 .69429 Mdot
.62891 .43707 Mdot
.50116 .57431 Mdot
.45062 .34864 Mdot
.36721 .63269 Mdot
.67541 .26985 Mdot
.68209 .45928 Mdot
.50541 .7076 Mdot
.50983 .71146 Mdot
.54911 .54029 Mdot
.49095 .35797 Mdot
.60019 .23903 Mdot
.29578 .45675 Mdot
.31618 .61942 Mdot
.53947 .67028 Mdot
.4049 .34963 Mdot
.32397 .46002 Mdot
.29598 .53358 Mdot
.31382 .45518 Mdot
.63196 .42625 Mdot
.547 .59033 Mdot
.38038 .35194 Mdot
.52699 .56719 Mdot
.67147 .45057 Mdot
.33066 .64448 Mdot
.53653 .5662 Mdot
.52208 .7128 Mdot
.31057 .45411 Mdot
.35345 .62085 Mdot
.62086 .44202 Mdot
.45201 .33785 Mdot
.66956 .53653 Mdot
.29095 .60366 Mdot
.74108 .4442 Mdot
.74115 .44427 Mdot
.47775 .27953 Mdot
.49543 .6064 Mdot
.34017 .40195 Mdot
.60211 .49219 Mdot
.33699 .52276 Mdot
.48138 .56077 Mdot
.26238 .66416 Mdot
.30108 .63959 Mdot
.33583 .61638 Mdot
.61385 .42814 Mdot
.34462 .65852 Mdot
.57304 .43931 Mdot
.37826 .62418 Mdot
.36621 .32268 Mdot
.69316 .43863 Mdot
.33136 .61126 Mdot
.52591 .60324 Mdot
.59206 .47083 Mdot
.44661 .34377 Mdot
.30149 .6451 Mdot
.58032 .47073 Mdot
.2693 .69565 Mdot
.32229 .44561 Mdot
.54334 .57859 Mdot
.61059 .61794 Mdot
.29996 .44174 Mdot
.46754 .30424 Mdot
.58313 .42501 Mdot
.52335 .67816 Mdot
.45519 .30679 Mdot
.54227 .54637 Mdot
.52961 .70029 Mdot
.6392 .66679 Mdot
.46625 .31378 Mdot
.53475 .56906 Mdot
.5088 .71751 Mdot
.56021 .58682 Mdot
.33271 .61578 Mdot
.31633 .58823 Mdot
.51804 .57098 Mdot
.60691 .43237 Mdot
.35443 .60125 Mdot
.2944 .46764 Mdot
.58705 .4534 Mdot
.32086 .63296 Mdot
.53775 .58442 Mdot
.61916 .47098 Mdot
.71835 .45371 Mdot
.60564 .21002 Mdot
.49251 .58402 Mdot
.52698 .71306 Mdot
.48662 .36381 Mdot
.65256 .45577 Mdot
.54136 .71651 Mdot
.29776 .60191 Mdot
.64067 .4661 Mdot
.47094 .36285 Mdot
.53537 .38068 Mdot
.37018 .64809 Mdot
.29083 .42959 Mdot
.30522 .61391 Mdot
.5518 .69526 Mdot
.87273 .40501 Mdot
.53835 .59797 Mdot
.66122 .47592 Mdot
.65034 .42759 Mdot
.29416 .63439 Mdot
.45221 .329 Mdot
.2721 .30007 Mdot
.63351 .41623 Mdot
.63154 .47117 Mdot
.60687 .44198 Mdot
.34774 .55434 Mdot
.45099 .28502 Mdot
.60458 .4422 Mdot
.50313 .53714 Mdot
.66084 .43852 Mdot
.54543 .6918 Mdot
.36835 .79529 Mdot
.54173 .56262 Mdot
.54668 .14402 Mdot
.53624 .59263 Mdot
.32974 .60768 Mdot
.7322 .55054 Mdot
.60837 .61721 Mdot
.38413 .59854 Mdot
.46694 .30172 Mdot
.38865 .34042 Mdot
.34944 .61534 Mdot
.29273 .575 Mdot
.72168 .44731 Mdot
.70897 .45938 Mdot
.58543 .46376 Mdot
.33973 .63353 Mdot
.35577 .6524 Mdot
.51326 .60827 Mdot
.50597 .56906 Mdot
.57558 .48239 Mdot
.30784 .63815 Mdot
.59682 .45372 Mdot
.63993 .48232 Mdot
.32512 .45727 Mdot
.46187 .36396 Mdot
.32065 .46211 Mdot
.32759 .44421 Mdot
.7009 .28393 Mdot
.65504 .6375 Mdot
.29147 .4763 Mdot
.28549 .48058 Mdot
.31639 .54127 Mdot
.69412 .30413 Mdot
.54714 .69591 Mdot
.71992 .40503 Mdot
.34863 .60398 Mdot
.64937 .44371 Mdot
.45142 .28405 Mdot
.50349 .56158 Mdot
.30071 .27414 Mdot
.79459 .61313 Mdot
.69052 .45782 Mdot
.3696 .61759 Mdot
.51978 .56891 Mdot
.51892 .56565 Mdot
.62689 .73188 Mdot
.59849 .45108 Mdot
.36464 .6512 Mdot
.68247 .30447 Mdot
.30555 .50037 Mdot
.29231 .53989 Mdot
.48906 .34772 Mdot
.6079 .45689 Mdot
.44302 .29068 Mdot
.28326 .42942 Mdot
.54163 .71251 Mdot
.52186 .7179 Mdot
.59029 .43342 Mdot
.73853 .4383 Mdot
.34057 .52151 Mdot
.71803 .45623 Mdot
.70031 .45618 Mdot
.52284 .57367 Mdot
.69317 .46858 Mdot
.64538 .46141 Mdot
.68961 .44809 Mdot
.54173 .55811 Mdot
.32383 .45744 Mdot
.68058 .28681 Mdot
.51073 .57321 Mdot
.59946 .41579 Mdot
.28618 .42792 Mdot
.72174 .45325 Mdot
.2955 .46394 Mdot
.29386 .5463 Mdot
.30117 .47584 Mdot
.52792 .71742 Mdot
.37623 .64841 Mdot
.6138 .20133 Mdot
.4719 .35417 Mdot
.27972 .44784 Mdot
.50951 .72242 Mdot
.29946 .46546 Mdot
.34037 .60057 Mdot
.31729 .49609 Mdot
.50734 .30268 Mdot
.62191 .67623 Mdot
.71452 .29737 Mdot
.30384 .49913 Mdot
.3724 .64577 Mdot
.47191 .34278 Mdot
.31587 .52144 Mdot
.62016 .41489 Mdot
.52098 .71998 Mdot
.60873 .45062 Mdot
.3101 .45147 Mdot
.36091 .6091 Mdot
.59991 .22303 Mdot
.52582 .71389 Mdot
.60573 .18813 Mdot
.305 .63725 Mdot
.62766 .42001 Mdot
.29783 .42189 Mdot
.35465 .43465 Mdot
.31879 .43326 Mdot
.70269 .60093 Mdot
.50659 .60994 Mdot
.52775 .7546 Mdot
.45969 .30969 Mdot
.49795 .59871 Mdot
.69451 .76229 Mdot
.36413 .37992 Mdot
.44185 .32775 Mdot
.28693 .63025 Mdot
.59456 .43578 Mdot
.68795 .47016 Mdot
.51314 .5993 Mdot
.48177 .35632 Mdot
.68767 .46789 Mdot
.54593 .58225 Mdot
.66915 .65975 Mdot
.48956 .35314 Mdot
.30605 .60229 Mdot
.5916 .46817 Mdot
.32024 .42467 Mdot
.29417 .425 Mdot
.54417 .59576 Mdot
.31806 .46249 Mdot
.59132 .41885 Mdot
.4679 .32315 Mdot
.72753 .44562 Mdot
.54369 .68491 Mdot
.39172 .3779 Mdot
.52314 .5512 Mdot
.5012 .69696 Mdot
.61244 .47549 Mdot
.35005 .61768 Mdot
.21214 .4441 Mdot
.66083 .42371 Mdot
.45645 .33601 Mdot
.64062 .42278 Mdot
.69037 .46845 Mdot
.71319 .45813 Mdot
.31634 .61961 Mdot
.63994 .64484 Mdot
.59772 .45429 Mdot
.27719 .43853 Mdot
.69215 .42038 Mdot
.64948 .41328 Mdot
.51824 .74338 Mdot
.72913 .43871 Mdot
.27519 .42879 Mdot
.48146 .28727 Mdot
.34764 .61992 Mdot
.4488 .31615 Mdot
.43783 .35133 Mdot
.46687 .30361 Mdot
.49314 .33886 Mdot
.59959 .49202 Mdot
.21555 .34755 Mdot
.60168 .24324 Mdot
.71853 .29617 Mdot
.43589 .34216 Mdot
.1886 .46811 Mdot
.44171 .33 Mdot
.46732 .30344 Mdot
.3749 .23128 Mdot
.46445 .29525 Mdot
.61243 .43313 Mdot
.64126 .42606 Mdot
.74821 .36742 Mdot
.38274 .56866 Mdot
.62268 .46813 Mdot
.54537 .5598 Mdot
.5145 .6835 Mdot
.49325 .36296 Mdot
.5209 .58575 Mdot
.63395 .6588 Mdot
.55018 .59037 Mdot
.61363 .43995 Mdot
.59516 .46097 Mdot
.72721 .45301 Mdot
.71727 .68026 Mdot
.39881 .57897 Mdot
.47592 .32013 Mdot
.64474 .41071 Mdot
.28436 .39218 Mdot
.58639 .46067 Mdot
.65152 .42488 Mdot
.61274 .48638 Mdot
.34896 .61972 Mdot
.43776 .27976 Mdot
.50341 .59206 Mdot
.38781 .37874 Mdot
.61335 .46482 Mdot
.50606 .55456 Mdot
.51716 .67362 Mdot
.59825 .44555 Mdot
.4707 .30144 Mdot
.68939 .46819 Mdot
.43338 .30408 Mdot
.46366 .30895 Mdot
.63694 .46844 Mdot
.49165 .36318 Mdot
.43383 .2906 Mdot
.70884 .45888 Mdot
.36528 .6086 Mdot
.36366 .33649 Mdot
.60299 .43513 Mdot
.52285 .70949 Mdot
.63188 .44617 Mdot
.54791 .69455 Mdot
.55025 .57246 Mdot
.52315 .57063 Mdot
.68868 .36132 Mdot
.3311 .65389 Mdot
.50723 .72855 Mdot
.32682 .6625 Mdot
.58982 .41145 Mdot
.41911 .35366 Mdot
.31707 .49152 Mdot
.27559 .64106 Mdot
.5244 .57236 Mdot
.5916 .6998 Mdot
.6577 .40111 Mdot
.30647 .47464 Mdot
.43883 .33215 Mdot
.66825 .29027 Mdot
.4961 .58821 Mdot
.30771 .60098 Mdot
.31187 .6079 Mdot
.36393 .39122 Mdot
.38715 .22957 Mdot
.61407 .42502 Mdot
.49701 .58254 Mdot
.57065 .50319 Mdot
.52757 .59017 Mdot
.51098 .60568 Mdot
.32631 .64506 Mdot
.61796 .4704 Mdot
.67351 .65878 Mdot
.32621 .63016 Mdot
.52694 .68579 Mdot
.44205 .30103 Mdot
.54341 .71721 Mdot
.30369 .30657 Mdot
.6152 .21039 Mdot
.33309 .62555 Mdot
.53581 .55802 Mdot
.65206 .44852 Mdot
.46704 .29109 Mdot
.42364 .28702 Mdot
.44954 .35118 Mdot
.53221 .67534 Mdot
.32339 .65569 Mdot
.27349 .70937 Mdot
.62294 .44834 Mdot
.46349 .32565 Mdot
.52042 .66341 Mdot
.63227 .45246 Mdot
.28306 .44191 Mdot
.68848 .46617 Mdot
.46584 .33546 Mdot
.65887 .4753 Mdot
.46007 .30912 Mdot
.3186 .60606 Mdot
.59588 .43002 Mdot
.58326 .44667 Mdot
.60284 .7212 Mdot
.51821 .69151 Mdot
.43261 .31464 Mdot
.65079 .628 Mdot
.6705 .44461 Mdot
.63546 .73053 Mdot
.59221 .4526 Mdot
.71714 .29984 Mdot
.52604 .61956 Mdot
.54709 .58234 Mdot
.64534 .42478 Mdot
.5996 .43776 Mdot
.42542 .28457 Mdot
.60336 .24682 Mdot
.61757 .21844 Mdot
.29125 .42812 Mdot
.44249 .33713 Mdot
.32951 .6322 Mdot
.30102 .64706 Mdot
.3583 .61341 Mdot
.54834 .68355 Mdot
.72535 .44923 Mdot
.62568 .42933 Mdot
.27007 .45811 Mdot
.51444 .68778 Mdot
.4581 .3197 Mdot
.53422 .71011 Mdot
.6494 .64228 Mdot
.51965 .70786 Mdot
.52659 .60726 Mdot
.16388 .53143 Mdot
.63866 .48295 Mdot
.52519 .69471 Mdot
.46467 .3643 Mdot
.69812 .42085 Mdot
.59635 .48168 Mdot
.60593 .20159 Mdot
.50597 .70251 Mdot
.28658 .62367 Mdot
.60618 .47474 Mdot
.69489 .58311 Mdot
.29982 .46179 Mdot
.54176 .71977 Mdot
.3144 .45581 Mdot
.69128 .45962 Mdot
.38994 .3086 Mdot
.46114 .34219 Mdot
.32509 .4612 Mdot
.65649 .42907 Mdot
.54124 .72008 Mdot
.33331 .62161 Mdot
.69303 .30473 Mdot
.30018 .53212 Mdot
.49045 .57113 Mdot
.6249 .72926 Mdot
.36238 .64233 Mdot
.71002 .31207 Mdot
.31226 .46583 Mdot
.67377 .42356 Mdot
.65104 .47735 Mdot
.65883 .45641 Mdot
.33133 .63953 Mdot
.33669 .61626 Mdot
.26311 .63935 Mdot
.58276 .44292 Mdot
.60844 .48615 Mdot
.49385 .30105 Mdot
.32804 .65713 Mdot
.46643 .30381 Mdot
.48371 .35066 Mdot
.31748 .63806 Mdot
.43562 .32927 Mdot
.53036 .69847 Mdot
.67891 .6309 Mdot
.31048 .46773 Mdot
.30402 .42506 Mdot
.3352 .62479 Mdot
.348 .64567 Mdot
.35083 .6177 Mdot
.68427 .46485 Mdot
.46523 .30821 Mdot
.58414 .4307 Mdot
.614 .45346 Mdot
.60363 .48151 Mdot
.48221 .32882 Mdot
.62867 .41508 Mdot
.68841 .42939 Mdot
.52391 .67191 Mdot
.33415 .60762 Mdot
.30967 .43563 Mdot
.66882 .5399 Mdot
.2765 .43777 Mdot
.66449 .44171 Mdot
.36725 .32732 Mdot
.43842 .32578 Mdot
.51419 .70869 Mdot
.73603 .44007 Mdot
.52257 .71521 Mdot
.32528 .45691 Mdot
.49627 .30641 Mdot
.6451 .66756 Mdot
.58956 .42874 Mdot
.64853 .63514 Mdot
.49279 .79583 Mdot
.50477 .37815 Mdot
.3042 .43951 Mdot
.6561 .47191 Mdot
.54598 .59715 Mdot
.57465 .48972 Mdot
.61842 .42851 Mdot
.65485 .41467 Mdot
.68651 .5783 Mdot
.65723 .43479 Mdot
.47009 .36793 Mdot
.69286 .42703 Mdot
.5264 .55691 Mdot
.6028 .47846 Mdot
.22497 .34891 Mdot
.62958 .46391 Mdot
.58699 .43313 Mdot
.63652 .4344 Mdot
.67386 .43489 Mdot
.48141 .32346 Mdot
.73273 .44479 Mdot
.28083 .43303 Mdot
.6792 .63151 Mdot
.30732 .46966 Mdot
.33993 .62766 Mdot
.49705 .57087 Mdot
.45423 .27587 Mdot
.52176 .71489 Mdot
.39269 .55157 Mdot
.69835 .58619 Mdot
.34909 .60159 Mdot
.5948 .71628 Mdot
.52501 .73097 Mdot
.51472 .605 Mdot
.55327 .69922 Mdot
.32844 .64272 Mdot
.28258 .44866 Mdot
.60906 .42266 Mdot
.47258 .32789 Mdot
.46697 .35661 Mdot
.60355 .47783 Mdot
.35988 .34607 Mdot
.29768 .42529 Mdot
.2949 .66552 Mdot
.62407 .4258 Mdot
.66651 .43899 Mdot
.43449 .29763 Mdot
.36806 .62303 Mdot
.66003 .4027 Mdot
.54082 .69052 Mdot
.58898 .46257 Mdot
.52105 .55987 Mdot
.64914 .64096 Mdot
.28905 .42904 Mdot
.53884 .57858 Mdot
.64588 .45176 Mdot
.65523 .64719 Mdot
.67209 .47283 Mdot
.51011 .53259 Mdot
.38327 .6327 Mdot
.63098 .47123 Mdot
.58308 .45112 Mdot
.48929 .35115 Mdot
.31395 .46472 Mdot
.45106 .33091 Mdot
.49181 .28626 Mdot
.5236 .57106 Mdot
.3215 .43806 Mdot
.67369 .43685 Mdot
.27175 .47317 Mdot
.69142 .4654 Mdot
.61773 .44689 Mdot
.30499 .44196 Mdot
.45885 .30016 Mdot
.26162 .31405 Mdot
.67915 .28648 Mdot
.69475 .45874 Mdot
.6338 .44738 Mdot
.38339 .56923 Mdot
.50412 .5609 Mdot
.60339 .42025 Mdot
.46981 .35855 Mdot
.63021 .45254 Mdot
.28573 .48647 Mdot
.53696 .71441 Mdot
.45621 .34014 Mdot
.37134 .62734 Mdot
.31561 .61039 Mdot
.38684 .63286 Mdot
.52317 .60843 Mdot
.69386 .46835 Mdot
.48678 .36245 Mdot
.48498 .35707 Mdot
.63599 .61947 Mdot
.33012 .60792 Mdot
.54003 .7039 Mdot
.58558 .46684 Mdot
.49978 .5751 Mdot
.30843 .42013 Mdot
.54287 .14178 Mdot
.64877 .66587 Mdot
.53407 .66737 Mdot
.56031 .52302 Mdot
.52435 .57694 Mdot
.65575 .4449 Mdot
.53913 .72031 Mdot
.31842 .63707 Mdot
.68289 .47304 Mdot
.48669 .55232 Mdot
.28536 .62473 Mdot
.35888 .63138 Mdot
.26917 .46599 Mdot
.37799 .63085 Mdot
.54559 .71978 Mdot
.5371 .59933 Mdot
.45989 .35048 Mdot
.5971 .44833 Mdot
.51078 .57995 Mdot
.33313 .60363 Mdot
.50045 .59707 Mdot
.62911 .42345 Mdot
.43627 .29963 Mdot
.35146 .60775 Mdot
.6153 .4369 Mdot
.61272 .49182 Mdot
.60642 .21157 Mdot
.36645 .61235 Mdot
.57747 .43187 Mdot
.44869 .57426 Mdot
.35753 .62798 Mdot
.33285 .64173 Mdot
.64439 .46395 Mdot
.52798 .72801 Mdot
.61062 .46215 Mdot
.28445 .44293 Mdot
.64107 .63784 Mdot
.32176 .44706 Mdot
.62704 .73428 Mdot
.61246 .47792 Mdot
.56254 .47872 Mdot
.42429 .35992 Mdot
.50183 .68307 Mdot
.67853 .71368 Mdot
.65165 .45543 Mdot
.4304 .28801 Mdot
.63717 .64413 Mdot
.61944 .66714 Mdot
.52132 .31438 Mdot
.54784 .70642 Mdot
.30417 .45881 Mdot
.58591 .44123 Mdot
.23516 .34752 Mdot
.54523 .6984 Mdot
.62811 .73252 Mdot
.63182 .41299 Mdot
.45912 .32919 Mdot
.61471 .42609 Mdot
.46293 .34884 Mdot
.6412 .44849 Mdot
.60122 .21583 Mdot
.3403 .5214 Mdot
.70241 .60028 Mdot
.52301 .60318 Mdot
.35461 .43443 Mdot
.71498 .29714 Mdot
.53338 .70039 Mdot
.65552 .47475 Mdot
.52901 .57901 Mdot
.28384 .45933 Mdot
.23184 .43125 Mdot
.35052 .61519 Mdot
.27587 .44552 Mdot
.44744 .30755 Mdot
.34493 .59698 Mdot
.4991 .59998 Mdot
.55902 .47582 Mdot
.53774 .72277 Mdot
.32119 .43698 Mdot
.59618 .44344 Mdot
.66841 .45504 Mdot
.34377 .55284 Mdot
.38114 .80142 Mdot
.47549 .37444 Mdot
.60476 .18399 Mdot
.49592 .30558 Mdot
.52169 .68547 Mdot
.36278 .60646 Mdot
.63097 .4361 Mdot
.60939 .46921 Mdot
.35948 .63275 Mdot
.46576 .28886 Mdot
.51123 .72974 Mdot
.52738 .75533 Mdot
.27504 .47329 Mdot
.43331 .81932 Mdot
.45672 .34279 Mdot
.4308 .81872 Mdot
.26353 .67427 Mdot
.41838 .22992 Mdot
.67237 .71658 Mdot
.29632 .44109 Mdot
.43235 .81946 Mdot
.46105 .32748 Mdot
.64596 .43187 Mdot
.53212 .57032 Mdot
.51703 .61029 Mdot
.43974 .29481 Mdot
.34333 .63096 Mdot
.53303 .72899 Mdot
.60914 .42822 Mdot
.51176 .52366 Mdot
.42344 .28593 Mdot
.32035 .65226 Mdot
.52239 .59283 Mdot
.30512 .4319 Mdot
.6335 .45052 Mdot
.52703 .67344 Mdot
.2956 .4426 Mdot
.54479 .57007 Mdot
.68844 .6056 Mdot
.58238 .42562 Mdot
.74032 .44047 Mdot
.29736 .46148 Mdot
.56152 .52589 Mdot
.58534 .4527 Mdot
.31241 .46563 Mdot
.5494 .59902 Mdot
.34715 .40086 Mdot
.61925 .39682 Mdot
.36411 .38006 Mdot
.32131 .59312 Mdot
.37646 .62067 Mdot
.31475 .70045 Mdot
.40361 .61188 Mdot
.29285 .47347 Mdot
.51589 .58007 Mdot
.35908 .79242 Mdot
.31656 .46117 Mdot
.65527 .4231 Mdot
.58956 .4384 Mdot
.68143 .30434 Mdot
.54303 .56522 Mdot
.53647 .59424 Mdot
.39794 .2781 Mdot
.70608 .44671 Mdot
.52115 .59158 Mdot
.5891 .45451 Mdot
.47617 .31378 Mdot
.29818 .4339 Mdot
.81264 .65087 Mdot
.30527 .49016 Mdot
.70782 .46843 Mdot
.35122 .60478 Mdot
.32463 .59283 Mdot
.59936 .44638 Mdot
.4372 .55717 Mdot
.86862 .50467 Mdot
.58863 .43896 Mdot
.73537 .43978 Mdot
.62319 .73464 Mdot
.60547 .47917 Mdot
.45306 .36143 Mdot
.53487 .56122 Mdot
.48411 .33891 Mdot
.29976 .44454 Mdot
.54766 .70577 Mdot
.52074 .65395 Mdot
.30348 .45868 Mdot
.61926 .46639 Mdot
.53471 .55014 Mdot
.60819 .44611 Mdot
.64267 .43304 Mdot
.6515 .64941 Mdot
.53753 .67072 Mdot
.35004 .62374 Mdot
.52438 .71753 Mdot
.46666 .3002 Mdot
.57894 .1645 Mdot
.53463 .7042 Mdot
.69333 .30421 Mdot
.64531 .63023 Mdot
.3664 .79339 Mdot
.46483 .35606 Mdot
.54636 .68765 Mdot
.30541 .45986 Mdot
.61342 .63353 Mdot
.71516 .323 Mdot
.2752 .44385 Mdot
.64235 .43504 Mdot
.48267 .33969 Mdot
.48211 .28468 Mdot
.28741 .42405 Mdot
.45282 .34859 Mdot
.58224 .40571 Mdot
.70404 .45292 Mdot
.28087 .43218 Mdot
.69877 .69753 Mdot
.31581 .42929 Mdot
.69126 .27916 Mdot
.69595 .46329 Mdot
.4565 .33783 Mdot
.72738 .30061 Mdot
.49982 .30997 Mdot
.54352 .58907 Mdot
.62523 .41767 Mdot
.53744 .70309 Mdot
.64253 .62344 Mdot
.37216 .6219 Mdot
.50233 .35747 Mdot
.46931 .34189 Mdot
.3064 .41841 Mdot
.45375 .34883 Mdot
.43758 .32989 Mdot
.32585 .45861 Mdot
.44149 .33373 Mdot
.61344 .46526 Mdot
.61939 .19218 Mdot
.45073 .34994 Mdot
.29567 .45355 Mdot
.53102 .67636 Mdot
.46359 .36542 Mdot
.28414 .58483 Mdot
.59312 .46963 Mdot
.29717 .61992 Mdot
.56209 .70718 Mdot
.47994 .32052 Mdot
.53513 .6995 Mdot
.33779 .60333 Mdot
.50386 .70811 Mdot
.26241 .44935 Mdot
.26525 .44104 Mdot
.52417 .6259 Mdot
.36414 .40994 Mdot
.46471 .29593 Mdot
.34825 .59772 Mdot
.57921 .45731 Mdot
.63174 .42726 Mdot
.55497 .68019 Mdot
.4313 .3065 Mdot
.35713 .34316 Mdot
.52051 .58719 Mdot
.39335 .37875 Mdot
.29378 .42638 Mdot
.29333 .66389 Mdot
.64489 .66918 Mdot
.30252 .52088 Mdot
.52717 .55647 Mdot
.52573 .57652 Mdot
.60653 .44156 Mdot
.60694 .72473 Mdot
.54723 .71639 Mdot
.18518 .48194 Mdot
.67818 .46374 Mdot
.35918 .63694 Mdot
.64437 .44437 Mdot
.71533 .44495 Mdot
.64993 .458 Mdot
.53685 .66775 Mdot
.27642 .46364 Mdot
.47147 .35575 Mdot
.54787 .69133 Mdot
.31478 .61101 Mdot
.72854 .56984 Mdot
.59887 .42165 Mdot
.57115 .44192 Mdot
.35134 .63065 Mdot
.47066 .31089 Mdot
.34011 .622 Mdot
.31038 .46761 Mdot
.53301 .70678 Mdot
.68611 .46763 Mdot
.54247 .56447 Mdot
.29441 .63589 Mdot
.27921 .4505 Mdot
.36433 .60651 Mdot
.28874 .49259 Mdot
.52606 .57324 Mdot
.56643 .44853 Mdot
.35989 .65409 Mdot
.50588 .5724 Mdot
.62719 .30378 Mdot
.68678 .60246 Mdot
.495 .26534 Mdot
.3434 .63301 Mdot
.37527 .59366 Mdot
.29536 .44661 Mdot
.31102 .48056 Mdot
.69056 .276 Mdot
.85862 .45177 Mdot
.68533 .41606 Mdot
.34667 .35858 Mdot
.30955 .46881 Mdot
.2909 .4592 Mdot
.34338 .62144 Mdot
.45677 .29775 Mdot
.4399 .37439 Mdot
.32624 .59663 Mdot
.65411 .72299 Mdot
.45835 .31987 Mdot
.74674 .36293 Mdot
.30749 .64468 Mdot
.71354 .45928 Mdot
.59919 .22208 Mdot
.51826 .67484 Mdot
.62071 .72677 Mdot
.31653 .49481 Mdot
.61828 .43368 Mdot
.21724 .34532 Mdot
.3476 .61325 Mdot
.49985 .58864 Mdot
.29871 .39397 Mdot
.67556 .44787 Mdot
.64695 .44319 Mdot
.62185 .4589 Mdot
.5559 .71322 Mdot
.60523 .26228 Mdot
.62371 .4343 Mdot
.69383 .60045 Mdot
.73083 .45782 Mdot
.29996 .59365 Mdot
.52551 .71754 Mdot
.59167 .71097 Mdot
.30701 .56164 Mdot
.38546 .37917 Mdot
.65378 .41396 Mdot
.29611 .4858 Mdot
.71444 .4438 Mdot
.30672 .44261 Mdot
.27267 .43535 Mdot
.45474 .83126 Mdot
.47573 .3594 Mdot
.68162 .46307 Mdot
.32677 .65018 Mdot
.43852 .37403 Mdot
.71968 .44501 Mdot
.58874 .17052 Mdot
.32055 .41866 Mdot
.87364 .39998 Mdot
.31085 .47829 Mdot
.5061 .60492 Mdot
.44411 .31205 Mdot
.42754 .28871 Mdot
.6499 .63552 Mdot
.46503 .30257 Mdot
.40559 .60314 Mdot
.48459 .36452 Mdot
.56846 .80685 Mdot
.51282 .30885 Mdot
.29078 .44838 Mdot
.29312 .42207 Mdot
.72775 .45029 Mdot
.60589 .46336 Mdot
.67091 .65991 Mdot
.521 .588 Mdot
.60316 .41631 Mdot
.32571 .63027 Mdot
.27045 .60993 Mdot
.21545 .41954 Mdot
.44051 .33024 Mdot
.281 .45958 Mdot
.64563 .443 Mdot
.69346 .46317 Mdot
.6385 .42402 Mdot
.32521 .53065 Mdot
.76185 .37152 Mdot
.6133 .4517 Mdot
.72542 .45023 Mdot
.33827 .59805 Mdot
.3468 .55434 Mdot
.39626 .22906 Mdot
.44501 .82537 Mdot
.62133 .47101 Mdot
.51789 .68618 Mdot
.54236 .67403 Mdot
.70289 .44129 Mdot
.53181 .45552 Mdot
.5736 .58983 Mdot
.59654 .4426 Mdot
.72992 .56361 Mdot
.30131 .60582 Mdot
.54392 .59841 Mdot
.33114 .6045 Mdot
.43345 .33992 Mdot
.54917 .5859 Mdot
.32298 .63517 Mdot
.70124 .62258 Mdot
.51821 .57244 Mdot
.34213 .40034 Mdot
.54382 .68445 Mdot
.58755 .45421 Mdot
.65815 .26923 Mdot
.32728 .65729 Mdot
.28547 .44619 Mdot
.44375 .32242 Mdot
.28943 .42984 Mdot
.39486 .63058 Mdot
.64118 .73087 Mdot
.54427 .58412 Mdot
.29454 .48641 Mdot
.7333 .43746 Mdot
.51458 .68946 Mdot
.31482 .47097 Mdot
.71564 .46436 Mdot
.6989 .44172 Mdot
.85421 .49232 Mdot
.57669 .45864 Mdot
.26686 .62067 Mdot
.32249 .44805 Mdot
.54825 .59462 Mdot
.59753 .4493 Mdot
.30197 .63262 Mdot
.55543 .59878 Mdot
.61003 .44518 Mdot
.36824 .63617 Mdot
.58927 .44107 Mdot
.53438 .72033 Mdot
.48746 .3466 Mdot
.63383 .64711 Mdot
.51473 .75497 Mdot
.54825 .70196 Mdot
.69852 .58291 Mdot
.61487 .41712 Mdot
.4094 .61283 Mdot
.45662 .32782 Mdot
.66369 .44144 Mdot
.57315 .78501 Mdot
.44621 .2977 Mdot
.45048 .31322 Mdot
.69472 .47145 Mdot
.29248 .49123 Mdot
.35061 .6268 Mdot
.51217 .7037 Mdot
.29288 .53767 Mdot
.61888 .4359 Mdot
.66068 .4725 Mdot
.54656 .69538 Mdot
.289 .43644 Mdot
.68755 .46038 Mdot
.32675 .38385 Mdot
.68089 .62599 Mdot
.32566 .44855 Mdot
.65921 .41671 Mdot
.76107 .35857 Mdot
.45461 .28026 Mdot
.21689 .34758 Mdot
.34076 .521 Mdot
.31274 .60889 Mdot
.51936 .5922 Mdot
.54965 .14664 Mdot
.53321 .67558 Mdot
.49062 .38741 Mdot
.63007 .42477 Mdot
.63463 .4404 Mdot
.47325 .3027 Mdot
.58171 .43541 Mdot
.43952 .33018 Mdot
.2871 .58127 Mdot
.86231 .44035 Mdot
.46425 .35336 Mdot
.46517 .34117 Mdot
.75327 .42626 Mdot
.34274 .66132 Mdot
.44095 .30294 Mdot
.5816 .44847 Mdot
.39631 .62873 Mdot
.52047 .52555 Mdot
.50922 .72599 Mdot
.55064 .72237 Mdot
.45421 .36433 Mdot
.71908 .32468 Mdot
.71812 .46161 Mdot
.68085 .34423 Mdot
.57254 .60212 Mdot
.29451 .47482 Mdot
.64472 .47024 Mdot
.52272 .58346 Mdot
.34057 .60626 Mdot
.59274 .48133 Mdot
.58937 .45699 Mdot
.47552 .35304 Mdot
.50699 .69273 Mdot
.31668 .45596 Mdot
.50466 .57488 Mdot
.3923 .62658 Mdot
.53374 .68784 Mdot
.43595 .32817 Mdot
.7092 .29081 Mdot
.52258 .55264 Mdot
.50115 .57399 Mdot
.65797 .44558 Mdot
.64021 .46603 Mdot
.52702 .55446 Mdot
.30319 .45653 Mdot
.31023 .6098 Mdot
.50383 .59095 Mdot
.62109 .61602 Mdot
.68211 .6498 Mdot
.6502 .45468 Mdot
.46668 .36315 Mdot
.28256 .45931 Mdot
.54072 .59085 Mdot
.35156 .78747 Mdot
.59137 .47265 Mdot
.7492 .36388 Mdot
.52715 .74136 Mdot
.52014 .58041 Mdot
.44092 .37522 Mdot
.51696 .71343 Mdot
.69578 .46308 Mdot
.69679 .60103 Mdot
.61616 .41352 Mdot
.6731 .42312 Mdot
.32075 .63949 Mdot
.3125 .44921 Mdot
.51955 .62545 Mdot
.33567 .60834 Mdot
.44935 .31509 Mdot
.68432 .34986 Mdot
.48218 .34576 Mdot
.48376 .35983 Mdot
.49461 .34379 Mdot
.2947 .42824 Mdot
.5489 .14566 Mdot
.5193 .55552 Mdot
.60721 .42542 Mdot
.28429 .47279 Mdot
.43899 .30855 Mdot
.63448 .4157 Mdot
.43853 .32642 Mdot
.43219 .31614 Mdot
.61091 .41378 Mdot
.71823 .45406 Mdot
.69963 .59573 Mdot
.74684 .35175 Mdot
.52383 .72047 Mdot
.46361 .28943 Mdot
.73398 .34055 Mdot
.62928 .4365 Mdot
.59662 .46182 Mdot
.73017 .44862 Mdot
.55058 .69808 Mdot
.68681 .35937 Mdot
.63383 .4269 Mdot
.60323 .72806 Mdot
.64207 .41829 Mdot
.43078 .3054 Mdot
.35052 .41994 Mdot
.71021 .46775 Mdot
.3416 .59706 Mdot
.46683 .28994 Mdot
.51764 .67502 Mdot
.442 .26909 Mdot
.60458 .49093 Mdot
.29646 .46662 Mdot
.46578 .33553 Mdot
.31956 .59793 Mdot
.28771 .44215 Mdot
.31557 .42932 Mdot
.73183 .44844 Mdot
.30599 .619 Mdot
.50752 .69094 Mdot
.31645 .43763 Mdot
.57839 .49225 Mdot
.2896 .44776 Mdot
.54786 .3573 Mdot
.56889 .44722 Mdot
.69419 .60214 Mdot
.51098 .5951 Mdot
.52513 .62108 Mdot
.32068 .44303 Mdot
.54179 .69017 Mdot
.68687 .46051 Mdot
.44668 .34541 Mdot
.52632 .67812 Mdot
.59996 .22713 Mdot
.32755 .5932 Mdot
.48297 .28674 Mdot
.2979 .53271 Mdot
.45385 .29002 Mdot
.6234 .72792 Mdot
.52489 .66897 Mdot
.49662 .57926 Mdot
.63995 .65446 Mdot
.52675 .59374 Mdot
.5862 .47753 Mdot
.68583 .46063 Mdot
.61612 .46517 Mdot
.35224 .60494 Mdot
.55386 .71646 Mdot
.45549 .35701 Mdot
.46883 .5595 Mdot
.29031 .43312 Mdot
.70635 .43348 Mdot
.50148 .59091 Mdot
.69183 .46056 Mdot
.43939 .31667 Mdot
.43419 .28818 Mdot
.6042 .25007 Mdot
.35918 .62521 Mdot
.47528 .57798 Mdot
.64806 .45577 Mdot
.47845 .54115 Mdot
.32118 .44259 Mdot
.36422 .38261 Mdot
.29629 .61658 Mdot
.87277 .39745 Mdot
.33248 .60934 Mdot
.50132 .54164 Mdot
.44099 .28722 Mdot
.52415 .70622 Mdot
.61927 .46794 Mdot
.49018 .35032 Mdot
.44796 .37989 Mdot
.54196 .65823 Mdot
.52063 .71329 Mdot
.31884 .52177 Mdot
.29373 .47729 Mdot
.50595 .57029 Mdot
.64493 .41919 Mdot
.62924 .4138 Mdot
.57882 .45235 Mdot
.28258 .46618 Mdot
.71207 .45224 Mdot
.3535 .43716 Mdot
.63573 .48385 Mdot
.57463 .78531 Mdot
.3391 .64319 Mdot
.20146 .63337 Mdot
.48059 .32471 Mdot
.68636 .35638 Mdot
.54474 .37531 Mdot
.68488 .60615 Mdot
.27568 .46568 Mdot
.55187 .59589 Mdot
.34633 .6243 Mdot
.2215 .44786 Mdot
.33814 .64442 Mdot
.84761 .58475 Mdot
.68018 .3034 Mdot
.34878 .41243 Mdot
.61292 .41524 Mdot
.31428 .63876 Mdot
.72492 .32679 Mdot
.50439 .5893 Mdot
.53564 .55036 Mdot
.6421 .48396 Mdot
.61581 .21728 Mdot
.52585 .72114 Mdot
.62345 .46732 Mdot
.48272 .33535 Mdot
.61561 .46864 Mdot
.6187 .46874 Mdot
.6342 .42461 Mdot
.32902 .44505 Mdot
.56789 .44507 Mdot
.609 .46454 Mdot
.28104 .72452 Mdot
.55562 .54634 Mdot
.37969 .63062 Mdot
.42887 .28242 Mdot
.51436 .68794 Mdot
.43298 .33772 Mdot
.63605 .65041 Mdot
.3132 .47965 Mdot
.60323 .25231 Mdot
.70492 .45792 Mdot
.49566 .3696 Mdot
.30385 .48901 Mdot
.52285 .72875 Mdot
.52549 .58171 Mdot
.30771 .26749 Mdot
.32796 .66268 Mdot
.53573 .58723 Mdot
.36904 .62961 Mdot
.567 .48245 Mdot
.45791 .34848 Mdot
.52622 .5931 Mdot
.31644 .44926 Mdot
.32804 .64552 Mdot
.69966 .58624 Mdot
.62585 .45197 Mdot
.34007 .63551 Mdot
.51247 .58089 Mdot
.64343 .62432 Mdot
.63837 .64334 Mdot
.31551 .64116 Mdot
.26868 .45489 Mdot
.31082 .4294 Mdot
.51859 .68002 Mdot
.44016 .28355 Mdot
.47203 .32105 Mdot
.29353 .43385 Mdot
.22134 .45736 Mdot
.61595 .43597 Mdot
.61988 .44773 Mdot
.6391 .66317 Mdot
.66428 .43214 Mdot
.40486 .58869 Mdot
.53307 .58833 Mdot
.47354 .33806 Mdot
.68625 .46025 Mdot
.68705 .45749 Mdot
.62823 .46541 Mdot
.65613 .72463 Mdot
.34938 .60491 Mdot
.72345 .45852 Mdot
.54017 .72006 Mdot
.61075 .21854 Mdot
.58767 .46378 Mdot
.49913 .72309 Mdot
.44178 .28524 Mdot
.26183 .39691 Mdot
.28519 .44812 Mdot
.32903 .65239 Mdot
.32728 .65109 Mdot
.49611 .79702 Mdot
.47833 .31822 Mdot
.53501 .58822 Mdot
.28528 .62256 Mdot
.53056 .60474 Mdot
.51845 .71046 Mdot
.62553 .39472 Mdot
.40582 .59235 Mdot
.37927 .63077 Mdot
.29116 .49921 Mdot
.67126 .44958 Mdot
.59036 .46399 Mdot
.36445 .36573 Mdot
.59256 .45392 Mdot
.53846 .70839 Mdot
.30556 .47739 Mdot
.46457 .33392 Mdot
.52338 .72332 Mdot
.30048 .48624 Mdot
.46794 .30582 Mdot
.72585 .45409 Mdot
.63792 .41653 Mdot
.44635 .31714 Mdot
.43472 .31789 Mdot
.61065 .43293 Mdot
.4726 .8412 Mdot
.47351 .35185 Mdot
.44363 .31806 Mdot
.61175 .21871 Mdot
.36539 .65027 Mdot
.55675 .59554 Mdot
.28952 .48841 Mdot
.61329 .46292 Mdot
.34473 .64078 Mdot
.51916 .69998 Mdot
.46987 .3374 Mdot
.63517 .46791 Mdot
.62077 .43841 Mdot
.51628 .68705 Mdot
.55248 .71292 Mdot
.53746 .683 Mdot
.28668 .42441 Mdot
.70846 .45969 Mdot
.44178 .30895 Mdot
.27464 .45191 Mdot
.52878 .67164 Mdot
.54861 .71908 Mdot
.60896 .78943 Mdot
.6137 .43429 Mdot
.55493 .70815 Mdot
.56946 .15898 Mdot
.70917 .61418 Mdot
.53865 .60072 Mdot
.37672 .61268 Mdot
.39691 .6226 Mdot
.5329 .53076 Mdot
.31166 .45272 Mdot
.72628 .4397 Mdot
.51183 .72647 Mdot
.50789 .58252 Mdot
.62218 .45017 Mdot
.61693 .47958 Mdot
.52539 .6803 Mdot
.63989 .73254 Mdot
.47813 .35182 Mdot
.46561 .24469 Mdot
.51358 .69021 Mdot
.31256 .64108 Mdot
.29573 .61289 Mdot
.3336 .61452 Mdot
.64543 .45911 Mdot
.75372 .39326 Mdot
.54641 .47254 Mdot
.62185 .35403 Mdot
.2974 .47717 Mdot
.43323 .29181 Mdot
.61039 .21184 Mdot
.45177 .31197 Mdot
.36321 .61768 Mdot
.54211 .69104 Mdot
.47375 .30736 Mdot
.30128 .42474 Mdot
.31609 .43292 Mdot
.35872 .65434 Mdot
.32777 .60786 Mdot
.33315 .62369 Mdot
.46566 .28491 Mdot
.43733 .29627 Mdot
.6214 .41495 Mdot
.4631 .36015 Mdot
.28987 .57982 Mdot
.29027 .57759 Mdot
.33827 .65893 Mdot
.30014 .45275 Mdot
.4636 .3096 Mdot
.58418 .44729 Mdot
.68356 .57757 Mdot
.28952 .6282 Mdot
.50983 .69045 Mdot
.61881 .19148 Mdot
.856 .45946 Mdot
.66388 .46837 Mdot
.29585 .47106 Mdot
.52969 .60176 Mdot
.6255 .45957 Mdot
.31275 .60729 Mdot
.49228 .56456 Mdot
.53732 .56344 Mdot
.5736 .44577 Mdot
.58618 .41915 Mdot
.28675 .46253 Mdot
.63337 .65196 Mdot
.50626 .58168 Mdot
.74124 .45064 Mdot
.29738 .48113 Mdot
.29731 .63778 Mdot
.29519 .69711 Mdot
.38358 .31069 Mdot
.58165 .66153 Mdot
.54679 .57478 Mdot
.58732 .47156 Mdot
.32169 .62916 Mdot
.52478 .72543 Mdot
.324 .62533 Mdot
.43655 .34437 Mdot
.36962 .64839 Mdot
.58699 .44578 Mdot
.44265 .30489 Mdot
.31602 .43159 Mdot
.60709 .63203 Mdot
.49384 .62455 Mdot
.3025 .63548 Mdot
.4993 .5727 Mdot
.70583 .44739 Mdot
.56196 .48526 Mdot
.52619 .62066 Mdot
.58676 .45737 Mdot
.30519 .44131 Mdot
.43961 .32515 Mdot
.28243 .43928 Mdot
.55091 .6051 Mdot
.52777 .37636 Mdot
.28461 .45026 Mdot
.75371 .40213 Mdot
.53406 .72894 Mdot
.64586 .72965 Mdot
.59444 .44037 Mdot
.31511 .44786 Mdot
.57199 .44192 Mdot
.46619 .29229 Mdot
.69166 .63314 Mdot
.68212 .62042 Mdot
.2997 .4342 Mdot
.50446 .60924 Mdot
.64448 .6289 Mdot
.55759 .5944 Mdot
.30858 .46884 Mdot
.71718 .60719 Mdot
.53561 .57932 Mdot
.53062 .68945 Mdot
.5487 .72071 Mdot
.53687 .69278 Mdot
.61563 .4525 Mdot
.75194 .33614 Mdot
.53539 .67206 Mdot
.23975 .42187 Mdot
.54175 .71186 Mdot
.53334 .5281 Mdot
.35856 .33964 Mdot
.54479 .72015 Mdot
.59253 .44784 Mdot
.64611 .4781 Mdot
.73051 .43961 Mdot
.30632 .60709 Mdot
.28741 .28648 Mdot
.2786 .72022 Mdot
.63143 .43593 Mdot
.61082 .20185 Mdot
.48881 .35619 Mdot
.4956 .57916 Mdot
.68311 .616 Mdot
.74339 .4393 Mdot
.45171 .30665 Mdot
.63731 .65342 Mdot
.47853 .2863 Mdot
.51426 .60306 Mdot
.61603 .44851 Mdot
.46785 .29098 Mdot
.50242 .35641 Mdot
.68006 .71249 Mdot
.38256 .37236 Mdot
.4664 .30938 Mdot
.31406 .46472 Mdot
.30932 .45608 Mdot
.30415 .43849 Mdot
.32088 .60847 Mdot
.46671 .34204 Mdot
.69423 .44039 Mdot
.31533 .6073 Mdot
.64011 .43278 Mdot
.29681 .43337 Mdot
.68624 .61316 Mdot
.46488 .33976 Mdot
.59728 .44035 Mdot
.72537 .33344 Mdot
.36411 .64 Mdot
.5185 .68442 Mdot
.61249 .19752 Mdot
.36721 .60645 Mdot
.27256 .47415 Mdot
.44191 .3551 Mdot
.55581 .54944 Mdot
.74171 .4485 Mdot
.65816 .45154 Mdot
.60692 .42255 Mdot
.74377 .44611 Mdot
.68215 .2999 Mdot
.5233 .56075 Mdot
.31514 .61086 Mdot
.37025 .64662 Mdot
.59016 .46969 Mdot
.46766 .34722 Mdot
.52267 .66452 Mdot
.50319 .72622 Mdot
.48266 .55659 Mdot
.64468 .63722 Mdot
.69356 .6007 Mdot
.67149 .434 Mdot
.70519 .38066 Mdot
.31513 .6009 Mdot
.53121 .60706 Mdot
.64783 .64221 Mdot
.53184 .6975 Mdot
.64453 .43152 Mdot
.42068 .30462 Mdot
.46804 .33366 Mdot
.34526 .63164 Mdot
.3204 .42519 Mdot
.52589 .55153 Mdot
.33935 .65923 Mdot
.59057 .46988 Mdot
.68713 .45834 Mdot
.31768 .46294 Mdot
.44244 .35314 Mdot
.52772 .68487 Mdot
.31959 .60413 Mdot
.5269 .7038 Mdot
.45217 .34538 Mdot
.47036 .33698 Mdot
.65392 .43397 Mdot
.4739 .57142 Mdot
.3026 .63854 Mdot
.6342 .46564 Mdot
.33431 .63485 Mdot
.34238 .55239 Mdot
.30633 .42041 Mdot
.66212 .43928 Mdot
.42901 .36588 Mdot
.2982 .43152 Mdot
.6362 .43647 Mdot
.734 .44263 Mdot
.68906 .4597 Mdot
.31273 .63814 Mdot
.50868 .73391 Mdot
.52842 .6936 Mdot
.55617 .37331 Mdot
.5974 .23765 Mdot
.67382 .4398 Mdot
.33329 .65712 Mdot
.63 .48987 Mdot
.28985 .46193 Mdot
.44732 .28757 Mdot
.16676 .57391 Mdot
.29381 .45353 Mdot
.59295 .43804 Mdot
.53521 .70485 Mdot
.43367 .31885 Mdot
.54788 .59056 Mdot
.63879 .69082 Mdot
.50977 .61798 Mdot
.47565 .565 Mdot
.51169 .56804 Mdot
.34996 .35703 Mdot
.33045 .62475 Mdot
.43928 .31286 Mdot
.29989 .47094 Mdot
.29321 .46518 Mdot
.36819 .62534 Mdot
.60154 .23116 Mdot
.41236 .22939 Mdot
.56549 .15233 Mdot
.30869 .65926 Mdot
.54198 .69946 Mdot
.69314 .6296 Mdot
.33554 .61437 Mdot
.37399 .62282 Mdot
.3298 .5332 Mdot
.36462 .36847 Mdot
.45832 .30193 Mdot
.62267 .43834 Mdot
.60565 .21137 Mdot
.62195 .42337 Mdot
.58192 .65623 Mdot
.29444 .43565 Mdot
.44775 .28748 Mdot
.35927 .48118 Mdot
.61309 .47624 Mdot
.64103 .45202 Mdot
.27959 .59313 Mdot
.52388 .58764 Mdot
.38883 .80192 Mdot
.63015 .42076 Mdot
.32032 .6148 Mdot
.4027 .34482 Mdot
.51021 .59917 Mdot
.72729 .33362 Mdot
.32189 .45207 Mdot
.54321 .58645 Mdot
.50875 .59896 Mdot
.71125 .38573 Mdot
.48839 .29513 Mdot
.47416 .31978 Mdot
.5538 .70136 Mdot
.369 .3268 Mdot
.32209 .45879 Mdot
.3357 .37569 Mdot
.58277 .45063 Mdot
.27336 .42984 Mdot
.52714 .75464 Mdot
.63428 .43419 Mdot
.72243 .4453 Mdot
.6035 .24999 Mdot
.65208 .46587 Mdot
.59165 .49054 Mdot
.29505 .44888 Mdot
.58133 .77731 Mdot
.67436 .42826 Mdot
.34162 .63398 Mdot
.45539 .29654 Mdot
.49157 .29491 Mdot
.51473 .7209 Mdot
.34832 .5141 Mdot
.86779 .42216 Mdot
.44834 .28804 Mdot
.62314 .45335 Mdot
.28972 .45941 Mdot
.54612 .58837 Mdot
.51318 .59544 Mdot
.49687 .60282 Mdot
.46673 .3273 Mdot
.50876 .59637 Mdot
.48503 .38855 Mdot
.63642 .65259 Mdot
.68546 .35457 Mdot
.3056 .43441 Mdot
.54044 .70183 Mdot
.50459 .53388 Mdot
.32884 .5469 Mdot
.65117 .42116 Mdot
.58175 .65779 Mdot
.48795 .3291 Mdot
.5396 .70545 Mdot
.62332 .46373 Mdot
.51377 .5638 Mdot
.73355 .55278 Mdot
.50507 .68511 Mdot
.51571 .56541 Mdot
.67196 .46965 Mdot
.46549 .29753 Mdot
.5352 .59058 Mdot
.46322 .3288 Mdot
.62447 .46469 Mdot
.57609 .60701 Mdot
.46003 .2884 Mdot
.27429 .3 Mdot
.51339 .55642 Mdot
.30692 .48416 Mdot
.5974 .48504 Mdot
.62092 .47137 Mdot
.75094 .3775 Mdot
.54204 .59317 Mdot
.22679 .34621 Mdot
.33515 .63945 Mdot
.37042 .80019 Mdot
.38738 .63906 Mdot
.32047 .52809 Mdot
.30484 .38596 Mdot
.63275 .47171 Mdot
.60232 .23171 Mdot
.75314 .38794 Mdot
.27075 .46022 Mdot
.75409 .38347 Mdot
.60608 .46338 Mdot
.65725 .44567 Mdot
.33548 .63529 Mdot
.30696 .41081 Mdot
.70122 .47016 Mdot
.64763 .64115 Mdot
.52129 .72928 Mdot
.45139 .32843 Mdot
.60928 .45843 Mdot
.50866 .36547 Mdot
.31607 .64439 Mdot
.49233 .26133 Mdot
.59477 .44541 Mdot
.52422 .58735 Mdot
.27828 .42673 Mdot
.31889 .434 Mdot
.30711 .6299 Mdot
.30517 .63009 Mdot
.61997 .47142 Mdot
.27821 .43993 Mdot
.65173 .41825 Mdot
.6442 .62775 Mdot
.51272 .57851 Mdot
.51549 .7041 Mdot
.58492 .43434 Mdot
.43178 .23257 Mdot
.68456 .76677 Mdot
.64599 .45842 Mdot
.48187 .33945 Mdot
.33689 .62548 Mdot
.3617 .61132 Mdot
.47151 .32076 Mdot
.36259 .6123 Mdot
.46566 .24367 Mdot
.75337 .33909 Mdot
.52108 .71064 Mdot
.59782 .49891 Mdot
.54739 .70554 Mdot
.54231 .58939 Mdot
.61226 .43398 Mdot
.19754 .46272 Mdot
.31084 .65936 Mdot
.66899 .53968 Mdot
.29048 .43929 Mdot
.51913 .61013 Mdot
.71069 .45439 Mdot
.56259 .70037 Mdot
.34471 .61004 Mdot
.54098 .55364 Mdot
.63987 .42686 Mdot
.46492 .28629 Mdot
.66372 .47366 Mdot
.50938 .60475 Mdot
.53565 .59624 Mdot
.54379 .55781 Mdot
.3004 .4863 Mdot
.4431 .33862 Mdot
.31916 .52199 Mdot
.35854 .64553 Mdot
.59882 .41745 Mdot
.62411 .45499 Mdot
.43528 .28937 Mdot
.60082 .42747 Mdot
.27888 .43546 Mdot
.52332 .13273 Mdot
.54175 .68643 Mdot
.54406 .59384 Mdot
.30356 .30669 Mdot
.5476 .55978 Mdot
.67999 .46929 Mdot
.74626 .43319 Mdot
.42361 .28656 Mdot
.29869 .48862 Mdot
.62598 .40826 Mdot
.38146 .63443 Mdot
.52788 .68675 Mdot
.3022 .42396 Mdot
.70272 .45101 Mdot
.58927 .44707 Mdot
.53898 .70355 Mdot
.3614 .47038 Mdot
.5183 .73476 Mdot
.3012 .47257 Mdot
.52458 .61405 Mdot
.68836 .57324 Mdot
.60836 .44163 Mdot
.53027 .58705 Mdot
.4455 .33494 Mdot
.2911 .47469 Mdot
.607 .26534 Mdot
.51169 .60223 Mdot
.29261 .53601 Mdot
.32178 .43901 Mdot
.66085 .449 Mdot
.47706 .30362 Mdot
.50086 .29829 Mdot
.44132 .32695 Mdot
.52586 .80234 Mdot
.29586 .55139 Mdot
.33356 .62725 Mdot
.29899 .45403 Mdot
.34994 .63875 Mdot
.53555 .72883 Mdot
.68041 .64763 Mdot
.30376 .6328 Mdot
.47241 .36891 Mdot
.34309 .64444 Mdot
.64755 .41711 Mdot
.30838 .48466 Mdot
.30565 .64424 Mdot
.58064 .44268 Mdot
.72816 .45347 Mdot
.52983 .59718 Mdot
.52216 .66642 Mdot
.64081 .64571 Mdot
.60229 .43156 Mdot
.52968 .58206 Mdot
.60044 .43999 Mdot
.27909 .43568 Mdot
.60146 .63121 Mdot
.58918 .41987 Mdot
.30776 .65869 Mdot
.3269 .25024 Mdot
.35905 .65207 Mdot
.45042 .57312 Mdot
.63605 .43165 Mdot
.60947 .43899 Mdot
.71119 .44997 Mdot
.62914 .20681 Mdot
.26684 .45185 Mdot
.56584 .45042 Mdot
.35134 .60014 Mdot
.45609 .30941 Mdot
.47712 .31681 Mdot
.68937 .41358 Mdot
.53325 .58628 Mdot
.28515 .42673 Mdot
.61215 .43751 Mdot
.52022 .60754 Mdot
.66115 .65606 Mdot
.36558 .33878 Mdot
.3006 .56736 Mdot
.37209 .63178 Mdot
.44792 .27818 Mdot
.34689 .60201 Mdot
.70588 .45187 Mdot
.51268 .59951 Mdot
.29367 .5494 Mdot
.26082 .48975 Mdot
.52702 .68777 Mdot
.65056 .44127 Mdot
.66301 .72193 Mdot
.33743 .59806 Mdot
.30721 .61536 Mdot
.64912 .41721 Mdot
.39118 .3511 Mdot
.65719 .77704 Mdot
.28049 .46873 Mdot
.53963 .34283 Mdot
.67391 .27021 Mdot
.80413 .5903 Mdot
.30276 .46147 Mdot
.72018 .44431 Mdot
.31111 .59938 Mdot
.44619 .79547 Mdot
.45288 .30885 Mdot
.52654 .68618 Mdot
.58144 .44027 Mdot
.47477 .36571 Mdot
.3082 .66002 Mdot
.44385 .34688 Mdot
.52002 .59068 Mdot
.30586 .48761 Mdot
.34272 .60545 Mdot
.32332 .42653 Mdot
.4242 .35853 Mdot
.54336 .69493 Mdot
.60232 .7194 Mdot
.616 .49069 Mdot
.60271 .24741 Mdot
.71201 .45848 Mdot
.55502 .54386 Mdot
.71936 .45785 Mdot
.49544 .29884 Mdot
.59358 .44141 Mdot
.66216 .41834 Mdot
.3229 .59283 Mdot
.65304 .45395 Mdot
.58231 .44707 Mdot
.72811 .33619 Mdot
.6447 .43945 Mdot
.62353 .46806 Mdot
.65954 .4518 Mdot
.48105 .34673 Mdot
.64762 .42883 Mdot
.43562 .31164 Mdot
.49766 .37235 Mdot
.35997 .64422 Mdot
.54272 .72367 Mdot
.54625 .71877 Mdot
.58106 .61285 Mdot
.66126 .72247 Mdot
.60713 .21218 Mdot
.45863 .31636 Mdot
.3207 .44019 Mdot
.62643 .41441 Mdot
.62018 .78964 Mdot
.57664 .60786 Mdot
.30237 .61036 Mdot
.31743 .64783 Mdot
.57723 .4516 Mdot
.85306 .46802 Mdot
.62754 .41958 Mdot
.64741 .66626 Mdot
.61444 .45324 Mdot
.66324 .43832 Mdot
.38549 .63394 Mdot
.62265 .72842 Mdot
.72491 .45846 Mdot
.48879 .30216 Mdot
.52363 .68942 Mdot
.5323 .59134 Mdot
.57769 .61143 Mdot
.69969 .28304 Mdot
.40529 .27206 Mdot
.71119 .44955 Mdot
.3201 .60242 Mdot
.47199 .33569 Mdot
.6403 .66165 Mdot
.27513 .45476 Mdot
.64123 .6926 Mdot
.5508 .35426 Mdot
.27955 .46953 Mdot
.53034 .68843 Mdot
.29111 .62978 Mdot
.63881 .4587 Mdot
.31827 .62846 Mdot
.61693 .47555 Mdot
.65802 .66806 Mdot
.51797 .70751 Mdot
.48264 .36976 Mdot
.31432 .46632 Mdot
.47972 .35498 Mdot
.49833 .26887 Mdot
.57505 .61717 Mdot
.32358 .76772 Mdot
.34459 .65771 Mdot
.46607 .55414 Mdot
.44077 .29473 Mdot
.59245 .4734 Mdot
.56101 .1538 Mdot
.45537 .34255 Mdot
.46561 .28812 Mdot
.62306 .68068 Mdot
.62551 .73828 Mdot
.64997 .45934 Mdot
.46785 .36454 Mdot
.29083 .6336 Mdot
.52461 .71548 Mdot
.58146 .4547 Mdot
.51903 .60176 Mdot
.47373 .30546 Mdot
.35577 .61315 Mdot
.61678 .72516 Mdot
.32319 .61058 Mdot
.45363 .30136 Mdot
.33073 .65402 Mdot
.32591 .5098 Mdot
.30373 .63364 Mdot
.59041 .43034 Mdot
.61139 .43836 Mdot
.50888 .30539 Mdot
.4704 .33731 Mdot
.68036 .46929 Mdot
.61472 .42491 Mdot
.44016 .30522 Mdot
.28644 .63541 Mdot
.42 .26651 Mdot
.68366 .46274 Mdot
.61887 .43672 Mdot
.5481 .69285 Mdot
.62645 .61826 Mdot
.61721 .65286 Mdot
.6267 .41518 Mdot
.54138 .69591 Mdot
.46091 .28264 Mdot
.60615 .4348 Mdot
.62112 .73381 Mdot
.31008 .5948 Mdot
.67989 .43426 Mdot
.54804 .58521 Mdot
.7038 .46553 Mdot
.71596 .67929 Mdot
.70843 .44881 Mdot
.44667 .30934 Mdot
.44806 .2979 Mdot
.29961 .60149 Mdot
.44714 .31998 Mdot
.54364 .59321 Mdot
.30222 .42865 Mdot
.55031 .33514 Mdot
.52592 .60925 Mdot
.53455 .55859 Mdot
.51885 .55568 Mdot
.50078 .58318 Mdot
.50212 .73759 Mdot
.30432 .56207 Mdot
.54229 .56949 Mdot
.43726 .3137 Mdot
.5231 .45696 Mdot
.54945 .60111 Mdot
.28219 .42796 Mdot
.50806 .5975 Mdot
.6798 .43474 Mdot
.71569 .44773 Mdot
.4263 .29958 Mdot
.27399 .45241 Mdot
.52947 .62291 Mdot
.58105 .45394 Mdot
.42261 .29279 Mdot
.60784 .45976 Mdot
.50507 .70727 Mdot
.46362 .33713 Mdot
.32373 .60479 Mdot
.51509 .70697 Mdot
.50725 .57558 Mdot
.51989 .6814 Mdot
.32475 .63199 Mdot
.3163 .44151 Mdot
.58802 .43465 Mdot
.50336 .71606 Mdot
.54013 .72419 Mdot
.62478 .48017 Mdot
.44955 .29471 Mdot
.49867 .61342 Mdot
.61396 .43155 Mdot
.71553 .45206 Mdot
.47243 .32145 Mdot
.21333 .35046 Mdot
.64504 .45414 Mdot
.74051 .45169 Mdot
.49515 .30822 Mdot
.515 .60822 Mdot
.31922 .60664 Mdot
.63158 .46946 Mdot
.28364 .4424 Mdot
.29329 .43339 Mdot
.31282 .6589 Mdot
.47384 .31404 Mdot
.35519 .60918 Mdot
.59562 .47857 Mdot
.50585 .59423 Mdot
.5908 .46176 Mdot
.26502 .63261 Mdot
.24738 .32062 Mdot
.43491 .32471 Mdot
.36131 .64505 Mdot
.66967 .64751 Mdot
.29134 .49071 Mdot
.28892 .65619 Mdot
.49085 .30266 Mdot
.47201 .36267 Mdot
.47002 .31596 Mdot
.5426 .71937 Mdot
.33117 .60796 Mdot
.43249 .28548 Mdot
.43128 .28902 Mdot
.69528 .45602 Mdot
.57895 .44786 Mdot
.45517 .28043 Mdot
.32507 .54486 Mdot
.52717 .69263 Mdot
.36076 .60542 Mdot
.66396 .77566 Mdot
.28588 .47325 Mdot
.72896 .3347 Mdot
.64797 .41928 Mdot
.8729 .39214 Mdot
.62657 .41985 Mdot
.61719 .45614 Mdot
.43345 .33989 Mdot
.54118 .73017 Mdot
.5293 .71455 Mdot
.44181 .29482 Mdot
.43627 .33587 Mdot
.50854 .71361 Mdot
.6393 .5985 Mdot
.7008 .69799 Mdot
.65515 .65268 Mdot
.44646 .3484 Mdot
.54273 .36319 Mdot
.30139 .44211 Mdot
.48809 .35303 Mdot
.35277 .46625 Mdot
.32001 .65481 Mdot
.30379 .63648 Mdot
.31923 .45663 Mdot
.63842 .45773 Mdot
.38466 .63602 Mdot
.71417 .4619 Mdot
.35252 .41379 Mdot
.71301 .44439 Mdot
.48733 .84742 Mdot
.59498 .42932 Mdot
.44086 .55107 Mdot
.35487 .34907 Mdot
.68667 .46956 Mdot
.73512 .31291 Mdot
.52798 .68238 Mdot
.49093 .29216 Mdot
.2743 .43988 Mdot
.60473 .21051 Mdot
.60885 .44044 Mdot
.46444 .36492 Mdot
.30705 .47423 Mdot
.23344 .33746 Mdot
.73784 .44878 Mdot
.69258 .46119 Mdot
.55327 .15003 Mdot
.47653 .37373 Mdot
.32027 .6074 Mdot
.53474 .3274 Mdot
.43177 .31664 Mdot
.73391 .44578 Mdot
.29046 .64465 Mdot
.73084 .55051 Mdot
.45769 .36301 Mdot
.5197 .73555 Mdot
.45483 .32813 Mdot
.50926 .70772 Mdot
.43317 .28411 Mdot
.35778 .64383 Mdot
.64997 .44649 Mdot
.36106 .64223 Mdot
.51691 .67718 Mdot
.35257 .65343 Mdot
.27282 .44547 Mdot
.52381 .57109 Mdot
.29897 .43211 Mdot
.68524 .64104 Mdot
.61407 .27843 Mdot
.31235 .44664 Mdot
.71743 .41876 Mdot
.58786 .44774 Mdot
.43433 .28356 Mdot
.32863 .60268 Mdot
.34481 .59321 Mdot
.64155 .64312 Mdot
.46197 .30045 Mdot
.36297 .61994 Mdot
.57712 .49029 Mdot
.21259 .43097 Mdot
.73227 .45661 Mdot
.17445 .5949 Mdot
.44179 .3115 Mdot
.34413 .5938 Mdot
.64367 .66447 Mdot
.45894 .37109 Mdot
.30349 .64074 Mdot
.3128 .46243 Mdot
.2839 .44247 Mdot
.59974 .42479 Mdot
.32022 .41788 Mdot
.30536 .60816 Mdot
.52927 .37682 Mdot
.45132 .28441 Mdot
.25547 .31221 Mdot
.54072 .68861 Mdot
.34524 .60242 Mdot
.50991 .58349 Mdot
.42873 .36511 Mdot
.34852 .64135 Mdot
.86579 .42913 Mdot
.63583 .82014 Mdot
.3604 .61729 Mdot
.46316 .33439 Mdot
.46766 .32482 Mdot
.66816 .46666 Mdot
.64537 .63976 Mdot
.34644 .61119 Mdot
.19536 .4628 Mdot
.69743 .59792 Mdot
.52684 .57186 Mdot
.27988 .72262 Mdot
.69786 .44262 Mdot
.711 .45667 Mdot
.2893 .47222 Mdot
.64154 .45074 Mdot
.43852 .34038 Mdot
.62816 .41997 Mdot
.28752 .43008 Mdot
.31705 .65897 Mdot
.60566 .43918 Mdot
.52927 .68692 Mdot
.28417 .4622 Mdot
.27929 .44798 Mdot
.33494 .65227 Mdot
.47304 .31148 Mdot
.60138 .20847 Mdot
.32674 .60765 Mdot
.70787 .46122 Mdot
.52648 .57957 Mdot
.65879 .45182 Mdot
.49119 .36229 Mdot
.47826 .28273 Mdot
.34037 .60008 Mdot
.60786 .48173 Mdot
.29765 .45967 Mdot
.31953 .59359 Mdot
.70843 .4473 Mdot
.29717 .63336 Mdot
.48766 .58014 Mdot
.39454 .62186 Mdot
.41893 .35334 Mdot
.49684 .57579 Mdot
.46938 .36708 Mdot
.53912 .5685 Mdot
.49847 .79895 Mdot
.52988 .69008 Mdot
.37506 .64399 Mdot
.26787 .30596 Mdot
.36448 .64101 Mdot
.64256 .43871 Mdot
.58887 .44145 Mdot
.32967 .63754 Mdot
.54382 .69692 Mdot
.52642 .53027 Mdot
.50603 .72623 Mdot
.46656 .33689 Mdot
.73834 .43837 Mdot
.59366 .8305 Mdot
.32739 .58819 Mdot
.32084 .45968 Mdot
.38592 .30171 Mdot
.53228 .55848 Mdot
.27265 .4492 Mdot
.27946 .45409 Mdot
.52097 .67646 Mdot
.3742 .62503 Mdot
.4839 .33447 Mdot
.32348 .45853 Mdot
.44878 .36182 Mdot
.61602 .73325 Mdot
.50262 .59282 Mdot
.4941 .52936 Mdot
.51227 .56466 Mdot
.63884 .65065 Mdot
.31391 .48123 Mdot
.60029 .45336 Mdot
.47799 .57711 Mdot
.307 .47151 Mdot
.53274 .67043 Mdot
.71462 .44529 Mdot
.36366 .6227 Mdot
.57991 .17182 Mdot
.59053 .42935 Mdot
.62821 .43064 Mdot
.29599 .47762 Mdot
.72204 .29539 Mdot
.48731 .29499 Mdot
.46531 .29616 Mdot
.33083 .62423 Mdot
.6217 .67571 Mdot
.64011 .42548 Mdot
.58587 .44218 Mdot
.32662 .6399 Mdot
.53604 .583 Mdot
.30055 .74856 Mdot
.61931 .43936 Mdot
.29866 .4484 Mdot
.71911 .44518 Mdot
.26941 .45789 Mdot
.62182 .40908 Mdot
.64177 .44094 Mdot
.69836 .46305 Mdot
.72279 .45458 Mdot
.3004 .43307 Mdot
.51068 .56819 Mdot
.54882 .56727 Mdot
.44233 .33237 Mdot
.57612 .45748 Mdot
.69732 .596 Mdot
.61411 .44083 Mdot
.52957 .68297 Mdot
.61849 .65692 Mdot
.62496 .41221 Mdot
.57259 .44823 Mdot
.69865 .60033 Mdot
.61683 .46589 Mdot
.29593 .47861 Mdot
.46624 .31791 Mdot
.29625 .46111 Mdot
.31719 .46962 Mdot
.34485 .64514 Mdot
.53892 .67333 Mdot
.62838 .46944 Mdot
.5202 .72601 Mdot
.67303 .45979 Mdot
.54466 .61309 Mdot
.64451 .62448 Mdot
.64883 .6654 Mdot
.51091 .67502 Mdot
.58607 .44746 Mdot
.32794 .62927 Mdot
.37419 .61765 Mdot
.72573 .43983 Mdot
.59246 .48155 Mdot
.31411 .41596 Mdot
.31497 .44864 Mdot
.29094 .57649 Mdot
.33451 .69324 Mdot
.50499 .71587 Mdot
.49708 .54903 Mdot
.72543 .45449 Mdot
.64793 .43683 Mdot
.52118 .56494 Mdot
.34878 .63473 Mdot
.54052 .56785 Mdot
.30329 .56514 Mdot
.27049 .44927 Mdot
.2961 .46812 Mdot
.59221 .43017 Mdot
.86942 .51012 Mdot
.45666 .3494 Mdot
.46807 .32434 Mdot
.29368 .42595 Mdot
.36026 .65159 Mdot
.5187 .59348 Mdot
.60474 .18323 Mdot
.47144 .27891 Mdot
.53939 .72804 Mdot
.59992 .46914 Mdot
.32405 .65612 Mdot
.43856 .32761 Mdot
.50594 .72146 Mdot
.56758 .43983 Mdot
.28952 .64681 Mdot
.60599 .45103 Mdot
.56592 .4975 Mdot
.4391 .29132 Mdot
.6359 .62005 Mdot
.47532 .36938 Mdot
.29657 .43584 Mdot
.3173 .47357 Mdot
.63772 .43728 Mdot
.59853 .18367 Mdot
.39711 .34415 Mdot
.32538 .45559 Mdot
.55317 .70323 Mdot
.51898 .57248 Mdot
.53644 .67224 Mdot
.33724 .63306 Mdot
.52951 .68894 Mdot
.34828 .64227 Mdot
.28735 .61959 Mdot
.48176 .32962 Mdot
.53871 .70392 Mdot
.70399 .31322 Mdot
.5137 .59953 Mdot
.55497 .71054 Mdot
.58129 .42807 Mdot
.67787 .46456 Mdot
.35201 .61645 Mdot
.52387 .72803 Mdot
.63862 .46619 Mdot
.29779 .31073 Mdot
.31072 .4805 Mdot
.273 .44386 Mdot
.52019 .59163 Mdot
.31639 .59903 Mdot
.48145 .32625 Mdot
.67194 .64668 Mdot
.45431 .38346 Mdot
.58522 .44154 Mdot
.63017 .46807 Mdot
.43829 .37427 Mdot
.48058 .32361 Mdot
.63919 .44097 Mdot
.68274 .3471 Mdot
.50887 .58165 Mdot
.28618 .437 Mdot
.4667 .34078 Mdot
.47082 .34666 Mdot
.30375 .61501 Mdot
.47147 .30005 Mdot
.4772 .55615 Mdot
.27094 .44945 Mdot
.55132 .57107 Mdot
.29723 .45626 Mdot
.56669 .58936 Mdot
.35974 .62577 Mdot
.25109 .32387 Mdot
.46624 .29534 Mdot
.68641 .4621 Mdot
.46791 .29385 Mdot
.53731 .68226 Mdot
.46225 .3621 Mdot
.48917 .35694 Mdot
.5817 .44219 Mdot
.51171 .56854 Mdot
.53996 .59081 Mdot
.64346 .64659 Mdot
.45512 .34568 Mdot
.63781 .46208 Mdot
.64718 .42493 Mdot
.61051 .42575 Mdot
.64672 .62875 Mdot
.47975 .33846 Mdot
.70151 .28423 Mdot
.43338 .28106 Mdot
.43758 .29527 Mdot
.70304 .75737 Mdot
.53819 .59762 Mdot
.53449 .56275 Mdot
.28864 .394 Mdot
.62176 .43775 Mdot
.36433 .61552 Mdot
.70613 .46016 Mdot
.51206 .57228 Mdot
.57742 .42847 Mdot
.52434 .721 Mdot
.60807 .47613 Mdot
.53229 .57428 Mdot
.33087 .60398 Mdot
.6896 .4602 Mdot
.6144 .43515 Mdot
.5369 .58723 Mdot
.46935 .29203 Mdot
.4772 .3502 Mdot
.42126 .37282 Mdot
.50877 .69797 Mdot
.30786 .44597 Mdot
.70655 .45835 Mdot
.32992 .62639 Mdot
.36776 .61897 Mdot
.47398 .3683 Mdot
.31134 .63162 Mdot
.29544 .46971 Mdot
.62373 .45154 Mdot
.29812 .43409 Mdot
.51813 .71894 Mdot
.46374 .33894 Mdot
.70922 .4521 Mdot
.66391 .47535 Mdot
.44795 .29785 Mdot
.50693 .58431 Mdot
.54779 .68897 Mdot
.32018 .64201 Mdot
.43421 .31012 Mdot
.29725 .42988 Mdot
.30259 .62286 Mdot
.68822 .46301 Mdot
.78501 .68341 Mdot
.64205 .44996 Mdot
.62491 .42303 Mdot
.40598 .33984 Mdot
.65754 .41551 Mdot
.35774 .64619 Mdot
.47679 .30984 Mdot
.681 .46384 Mdot
.70522 .61883 Mdot
.52837 .66124 Mdot
.36841 .60099 Mdot
.61505 .46307 Mdot
.75099 .37844 Mdot
.67292 .43975 Mdot
.28102 .2941 Mdot
.64316 .6247 Mdot
.2952 .53931 Mdot
.48071 .53914 Mdot
.32624 .4463 Mdot
.53123 .58124 Mdot
.34693 .64631 Mdot
.67541 .33387 Mdot
.63883 .44604 Mdot
.60188 .25618 Mdot
.70335 .45016 Mdot
.30061 .46426 Mdot
.71902 .30155 Mdot
.31744 .60322 Mdot
.3609 .79419 Mdot
.5819 .4671 Mdot
.4826 .28894 Mdot
.35918 .55263 Mdot
.52361 .56617 Mdot
.52724 .56038 Mdot
.50515 .71208 Mdot
.2949 .6628 Mdot
.51521 .62083 Mdot
.29612 .45888 Mdot
.64845 .43491 Mdot
.59049 .48774 Mdot
.22085 .35135 Mdot
.43942 .31846 Mdot
.31348 .47134 Mdot
.38568 .60685 Mdot
.59562 .45433 Mdot
.47347 .36096 Mdot
.45282 .30931 Mdot
.52809 .72467 Mdot
.29862 .53367 Mdot
.29214 .663 Mdot
.8496 .48701 Mdot
.51487 .62746 Mdot
.34606 .63649 Mdot
.49808 .57681 Mdot
.7043 .4616 Mdot
.57631 .6079 Mdot
.32113 .46187 Mdot
.6387 .43369 Mdot
.60077 .2437 Mdot
.44299 .31932 Mdot
.61417 .44658 Mdot
.52407 .69491 Mdot
.6163 .18751 Mdot
.6015 .49146 Mdot
.68762 .35349 Mdot
.29075 .63419 Mdot
.63277 .46666 Mdot
.47629 .56 Mdot
.5211 .60779 Mdot
.65673 .41491 Mdot
.32248 .60644 Mdot
.49819 .57313 Mdot
.52481 .70112 Mdot
.44191 .33699 Mdot
.52974 .58306 Mdot
.70313 .44978 Mdot
.62149 .47369 Mdot
.55269 .69939 Mdot
.69729 .46122 Mdot
.54042 .31457 Mdot
.49799 .59913 Mdot
.30783 .63922 Mdot
.43321 .31291 Mdot
.64336 .46001 Mdot
.51798 .57212 Mdot
.59191 .46126 Mdot
.43332 .23272 Mdot
.64176 .43432 Mdot
.26381 .33101 Mdot
.45629 .29673 Mdot
.28666 .44793 Mdot
.71352 .44943 Mdot
.60588 .44793 Mdot
.49541 .58154 Mdot
.51928 .59576 Mdot
.58559 .46652 Mdot
.47121 .3678 Mdot
.44785 .34437 Mdot
.47913 .28692 Mdot
.29952 .62237 Mdot
.65532 .64705 Mdot
.29182 .44169 Mdot
.52259 .56426 Mdot
.3235 .45797 Mdot
.75465 .39555 Mdot
.51169 .69303 Mdot
.23278 .34721 Mdot
.62894 .44873 Mdot
.46493 .3047 Mdot
.69511 .70131 Mdot
.47765 .36421 Mdot
.3075 .39686 Mdot
.32199 .4589 Mdot
.45804 .34118 Mdot
.61967 .46219 Mdot
.63707 .65568 Mdot
.75282 .37568 Mdot
.29784 .4896 Mdot
.55062 .57478 Mdot
.55072 .63906 Mdot
.29854 .64242 Mdot
.6935 .76372 Mdot
.31501 .42888 Mdot
.35489 .34621 Mdot
.68346 .46292 Mdot
.45922 .29064 Mdot
.30645 .43565 Mdot
.27804 .44713 Mdot
.31866 .60104 Mdot
.69409 .45692 Mdot
.6082 .44757 Mdot
.54768 .5843 Mdot
.31699 .43697 Mdot
.61185 .47953 Mdot
.68837 .47028 Mdot
.2628 .64421 Mdot
.48673 .29084 Mdot
.21243 .34922 Mdot
.74923 .42685 Mdot
.60212 .2437 Mdot
.21319 .46457 Mdot
.43942 .28298 Mdot
.62643 .46645 Mdot
.51362 .58463 Mdot
.31391 .63929 Mdot
.62826 .4541 Mdot
.36393 .64312 Mdot
.30576 .45807 Mdot
.28087 .32235 Mdot
.7474 .42988 Mdot
.35122 .40957 Mdot
.64763 .44688 Mdot
.63513 .48511 Mdot
.53127 .70258 Mdot
.27442 .43747 Mdot
.48406 .30081 Mdot
.65338 .4552 Mdot
.31033 .61243 Mdot
.30198 .64376 Mdot
.44353 .32375 Mdot
.38643 .37912 Mdot
.25776 .31586 Mdot
.50905 .58892 Mdot
.31271 .62455 Mdot
.51536 .5738 Mdot
.68812 .35662 Mdot
.32436 .45612 Mdot
.52486 .70266 Mdot
.32649 .65235 Mdot
.28791 .42422 Mdot
.67734 .46511 Mdot
.44976 .33311 Mdot
.44824 .37983 Mdot
.73894 .44447 Mdot
.36334 .61947 Mdot
.5128 .69852 Mdot
.69401 .42926 Mdot
.73832 .43959 Mdot
.5161 .70278 Mdot
.30195 .61344 Mdot
.46628 .35559 Mdot
.45152 .30336 Mdot
.46466 .31445 Mdot
.72744 .33341 Mdot
.47618 .28091 Mdot
.59327 .70994 Mdot
.66682 .41989 Mdot
.54016 .37485 Mdot
.67149 .44783 Mdot
.27392 .44169 Mdot
.44351 .28822 Mdot
.64281 .62388 Mdot
.72802 .45783 Mdot
.75634 .37653 Mdot
.61051 .42809 Mdot
.73009 .44794 Mdot
.62136 .43715 Mdot
.53101 .37905 Mdot
.48321 .28349 Mdot
.57271 .45618 Mdot
.27721 .47322 Mdot
.52566 .67929 Mdot
.43623 .34248 Mdot
.61627 .47069 Mdot
.50857 .38136 Mdot
.5842 .42552 Mdot
.27719 .32308 Mdot
.7306 .44389 Mdot
.40251 .5849 Mdot
.65739 .43839 Mdot
.35828 .65481 Mdot
.65445 .47749 Mdot
.55136 .34225 Mdot
.30755 .48492 Mdot
.60275 .49186 Mdot
.37994 .64314 Mdot
.71714 .30041 Mdot
.51112 .59314 Mdot
.52848 .6954 Mdot
.50906 .56174 Mdot
.29231 .43046 Mdot
.63342 .44726 Mdot
.6073 .47461 Mdot
.63126 .40678 Mdot
.6883 .35769 Mdot
.5294 .60154 Mdot
.50842 .67908 Mdot
.54669 .35908 Mdot
.59155 .46892 Mdot
.39068 .62619 Mdot
.4756 .3315 Mdot
.70684 .30647 Mdot
.69114 .30136 Mdot
.68409 .47195 Mdot
.45438 .34095 Mdot
.47375 .31346 Mdot
.63719 .78548 Mdot
.53661 .6964 Mdot
.63024 .42939 Mdot
.51893 .74869 Mdot
.7064 .45634 Mdot
.30391 .45128 Mdot
.65303 .41514 Mdot
.36042 .62472 Mdot
.63696 .66357 Mdot
.29962 .61793 Mdot
.60752 .42665 Mdot
.45571 .32676 Mdot
.29246 .48774 Mdot
.28805 .61501 Mdot
.30059 .53217 Mdot
.59499 .71641 Mdot
.28998 .66008 Mdot
.50681 .71943 Mdot
.52498 .67525 Mdot
.27434 .43805 Mdot
.61833 .4586 Mdot
.64632 .63214 Mdot
.76416 .4223 Mdot
.62559 .44033 Mdot
.63618 .45775 Mdot
.24662 .41559 Mdot
.3219 .44624 Mdot
.33253 .65508 Mdot
.63876 .44207 Mdot
.60865 .47701 Mdot
.45796 .33305 Mdot
.5204 .72986 Mdot
.33189 .64573 Mdot
.50619 .70044 Mdot
.32028 .62059 Mdot
.71661 .67939 Mdot
.50372 .59346 Mdot
.51559 .68462 Mdot
.31663 .42871 Mdot
.46842 .31504 Mdot
.53977 .5969 Mdot
.34227 .62558 Mdot
.31107 .62639 Mdot
.66797 .46244 Mdot
.43953 .32992 Mdot
.46512 .29566 Mdot
.50699 .7089 Mdot
.31402 .44652 Mdot
.71791 .46094 Mdot
.5147 .5635 Mdot
.33213 .58277 Mdot
.30755 .62071 Mdot
.54418 .36329 Mdot
.41295 .34625 Mdot
.5949 .46069 Mdot
.47643 .35187 Mdot
.60128 .44332 Mdot
.48434 .37988 Mdot
.47496 .37494 Mdot
.61854 .41007 Mdot
.60546 .3626 Mdot
.34969 .63597 Mdot
.5551 .83826 Mdot
.73371 .45607 Mdot
.26467 .46122 Mdot
.70416 .45998 Mdot
.32273 .76822 Mdot
.6913 .70441 Mdot
.58614 .46184 Mdot
.62461 .46942 Mdot
.85937 .53757 Mdot
.66553 .43288 Mdot
.53816 .56999 Mdot
.51136 .59463 Mdot
.47491 .35594 Mdot
.51617 .55801 Mdot
.64052 .64764 Mdot
.54269 .70461 Mdot
.33163 .62491 Mdot
.62475 .73362 Mdot
.50911 .70405 Mdot
.44462 .31136 Mdot
.71603 .46223 Mdot
.40721 .34993 Mdot
.38515 .62966 Mdot
.52975 .58899 Mdot
.30364 .46079 Mdot
.64153 .63763 Mdot
.31231 .60725 Mdot
.30613 .42822 Mdot
.65619 .42759 Mdot
.30149 .56976 Mdot
.27293 .46575 Mdot
.56873 .83148 Mdot
.27939 .46336 Mdot
.30049 .42768 Mdot
.65021 .64097 Mdot
.54283 .70493 Mdot
.49334 .59129 Mdot
.55582 .59801 Mdot
.29498 .48484 Mdot
.41028 .81336 Mdot
.31866 .59901 Mdot
.66165 .66651 Mdot
.49001 .29029 Mdot
.51083 .60045 Mdot
.64653 .45093 Mdot
.28855 .47276 Mdot
.59385 .48323 Mdot
.49582 .5788 Mdot
.28729 .46264 Mdot
.65557 .47717 Mdot
.62211 .67331 Mdot
.51728 .57612 Mdot
.54179 .58973 Mdot
.51493 .73024 Mdot
.40543 .60403 Mdot
.46915 .30441 Mdot
.54531 .72234 Mdot
.68286 .62348 Mdot
.6196 .42538 Mdot
.30128 .43352 Mdot
.52963 .58399 Mdot
.28913 .43994 Mdot
.5299 .70983 Mdot
.55335 .69817 Mdot
.44132 .32981 Mdot
.48133 .28899 Mdot
.53432 .60713 Mdot
.70285 .59053 Mdot
.67451 .42993 Mdot
.6053 .26738 Mdot
.48195 .33846 Mdot
.74183 .32211 Mdot
.54451 .71319 Mdot
.52474 .72976 Mdot
.64489 .48033 Mdot
.62005 .4151 Mdot
.7273 .44738 Mdot
.61801 .41278 Mdot
.39238 .796 Mdot
.70828 .45118 Mdot
.31825 .63931 Mdot
.58885 .41971 Mdot
.36818 .32125 Mdot
.66179 .46846 Mdot
.60743 .4705 Mdot
.33127 .61279 Mdot
.66404 .45846 Mdot
.35634 .61902 Mdot
.65162 .45093 Mdot
.2644 .67473 Mdot
.32979 .62593 Mdot
.53226 .53673 Mdot
.6166 .39607 Mdot
.54079 .57551 Mdot
.53577 .71859 Mdot
.50318 .70931 Mdot
.61436 .72454 Mdot
.46308 .35265 Mdot
.63484 .21309 Mdot
.60506 .46931 Mdot
.314 .60198 Mdot
.30759 .45775 Mdot
.66786 .47381 Mdot
.61637 .42216 Mdot
.72946 .45353 Mdot
.45012 .34091 Mdot
.31123 .60052 Mdot
.53549 .71176 Mdot
.3748 .63103 Mdot
.26368 .67644 Mdot
.35774 .62745 Mdot
.70914 .38311 Mdot
.67503 .46444 Mdot
.47694 .55826 Mdot
.62756 .30203 Mdot
.56055 .71494 Mdot
.44593 .32908 Mdot
.52959 .57937 Mdot
.52993 .67284 Mdot
.60731 .63282 Mdot
.47174 .31641 Mdot
.32611 .63936 Mdot
.6053 .45124 Mdot
.49995 .58236 Mdot
.55505 .59935 Mdot
.44071 .34755 Mdot
.54873 .68515 Mdot
.33773 .62129 Mdot
.52287 .57515 Mdot
.65712 .65101 Mdot
.67535 .27019 Mdot
.682 .64873 Mdot
.60325 .4466 Mdot
.50827 .71228 Mdot
.4394 .33033 Mdot
.73355 .45052 Mdot
.30437 .4723 Mdot
.64414 .64161 Mdot
.6452 .4495 Mdot
.3428 .39886 Mdot
.45455 .32525 Mdot
.54196 .69294 Mdot
.28465 .47011 Mdot
.53574 .69395 Mdot
.53459 .56367 Mdot
.42849 .31836 Mdot
.52729 .56052 Mdot
.70785 .44848 Mdot
.30735 .45367 Mdot
.46775 .30148 Mdot
.26336 .67221 Mdot
.49493 .60552 Mdot
.33078 .63684 Mdot
.60979 .63242 Mdot
.44528 .34136 Mdot
.32471 .52228 Mdot
.37444 .63224 Mdot
.24916 .4744 Mdot
.62337 .61729 Mdot
.28987 .4681 Mdot
.61057 .47092 Mdot
.4624 .31834 Mdot
.29701 .49005 Mdot
.33854 .55074 Mdot
.74702 .36394 Mdot
.50811 .61068 Mdot
.58764 .44554 Mdot
.2904 .28385 Mdot
.36096 .34496 Mdot
.50191 .29776 Mdot
.30322 .42421 Mdot
.6259 .43208 Mdot
.50796 .58865 Mdot
.57696 .46124 Mdot
.29967 .48521 Mdot
.31742 .48907 Mdot
.36497 .60852 Mdot
.60213 .45384 Mdot
.53295 .68582 Mdot
.36098 .63454 Mdot
.29712 .64728 Mdot
.32271 .65216 Mdot
.48399 .29875 Mdot
.5102 .60292 Mdot
.50962 .59402 Mdot
.6826 .71032 Mdot
.2874 .43955 Mdot
.54039 .57518 Mdot
.60935 .47546 Mdot
.59417 .70991 Mdot
.46208 .30552 Mdot
.34059 .61776 Mdot
.62652 .43024 Mdot
.74319 .44795 Mdot
.53382 .59115 Mdot
.32902 .60815 Mdot
.48082 .32606 Mdot
.53245 .4724 Mdot
.62849 .45269 Mdot
.69939 .45335 Mdot
.44395 .30379 Mdot
.40642 .22934 Mdot
.65792 .65758 Mdot
.60326 .44224 Mdot
.29242 .43319 Mdot
.3766 .23712 Mdot
.65986 .43076 Mdot
.42947 .38018 Mdot
.54931 .58233 Mdot
.52086 .43626 Mdot
.54133 .32907 Mdot
.55642 .46286 Mdot
.43727 .4985 Mdot
.67301 .54013 Mdot
.45506 .51516 Mdot
.43277 .80162 Mdot
.39707 .51011 Mdot
.58866 .82771 Mdot
.30232 .4116 Mdot
.56246 .49354 Mdot
.85855 .42888 Mdot
.35669 .36573 Mdot
.37615 .53226 Mdot
.30062 .50614 Mdot
.56943 .70147 Mdot
.29118 .73791 Mdot
.29909 .57045 Mdot
.43597 .7993 Mdot
.69778 .4438 Mdot
.38505 .26433 Mdot
.58123 .49704 Mdot
.34107 .51617 Mdot
.30042 .54081 Mdot
.71902 .44084 Mdot
.83801 .55922 Mdot
.32288 .4026 Mdot
.75691 .68948 Mdot
.61671 .22898 Mdot
.31905 .57544 Mdot
.69326 .57478 Mdot
.60905 .75719 Mdot
.64303 .48885 Mdot
.4909 .47657 Mdot
.3067 .40945 Mdot
.42328 .27356 Mdot
.20571 .44276 Mdot
.3196 .63388 Mdot
.44716 .35498 Mdot
.28485 .38812 Mdot
.81374 .62404 Mdot
.25857 .43159 Mdot
.43592 .50005 Mdot
.50132 .611 Mdot
.53126 .42477 Mdot
.64319 .62048 Mdot
.52971 .36526 Mdot
.27232 .61523 Mdot
.29534 .73853 Mdot
.40654 .3294 Mdot
.36153 .56261 Mdot
.59845 .63243 Mdot
.37 .53212 Mdot
.52697 .30974 Mdot
.56282 .68832 Mdot
.5307 .53855 Mdot
.4824 .33902 Mdot
.82244 .52384 Mdot
.69765 .40153 Mdot
.68754 .61933 Mdot
.31388 .55143 Mdot
.40411 .28201 Mdot
.60168 .20346 Mdot
.38458 .37526 Mdot
.50973 .84685 Mdot
.78522 .67753 Mdot
.47717 .81538 Mdot
.59564 .39771 Mdot
.26347 .41757 Mdot
.57847 .62276 Mdot
.44016 .55908 Mdot
.49904 .82197 Mdot
.43096 .23361 Mdot
.83908 .50783 Mdot
.49528 .40869 Mdot
.81975 .63566 Mdot
.4208 .32945 Mdot
.48314 .59816 Mdot
.51345 .30588 Mdot
.54567 .48624 Mdot
.67298 .69403 Mdot
.83083 .6027 Mdot
.35309 .52161 Mdot
.49315 .60701 Mdot
.35756 .37242 Mdot
.53901 .31724 Mdot
.27123 .61382 Mdot
.52128 .55115 Mdot
.65243 .30055 Mdot
.84411 .57609 Mdot
.44811 .48759 Mdot
.81198 .58487 Mdot
.26652 .65248 Mdot
.16565 .55002 Mdot
.29721 .65081 Mdot
.32906 .43788 Mdot
.7715 .68078 Mdot
.45878 .31363 Mdot
.53693 .85073 Mdot
.40069 .52812 Mdot
.41516 .57157 Mdot
.84412 .56815 Mdot
.48581 .84171 Mdot
.54299 .45644 Mdot
.50452 .54374 Mdot
.21407 .43337 Mdot
.47775 .51009 Mdot
.36357 .45046 Mdot
.5674 .56787 Mdot
.28066 .30817 Mdot
.78475 .66216 Mdot
.46785 .83102 Mdot
.84517 .4739 Mdot
.68373 .6139 Mdot
.56319 .74604 Mdot
.40273 .33222 Mdot
.41014 .44556 Mdot
.35962 .47282 Mdot
.81089 .65036 Mdot
.5839 .49086 Mdot
.35313 .24228 Mdot
.45014 .80488 Mdot
.69793 .29788 Mdot
.32264 .28858 Mdot
.34806 .38836 Mdot
.54374 .49615 Mdot
.5062 .3799 Mdot
.50712 .66976 Mdot
.66202 .70459 Mdot
.63834 .28333 Mdot
.38848 .57319 Mdot
.64881 .65765 Mdot
.3937 .39072 Mdot
.54702 .79904 Mdot
.35628 .26627 Mdot
.65 .29412 Mdot
.44182 .37507 Mdot
.50028 .82053 Mdot
.45458 .81078 Mdot
.33775 .26082 Mdot
.37519 .59667 Mdot
.80976 .5953 Mdot
.37533 .41664 Mdot
.5469 .41794 Mdot
.57604 .49781 Mdot
.63275 .48982 Mdot
.32306 .75433 Mdot
.6767 .36964 Mdot
.63631 .77862 Mdot
.35698 .43779 Mdot
.62926 .31395 Mdot
.63003 .76194 Mdot
.63378 .3091 Mdot
.54928 .33454 Mdot
.42263 .38527 Mdot
.32794 .40783 Mdot
.60023 .36848 Mdot
.841 .55937 Mdot
.34553 .6501 Mdot
.49656 .82471 Mdot
.26533 .42427 Mdot
.30992 .56841 Mdot
.4016 .56435 Mdot
.3924 .56148 Mdot
.7307 .71979 Mdot
.34864 .37465 Mdot
.55972 .67363 Mdot
.52099 .31521 Mdot
.41915 .53941 Mdot
.61217 .2704 Mdot
.74081 .41587 Mdot
.40953 .26421 Mdot
.54829 .68957 Mdot
.66038 .32723 Mdot
.51539 .37744 Mdot
.38515 .60355 Mdot
.72281 .39002 Mdot
.71422 .55812 Mdot
.54606 .59609 Mdot
.60976 .69579 Mdot
.71286 .68462 Mdot
.55116 .39862 Mdot
.49843 .83611 Mdot
.37206 .37539 Mdot
.61261 .70174 Mdot
.35757 .47848 Mdot
.64107 .21773 Mdot
.82237 .63245 Mdot
.68665 .76255 Mdot
.40464 .23659 Mdot
.31397 .28383 Mdot
.18817 .63299 Mdot
.31482 .52112 Mdot
.58145 .81473 Mdot
.2653 .42411 Mdot
.52224 .1341 Mdot
.35358 .64963 Mdot
.57041 .63084 Mdot
.4228 .30902 Mdot
.70812 .55777 Mdot
.8279 .58894 Mdot
.53466 .41077 Mdot
.55398 .7138 Mdot
.50572 .29471 Mdot
.60728 .36334 Mdot
.833 .55448 Mdot
.83198 .52213 Mdot
.82748 .53217 Mdot
.30424 .3886 Mdot
.66736 .35026 Mdot
.8511 .54672 Mdot
.58162 .67451 Mdot
.61629 .3753 Mdot
.58047 .48499 Mdot
.70997 .60588 Mdot
.56115 .82023 Mdot
.55572 .73735 Mdot
.48307 .50728 Mdot
.40709 .33081 Mdot
.85105 .56915 Mdot
.70562 .69857 Mdot
.53174 .4391 Mdot
.73501 .70706 Mdot
.53311 .76631 Mdot
.64389 .75655 Mdot
.71367 .73281 Mdot
.46791 .48085 Mdot
.35123 .3932 Mdot
.85798 .56721 Mdot
.48591 .80337 Mdot
.29648 .50742 Mdot
.51051 .37987 Mdot
.55523 .82873 Mdot
.31421 .29297 Mdot
.23319 .4388 Mdot
.4197 .32093 Mdot
.6624 .23437 Mdot
.37408 .49673 Mdot
.49568 .47768 Mdot
.61284 .40355 Mdot
.62249 .77189 Mdot
.35102 .65316 Mdot
.52797 .81417 Mdot
.37058 .47118 Mdot
.59452 .37645 Mdot
.62744 .71254 Mdot
.44476 .8235 Mdot
.49051 .43757 Mdot
.70529 .35733 Mdot
.37233 .37753 Mdot
.36748 .25373 Mdot
.33367 .27884 Mdot
.63927 .25013 Mdot
.65733 .45823 Mdot
.81875 .61744 Mdot
.61517 .82225 Mdot
.71779 .73352 Mdot
.34714 .26016 Mdot
.17973 .59266 Mdot
.30059 .41756 Mdot
.58788 .68322 Mdot
.72155 .54187 Mdot
.4548 .45717 Mdot
.6902 .5334 Mdot
.2978 .49627 Mdot
.6012 .20256 Mdot
.4011 .55948 Mdot
.58219 .67376 Mdot
.43588 .25087 Mdot
.42046 .55745 Mdot
.69807 .35835 Mdot
.44727 .37627 Mdot
.32292 .25598 Mdot
.50344 .82027 Mdot
.34064 .65096 Mdot
.36398 .59401 Mdot
.66221 .37207 Mdot
.47855 .5708 Mdot
.54897 .65113 Mdot
.55218 .41561 Mdot
.60589 .24306 Mdot
.18965 .61091 Mdot
.67434 .75617 Mdot
.55313 .83743 Mdot
.71096 .73571 Mdot
.4688 .81657 Mdot
.33236 .55413 Mdot
.62021 .69437 Mdot
.24822 .45459 Mdot
.2784 .41252 Mdot
.61518 .67729 Mdot
.44901 .81841 Mdot
.53732 .43116 Mdot
.51365 .31094 Mdot
.6391 .46907 Mdot
.69824 .69708 Mdot
.59923 .75549 Mdot
.60341 .67746 Mdot
.65623 .25888 Mdot
.48553 .33357 Mdot
.58027 .7156 Mdot
.51435 .4705 Mdot
.70048 .47265 Mdot
.317 .27855 Mdot
.29853 .49134 Mdot
.45915 .37868 Mdot
.44417 .82441 Mdot
.1903 .626 Mdot
.43914 .53469 Mdot
.71433 .41466 Mdot
.78936 .65136 Mdot
.64013 .39614 Mdot
.30024 .29726 Mdot
.67962 .24386 Mdot
.31547 .53176 Mdot
.41044 .32679 Mdot
.58219 .38435 Mdot
.41011 .577 Mdot
.40151 .24895 Mdot
.43977 .36575 Mdot
.6486 .48338 Mdot
.7699 .68993 Mdot
.67858 .42038 Mdot
.47919 .48674 Mdot
.67159 .64887 Mdot
.39645 .4597 Mdot
.40836 .53106 Mdot
.62709 .7201 Mdot
.44702 .51135 Mdot
.81878 .53749 Mdot
.5937 .20012 Mdot
.49659 .50354 Mdot
.57788 .68417 Mdot
.58204 .66865 Mdot
.61609 .22875 Mdot
.52436 .30251 Mdot
.3567 .45126 Mdot
.68862 .4373 Mdot
.75982 .70573 Mdot
.47208 .40822 Mdot
.62103 .70787 Mdot
.38522 .40596 Mdot
.68183 .4457 Mdot
.49433 .61362 Mdot
.71954 .72785 Mdot
.51912 .44141 Mdot
.86402 .41181 Mdot
.42138 .80454 Mdot
.39095 .28504 Mdot
.54051 .33962 Mdot
.5123 .82963 Mdot
.37537 .31608 Mdot
.40652 .51162 Mdot
.37485 .45703 Mdot
.54296 .82684 Mdot
.51411 .4331 Mdot
.51841 .45239 Mdot
.30937 .27043 Mdot
.84832 .53542 Mdot
.47763 .50272 Mdot
.23662 .43054 Mdot
.55557 .74933 Mdot
.63077 .42357 Mdot
.38097 .37641 Mdot
.23912 .33377 Mdot
.40598 .4141 Mdot
.45815 .52094 Mdot
.60856 .82843 Mdot
.54551 .40745 Mdot
.37078 .37995 Mdot
.86456 .41569 Mdot
.87026 .40269 Mdot
.38001 .36223 Mdot
.8026 .66234 Mdot
.52253 .44855 Mdot
.30065 .30007 Mdot
.30133 .40705 Mdot
.7233 .43386 Mdot
.60344 .26052 Mdot
.73249 .73094 Mdot
.17205 .60058 Mdot
.36155 .45789 Mdot
.41597 .29746 Mdot
.7291 .73694 Mdot
.54991 .388 Mdot
.56764 .66396 Mdot
.16691 .55011 Mdot
.37021 .79847 Mdot
.51042 .84356 Mdot
.66035 .25282 Mdot
.32258 .75815 Mdot
.39217 .78226 Mdot
.35673 .51195 Mdot
.56082 .83079 Mdot
.52715 .63159 Mdot
.65142 .22134 Mdot
.4983 .82029 Mdot
.29715 .28735 Mdot
.27329 .70275 Mdot
.41189 .52808 Mdot
.55616 .40744 Mdot
.43641 .39058 Mdot
.27788 .31284 Mdot
.33929 .38475 Mdot
.63316 .38394 Mdot
.6135 .64018 Mdot
.54872 .33926 Mdot
.37633 .23313 Mdot
.69682 .25103 Mdot
.55522 .41841 Mdot
.82638 .49451 Mdot
.34505 .41005 Mdot
.59648 .65134 Mdot
.53305 .32661 Mdot
.60745 .73423 Mdot
.56407 .67703 Mdot
.58763 .42151 Mdot
.77505 .68354 Mdot
.56056 .67233 Mdot
.82663 .50765 Mdot
.53472 .85413 Mdot
.74466 .69495 Mdot
.42601 .58362 Mdot
.55561 .62969 Mdot
.5596 .81665 Mdot
.5672 .81266 Mdot
.83397 .48702 Mdot
.44096 .79678 Mdot
.61433 .67207 Mdot
.60376 .3866 Mdot
.73739 .42558 Mdot
.69728 .36665 Mdot
.51661 .8291 Mdot
.61304 .22096 Mdot
.63183 .757 Mdot
.40307 .24041 Mdot
.44828 .82108 Mdot
.54522 .46373 Mdot
.60927 .72907 Mdot
.39495 .42218 Mdot
.5094 .54423 Mdot
.32433 .59558 Mdot
.86385 .50908 Mdot
.33098 .26658 Mdot
.66047 .75479 Mdot
.34722 .24668 Mdot
.50624 .38599 Mdot
.40815 .79462 Mdot
.50877 .29507 Mdot
.46109 .55294 Mdot
.33422 .56627 Mdot
.57535 .78666 Mdot
.54101 .44107 Mdot
.28127 .29305 Mdot
.68007 .28924 Mdot
.73645 .71788 Mdot
.63168 .76283 Mdot
.84691 .45872 Mdot
.5743 .72445 Mdot
.65858 .32584 Mdot
.82025 .51937 Mdot
.38675 .24275 Mdot
.59743 .66838 Mdot
.83825 .54869 Mdot
.48544 .28065 Mdot
.78933 .67258 Mdot
.30704 .46775 Mdot
.57207 .68044 Mdot
.26107 .31594 Mdot
.59216 .67467 Mdot
.59057 .66925 Mdot
.66202 .76331 Mdot
.35893 .3749 Mdot
.36992 .36583 Mdot
.37447 .41716 Mdot
.29469 .57695 Mdot
.72885 .42794 Mdot
.46514 .49167 Mdot
.84501 .47767 Mdot
.656 .4577 Mdot
.47525 .78729 Mdot
.49696 .82963 Mdot
.24684 .45168 Mdot
.57354 .39985 Mdot
.2752 .30354 Mdot
.6804 .25703 Mdot
.67294 .71031 Mdot
.84666 .54206 Mdot
.57663 .39855 Mdot
.71084 .54656 Mdot
.72869 .29998 Mdot
.23153 .41871 Mdot
.35828 .45711 Mdot
.44205 .49972 Mdot
.65638 .39528 Mdot
.6599 .65501 Mdot
.47485 .81279 Mdot
.59853 .82908 Mdot
.82868 .48963 Mdot
.35591 .46815 Mdot
.59839 .67917 Mdot
.42102 .37711 Mdot
.59321 .7741 Mdot
.84963 .46702 Mdot
.30548 .75294 Mdot
.50978 .3792 Mdot
.45832 .8229 Mdot
.35807 .39051 Mdot
.56923 .66542 Mdot
.60836 .67739 Mdot
.82202 .52853 Mdot
.43033 .27777 Mdot
.52466 .40197 Mdot
.39822 .39814 Mdot
.63528 .64381 Mdot
.38954 .53876 Mdot
.65347 .23378 Mdot
.3432 .37162 Mdot
.84678 .45741 Mdot
.37308 .77814 Mdot
.70979 .30136 Mdot
.85502 .43719 Mdot
.48184 .32341 Mdot
.38545 .53915 Mdot
.16822 .52346 Mdot
.60761 .6985 Mdot
.3072 .65095 Mdot
.61539 .47856 Mdot
.61424 .65775 Mdot
.386 .27753 Mdot
.5653 .73316 Mdot
.54716 .6788 Mdot
.45794 .37673 Mdot
.40774 .78982 Mdot
.45419 .37888 Mdot
.599 .82626 Mdot
.46722 .47662 Mdot
.54516 .34923 Mdot
.7092 .26711 Mdot
.34092 .55728 Mdot
.37432 .24918 Mdot
.75246 .69313 Mdot
.70532 .60919 Mdot
.44361 .36249 Mdot
.43365 .35051 Mdot
.45615 .25845 Mdot
.26757 .49175 Mdot
.80151 .6351 Mdot
.48727 .83916 Mdot
.33884 .58391 Mdot
.46956 .26783 Mdot
.6062 .39676 Mdot
.55117 .41345 Mdot
.68724 .73933 Mdot
.37299 .62914 Mdot
.83443 .61586 Mdot
.62599 .21061 Mdot
.37945 .26546 Mdot
.46248 .44702 Mdot
.72664 .55251 Mdot
.58768 .63742 Mdot
.37044 .56677 Mdot
.54675 .43225 Mdot
.37832 .32854 Mdot
.46605 .28156 Mdot
.39248 .55021 Mdot
.54824 .71051 Mdot
.37685 .59567 Mdot
.26402 .47547 Mdot
.63228 .24628 Mdot
.51016 .83499 Mdot
.42804 .36741 Mdot
.55386 .65566 Mdot
.39228 .58605 Mdot
.701 .37592 Mdot
.71972 .57956 Mdot
.8655 .53184 Mdot
.77113 .66978 Mdot
.47119 .36996 Mdot
.36312 .2629 Mdot
.26618 .67002 Mdot
.67362 .7554 Mdot
.51569 .41026 Mdot
.51308 .82501 Mdot
.65545 .30845 Mdot
.70583 .7322 Mdot
.54072 .33095 Mdot
.44275 .48193 Mdot
.4802 .82667 Mdot
.51247 .75134 Mdot
.4552 .82666 Mdot
.68791 .26705 Mdot
.69342 .40947 Mdot
.38827 .80531 Mdot
.40164 .40785 Mdot
.5343 .44955 Mdot
.71913 .46754 Mdot
.45332 .46172 Mdot
.54481 .82266 Mdot
.47776 .30618 Mdot
.56839 .71284 Mdot
.44242 .24051 Mdot
.36161 .45526 Mdot
.78148 .66509 Mdot
.34533 .26635 Mdot
.48128 .83629 Mdot
.73105 .42197 Mdot
.55798 .77834 Mdot
.61018 .22546 Mdot
.69279 .61128 Mdot
.50994 .56464 Mdot
.64146 .29376 Mdot
.49266 .57972 Mdot
.68739 .70954 Mdot
.70692 .37205 Mdot
.82896 .59704 Mdot
.70725 .68924 Mdot
.43766 .39147 Mdot
.48332 .57178 Mdot
.43641 .28075 Mdot
.83833 .59858 Mdot
.67768 .70497 Mdot
.2733 .3129 Mdot
.51039 .84239 Mdot
.44299 .7936 Mdot
.85682 .43186 Mdot
.3582 .38021 Mdot
.58599 .37462 Mdot
.56575 .83017 Mdot
.48932 .40571 Mdot
.39658 .78307 Mdot
.54107 .44057 Mdot
.40338 .34113 Mdot
.84313 .56039 Mdot
.50583 .6309 Mdot
.42042 .38941 Mdot
.75449 .38463 Mdot
.40937 .32324 Mdot
.68046 .69675 Mdot
.56351 .41756 Mdot
.32459 .64082 Mdot
.71779 .55187 Mdot
.31462 .74874 Mdot
.45069 .25849 Mdot
.50612 .83082 Mdot
.51966 .82165 Mdot
.55993 .7557 Mdot
.41631 .60719 Mdot
.85582 .43011 Mdot
.65375 .34574 Mdot
.56211 .44291 Mdot
.44557 .37313 Mdot
.54217 .67232 Mdot
.4641 .80191 Mdot
.68489 .4463 Mdot
.70552 .57451 Mdot
.65343 .30324 Mdot
.74621 .71725 Mdot
.40406 .43874 Mdot
.34068 .41821 Mdot
.47939 .27412 Mdot
.27735 .31075 Mdot
.41671 .23449 Mdot
.35545 .35554 Mdot
.54419 .82054 Mdot
.43979 .53375 Mdot
.43857 .49367 Mdot
.47455 .39484 Mdot
.52492 .8075 Mdot
.34873 .50027 Mdot
.27452 .47452 Mdot
.60602 .24802 Mdot
.83593 .47548 Mdot
.49972 .38195 Mdot
.41836 .52682 Mdot
.49407 .46084 Mdot
.67496 .40318 Mdot
.363 .45685 Mdot
.36685 .37596 Mdot
.42646 .35039 Mdot
.82132 .5582 Mdot
.49571 .4894 Mdot
.55298 .63591 Mdot
.44046 .81016 Mdot
.48161 .46765 Mdot
.52164 .82482 Mdot
.60476 .36253 Mdot
.82731 .53893 Mdot
.61884 .70885 Mdot
.52893 .76282 Mdot
.64455 .46877 Mdot
.42878 .24135 Mdot
.71868 .72924 Mdot
.51175 .41106 Mdot
.44944 .54098 Mdot
.5054 .28464 Mdot
.52956 .85027 Mdot
.54637 .54994 Mdot
.18832 .60714 Mdot
.50127 .54775 Mdot
.71295 .56374 Mdot
.71046 .55277 Mdot
.25641 .47997 Mdot
.54545 .41875 Mdot
.364 .51465 Mdot
.66991 .39671 Mdot
.61141 .24519 Mdot
.6213 .78838 Mdot
.86037 .50431 Mdot
.40238 .28336 Mdot
.50024 .8497 Mdot
.41615 .26681 Mdot
.39551 .32104 Mdot
.37651 .77822 Mdot
.45058 .5479 Mdot
.66818 .36795 Mdot
.55561 .74366 Mdot
.48324 .32027 Mdot
.85503 .49722 Mdot
.4541 .5239 Mdot
.56618 .72064 Mdot
.26599 .63659 Mdot
.40827 .53639 Mdot
.20137 .44606 Mdot
.27561 .41686 Mdot
.54095 .84767 Mdot
.49933 .82215 Mdot
.3322 .40979 Mdot
.52189 .44749 Mdot
.45547 .53259 Mdot
.83164 .55483 Mdot
.48871 .56249 Mdot
.76573 .68229 Mdot
.311 .38829 Mdot
.62944 .25625 Mdot
.70583 .68703 Mdot
.66479 .70457 Mdot
.69489 .61529 Mdot
.65288 .28014 Mdot
.80384 .59421 Mdot
.52843 .60721 Mdot
.36654 .59171 Mdot
.27597 .70819 Mdot
.8478 .47444 Mdot
.38462 .25551 Mdot
.51446 .619 Mdot
.60349 .76845 Mdot
.49554 .48685 Mdot
.59699 .64709 Mdot
.37425 .43401 Mdot
.54926 .64929 Mdot
.26097 .39879 Mdot
.36543 .24251 Mdot
.75931 .70511 Mdot
.62754 .47812 Mdot
.67742 .53308 Mdot
.34418 .51653 Mdot
.32481 .6583 Mdot
.46493 .24777 Mdot
.86372 .52876 Mdot
.28206 .48384 Mdot
.17097 .51435 Mdot
.25342 .47144 Mdot
.669 .7527 Mdot
.17882 .60178 Mdot
.27435 .49856 Mdot
.5945 .83016 Mdot
.38305 .27597 Mdot
.68506 .27794 Mdot
.3526 .23997 Mdot
.69206 .70684 Mdot
.63778 .2909 Mdot
.56656 .56126 Mdot
.79891 .65556 Mdot
.58917 .64627 Mdot
.57081 .70106 Mdot
.81052 .57843 Mdot
.4735 .82664 Mdot
.42835 .80716 Mdot
.30594 .51624 Mdot
.41394 .30391 Mdot
.195 .63482 Mdot
.3139 .57116 Mdot
.60668 .18273 Mdot
.77156 .66719 Mdot
.75403 .36154 Mdot
.51361 .40851 Mdot
.37694 .41162 Mdot
.83226 .56542 Mdot
.53541 .81673 Mdot
.53312 .45932 Mdot
.39324 .62017 Mdot
.65095 .71294 Mdot
.59016 .77036 Mdot
.36779 .39763 Mdot
.72005 .7156 Mdot
.36743 .56614 Mdot
.49303 .61723 Mdot
.48675 .83041 Mdot
.43157 .24172 Mdot
.68588 .60817 Mdot
.83594 .47827 Mdot
.71441 .59076 Mdot
.42998 .81668 Mdot
.3039 .38838 Mdot
.26648 .67928 Mdot
.84445 .48311 Mdot
.4036 .25518 Mdot
.67603 .31234 Mdot
.86256 .41325 Mdot
.81901 .63631 Mdot
.45717 .53209 Mdot
.68002 .42994 Mdot
.58311 .82993 Mdot
.38645 .62709 Mdot
.64907 .76445 Mdot
.60292 .20304 Mdot
.40707 .79905 Mdot
.72414 .38211 Mdot
.68349 .43464 Mdot
.57514 .66021 Mdot
.49276 .36516 Mdot
.41775 .31627 Mdot
.29722 .58154 Mdot
.44913 .81761 Mdot
.63283 .24168 Mdot
.59364 .20035 Mdot
.68223 .26281 Mdot
.4622 .36907 Mdot
.78416 .67213 Mdot
.46655 .566 Mdot
.61873 .22314 Mdot
.82806 .55135 Mdot
.7114 .52898 Mdot
.36153 .5012 Mdot
.60338 .23139 Mdot
.61628 .69393 Mdot
.31007 .74438 Mdot
.85864 .44295 Mdot
.61363 .25917 Mdot
.83871 .60748 Mdot
.68733 .76413 Mdot
.45372 .36188 Mdot
.44081 .26167 Mdot
.58414 .63161 Mdot
.46674 .50604 Mdot
.23599 .41233 Mdot
.31133 .5682 Mdot
.4264 .79122 Mdot
.39381 .60446 Mdot
.5809 .45862 Mdot
.37847 .39667 Mdot
.74051 .71196 Mdot
.56872 .66912 Mdot
.75025 .70383 Mdot
.64093 .26697 Mdot
.65144 .46027 Mdot
.86691 .3989 Mdot
.29812 .30115 Mdot
.73801 .4082 Mdot
.55694 .58085 Mdot
.51071 .61803 Mdot
.57555 .43017 Mdot
.31385 .49405 Mdot
.59644 .70801 Mdot
.38071 .79124 Mdot
.80059 .65085 Mdot
.46993 .26959 Mdot
.58718 .64105 Mdot
.27291 .42686 Mdot
.62791 .61515 Mdot
.72326 .37784 Mdot
.28229 .48652 Mdot
.34972 .77448 Mdot
.204 .45315 Mdot
.35593 .48549 Mdot
.3907 .53647 Mdot
.61642 .64641 Mdot
.51813 .61513 Mdot
.36443 .77748 Mdot
.24852 .46821 Mdot
.34964 .5097 Mdot
.47795 .83562 Mdot
.66128 .28848 Mdot
.35694 .39629 Mdot
.27468 .69464 Mdot
.60018 .67036 Mdot
.38585 .3988 Mdot
.47702 .51393 Mdot
.66854 .23874 Mdot
.81843 .58485 Mdot
.27415 .64701 Mdot
.52926 .60762 Mdot
.73433 .30485 Mdot
.82626 .5949 Mdot
.29199 .4267 Mdot
.61239 .81959 Mdot
.45882 .53947 Mdot
.45994 .24726 Mdot
.76328 .37531 Mdot
.57245 .3966 Mdot
.59095 .49201 Mdot
.65816 .4148 Mdot
.6738 .57688 Mdot
.19445 .44847 Mdot
.56123 .40739 Mdot
.40375 .54064 Mdot
.43809 .52565 Mdot
.58151 .69883 Mdot
.59319 .49012 Mdot
.61962 .42776 Mdot
.54669 .55373 Mdot
.63836 .69405 Mdot
.5566 .64726 Mdot
.57717 .7067 Mdot
.35068 .39368 Mdot
.36455 .77866 Mdot
.42388 .80501 Mdot
.66679 .35627 Mdot
.83673 .56324 Mdot
.71252 .46904 Mdot
.76654 .674 Mdot
.38615 .45469 Mdot
.35014 .38537 Mdot
.71564 .58398 Mdot
.85704 .44453 Mdot
.40803 .37617 Mdot
.52803 .52022 Mdot
.67875 .76644 Mdot
.73338 .71094 Mdot
.34866 .4077 Mdot
.29695 .28299 Mdot
.27941 .71551 Mdot
.58385 .65302 Mdot
.37005 .23931 Mdot
.34475 .58729 Mdot
.68058 .75487 Mdot
.67444 .39331 Mdot
.4545 .54175 Mdot
.64708 .23441 Mdot
.70822 .38166 Mdot
.35791 .60947 Mdot
.67826 .24325 Mdot
.65431 .27989 Mdot
.80196 .59748 Mdot
.56367 .44127 Mdot
.43264 .45396 Mdot
.4226 .377 Mdot
.84315 .4666 Mdot
.30956 .59606 Mdot
.71072 .54527 Mdot
.61383 .18578 Mdot
.19596 .44593 Mdot
.39696 .78192 Mdot
.83056 .48509 Mdot
.27905 .41277 Mdot
.6638 .39568 Mdot
.22209 .34582 Mdot
.41442 .37583 Mdot
.43716 .36902 Mdot
.26473 .47766 Mdot
.56732 .77391 Mdot
.40196 .38731 Mdot
.86565 .42821 Mdot
.70282 .7362 Mdot
.64974 .36427 Mdot
.5943 .17256 Mdot
.49093 .83016 Mdot
.69549 .54679 Mdot
.35298 .3766 Mdot
.77283 .68507 Mdot
.24597 .40486 Mdot
.57049 .83006 Mdot
.48095 .47671 Mdot
.44078 .26535 Mdot
.58677 .76625 Mdot
.34808 .24909 Mdot
.59884 .39231 Mdot
.59272 .19199 Mdot
.31956 .27568 Mdot
.60953 .75719 Mdot
.50937 .43336 Mdot
.38807 .31755 Mdot
.38442 .30488 Mdot
.4704 .44982 Mdot
.44239 .55889 Mdot
.41956 .52625 Mdot
.44452 .49109 Mdot
.35079 .49732 Mdot
.4538 .44502 Mdot
.29088 .30706 Mdot
.25247 .42752 Mdot
.66151 .26323 Mdot
.2912 .72511 Mdot
.57647 .71846 Mdot
.35987 .64793 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`2Vooooo`;o0000XOooool001cooooo00?o0000ooooooooool0Y_ooool2o`000:7ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0[Oooool3o`00
09Wooooo000Looooo`03o`000?oooooooooo0:gooooo1Ol0002Gooooo`007?ooool00ol0003ooooo
ooooo`2_ooooo`?o0000Uoooool001cooooo0_l0002aooooo`Ko0000Toooool001cooooo00?o0000
ooooooooool0/Oooool5o`0009?ooooo000Looooo`03o`000?oooooooooo0;Gooooo0_l0002Boooo
o`007?ooool00ol0003oooooooooo`2eooooo`;o0000T_ooool001cooooo00?o0000ooooooooool0
^?ooool2o`0008oooooo000Looooo`03o`000?oooooooooo0;Sooooo0_l0002?ooooo`007?ooool0
0ol0003oooooooooo`2iooooo`Co0000S?ooool001cooooo00?o0000ooooooooool0^Oooool6o`00
08[ooooo000Looooo`03o`000?oooooooooo0;gooooo0_l0002:ooooo`007?ooool00ol0003ooooo
ooooo`2nooooo`;o0000ROooool001cooooo00?o0000ooooooooool0__ooool5o`0008Kooooo000L
ooooo`03o`000?oooooooooo0;kooooo1Ol000000ooooooo0000o`000023ooooo`007?ooool00ol0
003oooooooooo`31ooooo`Ko0000P_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2
ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0;gooooo0_l00002ooooo`?o000000?ooooo
o`000?l00000P_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0;gooooo0_l00002ooooo`;o0000
0_ooool2o`0008;ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?o
V9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`2nooooo`Oo0000Q?ooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06ooooo`?o0000_Oooool9
o`0008?ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIV
I_ooool01Oooool00ol0003oooooooooo`2mooooo`Wo0000Poooool00003ooooool@413ooooo00;o
oooo00?o410@ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;oo
oooo0ol00007ooooo`;o0000O_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0
003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0`?ooool6o`0000;ooooo0ol0001n
ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
1_ooool00ol0003oooooooooo`30ooooo`Ko00000_ooool4o`0007gooooo000Looooo`03o`000?oo
oooooooo0<3ooooo1ol00003ooooo`Co0000Noooool001cooooo00?o0000ooooooooool0`?ooool7
o`0000Gooooo0_l00002ooooo`;o0000Moooool001cooooo00?o0000ooooooooool0_oooool2o`00
00;ooooo1?l00009ooooo`;o0000Moooool001cooooo00?o0000ooooooooool0_oooool5o`000003
ooooool0003o000008;ooooo000Looooo`03o`000?oooooooooo07[ooooo0_l000001?oooooo0000
o`000?ooool6o`0003Wooooo2?l00022ooooo`007?ooool00ol0003oooooooooo`1fooooo`?o0000
00Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000004o`0000;ooooo0ol0000eooooo`;o
00000_ooool3o`0000Wooooo0_l0001gooooo`007?ooool00ol0003oooooooooo`1`ooooo`;o0000
1?ooool3o`0000Oooooo0_l00002ooooo`;o00000_ooool3o`0000?ooooo0_l0000`ooooo`;o0000
3?ooool4o`000003ooooool0003o000000Cooooo0_l0001^ooooo`007?ooool00ol0003ooooooooo
o`1_ooooo`?o00000_ooool2o`000003ooooool0003o000000Oooooo0_l00002ooooo`;o00002?oo
ool2o`0002kooooo0ol0000=ooooo`;o00000oooool4o`0000;ooooo0_l0001^ooooo`007?ooool0
0ol0003oooooooooo`1_ooooo`;o00000_ooool3o`000004ooooool0003o0000ooooo`;o00000ooo
ool2o`0000Oooooo0_l00002ooooo`;o0000<?ooool5o`0000Oooooo0_l00009ooooo`;o0000L_oo
ool001cooooo00?o0000ooooooooool0Koooool2o`0000;ooooo0_l00005ooooo`;o00000oooool2
o`0000Oooooo0_l00002ooooo`;o00001Oooool3o`0002Wooooo1_l00005ooooo`;o00003Oooool2
o`0006kooooo000Looooo`03o`000?oooooooooo06gooooo0_l00007ooooo`;o00001oooool2o`00
017ooooo1?l0000Yooooo`Ko00001Oooool2o`0000gooooo0_l0001^ooooo`007?ooool2o`0006Oo
oooo0_l00005ooooo`;o00001oooool2o`0000Oooooo0_l00009ooooo`;o00001_ooool3o`0002_o
oooo0ol00007ooooo`Co00004Oooool2o`0006Sooooo000Looooo`03o`000?oooooooooo06Kooooo
0_l0000<ooooo`;o00002Oooool2o`0000Wooooo0_l0000dooooo`;o00002_ooool2o`0000Gooooo
0_l0000:ooooo`;o0000J?ooool001cooooo00?o0000ooooooooool0IOooool2o`0000gooooo0_l0
0003ooooo`;o00001?ooool2o`0000kooooo0ol0000^ooooo`;o00001oooool2o`0000Sooooo0_l0
0004ooooo`;o0000K_ooool001cooooo00?o0000ooooooooool0IOooool2o`0000?ooooo0_l00000
0ooooooo0000o`00000:ooooo`;o00005?ooool3o`0000[ooooo0_l0000Rooooo`;o00000_ooool2
o`0000?ooooo0_l00006ooooo`;o00001_ooool2o`0006kooooo000Looooo`03o`000?oooooooooo
06[ooooo0_l000000ooooooo0000o`000003ooooo`;o00001Oooool2o`0000Kooooo0_l00004oooo
o`;o00000_ooool2o`0000oooooo0_l0000Rooooo`?o000000?oooooo`000?l000002oooool4o`00
00Gooooo0_l0001]ooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o00001_ooool2o`0000;o
oooo0_l00002ooooo`Co00001?ooool3o`0000Kooooo2Ol000000ooooooo0000o`000002ooooo`;o
00003?ooool2o`0002;ooooo0_l00009ooooo`;o00001Oooool2o`0000Gooooo1?l00005ooooo`;o
0000I?ooool001cooooo00?o0000ooooooooool0H?ooool3o`0000Gooooo0_l00002ooooo`;o0000
00?oooooo`000?l000000_l00005ooooo`;o00002Oooool4o`000004ooooool0003o0000ooooo`?o
000000?oooooo`000?l000000_l00002ooooo`;o00001_ooool3o`00027ooooo1?l00007ooooo`;o
00001?ooool2o`0000?ooooo0ol00002ooooo`;o00001Oooool2o`0006Cooooo000Looooo`03o`00
0?oooooooooo067ooooo0_l0000<ooooo`;o00003oooool2o`0000Cooooo0_l00004ooooo`;o0000
0oooool2o`0000;ooooo0_l00007ooooo`;o00008oooool2o`0000gooooo0_l00003ooooo`?o0000
Koooool001cooooo00?o0000ooooooooool0G_ooool2o`0000Cooooo0_l0000Cooooo`;o00001Ooo
ool2o`0000Cooooo0_l00008ooooo`Co00001?ooool2o`0002Wooooo0_l0000Gooooo`?o0000J_oo
ool001cooooo00?o0000ooooooooool0G_ooool2o`0000?ooooo0ol00003ooooo`;o00003_ooool3
o`0000;ooooo1?l00006ooooo`Co000000?oooooo`000?l000001Ol000000ooooooo0000o`000003
o`0002Wooooo0ol0000:ooooo`?o00002?ooool4o`0006[ooooo000Looooo`03o`000?oooooooooo
05gooooo0_l00004ooooo`;o00001?ooool2o`0000oooooo2?l00006oooooaCo0000:?ooool2o`00
00[ooooo0ol00008ooooo`Ko0000J?ooool001cooooo00?o0000ooooooooool0Foooool4o`0000?o
oooo0_l0000Gooooo`?o000000Coooooo`000?l0003o00001?ooool8o`000003ooooool0003o0000
00Go000000?oooooo`000?l000001Ol00002ooooo`;o0000:_ooool2o`00013ooooo1?l0001Woooo
o`007?ooool00ol0003oooooooooo`1Iooooo`Ko00000oooool2o`000003ooooool0003o000001Co
oooo0ol000000ooooooo0000o`000005oooooa3o000000?oooooo`000?l000001Ol00002ooooo`;o
0000:_ooool2o`0000Gooooo0_l00004ooooo`Co00000oooool4o`0006Gooooo000Looooo`03o`00
0?oooooooooo05Sooooo1?l000000ooooooo0000o`000006ooooo`;o00007ooooolAo`000003oooo
ool0003o000000Co0000;Oooool2o`0000Kooooo1?l00002ooooo`Co00001?ooool4o`0006Cooooo
000Looooo`03o`000?oooooooooo05Sooooo0_l00008ooooo`;o00008OoooolBo`0000;ooooo1ol0
00001?oooooo0000o`000?l00002ooooo`;o00008oooool6o`0000Cooooo0_l0000<ooooo`?o0000
00?oooooo`000?l00000H?ooool001cooooo00?o0000ooooooooool0F?ooool2o`0000Cooooo0_l0
0002ooooo`;o00007ooooolEo`000003ooooool0003o000000Wo00000_ooool2o`0002Gooooo1?l0
000>ooooo`;o00000oooool6o`0005oooooo000Looooo`;o0000E_ooool2o`0000Kooooo0ol0000S
ooooo`;o00000_oooolAo`000003ooooool0003o000000Ko0000;oooool2o`0000Sooooo0_l00000
0ooooooo0000o`000002o`0000;ooooo2?l0001Nooooo`007?ooool00ol0003oooooooooo`1Eoooo
o`?o00001Oooool3o`0001[ooooo0_l00007ooooo`_o000000?oooooo`000?l000003_l00002oooo
o`;o00001?ooool2o`0001oooooo0_l00006ooooo`;o00001oooool3o`000004ooooool0003o0000
o`0000?ooooo2?l0001Nooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o000000?oooooo`00
0?l000000oooool2o`0000;ooooo0_l0000Hooooo`?o00001ooooolFo`0000;ooooo1?l00002oooo
o`Co00000_ooool2o`0001oooooo0_l00006ooooo`;o00001oooool3o`000004ooooool0003o0000
o`0000;ooooo0_l00006ooooo`?o0000G?ooool001cooooo00?o0000ooooooooool0Doooool2o`00
0004ooooool0003o0000o`0000;ooooo1_l0000Hooooo`Co00002OoooolCo`0000Cooooo1?l00000
1?oooooo0000o`000?l00002ooooo`;o00007oooool4o`0000Gooooo0_l00007ooooo`;o00000ooo
ool2o`000003ooooool0003o000000Kooooo0ol0001Looooo`007?ooool00ol0003oooooooooo`1?
ooooo`?o00000oooool4o`0000Cooooo0_l0000Jooooo`Co00002Oooool2o`000003ooooool0003o
000000ko00001?ooool4o`0000;ooooo0_l00002ooooo`;o00007oooool4o`0000Gooooo0_l00005
ooooo`;o00001Oooool6o`0000Kooooo0_l0001Looooo`007?ooool00ol0003oooooooooo`1?oooo
o`Co00000_ooool4o`0001gooooo0_l0000<ooooo`;o00000oooool@o`0000Cooooo0_l00006oooo
o`?o00001?ooool2o`0001_ooooo0_l0000:ooooo`Go00001_ooool5o`0000Kooooo0ol0001Koooo
o`007?ooool00ol0003oooooooooo`1?ooooo`Co00008oooool2o`0000;ooooo0_l00008ooooo`;o
000000?oooooo`000?l000001ol000000ooooooo0000o`000007o`0000?ooooo0_l00006ooooo`?o
00000oooool3o`0002Oooooo0ol0000:ooooo`;o00002?ooool2o`0005_ooooo000Looooo`03o`00
0?oooooooooo04gooooo1?l00005ooooo`Co00006Oooool3o`0000Cooooo0_l000000ooooooo0000
o`000002ooooo`;o00000_oooolFo`00013ooooo0_l0000hooooo`;o00001_ooool2o`0005[ooooo
000Looooo`03o`000?oooooooooo04gooooo1?l00005ooooo`Co00006Oooool3o`0000Cooooo0_l0
00000ooooooo0000o`000002ooooo`;o00000_ooool2o`0000;ooooo4_l0000gooooo`;o00004Ooo
ool3o`0000Gooooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`1=ooooo`?o00008_ooool4
o`000004ooooool0003o0000ooooo`;o00001?ooool4o`0000Kooooo4ol0000<ooooo`Go00009?oo
ool3o`0000;ooooo0_l0000=ooooo`Co0000Goooool001cooooo00?o0000ooooooooool0BOooool4
o`0000Gooooo0_l0000Nooooo`Co000000?oooooo`000?l000001_ooool5o`000003ooooool0003o
000000?ooooo4ol0000<ooooo`Go00009Oooool2o`0000;ooooo0_l0000?ooooo`;o0000Goooool0
01cooooo00?o0000ooooooooool0B?ooool5o`0000Gooooo0_l0000Nooooo`?o00002_ooool3o`00
00?ooooo0_l00002oooooa?o00003_ooool4o`000003ooooool0003o000002Oooooo0_l00002oooo
o`;o00002_ooool3o`0005kooooo000Looooo`03o`000?oooooooooo04Sooooo1?l0000Vooooo`?o
00005?oooolCo`0001?ooooo0_l0000Hooooo`;o00003Oooool2o`0000;ooooo0_l0000:ooooo`?o
00001Oooool2o`0005Oooooo000Looooo`03o`000?oooooooooo04Sooooo0_l0000Wooooo`Co0000
1_ooool2o`0000;ooooo0ol00007oooooa;o000000?oooooo`000?l000003_ooool5o`0001Sooooo
0_l0000Nooooo`Go00000_ooool3o`0005Kooooo000Looooo`03o`000?oooooooooo04Gooooo0_l0
000Yooooo`Go00001_ooool9o`0000Gooooo4_l000001?oooooo0000o`000?l0000=ooooo`Go0000
:?ooool3o`0000oooooo1?l00002ooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0@_oo
ool9o`0002Cooooo1Ol00007ooooo`Ko000000?oooooo`000?l000001_oooolEo`0000gooooo0_l0
00000ooooooo0000o`00000Pooooo`;o00001_ooool3o`00017ooooo0_l0001Jooooo`007?ooool2
o`0004;ooooo2_l0000Tooooo`Go00002Oooool2o`000003ooooool0003o000000;o00000ooooolF
o`00013ooooo0_l0000Hooooo`;o00002?ooool2o`0000;ooooo0_l00003ooooo`;o0000KOooool0
01cooooo00?o0000ooooooooool0@Oooool7o`0002Sooooo1?l00004ooooo`;o000000?oooooo`00
0?l000000oooool6o`000003ooooool0003o000001Co00004?ooool2o`0001Oooooo0ol0000<oooo
o`;o00000oooool4o`00017ooooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`12ooooo`Co
0000:?ooool4o`0000Kooooo0_l000000ooooooo0000o`000006ooooo`Co00000ooooolDo`000003
ooooool0003o000000kooooo0_l0000Eooooo`;o00003Oooool2o`0000Cooooo0ol0000@ooooo`?o
0000F?ooool001cooooo00?o0000ooooooooool0KOooool5o`00017ooooo1Ol00004oooooaKo0000
3?ooool3o`0002Cooooo0_l00004ooooo`?o000000?oooooo`000?l000000_l0000;ooooo`Co0000
00?oooooo`000?l00000E?ooool001cooooo00?o0000ooooooooool0KOooool2o`0000Wooooo0_l0
000<ooooo`?o00000ooooolFo`0000_ooooo0ol0000Aooooo`;o00006?ooool8o`0000cooooo1_l0
001Dooooo`007?ooool00ol0003oooooooooo`1`ooooo`;o000000Coooooo`000?l0003o00000_oo
ool2o`0000gooooo0ol000000ooooooo0000o`00000Ao`0000;ooooo0ol00005ooooo`;o00000ooo
ool2o`0001;ooooo0_l0000<ooooo`;o00002oooool3o`00013ooooo1?l0001Fooooo`007?ooool0
0ol0003oooooooooo`1`ooooo`;o000000Coooooo`000?l0003o00004Oooool6o`0000?ooooo4ol0
0005ooooo`;o00002_ooool2o`0000Wooooo1?l0000<ooooo`;o00001?ooool2o`0000Sooooo0_l0
000>ooooo`?o0000Eoooool001cooooo00?o0000ooooooooool0K?ooool2o`0000;ooooo0_l00000
0ooooooo0000o`000004ooooo`;o00001oooool2o`0000?ooooo1Ol00005ooooo`?o000000?ooooo
o`000?l000002Ol0000Dooooo`;o00002Oooool2o`0001;ooooo1?l000000ooooooo0000o`000005
ooooo`;o000000?oooooo`000?l000002oooool3o`0000;ooooo0_l0001Cooooo`007?ooool00ol0
003oooooooooo`1/ooooo`Oo00000_ooool2o`0000;ooooo0_l00007ooooo`;o000000Coooooo`00
0?l0003o00000oooool4o`0000;ooooo0_l00002ooooo`Ko00000_ooool3o`0000_ooooo1?l00002
ooooo`;o00002?ooool2o`0000Oooooo0_l0000=ooooo`;o00000oooool2o`0000Sooooo0_l0000<
ooooo`?o000000?oooooo`000?l00000Doooool001cooooo00?o0000ooooooooool0J?ooool3o`00
00?ooooo2Ol000001Ooooooo0000o`000?l0003ooooo00;o00000oooool7o`0000?ooooo1Ol00000
0ooooooo0000o`000002ooooo`Ko00000_ooool5o`0000;ooooo0_l00002ooooo`;o000000?ooooo
o`000?l000000_l00002ooooo`;o00002?ooool4o`0000Gooooo0_l0000Jooooo`;o00001Oooool2
o`0000Oooooo1_l0001Cooooo`007?ooool00ol0003oooooooooo`1Xooooo`?o00001?ooool8o`00
0003ooooool0003o000000Co00000oooool9o`0000Cooooo1Ol00007ooooo`;o000000Coooooo`00
0?l0003ooooo1ol000000ooooooo0000o`000003o`00013ooooo0_l0000Qooooo`Co00000oooool2
o`0000Oooooo1?l0001Eooooo`007?ooool00ol0003oooooooooo`1Vooooo`;o00000_ooool2o`00
00Gooooo1_l00002ooooo`Go00002_ooool2o`0000Cooooo1?l00008ooooo`;o00000oooool5o`00
0003ooooool0003o000000;ooooo0ol0000=ooooo`;o00003oooool2o`0001Gooooo1?l00002oooo
o`;o00002?ooool2o`0005Kooooo000Looooo`03o`000?oooooooooo05oooooo0_l00005ooooo`;o
00000_ooool2o`0000;ooooo0_l00002ooooo`?o00002_ooool2o`0000Gooooo0_l00008ooooo`;o
00000_ooool2o`0000Kooooo0_l000000ooooooo0000o`000002o`0001Kooooo0_l00005ooooo`;o
00002?ooool2o`0001Oooooo0_l00002ooooo`;o00002?ooool2o`0005Kooooo000Looooo`03o`00
0?oooooooooo05Wooooo0_l00004ooooo`Co00002_ooool3o`000004ooooool0003o0000o`0000So
oooo0_l000000ooooooo0000o`000004ooooo`?o00000_ooool2o`0000Sooooo0_l00004ooooo`Co
00000oooool2o`0000cooooo0_l0000?ooooo`;o00008Oooool2o`0000;ooooo0_l00008ooooo`;o
0000E_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@
413oooooooooo`04ooooo`03o`000?oooooooooo05Wooooo2_l0000:ooooo`?o000000Coooooo`00
0?l0003o00002?ooool2o`0000Oooooo0_l00003ooooo`;o00003_ooool4o`00017ooooo0_l0000>
ooooo`;o00005_ooool2o`0000kooooo0_l00008ooooo`;o00009Oooool2o`0002oooooo00001_oo
ooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0DOooool2o`000003ooooool0003o000000?ooooo1_l000000ooooooo0000o`00
000<ooooo`Ko00000oooool2o`00017ooooo0_l0000:ooooo`;o00007_ooool2o`0000Oooooo1?l0
0002ooooo`Co00000oooool2o`0000?ooooo0_l000000ooooooo0000o`000003o`0001Sooooo0_l0
000Uooooo`;o0000;oooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool5
o`0000Kooooo00?o0000ooooooooool0DOooool5o`0000[ooooo1?l00008ooooo`;o00000_ooool2
o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l0000Fooooo`;o00005ooo
ool2o`0000Gooooo1?l00004ooooo`;o000000?oooooo`000?l000000_ooool4o`0000?ooooo1?l0
00001?oooooo0000o`000?ooool4o`0000oooooo0_l00008ooooo`;o00008oooool4o`0002oooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo0000
1oooool3o`00057ooooo0ol0000>ooooo`;o000000?oooooo`000?l000001?ooool4o`0000Gooooo
0_l00004ooooo`;o00000_ooool2o`0002Oooooo0_l00006ooooo`;o00001_ooool3o`0000Cooooo
0_l0000>ooooo`;o00000_ooool3o`0000;ooooo0_l00006ooooo`;o00001_ooool2o`0000Sooooo
0_l00002ooooo`;o00007oooool4o`0002oooooo00000ooooooo0000ooooo`02ooooo`03o`000?oo
oooooooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`1<ooooo`;o0000
5oooool2o`0000Cooooo1?l0000:ooooo`;o00008?ooool2o`0000[ooooo0_l0000@ooooo`;o0000
2?ooool2o`0000Gooooo0_l00006ooooo`?o00000_ooool2o`0000Kooooo0_l00005ooooo`?o0000
2?ooool2o`0000;ooooo0_l0000Pooooo`?o0000;oooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo04cooooo0ol0
000?ooooo`Co00001Oooool2o`0000Gooooo0_l00009ooooo`;o00001?ooool2o`0001Gooooo0_l0
0003ooooo`Co00001?ooool2o`0000Sooooo0_l00002ooooo`Co00001?ooool2o`0000Gooooo0_l0
00001?oooooo0000o`000?ooool7o`0000_ooooo0_l00003ooooo`;o00001oooool3o`0000?ooooo
0_l0000Zooooo`;o0000;oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg3?ooool00oo^k^ko
A4A4o`000007ooooo`03o`000?oooooooooo04Gooooo0_l00002ooooo`Ko00002?ooool2o`0000Go
oooo1?l000000ooooooo0000o`000002ooooo`?o00000_ooool4o`0000?ooooo0_l00002ooooo`;o
00001_ooool2o`0001Gooooo0_l00005ooooo`;o00000oooool4o`0000Cooooo0_l000000ooooooo
0000o`000002ooooo`Co00000oooool2o`0000;ooooo0_l00002ooooo`;o00000oooool8o`000003
ooooool0003o000000Sooooo0_l00002ooooo`?o00003Oooool2o`0002Oooooo0_l0000booooo`00
00Koooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000oooo
ooooool0AOooool2o`0000;ooooo1Ol00009ooooo`;o00001Oooool7o`0000?ooooo0_l00002oooo
o`Go00000_ooool2o`0000;ooooo0_l00007ooooo`;o00008?ooool4o`0000Cooooo0_l00003oooo
o`?o00001_ooool2o`0000;ooooo0_l00002ooooo`go000000?oooooo`000?l000001?l00008oooo
o`;o00001_ooool2o`0002kooooo0ol0000booooo`007?ooool00ol0003oooooooooo`18ooooo`Ko
00001?ooool2o`0000;ooooo0ol00005ooooo`So00001?ooool3o`000004ooooool0003o0000o`00
00Gooooo0_l00008ooooo`;o0000:oooool8o`0000Wooooo5ol00006ooooo`?o00001_ooool2o`00
00Oooooo0_l0000Uooooo`Go0000<?ooool001cooooo00?o0000ooooooooool0@_ooool2o`0000Co
oooo0_l00008ooooo`;o00000_ooool2o`0000Kooooo2?l00004ooooo`?o000000?oooooo`000?l0
00001_ooool2o`0003Gooooo0ol000000ooooooo0000o`000002o`0000Kooooo2ol000000ooooooo
0000o`00000>o`0000;ooooo2?l00004ooooo`;o00001_ooool2o`0002Kooooo1?l0000`ooooo`00
7?ooool00ol0003oooooooooo`12ooooo`;o00001_ooool2o`0000Kooooo0_l00005ooooo`ko0000
1oooool2o`0000?ooooo0_l00008ooooo`;o0000:_ooool2o`00013ooooo0ol000000ooooooo0000
o`00000Jo`000003ooooool0003o000000?o00001?ooool2o`0000?ooooo0_l00008ooooo`;o0000
8?ooool2o`00037ooooo000Looooo`03o`000?oooooooooo04[ooooo0_l00002ooooo`;o00000_oo
ool2o`000003ooooool0003o000000[o00000_ooool5o`0000_ooooo0_l00008ooooo`;o0000:_oo
ool2o`0000kooooo7?l00002ooooo`?o00000oooool2o`0000[ooooo1Ol00002ooooo`?o000000?o
ooooo`000?l000008?ooool2o`00037ooooo000Looooo`03o`000?oooooooooo047ooooo0_l00006
ooooo`;o00000oooool2o`0000Gooooo4ol0001?oooooako000000?oooooo`000?l000000ol00000
0ooooooo0000o`000002o`0000Wooooo1Ol000000ooooooo0000o`000002o`0001oooooo1Ol0000b
ooooo`007?ooool00ol0003oooooooooo`11ooooo`?o00000oooool4o`0000Gooooo0_l00003oooo
oa?o00003_ooool2o`0002[ooooo0ol00006ooooo`;o000000?oooooo`000?l000001ooooolTo`00
0003ooooool0003o000000;o00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000003oooo
o`?o00008?ooool5o`0003;ooooo000Looooo`03o`000?oooooooooo04;ooooo0_l00003ooooo`?o
00001_ooool2o`0000?ooooo5?l00006ooooo`;o00001Oooool2o`0002[ooooo1Ol00004ooooo`;o
000000?oooooo`000?l000001ooooolUo`0000Cooooo1?l00003ooooo`;o00001_ooool4o`0001oo
oooo0_l0000eooooo`007?ooool00ol0003oooooooooo`18ooooo`;o00002ooooolDo`0000Kooooo
0ol0000>ooooo`;o00006_ooool2o`0000Oooooo0_l00002ooooo`;o00002_oooolLo`000003oooo
ool0003o000000_o000000?oooooo`000?l000001?ooool:o`000003ooooool0003o000001oooooo
0_l0000eooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00001oooool2o`0000Sooooo0_l0
00000ooooooo0000o`00000Bo`0000Oooooo0_l0000>ooooo`;o00006_ooool2o`0000Oooooo0_l0
0002ooooo`;o000000?oooooo`000?l000001OoooolXo`000003ooooool0003o000000Go00000ooo
ool;o`0002;ooooo0ol0000cooooo`007?ooool00ol0003oooooooooo`0looooo`So00003_oooolG
o`0001Sooooo0_l0000=ooooo`;o00004oooool2o`0000Gooooo0_l00005ooooobKo000000?ooooo
o`000?l000001ol000000ooooooo0000o`00000;o`0002;ooooo0ol0000cooooo`007?ooool00ol0
003oooooooooo`0kooooo`Go000000?oooooo`000?l000000ol0000<oooooaOo00006?ooool2o`00
00gooooo1?l0000Booooo`;o00000_ooool2o`0000Sooooo??l0000Sooooo`?o0000<oooool001co
oooo0_l0000looooo`;o00001oooool2o`0000;ooooo0_l00002ooooo`;o00001?oooolFo`0000So
oooo1?l0000Nooooo`;o000000?oooooo`000?l000003_ooool3o`0000;ooooo0_l00008ooooob7o
000000?oooooo`000?l000000_l00002oooooaCo00008oooool2o`0003Cooooo000Looooo`03o`00
0?oooooooooo03oooooo0_l00007ooooo`;o00000_ooool3o`0000Cooooo4Ol000001?oooooo0000
o`000?l00008ooooo`Co00001_ooool2o`0000gooooo0_l0000:ooooo`;o00003_ooool2o`0000;o
oooo0_l00009ooooo`;o00000_oooolLo`000004ooooool0003o0000o`0000Gooooo4ol0000Soooo
o`;o0000=?ooool001cooooo00?o0000ooooooooool0?oooool2o`0000?ooooo0ol00002ooooo`;o
00000_ooool2o`0000Gooooo1ol000000ooooooo0000o`00000:o`0000Wooooo0ol00002ooooo`;o
00000_ooool2o`0000gooooo0_l00005ooooo`;o00005?ooool2o`000003ooooool0003o000000;o
oooo0_l00003ooooo`;o00000_oooolDo`000003ooooool0003o000000[o00001?oooolBo`0002;o
oooo0_l0000hooooo`007?ooool00ol0003oooooooooo`14ooooo`?o00000_ooool3o`0000Kooooo
5_l00009ooooo`?o00000_ooool2o`0000Gooooo0_l0000Aooooo`;o00002oooool2o`0000Oooooo
0_l000000ooooooo0000o`000002ooooo`;o00000oooool2o`0000;ooooo8?l000000ooooooo0000
o`00000Do`0002;ooooo0_l000000ooooooo0000o`00000eooooo`007?ooool00ol0003ooooooooo
o`0looooo`;o00000oooool3o`0000Kooooo0_l00006oooooaKo00005Oooool2o`00017ooooo0_l0
000;ooooo`;o00002_ooool2o`0000;ooooo0_l00002ooooo`;o00001?oooolKo`0000;ooooo5ol0
000Wooooo`;o0000=Oooool001cooooo00?o0000ooooooooool0??ooool2o`0000?ooooo0ol0000@
oooooa?o00001oooool3o`000003ooooool0003o000002Gooooo0_l0000Booooo`;o00000_ooool2
o`0000Cooooo6ol00002oooooaCo000000?oooooo`000?l000008oooool5o`0003Kooooo000Loooo
o`03o`000?oooooooooo03[ooooo0_l0000@ooooo`?o00001OoooolBo`0000Sooooo1_l0000Uoooo
o`;o00002?ooool2o`0001?ooooo6_l000000ooooooo0000o`00000Co`0002Kooooo1Ol0000foooo
o`007?ooool00ol0003oooooooooo`0jooooo`;o00004?ooool5o`0000Cooooo4?l0000;ooooo`Co
000000?oooooo`000?l00000;?ooool2o`0000Cooooo0_l00003ooooo`;o00002OoooolGo`000003
ooooool0003o000001?o0000:Oooool2o`0003Sooooo000Looooo`03o`000?oooooooooo04gooooo
1?l000001?oooooo0000o`000?ooool@o`0000cooooo0_l00002ooooo`;o00007Oooool2o`0000;o
oooo0_l00002ooooo`;o00002oooool2o`0000?ooooo0_l00002ooooo`;o00001Oooool?o`000004
ooooool0003o0000o`0000Gooooo2ol00002ooooo`Co0000:_ooool2o`000004ooooool0003o0000
o`0003Oooooo000Looooo`03o`000?oooooooooo04gooooo0_l000000ooooooo0000o`000002o`00
0005ooooool0003o0000o`000?ooool02ol0000<ooooo`;o00008_ooool2o`0000;ooooo0_l00002
ooooo`?o00004oooool3o`0000Kooooo0_l000000ooooooo0000o`00000;o`0000?ooooo2?l00003
ooooo`;o0000<Oooool2o`000004ooooool0003o0000o`0003Oooooo000Looooo`03o`000?oooooo
oooo03Sooooo0_l0000Fooooo`Co00001Oooool;o`0000cooooo0ol0000Iooooo`;o00001_ooool2
o`0000Oooooo0_l0000Dooooo`?o000000?oooooo`000?l000000_ooool?o`0000;ooooo1ol0000i
ooooo`Go0000>?ooool001cooooo00?o0000ooooooooool0>?ooool2o`0001kooooo3Ol0000;oooo
o`?o00006Oooool2o`0000Kooooo0_l0000Gooooo`;o00001?ooool3o`000003ooooool0003o0000
00?o000000?oooooo`000?l000002?l00004ooooo`Ko0000>Oooool2o`0000;ooooo0_l0000ioooo
o`007?ooool00ol0003oooooooooo`1Hooooo`go00002oooool2o`0001cooooo0_l00008ooooo`;o
00000oooool2o`0000kooooo0_l00004ooooo`;o00000oooool8o`0000;ooooo0ol00006ooooo`Co
0000>oooool3o`0000?ooooo0_l0000gooooo`007?ooool00ol0003oooooooooo`1Aooooo`Co0000
1?ooool9o`000003ooooool0003o000002Sooooo0ol00003ooooo`;o00000oooool2o`0000?ooooo
0_l0000Hooooo`oo00000oooool3o`000003ooooool0003o000003[ooooo1?l00003ooooo`Co0000
=Oooool001cooooo00?o0000ooooooooool0DOooool4o`0000Cooooo2?l000001?oooooo0000o`00
0?l0000Vooooo`Co00001?ooool2o`0001kooooo0_l00002ooooo`oo00000oooool3o`0003gooooo
0_l00007ooooo`;o0000=Oooool001cooooo00?o0000ooooooooool0EOooool2o`0000Kooooo0ol0
0002ooooo`Co00002?ooool2o`0000Kooooo0_l0000Booooo`?o00008?ooool2o`0000Cooooo0ol0
00000ooooooo0000o`000002o`0004kooooo0_l00007ooooo`;o000000?oooooo`000?l00000<_oo
ool001cooooo0_l0000eooooo`;o00007oooool2o`0000Cooooo1ol000001?oooooo0000o`000?l0
0008ooooo`;o00000_ooool2o`0000;ooooo0_l0000Booooo`Co00007oooool2o`0000Gooooo0_l0
00000ooooooo0000o`000002o`0000?ooooo0_l0001Booooo`;o000000?oooooo`000?l00000<_oo
ool001cooooo00?o0000ooooooooool0=?ooool2o`0001oooooo0_l00004ooooo`Oo00003?ooool2
o`0000;ooooo0_l0000Fooooo`Co00002Oooool2o`0000Gooooo0_l0000Dooooo`Co00001_ooool2
o`0005Cooooo1?l0000aooooo`007?ooool00ol0003oooooooooo`1Mooooo`?o0000=?ooool2o`00
0003ooooool0003o000000;o00000oooool2o`0001Kooooo0_l0001Aooooo`;o00000_ooool2o`00
00Gooooo1?l0000aooooo`007?ooool00ol0003oooooooooo`1Mooooo`?o00001_ooool2o`0000Ko
oooo0_l0000=ooooo`;o00005Oooool2o`000003ooooool0003o000000;o0000K_ooool2o`0000;o
oooo0_l00006ooooo`Co0000<?ooool001cooooo00?o0000ooooooooool0I_ooool2o`0000Gooooo
1Ol0000;ooooo`;o000000?oooooo`000?l000002oooool2o`0000Sooooo0_l0000Nooooo`;o0000
G?ooool4o`00033ooooo000Looooo`03o`000?oooooooooo03Cooooo0_l0000Zooooo`;o00002Ooo
ool4o`000004ooooool0003o0000ooooo`;o00002oooool2o`0000_ooooo0_l000000ooooooo0000
o`000005ooooo`;o00007_ooool2o`00093ooooo000Looooo`03o`000?oooooooooo03Cooooo0_l0
000Zooooo`Go00001_ooool3o`0000Gooooo0_l0000Kooooo`;o00005?ooool4o`0000;ooooo0_l0
0004ooooo`;o0000Doooool2o`00043ooooo000Looooo`03o`000?oooooooooo03?ooooo0_l0000Z
ooooo`Wo00000_ooool3o`0000;ooooo0_l0000Pooooo`;o00004?ooool7o`000004ooooool0003o
0000o`0000Cooooo0_l0001Cooooo`;o000000?oooooo`000?l00000?Oooool001cooooo00?o0000
ooooooooool0<oooool2o`0002[ooooo0_l000000ooooooo0000o`000004o`0000;ooooo0ol00002
ooooo`;o00005?ooool2o`0000Cooooo0_l00003ooooo`?o00001?ooool2o`0000Wooooo1Ol00004
ooooo`;o00001Oooool3o`0005;ooooo0_l000000ooooooo0000o`00000mooooo`007?ooool00ol0
003oooooooooo`1Rooooo`Co00006?ooool2o`0000;ooooo1Ol00004ooooo`;o00000oooool2o`00
00Gooooo0_l00004ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`?o000000?ooooo
o`000?l000001Oooool2o`0002kooooo0_l0000Rooooo`;o00003?ooool2o`0003;ooooo000Loooo
o`03o`000?oooooooooo03;ooooo0_l0000Xooooo`Co00000oooool5o`0000cooooo1?l00006oooo
o`;o000000?oooooo`000?l000000ol0000:ooooo`?o00002_ooool2o`0000?ooooo0_l00003oooo
o`Co000000?oooooo`000?l00000=Oooool2o`0002;ooooo1?l0000:ooooo`;o0000<_ooool001co
oooo00?o0000ooooooooool0<_ooool2o`0002Oooooo1_l00002ooooo`Ko00002oooool4o`0000Wo
oooo0_l00008ooooo`;o00000oooool3o`0000gooooo1?l00003ooooo`Co0000;Oooool2o`0000;o
oooo0_l0000[ooooo`;o00001Oooool2o`0000?ooooo0_l0000booooo`007?ooool00ol0003ooooo
ooooo`1Kooooo`Ko00001Oooool6o`0000oooooo0_l00004ooooo`;o00002?ooool2o`0001?ooooo
0ol00006ooooo`;o0000:oooool4o`0000;ooooo0_l0000Xooooo`;o00002?ooool2o`000003oooo
ool0003o000003Cooooo000Looooo`03o`000?oooooooooo05_ooooo1_l00002ooooo`;o00000ooo
ool4o`0000gooooo1?l00002ooooo`Co000000?oooooo`000?l000002?ooool5o`0000Gooooo0_l0
0005ooooo`?o00001oooool2o`0000Cooooo0_l0000Tooooo`Co00003_ooool2o`0001gooooo0_l0
00000ooooooo0000o`000008ooooo`;o0000=?ooool001cooooo00?o0000ooooooooool0<_ooool2
o`0002Oooooo1Ol00003ooooo`;o000000?oooooo`000?l000004Oooool2o`0000Cooooo0_l00003
ooooo`;o00002?ooool5o`0000Gooooo0_l00005ooooo`Go00002oooool4o`0002;ooooo1?l0000>
ooooo`;o00008?ooool2o`0000Cooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0boooo
o`;o00009oooool3o`0000Sooooo0ol0000Qooooo`;o00000oooool2o`0000kooooo1Ol00008oooo
o`;o00000_ooool3o`0002_ooooo0_l00003ooooo`;o0000:_ooool4o`0003Kooooo000Looooo`;o
0000<oooool3o`0002Oooooo0_l00009ooooo`;o000000?oooooo`000?l000004?ooool2o`0000co
oooo1?l000000ooooooo0000o`00000=ooooo`?o00001Oooool2o`0000;ooooo2Ol0000[ooooo`;o
00000oooool2o`0000Gooooo0_l0000Pooooo`;o00000oooool2o`0003Kooooo000Looooo`03o`00
0?oooooooooo037ooooo1?l0000Wooooo`;o00001?ooool2o`0000Cooooo1_l00003ooooo`;o0000
00?oooooo`000?l000001_ooool2o`0000gooooo0ol00004ooooo`Co00000_ooool8o`0000Kooooo
2_l000000ooooooo0000o`00000`ooooo`Co000000?oooooo`000?l000000_l0000Mooooo`;o0000
00?oooooo`000?l00000>oooool001cooooo00?o0000ooooooooool0<Oooool2o`0002Wooooo0_l0
0004ooooo`;o00001?ooool2o`000003ooooool0003o000000?o000000Coooooo`000?l0003ooooo
0_l00006ooooo`;o00003?ooool2o`0000Kooooo3?l00003ooooo`oo000000?oooooo`000?l00000
<?ooool4o`000003ooooool0003o000000;o00007Oooool4o`0003cooooo000Looooo`03o`000?oo
oooooooo05oooooo0_l0000:ooooo`Go00003oooool2o`0000Cooooo0_l00003ooooo`Co00001_oo
ool;o`0000;ooooo3ol000000ooooooo0000o`00000_ooooo`Co00000oooool2o`0001cooooo0_l0
00000ooooooo0000o`000004o`0003Wooooo000Looooo`03o`000?oooooooooo037ooooo0_l0000[
ooooo`Co00004?ooool2o`0000Sooooo0_l000000ooooooo0000o`000004ooooo`;o00001?ooool3
o`0000Oooooo2_l000000ooooooo0000o`00000>o`0000Cooooo0_l0000/ooooo`Co00000oooool2
o`0001cooooo0_l00003ooooo`Co0000>Oooool001cooooo00?o0000ooooooooool0<Oooool2o`00
02_ooooo1?l00007ooooo`;o00001oooool4o`0000Kooooo0_l000000ooooooo0000o`00000Coooo
o`;o000000?oooooo`000?l000001Ol000000ooooooo0000o`00000?o`0000Cooooo0_l0000^oooo
o`;o00000oooool2o`00023ooooo0ol0000kooooo`007?ooool00ol0003oooooooooo`1Nooooo`Go
00001_ooool2o`0000Wooooo0ol000001?oooooo0000o`000?l00004ooooo`;o00004oooool2o`00
0003ooooool0003o000000;o000000Coooooo`000?l0003ooooo4_l00002ooooo`Co0000;Oooool2
o`0000?ooooo0_l0000Pooooo`;o000000Coooooo`000?l0003ooooo1?l0000dooooo`007?ooool0
0ol0003oooooooooo`1Mooooo`?o000000Coooooo`000?l0003o00004Oooool2o`000004ooooool0
003o0000o`0000Sooooo0_l0000Aooooo`Go000000?oooooo`000?l000000_l000000ooooooo0000
o`00000>o`0000;ooooo1?l0000booooo`;o00008oooool2o`000003ooooool0003o000000;o0000
=?ooool001cooooo00?o0000ooooooooool0<_ooool2o`0002Oooooo1Ol00002ooooo`Co00005?oo
ool2o`0000Oooooo0_l00008ooooo`Co00001Oooool5o`000003ooooool0003o000001?o0000:ooo
ool3o`0000;ooooo0_l00006ooooo`;o0000G_ooool001cooooo00?o0000ooooooooool0<_ooool2
o`0002Kooooo1?l00006ooooo`;o00005?ooool2o`0000Gooooo0_l0000:ooooo`Co00001_ooool3
o`0000?ooooo5?l0000Vooooo`;o000000?oooooo`000?l000000ol00002ooooo`;o00001Oooool2
o`0001Wooooo0_l00009ooooo`;o0000>Oooool001cooooo00?o0000ooooooooool0F_ooool5o`00
01oooooo0_l000000ooooooo0000o`00000Dooooo`?o000000?oooooo`000?l000005ol00002oooo
o`;o00007Oooool4o`000003ooooool0003o000000;o00002?ooool4o`0001Wooooo0_l00009oooo
o`;o0000>Oooool001cooooo00?o0000ooooooooool0FOooool3o`000003ooooool0003o000000Wo
oooo1?l0000Booooo`?o00001_ooool2o`0000?ooooo0_l0000=oooooaWo00000_ooool2o`0001go
oooo0_l00005ooooo`Go00001?ooool3o`0001cooooo1?l00008ooooo`;o0000=oooool001cooooo
00?o0000ooooooooool0FOooool2o`0000Wooooo2_l0000>ooooo`;o000000?oooooo`000?l00000
1_ooool2o`0000?ooooo0_l0000>oooooaSo0000:Oooool4o`0000Cooooo0_l0000Mooooo`Co0000
2?ooool2o`0003Oooooo000Looooo`03o`000?oooooooooo06?ooooo1_l00003ooooo`;o00003_oo
ool2o`0000;ooooo0_l0000Kooooo`Oo000000?oooooo`000?l000003ol000000ooooooo0000o`00
000Vooooo`Co000000?oooooo`000?l000000_ooool2o`0001Oooooo0_l00006ooooo`;o0000?_oo
ool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o
410@olc<c006ooooo`03o`000?oooooooooo03Oooooo0_l0000Nooooo`;o00001Oooool2o`0000?o
oooo1_l00002ooooo`?o00001?ooool3o`000003ooooool0003o000000Sooooo0_l0000Fooooo`;o
00000_oooolGo`000004ooooool0003o0000ooooo`;o0000:?ooool2o`000003ooooool0003o0000
00;ooooo0_l0000Gooooo`;o00001_ooool2o`0003kooooo00001_ooooooMgMgoiRHV?ooooooV9RH
ogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooooooo
o`0eooooo`Co00007Oooool3o`0000Gooooo0_l000001?oooooo0000o`000?ooool5o`0000;ooooo
0ol00003ooooo`Co000000Coooooo`000?l0003o00001oooool2o`0001Kooooo0_l00002oooooaOo
00001?ooool2o`0002Kooooo1?l0000Nooooo`Co00001?ooool2o`0003kooooo00000ooooooo410@
ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo03Gooooo0_l0000Oooooo`;o00002Oooool8o`000003ooooool0003o000000Co
000000?oooooo`000?l000000oooool5o`0001kooooo0_l00003oooooaGo00001?ooool2o`0000ko
oooo0_l00003ooooo`;o00004?ooool4o`0001oooooo1?l00004ooooo`;o000000?oooooo`000?l0
0000>oooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oV9RH
oooooonHV9So8B4Q00Kooooo0ol0000dooooo`Co00007Oooool2o`0000Kooooo5?l00003ooooo`;o
00000oooool2o`0000Gooooo0_l0000Fooooo`?o00000_oooolFo`0000?ooooo0_l0000?ooooo`;o
00000oooool2o`0000gooooo1ol0000Oooooo`;o00001oooool4o`0003_ooooo00000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03
o`000?oooooooooo03Cooooo1?l0000Mooooo`;o00000ooooolLo`0000?ooooo0_l000000ooooooo
0000o`000002ooooo`;o00005_ooool3o`0000;ooooo5Ol00004ooooo`;o00008oooool7o`000003
ooooool0003o000002Gooooo0_l0000mooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooo
ooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0>Oooool2o`0001Wooooo
0_l00004oooooaco00001?ooool4o`0000;ooooo0_l000000ooooooo0000o`00000Dooooo`;o0000
00?oooooo`000?l000003_l000000ooooooo0000o`000003o`0000Gooooo0ol0000Qooooo`co0000
9_ooool2o`0003[ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nH
V9P02?ooool00ol0003oooooooooo`0iooooo`?o00006?ooool2o`0000Gooooo0_l000000ooooooo
0000o`00000Lo`0000?ooooo0_l00002ooooo`;o00005OoooolBo`0000_ooooo0ol0000Qooooo`Co
00000_ooool6o`0002Kooooo0_l0000jooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<oooo
o`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0>_ooool2o`0001Sooooo0ol00000
0ooooooo0000o`00000Qo`0000Cooooo1?l0000Gooooo`;o000000?oooooo`000?l000002_l00000
0ooooooo0000o`000003o`0000Wooooo1Ol0000;ooooo`;o00004?ooool6o`0000?ooooo0_l0000I
ooooo`;o00002oooool2o`0003cooooo000Looooo`03o`000?oooooooooo05Cooooo0ol000000ooo
oooo0000o`000008o`000003ooooool0003o000001?o00002Oooool2o`0001Oooooo1_l00002oooo
o`Oo000000?oooooo`000?l000000ol00008ooooo`[o000000Goooooo`000?l0003o0000ooooo`05
o`0000oooooo0ol000001?oooooo0000o`000?ooool4o`0001Wooooo0_l00006ooooo`;o00000ooo
ool2o`0003cooooo000Looooo`03o`000?oooooooooo03cooooo0_l0000Eooooo`;o00001OoooolO
o`0000?ooooo0_l0000Nooooo`;o00001?ooool4o`000003ooooool0003o000000?ooooo0_l00009
ooooo`;o00001?ooool4o`000005ooooool0003o0000o`000?ooool02Ol0000;ooooo`Co00000ooo
ool3o`0002;ooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0looooo`;o00005Oooool2
o`0000Cooooo8?l00002ooooo`Co00007Oooool3o`0000?ooooo1?l000001?oooooo0000o`000?l0
000>ooooo`;o00004?ooool6o`0000[ooooo1?l000001?oooooo0000o`000?l0000Sooooo`;o0000
@_ooool001cooooo00?o0000ooooooooool0>_ooool2o`0001gooooo0ol00002oooooa_o000000?o
ooooo`000?l000000ol0000Mooooo`?o00000oooool8o`0000kooooo0_l0000Booooo`Ko00001ooo
ool3o`0000?ooooo0ol0000Sooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0>_ooool2
o`000003ooooool0003o000001[ooooo1Ol000000ooooooo0000o`00000Bo`000003ooooool0003o
000000Wo00007_ooool2o`0000;ooooo2?l00008ooooo`;o00000oooool2o`0000Sooooo0_l0000;
ooooo`Go00001oooool2o`0000;ooooo0_l0001Zooooo`007?ooool00ol0003oooooooooo`0ioooo
o`;o00000_ooool3o`0001;ooooo0_l00005oooooa[o000000?oooooo`000?l000002Ol0000Poooo
o`Co00001?ooool2o`0000Sooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo1_l00009oooo
o`;o00002Oooool2o`0000;ooooo0_l0000Xooooo`;o0000@?ooool001cooooo00?o0000oooooooo
ool0>Oooool2o`000003ooooool0003o000000;o00004_ooool3o`0000Cooooo9Ol0000Qooooo`;o
00001_ooool2o`0000Oooooo0_l00008ooooo`?o00000_ooool7o`0000Oooooo1?l00008ooooo`;o
00000_ooool2o`0002;ooooo0_l00003ooooo`?o0000@?ooool001cooooo00?o0000ooooooooool0
??ooool2o`0001Cooooo0ol00004oooooago00000_ooool4o`0003?ooooo0ol00009ooooo`;o0000
1oooool2o`0000Kooooo1ol00005ooooo`;o00000oooool2o`0002;ooooo0_l00003ooooo`;o0000
@Oooool001cooooo00?o0000ooooooooool0?oooool2o`00017ooooo0_l00002ooooo`;o00000_oo
oolKo`0000?ooooo1?l0000cooooo`;o00002_ooool2o`0000Oooooo0_l00006ooooo`Oo00001Ooo
ool7o`0006[ooooo000Looooo`03o`000?oooooooooo03oooooo0_l0000Aooooo`;o00000_ooool2
o`000003ooooool0003o000001oo0000@Oooool3o`0000Kooooo0ol00004ooooo`Ko00001Oooool2
o`0000;ooooo0ol0001/ooooo`007?ooool00ol0003oooooooooo`1Booooo`;o000000?oooooo`00
0?l000000_oooolOo`0003Oooooo1?l00009ooooo`Co00001?ooool3o`0000?ooooo2Ol00003oooo
o`;o000000Coooooo`000?l0003o0000KOooool001cooooo0_l0001Dooooo`Go00000_ooool2o`00
0003ooooool0003o000001Wo0000<_ooool2o`0000?ooooo1?l0000;ooooo`;o00001Oooool2o`00
00?ooooo1?l00002ooooo`So000000Coooooo`000?l0003o00008Oooool2o`000003ooooool0003o
000000;ooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o000000?oooooo`00
0?l000001OoooolHo`00033ooooo0_l00003ooooo`;o00000oooool3o`0000Sooooo0_l00002oooo
o`;o00001Oooool2o`0000?ooooo1?l00003ooooo`Ko00000oooool2o`00027ooooo0_l000001?oo
oooo0000o`000?ooool3o`0004?ooooo000Looooo`03o`000?oooooooooo05[ooooo0_l00004oooo
oa?o0000<_ooool3o`0000Cooooo0_l00002ooooo`;o00001oooool3o`0000Sooooo0ol00003oooo
o`Oo000000Coooooo`000?l0003o00000_ooool2o`0002Oooooo0_l000000ooooooo0000o`000014
ooooo`007?ooool00ol0003oooooooooo`1JoooooaGo0000=_ooool5o`0000;ooooo0_l00009oooo
o`Co00002Oooool3o`0000?ooooo1ol000001Ooooooo0000o`000?l0003ooooo00?o0000L?ooool0
01cooooo00?o0000ooooooooool0D_ooool2o`0000Kooooo2Ol00002ooooo`Wo0000=_ooool6o`00
00Cooooo0_l00005ooooo`Ko00004?ooool4o`0000Gooooo1?l0000Rooooo`?o00001?ooool2o`00
04Kooooo000Looooo`03o`000?oooooooooo05;ooooo0_l00007ooooo`Go00001_ooool3o`0003_o
oooo2Ol000000ooooooo0000o`000005ooooo`;o00000_ooool2o`0000[ooooo0_l00004ooooo`co
00008?ooool2o`000004ooooool0003o0000o`0000Cooooo0_l00016ooooo`007?ooool00ol0003o
ooooooooo`1Cooooo`;o00001oooool3o`0004;ooooo0_l000000ooooooo0000o`000007o`000003
ooooool0003o000000Gooooo0_l00002ooooo`;o000000?oooooo`000?l000000ol00004ooooo`;o
00001Oooool9o`0002;ooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`1Booooo`?o0000
C?ooool2o`000003ooooool0003o000000[o00000_ooool2o`000003ooooool0003o000000;ooooo
0_l000000ooooooo0000o`000003o`0000?ooooo1?l00006ooooo`;o00009Oooool4o`0000;ooooo
1?l0001:ooooo`007?ooool00ol0003oooooooooo`1Booooo`;o0000C_ooool?o`000004ooooool0
003o0000o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l000001_l0000]ooooo`;o0000
1?ooool4o`0004[ooooo000Looooo`03o`000?oooooooooo05;ooooo0ol0001<oooooaCo000000Co
ooooo`000?l0003ooooo0_l00002ooooo`_o00007Oooool2o`0001Cooooo0_l0001<ooooo`007?oo
ool00ol0003oooooooooo`1Booooo`?o00000oooool2o`0004Gooooo4Ol000000ooooooo0000o`00
0003ooooo`;o00000oooool2o`0000;ooooo0_l00005ooooo`?o00007?ooool2o`0000kooooo1Ol0
00000ooooooo0000o`00001<ooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00000oooool2
o`0004Gooooo0ol000000ooooooo0000o`00000;o`0000Sooooo0_l000000ooooooo0000o`00000:
ooooo`;o00006?ooool2o`000003ooooool0003o000000oooooo1Ol000000ooooooo0000o`00001<
ooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00001?ooool2o`0004Gooooo4Ol00002oooo
o`;o00000oooool2o`00013ooooo0_l0000@ooooo`;o00000oooool5o`0000cooooo0_l00003oooo
o`;o0000D?ooool001cooooo00?o0000ooooooooool0FOooool2o`0004Gooooo4Ol00002ooooo`;o
00005?ooool6o`0000gooooo0_l00003ooooo`?o00003_ooool2o`0000;ooooo0_l0001Aooooo`00
7?ooool00ol0003oooooooooo`1Dooooo`Co00004Oooool2o`0003Gooooo4_l000000ooooooo0000
o`000006ooooo`;o00001Oooool6o`000004ooooool0003o0000ooooo`Co00001oooool2o`0001Go
oooo0_l000000ooooooo0000o`000003ooooo`;o0000DOooool001cooooo00?o0000ooooooooool0
E?ooool4o`0000Cooooo0_l0000;ooooo`;o0000=?oooolCo`000003ooooool0003o000000Cooooo
1Ol00004ooooo`Ko00001?ooool4o`0000Oooooo1?l00004ooooo`Co00002oooool2o`000003oooo
ool0003o000005Kooooo000Looooo`;o0000GOooool2o`0000Gooooo0_l0000joooooa?o000000?o
ooooo`000?l000000ol000000ooooooo0000o`000003o`0000Cooooo0ol0000Dooooo`;o00000ooo
ool5o`0006Kooooo000Looooo`03o`000?oooooooooo05Gooooo0_l0000<ooooo`;o0000>_oooolC
o`000003ooooool0003o000000?o00001?ooool2o`0000Gooooo0_l0000>ooooo`?o00000_ooool2
o`0000?ooooo1?l0000?ooooo`;o000000?oooooo`000?l00000E?ooool001cooooo00?o0000oooo
ooooool0EOooool3o`0004Oooooo4ol000000ooooooo0000o`000003ooooo`;o00001?ooool2o`00
00Kooooo0_l0000;ooooo`?o00000_ooool2o`0000;ooooo0ol0000<ooooo`;o00000oooool2o`00
0003ooooool0003o000005Cooooo000Looooo`03o`000?oooooooooo05Gooooo0ol00018oooooaGo
00000oooool2o`0000;ooooo1?l00005ooooo`?o00003oooool8o`0000_ooooo0ol00006ooooo`;o
0000E?ooool001cooooo00?o0000ooooooooool0EOooool3o`0004Sooooo4ol00002ooooo`;o0000
1Oooool4o`0000Gooooo0_l000000ooooooo0000o`000006ooooo`;o00001Oooool6o`0000gooooo
0_l000000ooooooo0000o`00001Jooooo`007?ooool00ol0003oooooooooo`1Eooooo`Co0000Aooo
oolDo`000003ooooool0003o000000;ooooo0_l00002ooooo`Co00001oooool2o`0000Kooooo0_l0
0005ooooo`Go00002_ooool2o`0000Gooooo1?l0001Hooooo`007?ooool00ol0003oooooooooo`1G
ooooo`;o0000AooooolFo`000003ooooool0003o000000;o00000_ooool5o`0000Kooooo0_l0000:
ooooo`Go00003Oooool2o`0000;ooooo0ol00002ooooo`;o0000F?ooool001cooooo00?o0000oooo
ooooool0Eoooool3o`0004Cooooo0_l000000ooooooo0000o`00000>o`0000?ooooo0_l000000ooo
oooo0000o`000006ooooo`Go00001?ooool2o`0000Oooooo1_l0000Cooooo`?o0000G?ooool001co
oooo00?o0000ooooooooool0Eoooool3o`000003ooooool0003o0000047ooooo4ol00006ooooo`;o
00001_ooool:o`0000Cooooo2Ol0001cooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o0000
00?oooooo`000?l00000@oooool4o`000003ooooool0003o000000Wo00001oooool2o`0000Oooooo
2Ol00004ooooo`Ko000000?oooooo`000?l000004?ooool2o`00067ooooo000Looooo`03o`000?oo
oooooooo0:7ooooo3ol0000@ooooo`[o000000?oooooo`000?l000001Ol0000?ooooo`;o000000?o
ooooo`000?l000000_l00002ooooo`;o0000GOooool001cooooo00?o0000ooooooooool0XOooool2
o`000003ooooool0003o000000Co00000_ooool2o`0000Kooooo0_l0000<ooooo`co00000_ooool2
o`0000oooooo1_l00003ooooo`;o0000GOooool001cooooo00?o0000ooooooooool0Foooool3o`00
047ooooo2?l0000:ooooo`;o000000?oooooo`000?l000003?ooool;o`0001?ooooo0_l000000ooo
oooo0000o`000002o`0000;ooooo0_l0001Nooooo`007?ooool00ol0003oooooooooo`1Kooooo`?o
0000@Oooool2o`0000;ooooo1_l00008ooooo`;o00004Oooool2o`000003ooooool0003o000001;o
oooo0_l00003ooooo`;o00001oooool2o`0005kooooo000Looooo`03o`000?oooooooooo067ooooo
0_l00011ooooo`Go00002?ooool2o`0002Sooooo0_l0001/ooooo`007?ooool00ol0003ooooooooo
o`1Qooooo`;o0000@Oooool3o`0000[ooooo1?l0002Dooooo`007?ooool2o`0005oooooo0_l00002
ooooo`;o0000?oooool4o`0000[ooooo1?l0002Dooooo`007?ooool00ol0003oooooooooo`1Noooo
o`Ko000000?oooooo`000?l00000??ooool4o`0000[ooooo0_l0000Sooooo`;o0000LOooool001co
oooo00?o0000ooooooooool0H?ooool2o`0000?ooooo1?l0000jooooo`;o00000_ooool3o`0000So
oooo0_l0000;ooooo`;o000000?oooooo`000?l000001Oooool2o`0000;ooooo0_l00004ooooo`;o
000000?oooooo`000?l000000ol00006ooooo`;o0000I_ooool001cooooo00?o0000ooooooooool0
H?ooool2o`0000?ooooo1?l0000jooooo`;o00000_ooool3o`0000Sooooo0_l0000;ooooo`;o0000
00?oooooo`000?l000001Oooool2o`0000;ooooo0_l00004ooooo`;o00000_ooool4o`0000Kooooo
0_l0001Vooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o0000@Oooool2o`0001oooooo0_l0
0008ooooo`;o00001_ooool5o`0006Wooooo000Looooo`03o`000?oooooooooo0:Sooooo0ol0000@
ooooo`;o00003?ooool2o`0000Cooooo0_l00002ooooo`;o00001?ooool7o`0006Wooooo000Loooo
o`03o`000?oooooooooo06Gooooo0_l00012ooooo`;o00004?ooool2o`0000?ooooo0_l0000=oooo
o`;o00002?ooool4o`0006cooooo000Looooo`03o`000?oooooooooo06Gooooo0_l0001Eooooo`;o
00000_ooool2o`0000Cooooo0_l00021ooooo`007?ooool00ol0003oooooooooo`1Xooooo`?o0000
0oooool2o`0004Gooooo0_l00005ooooo`?o00001oooool2o`0000cooooo0_l0001cooooo`007?oo
ool00ol0003oooooooooo`1Xooooo`?o00000oooool2o`0000?ooooo1_l0000hooooo`;o00000_oo
ool2o`0000;ooooo0_l00002ooooo`;o00003?ooool2o`0000Gooooo1?l0001cooooo`007?ooool0
0ol0003oooooooooo`1cooooo`Ko00001?ooool2o`0003;ooooo0_l00006ooooo`;o00004?ooool2
o`0000Gooooo0_l0001eooooo`007?ooool00ol0003oooooooooo`1looooo`?o0000=oooool3o`00
093ooooo000Looooo`03o`000?oooooooooo06kooooo0_l0000<ooooo`?o00006?ooool2o`0001go
oooo0ol00004ooooo`;o00001oooool3o`0000;ooooo0_l0001looooo`007?ooool00ol0003ooooo
ooooo`1^ooooo`;o00002?ooool2o`0000Oooooo0_l00003ooooo`?o00003_ooool2o`0001kooooo
0_l00004ooooo`;o000000?oooooo`000?l000000_l00002ooooo`?o00000_ooool2o`0007cooooo
00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q
8Oo<c<`01_ooool00ol0003oooooooooo`1aooooo`Co00000oooool2o`0000Oooooo0_l00003oooo
o`?o00000oooool2o`0001gooooo0_l0000Cooooo`Co00000_ooool2o`00087ooooo00001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_oo
ool00ol0003oooooooooo`1aooooo`Go00001_ooool2o`0000?ooooo0_l00008ooooo`Co00003Ooo
ool3o`0000cooooo0_l0002Looooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`1cooooo`Co00001Ooo
ool2o`0000;ooooo0ol00007ooooo`Go00003Oooool4o`0000kooooo0_l0002Iooooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_oo
ool3o`0007Gooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0ol00006ooooo`?o0000
1oooool2o`0000Gooooo0_l00002ooooo`;o00001oooool2o`0000Gooooo0_l0002Iooooo`0000?o
ooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<c<`0
1_ooool00ol0003oooooooooo`1hooooo`Go00001?ooool2o`0000;ooooo0ol000000ooooooo0000
o`000003ooooo`;o00000oooool2o`0000Gooooo0_l0000;ooooo`;o00003?ooool2o`0009;ooooo
00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go410@okZj^_oooooo^[Zj
oa0@4006ooooo`03o`000?oooooooooo07[ooooo0_l00009ooooo`Co00001Oooool2o`0001Oooooo
0_l0000<ooooo`;o0000T_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o
^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0Qoooool2o`0000;ooooo0_l00003oooo
o`;o00001?ooool2o`0000oooooo0_l0000;ooooo`;o0000Toooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0P_oo
ool2o`0000Oooooo0_l00003ooooo`;o00001?ooool3o`0000oooooo0_l0000:ooooo`;o00000ooo
ool2o`0008kooooo000Looooo`03o`000?oooooooooo08;ooooo0_l00004ooooo`;o00001?ooool2
o`0000Gooooo1?l0000?ooooo`Co00001_ooool2o`0000Gooooo0_l0002>ooooo`007?ooool00ol0
003oooooooooo`28ooooo`?o00000oooool2o`0000Gooooo0_l00007ooooo`Co00000oooool2o`00
00?ooooo0_l000000ooooooo0000o`000003ooooo`?o00003_ooool3o`0000Gooooo0_l0001loooo
o`007?ooool00ol0003oooooooooo`29ooooo`;o00000_ooool3o`000003ooooool0003o000000_o
oooo1?l000000ooooooo0000o`000003o`0000Gooooo0_l00004ooooo`;o00003_ooool3o`0000Co
oooo0ol0001looooo`007?ooool00ol0003oooooooooo`2=ooooo`;o000000Coooooo`000?l0003o
00000oooool4o`0000Cooooo0_l00003ooooo`;o000000?oooooo`000?l000001Oooool2o`0000co
oooo0_l00002ooooo`;o000000?oooooo`000?l000001_ooool2o`0007gooooo000Looooo`03o`00
0?oooooooooo08oooooo0ol00002ooooo`co000000?oooooo`000?l000000ol00007ooooo`;o0000
0_ooool7o`0000;ooooo1ol000000ooooooo0000o`000025ooooo`007?ooool00ol0003ooooooooo
o`2?ooooo`Co000000?oooooo`000?l000001?ooool6o`000003ooooool0003o000000?o00002ooo
ool7o`0000;ooooo0_l000000ooooooo0000o`000002o`0008Sooooo000Looooo`03o`000?oooooo
oooo097ooooo1?l00002ooooo`Co00000oooool2o`0000;ooooo0_l0000<ooooo`;o0000Uoooool0
01cooooo00?o0000ooooooooool0Toooool2o`0000;ooooo1_l000000ooooooo0000o`000002oooo
o`;o00003?ooool3o`0009Kooooo000Looooo`03o`000?oooooooooo09Kooooo0_l00002ooooo`?o
00001Oooool2o`0000gooooo0_l0002Fooooo`007?ooool00ol0003oooooooooo`2Fooooo`;o0000
0_ooool2o`0000Kooooo0_l0002Uooooo`007?ooool00ol0003oooooooooo`2Kooooo`Ko000000?o
ooooo`000?l000002?ooool2o`0009_ooooo000Looooo`;o0000W?ooool6o`0000Oooooo0_l00000
0ooooooo0000o`000002o`0009[ooooo000Looooo`03o`000?oooooooooo0:Sooooo1ol0002Joooo
o`007?ooool00ol0003oooooooooo`2Zooooo`;o0000WOooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001;ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood[o
oooo000Dooooo`03o`000?oooooooooo00Gooooo0ol0003ooooood[ooooo000Dooooo`03o`000?oo
oooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0
003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001;ooooo
00?oEEEEofIVI_l00000oooooomDooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00YOooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo01Gooooo1Ol00004oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o410@olc<c93ooooo002Vooooo`05o`000?oo
ooooooooooooool000002Oooool6o`0000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03
o`000?oooooooooo00;ooooo00GoEEEEogMgMoooooooV9RHob4Q8@2@ooooo`00Y_ooool01Ol0003o
oooooooooooooooo000001Wooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool00000T?ooool00:Kooooo00Go0000ooooooooooooooooo`000009
ooooo`Ko00002oooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000
oiRHV?ooooooV9RHob4Q8@2@ooooo`00Y_ooool01Ol0003oQhN7oooooonYZJWo000001_ooooo00?o
MgMgofIVI_ooool01Oooool00ol0003oooooooooo`02ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
T?ooool00:Gooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00omEEEGoQhN7ooooo`2Booooo`00`oooool0
1Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool00_ooool00ooMgMgo410@oiRH
V02Booooo`00`oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo00?oEEEEofIVI_l000001Ooo
ool01?o<c<coA4A4o`000?l@412@ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(222) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.45624 .34894 Mdot
.48604 .32196 Mdot
.29619 .57203 Mdot
.66021 .45897 Mdot
.51819 .70915 Mdot
.33316 .58862 Mdot
.31286 .43011 Mdot
.30058 .43551 Mdot
.29278 .62454 Mdot
.71755 .38926 Mdot
.28599 .44724 Mdot
.65302 .43453 Mdot
.30582 .42117 Mdot
.63279 .45605 Mdot
.59486 .65682 Mdot
.6536 .49918 Mdot
.48043 .3577 Mdot
.47616 .67649 Mdot
.65771 .50081 Mdot
.31095 .63608 Mdot
.46853 .6022 Mdot
.61611 .45104 Mdot
.49303 .27661 Mdot
.63052 .45728 Mdot
.69222 .49852 Mdot
.49202 .30929 Mdot
.45664 .34848 Mdot
.71156 .50368 Mdot
.66873 .46424 Mdot
.31121 .45474 Mdot
.73415 .4995 Mdot
.65389 .73796 Mdot
.53536 .56868 Mdot
.65972 .32614 Mdot
.3278 .44251 Mdot
.28343 .46679 Mdot
.30337 .58288 Mdot
.32868 .44501 Mdot
.27868 .4206 Mdot
.2906 .44272 Mdot
.29507 .44552 Mdot
.49524 .31011 Mdot
.34023 .42696 Mdot
.17181 .47108 Mdot
.6302 .46434 Mdot
.64259 .23552 Mdot
.2886 .55966 Mdot
.64798 .4356 Mdot
.49806 .27906 Mdot
.27588 .61494 Mdot
.56398 .73785 Mdot
.29207 .42549 Mdot
.51283 .58599 Mdot
.58129 .15641 Mdot
.30284 .43008 Mdot
.67533 .49983 Mdot
.3353 .61392 Mdot
.62553 .47675 Mdot
.60044 .42628 Mdot
.63953 .29056 Mdot
.64123 .48074 Mdot
.48844 .71031 Mdot
.46103 .37319 Mdot
.27012 .59493 Mdot
.28567 .61781 Mdot
.33852 .43336 Mdot
.47845 .36482 Mdot
.3319 .41806 Mdot
.66096 .45454 Mdot
.32104 .63296 Mdot
.68301 .47908 Mdot
.28642 .44801 Mdot
.46372 .35047 Mdot
.61182 .4426 Mdot
.49545 .38188 Mdot
.30322 .47639 Mdot
.5014 .65758 Mdot
.46877 .2786 Mdot
.26578 .61926 Mdot
.60854 .62373 Mdot
.61179 .4458 Mdot
.23716 .31814 Mdot
.62949 .69618 Mdot
.4704 .30912 Mdot
.58936 .47634 Mdot
.31032 .26721 Mdot
.69286 .48196 Mdot
.72613 .49315 Mdot
.71667 .50029 Mdot
.55231 .62487 Mdot
.3394 .61451 Mdot
.5032 .29042 Mdot
.61282 .45651 Mdot
.6445 .44022 Mdot
.71313 .3778 Mdot
.67296 .48096 Mdot
.71087 .49852 Mdot
.49722 .5616 Mdot
.2889 .41941 Mdot
.51629 .56769 Mdot
.31629 .51103 Mdot
.52791 .58082 Mdot
.68701 .48136 Mdot
.32508 .59351 Mdot
.47888 .37236 Mdot
.53184 .57017 Mdot
.33161 .42752 Mdot
.61695 .45692 Mdot
.34959 .46523 Mdot
.49434 .2786 Mdot
.69553 .50763 Mdot
.50389 .70105 Mdot
.43963 .55596 Mdot
.46256 .34065 Mdot
.74175 .32149 Mdot
.65144 .45483 Mdot
.59984 .46359 Mdot
.48867 .32175 Mdot
.33072 .63924 Mdot
.2188 .42184 Mdot
.48093 .34753 Mdot
.28549 .42688 Mdot
.48409 .35735 Mdot
.52083 .55809 Mdot
.31857 .63879 Mdot
.51332 .60729 Mdot
.48414 .57792 Mdot
.61838 .74809 Mdot
.66259 .46959 Mdot
.48627 .6131 Mdot
.31886 .589 Mdot
.48004 .34523 Mdot
.30771 .41205 Mdot
.58176 .45042 Mdot
.4826 .30059 Mdot
.30967 .43474 Mdot
.48697 .67444 Mdot
.46894 .69582 Mdot
.46505 .32326 Mdot
.73398 .31285 Mdot
.34327 .40178 Mdot
.31937 .39622 Mdot
.56505 .73622 Mdot
.46932 .31254 Mdot
.48505 .6906 Mdot
.32832 .42297 Mdot
.30062 .73679 Mdot
.68022 .5047 Mdot
.5796 .75579 Mdot
.23942 .32091 Mdot
.56365 .7368 Mdot
.46692 .58539 Mdot
.49538 .69433 Mdot
.30941 .43522 Mdot
.61104 .43216 Mdot
.47219 .32241 Mdot
.48414 .30237 Mdot
.67888 .47009 Mdot
.53505 .57852 Mdot
.64553 .46352 Mdot
.51113 .56424 Mdot
.48246 .58527 Mdot
.6187 .45938 Mdot
.63344 .21974 Mdot
.48168 .29322 Mdot
.58563 .47086 Mdot
.29885 .59016 Mdot
.52458 .61992 Mdot
.3411 .42025 Mdot
.58793 .46263 Mdot
.59055 .4834 Mdot
.65478 .43478 Mdot
.31505 .39441 Mdot
.39347 .3051 Mdot
.26107 .61098 Mdot
.28146 .43544 Mdot
.31293 .50845 Mdot
.30877 .60072 Mdot
.60677 .42595 Mdot
.50653 .69281 Mdot
.50281 .5802 Mdot
.61833 .43413 Mdot
.56138 .73864 Mdot
.59824 .42894 Mdot
.4741 .53628 Mdot
.48805 .53432 Mdot
.27454 .29926 Mdot
.39994 .29972 Mdot
.65034 .44805 Mdot
.60761 .49949 Mdot
.57649 .74592 Mdot
.26232 .37308 Mdot
.31154 .40942 Mdot
.35149 .62325 Mdot
.3402 .63707 Mdot
.29008 .49866 Mdot
.72423 .33371 Mdot
.7701 .42494 Mdot
.60382 .47738 Mdot
.52147 .58011 Mdot
.4411 .33728 Mdot
.4937 .69568 Mdot
.46649 .33949 Mdot
.23349 .32038 Mdot
.65853 .6058 Mdot
.74334 .50068 Mdot
.23828 .64221 Mdot
.27464 .60327 Mdot
.52938 .58664 Mdot
.49261 .6806 Mdot
.63516 .47362 Mdot
.48392 .28558 Mdot
.57283 .74153 Mdot
.53659 .58963 Mdot
.79293 .6794 Mdot
.47901 .35223 Mdot
.66782 .63806 Mdot
.30525 .42829 Mdot
.31245 .61963 Mdot
.69222 .48242 Mdot
.63171 .44696 Mdot
.50916 .28619 Mdot
.60676 .43073 Mdot
.74604 .49418 Mdot
.68887 .50358 Mdot
.28064 .62471 Mdot
.32396 .51442 Mdot
.2819 .41856 Mdot
.25152 .64839 Mdot
.46167 .34029 Mdot
.63628 .20443 Mdot
.32304 .60551 Mdot
.47289 .54748 Mdot
.29125 .45105 Mdot
.48092 .67986 Mdot
.32846 .60235 Mdot
.51602 .71374 Mdot
.59368 .42816 Mdot
.29782 .60386 Mdot
.49811 .70923 Mdot
.68775 .43777 Mdot
.53081 .57021 Mdot
.55746 .79887 Mdot
.31959 .4283 Mdot
.50986 .30996 Mdot
.615 .43365 Mdot
.51081 .58077 Mdot
.53684 .59353 Mdot
.62516 .64662 Mdot
.4898 .59247 Mdot
.53294 .59307 Mdot
.57986 .64054 Mdot
.4836 .67056 Mdot
.38399 .24788 Mdot
.73163 .50171 Mdot
.47796 .35826 Mdot
.63612 .4365 Mdot
.31307 .50067 Mdot
.31245 .43525 Mdot
.63837 .47606 Mdot
.26137 .30476 Mdot
.32546 .42005 Mdot
.60879 .47009 Mdot
.27889 .44008 Mdot
.4774 .3027 Mdot
.67248 .60924 Mdot
.46605 .35685 Mdot
.61589 .46094 Mdot
.28043 .44399 Mdot
.35237 .61778 Mdot
.49076 .30818 Mdot
.61569 .45442 Mdot
.6544 .48221 Mdot
.51921 .58258 Mdot
.68518 .50366 Mdot
.24665 .4047 Mdot
.66742 .4481 Mdot
.3141 .56777 Mdot
.6722 .47509 Mdot
.46659 .71634 Mdot
.39496 .77478 Mdot
.46655 .3168 Mdot
.49166 .59484 Mdot
.33318 .60753 Mdot
.72039 .469 Mdot
.67833 .62906 Mdot
.63104 .4623 Mdot
.51453 .6032 Mdot
.66041 .67793 Mdot
.31283 .40029 Mdot
.7204 .50675 Mdot
.55384 .56245 Mdot
.33958 .60949 Mdot
.52614 .58172 Mdot
.612 .48507 Mdot
.4827 .27628 Mdot
.66409 .49935 Mdot
.30452 .6082 Mdot
.48613 .35075 Mdot
.67653 .48711 Mdot
.26477 .45305 Mdot
.51561 .61591 Mdot
.30487 .40021 Mdot
.72425 .50203 Mdot
.61001 .42599 Mdot
.31583 .63269 Mdot
.49684 .30733 Mdot
.30125 .43247 Mdot
.46116 .34417 Mdot
.55719 .68529 Mdot
.66328 .65251 Mdot
.49268 .37322 Mdot
.4985 .66714 Mdot
.3394 .78143 Mdot
.28335 .43076 Mdot
.49875 .57271 Mdot
.3227 .5645 Mdot
.47716 .27737 Mdot
.33016 .59607 Mdot
.72298 .30542 Mdot
.33779 .61534 Mdot
.65785 .50448 Mdot
.34729 .62268 Mdot
.77021 .40605 Mdot
.5891 .45135 Mdot
.28144 .61045 Mdot
.49601 .5617 Mdot
.59212 .4648 Mdot
.48424 .29943 Mdot
.67268 .72913 Mdot
.69773 .33613 Mdot
.72811 .33787 Mdot
.33158 .61469 Mdot
.7178 .29809 Mdot
.69538 .50596 Mdot
.72105 .50219 Mdot
.47506 .32328 Mdot
.50013 .57303 Mdot
.48223 .72173 Mdot
.48936 .7271 Mdot
.45987 .78714 Mdot
.70672 .62505 Mdot
.74709 .3303 Mdot
.4831 .30584 Mdot
.29821 .53597 Mdot
.49589 .3806 Mdot
.5359 .59041 Mdot
.30052 .43571 Mdot
.38833 .31245 Mdot
.69634 .4757 Mdot
.48996 .54296 Mdot
.74499 .4921 Mdot
.50792 .31364 Mdot
.4941 .36703 Mdot
.30128 .43369 Mdot
.73117 .33884 Mdot
.72062 .39352 Mdot
.64644 .46678 Mdot
.30686 .44054 Mdot
.53705 .59158 Mdot
.71504 .48314 Mdot
.6192 .75478 Mdot
.16621 .56985 Mdot
.62281 .46393 Mdot
.40516 .35966 Mdot
.61473 .43453 Mdot
.60945 .74924 Mdot
.63013 .4733 Mdot
.49598 .30218 Mdot
.71041 .51429 Mdot
.70899 .4796 Mdot
.24754 .68644 Mdot
.6507 .60631 Mdot
.51611 .70521 Mdot
.62892 .45392 Mdot
.64697 .4593 Mdot
.47982 .69376 Mdot
.50237 .29785 Mdot
.6573 .44462 Mdot
.39371 .24467 Mdot
.61143 .45419 Mdot
.34011 .41554 Mdot
.61491 .67172 Mdot
.65118 .73748 Mdot
.69561 .50407 Mdot
.48342 .27554 Mdot
.31576 .39649 Mdot
.30796 .45095 Mdot
.4934 .59088 Mdot
.31356 .43522 Mdot
.60264 .43688 Mdot
.61574 .67072 Mdot
.47934 .36623 Mdot
.53248 .57808 Mdot
.50611 .30814 Mdot
.37435 .59953 Mdot
.3179 .42737 Mdot
.51646 .59353 Mdot
.70985 .3267 Mdot
.32113 .41368 Mdot
.369 .54389 Mdot
.70301 .50826 Mdot
.53633 .59342 Mdot
.45589 .3343 Mdot
.32532 .63221 Mdot
.5257 .60156 Mdot
.30282 .43094 Mdot
.63155 .46374 Mdot
.67899 .50052 Mdot
.31326 .43614 Mdot
.47868 .25264 Mdot
.73516 .50131 Mdot
.60845 .45528 Mdot
.48832 .29323 Mdot
.48817 .33664 Mdot
.58521 .46684 Mdot
.62311 .43244 Mdot
.33667 .59021 Mdot
.51273 .6037 Mdot
.51299 .60457 Mdot
.48444 .58398 Mdot
.32444 .61888 Mdot
.30597 .75754 Mdot
.32822 .40148 Mdot
.65368 .73602 Mdot
.38381 .36722 Mdot
.50896 .58524 Mdot
.33228 .58382 Mdot
.64215 .44966 Mdot
.6829 .46664 Mdot
.28268 .45023 Mdot
.44399 .83395 Mdot
.69058 .46532 Mdot
.47151 .35641 Mdot
.29831 .43865 Mdot
.5739 .4712 Mdot
.29886 .50505 Mdot
.49919 .71919 Mdot
.74592 .32635 Mdot
.29541 .43564 Mdot
.52065 .32433 Mdot
.29456 .43474 Mdot
.64596 .45932 Mdot
.61106 .48414 Mdot
.5059 .32121 Mdot
.51815 .7 Mdot
.67268 .46142 Mdot
.6128 .47005 Mdot
.27104 .55491 Mdot
.50337 .38091 Mdot
.49594 .73041 Mdot
.66382 .44688 Mdot
.50575 .55969 Mdot
.52059 .69498 Mdot
.60105 .45042 Mdot
.67541 .47444 Mdot
.48037 .6066 Mdot
.29575 .46125 Mdot
.51152 .67328 Mdot
.25246 .69786 Mdot
.47625 .35323 Mdot
.24878 .38907 Mdot
.52325 .60949 Mdot
.28357 .43321 Mdot
.74437 .48253 Mdot
.52414 .59122 Mdot
.36162 .35643 Mdot
.8748 .44368 Mdot
.5262 .59856 Mdot
.33071 .57871 Mdot
.7111 .37241 Mdot
.67472 .47091 Mdot
.6078 .456 Mdot
.47963 .71944 Mdot
.48428 .33346 Mdot
.39932 .30119 Mdot
.28031 .43382 Mdot
.6268 .44123 Mdot
.46025 .33475 Mdot
.28482 .28827 Mdot
.52253 .58522 Mdot
.5097 .70588 Mdot
.50439 .67151 Mdot
.60398 .44299 Mdot
.67777 .65757 Mdot
.49009 .30604 Mdot
.61591 .45463 Mdot
.59605 .45542 Mdot
.35183 .60668 Mdot
.47001 .30671 Mdot
.29924 .60224 Mdot
.72674 .50775 Mdot
.77919 .39257 Mdot
.31743 .50242 Mdot
.32516 .42368 Mdot
.50189 .59901 Mdot
.28305 .41585 Mdot
.28852 .56457 Mdot
.51173 .60402 Mdot
.61687 .45425 Mdot
.48059 .36664 Mdot
.61537 .45518 Mdot
.61156 .45485 Mdot
.63296 .46705 Mdot
.74864 .33013 Mdot
.26267 .61576 Mdot
.51023 .69772 Mdot
.63367 .42832 Mdot
.31039 .61367 Mdot
.28972 .50912 Mdot
.7151 .38566 Mdot
.62652 .44983 Mdot
.60144 .46515 Mdot
.46303 .30318 Mdot
.67729 .50508 Mdot
.31996 .41645 Mdot
.50783 .31717 Mdot
.68843 .48525 Mdot
.25284 .60501 Mdot
.65244 .44079 Mdot
.49061 .37297 Mdot
.33254 .40884 Mdot
.60261 .37973 Mdot
.53954 .59578 Mdot
.50517 .60348 Mdot
.52698 .59982 Mdot
.4855 .58836 Mdot
.34024 .42236 Mdot
.3268 .57782 Mdot
.25208 .65389 Mdot
.65303 .42778 Mdot
.61185 .431 Mdot
.60704 .48342 Mdot
.34714 .58719 Mdot
.49974 .55811 Mdot
.71456 .31104 Mdot
.57021 .46705 Mdot
.31191 .62368 Mdot
.48854 .56857 Mdot
.54098 .28383 Mdot
.50794 .30669 Mdot
.2665 .59289 Mdot
.3094 .4528 Mdot
.49829 .71231 Mdot
.5026 .79438 Mdot
.49589 .32972 Mdot
.44093 .32153 Mdot
.30702 .58828 Mdot
.62873 .66162 Mdot
.57701 .15135 Mdot
.33059 .5916 Mdot
.74147 .49538 Mdot
.4764 .31528 Mdot
.5175 .56107 Mdot
.65601 .6823 Mdot
.62368 .67112 Mdot
.29464 .62159 Mdot
.65573 .48108 Mdot
.37105 .62665 Mdot
.34229 .59619 Mdot
.49706 .58686 Mdot
.32989 .61492 Mdot
.31149 .39906 Mdot
.31793 .59284 Mdot
.50886 .27215 Mdot
.66182 .46439 Mdot
.57938 .15496 Mdot
.59382 .69396 Mdot
.64967 .44967 Mdot
.30632 .40424 Mdot
.25169 .41768 Mdot
.64709 .4722 Mdot
.49738 .72467 Mdot
.32928 .57779 Mdot
.3516 .54306 Mdot
.6627 .50207 Mdot
.34505 .62462 Mdot
.48071 .27678 Mdot
.32946 .52061 Mdot
.31581 .51092 Mdot
.52324 .60246 Mdot
.47483 .306 Mdot
.30576 .47742 Mdot
.28601 .42507 Mdot
.51139 .61655 Mdot
.59417 .44 Mdot
.48886 .28618 Mdot
.70639 .45354 Mdot
.54271 .52515 Mdot
.61202 .45306 Mdot
.30133 .59998 Mdot
.27385 .61486 Mdot
.59539 .66547 Mdot
.32228 .60751 Mdot
.49603 .58716 Mdot
.48531 .29192 Mdot
.65896 .50149 Mdot
.48363 .34353 Mdot
.63702 .43626 Mdot
.30766 .49903 Mdot
.50627 .29503 Mdot
.47325 .54703 Mdot
.63181 .48139 Mdot
.63536 .22391 Mdot
.64514 .43231 Mdot
.60871 .45433 Mdot
.29579 .63126 Mdot
.48105 .69156 Mdot
.51703 .52905 Mdot
.29328 .50303 Mdot
.4874 .71456 Mdot
.48577 .25778 Mdot
.32793 .63963 Mdot
.48052 .68236 Mdot
.46459 .7917 Mdot
.49322 .59705 Mdot
.50885 .67915 Mdot
.58856 .47496 Mdot
.32444 .42732 Mdot
.49202 .35811 Mdot
.59137 .46459 Mdot
.77248 .39208 Mdot
.73716 .50587 Mdot
.51862 .58561 Mdot
.60518 .45635 Mdot
.64891 .45654 Mdot
.46017 .33637 Mdot
.23396 .32308 Mdot
.29204 .56931 Mdot
.50949 .56782 Mdot
.48922 .34058 Mdot
.2385 .31729 Mdot
.28421 .61305 Mdot
.47166 .69662 Mdot
.28249 .41255 Mdot
.51883 .34096 Mdot
.5147 .58402 Mdot
.31605 .42995 Mdot
.3632 .63378 Mdot
.55983 .73227 Mdot
.66633 .49775 Mdot
.31292 .57892 Mdot
.56315 .737 Mdot
.70489 .51015 Mdot
.28657 .49855 Mdot
.26794 .37116 Mdot
.49697 .28085 Mdot
.31123 .43754 Mdot
.51263 .70539 Mdot
.47067 .36128 Mdot
.50629 .30723 Mdot
.32723 .41846 Mdot
.70729 .25619 Mdot
.66055 .67591 Mdot
.2772 .41854 Mdot
.61845 .64396 Mdot
.56222 .73354 Mdot
.51582 .58138 Mdot
.50783 .69592 Mdot
.32365 .5142 Mdot
.49486 .31043 Mdot
.3888 .32368 Mdot
.56381 .73948 Mdot
.70858 .50856 Mdot
.49573 .71104 Mdot
.2882 .28861 Mdot
.35699 .41702 Mdot
.31932 .42123 Mdot
.2744 .55124 Mdot
.48396 .70934 Mdot
.58694 .46321 Mdot
.46602 .84564 Mdot
.5904 .45148 Mdot
.32838 .42511 Mdot
.74524 .49272 Mdot
.47007 .33997 Mdot
.32852 .40382 Mdot
.74797 .49676 Mdot
.66799 .44995 Mdot
.65495 .46043 Mdot
.26576 .62045 Mdot
.51017 .29024 Mdot
.52749 .61051 Mdot
.64747 .44732 Mdot
.615 .47323 Mdot
.54017 .58297 Mdot
.64583 .73898 Mdot
.44189 .53198 Mdot
.53352 .56847 Mdot
.29829 .61506 Mdot
.53268 .57665 Mdot
.50743 .56937 Mdot
.46046 .31401 Mdot
.30101 .5278 Mdot
.53303 .60104 Mdot
.61683 .46308 Mdot
.61254 .45923 Mdot
.28016 .41565 Mdot
.65973 .67844 Mdot
.62898 .66559 Mdot
.3065 .56588 Mdot
.55152 .58463 Mdot
.65886 .48495 Mdot
.47297 .30653 Mdot
.52534 .71933 Mdot
.49276 .58691 Mdot
.47668 .35535 Mdot
.66501 .46502 Mdot
.35211 .6056 Mdot
.52399 .59843 Mdot
.54106 .57212 Mdot
.49699 .70578 Mdot
.2959 .39698 Mdot
.47033 .26953 Mdot
.3385 .58988 Mdot
.69137 .49671 Mdot
.55182 .57141 Mdot
.34468 .61719 Mdot
.51709 .58011 Mdot
.52914 .57183 Mdot
.4784 .30374 Mdot
.52334 .31428 Mdot
.51182 .55299 Mdot
.31986 .61756 Mdot
.15759 .52451 Mdot
.28942 .43093 Mdot
.6157 .42577 Mdot
.294 .40159 Mdot
.49316 .27799 Mdot
.61717 .74954 Mdot
.49176 .67372 Mdot
.3223 .41825 Mdot
.53589 .5878 Mdot
.50693 .30199 Mdot
.50108 .27637 Mdot
.61986 .46037 Mdot
.61956 .45084 Mdot
.27895 .56467 Mdot
.5799 .7509 Mdot
.27995 .44737 Mdot
.47786 .71456 Mdot
.29798 .56924 Mdot
.67081 .50068 Mdot
.46883 .32701 Mdot
.59155 .80195 Mdot
.61756 .42503 Mdot
.31373 .61441 Mdot
.48515 .31967 Mdot
.48361 .72137 Mdot
.5112 .69559 Mdot
.63223 .43813 Mdot
.46696 .58383 Mdot
.32444 .41372 Mdot
.48785 .29941 Mdot
.42131 .31641 Mdot
.64936 .43537 Mdot
.62471 .45187 Mdot
.70227 .50936 Mdot
.27979 .41199 Mdot
.58753 .4706 Mdot
.51748 .69935 Mdot
.46398 .33363 Mdot
.63052 .43958 Mdot
.48307 .70631 Mdot
.50765 .60996 Mdot
.52361 .59415 Mdot
.28428 .62104 Mdot
.49424 .7261 Mdot
.48332 .69898 Mdot
.48469 .715 Mdot
.38801 .31268 Mdot
.57441 .43633 Mdot
.50881 .54549 Mdot
.65434 .48307 Mdot
.56178 .73181 Mdot
.65213 .49671 Mdot
.29383 .41302 Mdot
.31262 .63214 Mdot
.6397 .4672 Mdot
.65008 .48374 Mdot
.47706 .26913 Mdot
.64946 .50052 Mdot
.58566 .46646 Mdot
.46798 .33726 Mdot
.42585 .31282 Mdot
.34533 .63342 Mdot
.24118 .31992 Mdot
.51606 .85438 Mdot
.58569 .43961 Mdot
.62429 .66343 Mdot
.50321 .29626 Mdot
.28142 .41376 Mdot
.62469 .64884 Mdot
.3069 .39329 Mdot
.48963 .3312 Mdot
.64979 .50353 Mdot
.46704 .25035 Mdot
.48915 .71357 Mdot
.64467 .46014 Mdot
.32667 .41162 Mdot
.64522 .46188 Mdot
.32141 .40159 Mdot
.70368 .28915 Mdot
.64068 .69417 Mdot
.59113 .43766 Mdot
.67325 .48016 Mdot
.47239 .61254 Mdot
.62345 .45022 Mdot
.23816 .6504 Mdot
.48086 .3217 Mdot
.51787 .61865 Mdot
.64429 .50304 Mdot
.69832 .33851 Mdot
.60186 .45905 Mdot
.75877 .48897 Mdot
.6013 .47113 Mdot
.42792 .82357 Mdot
.59423 .42875 Mdot
.5924 .44247 Mdot
.30512 .40993 Mdot
.2863 .44394 Mdot
.48828 .26955 Mdot
.52948 .57757 Mdot
.28072 .29403 Mdot
.60847 .46845 Mdot
.27978 .58832 Mdot
.5352 .51606 Mdot
.48177 .69784 Mdot
.46464 .34377 Mdot
.88211 .41944 Mdot
.34165 .42397 Mdot
.29341 .6012 Mdot
.73631 .49763 Mdot
.29739 .6099 Mdot
.27191 .58796 Mdot
.41986 .29453 Mdot
.50805 .69733 Mdot
.64571 .43757 Mdot
.65867 .32097 Mdot
.48975 .38742 Mdot
.65009 .4359 Mdot
.36036 .63194 Mdot
.4792 .6037 Mdot
.64799 .56829 Mdot
.48372 .66853 Mdot
.49099 .69087 Mdot
.30724 .43136 Mdot
.28071 .59 Mdot
.51153 .56835 Mdot
.48194 .68008 Mdot
.34544 .63079 Mdot
.49275 .59456 Mdot
.29052 .53861 Mdot
.4903 .30497 Mdot
.7194 .30013 Mdot
.64346 .23168 Mdot
.29923 .4023 Mdot
.28672 .50478 Mdot
.48051 .36733 Mdot
.46605 .35809 Mdot
.5215 .57514 Mdot
.31152 .6253 Mdot
.50262 .34503 Mdot
.63555 .44064 Mdot
.53189 .57611 Mdot
.60699 .43873 Mdot
.47659 .67785 Mdot
.60785 .46218 Mdot
.34642 .62746 Mdot
.30939 .40658 Mdot
.3381 .60899 Mdot
.31059 .43215 Mdot
.66095 .73381 Mdot
.62056 .47922 Mdot
.62546 .45389 Mdot
.61653 .6708 Mdot
.47401 .29603 Mdot
.66143 .33134 Mdot
.31983 .61575 Mdot
.33544 .61219 Mdot
.64291 .50221 Mdot
.4845 .35891 Mdot
.52493 .55283 Mdot
.61301 .64168 Mdot
.59961 .46874 Mdot
.48084 .32386 Mdot
.6325 .49666 Mdot
.24378 .37344 Mdot
.62365 .69539 Mdot
.47249 .29585 Mdot
.24563 .68429 Mdot
.59715 .47286 Mdot
.50166 .56802 Mdot
.48507 .6083 Mdot
.69024 .64946 Mdot
.51887 .52751 Mdot
.47886 .35295 Mdot
.51579 .56605 Mdot
.46999 .32378 Mdot
.34338 .60801 Mdot
.33306 .4061 Mdot
.47325 .32826 Mdot
.60553 .47522 Mdot
.51666 .85355 Mdot
.32687 .40761 Mdot
.6413 .45931 Mdot
.33237 .41636 Mdot
.49511 .36029 Mdot
.47714 .34155 Mdot
.49277 .5944 Mdot
.74228 .49684 Mdot
.32385 .41577 Mdot
.60807 .43186 Mdot
.40137 .34904 Mdot
.66335 .49933 Mdot
.54753 .60063 Mdot
.66554 .4836 Mdot
.66641 .46754 Mdot
.27892 .73436 Mdot
.71468 .45897 Mdot
.31526 .50303 Mdot
.2863 .39668 Mdot
.39459 .30097 Mdot
.45904 .32315 Mdot
.47189 .6866 Mdot
.48446 .26768 Mdot
.51007 .60551 Mdot
.29576 .61487 Mdot
.63531 .4653 Mdot
.48988 .59704 Mdot
.27638 .44418 Mdot
.50432 .67787 Mdot
.5983 .42894 Mdot
.30434 .57546 Mdot
.49404 .56872 Mdot
.31768 .42595 Mdot
.49633 .31214 Mdot
.47075 .34712 Mdot
.30146 .53058 Mdot
.63291 .44073 Mdot
.61814 .45226 Mdot
.33467 .42897 Mdot
.47431 .5508 Mdot
.48936 .7182 Mdot
.49602 .56163 Mdot
.33353 .42472 Mdot
.62535 .69576 Mdot
.51103 .29068 Mdot
.64627 .45309 Mdot
.61184 .67376 Mdot
.39831 .2978 Mdot
.58202 .35708 Mdot
.49031 .69698 Mdot
.67864 .6368 Mdot
.47932 .35257 Mdot
.3053 .41366 Mdot
.45996 .78933 Mdot
.69513 .50941 Mdot
.65282 .47042 Mdot
.68441 .62755 Mdot
.61511 .64078 Mdot
.73259 .49349 Mdot
.53212 .60528 Mdot
.65339 .67336 Mdot
.63896 .50064 Mdot
.68452 .4979 Mdot
.6559 .48607 Mdot
.66669 .48384 Mdot
.47855 .33187 Mdot
.73174 .34246 Mdot
.30855 .59196 Mdot
.58704 .49296 Mdot
.50146 .65153 Mdot
.71019 .5071 Mdot
.68252 .47086 Mdot
.55669 .31928 Mdot
.7117 .59294 Mdot
.48108 .31295 Mdot
.47878 .28219 Mdot
.29514 .4039 Mdot
.65784 .49994 Mdot
.3167 .61579 Mdot
.47642 .58621 Mdot
.31787 .63061 Mdot
.48033 .33019 Mdot
.35033 .63355 Mdot
.34364 .42427 Mdot
.3125 .5788 Mdot
.30696 .62148 Mdot
.30462 .40738 Mdot
.51135 .29785 Mdot
.64697 .43292 Mdot
.30473 .4069 Mdot
.53783 .56471 Mdot
.471 .69483 Mdot
.43501 .31606 Mdot
.52585 .56372 Mdot
.68726 .4632 Mdot
.16289 .50205 Mdot
.30403 .58182 Mdot
.6769 .61239 Mdot
.50746 .29263 Mdot
.52582 .68767 Mdot
.47287 .33217 Mdot
.5122 .55238 Mdot
.49108 .70157 Mdot
.59022 .47672 Mdot
.54039 .79495 Mdot
.27264 .37052 Mdot
.70406 .48675 Mdot
.42536 .31317 Mdot
.32203 .62998 Mdot
.31226 .40156 Mdot
.23384 .41257 Mdot
.50979 .56708 Mdot
.4821 .27497 Mdot
.52653 .31266 Mdot
.5115 .60496 Mdot
.3088 .41161 Mdot
.62963 .23664 Mdot
.64417 .44644 Mdot
.29407 .40268 Mdot
.66543 .48283 Mdot
.73814 .31809 Mdot
.52777 .67805 Mdot
.48367 .58614 Mdot
.65394 .50443 Mdot
.28474 .61315 Mdot
.64536 .50283 Mdot
.76151 .3728 Mdot
.59721 .75521 Mdot
.6353 .48363 Mdot
.68094 .61692 Mdot
.29679 .5615 Mdot
.46844 .32122 Mdot
.50662 .59248 Mdot
.51753 .58249 Mdot
.66541 .50701 Mdot
.60615 .83876 Mdot
.48955 .67812 Mdot
.23785 .63315 Mdot
.61558 .47741 Mdot
.61229 .44631 Mdot
.47805 .26595 Mdot
.70219 .29028 Mdot
.50147 .55996 Mdot
.65004 .47691 Mdot
.71215 .60154 Mdot
.29713 .42222 Mdot
.67498 .48632 Mdot
.60744 .44099 Mdot
.33645 .52393 Mdot
.30477 .41128 Mdot
.3488 .60224 Mdot
.49676 .60027 Mdot
.28692 .62606 Mdot
.51819 .70756 Mdot
.67002 .6362 Mdot
.6334 .74424 Mdot
.61954 .69251 Mdot
.50324 .72252 Mdot
.69184 .50508 Mdot
.67564 .44461 Mdot
.65876 .46797 Mdot
.49163 .68715 Mdot
.30923 .45575 Mdot
.47894 .32524 Mdot
.7306 .30922 Mdot
.51918 .58073 Mdot
.70327 .49597 Mdot
.51302 .66753 Mdot
.47287 .32046 Mdot
.63217 .21865 Mdot
.48337 .33306 Mdot
.31518 .42318 Mdot
.28637 .4999 Mdot
.48984 .70585 Mdot
.47242 .3322 Mdot
.2979 .63135 Mdot
.29994 .49164 Mdot
.56349 .45774 Mdot
.34303 .42612 Mdot
.51567 .28813 Mdot
.47727 .28718 Mdot
.46691 .36645 Mdot
.66406 .50471 Mdot
.67933 .61529 Mdot
.49987 .59698 Mdot
.3339 .41444 Mdot
.28818 .59513 Mdot
.58383 .75154 Mdot
.62981 .25844 Mdot
.63808 .68277 Mdot
.6019 .48242 Mdot
.6087 .46206 Mdot
.60305 .44588 Mdot
.54232 .58766 Mdot
.67686 .44425 Mdot
.64298 .48435 Mdot
.2824 .45014 Mdot
.34741 .6103 Mdot
.61741 .47633 Mdot
.51957 .59703 Mdot
.49932 .53983 Mdot
.52551 .68893 Mdot
.75093 .32696 Mdot
.43742 .31051 Mdot
.47351 .32342 Mdot
.30578 .60827 Mdot
.32544 .64022 Mdot
.48463 .6758 Mdot
.30282 .43747 Mdot
.48506 .33355 Mdot
.42312 .81944 Mdot
.49304 .71578 Mdot
.6199 .46481 Mdot
.61559 .67167 Mdot
.70767 .6127 Mdot
.6765 .46848 Mdot
.63285 .46795 Mdot
.53434 .58739 Mdot
.31318 .61629 Mdot
.77037 .41585 Mdot
.63321 .22147 Mdot
.48394 .70526 Mdot
.47391 .69923 Mdot
.4683 .36485 Mdot
.60015 .43419 Mdot
.32682 .41415 Mdot
.66275 .67531 Mdot
.25021 .41 Mdot
.31508 .26582 Mdot
.36683 .61507 Mdot
.64831 .43842 Mdot
.70506 .3592 Mdot
.69654 .47459 Mdot
.47828 .37214 Mdot
.51984 .32111 Mdot
.48216 .30833 Mdot
.29676 .42742 Mdot
.55811 .72001 Mdot
.29811 .44771 Mdot
.48963 .56786 Mdot
.50092 .32427 Mdot
.7131 .46839 Mdot
.33399 .61279 Mdot
.65164 .49848 Mdot
.50348 .69233 Mdot
.55529 .61143 Mdot
.50701 .58821 Mdot
.67566 .63662 Mdot
.33181 .58351 Mdot
.51133 .31402 Mdot
.64795 .49838 Mdot
.29942 .50687 Mdot
.64668 .68111 Mdot
.32825 .56465 Mdot
.49118 .59868 Mdot
.48855 .71071 Mdot
.71605 .38939 Mdot
.50001 .71582 Mdot
.32382 .41847 Mdot
.6279 .48049 Mdot
.59667 .43848 Mdot
.60724 .45249 Mdot
.59015 .46974 Mdot
.30035 .42948 Mdot
.71141 .49662 Mdot
.52447 .55767 Mdot
.48674 .58958 Mdot
.72946 .5024 Mdot
.50935 .68835 Mdot
.28966 .42548 Mdot
.34652 .61573 Mdot
.53236 .59635 Mdot
.51417 .67289 Mdot
.64095 .49324 Mdot
.64506 .48226 Mdot
.48857 .57336 Mdot
.58882 .47469 Mdot
.71556 .49761 Mdot
.3176 .58414 Mdot
.72642 .49458 Mdot
.52471 .68836 Mdot
.50065 .69659 Mdot
.31744 .43415 Mdot
.47194 .33136 Mdot
.50303 .66917 Mdot
.30633 .56939 Mdot
.67368 .48912 Mdot
.66323 .48441 Mdot
.51422 .27906 Mdot
.56224 .73923 Mdot
.52647 .69174 Mdot
.58694 .46967 Mdot
.46547 .31317 Mdot
.5277 .31817 Mdot
.65155 .47277 Mdot
.71325 .50163 Mdot
.45748 .32345 Mdot
.47509 .68709 Mdot
.30896 .44031 Mdot
.59478 .70483 Mdot
.3229 .39834 Mdot
.49729 .30987 Mdot
.51997 .56865 Mdot
.51125 .30288 Mdot
.51113 .56637 Mdot
.39045 .21836 Mdot
.64758 .48503 Mdot
.4312 .26078 Mdot
.50082 .557 Mdot
.33175 .61574 Mdot
.32575 .62398 Mdot
.52087 .60021 Mdot
.48384 .3517 Mdot
.49667 .58856 Mdot
.5074 .71125 Mdot
.39387 .30665 Mdot
.46165 .31049 Mdot
.30838 .62247 Mdot
.30337 .58044 Mdot
.33393 .42332 Mdot
.60511 .46061 Mdot
.64673 .45285 Mdot
.3155 .57818 Mdot
.24883 .40734 Mdot
.49805 .28438 Mdot
.61856 .45276 Mdot
.53641 .57166 Mdot
.31316 .58811 Mdot
.32935 .36839 Mdot
.49861 .34847 Mdot
.65509 .50545 Mdot
.60223 .7553 Mdot
.33586 .40916 Mdot
.69123 .48162 Mdot
.71346 .49851 Mdot
.48543 .68495 Mdot
.68177 .63511 Mdot
.5647 .73536 Mdot
.34172 .42571 Mdot
.50384 .60223 Mdot
.67749 .46832 Mdot
.33312 .61944 Mdot
.64416 .49023 Mdot
.85018 .50263 Mdot
.48511 .57821 Mdot
.63041 .44107 Mdot
.4807 .59754 Mdot
.48297 .34434 Mdot
.61386 .4504 Mdot
.30991 .49735 Mdot
.3087 .60573 Mdot
.6361 .44296 Mdot
.46749 .59688 Mdot
.33184 .4161 Mdot
.50762 .58879 Mdot
.48659 .71163 Mdot
.73468 .49203 Mdot
.67147 .72956 Mdot
.34538 .58524 Mdot
.51283 .69055 Mdot
.6037 .46267 Mdot
.29385 .57047 Mdot
.28513 .44163 Mdot
.50837 .59641 Mdot
.69472 .49079 Mdot
.28912 .41704 Mdot
.29651 .41845 Mdot
.49312 .70769 Mdot
.62707 .19163 Mdot
.58535 .44245 Mdot
.63691 .45284 Mdot
.62761 .20852 Mdot
.53534 .32066 Mdot
.64329 .46153 Mdot
.59462 .45104 Mdot
.31939 .42867 Mdot
.55563 .71918 Mdot
.67726 .63596 Mdot
.4801 .57442 Mdot
.30891 .40214 Mdot
.36545 .62749 Mdot
.2984 .5937 Mdot
.51484 .68911 Mdot
.48604 .31944 Mdot
.49115 .67079 Mdot
.31463 .59547 Mdot
.6202 .46245 Mdot
.31666 .44055 Mdot
.77897 .44227 Mdot
.33041 .40699 Mdot
.30882 .57107 Mdot
.48334 .37126 Mdot
.77098 .40386 Mdot
.85421 .49352 Mdot
.43721 .53129 Mdot
.28444 .49759 Mdot
.48165 .69662 Mdot
.63281 .22127 Mdot
.60733 .47366 Mdot
.75285 .3673 Mdot
.6424 .45695 Mdot
.46748 .72565 Mdot
.33285 .63061 Mdot
.49285 .59461 Mdot
.50862 .56718 Mdot
.67534 .63254 Mdot
.29436 .42389 Mdot
.31574 .45044 Mdot
.52459 .56789 Mdot
.31631 .41895 Mdot
.633 .4442 Mdot
.33375 .59056 Mdot
.4243 .21443 Mdot
.6013 .472 Mdot
.52875 .61528 Mdot
.34323 .40548 Mdot
.49952 .3699 Mdot
.36487 .62804 Mdot
.70213 .35062 Mdot
.26641 .30558 Mdot
.32133 .4121 Mdot
.7519 .32994 Mdot
.31066 .61094 Mdot
.53261 .59568 Mdot
.28895 .57243 Mdot
.63968 .45159 Mdot
.64795 .43809 Mdot
.53942 .58726 Mdot
.59937 .46093 Mdot
.66432 .35796 Mdot
.72007 .50736 Mdot
.55877 .49097 Mdot
.65589 .48189 Mdot
.45072 .25373 Mdot
.28386 .44442 Mdot
.52474 .56885 Mdot
.57558 .64058 Mdot
.66432 .46712 Mdot
.45659 .33287 Mdot
.29305 .41122 Mdot
.25031 .32152 Mdot
.29791 .42593 Mdot
.33865 .61208 Mdot
.29892 .43517 Mdot
.69574 .47758 Mdot
.49288 .32901 Mdot
.32371 .601 Mdot
.51051 .58546 Mdot
.28855 .60519 Mdot
.64908 .44923 Mdot
.34783 .38127 Mdot
.29406 .60064 Mdot
.70404 .5092 Mdot
.49017 .33313 Mdot
.56902 .80274 Mdot
.45154 .3649 Mdot
.62742 .45986 Mdot
.6367 .46118 Mdot
.50267 .55874 Mdot
.30905 .43534 Mdot
.51375 .30462 Mdot
.26603 .56041 Mdot
.52642 .68914 Mdot
.48464 .31322 Mdot
.46921 .57396 Mdot
.62917 .6605 Mdot
.46253 .34109 Mdot
.71118 .6058 Mdot
.3265 .42137 Mdot
.47442 .35191 Mdot
.54355 .52031 Mdot
.60306 .49937 Mdot
.50521 .70244 Mdot
.2926 .62973 Mdot
.62774 .65374 Mdot
.29867 .5984 Mdot
.30842 .49969 Mdot
.28037 .62432 Mdot
.3212 .40721 Mdot
.46738 .57286 Mdot
.74436 .492 Mdot
.32346 .44828 Mdot
.37593 .42062 Mdot
.3054 .59722 Mdot
.51651 .56237 Mdot
.72666 .49693 Mdot
.54205 .57409 Mdot
.50263 .56483 Mdot
.34094 .42656 Mdot
.47364 .35274 Mdot
.47779 .36069 Mdot
.50082 .61612 Mdot
.46875 .34297 Mdot
.32886 .59287 Mdot
.6107 .68872 Mdot
.70935 .32674 Mdot
.286 .4507 Mdot
.72544 .49212 Mdot
.68559 .47797 Mdot
.34502 .62617 Mdot
.33449 .59658 Mdot
.29542 .42506 Mdot
.56012 .38411 Mdot
.49653 .57107 Mdot
.49639 .36265 Mdot
.49585 .33064 Mdot
.48054 .34695 Mdot
.49785 .27783 Mdot
.55887 .72884 Mdot
.30555 .40442 Mdot
.48498 .34978 Mdot
.59546 .47381 Mdot
.59706 .45019 Mdot
.52873 .60054 Mdot
.47392 .68353 Mdot
.717 .50223 Mdot
.49592 .58808 Mdot
.65204 .46853 Mdot
.32884 .61497 Mdot
.52707 .5153 Mdot
.50972 .60675 Mdot
.31658 .61662 Mdot
.32381 .61794 Mdot
.50316 .60293 Mdot
.52277 .51605 Mdot
.6627 .36887 Mdot
.65068 .508 Mdot
.41521 .31351 Mdot
.31827 .62639 Mdot
.36297 .46388 Mdot
.4342 .25818 Mdot
.60194 .43632 Mdot
.49258 .56298 Mdot
.33918 .5968 Mdot
.46531 .30376 Mdot
.62804 .44861 Mdot
.52007 .57373 Mdot
.50259 .70918 Mdot
.51116 .58983 Mdot
.53397 .58515 Mdot
.47747 .29571 Mdot
.16095 .5164 Mdot
.46056 .33353 Mdot
.26668 .61586 Mdot
.50708 .58062 Mdot
.57735 .15318 Mdot
.32845 .62883 Mdot
.39223 .3098 Mdot
.74488 .49375 Mdot
.6555 .46981 Mdot
.30517 .60678 Mdot
.48079 .27713 Mdot
.33745 .43815 Mdot
.71397 .58867 Mdot
.47147 .3337 Mdot
.52444 .60928 Mdot
.52918 .59407 Mdot
.30955 .59036 Mdot
.50047 .30541 Mdot
.71345 .49892 Mdot
.47415 .34697 Mdot
.30984 .44833 Mdot
.60032 .48612 Mdot
.27907 .29547 Mdot
.51269 .56882 Mdot
.46563 .33881 Mdot
.29052 .58589 Mdot
.51803 .69789 Mdot
.58961 .45208 Mdot
.25745 .30786 Mdot
.60241 .46113 Mdot
.32749 .44153 Mdot
.5383 .52947 Mdot
.61186 .49855 Mdot
.62806 .47204 Mdot
.68044 .46502 Mdot
.30243 .46596 Mdot
.63179 .47343 Mdot
.66738 .46181 Mdot
.63876 .22979 Mdot
.46287 .32932 Mdot
.61434 .47546 Mdot
.32166 .58131 Mdot
.48645 .5124 Mdot
.61566 .4389 Mdot
.2901 .50546 Mdot
.68687 .65077 Mdot
.49745 .557 Mdot
.52042 .62101 Mdot
.61509 .75013 Mdot
.63703 .45806 Mdot
.60585 .43128 Mdot
.60041 .48569 Mdot
.71769 .36137 Mdot
.31172 .59947 Mdot
.28171 .60629 Mdot
.51679 .6973 Mdot
.68584 .62434 Mdot
.49819 .70033 Mdot
.28471 .44091 Mdot
.74128 .50141 Mdot
.49364 .59941 Mdot
.47081 .32884 Mdot
.60796 .45076 Mdot
.28614 .59338 Mdot
.63895 .44859 Mdot
.68135 .50112 Mdot
.32399 .59014 Mdot
.34076 .60138 Mdot
.29169 .63379 Mdot
.48223 .70906 Mdot
.47742 .31696 Mdot
.5867 .45089 Mdot
.48514 .71308 Mdot
.54069 .58475 Mdot
.60366 .7116 Mdot
.47886 .31384 Mdot
.4653 .33438 Mdot
.498 .33739 Mdot
.59273 .44002 Mdot
.5914 .48308 Mdot
.29465 .44462 Mdot
.5144 .27919 Mdot
.33011 .42086 Mdot
.30277 .60528 Mdot
.34583 .60184 Mdot
.64095 .45257 Mdot
.47102 .56357 Mdot
.50894 .69153 Mdot
.29372 .59307 Mdot
.48432 .59752 Mdot
.5166 .68102 Mdot
.6197 .43252 Mdot
.29912 .60116 Mdot
.49451 .72456 Mdot
.5621 .38366 Mdot
.31026 .2963 Mdot
.51914 .69252 Mdot
.50459 .56801 Mdot
.6317 .26835 Mdot
.59359 .75203 Mdot
.52746 .71514 Mdot
.28488 .4462 Mdot
.61334 .42474 Mdot
.48351 .5911 Mdot
.51601 .67695 Mdot
.56994 .75143 Mdot
.32003 .59384 Mdot
.49989 .56981 Mdot
.44148 .55501 Mdot
.71005 .32849 Mdot
.51914 .69677 Mdot
.46494 .33795 Mdot
.51524 .29113 Mdot
.62506 .46766 Mdot
.74028 .49815 Mdot
.28582 .45392 Mdot
.31521 .63893 Mdot
.28308 .60253 Mdot
.5204 .32774 Mdot
.6211 .69391 Mdot
.31303 .58187 Mdot
.61101 .42672 Mdot
.50203 .6603 Mdot
.59637 .47504 Mdot
.54532 .53244 Mdot
.61502 .49937 Mdot
.50548 .62195 Mdot
.5187 .69555 Mdot
.28939 .4563 Mdot
.3103 .40688 Mdot
.30595 .43366 Mdot
.31258 .58434 Mdot
.6275 .64971 Mdot
.28199 .59311 Mdot
.63767 .20548 Mdot
.49105 .67676 Mdot
.32185 .76815 Mdot
.68592 .45938 Mdot
.65575 .46505 Mdot
.66434 .49733 Mdot
.53522 .57301 Mdot
.63518 .45708 Mdot
.28747 .4221 Mdot
.2958 .62969 Mdot
.29851 .36401 Mdot
.48875 .29198 Mdot
.63894 .21225 Mdot
.33287 .61228 Mdot
.51244 .61562 Mdot
.50578 .69012 Mdot
.63353 .74929 Mdot
.46971 .71483 Mdot
.33327 .58177 Mdot
.6503 .44461 Mdot
.46375 .36369 Mdot
.43544 .82799 Mdot
.6117 .45178 Mdot
.30269 .58258 Mdot
.33354 .57041 Mdot
.58401 .4927 Mdot
.7438 .44047 Mdot
.26139 .37282 Mdot
.61451 .6772 Mdot
.49818 .72704 Mdot
.54063 .57508 Mdot
.66799 .67117 Mdot
.31294 .59527 Mdot
.29146 .62239 Mdot
.49424 .73148 Mdot
.49911 .37167 Mdot
.49776 .33335 Mdot
.4263 .34212 Mdot
.28744 .43307 Mdot
.65643 .47344 Mdot
.30189 .59754 Mdot
.48058 .36964 Mdot
.56712 .63865 Mdot
.30794 .42731 Mdot
.29284 .59956 Mdot
.59975 .45891 Mdot
.62424 .47128 Mdot
.49832 .7024 Mdot
.50365 .53855 Mdot
.53576 .56642 Mdot
.39341 .30972 Mdot
.63448 .66885 Mdot
.7475 .49747 Mdot
.65288 .47053 Mdot
.49063 .28038 Mdot
.5083 .60395 Mdot
.50855 .6969 Mdot
.64421 .48985 Mdot
.76653 .3882 Mdot
.47985 .28167 Mdot
.32746 .41712 Mdot
.51336 .57984 Mdot
.66945 .6327 Mdot
.60037 .46042 Mdot
.64189 .4562 Mdot
.6639 .50462 Mdot
.77354 .41011 Mdot
.31467 .63218 Mdot
.46761 .31271 Mdot
.48533 .71002 Mdot
.47906 .3402 Mdot
.30166 .53476 Mdot
.73457 .50309 Mdot
.59665 .42742 Mdot
.46128 .31847 Mdot
.4885 .32997 Mdot
.3261 .44261 Mdot
.31209 .40436 Mdot
.35716 .59878 Mdot
.59347 .44988 Mdot
.48398 .5797 Mdot
.48527 .34795 Mdot
.29829 .63342 Mdot
.49658 .70163 Mdot
.28624 .50795 Mdot
.6457 .4835 Mdot
.30829 .59477 Mdot
.50434 .59166 Mdot
.48265 .29332 Mdot
.31777 .61342 Mdot
.533 .59503 Mdot
.47248 .69512 Mdot
.66957 .4545 Mdot
.30691 .55611 Mdot
.5245 .57381 Mdot
.59131 .45785 Mdot
.56336 .51387 Mdot
.73909 .49729 Mdot
.47777 .58202 Mdot
.35183 .623 Mdot
.52296 .57783 Mdot
.51497 .2933 Mdot
.57964 .48698 Mdot
.28731 .62105 Mdot
.46567 .25022 Mdot
.74699 .49344 Mdot
.51388 .56625 Mdot
.46856 .32278 Mdot
.29001 .53956 Mdot
.51387 .37778 Mdot
.59189 .7473 Mdot
.62073 .44163 Mdot
.29874 .59805 Mdot
.5037 .70446 Mdot
.31719 .4492 Mdot
.36565 .41922 Mdot
.34919 .49958 Mdot
.316 .62227 Mdot
.60763 .44957 Mdot
.47618 .35207 Mdot
.32141 .41494 Mdot
.47446 .26588 Mdot
.29226 .57305 Mdot
.32574 .58191 Mdot
.67291 .49765 Mdot
.49811 .69921 Mdot
.67871 .44705 Mdot
.28694 .62328 Mdot
.27537 .61506 Mdot
.63822 .23201 Mdot
.49925 .72625 Mdot
.66344 .50539 Mdot
.50146 .61715 Mdot
.67069 .48682 Mdot
.63058 .21632 Mdot
.5314 .58689 Mdot
.49005 .29107 Mdot
.64224 .4666 Mdot
.18719 .59697 Mdot
.33586 .627 Mdot
.61476 .67746 Mdot
.27569 .36962 Mdot
.29747 .41371 Mdot
.31282 .60581 Mdot
.62167 .4463 Mdot
.28475 .50468 Mdot
.51488 .68675 Mdot
.64239 .50321 Mdot
.51885 .56546 Mdot
.52382 .32715 Mdot
.31421 .44223 Mdot
.46895 .53608 Mdot
.31308 .44998 Mdot
.31484 .43482 Mdot
.53598 .38807 Mdot
.62381 .46699 Mdot
.3291 .61037 Mdot
.30999 .57418 Mdot
.53829 .61177 Mdot
.26385 .62597 Mdot
.50741 .3152 Mdot
.18515 .58808 Mdot
.76748 .39454 Mdot
.62539 .48117 Mdot
.5313 .60602 Mdot
.4954 .56348 Mdot
.28577 .49931 Mdot
.63305 .47135 Mdot
.47025 .31642 Mdot
.28616 .62387 Mdot
.30121 .59138 Mdot
.70412 .50904 Mdot
.31024 .40651 Mdot
.47398 .71272 Mdot
.33229 .59647 Mdot
.5939 .70126 Mdot
.63031 .44062 Mdot
.34725 .40189 Mdot
.3312 .5975 Mdot
.54312 .83793 Mdot
.15647 .53504 Mdot
.46155 .34803 Mdot
.671 .45334 Mdot
.49872 .34715 Mdot
.51575 .70526 Mdot
.27446 .58984 Mdot
.3179 .45076 Mdot
.50818 .58274 Mdot
.22569 .40213 Mdot
.30565 .58963 Mdot
.47998 .32927 Mdot
.62795 .4647 Mdot
.75551 .3356 Mdot
.60182 .47137 Mdot
.55503 .71678 Mdot
.5271 .69547 Mdot
.36593 .41488 Mdot
.33498 .42657 Mdot
.67052 .4523 Mdot
.48573 .71651 Mdot
.32715 .57454 Mdot
.32215 .58989 Mdot
.24734 .3141 Mdot
.5336 .58687 Mdot
.27553 .58217 Mdot
.59149 .4556 Mdot
.28779 .63079 Mdot
.62957 .25796 Mdot
.2994 .41263 Mdot
.6728 .48274 Mdot
.29592 .60691 Mdot
.51371 .37299 Mdot
.61927 .67077 Mdot
.6238 .43993 Mdot
.48245 .60333 Mdot
.31861 .40734 Mdot
.64061 .21341 Mdot
.33739 .63019 Mdot
.61991 .48397 Mdot
.28681 .4184 Mdot
.4676 .57377 Mdot
.30755 .36235 Mdot
.47748 .31625 Mdot
.30238 .57979 Mdot
.30888 .44088 Mdot
.50154 .58015 Mdot
.4958 .72337 Mdot
.30959 .56815 Mdot
.29443 .61024 Mdot
.69042 .50367 Mdot
.50173 .61377 Mdot
.4701 .56989 Mdot
.50221 .28992 Mdot
.32291 .42557 Mdot
.67637 .50253 Mdot
.60091 .71405 Mdot
.62646 .49089 Mdot
.32275 .42968 Mdot
.59347 .16476 Mdot
.65341 .44509 Mdot
.6525 .48285 Mdot
.76115 .34688 Mdot
.51259 .31558 Mdot
.49283 .27712 Mdot
.6417 .68271 Mdot
.70909 .50297 Mdot
.71176 .46456 Mdot
.47677 .32192 Mdot
.48233 .32985 Mdot
.71212 .46577 Mdot
.69012 .50222 Mdot
.43222 .34846 Mdot
.31898 .41551 Mdot
.29945 .41099 Mdot
.48126 .34585 Mdot
.65749 .49713 Mdot
.28063 .41575 Mdot
.56546 .34947 Mdot
.31897 .57506 Mdot
.67635 .65822 Mdot
.48462 .33828 Mdot
.61517 .66877 Mdot
.32384 .41911 Mdot
.66251 .71774 Mdot
.69145 .64711 Mdot
.58352 .44772 Mdot
.62696 .46974 Mdot
.48297 .69285 Mdot
.50907 .58903 Mdot
.50426 .60388 Mdot
.30583 .43414 Mdot
.6761 .44343 Mdot
.48337 .30767 Mdot
.69587 .47944 Mdot
.58176 .75183 Mdot
.68115 .71413 Mdot
.7697 .43995 Mdot
.48572 .32158 Mdot
.49339 .30982 Mdot
.34652 .59906 Mdot
.34928 .63586 Mdot
.59034 .43558 Mdot
.31585 .40633 Mdot
.47007 .35126 Mdot
.32377 .43313 Mdot
.31431 .59449 Mdot
.33401 .60979 Mdot
.51826 .6062 Mdot
.4984 .57133 Mdot
.3176 .60226 Mdot
.28973 .50498 Mdot
.60162 .71366 Mdot
.52293 .30492 Mdot
.63903 .20196 Mdot
.65283 .73778 Mdot
.73616 .31546 Mdot
.50341 .70725 Mdot
.53005 .51591 Mdot
.28635 .42188 Mdot
.67432 .45595 Mdot
.64822 .46563 Mdot
.52262 .5857 Mdot
.29265 .40564 Mdot
.49903 .68017 Mdot
.29809 .41363 Mdot
.49421 .72224 Mdot
.2845 .61129 Mdot
.60974 .44704 Mdot
.65105 .44838 Mdot
.32251 .44491 Mdot
.3436 .5932 Mdot
.29759 .60553 Mdot
.50704 .70466 Mdot
.63886 .74297 Mdot
.30994 .5913 Mdot
.48531 .33672 Mdot
.4963 .23488 Mdot
.5291 .59097 Mdot
.62685 .44878 Mdot
.61679 .75079 Mdot
.57938 .48618 Mdot
.54019 .58727 Mdot
.51427 .57982 Mdot
.62529 .19055 Mdot
.6329 .43899 Mdot
.23725 .32353 Mdot
.51203 .6073 Mdot
.51136 .3036 Mdot
.32364 .60967 Mdot
.53232 .60335 Mdot
.49165 .61753 Mdot
.51493 .6563 Mdot
.53711 .59898 Mdot
.49528 .33684 Mdot
.50514 .3295 Mdot
.72942 .49715 Mdot
.6467 .20366 Mdot
.48765 .71151 Mdot
.50751 .6802 Mdot
.31083 .63051 Mdot
.30874 .50033 Mdot
.62585 .41558 Mdot
.50448 .67611 Mdot
.43523 .32194 Mdot
.67662 .4981 Mdot
.73365 .49334 Mdot
.7296 .50148 Mdot
.5069 .28218 Mdot
.58498 .48377 Mdot
.32196 .631 Mdot
.4801 .32689 Mdot
.72514 .49429 Mdot
.67571 .48987 Mdot
.48012 .31116 Mdot
.31572 .43204 Mdot
.76026 .4811 Mdot
.4715 .34678 Mdot
.71515 .58693 Mdot
.32523 .41239 Mdot
.7282 .4906 Mdot
.38057 .78783 Mdot
.57008 .84092 Mdot
.29915 .41522 Mdot
.29395 .59674 Mdot
.30312 .59847 Mdot
.31923 .58551 Mdot
.49926 .28245 Mdot
.34406 .61316 Mdot
.49927 .29903 Mdot
.28635 .49655 Mdot
.68066 .62811 Mdot
.49023 .70385 Mdot
.26103 .61778 Mdot
.47952 .34649 Mdot
.63345 .21033 Mdot
.87642 .43969 Mdot
.61087 .4827 Mdot
.32646 .44598 Mdot
.5022 .67119 Mdot
.60969 .6801 Mdot
.48541 .68536 Mdot
.30983 .6106 Mdot
.67211 .63318 Mdot
.63729 .44589 Mdot
.28989 .30647 Mdot
.50341 .70235 Mdot
.4825 .33133 Mdot
.69394 .50624 Mdot
.35494 .61424 Mdot
.5146 .69455 Mdot
.50167 .69525 Mdot
.63361 .45544 Mdot
.51152 .31318 Mdot
.30507 .6102 Mdot
.30191 .40039 Mdot
.37804 .55971 Mdot
.55538 .52554 Mdot
.62662 .43627 Mdot
.6609 .48177 Mdot
.62613 .6645 Mdot
.28718 .50871 Mdot
.31524 .4115 Mdot
.56941 .7434 Mdot
.34697 .62566 Mdot
.58871 .75417 Mdot
.50104 .37819 Mdot
.26086 .61527 Mdot
.53085 .5858 Mdot
.53129 .59837 Mdot
.61749 .4541 Mdot
.86408 .47088 Mdot
.74416 .44981 Mdot
.27944 .42075 Mdot
.52515 .59017 Mdot
.34555 .59374 Mdot
.49199 .27434 Mdot
.43261 .56504 Mdot
.71877 .50065 Mdot
.30329 .39958 Mdot
.31687 .58918 Mdot
.861 .52286 Mdot
.48008 .69801 Mdot
.61494 .68305 Mdot
.59518 .45521 Mdot
.62195 .45395 Mdot
.30342 .42582 Mdot
.29963 .45743 Mdot
.64343 .22826 Mdot
.47061 .72475 Mdot
.28401 .28946 Mdot
.28501 .46349 Mdot
.86555 .5337 Mdot
.48922 .56935 Mdot
.4933 .3028 Mdot
.4994 .60051 Mdot
.2969 .45868 Mdot
.64358 .46391 Mdot
.51233 .31321 Mdot
.50738 .59719 Mdot
.44023 .33136 Mdot
.73614 .49296 Mdot
.59572 .70509 Mdot
.60927 .46289 Mdot
.49126 .35531 Mdot
.4795 .32116 Mdot
.49026 .36775 Mdot
.52384 .60045 Mdot
.6504 .47736 Mdot
.61655 .48297 Mdot
.65835 .48109 Mdot
.64464 .236 Mdot
.61347 .44819 Mdot
.49308 .38103 Mdot
.6357 .69339 Mdot
.19195 .61143 Mdot
.65261 .45065 Mdot
.3058 .43812 Mdot
.61309 .45696 Mdot
.48265 .71549 Mdot
.67201 .46046 Mdot
.73752 .49168 Mdot
.31419 .41566 Mdot
.7637 .37596 Mdot
.50325 .65234 Mdot
.62816 .43556 Mdot
.50175 .72319 Mdot
.38216 .31758 Mdot
.57035 .74028 Mdot
.62955 .23796 Mdot
.47531 .34663 Mdot
.28374 .57912 Mdot
.28485 .45409 Mdot
.33799 .61245 Mdot
.7123 .51315 Mdot
.49002 .5941 Mdot
.3056 .75731 Mdot
.61487 .71936 Mdot
.64279 .46522 Mdot
.5088 .55839 Mdot
.46556 .32569 Mdot
.33159 .62864 Mdot
.7048 .29097 Mdot
.66713 .49759 Mdot
.47794 .68146 Mdot
.47905 .68713 Mdot
.55119 .55717 Mdot
.49485 .36938 Mdot
.62785 .25111 Mdot
.30432 .42408 Mdot
.30954 .58515 Mdot
.52141 .68308 Mdot
.42794 .31785 Mdot
.3151 .45419 Mdot
.28908 .49896 Mdot
.31182 .44263 Mdot
.65859 .46195 Mdot
.51964 .60914 Mdot
.4047 .32479 Mdot
.52798 .57799 Mdot
.66441 .48992 Mdot
.2955 .61103 Mdot
.53228 .58682 Mdot
.48606 .69709 Mdot
.31103 .43886 Mdot
.33109 .614 Mdot
.63311 .46137 Mdot
.47422 .32095 Mdot
.64688 .56394 Mdot
.29139 .55973 Mdot
.74073 .49929 Mdot
.74075 .49935 Mdot
.5258 .30101 Mdot
.47819 .57748 Mdot
.36419 .39024 Mdot
.57954 .48862 Mdot
.33427 .50881 Mdot
.48876 .54054 Mdot
.23892 .62268 Mdot
.28212 .59031 Mdot
.32436 .59895 Mdot
.64813 .45165 Mdot
.29667 .63361 Mdot
.60624 .42628 Mdot
.35059 .62709 Mdot
.39834 .29458 Mdot
.70425 .48645 Mdot
.32626 .59289 Mdot
.49764 .59514 Mdot
.58988 .45422 Mdot
.46695 .31912 Mdot
.27809 .5958 Mdot
.58333 .44829 Mdot
.24085 .66387 Mdot
.32499 .44352 Mdot
.52496 .6005 Mdot
.59372 .64059 Mdot
.31838 .42279 Mdot
.50434 .31877 Mdot
.62918 .42653 Mdot
.507 .67541 Mdot
.49647 .30809 Mdot
.54688 .56512 Mdot
.49869 .6971 Mdot
.61068 .69075 Mdot
.49716 .32427 Mdot
.52936 .58705 Mdot
.47428 .69141 Mdot
.53658 .61545 Mdot
.32311 .5962 Mdot
.32454 .56423 Mdot
.52182 .57212 Mdot
.64071 .44843 Mdot
.35051 .60087 Mdot
.29457 .42893 Mdot
.6074 .43989 Mdot
.30084 .59623 Mdot
.51746 .59795 Mdot
.59915 .4731 Mdot
.71057 .50318 Mdot
.63464 .22214 Mdot
.49229 .55916 Mdot
.48817 .70172 Mdot
.48636 .36912 Mdot
.63604 .48492 Mdot
.49185 .71786 Mdot
.30039 .56098 Mdot
.61552 .48497 Mdot
.46875 .35452 Mdot
.55765 .38719 Mdot
.3253 .64004 Mdot
.32508 .40661 Mdot
.3045 .57334 Mdot
.51535 .7137 Mdot
.88124 .42624 Mdot
.50825 .60494 Mdot
.62935 .50116 Mdot
.66992 .47117 Mdot
.27991 .58376 Mdot
.48054 .31709 Mdot
.29974 .27563 Mdot
.67062 .45545 Mdot
.60513 .48265 Mdot
.62941 .45164 Mdot
.34955 .54182 Mdot
.50548 .2894 Mdot
.62859 .45001 Mdot
.51674 .52952 Mdot
.66655 .48095 Mdot
.51265 .70743 Mdot
.3414 .77922 Mdot
.53752 .58796 Mdot
.57063 .14812 Mdot
.50969 .59986 Mdot
.32799 .58963 Mdot
.71568 .58622 Mdot
.59129 .63998 Mdot
.37457 .59997 Mdot
.50582 .31635 Mdot
.41582 .31072 Mdot
.3338 .60834 Mdot
.29293 .53781 Mdot
.72146 .49822 Mdot
.69511 .50522 Mdot
.59377 .44471 Mdot
.3101 .61067 Mdot
.30849 .6352 Mdot
.48839 .58864 Mdot
.51594 .55996 Mdot
.57025 .46426 Mdot
.28833 .59201 Mdot
.61214 .44679 Mdot
.60668 .49829 Mdot
.31869 .45304 Mdot
.4615 .34518 Mdot
.31094 .45282 Mdot
.33116 .44451 Mdot
.72947 .30899 Mdot
.63527 .66709 Mdot
.28702 .4323 Mdot
.28128 .42993 Mdot
.3132 .51751 Mdot
.72119 .32864 Mdot
.51107 .71131 Mdot
.74204 .44923 Mdot
.34419 .60033 Mdot
.64832 .47842 Mdot
.50627 .28912 Mdot
.5165 .55268 Mdot
.33002 .25192 Mdot
.77987 .63944 Mdot
.67813 .49927 Mdot
.34729 .62009 Mdot
.52412 .57241 Mdot
.52618 .56949 Mdot
.59219 .75229 Mdot
.61603 .44739 Mdot
.31811 .63948 Mdot
.71043 .32724 Mdot
.29056 .46987 Mdot
.28631 .50366 Mdot
.49686 .36324 Mdot
.61126 .45573 Mdot
.4967 .28526 Mdot
.32055 .3989 Mdot
.49508 .71586 Mdot
.48216 .70051 Mdot
.62918 .43549 Mdot
.74384 .49251 Mdot
.33829 .50898 Mdot
.7072 .50518 Mdot
.69071 .50056 Mdot
.52165 .57821 Mdot
.66971 .50694 Mdot
.62339 .48452 Mdot
.68905 .49285 Mdot
.54099 .58258 Mdot
.31707 .45254 Mdot
.70956 .30865 Mdot
.5158 .56639 Mdot
.64906 .43251 Mdot
.32337 .40077 Mdot
.71425 .50365 Mdot
.29793 .4276 Mdot
.28895 .51088 Mdot
.29189 .44154 Mdot
.48532 .70554 Mdot
.33271 .64294 Mdot
.64328 .21631 Mdot
.4745 .35088 Mdot
.3057 .40499 Mdot
.47155 .69651 Mdot
.29808 .43231 Mdot
.34031 .59333 Mdot
.30422 .47529 Mdot
.53918 .3293 Mdot
.5937 .69804 Mdot
.74105 .32503 Mdot
.28865 .46721 Mdot
.32851 .63947 Mdot
.48159 .34641 Mdot
.30925 .49806 Mdot
.66412 .4467 Mdot
.48015 .70137 Mdot
.61889 .45493 Mdot
.31264 .43732 Mdot
.34792 .61001 Mdot
.62826 .23363 Mdot
.487 .70125 Mdot
.63599 .20001 Mdot
.28702 .58993 Mdot
.66368 .45567 Mdot
.33302 .40599 Mdot
.36393 .43451 Mdot
.33311 .43181 Mdot
.68425 .63416 Mdot
.48355 .58595 Mdot
.47936 .74808 Mdot
.4967 .31498 Mdot
.48605 .57163 Mdot
.66695 .78429 Mdot
.38511 .35966 Mdot
.47524 .30535 Mdot
.27562 .57879 Mdot
.6307 .43986 Mdot
.6626 .50616 Mdot
.49543 .58083 Mdot
.4818 .36127 Mdot
.66426 .5045 Mdot
.5239 .60433 Mdot
.64268 .69112 Mdot
.49485 .36611 Mdot
.31009 .56688 Mdot
.59235 .45159 Mdot
.34141 .42429 Mdot
.32961 .40607 Mdot
.51403 .60959 Mdot
.30904 .45039 Mdot
.64071 .42881 Mdot
.49204 .33192 Mdot
.72796 .49811 Mdot
.51618 .7008 Mdot
.40705 .35638 Mdot
.5344 .55859 Mdot
.47902 .6716 Mdot
.59294 .47164 Mdot
.3319 .61001 Mdot
.22388 .40292 Mdot
.6838 .47139 Mdot
.47773 .32509 Mdot
.66814 .46415 Mdot
.66673 .50585 Mdot
.7005 .5054 Mdot
.30951 .58538 Mdot
.61854 .66927 Mdot
.61181 .4476 Mdot
.3105 .39846 Mdot
.71593 .46928 Mdot
.68371 .45829 Mdot
.46933 .72832 Mdot
.73628 .49153 Mdot
.31339 .39147 Mdot
.52435 .31141 Mdot
.32812 .60958 Mdot
.48698 .30625 Mdot
.45602 .31957 Mdot
.50443 .31774 Mdot
.50685 .36013 Mdot
.57836 .48698 Mdot
.23683 .31859 Mdot
.62923 .25605 Mdot
.74496 .32437 Mdot
.46101 .31049 Mdot
.19358 .43216 Mdot
.47367 .30649 Mdot
.50479 .31801 Mdot
.4101 .21471 Mdot
.50893 .30912 Mdot
.64196 .45291 Mdot
.66465 .46675 Mdot
.76838 .4032 Mdot
.38058 .56089 Mdot
.60325 .474 Mdot
.54182 .58616 Mdot
.49761 .67102 Mdot
.49672 .37334 Mdot
.5107 .58195 Mdot
.60815 .68116 Mdot
.52299 .61163 Mdot
.6337 .45598 Mdot
.6023 .44831 Mdot
.71937 .5048 Mdot
.69514 .70975 Mdot
.39273 .57146 Mdot
.49902 .33763 Mdot
.68205 .45378 Mdot
.32221 .36423 Mdot
.59789 .44326 Mdot
.67415 .46967 Mdot
.58709 .48589 Mdot
.32918 .61039 Mdot
.49416 .27242 Mdot
.49667 .56922 Mdot
.40378 .35786 Mdot
.60396 .46412 Mdot
.52006 .54856 Mdot
.50096 .66515 Mdot
.62285 .44596 Mdot
.50802 .31902 Mdot
.66587 .50531 Mdot
.48138 .28382 Mdot
.49914 .31844 Mdot
.61096 .4842 Mdot
.49421 .37237 Mdot
.48761 .27641 Mdot
.69559 .50482 Mdot
.35198 .61105 Mdot
.39304 .30855 Mdot
.63624 .44648 Mdot
.48892 .6956 Mdot
.63226 .46969 Mdot
.51257 .71104 Mdot
.5352 .60102 Mdot
.52403 .57663 Mdot
.71763 .39353 Mdot
.2894 .62031 Mdot
.46663 .70277 Mdot
.28254 .62795 Mdot
.63964 .42168 Mdot
.43922 .32012 Mdot
.30291 .47099 Mdot
.2584 .59041 Mdot
.52319 .57891 Mdot
.55909 .72077 Mdot
.69507 .44356 Mdot
.29541 .44605 Mdot
.47017 .30515 Mdot
.69742 .31068 Mdot
.49296 .56347 Mdot
.31239 .56735 Mdot
.31408 .57521 Mdot
.38264 .37503 Mdot
.42404 .21449 Mdot
.65151 .45007 Mdot
.49865 .56011 Mdot
.56064 .49886 Mdot
.50889 .59024 Mdot
.48902 .5845 Mdot
.29281 .60858 Mdot
.59944 .47172 Mdot
.64754 .69071 Mdot
.30624 .59849 Mdot
.50672 .6853 Mdot
.49108 .29026 Mdot
.49334 .72037 Mdot
.33179 .28351 Mdot
.64361 .22603 Mdot
.31414 .60129 Mdot
.53821 .57929 Mdot
.64454 .48154 Mdot
.51291 .30735 Mdot
.4744 .26662 Mdot
.4631 .32679 Mdot
.51515 .68221 Mdot
.28373 .61784 Mdot
.24468 .68094 Mdot
.62542 .46445 Mdot
.48813 .32855 Mdot
.50485 .6587 Mdot
.6247 .47217 Mdot
.31225 .40558 Mdot
.66677 .5037 Mdot
.48278 .33633 Mdot
.62727 .4999 Mdot
.49727 .31504 Mdot
.32122 .57971 Mdot
.63636 .43841 Mdot
.61204 .43509 Mdot
.56701 .73897 Mdot
.49786 .67997 Mdot
.47534 .28942 Mdot
.63423 .65624 Mdot
.67065 .48687 Mdot
.60183 .75238 Mdot
.61139 .44317 Mdot
.74324 .32804 Mdot
.49167 .61124 Mdot
.52483 .60525 Mdot
.6693 .46745 Mdot
.63224 .44481 Mdot
.47746 .26623 Mdot
.63083 .26032 Mdot
.64513 .23489 Mdot
.32623 .4059 Mdot
.4693 .31149 Mdot
.30602 .60216 Mdot
.27625 .59784 Mdot
.34193 .61188 Mdot
.52031 .70245 Mdot
.72214 .5009 Mdot
.65161 .45987 Mdot
.28794 .40521 Mdot
.49642 .67407 Mdot
.48941 .31944 Mdot
.49339 .70717 Mdot
.62829 .67004 Mdot
.48836 .69168 Mdot
.49638 .59952 Mdot
.16225 .5027 Mdot
.60548 .49822 Mdot
.50002 .68897 Mdot
.46331 .34867 Mdot
.72123 .46955 Mdot
.58198 .46858 Mdot
.63577 .2138 Mdot
.48146 .67806 Mdot
.27907 .57279 Mdot
.59176 .46669 Mdot
.67907 .61384 Mdot
.3012 .43045 Mdot
.49108 .72066 Mdot
.31166 .44348 Mdot
.67681 .5006 Mdot
.42585 .27976 Mdot
.47573 .33343 Mdot
.3158 .45566 Mdot
.67365 .4741 Mdot
.49055 .7204 Mdot
.31803 .59952 Mdot
.72015 .32912 Mdot
.29324 .49949 Mdot
.4977 .55038 Mdot
.5904 .7497 Mdot
.31904 .63158 Mdot
.73529 .33976 Mdot
.3038 .44628 Mdot
.69632 .47256 Mdot
.6185 .49877 Mdot
.64223 .48786 Mdot
.30018 .60792 Mdot
.32497 .59957 Mdot
.24721 .5914 Mdot
.61494 .43353 Mdot
.58489 .48267 Mdot
.52592 .32839 Mdot
.28578 .62208 Mdot
.50407 .3175 Mdot
.48795 .36032 Mdot
.29435 .59735 Mdot
.46953 .30078 Mdot
.5002 .69682 Mdot
.65824 .66306 Mdot
.30165 .44552 Mdot
.33374 .41477 Mdot
.31602 .60255 Mdot
.30548 .62449 Mdot
.33241 .61054 Mdot
.66362 .5015 Mdot
.50041 .31946 Mdot
.6256 .42978 Mdot
.61642 .45941 Mdot
.58494 .47242 Mdot
.49927 .34822 Mdot
.66876 .45176 Mdot
.70678 .47837 Mdot
.50799 .67 Mdot
.33106 .59328 Mdot
.3264 .42823 Mdot
.64675 .56716 Mdot
.31037 .39748 Mdot
.66695 .48361 Mdot
.39846 .29913 Mdot
.47412 .30077 Mdot
.48408 .68813 Mdot
.74012 .49465 Mdot
.48448 .69924 Mdot
.31919 .45284 Mdot
.52531 .33357 Mdot
.61596 .69298 Mdot
.63226 .43289 Mdot
.63013 .66292 Mdot
.46015 .78849 Mdot
.51094 .38496 Mdot
.3213 .42599 Mdot
.62643 .49633 Mdot
.51535 .61207 Mdot
.56591 .47565 Mdot
.64953 .45493 Mdot
.6866 .46113 Mdot
.67089 .60726 Mdot
.66735 .47781 Mdot
.4662 .35772 Mdot
.71282 .47608 Mdot
.53486 .56884 Mdot
.58715 .46832 Mdot
.24712 .32031 Mdot
.61056 .47643 Mdot
.62646 .43288 Mdot
.65048 .46845 Mdot
.686 .48201 Mdot
.50136 .34429 Mdot
.73291 .49863 Mdot
.31672 .39876 Mdot
.65838 .66377 Mdot
.29872 .44328 Mdot
.31579 .60768 Mdot
.50657 .55346 Mdot
.51087 .28342 Mdot
.48434 .69827 Mdot
.39145 .54123 Mdot
.6821 .6178 Mdot
.34627 .5985 Mdot
.55859 .73433 Mdot
.47613 .7159 Mdot
.49139 .58659 Mdot
.51399 .7173 Mdot
.29587 .60809 Mdot
.30666 .408 Mdot
.65123 .44501 Mdot
.49177 .33967 Mdot
.46969 .34662 Mdot
.58798 .46811 Mdot
.38769 .31884 Mdot
.33096 .40953 Mdot
.26174 .62272 Mdot
.65517 .45701 Mdot
.67283 .48288 Mdot
.48553 .28109 Mdot
.34107 .62313 Mdot
.69627 .44624 Mdot
.51065 .70269 Mdot
.59715 .44587 Mdot
.53104 .56711 Mdot
.62857 .66871 Mdot
.32446 .4044 Mdot
.52282 .59636 Mdot
.63435 .47998 Mdot
.63191 .67647 Mdot
.6428 .50239 Mdot
.52302 .52744 Mdot
.34953 .63423 Mdot
.60468 .4823 Mdot
.60722 .43648 Mdot
.49543 .365 Mdot
.3054 .44741 Mdot
.47864 .31669 Mdot
.53267 .31229 Mdot
.52387 .57732 Mdot
.33027 .43751 Mdot
.68378 .48341 Mdot
.27686 .41898 Mdot
.67068 .50422 Mdot
.6254 .46057 Mdot
.31925 .42799 Mdot
.50283 .3078 Mdot
.288 .28857 Mdot
.70818 .30812 Mdot
.68156 .50091 Mdot
.63167 .4713 Mdot
.38106 .56153 Mdot
.51729 .55267 Mdot
.6498 .43918 Mdot
.47031 .35063 Mdot
.62352 .47084 Mdot
.27784 .43716 Mdot
.49132 .71238 Mdot
.4747 .3266 Mdot
.3406 .62708 Mdot
.31569 .57972 Mdot
.35402 .63481 Mdot
.49358 .59714 Mdot
.67067 .50702 Mdot
.48705 .36851 Mdot
.48624 .36432 Mdot
.62184 .64454 Mdot
.32806 .59008 Mdot
.50069 .70968 Mdot
.59057 .44709 Mdot
.50719 .55761 Mdot
.3387 .41196 Mdot
.56658 .14544 Mdot
.61992 .69224 Mdot
.51736 .6751 Mdot
.55643 .53138 Mdot
.51968 .5816 Mdot
.65277 .48187 Mdot
.48874 .71849 Mdot
.29576 .59723 Mdot
.6546 .50634 Mdot
.49802 .53651 Mdot
.27716 .57362 Mdot
.32541 .62309 Mdot
.28042 .41147 Mdot
.34475 .63162 Mdot
.4948 .72428 Mdot
.50682 .60447 Mdot
.46933 .3354 Mdot
.61898 .44569 Mdot
.51068 .56971 Mdot
.33316 .58998 Mdot
.48973 .57137 Mdot
.66038 .45866 Mdot
.48655 .28382 Mdot
.34257 .60436 Mdot
.63816 .45626 Mdot
.58519 .49393 Mdot
.63522 .22398 Mdot
.34948 .61464 Mdot
.61737 .4257 Mdot
.44265 .55447 Mdot
.32739 .6204 Mdot
.29903 .61056 Mdot
.62047 .4856 Mdot
.47908 .71513 Mdot
.60602 .46005 Mdot
.31219 .40735 Mdot
.62224 .66312 Mdot
.32337 .44436 Mdot
.59201 .75438 Mdot
.59069 .47391 Mdot
.56348 .45919 Mdot
.43976 .32757 Mdot
.48292 .66179 Mdot
.64998 .73969 Mdot
.63548 .48435 Mdot
.48377 .27203 Mdot
.61625 .66772 Mdot
.59316 .68782 Mdot
.55092 .33765 Mdot
.50395 .71806 Mdot
.30495 .4339 Mdot
.61931 .43519 Mdot
.25846 .31972 Mdot
.50788 .71139 Mdot
.59345 .75306 Mdot
.67217 .45124 Mdot
.48367 .32523 Mdot
.6507 .45117 Mdot
.47223 .33844 Mdot
.63443 .47619 Mdot
.62995 .2264 Mdot
.33798 .50879 Mdot
.68411 .63342 Mdot
.49627 .59203 Mdot
.36398 .43426 Mdot
.74152 .32487 Mdot
.50029 .70115 Mdot
.62414 .49828 Mdot
.51923 .58721 Mdot
.29771 .41417 Mdot
.25066 .38753 Mdot
.3347 .6089 Mdot
.30438 .40091 Mdot
.49172 .29964 Mdot
.34531 .59146 Mdot
.48599 .573 Mdot
.56206 .45574 Mdot
.4872 .71934 Mdot
.33112 .43637 Mdot
.62491 .4439 Mdot
.65512 .49097 Mdot
.34546 .53938 Mdot
.35395 .78622 Mdot
.46978 .36763 Mdot
.6348 .19551 Mdot
.52542 .33277 Mdot
.5039 .67961 Mdot
.35186 .60854 Mdot
.64503 .46608 Mdot
.59823 .46388 Mdot
.32466 .62422 Mdot
.51343 .3044 Mdot
.46855 .70597 Mdot
.47927 .74881 Mdot
.27959 .41959 Mdot
.40508 .80656 Mdot
.47307 .32833 Mdot
.40266 .80574 Mdot
.23785 .63609 Mdot
.46068 .21988 Mdot
.64305 .74195 Mdot
.31822 .41873 Mdot
.40415 .80662 Mdot
.48573 .32669 Mdot
.661 .47206 Mdot
.52746 .58527 Mdot
.48918 .59362 Mdot
.49198 .28437 Mdot
.31461 .61199 Mdot
.48239 .72094 Mdot
.64597 .44826 Mdot
.5225 .51742 Mdot
.47431 .26583 Mdot
.28398 .61211 Mdot
.50479 .58623 Mdot
.32859 .42163 Mdot
.62767 .4722 Mdot
.51083 .67478 Mdot
.31672 .41859 Mdot
.53321 .59618 Mdot
.67044 .63555 Mdot
.62795 .42629 Mdot
.74344 .49515 Mdot
.30062 .42789 Mdot
.55752 .53647 Mdot
.60719 .43846 Mdot
.304 .44632 Mdot
.51844 .6161 Mdot
.36906 .38868 Mdot
.66849 .42503 Mdot
.38507 .35985 Mdot
.32871 .5722 Mdot
.35154 .62418 Mdot
.27761 .67492 Mdot
.38544 .61111 Mdot
.28959 .43149 Mdot
.51333 .5747 Mdot
.33227 .7757 Mdot
.30894 .44808 Mdot
.67942 .46954 Mdot
.62468 .43693 Mdot
.70947 .32695 Mdot
.53617 .59109 Mdot
.50872 .60078 Mdot
.43899 .25484 Mdot
.70796 .49459 Mdot
.50548 .58453 Mdot
.60721 .4417 Mdot
.50304 .33326 Mdot
.32495 .41692 Mdot
.79695 .67503 Mdot
.28965 .45907 Mdot
.68569 .51147 Mdot
.34517 .60208 Mdot
.33174 .57442 Mdot
.62213 .447 Mdot
.43476 .54058 Mdot
.86533 .52883 Mdot
.62346 .43643 Mdot
.73989 .49421 Mdot
.58765 .75395 Mdot
.58741 .47062 Mdot
.4581 .33799 Mdot
.53545 .58124 Mdot
.49577 .35513 Mdot
.31586 .42373 Mdot
.5043 .71754 Mdot
.50048 .64819 Mdot
.30484 .43308 Mdot
.60395 .47011 Mdot
.54194 .56747 Mdot
.62437 .45356 Mdot
.65687 .47097 Mdot
.62747 .67738 Mdot
.51985 .68185 Mdot
.32592 .61317 Mdot
.48361 .7025 Mdot
.50677 .31492 Mdot
.60554 .17209 Mdot
.49803 .7044 Mdot
.72046 .3286 Mdot
.62866 .65716 Mdot
.33946 .77714 Mdot
.46866 .34392 Mdot
.51616 .70483 Mdot
.30456 .43566 Mdot
.59448 .65419 Mdot
.73962 .35218 Mdot
.30497 .39956 Mdot
.65392 .47167 Mdot
.49368 .35447 Mdot
.52628 .30881 Mdot
.32656 .39903 Mdot
.4668 .32739 Mdot
.6297 .41256 Mdot
.69848 .4991 Mdot
.31721 .39829 Mdot
.67371 .72593 Mdot
.33511 .42667 Mdot
.72041 .30266 Mdot
.67771 .50428 Mdot
.47647 .32594 Mdot
.75271 .33 Mdot
.52724 .33695 Mdot
.51705 .6055 Mdot
.66467 .45237 Mdot
.50006 .70671 Mdot
.62771 .64978 Mdot
.34613 .62385 Mdot
.51284 .37296 Mdot
.48053 .3432 Mdot
.33868 .408 Mdot
.46714 .32835 Mdot
.47073 .3027 Mdot
.31841 .45432 Mdot
.471 .30851 Mdot
.60352 .46448 Mdot
.64897 .20819 Mdot
.46466 .32667 Mdot
.30711 .42276 Mdot
.51406 .68211 Mdot
.46192 .34837 Mdot
.28362 .54276 Mdot
.59158 .45371 Mdot
.29276 .57345 Mdot
.51927 .72639 Mdot
.50178 .34125 Mdot
.50167 .7025 Mdot
.33677 .59384 Mdot
.47622 .68109 Mdot
.28567 .39711 Mdot
.29477 .39282 Mdot
.49065 .61749 Mdot
.37921 .40115 Mdot
.50863 .30989 Mdot
.34743 .59377 Mdot
.5969 .43743 Mdot
.65721 .46238 Mdot
.52759 .70223 Mdot
.47794 .28358 Mdot
.3857 .31562 Mdot
.50925 .58214 Mdot
.4081 .35738 Mdot
.32855 .40691 Mdot
.26131 .62013 Mdot
.61545 .69458 Mdot
.2931 .48926 Mdot
.53544 .56905 Mdot
.52044 .58273 Mdot
.62987 .45129 Mdot
.57096 .7424 Mdot
.49749 .72336 Mdot
.18812 .4474 Mdot
.65773 .49881 Mdot
.32066 .62634 Mdot
.64285 .47622 Mdot
.7191 .4946 Mdot
.63102 .48483 Mdot
.51955 .67781 Mdot
.28933 .41141 Mdot
.47322 .35112 Mdot
.51477 .70866 Mdot
.31458 .57939 Mdot
.71136 .60488 Mdot
.64561 .43657 Mdot
.60148 .4268 Mdot
.3203 .61764 Mdot
.50143 .32641 Mdot
.32148 .605 Mdot
.30168 .44535 Mdot
.4954 .70411 Mdot
.66285 .5038 Mdot
.53644 .59013 Mdot
.27908 .58507 Mdot
.30309 .40596 Mdot
.35308 .60897 Mdot
.27714 .44688 Mdot
.52312 .58109 Mdot
.5893 .42902 Mdot
.31213 .63912 Mdot
.51336 .56157 Mdot
.6582 .32141 Mdot
.66944 .63179 Mdot
.54079 .28416 Mdot
.31277 .61316 Mdot
.36943 .5938 Mdot
.31313 .41988 Mdot
.29596 .4555 Mdot
.71979 .29935 Mdot
.86157 .47689 Mdot
.7115 .46444 Mdot
.37433 .33279 Mdot
.30047 .44519 Mdot
.3005 .42054 Mdot
.32395 .60723 Mdot
.50316 .30393 Mdot
.4438 .34739 Mdot
.33187 .57892 Mdot
.62288 .74697 Mdot
.48941 .31983 Mdot
.76757 .39804 Mdot
.28253 .59789 Mdot
.69945 .50639 Mdot
.62765 .23238 Mdot
.50204 .66722 Mdot
.58617 .74681 Mdot
.30293 .47354 Mdot
.64324 .45724 Mdot
.23895 .31663 Mdot
.33461 .60605 Mdot
.49666 .5652 Mdot
.33655 .37088 Mdot
.67291 .48997 Mdot
.6468 .47705 Mdot
.61237 .46773 Mdot
.50869 .7278 Mdot
.63308 .27708 Mdot
.64441 .46094 Mdot
.6762 .63137 Mdot
.71792 .50957 Mdot
.30409 .55624 Mdot
.48413 .7035 Mdot
.55617 .72994 Mdot
.30699 .53234 Mdot
.40182 .35857 Mdot
.68632 .46014 Mdot
.28399 .44567 Mdot
.71974 .49335 Mdot
.31902 .43011 Mdot
.30763 .39325 Mdot
.42603 .82112 Mdot
.47394 .35717 Mdot
.66251 .49958 Mdot
.28905 .61363 Mdot
.44301 .34675 Mdot
.72264 .49558 Mdot
.61673 .17907 Mdot
.34558 .41616 Mdot
.88273 .42078 Mdot
.29664 .45358 Mdot
.48691 .58072 Mdot
.48675 .29847 Mdot
.47967 .27033 Mdot
.63126 .66369 Mdot
.50422 .3154 Mdot
.3913 .60003 Mdot
.48304 .368 Mdot
.53565 .81348 Mdot
.54279 .33419 Mdot
.31042 .41573 Mdot
.33071 .4022 Mdot
.7229 .50247 Mdot
.60348 .45664 Mdot
.64456 .69146 Mdot
.50867 .58294 Mdot
.65175 .43576 Mdot
.30588 .59818 Mdot
.26472 .56188 Mdot
.2333 .38027 Mdot
.47272 .30538 Mdot
.29619 .41183 Mdot
.64585 .47634 Mdot
.67523 .50349 Mdot
.66521 .4641 Mdot
.32162 .51178 Mdot
.77984 .40808 Mdot
.61841 .45852 Mdot
.72103 .50185 Mdot
.34002 .58974 Mdot
.34865 .54162 Mdot
.43455 .21523 Mdot
.41638 .81388 Mdot
.59982 .47486 Mdot
.50026 .6763 Mdot
.52196 .6896 Mdot
.71142 .48955 Mdot
.54083 .44135 Mdot
.5532 .61951 Mdot
.62613 .444 Mdot
.713 .59876 Mdot
.30365 .5654 Mdot
.51285 .61097 Mdot
.33115 .58885 Mdot
.46049 .30764 Mdot
.52446 .60853 Mdot
.29993 .59914 Mdot
.67941 .65612 Mdot
.52078 .57314 Mdot
.36579 .38782 Mdot
.51659 .70048 Mdot
.60666 .44054 Mdot
.68743 .28851 Mdot
.28522 .62185 Mdot
.31021 .40965 Mdot
.47995 .30424 Mdot
.32415 .40534 Mdot
.36595 .63226 Mdot
.60805 .75339 Mdot
.52118 .60385 Mdot
.28284 .44479 Mdot
.74052 .49109 Mdot
.49588 .67532 Mdot
.30294 .45249 Mdot
.69683 .51071 Mdot
.70707 .4894 Mdot
.85184 .5183 Mdot
.59273 .43727 Mdot
.25761 .57139 Mdot
.32335 .4453 Mdot
.51882 .61252 Mdot
.6179 .44625 Mdot
.28834 .58499 Mdot
.526 .62015 Mdot
.62594 .4547 Mdot
.32947 .63116 Mdot
.62236 .43768 Mdot
.48599 .71363 Mdot
.49533 .36147 Mdot
.61204 .66955 Mdot
.46863 .74305 Mdot
.50765 .71572 Mdot
.68253 .61446 Mdot
.65928 .44511 Mdot
.39093 .61015 Mdot
.48344 .32166 Mdot
.66632 .48323 Mdot
.53701 .79257 Mdot
.49582 .29274 Mdot
.48976 .30653 Mdot
.66889 .50951 Mdot
.27993 .44834 Mdot
.32333 .61512 Mdot
.48592 .68311 Mdot
.28654 .50166 Mdot
.64058 .45838 Mdot
.63078 .49837 Mdot
.51101 .71055 Mdot
.31936 .40887 Mdot
.67195 .49995 Mdot
.35689 .36298 Mdot
.66075 .65747 Mdot
.32625 .44687 Mdot
.68852 .46424 Mdot
.78081 .39344 Mdot
.51031 .28865 Mdot
.23832 .31867 Mdot
.33847 .50857 Mdot
.31428 .5765 Mdot
.50426 .58306 Mdot
.57385 .15109 Mdot
.51578 .68346 Mdot
.48848 .3865 Mdot
.65939 .46006 Mdot
.64086 .46973 Mdot
.50853 .32202 Mdot
.61951 .42998 Mdot
.47204 .30447 Mdot
.28707 .54103 Mdot
.86672 .46452 Mdot
.47007 .342 Mdot
.47854 .33809 Mdot
.76308 .4754 Mdot
.29432 .63533 Mdot
.48929 .29015 Mdot
.60868 .43464 Mdot
.36884 .63045 Mdot
.53034 .52271 Mdot
.46926 .70041 Mdot
.50009 .73027 Mdot
.45704 .3416 Mdot
.74322 .35442 Mdot
.70153 .50937 Mdot
.7107 .37203 Mdot
.54947 .62818 Mdot
.28944 .43418 Mdot
.61621 .49019 Mdot
.51343 .58285 Mdot
.33661 .59799 Mdot
.58077 .46614 Mdot
.60422 .44294 Mdot
.47761 .35415 Mdot
.48691 .67175 Mdot
.31269 .44585 Mdot
.51074 .5617 Mdot
.36524 .62925 Mdot
.50878 .69368 Mdot
.47054 .30027 Mdot
.73675 .31732 Mdot
.53386 .55995 Mdot
.50899 .55822 Mdot
.65407 .48314 Mdot
.61521 .48465 Mdot
.53626 .56644 Mdot
.3065 .43193 Mdot
.31144 .57497 Mdot
.49799 .56871 Mdot
.60574 .63922 Mdot
.65787 .68294 Mdot
.63479 .48333 Mdot
.46539 .35004 Mdot
.2972 .41301 Mdot
.51367 .60365 Mdot
.32473 .77027 Mdot
.58779 .45557 Mdot
.76967 .39922 Mdot
.47562 .73061 Mdot
.51523 .57909 Mdot
.44408 .34888 Mdot
.48264 .69346 Mdot
.67776 .50409 Mdot
.6788 .63276 Mdot
.66216 .44253 Mdot
.69602 .4721 Mdot
.29482 .60047 Mdot
.31529 .4389 Mdot
.48648 .61329 Mdot
.33155 .59497 Mdot
.48795 .30628 Mdot
.71385 .37916 Mdot
.4893 .35681 Mdot
.48327 .36473 Mdot
.5065 .36369 Mdot
.32779 .4094 Mdot
.57302 .15002 Mdot
.53134 .56049 Mdot
.64775 .4453 Mdot
.28661 .42297 Mdot
.48473 .29126 Mdot
.6717 .45536 Mdot
.47378 .30126 Mdot
.47409 .29007 Mdot
.65835 .43909 Mdot
.71002 .50344 Mdot
.68228 .628 Mdot
.76864 .38559 Mdot
.4812 .70411 Mdot
.51183 .30342 Mdot
.75709 .37282 Mdot
.64372 .46524 Mdot
.60195 .44964 Mdot
.72681 .50149 Mdot
.51225 .71518 Mdot
.71607 .39086 Mdot
.65881 .46339 Mdot
.56595 .74444 Mdot
.67405 .46093 Mdot
.47789 .28254 Mdot
.36583 .41736 Mdot
.68873 .51167 Mdot
.34284 .59016 Mdot
.51344 .30614 Mdot
.50138 .66681 Mdot
.49889 .26625 Mdot
.58121 .48787 Mdot
.29612 .43021 Mdot
.4827 .33629 Mdot
.32603 .57487 Mdot
.31446 .41025 Mdot
.33496 .42659 Mdot
.72839 .50173 Mdot
.30209 .57694 Mdot
.48813 .67077 Mdot
.32724 .43478 Mdot
.56725 .48043 Mdot
.31055 .41432 Mdot
.57702 .37045 Mdot
.59393 .42877 Mdot
.67622 .63325 Mdot
.4983 .5764 Mdot
.49082 .61227 Mdot
.32534 .44121 Mdot
.51146 .70329 Mdot
.67107 .49981 Mdot
.46575 .32029 Mdot
.50982 .6787 Mdot
.62806 .23809 Mdot
.33425 .57702 Mdot
.52573 .31139 Mdot
.29095 .499 Mdot
.50508 .29562 Mdot
.58896 .74829 Mdot
.50915 .66811 Mdot
.50087 .55786 Mdot
.61483 .67838 Mdot
.50545 .59084 Mdot
.58097 .458 Mdot
.66981 .49955 Mdot
.60438 .4667 Mdot
.34571 .60267 Mdot
.50511 .7285 Mdot
.46226 .3353 Mdot
.47199 .53873 Mdot
.3223 .40832 Mdot
.72191 .48262 Mdot
.49611 .56749 Mdot
.67635 .50135 Mdot
.48052 .29626 Mdot
.48877 .27523 Mdot
.63166 .26398 Mdot
.33112 .61999 Mdot
.47388 .55187 Mdot
.6315 .48286 Mdot
.48765 .5255 Mdot
.32613 .44107 Mdot
.38462 .36327 Mdot
.29349 .57074 Mdot
.88219 .41817 Mdot
.32858 .59282 Mdot
.51576 .53354 Mdot
.49665 .28121 Mdot
.49196 .69481 Mdot
.60234 .47113 Mdot
.49711 .3653 Mdot
.44686 .35835 Mdot
.52446 .67036 Mdot
.48496 .69612 Mdot
.31287 .5002 Mdot
.28742 .43533 Mdot
.515 .56057 Mdot
.67526 .46281 Mdot
.67007 .45077 Mdot
.60195 .43473 Mdot
.29118 .41707 Mdot
.70668 .5004 Mdot
.36184 .43774 Mdot
.6029 .49751 Mdot
.53862 .79313 Mdot
.30128 .61621 Mdot
.18831 .6016 Mdot
.49995 .34453 Mdot
.71569 .38721 Mdot
.57161 .3837 Mdot
.66718 .6354 Mdot
.28687 .4126 Mdot
.52247 .61602 Mdot
.32296 .6108 Mdot
.23335 .40423 Mdot
.29982 .61646 Mdot
.8362 .6088 Mdot
.70835 .32577 Mdot
.36708 .4062 Mdot
.65913 .44198 Mdot
.29188 .59602 Mdot
.74872 .35726 Mdot
.4999 .56798 Mdot
.54232 .56845 Mdot
.60808 .50096 Mdot
.64353 .23317 Mdot
.48166 .70642 Mdot
.60434 .47407 Mdot
.49625 .35232 Mdot
.60061 .46856 Mdot
.60136 .47119 Mdot
.66185 .46233 Mdot
.33204 .44564 Mdot
.59417 .4274 Mdot
.60302 .46011 Mdot
.25197 .69927 Mdot
.55367 .57002 Mdot
.34686 .63201 Mdot
.48259 .26725 Mdot
.49629 .6741 Mdot
.46157 .30571 Mdot
.61287 .67337 Mdot
.29839 .45698 Mdot
.63078 .26616 Mdot
.69303 .50304 Mdot
.49823 .37799 Mdot
.2884 .45652 Mdot
.47576 .71156 Mdot
.51586 .58493 Mdot
.33726 .24568 Mdot
.28322 .62875 Mdot
.51425 .5972 Mdot
.33617 .62765 Mdot
.56457 .4643 Mdot
.46964 .3322 Mdot
.50585 .59007 Mdot
.31716 .44286 Mdot
.29332 .61015 Mdot
.68334 .61817 Mdot
.62203 .46768 Mdot
.30849 .61207 Mdot
.51088 .57174 Mdot
.62836 .65084 Mdot
.61768 .66736 Mdot
.29047 .5987 Mdot
.28909 .40261 Mdot
.33278 .42385 Mdot
.50221 .67222 Mdot
.49668 .2778 Mdot
.49583 .33471 Mdot
.3233 .41218 Mdot
.23008 .41336 Mdot
.63956 .45642 Mdot
.62491 .46223 Mdot
.6114 .68694 Mdot
.67836 .47827 Mdot
.39543 .58217 Mdot
.51233 .59501 Mdot
.48583 .34622 Mdot
.67068 .49946 Mdot
.67476 .49818 Mdot
.6084 .4764 Mdot
.62491 .74861 Mdot
.34383 .60133 Mdot
.70971 .50843 Mdot
.48961 .71932 Mdot
.63863 .23267 Mdot
.59505 .44598 Mdot
.46343 .69424 Mdot
.49815 .28072 Mdot
.29532 .36247 Mdot
.30839 .4102 Mdot
.28905 .61743 Mdot
.28879 .61493 Mdot
.46338 .79041 Mdot
.50192 .33827 Mdot
.51311 .59688 Mdot
.27822 .57171 Mdot
.50019 .60169 Mdot
.48576 .69241 Mdot
.6732 .42506 Mdot
.39514 .58648 Mdot
.34625 .63198 Mdot
.27764 .45705 Mdot
.66537 .4894 Mdot
.59626 .44763 Mdot
.38809 .34172 Mdot
.6099 .44382 Mdot
.49657 .71052 Mdot
.29338 .44726 Mdot
.48318 .33399 Mdot
.47903 .7062 Mdot
.28644 .4504 Mdot
.50343 .32026 Mdot
.71694 .50543 Mdot
.673 .45764 Mdot
.48487 .30407 Mdot
.47577 .29284 Mdot
.64152 .4515 Mdot
.44353 .83345 Mdot
.47702 .3516 Mdot
.48262 .30154 Mdot
.63956 .23321 Mdot
.31919 .63918 Mdot
.52869 .61903 Mdot
.27913 .44222 Mdot
.60595 .46287 Mdot
.30677 .61867 Mdot
.4933 .68624 Mdot
.48372 .34213 Mdot
.61008 .48268 Mdot
.63794 .46038 Mdot
.49842 .67533 Mdot
.50472 .7253 Mdot
.51389 .6939 Mdot
.32584 .39863 Mdot
.69425 .50531 Mdot
.48682 .29428 Mdot
.29791 .40357 Mdot
.51254 .67475 Mdot
.49824 .72634 Mdot
.57548 .80229 Mdot
.64095 .45424 Mdot
.50981 .72406 Mdot
.59511 .16578 Mdot
.68838 .64866 Mdot
.50756 .60719 Mdot
.35843 .61681 Mdot
.37288 .62498 Mdot
.54106 .5356 Mdot
.31251 .43943 Mdot
.73326 .49193 Mdot
.4706 .70225 Mdot
.50715 .56814 Mdot
.62263 .46451 Mdot
.59151 .47938 Mdot
.50884 .67981 Mdot
.60645 .75475 Mdot
.4803 .35621 Mdot
.51542 .25009 Mdot
.49463 .67491 Mdot
.28879 .59701 Mdot
.29434 .56796 Mdot
.3248 .59631 Mdot
.6256 .48325 Mdot
.76969 .4335 Mdot
.55128 .45499 Mdot
.66028 .375 Mdot
.28925 .43884 Mdot
.48644 .27663 Mdot
.63893 .22574 Mdot
.49128 .30733 Mdot
.3415 .61756 Mdot
.51106 .70417 Mdot
.50559 .32627 Mdot
.33284 .41215 Mdot
.33185 .43019 Mdot
.31089 .63863 Mdot
.32648 .5881 Mdot
.31597 .6004 Mdot
.51532 .30056 Mdot
.4891 .28287 Mdot
.66489 .4476 Mdot
.46475 .34389 Mdot
.29037 .54096 Mdot
.29042 .53912 Mdot
.29161 .63006 Mdot
.30882 .4272 Mdot
.49866 .31882 Mdot
.61225 .4359 Mdot
.66777 .60601 Mdot
.27951 .57721 Mdot
.49079 .67205 Mdot
.64846 .20727 Mdot
.85803 .48519 Mdot
.63711 .49656 Mdot
.29248 .43259 Mdot
.50058 .59814 Mdot
.61309 .47091 Mdot
.31529 .57557 Mdot
.50316 .54691 Mdot
.53474 .58554 Mdot
.60185 .42945 Mdot
.63522 .42523 Mdot
.296 .41865 Mdot
.60989 .67413 Mdot
.50686 .56628 Mdot
.73452 .50582 Mdot
.28692 .44227 Mdot
.28029 .58757 Mdot
.26134 .66798 Mdot
.41844 .28223 Mdot
.55755 .68289 Mdot
.53059 .60079 Mdot
.58686 .45216 Mdot
.30478 .59457 Mdot
.47849 .70946 Mdot
.30956 .59414 Mdot
.45998 .31263 Mdot
.32454 .63999 Mdot
.61617 .43744 Mdot
.48967 .29299 Mdot
.33309 .42891 Mdot
.58778 .65295 Mdot
.46796 .59983 Mdot
.28648 .58746 Mdot
.50808 .55607 Mdot
.70686 .49511 Mdot
.56001 .46827 Mdot
.49165 .61266 Mdot
.60218 .44168 Mdot
.31987 .42791 Mdot
.47542 .30149 Mdot
.31382 .40374 Mdot
.51877 .6212 Mdot
.54719 .38448 Mdot
.30624 .41053 Mdot
.76864 .44425 Mdot
.48314 .7218 Mdot
.61329 .75273 Mdot
.62702 .44158 Mdot
.31744 .44099 Mdot
.60273 .42707 Mdot
.51171 .3078 Mdot
.66922 .66636 Mdot
.6627 .65111 Mdot
.32514 .41857 Mdot
.48274 .58401 Mdot
.62823 .65563 Mdot
.53018 .61885 Mdot
.29991 .44414 Mdot
.69752 .64241 Mdot
.52103 .59364 Mdot
.50617 .6915 Mdot
.49802 .7276 Mdot
.50705 .70023 Mdot
.61783 .46038 Mdot
.77407 .36867 Mdot
.51805 .68156 Mdot
.26328 .37918 Mdot
.49564 .71562 Mdot
.54081 .53175 Mdot
.38765 .31188 Mdot
.4939 .72385 Mdot
.61768 .44208 Mdot
.61348 .49735 Mdot
.73645 .49284 Mdot
.30885 .57021 Mdot
.31605 .26334 Mdot
.24957 .69414 Mdot
.6455 .46628 Mdot
.64041 .21579 Mdot
.49236 .36694 Mdot
.49971 .55736 Mdot
.66422 .64612 Mdot
.74742 .49335 Mdot
.49475 .30408 Mdot
.6129 .67664 Mdot
.52292 .30918 Mdot
.49267 .58452 Mdot
.62282 .4598 Mdot
.51344 .30783 Mdot
.51333 .37236 Mdot
.65176 .73867 Mdot
.40128 .34977 Mdot
.50016 .3214 Mdot
.30547 .44753 Mdot
.30907 .43835 Mdot
.32222 .42536 Mdot
.3213 .58289 Mdot
.47888 .34027 Mdot
.70371 .48793 Mdot
.31758 .57772 Mdot
.65518 .4696 Mdot
.32491 .41525 Mdot
.66732 .64341 Mdot
.47933 .33715 Mdot
.62873 .4439 Mdot
.74911 .36444 Mdot
.32214 .63106 Mdot
.50139 .67565 Mdot
.64242 .21194 Mdot
.35554 .60944 Mdot
.27676 .42008 Mdot
.45602 .32552 Mdot
.55279 .57515 Mdot
.73726 .5037 Mdot
.64701 .48549 Mdot
.64999 .44331 Mdot
.74189 .50095 Mdot
.7103 .3223 Mdot
.53129 .56986 Mdot
.31498 .5796 Mdot
.32572 .63904 Mdot
.59009 .45209 Mdot
.47618 .34334 Mdot
.50729 .6617 Mdot
.46496 .69883 Mdot
.49155 .53821 Mdot
.62585 .66371 Mdot
.6759 .63157 Mdot
.68431 .48105 Mdot
.73119 .4183 Mdot
.32074 .57355 Mdot
.4999 .60441 Mdot
.62687 .66945 Mdot
.50153 .69783 Mdot
.66034 .4712 Mdot
.46552 .27616 Mdot
.48515 .33811 Mdot
.31517 .6138 Mdot
.3411 .42484 Mdot
.53628 .56148 Mdot
.29223 .631 Mdot
.59011 .45249 Mdot
.67383 .49867 Mdot
.30858 .45026 Mdot
.45768 .32401 Mdot
.50772 .68553 Mdot
.32319 .57926 Mdot
.49504 .69612 Mdot
.46881 .32494 Mdot
.4843 .34247 Mdot
.66512 .47631 Mdot
.47478 .54714 Mdot
.28413 .59003 Mdot
.6113 .48055 Mdot
.30602 .60732 Mdot
.34402 .53862 Mdot
.33758 .41076 Mdot
.66714 .48171 Mdot
.44007 .33518 Mdot
.32685 .41537 Mdot
.64737 .46911 Mdot
.73606 .49689 Mdot
.67434 .50001 Mdot
.2915 .59464 Mdot
.4652 .71041 Mdot
.50238 .69175 Mdot
.58799 .38286 Mdot
.62535 .24894 Mdot
.68067 .48541 Mdot
.28915 .62517 Mdot
.59675 .50105 Mdot
.29769 .42114 Mdot
.50144 .28753 Mdot
.1609 .54574 Mdot
.30664 .42083 Mdot
.62768 .43947 Mdot
.4978 .70534 Mdot
.47418 .29272 Mdot
.52042 .60997 Mdot
.60818 .71531 Mdot
.48123 .59703 Mdot
.47952 .54237 Mdot
.52056 .56457 Mdot
.37732 .3311 Mdot
.31353 .59882 Mdot
.48261 .29396 Mdot
.29435 .43652 Mdot
.29608 .42618 Mdot
.33916 .62463 Mdot
.62928 .24293 Mdot
.45349 .21816 Mdot
.59036 .15869 Mdot
.27287 .61568 Mdot
.50509 .70917 Mdot
.671 .66264 Mdot
.32613 .59778 Mdot
.34724 .62501 Mdot
.32722 .51583 Mdot
.38772 .34509 Mdot
.50134 .30844 Mdot
.63874 .46158 Mdot
.63452 .2235 Mdot
.65696 .45431 Mdot
.55859 .67699 Mdot
.32225 .41413 Mdot
.5018 .28789 Mdot
.35769 .47572 Mdot
.59241 .47278 Mdot
.63009 .47749 Mdot
.2781 .54834 Mdot
.50998 .58561 Mdot
.36147 .78704 Mdot
.66413 .45757 Mdot
.3161 .58585 Mdot
.42798 .31284 Mdot
.4942 .57849 Mdot
.7509 .36479 Mdot
.31946 .44796 Mdot
.51861 .60401 Mdot
.49364 .57731 Mdot
.73608 .42475 Mdot
.52479 .32159 Mdot
.49799 .3359 Mdot
.513 .71907 Mdot
.4003 .29855 Mdot
.31416 .45218 Mdot
.36406 .35292 Mdot
.60748 .43611 Mdot
.31066 .39079 Mdot
.47882 .74784 Mdot
.64943 .46716 Mdot
.72439 .49654 Mdot
.63099 .26374 Mdot
.62651 .49051 Mdot
.57496 .48073 Mdot
.31106 .42038 Mdot
.5445 .78651 Mdot
.6929 .47682 Mdot
.3108 .61236 Mdot
.50294 .30169 Mdot
.52757 .32192 Mdot
.47592 .69764 Mdot
.34617 .50338 Mdot
.87432 .44487 Mdot
.50197 .28884 Mdot
.61896 .46632 Mdot
.29989 .41956 Mdot
.51991 .60741 Mdot
.4989 .57853 Mdot
.48189 .57454 Mdot
.4887 .33308 Mdot
.49607 .57552 Mdot
.48011 .38476 Mdot
.61241 .67558 Mdot
.71491 .3849 Mdot
.3264 .42387 Mdot
.50247 .70897 Mdot
.51756 .52656 Mdot
.32834 .52843 Mdot
.67805 .46668 Mdot
.55821 .67871 Mdot
.50512 .35149 Mdot
.49929 .7101 Mdot
.60802 .47173 Mdot
.52506 .56382 Mdot
.71706 .58843 Mdot
.48665 .66498 Mdot
.52488 .56653 Mdot
.64519 .50023 Mdot
.50801 .31183 Mdot
.51108 .59801 Mdot
.48592 .32984 Mdot
.60748 .4732 Mdot
.55372 .63195 Mdot
.51003 .2998 Mdot
.302 .27569 Mdot
.5267 .55636 Mdot
.29154 .45461 Mdot
.58013 .47401 Mdot
.59931 .47479 Mdot
.76944 .41491 Mdot
.51338 .60607 Mdot
.24936 .31799 Mdot
.30226 .61072 Mdot
.34346 .78435 Mdot
.35007 .63943 Mdot
.3158 .50721 Mdot
.34005 .3628 Mdot
.60565 .48393 Mdot
.62997 .24376 Mdot
.76988 .4272 Mdot
.28679 .40692 Mdot
.77131 .42193 Mdot
.6035 .45681 Mdot
.65325 .48284 Mdot
.30621 .60845 Mdot
.34272 .39735 Mdot
.67707 .51077 Mdot
.6271 .66839 Mdot
.47463 .71094 Mdot
.48051 .31589 Mdot
.60975 .4571 Mdot
.52069 .3782 Mdot
.28795 .60192 Mdot
.53881 .27823 Mdot
.62182 .44323 Mdot
.51036 .58583 Mdot
.3175 .39267 Mdot
.33245 .43256 Mdot
.29473 .58516 Mdot
.29302 .58435 Mdot
.59893 .47407 Mdot
.31048 .40007 Mdot
.68132 .46421 Mdot
.62827 .65442 Mdot
.51283 .57088 Mdot
.48814 .68586 Mdot
.6235 .43186 Mdot
.47702 .22569 Mdot
.65604 .78788 Mdot
.62682 .48317 Mdot
.49293 .35377 Mdot
.31626 .60421 Mdot
.34646 .61206 Mdot
.49568 .33405 Mdot
.34625 .61319 Mdot
.51515 .24885 Mdot
.77528 .37188 Mdot
.48716 .69476 Mdot
.5752 .49834 Mdot
.50425 .7172 Mdot
.51585 .60455 Mdot
.64087 .4531 Mdot
.20365 .4246 Mdot
.27409 .61657 Mdot
.64688 .56696 Mdot
.31789 .41186 Mdot
.49041 .59514 Mdot
.70272 .50182 Mdot
.52329 .72171 Mdot
.33583 .60256 Mdot
.54334 .57605 Mdot
.66268 .46665 Mdot
.51418 .30141 Mdot
.63317 .50019 Mdot
.48893 .58252 Mdot
.50703 .60089 Mdot
.5423 .58297 Mdot
.28637 .45038 Mdot
.46863 .31289 Mdot
.31328 .5006 Mdot
.31385 .6315 Mdot
.648 .43349 Mdot
.61746 .46768 Mdot
.48979 .27695 Mdot
.642 .4412 Mdot
.31389 .39832 Mdot
.54564 .13452 Mdot
.51396 .70056 Mdot
.51484 .60844 Mdot
.33165 .28363 Mdot
.5431 .58694 Mdot
.65446 .50274 Mdot
.75427 .48536 Mdot
.47443 .26632 Mdot
.28459 .45127 Mdot
.67103 .44269 Mdot
.3458 .6351 Mdot
.50657 .6869 Mdot
.33372 .41212 Mdot
.69959 .49735 Mdot
.61669 .43943 Mdot
.50042 .70848 Mdot
.36172 .46676 Mdot
.47077 .71597 Mdot
.2939 .43904 Mdot
.49258 .60425 Mdot
.67252 .60258 Mdot
.63019 .45264 Mdot
.51255 .59172 Mdot
.4727 .31299 Mdot
.28801 .43074 Mdot
.63495 .28054 Mdot
.49215 .58189 Mdot
.28596 .49981 Mdot
.32952 .43853 Mdot
.65298 .48564 Mdot
.51036 .3251 Mdot
.53436 .32579 Mdot
.47542 .30431 Mdot
.49211 .80172 Mdot
.29195 .51681 Mdot
.31278 .60252 Mdot
.30747 .42646 Mdot
.31214 .62115 Mdot
.48427 .72305 Mdot
.65655 .68074 Mdot
.2897 .58584 Mdot
.4682 .36078 Mdot
.30294 .62007 Mdot
.67913 .46165 Mdot
.29282 .45653 Mdot
.28171 .59656 Mdot
.61311 .43196 Mdot
.7197 .50543 Mdot
.50345 .59526 Mdot
.50662 .66305 Mdot
.61899 .67037 Mdot
.63943 .44439 Mdot
.51678 .58916 Mdot
.6304 .44634 Mdot
.31392 .39863 Mdot
.58169 .65234 Mdot
.63835 .42802 Mdot
.27264 .61456 Mdot
.35729 .22956 Mdot
.31175 .63697 Mdot
.44501 .55291 Mdot
.65397 .46701 Mdot
.63391 .45277 Mdot
.70872 .4983 Mdot
.65719 .22559 Mdot
.28933 .40006 Mdot
.58692 .43012 Mdot
.34875 .5981 Mdot
.49517 .31074 Mdot
.50188 .33627 Mdot
.71579 .46121 Mdot
.51421 .59436 Mdot
.32344 .39897 Mdot
.63649 .45424 Mdot
.49237 .59342 Mdot
.63491 .68646 Mdot
.39436 .31087 Mdot
.30067 .53421 Mdot
.33744 .6302 Mdot
.5049 .28043 Mdot
.34436 .5978 Mdot
.70146 .49869 Mdot
.49504 .58059 Mdot
.28922 .51388 Mdot
.25841 .43684 Mdot
.50545 .68664 Mdot
.65258 .47812 Mdot
.63254 .74641 Mdot
.33942 .58917 Mdot
.30545 .57578 Mdot
.68022 .46227 Mdot
.41464 .32221 Mdot
.62631 .79562 Mdot
.28806 .41693 Mdot
.56795 .35899 Mdot
.7033 .29115 Mdot
.79108 .61661 Mdot
.30236 .43349 Mdot
.72385 .49503 Mdot
.31673 .56905 Mdot
.41763 .78327 Mdot
.49393 .30677 Mdot
.50624 .68512 Mdot
.61579 .43166 Mdot
.47128 .36056 Mdot
.27218 .61657 Mdot
.46301 .31938 Mdot
.50589 .58306 Mdot
.29023 .45698 Mdot
.33886 .59871 Mdot
.34184 .42703 Mdot
.44053 .32584 Mdot
.50913 .70775 Mdot
.56681 .73748 Mdot
.58735 .49416 Mdot
.63022 .2608 Mdot
.699 .50536 Mdot
.55396 .56559 Mdot
.70652 .50684 Mdot
.52872 .32637 Mdot
.62552 .44123 Mdot
.68984 .46644 Mdot
.3302 .57311 Mdot
.63864 .48427 Mdot
.61074 .43462 Mdot
.75165 .36765 Mdot
.64991 .47454 Mdot
.60361 .47462 Mdot
.64819 .48618 Mdot
.48729 .35637 Mdot
.66617 .47097 Mdot
.47987 .29005 Mdot
.50043 .3803 Mdot
.31577 .63145 Mdot
.49128 .72489 Mdot
.49575 .72413 Mdot
.55963 .63662 Mdot
.63061 .74683 Mdot
.63583 .22486 Mdot
.4918 .31798 Mdot
.32743 .43926 Mdot
.66805 .44992 Mdot
.58743 .80396 Mdot
.55437 .63263 Mdot
.30321 .56902 Mdot
.28583 .60597 Mdot
.60094 .43368 Mdot
.85406 .49423 Mdot
.66407 .4553 Mdot
.61849 .69228 Mdot
.61676 .45967 Mdot
.66974 .48153 Mdot
.35139 .63548 Mdot
.58804 .74857 Mdot
.71126 .50874 Mdot
.5207 .3283 Mdot
.50255 .68407 Mdot
.50942 .59541 Mdot
.55544 .63537 Mdot
.72838 .30791 Mdot
.44895 .25116 Mdot
.70924 .49795 Mdot
.32455 .57852 Mdot
.48624 .34356 Mdot
.61283 .68567 Mdot
.29601 .40537 Mdot
.61061 .71731 Mdot
.581 .36818 Mdot
.2867 .4171 Mdot
.5067 .69055 Mdot
.28008 .57901 Mdot
.6212 .47927 Mdot
.30335 .5917 Mdot
.5941 .47495 Mdot
.62926 .69661 Mdot
.48753 .69009 Mdot
.47834 .36957 Mdot
.30473 .44881 Mdot
.47966 .35897 Mdot
.5429 .28926 Mdot
.55185 .63943 Mdot
.29578 .749 Mdot
.29699 .63281 Mdot
.46964 .53478 Mdot
.4929 .28536 Mdot
.58758 .45697 Mdot
.58592 .15962 Mdot
.47256 .3267 Mdot
.51374 .30362 Mdot
.59409 .70297 Mdot
.58977 .75753 Mdot
.62969 .48552 Mdot
.46558 .35247 Mdot
.27737 .58229 Mdot
.48524 .70126 Mdot
.60179 .43724 Mdot
.49571 .58731 Mdot
.50687 .32466 Mdot
.34039 .61037 Mdot
.58206 .74468 Mdot
.32137 .58591 Mdot
.49931 .30297 Mdot
.28909 .62021 Mdot
.31919 .49291 Mdot
.28899 .58649 Mdot
.63171 .43425 Mdot
.6352 .45397 Mdot
.53971 .3316 Mdot
.48411 .34266 Mdot
.65488 .50286 Mdot
.65193 .45045 Mdot
.4875 .29058 Mdot
.27205 .58368 Mdot
.4699 .25102 Mdot
.66516 .50008 Mdot
.63952 .45863 Mdot
.51388 .70996 Mdot
.61163 .64172 Mdot
.59427 .6725 Mdot
.6676 .45082 Mdot
.50722 .70667 Mdot
.51339 .29537 Mdot
.6378 .44882 Mdot
.58544 .75282 Mdot
.31628 .5647 Mdot
.69336 .48213 Mdot
.5238 .60734 Mdot
.68374 .50819 Mdot
.69376 .7089 Mdot
.70757 .49676 Mdot
.49013 .29977 Mdot
.49707 .29482 Mdot
.30279 .56149 Mdot
.48356 .30665 Mdot
.51474 .6077 Mdot
.33051 .41679 Mdot
.58182 .35263 Mdot
.49518 .60065 Mdot
.53728 .57858 Mdot
.531 .56026 Mdot
.50236 .56218 Mdot
.45982 .71386 Mdot
.30384 .53123 Mdot
.53212 .59419 Mdot
.48032 .29266 Mdot
.53089 .44394 Mdot
.51791 .6175 Mdot
.32077 .39694 Mdot
.49466 .57583 Mdot
.69281 .48249 Mdot
.71578 .49727 Mdot
.47485 .27598 Mdot
.29683 .40348 Mdot
.49512 .61835 Mdot
.60232 .43664 Mdot
.47162 .2696 Mdot
.60795 .45639 Mdot
.47783 .68103 Mdot
.48051 .33433 Mdot
.32574 .58295 Mdot
.48591 .68755 Mdot
.51184 .56436 Mdot
.50339 .67466 Mdot
.3038 .59847 Mdot
.32306 .43814 Mdot
.62622 .43427 Mdot
.47096 .68797 Mdot
.48886 .72297 Mdot
.59583 .48628 Mdot
.49968 .29437 Mdot
.47629 .58612 Mdot
.64431 .45339 Mdot
.71007 .50107 Mdot
.49583 .33534 Mdot
.23404 .32118 Mdot
.63068 .48059 Mdot
.73271 .5067 Mdot
.52318 .33522 Mdot
.48934 .58987 Mdot
.32132 .58054 Mdot
.60633 .48138 Mdot
.31218 .40634 Mdot
.32353 .41165 Mdot
.27552 .61669 Mdot
.50131 .3316 Mdot
.34378 .6072 Mdot
.5843 .46451 Mdot
.49637 .57213 Mdot
.59911 .44638 Mdot
.2515 .58365 Mdot
.27283 .29417 Mdot
.47192 .29727 Mdot
.31659 .6329 Mdot
.64604 .67976 Mdot
.27942 .44661 Mdot
.26165 .60859 Mdot
.52221 .32931 Mdot
.46967 .35553 Mdot
.49779 .32944 Mdot
.49196 .72117 Mdot
.32875 .59097 Mdot
.48714 .27202 Mdot
.48471 .27333 Mdot
.6855 .49924 Mdot
.60673 .4327 Mdot
.51061 .2892 Mdot
.32374 .52508 Mdot
.50236 .68982 Mdot
.3512 .60703 Mdot
.63365 .79474 Mdot
.28693 .42478 Mdot
.75246 .3661 Mdot
.67747 .46397 Mdot
.88286 .41249 Mdot
.66329 .45494 Mdot
.61403 .46261 Mdot
.4605 .30762 Mdot
.48863 .72922 Mdot
.48805 .70496 Mdot
.49372 .28646 Mdot
.46568 .30575 Mdot
.47666 .68796 Mdot
.62541 .62415 Mdot
.67587 .72643 Mdot
.62985 .68159 Mdot
.4634 .32242 Mdot
.56978 .37471 Mdot
.31836 .42438 Mdot
.49276 .36492 Mdot
.35177 .46397 Mdot
.28224 .61494 Mdot
.28672 .58878 Mdot
.31355 .44868 Mdot
.62205 .47853 Mdot
.34858 .63689 Mdot
.69746 .50851 Mdot
.36938 .40783 Mdot
.71759 .49369 Mdot
.4583 .84215 Mdot
.63627 .43737 Mdot
.44015 .53426 Mdot
.38269 .32217 Mdot
.66168 .50527 Mdot
.75904 .34346 Mdot
.50951 .68419 Mdot
.5287 .31888 Mdot
.30694 .3968 Mdot
.63374 .22229 Mdot
.63185 .45271 Mdot
.46281 .34892 Mdot
.29598 .44636 Mdot
.25724 .3102 Mdot
.73311 .50349 Mdot
.67646 .50196 Mdot
.57779 .15491 Mdot
.47095 .36786 Mdot
.32161 .58179 Mdot
.56423 .3468 Mdot
.47339 .2901 Mdot
.73285 .49982 Mdot
.26978 .59369 Mdot
.71425 .5861 Mdot
.45972 .34193 Mdot
.47153 .71786 Mdot
.48241 .31972 Mdot
.48106 .68396 Mdot
.48831 .27167 Mdot
.31412 .62973 Mdot
.64518 .47976 Mdot
.31787 .63072 Mdot
.50051 .66808 Mdot
.30532 .63398 Mdot
.30128 .39893 Mdot
.52392 .57754 Mdot
.32665 .41654 Mdot
.66225 .67431 Mdot
.64297 .2947 Mdot
.31697 .43775 Mdot
.73867 .4667 Mdot
.61485 .43861 Mdot
.48988 .27229 Mdot
.33046 .58548 Mdot
.34701 .58723 Mdot
.62071 .6682 Mdot
.50419 .31105 Mdot
.33904 .61909 Mdot
.56709 .47678 Mdot
.22772 .39078 Mdot
.72045 .50892 Mdot
.16666 .56596 Mdot
.4854 .2957 Mdot
.34624 .58762 Mdot
.61524 .68947 Mdot
.45646 .35146 Mdot
.28306 .59229 Mdot
.30618 .44485 Mdot
.31226 .40663 Mdot
.64357 .43895 Mdot
.3458 .41478 Mdot
.30734 .57008 Mdot
.5493 .38474 Mdot
.50602 .28928 Mdot
.28174 .28643 Mdot
.51189 .70124 Mdot
.34287 .59738 Mdot
.5075 .57044 Mdot
.44025 .3341 Mdot
.30891 .62173 Mdot
.87152 .4524 Mdot
.60847 .83427 Mdot
.33964 .61585 Mdot
.48214 .33248 Mdot
.49083 .33267 Mdot
.64342 .497 Mdot
.62555 .66634 Mdot
.33587 .6042 Mdot
.20141 .42517 Mdot
.67991 .62968 Mdot
.52444 .58099 Mdot
.25082 .697 Mdot
.70499 .49001 Mdot
.70021 .50369 Mdot
.2891 .42725 Mdot
.63196 .47727 Mdot
.46433 .31035 Mdot
.66399 .45594 Mdot
.32283 .40355 Mdot
.27804 .61864 Mdot
.63271 .45005 Mdot
.50716 .68846 Mdot
.29528 .41612 Mdot
.30526 .40472 Mdot
.29264 .62106 Mdot
.50242 .32901 Mdot
.63074 .21904 Mdot
.32591 .58712 Mdot
.692 .50627 Mdot
.51804 .58504 Mdot
.64736 .48587 Mdot
.4938 .37161 Mdot
.52471 .30509 Mdot
.34058 .59286 Mdot
.58643 .47552 Mdot
.30229 .4272 Mdot
.32702 .57128 Mdot
.70945 .4955 Mdot
.28344 .58391 Mdot
.48902 .55472 Mdot
.3706 .62484 Mdot
.43925 .31975 Mdot
.50348 .556 Mdot
.46582 .35627 Mdot
.53137 .59096 Mdot
.46591 .79303 Mdot
.50539 .69112 Mdot
.3322 .63947 Mdot
.29501 .28111 Mdot
.32179 .63194 Mdot
.6491 .47318 Mdot
.6217 .4375 Mdot
.30118 .60549 Mdot
.50802 .70934 Mdot
.53599 .5317 Mdot
.46699 .69956 Mdot
.48216 .33794 Mdot
.74361 .4926 Mdot
.56471 .84012 Mdot
.33517 .57209 Mdot
.3124 .45157 Mdot
.42232 .27401 Mdot
.53642 .57622 Mdot
.29813 .40095 Mdot
.30011 .40792 Mdot
.50474 .67128 Mdot
.3456 .62654 Mdot
.498 .35268 Mdot
.31577 .453 Mdot
.45545 .33606 Mdot
.57974 .75124 Mdot
.49535 .56934 Mdot
.50559 .51828 Mdot
.52358 .56311 Mdot
.61528 .67438 Mdot
.2988 .45894 Mdot
.61378 .44927 Mdot
.47784 .55082 Mdot
.29743 .44423 Mdot
.51602 .67732 Mdot
.71796 .4948 Mdot
.3372 .62105 Mdot
.60736 .17915 Mdot
.6326 .43391 Mdot
.65111 .46206 Mdot
.28825 .4378 Mdot
.74829 .32393 Mdot
.524 .32119 Mdot
.50881 .31053 Mdot
.31423 .59884 Mdot
.5936 .69745 Mdot
.66449 .46585 Mdot
.61848 .43549 Mdot
.29745 .60474 Mdot
.51806 .59567 Mdot
.27206 .72719 Mdot
.63615 .45968 Mdot
.31224 .42402 Mdot
.72199 .4956 Mdot
.28742 .40486 Mdot
.66798 .44138 Mdot
.64529 .47365 Mdot
.68049 .5048 Mdot
.71357 .50507 Mdot
.3263 .41852 Mdot
.51977 .56372 Mdot
.5383 .59554 Mdot
.4725 .3085 Mdot
.59336 .43645 Mdot
.68011 .62766 Mdot
.63263 .45653 Mdot
.50993 .68623 Mdot
.59458 .6767 Mdot
.66872 .44686 Mdot
.59826 .43033 Mdot
.68063 .63252 Mdot
.60383 .46775 Mdot
.28763 .43858 Mdot
.49448 .32702 Mdot
.30059 .42663 Mdot
.30539 .45409 Mdot
.30361 .62185 Mdot
.52014 .68608 Mdot
.60425 .47909 Mdot
.47575 .70642 Mdot
.65555 .49483 Mdot
.51012 .62223 Mdot
.62936 .65124 Mdot
.62008 .6918 Mdot
.49409 .66096 Mdot
.61371 .43727 Mdot
.30796 .59929 Mdot
.35171 .62142 Mdot
.73273 .49193 Mdot
.58049 .46627 Mdot
.34366 .40925 Mdot
.31685 .44115 Mdot
.29104 .53841 Mdot
.29261 .67011 Mdot
.47244 .68834 Mdot
.51152 .53809 Mdot
.7161 .50566 Mdot
.65615 .47512 Mdot
.5275 .57102 Mdot
.31481 .61805 Mdot
.53251 .59176 Mdot
.3034 .53363 Mdot
.29571 .39986 Mdot
.29483 .43087 Mdot
.63338 .43558 Mdot
.86557 .53402 Mdot
.4683 .33135 Mdot
.49137 .33281 Mdot
.32877 .40645 Mdot
.31314 .63732 Mdot
.50284 .58297 Mdot
.63473 .19474 Mdot
.52184 .29746 Mdot
.48748 .72577 Mdot
.5951 .45713 Mdot
.28385 .6187 Mdot
.473 .30205 Mdot
.46968 .69395 Mdot
.59754 .42469 Mdot
.26761 .59628 Mdot
.61784 .45299 Mdot
.55904 .48827 Mdot
.49301 .28176 Mdot
.62166 .64507 Mdot
.47088 .36372 Mdot
.32283 .41645 Mdot
.30426 .45687 Mdot
.64723 .47022 Mdot
.62849 .19361 Mdot
.42275 .31325 Mdot
.32043 .45189 Mdot
.51104 .71999 Mdot
.52112 .57388 Mdot
.51883 .68267 Mdot
.30922 .60852 Mdot
.50595 .69 Mdot
.30801 .62217 Mdot
.28186 .56979 Mdot
.4984 .34841 Mdot
.50002 .70841 Mdot
.72968 .34008 Mdot
.49547 .58141 Mdot
.50867 .72555 Mdot
.62484 .4266 Mdot
.65653 .49918 Mdot
.33448 .61053 Mdot
.47669 .71155 Mdot
.61393 .48374 Mdot
.32545 .28748 Mdot
.29568 .45514 Mdot
.30263 .39813 Mdot
.50509 .58361 Mdot
.3227 .57326 Mdot
.4999 .34612 Mdot
.6485 .67919 Mdot
.45041 .36533 Mdot
.61839 .4348 Mdot
.60657 .47942 Mdot
.44274 .34709 Mdot
.50054 .34382 Mdot
.64307 .47237 Mdot
.71243 .37567 Mdot
.50834 .56867 Mdot
.31749 .40626 Mdot
.47967 .3398 Mdot
.47851 .34666 Mdot
.30258 .57283 Mdot
.50943 .31852 Mdot
.48404 .53645 Mdot
.29608 .40017 Mdot
.53716 .60021 Mdot
.30515 .42541 Mdot
.54423 .6187 Mdot
.33107 .62064 Mdot
.27648 .29752 Mdot
.50984 .3105 Mdot
.66885 .50061 Mdot
.51171 .31044 Mdot
.51431 .69319 Mdot
.4629 .34413 Mdot
.49257 .36756 Mdot
.61452 .43253 Mdot
.52016 .56485 Mdot
.51315 .60288 Mdot
.62107 .67208 Mdot
.47016 .32794 Mdot
.61695 .48057 Mdot
.67059 .46821 Mdot
.64909 .44791 Mdot
.63036 .65605 Mdot
.49121 .35174 Mdot
.73002 .30938 Mdot
.48892 .26965 Mdot
.48978 .28253 Mdot
.67622 .78008 Mdot
.50827 .60453 Mdot
.53417 .5821 Mdot
.32732 .36761 Mdot
.63918 .46084 Mdot
.34458 .61644 Mdot
.69148 .50501 Mdot
.51734 .56715 Mdot
.61986 .42425 Mdot
.48106 .70498 Mdot
.59104 .46925 Mdot
.52426 .58787 Mdot
.3313 .58828 Mdot
.67435 .50047 Mdot
.64013 .45506 Mdot
.51467 .59835 Mdot
.51366 .30979 Mdot
.48058 .35466 Mdot
.43122 .34547 Mdot
.48655 .67658 Mdot
.31631 .43269 Mdot
.69408 .5038 Mdot
.31169 .59925 Mdot
.34432 .62046 Mdot
.46987 .36175 Mdot
.29627 .58889 Mdot
.29336 .43131 Mdot
.62154 .46605 Mdot
.32477 .41698 Mdot
.47933 .69846 Mdot
.47932 .33532 Mdot
.70424 .49962 Mdot
.63242 .50155 Mdot
.49702 .29469 Mdot
.50526 .56802 Mdot
.51631 .70676 Mdot
.29229 .60213 Mdot
.47928 .28796 Mdot
.3277 .41321 Mdot
.29639 .57762 Mdot
.66983 .50174 Mdot
.7665 .70832 Mdot
.63331 .47723 Mdot
.65873 .45589 Mdot
.43362 .3068 Mdot
.68806 .46258 Mdot
.31282 .63147 Mdot
.50598 .33036 Mdot
.66099 .49982 Mdot
.68379 .65279 Mdot
.51298 .66348 Mdot
.36101 .60367 Mdot
.60628 .46449 Mdot
.76935 .41601 Mdot
.67967 .48522 Mdot
.30917 .27038 Mdot
.62801 .65116 Mdot
.28929 .50445 Mdot
.49048 .52432 Mdot
.32843 .44549 Mdot
.51797 .59031 Mdot
.30431 .62426 Mdot
.70521 .35927 Mdot
.63577 .47401 Mdot
.62959 .27002 Mdot
.70119 .49683 Mdot
.29941 .43265 Mdot
.74481 .3301 Mdot
.32198 .57698 Mdot
.33408 .77762 Mdot
.58816 .4452 Mdot
.52418 .3136 Mdot
.36023 .54241 Mdot
.52749 .57408 Mdot
.53306 .57312 Mdot
.47494 .68498 Mdot
.26271 .61854 Mdot
.48386 .60431 Mdot
.30253 .42533 Mdot
.65908 .47464 Mdot
.57551 .47516 Mdot
.24233 .32225 Mdot
.4795 .29732 Mdot
.30172 .45129 Mdot
.37091 .60988 Mdot
.61088 .44609 Mdot
.47154 .35585 Mdot
.4936 .30699 Mdot
.48063 .71168 Mdot
.29188 .50033 Mdot
.26085 .61865 Mdot
.84784 .51347 Mdot
.48293 .61257 Mdot
.31134 .61709 Mdot
.5043 .55726 Mdot
.68812 .50551 Mdot
.55394 .63263 Mdot
.31144 .45311 Mdot
.65296 .46928 Mdot
.62839 .25633 Mdot
.48144 .30156 Mdot
.62498 .45801 Mdot
.4993 .68792 Mdot
.64615 .20234 Mdot
.57949 .48706 Mdot
.71673 .384 Mdot
.27692 .58281 Mdot
.60944 .48026 Mdot
.48194 .53893 Mdot
.49271 .59451 Mdot
.68787 .46177 Mdot
.32377 .58296 Mdot
.50664 .55545 Mdot
.49582 .69244 Mdot
.46901 .31089 Mdot
.51591 .58963 Mdot
.70144 .49649 Mdot
.59711 .47688 Mdot
.51329 .71717 Mdot
.68139 .50327 Mdot
.57295 .33516 Mdot
.48573 .57197 Mdot
.28739 .59291 Mdot
.47686 .28877 Mdot
.62291 .48263 Mdot
.52092 .57274 Mdot
.6003 .44669 Mdot
.47883 .22628 Mdot
.65441 .47109 Mdot
.28945 .30519 Mdot
.50344 .30273 Mdot
.30923 .41149 Mdot
.71157 .49833 Mdot
.62163 .45225 Mdot
.49759 .55879 Mdot
.50103 .58448 Mdot
.59091 .44683 Mdot
.46732 .35873 Mdot
.46719 .32057 Mdot
.52296 .31011 Mdot
.29365 .57606 Mdot
.63205 .67635 Mdot
.31646 .41429 Mdot
.52851 .57181 Mdot
.31626 .45267 Mdot
.77021 .4362 Mdot
.49164 .67526 Mdot
.25586 .3193 Mdot
.62763 .46858 Mdot
.50269 .31676 Mdot
.66937 .72923 Mdot
.47443 .36219 Mdot
.34369 .37733 Mdot
.31399 .45215 Mdot
.47487 .32918 Mdot
.60838 .46784 Mdot
.61188 .67879 Mdot
.77132 .41283 Mdot
.28376 .45156 Mdot
.53358 .60303 Mdot
.52722 .65186 Mdot
.27793 .59212 Mdot
.66588 .78554 Mdot
.33509 .42587 Mdot
.38314 .31899 Mdot
.66474 .50012 Mdot
.50841 .30101 Mdot
.32544 .42551 Mdot
.30499 .40331 Mdot
.32411 .57649 Mdot
.68309 .49955 Mdot
.62252 .4539 Mdot
.52405 .60662 Mdot
.32827 .43443 Mdot
.58928 .47532 Mdot
.66295 .5064 Mdot
.2452 .5972 Mdot
.52613 .3167 Mdot
.23317 .32003 Mdot
.75974 .47657 Mdot
.62964 .25666 Mdot
.21927 .42285 Mdot
.49591 .27663 Mdot
.60647 .47576 Mdot
.5085 .57445 Mdot
.29119 .59624 Mdot
.62061 .4702 Mdot
.3201 .63307 Mdot
.30606 .43535 Mdot
.30744 .29802 Mdot
.75691 .48082 Mdot
.36976 .4017 Mdot
.64244 .47879 Mdot
.60209 .49849 Mdot
.4978 .70007 Mdot
.30853 .39566 Mdot
.51755 .32569 Mdot
.6376 .48501 Mdot
.30991 .5766 Mdot
.27951 .5946 Mdot
.47895 .3048 Mdot
.4026 .35846 Mdot
.28388 .29008 Mdot
.50271 .57188 Mdot
.30299 .58536 Mdot
.51806 .57109 Mdot
.71717 .38781 Mdot
.31879 .4519 Mdot
.49482 .6934 Mdot
.28756 .61585 Mdot
.32678 .39963 Mdot
.65534 .49932 Mdot
.47641 .31632 Mdot
.44706 .35836 Mdot
.73822 .49979 Mdot
.33981 .61894 Mdot
.48959 .67996 Mdot
.71253 .47824 Mdot
.74246 .49416 Mdot
.48942 .6855 Mdot
.3014 .5706 Mdot
.46991 .34537 Mdot
.49685 .30184 Mdot
.49591 .32317 Mdot
.75104 .36458 Mdot
.52411 .30198 Mdot
.55837 .72922 Mdot
.69286 .46852 Mdot
.56511 .38321 Mdot
.66784 .48867 Mdot
.30519 .39755 Mdot
.49826 .28428 Mdot
.62788 .65027 Mdot
.71504 .50899 Mdot
.77426 .41385 Mdot
.64672 .44918 Mdot
.72749 .50085 Mdot
.63983 .46041 Mdot
.55152 .3862 Mdot
.52769 .30765 Mdot
.59072 .43488 Mdot
.28149 .41984 Mdot
.50915 .67913 Mdot
.46105 .31092 Mdot
.59868 .47051 Mdot
.51702 .38764 Mdot
.62982 .42753 Mdot
.30357 .29852 Mdot
.73218 .49725 Mdot
.39452 .578 Mdot
.6628 .47983 Mdot
.31035 .63876 Mdot
.62177 .50015 Mdot
.58252 .35851 Mdot
.29204 .45598 Mdot
.57997 .48841 Mdot
.33884 .64064 Mdot
.74318 .32864 Mdot
.50006 .57555 Mdot
.50125 .69292 Mdot
.52221 .55788 Mdot
.32524 .40878 Mdot
.63163 .47102 Mdot
.59224 .46729 Mdot
.67513 .44352 Mdot
.71732 .38911 Mdot
.50044 .59761 Mdot
.49116 .66248 Mdot
.57537 .37176 Mdot
.59155 .45221 Mdot
.36352 .6291 Mdot
.49168 .34471 Mdot
.73281 .3333 Mdot
.71861 .32519 Mdot
.65682 .50601 Mdot
.47321 .32491 Mdot
.50162 .3311 Mdot
.60528 .80194 Mdot
.50449 .70225 Mdot
.65369 .46265 Mdot
.47015 .73616 Mdot
.69637 .50226 Mdot
.31097 .43063 Mdot
.68485 .46131 Mdot
.33256 .62049 Mdot
.60945 .68686 Mdot
.29666 .57279 Mdot
.64681 .44624 Mdot
.48375 .32011 Mdot
.28113 .44422 Mdot
.28445 .56675 Mdot
.29369 .49974 Mdot
.55879 .73444 Mdot
.2605 .61415 Mdot
.4716 .69224 Mdot
.50878 .67437 Mdot
.30808 .3959 Mdot
.61173 .46464 Mdot
.62902 .65932 Mdot
.77399 .46751 Mdot
.63717 .46404 Mdot
.62073 .47716 Mdot
.27395 .37453 Mdot
.32413 .44383 Mdot
.28969 .6225 Mdot
.64116 .47256 Mdot
.59039 .47048 Mdot
.48049 .32558 Mdot
.47385 .71089 Mdot
.29513 .61292 Mdot
.48286 .6767 Mdot
.31146 .58886 Mdot
.69447 .70896 Mdot
.49559 .57037 Mdot
.49847 .67296 Mdot
.33609 .4265 Mdot
.49746 .32733 Mdot
.50972 .60578 Mdot
.31921 .60841 Mdot
.30043 .58518 Mdot
.64687 .49441 Mdot
.47223 .30432 Mdot
.50903 .30996 Mdot
.47847 .68339 Mdot
.31779 .43939 Mdot
.70191 .50882 Mdot
.52578 .56441 Mdot
.33991 .56962 Mdot
.30219 .57917 Mdot
.57174 .37483 Mdot
.43759 .3123 Mdot
.60252 .44801 Mdot
.47893 .35458 Mdot
.62645 .4478 Mdot
.47757 .37687 Mdot
.46916 .36763 Mdot
.66536 .44048 Mdot
.64649 .38096 Mdot
.31437 .61939 Mdot
.52539 .84259 Mdot
.72235 .50879 Mdot
.2795 .40672 Mdot
.68979 .50433 Mdot
.29498 .74945 Mdot
.66488 .73188 Mdot
.59638 .44384 Mdot
.60265 .47632 Mdot
.85256 .56213 Mdot
.67893 .4791 Mdot
.5298 .591 Mdot
.49887 .57647 Mdot
.47541 .35474 Mdot
.52876 .56052 Mdot
.61797 .67207 Mdot
.50177 .71251 Mdot
.31399 .59982 Mdot
.58954 .75338 Mdot
.48326 .68118 Mdot
.48752 .29862 Mdot
.69897 .50926 Mdot
.43003 .31771 Mdot
.35431 .63228 Mdot
.51065 .59195 Mdot
.30319 .43414 Mdot
.62275 .66307 Mdot
.31487 .57519 Mdot
.33223 .41957 Mdot
.6751 .47301 Mdot
.30241 .53698 Mdot
.28428 .41176 Mdot
.53868 .83785 Mdot
.29202 .41275 Mdot
.33055 .41441 Mdot
.62956 .66907 Mdot
.50162 .71281 Mdot
.48759 .56447 Mdot
.52675 .61992 Mdot
.28374 .44353 Mdot
.38268 .79924 Mdot
.3249 .57502 Mdot
.63346 .69598 Mdot
.52906 .31663 Mdot
.49331 .57987 Mdot
.63601 .47995 Mdot
.28839 .42693 Mdot
.57982 .46938 Mdot
.50024 .55723 Mdot
.29612 .41921 Mdot
.62303 .50028 Mdot
.59439 .69484 Mdot
.51723 .57415 Mdot
.51521 .60422 Mdot
.47055 .70828 Mdot
.39078 .60113 Mdot
.50506 .32025 Mdot
.4941 .72609 Mdot
.66284 .65473 Mdot
.65362 .45401 Mdot
.32611 .41958 Mdot
.51506 .58989 Mdot
.31682 .41077 Mdot
.49182 .7027 Mdot
.5148 .71656 Mdot
.47355 .30596 Mdot
.52325 .31318 Mdot
.5023 .60776 Mdot
.68593 .6234 Mdot
.69154 .47821 Mdot
.63339 .28245 Mdot
.49361 .35335 Mdot
.76501 .35344 Mdot
.4964 .71893 Mdot
.47645 .71425 Mdot
.61149 .49878 Mdot
.66393 .44683 Mdot
.72584 .49966 Mdot
.66378 .44304 Mdot
.36499 .78119 Mdot
.70452 .49867 Mdot
.29365 .59875 Mdot
.63806 .42766 Mdot
.40057 .29313 Mdot
.63467 .49588 Mdot
.59634 .46355 Mdot
.32489 .59359 Mdot
.6461 .4909 Mdot
.33496 .61474 Mdot
.641 .48233 Mdot
.23845 .63666 Mdot
.31206 .59891 Mdot
.5417 .54446 Mdot
.66607 .42275 Mdot
.52618 .59671 Mdot
.4877 .71372 Mdot
.47487 .68188 Mdot
.57945 .74368 Mdot
.46981 .34029 Mdot
.66254 .23281 Mdot
.59682 .46074 Mdot
.31905 .57329 Mdot
.30709 .43719 Mdot
.6375 .50166 Mdot
.65554 .44987 Mdot
.72079 .50579 Mdot
.47101 .32056 Mdot
.31655 .56996 Mdot
.49268 .70939 Mdot
.34103 .63071 Mdot
.23765 .63902 Mdot
.32801 .62026 Mdot
.73442 .42145 Mdot
.65332 .49813 Mdot
.48324 .53784 Mdot
.65845 .31962 Mdot
.51428 .73127 Mdot
.47696 .31028 Mdot
.51908 .58793 Mdot
.51345 .67719 Mdot
.58789 .65365 Mdot
.49855 .33133 Mdot
.29768 .60402 Mdot
.61745 .45253 Mdot
.50222 .56125 Mdot
.52533 .62026 Mdot
.46065 .31778 Mdot
.51956 .70408 Mdot
.32083 .60281 Mdot
.52055 .57912 Mdot
.63239 .68062 Mdot
.70474 .29131 Mdot
.65793 .6819 Mdot
.62271 .45 Mdot
.47734 .68675 Mdot
.47185 .30447 Mdot
.7276 .50407 Mdot
.29557 .44203 Mdot
.6237 .66766 Mdot
.6366 .47869 Mdot
.36649 .38561 Mdot
.4842 .31808 Mdot
.50966 .7053 Mdot
.28885 .42149 Mdot
.50573 .69979 Mdot
.53352 .58296 Mdot
.46907 .28906 Mdot
.53298 .57327 Mdot
.70744 .49638 Mdot
.31003 .43528 Mdot
.50642 .31675 Mdot
.23801 .63335 Mdot
.4784 .57641 Mdot
.30239 .60587 Mdot
.59068 .65324 Mdot
.468 .31643 Mdot
.31987 .5038 Mdot
.33958 .63137 Mdot
.25387 .42193 Mdot
.6082 .6405 Mdot
.29249 .42495 Mdot
.59685 .46625 Mdot
.49227 .32339 Mdot
.28312 .4513 Mdot
.33979 .53594 Mdot
.76771 .3992 Mdot
.48398 .58765 Mdot
.61698 .43783 Mdot
.31923 .26093 Mdot
.38887 .31759 Mdot
.53572 .32517 Mdot
.33398 .41319 Mdot
.64821 .46136 Mdot
.50238 .57076 Mdot
.58997 .43922 Mdot
.28629 .4485 Mdot
.30295 .46907 Mdot
.35179 .6109 Mdot
.61363 .45076 Mdot
.50973 .69153 Mdot
.32429 .62613 Mdot
.27321 .59741 Mdot
.28545 .61341 Mdot
.51886 .32379 Mdot
.49083 .58145 Mdot
.49862 .57467 Mdot
.65475 .73683 Mdot
.31633 .40881 Mdot
.52629 .59615 Mdot
.59206 .46949 Mdot
.55946 .72924 Mdot
.50072 .31458 Mdot
.32578 .60333 Mdot
.65085 .46083 Mdot
.73953 .50296 Mdot
.51011 .59686 Mdot
.32714 .5893 Mdot
.49941 .34555 Mdot
.5378 .45791 Mdot
.62244 .46974 Mdot
.69344 .49831 Mdot
.49124 .29377 Mdot
.44651 .21704 Mdot
.63114 .68698 Mdot
.62826 .44904 Mdot
.32327 .41058 Mdot
.41236 .22002 Mdot
.67503 .47621 Mdot
.43429 .35607 Mdot
.52686 .60681 Mdot
.53145 .42627 Mdot
.57188 .34776 Mdot
.56624 .44173 Mdot
.44184 .48598 Mdot
.65118 .56808 Mdot
.46056 .5015 Mdot
.40481 .78865 Mdot
.39904 .50005 Mdot
.55914 .83682 Mdot
.33988 .39588 Mdot
.55781 .48125 Mdot
.86478 .45268 Mdot
.38176 .34151 Mdot
.37638 .52218 Mdot
.28666 .47249 Mdot
.53142 .72333 Mdot
.26227 .71503 Mdot
.29964 .53639 Mdot
.40792 .78651 Mdot
.70357 .49093 Mdot
.42307 .24354 Mdot
.5674 .48961 Mdot
.33843 .50418 Mdot
.29514 .50842 Mdot
.72678 .4914 Mdot
.82847 .5846 Mdot
.35342 .38955 Mdot
.73701 .71541 Mdot
.64361 .24527 Mdot
.32636 .55336 Mdot
.67765 .60504 Mdot
.57119 .77159 Mdot
.60871 .50651 Mdot
.4973 .46552 Mdot
.34285 .39517 Mdot
.47499 .25763 Mdot
.21718 .403 Mdot
.29932 .59589 Mdot
.4591 .32867 Mdot
.32163 .36027 Mdot
.79927 .64871 Mdot
.28855 .38541 Mdot
.44039 .48752 Mdot
.47953 .58432 Mdot
.54719 .41666 Mdot
.62899 .64699 Mdot
.55172 .37657 Mdot
.26561 .56617 Mdot
.26622 .71607 Mdot
.439 .29622 Mdot
.36288 .55325 Mdot
.5782 .65345 Mdot
.37004 .52202 Mdot
.5588 .33267 Mdot
.53014 .71204 Mdot
.54074 .54645 Mdot
.49378 .35395 Mdot
.81567 .55181 Mdot
.72456 .44528 Mdot
.66746 .65056 Mdot
.3125 .52607 Mdot
.44691 .25805 Mdot
.63148 .21416 Mdot
.40214 .35344 Mdot
.48038 .84512 Mdot
.76712 .70264 Mdot
.4474 .80742 Mdot
.64565 .41332 Mdot
.29907 .37823 Mdot
.55608 .6443 Mdot
.43743 .54184 Mdot
.4686 .81785 Mdot
.47636 .22644 Mdot
.83442 .53474 Mdot
.49732 .40426 Mdot
.80497 .65976 Mdot
.4549 .29544 Mdot
.47243 .56803 Mdot
.54465 .33142 Mdot
.54685 .47205 Mdot
.64546 .72116 Mdot
.81785 .62721 Mdot
.35174 .511 Mdot
.47601 .57764 Mdot
.38142 .34975 Mdot
.57101 .33772 Mdot
.26469 .56507 Mdot
.53314 .55692 Mdot
.68224 .31997 Mdot
.83318 .60065 Mdot
.4534 .47557 Mdot
.79963 .61087 Mdot
.24566 .60646 Mdot
.16201 .52156 Mdot
.27085 .6018 Mdot
.3365 .44035 Mdot
.75274 .70625 Mdot
.49366 .31644 Mdot
.50851 .85259 Mdot
.40168 .51687 Mdot
.40926 .55992 Mdot
.83392 .593 Mdot
.45625 .83592 Mdot
.55356 .43947 Mdot
.51957 .53748 Mdot
.2289 .39265 Mdot
.4852 .49793 Mdot
.36813 .44885 Mdot
.55349 .6008 Mdot
.30793 .28418 Mdot
.7679 .68752 Mdot
.43878 .82244 Mdot
.84542 .50076 Mdot
.66506 .64381 Mdot
.51765 .75485 Mdot
.43355 .29978 Mdot
.41498 .43677 Mdot
.35935 .46889 Mdot
.79518 .67463 Mdot
.57074 .47865 Mdot
.38595 .2229 Mdot
.42169 .79361 Mdot
.72526 .32265 Mdot
.35232 .26604 Mdot
.37186 .37046 Mdot
.5446 .48608 Mdot
.51313 .3863 Mdot
.48909 .6541 Mdot
.63283 .72998 Mdot
.66809 .30129 Mdot
.38491 .56581 Mdot
.62191 .68427 Mdot
.40549 .37346 Mdot
.51252 .80194 Mdot
.38918 .24452 Mdot
.67978 .31309 Mdot
.44468 .34909 Mdot
.46972 .81656 Mdot
.4259 .80013 Mdot
.36901 .23943 Mdot
.36833 .59801 Mdot
.7966 .62104 Mdot
.38661 .40879 Mdot
.57138 .41087 Mdot
.56443 .49029 Mdot
.59918 .50243 Mdot
.29421 .73525 Mdot
.7081 .40201 Mdot
.60352 .79543 Mdot
.36502 .43765 Mdot
.66096 .3323 Mdot
.59475 .77929 Mdot
.66487 .32752 Mdot
.58065 .35214 Mdot
.42833 .36357 Mdot
.35539 .39877 Mdot
.64245 .38565 Mdot
.83157 .58466 Mdot
.30114 .62643 Mdot
.46629 .82026 Mdot
.301 .38321 Mdot
.31269 .54073 Mdot
.39793 .55444 Mdot
.39004 .55193 Mdot
.7072 .74555 Mdot
.37419 .35213 Mdot
.53453 .69665 Mdot
.55027 .33842 Mdot
.41904 .52611 Mdot
.64038 .2864 Mdot
.75709 .46247 Mdot
.45471 .24625 Mdot
.51628 .70753 Mdot
.69109 .34969 Mdot
.52856 .38573 Mdot
.37256 .60598 Mdot
.74525 .43 Mdot
.69729 .59153 Mdot
.51582 .61148 Mdot
.57967 .71752 Mdot
.69008 .71395 Mdot
.58048 .3993 Mdot
.46833 .83235 Mdot
.39221 .35399 Mdot
.58176 .72353 Mdot
.35598 .47348 Mdot
.66869 .23773 Mdot
.80777 .65649 Mdot
.65823 .78419 Mdot
.44538 .22299 Mdot
.34343 .26161 Mdot
.17546 .60331 Mdot
.30792 .4971 Mdot
.55021 .82332 Mdot
.301 .38311 Mdot
.54476 .1358 Mdot
.3077 .63143 Mdot
.54703 .65013 Mdot
.46657 .28014 Mdot
.69115 .59025 Mdot
.8157 .61401 Mdot
.55357 .40698 Mdot
.5061 .7269 Mdot
.54112 .32151 Mdot
.64848 .38215 Mdot
.82372 .58019 Mdot
.82583 .54936 Mdot
.82019 .55924 Mdot
.34001 .36586 Mdot
.6994 .3768 Mdot
.84337 .57179 Mdot
.55474 .69706 Mdot
.66038 .39767 Mdot
.57176 .46818 Mdot
.69041 .64052 Mdot
.52994 .82569 Mdot
.50518 .74453 Mdot
.49065 .49576 Mdot
.43899 .29748 Mdot
.84107 .59349 Mdot
.68111 .727 Mdot
.54475 .42734 Mdot
.71275 .73355 Mdot
.48872 .76402 Mdot
.61001 .77608 Mdot
.68786 .75766 Mdot
.47384 .46924 Mdot
.37327 .37751 Mdot
.8485 .59107 Mdot
.45497 .79585 Mdot
.28307 .47119 Mdot
.52033 .38702 Mdot
.52467 .83318 Mdot
.3433 .27046 Mdot
.25019 .39343 Mdot
.45773 .28817 Mdot
.69048 .25442 Mdot
.37424 .48927 Mdot
.50216 .46673 Mdot
.66271 .42948 Mdot
.58758 .78749 Mdot
.30409 .63275 Mdot
.49572 .81457 Mdot
.37183 .46685 Mdot
.63828 .39195 Mdot
.59576 .73522 Mdot
.41613 .81193 Mdot
.4954 .42811 Mdot
.7317 .39071 Mdot
.39193 .35677 Mdot
.40214 .23386 Mdot
.36424 .25647 Mdot
.66742 .26901 Mdot
.63862 .48811 Mdot
.80465 .64206 Mdot
.58654 .83457 Mdot
.69238 .75831 Mdot
.37922 .23892 Mdot
.17224 .56296 Mdot
.33659 .4029 Mdot
.55901 .70553 Mdot
.70413 .57702 Mdot
.4594 .44598 Mdot
.66842 .56461 Mdot
.28322 .45914 Mdot
.6311 .21309 Mdot
.3982 .54921 Mdot
.5555 .6962 Mdot
.48757 .24469 Mdot
.41719 .54395 Mdot
.72557 .39134 Mdot
.44752 .3531 Mdot
.35316 .23487 Mdot
.47275 .81686 Mdot
.29711 .62376 Mdot
.36093 .59446 Mdot
.69727 .40313 Mdot
.48125 .54623 Mdot
.52943 .66529 Mdot
.58033 .40943 Mdot
.63315 .25691 Mdot
.17989 .58013 Mdot
.6443 .77776 Mdot
.5233 .84148 Mdot
.68479 .76028 Mdot
.43948 .80767 Mdot
.33393 .537 Mdot
.59013 .71688 Mdot
.2631 .40247 Mdot
.31935 .38135 Mdot
.58727 .69883 Mdot
.42037 .80728 Mdot
.55418 .4206 Mdot
.54296 .33591 Mdot
.61217 .4861 Mdot
.67318 .72549 Mdot
.56057 .76846 Mdot
.57602 .69878 Mdot
.6852 .27824 Mdot
.50022 .35337 Mdot
.54081 .7335 Mdot
.52041 .4584 Mdot
.67417 .51239 Mdot
.34675 .25648 Mdot
.28399 .45415 Mdot
.45449 .36078 Mdot
.41555 .8128 Mdot
.17841 .59559 Mdot
.44125 .5196 Mdot
.7367 .46164 Mdot
.77326 .67667 Mdot
.68378 .43241 Mdot
.32863 .27453 Mdot
.70808 .26503 Mdot
.31062 .50782 Mdot
.44449 .29301 Mdot
.62564 .39523 Mdot
.40329 .56709 Mdot
.44295 .23289 Mdot
.44795 .33565 Mdot
.61429 .50326 Mdot
.75036 .71524 Mdot
.70333 .4697 Mdot
.48571 .47529 Mdot
.64759 .68132 Mdot
.40045 .45284 Mdot
.40923 .51908 Mdot
.59435 .74214 Mdot
.45192 .49804 Mdot
.81034 .56498 Mdot
.62375 .20844 Mdot
.50443 .4933 Mdot
.54808 .70753 Mdot
.55652 .69072 Mdot
.64302 .24486 Mdot
.55775 .32637 Mdot
.36065 .4507 Mdot
.70054 .48515 Mdot
.73897 .73099 Mdot
.46979 .39895 Mdot
.58965 .73019 Mdot
.39637 .39412 Mdot
.68308 .49017 Mdot
.47297 .58568 Mdot
.69455 .75314 Mdot
.52867 .43051 Mdot
.8722 .43416 Mdot
.39355 .79075 Mdot
.42976 .25999 Mdot
.56948 .35642 Mdot
.48171 .82804 Mdot
.40876 .28789 Mdot
.40895 .50065 Mdot
.37853 .45354 Mdot
.51208 .82951 Mdot
.52323 .42423 Mdot
.5264 .44027 Mdot
.33899 .24852 Mdot
.84162 .56096 Mdot
.4847 .49089 Mdot
.257 .38615 Mdot
.50851 .7553 Mdot
.66116 .45972 Mdot
.39899 .35515 Mdot
.26349 .30684 Mdot
.41262 .40226 Mdot
.46385 .50684 Mdot
.58027 .83981 Mdot
.57049 .40448 Mdot
.39018 .35994 Mdot
.8722 .43824 Mdot
.8792 .42397 Mdot
.40182 .33708 Mdot
.786 .68686 Mdot
.53173 .43617 Mdot
.3289 .27728 Mdot
.33974 .38908 Mdot
.73595 .48496 Mdot
.63126 .27493 Mdot
.70862 .75576 Mdot
.16364 .57206 Mdot
.36403 .45605 Mdot
.46097 .27021 Mdot
.70472 .76131 Mdot
.57874 .39232 Mdot
.5442 .68581 Mdot
.16325 .5215 Mdot
.34326 .78259 Mdot
.48066 .84192 Mdot
.6892 .27261 Mdot
.29407 .73914 Mdot
.36475 .76731 Mdot
.35519 .50255 Mdot
.5305 .83604 Mdot
.49651 .62685 Mdot
.67903 .24124 Mdot
.46779 .81595 Mdot
.32603 .26466 Mdot
.24425 .67295 Mdot
.41322 .51586 Mdot
.588 .40496 Mdot
.43721 .37112 Mdot
.30477 .28861 Mdot
.36606 .36499 Mdot
.67718 .41336 Mdot
.59324 .66016 Mdot
.57957 .35608 Mdot
.41185 .21648 Mdot
.72495 .27376 Mdot
.5852 .41111 Mdot
.823 .52326 Mdot
.36528 .40284 Mdot
.5736 .67157 Mdot
.56228 .34633 Mdot
.56981 .75029 Mdot
.53687 .70109 Mdot
.6362 .42801 Mdot
.75618 .70881 Mdot
.53575 .69529 Mdot
.82171 .53594 Mdot
.50668 .8557 Mdot
.72387 .72149 Mdot
.41662 .57074 Mdot
.52964 .64437 Mdot
.52801 .82191 Mdot
.53521 .8191 Mdot
.83185 .51498 Mdot
.41271 .78427 Mdot
.58737 .69316 Mdot
.65147 .40559 Mdot
.75155 .47556 Mdot
.72475 .401 Mdot
.48591 .82819 Mdot
.64062 .23596 Mdot
.59634 .77505 Mdot
.444 .22603 Mdot
.4196 .80991 Mdot
.55317 .44585 Mdot
.57277 .74635 Mdot
.40254 .41303 Mdot
.52465 .5408 Mdot
.33071 .57657 Mdot
.85988 .53369 Mdot
.36168 .24486 Mdot
.62868 .77571 Mdot
.37946 .22666 Mdot
.51288 .39021 Mdot
.38054 .78028 Mdot
.54403 .32155 Mdot
.46331 .53382 Mdot
.33909 .55084 Mdot
.53962 .79458 Mdot
.5565 .42699 Mdot
.30949 .26937 Mdot
.70893 .31103 Mdot
.71351 .74361 Mdot
.59669 .78032 Mdot
.84947 .48515 Mdot
.53148 .73985 Mdot
.68932 .34793 Mdot
.81375 .54785 Mdot
.42456 .22589 Mdot
.57168 .68953 Mdot
.82988 .57446 Mdot
.53073 .30447 Mdot
.77174 .69762 Mdot
.29979 .4417 Mdot
.54337 .70444 Mdot
.28729 .29038 Mdot
.56528 .69641 Mdot
.56475 .69081 Mdot
.63079 .78338 Mdot
.38208 .35292 Mdot
.39257 .34191 Mdot
.38581 .40956 Mdot
.29579 .54042 Mdot
.74387 .47853 Mdot
.47124 .47969 Mdot
.84463 .50457 Mdot
.63768 .4873 Mdot
.44331 .7765 Mdot
.46677 .8254 Mdot
.26274 .40043 Mdot
.61686 .40469 Mdot
.3027 .27923 Mdot
.70953 .27867 Mdot
.64427 .73607 Mdot
.83934 .56759 Mdot
.62121 .40488 Mdot
.69299 .57994 Mdot
.75398 .32944 Mdot
.25316 .37755 Mdot
.36066 .45575 Mdot
.44689 .4871 Mdot
.69497 .43477 Mdot
.63387 .68519 Mdot
.44512 .80442 Mdot
.5697 .83933 Mdot
.82605 .51821 Mdot
.35543 .46525 Mdot
.57074 .70071 Mdot
.42945 .3517 Mdot
.55666 .78538 Mdot
.85087 .49346 Mdot
.27713 .73221 Mdot
.5192 .38648 Mdot
.4294 .81299 Mdot
.37857 .3739 Mdot
.54532 .68755 Mdot
.5808 .69875 Mdot
.81474 .55625 Mdot
.48487 .26491 Mdot
.53965 .40139 Mdot
.40781 .38286 Mdot
.6146 .66686 Mdot
.38956 .52811 Mdot
.68148 .25354 Mdot
.37026 .34814 Mdot
.84953 .48381 Mdot
.3458 .7622 Mdot
.73612 .32841 Mdot
.86021 .46184 Mdot
.50177 .3445 Mdot
.38551 .52871 Mdot
.16727 .49387 Mdot
.57712 .72001 Mdot
.27742 .60442 Mdot
.59126 .47683 Mdot
.5902 .6776 Mdot
.42404 .25405 Mdot
.5184 .74479 Mdot
.52253 .6974 Mdot
.45412 .35792 Mdot
.38016 .77546 Mdot
.45119 .35927 Mdot
.5699 .83668 Mdot
.473 .46511 Mdot
.57418 .36409 Mdot
.73741 .29198 Mdot
.34361 .54349 Mdot
.41005 .23033 Mdot
.73214 .71923 Mdot
.68529 .64314 Mdot
.4521 .3339 Mdot
.45343 .31734 Mdot
.51138 .26337 Mdot
.26295 .43966 Mdot
.7864 .66012 Mdot
.45759 .83353 Mdot
.34582 .57455 Mdot
.52273 .28197 Mdot
.65651 .41809 Mdot
.57892 .40815 Mdot
.65838 .76321 Mdot
.34075 .62884 Mdot
.82089 .63962 Mdot
.65395 .22899 Mdot
.4162 .24422 Mdot
.46664 .43623 Mdot
.70989 .58767 Mdot
.56603 .65789 Mdot
.37052 .55842 Mdot
.56752 .41988 Mdot
.40915 .2998 Mdot
.51715 .29738 Mdot
.39141 .53978 Mdot
.50136 .72069 Mdot
.36992 .59659 Mdot
.26849 .42014 Mdot
.65997 .26486 Mdot
.47981 .83318 Mdot
.43857 .33741 Mdot
.5337 .67278 Mdot
.38556 .58115 Mdot
.72774 .41233 Mdot
.70241 .61431 Mdot
.85931 .55581 Mdot
.75328 .69556 Mdot
.46677 .3605 Mdot
.39702 .24165 Mdot
.24059 .63012 Mdot
.64347 .77702 Mdot
.52627 .40726 Mdot
.48227 .82344 Mdot
.68534 .32859 Mdot
.67917 .75711 Mdot
.5709 .34936 Mdot
.44783 .47012 Mdot
.45062 .81959 Mdot
.46606 .73739 Mdot
.42635 .81644 Mdot
.71718 .28982 Mdot
.7201 .45581 Mdot
.36096 .79045 Mdot
.40942 .39506 Mdot
.54537 .43544 Mdot
.69807 .5139 Mdot
.45814 .45044 Mdot
.51358 .82561 Mdot
.50907 .32776 Mdot
.5258 .73145 Mdot
.49146 .23698 Mdot
.36481 .45362 Mdot
.76431 .69056 Mdot
.3771 .24459 Mdot
.4518 .82963 Mdot
.74841 .47082 Mdot
.51926 .78298 Mdot
.63761 .23964 Mdot
.67333 .64266 Mdot
.52208 .56104 Mdot
.67154 .3121 Mdot
.49565 .55648 Mdot
.66005 .73641 Mdot
.73282 .40792 Mdot
.81627 .62184 Mdot
.68364 .71834 Mdot
.43802 .37236 Mdot
.48743 .54806 Mdot
.49254 .27202 Mdot
.8258 .6228 Mdot
.64996 .73143 Mdot
.30007 .28833 Mdot
.48049 .84075 Mdot
.41456 .78106 Mdot
.86271 .456 Mdot
.38059 .35978 Mdot
.62794 .38792 Mdot
.53548 .83615 Mdot
.48912 .40051 Mdot
.3691 .76828 Mdot
.55673 .42661 Mdot
.43031 .30872 Mdot
.83368 .58558 Mdot
.47595 .6114 Mdot
.42596 .36941 Mdot
.77149 .42328 Mdot
.44465 .28996 Mdot
.65378 .72404 Mdot
.60015 .41212 Mdot
.29559 .60401 Mdot
.70071 .58592 Mdot
.28553 .72866 Mdot
.50637 .26064 Mdot
.47569 .82824 Mdot
.48847 .82112 Mdot
.51569 .76226 Mdot
.40015 .6011 Mdot
.86202 .45424 Mdot
.68723 .36974 Mdot
.5868 .42522 Mdot
.44774 .34814 Mdot
.52255 .68755 Mdot
.43471 .79171 Mdot
.68587 .49097 Mdot
.68939 .60711 Mdot
.68327 .32289 Mdot
.724 .74262 Mdot
.40953 .43025 Mdot
.35895 .41634 Mdot
.52875 .29444 Mdot
.30437 .2865 Mdot
.4596 .22353 Mdot
.38224 .32951 Mdot
.51277 .82341 Mdot
.44212 .51871 Mdot
.44334 .48136 Mdot
.46931 .38625 Mdot
.49189 .80704 Mdot
.34571 .49092 Mdot
.27811 .42075 Mdot
.63334 .26221 Mdot
.8358 .50329 Mdot
.50232 .38655 Mdot
.42004 .51411 Mdot
.50028 .44984 Mdot
.707 .44784 Mdot
.36587 .45491 Mdot
.38802 .3546 Mdot
.44751 .31618 Mdot
.81115 .58425 Mdot
.50251 .47871 Mdot
.52856 .64946 Mdot
.41226 .79803 Mdot
.48763 .45654 Mdot
.49059 .82463 Mdot
.64576 .38073 Mdot
.81935 .56563 Mdot
.58723 .73086 Mdot
.48337 .75854 Mdot
.61705 .48901 Mdot
.47592 .23308 Mdot
.69354 .7544 Mdot
.52064 .4077 Mdot
.45202 .52462 Mdot
.54482 .31002 Mdot
.50097 .85118 Mdot
.54776 .57239 Mdot
.17909 .57649 Mdot
.51611 .53934 Mdot
.69617 .59706 Mdot
.69317 .58571 Mdot
.25845 .42594 Mdot
.56897 .41141 Mdot
.36319 .50559 Mdot
.70419 .43832 Mdot
.63845 .26051 Mdot
.58846 .80291 Mdot
.85679 .52944 Mdot
.44448 .25891 Mdot
.47121 .84658 Mdot
.46428 .24987 Mdot
.42955 .29035 Mdot
.34919 .76248 Mdot
.45207 .53048 Mdot
.70142 .39863 Mdot
.5069 .75021 Mdot
.50484 .34275 Mdot
.85205 .523 Mdot
.45921 .50951 Mdot
.52096 .73638 Mdot
.251 .5876 Mdot
.40847 .52433 Mdot
.21166 .40704 Mdot
.31608 .38333 Mdot
.51222 .85006 Mdot
.46888 .81809 Mdot
.35701 .40254 Mdot
.53115 .43532 Mdot
.46 .51718 Mdot
.82226 .58055 Mdot
.49875 .54417 Mdot
.74668 .70793 Mdot
.34535 .36697 Mdot
.65743 .2743 Mdot
.68224 .7163 Mdot
.63586 .73014 Mdot
.67451 .6474 Mdot
.68237 .29899 Mdot
.79051 .62038 Mdot
.49776 .60154 Mdot
.36366 .59121 Mdot
.24671 .67971 Mdot
.84794 .50113 Mdot
.42244 .23638 Mdot
.48402 .60157 Mdot
.56675 .78152 Mdot
.50221 .47609 Mdot
.57472 .66728 Mdot
.38236 .42968 Mdot
.52933 .66319 Mdot
.29442 .36383 Mdot
.39981 .22387 Mdot
.73848 .73042 Mdot
.59859 .4861 Mdot
.65445 .56198 Mdot
.34185 .50506 Mdot
.28314 .6217 Mdot
.51578 .25372 Mdot
.85773 .55299 Mdot
.27695 .43225 Mdot
.17081 .484 Mdot
.2601 .41722 Mdot
.63822 .77436 Mdot
.17028 .57237 Mdot
.26559 .44995 Mdot
.56556 .83989 Mdot
.42045 .25279 Mdot
.71432 .30045 Mdot
.38531 .2208 Mdot
.66544 .73417 Mdot
.66787 .30889 Mdot
.55552 .59348 Mdot
.78268 .68036 Mdot
.56688 .66655 Mdot
.53335 .72308 Mdot
.7986 .60474 Mdot
.44416 .81869 Mdot
.4004 .79388 Mdot
.29556 .48663 Mdot
.45651 .27428 Mdot
.18184 .60417 Mdot
.31879 .54597 Mdot
.63662 .19473 Mdot
.75394 .69303 Mdot
.77425 .39673 Mdot
.52327 .40599 Mdot
.38882 .40218 Mdot
.82191 .59075 Mdot
.50347 .81833 Mdot
.54127 .44467 Mdot
.37008 .62362 Mdot
.62038 .73721 Mdot
.55292 .78134 Mdot
.38426 .38393 Mdot
.69584 .74203 Mdot
.36802 .55755 Mdot
.47011 .58996 Mdot
.45695 .82444 Mdot
.47938 .23436 Mdot
.66776 .63781 Mdot
.83532 .50607 Mdot
.69669 .6257 Mdot
.40189 .80361 Mdot
.3397 .36551 Mdot
.2394 .64275 Mdot
.84318 .50999 Mdot
.44608 .23817 Mdot
.70446 .33499 Mdot
.87066 .4358 Mdot
.80419 .66043 Mdot
.46198 .51671 Mdot
.69743 .47864 Mdot
.55353 .83826 Mdot
.35779 .63016 Mdot
.61634 .78356 Mdot
.63273 .21418 Mdot
.37943 .78468 Mdot
.7468 .42017 Mdot
.69713 .48266 Mdot
.55169 .6814 Mdot
.49526 .37407 Mdot
.45728 .28424 Mdot
.29989 .5455 Mdot
.4205 .80649 Mdot
.66039 .26042 Mdot
.62367 .20865 Mdot
.7115 .28477 Mdot
.45924 .35077 Mdot
.76648 .69739 Mdot
.46688 .54371 Mdot
.64595 .23993 Mdot
.81884 .57735 Mdot
.69124 .56383 Mdot
.36009 .49325 Mdot
.63096 .24375 Mdot
.58632 .71613 Mdot
.28073 .72363 Mdot
.86284 .46758 Mdot
.6412 .27524 Mdot
.82574 .63131 Mdot
.65903 .78564 Mdot
.45819 .33879 Mdot
.49713 .25839 Mdot
.56248 .65238 Mdot
.47324 .49352 Mdot
.25986 .37233 Mdot
.31443 .54138 Mdot
.39854 .77758 Mdot
.37992 .60498 Mdot
.59678 .43896 Mdot
.39254 .38231 Mdot
.71827 .73789 Mdot
.54391 .69189 Mdot
.7291 .72967 Mdot
.66989 .28532 Mdot
.63029 .4867 Mdot
.87647 .42024 Mdot
.32623 .27826 Mdot
.75593 .45276 Mdot
.53565 .61027 Mdot
.48185 .5977 Mdot
.61624 .4238 Mdot
.29924 .4706 Mdot
.56268 .72778 Mdot
.35353 .7759 Mdot
.78466 .67564 Mdot
.52304 .2846 Mdot
.56527 .66136 Mdot
.3112 .38872 Mdot
.6135 .6391 Mdot
.74632 .41499 Mdot
.2756 .43569 Mdot
.32231 .75724 Mdot
.21268 .4134 Mdot
.35352 .47908 Mdot
.39085 .52578 Mdot
.59497 .66607 Mdot
.4878 .59982 Mdot
.3372 .76103 Mdot
.25632 .41541 Mdot
.34732 .49948 Mdot
.44859 .82847 Mdot
.69067 .30815 Mdot
.37667 .38212 Mdot
.24514 .6629 Mdot
.57404 .69149 Mdot
.39796 .38466 Mdot
.4847 .50144 Mdot
.69683 .25913 Mdot
.80627 .61049 Mdot
.25434 .59788 Mdot
.49823 .6028 Mdot
.75884 .33496 Mdot
.81363 .61989 Mdot
.32747 .40544 Mdot
.58326 .83174 Mdot
.46301 .52289 Mdot
.51131 .25137 Mdot
.78056 .41234 Mdot
.61469 .40194 Mdot
.57409 .48313 Mdot
.68905 .46187 Mdot
.65734 .6039 Mdot
.20365 .41089 Mdot
.5967 .4058 Mdot
.40341 .52902 Mdot
.44126 .51142 Mdot
.54736 .72042 Mdot
.5759 .48063 Mdot
.6509 .45532 Mdot
.54619 .57829 Mdot
.60777 .71841 Mdot
.53538 .6637 Mdot
.53934 .72694 Mdot
.3728 .37818 Mdot
.33737 .76222 Mdot
.39601 .79137 Mdot
.69937 .38376 Mdot
.82674 .58851 Mdot
.69013 .51325 Mdot
.74819 .69984 Mdot
.39053 .44943 Mdot
.37381 .3664 Mdot
.69835 .61858 Mdot
.86108 .46939 Mdot
.42008 .35188 Mdot
.53503 .5181 Mdot
.64955 .78725 Mdot
.71071 .73725 Mdot
.36857 .39906 Mdot
.32601 .26037 Mdot
.24999 .68868 Mdot
.56086 .67353 Mdot
.40496 .22138 Mdot
.34965 .58049 Mdot
.65125 .77695 Mdot
.70763 .43382 Mdot
.45769 .52497 Mdot
.67498 .25401 Mdot
.7337 .41961 Mdot
.34541 .60878 Mdot
.70672 .26432 Mdot
.68378 .29882 Mdot
.78832 .62367 Mdot
.59032 .42456 Mdot
.43704 .44324 Mdot
.4306 .35149 Mdot
.84463 .49349 Mdot
.31551 .56526 Mdot
.69273 .57872 Mdot
.64374 .19984 Mdot
.20585 .40808 Mdot
.36944 .76711 Mdot
.82867 .51353 Mdot
.32014 .38198 Mdot
.70002 .43629 Mdot
.24425 .31732 Mdot
.42506 .35048 Mdot
.44442 .33954 Mdot
.26763 .42248 Mdot
.52862 .78064 Mdot
.41257 .36814 Mdot
.87152 .45144 Mdot
.67578 .76069 Mdot
.68643 .39126 Mdot
.62305 .18192 Mdot
.46097 .82489 Mdot
.67663 .57794 Mdot
.37725 .35482 Mdot
.75376 .71038 Mdot
.27394 .36673 Mdot
.54037 .8367 Mdot
.4872 .46546 Mdot
.49764 .26193 Mdot
.54875 .77693 Mdot
.38041 .22886 Mdot
.64793 .40943 Mdot
.62274 .2003 Mdot
.34948 .25369 Mdot
.57171 .77167 Mdot
.5174 .42451 Mdot
.42211 .2881 Mdot
.42025 .27689 Mdot
.47503 .43921 Mdot
.43991 .54124 Mdot
.42136 .51346 Mdot
.44963 .47891 Mdot
.3479 .48869 Mdot
.4577 .43404 Mdot
.31845 .28369 Mdot
.2803 .38242 Mdot
.69068 .28291 Mdot
.26109 .70096 Mdot
.53529 .73568 Mdot
.31398 .6342 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`2]ooooo`;o0000V_ooool001cooooo00?o0000ooooooooool0[Oooool2o`0009[ooooo000L
ooooo`03o`000?oooooooooo0:gooooo0_l0002Jooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0;Cooooo0_l0002Cooooo`007?ooool00ol0003ooooo
ooooo`2dooooo`Co0000TOooool001cooooo0_l0002gooooo`Co0000Soooool001cooooo00?o0000
ooooooooool0]oooool4o`0008kooooo000Looooo`03o`000?oooooooooo0;Sooooo1_l0002;oooo
o`007?ooool00ol0003oooooooooo`2kooooo`?o0000Roooool001cooooo00?o0000ooooooooool0
_Oooool3o`0008Wooooo000Looooo`03o`000?oooooooooo0;gooooo0ol00029ooooo`007?ooool0
0ol0003oooooooooo`31ooooo`;o0000Q_ooool001cooooo00?o0000ooooooooool0`Oooool2o`00
08Kooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
`_ooool2o`000003ooooool0003o000008;ooooo000Looooo`03o`000?oooooooooo0<;ooooo0_l0
00000ooooooo0000o`000002o`00083ooooo000Looooo`03o`000?oooooooooo0<Oooooo0_l00020
ooooo`007?ooool00ol0003oooooooooo`37ooooo`;o0000P?ooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0<Oooooo0ol0001o
ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^
k_ooooooA4A400Kooooo00?o0000ooooooooool0b?ooool5o`0007cooooo00000ooooooo410@oooo
o`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003ooooooooo
o`3:ooooo`Go0000N_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool0
0onHV9So8B4Qonk^kP06ooooo`?o0000aoooool2o`0000;ooooo1Ol0001iooooo`0000?oooooo`00
0?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000oooo
ooooool0aoooool2o`0000;ooooo1Ol0001iooooo`0000?ooooooa0@4?ooool00_ooool00ol@413o
ooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0aoooool3o`000004
ooooool0003o0000ooooo`?o0000N?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool0
1Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0aoooool:o`0007Sooooo0000
1_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03
o`000?oooooooooo087ooooo0_l00003ooooo`;o000000?oooooo`000?l00000?_ooool6o`0007[o
oooo000Looooo`03o`000?oooooooooo07_ooooo0_l00004ooooo`?o00000_ooool2o`000003oooo
ool0003o000000;ooooo0_l000000ooooooo0000o`00000gooooo`Ko0000N_ooool001cooooo00?o
0000ooooooooool0NOooool4o`0000?ooooo1?l00009ooooo`;o000000?oooooo`000?l000000_l0
000eooooo`Ko0000N_ooool001cooooo00?o0000ooooooooool0NOooool3o`0000;ooooo1_l00009
ooooo`;o00000oooool2o`0003Gooooo1?l0001looooo`007?ooool00ol0003oooooooooo`1hoooo
o`Co00000_ooool2o`0000Kooooo0_l00004ooooo`?o00000oooool2o`0000?ooooo0ol0000_oooo
o`Ko00000oooool2o`0007Gooooo000Looooo`03o`000?oooooooooo073ooooo0_l00006ooooo`;o
00001oooool2o`0000?ooooo0_l00004ooooo`;o00002Oooool3o`0002oooooo1_l00002ooooo`?o
0000MOooool001cooooo00?o0000ooooooooool0L?ooool2o`0000Kooooo0_l00005ooooo`Co0000
2Oooool2o`0000Wooooo0_l0000_ooooo`;o00000_ooool3o`0000;ooooo1?l0001dooooo`007?oo
ool00ol0003oooooooooo`1_ooooo`;o00003_ooool2o`0000Cooooo0_l00005ooooo`;o00002Ooo
ool3o`0000;ooooo0ol0000Yooooo`?o000000?oooooo`000?l000000_l00003ooooo`;o0000M?oo
ool001cooooo00?o0000ooooooooool0Koooool2o`0000?ooooo0_l000000ooooooo0000o`00000<
ooooo`;o00001_ooool2o`0000Wooooo0_l00002ooooo`?o0000:Oooool8o`0000Gooooo0_l0001b
ooooo`007?ooool00ol0003oooooooooo`1dooooo`;o000000?oooooo`000?l000001?ooool2o`00
00kooooo0_l0000iooooo`Go000000?oooooo`000?l000001Oooool2o`0000;ooooo0_l0001^oooo
o`007?ooool00ol0003oooooooooo`1Zooooo`;o00001_ooool2o`0000?ooooo0_l00002ooooo`Co
00001?ooool2o`000003ooooool0003o000000Sooooo0_l00009ooooo`;o0000;?ooool2o`0000;o
oooo0_l0000:ooooo`;o0000K_ooool001cooooo00?o0000ooooooooool0J_ooool2o`0000Kooooo
0_l00003ooooo`Oo00001Oooool2o`000003ooooool0003o000000Sooooo0_l00009ooooo`;o0000
1oooool2o`00027ooooo1?l00002ooooo`;o0000N_ooool001cooooo0_l0001Xooooo`;o000000?o
ooooo`000?l000003Oooool2o`0001?ooooo0_l00003ooooo`Co00002oooool4o`00027ooooo0ol0
001oooooo`007?ooool00ol0003oooooooooo`1Wooooo`;o00001Oooool2o`0001Gooooo0ol00003
ooooo`;o000000Coooooo`000?l0003o00000_ooool4o`000003ooooool0003o000000Sooooo1?l0
000Rooooo`;o00003Oooool2o`000003ooooool0003o000000;o0000Joooool001cooooo00?o0000
ooooooooool0KOooool3o`0000?ooooo0_l0000@ooooo`?o000000?oooooo`000?l000001_l00006
ooooo`Go00000_ooool2o`0000Cooooo0_l0000Rooooo`Co00002oooool2o`000003ooooool0003o
000000;o00001?ooool2o`0006Gooooo000Looooo`03o`000?oooooooooo06Cooooo1?l00004oooo
o`?o00001?ooool2o`0001?ooooo0ol00002ooooo`;o00002?ooool2o`000003ooooool0003o0000
00;ooooo0_l000000ooooooo0000o`00000Uooooo`Ko00001Oooool2o`0000[ooooo0_l000000ooo
oooo0000o`00001Uooooo`007?ooool00ol0003oooooooooo`1Sooooo`Go00001?ooool2o`0001[o
oooo0_l00003ooooo`;o00003oooool2o`000004ooooool0003o0000o`0002Gooooo1Ol00005oooo
o`;o00002_ooool2o`000003ooooool0003o000006Gooooo000Looooo`03o`000?oooooooooo067o
oooo1?l000000ooooooo0000o`000007ooooo`;o00009Oooool6o`0000;ooooo0_l00002ooooo`;o
00009Oooool3o`0000Oooooo0_l0000=ooooo`;o0000IOooool001cooooo00?o0000ooooooooool0
HOooool4o`0000Oooooo0_l000000ooooooo0000o`00000Qooooo`;o000000?oooooo`000?l00000
1_l000000ooooooo0000o`00000Yooooo`;o00002?ooool4o`0000_ooooo0_l0001Uooooo`007?oo
ool00ol0003oooooooooo`1Qooooo`;o00002Oooool2o`0002Cooooo0_l000000ooooooo0000o`00
0008o`0000?ooooo0_l0000Uooooo`;o00002_ooool2o`0000Gooooo0_l0000:ooooo`;o0000Gooo
ool001cooooo00?o0000ooooooooool0G_ooool2o`0000Oooooo0_l0000Looooo`;o00002_ooool4
o`000003ooooool0003o000000Wo000000?oooooo`000?l000009Oooool2o`000003ooooool0003o
000000Cooooo0_l00008ooooo`;o00002_ooool2o`0005oooooo000Looooo`03o`000?oooooooooo
05kooooo0ol00005ooooo`?o00007?ooool4o`0000Sooooo4?l00002ooooo`;o00001_ooool2o`00
01cooooo1Ol00004ooooo`;o00001oooool2o`0000Kooooo0_l0001Tooooo`007?ooool00ol0003o
ooooooooo`1Looooo`;o000000?oooooo`000?l000001Oooool3o`0001_ooooo0_l000000ooooooo
0000o`00000;oooooa7o000000?oooooo`000?l000000oooool2o`0001gooooo0_l0000?ooooo`Co
00001?ooool2o`0006Cooooo000Looooo`03o`000?oooooooooo05cooooo0_l00002ooooo`;o0000
0_ooool2o`0000;ooooo0_l0000Jooooo`;o00002oooool2o`0000Cooooo3Ol00002ooooo`;o0000
1?ooool2o`0001cooooo0_l0000:ooooo`;o00001Oooool2o`0000Cooooo0_l0001Tooooo`007?oo
ool00ol0003oooooooooo`1Hooooo`Co00000_ooool4o`0000;ooooo1_l0000Gooooo`;o00000_oo
ool2o`0000[ooooo0_l00002oooooa?o00001?ooool3o`0001gooooo0_l00008ooooo`;o00001?oo
ool2o`0000?ooooo1?l0001Tooooo`007?ooool00ol0003oooooooooo`1Hooooo`Co00000_ooool3
o`0000Gooooo0_l0000Iooooo`;o00000_ooool2o`000003ooooool0003o000000?ooooo0_l00002
ooooo`;o00000_oooolAo`0000Oooooo0_l0000Mooooo`;o00003_ooool2o`0000;ooooo0ol00002
ooooo`;o00001Oooool2o`0005_ooooo000Looooo`03o`000?oooooooooo05Gooooo1ol0000Roooo
o`;o00001Oooool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000004oooo
oa3o00000_ooool2o`0002;ooooo0ol0000Aooooo`?o00000_ooool2o`0000Gooooo0_l0001Koooo
o`007?ooool00ol0003oooooooooo`1Eooooo`Co00001_ooool4o`0001_ooooo0_l00005ooooo`;o
00001?ooool4o`000003ooooool0003o000000Cooooo5?l0000Sooooo`;o00005_ooool2o`0006;o
oooo000Looooo`;o0000E_ooool3o`0000Oooooo1?l0000Iooooo`Co000000?oooooo`000?l00000
1_ooool4o`0000Sooooo5?l0000/ooooo`;o00000oooool2o`0000Sooooo1?l0001Qooooo`007?oo
ool00ol0003oooooooooo`1Aooooo`;o00000_ooool2o`0002Gooooo1?l000000ooooooo0000o`00
0006ooooo`;o00002?oooolHo`0002[ooooo0_l00003ooooo`;o00002?ooool4o`00067ooooo000L
ooooo`03o`000?oooooooooo053ooooo1Ol00005ooooo`;o00008?ooool2o`0000_ooooo0_l00007
oooooa?o000000?oooooo`000?l000000ol0000kooooo`?o0000H?ooool001cooooo00?o0000oooo
ooooool0D?ooool5o`0000Gooooo0_l0000Pooooo`;o00001Oooool2o`0000?ooooo1?l00006oooo
oa?o000000?oooooo`000?l000000_l00003ooooo`;o00009_ooool2o`0000Kooooo1?l000001?oo
oooo0000o`000?l00002ooooo`Go0000GOooool001cooooo00?o0000ooooooooool0D?ooool2o`00
02Sooooo1?l00005ooooo`;o000000?oooooo`000?l000001?l00006oooooa?o000000?oooooo`00
0?l000000ol00002ooooo`;o00009_ooool3o`000003ooooool0003o000000;ooooo1?l000000ooo
oooo0000o`000002o`0000?ooooo1?l0001Looooo`007?ooool00ol0003oooooooooo`1:ooooo`;o
000000?oooooo`000?l00000:oooool2o`0000Oooooo1_l000000ooooooo0000o`000002ooooo`;o
00000_ooool:o`000003ooooool0003o000000Ko000000?oooooo`000?l000000ol0000[ooooo`;o
000000?oooooo`000?l000001oooool4o`0000Gooooo0_l0001Looooo`007?ooool00ol0003ooooo
ooooo`18ooooo`[o00009_ooool5o`0000Sooooo2?l000000ooooooo0000o`00000Eo`000003oooo
ool0003o000000;o00001oooool2o`0001oooooo0_l00006ooooo`;o00003oooool3o`0005_ooooo
000Looooo`03o`000?oooooooooo04Sooooo2_l0000Vooooo`Go00001_ooool2o`0000;ooooo1_l0
0003oooooaCo000000?oooooo`000?l000002?l00002ooooo`;o00007oooool2o`0000Kooooo0_l0
0007ooooo`;o00000oooool2o`0000;ooooo0ol0001Jooooo`007?ooool00ol0003oooooooooo`18
ooooo`So0000:Oooool4o`0000?ooooo0_l000000ooooooo0000o`000005ooooo`?o00000ooooolO
o`0002?ooooo0ol00005ooooo`;o00001_ooool3o`000003ooooool0003o000000;o00000oooool4
o`0005Sooooo000Looooo`03o`000?oooooooooo04Wooooo0_l0000`ooooo`;o00000oooool2o`00
00Wooooo0_l00003oooooago00001?ooool2o`00023ooooo0ol00005ooooo`;o00001Oooool3o`00
0003ooooool0003o000000?ooooo1ol0001Gooooo`007?ooool00ol0003oooooooooo`1gooooo`?o
00004Oooool2o`0000Cooooo4ol000000ooooooo0000o`000003o`000003ooooool0003o000000;o
00000_ooool2o`00023ooooo0ol00005ooooo`;o00001_ooool2o`000003ooooool0003o000000?o
oooo0_l000000ooooooo0000o`000003o`0005Kooooo000Looooo`03o`000?oooooooooo07Kooooo
1?l0000Aooooo`;o00000_oooolDo`0000?ooooo0ol00003ooooo`?o00000oooool2o`0000;ooooo
0_l0000Kooooo`;o00003?ooool2o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`Oo0000
E?ooool001cooooo00?o0000ooooooooool0M_ooool2o`0000Oooooo0_l0000:oooooaOo00001?oo
ool3o`0000Cooooo1?l000000ooooooo0000o`000002ooooo`;o00009oooool4o`0000Cooooo1Ol0
0006ooooo`?o0000E?ooool001cooooo00?o0000ooooooooool0N?ooool4o`0000?ooooo0_l0000:
oooooaKo00001?ooool4o`0000Cooooo1?l00005ooooo`;o00009oooool2o`0000Sooooo1?l00005
ooooo`;o0000EOooool001cooooo00?o0000ooooooooool0N?ooool6o`0000Wooooo0_l00004oooo
o`;o00000_ooool=o`000004ooooool0003o0000o`0000?ooooo0_l00012ooooo`Co00001_ooool2
o`0005Cooooo000Looooo`03o`000?oooooooooo07[ooooo1?l00009ooooo`?o00000_ooool2o`00
00Cooooo4?l0000Aooooo`Go0000<_ooool2o`0000Oooooo0_l0001Dooooo`007?ooool2o`0007Ko
oooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l00005ooooo`Go000000?oooooo`000?l0
00003_l00002ooooo`Co00004Oooool5o`0002Cooooo0ol000000ooooooo0000o`00000Aooooo`;o
0000E?ooool001cooooo00?o0000ooooooooool0Loooool7o`0000;ooooo0_l000000ooooooo0000
o`000004ooooo`Ko00000_oooolEo`0001;ooooo1?l000000ooooooo0000o`00000Qooooo`?o0000
00?oooooo`000?l000002_ooool2o`0000Oooooo0_l0001Booooo`007?ooool00ol0003ooooooooo
o`1booooo`?o000000?oooooo`000?l000002_l00003ooooo`;o000000Coooooo`000?l0003o0000
0oooool2o`000003ooooool0003o000000oo00004oooool2o`000004ooooool0003o0000o`00037o
oooo1?l00005ooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0L_ooool2o`0000?ooooo
3?l00006ooooo`;o00000_ooool5o`0000;ooooo2ol00002ooooo`;o00004_ooool2o`000004oooo
ool0003o0000o`0001Wooooo0_l0000;ooooo`;o00002oooool3o`0005Sooooo000Looooo`03o`00
0?oooooooooo05cooooo0_l00002ooooo`;o00000oooool2o`0000Cooooo0_l00003ooooo`;o0000
1_ooool5o`0000;ooooo1?l0000:ooooo`Go00000_ooool<o`000003ooooool0003o000001;ooooo
0_l00002ooooo`;o00006Oooool2o`0000_ooooo0_l00002ooooo`;o00002?ooool2o`0005Sooooo
000Looooo`03o`000?oooooooooo05cooooo0ol000000ooooooo0000o`000003ooooo`;o00001?oo
ool2o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`;o00003?ooool2o`0000Kooooo0ol0
00000ooooooo0000o`00000;o`000003ooooool0003o000001Cooooo0_l0000/ooooo`;o00002Ooo
ool3o`0005Kooooo000Looooo`03o`000?oooooooooo05Gooooo0_l00005ooooo`?o00001_ooool4
o`0000;ooooo0ol00005ooooo`;o000000Coooooo`000?l0003ooooo0_l00007ooooo`;o00000ooo
ool2o`0000Kooooo0_l00002ooooo`Co000000?oooooo`000?l000001_l000000ooooooo0000o`00
000Dooooo`Co00006?ooool2o`0001_ooooo0ol00005ooooo`;o0000Coooool001cooooo00?o0000
ooooooooool0DOooool7o`0000oooooo0_l000000ooooooo0000o`000002o`0000Oooooo0ol00000
0ooooooo0000o`000007ooooo`;o00000oooool2o`000004ooooool0003o0000o`0000Oooooo0ol0
00000ooooooo0000o`000007o`0000;ooooo0_l0000Booooo`Co00006?ooool2o`0000Kooooo0_l0
0006ooooo`;o00002oooool3o`0000Gooooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`1;
ooooo`;o00001?ooool7o`0001;ooooo0_l00009ooooo`Ko00001Oooool2o`0000Sooooo0ol00005
ooooo`;o00001?ooool3o`000003ooooool0003o000000?o00000_ooool2o`00013ooooo1Ol0000I
ooooo`;o00001_ooool2o`0000Kooooo0_l0000=ooooo`Co00000_ooool2o`0004oooooo000Loooo
o`03o`000?oooooooooo04_ooooo0_l00002ooooo`Co00000_ooool2o`0000Kooooo0_l0000=oooo
o`;o00001oooool6o`0000Gooooo0_l0000@ooooo`;o00000oooool2o`0000?ooooo1Ol00002oooo
o`Co00002?ooool2o`0000Cooooo0ol0000Kooooo`;o00002_ooool2o`0000?ooooo0_l0000<oooo
o`Co0000Doooool001cooooo00?o0000ooooooooool0B?ooool2o`0000Gooooo0_l000000ooooooo
0000o`000009ooooo`;o00001Oooool2o`0000Kooooo0ol00006ooooo`?o00007oooool2o`0000?o
oooo1_l000000ooooooo0000o`000002o`0000Sooooo0_l0000?ooooo`;o00003?ooool2o`0000oo
oooo0_l00003ooooo`;o00003_ooool2o`0005?ooooo000Looooo`03o`000?oooooooooo04Sooooo
0_l00008ooooo`;o00000oooool2o`0000Gooooo0_l00003ooooo`?o00001oooool2o`0000Sooooo
1?l000000ooooooo0000o`000002o`000003ooooool0003o000001Gooooo0_l00002ooooo`Ko0000
3?ooool3o`000003ooooool0003o000000Co00000oooool2o`0000?ooooo0_l0000<ooooo`?o0000
3_ooool2o`0000?ooooo0ol0001Rooooo`007?ooool00ol0003oooooooooo`1>ooooo`Co00001Ooo
ool2o`000003ooooool0003o000000;ooooo0_l00003ooooo`?o00003Oooool2o`0000;ooooo1?l0
00000ooooooo0000o`000002o`000003ooooool0003o000001;ooooo0_l000001?oooooo0000o`00
0?ooool6o`000003ooooool0003o000000?o000000?oooooo`000?l000001?ooool:o`0000?ooooo
0_l0000;ooooo`;o00000oooool4o`0000kooooo0_l00003ooooo`?o00003oooool2o`00057ooooo
000Looooo`03o`000?oooooooooo04Kooooo0_l00005ooooo`Go00002?ooool2o`0000Gooooo0_l0
0008ooooo`;o00000_ooool2o`0000;ooooo0ol0000Oooooo`;o00001?ooool2o`0000;ooooo0_l0
00000ooooooo0000o`000003o`000003ooooool0003o000000;o00000oooool4o`0001Gooooo0_l0
0003ooooo`;o00005Oooool3o`0000?ooooo0_l00009ooooo`?o0000DOooool00006ooooooo^k^ko
<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`00
0?oooooooooo04Kooooo0ol00004ooooo`?o00003?ooool2o`0000;ooooo1Ol00006ooooo`;o0000
0_ooool2o`0000;ooooo0ol0000]ooooo`;o00001Oooool2o`0000cooooo0_l0000Booooo`;o0000
3Oooool2o`0000Sooooo1ol00009ooooo`Oo0000COooool00006oooooomgMgOoV9RHoooooonHV9So
MgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`17ooooo`;o
00001Oooool2o`0000Wooooo0_l000000ooooooo0000o`000002ooooo`Ko00001Oooool3o`0000oo
oooo0_l00002ooooo`;o0000=Oooool2o`0000gooooo0_l00003ooooo`;o00003Oooool2o`0000So
oooo1Ol0000;ooooo`Oo0000COooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool0
2Oooool5o`0000Kooooo00?o0000ooooooooool0FOooool?o`0000?ooooo0ol00002ooooo`;o0000
0_ooool2o`0000Oooooo0_l00002ooooo`;o00004_ooool2o`0002;ooooo0_l0000<ooooo`;o0000
2_ooool2o`0000_ooooo0_l0000Cooooo`Go0000Coooool00003ooooool0003ooooo00;ooooo00?o
0000ooooooooool02Oooool01?m4A4CogMgMooooool00007ooooo`?o0000@oooool5o`0000[ooooo
0_l00006oooooaGo000000Coooooo`000?l0003ooooo0ol000000ooooooo0000o`000002ooooo`;o
00001Oooool2o`00017ooooo0_l00004ooooo`;o00003oooool2o`0000_ooooo0_l00009ooooo`;o
00003Oooool2o`0000[ooooo1Ol00004ooooo`;o00003?ooool2o`00057ooooo00000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003o
ooooooooo`13ooooo`Oo00000_ooool2o`0000Cooooo0_l00006oooooaGo000000Coooooo`000?l0
003ooooo0ol000000ooooooo0000o`000002ooooo`;o00001Oooool2o`0001Oooooo0_l000000ooo
oooo0000o`000006ooooo`;o00001?ooool2o`0000Sooooo0_l00003ooooo`;o000000?oooooo`00
0?l000001?ooool4o`0000Sooooo0_l0000=ooooo`;o000000?oooooo`000?l000001?ooool2o`00
00cooooo0ol0001@ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03
ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0?oooool4o`0000Gooooo0_l00002ooooo`?o
00002?oooolGo`0000Kooooo0_l00004ooooo`;o00008_ooool2o`0000Gooooo1?l00007ooooo`;o
00001?ooool7o`000003ooooool0003o000000Gooooo0ol00007ooooo`?o00006?ooool2o`0000[o
oooo0ol000000ooooooo0000o`00001=ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<oooo
o`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0?_ooool5o`0000Gooooo0_l00003oooo
o`?o00001ooooolGo`0000Kooooo0_l00004ooooo`;o0000:Oooool4o`0000Oooooo0_l00003oooo
o`Oo00000oooool2o`0000Sooooo0_l00004ooooo`;o00006?ooool3o`0000_ooooo0_l000000ooo
oooo0000o`00000Oooooo`;o0000;?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool0
0omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo03kooooo0_l000000ooooooo0000o`000004
ooooo`?o00001?ooool4o`0000Gooooo6?l00004ooooo`;o00001Oooool2o`0000?ooooo0_l0000d
ooooo`?o00000_ooool2o`0000?ooooo0_l00007ooooo`?o00000oooool2o`0000Sooooo0_l0000?
ooooo`;o00001?ooool2o`0000Gooooo1_l0000Oooooo`;o0000;?ooool001cooooo00?o0000oooo
ooooool0@Oooool2o`0000Cooooo0_l00005ooooo`Go00000ooooolIo`000003ooooool0003o0000
00?o00002_ooool2o`0002gooooo0_l0000Hooooo`;o00001?ooool2o`000003ooooool0003o0000
00Gooooo0_l0000@ooooo`;o00000oooool2o`0000Gooooo1?l0000Qooooo`;o0000;?ooool001co
oooo00?o0000ooooooooool0@oooool2o`0000Wooooo0_l000001?oooooo0000o`000?oooolFo`00
0003ooooool0003o000000;o000000?oooooo`000?l000000ol000000ooooooo0000o`00000foooo
o`Co00000oooool2o`0001Gooooo0_l00003ooooo`;o00005oooool3o`0000;ooooo0_l00005oooo
o`;o00008Oooool4o`0002cooooo000Looooo`03o`000?oooooooooo03kooooo0_l00003ooooo`?o
00002Oooool2o`0000;ooooo6ol00005ooooo`;o000000?oooooo`000?l00000;?ooool4o`0000So
oooo0_l00003ooooo`;o00001Oooool4o`0000?ooooo1Ol00004ooooo`;o00001oooool2o`0001Co
oooo0_l00002ooooo`;o00001_ooool2o`00023ooooo1?l0000/ooooo`007?ooool00ol0003ooooo
ooooo`0nooooo`;o00001?ooool2o`0000Wooooo0ol000000ooooooo0000o`000004oooooaGo0000
=_ooool4o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o00002?oooolBo`0000?ooooo
0_l00003ooooo`Co00004_ooool2o`0000Wooooo0ol0000Qooooo`;o0000;Oooool001cooooo00?o
0000ooooooooool0?_ooool2o`00013ooooo0_l00006oooooaKo00002_ooool2o`0000Oooooo0_l0
000Jooooo`;o00002Oooool3o`0000;ooooo0_l00002ooooo`;o00002?oooolCo`0000;ooooo0_l0
00000ooooooo0000o`000004o`0001Gooooo0_l00006ooooo`;o00008_ooool2o`0002gooooo000L
ooooo`03o`000?oooooooooo03_ooooo0_l0000IoooooaKo00003?ooool2o`0000Oooooo0_l0000>
ooooo`;o00002_ooool2o`0000Wooooo0_l0000AoooooaKo00000_ooool2o`0000Gooooo0_l00006
ooooo`;o00002_ooool2o`0000Kooooo0_l0000Oooooo`;o0000<?ooool001cooooo00?o0000oooo
ooooool0>oooool2o`0001?ooooo0_l00004oooooaKo00001_ooool2o`0000oooooo0_l0000<oooo
o`;o000000?oooooo`000?l000004oooool2o`0000;ooooo0_l00008ooooo`;o00000ooooolAo`00
0003ooooool0003o000000?o00001oooool2o`0000;ooooo1_l0000Booooo`;o00007oooool2o`00
033ooooo000Looooo`03o`000?oooooooooo053ooooo1?l00002oooooaKo00001_ooool3o`0000ko
oooo0_l0000?ooooo`;o000000?oooooo`000?l000003_ooool4o`0000;ooooo0_l000000ooooooo
0000o`000005ooooo`;o000000?oooooo`000?l000006?l00008ooooo`Oo00004oooool2o`0001oo
oooo1?l0000^ooooo`007?ooool00ol0003oooooooooo`1Booooo`;o00000ooooolEo`0000Kooooo
0ol0000Eooooo`;o00002oooool2o`0000kooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo
0_l00004oooooako00001?ooool2o`0000?ooooo0_l0000;ooooo`;o00001_ooool2o`000003oooo
ool0003o000001cooooo1?l0000^ooooo`007?ooool00ol0003oooooooooo`1FoooooaKo00007_oo
ool2o`0000Gooooo0_l0000Fooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l0
0004ooooob3o00001?ooool2o`0000Sooooo0_l00004ooooo`;o00001_ooool2o`000003ooooool0
003o000001gooooo0_l0000_ooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00006oooool5
o`000003ooooool0003o000000co00002_ooool2o`0000Gooooo0_l0000Dooooo`;o00005_ooool2
o`000003ooooool0003o000000;ooooo0_l00008oooooago000000Coooooo`000?l0003o00000ooo
ool2o`0000;ooooo0_l00004ooooo`;o00000oooool2o`0000Oooooo0_l0000Pooooo`;o0000;ooo
ool001cooooo0_l0000jooooo`;o00006?ooool2o`000003ooooool0003o0000013o00002Oooool2
o`000003ooooool0003o000000Gooooo0_l0000Dooooo`;o00003?ooool2o`0001Sooooo6_l00000
0ooooooo0000o`000005o`0000Oooooo0_l00009ooooo`?o00009oooool2o`00033ooooo000Loooo
o`03o`000?oooooooooo05;ooooo0ol00003ooooo`ko00002oooool4o`0000;ooooo0_l00005oooo
o`;o00004Oooool2o`0000cooooo0_l0000>ooooo`;o00002?oooolPo`000003ooooool0003o0000
00Kooooo0_l0000:ooooo`;o00000_ooool2o`00023ooooo1Ol0000`ooooo`007?ooool00ol0003o
ooooooooo`1Booooo`;o00000_ooool2o`000003ooooool0003o000000_o00002oooool4o`0000;o
oooo0_l00005ooooo`;o00006oooool2o`0000Sooooo0_l00004ooooo`;o00000_ooool2o`0000;o
oooo0_l00004ooooob3o000000?oooooo`000?l000001_ooool2o`0000;ooooo0_l0000:ooooo`;o
00008?ooool3o`0003;ooooo000Looooo`03o`000?oooooooooo05Kooooo3Ol0000>ooooo`Co0000
9_ooool2o`0000Sooooo0_l00004ooooo`;o00001_ooool2o`0000Cooooo9Ol00006ooooo`Co0000
0oooool2o`0002Oooooo0_l0000cooooo`007?ooool00ol0003oooooooooo`1Hooooo`Oo00004?oo
ool2o`000003ooooool0003o000003oooooo1?l00003ooooobCo00001Oooool4o`0000Cooooo0_l0
0005ooooo`;o00008?ooool4o`00037ooooo000Looooo`03o`000?oooooooooo05Sooooo1?l00003
ooooo`;o00003Oooool6o`000003ooooool0003o000001oooooo0_l00003ooooo`;o000000Cooooo
o`000?l0003o00004oooool3o`0000;ooooo9_l00004ooooo`?o00001_ooool2o`0000Cooooo0_l0
0004ooooo`;o00006_ooool4o`00037ooooo000Looooo`03o`000?oooooooooo03Cooooo0_l0000R
ooooo`Wo00003Oooool6o`000003ooooool0003o000001Oooooo0_l00006ooooo`;o00000oooool2
o`000004ooooool0003o0000o`00017ooooo0_l000001Ooooooo0000o`000?l0003ooooo02Ko0000
0_ooool2o`000003ooooool0003o000000;o00001?ooool2o`000003ooooool0003o000000Oooooo
0_l0000Jooooo`?o0000<_ooool001cooooo00?o0000ooooooooool0=?ooool2o`0002;ooooo2Ol0
000?ooooo`?o00006oooool2o`0000Kooooo0_l0000Fooooo`;o00000_ooool2o`0000;ooooo9_l0
00001Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`000?l000000_l00007ooooo`;o0000
8oooool3o`0003;ooooo000Looooo`03o`000?oooooooooo05Sooooo0ol00004ooooo`;o00003ooo
ool2o`0001kooooo0_l00008ooooo`;o00000oooool2o`0000gooooo0_l00004ooooo`;o000000?o
ooooo`000?l000008ol000001?oooooo0000o`000?l00004ooooo`;o00002_ooool2o`000004oooo
ool0003o0000o`0001kooooo0_l0000cooooo`007?ooool00ol0003oooooooooo`1Oooooo`?o0000
3Oooool3o`0001cooooo1?l00003ooooo`;o00000oooool2o`0000?ooooo0_l0000Cooooo`Go0000
0_oooolVo`000003ooooool0003o000000;o00002?ooool4o`000004ooooool0003o0000o`0001ko
oooo0_l0000cooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o00003Oooool2o`0001_ooooo
1?l00005ooooo`;o00002?ooool2o`00013ooooo0_l000000ooooooo0000o`000003o`000003oooo
ool0003o000000;o00000_oooolQo`000003ooooool0003o000000;o000000?oooooo`000?l00000
1Oooool2o`0000;ooooo0ol0001Dooooo`007?ooool00ol0003oooooooooo`0dooooo`;o0000E_oo
ool2o`0001oooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo;?l000001?oooooo0000
o`000?ooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool4o`0001_ooooo0_l000000ooo
oooo0000o`00000dooooo`007?ooool00ol0003oooooooooo`0dooooo`;o00009Oooool3o`0000oo
oooo0_l00007ooooo`;o00004oooool4o`0001kooooo0_l00003ooooo`;o00001?ooool5o`000003
ooooool0003o000001_o000000?oooooo`000?l000000_ooool5o`0000Kooooo0_l00004ooooo`Co
00006oooool2o`000003ooooool0003o000003Cooooo000Looooo`03o`000?oooooooooo05_ooooo
1Ol0000=ooooo`;o00001oooool2o`0001?ooooo1?l0000;ooooo`;o00005_ooool5o`000004oooo
ool0003o0000o`0000Wooooo0ol000000ooooooo0000o`000006o`000004ooooool0003o0000oooo
o`Wo000000Coooooo`000?l0003ooooo1?l00003ooooo`So00000oooool2o`0005Cooooo000Loooo
o`03o`000?oooooooooo03?ooooo0_l0000Yooooo`;o00001?ooool2o`0000Oooooo0_l00002oooo
o`;o00008oooool2o`0000;ooooo1?l00002ooooo`;o00004?ooool5o`0000?ooooo0ol00007oooo
o`;o00000_ooool2o`0000;ooooo1?l000001?oooooo0000o`000?ooool2o`000003ooooool0003o
000000Oo000000?oooooo`000?l000003_l0000Nooooo`Go0000=Oooool001cooooo00?o0000oooo
ooooool0<oooool2o`0002Cooooo1?l00003ooooo`?o000000?oooooo`000?l000002oooool2o`00
01cooooo0_l00005ooooo`;o00000_ooool4o`0000;ooooo0_l0000Eooooo`;o000000Coooooo`00
0?l0003o00000ooooolJo`000003ooooool0003o000001Co00007_ooool5o`0003Gooooo000Loooo
o`;o0000F_ooool5o`0000;ooooo1?l00009ooooo`?o00003_ooool2o`000003ooooool0003o0000
00cooooo0_l000000ooooooo0000o`000006ooooo`;o00005_ooool2o`0000?ooooo0_l00005oooo
oc?o00007_ooool3o`0003Oooooo000Looooo`03o`000?oooooooooo037ooooo0_l0000Vooooo`Go
00000_ooool6o`0000Cooooo0_l000000ooooooo0000o`000003o`0000cooooo0_l000000ooooooo
0000o`00000?ooooo`;o00001_ooool2o`0001Kooooo0_l0000:oooooc;o00007?ooool2o`000004
ooooool0003o0000o`0003Oooooo000Looooo`03o`000?oooooooooo037ooooo0_l0000Vooooo`Oo
000000?oooooo`000?l000000ol00004ooooo`Go000000?oooooo`000?l000000_l0000Oooooo`;o
0000:_ooool2o`000003ooooool0003o000000;o00001ooooolQo`0001kooooo0_l000001?oooooo
0000o`000?l0000gooooo`007?ooool00ol0003oooooooooo`1Iooooo`Oo000000?oooooo`000?l0
00000_l00004ooooo`Co00000_ooool2o`000003ooooool0003o000001gooooo1?l0000]ooooo`;o
00003?oooolNo`0001kooooo1?l0000iooooo`007?ooool00ol0003oooooooooo`1Jooooo`Co0000
1?ooool5o`0000;ooooo0ol00003ooooo`;o00005?ooool2o`0000Gooooo0_l00003ooooo`;o0000
1oooool2o`0001Oooooo0_l0000PoooooaCo00008?ooool2o`0000?ooooo1?l0000gooooo`007?oo
ool00ol0003oooooooooo`0aooooo`;o00009oooool3o`0000Sooooo1?l0000Fooooo`;o000000Co
ooooo`000?l0003ooooo0_l00005ooooo`;o00001?ooool2o`0000Kooooo0_l0000:ooooo`Ko0000
1oooool2o`0002;ooooo0_l00002ooooo`?o000000?oooooo`000?l000000_ooool3o`0002?ooooo
0ol00004ooooo`;o0000=oooool001cooooo00?o0000ooooooooool0<Oooool2o`0002Sooooo0_l0
0005ooooo`;o00000_ooool3o`0001Kooooo1Ol00008ooooo`;o00001?ooool2o`0000cooooo0_l0
0004ooooo`Ko000000?oooooo`000?l00000=?ooool2o`0002Cooooo0ol00005ooooo`;o0000=_oo
ool001cooooo00?o0000ooooooooool0<Oooool2o`0002oooooo0_l00003ooooo`;o00002oooool2
o`000003ooooool0003o000000Sooooo0_l00009ooooo`;o00001Oooool2o`0000_ooooo0_l00004
ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0005Wooooo0ol00006ooooo`;o000000?o
ooooo`000?l00000<oooool001cooooo00?o0000ooooooooool0;oooool4o`0002oooooo0_l00000
0ooooooo0000o`000002o`000003ooooool0003o000000Sooooo0_l000000ooooooo0000o`000002
ooooo`;o00001?ooool2o`000003ooooool0003o000000Wooooo1_l00006ooooo`?o00001_ooool2
o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`0005Gooooo0_l00007ooooo`;o000000?ooooo
o`000?l00000<oooool001cooooo00?o0000ooooooooool0;oooool2o`0002gooooo0_l00002oooo
o`;o000000?oooooo`000?l000000_l000000ooooooo0000o`00000=ooooo`Co00000_ooool4o`00
0003ooooool0003o000000Wooooo1?l00008ooooo`?o00001_ooool4o`0000?ooooo1?l00002oooo
o`;o0000Goooool2o`000003ooooool0003o000003;ooooo000Looooo`03o`000?oooooooooo05ko
oooo1?l00005ooooo`;o00004?ooool4o`0000;ooooo0_l00009ooooo`Co000000?oooooo`000?l0
00004oooool4o`0000;ooooo1Ol00002ooooo`;o0000Goooool2o`000003ooooool0003o000003;o
oooo000Looooo`03o`000?oooooooooo02oooooo0_l0000]ooooo`Co0000:?ooool4o`000003oooo
ool0003o000000;ooooo1?l00004ooooo`;o00001oooool2o`0000Cooooo1Ol00002ooooo`;o0000
F?ooool2o`0000Kooooo1?l0000booooo`007?ooool00ol0003oooooooooo`0_ooooo`;o0000:_oo
ool6o`0000Sooooo1Ol0000Mooooo`;o00001_ooool5o`000003ooooool0003o000000co00001Ooo
ool2o`0000?ooooo0_l0001Dooooo`;o00000_ooool2o`0000Kooooo1?l0000booooo`007?ooool0
0ol0003oooooooooo`1Jooooo`Oo000000?oooooo`000?l000001Oooool7o`0000_ooooo0_l0000<
ooooo`Co00002?ooool3o`000003ooooool0003o000000ko00002?ooool2o`0005Cooooo0_l00010
ooooo`007?ooool00ol0003oooooooooo`1Hooooo`Ko00001?ooool2o`0000Sooooo1?l000001?oo
oooo0000o`000?ooool2o`0000Gooooo0_l00007ooooo`;o00000oooool4o`0000Oooooo0_l00002
ooooo`Go000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000?ooooo0_l0002K
ooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00009Oooool2o`0000Cooooo0_l00004oooo
o`;o00001_ooool4o`000004ooooool0003o0000ooooo`;o00003_ooool2o`0000kooooo2Ol00000
0ooooooo0000o`000004o`0000Sooooo0_l0001Gooooo`;o0000@_ooool001cooooo0_l0000boooo
o`;o00009?ooool2o`0000Gooooo0_l00004ooooo`;o00001?ooool2o`0001;ooooo0_l0000Foooo
o`Oo000000?oooooo`000?l000001?l000000ooooooo0000o`000005ooooo`;o0000Eoooool2o`00
0003ooooool0003o000003oooooo000Looooo`03o`000?oooooooooo05Gooooo1?l0000=ooooo`;o
00000_ooool2o`0000Kooooo0_l00007ooooo`;o000000?oooooo`000?l000003Oooool2o`0000Oo
oooo0ol00005ooooo`;o000000?oooooo`000?l000001_l0001Looooo`;o000000?oooooo`000?l0
00002Oooool2o`0003Cooooo000Looooo`03o`000?oooooooooo05Cooooo0ol00008ooooo`?o0000
1?ooool2o`0000[ooooo0_l00007ooooo`;o000000?oooooo`000?l000002oooool4o`0000Oooooo
0_l00003ooooo`_o000000?oooooo`000?l000000_l00004ooooo`;o0000E?ooool2o`0000cooooo
0_l0000dooooo`007?ooool00ol0003oooooooooo`1Cooooo`?o00001?ooool3o`0000;ooooo0ol0
000Booooo`Go00001Oooool2o`000003ooooool0003o000000Sooooo0ol0000=oooooa7o00000ooo
ool2o`0005Cooooo1?l0000:ooooo`;o0000=?ooool001cooooo00?o0000ooooooooool0=?ooool2
o`0001cooooo0ol00005ooooo`Oo00004oooool6o`0000Oooooo0_l0000Ioooooa3o00001?ooool2
o`0001oooooo0_l0000dooooo`;o00001Oooool2o`000003ooooool0003o000003Kooooo000Loooo
o`03o`000?oooooooooo03;ooooo1?l0000Looooo`?o00000_ooool2o`000004ooooool0003o0000
ooooo`Go000000?oooooo`000?l000001?l0000?ooooo`?o00003_ooool2o`0000[ooooo0_l00004
oooooa;o000000?oooooo`000?l000000_l0000Looooo`;o000000?oooooo`000?l000000_ooool2
o`0000Kooooo0_l0000Tooooo`;o000000?oooooo`000?l000001_ooool2o`000003ooooool0003o
000003Kooooo000Looooo`03o`000?oooooooooo03;ooooo0_l0000Nooooo`?o00000_oooolBo`00
00;ooooo0_l0000<ooooo`;o00001?ooool2o`0000Sooooo0_l0000:ooooo`?o00000ooooolGo`00
01cooooo1?l00003ooooo`;o00001_ooool2o`0002Cooooo0_l000000ooooooo0000o`000005oooo
o`;o0000>_ooool001cooooo00?o0000ooooooooool0<Oooool5o`0001[ooooo0_l00005ooooo`ko
00000_ooool6o`0000oooooo0_l000000ooooooo0000o`000003ooooo`;o00003oooool3o`0000;o
oooo6?l0000Looooo`Co0000>oooool3o`0003Wooooo000Looooo`03o`000?oooooooooo037ooooo
1Ol0000Jooooo`;o00001?oooolEo`0000;ooooo0_l0000=ooooo`;o00001_ooool2o`0000kooooo
0ol000000ooooooo0000o`00000Ho`0005Sooooo0_l00002ooooo`;o0000>Oooool001cooooo00?o
0000ooooooooool0=_ooool2o`0001kooooo0ol00002oooooa3o00000_ooool2o`0000gooooo0_l0
000Foooooako00009_ooool2o`0000?ooooo0_l00002ooooo`;o00008oooool2o`0000;ooooo0_l0
000mooooo`007?ooool00ol0003oooooooooo`0fooooo`?o00007Oooool4o`0000;ooooo3ol00003
ooooo`;o00002_ooool4o`0001Wooooo6Ol0000Xooooo`;o00000oooool2o`0000;ooooo0_l0000S
ooooo`Co0000?oooool001cooooo00?o0000ooooooooool0=oooool2o`0001Gooooo0_l00005oooo
o`So000000Goooooo`000?l0003o0000ooooo`09o`0000?ooooo0_l0000:ooooo`;o000000?ooooo
o`000?l000005Oooool2o`000003ooooool0003o000001Go000000?oooooo`000?l00000;?ooool2
o`0002Gooooo0_l000000ooooooo0000o`000003o`0003gooooo000Looooo`03o`000?oooooooooo
03Sooooo0_l0000Dooooo`;o00001OoooolEo`0000;ooooo0ol0000>ooooo`;o00005OoooolMo`00
02cooooo0_l000001?oooooo0000o`000?ooool4o`0001gooooo0_l00003ooooo`Co0000??ooool0
01cooooo00?o0000ooooooooool0>?ooool2o`0001Cooooo1?l00003oooooa[o00000oooool2o`00
00Wooooo0_l0000Eoooooa_o0000;_ooool2o`000004ooooool0003o0000ooooo`Co00008?ooool6
o`0000?ooooo0_l0000gooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?oo
ool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0COooool2o`000004oooo
ool0003o0000oooooaco00000oooool4o`0001oooooo0_l00002oooooaCo00001?ooool2o`0002[o
oooo1?l00002ooooo`Co00008?ooool8o`000003ooooool0003o000003Oooooo00001_ooooooMgMg
oiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool0
0ol0003oooooooooo`0fooooo`;o000000?oooooo`000?l000004Oooool3o`0000Cooooo7?l00003
ooooo`Co00007_ooool2o`0000?ooooo5?l00004ooooo`;o0000:oooool3o`0000;ooooo0_l0000V
ooooo`Co0000>_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0=_ooool2o`000003ooooool0003o
0000017ooooo0_l000000ooooooo0000o`000002ooooobGo00000oooool2o`0001Oooooo0_l00002
oooooaGo0000<Oooool2o`0000Cooooo0_l0001Sooooo`0000?oooooo`000?ooool00_ooool00ol0
003oooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0003Gooooo0_l00002
ooooo`;o00005?ooool2o`0000?ooooo7_l00002ooooo`Co00000oooool2o`000003ooooool0003o
000001Cooooo0_l00002oooooaGo000000?oooooo`000?l000000_l0000Uooooo`;o00002oooool2
o`0002Gooooo0_l0000looooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09oooo
o`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0eooooo`Ko00004Oooool4
o`0000Cooooo7Ol000001?oooooo0000o`000?ooool2o`000004ooooool0003o0000ooooo`;o0000
00?oooooo`000?l000005?ooool2o`0000;ooooo0ol000000ooooooo0000o`00000>o`0000;ooooo
1?l0000Nooooo`Co000000?oooooo`000?l000000ol00009ooooo`?o00006_ooool2o`0000Wooooo
0_l0000looooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`03oeEEEOn7
QhOooooo00Sooooo00?o0000ooooooooool0=oooool2o`0001?ooooo1?l000000ooooooo0000o`00
0003oooooako000000Coooooo`000?l0003ooooo0_l0000Nooooo`Ko000000?oooooo`000?l00000
2_l0000Uooooo`Co000000?oooooo`000?l000000ol00002ooooo`;o00001Oooool2o`0001_ooooo
0_l0000:ooooo`;o0000>oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo
410@oiRHV008ooooo`03o`000?oooooooooo03_ooooo0_l0000Dooooo`;o00001OoooolJo`0000?o
oooo0_l00002ooooo`Co00006Oooool8o`000003ooooool0003o000000co00001?ooool2o`0002?o
oooo1?l00002ooooo`;o00001?ooool2o`0001cooooo1?l00008ooooo`;o0000>oooool00006oooo
ooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooo
oooo03_ooooo0_l0000Dooooob7o000000?oooooo`000?l000000_l00002ooooo`Co00006Oooool8
o`000003ooooool0003o000000co00001?ooool2o`0002Gooooo1?l00004ooooo`Co00007?ooool4
o`000003ooooool0003o000004;ooooo000Looooo`03o`000?oooooooooo057ooooo9?l0000Uoooo
o`Oo000000?oooooo`000?l000001_l000000ooooooo0000o`000002o`0002[ooooo0ol00003oooo
o`?o00006oooool2o`0000Kooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`1Aooooob;o
0000:Oooool>o`0000?ooooo0_l000000ooooooo0000o`00000Wooooo`?o00000oooool2o`0001co
oooo1?l00003ooooo`?o0000@_ooool001cooooo00?o0000ooooooooool0B_ooool2o`0000Gooooo
1?l00002ooooo`ko000000?oooooo`000?l000002Ol00003ooooo`?o0000:Oooool4o`000003oooo
ool0003o000000?o00001_ooool2o`00013ooooo0_l00003ooooo`;o00004_ooool2o`0000Gooooo
0_l0000Hooooo`Go00000oooool3o`000003ooooool0003o000003oooooo000Looooo`03o`000?oo
oooooooo04[ooooo0_l00005ooooo`?o00000ooooolAo`000003ooooool0003o000000Ko00000_oo
ool4o`0002Oooooo0_l00002ooooo`;o00002oooool3o`00013ooooo0_l00003ooooo`;o00004?oo
ool4o`0000;ooooo0_l000000ooooooo0000o`00000Hooooo`;o00002?ooool4o`0003oooooo000L
ooooo`03o`000?oooooooooo04[ooooo0_l00006ooooo`;o00001?ooool8o`000003ooooool0003o
000001Co00009oooool2o`0000oooooo0_l0000Xooooo`Co00000_ooool2o`0002Gooooo0_l00011
ooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o00003?oooolNo`0003[ooooo0_l0000Toooo
o`Ko0000;?ooool2o`0003oooooo000Looooo`03o`000?oooooooooo04[ooooo0_l0000?ooooo`go
00000oooool:o`0003_ooooo1?l0000Qooooo`Oo0000;?ooool2o`0003oooooo000Looooo`03o`00
0?oooooooooo04Wooooo0ol0000@ooooo`;o00000_ooool:o`000003ooooool0003o000000Co0000
?_ooool7o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`Go00003oooool9o`0001cooooo
0_l0000;ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0BOooool3o`0001Gooooo2ol0
0002ooooo`;o0000?oooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`000004ooooool0
003o0000o`0000;ooooo1Ol0000?ooooo`Co00000_ooool3o`000003ooooool0003o000001Wooooo
0_l00006ooooo`;o00000oooool2o`00043ooooo000Looooo`03o`000?oooooooooo04[ooooo0_l0
000Looooo`Co0000??ooool2o`0000Oooooo0_l00004ooooo`;o00001?ooool2o`0000Cooooo1_l0
000;ooooo`Go00000_ooool2o`0000;ooooo0_l0000Qooooo`;o0000AOooool001cooooo00?o0000
ooooooooool0C_ooool2o`0004oooooo0_l00007ooooo`;o00001oooool2o`0001;ooooo1_l00009
ooooo`;o000000?oooooo`000?l000000oooool3o`00027ooooo0_l00017ooooo`007?ooool2o`00
04_ooooo0_l00002ooooo`;o0000Coooool3o`0000Gooooo0ol00004ooooo`;o00000oooool2o`00
00Cooooo0_l0000<ooooo`Co00002?ooool6o`000003ooooool0003o000000?o00008Oooool2o`00
04Oooooo000Looooo`03o`000?oooooooooo04[ooooo0_l00002ooooo`;o0000Boooool2o`0000;o
oooo0ol00005ooooo`;o00001Oooool2o`0000?ooooo0_l00003ooooo`Oo00002Oooool3o`0000So
oooo1?l00003ooooo`?o0000K?ooool001cooooo00?o0000ooooooooool0C_ooool2o`0004_ooooo
0_l00002ooooo`?o00000_ooool2o`0000kooooo0_l00002ooooo`;o000000?oooooo`000?l00000
0_l00009ooooo`Co00001oooool3o`0000;ooooo0ol0000Xooooo`;o0000A?ooool001cooooo00?o
0000ooooooooool0VOooool2o`0000;ooooo1_l000000ooooooo0000o`00000>ooooo`;o00001ooo
ool2o`0000Wooooo1?l00007ooooo`;o00000oooool3o`00027ooooo0_l00003ooooo`Co0000A?oo
ool001cooooo00?o0000ooooooooool0Boooool3o`0004_ooooo3?l00003ooooo`Co00002?ooool2
o`0000Oooooo0_l00007ooooo`Go00001oooool2o`0000;ooooo0_l0000Tooooo`;o00000oooool3
o`0004Gooooo000Looooo`03o`000?oooooooooo04_ooooo0ol00003ooooo`;o0000Aoooool;o`00
00?ooooo1?l00008ooooo`;o000000?oooooo`000?l000001?ooool3o`0000Cooooo2Ol00005oooo
o`;o00000_ooool2o`00077ooooo000Looooo`03o`000?oooooooooo057ooooo0_l00008ooooo`;o
0000??ooool<o`0000;ooooo0ol0000:ooooo`;o000000?oooooo`000?l000001?ooool3o`0000?o
oooo2_l00008ooooo`?o0000LOooool001cooooo00?o0000ooooooooool0C?ooool2o`0000gooooo
0_l0000kooooo`go00000_ooool2o`000003ooooool0003o000000Kooooo0_l00003ooooo`;o0000
1?ooool2o`0000?ooooo2_l00004ooooo`;o000000?oooooo`000?l000000_l0001booooo`007?oo
ool00ol0003oooooooooo`1<ooooo`;o00002?ooool2o`0003oooooo3ol00004ooooo`;o00001_oo
ool2o`0000?ooooo0_l00004ooooo`;o00000oooool:o`0000Cooooo0_l000000ooooooo0000o`00
000Rooooo`;o00000_ooool2o`000004ooooool0003o0000o`0004Sooooo000Looooo`03o`000?oo
oooooooo04cooooo0_l00008ooooo`;o0000?oooool@o`000003ooooool0003o000000Sooooo0_l0
0008ooooo`?o00000oooool4o`0000;ooooo1?l00002ooooo`?o00000_ooool2o`0002;ooooo0_l0
00001Ooooooo0000o`000?l0003ooooo00?o0000B?ooool001cooooo00?o0000ooooooooool0C?oo
ool2o`0004Sooooo5?l00005ooooo`Go00002?ooool2o`0000Cooooo1?l00003ooooo`co00009Ooo
ool2o`0000;ooooo0_l00019ooooo`007?ooool00ol0003oooooooooo`1<ooooo`?o0000Aoooool8
o`000003ooooool0003o000000Oo00001Oooool6o`0000oooooo1_l000000ooooooo0000o`000009
o`0007Gooooo000Looooo`03o`000?oooooooooo04cooooo0ol00016oooooaCo00001?ooool2o`00
00;ooooo0_l00003ooooo`;o00001Oooool2o`0000?ooooo1_l000001?oooooo0000o`000?l0000Z
ooooo`;o00001?ooool2o`0004_ooooo000Looooo`03o`000?oooooooooo04gooooo0_l00016oooo
oaCo00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000003o`0000Cooooo0_l00003oooo
o`Ko000000?oooooo`000?l000000_ooool4o`0002?ooooo1?l00004ooooo`;o0000Boooool001co
oooo00?o0000ooooooooool0COooool2o`0004Cooooo5_l000001?oooooo0000o`000?ooool2o`00
00;ooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo1?l00004ooooo`Ko000000?ooooo
o`000?l000001Ol0000Pooooo`;o000000?oooooo`000?l00000Doooool001cooooo00?o0000oooo
ooooool0COooool3o`0004?ooooo5_l000000ooooooo0000o`000004ooooo`?o000000Coooooo`00
0?l0003ooooo2?l00005ooooo`[o00008oooool2o`0000;ooooo1?l0001@ooooo`007?ooool2o`00
04oooooo0_l000000ooooooo0000o`000010oooooaGo00000_ooool3o`0000?ooooo0ol000000ooo
oooo0000o`000009o`0000[ooooo0_l0000Tooooo`;o00001?ooool4o`00053ooooo000Looooo`03
o`000?oooooooooo04kooooo0_l000000ooooooo0000o`000011oooooa?o000000Coooooo`000?l0
003ooooo1?l00007ooooo`;o00001Oooool3o`0002oooooo0_l00004ooooo`;o0000D_ooool001co
oooo00?o0000ooooooooool0U?oooolCo`000003ooooool0003o000000?ooooo0ol00002ooooo`;o
00002Oooool3o`0002oooooo1?l00002ooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0
TooooolDo`0000Oooooo0_l00002ooooo`;o0000:_ooool2o`0000oooooo1Ol000000ooooooo0000
o`00001Booooo`007?ooool00ol0003oooooooooo`2Booooo`?o000000?oooooo`000?l000003ol0
00000ooooooo0000o`00000Eooooo`?o00005oooool2o`000003ooooool0003o000000;o00004Ooo
ool3o`000003ooooool0003o000005;ooooo000Looooo`03o`000?oooooooooo057ooooo1?l0000m
oooooaCo00000_ooool2o`0000Oooooo0_l00006ooooo`Go000000?oooooo`000?l000001?l0000D
ooooo`Go00003_ooool2o`0000;ooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`1Aoooo
o`Co0000?ooooolAo`0000;ooooo0ol00004ooooo`;o000000Coooooo`000?l0003o00001?ooool6
o`0000Cooooo1?l0000=ooooo`;o00001Oooool2o`0000kooooo1?l00002ooooo`;o0000Eoooool0
01cooooo00?o0000ooooooooool0Eoooool2o`0003cooooo0_l000000ooooooo0000o`00000;o`00
0003ooooool0003o000000?o00000oooool2o`000004ooooool0003o0000o`0000Cooooo0ol00007
ooooo`Co00002?ooool2o`0000?ooooo0_l00005ooooo`;o00002oooool2o`000003ooooool0003o
000005gooooo000Looooo`03o`000?oooooooooo05Oooooo0_l0000kooooo`?o00000_ooool;o`00
0005ooooool0003o0000o`000?ooool00_l00007ooooo`;o00001Oooool2o`0001?ooooo0_l00000
0ooooooo0000o`000004ooooo`?o00003Oooool2o`00063ooooo000Looooo`03o`000?oooooooooo
05Gooooo0_l00002ooooo`;o0000>Oooool3o`0000Cooooo2Ol000000ooooooo0000o`000004oooo
o`;o00001Oooool3o`0001cooooo0_l00003ooooo`Go00003_ooool2o`0005kooooo000Looooo`03
o`000?oooooooooo05Gooooo0ol000000ooooooo0000o`00000jooooo`Co00000_ooool:o`0000;o
oooo0_l00002ooooo`;o00001?ooool4o`0000Kooooo0ol0000<ooooo`?o00000_ooool2o`0000?o
oooo1ol0000>ooooo`;o000000?oooooo`000?l00000Foooool001cooooo00?o0000ooooooooool0
E_ooool3o`0000?ooooo0_l0000iooooo`;o00001?ooool4o`0000;ooooo0_l00002ooooo`;o0000
00?oooooo`000?l000000_l00003ooooo`Go00001Oooool5o`0000[ooooo0ol00002ooooo`Oo0000
3_ooool2o`0000Kooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`1Gooooo`;o00000ooo
ool4o`0003Cooooo0ol0000>ooooo`;o00000oooool4o`0000Cooooo1?l00008ooooo`;o00001_oo
ool2o`0000Gooooo2Ol0000=ooooo`Go0000HOooool001cooooo00?o0000ooooooooool0G?ooool4
o`0003Cooooo0ol0000>ooooo`;o00000_ooool2o`0000Sooooo1Ol00005ooooo`;o00001oooool2
o`0000Gooooo2?l00009ooooo`;o00000oooool2o`000003ooooool0003o0000067ooooo000Loooo
o`03o`000?oooooooooo05cooooo0_l0000fooooo`;o00002_ooool2o`0000?ooooo0_l00002oooo
o`;o00002?ooool8o`0000;ooooo0_l0000;ooooo`Oo00003Oooool2o`0000Cooooo0_l000000ooo
oooo0000o`00001Pooooo`007?ooool00ol0003oooooooooo`2Dooooo`;o00000_ooool2o`0000Ko
oooo0_l00003ooooo`;o00003Oooool:o`0000Oooooo2Ol0000Dooooo`Co000000?oooooo`000?l0
0000H?ooool001cooooo0_l0001Mooooo`;o0000>_ooool2o`0000Oooooo0_l0000Booooo`Wo0000
1?ooool:o`0001Kooooo0_l0001Uooooo`007?ooool00ol0003oooooooooo`1Looooo`;o0000>_oo
ool2o`0000Oooooo0_l0000Booooo`;o00000_ooool6o`000003ooooool0003o000000Oo000000?o
ooooo`000?l000004Oooool3o`0006Wooooo000Looooo`03o`000?oooooooooo063ooooo0_l00003
ooooo`;o0000>_ooool2o`000003ooooool0003o000001;ooooo3ol0000Booooo`;o00000_ooool3
o`0000;ooooo0_l0001Uooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o00000oooool2o`00
03;ooooo0_l00006ooooo`;o000000?oooooo`000?l000004_ooool2o`0000;ooooo1ol00002oooo
o`;o00004_ooool6o`0000?ooooo0_l0001Uooooo`007?ooool00ol0003oooooooooo`1Zooooo`;o
000000Coooooo`000?l0003o0000:Oooool2o`0000Wooooo0_l0000/ooooo`;o00001?ooool2o`00
0003ooooool0003o000000;o00000_ooool2o`0006Kooooo000Looooo`03o`000?oooooooooo06[o
oooo0_l000001?oooooo0000o`000?l0000[ooooo`;o00001oooool2o`0002cooooo0_l00004oooo
o`;o00001oooool2o`0006Kooooo000Looooo`03o`000?oooooooooo06Gooooo0_l0000<ooooo`?o
00009Oooool2o`0001Gooooo0_l0002Eooooo`007?ooool00ol0003oooooooooo`1Uooooo`?o0000
2oooool3o`0003cooooo0_l00002ooooo`;o0000TOooool001cooooo00?o0000ooooooooool0I_oo
ool4o`0000Gooooo0_l00007ooooo`;o00000oooool2o`0003Oooooo0_l00006ooooo`;o00000_oo
ool2o`0000Cooooo0_l00002ooooo`;o0000Noooool001cooooo00?o0000ooooooooool0J?ooool5
o`0000;ooooo0_l00007ooooo`;o00000oooool3o`0000cooooo0_l0000Pooooo`;o00003_ooool2
o`0000;ooooo0_l00004ooooo`;o00000_ooool6o`0007Oooooo000Looooo`03o`000?oooooooooo
06Wooooo1?l00006ooooo`;o00000oooool2o`0000Cooooo0_l00003ooooo`;o00001oooool2o`00
01[ooooo0_l00004ooooo`Co00000_ooool2o`0000Oooooo0ol0000=ooooo`Go00001_ooool2o`00
06oooooo000Looooo`03o`000?oooooooooo06_ooooo0ol00005ooooo`;o00000oooool2o`0000So
oooo1?l0000Oooooo`;o000000?oooooo`000?l000001_ooool2o`0000;ooooo0_l00007ooooo`?o
00001?ooool2o`0000?ooooo0_l00007ooooo`;o000000Coooooo`000?l0003ooooo0_l0001_oooo
o`007?ooool00ol0003oooooooooo`1/ooooo`;o000000Coooooo`000?l0003ooooo0_l00004oooo
o`;o00001oooool5o`0000cooooo0_l0000Aooooo`;o00001_ooool2o`0000;ooooo0_l00008oooo
o`;o00001oooool2o`0000?ooooo0_l00004ooooo`Go000000?oooooo`000?l00000L_ooool001co
oooo00?o0000ooooooooool0Koooool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`?o
000000Coooooo`000?l0003o00003oooool3o`0001Sooooo0_l00002ooooo`;o00002?ooool2o`00
01;ooooo1Ol000000ooooooo0000o`00001booooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5
ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0L_oo
ool2o`0000Sooooo1_l00003ooooo`;o00000_ooool2o`0000Oooooo1?l00009ooooo`;o00002_oo
ool2o`0009cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q
8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1nooooo`;o00001Oooool2o`0000;o
oooo0_l00005ooooo`;o000000Coooooo`000?l0003o00002Oooool2o`0000[ooooo0ol0000Boooo
o`;o00001_ooool4o`0007gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wo
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo07Wooooo0_l00007oooo
o`;o00000oooool2o`0000Oooooo0_l0000Jooooo`;o00000oooool2o`0000gooooo0_l00006oooo
o`Co0000OOooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Olb<S;o
V9RHoooooonHV9So<S8b00Kooooo0ol0001iooooo`;o00001?ooool2o`000003ooooool0003o0000
00?ooooo0_l0000Cooooo`;o00001Oooool2o`0000cooooo0_l00002ooooo`Co00000_ooool3o`00
00?ooooo0_l00026ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05
olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`1oooooo`?o00000oooool2o`00
00Kooooo0_l0000=ooooo`;o00001Oooool2o`00013ooooo1?l00002ooooo`?o00000oooool2o`00
08Kooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go410@okZj^_oo
oooo^[Zjoa0@4006ooooo`03o`000?oooooooooo07oooooo0ol00003ooooo`;o00001?ooool5o`00
00cooooo0_l0000Mooooo`;o0000S?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool0
1Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0Poooool4o`000004ooooool0
003o0000ooooo`;o000000?oooooo`000?l000003?ooool2o`000:_ooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo
08?ooooo0ol00002ooooo`;o00002_ooool2o`0000Oooooo0_l0000;ooooo`;o0000WOooool001co
oooo00?o0000ooooooooool0Q?ooool2o`000003ooooool0003o000000Cooooo0_l00005ooooo`Co
00001Oooool2o`000003ooooool0003o000000Sooooo0_l0002Mooooo`007?ooool00ol0003ooooo
ooooo`26ooooo`?o00001?ooool4o`0000?ooooo1?l00003ooooo`;o00000oooool2o`0000Kooooo
1?l0002Mooooo`007?ooool00ol0003oooooooooo`26ooooo`?o00000_ooool2o`0000;ooooo1ol0
0003ooooo`Go00001Oooool2o`0000?ooooo0_l00005ooooo`;o0000V?ooool001cooooo00?o0000
ooooooooool0Qoooool2o`000004ooooool0003o0000o`0000Cooooo1Ol000000ooooooo0000o`00
0005o`0000Gooooo0_l00003ooooo`;o00001Oooool2o`0009Sooooo000Looooo`03o`000?oooooo
oooo08[ooooo0_l00002ooooo`?o00000oooool2o`000003ooooool0003o000000?o00001oooool2
o`0000?ooooo0_l0002Oooooo`007?ooool00ol0003oooooooooo`2<ooooo`Oo000000?oooooo`00
0?l000000_ooool2o`0000Wooooo0_l00002ooooo`;o00004Oooool3o`0000Gooooo0_l00025oooo
o`007?ooool00ol0003oooooooooo`2<ooooo`;o00000_ooool3o`000003ooooool0003o000000;o
oooo0_l0000=ooooo`Oo00001?ooool2o`000003ooooool0003o000000?ooooo0ol00005ooooo`;o
0000QOooool001cooooo00?o0000ooooooooool0T?ooool2o`0000Kooooo0_l0000?ooooo`Ko0000
00?oooooo`000?l000001Ol00002ooooo`;o00001_ooool2o`0008Kooooo000Looooo`03o`000?oo
oooooooo097ooooo0_l00005ooooo`;o00003?ooool3o`0000;ooooo1?l000000ooooooo0000o`00
0002ooooo`?o00000_ooool2o`0000Kooooo0_l00026ooooo`007?ooool00ol0003oooooooooo`2A
ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000cooooo0ol0000<ooooo`;o0000T_oo
ool001cooooo00?o0000ooooooooool0U?ooool3o`000003ooooool0003o00000:oooooo000Loooo
o`;o0000X?ooool6o`000:Cooooo000Looooo`03o`000?oooooooooo09oooooo1ol0002Sooooo`00
7?ooool00ol0003oooooooooo`2Qooooo`;o000000?oooooo`000?l00000Xoooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?oo
ooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001;ooooo1?l000000ol@413oooooooooo`03ooooo`03
o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo0ol0003ooooood[ooooo000D
ooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBoooo
o`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?oooooo
D_ooool001;ooooo00?oEEEEofIVI_l00000oooooomDooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00YOooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo01Go
oooo1Ol00003ooooo`Go00000oooool5o`00093ooooo002Vooooo`05o`000?ooooooooooooooool0
00002Oooool6o`0000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OnHV9So8B4Qonk^k_ooooooA4A4093ooooo002Vooooo`05o`000?oooooo
ooooooooool000006Oooool00onHV9So8B4Qonk^kP05ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?o
V9RHob4Q8Oo^k^h0TOooool00:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00002ooo
ool00onHV9So8B4Qonk^kP05ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?oV9RHob4Q8Oo^k^h0T?oo
ool00:Kooooo00Go0000ohN7QoooooooZJVYo`00000Kooooo`03ogMgMomVIVKooooo00Gooooo00?o
MgMgofIVI_ooool01Oooool00omgMgOoIVIVooooo`2?ooooo`00YOooool00ol@413o0000ogMgM`02
o`000003oiRHV?oooooooooo01[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo08kooooo0033ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool0
1Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go0000okZj^_ooooooV9RHoa0@402@ooooo`00`ooo
ool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`0T?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(228) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.4763 .31917 Mdot
.51199 .32233 Mdot
.30586 .54283 Mdot
.6637 .50315 Mdot
.47193 .71542 Mdot
.32318 .58444 Mdot
.32002 .4057 Mdot
.31248 .39712 Mdot
.26622 .57741 Mdot
.73892 .42549 Mdot
.29401 .3962 Mdot
.68229 .4869 Mdot
.32772 .39501 Mdot
.64519 .48012 Mdot
.57294 .67372 Mdot
.62249 .50907 Mdot
.48261 .3422 Mdot
.463 .65547 Mdot
.62534 .51316 Mdot
.27119 .59766 Mdot
.45619 .57059 Mdot
.64153 .46544 Mdot
.54584 .2932 Mdot
.64245 .47813 Mdot
.66587 .53501 Mdot
.52395 .32014 Mdot
.477 .31888 Mdot
.68665 .5458 Mdot
.66751 .51004 Mdot
.30176 .42205 Mdot
.7174 .55053 Mdot
.6234 .75994 Mdot
.52546 .59344 Mdot
.68792 .34897 Mdot
.31748 .42679 Mdot
.28081 .41751 Mdot
.30801 .55725 Mdot
.3173 .42949 Mdot
.31072 .37371 Mdot
.3007 .39475 Mdot
.30025 .39988 Mdot
.52439 .32364 Mdot
.33816 .42647 Mdot
.17711 .44079 Mdot
.6342 .47811 Mdot
.66899 .2546 Mdot
.29868 .52641 Mdot
.67752 .48535 Mdot
.54786 .30029 Mdot
.26129 .56291 Mdot
.52607 .74741 Mdot
.3183 .3852 Mdot
.50122 .58376 Mdot
.60633 .1646 Mdot
.3183 .39647 Mdot
.64331 .5253 Mdot
.30326 .59936 Mdot
.61673 .47614 Mdot
.64794 .44119 Mdot
.66607 .31124 Mdot
.6251 .49027 Mdot
.45301 .68834 Mdot
.46372 .34934 Mdot
.26954 .54478 Mdot
.26679 .56819 Mdot
.33275 .42903 Mdot
.4774 .34835 Mdot
.33797 .41594 Mdot
.66937 .50222 Mdot
.27983 .6006 Mdot
.67092 .52368 Mdot
.29359 .39717 Mdot
.47955 .32467 Mdot
.64781 .46066 Mdot
.49089 .37736 Mdot
.29483 .44271 Mdot
.48515 .65576 Mdot
.5249 .27326 Mdot
.24929 .56696 Mdot
.5901 .6449 Mdot
.64453 .46102 Mdot
.26188 .29056 Mdot
.59648 .7186 Mdot
.51721 .29893 Mdot
.5954 .45811 Mdot
.34072 .2468 Mdot
.68249 .52901 Mdot
.71383 .54446 Mdot
.69587 .54602 Mdot
.52459 .64331 Mdot
.30623 .60284 Mdot
.54451 .31568 Mdot
.63367 .46292 Mdot
.67072 .48689 Mdot
.73628 .41146 Mdot
.65594 .51763 Mdot
.69046 .54303 Mdot
.51005 .55515 Mdot
.32113 .3796 Mdot
.51683 .57932 Mdot
.31668 .48912 Mdot
.51111 .59734 Mdot
.67444 .52646 Mdot
.31324 .58217 Mdot
.47524 .35706 Mdot
.5224 .59259 Mdot
.33073 .42068 Mdot
.63541 .46642 Mdot
.34392 .45573 Mdot
.54587 .29665 Mdot
.66371 .54088 Mdot
.4666 .69844 Mdot
.43815 .53646 Mdot
.4879 .31498 Mdot
.76476 .35127 Mdot
.66026 .49636 Mdot
.61842 .45467 Mdot
.51284 .32477 Mdot
.28512 .61279 Mdot
.23204 .38191 Mdot
.48953 .33499 Mdot
.31229 .38141 Mdot
.48499 .34574 Mdot
.5255 .57395 Mdot
.27546 .60476 Mdot
.48538 .59589 Mdot
.48887 .5544 Mdot
.58466 .76614 Mdot
.65494 .50709 Mdot
.46591 .58422 Mdot
.31318 .57498 Mdot
.49087 .33237 Mdot
.33663 .39241 Mdot
.61354 .439 Mdot
.52831 .30526 Mdot
.31503 .40518 Mdot
.47333 .66244 Mdot
.44869 .6655 Mdot
.50352 .30435 Mdot
.7585 .34129 Mdot
.36322 .40563 Mdot
.35347 .38878 Mdot
.52759 .74633 Mdot
.51416 .30025 Mdot
.46596 .6738 Mdot
.3318 .41556 Mdot
.27391 .71562 Mdot
.64643 .53125 Mdot
.54163 .76605 Mdot
.26423 .29318 Mdot
.52583 .74649 Mdot
.46362 .55513 Mdot
.46826 .68613 Mdot
.31454 .4052 Mdot
.65523 .45556 Mdot
.50768 .30946 Mdot
.52734 .308 Mdot
.67392 .51843 Mdot
.51708 .60154 Mdot
.64597 .49134 Mdot
.51693 .5715 Mdot
.48268 .55698 Mdot
.63348 .46795 Mdot
.66235 .23536 Mdot
.53163 .29798 Mdot
.59834 .45247 Mdot
.29987 .55784 Mdot
.48973 .62007 Mdot
.34352 .42215 Mdot
.60912 .44782 Mdot
.58856 .46548 Mdot
.68346 .48774 Mdot
.35273 .3837 Mdot
.42848 .28132 Mdot
.25036 .5584 Mdot
.3015 .38448 Mdot
.3128 .48475 Mdot
.2975 .57149 Mdot
.65447 .44702 Mdot
.47428 .69623 Mdot
.50193 .57088 Mdot
.65927 .46389 Mdot
.52288 .74749 Mdot
.64452 .4407 Mdot
.48549 .52094 Mdot
.5026 .52412 Mdot
.3028 .27522 Mdot
.4365 .27649 Mdot
.66685 .49356 Mdot
.58765 .48961 Mdot
.53936 .75696 Mdot
.29487 .33837 Mdot
.34031 .39464 Mdot
.31224 .61539 Mdot
.29474 .61738 Mdot
.28807 .46253 Mdot
.74663 .36167 Mdot
.77946 .46414 Mdot
.60413 .46363 Mdot
.50894 .59111 Mdot
.47054 .30598 Mdot
.46657 .68514 Mdot
.49098 .3168 Mdot
.25757 .29238 Mdot
.63748 .62931 Mdot
.7274 .55261 Mdot
.21774 .60301 Mdot
.26934 .55244 Mdot
.50674 .60119 Mdot
.47579 .67444 Mdot
.62688 .483 Mdot
.53655 .29349 Mdot
.53586 .75249 Mdot
.51003 .6091 Mdot
.77445 .7031 Mdot
.48543 .33655 Mdot
.64537 .66455 Mdot
.32053 .39778 Mdot
.28282 .58433 Mdot
.68107 .52896 Mdot
.65477 .47895 Mdot
.55108 .31442 Mdot
.65254 .4504 Mdot
.73535 .54728 Mdot
.65786 .53559 Mdot
.25745 .57374 Mdot
.32494 .496 Mdot
.31551 .3744 Mdot
.22704 .6095 Mdot
.48771 .31411 Mdot
.66625 .22029 Mdot
.3014 .58557 Mdot
.48384 .52929 Mdot
.29363 .40304 Mdot
.46706 .66199 Mdot
.30776 .58884 Mdot
.46707 .71647 Mdot
.63881 .43605 Mdot
.28776 .56485 Mdot
.45804 .69699 Mdot
.70792 .49248 Mdot
.52184 .59197 Mdot
.5228 .80447 Mdot
.32318 .41098 Mdot
.5332 .33418 Mdot
.65721 .46031 Mdot
.5049 .57981 Mdot
.50815 .61149 Mdot
.60669 .66949 Mdot
.48289 .56648 Mdot
.50495 .60758 Mdot
.55773 .65945 Mdot
.47119 .6557 Mdot
.41801 .23099 Mdot
.71271 .55149 Mdot
.48095 .34111 Mdot
.66841 .47953 Mdot
.31154 .47683 Mdot
.31514 .40808 Mdot
.62698 .48631 Mdot
.28903 .27981 Mdot
.33367 .41162 Mdot
.61569 .4634 Mdot
.29536 .38656 Mdot
.52493 .30136 Mdot
.65183 .63517 Mdot
.47564 .33245 Mdot
.6302 .46577 Mdot
.29342 .39029 Mdot
.31701 .6125 Mdot
.52448 .31822 Mdot
.63755 .46524 Mdot
.6351 .50191 Mdot
.50608 .58951 Mdot
.65303 .53363 Mdot
.27015 .36135 Mdot
.68246 .50246 Mdot
.32292 .55405 Mdot
.66075 .5154 Mdot
.43422 .68214 Mdot
.36744 .75698 Mdot
.50942 .30078 Mdot
.48231 .56922 Mdot
.30672 .59487 Mdot
.7255 .52253 Mdot
.65607 .65742 Mdot
.63705 .47871 Mdot
.48815 .59346 Mdot
.63238 .70708 Mdot
.34798 .38869 Mdot
.69531 .55109 Mdot
.54293 .59036 Mdot
.31043 .60071 Mdot
.50946 .59617 Mdot
.60009 .47389 Mdot
.53905 .28286 Mdot
.63184 .51676 Mdot
.28824 .57208 Mdot
.49019 .34286 Mdot
.65462 .52188 Mdot
.27205 .39964 Mdot
.48402 .60708 Mdot
.34452 .38159 Mdot
.70359 .54959 Mdot
.65719 .45006 Mdot
.27618 .59696 Mdot
.52741 .32325 Mdot
.31563 .3962 Mdot
.48393 .31705 Mdot
.52742 .7026 Mdot
.63907 .68035 Mdot
.48827 .36797 Mdot
.48306 .6655 Mdot
.31334 .76234 Mdot
.30714 .38243 Mdot
.50514 .56343 Mdot
.32992 .55519 Mdot
.53388 .27887 Mdot
.31456 .58719 Mdot
.7486 .33213 Mdot
.30422 .60197 Mdot
.62374 .5161 Mdot
.30772 .61243 Mdot
.78307 .44298 Mdot
.62152 .44337 Mdot
.2699 .56028 Mdot
.50898 .55408 Mdot
.61082 .45082 Mdot
.5296 .30606 Mdot
.64457 .75346 Mdot
.72272 .3617 Mdot
.74978 .36666 Mdot
.29961 .59669 Mdot
.74409 .32399 Mdot
.66463 .53996 Mdot
.69958 .54862 Mdot
.50806 .31261 Mdot
.50569 .5649 Mdot
.44142 .69374 Mdot
.4427 .70505 Mdot
.42673 .77545 Mdot
.68324 .6579 Mdot
.76849 .36103 Mdot
.52428 .30915 Mdot
.30386 .5068 Mdot
.49127 .37642 Mdot
.50899 .60893 Mdot
.31226 .39717 Mdot
.42178 .28831 Mdot
.6936 .52729 Mdot
.50605 .53351 Mdot
.73564 .54534 Mdot
.52859 .3353 Mdot
.49022 .36389 Mdot
.31443 .39686 Mdot
.7525 .36812 Mdot
.74099 .43071 Mdot
.64317 .49223 Mdot
.30895 .40567 Mdot
.50928 .61058 Mdot
.71046 .53519 Mdot
.58523 .77243 Mdot
.16149 .5403 Mdot
.63035 .47182 Mdot
.42518 .33913 Mdot
.65647 .46059 Mdot
.57499 .76636 Mdot
.62363 .47872 Mdot
.53148 .31905 Mdot
.67791 .55162 Mdot
.70628 .5318 Mdot
.22243 .65737 Mdot
.62969 .62904 Mdot
.47257 .71148 Mdot
.64537 .4768 Mdot
.65177 .49264 Mdot
.46019 .67095 Mdot
.53849 .32116 Mdot
.67651 .49603 Mdot
.42876 .22857 Mdot
.63535 .46149 Mdot
.34675 .41817 Mdot
.5897 .6909 Mdot
.62047 .75921 Mdot
.66623 .53915 Mdot
.53965 .28273 Mdot
.35168 .38663 Mdot
.3015 .4149 Mdot
.48675 .56842 Mdot
.3154 .40911 Mdot
.64631 .44992 Mdot
.59085 .69021 Mdot
.47728 .35037 Mdot
.51596 .59951 Mdot
.53208 .33056 Mdot
.35592 .59961 Mdot
.32357 .40898 Mdot
.49609 .59024 Mdot
.73415 .35246 Mdot
.33887 .40498 Mdot
.36829 .53536 Mdot
.67252 .54456 Mdot
.50775 .61095 Mdot
.48852 .30628 Mdot
.28348 .60294 Mdot
.49556 .605 Mdot
.31744 .39687 Mdot
.6357 .47919 Mdot
.64721 .52823 Mdot
.31449 .40933 Mdot
.53229 .25491 Mdot
.71721 .55195 Mdot
.63236 .45908 Mdot
.53501 .30511 Mdot
.49997 .33474 Mdot
.60214 .44941 Mdot
.66377 .46727 Mdot
.32445 .58757 Mdot
.48699 .59205 Mdot
.48662 .59305 Mdot
.48525 .55779 Mdot
.29108 .59286 Mdot
.28026 .73702 Mdot
.35417 .40076 Mdot
.62328 .75812 Mdot
.40584 .35091 Mdot
.50062 .57936 Mdot
.32646 .58073 Mdot
.65882 .48812 Mdot
.68264 .51816 Mdot
.28976 .39723 Mdot
.41461 .82292 Mdot
.69403 .51942 Mdot
.47874 .33534 Mdot
.30863 .39677 Mdot
.58584 .45069 Mdot
.29766 .47397 Mdot
.45185 .70474 Mdot
.76795 .35677 Mdot
.31051 .39286 Mdot
.53328 .34877 Mdot
.31095 .39177 Mdot
.65092 .49172 Mdot
.60038 .47255 Mdot
.52095 .33894 Mdot
.47745 .70976 Mdot
.67492 .51187 Mdot
.61777 .46597 Mdot
.27805 .51351 Mdot
.5005 .38084 Mdot
.4456 .71407 Mdot
.68029 .50047 Mdot
.51712 .5626 Mdot
.4827 .70803 Mdot
.63292 .45198 Mdot
.6654 .51743 Mdot
.46469 .57547 Mdot
.28988 .41768 Mdot
.4903 .68369 Mdot
.22682 .67083 Mdot
.48345 .33525 Mdot
.27603 .34961 Mdot
.4911 .60881 Mdot
.30521 .38397 Mdot
.74182 .53477 Mdot
.50051 .5976 Mdot
.39113 .33756 Mdot
.87947 .46573 Mdot
.49703 .60338 Mdot
.32853 .57501 Mdot
.73482 .40491 Mdot
.66798 .51592 Mdot
.6312 .45865 Mdot
.44145 .6899 Mdot
.50177 .32854 Mdot
.43554 .2778 Mdot
.30193 .38285 Mdot
.65803 .47411 Mdot
.49158 .30908 Mdot
.31383 .26526 Mdot
.50499 .59391 Mdot
.46721 .70648 Mdot
.48602 .67594 Mdot
.64258 .45342 Mdot
.65112 .68754 Mdot
.52606 .31618 Mdot
.63743 .46544 Mdot
.62396 .44934 Mdot
.32541 .60562 Mdot
.51826 .29701 Mdot
.29019 .56495 Mdot
.7024 .55379 Mdot
.7935 .42777 Mdot
.31641 .48093 Mdot
.32989 .41324 Mdot
.48544 .57927 Mdot
.31829 .3736 Mdot
.29883 .53091 Mdot
.48632 .5913 Mdot
.63839 .46627 Mdot
.47786 .35149 Mdot
.63652 .465 Mdot
.63472 .46168 Mdot
.63272 .48052 Mdot
.76997 .36101 Mdot
.24882 .56328 Mdot
.47267 .70259 Mdot
.67302 .4712 Mdot
.2868 .57947 Mdot
.28923 .47374 Mdot
.73723 .42104 Mdot
.6486 .47465 Mdot
.6177 .45636 Mdot
.51416 .28856 Mdot
.64284 .52955 Mdot
.33555 .40537 Mdot
.52552 .33758 Mdot
.67262 .52847 Mdot
.24491 .5538 Mdot
.67631 .49144 Mdot
.48608 .36613 Mdot
.34888 .40922 Mdot
.64152 .39979 Mdot
.50962 .6153 Mdot
.48358 .58482 Mdot
.49711 .60514 Mdot
.48284 .56094 Mdot
.34113 .4234 Mdot
.32624 .57166 Mdot
.2269 .61677 Mdot
.68634 .47892 Mdot
.65644 .45553 Mdot
.59879 .47011 Mdot
.33573 .58947 Mdot
.51286 .55444 Mdot
.74 .33674 Mdot
.58455 .44743 Mdot
.27917 .58668 Mdot
.49857 .55247 Mdot
.57778 .31402 Mdot
.5346 .33086 Mdot
.26636 .54228 Mdot
.30144 .41822 Mdot
.45604 .69909 Mdot
.46721 .79078 Mdot
.50834 .33723 Mdot
.48001 .29305 Mdot
.30653 .56376 Mdot
.60612 .68569 Mdot
.60164 .15886 Mdot
.31881 .58489 Mdot
.72905 .54838 Mdot
.5148 .30859 Mdot
.52206 .5752 Mdot
.62735 .71073 Mdot
.59792 .6932 Mdot
.26979 .57526 Mdot
.6373 .50282 Mdot
.33866 .62259 Mdot
.32405 .595 Mdot
.49272 .56923 Mdot
.29807 .5954 Mdot
.34821 .38624 Mdot
.30944 .5759 Mdot
.55706 .29705 Mdot
.65951 .50547 Mdot
.60431 .16287 Mdot
.56345 .70988 Mdot
.66454 .4937 Mdot
.34236 .38618 Mdot
.27315 .37015 Mdot
.63795 .49315 Mdot
.44808 .70848 Mdot
.32799 .5731 Mdot
.35311 .53431 Mdot
.62909 .51747 Mdot
.30436 .61212 Mdot
.53734 .28153 Mdot
.33118 .50458 Mdot
.31617 .48876 Mdot
.49356 .6029 Mdot
.52168 .30107 Mdot
.2974 .44567 Mdot
.31423 .38075 Mdot
.48111 .60367 Mdot
.63649 .44289 Mdot
.53898 .29907 Mdot
.71793 .50819 Mdot
.54418 .53 Mdot
.63693 .46191 Mdot
.29362 .56523 Mdot
.2596 .56234 Mdot
.57174 .68139 Mdot
.2992 .58578 Mdot
.49172 .56856 Mdot
.53422 .30073 Mdot
.62611 .51454 Mdot
.49329 .3349 Mdot
.6692 .47992 Mdot
.30549 .47221 Mdot
.5432 .32165 Mdot
.48437 .52904 Mdot
.61704 .483 Mdot
.6636 .24029 Mdot
.67798 .48107 Mdot
.63353 .45916 Mdot
.26353 .58569 Mdot
.46242 .67071 Mdot
.52802 .52973 Mdot
.29181 .46899 Mdot
.44931 .69058 Mdot
.54107 .26487 Mdot
.2826 .61141 Mdot
.46593 .66369 Mdot
.43151 .78135 Mdot
.48159 .57162 Mdot
.48579 .68801 Mdot
.59635 .45662 Mdot
.32629 .41462 Mdot
.48978 .3545 Mdot
.61036 .45035 Mdot
.78743 .42751 Mdot
.71656 .55527 Mdot
.50335 .58987 Mdot
.62924 .45658 Mdot
.65636 .49431 Mdot
.49017 .3102 Mdot
.25793 .29481 Mdot
.30229 .53748 Mdot
.5136 .57182 Mdot
.49724 .3386 Mdot
.26346 .28988 Mdot
.26994 .56341 Mdot
.45107 .66738 Mdot
.31921 .37134 Mdot
.52385 .35958 Mdot
.50346 .58512 Mdot
.32071 .40861 Mdot
.32542 .62648 Mdot
.5219 .74207 Mdot
.63495 .51762 Mdot
.3166 .56297 Mdot
.52521 .74654 Mdot
.6736 .54655 Mdot
.28481 .46058 Mdot
.30235 .33776 Mdot
.54634 .30139 Mdot
.31276 .40816 Mdot
.46966 .70878 Mdot
.47504 .33995 Mdot
.533 .33009 Mdot
.33595 .41226 Mdot
.73311 .27952 Mdot
.63277 .70518 Mdot
.31005 .37182 Mdot
.60052 .66554 Mdot
.5246 .74357 Mdot
.50603 .58544 Mdot
.47248 .69939 Mdot
.3246 .49566 Mdot
.52395 .32352 Mdot
.42017 .29947 Mdot
.52566 .74869 Mdot
.6794 .54726 Mdot
.45563 .69564 Mdot
.31731 .26589 Mdot
.36401 .42227 Mdot
.33034 .40714 Mdot
.2815 .51085 Mdot
.45158 .68401 Mdot
.60754 .44772 Mdot
.43647 .83842 Mdot
.62276 .44421 Mdot
.33011 .41678 Mdot
.73547 .54594 Mdot
.49197 .31995 Mdot
.3521 .40296 Mdot
.73588 .54945 Mdot
.68128 .50403 Mdot
.65706 .49988 Mdot
.24848 .56837 Mdot
.54929 .31919 Mdot
.49379 .61408 Mdot
.66539 .49154 Mdot
.61514 .46861 Mdot
.51737 .60796 Mdot
.61456 .76004 Mdot
.44554 .51565 Mdot
.52464 .59209 Mdot
.27799 .57181 Mdot
.51736 .59857 Mdot
.51155 .57048 Mdot
.50697 .29418 Mdot
.3044 .4991 Mdot
.50169 .61256 Mdot
.6281 .46673 Mdot
.63052 .46296 Mdot
.31514 .37168 Mdot
.63163 .70751 Mdot
.60489 .68964 Mdot
.31652 .54552 Mdot
.52871 .61349 Mdot
.63707 .5067 Mdot
.52035 .29962 Mdot
.47699 .72624 Mdot
.48952 .56583 Mdot
.48219 .33746 Mdot
.66243 .50775 Mdot
.32656 .60502 Mdot
.49545 .60061 Mdot
.52623 .6002 Mdot
.4601 .69386 Mdot
.3392 .3707 Mdot
.52589 .26627 Mdot
.32612 .58845 Mdot
.66623 .5339 Mdot
.53634 .60182 Mdot
.30899 .60786 Mdot
.5075 .5864 Mdot
.51964 .59234 Mdot
.52468 .30313 Mdot
.54311 .34356 Mdot
.52309 .56109 Mdot
.28916 .5886 Mdot
.15757 .49657 Mdot
.31165 .38622 Mdot
.66189 .45516 Mdot
.33623 .37277 Mdot
.54541 .29493 Mdot
.58328 .7674 Mdot
.47694 .66643 Mdot
.33448 .40809 Mdot
.51058 .60752 Mdot
.53793 .32719 Mdot
.5508 .2991 Mdot
.63294 .469 Mdot
.64368 .46854 Mdot
.2881 .52479 Mdot
.54247 .76191 Mdot
.29037 .39286 Mdot
.4438 .68458 Mdot
.30812 .54171 Mdot
.63771 .52243 Mdot
.5025 .30992 Mdot
.55859 .81251 Mdot
.66361 .45611 Mdot
.28813 .58232 Mdot
.51365 .31995 Mdot
.44239 .69425 Mdot
.47478 .70206 Mdot
.6645 .47777 Mdot
.46444 .55397 Mdot
.34 .40756 Mdot
.53075 .30969 Mdot
.45683 .28997 Mdot
.67877 .48582 Mdot
.64534 .47312 Mdot
.67087 .54485 Mdot
.31631 .36939 Mdot
.60029 .45281 Mdot
.47729 .70889 Mdot
.49462 .31095 Mdot
.66205 .47696 Mdot
.45349 .6812 Mdot
.4809 .59285 Mdot
.49782 .59802 Mdot
.26302 .5708 Mdot
.44578 .70752 Mdot
.45936 .67691 Mdot
.44756 .6891 Mdot
.42142 .28854 Mdot
.60687 .42899 Mdot
.52236 .54857 Mdot
.63433 .50211 Mdot
.52435 .74211 Mdot
.6224 .50623 Mdot
.32953 .3799 Mdot
.27413 .59437 Mdot
.63712 .486 Mdot
.63003 .49868 Mdot
.53337 .27074 Mdot
.61815 .50722 Mdot
.60295 .44927 Mdot
.49357 .31637 Mdot
.46364 .2867 Mdot
.30151 .6181 Mdot
.26626 .29245 Mdot
.48785 .85421 Mdot
.62461 .43602 Mdot
.60142 .68609 Mdot
.54028 .32055 Mdot
.31741 .37138 Mdot
.60587 .67167 Mdot
.34904 .37652 Mdot
.505 .33237 Mdot
.6173 .51027 Mdot
.51756 .24689 Mdot
.45084 .69137 Mdot
.64897 .49054 Mdot
.343 .40803 Mdot
.64752 .49106 Mdot
.35075 .39669 Mdot
.73035 .31327 Mdot
.60909 .71926 Mdot
.63282 .439 Mdot
.65707 .5176 Mdot
.45516 .58244 Mdot
.64647 .47196 Mdot
.21627 .61346 Mdot
.51099 .31706 Mdot
.48455 .61197 Mdot
.61288 .50668 Mdot
.72319 .36439 Mdot
.62442 .45463 Mdot
.75251 .53927 Mdot
.61062 .4587 Mdot
.39863 .81012 Mdot
.63936 .43686 Mdot
.63319 .44243 Mdot
.33744 .38875 Mdot
.29713 .3934 Mdot
.54364 .28036 Mdot
.5148 .59692 Mdot
.30936 .27054 Mdot
.61752 .46253 Mdot
.28384 .54275 Mdot
.53973 .51505 Mdot
.45912 .67493 Mdot
.4861 .31891 Mdot
.88971 .43929 Mdot
.34193 .42473 Mdot
.28701 .56014 Mdot
.72139 .54945 Mdot
.28207 .56806 Mdot
.27484 .54005 Mdot
.4603 .27246 Mdot
.47154 .70041 Mdot
.67412 .48578 Mdot
.68675 .34335 Mdot
.48537 .37961 Mdot
.6789 .48666 Mdot
.32184 .62456 Mdot
.46536 .57235 Mdot
.62178 .58905 Mdot
.47133 .6538 Mdot
.46919 .67984 Mdot
.31784 .40115 Mdot
.28394 .54433 Mdot
.51416 .57433 Mdot
.46792 .66307 Mdot
.30231 .61637 Mdot
.48329 .56991 Mdot
.29637 .5057 Mdot
.52701 .31568 Mdot
.74554 .32628 Mdot
.67019 .25087 Mdot
.34024 .37791 Mdot
.28573 .46753 Mdot
.47757 .35221 Mdot
.4747 .3337 Mdot
.5132 .58906 Mdot
.27769 .58763 Mdot
.50486 .35368 Mdot
.66407 .48122 Mdot
.51739 .59764 Mdot
.64839 .45525 Mdot
.46336 .65695 Mdot
.62469 .45987 Mdot
.30458 .61486 Mdot
.34189 .3908 Mdot
.30955 .59939 Mdot
.31765 .40465 Mdot
.63137 .75686 Mdot
.61103 .47439 Mdot
.64348 .47379 Mdot
.59154 .69053 Mdot
.52561 .29253 Mdot
.6897 .35472 Mdot
.29066 .58763 Mdot
.30476 .5987 Mdot
.612 .50504 Mdot
.48426 .34739 Mdot
.5301 .56909 Mdot
.59519 .66239 Mdot
.61246 .45656 Mdot
.5092 .31846 Mdot
.60608 .49445 Mdot
.27056 .33755 Mdot
.59064 .71645 Mdot
.5246 .29093 Mdot
.22081 .65481 Mdot
.60554 .45761 Mdot
.50985 .5639 Mdot
.46752 .57823 Mdot
.66442 .68073 Mdot
.52913 .52808 Mdot
.4849 .33699 Mdot
.5178 .57776 Mdot
.50571 .30852 Mdot
.31522 .60258 Mdot
.35216 .40701 Mdot
.50333 .31439 Mdot
.60773 .4636 Mdot
.48835 .85346 Mdot
.34741 .40517 Mdot
.64725 .48749 Mdot
.33995 .41539 Mdot
.4917 .3593 Mdot
.49298 .32703 Mdot
.48343 .56983 Mdot
.72891 .5496 Mdot
.33765 .4081 Mdot
.65309 .45246 Mdot
.42552 .32642 Mdot
.63117 .5162 Mdot
.5175 .62348 Mdot
.64508 .51233 Mdot
.66145 .5093 Mdot
.25306 .71188 Mdot
.72391 .51276 Mdot
.31427 .48042 Mdot
.32893 .36342 Mdot
.43044 .27755 Mdot
.49969 .29992 Mdot
.4562 .66018 Mdot
.54039 .27509 Mdot
.48463 .5909 Mdot
.27648 .57024 Mdot
.63618 .48231 Mdot
.47932 .56916 Mdot
.28954 .38927 Mdot
.48416 .68333 Mdot
.64459 .44075 Mdot
.31208 .5525 Mdot
.5043 .55715 Mdot
.32497 .40805 Mdot
.52314 .32583 Mdot
.48588 .32607 Mdot
.30562 .50248 Mdot
.66231 .47924 Mdot
.64132 .46733 Mdot
.33218 .42381 Mdot
.48548 .53205 Mdot
.44761 .69527 Mdot
.50901 .55403 Mdot
.3338 .42073 Mdot
.59223 .71721 Mdot
.5496 .32011 Mdot
.65811 .49183 Mdot
.58613 .69189 Mdot
.43497 .27478 Mdot
.61301 .37686 Mdot
.4642 .68242 Mdot
.65508 .66576 Mdot
.48538 .33708 Mdot
.33437 .39097 Mdot
.4271 .77795 Mdot
.66206 .54166 Mdot
.64494 .49851 Mdot
.66183 .65735 Mdot
.59746 .66189 Mdot
.72067 .54569 Mdot
.49958 .61474 Mdot
.62616 .7021 Mdot
.60924 .50134 Mdot
.65596 .53064 Mdot
.63334 .50441 Mdot
.64614 .51336 Mdot
.50181 .32173 Mdot
.75277 .37213 Mdot
.30463 .56708 Mdot
.57869 .47686 Mdot
.48282 .64685 Mdot
.68243 .54711 Mdot
.67819 .52025 Mdot
.58474 .34701 Mdot
.68864 .62533 Mdot
.51804 .31163 Mdot
.53505 .28519 Mdot
.33623 .37537 Mdot
.62587 .51259 Mdot
.28875 .58531 Mdot
.47476 .5568 Mdot
.27871 .59641 Mdot
.50369 .32228 Mdot
.30757 .62115 Mdot
.34428 .42538 Mdot
.3164 .56249 Mdot
.27779 .58175 Mdot
.33923 .38665 Mdot
.54462 .32699 Mdot
.67887 .48247 Mdot
.33965 .38644 Mdot
.52971 .59102 Mdot
.4514 .66576 Mdot
.47442 .28882 Mdot
.52422 .58269 Mdot
.69138 .51733 Mdot
.16535 .47333 Mdot
.30912 .55714 Mdot
.65622 .6394 Mdot
.5458 .32019 Mdot
.49221 .70509 Mdot
.49993 .31673 Mdot
.52346 .56058 Mdot
.46103 .68561 Mdot
.59561 .45873 Mdot
.5051 .79766 Mdot
.30859 .33812 Mdot
.69346 .53518 Mdot
.46292 .28701 Mdot
.2821 .5987 Mdot
.34686 .38941 Mdot
.25168 .37009 Mdot
.51427 .57172 Mdot
.53853 .28094 Mdot
.54833 .34312 Mdot
.48566 .59188 Mdot
.3374 .39322 Mdot
.65711 .25199 Mdot
.66382 .48908 Mdot
.3359 .37361 Mdot
.64561 .51204 Mdot
.76185 .3473 Mdot
.49966 .69617 Mdot
.48304 .55834 Mdot
.62048 .51367 Mdot
.27025 .5637 Mdot
.61381 .50698 Mdot
.77898 .40676 Mdot
.56127 .76973 Mdot
.61805 .4869 Mdot
.65996 .64514 Mdot
.3077 .53359 Mdot
.507 .30543 Mdot
.4935 .57998 Mdot
.50563 .58765 Mdot
.62913 .52264 Mdot
.57956 .84963 Mdot
.47426 .66866 Mdot
.21947 .59132 Mdot
.61049 .47082 Mdot
.64431 .46155 Mdot
.53426 .26838 Mdot
.72885 .31425 Mdot
.51387 .55812 Mdot
.63597 .49669 Mdot
.68916 .63405 Mdot
.32409 .38761 Mdot
.65346 .52052 Mdot
.64682 .45639 Mdot
.33823 .51057 Mdot
.33617 .38918 Mdot
.32555 .60184 Mdot
.48121 .57603 Mdot
.26102 .57695 Mdot
.47295 .71441 Mdot
.64757 .66299 Mdot
.60095 .76379 Mdot
.58722 .71259 Mdot
.45245 .71139 Mdot
.66074 .53784 Mdot
.6932 .50095 Mdot
.65265 .50374 Mdot
.47218 .6784 Mdot
.30012 .42107 Mdot
.50758 .31754 Mdot
.75561 .33706 Mdot
.50763 .58886 Mdot
.68321 .53894 Mdot
.49265 .6775 Mdot
.50947 .30879 Mdot
.66128 .23381 Mdot
.50191 .32732 Mdot
.32735 .40447 Mdot
.2848 .46198 Mdot
.45713 .68676 Mdot
.49973 .31639 Mdot
.26486 .58647 Mdot
.29582 .4597 Mdot
.58114 .44139 Mdot
.34236 .4265 Mdot
.55471 .31902 Mdot
.53169 .28816 Mdot
.47005 .34379 Mdot
.62892 .52018 Mdot
.65854 .64302 Mdot
.48606 .57655 Mdot
.34311 .41474 Mdot
.28774 .55275 Mdot
.54679 .76347 Mdot
.65622 .27606 Mdot
.60819 .70838 Mdot
.59684 .46738 Mdot
.62531 .46049 Mdot
.63896 .45298 Mdot
.51658 .61228 Mdot
.69464 .50069 Mdot
.62362 .49323 Mdot
.28966 .39698 Mdot
.31757 .6059 Mdot
.61276 .47136 Mdot
.49411 .59481 Mdot
.51518 .53549 Mdot
.49118 .70597 Mdot
.77255 .3578 Mdot
.47966 .28488 Mdot
.50738 .31131 Mdot
.28894 .57306 Mdot
.28035 .61044 Mdot
.47114 .66153 Mdot
.31099 .40016 Mdot
.50188 .32939 Mdot
.39397 .80535 Mdot
.45106 .69655 Mdot
.62764 .46932 Mdot
.59035 .69107 Mdot
.68462 .64523 Mdot
.67253 .51638 Mdot
.63162 .48048 Mdot
.50963 .606 Mdot
.28617 .58298 Mdot
.78137 .45393 Mdot
.66192 .23708 Mdot
.45481 .68116 Mdot
.45179 .67042 Mdot
.47168 .34267 Mdot
.64525 .44576 Mdot
.34035 .40972 Mdot
.63503 .70475 Mdot
.27355 .36478 Mdot
.34563 .24581 Mdot
.33786 .61442 Mdot
.67534 .4878 Mdot
.72942 .38892 Mdot
.69488 .52677 Mdot
.47485 .35654 Mdot
.53409 .34649 Mdot
.52204 .30978 Mdot
.31917 .38985 Mdot
.52187 .73233 Mdot
.29965 .40374 Mdot
.50015 .5529 Mdot
.51561 .3373 Mdot
.71837 .5226 Mdot
.30306 .59782 Mdot
.62104 .50712 Mdot
.4732 .69307 Mdot
.52755 .63361 Mdot
.49744 .57842 Mdot
.65248 .66481 Mdot
.32637 .58026 Mdot
.5309 .3377 Mdot
.61772 .50435 Mdot
.29855 .47615 Mdot
.61768 .70864 Mdot
.33374 .55804 Mdot
.47886 .57106 Mdot
.45274 .68873 Mdot
.73765 .42558 Mdot
.45454 .70309 Mdot
.33479 .40941 Mdot
.61469 .47968 Mdot
.63979 .44457 Mdot
.63458 .45765 Mdot
.60356 .45289 Mdot
.3184 .39392 Mdot
.69294 .54229 Mdot
.52747 .57531 Mdot
.48288 .56255 Mdot
.70958 .55136 Mdot
.47928 .69539 Mdot
.31671 .38341 Mdot
.31209 .60832 Mdot
.50286 .60881 Mdot
.49213 .68496 Mdot
.61473 .49608 Mdot
.62703 .49403 Mdot
.49596 .55534 Mdot
.59685 .45647 Mdot
.69706 .54419 Mdot
.31614 .57112 Mdot
.71281 .54552 Mdot
.49067 .70525 Mdot
.46863 .69273 Mdot
.31729 .41223 Mdot
.50028 .31541 Mdot
.48565 .67197 Mdot
.31568 .54886 Mdot
.64949 .52034 Mdot
.64195 .51052 Mdot
.55833 .30815 Mdot
.52384 .74815 Mdot
.4906 .70845 Mdot
.6008 .45193 Mdot
.5114 .29745 Mdot
.54622 .34715 Mdot
.6414 .49752 Mdot
.69053 .54546 Mdot
.49816 .29921 Mdot
.45915 .66284 Mdot
.30964 .40751 Mdot
.56267 .72132 Mdot
.35371 .39363 Mdot
.52546 .32522 Mdot
.51782 .58383 Mdot
.54038 .33046 Mdot
.5154 .57276 Mdot
.42397 .20448 Mdot
.62685 .49713 Mdot
.47427 .24603 Mdot
.51389 .55441 Mdot
.29894 .59731 Mdot
.2883 .59685 Mdot
.49265 .59812 Mdot
.48834 .34118 Mdot
.49101 .56979 Mdot
.46208 .70747 Mdot
.42861 .28277 Mdot
.50984 .2926 Mdot
.27788 .58343 Mdot
.30937 .55563 Mdot
.33487 .42033 Mdot
.62479 .45741 Mdot
.65873 .49222 Mdot
.3187 .56473 Mdot
.27242 .36301 Mdot
.54522 .30602 Mdot
.64099 .46771 Mdot
.52371 .59686 Mdot
.31043 .56927 Mdot
.36627 .35252 Mdot
.49924 .35379 Mdot
.62097 .51519 Mdot
.56678 .77077 Mdot
.35062 .41092 Mdot
.68042 .52825 Mdot
.69366 .54397 Mdot
.46907 .67033 Mdot
.65822 .66474 Mdot
.5273 .74556 Mdot
.34092 .42592 Mdot
.48382 .58277 Mdot
.67389 .517 Mdot
.29716 .60012 Mdot
.61965 .49662 Mdot
.84794 .5295 Mdot
.48962 .55529 Mdot
.66038 .47714 Mdot
.47113 .56669 Mdot
.4925 .3348 Mdot
.64094 .46337 Mdot
.30743 .47162 Mdot
.29299 .57393 Mdot
.66197 .48229 Mdot
.45795 .56525 Mdot
.34003 .41482 Mdot
.49715 .57928 Mdot
.45115 .68772 Mdot
.7242 .54469 Mdot
.64321 .75378 Mdot
.33559 .58752 Mdot
.47969 .69968 Mdot
.62176 .45707 Mdot
.30389 .53976 Mdot
.29853 .39081 Mdot
.49084 .58352 Mdot
.67624 .53328 Mdot
.32308 .37841 Mdot
.32705 .38517 Mdot
.45708 .691 Mdot
.65668 .20488 Mdot
.62323 .43719 Mdot
.65147 .48371 Mdot
.65757 .22205 Mdot
.55555 .34978 Mdot
.64634 .48927 Mdot
.62733 .44686 Mdot
.32275 .41101 Mdot
.51886 .73147 Mdot
.65401 .66452 Mdot
.48647 .54956 Mdot
.34504 .38699 Mdot
.3305 .62302 Mdot
.29672 .55956 Mdot
.48207 .70009 Mdot
.51405 .32067 Mdot
.47728 .6628 Mdot
.30531 .57417 Mdot
.63064 .46943 Mdot
.31182 .41521 Mdot
.78461 .48221 Mdot
.34976 .40658 Mdot
.31741 .55266 Mdot
.4787 .35825 Mdot
.78416 .44052 Mdot
.85326 .51992 Mdot
.44023 .51528 Mdot
.28275 .45839 Mdot
.45981 .67417 Mdot
.66157 .23674 Mdot
.61059 .46401 Mdot
.77103 .4007 Mdot
.65079 .4885 Mdot
.42989 .69336 Mdot
.29028 .60707 Mdot
.48331 .57002 Mdot
.51366 .57053 Mdot
.65285 .66036 Mdot
.32113 .38615 Mdot
.30614 .42237 Mdot
.52058 .58601 Mdot
.33196 .4035 Mdot
.65856 .47977 Mdot
.322 .58607 Mdot
.46123 .2048 Mdot
.60954 .45911 Mdot
.49324 .61927 Mdot
.36018 .40933 Mdot
.4958 .37038 Mdot
.32951 .62326 Mdot
.72664 .37867 Mdot
.29426 .28093 Mdot
.34059 .40439 Mdot
.77307 .36104 Mdot
.2894 .57817 Mdot
.5034 .60869 Mdot
.29841 .53787 Mdot
.6548 .4861 Mdot
.67537 .48739 Mdot
.51388 .61015 Mdot
.62091 .45342 Mdot
.69466 .38497 Mdot
.69447 .55133 Mdot
.55915 .47642 Mdot
.63675 .50316 Mdot
.49757 .24419 Mdot
.29525 .39246 Mdot
.51992 .58699 Mdot
.55279 .6594 Mdot
.65946 .50778 Mdot
.49024 .30558 Mdot
.33022 .37818 Mdot
.27638 .29483 Mdot
.32108 .3901 Mdot
.30754 .60118 Mdot
.3124 .39544 Mdot
.69102 .52806 Mdot
.50786 .33396 Mdot
.30576 .58428 Mdot
.50093 .58109 Mdot
.28013 .55893 Mdot
.66456 .49318 Mdot
.37706 .37322 Mdot
.28794 .5603 Mdot
.67318 .54559 Mdot
.50347 .33432 Mdot
.53528 .81008 Mdot
.46065 .33737 Mdot
.63776 .47556 Mdot
.64169 .48333 Mdot
.51498 .55814 Mdot
.31435 .40493 Mdot
.5409 .33307 Mdot
.27228 .5171 Mdot
.492 .70645 Mdot
.51873 .31533 Mdot
.47197 .54719 Mdot
.60693 .68472 Mdot
.48751 .31528 Mdot
.68816 .63832 Mdot
.33264 .41317 Mdot
.48359 .33278 Mdot
.54496 .52224 Mdot
.58495 .48865 Mdot
.46643 .70048 Mdot
.26236 .58284 Mdot
.60757 .67742 Mdot
.29311 .56241 Mdot
.30644 .47333 Mdot
.25754 .57322 Mdot
.34559 .40147 Mdot
.46987 .54624 Mdot
.735 .54529 Mdot
.31188 .42791 Mdot
.38322 .4212 Mdot
.29854 .56693 Mdot
.52075 .57571 Mdot
.7109 .54715 Mdot
.52547 .60244 Mdot
.51252 .56313 Mdot
.33934 .42636 Mdot
.48258 .333 Mdot
.47926 .34348 Mdot
.47417 .59413 Mdot
.48871 .32122 Mdot
.31646 .58459 Mdot
.58016 .70656 Mdot
.73368 .35246 Mdot
.29122 .39964 Mdot
.71401 .54358 Mdot
.67572 .52454 Mdot
.30359 .61305 Mdot
.31736 .59043 Mdot
.32066 .3876 Mdot
.58429 .39352 Mdot
.50487 .56063 Mdot
.49291 .36233 Mdot
.5075 .3379 Mdot
.48979 .33415 Mdot
.54828 .29865 Mdot
.5213 .73924 Mdot
.34187 .38555 Mdot
.49009 .34094 Mdot
.60305 .45766 Mdot
.63029 .44858 Mdot
.49822 .60767 Mdot
.45936 .65934 Mdot
.69459 .54719 Mdot
.49087 .56894 Mdot
.64617 .49761 Mdot
.29728 .59455 Mdot
.53395 .51269 Mdot
.48374 .59168 Mdot
.28797 .58567 Mdot
.29143 .5919 Mdot
.48293 .58274 Mdot
.53092 .51304 Mdot
.69453 .39794 Mdot
.61618 .51475 Mdot
.45039 .2881 Mdot
.28137 .59311 Mdot
.36078 .45765 Mdot
.47765 .24438 Mdot
.64603 .4489 Mdot
.50537 .55202 Mdot
.32087 .59355 Mdot
.516 .29082 Mdot
.6508 .47592 Mdot
.51377 .587 Mdot
.46054 .70154 Mdot
.49749 .58333 Mdot
.51094 .60454 Mdot
.52801 .29575 Mdot
.16186 .48798 Mdot
.4928 .30838 Mdot
.25252 .563 Mdot
.50344 .5756 Mdot
.60215 .16077 Mdot
.28757 .6024 Mdot
.42626 .28574 Mdot
.73429 .54696 Mdot
.64794 .50095 Mdot
.28993 .57178 Mdot
.53742 .28197 Mdot
.32884 .43101 Mdot
.69073 .62139 Mdot
.49808 .31665 Mdot
.492 .60992 Mdot
.50147 .60419 Mdot
.30649 .56716 Mdot
.53082 .32495 Mdot
.69325 .54417 Mdot
.48744 .32847 Mdot
.30383 .41442 Mdot
.59217 .4709 Mdot
.30761 .27183 Mdot
.51436 .57588 Mdot
.49115 .31571 Mdot
.29542 .54894 Mdot
.4786 .70839 Mdot
.62131 .44398 Mdot
.28479 .2826 Mdot
.62262 .45565 Mdot
.31775 .4258 Mdot
.54128 .53663 Mdot
.59085 .48929 Mdot
.62382 .4769 Mdot
.68087 .51678 Mdot
.29287 .42819 Mdot
.62454 .48007 Mdot
.66847 .50849 Mdot
.66599 .24749 Mdot
.49746 .3071 Mdot
.61213 .4692 Mdot
.32076 .57213 Mdot
.49762 .50237 Mdot
.65379 .46358 Mdot
.28909 .46999 Mdot
.66079 .68166 Mdot
.5112 .55122 Mdot
.48622 .61741 Mdot
.58102 .76775 Mdot
.64553 .48374 Mdot
.65157 .44984 Mdot
.59262 .47045 Mdot
.74031 .39236 Mdot
.30024 .57344 Mdot
.27372 .55678 Mdot
.47795 .70713 Mdot
.66358 .65428 Mdot
.46475 .69219 Mdot
.29891 .39003 Mdot
.72435 .55293 Mdot
.4799 .5732 Mdot
.50191 .31275 Mdot
.63686 .45804 Mdot
.28701 .55024 Mdot
.65768 .48531 Mdot
.64975 .53007 Mdot
.31547 .5798 Mdot
.3182 .5975 Mdot
.25927 .58738 Mdot
.45084 .68254 Mdot
.51378 .31066 Mdot
.61936 .44176 Mdot
.44927 .68776 Mdot
.51668 .60941 Mdot
.57045 .72935 Mdot
.5167 .31004 Mdot
.49471 .31241 Mdot
.50396 .3448 Mdot
.63455 .4416 Mdot
.58944 .46535 Mdot
.30092 .39882 Mdot
.5584 .30837 Mdot
.3344 .41595 Mdot
.28982 .56918 Mdot
.32275 .60041 Mdot
.65465 .48721 Mdot
.47842 .5402 Mdot
.47657 .69738 Mdot
.29366 .55567 Mdot
.47452 .56735 Mdot
.48911 .69457 Mdot
.66126 .46409 Mdot
.29106 .56426 Mdot
.44657 .70598 Mdot
.58709 .39353 Mdot
.33975 .27534 Mdot
.48293 .7055 Mdot
.5112 .56681 Mdot
.65784 .28711 Mdot
.55752 .76616 Mdot
.4806 .72433 Mdot
.29429 .3946 Mdot
.66043 .45211 Mdot
.47899 .56173 Mdot
.49138 .69041 Mdot
.5312 .75979 Mdot
.3098 .57815 Mdot
.5078 .56308 Mdot
.44052 .5353 Mdot
.73419 .3544 Mdot
.48026 .70837 Mdot
.49155 .31461 Mdot
.55256 .32217 Mdot
.62722 .47401 Mdot
.72554 .55042 Mdot
.28867 .40282 Mdot
.27296 .60298 Mdot
.27809 .55418 Mdot
.53104 .35088 Mdot
.58843 .71437 Mdot
.3148 .56527 Mdot
.65775 .45159 Mdot
.48686 .66044 Mdot
.60214 .45903 Mdot
.54535 .54188 Mdot
.59232 .491 Mdot
.47593 .60495 Mdot
.48064 .70728 Mdot
.28888 .40763 Mdot
.34202 .39189 Mdot
.31536 .40115 Mdot
.31285 .56653 Mdot
.60826 .67317 Mdot
.28351 .54707 Mdot
.66754 .22178 Mdot
.47565 .66883 Mdot
.29625 .74808 Mdot
.69276 .51454 Mdot
.65301 .50083 Mdot
.6333 .51591 Mdot
.52193 .59724 Mdot
.64547 .48216 Mdot
.31793 .38004 Mdot
.26452 .58392 Mdot
.33904 .33938 Mdot
.53596 .30443 Mdot
.66829 .22931 Mdot
.30254 .59668 Mdot
.48208 .60371 Mdot
.47603 .69371 Mdot
.60089 .76859 Mdot
.4376 .68153 Mdot
.32873 .57985 Mdot
.67055 .49218 Mdot
.46972 .33852 Mdot
.40604 .81558 Mdot
.63811 .4615 Mdot
.30771 .55646 Mdot
.33469 .56733 Mdot
.57685 .47626 Mdot
.75393 .4854 Mdot
.2936 .33804 Mdot
.58731 .69603 Mdot
.44778 .71185 Mdot
.52356 .60256 Mdot
.6407 .7008 Mdot
.30449 .57259 Mdot
.26701 .57469 Mdot
.44431 .71412 Mdot
.49525 .37141 Mdot
.50619 .34158 Mdot
.4518 .31287 Mdot
.3082 .38618 Mdot
.64513 .50219 Mdot
.2961 .5643 Mdot
.47692 .35481 Mdot
.54307 .65739 Mdot
.32199 .39975 Mdot
.28793 .55877 Mdot
.62324 .45305 Mdot
.62237 .47364 Mdot
.46321 .69341 Mdot
.51865 .53633 Mdot
.52737 .59149 Mdot
.42751 .28565 Mdot
.60887 .69439 Mdot
.73483 .55008 Mdot
.64488 .49857 Mdot
.54287 .29521 Mdot
.48477 .58798 Mdot
.47214 .70063 Mdot
.62 .49649 Mdot
.78238 .42343 Mdot
.53604 .28577 Mdot
.33744 .41176 Mdot
.50653 .58226 Mdot
.64756 .65908 Mdot
.62211 .45397 Mdot
.65125 .48807 Mdot
.62884 .52001 Mdot
.78535 .44737 Mdot
.27558 .59569 Mdot
.51314 .29888 Mdot
.45176 .68555 Mdot
.49467 .32792 Mdot
.30701 .50734 Mdot
.71522 .55303 Mdot
.64289 .43828 Mdot
.50502 .29786 Mdot
.50577 .33035 Mdot
.31606 .42548 Mdot
.34476 .39183 Mdot
.33708 .60127 Mdot
.62752 .44564 Mdot
.48767 .5552 Mdot
.49129 .33989 Mdot
.26387 .58893 Mdot
.46312 .69122 Mdot
.28566 .47074 Mdot
.62655 .49504 Mdot
.30221 .56825 Mdot
.49318 .57749 Mdot
.53212 .29911 Mdot
.29139 .58487 Mdot
.50403 .60873 Mdot
.45276 .66673 Mdot
.67845 .50746 Mdot
.31726 .53496 Mdot
.51567 .59077 Mdot
.6172 .44732 Mdot
.55763 .5123 Mdot
.72483 .54959 Mdot
.47927 .55372 Mdot
.31276 .61544 Mdot
.51149 .59166 Mdot
.55087 .32433 Mdot
.57766 .46819 Mdot
.26522 .57181 Mdot
.5158 .24618 Mdot
.73699 .54648 Mdot
.51677 .57572 Mdot
.5058 .30668 Mdot
.29609 .50647 Mdot
.51606 .38325 Mdot
.55619 .76171 Mdot
.65409 .46878 Mdot
.29344 .56226 Mdot
.46429 .70004 Mdot
.3075 .42267 Mdot
.3725 .42245 Mdot
.34844 .48828 Mdot
.28293 .58858 Mdot
.63791 .4576 Mdot
.48429 .33418 Mdot
.33765 .40579 Mdot
.53043 .26574 Mdot
.30173 .54077 Mdot
.32319 .57518 Mdot
.64197 .52264 Mdot
.46558 .69152 Mdot
.69426 .50347 Mdot
.26315 .57396 Mdot
.26074 .56291 Mdot
.66524 .24962 Mdot
.44868 .71186 Mdot
.628 .52019 Mdot
.47426 .59586 Mdot
.64804 .51737 Mdot
.66002 .2309 Mdot
.50786 .60311 Mdot
.53712 .30492 Mdot
.63979 .48822 Mdot
.17856 .56424 Mdot
.29447 .60673 Mdot
.58744 .69636 Mdot
.31252 .33806 Mdot
.33119 .38356 Mdot
.29525 .57722 Mdot
.64974 .47016 Mdot
.28383 .4664 Mdot
.48389 .69818 Mdot
.61129 .50588 Mdot
.51964 .58028 Mdot
.53608 .35154 Mdot
.30957 .41396 Mdot
.47875 .51995 Mdot
.30483 .41929 Mdot
.31602 .4101 Mdot
.54938 .39422 Mdot
.62729 .47289 Mdot
.30126 .59272 Mdot
.3172 .55646 Mdot
.50452 .6253 Mdot
.24353 .57565 Mdot
.52686 .336 Mdot
.17813 .55557 Mdot
.78247 .43032 Mdot
.6123 .47855 Mdot
.49859 .61448 Mdot
.50787 .5549 Mdot
.28418 .46102 Mdot
.62781 .4809 Mdot
.51149 .30372 Mdot
.26214 .5743 Mdot
.30071 .56034 Mdot
.67339 .54553 Mdot
.34229 .39158 Mdot
.44231 .68128 Mdot
.31579 .58894 Mdot
.56234 .71754 Mdot
.66081 .47699 Mdot
.36614 .40574 Mdot
.31405 .58869 Mdot
.51333 .84147 Mdot
.15538 .50724 Mdot
.48055 .32098 Mdot
.68106 .50746 Mdot
.49993 .35288 Mdot
.47222 .71125 Mdot
.27691 .54217 Mdot
.30737 .4248 Mdot
.50233 .57764 Mdot
.24454 .36261 Mdot
.30471 .56329 Mdot
.5044 .32128 Mdot
.63245 .47626 Mdot
.7758 .36721 Mdot
.61059 .45918 Mdot
.51851 .72959 Mdot
.48932 .71133 Mdot
.37507 .41756 Mdot
.33382 .42279 Mdot
.68156 .5066 Mdot
.447 .69113 Mdot
.3283 .56839 Mdot
.31448 .57829 Mdot
.2735 .28772 Mdot
.50943 .60509 Mdot
.28152 .53672 Mdot
.61961 .44655 Mdot
.25838 .58264 Mdot
.65602 .27549 Mdot
.333 .38476 Mdot
.65411 .51797 Mdot
.28377 .56528 Mdot
.51564 .37986 Mdot
.59405 .69139 Mdot
.65765 .47125 Mdot
.4685 .57237 Mdot
.34463 .39973 Mdot
.6697 .23104 Mdot
.29431 .61014 Mdot
.6062 .47746 Mdot
.32016 .37752 Mdot
.46983 .5469 Mdot
.34779 .34021 Mdot
.51436 .31026 Mdot
.30896 .55431 Mdot
.30913 .40783 Mdot
.50143 .56954 Mdot
.44777 .70573 Mdot
.31893 .55057 Mdot
.27978 .56625 Mdot
.65982 .53642 Mdot
.47567 .59193 Mdot
.47489 .54444 Mdot
.54426 .31454 Mdot
.32721 .41231 Mdot
.64306 .52748 Mdot
.56773 .73151 Mdot
.60584 .48689 Mdot
.32341 .41449 Mdot
.6192 .17445 Mdot
.67261 .49416 Mdot
.63286 .50044 Mdot
.78016 .37913 Mdot
.53065 .33944 Mdot
.54555 .29363 Mdot
.61208 .70919 Mdot
.68425 .54446 Mdot
.71878 .51901 Mdot
.50967 .31332 Mdot
.50443 .32404 Mdot
.71858 .52014 Mdot
.66035 .53555 Mdot
.45436 .31867 Mdot
.33627 .40412 Mdot
.33427 .38386 Mdot
.49084 .33411 Mdot
.6271 .51059 Mdot
.31563 .37202 Mdot
.59187 .36929 Mdot
.3227 .56452 Mdot
.64977 .68807 Mdot
.49771 .33222 Mdot
.59104 .68819 Mdot
.33413 .40976 Mdot
.63386 .74222 Mdot
.66596 .67857 Mdot
.61785 .43866 Mdot
.62589 .47578 Mdot
.46311 .6732 Mdot
.49747 .58085 Mdot
.48283 .58435 Mdot
.31487 .40128 Mdot
.69456 .49987 Mdot
.52288 .31057 Mdot
.68946 .52902 Mdot
.54443 .76318 Mdot
.65456 .74012 Mdot
.77656 .48098 Mdot
.51223 .32176 Mdot
.52393 .3218 Mdot
.32566 .599 Mdot
.3056 .62211 Mdot
.63223 .43727 Mdot
.34459 .39672 Mdot
.48205 .32935 Mdot
.32118 .41738 Mdot
.30596 .57345 Mdot
.30547 .59652 Mdot
.4889 .60037 Mdot
.50592 .56242 Mdot
.30108 .57965 Mdot
.28867 .46929 Mdot
.56842 .7312 Mdot
.54972 .33657 Mdot
.66885 .21843 Mdot
.62226 .75967 Mdot
.76032 .34431 Mdot
.4623 .70128 Mdot
.53609 .51399 Mdot
.31712 .37918 Mdot
.6821 .51004 Mdot
.64595 .49389 Mdot
.50461 .59416 Mdot
.33327 .37443 Mdot
.48029 .68083 Mdot
.33157 .38408 Mdot
.44755 .70325 Mdot
.2717 .56202 Mdot
.64193 .45923 Mdot
.66707 .49413 Mdot
.31239 .42418 Mdot
.32772 .59346 Mdot
.28613 .56564 Mdot
.46614 .70342 Mdot
.60687 .7631 Mdot
.30598 .568 Mdot
.49922 .33186 Mdot
.54422 .24246 Mdot
.50336 .60266 Mdot
.64993 .47489 Mdot
.58282 .76853 Mdot
.57805 .46712 Mdot
.51457 .61079 Mdot
.50684 .58324 Mdot
.65471 .20344 Mdot
.66406 .47867 Mdot
.2616 .29538 Mdot
.48466 .59456 Mdot
.53985 .33098 Mdot
.29816 .58784 Mdot
.50041 .61353 Mdot
.46783 .59156 Mdot
.49547 .66384 Mdot
.50609 .61508 Mdot
.50244 .34209 Mdot
.51447 .3439 Mdot
.7139 .54797 Mdot
.67564 .22212 Mdot
.45173 .68853 Mdot
.48434 .6879 Mdot
.27368 .59166 Mdot
.30693 .47418 Mdot
.67232 .45129 Mdot
.485 .68153 Mdot
.47232 .29321 Mdot
.646 .52553 Mdot
.72195 .5457 Mdot
.71046 .55083 Mdot
.55181 .30898 Mdot
.58446 .46437 Mdot
.28152 .59952 Mdot
.50648 .31978 Mdot
.71162 .54502 Mdot
.65125 .52207 Mdot
.51924 .30953 Mdot
.31873 .40942 Mdot
.7576 .53014 Mdot
.4865 .32633 Mdot
.69184 .61982 Mdot
.34165 .40749 Mdot
.71845 .5428 Mdot
.35322 .76997 Mdot
.5417 .84794 Mdot
.33084 .38591 Mdot
.29096 .55797 Mdot
.29608 .56576 Mdot
.31617 .57353 Mdot
.54694 .3051 Mdot
.31168 .60553 Mdot
.53566 .31974 Mdot
.28435 .45821 Mdot
.65833 .65701 Mdot
.45888 .68602 Mdot
.24595 .56579 Mdot
.48977 .33276 Mdot
.66331 .2256 Mdot
.88156 .46136 Mdot
.60174 .47127 Mdot
.31501 .42851 Mdot
.48462 .67362 Mdot
.58194 .69752 Mdot
.46889 .67062 Mdot
.28922 .57736 Mdot
.64987 .66024 Mdot
.65952 .48359 Mdot
.31876 .2835 Mdot
.46549 .69863 Mdot
.5032 .32524 Mdot
.66262 .53943 Mdot
.32304 .61145 Mdot
.47802 .70378 Mdot
.47012 .69299 Mdot
.64639 .48084 Mdot
.53179 .33726 Mdot
.28675 .5736 Mdot
.34296 .37893 Mdot
.37379 .5523 Mdot
.55184 .53126 Mdot
.66286 .47245 Mdot
.6418 .50781 Mdot
.6027 .6877 Mdot
.28667 .47203 Mdot
.33943 .39915 Mdot
.53169 .75317 Mdot
.30592 .61405 Mdot
.55195 .76697 Mdot
.49705 .37749 Mdot
.24738 .563 Mdot
.50835 .60214 Mdot
.50115 .60896 Mdot
.63889 .4668 Mdot
.86579 .49527 Mdot
.75244 .4966 Mdot
.31149 .3742 Mdot
.5018 .59829 Mdot
.32911 .59461 Mdot
.54586 .28956 Mdot
.42819 .5461 Mdot
.69806 .54692 Mdot
.34416 .37955 Mdot
.31185 .57325 Mdot
.85607 .54853 Mdot
.45787 .67355 Mdot
.58565 .70193 Mdot
.62344 .44869 Mdot
.6415 .47073 Mdot
.32269 .3949 Mdot
.29371 .41529 Mdot
.67052 .24733 Mdot
.43238 .69285 Mdot
.31294 .26635 Mdot
.28269 .41381 Mdot
.85948 .55844 Mdot
.49893 .55351 Mdot
.52981 .31711 Mdot
.48273 .57813 Mdot
.29155 .41512 Mdot
.64394 .48952 Mdot
.53248 .33774 Mdot
.48977 .583 Mdot
.47343 .3008 Mdot
.72501 .54568 Mdot
.56353 .72167 Mdot
.62462 .46112 Mdot
.49081 .35159 Mdot
.51108 .31539 Mdot
.48614 .36116 Mdot
.49458 .60193 Mdot
.63587 .49712 Mdot
.60497 .47477 Mdot
.63983 .50526 Mdot
.67094 .25567 Mdot
.64306 .46282 Mdot
.48817 .37508 Mdot
.60364 .71745 Mdot
.18078 .57828 Mdot
.66588 .49592 Mdot
.31101 .40332 Mdot
.63331 .46318 Mdot
.44609 .68816 Mdot
.6751 .51114 Mdot
.72758 .5447 Mdot
.33488 .40011 Mdot
.78084 .41018 Mdot
.48464 .64946 Mdot
.66443 .47338 Mdot
.45122 .71073 Mdot
.41478 .29341 Mdot
.53319 .75086 Mdot
.65694 .25343 Mdot
.48817 .32913 Mdot
.29146 .5393 Mdot
.28801 .40241 Mdot
.30669 .60083 Mdot
.68079 .55164 Mdot
.48176 .56755 Mdot
.27989 .73678 Mdot
.58142 .73855 Mdot
.64182 .48876 Mdot
.51952 .56462 Mdot
.50189 .30647 Mdot
.29014 .60464 Mdot
.73144 .31524 Mdot
.63589 .51819 Mdot
.46378 .66093 Mdot
.4628 .66605 Mdot
.5435 .583 Mdot
.49085 .36644 Mdot
.65471 .26759 Mdot
.32457 .39492 Mdot
.31038 .56423 Mdot
.49114 .69912 Mdot
.46459 .29046 Mdot
.30451 .4254 Mdot
.28719 .46234 Mdot
.30852 .41191 Mdot
.65879 .50286 Mdot
.48877 .60461 Mdot
.43569 .29942 Mdot
.51366 .596 Mdot
.63867 .51305 Mdot
.27977 .56748 Mdot
.5085 .60387 Mdot
.46219 .6784 Mdot
.31149 .4087 Mdot
.29975 .59598 Mdot
.63931 .48036 Mdot
.5096 .31032 Mdot
.62004 .58404 Mdot
.30181 .52828 Mdot
.72519 .55134 Mdot
.72517 .55139 Mdot
.55573 .33372 Mdot
.48248 .55061 Mdot
.38518 .38559 Mdot
.57634 .47048 Mdot
.33447 .49387 Mdot
.5044 .53056 Mdot
.22361 .57751 Mdot
.28515 .54551 Mdot
.30796 .58396 Mdot
.66113 .49323 Mdot
.26271 .58866 Mdot
.65389 .44674 Mdot
.30969 .61718 Mdot
.4354 .27196 Mdot
.69402 .5351 Mdot
.3146 .58277 Mdot
.48613 .57394 Mdot
.61941 .44502 Mdot
.50788 .30272 Mdot
.27781 .54758 Mdot
.61718 .43882 Mdot
.21733 .6301 Mdot
.31476 .42525 Mdot
.49533 .60328 Mdot
.57359 .65958 Mdot
.32843 .40709 Mdot
.52193 .3362 Mdot
.67104 .46652 Mdot
.48676 .68284 Mdot
.52661 .32342 Mdot
.53595 .59429 Mdot
.46744 .69099 Mdot
.57963 .70867 Mdot
.51365 .33431 Mdot
.5064 .60134 Mdot
.45646 .66524 Mdot
.50258 .62694 Mdot
.30958 .58172 Mdot
.33126 .55573 Mdot
.51587 .58764 Mdot
.65911 .48684 Mdot
.32843 .60153 Mdot
.31667 .38885 Mdot
.64784 .45613 Mdot
.29644 .56277 Mdot
.49276 .59299 Mdot
.60671 .4586 Mdot
.6859 .54517 Mdot
.66316 .23823 Mdot
.50607 .54879 Mdot
.45964 .68288 Mdot
.48195 .35883 Mdot
.61759 .48815 Mdot
.44911 .69725 Mdot
.31129 .53562 Mdot
.6025 .47583 Mdot
.47877 .33175 Mdot
.58084 .39539 Mdot
.28028 .61015 Mdot
.34772 .40332 Mdot
.31294 .55084 Mdot
.46649 .71591 Mdot
.88806 .44657 Mdot
.48409 .58874 Mdot
.60147 .49788 Mdot
.66184 .51269 Mdot
.28599 .53979 Mdot
.51458 .31377 Mdot
.32968 .25417 Mdot
.67863 .5085 Mdot
.59849 .46864 Mdot
.64821 .4772 Mdot
.35139 .53268 Mdot
.54665 .31601 Mdot
.64956 .47645 Mdot
.52786 .53031 Mdot
.64846 .51256 Mdot
.46841 .70993 Mdot
.3153 .76015 Mdot
.51184 .60893 Mdot
.59504 .15482 Mdot
.48848 .58644 Mdot
.31867 .58212 Mdot
.69233 .61918 Mdot
.57086 .65901 Mdot
.35596 .59997 Mdot
.52485 .33565 Mdot
.45188 .2857 Mdot
.30653 .59572 Mdot
.29875 .50608 Mdot
.70357 .54643 Mdot
.6648 .53948 Mdot
.63324 .44448 Mdot
.28931 .5776 Mdot
.26987 .59537 Mdot
.48487 .56331 Mdot
.52213 .57306 Mdot
.5866 .44534 Mdot
.28975 .55104 Mdot
.6437 .46145 Mdot
.58779 .48786 Mdot
.3072 .42775 Mdot
.48314 .31823 Mdot
.30231 .41981 Mdot
.31992 .43096 Mdot
.75454 .33667 Mdot
.61022 .6929 Mdot
.30866 .38548 Mdot
.30612 .38073 Mdot
.31457 .49429 Mdot
.74438 .35584 Mdot
.4647 .7108 Mdot
.75071 .4963 Mdot
.32231 .59879 Mdot
.63307 .4955 Mdot
.54737 .31611 Mdot
.52597 .56438 Mdot
.36095 .2332 Mdot
.76166 .66525 Mdot
.64695 .52706 Mdot
.30933 .61096 Mdot
.51672 .58956 Mdot
.5201 .58843 Mdot
.55597 .76611 Mdot
.64551 .46516 Mdot
.27481 .60518 Mdot
.73463 .3531 Mdot
.28484 .42632 Mdot
.2852 .46609 Mdot
.49337 .3632 Mdot
.6336 .4615 Mdot
.54397 .30573 Mdot
.35225 .39295 Mdot
.452 .6984 Mdot
.45757 .67671 Mdot
.66508 .47408 Mdot
.73402 .54583 Mdot
.3385 .49549 Mdot
.68004 .54474 Mdot
.66223 .53505 Mdot
.51064 .59059 Mdot
.63342 .52547 Mdot
.60829 .47995 Mdot
.66627 .53127 Mdot
.51839 .60818 Mdot
.3063 .42569 Mdot
.73536 .3337 Mdot
.51756 .57797 Mdot
.68071 .48299 Mdot
.35227 .397 Mdot
.69002 .54689 Mdot
.31947 .39092 Mdot
.28873 .47525 Mdot
.30258 .39445 Mdot
.45533 .68242 Mdot
.28624 .61765 Mdot
.67179 .23486 Mdot
.48442 .33194 Mdot
.34154 .38613 Mdot
.45102 .66724 Mdot
.31495 .3933 Mdot
.32471 .59194 Mdot
.29541 .44192 Mdot
.55763 .35547 Mdot
.56264 .71417 Mdot
.76357 .35492 Mdot
.28396 .42137 Mdot
.28315 .61162 Mdot
.49055 .33486 Mdot
.30691 .47202 Mdot
.68076 .50048 Mdot
.45568 .67564 Mdot
.6387 .46805 Mdot
.31331 .40941 Mdot
.31836 .60599 Mdot
.65614 .24835 Mdot
.45948 .68152 Mdot
.66607 .2156 Mdot
.2899 .54885 Mdot
.67097 .50421 Mdot
.35226 .40689 Mdot
.36565 .43504 Mdot
.32919 .42417 Mdot
.66067 .66433 Mdot
.48309 .55815 Mdot
.43421 .72955 Mdot
.52103 .32782 Mdot
.49431 .55239 Mdot
.63855 .80309 Mdot
.40889 .34082 Mdot
.5223 .30105 Mdot
.28278 .53424 Mdot
.66188 .4772 Mdot
.62689 .5202 Mdot
.49644 .56482 Mdot
.48105 .34653 Mdot
.62921 .52017 Mdot
.49335 .60521 Mdot
.61171 .71691 Mdot
.49107 .36377 Mdot
.31964 .54971 Mdot
.62468 .44545 Mdot
.34142 .42491 Mdot
.35032 .40539 Mdot
.485 .59897 Mdot
.30237 .41551 Mdot
.67728 .47545 Mdot
.50504 .33531 Mdot
.71133 .54826 Mdot
.47534 .70883 Mdot
.42794 .33462 Mdot
.53194 .58207 Mdot
.46636 .6532 Mdot
.60371 .45516 Mdot
.30366 .5949 Mdot
.24225 .36362 Mdot
.67947 .5209 Mdot
.50738 .31629 Mdot
.66692 .50963 Mdot
.63093 .52274 Mdot
.67149 .54202 Mdot
.31019 .56434 Mdot
.59397 .68975 Mdot
.64263 .46121 Mdot
.34815 .38478 Mdot
.72101 .52331 Mdot
.69094 .51333 Mdot
.43007 .69754 Mdot
.72635 .54443 Mdot
.35386 .37921 Mdot
.54655 .34175 Mdot
.30124 .59156 Mdot
.52495 .31329 Mdot
.4994 .29564 Mdot
.52283 .33558 Mdot
.50581 .36747 Mdot
.57658 .46839 Mdot
.26147 .29094 Mdot
.65576 .27333 Mdot
.76734 .3546 Mdot
.50929 .2921 Mdot
.20345 .39737 Mdot
.52077 .30027 Mdot
.52284 .33601 Mdot
.44542 .20322 Mdot
.53322 .33306 Mdot
.65502 .48808 Mdot
.66023 .50792 Mdot
.78192 .43986 Mdot
.37583 .55323 Mdot
.60805 .46145 Mdot
.51691 .611 Mdot
.48151 .66907 Mdot
.49258 .37104 Mdot
.50391 .58011 Mdot
.58018 .69821 Mdot
.49019 .61039 Mdot
.64582 .48091 Mdot
.63591 .45272 Mdot
.69548 .54956 Mdot
.67002 .73616 Mdot
.38487 .56261 Mdot
.50466 .34572 Mdot
.69262 .50985 Mdot
.36071 .34578 Mdot
.63825 .44782 Mdot
.66849 .51516 Mdot
.58398 .46741 Mdot
.3013 .5928 Mdot
.54774 .28899 Mdot
.50629 .55979 Mdot
.42463 .33702 Mdot
.62031 .45776 Mdot
.52886 .56034 Mdot
.4852 .66537 Mdot
.65077 .47119 Mdot
.52411 .33894 Mdot
.63033 .52179 Mdot
.53596 .28927 Mdot
.51934 .33201 Mdot
.60028 .47255 Mdot
.48995 .36841 Mdot
.54245 .28777 Mdot
.66569 .53951 Mdot
.3221 .60833 Mdot
.42737 .28454 Mdot
.65816 .48277 Mdot
.46468 .68032 Mdot
.62923 .48013 Mdot
.46605 .71193 Mdot
.50361 .61465 Mdot
.51301 .59202 Mdot
.7385 .43063 Mdot
.26731 .57184 Mdot
.44247 .66985 Mdot
.25655 .57802 Mdot
.68019 .4665 Mdot
.47846 .29188 Mdot
.29333 .43535 Mdot
.25779 .53962 Mdot
.51065 .59232 Mdot
.52296 .73301 Mdot
.71163 .4986 Mdot
.2999 .40057 Mdot
.51912 .29608 Mdot
.72352 .33455 Mdot
.50557 .55271 Mdot
.32163 .55228 Mdot
.31955 .56097 Mdot
.40303 .36168 Mdot
.46095 .20482 Mdot
.66559 .49503 Mdot
.51163 .55529 Mdot
.5582 .48806 Mdot
.49636 .58118 Mdot
.48856 .56163 Mdot
.28016 .56406 Mdot
.6087 .45792 Mdot
.61719 .71732 Mdot
.29796 .56827 Mdot
.48019 .69107 Mdot
.5381 .30523 Mdot
.4482 .70069 Mdot
.3622 .26405 Mdot
.67094 .24508 Mdot
.30002 .57631 Mdot
.51851 .6042 Mdot
.62718 .49332 Mdot
.53796 .33432 Mdot
.53041 .26639 Mdot
.49962 .30543 Mdot
.48734 .69461 Mdot
.26529 .56759 Mdot
.22004 .65078 Mdot
.63125 .4741 Mdot
.50692 .32896 Mdot
.4886 .66037 Mdot
.62157 .47412 Mdot
.34385 .39291 Mdot
.63193 .52132 Mdot
.49896 .329 Mdot
.60029 .49543 Mdot
.52122 .32834 Mdot
.32147 .57037 Mdot
.66677 .48081 Mdot
.65425 .45833 Mdot
.5295 .74901 Mdot
.47954 .67938 Mdot
.52941 .28821 Mdot
.61276 .68159 Mdot
.64795 .51735 Mdot
.56653 .76808 Mdot
.64699 .46034 Mdot
.76518 .35827 Mdot
.4706 .58379 Mdot
.49367 .607 Mdot
.66493 .51124 Mdot
.65744 .47919 Mdot
.53365 .26822 Mdot
.65709 .27828 Mdot
.6715 .25466 Mdot
.34892 .40346 Mdot
.51497 .29952 Mdot
.29464 .56999 Mdot
.27461 .54861 Mdot
.31068 .60346 Mdot
.47804 .71263 Mdot
.70195 .54823 Mdot
.65489 .49686 Mdot
.32881 .37044 Mdot
.47997 .67131 Mdot
.51496 .32394 Mdot
.45758 .69098 Mdot
.60258 .6937 Mdot
.46738 .67766 Mdot
.48158 .57531 Mdot
.16465 .47407 Mdot
.58709 .48752 Mdot
.47431 .68775 Mdot
.4809 .32267 Mdot
.72609 .52301 Mdot
.59724 .44978 Mdot
.66522 .22993 Mdot
.46792 .66084 Mdot
.28772 .53137 Mdot
.60842 .45163 Mdot
.65829 .64143 Mdot
.31761 .39515 Mdot
.44688 .699 Mdot
.30777 .41233 Mdot
.6446 .52674 Mdot
.46875 .26082 Mdot
.4997 .32016 Mdot
.30452 .42752 Mdot
.66352 .51611 Mdot
.44677 .69831 Mdot
.30373 .57886 Mdot
.74336 .3562 Mdot
.29117 .46508 Mdot
.51284 .54523 Mdot
.55428 .76348 Mdot
.27907 .59806 Mdot
.7562 .36963 Mdot
.30314 .40663 Mdot
.69629 .52555 Mdot
.59486 .49119 Mdot
.62007 .49416 Mdot
.28574 .56879 Mdot
.30781 .58474 Mdot
.24393 .54236 Mdot
.65724 .46018 Mdot
.58542 .46309 Mdot
.53837 .35297 Mdot
.2633 .57231 Mdot
.52279 .33518 Mdot
.48568 .35211 Mdot
.29077 .55862 Mdot
.52048 .29226 Mdot
.46826 .6924 Mdot
.63285 .6918 Mdot
.3031 .40397 Mdot
.34262 .41492 Mdot
.29994 .57844 Mdot
.27444 .58319 Mdot
.30361 .59555 Mdot
.63021 .51774 Mdot
.51914 .33369 Mdot
.66702 .46716 Mdot
.63227 .46605 Mdot
.5961 .4535 Mdot
.4999 .35414 Mdot
.68033 .50563 Mdot
.70461 .53068 Mdot
.48876 .67706 Mdot
.31769 .58624 Mdot
.32658 .41683 Mdot
.62046 .58763 Mdot
.34869 .38364 Mdot
.64661 .51352 Mdot
.43496 .27595 Mdot
.52379 .29654 Mdot
.46658 .67125 Mdot
.72806 .54762 Mdot
.4598 .67808 Mdot
.30758 .42805 Mdot
.53534 .35605 Mdot
.58388 .71221 Mdot
.66895 .4745 Mdot
.60693 .68739 Mdot
.42715 .77704 Mdot
.51243 .38727 Mdot
.32613 .41117 Mdot
.60194 .49161 Mdot
.48506 .60287 Mdot
.57352 .4562 Mdot
.65861 .49481 Mdot
.69221 .51589 Mdot
.65015 .63282 Mdot
.65223 .51251 Mdot
.47506 .33342 Mdot
.71361 .5295 Mdot
.52507 .59327 Mdot
.60241 .45101 Mdot
.27288 .2934 Mdot
.60894 .46738 Mdot
.6656 .47037 Mdot
.6449 .49614 Mdot
.6723 .52621 Mdot
.5039 .3523 Mdot
.71669 .54971 Mdot
.35065 .39002 Mdot
.63285 .69256 Mdot
.30416 .40018 Mdot
.29526 .58052 Mdot
.51906 .55635 Mdot
.55379 .31214 Mdot
.46045 .67743 Mdot
.38989 .53049 Mdot
.66094 .64637 Mdot
.32589 .59848 Mdot
.52006 .74344 Mdot
.44165 .68511 Mdot
.48874 .56458 Mdot
.46305 .71698 Mdot
.28269 .56594 Mdot
.33962 .38905 Mdot
.67087 .49289 Mdot
.49902 .34058 Mdot
.48584 .32488 Mdot
.60341 .45109 Mdot
.42 .29458 Mdot
.34727 .40899 Mdot
.24359 .57162 Mdot
.66103 .49942 Mdot
.65402 .51802 Mdot
.53963 .29084 Mdot
.30122 .60834 Mdot
.71144 .50155 Mdot
.4699 .70557 Mdot
.63493 .44766 Mdot
.52437 .58922 Mdot
.60334 .69252 Mdot
.34972 .40134 Mdot
.49577 .59796 Mdot
.62016 .48422 Mdot
.60369 .70085 Mdot
.61186 .50519 Mdot
.53178 .5291 Mdot
.30638 .62116 Mdot
.59862 .46814 Mdot
.65 .45436 Mdot
.49176 .36337 Mdot
.30277 .40918 Mdot
.51436 .31167 Mdot
.55644 .34369 Mdot
.51232 .59224 Mdot
.32299 .42533 Mdot
.66773 .52545 Mdot
.3094 .3719 Mdot
.63574 .52442 Mdot
.6358 .47387 Mdot
.32335 .41051 Mdot
.53017 .32817 Mdot
.3171 .26583 Mdot
.73407 .333 Mdot
.65014 .5301 Mdot
.62697 .47978 Mdot
.37614 .55386 Mdot
.52639 .56489 Mdot
.67581 .48911 Mdot
.48269 .32889 Mdot
.62246 .47299 Mdot
.29682 .38412 Mdot
.4527 .69239 Mdot
.50522 .3145 Mdot
.29869 .61048 Mdot
.31791 .5662 Mdot
.31196 .62389 Mdot
.48174 .57195 Mdot
.6344 .52618 Mdot
.48272 .3589 Mdot
.48281 .35404 Mdot
.60384 .66675 Mdot
.31834 .58245 Mdot
.4591 .6999 Mdot
.62771 .44254 Mdot
.51871 .56188 Mdot
.34972 .41441 Mdot
.59075 .15166 Mdot
.58762 .71241 Mdot
.49322 .68925 Mdot
.55208 .54079 Mdot
.50705 .5897 Mdot
.63392 .50038 Mdot
.44709 .69502 Mdot
.2919 .5596 Mdot
.62016 .51562 Mdot
.51341 .53086 Mdot
.28545 .53101 Mdot
.28861 .59599 Mdot
.3173 .36946 Mdot
.30129 .61647 Mdot
.44685 .70592 Mdot
.48368 .58705 Mdot
.4958 .31608 Mdot
.6489 .46768 Mdot
.51279 .57416 Mdot
.32206 .58534 Mdot
.49835 .55512 Mdot
.66424 .50316 Mdot
.53886 .29445 Mdot
.31743 .60017 Mdot
.64838 .48479 Mdot
.57695 .47822 Mdot
.66346 .24032 Mdot
.31623 .60937 Mdot
.66316 .45654 Mdot
.44215 .53468 Mdot
.29197 .59599 Mdot
.28256 .56955 Mdot
.60536 .47917 Mdot
.44425 .68563 Mdot
.62592 .45798 Mdot
.34236 .39404 Mdot
.59965 .68513 Mdot
.31319 .42451 Mdot
.55558 .76791 Mdot
.59922 .45636 Mdot
.58039 .44239 Mdot
.4752 .29767 Mdot
.46946 .64594 Mdot
.61904 .76114 Mdot
.61761 .48744 Mdot
.53988 .27925 Mdot
.59242 .68756 Mdot
.56409 .70338 Mdot
.57284 .36091 Mdot
.45536 .70841 Mdot
.31494 .40035 Mdot
.65918 .4654 Mdot
.2855 .29403 Mdot
.46233 .70799 Mdot
.55729 .76704 Mdot
.68418 .50626 Mdot
.50867 .32219 Mdot
.66371 .49486 Mdot
.49417 .32059 Mdot
.62369 .48294 Mdot
.65835 .24119 Mdot
.33817 .49518 Mdot
.66066 .66351 Mdot
.4878 .5713 Mdot
.36578 .43485 Mdot
.76404 .35479 Mdot
.46494 .69479 Mdot
.59895 .49251 Mdot
.50219 .59106 Mdot
.33095 .38403 Mdot
.27876 .34844 Mdot
.30677 .59668 Mdot
.34379 .38167 Mdot
.53184 .31358 Mdot
.33072 .59274 Mdot
.49347 .55312 Mdot
.58011 .4402 Mdot
.44568 .69466 Mdot
.32451 .42528 Mdot
.65409 .47277 Mdot
.62885 .50556 Mdot
.34782 .52952 Mdot
.32737 .76785 Mdot
.47119 .34688 Mdot
.66488 .21059 Mdot
.53579 .35557 Mdot
.48295 .68466 Mdot
.32397 .60679 Mdot
.64271 .49087 Mdot
.61695 .45372 Mdot
.28736 .59622 Mdot
.54083 .33274 Mdot
.44244 .67308 Mdot
.43426 .73055 Mdot
.31247 .37359 Mdot
.37661 .79023 Mdot
.50321 .31428 Mdot
.3743 .78918 Mdot
.21872 .59516 Mdot
.50291 .21644 Mdot
.61143 .76256 Mdot
.33267 .40501 Mdot
.37572 .7902 Mdot
.50792 .32525 Mdot
.65081 .50618 Mdot
.507 .59879 Mdot
.48155 .56662 Mdot
.54167 .30046 Mdot
.29078 .58172 Mdot
.44203 .69299 Mdot
.66322 .49082 Mdot
.53082 .51479 Mdot
.53026 .26558 Mdot
.27058 .56253 Mdot
.49819 .57538 Mdot
.33312 .41507 Mdot
.62339 .4766 Mdot
.48928 .68493 Mdot
.33242 .40369 Mdot
.50364 .60959 Mdot
.64804 .66238 Mdot
.67032 .46538 Mdot
.73156 .54826 Mdot
.32 .39341 Mdot
.55224 .54915 Mdot
.64869 .45531 Mdot
.30317 .40686 Mdot
.48572 .61 Mdot
.38942 .38246 Mdot
.69824 .47636 Mdot
.4088 .34106 Mdot
.33057 .56673 Mdot
.31193 .61598 Mdot
.24646 .64437 Mdot
.36355 .60687 Mdot
.31122 .38665 Mdot
.51037 .57978 Mdot
.30649 .75615 Mdot
.30353 .41327 Mdot
.67518 .5185 Mdot
.66109 .47108 Mdot
.73378 .35269 Mdot
.50882 .60952 Mdot
.48732 .58607 Mdot
.48309 .24248 Mdot
.69063 .54011 Mdot
.49988 .57538 Mdot
.64596 .45627 Mdot
.51053 .3451 Mdot
.3368 .40957 Mdot
.77876 .6987 Mdot
.28721 .41097 Mdot
.64953 .53834 Mdot
.3219 .60024 Mdot
.33149 .57088 Mdot
.64926 .47064 Mdot
.43583 .52371 Mdot
.85984 .55377 Mdot
.66081 .46977 Mdot
.72815 .54722 Mdot
.55079 .76652 Mdot
.60017 .4528 Mdot
.48738 .3101 Mdot
.51496 .60377 Mdot
.49406 .35596 Mdot
.32689 .40534 Mdot
.45591 .70839 Mdot
.48075 .64125 Mdot
.31571 .39982 Mdot
.61323 .46012 Mdot
.53038 .59605 Mdot
.64326 .47284 Mdot
.64799 .50233 Mdot
.59906 .70033 Mdot
.49075 .69725 Mdot
.29669 .59128 Mdot
.45683 .6791 Mdot
.52668 .33537 Mdot
.63214 .1828 Mdot
.46157 .69417 Mdot
.7437 .35569 Mdot
.60749 .68118 Mdot
.31345 .75794 Mdot
.4878 .32192 Mdot
.47285 .71127 Mdot
.31313 .40088 Mdot
.57297 .67143 Mdot
.75938 .38349 Mdot
.34499 .38111 Mdot
.64465 .49966 Mdot
.49292 .35338 Mdot
.55079 .34014 Mdot
.35504 .3965 Mdot
.5012 .30861 Mdot
.67524 .44912 Mdot
.67379 .53821 Mdot
.35117 .38981 Mdot
.64589 .75057 Mdot
.33386 .42295 Mdot
.74635 .32899 Mdot
.64371 .52935 Mdot
.50633 .31565 Mdot
.77383 .36116 Mdot
.53695 .35872 Mdot
.48835 .59832 Mdot
.6755 .50355 Mdot
.46075 .69752 Mdot
.60845 .67328 Mdot
.30582 .61241 Mdot
.51434 .37943 Mdot
.49259 .33145 Mdot
.354 .41073 Mdot
.50059 .30954 Mdot
.52063 .29481 Mdot
.30665 .4287 Mdot
.51794 .2991 Mdot
.61966 .45758 Mdot
.67752 .22768 Mdot
.50065 .30647 Mdot
.32644 .39689 Mdot
.48672 .69383 Mdot
.48044 .32152 Mdot
.28995 .5065 Mdot
.62164 .44583 Mdot
.30213 .54146 Mdot
.46891 .72824 Mdot
.50558 .35023 Mdot
.46454 .69692 Mdot
.3215 .59006 Mdot
.46225 .65932 Mdot
.32814 .36335 Mdot
.33871 .36615 Mdot
.46716 .59112 Mdot
.39324 .39817 Mdot
.53236 .33335 Mdot
.3309 .59518 Mdot
.64043 .44424 Mdot
.657 .50195 Mdot
.48646 .71597 Mdot
.53381 .28562 Mdot
.41859 .29144 Mdot
.50321 .57858 Mdot
.42848 .33569 Mdot
.34893 .40552 Mdot
.24474 .5685 Mdot
.58314 .71373 Mdot
.2892 .4534 Mdot
.52523 .59383 Mdot
.50635 .59089 Mdot
.64888 .47759 Mdot
.53361 .75272 Mdot
.44869 .70715 Mdot
.19584 .41381 Mdot
.62639 .5118 Mdot
.28312 .59476 Mdot
.6304 .49012 Mdot
.7042 .54354 Mdot
.61378 .48476 Mdot
.49319 .69333 Mdot
.32724 .37521 Mdot
.48366 .33124 Mdot
.46928 .71243 Mdot
.31739 .56489 Mdot
.68834 .63739 Mdot
.6749 .48496 Mdot
.64895 .44253 Mdot
.28938 .58898 Mdot
.51415 .33916 Mdot
.3009 .58405 Mdot
.30328 .40386 Mdot
.46075 .69134 Mdot
.62833 .51875 Mdot
.5096 .60927 Mdot
.28451 .54025 Mdot
.3397 .38422 Mdot
.32504 .60748 Mdot
.28818 .39175 Mdot
.50872 .59309 Mdot
.63242 .43303 Mdot
.27077 .6017 Mdot
.51992 .57225 Mdot
.68632 .3438 Mdot
.64768 .6581 Mdot
.57752 .31447 Mdot
.28866 .58094 Mdot
.3535 .59464 Mdot
.33039 .40112 Mdot
.29277 .41073 Mdot
.74596 .32553 Mdot
.8626 .50184 Mdot
.71855 .51891 Mdot
.40526 .30952 Mdot
.30301 .40283 Mdot
.32692 .38983 Mdot
.30048 .58705 Mdot
.53373 .32592 Mdot
.4662 .31584 Mdot
.32927 .57597 Mdot
.58954 .76546 Mdot
.51464 .3242 Mdot
.78202 .43417 Mdot
.28109 .55041 Mdot
.66944 .54202 Mdot
.6557 .24684 Mdot
.48545 .66877 Mdot
.55002 .76008 Mdot
.29391 .43876 Mdot
.65112 .48925 Mdot
.26401 .28931 Mdot
.30909 .59537 Mdot
.50836 .55733 Mdot
.37124 .35707 Mdot
.64791 .51999 Mdot
.633 .49379 Mdot
.62032 .46482 Mdot
.45678 .7216 Mdot
.65924 .2966 Mdot
.64789 .49031 Mdot
.6538 .65933 Mdot
.69018 .55176 Mdot
.31445 .5331 Mdot
.45634 .68012 Mdot
.51774 .73964 Mdot
.3117 .50754 Mdot
.42275 .33822 Mdot
.69265 .51516 Mdot
.29423 .39361 Mdot
.7062 .54297 Mdot
.3212 .41147 Mdot
.34953 .37703 Mdot
.39677 .80739 Mdot
.47952 .33761 Mdot
.63025 .51572 Mdot
.273 .56587 Mdot
.46592 .31511 Mdot
.70749 .54519 Mdot
.64447 .19077 Mdot
.35206 .41994 Mdot
.89014 .44064 Mdot
.29441 .409 Mdot
.48966 .55798 Mdot
.53108 .30788 Mdot
.53613 .27403 Mdot
.60768 .68849 Mdot
.52458 .33394 Mdot
.37432 .59432 Mdot
.47907 .35458 Mdot
.50316 .81598 Mdot
.56154 .35875 Mdot
.33396 .39676 Mdot
.35477 .40259 Mdot
.70159 .54942 Mdot
.62789 .4553 Mdot
.61378 .71757 Mdot
.50236 .57825 Mdot
.68033 .48739 Mdot
.298 .56782 Mdot
.27064 .51801 Mdot
.25716 .34345 Mdot
.52081 .2986 Mdot
.33188 .38131 Mdot
.63284 .49277 Mdot
.64124 .52723 Mdot
.66363 .50765 Mdot
.32222 .49241 Mdot
.79156 .44476 Mdot
.63432 .46767 Mdot
.69983 .54841 Mdot
.3274 .58929 Mdot
.35063 .53237 Mdot
.47282 .20702 Mdot
.38749 .79895 Mdot
.60487 .46006 Mdot
.48208 .67769 Mdot
.48729 .70499 Mdot
.69984 .53851 Mdot
.55465 .43198 Mdot
.52507 .63928 Mdot
.65467 .47381 Mdot
.69002 .63131 Mdot
.31399 .54266 Mdot
.48377 .59915 Mdot
.32156 .58343 Mdot
.51007 .28979 Mdot
.49227 .60931 Mdot
.29341 .56373 Mdot
.65277 .68624 Mdot
.51455 .58737 Mdot
.38732 .38169 Mdot
.47587 .70893 Mdot
.64681 .4556 Mdot
.71423 .31133 Mdot
.26307 .57189 Mdot
.33963 .3935 Mdot
.52477 .30498 Mdot
.34865 .40186 Mdot
.32985 .62609 Mdot
.57324 .76998 Mdot
.49165 .60163 Mdot
.29431 .39221 Mdot
.73134 .54448 Mdot
.4793 .67216 Mdot
.29803 .41178 Mdot
.66331 .54314 Mdot
.69465 .53735 Mdot
.84716 .5449 Mdot
.63512 .44015 Mdot
.26115 .52433 Mdot
.3128 .42527 Mdot
.48712 .60691 Mdot
.64772 .46676 Mdot
.29371 .54669 Mdot
.49127 .62183 Mdot
.64283 .47421 Mdot
.28724 .60499 Mdot
.65903 .46932 Mdot
.44931 .6888 Mdot
.49188 .36044 Mdot
.58782 .68795 Mdot
.42668 .71954 Mdot
.45929 .71039 Mdot
.6615 .64291 Mdot
.67777 .49732 Mdot
.37038 .60423 Mdot
.51163 .31956 Mdot
.64624 .5129 Mdot
.50132 .79465 Mdot
.53882 .31188 Mdot
.52554 .31619 Mdot
.63167 .52687 Mdot
.28958 .39376 Mdot
.29338 .59009 Mdot
.4702 .66943 Mdot
.28518 .464 Mdot
.64775 .48687 Mdot
.60366 .49518 Mdot
.46515 .7103 Mdot
.34329 .40124 Mdot
.6394 .52289 Mdot
.38653 .34635 Mdot
.63609 .68584 Mdot
.31458 .42908 Mdot
.69218 .51826 Mdot
.79486 .42861 Mdot
.5504 .31764 Mdot
.26314 .2911 Mdot
.33863 .49513 Mdot
.31889 .56221 Mdot
.50049 .57354 Mdot
.59851 .15821 Mdot
.48687 .69605 Mdot
.48369 .37792 Mdot
.66167 .50293 Mdot
.63529 .48722 Mdot
.522 .34133 Mdot
.66266 .46207 Mdot
.52077 .29731 Mdot
.29328 .5065 Mdot
.86912 .48835 Mdot
.49014 .32147 Mdot
.49639 .32599 Mdot
.76264 .52263 Mdot
.26017 .59002 Mdot
.53726 .3033 Mdot
.65213 .45479 Mdot
.33452 .62525 Mdot
.5364 .52386 Mdot
.44653 .669 Mdot
.44856 .71712 Mdot
.48343 .3126 Mdot
.76256 .38619 Mdot
.66994 .54451 Mdot
.73448 .40443 Mdot
.52141 .6453 Mdot
.30848 .38805 Mdot
.59899 .4811 Mdot
.50403 .58336 Mdot
.31779 .59267 Mdot
.59834 .44775 Mdot
.64276 .45363 Mdot
.48348 .33703 Mdot
.47401 .65979 Mdot
.30668 .41525 Mdot
.51858 .56953 Mdot
.3297 .6241 Mdot
.47477 .69877 Mdot
.52147 .29278 Mdot
.76063 .34632 Mdot
.53085 .58349 Mdot
.5197 .56464 Mdot
.63402 .50189 Mdot
.60258 .47538 Mdot
.52762 .59182 Mdot
.31715 .40076 Mdot
.31793 .55842 Mdot
.50753 .56072 Mdot
.58727 .65911 Mdot
.62924 .71147 Mdot
.61789 .48637 Mdot
.48077 .32528 Mdot
.3316 .38294 Mdot
.48748 .59296 Mdot
.29911 .75033 Mdot
.61583 .44449 Mdot
.78377 .43542 Mdot
.43334 .70224 Mdot
.50775 .58401 Mdot
.46535 .31748 Mdot
.4625 .67326 Mdot
.64387 .52928 Mdot
.6559 .66149 Mdot
.68295 .49694 Mdot
.69624 .52518 Mdot
.28864 .56076 Mdot
.31266 .41288 Mdot
.46597 .5845 Mdot
.31657 .58761 Mdot
.5252 .31427 Mdot
.73679 .41315 Mdot
.48865 .35073 Mdot
.48032 .35134 Mdot
.50528 .36979 Mdot
.34588 .4071 Mdot
.59759 .15703 Mdot
.52918 .58255 Mdot
.66777 .49091 Mdot
.31648 .37997 Mdot
.53423 .29952 Mdot
.67985 .50895 Mdot
.52335 .29659 Mdot
.52826 .28755 Mdot
.68283 .49295 Mdot
.68499 .54507 Mdot
.65982 .6573 Mdot
.78462 .42056 Mdot
.45419 .67825 Mdot
.54038 .33115 Mdot
.77475 .40677 Mdot
.64257 .48964 Mdot
.63428 .45263 Mdot
.70711 .55006 Mdot
.46307 .71414 Mdot
.73751 .42736 Mdot
.65744 .50329 Mdot
.5276 .75322 Mdot
.67698 .51261 Mdot
.53426 .28463 Mdot
.37353 .42049 Mdot
.65294 .53992 Mdot
.32948 .5909 Mdot
.53939 .33388 Mdot
.48509 .66771 Mdot
.55192 .28417 Mdot
.57821 .46928 Mdot
.31616 .3907 Mdot
.49897 .32889 Mdot
.32736 .56812 Mdot
.34047 .39785 Mdot
.33379 .42278 Mdot
.70881 .55066 Mdot
.30975 .55177 Mdot
.47516 .65996 Mdot
.32255 .42125 Mdot
.57154 .46151 Mdot
.33537 .39622 Mdot
.60719 .38662 Mdot
.63897 .4366 Mdot
.65352 .66135 Mdot
.50213 .56486 Mdot
.46948 .58466 Mdot
.31623 .42379 Mdot
.4701 .70661 Mdot
.63849 .52217 Mdot
.50625 .30271 Mdot
.48661 .68831 Mdot
.65562 .25317 Mdot
.33198 .57533 Mdot
.54826 .34202 Mdot
.28893 .46335 Mdot
.54193 .32138 Mdot
.55287 .76195 Mdot
.48994 .67558 Mdot
.51377 .55533 Mdot
.58717 .69728 Mdot
.49446 .57809 Mdot
.60584 .44262 Mdot
.63729 .5211 Mdot
.6176 .45901 Mdot
.32197 .60083 Mdot
.4531 .71927 Mdot
.49232 .31091 Mdot
.48284 .52244 Mdot
.34485 .40289 Mdot
.7189 .53568 Mdot
.50681 .55829 Mdot
.64366 .52682 Mdot
.52959 .29939 Mdot
.5435 .28753 Mdot
.65781 .2824 Mdot
.29511 .59876 Mdot
.48477 .53267 Mdot
.61571 .48377 Mdot
.50085 .51554 Mdot
.31692 .42436 Mdot
.40752 .34558 Mdot
.30347 .53973 Mdot
.88993 .43794 Mdot
.31631 .58437 Mdot
.52758 .53568 Mdot
.54598 .30148 Mdot
.46655 .68292 Mdot
.61115 .45944 Mdot
.49351 .36501 Mdot
.46106 .32888 Mdot
.50014 .68681 Mdot
.46236 .67683 Mdot
.31124 .47624 Mdot
.30601 .38747 Mdot
.52132 .57289 Mdot
.67654 .51399 Mdot
.68254 .50531 Mdot
.64672 .44799 Mdot
.32472 .37995 Mdot
.68347 .54227 Mdot
.36203 .43769 Mdot
.58594 .4861 Mdot
.50304 .7955 Mdot
.27886 .57449 Mdot
.17884 .56878 Mdot
.50234 .35165 Mdot
.73757 .42294 Mdot
.60072 .39531 Mdot
.64518 .66148 Mdot
.32398 .37422 Mdot
.48836 .61383 Mdot
.29677 .58775 Mdot
.25322 .36311 Mdot
.2777 .57367 Mdot
.82203 .63349 Mdot
.73285 .35132 Mdot
.38072 .40712 Mdot
.68083 .49548 Mdot
.28999 .55601 Mdot
.76758 .38961 Mdot
.50909 .56215 Mdot
.52998 .59718 Mdot
.58716 .4917 Mdot
.67011 .25243 Mdot
.45263 .68018 Mdot
.60853 .46223 Mdot
.49579 .35432 Mdot
.61332 .45712 Mdot
.61058 .45877 Mdot
.66181 .50501 Mdot
.32056 .4325 Mdot
.63965 .43605 Mdot
.62406 .45577 Mdot
.22642 .67244 Mdot
.5388 .60001 Mdot
.30364 .61813 Mdot
.53877 .27318 Mdot
.47987 .67122 Mdot
.51183 .28927 Mdot
.58724 .69181 Mdot
.29326 .41399 Mdot
.657 .2846 Mdot
.66362 .53743 Mdot
.49392 .37569 Mdot
.28821 .40729 Mdot
.44449 .68102 Mdot
.50307 .58666 Mdot
.36828 .22749 Mdot
.25651 .57914 Mdot
.49236 .58951 Mdot
.29442 .60742 Mdot
.57907 .44601 Mdot
.49861 .31414 Mdot
.49531 .57811 Mdot
.31056 .41733 Mdot
.27912 .56542 Mdot
.66203 .64707 Mdot
.62541 .47141 Mdot
.28711 .57716 Mdot
.51142 .57547 Mdot
.60882 .67454 Mdot
.59388 .68767 Mdot
.28685 .55651 Mdot
.33085 .36959 Mdot
.33375 .41971 Mdot
.48439 .67484 Mdot
.54759 .29773 Mdot
.50406 .34102 Mdot
.34119 .40593 Mdot
.24698 .37158 Mdot
.64922 .48601 Mdot
.63358 .47354 Mdot
.58127 .7049 Mdot
.66542 .52055 Mdot
.38465 .57363 Mdot
.49353 .58666 Mdot
.49255 .33919 Mdot
.63828 .52171 Mdot
.64375 .52422 Mdot
.60781 .46603 Mdot
.59165 .76718 Mdot
.32114 .59917 Mdot
.68091 .54768 Mdot
.44698 .6965 Mdot
.66555 .25045 Mdot
.63312 .44587 Mdot
.44306 .66249 Mdot
.54712 .30229 Mdot
.33511 .33695 Mdot
.33847 .39204 Mdot
.26958 .5691 Mdot
.27163 .56683 Mdot
.43026 .7797 Mdot
.50698 .34808 Mdot
.49224 .58826 Mdot
.28685 .53006 Mdot
.48226 .5795 Mdot
.46533 .67556 Mdot
.70152 .47638 Mdot
.38302 .57841 Mdot
.30294 .61772 Mdot
.28093 .40345 Mdot
.64009 .51371 Mdot
.63238 .44729 Mdot
.41599 .31891 Mdot
.64542 .45904 Mdot
.45639 .69618 Mdot
.29782 .40052 Mdot
.50106 .32779 Mdot
.45108 .6783 Mdot
.29169 .3996 Mdot
.52025 .33648 Mdot
.69201 .54896 Mdot
.67906 .51069 Mdot
.52615 .30983 Mdot
.52818 .29157 Mdot
.65629 .48766 Mdot
.41414 .82233 Mdot
.48502 .33443 Mdot
.52761 .30596 Mdot
.66636 .2513 Mdot
.27574 .60552 Mdot
.4938 .62316 Mdot
.2938 .38836 Mdot
.62285 .45873 Mdot
.28008 .57975 Mdot
.47366 .67957 Mdot
.49432 .33398 Mdot
.6013 .47078 Mdot
.64348 .48445 Mdot
.48103 .67472 Mdot
.45287 .71563 Mdot
.47794 .70286 Mdot
.35494 .39556 Mdot
.66365 .53912 Mdot
.53374 .30446 Mdot
.33859 .37762 Mdot
.49033 .68605 Mdot
.44802 .7111 Mdot
.54189 .81056 Mdot
.65274 .48724 Mdot
.45798 .71901 Mdot
.62094 .17562 Mdot
.66258 .67975 Mdot
.48234 .59008 Mdot
.32536 .61439 Mdot
.34163 .62127 Mdot
.5425 .5469 Mdot
.3114 .41047 Mdot
.72275 .54444 Mdot
.44675 .67098 Mdot
.51229 .56953 Mdot
.62957 .4717 Mdot
.59347 .46162 Mdot
.48533 .68855 Mdot
.57142 .77097 Mdot
.48353 .34084 Mdot
.56284 .26748 Mdot
.47857 .67048 Mdot
.2869 .55429 Mdot
.30485 .53793 Mdot
.31058 .58317 Mdot
.61091 .48028 Mdot
.77762 .47375 Mdot
.5653 .44114 Mdot
.69325 .40525 Mdot
.3038 .39079 Mdot
.54163 .28686 Mdot
.66663 .24334 Mdot
.52535 .31816 Mdot
.30567 .60579 Mdot
.46927 .70674 Mdot
.51694 .34205 Mdot
.34526 .41222 Mdot
.32925 .4223 Mdot
.27009 .60051 Mdot
.31896 .58029 Mdot
.30181 .57749 Mdot
.54569 .33095 Mdot
.54076 .29611 Mdot
.68058 .5013 Mdot
.48605 .31909 Mdot
.29686 .50817 Mdot
.29641 .50621 Mdot
.26147 .5829 Mdot
.32225 .40049 Mdot
.51882 .33186 Mdot
.65388 .459 Mdot
.64691 .63094 Mdot
.28761 .53498 Mdot
.4767 .66375 Mdot
.67711 .22654 Mdot
.85807 .51093 Mdot
.60947 .49637 Mdot
.3119 .38922 Mdot
.48547 .57774 Mdot
.6169 .46649 Mdot
.32012 .56236 Mdot
.51777 .54584 Mdot
.51122 .60537 Mdot
.64869 .44468 Mdot
.6757 .4687 Mdot
.32665 .38481 Mdot
.58419 .6917 Mdot
.51347 .56818 Mdot
.71336 .5547 Mdot
.29906 .3923 Mdot
.28474 .54252 Mdot
.23358 .63498 Mdot
.45959 .26223 Mdot
.52834 .70018 Mdot
.49967 .60988 Mdot
.61823 .44243 Mdot
.30032 .56505 Mdot
.44812 .6805 Mdot
.30347 .56907 Mdot
.50733 .29289 Mdot
.27968 .60962 Mdot
.65533 .46349 Mdot
.53578 .30626 Mdot
.33099 .42257 Mdot
.56552 .6703 Mdot
.45682 .56814 Mdot
.29079 .54694 Mdot
.51973 .56108 Mdot
.68872 .53995 Mdot
.57123 .45004 Mdot
.46987 .58547 Mdot
.64288 .45153 Mdot
.32366 .41101 Mdot
.52431 .2984 Mdot
.34592 .39287 Mdot
.48496 .61604 Mdot
.56558 .39254 Mdot
.33737 .39015 Mdot
.77492 .48598 Mdot
.44187 .69437 Mdot
.57894 .76997 Mdot
.65778 .47433 Mdot
.31188 .41628 Mdot
.6502 .44391 Mdot
.53659 .3339 Mdot
.6424 .69592 Mdot
.63881 .67868 Mdot
.33513 .41056 Mdot
.48382 .55649 Mdot
.60753 .67949 Mdot
.49547 .62441 Mdot
.30383 .40163 Mdot
.67272 .67467 Mdot
.49738 .59511 Mdot
.47514 .69501 Mdot
.4475 .71235 Mdot
.46901 .70105 Mdot
.63185 .46728 Mdot
.7911 .40213 Mdot
.48971 .6959 Mdot
.29655 .34318 Mdot
.45243 .69872 Mdot
.54268 .54051 Mdot
.42119 .28776 Mdot
.44655 .70468 Mdot
.65197 .46615 Mdot
.5926 .4882 Mdot
.72544 .54561 Mdot
.31769 .55187 Mdot
.34665 .24345 Mdot
.22422 .66642 Mdot
.6429 .49132 Mdot
.66926 .23349 Mdot
.4884 .36232 Mdot
.51297 .55368 Mdot
.64094 .67307 Mdot
.73754 .54634 Mdot
.52931 .31926 Mdot
.58606 .69499 Mdot
.54651 .33981 Mdot
.49137 .56452 Mdot
.63526 .4716 Mdot
.53799 .33494 Mdot
.51506 .37924 Mdot
.62104 .76038 Mdot
.4252 .32733 Mdot
.51747 .33478 Mdot
.30269 .40934 Mdot
.31151 .40655 Mdot
.32714 .41161 Mdot
.31948 .57333 Mdot
.49457 .32778 Mdot
.69178 .53562 Mdot
.3203 .56619 Mdot
.64787 .50064 Mdot
.33856 .40871 Mdot
.64405 .67045 Mdot
.49741 .32612 Mdot
.65627 .47605 Mdot
.76766 .39747 Mdot
.28163 .59971 Mdot
.48301 .67806 Mdot
.67145 .22999 Mdot
.32757 .60856 Mdot
.30871 .37246 Mdot
.49543 .29986 Mdot
.53502 .60584 Mdot
.71808 .55386 Mdot
.62598 .49684 Mdot
.67169 .4914 Mdot
.72541 .55269 Mdot
.73494 .34784 Mdot
.52237 .59196 Mdot
.31753 .56543 Mdot
.28101 .60945 Mdot
.62181 .44428 Mdot
.49118 .32742 Mdot
.49005 .6662 Mdot
.44277 .66625 Mdot
.50719 .52956 Mdot
.60274 .68686 Mdot
.6535 .65947 Mdot
.67083 .52501 Mdot
.74686 .4599 Mdot
.32469 .56396 Mdot
.48003 .58123 Mdot
.60149 .69267 Mdot
.46803 .6943 Mdot
.65097 .5055 Mdot
.52059 .26881 Mdot
.49799 .33265 Mdot
.28952 .58309 Mdot
.34067 .42522 Mdot
.53111 .58665 Mdot
.26131 .5842 Mdot
.62141 .44445 Mdot
.64234 .52374 Mdot
.30217 .41489 Mdot
.49792 .29973 Mdot
.48052 .69205 Mdot
.32303 .57106 Mdot
.46675 .68674 Mdot
.50416 .30843 Mdot
.49425 .33483 Mdot
.65114 .51037 Mdot
.4864 .52955 Mdot
.28721 .54679 Mdot
.60438 .46998 Mdot
.28996 .57272 Mdot
.34654 .52852 Mdot
.35016 .41295 Mdot
.64843 .51322 Mdot
.47078 .30408 Mdot
.33908 .41037 Mdot
.64147 .49321 Mdot
.72169 .54887 Mdot
.64204 .52467 Mdot
.29079 .55493 Mdot
.43659 .67573 Mdot
.47318 .69165 Mdot
.62395 .39871 Mdot
.65263 .26464 Mdot
.66153 .52414 Mdot
.26324 .57673 Mdot
.58029 .49024 Mdot
.32532 .38755 Mdot
.54531 .31177 Mdot
.15881 .51721 Mdot
.32824 .39561 Mdot
.66044 .47456 Mdot
.46076 .69445 Mdot
.52716 .2899 Mdot
.489 .6062 Mdot
.5747 .73373 Mdot
.47204 .56632 Mdot
.49266 .52769 Mdot
.52105 .58046 Mdot
.40824 .3076 Mdot
.30182 .5747 Mdot
.53179 .29963 Mdot
.30906 .3926 Mdot
.32002 .38869 Mdot
.2986 .60781 Mdot
.65638 .25884 Mdot
.49454 .21318 Mdot
.61554 .16805 Mdot
.25813 .56298 Mdot
.46202 .70403 Mdot
.64444 .69219 Mdot
.31016 .58489 Mdot
.30652 .61381 Mdot
.32837 .49869 Mdot
.41484 .32282 Mdot
.52871 .3275 Mdot
.64269 .48512 Mdot
.66288 .2396 Mdot
.66571 .49978 Mdot
.5307 .69424 Mdot
.33879 .40606 Mdot
.5453 .31236 Mdot
.35513 .46712 Mdot
.60191 .45593 Mdot
.61889 .4795 Mdot
.28517 .50933 Mdot
.50063 .58058 Mdot
.33466 .76891 Mdot
.66942 .50511 Mdot
.31395 .57073 Mdot
.46631 .28658 Mdot
.49728 .5626 Mdot
.76932 .39791 Mdot
.30927 .42383 Mdot
.48989 .59877 Mdot
.49773 .56153 Mdot
.75006 .46727 Mdot
.54027 .34854 Mdot
.50479 .34368 Mdot
.46149 .71738 Mdot
.43706 .27547 Mdot
.30451 .42245 Mdot
.3936 .333 Mdot
.65042 .45443 Mdot
.35237 .37649 Mdot
.43381 .72904 Mdot
.64536 .49509 Mdot
.70862 .54628 Mdot
.65721 .28203 Mdot
.60616 .4866 Mdot
.57859 .4607 Mdot
.32952 .39948 Mdot
.50796 .78976 Mdot
.68752 .52663 Mdot
.28822 .57905 Mdot
.53555 .32432 Mdot
.54386 .34951 Mdot
.4546 .67048 Mdot
.34578 .49153 Mdot
.87885 .46703 Mdot
.5448 .31337 Mdot
.62533 .46877 Mdot
.32759 .3888 Mdot
.48953 .60331 Mdot
.50095 .56644 Mdot
.48831 .55091 Mdot
.50314 .33278 Mdot
.50113 .56254 Mdot
.47523 .37169 Mdot
.586 .69382 Mdot
.73715 .42012 Mdot
.3302 .4144 Mdot
.46061 .7013 Mdot
.52816 .52634 Mdot
.33138 .51281 Mdot
.67618 .51681 Mdot
.52995 .69598 Mdot
.50479 .36029 Mdot
.45806 .69874 Mdot
.61331 .46359 Mdot
.52376 .58233 Mdot
.69387 .6215 Mdot
.47393 .65253 Mdot
.52175 .58491 Mdot
.6145 .50413 Mdot
.53022 .33418 Mdot
.49056 .58683 Mdot
.50527 .32765 Mdot
.61124 .4639 Mdot
.52701 .6497 Mdot
.54208 .32768 Mdot
.33198 .25443 Mdot
.52929 .57483 Mdot
.29114 .40704 Mdot
.59037 .45341 Mdot
.6046 .45982 Mdot
.78073 .45292 Mdot
.48601 .5948 Mdot
.27549 .29151 Mdot
.2845 .57189 Mdot
.31724 .76552 Mdot
.30561 .62492 Mdot
.31556 .48496 Mdot
.37402 .34614 Mdot
.59747 .47012 Mdot
.65694 .25994 Mdot
.77886 .4667 Mdot
.32695 .37076 Mdot
.78106 .46068 Mdot
.62772 .45536 Mdot
.63351 .50107 Mdot
.28904 .57348 Mdot
.36582 .39983 Mdot
.64 .53305 Mdot
.60211 .69175 Mdot
.44409 .67997 Mdot
.51553 .31297 Mdot
.63123 .46043 Mdot
.52631 .38557 Mdot
.28243 .55653 Mdot
.57744 .30738 Mdot
.65304 .46996 Mdot
.50057 .58106 Mdot
.355 .38314 Mdot
.32819 .42409 Mdot
.29975 .55166 Mdot
.29857 .54982 Mdot
.60527 .45916 Mdot
.34714 .38646 Mdot
.68277 .51654 Mdot
.60787 .67825 Mdot
.51292 .57719 Mdot
.47064 .67384 Mdot
.66441 .46719 Mdot
.52229 .2264 Mdot
.62675 .80557 Mdot
.61188 .48096 Mdot
.49277 .3521 Mdot
.2986 .57934 Mdot
.31508 .60639 Mdot
.50444 .3404 Mdot
.31389 .60691 Mdot
.56253 .26569 Mdot
.79203 .40552 Mdot
.46451 .67818 Mdot
.56805 .48588 Mdot
.45611 .70811 Mdot
.48806 .59608 Mdot
.65398 .48715 Mdot
.21519 .38779 Mdot
.25844 .56405 Mdot
.62055 .58742 Mdot
.33978 .40152 Mdot
.48121 .56843 Mdot
.67719 .54131 Mdot
.47411 .727 Mdot
.31311 .59472 Mdot
.52508 .60469 Mdot
.65805 .50655 Mdot
.54397 .33114 Mdot
.60472 .49821 Mdot
.48997 .56052 Mdot
.48646 .58467 Mdot
.51941 .60917 Mdot
.29167 .39953 Mdot
.51355 .29988 Mdot
.31175 .47688 Mdot
.27532 .59448 Mdot
.67923 .4835 Mdot
.62293 .46803 Mdot
.54371 .29057 Mdot
.66785 .48586 Mdot
.34971 .38742 Mdot
.56846 .13863 Mdot
.47368 .70709 Mdot
.48591 .59865 Mdot
.36206 .26416 Mdot
.51784 .61221 Mdot
.62166 .51258 Mdot
.74982 .53616 Mdot
.53043 .26613 Mdot
.29003 .3994 Mdot
.69057 .49871 Mdot
.30161 .61957 Mdot
.47891 .69209 Mdot
.34582 .41264 Mdot
.67691 .53799 Mdot
.65395 .46471 Mdot
.45976 .69892 Mdot
.3594 .46003 Mdot
.43768 .68302 Mdot
.30621 .39382 Mdot
.47551 .57654 Mdot
.65142 .62831 Mdot
.64754 .4779 Mdot
.49636 .5855 Mdot
.51534 .30357 Mdot
.31084 .38518 Mdot
.66111 .30045 Mdot
.49302 .56273 Mdot
.28442 .46167 Mdot
.32161 .42538 Mdot
.63097 .50175 Mdot
.5212 .34456 Mdot
.55179 .3529 Mdot
.52297 .30051 Mdot
.4588 .79703 Mdot
.29268 .48298 Mdot
.29817 .57567 Mdot
.32278 .3989 Mdot
.28135 .58508 Mdot
.44177 .69657 Mdot
.62807 .70938 Mdot
.29465 .54829 Mdot
.47399 .33789 Mdot
.2764 .57814 Mdot
.68233 .51467 Mdot
.29049 .40998 Mdot
.28121 .54912 Mdot
.65691 .45744 Mdot
.69542 .55005 Mdot
.48957 .57853 Mdot
.48935 .66739 Mdot
.59395 .69093 Mdot
.66258 .48513 Mdot
.49982 .58906 Mdot
.65465 .4778 Mdot
.34952 .38779 Mdot
.55873 .66977 Mdot
.67622 .47349 Mdot
.2588 .56182 Mdot
.38861 .21283 Mdot
.27136 .59906 Mdot
.44553 .53306 Mdot
.64944 .4993 Mdot
.64963 .48111 Mdot
.68799 .54211 Mdot
.68389 .24806 Mdot
.33193 .36803 Mdot
.62868 .43188 Mdot
.32871 .59908 Mdot
.52381 .32398 Mdot
.50789 .34656 Mdot
.72418 .51502 Mdot
.49471 .58825 Mdot
.35356 .39474 Mdot
.64959 .48335 Mdot
.48395 .56899 Mdot
.60399 .71089 Mdot
.42826 .28674 Mdot
.30585 .50616 Mdot
.29434 .61019 Mdot
.5515 .30612 Mdot
.32461 .59718 Mdot
.67822 .53934 Mdot
.49632 .56438 Mdot
.28946 .47858 Mdot
.27369 .38398 Mdot
.47855 .69098 Mdot
.6371 .49927 Mdot
.59993 .76577 Mdot
.32739 .58851 Mdot
.31288 .55374 Mdot
.68312 .51527 Mdot
.44711 .29573 Mdot
.59496 .81028 Mdot
.32228 .37759 Mdot
.59481 .37652 Mdot
.72994 .31525 Mdot
.77432 .64297 Mdot
.31484 .39775 Mdot
.70942 .54518 Mdot
.32453 .55725 Mdot
.38893 .76706 Mdot
.52672 .32029 Mdot
.48008 .69055 Mdot
.65901 .45983 Mdot
.47582 .33953 Mdot
.25683 .56384 Mdot
.50538 .2999 Mdot
.50115 .57528 Mdot
.28886 .40893 Mdot
.31896 .5946 Mdot
.34024 .42684 Mdot
.47725 .29631 Mdot
.46559 .70704 Mdot
.52947 .74776 Mdot
.57823 .47875 Mdot
.65655 .2787 Mdot
.66963 .54133 Mdot
.54142 .59447 Mdot
.67795 .54532 Mdot
.5432 .35251 Mdot
.65728 .47296 Mdot
.69212 .51988 Mdot
.3311 .56855 Mdot
.62017 .4898 Mdot
.65366 .45684 Mdot
.7699 .40106 Mdot
.63811 .49613 Mdot
.60747 .46201 Mdot
.62638 .49804 Mdot
.4876 .34833 Mdot
.65757 .51004 Mdot
.53208 .2933 Mdot
.49635 .37883 Mdot
.27675 .59575 Mdot
.44469 .70381 Mdot
.44742 .70654 Mdot
.5343 .65491 Mdot
.59785 .76599 Mdot
.6639 .24142 Mdot
.51686 .32527 Mdot
.3193 .42419 Mdot
.68137 .50403 Mdot
.55457 .81392 Mdot
.52785 .65042 Mdot
.31294 .54581 Mdot
.27743 .55807 Mdot
.64622 .4463 Mdot
.85301 .52066 Mdot
.67179 .50431 Mdot
.58632 .71211 Mdot
.63213 .46634 Mdot
.65155 .51529 Mdot
.3084 .62298 Mdot
.55183 .76198 Mdot
.68261 .54854 Mdot
.53118 .35134 Mdot
.47911 .68675 Mdot
.49212 .58403 Mdot
.52931 .65307 Mdot
.75359 .3354 Mdot
.49492 .24164 Mdot
.68897 .54214 Mdot
.32435 .57109 Mdot
.49424 .33767 Mdot
.58293 .70398 Mdot
.33627 .37715 Mdot
.5771 .73604 Mdot
.61231 .3856 Mdot
.321 .37671 Mdot
.47616 .69479 Mdot
.28774 .53664 Mdot
.61133 .47477 Mdot
.30175 .56237 Mdot
.60059 .45827 Mdot
.59619 .71896 Mdot
.46793 .67593 Mdot
.47555 .35364 Mdot
.30146 .40964 Mdot
.48137 .3428 Mdot
.57802 .32016 Mdot
.52548 .6562 Mdot
.26994 .72798 Mdot
.26336 .58782 Mdot
.47967 .51901 Mdot
.54172 .30234 Mdot
.61423 .44501 Mdot
.61121 .16845 Mdot
.50436 .31273 Mdot
.54172 .33242 Mdot
.56229 .71932 Mdot
.55288 .77021 Mdot
.61224 .48446 Mdot
.47882 .32777 Mdot
.28367 .53749 Mdot
.45866 .67985 Mdot
.64542 .44921 Mdot
.49137 .56838 Mdot
.51893 .34192 Mdot
.31045 .6017 Mdot
.54579 .75734 Mdot
.31725 .57562 Mdot
.53232 .32243 Mdot
.26717 .57163 Mdot
.31611 .47189 Mdot
.29366 .54818 Mdot
.66758 .47511 Mdot
.64907 .48223 Mdot
.55759 .35695 Mdot
.49405 .33477 Mdot
.62196 .51295 Mdot
.66551 .49543 Mdot
.53606 .30185 Mdot
.27672 .53689 Mdot
.52131 .24881 Mdot
.63236 .51792 Mdot
.64665 .48592 Mdot
.46775 .71244 Mdot
.59371 .6622 Mdot
.56893 .68786 Mdot
.68009 .5045 Mdot
.46496 .70469 Mdot
.5481 .32584 Mdot
.65663 .48432 Mdot
.54844 .76498 Mdot
.32528 .55214 Mdot
.68306 .52927 Mdot
.49223 .60759 Mdot
.64881 .53527 Mdot
.66851 .7354 Mdot
.688 .54095 Mdot
.5312 .31216 Mdot
.53792 .31471 Mdot
.3136 .53794 Mdot
.52375 .31012 Mdot
.48609 .59781 Mdot
.33883 .41412 Mdot
.61267 .37319 Mdot
.47988 .5751 Mdot
.51843 .60307 Mdot
.52914 .58209 Mdot
.51394 .56112 Mdot
.42961 .67921 Mdot
.30821 .50452 Mdot
.50372 .60736 Mdot
.53113 .29605 Mdot
.5416 .43454 Mdot
.48494 .61087 Mdot
.35363 .39058 Mdot
.49972 .56156 Mdot
.68187 .52921 Mdot
.69766 .54407 Mdot
.53149 .27553 Mdot
.33778 .37658 Mdot
.46978 .59403 Mdot
.64618 .44946 Mdot
.52748 .26717 Mdot
.63089 .45883 Mdot
.46381 .66051 Mdot
.50015 .32535 Mdot
.32248 .5761 Mdot
.46822 .67268 Mdot
.51718 .57234 Mdot
.48461 .67881 Mdot
.29651 .56628 Mdot
.31684 .41983 Mdot
.66432 .47104 Mdot
.45462 .66068 Mdot
.44437 .69972 Mdot
.58927 .47009 Mdot
.53963 .31648 Mdot
.47467 .55671 Mdot
.65629 .49013 Mdot
.68711 .54395 Mdot
.50367 .34149 Mdot
.25814 .29311 Mdot
.61676 .48167 Mdot
.71052 .55483 Mdot
.53168 .35657 Mdot
.4846 .56472 Mdot
.32103 .57122 Mdot
.60059 .46784 Mdot
.34321 .39338 Mdot
.34183 .40583 Mdot
.25955 .56442 Mdot
.51006 .34279 Mdot
.31631 .60235 Mdot
.60353 .44758 Mdot
.50398 .56103 Mdot
.63587 .44951 Mdot
.25153 .53499 Mdot
.30116 .27013 Mdot
.52364 .29157 Mdot
.27663 .59766 Mdot
.61728 .70733 Mdot
.29054 .39203 Mdot
.25257 .55574 Mdot
.53279 .35243 Mdot
.47847 .33333 Mdot
.50946 .33862 Mdot
.44702 .70027 Mdot
.31805 .58341 Mdot
.54271 .28221 Mdot
.54069 .28148 Mdot
.65627 .53172 Mdot
.65163 .45166 Mdot
.55025 .31837 Mdot
.32644 .50749 Mdot
.47467 .6905 Mdot
.32441 .60563 Mdot
.60281 .81004 Mdot
.31522 .38119 Mdot
.77073 .39938 Mdot
.6781 .51549 Mdot
.89112 .43187 Mdot
.67135 .50371 Mdot
.62727 .46456 Mdot
.51009 .28979 Mdot
.44148 .70721 Mdot
.45705 .68454 Mdot
.54165 .30424 Mdot
.51545 .29257 Mdot
.46026 .66472 Mdot
.6074 .64638 Mdot
.64824 .75116 Mdot
.59997 .70499 Mdot
.50325 .30246 Mdot
.59744 .38847 Mdot
.32675 .40785 Mdot
.48897 .36096 Mdot
.34657 .45523 Mdot
.26666 .56449 Mdot
.29033 .54794 Mdot
.30567 .41857 Mdot
.61267 .4749 Mdot
.30445 .62243 Mdot
.66553 .54224 Mdot
.38209 .40841 Mdot
.70327 .54255 Mdot
.42868 .83355 Mdot
.6677 .48015 Mdot
.44311 .51766 Mdot
.41459 .29804 Mdot
.62659 .51905 Mdot
.77841 .37553 Mdot
.48252 .69236 Mdot
.54715 .3478 Mdot
.34758 .38025 Mdot
.66231 .2381 Mdot
.64845 .47934 Mdot
.48043 .3226 Mdot
.29987 .40119 Mdot
.28447 .28485 Mdot
.71319 .55295 Mdot
.64346 .52723 Mdot
.60274 .1626 Mdot
.47176 .3478 Mdot
.32042 .57253 Mdot
.5904 .36728 Mdot
.52775 .2869 Mdot
.71562 .55054 Mdot
.26976 .54376 Mdot
.69087 .6189 Mdot
.48518 .31411 Mdot
.43699 .68516 Mdot
.51295 .31729 Mdot
.4659 .66546 Mdot
.54369 .28286 Mdot
.27639 .59297 Mdot
.62918 .49316 Mdot
.27865 .59651 Mdot
.48421 .66842 Mdot
.2682 .59245 Mdot
.34324 .37711 Mdot
.51215 .5924 Mdot
.33779 .4108 Mdot
.63468 .70372 Mdot
.66981 .31568 Mdot
.31414 .41384 Mdot
.74352 .51752 Mdot
.65354 .46274 Mdot
.54482 .28508 Mdot
.32386 .58082 Mdot
.33559 .58949 Mdot
.59636 .68944 Mdot
.52825 .33114 Mdot
.30226 .60466 Mdot
.57397 .45725 Mdot
.24912 .3527 Mdot
.69379 .55238 Mdot
.16249 .53635 Mdot
.53231 .30416 Mdot
.33457 .58975 Mdot
.58401 .70845 Mdot
.47432 .3218 Mdot
.28493 .54737 Mdot
.305 .40788 Mdot
.34302 .39366 Mdot
.67126 .48561 Mdot
.35376 .41869 Mdot
.31638 .55039 Mdot
.56866 .39288 Mdot
.54709 .31615 Mdot
.3107 .26321 Mdot
.47163 .7059 Mdot
.32358 .59613 Mdot
.51082 .57113 Mdot
.47167 .30317 Mdot
.27883 .58327 Mdot
.87521 .47522 Mdot
.58137 .84557 Mdot
.30535 .60363 Mdot
.50213 .32569 Mdot
.50403 .33465 Mdot
.61431 .50016 Mdot
.60148 .68928 Mdot
.31171 .59551 Mdot
.21273 .3888 Mdot
.65741 .6585 Mdot
.50937 .5943 Mdot
.22536 .66978 Mdot
.69138 .53698 Mdot
.67244 .5411 Mdot
.31473 .38399 Mdot
.62063 .48105 Mdot
.51214 .29465 Mdot
.67102 .50449 Mdot
.34985 .39969 Mdot
.26008 .56685 Mdot
.65195 .48 Mdot
.47802 .69369 Mdot
.32815 .38285 Mdot
.34154 .3855 Mdot
.2689 .57393 Mdot
.51272 .3417 Mdot
.65989 .23376 Mdot
.31941 .57935 Mdot
.66019 .53851 Mdot
.50365 .58905 Mdot
.62594 .49725 Mdot
.48957 .36747 Mdot
.55161 .33698 Mdot
.32534 .59177 Mdot
.59406 .45648 Mdot
.32106 .39456 Mdot
.32994 .56484 Mdot
.69161 .54106 Mdot
.28941 .54239 Mdot
.50355 .54276 Mdot
.33851 .62141 Mdot
.47866 .29161 Mdot
.51613 .55606 Mdot
.47595 .33171 Mdot
.50496 .60497 Mdot
.43289 .78304 Mdot
.47505 .69408 Mdot
.28632 .61397 Mdot
.32465 .25913 Mdot
.28091 .60019 Mdot
.63876 .4952 Mdot
.65884 .4687 Mdot
.28861 .56814 Mdot
.46376 .70693 Mdot
.53978 .53959 Mdot
.44459 .66752 Mdot
.49742 .32948 Mdot
.73368 .54594 Mdot
.53599 .84649 Mdot
.33502 .57019 Mdot
.30372 .4201 Mdot
.46426 .25579 Mdot
.51993 .60069 Mdot
.34001 .37592 Mdot
.3369 .38261 Mdot
.48631 .67599 Mdot
.30404 .61369 Mdot
.49687 .35631 Mdot
.30531 .42488 Mdot
.48674 .30738 Mdot
.54224 .76215 Mdot
.50514 .55868 Mdot
.51726 .51238 Mdot
.5235 .58072 Mdot
.58905 .69356 Mdot
.29247 .41659 Mdot
.6421 .4632 Mdot
.49018 .53334 Mdot
.30263 .40008 Mdot
.49117 .69079 Mdot
.70263 .54332 Mdot
.29923 .60418 Mdot
.63477 .18994 Mdot
.66839 .47555 Mdot
.65215 .49646 Mdot
.30418 .38951 Mdot
.77051 .35441 Mdot
.53945 .34802 Mdot
.53193 .33387 Mdot
.3022 .57532 Mdot
.56264 .71355 Mdot
.66098 .50759 Mdot
.65839 .4648 Mdot
.28673 .56509 Mdot
.4948 .59273 Mdot
.24624 .70395 Mdot
.64307 .48291 Mdot
.32601 .40218 Mdot
.7067 .54502 Mdot
.32834 .36984 Mdot
.68893 .49695 Mdot
.63496 .49171 Mdot
.64671 .53148 Mdot
.68808 .54739 Mdot
.33557 .41151 Mdot
.52127 .5792 Mdot
.50849 .61405 Mdot
.51884 .30044 Mdot
.63619 .44026 Mdot
.6579 .65639 Mdot
.64454 .47997 Mdot
.48124 .69422 Mdot
.56822 .692 Mdot
.68483 .50186 Mdot
.64417 .44154 Mdot
.6576 .6617 Mdot
.61606 .45904 Mdot
.30301 .38977 Mdot
.51017 .33397 Mdot
.32123 .39278 Mdot
.29858 .41561 Mdot
.27539 .57998 Mdot
.48801 .70124 Mdot
.6022 .46503 Mdot
.44842 .67666 Mdot
.62669 .50776 Mdot
.47901 .60941 Mdot
.60964 .67518 Mdot
.58787 .71201 Mdot
.47991 .65424 Mdot
.65388 .46108 Mdot
.29828 .57012 Mdot
.3134 .6144 Mdot
.72218 .54438 Mdot
.59794 .44776 Mdot
.35716 .41294 Mdot
.3115 .41582 Mdot
.29687 .50575 Mdot
.25732 .63933 Mdot
.45607 .6618 Mdot
.52505 .54014 Mdot
.69081 .54877 Mdot
.64324 .50215 Mdot
.51951 .59063 Mdot
.28565 .58514 Mdot
.50539 .60648 Mdot
.30844 .50701 Mdot
.33836 .37296 Mdot
.31487 .39004 Mdot
.66756 .47732 Mdot
.85946 .55875 Mdot
.49873 .31251 Mdot
.50406 .3353 Mdot
.34953 .40526 Mdot
.27219 .60017 Mdot
.49995 .57204 Mdot
.66478 .20976 Mdot
.55406 .33012 Mdot
.44219 .70203 Mdot
.62141 .44933 Mdot
.26465 .56843 Mdot
.52252 .29644 Mdot
.4504 .66448 Mdot
.64478 .43743 Mdot
.26611 .54511 Mdot
.64033 .46709 Mdot
.56036 .47261 Mdot
.54356 .29885 Mdot
.6036 .66725 Mdot
.47374 .34285 Mdot
.33657 .40763 Mdot
.29658 .41784 Mdot
.64014 .49312 Mdot
.65833 .2072 Mdot
.45959 .28728 Mdot
.30867 .42836 Mdot
.45944 .71633 Mdot
.5141 .58808 Mdot
.48945 .69735 Mdot
.29076 .57578 Mdot
.47621 .69377 Mdot
.27789 .58297 Mdot
.29113 .53085 Mdot
.49911 .35354 Mdot
.45958 .69846 Mdot
.75103 .36926 Mdot
.49599 .56515 Mdot
.45674 .71944 Mdot
.66814 .46356 Mdot
.6251 .51115 Mdot
.30525 .59721 Mdot
.44519 .6814 Mdot
.6026 .47388 Mdot
.35554 .26764 Mdot
.29288 .41016 Mdot
.34447 .37764 Mdot
.50042 .57464 Mdot
.3261 .56467 Mdot
.50154 .35288 Mdot
.61997 .70714 Mdot
.45959 .33809 Mdot
.65885 .46435 Mdot
.60311 .46648 Mdot
.46541 .31548 Mdot
.50327 .35145 Mdot
.63434 .4895 Mdot
.73582 .40887 Mdot
.51246 .57107 Mdot
.34526 .39805 Mdot
.49518 .32824 Mdot
.4893 .33191 Mdot
.31139 .5487 Mdot
.52555 .33953 Mdot
.49788 .52449 Mdot
.3386 .37352 Mdot
.50569 .61592 Mdot
.32345 .39627 Mdot
.5129 .63534 Mdot
.29459 .59906 Mdot
.30486 .27364 Mdot
.53271 .33453 Mdot
.63563 .52092 Mdot
.53433 .33559 Mdot
.47873 .70268 Mdot
.4849 .31808 Mdot
.48857 .36303 Mdot
.65759 .45916 Mdot
.52067 .58052 Mdot
.48769 .59178 Mdot
.59517 .69322 Mdot
.50236 .31161 Mdot
.60758 .47322 Mdot
.66567 .51232 Mdot
.66601 .49273 Mdot
.60933 .68048 Mdot
.49272 .34884 Mdot
.75503 .33715 Mdot
.54419 .28105 Mdot
.54131 .29647 Mdot
.64846 .79971 Mdot
.48437 .58842 Mdot
.51343 .60318 Mdot
.36479 .35111 Mdot
.64387 .48554 Mdot
.30951 .60743 Mdot
.66033 .53762 Mdot
.51772 .58022 Mdot
.66569 .4574 Mdot
.45342 .67872 Mdot
.6049 .45285 Mdot
.5034 .59658 Mdot
.32214 .58314 Mdot
.64179 .52492 Mdot
.65119 .48654 Mdot
.49156 .59043 Mdot
.53653 .3363 Mdot
.4847 .33996 Mdot
.4551 .31534 Mdot
.47243 .6641 Mdot
.31825 .41033 Mdot
.66446 .5383 Mdot
.30041 .57331 Mdot
.30598 .60919 Mdot
.47432 .34 Mdot
.29878 .55513 Mdot
.31368 .38915 Mdot
.62709 .47086 Mdot
.33668 .40946 Mdot
.45701 .67324 Mdot
.499 .32486 Mdot
.68104 .54091 Mdot
.60384 .49965 Mdot
.53799 .31455 Mdot
.51151 .5675 Mdot
.47176 .71258 Mdot
.28541 .55985 Mdot
.53267 .29085 Mdot
.34166 .40983 Mdot
.30466 .54759 Mdot
.63604 .5223 Mdot
.74591 .73197 Mdot
.62176 .48224 Mdot
.66565 .50133 Mdot
.47562 .28203 Mdot
.69292 .51714 Mdot
.27458 .59379 Mdot
.51462 .34506 Mdot
.62872 .51473 Mdot
.65738 .68335 Mdot
.49339 .67225 Mdot
.33806 .60538 Mdot
.62122 .45953 Mdot
.78044 .45416 Mdot
.66041 .52342 Mdot
.33947 .24981 Mdot
.60844 .67479 Mdot
.28816 .46848 Mdot
.50386 .51514 Mdot
.31694 .42968 Mdot
.49922 .59072 Mdot
.2739 .58236 Mdot
.72956 .389 Mdot
.62696 .4836 Mdot
.65593 .28861 Mdot
.67959 .53844 Mdot
.31507 .3946 Mdot
.76636 .3606 Mdot
.32348 .56804 Mdot
.30825 .75821 Mdot
.626 .44019 Mdot
.54468 .3433 Mdot
.36031 .53426 Mdot
.51689 .59319 Mdot
.52063 .59595 Mdot
.45983 .66123 Mdot
.24702 .56644 Mdot
.46903 .57354 Mdot
.32293 .3939 Mdot
.64646 .50481 Mdot
.58419 .45425 Mdot
.2674 .29465 Mdot
.52854 .29923 Mdot
.29837 .40965 Mdot
.34641 .60954 Mdot
.64364 .46019 Mdot
.47917 .33479 Mdot
.5264 .32013 Mdot
.44782 .68357 Mdot
.29003 .4653 Mdot
.24524 .56683 Mdot
.84378 .54047 Mdot
.46369 .58287 Mdot
.28434 .58207 Mdot
.51651 .55827 Mdot
.65572 .53619 Mdot
.52733 .65034 Mdot
.30247 .4206 Mdot
.64621 .49853 Mdot
.65502 .27348 Mdot
.52729 .30479 Mdot
.63852 .47343 Mdot
.47481 .68641 Mdot
.67516 .22054 Mdot
.57747 .46832 Mdot
.73876 .41914 Mdot
.28295 .53768 Mdot
.60367 .46871 Mdot
.49553 .52587 Mdot
.4833 .56985 Mdot
.69332 .51659 Mdot
.32111 .57489 Mdot
.51872 .55875 Mdot
.4699 .68555 Mdot
.5152 .2989 Mdot
.49916 .58829 Mdot
.68027 .53841 Mdot
.60039 .46091 Mdot
.46256 .71629 Mdot
.64855 .53116 Mdot
.60247 .35845 Mdot
.49378 .55234 Mdot
.28838 .55088 Mdot
.5307 .28915 Mdot
.60938 .47814 Mdot
.51495 .58727 Mdot
.63639 .45064 Mdot
.52441 .22752 Mdot
.64568 .50007 Mdot
.31826 .28223 Mdot
.53496 .32532 Mdot
.33765 .39357 Mdot
.6915 .5432 Mdot
.64323 .47041 Mdot
.51101 .55303 Mdot
.4976 .57116 Mdot
.62831 .44273 Mdot
.47487 .33513 Mdot
.50685 .304 Mdot
.54582 .34053 Mdot
.30238 .54423 Mdot
.60387 .70079 Mdot
.33685 .40145 Mdot
.51935 .59192 Mdot
.30573 .42503 Mdot
.77762 .47672 Mdot
.47646 .66789 Mdot
.28263 .2934 Mdot
.62767 .47625 Mdot
.52253 .33372 Mdot
.64092 .75334 Mdot
.47653 .34316 Mdot
.37503 .36733 Mdot
.3044 .42224 Mdot
.50311 .31643 Mdot
.61822 .46223 Mdot
.58437 .69682 Mdot
.78281 .4505 Mdot
.28936 .39921 Mdot
.5016 .61454 Mdot
.50404 .66369 Mdot
.27974 .54484 Mdot
.63746 .80416 Mdot
.3343 .42252 Mdot
.41553 .29479 Mdot
.63196 .51764 Mdot
.53987 .32747 Mdot
.32834 .41447 Mdot
.34239 .38414 Mdot
.32518 .56873 Mdot
.65288 .53044 Mdot
.64187 .47124 Mdot
.49265 .60726 Mdot
.3236 .42188 Mdot
.59653 .45713 Mdot
.62708 .52058 Mdot
.23956 .54788 Mdot
.54505 .34584 Mdot
.25724 .29206 Mdot
.75885 .525 Mdot
.6561 .27408 Mdot
.23232 .38276 Mdot
.54759 .2957 Mdot
.60756 .46448 Mdot
.50842 .57425 Mdot
.2893 .55562 Mdot
.62156 .47073 Mdot
.27909 .60009 Mdot
.31374 .40211 Mdot
.33683 .27679 Mdot
.75457 .53049 Mdot
.38503 .40119 Mdot
.62776 .49055 Mdot
.58487 .4873 Mdot
.4648 .69166 Mdot
.34897 .38027 Mdot
.52853 .34849 Mdot
.61872 .48933 Mdot
.316 .5584 Mdot
.28008 .54704 Mdot
.52401 .30434 Mdot
.42343 .33797 Mdot
.31278 .26694 Mdot
.50764 .5669 Mdot
.30617 .55852 Mdot
.5151 .58335 Mdot
.73874 .42373 Mdot
.3076 .42677 Mdot
.46876 .68506 Mdot
.26991 .56712 Mdot
.35475 .39745 Mdot
.62398 .51041 Mdot
.51398 .30928 Mdot
.46122 .32888 Mdot
.72187 .55135 Mdot
.30302 .60518 Mdot
.47388 .67058 Mdot
.71161 .53118 Mdot
.73116 .54737 Mdot
.47169 .67495 Mdot
.31098 .54575 Mdot
.48705 .32401 Mdot
.53216 .31957 Mdot
.51402 .33249 Mdot
.76946 .39768 Mdot
.55323 .33435 Mdot
.52061 .73945 Mdot
.69456 .52196 Mdot
.59137 .39373 Mdot
.64332 .51556 Mdot
.34635 .37949 Mdot
.5454 .3061 Mdot
.6085 .67383 Mdot
.6871 .55026 Mdot
.78528 .45149 Mdot
.66278 .49158 Mdot
.70843 .54987 Mdot
.64483 .48614 Mdot
.57193 .39407 Mdot
.55327 .33943 Mdot
.63294 .43722 Mdot
.31427 .37487 Mdot
.48597 .68821 Mdot
.50914 .29241 Mdot
.60963 .45692 Mdot
.52155 .39136 Mdot
.67101 .46805 Mdot
.33281 .27699 Mdot
.71699 .5486 Mdot
.38487 .56932 Mdot
.64542 .50909 Mdot
.26965 .60038 Mdot
.59623 .49375 Mdot
.61369 .37809 Mdot
.29047 .40889 Mdot
.57685 .47011 Mdot
.29242 .61929 Mdot
.76503 .35889 Mdot
.50391 .56602 Mdot
.47177 .69123 Mdot
.52626 .57438 Mdot
.34551 .40501 Mdot
.62728 .47973 Mdot
.60817 .45218 Mdot
.69359 .49991 Mdot
.73873 .4253 Mdot
.48586 .57735 Mdot
.47771 .6536 Mdot
.60504 .3873 Mdot
.6232 .44521 Mdot
.32725 .62367 Mdot
.49659 .34412 Mdot
.75461 .36241 Mdot
.74237 .35186 Mdot
.62213 .51663 Mdot
.50608 .31203 Mdot
.51064 .34263 Mdot
.57317 .81428 Mdot
.46615 .69967 Mdot
.65372 .49884 Mdot
.42837 .70937 Mdot
.6685 .53866 Mdot
.3192 .40422 Mdot
.68984 .51562 Mdot
.29588 .60018 Mdot
.57956 .70432 Mdot
.30609 .5438 Mdot
.66602 .49071 Mdot
.51296 .31886 Mdot
.2937 .39083 Mdot
.2943 .53012 Mdot
.29164 .46559 Mdot
.52028 .74357 Mdot
.24775 .56184 Mdot
.45333 .66416 Mdot
.48821 .68304 Mdot
.34862 .38019 Mdot
.62368 .46332 Mdot
.60718 .68349 Mdot
.77536 .5109 Mdot
.63883 .48376 Mdot
.61354 .47356 Mdot
.31093 .34155 Mdot
.31398 .42475 Mdot
.26571 .57413 Mdot
.6326 .48788 Mdot
.60292 .45354 Mdot
.50768 .31928 Mdot
.44351 .67959 Mdot
.27783 .56851 Mdot
.46944 .66078 Mdot
.30882 .56811 Mdot
.66928 .73545 Mdot
.50469 .55945 Mdot
.48165 .67209 Mdot
.3347 .42359 Mdot
.51116 .33677 Mdot
.48429 .5908 Mdot
.29656 .5836 Mdot
.30465 .55617 Mdot
.61881 .50072 Mdot
.52097 .29738 Mdot
.53258 .33365 Mdot
.46369 .66286 Mdot
.31315 .41559 Mdot
.67077 .54437 Mdot
.52372 .58337 Mdot
.33951 .56928 Mdot
.30908 .55366 Mdot
.60017 .38892 Mdot
.47925 .28618 Mdot
.63636 .45286 Mdot
.48388 .33841 Mdot
.65077 .47447 Mdot
.47391 .36166 Mdot
.47082 .34654 Mdot
.68742 .49572 Mdot
.683 .4109 Mdot
.28422 .58558 Mdot
.49584 .84353 Mdot
.69621 .55299 Mdot
.31792 .3661 Mdot
.65859 .53643 Mdot
.26919 .72842 Mdot
.63581 .75545 Mdot
.63647 .44655 Mdot
.6048 .46234 Mdot
.84323 .58758 Mdot
.66537 .52119 Mdot
.50382 .60339 Mdot
.50248 .5654 Mdot
.48193 .33604 Mdot
.52782 .58104 Mdot
.59237 .6922 Mdot
.4578 .70271 Mdot
.30122 .57555 Mdot
.55294 .76648 Mdot
.46869 .66518 Mdot
.53122 .30878 Mdot
.66687 .54332 Mdot
.46727 .29018 Mdot
.31309 .6224 Mdot
.49552 .58366 Mdot
.31436 .39884 Mdot
.60014 .68525 Mdot
.32009 .56167 Mdot
.33647 .41703 Mdot
.66638 .5168 Mdot
.30841 .5103 Mdot
.32162 .37202 Mdot
.50877 .84074 Mdot
.32844 .3782 Mdot
.34144 .41269 Mdot
.60413 .69316 Mdot
.45752 .70275 Mdot
.49929 .54906 Mdot
.49198 .62228 Mdot
.29597 .39162 Mdot
.35517 .78164 Mdot
.32653 .56765 Mdot
.60083 .71931 Mdot
.549 .34636 Mdot
.49553 .56261 Mdot
.62155 .48563 Mdot
.31448 .38334 Mdot
.59439 .44978 Mdot
.51341 .55406 Mdot
.32629 .3852 Mdot
.59704 .49432 Mdot
.56384 .71084 Mdot
.51241 .584 Mdot
.4879 .59506 Mdot
.44273 .6758 Mdot
.37334 .59567 Mdot
.52119 .33768 Mdot
.44571 .7074 Mdot
.63833 .6829 Mdot
.66303 .49763 Mdot
.33438 .41192 Mdot
.49868 .58747 Mdot
.34062 .40013 Mdot
.46045 .68695 Mdot
.46418 .7172 Mdot
.52099 .29979 Mdot
.54383 .34278 Mdot
.47913 .58601 Mdot
.66378 .65329 Mdot
.68422 .52683 Mdot
.65973 .30233 Mdot
.49345 .35247 Mdot
.78337 .38604 Mdot
.45065 .70205 Mdot
.44303 .68367 Mdot
.59048 .48949 Mdot
.68045 .50049 Mdot
.70744 .54866 Mdot
.6839 .49776 Mdot
.33818 .76304 Mdot
.68228 .54061 Mdot
.28915 .5589 Mdot
.67623 .47294 Mdot
.43805 .27074 Mdot
.60822 .49477 Mdot
.61582 .45246 Mdot
.31304 .58206 Mdot
.62068 .49835 Mdot
.30234 .59945 Mdot
.62364 .49078 Mdot
.21909 .59576 Mdot
.30091 .57348 Mdot
.54159 .56256 Mdot
.69733 .47301 Mdot
.49786 .60221 Mdot
.45007 .6902 Mdot
.46074 .65886 Mdot
.54304 .75589 Mdot
.49157 .31999 Mdot
.68881 .25579 Mdot
.61919 .45167 Mdot
.3238 .56284 Mdot
.31218 .40406 Mdot
.60781 .5019 Mdot
.66927 .49737 Mdot
.6965 .55065 Mdot
.50865 .30719 Mdot
.32407 .55809 Mdot
.45556 .69158 Mdot
.29758 .61327 Mdot
.21787 .59901 Mdot
.29254 .59641 Mdot
.74915 .46341 Mdot
.62278 .50813 Mdot
.49705 .52543 Mdot
.68649 .34192 Mdot
.463 .72888 Mdot
.51896 .3059 Mdot
.50155 .59114 Mdot
.48965 .68916 Mdot
.56556 .67091 Mdot
.50821 .34065 Mdot
.28752 .56485 Mdot
.64063 .46672 Mdot
.51411 .56014 Mdot
.49064 .6213 Mdot
.50497 .29694 Mdot
.47635 .71318 Mdot
.30243 .5826 Mdot
.50945 .58981 Mdot
.60281 .70484 Mdot
.73137 .31557 Mdot
.6294 .71054 Mdot
.64631 .47129 Mdot
.46136 .66441 Mdot
.52063 .29714 Mdot
.70607 .55185 Mdot
.30395 .39708 Mdot
.59929 .68993 Mdot
.62315 .48566 Mdot
.38863 .37832 Mdot
.51469 .318 Mdot
.46756 .70613 Mdot
.31948 .38069 Mdot
.46844 .6996 Mdot
.51234 .60308 Mdot
.52449 .28229 Mdot
.52046 .59602 Mdot
.68821 .54073 Mdot
.31461 .40581 Mdot
.5249 .33633 Mdot
.21955 .59154 Mdot
.4833 .55 Mdot
.28904 .56923 Mdot
.56878 .67054 Mdot
.51049 .30174 Mdot
.31919 .48361 Mdot
.29589 .61267 Mdot
.27461 .37291 Mdot
.58999 .66059 Mdot
.31906 .38523 Mdot
.61323 .45391 Mdot
.5125 .32935 Mdot
.2892 .39858 Mdot
.34263 .52503 Mdot
.78197 .43545 Mdot
.48217 .55939 Mdot
.65555 .46445 Mdot
.34994 .24132 Mdot
.42138 .29333 Mdot
.55411 .35263 Mdot
.34468 .41371 Mdot
.65052 .4938 Mdot
.50827 .56602 Mdot
.63092 .43883 Mdot
.29311 .39759 Mdot
.29306 .4328 Mdot
.322 .60817 Mdot
.64041 .46318 Mdot
.477 .69803 Mdot
.28592 .59731 Mdot
.27161 .54747 Mdot
.27055 .5642 Mdot
.5313 .34777 Mdot
.49231 .56145 Mdot
.50365 .56429 Mdot
.6244 .75899 Mdot
.34247 .39878 Mdot
.49822 .60203 Mdot
.60549 .45342 Mdot
.52195 .73965 Mdot
.52317 .33089 Mdot
.30506 .587 Mdot
.65324 .49619 Mdot
.72123 .55375 Mdot
.49116 .58537 Mdot
.31837 .58143 Mdot
.50135 .35211 Mdot
.54778 .44568 Mdot
.62315 .47196 Mdot
.66769 .53553 Mdot
.53597 .30849 Mdot
.48655 .21076 Mdot
.5999 .71036 Mdot
.65045 .47612 Mdot
.34285 .40498 Mdot
.44848 .20835 Mdot
.66319 .51768 Mdot
.45196 .32766 Mdot
.4946 .61045 Mdot
.54359 .42091 Mdot
.60043 .36844 Mdot
.59223 .43093 Mdot
.44814 .47413 Mdot
.6247 .5893 Mdot
.46853 .48911 Mdot
.37684 .77186 Mdot
.40157 .48976 Mdot
.52981 .84256 Mdot
.36477 .39736 Mdot
.56226 .46406 Mdot
.86886 .47608 Mdot
.4105 .3189 Mdot
.37683 .51208 Mdot
.28207 .42765 Mdot
.4855 .73118 Mdot
.23639 .69037 Mdot
.30545 .50807 Mdot
.37984 .76987 Mdot
.6886 .5369 Mdot
.46285 .23036 Mdot
.5663 .47337 Mdot
.33811 .49062 Mdot
.29453 .47568 Mdot
.71618 .54328 Mdot
.81583 .61083 Mdot
.3776 .38624 Mdot
.71489 .73942 Mdot
.66934 .26504 Mdot
.33325 .54221 Mdot
.65662 .63188 Mdot
.53286 .77942 Mdot
.58605 .50019 Mdot
.50506 .45602 Mdot
.36723 .39621 Mdot
.5296 .25799 Mdot
.2345 .36487 Mdot
.29562 .56146 Mdot
.49557 .30394 Mdot
.35974 .34086 Mdot
.78185 .6732 Mdot
.33235 .35585 Mdot
.44657 .47554 Mdot
.48007 .55554 Mdot
.56594 .41468 Mdot
.61013 .6706 Mdot
.57192 .38737 Mdot
.27162 .5217 Mdot
.2401 .69167 Mdot
.4851 .27483 Mdot
.36126 .54692 Mdot
.5547 .67074 Mdot
.3705 .51204 Mdot
.58486 .35707 Mdot
.48527 .72324 Mdot
.54057 .56606 Mdot
.49326 .3531 Mdot
.80556 .58101 Mdot
.73661 .49474 Mdot
.64297 .6786 Mdot
.31562 .5034 Mdot
.49349 .24685 Mdot
.66109 .22895 Mdot
.42474 .33171 Mdot
.45066 .84015 Mdot
.74683 .7265 Mdot
.4172 .79614 Mdot
.6858 .4562 Mdot
.34338 .35439 Mdot
.53056 .66153 Mdot
.43861 .52447 Mdot
.43778 .81025 Mdot
.52179 .22696 Mdot
.82714 .56271 Mdot
.49718 .39858 Mdot
.78753 .68365 Mdot
.50717 .27792 Mdot
.4789 .54338 Mdot
.56514 .357 Mdot
.55476 .45655 Mdot
.61467 .74359 Mdot
.80191 .65202 Mdot
.35193 .50012 Mdot
.47948 .55041 Mdot
.40842 .32854 Mdot
.59992 .36057 Mdot
.2705 .52058 Mdot
.53224 .57919 Mdot
.70877 .34349 Mdot
.81933 .62589 Mdot
.46028 .46432 Mdot
.78372 .63714 Mdot
.2364 .55685 Mdot
.16238 .493 Mdot
.26646 .55025 Mdot
.32661 .4317 Mdot
.73169 .73016 Mdot
.51871 .32601 Mdot
.48011 .85135 Mdot
.40319 .50534 Mdot
.40418 .54684 Mdot
.82076 .61858 Mdot
.42647 .82679 Mdot
.57269 .42994 Mdot
.53023 .54287 Mdot
.25025 .35411 Mdot
.49462 .48789 Mdot
.36802 .44602 Mdot
.52575 .62555 Mdot
.33763 .26333 Mdot
.74843 .71176 Mdot
.40912 .81027 Mdot
.84349 .52799 Mdot
.64204 .67055 Mdot
.47194 .75298 Mdot
.47728 .27697 Mdot
.4208 .42934 Mdot
.35665 .46144 Mdot
.77694 .69838 Mdot
.57622 .45883 Mdot
.41939 .20826 Mdot
.39284 .77847 Mdot
.74894 .35015 Mdot
.38399 .24755 Mdot
.39614 .35604 Mdot
.54876 .47275 Mdot
.51579 .38909 Mdot
.47298 .64093 Mdot
.60072 .75028 Mdot
.69535 .32335 Mdot
.37876 .55796 Mdot
.59152 .70513 Mdot
.4212 .35717 Mdot
.47843 .80037 Mdot
.42368 .22818 Mdot
.70657 .33611 Mdot
.46576 .31773 Mdot
.43878 .80909 Mdot
.39678 .7858 Mdot
.40149 .22254 Mdot
.34991 .59962 Mdot
.77996 .64689 Mdot
.39757 .40541 Mdot
.60309 .41365 Mdot
.56375 .47464 Mdot
.58113 .49257 Mdot
.26767 .71366 Mdot
.7299 .44108 Mdot
.57036 .80782 Mdot
.3659 .43737 Mdot
.68932 .35575 Mdot
.5587 .79124 Mdot
.69271 .35074 Mdot
.61127 .37267 Mdot
.44313 .33928 Mdot
.37439 .40086 Mdot
.68062 .4161 Mdot
.8191 .61078 Mdot
.27023 .58265 Mdot
.43567 .81236 Mdot
.34566 .36096 Mdot
.31974 .52065 Mdot
.3938 .54347 Mdot
.38667 .54198 Mdot
.68206 .76873 Mdot
.40196 .33166 Mdot
.49768 .71365 Mdot
.57174 .36144 Mdot
.42052 .51231 Mdot
.66667 .30701 Mdot
.76086 .50911 Mdot
.50121 .23903 Mdot
.47126 .713 Mdot
.71703 .37687 Mdot
.53832 .39182 Mdot
.35059 .60582 Mdot
.75704 .47246 Mdot
.6743 .62162 Mdot
.48555 .60274 Mdot
.54653 .73263 Mdot
.66438 .74007 Mdot
.61627 .40885 Mdot
.43806 .82515 Mdot
.41621 .33331 Mdot
.54816 .73864 Mdot
.35295 .46471 Mdot
.69484 .26077 Mdot
.7905 .6804 Mdot
.62893 .80238 Mdot
.48638 .21612 Mdot
.37476 .24319 Mdot
.1659 .57291 Mdot
.30528 .47026 Mdot
.51909 .82805 Mdot
.34566 .36084 Mdot
.56779 .13985 Mdot
.27111 .59084 Mdot
.52135 .66633 Mdot
.52241 .27295 Mdot
.66821 .61911 Mdot
.80033 .63951 Mdot
.57531 .40854 Mdot
.45406 .7185 Mdot
.56351 .35058 Mdot
.68476 .41279 Mdot
.81124 .6068 Mdot
.81683 .57768 Mdot
.80977 .58745 Mdot
.37389 .35023 Mdot
.72481 .40925 Mdot
.83284 .59795 Mdot
.52214 .7136 Mdot
.69539 .43523 Mdot
.58565 .44827 Mdot
.66568 .672 Mdot
.49885 .82739 Mdot
.45435 .73651 Mdot
.50002 .48624 Mdot
.48493 .27573 Mdot
.82829 .61873 Mdot
.65399 .75193 Mdot
.56175 .42195 Mdot
.68851 .75753 Mdot
.44603 .75349 Mdot
.57522 .79051 Mdot
.66053 .77951 Mdot
.48125 .45881 Mdot
.39553 .36589 Mdot
.8364 .61591 Mdot
.42335 .78454 Mdot
.27972 .4238 Mdot
.52639 .39154 Mdot
.49422 .83401 Mdot
.3745 .25174 Mdot
.27733 .35284 Mdot
.51151 .27379 Mdot
.71672 .2774 Mdot
.37432 .48095 Mdot
.50997 .45712 Mdot
.69228 .48251 Mdot
.55214 .79793 Mdot
.26803 .59053 Mdot
.46362 .81126 Mdot
.37122 .46087 Mdot
.67857 .42329 Mdot
.56165 .75162 Mdot
.38724 .79692 Mdot
.50003 .42023 Mdot
.75078 .42746 Mdot
.41516 .33681 Mdot
.43786 .21963 Mdot
.39668 .23849 Mdot
.69368 .29145 Mdot
.61698 .49166 Mdot
.78757 .66664 Mdot
.55809 .84383 Mdot
.66553 .78022 Mdot
.41253 .22252 Mdot
.16865 .53255 Mdot
.3575 .40539 Mdot
.52548 .7205 Mdot
.67967 .60834 Mdot
.46534 .4357 Mdot
.64043 .58864 Mdot
.28376 .40716 Mdot
.66081 .22773 Mdot
.39512 .53795 Mdot
.52321 .7128 Mdot
.53896 .25059 Mdot
.41565 .52936 Mdot
.74545 .42819 Mdot
.46536 .32236 Mdot
.38449 .2177 Mdot
.44172 .80995 Mdot
.26971 .57836 Mdot
.3439 .59694 Mdot
.72162 .44284 Mdot
.49497 .53166 Mdot
.50521 .68172 Mdot
.61783 .41558 Mdot
.65922 .27505 Mdot
.17411 .54849 Mdot
.61315 .79532 Mdot
.49362 .84209 Mdot
.65714 .78179 Mdot
.40973 .79536 Mdot
.33774 .52457 Mdot
.55716 .73316 Mdot
.29442 .35909 Mdot
.3596 .36858 Mdot
.55637 .71462 Mdot
.39139 .7926 Mdot
.57625 .41773 Mdot
.56129 .35985 Mdot
.5993 .47499 Mdot
.64533 .75013 Mdot
.52168 .77424 Mdot
.545 .71441 Mdot
.71192 .30103 Mdot
.49833 .35884 Mdot
.49765 .73989 Mdot
.52865 .44822 Mdot
.63626 .53252 Mdot
.37824 .23828 Mdot
.2875 .40195 Mdot
.46545 .33172 Mdot
.38669 .79775 Mdot
.17001 .5644 Mdot
.44626 .50484 Mdot
.74326 .51204 Mdot
.75438 .70103 Mdot
.70688 .48589 Mdot
.35919 .25526 Mdot
.73428 .2888 Mdot
.31031 .48291 Mdot
.49294 .27339 Mdot
.66921 .42364 Mdot
.39637 .55572 Mdot
.48501 .22446 Mdot
.4793 .30523 Mdot
.59029 .49619 Mdot
.72874 .73892 Mdot
.70658 .52385 Mdot
.49361 .46533 Mdot
.61861 .70896 Mdot
.40443 .44672 Mdot
.411 .50672 Mdot
.55943 .7576 Mdot
.45902 .48548 Mdot
.79835 .59349 Mdot
.65362 .22092 Mdot
.51319 .48453 Mdot
.51151 .72224 Mdot
.52551 .7078 Mdot
.66877 .26448 Mdot
.58464 .35241 Mdot
.35892 .44746 Mdot
.69041 .53333 Mdot
.71636 .75436 Mdot
.46924 .38624 Mdot
.55583 .74617 Mdot
.40948 .38552 Mdot
.66042 .52707 Mdot
.47091 .556 Mdot
.66797 .77558 Mdot
.53972 .42409 Mdot
.87835 .45589 Mdot
.36584 .77337 Mdot
.47244 .24514 Mdot
.59693 .37478 Mdot
.45102 .82311 Mdot
.44784 .26644 Mdot
.41226 .48954 Mdot
.37996 .44991 Mdot
.48128 .82866 Mdot
.53291 .4189 Mdot
.5365 .43173 Mdot
.37016 .23031 Mdot
.83212 .58755 Mdot
.49347 .48081 Mdot
.28754 .34757 Mdot
.46196 .75014 Mdot
.66389 .50394 Mdot
.4215 .33423 Mdot
.29119 .28199 Mdot
.42204 .39289 Mdot
.47228 .49433 Mdot
.55221 .84814 Mdot
.60105 .40937 Mdot
.41282 .34096 Mdot
.87778 .46021 Mdot
.88642 .4444 Mdot
.42958 .31256 Mdot
.76703 .7106 Mdot
.54322 .42848 Mdot
.35937 .25795 Mdot
.36873 .38628 Mdot
.73149 .53812 Mdot
.6575 .2941 Mdot
.68339 .77813 Mdot
.15853 .54289 Mdot
.36249 .4516 Mdot
.51394 .26124 Mdot
.67912 .78319 Mdot
.61224 .40332 Mdot
.51307 .70454 Mdot
.16364 .49277 Mdot
.31705 .76369 Mdot
.45056 .83695 Mdot
.71585 .29563 Mdot
.26777 .71771 Mdot
.33821 .74885 Mdot
.35473 .49229 Mdot
.50033 .83772 Mdot
.46983 .60679 Mdot
.70513 .26418 Mdot
.43689 .80811 Mdot
.35684 .24542 Mdot
.21983 .6411 Mdot
.41558 .50335 Mdot
.62955 .41586 Mdot
.44734 .34774 Mdot
.33424 .26742 Mdot
.39304 .34874 Mdot
.70662 .45865 Mdot
.57047 .67662 Mdot
.61 .37574 Mdot
.44754 .20505 Mdot
.75057 .29868 Mdot
.62656 .419 Mdot
.81694 .55294 Mdot
.3807 .40364 Mdot
.54725 .68779 Mdot
.58783 .36684 Mdot
.53121 .75884 Mdot
.49883 .71711 Mdot
.67482 .47231 Mdot
.73511 .73261 Mdot
.49975 .71271 Mdot
.81387 .5654 Mdot
.47866 .85426 Mdot
.70091 .74577 Mdot
.40942 .55598 Mdot
.50379 .65477 Mdot
.49659 .82336 Mdot
.50352 .82168 Mdot
.82718 .54373 Mdot
.38436 .76782 Mdot
.5574 .70882 Mdot
.68973 .44568 Mdot
.7519 .52535 Mdot
.74359 .43959 Mdot
.45513 .82393 Mdot
.66709 .25449 Mdot
.56 .78752 Mdot
.48527 .21861 Mdot
.3906 .79521 Mdot
.57083 .43427 Mdot
.53509 .75635 Mdot
.41137 .40689 Mdot
.5326 .55006 Mdot
.32965 .57265 Mdot
.85355 .55907 Mdot
.3938 .22744 Mdot
.59579 .79209 Mdot
.41245 .21121 Mdot
.51582 .39183 Mdot
.35337 .76231 Mdot
.56754 .3504 Mdot
.47135 .51749 Mdot
.34272 .54348 Mdot
.50427 .79715 Mdot
.57904 .42195 Mdot
.33981 .24885 Mdot
.73457 .33605 Mdot
.68895 .76687 Mdot
.56096 .79253 Mdot
.84981 .51171 Mdot
.48535 .74295 Mdot
.71543 .37473 Mdot
.80388 .57759 Mdot
.46296 .21524 Mdot
.54198 .70557 Mdot
.81842 .60118 Mdot
.55888 .33717 Mdot
.75185 .72156 Mdot
.30617 .39981 Mdot
.50619 .71984 Mdot
.31629 .26754 Mdot
.53408 .71234 Mdot
.53446 .70716 Mdot
.59869 .79929 Mdot
.4082 .33238 Mdot
.41988 .3189 Mdot
.39662 .40646 Mdot
.30263 .51051 Mdot
.74363 .5302 Mdot
.479 .46896 Mdot
.84204 .53187 Mdot
.61692 .4906 Mdot
.41105 .76089 Mdot
.43634 .81776 Mdot
.2943 .35775 Mdot
.66409 .43174 Mdot
.33256 .25796 Mdot
.73613 .30309 Mdot
.61301 .75714 Mdot
.82908 .59413 Mdot
.66787 .43434 Mdot
.66869 .60902 Mdot
.77508 .36062 Mdot
.28268 .34091 Mdot
.35848 .4512 Mdot
.45355 .47525 Mdot
.7149 .48728 Mdot
.60321 .70944 Mdot
.41496 .79264 Mdot
.5411 .84637 Mdot
.82079 .54761 Mdot
.35146 .45723 Mdot
.53922 .7162 Mdot
.44991 .32333 Mdot
.51997 .7907 Mdot
.84999 .52013 Mdot
.25127 .70953 Mdot
.52469 .39101 Mdot
.40005 .79953 Mdot
.40025 .36043 Mdot
.51378 .70609 Mdot
.54995 .71438 Mdot
.80408 .58518 Mdot
.54069 .27236 Mdot
.55517 .40367 Mdot
.42105 .36932 Mdot
.59118 .68622 Mdot
.38967 .51721 Mdot
.70772 .2764 Mdot
.39944 .32697 Mdot
.85006 .51032 Mdot
.31975 .743 Mdot
.75839 .35776 Mdot
.86334 .48612 Mdot
.50423 .35272 Mdot
.38555 .51814 Mdot
.1705 .46448 Mdot
.54356 .73467 Mdot
.2712 .55411 Mdot
.59625 .45915 Mdot
.5635 .69287 Mdot
.46494 .23935 Mdot
.46971 .74332 Mdot
.48325 .71066 Mdot
.46728 .32829 Mdot
.3531 .75739 Mdot
.46389 .32972 Mdot
.54098 .84383 Mdot
.48019 .45473 Mdot
.60319 .38124 Mdot
.76262 .3191 Mdot
.3465 .53409 Mdot
.44665 .21734 Mdot
.70966 .74328 Mdot
.66026 .67376 Mdot
.48514 .3046 Mdot
.49782 .29287 Mdot
.56035 .28563 Mdot
.27758 .38571 Mdot
.76834 .68456 Mdot
.42768 .82453 Mdot
.34215 .57539 Mdot
.56335 .31329 Mdot
.69225 .46552 Mdot
.61523 .41418 Mdot
.62799 .7832 Mdot
.298 .61175 Mdot
.80457 .66366 Mdot
.68052 .25088 Mdot
.45472 .23009 Mdot
.47177 .4262 Mdot
.68654 .61986 Mdot
.54089 .67485 Mdot
.36726 .55198 Mdot
.59748 .41868 Mdot
.44673 .27664 Mdot
.54978 .32888 Mdot
.39004 .529 Mdot
.45209 .70789 Mdot
.35251 .59763 Mdot
.29677 .37062 Mdot
.68594 .28722 Mdot
.44935 .82799 Mdot
.46764 .30605 Mdot
.50711 .69109 Mdot
.37511 .57524 Mdot
.74471 .45297 Mdot
.67952 .64651 Mdot
.85067 .58066 Mdot
.73286 .71986 Mdot
.47336 .33668 Mdot
.43237 .22612 Mdot
.22267 .58666 Mdot
.61219 .79458 Mdot
.5362 .40656 Mdot
.45138 .81857 Mdot
.71157 .35284 Mdot
.65088 .77874 Mdot
.59909 .36959 Mdot
.45432 .45913 Mdot
.4205 .80905 Mdot
.42548 .71055 Mdot
.3971 .80267 Mdot
.74364 .31535 Mdot
.72992 .50823 Mdot
.33415 .7724 Mdot
.42035 .38454 Mdot
.56155 .42756 Mdot
.66306 .54572 Mdot
.46428 .44003 Mdot
.48245 .82499 Mdot
.51861 .34542 Mdot
.47748 .73497 Mdot
.54035 .24326 Mdot
.36362 .44975 Mdot
.74458 .71481 Mdot
.41032 .22767 Mdot
.42193 .81956 Mdot
.75078 .52044 Mdot
.48134 .78163 Mdot
.66398 .25751 Mdot
.6494 .67081 Mdot
.52416 .57776 Mdot
.69877 .33467 Mdot
.50976 .54921 Mdot
.63023 .75918 Mdot
.74967 .44735 Mdot
.80052 .64699 Mdot
.65719 .74405 Mdot
.44754 .34934 Mdot
.503 .53649 Mdot
.54676 .28715 Mdot
.81038 .64751 Mdot
.61944 .75344 Mdot
.32947 .26673 Mdot
.45031 .83574 Mdot
.38601 .76446 Mdot
.86647 .47976 Mdot
.4053 .34115 Mdot
.66922 .41534 Mdot
.50537 .83858 Mdot
.48756 .39274 Mdot
.34243 .74991 Mdot
.57945 .42172 Mdot
.47069 .28342 Mdot
.82123 .61156 Mdot
.45856 .5809 Mdot
.43897 .34785 Mdot
.78097 .46218 Mdot
.49332 .27118 Mdot
.62394 .74708 Mdot
.64866 .4293 Mdot
.28607 .56336 Mdot
.67715 .61659 Mdot
.25898 .7062 Mdot
.55712 .27985 Mdot
.44514 .82228 Mdot
.45725 .81716 Mdot
.47203 .75975 Mdot
.38362 .59248 Mdot
.86607 .47796 Mdot
.71465 .40029 Mdot
.62972 .42925 Mdot
.46939 .31679 Mdot
.48916 .70362 Mdot
.40477 .77758 Mdot
.66355 .52894 Mdot
.66766 .63655 Mdot
.7097 .34665 Mdot
.70023 .76576 Mdot
.41584 .42376 Mdot
.36649 .42119 Mdot
.56271 .32781 Mdot
.33392 .26531 Mdot
.50251 .21969 Mdot
.41302 .30576 Mdot
.48143 .82271 Mdot
.44732 .50405 Mdot
.44973 .4698 Mdot
.46741 .37033 Mdot
.45918 .80267 Mdot
.34393 .47893 Mdot
.30995 .37351 Mdot
.65935 .28078 Mdot
.83328 .53161 Mdot
.49994 .38506 Mdot
.42311 .50116 Mdot
.50755 .44078 Mdot
.72065 .50131 Mdot
.36477 .45077 Mdot
.4126 .33426 Mdot
.49101 .29018 Mdot
.79752 .61115 Mdot
.5105 .46923 Mdot
.50455 .66103 Mdot
.38375 .78217 Mdot
.49474 .44697 Mdot
.45953 .82103 Mdot
.68238 .41047 Mdot
.80814 .59344 Mdot
.55326 .74646 Mdot
.4398 .74497 Mdot
.60043 .48041 Mdot
.52326 .23359 Mdot
.66684 .7767 Mdot
.52832 .40625 Mdot
.4582 .50923 Mdot
.57286 .34114 Mdot
.47236 .84893 Mdot
.53189 .60252 Mdot
.17384 .54498 Mdot
.52809 .54425 Mdot
.67363 .62712 Mdot
.66964 .61489 Mdot
.27926 .37507 Mdot
.5992 .41351 Mdot
.36312 .49616 Mdot
.72142 .49006 Mdot
.66405 .27992 Mdot
.55548 .81303 Mdot
.85085 .55525 Mdot
.49053 .24699 Mdot
.44175 .84023 Mdot
.51397 .24528 Mdot
.4731 .26958 Mdot
.32306 .74341 Mdot
.45769 .51416 Mdot
.72506 .43668 Mdot
.45833 .74386 Mdot
.50801 .35333 Mdot
.84674 .54944 Mdot
.46705 .49631 Mdot
.47102 .73671 Mdot
.24977 .5384 Mdot
.40959 .51176 Mdot
.22742 .36951 Mdot
.35732 .36987 Mdot
.48351 .84929 Mdot
.43806 .81055 Mdot
.37357 .40533 Mdot
.54255 .42783 Mdot
.46783 .50313 Mdot
.80965 .6072 Mdot
.51494 .53985 Mdot
.72531 .7319 Mdot
.37763 .35185 Mdot
.68359 .29633 Mdot
.65572 .74214 Mdot
.60401 .75073 Mdot
.64965 .67622 Mdot
.70926 .32159 Mdot
.77353 .64655 Mdot
.48086 .57761 Mdot
.34878 .59312 Mdot
.22176 .64934 Mdot
.84594 .52816 Mdot
.46145 .22409 Mdot
.47112 .5709 Mdot
.52953 .78853 Mdot
.51017 .46659 Mdot
.54908 .6836 Mdot
.38793 .42812 Mdot
.50536 .679 Mdot
.3345 .33803 Mdot
.43475 .21041 Mdot
.71585 .75383 Mdot
.59113 .47049 Mdot
.62659 .58311 Mdot
.34164 .49245 Mdot
.26164 .57114 Mdot
.56334 .27271 Mdot
.84931 .57808 Mdot
.29982 .38054 Mdot
.17494 .454 Mdot
.28539 .3684 Mdot
.60623 .79171 Mdot
.16534 .5422 Mdot
.27451 .39591 Mdot
.53686 .84638 Mdot
.4605 .23783 Mdot
.74057 .32598 Mdot
.41853 .20629 Mdot
.63628 .75761 Mdot
.69525 .33116 Mdot
.5302 .62082 Mdot
.76388 .70434 Mdot
.54087 .68329 Mdot
.48825 .73152 Mdot
.78297 .63142 Mdot
.41429 .80718 Mdot
.37243 .77693 Mdot
.29081 .45151 Mdot
.50855 .26247 Mdot
.17198 .5727 Mdot
.32681 .53003 Mdot
.66655 .21016 Mdot
.73367 .71742 Mdot
.78837 .43256 Mdot
.53191 .40527 Mdot
.40121 .39731 Mdot
.80833 .61687 Mdot
.47161 .81632 Mdot
.55476 .43443 Mdot
.33812 .62063 Mdot
.58729 .75596 Mdot
.51565 .78595 Mdot
.40218 .37379 Mdot
.66969 .76554 Mdot
.36517 .55133 Mdot
.46477 .55921 Mdot
.42675 .81504 Mdot
.52749 .23611 Mdot
.64535 .66426 Mdot
.83228 .53446 Mdot
.67344 .6578 Mdot
.37359 .78694 Mdot
.37368 .34975 Mdot
.21855 .60353 Mdot
.8396 .5374 Mdot
.48945 .2298 Mdot
.72876 .36095 Mdot
.87665 .45777 Mdot
.7867 .68433 Mdot
.47019 .50294 Mdot
.69252 .52921 Mdot
.52415 .84321 Mdot
.31867 .62254 Mdot
.58289 .79813 Mdot
.66228 .22936 Mdot
.35218 .76676 Mdot
.76005 .46044 Mdot
.68808 .53096 Mdot
.52247 .69937 Mdot
.49096 .37059 Mdot
.51083 .27056 Mdot
.30815 .51847 Mdot
.39153 .7918 Mdot
.68628 .28288 Mdot
.65354 .22111 Mdot
.7381 .30956 Mdot
.47688 .32225 Mdot
.74643 .72143 Mdot
.47571 .5256 Mdot
.67192 .26009 Mdot
.80631 .60435 Mdot
.66344 .59261 Mdot
.35899 .48406 Mdot
.6578 .26016 Mdot
.55345 .73199 Mdot
.25413 .70057 Mdot
.86505 .49193 Mdot
.66702 .29564 Mdot
.80998 .65555 Mdot
.62991 .80377 Mdot
.48682 .31071 Mdot
.55066 .27258 Mdot
.53746 .66957 Mdot
.48186 .48249 Mdot
.29152 .33745 Mdot
.32165 .52248 Mdot
.37089 .75999 Mdot
.35967 .60295 Mdot
.63974 .44495 Mdot
.4089 .37069 Mdot
.69425 .76146 Mdot
.51078 .71004 Mdot
.70605 .75339 Mdot
.69667 .30749 Mdot
.6118 .48567 Mdot
.88428 .44075 Mdot
.35659 .25877 Mdot
.76207 .49794 Mdot
.50141 .62173 Mdot
.4721 .56701 Mdot
.66313 .45389 Mdot
.29049 .43258 Mdot
.52612 .73907 Mdot
.32716 .75728 Mdot
.76608 .69968 Mdot
.56243 .31643 Mdot
.53972 .67825 Mdot
.35326 .37435 Mdot
.59583 .66004 Mdot
.76045 .45437 Mdot
.29555 .3825 Mdot
.2964 .73714 Mdot
.22721 .37524 Mdot
.35072 .46919 Mdot
.39122 .51477 Mdot
.57116 .68191 Mdot
.4755 .57037 Mdot
.31129 .74147 Mdot
.28046 .3677 Mdot
.34654 .48783 Mdot
.41877 .81783 Mdot
.71711 .3315 Mdot
.39692 .3721 Mdot
.22085 .62872 Mdot
.5441 .70738 Mdot
.4127 .37315 Mdot
.49442 .49135 Mdot
.72316 .28233 Mdot
.79075 .63646 Mdot
.25004 .54678 Mdot
.48016 .57879 Mdot
.77901 .36665 Mdot
.79788 .64523 Mdot
.34997 .40374 Mdot
.55426 .8407 Mdot
.47144 .50849 Mdot
.56009 .26823 Mdot
.79145 .44937 Mdot
.66141 .42715 Mdot
.57584 .46385 Mdot
.69476 .51692 Mdot
.63609 .62724 Mdot
.2178 .37461 Mdot
.64241 .42114 Mdot
.40363 .51688 Mdot
.44687 .49757 Mdot
.50792 .73168 Mdot
.57957 .46042 Mdot
.65928 .49603 Mdot
.52639 .60741 Mdot
.5743 .73676 Mdot
.51033 .68066 Mdot
.49632 .73526 Mdot
.39503 .36688 Mdot
.31148 .74268 Mdot
.36822 .77413 Mdot
.72449 .41773 Mdot
.81361 .61458 Mdot
.65377 .54152 Mdot
.72732 .72405 Mdot
.39376 .44487 Mdot
.39852 .35031 Mdot
.67553 .65059 Mdot
.86314 .494 Mdot
.4412 .32603 Mdot
.5396 .51798 Mdot
.61955 .80445 Mdot
.68615 .76101 Mdot
.3851 .39783 Mdot
.35689 .24121 Mdot
.22453 .66008 Mdot
.53364 .69059 Mdot
.44032 .20873 Mdot
.34264 .58265 Mdot
.62079 .79518 Mdot
.72534 .4834 Mdot
.46479 .50966 Mdot
.70117 .27681 Mdot
.74881 .46123 Mdot
.3167 .60404 Mdot
.73295 .288 Mdot
.71063 .3215 Mdot
.77107 .64979 Mdot
.63508 .43139 Mdot
.44289 .43341 Mdot
.4511 .32277 Mdot
.8439 .52068 Mdot
.32457 .55228 Mdot
.66822 .60775 Mdot
.67308 .21725 Mdot
.22075 .37156 Mdot
.34276 .74871 Mdot
.8242 .5427 Mdot
.36005 .36982 Mdot
.71854 .48832 Mdot
.26987 .29039 Mdot
.44641 .32298 Mdot
.47254 .30818 Mdot
.29427 .37212 Mdot
.49061 .78094 Mdot
.42849 .34901 Mdot
.87533 .47421 Mdot
.64716 .78182 Mdot
.71422 .42702 Mdot
.65133 .19441 Mdot
.43066 .81618 Mdot
.65172 .60384 Mdot
.40386 .3349 Mdot
.73252 .73415 Mdot
.30976 .33536 Mdot
.51038 .83985 Mdot
.49476 .45563 Mdot
.55104 .27759 Mdot
.51082 .78075 Mdot
.41358 .21331 Mdot
.68745 .45071 Mdot
.65255 .21261 Mdot
.38107 .23565 Mdot
.53339 .7796 Mdot
.52529 .41879 Mdot
.46384 .26729 Mdot
.46178 .25798 Mdot
.4804 .42958 Mdot
.44157 .52365 Mdot
.42466 .50047 Mdot
.45638 .46752 Mdot
.34594 .47715 Mdot
.46285 .42358 Mdot
.34837 .26366 Mdot
.32099 .34971 Mdot
.71745 .30595 Mdot
.23454 .67475 Mdot
.49013 .74045 Mdot
.2741 .59723 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0]Oooool2o`0009;ooooo000Looooo`03o`000?oooooooooo0;Gooooo0_l0002Boooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo0_l0002mooooo`;o0000Roooool001cooooo00?o0000ooooooooool0_?ooool4
o`0008Wooooo000Looooo`03o`000?oooooooooo0;kooooo1?l00027ooooo`007?ooool00ol0003o
ooooooooo`2nooooo`Go0000Q_ooool001cooooo00?o0000ooooooooool0`?ooool3o`0008Kooooo
000Looooo`03o`000?oooooooooo0<7ooooo1Ol00023ooooo`007?ooool00ol0003oooooooooo`33
ooooo`?o0000Poooool001cooooo00?o0000ooooooooool0aOooool2o`0008;ooooo000Looooo`03
o`000?oooooooooo0<Gooooo0ol00021ooooo`007?ooool00ol0003oooooooooo`36ooooo`;o0000
POooool001cooooo00?o0000ooooooooool0b_ooool2o`0007gooooo000Looooo`03o`000?oooooo
oooo0<[ooooo0_l0001mooooo`007?ooool00ol0003oooooooooo`3:ooooo`;o00000_ooool2o`00
07Wooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool0
0ol0003oooooooooo`3:ooooo`;o00000_ooool2o`0007Wooooo00001_ooooooMgMgoiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003ooooo
ooooo`3@ooooo`;o0000Moooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_oo
ool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0=3ooooo0_l0001gooooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003o
oooood[ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIV
I_ooool01Oooool00ol0003oooooooooo`26ooooo`;o00001Oooool3o`0000;ooooo0_l0000moooo
o`?o0000MOooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool03Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo08Cooooo1?l00003ooooo`Go00000_ooool2o`0000;o
oooo0_l0000iooooo`?o0000MOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0
003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0P_ooool4o`0000?ooooo1?l00000
0ooooooo0000o`000006ooooo`;o00000_ooool2o`0003Kooooo1Ol0001booooo`0000Koooooonk^
k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`1jooooo`;o00001_ooool3o`0000Cooooo0_l00008ooooo`;o00001Oooool2o`000003oooo
ool0003o0000037ooooo0_l00002ooooo`?o0000L_ooool001cooooo00?o0000ooooooooool0NOoo
ool3o`0000Oooooo0_l00008ooooo`;o00001?ooool2o`0000Gooooo0_l000001?oooooo0000o`00
0?ooool2o`0002kooooo0_l00003ooooo`Co0000L?ooool001cooooo00?o0000ooooooooool0NOoo
ool2o`0000oooooo0_l000000ooooooo0000o`00000;ooooo`;o00000oooool3o`0002kooooo0ol0
0002ooooo`Go0000Koooool001cooooo00?o0000ooooooooool0Ooooool2o`000003ooooool0003o
000000Kooooo0_l00006ooooo`;o00001_ooool2o`0000?ooooo0_l0000_ooooo`Co000000Cooooo
o`000?l0003ooooo0_l0001_ooooo`007?ooool00ol0003oooooooooo`1dooooo`;o00001_ooool2
o`000004ooooool0003o0000ooooo`;o00001Oooool2o`0000Oooooo0_l00006ooooo`;o00002_oo
ool3o`0002Wooooo1Ol000000ooooooo0000o`00001_ooooo`007?ooool00ol0003oooooooooo`1d
ooooo`?o00001Oooool2o`0000Cooooo0_l00002ooooo`Go00001Oooool2o`000003ooooool0003o
000000Kooooo0_l00009ooooo`?o0000:_ooool7o`0006oooooo000Looooo`03o`000?oooooooooo
07;ooooo0_l000000ooooooo0000o`00000=ooooo`Ko00001_ooool2o`000003ooooool0003o0000
00Kooooo0_l00009ooooo`;o0000:oooool5o`00077ooooo000Looooo`03o`000?oooooooooo07;o
oooo0_l00004ooooo`;o00002_ooool2o`00023ooooo1?l0000Yooooo`;o000000?oooooo`000?l0
0000LOooool001cooooo00?o0000ooooooooool0Moooool3o`0000?ooooo0_l0000Cooooo`?o0000
2_ooool2o`0000Oooooo0_l0000Yooooo`Go0000LOooool001cooooo00?o0000ooooooooool0K_oo
ool4o`0000Gooooo0_l00004ooooo`;o00004oooool3o`0000Cooooo0_l00002ooooo`Co00003?oo
ool2o`0002?ooooo1?l0001cooooo`007?ooool00ol0003oooooooooo`1]ooooo`Go00001?ooool2
o`0001kooooo1Ol00002ooooo`?o00000oooool3o`0000Kooooo0ol0000Sooooo`Ko0000LOooool0
01cooooo00?o0000ooooooooool0Joooool4o`000003ooooool0003o000000Cooooo0_l000000ooo
oooo0000o`00000Kooooo`?o00000oooool4o`0000?ooooo1Ol00004ooooo`;o00008oooool2o`00
00;ooooo0ol00002ooooo`;o0000KOooool001cooooo0_l0001/ooooo`;o00002Oooool2o`000003
ooooool0003o0000027ooooo0ol00005ooooo`Co00000oooool2o`0002Cooooo1ol000001?oooooo
0000o`000?l0001]ooooo`007?ooool00ol0003oooooooooo`1Wooooo`?o000000?oooooo`000?l0
00001?ooool2o`0000?ooooo0_l0000aooooo`Co00009?ooool7o`000003ooooool0003o000006ko
oooo000Looooo`03o`000?oooooooooo06Oooooo0ol00007ooooo`;o00007oooool3o`0001?ooooo
0ol0000Vooooo`Oo00001?ooool2o`0006_ooooo000Looooo`03o`000?oooooooooo06Kooooo1?l0
0006ooooo`?o00007oooool5o`0000cooooo0_l00003ooooo`;o00009oooool7o`0000Cooooo1?l0
001Yooooo`007?ooool00ol0003oooooooooo`1Qooooo`;o00000oooool2o`0000;ooooo0_l00000
1?oooooo0000o`000?ooool4o`0001kooooo0_l000000ooooooo0000o`00000:ooooo`Co0000:ooo
ool4o`000004ooooool0003o0000o`0000Kooooo0_l000000ooooooo0000o`00001Vooooo`007?oo
ool00ol0003oooooooooo`1Qooooo`Co00000_ooool5o`000004ooooool0003o0000ooooo`Co0000
6_ooool2o`0000;ooooo0ol0000<ooooo`;o00001?ooool4o`000003ooooool0003o000000Gooooo
0_l0000Kooooo`?o00000_ooool3o`0000Wooooo0_l0001Vooooo`007?ooool00ol0003ooooooooo
o`1Nooooo`;o000000?oooooo`000?l000000_l00002ooooo`Co00001Oooool2o`0001Wooooo0_l0
00000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000002_ooool2o`000003ooooool0
003o000000Oo00001?ooool3o`0001cooooo0_l00003ooooo`;o0000LOooool001cooooo00?o0000
ooooooooool0G_ooool5o`0002Oooooo0ol00005ooooo`;o00000_ooool2o`0000Cooooo0_l00004
ooooo`;o000000?oooooo`000?l000001ol000001?oooooo0000o`000?ooool3o`0001cooooo0_l0
001fooooo`007?ooool00ol0003oooooooooo`1Oooooo`?o00001_ooool5o`0001gooooo0_l00000
0ooooooo0000o`000003ooooo`;o00000oooool2o`000003ooooool0003o000000;o00001?ooool2
o`0000;ooooo2?l000000ooooooo0000o`000002ooooo`;o00007?ooool3o`0000cooooo1?l0001U
ooooo`007?ooool00ol0003oooooooooo`1Jooooo`;o00000oooool2o`0000Oooooo1Ol0000Koooo
o`Co000000?oooooo`000?l000002?ooool2o`000003ooooool0003o000000Gooooo0_l00006oooo
o`Go000000?oooooo`000?l000000_l0000Nooooo`Go00002_ooool4o`000003ooooool0003o0000
00?ooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1Iooooo`Go00001_ooool2o`00027o
oooo1Ol0000;ooooo`;o00002?ooool2o`0000Cooooo0_l000000ooooooo0000o`000007o`0001ko
oooo1Ol00005ooooo`;o00002?ooool4o`000003ooooool0003o000005gooooo000Looooo`03o`00
0?oooooooooo05Wooooo1Ol00006ooooo`;o00008Oooool2o`0000Kooooo0_l00004ooooo`Go0000
3Oooool2o`000003ooooool0003o000000?o000000?oooooo`000?l000000_l0000Nooooo`;o0000
1oooool2o`0000[ooooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`1Booooo`;o000000?o
ooooo`000?l000000_ooool2o`0000Wooooo0_l0000Oooooo`Co00001_ooool2o`000003ooooool0
003o000000Ko00002?ooool3o`0000?ooooo3?l0000Mooooo`?o00001oooool2o`0000gooooo0ol0
001Looooo`007?ooool00ol0003oooooooooo`1@ooooo`So0000;?ooool5o`0000Kooooo2ol00002
ooooo`;o00001?ooool>o`00027ooooo0ol00007ooooo`;o000000?oooooo`000?l000002_ooool3
o`0005cooooo000Looooo`03o`000?oooooooooo053ooooo2ol0000Xooooo`Co00002_ooool9o`00
00;ooooo1?l000000ooooooo0000o`00000=o`0002;ooooo0_l0000:ooooo`;o0000JOooool001co
oooo00?o0000ooooooooool0D?ooool;o`0002Sooooo1?l00006ooooo`;o00001oooool4o`0000Co
oooo4_l000000ooooooo0000o`00000Oooooo`;o000000?oooooo`000?l000000oooool2o`0000Wo
oooo0_l0001Rooooo`007?ooool2o`0008Cooooo1?l00003ooooo`;o000000?oooooo`000?l00000
1oooool3o`0000Cooooo5_l0000Oooooo`Go00000oooool2o`0000Oooooo1?l00009ooooo`;o0000
Eoooool001cooooo00?o0000ooooooooool0QOooool2o`0000?ooooo0_l00009ooooo`?o00000_oo
ool2o`000003ooooool0003o000001;o00008_ooool2o`0000kooooo0_l00006ooooo`;o00000ooo
ool2o`0005Oooooo000Looooo`03o`000?oooooooooo087ooooo0ol0000@ooooo`?o000000?ooooo
o`000?l000005ol00007ooooo`;o00006Oooool4o`0000Sooooo0_l00004ooooo`;o00001?ooool2
o`0005cooooo000Looooo`03o`000?oooooooooo083ooooo1?l0000@oooooago000000?oooooo`00
0?l000001?ooool2o`0001_ooooo0_l00008ooooo`;o00001?ooool2o`0000Gooooo0_l0001Koooo
o`007?ooool00ol0003oooooooooo`20ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o
000000?oooooo`000?l000006_l00003ooooo`;o00006oooool2o`0000gooooo0_l00003ooooo`;o
000000?oooooo`000?l00000Foooool001cooooo00?o0000ooooooooool0R?ooool2o`0000Gooooo
0ol000000ooooooo0000o`000002o`0000;ooooo6Ol000000ooooooo0000o`000003ooooo`;o0000
6oooool3o`0000cooooo0_l00003ooooo`?o00000_ooool2o`0005Wooooo000Looooo`03o`000?oo
oooooooo08;ooooo1Ol00009ooooo`;o000000?oooooo`000?l000007Ol000000ooooooo0000o`00
0003ooooo`;o00007?ooool2o`00017ooooo0ol00002ooooo`;o00001?ooool2o`0005?ooooo000L
ooooo`03o`000?oooooooooo08;ooooo1Ol00006ooooo`Go000000?oooooo`000?l000004?l00000
0ooooooo0000o`00000:o`0000Kooooo0_l0000Yooooo`;o00003oooool2o`0005?ooooo000Loooo
o`03o`000?oooooooooo08?ooooo0_l00007ooooo`Go00000_ooool2o`000003ooooool0003o0000
01[o0000;?ooool2o`0000?ooooo0_l00008ooooo`Co0000F?ooool001cooooo00?o0000oooooooo
ool0O_ooool2o`000003ooooool0003o000000?ooooo0_l00004ooooo`Go000000?oooooo`000?l0
00000_l00002oooooaWo00000_ooool2o`0002Wooooo0_l0000=ooooo`Co0000F?ooool001cooooo
00?o0000ooooooooool0O_ooool5o`0000?ooooo0_l00007ooooo`;o000000?oooooo`000?l00000
0_l000000ooooooo0000o`00000Io`000003ooooool0003o000002Wooooo0_l00005ooooo`;o0000
2?ooool2o`0005Sooooo000Looooo`03o`000?oooooooooo067ooooo0_l0000Iooooo`;o000000?o
ooooo`000?l000002?l0000:ooooo`;o000000?oooooo`000?l000005ol000001?oooooo0000o`00
0?l0000[ooooo`?o00001?ooool4o`0000;ooooo0_l00002ooooo`Co0000E_ooool001cooooo00?o
0000ooooooooool0E?ooool2o`0000Gooooo1Ol000001?oooooo0000o`000?l00005ooooo`;o0000
4?ooool3o`000004ooooool0003o0000ooooo`Oo00002Oooool2o`000003ooooool0003o000001Oo
000000?oooooo`000?l000000ol0000[ooooo`;o000000?oooooo`000?l000000oooool2o`0000;o
oooo1?l00002ooooo`?o0000EOooool001cooooo00?o0000ooooooooool0E?ooool2o`0000;ooooo
0_l000000ooooooo0000o`000003o`000004ooooool0003o0000o`0000Gooooo0ol000000ooooooo
0000o`000002ooooo`;o00002?ooool2o`0000?ooooo1Ol000001?oooooo0000o`000?l00003oooo
o`;o00001?ooool2o`000003ooooool0003o000001Ko000000?oooooo`000?l000001?l00002oooo
o`;o0000:_ooool2o`0000Oooooo1?l00002ooooo`Co0000E?ooool001cooooo00?o0000oooooooo
ool0D?ooool2o`0000Kooooo0_l00003ooooo`;o00000_ooool2o`0000Oooooo0_l000000ooooooo
0000o`000002ooooo`;o00003Oooool4o`0000;ooooo0_l00004ooooo`;o00001ooooolFo`0000;o
oooo1_l00003ooooo`;o00008oooool2o`0000Gooooo0_l0000?ooooo`;o0000E?ooool001cooooo
00?o0000ooooooooool0D?ooool2o`0000Sooooo0_l000000ooooooo0000o`00000Booooo`;o0000
0oooool2o`0000;ooooo0_l00005ooooo`;o00002?ooool2o`000003ooooool0003o000000Gooooo
2?l000000ooooooo0000o`000008o`000005ooooool0003o0000o`000?ooool01_l00007ooooo`;o
00007oooool2o`0000Gooooo0ol00006ooooo`;o00001_ooool3o`0005?ooooo000Looooo`;o0000
Eoooool3o`000003ooooool0003o000000Wooooo0_l0000:ooooo`;o00000oooool2o`0000;ooooo
2Ol00004ooooo`;o00000_ooool2o`000003ooooool0003o000000?ooooo2ol00002ooooo`Oo0000
00?oooooo`000?l000003Ol00003ooooo`;o00008?ooool3o`0000Cooooo0_l00006ooooo`;o0000
0_ooool2o`0000;ooooo0ol0001Cooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00001ooo
ool3o`0000cooooo0_l0000<ooooo`;o000000Coooooo`000?l0003o00000oooool6o`0000Gooooo
0_l00005ooooo`;o00000oooool2o`0000;ooooo3?l00005ooooo`oo00000oooool2o`00023ooooo
0ol00004ooooo`;o00001Oooool7o`0000Cooooo0_l0001Booooo`007?ooool00ol0003ooooooooo
o`1=ooooo`?o00001_ooool2o`00013ooooo0_l00002ooooo`;o00001Oooool6o`0000Cooooo0_l0
000Gooooo`go00001_ooool:o`000003ooooool0003o000000Cooooo0_l0000Pooooo`;o00001Ooo
ool2o`0000Gooooo1_l00004ooooo`Co0000DOooool001cooooo00?o0000ooooooooool0C_ooool2
o`0000cooooo0_l0000:ooooo`;o00000_ooool2o`0000Oooooo0_l00006ooooo`;o00001_ooool2
o`0000oooooo2ol00005ooooo`;o000000?oooooo`000?l000000_l00004ooooo`Go00001?ooool2
o`0000Cooooo0_l0000Jooooo`;o00003Oooool2o`000003ooooool0003o000000?ooooo1_l0001@
ooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o000000?oooooo`000?l000000oooool3o`00
00Gooooo0_l0000?ooooo`;o00003oooool3o`0000Cooooo0_l0000?ooooo`co00001?ooool2o`00
00?ooooo0_l00006ooooo`;o000000?oooooo`000?l000001oooool3o`0002Gooooo1?l00004oooo
o`_o0000Coooool001cooooo00?o0000ooooooooool0B?ooool2o`000005ooooool0003o0000o`00
0?ooool00_l00003ooooo`?o00003Oooool2o`000004ooooool0003o0000ooooo`;o000000?ooooo
o`000?l000003_ooool4o`0001Gooooo0_l00002ooooo`Go000000?oooooo`000?l000005?ooool2
o`0000Oooooo0_l0000Vooooo`Co00001?ooool4o`0000;ooooo1Ol0001?ooooo`007?ooool00ol0
003oooooooooo`18ooooo`;o000000?oooooo`000?l000002?ooool6o`0000Sooooo0ol000000ooo
oooo0000o`000003o`0000Gooooo0_l00003ooooo`;o00001Oooool2o`0000Kooooo0_l0000Coooo
o`Go00000_ooool2o`0001Sooooo0ol000000ooooooo0000o`00000Vooooo`;o00001oooool3o`00
00Gooooo0ol0001>ooooo`007?ooool00ol0003oooooooooo`14ooooo`Co00001Oooool3o`0000Go
oooo1_l000001?oooooo0000o`000?l00002ooooo`_o00001?ooool3o`0000?ooooo0_l00005oooo
o`;o00000_ooool2o`0000;ooooo0_l0000=ooooo`;o000000?oooooo`000?l000000_ooool4o`00
0004ooooool0003o0000o`0001Sooooo0ol000000ooooooo0000o`00000_ooooo`Co00001?ooool3
o`0004kooooo000Looooo`03o`000?oooooooooo04?ooooo1Ol00005ooooo`?o00001Oooool4o`00
00?ooooo0ol00002ooooo`_o00000oooool4o`0000Cooooo0_l00004ooooo`Oo00004?ooool2o`00
0003ooooool0003o000000;ooooo1?l000000ooooooo0000o`00000Looooo`?o00000_ooool2o`00
023ooooo0_l0000:ooooo`?o00001Oooool2o`0004kooooo000Looooo`03o`000?oooooooooo04?o
oooo0_l000000ooooooo0000o`00000=ooooo`Co00002?ooool@o`0000Kooooo0_l00002ooooo`;o
00000_ooool2o`000003ooooool0003o000001Gooooo1ol0000Mooooo`?o00000_ooool4o`0001oo
oooo0_l000000ooooooo0000o`00000?ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0
G_oooolCo`0000Wooooo0ol0000Looooo`So00000_ooool3o`0001Oooooo0_l000000ooooooo0000
o`000004o`0001oooooo0_l000000ooooooo0000o`00000@ooooo`;o0000COooool001cooooo00?o
0000ooooooooool0B?ooool2o`0000_ooooo0_l00005oooooaKo00002?ooool3o`0000Sooooo0_l0
000Cooooo`;o000000?oooooo`000?l000000_l00002ooooo`?o00006_ooool2o`00037ooooo0_l0
0005ooooo`;o0000COooool001cooooo00?o0000ooooooooool0@_ooool2o`0000Cooooo0_l0000;
ooooo`?o00001?oooolFo`0000;ooooo0_l000000ooooooo0000o`000004o`0000Cooooo0_l00002
ooooo`;o00003_ooool2o`0000Sooooo0_l00002ooooo`?o000000?oooooo`000?l000003Oooool2
o`0000Wooooo1?l0000Iooooo`;o00004oooool3o`0000Gooooo0_l0001<ooooo`007?ooool00ol0
003oooooooooo`11ooooo`?o00004_ooool2o`0000;ooooo5ol00003ooooo`;o000000?oooooo`00
0?l000000_l00006ooooo`;o00004_ooool2o`0000Sooooo0_l00002ooooo`?o000000?oooooo`00
0?l000003Oooool2o`0000Kooooo1ol0000Iooooo`;o00002Oooool2o`0000Wooooo1?l00003oooo
o`;o0000C?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l00000
0ol@413oooooooooo`04ooooo`03o`000?oooooooooo047ooooo0_l0000GoooooaOo00005?ooool2
o`0001Cooooo0_l00007ooooo`Go00000_ooool2o`0000Oooooo1?l00002ooooo`Oo0000:?ooool2
o`0000;ooooo0_l00007ooooo`;o0000DOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Ooo
ool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Eooooo`;o00000ooo
oolHo`0000;ooooo0_l0000?ooooo`;o00005?ooool2o`0000Oooooo1Ol00002ooooo`;o00000_oo
ool2o`0000?ooooo1?l000000ooooooo0000o`000003o`000003ooooool0003o000002cooooo0_l0
001Jooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`Go00001_ooool0
0ol0003oooooooooo`0nooooo`;o00005Oooool2o`0000?ooooo6?l000001?oooooo0000o`000?l0
0003ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Mooooo`;o00003oooool2o`0000Sooooo
0_l00004ooooo`;o00001_ooool2o`0000Cooooo0_l0000?ooooo`;o00005_ooool3o`00053ooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo0000
1oooool3o`0003kooooo0_l0000Eooooo`;o00000ooooolHo`000004ooooool0003o0000ooooo`;o
000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00000Mooooo`;o00008oooool2o`00
00;ooooo0_l00004ooooo`;o00003oooool2o`0000Cooooo0_l0000@ooooo`?o00001?ooool2o`00
04[ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoo
oooo00001oooool00ol0003oooooooooo`1Hoooooago000000?oooooo`000?l000000ol00002oooo
o`;o0000:Oooool3o`0000Kooooo0_l0000@ooooo`;o00006?ooool2o`0000Gooooo0_l00005oooo
o`;o00002Oooool3o`0000Cooooo0_l0001:ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413o
ooooooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0F?oooolMo`000003
ooooool0003o000000;o00000oooool2o`0000?ooooo0_l0000Tooooo`Co00001Oooool2o`0000Co
oooo0_l00006ooooo`;o00000oooool2o`0001Oooooo0_l00009ooooo`;o000000?oooooo`000?l0
00002oooool3o`0000;ooooo0_l0001:ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<oooo
o`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0F?oooolKo`0000Gooooo0_l00003oooo
o`;o00000oooool2o`0002Kooooo0_l0000;ooooo`;o00001_ooool2o`0000?ooooo0_l0000Doooo
o`;o00003?ooool2o`000003ooooool0003o000000_ooooo1?l0001=ooooo`0000Koooooonk^k_lb
<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0??ooool2
o`0001[ooooo6_l00012ooooo`;o00002Oooool3o`0000;ooooo0ol0000?ooooo`;o00000_ooool3
o`0000kooooo0ol0000<ooooo`;o0000COooool001cooooo00?o0000ooooooooool0??ooool2o`00
01[ooooo3?l000000ooooooo0000o`00000;o`0000Cooooo0_l0000looooo`;o000000?oooooo`00
0?l000001Oooool4o`0000;ooooo0ol00002ooooo`;o00002oooool2o`000003ooooool0003o0000
00;o00002oooool2o`0000;ooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`1HoooooaCo
000000?oooooo`000?l000000_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Toooo
o`;o00001_ooool4o`0000;ooooo0_l00008ooooo`?o00001?ooool2o`0000Sooooo0ol00002oooo
o`;o00002_ooool2o`0000gooooo0_l00002ooooo`;o00003Oooool2o`0004cooooo000Looooo`03
o`000?oooooooooo05Oooooo1?l00003oooooa3o000000?oooooo`000?l000000_ooool5o`000003
ooooool0003o000000Sooooo0_l0000>ooooo`;o00002_ooool2o`0000Kooooo1?l000001?oooooo
0000o`000?l00004ooooo`;o00000oooool2o`0000kooooo0_l00003ooooo`;o00001oooool2o`00
0003ooooool0003o0000017ooooo0_l0000<ooooo`?o0000C?ooool001cooooo00?o0000oooooooo
ool0Eoooool4o`0000?ooooo4?l00005ooooo`Co00003?ooool2o`0000kooooo1?l0000Eooooo`;o
00001Oooool2o`0000?ooooo0_l0000Iooooo`;o000000Coooooo`000?l0003ooooo0_l00009oooo
o`;o00001_ooool2o`0000;ooooo0_l00008ooooo`Ko0000BOooool001cooooo00?o0000oooooooo
ool0F?ooool5o`0000;ooooo3ol0000<ooooo`;o00002Oooool2o`0000kooooo0_l000000ooooooo
0000o`00000Booooo`?o00001?ooool2o`000003ooooool0003o000000Gooooo0_l00002ooooo`;o
00001_ooool2o`0000Cooooo0_l00002ooooo`;o00003oooool2o`0000Kooooo1_l00008ooooo`Ko
0000BOooool001cooooo00?o0000ooooooooool0Foooool2o`0000?ooooo2_l0000@ooooo`;o0000
2Oooool2o`0000Gooooo0_l0000:ooooo`;o00004Oooool4o`000003ooooool0003o000000Cooooo
0_l00005ooooo`;o00000_ooool2o`0000Gooooo1Ol00002ooooo`;o00000oooool2o`0001Kooooo
1?l0000:ooooo`Ko00007_ooool2o`0002Wooooo000Looooo`03o`000?oooooooooo05_ooooo0ol0
0006ooooo`Co00002oooool2o`0001Oooooo0_l00005ooooo`;o00005_ooool3o`0000;ooooo0_l0
0004ooooo`;o00003oooool7o`0000Kooooo0ol00007ooooo`;o00002?ooool2o`00013ooooo1?l0
000Pooooo`;o0000:Oooool001cooooo00?o0000ooooooooool0G?ooool2o`0001Cooooo0ol0000N
ooooo`;o00005oooool2o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l000002Oooool<
o`0000Gooooo0_l00007ooooo`;o00002?ooool2o`0000Cooooo0_l0000:ooooo`?o00008?ooool2
o`0002[ooooo000Looooo`03o`000?oooooooooo03Kooooo0_l0000Tooooo`;o00005?ooool3o`00
01kooooo0_l0000<ooooo`;o00004Oooool2o`0000?ooooo0_l00006ooooo`;o000000?oooooo`00
0?l000002ol0000Fooooo`Co00000oooool2o`0000[ooooo0ol0000Nooooo`Co0000:_ooool001co
oooo00?o0000ooooooooool0=_ooool2o`0002Cooooo0ol0000Eooooo`;o00001_ooool2o`0002?o
oooo0_l0000;ooooo`;o00001?ooool2o`0000;ooooo1Ol00004ooooo`;o000000?oooooo`000?l0
00002ol0000;ooooo`;o00002Oooool4o`00013ooooo1?l0000Looooo`Co0000:_ooool001cooooo
00?o0000ooooooooool0GOooool2o`0001;ooooo0_l000000ooooooo0000o`000006ooooo`;o0000
0_ooool2o`0001_ooooo0_l00009ooooo`;o00001?ooool2o`0000Sooooo1Ol000000ooooooo0000
o`00000Co`0000Gooooo0_l00002ooooo`;o00004_ooool2o`0000Wooooo1?l0000Mooooo`?o0000
:_ooool001cooooo0_l0001Looooo`;o00005?ooool4o`0000?ooooo0_l00006ooooo`;o00006ooo
ool2o`0000Wooooo0_l0000<ooooo`;o00000_oooolKo`0000;ooooo0ol00002ooooo`;o00004_oo
ool2o`0000Sooooo1Ol0000Nooooo`;o0000:_ooool001cooooo00?o0000ooooooooool0=Oooool2
o`0002?ooooo0ol0000@ooooo`;o00000_ooool4o`0000?ooooo0_l0000Nooooo`;o00000oooool2
o`0001Oooooo0_l00002oooooaco000000?oooooo`000?l000000oooool2o`00013ooooo0_l00003
ooooo`;o00001Oooool3o`0004cooooo000Looooo`03o`000?oooooooooo03Gooooo0_l0000Qoooo
o`Co00004?ooool4o`000003ooooool0003o000002Gooooo0_l00003ooooo`;o000000?oooooo`00
0?l000000_l0000<ooooo`;o00001Oooool2o`000003ooooool0003o000001[o00001Oooool2o`00
00Gooooo0_l0000:ooooo`;o00000oooool2o`0000Gooooo0_l0000Mooooo`;o0000;_ooool001co
oooo00?o0000ooooooooool0F?ooool3o`000003ooooool0003o000000kooooo1ol00002ooooo`;o
00006Oooool2o`0000Oooooo0_l00005ooooo`Co00003?ooool2o`0000Cooooo1?l00003oooooaWo
00001Oooool2o`0000Gooooo0_l0000;ooooo`;o00000_ooool2o`0000Gooooo0_l0000Mooooo`Co
0000;?ooool001cooooo00?o0000ooooooooool0=?ooool2o`0002?ooooo1Ol0000Aooooo`Co0000
0_ooool2o`0001Wooooo1?l00005ooooo`;o00006?ooool2o`000003ooooool0003o000000Co0000
00?oooooo`000?l000006?l0000Hooooo`?o000000?oooooo`000?l000001?ooool3o`0001gooooo
1?l0000/ooooo`007?ooool00ol0003oooooooooo`0dooooo`;o00008_ooool5o`0001;ooooo0ol0
000Nooooo`Co00002Oooool2o`0000?ooooo0_l0000?ooooo`;o00000_oooolQo`000003ooooool0
003o000000;ooooo0_l0000Aooooo`;o00001oooool3o`0001kooooo0_l0000]ooooo`007?ooool0
0ol0003oooooooooo`1Hooooo`Go00000_ooool2o`0000gooooo1?l0000Looooo`Co00001_ooool2
o`0000?ooooo0_l00003ooooo`;o00004ooooolTo`0000;ooooo0_l0000Aooooo`;o00001oooool2
o`0001oooooo0_l0000]ooooo`007?ooool00ol0003oooooooooo`0booooo`;o00009Oooool9o`00
0003ooooool0003o000000Wooooo0_l0000Nooooo`;o00002?ooool2o`0000Sooooo0_l0000:oooo
o`;o00000_ooool4o`000004ooooool0003o0000o`0000;ooooo7_l00005ooooo`;o00004Oooool2
o`0000Gooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`0booooo`;o00009Oooool6o`00
0003ooooool0003o000000?o00002?ooool2o`0001kooooo1Ol0000Looooo`;o00000_ooool4o`00
00;ooooo0_l00005oooooa_o00001Oooool3o`00013ooooo0_l00005ooooo`;o00006oooool4o`00
02oooooo000Looooo`03o`000?oooooooooo05[ooooo1Ol00002ooooo`?o00002?ooool3o`0001ko
oooo0_l000000ooooooo0000o`00000Pooooo`?o00000oooool2o`0000Gooooo6ol000000ooooooo
0000o`000002ooooo`?o00005oooool2o`0001[ooooo1Ol0000_ooooo`007?ooool00ol0003ooooo
ooooo`1Jooooo`?o00001?ooool4o`0000Oooooo0_l00008ooooo`;o00008Oooool2o`0000;ooooo
0_l0000Iooooo`;o00001OoooolPo`0000Wooooo0_l0000>ooooo`;o000000?oooooo`000?l00000
6?ooool3o`00037ooooo000Looooo`03o`000?oooooooooo05_ooooo0_l00004ooooo`Go00002ooo
ool2o`0000?ooooo0_l0000Iooooo`;o00001_ooool2o`0000;ooooo1?l00002ooooo`;o00004?oo
ool2o`0000Cooooo0_l00002ooooo`;o00000_oooolHo`0000;ooooo0_l00003ooooo`;o00001?oo
ool2o`0000Oooooo0_l00005ooooo`;o000000?oooooo`000?l000006?ooool2o`0003;ooooo000L
ooooo`03o`000?oooooooooo037ooooo0_l0000_ooooo`Co00001oooool2o`0000;ooooo0_l0000?
ooooo`;o00003Oooool2o`000003ooooool0003o000000Oooooo1?l00002ooooo`;o00003Oooool2
o`000003ooooool0003o000000?ooooo1Ol00002oooooa_o00001_ooool6o`0000Wooooo0_l00005
ooooo`;o00006oooool3o`00037ooooo000Looooo`03o`000?oooooooooo037ooooo0_l0000`oooo
o`Co00000oooool7o`0000kooooo0_l000000ooooooo0000o`00000@ooooo`;o00001oooool2o`00
01?ooooo0_l00005ooooo`[o00000_oooolGo`0000Kooooo1ol0000/ooooo`?o0000<Oooool001co
oooo00?o0000ooooooooool0<Oooool2o`0002oooooo0_l000001Ooooooo0000o`000?l0003ooooo
00So00003_ooool2o`0001Gooooo0_l00005ooooo`;o00006_ooool;o`000003ooooool0003o0000
01Ko00001Oooool2o`0000?ooooo0_l00002ooooo`;o0000:?ooool2o`0003;ooooo000Looooo`03
o`000?oooooooooo02oooooo1?l0000_ooooo`;o00000_ooool6o`0000Kooooo0_l0000Iooooo`;o
00001Oooool4o`0002Cooooo8ol00004ooooo`;o00001_ooool2o`0000?ooooo0ol000000ooooooo
0000o`00000Oooooo`;o0000<_ooool001cooooo0_l0000`ooooo`;o0000;_ooool2o`0000Gooooo
0ol00006ooooo`;o000000?oooooo`000?l000004_ooool2o`0000Gooooo0_l00005ooooo`;o0000
9Oooool3o`0000;ooooo8?l00003ooooo`;o000000?oooooo`000?l000002?ooool3o`000003oooo
ool0003o000001kooooo0_l0000cooooo`007?ooool00ol0003oooooooooo`1Oooooo`?o000000?o
ooooo`000?l000000oooool2o`0000Gooooo0_l0000Booooo`;o000000?oooooo`000?l000001Ooo
ool3o`0000Cooooo0ol00007ooooo`;o00006oooool2o`0000?ooooo1ol00002oooooaOo00000ooo
ool2o`000003ooooool0003o000002cooooo0_l0000cooooo`007?ooool00ol0003oooooooooo`0_
ooooo`;o0000:Oooool;o`000003ooooool0003o000000;o00005Oooool2o`000004ooooool0003o
0000o`0000Sooooo0ol00004ooooo`?o00001oooool2o`0002?ooooo6Ol00002ooooo`;o0000JOoo
ool001cooooo00?o0000ooooooooool0;oooool2o`0002Oooooo3?l00002ooooo`;o00000_ooool2
o`0001?ooooo0_l000000ooooooo0000o`00000=ooooo`Ko0000;?ooool7o`000003ooooool0003o
000000oo000000?oooooo`000?l000001_ooool2o`0000;ooooo0_l00008ooooo`;o00000oooool2
o`0001Kooooo0_l000000ooooooo0000o`00000dooooo`007?ooool00ol0003oooooooooo`1Goooo
o`Co00000_ooool5o`0000Kooooo1?l00009ooooo`Co00002?ooool2o`0000;ooooo0_l0000:oooo
o`Ko00003Oooool2o`0000?ooooo0ol00005ooooo`;o00004_ooool5o`0000;ooooo4?l000000ooo
oooo0000o`000006ooooo`Ko00000oooool2o`0000?ooooo0_l00003ooooo`;o00005_ooool2o`00
0003ooooool0003o000003Cooooo000Looooo`03o`000?oooooooooo033ooooo0_l0000Sooooo`Co
00003oooool2o`0000_ooooo1?l00002ooooo`;o00000_ooool4o`0000;ooooo0_l00004ooooo`Co
00000_ooool2o`0000cooooo0ol00002ooooo`;o00000oooool5o`0000?ooooo0_l0000Aooooo`ko
000000?oooooo`000?l000002ol00007ooooo`;o00001Oooool2o`00023ooooo0_l0000gooooo`00
7?ooool00ol0003oooooooooo`0`ooooo`;o00008_ooool3o`0000Wooooo0_l0000Hooooo`?o0000
0_ooool2o`0000[ooooo1?l00006ooooo`;o000000?oooooo`000?l000001Oooool3o`0000Oooooo
0_l000000ooooooo0000o`00000Foooooaco00001_ooool3o`0000Gooooo0_l0000Pooooo`?o0000
=_ooool001cooooo00?o0000ooooooooool0E?ooool3o`0000Wooooo0_l00002ooooo`?o00004ooo
ool2o`00013ooooo0_l00007ooooo`;o000000?oooooo`000?l000000_l0000@ooooo`?o00006Ooo
ool>o`000003ooooool0003o000000?o000000Coooooo`000?l0003o00001_ooool4o`0000Cooooo
1?l00002ooooo`;o00006?ooool5o`0003Kooooo000Looooo`03o`000?oooooooooo057ooooo0_l0
00001?oooooo0000o`000?l00003ooooo`;o000000?oooooo`000?l000001Oooool3o`0000?ooooo
1?l0000Looooo`Co00002Oooool5o`000003ooooool0003o000000;o00001oooool4o`000003oooo
ool0003o000001Wooooo4ol00003ooooo`;o00000_ooool2o`0000;ooooo1?l00006ooooo`;o0000
00Coooooo`000?l0003o00006?ooool2o`000003ooooool0003o000003Kooooo000Looooo`03o`00
0?oooooooooo057ooooo0_l00007ooooo`;o000000Coooooo`000?l0003o00002_ooool5o`0000co
oooo0_l00006ooooo`;o00001Oooool4o`0000Wooooo3?l00005ooooo`Co00007Oooool7o`0000?o
oooo3Ol00002ooooo`Co00002_ooool2o`000003ooooool0003o000001Wooooo1?l0000gooooo`00
7?ooool00ol0003oooooooooo`0cooooo`;o00009?ooool7o`0000Kooooo0_l00005ooooo`?o0000
2oooool2o`0000Kooooo0_l0000Dooooo`Ko000000?oooooo`000?l000000ol00003ooooo`?o0000
0_ooool4o`0001Sooooo5ol000000ooooooo0000o`000003o`0000Sooooo0_l000001?oooooo0000
o`000?l0000Gooooo`;o000000?oooooo`000?l000000_l0000gooooo`007?ooool00ol0003ooooo
ooooo`0cooooo`;o00006Oooool2o`0000Sooooo1ol000000ooooooo0000o`000003o`000003oooo
ool0003o000000Gooooo1_l000000ooooooo0000o`000005ooooo`;o00003_ooool4o`0000_ooooo
1Ol000000ooooooo0000o`000004o`0000;ooooo0_l00003ooooo`Co00006_ooool<o`000003oooo
ool0003o000000;ooooo1?l000000ooooooo0000o`000002o`000003ooooool0003o000000Gooooo
0ol000001?oooooo0000o`000?l0000Gooooo`;o000000?oooooo`000?l00000>Oooool001cooooo
00?o0000ooooooooool0<Oooool2o`0001[ooooo0ol00006ooooo`Ko000000?oooooo`000?l00000
1_l00008ooooo`Ko000000?oooooo`000?l000001oooool2o`0000cooooo1?l0000<ooooo`;o0000
0oooool3o`000005ooooool0003o0000o`000?ooool00_l00002ooooo`;o00007_ooool2o`000003
ooooool0003o000000[o000000?oooooo`000?l000001?l000001?oooooo0000o`000?ooool2o`00
00;ooooo0_l000001?oooooo0000o`000?ooool2o`0001Wooooo1?l0000jooooo`007?ooool00ol0
003oooooooooo`0aooooo`;o00006_ooool2o`000003ooooool0003o000000Cooooo3_l0000Ioooo
o`;o00003?ooool2o`0000_ooooo0_l00006ooooo`;o00000_ooool5o`0000?ooooo0ol000000ooo
oooo0000o`00000Moooooa?o00002?ooool2o`0000Cooooo0ol0000Jooooo`?o0000>Oooool001co
oooo00?o0000ooooooooool0<?ooool4o`000003ooooool0003o000001Gooooo0_l00002ooooo`;o
000000?oooooo`000?l000002?l000000ooooooo0000o`000004o`0000Gooooo0_l000000ooooooo
0000o`00000<ooooo`Co00006Oooool3o`0000Kooooo0_l00002ooooo`;o000000Coooooo`000?l0
003o00000_ooool3o`000003ooooool0003o000001kooooo7?l00005ooooo`;o00005Oooool3o`00
00?ooooo0ol0000hooooo`007?ooool00ol0003oooooooooo`0`ooooo`Co000000?oooooo`000?l0
00004oooool6o`0000?ooooo2ol000000ooooooo0000o`000004o`0000Cooooo0_l000000ooooooo
0000o`000004ooooo`;o00001_ooool4o`0000;ooooo0_l00005ooooo`;o00003?ooool5o`0000Ko
oooo0_l000001?oooooo0000o`000?l00002ooooo`;o00000_ooool2o`0002Kooooo6_l0000Ioooo
o`Co00001?ooool2o`0003Sooooo000Looooo`;o0000=_ooool2o`0001?ooooo0_l00002ooooo`;o
00000ooooolCo`0000cooooo0_l0000<ooooo`;o00001Oooool2o`0000cooooo2?l000001?oooooo
0000o`000?ooool7o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0002;ooooo0_l00000
0ooooooo0000o`00000Eo`0001Wooooo0_l00006ooooo`;o000000?oooooo`000?l00000=Oooool0
01cooooo00?o0000ooooooooool0=Oooool2o`0001Gooooo0_l00005ooooo`go000000?oooooo`00
0?l000001Ol0000;ooooo`Go00006oooool2o`0000?ooooo3Ol000001?oooooo0000o`000?ooool2
o`0000Gooooo0_l0000VoooooaGo00006Oooool2o`0000Oooooo0_l000001?oooooo0000o`000?l0
000dooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00004Oooool2o`000003ooooool0003o
000000;o00001?oooolFo`0000Wooooo1Ol00005ooooo`;o00000_ooool2o`00013ooooo5?l0000a
ooooo`?o000000?oooooo`000?l000003?l0000Looooo`;o00002Oooool4o`0003Cooooo000Loooo
o`03o`000?oooooooooo03Kooooo0_l0000Aooooo`;o00000oooool2o`0000Cooooo5ol0000<oooo
o`;o00001?ooool2o`0000;ooooo0_l0000@oooooaCo000000?oooooo`000?l00000>Oooool4o`00
02[ooooo1?l0000dooooo`007?ooool00ol0003oooooooooo`1=ooooo`Ko000000?oooooo`000?l0
00003?l000000ooooooo0000o`000003o`000003ooooool0003o000000cooooo1?l0000Hooooo`;o
00000ooooolBo`0000;ooooo0_l0001Kooooo`;o00001_ooool4o`0003Cooooo000Looooo`03o`00
0?oooooooooo03Cooooo1?l0000Doooooago00004?ooool2o`0001Kooooo0_l00003oooooa?o0000
0oooool2o`0005Oooooo0_l00002ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0=?oo
ool4o`0001Cooooo0ol000000ooooooo0000o`00000Ko`0000cooooo0_l0000Fooooo`;o00000_oo
oolEo`0000;ooooo0_l0001Gooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0=?ooool4
o`0001?ooooo1?l00002oooooaco00003?ooool2o`0001Gooooo5ol000000ooooooo0000o`00002O
ooooo`007?ooool00ol0003oooooooooo`0booooo`Co00005Oooool2o`0000?ooooo7Ol00009oooo
o`;o000000?oooooo`000?l000005Oooool2o`000003ooooool0003o000001Go0000Woooool001co
oooo00?o0000ooooooooool0<_ooool2o`0000?ooooo0_l0000<ooooo`;o00001?ooool2o`0000?o
oooo6_l000000ooooooo0000o`000009ooooo`;o000000?oooooo`000?l000006?oooolGo`0005Oo
oooo0_l00003ooooo`;o00002?ooool2o`0003Oooooo000Looooo`03o`000?oooooooooo03Oooooo
0_l0000<ooooo`;o00002OoooolIo`00013ooooo0_l0000Fooooo`;o000000Coooooo`000?l0003o
oooo5?l0001Fooooo`?o00000_ooool2o`0000Sooooo0_l0000gooooo`007?ooool00ol0003ooooo
ooooo`1@oooooaWo00000oooool2o`0002;ooooo1ol000000ooooooo0000o`00000Ao`0000;ooooo
0_l0000Gooooo`Co0000>?ooool2o`0000cooooo0_l0000gooooo`007?ooool00ol0003ooooooooo
o`15ooooo`;o00002OoooolHo`000004ooooool0003o0000ooooo`;o00008_ooool2o`000003oooo
ool0003o000000;o000000?oooooo`000?l000004Ol00002ooooo`;o00005oooool4o`0003Oooooo
1?l00005ooooo`;o00000_ooool2o`0003Wooooo000Looooo`03o`000?oooooooooo04Gooooo0_l0
000:oooooa[o0000:Oooool3o`000003ooooool0003o0000017o00000_ooool2o`0001Oooooo0ol0
0003ooooo`;o0000<oooool4o`0000Gooooo0_l00002ooooo`;o0000>Oooool00006ooooooo^k^ko
<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03
o`000?oooooooooo04Cooooo0_l0000;oooooa[o00000oooool2o`0000Kooooo0_l000000ooooooo
0000o`00000IoooooaSo000000?oooooo`000?l000005oooool3o`0000?ooooo0_l00006ooooo`;o
0000:_ooool2o`000003ooooool0003o000000Cooooo0_l0000nooooo`0000KoooooogMgMonHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000
ooooooooool0@oooool3o`0000gooooo5ol00002ooooo`Go00001Oooool2o`000003ooooool0003o
000001Wooooo6_l0000Vooooo`;o0000:_ooool2o`000003ooooool0003o000000Cooooo0_l0000n
ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`13ooooo`;o00003ooooolFo`0000;ooooo1_l00004
ooooo`;o00007_ooool2o`000003ooooool0003o000001?o0000GOooool2o`0003cooooo00000ooo
oooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@06
ooooo`?o0000@oooool2o`0000oooooo5Ol000000ooooooo0000o`000002ooooo`Go00009_oooolD
o`0005Wooooo0_l00003ooooo`;o0000??ooool00003ooooool0003ooooo00;ooooo00?o0000oooo
ooooool02Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0@oooool2
o`0000oooooo5Ol000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000_ooool2
o`00023ooooo5Ol0000Tooooo`;o0000<?ooool2o`0000;ooooo0_l00011ooooo`0000?ooooooa0@
4?ooool00_ooool00ol@413oooooooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000oooo
ooooool0A_ooool2o`0000kooooo4ol000001?oooooo0000o`000?ooool3o`0000;ooooo0_l00000
0ooooooo0000o`00000NoooooaCo000000?oooooo`000?l000009?ooool2o`0000?ooooo0_l00002
ooooo`;o00009oooool4o`0004?ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00?o
gMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`16ooooo`;o00003ooooolBo`0000Cooooo0_l0
0003ooooo`;o00008Oooool2o`000003ooooool0003o000000oo0000;?ooool2o`0000;ooooo0_l0
000Tooooo`;o00000_ooool6o`00043ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo
00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`13ooooo`;o00004_ooool4o`000003
ooooool0003o000000[o00000_ooool2o`0002kooooo3?l00002ooooo`;o0000;?ooool2o`0002Oo
oooo0_l00003ooooo`Go0000@?ooool001cooooo00?o0000ooooooooool0@oooool2o`000003oooo
ool0003o0000017ooooo0_l000000ooooooo0000o`000006o`0000;ooooo0_l00002ooooo`;o0000
;_ooool:o`0000Cooooo0_l0000/ooooo`Co00000oooool2o`0002Cooooo0ol000000ooooooo0000
o`000002o`000003ooooool0003o000003_ooooo000Looooo`03o`000?oooooooooo04Kooooo0_l0
000Aooooo`_o00001_ooool3o`0002gooooo1?l000000ooooooo0000o`000002o`0000Gooooo0_l0
000[ooooo`Go000000?oooooo`000?l000000ol0000Sooooo`;o00000_ooool4o`000003ooooool0
003o000003_ooooo000Looooo`03o`000?oooooooooo05_ooooo0_l000000ooooooo0000o`00000=
o`0002kooooo1_l00003ooooo`;o00000_ooool2o`0002_ooooo1?l00002ooooo`Go0000JOooool0
01cooooo00?o0000ooooooooool0Goooool=o`00033ooooo1_l00002ooooo`;o000000?oooooo`00
0?l000008_ooool2o`0000[ooooo0_l00003ooooo`;o0000:?ooool2o`00047ooooo000Looooo`03
o`000?oooooooooo04?ooooo0ol0000Pooooo`Go0000=?ooool3o`0000Gooooo0_l0000Pooooo`Co
000000?oooooo`000?l000000_l00005ooooo`;o00000oooool2o`0002Sooooo0_l00011ooooo`00
7?ooool00ol0003oooooooooo`13ooooo`?o0000H_ooool2o`0001oooooo1?l000000ooooooo0000
o`000003o`0000Wooooo0_l0000Mooooo`;o00002_ooool2o`00043ooooo000Looooo`03o`000?oo
oooooooo04Sooooo0_l0001Iooooo`;o00000oooool2o`0002Gooooo1?l00002ooooo`;o00001Ooo
ool2o`0001gooooo1?l00008ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0B?ooool2
o`0000Kooooo0_l0001Aooooo`;o00000_ooool2o`0002Oooooo0ol00002ooooo`;o00001Oooool2
o`0001gooooo1?l000000ooooooo0000o`000017ooooo`007?ooool00ol0003oooooooooo`14oooo
o`;o00002_ooool2o`0004Cooooo1?l0000=ooooo`;o0000:?ooool4o`0000Oooooo0_l0000Joooo
o`;o00001_ooool2o`0004Oooooo000Looooo`03o`000?oooooooooo04Cooooo0_l00006ooooo`;o
0000Aoooool5o`0000cooooo0ol0000Cooooo`;o00001?ooool2o`0000kooooo0ol00004ooooo`Co
00006_ooool3o`0000Gooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o0000
1_ooool2o`0004Oooooo0_l00002ooooo`?o00002_ooool3o`0001?ooooo0_l00004ooooo`;o0000
3oooool2o`0000Cooooo1?l0000Jooooo`;o000000?oooooo`000?l000000oooool3o`000003oooo
ool0003o000004Cooooo000Looooo`;o0000AOooool2o`00053ooooo0_l000001?oooooo0000o`00
0?l0000;ooooo`?o0000:Oooool2o`0000?ooooo0_l0000Mooooo`;o000000?oooooo`000?l00000
1?ooool5o`0004Cooooo000Looooo`03o`000?oooooooooo04Cooooo0_l0001=ooooo`Wo00001?oo
ool2o`0000Kooooo1?l0000Xooooo`;o00000_ooool2o`0002Oooooo1?l00014ooooo`007?ooool0
0ol0003oooooooooo`14ooooo`?o0000Boooool:o`0000Cooooo0_l00005ooooo`Go000000?ooooo
o`000?l000001oooool2o`0001Oooooo1ol000001?oooooo0000o`000?ooool2o`0002Oooooo0_l0
0014ooooo`007?ooool00ol0003oooooooooo`15ooooo`;o0000BOooool9o`000004ooooool0003o
0000o`0000?ooooo0_l00005ooooo`Co00000_ooool2o`000004ooooool0003o0000o`0000?ooooo
0ol00002ooooo`Go00003_ooool7o`0000;ooooo0_l000000ooooooo0000o`00001]ooooo`007?oo
ool00ol0003oooooooooo`15ooooo`;o0000AOooool2o`000003ooooool0003o000000So000000?o
ooooo`000?l000000ol000000ooooooo0000o`000007ooooo`;o00001Oooool3o`0000Cooooo0_l0
0002ooooo`Go00003_ooool7o`0002gooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`15
ooooo`;o0000AOoooolCo`000003ooooool0003o000000Cooooo0_l0000Eooooo`Go00003?ooool7
o`0001oooooo0_l00006ooooo`;o00001?ooool2o`0004Gooooo000Looooo`03o`000?oooooooooo
04Gooooo0ol00014oooooa7o00002Oooool2o`0000?ooooo0_l00003ooooo`Oo00002?ooool5o`00
00Wooooo1_l0000Qooooo`;o00001_ooool2o`0004_ooooo000Looooo`03o`000?oooooooooo04Go
oooo0ol00014oooooa3o000000?oooooo`000?l000003?ooool2o`0000?ooooo2?l00009ooooo`?o
00002?ooool5o`0000;ooooo0ol0000Tooooo`;o0000COooool001cooooo00?o0000ooooooooool0
A_ooool4o`00043ooooo5Ol0000=ooooo`;o00002?ooool2o`0000Wooooo0ol00008ooooo`;o0000
00?oooooo`000?l000000_ooool3o`000003ooooool0003o0000027ooooo0_l0001=ooooo`007?oo
ool00ol0003oooooooooo`18ooooo`;o0000?_oooolFo`0000;ooooo0_l0000:ooooo`;o00002?oo
ool2o`0000[ooooo0_l00008ooooo`Go00000_ooool6o`0002Cooooo0_l0001:ooooo`007?ooool0
0ol0003oooooooooo`28oooooaGo00000oooool4o`0000Sooooo0_l000000ooooooo0000o`000005
ooooo`;o00002Oooool4o`0000Oooooo0ol00003ooooo`Go00009Oooool3o`0004[ooooo000Loooo
o`03o`000?oooooooooo08Wooooo5Ol00002ooooo`Co00002?ooool2o`000003ooooool0003o0000
00Gooooo0_l00004ooooo`;o000000?oooooo`000?l000001?l00006ooooo`?o00000_ooool6o`00
023ooooo0_l00004ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0R_oooolDo`000003
ooooool0003o000000gooooo0_l00005ooooo`;o00001?ooool9o`0000Oooooo0_l00002ooooo`?o
00009?ooool2o`0000Cooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`19ooooo`?o0000
?Oooool2o`000003ooooool0003o0000013o000000?oooooo`000?l000000_l00007ooooo`;o0000
0_ooool2o`0000?ooooo1?l00003ooooo`[o00001_ooool2o`0000;ooooo1?l0001gooooo`007?oo
ool00ol0003oooooooooo`19ooooo`?o0000??ooool3o`000003ooooool0003o0000013o00000ooo
ool2o`0000Gooooo1?l00007ooooo`Co00000oooool:o`0000Kooooo0_l000001?oooooo0000o`00
0?l0001iooooo`007?ooool00ol0003oooooooooo`28ooooo`;o00000_oooolBo`000003ooooool0
003o000000Oooooo0ol0000>ooooo`_o00002Oooool2o`0002[ooooo0_l0001>ooooo`007?ooool2
o`00053ooooo0_l0000gooooo`;o00000_oooolBo`000003ooooool0003o000000Gooooo1?l0000?
ooooo`Co00000_ooool3o`0000Kooooo0_l00002ooooo`;o00008oooool2o`0000;ooooo0_l00002
ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0C?ooool2o`000003ooooool0003o0000
03Sooooo0_l000000ooooooo0000o`00000@o`0000Gooooo0_l000000ooooooo0000o`000002o`00
00Wooooo0_l00003ooooo`Ko000000Coooooo`000?l0003o00001_ooool6o`0002?ooooo0_l00000
1Ooooooo0000o`000?l0003ooooo00;o0000Coooool001cooooo00?o0000ooooooooool0C?ooool2
o`0000;ooooo0_l0000gooooo`;o000000?oooooo`000?l000004?l00005ooooo`;o00000_ooool8
o`0000Cooooo0_l00003ooooo`Ko000000Coooooo`000?l0003o00000oooool3o`000004ooooool0
003o0000o`0002Sooooo0_l00002ooooo`;o0000Coooool001cooooo00?o0000ooooooooool0C_oo
ool4o`0003Cooooo0ol00003oooooa;o00001?ooool3o`0000;ooooo0_l000000ooooooo0000o`00
0003o`0000;ooooo1?l00004ooooo`?o00000oooool=o`0002Wooooo0_l0001Booooo`007?ooool0
0ol0003oooooooooo`1>ooooo`;o00000oooool2o`00037ooooo0ol00004oooooaCo000000?ooooo
o`000?l000000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000006o`0000Cooooo1?l00002
ooooo`So000000Coooooo`000?l0003o00009?ooool2o`0000Cooooo0_l0001Booooo`007?ooool0
0ol0003oooooooooo`1>ooooo`;o00000oooool4o`0003Kooooo3ol00002ooooo`?o00001Oooool2
o`0000;ooooo2ol00005ooooo`Go000000Coooooo`000?l0003ooooo1?l00002ooooo`;o00008?oo
ool2o`000004ooooool0003o0000o`0005Sooooo000Looooo`03o`000?oooooooooo05?ooooo1?l0
000`ooooo`;o00001Oooool:o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000001?oo
ool2o`0000;ooooo0_l00004ooooo`Co00001oooool;o`0002?ooooo0ol000000ooooooo0000o`00
001Iooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o0000<_ooool2o`0000Kooooo1?l00007
ooooo`;o00001Oooool3o`0000?ooooo0_l0000:ooooo`;o00002Oooool3o`000003ooooool0003o
000000;o00009?ooool2o`0000?ooooo0ol0001Gooooo`007?ooool00ol0003oooooooooo`2Aoooo
o`;o00001?ooool5o`0000Kooooo0_l0000?ooooo`;o0000<oooool2o`0000Gooooo0ol0001Goooo
o`007?ooool00ol0003oooooooooo`1Dooooo`;o0000<oooool2o`0000Sooooo1ol0000;ooooo`;o
00003oooool2o`00033ooooo0_l00005ooooo`;o0000F?ooool001cooooo00?o0000ooooooooool0
E?ooool2o`0003?ooooo0_l00008ooooo`Go00000_ooool3o`0000Cooooo0_l00002ooooo`?o0000
1_ooool4o`0000?ooooo0ol0000`ooooo`Go000000?oooooo`000?l00000FOooool001cooooo00?o
0000ooooooooool0ROooool2o`0000cooooo0_l000000ooooooo0000o`000003o`0000;ooooo0_l0
0002ooooo`?o00001Oooool6o`0000;ooooo1Ol0000Kooooo`?o00004?ooool5o`000003ooooool0
003o000005Wooooo000Looooo`03o`000?oooooooooo05Oooooo0_l00004ooooo`;o0000<Oooool2
o`0000?ooooo1?l00004ooooo`;o00001oooool3o`0000Cooooo0ol000000ooooooo0000o`000004
ooooo`Co00006_ooool3o`00017ooooo0ol0001Mooooo`007?ooool00ol0003oooooooooo`1Goooo
o`;o00001?ooool2o`0000;ooooo0_l0000]ooooo`;o00000oooool2o`0000Cooooo0_l000000ooo
oooo0000o`000004ooooo`Go00001Oooool2o`0000Oooooo1?l0000Fooooo`;o000000?oooooo`00
0?l000000_l0000<ooooo`;o00000oooool2o`0005kooooo000Looooo`03o`000?oooooooooo067o
oooo0_l000001?oooooo0000o`000?l0000Tooooo`;o00001?ooool2o`0000;ooooo0_l00003oooo
o`?o000000?oooooo`000?l000001?ooool5o`0001_ooooo0_l00004ooooo`;o00001Oooool5o`00
00gooooo0ol0001Sooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o00000_ooool2o`000004
ooooool0003o0000o`0002Cooooo0_l00004ooooo`;o00000_ooool2o`0000?ooooo0_l00009oooo
o`Go00001_ooool3o`00017ooooo0_l000001?oooooo0000o`000?ooool2o`0000Kooooo0_l0000<
ooooo`;o000000?oooooo`000?l00000I?ooool001cooooo0_l0001Nooooo`;o00002oooool4o`00
02Cooooo0_l0000Booooo`Go00001Oooool3o`0000cooooo0ol00005ooooo`;o00001Oooool3o`00
00oooooo0_l0001Wooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o00002oooool4o`0001oo
oooo0_l00003ooooo`;o00000_ooool2o`0000oooooo1Ol00007ooooo`;o00002_ooool3o`0000?o
oooo0_l00005ooooo`Oo00003oooool2o`000003ooooool0003o000006;ooooo000Looooo`03o`00
0?oooooooooo063ooooo0_l00005ooooo`;o00001_ooool2o`0000?ooooo0_l0000Gooooo`;o0000
1oooool2o`00013ooooo2?l00002ooooo`?o00001_ooool2o`0000Kooooo1?l00002ooooo`Oo0000
00?oooooo`000?l000002Oooool2o`0000Cooooo0_l000000ooooooo0000o`00001Rooooo`007?oo
ool00ol0003oooooooooo`1Pooooo`Go00000_ooool2o`0000Kooooo0_l00003ooooo`?o00007ooo
ool2o`00017ooooo2?l000000ooooooo0000o`000007ooooo`;o00001_ooool:o`0000oooooo0_l0
001[ooooo`007?ooool00ol0003oooooooooo`1Pooooo`Go00001Oooool2o`0000?ooooo0_l00004
ooooo`;o00002oooool2o`0001;ooooo0_l0000Aooooo`;o000000?oooooo`000?l000001Ol0000>
ooooo`co00003_ooool2o`000003ooooool0003o000006Wooooo000Looooo`03o`000?oooooooooo
06;ooooo0ol00005ooooo`;o00000oooool2o`0000Wooooo0_l00006ooooo`;o0000:?ooool7o`00
00Cooooo0_l000000ooooooo0000o`00000;o`0000oooooo0_l00003ooooo`;o000000?oooooo`00
0?l000000_l0001Wooooo`007?ooool00ol0003oooooooooo`1Sooooo`;o00000_ooool4o`0000Co
oooo0_l00007ooooo`Go0000;oooool:o`000003ooooool0003o000000So00005Oooool2o`0000;o
oooo1?l00002ooooo`;o0000Ioooool001cooooo00?o0000ooooooooool0Ioooool4o`0000Cooooo
0_l00006ooooo`Ko0000<oooool>o`000003ooooool0003o000001Wooooo1?l0001[ooooo`007?oo
ool00ol0003oooooooooo`1Yooooo`;o00001?ooool2o`0000;ooooo0ol000000ooooooo0000o`00
000>ooooo`;o00007Oooool2o`0000Sooooo0_l00002ooooo`So00006Oooool2o`0007;ooooo000L
ooooo`03o`000?oooooooooo07?ooooo1?l00005ooooo`;o00000_ooool2o`0000Gooooo0_l0000M
ooooo`;o0000:?ooool2o`0000?ooooo0_l00003ooooo`;o0000KOooool001cooooo00?o0000oooo
ooooool0L?ooool2o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`00
00Gooooo0ol0000?ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Gooooo0_l0000Soooo
o`Wo00000oooool2o`0006gooooo000Looooo`03o`000?oooooooooo073ooooo0_l00007ooooo`;o
00002oooool5o`0000kooooo0_l000000ooooooo0000o`000004ooooo`;o00001Oooool2o`0001go
oooo0_l00004ooooo`;o00000_ooool4o`0000?ooooo0_l0001^ooooo`007?ooool00ol0003ooooo
ooooo`1fooooo`;o00001Oooool2o`0000Oooooo0_l000000ooooooo0000o`00000Iooooo`;o0000
3?ooool2o`0001Cooooo0_l0000?ooooo`;o0000K_ooool001cooooo00?o0000ooooooooool0M_oo
ool3o`0000Cooooo0_l0000Eooooo`;o00002oooool2o`000005ooooool0003o0000o`000?ooool0
0_l00008ooooo`;o00000oooool2o`00093ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGo
oooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1foooo
o`?o00000_ooool2o`0000Kooooo0_l0000?ooooo`;o00002oooool2o`0000;ooooo0_l000000ooo
oooo0000o`000008ooooo`;o00000oooool2o`0000Gooooo0_l000000ooooooo0000o`000026oooo
o`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonH
V9So8B4Q00Kooooo00?o0000ooooooooool0N_ooool3o`0000Cooooo1Ol0000;ooooo`;o00003?oo
ool3o`00013ooooo0_l0000:ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`00
0021ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`1jooooo`?o000000Coooooo`000?l0003ooooo
0_l000000ooooooo0000o`00000;ooooo`;o00001Oooool2o`0000Gooooo0ol0000>ooooo`;o0000
2?ooool2o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000001oooool2o`0007Sooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RH
oc8b<P06ooooo`?o0000N_ooool2o`000004ooooool0003o0000o`00017ooooo0_l00005ooooo`;o
00001_ooool2o`0000kooooo0_l00008ooooo`;o00000oooool2o`0000Sooooo0_l000001?oooooo
0000o`000?ooool2o`0007Sooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wo
oooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo07cooooo0ol0000Boooo
o`;o00004oooool2o`0001gooooo0_l000000ooooooo0000o`000004o`0007_ooooo00000ooooooo
410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go410@okZj^_oooooo^[Zjoa0@4006oooo
o`03o`000?oooooooooo07cooooo0ol00004ooooo`Co00000oooool4o`0001Sooooo0_l0000=oooo
o`;o00003_ooool2o`000004ooooool0003o0000ooooo`;o0000O?ooool00006oooooomgMgOoV9RH
oooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0
OOooool3o`000003ooooool0003o000000Co00000oooool4o`0000Gooooo0_l0000Eooooo`Co0000
0oooool3o`000003ooooool0003o000000Kooooo0_l000000ooooooo0000o`000027ooooo`0000Ko
ooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0
003oooooooooo`1nooooo`Go00001?ooool2o`000004ooooool0003o0000o`0000Kooooo0_l0000;
ooooo`;o00002?ooool4o`0000;ooooo1?l00002ooooo`;o00001Oooool2o`000003ooooool0003o
000008Oooooo000Looooo`03o`000?oooooooooo083ooooo0_l00002ooooo`;o000000?oooooo`00
0?l000000ol00003ooooo`Co00000_ooool2o`0000Wooooo0_l0000>ooooo`;o00001?ooool2o`00
097ooooo000Looooo`03o`000?oooooooooo08Cooooo0ol000000ooooooo0000o`000002o`000003
ooooool0003o000000Go000000?oooooo`000?l000002Oooool2o`000:Oooooo000Looooo`03o`00
0?oooooooooo08?ooooo1_l00002ooooo`Wo00001Oooool2o`0000?ooooo1?l0002Wooooo`007?oo
ool00ol0003oooooooooo`23ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`00
0002o`0000Oooooo0_l00003ooooo`;o00001Oooool2o`000:;ooooo000Looooo`03o`000?oooooo
oooo08Oooooo0_l00005ooooo`;o00002Oooool2o`0000?ooooo0_l00005ooooo`;o0000X_ooool0
01cooooo00?o0000ooooooooool0R?ooool2o`0000oooooo0_l00002ooooo`;o0000Z_ooool001co
oooo00?o0000ooooooooool0R?ooool2o`0000Gooooo0_l0000<ooooo`;o0000Z_ooool001cooooo
00?o0000ooooooooool0R_ooool4o`000003ooooool0003o000000kooooo1Ol0000<ooooo`;o0000
Uoooool001cooooo00?o0000ooooooooool0R_ooool4o`000003ooooool0003o000000cooooo2?l0
00000ooooooo0000o`000002o`0000;ooooo0_l00002ooooo`Co0000UOooool001cooooo00?o0000
ooooooooool0WOooool2o`0000Cooooo0_l000000ooooooo0000o`000006o`0000Cooooo0_l00005
ooooo`;o0000S_ooool001cooooo00?o0000ooooooooool0U_ooool2o`000003ooooool0003o0000
00oooooo1?l00002ooooo`;o00001_ooool3o`0008kooooo000Looooo`;o0000Uoooool5o`00017o
oooo0_l00002ooooo`;o00001_ooool2o`0008oooooo000Looooo`03o`000?oooooooooo09Sooooo
0_l000000ooooooo0000o`00002/ooooo`007?ooool00ol0003oooooooooo`2Hooooo`;o000000?o
ooooo`000?l00000[?ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001;ooooo
1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooo
oooo00Gooooo0ol0003ooooood[ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Co
oooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo
000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001;ooooo00?oEEEEofIVI_l00000oooooomD
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00YOooool01?l@413o0000o`00
0?ooool2o`000003oa0@4?oooooooooo01Gooooo1Ol00003ooooo`Go00000oooool01Oo<c<co8B4Q
o`000?lQ8B7oc<c<093ooooo002Vooooo`05o`000?ooooooooooooooool000002Oooool6o`0000Wo
oooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool0
1OlQ8B7oV9RHoooooonHV9So8B4Q093ooooo002Vooooo`05o`000?ooooooooooooooool000006Ooo
ool00onHV9So8B4Qonk^kP05ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go0000oooooooooooooooo
o`00002@ooooo`00Y_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l0000;ooooo`03oiRH
V?lQ8B7ok^k^00Gooooo00?oV9RHob4Q8Oo^k^h00oooool01Olb<S;oV9RHoooooonHV9So<S8b093o
oooo002Vooooo`05o`000?n7QhOoooooojVYZOl000006oooool00omgMgOoIVIVooooo`05ooooo`03
ogMgMomVIVKooooo00;ooooo00Goc<c<o`000?l0003o0000olc<c02@ooooo`00YOooool00ol@413o
0000ogMgM`02o`000003oiRHV?oooooooooo01[ooooo00?o0000ooooooooool01Oooool02Ol0003o
oooooooooooooooo410@okZj^_oooooo^[Zjoa0@402@ooooo`00`oooool01Ol0003o^[ZjoooooonH
V9So410@00?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05o`000?nj^[[ooooookZj^_l0
0000T?ooool00<?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`00oooool01OnYZJWo410@o`000?l@413oZJVY093ooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(234) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.51941 .2989 Mdot
.53772 .32531 Mdot
.31481 .53094 Mdot
.64279 .5324 Mdot
.42352 .69978 Mdot
.29673 .57601 Mdot
.33583 .37614 Mdot
.34148 .36718 Mdot
.26469 .52668 Mdot
.75228 .46475 Mdot
.3284 .35231 Mdot
.67524 .5447 Mdot
.34935 .37977 Mdot
.64958 .5067 Mdot
.54918 .68664 Mdot
.61229 .49629 Mdot
.50346 .31785 Mdot
.45214 .64278 Mdot
.61115 .5013 Mdot
.25268 .54522 Mdot
.45938 .54161 Mdot
.66053 .50149 Mdot
.58127 .32863 Mdot
.6501 .5033 Mdot
.62834 .54913 Mdot
.54519 .33337 Mdot
.52032 .29907 Mdot
.64767 .57335 Mdot
.64232 .53901 Mdot
.31089 .37267 Mdot
.6869 .59298 Mdot
.59125 .77723 Mdot
.49608 .61068 Mdot
.71222 .37562 Mdot
.31531 .38754 Mdot
.29709 .36414 Mdot
.30818 .54625 Mdot
.31368 .39059 Mdot
.35625 .35175 Mdot
.33611 .35648 Mdot
.33129 .35829 Mdot
.54209 .33536 Mdot
.32846 .40493 Mdot
.18656 .41097 Mdot
.6462 .49369 Mdot
.69406 .27702 Mdot
.31166 .50555 Mdot
.67066 .54156 Mdot
.57755 .33596 Mdot
.2697 .51501 Mdot
.48789 .74921 Mdot
.35498 .36697 Mdot
.49143 .58092 Mdot
.63176 .17545 Mdot
.34487 .37204 Mdot
.61442 .52335 Mdot
.27308 .56657 Mdot
.63544 .47602 Mdot
.682 .49173 Mdot
.69014 .336 Mdot
.62961 .48742 Mdot
.43164 .66367 Mdot
.48249 .3219 Mdot
.28496 .50586 Mdot
.27175 .52157 Mdot
.3238 .40259 Mdot
.4947 .3219 Mdot
.33348 .39713 Mdot
.64906 .53869 Mdot
.25697 .55068 Mdot
.6386 .54805 Mdot
.32728 .35248 Mdot
.51806 .30396 Mdot
.6673 .5069 Mdot
.49073 .36399 Mdot
.29673 .39881 Mdot
.46536 .66025 Mdot
.57862 .2909 Mdot
.25267 .51534 Mdot
.56836 .66184 Mdot
.6655 .50383 Mdot
.2895 .26493 Mdot
.56095 .73415 Mdot
.5632 .31478 Mdot
.62607 .4542 Mdot
.37267 .23002 Mdot
.64986 .56194 Mdot
.68533 .58823 Mdot
.65949 .57981 Mdot
.49438 .65583 Mdot
.27246 .57143 Mdot
.56255 .34609 Mdot
.65893 .49223 Mdot
.66175 .53572 Mdot
.75251 .4483 Mdot
.62775 .52956 Mdot
.65342 .57461 Mdot
.51525 .56683 Mdot
.36052 .36538 Mdot
.50026 .59416 Mdot
.32126 .46745 Mdot
.48398 .5978 Mdot
.64133 .55294 Mdot
.29193 .56656 Mdot
.4867 .33171 Mdot
.49375 .60762 Mdot
.32591 .3928 Mdot
.65688 .49449 Mdot
.33857 .43945 Mdot
.57875 .332 Mdot
.6246 .5521 Mdot
.42982 .68199 Mdot
.44168 .51798 Mdot
.53263 .30322 Mdot
.78352 .38258 Mdot
.64444 .52669 Mdot
.65526 .47394 Mdot
.53552 .32709 Mdot
.25312 .56625 Mdot
.25112 .34433 Mdot
.51484 .31621 Mdot
.35448 .35928 Mdot
.50138 .32259 Mdot
.50914 .5969 Mdot
.25103 .55387 Mdot
.47597 .57036 Mdot
.50313 .5479 Mdot
.54979 .77826 Mdot
.63336 .52362 Mdot
.46568 .55259 Mdot
.29784 .56248 Mdot
.51828 .31546 Mdot
.355 .38597 Mdot
.65819 .46031 Mdot
.56153 .32839 Mdot
.33446 .37174 Mdot
.45735 .66167 Mdot
.44019 .64221 Mdot
.55255 .3078 Mdot
.77922 .37154 Mdot
.36506 .40868 Mdot
.36839 .39351 Mdot
.48972 .7487 Mdot
.56085 .31335 Mdot
.44729 .66606 Mdot
.33053 .39102 Mdot
.24969 .69236 Mdot
.61355 .53084 Mdot
.50393 .77006 Mdot
.29209 .26752 Mdot
.48769 .74838 Mdot
.4742 .53256 Mdot
.43993 .67752 Mdot
.33421 .37134 Mdot
.67564 .51029 Mdot
.54918 .31449 Mdot
.55851 .3294 Mdot
.64481 .54918 Mdot
.48607 .60804 Mdot
.6406 .50847 Mdot
.50621 .58855 Mdot
.49688 .54455 Mdot
.65461 .49241 Mdot
.69046 .25455 Mdot
.5695 .32549 Mdot
.63318 .45401 Mdot
.30308 .54084 Mdot
.46436 .60087 Mdot
.33379 .40585 Mdot
.64955 .4613 Mdot
.61178 .4544 Mdot
.67608 .54555 Mdot
.37314 .38847 Mdot
.46751 .2639 Mdot
.25845 .50892 Mdot
.34378 .3521 Mdot
.31712 .46051 Mdot
.29173 .54717 Mdot
.68167 .50236 Mdot
.43513 .6883 Mdot
.5014 .57426 Mdot
.67108 .51788 Mdot
.48423 .74849 Mdot
.68045 .48902 Mdot
.50047 .51184 Mdot
.51659 .52081 Mdot
.33362 .25422 Mdot
.47713 .26053 Mdot
.65232 .5337 Mdot
.59276 .47235 Mdot
.50186 .761 Mdot
.33444 .31156 Mdot
.35411 .38967 Mdot
.27108 .58688 Mdot
.25751 .57658 Mdot
.29199 .42414 Mdot
.76472 .3913 Mdot
.78171 .50333 Mdot
.6347 .46304 Mdot
.48808 .59261 Mdot
.51851 .28818 Mdot
.43997 .67529 Mdot
.53315 .30644 Mdot
.28456 .26619 Mdot
.61243 .6485 Mdot
.69916 .5972 Mdot
.2042 .56201 Mdot
.28268 .512 Mdot
.47996 .59521 Mdot
.45147 .67585 Mdot
.63714 .4871 Mdot
.57553 .32427 Mdot
.4984 .75612 Mdot
.47866 .60671 Mdot
.75374 .72599 Mdot
.51088 .31482 Mdot
.6192 .68745 Mdot
.34441 .37441 Mdot
.27246 .54139 Mdot
.64805 .56057 Mdot
.65476 .51828 Mdot
.57014 .34825 Mdot
.67813 .50413 Mdot
.71201 .59449 Mdot
.62065 .54296 Mdot
.2582 .52143 Mdot
.3293 .47881 Mdot
.36009 .3562 Mdot
.21073 .56772 Mdot
.53329 .30256 Mdot
.69523 .23955 Mdot
.28269 .55758 Mdot
.49974 .51943 Mdot
.32227 .35567 Mdot
.45394 .65564 Mdot
.28363 .565 Mdot
.41939 .69652 Mdot
.67916 .47926 Mdot
.29093 .5349 Mdot
.42726 .67326 Mdot
.70337 .54974 Mdot
.49366 .60672 Mdot
.48832 .80522 Mdot
.3314 .3808 Mdot
.53891 .34745 Mdot
.67288 .5146 Mdot
.49565 .58322 Mdot
.4766 .60696 Mdot
.5844 .68881 Mdot
.4938 .55163 Mdot
.4761 .59905 Mdot
.53258 .67359 Mdot
.45701 .64982 Mdot
.45294 .21924 Mdot
.68003 .59166 Mdot
.50361 .31596 Mdot
.66527 .53135 Mdot
.31449 .45082 Mdot
.33141 .37275 Mdot
.63429 .48812 Mdot
.31935 .25761 Mdot
.33445 .39087 Mdot
.64638 .47335 Mdot
.33595 .34857 Mdot
.56385 .323 Mdot
.62688 .65714 Mdot
.5077 .30703 Mdot
.65461 .4886 Mdot
.33144 .34924 Mdot
.27601 .58828 Mdot
.54729 .33286 Mdot
.6589 .49684 Mdot
.62638 .50093 Mdot
.48843 .58877 Mdot
.61713 .53745 Mdot
.30328 .32395 Mdot
.66529 .55194 Mdot
.32 .55264 Mdot
.63281 .53342 Mdot
.41912 .64687 Mdot
.3407 .73541 Mdot
.55842 .30997 Mdot
.49202 .55267 Mdot
.27847 .56714 Mdot
.71247 .57382 Mdot
.62974 .68228 Mdot
.64722 .49693 Mdot
.47937 .57077 Mdot
.6008 .73092 Mdot
.36475 .39129 Mdot
.65654 .58207 Mdot
.51687 .61599 Mdot
.2765 .57377 Mdot
.48434 .59543 Mdot
.6201 .46374 Mdot
.58412 .31281 Mdot
.6126 .50803 Mdot
.2859 .53918 Mdot
.50683 .32245 Mdot
.6245 .5308 Mdot
.29677 .34932 Mdot
.46702 .57966 Mdot
.37014 .38389 Mdot
.6684 .58625 Mdot
.68109 .50709 Mdot
.25704 .54605 Mdot
.54399 .33757 Mdot
.34396 .3696 Mdot
.52785 .30189 Mdot
.49405 .7122 Mdot
.61087 .70444 Mdot
.48991 .35108 Mdot
.46057 .67166 Mdot
.28843 .74061 Mdot
.35001 .3556 Mdot
.50786 .57103 Mdot
.32474 .55492 Mdot
.58334 .30432 Mdot
.28882 .5703 Mdot
.77074 .36095 Mdot
.27184 .56913 Mdot
.60774 .50334 Mdot
.26862 .58054 Mdot
.78962 .48018 Mdot
.66423 .47107 Mdot
.27968 .51822 Mdot
.51538 .56455 Mdot
.65019 .46441 Mdot
.56132 .32989 Mdot
.61459 .77379 Mdot
.74325 .38987 Mdot
.767 .39706 Mdot
.27299 .5619 Mdot
.76695 .35204 Mdot
.62566 .55191 Mdot
.66334 .58342 Mdot
.54623 .31679 Mdot
.507 .57274 Mdot
.4197 .65841 Mdot
.41225 .66814 Mdot
.3939 .75937 Mdot
.65514 .68782 Mdot
.78543 .3931 Mdot
.55615 .32771 Mdot
.31293 .48276 Mdot
.49105 .36297 Mdot
.47809 .60536 Mdot
.34131 .367 Mdot
.45931 .26961 Mdot
.66652 .57015 Mdot
.51942 .53438 Mdot
.71323 .59307 Mdot
.53423 .3445 Mdot
.49248 .34675 Mdot
.3427 .36877 Mdot
.76931 .3989 Mdot
.75304 .47069 Mdot
.63857 .50523 Mdot
.33093 .36714 Mdot
.47765 .60732 Mdot
.68633 .58196 Mdot
.55036 .78426 Mdot
.16049 .51003 Mdot
.64954 .48912 Mdot
.45023 .31952 Mdot
.67216 .51417 Mdot
.53955 .77717 Mdot
.63872 .48281 Mdot
.55001 .33874 Mdot
.63604 .57083 Mdot
.68256 .5787 Mdot
.20146 .62727 Mdot
.60484 .64747 Mdot
.42523 .69696 Mdot
.65245 .50678 Mdot
.64239 .51592 Mdot
.4465 .65804 Mdot
.553 .345 Mdot
.66172 .54421 Mdot
.46471 .21806 Mdot
.66102 .49404 Mdot
.33907 .40587 Mdot
.56259 .70523 Mdot
.58807 .77615 Mdot
.62735 .55243 Mdot
.58452 .31299 Mdot
.36936 .39097 Mdot
.31727 .3671 Mdot
.49587 .55673 Mdot
.33043 .37329 Mdot
.67522 .49892 Mdot
.56388 .70499 Mdot
.49299 .32412 Mdot
.486 .6051 Mdot
.54038 .34473 Mdot
.33056 .59335 Mdot
.3335 .3804 Mdot
.48474 .57788 Mdot
.75443 .38038 Mdot
.34224 .39284 Mdot
.36611 .52732 Mdot
.63188 .56142 Mdot
.47655 .60595 Mdot
.54007 .29819 Mdot
.25786 .55478 Mdot
.47368 .58642 Mdot
.3441 .3714 Mdot
.64609 .49544 Mdot
.61559 .52872 Mdot
.32979 .37268 Mdot
.5823 .2711 Mdot
.68591 .59375 Mdot
.66143 .49032 Mdot
.56472 .33321 Mdot
.51988 .32311 Mdot
.63992 .45578 Mdot
.67157 .52248 Mdot
.29587 .57869 Mdot
.4799 .5688 Mdot
.47892 .56916 Mdot
.49894 .54754 Mdot
.2708 .55275 Mdot
.25645 .71444 Mdot
.3572 .40296 Mdot
.59114 .77552 Mdot
.42978 .33717 Mdot
.49461 .57828 Mdot
.30226 .57576 Mdot
.64958 .52385 Mdot
.65621 .55808 Mdot
.32239 .35075 Mdot
.38498 .80857 Mdot
.6721 .56708 Mdot
.50769 .31042 Mdot
.33952 .36378 Mdot
.61505 .44629 Mdot
.30134 .44125 Mdot
.418 .67327 Mdot
.78562 .38862 Mdot
.34429 .3639 Mdot
.53228 .35669 Mdot
.34559 .36386 Mdot
.64269 .51473 Mdot
.62173 .46329 Mdot
.52526 .34037 Mdot
.42986 .7003 Mdot
.64967 .54792 Mdot
.64579 .47566 Mdot
.29106 .47823 Mdot
.49825 .37131 Mdot
.40813 .67964 Mdot
.66356 .54939 Mdot
.51277 .58097 Mdot
.43553 .70371 Mdot
.66721 .48832 Mdot
.6359 .53936 Mdot
.46866 .5463 Mdot
.30528 .36477 Mdot
.45587 .69305 Mdot
.20488 .64281 Mdot
.51099 .31284 Mdot
.31138 .3161 Mdot
.46949 .58666 Mdot
.34751 .35496 Mdot
.72526 .5836 Mdot
.4806 .58618 Mdot
.42142 .32165 Mdot
.88216 .48727 Mdot
.47528 .58618 Mdot
.30899 .5728 Mdot
.75198 .44055 Mdot
.63932 .54166 Mdot
.66115 .48894 Mdot
.42252 .65577 Mdot
.52728 .32087 Mdot
.47592 .26153 Mdot
.34496 .35148 Mdot
.66098 .52072 Mdot
.54094 .30205 Mdot
.34504 .24542 Mdot
.48472 .58947 Mdot
.42432 .68772 Mdot
.45703 .68482 Mdot
.67077 .49837 Mdot
.62087 .71332 Mdot
.55 .33307 Mdot
.65867 .49673 Mdot
.66286 .47735 Mdot
.28647 .58993 Mdot
.5652 .31395 Mdot
.29238 .53714 Mdot
.66491 .58784 Mdot
.80215 .46317 Mdot
.31982 .45781 Mdot
.33166 .38806 Mdot
.48797 .56098 Mdot
.36259 .35778 Mdot
.31195 .51144 Mdot
.48013 .56772 Mdot
.65843 .49792 Mdot
.49251 .32556 Mdot
.65862 .49565 Mdot
.66055 .49334 Mdot
.64318 .49241 Mdot
.78685 .39317 Mdot
.25411 .51246 Mdot
.42962 .6903 Mdot
.67638 .53185 Mdot
.27931 .54153 Mdot
.29376 .43779 Mdot
.75171 .4596 Mdot
.65562 .51059 Mdot
.65357 .47385 Mdot
.56759 .30202 Mdot
.61198 .527 Mdot
.34055 .39008 Mdot
.53013 .34334 Mdot
.63825 .55196 Mdot
.25278 .50503 Mdot
.6647 .54247 Mdot
.48908 .3476 Mdot
.34738 .40292 Mdot
.67828 .43152 Mdot
.4761 .6125 Mdot
.48332 .56165 Mdot
.47414 .58797 Mdot
.49589 .54781 Mdot
.33144 .40482 Mdot
.30961 .5694 Mdot
.20899 .57695 Mdot
.68528 .53948 Mdot
.6764 .5111 Mdot
.6222 .46124 Mdot
.3075 .58522 Mdot
.51685 .56842 Mdot
.76199 .36473 Mdot
.61454 .44422 Mdot
.26774 .54047 Mdot
.51048 .55402 Mdot
.60339 .34916 Mdot
.54229 .34683 Mdot
.28189 .50209 Mdot
.31406 .36932 Mdot
.42458 .67273 Mdot
.43266 .7825 Mdot
.52048 .33037 Mdot
.53329 .28391 Mdot
.30285 .55033 Mdot
.57945 .70578 Mdot
.62674 .16894 Mdot
.29318 .57282 Mdot
.70336 .59464 Mdot
.55301 .31962 Mdot
.50587 .59583 Mdot
.59519 .73367 Mdot
.5692 .71041 Mdot
.26939 .52765 Mdot
.62687 .50355 Mdot
.3008 .60799 Mdot
.29092 .58251 Mdot
.49884 .56363 Mdot
.27308 .55989 Mdot
.36753 .38929 Mdot
.29491 .55994 Mdot
.58759 .33547 Mdot
.63776 .5282 Mdot
.62966 .17342 Mdot
.5316 .7192 Mdot
.64991 .53115 Mdot
.36428 .38661 Mdot
.30696 .33021 Mdot
.63514 .5004 Mdot
.41321 .67422 Mdot
.31004 .57118 Mdot
.35207 .52819 Mdot
.61033 .50709 Mdot
.26638 .57769 Mdot
.58397 .31 Mdot
.33523 .49105 Mdot
.32076 .46679 Mdot
.47439 .58257 Mdot
.5629 .32007 Mdot
.29827 .404 Mdot
.35606 .36042 Mdot
.46733 .57448 Mdot
.67456 .48479 Mdot
.57218 .33104 Mdot
.70921 .56183 Mdot
.54403 .5357 Mdot
.66142 .49585 Mdot
.29422 .54038 Mdot
.26831 .51376 Mdot
.54634 .69308 Mdot
.28129 .5557 Mdot
.49885 .56213 Mdot
.56824 .32949 Mdot
.6106 .50296 Mdot
.51685 .31859 Mdot
.66573 .53219 Mdot
.30804 .44275 Mdot
.55713 .34845 Mdot
.50029 .51942 Mdot
.62926 .47762 Mdot
.69095 .26021 Mdot
.67427 .54013 Mdot
.66201 .49165 Mdot
.25562 .53196 Mdot
.44774 .66003 Mdot
.53396 .53456 Mdot
.29554 .43335 Mdot
.42782 .66184 Mdot
.5902 .28787 Mdot
.25217 .56362 Mdot
.45288 .65671 Mdot
.39878 .76691 Mdot
.49027 .55327 Mdot
.44895 .69361 Mdot
.62817 .45425 Mdot
.32907 .38527 Mdot
.497 .33473 Mdot
.64986 .46373 Mdot
.79645 .4633 Mdot
.68361 .59554 Mdot
.48733 .58589 Mdot
.66165 .48629 Mdot
.64347 .52173 Mdot
.53881 .30179 Mdot
.28491 .26837 Mdot
.31363 .52189 Mdot
.50471 .58574 Mdot
.51464 .32366 Mdot
.2913 .26449 Mdot
.27783 .5204 Mdot
.4415 .64598 Mdot
.36415 .35628 Mdot
.51936 .35964 Mdot
.49105 .58401 Mdot
.33299 .37767 Mdot
.28324 .60557 Mdot
.48343 .74368 Mdot
.61379 .51064 Mdot
.30944 .55782 Mdot
.48697 .74827 Mdot
.63248 .56366 Mdot
.28933 .4206 Mdot
.34327 .31324 Mdot
.57552 .33624 Mdot
.33021 .37095 Mdot
.42439 .69188 Mdot
.50029 .31279 Mdot
.54146 .34522 Mdot
.33497 .39337 Mdot
.75667 .30494 Mdot
.60138 .7292 Mdot
.35608 .34955 Mdot
.57937 .68362 Mdot
.48651 .74563 Mdot
.49158 .58695 Mdot
.43175 .68821 Mdot
.32898 .47829 Mdot
.54198 .33497 Mdot
.45602 .27969 Mdot
.48731 .75019 Mdot
.63866 .56866 Mdot
.42718 .67041 Mdot
.34858 .24643 Mdot
.35843 .41984 Mdot
.33739 .38598 Mdot
.2937 .4768 Mdot
.43412 .65947 Mdot
.64777 .4598 Mdot
.40698 .82808 Mdot
.66485 .47296 Mdot
.32878 .39001 Mdot
.71276 .59351 Mdot
.53101 .30902 Mdot
.35414 .40242 Mdot
.71177 .59607 Mdot
.66275 .55155 Mdot
.63977 .52369 Mdot
.25079 .51636 Mdot
.56507 .35074 Mdot
.46807 .59552 Mdot
.65233 .53166 Mdot
.64102 .47354 Mdot
.48399 .61366 Mdot
.58167 .77612 Mdot
.45284 .50065 Mdot
.49596 .60918 Mdot
.27912 .5308 Mdot
.48732 .60606 Mdot
.50497 .58278 Mdot
.56044 .30205 Mdot
.31195 .47341 Mdot
.47261 .60114 Mdot
.65256 .48637 Mdot
.65717 .48872 Mdot
.36069 .35335 Mdot
.59998 .73125 Mdot
.5769 .70937 Mdot
.32107 .54128 Mdot
.49378 .62784 Mdot
.62361 .50531 Mdot
.56379 .31791 Mdot
.42601 .71443 Mdot
.4994 .55812 Mdot
.50794 .31372 Mdot
.6388 .53234 Mdot
.28797 .59031 Mdot
.47675 .58247 Mdot
.49384 .61594 Mdot
.43069 .67342 Mdot
.37541 .36802 Mdot
.57894 .28243 Mdot
.29704 .58018 Mdot
.62912 .54876 Mdot
.50511 .62257 Mdot
.27156 .57765 Mdot
.49128 .58897 Mdot
.49184 .60472 Mdot
.56212 .32407 Mdot
.54517 .35984 Mdot
.51704 .5828 Mdot
.27309 .54865 Mdot
.16149 .46823 Mdot
.35056 .36171 Mdot
.68025 .51438 Mdot
.37243 .36914 Mdot
.57973 .33019 Mdot
.54832 .77928 Mdot
.45682 .66854 Mdot
.3378 .39015 Mdot
.47959 .60583 Mdot
.548 .34752 Mdot
.58082 .336 Mdot
.65344 .49186 Mdot
.65879 .50427 Mdot
.30289 .49697 Mdot
.50503 .76646 Mdot
.32599 .3487 Mdot
.42821 .65355 Mdot
.31669 .53118 Mdot
.61223 .51672 Mdot
.54651 .31071 Mdot
.52571 .81875 Mdot
.68071 .5159 Mdot
.27772 .5442 Mdot
.5408 .32543 Mdot
.42009 .65937 Mdot
.43104 .69207 Mdot
.66295 .52732 Mdot
.4756 .53203 Mdot
.34064 .39492 Mdot
.55841 .33304 Mdot
.50202 .27356 Mdot
.67177 .54274 Mdot
.65556 .50656 Mdot
.63021 .56052 Mdot
.36231 .35203 Mdot
.63568 .45568 Mdot
.42998 .6995 Mdot
.54115 .30541 Mdot
.66152 .52496 Mdot
.43703 .65933 Mdot
.4751 .56543 Mdot
.47945 .58347 Mdot
.26645 .52091 Mdot
.41252 .67202 Mdot
.44238 .66195 Mdot
.42784 .65945 Mdot
.45889 .26979 Mdot
.65017 .44613 Mdot
.52489 .56407 Mdot
.62579 .50026 Mdot
.48633 .74433 Mdot
.6145 .49389 Mdot
.36421 .37293 Mdot
.25751 .54299 Mdot
.64085 .49791 Mdot
.62598 .49474 Mdot
.58466 .29256 Mdot
.61012 .49308 Mdot
.64105 .45641 Mdot
.5353 .308 Mdot
.51166 .27279 Mdot
.26201 .58163 Mdot
.2944 .26709 Mdot
.45966 .85093 Mdot
.66965 .46783 Mdot
.57503 .70482 Mdot
.55501 .34597 Mdot
.36271 .35492 Mdot
.58325 .69099 Mdot
.37689 .37948 Mdot
.52432 .32524 Mdot
.60708 .49548 Mdot
.56666 .25599 Mdot
.42806 .66367 Mdot
.64268 .51217 Mdot
.34269 .39762 Mdot
.64157 .51041 Mdot
.35753 .39853 Mdot
.75403 .33985 Mdot
.57411 .7378 Mdot
.67429 .47797 Mdot
.62864 .53069 Mdot
.45346 .55122 Mdot
.65703 .50786 Mdot
.20054 .57493 Mdot
.54288 .32187 Mdot
.4646 .58581 Mdot
.60587 .49074 Mdot
.74351 .39296 Mdot
.65976 .48035 Mdot
.73618 .58573 Mdot
.64559 .46751 Mdot
.36928 .7934 Mdot
.67915 .48066 Mdot
.67276 .48145 Mdot
.35931 .38492 Mdot
.33368 .35315 Mdot
.58817 .31143 Mdot
.48634 .60195 Mdot
.34037 .25019 Mdot
.64861 .47505 Mdot
.29884 .51417 Mdot
.54429 .51378 Mdot
.44352 .66016 Mdot
.52792 .30442 Mdot
.89543 .45838 Mdot
.3317 .40667 Mdot
.29348 .53136 Mdot
.69281 .59375 Mdot
.28508 .53167 Mdot
.29107 .50481 Mdot
.50657 .26089 Mdot
.43053 .68784 Mdot
.66642 .53854 Mdot
.71116 .36951 Mdot
.48631 .36481 Mdot
.67132 .54317 Mdot
.27886 .60185 Mdot
.47098 .54453 Mdot
.59347 .60325 Mdot
.45725 .64697 Mdot
.4448 .67444 Mdot
.33987 .37299 Mdot
.29859 .51578 Mdot
.50304 .58819 Mdot
.45422 .65784 Mdot
.26324 .58039 Mdot
.49246 .55403 Mdot
.30633 .4776 Mdot
.55093 .33355 Mdot
.76821 .35456 Mdot
.69553 .27339 Mdot
.37074 .37789 Mdot
.29027 .42927 Mdot
.49176 .32628 Mdot
.5057 .30762 Mdot
.49112 .59624 Mdot
.26578 .54018 Mdot
.50678 .3427 Mdot
.65955 .52805 Mdot
.48771 .60544 Mdot
.67211 .50455 Mdot
.45221 .64513 Mdot
.65602 .48213 Mdot
.26542 .58051 Mdot
.35916 .38901 Mdot
.27688 .5722 Mdot
.3361 .37376 Mdot
.60001 .77541 Mdot
.63149 .47108 Mdot
.65421 .50436 Mdot
.56441 .70555 Mdot
.57144 .31535 Mdot
.71381 .38194 Mdot
.27484 .54926 Mdot
.27444 .56746 Mdot
.60626 .48902 Mdot
.49952 .32395 Mdot
.51617 .59381 Mdot
.5743 .67958 Mdot
.64873 .46855 Mdot
.54072 .32128 Mdot
.60877 .47856 Mdot
.30304 .30593 Mdot
.55548 .73053 Mdot
.57211 .31281 Mdot
.20021 .62429 Mdot
.64019 .4622 Mdot
.50918 .57554 Mdot
.47081 .54921 Mdot
.63424 .70821 Mdot
.5349 .53224 Mdot
.51009 .31484 Mdot
.50187 .59399 Mdot
.54932 .31231 Mdot
.27893 .57935 Mdot
.35189 .40436 Mdot
.54233 .31418 Mdot
.63861 .4661 Mdot
.46006 .85022 Mdot
.34857 .39985 Mdot
.64436 .50974 Mdot
.33506 .39868 Mdot
.49549 .34165 Mdot
.52487 .31375 Mdot
.49261 .55413 Mdot
.70261 .59544 Mdot
.33891 .39309 Mdot
.67689 .5064 Mdot
.45526 .30532 Mdot
.61262 .50715 Mdot
.48322 .63007 Mdot
.62353 .51569 Mdot
.63696 .5317 Mdot
.22983 .68793 Mdot
.71451 .56511 Mdot
.31777 .45622 Mdot
.37293 .35338 Mdot
.47005 .26085 Mdot
.55333 .3015 Mdot
.44671 .64317 Mdot
.58834 .30244 Mdot
.47944 .56612 Mdot
.27904 .52888 Mdot
.64362 .49636 Mdot
.48959 .54978 Mdot
.32702 .34641 Mdot
.45088 .68945 Mdot
.68046 .48913 Mdot
.31383 .54512 Mdot
.51172 .56426 Mdot
.33486 .38136 Mdot
.53927 .33544 Mdot
.52136 .3086 Mdot
.31362 .47818 Mdot
.65968 .52592 Mdot
.65882 .50139 Mdot
.32511 .39678 Mdot
.5018 .52307 Mdot
.42303 .66364 Mdot
.51542 .5645 Mdot
.32776 .39589 Mdot
.55691 .7317 Mdot
.56486 .35147 Mdot
.64634 .52346 Mdot
.55887 .70493 Mdot
.47549 .25894 Mdot
.64428 .40158 Mdot
.44094 .67116 Mdot
.62755 .69102 Mdot
.51029 .31516 Mdot
.35573 .38362 Mdot
.3945 .76233 Mdot
.62294 .55167 Mdot
.63435 .50915 Mdot
.63488 .68375 Mdot
.5766 .67946 Mdot
.6939 .59131 Mdot
.4708 .60171 Mdot
.59491 .72573 Mdot
.60646 .48494 Mdot
.62101 .53776 Mdot
.62337 .50049 Mdot
.62331 .51723 Mdot
.53442 .31737 Mdot
.76907 .40329 Mdot
.29926 .55106 Mdot
.59084 .46099 Mdot
.46378 .64369 Mdot
.64225 .57096 Mdot
.64911 .5544 Mdot
.60747 .37382 Mdot
.66023 .65421 Mdot
.55123 .32424 Mdot
.58061 .31348 Mdot
.37056 .37239 Mdot
.61198 .50106 Mdot
.27559 .54636 Mdot
.48916 .53834 Mdot
.25937 .54674 Mdot
.53466 .31913 Mdot
.26556 .58899 Mdot
.33357 .40913 Mdot
.30968 .55733 Mdot
.27083 .53659 Mdot
.36227 .38522 Mdot
.55531 .35208 Mdot
.6743 .54122 Mdot
.36266 .38535 Mdot
.5016 .61179 Mdot
.44211 .64477 Mdot
.52665 .2784 Mdot
.50158 .60277 Mdot
.66934 .56449 Mdot
.1718 .44452 Mdot
.30891 .54699 Mdot
.63124 .66266 Mdot
.56067 .34949 Mdot
.44757 .70839 Mdot
.53847 .31297 Mdot
.51766 .58225 Mdot
.43739 .66985 Mdot
.62609 .45458 Mdot
.47023 .79521 Mdot
.35054 .31552 Mdot
.66161 .57329 Mdot
.51065 .27279 Mdot
.26002 .55044 Mdot
.36331 .39131 Mdot
.27695 .33109 Mdot
.50503 .58627 Mdot
.58495 .3099 Mdot
.55233 .36318 Mdot
.4793 .56758 Mdot
.35442 .38689 Mdot
.6838 .27102 Mdot
.65281 .52953 Mdot
.37166 .37002 Mdot
.62405 .51606 Mdot
.78142 .37814 Mdot
.45964 .70602 Mdot
.49683 .54597 Mdot
.60715 .49972 Mdot
.27794 .52078 Mdot
.60648 .49135 Mdot
.791 .4415 Mdot
.5248 .77791 Mdot
.62681 .47984 Mdot
.63442 .66984 Mdot
.31811 .52032 Mdot
.55289 .31129 Mdot
.49125 .57023 Mdot
.48974 .58747 Mdot
.60668 .51221 Mdot
.55334 .85753 Mdot
.45423 .66879 Mdot
.2093 .54772 Mdot
.63441 .46985 Mdot
.66497 .50377 Mdot
.58541 .28973 Mdot
.75254 .34074 Mdot
.51481 .57368 Mdot
.6311 .49955 Mdot
.66112 .66335 Mdot
.35552 .37362 Mdot
.62428 .52881 Mdot
.67041 .50379 Mdot
.34111 .50014 Mdot
.35833 .3842 Mdot
.2882 .58754 Mdot
.48759 .55512 Mdot
.26003 .52416 Mdot
.42464 .69981 Mdot
.6214 .6862 Mdot
.56706 .77791 Mdot
.55294 .72576 Mdot
.41368 .68007 Mdot
.62262 .54711 Mdot
.68074 .55616 Mdot
.63431 .51982 Mdot
.44712 .67616 Mdot
.31078 .37076 Mdot
.54098 .31945 Mdot
.77703 .36683 Mdot
.48941 .59019 Mdot
.64587 .56677 Mdot
.46169 .68884 Mdot
.55061 .31546 Mdot
.68969 .25257 Mdot
.52865 .32034 Mdot
.33922 .38238 Mdot
.28935 .42229 Mdot
.43481 .66665 Mdot
.5387 .31261 Mdot
.25622 .53291 Mdot
.29804 .42346 Mdot
.61112 .43963 Mdot
.33167 .40861 Mdot
.57174 .35259 Mdot
.57709 .31493 Mdot
.49246 .31551 Mdot
.60818 .5095 Mdot
.63328 .66716 Mdot
.49013 .56031 Mdot
.33799 .40108 Mdot
.29788 .52644 Mdot
.50964 .76906 Mdot
.68108 .29775 Mdot
.57428 .72769 Mdot
.62218 .45894 Mdot
.65592 .48284 Mdot
.66938 .4947 Mdot
.48185 .6166 Mdot
.68282 .55634 Mdot
.62613 .4869 Mdot
.32244 .35057 Mdot
.27909 .58376 Mdot
.63614 .47185 Mdot
.48065 .57781 Mdot
.52569 .5408 Mdot
.44602 .70835 Mdot
.78981 .38997 Mdot
.53363 .27788 Mdot
.54724 .31543 Mdot
.28555 .54028 Mdot
.25118 .56174 Mdot
.45646 .65873 Mdot
.33767 .36692 Mdot
.52639 .3214 Mdot
.36476 .78796 Mdot
.42409 .66708 Mdot
.65001 .48604 Mdot
.56312 .70562 Mdot
.65672 .67471 Mdot
.64422 .54689 Mdot
.64253 .49124 Mdot
.47957 .60329 Mdot
.27592 .54302 Mdot
.78575 .49213 Mdot
.68986 .25625 Mdot
.43768 .66062 Mdot
.44112 .6493 Mdot
.49491 .31461 Mdot
.67754 .49443 Mdot
.33905 .39621 Mdot
.60373 .72901 Mdot
.30807 .3267 Mdot
.37765 .22951 Mdot
.30083 .60219 Mdot
.6663 .54032 Mdot
.74818 .42169 Mdot
.66873 .57081 Mdot
.48676 .331 Mdot
.53402 .35567 Mdot
.55464 .32632 Mdot
.35148 .37028 Mdot
.48419 .73572 Mdot
.32721 .35953 Mdot
.51124 .55577 Mdot
.52327 .3352 Mdot
.70396 .57415 Mdot
.27413 .56551 Mdot
.61267 .49404 Mdot
.43704 .68564 Mdot
.49599 .64642 Mdot
.49403 .57401 Mdot
.6254 .68937 Mdot
.30255 .5754 Mdot
.5349 .34771 Mdot
.61195 .49062 Mdot
.30246 .44408 Mdot
.58472 .73011 Mdot
.32617 .55892 Mdot
.48824 .55044 Mdot
.4312 .66366 Mdot
.75115 .46494 Mdot
.42066 .67409 Mdot
.33676 .39098 Mdot
.63006 .475 Mdot
.67555 .48919 Mdot
.66381 .49249 Mdot
.64001 .45848 Mdot
.34737 .37126 Mdot
.65718 .57601 Mdot
.50965 .599 Mdot
.49538 .54901 Mdot
.67581 .59026 Mdot
.4385 .69271 Mdot
.35548 .36436 Mdot
.27363 .58067 Mdot
.47452 .59801 Mdot
.45686 .69472 Mdot
.61582 .48364 Mdot
.6278 .49047 Mdot
.50795 .5551 Mdot
.62896 .45455 Mdot
.66199 .57971 Mdot
.30277 .56241 Mdot
.68337 .58844 Mdot
.44559 .70761 Mdot
.43512 .68112 Mdot
.32799 .37597 Mdot
.53995 .31242 Mdot
.45891 .68051 Mdot
.31842 .54437 Mdot
.62134 .5248 Mdot
.62324 .5118 Mdot
.5821 .34568 Mdot
.48528 .74929 Mdot
.44457 .70957 Mdot
.63681 .45574 Mdot
.56178 .30868 Mdot
.54822 .36402 Mdot
.63336 .50507 Mdot
.65256 .57593 Mdot
.55204 .29977 Mdot
.44853 .64897 Mdot
.32938 .36834 Mdot
.52912 .73097 Mdot
.36298 .39814 Mdot
.54108 .33697 Mdot
.49713 .59794 Mdot
.54833 .35089 Mdot
.50469 .58813 Mdot
.4577 .19519 Mdot
.62519 .49129 Mdot
.51948 .24133 Mdot
.51729 .56929 Mdot
.27211 .56174 Mdot
.26579 .5533 Mdot
.47769 .57808 Mdot
.50762 .31999 Mdot
.49754 .56205 Mdot
.42118 .68369 Mdot
.46751 .26516 Mdot
.56311 .30279 Mdot
.26949 .53766 Mdot
.31009 .54587 Mdot
.32869 .39666 Mdot
.658 .48169 Mdot
.6464 .52423 Mdot
.30935 .5605 Mdot
.30648 .32529 Mdot
.57091 .33942 Mdot
.65836 .50104 Mdot
.49284 .61153 Mdot
.30089 .55691 Mdot
.39898 .34399 Mdot
.50287 .33894 Mdot
.60638 .50139 Mdot
.53068 .7799 Mdot
.34801 .4051 Mdot
.64759 .55967 Mdot
.65743 .57733 Mdot
.45083 .66596 Mdot
.6305 .69069 Mdot
.48946 .74798 Mdot
.33059 .40687 Mdot
.48481 .56094 Mdot
.64555 .54862 Mdot
.26889 .56214 Mdot
.61999 .486 Mdot
.84318 .55638 Mdot
.50345 .54941 Mdot
.65994 .52366 Mdot
.48135 .543 Mdot
.51657 .31801 Mdot
.66203 .5006 Mdot
.30968 .44296 Mdot
.28721 .54433 Mdot
.65661 .52648 Mdot
.46369 .53761 Mdot
.33548 .39846 Mdot
.49329 .57412 Mdot
.43111 .66154 Mdot
.69896 .59144 Mdot
.61309 .77395 Mdot
.30838 .58397 Mdot
.43548 .69548 Mdot
.65619 .47838 Mdot
.31425 .52585 Mdot
.33685 .35303 Mdot
.48757 .56891 Mdot
.64013 .55776 Mdot
.3622 .36598 Mdot
.35888 .37486 Mdot
.43156 .66906 Mdot
.68577 .22127 Mdot
.66835 .46788 Mdot
.64939 .51461 Mdot
.68708 .2392 Mdot
.56175 .37126 Mdot
.64247 .50874 Mdot
.66672 .4794 Mdot
.33123 .38041 Mdot
.48054 .73441 Mdot
.6268 .68942 Mdot
.5027 .54144 Mdot
.3649 .38847 Mdot
.28945 .60518 Mdot
.30011 .53974 Mdot
.43734 .69798 Mdot
.54022 .32607 Mdot
.45894 .66474 Mdot
.29401 .55549 Mdot
.65179 .48932 Mdot
.32237 .3737 Mdot
.78342 .52134 Mdot
.34987 .40233 Mdot
.31698 .54928 Mdot
.48832 .33383 Mdot
.79113 .47745 Mdot
.84982 .54627 Mdot
.44662 .50026 Mdot
.28772 .41718 Mdot
.44435 .66025 Mdot
.68959 .25578 Mdot
.64107 .46873 Mdot
.78402 .43516 Mdot
.64522 .51421 Mdot
.40832 .65503 Mdot
.2597 .56285 Mdot
.49243 .55412 Mdot
.50568 .58477 Mdot
.62648 .68462 Mdot
.35552 .37009 Mdot
.31291 .37581 Mdot
.49661 .60202 Mdot
.34143 .38622 Mdot
.65612 .52271 Mdot
.29462 .57616 Mdot
.49817 .20063 Mdot
.64418 .46663 Mdot
.46639 .60252 Mdot
.35895 .41075 Mdot
.49465 .3575 Mdot
.28816 .60491 Mdot
.74588 .4096 Mdot
.32488 .25914 Mdot
.34381 .39396 Mdot
.7898 .39337 Mdot
.28183 .54319 Mdot
.47485 .59848 Mdot
.31099 .51991 Mdot
.64911 .51887 Mdot
.66665 .54022 Mdot
.48085 .6119 Mdot
.6581 .47612 Mdot
.71913 .4172 Mdot
.65534 .58167 Mdot
.56835 .46305 Mdot
.62629 .5032 Mdot
.54502 .24641 Mdot
.33222 .35142 Mdot
.49547 .60207 Mdot
.52688 .67347 Mdot
.63625 .52888 Mdot
.54221 .29888 Mdot
.36569 .37163 Mdot
.3058 .27049 Mdot
.35206 .37209 Mdot
.27438 .57144 Mdot
.34297 .3665 Mdot
.66226 .56864 Mdot
.52372 .32812 Mdot
.28611 .56092 Mdot
.49343 .57949 Mdot
.28938 .52446 Mdot
.65029 .53106 Mdot
.39961 .37351 Mdot
.29403 .53231 Mdot
.63227 .56263 Mdot
.52168 .32531 Mdot
.50166 .81282 Mdot
.48804 .30885 Mdot
.65026 .49762 Mdot
.64542 .5027 Mdot
.51522 .57469 Mdot
.33442 .37112 Mdot
.54737 .35259 Mdot
.28613 .48 Mdot
.44692 .70911 Mdot
.54765 .32692 Mdot
.48712 .52987 Mdot
.58052 .70501 Mdot
.53207 .30314 Mdot
.66022 .66771 Mdot
.33278 .39062 Mdot
.51344 .31133 Mdot
.54659 .52347 Mdot
.59042 .47147 Mdot
.42813 .68288 Mdot
.25672 .52929 Mdot
.58337 .69752 Mdot
.29594 .53826 Mdot
.30911 .44446 Mdot
.25868 .52102 Mdot
.3496 .39666 Mdot
.48438 .52822 Mdot
.71244 .59302 Mdot
.31187 .38541 Mdot
.38488 .42133 Mdot
.29585 .54576 Mdot
.50472 .59522 Mdot
.67987 .58853 Mdot
.49246 .61695 Mdot
.5107 .57724 Mdot
.32933 .40589 Mdot
.51259 .31088 Mdot
.50029 .31749 Mdot
.46808 .56368 Mdot
.5278 .30747 Mdot
.29195 .5706 Mdot
.54829 .71796 Mdot
.75401 .38034 Mdot
.32252 .35264 Mdot
.68607 .58781 Mdot
.64383 .55347 Mdot
.26544 .578 Mdot
.28827 .57454 Mdot
.35411 .37048 Mdot
.60957 .40729 Mdot
.50975 .56841 Mdot
.49476 .34611 Mdot
.51947 .33022 Mdot
.51585 .31584 Mdot
.57911 .33467 Mdot
.48288 .74113 Mdot
.36468 .38593 Mdot
.50877 .32078 Mdot
.63686 .45999 Mdot
.66765 .48348 Mdot
.47304 .59169 Mdot
.4492 .6449 Mdot
.65724 .57953 Mdot
.49812 .56142 Mdot
.63567 .51017 Mdot
.27328 .55875 Mdot
.54038 .51072 Mdot
.47821 .5661 Mdot
.27479 .54596 Mdot
.27179 .55241 Mdot
.48438 .55999 Mdot
.53809 .51106 Mdot
.71927 .4333 Mdot
.60292 .4995 Mdot
.49353 .27127 Mdot
.26406 .54609 Mdot
.3577 .448 Mdot
.52299 .24072 Mdot
.67581 .49785 Mdot
.51438 .55879 Mdot
.28892 .57926 Mdot
.56799 .30591 Mdot
.6555 .51332 Mdot
.49298 .59579 Mdot
.42477 .67801 Mdot
.49043 .57644 Mdot
.48096 .60352 Mdot
.56993 .32052 Mdot
.16683 .45928 Mdot
.54253 .30246 Mdot
.2591 .51262 Mdot
.49842 .57919 Mdot
.6274 .17099 Mdot
.26108 .55695 Mdot
.46455 .26759 Mdot
.7108 .59423 Mdot
.63395 .51341 Mdot
.28711 .54053 Mdot
.58377 .31065 Mdot
.32034 .40105 Mdot
.66204 .65042 Mdot
.53757 .31152 Mdot
.46928 .58874 Mdot
.47622 .59153 Mdot
.30027 .55255 Mdot
.54421 .3411 Mdot
.65678 .57715 Mdot
.52012 .31098 Mdot
.31906 .36823 Mdot
.61279 .45854 Mdot
.33855 .25131 Mdot
.50194 .58951 Mdot
.53428 .30589 Mdot
.3053 .52985 Mdot
.43128 .70036 Mdot
.66375 .47126 Mdot
.31489 .25996 Mdot
.65781 .47881 Mdot
.31602 .38655 Mdot
.54011 .54674 Mdot
.59645 .472 Mdot
.64053 .48277 Mdot
.65456 .55591 Mdot
.30036 .37727 Mdot
.63813 .48389 Mdot
.64426 .53961 Mdot
.69214 .26861 Mdot
.54675 .30504 Mdot
.6376 .47095 Mdot
.30484 .56656 Mdot
.51014 .49545 Mdot
.66788 .51334 Mdot
.29326 .43346 Mdot
.63052 .70865 Mdot
.51786 .56265 Mdot
.46318 .59437 Mdot
.54592 .77932 Mdot
.64671 .50737 Mdot
.67801 .50286 Mdot
.61379 .45845 Mdot
.75738 .42571 Mdot
.29179 .55062 Mdot
.28517 .51804 Mdot
.4311 .69885 Mdot
.63683 .68082 Mdot
.43387 .67712 Mdot
.33778 .35295 Mdot
.69499 .59681 Mdot
.48814 .55247 Mdot
.54336 .31205 Mdot
.66457 .49499 Mdot
.29859 .52374 Mdot
.65115 .52222 Mdot
.6165 .53222 Mdot
.29518 .56717 Mdot
.2843 .57907 Mdot
.25003 .53326 Mdot
.43476 .65774 Mdot
.55054 .32014 Mdot
.66321 .46784 Mdot
.42995 .65994 Mdot
.48296 .61419 Mdot
.53563 .74041 Mdot
.55233 .32215 Mdot
.53978 .3064 Mdot
.51152 .33303 Mdot
.67404 .48188 Mdot
.61313 .45465 Mdot
.33272 .35834 Mdot
.58205 .34588 Mdot
.33142 .39373 Mdot
.28902 .53909 Mdot
.28632 .58451 Mdot
.64814 .51878 Mdot
.49487 .52736 Mdot
.43542 .69114 Mdot
.30056 .53417 Mdot
.48534 .54514 Mdot
.44741 .70015 Mdot
.67236 .5194 Mdot
.2934 .53752 Mdot
.41414 .67082 Mdot
.61349 .40806 Mdot
.37127 .25824 Mdot
.43658 .70222 Mdot
.50755 .57932 Mdot
.68207 .31002 Mdot
.52097 .77394 Mdot
.42949 .71489 Mdot
.32971 .35178 Mdot
.68158 .51104 Mdot
.4922 .54484 Mdot
.45248 .69884 Mdot
.49256 .76111 Mdot
.29327 .56144 Mdot
.50905 .57302 Mdot
.44484 .51695 Mdot
.75424 .38241 Mdot
.43286 .70186 Mdot
.5356 .30549 Mdot
.56723 .35397 Mdot
.64559 .48588 Mdot
.69777 .5954 Mdot
.31684 .35341 Mdot
.2503 .55133 Mdot
.29013 .51925 Mdot
.52924 .35678 Mdot
.5537 .72787 Mdot
.30659 .55786 Mdot
.68032 .50899 Mdot
.46517 .66767 Mdot
.63501 .45973 Mdot
.54097 .5549 Mdot
.59691 .47357 Mdot
.46272 .5737 Mdot
.43361 .70144 Mdot
.31301 .35663 Mdot
.35806 .38961 Mdot
.33884 .37087 Mdot
.30446 .55713 Mdot
.58506 .69306 Mdot
.29734 .51795 Mdot
.69631 .24148 Mdot
.45481 .67009 Mdot
.27223 .72568 Mdot
.67297 .56392 Mdot
.63668 .51917 Mdot
.61415 .50818 Mdot
.49122 .61006 Mdot
.648 .50719 Mdot
.3586 .36304 Mdot
.25801 .53056 Mdot
.37971 .32469 Mdot
.56585 .33331 Mdot
.69645 .24985 Mdot
.2747 .56441 Mdot
.46795 .575 Mdot
.43803 .68867 Mdot
.56701 .78249 Mdot
.42326 .64806 Mdot
.3051 .5764 Mdot
.65741 .53719 Mdot
.49658 .31049 Mdot
.37654 .7999 Mdot
.66233 .49717 Mdot
.30853 .54535 Mdot
.32101 .56793 Mdot
.58892 .46052 Mdot
.75292 .53041 Mdot
.33281 .31091 Mdot
.55852 .70926 Mdot
.41082 .67782 Mdot
.49071 .6154 Mdot
.60968 .7258 Mdot
.29484 .55399 Mdot
.26738 .5256 Mdot
.40729 .67927 Mdot
.49422 .3585 Mdot
.51526 .33182 Mdot
.49026 .28936 Mdot
.34851 .35876 Mdot
.63155 .51096 Mdot
.29636 .5421 Mdot
.48944 .32922 Mdot
.51584 .67149 Mdot
.34279 .37626 Mdot
.29488 .53122 Mdot
.66 .47842 Mdot
.64241 .481 Mdot
.43229 .67622 Mdot
.52763 .54295 Mdot
.49892 .61073 Mdot
.46593 .26758 Mdot
.57898 .71504 Mdot
.71013 .59648 Mdot
.63427 .50911 Mdot
.57782 .32937 Mdot
.48176 .56439 Mdot
.43065 .68855 Mdot
.62043 .48606 Mdot
.79226 .45923 Mdot
.58076 .31483 Mdot
.33601 .39454 Mdot
.49423 .58604 Mdot
.62197 .68189 Mdot
.65859 .47761 Mdot
.64579 .51474 Mdot
.60825 .5093 Mdot
.79088 .48472 Mdot
.25756 .5447 Mdot
.5616 .31141 Mdot
.43307 .66067 Mdot
.52487 .31541 Mdot
.31563 .48505 Mdot
.68273 .59362 Mdot
.68061 .4849 Mdot
.55787 .3039 Mdot
.52681 .32471 Mdot
.31537 .38513 Mdot
.3596 .39148 Mdot
.3027 .5932 Mdot
.66747 .4787 Mdot
.50188 .54755 Mdot
.51047 .3207 Mdot
.25329 .5351 Mdot
.43397 .67502 Mdot
.29035 .43299 Mdot
.62666 .49033 Mdot
.29698 .54976 Mdot
.49287 .56861 Mdot
.56871 .32677 Mdot
.27756 .5483 Mdot
.47518 .59923 Mdot
.44288 .64693 Mdot
.65687 .55009 Mdot
.32445 .52737 Mdot
.49067 .5997 Mdot
.65839 .46904 Mdot
.55759 .50723 Mdot
.69727 .59472 Mdot
.49471 .53917 Mdot
.27147 .58731 Mdot
.48848 .59564 Mdot
.56393 .35462 Mdot
.5949 .45408 Mdot
.26779 .52282 Mdot
.56471 .25458 Mdot
.71445 .59394 Mdot
.503 .59159 Mdot
.55118 .31117 Mdot
.30626 .47843 Mdot
.51473 .38023 Mdot
.5198 .76966 Mdot
.66333 .51548 Mdot
.29625 .53846 Mdot
.42755 .68063 Mdot
.31339 .37702 Mdot
.3705 .42154 Mdot
.34955 .47661 Mdot
.26892 .54409 Mdot
.66539 .49595 Mdot
.51255 .31261 Mdot
.3409 .39215 Mdot
.58256 .28416 Mdot
.31251 .52564 Mdot
.30415 .5701 Mdot
.61489 .51989 Mdot
.43473 .6776 Mdot
.68092 .558 Mdot
.26443 .52283 Mdot
.26916 .51471 Mdot
.69122 .27067 Mdot
.41132 .67838 Mdot
.60758 .5091 Mdot
.46701 .56508 Mdot
.62187 .52138 Mdot
.68885 .2491 Mdot
.47958 .59837 Mdot
.56604 .33443 Mdot
.64037 .5009 Mdot
.17407 .53071 Mdot
.26266 .5654 Mdot
.55853 .70962 Mdot
.35485 .31665 Mdot
.36208 .37744 Mdot
.28591 .54798 Mdot
.65995 .51162 Mdot
.28864 .42723 Mdot
.43998 .69838 Mdot
.60501 .48945 Mdot
.50069 .59743 Mdot
.53376 .3602 Mdot
.32254 .37145 Mdot
.49302 .5087 Mdot
.31489 .3722 Mdot
.32966 .37411 Mdot
.55899 .39997 Mdot
.64664 .48588 Mdot
.27697 .56104 Mdot
.3143 .55269 Mdot
.47223 .62145 Mdot
.24049 .52202 Mdot
.53229 .3435 Mdot
.17533 .52223 Mdot
.79134 .46663 Mdot
.62878 .473 Mdot
.47039 .60048 Mdot
.51446 .56463 Mdot
.28884 .42091 Mdot
.63966 .48751 Mdot
.55646 .31366 Mdot
.26326 .52248 Mdot
.30189 .54342 Mdot
.6325 .56274 Mdot
.35854 .38965 Mdot
.42861 .65032 Mdot
.2883 .57232 Mdot
.52923 .72698 Mdot
.66044 .52396 Mdot
.36882 .40914 Mdot
.2874 .57063 Mdot
.48367 .84168 Mdot
.15812 .47895 Mdot
.52202 .30226 Mdot
.6604 .55261 Mdot
.50379 .33836 Mdot
.42501 .69642 Mdot
.29276 .50817 Mdot
.31171 .37913 Mdot
.4965 .57932 Mdot
.26919 .32592 Mdot
.30213 .54859 Mdot
.53594 .31915 Mdot
.64685 .49164 Mdot
.79152 .3998 Mdot
.64526 .46765 Mdot
.48026 .73287 Mdot
.44214 .7106 Mdot
.37513 .41843 Mdot
.32668 .3975 Mdot
.66161 .55274 Mdot
.42588 .66042 Mdot
.31412 .56774 Mdot
.29585 .56548 Mdot
.30263 .26363 Mdot
.47979 .60219 Mdot
.29735 .50608 Mdot
.66103 .47113 Mdot
.25263 .52889 Mdot
.68094 .29709 Mdot
.36177 .37981 Mdot
.62613 .52789 Mdot
.28806 .53161 Mdot
.51366 .37672 Mdot
.56641 .70727 Mdot
.66335 .51943 Mdot
.47509 .54578 Mdot
.35074 .39509 Mdot
.69753 .25213 Mdot
.26054 .56852 Mdot
.62345 .46876 Mdot
.3614 .36276 Mdot
.48431 .52871 Mdot
.38655 .32681 Mdot
.55118 .32036 Mdot
.31074 .54442 Mdot
.32878 .3681 Mdot
.5022 .57278 Mdot
.41501 .67127 Mdot
.31935 .54798 Mdot
.28477 .52874 Mdot
.62213 .54513 Mdot
.47095 .56259 Mdot
.49086 .52914 Mdot
.56311 .34527 Mdot
.33148 .38508 Mdot
.61316 .52518 Mdot
.53287 .74229 Mdot
.6145 .47343 Mdot
.32807 .3824 Mdot
.64513 .18693 Mdot
.65832 .53981 Mdot
.6263 .49798 Mdot
.79435 .4121 Mdot
.53382 .3486 Mdot
.58077 .32895 Mdot
.57839 .72934 Mdot
.64516 .5707 Mdot
.70613 .57115 Mdot
.54619 .31851 Mdot
.53312 .32056 Mdot
.7054 .57212 Mdot
.62292 .54491 Mdot
.49152 .29355 Mdot
.34198 .39028 Mdot
.36316 .38035 Mdot
.51646 .31649 Mdot
.61446 .49992 Mdot
.36102 .35409 Mdot
.61747 .39072 Mdot
.31234 .56284 Mdot
.61952 .7137 Mdot
.52169 .32001 Mdot
.56475 .70318 Mdot
.33623 .39051 Mdot
.60279 .76225 Mdot
.636 .70627 Mdot
.66285 .46409 Mdot
.64306 .48466 Mdot
.44646 .66275 Mdot
.49226 .57526 Mdot
.48327 .56063 Mdot
.33848 .37049 Mdot
.68313 .55578 Mdot
.55417 .32747 Mdot
.65945 .56785 Mdot
.50711 .76817 Mdot
.62575 .7622 Mdot
.77556 .52147 Mdot
.5384 .32522 Mdot
.54363 .33413 Mdot
.28998 .58592 Mdot
.26387 .58883 Mdot
.67462 .47564 Mdot
.35413 .3937 Mdot
.51569 .30829 Mdot
.32447 .38156 Mdot
.29496 .55569 Mdot
.2765 .56687 Mdot
.47434 .57633 Mdot
.50885 .57083 Mdot
.28728 .55441 Mdot
.29286 .43247 Mdot
.53355 .74206 Mdot
.55648 .36062 Mdot
.69765 .23819 Mdot
.59001 .77682 Mdot
.78046 .37487 Mdot
.42573 .67952 Mdot
.54181 .51253 Mdot
.3587 .36164 Mdot
.66031 .55449 Mdot
.63852 .50883 Mdot
.48442 .58916 Mdot
.36974 .36958 Mdot
.44987 .68511 Mdot
.3618 .37815 Mdot
.41677 .66895 Mdot
.28039 .52052 Mdot
.66583 .50061 Mdot
.65214 .53407 Mdot
.31463 .38161 Mdot
.29567 .58406 Mdot
.28935 .53391 Mdot
.42583 .68448 Mdot
.57337 .77799 Mdot
.29933 .55268 Mdot
.52268 .32086 Mdot
.58957 .25908 Mdot
.47781 .59234 Mdot
.65598 .51221 Mdot
.54781 .78028 Mdot
.59602 .45335 Mdot
.48108 .61319 Mdot
.49356 .58681 Mdot
.68365 .21949 Mdot
.66175 .52725 Mdot
.28906 .2692 Mdot
.47655 .56887 Mdot
.5474 .35079 Mdot
.27906 .55579 Mdot
.4716 .60092 Mdot
.4636 .55889 Mdot
.46958 .6748 Mdot
.47409 .60863 Mdot
.5132 .32964 Mdot
.51808 .33962 Mdot
.6836 .59022 Mdot
.70353 .24391 Mdot
.43083 .6626 Mdot
.44782 .69253 Mdot
.25936 .54057 Mdot
.30972 .44566 Mdot
.69056 .51206 Mdot
.45272 .68882 Mdot
.52329 .28051 Mdot
.61612 .52548 Mdot
.69556 .59165 Mdot
.67731 .59035 Mdot
.57463 .34442 Mdot
.60653 .45255 Mdot
.25896 .55067 Mdot
.53828 .31992 Mdot
.68197 .58767 Mdot
.6218 .52771 Mdot
.55381 .32391 Mdot
.33148 .37615 Mdot
.745 .57562 Mdot
.52155 .30914 Mdot
.66302 .64898 Mdot
.34196 .39624 Mdot
.69252 .58888 Mdot
.32656 .74884 Mdot
.51349 .85174 Mdot
.3598 .37862 Mdot
.29742 .53342 Mdot
.29527 .54288 Mdot
.30083 .56389 Mdot
.57312 .33938 Mdot
.27466 .57816 Mdot
.55189 .34229 Mdot
.28894 .41748 Mdot
.63179 .68245 Mdot
.43617 .66791 Mdot
.24905 .5141 Mdot
.51728 .31499 Mdot
.69227 .24442 Mdot
.88482 .48243 Mdot
.62453 .46352 Mdot
.31312 .38807 Mdot
.45728 .68184 Mdot
.55293 .70909 Mdot
.45057 .66606 Mdot
.28237 .54264 Mdot
.62388 .68372 Mdot
.65352 .52421 Mdot
.35017 .26407 Mdot
.42919 .68101 Mdot
.53139 .32024 Mdot
.62396 .54998 Mdot
.2822 .59225 Mdot
.43231 .69654 Mdot
.43559 .68269 Mdot
.64949 .50821 Mdot
.53592 .34811 Mdot
.28386 .5386 Mdot
.37151 .38049 Mdot
.3676 .5443 Mdot
.54893 .53652 Mdot
.66626 .52402 Mdot
.62532 .5103 Mdot
.57561 .70681 Mdot
.29132 .43488 Mdot
.34856 .3909 Mdot
.49367 .75553 Mdot
.26667 .58069 Mdot
.51497 .77346 Mdot
.49551 .36633 Mdot
.25239 .5121 Mdot
.48024 .5981 Mdot
.47355 .59621 Mdot
.65822 .49854 Mdot
.86514 .51943 Mdot
.74889 .54287 Mdot
.35686 .3528 Mdot
.48047 .58792 Mdot
.2965 .58553 Mdot
.58382 .32459 Mdot
.42846 .52744 Mdot
.66206 .58164 Mdot
.37174 .38171 Mdot
.29848 .5604 Mdot
.84875 .57442 Mdot
.44374 .65787 Mdot
.55491 .71452 Mdot
.66285 .47641 Mdot
.656 .50184 Mdot
.34798 .37542 Mdot
.31093 .36368 Mdot
.69623 .26976 Mdot
.41141 .65478 Mdot
.3441 .24641 Mdot
.30141 .36068 Mdot
.85109 .58364 Mdot
.51034 .5555 Mdot
.55093 .33647 Mdot
.48733 .55758 Mdot
.30911 .36289 Mdot
.64118 .50577 Mdot
.5363 .34892 Mdot
.48747 .56747 Mdot
.5237 .28604 Mdot
.6995 .59222 Mdot
.52991 .73142 Mdot
.65493 .48218 Mdot
.49953 .33183 Mdot
.54465 .32092 Mdot
.49118 .34112 Mdot
.47547 .58262 Mdot
.6307 .49958 Mdot
.6247 .46689 Mdot
.62629 .50715 Mdot
.69574 .27866 Mdot
.66338 .5028 Mdot
.48876 .36012 Mdot
.56828 .73481 Mdot
.17362 .5445 Mdot
.64967 .53313 Mdot
.33446 .36793 Mdot
.65852 .49185 Mdot
.42752 .65769 Mdot
.65033 .54787 Mdot
.70328 .59198 Mdot
.34578 .38765 Mdot
.79246 .44508 Mdot
.46483 .64921 Mdot
.66675 .52561 Mdot
.41345 .67861 Mdot
.45116 .27401 Mdot
.49559 .75399 Mdot
.68351 .27257 Mdot
.51996 .31182 Mdot
.3058 .51671 Mdot
.31638 .35294 Mdot
.2741 .57047 Mdot
.63915 .57286 Mdot
.49241 .55117 Mdot
.25608 .71419 Mdot
.54596 .75144 Mdot
.64089 .5031 Mdot
.51223 .58506 Mdot
.5497 .30798 Mdot
.26124 .5606 Mdot
.75506 .34195 Mdot
.61389 .51167 Mdot
.45208 .65107 Mdot
.45025 .6562 Mdot
.52044 .60957 Mdot
.49203 .35034 Mdot
.68033 .28806 Mdot
.34855 .37705 Mdot
.30477 .55369 Mdot
.44788 .70419 Mdot
.51282 .27578 Mdot
.3098 .37792 Mdot
.29127 .42358 Mdot
.3241 .36955 Mdot
.63895 .52656 Mdot
.47115 .58021 Mdot
.47311 .27961 Mdot
.48609 .60007 Mdot
.61942 .51009 Mdot
.28395 .52946 Mdot
.47967 .59991 Mdot
.44271 .66601 Mdot
.32903 .3702 Mdot
.27361 .56161 Mdot
.64689 .49965 Mdot
.54914 .31656 Mdot
.59184 .59709 Mdot
.31411 .50979 Mdot
.69685 .59594 Mdot
.69679 .59597 Mdot
.566 .36218 Mdot
.49865 .53922 Mdot
.40112 .38748 Mdot
.59182 .45575 Mdot
.33733 .47958 Mdot
.51815 .52978 Mdot
.21828 .53075 Mdot
.29921 .51793 Mdot
.28757 .56276 Mdot
.64729 .52713 Mdot
.25241 .5347 Mdot
.68154 .50174 Mdot
.26846 .58656 Mdot
.47617 .25659 Mdot
.66246 .57364 Mdot
.29225 .56805 Mdot
.49199 .55904 Mdot
.66162 .46998 Mdot
.5559 .31014 Mdot
.29251 .51372 Mdot
.66212 .46359 Mdot
.19906 .59498 Mdot
.31489 .38408 Mdot
.47476 .58454 Mdot
.55085 .67428 Mdot
.33686 .38421 Mdot
.52791 .33949 Mdot
.67825 .52765 Mdot
.45329 .69079 Mdot
.54342 .33701 Mdot
.50709 .61709 Mdot
.43593 .67913 Mdot
.54713 .72004 Mdot
.52567 .33231 Mdot
.47974 .59492 Mdot
.44595 .64896 Mdot
.47128 .62243 Mdot
.29024 .5631 Mdot
.32548 .55576 Mdot
.49329 .59826 Mdot
.6507 .52404 Mdot
.29153 .58927 Mdot
.35117 .36755 Mdot
.67112 .50459 Mdot
.29766 .54148 Mdot
.48152 .57543 Mdot
.64117 .46371 Mdot
.64692 .5724 Mdot
.69083 .25786 Mdot
.51597 .55511 Mdot
.43871 .6667 Mdot
.48987 .33592 Mdot
.62526 .48013 Mdot
.42237 .66603 Mdot
.32015 .52535 Mdot
.62095 .466 Mdot
.51105 .30801 Mdot
.60502 .40777 Mdot
.25129 .56137 Mdot
.34998 .39924 Mdot
.31545 .54423 Mdot
.41912 .69545 Mdot
.893 .46621 Mdot
.48083 .56418 Mdot
.6016 .47969 Mdot
.63528 .53341 Mdot
.30127 .51296 Mdot
.5477 .32275 Mdot
.3614 .2362 Mdot
.65648 .55063 Mdot
.62328 .46039 Mdot
.65331 .51025 Mdot
.35087 .52645 Mdot
.5644 .3474 Mdot
.65451 .51185 Mdot
.53378 .53539 Mdot
.62522 .5191 Mdot
.42305 .69166 Mdot
.29037 .73837 Mdot
.47991 .60857 Mdot
.61996 .16396 Mdot
.48449 .56767 Mdot
.29519 .57119 Mdot
.66343 .64839 Mdot
.54775 .67362 Mdot
.33045 .59362 Mdot
.53078 .34164 Mdot
.49567 .26962 Mdot
.27773 .56742 Mdot
.3085 .47927 Mdot
.66992 .58464 Mdot
.62595 .55165 Mdot
.67178 .48329 Mdot
.28223 .54283 Mdot
.25336 .5426 Mdot
.49681 .55153 Mdot
.5075 .59421 Mdot
.61888 .44411 Mdot
.30024 .52688 Mdot
.66479 .50312 Mdot
.59404 .47072 Mdot
.30958 .38226 Mdot
.52627 .30214 Mdot
.31308 .37101 Mdot
.31448 .39406 Mdot
.77605 .36632 Mdot
.5808 .71398 Mdot
.34928 .35873 Mdot
.35 .35367 Mdot
.32008 .47261 Mdot
.76342 .38484 Mdot
.4205 .68901 Mdot
.74726 .54296 Mdot
.28693 .58325 Mdot
.63039 .49657 Mdot
.56506 .34782 Mdot
.51647 .58744 Mdot
.39301 .2183 Mdot
.74022 .69025 Mdot
.616 .52753 Mdot
.27046 .58059 Mdot
.49209 .60014 Mdot
.49453 .60308 Mdot
.51931 .77356 Mdot
.66241 .50591 Mdot
.2503 .55426 Mdot
.7548 .38108 Mdot
.29537 .37422 Mdot
.28976 .42738 Mdot
.4947 .34745 Mdot
.66008 .49203 Mdot
.57008 .3387 Mdot
.36269 .39693 Mdot
.4231 .66898 Mdot
.44164 .66002 Mdot
.66669 .52644 Mdot
.71096 .5934 Mdot
.34086 .48279 Mdot
.64014 .56754 Mdot
.62488 .54616 Mdot
.48903 .59423 Mdot
.60785 .51756 Mdot
.62321 .47091 Mdot
.63017 .54719 Mdot
.48464 .61491 Mdot
.31052 .37938 Mdot
.75778 .36115 Mdot
.50161 .59391 Mdot
.67608 .5421 Mdot
.35807 .39989 Mdot
.65139 .57634 Mdot
.35065 .37104 Mdot
.29348 .43932 Mdot
.33769 .35791 Mdot
.43705 .66203 Mdot
.25164 .57275 Mdot
.69895 .25687 Mdot
.5148 .31129 Mdot
.36391 .38615 Mdot
.4415 .64581 Mdot
.34634 .36795 Mdot
.29342 .58136 Mdot
.29718 .39771 Mdot
.56472 .37532 Mdot
.53001 .7235 Mdot
.78176 .38628 Mdot
.29747 .36834 Mdot
.25242 .56409 Mdot
.51553 .31677 Mdot
.30929 .44318 Mdot
.66418 .5498 Mdot
.44139 .6573 Mdot
.65707 .4984 Mdot
.32915 .37183 Mdot
.27969 .58453 Mdot
.68334 .2668 Mdot
.43954 .6656 Mdot
.69518 .23444 Mdot
.30138 .52511 Mdot
.64957 .54109 Mdot
.35206 .40437 Mdot
.36101 .42964 Mdot
.32285 .39403 Mdot
.63279 .69085 Mdot
.49693 .54586 Mdot
.39533 .69944 Mdot
.5361 .33473 Mdot
.50782 .55052 Mdot
.60977 .81854 Mdot
.43533 .32388 Mdot
.56315 .32057 Mdot
.29842 .50427 Mdot
.66117 .5249 Mdot
.60685 .5086 Mdot
.50383 .56465 Mdot
.49854 .32152 Mdot
.60837 .50963 Mdot
.47271 .58457 Mdot
.57715 .73622 Mdot
.49306 .34702 Mdot
.32041 .54709 Mdot
.66571 .47584 Mdot
.33125 .4064 Mdot
.3511 .40221 Mdot
.47329 .57246 Mdot
.31716 .368 Mdot
.67761 .53633 Mdot
.52123 .32698 Mdot
.6799 .58932 Mdot
.42832 .69758 Mdot
.45463 .31381 Mdot
.50888 .6065 Mdot
.45449 .64224 Mdot
.63903 .45956 Mdot
.27667 .56436 Mdot
.26626 .32702 Mdot
.65039 .55598 Mdot
.54216 .31853 Mdot
.64196 .53819 Mdot
.60779 .51317 Mdot
.63161 .55876 Mdot
.30458 .55362 Mdot
.56692 .70569 Mdot
.66452 .50197 Mdot
.36903 .38796 Mdot
.70685 .57475 Mdot
.67098 .56233 Mdot
.40598 .6588 Mdot
.70185 .59163 Mdot
.37799 .38439 Mdot
.55031 .36121 Mdot
.27786 .56043 Mdot
.55234 .33066 Mdot
.55386 .29763 Mdot
.52912 .33991 Mdot
.50287 .35875 Mdot
.59331 .45418 Mdot
.28903 .26524 Mdot
.68084 .29465 Mdot
.7854 .38631 Mdot
.5628 .30187 Mdot
.21763 .36399 Mdot
.56334 .31875 Mdot
.52881 .34015 Mdot
.48079 .19677 Mdot
.53961 .34687 Mdot
.64763 .5193 Mdot
.63679 .52982 Mdot
.78915 .4769 Mdot
.36946 .54482 Mdot
.64093 .46597 Mdot
.48253 .6158 Mdot
.45779 .67476 Mdot
.49225 .35694 Mdot
.49511 .58235 Mdot
.551 .70936 Mdot
.46821 .58782 Mdot
.64919 .50752 Mdot
.66811 .49166 Mdot
.6574 .58135 Mdot
.64268 .75914 Mdot
.37657 .55222 Mdot
.51115 .33437 Mdot
.67533 .56142 Mdot
.3962 .33455 Mdot
.67266 .49052 Mdot
.64031 .54195 Mdot
.60403 .4542 Mdot
.27693 .56111 Mdot
.58546 .32447 Mdot
.51085 .56884 Mdot
.45054 .31716 Mdot
.65464 .47704 Mdot
.52134 .58268 Mdot
.46194 .67263 Mdot
.65949 .51296 Mdot
.52814 .34308 Mdot
.60801 .51183 Mdot
.57838 .31909 Mdot
.5308 .3354 Mdot
.62161 .46323 Mdot
.49093 .35244 Mdot
.58293 .32083 Mdot
.62675 .55231 Mdot
.28221 .58928 Mdot
.4659 .26661 Mdot
.65339 .5226 Mdot
.44254 .67014 Mdot
.64132 .48874 Mdot
.42064 .69126 Mdot
.47294 .60565 Mdot
.48874 .59743 Mdot
.75082 .47083 Mdot
.26969 .52411 Mdot
.43321 .64157 Mdot
.25406 .5248 Mdot
.68686 .52871 Mdot
.53156 .28235 Mdot
.29736 .38739 Mdot
.27233 .49623 Mdot
.48768 .59503 Mdot
.48546 .73651 Mdot
.70524 .5545 Mdot
.33038 .35833 Mdot
.56627 .3138 Mdot
.74622 .3611 Mdot
.51424 .55984 Mdot
.32018 .55036 Mdot
.31273 .55883 Mdot
.42447 .35184 Mdot
.49787 .20061 Mdot
.65001 .53261 Mdot
.51582 .5684 Mdot
.5639 .47523 Mdot
.49158 .57412 Mdot
.50056 .55408 Mdot
.2864 .52773 Mdot
.64389 .46534 Mdot
.58338 .73776 Mdot
.29449 .54596 Mdot
.44245 .69107 Mdot
.56632 .33528 Mdot
.41913 .66756 Mdot
.3942 .24871 Mdot
.69689 .26751 Mdot
.28937 .55182 Mdot
.48617 .61177 Mdot
.62848 .49039 Mdot
.54329 .35111 Mdot
.58257 .28501 Mdot
.54966 .30555 Mdot
.44551 .69901 Mdot
.27073 .5203 Mdot
.19978 .61957 Mdot
.64808 .49021 Mdot
.52875 .32482 Mdot
.46627 .66829 Mdot
.64136 .4803 Mdot
.35794 .39135 Mdot
.60932 .51225 Mdot
.52569 .31904 Mdot
.60221 .47735 Mdot
.53567 .33513 Mdot
.30675 .56594 Mdot
.66257 .53032 Mdot
.67272 .51128 Mdot
.49163 .75144 Mdot
.45041 .68363 Mdot
.57598 .31331 Mdot
.58688 .70314 Mdot
.62182 .52128 Mdot
.53052 .77743 Mdot
.66718 .50602 Mdot
.78272 .38994 Mdot
.47127 .55423 Mdot
.47168 .58676 Mdot
.63903 .53645 Mdot
.65589 .52144 Mdot
.585 .28921 Mdot
.68174 .30033 Mdot
.69634 .27774 Mdot
.35097 .40024 Mdot
.56182 .31345 Mdot
.29123 .54384 Mdot
.28923 .51226 Mdot
.27503 .57577 Mdot
.4295 .70299 Mdot
.66675 .58462 Mdot
.64075 .52047 Mdot
.37035 .36208 Mdot
.4556 .67629 Mdot
.53724 .32827 Mdot
.43181 .66951 Mdot
.57326 .71251 Mdot
.4454 .67071 Mdot
.48826 .55514 Mdot
.17102 .44535 Mdot
.59349 .47041 Mdot
.44162 .68392 Mdot
.52083 .30351 Mdot
.7129 .57421 Mdot
.63301 .45211 Mdot
.69364 .24961 Mdot
.45463 .65485 Mdot
.3029 .50459 Mdot
.647 .46244 Mdot
.63311 .66535 Mdot
.34585 .37099 Mdot
.41965 .66546 Mdot
.32329 .36936 Mdot
.61457 .52558 Mdot
.51596 .25342 Mdot
.53503 .31484 Mdot
.30835 .38031 Mdot
.63483 .5367 Mdot
.42012 .66493 Mdot
.28937 .55642 Mdot
.76243 .3851 Mdot
.29469 .42845 Mdot
.52117 .55513 Mdot
.51766 .77083 Mdot
.25834 .54815 Mdot
.77253 .40088 Mdot
.32653 .36332 Mdot
.67164 .57113 Mdot
.5995 .47368 Mdot
.62245 .48462 Mdot
.28692 .53526 Mdot
.28687 .56301 Mdot
.25441 .49634 Mdot
.67301 .51456 Mdot
.60866 .45211 Mdot
.53589 .3625 Mdot
.26569 .52196 Mdot
.52944 .33967 Mdot
.49647 .32988 Mdot
.29692 .53371 Mdot
.56947 .311 Mdot
.43521 .68061 Mdot
.60329 .71627 Mdot
.32918 .36217 Mdot
.33743 .40077 Mdot
.28762 .55279 Mdot
.26694 .53534 Mdot
.27616 .56466 Mdot
.61084 .50792 Mdot
.52889 .33604 Mdot
.67431 .5249 Mdot
.65559 .49094 Mdot
.62942 .45283 Mdot
.5031 .33976 Mdot
.6605 .55127 Mdot
.68084 .57749 Mdot
.45857 .68707 Mdot
.29147 .57257 Mdot
.32721 .38659 Mdot
.5923 .60149 Mdot
.37053 .38714 Mdot
.62345 .51777 Mdot
.47538 .25992 Mdot
.56769 .31801 Mdot
.44917 .66448 Mdot
.70245 .594 Mdot
.44188 .66333 Mdot
.30958 .38286 Mdot
.53225 .36314 Mdot
.55001 .72459 Mdot
.66989 .5299 Mdot
.5796 .70771 Mdot
.39445 .76127 Mdot
.51164 .3828 Mdot
.33218 .3836 Mdot
.60677 .47461 Mdot
.47041 .57589 Mdot
.59394 .4462 Mdot
.64444 .52449 Mdot
.6714 .56429 Mdot
.62509 .65429 Mdot
.62787 .52304 Mdot
.50629 .3075 Mdot
.69408 .57916 Mdot
.49578 .61028 Mdot
.63944 .45669 Mdot
.30186 .26874 Mdot
.63618 .46786 Mdot
.67036 .52526 Mdot
.63621 .50826 Mdot
.63899 .55064 Mdot
.50683 .34056 Mdot
.6864 .59224 Mdot
.36496 .39364 Mdot
.60315 .71705 Mdot
.33361 .36145 Mdot
.28329 .5496 Mdot
.51822 .57563 Mdot
.57467 .34746 Mdot
.44257 .66345 Mdot
.38875 .51928 Mdot
.63521 .67144 Mdot
.29056 .58578 Mdot
.48117 .74437 Mdot
.42579 .65262 Mdot
.49945 .55646 Mdot
.41644 .69364 Mdot
.28692 .53106 Mdot
.35989 .38664 Mdot
.65725 .53773 Mdot
.51326 .32615 Mdot
.52243 .30787 Mdot
.64072 .45759 Mdot
.45657 .27522 Mdot
.346 .40155 Mdot
.24277 .51861 Mdot
.6429 .52823 Mdot
.62603 .52783 Mdot
.57916 .32319 Mdot
.26596 .57169 Mdot
.70387 .55717 Mdot
.42629 .68959 Mdot
.67098 .48733 Mdot
.49739 .6071 Mdot
.57439 .71167 Mdot
.35291 .39989 Mdot
.47884 .58124 Mdot
.63116 .48051 Mdot
.57176 .71954 Mdot
.60603 .48909 Mdot
.53635 .53411 Mdot
.26465 .58825 Mdot
.62393 .46024 Mdot
.67369 .50526 Mdot
.49364 .34685 Mdot
.32376 .3644 Mdot
.54977 .32126 Mdot
.56425 .3681 Mdot
.48832 .5968 Mdot
.31878 .38937 Mdot
.6342 .54545 Mdot
.35546 .34915 Mdot
.60988 .51756 Mdot
.65077 .49531 Mdot
.33192 .38078 Mdot
.54089 .3421 Mdot
.34837 .24635 Mdot
.75658 .36032 Mdot
.61678 .53255 Mdot
.64011 .48634 Mdot
.36962 .5454 Mdot
.51639 .58815 Mdot
.66585 .54119 Mdot
.51655 .30839 Mdot
.64308 .48101 Mdot
.33869 .34827 Mdot
.42827 .66594 Mdot
.54304 .31573 Mdot
.26309 .57173 Mdot
.30774 .56079 Mdot
.26879 .59487 Mdot
.4902 .5536 Mdot
.60814 .51888 Mdot
.4903 .33642 Mdot
.49352 .33067 Mdot
.58228 .68543 Mdot
.29474 .57107 Mdot
.42539 .6757 Mdot
.66917 .47655 Mdot
.51389 .58178 Mdot
.34483 .40618 Mdot
.61541 .16023 Mdot
.55335 .72568 Mdot
.45528 .69857 Mdot
.54617 .55162 Mdot
.48858 .58992 Mdot
.62697 .49896 Mdot
.42288 .66309 Mdot
.29707 .53541 Mdot
.60547 .50149 Mdot
.52474 .5337 Mdot
.30084 .50256 Mdot
.26669 .55292 Mdot
.36312 .35285 Mdot
.26244 .57973 Mdot
.41435 .67091 Mdot
.48186 .56283 Mdot
.53686 .30946 Mdot
.66172 .51016 Mdot
.50266 .58681 Mdot
.29518 .57575 Mdot
.50946 .55687 Mdot
.64327 .53303 Mdot
.57594 .32676 Mdot
.28197 .57987 Mdot
.64712 .51094 Mdot
.58777 .46218 Mdot
.69082 .26019 Mdot
.27646 .58514 Mdot
.68007 .51611 Mdot
.44704 .51641 Mdot
.26888 .55547 Mdot
.28435 .53287 Mdot
.62085 .46904 Mdot
.42799 .65458 Mdot
.65835 .48307 Mdot
.3559 .39083 Mdot
.57376 .70329 Mdot
.31475 .38242 Mdot
.5188 .77509 Mdot
.63238 .45624 Mdot
.60973 .43993 Mdot
.52653 .28473 Mdot
.45627 .63339 Mdot
.58651 .77776 Mdot
.6259 .47978 Mdot
.58656 .30834 Mdot
.56626 .70307 Mdot
.53356 .7127 Mdot
.58976 .38221 Mdot
.41718 .67902 Mdot
.33946 .37027 Mdot
.66967 .51841 Mdot
.3159 .27085 Mdot
.42095 .68435 Mdot
.52067 .77468 Mdot
.66544 .55471 Mdot
.53662 .32281 Mdot
.64832 .53044 Mdot
.53177 .31096 Mdot
.63494 .48381 Mdot
.68614 .25961 Mdot
.34055 .48234 Mdot
.6329 .68999 Mdot
.49476 .5594 Mdot
.36118 .42952 Mdot
.78222 .38621 Mdot
.43194 .67858 Mdot
.60293 .47476 Mdot
.48607 .58511 Mdot
.36158 .37756 Mdot
.31503 .31575 Mdot
.27714 .56815 Mdot
.36966 .38369 Mdot
.55531 .33612 Mdot
.29955 .58515 Mdot
.50701 .55061 Mdot
.60935 .43848 Mdot
.42225 .66179 Mdot
.31952 .39043 Mdot
.65971 .51678 Mdot
.6198 .49695 Mdot
.34834 .52295 Mdot
.30172 .74659 Mdot
.49091 .31909 Mdot
.69401 .22878 Mdot
.53276 .363 Mdot
.44907 .68944 Mdot
.28462 .58963 Mdot
.63951 .50443 Mdot
.65459 .47199 Mdot
.26566 .55218 Mdot
.54747 .35236 Mdot
.43207 .64417 Mdot
.39529 .70095 Mdot
.35788 .35302 Mdot
.34836 .77059 Mdot
.54239 .31402 Mdot
.34618 .76934 Mdot
.20735 .55237 Mdot
.54459 .21983 Mdot
.57827 .77807 Mdot
.34009 .38735 Mdot
.34751 .7705 Mdot
.53311 .32371 Mdot
.63145 .51876 Mdot
.4816 .59388 Mdot
.49261 .55039 Mdot
.57272 .33358 Mdot
.27978 .54616 Mdot
.42075 .65827 Mdot
.65087 .52917 Mdot
.53788 .51338 Mdot
.58239 .28386 Mdot
.279 .52019 Mdot
.49663 .57333 Mdot
.33151 .39205 Mdot
.6405 .48231 Mdot
.45413 .69359 Mdot
.34135 .38669 Mdot
.47467 .59978 Mdot
.62191 .68563 Mdot
.67856 .52646 Mdot
.70668 .5949 Mdot
.34853 .3725 Mdot
.5433 .56521 Mdot
.67223 .50483 Mdot
.32632 .36344 Mdot
.46625 .58417 Mdot
.40637 .38258 Mdot
.70002 .53688 Mdot
.43518 .32419 Mdot
.31753 .56691 Mdot
.27063 .58717 Mdot
.22153 .61048 Mdot
.33892 .59751 Mdot
.34995 .36156 Mdot
.49746 .58855 Mdot
.28201 .73405 Mdot
.32006 .36736 Mdot
.64631 .55056 Mdot
.66604 .52214 Mdot
.75407 .38059 Mdot
.47776 .60575 Mdot
.48422 .56623 Mdot
.52867 .24048 Mdot
.65495 .57328 Mdot
.49733 .57535 Mdot
.67008 .50295 Mdot
.51487 .33798 Mdot
.33741 .39294 Mdot
.75828 .72171 Mdot
.30834 .35871 Mdot
.61267 .53948 Mdot
.28564 .58372 Mdot
.31522 .57067 Mdot
.65934 .51111 Mdot
.44056 .50757 Mdot
.85203 .57912 Mdot
.667 .52138 Mdot
.70277 .59374 Mdot
.51375 .7728 Mdot
.63553 .45557 Mdot
.53664 .29985 Mdot
.4839 .60748 Mdot
.49864 .33874 Mdot
.3382 .38224 Mdot
.41748 .67945 Mdot
.46195 .63267 Mdot
.34036 .37078 Mdot
.64717 .47056 Mdot
.49996 .61567 Mdot
.65494 .50405 Mdot
.63292 .51407 Mdot
.5676 .71751 Mdot
.44807 .70282 Mdot
.27547 .55635 Mdot
.43985 .66117 Mdot
.53253 .34299 Mdot
.6587 .1964 Mdot
.43104 .67499 Mdot
.76281 .3846 Mdot
.58219 .7015 Mdot
.28866 .73603 Mdot
.52651 .30732 Mdot
.42553 .69708 Mdot
.33805 .3689 Mdot
.5495 .68466 Mdot
.7743 .41617 Mdot
.37087 .38361 Mdot
.6333 .5093 Mdot
.49942 .33501 Mdot
.55648 .36322 Mdot
.36081 .40117 Mdot
.54725 .30886 Mdot
.69404 .50919 Mdot
.63531 .55809 Mdot
.36556 .39365 Mdot
.6161 .77124 Mdot
.32664 .39768 Mdot
.7688 .35745 Mdot
.61266 .52738 Mdot
.54236 .31732 Mdot
.7905 .39352 Mdot
.53415 .36624 Mdot
.47568 .57436 Mdot
.65532 .54581 Mdot
.42804 .67599 Mdot
.5852 .69322 Mdot
.26728 .57906 Mdot
.51224 .37571 Mdot
.52018 .31601 Mdot
.35154 .40751 Mdot
.54602 .30898 Mdot
.56782 .31377 Mdot
.30871 .38305 Mdot
.56335 .31552 Mdot
.65428 .47629 Mdot
.70476 .2505 Mdot
.54914 .30703 Mdot
.34701 .37931 Mdot
.44549 .69808 Mdot
.52146 .30253 Mdot
.30065 .47553 Mdot
.6631 .47283 Mdot
.3126 .52672 Mdot
.41893 .71125 Mdot
.50903 .33956 Mdot
.43012 .67925 Mdot
.29165 .57789 Mdot
.45128 .64747 Mdot
.37238 .35283 Mdot
.37824 .36177 Mdot
.46318 .55824 Mdot
.4036 .39947 Mdot
.5387 .34637 Mdot
.29828 .58674 Mdot
.67609 .48937 Mdot
.63827 .5242 Mdot
.43728 .71182 Mdot
.57973 .3132 Mdot
.45547 .27231 Mdot
.49608 .5808 Mdot
.45472 .31492 Mdot
.34974 .4012 Mdot
.246 .51612 Mdot
.54902 .72601 Mdot
.29246 .41281 Mdot
.49565 .61077 Mdot
.48744 .58967 Mdot
.65326 .51107 Mdot
.49587 .75569 Mdot
.4145 .67321 Mdot
.20798 .38136 Mdot
.61297 .50063 Mdot
.26392 .5483 Mdot
.63324 .49254 Mdot
.67236 .58366 Mdot
.62442 .47613 Mdot
.45267 .70178 Mdot
.36629 .36628 Mdot
.51499 .3104 Mdot
.42247 .6947 Mdot
.30844 .55961 Mdot
.66039 .66675 Mdot
.66794 .53901 Mdot
.68165 .4938 Mdot
.27291 .54905 Mdot
.52075 .33532 Mdot
.28363 .55638 Mdot
.32941 .36225 Mdot
.43293 .67272 Mdot
.60886 .5079 Mdot
.47833 .60639 Mdot
.2999 .51224 Mdot
.36497 .38389 Mdot
.28548 .59092 Mdot
.32364 .34722 Mdot
.48648 .59325 Mdot
.67592 .47065 Mdot
.24952 .54945 Mdot
.50688 .59186 Mdot
.71077 .36999 Mdot
.62219 .68084 Mdot
.60294 .34959 Mdot
.2792 .5439 Mdot
.32928 .58992 Mdot
.34352 .38408 Mdot
.3143 .36012 Mdot
.76866 .35381 Mdot
.8612 .52662 Mdot
.70589 .57108 Mdot
.4394 .28973 Mdot
.3303 .36163 Mdot
.3545 .37717 Mdot
.28099 .55747 Mdot
.54534 .34381 Mdot
.50883 .29295 Mdot
.3089 .57383 Mdot
.55496 .77819 Mdot
.53684 .32816 Mdot
.7903 .47078 Mdot
.29407 .51873 Mdot
.62967 .55728 Mdot
.68312 .26505 Mdot
.46042 .6767 Mdot
.51332 .76681 Mdot
.29665 .39254 Mdot
.64477 .51469 Mdot
.29195 .26404 Mdot
.27948 .56959 Mdot
.51325 .56797 Mdot
.40139 .35027 Mdot
.62035 .52301 Mdot
.63175 .49603 Mdot
.64878 .47808 Mdot
.4107 .69466 Mdot
.68314 .3203 Mdot
.64236 .5108 Mdot
.62748 .68376 Mdot
.64987 .57925 Mdot
.32283 .52369 Mdot
.439 .66146 Mdot
.4785 .74056 Mdot
.31948 .48769 Mdot
.4483 .31893 Mdot
.67246 .56418 Mdot
.33027 .35129 Mdot
.67551 .58433 Mdot
.33025 .37914 Mdot
.37683 .38036 Mdot
.36746 .79037 Mdot
.50614 .31234 Mdot
.61242 .5062 Mdot
.27905 .5239 Mdot
.50876 .29242 Mdot
.67604 .58598 Mdot
.67188 .20543 Mdot
.34362 .41089 Mdot
.89568 .45976 Mdot
.31752 .35961 Mdot
.50266 .55199 Mdot
.56027 .33218 Mdot
.58598 .29867 Mdot
.57991 .70901 Mdot
.53188 .34052 Mdot
.35614 .58469 Mdot
.49104 .32953 Mdot
.47086 .81425 Mdot
.57123 .3784 Mdot
.34923 .38563 Mdot
.3568 .40422 Mdot
.66569 .58499 Mdot
.6617 .4844 Mdot
.57949 .73726 Mdot
.49605 .5797 Mdot
.6725 .54426 Mdot
.29486 .54576 Mdot
.28463 .48043 Mdot
.28618 .30983 Mdot
.56488 .31748 Mdot
.36422 .37622 Mdot
.63251 .4956 Mdot
.61207 .52376 Mdot
.63995 .53371 Mdot
.32656 .47354 Mdot
.79724 .48143 Mdot
.65527 .49334 Mdot
.66379 .58347 Mdot
.29787 .5814 Mdot
.35026 .52615 Mdot
.51104 .20458 Mdot
.35858 .78061 Mdot
.63814 .46256 Mdot
.45315 .68422 Mdot
.44159 .70528 Mdot
.66891 .57893 Mdot
.57012 .42871 Mdot
.49421 .65154 Mdot
.65909 .51762 Mdot
.66187 .6606 Mdot
.32066 .5366 Mdot
.47239 .5718 Mdot
.29618 .57422 Mdot
.56408 .30016 Mdot
.46974 .58822 Mdot
.29517 .53931 Mdot
.62254 .71218 Mdot
.49299 .59678 Mdot
.40481 .38233 Mdot
.42874 .69817 Mdot
.67104 .50333 Mdot
.73817 .3369 Mdot
.26576 .52158 Mdot
.35505 .38867 Mdot
.56041 .3254 Mdot
.35167 .3993 Mdot
.28873 .60734 Mdot
.53761 .78024 Mdot
.47459 .5797 Mdot
.33126 .3507 Mdot
.70816 .59223 Mdot
.45473 .67667 Mdot
.31806 .36317 Mdot
.62375 .55399 Mdot
.66208 .575 Mdot
.83998 .57168 Mdot
.67516 .48105 Mdot
.27519 .48389 Mdot
.31399 .38294 Mdot
.46878 .58147 Mdot
.662 .50869 Mdot
.30503 .5263 Mdot
.4648 .60484 Mdot
.65359 .5036 Mdot
.25907 .55896 Mdot
.66607 .51981 Mdot
.4292 .66066 Mdot
.495 .34318 Mdot
.56179 .70186 Mdot
.39231 .68472 Mdot
.41786 .68391 Mdot
.63595 .66776 Mdot
.66239 .54588 Mdot
.34847 .59411 Mdot
.54044 .32375 Mdot
.62373 .51711 Mdot
.46616 .79142 Mdot
.561 .34023 Mdot
.54976 .33267 Mdot
.60599 .51828 Mdot
.32432 .34885 Mdot
.27446 .55291 Mdot
.45188 .66613 Mdot
.28969 .42487 Mdot
.6451 .5103 Mdot
.60582 .47793 Mdot
.42103 .68899 Mdot
.34841 .39469 Mdot
.61304 .51822 Mdot
.41575 .33345 Mdot
.6073 .71021 Mdot
.31259 .3885 Mdot
.66999 .56545 Mdot
.80331 .46395 Mdot
.5673 .35017 Mdot
.29091 .26555 Mdot
.34095 .48242 Mdot
.3114 .55913 Mdot
.49897 .57495 Mdot
.62365 .16789 Mdot
.44408 .69958 Mdot
.48518 .362 Mdot
.64112 .52994 Mdot
.63872 .49646 Mdot
.52511 .3431 Mdot
.67516 .51945 Mdot
.56596 .31631 Mdot
.30375 .47708 Mdot
.8692 .51192 Mdot
.52847 .30861 Mdot
.5277 .31559 Mdot
.75266 .56709 Mdot
.24897 .53594 Mdot
.56754 .33333 Mdot
.6745 .50731 Mdot
.29488 .60854 Mdot
.54036 .52672 Mdot
.43766 .64349 Mdot
.4082 .68472 Mdot
.53116 .29883 Mdot
.77713 .41925 Mdot
.62945 .55964 Mdot
.75174 .43999 Mdot
.49155 .6573 Mdot
.34721 .35996 Mdot
.61204 .46675 Mdot
.4926 .58389 Mdot
.28702 .57612 Mdot
.63559 .45208 Mdot
.67069 .49866 Mdot
.50918 .31411 Mdot
.45838 .65855 Mdot
.31975 .37053 Mdot
.50832 .58844 Mdot
.2884 .60565 Mdot
.43332 .69012 Mdot
.56957 .31234 Mdot
.78042 .377 Mdot
.50697 .60706 Mdot
.51229 .58524 Mdot
.6258 .49984 Mdot
.62147 .46584 Mdot
.49898 .61113 Mdot
.34003 .37228 Mdot
.31343 .55512 Mdot
.51063 .57072 Mdot
.56605 .6752 Mdot
.59716 .73456 Mdot
.62711 .4795 Mdot
.51848 .30503 Mdot
.3628 .37735 Mdot
.47943 .56984 Mdot
.27499 .72798 Mdot
.65853 .46604 Mdot
.79171 .47202 Mdot
.40625 .66363 Mdot
.49325 .58812 Mdot
.50697 .29385 Mdot
.44615 .6622 Mdot
.6128 .52742 Mdot
.62899 .68664 Mdot
.66941 .55 Mdot
.67181 .57094 Mdot
.29419 .53323 Mdot
.32516 .37284 Mdot
.4656 .55281 Mdot
.28975 .57231 Mdot
.55148 .3314 Mdot
.7527 .45028 Mdot
.49907 .32979 Mdot
.49416 .32635 Mdot
.50246 .36104 Mdot
.34594 .39954 Mdot
.62265 .16655 Mdot
.50593 .60565 Mdot
.6553 .53408 Mdot
.35785 .36175 Mdot
.56932 .32853 Mdot
.65785 .552 Mdot
.56749 .31772 Mdot
.57588 .31168 Mdot
.67175 .54806 Mdot
.64585 .57164 Mdot
.63308 .68317 Mdot
.7948 .45601 Mdot
.43922 .65784 Mdot
.54787 .35124 Mdot
.78697 .44167 Mdot
.64047 .50406 Mdot
.6674 .48999 Mdot
.67305 .5884 Mdot
.41777 .69069 Mdot
.75066 .46706 Mdot
.63768 .52511 Mdot
.48909 .75448 Mdot
.65184 .55037 Mdot
.58057 .31226 Mdot
.37204 .42024 Mdot
.61519 .54335 Mdot
.29921 .58345 Mdot
.54514 .35192 Mdot
.46073 .67528 Mdot
.59111 .31933 Mdot
.59506 .45489 Mdot
.34931 .36796 Mdot
.52582 .319 Mdot
.31346 .56726 Mdot
.35057 .39115 Mdot
.32666 .39746 Mdot
.67512 .58953 Mdot
.31292 .54277 Mdot
.45907 .65978 Mdot
.32144 .385 Mdot
.58937 .44929 Mdot
.35031 .38655 Mdot
.63885 .40859 Mdot
.67903 .48005 Mdot
.62691 .68587 Mdot
.5058 .56966 Mdot
.46949 .55436 Mdot
.31669 .38353 Mdot
.42583 .69058 Mdot
.61286 .51694 Mdot
.55528 .30884 Mdot
.44946 .69434 Mdot
.68239 .27199 Mdot
.31214 .5744 Mdot
.55251 .36254 Mdot
.29273 .42548 Mdot
.556 .34748 Mdot
.51626 .76916 Mdot
.46035 .68612 Mdot
.51665 .57032 Mdot
.55794 .71042 Mdot
.49301 .57037 Mdot
.64804 .45583 Mdot
.61273 .51514 Mdot
.65166 .47462 Mdot
.28536 .58413 Mdot
.4096 .68986 Mdot
.5397 .30373 Mdot
.49779 .5124 Mdot
.34798 .39672 Mdot
.6973 .58434 Mdot
.51205 .56772 Mdot
.61389 .52499 Mdot
.56748 .32514 Mdot
.5837 .32103 Mdot
.6822 .30493 Mdot
.26867 .55964 Mdot
.50108 .52335 Mdot
.62725 .47692 Mdot
.51444 .51043 Mdot
.31656 .38446 Mdot
.43272 .33002 Mdot
.31397 .52554 Mdot
.89579 .45695 Mdot
.29202 .57036 Mdot
.5327 .5434 Mdot
.57516 .33616 Mdot
.44156 .67395 Mdot
.64567 .4683 Mdot
.49417 .34982 Mdot
.49442 .30155 Mdot
.46419 .69892 Mdot
.44378 .66492 Mdot
.31408 .45 Mdot
.34594 .35759 Mdot
.50715 .5935 Mdot
.6505 .55038 Mdot
.66372 .55308 Mdot
.67681 .49767 Mdot
.36194 .36882 Mdot
.64498 .56881 Mdot
.35647 .43062 Mdot
.59313 .46909 Mdot
.46794 .79259 Mdot
.27781 .53293 Mdot
.17347 .53521 Mdot
.50609 .33875 Mdot
.75162 .46182 Mdot
.63235 .41382 Mdot
.61954 .68398 Mdot
.36545 .36282 Mdot
.46564 .5908 Mdot
.27833 .55451 Mdot
.27996 .32543 Mdot
.27743 .53173 Mdot
.80516 .65872 Mdot
.75337 .37909 Mdot
.38662 .41049 Mdot
.66754 .54799 Mdot
.29782 .53105 Mdot
.78157 .42311 Mdot
.51016 .57332 Mdot
.49907 .61624 Mdot
.59094 .47438 Mdot
.69529 .27502 Mdot
.43732 .65776 Mdot
.64073 .46658 Mdot
.50051 .33764 Mdot
.64921 .46962 Mdot
.6455 .4675 Mdot
.63996 .53076 Mdot
.31452 .39657 Mdot
.67966 .47987 Mdot
.65874 .48043 Mdot
.20451 .64466 Mdot
.5086 .62238 Mdot
.26357 .58319 Mdot
.5878 .29887 Mdot
.4556 .67611 Mdot
.56564 .30097 Mdot
.55995 .70523 Mdot
.31172 .3626 Mdot
.6814 .30723 Mdot
.62545 .54911 Mdot
.49312 .36307 Mdot
.31256 .35619 Mdot
.43091 .65153 Mdot
.48973 .58421 Mdot
.40027 .21319 Mdot
.25317 .52575 Mdot
.48391 .57337 Mdot
.26221 .56602 Mdot
.60633 .44143 Mdot
.54032 .31038 Mdot
.49336 .57137 Mdot
.31965 .37442 Mdot
.28476 .52774 Mdot
.63612 .67249 Mdot
.64668 .4838 Mdot
.2813 .54066 Mdot
.50117 .58652 Mdot
.58522 .69466 Mdot
.56757 .7037 Mdot
.29537 .52861 Mdot
.37193 .36238 Mdot
.32834 .39515 Mdot
.45643 .68299 Mdot
.57925 .3336 Mdot
.5149 .32995 Mdot
.34291 .39513 Mdot
.27081 .33296 Mdot
.64648 .51205 Mdot
.64988 .49278 Mdot
.54985 .71648 Mdot
.63417 .54073 Mdot
.37349 .56289 Mdot
.48644 .57337 Mdot
.51185 .32097 Mdot
.61299 .51637 Mdot
.61528 .5227 Mdot
.63631 .46664 Mdot
.55719 .78007 Mdot
.28564 .5825 Mdot
.6403 .57014 Mdot
.42168 .66394 Mdot
.6914 .27164 Mdot
.67098 .48434 Mdot
.43549 .63566 Mdot
.57543 .33728 Mdot
.37609 .32114 Mdot
.35617 .38716 Mdot
.27369 .52383 Mdot
.27714 .52366 Mdot
.39747 .76482 Mdot
.51106 .33836 Mdot
.48477 .57265 Mdot
.30208 .50244 Mdot
.48619 .55775 Mdot
.44588 .6669 Mdot
.70353 .53586 Mdot
.37041 .56786 Mdot
.26321 .58226 Mdot
.30671 .35172 Mdot
.61969 .51169 Mdot
.66971 .48472 Mdot
.44811 .29865 Mdot
.66755 .50395 Mdot
.42714 .67135 Mdot
.3287 .35679 Mdot
.52783 .31995 Mdot
.43746 .65485 Mdot
.32315 .35281 Mdot
.52646 .33823 Mdot
.65303 .57876 Mdot
.6557 .55185 Mdot
.55626 .32958 Mdot
.57318 .31631 Mdot
.64859 .52078 Mdot
.3845 .80789 Mdot
.51276 .31319 Mdot
.56058 .32832 Mdot
.69202 .27278 Mdot
.25078 .55482 Mdot
.4659 .60899 Mdot
.33313 .34851 Mdot
.6557 .47998 Mdot
.27437 .5368 Mdot
.44708 .67866 Mdot
.51833 .3187 Mdot
.6245 .46304 Mdot
.64524 .50492 Mdot
.45422 .6808 Mdot
.41141 .68524 Mdot
.43267 .69581 Mdot
.36165 .40039 Mdot
.625 .55051 Mdot
.56464 .33191 Mdot
.37009 .37657 Mdot
.45437 .69495 Mdot
.41143 .6771 Mdot
.50838 .81426 Mdot
.64718 .51648 Mdot
.41243 .69207 Mdot
.64695 .18828 Mdot
.63244 .707 Mdot
.47848 .56403 Mdot
.28404 .59605 Mdot
.30515 .60783 Mdot
.53695 .56414 Mdot
.32709 .37087 Mdot
.69724 .59101 Mdot
.43721 .6453 Mdot
.50594 .58268 Mdot
.64917 .48826 Mdot
.62134 .45469 Mdot
.44815 .69367 Mdot
.53565 .78088 Mdot
.50535 .31697 Mdot
.60427 .29629 Mdot
.45533 .67427 Mdot
.2965 .52691 Mdot
.31527 .52413 Mdot
.28964 .56472 Mdot
.62563 .47257 Mdot
.77794 .51375 Mdot
.58571 .43587 Mdot
.71809 .44282 Mdot
.34154 .35726 Mdot
.58307 .31933 Mdot
.69325 .26439 Mdot
.54777 .33352 Mdot
.27026 .57311 Mdot
.42529 .6899 Mdot
.52054 .33966 Mdot
.34187 .40154 Mdot
.32397 .39249 Mdot
.24979 .54799 Mdot
.29688 .5703 Mdot
.28942 .55401 Mdot
.55422 .35488 Mdot
.57572 .3293 Mdot
.66342 .54995 Mdot
.52773 .3045 Mdot
.30733 .48096 Mdot
.30649 .47826 Mdot
.25575 .52926 Mdot
.34207 .3767 Mdot
.53069 .33493 Mdot
.67193 .51137 Mdot
.62179 .65167 Mdot
.30285 .50873 Mdot
.45816 .6654 Mdot
.7045 .24916 Mdot
.85563 .5366 Mdot
.61057 .48149 Mdot
.34825 .36347 Mdot
.48902 .56027 Mdot
.6446 .47488 Mdot
.31205 .56011 Mdot
.52359 .55853 Mdot
.48083 .6046 Mdot
.68008 .49584 Mdot
.68079 .53062 Mdot
.35901 .37426 Mdot
.55708 .70411 Mdot
.50735 .58265 Mdot
.67951 .59388 Mdot
.33639 .3541 Mdot
.29965 .51468 Mdot
.21199 .59922 Mdot
.5049 .25224 Mdot
.49536 .71023 Mdot
.4725 .59565 Mdot
.66187 .46719 Mdot
.2983 .54635 Mdot
.43425 .6539 Mdot
.29705 .55129 Mdot
.56105 .3011 Mdot
.25118 .56058 Mdot
.66887 .51463 Mdot
.5641 .33455 Mdot
.32484 .39445 Mdot
.54092 .68325 Mdot
.46109 .53968 Mdot
.30284 .52411 Mdot
.51497 .58171 Mdot
.65246 .57178 Mdot
.59265 .44223 Mdot
.46945 .55509 Mdot
.67234 .49729 Mdot
.33153 .38126 Mdot
.56634 .32017 Mdot
.35908 .39286 Mdot
.46305 .59156 Mdot
.58222 .4023 Mdot
.35777 .38551 Mdot
.77305 .52696 Mdot
.41959 .65913 Mdot
.54367 .7811 Mdot
.66059 .52058 Mdot
.32132 .37449 Mdot
.68142 .49616 Mdot
.54214 .34987 Mdot
.61175 .72112 Mdot
.61094 .70253 Mdot
.33591 .39178 Mdot
.49802 .54515 Mdot
.58275 .69973 Mdot
.46664 .61232 Mdot
.33204 .36175 Mdot
.64345 .70315 Mdot
.48149 .58161 Mdot
.43655 .68849 Mdot
.41036 .67825 Mdot
.42887 .68572 Mdot
.65431 .49054 Mdot
.80304 .43606 Mdot
.44741 .70135 Mdot
.33758 .31634 Mdot
.42307 .66953 Mdot
.53961 .55312 Mdot
.45873 .26909 Mdot
.4151 .66952 Mdot
.66455 .51268 Mdot
.59911 .471 Mdot
.70009 .59225 Mdot
.31767 .54873 Mdot
.37866 .22728 Mdot
.20267 .63779 Mdot
.63922 .50474 Mdot
.69687 .25465 Mdot
.49199 .34378 Mdot
.51734 .56751 Mdot
.61382 .69633 Mdot
.71521 .59385 Mdot
.54866 .33716 Mdot
.55774 .70782 Mdot
.55096 .36011 Mdot
.50154 .55932 Mdot
.65243 .49461 Mdot
.54295 .35145 Mdot
.51297 .37582 Mdot
.58868 .77733 Mdot
.45465 .30631 Mdot
.52686 .33528 Mdot
.32354 .36445 Mdot
.33135 .3694 Mdot
.33209 .3847 Mdot
.30302 .56633 Mdot
.52495 .31527 Mdot
.65898 .57224 Mdot
.30923 .56257 Mdot
.63415 .5132 Mdot
.33883 .39421 Mdot
.61701 .6938 Mdot
.52805 .31641 Mdot
.65798 .51971 Mdot
.78116 .43165 Mdot
.25889 .55087 Mdot
.45354 .68516 Mdot
.6992 .2515 Mdot
.288 .59335 Mdot
.35464 .34911 Mdot
.54942 .29836 Mdot
.50273 .62495 Mdot
.68623 .59527 Mdot
.62484 .49038 Mdot
.6593 .53803 Mdot
.6965 .59686 Mdot
.75575 .37565 Mdot
.49407 .60723 Mdot
.3081 .56004 Mdot
.25216 .56075 Mdot
.66402 .47198 Mdot
.52348 .31275 Mdot
.46479 .67577 Mdot
.43451 .63875 Mdot
.52025 .52961 Mdot
.57595 .70599 Mdot
.6272 .68383 Mdot
.63784 .54854 Mdot
.75207 .50337 Mdot
.31441 .56321 Mdot
.48351 .55661 Mdot
.57264 .71117 Mdot
.43364 .68132 Mdot
.63206 .51866 Mdot
.575 .28269 Mdot
.52134 .32046 Mdot
.27793 .54576 Mdot
.3306 .40603 Mdot
.50537 .6095 Mdot
.25458 .53039 Mdot
.6636 .47168 Mdot
.61457 .52119 Mdot
.31766 .36751 Mdot
.55174 .30004 Mdot
.44194 .69192 Mdot
.30738 .56735 Mdot
.43885 .67634 Mdot
.54875 .31104 Mdot
.51738 .31919 Mdot
.6285 .52088 Mdot
.50256 .52089 Mdot
.30024 .52086 Mdot
.62874 .46492 Mdot
.2864 .54101 Mdot
.34741 .52182 Mdot
.34625 .40576 Mdot
.62472 .5194 Mdot
.51941 .28707 Mdot
.33779 .39542 Mdot
.63695 .50372 Mdot
.69354 .5935 Mdot
.61389 .52182 Mdot
.29897 .53096 Mdot
.42419 .64357 Mdot
.43812 .68489 Mdot
.6611 .42528 Mdot
.67878 .28439 Mdot
.6289 .53869 Mdot
.26257 .52451 Mdot
.58444 .47313 Mdot
.35604 .37467 Mdot
.56629 .34383 Mdot
.16067 .48808 Mdot
.34885 .38042 Mdot
.66235 .52288 Mdot
.43049 .67435 Mdot
.57389 .31366 Mdot
.47017 .58202 Mdot
.53939 .74561 Mdot
.48276 .54311 Mdot
.50851 .52157 Mdot
.50125 .59882 Mdot
.44262 .2877 Mdot
.29167 .55266 Mdot
.56813 .32696 Mdot
.34363 .36256 Mdot
.35293 .37049 Mdot
.26464 .56928 Mdot
.6825 .27848 Mdot
.53525 .21468 Mdot
.64099 .18 Mdot
.26623 .51363 Mdot
.42354 .68104 Mdot
.61408 .71745 Mdot
.28803 .56521 Mdot
.26718 .58089 Mdot
.33244 .48317 Mdot
.44599 .3028 Mdot
.54058 .34066 Mdot
.64433 .50399 Mdot
.69039 .25924 Mdot
.64679 .53378 Mdot
.49873 .70509 Mdot
.34118 .39324 Mdot
.5658 .34426 Mdot
.35345 .45556 Mdot
.63623 .4583 Mdot
.63428 .4784 Mdot
.29681 .47673 Mdot
.49371 .57891 Mdot
.30869 .74775 Mdot
.6473 .53961 Mdot
.30177 .56051 Mdot
.5154 .2736 Mdot
.50574 .56372 Mdot
.78265 .43213 Mdot
.31339 .37933 Mdot
.47608 .57588 Mdot
.50667 .56327 Mdot
.7534 .51107 Mdot
.53923 .36072 Mdot
.51281 .3326 Mdot
.41531 .69282 Mdot
.47787 .25974 Mdot
.31201 .37483 Mdot
.42454 .31572 Mdot
.67386 .50565 Mdot
.37904 .38047 Mdot
.39511 .69864 Mdot
.63728 .50846 Mdot
.67712 .5871 Mdot
.68167 .30445 Mdot
.61507 .47341 Mdot
.59983 .44934 Mdot
.34505 .38281 Mdot
.47189 .78726 Mdot
.65809 .56545 Mdot
.28047 .54256 Mdot
.54808 .3444 Mdot
.54418 .36382 Mdot
.44305 .65208 Mdot
.3473 .47968 Mdot
.88137 .48871 Mdot
.5645 .34476 Mdot
.64897 .48355 Mdot
.35575 .37729 Mdot
.47241 .57951 Mdot
.50427 .56994 Mdot
.50381 .54414 Mdot
.52319 .32418 Mdot
.50712 .56694 Mdot
.48011 .3519 Mdot
.55809 .70669 Mdot
.75181 .45851 Mdot
.33075 .38888 Mdot
.42498 .67793 Mdot
.53459 .52953 Mdot
.33576 .50111 Mdot
.64847 .55102 Mdot
.49768 .70664 Mdot
.50332 .34993 Mdot
.42585 .67418 Mdot
.64408 .47114 Mdot
.5015 .6022 Mdot
.66513 .65102 Mdot
.45876 .64687 Mdot
.49818 .60231 Mdot
.6092 .48926 Mdot
.53634 .34516 Mdot
.4851 .57014 Mdot
.52954 .32296 Mdot
.64183 .46929 Mdot
.49796 .66303 Mdot
.55204 .35068 Mdot
.36374 .23671 Mdot
.51144 .59938 Mdot
.31603 .35697 Mdot
.62079 .44956 Mdot
.63789 .46222 Mdot
.78535 .4911 Mdot
.47719 .56998 Mdot
.30481 .26735 Mdot
.28387 .53577 Mdot
.29207 .74401 Mdot
.26339 .59214 Mdot
.31967 .46206 Mdot
.40606 .33439 Mdot
.62054 .46052 Mdot
.68288 .27982 Mdot
.78057 .50615 Mdot
.36923 .36127 Mdot
.78401 .49942 Mdot
.66154 .48423 Mdot
.62618 .49891 Mdot
.28528 .54058 Mdot
.3714 .40515 Mdot
.6084 .52911 Mdot
.57356 .71051 Mdot
.43107 .65049 Mdot
.54891 .32303 Mdot
.65969 .48927 Mdot
.52684 .38602 Mdot
.29219 .52468 Mdot
.60491 .34313 Mdot
.66168 .51492 Mdot
.49333 .57906 Mdot
.37527 .38853 Mdot
.32218 .39287 Mdot
.30688 .53564 Mdot
.30705 .53309 Mdot
.6391 .46256 Mdot
.36664 .38904 Mdot
.65737 .55757 Mdot
.5834 .69848 Mdot
.5004 .58913 Mdot
.44933 .67058 Mdot
.67214 .52291 Mdot
.56617 .23485 Mdot
.5971 .81975 Mdot
.62598 .47342 Mdot
.50021 .33343 Mdot
.28613 .55203 Mdot
.27687 .58188 Mdot
.51568 .32975 Mdot
.27569 .58118 Mdot
.60428 .29368 Mdot
.8036 .43958 Mdot
.44383 .6682 Mdot
.5742 .47082 Mdot
.41776 .67936 Mdot
.47732 .57249 Mdot
.64786 .51797 Mdot
.23144 .35272 Mdot
.26598 .51447 Mdot
.59236 .60125 Mdot
.34608 .39213 Mdot
.49153 .55114 Mdot
.63792 .56293 Mdot
.42336 .71326 Mdot
.28249 .57295 Mdot
.49139 .6183 Mdot
.63595 .52688 Mdot
.5521 .35375 Mdot
.60456 .48067 Mdot
.50215 .55467 Mdot
.48479 .56465 Mdot
.48501 .61674 Mdot
.32317 .35277 Mdot
.56096 .31258 Mdot
.31469 .45097 Mdot
.25833 .54359 Mdot
.67399 .54191 Mdot
.64785 .48104 Mdot
.58178 .32487 Mdot
.65948 .53277 Mdot
.36722 .39093 Mdot
.59177 .14492 Mdot
.42782 .69458 Mdot
.4741 .5728 Mdot
.39405 .2488 Mdot
.48275 .61777 Mdot
.60888 .49915 Mdot
.73408 .58342 Mdot
.58258 .28467 Mdot
.32119 .35201 Mdot
.67844 .55409 Mdot
.26156 .58327 Mdot
.44087 .69051 Mdot
.34212 .40221 Mdot
.63885 .56076 Mdot
.66696 .51392 Mdot
.42648 .67578 Mdot
.3566 .44978 Mdot
.42269 .64911 Mdot
.34067 .36063 Mdot
.48161 .5514 Mdot
.62583 .64971 Mdot
.65243 .50947 Mdot
.48839 .57608 Mdot
.55811 .31666 Mdot
.35084 .3604 Mdot
.68492 .3245 Mdot
.50354 .55971 Mdot
.28904 .42177 Mdot
.31809 .38847 Mdot
.62414 .49682 Mdot
.5229 .34502 Mdot
.55557 .37099 Mdot
.56392 .32075 Mdot
.42576 .78821 Mdot
.29812 .44952 Mdot
.28881 .54985 Mdot
.34394 .37672 Mdot
.27074 .54087 Mdot
.41791 .66051 Mdot
.59608 .73255 Mdot
.30505 .52862 Mdot
.50126 .31078 Mdot
.27276 .53353 Mdot
.65785 .55646 Mdot
.31265 .35884 Mdot
.29472 .51776 Mdot
.67513 .51264 Mdot
.65712 .58158 Mdot
.49048 .56509 Mdot
.46378 .67688 Mdot
.56649 .70679 Mdot
.6548 .52757 Mdot
.48688 .58157 Mdot
.65567 .51806 Mdot
.3667 .39119 Mdot
.53306 .68257 Mdot
.67791 .53461 Mdot
.26769 .51309 Mdot
.42037 .2002 Mdot
.25179 .54671 Mdot
.45158 .51505 Mdot
.63598 .51449 Mdot
.65068 .51219 Mdot
.65064 .57228 Mdot
.70878 .27326 Mdot
.37354 .36112 Mdot
.67334 .46645 Mdot
.29323 .58801 Mdot
.54146 .33508 Mdot
.5124 .3375 Mdot
.714 .56714 Mdot
.48573 .57542 Mdot
.36152 .39909 Mdot
.64883 .51231 Mdot
.49343 .55417 Mdot
.56941 .72881 Mdot
.46664 .26858 Mdot
.31447 .48296 Mdot
.26053 .56858 Mdot
.57642 .34199 Mdot
.29009 .58413 Mdot
.63974 .56261 Mdot
.5041 .56421 Mdot
.29451 .44337 Mdot
.30508 .33888 Mdot
.44151 .68956 Mdot
.62963 .50159 Mdot
.56598 .77968 Mdot
.29833 .58095 Mdot
.31348 .54684 Mdot
.65862 .55738 Mdot
.48816 .27673 Mdot
.56347 .82096 Mdot
.36237 .36455 Mdot
.62188 .39685 Mdot
.75358 .34185 Mdot
.75406 .66912 Mdot
.34201 .3694 Mdot
.6788 .58684 Mdot
.31914 .55669 Mdot
.3605 .74688 Mdot
.54639 .33562 Mdot
.44277 .69069 Mdot
.67447 .5157 Mdot
.50136 .31265 Mdot
.26416 .51385 Mdot
.55723 .30603 Mdot
.49788 .5767 Mdot
.31186 .35754 Mdot
.28671 .57818 Mdot
.32985 .40713 Mdot
.52937 .28477 Mdot
.42317 .68665 Mdot
.49173 .75039 Mdot
.58899 .46258 Mdot
.68124 .30072 Mdot
.63003 .55686 Mdot
.51361 .61908 Mdot
.63763 .56627 Mdot
.54258 .36527 Mdot
.66151 .51973 Mdot
.66897 .56615 Mdot
.31663 .56864 Mdot
.62631 .48258 Mdot
.67364 .50996 Mdot
.78293 .43557 Mdot
.63274 .50136 Mdot
.63986 .46557 Mdot
.62415 .49115 Mdot
.50046 .32661 Mdot
.63341 .52766 Mdot
.57355 .32109 Mdot
.49495 .36766 Mdot
.25839 .54523 Mdot
.41453 .66789 Mdot
.41423 .67187 Mdot
.50609 .66876 Mdot
.56377 .77965 Mdot
.69107 .26151 Mdot
.53669 .33032 Mdot
.31778 .38574 Mdot
.66287 .55163 Mdot
.52183 .81954 Mdot
.49892 .66387 Mdot
.31871 .53952 Mdot
.28769 .52163 Mdot
.6777 .49574 Mdot
.84948 .54704 Mdot
.65042 .54205 Mdot
.55224 .72505 Mdot
.65527 .49081 Mdot
.62567 .52377 Mdot
.26585 .59154 Mdot
.51514 .76895 Mdot
.64202 .572 Mdot
.52917 .35719 Mdot
.44499 .68765 Mdot
.48776 .57058 Mdot
.50061 .66664 Mdot
.77529 .36489 Mdot
.54146 .24308 Mdot
.65186 .57303 Mdot
.30845 .56806 Mdot
.5143 .32105 Mdot
.55169 .71593 Mdot
.36926 .37463 Mdot
.54167 .74832 Mdot
.64493 .40927 Mdot
.36233 .36271 Mdot
.43725 .68937 Mdot
.30292 .51075 Mdot
.63142 .47139 Mdot
.30107 .54567 Mdot
.63333 .45809 Mdot
.56065 .73443 Mdot
.44677 .66979 Mdot
.48928 .32752 Mdot
.32248 .36387 Mdot
.50217 .31785 Mdot
.60213 .35423 Mdot
.49662 .66943 Mdot
.24626 .70512 Mdot
.25371 .53392 Mdot
.49392 .50811 Mdot
.57119 .33506 Mdot
.65661 .46474 Mdot
.63681 .17996 Mdot
.54447 .31395 Mdot
.54873 .35283 Mdot
.52897 .72883 Mdot
.51576 .77657 Mdot
.62314 .47514 Mdot
.5147 .30546 Mdot
.29927 .50855 Mdot
.44025 .66359 Mdot
.67528 .4976 Mdot
.49881 .56165 Mdot
.52207 .34101 Mdot
.2759 .57441 Mdot
.50894 .76324 Mdot
.29977 .56602 Mdot
.54742 .34106 Mdot
.26971 .5239 Mdot
.31766 .44727 Mdot
.30439 .52771 Mdot
.66807 .52899 Mdot
.64952 .5116 Mdot
.56462 .37621 Mdot
.51735 .31902 Mdot
.60882 .49963 Mdot
.64965 .53262 Mdot
.56817 .33153 Mdot
.2929 .50284 Mdot
.57083 .25948 Mdot
.61203 .50932 Mdot
.6454 .50889 Mdot
.42146 .69328 Mdot
.57281 .67914 Mdot
.54187 .69838 Mdot
.66084 .55063 Mdot
.42439 .68426 Mdot
.55983 .35393 Mdot
.65141 .5209 Mdot
.51133 .77084 Mdot
.323 .55065 Mdot
.65045 .56257 Mdot
.47073 .5862 Mdot
.61322 .53598 Mdot
.641 .75843 Mdot
.65112 .57171 Mdot
.5563 .33485 Mdot
.55793 .34122 Mdot
.32134 .52997 Mdot
.55498 .32788 Mdot
.47489 .57228 Mdot
.33516 .39699 Mdot
.64342 .39816 Mdot
.48709 .55341 Mdot
.4865 .61079 Mdot
.50621 .60529 Mdot
.51267 .57668 Mdot
.41446 .64359 Mdot
.31615 .48207 Mdot
.47549 .59734 Mdot
.57092 .32329 Mdot
.55296 .42973 Mdot
.46537 .5847 Mdot
.36649 .39527 Mdot
.50735 .56498 Mdot
.64895 .56143 Mdot
.66289 .58004 Mdot
.58274 .29817 Mdot
.37045 .37478 Mdot
.46406 .56171 Mdot
.67549 .49844 Mdot
.58036 .28442 Mdot
.66083 .48863 Mdot
.45216 .65053 Mdot
.53009 .31802 Mdot
.30283 .57024 Mdot
.44898 .66728 Mdot
.50569 .58943 Mdot
.45423 .68672 Mdot
.29513 .54356 Mdot
.32021 .38021 Mdot
.66871 .52457 Mdot
.44544 .64236 Mdot
.41743 .66423 Mdot
.60947 .45712 Mdot
.55761 .34344 Mdot
.48907 .53822 Mdot
.64669 .52108 Mdot
.64887 .57262 Mdot
.51429 .33003 Mdot
.28519 .26688 Mdot
.63021 .47701 Mdot
.67557 .59275 Mdot
.52812 .36148 Mdot
.49598 .55221 Mdot
.30576 .56618 Mdot
.6266 .46139 Mdot
.35709 .39113 Mdot
.34347 .3956 Mdot
.26706 .5151 Mdot
.51606 .33551 Mdot
.27987 .5802 Mdot
.64265 .45618 Mdot
.50916 .56801 Mdot
.67036 .48959 Mdot
.26488 .49105 Mdot
.33192 .24903 Mdot
.57129 .31278 Mdot
.25684 .54685 Mdot
.58448 .72885 Mdot
.32676 .34833 Mdot
.26243 .50715 Mdot
.53022 .35893 Mdot
.50937 .30891 Mdot
.51948 .33196 Mdot
.41875 .66638 Mdot
.29382 .57134 Mdot
.58655 .31371 Mdot
.58585 .31186 Mdot
.62068 .53873 Mdot
.67668 .50449 Mdot
.5667 .35059 Mdot
.33155 .49315 Mdot
.43977 .68568 Mdot
.28546 .58917 Mdot
.57176 .82149 Mdot
.35629 .36155 Mdot
.78384 .43373 Mdot
.65167 .55257 Mdot
.89756 .45045 Mdot
.6503 .54137 Mdot
.65389 .48531 Mdot
.5641 .30017 Mdot
.40984 .67006 Mdot
.43638 .66517 Mdot
.56952 .33647 Mdot
.56677 .30728 Mdot
.44893 .65217 Mdot
.58566 .66458 Mdot
.61869 .77195 Mdot
.56684 .72218 Mdot
.55432 .30629 Mdot
.62677 .40709 Mdot
.33561 .38293 Mdot
.49299 .34233 Mdot
.34139 .44002 Mdot
.27402 .51914 Mdot
.30209 .52466 Mdot
.316 .3722 Mdot
.63266 .47244 Mdot
.26294 .58848 Mdot
.62593 .55462 Mdot
.38773 .41127 Mdot
.6716 .5827 Mdot
.3991 .82176 Mdot
.66404 .53094 Mdot
.44984 .50233 Mdot
.4504 .27833 Mdot
.6075 .50737 Mdot
.793 .40838 Mdot
.44318 .69378 Mdot
.54944 .36503 Mdot
.37317 .38366 Mdot
.69008 .25746 Mdot
.65161 .51063 Mdot
.52052 .30319 Mdot
.32977 .35857 Mdot
.31457 .26209 Mdot
.67998 .59271 Mdot
.61356 .52524 Mdot
.62812 .17297 Mdot
.49066 .32019 Mdot
.30428 .56656 Mdot
.61539 .38898 Mdot
.57606 .31055 Mdot
.68451 .5923 Mdot
.28536 .5051 Mdot
.66197 .64787 Mdot
.53133 .30089 Mdot
.42084 .65022 Mdot
.54337 .32353 Mdot
.4523 .65869 Mdot
.58671 .31499 Mdot
.26039 .54303 Mdot
.62991 .49226 Mdot
.25925 .54678 Mdot
.4598 .67564 Mdot
.25433 .53939 Mdot
.37302 .37813 Mdot
.48814 .59669 Mdot
.3369 .39442 Mdot
.60344 .72804 Mdot
.69402 .34066 Mdot
.32489 .37444 Mdot
.73382 .56635 Mdot
.66848 .51279 Mdot
.58607 .31846 Mdot
.29996 .5742 Mdot
.30732 .58518 Mdot
.56921 .70627 Mdot
.537 .34206 Mdot
.26885 .56946 Mdot
.59425 .44686 Mdot
.27585 .31748 Mdot
.65403 .58182 Mdot
.16212 .50604 Mdot
.56425 .33071 Mdot
.30592 .58497 Mdot
.55117 .72076 Mdot
.51536 .29954 Mdot
.29827 .5194 Mdot
.3264 .36518 Mdot
.35667 .39112 Mdot
.66334 .53584 Mdot
.34637 .41144 Mdot
.31784 .54633 Mdot
.58685 .40318 Mdot
.56476 .34771 Mdot
.34181 .24311 Mdot
.42713 .6916 Mdot
.28978 .58277 Mdot
.50423 .58262 Mdot
.52081 .28684 Mdot
.27038 .53815 Mdot
.8767 .49767 Mdot
.5546 .8538 Mdot
.27141 .57123 Mdot
.53052 .31966 Mdot
.52154 .3259 Mdot
.61212 .48621 Mdot
.57391 .70793 Mdot
.28103 .57209 Mdot
.22863 .35411 Mdot
.63079 .68383 Mdot
.48575 .5945 Mdot
.20361 .64163 Mdot
.65767 .57251 Mdot
.63277 .55873 Mdot
.35402 .36303 Mdot
.63432 .48021 Mdot
.56379 .30664 Mdot
.64946 .54124 Mdot
.35397 .39927 Mdot
.26623 .51688 Mdot
.65263 .51495 Mdot
.43911 .69058 Mdot
.36131 .37424 Mdot
.36456 .38572 Mdot
.2696 .52632 Mdot
.51818 .33641 Mdot
.68843 .2521 Mdot
.29796 .57005 Mdot
.62192 .54723 Mdot
.48805 .58587 Mdot
.62449 .49048 Mdot
.49091 .35104 Mdot
.55875 .36213 Mdot
.29416 .58169 Mdot
.62487 .4528 Mdot
.34777 .37385 Mdot
.31836 .56511 Mdot
.65587 .57445 Mdot
.3035 .51843 Mdot
.51675 .5454 Mdot
.30063 .60711 Mdot
.53185 .28226 Mdot
.5171 .57332 Mdot
.50866 .30666 Mdot
.47715 .5964 Mdot
.40022 .76906 Mdot
.43723 .68791 Mdot
.25331 .56811 Mdot
.35618 .24058 Mdot
.25801 .5508 Mdot
.63387 .5017 Mdot
.66648 .51941 Mdot
.28909 .53746 Mdot
.42235 .68486 Mdot
.53804 .55188 Mdot
.43617 .64086 Mdot
.52454 .31821 Mdot
.71047 .59345 Mdot
.50745 .84959 Mdot
.3193 .57059 Mdot
.31358 .37212 Mdot
.50957 .24758 Mdot
.48827 .61053 Mdot
.3721 .37522 Mdot
.36545 .38111 Mdot
.45723 .685 Mdot
.2655 .57897 Mdot
.50013 .34064 Mdot
.3106 .37789 Mdot
.53766 .29773 Mdot
.50477 .76661 Mdot
.51117 .56671 Mdot
.52786 .50962 Mdot
.50257 .60092 Mdot
.56104 .70749 Mdot
.3086 .36432 Mdot
.66265 .50182 Mdot
.50666 .52683 Mdot
.33271 .36021 Mdot
.45203 .69896 Mdot
.67026 .58269 Mdot
.26729 .56668 Mdot
.66202 .2038 Mdot
.66851 .52984 Mdot
.63958 .51702 Mdot
.34287 .357 Mdot
.78843 .38632 Mdot
.53843 .35988 Mdot
.53799 .34632 Mdot
.29138 .55329 Mdot
.53011 .72286 Mdot
.63764 .5306 Mdot
.66967 .51755 Mdot
.2901 .53412 Mdot
.48243 .57758 Mdot
.22325 .67935 Mdot
.64636 .50433 Mdot
.34129 .38051 Mdot
.67503 .58554 Mdot
.37052 .36111 Mdot
.6773 .55259 Mdot
.63466 .49728 Mdot
.61363 .53124 Mdot
.64884 .57525 Mdot
.33537 .39265 Mdot
.50234 .59816 Mdot
.47586 .60999 Mdot
.56243 .31728 Mdot
.67576 .48208 Mdot
.63149 .68166 Mdot
.64943 .50591 Mdot
.4408 .69377 Mdot
.5403 .70189 Mdot
.66888 .55334 Mdot
.67977 .48962 Mdot
.63045 .68732 Mdot
.65038 .47304 Mdot
.34182 .35612 Mdot
.52462 .32972 Mdot
.34959 .37337 Mdot
.31471 .36585 Mdot
.2704 .53397 Mdot
.44351 .70348 Mdot
.63121 .46181 Mdot
.43637 .65121 Mdot
.61652 .49725 Mdot
.46259 .57988 Mdot
.58579 .69552 Mdot
.55367 .72533 Mdot
.46212 .65419 Mdot
.67013 .5124 Mdot
.29325 .5472 Mdot
.2723 .58688 Mdot
.69653 .59086 Mdot
.63502 .45179 Mdot
.35358 .41087 Mdot
.3216 .37393 Mdot
.30679 .47791 Mdot
.22981 .60312 Mdot
.44635 .64489 Mdot
.52986 .5502 Mdot
.65161 .57786 Mdot
.63061 .50899 Mdot
.49278 .60363 Mdot
.27372 .54389 Mdot
.47678 .59847 Mdot
.31675 .48536 Mdot
.37339 .3705 Mdot
.34926 .3665 Mdot
.66627 .5298 Mdot
.85103 .58394 Mdot
.54203 .30945 Mdot
.52087 .32631 Mdot
.35045 .40154 Mdot
.25163 .54805 Mdot
.4999 .57338 Mdot
.69387 .22786 Mdot
.56518 .35944 Mdot
.41411 .66517 Mdot
.66093 .47459 Mdot
.2696 .52044 Mdot
.56731 .31692 Mdot
.44167 .64271 Mdot
.68206 .48513 Mdot
.28112 .50436 Mdot
.65861 .50023 Mdot
.57106 .45918 Mdot
.57541 .33299 Mdot
.582 .68591 Mdot
.49659 .31516 Mdot
.3389 .3919 Mdot
.31101 .36662 Mdot
.63635 .5024 Mdot
.68761 .22395 Mdot
.506 .2721 Mdot
.30995 .38392 Mdot
.41458 .69003 Mdot
.49223 .59668 Mdot
.44649 .70208 Mdot
.28448 .54324 Mdot
.43808 .68888 Mdot
.26989 .53738 Mdot
.3058 .50635 Mdot
.50293 .33857 Mdot
.42676 .67538 Mdot
.76781 .4 Mdot
.50341 .56447 Mdot
.41153 .69186 Mdot
.67823 .52404 Mdot
.61259 .49935 Mdot
.27585 .56703 Mdot
.43131 .65229 Mdot
.62293 .46517 Mdot
.38728 .2519 Mdot
.31493 .35977 Mdot
.37335 .37929 Mdot
.49811 .57557 Mdot
.31507 .56417 Mdot
.50489 .33952 Mdot
.5875 .72926 Mdot
.4864 .3095 Mdot
.67039 .51774 Mdot
.6308 .46293 Mdot
.50792 .29253 Mdot
.50683 .3392 Mdot
.63618 .49613 Mdot
.75247 .44524 Mdot
.50485 .5841 Mdot
.353 .39484 Mdot
.5248 .31594 Mdot
.51787 .31418 Mdot
.31593 .54117 Mdot
.52914 .34467 Mdot
.51284 .51975 Mdot
.37311 .37135 Mdot
.47359 .6092 Mdot
.34681 .37651 Mdot
.48196 .64191 Mdot
.26811 .55946 Mdot
.33573 .25284 Mdot
.53828 .34727 Mdot
.61185 .51391 Mdot
.53908 .34905 Mdot
.43338 .69649 Mdot
.52772 .30315 Mdot
.49181 .3448 Mdot
.6741 .51421 Mdot
.501 .59852 Mdot
.48042 .56931 Mdot
.56673 .70941 Mdot
.54472 .31168 Mdot
.62902 .46819 Mdot
.63912 .53769 Mdot
.65206 .53258 Mdot
.58408 .70119 Mdot
.50264 .32969 Mdot
.77646 .36687 Mdot
.58812 .31259 Mdot
.57579 .32987 Mdot
.62026 .81613 Mdot
.48126 .5642 Mdot
.48311 .60524 Mdot
.39824 .34201 Mdot
.64449 .50544 Mdot
.27213 .57775 Mdot
.62228 .54658 Mdot
.49993 .59557 Mdot
.68122 .51778 Mdot
.43861 .65743 Mdot
.64176 .45968 Mdot
.48222 .58889 Mdot
.29683 .57447 Mdot
.6136 .52187 Mdot
.647 .51452 Mdot
.48293 .57291 Mdot
.54065 .35105 Mdot
.50691 .31688 Mdot
.49378 .29115 Mdot
.45604 .66275 Mdot
.33034 .37603 Mdot
.62598 .55046 Mdot
.29199 .55071 Mdot
.26877 .57619 Mdot
.49964 .31262 Mdot
.30421 .53789 Mdot
.34932 .36499 Mdot
.64833 .48553 Mdot
.33744 .39277 Mdot
.44337 .65676 Mdot
.53007 .31692 Mdot
.64251 .56598 Mdot
.60258 .48149 Mdot
.55813 .34118 Mdot
.50715 .5802 Mdot
.42422 .6971 Mdot
.29254 .52972 Mdot
.57567 .31874 Mdot
.34018 .39737 Mdot
.31219 .53531 Mdot
.61127 .51554 Mdot
.72352 .75412 Mdot
.63413 .48159 Mdot
.64575 .53414 Mdot
.528 .27373 Mdot
.67173 .56531 Mdot
.25832 .54271 Mdot
.51766 .34079 Mdot
.61222 .50444 Mdot
.62716 .70985 Mdot
.46475 .684 Mdot
.3028 .59622 Mdot
.65391 .47841 Mdot
.78481 .49247 Mdot
.62831 .53723 Mdot
.3714 .23288 Mdot
.58482 .69486 Mdot
.29237 .43132 Mdot
.51692 .51062 Mdot
.3134 .39061 Mdot
.48541 .58163 Mdot
.2672 .53447 Mdot
.74829 .42179 Mdot
.63665 .48735 Mdot
.6803 .31146 Mdot
.64174 .5634 Mdot
.34522 .36855 Mdot
.78347 .39246 Mdot
.3102 .56557 Mdot
.28365 .7362 Mdot
.66917 .47309 Mdot
.54731 .36078 Mdot
.35847 .52729 Mdot
.48963 .60217 Mdot
.49071 .60791 Mdot
.44932 .64768 Mdot
.25007 .51471 Mdot
.4752 .54676 Mdot
.3491 .3753 Mdot
.63018 .51352 Mdot
.61079 .44737 Mdot
.29565 .2692 Mdot
.5672 .32416 Mdot
.32039 .362 Mdot
.31417 .60088 Mdot
.6658 .50268 Mdot
.50854 .31025 Mdot
.54639 .33529 Mdot
.43217 .65583 Mdot
.29375 .42828 Mdot
.24756 .51484 Mdot
.83716 .56766 Mdot
.46382 .55076 Mdot
.27547 .54113 Mdot
.5157 .5762 Mdot
.61854 .54177 Mdot
.49836 .66372 Mdot
.31248 .37177 Mdot
.63497 .51056 Mdot
.68019 .29472 Mdot
.56156 .32727 Mdot
.65243 .49845 Mdot
.44285 .68369 Mdot
.70318 .24203 Mdot
.59458 .45417 Mdot
.75338 .45728 Mdot
.29862 .50822 Mdot
.6292 .46401 Mdot
.51093 .52057 Mdot
.4925 .55401 Mdot
.67264 .56526 Mdot
.30283 .56853 Mdot
.51625 .57854 Mdot
.44108 .67879 Mdot
.56244 .3131 Mdot
.48725 .5805 Mdot
.64256 .56398 Mdot
.63168 .45892 Mdot
.41646 .69252 Mdot
.61506 .53219 Mdot
.63037 .38373 Mdot
.50747 .55003 Mdot
.29932 .52552 Mdot
.57598 .3154 Mdot
.62615 .47093 Mdot
.49322 .59712 Mdot
.66985 .49088 Mdot
.56846 .23661 Mdot
.63349 .51056 Mdot
.34961 .26276 Mdot
.54678 .34444 Mdot
.35413 .38722 Mdot
.65479 .57544 Mdot
.65701 .50388 Mdot
.51685 .56495 Mdot
.49964 .57031 Mdot
.66947 .47724 Mdot
.50456 .30881 Mdot
.55425 .3102 Mdot
.5498 .36002 Mdot
.31194 .53009 Mdot
.57195 .71954 Mdot
.34492 .38977 Mdot
.49189 .60416 Mdot
.3107 .37833 Mdot
.77738 .51685 Mdot
.45575 .66981 Mdot
.31272 .26994 Mdot
.64386 .48652 Mdot
.5308 .33876 Mdot
.61057 .77332 Mdot
.49862 .31617 Mdot
.40067 .36507 Mdot
.31213 .37456 Mdot
.54019 .31526 Mdot
.64942 .47571 Mdot
.55551 .70903 Mdot
.78783 .4883 Mdot
.32046 .35163 Mdot
.47191 .60344 Mdot
.47619 .67668 Mdot
.29489 .51277 Mdot
.60867 .81943 Mdot
.32712 .39773 Mdot
.4518 .27531 Mdot
.612 .50885 Mdot
.54971 .34905 Mdot
.32998 .38716 Mdot
.36642 .38509 Mdot
.31106 .56684 Mdot
.6187 .53504 Mdot
.65573 .50231 Mdot
.47111 .58617 Mdot
.32144 .38647 Mdot
.62816 .45458 Mdot
.60671 .50908 Mdot
.24734 .50021 Mdot
.54695 .36248 Mdot
.28418 .26588 Mdot
.7479 .5703 Mdot
.6811 .29554 Mdot
.25128 .34504 Mdot
.58074 .33172 Mdot
.63759 .46611 Mdot
.50107 .58285 Mdot
.29756 .53013 Mdot
.64446 .47988 Mdot
.25681 .54992 Mdot
.33709 .36978 Mdot
.36835 .2594 Mdot
.7415 .57671 Mdot
.39355 .40464 Mdot
.63117 .49011 Mdot
.59117 .47021 Mdot
.4343 .6769 Mdot
.37394 .38421 Mdot
.52794 .35343 Mdot
.62533 .4814 Mdot
.31224 .55352 Mdot
.29467 .51505 Mdot
.56073 .32437 Mdot
.44903 .31851 Mdot
.34393 .24698 Mdot
.50623 .57615 Mdot
.30626 .54597 Mdot
.49639 .59513 Mdot
.75248 .46269 Mdot
.31041 .38136 Mdot
.44093 .67746 Mdot
.27535 .52279 Mdot
.35972 .40177 Mdot
.61238 .49809 Mdot
.55201 .31941 Mdot
.49461 .30156 Mdot
.69246 .59507 Mdot
.26901 .5705 Mdot
.45289 .67039 Mdot
.69043 .57988 Mdot
.70658 .59424 Mdot
.44912 .67256 Mdot
.31739 .53802 Mdot
.52407 .3081 Mdot
.5499 .33953 Mdot
.5278 .33166 Mdot
.78279 .43188 Mdot
.56201 .36162 Mdot
.48203 .74113 Mdot
.67134 .56855 Mdot
.61944 .40946 Mdot
.62002 .51567 Mdot
.37305 .38237 Mdot
.571 .33955 Mdot
.5851 .69383 Mdot
.64668 .57627 Mdot
.78998 .48913 Mdot
.64989 .52878 Mdot
.67499 .58893 Mdot
.64441 .50666 Mdot
.59186 .40474 Mdot
.56018 .36448 Mdot
.6751 .47614 Mdot
.35895 .35561 Mdot
.44896 .69386 Mdot
.56259 .30206 Mdot
.64559 .46586 Mdot
.52252 .38964 Mdot
.67696 .52861 Mdot
.36426 .25921 Mdot
.68744 .59172 Mdot
.37484 .55874 Mdot
.62626 .51446 Mdot
.24955 .54774 Mdot
.59918 .47604 Mdot
.64525 .40286 Mdot
.31362 .35801 Mdot
.59271 .45547 Mdot
.25521 .57756 Mdot
.78247 .39057 Mdot
.50558 .57213 Mdot
.43773 .68337 Mdot
.5094 .59762 Mdot
.34697 .39826 Mdot
.64037 .48665 Mdot
.64639 .46244 Mdot
.6818 .55558 Mdot
.75216 .46454 Mdot
.48948 .56049 Mdot
.46082 .65139 Mdot
.6363 .40851 Mdot
.66472 .47412 Mdot
.28527 .60415 Mdot
.50868 .32732 Mdot
.77205 .39303 Mdot
.76214 .38051 Mdot
.60618 .50324 Mdot
.54594 .31487 Mdot
.51646 .33578 Mdot
.54111 .82247 Mdot
.42864 .68217 Mdot
.63858 .51946 Mdot
.39785 .6711 Mdot
.62975 .55396 Mdot
.33713 .37499 Mdot
.66809 .56269 Mdot
.26807 .56119 Mdot
.54843 .71554 Mdot
.31466 .53224 Mdot
.65361 .53218 Mdot
.54168 .32439 Mdot
.33143 .34967 Mdot
.30839 .50757 Mdot
.29513 .42925 Mdot
.48143 .74454 Mdot
.25343 .51126 Mdot
.4439 .64495 Mdot
.4544 .69163 Mdot
.37382 .38399 Mdot
.65242 .48142 Mdot
.58117 .70382 Mdot
.76896 .55231 Mdot
.64377 .49938 Mdot
.63481 .4729 Mdot
.35408 .31971 Mdot
.31493 .38313 Mdot
.26665 .52447 Mdot
.63654 .49405 Mdot
.63881 .45819 Mdot
.53927 .32057 Mdot
.43067 .64981 Mdot
.28159 .52868 Mdot
.45555 .65612 Mdot
.30087 .55495 Mdot
.64185 .75848 Mdot
.5105 .56715 Mdot
.45617 .67829 Mdot
.32696 .39907 Mdot
.52202 .33195 Mdot
.47931 .5658 Mdot
.28154 .55227 Mdot
.30692 .54286 Mdot
.61582 .48834 Mdot
.56597 .31654 Mdot
.53868 .3467 Mdot
.4517 .65348 Mdot
.32262 .3748 Mdot
.63027 .5601 Mdot
.50072 .60284 Mdot
.32447 .57029 Mdot
.31125 .54395 Mdot
.63043 .40832 Mdot
.53315 .2787 Mdot
.66823 .49217 Mdot
.50802 .31528 Mdot
.65669 .51321 Mdot
.48299 .33774 Mdot
.49088 .31866 Mdot
.67606 .55149 Mdot
.71028 .45078 Mdot
.27236 .54313 Mdot
.46632 .84113 Mdot
.65691 .58364 Mdot
.36425 .34968 Mdot
.62104 .54421 Mdot
.24555 .70557 Mdot
.60491 .77466 Mdot
.6725 .48786 Mdot
.63652 .46325 Mdot
.83138 .61364 Mdot
.6338 .54099 Mdot
.47753 .59351 Mdot
.50554 .5704 Mdot
.50922 .31258 Mdot
.50572 .60387 Mdot
.56457 .70742 Mdot
.42255 .67648 Mdot
.29066 .55253 Mdot
.51606 .77323 Mdot
.45378 .66088 Mdot
.55949 .33285 Mdot
.62686 .55645 Mdot
.51663 .27652 Mdot
.26987 .59408 Mdot
.48942 .57429 Mdot
.34069 .36933 Mdot
.57416 .70357 Mdot
.31255 .55967 Mdot
.33185 .3963 Mdot
.63724 .54022 Mdot
.31726 .48956 Mdot
.36563 .35889 Mdot
.47895 .84029 Mdot
.36486 .37032 Mdot
.33794 .39862 Mdot
.57488 .71255 Mdot
.42239 .67627 Mdot
.51207 .55055 Mdot
.4651 .60614 Mdot
.33358 .35152 Mdot
.3281 .76085 Mdot
.3131 .56661 Mdot
.56527 .7359 Mdot
.55249 .36543 Mdot
.50505 .56212 Mdot
.63101 .4824 Mdot
.35435 .36239 Mdot
.62885 .45017 Mdot
.5173 .5684 Mdot
.35852 .37419 Mdot
.59964 .47654 Mdot
.53179 .72018 Mdot
.49486 .59284 Mdot
.47803 .57162 Mdot
.43145 .64646 Mdot
.35457 .58614 Mdot
.52622 .33973 Mdot
.41255 .67187 Mdot
.6098 .70717 Mdot
.6458 .53021 Mdot
.33453 .3917 Mdot
.48772 .57959 Mdot
.34803 .39221 Mdot
.43617 .67001 Mdot
.41701 .69475 Mdot
.56387 .31858 Mdot
.54641 .3599 Mdot
.47882 .55948 Mdot
.63711 .67978 Mdot
.6533 .56274 Mdot
.68363 .3264 Mdot
.50033 .33421 Mdot
.79691 .41927 Mdot
.41944 .67038 Mdot
.42798 .65245 Mdot
.59592 .47219 Mdot
.66375 .54954 Mdot
.67424 .58783 Mdot
.67016 .55092 Mdot
.31231 .74174 Mdot
.64412 .56686 Mdot
.29565 .53243 Mdot
.67832 .53418 Mdot
.4793 .25586 Mdot
.61061 .47979 Mdot
.65441 .4703 Mdot
.2919 .56633 Mdot
.61947 .48755 Mdot
.27247 .56585 Mdot
.62816 .48613 Mdot
.20751 .55298 Mdot
.29214 .55124 Mdot
.52881 .58708 Mdot
.70071 .53365 Mdot
.47636 .58605 Mdot
.42856 .66225 Mdot
.45028 .64546 Mdot
.50603 .76116 Mdot
.53073 .30876 Mdot
.71319 .28152 Mdot
.65774 .4734 Mdot
.31454 .56208 Mdot
.33431 .36911 Mdot
.6047 .48477 Mdot
.65214 .53726 Mdot
.65827 .58257 Mdot
.55184 .31377 Mdot
.3182 .55762 Mdot
.43038 .66802 Mdot
.26113 .5739 Mdot
.2054 .55718 Mdot
.2689 .55618 Mdot
.75342 .5069 Mdot
.61327 .49561 Mdot
.5122 .52059 Mdot
.71093 .36796 Mdot
.41423 .70831 Mdot
.55728 .32126 Mdot
.48581 .58443 Mdot
.45167 .69687 Mdot
.5409 .68377 Mdot
.51697 .33248 Mdot
.29078 .53469 Mdot
.65905 .50055 Mdot
.51345 .57596 Mdot
.46457 .60349 Mdot
.55821 .30301 Mdot
.42783 .70191 Mdot
.28565 .55706 Mdot
.48924 .5926 Mdot
.56962 .72294 Mdot
.75499 .34229 Mdot
.59741 .73375 Mdot
.65753 .50763 Mdot
.44979 .65294 Mdot
.56605 .31604 Mdot
.67075 .58878 Mdot
.33623 .36008 Mdot
.57168 .7078 Mdot
.63216 .48405 Mdot
.40729 .37748 Mdot
.54325 .32524 Mdot
.42472 .68778 Mdot
.35895 .36487 Mdot
.42972 .68438 Mdot
.48243 .60388 Mdot
.57647 .30247 Mdot
.49053 .60779 Mdot
.65148 .57176 Mdot
.33359 .37158 Mdot
.53036 .34208 Mdot
.20931 .54794 Mdot
.49961 .53933 Mdot
.28852 .53841 Mdot
.54471 .68362 Mdot
.55796 .31148 Mdot
.32277 .46216 Mdot
.26019 .5721 Mdot
.30885 .33221 Mdot
.56897 .67699 Mdot
.35533 .36767 Mdot
.65106 .46823 Mdot
.53054 .32904 Mdot
.3207 .35123 Mdot
.34457 .51765 Mdot
.79002 .47216 Mdot
.49578 .54603 Mdot
.66813 .5152 Mdot
.38196 .22547 Mdot
.45823 .27412 Mdot
.55911 .37218 Mdot
.34023 .40183 Mdot
.64084 .51453 Mdot
.50709 .57597 Mdot
.67318 .47626 Mdot
.32638 .35245 Mdot
.29826 .38366 Mdot
.28217 .58908 Mdot
.66196 .49998 Mdot
.43513 .69191 Mdot
.26381 .5519 Mdot
.2867 .50941 Mdot
.27789 .52129 Mdot
.53086 .35475 Mdot
.50356 .5579 Mdot
.50673 .57048 Mdot
.59236 .77648 Mdot
.35064 .39301 Mdot
.4766 .58626 Mdot
.64225 .46046 Mdot
.48364 .74165 Mdot
.53412 .3379 Mdot
.28357 .5616 Mdot
.64036 .51831 Mdot
.6905 .59635 Mdot
.4864 .57012 Mdot
.29558 .57053 Mdot
.50517 .33853 Mdot
.56073 .43847 Mdot
.64454 .48154 Mdot
.62999 .5511 Mdot
.56224 .33616 Mdot
.52641 .21068 Mdot
.56537 .72714 Mdot
.65517 .5129 Mdot
.34491 .39605 Mdot
.48469 .20197 Mdot
.6337 .53708 Mdot
.4839 .30103 Mdot
.47011 .59159 Mdot
.55521 .41928 Mdot
.62853 .39163 Mdot
.62878 .43802 Mdot
.4562 .46327 Mdot
.59593 .60369 Mdot
.47873 .47841 Mdot
.34923 .75146 Mdot
.40485 .47946 Mdot
.50063 .84496 Mdot
.37156 .40324 Mdot
.57618 .45156 Mdot
.87055 .4992 Mdot
.44286 .29899 Mdot
.37746 .50221 Mdot
.29263 .37573 Mdot
.43673 .72442 Mdot
.21374 .66461 Mdot
.31448 .48518 Mdot
.35215 .7495 Mdot
.65379 .57037 Mdot
.50373 .22437 Mdot
.57776 .45905 Mdot
.34027 .47709 Mdot
.29876 .44199 Mdot
.68921 .58842 Mdot
.80031 .63762 Mdot
.39341 .39052 Mdot
.69099 .76122 Mdot
.69359 .28824 Mdot
.33399 .53949 Mdot
.63113 .65461 Mdot
.49456 .78075 Mdot
.58483 .48348 Mdot
.51401 .44837 Mdot
.37539 .40253 Mdot
.58055 .27383 Mdot
.25686 .32903 Mdot
.29811 .53994 Mdot
.54825 .3015 Mdot
.39577 .32817 Mdot
.76169 .69728 Mdot
.37578 .3444 Mdot
.45453 .46458 Mdot
.49493 .54116 Mdot
.58589 .41835 Mdot
.58721 .69057 Mdot
.59085 .39994 Mdot
.2864 .48465 Mdot
.21718 .66601 Mdot
.53863 .27155 Mdot
.35636 .54127 Mdot
.52835 .68336 Mdot
.37114 .50255 Mdot
.60744 .38097 Mdot
.43477 .71685 Mdot
.52617 .5914 Mdot
.4998 .33484 Mdot
.79246 .61066 Mdot
.73357 .54475 Mdot
.61457 .70283 Mdot
.32211 .48437 Mdot
.54125 .24778 Mdot
.69001 .24734 Mdot
.45265 .31113 Mdot
.42092 .83183 Mdot
.72461 .74889 Mdot
.3868 .78122 Mdot
.69881 .51689 Mdot
.38325 .34554 Mdot
.50181 .6749 Mdot
.44378 .50808 Mdot
.40703 .79912 Mdot
.56582 .23534 Mdot
.81714 .59102 Mdot
.49813 .38995 Mdot
.76759 .70716 Mdot
.5642 .28584 Mdot
.49556 .53054 Mdot
.5772 .37826 Mdot
.56803 .44654 Mdot
.58144 .76092 Mdot
.78321 .67696 Mdot
.35333 .48985 Mdot
.49565 .53678 Mdot
.43857 .30944 Mdot
.62747 .38519 Mdot
.28503 .48308 Mdot
.51094 .60437 Mdot
.73161 .36997 Mdot
.80276 .65166 Mdot
.46888 .45432 Mdot
.76447 .66342 Mdot
.24062 .50726 Mdot
.16686 .46409 Mdot
.28029 .50874 Mdot
.31856 .39986 Mdot
.70871 .75227 Mdot
.53678 .33208 Mdot
.45167 .84688 Mdot
.40579 .4936 Mdot
.40088 .53292 Mdot
.80483 .64475 Mdot
.39648 .81423 Mdot
.59692 .42993 Mdot
.53156 .55578 Mdot
.2771 .31854 Mdot
.50559 .48001 Mdot
.36468 .43888 Mdot
.49235 .63776 Mdot
.36916 .24621 Mdot
.72669 .73462 Mdot
.37935 .79479 Mdot
.83897 .55523 Mdot
.61523 .69358 Mdot
.42799 .74169 Mdot
.52928 .27009 Mdot
.42718 .42356 Mdot
.35399 .45023 Mdot
.75638 .72143 Mdot
.59704 .44799 Mdot
.45305 .19821 Mdot
.36401 .75956 Mdot
.7686 .37956 Mdot
.41695 .23348 Mdot
.42063 .34536 Mdot
.55817 .46129 Mdot
.51562 .38569 Mdot
.45733 .62721 Mdot
.56657 .76509 Mdot
.71953 .34869 Mdot
.37125 .549 Mdot
.55911 .71956 Mdot
.44058 .34269 Mdot
.44484 .79436 Mdot
.45901 .2172 Mdot
.72992 .36212 Mdot
.50739 .29408 Mdot
.40798 .79809 Mdot
.36763 .76779 Mdot
.43462 .21018 Mdot
.32191 .59399 Mdot
.76007 .67256 Mdot
.40608 .40534 Mdot
.64078 .43048 Mdot
.57422 .46062 Mdot
.58406 .47548 Mdot
.24366 .69015 Mdot
.74104 .4845 Mdot
.53724 .81582 Mdot
.36138 .43142 Mdot
.71346 .38308 Mdot
.52288 .79778 Mdot
.71654 .37759 Mdot
.64175 .3974 Mdot
.46781 .31506 Mdot
.38164 .40662 Mdot
.70817 .45835 Mdot
.80383 .63751 Mdot
.26401 .53229 Mdot
.40504 .80093 Mdot
.38394 .35599 Mdot
.32721 .5083 Mdot
.39051 .53155 Mdot
.38338 .5313 Mdot
.65581 .78906 Mdot
.43208 .31342 Mdot
.45242 .7164 Mdot
.58807 .38238 Mdot
.42408 .49862 Mdot
.69057 .33166 Mdot
.75427 .55387 Mdot
.54763 .24234 Mdot
.42371 .69702 Mdot
.73771 .40739 Mdot
.54311 .3952 Mdot
.321 .59824 Mdot
.75878 .51533 Mdot
.64642 .6474 Mdot
.47078 .57608 Mdot
.512 .74078 Mdot
.63655 .76265 Mdot
.65601 .43252 Mdot
.40765 .81451 Mdot
.44407 .3142 Mdot
.5132 .74679 Mdot
.35084 .45238 Mdot
.71911 .28663 Mdot
.77072 .70401 Mdot
.59919 .817 Mdot
.52729 .21593 Mdot
.40724 .22903 Mdot
.15962 .54202 Mdot
.30751 .44043 Mdot
.488 .82894 Mdot
.38396 .3558 Mdot
.5913 .14612 Mdot
.25801 .53875 Mdot
.49187 .67979 Mdot
.57684 .289 Mdot
.64047 .64329 Mdot
.78202 .66524 Mdot
.59906 .41604 Mdot
.41051 .68935 Mdot
.57484 .37399 Mdot
.71141 .45335 Mdot
.7958 .63399 Mdot
.80488 .60658 Mdot
.79637 .61621 Mdot
.40506 .34012 Mdot
.74308 .44602 Mdot
.81973 .62468 Mdot
.4864 .72073 Mdot
.71502 .48459 Mdot
.6159 .44506 Mdot
.63641 .69971 Mdot
.46783 .82531 Mdot
.40859 .71475 Mdot
.51063 .47869 Mdot
.53865 .2723 Mdot
.81289 .64462 Mdot
.62502 .77304 Mdot
.58037 .42272 Mdot
.66289 .7787 Mdot
.40582 .73515 Mdot
.54033 .79977 Mdot
.63226 .79813 Mdot
.49014 .44996 Mdot
.41729 .3588 Mdot
.82186 .64135 Mdot
.39185 .76944 Mdot
.29263 .37083 Mdot
.52836 .39134 Mdot
.46383 .83125 Mdot
.407 .2373 Mdot
.31337 .31876 Mdot
.56781 .28355 Mdot
.74079 .30284 Mdot
.37492 .47216 Mdot
.51899 .44963 Mdot
.68998 .54264 Mdot
.51671 .80318 Mdot
.25572 .5375 Mdot
.43173 .80409 Mdot
.37 .45291 Mdot
.70588 .46936 Mdot
.52608 .7615 Mdot
.35836 .77846 Mdot
.5051 .41291 Mdot
.76243 .46619 Mdot
.44197 .31839 Mdot
.47403 .21094 Mdot
.43017 .22511 Mdot
.71761 .31692 Mdot
.62163 .48176 Mdot
.76774 .69098 Mdot
.52986 .84978 Mdot
.63779 .79902 Mdot
.44642 .21094 Mdot
.16918 .50138 Mdot
.35796 .40746 Mdot
.48976 .7267 Mdot
.64946 .63446 Mdot
.47278 .42653 Mdot
.60906 .6045 Mdot
.30754 .35499 Mdot
.68986 .24596 Mdot
.39287 .52591 Mdot
.48783 .72019 Mdot
.58704 .26802 Mdot
.41645 .5145 Mdot
.75754 .46741 Mdot
.50423 .2972 Mdot
.4164 .20464 Mdot
.41084 .79946 Mdot
.26694 .5294 Mdot
.31449 .59228 Mdot
.73382 .48845 Mdot
.51085 .52719 Mdot
.47214 .69541 Mdot
.66023 .44033 Mdot
.68378 .29709 Mdot
.17245 .51598 Mdot
.58138 .80874 Mdot
.46395 .83929 Mdot
.62861 .80004 Mdot
.37978 .77943 Mdot
.34044 .517 Mdot
.52258 .74263 Mdot
.33831 .32916 Mdot
.38881 .36938 Mdot
.5237 .72363 Mdot
.3624 .7744 Mdot
.60193 .42293 Mdot
.57083 .37901 Mdot
.61813 .46383 Mdot
.61549 .77079 Mdot
.48324 .77335 Mdot
.51197 .72293 Mdot
.73599 .32654 Mdot
.49971 .3445 Mdot
.45324 .73603 Mdot
.53809 .44106 Mdot
.60628 .52703 Mdot
.41077 .22434 Mdot
.31609 .35249 Mdot
.49749 .30431 Mdot
.35783 .77927 Mdot
.16522 .53247 Mdot
.45418 .49133 Mdot
.73529 .56092 Mdot
.73301 .72416 Mdot
.70509 .54373 Mdot
.39122 .24003 Mdot
.75797 .31468 Mdot
.31452 .4572 Mdot
.54777 .27371 Mdot
.69992 .46991 Mdot
.39063 .54299 Mdot
.52744 .22374 Mdot
.53023 .29177 Mdot
.59143 .47881 Mdot
.7054 .76069 Mdot
.688 .57421 Mdot
.50308 .4571 Mdot
.58572 .73059 Mdot
.40795 .441 Mdot
.41419 .49429 Mdot
.52345 .76666 Mdot
.46821 .47421 Mdot
.783 .62256 Mdot
.68324 .23718 Mdot
.52299 .47752 Mdot
.4715 .72595 Mdot
.49121 .71637 Mdot
.69309 .28751 Mdot
.60718 .37768 Mdot
.35391 .43751 Mdot
.65828 .57028 Mdot
.69237 .77558 Mdot
.47379 .37159 Mdot
.5204 .75513 Mdot
.42333 .38093 Mdot
.62645 .53936 Mdot
.48449 .53573 Mdot
.64039 .79488 Mdot
.55024 .42124 Mdot
.8825 .47703 Mdot
.33863 .75252 Mdot
.51721 .24001 Mdot
.62455 .39597 Mdot
.42021 .8146 Mdot
.49093 .2536 Mdot
.41673 .47863 Mdot
.37946 .44482 Mdot
.45061 .82407 Mdot
.54119 .41606 Mdot
.54641 .42712 Mdot
.40233 .21606 Mdot
.81993 .61471 Mdot
.50382 .47267 Mdot
.32697 .31723 Mdot
.4179 .73515 Mdot
.64248 .53286 Mdot
.44862 .31452 Mdot
.32166 .25992 Mdot
.43326 .38647 Mdot
.48324 .48374 Mdot
.52438 .85324 Mdot
.6366 .42577 Mdot
.43858 .32362 Mdot
.88133 .48164 Mdot
.89171 .4641 Mdot
.46335 .29132 Mdot
.74592 .73334 Mdot
.55492 .42511 Mdot
.39134 .24267 Mdot
.38491 .39243 Mdot
.71151 .58741 Mdot
.68159 .31751 Mdot
.65731 .79779 Mdot
.15703 .51309 Mdot
.35872 .44281 Mdot
.56688 .27051 Mdot
.65279 .80231 Mdot
.64928 .42534 Mdot
.47599 .71352 Mdot
.16819 .4637 Mdot
.29194 .74209 Mdot
.42062 .82857 Mdot
.73994 .32124 Mdot
.24389 .69439 Mdot
.31291 .72712 Mdot
.35554 .482 Mdot
.47018 .83594 Mdot
.45733 .57361 Mdot
.72932 .28976 Mdot
.40612 .79676 Mdot
.389 .23013 Mdot
.20024 .60801 Mdot
.41951 .49089 Mdot
.6724 .44682 Mdot
.46784 .32353 Mdot
.36565 .24994 Mdot
.42026 .33591 Mdot
.71634 .51334 Mdot
.54585 .68892 Mdot
.64062 .39985 Mdot
.48332 .19879 Mdot
.77339 .32533 Mdot
.67029 .44909 Mdot
.80767 .5829 Mdot
.38785 .40768 Mdot
.51792 .69854 Mdot
.61186 .38826 Mdot
.49258 .7602 Mdot
.45315 .71898 Mdot
.67735 .53341 Mdot
.71219 .75466 Mdot
.45562 .71652 Mdot
.80301 .59527 Mdot
.4506 .84971 Mdot
.67626 .7675 Mdot
.405 .54031 Mdot
.47762 .66569 Mdot
.46528 .82091 Mdot
.47193 .82025 Mdot
.8197 .5724 Mdot
.35638 .74749 Mdot
.52567 .71796 Mdot
.70706 .50151 Mdot
.74021 .57229 Mdot
.75349 .48067 Mdot
.42427 .81606 Mdot
.69234 .2764 Mdot
.52397 .79442 Mdot
.52661 .21813 Mdot
.3616 .77703 Mdot
.59413 .43232 Mdot
.49714 .75919 Mdot
.42017 .4038 Mdot
.52976 .56813 Mdot
.31197 .57153 Mdot
.84477 .58482 Mdot
.42672 .21443 Mdot
.56238 .80378 Mdot
.44572 .20031 Mdot
.51622 .3883 Mdot
.32704 .74098 Mdot
.58155 .37493 Mdot
.48419 .50469 Mdot
.34054 .54126 Mdot
.46936 .79454 Mdot
.60657 .42648 Mdot
.37176 .23195 Mdot
.75681 .36348 Mdot
.66326 .78743 Mdot
.52536 .79943 Mdot
.84754 .5382 Mdot
.43914 .73532 Mdot
.73636 .40485 Mdot
.79096 .60772 Mdot
.50154 .21059 Mdot
.50983 .71482 Mdot
.80415 .62856 Mdot
.56967 .36512 Mdot
.72997 .74415 Mdot
.33526 .3629 Mdot
.464 .72306 Mdot
.34752 .24795 Mdot
.50035 .72049 Mdot
.50138 .7161 Mdot
.56619 .81085 Mdot
.43732 .3138 Mdot
.4519 .29832 Mdot
.40482 .40652 Mdot
.31261 .48687 Mdot
.72921 .57887 Mdot
.48851 .45981 Mdot
.83683 .55926 Mdot
.62248 .48106 Mdot
.37932 .74065 Mdot
.40579 .8066 Mdot
.33791 .32799 Mdot
.69505 .48284 Mdot
.36423 .2403 Mdot
.75987 .3297 Mdot
.57999 .77317 Mdot
.81618 .62134 Mdot
.6965 .48726 Mdot
.63914 .63253 Mdot
.79177 .39299 Mdot
.31939 .31063 Mdot
.35409 .44094 Mdot
.46207 .46437 Mdot
.71351 .54278 Mdot
.56887 .72726 Mdot
.38462 .77725 Mdot
.51266 .85013 Mdot
.81251 .57706 Mdot
.3475 .44415 Mdot
.50557 .72423 Mdot
.48363 .2976 Mdot
.48352 .79027 Mdot
.84661 .54676 Mdot
.22809 .68539 Mdot
.52619 .39033 Mdot
.37061 .78258 Mdot
.42261 .35064 Mdot
.47667 .71464 Mdot
.51715 .72312 Mdot
.79036 .61458 Mdot
.58914 .29852 Mdot
.56873 .40828 Mdot
.43733 .35823 Mdot
.56552 .70141 Mdot
.39025 .50617 Mdot
.73182 .3019 Mdot
.43092 .30827 Mdot
.84796 .53676 Mdot
.29524 .72087 Mdot
.77633 .38863 Mdot
.86398 .51018 Mdot
.50684 .34124 Mdot
.38587 .50751 Mdot
.17785 .43518 Mdot
.50872 .74227 Mdot
.28412 .51443 Mdot
.62681 .45515 Mdot
.53506 .70246 Mdot
.50762 .23287 Mdot
.42294 .72972 Mdot
.43529 .70592 Mdot
.50223 .30188 Mdot
.32698 .7359 Mdot
.4972 .30253 Mdot
.51222 .84764 Mdot
.4888 .44587 Mdot
.63305 .40281 Mdot
.78448 .34773 Mdot
.34624 .52871 Mdot
.48359 .21 Mdot
.68547 .76499 Mdot
.63089 .70059 Mdot
.53716 .29486 Mdot
.55294 .29419 Mdot
.59661 .32222 Mdot
.31048 .3404 Mdot
.74756 .70823 Mdot
.39755 .81208 Mdot
.3234 .57614 Mdot
.58561 .35009 Mdot
.69956 .5267 Mdot
.65667 .43742 Mdot
.59665 .79915 Mdot
.26204 .57256 Mdot
.78572 .68779 Mdot
.70525 .2758 Mdot
.49434 .22272 Mdot
.47845 .4171 Mdot
.65784 .64812 Mdot
.51234 .68712 Mdot
.3609 .54539 Mdot
.63437 .43182 Mdot
.48945 .26181 Mdot
.56014 .35668 Mdot
.38916 .51778 Mdot
.41583 .67616 Mdot
.32658 .5923 Mdot
.34181 .33923 Mdot
.7097 .31269 Mdot
.41882 .81931 Mdot
.51451 .28716 Mdot
.47101 .70351 Mdot
.36241 .56699 Mdot
.7516 .49586 Mdot
.65185 .67549 Mdot
.83965 .60605 Mdot
.71025 .74239 Mdot
.50175 .30965 Mdot
.46851 .21622 Mdot
.21403 .54132 Mdot
.58028 .80794 Mdot
.54352 .40665 Mdot
.42038 .80995 Mdot
.73368 .37997 Mdot
.62158 .79687 Mdot
.62693 .3923 Mdot
.4625 .44918 Mdot
.39029 .79511 Mdot
.39485 .67254 Mdot
.36776 .78551 Mdot
.76692 .34299 Mdot
.72241 .55977 Mdot
.30812 .75136 Mdot
.43329 .37734 Mdot
.58007 .42644 Mdot
.6229 .55621 Mdot
.47196 .43084 Mdot
.45147 .82057 Mdot
.52025 .34375 Mdot
.42841 .72408 Mdot
.58662 .25921 Mdot
.3598 .44136 Mdot
.72262 .73758 Mdot
.44431 .21559 Mdot
.39188 .80605 Mdot
.74063 .56768 Mdot
.44457 .77459 Mdot
.68929 .27883 Mdot
.62162 .69523 Mdot
.5053 .59922 Mdot
.72259 .36047 Mdot
.51787 .5586 Mdot
.59872 .7774 Mdot
.75742 .48858 Mdot
.78192 .67227 Mdot
.62864 .76599 Mdot
.46726 .32542 Mdot
.51723 .53684 Mdot
.58599 .32175 Mdot
.79229 .67247 Mdot
.58698 .77064 Mdot
.36086 .24872 Mdot
.42028 .82731 Mdot
.35787 .74387 Mdot
.86779 .50326 Mdot
.43225 .32466 Mdot
.70061 .45693 Mdot
.47529 .83761 Mdot
.48869 .38154 Mdot
.31694 .72822 Mdot
.60719 .42646 Mdot
.52136 .27284 Mdot
.80602 .63819 Mdot
.45838 .54913 Mdot
.45969 .32639 Mdot
.78362 .50103 Mdot
.54757 .27169 Mdot
.59186 .76542 Mdot
.68674 .47504 Mdot
.29081 .53251 Mdot
.6485 .64266 Mdot
.23522 .68202 Mdot
.59697 .314 Mdot
.41446 .8128 Mdot
.42597 .80937 Mdot
.43007 .7493 Mdot
.36765 .58063 Mdot
.86765 .50142 Mdot
.7353 .43552 Mdot
.67413 .46383 Mdot
.5126 .29459 Mdot
.4442 .70571 Mdot
.37488 .75955 Mdot
.62845 .54327 Mdot
.64144 .66219 Mdot
.7323 .37334 Mdot
.67534 .78646 Mdot
.42227 .41911 Mdot
.36196 .41949 Mdot
.5788 .36018 Mdot
.36538 .24781 Mdot
.5449 .2231 Mdot
.44769 .28573 Mdot
.45027 .81817 Mdot
.45539 .49066 Mdot
.45783 .45925 Mdot
.4749 .35005 Mdot
.4269 .79443 Mdot
.34431 .46535 Mdot
.35558 .35098 Mdot
.68362 .30337 Mdot
.82786 .55993 Mdot
.49813 .3759 Mdot
.42814 .48851 Mdot
.51555 .43359 Mdot
.71482 .55512 Mdot
.36133 .44255 Mdot
.44058 .31563 Mdot
.54659 .28785 Mdot
.78061 .63857 Mdot
.51998 .46171 Mdot
.47724 .67352 Mdot
.35543 .76274 Mdot
.50305 .43901 Mdot
.4284 .81375 Mdot
.70986 .45021 Mdot
.79392 .6218 Mdot
.51775 .75495 Mdot
.39957 .72251 Mdot
.6143 .46698 Mdot
.5688 .24306 Mdot
.63916 .79586 Mdot
.53384 .40465 Mdot
.46772 .4957 Mdot
.59085 .36977 Mdot
.44368 .84342 Mdot
.49947 .62103 Mdot
.17279 .5126 Mdot
.52985 .55775 Mdot
.64625 .65322 Mdot
.64112 .63907 Mdot
.31597 .33458 Mdot
.6353 .42841 Mdot
.36378 .48674 Mdot
.71956 .54381 Mdot
.68802 .30315 Mdot
.52262 .81879 Mdot
.84241 .58138 Mdot
.53802 .24701 Mdot
.41217 .83071 Mdot
.5626 .25297 Mdot
.52267 .26232 Mdot
.29844 .72135 Mdot
.46719 .49984 Mdot
.73811 .4799 Mdot
.41313 .72591 Mdot
.50919 .34443 Mdot
.83888 .57614 Mdot
.4775 .48504 Mdot
.42247 .72263 Mdot
.26265 .49361 Mdot
.41211 .49904 Mdot
.24795 .33403 Mdot
.38656 .37132 Mdot
.45479 .8452 Mdot
.40731 .79947 Mdot
.37871 .40981 Mdot
.55403 .42454 Mdot
.47879 .49152 Mdot
.79404 .6344 Mdot
.52453 .54741 Mdot
.70201 .7539 Mdot
.40745 .34204 Mdot
.7074 .32167 Mdot
.62702 .76413 Mdot
.57011 .76594 Mdot
.62088 .7012 Mdot
.73307 .34713 Mdot
.75312 .67245 Mdot
.48643 .5555 Mdot
.32334 .58934 Mdot
.20132 .61777 Mdot
.84139 .5552 Mdot
.50114 .21849 Mdot
.47929 .54583 Mdot
.49254 .78965 Mdot
.51958 .459 Mdot
.52049 .69472 Mdot
.38992 .42648 Mdot
.47331 .69307 Mdot
.37575 .32229 Mdot
.46988 .20201 Mdot
.69184 .77508 Mdot
.61171 .45797 Mdot
.59709 .59623 Mdot
.34355 .47999 Mdot
.26494 .52031 Mdot
.60368 .30395 Mdot
.83844 .60372 Mdot
.34385 .34836 Mdot
.18327 .42427 Mdot
.32615 .33229 Mdot
.57361 .8046 Mdot
.16426 .51127 Mdot
.30182 .34647 Mdot
.50832 .84959 Mdot
.50222 .2306 Mdot
.76344 .35376 Mdot
.45196 .19629 Mdot
.60539 .77669 Mdot
.71934 .35674 Mdot
.49657 .63524 Mdot
.74276 .7273 Mdot
.51136 .69475 Mdot
.44025 .72602 Mdot
.76388 .65817 Mdot
.38427 .79233 Mdot
.34481 .75651 Mdot
.29363 .41068 Mdot
.56166 .26944 Mdot
.16578 .54057 Mdot
.33196 .52232 Mdot
.69552 .22866 Mdot
.71116 .74007 Mdot
.79653 .46864 Mdot
.53803 .40464 Mdot
.41209 .39635 Mdot
.79173 .64342 Mdot
.43989 .81036 Mdot
.57026 .43045 Mdot
.30017 .60644 Mdot
.5526 .76893 Mdot
.47872 .78449 Mdot
.42031 .36786 Mdot
.64224 .78584 Mdot
.35891 .54515 Mdot
.47513 .53567 Mdot
.39644 .80219 Mdot
.57336 .24706 Mdot
.61924 .68712 Mdot
.82636 .56284 Mdot
.64562 .68657 Mdot
.34556 .76696 Mdot
.40502 .33944 Mdot
.2048 .56243 Mdot
.83338 .56501 Mdot
.53319 .22995 Mdot
.74868 .38922 Mdot
.88059 .47921 Mdot
.76672 .70782 Mdot
.48151 .49164 Mdot
.66375 .57019 Mdot
.49491 .84487 Mdot
.27534 .59797 Mdot
.54913 .80801 Mdot
.69104 .24813 Mdot
.3257 .74555 Mdot
.76429 .50154 Mdot
.65632 .56754 Mdot
.4886 .70971 Mdot
.49118 .35567 Mdot
.56629 .2795 Mdot
.31814 .5002 Mdot
.36255 .77358 Mdot
.71003 .3084 Mdot
.68315 .23737 Mdot
.76171 .33657 Mdot
.51754 .30108 Mdot
.72435 .74401 Mdot
.49028 .51287 Mdot
.69628 .28356 Mdot
.79073 .63189 Mdot
.63022 .61322 Mdot
.35896 .47418 Mdot
.6836 .28025 Mdot
.51901 .74102 Mdot
.23051 .67588 Mdot
.86485 .51604 Mdot
.69071 .31993 Mdot
.79164 .67999 Mdot
.60038 .81838 Mdot
.53566 .29987 Mdot
.59525 .30207 Mdot
.50894 .68244 Mdot
.49224 .47329 Mdot
.3301 .30984 Mdot
.32873 .51112 Mdot
.3439 .73866 Mdot
.33465 .5953 Mdot
.67531 .48949 Mdot
.42679 .36247 Mdot
.66896 .7824 Mdot
.47198 .71713 Mdot
.68155 .77473 Mdot
.72075 .33276 Mdot
.62163 .47561 Mdot
.89009 .46052 Mdot
.38847 .24331 Mdot
.75811 .542 Mdot
.46983 .61284 Mdot
.48253 .5436 Mdot
.68207 .5136 Mdot
.29658 .38305 Mdot
.48869 .74223 Mdot
.30192 .73567 Mdot
.74511 .72276 Mdot
.58301 .35249 Mdot
.51069 .69022 Mdot
.38106 .37761 Mdot
.57502 .67738 Mdot
.766 .4948 Mdot
.33789 .34645 Mdot
.27231 .71461 Mdot
.24676 .33918 Mdot
.34943 .45646 Mdot
.39211 .50363 Mdot
.54557 .69349 Mdot
.48506 .54761 Mdot
.28699 .71916 Mdot
.31848 .3302 Mdot
.34777 .47575 Mdot
.38882 .80385 Mdot
.74022 .35762 Mdot
.41643 .36679 Mdot
.20217 .59283 Mdot
.5119 .71648 Mdot
.42934 .36483 Mdot
.50581 .48358 Mdot
.74714 .30786 Mdot
.77205 .66259 Mdot
.26169 .50016 Mdot
.4852 .55545 Mdot
.79467 .39922 Mdot
.77922 .67066 Mdot
.35175 .40117 Mdot
.52544 .84628 Mdot
.48337 .49687 Mdot
.60224 .29733 Mdot
.79624 .48633 Mdot
.69462 .47516 Mdot
.59451 .451 Mdot
.6746 .56624 Mdot
.61083 .64618 Mdot
.23624 .34009 Mdot
.6833 .45997 Mdot
.405 .50443 Mdot
.45496 .4848 Mdot
.46632 .73223 Mdot
.60138 .44931 Mdot
.64402 .52549 Mdot
.49177 .6213 Mdot
.53899 .74864 Mdot
.47817 .69448 Mdot
.45109 .73207 Mdot
.41657 .36023 Mdot
.28717 .72039 Mdot
.34089 .75341 Mdot
.74156 .45628 Mdot
.79756 .64116 Mdot
.61569 .54586 Mdot
.70432 .74637 Mdot
.39563 .44007 Mdot
.42413 .33735 Mdot
.64804 .67921 Mdot
.86275 .5184 Mdot
.4719 .30192 Mdot
.5438 .51786 Mdot
.58917 .81797 Mdot
.6603 .78194 Mdot
.39485 .40154 Mdot
.38903 .22594 Mdot
.20313 .63042 Mdot
.50247 .70172 Mdot
.47581 .20118 Mdot
.31985 .5821 Mdot
.58965 .80948 Mdot
.72568 .5358 Mdot
.47556 .49696 Mdot
.72523 .30237 Mdot
.75359 .50448 Mdot
.27929 .58168 Mdot
.75668 .31383 Mdot
.7344 .34708 Mdot
.75038 .67554 Mdot
.67806 .47044 Mdot
.45022 .42501 Mdot
.48541 .29694 Mdot
.84056 .54783 Mdot
.32239 .55072 Mdot
.63845 .63106 Mdot
.70145 .23787 Mdot
.24002 .33686 Mdot
.31729 .72695 Mdot
.8168 .57173 Mdot
.38839 .37134 Mdot
.71719 .54277 Mdot
.29852 .26565 Mdot
.47949 .29796 Mdot
.52053 .2904 Mdot
.33843 .33883 Mdot
.45357 .77523 Mdot
.44946 .3307 Mdot
.87697 .4966 Mdot
.61762 .79947 Mdot
.73149 .46913 Mdot
.67928 .20984 Mdot
.40025 .804 Mdot
.62209 .62345 Mdot
.43286 .3171 Mdot
.70945 .75613 Mdot
.35108 .31312 Mdot
.48047 .83964 Mdot
.50362 .44756 Mdot
.59388 .30964 Mdot
.47339 .77814 Mdot
.44706 .20238 Mdot
.70301 .50949 Mdot
.6821 .22852 Mdot
.41367 .22187 Mdot
.49513 .78105 Mdot
.53223 .41482 Mdot
.51075 .25768 Mdot
.50693 .24894 Mdot
.48705 .42083 Mdot
.44748 .50739 Mdot
.42995 .48782 Mdot
.4649 .4572 Mdot
.34595 .46386 Mdot
.4698 .41429 Mdot
.38 .24752 Mdot
.36639 .33204 Mdot
.74143 .33164 Mdot
.21171 .64724 Mdot
.44413 .73444 Mdot
.25525 .54563 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0;cooooo0_l0002;ooooo`007?ooool00ol0003oooooooooo`2looooo`;o0000
Roooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`34ooooo`;o
0000Poooool001cooooo00?o0000ooooooooool0a?ooool4o`00087ooooo000Looooo`03o`000?oo
oooooooo0<Kooooo1?l0001oooooo`007?ooool00ol0003oooooooooo`36ooooo`Co0000Ooooool0
01cooooo00?o0000ooooooooool0b?ooool3o`0007kooooo000Looooo`03o`000?oooooooooo0<So
oooo0ol0001nooooo`007?ooool00ol0003oooooooooo`39ooooo`Go0000Noooool001cooooo00?o
0000ooooooooool0boooool3o`0007_ooooo000Looooo`03o`000?oooooooooo0<kooooo0_l0001i
ooooo`007?ooool00ol0003oooooooooo`3>ooooo`;o0000NOooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0<kooooo0_l0001i
ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^
k_ooooooA4A400Kooooo00?o0000ooooooooool0Soooool4o`0000Gooooo0_l0000hooooo`;o0000
MOooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^
kP07ooooo`03o`000?oooooooooo08oooooo1?l00005ooooo`?o0000=oooool2o`0007Gooooo0000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3
o`0008Gooooo0_l00006ooooo`Co00001?ooool7o`0000;ooooo0_l0002Yooooo`0000?oooooo`00
0?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000oooo
ooooool0Q?ooool3o`0000Kooooo0_l00006ooooo`Co000000?oooooo`000?l000000_ooool2o`00
00;ooooo0_l0000_ooooo`;o000000?oooooo`000?l00000LOooool00003ooooool@413ooooo00;o
oooo00?o410@ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08Co
oooo0_l0000Looooo`;o0000;oooool2o`000003ooooool0003o0000077ooooo00001_ooooooMgMg
oiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooo
oooo08Wooooo0_l00002ooooo`;o00001oooool2o`000003ooooool0003o000000Cooooo0_l00006
ooooo`;o0000<?ooool2o`0006kooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo07kooooo0_l00007ooooo`Co0000
0_ooool2o`0000Oooooo0_l000000ooooooo0000o`000004ooooo`;o00001_ooool2o`000003oooo
ool0003o000002gooooo0_l0001^ooooo`007?ooool00ol0003oooooooooo`1looooo`Go00001_oo
ool2o`0000Cooooo0_l00002ooooo`Go00002Oooool2o`0000Kooooo1Ol0002Mooooo`007?ooool0
0ol0003oooooooooo`1looooo`;o000000?oooooo`000?l000003?ooool9o`0000Wooooo0_l00006
ooooo`?o00000oooool2o`0002_ooooo0ol0001/ooooo`007?ooool00ol0003oooooooooo`22oooo
o`?o00002_ooool2o`0000cooooo0_l000000ooooooo0000o`000006ooooo`;o00000oooool2o`00
02_ooooo1?l0001[ooooo`007?ooool00ol0003oooooooooo`1gooooo`?o000000?oooooo`000?l0
00001Oooool3o`0000?ooooo0_l0000Cooooo`;o000000?oooooo`000?l000001_ooool2o`0000?o
oooo0_l0000]ooooo`;o0000Joooool001cooooo00?o0000ooooooooool0MOooool5o`000003oooo
ool0003o000000Cooooo0_l00005ooooo`;o00005Oooool2o`0000Sooooo0_l0000_ooooo`;o0000
0_ooool2o`0006Wooooo000Looooo`03o`000?oooooooooo07Gooooo1?l00002ooooo`;o00001?oo
ool2o`000003ooooool0003o000001Wooooo1?l00006ooooo`;o0000;oooool2o`0000;ooooo0_l0
001Yooooo`007?ooool00ol0003oooooooooo`1booooo`;o000000?oooooo`000?l000003Oooool2
o`0001_ooooo0_l0000Aooooo`?o00009oooool2o`0006Wooooo000Looooo`03o`000?oooooooooo
07;ooooo0_l00007ooooo`;o00000oooool2o`0002;ooooo0_l0000>ooooo`?o00008oooool3o`00
0003ooooool0003o000000;o0000Ioooool001cooooo00?o0000ooooooooool0Joooool2o`0000?o
oooo0_l000000ooooooo0000o`000006ooooo`;o00000oooool2o`0002;ooooo1_l00002ooooo`Co
00001Oooool2o`0002?ooooo0ol000000ooooooo0000o`000003o`0006Kooooo000Looooo`03o`00
0?oooooooooo06_ooooo0ol00002ooooo`;o000000Coooooo`000?l0003o00001?ooool3o`0002So
oooo1Ol00002ooooo`Co00001Oooool2o`0002Gooooo1?l000000ooooooo0000o`00001Vooooo`00
7?ooool00ol0003oooooooooo`1Xooooo`;o00000_ooool4o`000003ooooool0003o000000?o0000
0_ooool6o`0002?ooooo0ol00007ooooo`Co00001oooool2o`0002Cooooo0ol00002ooooo`;o0000
I_ooool001cooooo0_l0001Yooooo`So000000?oooooo`000?l000000_l00003ooooo`Ko00008_oo
ool4o`0000Oooooo1?l00007ooooo`;o00009?ooool7o`0006Kooooo000Looooo`03o`000?oooooo
oooo06Wooooo1?l00006ooooo`;o00001Oooool2o`00023ooooo0_l00002ooooo`;o00000_ooool2
o`0000gooooo0ol0000Vooooo`Oo0000I_ooool001cooooo00?o0000ooooooooool0I?ooool2o`00
00?ooooo0_l0000:ooooo`;o00008?ooool3o`0000;ooooo0_l00004ooooo`Co00003Oooool3o`00
02Kooooo1Ol0001Xooooo`007?ooool00ol0003oooooooooo`1Sooooo`Go00002oooool4o`0001ko
oooo1Ol00007ooooo`?o00004?ooool4o`0000?ooooo0ol0000Mooooo`Ko0000J?ooool001cooooo
00?o0000ooooooooool0Foooool2o`0000;ooooo0_l000000ooooooo0000o`000004o`0000Kooooo
0_l00003ooooo`?o00007_ooool5o`0000;ooooo0_l00004ooooo`;o00000oooool2o`0000kooooo
0_l00003ooooo`?o00007Oooool4o`0006[ooooo000Looooo`03o`000?oooooooooo05Wooooo2?l0
00000ooooooo0000o`00000:ooooo`;o00008oooool3o`0000Gooooo0_l00009ooooo`;o0000<_oo
ool2o`000003ooooool0003o000000;o0000J?ooool001cooooo00?o0000ooooooooool0FOooool<
o`0002cooooo1Ol00007ooooo`;o00002Oooool2o`0000Wooooo0ol00005ooooo`;o00007Oooool2
o`000003ooooool0003o000000;o0000J?ooool001cooooo00?o0000ooooooooool0FOooool<o`00
02_ooooo0ol000000ooooooo0000o`000007ooooo`go000000Coooooo`000?l0003ooooo0_l00003
ooooo`?o00000oooool4o`0001gooooo0_l000001?oooooo0000o`000?l00002ooooo`;o0000IOoo
ool001cooooo00?o0000ooooooooool0Soooool4o`0000Sooooo3ol000001?oooooo0000o`000?oo
ool2o`0000Wooooo0_l0000Oooooo`;o000000Goooooo`000?l0003o0000ooooo`03o`0006Gooooo
000Looooo`03o`000?oooooooooo08oooooo1?l00003ooooo`;o00000oooool2o`0000Kooooo0ol0
00000ooooooo0000o`000003o`0000Sooooo0_l0000Tooooo`Ko000000?oooooo`000?l00000I_oo
ool001cooooo00?o0000ooooooooool0Soooool3o`0000Cooooo0_l0000>ooooo`Ko00002?ooool2
o`000004ooooool0003o0000o`00023ooooo1_l00004ooooo`;o0000Hoooool001cooooo00?o0000
ooooooooool0S_ooool2o`0001Kooooo1Ol00008ooooo`So00007_ooool3o`0000;ooooo0_l00004
ooooo`;o0000Hoooool001cooooo00?o0000ooooooooool0S?ooool4o`0000_ooooo0_l00006oooo
o`So00000oooool2o`0000?ooooo1?l000000ooooooo0000o`000004o`0001_ooooo0_l00002oooo
o`?o00001_ooool2o`00067ooooo000Looooo`03o`000?oooooooooo08_ooooo0ol00005ooooo`;o
00001_ooool4o`0000;ooooo1_l000000ooooooo0000o`000004ooooo`;o00002?ooool6o`0001_o
oooo0_l00002ooooo`?o00001_ooool2o`000003ooooool0003o000005kooooo000Looooo`03o`00
0?oooooooooo08_ooooo0_l00006ooooo`;o00001oooool3o`0000;ooooo1_l000001?oooooo0000
o`000?ooool2o`0000?ooooo0_l00006ooooo`Co00001Oooool2o`0001Kooooo0_l0000>ooooo`;o
0000G_ooool001cooooo00?o0000ooooooooool0Soooool2o`0000Oooooo1_l00002ooooo`Go0000
1_ooool3o`000004ooooool0003o0000o`0000Sooooo1?l00002ooooo`?o00005_ooool3o`0006go
oooo000Looooo`;o0000SOooool5o`0000Oooooo1?l000001?oooooo0000o`000?ooool2o`0000;o
oooo0ol00002ooooo`go00001?ooool4o`0000;ooooo0ol0000Fooooo`?o0000KOooool001cooooo
00?o0000ooooooooool0S?ooool4o`0000Kooooo0_l000000ooooooo0000o`000002ooooo`Co0000
0ooooolEo`000005ooooool0003o0000o`000?ooool01?l0000Gooooo`Go00002_ooool4o`000003
ooooool0003o000005[ooooo000Looooo`03o`000?oooooooooo05oooooo0_l0000/ooooo`;o0000
00?oooooo`000?l000001?ooool2o`0000Kooooo6ol000001Ooooooo0000o`000?l0003ooooo00Co
00006?ooool4o`0000[ooooo1?l000000ooooooo0000o`000002o`000003ooooool0003o000005Go
oooo000Looooo`03o`000?oooooooooo05Wooooo0_l00004ooooo`;o00000oooool2o`0000;ooooo
0_l0000Nooooo`;o000000?oooooo`000?l000000oooool2o`0000Sooooo0ol000000ooooooo0000
o`00000Io`000003ooooool0003o000000?o00006oooool2o`0000Oooooo0_l0000:ooooo`;o0000
00?oooooo`000?l00000EOooool001cooooo00?o0000ooooooooool0FOooool2o`0000Wooooo0_l0
0002ooooo`?o000000?oooooo`000?l000000_l0000Hooooo`Go00000_ooool3o`0000Sooooo0ol0
00000ooooooo0000o`00000Po`0001Wooooo0ol00007ooooo`;o00003Oooool2o`0005Gooooo000L
ooooo`03o`000?oooooooooo067ooooo1?l00004ooooo`Wo00005?ooool2o`000003ooooool0003o
000000Oo00000_ooool2o`0000Kooooo8Ol000000ooooooo0000o`00000Iooooo`;o00002?ooool4
o`0000_ooooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`1Fooooo`;o00002Oooool4o`00
0003ooooool0003o000000;ooooo0_l00002ooooo`Co00005?ooool2o`000003ooooool0003o0000
00Oo00000_ooool2o`0000Kooooo8_l0000Looooo`;o000000?oooooo`000?l000001_ooool2o`00
00_ooooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`1Fooooo`;o00002_ooool2o`0000;o
oooo0_l00007ooooo`;o00001Oooool2o`0000gooooo0_l00005ooooo`Go00002?ooool2o`000003
ooooool0003o000002;o00006_ooool2o`000003ooooool0003o000000?ooooo0_l00009ooooo`;o
0000F_ooool001cooooo00?o0000ooooooooool0E?ooool2o`000003ooooool0003o000000Kooooo
0ol0000Dooooo`Co00002oooool2o`0000;ooooo1?l00007ooooo`;o00000oooool2o`000003oooo
ool0003o000001oo000000?oooooo`000?l000006_ooool3o`0000Gooooo0_l00009ooooo`;o0000
2?ooool2o`00053ooooo000Looooo`03o`000?oooooooooo053ooooo0_l000001Ooooooo0000o`00
0?l0003ooooo00;o00001_ooool3o`0000Sooooo0_l0000<ooooo`Co000000?oooooo`000?l00000
2_ooool4o`0000Gooooo1?l00005ooooob7o00007_ooool3o`0000kooooo0_l0000:ooooo`;o0000
D?ooool001cooooo00?o0000ooooooooool0D?ooool2o`000004ooooool0003o0000ooooo`;o0000
2?ooool3o`000003ooooool0003o000000;o00000_ooool2o`0000Oooooo0_l00005ooooo`;o0000
00?oooooo`000?l000002_ooool2o`0000?ooooo0_l00002ooooo`;o00001_oooolCo`000003oooo
ool0003o000000_o00007oooool2o`000003ooooool0003o000000cooooo1?l00004ooooo`;o0000
E?ooool001cooooo00?o0000ooooooooool0COooool2o`0000Gooooo1?l00008ooooo`So00002ooo
ool2o`0000Sooooo0_l000001?oooooo0000o`000?ooool2o`0000Cooooo0_l00003ooooo`;o0000
2_oooolSo`00023ooooo0_l00007ooooo`;o00001Oooool2o`0000Cooooo0_l0001Dooooo`007?oo
ool00ol0003oooooooooo`1:ooooo`;o000000?oooooo`000?l000001Oooool2o`0000gooooo0_l0
000Hooooo`;o000000Coooooo`000?l0003ooooo1ol0000?ooooobCo00007oooool2o`0000Sooooo
0_l00004ooooo`;o00001_ooool2o`0005?ooooo000Looooo`03o`000?oooooooooo04Wooooo1Ol0
000Aooooo`Co00001oooool3o`0001?ooooo0_l00003ooooo`Go00003ooooolRo`00027ooooo1?l0
000<ooooo`;o00000oooool2o`000003ooooool0003o000005?ooooo000Looooo`03o`000?oooooo
oooo04Wooooo0_l000000ooooooo0000o`000002o`0000oooooo1?l00007ooooo`?o00002Oooool2
o`0000Kooooo1Ol00008ooooo`;o00003ooooolMo`0000Sooooo0_l0000Kooooo`;o00004Oooool2
o`0000;ooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`1>ooooo`;o00003_ooool2o`00
00Gooooo1?l000000ooooooo0000o`00000:ooooo`;o000000?oooooo`000?l000000oooool2o`00
0003ooooool0003o000000;ooooo0_l00004ooooo`;o00003_ooool9o`000003ooooool0003o0000
00oo000000?oooooo`000?l000000_l00006ooooo`;o00009oooool3o`0000Cooooo0_l00002oooo
o`;o00001?ooool2o`0004cooooo000Looooo`;o0000Coooool2o`0000gooooo0ol00005ooooo`Wo
000000Goooooo`000?l0003o0000ooooo`02o`0000Cooooo0_l00004ooooo`;o00001?ooool3o`00
00oooooo0_l00002ooooo`Co000000?oooooo`000?l000001?ooool2o`0000;ooooo4_l00004oooo
o`;o00009?ooool2o`0000;ooooo0ol0000>ooooo`;o0000C?ooool001cooooo00?o0000oooooooo
ool0Aoooool2o`0001Cooooo0_l000001?oooooo0000o`000?oooolDo`0000Sooooo0_l00005oooo
o`;o00003oooool3o`000003ooooool0003o000000;o000000?oooooo`000?l000001_ooool@o`00
00;ooooo0_l00004ooooo`;o00009?ooool2o`0000cooooo1?l0001Aooooo`007?ooool00ol0003o
ooooooooo`17ooooo`;o00005ooooolGo`0000;ooooo0_l0000;ooooo`;o00004?ooool2o`000004
ooooool0003o0000o`0000[ooooo4?l00002ooooo`;o00001?ooool2o`0002Cooooo0_l0000<oooo
o`Co0000DOooool001cooooo00?o0000ooooooooool0Aoooool2o`0001Oooooo5Ol00004ooooo`;o
00002Oooool2o`0000Cooooo0_l0000?ooooo`Co000000?oooooo`000?l000000oooool2o`000003
ooooool0003o000000co00000_ooool2o`0000Kooooo0_l0000Tooooo`;o00001Oooool2o`0000Oo
oooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`1Nooooo`So000000?oooooo`000?l00000
4?l0000;ooooo`;o000000Coooooo`000?l0003ooooo0_l0000>ooooo`So00000oooool2o`000003
ooooool0003o000000co00000_ooool2o`0002gooooo1?l00002ooooo`Co000000?oooooo`000?l0
00000_ooool3o`00053ooooo000Looooo`03o`000?oooooooooo04?ooooo0_l0000Hoooooaco0000
1Oooool2o`0000Oooooo0ol0000@ooooo`Oo00001oooool?o`00033ooooo1?l00004ooooo`;o0000
00?oooooo`000?l000000_l000001?oooooo0000o`000?l0001?ooooo`007?ooool00ol0003ooooo
ooooo`13ooooo`;o00006?oooolKo`0000?ooooo0_l000000ooooooo0000o`000004ooooo`?o0000
00?oooooo`000?l000004?ooool5o`0000_ooooo3Ol0000/ooooo`;o00003Oooool4o`0000;ooooo
0ol0001>ooooo`007?ooool00ol0003oooooooooo`1Kooooo`Co00000_oooolGo`0000;ooooo0ol0
0007ooooo`?o00003oooool2o`0000Gooooo0ol0000Aooooo`Go00001_ooool2o`0002Gooooo0_l0
0005ooooo`;o00003?ooool3o`0004kooooo000Looooo`03o`000?oooooooooo05_ooooo0ol00003
oooooaOo00000_ooool2o`0000;ooooo0_l0000Fooooo`;o00001_ooool2o`00017ooooo1Ol00000
0ooooooo0000o`000002o`000003ooooool0003o000000Cooooo0_l0000Oooooo`?o00001?ooool2
o`0000gooooo0ol0001=ooooo`007?ooool00ol0003oooooooooo`1Kooooo`Go000000?oooooo`00
0?l000005?l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000001_ooool2o`00
01?ooooo0_l00003ooooo`;o00003oooool7o`0000Kooooo0ol0000Pooooo`?o00000oooool2o`00
00Kooooo0_l00006ooooo`;o0000COooool001cooooo00?o0000ooooooooool0@?ooool2o`0001Wo
oooo0_l000000ooooooo0000o`00000Jo`0000Oooooo0_l00003ooooo`;o000000?oooooo`000?l0
00004?ooool2o`000003ooooool0003o000000?ooooo0_l0000?ooooo`Ko00001oooool3o`00027o
oooo0_l00004ooooo`;o00001?ooool7o`0000;ooooo0_l0001=ooooo`007?ooool00ol0003ooooo
ooooo`10ooooo`;o00006oooool2o`000003ooooool0003o000001Oo00001oooool2o`0000Cooooo
0_l0000Cooooo`;o00001Oooool3o`00017ooooo0_l00003ooooo`?o00001?ooool2o`0000Gooooo
0_l0000Iooooo`;o00001Oooool2o`0000Cooooo0_l000000ooooooo0000o`000002o`0000?ooooo
0_l0001<ooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o00000_oooolHo`0000Kooooo0ol0
0007ooooo`;o00005oooool4o`000003ooooool0003o000001;ooooo0ol0000:ooooo`?o00006Ooo
ool2o`0000_ooooo0_l000000ooooooo0000o`000004ooooo`Co0000Boooool001cooooo00?o0000
ooooooooool0GOooool2o`0000?ooooo5_l00004ooooo`;o000000?oooooo`000?l000002?ooool2
o`0001?ooooo0_l00004ooooo`Go00006_ooool4o`000003ooooool0003o000002Cooooo0ol00003
ooooo`;o00000_ooool7o`0004[ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ
8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`1Mooooo`;o00000ooo
oolFo`000004ooooool0003o0000ooooo`;o00008?ooool2o`0000Cooooo1_l0000Iooooo`Co0000
00?oooooo`000?l000009?ooool3o`0000Cooooo2_l0001:ooooo`0000KoooooogMgMonHV9Sooooo
oiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05go
oooo0_l00003ooooo`;o000000?oooooo`000?l000003ol00003ooooo`;o00001oooool2o`0002Co
oooo0_l00003ooooo`;o00005oooool4o`0002Cooooo0_l00005ooooo`Co00000_ooool4o`0004[o
oooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006ooooo`03o`00
0?oooooooooo05gooooo0_l00003oooooa?o00002_ooool2o`000003ooooool0003o000002Wooooo
0_l00003ooooo`;o00002?ooool2o`0000Sooooo0ol00003ooooo`?o00009_ooool3o`0000Gooooo
0ol00019ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04odA4A?oM
gMgoooooo`0000Oooooo0ol0001Mooooo`;o00001Oooool@o`000004ooooool0003o0000o`0000Go
oooo1?l0000aooooo`;o00001Oooool5o`0000cooooo1_l0000Vooooo`?o00001?ooool3o`0004Wo
oooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`1Mooooo`;o00001Oooool@o`000004ooooool0003o0000o`00
00Cooooo0ol000000ooooooo0000o`000003ooooo`;o00008oooool3o`0000cooooo1Ol0000<oooo
o`;o000000Coooooo`000?l0003o00006oooool2o`0000Wooooo0ol0001@ooooo`0000?ooooooa0@
4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0GOooool2o`0000Sooooo4?l000000ooooooo0000o`000004o`0000;ooooo0_l00003oooo
o`;o00008oooool5o`0000Kooooo0_l00005ooooo`;o00000oooool6o`000003ooooool0003o0000
00Ko00006oooool3o`00013ooooo0_l00019ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<
ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0>Oooool2o`00027ooooo0_l00009
ooooo`Co000000?oooooo`000?l000002?l000000ooooooo0000o`000003o`0000Cooooo0_l0000[
ooooo`;o00001_ooool2o`0000[ooooo1_l000000ooooooo0000o`000006o`0001cooooo1?l0000>
ooooo`;o0000BOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000oooo
o`06ooooo`03o`000?oooooooooo03Wooooo0_l0000Pooooo`?o00003_ooool7o`0000Cooooo0_l0
00000ooooooo0000o`00000Iooooo`;o00002Oooool2o`0000Oooooo0_l0000Oooooo`;o00008_oo
ool2o`0000kooooo0_l00019ooooo`007?ooool00ol0003oooooooooo`1Jooooo`?o00006Oooool2
o`0001gooooo0_l000000ooooooo0000o`000006ooooo`;o00001oooool2o`000003ooooool0003o
000000gooooo0_l00002ooooo`;o00002Oooool2o`0001[ooooo0_l0000@ooooo`;o0000Coooool0
01cooooo00?o0000ooooooooool0F_ooool2o`0001Gooooo0ol000001Ooooooo0000o`000?l0003o
oooo00;o00002_ooool2o`00017ooooo1?l0000@ooooo`;o000000?oooooo`000?l000000_l00008
ooooo`;o00000_ooool2o`0002Gooooo0_l00007ooooo`;o00001oooool3o`0000Cooooo0_l00018
ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00008?ooool5o`0001;ooooo0ol000000ooo
oooo0000o`000002ooooo`;o00002_ooool4o`00017ooooo0_l0000Cooooo`Co00001_ooool2o`00
00Gooooo0_l0000]ooooo`;o00002?ooool3o`0000?ooooo0_l00018ooooo`007?ooool00ol0003o
ooooooooo`0hooooo`;o00008?ooool5o`0001cooooo0_l0000:ooooo`;o00001Oooool2o`0000Ko
oooo0_l0000Fooooo`Co00001oooool2o`0000Gooooo0ol00008ooooo`;o00000_ooool2o`0000;o
oooo0_l0000Mooooo`;o00001_ooool2o`0004gooooo000Looooo`03o`000?oooooooooo05[ooooo
1?l0000Booooo`Co00001oooool2o`00017ooooo0_l00006ooooo`;o00005_ooool4o`0000?ooooo
0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000000Sooooo0ol000000ooooooo0000
o`000002ooooo`;o00007Oooool2o`0005Gooooo000Looooo`03o`000?oooooooooo05_ooooo0ol0
000Booooo`Co00008_ooool2o`0000cooooo0_l0000:ooooo`;o00000oooool2o`0000Kooooo0ol0
000:ooooo`Co00000oooool2o`0000Kooooo0_l0000;ooooo`;o00004_ooool3o`0004cooooo000L
ooooo`03o`000?oooooooooo03Kooooo0_l0000Sooooo`?o00005?ooool2o`00033ooooo0_l0000D
ooooo`;o000000?oooooo`000?l000002oooool2o`0000Gooooo0_l00006ooooo`;o00002oooool2
o`0000?ooooo0_l0000=ooooo`?o00001?ooool2o`0004Kooooo000Looooo`03o`000?oooooooooo
03Kooooo0_l0000Sooooo`?o00003?ooool3o`0000;ooooo0_l00002ooooo`;o00002?ooool2o`00
027ooooo0_l0000@ooooo`;o00001_ooool2o`0000Kooooo0ol00003ooooo`;o00002?ooool2o`00
01Oooooo0_l00003ooooo`;o00002Oooool2o`0000Cooooo0_l00016ooooo`007?ooool00ol0003o
ooooooooo`1Looooo`Oo00001oooool3o`0000;ooooo1_l00008ooooo`;o00000_ooool2o`0001go
oooo0_l00009ooooo`;o00001Oooool2o`0000Wooooo0_l00002ooooo`Co00000oooool2o`0000So
oooo0ol0000@ooooo`;o00002Oooool2o`0000[ooooo0ol00002ooooo`;o0000A_ooool001cooooo
00?o0000ooooooooool0=?ooool2o`0002Kooooo1ol0000:ooooo`Oo00001?ooool2o`0000Oooooo
0_l0000Hooooo`;o00003_ooool2o`00013ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o
00002?ooool2o`0000;ooooo0_l0000@ooooo`;o00001oooool5o`0000Wooooo1?l00019ooooo`00
7?ooool00ol0003oooooooooo`0dooooo`;o00009oooool8o`0000Sooooo0_l000000ooooooo0000
o`000006ooooo`;o00006?ooool2o`0000Oooooo0_l00003ooooo`;o000000?oooooo`000?l00000
4?ooool2o`0000Gooooo1_l000000ooooooo0000o`000003o`0000Oooooo0_l00005ooooo`?o0000
5Oooool2o`000003ooooool0003o000000_ooooo0_l00019ooooo`007?ooool2o`0005kooooo0_l0
0003ooooo`?o00002Oooool4o`00023ooooo0_l00007ooooo`;o00000oooool2o`000003ooooool0
003o000000;o00003_ooool4o`0000?ooooo2Ol000000ooooooo0000o`000005o`0000Wooooo0ol0
000:ooooo`;o00003?ooool2o`0002gooooo0_l0000Wooooo`007?ooool00ol0003oooooooooo`1R
ooooo`;o00002_ooool4o`0000;ooooo0_l0000Oooooo`;o00001?ooool2o`0000Sooooo0_l0000@
ooooo`;o00001?ooool8o`000003ooooool0003o000000Go00005_ooool2o`0000cooooo0_l0000]
ooooo`;o00009oooool001cooooo00?o0000ooooooooool0H_ooool4o`0000Sooooo0ol00003oooo
o`;o00007Oooool4o`0000Wooooo0_l0000JoooooaGo00003oooool5o`0000Sooooo0_l000001?oo
oooo0000o`000?l0000;ooooo`;o00007oooool2o`0002Sooooo000Looooo`03o`000?oooooooooo
03;ooooo0_l0000^ooooo`Co00002?ooool2o`00027ooooo1?l00006ooooo`;o00000oooool2o`00
00?ooooo0_l0000;ooooo`;o00000_ooool4o`0000;ooooo0_l00004ooooo`oo000000?oooooo`00
0?l000001_ooool2o`0000Cooooo1?l00009ooooo`;o000000Coooooo`000?l0003o00002oooool2
o`0001gooooo1?l0000Xooooo`007?ooool00ol0003oooooooooo`0booooo`?o0000;_ooool4o`00
00Kooooo0_l0000Qooooo`Co00001oooool2o`0000Sooooo0_l0000;ooooo`;o000000?oooooo`00
0?l000000ol000001?oooooo0000o`000?l00007oooooa7o000000Coooooo`000?l0003ooooo0_l0
000Dooooo`?o00002oooool5o`0001[ooooo1?l0000Xooooo`007?ooool00ol0003oooooooooo`0c
ooooo`;o0000;oooool3o`0000Gooooo0ol0000Qooooo`Co00008Oooool2o`0000Cooooo0ol00005
oooooaKo00005oooool6o`0000Oooooo1_l0000Kooooo`;o0000:Oooool001cooooo00?o0000oooo
ooooool0<Oooool2o`00037ooooo0ol00005ooooo`;o0000BOooool2o`0000?ooooo1Ol00002oooo
oaOo00001_ooool3o`0000Oooooo0_l00004ooooo`Ko00001oooool4o`0001gooooo0_l0000Yoooo
o`007?ooool00ol0003oooooooooo`0aooooo`;o0000;oooool6o`0000Wooooo0_l00003ooooo`;o
00009?ooool2o`0000;ooooo0_l0000Eooooo`;o000000?oooooo`000?l000001Ol00003oooooaKo
00001_ooool3o`0000Oooooo0_l00004ooooo`?o00002_ooool4o`0004Sooooo000Looooo`03o`00
0?oooooooooo05cooooo1Ol000000ooooooo0000o`000004o`0000?ooooo1Ol000000ooooooo0000
o`000003ooooo`;o00007?ooool2o`0000Kooooo0_l00002ooooo`;o00004Oooool2o`0000Gooooo
2Ol000000ooooooo0000o`00000Co`0000;ooooo0_l000000ooooooo0000o`00000Mooooo`;o0000
7?ooool2o`0002cooooo000Looooo`03o`000?oooooooooo033ooooo0_l0000Wooooo`_o00000ooo
ool2o`000003ooooool0003o000000Co00004?ooool2o`0000;ooooo0_l0000>ooooo`;o00000_oo
ool2o`0000Kooooo1?l00002ooooo`;o00002oooool2o`0000Gooooo1?l000000ooooooo0000o`00
0004o`000003ooooool0003o000001Go000000?oooooo`000?l000003?ooool2o`0000oooooo0_l0
000Kooooo`?o0000;?ooool001cooooo00?o0000ooooooooool0<?ooool2o`0002Oooooo1?l00003
ooooo`Go00000_ooool8o`000003ooooool0003o000000kooooo0_l00002ooooo`;o00004_ooool2
o`0000Kooooo1?l00002ooooo`;o00005?ooool2o`0000;ooooo1Ol000000ooooooo0000o`00000C
o`0000?ooooo0_l0000<ooooo`;o00000oooool2o`0000[ooooo1?l0000Iooooo`Co0000:oooool0
01cooooo00?o0000ooooooooool0E_ooool2o`000003ooooool0003o000000Gooooo1ol000001?oo
oooo0000o`000?ooool2o`0000?ooooo0_l0000Nooooo`;o00001Oooool4o`0000Kooooo0_l0000G
ooooo`;o00001?oooolLo`0000;ooooo0_l00004ooooo`;o00001oooool2o`0000;ooooo0_l0000:
ooooo`Co00006Oooool4o`0002_ooooo000Looooo`03o`000?oooooooooo033ooooo0_l0000Toooo
o`;o000000?oooooo`000?l000001oooool5o`0000_ooooo0_l0000Cooooo`?o00001_ooool2o`00
00Gooooo1?l00006ooooo`;o00005oooool2o`0000Gooooo6ol00002ooooo`;o00001?ooool2o`00
00Gooooo1?l00003ooooo`;o00002?ooool5o`0001Wooooo0ol0000/ooooo`007?ooool00ol0003o
ooooooooo`0`ooooo`;o00008?ooool2o`0000kooooo1?l00003ooooo`;o00001?ooool2o`000003
ooooool0003o0000017ooooo1Ol00006ooooo`;o00001_ooool3o`0002Kooooo6ol00002ooooo`;o
00002oooool2o`0000Gooooo0_l00007ooooo`Co00006oooool3o`0002cooooo000Looooo`03o`00
0?oooooooooo05;ooooo0_l0000Dooooo`?o00001?ooool2o`0000oooooo0_l000000ooooooo0000
o`000002o`0000Wooooo0_l00002ooooo`;o00000_ooool3o`0000Oooooo0_l0000Mooooo`Go0000
00?oooooo`000?l000004ol0000Iooooo`;o00001?ooool2o`0004cooooo000Looooo`03o`000?oo
oooooooo04oooooo0_l000001?oooooo0000o`000?ooool2o`0000Sooooo0_l00007ooooo`;o0000
5_ooool2o`000004ooooool0003o0000ooooo`;o00003?ooool2o`000003ooooool0003o000000;o
00001oooool2o`0001gooooo6ol0000Dooooo`;o00000oooool2o`0002;ooooo0_l0000^ooooo`00
7?ooool2o`0003Cooooo0_l0000Hooooo`Ko00000_ooool2o`0000Sooooo0_l00003ooooo`;o0000
0oooool4o`0001Gooooo0_l00002ooooo`;o00001Oooool4o`0000?ooooo0_l000000ooooooo0000
o`000002o`0002Gooooo7?l00006ooooo`;o00003?ooool2o`0000;ooooo0_l00005ooooo`;o0000
6Oooool5o`0002kooooo000Looooo`03o`000?oooooooooo03?ooooo0_l0000Hooooo`;o00000_oo
ool2o`0000Gooooo0_l000000ooooooo0000o`000004o`0000?ooooo0_l00003ooooo`Co00002?oo
ool4o`0000?ooooo0_l00002ooooo`Co00002Oooool4o`0000?ooooo0_l00004ooooo`;o00009?oo
ool6o`000003ooooool0003o000001?o00001_ooool2o`0000cooooo0ol000000ooooooo0000o`00
0004ooooo`?o00006Oooool3o`00033ooooo000Looooo`03o`000?oooooooooo037ooooo0_l0000G
ooooo`;o00000_ooool2o`0000;ooooo0_l00004ooooo`co00004Oooool4o`000003ooooool0003o
000000;o00000_ooool2o`0000Wooooo1Ol0000:ooooo`;o00005Oooool2o`0000kooooo1?l00002
oooooaGo00005?ooool3o`0000Oooooo0_l0000Jooooo`;o0000<Oooool001cooooo00?o0000oooo
ooooool0<?ooool3o`0001Oooooo0_l00002ooooo`Ko00000oooool=o`0000?ooooo0_l0000Aoooo
o`?o00003_ooool5o`0000cooooo0ol00004ooooo`?o00000_ooool2o`000004ooooool0003o0000
o`0000?ooooo0_l0000>oooooa_o00000_ooool2o`000003ooooool0003o000000kooooo0_l00007
ooooo`;o00006Oooool2o`0003;ooooo000Looooo`03o`000?oooooooooo02oooooo1ol0000Goooo
o`So00000_ooool:o`000003ooooool0003o000000?ooooo0_l0000cooooo`Go00000_ooool3o`00
00;ooooo0_l000000ooooooo0000o`000002o`0001;ooooo6ol000001Ooooooo0000o`000?l0003o
oooo00;o00000_ooool2o`0000[ooooo0_l00006ooooo`;o00006_ooool4o`00033ooooo000Loooo
o`03o`000?oooooooooo02oooooo0_l000000ooooooo0000o`000002o`0001Kooooo2_l00002oooo
o`co00001oooool2o`0001Oooooo0_l00007ooooo`Co00002oooool5o`0000[ooooo1?l0000Boooo
oa_o000000?oooooo`000?l000000_l00004ooooo`;o00003?ooool2o`0000Cooooo0_l0000Joooo
o`Co0000<?ooool001cooooo00?o0000ooooooooool0=?ooool2o`0001Gooooo1Ol00002oooooa7o
000000?oooooo`000?l000001Oooool3o`0000gooooo0_l00007ooooo`;o00001_ooool5o`0000ko
oooo0_l00002ooooo`;o00002?ooool2o`0001;ooooo6_l00004ooooo`;o00004_ooool2o`0000Co
oooo0_l0000Iooooo`?o0000<_ooool001cooooo00?o0000ooooooooool0=Oooool2o`0001?ooooo
0ol00003oooooaKo00000_ooool2o`0000;ooooo0ol0000<ooooo`;o00003oooool2o`00017ooooo
1ol00007ooooo`?o00004OoooolJo`0001gooooo0_l000000ooooooo0000o`00000Gooooo`?o0000
<_ooool001cooooo00?o0000ooooooooool0=Oooool2o`0001?ooooo0_l00003ooooo`[o000000?o
ooooo`000?l000001Ol000000ooooooo0000o`000003o`000003ooooool0003o000000?ooooo0ol0
000<ooooo`;o00008Oooool7o`0000Sooooo0_l0000CoooooaSo00007Oooool2o`000003ooooool0
003o000004cooooo000Looooo`03o`000?oooooooooo04kooooo4ol000000ooooooo0000o`000004
o`0000Gooooo2?l00007ooooo`;o00002Oooool2o`00017ooooo1Ol00002ooooo`?o000000?ooooo
o`000?l000000oooool4o`0001?ooooo7?l00002ooooo`;o00005_ooool2o`0001_ooooo0_l0000c
ooooo`007?ooool00ol0003oooooooooo`0booooo`;o000000?oooooo`000?l000003?ooool2o`00
00Wooooo4ol000000ooooooo0000o`000004o`0000Gooooo2?l00004ooooo`Co00002_ooool2o`00
00gooooo0ol000000ooooooo0000o`000003o`0000;ooooo0ol000000ooooooo0000o`000003oooo
o`Co00004ooooolLo`0000;ooooo0_l0000@ooooo`;o00001?ooool2o`0001_ooooo0_l0000coooo
o`007?ooool00ol0003oooooooooo`0booooo`;o000000?oooooo`000?l000003?ooool2o`0000Wo
oooo6Ol0000Booooo`Co000000?oooooo`000?l000005_ooool3o`000004ooooool0003o0000oooo
o`;o00001_ooool4o`000004ooooool0003o0000ooooo`;o00005OoooolGo`0000Gooooo0_l00006
ooooo`;o00001oooool2o`0005Kooooo000Looooo`03o`000?oooooooooo03Gooooo0_l0000Foooo
o`Go000000?oooooo`000?l000004Ol0000Hooooo`;o00004oooool2o`0000;ooooo0_l000000ooo
oooo0000o`000003o`0000Gooooo1Ol000001?oooooo0000o`000?ooool4o`0001;ooooo5?l00000
1?oooooo0000o`000?l00005ooooo`?o00001Oooool2o`0002Gooooo1Ol0000eooooo`007?ooool0
0ol0003oooooooooo`0booooo`;o00003_ooool2o`0000Wooooo5?l00002ooooo`Co00000_ooool4
o`0000?ooooo0_l0000>ooooo`;o00003oooool4o`0000Kooooo1ol00002ooooo`;o000000?ooooo
o`000?l000001_ooool2o`0001;ooooo5ol000000ooooooo0000o`000003ooooo`?o0000;?ooool5
o`0003Gooooo000Looooo`03o`000?oooooooooo033ooooo1?l000000ooooooo0000o`00000;oooo
o`;o00002ooooolHo`0000;ooooo1?l00003ooooo`;o00000_ooool2o`0000Gooooo0_l00003oooo
o`;o00003oooool3o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000004o`00
00Gooooo1?l0000Hooooo`ko000000?oooooo`000?l000001_l000001?oooooo0000o`000?l00003
ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00000oooool2o`000003ooooool0003o
000005Gooooo000Looooo`03o`000?oooooooooo033ooooo0_l00003ooooo`;o00002Oooool2o`00
00_ooooo6Ol0000;ooooo`;o000000?oooooo`000?l000001Oooool2o`0001Oooooo3_l00002oooo
o`;o000000?oooooo`000?l000000_l000000ooooooo0000o`00000FoooooaKo00000_ooool2o`00
00?ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00003ooooo`;o000000?oooooo`00
0?l000006Oooool5o`0003Oooooo000Looooo`;o0000@Oooool2o`0000_ooooo1ol000000ooooooo
0000o`00000@o`0000[ooooo0_l000001?oooooo0000o`000?l0000JoooooaGo000000Coooooo`00
0?l0003o00000_ooool2o`0001Kooooo5_l00007ooooo`;o0000:_ooool5o`0003Oooooo000Loooo
o`03o`000?oooooooooo043ooooo0_l0000;oooooaCo000000?oooooo`000?l000000ol0000>oooo
o`Co00005oooool7o`0000;ooooo3?l00003ooooo`;o000000?oooooo`000?l000000ol0000Goooo
oaCo00001_ooool2o`0000kooooo0_l00003ooooo`;o0000DOooool001cooooo00?o0000oooooooo
ool0?oooool3o`0000cooooo6_l0000?ooooo`;o00005oooool2o`000003ooooool0003o000000;o
00000_ooool?o`000003ooooool0003o000000Go00005oooool4o`000003ooooool0003o000000Wo
000000?oooooo`000?l000000_l00005ooooo`;o000000?oooooo`000?l000002oooool2o`0000?o
oooo0_l0000Eooooo`?o0000>Oooool001cooooo00?o0000ooooooooool0?oooool2o`0000gooooo
6_l0000>ooooo`;o00006oooool4o`000003ooooool0003o0000017o000000?oooooo`000?l00000
6Oooool7o`000003ooooool0003o000000Go00000oooool3o`0000Gooooo0_l000001?oooooo0000
o`000?ooool2o`00023ooooo0_l000000ooooooo0000o`000002o`0003Wooooo000Looooo`03o`00
0?oooooooooo03oooooo0_l0000=oooooa[o00003_ooool2o`0001_ooooo1?l000000ooooooo0000
o`00000@o`0001oooooo2ol000000ooooooo0000o`000004o`0000Sooooo0_l00002ooooo`;o0000
0_ooool2o`0001cooooo0_l000000ooooooo0000o`00000kooooo`007?ooool00ol0003ooooooooo
o`0oooooo`;o00003OoooolHo`00013ooooo0_l0000Koooooa?o000000?oooooo`000?l000000_oo
ool4o`0001[ooooo2ol000000ooooooo0000o`000003o`0000Wooooo0ol00005ooooo`;o00007?oo
ool4o`0003cooooo000Looooo`03o`000?oooooooooo047ooooo0_l0000;oooooaWo00002oooool2
o`000003ooooool0003o000001gooooo0_l000000ooooooo0000o`00000=o`000005ooooool0003o
0000o`000?ooool01?l0000Kooooo`Ko000000?oooooo`000?l000000_l000001?oooooo0000o`00
0?l0000;ooooo`;o00001Oooool4o`0000;ooooo0_l0000Hooooo`?o0000>oooool001cooooo00?o
0000ooooooooool0@Oooool2o`0000_ooooo6_l0000:ooooo`;o000000?oooooo`000?l000007ooo
ool@o`0000;ooooo0_l0000Qooooo`ko00002?ooool5o`0000Oooooo1_l0000Booooo`?o00001?oo
ool3o`0003[ooooo000Looooo`03o`000?oooooooooo03gooooo0_l0000?ooooo`;o000000?ooooo
o`000?l000005Ol0000YoooooaKo00009?ooool=o`0000Cooooo0_l00003ooooo`Go00001oooool4
o`0001Cooooo0ol00005ooooo`;o000000?oooooo`000?l00000=oooool001cooooo00?o0000oooo
ooooool0?Oooool2o`000003ooooool0003o000000gooooo5Ol000000ooooooo0000o`00000Zoooo
oaKo00009Oooool;o`0000;ooooo1Ol00003ooooo`Go00000oooool2o`0000;ooooo0ol0000Doooo
o`;o00001oooool2o`000003ooooool0003o000003Oooooo000Looooo`03o`000?oooooooooo043o
oooo0_l0000=oooooa;o00001?ooool2o`0000gooooo0_l0000Mooooo`go000000?oooooo`000?l0
00000ol0000Xooooo`Wo00000_ooool7o`0000Wooooo0_l00002ooooo`;o00005Oooool2o`0000Oo
oooo0ol000000ooooooo0000o`00000fooooo`007?ooool00ol0003oooooooooo`1Aooooo`ko0000
00?oooooo`000?l000000_ooool2o`0000[ooooo0_l00002ooooo`;o00007OoooolEo`0002Oooooo
2ol000000ooooooo0000o`000004o`0000Oooooo0_l000000ooooooo0000o`00000Fooooo`;o0000
2Oooool5o`0003Kooooo000Looooo`03o`000?oooooooooo057ooooo4Ol00002ooooo`;o00002Ooo
ool3o`00027ooooo5ol0000Wooooo`co00000_ooool2o`0000;ooooo0_l00003ooooo`;o000000?o
ooooo`000?l000005_ooool2o`0000[ooooo1?l0000fooooo`007?ooool00ol0003oooooooooo`1B
oooooa3o00000oooool4o`0000Kooooo0_l0000Roooooa?o00000_ooool2o`0002[ooooo3Ol00002
ooooo`;o00001_ooool2o`0001Wooooo0_l00011ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^
k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0
?_ooool2o`0001;ooooo2ol00002ooooo`;o000000Coooooo`000?l0003ooooo1Ol00003ooooo`;o
00009?ooool@o`000004ooooool0003o0000ooooo`;o0000;OoooolAo`0001oooooo0_l00011oooo
o`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonH
V9So8B4Q00Kooooo00?o0000ooooooooool0?Oooool3o`0001;ooooo1?l00002ooooo`Co00000ooo
ool2o`000004ooooool0003o0000ooooo`Ko00000_ooool2o`0002Cooooo4ol000000ooooooo0000
o`00000Cooooo`Co00006?ooool?o`0001[ooooo0_l00016ooooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`0mooooo`;o00000_ooool2o`00017ooooo1?l000000ooooooo0000o`000004ooooo`;o0000
1?ooool2o`0000;ooooo0ol0000Woooooa7o00006?ooool4o`0001[ooooo2ol0000Looooo`;o0000
A_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oV9RHoooo
oonHV9So8B4Q00Kooooo0ol00011ooooo`;o00001?ooool2o`0000gooooo0ol00005ooooo`;o0000
0_ooool2o`000003ooooool0003o000000?ooooo0_l0000Woooooa7o00006Oooool2o`0008[ooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oeEEEOl0003o410@
olc<c006ooooo`03o`000?oooooooooo04Oooooo0_l0000>ooooo`Go00000_ooool2o`0000;ooooo
0_l0000_oooooa7o00006Oooool3o`0000;ooooo0_l0000nooooo`;o00002Oooool2o`0003[ooooo
00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qoooool02?oo
ool00ol0003oooooooooo`0mooooo`;o00006Oooool9o`0003;ooooo4Ol000000ooooooo0000o`00
000Gooooo`;o00000_ooool2o`0003Wooooo0_l00003ooooo`;o00002Oooool2o`0003[ooooo0000
1_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003ooooo
ooooo`0mooooo`;o00001Oooool2o`0001Cooooo1ol0000cooooo`oo00000_ooool2o`0005Kooooo
0ol00019ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co0000oa0@
40Kooooo00?o0000ooooooooool0A?ooool2o`0004kooooo3Ol0000Xooooo`;o0000<_ooool3o`00
00Oooooo0_l000000ooooooo0000o`00000mooooo`007?ooool00ol0003oooooooooo`0nooooo`;o
0000EOooool2o`0000;ooooo2_l000000ooooooo0000o`00000Sooooo`;o0000<_ooool4o`0000Ko
oooo0_l000000ooooooo0000o`00000mooooo`007?ooool00ol0003oooooooooo`0mooooo`?o0000
E_ooool2o`000003ooooool0003o000000Go000000?oooooo`000?l000000ol0001Hooooo`?o0000
1?ooool2o`0004;ooooo000Looooo`03o`000?oooooooooo03gooooo0_l0001Fooooo`?o00001?oo
ool9o`00027ooooo0_l0000cooooo`;o000000?oooooo`000?l000001Oooool3o`00047ooooo000L
ooooo`03o`000?oooooooooo03gooooo0ol0001Aooooo`;o00000_ooool2o`0000Kooooo0_l00000
1?oooooo0000o`000?l0000Sooooo`;o0000<oooool2o`0000Wooooo0_l00011ooooo`007?ooool0
0ol0003oooooooooo`0nooooo`;o0000DOooool2o`0000Kooooo0_l00002ooooo`;o0000;Oooool2
o`0003?ooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`0nooooo`;o0000D?ooool4o`00
00Gooooo0_l0000aooooo`;o0000;oooool6o`0004Kooooo000Looooo`03o`000?oooooooooo08[o
oooo0_l00004ooooo`Co00002_ooool2o`0002cooooo0_l000000ooooooo0000o`00000/ooooo`Co
0000B?ooool001cooooo00?o0000ooooooooool0?_ooool2o`0004Wooooo0ol0000@ooooo`Co0000
;?ooool2o`000003ooooool0003o000002Wooooo0_l00002ooooo`Ko0000AOooool001cooooo00?o
0000ooooooooool0?_ooool3o`0004;ooooo0_l000001?oooooo0000o`000?ooool9o`0000Oooooo
0_l000000ooooooo0000o`00000^ooooo`;o000000?oooooo`000?l00000:Oooool2o`000003oooo
ool0003o000000Go00000oooool2o`00043ooooo000Looooo`03o`000?oooooooooo03kooooo0ol0
0012ooooo`;o000000?oooooo`000?l000002_l000000ooooooo0000o`000004ooooo`;o00000_oo
ool2o`0002Cooooo0_l00007ooooo`;o000000?oooooo`000?l00000;?ooool4o`000003ooooool0
003o000000;o000000?oooooo`000?l00000@?ooool001cooooo00?o0000ooooooooool0?oooool4
o`00047ooooo4Ol00008ooooo`;o00008_ooool4o`0000?ooooo0_l00004ooooo`;o00000_ooool4
o`0002cooooo1?l00013ooooo`007?ooool2o`0004;ooooo0_l00011oooooa7o00002?ooool2o`00
02;ooooo1?l000000ooooooo0000o`000002o`0000Cooooo0_l00002ooooo`Co0000:oooool2o`00
04Kooooo000Looooo`03o`000?oooooooooo087ooooo0ol000000ooooooo0000o`00000=o`0000Wo
oooo0_l0000Wooooo`Go00000oooool2o`0000?ooooo0ol0000[ooooo`;o0000A_ooool001cooooo
00?o0000ooooooooool0P?ooool4o`000003ooooool0003o000000go00002?ooool3o`0002Sooooo
1?l00003ooooo`;o00000oooool2o`0001oooooo0_l0000<ooooo`;o0000AOooool001cooooo00?o
0000ooooooooool0P?ooool2o`0000;ooooo4Ol00007ooooo`;o00005oooool2o`00017ooooo0_l0
0009ooooo`;o00007oooool2o`0000cooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`12
ooooo`;o0000??ooool2o`000003ooooool0003o0000013o00002Oooool2o`0001Gooooo0_l00003
ooooo`;o00003Oooool2o`0000;ooooo0_l00004ooooo`;o00008?ooool4o`00053ooooo000Loooo
o`03o`000?oooooooooo04;ooooo0ol0000koooooaGo00000_ooool2o`0000Gooooo0ol0000Ioooo
o`;o00003Oooool6o`0000Cooooo0_l0000Pooooo`Co000000?oooooo`000?l00000COooool001co
oooo00?o0000ooooooooool0@oooool2o`0003Sooooo0_l00002oooooaGo000000?oooooo`000?l0
00001Oooool5o`0002Oooooo0ol00006ooooo`;o00007?ooool2o`0000Kooooo0ol0001=ooooo`00
7?ooool00ol0003oooooooooo`1mooooo`;o00000_oooolEo`000003ooooool0003o000000Gooooo
0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000;o00000oooool3o`0001Wo
oooo0ol0000Tooooo`Co00001?ooool3o`0000;ooooo0_l00019ooooo`007?ooool00ol0003ooooo
ooooo`17ooooo`;o0000=?ooool2o`0000?ooooo5ol00006ooooo`;o00000oooool2o`000003oooo
ool0003o000000;o00000oooool3o`0000?ooooo1Ol0000Booooo`;o00000oooool4o`0001cooooo
1Ol00005ooooo`?o000000?oooooo`000?l00000BOooool001cooooo00?o0000ooooooooool0AOoo
ool4o`0003Sooooo6?l00003ooooo`;o000000?oooooo`000?l000004oooool6o`00017ooooo0_l0
0002ooooo`Go00007?ooool2o`0000Wooooo1?l0001:ooooo`007?ooool00ol0003oooooooooo`15
ooooo`;o00000_ooool2o`0003Kooooo4_l00009ooooo`;o00001?ooool2o`0000Cooooo0ol00000
1?oooooo0000o`000?l00007ooooo`Co00003?ooool2o`000003ooooool0003o000000;o00000_oo
ool2o`0002cooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`16ooooo`;o000000?ooooo
o`000?l00000<Oooool2o`0000?ooooo5?l0000=ooooo`;o00001?ooool3o`000003ooooool0003o
000000?o00001oooool3o`0000[ooooo2?l000000ooooooo0000o`00001iooooo`007?ooool00ol0
003oooooooooo`16ooooo`?o0000<oooool2o`0000?ooooo5?l0000>ooooo`;o00001oooool5o`00
00Sooooo0ol00009ooooo`Oo00000_ooool2o`000003ooooool0003o000002Sooooo0_l0001<oooo
o`007?ooool00ol0003oooooooooo`17ooooo`;o00000_ooool4o`0003;ooooo4ol0000>ooooo`?o
00002Oooool2o`0000[ooooo0ol00008ooooo`Oo00001Oooool2o`0001[ooooo0_l00007ooooo`;o
00000oooool2o`0004cooooo000Looooo`03o`000?oooooooooo04_ooooo1?l0000boooooa;o0000
0oooool4o`0000Sooooo0_l000000ooooooo0000o`000006ooooo`?o00002_ooool3o`0000Oooooo
2?l0000Qooooo`;o00001oooool2o`00057ooooo000Looooo`03o`000?oooooooooo04cooooo0_l0
000_ooooo`;o00000ooooolCo`000003ooooool0003o000000;o00002?ooool5o`0000Gooooo1?l0
000:ooooo`?o00001oooool4o`0002cooooo0_l0001Cooooo`007?ooool2o`0007kooooo0_l00005
ooooo`ko000000?oooooo`000?l000002_ooool2o`0000?ooooo0_l00006ooooo`;o00001Oooool3
o`0000?ooooo0ol00008ooooo`Co000000?oooooo`000?l000000_l0000Wooooo`;o0000Doooool0
01cooooo00?o0000ooooooooool0C?ooool2o`0002oooooo0_l00007ooooo`_o00001?ooool2o`00
00Oooooo0ol00009ooooo`Co00000oooool<o`0000Kooooo1Ol000000ooooooo0000o`000004o`00
02Sooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o0000=Oooool2o`0000?o
oooo2?l00002ooooo`;o000000?oooooo`000?l000001oooool2o`0000[ooooo0_l00005ooooo`co
00001Oooool4o`0000Cooooo1Ol0000Pooooo`;o00001?ooool4o`00053ooooo000Looooo`03o`00
0?oooooooooo04cooooo0_l0000eooooo`?o00001?ooool6o`0000;ooooo0_l00007ooooo`Go0000
3oooool<o`0000Kooooo0ol00004ooooo`Go00008_ooool2o`0000Cooooo0ol0001Aooooo`007?oo
ool00ol0003oooooooooo`1?ooooo`?o0000<_ooool5o`000003ooooool0003o000000Co00001ooo
ool2o`0000;ooooo1?l0000;ooooo`;o00000oooool<o`0000Kooooo0_l00002ooooo`Ko0000O_oo
ool001cooooo00?o0000ooooooooool0Coooool3o`0000?ooooo0_l0000Zooooo`;o00000oooool6
o`0000?ooooo0ol00004ooooo`?o00000oooool5o`000004ooooool0003o0000o`0000Gooooo0_l0
0002ooooo`Co00000oooool6o`0000Gooooo0_l00002ooooo`Co0000POooool001cooooo00?o0000
ooooooooool0EOooool2o`0000?ooooo0_l0000Uooooo`;o00001Oooool3o`0000Cooooo0ol00004
ooooo`?o00000_ooool3o`000004ooooool0003o0000ooooo`?o00000_ooool4o`0000?ooooo1_l0
00000ooooooo0000o`000003o`0000Kooooo0_l00002ooooo`;o0000Poooool001cooooo00?o0000
ooooooooool0F_ooool5o`0001oooooo0_l00005ooooo`;o00002?ooool2o`0000;ooooo0_l00005
ooooo`?o00000_ooool2o`0000;ooooo2?l00003ooooo`?o000000?oooooo`000?l000001?l0000;
ooooo`;o0000:Oooool2o`0000;ooooo0ol0001Dooooo`007?ooool00ol0003oooooooooo`1Eoooo
o`;o00001Oooool3o`0001oooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l000001?oo
oooo0000o`000?l00006ooooo`Co00000oooool3o`0000?ooooo0_l000000ooooooo0000o`000005
o`0000Gooooo0ol00002ooooo`?o00001_ooool2o`0000?ooooo0ol0000Uooooo`;o00000_ooool2
o`000003ooooool0003o000000;o0000E?ooool001cooooo00?o0000ooooooooool0EOooool3o`00
00[ooooo0ol0000Mooooo`;o00000_ooool3o`000004ooooool0003o0000o`0000Sooooo0_l00004
ooooo`;o00000oooool2o`0000Kooooo0_l00005ooooo`?o00000_ooool;o`000003ooooool0003o
000000;o00009_ooool2o`000003ooooool0003o000000;ooooo0_l0001Fooooo`007?ooool00ol0
003oooooooooo`1Fooooo`;o00002_ooool3o`00027ooooo0_l00007ooooo`;o00000oooool2o`00
00;ooooo0_l0000>ooooo`;o00001_ooool3o`000003ooooool0003o000000Oo000000?oooooo`00
0?l000000_l0000[ooooo`;o0000F_ooool001cooooo00?o0000ooooooooool0F?ooool4o`0000;o
oooo0_l00006ooooo`;o00000oooool2o`0001?ooooo0_l00002ooooo`;o00001Oooool6o`0000?o
oooo0_l00002ooooo`Co00003?ooool2o`0000Oooooo1_l00003ooooo`;o00000_ooool3o`0002Oo
oooo0_l00004ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0F?ooool5o`000003oooo
ool0003o000000Kooooo0_l00003ooooo`?o00004_ooool2o`0000;ooooo0_l00005ooooo`Ko0000
1oooool4o`0001Kooooo2_l00002ooooo`;o00009oooool3o`0000Cooooo0_l0001Iooooo`007?oo
ool00ol0003oooooooooo`1Hooooo`Go00001Oooool2o`0000?ooooo0_l00003ooooo`;o00002Ooo
ool2o`0000kooooo0_l0000?ooooo`Co00001oooool4o`0000?ooooo0_l0000;ooooo`Go00009ooo
ool2o`0000;ooooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`1Jooooo`?o00001Oooool2
o`0000?ooooo0_l00008ooooo`;o00001?ooool2o`0000kooooo0_l0000?ooooo`Go00001?ooool7
o`000004ooooool0003o0000o`0003Oooooo0_l00002ooooo`Co0000G_ooool001cooooo00?o0000
ooooooooool0Foooool2o`000004ooooool0003o0000ooooo`;o00000oooool2o`0000Sooooo0ol0
000Vooooo`Co00001?ooool4o`000004ooooool0003o0000ooooo`Go0000<oooool4o`0000;ooooo
1?l0001Nooooo`007?ooool2o`0005oooooo1Ol00003ooooo`;o00001oooool4o`0001Gooooo0_l0
000@ooooo`Co00001Oooool2o`0000Kooooo1Ol0000aooooo`;o00001Oooool2o`0005oooooo000L
ooooo`03o`000?oooooooooo063ooooo0_l00004ooooo`;o00000_ooool3o`000004ooooool0003o
0000o`0001Oooooo0_l0000@ooooo`Go00003?ooool2o`000003ooooool0003o0000033ooooo1?l0
0003ooooo`?o0000Goooool001cooooo00?o0000ooooooooool0J_ooool6o`0002_ooooo1Ol00004
ooooo`?o0000>Oooool6o`000003ooooool0003o0000063ooooo000Looooo`03o`000?oooooooooo
06cooooo0_l00005ooooo`;o000000?oooooo`000?l000001?ooool2o`0001kooooo1?l00004oooo
o`?o00009Oooool3o`0001Cooooo0ol0001Sooooo`007?ooool00ol0003oooooooooo`1Wooooo`;o
00001oooool2o`000004ooooool0003o0000ooooo`;o00001?ooool2o`0001kooooo2?l00003oooo
o`;o00004?ooool2o`0000Gooooo0_l00005ooooo`;o00000_ooool4o`0000kooooo0_l00002oooo
o`;o0000I_ooool001cooooo00?o0000ooooooooool0Ioooool2o`0000Oooooo0_l0000:ooooo`?o
00007Oooool2o`000003ooooool0003o000000Co000000Coooooo`000?l0003o00002oooool3o`00
00;ooooo0_l000000ooooooo0000o`000002ooooo`;o00001Oooool3o`000003ooooool0003o0000
00kooooo1?l00002ooooo`;o0000I_ooool001cooooo00?o0000ooooooooool0KOooool2o`0000Go
oooo0_l00006ooooo`Co00008?ooool8o`0000Sooooo0_l00002ooooo`?o00001Oooool2o`0000[o
oooo0_l0000>ooooo`;o000000?oooooo`000?l00000K?ooool001cooooo00?o0000ooooooooool0
KOooool2o`0000Gooooo0_l00006ooooo`Co00008?ooool7o`0000Wooooo0_l00009ooooo`;o0000
1oooool3o`00017ooooo0_l0001_ooooo`007?ooool00ol0003oooooooooo`1]ooooo`;o00000ooo
ool2o`0001Wooooo0_l000000ooooooo0000o`000007ooooo`;o00001Oooool7o`0001;ooooo1Ol0
00000ooooooo0000o`000008o`00017ooooo0_l000000ooooooo0000o`00001Zooooo`007?ooool0
0ol0003oooooooooo`1aooooo`?o00001Oooool2o`0001;ooooo0_l000000ooooooo0000o`000004
ooooo`;o000000?oooooo`000?l000002Oooool9o`0000;ooooo0ol00002oooooa;o000000?ooooo
o`000?l000002oooool2o`0000Cooooo0_l000000ooooooo0000o`00001Zooooo`007?ooool00ol0
003oooooooooo`1aooooo`?o00001?ooool4o`0001[ooooo0_l00005ooooo`;o00001Oooool2o`00
0003ooooool0003o000001[o00004?ooool3o`0007?ooooo000Looooo`03o`000?oooooooooo077o
oooo0_l00002ooooo`;o000000?oooooo`000?l000000_l0000=ooooo`;o00003Oooool2o`0000?o
oooo0_l0000:ooooo`go00007Oooool2o`000003ooooool0003o0000077ooooo000Looooo`03o`00
0?oooooooooo07?ooooo1?l0000@ooooo`Co00002oooool4o`0001Gooooo0_l00003ooooo`;o0000
5oooool2o`0000Gooooo1_l0001_ooooo`007?ooool00ol0003oooooooooo`1cooooo`?o00004Ooo
ool2o`0000_ooooo1?l000001?oooooo0000o`000?ooool2o`0002oooooo0_l00002ooooo`;o0000
00?oooooo`000?l000000_ooool2o`0006oooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGo
oooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1doooo
o`;o00000oooool2o`0000cooooo0_l00004ooooo`;o00001Oooool3o`0000;ooooo0_l000000ooo
oooo0000o`000008ooooo`;o0000:Oooool2o`0007Kooooo00001_ooooooMgMgoiRHV?ooooooV9RH
ogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003ooooooooo
o`1dooooo`;o000000?oooooo`000?l000001?l00003ooooo`;o00001Oooool2o`0000Cooooo0_l0
0005ooooo`?o00003oooool2o`0001kooooo0_l00004ooooo`;o0000Noooool00003ooooool@413o
oooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool0Moooool2o`0000;ooooo0_l00003ooooo`Co00004Oooool2o`0000oooooo0ol0
0003ooooo`;o00004?ooool2o`0000Gooooo2Ol00004ooooo`;o0000MOooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool02Oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0
001gooooo`;o00001?ooool2o`000003ooooool0003o000000;o00008?ooool5o`0000?ooooo0_l0
0005ooooo`;o00002Oooool2o`0000Gooooo0_l000000ooooooo0000o`000003o`0000?ooooo1?l0
001eooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05olc<c?l0003o
0000o`000?o<c<`01_ooool00ol0003oooooooooo`1kooooo`Oo00001_ooool2o`00017ooooo0_l0
0007ooooo`;o00003Oooool2o`0000;ooooo0_l0000Gooooo`;o0000Moooool00003ooooool@413o
oooo00;ooooo00?o410@ooooooooool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o
0000ooooooooool0NOooool9o`0000?ooooo1Ol0000Aooooo`;o00004_ooool2o`0000Kooooo1?l0
00000ooooooo0000o`00002;ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`00
0?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`1iooooo`;o00000_ooool2o`0000Co
oooo1_l00002ooooo`;o00004_ooool2o`0000kooooo0_l00003ooooo`;o00000oooool2o`000003
ooooool0003o000008_ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@
4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo07gooooo0_l00002ooooo`So00000_ooool2
o`0000Sooooo0_l00008ooooo`Co00002?ooool2o`0000Oooooo0_l0000@ooooo`;o0000POooool0
01cooooo00?o0000ooooooooool0OOooool2o`0000;ooooo0_l00002ooooo`Co00001_ooool2o`00
00Cooooo0_l0000:ooooo`;o00000oooool3o`0000;ooooo0_l0000?ooooo`;o000000Coooooo`00
0?l0003ooooo0_l00002ooooo`;o0000POooool001cooooo00?o0000ooooooooool0O_ooool2o`00
00Cooooo0_l00009ooooo`;o00000_ooool2o`000003ooooool0003o000000kooooo0ol0000:oooo
o`;o000000?oooooo`000?l000001?ooool5o`000003ooooool0003o000008Gooooo000Looooo`03
o`000?oooooooooo07kooooo0_l00004ooooo`;o00002Oooool2o`0000;ooooo1Ol0000>ooooo`;o
00001?ooool2o`0000Gooooo0_l000000ooooooo0000o`000006ooooo`;o00000_ooool2o`0008Go
oooo000Looooo`03o`000?oooooooooo083ooooo0_l00003ooooo`;o00002?ooool2o`0000?ooooo
0_l0000Fooooo`;o0000Voooool001cooooo00?o0000ooooooooool0P?ooool4o`000003ooooool0
003o000000cooooo0_l00006ooooo`;o0000[?ooool001cooooo00?o0000ooooooooool0P_ooool2
o`000003ooooool0003o000000cooooo0_l00006ooooo`;o0000[?ooool001cooooo00?o0000oooo
ooooool0QOooool2o`0000kooooo1?l0002`ooooo`007?ooool00ol0003oooooooooo`2Cooooo`Oo
0000[oooool001cooooo00?o0000ooooooooool0S?ooool2o`0000Gooooo0ol00002ooooo`?o0000
[_ooool001cooooo00?o0000ooooooooool0S?ooool2o`000004ooooool0003o0000o`0000;ooooo
0_l00003ooooo`;o00000_ooool4o`0000Kooooo0_l0002Pooooo`007?ooool00ol0003ooooooooo
o`2?ooooo`?o00002oooool8o`0000;ooooo0ol0002Oooooo`007?ooool2o`00093ooooo0_l00000
0ooooooo0000o`00000=ooooo`Co00000oooool2o`0009oooooo000Looooo`03o`000?oooooooooo
09;ooooo0_l0000?ooooo`;o00000_ooool2o`0000Oooooo0_l0002Gooooo`007?ooool00ol0003o
ooooooooo`2Wooooo`;o00001oooool2o`0009Oooooo000Looooo`03o`000?oooooooooo0;3ooooo
0_l0002Gooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001;ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood[o
oooo000Dooooo`03o`000?oooooooooo00Gooooo0ol0003ooooood[ooooo000Dooooo`03o`000?oo
oooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0
003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001;ooooo
00?oEEEEofIVI_l00000oooooomDooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00YOooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo01Gooooo1Ol00003oooo
o`05oiRHV?l@413o0000oc8b<_o<c<`01Oooool2o`000003oa0@4?oooooooooo08kooooo002Voooo
o`05o`000?ooooooooooooooool000002Oooool6o`0000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4
A003ooooo`05oa0@4?nj^[[oooooogMgMolb<S801_ooool00ol0003oooooooooo`2?ooooo`00Y_oo
ool01Ol0003ooooooooooooooooo000001Wooooo00?oV9RHob4Q8Oo^k^h02?ooool01?l0003ooooo
ooooooooool5o`00093ooooo002Vooooo`05o`000?ooooooooooooooool000002Oooool6o`0000_o
oooo00?oV9RHob4Q8Oo^k^h01_ooool00onYZJWo410@ooooo`02ooooo`04odA4A?oMgMgoooooo`00
097ooooo002Vooooo`05o`000?n7QhOoooooojVYZOl000006oooool00omgMgOoIVIVooooo`04oooo
o`03oa0@4?l0003o^[Zj00?ooooo00CogMgMoeEEEOoooooo0000TOooool00:Gooooo00?o410@o`00
0?mgMgL00_l000000onHV9Soooooooooo`0Jooooo`03o`000?oooooooooo00Cooooo00?o^[Zjob4Q
8Oooool00oooool00omgMgOoc<c<o`00002Aooooo`00`oooool01Ol0003o^[ZjoooooonHV9So410@
00?ooooo00Go410@oiRHV?oooooo^[Zjo`000004ooooo`03onk^k_m4A4Co0000097ooooo0033oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01OnYZJWo410@o`000?l@413oZJVY00Gooooo00?o
MgMgo`000?ooool0T?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(240) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.57273 .30536 Mdot
.56445 .33118 Mdot
.31073 .52788 Mdot
.62478 .53642 Mdot
.38561 .66536 Mdot
.26521 .54867 Mdot
.36164 .35259 Mdot
.37242 .35547 Mdot
.28223 .48861 Mdot
.75777 .50576 Mdot
.37489 .33473 Mdot
.6391 .58363 Mdot
.36297 .36646 Mdot
.64712 .53319 Mdot
.52373 .69472 Mdot
.63279 .49098 Mdot
.5445 .30294 Mdot
.43755 .63764 Mdot
.62855 .49272 Mdot
.26058 .49379 Mdot
.47362 .52135 Mdot
.65315 .54477 Mdot
.59423 .36382 Mdot
.64996 .53292 Mdot
.60632 .53898 Mdot
.56058 .33911 Mdot
.57348 .30627 Mdot
.60721 .57814 Mdot
.61994 .5402 Mdot
.34635 .32952 Mdot
.64653 .62358 Mdot
.55806 .78976 Mdot
.46388 .60782 Mdot
.73196 .4049 Mdot
.3383 .34028 Mdot
.33258 .31942 Mdot
.29412 .53877 Mdot
.33426 .34193 Mdot
.39236 .35369 Mdot
.37767 .34439 Mdot
.37384 .34147 Mdot
.55678 .3373 Mdot
.33284 .3632 Mdot
.20001 .38168 Mdot
.65683 .52538 Mdot
.71715 .30228 Mdot
.3213 .49622 Mdot
.63517 .57658 Mdot
.58459 .36611 Mdot
.29052 .48254 Mdot
.45052 .744 Mdot
.37876 .36645 Mdot
.48188 .57538 Mdot
.65742 .18887 Mdot
.3691 .36005 Mdot
.61516 .50855 Mdot
.2604 .52127 Mdot
.66426 .50495 Mdot
.67412 .55576 Mdot
.71097 .36397 Mdot
.65355 .50359 Mdot
.41676 .64524 Mdot
.51767 .29964 Mdot
.30431 .48295 Mdot
.29039 .49011 Mdot
.33189 .35748 Mdot
.53235 .30115 Mdot
.3411 .35858 Mdot
.62323 .54786 Mdot
.26137 .49944 Mdot
.61294 .54503 Mdot
.37382 .33375 Mdot
.56875 .30742 Mdot
.65141 .5535 Mdot
.50038 .34609 Mdot
.31438 .34883 Mdot
.43595 .6674 Mdot
.61933 .32656 Mdot
.27328 .47229 Mdot
.54384 .67388 Mdot
.65312 .55052 Mdot
.31941 .24181 Mdot
.52392 .74227 Mdot
.59137 .34625 Mdot
.66508 .47991 Mdot
.40574 .21727 Mdot
.61288 .56909 Mdot
.64541 .61969 Mdot
.61541 .59439 Mdot
.46313 .66504 Mdot
.25621 .52472 Mdot
.56414 .36027 Mdot
.66118 .53913 Mdot
.6304 .56167 Mdot
.76196 .48692 Mdot
.62033 .51987 Mdot
.61129 .58427 Mdot
.50125 .58428 Mdot
.38355 .36922 Mdot
.4727 .59564 Mdot
.3295 .44681 Mdot
.46705 .58083 Mdot
.61159 .55225 Mdot
.26917 .53791 Mdot
.51601 .30793 Mdot
.46369 .60175 Mdot
.34094 .35035 Mdot
.65849 .53838 Mdot
.33819 .41687 Mdot
.58862 .36451 Mdot
.60211 .54045 Mdot
.40147 .6551 Mdot
.44995 .50174 Mdot
.5804 .31831 Mdot
.79797 .41461 Mdot
.62989 .53503 Mdot
.67535 .52491 Mdot
.56125 .32993 Mdot
.24656 .51182 Mdot
.27499 .30988 Mdot
.55604 .30973 Mdot
.386 .36154 Mdot
.53866 .30441 Mdot
.47642 .60651 Mdot
.25302 .50053 Mdot
.4856 .55211 Mdot
.51046 .55488 Mdot
.51444 .7846 Mdot
.62793 .52202 Mdot
.48173 .53187 Mdot
.27513 .54059 Mdot
.55953 .31213 Mdot
.35949 .37404 Mdot
.68583 .51427 Mdot
.57669 .35076 Mdot
.36508 .35029 Mdot
.42928 .66511 Mdot
.43188 .62887 Mdot
.59117 .33541 Mdot
.79575 .40284 Mdot
.35703 .39705 Mdot
.36654 .38872 Mdot
.45256 .74405 Mdot
.59122 .34399 Mdot
.42052 .66186 Mdot
.34501 .35229 Mdot
.22826 .66756 Mdot
.60891 .5146 Mdot
.46695 .7677 Mdot
.32238 .24443 Mdot
.45035 .7432 Mdot
.49256 .51918 Mdot
.40862 .66256 Mdot
.36531 .34995 Mdot
.65384 .56297 Mdot
.58279 .33675 Mdot
.57347 .34873 Mdot
.61553 .55195 Mdot
.46016 .59389 Mdot
.644 .52303 Mdot
.47923 .59709 Mdot
.50939 .54705 Mdot
.65983 .53501 Mdot
.71714 .27693 Mdot
.58548 .35552 Mdot
.67197 .48675 Mdot
.29497 .53169 Mdot
.45694 .56877 Mdot
.335 .36753 Mdot
.68051 .50915 Mdot
.64735 .46724 Mdot
.6399 .58505 Mdot
.37454 .38942 Mdot
.50938 .25421 Mdot
.28069 .47001 Mdot
.38505 .34713 Mdot
.32553 .43631 Mdot
.28453 .52595 Mdot
.66491 .5628 Mdot
.39874 .66459 Mdot
.48818 .58161 Mdot
.64573 .56226 Mdot
.44653 .74233 Mdot
.67488 .55352 Mdot
.51607 .50742 Mdot
.52823 .52157 Mdot
.36651 .23684 Mdot
.52064 .25321 Mdot
.62752 .5482 Mdot
.61566 .46682 Mdot
.46507 .7585 Mdot
.37835 .29479 Mdot
.3565 .37473 Mdot
.24413 .53984 Mdot
.24254 .52299 Mdot
.30357 .38285 Mdot
.77849 .42199 Mdot
.77724 .54237 Mdot
.67002 .49588 Mdot
.47207 .58064 Mdot
.57332 .29458 Mdot
.41038 .66132 Mdot
.57845 .32045 Mdot
.31379 .24242 Mdot
.5839 .66275 Mdot
.6616 .63235 Mdot
.1984 .51986 Mdot
.30147 .48882 Mdot
.46805 .57484 Mdot
.41569 .672 Mdot
.65812 .51208 Mdot
.59181 .35851 Mdot
.46162 .7531 Mdot
.45884 .58521 Mdot
.73113 .74776 Mdot
.55375 .30631 Mdot
.58998 .70647 Mdot
.36655 .36033 Mdot
.27922 .50495 Mdot
.61215 .56598 Mdot
.63868 .54284 Mdot
.57118 .36786 Mdot
.66046 .56155 Mdot
.67863 .63396 Mdot
.60535 .52865 Mdot
.278 .47996 Mdot
.33615 .46409 Mdot
.39165 .36095 Mdot
.20308 .52385 Mdot
.58139 .31845 Mdot
.72297 .26172 Mdot
.27226 .52401 Mdot
.51594 .51574 Mdot
.36825 .33114 Mdot
.431 .65657 Mdot
.26664 .52945 Mdot
.38548 .65935 Mdot
.6837 .54328 Mdot
.29366 .51694 Mdot
.40779 .64744 Mdot
.67756 .59875 Mdot
.46394 .60058 Mdot
.45414 .80117 Mdot
.35523 .34935 Mdot
.54505 .34104 Mdot
.64901 .56251 Mdot
.48059 .58174 Mdot
.45801 .58394 Mdot
.55871 .7041 Mdot
.50398 .55375 Mdot
.46364 .57503 Mdot
.50526 .68205 Mdot
.43611 .65042 Mdot
.48817 .21255 Mdot
.63775 .61891 Mdot
.54614 .30206 Mdot
.6345 .56317 Mdot
.32195 .42309 Mdot
.3626 .34751 Mdot
.65596 .50919 Mdot
.35195 .23871 Mdot
.34715 .35529 Mdot
.67162 .51564 Mdot
.38258 .33836 Mdot
.58362 .35052 Mdot
.59832 .67455 Mdot
.55737 .30074 Mdot
.66314 .53305 Mdot
.3786 .33493 Mdot
.24608 .54425 Mdot
.56229 .34056 Mdot
.65686 .54144 Mdot
.6427 .5062 Mdot
.47528 .57783 Mdot
.60682 .52215 Mdot
.34436 .29469 Mdot
.62749 .57859 Mdot
.30027 .54878 Mdot
.6198 .52718 Mdot
.41649 .61947 Mdot
.3154 .71033 Mdot
.59292 .34037 Mdot
.5026 .55338 Mdot
.26255 .52636 Mdot
.68441 .61784 Mdot
.60007 .70318 Mdot
.65456 .52764 Mdot
.4875 .55554 Mdot
.56648 .74882 Mdot
.36423 .38487 Mdot
.61249 .59419 Mdot
.48111 .628 Mdot
.25636 .52963 Mdot
.46904 .57913 Mdot
.65625 .48048 Mdot
.60949 .35393 Mdot
.6256 .49728 Mdot
.28816 .5154 Mdot
.54373 .30721 Mdot
.6174 .51885 Mdot
.33578 .31048 Mdot
.47255 .55244 Mdot
.37423 .38503 Mdot
.6239 .60715 Mdot
.66074 .56523 Mdot
.26476 .49586 Mdot
.55567 .33942 Mdot
.37119 .35851 Mdot
.57764 .31391 Mdot
.45917 .71312 Mdot
.57953 .72407 Mdot
.50564 .32911 Mdot
.42539 .67512 Mdot
.26497 .7165 Mdot
.38604 .35463 Mdot
.49336 .58437 Mdot
.30418 .55184 Mdot
.6151 .34479 Mdot
.26489 .53762 Mdot
.78902 .39115 Mdot
.25775 .52225 Mdot
.62333 .49184 Mdot
.2469 .53117 Mdot
.79016 .51756 Mdot
.68176 .52928 Mdot
.29763 .49326 Mdot
.50336 .58188 Mdot
.67906 .51238 Mdot
.57514 .35117 Mdot
.58348 .78984 Mdot
.7591 .41971 Mdot
.77971 .42827 Mdot
.26408 .51811 Mdot
.78618 .38154 Mdot
.60292 .54066 Mdot
.61862 .60096 Mdot
.57857 .33537 Mdot
.49155 .58516 Mdot
.41348 .6302 Mdot
.40146 .63202 Mdot
.362 .7392 Mdot
.62343 .71355 Mdot
.79782 .42559 Mdot
.57346 .34627 Mdot
.32382 .46366 Mdot
.50096 .34475 Mdot
.4596 .58311 Mdot
.37249 .35526 Mdot
.49973 .25777 Mdot
.62432 .5935 Mdot
.52621 .54175 Mdot
.68047 .63308 Mdot
.54341 .33555 Mdot
.51048 .32372 Mdot
.37148 .35713 Mdot
.78156 .43038 Mdot
.75685 .51229 Mdot
.64567 .51996 Mdot
.36715 .34539 Mdot
.45811 .58516 Mdot
.64814 .61633 Mdot
.51516 .79043 Mdot
.16347 .479 Mdot
.66135 .5278 Mdot
.48031 .30271 Mdot
.64879 .56159 Mdot
.50379 .782 Mdot
.66175 .51215 Mdot
.55915 .34534 Mdot
.60039 .56834 Mdot
.64355 .61214 Mdot
.18455 .59687 Mdot
.5767 .66083 Mdot
.38839 .66348 Mdot
.64749 .53666 Mdot
.63838 .52741 Mdot
.42578 .65405 Mdot
.55731 .35176 Mdot
.62704 .56803 Mdot
.50102 .21281 Mdot
.66022 .5419 Mdot
.33757 .37057 Mdot
.53407 .71467 Mdot
.55459 .78825 Mdot
.60366 .54222 Mdot
.60972 .35416 Mdot
.36915 .38806 Mdot
.35732 .33207 Mdot
.50202 .56174 Mdot
.36159 .34669 Mdot
.66241 .55647 Mdot
.53542 .71485 Mdot
.52867 .30215 Mdot
.46194 .59019 Mdot
.548 .34049 Mdot
.30042 .57858 Mdot
.35664 .35122 Mdot
.48348 .56603 Mdot
.77063 .40976 Mdot
.34879 .36357 Mdot
.36337 .51902 Mdot
.60121 .55507 Mdot
.4587 .58256 Mdot
.58963 .32031 Mdot
.25929 .50305 Mdot
.4722 .56269 Mdot
.36945 .35918 Mdot
.65548 .52581 Mdot
.61215 .51348 Mdot
.36178 .34591 Mdot
.62484 .29923 Mdot
.64508 .62356 Mdot
.66381 .54022 Mdot
.57493 .35526 Mdot
.55433 .31621 Mdot
.67656 .49511 Mdot
.64321 .5652 Mdot
.26309 .54994 Mdot
.48888 .55476 Mdot
.48819 .55401 Mdot
.50867 .55221 Mdot
.26997 .51052 Mdot
.23486 .69018 Mdot
.351 .38533 Mdot
.5579 .78815 Mdot
.45548 .32651 Mdot
.48423 .57703 Mdot
.26912 .55326 Mdot
.63351 .5392 Mdot
.6186 .57272 Mdot
.36999 .3278 Mdot
.35558 .79099 Mdot
.63134 .59677 Mdot
.55456 .30219 Mdot
.37435 .35221 Mdot
.65158 .46354 Mdot
.30956 .40653 Mdot
.40261 .63959 Mdot
.79883 .421 Mdot
.37667 .35652 Mdot
.53475 .34571 Mdot
.37737 .35766 Mdot
.63952 .52725 Mdot
.65822 .48187 Mdot
.54056 .32775 Mdot
.3887 .67022 Mdot
.61861 .55634 Mdot
.66987 .51658 Mdot
.3069 .44886 Mdot
.50429 .35527 Mdot
.3897 .63872 Mdot
.62681 .57444 Mdot
.48854 .59601 Mdot
.39055 .67843 Mdot
.66789 .54388 Mdot
.61676 .53422 Mdot
.48638 .5285 Mdot
.34401 .32267 Mdot
.4114 .68738 Mdot
.1866 .61454 Mdot
.55552 .30555 Mdot
.35349 .29076 Mdot
.4697 .55959 Mdot
.38509 .35238 Mdot
.69774 .62613 Mdot
.47583 .56802 Mdot
.45266 .30896 Mdot
.88283 .50853 Mdot
.47322 .56378 Mdot
.27662 .55638 Mdot
.76277 .47789 Mdot
.61701 .53933 Mdot
.66496 .53924 Mdot
.41709 .62994 Mdot
.5623 .32165 Mdot
.51926 .25384 Mdot
.38614 .34746 Mdot
.63865 .55166 Mdot
.58786 .32393 Mdot
.37793 .22942 Mdot
.47414 .57446 Mdot
.39465 .6541 Mdot
.41548 .68248 Mdot
.66051 .5525 Mdot
.5875 .73433 Mdot
.56388 .34284 Mdot
.6569 .54117 Mdot
.67594 .53364 Mdot
.25131 .55281 Mdot
.59355 .34685 Mdot
.29262 .51982 Mdot
.6199 .60588 Mdot
.80561 .4983 Mdot
.32732 .43391 Mdot
.34843 .35182 Mdot
.49651 .5574 Mdot
.39209 .36362 Mdot
.31934 .50426 Mdot
.48956 .55425 Mdot
.65573 .54142 Mdot
.52696 .30303 Mdot
.65789 .54063 Mdot
.66069 .54114 Mdot
.65681 .52136 Mdot
.79917 .42578 Mdot
.2753 .4707 Mdot
.39502 .66072 Mdot
.64388 .5756 Mdot
.28333 .51104 Mdot
.30345 .40023 Mdot
.75861 .5 Mdot
.64485 .54149 Mdot
.67467 .52328 Mdot
.60578 .33819 Mdot
.61033 .51058 Mdot
.35053 .36076 Mdot
.54134 .33244 Mdot
.61045 .54875 Mdot
.27432 .46413 Mdot
.62977 .57033 Mdot
.50704 .32479 Mdot
.34378 .37485 Mdot
.70481 .47493 Mdot
.45437 .59161 Mdot
.49405 .55297 Mdot
.47126 .5643 Mdot
.50709 .55061 Mdot
.33439 .36484 Mdot
.27898 .55456 Mdot
.1986 .53513 Mdot
.65252 .58776 Mdot
.65382 .56405 Mdot
.65937 .48112 Mdot
.27029 .56409 Mdot
.50087 .5867 Mdot
.78008 .39429 Mdot
.6507 .46153 Mdot
.2767 .50034 Mdot
.5101 .56712 Mdot
.61929 .38188 Mdot
.54809 .34367 Mdot
.30247 .47624 Mdot
.35236 .33028 Mdot
.40704 .64463 Mdot
.39934 .76971 Mdot
.54745 .31949 Mdot
.58754 .30059 Mdot
.28726 .5377 Mdot
.54948 .72093 Mdot
.65211 .18144 Mdot
.2653 .54323 Mdot
.6675 .63208 Mdot
.57985 .34142 Mdot
.47427 .60282 Mdot
.56023 .75028 Mdot
.53844 .72186 Mdot
.28578 .49306 Mdot
.64077 .50766 Mdot
.26282 .58104 Mdot
.25776 .54883 Mdot
.49682 .57131 Mdot
.26572 .51688 Mdot
.36834 .38587 Mdot
.27565 .53653 Mdot
.59841 .3706 Mdot
.62614 .52908 Mdot
.65526 .1865 Mdot
.49929 .72189 Mdot
.62815 .54353 Mdot
.36681 .38209 Mdot
.35069 .30085 Mdot
.64787 .5149 Mdot
.39844 .63668 Mdot
.27847 .55602 Mdot
.3481 .5227 Mdot
.62382 .4954 Mdot
.24775 .52716 Mdot
.6115 .35112 Mdot
.34003 .48112 Mdot
.32904 .44578 Mdot
.47565 .56014 Mdot
.58583 .34867 Mdot
.31354 .35514 Mdot
.38598 .36356 Mdot
.47554 .54899 Mdot
.67426 .54799 Mdot
.58271 .36012 Mdot
.68309 .60796 Mdot
.54318 .54099 Mdot
.65867 .54319 Mdot
.29093 .52381 Mdot
.28958 .4804 Mdot
.52005 .69987 Mdot
.27315 .5216 Mdot
.4982 .57009 Mdot
.58078 .35651 Mdot
.62688 .49327 Mdot
.55575 .3122 Mdot
.63442 .56425 Mdot
.31523 .41067 Mdot
.55806 .35727 Mdot
.51635 .51588 Mdot
.6591 .49855 Mdot
.71679 .28324 Mdot
.63916 .57924 Mdot
.66281 .54143 Mdot
.27105 .48565 Mdot
.42492 .65744 Mdot
.53615 .54115 Mdot
.30511 .39516 Mdot
.41679 .63997 Mdot
.62818 .32304 Mdot
.24752 .50919 Mdot
.42975 .65722 Mdot
.36683 .74851 Mdot
.50147 .55234 Mdot
.40466 .68202 Mdot
.66725 .48203 Mdot
.34978 .34856 Mdot
.52392 .31141 Mdot
.67929 .51151 Mdot
.79999 .49916 Mdot
.64187 .6236 Mdot
.47756 .5744 Mdot
.66756 .5382 Mdot
.6337 .53136 Mdot
.58637 .3222 Mdot
.31423 .24438 Mdot
.31571 .51852 Mdot
.48079 .5934 Mdot
.54945 .31253 Mdot
.32145 .24162 Mdot
.29554 .49393 Mdot
.43149 .63572 Mdot
.39432 .36219 Mdot
.5238 .34291 Mdot
.47942 .57713 Mdot
.35893 .35015 Mdot
.24638 .57015 Mdot
.44577 .73773 Mdot
.6248 .49943 Mdot
.28644 .54695 Mdot
.44956 .74289 Mdot
.60062 .55804 Mdot
.30202 .37807 Mdot
.38709 .29955 Mdot
.582 .3651 Mdot
.36358 .34589 Mdot
.39152 .65785 Mdot
.54545 .29841 Mdot
.54851 .34182 Mdot
.34515 .35708 Mdot
.77762 .3319 Mdot
.56717 .74733 Mdot
.39375 .35089 Mdot
.55479 .69782 Mdot
.44917 .74038 Mdot
.47715 .57996 Mdot
.39742 .66114 Mdot
.33591 .46333 Mdot
.55712 .33711 Mdot
.4953 .26623 Mdot
.44984 .74471 Mdot
.6029 .56713 Mdot
.41008 .64557 Mdot
.38153 .23089 Mdot
.35098 .40288 Mdot
.35302 .35628 Mdot
.30879 .448 Mdot
.42037 .6439 Mdot
.6801 .50621 Mdot
.37745 .81454 Mdot
.68059 .53162 Mdot
.34505 .35048 Mdot
.67979 .63334 Mdot
.5748 .32001 Mdot
.34898 .38184 Mdot
.67802 .63507 Mdot
.62554 .57521 Mdot
.63075 .52857 Mdot
.27083 .47223 Mdot
.56459 .36529 Mdot
.46286 .56571 Mdot
.62875 .5468 Mdot
.66887 .50993 Mdot
.45688 .59974 Mdot
.54773 .78718 Mdot
.46347 .48765 Mdot
.4643 .60593 Mdot
.2905 .50351 Mdot
.46169 .59276 Mdot
.48313 .59131 Mdot
.60107 .33511 Mdot
.32263 .45095 Mdot
.46088 .57401 Mdot
.66443 .52976 Mdot
.66379 .53563 Mdot
.39401 .35754 Mdot
.56558 .74898 Mdot
.54592 .72359 Mdot
.30857 .54033 Mdot
.46055 .62961 Mdot
.63728 .50517 Mdot
.58863 .34821 Mdot
.38224 .68586 Mdot
.50217 .56605 Mdot
.55202 .30378 Mdot
.62329 .53242 Mdot
.25232 .55435 Mdot
.47704 .56196 Mdot
.461 .61217 Mdot
.40886 .65089 Mdot
.39234 .3762 Mdot
.62147 .31446 Mdot
.26291 .5521 Mdot
.60704 .53899 Mdot
.46911 .62916 Mdot
.25074 .52991 Mdot
.4755 .58122 Mdot
.46385 .59615 Mdot
.58133 .34968 Mdot
.54219 .35549 Mdot
.4902 .60019 Mdot
.27434 .51001 Mdot
.16948 .43934 Mdot
.38192 .36075 Mdot
.65523 .56891 Mdot
.38853 .37664 Mdot
.59118 .36399 Mdot
.51293 .78537 Mdot
.42465 .6702 Mdot
.34936 .35798 Mdot
.45974 .58486 Mdot
.55197 .34917 Mdot
.58885 .36776 Mdot
.66001 .53348 Mdot
.6504 .5436 Mdot
.31702 .47965 Mdot
.46827 .76457 Mdot
.37392 .32953 Mdot
.42128 .63259 Mdot
.31188 .52894 Mdot
.61829 .50281 Mdot
.58472 .33312 Mdot
.49304 .82067 Mdot
.65489 .57011 Mdot
.28042 .51131 Mdot
.56621 .33363 Mdot
.4135 .63127 Mdot
.39437 .66348 Mdot
.63556 .55781 Mdot
.49407 .51931 Mdot
.34641 .36277 Mdot
.57001 .35003 Mdot
.55351 .27118 Mdot
.63597 .57865 Mdot
.6481 .54033 Mdot
.60058 .55314 Mdot
.39598 .35613 Mdot
.67345 .49077 Mdot
.38922 .66951 Mdot
.58557 .32627 Mdot
.63631 .55463 Mdot
.42137 .64663 Mdot
.48752 .54781 Mdot
.47766 .56492 Mdot
.2861 .48551 Mdot
.39954 .63463 Mdot
.42135 .65459 Mdot
.41844 .63796 Mdot
.49925 .25788 Mdot
.68552 .49091 Mdot
.5102 .58492 Mdot
.64285 .50534 Mdot
.44902 .73915 Mdot
.63666 .49152 Mdot
.37828 .37547 Mdot
.26721 .49397 Mdot
.652 .52046 Mdot
.64657 .50306 Mdot
.62277 .32942 Mdot
.63217 .48773 Mdot
.67711 .49673 Mdot
.57902 .32303 Mdot
.56506 .27524 Mdot
.24208 .52963 Mdot
.32501 .24433 Mdot
.4314 .84457 Mdot
.68723 .52749 Mdot
.54575 .71846 Mdot
.55814 .35402 Mdot
.39429 .36009 Mdot
.55727 .70629 Mdot
.38377 .38621 Mdot
.55571 .32056 Mdot
.62708 .487 Mdot
.61152 .27685 Mdot
.41558 .64167 Mdot
.64162 .52643 Mdot
.34508 .36626 Mdot
.64275 .52466 Mdot
.35342 .38266 Mdot
.77439 .36814 Mdot
.53699 .74914 Mdot
.68122 .54104 Mdot
.61989 .52152 Mdot
.46486 .52694 Mdot
.64724 .54243 Mdot
.19122 .53517 Mdot
.5712 .33432 Mdot
.46722 .55521 Mdot
.62831 .4836 Mdot
.75901 .42312 Mdot
.67208 .53328 Mdot
.71085 .62674 Mdot
.6748 .51054 Mdot
.34024 .7736 Mdot
.6823 .54483 Mdot
.67667 .54429 Mdot
.36308 .3775 Mdot
.37858 .34005 Mdot
.61426 .35299 Mdot
.46425 .58707 Mdot
.37327 .2336 Mdot
.67157 .51919 Mdot
.31077 .50184 Mdot
.551 .5112 Mdot
.42306 .65389 Mdot
.57583 .31529 Mdot
.89935 .47691 Mdot
.33351 .36734 Mdot
.29754 .51671 Mdot
.65408 .6271 Mdot
.29305 .50933 Mdot
.30875 .48527 Mdot
.55613 .26184 Mdot
.39718 .65969 Mdot
.63242 .56944 Mdot
.73129 .39833 Mdot
.49671 .34735 Mdot
.63541 .57852 Mdot
.24345 .56326 Mdot
.48929 .52831 Mdot
.56435 .6116 Mdot
.43775 .64643 Mdot
.41306 .66543 Mdot
.36629 .35579 Mdot
.3098 .50372 Mdot
.47823 .59376 Mdot
.42969 .65963 Mdot
.24374 .52869 Mdot
.50206 .55534 Mdot
.31874 .4541 Mdot
.56407 .34379 Mdot
.78722 .38426 Mdot
.71887 .29869 Mdot
.37843 .3826 Mdot
.30135 .38916 Mdot
.52559 .30352 Mdot
.55481 .29947 Mdot
.46963 .58702 Mdot
.2755 .49851 Mdot
.5246 .3213 Mdot
.63367 .55383 Mdot
.46218 .59243 Mdot
.65601 .55692 Mdot
.4366 .64139 Mdot
.66916 .53094 Mdot
.24505 .5296 Mdot
.36017 .37944 Mdot
.25777 .52862 Mdot
.36398 .35236 Mdot
.56752 .78945 Mdot
.6641 .49753 Mdot
.64972 .53813 Mdot
.53572 .71555 Mdot
.59665 .3512 Mdot
.73311 .41189 Mdot
.2749 .5119 Mdot
.26035 .52309 Mdot
.62985 .48288 Mdot
.53575 .3043 Mdot
.48383 .60871 Mdot
.55045 .69273 Mdot
.67585 .51456 Mdot
.57051 .33252 Mdot
.63767 .47901 Mdot
.3402 .27988 Mdot
.51975 .73734 Mdot
.59956 .34985 Mdot
.18369 .59351 Mdot
.67412 .50106 Mdot
.49046 .58903 Mdot
.48866 .53201 Mdot
.60108 .73101 Mdot
.5376 .53785 Mdot
.55302 .30576 Mdot
.47327 .59724 Mdot
.58502 .33588 Mdot
.25329 .53627 Mdot
.34655 .38117 Mdot
.57868 .33145 Mdot
.67132 .50227 Mdot
.43171 .84388 Mdot
.34635 .37392 Mdot
.64382 .52777 Mdot
.3406 .36088 Mdot
.5168 .31797 Mdot
.56625 .31691 Mdot
.50207 .5556 Mdot
.66638 .63238 Mdot
.34724 .36024 Mdot
.65784 .56179 Mdot
.49028 .28871 Mdot
.62628 .49682 Mdot
.45362 .62746 Mdot
.62884 .50907 Mdot
.623 .53028 Mdot
.20942 .66302 Mdot
.6889 .61071 Mdot
.32545 .43112 Mdot
.4024 .36002 Mdot
.51227 .25204 Mdot
.59683 .33092 Mdot
.43495 .63505 Mdot
.62039 .34282 Mdot
.49007 .55241 Mdot
.29165 .50199 Mdot
.65403 .52319 Mdot
.50299 .54785 Mdot
.37541 .32848 Mdot
.40796 .68078 Mdot
.67479 .55361 Mdot
.2997 .5405 Mdot
.50177 .57959 Mdot
.35632 .35273 Mdot
.55506 .33515 Mdot
.56767 .31196 Mdot
.32421 .45786 Mdot
.63501 .55278 Mdot
.65279 .5429 Mdot
.33703 .35278 Mdot
.51738 .52068 Mdot
.41337 .63694 Mdot
.50342 .58185 Mdot
.33925 .35388 Mdot
.52075 .73886 Mdot
.56412 .36561 Mdot
.63308 .53538 Mdot
.53052 .71328 Mdot
.51854 .25143 Mdot
.67374 .43277 Mdot
.41396 .65983 Mdot
.59669 .71213 Mdot
.55293 .30604 Mdot
.36169 .37382 Mdot
.36274 .74275 Mdot
.60126 .53926 Mdot
.6404 .51696 Mdot
.6044 .70611 Mdot
.55263 .693 Mdot
.65608 .6259 Mdot
.45979 .57309 Mdot
.56043 .74298 Mdot
.63238 .48079 Mdot
.60948 .52372 Mdot
.64097 .50301 Mdot
.6275 .50945 Mdot
.57048 .32641 Mdot
.78085 .43519 Mdot
.28476 .5351 Mdot
.61545 .45921 Mdot
.44232 .64454 Mdot
.60445 .57189 Mdot
.61519 .56127 Mdot
.62676 .39985 Mdot
.62784 .67876 Mdot
.57383 .34138 Mdot
.60574 .35396 Mdot
.38344 .37893 Mdot
.62962 .49319 Mdot
.27754 .51079 Mdot
.50664 .53426 Mdot
.26658 .4975 Mdot
.56897 .32719 Mdot
.23973 .53999 Mdot
.33319 .37161 Mdot
.28701 .54682 Mdot
.28139 .50044 Mdot
.36575 .37985 Mdot
.55442 .35817 Mdot
.63893 .58008 Mdot
.36604 .38022 Mdot
.46676 .61429 Mdot
.43225 .63445 Mdot
.58161 .29001 Mdot
.46937 .60493 Mdot
.62868 .59231 Mdot
.18243 .41559 Mdot
.29417 .53965 Mdot
.60251 .68164 Mdot
.56025 .36072 Mdot
.39946 .69341 Mdot
.57721 .32795 Mdot
.49105 .60008 Mdot
.41375 .65554 Mdot
.66507 .48027 Mdot
.43589 .78774 Mdot
.39376 .30413 Mdot
.6187 .59092 Mdot
.56385 .27472 Mdot
.26463 .50033 Mdot
.36274 .3838 Mdot
.308 .29683 Mdot
.48051 .59413 Mdot
.61246 .35109 Mdot
.54912 .36531 Mdot
.48924 .5533 Mdot
.35858 .37383 Mdot
.70915 .29337 Mdot
.63031 .5461 Mdot
.38695 .37721 Mdot
.62886 .5097 Mdot
.79678 .40988 Mdot
.41322 .69972 Mdot
.50857 .54887 Mdot
.62478 .48935 Mdot
.29545 .49435 Mdot
.62873 .48432 Mdot
.79796 .47652 Mdot
.48831 .77982 Mdot
.65606 .49696 Mdot
.60524 .69047 Mdot
.31938 .51866 Mdot
.5882 .33775 Mdot
.49032 .56776 Mdot
.47651 .57827 Mdot
.61625 .49713 Mdot
.52748 .86265 Mdot
.42268 .66877 Mdot
.20857 .50318 Mdot
.66676 .50011 Mdot
.65292 .54999 Mdot
.62429 .32552 Mdot
.77288 .36897 Mdot
.4952 .59107 Mdot
.64653 .51043 Mdot
.62915 .68878 Mdot
.372 .36965 Mdot
.61886 .51697 Mdot
.65558 .5551 Mdot
.34392 .49284 Mdot
.36286 .37636 Mdot
.25348 .55153 Mdot
.49917 .55139 Mdot
.27886 .48321 Mdot
.38618 .66607 Mdot
.59212 .70551 Mdot
.53237 .78661 Mdot
.51861 .73182 Mdot
.39429 .64136 Mdot
.60391 .53388 Mdot
.64454 .59636 Mdot
.63161 .52086 Mdot
.41291 .66858 Mdot
.34766 .32849 Mdot
.5726 .33224 Mdot
.79429 .39775 Mdot
.47426 .5801 Mdot
.60842 .57011 Mdot
.41931 .68821 Mdot
.58271 .33818 Mdot
.71671 .27458 Mdot
.56381 .32264 Mdot
.35709 .3572 Mdot
.30172 .38023 Mdot
.41548 .65073 Mdot
.5777 .32799 Mdot
.27127 .48664 Mdot
.30826 .38267 Mdot
.64569 .45577 Mdot
.33252 .36988 Mdot
.57197 .37195 Mdot
.60155 .35378 Mdot
.53415 .29649 Mdot
.61976 .49599 Mdot
.60434 .68716 Mdot
.49778 .55922 Mdot
.34011 .3648 Mdot
.30333 .51581 Mdot
.473 .76819 Mdot
.70388 .323 Mdot
.53829 .73967 Mdot
.66001 .47964 Mdot
.6685 .53126 Mdot
.66299 .54941 Mdot
.45494 .60256 Mdot
.64744 .59784 Mdot
.6513 .49958 Mdot
.37008 .32771 Mdot
.25044 .54094 Mdot
.66689 .50333 Mdot
.48298 .56158 Mdot
.52736 .5512 Mdot
.39797 .69214 Mdot
.80263 .42269 Mdot
.58784 .29363 Mdot
.58059 .33566 Mdot
.28719 .51583 Mdot
.24788 .50726 Mdot
.43045 .66207 Mdot
.37082 .35186 Mdot
.56114 .32107 Mdot
.33591 .76742 Mdot
.41132 .64041 Mdot
.66387 .52685 Mdot
.53445 .7152 Mdot
.62513 .70035 Mdot
.6165 .5492 Mdot
.65742 .52015 Mdot
.46158 .58198 Mdot
.28023 .50898 Mdot
.78378 .53036 Mdot
.71639 .27864 Mdot
.4207 .64856 Mdot
.42963 .63962 Mdot
.53778 .29684 Mdot
.66758 .55584 Mdot
.34464 .36187 Mdot
.56969 .74752 Mdot
.35159 .29854 Mdot
.41073 .21731 Mdot
.26187 .57519 Mdot
.63169 .57058 Mdot
.76117 .4562 Mdot
.62669 .59612 Mdot
.51658 .30729 Mdot
.53654 .34551 Mdot
.57384 .34462 Mdot
.37361 .36513 Mdot
.44691 .73108 Mdot
.37065 .33841 Mdot
.5091 .56969 Mdot
.54442 .32366 Mdot
.67384 .61734 Mdot
.26175 .5215 Mdot
.63455 .49012 Mdot
.40134 .66465 Mdot
.46409 .65455 Mdot
.48759 .57343 Mdot
.59507 .70984 Mdot
.26955 .55325 Mdot
.54172 .33852 Mdot
.63579 .4878 Mdot
.31066 .4104 Mdot
.54879 .74478 Mdot
.30333 .55532 Mdot
.50197 .54735 Mdot
.41663 .6448 Mdot
.7567 .50616 Mdot
.40378 .64214 Mdot
.34815 .35735 Mdot
.66107 .49805 Mdot
.67073 .55147 Mdot
.66273 .54338 Mdot
.67564 .49782 Mdot
.37085 .36203 Mdot
.61408 .58889 Mdot
.47621 .60872 Mdot
.50617 .55178 Mdot
.63244 .61525 Mdot
.39747 .67125 Mdot
.38176 .36561 Mdot
.24959 .53418 Mdot
.46383 .57291 Mdot
.41182 .6893 Mdot
.64435 .48744 Mdot
.65044 .50303 Mdot
.50817 .56707 Mdot
.66794 .48305 Mdot
.6178 .59649 Mdot
.27794 .54477 Mdot
.64274 .6187 Mdot
.39764 .69104 Mdot
.40405 .65983 Mdot
.35784 .345 Mdot
.57872 .32891 Mdot
.41876 .68088 Mdot
.30428 .54171 Mdot
.61997 .51226 Mdot
.63175 .5073 Mdot
.58731 .37407 Mdot
.44765 .74333 Mdot
.39648 .69226 Mdot
.67427 .49194 Mdot
.59627 .34136 Mdot
.54493 .36282 Mdot
.64327 .51455 Mdot
.61034 .58487 Mdot
.59727 .32871 Mdot
.4328 .64443 Mdot
.36532 .34427 Mdot
.49507 .73385 Mdot
.35782 .38731 Mdot
.55458 .33699 Mdot
.46922 .59515 Mdot
.55004 .3517 Mdot
.47891 .59531 Mdot
.49109 .19031 Mdot
.64799 .50063 Mdot
.56546 .24637 Mdot
.50044 .5878 Mdot
.26378 .51722 Mdot
.26661 .50657 Mdot
.48134 .55912 Mdot
.54662 .30636 Mdot
.49802 .56877 Mdot
.39642 .64857 Mdot
.50938 .25529 Mdot
.60221 .33705 Mdot
.27974 .50001 Mdot
.29593 .53954 Mdot
.33909 .35513 Mdot
.67027 .53248 Mdot
.63247 .53585 Mdot
.28428 .54858 Mdot
.34918 .2968 Mdot
.57553 .36331 Mdot
.65303 .54225 Mdot
.46193 .60559 Mdot
.2811 .53989 Mdot
.42744 .34152 Mdot
.52494 .31657 Mdot
.62287 .49 Mdot
.49454 .78295 Mdot
.34336 .37763 Mdot
.61217 .56466 Mdot
.61405 .59033 Mdot
.42254 .66431 Mdot
.59942 .71247 Mdot
.45232 .74333 Mdot
.33284 .36692 Mdot
.49509 .55393 Mdot
.61622 .55215 Mdot
.26184 .51463 Mdot
.64693 .49267 Mdot
.83559 .58343 Mdot
.50975 .55709 Mdot
.63645 .55185 Mdot
.49994 .53387 Mdot
.556 .31176 Mdot
.65449 .54591 Mdot
.31664 .4115 Mdot
.28482 .52 Mdot
.63365 .54914 Mdot
.47951 .51964 Mdot
.34098 .36096 Mdot
.48742 .57269 Mdot
.41809 .64291 Mdot
.66266 .6282 Mdot
.58183 .78982 Mdot
.27151 .56367 Mdot
.3943 .67045 Mdot
.67237 .52882 Mdot
.31369 .52274 Mdot
.38048 .34258 Mdot
.49087 .56287 Mdot
.60813 .55611 Mdot
.38406 .37039 Mdot
.37256 .37268 Mdot
.41264 .64904 Mdot
.71372 .24038 Mdot
.68644 .52706 Mdot
.64071 .53516 Mdot
.7154 .25957 Mdot
.55848 .37929 Mdot
.64423 .52528 Mdot
.6758 .53815 Mdot
.35551 .34909 Mdot
.4426 .72899 Mdot
.59631 .71024 Mdot
.5139 .54589 Mdot
.36622 .38351 Mdot
.25131 .5725 Mdot
.29407 .52873 Mdot
.39391 .67435 Mdot
.5652 .33334 Mdot
.42849 .66857 Mdot
.2788 .53309 Mdot
.66175 .53044 Mdot
.35638 .33911 Mdot
.77545 .55984 Mdot
.3459 .37718 Mdot
.29968 .54494 Mdot
.51619 .30988 Mdot
.79219 .51457 Mdot
.84365 .57271 Mdot
.45622 .48703 Mdot
.30135 .37356 Mdot
.42332 .65474 Mdot
.71622 .27805 Mdot
.67158 .50679 Mdot
.79199 .47004 Mdot
.64041 .53001 Mdot
.40216 .62076 Mdot
.25486 .51037 Mdot
.502 .5554 Mdot
.48192 .59354 Mdot
.59684 .7049 Mdot
.37577 .36819 Mdot
.34633 .33218 Mdot
.4669 .59862 Mdot
.35432 .3604 Mdot
.6359 .54646 Mdot
.26394 .54692 Mdot
.53498 .2016 Mdot
.67451 .50843 Mdot
.45701 .57153 Mdot
.35099 .39423 Mdot
.50603 .33733 Mdot
.25021 .57152 Mdot
.75984 .44225 Mdot
.35774 .24083 Mdot
.34856 .36579 Mdot
.80199 .42621 Mdot
.28332 .51434 Mdot
.46361 .57356 Mdot
.31502 .51479 Mdot
.6373 .53631 Mdot
.632 .57092 Mdot
.45632 .59417 Mdot
.67498 .52898 Mdot
.73682 .45297 Mdot
.61158 .59291 Mdot
.58329 .45662 Mdot
.64072 .50697 Mdot
.59149 .25986 Mdot
.37844 .33749 Mdot
.4664 .5973 Mdot
.49865 .68172 Mdot
.62492 .52798 Mdot
.59084 .32226 Mdot
.38066 .37587 Mdot
.3379 .24917 Mdot
.37196 .3663 Mdot
.25716 .52611 Mdot
.37372 .35659 Mdot
.6204 .58803 Mdot
.55221 .32104 Mdot
.27101 .52915 Mdot
.48317 .57658 Mdot
.30008 .50733 Mdot
.62836 .54394 Mdot
.41409 .37934 Mdot
.29709 .5179 Mdot
.60091 .5567 Mdot
.55363 .31844 Mdot
.46823 .81101 Mdot
.5317 .29099 Mdot
.65465 .53152 Mdot
.64957 .52716 Mdot
.49473 .59218 Mdot
.3656 .35008 Mdot
.54824 .35204 Mdot
.30317 .44937 Mdot
.39881 .69364 Mdot
.56877 .33931 Mdot
.50541 .52301 Mdot
.55072 .72045 Mdot
.58001 .31783 Mdot
.62838 .69332 Mdot
.34655 .3538 Mdot
.55893 .30676 Mdot
.55016 .52304 Mdot
.61234 .46548 Mdot
.40011 .65405 Mdot
.27343 .48454 Mdot
.5557 .7134 Mdot
.29334 .52384 Mdot
.31633 .4132 Mdot
.27862 .47998 Mdot
.34928 .37339 Mdot
.50297 .51973 Mdot
.67948 .63294 Mdot
.33697 .33743 Mdot
.38205 .41711 Mdot
.28744 .52883 Mdot
.47372 .60124 Mdot
.638 .6167 Mdot
.45989 .61226 Mdot
.49 .59152 Mdot
.33267 .36482 Mdot
.55856 .30594 Mdot
.54178 .30097 Mdot
.48154 .54142 Mdot
.57344 .31665 Mdot
.26624 .54062 Mdot
.51609 .72258 Mdot
.77024 .40969 Mdot
.36943 .32925 Mdot
.6465 .61984 Mdot
.61264 .55507 Mdot
.24694 .52703 Mdot
.26154 .54015 Mdot
.37465 .36726 Mdot
.63574 .42683 Mdot
.49668 .58319 Mdot
.51284 .32303 Mdot
.54685 .31869 Mdot
.55718 .31037 Mdot
.58733 .36618 Mdot
.44521 .73532 Mdot
.36764 .38205 Mdot
.54697 .30739 Mdot
.67288 .49593 Mdot
.67253 .54151 Mdot
.46788 .56646 Mdot
.43551 .63944 Mdot
.61346 .59218 Mdot
.4987 .56885 Mdot
.64027 .5186 Mdot
.26671 .51635 Mdot
.54838 .50829 Mdot
.48937 .55117 Mdot
.27737 .50983 Mdot
.27079 .51117 Mdot
.49534 .55267 Mdot
.54637 .50917 Mdot
.73577 .47286 Mdot
.61963 .48723 Mdot
.54217 .26612 Mdot
.27041 .50076 Mdot
.35685 .4349 Mdot
.56891 .24684 Mdot
.66368 .55635 Mdot
.50804 .57493 Mdot
.25858 .54432 Mdot
.60283 .3422 Mdot
.64264 .54212 Mdot
.47029 .5887 Mdot
.4028 .64798 Mdot
.48527 .5712 Mdot
.46179 .5835 Mdot
.5905 .35333 Mdot
.17593 .43021 Mdot
.5888 .3253 Mdot
.28095 .47347 Mdot
.48398 .58187 Mdot
.65291 .18369 Mdot
.2607 .50567 Mdot
.50586 .25684 Mdot
.67713 .6336 Mdot
.63663 .51812 Mdot
.28771 .51742 Mdot
.61083 .35177 Mdot
.33097 .35339 Mdot
.62918 .67499 Mdot
.57785 .32659 Mdot
.46812 .5611 Mdot
.46944 .5689 Mdot
.28407 .53688 Mdot
.5533 .34161 Mdot
.61351 .58955 Mdot
.56476 .31188 Mdot
.35822 .33412 Mdot
.64849 .47089 Mdot
.37145 .23449 Mdot
.47685 .59367 Mdot
.57975 .32107 Mdot
.30525 .5226 Mdot
.38943 .67147 Mdot
.68137 .52927 Mdot
.34735 .24053 Mdot
.67266 .53054 Mdot
.3398 .33998 Mdot
.53433 .55867 Mdot
.6214 .46802 Mdot
.66264 .51433 Mdot
.61821 .56892 Mdot
.33032 .32837 Mdot
.66074 .51191 Mdot
.62051 .54289 Mdot
.71658 .2927 Mdot
.58967 .32975 Mdot
.66829 .50446 Mdot
.27644 .54913 Mdot
.52356 .49098 Mdot
.64688 .55672 Mdot
.30329 .39484 Mdot
.59721 .73093 Mdot
.50638 .58107 Mdot
.46081 .56144 Mdot
.51044 .78506 Mdot
.64611 .52995 Mdot
.6613 .56078 Mdot
.64983 .47162 Mdot
.76888 .46039 Mdot
.28179 .52813 Mdot
.30136 .49747 Mdot
.39018 .66983 Mdot
.6065 .70347 Mdot
.40685 .65625 Mdot
.38107 .34329 Mdot
.65632 .63025 Mdot
.50083 .54932 Mdot
.58137 .33134 Mdot
.66069 .54542 Mdot
.30549 .51331 Mdot
.63506 .54018 Mdot
.61031 .51692 Mdot
.27032 .54118 Mdot
.25623 .54019 Mdot
.26404 .48396 Mdot
.42168 .64275 Mdot
.57776 .33971 Mdot
.6836 .52511 Mdot
.4188 .6404 Mdot
.45623 .59959 Mdot
.50015 .74444 Mdot
.57674 .34162 Mdot
.58376 .32578 Mdot
.53764 .31568 Mdot
.67699 .54532 Mdot
.64917 .46843 Mdot
.37462 .34277 Mdot
.5872 .37416 Mdot
.34304 .35466 Mdot
.28964 .51816 Mdot
.25385 .54695 Mdot
.63721 .53513 Mdot
.51188 .52371 Mdot
.39696 .66697 Mdot
.29886 .52457 Mdot
.50295 .53919 Mdot
.40079 .68551 Mdot
.64558 .56437 Mdot
.29278 .52101 Mdot
.40154 .63509 Mdot
.64093 .42889 Mdot
.40427 .2455 Mdot
.39167 .67763 Mdot
.4868 .59084 Mdot
.70385 .33646 Mdot
.48452 .77531 Mdot
.38451 .68837 Mdot
.37623 .33553 Mdot
.65855 .56783 Mdot
.50695 .54422 Mdot
.406 .68872 Mdot
.45491 .75594 Mdot
.27369 .53596 Mdot
.49232 .58689 Mdot
.45392 .50101 Mdot
.77014 .41188 Mdot
.38949 .67432 Mdot
.58112 .32193 Mdot
.56627 .36931 Mdot
.66242 .52173 Mdot
.66017 .63048 Mdot
.36317 .32448 Mdot
.25394 .49826 Mdot
.30349 .50266 Mdot
.53252 .34439 Mdot
.51879 .73419 Mdot
.28414 .54496 Mdot
.65853 .56587 Mdot
.43196 .67395 Mdot
.67165 .4938 Mdot
.53048 .57032 Mdot
.62168 .46912 Mdot
.47133 .54558 Mdot
.3901 .67446 Mdot
.35762 .32315 Mdot
.35892 .37874 Mdot
.36785 .35425 Mdot
.2832 .5429 Mdot
.5584 .70883 Mdot
.308 .50578 Mdot
.72381 .26407 Mdot
.42217 .67014 Mdot
.25011 .70123 Mdot
.63302 .59539 Mdot
.63324 .52301 Mdot
.62713 .49832 Mdot
.46157 .60205 Mdot
.64647 .53144 Mdot
.38478 .36666 Mdot
.27419 .48623 Mdot
.41712 .31807 Mdot
.57574 .35623 Mdot
.72301 .27333 Mdot
.2629 .52128 Mdot
.47583 .54978 Mdot
.39969 .66775 Mdot
.53245 .79099 Mdot
.42008 .62308 Mdot
.27114 .55598 Mdot
.62771 .55717 Mdot
.54233 .29524 Mdot
.34729 .78108 Mdot
.65779 .54465 Mdot
.29507 .53834 Mdot
.29265 .56006 Mdot
.61252 .45816 Mdot
.74148 .57432 Mdot
.37656 .29356 Mdot
.5287 .71719 Mdot
.39361 .63821 Mdot
.4595 .60861 Mdot
.57598 .74529 Mdot
.28039 .53293 Mdot
.28509 .48992 Mdot
.3891 .63821 Mdot
.50525 .33868 Mdot
.54188 .31693 Mdot
.53919 .27904 Mdot
.38293 .35656 Mdot
.63733 .51493 Mdot
.29055 .52694 Mdot
.52079 .30581 Mdot
.48591 .67966 Mdot
.36417 .3593 Mdot
.29832 .51787 Mdot
.67382 .53223 Mdot
.66466 .51572 Mdot
.40708 .65415 Mdot
.52747 .55443 Mdot
.46542 .6107 Mdot
.50746 .25707 Mdot
.54611 .72961 Mdot
.67582 .63512 Mdot
.64039 .51686 Mdot
.58973 .36254 Mdot
.492 .55352 Mdot
.39672 .66034 Mdot
.64726 .49316 Mdot
.79669 .49528 Mdot
.6048 .35503 Mdot
.34462 .35855 Mdot
.47821 .58228 Mdot
.59326 .70085 Mdot
.67397 .53043 Mdot
.64008 .53086 Mdot
.61997 .49589 Mdot
.79039 .52211 Mdot
.26616 .49517 Mdot
.59362 .34324 Mdot
.41925 .64403 Mdot
.56489 .31755 Mdot
.3258 .46777 Mdot
.64099 .62177 Mdot
.67918 .5495 Mdot
.59787 .33545 Mdot
.558 .32237 Mdot
.34053 .33874 Mdot
.35891 .38106 Mdot
.26423 .56784 Mdot
.67673 .53827 Mdot
.51005 .55376 Mdot
.54853 .30846 Mdot
.26701 .48653 Mdot
.40859 .65514 Mdot
.30094 .39378 Mdot
.64969 .50175 Mdot
.28475 .53229 Mdot
.49185 .56838 Mdot
.58366 .3556 Mdot
.27718 .5137 Mdot
.46317 .57444 Mdot
.43177 .63816 Mdot
.62178 .56683 Mdot
.32084 .52629 Mdot
.46681 .58947 Mdot
.68032 .5236 Mdot
.56442 .50028 Mdot
.65967 .62977 Mdot
.51052 .53875 Mdot
.24411 .54056 Mdot
.46967 .58364 Mdot
.56215 .36705 Mdot
.62206 .45638 Mdot
.28654 .48805 Mdot
.60973 .27468 Mdot
.68188 .63388 Mdot
.47547 .59651 Mdot
.58724 .33651 Mdot
.31877 .45516 Mdot
.5169 .3687 Mdot
.48353 .7711 Mdot
.64317 .55244 Mdot
.29332 .52428 Mdot
.40174 .65213 Mdot
.34588 .33304 Mdot
.36443 .41158 Mdot
.3527 .4659 Mdot
.275 .50362 Mdot
.66013 .54666 Mdot
.55709 .30659 Mdot
.34886 .3619 Mdot
.62363 .31735 Mdot
.31272 .52178 Mdot
.27372 .55094 Mdot
.61825 .50615 Mdot
.40676 .65737 Mdot
.64459 .59774 Mdot
.28355 .4855 Mdot
.29011 .48187 Mdot
.71549 .29471 Mdot
.39365 .63885 Mdot
.61938 .49546 Mdot
.47974 .54187 Mdot
.62319 .51011 Mdot
.71634 .27059 Mdot
.4654 .57725 Mdot
.57498 .35689 Mdot
.6496 .5208 Mdot
.17422 .49639 Mdot
.25521 .51366 Mdot
.52858 .71752 Mdot
.39749 .30638 Mdot
.37193 .37607 Mdot
.28138 .5211 Mdot
.64482 .54699 Mdot
.30027 .38643 Mdot
.39557 .67723 Mdot
.62795 .48235 Mdot
.47042 .59883 Mdot
.53397 .3498 Mdot
.3584 .33855 Mdot
.50915 .50223 Mdot
.3511 .33206 Mdot
.36042 .34615 Mdot
.56343 .40454 Mdot
.6628 .52296 Mdot
.26672 .5211 Mdot
.29467 .54643 Mdot
.44947 .60487 Mdot
.25577 .47367 Mdot
.54275 .33368 Mdot
.17729 .48807 Mdot
.79451 .50322 Mdot
.66108 .49546 Mdot
.46049 .57159 Mdot
.50281 .58147 Mdot
.30154 .37844 Mdot
.65898 .51524 Mdot
.58815 .3414 Mdot
.28257 .48436 Mdot
.29212 .53273 Mdot
.60102 .55694 Mdot
.35923 .37923 Mdot
.42264 .62954 Mdot
.26318 .53859 Mdot
.49574 .72977 Mdot
.63647 .55267 Mdot
.36182 .40002 Mdot
.26397 .53659 Mdot
.45407 .83858 Mdot
.16488 .44995 Mdot
.57303 .30966 Mdot
.62339 .57321 Mdot
.52623 .31638 Mdot
.38864 .66279 Mdot
.30932 .4908 Mdot
.3423 .33336 Mdot
.48359 .57983 Mdot
.29845 .29304 Mdot
.28816 .53611 Mdot
.56977 .32822 Mdot
.6586 .52547 Mdot
.80261 .43286 Mdot
.67454 .51031 Mdot
.44228 .72763 Mdot
.39422 .6915 Mdot
.36999 .41134 Mdot
.3373 .35446 Mdot
.62428 .57479 Mdot
.41704 .63697 Mdot
.28448 .5564 Mdot
.2719 .5407 Mdot
.33413 .24237 Mdot
.46247 .58101 Mdot
.31263 .49045 Mdot
.68009 .52756 Mdot
.26907 .48203 Mdot
.70382 .32224 Mdot
.3691 .37688 Mdot
.62076 .51733 Mdot
.29464 .51196 Mdot
.51621 .36395 Mdot
.53696 .71787 Mdot
.64043 .55406 Mdot
.49377 .53191 Mdot
.35098 .37379 Mdot
.72367 .27612 Mdot
.25105 .51586 Mdot
.65822 .48696 Mdot
.38676 .36771 Mdot
.50288 .52024 Mdot
.42216 .32031 Mdot
.57793 .34025 Mdot
.29754 .53873 Mdot
.36518 .3436 Mdot
.48958 .58132 Mdot
.40188 .63607 Mdot
.30282 .54486 Mdot
.29485 .50684 Mdot
.60487 .53153 Mdot
.48509 .54243 Mdot
.50861 .52406 Mdot
.56519 .36027 Mdot
.35118 .35059 Mdot
.61268 .50951 Mdot
.49754 .74608 Mdot
.64671 .4807 Mdot
.35193 .34681 Mdot
.67106 .20204 Mdot
.62671 .56026 Mdot
.64475 .50486 Mdot
.80377 .44545 Mdot
.54038 .33877 Mdot
.59338 .36378 Mdot
.54208 .74239 Mdot
.6065 .57366 Mdot
.67729 .6152 Mdot
.57676 .33591 Mdot
.56653 .32634 Mdot
.67617 .6159 Mdot
.60555 .53162 Mdot
.54026 .28224 Mdot
.35091 .36232 Mdot
.36978 .37814 Mdot
.55715 .31109 Mdot
.63307 .49448 Mdot
.39373 .35859 Mdot
.64249 .41526 Mdot
.28525 .55215 Mdot
.58621 .73456 Mdot
.55858 .31659 Mdot
.53687 .71342 Mdot
.34833 .35667 Mdot
.57007 .77764 Mdot
.60296 .72938 Mdot
.68615 .52073 Mdot
.66232 .51819 Mdot
.42238 .65892 Mdot
.4864 .57238 Mdot
.49449 .55207 Mdot
.36805 .3538 Mdot
.64793 .59764 Mdot
.57234 .34459 Mdot
.61797 .58443 Mdot
.47039 .76673 Mdot
.59541 .78021 Mdot
.76717 .56126 Mdot
.56496 .3317 Mdot
.55891 .33813 Mdot
.25536 .55123 Mdot
.23878 .53923 Mdot
.68371 .53834 Mdot
.35389 .37667 Mdot
.56332 .30731 Mdot
.35063 .34341 Mdot
.27908 .53405 Mdot
.26182 .52448 Mdot
.48045 .55515 Mdot
.49406 .58483 Mdot
.27679 .52632 Mdot
.30302 .39356 Mdot
.49818 .74593 Mdot
.55329 .36606 Mdot
.72518 .2607 Mdot
.55671 .78918 Mdot
.79644 .40643 Mdot
.40197 .64975 Mdot
.5492 .51021 Mdot
.38621 .36578 Mdot
.62271 .57463 Mdot
.64286 .52093 Mdot
.47434 .57392 Mdot
.38583 .37621 Mdot
.40869 .67695 Mdot
.37095 .37619 Mdot
.40484 .63586 Mdot
.29723 .4961 Mdot
.65606 .54952 Mdot
.62722 .54824 Mdot
.343 .33625 Mdot
.26011 .55424 Mdot
.29365 .51481 Mdot
.39793 .65287 Mdot
.53901 .78764 Mdot
.2835 .53613 Mdot
.55864 .31772 Mdot
.63003 .28404 Mdot
.46948 .57081 Mdot
.6436 .54238 Mdot
.51243 .78626 Mdot
.62382 .45639 Mdot
.45577 .59635 Mdot
.47751 .58211 Mdot
.7115 .23824 Mdot
.63505 .5562 Mdot
.31897 .24558 Mdot
.48684 .55158 Mdot
.54941 .35083 Mdot
.27198 .51967 Mdot
.46064 .57299 Mdot
.47775 .53551 Mdot
.43278 .68164 Mdot
.45603 .58444 Mdot
.54239 .31454 Mdot
.5361 .32318 Mdot
.64272 .61999 Mdot
.7298 .26811 Mdot
.41726 .64353 Mdot
.40409 .68025 Mdot
.27049 .49353 Mdot
.317 .41492 Mdot
.6697 .57185 Mdot
.40985 .68193 Mdot
.57864 .29031 Mdot
.61502 .51092 Mdot
.65818 .62687 Mdot
.6344 .6163 Mdot
.57742 .36908 Mdot
.63968 .4622 Mdot
.26342 .50007 Mdot
.57044 .33028 Mdot
.641 .6174 Mdot
.61799 .51482 Mdot
.57581 .34325 Mdot
.35959 .34838 Mdot
.72347 .61686 Mdot
.56738 .31233 Mdot
.62993 .67361 Mdot
.34592 .36485 Mdot
.65488 .6237 Mdot
.30107 .72468 Mdot
.48545 .85236 Mdot
.36898 .37496 Mdot
.29779 .52171 Mdot
.28945 .52647 Mdot
.27563 .5441 Mdot
.5777 .36504 Mdot
.252 .53231 Mdot
.55823 .34912 Mdot
.30235 .37395 Mdot
.60185 .7039 Mdot
.41491 .65301 Mdot
.26892 .46985 Mdot
.55909 .31116 Mdot
.71988 .26635 Mdot
.88608 .50318 Mdot
.66115 .48499 Mdot
.33584 .33978 Mdot
.41671 .68061 Mdot
.52314 .71556 Mdot
.42232 .6642 Mdot
.28397 .51447 Mdot
.5947 .70328 Mdot
.63414 .54398 Mdot
.38356 .24888 Mdot
.40204 .65391 Mdot
.56575 .32486 Mdot
.60299 .53767 Mdot
.24781 .55272 Mdot
.39213 .66867 Mdot
.40298 .66126 Mdot
.64588 .53349 Mdot
.54226 .33946 Mdot
.28762 .51317 Mdot
.37753 .38437 Mdot
.36055 .53479 Mdot
.54689 .54047 Mdot
.63911 .56003 Mdot
.63422 .50872 Mdot
.5456 .72064 Mdot
.30164 .39622 Mdot
.35302 .36946 Mdot
.45647 .75124 Mdot
.24565 .5304 Mdot
.47828 .77351 Mdot
.50332 .34896 Mdot
.27327 .46965 Mdot
.46583 .57759 Mdot
.4648 .57063 Mdot
.65513 .54139 Mdot
.86194 .54368 Mdot
.73456 .58691 Mdot
.39202 .35523 Mdot
.47427 .5693 Mdot
.26029 .55627 Mdot
.60028 .36269 Mdot
.43325 .51018 Mdot
.61757 .59828 Mdot
.37706 .38511 Mdot
.27706 .53991 Mdot
.83869 .60054 Mdot
.42475 .65149 Mdot
.52347 .721 Mdot
.67674 .53297 Mdot
.65205 .53962 Mdot
.36686 .3639 Mdot
.35202 .32535 Mdot
.71998 .29495 Mdot
.40566 .62221 Mdot
.37699 .23028 Mdot
.34037 .31867 Mdot
.84009 .60911 Mdot
.5089 .56887 Mdot
.56152 .34497 Mdot
.49781 .55351 Mdot
.3502 .32366 Mdot
.64617 .52301 Mdot
.54206 .34038 Mdot
.49202 .56176 Mdot
.57859 .29631 Mdot
.66315 .62896 Mdot
.49577 .73439 Mdot
.66872 .52995 Mdot
.52876 .3097 Mdot
.57328 .33544 Mdot
.51341 .31714 Mdot
.47621 .56105 Mdot
.64628 .51004 Mdot
.6601 .48725 Mdot
.63741 .50846 Mdot
.71843 .30442 Mdot
.65306 .54808 Mdot
.50028 .34108 Mdot
.53097 .74474 Mdot
.1709 .50999 Mdot
.62675 .5445 Mdot
.36838 .34912 Mdot
.6614 .53855 Mdot
.41921 .63602 Mdot
.61896 .55707 Mdot
.66805 .63016 Mdot
.3546 .36528 Mdot
.79891 .48023 Mdot
.44061 .65299 Mdot
.63847 .56152 Mdot
.39527 .64008 Mdot
.49028 .26077 Mdot
.45868 .75041 Mdot
.70871 .29501 Mdot
.56395 .31207 Mdot
.3134 .50817 Mdot
.36278 .32378 Mdot
.2578 .5251 Mdot
.60169 .5721 Mdot
.50359 .55198 Mdot
.2345 .68994 Mdot
.50999 .75769 Mdot
.64807 .52199 Mdot
.48521 .59906 Mdot
.58915 .33361 Mdot
.25792 .50886 Mdot
.77529 .37035 Mdot
.62402 .50008 Mdot
.43303 .64933 Mdot
.42879 .65471 Mdot
.48544 .62388 Mdot
.50781 .32813 Mdot
.70423 .31192 Mdot
.36541 .36491 Mdot
.28602 .54112 Mdot
.40019 .68953 Mdot
.56721 .27882 Mdot
.34109 .33188 Mdot
.30309 .38206 Mdot
.36103 .33947 Mdot
.62799 .52933 Mdot
.47543 .55574 Mdot
.51558 .26807 Mdot
.46566 .58496 Mdot
.63058 .5031 Mdot
.29394 .50668 Mdot
.46421 .57867 Mdot
.41848 .65809 Mdot
.36355 .34451 Mdot
.26462 .51848 Mdot
.65232 .52806 Mdot
.58065 .33749 Mdot
.56344 .60459 Mdot
.32129 .50301 Mdot
.65887 .63045 Mdot
.65879 .63045 Mdot
.56403 .3747 Mdot
.51294 .54094 Mdot
.41 .3919 Mdot
.61721 .45617 Mdot
.34231 .46749 Mdot
.52671 .53492 Mdot
.22423 .48437 Mdot
.30905 .50671 Mdot
.27015 .53161 Mdot
.63036 .53831 Mdot
.26618 .48589 Mdot
.66522 .56238 Mdot
.24281 .53822 Mdot
.51915 .24947 Mdot
.61947 .59206 Mdot
.26821 .53915 Mdot
.49918 .56011 Mdot
.68122 .52672 Mdot
.59117 .33893 Mdot
.30758 .49778 Mdot
.68604 .51987 Mdot
.18601 .55891 Mdot
.34104 .33785 Mdot
.47427 .56203 Mdot
.52621 .68405 Mdot
.35446 .35527 Mdot
.54331 .32869 Mdot
.64724 .57477 Mdot
.40969 .68374 Mdot
.55589 .33881 Mdot
.47024 .624 Mdot
.40592 .65945 Mdot
.51448 .72444 Mdot
.54917 .32402 Mdot
.4682 .57442 Mdot
.43176 .64279 Mdot
.44884 .60624 Mdot
.27101 .53424 Mdot
.30455 .55265 Mdot
.46838 .59108 Mdot
.63359 .54058 Mdot
.25523 .55584 Mdot
.37632 .36378 Mdot
.65535 .55612 Mdot
.2916 .52772 Mdot
.48488 .56089 Mdot
.67407 .50323 Mdot
.60705 .57662 Mdot
.71702 .28065 Mdot
.51178 .57146 Mdot
.4166 .65477 Mdot
.51618 .3119 Mdot
.65471 .49541 Mdot
.41122 .63816 Mdot
.31806 .52448 Mdot
.65651 .48268 Mdot
.55959 .30364 Mdot
.6299 .42569 Mdot
.24823 .50696 Mdot
.34772 .37518 Mdot
.30173 .54046 Mdot
.38609 .65814 Mdot
.89603 .48534 Mdot
.49167 .55241 Mdot
.62716 .47494 Mdot
.62093 .52964 Mdot
.3127 .50141 Mdot
.57323 .33825 Mdot
.39439 .22224 Mdot
.62134 .56681 Mdot
.6608 .48173 Mdot
.64479 .53862 Mdot
.34742 .52123 Mdot
.5652 .36259 Mdot
.64368 .54051 Mdot
.53569 .54235 Mdot
.62716 .51196 Mdot
.39099 .65669 Mdot
.26695 .71417 Mdot
.45799 .58855 Mdot
.6452 .17552 Mdot
.49127 .55872 Mdot
.2675 .54387 Mdot
.63025 .67305 Mdot
.5227 .68312 Mdot
.30026 .57876 Mdot
.54322 .33154 Mdot
.54469 .26544 Mdot
.26197 .52591 Mdot
.3205 .45718 Mdot
.62587 .60709 Mdot
.60326 .54052 Mdot
.6744 .54486 Mdot
.28377 .51448 Mdot
.26307 .49183 Mdot
.50541 .556 Mdot
.47619 .60289 Mdot
.65651 .46464 Mdot
.30437 .5175 Mdot
.65341 .54955 Mdot
.61805 .46631 Mdot
.33733 .3344 Mdot
.57628 .31288 Mdot
.35001 .33026 Mdot
.33208 .34492 Mdot
.79341 .39715 Mdot
.54818 .72921 Mdot
.3834 .35717 Mdot
.38738 .35262 Mdot
.32892 .45307 Mdot
.77836 .41516 Mdot
.39171 .6525 Mdot
.73273 .58731 Mdot
.25492 .54617 Mdot
.64822 .50853 Mdot
.56573 .36341 Mdot
.48684 .60373 Mdot
.4257 .20762 Mdot
.71598 .7139 Mdot
.61338 .51259 Mdot
.24792 .53218 Mdot
.46672 .59139 Mdot
.46559 .59733 Mdot
.48281 .77459 Mdot
.65008 .54812 Mdot
.25203 .50066 Mdot
.77087 .41052 Mdot
.32548 .32568 Mdot
.30118 .38675 Mdot
.51185 .3246 Mdot
.66173 .54006 Mdot
.57519 .36228 Mdot
.35831 .3864 Mdot
.40932 .64085 Mdot
.42246 .65198 Mdot
.638 .56195 Mdot
.6775 .63302 Mdot
.34521 .47198 Mdot
.60429 .56665 Mdot
.60604 .53377 Mdot
.47091 .58304 Mdot
.61346 .5015 Mdot
.65716 .48797 Mdot
.60867 .53782 Mdot
.45673 .60222 Mdot
.34076 .33299 Mdot
.77645 .39024 Mdot
.47326 .59689 Mdot
.64064 .58244 Mdot
.35299 .38393 Mdot
.60933 .58431 Mdot
.37244 .36474 Mdot
.30316 .40203 Mdot
.3776 .34681 Mdot
.41952 .64926 Mdot
.24075 .51776 Mdot
.72424 .28168 Mdot
.56009 .3078 Mdot
.36674 .38158 Mdot
.43155 .63547 Mdot
.37381 .35999 Mdot
.26 .54996 Mdot
.31527 .34749 Mdot
.56294 .38468 Mdot
.49703 .72624 Mdot
.79556 .41829 Mdot
.33127 .32211 Mdot
.24744 .50968 Mdot
.55615 .31047 Mdot
.31633 .41164 Mdot
.62719 .57553 Mdot
.42425 .64873 Mdot
.65506 .54 Mdot
.36218 .34507 Mdot
.25026 .54214 Mdot
.70931 .28857 Mdot
.4177 .65479 Mdot
.72312 .2561 Mdot
.30626 .51617 Mdot
.62216 .55043 Mdot
.34666 .38135 Mdot
.35547 .41542 Mdot
.33809 .34921 Mdot
.6015 .71317 Mdot
.50868 .54878 Mdot
.36592 .65938 Mdot
.5538 .33251 Mdot
.51123 .56104 Mdot
.58088 .83062 Mdot
.46441 .30952 Mdot
.5855 .34905 Mdot
.31356 .48838 Mdot
.6362 .55413 Mdot
.61892 .49479 Mdot
.49767 .57576 Mdot
.53676 .30243 Mdot
.61988 .49616 Mdot
.47312 .56042 Mdot
.54023 .74842 Mdot
.51078 .32404 Mdot
.3044 .54458 Mdot
.67848 .5347 Mdot
.33342 .36671 Mdot
.34685 .37843 Mdot
.48223 .55143 Mdot
.35658 .33231 Mdot
.64382 .57975 Mdot
.55158 .31867 Mdot
.63791 .61723 Mdot
.38955 .66628 Mdot
.48695 .29665 Mdot
.47367 .61491 Mdot
.43874 .63796 Mdot
.67453 .4978 Mdot
.26389 .52298 Mdot
.29479 .29404 Mdot
.61541 .5641 Mdot
.57428 .33289 Mdot
.62024 .53913 Mdot
.61672 .49829 Mdot
.60247 .55178 Mdot
.28596 .54093 Mdot
.538 .71654 Mdot
.65429 .54884 Mdot
.37068 .38627 Mdot
.67728 .61814 Mdot
.63095 .59247 Mdot
.39867 .62225 Mdot
.66632 .62943 Mdot
.38214 .38971 Mdot
.54707 .36157 Mdot
.26765 .52148 Mdot
.56787 .34406 Mdot
.59994 .32752 Mdot
.54371 .32957 Mdot
.51168 .33954 Mdot
.61958 .45576 Mdot
.31887 .24203 Mdot
.70397 .31948 Mdot
.79907 .4186 Mdot
.60277 .33605 Mdot
.23568 .3324 Mdot
.58747 .34832 Mdot
.54325 .32955 Mdot
.51588 .19499 Mdot
.54599 .34123 Mdot
.63668 .53476 Mdot
.62441 .52904 Mdot
.79041 .51421 Mdot
.36255 .53493 Mdot
.67286 .50467 Mdot
.4555 .60181 Mdot
.42101 .6758 Mdot
.50443 .33662 Mdot
.48116 .58049 Mdot
.52111 .71532 Mdot
.46814 .55954 Mdot
.64639 .53294 Mdot
.66517 .54667 Mdot
.61333 .59414 Mdot
.61384 .77847 Mdot
.36908 .54019 Mdot
.536 .31635 Mdot
.63655 .59565 Mdot
.42795 .32941 Mdot
.66813 .5499 Mdot
.61733 .54056 Mdot
.63601 .4617 Mdot
.26664 .52111 Mdot
.60222 .36324 Mdot
.49689 .5842 Mdot
.48145 .30037 Mdot
.67276 .52653 Mdot
.49364 .6025 Mdot
.42598 .67667 Mdot
.6437 .54682 Mdot
.54014 .33119 Mdot
.61791 .49747 Mdot
.59899 .35704 Mdot
.54956 .32882 Mdot
.6581 .48171 Mdot
.50571 .33082 Mdot
.60209 .36012 Mdot
.60336 .54174 Mdot
.24912 .54921 Mdot
.50746 .25623 Mdot
.63524 .54303 Mdot
.41536 .66071 Mdot
.6588 .51774 Mdot
.39 .65469 Mdot
.45769 .57947 Mdot
.46828 .58544 Mdot
.75478 .51285 Mdot
.28767 .49057 Mdot
.42761 .62242 Mdot
.27233 .4799 Mdot
.65757 .58126 Mdot
.58603 .2977 Mdot
.32088 .33649 Mdot
.29409 .46401 Mdot
.47003 .58225 Mdot
.44837 .7321 Mdot
.67931 .60228 Mdot
.37328 .34064 Mdot
.59443 .34736 Mdot
.76523 .38945 Mdot
.50707 .57605 Mdot
.30203 .54705 Mdot
.28856 .54972 Mdot
.44642 .3459 Mdot
.53466 .20153 Mdot
.62723 .54458 Mdot
.50023 .5862 Mdot
.57658 .46718 Mdot
.48723 .57084 Mdot
.50566 .56173 Mdot
.29637 .50746 Mdot
.67496 .50713 Mdot
.54711 .75145 Mdot
.28669 .52772 Mdot
.40066 .67397 Mdot
.57451 .3575 Mdot
.40774 .63664 Mdot
.42717 .23796 Mdot
.72088 .29269 Mdot
.27978 .52666 Mdot
.45855 .59912 Mdot
.65099 .50374 Mdot
.54609 .3475 Mdot
.62347 .31856 Mdot
.59119 .332 Mdot
.39966 .68293 Mdot
.29003 .48824 Mdot
.18373 .588 Mdot
.66008 .52648 Mdot
.5592 .32395 Mdot
.43267 .67489 Mdot
.66471 .51414 Mdot
.35783 .37942 Mdot
.61898 .49834 Mdot
.56257 .31963 Mdot
.62868 .47404 Mdot
.55312 .33229 Mdot
.27838 .5502 Mdot
.6337 .55915 Mdot
.65122 .56069 Mdot
.45449 .74703 Mdot
.4098 .67643 Mdot
.60209 .35216 Mdot
.55729 .71996 Mdot
.62323 .51002 Mdot
.49434 .78056 Mdot
.65209 .55303 Mdot
.79578 .42213 Mdot
.48824 .53621 Mdot
.47087 .56139 Mdot
.62024 .535 Mdot
.63667 .54551 Mdot
.62416 .32474 Mdot
.70424 .32594 Mdot
.71906 .30355 Mdot
.3478 .37686 Mdot
.59177 .34465 Mdot
.28694 .52338 Mdot
.30601 .49385 Mdot
.25404 .53038 Mdot
.38712 .67286 Mdot
.62216 .60465 Mdot
.63383 .52782 Mdot
.39375 .36966 Mdot
.41827 .67537 Mdot
.56111 .33159 Mdot
.41236 .6496 Mdot
.54147 .72532 Mdot
.41621 .66352 Mdot
.49949 .55211 Mdot
.18153 .41647 Mdot
.61728 .46591 Mdot
.40446 .66813 Mdot
.57121 .30932 Mdot
.68484 .61817 Mdot
.67206 .48468 Mdot
.72057 .27236 Mdot
.43189 .65593 Mdot
.3162 .49084 Mdot
.67833 .50787 Mdot
.60421 .68509 Mdot
.37052 .36061 Mdot
.40972 .63555 Mdot
.36069 .33859 Mdot
.61361 .51039 Mdot
.56484 .25777 Mdot
.57317 .32595 Mdot
.33762 .33264 Mdot
.61825 .53135 Mdot
.41044 .63551 Mdot
.27602 .52945 Mdot
.77739 .41535 Mdot
.305 .3888 Mdot
.51454 .57377 Mdot
.48125 .7717 Mdot
.26461 .49797 Mdot
.78429 .43274 Mdot
.36759 .33962 Mdot
.63004 .59906 Mdot
.62566 .47036 Mdot
.64978 .4946 Mdot
.29147 .51357 Mdot
.26964 .53112 Mdot
.27589 .457 Mdot
.64913 .56262 Mdot
.64284 .46334 Mdot
.53458 .35319 Mdot
.28502 .48577 Mdot
.54419 .32967 Mdot
.52759 .30724 Mdot
.29734 .52147 Mdot
.59934 .34721 Mdot
.40448 .65961 Mdot
.57053 .73539 Mdot
.36994 .34157 Mdot
.34008 .36418 Mdot
.27825 .52566 Mdot
.27942 .49635 Mdot
.2634 .52273 Mdot
.62379 .49617 Mdot
.54756 .32773 Mdot
.64453 .56938 Mdot
.66138 .53527 Mdot
.66856 .48186 Mdot
.52438 .31743 Mdot
.62389 .57224 Mdot
.64134 .61029 Mdot
.41634 .68511 Mdot
.26459 .54156 Mdot
.34746 .34759 Mdot
.56347 .60968 Mdot
.37269 .38692 Mdot
.62716 .50979 Mdot
.5185 .25229 Mdot
.59125 .35062 Mdot
.42261 .66209 Mdot
.66648 .63131 Mdot
.42017 .65528 Mdot
.33683 .33481 Mdot
.53185 .35242 Mdot
.51616 .72989 Mdot
.63863 .5677 Mdot
.54898 .7229 Mdot
.36261 .74149 Mdot
.51426 .37154 Mdot
.35297 .35078 Mdot
.63596 .47546 Mdot
.47752 .55206 Mdot
.62086 .45079 Mdot
.6317 .53387 Mdot
.63105 .5942 Mdot
.59644 .67102 Mdot
.62558 .51614 Mdot
.55553 .29988 Mdot
.65948 .61799 Mdot
.46386 .60705 Mdot
.67593 .49557 Mdot
.33342 .24694 Mdot
.6689 .50086 Mdot
.64104 .56547 Mdot
.64217 .51844 Mdot
.61164 .54796 Mdot
.52655 .31933 Mdot
.64602 .62284 Mdot
.36288 .38629 Mdot
.57028 .73612 Mdot
.37297 .34546 Mdot
.27899 .5197 Mdot
.49614 .5945 Mdot
.57662 .37094 Mdot
.42032 .65605 Mdot
.38883 .50768 Mdot
.60585 .6925 Mdot
.2558 .55157 Mdot
.44319 .73769 Mdot
.42033 .62962 Mdot
.50352 .56409 Mdot
.38564 .65512 Mdot
.29443 .51052 Mdot
.36245 .37882 Mdot
.62736 .55736 Mdot
.5459 .31271 Mdot
.56904 .31249 Mdot
.67644 .49759 Mdot
.49624 .26235 Mdot
.34377 .37226 Mdot
.25979 .47158 Mdot
.62814 .53424 Mdot
.62075 .51721 Mdot
.59629 .35977 Mdot
.25229 .52113 Mdot
.67712 .60422 Mdot
.39411 .65719 Mdot
.67034 .54656 Mdot
.46571 .60509 Mdot
.54282 .72492 Mdot
.34937 .37872 Mdot
.47924 .56266 Mdot
.6588 .50216 Mdot
.53788 .73133 Mdot
.62949 .48277 Mdot
.53794 .5404 Mdot
.23959 .53871 Mdot
.66153 .48232 Mdot
.65649 .5586 Mdot
.51139 .32385 Mdot
.36491 .33727 Mdot
.57609 .33944 Mdot
.56173 .37834 Mdot
.46871 .58444 Mdot
.33956 .34333 Mdot
.61207 .53884 Mdot
.39364 .35015 Mdot
.61541 .50239 Mdot
.65663 .53145 Mdot
.3555 .34983 Mdot
.55013 .33921 Mdot
.38131 .23078 Mdot
.77538 .38928 Mdot
.61028 .51731 Mdot
.65998 .5153 Mdot
.36258 .53543 Mdot
.48644 .60424 Mdot
.63105 .57071 Mdot
.56396 .30803 Mdot
.66493 .51651 Mdot
.38476 .34025 Mdot
.41397 .64358 Mdot
.57764 .3326 Mdot
.25036 .51991 Mdot
.28273 .54762 Mdot
.23876 .54941 Mdot
.50126 .55261 Mdot
.61276 .50258 Mdot
.51622 .31238 Mdot
.52395 .30738 Mdot
.55726 .70018 Mdot
.26734 .54339 Mdot
.40497 .6472 Mdot
.67948 .53756 Mdot
.48868 .59743 Mdot
.3405 .37505 Mdot
.64048 .17119 Mdot
.51901 .73184 Mdot
.40882 .69081 Mdot
.53676 .564 Mdot
.47436 .57894 Mdot
.64453 .50597 Mdot
.41367 .63639 Mdot
.29607 .52282 Mdot
.62169 .48963 Mdot
.53009 .54041 Mdot
.31525 .48701 Mdot
.26742 .50711 Mdot
.39597 .3574 Mdot
.2437 .52769 Mdot
.40163 .63531 Mdot
.49281 .55242 Mdot
.57907 .32505 Mdot
.64647 .54867 Mdot
.4792 .59226 Mdot
.26451 .54712 Mdot
.50742 .57004 Mdot
.62446 .53725 Mdot
.58997 .36008 Mdot
.25448 .53906 Mdot
.64332 .53139 Mdot
.61059 .45886 Mdot
.71668 .28319 Mdot
.24817 .54078 Mdot
.65406 .5698 Mdot
.45667 .50065 Mdot
.26688 .51049 Mdot
.29186 .50957 Mdot
.65547 .48432 Mdot
.42075 .63343 Mdot
.66919 .53358 Mdot
.35677 .37711 Mdot
.54511 .71654 Mdot
.34238 .33679 Mdot
.48218 .77589 Mdot
.67081 .48807 Mdot
.64374 .45512 Mdot
.58127 .29688 Mdot
.44091 .62142 Mdot
.55296 .7895 Mdot
.65543 .49592 Mdot
.61499 .34961 Mdot
.53831 .71382 Mdot
.50236 .71603 Mdot
.60223 .40164 Mdot
.39772 .64253 Mdot
.36867 .35469 Mdot
.64447 .56103 Mdot
.34909 .25106 Mdot
.39575 .64891 Mdot
.48416 .77593 Mdot
.62682 .58101 Mdot
.56638 .32969 Mdot
.62808 .5412 Mdot
.57391 .32156 Mdot
.65912 .50805 Mdot
.71268 .28135 Mdot
.34496 .4714 Mdot
.60173 .71229 Mdot
.49982 .56369 Mdot
.3556 .41537 Mdot
.79602 .41825 Mdot
.40501 .65517 Mdot
.63044 .47305 Mdot
.47806 .57247 Mdot
.37143 .37577 Mdot
.35798 .29174 Mdot
.26111 .52592 Mdot
.37388 .38459 Mdot
.56504 .34868 Mdot
.26281 .55838 Mdot
.51078 .5607 Mdot
.64305 .45376 Mdot
.41399 .63486 Mdot
.33919 .34453 Mdot
.64096 .54845 Mdot
.64013 .49782 Mdot
.34596 .51822 Mdot
.27735 .72275 Mdot
.53 .29824 Mdot
.72202 .24967 Mdot
.53225 .35247 Mdot
.40634 .6792 Mdot
.25033 .55119 Mdot
.64664 .52078 Mdot
.67644 .52281 Mdot
.26733 .5058 Mdot
.54846 .35198 Mdot
.42639 .62508 Mdot
.36531 .6614 Mdot
.39249 .35594 Mdot
.32077 .74777 Mdot
.57888 .33143 Mdot
.31875 .74633 Mdot
.20487 .50859 Mdot
.58558 .23009 Mdot
.54419 .78848 Mdot
.3528 .35937 Mdot
.31997 .74763 Mdot
.56323 .32714 Mdot
.63095 .5177 Mdot
.46961 .57518 Mdot
.50411 .55124 Mdot
.58102 .3618 Mdot
.2801 .51435 Mdot
.41453 .63082 Mdot
.62985 .54348 Mdot
.54571 .51213 Mdot
.62358 .31692 Mdot
.29644 .49468 Mdot
.4884 .57578 Mdot
.34458 .35358 Mdot
.66294 .51408 Mdot
.40948 .68638 Mdot
.35386 .36046 Mdot
.46259 .57447 Mdot
.59266 .70498 Mdot
.64799 .57432 Mdot
.67171 .63323 Mdot
.37004 .36345 Mdot
.52665 .58309 Mdot
.65586 .55717 Mdot
.36737 .33947 Mdot
.46935 .55517 Mdot
.41777 .38638 Mdot
.67502 .58949 Mdot
.46418 .3099 Mdot
.28872 .5578 Mdot
.24371 .54 Mdot
.20263 .57443 Mdot
.31247 .58197 Mdot
.3817 .36012 Mdot
.47672 .58789 Mdot
.2592 .70972 Mdot
.35983 .33475 Mdot
.61554 .55476 Mdot
.64011 .55877 Mdot
.77025 .40996 Mdot
.45922 .58328 Mdot
.49208 .55745 Mdot
.57453 .24836 Mdot
.61278 .58432 Mdot
.48682 .57796 Mdot
.65612 .55438 Mdot
.53535 .32055 Mdot
.3467 .35882 Mdot
.73584 .74371 Mdot
.35094 .32094 Mdot
.6019 .52268 Mdot
.25392 .54563 Mdot
.28455 .55881 Mdot
.64508 .5461 Mdot
.44891 .49307 Mdot
.84158 .60472 Mdot
.6411 .55948 Mdot
.66694 .63124 Mdot
.47706 .77262 Mdot
.67337 .49052 Mdot
.58597 .3193 Mdot
.45985 .59097 Mdot
.52184 .31541 Mdot
.35685 .35615 Mdot
.39758 .64302 Mdot
.44347 .62262 Mdot
.36857 .35567 Mdot
.67378 .51448 Mdot
.46447 .61721 Mdot
.65008 .53892 Mdot
.63553 .51738 Mdot
.53452 .72799 Mdot
.40062 .6884 Mdot
.26972 .51683 Mdot
.42103 .65134 Mdot
.54332 .33345 Mdot
.68495 .21267 Mdot
.40769 .65218 Mdot
.77783 .41486 Mdot
.55341 .71729 Mdot
.26546 .71175 Mdot
.57256 .31552 Mdot
.38847 .66379 Mdot
.36926 .35291 Mdot
.52423 .69305 Mdot
.78437 .44952 Mdot
.37511 .38541 Mdot
.63969 .51599 Mdot
.52578 .31215 Mdot
.55332 .36856 Mdot
.35432 .38739 Mdot
.58681 .33255 Mdot
.67594 .5703 Mdot
.6051 .55329 Mdot
.3635 .38674 Mdot
.58509 .78767 Mdot
.33713 .35458 Mdot
.78752 .38733 Mdot
.61064 .51118 Mdot
.57563 .33264 Mdot
.80265 .42639 Mdot
.53258 .35689 Mdot
.4829 .55468 Mdot
.62248 .5614 Mdot
.40581 .64983 Mdot
.55849 .70902 Mdot
.24723 .52899 Mdot
.51511 .36245 Mdot
.56066 .31384 Mdot
.3453 .38391 Mdot
.58593 .33184 Mdot
.59552 .34824 Mdot
.33575 .33468 Mdot
.59074 .34676 Mdot
.67316 .52567 Mdot
.7302 .27571 Mdot
.58959 .33263 Mdot
.36265 .3641 Mdot
.40002 .68219 Mdot
.57241 .30936 Mdot
.31413 .44907 Mdot
.67984 .53053 Mdot
.31207 .52285 Mdot
.37828 .67808 Mdot
.5292 .31918 Mdot
.40385 .65373 Mdot
.26107 .54563 Mdot
.43487 .64404 Mdot
.40234 .35913 Mdot
.40054 .37039 Mdot
.47734 .53486 Mdot
.40865 .40139 Mdot
.54559 .34009 Mdot
.26131 .55879 Mdot
.67087 .55199 Mdot
.62966 .52737 Mdot
.39024 .68936 Mdot
.6052 .35347 Mdot
.49522 .25966 Mdot
.48245 .58044 Mdot
.48666 .29769 Mdot
.34641 .3762 Mdot
.26474 .47036 Mdot
.51489 .73115 Mdot
.30635 .36761 Mdot
.46364 .60751 Mdot
.47441 .57747 Mdot
.64412 .53879 Mdot
.45887 .752 Mdot
.40013 .63693 Mdot
.22413 .35027 Mdot
.631 .49369 Mdot
.26887 .50199 Mdot
.6525 .50991 Mdot
.62895 .60823 Mdot
.65608 .49234 Mdot
.4053 .69118 Mdot
.38663 .37219 Mdot
.56098 .3076 Mdot
.38847 .65939 Mdot
.28422 .54737 Mdot
.62853 .69232 Mdot
.63345 .57158 Mdot
.67184 .55728 Mdot
.27394 .5101 Mdot
.54249 .32218 Mdot
.27365 .52414 Mdot
.37001 .34182 Mdot
.41013 .65273 Mdot
.62163 .49525 Mdot
.45896 .58455 Mdot
.31232 .49995 Mdot
.36921 .38124 Mdot
.25037 .55324 Mdot
.37208 .32612 Mdot
.47128 .57943 Mdot
.68914 .53259 Mdot
.25436 .49648 Mdot
.47694 .60046 Mdot
.7309 .39885 Mdot
.5936 .69973 Mdot
.61861 .38214 Mdot
.28149 .51243 Mdot
.29865 .57606 Mdot
.357 .36189 Mdot
.35805 .32625 Mdot
.7877 .3835 Mdot
.85713 .55156 Mdot
.67701 .61513 Mdot
.47642 .2748 Mdot
.37097 .34237 Mdot
.36766 .37023 Mdot
.27158 .52242 Mdot
.5524 .3444 Mdot
.56222 .29155 Mdot
.27609 .55698 Mdot
.51979 .78522 Mdot
.56098 .33125 Mdot
.79274 .50771 Mdot
.30585 .50478 Mdot
.60215 .54907 Mdot
.70935 .28658 Mdot
.42182 .67909 Mdot
.47697 .76696 Mdot
.31738 .3419 Mdot
.63996 .52962 Mdot
.32218 .2413 Mdot
.26107 .52891 Mdot
.49907 .58448 Mdot
.42686 .34965 Mdot
.62064 .51047 Mdot
.64936 .50975 Mdot
.66945 .52123 Mdot
.381 .65407 Mdot
.70431 .3475 Mdot
.64263 .52568 Mdot
.59786 .70421 Mdot
.60762 .58619 Mdot
.32155 .52237 Mdot
.42054 .65073 Mdot
.44011 .73358 Mdot
.32859 .47267 Mdot
.47858 .30238 Mdot
.63232 .59513 Mdot
.37688 .33563 Mdot
.63283 .611 Mdot
.35618 .34788 Mdot
.38317 .38679 Mdot
.33848 .77024 Mdot
.55152 .30193 Mdot
.62674 .49618 Mdot
.29466 .49798 Mdot
.56222 .29107 Mdot
.63335 .61251 Mdot
.69862 .22268 Mdot
.33836 .37984 Mdot
.89943 .47831 Mdot
.36182 .32888 Mdot
.50787 .5601 Mdot
.57219 .35121 Mdot
.62079 .33783 Mdot
.54885 .72427 Mdot
.54504 .33158 Mdot
.33744 .57084 Mdot
.52231 .30614 Mdot
.43876 .80826 Mdot
.57295 .39113 Mdot
.35757 .36808 Mdot
.35031 .38603 Mdot
.62098 .60415 Mdot
.6693 .5372 Mdot
.54278 .75001 Mdot
.48324 .57961 Mdot
.63633 .58057 Mdot
.28701 .52793 Mdot
.30199 .4494 Mdot
.31928 .28056 Mdot
.58982 .34867 Mdot
.3748 .37703 Mdot
.65007 .51038 Mdot
.61276 .50793 Mdot
.62271 .5343 Mdot
.33405 .45653 Mdot
.79722 .51802 Mdot
.65916 .53618 Mdot
.61908 .60138 Mdot
.26278 .55381 Mdot
.34687 .52107 Mdot
.54914 .20752 Mdot
.33016 .75909 Mdot
.67255 .49911 Mdot
.41181 .67923 Mdot
.39451 .68522 Mdot
.6253 .60201 Mdot
.58456 .43129 Mdot
.46285 .6604 Mdot
.64021 .54798 Mdot
.62979 .68593 Mdot
.31126 .5359 Mdot
.48182 .55031 Mdot
.26606 .5469 Mdot
.60501 .335 Mdot
.46873 .56104 Mdot
.29219 .52392 Mdot
.58917 .7334 Mdot
.4695 .58951 Mdot
.41608 .38659 Mdot
.38936 .66718 Mdot
.65632 .55538 Mdot
.75886 .3645 Mdot
.28522 .48552 Mdot
.35766 .37526 Mdot
.57876 .34883 Mdot
.34888 .37707 Mdot
.25089 .57479 Mdot
.50182 .7846 Mdot
.47812 .55795 Mdot
.37794 .33604 Mdot
.6742 .63169 Mdot
.41736 .67499 Mdot
.36045 .33109 Mdot
.60037 .54235 Mdot
.61879 .59274 Mdot
.82992 .5986 Mdot
.67868 .54473 Mdot
.29464 .45046 Mdot
.3412 .33671 Mdot
.47283 .55499 Mdot
.64771 .54854 Mdot
.30766 .51911 Mdot
.45439 .5738 Mdot
.65026 .53718 Mdot
.25727 .50683 Mdot
.64152 .55758 Mdot
.41808 .64031 Mdot
.51518 .31964 Mdot
.5345 .71125 Mdot
.36947 .64306 Mdot
.39426 .64662 Mdot
.60662 .68851 Mdot
.62701 .5702 Mdot
.32606 .57889 Mdot
.56775 .33292 Mdot
.62784 .5098 Mdot
.43166 .78304 Mdot
.56651 .35562 Mdot
.56411 .34251 Mdot
.61113 .5012 Mdot
.37234 .3281 Mdot
.27195 .51378 Mdot
.42303 .66517 Mdot
.30155 .38356 Mdot
.64351 .5288 Mdot
.63371 .47664 Mdot
.39201 .65281 Mdot
.35007 .37108 Mdot
.61787 .50422 Mdot
.44464 .32449 Mdot
.57534 .72974 Mdot
.33499 .33989 Mdot
.62922 .59361 Mdot
.80662 .49896 Mdot
.56735 .36679 Mdot
.32103 .24252 Mdot
.34531 .47154 Mdot
.28711 .54909 Mdot
.48728 .57949 Mdot
.64908 .18002 Mdot
.39822 .68204 Mdot
.49679 .34373 Mdot
.62612 .53336 Mdot
.65233 .51753 Mdot
.53797 .32956 Mdot
.64769 .56722 Mdot
.59174 .34865 Mdot
.31673 .45236 Mdot
.86689 .53552 Mdot
.57309 .31772 Mdot
.56701 .32003 Mdot
.73408 .60818 Mdot
.26143 .48569 Mdot
.57706 .35762 Mdot
.65542 .56037 Mdot
.25685 .57893 Mdot
.5437 .52943 Mdot
.43 .62867 Mdot
.38594 .64332 Mdot
.58222 .31452 Mdot
.78675 .4529 Mdot
.60059 .55169 Mdot
.76264 .47726 Mdot
.46031 .66651 Mdot
.38134 .35656 Mdot
.64541 .47502 Mdot
.47966 .57879 Mdot
.25978 .54023 Mdot
.67423 .48698 Mdot
.6602 .55259 Mdot
.55282 .30481 Mdot
.43174 .66298 Mdot
.35714 .33554 Mdot
.48031 .59887 Mdot
.25044 .57257 Mdot
.39673 .66409 Mdot
.59815 .3482 Mdot
.79603 .40865 Mdot
.47199 .61399 Mdot
.48511 .59925 Mdot
.64316 .50517 Mdot
.65714 .48312 Mdot
.46533 .61121 Mdot
.36703 .35576 Mdot
.29204 .54765 Mdot
.49512 .58587 Mdot
.54255 .68698 Mdot
.56244 .75149 Mdot
.65648 .49713 Mdot
.56825 .30821 Mdot
.37255 .37653 Mdot
.48808 .55498 Mdot
.25272 .70353 Mdot
.68249 .52076 Mdot
.79385 .50884 Mdot
.39722 .62578 Mdot
.47644 .58279 Mdot
.55995 .29089 Mdot
.42264 .65825 Mdot
.61074 .51126 Mdot
.59874 .70775 Mdot
.63179 .58186 Mdot
.63027 .59909 Mdot
.29647 .5187 Mdot
.35895 .34149 Mdot
.48157 .532 Mdot
.26391 .53986 Mdot
.56654 .34357 Mdot
.7617 .48918 Mdot
.53015 .30805 Mdot
.52815 .30404 Mdot
.51038 .34249 Mdot
.34519 .37086 Mdot
.648 .17851 Mdot
.47155 .61182 Mdot
.62854 .55222 Mdot
.38564 .3654 Mdot
.5825 .35688 Mdot
.62177 .56959 Mdot
.5914 .35034 Mdot
.60348 .35081 Mdot
.63465 .58283 Mdot
.60661 .57512 Mdot
.60288 .70502 Mdot
.79965 .4916 Mdot
.4231 .64722 Mdot
.54948 .35154 Mdot
.79409 .47692 Mdot
.64723 .52177 Mdot
.66643 .54505 Mdot
.62929 .61212 Mdot
.38869 .6526 Mdot
.75568 .50862 Mdot
.62864 .52728 Mdot
.45157 .74906 Mdot
.61851 .56095 Mdot
.60671 .35281 Mdot
.36621 .41122 Mdot
.60109 .52747 Mdot
.26306 .55664 Mdot
.54698 .34968 Mdot
.4231 .67812 Mdot
.61191 .3605 Mdot
.62228 .45698 Mdot
.37504 .36249 Mdot
.56271 .31972 Mdot
.284 .55571 Mdot
.35369 .37167 Mdot
.33732 .35441 Mdot
.63167 .61429 Mdot
.30058 .5383 Mdot
.4315 .6645 Mdot
.3454 .3424 Mdot
.6138 .45098 Mdot
.35717 .36949 Mdot
.66986 .43872 Mdot
.68281 .54416 Mdot
.59702 .7064 Mdot
.49359 .58179 Mdot
.48622 .53519 Mdot
.34317 .33848 Mdot
.39316 .65774 Mdot
.61872 .50325 Mdot
.59197 .3377 Mdot
.40483 .68298 Mdot
.70783 .29412 Mdot
.27946 .55938 Mdot
.54932 .3648 Mdot
.30391 .38469 Mdot
.55787 .35577 Mdot
.47989 .76982 Mdot
.41858 .68561 Mdot
.49917 .58855 Mdot
.52773 .7181 Mdot
.49042 .56977 Mdot
.68177 .50207 Mdot
.62003 .50192 Mdot
.67325 .52193 Mdot
.25353 .54583 Mdot
.38342 .64868 Mdot
.58573 .32415 Mdot
.51387 .50741 Mdot
.3484 .37167 Mdot
.6624 .62268 Mdot
.49861 .58362 Mdot
.61346 .50964 Mdot
.5842 .35396 Mdot
.60276 .36046 Mdot
.70431 .33097 Mdot
.26366 .51281 Mdot
.51685 .52082 Mdot
.65794 .49591 Mdot
.52741 .50851 Mdot
.34219 .33896 Mdot
.4602 .31715 Mdot
.31371 .52232 Mdot
.89988 .47537 Mdot
.26646 .54052 Mdot
.53083 .55452 Mdot
.58165 .36483 Mdot
.41207 .66205 Mdot
.67438 .51123 Mdot
.50988 .32747 Mdot
.54293 .28871 Mdot
.4193 .69657 Mdot
.4197 .65826 Mdot
.32148 .42191 Mdot
.38229 .35346 Mdot
.47626 .602 Mdot
.61772 .5594 Mdot
.62585 .57762 Mdot
.6644 .55705 Mdot
.38098 .37203 Mdot
.60707 .57157 Mdot
.35152 .41421 Mdot
.6171 .465 Mdot
.43346 .78456 Mdot
.28833 .50391 Mdot
.17264 .50089 Mdot
.52767 .31751 Mdot
.75795 .50254 Mdot
.66435 .44182 Mdot
.59083 .70268 Mdot
.38946 .36907 Mdot
.46466 .55997 Mdot
.27264 .51824 Mdot
.31211 .29253 Mdot
.28892 .50274 Mdot
.78574 .68391 Mdot
.76982 .40836 Mdot
.38485 .40922 Mdot
.63061 .57809 Mdot
.29984 .52022 Mdot
.79065 .45708 Mdot
.49271 .58787 Mdot
.46374 .61711 Mdot
.61238 .46743 Mdot
.71845 .30038 Mdot
.4225 .64525 Mdot
.67244 .50489 Mdot
.52432 .31478 Mdot
.67541 .51583 Mdot
.67476 .51044 Mdot
.62503 .53264 Mdot
.33005 .34716 Mdot
.68351 .54402 Mdot
.67164 .5324 Mdot
.18621 .61664 Mdot
.47255 .63073 Mdot
.24202 .53198 Mdot
.62207 .33814 Mdot
.4184 .67523 Mdot
.60536 .33639 Mdot
.5315 .71386 Mdot
.3536 .3254 Mdot
.70342 .3334 Mdot
.60452 .53728 Mdot
.50252 .3448 Mdot
.35722 .32255 Mdot
.4235 .63282 Mdot
.47914 .5758 Mdot
.43273 .20309 Mdot
.27095 .48009 Mdot
.48681 .56203 Mdot
.25436 .51408 Mdot
.63897 .45414 Mdot
.58082 .32828 Mdot
.48965 .57085 Mdot
.35394 .33672 Mdot
.29547 .50602 Mdot
.60658 .69392 Mdot
.66437 .522 Mdot
.28493 .51226 Mdot
.47902 .59047 Mdot
.55815 .7106 Mdot
.5393 .71486 Mdot
.30048 .51626 Mdot
.39473 .37022 Mdot
.34021 .3537 Mdot
.41549 .68079 Mdot
.58812 .36564 Mdot
.54349 .31568 Mdot
.34723 .36536 Mdot
.29999 .29854 Mdot
.64233 .53092 Mdot
.65848 .52955 Mdot
.51799 .7215 Mdot
.61502 .53412 Mdot
.3631 .54996 Mdot
.48718 .56476 Mdot
.54948 .30953 Mdot
.61929 .5029 Mdot
.61641 .50838 Mdot
.66953 .50017 Mdot
.52215 .78732 Mdot
.25465 .54444 Mdot
.60343 .56961 Mdot
.41228 .63602 Mdot
.71551 .29582 Mdot
.6731 .54481 Mdot
.42979 .61519 Mdot
.58128 .36562 Mdot
.41445 .31366 Mdot
.35925 .37575 Mdot
.29098 .49355 Mdot
.2936 .49622 Mdot
.3655 .74595 Mdot
.53198 .31911 Mdot
.48749 .56246 Mdot
.316 .48736 Mdot
.49719 .55247 Mdot
.41925 .66131 Mdot
.68033 .58871 Mdot
.35833 .55467 Mdot
.24241 .53075 Mdot
.35069 .31595 Mdot
.62949 .50398 Mdot
.67224 .54396 Mdot
.48408 .28298 Mdot
.654 .55252 Mdot
.4093 .64612 Mdot
.37313 .33812 Mdot
.56354 .32181 Mdot
.4245 .64234 Mdot
.36995 .32995 Mdot
.54359 .32719 Mdot
.6102 .58813 Mdot
.62039 .56688 Mdot
.57166 .34696 Mdot
.59709 .35272 Mdot
.63569 .53655 Mdot
.35511 .79023 Mdot
.5568 .30698 Mdot
.57602 .34998 Mdot
.71589 .2972 Mdot
.25215 .50125 Mdot
.45225 .58019 Mdot
.38028 .3358 Mdot
.67089 .52943 Mdot
.28364 .5036 Mdot
.41094 .67011 Mdot
.55689 .3134 Mdot
.66128 .48467 Mdot
.64778 .52754 Mdot
.41415 .67765 Mdot
.3883 .64487 Mdot
.39273 .66829 Mdot
.35532 .38754 Mdot
.60335 .53873 Mdot
.57594 .35463 Mdot
.37886 .38152 Mdot
.40923 .68753 Mdot
.39472 .63789 Mdot
.47507 .81345 Mdot
.63889 .53308 Mdot
.38397 .65187 Mdot
.67292 .20356 Mdot
.59929 .72957 Mdot
.49055 .5499 Mdot
.24813 .55851 Mdot
.2676 .5827 Mdot
.5213 .58346 Mdot
.36181 .3428 Mdot
.66053 .6272 Mdot
.42922 .63085 Mdot
.48358 .59213 Mdot
.6619 .52696 Mdot
.65966 .47556 Mdot
.40394 .68136 Mdot
.49978 .78484 Mdot
.54694 .3036 Mdot
.63653 .33338 Mdot
.41958 .67363 Mdot
.30226 .51543 Mdot
.31541 .52154 Mdot
.26948 .5347 Mdot
.65866 .49164 Mdot
.77113 .55337 Mdot
.60824 .44058 Mdot
.73334 .48515 Mdot
.38013 .34956 Mdot
.60339 .3591 Mdot
.71816 .2884 Mdot
.56195 .34113 Mdot
.25368 .52482 Mdot
.3934 .6567 Mdot
.5379 .32459 Mdot
.34155 .36766 Mdot
.34011 .34889 Mdot
.25561 .49533 Mdot
.269 .54477 Mdot
.27801 .52805 Mdot
.55192 .35919 Mdot
.58757 .36136 Mdot
.62655 .57473 Mdot
.57564 .31519 Mdot
.31974 .45896 Mdot
.31892 .45502 Mdot
.27241 .48393 Mdot
.3635 .35874 Mdot
.54998 .32858 Mdot
.65065 .55998 Mdot
.59309 .66752 Mdot
.31532 .49665 Mdot
.42757 .6686 Mdot
.73011 .27416 Mdot
.85049 .56238 Mdot
.63926 .48191 Mdot
.37911 .35985 Mdot
.49732 .55793 Mdot
.66979 .5148 Mdot
.28691 .55015 Mdot
.5137 .57824 Mdot
.46097 .58456 Mdot
.66827 .55825 Mdot
.64905 .57884 Mdot
.37328 .37251 Mdot
.52895 .71206 Mdot
.48429 .59328 Mdot
.63679 .62014 Mdot
.37946 .34295 Mdot
.31095 .50287 Mdot
.19644 .56163 Mdot
.5522 .25268 Mdot
.46071 .71166 Mdot
.46475 .56932 Mdot
.68335 .52382 Mdot
.28806 .53142 Mdot
.42402 .63837 Mdot
.28356 .53328 Mdot
.60227 .33452 Mdot
.24867 .50623 Mdot
.6465 .55834 Mdot
.57333 .35535 Mdot
.33887 .35082 Mdot
.51452 .69082 Mdot
.47601 .52046 Mdot
.30777 .51577 Mdot
.48943 .5981 Mdot
.61121 .58079 Mdot
.61909 .44764 Mdot
.48598 .53572 Mdot
.66228 .55321 Mdot
.35487 .34958 Mdot
.58816 .35094 Mdot
.35772 .38125 Mdot
.46267 .55865 Mdot
.596 .41425 Mdot
.36145 .37652 Mdot
.76353 .56699 Mdot
.41309 .63072 Mdot
.50816 .78644 Mdot
.63861 .55111 Mdot
.355 .33833 Mdot
.66944 .55886 Mdot
.54601 .34561 Mdot
.57829 .74104 Mdot
.57992 .72204 Mdot
.34703 .35701 Mdot
.5096 .54852 Mdot
.55448 .71561 Mdot
.45065 .58564 Mdot
.37187 .34411 Mdot
.61082 .72739 Mdot
.48017 .56514 Mdot
.39918 .66614 Mdot
.39284 .63838 Mdot
.39815 .65663 Mdot
.66136 .53375 Mdot
.81014 .46979 Mdot
.40038 .68651 Mdot
.38265 .30125 Mdot
.40887 .6412 Mdot
.53042 .56812 Mdot
.49911 .25725 Mdot
.40314 .63497 Mdot
.64568 .55276 Mdot
.6258 .46866 Mdot
.6639 .62922 Mdot
.30073 .54478 Mdot
.41173 .21517 Mdot
.18491 .60892 Mdot
.6463 .52053 Mdot
.72274 .27872 Mdot
.51214 .32018 Mdot
.50191 .58602 Mdot
.58361 .71558 Mdot
.68288 .63391 Mdot
.55935 .34334 Mdot
.52839 .71566 Mdot
.54769 .36095 Mdot
.50194 .56859 Mdot
.65754 .53329 Mdot
.54561 .34744 Mdot
.5157 .36269 Mdot
.55528 .78944 Mdot
.48934 .28967 Mdot
.54691 .32608 Mdot
.3647 .33707 Mdot
.36554 .34659 Mdot
.35185 .35101 Mdot
.27528 .54753 Mdot
.56507 .31757 Mdot
.6165 .58746 Mdot
.28265 .54982 Mdot
.63692 .51823 Mdot
.34623 .36063 Mdot
.58688 .71321 Mdot
.56663 .32065 Mdot
.63844 .54738 Mdot
.78959 .46632 Mdot
.2632 .50019 Mdot
.41186 .68016 Mdot
.72521 .2758 Mdot
.25161 .55783 Mdot
.39319 .3498 Mdot
.59645 .32595 Mdot
.46733 .63075 Mdot
.64527 .62483 Mdot
.64825 .49984 Mdot
.62806 .5602 Mdot
.65825 .63097 Mdot
.77259 .40497 Mdot
.46398 .60163 Mdot
.2836 .5474 Mdot
.24946 .50664 Mdot
.68096 .53021 Mdot
.56596 .31535 Mdot
.4269 .68068 Mdot
.42888 .61923 Mdot
.52821 .53469 Mdot
.5462 .71994 Mdot
.5976 .70422 Mdot
.61224 .54492 Mdot
.74696 .54769 Mdot
.28711 .55366 Mdot
.49634 .54868 Mdot
.54136 .72383 Mdot
.40338 .65848 Mdot
.63136 .51824 Mdot
.61869 .31417 Mdot
.5579 .31646 Mdot
.27935 .51247 Mdot
.33327 .36581 Mdot
.47005 .61511 Mdot
.27062 .48402 Mdot
.68097 .52967 Mdot
.61695 .50697 Mdot
.35743 .33259 Mdot
.59689 .3288 Mdot
.39989 .67408 Mdot
.27806 .5516 Mdot
.40917 .6608 Mdot
.58584 .33482 Mdot
.55571 .31284 Mdot
.62764 .51575 Mdot
.51807 .51817 Mdot
.30811 .51084 Mdot
.66462 .49056 Mdot
.28702 .51708 Mdot
.34534 .51718 Mdot
.34175 .37629 Mdot
.62664 .5116 Mdot
.57435 .29418 Mdot
.34468 .36035 Mdot
.64612 .51781 Mdot
.65509 .62724 Mdot
.61585 .50716 Mdot
.30052 .52079 Mdot
.42155 .61892 Mdot
.40228 .66522 Mdot
.69243 .46472 Mdot
.70333 .30754 Mdot
.61377 .52858 Mdot
.2811 .48537 Mdot
.60321 .46513 Mdot
.37113 .37049 Mdot
.56893 .36206 Mdot
.16665 .45822 Mdot
.36218 .36617 Mdot
.63791 .55457 Mdot
.40803 .65126 Mdot
.60011 .35141 Mdot
.47351 .55639 Mdot
.50367 .75051 Mdot
.50113 .53508 Mdot
.52232 .52087 Mdot
.47027 .60071 Mdot
.48006 .27291 Mdot
.28009 .52927 Mdot
.58302 .35528 Mdot
.37743 .3552 Mdot
.37407 .36634 Mdot
.25339 .51817 Mdot
.70716 .30143 Mdot
.57561 .22257 Mdot
.66656 .19452 Mdot
.2878 .47892 Mdot
.39973 .64876 Mdot
.58081 .73771 Mdot
.26838 .53356 Mdot
.2458 .53087 Mdot
.33848 .47051 Mdot
.48107 .28687 Mdot
.55091 .338 Mdot
.64831 .52622 Mdot
.71645 .28204 Mdot
.62517 .54149 Mdot
.46473 .7077 Mdot
.34803 .36261 Mdot
.56824 .3619 Mdot
.35436 .4423 Mdot
.67302 .49377 Mdot
.66214 .5048 Mdot
.3113 .44908 Mdot
.48366 .57648 Mdot
.28396 .72386 Mdot
.62191 .54648 Mdot
.2788 .54275 Mdot
.56956 .27807 Mdot
.49947 .57576 Mdot
.79097 .4668 Mdot
.34387 .33426 Mdot
.48209 .55609 Mdot
.50032 .57576 Mdot
.74636 .55519 Mdot
.53747 .35258 Mdot
.53911 .31605 Mdot
.38545 .65379 Mdot
.52145 .25265 Mdot
.34604 .3312 Mdot
.45681 .30185 Mdot
.6563 .55895 Mdot
.38575 .3872 Mdot
.36606 .65839 Mdot
.64255 .51957 Mdot
.63462 .61398 Mdot
.70387 .33041 Mdot
.64742 .48119 Mdot
.62964 .45573 Mdot
.35869 .36306 Mdot
.43652 .77928 Mdot
.6175 .58106 Mdot
.28314 .51272 Mdot
.55407 .3472 Mdot
.54077 .35907 Mdot
.42852 .64437 Mdot
.35081 .46913 Mdot
.88185 .51013 Mdot
.56674 .36112 Mdot
.66542 .52445 Mdot
.36815 .37129 Mdot
.47682 .55613 Mdot
.49276 .58085 Mdot
.51291 .55013 Mdot
.55595 .31929 Mdot
.49683 .58013 Mdot
.49706 .33078 Mdot
.52912 .71471 Mdot
.75898 .49873 Mdot
.34717 .35145 Mdot
.40295 .64813 Mdot
.53834 .53406 Mdot
.33936 .49389 Mdot
.61638 .55758 Mdot
.46347 .70891 Mdot
.51676 .32864 Mdot
.40643 .64671 Mdot
.67187 .51171 Mdot
.46948 .60427 Mdot
.63212 .6762 Mdot
.43848 .64705 Mdot
.46761 .60078 Mdot
.63336 .48503 Mdot
.54451 .33741 Mdot
.48951 .56108 Mdot
.56169 .32407 Mdot
.67177 .50803 Mdot
.46628 .67179 Mdot
.55293 .35463 Mdot
.39673 .22303 Mdot
.47772 .61034 Mdot
.36107 .32596 Mdot
.65921 .47081 Mdot
.67254 .4986 Mdot
.78362 .52934 Mdot
.48668 .55293 Mdot
.33665 .24614 Mdot
.2896 .5112 Mdot
.26828 .72008 Mdot
.23678 .54364 Mdot
.32773 .43929 Mdot
.43619 .32745 Mdot
.65775 .47901 Mdot
.70732 .30302 Mdot
.77544 .5454 Mdot
.39364 .3687 Mdot
.78045 .53807 Mdot
.66939 .53698 Mdot
.64407 .50514 Mdot
.28685 .51578 Mdot
.36506 .39843 Mdot
.60578 .51105 Mdot
.54244 .72353 Mdot
.42399 .63184 Mdot
.57367 .33925 Mdot
.66411 .53822 Mdot
.52693 .37881 Mdot
.30144 .50998 Mdot
.62201 .37793 Mdot
.6429 .55022 Mdot
.48351 .57616 Mdot
.37669 .3909 Mdot
.33874 .348 Mdot
.30182 .52884 Mdot
.30392 .52648 Mdot
.67321 .50014 Mdot
.36761 .3851 Mdot
.61959 .57367 Mdot
.55545 .71443 Mdot
.47673 .59172 Mdot
.41837 .66659 Mdot
.64348 .56603 Mdot
.60797 .25118 Mdot
.56739 .83038 Mdot
.65857 .49252 Mdot
.5279 .31117 Mdot
.27823 .52381 Mdot
.25051 .5375 Mdot
.54432 .31601 Mdot
.25034 .53596 Mdot
.63739 .32995 Mdot
.81031 .4734 Mdot
.41733 .66055 Mdot
.58964 .46277 Mdot
.39786 .64313 Mdot
.48525 .55476 Mdot
.6378 .53448 Mdot
.25172 .31994 Mdot
.28737 .47951 Mdot
.56354 .6094 Mdot
.35099 .3674 Mdot
.5032 .55117 Mdot
.60453 .56028 Mdot
.38066 .68286 Mdot
.25987 .53391 Mdot
.45885 .61316 Mdot
.62641 .52654 Mdot
.55102 .35673 Mdot
.63119 .47727 Mdot
.50597 .56331 Mdot
.49321 .5569 Mdot
.45625 .60533 Mdot
.36998 .32995 Mdot
.59205 .3436 Mdot
.32214 .42335 Mdot
.26763 .49483 Mdot
.63845 .58028 Mdot
.66689 .52193 Mdot
.59777 .36193 Mdot
.63095 .55672 Mdot
.36698 .3865 Mdot
.61548 .15335 Mdot
.39125 .66302 Mdot
.48266 .5523 Mdot
.42702 .23805 Mdot
.45493 .60518 Mdot
.62716 .49012 Mdot
.7087 .62506 Mdot
.62355 .31808 Mdot
.36841 .32758 Mdot
.64169 .59314 Mdot
.24068 .53136 Mdot
.39997 .67193 Mdot
.34121 .36847 Mdot
.60595 .55835 Mdot
.64596 .55599 Mdot
.40536 .64826 Mdot
.35621 .43657 Mdot
.41949 .62375 Mdot
.37734 .35142 Mdot
.49772 .54205 Mdot
.59657 .6661 Mdot
.64529 .53735 Mdot
.48531 .56873 Mdot
.58616 .34398 Mdot
.38311 .35999 Mdot
.70594 .35197 Mdot
.5024 .57012 Mdot
.30155 .37956 Mdot
.33983 .3423 Mdot
.6439 .5021 Mdot
.53481 .32986 Mdot
.55217 .37528 Mdot
.58586 .34962 Mdot
.39368 .77527 Mdot
.30754 .41557 Mdot
.28113 .52492 Mdot
.36412 .36048 Mdot
.27847 .50315 Mdot
.41076 .63072 Mdot
.56126 .74943 Mdot
.30601 .52132 Mdot
.5479 .29792 Mdot
.28474 .50001 Mdot
.62029 .5733 Mdot
.3565 .32413 Mdot
.3067 .50402 Mdot
.65191 .56365 Mdot
.61305 .59413 Mdot
.49443 .56331 Mdot
.42532 .68104 Mdot
.5372 .71744 Mdot
.63231 .54745 Mdot
.48094 .57086 Mdot
.63906 .54389 Mdot
.36629 .38626 Mdot
.50549 .68976 Mdot
.64461 .57887 Mdot
.2892 .47937 Mdot
.45231 .19172 Mdot
.25864 .49478 Mdot
.46228 .49975 Mdot
.63685 .52044 Mdot
.64285 .53601 Mdot
.60967 .57968 Mdot
.73137 .30089 Mdot
.39713 .3693 Mdot
.6906 .52653 Mdot
.25692 .55592 Mdot
.55671 .33674 Mdot
.53392 .31907 Mdot
.68781 .61236 Mdot
.48549 .5654 Mdot
.35594 .38668 Mdot
.64248 .53382 Mdot
.50241 .55643 Mdot
.53314 .73929 Mdot
.50825 .25804 Mdot
.32494 .46452 Mdot
.25099 .51592 Mdot
.5802 .36898 Mdot
.25632 .54959 Mdot
.60586 .56102 Mdot
.49824 .57541 Mdot
.30401 .40714 Mdot
.34923 .30659 Mdot
.40088 .6719 Mdot
.64407 .50964 Mdot
.53129 .78815 Mdot
.26333 .55383 Mdot
.29818 .54169 Mdot
.62053 .57497 Mdot
.53575 .26888 Mdot
.53208 .82762 Mdot
.38562 .36943 Mdot
.64881 .42173 Mdot
.77384 .37016 Mdot
.73069 .69439 Mdot
.37059 .35672 Mdot
.63689 .61492 Mdot
.29646 .55164 Mdot
.33308 .72295 Mdot
.55906 .34072 Mdot
.40106 .67401 Mdot
.64944 .56461 Mdot
.5467 .29898 Mdot
.28584 .47776 Mdot
.5957 .33684 Mdot
.48576 .57952 Mdot
.35592 .32278 Mdot
.25815 .54155 Mdot
.33232 .36682 Mdot
.5839 .29892 Mdot
.39495 .65237 Mdot
.45467 .74611 Mdot
.61239 .45952 Mdot
.70376 .3263 Mdot
.60263 .54878 Mdot
.47752 .62947 Mdot
.6031 .5639 Mdot
.53917 .35945 Mdot
.6395 .55188 Mdot
.62792 .59308 Mdot
.28703 .55833 Mdot
.65403 .49772 Mdot
.65279 .56092 Mdot
.79091 .47052 Mdot
.64594 .51272 Mdot
.67239 .50326 Mdot
.64725 .49948 Mdot
.53431 .30639 Mdot
.62462 .52438 Mdot
.59289 .3557 Mdot
.50252 .35067 Mdot
.26663 .49599 Mdot
.40364 .63349 Mdot
.4009 .63585 Mdot
.47483 .677 Mdot
.52899 .78781 Mdot
.7167 .28469 Mdot
.55868 .33171 Mdot
.34206 .34039 Mdot
.62562 .57542 Mdot
.48926 .82089 Mdot
.46722 .67255 Mdot
.30761 .538 Mdot
.30083 .50318 Mdot
.66657 .55669 Mdot
.84321 .57352 Mdot
.62206 .55224 Mdot
.51813 .7309 Mdot
.6614 .53488 Mdot
.62376 .51439 Mdot
.23856 .54353 Mdot
.47874 .76938 Mdot
.60391 .57285 Mdot
.53226 .34477 Mdot
.40401 .67408 Mdot
.48957 .56424 Mdot
.46885 .67506 Mdot
.79287 .3956 Mdot
.58751 .25511 Mdot
.61042 .58145 Mdot
.27855 .55287 Mdot
.55153 .31125 Mdot
.51993 .72145 Mdot
.38003 .37998 Mdot
.50585 .75374 Mdot
.67578 .44119 Mdot
.38743 .36798 Mdot
.39891 .66749 Mdot
.31466 .49934 Mdot
.6639 .49763 Mdot
.28986 .53348 Mdot
.67097 .49069 Mdot
.5236 .74248 Mdot
.41759 .664 Mdot
.52188 .30436 Mdot
.3642 .33573 Mdot
.5433 .30218 Mdot
.61723 .38515 Mdot
.4644 .6777 Mdot
.225 .68085 Mdot
.26804 .48596 Mdot
.50994 .50181 Mdot
.5786 .36134 Mdot
.68234 .51815 Mdot
.66257 .19413 Mdot
.58028 .33297 Mdot
.54911 .35334 Mdot
.49522 .73165 Mdot
.47892 .77657 Mdot
.65537 .49036 Mdot
.56481 .30541 Mdot
.31329 .49482 Mdot
.41942 .65391 Mdot
.6636 .55578 Mdot
.49866 .56961 Mdot
.53768 .32637 Mdot
.25556 .52974 Mdot
.4726 .76258 Mdot
.27351 .54453 Mdot
.55571 .34446 Mdot
.28777 .49042 Mdot
.324 .41981 Mdot
.30627 .52017 Mdot
.63762 .56511 Mdot
.64315 .53444 Mdot
.56301 .38539 Mdot
.55582 .31275 Mdot
.62682 .49034 Mdot
.62708 .54414 Mdot
.57903 .35733 Mdot
.3102 .48352 Mdot
.61535 .28213 Mdot
.62404 .49763 Mdot
.64468 .52879 Mdot
.38895 .65729 Mdot
.54906 .69203 Mdot
.51425 .70381 Mdot
.62435 .57213 Mdot
.39747 .65151 Mdot
.55759 .36315 Mdot
.63611 .53987 Mdot
.47466 .77025 Mdot
.30491 .54808 Mdot
.61305 .57026 Mdot
.47075 .56018 Mdot
.60489 .51941 Mdot
.61197 .77773 Mdot
.61022 .57956 Mdot
.56686 .34899 Mdot
.56334 .35361 Mdot
.31624 .52933 Mdot
.57247 .34536 Mdot
.48362 .55255 Mdot
.34203 .35954 Mdot
.67233 .42898 Mdot
.49978 .5492 Mdot
.45905 .59808 Mdot
.47187 .61171 Mdot
.49158 .59237 Mdot
.41146 .61443 Mdot
.32616 .46396 Mdot
.4647 .57318 Mdot
.58864 .35533 Mdot
.5627 .4289 Mdot
.4684 .55494 Mdot
.36339 .3883 Mdot
.49894 .57805 Mdot
.61245 .56771 Mdot
.61865 .59758 Mdot
.61869 .33693 Mdot
.38078 .38078 Mdot
.47755 .53777 Mdot
.66298 .55641 Mdot
.62207 .3175 Mdot
.66511 .53881 Mdot
.4334 .64865 Mdot
.56685 .32302 Mdot
.27271 .54993 Mdot
.42056 .66396 Mdot
.4783 .59733 Mdot
.41197 .68175 Mdot
.28886 .52677 Mdot
.34907 .33924 Mdot
.64022 .5632 Mdot
.43456 .63284 Mdot
.40831 .63313 Mdot
.64399 .46739 Mdot
.56169 .35462 Mdot
.50658 .53407 Mdot
.63506 .53453 Mdot
.60831 .57842 Mdot
.5429 .31538 Mdot
.31452 .24309 Mdot
.66014 .4993 Mdot
.63193 .61696 Mdot
.52948 .34878 Mdot
.50464 .55626 Mdot
.27742 .54959 Mdot
.66404 .48594 Mdot
.35739 .37846 Mdot
.34709 .36619 Mdot
.28818 .48081 Mdot
.53875 .31958 Mdot
.25319 .53774 Mdot
.6782 .49787 Mdot
.49673 .58245 Mdot
.66798 .54737 Mdot
.2864 .45519 Mdot
.36462 .23145 Mdot
.59899 .34939 Mdot
.26399 .49636 Mdot
.54867 .74358 Mdot
.37471 .32994 Mdot
.2851 .47067 Mdot
.53215 .34701 Mdot
.55738 .30276 Mdot
.54502 .31951 Mdot
.40834 .63555 Mdot
.26667 .54277 Mdot
.61115 .35503 Mdot
.61183 .35316 Mdot
.6085 .52451 Mdot
.65915 .5606 Mdot
.56652 .36656 Mdot
.3371 .48303 Mdot
.40243 .66742 Mdot
.25105 .55127 Mdot
.54078 .82907 Mdot
.38501 .36443 Mdot
.79196 .46849 Mdot
.61752 .56264 Mdot
.90236 .46837 Mdot
.62236 .55152 Mdot
.66572 .53057 Mdot
.60502 .33502 Mdot
.39814 .63179 Mdot
.41706 .65125 Mdot
.57628 .36071 Mdot
.60082 .34285 Mdot
.43091 .64874 Mdot
.56074 .67819 Mdot
.58795 .7886 Mdot
.53251 .73218 Mdot
.59358 .33531 Mdot
.65652 .43289 Mdot
.35514 .3538 Mdot
.5141 .31858 Mdot
.34055 .41863 Mdot
.29309 .48972 Mdot
.30698 .51601 Mdot
.35228 .3329 Mdot
.66426 .49969 Mdot
.2384 .53845 Mdot
.60142 .54397 Mdot
.38632 .40994 Mdot
.62811 .60695 Mdot
.36953 .80679 Mdot
.63404 .5614 Mdot
.45998 .48898 Mdot
.48916 .2646 Mdot
.62046 .49429 Mdot
.8029 .44165 Mdot
.39987 .67672 Mdot
.54615 .3649 Mdot
.37734 .38705 Mdot
.71642 .28001 Mdot
.64423 .53668 Mdot
.57122 .30893 Mdot
.37276 .34022 Mdot
.34711 .24257 Mdot
.63753 .61961 Mdot
.61299 .50971 Mdot
.65376 .18586 Mdot
.52893 .29887 Mdot
.27599 .5487 Mdot
.63959 .41329 Mdot
.6046 .34987 Mdot
.64354 .62186 Mdot
.30472 .48224 Mdot
.62883 .6722 Mdot
.58105 .31601 Mdot
.41759 .62359 Mdot
.56974 .33512 Mdot
.4281 .65932 Mdot
.61039 .35617 Mdot
.2698 .49584 Mdot
.65076 .50613 Mdot
.26643 .49747 Mdot
.422 .67786 Mdot
.26597 .48993 Mdot
.38043 .38419 Mdot
.46877 .58416 Mdot
.34515 .35913 Mdot
.56942 .74657 Mdot
.71485 .36873 Mdot
.35733 .34169 Mdot
.71202 .61041 Mdot
.64761 .55712 Mdot
.60718 .35905 Mdot
.2683 .55023 Mdot
.27011 .56394 Mdot
.5399 .7179 Mdot
.54736 .33588 Mdot
.25585 .52057 Mdot
.62132 .45135 Mdot
.30678 .28614 Mdot
.61053 .59217 Mdot
.16588 .47494 Mdot
.57665 .3538 Mdot
.26867 .56287 Mdot
.51817 .72617 Mdot
.56888 .30256 Mdot
.30778 .50808 Mdot
.3661 .34026 Mdot
.35712 .37804 Mdot
.63128 .56377 Mdot
.34011 .38285 Mdot
.30249 .54299 Mdot
.60303 .41635 Mdot
.56545 .36309 Mdot
.37462 .22674 Mdot
.39302 .65971 Mdot
.2569 .54809 Mdot
.48296 .59049 Mdot
.57577 .295 Mdot
.28004 .50108 Mdot
.87602 .52003 Mdot
.52814 .8591 Mdot
.25583 .5238 Mdot
.56572 .32397 Mdot
.55293 .31854 Mdot
.63867 .48564 Mdot
.54365 .72116 Mdot
.25982 .53198 Mdot
.24848 .32162 Mdot
.60076 .70514 Mdot
.4701 .57976 Mdot
.18553 .61326 Mdot
.61529 .58637 Mdot
.6032 .55243 Mdot
.38232 .36402 Mdot
.66108 .50571 Mdot
.59941 .34078 Mdot
.62204 .55041 Mdot
.35053 .37949 Mdot
.28702 .48184 Mdot
.64092 .53914 Mdot
.39902 .67023 Mdot
.37482 .37412 Mdot
.36766 .38185 Mdot
.28662 .49224 Mdot
.53947 .32128 Mdot
.71564 .27375 Mdot
.26974 .54557 Mdot
.60336 .53372 Mdot
.47765 .57518 Mdot
.64791 .49952 Mdot
.50647 .32903 Mdot
.55559 .36922 Mdot
.26029 .55087 Mdot
.66384 .47743 Mdot
.36837 .36323 Mdot
.29044 .55711 Mdot
.61328 .58621 Mdot
.31123 .5093 Mdot
.51853 .55884 Mdot
.26245 .58006 Mdot
.5863 .29778 Mdot
.49709 .59176 Mdot
.5586 .30131 Mdot
.46605 .57369 Mdot
.36829 .75113 Mdot
.39985 .66641 Mdot
.24537 .51365 Mdot
.38917 .226 Mdot
.26236 .49981 Mdot
.64623 .51399 Mdot
.64202 .55787 Mdot
.29091 .51708 Mdot
.39602 .65032 Mdot
.52995 .56663 Mdot
.42962 .62355 Mdot
.56233 .31833 Mdot
.67686 .63299 Mdot
.47904 .84943 Mdot
.28947 .56094 Mdot
.34974 .33106 Mdot
.55635 .24958 Mdot
.45999 .59961 Mdot
.38183 .38181 Mdot
.37139 .38024 Mdot
.41563 .68274 Mdot
.24624 .52803 Mdot
.52142 .3176 Mdot
.34203 .3322 Mdot
.58801 .31831 Mdot
.46799 .76465 Mdot
.49908 .58206 Mdot
.53828 .50787 Mdot
.47049 .6041 Mdot
.53178 .7163 Mdot
.3488 .324 Mdot
.6536 .54701 Mdot
.51991 .52756 Mdot
.37339 .34398 Mdot
.40551 .68846 Mdot
.62646 .60589 Mdot
.25723 .51709 Mdot
.68881 .22048 Mdot
.63756 .56613 Mdot
.63639 .52496 Mdot
.38102 .35042 Mdot
.80199 .41884 Mdot
.53729 .35139 Mdot
.54505 .33949 Mdot
.27944 .52939 Mdot
.49723 .72559 Mdot
.62416 .53031 Mdot
.64504 .56061 Mdot
.29385 .51563 Mdot
.4834 .56333 Mdot
.20326 .65397 Mdot
.64848 .52871 Mdot
.35959 .35882 Mdot
.63205 .6115 Mdot
.39478 .36878 Mdot
.64037 .59115 Mdot
.64997 .51334 Mdot
.60868 .51499 Mdot
.60751 .58101 Mdot
.346 .35697 Mdot
.47116 .60126 Mdot
.45577 .58768 Mdot
.58835 .34705 Mdot
.678 .54599 Mdot
.60169 .70296 Mdot
.64774 .53281 Mdot
.3982 .67434 Mdot
.5117 .70678 Mdot
.63044 .58386 Mdot
.67364 .55383 Mdot
.59993 .70884 Mdot
.67376 .51955 Mdot
.38106 .34886 Mdot
.55116 .32229 Mdot
.36958 .36467 Mdot
.35541 .32922 Mdot
.28283 .49832 Mdot
.39647 .68504 Mdot
.66784 .49117 Mdot
.4264 .63744 Mdot
.63678 .49491 Mdot
.46856 .54966 Mdot
.55844 .71161 Mdot
.51939 .73157 Mdot
.43651 .65935 Mdot
.64881 .55866 Mdot
.28517 .52735 Mdot
.24482 .54051 Mdot
.65965 .62677 Mdot
.67379 .48615 Mdot
.34632 .38952 Mdot
.35569 .33844 Mdot
.31911 .4547 Mdot
.21016 .56329 Mdot
.43424 .63765 Mdot
.52478 .56559 Mdot
.60924 .58608 Mdot
.63842 .5133 Mdot
.46472 .59595 Mdot
.27822 .50761 Mdot
.46433 .57509 Mdot
.32661 .4686 Mdot
.38796 .37811 Mdot
.37651 .3619 Mdot
.63595 .56345 Mdot
.83999 .60939 Mdot
.58282 .32912 Mdot
.552 .31813 Mdot
.34674 .37723 Mdot
.25756 .49584 Mdot
.48863 .57944 Mdot
.72186 .24864 Mdot
.56302 .37181 Mdot
.40475 .6314 Mdot
.67744 .53027 Mdot
.289 .48749 Mdot
.59208 .34978 Mdot
.43261 .63087 Mdot
.68046 .54962 Mdot
.3017 .47861 Mdot
.65374 .54235 Mdot
.58696 .45383 Mdot
.5841 .36324 Mdot
.55696 .70065 Mdot
.53942 .29794 Mdot
.34828 .35976 Mdot
.35052 .32681 Mdot
.64687 .51679 Mdot
.71571 .24346 Mdot
.55811 .27175 Mdot
.33632 .33567 Mdot
.38699 .65072 Mdot
.46946 .58861 Mdot
.39939 .68636 Mdot
.28448 .51677 Mdot
.39959 .66795 Mdot
.28021 .50016 Mdot
.31764 .49468 Mdot
.52534 .31626 Mdot
.4058 .64829 Mdot
.78006 .43151 Mdot
.49767 .57532 Mdot
.3835 .65128 Mdot
.64854 .57257 Mdot
.63133 .49277 Mdot
.26137 .52403 Mdot
.42339 .634 Mdot
.65895 .48426 Mdot
.42021 .24059 Mdot
.3589 .32662 Mdot
.37999 .38506 Mdot
.4867 .57898 Mdot
.28727 .55466 Mdot
.526 .31776 Mdot
.55193 .74468 Mdot
.52919 .29098 Mdot
.64538 .56146 Mdot
.66708 .4915 Mdot
.56124 .29055 Mdot
.52782 .31814 Mdot
.65151 .51457 Mdot
.76244 .48335 Mdot
.4821 .59223 Mdot
.35246 .37605 Mdot
.5644 .3177 Mdot
.56026 .31131 Mdot
.3042 .53826 Mdot
.5396 .33295 Mdot
.52571 .51953 Mdot
.38679 .37884 Mdot
.45546 .58493 Mdot
.36532 .36315 Mdot
.45298 .64675 Mdot
.26351 .5122 Mdot
.36862 .2357 Mdot
.54467 .34041 Mdot
.62016 .50066 Mdot
.54415 .34233 Mdot
.39268 .6695 Mdot
.57662 .31448 Mdot
.51126 .32139 Mdot
.65016 .56349 Mdot
.47022 .60016 Mdot
.48879 .55564 Mdot
.5365 .72001 Mdot
.58262 .33221 Mdot
.6635 .49291 Mdot
.61935 .5358 Mdot
.62808 .54711 Mdot
.55525 .71743 Mdot
.53338 .30942 Mdot
.79374 .39776 Mdot
.6134 .35416 Mdot
.58716 .36171 Mdot
.59192 .82935 Mdot
.49185 .55286 Mdot
.4611 .58748 Mdot
.42762 .33892 Mdot
.64721 .52679 Mdot
.25098 .53034 Mdot
.60403 .53316 Mdot
.47149 .59642 Mdot
.65441 .57156 Mdot
.42315 .64617 Mdot
.67627 .50052 Mdot
.47404 .5716 Mdot
.26627 .54765 Mdot
.61555 .50708 Mdot
.64043 .53225 Mdot
.48702 .56067 Mdot
.54409 .3451 Mdot
.54847 .30446 Mdot
.54382 .28148 Mdot
.42781 .66516 Mdot
.35911 .34727 Mdot
.60402 .53915 Mdot
.28181 .52837 Mdot
.25035 .52683 Mdot
.54484 .29794 Mdot
.29815 .5298 Mdot
.37809 .36133 Mdot
.66367 .5247 Mdot
.34687 .35877 Mdot
.42539 .64993 Mdot
.56779 .32258 Mdot
.60647 .56678 Mdot
.62807 .47651 Mdot
.56352 .35375 Mdot
.48597 .59119 Mdot
.38776 .66299 Mdot
.29826 .51461 Mdot
.59689 .35548 Mdot
.34416 .36344 Mdot
.30579 .53093 Mdot
.6183 .50155 Mdot
.69971 .77451 Mdot
.6601 .50612 Mdot
.62451 .54052 Mdot
.5822 .28527 Mdot
.63124 .59521 Mdot
.26818 .49425 Mdot
.53464 .32376 Mdot
.62775 .4951 Mdot
.59377 .73166 Mdot
.42438 .68642 Mdot
.26409 .57066 Mdot
.67141 .52671 Mdot
.78278 .53083 Mdot
.61457 .5269 Mdot
.40443 .22003 Mdot
.55774 .71076 Mdot
.30278 .39204 Mdot
.5294 .50897 Mdot
.334 .34184 Mdot
.48074 .5693 Mdot
.28017 .496 Mdot
.76126 .45631 Mdot
.65773 .5116 Mdot
.70213 .33792 Mdot
.60691 .56344 Mdot
.37273 .35928 Mdot
.79603 .42477 Mdot
.28164 .55245 Mdot
.26065 .71193 Mdot
.68275 .53371 Mdot
.54398 .35844 Mdot
.35524 .52043 Mdot
.46478 .59075 Mdot
.46204 .59876 Mdot
.43393 .64326 Mdot
.27015 .4707 Mdot
.49378 .53283 Mdot
.3674 .36488 Mdot
.63445 .51457 Mdot
.64571 .46134 Mdot
.32645 .2464 Mdot
.58492 .35333 Mdot
.36356 .33279 Mdot
.27756 .57995 Mdot
.65424 .55033 Mdot
.55548 .30273 Mdot
.55936 .3406 Mdot
.42205 .63841 Mdot
.3043 .38844 Mdot
.26693 .46991 Mdot
.82761 .59489 Mdot
.4794 .52973 Mdot
.28134 .5074 Mdot
.49393 .59377 Mdot
.60466 .52676 Mdot
.46665 .67242 Mdot
.3488 .33013 Mdot
.63956 .51806 Mdot
.7034 .31947 Mdot
.57776 .35036 Mdot
.65434 .53439 Mdot
.40519 .66922 Mdot
.72967 .26595 Mdot
.62155 .4563 Mdot
.76068 .49713 Mdot
.31297 .49405 Mdot
.66539 .49051 Mdot
.52425 .52013 Mdot
.50209 .55535 Mdot
.63234 .59602 Mdot
.27376 .5488 Mdot
.49262 .59609 Mdot
.40806 .66442 Mdot
.59251 .3448 Mdot
.4818 .57054 Mdot
.60724 .5647 Mdot
.66936 .48959 Mdot
.38645 .65389 Mdot
.60916 .51643 Mdot
.65665 .41207 Mdot
.51134 .56018 Mdot
.30477 .51563 Mdot
.60021 .35356 Mdot
.65983 .49128 Mdot
.46927 .59006 Mdot
.66658 .54772 Mdot
.61022 .25362 Mdot
.63874 .51665 Mdot
.38291 .2475 Mdot
.55307 .34609 Mdot
.35821 .37368 Mdot
.61218 .58618 Mdot
.65049 .54136 Mdot
.50378 .5831 Mdot
.49119 .57695 Mdot
.67897 .53847 Mdot
.55281 .29922 Mdot
.59007 .33798 Mdot
.54651 .35984 Mdot
.30937 .52578 Mdot
.53806 .73139 Mdot
.35245 .36518 Mdot
.46414 .59555 Mdot
.3418 .33248 Mdot
.76995 .55647 Mdot
.42305 .67049 Mdot
.34556 .24975 Mdot
.66133 .51997 Mdot
.54609 .33012 Mdot
.57904 .78896 Mdot
.54101 .29945 Mdot
.41963 .36921 Mdot
.34637 .33113 Mdot
.57628 .33025 Mdot
.67144 .52048 Mdot
.52576 .71616 Mdot
.78666 .52616 Mdot
.36783 .32664 Mdot
.45895 .57583 Mdot
.44011 .68407 Mdot
.30935 .49805 Mdot
.5798 .83134 Mdot
.33735 .35495 Mdot
.4909 .26199 Mdot
.62435 .49736 Mdot
.55226 .35162 Mdot
.34843 .35006 Mdot
.36987 .38292 Mdot
.28175 .55386 Mdot
.60988 .52029 Mdot
.65162 .53942 Mdot
.47099 .56046 Mdot
.34401 .34324 Mdot
.66719 .48231 Mdot
.61844 .49504 Mdot
.2677 .45849 Mdot
.54364 .36003 Mdot
.31336 .24211 Mdot
.72792 .61179 Mdot
.70411 .32052 Mdot
.2751 .31047 Mdot
.59131 .36533 Mdot
.67062 .50116 Mdot
.4818 .58752 Mdot
.30044 .51922 Mdot
.66631 .51752 Mdot
.26176 .49875 Mdot
.36804 .35225 Mdot
.4014 .24635 Mdot
.71904 .61833 Mdot
.39494 .40568 Mdot
.65289 .50655 Mdot
.61382 .46498 Mdot
.40718 .65655 Mdot
.3778 .38785 Mdot
.53325 .34038 Mdot
.65399 .49611 Mdot
.29216 .54591 Mdot
.30808 .5007 Mdot
.58003 .34872 Mdot
.47946 .30187 Mdot
.37682 .23083 Mdot
.48853 .58729 Mdot
.29289 .53744 Mdot
.47135 .59197 Mdot
.75849 .5034 Mdot
.33895 .33417 Mdot
.40906 .66351 Mdot
.29269 .49401 Mdot
.35328 .38682 Mdot
.63183 .49198 Mdot
.57945 .34059 Mdot
.54319 .28881 Mdot
.65338 .6279 Mdot
.25509 .52162 Mdot
.42072 .669 Mdot
.65432 .61707 Mdot
.67171 .63274 Mdot
.41677 .66782 Mdot
.30766 .53593 Mdot
.57011 .31391 Mdot
.55851 .34569 Mdot
.55136 .32534 Mdot
.79113 .46653 Mdot
.55905 .37112 Mdot
.44422 .73507 Mdot
.63017 .59705 Mdot
.6486 .43236 Mdot
.62649 .50599 Mdot
.37796 .38634 Mdot
.57554 .36344 Mdot
.55826 .70967 Mdot
.60563 .58049 Mdot
.78858 .52677 Mdot
.62979 .54209 Mdot
.6316 .6138 Mdot
.64625 .52702 Mdot
.61076 .41908 Mdot
.55698 .37236 Mdot
.68355 .53906 Mdot
.39135 .35967 Mdot
.40457 .6822 Mdot
.60248 .33613 Mdot
.67575 .50923 Mdot
.52384 .38169 Mdot
.64559 .57415 Mdot
.39734 .24571 Mdot
.6475 .62304 Mdot
.36563 .54614 Mdot
.63143 .51119 Mdot
.2555 .49507 Mdot
.62453 .47155 Mdot
.67489 .43436 Mdot
.35794 .32444 Mdot
.6186 .45635 Mdot
.24012 .5235 Mdot
.79543 .42275 Mdot
.4914 .58362 Mdot
.40325 .66384 Mdot
.4764 .60733 Mdot
.34673 .37136 Mdot
.65987 .51574 Mdot
.67795 .50727 Mdot
.64606 .5967 Mdot
.75772 .50554 Mdot
.49741 .55865 Mdot
.43721 .65468 Mdot
.66726 .43778 Mdot
.67952 .53267 Mdot
.2479 .56919 Mdot
.54083 .31083 Mdot
.78499 .42437 Mdot
.77789 .41055 Mdot
.62154 .49105 Mdot
.58034 .33446 Mdot
.53879 .31996 Mdot
.50923 .8266 Mdot
.40088 .6541 Mdot
.63382 .52509 Mdot
.38265 .63055 Mdot
.60422 .5453 Mdot
.36328 .35362 Mdot
.62766 .5898 Mdot
.26215 .51328 Mdot
.51686 .72026 Mdot
.30973 .52906 Mdot
.62896 .54878 Mdot
.56782 .33404 Mdot
.37844 .3353 Mdot
.31889 .49759 Mdot
.30523 .3899 Mdot
.44348 .73792 Mdot
.27463 .46945 Mdot
.43306 .63606 Mdot
.41044 .68524 Mdot
.3778 .38766 Mdot
.66843 .527 Mdot
.55172 .7194 Mdot
.75507 .59174 Mdot
.65179 .52427 Mdot
.6655 .50242 Mdot
.39727 .3099 Mdot
.34191 .33731 Mdot
.28489 .48846 Mdot
.65311 .51418 Mdot
.67494 .49633 Mdot
.57037 .33122 Mdot
.42398 .63073 Mdot
.29315 .50402 Mdot
.43155 .65822 Mdot
.2826 .53875 Mdot
.6129 .77782 Mdot
.4983 .58221 Mdot
.41715 .67733 Mdot
.33616 .35595 Mdot
.54692 .32131 Mdot
.49015 .55204 Mdot
.27605 .51973 Mdot
.2959 .53559 Mdot
.64143 .48988 Mdot
.59153 .34878 Mdot
.54536 .34031 Mdot
.43131 .65225 Mdot
.35555 .33967 Mdot
.60084 .55265 Mdot
.46883 .60413 Mdot
.29648 .56258 Mdot
.29832 .53856 Mdot
.66092 .43547 Mdot
.58748 .29437 Mdot
.66474 .54706 Mdot
.5508 .3045 Mdot
.64291 .54351 Mdot
.508 .31381 Mdot
.53025 .29795 Mdot
.63895 .58932 Mdot
.72515 .49726 Mdot
.27791 .50596 Mdot
.43679 .83536 Mdot
.61257 .59609 Mdot
.39879 .35329 Mdot
.60475 .53011 Mdot
.22432 .68133 Mdot
.57286 .78948 Mdot
.67047 .54819 Mdot
.67115 .49792 Mdot
.81699 .63985 Mdot
.61467 .53407 Mdot
.46844 .57156 Mdot
.49285 .58219 Mdot
.55414 .30419 Mdot
.47187 .60995 Mdot
.5352 .71737 Mdot
.40294 .64519 Mdot
.27975 .52827 Mdot
.47943 .77355 Mdot
.42757 .66238 Mdot
.57101 .35085 Mdot
.60089 .54662 Mdot
.57161 .28176 Mdot
.23976 .54877 Mdot
.48684 .56862 Mdot
.37009 .35551 Mdot
.54538 .71695 Mdot
.28773 .55017 Mdot
.34102 .35692 Mdot
.61683 .53609 Mdot
.3269 .4746 Mdot
.39327 .36552 Mdot
.44921 .83648 Mdot
.38145 .37458 Mdot
.34201 .36261 Mdot
.54298 .72592 Mdot
.40303 .64492 Mdot
.51323 .56349 Mdot
.45369 .57573 Mdot
.37946 .33878 Mdot
.30191 .73711 Mdot
.28392 .55507 Mdot
.5279 .74504 Mdot
.54923 .3677 Mdot
.50072 .5736 Mdot
.65753 .50286 Mdot
.38316 .36394 Mdot
.6682 .47875 Mdot
.50117 .5869 Mdot
.37308 .37212 Mdot
.6251 .47204 Mdot
.49932 .72292 Mdot
.47293 .58837 Mdot
.48623 .55483 Mdot
.42544 .62746 Mdot
.33517 .57219 Mdot
.54188 .32789 Mdot
.39966 .63456 Mdot
.57811 .72683 Mdot
.62748 .53834 Mdot
.34644 .35577 Mdot
.48254 .57043 Mdot
.35176 .36948 Mdot
.41325 .65439 Mdot
.38525 .65655 Mdot
.58801 .34858 Mdot
.54324 .35665 Mdot
.49268 .54661 Mdot
.60685 .70239 Mdot
.61495 .57328 Mdot
.70469 .35394 Mdot
.52729 .31182 Mdot
.80563 .45278 Mdot
.40587 .63879 Mdot
.42159 .63127 Mdot
.62054 .46793 Mdot
.62692 .5748 Mdot
.6308 .61253 Mdot
.63226 .58346 Mdot
.2878 .71759 Mdot
.60722 .56892 Mdot
.29775 .51944 Mdot
.64517 .57899 Mdot
.52277 .24945 Mdot
.63983 .48104 Mdot
.67754 .52129 Mdot
.26933 .53774 Mdot
.64554 .49288 Mdot
.26068 .52026 Mdot
.65328 .5014 Mdot
.20483 .50916 Mdot
.28144 .52883 Mdot
.49995 .60739 Mdot
.67676 .58721 Mdot
.47388 .56455 Mdot
.41676 .64101 Mdot
.43564 .64081 Mdot
.46961 .75986 Mdot
.57477 .31965 Mdot
.73523 .30968 Mdot
.67688 .52666 Mdot
.28792 .55299 Mdot
.36732 .34938 Mdot
.62999 .47956 Mdot
.6254 .55056 Mdot
.61392 .59609 Mdot
.58519 .33835 Mdot
.2948 .55194 Mdot
.4131 .64715 Mdot
.24726 .5213 Mdot
.2012 .51428 Mdot
.26637 .51093 Mdot
.74745 .55095 Mdot
.63428 .49139 Mdot
.52516 .52045 Mdot
.73115 .39667 Mdot
.37613 .67225 Mdot
.58086 .34512 Mdot
.47859 .57168 Mdot
.40595 .68665 Mdot
.51446 .69126 Mdot
.54257 .31826 Mdot
.29375 .51665 Mdot
.65355 .54294 Mdot
.49264 .59221 Mdot
.45518 .57205 Mdot
.5988 .33485 Mdot
.38676 .67042 Mdot
.27395 .5264 Mdot
.47227 .5819 Mdot
.53497 .73379 Mdot
.77519 .37069 Mdot
.5627 .75079 Mdot
.6475 .54296 Mdot
.43078 .65028 Mdot
.59208 .34856 Mdot
.6265 .61081 Mdot
.37537 .34703 Mdot
.54164 .72024 Mdot
.65732 .50493 Mdot
.42059 .38128 Mdot
.56787 .33547 Mdot
.3948 .65445 Mdot
.38314 .36807 Mdot
.39952 .65654 Mdot
.4619 .58528 Mdot
.61137 .34145 Mdot
.462 .5984 Mdot
.61046 .57992 Mdot
.36477 .34939 Mdot
.54254 .33163 Mdot
.2085 .50341 Mdot
.51343 .54158 Mdot
.28994 .51724 Mdot
.51884 .69153 Mdot
.59122 .34109 Mdot
.33018 .44053 Mdot
.24799 .51925 Mdot
.35365 .30329 Mdot
.54544 .68922 Mdot
.37822 .367 Mdot
.67723 .51646 Mdot
.55599 .32657 Mdot
.36822 .3266 Mdot
.34349 .51299 Mdot
.79221 .50918 Mdot
.50804 .54825 Mdot
.64567 .55782 Mdot
.41499 .21371 Mdot
.49819 .26156 Mdot
.55562 .37853 Mdot
.34059 .36683 Mdot
.6391 .52521 Mdot
.48905 .58785 Mdot
.68217 .5387 Mdot
.37304 .33284 Mdot
.32401 .33299 Mdot
.24919 .54896 Mdot
.65503 .54559 Mdot
.39633 .66727 Mdot
.26636 .50408 Mdot
.30496 .4886 Mdot
.29518 .49476 Mdot
.53475 .34314 Mdot
.50404 .56804 Mdot
.4933 .58314 Mdot
.55924 .78923 Mdot
.35241 .37264 Mdot
.47383 .56492 Mdot
.67624 .50165 Mdot
.44607 .73599 Mdot
.54926 .33201 Mdot
.26936 .52727 Mdot
.63556 .52633 Mdot
.65063 .62784 Mdot
.48973 .56246 Mdot
.26817 .54376 Mdot
.52716 .31701 Mdot
.57353 .43734 Mdot
.66513 .51846 Mdot
.60613 .54216 Mdot
.57051 .35456 Mdot
.56607 .21654 Mdot
.52975 .73651 Mdot
.64293 .54161 Mdot
.34735 .36794 Mdot
.52081 .20067 Mdot
.61745 .53069 Mdot
.52827 .28489 Mdot
.46652 .56407 Mdot
.56399 .42046 Mdot
.65566 .4189 Mdot
.66778 .46636 Mdot
.46627 .45372 Mdot
.56641 .61189 Mdot
.49091 .46988 Mdot
.32256 .72765 Mdot
.40935 .46932 Mdot
.47156 .84399 Mdot
.36533 .39699 Mdot
.59423 .44903 Mdot
.86988 .5223 Mdot
.47857 .28342 Mdot
.3789 .49236 Mdot
.32117 .32703 Mdot
.3905 .70434 Mdot
.19436 .63835 Mdot
.32497 .46753 Mdot
.32536 .72562 Mdot
.61261 .58064 Mdot
.545 .22526 Mdot
.59609 .45446 Mdot
.34477 .46507 Mdot
.30748 .40659 Mdot
.65059 .62184 Mdot
.78195 .66436 Mdot
.39927 .39538 Mdot
.66579 .78052 Mdot
.7157 .31434 Mdot
.32354 .53815 Mdot
.6019 .67267 Mdot
.45723 .77601 Mdot
.60137 .47235 Mdot
.52401 .44289 Mdot
.37024 .39906 Mdot
.62354 .30272 Mdot
.28326 .29624 Mdot
.29301 .52707 Mdot
.59338 .32807 Mdot
.42925 .32108 Mdot
.73914 .7205 Mdot
.4096 .34632 Mdot
.46451 .45487 Mdot
.51033 .54143 Mdot
.60535 .4277 Mdot
.56087 .70638 Mdot
.60807 .41506 Mdot
.30429 .45534 Mdot
.19755 .63977 Mdot
.59127 .28808 Mdot
.34844 .53457 Mdot
.49999 .69021 Mdot
.37242 .4933 Mdot
.62774 .40518 Mdot
.38819 .69402 Mdot
.49524 .61093 Mdot
.52627 .31213 Mdot
.77605 .63995 Mdot
.71664 .5917 Mdot
.58306 .72277 Mdot
.33064 .46896 Mdot
.5884 .26038 Mdot
.71756 .26898 Mdot
.48571 .29434 Mdot
.39135 .82035 Mdot
.70087 .76953 Mdot
.35682 .76297 Mdot
.67931 .57566 Mdot
.41443 .34706 Mdot
.46982 .68253 Mdot
.45275 .49365 Mdot
.37665 .78441 Mdot
.60775 .25171 Mdot
.80399 .61935 Mdot
.5031 .37841 Mdot
.74548 .7299 Mdot
.61083 .31618 Mdot
.51202 .52811 Mdot
.58143 .39414 Mdot
.58333 .44435 Mdot
.54668 .77282 Mdot
.76202 .7015 Mdot
.35576 .48109 Mdot
.51137 .5362 Mdot
.47189 .29371 Mdot
.65355 .41282 Mdot
.30285 .45285 Mdot
.47611 .61442 Mdot
.75032 .39848 Mdot
.78352 .6774 Mdot
.4792 .44584 Mdot
.74224 .68904 Mdot
.25839 .46282 Mdot
.17553 .43477 Mdot
.30041 .4833 Mdot
.33059 .35135 Mdot
.68423 .77226 Mdot
.55694 .33227 Mdot
.42314 .83921 Mdot
.40991 .48213 Mdot
.40021 .5186 Mdot
.78624 .67094 Mdot
.36679 .79851 Mdot
.62384 .44039 Mdot
.52239 .57338 Mdot
.30838 .28703 Mdot
.51796 .47431 Mdot
.3616 .42716 Mdot
.46059 .64356 Mdot
.40199 .2333 Mdot
.70309 .75578 Mdot
.34989 .7761 Mdot
.83141 .58264 Mdot
.58538 .71272 Mdot
.38703 .72254 Mdot
.58263 .28171 Mdot
.43368 .41894 Mdot
.35405 .43623 Mdot
.73385 .74342 Mdot
.62553 .45335 Mdot
.48649 .19265 Mdot
.33596 .73714 Mdot
.78419 .41021 Mdot
.45055 .22404 Mdot
.4452 .33872 Mdot
.57092 .45549 Mdot
.51761 .37568 Mdot
.44203 .6096 Mdot
.53113 .77425 Mdot
.74011 .37643 Mdot
.36358 .53834 Mdot
.52595 .72716 Mdot
.46319 .33081 Mdot
.41186 .78393 Mdot
.49466 .2113 Mdot
.7494 .39024 Mdot
.5604 .29139 Mdot
.37752 .78348 Mdot
.33903 .74632 Mdot
.46795 .20237 Mdot
.28779 .57743 Mdot
.73731 .69745 Mdot
.41091 .40578 Mdot
.67747 .46453 Mdot
.59113 .4551 Mdot
.60215 .46673 Mdot
.22251 .66528 Mdot
.74146 .53028 Mdot
.50432 .8194 Mdot
.35628 .41761 Mdot
.73276 .41319 Mdot
.48714 .79895 Mdot
.73579 .40695 Mdot
.6706 .42784 Mdot
.50215 .29557 Mdot
.37821 .40567 Mdot
.72111 .50825 Mdot
.78575 .66423 Mdot
.27874 .49194 Mdot
.37479 .786 Mdot
.40945 .36285 Mdot
.33139 .50249 Mdot
.38887 .51896 Mdot
.38098 .51983 Mdot
.62891 .80635 Mdot
.46449 .2984 Mdot
.40528 .70423 Mdot
.59966 .40119 Mdot
.4301 .48566 Mdot
.71137 .35951 Mdot
.7384 .59599 Mdot
.59294 .25588 Mdot
.38753 .66257 Mdot
.75292 .44 Mdot
.54421 .39405 Mdot
.28667 .58027 Mdot
.75097 .55818 Mdot
.61468 .66814 Mdot
.47773 .55246 Mdot
.47714 .74194 Mdot
.60728 .78139 Mdot
.68951 .47352 Mdot
.37753 .80047 Mdot
.47596 .2981 Mdot
.47801 .7479 Mdot
.35171 .43775 Mdot
.74102 .3148 Mdot
.74874 .72692 Mdot
.56932 .82803 Mdot
.56803 .22219 Mdot
.44044 .21933 Mdot
.15691 .5107 Mdot
.31457 .40757 Mdot
.45707 .82605 Mdot
.40957 .36259 Mdot
.61521 .15456 Mdot
.27019 .49148 Mdot
.45823 .68694 Mdot
.61865 .32353 Mdot
.60881 .66208 Mdot
.76105 .69054 Mdot
.62386 .43034 Mdot
.38453 .64844 Mdot
.57689 .38966 Mdot
.72531 .50044 Mdot
.77742 .66104 Mdot
.78986 .63535 Mdot
.77985 .64477 Mdot
.43377 .33506 Mdot
.75402 .48528 Mdot
.80395 .6515 Mdot
.45021 .7188 Mdot
.71548 .54017 Mdot
.65264 .46319 Mdot
.60375 .72306 Mdot
.43708 .81942 Mdot
.37114 .68066 Mdot
.52273 .47341 Mdot
.5914 .28905 Mdot
.79498 .67059 Mdot
.59493 .79018 Mdot
.59808 .42933 Mdot
.63641 .79689 Mdot
.36902 .70959 Mdot
.50537 .80392 Mdot
.60351 .81335 Mdot
.50052 .44269 Mdot
.43761 .35649 Mdot
.8049 .66705 Mdot
.36092 .75064 Mdot
.3233 .32349 Mdot
.52922 .38527 Mdot
.43363 .82489 Mdot
.44029 .22739 Mdot
.35677 .29385 Mdot
.61359 .31389 Mdot
.76227 .33022 Mdot
.37668 .46329 Mdot
.52901 .44448 Mdot
.65904 .59157 Mdot
.48158 .80336 Mdot
.26849 .48935 Mdot
.40034 .7932 Mdot
.36979 .44332 Mdot
.71434 .52478 Mdot
.49036 .76483 Mdot
.32999 .7568 Mdot
.51142 .40539 Mdot
.76692 .506 Mdot
.47247 .30265 Mdot
.51044 .20742 Mdot
.46409 .21656 Mdot
.73867 .34483 Mdot
.65086 .49231 Mdot
.74548 .71462 Mdot
.50189 .8525 Mdot
.60962 .81459 Mdot
.48053 .20408 Mdot
.17419 .46946 Mdot
.35051 .39014 Mdot
.45384 .72468 Mdot
.61529 .65414 Mdot
.48202 .41868 Mdot
.57714 .61212 Mdot
.35105 .31836 Mdot
.71757 .26745 Mdot
.39237 .51339 Mdot
.45192 .71862 Mdot
.62833 .29555 Mdot
.42001 .50015 Mdot
.76189 .50794 Mdot
.55625 .29144 Mdot
.44867 .19574 Mdot
.3803 .78537 Mdot
.28281 .49232 Mdot
.27774 .57332 Mdot
.733 .5371 Mdot
.52254 .52958 Mdot
.43109 .6971 Mdot
.69263 .48614 Mdot
.70631 .32259 Mdot
.17536 .48267 Mdot
.54932 .81798 Mdot
.43432 .83311 Mdot
.59962 .81486 Mdot
.35023 .7602 Mdot
.3395 .513 Mdot
.48765 .74513 Mdot
.38602 .31652 Mdot
.40513 .37754 Mdot
.49063 .72599 Mdot
.33393 .75287 Mdot
.62936 .437 Mdot
.57257 .39142 Mdot
.6539 .47866 Mdot
.58441 .78719 Mdot
.44584 .7662 Mdot
.47835 .72456 Mdot
.757 .35412 Mdot
.51798 .3217 Mdot
.40993 .72335 Mdot
.54757 .43735 Mdot
.60533 .50836 Mdot
.44391 .21492 Mdot
.36258 .32324 Mdot
.54632 .29195 Mdot
.32947 .75762 Mdot
.16446 .4999 Mdot
.46482 .47941 Mdot
.71501 .60552 Mdot
.70954 .74575 Mdot
.68088 .59436 Mdot
.42414 .22925 Mdot
.77885 .34209 Mdot
.32294 .4311 Mdot
.59892 .29452 Mdot
.7086 .52839 Mdot
.38708 .52941 Mdot
.56976 .23035 Mdot
.584 .30721 Mdot
.61195 .47027 Mdot
.68076 .78031 Mdot
.65225 .61237 Mdot
.51386 .45081 Mdot
.54986 .74547 Mdot
.41133 .43518 Mdot
.41915 .48226 Mdot
.48746 .7691 Mdot
.47951 .46483 Mdot
.76435 .65114 Mdot
.71178 .25667 Mdot
.53457 .47258 Mdot
.43086 .71951 Mdot
.4559 .71613 Mdot
.7153 .31346 Mdot
.62687 .40265 Mdot
.35105 .42121 Mdot
.61637 .58517 Mdot
.66742 .79441 Mdot
.48519 .35701 Mdot
.48493 .75753 Mdot
.43606 .3803 Mdot
.61181 .52779 Mdot
.5029 .52821 Mdot
.61226 .81093 Mdot
.55855 .42107 Mdot
.88457 .49782 Mdot
.31244 .72848 Mdot
.56274 .24429 Mdot
.65175 .42173 Mdot
.38971 .80256 Mdot
.53622 .25003 Mdot
.42263 .46816 Mdot
.37862 .43742 Mdot
.42012 .81582 Mdot
.54719 .41415 Mdot
.555 .42555 Mdot
.43498 .20611 Mdot
.80498 .64195 Mdot
.51572 .46667 Mdot
.37229 .298 Mdot
.3778 .71178 Mdot
.62431 .53636 Mdot
.48044 .29799 Mdot
.35445 .24125 Mdot
.44503 .38336 Mdot
.49596 .4756 Mdot
.49678 .85526 Mdot
.67225 .45683 Mdot
.4675 .30875 Mdot
.88282 .50277 Mdot
.89505 .48329 Mdot
.50236 .27661 Mdot
.72301 .75479 Mdot
.56444 .42534 Mdot
.42423 .23189 Mdot
.38662 .39587 Mdot
.67971 .62857 Mdot
.70293 .34448 Mdot
.63081 .81454 Mdot
.15928 .48254 Mdot
.35666 .42934 Mdot
.61328 .29579 Mdot
.62616 .8185 Mdot
.68325 .46161 Mdot
.4364 .71115 Mdot
.17698 .43423 Mdot
.26824 .71806 Mdot
.39071 .81693 Mdot
.76109 .34883 Mdot
.22273 .66972 Mdot
.28935 .70241 Mdot
.35797 .47276 Mdot
.44018 .83066 Mdot
.46529 .54314 Mdot
.75115 .31748 Mdot
.37571 .7818 Mdot
.42208 .21911 Mdot
.18529 .5742 Mdot
.42536 .47898 Mdot
.69925 .49767 Mdot
.49858 .30287 Mdot
.3985 .23663 Mdot
.44774 .32679 Mdot
.70426 .56883 Mdot
.51978 .69622 Mdot
.66992 .43012 Mdot
.51888 .19737 Mdot
.79319 .35313 Mdot
.69739 .50098 Mdot
.79489 .61264 Mdot
.38673 .40728 Mdot
.4871 .70286 Mdot
.6349 .41184 Mdot
.45497 .75511 Mdot
.40636 .70696 Mdot
.6444 .57753 Mdot
.68785 .77469 Mdot
.40902 .70612 Mdot
.78878 .62489 Mdot
.42248 .84206 Mdot
.65042 .78644 Mdot
.40404 .52447 Mdot
.44507 .67419 Mdot
.4342 .81449 Mdot
.44056 .81479 Mdot
.80875 .60101 Mdot
.32933 .72356 Mdot
.49341 .72037 Mdot
.69779 .56183 Mdot
.71838 .6147 Mdot
.75453 .52325 Mdot
.39367 .80462 Mdot
.71571 .30122 Mdot
.48811 .79584 Mdot
.56781 .22433 Mdot
.33309 .75557 Mdot
.62019 .44108 Mdot
.46002 .7555 Mdot
.42779 .40259 Mdot
.5118 .58944 Mdot
.28047 .55746 Mdot
.83324 .61083 Mdot
.45991 .206 Mdot
.52883 .81082 Mdot
.47893 .1939 Mdot
.5183 .37884 Mdot
.30205 .71654 Mdot
.58746 .39341 Mdot
.4994 .49613 Mdot
.32988 .53868 Mdot
.435 .78688 Mdot
.63651 .44207 Mdot
.40481 .21913 Mdot
.77522 .39255 Mdot
.63691 .80511 Mdot
.48982 .80103 Mdot
.84243 .56482 Mdot
.3952 .71827 Mdot
.75188 .43708 Mdot
.77463 .63741 Mdot
.54015 .21162 Mdot
.47661 .71689 Mdot
.78702 .65593 Mdot
.56868 .37972 Mdot
.70647 .76508 Mdot
.37277 .34773 Mdot
.42051 .71491 Mdot
.38046 .23228 Mdot
.46595 .72094 Mdot
.46727 .71723 Mdot
.5336 .8181 Mdot
.46942 .29831 Mdot
.48817 .28259 Mdot
.40922 .40686 Mdot
.32365 .46913 Mdot
.70364 .62175 Mdot
.49958 .45246 Mdot
.82857 .58676 Mdot
.65195 .49289 Mdot
.349 .71573 Mdot
.37561 .79199 Mdot
.38548 .31492 Mdot
.69538 .54682 Mdot
.39719 .22673 Mdot
.78044 .35785 Mdot
.54583 .78413 Mdot
.80051 .64857 Mdot
.69354 .55141 Mdot
.60578 .64948 Mdot
.80397 .42589 Mdot
.36185 .28856 Mdot
.35213 .42535 Mdot
.47253 .4551 Mdot
.69226 .59318 Mdot
.53305 .73766 Mdot
.3547 .75844 Mdot
.48439 .85065 Mdot
.80059 .60644 Mdot
.34712 .42656 Mdot
.47141 .7252 Mdot
.52843 .28259 Mdot
.44767 .78431 Mdot
.84042 .5735 Mdot
.20779 .66034 Mdot
.52713 .38352 Mdot
.34152 .76242 Mdot
.44518 .34485 Mdot
.43738 .71212 Mdot
.48385 .7251 Mdot
.77337 .6436 Mdot
.62327 .33774 Mdot
.57857 .41488 Mdot
.45592 .35052 Mdot
.53822 .71198 Mdot
.39213 .49503 Mdot
.75334 .32952 Mdot
.46467 .29307 Mdot
.84301 .56332 Mdot
.2727 .69614 Mdot
.78988 .42027 Mdot
.86204 .53432 Mdot
.52594 .31996 Mdot
.3873 .49671 Mdot
.18947 .40593 Mdot
.47368 .74288 Mdot
.30186 .49267 Mdot
.6658 .48151 Mdot
.5058 .70696 Mdot
.55097 .23446 Mdot
.38067 .70582 Mdot
.38979 .68077 Mdot
.55304 .29341 Mdot
.30231 .71121 Mdot
.54647 .29067 Mdot
.4836 .84813 Mdot
.49888 .43853 Mdot
.66263 .43091 Mdot
.80272 .37723 Mdot
.3416 .52452 Mdot
.52068 .208 Mdot
.66007 .7841 Mdot
.59824 .72292 Mdot
.58883 .31519 Mdot
.60087 .3231 Mdot
.61675 .36298 Mdot
.35719 .3107 Mdot
.72443 .73068 Mdot
.36774 .79639 Mdot
.29287 .56596 Mdot
.59185 .37836 Mdot
.677 .58248 Mdot
.69023 .48081 Mdot
.56475 .81086 Mdot
.24895 .52034 Mdot
.76457 .71155 Mdot
.72765 .30308 Mdot
.53432 .22178 Mdot
.48723 .40888 Mdot
.62509 .6716 Mdot
.48133 .69299 Mdot
.35245 .53719 Mdot
.67198 .46285 Mdot
.53579 .25727 Mdot
.55731 .36553 Mdot
.38947 .50619 Mdot
.39893 .63976 Mdot
.29449 .57737 Mdot
.38878 .33158 Mdot
.73071 .34073 Mdot
.38847 .80715 Mdot
.56941 .29076 Mdot
.429 .70258 Mdot
.34859 .55554 Mdot
.74853 .53998 Mdot
.62052 .7006 Mdot
.82608 .63169 Mdot
.6859 .76283 Mdot
.54917 .29763 Mdot
.505 .21158 Mdot
.21601 .49534 Mdot
.54807 .81708 Mdot
.54765 .40578 Mdot
.38975 .79784 Mdot
.75134 .40906 Mdot
.59173 .81134 Mdot
.65394 .4191 Mdot
.47234 .44067 Mdot
.36043 .77782 Mdot
.37807 .63162 Mdot
.33878 .76516 Mdot
.7867 .37204 Mdot
.69974 .60599 Mdot
.28325 .72764 Mdot
.44707 .37364 Mdot
.59824 .43198 Mdot
.59847 .54467 Mdot
.48135 .42294 Mdot
.42066 .81234 Mdot
.53389 .32733 Mdot
.38389 .7002 Mdot
.62777 .28399 Mdot
.35727 .42811 Mdot
.69887 .75856 Mdot
.47858 .20833 Mdot
.36215 .78929 Mdot
.71985 .61061 Mdot
.40913 .76232 Mdot
.71283 .30322 Mdot
.59064 .71549 Mdot
.47273 .60524 Mdot
.74256 .38854 Mdot
.50989 .57657 Mdot
.56617 .79109 Mdot
.75621 .53088 Mdot
.76076 .69713 Mdot
.59873 .78396 Mdot
.497 .30474 Mdot
.52374 .5454 Mdot
.60473 .36154 Mdot
.77174 .69717 Mdot
.55322 .78291 Mdot
.39377 .23482 Mdot
.39027 .81558 Mdot
.33079 .71955 Mdot
.86667 .52678 Mdot
.46143 .31086 Mdot
.71568 .50872 Mdot
.44535 .83316 Mdot
.49569 .36842 Mdot
.29315 .70345 Mdot
.63735 .44236 Mdot
.57566 .28057 Mdot
.78806 .66485 Mdot
.47194 .52646 Mdot
.48775 .30759 Mdot
.77969 .53977 Mdot
.59852 .2918 Mdot
.55826 .77884 Mdot
.69397 .53801 Mdot
.29538 .51512 Mdot
.61593 .66332 Mdot
.21451 .65671 Mdot
.62147 .35582 Mdot
.3841 .79981 Mdot
.3951 .79803 Mdot
.39062 .73212 Mdot
.35282 .56561 Mdot
.86678 .52491 Mdot
.74884 .47355 Mdot
.69301 .52317 Mdot
.56633 .29579 Mdot
.39659 .68789 Mdot
.34565 .73786 Mdot
.61018 .5327 Mdot
.61142 .68354 Mdot
.75066 .40202 Mdot
.64975 .8045 Mdot
.42842 .41557 Mdot
.35437 .40492 Mdot
.58032 .38203 Mdot
.39824 .23446 Mdot
.58653 .23374 Mdot
.48567 .27117 Mdot
.41926 .8097 Mdot
.46615 .47889 Mdot
.46786 .45002 Mdot
.49328 .32927 Mdot
.39518 .78219 Mdot
.34791 .45167 Mdot
.39249 .35247 Mdot
.70571 .32944 Mdot
.81914 .58807 Mdot
.5037 .36107 Mdot
.43538 .47662 Mdot
.52402 .42795 Mdot
.69136 .60269 Mdot
.35893 .43001 Mdot
.47199 .29994 Mdot
.59785 .31225 Mdot
.76058 .66557 Mdot
.53084 .45655 Mdot
.4421 .68152 Mdot
.32781 .73998 Mdot
.51242 .43253 Mdot
.39759 .80277 Mdot
.72498 .49658 Mdot
.77662 .64996 Mdot
.48225 .75679 Mdot
.36409 .69151 Mdot
.64828 .47699 Mdot
.61152 .26139 Mdot
.61096 .81175 Mdot
.53716 .4012 Mdot
.48027 .48486 Mdot
.60136 .39332 Mdot
.41496 .83455 Mdot
.46389 .62358 Mdot
.17632 .47945 Mdot
.51956 .5765 Mdot
.61512 .67462 Mdot
.60873 .65743 Mdot
.36374 .3092 Mdot
.67182 .45931 Mdot
.36578 .47802 Mdot
.69978 .59323 Mdot
.7097 .32965 Mdot
.48994 .82024 Mdot
.83113 .60775 Mdot
.58523 .25852 Mdot
.38272 .81804 Mdot
.60777 .27224 Mdot
.57426 .2699 Mdot
.27577 .69662 Mdot
.47997 .48861 Mdot
.74013 .52581 Mdot
.37345 .69793 Mdot
.52499 .32369 Mdot
.82813 .60297 Mdot
.49008 .47612 Mdot
.37945 .69585 Mdot
.28455 .45712 Mdot
.41652 .48667 Mdot
.27235 .30134 Mdot
.4013 .38 Mdot
.42595 .83786 Mdot
.37693 .78483 Mdot
.37444 .40667 Mdot
.56331 .42468 Mdot
.49207 .48247 Mdot
.77547 .66144 Mdot
.52257 .56213 Mdot
.67724 .77363 Mdot
.43519 .33712 Mdot
.72827 .34966 Mdot
.59689 .78211 Mdot
.53489 .77563 Mdot
.58888 .72181 Mdot
.75338 .37478 Mdot
.72966 .69742 Mdot
.49839 .55057 Mdot
.28991 .57451 Mdot
.18523 .58571 Mdot
.83393 .58241 Mdot
.54103 .21909 Mdot
.49781 .53499 Mdot
.4562 .78512 Mdot
.53026 .45384 Mdot
.49034 .69962 Mdot
.38901 .42217 Mdot
.43322 .69577 Mdot
.41417 .31508 Mdot
.50498 .19847 Mdot
.66685 .79393 Mdot
.6471 .46966 Mdot
.56789 .60287 Mdot
.34758 .46899 Mdot
.28499 .48391 Mdot
.633 .34332 Mdot
.82498 .62956 Mdot
.38765 .34372 Mdot
.19585 .39483 Mdot
.37509 .31336 Mdot
.5407 .81304 Mdot
.16734 .47957 Mdot
.34415 .31033 Mdot
.47992 .84955 Mdot
.5446 .23092 Mdot
.78267 .38309 Mdot
.48511 .1907 Mdot
.57343 .79141 Mdot
.73967 .38468 Mdot
.46367 .64147 Mdot
.71969 .74891 Mdot
.4798 .69943 Mdot
.3939 .70789 Mdot
.74168 .68426 Mdot
.35459 .77417 Mdot
.31808 .73281 Mdot
.30782 .36463 Mdot
.60923 .29319 Mdot
.1635 .50784 Mdot
.33047 .52 Mdot
.72342 .24979 Mdot
.68686 .76065 Mdot
.7991 .50479 Mdot
.54125 .40212 Mdot
.42 .3974 Mdot
.77227 .66981 Mdot
.4085 .80058 Mdot
.58499 .43263 Mdot
.26182 .57917 Mdot
.51707 .77599 Mdot
.44251 .77727 Mdot
.43736 .36633 Mdot
.61405 .80275 Mdot
.35019 .5375 Mdot
.49372 .52253 Mdot
.36649 .78597 Mdot
.61593 .26703 Mdot
.59007 .70611 Mdot
.81715 .591 Mdot
.614 .71145 Mdot
.31826 .74379 Mdot
.43393 .33418 Mdot
.19888 .52012 Mdot
.8241 .59259 Mdot
.57667 .23837 Mdot
.76407 .41895 Mdot
.88245 .50031 Mdot
.74457 .73052 Mdot
.49497 .48301 Mdot
.62151 .59075 Mdot
.46579 .8432 Mdot
.24185 .55653 Mdot
.51553 .81329 Mdot
.71842 .27009 Mdot
.30045 .72129 Mdot
.7599 .5431 Mdot
.61546 .58085 Mdot
.45286 .71048 Mdot
.50422 .335 Mdot
.61306 .30785 Mdot
.32644 .4904 Mdot
.3341 .75201 Mdot
.7311 .33647 Mdot
.71169 .25684 Mdot
.78203 .36511 Mdot
.57033 .30557 Mdot
.70062 .76482 Mdot
.50701 .50588 Mdot
.7185 .30979 Mdot
.7721 .6592 Mdot
.5944 .6245 Mdot
.36068 .46459 Mdot
.70788 .30363 Mdot
.4842 .74305 Mdot
.21004 .65016 Mdot
.8621 .54024 Mdot
.71159 .34742 Mdot
.77095 .70419 Mdot
.57076 .82947 Mdot
.58518 .31859 Mdot
.62629 .34234 Mdot
.47765 .68897 Mdot
.50439 .46624 Mdot
.37344 .29152 Mdot
.33164 .50611 Mdot
.31824 .7138 Mdot
.30639 .58026 Mdot
.67035 .55144 Mdot
.44505 .35843 Mdot
.64291 .80051 Mdot
.43094 .71278 Mdot
.65608 .79344 Mdot
.74163 .36042 Mdot
.65382 .48896 Mdot
.89393 .47977 Mdot
.42132 .23229 Mdot
.74483 .58427 Mdot
.45178 .58821 Mdot
.50087 .53539 Mdot
.65775 .5696 Mdot
.32245 .33253 Mdot
.45178 .73797 Mdot
.27822 .71141 Mdot
.7221 .74455 Mdot
.58747 .37875 Mdot
.47927 .69559 Mdot
.38999 .38532 Mdot
.55129 .6906 Mdot
.76326 .5359 Mdot
.38477 .33777 Mdot
.25041 .68998 Mdot
.27048 .30592 Mdot
.35109 .4422 Mdot
.39437 .49245 Mdot
.51914 .7001 Mdot
.50165 .54145 Mdot
.26474 .69442 Mdot
.36612 .30676 Mdot
.35117 .46464 Mdot
.35915 .78657 Mdot
.75971 .38566 Mdot
.43405 .36619 Mdot
.18908 .55572 Mdot
.47876 .71845 Mdot
.44671 .36049 Mdot
.51846 .47801 Mdot
.76843 .33519 Mdot
.75048 .68818 Mdot
.28439 .46355 Mdot
.49778 .54927 Mdot
.80578 .43228 Mdot
.75793 .69564 Mdot
.34786 .37837 Mdot
.49682 .84851 Mdot
.49753 .48837 Mdot
.63439 .33514 Mdot
.79524 .52317 Mdot
.70047 .53762 Mdot
.62157 .45419 Mdot
.63472 .5983 Mdot
.58215 .66003 Mdot
.25833 .30792 Mdot
.70152 .51753 Mdot
.40828 .49212 Mdot
.46553 .47355 Mdot
.42481 .72342 Mdot
.63195 .45663 Mdot
.63075 .53394 Mdot
.45835 .61799 Mdot
.50328 .75371 Mdot
.43959 .69756 Mdot
.4066 .7188 Mdot
.43644 .35853 Mdot
.2649 .69568 Mdot
.31454 .72944 Mdot
.75035 .49751 Mdot
.77868 .66766 Mdot
.59982 .5303 Mdot
.67967 .76646 Mdot
.39687 .43436 Mdot
.4506 .32786 Mdot
.61679 .70415 Mdot
.85972 .5429 Mdot
.51131 .28478 Mdot
.54966 .51637 Mdot
.55867 .82774 Mdot
.63367 .79986 Mdot
.39714 .40351 Mdot
.4221 .21489 Mdot
.18578 .6004 Mdot
.46916 .70509 Mdot
.51121 .19854 Mdot
.28593 .56839 Mdot
.55822 .81974 Mdot
.70934 .5855 Mdot
.48915 .48713 Mdot
.7467 .33018 Mdot
.74824 .54846 Mdot
.25191 .53889 Mdot
.77763 .34121 Mdot
.75468 .37474 Mdot
.72666 .70026 Mdot
.69083 .53252 Mdot
.45902 .41808 Mdot
.53107 .28259 Mdot
.83416 .57515 Mdot
.30416 .548 Mdot
.60488 .64762 Mdot
.72847 .26101 Mdot
.26292 .30464 Mdot
.29355 .70212 Mdot
.80576 .60078 Mdot
.40327 .37983 Mdot
.69699 .59275 Mdot
.32962 .24362 Mdot
.52241 .28226 Mdot
.57514 .29828 Mdot
.38617 .32902 Mdot
.41777 .76398 Mdot
.47549 .31451 Mdot
.87643 .51889 Mdot
.58759 .8134 Mdot
.73758 .51503 Mdot
.70634 .22774 Mdot
.37021 .78841 Mdot
.58936 .63574 Mdot
.46415 .30236 Mdot
.68498 .77601 Mdot
.39383 .30139 Mdot
.45066 .83603 Mdot
.51371 .44126 Mdot
.62078 .35143 Mdot
.43693 .76963 Mdot
.48057 .196 Mdot
.68845 .56971 Mdot
.71053 .24744 Mdot
.44676 .21264 Mdot
.45781 .77643 Mdot
.53759 .41106 Mdot
.56012 .2602 Mdot
.55373 .25009 Mdot
.4955 .41306 Mdot
.45719 .49324 Mdot
.43747 .47596 Mdot
.47519 .44843 Mdot
.34915 .45024 Mdot
.47891 .40624 Mdot
.41275 .23575 Mdot
.40625 .32832 Mdot
.76227 .35929 Mdot
.19259 .61924 Mdot
.39985 .71896 Mdot
.26317 .49479 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000<Gooooo0_l00023ooooo`007?ooool00ol0003oooooooooo`34ooooo`;o0000Poooool0
01cooooo00?o0000ooooooooool0a?ooool2o`0008?ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0<cooooo0_l0001kooooo`007?ooool00ol0
003oooooooooo`3<ooooo`;o0000Noooool001cooooo00?o0000ooooooooool0c_ooool2o`0007Wo
oooo000Looooo`03o`000?oooooooooo0<kooooo1?l0001gooooo`007?ooool00ol0003ooooooooo
o`3?ooooo`?o0000Moooool001cooooo00?o0000ooooooooool0d?ooool3o`0007Kooooo000Loooo
o`03o`000?oooooooooo09[ooooo1?l0000cooooo`?o0000MOooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo08oooooo0_l00009
ooooo`Co0000=?ooool2o`0007Gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ
8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`2>ooooo`?o0000
1oooool4o`0000Sooooo0_l0000]ooooo`Co0000L_ooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo08kooooo0_l0
0008ooooo`;o00001_ooool7o`0002cooooo1?l0001booooo`0000?oooooo`000?ooool00_ooool0
0ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol00029ooooo`;o00002Oooool2
o`0000[ooooo1?l000000ooooooo0000o`000003ooooo`;o0000:_ooool2o`00077ooooo00000ooo
oooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0
003oooooooooo`29ooooo`?o00001_ooool4o`0000;ooooo0_l0000;ooooo`;o00000oooool2o`00
02[ooooo0ol0001`ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0=ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0Qoooool2o`000003ooooool0003o000000Ko
oooo0_l00004ooooo`;o00002?ooool2o`000003ooooool0003o000000Sooooo0_l0000Vooooo`;o
0000L?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So
410@00Kooooo00?o0000ooooooooool0Qoooool2o`0000oooooo0_l00003ooooo`;o000000?ooooo
o`000?l000000_l000000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l00000V?ooool0
0006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo
00?o0000ooooooooool0P_ooool5o`0000Gooooo0ol0000<ooooo`Oo00002_ooool2o`0002gooooo
0_l0001/ooooo`007?ooool00ol0003oooooooooo`20ooooo`Oo00001Oooool3o`0000Cooooo0_l0
0006ooooo`;o00000_ooool2o`0001?ooooo0_l0000Uooooo`;o0000K?ooool001cooooo00?o0000
ooooooooool0P?ooool4o`000003ooooool0003o000000Cooooo0_l00006ooooo`;o00005oooool2
o`0000Kooooo0_l0000Vooooo`;o0000Joooool001cooooo00?o0000ooooooooool0O?ooool3o`00
0003ooooool0003o000000?ooooo0_l00004ooooo`;o00000_ooool2o`0001Wooooo1?l00007oooo
o`Co00008oooool2o`000003ooooool0003o000006Sooooo000Looooo`03o`000?oooooooooo07Ko
oooo0_l00003ooooo`Co00003?ooool2o`0000;ooooo0_l0000Iooooo`;o000000?oooooo`000?l0
00001_ooool4o`0002Kooooo0_l000000ooooooo0000o`00001Uooooo`007?ooool00ol0003ooooo
ooooo`1fooooo`Co000000?oooooo`000?l000000_l00007ooooo`;o00000oooool2o`00023ooooo
0_l00006ooooo`;o00000oooool2o`0002Kooooo0_l0001Uooooo`007?ooool00ol0003ooooooooo
o`1cooooo`;o000000?oooooo`000?l000000_l00005ooooo`;o00001?ooool3o`0002Gooooo0_l0
0006ooooo`;o00000oooool3o`0008cooooo000Looooo`03o`000?oooooooooo07?ooooo1ol00002
ooooo`Go000000Coooooo`000?l0003ooooo0ol0000Uooooo`Co00002_ooool2o`0008cooooo000L
ooooo`03o`000?oooooooooo06oooooo0_l00002ooooo`Co00001Oooool4o`0000;ooooo0_l00003
ooooo`;o00009_ooool2o`0000Oooooo0_l0000Yooooo`;o0000I?ooool001cooooo00?o0000oooo
ooooool0H_ooool5o`0000;ooooo0_l00002ooooo`Go00004oooool4o`0002oooooo0_l0000Yoooo
o`?o0000Hoooool001cooooo00?o0000ooooooooool0H_ooool:o`000003ooooool0003o000000?o
00002oooool2o`000003ooooool0003o000000?ooooo0_l0000/ooooo`;o0000;oooool3o`0006;o
oooo000Looooo`03o`000?oooooooooo06;ooooo2_l0000=ooooo`;o00000_ooool5o`00037ooooo
1_l0000Zooooo`Ko0000H?ooool001cooooo0_l0001Wooooo`;o000000Goooooo`000?l0003o0000
ooooo`03o`0000Wooooo0_l00004ooooo`;o00008_ooool5o`0000;ooooo0_l00004ooooo`?o0000
00?oooooo`000?l000000ol00009ooooo`;o00007oooool2o`0000;ooooo0_l0001Pooooo`007?oo
ool00ol0003oooooooooo`1]ooooo`?o0000<_ooool6o`0000;ooooo0_l00004ooooo`?o00002?oo
ool2o`0000Gooooo0_l0000Sooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0W_ooool6
o`000004ooooool0003o0000o`0000;ooooo0_l00004ooooo`;o00000_ooool2o`0000Cooooo1Ol0
0003ooooo`;o00007oooool2o`0000;ooooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`2L
ooooo`Oo00001oooool2o`0000Kooooo1?l00004ooooo`Go00001?ooool2o`0001kooooo2?l0001N
ooooo`007?ooool00ol0003oooooooooo`2Kooooo`Go00004Oooool3o`0000Oooooo0ol00005oooo
o`;o00008?ooool6o`0005kooooo000Looooo`03o`000?oooooooooo09_ooooo1?l0000=ooooo`?o
00000_ooool2o`00017ooooo0_l0000Oooooo`Ko0000G_ooool001cooooo00?o0000ooooooooool0
WOooool2o`0000Gooooo0_l00004ooooo`Go00002?ooool2o`0000_ooooo0_l0000Oooooo`?o0000
00?oooooo`000?l00000G_ooool001cooooo00?o0000ooooooooool0V?ooool4o`0000Sooooo0_l0
0004ooooo`;o00001?ooool4o`0000?ooooo0_l00009ooooo`;o00008Oooool6o`0005kooooo000L
ooooo`03o`000?oooooooooo09Oooooo1Ol00003ooooo`;o00003oooool6o`0000cooooo0ol0000P
ooooo`Ko0000G_ooool001cooooo00?o0000ooooooooool0Joooool2o`0002[ooooo0_l00006oooo
o`;o00002_ooool2o`0000Kooooo1?l0000;ooooo`?o00008?ooool6o`0005kooooo000Looooo`03
o`000?oooooooooo06Cooooo0_l00005ooooo`;o0000;?ooool4o`0000Wooooo2Ol00005ooooo`Oo
00002Oooool2o`0001kooooo1Ol0001Pooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o0000
0_ooool2o`0003;ooooo1Ol00005ooooo`;o00000_ooool5o`000004ooooool0003o0000o`0000Oo
oooo1Ol00009ooooo`;o00000_ooool3o`0001Wooooo1Ol0001Pooooo`007?ooool00ol0003ooooo
ooooo`1Pooooo`;o00004?ooool2o`0002Cooooo0ol000000ooooooo0000o`000004ooooo`;o0000
1?ooool2o`0000?ooooo0_l0000:ooooo`;o000000?oooooo`000?l000002_ooool3o`0001Sooooo
1?l0001Rooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o00003Oooool5o`0000;ooooo0_l0
000Qooooo`Go00002_ooool3o`0000;ooooo0ol000000ooooooo0000o`000004o`000005ooooool0
003o0000o`000?ooool00_l000000ooooooo0000o`00000Rooooo`Co0000H_ooool001cooooo00?o
0000ooooooooool0G?ooool3o`0000?ooooo0_l00008ooooo`;o000000?oooooo`000?l000000_l0
0003ooooo`?o00006_ooool2o`000003ooooool0003o000000;ooooo0ol0000;ooooo`?o000000?o
ooooo`000?l000003ol00002ooooo`;o000000?oooooo`000?l000007_ooool6o`00067ooooo000L
ooooo`03o`000?oooooooooo05Sooooo0_l00002ooooo`So00002?ooool6o`0000?ooooo1?l0000J
ooooo`Wo00000oooool2o`0000Oooooo2_l00002ooooo`Wo00000_ooool2o`000004ooooool0003o
0000o`0000?ooooo0_l0000Hooooo`Ko0000HOooool001cooooo0_l0001Fooooo`;o000000?ooooo
o`000?l000001?ooool4o`0000cooooo0_l00005ooooo`;o00000_ooool5o`0001Gooooo2Ol00003
ooooo`;o00000oooool2o`0000;ooooo3_l000000ooooooo0000o`000004o`0000Kooooo0_l00002
ooooo`?o00006?ooool2o`000004ooooool0003o0000o`0000;ooooo0_l0001Mooooo`007?ooool0
0ol0003oooooooooo`1Booooo`;o000000?oooooo`000?l000005oooool3o`0000Sooooo1Ol0000C
ooooo`Co000000?oooooo`000?l000000ol00003ooooo`;o00001?ooool@o`000003ooooool0003o
000000?ooooo0ol0000:ooooo`;o00006Oooool6o`000004ooooool0003o0000o`0005gooooo000L
ooooo`03o`000?oooooooooo05;ooooo1?l0000Hooooo`?o00000_ooool2o`0000Oooooo0ol0000B
ooooo`Co000000?oooooo`000?l000000_l000001?oooooo0000o`000?ooool2o`0000Cooooo5Ol0
00000ooooooo0000o`000007ooooo`;o00000_ooool2o`0001Sooooo1ol000000ooooooo0000o`00
001Nooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00000_ooool4o`00017ooooo0_l00000
0ooooooo0000o`000007o`0000Sooooo0_l0000@ooooo`;o000000?oooooo`000?l000000_l00005
ooooo`;o00001ooooolEo`000003ooooool0003o000000Oooooo0_l0000Looooo`;o00000oooool2
o`0000?ooooo0_l0001Looooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00001?ooool2o`00
017ooooo0_l000000ooooooo0000o`000002ooooo`Co00000_ooool2o`0000Gooooo0_l00004oooo
o`;o00002_ooool2o`000003ooooool0003o000000;o00002oooool2o`000003ooooool0003o0000
00Go000000?oooooo`000?l000003?l00004ooooo`;o00001?ooool2o`0001_ooooo0_l00002oooo
o`?o00000oooool2o`0005cooooo000Looooo`03o`000?oooooooooo06kooooo0_l00006ooooo`;o
000000Coooooo`000?l0003o00001oooool2o`0001;ooooo0_l00008ooooo`;o000000?oooooo`00
0?l000005ol000000ooooooo0000o`000003ooooo`Ko00006?ooool2o`0000;ooooo0_l00006oooo
o`;o0000F_ooool001cooooo00?o0000ooooooooool0C_ooool2o`0001Sooooo0_l000001?oooooo
0000o`000?ooool2o`0000Wooooo0ol00007ooooo`?o00003?ooool2o`0000?ooooo0_l0000:oooo
oa[o00001_ooool6o`0001Sooooo0_l00002ooooo`;o00001_ooool2o`000003ooooool0003o0000
05Oooooo000Looooo`03o`000?oooooooooo04gooooo0ol0000Hooooo`;o000000?oooooo`000?l0
00001ol0000@ooooo`?o000000?oooooo`000?l000002?ooool2o`0000kooooo7?l000000ooooooo
0000o`000005ooooo`Co00005oooool3o`0000cooooo0_l0001Gooooo`007?ooool00ol0003ooooo
ooooo`1=ooooo`;o00005_ooool5o`0000;ooooo2?l000000ooooooo0000o`00000>ooooo`;o0000
00?oooooo`000?l000000oooool2o`0001;ooooo1Ol000001?oooooo0000o`000?oooolGo`0000Co
oooo1Ol0000Gooooo`?o0000IOooool001cooooo00?o0000ooooooooool0IOooool5o`0000?ooooo
2ol00002ooooo`;o00001?ooool2o`0000Gooooo0_l000001?oooooo0000o`000?ooool5o`0000[o
oooo0_l00002ooooo`Ko000000Coooooo`000?l0003ooooo5ol00004ooooo`Co00006?ooool2o`00
06Kooooo000Looooo`03o`000?oooooooooo04Wooooo0_l0000Jooooo`;o000000Coooooo`000?l0
003ooooo3Ol00002ooooo`?o00000oooool2o`0000Gooooo0_l000000ooooooo0000o`000002oooo
o`Co000000?oooooo`000?l000001oooool:o`0000Cooooo5ol00004ooooo`Co00000_ooool2o`00
01Cooooo1?l0000:ooooo`Co000000?oooooo`000?l000000oooool2o`0004kooooo000Looooo`03
o`000?oooooooooo04Wooooo0_l0000Jooooo`?o000000?oooooo`000?l000003_l00002ooooo`;o
00003?ooool2o`0000Sooooo0_l00009ooooo`Go00001ooooolIo`0000Oooooo0ol0000Dooooo`Co
00002_ooool4o`000003ooooool0003o000000;o000000?oooooo`000?l00000C_ooool001cooooo
00?o0000ooooooooool0IOooool3o`000003ooooool0003o0000013o00003_ooool3o`0001Cooooo
0ol00009oooooaOo00000_ooool4o`000004ooooool0003o0000o`0001?ooooo0ol00007ooooo`;o
00002_ooool2o`00057ooooo000Looooo`03o`000?oooooooooo06Gooooo0_l00002oooooa;o0000
3?ooool2o`000004ooooool0003o0000ooooo`;o00004?ooool5o`0000Gooooo0_l000000ooooooo
0000o`00000Ko`0001Oooooo0ol00007ooooo`;o00003Oooool2o`0004kooooo000Looooo`03o`00
0?oooooooooo06?ooooo0_l00004oooooa?o00002oooool2o`0000Cooooo0_l0000?ooooo`Ko0000
0_ooool2o`000003ooooool0003o000001Oo000000?oooooo`000?l000001ol0000Eooooo`;o0000
1oooool2o`0000gooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`1Sooooo`;o00000_oo
oolEo`0000Gooooo1?l00008ooooo`;o00003oooool3o`000003ooooool0003o000000;ooooo0_l0
00000ooooooo0000o`00000Go`0000;ooooo2?l0000Eooooo`Co00001oooool2o`0000_ooooo0_l0
001>ooooo`007?ooool2o`0004Kooooo0_l0000Kooooo`?o00000_oooolGo`0000?ooooo1?l00002
ooooo`;o00001?ooool2o`000003ooooool0003o000000cooooo1?l00006oooooa_o000000?ooooo
o`000?l000006oooool4o`0000Cooooo0_l000000ooooooo0000o`000005ooooo`;o0000E?ooool0
01cooooo00?o0000ooooooooool0AOooool2o`0001_ooooo0_l00004oooooaSo00001oooool2o`00
00Oooooo0_l0000=ooooo`?o00001_ooool5o`000003ooooool0003o000001So00006Oooool3o`00
00Gooooo0_l00008ooooo`;o00002Oooool2o`0004Wooooo000Looooo`03o`000?oooooooooo06;o
oooo0_l00004oooooaSo00002_ooool2o`0000kooooo0_l00004ooooo`;o00001ooooolOo`0001Wo
oooo0ol0000>ooooo`;o00002_ooool2o`0004Wooooo000Looooo`03o`000?oooooooooo06;ooooo
0_l00004oooooaWo00002Oooool2o`000003ooooool0003o000000_ooooo0_l00004ooooo`;o0000
1ooooolLo`000003ooooool0003o000001_ooooo0_l0000=ooooo`Co00001?ooool2o`0004gooooo
000Looooo`03o`000?oooooooooo06Sooooo0_l000000ooooooo0000o`00000Fo`0000Oooooo0_l0
00000ooooooo0000o`00000Aooooo`;o00000_ooool2o`0000Gooooo7?l0000Looooo`;o00002?oo
ool2o`0000Gooooo0_l00004ooooo`;o0000COooool001cooooo00?o0000ooooooooool0H?ooool2
o`0000Kooooo5_l00003ooooo`;o00001_ooool3o`000003ooooool0003o0000017ooooo0_l00002
ooooo`;o00001ooooolJo`0001cooooo0_l00008ooooo`;o00001?ooool2o`0000Gooooo0_l0001=
ooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o00001_oooolGo`0000Kooooo0_l00002oooo
o`?o00004Oooool2o`0000Gooooo0_l00008oooooa7o00009?ooool3o`0000gooooo0_l00002oooo
o`Go0000COooool001cooooo00?o0000ooooooooool0H?ooool2o`0000Kooooo6?l00005ooooo`;o
00005_ooool2o`0000Cooooo0ol00009ooooo`ko00000_ooool2o`0002?ooooo0_l0000Aooooo`?o
00000_ooool2o`0004_ooooo000Looooo`03o`000?oooooooooo05kooooo0_l00008oooooaSo0000
3Oooool2o`0001Cooooo0_l0000;ooooo`Go000000?oooooo`000?l000000_l000000ooooooo0000
o`000002ooooo`;o0000<?ooool2o`0000Gooooo0_l00002ooooo`;o0000Boooool001cooooo00?o
0000ooooooooool0G_ooool2o`0000_ooooo4ol00002ooooo`;o00002oooool2o`00017ooooo0_l0
0002ooooo`;o00002_ooool5o`0000Kooooo0ol00008ooooo`;o00009Oooool2o`0000;ooooo0_l0
000>ooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0?Oooool2o`0001oooooo0_l0000:
oooooaCo000000Goooooo`000?l0003o0000ooooo`04o`0000?ooooo0_l0000Dooooo`;o00000_oo
ool5o`0000Sooooo1_l00004ooooo`?o00002?ooool2o`0002Gooooo0_l0000=ooooo`;o00000ooo
ool2o`0004Kooooo000Looooo`03o`000?oooooooooo03gooooo0_l0000Oooooo`Co00002?oooolB
o`0000?ooooo0_l00002ooooo`Co00000oooool2o`000003ooooool0003o000001Kooooo1?l00009
ooooo`Go00000_ooool4o`0000Sooooo0_l0000Uooooo`;o00003?ooool4o`0004_ooooo000Loooo
o`03o`000?oooooooooo05kooooo1?l00009oooooa;o00001_ooool3o`0000Oooooo0_l0000Hoooo
o`?o00002Oooool2o`0000Cooooo0_l0000:ooooo`;o00009Oooool2o`0000Gooooo0_l00005oooo
o`Co0000Boooool001cooooo00?o0000ooooooooool0G_ooool3o`0000cooooo4?l00006ooooo`?o
00008_ooool2o`0000Wooooo0_l00003ooooo`;o00002oooool2o`0002Kooooo0_l000001?oooooo
0000o`000?ooool4o`000003ooooool0003o000000;ooooo0_l0001;ooooo`0000Koooooonk^k_lb
<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000
ooooooooool0G_ooool3o`0000cooooo0ol00002ooooo`So00001oooool2o`0002[ooooo0_l00007
ooooo`Co000000?oooooo`000?l000000oooool2o`0002_ooooo0_l000000ooooooo0000o`000003
ooooo`;o000000?oooooo`000?l000000_ooool2o`0004_ooooo00001_ooooooMgMgoiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0??oo
ool2o`00023ooooo0ol0000=ooooo`Co000000?oooooo`000?l000001Oooool2o`0000;ooooo0_l0
00000ooooooo0000o`00000Zooooo`;o00001oooool2o`000003ooooool0003o000000;o00000ooo
ool2o`0002Sooooo0_l0000<ooooo`So0000BOooool00003ooooool@413ooooo00;ooooo00?o410@
ooooooooool02Oooool5o`0000Kooooo00?o0000ooooooooool0??ooool2o`00023ooooo0ol0000=
ooooo`Wo00000oooool2o`0000;ooooo0_l00005ooooo`;o0000<_ooool2o`0000gooooo0_l0000P
ooooo`;o00001?ooool2o`0000Sooooo0_l00002ooooo`;o0000BOooool00003ooooool0003ooooo
00;ooooo00?o0000ooooooooool02Oooool01?m4A4CogMgMooooool00007ooooo`?o0000Goooool2
o`0000gooooo0_l00002ooooo`Go00002_ooool2o`0000;ooooo1?l0000Rooooo`?o00004Oooool3
o`0000Kooooo0_l0000Pooooo`;o00001?ooool2o`0000cooooo0ol00018ooooo`0000?oooooo`00
0?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000
ooooooooool0>_ooool2o`0002?ooooo0_l0000=ooooo`?o00001_ooool2o`0000Cooooo0_l00002
ooooo`?o00000oooool2o`0000oooooo0_l00008ooooo`;o00001oooool5o`0000?ooooo0_l0000:
ooooo`?o00001_ooool2o`00023ooooo0_l00004ooooo`;o00001Oooool2o`0000Kooooo0_l00018
ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co0000
00Oooooo00?o0000ooooooooool0>_ooool2o`0002?ooooo1Ol0000;ooooo`;o00001Oooool6o`00
0003ooooool0003o000000;ooooo0ol0000Dooooo`;o000000?oooooo`000?l000001Oooool2o`00
00[ooooo0_l00003ooooo`;o00004oooool2o`00023ooooo0ol00003ooooo`;o00001?ooool3o`00
00Kooooo0_l00018ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co
000000Oooooo00?o0000ooooooooool0Goooool6o`0000kooooo1Ol000001?oooooo0000o`000?l0
0005ooooo`;o00006?ooool2o`0000kooooo0_l0000Mooooo`;o00001_ooool2o`0001Kooooo0ol0
0003ooooo`;o00001?ooool7o`0000;ooooo0_l00018ooooo`0000Koooooonk^k_lb<S;o0000oc8b
<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0>?ooool2o`0002Kooooo
1Ol00009ooooo`Co000000Coooooo`000?l0003o00001?ooool2o`0000_ooooo0_l0000Dooooo`;o
00003?ooool2o`000003ooooool0003o000000Sooooo0_l00004ooooo`;o00000_ooool2o`0000Ko
oooo1Ol00002ooooo`?o00005_ooool2o`0000[ooooo1ol00002ooooo`;o0000B?ooool001cooooo
00?o0000ooooooooool0=oooool3o`0002Kooooo0_l000000ooooooo0000o`000005ooooo`?o0000
00?oooooo`000?l000000_l00006ooooo`;o00003Oooool2o`0000Sooooo0_l00006ooooo`;o0000
0_ooool2o`0000oooooo0_l00008ooooo`;o00001?ooool6o`0000Sooooo0ol00002ooooo`;o0000
5oooool2o`0000gooooo0_l00004ooooo`?o0000Aoooool001cooooo00?o0000ooooooooool0=ooo
ool2o`0002gooooo0_l00002ooooo`?o000000?oooooo`000?l000000_l00006ooooo`;o00003ooo
ool2o`0000Kooooo0_l00006ooooo`;o00005oooool3o`0000_ooooo0_l000000ooooooo0000o`00
000:ooooo`Co00008?ooool3o`0000Oooooo1_l00016ooooo`007?ooool00ol0003oooooooooo`1U
ooooo`?o00001_ooool2o`0000_ooooo0_l0000<ooooo`;o00003_ooool2o`0001Oooooo0ol0000>
ooooo`;o00002_ooool4o`00023ooooo0ol00003ooooo`[o0000A_ooool001cooooo00?o0000oooo
ooooool0IOooool2o`0000Kooooo1?l000000ooooooo0000o`000007ooooo`;o00007?ooool2o`00
00_ooooo0_l00009ooooo`Go00002oooool2o`0000Kooooo1?l00009ooooo`;o00006oooool2o`00
00Cooooo1?l00002ooooo`Co0000A_ooool001cooooo00?o0000ooooooooool0=Oooool2o`0003Ko
oooo1ol0000booooo`;o00002Oooool5o`0000Sooooo0_l000000ooooooo0000o`000004ooooo`Oo
00001Oooool2o`000004ooooool0003o0000o`00023ooooo0ol00003ooooo`Co0000A_ooool001co
oooo00?o0000ooooooooool0=Oooool2o`0002kooooo1?l00007ooooo`?o0000<?ooool2o`0000ko
oooo0_l00005ooooo`;o00000_ooool3o`0000Kooooo0_l00003ooooo`;o000000?oooooo`000?l0
00001?l000001?oooooo0000o`000?l0000Pooooo`Co00001?ooool3o`0004Gooooo000Looooo`03
o`000?oooooooooo03Gooooo0ol0000]ooooo`Co00001_ooool3o`0000_ooooo0_l00003ooooo`;o
00007oooool2o`0001Gooooo0_l00003ooooo`;o00002?ooool2o`0000Cooooo1_l00002ooooo`;o
00005oooool2o`0000Sooooo0ol00004ooooo`?o0000AOooool001cooooo00?o0000ooooooooool0
<oooool5o`0002kooooo0ol00006ooooo`?o00001Oooool2o`0000Cooooo0_l00003ooooo`;o0000
6_ooool2o`0000kooooo0_l00007ooooo`;o00004?ooool2o`0000Sooooo1_l0000Gooooo`?o0000
1oooool2o`0004gooooo000Looooo`03o`000?oooooooooo03?ooooo0_l0000booooo`?o00001?oo
ool3o`0000?ooooo0_l000000ooooooo0000o`00000Mooooo`;o00001_ooool3o`0000;ooooo0_l0
00000ooooooo0000o`000006ooooo`;o00001oooool2o`0000Wooooo0_l00002ooooo`?o00000_oo
ool2o`0000Oooooo1_l0000Gooooo`Co00003?ooool2o`0004Kooooo000Looooo`03o`000?oooooo
oooo06Oooooo0ol00004ooooo`?o00000oooool2o`00023ooooo1?l00005ooooo`;o00000_ooool2
o`000003ooooool0003o000000;o00004?ooool2o`0000Kooooo0_l00002ooooo`?o00000_ooool2
o`0000Oooooo0_l00002ooooo`;o00006Oooool2o`0000cooooo0_l00016ooooo`007?ooool00ol0
003oooooooooo`1Nooooo`Ko00000oooool2o`0002kooooo0ol0000>ooooo`;o00004?ooool2o`00
0003ooooool0003o000000Kooooo0_l0000dooooo`;o00001?ooool2o`0004Kooooo000Looooo`;o
0000<oooool2o`0002Sooooo3Ol00004ooooo`?o00009?ooool2o`000003ooooool0003o000000Ko
oooo0_l00002ooooo`;o00006?ooool2o`0000Gooooo1?l0000cooooo`;o0000C?ooool001cooooo
00?o0000ooooooooool0<_ooool2o`0002Gooooo0_l000001?oooooo0000o`000?ooool2o`0000;o
oooo1_l00004ooooo`?o00008oooool5o`0000Oooooo0_l00002ooooo`;o00000oooool2o`0000co
oooo0_l00003ooooo`Go00001?ooool5o`0000?ooooo0ol0000Mooooo`;o00003_ooool2o`0000Co
oooo0_l00015ooooo`007?ooool00ol0003oooooooooo`0booooo`;o00007oooool2o`000004oooo
ool0003o0000ooooo`;o00001?ooool2o`0000?ooooo1ol0000Xooooo`Go00004?ooool3o`0000_o
oooo0_l00002ooooo`Ko00000oooool8o`000003ooooool0003o000000;o00001oooool2o`0001?o
oooo0_l00005ooooo`;o00001oooool3o`0000?ooooo0_l00015ooooo`007?ooool00ol0003ooooo
ooooo`0booooo`;o00007oooool2o`000004ooooool0003o0000ooooo`;o00002Oooool4o`000003
ooooool0003o000003kooooo0_l0000?ooooo`;o00001oooool:o`000003ooooool0003o000000;o
00001?ooool3o`000003ooooool0003o000001Oooooo0_l000000ooooooo0000o`000005ooooo`;o
0000B_ooool001cooooo00?o0000ooooooooool0D?ooool2o`0000?ooooo0_l00002ooooo`;o0000
00?oooooo`000?l000001_ooool4o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000
o`000004ooooo`;o00007oooool2o`0002;ooooo0_l00005ooooo`?o00001Oooool8o`0000?ooooo
1_l000000ooooooo0000o`00000Gooooo`;o0000DOooool001cooooo00?o0000ooooooooool0D?oo
ool2o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000001oooool3o`000003ooooool0
003o000000So00001?ooool2o`0001oooooo0_l00006ooooo`;o00000_ooool2o`0001;ooooo0_l0
0002ooooo`;o00000_ooool2o`000003ooooool0003o000000?o00001?ooool7o`0000;ooooo1Ol0
0003ooooo`;o00007_ooool2o`0004[ooooo000Looooo`03o`000?oooooooooo03Gooooo0_l0000K
ooooo`Wo00002_ooool<o`00013ooooo0_l00003ooooo`;o00005?ooool2o`0000;ooooo0_l00002
ooooo`;o00004_ooool2o`0000Kooooo0_l000000ooooooo0000o`000004o`0000Cooooo1?l00000
1?oooooo0000o`000?ooool2o`0002Kooooo0_l00004ooooo`;o00007?ooool2o`0002Kooooo000L
ooooo`03o`000?oooooooooo03Gooooo0_l0000Hooooo`co00002_ooool;o`000003ooooool0003o
000000kooooo0_l00003ooooo`;o00002oooool2o`0000Oooooo0_l00008ooooo`;o00000_ooool2
o`0001Cooooo0_l000001?oooooo0000o`000?ooool5o`0000?ooooo0ol000000ooooooo0000o`00
0008ooooo`;o00003Oooool2o`0000;ooooo0_l0000<ooooo`;o00001?ooool2o`0001cooooo0_l0
000Vooooo`007?ooool00ol0003oooooooooo`0booooo`;o00006oooool4o`000005ooooool0003o
0000o`000?ooool00_l00005ooooo`;o00001Oooool3o`0000?ooooo0_l00003ooooo`;o00005ooo
ool2o`0000Oooooo0_l00006ooooo`Co00001Oooool4o`0000;ooooo0_l0000Dooooo`;o00001Ooo
ool6o`000005ooooool0003o0000o`000?ooool00_l00008ooooo`;o00000oooool2o`0000Sooooo
0_l00002ooooo`;o00000oooool2o`0000Sooooo0ol00002ooooo`;o00006oooool2o`0002Oooooo
000Looooo`03o`000?oooooooooo037ooooo1?l000000ooooooo0000o`00000Looooo`So00000_oo
ool3o`0000;ooooo0_l000000ooooooo0000o`00000;ooooo`;o00004Oooool2o`0000;ooooo0_l0
0007ooooo`?o00001Oooool4o`0000Gooooo0ol0000Qooooo`Go000000?oooooo`000?l000001ol0
000:ooooo`;o00004Oooool2o`0000Sooooo1?l0000Mooooo`?o00009oooool001cooooo00?o0000
ooooooooool0<?ooool8o`0001cooooo2Ol000001?oooooo0000o`000?l00002ooooo`;o00001Ooo
ool3o`0000?ooooo0_l000000ooooooo0000o`00000<ooooo`;o000000?oooooo`000?l000000_l0
000;ooooo`?o00001_ooool3o`0000Kooooo0_l0000Qooooo`oo00001Oooool2o`0001Kooooo0_l0
000:ooooo`;o00007Oooool3o`0002Oooooo000Looooo`03o`000?oooooooooo033ooooo0_l00003
ooooo`;o00003_ooool2o`0000[ooooo3?l000000ooooooo0000o`000003o`0000Oooooo0ol00003
ooooo`;o00003oooool2o`000003ooooool0003o000000;ooooo0_l0000>ooooo`;o00000_ooool3
o`0002Wooooo4Ol00003ooooo`?o00002oooool2o`0000Gooooo0_l000000ooooooo0000o`00000Y
ooooo`;o0000:?ooool001cooooo00?o0000ooooooooool0=_ooool2o`0000gooooo0_l0000:oooo
o`Ko000000?oooooo`000?l000000_l00002ooooo`Oo00007oooool2o`0000;ooooo0_l00006oooo
o`Go00000oooool2o`000004ooooool0003o0000ooooo`;o00009Oooool;o`000003ooooool0003o
000000Ko00001?ooool2o`0000_ooooo0_l00005ooooo`;o000000?oooooo`000?l00000:Oooool2
o`0002Sooooo000Looooo`03o`000?oooooooooo03Kooooo0_l0000Jooooo`Co000000?oooooo`00
0?l000001?l000000ooooooo0000o`000005o`000003ooooool0003o000000oooooo0_l00003oooo
o`;o00000oooool2o`000003ooooool0003o000000[ooooo1Ol00003ooooo`;o000000Coooooo`00
0?l0003ooooo0_l00006ooooo`;o00007OoooolDo`0000;ooooo0_l0000Gooooo`;o00002_ooool2
o`0004Oooooo000Looooo`03o`000?oooooooooo04;ooooo0_l0000;ooooo`Oo000000?oooooo`00
0?l000003?l000000ooooooo0000o`000003ooooo`?o00001oooool4o`0000?ooooo0_l00003oooo
o`;o00002oooool5o`0001?ooooo0_l0000MoooooaGo000000?oooooo`000?l000008_ooool3o`00
04Oooooo000Looooo`03o`000?oooooooooo03Gooooo0_l0000;ooooo`;o00002ooooolHo`0000Co
oooo0ol00007ooooo`;o00000oooool4o`00013ooooo1Ol0000;ooooo`;o00009?oooolGo`0000Co
oooo0_l00007ooooo`;o00001_ooool2o`000003ooooool0003o000000[ooooo0_l000000ooooooo
0000o`00000Gooooo`;o0000;?ooool001cooooo0_l0000cooooo`Go00005oooool=o`000003oooo
ool0003o000000Wo00004oooool2o`0000Wooooo0_l00007ooooo`Ko00002_ooool2o`0000;ooooo
0_l0000@ooooo`;o00003Oooool7o`0000;ooooo3ol00004ooooo`;o00001oooool2o`0000Kooooo
0_l000000ooooooo0000o`00000;ooooo`Co00005oooool2o`0002cooooo000Looooo`03o`000?oo
oooooooo03;ooooo1?l0000:ooooo`;o00003?ooool2o`000003ooooool0003o000001Co000000?o
ooooo`000?l000006oooool2o`0000Oooooo1_l0000>ooooo`;o00004?ooool2o`0000gooooo2?l0
00000ooooooo0000o`00000>o`0000?ooooo0_l00007ooooo`;o00002?ooool3o`0000Wooooo1_l0
000Gooooo`?o0000:oooool001cooooo00?o0000ooooooooool0<Oooool2o`0000gooooo0_l0000;
ooooo`;o000000?oooooo`000?l000004Ol000001Ooooooo0000o`000?l0003ooooo00;o00004Ooo
ool2o`0002Cooooo1Ol00005ooooo`;o00005_ooool4o`000003ooooool0003o000001;o00005_oo
ool5o`0000Oooooo1?l0000Iooooo`?o0000:oooool001cooooo00?o0000ooooooooool0;oooool4
o`000003ooooool0003o000000Wooooo0_l0000<ooooo`go000000?oooooo`000?l000001ol00004
ooooo`;o00004Oooool2o`0000cooooo0_l0000Fooooo`Go00000_ooool2o`000004ooooool0003o
0000ooooo`?o00004?oooolJo`0000[ooooo0ol0000:ooooo`Go00001oooool2o`0001_ooooo0_l0
000/ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00000oooool2o`0000Wooooo0_l0000;
oooooaSo00001oooool3o`0000kooooo0_l0000;ooooo`;o00007Oooool2o`0000?ooooo1?l0000@
oooooa[o00002_ooool3o`0000Wooooo0ol00009ooooo`?o00006oooool2o`0002cooooo000Loooo
o`03o`000?oooooooooo03kooooo0_l0000<oooooaKo000000?oooooo`000?l000001_ooool3o`00
00kooooo0_l0000Vooooo`;o00001oooool4o`00017ooooo6ol0000?ooooo`;o00000oooool3o`00
00Wooooo0ol00019ooooo`007?ooool00ol0003oooooooooo`0mooooo`?o00002_ooool2o`000003
ooooool0003o000001?o000000Coooooo`000?l0003o00000_ooool2o`0000;ooooo0ol00003oooo
o`;o00001?ooool2o`000004ooooool0003o0000ooooo`;o00006?ooool2o`0000;ooooo0ol00000
0ooooooo0000o`000002ooooo`Go00001_ooool2o`00013ooooo0ol000000ooooooo0000o`00000F
o`0000?ooooo0_l0000:ooooo`;o00003oooool4o`0001Sooooo0_l0000^ooooo`007?ooool00ol0
003oooooooooo`0mooooo`;o00002ooooolMo`000003ooooool0003o000000?ooooo0_l000000ooo
oooo0000o`000002o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0001Kooooo1?l00002
ooooo`?o000000?oooooo`000?l000000_ooool6o`0000Gooooo0_l0000?ooooo`Co000000?ooooo
o`000?l000006?l000000ooooooo0000o`00000?ooooo`;o00002_ooool4o`0001Kooooo1?l0000^
ooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00002_oooolMo`0000Cooooo1?l000000ooo
oooo0000o`00000>ooooo`;o00005?ooool3o`0000Cooooo0_l000000ooooooo0000o`000008o`00
00Gooooo0_l0000?ooooo`Co00000_oooolIo`0000Gooooo0_l00007ooooo`;o00000_ooool2o`00
00Wooooo1?l0000Fooooo`?o0000<?ooool001cooooo00?o0000ooooooooool0?_ooool2o`0000[o
oooo7?l00005ooooo`;o00003Oooool2o`0000Cooooo0_l0000Aooooo`;o000000?oooooo`000?l0
00000_ooool3o`0000?ooooo2?l00005ooooo`;o00004?oooolPo`0000?ooooo1?l00007ooooo`;o
00003?ooool3o`0001Sooooo0_l0000aooooo`007?ooool00ol0003oooooooooo`1:oooooa_o0000
5Oooool2o`0001Oooooo0_l00003ooooo`Oo000000Coooooo`000?l0003ooooo1Ol00005ooooo`;o
00004?oooolPo`0000?ooooo0_l00009ooooo`;o00000oooool2o`0000Kooooo1?l0000Hooooo`;o
0000<Oooool001cooooo00?o0000ooooooooool0>_ooool2o`000003ooooool0003o000000_ooooo
3?l000000ooooooo0000o`000006o`000003ooooool0003o000000_ooooo0_l00002ooooo`?o0000
8oooool<o`0000Cooooo0ol000000ooooooo0000o`00000Booooob3o00003_ooool2o`0000?ooooo
0_l00006ooooo`?o00005oooool4o`00037ooooo000Looooo`03o`000?oooooooooo03[ooooo0_l0
00000ooooooo0000o`00000;oooooaWo00000_ooool4o`0000Cooooo1ol0000Sooooo`;o000000?o
ooooo`000?l000002?l00003ooooo`?o000000?oooooo`000?l000004ooooolLo`0000;ooooo1?l0
0008ooooo`;o00002?ooool2o`0000Cooooo0_l0000Hooooo`Co0000<Oooool001cooooo00?o0000
ooooooooool0B_oooolIo`0000;ooooo1?l00005ooooo`?o000000?oooooo`000?l000000_l0000Q
ooooo`Ko00000_ooool6o`0000;ooooo2Ol0000@oooooaco00000_ooool4o`0000?ooooo0_l00003
ooooo`;o00000oooool2o`0000?ooooo0_l00003ooooo`?o00006?ooool2o`0003?ooooo000Loooo
o`03o`000?oooooooooo04Wooooo4_l000000ooooooo0000o`000005o`00017ooooo0_l0000Moooo
o`;o00000oooool4o`0000;ooooo1ol00002ooooo`Wo00003ooooolMo`0000Wooooo0_l00008oooo
o`;o00000_ooool2o`0000Cooooo0_l0000Hooooo`?o0000<oooool001cooooo00?o0000oooooooo
ool0BOoooolHo`0001;ooooo0_l0000Nooooo`Co00000oooool;o`000003ooooool0003o000000;o
oooo0_l0000Cooooo`Ko000000?oooooo`000?l000005?l00002ooooo`;o00003oooool2o`0000;o
oooo0_l00003ooooo`?o00006?ooool3o`0003?ooooo000Looooo`;o0000Boooool2o`000003oooo
ool0003o000001;o00004Oooool3o`0001oooooo4Ol000000ooooooo0000o`000002o`0001Gooooo
0ol000000ooooooo0000o`00000Fo`0000?ooooo0_l0000?ooooo`;o00001oooool2o`0004oooooo
000Looooo`03o`000?oooooooooo04[ooooo0_l000000ooooooo0000o`00000Bo`00017ooooo0_l0
000Poooooa7o00000oooool2o`0001Gooooo7?l00002ooooo`;o00004?ooool2o`0000Kooooo0_l0
000Jooooo`;o0000=?ooool001cooooo00?o0000ooooooooool0>_ooool2o`0000oooooo5_l0000=
ooooo`;o000000?oooooo`000?l000008Oooool@o`0000Cooooo0ol0000Doooooa[o00001?ooool2
o`00013ooooo0_l00005ooooo`?o00006_ooool2o`0003Cooooo000Looooo`03o`000?oooooooooo
03Wooooo0ol0000?oooooa;o00000_ooool2o`0000gooooo0_l000000ooooooo0000o`00000Poooo
oa7o000000Coooooo`000?l0003ooooo1?l0000Cooooo`So000000?oooooo`000?l000003ol0000F
ooooo`?o00001?ooool4o`0004oooooo000Looooo`03o`000?oooooooooo03Wooooo0_l000000ooo
oooo0000o`000003ooooo`;o00002?ooool5o`000003ooooool0003o000000?o000000?oooooo`00
0?l000001_l0000coooooaKo00000_ooool2o`0001?ooooo1?l000000ooooooo0000o`00000Bo`00
00Oooooo0_l0000?ooooo`;o00000oooool2o`000003ooooool0003o000001Cooooo1?l0000goooo
o`007?ooool00ol0003oooooooooo`0looooo`;o00000oooool2o`0000Sooooo0_l00007ooooo`;o
00001?ooool5o`00013ooooo0_l0000Qoooooa?o000000Coooooo`000?l0003o00000_ooool2o`00
01?ooooo2?l000000ooooooo0000o`00000;o`0000Wooooo0_l0000Dooooo`;o00005oooool4o`00
03Oooooo000Looooo`03o`000?oooooooooo04gooooo0_l00003ooooo`Co00000oooool4o`0001;o
oooo0_l0000Poooooa?o00000oooool6o`0001;ooooo5_l0000<ooooo`;o00004Oooool2o`0001So
oooo0_l0000iooooo`007?ooool00ol0003oooooooooo`1<ooooo`Co00000_ooool2o`0000Gooooo
0_l0000>ooooo`?o00009?oooolDo`0000Cooooo0ol0000DoooooaGo00000_ooool4o`0000;ooooo
0_l00003ooooo`;o00004Oooool2o`0001Sooooo0_l0000iooooo`007?ooool00ol0003ooooooooo
o`0hooooo`;o00001?ooool2o`0000cooooo1?l000001?oooooo0000o`000?l00003ooooo`;o0000
00?oooooo`000?l000003Oooool3o`0002Cooooo5Ol000001?oooooo0000o`000?ooool2o`0001Go
oooo3?l000000ooooooo0000o`000004o`0000?ooooo1Ol000000ooooooo0000o`00000?ooooo`;o
00007?ooool5o`0003Wooooo000Looooo`03o`000?oooooooooo03Sooooo0_l00004ooooo`;o0000
3_ooool5o`0000Cooooo0_l000000ooooooo0000o`000004o`0000Kooooo0_l0000XoooooaSo0000
6?oooolAo`0000Sooooo0_l0000Booooo`;o00007?ooool5o`0003Wooooo000Looooo`03o`000?oo
oooooooo053ooooo1?l00002ooooo`;o000000?oooooo`000?l000002Ol00002ooooo`;o00009ooo
oolHo`0001[ooooo1_l000000ooooooo0000o`000007o`000003ooooool0003o000007Gooooo000L
ooooo`03o`000?oooooooooo057ooooo1?l000001?oooooo0000o`000?ooool2o`0000Gooooo1?l0
000[oooooaGo00000_ooool3o`0001Sooooo1_l000000ooooooo0000o`000006o`0000;ooooo0_l0
0004ooooo`;o00005?ooool2o`0001[ooooo1?l0000kooooo`007?ooool00ol0003oooooooooo`0h
ooooo`;o00006Oooool2o`0003[ooooo5Ol00002ooooo`?o00006Oooool6o`000003ooooool0003o
000000?o00000_ooool2o`0000Kooooo0_l00009ooooo`;o00001Oooool3o`000003ooooool0003o
000001Kooooo0_l000000ooooooo0000o`000003o`0003_ooooo000Looooo`03o`000?oooooooooo
03Sooooo0_l0001Eoooooa;o000000?oooooo`000?l000007_ooool8o`0000;ooooo0_l00002oooo
o`;o00001Oooool4o`0000Sooooo0_l00005ooooo`?o00006Oooool2o`000003ooooool0003o0000
03kooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o
0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0hooooo`;o0000EOoooolAo`0000;ooooo0_l0
000Oooooo`So000000Coooooo`000?l0003o00000oooool2o`0000?ooooo1?l00002ooooo`Go0000
0oooool2o`0000[ooooo0_l0000Cooooo`Co0000?oooool00006oooooomgMgOoV9RHoooooonHV9So
MgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo
03Sooooo0_l0001Foooooa3o00008oooool=o`0000;ooooo0_l00005ooooo`;o00000_ooool5o`00
00?ooooo0_l00005ooooo`;o00000oooool2o`0001Gooooo0ol0000nooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`0hooooo`?o0000EOooool?o`0002Cooooo1?l000000ooooooo0000o`000003o`00
0004ooooool0003o0000o`0000Oooooo0ol0000Aooooo`;o00006oooool3o`0003gooooo00000ooo
oooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@06
ooooo`?o0000>Oooool2o`0005Gooooo3ol0000Fooooo`;o00003_ooool7o`0000;ooooo0ol00007
ooooo`?o00000_ooool2o`0002?ooooo0ol00004ooooo`?o000000?oooooo`000?l00000>_ooool0
0003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oEEEEo`000?l@413o
c<c<00Kooooo00?o0000ooooooooool0S_ooool;o`000004ooooool0003o0000ooooo`;o00005?oo
ool4o`0000kooooo1Ol0000>ooooo`?o00000_ooool4o`0000?ooooo0_l0000Jooooo`Go00001?oo
ool2o`0000;ooooo0ol0000iooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09
ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0>?ooool2o`0005;ooooo4?l00003
ooooo`;o00004_ooool2o`00017ooooo1Ol0000=ooooo`Co00000oooool2o`0000?ooooo0_l00005
ooooo`;o00004oooool2o`0000Sooooo0_l000001?oooooo0000o`000?l0000iooooo`0000Kooooo
ogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0
>?ooool2o`0005;ooooo0_l00004ooooo`Wo00000_ooool4o`0001;ooooo0ol00002ooooo`;o0000
3Oooool5o`000004ooooool0003o0000ooooo`;o00002?ooool4o`0000Gooooo0_l000001?oooooo
0000o`000?ooool4o`00017ooooo0_l0000:ooooo`Go0000>_ooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo03Wooooo0_l0
0017ooooo`;o00001?ooool2o`0000Oooooo2?l00004ooooo`;o00005Oooool2o`0000;ooooo0_l0
000>ooooo`Oo000000?oooooo`000?l000001_ooool2o`0000;ooooo0_l00005ooooo`;o000000Co
ooooo`000?l0003ooooo0_l0000Cooooo`;o00002oooool2o`0003cooooo000Looooo`03o`000?oo
oooooooo03Wooooo0_l00017ooooo`;o000000Coooooo`000?l0003ooooo0_l00007ooooo`So0000
<?ooool;o`0000?ooooo0ol000000ooooooo0000o`000009ooooo`?o0000H?ooool001cooooo00?o
0000ooooooooool0>Oooool4o`0004;ooooo0_l00003ooooo`?o000000Coooooo`000?l0003ooooo
0_l00004ooooo`Co0000=?ooool;o`0000?ooooo0ol000000ooooooo0000o`000004ooooo`;o0000
0oooool3o`0001Sooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`0kooooo`;o0000@Ooo
ool4o`0000;ooooo1_l000001?oooooo0000o`000?l00005ooooo`Co00000oooool2o`00027ooooo
0_l0000<ooooo`[o00003?ooool3o`0001Sooooo0_l00003ooooo`;o0000A_ooool001cooooo00?o
0000ooooooooool0OOooool5o`0000;ooooo1_l00002ooooo`;o00000_ooool2o`000003ooooool0
003o000000;o00000_ooool3o`00027ooooo0_l0000>ooooo`So00002_ooool2o`000004ooooool0
003o0000o`0001Oooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`1iooooo`;o00000_oo
ool2o`0000?ooooo2Ol00005ooooo`_o0000=Oooool7o`0000;ooooo0_l00004ooooo`;o00000_oo
ool2o`0002?ooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`1gooooo`Co00000oooool=
o`0000Oooooo1ol0000hooooo`_o0000;?ooool3o`0003kooooo000Looooo`03o`000?oooooooooo
07Oooooo0_l00005ooooo`ko0000<?ooool2o`0001Gooooo2Ol0000Looooo`;o00000oooool2o`00
00[ooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0kooooo`?o0000?OoooolBo`0002oo
oooo0_l0000Jooooo`;o00007_ooool2o`0000?ooooo0_l00007ooooo`;o0000@Oooool001cooooo
00?o0000ooooooooool0>oooool3o`0003Kooooo0_l00004oooooa?o00001Oooool3o`0006;ooooo
0ol00008ooooo`;o00000_ooool2o`00047ooooo000Looooo`03o`000?oooooooooo07Cooooo0_l0
0004oooooaCo00001?ooool3o`0006;ooooo0_l000000ooooooo0000o`000006ooooo`;o0000AOoo
ool001cooooo00?o0000ooooooooool0NOoooolEo`000003ooooool0003o0000033ooooo0_l0000g
ooooo`;o00001?ooool2o`0004Oooooo000Looooo`;o0000@_ooool2o`0003Kooooo5?l00002oooo
o`;o0000<?ooool2o`00037ooooo0_l00002ooooo`;o00001_ooool3o`0004Kooooo000Looooo`03
o`000?oooooooooo03kooooo0_l000000ooooooo0000o`00000eoooooaGo00001_ooool2o`0002oo
oooo0_l0000^ooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o0000A_ooool001cooooo
00?o0000ooooooooool0?_ooool2o`0000;ooooo0_l0000_ooooo`;o00000ooooolEo`0000Kooooo
0_l0000]ooooo`Co0000=_ooool2o`0004_ooooo000Looooo`03o`000?oooooooooo043ooooo1?l0
000_ooooo`;o00001?oooolCo`0000Oooooo0_l0000Sooooo`?o00001oooool2o`0003?ooooo1?l0
001>ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o0000<Oooool2o`0000Cooooo4ol00007
ooooo`;o00008oooool4o`0000Kooooo1?l0000aooooo`Oo0000Boooool001cooooo00?o0000oooo
ooooool0@?ooool2o`0000?ooooo0ol0000boooooa;o00001_ooool3o`0002Gooooo0_l000001?oo
oooo0000o`000?l00004ooooo`;o0000;Oooool2o`0000Cooooo1Ol00004ooooo`;o0000AOooool0
01cooooo00?o0000ooooooooool0AOooool3o`0003;ooooo3ol000000ooooooo0000o`000006oooo
o`;o0000:Oooool3o`0000Cooooo0_l0000]ooooo`;o00000_ooool4o`000003ooooool0003o0000
00;o00000_ooool2o`0004Gooooo000Looooo`03o`000?oooooooooo04Gooooo0_l0000_ooooo`;o
00000_oooolAo`0000;ooooo0_l00005ooooo`;o00005oooool2o`0000oooooo1?l00005ooooo`Co
0000;?ooool2o`0000?ooooo1?l00019ooooo`007?ooool00ol0003oooooooooo`1fooooo`;o0000
0_oooolAo`0000;ooooo0_l00005ooooo`Co00005Oooool2o`00013ooooo0ol00002ooooo`;o0000
00?oooooo`000?l000000ol0000_ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0Mooo
ool2o`0000;ooooo4?l00008ooooo`Go00000_ooool2o`0001Kooooo0_l0000;ooooo`;o00000ooo
ool2o`0000;ooooo1?l0000_ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0AOooool2
o`0002kooooo1Ol000001?oooooo0000o`000?ooool=o`000003ooooool0003o000000Gooooo1?l0
0003ooooo`;o00000_ooool4o`0000Cooooo0_l0000:ooooo`;o00003?ooool2o`000003ooooool0
003o000000?ooooo0_l0001oooooo`007?ooool00ol0003oooooooooo`15ooooo`;o0000;_ooool2
o`000004ooooool0003o0000oooooa?o00001oooool2o`0000Oooooo1?l00004ooooo`?o00005ooo
ool2o`000003ooooool0003o000000Cooooo0_l0000Rooooo`;o00003?ooool2o`0004cooooo000L
ooooo`03o`000?oooooooooo07Sooooo4?l00003ooooo`;o00001?ooool2o`0000Cooooo0_l00007
ooooo`;o00001Oooool2o`0000?ooooo0ol0000Aooooo`?o00001_ooool2o`0002;ooooo0_l00000
0ooooooo0000o`000009ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0B?ooool3o`00
00?ooooo0_l0000Sooooo`;o00001?ooool=o`0000_ooooo0_l00004ooooo`;o00001_ooool3o`00
0003ooooool0003o000000;o00001Oooool5o`00013ooooo0_l00005ooooo`?o00008_ooool2o`00
0004ooooool0003o0000ooooo`;o0000E?ooool001cooooo00?o0000ooooooooool0B?ooool3o`00
00?ooooo0_l00002ooooo`;o00007oooool2o`0000?ooooo2ol00006ooooo`;o00003Oooool3o`00
00Cooooo0_l00002ooooo`Ko00001_ooool3o`0000oooooo0_l00005ooooo`;o00008?ooool2o`00
00Kooooo0ol0001Dooooo`007?ooool00ol0003oooooooooo`1Booooo`;o000000Coooooo`000?l0
003o00007_ooool6o`0000;ooooo0_l00004ooooo`;o00000_ooool5o`0000_ooooo0ol0000:oooo
o`Co00001oooool2o`0000oooooo0_l00005ooooo`;o00007oooool5o`0000Cooooo0ol00002oooo
o`;o0000D?ooool001cooooo0_l0001?ooooo`;o00001Oooool3o`0000Cooooo0_l0000Hooooo`;o
000000?oooooo`000?l000001oooool4o`0000;ooooo0_l000000ooooooo0000o`00000;ooooo`;o
00000_ooool2o`0000Oooooo0_l00009ooooo`?o00002_ooool2o`0000Oooooo0ol0000Oooooo`?o
000000?oooooo`000?l000001Oooool3o`000003ooooool0003o0000053ooooo000Looooo`03o`00
0?oooooooooo04kooooo0_l0000:ooooo`Co00006oooool4o`0000?ooooo1?l00004ooooo`;o0000
2oooool2o`000003ooooool0003o000000Co00001Oooool4o`0000[ooooo0ol00008ooooo`Oo0000
0_ooool4o`0001oooooo0_l0000:ooooo`;o000000?oooooo`000?l00000D?ooool001cooooo00?o
0000ooooooooool0C_ooool2o`0000[ooooo1?l0000Jooooo`;o000000Coooooo`000?l0003o0000
0_ooool3o`0000Gooooo0_l00009ooooo`Co00000oooool2o`0000Gooooo1?l0000<ooooo`?o0000
2?ooool7o`0000;ooooo0_l0000`ooooo`;o0000D?ooool001cooooo00?o0000ooooooooool0D?oo
ool2o`0000cooooo0_l00003ooooo`;o00003oooool2o`0000;ooooo0_l00002ooooo`;o00000_oo
ool3o`0000Oooooo0_l00003ooooo`;o00000_ooool2o`0000cooooo0ol00006ooooo`;o00001Ooo
ool3o`0000Sooooo1ol00026ooooo`007?ooool00ol0003oooooooooo`1@ooooo`Go00000_ooool2
o`0000Gooooo0_l00003ooooo`?o00003_ooool2o`000003ooooool0003o000000oooooo1?l00003
ooooo`Ko00004oooool5o`0000Cooooo0ol00006ooooo`?o000000?oooooo`000?l000000_l00002
ooooo`;o000000?oooooo`000?l000007?ooool2o`0000kooooo0_l0001Booooo`007?ooool00ol0
003oooooooooo`1Aooooo`Co00000_ooool2o`0000Gooooo0_l00004ooooo`;o00002?ooool2o`00
00Oooooo0_l0000<ooooo`;o000000?oooooo`000?l000000_l00004ooooo`Ko000000?oooooo`00
0?l000001_ooool2o`0000Gooooo2Ol000000ooooooo0000o`000002o`0000Kooooo2?l00002oooo
o`;o000000?oooooo`000?l000007?ooool2o`0000Oooooo0_l00005ooooo`;o0000D_ooool001co
oooo00?o0000ooooooooool0D_ooool3o`0000Gooooo0_l00002ooooo`;o00002?ooool2o`0000Co
oooo0_l0000=ooooo`Go00000oooool2o`000003ooooool0003o000000Cooooo1?l00002ooooo`;o
000000Coooooo`000?l0003o00000oooool4o`0000?ooooo3ol00007ooooo`Co0000;_ooool4o`00
05Wooooo000Looooo`03o`000?oooooooooo05?ooooo0_l000000ooooooo0000o`000002ooooo`;o
00000_ooool2o`0000Oooooo0ol0000@ooooo`;o000000?oooooo`000?l000001?l00003ooooo`Co
00001?ooool3o`0000?ooooo0_l00002ooooo`;o00000oooool3o`0000Cooooo1_l000000ooooooo
0000o`000006o`0000Kooooo1Ol000001?oooooo0000o`000?l0000Zooooo`;o0000Foooool001co
oooo00?o0000ooooooooool0E_ooool2o`000003ooooool0003o000000?ooooo0_l00006ooooo`Co
00004?ooool2o`0000Gooooo0_l00003ooooo`;o00002?ooool2o`0000;ooooo0ol000001Ooooooo
0000o`000?l0003ooooo00Co00000oooool5o`0000?ooooo1_l00007ooooo`Ko000000Coooooo`00
0?l0003o0000Qoooool001cooooo00?o0000ooooooooool0F?ooool3o`0000?ooooo0_l00002oooo
o`;o000000Coooooo`000?l0003o00009?ooool2o`0000;ooooo0_l00003ooooo`;o000000Gooooo
o`000?l0003o0000ooooo`04o`0000?ooooo1_l000000ooooooo0000o`000005o`0000Kooooo0ol0
0005ooooo`?o000000?oooooo`000?l00000:_ooool2o`0005Sooooo000Looooo`03o`000?oooooo
oooo05Sooooo0_l00008ooooo`Go00005?ooool2o`0000oooooo1?l0000=ooooo`;o00001?ooool:
o`000003ooooool0003o000000Oooooo0ol00003ooooo`Go000000?oooooo`000?l000008oooool2
o`0000Cooooo0ol0001Hooooo`007?ooool00ol0003oooooooooo`1Tooooo`;o00005Oooool2o`00
00kooooo1Ol0000=ooooo`;o00001?ooool4o`0000;ooooo1?l00009ooooo`;o00000oooool6o`00
02Oooooo0_l00004ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0G_ooool2o`0000Wo
oooo0_l00002ooooo`;o00007?ooool6o`0000cooooo0_l00006ooooo`;o000000?oooooo`000?l0
00000_l00009ooooo`?o000000?oooooo`000?l000000ol0002;ooooo`007?ooool00ol0003ooooo
ooooo`1Nooooo`;o00001oooool4o`0000;ooooo0_l00003ooooo`;o00006?ooool5o`0000Kooooo
0_l0000<ooooo`;o000000?oooooo`000?l000000ol00008ooooo`;o000000Coooooo`000?l0003o
0000S_ooool001cooooo00?o0000ooooooooool0I?ooool2o`000003ooooool0003o000000Wooooo
0_l0000Iooooo`Co00001Oooool3o`000004ooooool0003o0000o`0000;ooooo0_l00005ooooo`ko
00001?ooool2o`0002gooooo0_l00002ooooo`;o0000G?ooool001cooooo00?o0000ooooooooool0
I?ooool2o`0000Cooooo0_l00006ooooo`?o00006?ooool5o`0000Cooooo1ol000001?oooooo0000
o`000?l00005ooooo`Go000000?oooooo`000?l000002ol0000Zooooo`;o00000_ooool2o`000004
ooooool0003o0000o`0005cooooo000Looooo`;o0000IOooool2o`0000Cooooo0_l00006ooooo`Co
00006Oooool4o`0000Gooooo0_l00004ooooo`Co00002Oooool6o`000003ooooool0003o000000Go
0000:_ooool2o`000003ooooool0003o000000;ooooo0_l0001Mooooo`007?ooool00ol0003ooooo
ooooo`1Yooooo`;o00001oooool4o`0001Wooooo1Ol0000<ooooo`?o00002?ooool5o`0000;ooooo
1?l0000`ooooo`;o0000HOooool001cooooo00?o0000ooooooooool0Ioooool4o`0002Gooooo1?l0
0005ooooo`?o00001?ooool3o`0000_ooooo0_l00003ooooo`;o0000;?ooool2o`0000Cooooo0_l0
001Pooooo`007?ooool00ol0003oooooooooo`1Wooooo`?o00001?ooool3o`0001oooooo1ol00002
ooooo`?o00001_ooool2o`0003Oooooo0_l00002ooooo`Co00001?ooool2o`00063ooooo000Loooo
o`03o`000?oooooooooo06Oooooo0ol000001?oooooo0000o`000?ooool4o`0000oooooo0_l0000@
ooooo`Go00002_ooool2o`0003Oooooo0_l00002ooooo`;o0000J?ooool001cooooo00?o0000oooo
ooooool0J_ooool3o`0000?ooooo0_l0000?ooooo`;o000000?oooooo`000?l000001oooool2o`00
00Gooooo1?l00004ooooo`;o0000>oooool4o`0000?ooooo1?l0001Uooooo`007?ooool00ol0003o
ooooooooo`1Yooooo`?o00004_ooool2o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l0
00001Oooool6o`000004ooooool0003o0000o`0003_ooooo0_l00005ooooo`Co0000IOooool001co
oooo00?o0000ooooooooool0JOooool3o`0001;ooooo0_l0000:ooooo`;o00002?ooool9o`00017o
oooo0_l0000Zooooo`;o00001?ooool2o`0006Oooooo000Looooo`03o`000?oooooooooo06[ooooo
0ol00002ooooo`;o00002oooool2o`0001?ooooo0_l00003ooooo`Ko00002?ooool2o`0000?ooooo
0ol00002ooooo`;o0000:?ooool6o`000003ooooool0003o000006Sooooo000Looooo`03o`000?oo
oooooooo06_ooooo0_l000000ooooooo0000o`000003o`0000Wooooo0_l0000>ooooo`;o00000ooo
ool2o`0000Gooooo1?l00008ooooo`;o00000oooool3o`0000Kooooo0_l000000ooooooo0000o`00
000<ooooo`?o00004_ooool2o`000005ooooool0003o0000o`000?ooool00_l0001Xooooo`007?oo
ool00ol0003oooooooooo`1]ooooo`?o000000?oooooo`000?l000000oooool2o`0000Gooooo0_l0
000;ooooo`Co00000oooool2o`0000Gooooo0_l000000ooooooo0000o`000002o`000003ooooool0
003o0000013ooooo0_l000000ooooooo0000o`000007ooooo`;o000000?oooooo`000?l000000ol0
000>ooooo`;o00000oooool2o`0006kooooo000Looooo`03o`000?oooooooooo06gooooo0_l00007
ooooo`?o00001?ooool2o`0000?ooooo0_l00004ooooo`Co00000_ooool4o`0000Wooooo3?l00007
ooooo`Co00003?ooool5o`00013ooooo0ol00003ooooo`;o0000K_ooool001cooooo00?o0000oooo
ooooool0LOooool9o`0000Sooooo0_l00004ooooo`Co00000_ooool4o`0000_ooooo4?l000000ooo
oooo0000o`000003o`0000Oooooo0_l00003ooooo`;o00003_ooool2o`0000;ooooo0_l0001doooo
o`007?ooool00ol0003oooooooooo`1`ooooo`[o00004?ooool2o`0001Gooooo7_l0000@ooooo`;o
0000N?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q
8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo073ooooo1?l00002ooooo`;o00001_ooool2
o`0002Cooooo0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o000000go00004_ooool2
o`0000;ooooo0_l0001booooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?oo
ool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0M?ooool4o`0000Kooooo
0_l0000Kooooo`;o0000;_ooool2o`0000Cooooo0_l00002ooooo`;o0000L_ooool00003ooooool@
413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0Loooool3o`000003ooooool0003o000000Ko00000_ooool2o`0001Oooooo
0ol0000]ooooo`Go0000N_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Ooo
ool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0001cooooo`;o00000_ooool8o`0000;ooooo
0_l0000=ooooo`;o00001oooool4o`0002Oooooo0_l00004ooooo`;o000000?oooooo`000?l00000
N_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Oo<c<co0000o`00
0?l0003oc<c<00Kooooo00?o0000ooooooooool0M?ooool2o`0000Gooooo1?l0000Aooooo`;o0000
1oooool4o`0000?ooooo0_l0000Rooooo`;o00000oooool4o`0000;ooooo0_l0001hooooo`0000?o
oooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@4100
1_ooool00ol0003oooooooooo`1dooooo`;o00001?ooool4o`0000Kooooo0_l00005ooooo`;o0000
4oooool2o`0002Oooooo1?l00002ooooo`;o0000N?ooool00006oooooomgMgOoV9RHoooooonHV9So
MgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0N_ooool2o`00
00Sooooo0ol00004ooooo`;o00001oooool2o`0001;ooooo0_l00002ooooo`;o00001_ooool2o`00
00Kooooo0_l00005ooooo`;o0000Q?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool0
1OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0Moooool2o`0000;ooooo0_l0
0008ooooo`;o00000_ooool4o`0000Oooooo0_l000000ooooooo0000o`00000;ooooo`;o00000_oo
ool2o`0000;ooooo0_l00006ooooo`;o00001Oooool3o`000003ooooool0003o000000Co00001?oo
ool2o`0007kooooo000Looooo`03o`000?oooooooooo07Oooooo1_l00008ooooo`;o00000_ooool4
o`0000[ooooo0_l0000;ooooo`;o00001?ooool2o`0000;ooooo0ol0000:ooooo`;o00000_ooool5
o`0000Cooooo0ol0001nooooo`007?ooool00ol0003oooooooooo`1iooooo`Co00003Oooool2o`00
00oooooo0ol00002ooooo`;o00002?ooool2o`0000;ooooo0ol000000ooooooo0000o`00000Doooo
o`;o0000Ooooool001cooooo00?o0000ooooooooool0Noooool2o`0000cooooo0ol0000?ooooo`?o
00000_ooool2o`00013ooooo0_l0002Eooooo`007?ooool00ol0003oooooooooo`29ooooo`;o0000
1_ooool2o`0000oooooo0_l00005ooooo`;o00001oooool2o`000003ooooool0003o000009;ooooo
000Looooo`03o`000?oooooooooo08_ooooo0_l00004ooooo`;o00003oooool2o`0000Gooooo0_l0
00000ooooooo0000o`000004ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`000003oooo
ool0003o000008_ooooo000Looooo`03o`000?oooooooooo08?ooooo0_l00004ooooo`Ko00007Ooo
ool2o`0000Oooooo0ol000001?oooooo0000o`000?ooool2o`0008_ooooo000Looooo`03o`000?oo
oooooooo08?ooooo0_l00004ooooo`?o000000?oooooo`000?l000000_l0002hooooo`007?ooool0
0ol0003oooooooooo`26ooooo`?o000000?oooooo`000?l000000_ooool4o`000;Oooooo000Loooo
o`03o`000?oooooooooo08Gooooo1?l00007ooooo`;o00000_ooool2o`000;?ooooo000Looooo`03
o`000?oooooooooo08Gooooo0_l000000ooooooo0000o`00000:ooooo`?o0000/_ooool001cooooo
00?o0000ooooooooool0R?ooool2o`0000_ooooo0_l000001?oooooo0000o`000?l00003ooooo`;o
0000ZOooool001cooooo0_l0002Iooooo`Co00000_ooool3o`000:Sooooo000Looooo`03o`000?oo
oooooooo09[ooooo0_l00002ooooo`?o0000Z?ooool001cooooo00?o0000ooooooooool0W_ooool2
o`0000Sooooo0_l0002Oooooo`007?ooool00ol0003oooooooooo`2Xooooo`;o0000Woooool001co
oooo00?o0000ooooooooool0Z?ooool2o`0009oooooo000Looooo`03o`000?oooooooooo0:Sooooo
0_l0002Oooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2
o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooo
oom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool0
01Cooooo00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o0000oooooooo
ool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oo
oooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`004_ooool00omE
EEGoIVIVo`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002U
ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05Oooool5o`0000Gooooo0_l0
00002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP2@ooooo`00Y_ooool01Ol0003o
oooooooooooooooo000000Wooooo1_l00009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0T?ooool00:Kooooo00Go0000
ooooooooooooooooo`00000Iooooo`03oiRHV?lQ8B7ok^k^00Cooooo1Ol00003ooooo`05oa0@4?oo
ooooooooooooool@4100T?ooool00:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko0000
2oooool00onHV9So8B4Qonk^kP03ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000oooooooo
ooooooooo`00002@ooooo`00Y_ooool01Ol0003oQhN7oooooonYZJWo000001_ooooo00?oMgMgofIV
I_ooool00_ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool00000T?oo
ool00:Gooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Jooooo`03o`000?oooooo
oooo00;ooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@093ooooo0033
ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0T?ooool00<?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03ogMg
Mol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP2@ooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(246) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.61477 .33726 Mdot
.59027 .34226 Mdot
.29135 .52005 Mdot
.63085 .53749 Mdot
.36699 .62257 Mdot
.24707 .50341 Mdot
.38884 .33947 Mdot
.39017 .35107 Mdot
.30222 .46781 Mdot
.75546 .54739 Mdot
.4095 .34064 Mdot
.59715 .59422 Mdot
.37746 .34523 Mdot
.63863 .55886 Mdot
.49838 .69803 Mdot
.6622 .51705 Mdot
.59533 .31128 Mdot
.41324 .63755 Mdot
.65825 .51391 Mdot
.28599 .45596 Mdot
.49356 .5099 Mdot
.62812 .57004 Mdot
.59196 .38337 Mdot
.63904 .56166 Mdot
.61634 .52676 Mdot
.58114 .34044 Mdot
.61479 .33862 Mdot
.58532 .56557 Mdot
.6259 .53496 Mdot
.39572 .31087 Mdot
.60221 .6409 Mdot
.52427 .79735 Mdot
.44155 .59055 Mdot
.74684 .43577 Mdot
.38443 .30997 Mdot
.38143 .29163 Mdot
.26971 .51813 Mdot
.37903 .30746 Mdot
.40645 .36399 Mdot
.40321 .35038 Mdot
.40368 .3462 Mdot
.58002 .33629 Mdot
.36335 .31838 Mdot
.21742 .35317 Mdot
.64663 .56544 Mdot
.73768 .32981 Mdot
.32256 .49349 Mdot
.5983 .58158 Mdot
.58146 .37607 Mdot
.30973 .46614 Mdot
.41481 .73239 Mdot
.38474 .36162 Mdot
.47376 .56802 Mdot
.68304 .20476 Mdot
.38473 .3495 Mdot
.64094 .51131 Mdot
.2699 .47847 Mdot
.66821 .55763 Mdot
.63074 .59707 Mdot
.72787 .39415 Mdot
.66602 .54762 Mdot
.39764 .63288 Mdot
.56402 .29086 Mdot
.31793 .47293 Mdot
.30607 .47545 Mdot
.36696 .31394 Mdot
.58369 .30041 Mdot
.37422 .32087 Mdot
.62086 .54276 Mdot
.28426 .4618 Mdot
.61712 .53459 Mdot
.40953 .33895 Mdot
.61097 .33609 Mdot
.62004 .57338 Mdot
.52101 .32895 Mdot
.34876 .30488 Mdot
.39565 .66367 Mdot
.64252 .36978 Mdot
.30047 .44256 Mdot
.51731 .68053 Mdot
.62294 .57323 Mdot
.35089 .22175 Mdot
.48708 .74303 Mdot
.59895 .37303 Mdot
.68758 .53203 Mdot
.43944 .20907 Mdot
.59653 .55624 Mdot
.60089 .63664 Mdot
.57968 .58995 Mdot
.42865 .66716 Mdot
.26451 .47819 Mdot
.56743 .35363 Mdot
.63412 .57571 Mdot
.60981 .56007 Mdot
.76476 .5263 Mdot
.64016 .52381 Mdot
.58312 .57461 Mdot
.47196 .5918 Mdot
.38728 .36678 Mdot
.45356 .57891 Mdot
.34073 .42825 Mdot
.4669 .55898 Mdot
.61015 .53974 Mdot
.25848 .49702 Mdot
.55916 .29583 Mdot
.44602 .58041 Mdot
.38064 .31722 Mdot
.63447 .57261 Mdot
.34457 .38882 Mdot
.5861 .3788 Mdot
.61191 .52578 Mdot
.38469 .62579 Mdot
.46216 .48849 Mdot
.61211 .35283 Mdot
.80792 .44712 Mdot
.63408 .54191 Mdot
.65394 .58068 Mdot
.58914 .33859 Mdot
.26516 .46332 Mdot
.3026 .27926 Mdot
.60089 .32597 Mdot
.39475 .36487 Mdot
.58921 .30716 Mdot
.4465 .59743 Mdot
.27687 .45723 Mdot
.49625 .54955 Mdot
.50411 .56776 Mdot
.47905 .7853 Mdot
.64283 .53303 Mdot
.50203 .52409 Mdot
.25823 .50386 Mdot
.60182 .33086 Mdot
.37014 .34471 Mdot
.67205 .5774 Mdot
.58268 .35922 Mdot
.39203 .34215 Mdot
.38921 .65807 Mdot
.41703 .62183 Mdot
.60774 .36901 Mdot
.80807 .43471 Mdot
.35638 .3672 Mdot
.36458 .36369 Mdot
.41698 .73303 Mdot
.60047 .37228 Mdot
.3852 .64823 Mdot
.3817 .32202 Mdot
.20995 .64169 Mdot
.63229 .51062 Mdot
.43102 .75932 Mdot
.35436 .22456 Mdot
.41465 .73159 Mdot
.51172 .5142 Mdot
.38065 .63719 Mdot
.39241 .34225 Mdot
.61305 .58392 Mdot
.59919 .36229 Mdot
.58216 .35579 Mdot
.61267 .54176 Mdot
.45185 .56769 Mdot
.6476 .55073 Mdot
.45351 .58664 Mdot
.51072 .55704 Mdot
.6378 .57255 Mdot
.74175 .3019 Mdot
.58721 .37021 Mdot
.68666 .54409 Mdot
.27525 .51391 Mdot
.47053 .54265 Mdot
.36182 .32255 Mdot
.67135 .57219 Mdot
.67862 .50525 Mdot
.59701 .59679 Mdot
.36989 .37273 Mdot
.55256 .25274 Mdot
.30644 .44396 Mdot
.4059 .35591 Mdot
.33719 .41244 Mdot
.27487 .50184 Mdot
.61983 .59479 Mdot
.37559 .62972 Mdot
.46806 .57917 Mdot
.61162 .57517 Mdot
.41063 .7297 Mdot
.6325 .59615 Mdot
.53121 .50618 Mdot
.53861 .52333 Mdot
.40095 .22352 Mdot
.56543 .25474 Mdot
.62169 .5467 Mdot
.6458 .47966 Mdot
.42948 .74994 Mdot
.42232 .28923 Mdot
.36833 .34211 Mdot
.24276 .48416 Mdot
.25459 .47058 Mdot
.32439 .33985 Mdot
.78786 .45285 Mdot
.76617 .58116 Mdot
.67803 .55436 Mdot
.46761 .56336 Mdot
.62024 .32624 Mdot
.3822 .63805 Mdot
.60902 .35265 Mdot
.34456 .22156 Mdot
.5528 .67128 Mdot
.61877 .6561 Mdot
.20079 .47675 Mdot
.3133 .47943 Mdot
.47243 .55512 Mdot
.3766 .65152 Mdot
.6597 .55876 Mdot
.59164 .37808 Mdot
.42618 .74402 Mdot
.4601 .55683 Mdot
.70694 .76797 Mdot
.6011 .32166 Mdot
.55845 .72123 Mdot
.38369 .34694 Mdot
.29061 .48133 Mdot
.59882 .55228 Mdot
.62868 .55479 Mdot
.56984 .36703 Mdot
.61693 .58938 Mdot
.63807 .6638 Mdot
.62268 .51865 Mdot
.3031 .4548 Mdot
.34436 .45278 Mdot
.40043 .3688 Mdot
.20484 .47887 Mdot
.61281 .35355 Mdot
.74868 .28616 Mdot
.27215 .49026 Mdot
.53014 .5159 Mdot
.4083 .33215 Mdot
.39569 .65249 Mdot
.26537 .48922 Mdot
.37175 .61726 Mdot
.64715 .59617 Mdot
.28708 .50209 Mdot
.39344 .62646 Mdot
.63709 .63343 Mdot
.44708 .57876 Mdot
.4206 .79247 Mdot
.38915 .33155 Mdot
.5679 .32867 Mdot
.61192 .57869 Mdot
.46698 .57218 Mdot
.46079 .55516 Mdot
.53028 .71508 Mdot
.50129 .56458 Mdot
.47071 .55181 Mdot
.47689 .68414 Mdot
.40428 .64971 Mdot
.52335 .21077 Mdot
.5928 .63146 Mdot
.59722 .31223 Mdot
.6092 .5655 Mdot
.33324 .3933 Mdot
.39356 .33879 Mdot
.66188 .55444 Mdot
.38624 .22352 Mdot
.38048 .32521 Mdot
.66088 .57171 Mdot
.41183 .34791 Mdot
.58881 .36637 Mdot
.56701 .6869 Mdot
.60699 .32141 Mdot
.6404 .57496 Mdot
.41166 .34282 Mdot
.24017 .48911 Mdot
.58117 .34267 Mdot
.6315 .57227 Mdot
.66019 .53884 Mdot
.47065 .56399 Mdot
.6273 .51472 Mdot
.39068 .2757 Mdot
.59426 .57718 Mdot
.26981 .52985 Mdot
.63493 .52756 Mdot
.41431 .59921 Mdot
.29211 .6821 Mdot
.60519 .37235 Mdot
.50089 .56368 Mdot
.26656 .48376 Mdot
.64581 .65187 Mdot
.56777 .71977 Mdot
.64432 .56412 Mdot
.49412 .55474 Mdot
.53052 .76021 Mdot
.36474 .3571 Mdot
.57811 .58834 Mdot
.44606 .6302 Mdot
.26001 .48227 Mdot
.46874 .55936 Mdot
.68242 .52776 Mdot
.61627 .38898 Mdot
.65444 .51439 Mdot
.28585 .4969 Mdot
.59214 .31278 Mdot
.63836 .52025 Mdot
.38444 .28617 Mdot
.49065 .53943 Mdot
.37093 .36817 Mdot
.58146 .61049 Mdot
.61583 .5932 Mdot
.28803 .46114 Mdot
.57747 .33599 Mdot
.38685 .35105 Mdot
.61308 .3479 Mdot
.42468 .70637 Mdot
.5457 .7382 Mdot
.5349 .3109 Mdot
.3825 .66279 Mdot
.24339 .69041 Mdot
.39966 .36168 Mdot
.46806 .586 Mdot
.27332 .53436 Mdot
.62829 .38566 Mdot
.25708 .49359 Mdot
.80335 .42204 Mdot
.26765 .47726 Mdot
.65401 .50745 Mdot
.25184 .47888 Mdot
.78513 .55493 Mdot
.65433 .58737 Mdot
.30793 .48306 Mdot
.47476 .59105 Mdot
.66728 .57422 Mdot
.58131 .35799 Mdot
.55177 .80148 Mdot
.77031 .45021 Mdot
.7879 .45965 Mdot
.27388 .47922 Mdot
.80157 .41179 Mdot
.61244 .52632 Mdot
.57857 .60001 Mdot
.59699 .35775 Mdot
.46674 .58527 Mdot
.4081 .61322 Mdot
.40117 .60703 Mdot
.33183 .71535 Mdot
.58901 .73492 Mdot
.80556 .45829 Mdot
.58414 .35506 Mdot
.33564 .44964 Mdot
.52215 .32739 Mdot
.46291 .55487 Mdot
.39041 .35105 Mdot
.54175 .25371 Mdot
.58511 .59413 Mdot
.52665 .55061 Mdot
.64029 .66361 Mdot
.57123 .32485 Mdot
.54346 .30585 Mdot
.38826 .35081 Mdot
.78928 .46207 Mdot
.75255 .55446 Mdot
.65053 .5509 Mdot
.39717 .34226 Mdot
.45955 .55658 Mdot
.60383 .63518 Mdot
.48 .79111 Mdot
.17084 .44697 Mdot
.64491 .57098 Mdot
.51487 .29088 Mdot
.61265 .57753 Mdot
.4682 .78108 Mdot
.66069 .56169 Mdot
.57524 .34168 Mdot
.58827 .55251 Mdot
.59866 .62853 Mdot
.1716 .5668 Mdot
.54612 .66855 Mdot
.3707 .62213 Mdot
.63538 .56068 Mdot
.64298 .54696 Mdot
.39423 .64708 Mdot
.569 .34336 Mdot
.6031 .56453 Mdot
.53728 .21263 Mdot
.63149 .57603 Mdot
.36152 .32612 Mdot
.50478 .71904 Mdot
.52049 .79532 Mdot
.61203 .52781 Mdot
.61652 .38924 Mdot
.36653 .36582 Mdot
.40225 .32381 Mdot
.49165 .57232 Mdot
.39386 .33747 Mdot
.62085 .58713 Mdot
.50603 .71971 Mdot
.57866 .29852 Mdot
.45649 .56399 Mdot
.57075 .33034 Mdot
.26876 .55394 Mdot
.38822 .33373 Mdot
.48448 .56099 Mdot
.78265 .43972 Mdot
.37445 .3299 Mdot
.36064 .50944 Mdot
.60042 .53778 Mdot
.46263 .55407 Mdot
.61843 .35936 Mdot
.28101 .46339 Mdot
.48389 .54862 Mdot
.38563 .34955 Mdot
.6461 .56421 Mdot
.63594 .51218 Mdot
.39456 .33735 Mdot
.65722 .33652 Mdot
.60066 .64013 Mdot
.63384 .57887 Mdot
.57807 .35951 Mdot
.59538 .32748 Mdot
.6823 .55625 Mdot
.60874 .57588 Mdot
.24499 .50331 Mdot
.49512 .55514 Mdot
.49552 .55376 Mdot
.5056 .564 Mdot
.28232 .47829 Mdot
.21575 .6646 Mdot
.35761 .3482 Mdot
.52399 .79581 Mdot
.48263 .3197 Mdot
.4721 .5716 Mdot
.24551 .51049 Mdot
.6314 .5478 Mdot
.59615 .56371 Mdot
.4114 .32992 Mdot
.32696 .77058 Mdot
.58838 .60356 Mdot
.60404 .31988 Mdot
.39417 .35141 Mdot
.68213 .50343 Mdot
.32366 .36932 Mdot
.39817 .61544 Mdot
.80746 .45366 Mdot
.39129 .35525 Mdot
.55528 .32719 Mdot
.39061 .35632 Mdot
.64338 .54812 Mdot
.68287 .53069 Mdot
.57555 .31911 Mdot
.36542 .62855 Mdot
.61037 .54717 Mdot
.65924 .57121 Mdot
.32438 .42445 Mdot
.52117 .33848 Mdot
.38781 .6051 Mdot
.59745 .57164 Mdot
.45712 .59357 Mdot
.36048 .63806 Mdot
.63226 .58466 Mdot
.62795 .52916 Mdot
.50622 .52254 Mdot
.39508 .30279 Mdot
.36776 .66275 Mdot
.17204 .58659 Mdot
.60298 .32297 Mdot
.39946 .27558 Mdot
.48454 .54398 Mdot
.40095 .3598 Mdot
.66156 .66063 Mdot
.48111 .5561 Mdot
.48492 .30029 Mdot
.88149 .52977 Mdot
.48361 .55038 Mdot
.24806 .51897 Mdot
.7672 .51604 Mdot
.62443 .53256 Mdot
.63519 .5795 Mdot
.40991 .61571 Mdot
.59654 .33756 Mdot
.56392 .25497 Mdot
.40647 .3566 Mdot
.62034 .55919 Mdot
.61411 .36061 Mdot
.41219 .21753 Mdot
.47404 .56007 Mdot
.38212 .6194 Mdot
.37175 .66081 Mdot
.62235 .58233 Mdot
.55192 .74975 Mdot
.58045 .34512 Mdot
.63175 .57219 Mdot
.64621 .58603 Mdot
.23617 .50069 Mdot
.60048 .37523 Mdot
.28406 .50351 Mdot
.57872 .6067 Mdot
.80421 .53314 Mdot
.3383 .40962 Mdot
.38398 .32521 Mdot
.49454 .56462 Mdot
.39924 .37045 Mdot
.31582 .50229 Mdot
.49571 .55522 Mdot
.6314 .57111 Mdot
.57613 .29797 Mdot
.63233 .57297 Mdot
.63226 .57615 Mdot
.65048 .56351 Mdot
.80686 .4585 Mdot
.3023 .44186 Mdot
.37705 .62406 Mdot
.6025 .58864 Mdot
.28748 .48971 Mdot
.31951 .36095 Mdot
.75805 .54105 Mdot
.63065 .56012 Mdot
.65508 .57917 Mdot
.62143 .37879 Mdot
.6354 .50873 Mdot
.37771 .33042 Mdot
.57219 .32182 Mdot
.61243 .53621 Mdot
.30154 .43347 Mdot
.60172 .56947 Mdot
.53877 .30696 Mdot
.36191 .33327 Mdot
.71656 .52613 Mdot
.45055 .56279 Mdot
.49793 .55788 Mdot
.48228 .54925 Mdot
.50621 .56135 Mdot
.36347 .32023 Mdot
.25043 .51895 Mdot
.19598 .49185 Mdot
.6063 .61021 Mdot
.61249 .58502 Mdot
.68391 .53057 Mdot
.24061 .52352 Mdot
.47012 .59376 Mdot
.79432 .42459 Mdot
.68135 .50036 Mdot
.29278 .47516 Mdot
.49087 .58095 Mdot
.62846 .41061 Mdot
.56817 .33209 Mdot
.31906 .46265 Mdot
.40044 .31761 Mdot
.39567 .62359 Mdot
.36755 .75273 Mdot
.58798 .32187 Mdot
.62747 .33903 Mdot
.26605 .51209 Mdot
.51722 .73027 Mdot
.67761 .19634 Mdot
.25188 .49859 Mdot
.62539 .65836 Mdot
.59291 .36037 Mdot
.44798 .59004 Mdot
.52384 .7602 Mdot
.5065 .72743 Mdot
.30181 .47535 Mdot
.65846 .53782 Mdot
.23322 .54299 Mdot
.24309 .49931 Mdot
.48031 .57702 Mdot
.27551 .47967 Mdot
.36684 .36271 Mdot
.26208 .5015 Mdot
.59564 .39146 Mdot
.63669 .535 Mdot
.68088 .20203 Mdot
.46766 .71823 Mdot
.62622 .54468 Mdot
.36773 .35762 Mdot
.39961 .28527 Mdot
.65526 .55022 Mdot
.39669 .6095 Mdot
.24941 .51999 Mdot
.34114 .51519 Mdot
.65355 .51095 Mdot
.25592 .47606 Mdot
.62061 .38881 Mdot
.34402 .47478 Mdot
.34037 .42669 Mdot
.48725 .54912 Mdot
.59218 .36815 Mdot
.34541 .30963 Mdot
.39344 .36583 Mdot
.49448 .5383 Mdot
.63479 .59229 Mdot
.58208 .36975 Mdot
.64445 .64307 Mdot
.54235 .54502 Mdot
.63013 .57502 Mdot
.27971 .50524 Mdot
.31001 .46279 Mdot
.49411 .70198 Mdot
.27455 .48934 Mdot
.48191 .57696 Mdot
.58206 .36546 Mdot
.65671 .51255 Mdot
.5991 .32702 Mdot
.60818 .56666 Mdot
.32785 .37534 Mdot
.56543 .34717 Mdot
.53046 .51611 Mdot
.67197 .54816 Mdot
.74041 .3088 Mdot
.59881 .58873 Mdot
.63248 .57846 Mdot
.29655 .45591 Mdot
.39093 .64891 Mdot
.53564 .54745 Mdot
.32203 .3546 Mdot
.40211 .62762 Mdot
.65284 .3645 Mdot
.26751 .46166 Mdot
.39422 .65228 Mdot
.33636 .72658 Mdot
.50132 .56193 Mdot
.36548 .65119 Mdot
.68744 .53577 Mdot
.38726 .32535 Mdot
.56787 .30094 Mdot
.66822 .57367 Mdot
.7984 .53479 Mdot
.59722 .63845 Mdot
.47448 .56316 Mdot
.63725 .58142 Mdot
.63829 .54398 Mdot
.61418 .35872 Mdot
.34516 .22335 Mdot
.30266 .5139 Mdot
.45691 .58378 Mdot
.5939 .32077 Mdot
.35318 .22189 Mdot
.30626 .48279 Mdot
.41157 .63203 Mdot
.40257 .37061 Mdot
.54626 .32295 Mdot
.47169 .56722 Mdot
.38996 .33589 Mdot
.22357 .52454 Mdot
.40995 .72524 Mdot
.65304 .51518 Mdot
.25922 .51822 Mdot
.41383 .73108 Mdot
.59706 .54113 Mdot
.3246 .33456 Mdot
.42937 .29665 Mdot
.57939 .37277 Mdot
.39533 .33916 Mdot
.37758 .61931 Mdot
.59833 .30914 Mdot
.57003 .33134 Mdot
.37791 .32398 Mdot
.79563 .35987 Mdot
.53128 .75893 Mdot
.41025 .3619 Mdot
.52821 .70752 Mdot
.41351 .72863 Mdot
.46863 .56747 Mdot
.3779 .62612 Mdot
.34427 .45175 Mdot
.58041 .33654 Mdot
.53698 .26034 Mdot
.41405 .73287 Mdot
.59138 .55125 Mdot
.39566 .62711 Mdot
.41581 .21956 Mdot
.35192 .37304 Mdot
.38257 .33145 Mdot
.32569 .4238 Mdot
.39977 .63495 Mdot
.67378 .56947 Mdot
.34843 .79811 Mdot
.65137 .58814 Mdot
.38312 .32133 Mdot
.63946 .66365 Mdot
.60664 .34952 Mdot
.35898 .34318 Mdot
.63731 .66454 Mdot
.59644 .57152 Mdot
.63919 .53946 Mdot
.29842 .44109 Mdot
.56532 .35876 Mdot
.47649 .54419 Mdot
.62323 .54712 Mdot
.66514 .5653 Mdot
.44501 .57398 Mdot
.51317 .79309 Mdot
.47687 .47749 Mdot
.44299 .58755 Mdot
.2967 .48916 Mdot
.45366 .56701 Mdot
.45923 .58379 Mdot
.61838 .37473 Mdot
.33577 .43196 Mdot
.47024 .54899 Mdot
.64395 .57468 Mdot
.63813 .5767 Mdot
.40536 .36737 Mdot
.52957 .76018 Mdot
.51293 .73167 Mdot
.28199 .52792 Mdot
.43152 .62882 Mdot
.65847 .5324 Mdot
.59507 .37089 Mdot
.35095 .64428 Mdot
.48722 .57625 Mdot
.60112 .31851 Mdot
.63296 .5339 Mdot
.23553 .5029 Mdot
.48654 .55191 Mdot
.43795 .59697 Mdot
.39069 .62992 Mdot
.39149 .37702 Mdot
.64986 .35575 Mdot
.24322 .50539 Mdot
.61692 .52712 Mdot
.43716 .62946 Mdot
.25576 .47971 Mdot
.46728 .56701 Mdot
.45109 .57257 Mdot
.58736 .3637 Mdot
.55497 .33865 Mdot
.45539 .5996 Mdot
.28456 .48156 Mdot
.18183 .40989 Mdot
.39151 .36138 Mdot
.61114 .59162 Mdot
.3871 .37454 Mdot
.58874 .38077 Mdot
.47756 .78583 Mdot
.38344 .65839 Mdot
.37944 .32832 Mdot
.46126 .55666 Mdot
.56691 .33805 Mdot
.58495 .38115 Mdot
.63926 .57209 Mdot
.62897 .56666 Mdot
.3272 .47178 Mdot
.43248 .75653 Mdot
.41244 .33411 Mdot
.40959 .62241 Mdot
.29209 .52117 Mdot
.6464 .51042 Mdot
.60383 .36304 Mdot
.46071 .81834 Mdot
.61053 .5926 Mdot
.286 .48761 Mdot
.58945 .34464 Mdot
.40751 .61461 Mdot
.37438 .62577 Mdot
.61427 .56064 Mdot
.51302 .51482 Mdot
.37383 .32748 Mdot
.57893 .35346 Mdot
.60564 .28542 Mdot
.5977 .58494 Mdot
.63194 .56284 Mdot
.60145 .53573 Mdot
.4086 .36668 Mdot
.68437 .54999 Mdot
.36633 .6281 Mdot
.61025 .36046 Mdot
.61731 .5588 Mdot
.39785 .63809 Mdot
.50041 .54658 Mdot
.4845 .55502 Mdot
.30587 .46706 Mdot
.39869 .60841 Mdot
.39154 .6439 Mdot
.4042 .62668 Mdot
.5412 .25371 Mdot
.69256 .55199 Mdot
.47902 .59653 Mdot
.66081 .5384 Mdot
.41341 .72746 Mdot
.66489 .52152 Mdot
.3782 .36575 Mdot
.29048 .46125 Mdot
.65087 .55795 Mdot
.66386 .54049 Mdot
.64472 .37231 Mdot
.66266 .51356 Mdot
.68114 .55834 Mdot
.60742 .35428 Mdot
.61621 .29616 Mdot
.24948 .47544 Mdot
.3573 .22489 Mdot
.40314 .83521 Mdot
.66199 .58812 Mdot
.51454 .72693 Mdot
.56792 .34525 Mdot
.40392 .36925 Mdot
.52849 .71723 Mdot
.37806 .37802 Mdot
.59305 .33052 Mdot
.65846 .50744 Mdot
.64999 .30835 Mdot
.40037 .62836 Mdot
.64436 .54994 Mdot
.3701 .32805 Mdot
.64603 .55025 Mdot
.36054 .34649 Mdot
.7911 .39742 Mdot
.49949 .75331 Mdot
.64537 .59348 Mdot
.63899 .52439 Mdot
.48419 .51216 Mdot
.6299 .56294 Mdot
.1884 .49425 Mdot
.59237 .34995 Mdot
.48539 .53825 Mdot
.66034 .50578 Mdot
.76979 .45401 Mdot
.64414 .58282 Mdot
.67775 .66142 Mdot
.66676 .5702 Mdot
.31209 .75098 Mdot
.64472 .59624 Mdot
.63913 .59201 Mdot
.36894 .3505 Mdot
.40764 .3479 Mdot
.62348 .39091 Mdot
.46074 .56177 Mdot
.40762 .22113 Mdot
.65746 .5743 Mdot
.31073 .49755 Mdot
.56207 .50879 Mdot
.39292 .64483 Mdot
.61084 .34763 Mdot
.9016 .49498 Mdot
.3606 .32189 Mdot
.28918 .50474 Mdot
.61058 .64794 Mdot
.29319 .49603 Mdot
.31976 .47772 Mdot
.6056 .27566 Mdot
.37895 .625 Mdot
.6031 .57076 Mdot
.74678 .42869 Mdot
.51691 .33115 Mdot
.59752 .58424 Mdot
.22413 .51396 Mdot
.5085 .52371 Mdot
.53441 .6149 Mdot
.40801 .64691 Mdot
.37986 .64357 Mdot
.3876 .3452 Mdot
.30864 .4991 Mdot
.45612 .58178 Mdot
.39218 .65415 Mdot
.25153 .47545 Mdot
.49846 .56604 Mdot
.33291 .43521 Mdot
.57984 .34569 Mdot
.80231 .4147 Mdot
.73962 .32623 Mdot
.37447 .37026 Mdot
.32039 .34743 Mdot
.57411 .29737 Mdot
.60567 .3182 Mdot
.4613 .56662 Mdot
.29326 .47243 Mdot
.56229 .30702 Mdot
.61761 .55596 Mdot
.45422 .56683 Mdot
.61783 .58085 Mdot
.4101 .64188 Mdot
.6448 .57929 Mdot
.2518 .47676 Mdot
.36616 .34812 Mdot
.26198 .48213 Mdot
.38984 .34173 Mdot
.53439 .79868 Mdot
.67459 .55118 Mdot
.63408 .56358 Mdot
.50614 .72047 Mdot
.60048 .37937 Mdot
.74728 .44336 Mdot
.28325 .48355 Mdot
.26845 .47971 Mdot
.66189 .50675 Mdot
.58633 .30487 Mdot
.44977 .60587 Mdot
.52492 .70135 Mdot
.66377 .57374 Mdot
.59336 .34884 Mdot
.66942 .51081 Mdot
.38073 .26041 Mdot
.48393 .73694 Mdot
.60507 .38077 Mdot
.17118 .56303 Mdot
.675 .56215 Mdot
.46346 .58801 Mdot
.50736 .52806 Mdot
.5654 .74869 Mdot
.53878 .543 Mdot
.60082 .32063 Mdot
.4523 .58147 Mdot
.60172 .36427 Mdot
.25174 .48604 Mdot
.35823 .34103 Mdot
.60036 .35697 Mdot
.67294 .561 Mdot
.40336 .83452 Mdot
.36414 .33404 Mdot
.64342 .55295 Mdot
.372 .32155 Mdot
.55457 .30245 Mdot
.60297 .34008 Mdot
.49818 .56637 Mdot
.62411 .65816 Mdot
.37647 .32711 Mdot
.61548 .58695 Mdot
.52951 .27914 Mdot
.65512 .51476 Mdot
.42831 .62452 Mdot
.65138 .52588 Mdot
.63433 .53246 Mdot
.19202 .63756 Mdot
.65138 .64668 Mdot
.33664 .40523 Mdot
.41403 .37004 Mdot
.55565 .25144 Mdot
.61714 .37008 Mdot
.41389 .63244 Mdot
.63573 .38457 Mdot
.49735 .55372 Mdot
.29837 .48871 Mdot
.64849 .56146 Mdot
.50655 .55599 Mdot
.414 .33356 Mdot
.36779 .65241 Mdot
.63236 .59614 Mdot
.27279 .52333 Mdot
.47507 .5881 Mdot
.38685 .33386 Mdot
.58058 .33407 Mdot
.60742 .33856 Mdot
.33652 .44182 Mdot
.61878 .55647 Mdot
.6298 .56879 Mdot
.37563 .31487 Mdot
.53037 .52203 Mdot
.40351 .62121 Mdot
.47481 .59106 Mdot
.37669 .31724 Mdot
.48438 .73872 Mdot
.56481 .35867 Mdot
.63478 .54544 Mdot
.50166 .7165 Mdot
.56276 .25248 Mdot
.69724 .4709 Mdot
.38453 .64051 Mdot
.56341 .72878 Mdot
.60059 .3207 Mdot
.37115 .34705 Mdot
.33258 .71958 Mdot
.61196 .52454 Mdot
.65184 .54352 Mdot
.57119 .72407 Mdot
.52684 .70198 Mdot
.61285 .6479 Mdot
.4702 .54757 Mdot
.52418 .75337 Mdot
.6646 .50751 Mdot
.62923 .51742 Mdot
.66156 .53484 Mdot
.65032 .52469 Mdot
.59838 .34737 Mdot
.7879 .46722 Mdot
.26696 .50823 Mdot
.64414 .47327 Mdot
.41257 .6468 Mdot
.58874 .55697 Mdot
.60421 .54946 Mdot
.64335 .42662 Mdot
.5929 .69839 Mdot
.58843 .35422 Mdot
.6108 .38658 Mdot
.38004 .37203 Mdot
.659 .51548 Mdot
.28524 .48486 Mdot
.51801 .53825 Mdot
.28852 .46413 Mdot
.59667 .34601 Mdot
.2384 .48416 Mdot
.35698 .32557 Mdot
.25969 .51858 Mdot
.2949 .47905 Mdot
.3684 .35478 Mdot
.56213 .34601 Mdot
.59836 .58958 Mdot
.36836 .35536 Mdot
.43951 .60411 Mdot
.41299 .63047 Mdot
.62686 .32378 Mdot
.44519 .58945 Mdot
.58809 .59592 Mdot
.1974 .38663 Mdot
.26912 .51877 Mdot
.57113 .69583 Mdot
.5645 .35072 Mdot
.35856 .66198 Mdot
.60212 .35458 Mdot
.45601 .60009 Mdot
.38803 .63755 Mdot
.68736 .53249 Mdot
.40232 .77557 Mdot
.43411 .30332 Mdot
.58345 .58698 Mdot
.61519 .29492 Mdot
.28596 .46521 Mdot
.36434 .35428 Mdot
.34324 .26842 Mdot
.45623 .58433 Mdot
.62194 .38917 Mdot
.55409 .35114 Mdot
.49639 .55394 Mdot
.36993 .34363 Mdot
.73222 .31854 Mdot
.62417 .54827 Mdot
.38503 .3737 Mdot
.65104 .52631 Mdot
.80773 .44215 Mdot
.36825 .67806 Mdot
.50865 .55936 Mdot
.65587 .50698 Mdot
.30589 .48323 Mdot
.66056 .50686 Mdot
.79999 .51127 Mdot
.45232 .7759 Mdot
.67199 .54417 Mdot
.57359 .7066 Mdot
.30632 .51483 Mdot
.60289 .36767 Mdot
.48326 .56841 Mdot
.4703 .56548 Mdot
.64621 .50408 Mdot
.50188 .865 Mdot
.3824 .65558 Mdot
.2186 .45877 Mdot
.67331 .55556 Mdot
.62338 .57268 Mdot
.648 .36796 Mdot
.78956 .39821 Mdot
.46407 .59373 Mdot
.65858 .5458 Mdot
.59451 .70982 Mdot
.37831 .35641 Mdot
.64036 .52043 Mdot
.61931 .57897 Mdot
.34497 .48768 Mdot
.36965 .34963 Mdot
.23849 .49996 Mdot
.50102 .55981 Mdot
.30259 .45918 Mdot
.36687 .62345 Mdot
.56047 .72062 Mdot
.49726 .78997 Mdot
.48447 .73103 Mdot
.39076 .6103 Mdot
.61777 .5219 Mdot
.59929 .61357 Mdot
.64543 .53629 Mdot
.37755 .64586 Mdot
.39715 .31141 Mdot
.59511 .35095 Mdot
.80753 .42927 Mdot
.46832 .56491 Mdot
.59302 .55576 Mdot
.3737 .66989 Mdot
.59792 .36252 Mdot
.7417 .29921 Mdot
.59677 .33938 Mdot
.38339 .33601 Mdot
.32356 .33704 Mdot
.39254 .636 Mdot
.60246 .35508 Mdot
.29634 .45709 Mdot
.32873 .33897 Mdot
.67664 .49028 Mdot
.35768 .32385 Mdot
.56901 .37163 Mdot
.60483 .38377 Mdot
.58632 .29807 Mdot
.64988 .50685 Mdot
.57291 .70257 Mdot
.493 .56727 Mdot
.36827 .32333 Mdot
.29349 .50774 Mdot
.43725 .76128 Mdot
.72379 .35106 Mdot
.50072 .74425 Mdot
.68505 .52921 Mdot
.64417 .57892 Mdot
.62574 .58298 Mdot
.44204 .57729 Mdot
.60214 .61728 Mdot
.66824 .54228 Mdot
.4115 .32989 Mdot
.24576 .48832 Mdot
.67053 .55839 Mdot
.48852 .5567 Mdot
.52034 .56457 Mdot
.35799 .65946 Mdot
.81086 .45535 Mdot
.63014 .33006 Mdot
.59833 .35987 Mdot
.28505 .49648 Mdot
.26885 .46025 Mdot
.39136 .6566 Mdot
.39284 .34818 Mdot
.59623 .3362 Mdot
.30806 .74413 Mdot
.40027 .62337 Mdot
.64657 .57287 Mdot
.50501 .71967 Mdot
.59076 .72193 Mdot
.61588 .53994 Mdot
.65169 .56358 Mdot
.46492 .55516 Mdot
.28785 .48556 Mdot
.7757 .56849 Mdot
.74084 .30362 Mdot
.39604 .6391 Mdot
.40732 .63668 Mdot
.59076 .30122 Mdot
.62475 .59163 Mdot
.3736 .32553 Mdot
.53392 .75962 Mdot
.39988 .28319 Mdot
.44436 .2097 Mdot
.23261 .53471 Mdot
.60195 .5714 Mdot
.76845 .49161 Mdot
.58509 .59927 Mdot
.56023 .29559 Mdot
.55711 .32758 Mdot
.58575 .355 Mdot
.38218 .35611 Mdot
.41142 .71943 Mdot
.40452 .34137 Mdot
.4876 .58301 Mdot
.58232 .32074 Mdot
.63355 .64839 Mdot
.27028 .47975 Mdot
.66387 .51823 Mdot
.37659 .63181 Mdot
.43038 .65817 Mdot
.47649 .57143 Mdot
.56237 .726 Mdot
.24574 .51075 Mdot
.56726 .32523 Mdot
.6655 .51736 Mdot
.32425 .37438 Mdot
.51156 .75216 Mdot
.27174 .53646 Mdot
.50647 .55493 Mdot
.39799 .63237 Mdot
.75429 .54803 Mdot
.39674 .61861 Mdot
.37936 .32692 Mdot
.67309 .54931 Mdot
.62956 .59146 Mdot
.63077 .57933 Mdot
.67907 .5593 Mdot
.38357 .35197 Mdot
.58196 .58204 Mdot
.44574 .60066 Mdot
.50456 .56267 Mdot
.58773 .62473 Mdot
.36951 .63465 Mdot
.38806 .36356 Mdot
.25121 .48251 Mdot
.47236 .55038 Mdot
.36769 .6653 Mdot
.67166 .52509 Mdot
.66539 .54424 Mdot
.48956 .58017 Mdot
.6872 .53743 Mdot
.57988 .59388 Mdot
.2559 .50943 Mdot
.59795 .63415 Mdot
.35807 .65776 Mdot
.38154 .63105 Mdot
.3936 .33265 Mdot
.60249 .35634 Mdot
.37468 .66211 Mdot
.27646 .52697 Mdot
.64339 .51842 Mdot
.65413 .52787 Mdot
.58203 .38475 Mdot
.41179 .73096 Mdot
.35708 .6588 Mdot
.68385 .55175 Mdot
.60789 .37505 Mdot
.5524 .34693 Mdot
.65446 .54501 Mdot
.58217 .57501 Mdot
.61929 .36895 Mdot
.40582 .64298 Mdot
.39743 .34015 Mdot
.46155 .73018 Mdot
.35991 .35426 Mdot
.57871 .33424 Mdot
.45333 .57522 Mdot
.56352 .33874 Mdot
.45494 .58424 Mdot
.52408 .18972 Mdot
.66615 .54004 Mdot
.6105 .26096 Mdot
.46908 .59452 Mdot
.27444 .47831 Mdot
.28355 .47227 Mdot
.48982 .55297 Mdot
.59512 .31499 Mdot
.48331 .57559 Mdot
.38749 .61719 Mdot
.55265 .25374 Mdot
.61816 .37633 Mdot
.2945 .47736 Mdot
.27053 .51997 Mdot
.37558 .31762 Mdot
.64389 .58096 Mdot
.63423 .54505 Mdot
.25687 .51777 Mdot
.39678 .28009 Mdot
.57498 .36624 Mdot
.63042 .56873 Mdot
.44245 .58558 Mdot
.26117 .50844 Mdot
.4511 .3445 Mdot
.56576 .3044 Mdot
.65398 .50541 Mdot
.45876 .78025 Mdot
.3593 .33558 Mdot
.59995 .55083 Mdot
.58114 .58393 Mdot
.38461 .65192 Mdot
.56578 .72972 Mdot
.41676 .73228 Mdot
.36029 .32138 Mdot
.49735 .55987 Mdot
.61287 .54234 Mdot
.27561 .47478 Mdot
.67068 .53221 Mdot
.82491 .61075 Mdot
.50145 .57015 Mdot
.61984 .55729 Mdot
.5143 .5356 Mdot
.59957 .32704 Mdot
.62726 .57204 Mdot
.32892 .37664 Mdot
.28035 .49783 Mdot
.6219 .55319 Mdot
.49953 .51024 Mdot
.37219 .32191 Mdot
.47732 .57061 Mdot
.39999 .63189 Mdot
.62018 .65299 Mdot
.54997 .80124 Mdot
.24156 .5237 Mdot
.36852 .63193 Mdot
.64851 .58075 Mdot
.29735 .5172 Mdot
.40659 .35069 Mdot
.4885 .5646 Mdot
.60479 .54103 Mdot
.38696 .3678 Mdot
.37674 .35849 Mdot
.39326 .63219 Mdot
.74023 .26178 Mdot
.66145 .58757 Mdot
.63644 .55317 Mdot
.74212 .28258 Mdot
.55657 .37159 Mdot
.64564 .55212 Mdot
.64255 .58815 Mdot
.38946 .33176 Mdot
.40656 .71632 Mdot
.56339 .72668 Mdot
.51417 .55693 Mdot
.36664 .35814 Mdot
.22617 .52868 Mdot
.27705 .51116 Mdot
.36534 .63569 Mdot
.58899 .34354 Mdot
.38747 .66008 Mdot
.26632 .50187 Mdot
.64246 .57252 Mdot
.39709 .32778 Mdot
.76104 .59775 Mdot
.36105 .33671 Mdot
.27061 .52658 Mdot
.55848 .29713 Mdot
.78779 .55167 Mdot
.83459 .59958 Mdot
.46881 .4761 Mdot
.32546 .32979 Mdot
.39235 .64565 Mdot
.74077 .30293 Mdot
.66898 .56478 Mdot
.7951 .50478 Mdot
.64113 .55046 Mdot
.40476 .59472 Mdot
.27369 .46638 Mdot
.49836 .5661 Mdot
.45707 .585 Mdot
.5647 .72098 Mdot
.38129 .35973 Mdot
.39477 .31277 Mdot
.44964 .57807 Mdot
.37966 .33407 Mdot
.62476 .55393 Mdot
.24794 .50093 Mdot
.57142 .20725 Mdot
.66853 .56832 Mdot
.469 .54476 Mdot
.35376 .36019 Mdot
.53103 .31874 Mdot
.22571 .52702 Mdot
.76848 .47575 Mdot
.39232 .22637 Mdot
.37237 .33068 Mdot
.80958 .4589 Mdot
.28466 .49232 Mdot
.47177 .5507 Mdot
.30493 .51034 Mdot
.63479 .55026 Mdot
.60172 .57205 Mdot
.44943 .56668 Mdot
.64986 .58272 Mdot
.74746 .49083 Mdot
.57828 .58625 Mdot
.59916 .45948 Mdot
.65889 .53729 Mdot
.63461 .28389 Mdot
.40968 .34547 Mdot
.45069 .57582 Mdot
.46935 .68338 Mdot
.63691 .53317 Mdot
.61806 .36129 Mdot
.37953 .3681 Mdot
.37199 .23152 Mdot
.38061 .35484 Mdot
.26389 .47982 Mdot
.38973 .35268 Mdot
.58596 .58416 Mdot
.5903 .32717 Mdot
.26716 .49267 Mdot
.47252 .57024 Mdot
.29836 .49947 Mdot
.62587 .54513 Mdot
.42025 .38476 Mdot
.28793 .50531 Mdot
.59857 .53963 Mdot
.59333 .32772 Mdot
.43516 .80479 Mdot
.58361 .29197 Mdot
.64065 .56587 Mdot
.64442 .55866 Mdot
.46301 .59446 Mdot
.39241 .34258 Mdot
.56192 .33823 Mdot
.32175 .42406 Mdot
.35812 .66195 Mdot
.58656 .34857 Mdot
.52097 .52267 Mdot
.51855 .73017 Mdot
.61215 .35229 Mdot
.59385 .71471 Mdot
.38134 .32409 Mdot
.60486 .32705 Mdot
.55807 .52136 Mdot
.64084 .47645 Mdot
.38502 .62392 Mdot
.2986 .45652 Mdot
.5253 .72454 Mdot
.28086 .50704 Mdot
.32871 .37883 Mdot
.30353 .45528 Mdot
.36609 .3357 Mdot
.51991 .51783 Mdot
.63912 .66323 Mdot
.38401 .30714 Mdot
.37875 .40752 Mdot
.27359 .50615 Mdot
.44902 .58723 Mdot
.59296 .62938 Mdot
.43748 .59656 Mdot
.46133 .5901 Mdot
.36184 .31961 Mdot
.6051 .32616 Mdot
.59414 .30793 Mdot
.50093 .53489 Mdot
.60815 .34668 Mdot
.25471 .49696 Mdot
.48469 .72101 Mdot
.78229 .43963 Mdot
.41017 .33104 Mdot
.60208 .63739 Mdot
.60821 .54275 Mdot
.25541 .47558 Mdot
.25296 .49354 Mdot
.38123 .35816 Mdot
.66111 .45358 Mdot
.47033 .5875 Mdot
.54666 .30531 Mdot
.58794 .32094 Mdot
.60134 .32753 Mdot
.5841 .37871 Mdot
.40941 .72286 Mdot
.36825 .35853 Mdot
.59481 .31585 Mdot
.67931 .556 Mdot
.63738 .58736 Mdot
.47892 .54846 Mdot
.41061 .6394 Mdot
.57979 .5861 Mdot
.48335 .57619 Mdot
.65056 .54434 Mdot
.27633 .4801 Mdot
.56021 .50618 Mdot
.49818 .55178 Mdot
.28597 .48394 Mdot
.28217 .47952 Mdot
.4985 .55872 Mdot
.55806 .50738 Mdot
.74357 .51467 Mdot
.65107 .49985 Mdot
.59283 .27438 Mdot
.28917 .47031 Mdot
.36008 .42007 Mdot
.61369 .2625 Mdot
.62173 .58832 Mdot
.48273 .58718 Mdot
.24747 .49555 Mdot
.61496 .37923 Mdot
.62989 .55825 Mdot
.45976 .56874 Mdot
.3914 .62221 Mdot
.4788 .56736 Mdot
.46374 .55649 Mdot
.59331 .37447 Mdot
.18951 .40078 Mdot
.61384 .36201 Mdot
.30622 .44855 Mdot
.46706 .5755 Mdot
.6785 .19881 Mdot
.28054 .46672 Mdot
.54872 .25428 Mdot
.63633 .66304 Mdot
.64968 .54017 Mdot
.2839 .49805 Mdot
.61931 .38873 Mdot
.36863 .31119 Mdot
.59379 .69437 Mdot
.60371 .35474 Mdot
.48266 .54412 Mdot
.47785 .55161 Mdot
.26511 .50887 Mdot
.5739 .33483 Mdot
.58127 .58264 Mdot
.60559 .336 Mdot
.40128 .32617 Mdot
.67936 .51058 Mdot
.40583 .22178 Mdot
.45597 .58037 Mdot
.60954 .35392 Mdot
.28914 .51404 Mdot
.36492 .63012 Mdot
.65396 .58718 Mdot
.3815 .22473 Mdot
.64698 .58189 Mdot
.38617 .31118 Mdot
.52215 .57098 Mdot
.65334 .48511 Mdot
.65883 .56416 Mdot
.5993 .55885 Mdot
.37783 .29655 Mdot
.66059 .56072 Mdot
.62424 .53706 Mdot
.73859 .31921 Mdot
.6111 .3652 Mdot
.66996 .5604 Mdot
.25201 .51195 Mdot
.53818 .48895 Mdot
.61659 .57104 Mdot
.32054 .35421 Mdot
.56151 .748 Mdot
.47763 .59176 Mdot
.47743 .5394 Mdot
.47505 .78516 Mdot
.64161 .55637 Mdot
.6178 .5895 Mdot
.68027 .5124 Mdot
.77483 .49568 Mdot
.27185 .50106 Mdot
.30722 .48927 Mdot
.3667 .62891 Mdot
.5734 .72165 Mdot
.38548 .63144 Mdot
.40637 .35145 Mdot
.61297 .65182 Mdot
.50396 .55742 Mdot
.60258 .35954 Mdot
.62845 .57827 Mdot
.29746 .50656 Mdot
.63071 .54986 Mdot
.63276 .51324 Mdot
.25586 .50047 Mdot
.24989 .49075 Mdot
.29128 .44926 Mdot
.40118 .63498 Mdot
.59272 .35786 Mdot
.66005 .58523 Mdot
.4023 .62991 Mdot
.44484 .57353 Mdot
.46519 .74167 Mdot
.59035 .35724 Mdot
.60911 .359 Mdot
.58094 .31165 Mdot
.63888 .59281 Mdot
.68018 .50803 Mdot
.40295 .34747 Mdot
.58189 .38473 Mdot
.37857 .32109 Mdot
.28413 .50006 Mdot
.24249 .49543 Mdot
.63588 .5496 Mdot
.52508 .52537 Mdot
.37275 .63045 Mdot
.28316 .51152 Mdot
.51404 .54369 Mdot
.36171 .65235 Mdot
.60981 .57724 Mdot
.28309 .50452 Mdot
.39999 .61028 Mdot
.66705 .45765 Mdot
.4382 .23754 Mdot
.36171 .63776 Mdot
.46071 .58666 Mdot
.72234 .36563 Mdot
.44865 .77078 Mdot
.3513 .64829 Mdot
.40977 .34226 Mdot
.61353 .59372 Mdot
.51187 .55218 Mdot
.36381 .66024 Mdot
.419 .745 Mdot
.2619 .49946 Mdot
.46581 .5875 Mdot
.4668 .48821 Mdot
.78182 .44187 Mdot
.36286 .63303 Mdot
.60996 .35529 Mdot
.56539 .36452 Mdot
.65124 .56909 Mdot
.61725 .65383 Mdot
.41016 .3222 Mdot
.27862 .45577 Mdot
.30485 .49589 Mdot
.55406 .32553 Mdot
.48395 .7335 Mdot
.25888 .51479 Mdot
.61422 .5917 Mdot
.3895 .6664 Mdot
.68071 .55293 Mdot
.50951 .58463 Mdot
.65378 .48632 Mdot
.4919 .53226 Mdot
.36313 .63349 Mdot
.40672 .31623 Mdot
.36617 .34659 Mdot
.3895 .34627 Mdot
.25978 .51243 Mdot
.52894 .72024 Mdot
.30574 .5004 Mdot
.74915 .28892 Mdot
.38138 .65624 Mdot
.23021 .67505 Mdot
.58983 .60333 Mdot
.64452 .53916 Mdot
.65525 .51684 Mdot
.44506 .57963 Mdot
.64026 .55743 Mdot
.39023 .36644 Mdot
.29842 .45891 Mdot
.45021 .31851 Mdot
.57808 .3607 Mdot
.74733 .29911 Mdot
.27093 .48055 Mdot
.49428 .53927 Mdot
.3734 .63297 Mdot
.49758 .7942 Mdot
.415 .60746 Mdot
.24503 .51472 Mdot
.61323 .55371 Mdot
.59603 .30361 Mdot
.31885 .7594 Mdot
.62874 .57483 Mdot
.2707 .51853 Mdot
.25913 .53375 Mdot
.63972 .47067 Mdot
.72 .61585 Mdot
.42075 .28722 Mdot
.49884 .71931 Mdot
.39163 .60732 Mdot
.43955 .58953 Mdot
.5404 .75858 Mdot
.26704 .5031 Mdot
.30317 .47142 Mdot
.38743 .60433 Mdot
.52945 .32023 Mdot
.58441 .31565 Mdot
.59281 .28625 Mdot
.39549 .36024 Mdot
.65224 .53895 Mdot
.27672 .50725 Mdot
.56675 .29615 Mdot
.45484 .68089 Mdot
.38385 .34412 Mdot
.28857 .50617 Mdot
.64608 .58366 Mdot
.6581 .56685 Mdot
.38737 .63034 Mdot
.51793 .56875 Mdot
.44038 .59666 Mdot
.5506 .2549 Mdot
.51098 .73726 Mdot
.63472 .6639 Mdot
.6519 .54346 Mdot
.58793 .37852 Mdot
.49695 .55662 Mdot
.37821 .62503 Mdot
.67057 .53295 Mdot
.79591 .53112 Mdot
.60894 .38651 Mdot
.3764 .32409 Mdot
.46637 .57042 Mdot
.56217 .71568 Mdot
.64782 .58282 Mdot
.64036 .55054 Mdot
.65011 .50699 Mdot
.78436 .55944 Mdot
.28925 .46157 Mdot
.60345 .37396 Mdot
.39933 .63407 Mdot
.60154 .33894 Mdot
.33641 .45576 Mdot
.59623 .63615 Mdot
.63889 .59683 Mdot
.6146 .37318 Mdot
.5931 .33332 Mdot
.38736 .31115 Mdot
.36436 .34823 Mdot
.23545 .52526 Mdot
.64322 .58888 Mdot
.50494 .56633 Mdot
.59553 .31787 Mdot
.29321 .45382 Mdot
.38691 .6324 Mdot
.31877 .3529 Mdot
.66605 .54251 Mdot
.26937 .50632 Mdot
.48277 .57025 Mdot
.58543 .36828 Mdot
.28266 .48691 Mdot
.47094 .55102 Mdot
.40968 .63568 Mdot
.60256 .559 Mdot
.30406 .52096 Mdot
.45863 .56648 Mdot
.6583 .58278 Mdot
.57893 .49596 Mdot
.61673 .65299 Mdot
.518 .54571 Mdot
.24207 .48484 Mdot
.46452 .5637 Mdot
.56267 .35841 Mdot
.65213 .47528 Mdot
.30496 .4704 Mdot
.64878 .3054 Mdot
.64194 .66461 Mdot
.45335 .58251 Mdot
.60311 .36643 Mdot
.3329 .43668 Mdot
.52786 .35242 Mdot
.44784 .76652 Mdot
.6201 .56402 Mdot
.28047 .50734 Mdot
.38735 .62411 Mdot
.39409 .3129 Mdot
.36177 .39206 Mdot
.35773 .45719 Mdot
.28979 .47669 Mdot
.62727 .57839 Mdot
.60363 .32515 Mdot
.37592 .32925 Mdot
.65076 .35877 Mdot
.29693 .51623 Mdot
.24941 .5115 Mdot
.64482 .5126 Mdot
.38447 .63206 Mdot
.59937 .61506 Mdot
.30438 .46523 Mdot
.30975 .46503 Mdot
.73733 .32122 Mdot
.39139 .60787 Mdot
.64961 .50603 Mdot
.49956 .53408 Mdot
.64683 .52052 Mdot
.7419 .29475 Mdot
.46965 .55479 Mdot
.57714 .36047 Mdot
.65029 .55554 Mdot
.17933 .4612 Mdot
.27198 .46916 Mdot
.49864 .71956 Mdot
.43652 .30639 Mdot
.37433 .35959 Mdot
.27793 .49595 Mdot
.6254 .56269 Mdot
.32022 .3443 Mdot
.36404 .63962 Mdot
.66018 .50431 Mdot
.45033 .58117 Mdot
.55174 .33056 Mdot
.39839 .32955 Mdot
.52561 .49917 Mdot
.39866 .31761 Mdot
.39381 .33599 Mdot
.56473 .40522 Mdot
.65012 .57006 Mdot
.27256 .48359 Mdot
.26574 .52414 Mdot
.4382 .57845 Mdot
.28372 .43514 Mdot
.57228 .3235 Mdot
.18451 .45305 Mdot
.79236 .5397 Mdot
.67509 .54694 Mdot
.47152 .54697 Mdot
.47462 .59037 Mdot
.32401 .33505 Mdot
.65677 .56205 Mdot
.59983 .36868 Mdot
.30432 .46321 Mdot
.27271 .51251 Mdot
.59846 .5399 Mdot
.3659 .34713 Mdot
.41257 .61923 Mdot
.25534 .49323 Mdot
.46279 .72607 Mdot
.6191 .55774 Mdot
.35848 .37362 Mdot
.25769 .49215 Mdot
.42464 .83197 Mdot
.17593 .4202 Mdot
.61249 .34128 Mdot
.59749 .5675 Mdot
.56748 .30478 Mdot
.37146 .62166 Mdot
.31692 .48437 Mdot
.39078 .30943 Mdot
.46906 .57336 Mdot
.33098 .26474 Mdot
.26784 .51171 Mdot
.59638 .3471 Mdot
.64669 .56732 Mdot
.809 .46561 Mdot
.66684 .56987 Mdot
.40616 .71499 Mdot
.35594 .65648 Mdot
.36655 .39502 Mdot
.37465 .31586 Mdot
.5964 .57009 Mdot
.40458 .62429 Mdot
.25337 .52478 Mdot
.25691 .50131 Mdot
.36737 .22461 Mdot
.46591 .55517 Mdot
.31927 .48511 Mdot
.65447 .58532 Mdot
.29588 .45071 Mdot
.72382 .35023 Mdot
.37224 .35696 Mdot
.6417 .52264 Mdot
.29176 .49917 Mdot
.52883 .34666 Mdot
.50656 .72311 Mdot
.61833 .56226 Mdot
.51095 .53048 Mdot
.36658 .33725 Mdot
.74751 .30235 Mdot
.26719 .46849 Mdot
.6798 .53628 Mdot
.39145 .36849 Mdot
.51984 .51838 Mdot
.4542 .32007 Mdot
.5924 .35815 Mdot
.2723 .52057 Mdot
.39793 .33972 Mdot
.46871 .58015 Mdot
.39972 .61151 Mdot
.2737 .52845 Mdot
.29605 .49547 Mdot
.62029 .52059 Mdot
.50321 .53862 Mdot
.52272 .52506 Mdot
.56814 .3545 Mdot
.38637 .32761 Mdot
.63818 .50982 Mdot
.46266 .74318 Mdot
.67575 .5204 Mdot
.38958 .32696 Mdot
.69671 .21972 Mdot
.61012 .55558 Mdot
.66191 .54003 Mdot
.80868 .47844 Mdot
.56592 .32441 Mdot
.59107 .3826 Mdot
.50457 .74802 Mdot
.58862 .55974 Mdot
.63763 .64768 Mdot
.59515 .35603 Mdot
.59566 .34324 Mdot
.6363 .64792 Mdot
.62083 .52097 Mdot
.59407 .28993 Mdot
.37655 .33135 Mdot
.37186 .35841 Mdot
.60085 .3279 Mdot
.66118 .52023 Mdot
.40429 .36806 Mdot
.66588 .44444 Mdot
.25569 .52153 Mdot
.55066 .74976 Mdot
.59802 .33207 Mdot
.50783 .71893 Mdot
.38002 .32685 Mdot
.53639 .78812 Mdot
.56733 .74742 Mdot
.66671 .58279 Mdot
.6548 .56687 Mdot
.3884 .64784 Mdot
.47756 .56943 Mdot
.49882 .5573 Mdot
.38998 .34629 Mdot
.60263 .61742 Mdot
.58474 .35355 Mdot
.58663 .57793 Mdot
.4346 .75919 Mdot
.56421 .79392 Mdot
.75157 .60029 Mdot
.59019 .34291 Mdot
.5808 .33854 Mdot
.23978 .50049 Mdot
.238 .48355 Mdot
.64987 .59347 Mdot
.3655 .34135 Mdot
.60755 .33155 Mdot
.39141 .32405 Mdot
.26555 .50274 Mdot
.26785 .48188 Mdot
.49235 .54831 Mdot
.46805 .58696 Mdot
.2717 .49565 Mdot
.32061 .35263 Mdot
.46327 .74309 Mdot
.55667 .35343 Mdot
.75066 .28536 Mdot
.52279 .79657 Mdot
.80806 .43851 Mdot
.38954 .62271 Mdot
.56056 .50805 Mdot
.3922 .36711 Mdot
.59603 .56878 Mdot
.64919 .5484 Mdot
.47464 .55979 Mdot
.38458 .3723 Mdot
.3704 .64932 Mdot
.3737 .35859 Mdot
.40116 .61342 Mdot
.30561 .4861 Mdot
.62424 .5757 Mdot
.6216 .54643 Mdot
.39048 .31208 Mdot
.24009 .50594 Mdot
.2889 .50051 Mdot
.38486 .62135 Mdot
.50413 .79204 Mdot
.26551 .50789 Mdot
.59722 .33259 Mdot
.66381 .31668 Mdot
.47632 .55315 Mdot
.62971 .55932 Mdot
.47709 .78663 Mdot
.65429 .47653 Mdot
.44728 .56917 Mdot
.4665 .56963 Mdot
.73794 .25932 Mdot
.61568 .55879 Mdot
.35058 .22506 Mdot
.49707 .55005 Mdot
.56367 .33773 Mdot
.27574 .48698 Mdot
.47074 .5481 Mdot
.49838 .52584 Mdot
.38851 .67281 Mdot
.45865 .55506 Mdot
.58642 .31503 Mdot
.57442 .31382 Mdot
.59796 .63536 Mdot
.75382 .29447 Mdot
.39924 .63174 Mdot
.36616 .64874 Mdot
.29278 .46341 Mdot
.32923 .38123 Mdot
.62262 .60654 Mdot
.36829 .65535 Mdot
.62481 .32307 Mdot
.63975 .5128 Mdot
.61519 .64976 Mdot
.58954 .62693 Mdot
.5742 .37279 Mdot
.67188 .49401 Mdot
.28534 .46401 Mdot
.59516 .34828 Mdot
.59606 .63188 Mdot
.64061 .51814 Mdot
.58831 .35667 Mdot
.39168 .33597 Mdot
.69382 .65308 Mdot
.60699 .33857 Mdot
.59433 .69293 Mdot
.37182 .32797 Mdot
.61156 .64538 Mdot
.27725 .69787 Mdot
.45751 .84984 Mdot
.37334 .35576 Mdot
.28497 .50868 Mdot
.2766 .50608 Mdot
.25545 .50701 Mdot
.57598 .36944 Mdot
.2545 .48226 Mdot
.57169 .34269 Mdot
.3263 .33 Mdot
.56924 .72101 Mdot
.39044 .63701 Mdot
.29679 .4374 Mdot
.60217 .32988 Mdot
.74553 .29077 Mdot
.88538 .52383 Mdot
.68247 .53626 Mdot
.38188 .30762 Mdot
.37323 .66002 Mdot
.49365 .71615 Mdot
.38455 .65163 Mdot
.28483 .49294 Mdot
.56306 .71869 Mdot
.62685 .55092 Mdot
.41842 .23828 Mdot
.38594 .62553 Mdot
.59631 .34203 Mdot
.61443 .52423 Mdot
.23401 .49972 Mdot
.36876 .62896 Mdot
.37998 .63101 Mdot
.63829 .55771 Mdot
.56691 .32605 Mdot
.28754 .49477 Mdot
.37329 .37088 Mdot
.35396 .52308 Mdot
.54666 .54264 Mdot
.61272 .56623 Mdot
.65474 .53148 Mdot
.51365 .72887 Mdot
.31883 .35591 Mdot
.3713 .33628 Mdot
.42083 .74093 Mdot
.25157 .47768 Mdot
.44242 .76771 Mdot
.52268 .33148 Mdot
.30063 .43947 Mdot
.4695 .55538 Mdot
.47438 .54941 Mdot
.63137 .57048 Mdot
.85619 .56829 Mdot
.71013 .62742 Mdot
.40487 .36507 Mdot
.47937 .55584 Mdot
.23868 .50826 Mdot
.59922 .38774 Mdot
.44236 .49497 Mdot
.57877 .59609 Mdot
.37277 .37108 Mdot
.25955 .505 Mdot
.82585 .62702 Mdot
.39572 .64433 Mdot
.49254 .72113 Mdot
.64737 .58622 Mdot
.63277 .56655 Mdot
.38077 .34845 Mdot
.40172 .31301 Mdot
.74113 .32237 Mdot
.40679 .59789 Mdot
.41127 .21827 Mdot
.39166 .2962 Mdot
.82641 .63497 Mdot
.48822 .58218 Mdot
.57718 .34378 Mdot
.49832 .56193 Mdot
.4005 .30958 Mdot
.64787 .55302 Mdot
.56597 .32639 Mdot
.48976 .56462 Mdot
.62305 .33098 Mdot
.62069 .65385 Mdot
.46216 .73077 Mdot
.64558 .57843 Mdot
.5749 .30277 Mdot
.59294 .35233 Mdot
.55071 .30126 Mdot
.48686 .5504 Mdot
.65878 .54527 Mdot
.68052 .5381 Mdot
.65647 .53476 Mdot
.73857 .33235 Mdot
.62512 .57171 Mdot
.52311 .32362 Mdot
.49363 .74729 Mdot
.17288 .47471 Mdot
.62502 .54381 Mdot
.39435 .34484 Mdot
.6347 .57566 Mdot
.40603 .62502 Mdot
.6099 .54798 Mdot
.62613 .65695 Mdot
.37561 .33598 Mdot
.8004 .51508 Mdot
.40632 .65413 Mdot
.61129 .56731 Mdot
.3923 .61005 Mdot
.53127 .25467 Mdot
.42321 .74073 Mdot
.73159 .32029 Mdot
.6049 .33528 Mdot
.30837 .50403 Mdot
.41027 .32118 Mdot
.26523 .47943 Mdot
.58639 .55697 Mdot
.5029 .56212 Mdot
.2154 .66437 Mdot
.47388 .75755 Mdot
.64903 .55453 Mdot
.45337 .59429 Mdot
.60737 .36674 Mdot
.27695 .46721 Mdot
.79184 .39971 Mdot
.65218 .51482 Mdot
.40271 .64734 Mdot
.39563 .64957 Mdot
.44925 .62623 Mdot
.53791 .3098 Mdot
.72546 .33874 Mdot
.37949 .34727 Mdot
.26263 .51348 Mdot
.35995 .65716 Mdot
.61818 .30189 Mdot
.39017 .30727 Mdot
.32421 .33896 Mdot
.39902 .3329 Mdot
.63737 .53703 Mdot
.48996 .54479 Mdot
.56141 .26655 Mdot
.46288 .56119 Mdot
.65558 .52382 Mdot
.29577 .49464 Mdot
.4682 .55487 Mdot
.38749 .6437 Mdot
.39647 .33852 Mdot
.27382 .47994 Mdot
.64377 .56196 Mdot
.59684 .36032 Mdot
.53498 .60752 Mdot
.31846 .50137 Mdot
.61581 .6532 Mdot
.61572 .65316 Mdot
.56187 .36863 Mdot
.51758 .54962 Mdot
.41215 .39335 Mdot
.6459 .47182 Mdot
.34882 .45795 Mdot
.53147 .54087 Mdot
.24298 .4409 Mdot
.30587 .50152 Mdot
.26467 .49357 Mdot
.63162 .54414 Mdot
.29269 .45259 Mdot
.62021 .59471 Mdot
.24317 .48234 Mdot
.56317 .25077 Mdot
.58327 .58887 Mdot
.25692 .49721 Mdot
.49233 .56913 Mdot
.6562 .58536 Mdot
.60467 .37047 Mdot
.31123 .49179 Mdot
.66732 .58212 Mdot
.17804 .52238 Mdot
.38821 .31112 Mdot
.48533 .5497 Mdot
.50037 .68842 Mdot
.384 .33266 Mdot
.57707 .32177 Mdot
.60447 .59079 Mdot
.36756 .65716 Mdot
.57813 .33599 Mdot
.4383 .62244 Mdot
.38243 .63257 Mdot
.48255 .72267 Mdot
.58572 .32509 Mdot
.47284 .55492 Mdot
.40619 .64111 Mdot
.43697 .58071 Mdot
.26257 .49604 Mdot
.27357 .53515 Mdot
.4572 .56961 Mdot
.63007 .54859 Mdot
.23613 .5057 Mdot
.38473 .35817 Mdot
.61842 .57951 Mdot
.27657 .50861 Mdot
.48949 .55774 Mdot
.67306 .56384 Mdot
.58648 .56363 Mdot
.74105 .30598 Mdot
.48843 .58545 Mdot
.38959 .63973 Mdot
.55739 .29841 Mdot
.67257 .54161 Mdot
.40196 .62085 Mdot
.30148 .51923 Mdot
.68148 .53034 Mdot
.60725 .32562 Mdot
.65418 .45018 Mdot
.26933 .46017 Mdot
.36374 .33601 Mdot
.27462 .5246 Mdot
.3733 .61651 Mdot
.89725 .50415 Mdot
.49779 .55514 Mdot
.66009 .49671 Mdot
.63377 .53003 Mdot
.31244 .49776 Mdot
.59057 .35288 Mdot
.42845 .21267 Mdot
.60242 .55864 Mdot
.68427 .53218 Mdot
.6334 .55877 Mdot
.34073 .51409 Mdot
.56691 .35658 Mdot
.63152 .55851 Mdot
.53451 .54912 Mdot
.64874 .52597 Mdot
.37818 .61811 Mdot
.24548 .68793 Mdot
.45585 .56049 Mdot
.67066 .18938 Mdot
.49254 .56136 Mdot
.25229 .50061 Mdot
.59456 .69236 Mdot
.49657 .68703 Mdot
.26859 .55404 Mdot
.57451 .32293 Mdot
.59527 .27478 Mdot
.26671 .48298 Mdot
.33395 .43994 Mdot
.58293 .61158 Mdot
.61282 .52639 Mdot
.63672 .59065 Mdot
.28474 .49279 Mdot
.28846 .45603 Mdot
.49978 .56778 Mdot
.44839 .59178 Mdot
.68602 .5076 Mdot
.29283 .50958 Mdot
.62383 .57292 Mdot
.64887 .48101 Mdot
.38538 .30551 Mdot
.61278 .34618 Mdot
.39852 .31514 Mdot
.37488 .30749 Mdot
.80679 .42861 Mdot
.51316 .73752 Mdot
.39538 .36086 Mdot
.40253 .36129 Mdot
.34028 .43664 Mdot
.78902 .44573 Mdot
.38181 .61589 Mdot
.70787 .62797 Mdot
.24375 .49531 Mdot
.66054 .54633 Mdot
.56694 .35786 Mdot
.45263 .60149 Mdot
.45888 .20125 Mdot
.68933 .73549 Mdot
.63751 .51254 Mdot
.25173 .48015 Mdot
.45663 .56859 Mdot
.45045 .57531 Mdot
.44695 .76973 Mdot
.62476 .56863 Mdot
.27585 .45683 Mdot
.78275 .4405 Mdot
.37082 .29228 Mdot
.32093 .34461 Mdot
.5446 .30656 Mdot
.63343 .5767 Mdot
.57509 .36503 Mdot
.36056 .35338 Mdot
.3994 .62214 Mdot
.39415 .64301 Mdot
.61083 .56735 Mdot
.6368 .66267 Mdot
.35047 .46356 Mdot
.59294 .55081 Mdot
.61971 .52281 Mdot
.4652 .56432 Mdot
.64247 .50489 Mdot
.67864 .53646 Mdot
.61906 .52707 Mdot
.44303 .57761 Mdot
.38949 .30769 Mdot
.79125 .42015 Mdot
.4526 .58102 Mdot
.59833 .59417 Mdot
.35949 .34767 Mdot
.58195 .57393 Mdot
.38195 .3547 Mdot
.31901 .36316 Mdot
.40098 .35162 Mdot
.395 .63868 Mdot
.25601 .466 Mdot
.74713 .30863 Mdot
.60507 .32888 Mdot
.36799 .35717 Mdot
.41181 .6317 Mdot
.38651 .35412 Mdot
.2434 .50152 Mdot
.35042 .3039 Mdot
.55983 .38008 Mdot
.46463 .72254 Mdot
.80483 .45079 Mdot
.37964 .29286 Mdot
.26716 .46202 Mdot
.6005 .3265 Mdot
.32869 .37678 Mdot
.59662 .5732 Mdot
.39762 .64179 Mdot
.63265 .5698 Mdot
.39541 .33742 Mdot
.24461 .48921 Mdot
.73312 .31323 Mdot
.38994 .64078 Mdot
.74914 .27994 Mdot
.2956 .50928 Mdot
.6178 .54424 Mdot
.35816 .3413 Mdot
.3559 .3934 Mdot
.379 .31421 Mdot
.56755 .73091 Mdot
.50879 .55927 Mdot
.34949 .61528 Mdot
.58189 .33208 Mdot
.49836 .57488 Mdot
.55212 .83933 Mdot
.49625 .29905 Mdot
.5916 .36791 Mdot
.32107 .48301 Mdot
.61774 .55839 Mdot
.64929 .50502 Mdot
.47576 .58192 Mdot
.58855 .30473 Mdot
.64996 .50711 Mdot
.48588 .54734 Mdot
.50269 .75341 Mdot
.54364 .30611 Mdot
.27542 .52916 Mdot
.64737 .58829 Mdot
.36102 .32136 Mdot
.36049 .33841 Mdot
.49565 .54605 Mdot
.40171 .32328 Mdot
.60092 .59372 Mdot
.59168 .32573 Mdot
.59289 .62986 Mdot
.36917 .62519 Mdot
.52398 .28541 Mdot
.44263 .60901 Mdot
.41365 .63864 Mdot
.67841 .55889 Mdot
.2699 .48255 Mdot
.32654 .26544 Mdot
.60199 .55219 Mdot
.59581 .35282 Mdot
.62685 .53455 Mdot
.64648 .50548 Mdot
.60449 .53456 Mdot
.26274 .51329 Mdot
.508 .72228 Mdot
.62457 .5734 Mdot
.3682 .36566 Mdot
.63749 .6502 Mdot
.58923 .59812 Mdot
.40204 .5951 Mdot
.62423 .65563 Mdot
.37611 .37986 Mdot
.55464 .34642 Mdot
.27259 .48463 Mdot
.58215 .34923 Mdot
.62282 .36943 Mdot
.57662 .32248 Mdot
.5358 .32015 Mdot
.64893 .47303 Mdot
.3503 .22187 Mdot
.72427 .34721 Mdot
.80817 .45122 Mdot
.61958 .37607 Mdot
.25709 .30299 Mdot
.59393 .36974 Mdot
.57627 .32209 Mdot
.5506 .19764 Mdot
.5685 .32937 Mdot
.63612 .54888 Mdot
.6359 .53322 Mdot
.78611 .55154 Mdot
.35647 .52296 Mdot
.67135 .56405 Mdot
.44283 .5764 Mdot
.37838 .65976 Mdot
.52968 .31827 Mdot
.46826 .57165 Mdot
.49162 .71543 Mdot
.48362 .54278 Mdot
.63883 .558 Mdot
.62885 .58358 Mdot
.57863 .58861 Mdot
.58414 .79386 Mdot
.36348 .52648 Mdot
.57876 .31073 Mdot
.59247 .60644 Mdot
.4562 .32975 Mdot
.62849 .58817 Mdot
.62377 .53355 Mdot
.66844 .49083 Mdot
.27252 .48353 Mdot
.60211 .38936 Mdot
.46975 .58857 Mdot
.51678 .28875 Mdot
.65097 .57974 Mdot
.45783 .60447 Mdot
.38252 .66447 Mdot
.62548 .5615 Mdot
.57224 .32032 Mdot
.64779 .50609 Mdot
.59947 .38372 Mdot
.5819 .32708 Mdot
.68291 .53043 Mdot
.5341 .31247 Mdot
.60255 .38736 Mdot
.61209 .52732 Mdot
.2378 .49561 Mdot
.55053 .25413 Mdot
.62795 .55152 Mdot
.38428 .64245 Mdot
.6542 .56365 Mdot
.37917 .61597 Mdot
.46444 .55101 Mdot
.46269 .56398 Mdot
.75032 .55549 Mdot
.30429 .4741 Mdot
.41881 .60877 Mdot
.2989 .4507 Mdot
.61027 .60705 Mdot
.62756 .33513 Mdot
.36186 .29741 Mdot
.316 .44174 Mdot
.46588 .56286 Mdot
.413 .72078 Mdot
.63961 .63707 Mdot
.40411 .34533 Mdot
.60097 .37613 Mdot
.78034 .41884 Mdot
.48115 .58778 Mdot
.27218 .5296 Mdot
.25938 .52213 Mdot
.46796 .34409 Mdot
.57108 .20712 Mdot
.62503 .54434 Mdot
.47003 .5929 Mdot
.59208 .46728 Mdot
.47944 .56869 Mdot
.49368 .57401 Mdot
.29625 .49715 Mdot
.66989 .5676 Mdot
.50977 .75805 Mdot
.27423 .50479 Mdot
.36895 .63964 Mdot
.57644 .36046 Mdot
.40193 .61645 Mdot
.46086 .23198 Mdot
.74229 .32007 Mdot
.27243 .49839 Mdot
.44629 .5738 Mdot
.66503 .54533 Mdot
.56357 .33349 Mdot
.65016 .36021 Mdot
.61068 .36738 Mdot
.36247 .64844 Mdot
.30687 .47302 Mdot
.17178 .55668 Mdot
.64591 .5692 Mdot
.59263 .33496 Mdot
.39001 .66754 Mdot
.6597 .5656 Mdot
.36509 .34612 Mdot
.64859 .5079 Mdot
.59835 .33727 Mdot
.66167 .49728 Mdot
.58159 .3314 Mdot
.25236 .51441 Mdot
.61276 .56022 Mdot
.61376 .57902 Mdot
.41892 .73639 Mdot
.37122 .64985 Mdot
.60674 .38336 Mdot
.52499 .73128 Mdot
.6469 .5205 Mdot
.45847 .77783 Mdot
.62056 .57379 Mdot
.80426 .4547 Mdot
.50635 .53308 Mdot
.48405 .54644 Mdot
.62971 .53226 Mdot
.62578 .55419 Mdot
.6482 .36713 Mdot
.72377 .35428 Mdot
.73922 .33152 Mdot
.36231 .33755 Mdot
.60045 .37296 Mdot
.27821 .50195 Mdot
.31283 .4867 Mdot
.25768 .48172 Mdot
.36237 .63038 Mdot
.58051 .60639 Mdot
.64112 .54229 Mdot
.3972 .3746 Mdot
.37647 .65693 Mdot
.58768 .33887 Mdot
.3927 .63232 Mdot
.50809 .73175 Mdot
.38236 .64528 Mdot
.50044 .56099 Mdot
.19638 .38753 Mdot
.64778 .4801 Mdot
.37486 .63738 Mdot
.61146 .33966 Mdot
.64629 .65226 Mdot
.68832 .54139 Mdot
.74537 .29755 Mdot
.39692 .6524 Mdot
.32143 .4866 Mdot
.67076 .57044 Mdot
.57273 .70016 Mdot
.38471 .35113 Mdot
.40334 .61677 Mdot
.39945 .3319 Mdot
.63869 .51119 Mdot
.61242 .27408 Mdot
.6007 .34999 Mdot
.38625 .30463 Mdot
.63101 .52856 Mdot
.40365 .6173 Mdot
.26863 .49709 Mdot
.78805 .44583 Mdot
.32373 .3468 Mdot
.48934 .58826 Mdot
.44551 .7666 Mdot
.28702 .46301 Mdot
.79146 .46478 Mdot
.40208 .33955 Mdot
.58707 .60512 Mdot
.65837 .49094 Mdot
.67104 .53656 Mdot
.28892 .49801 Mdot
.26493 .49283 Mdot
.30202 .42565 Mdot
.61186 .57892 Mdot
.67468 .49749 Mdot
.5501 .33391 Mdot
.30511 .4666 Mdot
.57694 .3229 Mdot
.57511 .30084 Mdot
.28494 .50818 Mdot
.60677 .37944 Mdot
.38188 .63131 Mdot
.53515 .74815 Mdot
.40176 .3431 Mdot
.36878 .32295 Mdot
.2728 .49643 Mdot
.29655 .47353 Mdot
.26992 .48198 Mdot
.65331 .51154 Mdot
.58129 .32497 Mdot
.60571 .58176 Mdot
.63784 .5742 Mdot
.68826 .53615 Mdot
.56451 .30466 Mdot
.59848 .5668 Mdot
.59625 .62536 Mdot
.37171 .66428 Mdot
.25309 .49665 Mdot
.38678 .32254 Mdot
.53394 .613 Mdot
.36926 .36837 Mdot
.64992 .52455 Mdot
.56283 .25329 Mdot
.59572 .3742 Mdot
.38606 .6503 Mdot
.62429 .65729 Mdot
.39042 .64339 Mdot
.38464 .30536 Mdot
.54811 .33273 Mdot
.48269 .72859 Mdot
.60576 .57434 Mdot
.5161 .73193 Mdot
.33242 .7181 Mdot
.52486 .35632 Mdot
.38702 .32959 Mdot
.66855 .50554 Mdot
.4935 .54284 Mdot
.64947 .46934 Mdot
.63562 .5432 Mdot
.5886 .60038 Mdot
.56497 .68254 Mdot
.64548 .52701 Mdot
.60602 .31915 Mdot
.61699 .64285 Mdot
.44206 .5892 Mdot
.68145 .55665 Mdot
.36686 .2287 Mdot
.67336 .55792 Mdot
.60814 .57412 Mdot
.65116 .54624 Mdot
.61387 .53622 Mdot
.56597 .30658 Mdot
.60164 .63995 Mdot
.36321 .35689 Mdot
.53484 .74882 Mdot
.3997 .34734 Mdot
.27828 .49295 Mdot
.46191 .59788 Mdot
.57291 .37392 Mdot
.38984 .64405 Mdot
.39097 .49583 Mdot
.57397 .70908 Mdot
.23975 .50104 Mdot
.40715 .7245 Mdot
.41153 .61789 Mdot
.48995 .57522 Mdot
.37544 .61382 Mdot
.29284 .49798 Mdot
.36766 .35046 Mdot
.61295 .55362 Mdot
.59073 .31739 Mdot
.60799 .34015 Mdot
.67981 .55927 Mdot
.53805 .25711 Mdot
.3641 .33107 Mdot
.28802 .43475 Mdot
.63388 .53973 Mdot
.64174 .52255 Mdot
.59525 .38274 Mdot
.26468 .47317 Mdot
.63706 .63806 Mdot
.37948 .62087 Mdot
.6322 .58829 Mdot
.444 .58711 Mdot
.50951 .73184 Mdot
.36155 .34018 Mdot
.48678 .5544 Mdot
.66888 .55098 Mdot
.50249 .73613 Mdot
.6616 .50628 Mdot
.53763 .54611 Mdot
.23942 .48282 Mdot
.68429 .53331 Mdot
.61671 .58269 Mdot
.54447 .30595 Mdot
.40235 .33497 Mdot
.59168 .35608 Mdot
.55907 .37144 Mdot
.46367 .56352 Mdot
.38417 .31267 Mdot
.62106 .5295 Mdot
.41081 .36121 Mdot
.64406 .50728 Mdot
.64087 .56783 Mdot
.38888 .33202 Mdot
.57352 .33136 Mdot
.41559 .21942 Mdot
.7903 .4191 Mdot
.63258 .5135 Mdot
.65697 .56295 Mdot
.3564 .52336 Mdot
.45227 .60186 Mdot
.60169 .571 Mdot
.60752 .33263 Mdot
.65739 .56768 Mdot
.41191 .35013 Mdot
.39837 .62884 Mdot
.5986 .35619 Mdot
.26399 .47124 Mdot
.25641 .51568 Mdot
.22949 .49525 Mdot
.50092 .56225 Mdot
.64139 .50503 Mdot
.55718 .29872 Mdot
.57035 .29874 Mdot
.52989 .7105 Mdot
.25265 .50009 Mdot
.39282 .62365 Mdot
.64605 .59048 Mdot
.45597 .59525 Mdot
.35981 .33145 Mdot
.66577 .18437 Mdot
.48483 .73112 Mdot
.36522 .66483 Mdot
.52136 .57576 Mdot
.46946 .56406 Mdot
.66109 .54061 Mdot
.40402 .62083 Mdot
.28314 .50826 Mdot
.65291 .50384 Mdot
.53097 .54776 Mdot
.32296 .48172 Mdot
.28362 .47338 Mdot
.40772 .36764 Mdot
.2523 .47465 Mdot
.39994 .61057 Mdot
.49809 .55617 Mdot
.60586 .35519 Mdot
.62393 .56519 Mdot
.45754 .58102 Mdot
.24804 .50148 Mdot
.486 .58268 Mdot
.63014 .53761 Mdot
.5891 .37716 Mdot
.24988 .48891 Mdot
.64012 .55414 Mdot
.63711 .47014 Mdot
.74032 .30872 Mdot
.24451 .487 Mdot
.61015 .59144 Mdot
.47001 .48822 Mdot
.28097 .4757 Mdot
.29245 .49528 Mdot
.67993 .5313 Mdot
.40871 .62308 Mdot
.64225 .58064 Mdot
.36652 .34382 Mdot
.51461 .72491 Mdot
.38975 .3118 Mdot
.44626 .77085 Mdot
.68502 .54531 Mdot
.67488 .48843 Mdot
.62462 .33287 Mdot
.42507 .61033 Mdot
.51883 .79621 Mdot
.67249 .5427 Mdot
.626 .3889 Mdot
.50912 .71985 Mdot
.47166 .71322 Mdot
.60937 .41936 Mdot
.39277 .61387 Mdot
.38941 .34722 Mdot
.61252 .57262 Mdot
.38431 .23516 Mdot
.38683 .61686 Mdot
.44826 .77131 Mdot
.59272 .57969 Mdot
.59281 .34391 Mdot
.62845 .54332 Mdot
.60477 .34939 Mdot
.66374 .55619 Mdot
.73718 .30584 Mdot
.35036 .46286 Mdot
.5679 .73004 Mdot
.48892 .57254 Mdot
.35598 .39338 Mdot
.80528 .45077 Mdot
.38587 .62904 Mdot
.66343 .49795 Mdot
.47667 .56194 Mdot
.37423 .35889 Mdot
.40436 .27852 Mdot
.26638 .48228 Mdot
.37088 .36742 Mdot
.57671 .34865 Mdot
.23863 .51208 Mdot
.49839 .57442 Mdot
.6741 .48641 Mdot
.40532 .61935 Mdot
.38309 .31294 Mdot
.62363 .5597 Mdot
.66432 .5302 Mdot
.3399 .51171 Mdot
.25466 .69663 Mdot
.58082 .29654 Mdot
.74826 .27269 Mdot
.54844 .33284 Mdot
.36789 .64941 Mdot
.23691 .49841 Mdot
.64997 .55238 Mdot
.65654 .57996 Mdot
.28441 .4722 Mdot
.56213 .33828 Mdot
.41698 .61348 Mdot
.34791 .61725 Mdot
.40484 .36576 Mdot
.29441 .72218 Mdot
.60052 .35716 Mdot
.29258 .72059 Mdot
.21238 .46441 Mdot
.62544 .24686 Mdot
.50955 .79371 Mdot
.37995 .33217 Mdot
.29366 .722 Mdot
.59274 .33996 Mdot
.64745 .53375 Mdot
.47256 .55666 Mdot
.50392 .56124 Mdot
.57979 .36923 Mdot
.28329 .4898 Mdot
.40824 .61485 Mdot
.62659 .54637 Mdot
.55675 .51062 Mdot
.65087 .35827 Mdot
.30621 .4841 Mdot
.4739 .57427 Mdot
.38041 .32208 Mdot
.65918 .56418 Mdot
.36665 .66001 Mdot
.37943 .33361 Mdot
.47067 .5506 Mdot
.56102 .72015 Mdot
.60507 .59095 Mdot
.63009 .66091 Mdot
.38211 .35165 Mdot
.49867 .59675 Mdot
.6176 .58089 Mdot
.40206 .33921 Mdot
.48689 .53969 Mdot
.42386 .38979 Mdot
.63225 .62458 Mdot
.49591 .29948 Mdot
.25619 .52908 Mdot
.24228 .48417 Mdot
.18968 .53741 Mdot
.28504 .55939 Mdot
.39173 .36093 Mdot
.46098 .57412 Mdot
.23844 .68349 Mdot
.40165 .32818 Mdot
.61007 .54417 Mdot
.614 .56595 Mdot
.78226 .43991 Mdot
.46244 .55487 Mdot
.49375 .56081 Mdot
.61894 .26584 Mdot
.58389 .57537 Mdot
.47131 .57476 Mdot
.62 .579 Mdot
.5754 .31212 Mdot
.37737 .32606 Mdot
.71175 .76423 Mdot
.40157 .30749 Mdot
.62191 .51272 Mdot
.24367 .49425 Mdot
.25234 .52704 Mdot
.62626 .56253 Mdot
.46065 .48088 Mdot
.82846 .63075 Mdot
.61347 .56763 Mdot
.62481 .65742 Mdot
.44122 .76657 Mdot
.68453 .54962 Mdot
.61597 .35667 Mdot
.45461 .56397 Mdot
.56261 .30242 Mdot
.38419 .33545 Mdot
.39234 .61413 Mdot
.42559 .61361 Mdot
.38848 .34747 Mdot
.66289 .57231 Mdot
.43724 .6085 Mdot
.63335 .56426 Mdot
.64976 .53851 Mdot
.50057 .73179 Mdot
.36054 .65596 Mdot
.27718 .48297 Mdot
.394 .64139 Mdot
.57295 .32385 Mdot
.71056 .23142 Mdot
.38925 .62965 Mdot
.78857 .44537 Mdot
.52206 .72784 Mdot
.24427 .68544 Mdot
.60833 .34529 Mdot
.3705 .62244 Mdot
.39126 .3471 Mdot
.49883 .69657 Mdot
.78984 .483 Mdot
.37136 .36941 Mdot
.6523 .54216 Mdot
.5697 .30231 Mdot
.55568 .35637 Mdot
.35806 .35251 Mdot
.60613 .36451 Mdot
.63028 .60918 Mdot
.60531 .53697 Mdot
.36338 .35805 Mdot
.5534 .79967 Mdot
.37441 .3158 Mdot
.8023 .41794 Mdot
.63546 .50939 Mdot
.59701 .35417 Mdot
.8102 .45908 Mdot
.54611 .33747 Mdot
.49342 .54991 Mdot
.60763 .55378 Mdot
.39079 .6263 Mdot
.52897 .72046 Mdot
.25398 .47728 Mdot
.5284 .34499 Mdot
.60141 .3329 Mdot
.35565 .34341 Mdot
.60597 .36347 Mdot
.60142 .37731 Mdot
.38336 .30441 Mdot
.59801 .37255 Mdot
.65201 .57955 Mdot
.75323 .30312 Mdot
.60862 .36659 Mdot
.37932 .34406 Mdot
.36306 .64777 Mdot
.61225 .3406 Mdot
.32957 .42686 Mdot
.65164 .58702 Mdot
.29552 .51691 Mdot
.35228 .63373 Mdot
.56924 .30772 Mdot
.38677 .62706 Mdot
.24765 .49808 Mdot
.40745 .64352 Mdot
.41449 .36938 Mdot
.4051 .37733 Mdot
.49807 .5249 Mdot
.40911 .40005 Mdot
.56915 .32849 Mdot
.23748 .51167 Mdot
.62943 .59194 Mdot
.6396 .53771 Mdot
.35429 .65165 Mdot
.61028 .38598 Mdot
.53677 .25453 Mdot
.46836 .5728 Mdot
.52342 .28627 Mdot
.36216 .33613 Mdot
.29287 .43589 Mdot
.48115 .72968 Mdot
.3326 .32249 Mdot
.44168 .58985 Mdot
.47094 .56288 Mdot
.6332 .55817 Mdot
.42332 .74228 Mdot
.3981 .61098 Mdot
.24393 .32089 Mdot
.65989 .51736 Mdot
.28757 .47013 Mdot
.66046 .55178 Mdot
.58518 .61479 Mdot
.67531 .53989 Mdot
.3628 .66284 Mdot
.38826 .37072 Mdot
.60583 .32963 Mdot
.37423 .61867 Mdot
.25749 .51674 Mdot
.59398 .71364 Mdot
.60143 .5741 Mdot
.62789 .59636 Mdot
.28433 .48128 Mdot
.58162 .31842 Mdot
.27252 .49152 Mdot
.40157 .34327 Mdot
.3894 .63233 Mdot
.65172 .50834 Mdot
.46095 .5561 Mdot
.31315 .49599 Mdot
.36963 .35969 Mdot
.23523 .50094 Mdot
.4136 .32928 Mdot
.46871 .56164 Mdot
.6609 .59186 Mdot
.27966 .45445 Mdot
.45029 .58892 Mdot
.74637 .42928 Mdot
.56263 .71451 Mdot
.62752 .41062 Mdot
.28553 .48938 Mdot
.26631 .55116 Mdot
.37939 .33732 Mdot
.40623 .31988 Mdot
.80285 .41392 Mdot
.85046 .57685 Mdot
.6373 .64752 Mdot
.51536 .26592 Mdot
.40153 .34431 Mdot
.3761 .35193 Mdot
.27327 .48858 Mdot
.57095 .33551 Mdot
.6136 .31563 Mdot
.24743 .51919 Mdot
.48446 .7867 Mdot
.58788 .33865 Mdot
.78976 .54459 Mdot
.30486 .49885 Mdot
.60624 .53219 Mdot
.73347 .31102 Mdot
.37786 .66315 Mdot
.44137 .76103 Mdot
.3552 .30026 Mdot
.64142 .54979 Mdot
.35398 .22172 Mdot
.26381 .48429 Mdot
.47056 .59051 Mdot
.44712 .35393 Mdot
.64474 .51796 Mdot
.65995 .54841 Mdot
.65447 .57432 Mdot
.37093 .61168 Mdot
.72201 .37722 Mdot
.64512 .55063 Mdot
.56569 .72043 Mdot
.57972 .57567 Mdot
.30649 .51826 Mdot
.39427 .64057 Mdot
.40377 .71986 Mdot
.33725 .46296 Mdot
.51302 .29069 Mdot
.58936 .60248 Mdot
.41009 .34271 Mdot
.58813 .62049 Mdot
.3907 .33208 Mdot
.37735 .37806 Mdot
.31045 .74731 Mdot
.60174 .31693 Mdot
.6557 .51475 Mdot
.30278 .48684 Mdot
.61372 .31507 Mdot
.58855 .62242 Mdot
.72431 .24227 Mdot
.35455 .335 Mdot
.90149 .49642 Mdot
.40669 .32542 Mdot
.49692 .57317 Mdot
.57942 .35571 Mdot
.63855 .38049 Mdot
.51551 .73316 Mdot
.57598 .32436 Mdot
.31877 .55217 Mdot
.56871 .29707 Mdot
.40695 .7982 Mdot
.57045 .39412 Mdot
.37431 .34007 Mdot
.35686 .34871 Mdot
.57973 .60512 Mdot
.63906 .58247 Mdot
.50529 .75559 Mdot
.46928 .57286 Mdot
.59704 .58771 Mdot
.27419 .50519 Mdot
.32092 .42374 Mdot
.35511 .25655 Mdot
.59581 .3722 Mdot
.37535 .3631 Mdot
.65956 .54961 Mdot
.63897 .50877 Mdot
.63137 .53432 Mdot
.34362 .44253 Mdot
.79204 .5545 Mdot
.63663 .57236 Mdot
.57882 .60074 Mdot
.24184 .50705 Mdot
.3401 .51404 Mdot
.58678 .21548 Mdot
.30278 .73479 Mdot
.67612 .55929 Mdot
.37065 .65436 Mdot
.35854 .64827 Mdot
.58317 .60526 Mdot
.59598 .43867 Mdot
.42855 .66345 Mdot
.62399 .55875 Mdot
.59502 .70676 Mdot
.28772 .52579 Mdot
.49639 .54456 Mdot
.24894 .50232 Mdot
.62285 .37636 Mdot
.48307 .54452 Mdot
.28022 .50625 Mdot
.55357 .74909 Mdot
.4589 .56884 Mdot
.4216 .39007 Mdot
.36834 .62589 Mdot
.61918 .57999 Mdot
.7759 .3934 Mdot
.30535 .46646 Mdot
.36843 .34351 Mdot
.58581 .36083 Mdot
.36268 .33838 Mdot
.2254 .53198 Mdot
.46629 .78328 Mdot
.48963 .54909 Mdot
.41045 .34371 Mdot
.63303 .66052 Mdot
.37596 .65576 Mdot
.40449 .32597 Mdot
.6092 .52638 Mdot
.58251 .58943 Mdot
.81687 .62573 Mdot
.64083 .59374 Mdot
.31573 .42306 Mdot
.38879 .31058 Mdot
.48911 .54207 Mdot
.62414 .56638 Mdot
.29421 .51233 Mdot
.46509 .5453 Mdot
.63501 .56374 Mdot
.27754 .46511 Mdot
.61522 .56627 Mdot
.40218 .62914 Mdot
.55156 .30321 Mdot
.50612 .71606 Mdot
.36015 .60237 Mdot
.38757 .61406 Mdot
.57485 .70467 Mdot
.60116 .56699 Mdot
.30337 .55822 Mdot
.59108 .34607 Mdot
.65035 .52529 Mdot
.3981 .76992 Mdot
.57241 .35311 Mdot
.58086 .3452 Mdot
.63997 .50268 Mdot
.41246 .33172 Mdot
.28051 .48254 Mdot
.38442 .65304 Mdot
.32229 .34089 Mdot
.64249 .55313 Mdot
.66643 .5047 Mdot
.38174 .61635 Mdot
.36851 .33469 Mdot
.64539 .51092 Mdot
.47334 .31989 Mdot
.5406 .74336 Mdot
.38086 .30699 Mdot
.58773 .59807 Mdot
.80512 .53369 Mdot
.56712 .3628 Mdot
.35274 .22263 Mdot
.35063 .46305 Mdot
.25862 .52048 Mdot
.4697 .57647 Mdot
.67467 .19454 Mdot
.36222 .64654 Mdot
.51841 .3272 Mdot
.6336 .53724 Mdot
.65362 .55663 Mdot
.57152 .31807 Mdot
.60821 .58237 Mdot
.59755 .37407 Mdot
.33149 .43221 Mdot
.86223 .55938 Mdot
.60711 .34695 Mdot
.60107 .34205 Mdot
.70743 .64526 Mdot
.28876 .44913 Mdot
.57837 .3627 Mdot
.61513 .58304 Mdot
.229 .53888 Mdot
.54876 .53059 Mdot
.41635 .62088 Mdot
.38244 .60586 Mdot
.61617 .35116 Mdot
.79178 .48664 Mdot
.60268 .5342 Mdot
.76718 .51534 Mdot
.42527 .66821 Mdot
.39428 .35904 Mdot
.6763 .51306 Mdot
.46996 .56883 Mdot
.25196 .49259 Mdot
.68776 .5452 Mdot
.62219 .58207 Mdot
.60119 .31988 Mdot
.39209 .65825 Mdot
.39977 .32608 Mdot
.45223 .58979 Mdot
.2256 .52862 Mdot
.37511 .62783 Mdot
.60453 .37911 Mdot
.80725 .44084 Mdot
.44209 .60649 Mdot
.4532 .59445 Mdot
.66105 .53862 Mdot
.68155 .5313 Mdot
.4401 .59753 Mdot
.38788 .34594 Mdot
.26307 .52314 Mdot
.46782 .58872 Mdot
.51726 .69404 Mdot
.5262 .76184 Mdot
.67204 .54467 Mdot
.61018 .33631 Mdot
.37439 .3605 Mdot
.49472 .55467 Mdot
.23262 .67731 Mdot
.66281 .58175 Mdot
.79061 .54563 Mdot
.39981 .59818 Mdot
.46579 .56921 Mdot
.61212 .31328 Mdot
.3891 .64757 Mdot
.63551 .50953 Mdot
.56593 .72454 Mdot
.59455 .58505 Mdot
.58726 .60534 Mdot
.28693 .50546 Mdot
.39665 .33206 Mdot
.50189 .52414 Mdot
.25441 .49475 Mdot
.58166 .34785 Mdot
.76397 .52882 Mdot
.57764 .30279 Mdot
.57741 .29936 Mdot
.5328 .32329 Mdot
.36611 .33094 Mdot
.67354 .19282 Mdot
.44262 .60254 Mdot
.6181 .55043 Mdot
.39191 .36648 Mdot
.58352 .36759 Mdot
.60009 .56214 Mdot
.59603 .37424 Mdot
.60955 .38359 Mdot
.59542 .58894 Mdot
.58745 .56162 Mdot
.57 .72252 Mdot
.79936 .52694 Mdot
.39817 .63984 Mdot
.56321 .33836 Mdot
.79626 .51197 Mdot
.64913 .55351 Mdot
.6307 .5839 Mdot
.585 .61944 Mdot
.37991 .61356 Mdot
.75253 .55084 Mdot
.63919 .5366 Mdot
.4157 .7375 Mdot
.60623 .551 Mdot
.61285 .38664 Mdot
.36324 .39264 Mdot
.61896 .51594 Mdot
.23991 .51025 Mdot
.56266 .33567 Mdot
.37937 .66338 Mdot
.61758 .394 Mdot
.65253 .47599 Mdot
.38492 .35636 Mdot
.59837 .33744 Mdot
.25331 .52379 Mdot
.36968 .33806 Mdot
.37471 .31586 Mdot
.58702 .62327 Mdot
.27498 .52239 Mdot
.39148 .65917 Mdot
.38933 .31807 Mdot
.64 .46538 Mdot
.37298 .34024 Mdot
.69448 .47752 Mdot
.64566 .59616 Mdot
.56464 .72268 Mdot
.46992 .58387 Mdot
.50507 .53064 Mdot
.38974 .31365 Mdot
.37858 .62044 Mdot
.64655 .51115 Mdot
.60653 .37056 Mdot
.36505 .65242 Mdot
.73099 .31915 Mdot
.24846 .52404 Mdot
.55448 .35065 Mdot
.32408 .34198 Mdot
.56641 .34609 Mdot
.44421 .76449 Mdot
.37339 .66664 Mdot
.46786 .59431 Mdot
.49766 .71976 Mdot
.48105 .57035 Mdot
.6797 .56501 Mdot
.64827 .51163 Mdot
.65554 .5774 Mdot
.24328 .49422 Mdot
.37731 .60825 Mdot
.61209 .35941 Mdot
.52934 .5059 Mdot
.36714 .3338 Mdot
.62021 .64822 Mdot
.47092 .58938 Mdot
.63889 .51054 Mdot
.58697 .36818 Mdot
.60352 .38803 Mdot
.72331 .35975 Mdot
.27775 .47487 Mdot
.52991 .52217 Mdot
.67351 .54478 Mdot
.54071 .50809 Mdot
.38874 .31294 Mdot
.4898 .30805 Mdot
.29765 .51686 Mdot
.90231 .49331 Mdot
.2549 .49702 Mdot
.52136 .56751 Mdot
.57918 .37225 Mdot
.38214 .64019 Mdot
.66599 .57041 Mdot
.5407 .30906 Mdot
.59683 .2979 Mdot
.37378 .67834 Mdot
.38777 .64497 Mdot
.33281 .39158 Mdot
.39791 .35829 Mdot
.449 .59052 Mdot
.60717 .54926 Mdot
.59447 .57471 Mdot
.62183 .58955 Mdot
.38271 .36625 Mdot
.59084 .55721 Mdot
.35307 .39012 Mdot
.64737 .4792 Mdot
.39985 .7718 Mdot
.29541 .48774 Mdot
.17667 .46567 Mdot
.56851 .30604 Mdot
.75662 .5439 Mdot
.69033 .48018 Mdot
.55975 .71719 Mdot
.39321 .37121 Mdot
.48104 .54074 Mdot
.27717 .48649 Mdot
.34805 .26538 Mdot
.29656 .48717 Mdot
.76387 .70853 Mdot
.78212 .43826 Mdot
.37987 .40016 Mdot
.59575 .57919 Mdot
.2873 .50906 Mdot
.79509 .49104 Mdot
.46527 .58874 Mdot
.43696 .60801 Mdot
.64124 .47804 Mdot
.73904 .32799 Mdot
.39941 .63784 Mdot
.671 .56391 Mdot
.56615 .30309 Mdot
.66242 .57437 Mdot
.66683 .5701 Mdot
.63361 .53576 Mdot
.37122 .30744 Mdot
.64658 .59648 Mdot
.64468 .58202 Mdot
.17156 .58896 Mdot
.43957 .63216 Mdot
.24753 .47722 Mdot
.6399 .38072 Mdot
.37661 .65694 Mdot
.62225 .37742 Mdot
.50247 .71736 Mdot
.403 .31465 Mdot
.72225 .36233 Mdot
.61599 .52468 Mdot
.52367 .32713 Mdot
.40651 .31515 Mdot
.41029 .62407 Mdot
.47309 .56584 Mdot
.46564 .19728 Mdot
.29778 .44996 Mdot
.48897 .56046 Mdot
.27107 .46894 Mdot
.67039 .48454 Mdot
.60465 .35794 Mdot
.47972 .57074 Mdot
.39746 .32359 Mdot
.297 .49531 Mdot
.5745 .7109 Mdot
.65164 .57086 Mdot
.28714 .49195 Mdot
.45901 .57895 Mdot
.52829 .72211 Mdot
.50977 .72121 Mdot
.29108 .5065 Mdot
.39786 .37556 Mdot
.37756 .318 Mdot
.37232 .65912 Mdot
.58511 .37908 Mdot
.58673 .31652 Mdot
.37207 .32933 Mdot
.33313 .26932 Mdot
.64049 .55291 Mdot
.64284 .56889 Mdot
.48693 .72028 Mdot
.62678 .52789 Mdot
.35445 .53477 Mdot
.48616 .56308 Mdot
.59572 .31932 Mdot
.64719 .51152 Mdot
.64216 .51232 Mdot
.67418 .55784 Mdot
.48692 .7891 Mdot
.24513 .49356 Mdot
.5898 .55416 Mdot
.40388 .61931 Mdot
.73716 .32245 Mdot
.63567 .58958 Mdot
.42278 .59504 Mdot
.57853 .37257 Mdot
.44884 .31364 Mdot
.36872 .34533 Mdot
.30415 .47963 Mdot
.3035 .48423 Mdot
.33509 .72353 Mdot
.57253 .30932 Mdot
.48859 .5614 Mdot
.32328 .48226 Mdot
.49912 .56019 Mdot
.38509 .64664 Mdot
.63913 .62603 Mdot
.34769 .53875 Mdot
.24881 .47647 Mdot
.40171 .30166 Mdot
.65436 .52323 Mdot
.63553 .58841 Mdot
.5233 .27379 Mdot
.62129 .57546 Mdot
.39498 .62686 Mdot
.40602 .34305 Mdot
.59724 .33887 Mdot
.40262 .6367 Mdot
.40997 .33215 Mdot
.57863 .32136 Mdot
.58012 .57925 Mdot
.60203 .55801 Mdot
.58237 .35363 Mdot
.59986 .38034 Mdot
.63428 .54873 Mdot
.32649 .76972 Mdot
.60318 .32512 Mdot
.58286 .35841 Mdot
.73727 .32404 Mdot
.27572 .45738 Mdot
.45861 .54998 Mdot
.41212 .34457 Mdot
.64714 .5799 Mdot
.29355 .48369 Mdot
.3757 .64515 Mdot
.5991 .32881 Mdot
.68273 .53596 Mdot
.64395 .55698 Mdot
.37269 .65502 Mdot
.38391 .60845 Mdot
.36943 .62896 Mdot
.35847 .35322 Mdot
.61405 .52516 Mdot
.57922 .36001 Mdot
.37514 .36982 Mdot
.3662 .66118 Mdot
.39277 .60784 Mdot
.4421 .8083 Mdot
.63809 .55036 Mdot
.37583 .61083 Mdot
.69857 .22142 Mdot
.56362 .74701 Mdot
.49961 .55143 Mdot
.22987 .50746 Mdot
.23694 .54649 Mdot
.49192 .59743 Mdot
.39701 .33585 Mdot
.61784 .65118 Mdot
.41437 .62392 Mdot
.45866 .58507 Mdot
.64585 .57115 Mdot
.68621 .52373 Mdot
.36548 .64988 Mdot
.46423 .78316 Mdot
.597 .3138 Mdot
.65761 .37404 Mdot
.37804 .65672 Mdot
.29302 .50689 Mdot
.30003 .51654 Mdot
.26162 .49506 Mdot
.67688 .54134 Mdot
.7574 .59248 Mdot
.62998 .45423 Mdot
.73838 .52986 Mdot
.39996 .35488 Mdot
.60493 .38768 Mdot
.74068 .3148 Mdot
.58048 .34256 Mdot
.2626 .47688 Mdot
.3795 .61997 Mdot
.57532 .31577 Mdot
.36677 .32616 Mdot
.38114 .31579 Mdot
.28123 .45414 Mdot
.25211 .50247 Mdot
.27058 .49783 Mdot
.55967 .34598 Mdot
.58632 .37567 Mdot
.59714 .57175 Mdot
.61077 .34741 Mdot
.33326 .44218 Mdot
.33301 .43654 Mdot
.29801 .4551 Mdot
.38413 .34323 Mdot
.58242 .32736 Mdot
.61425 .57775 Mdot
.56156 .67798 Mdot
.31736 .4932 Mdot
.38655 .65947 Mdot
.75335 .30136 Mdot
.84269 .58851 Mdot
.66992 .51514 Mdot
.38968 .35876 Mdot
.49416 .56578 Mdot
.66088 .56985 Mdot
.25794 .52119 Mdot
.48595 .59185 Mdot
.46239 .55688 Mdot
.62416 .594 Mdot
.60413 .59736 Mdot
.37724 .35918 Mdot
.50042 .7149 Mdot
.4579 .58694 Mdot
.59193 .63219 Mdot
.40556 .3505 Mdot
.31012 .49865 Mdot
.18675 .523 Mdot
.5994 .26382 Mdot
.42633 .70537 Mdot
.47529 .54837 Mdot
.66098 .58422 Mdot
.27165 .50842 Mdot
.40583 .6316 Mdot
.268 .506 Mdot
.62017 .37498 Mdot
.27011 .45978 Mdot
.61511 .57205 Mdot
.577 .35834 Mdot
.37865 .31557 Mdot
.48772 .69294 Mdot
.496 .50985 Mdot
.29729 .50949 Mdot
.45573 .5966 Mdot
.58558 .57022 Mdot
.64649 .46542 Mdot
.50482 .53114 Mdot
.62274 .58463 Mdot
.38881 .33124 Mdot
.59268 .37123 Mdot
.36363 .34754 Mdot
.4802 .5383 Mdot
.60549 .42773 Mdot
.36898 .34813 Mdot
.74651 .60598 Mdot
.40763 .6136 Mdot
.47279 .78615 Mdot
.62085 .55887 Mdot
.39694 .32579 Mdot
.62501 .59549 Mdot
.56495 .33203 Mdot
.54274 .75485 Mdot
.54647 .73619 Mdot
.37906 .32569 Mdot
.50954 .5592 Mdot
.52355 .72648 Mdot
.45308 .55464 Mdot
.4004 .34583 Mdot
.57562 .74665 Mdot
.48498 .55735 Mdot
.37449 .63128 Mdot
.39086 .60693 Mdot
.38192 .62391 Mdot
.63927 .57355 Mdot
.81266 .50319 Mdot
.36102 .65335 Mdot
.42621 .29821 Mdot
.399 .62211 Mdot
.51092 .58245 Mdot
.54101 .25311 Mdot
.40079 .61126 Mdot
.62004 .5668 Mdot
.65843 .48945 Mdot
.62152 .6544 Mdot
.27167 .52712 Mdot
.44528 .20761 Mdot
.17089 .58044 Mdot
.65015 .55189 Mdot
.74631 .30505 Mdot
.54742 .30316 Mdot
.47128 .59378 Mdot
.55111 .73001 Mdot
.64313 .66489 Mdot
.57693 .34095 Mdot
.49893 .71787 Mdot
.55548 .34604 Mdot
.48439 .57845 Mdot
.63919 .56952 Mdot
.56324 .33321 Mdot
.52884 .3452 Mdot
.52129 .79656 Mdot
.52821 .27983 Mdot
.58221 .32382 Mdot
.40239 .33461 Mdot
.39549 .34122 Mdot
.38635 .32848 Mdot
.25269 .50965 Mdot
.60166 .33914 Mdot
.58412 .58129 Mdot
.25518 .5175 Mdot
.6497 .54055 Mdot
.37556 .32638 Mdot
.55453 .72795 Mdot
.6003 .34181 Mdot
.62429 .5568 Mdot
.79322 .50094 Mdot
.28514 .46395 Mdot
.37024 .6553 Mdot
.74888 .3023 Mdot
.23254 .50725 Mdot
.41068 .36079 Mdot
.62054 .36677 Mdot
.43575 .63146 Mdot
.60089 .64142 Mdot
.66682 .53967 Mdot
.61056 .55651 Mdot
.61509 .65336 Mdot
.78537 .43492 Mdot
.44621 .5804 Mdot
.25708 .51624 Mdot
.2707 .46049 Mdot
.65282 .58757 Mdot
.60393 .33907 Mdot
.38206 .66838 Mdot
.42074 .60282 Mdot
.53278 .54036 Mdot
.51446 .72843 Mdot
.56546 .72038 Mdot
.6167 .53414 Mdot
.73185 .59137 Mdot
.25649 .52429 Mdot
.50252 .55446 Mdot
.50852 .73033 Mdot
.38248 .6296 Mdot
.64726 .53452 Mdot
.64749 .35582 Mdot
.59765 .3313 Mdot
.28458 .4877 Mdot
.36162 .32058 Mdot
.44072 .60737 Mdot
.29663 .45388 Mdot
.65328 .58722 Mdot
.6433 .51186 Mdot
.40195 .3243 Mdot
.61884 .36882 Mdot
.36854 .63915 Mdot
.25144 .51547 Mdot
.38224 .63653 Mdot
.60331 .36466 Mdot
.59866 .32731 Mdot
.6469 .52895 Mdot
.53156 .51895 Mdot
.30185 .50498 Mdot
.68017 .54484 Mdot
.28388 .49729 Mdot
.3395 .51091 Mdot
.35953 .33332 Mdot
.6486 .52518 Mdot
.62103 .32632 Mdot
.37492 .32489 Mdot
.65244 .5501 Mdot
.6117 .64857 Mdot
.64221 .51098 Mdot
.28718 .50997 Mdot
.41743 .60064 Mdot
.37644 .63303 Mdot
.70985 .51432 Mdot
.72529 .33368 Mdot
.62986 .52354 Mdot
.30305 .46335 Mdot
.6275 .47131 Mdot
.37736 .35586 Mdot
.5701 .35944 Mdot
.1771 .42754 Mdot
.37745 .34428 Mdot
.61758 .56015 Mdot
.39014 .62936 Mdot
.60462 .38182 Mdot
.48855 .54392 Mdot
.46823 .74879 Mdot
.51464 .53758 Mdot
.5342 .52238 Mdot
.44866 .58367 Mdot
.51952 .26438 Mdot
.27021 .50039 Mdot
.58501 .36744 Mdot
.39303 .3553 Mdot
.3815 .35713 Mdot
.2677 .4715 Mdot
.72936 .32725 Mdot
.61519 .23646 Mdot
.69197 .21145 Mdot
.30948 .45975 Mdot
.3893 .62007 Mdot
.54527 .75201 Mdot
.26229 .49337 Mdot
.25129 .47812 Mdot
.345 .46133 Mdot
.51937 .27705 Mdot
.57514 .33153 Mdot
.6452 .55691 Mdot
.74032 .30739 Mdot
.62748 .5405 Mdot
.43069 .70256 Mdot
.37486 .32882 Mdot
.56958 .35865 Mdot
.35909 .42888 Mdot
.68145 .5535 Mdot
.66767 .55586 Mdot
.32753 .42605 Mdot
.47266 .57061 Mdot
.2609 .6976 Mdot
.62175 .54064 Mdot
.25787 .50858 Mdot
.61986 .30194 Mdot
.47644 .58325 Mdot
.79447 .50139 Mdot
.39193 .31165 Mdot
.49212 .55064 Mdot
.47684 .58385 Mdot
.72929 .59826 Mdot
.55305 .33401 Mdot
.58227 .31293 Mdot
.37622 .61273 Mdot
.56628 .25442 Mdot
.39487 .31176 Mdot
.49063 .29204 Mdot
.61641 .58277 Mdot
.38047 .38028 Mdot
.35008 .61438 Mdot
.65029 .54731 Mdot
.58968 .62467 Mdot
.72297 .35912 Mdot
.67609 .52151 Mdot
.66098 .48005 Mdot
.37893 .33948 Mdot
.40222 .7663 Mdot
.58862 .57346 Mdot
.28598 .49091 Mdot
.57005 .3383 Mdot
.55158 .34148 Mdot
.40321 .64083 Mdot
.35573 .46063 Mdot
.8803 .53155 Mdot
.56879 .35657 Mdot
.64956 .57301 Mdot
.37553 .35297 Mdot
.4903 .54628 Mdot
.4702 .58238 Mdot
.51001 .5626 Mdot
.59422 .3304 Mdot
.47235 .58491 Mdot
.52442 .31364 Mdot
.4999 .71728 Mdot
.75877 .5396 Mdot
.38359 .32383 Mdot
.39132 .62246 Mdot
.5412 .5382 Mdot
.3401 .48957 Mdot
.60802 .54702 Mdot
.42931 .70343 Mdot
.54806 .31005 Mdot
.39369 .62465 Mdot
.66452 .56903 Mdot
.44567 .58847 Mdot
.59655 .69625 Mdot
.40818 .64782 Mdot
.44793 .58171 Mdot
.66441 .51245 Mdot
.57057 .32651 Mdot
.49017 .56198 Mdot
.59419 .33756 Mdot
.6679 .56592 Mdot
.43204 .67277 Mdot
.56357 .34252 Mdot
.43079 .2138 Mdot
.44601 .60419 Mdot
.40823 .32217 Mdot
.68716 .5172 Mdot
.67658 .55878 Mdot
.77576 .5675 Mdot
.49594 .55133 Mdot
.37038 .2285 Mdot
.29008 .4948 Mdot
.24624 .69407 Mdot
.23206 .48875 Mdot
.33907 .41723 Mdot
.46457 .32531 Mdot
.68393 .52697 Mdot
.72928 .32905 Mdot
.76363 .58432 Mdot
.39768 .37403 Mdot
.77048 .57653 Mdot
.63931 .58244 Mdot
.66144 .53955 Mdot
.28494 .49617 Mdot
.36107 .37399 Mdot
.63042 .50597 Mdot
.50965 .73043 Mdot
.4113 .623 Mdot
.59006 .35355 Mdot
.63583 .5782 Mdot
.53357 .36516 Mdot
.29711 .50218 Mdot
.63176 .40841 Mdot
.62217 .56245 Mdot
.473 .5702 Mdot
.37121 .37626 Mdot
.38045 .31422 Mdot
.282 .51658 Mdot
.28532 .51614 Mdot
.67544 .56075 Mdot
.36672 .36115 Mdot
.59576 .56545 Mdot
.52478 .72553 Mdot
.45758 .57801 Mdot
.38103 .64977 Mdot
.60805 .57703 Mdot
.64694 .27517 Mdot
.53775 .83747 Mdot
.67623 .54213 Mdot
.5729 .30299 Mdot
.27442 .49517 Mdot
.24887 .48557 Mdot
.5873 .31742 Mdot
.25015 .48427 Mdot
.6596 .37027 Mdot
.81244 .50691 Mdot
.38503 .64426 Mdot
.60814 .4655 Mdot
.39248 .61443 Mdot
.49408 .55198 Mdot
.63658 .5499 Mdot
.27535 .28994 Mdot
.30903 .46028 Mdot
.53407 .61268 Mdot
.37218 .33354 Mdot
.50347 .56084 Mdot
.59864 .54373 Mdot
.35145 .64002 Mdot
.25819 .48754 Mdot
.43664 .59798 Mdot
.63868 .53392 Mdot
.56071 .34348 Mdot
.664 .50292 Mdot
.4922 .57562 Mdot
.49444 .56127 Mdot
.44057 .58245 Mdot
.40999 .33218 Mdot
.60155 .37287 Mdot
.3334 .39371 Mdot
.29037 .4624 Mdot
.59807 .58937 Mdot
.6527 .57278 Mdot
.59623 .38526 Mdot
.61442 .55583 Mdot
.36572 .36183 Mdot
.63961 .16386 Mdot
.37302 .62333 Mdot
.49513 .5473 Mdot
.46071 .23206 Mdot
.44016 .58158 Mdot
.65783 .51022 Mdot
.67514 .66008 Mdot
.65041 .35964 Mdot
.41073 .3286 Mdot
.59677 .60789 Mdot
.24695 .4762 Mdot
.37019 .63708 Mdot
.36589 .32643 Mdot
.60159 .54185 Mdot
.61713 .56943 Mdot
.39203 .62478 Mdot
.35981 .42203 Mdot
.41435 .60816 Mdot
.39657 .35354 Mdot
.50928 .54588 Mdot
.56453 .67694 Mdot
.63464 .55873 Mdot
.48164 .56504 Mdot
.5961 .3673 Mdot
.3931 .36193 Mdot
.72329 .38186 Mdot
.4829 .58018 Mdot
.32363 .3363 Mdot
.38499 .31239 Mdot
.6634 .53713 Mdot
.56799 .31626 Mdot
.55313 .36457 Mdot
.59153 .36847 Mdot
.36279 .7584 Mdot
.32182 .38058 Mdot
.27446 .49836 Mdot
.38282 .34443 Mdot
.29163 .47913 Mdot
.40654 .61186 Mdot
.52495 .75964 Mdot
.2908 .51345 Mdot
.60058 .31083 Mdot
.29669 .48132 Mdot
.59635 .56544 Mdot
.40561 .3162 Mdot
.30609 .49839 Mdot
.61188 .5827 Mdot
.57847 .58848 Mdot
.48848 .56791 Mdot
.38045 .66754 Mdot
.50694 .72281 Mdot
.62325 .55097 Mdot
.47883 .56319 Mdot
.62772 .55566 Mdot
.36536 .36078 Mdot
.47729 .69087 Mdot
.60166 .59337 Mdot
.31015 .46119 Mdot
.48412 .1875 Mdot
.2841 .45551 Mdot
.47653 .48824 Mdot
.64799 .5417 Mdot
.6358 .55568 Mdot
.58557 .5683 Mdot
.75106 .33044 Mdot
.40123 .37616 Mdot
.6671 .58806 Mdot
.23703 .50642 Mdot
.58043 .33604 Mdot
.5748 .31046 Mdot
.65005 .64788 Mdot
.48533 .56219 Mdot
.35925 .35248 Mdot
.63785 .55437 Mdot
.4975 .56742 Mdot
.49575 .74232 Mdot
.5516 .256 Mdot
.33632 .45107 Mdot
.2671 .46851 Mdot
.57632 .3746 Mdot
.24166 .49934 Mdot
.59906 .54473 Mdot
.47626 .58203 Mdot
.3191 .36956 Mdot
.39949 .29061 Mdot
.37059 .63777 Mdot
.65829 .54264 Mdot
.49624 .79129 Mdot
.24211 .50738 Mdot
.27088 .52313 Mdot
.595 .56765 Mdot
.58645 .27437 Mdot
.50078 .8304 Mdot
.38916 .3685 Mdot
.67361 .45275 Mdot
.79044 .39946 Mdot
.70454 .71784 Mdot
.38828 .3498 Mdot
.59184 .62697 Mdot
.26532 .52945 Mdot
.30725 .6957 Mdot
.57878 .33953 Mdot
.36908 .64 Mdot
.61043 .58128 Mdot
.5992 .31069 Mdot
.30868 .45704 Mdot
.61112 .37264 Mdot
.46953 .57512 Mdot
.40544 .3142 Mdot
.24977 .49289 Mdot
.35988 .32115 Mdot
.6256 .33631 Mdot
.38367 .61853 Mdot
.41915 .73557 Mdot
.63982 .4717 Mdot
.72331 .35465 Mdot
.60683 .53218 Mdot
.4433 .63134 Mdot
.59423 .54762 Mdot
.5501 .34127 Mdot
.62027 .56007 Mdot
.58729 .59628 Mdot
.25451 .52834 Mdot
.67064 .54307 Mdot
.61382 .58081 Mdot
.79403 .50535 Mdot
.65666 .54668 Mdot
.67244 .56259 Mdot
.66663 .53842 Mdot
.58339 .30483 Mdot
.63941 .53089 Mdot
.5941 .37774 Mdot
.52124 .33357 Mdot
.28921 .46272 Mdot
.40173 .61003 Mdot
.39925 .61056 Mdot
.44193 .67773 Mdot
.49387 .79059 Mdot
.74008 .31039 Mdot
.58594 .33643 Mdot
.38802 .31365 Mdot
.59628 .57184 Mdot
.45701 .81802 Mdot
.43311 .67345 Mdot
.28229 .52585 Mdot
.30253 .49556 Mdot
.62351 .59133 Mdot
.83404 .60042 Mdot
.61595 .54573 Mdot
.48428 .72999 Mdot
.63821 .57406 Mdot
.64527 .52393 Mdot
.23401 .48833 Mdot
.44307 .76379 Mdot
.5875 .55814 Mdot
.55354 .32578 Mdot
.37025 .6424 Mdot
.48694 .56466 Mdot
.43497 .67563 Mdot
.8065 .42694 Mdot
.63086 .27713 Mdot
.58461 .57077 Mdot
.25106 .51703 Mdot
.59645 .3222 Mdot
.48889 .72061 Mdot
.37647 .36979 Mdot
.47014 .75264 Mdot
.69931 .48167 Mdot
.39192 .36914 Mdot
.37327 .63219 Mdot
.31522 .49609 Mdot
.67443 .55112 Mdot
.27084 .51127 Mdot
.68306 .54882 Mdot
.48678 .74319 Mdot
.38246 .647 Mdot
.56882 .29574 Mdot
.40309 .33307 Mdot
.59476 .30984 Mdot
.62618 .41244 Mdot
.42957 .6774 Mdot
.20642 .65553 Mdot
.29417 .45399 Mdot
.52633 .49883 Mdot
.57804 .36691 Mdot
.66488 .5798 Mdot
.68819 .21078 Mdot
.60033 .35894 Mdot
.56166 .33974 Mdot
.462 .72795 Mdot
.44293 .77082 Mdot
.67629 .53739 Mdot
.60961 .33131 Mdot
.31707 .49038 Mdot
.39127 .64177 Mdot
.62197 .5878 Mdot
.48251 .57687 Mdot
.57378 .31636 Mdot
.25935 .48196 Mdot
.43706 .75566 Mdot
.25418 .50567 Mdot
.57341 .33816 Mdot
.30443 .474 Mdot
.33453 .38936 Mdot
.29204 .51263 Mdot
.60793 .57052 Mdot
.63729 .55532 Mdot
.56004 .38106 Mdot
.59879 .32738 Mdot
.65748 .51004 Mdot
.62542 .54395 Mdot
.58002 .36413 Mdot
.3214 .47591 Mdot
.6524 .31536 Mdot
.65306 .51297 Mdot
.64259 .55434 Mdot
.37634 .61725 Mdot
.52365 .7004 Mdot
.48668 .70433 Mdot
.59871 .56703 Mdot
.38574 .62008 Mdot
.5611 .35168 Mdot
.63118 .55076 Mdot
.43886 .7637 Mdot
.27496 .53197 Mdot
.59561 .55776 Mdot
.48479 .54529 Mdot
.62637 .51164 Mdot
.58205 .79306 Mdot
.58599 .56833 Mdot
.57767 .35038 Mdot
.57182 .34947 Mdot
.29708 .5225 Mdot
.58421 .35389 Mdot
.49526 .54835 Mdot
.37404 .32215 Mdot
.69584 .46613 Mdot
.50351 .55693 Mdot
.44743 .57263 Mdot
.44281 .60256 Mdot
.46137 .59223 Mdot
.41181 .58986 Mdot
.33723 .45057 Mdot
.47252 .55124 Mdot
.59032 .3734 Mdot
.5702 .43063 Mdot
.48638 .53881 Mdot
.36267 .35965 Mdot
.47458 .58481 Mdot
.5975 .55439 Mdot
.57976 .59572 Mdot
.63661 .3797 Mdot
.37666 .37107 Mdot
.4981 .52817 Mdot
.62124 .58767 Mdot
.64925 .35921 Mdot
.63565 .57943 Mdot
.40343 .64696 Mdot
.59856 .34268 Mdot
.24969 .50985 Mdot
.38377 .64984 Mdot
.45314 .58608 Mdot
.36974 .65703 Mdot
.27606 .50584 Mdot
.39341 .32023 Mdot
.61004 .57081 Mdot
.41538 .6289 Mdot
.40412 .61294 Mdot
.67577 .50302 Mdot
.56995 .34854 Mdot
.51804 .53797 Mdot
.63599 .54709 Mdot
.58577 .56628 Mdot
.58637 .31586 Mdot
.34543 .22223 Mdot
.67175 .54969 Mdot
.58732 .62625 Mdot
.54815 .32891 Mdot
.49903 .56789 Mdot
.25216 .51311 Mdot
.68328 .5391 Mdot
.36569 .34517 Mdot
.37128 .3296 Mdot
.30902 .46249 Mdot
.57962 .31426 Mdot
.25032 .48716 Mdot
.68084 .55992 Mdot
.47083 .58689 Mdot
.63009 .58662 Mdot
.31015 .42683 Mdot
.39879 .2178 Mdot
.60469 .38019 Mdot
.28729 .46102 Mdot
.51143 .75099 Mdot
.41264 .33497 Mdot
.30938 .4471 Mdot
.55187 .3277 Mdot
.60594 .32285 Mdot
.58573 .31963 Mdot
.40279 .61571 Mdot
.25292 .4991 Mdot
.61823 .39059 Mdot
.62002 .39006 Mdot
.62792 .51739 Mdot
.61668 .58718 Mdot
.56652 .36185 Mdot
.34102 .47729 Mdot
.37469 .635 Mdot
.23727 .49876 Mdot
.50983 .83287 Mdot
.39194 .3655 Mdot
.79524 .50314 Mdot
.60428 .55199 Mdot
.90555 .48572 Mdot
.61679 .5453 Mdot
.64367 .5762 Mdot
.62283 .37637 Mdot
.39858 .6047 Mdot
.39257 .6378 Mdot
.57646 .36449 Mdot
.61203 .37843 Mdot
.40167 .64573 Mdot
.5334 .68668 Mdot
.55658 .80089 Mdot
.49718 .73513 Mdot
.61021 .37056 Mdot
.68262 .46727 Mdot
.38552 .33293 Mdot
.55078 .30233 Mdot
.34628 .39225 Mdot
.30783 .47669 Mdot
.29638 .50941 Mdot
.39909 .3194 Mdot
.67282 .55321 Mdot
.23826 .48281 Mdot
.60908 .528 Mdot
.38189 .40147 Mdot
.58466 .61277 Mdot
.34048 .78884 Mdot
.61073 .56306 Mdot
.47308 .47825 Mdot
.53012 .25789 Mdot
.65088 .50624 Mdot
.80816 .47457 Mdot
.36661 .64177 Mdot
.55219 .34965 Mdot
.37242 .37312 Mdot
.74064 .30514 Mdot
.63523 .55738 Mdot
.6117 .33936 Mdot
.40423 .34469 Mdot
.38138 .22667 Mdot
.59261 .63203 Mdot
.63839 .51021 Mdot
.67944 .20122 Mdot
.57942 .29633 Mdot
.25213 .51122 Mdot
.66232 .44179 Mdot
.61169 .38385 Mdot
.59893 .63766 Mdot
.31845 .47209 Mdot
.59322 .69111 Mdot
.61425 .35168 Mdot
.41338 .60659 Mdot
.59066 .3486 Mdot
.39137 .65271 Mdot
.61668 .39072 Mdot
.29131 .46512 Mdot
.66314 .54704 Mdot
.28844 .46398 Mdot
.37846 .66228 Mdot
.2913 .45636 Mdot
.37531 .37353 Mdot
.46395 .56332 Mdot
.37623 .3248 Mdot
.53366 .75866 Mdot
.73167 .39888 Mdot
.39577 .33038 Mdot
.68004 .64806 Mdot
.61633 .57216 Mdot
.61077 .39019 Mdot
.24736 .50698 Mdot
.24055 .52323 Mdot
.50932 .72431 Mdot
.57416 .32794 Mdot
.26778 .47479 Mdot
.65015 .47015 Mdot
.34073 .25965 Mdot
.57807 .58482 Mdot
.17411 .4429 Mdot
.5803 .3602 Mdot
.24007 .52106 Mdot
.4857 .72512 Mdot
.61378 .33198 Mdot
.30379 .50239 Mdot
.40087 .33862 Mdot
.36591 .34469 Mdot
.60802 .56327 Mdot
.35358 .33915 Mdot
.27407 .5269 Mdot
.61574 .43219 Mdot
.56688 .35729 Mdot
.40876 .21436 Mdot
.37691 .62177 Mdot
.24322 .49815 Mdot
.45985 .58279 Mdot
.62169 .32803 Mdot
.29385 .47855 Mdot
.87322 .54251 Mdot
.50192 .86156 Mdot
.26506 .47724 Mdot
.59701 .34174 Mdot
.59276 .32705 Mdot
.66833 .51819 Mdot
.51164 .72868 Mdot
.2601 .48593 Mdot
.27166 .29177 Mdot
.56811 .72213 Mdot
.46827 .56084 Mdot
.17116 .58524 Mdot
.58404 .57925 Mdot
.60461 .53536 Mdot
.38968 .36322 Mdot
.66648 .55579 Mdot
.61193 .3767 Mdot
.61775 .54414 Mdot
.36152 .34159 Mdot
.30793 .46308 Mdot
.63261 .55516 Mdot
.37105 .63475 Mdot
.37711 .3616 Mdot
.36837 .35841 Mdot
.30274 .47512 Mdot
.57925 .31555 Mdot
.74088 .29808 Mdot
.25171 .50369 Mdot
.61741 .52152 Mdot
.47364 .56391 Mdot
.66689 .53908 Mdot
.5359 .31073 Mdot
.5571 .35795 Mdot
.2428 .50258 Mdot
.68812 .52812 Mdot
.38178 .34981 Mdot
.25799 .52973 Mdot
.58299 .57807 Mdot
.30571 .50443 Mdot
.50603 .57393 Mdot
.23291 .54157 Mdot
.62771 .33528 Mdot
.4645 .59583 Mdot
.60765 .32294 Mdot
.47267 .55267 Mdot
.33779 .7297 Mdot
.37457 .632 Mdot
.26299 .46433 Mdot
.42335 .21574 Mdot
.28475 .46295 Mdot
.65569 .54782 Mdot
.61501 .56705 Mdot
.28565 .50018 Mdot
.38587 .61806 Mdot
.51147 .58104 Mdot
.41914 .61152 Mdot
.59921 .33659 Mdot
.63606 .66245 Mdot
.45072 .84607 Mdot
.25584 .53244 Mdot
.39802 .3155 Mdot
.60272 .26177 Mdot
.44652 .57499 Mdot
.37711 .37277 Mdot
.37147 .36135 Mdot
.37179 .66121 Mdot
.25402 .47606 Mdot
.56069 .30359 Mdot
.39093 .30839 Mdot
.61837 .357 Mdot
.43218 .75654 Mdot
.47214 .58835 Mdot
.55054 .50714 Mdot
.44608 .58901 Mdot
.50211 .71965 Mdot
.3992 .30857 Mdot
.62616 .57169 Mdot
.52927 .53158 Mdot
.40122 .34706 Mdot
.36355 .65955 Mdot
.58354 .61052 Mdot
.27134 .47306 Mdot
.71476 .23975 Mdot
.607 .5716 Mdot
.64436 .54353 Mdot
.3998 .35592 Mdot
.81097 .45144 Mdot
.55369 .33287 Mdot
.56922 .32786 Mdot
.26987 .49993 Mdot
.46493 .72188 Mdot
.63486 .53365 Mdot
.61295 .57275 Mdot
.2883 .50127 Mdot
.48721 .5586 Mdot
.18643 .62828 Mdot
.64291 .55826 Mdot
.38283 .33914 Mdot
.58742 .62054 Mdot
.3988 .37487 Mdot
.59582 .6046 Mdot
.65699 .55148 Mdot
.63191 .51075 Mdot
.58322 .56919 Mdot
.37852 .32469 Mdot
.4484 .58519 Mdot
.45514 .5587 Mdot
.59564 .37026 Mdot
.63952 .59394 Mdot
.56923 .71991 Mdot
.63903 .55933 Mdot
.36755 .63825 Mdot
.48326 .70646 Mdot
.59305 .58647 Mdot
.63109 .5954 Mdot
.56681 .72597 Mdot
.65812 .57604 Mdot
.40125 .3552 Mdot
.58854 .32649 Mdot
.38099 .35162 Mdot
.40312 .31993 Mdot
.29702 .47818 Mdot
.35967 .64918 Mdot
.68113 .5477 Mdot
.40769 .63184 Mdot
.66369 .52452 Mdot
.48851 .53428 Mdot
.5283 .72326 Mdot
.48527 .73092 Mdot
.39819 .65794 Mdot
.61512 .57473 Mdot
.27389 .50332 Mdot
.24264 .48505 Mdot
.61687 .6504 Mdot
.68816 .54394 Mdot
.35293 .35104 Mdot
.3972 .32658 Mdot
.33316 .43613 Mdot
.19832 .52139 Mdot
.41141 .63613 Mdot
.50616 .58105 Mdot
.58075 .57614 Mdot
.65375 .53907 Mdot
.45152 .57291 Mdot
.28809 .48277 Mdot
.47094 .55238 Mdot
.33682 .45706 Mdot
.38546 .37494 Mdot
.38628 .35746 Mdot
.60919 .56712 Mdot
.82629 .63525 Mdot
.60561 .35989 Mdot
.59236 .32593 Mdot
.36145 .33726 Mdot
.2828 .45578 Mdot
.46987 .57766 Mdot
.74811 .27154 Mdot
.56193 .36454 Mdot
.40315 .60846 Mdot
.65016 .58521 Mdot
.30666 .47143 Mdot
.59703 .37473 Mdot
.41591 .62515 Mdot
.64023 .59777 Mdot
.31784 .46586 Mdot
.63039 .5695 Mdot
.60333 .45789 Mdot
.58224 .37354 Mdot
.52952 .71097 Mdot
.59254 .3035 Mdot
.37744 .32787 Mdot
.40005 .31281 Mdot
.65345 .5503 Mdot
.74231 .26526 Mdot
.60992 .28839 Mdot
.38376 .30549 Mdot
.37967 .61126 Mdot
.45977 .56789 Mdot
.36057 .65255 Mdot
.28304 .49511 Mdot
.3732 .63305 Mdot
.29459 .47786 Mdot
.3202 .4916 Mdot
.56645 .30437 Mdot
.39214 .62521 Mdot
.7877 .46316 Mdot
.47613 .58153 Mdot
.37567 .61024 Mdot
.60608 .58939 Mdot
.66047 .51697 Mdot
.26805 .4812 Mdot
.40928 .62557 Mdot
.68181 .53397 Mdot
.45382 .23416 Mdot
.40671 .32106 Mdot
.37476 .37387 Mdot
.47019 .57552 Mdot
.2562 .52528 Mdot
.5663 .30548 Mdot
.51491 .75289 Mdot
.5804 .29049 Mdot
.61226 .57397 Mdot
.68053 .54763 Mdot
.61311 .31376 Mdot
.56829 .30643 Mdot
.65622 .55398 Mdot
.76591 .52222 Mdot
.45821 .58378 Mdot
.36533 .33988 Mdot
.6011 .33849 Mdot
.60288 .33114 Mdot
.27847 .5244 Mdot
.5702 .32086 Mdot
.53747 .52072 Mdot
.38367 .37449 Mdot
.45772 .55539 Mdot
.38093 .34657 Mdot
.42107 .65027 Mdot
.27807 .47428 Mdot
.40303 .22264 Mdot
.56811 .32808 Mdot
.64897 .51095 Mdot
.56608 .32881 Mdot
.3684 .63008 Mdot
.61196 .34759 Mdot
.54565 .30402 Mdot
.61138 .58081 Mdot
.44911 .58282 Mdot
.49439 .55598 Mdot
.50537 .72495 Mdot
.60286 .36091 Mdot
.67798 .54642 Mdot
.62859 .532 Mdot
.62281 .54663 Mdot
.52375 .72843 Mdot
.58042 .3056 Mdot
.80701 .42926 Mdot
.62183 .39135 Mdot
.58578 .37551 Mdot
.56373 .83926 Mdot
.49746 .55578 Mdot
.45908 .56034 Mdot
.45231 .34148 Mdot
.6446 .55603 Mdot
.25555 .48017 Mdot
.61838 .52142 Mdot
.45265 .57881 Mdot
.60973 .59374 Mdot
.39898 .63907 Mdot
.67675 .5627 Mdot
.47705 .55753 Mdot
.24841 .50316 Mdot
.64198 .51065 Mdot
.63914 .55156 Mdot
.49016 .55944 Mdot
.56382 .33065 Mdot
.59776 .31564 Mdot
.59779 .29148 Mdot
.38786 .65704 Mdot
.39238 .33502 Mdot
.61433 .52577 Mdot
.27164 .50123 Mdot
.25822 .477 Mdot
.59793 .30821 Mdot
.27875 .51478 Mdot
.38781 .35859 Mdot
.64865 .57168 Mdot
.37751 .32619 Mdot
.39734 .64348 Mdot
.59956 .34356 Mdot
.59448 .55135 Mdot
.66098 .49909 Mdot
.57183 .34969 Mdot
.46015 .58628 Mdot
.37065 .62138 Mdot
.29132 .50372 Mdot
.59794 .3813 Mdot
.372 .32583 Mdot
.28446 .52012 Mdot
.647 .5096 Mdot
.67486 .7928 Mdot
.66579 .55536 Mdot
.62792 .53933 Mdot
.6281 .3171 Mdot
.58854 .60171 Mdot
.29099 .46227 Mdot
.5724 .31316 Mdot
.65686 .51498 Mdot
.55815 .74813 Mdot
.37884 .6718 Mdot
.2347 .52915 Mdot
.65007 .57886 Mdot
.77454 .56909 Mdot
.6317 .52304 Mdot
.43827 .21173 Mdot
.52787 .7222 Mdot
.32083 .35081 Mdot
.54231 .5087 Mdot
.37877 .30719 Mdot
.48063 .56156 Mdot
.29715 .4738 Mdot
.76853 .49172 Mdot
.66006 .55804 Mdot
.72065 .36715 Mdot
.59772 .54762 Mdot
.38675 .35281 Mdot
.80398 .4574 Mdot
.25318 .51902 Mdot
.23965 .68575 Mdot
.65208 .5905 Mdot
.55442 .34221 Mdot
.35061 .51209 Mdot
.45688 .56639 Mdot
.44801 .57499 Mdot
.4073 .64243 Mdot
.29788 .43899 Mdot
.51075 .5317 Mdot
.38014 .34938 Mdot
.65121 .53556 Mdot
.67708 .497 Mdot
.35902 .22701 Mdot
.58806 .3687 Mdot
.40485 .33014 Mdot
.24484 .5466 Mdot
.62326 .5743 Mdot
.60447 .32106 Mdot
.57909 .33977 Mdot
.40501 .6303 Mdot
.32321 .3464 Mdot
.29497 .43647 Mdot
.81497 .62233 Mdot
.50027 .52039 Mdot
.28959 .4851 Mdot
.46141 .59544 Mdot
.62301 .51694 Mdot
.43245 .6733 Mdot
.39756 .31381 Mdot
.65075 .54328 Mdot
.72378 .34716 Mdot
.58377 .36014 Mdot
.6379 .56675 Mdot
.37428 .63896 Mdot
.75395 .292 Mdot
.6515 .47485 Mdot
.76089 .53762 Mdot
.31733 .48938 Mdot
.68053 .5453 Mdot
.53607 .52144 Mdot
.49847 .56606 Mdot
.58924 .60351 Mdot
.25104 .50959 Mdot
.45889 .59688 Mdot
.37898 .63796 Mdot
.60106 .37365 Mdot
.47927 .56367 Mdot
.59686 .54912 Mdot
.68309 .54657 Mdot
.37714 .61325 Mdot
.63182 .5121 Mdot
.67996 .44466 Mdot
.49936 .57397 Mdot
.29481 .50824 Mdot
.60316 .38284 Mdot
.67763 .54195 Mdot
.45834 .56921 Mdot
.62897 .58551 Mdot
.64892 .27838 Mdot
.65151 .54155 Mdot
.41763 .23675 Mdot
.57013 .33695 Mdot
.36991 .34318 Mdot
.5824 .57744 Mdot
.63107 .56574 Mdot
.47433 .59237 Mdot
.47293 .57775 Mdot
.64491 .59062 Mdot
.60423 .31629 Mdot
.60441 .36928 Mdot
.55533 .34452 Mdot
.29095 .51813 Mdot
.50263 .73625 Mdot
.37478 .33388 Mdot
.45175 .57197 Mdot
.39062 .30836 Mdot
.75553 .59551 Mdot
.38199 .65726 Mdot
.38036 .23332 Mdot
.65266 .56723 Mdot
.57811 .32457 Mdot
.54688 .80002 Mdot
.59393 .30615 Mdot
.43115 .3756 Mdot
.39517 .31207 Mdot
.5995 .35424 Mdot
.65612 .57518 Mdot
.49617 .71741 Mdot
.77964 .56395 Mdot
.41104 .32725 Mdot
.46792 .54899 Mdot
.39821 .67812 Mdot
.31227 .49272 Mdot
.55105 .8399 Mdot
.37432 .31614 Mdot
.53202 .25584 Mdot
.6534 .51309 Mdot
.56528 .33996 Mdot
.38542 .32454 Mdot
.36914 .36173 Mdot
.25252 .52037 Mdot
.63105 .51532 Mdot
.63294 .56603 Mdot
.48474 .54572 Mdot
.38788 .31703 Mdot
.68724 .5361 Mdot
.64876 .50471 Mdot
.29454 .42464 Mdot
.5531 .34357 Mdot
.34405 .22125 Mdot
.69965 .64868 Mdot
.72426 .34836 Mdot
.3027 .27975 Mdot
.58841 .38176 Mdot
.67368 .55955 Mdot
.46195 .5787 Mdot
.28851 .50871 Mdot
.6569 .56946 Mdot
.2848 .46149 Mdot
.39139 .3457 Mdot
.43544 .23807 Mdot
.68825 .65441 Mdot
.39177 .4006 Mdot
.66345 .54941 Mdot
.64287 .47696 Mdot
.38531 .63194 Mdot
.37261 .37433 Mdot
.55779 .32259 Mdot
.67177 .5416 Mdot
.26397 .52188 Mdot
.3096 .49535 Mdot
.58695 .36211 Mdot
.51413 .29018 Mdot
.41111 .2188 Mdot
.46403 .5847 Mdot
.26972 .51633 Mdot
.45671 .57318 Mdot
.7569 .54471 Mdot
.38727 .30679 Mdot
.38001 .63827 Mdot
.30467 .48125 Mdot
.35789 .35127 Mdot
.66112 .51685 Mdot
.59329 .35978 Mdot
.5971 .29819 Mdot
.6098 .6483 Mdot
.26638 .47512 Mdot
.38094 .65398 Mdot
.61092 .63933 Mdot
.63012 .6605 Mdot
.3796 .64915 Mdot
.28358 .5244 Mdot
.60775 .34201 Mdot
.57452 .34124 Mdot
.58617 .32755 Mdot
.79465 .50109 Mdot
.5591 .36151 Mdot
.40832 .72236 Mdot
.58745 .60295 Mdot
.6752 .46405 Mdot
.65122 .52134 Mdot
.37303 .37307 Mdot
.57493 .36636 Mdot
.52862 .72114 Mdot
.58249 .56792 Mdot
.78147 .56429 Mdot
.62792 .54556 Mdot
.58694 .62271 Mdot
.64432 .55514 Mdot
.62726 .43733 Mdot
.55729 .36239 Mdot
.64918 .59378 Mdot
.40096 .36791 Mdot
.36534 .65133 Mdot
.61918 .37596 Mdot
.66827 .56987 Mdot
.53063 .36894 Mdot
.60393 .5885 Mdot
.43145 .23693 Mdot
.60325 .64092 Mdot
.35825 .53159 Mdot
.65175 .53008 Mdot
.28117 .45386 Mdot
.65722 .49105 Mdot
.69827 .473 Mdot
.40666 .31792 Mdot
.64776 .47289 Mdot
.25201 .47004 Mdot
.80379 .45531 Mdot
.46775 .58375 Mdot
.3779 .63295 Mdot
.44622 .59867 Mdot
.36653 .33238 Mdot
.6565 .56318 Mdot
.67106 .56977 Mdot
.60074 .61508 Mdot
.75548 .54717 Mdot
.4935 .56648 Mdot
.40221 .65411 Mdot
.69229 .47582 Mdot
.64971 .58796 Mdot
.22483 .52326 Mdot
.58731 .31197 Mdot
.79358 .45602 Mdot
.78944 .44098 Mdot
.65253 .50482 Mdot
.59913 .35934 Mdot
.57942 .31446 Mdot
.47759 .82668 Mdot
.3853 .62463 Mdot
.64318 .54086 Mdot
.38242 .59536 Mdot
.6104 .53035 Mdot
.3885 .34144 Mdot
.58881 .5918 Mdot
.27666 .47401 Mdot
.48613 .71881 Mdot
.28966 .5205 Mdot
.62142 .54844 Mdot
.5902 .34639 Mdot
.4113 .34314 Mdot
.31943 .49538 Mdot
.3236 .34813 Mdot
.40747 .72479 Mdot
.3018 .43997 Mdot
.41209 .63324 Mdot
.36763 .65951 Mdot
.37265 .37416 Mdot
.6483 .57673 Mdot
.51982 .72943 Mdot
.73389 .62897 Mdot
.64728 .55962 Mdot
.67088 .5565 Mdot
.43567 .31121 Mdot
.38916 .31165 Mdot
.3038 .46965 Mdot
.65681 .5555 Mdot
.68011 .55724 Mdot
.59434 .34842 Mdot
.41218 .62149 Mdot
.29752 .49175 Mdot
.39474 .65422 Mdot
.26283 .50893 Mdot
.58308 .7932 Mdot
.47169 .58788 Mdot
.37491 .65755 Mdot
.37243 .31573 Mdot
.58627 .32212 Mdot
.49768 .5534 Mdot
.2772 .49048 Mdot
.27312 .51727 Mdot
.6688 .52465 Mdot
.59725 .3739 Mdot
.56877 .32847 Mdot
.39938 .64892 Mdot
.39635 .32728 Mdot
.60214 .5352 Mdot
.44559 .58777 Mdot
.26293 .53827 Mdot
.27301 .52101 Mdot
.68679 .47154 Mdot
.62968 .33099 Mdot
.62834 .58338 Mdot
.59969 .31779 Mdot
.62857 .55918 Mdot
.54551 .29831 Mdot
.58115 .29648 Mdot
.59502 .60128 Mdot
.72622 .54728 Mdot
.28925 .48112 Mdot
.40753 .82634 Mdot
.57711 .5909 Mdot
.41394 .36463 Mdot
.62119 .51946 Mdot
.20575 .65605 Mdot
.54019 .79955 Mdot
.63124 .58931 Mdot
.67667 .5571 Mdot
.79983 .666 Mdot
.62655 .52764 Mdot
.4753 .55291 Mdot
.46935 .58363 Mdot
.60261 .32077 Mdot
.4434 .59961 Mdot
.50508 .72195 Mdot
.3939 .6203 Mdot
.27098 .49944 Mdot
.44358 .768 Mdot
.38898 .65467 Mdot
.57894 .35462 Mdot
.60682 .52983 Mdot
.62134 .30801 Mdot
.23092 .49423 Mdot
.48192 .56625 Mdot
.3892 .34887 Mdot
.51472 .72539 Mdot
.25854 .52185 Mdot
.37549 .32011 Mdot
.62666 .53036 Mdot
.33559 .46542 Mdot
.39924 .37221 Mdot
.41968 .8292 Mdot
.3813 .368 Mdot
.37137 .3237 Mdot
.5093 .73282 Mdot
.39417 .62018 Mdot
.49731 .57793 Mdot
.46318 .54653 Mdot
.40928 .34722 Mdot
.27715 .71079 Mdot
.25352 .52315 Mdot
.49074 .74687 Mdot
.55311 .35395 Mdot
.47879 .58221 Mdot
.66788 .55051 Mdot
.39053 .3638 Mdot
.68988 .5318 Mdot
.47019 .59413 Mdot
.37737 .35877 Mdot
.65786 .49202 Mdot
.46753 .71925 Mdot
.46025 .57096 Mdot
.49432 .5529 Mdot
.41522 .61737 Mdot
.31568 .55324 Mdot
.57658 .32025 Mdot
.39885 .60843 Mdot
.5438 .74082 Mdot
.63071 .54118 Mdot
.37971 .32468 Mdot
.47946 .56423 Mdot
.37071 .33521 Mdot
.38881 .63634 Mdot
.37383 .61487 Mdot
.59423 .37036 Mdot
.55501 .34022 Mdot
.50318 .54921 Mdot
.57384 .72054 Mdot
.59387 .56257 Mdot
.72202 .38394 Mdot
.57174 .30296 Mdot
.80986 .48589 Mdot
.4 .61728 Mdot
.41077 .6209 Mdot
.65231 .48431 Mdot
.59717 .57214 Mdot
.58624 .62084 Mdot
.59409 .58751 Mdot
.26514 .69096 Mdot
.59321 .55402 Mdot
.28692 .50695 Mdot
.60191 .59403 Mdot
.56728 .2517 Mdot
.67065 .51481 Mdot
.65854 .57963 Mdot
.2587 .49701 Mdot
.66983 .53118 Mdot
.27082 .47799 Mdot
.66766 .54558 Mdot
.21216 .46491 Mdot
.27109 .50123 Mdot
.46277 .61306 Mdot
.63406 .62337 Mdot
.48332 .55157 Mdot
.40124 .62871 Mdot
.40979 .64102 Mdot
.43415 .75233 Mdot
.60688 .34932 Mdot
.75431 .33961 Mdot
.65321 .58278 Mdot
.25742 .52435 Mdot
.39369 .34394 Mdot
.6626 .5039 Mdot
.61888 .54661 Mdot
.5779 .59144 Mdot
.59981 .36504 Mdot
.26371 .52853 Mdot
.39504 .63116 Mdot
.26011 .47113 Mdot
.206 .47064 Mdot
.2804 .47563 Mdot
.73154 .59423 Mdot
.66321 .519 Mdot
.53666 .52187 Mdot
.74677 .42694 Mdot
.35383 .62709 Mdot
.59062 .36219 Mdot
.47762 .56175 Mdot
.36433 .65764 Mdot
.48767 .69333 Mdot
.58422 .31685 Mdot
.28738 .50194 Mdot
.62983 .56958 Mdot
.46199 .59289 Mdot
.46694 .54429 Mdot
.61609 .3734 Mdot
.36394 .62784 Mdot
.27064 .49332 Mdot
.46641 .5646 Mdot
.49888 .73753 Mdot
.79173 .40006 Mdot
.52647 .76125 Mdot
.62941 .56345 Mdot
.40047 .64696 Mdot
.59791 .37437 Mdot
.58293 .6163 Mdot
.39951 .35 Mdot
.5101 .72712 Mdot
.66603 .55206 Mdot
.42826 .38549 Mdot
.58907 .34676 Mdot
.38192 .61975 Mdot
.38769 .36586 Mdot
.38267 .62499 Mdot
.46201 .55821 Mdot
.62576 .38265 Mdot
.44832 .5745 Mdot
.58583 .56888 Mdot
.3927 .34156 Mdot
.57388 .32242 Mdot
.21845 .45897 Mdot
.51733 .55069 Mdot
.28506 .49958 Mdot
.49271 .69421 Mdot
.60287 .37133 Mdot
.34095 .41971 Mdot
.26222 .46977 Mdot
.4033 .28963 Mdot
.52015 .69684 Mdot
.38388 .36145 Mdot
.66273 .57603 Mdot
.58835 .3324 Mdot
.41127 .32745 Mdot
.33869 .50756 Mdot
.78895 .54618 Mdot
.50892 .55829 Mdot
.61546 .5707 Mdot
.44846 .20645 Mdot
.54023 .2568 Mdot
.55478 .36979 Mdot
.36687 .32487 Mdot
.64495 .54661 Mdot
.4638 .58569 Mdot
.64788 .59278 Mdot
.40969 .33748 Mdot
.36754 .29624 Mdot
.23806 .49533 Mdot
.62761 .57244 Mdot
.37219 .63031 Mdot
.28492 .4699 Mdot
.31557 .48034 Mdot
.30544 .48354 Mdot
.55716 .3251 Mdot
.48592 .57922 Mdot
.46889 .58483 Mdot
.52549 .79706 Mdot
.36827 .33753 Mdot
.48302 .55184 Mdot
.67561 .56377 Mdot
.41033 .72372 Mdot
.57894 .32797 Mdot
.26826 .49005 Mdot
.64298 .54335 Mdot
.60677 .64689 Mdot
.4888 .56329 Mdot
.25267 .50101 Mdot
.56821 .30553 Mdot
.58406 .44105 Mdot
.65551 .5693 Mdot
.61404 .52897 Mdot
.5758 .35583 Mdot
.60515 .22805 Mdot
.49313 .73853 Mdot
.6304 .55829 Mdot
.36987 .33079 Mdot
.5566 .20404 Mdot
.63095 .52754 Mdot
.57982 .28534 Mdot
.47981 .54549 Mdot
.56981 .42267 Mdot
.67993 .45161 Mdot
.69334 .51419 Mdot
.47804 .44592 Mdot
.5363 .61484 Mdot
.50473 .4638 Mdot
.29747 .70086 Mdot
.41546 .45972 Mdot
.44256 .83964 Mdot
.36156 .37242 Mdot
.61202 .45584 Mdot
.86694 .54557 Mdot
.51715 .27385 Mdot
.38141 .48263 Mdot
.36386 .29159 Mdot
.35117 .67362 Mdot
.17836 .61213 Mdot
.33587 .45528 Mdot
.30019 .69868 Mdot
.5864 .57073 Mdot
.58605 .23286 Mdot
.61549 .46059 Mdot
.35122 .45526 Mdot
.32197 .3692 Mdot
.6067 .64146 Mdot
.76072 .69045 Mdot
.39702 .3942 Mdot
.63974 .79704 Mdot
.73505 .34272 Mdot
.30283 .52967 Mdot
.57002 .68545 Mdot
.42136 .76582 Mdot
.62593 .47601 Mdot
.53475 .43951 Mdot
.36541 .3794 Mdot
.65529 .34109 Mdot
.31279 .26737 Mdot
.27787 .50917 Mdot
.61596 .36652 Mdot
.4604 .31934 Mdot
.71447 .74225 Mdot
.43085 .35602 Mdot
.47624 .44693 Mdot
.51587 .54941 Mdot
.62247 .44258 Mdot
.53174 .71793 Mdot
.62223 .43299 Mdot
.32282 .43274 Mdot
.18135 .61348 Mdot
.63378 .32292 Mdot
.33843 .52435 Mdot
.47099 .69077 Mdot
.37437 .48425 Mdot
.64608 .43134 Mdot
.35161 .6576 Mdot
.45812 .6146 Mdot
.5703 .30256 Mdot
.75608 .66831 Mdot
.68734 .63288 Mdot
.54926 .73735 Mdot
.33954 .45821 Mdot
.63224 .28394 Mdot
.74318 .29322 Mdot
.52305 .2835 Mdot
.36212 .80577 Mdot
.67596 .78808 Mdot
.3278 .7416 Mdot
.63538 .61519 Mdot
.43543 .35531 Mdot
.43608 .68191 Mdot
.46514 .48163 Mdot
.34719 .76637 Mdot
.6468 .27581 Mdot
.78743 .64752 Mdot
.51404 .36637 Mdot
.72148 .75134 Mdot
.63959 .35885 Mdot
.52339 .53154 Mdot
.57932 .4018 Mdot
.59727 .44944 Mdot
.51101 .77914 Mdot
.73852 .72501 Mdot
.35851 .47386 Mdot
.51989 .54248 Mdot
.50783 .28306 Mdot
.67697 .44478 Mdot
.32175 .4288 Mdot
.444 .60956 Mdot
.76478 .42809 Mdot
.76163 .70249 Mdot
.49111 .43902 Mdot
.71723 .71313 Mdot
.28553 .42602 Mdot
.18876 .40502 Mdot
.31539 .47207 Mdot
.36944 .30997 Mdot
.65868 .78981 Mdot
.5843 .33488 Mdot
.39473 .82846 Mdot
.41603 .47126 Mdot
.4029 .50437 Mdot
.76493 .69654 Mdot
.3377 .77972 Mdot
.65075 .46141 Mdot
.49787 .58889 Mdot
.34276 .26052 Mdot
.53174 .47143 Mdot
.36273 .41164 Mdot
.42858 .64732 Mdot
.43592 .22493 Mdot
.67805 .7748 Mdot
.3213 .75449 Mdot
.82071 .61028 Mdot
.55327 .72719 Mdot
.35015 .69706 Mdot
.6289 .31202 Mdot
.4405 .41513 Mdot
.35816 .42097 Mdot
.70965 .76389 Mdot
.65568 .47481 Mdot
.51953 .19148 Mdot
.30915 .71156 Mdot
.79557 .44135 Mdot
.48435 .21954 Mdot
.46915 .3363 Mdot
.58402 .45655 Mdot
.52684 .36121 Mdot
.43161 .58544 Mdot
.49521 .77764 Mdot
.75671 .40566 Mdot
.35706 .52558 Mdot
.49282 .72805 Mdot
.48867 .32249 Mdot
.37996 .76929 Mdot
.53023 .21033 Mdot
.76475 .41956 Mdot
.61236 .31419 Mdot
.34801 .76551 Mdot
.31161 .72176 Mdot
.50118 .19916 Mdot
.25417 .54799 Mdot
.71194 .72072 Mdot
.41238 .40395 Mdot
.69984 .51392 Mdot
.60893 .4598 Mdot
.62618 .47206 Mdot
.20448 .63951 Mdot
.73085 .57646 Mdot
.47168 .81864 Mdot
.35684 .39681 Mdot
.74685 .44483 Mdot
.45207 .79495 Mdot
.75018 .43776 Mdot
.6943 .46453 Mdot
.54311 .28501 Mdot
.37263 .39283 Mdot
.71703 .56131 Mdot
.76486 .69038 Mdot
.29855 .46852 Mdot
.3454 .76777 Mdot
.42162 .37227 Mdot
.32934 .49986 Mdot
.38976 .50589 Mdot
.38051 .50754 Mdot
.60184 .8205 Mdot
.49906 .28792 Mdot
.36183 .67926 Mdot
.60548 .41787 Mdot
.43878 .47396 Mdot
.7283 .38957 Mdot
.71376 .63465 Mdot
.63532 .27913 Mdot
.37083 .62091 Mdot
.76261 .47365 Mdot
.5465 .38666 Mdot
.25335 .55043 Mdot
.7339 .60007 Mdot
.58056 .68315 Mdot
.4933 .5434 Mdot
.44312 .73656 Mdot
.5772 .79615 Mdot
.7052 .52776 Mdot
.34799 .78321 Mdot
.51117 .28695 Mdot
.44361 .74256 Mdot
.35659 .42226 Mdot
.75994 .34467 Mdot
.72483 .7486 Mdot
.5395 .83546 Mdot
.60812 .23458 Mdot
.47387 .21438 Mdot
.15796 .47873 Mdot
.32754 .37117 Mdot
.42637 .81938 Mdot
.42191 .37204 Mdot
.63954 .16512 Mdot
.29355 .46116 Mdot
.42227 .68417 Mdot
.64334 .36662 Mdot
.57475 .67468 Mdot
.73754 .71474 Mdot
.64822 .45208 Mdot
.37875 .60844 Mdot
.57381 .39449 Mdot
.72505 .5509 Mdot
.75601 .68734 Mdot
.77144 .6636 Mdot
.75994 .67256 Mdot
.4596 .335 Mdot
.75774 .52568 Mdot
.78533 .6781 Mdot
.41494 .70931 Mdot
.69502 .59449 Mdot
.68301 .50366 Mdot
.56847 .74137 Mdot
.40649 .80972 Mdot
.3448 .63742 Mdot
.53626 .47087 Mdot
.6337 .32434 Mdot
.77449 .69616 Mdot
.56428 .80316 Mdot
.61293 .44129 Mdot
.60951 .81187 Mdot
.33639 .67774 Mdot
.47095 .80303 Mdot
.5747 .8252 Mdot
.5122 .43726 Mdot
.4554 .35827 Mdot
.78549 .69249 Mdot
.33127 .72849 Mdot
.36746 .28993 Mdot
.53441 .37364 Mdot
.40367 .81496 Mdot
.47396 .22234 Mdot
.40377 .28041 Mdot
.64307 .35609 Mdot
.78073 .35893 Mdot
.38033 .45507 Mdot
.53964 .44166 Mdot
.61351 .61859 Mdot
.44698 .7986 Mdot
.29331 .45769 Mdot
.36963 .77844 Mdot
.37259 .43312 Mdot
.70052 .58155 Mdot
.45491 .76186 Mdot
.30271 .73232 Mdot
.51988 .39761 Mdot
.76456 .5462 Mdot
.50631 .29134 Mdot
.54668 .20888 Mdot
.49805 .2128 Mdot
.7563 .37444 Mdot
.6729 .53539 Mdot
.72105 .7369 Mdot
.4741 .85211 Mdot
.58142 .82687 Mdot
.51441 .20191 Mdot
.18412 .43676 Mdot
.3548 .35408 Mdot
.41921 .71542 Mdot
.579 .66665 Mdot
.49306 .41227 Mdot
.54602 .61313 Mdot
.40191 .30472 Mdot
.74336 .29154 Mdot
.39437 .50058 Mdot
.41687 .70957 Mdot
.66082 .33142 Mdot
.42671 .48695 Mdot
.75889 .54889 Mdot
.60923 .31123 Mdot
.48086 .19121 Mdot
.35071 .76789 Mdot
.30064 .4722 Mdot
.24464 .53895 Mdot
.71858 .58565 Mdot
.53051 .53409 Mdot
.38773 .68492 Mdot
.7008 .5461 Mdot
.72596 .35077 Mdot
.18336 .44851 Mdot
.51712 .82313 Mdot
.40498 .82363 Mdot
.57059 .82624 Mdot
.32163 .7379 Mdot
.3339 .50821 Mdot
.45332 .74107 Mdot
.42642 .32064 Mdot
.4077 .38275 Mdot
.4581 .72194 Mdot
.30658 .72842 Mdot
.65639 .46088 Mdot
.57017 .39426 Mdot
.68152 .52392 Mdot
.55263 .79913 Mdot
.40987 .75328 Mdot
.44536 .71962 Mdot
.77454 .38305 Mdot
.55384 .30517 Mdot
.3698 .703 Mdot
.55648 .43641 Mdot
.63097 .50372 Mdot
.47724 .21012 Mdot
.41026 .32039 Mdot
.60034 .3038 Mdot
.30219 .73316 Mdot
.16802 .46641 Mdot
.47787 .47002 Mdot
.68416 .64404 Mdot
.68442 .76531 Mdot
.64073 .63084 Mdot
.45775 .22315 Mdot
.79655 .37044 Mdot
.33476 .4045 Mdot
.63779 .33252 Mdot
.69094 .58715 Mdot
.38651 .51523 Mdot
.61128 .24394 Mdot
.62175 .3454 Mdot
.64116 .48005 Mdot
.65522 .79746 Mdot
.6084 .63403 Mdot
.52573 .4467 Mdot
.51268 .75309 Mdot
.41518 .42905 Mdot
.4263 .47112 Mdot
.45187 .76541 Mdot
.49256 .45758 Mdot
.74212 .67851 Mdot
.73875 .27895 Mdot
.54768 .47084 Mdot
.39154 .70467 Mdot
.42116 .70831 Mdot
.7348 .34171 Mdot
.64425 .42897 Mdot
.35385 .39985 Mdot
.58531 .57816 Mdot
.64189 .81065 Mdot
.50262 .34516 Mdot
.44992 .7535 Mdot
.44675 .382 Mdot
.62897 .52168 Mdot
.51767 .52888 Mdot
.58406 .82366 Mdot
.56424 .42166 Mdot
.88461 .51847 Mdot
.28784 .7017 Mdot
.6076 .25783 Mdot
.67653 .4536 Mdot
.35967 .78701 Mdot
.58227 .25597 Mdot
.43034 .45852 Mdot
.37965 .42827 Mdot
.38983 .80385 Mdot
.55209 .41145 Mdot
.56156 .42538 Mdot
.46803 .20055 Mdot
.78704 .66896 Mdot
.52886 .46331 Mdot
.4181 .29148 Mdot
.34257 .68135 Mdot
.63068 .537 Mdot
.51616 .28671 Mdot
.38899 .22636 Mdot
.45624 .38293 Mdot
.51028 .47015 Mdot
.46934 .85424 Mdot
.69711 .50192 Mdot
.49958 .29784 Mdot
.88226 .5238 Mdot
.89656 .50215 Mdot
.54515 .2705 Mdot
.69866 .77453 Mdot
.57131 .42758 Mdot
.45785 .22578 Mdot
.38086 .38811 Mdot
.63965 .65968 Mdot
.72093 .37407 Mdot
.60428 .82831 Mdot
.16566 .4509 Mdot
.3592 .41279 Mdot
.64858 .33363 Mdot
.59958 .83174 Mdot
.70411 .51008 Mdot
.39702 .69891 Mdot
.19038 .40438 Mdot
.24637 .69195 Mdot
.36127 .80213 Mdot
.77886 .37772 Mdot
.20457 .64411 Mdot
.26809 .67508 Mdot
.36147 .46495 Mdot
.41043 .82193 Mdot
.48602 .52667 Mdot
.77011 .34681 Mdot
.34624 .7635 Mdot
.4556 .21274 Mdot
.17489 .54035 Mdot
.43341 .46813 Mdot
.69914 .55972 Mdot
.53715 .29017 Mdot
.43249 .22785 Mdot
.47543 .32184 Mdot
.67194 .61648 Mdot
.49401 .69866 Mdot
.69389 .46709 Mdot
.55407 .20048 Mdot
.80971 .38151 Mdot
.6949 .56417 Mdot
.77819 .64209 Mdot
.38173 .3989 Mdot
.45613 .7008 Mdot
.65657 .43911 Mdot
.41909 .74423 Mdot
.36305 .68308 Mdot
.60204 .59152 Mdot
.66248 .79236 Mdot
.36521 .68322 Mdot
.77086 .65398 Mdot
.39436 .83138 Mdot
.6239 .80236 Mdot
.40703 .50904 Mdot
.40562 .67212 Mdot
.40324 .80417 Mdot
.40933 .80531 Mdot
.79418 .62961 Mdot
.30389 .6964 Mdot
.46166 .71654 Mdot
.66236 .61134 Mdot
.68767 .65146 Mdot
.74689 .56629 Mdot
.36351 .78964 Mdot
.73658 .3284 Mdot
.45287 .79198 Mdot
.60832 .23688 Mdot
.30568 .73125 Mdot
.64646 .46019 Mdot
.42434 .74585 Mdot
.43369 .40169 Mdot
.47815 .60096 Mdot
.25004 .52284 Mdot
.81894 .63709 Mdot
.49314 .20215 Mdot
.49542 .8132 Mdot
.51176 .19188 Mdot
.52681 .36525 Mdot
.27894 .68934 Mdot
.58654 .40459 Mdot
.51591 .49126 Mdot
.31174 .5299 Mdot
.40144 .77453 Mdot
.6654 .46977 Mdot
.4386 .21086 Mdot
.78979 .42243 Mdot
.61034 .81972 Mdot
.45491 .79751 Mdot
.83432 .59187 Mdot
.3559 .69337 Mdot
.76195 .47036 Mdot
.75462 .66611 Mdot
.57844 .21804 Mdot
.44379 .71236 Mdot
.76687 .68275 Mdot
.56416 .37751 Mdot
.68172 .784 Mdot
.39756 .34815 Mdot
.37861 .69731 Mdot
.41476 .22082 Mdot
.43227 .71468 Mdot
.43364 .71155 Mdot
.50098 .82107 Mdot
.50416 .28746 Mdot
.52793 .27378 Mdot
.41024 .40466 Mdot
.33467 .45732 Mdot
.66898 .65732 Mdot
.51202 .44712 Mdot
.81718 .61445 Mdot
.6731 .53687 Mdot
.32093 .68648 Mdot
.34617 .77413 Mdot
.42632 .31831 Mdot
.66251 .60175 Mdot
.43129 .21764 Mdot
.79752 .38686 Mdot
.51098 .78986 Mdot
.78187 .67552 Mdot
.65782 .60423 Mdot
.57035 .65896 Mdot
.8116 .45856 Mdot
.40713 .27647 Mdot
.35529 .4059 Mdot
.48474 .44756 Mdot
.65521 .6328 Mdot
.49582 .74066 Mdot
.32577 .7365 Mdot
.45622 .84799 Mdot
.78486 .63566 Mdot
.35187 .40579 Mdot
.43797 .71948 Mdot
.58023 .28366 Mdot
.41282 .77324 Mdot
.83118 .60067 Mdot
.19055 .63481 Mdot
.53294 .37135 Mdot
.31344 .73931 Mdot
.46709 .34326 Mdot
.39844 .70006 Mdot
.45114 .72063 Mdot
.75281 .67165 Mdot
.6415 .38031 Mdot
.58384 .42173 Mdot
.4758 .34663 Mdot
.50954 .71808 Mdot
.39577 .48399 Mdot
.77182 .35864 Mdot
.50036 .28281 Mdot
.8351 .59032 Mdot
.2525 .66913 Mdot
.79899 .45228 Mdot
.85758 .55876 Mdot
.56482 .30672 Mdot
.39029 .48593 Mdot
.20538 .37697 Mdot
.43951 .73694 Mdot
.31094 .48394 Mdot
.68699 .53443 Mdot
.47667 .70576 Mdot
.59401 .24382 Mdot
.34454 .67332 Mdot
.35851 .64037 Mdot
.6063 .31094 Mdot
.27969 .68371 Mdot
.60049 .30261 Mdot
.45508 .84535 Mdot
.51035 .43284 Mdot
.68774 .46657 Mdot
.81727 .40697 Mdot
.33216 .5177 Mdot
.55759 .21108 Mdot
.6339 .80035 Mdot
.5632 .74019 Mdot
.6211 .35492 Mdot
.62669 .3659 Mdot
.62453 .39762 Mdot
.40764 .30039 Mdot
.69933 .75136 Mdot
.33859 .77761 Mdot
.25885 .53918 Mdot
.58798 .39264 Mdot
.63333 .61951 Mdot
.70226 .5386 Mdot
.53277 .8185 Mdot
.26237 .47103 Mdot
.74131 .73438 Mdot
.74723 .3323 Mdot
.57427 .22706 Mdot
.49803 .40206 Mdot
.58988 .68962 Mdot
.44961 .69185 Mdot
.34295 .52592 Mdot
.69661 .51039 Mdot
.58348 .26318 Mdot
.55971 .35416 Mdot
.39185 .49443 Mdot
.39562 .61261 Mdot
.26162 .55068 Mdot
.42111 .34136 Mdot
.74832 .37065 Mdot
.35856 .79162 Mdot
.61855 .31897 Mdot
.38583 .68877 Mdot
.33479 .54013 Mdot
.73571 .58393 Mdot
.58639 .72154 Mdot
.8098 .65745 Mdot
.66028 .7808 Mdot
.60178 .3117 Mdot
.54142 .21205 Mdot
.23017 .45078 Mdot
.51571 .82207 Mdot
.55089 .4021 Mdot
.35969 .78211 Mdot
.76445 .43912 Mdot
.5618 .82217 Mdot
.67827 .45138 Mdot
.48384 .43369 Mdot
.33146 .75743 Mdot
.37569 .59545 Mdot
.31079 .74196 Mdot
.80279 .40184 Mdot
.66488 .6441 Mdot
.25997 .70159 Mdot
.46055 .37316 Mdot
.61392 .44357 Mdot
.60548 .52794 Mdot
.49244 .41658 Mdot
.39007 .80035 Mdot
.56893 .31447 Mdot
.34741 .66567 Mdot
.662 .31686 Mdot
.35946 .41139 Mdot
.67373 .77733 Mdot
.5127 .2058 Mdot
.3332 .76947 Mdot
.68982 .64808 Mdot
.37571 .74522 Mdot
.73388 .3301 Mdot
.55744 .73107 Mdot
.44596 .59258 Mdot
.75829 .41801 Mdot
.48327 .58929 Mdot
.53303 .79997 Mdot
.74651 .57354 Mdot
.73719 .72091 Mdot
.56805 .79777 Mdot
.53462 .29159 Mdot
.52156 .55698 Mdot
.60634 .39 Mdot
.74883 .72102 Mdot
.51869 .79006 Mdot
.42789 .22538 Mdot
.36076 .80067 Mdot
.30541 .69183 Mdot
.8632 .55053 Mdot
.49289 .30094 Mdot
.71067 .56447 Mdot
.41563 .82525 Mdot
.5093 .35565 Mdot
.27164 .676 Mdot
.66631 .47048 Mdot
.62424 .30805 Mdot
.76732 .69096 Mdot
.4925 .51404 Mdot
.52224 .29449 Mdot
.7693 .5783 Mdot
.63817 .32884 Mdot
.52378 .78718 Mdot
.66425 .59621 Mdot
.28947 .50201 Mdot
.58094 .67775 Mdot
.19704 .63074 Mdot
.63254 .39386 Mdot
.35429 .78343 Mdot
.36477 .78294 Mdot
.35449 .7095 Mdot
.33956 .54744 Mdot
.86356 .5486 Mdot
.75533 .51317 Mdot
.67299 .58566 Mdot
.61521 .32336 Mdot
.35839 .65293 Mdot
.31781 .71284 Mdot
.62405 .52398 Mdot
.57886 .70013 Mdot
.76469 .43177 Mdot
.62389 .81967 Mdot
.43425 .41242 Mdot
.35396 .37757 Mdot
.57529 .38769 Mdot
.43225 .22562 Mdot
.62688 .25133 Mdot
.52588 .26329 Mdot
.3885 .79752 Mdot
.47928 .46966 Mdot
.47953 .44247 Mdot
.52081 .31291 Mdot
.36453 .76614 Mdot
.35456 .43923 Mdot
.40757 .36303 Mdot
.72472 .35815 Mdot
.80692 .61651 Mdot
.51852 .3455 Mdot
.44481 .46598 Mdot
.53314 .42343 Mdot
.65436 .64038 Mdot
.36098 .41442 Mdot
.50649 .28882 Mdot
.63018 .35442 Mdot
.73742 .69145 Mdot
.54257 .45428 Mdot
.40074 .67672 Mdot
.30146 .71424 Mdot
.52289 .42739 Mdot
.36723 .78819 Mdot
.72633 .54654 Mdot
.75598 .67729 Mdot
.4473 .75221 Mdot
.33539 .65239 Mdot
.67804 .51765 Mdot
.6503 .28825 Mdot
.58269 .82433 Mdot
.54148 .39427 Mdot
.49483 .47711 Mdot
.60475 .41182 Mdot
.38647 .82271 Mdot
.43459 .6203 Mdot
.185 .44544 Mdot
.49292 .59161 Mdot
.58159 .69077 Mdot
.57407 .66922 Mdot
.41263 .30232 Mdot
.6968 .50529 Mdot
.36883 .47003 Mdot
.66514 .63389 Mdot
.72832 .3586 Mdot
.45759 .81745 Mdot
.81704 .63433 Mdot
.6295 .28096 Mdot
.35369 .80244 Mdot
.64735 .3021 Mdot
.62256 .29275 Mdot
.25543 .66953 Mdot
.495 .48064 Mdot
.73089 .57247 Mdot
.34082 .66124 Mdot
.56117 .30862 Mdot
.81444 .62999 Mdot
.50435 .46991 Mdot
.34549 .65829 Mdot
.309 .42873 Mdot
.42321 .47511 Mdot
.29987 .27212 Mdot
.40152 .38418 Mdot
.39731 .82742 Mdot
.34746 .76685 Mdot
.36953 .39174 Mdot
.56997 .42663 Mdot
.5069 .4765 Mdot
.75386 .68768 Mdot
.50672 .57767 Mdot
.65145 .79078 Mdot
.4602 .33708 Mdot
.74555 .37952 Mdot
.56593 .79585 Mdot
.49916 .77974 Mdot
.55475 .73729 Mdot
.76988 .40368 Mdot
.7035 .72056 Mdot
.50148 .55829 Mdot
.25612 .54598 Mdot
.17334 .55383 Mdot
.82334 .60988 Mdot
.5807 .2257 Mdot
.51275 .5363 Mdot
.42082 .77534 Mdot
.54174 .45143 Mdot
.46002 .69819 Mdot
.38791 .41445 Mdot
.39028 .68474 Mdot
.44829 .31545 Mdot
.53969 .1995 Mdot
.64127 .81016 Mdot
.67844 .50806 Mdot
.53955 .60443 Mdot
.35301 .46022 Mdot
.30591 .46436 Mdot
.65062 .38411 Mdot
.80876 .65553 Mdot
.41118 .35387 Mdot
.2126 .36594 Mdot
.4198 .31349 Mdot
.50776 .81704 Mdot
.17501 .44691 Mdot
.39478 .29112 Mdot
.45161 .8463 Mdot
.58681 .2386 Mdot
.79801 .41319 Mdot
.51788 .18944 Mdot
.54093 .80144 Mdot
.75578 .41412 Mdot
.43155 .64526 Mdot
.69503 .76873 Mdot
.44787 .69715 Mdot
.35362 .67946 Mdot
.71657 .7088 Mdot
.32581 .75303 Mdot
.29286 .7063 Mdot
.33528 .3192 Mdot
.64597 .33049 Mdot
.16541 .47434 Mdot
.31922 .51603 Mdot
.74947 .27297 Mdot
.66124 .77875 Mdot
.79649 .54076 Mdot
.54491 .39626 Mdot
.42461 .39797 Mdot
.74993 .69534 Mdot
.37759 .787 Mdot
.59689 .43997 Mdot
.23244 .5402 Mdot
.48131 .77716 Mdot
.40753 .76483 Mdot
.45211 .36832 Mdot
.58565 .81625 Mdot
.33994 .5264 Mdot
.51287 .51829 Mdot
.33738 .76658 Mdot
.65377 .29561 Mdot
.55858 .72084 Mdot
.80437 .61946 Mdot
.57962 .73161 Mdot
.29224 .71789 Mdot
.46007 .3339 Mdot
.20124 .47686 Mdot
.8116 .62036 Mdot
.61901 .25469 Mdot
.775 .44934 Mdot
.88223 .52131 Mdot
.72053 .75191 Mdot
.50991 .47746 Mdot
.58508 .5885 Mdot
.43674 .83812 Mdot
.22682 .50435 Mdot
.48221 .81393 Mdot
.7438 .29462 Mdot
.27695 .69436 Mdot
.74735 .58461 Mdot
.58773 .57227 Mdot
.41735 .70267 Mdot
.53029 .31668 Mdot
.64489 .34892 Mdot
.33009 .48609 Mdot
.30677 .72751 Mdot
.74886 .36641 Mdot
.73866 .27912 Mdot
.79867 .39445 Mdot
.61307 .33575 Mdot
.67564 .78352 Mdot
.52354 .50298 Mdot
.73805 .33816 Mdot
.75031 .6856 Mdot
.55885 .62682 Mdot
.36484 .45634 Mdot
.72966 .32982 Mdot
.4501 .73853 Mdot
.19295 .62395 Mdot
.85681 .56478 Mdot
.72894 .37718 Mdot
.74806 .72754 Mdot
.54122 .83702 Mdot
.6158 .35571 Mdot
.64313 .3841 Mdot
.44532 .68809 Mdot
.51778 .46164 Mdot
.41793 .28383 Mdot
.32794 .5031 Mdot
.29451 .68579 Mdot
.2766 .55694 Mdot
.62926 .59111 Mdot
.46237 .35834 Mdot
.61653 .81558 Mdot
.3904 .69867 Mdot
.63005 .80929 Mdot
.75879 .38968 Mdot
.67638 .53471 Mdot
.89591 .49865 Mdot
.45495 .22596 Mdot
.72264 .6239 Mdot
.45177 .55787 Mdot
.51442 .53792 Mdot
.61242 .5948 Mdot
.36516 .29548 Mdot
.41643 .72715 Mdot
.25656 .68481 Mdot
.6974 .76457 Mdot
.58265 .38945 Mdot
.44723 .69384 Mdot
.38615 .3817 Mdot
.52555 .69918 Mdot
.7527 .57701 Mdot
.41397 .34777 Mdot
.23105 .66364 Mdot
.29753 .27616 Mdot
.35661 .42791 Mdot
.39842 .48144 Mdot
.49302 .70202 Mdot
.5116 .54647 Mdot
.24489 .66761 Mdot
.41452 .30014 Mdot
.35657 .45555 Mdot
.33029 .7663 Mdot
.77526 .41484 Mdot
.44861 .36906 Mdot
.18143 .5179 Mdot
.44607 .71396 Mdot
.46338 .36015 Mdot
.53257 .47529 Mdot
.78667 .36372 Mdot
.72621 .71243 Mdot
.30939 .43712 Mdot
.50252 .55611 Mdot
.81228 .46499 Mdot
.73419 .71948 Mdot
.36106 .33895 Mdot
.46838 .84747 Mdot
.51315 .48319 Mdot
.65476 .37617 Mdot
.78903 .55986 Mdot
.67423 .59638 Mdot
.65108 .47293 Mdot
.5908 .60792 Mdot
.55096 .66807 Mdot
.2834 .27867 Mdot
.68793 .57985 Mdot
.41384 .48035 Mdot
.47833 .46459 Mdot
.38527 .70667 Mdot
.66374 .48264 Mdot
.63523 .54223 Mdot
.43424 .60781 Mdot
.46773 .75228 Mdot
.39913 .68856 Mdot
.36559 .69708 Mdot
.4534 .36088 Mdot
.24497 .66889 Mdot
.28977 .70271 Mdot
.75081 .53996 Mdot
.75695 .69344 Mdot
.61624 .51746 Mdot
.65384 .78396 Mdot
.39852 .42746 Mdot
.47772 .32241 Mdot
.58275 .7246 Mdot
.85408 .56779 Mdot
.55717 .27898 Mdot
.55956 .51437 Mdot
.5282 .83385 Mdot
.60669 .81458 Mdot
.39419 .39949 Mdot
.4555 .20839 Mdot
.17235 .57073 Mdot
.43562 .70089 Mdot
.54626 .20048 Mdot
.25167 .53767 Mdot
.52667 .82609 Mdot
.67812 .62834 Mdot
.50445 .48066 Mdot
.76505 .35961 Mdot
.7331 .5918 Mdot
.24847 .48741 Mdot
.79541 .36958 Mdot
.77118 .40364 Mdot
.7003 .72309 Mdot
.66328 .59212 Mdot
.46925 .41271 Mdot
.5835 .28496 Mdot
.82454 .60282 Mdot
.27415 .53154 Mdot
.56932 .65649 Mdot
.75343 .28622 Mdot
.28884 .27548 Mdot
.27211 .67456 Mdot
.79099 .62971 Mdot
.40442 .38423 Mdot
.66143 .63317 Mdot
.36242 .22501 Mdot
.57258 .28063 Mdot
.61998 .33166 Mdot
.42068 .33757 Mdot
.38385 .74764 Mdot
.50592 .30244 Mdot
.87376 .54129 Mdot
.55747 .82365 Mdot
.73202 .56228 Mdot
.73214 .24788 Mdot
.34097 .76963 Mdot
.55507 .64067 Mdot
.49789 .29176 Mdot
.65952 .79349 Mdot
.43456 .29957 Mdot
.42106 .82892 Mdot
.52484 .43677 Mdot
.63286 .39084 Mdot
.40185 .75572 Mdot
.51368 .19409 Mdot
.6479 .61455 Mdot
.73744 .26899 Mdot
.48005 .20798 Mdot
.42192 .76636 Mdot
.54305 .40584 Mdot
.60886 .27531 Mdot
.60029 .26148 Mdot
.50596 .40614 Mdot
.4702 .48171 Mdot
.44718 .46541 Mdot
.48714 .44129 Mdot
.35556 .43772 Mdot
.49005 .39981 Mdot
.44643 .22865 Mdot
.43697 .33463 Mdot
.77958 .38821 Mdot
.17724 .59141 Mdot
.35972 .6954 Mdot
.28739 .45892 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0c?ooool2o`0007_ooooo000Looooo`03o`000?oooooooooo0<cooooo0_l0
001kooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0=Cooooo0_l0001cooooo`007?ooool0
0ol0003oooooooooo`2Jooooo`;o0000>?ooool2o`0007?ooooo000Looooo`03o`000?oooooooooo
09[ooooo0_l00008ooooo`Co0000;_ooool2o`00077ooooo00001_ooooook^k^oc8b<_l0003o<S8b
onk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`2Hooooo`;o00002?ooool6
o`0002kooooo0ol0001`ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0V?ooool2o`0000Sooooo
1Ol0000`ooooo`?o0000Koooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_oo
ool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo09Cooooo0_l00009ooooo`;o00000_oo
ool2o`0000Oooooo0_l000000ooooooo0000o`00000Vooooo`Co0000K_ooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06ooooo`?o0000TOooool2
o`000003ooooool0003o000000Kooooo0_l000000ooooooo0000o`000002ooooo`;o00001oooool6
o`0002Oooooo0_l0001^ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<oooo
o`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0TOooool2o`000003ooooool0003o0000
00Kooooo0_l00005ooooo`;o00002Oooool5o`0002Kooooo0ol0001]ooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0Roooool7o`0000Kooooo0_l00009ooooo`;o00002Oooool2o`000003ooooool0003o000000?o
oooo0_l0000Rooooo`;o0000KOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0
003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0Roooool7o`0000Gooooo0ol0000<
ooooo`Co00000_ooool4o`000003ooooool0003o000000?ooooo0_l0000Tooooo`?o0000J_ooool0
0006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo
00?o0000ooooooooool0POooool2o`0000Cooooo0ol000000ooooooo0000o`000002o`000003oooo
ool0003o000000Cooooo0ol00005ooooo`;o00001_ooool4o`000004ooooool0003o0000o`0000?o
oooo0_l0000Yooooo`?o0000J_ooool001cooooo00?o0000ooooooooool0O_ooool2o`000004oooo
ool0003o0000o`0000;ooooo1?l00006ooooo`;o00001?ooool2o`0000Kooooo0_l0000;ooooo`;o
00002oooool2o`000003ooooool0003o000008cooooo000Looooo`03o`000?oooooooooo06cooooo
0_l0000@ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000002o`00013ooooo
0_l0000Looooo`;o000000?oooooo`000?l000008_ooool2o`0006Sooooo000Looooo`03o`000?oo
oooooooo06cooooo1Ol00003ooooo`;o00001?ooool2o`0000?ooooo1_l0000<ooooo`;o00000ooo
ool2o`0000;ooooo0_l00013ooooo`;o0000J?ooool001cooooo00?o0000ooooooooool0K?ooool:
o`0000;ooooo1_l000001?oooooo0000o`000?l00005ooooo`Go00001?ooool3o`0000?ooooo0_l0
000Oooooo`Co0000S_ooool001cooooo00?o0000ooooooooool0K_ooool9o`000004ooooool0003o
0000ooooo`?o00002Oooool5o`000004ooooool0003o0000ooooo`?o00009?ooool4o`0000Kooooo
0_l00026ooooo`007?ooool00ol0003oooooooooo`1cooooo`Co000000?oooooo`000?l000003ooo
ool2o`0000;ooooo0_l00003ooooo`;o00009oooool2o`0000Cooooo0_l0000Pooooo`;o0000I?oo
ool001cooooo00?o0000ooooooooool0MOooool2o`000004ooooool0003o0000o`0000Wooooo0_l0
0002ooooo`;o00001_ooool4o`0002Oooooo0_l00005ooooo`Co00007Oooool2o`0006Cooooo000L
ooooo`03o`000?oooooooooo07Wooooo0_l00009ooooo`;o00000_ooool5o`0000?ooooo0_l0000Y
ooooo`;o00001Oooool4o`0001kooooo0_l0001Sooooo`007?ooool00ol0003oooooooooo`24oooo
o`;o00001?ooool3o`0002kooooo0_l0000Wooooo`;o000000?oooooo`000?l00000H?ooool001co
oooo00?o0000ooooooooool0_Oooool2o`0000Cooooo0_l0000Rooooo`;o0000H?ooool001cooooo
00?o0000ooooooooool0_Oooool2o`0000Cooooo0_l00002ooooo`;o00008Oooool2o`0005gooooo
000Looooo`;o0000/_ooool5o`00017ooooo0ol0000Pooooo`;o0000GOooool001cooooo00?o0000
ooooooooool0ZOooool=o`0000oooooo0_l000000ooooooo0000o`00001oooooo`007?ooool00ol0
003oooooooooo`1`ooooo`;o0000=_ooool:o`000004ooooool0003o0000o`0000?ooooo0_l00007
ooooo`;o000000?oooooo`000?l00000P_ooool001cooooo00?o0000ooooooooool0Joooool3o`00
00;ooooo0_l00006ooooo`;o0000;_ooool6o`000003ooooool0003o000000Sooooo0_l00004oooo
o`;o000000Coooooo`000?l0003o00009oooool2o`0005_ooooo000Looooo`03o`000?oooooooooo
06_ooooo0ol0000:ooooo`;o0000:oooool4o`0000;ooooo0_l0000=ooooo`;o00000oooool3o`00
0004ooooool0003o0000o`0002Kooooo0ol0001Jooooo`007?ooool00ol0003oooooooooo`1Roooo
o`;o00000_ooool4o`0000?ooooo0_l0000eooooo`Go00002_ooool2o`0000Gooooo0_l00003oooo
o`?o00000_ooool3o`0002Kooooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`1Rooooo`;o
00000_ooool4o`0000;ooooo0ol0000eooooo`;o00001oooool2o`0000Cooooo0_l0000@ooooo`;o
00009Oooool3o`0005[ooooo000Looooo`03o`000?oooooooooo05kooooo0_l00008ooooo`;o0000
0_ooool2o`0003Kooooo1_l00003ooooo`;o0000?Oooool2o`000004ooooool0003o0000o`0005Oo
oooo000Looooo`03o`000?oooooooooo05[ooooo0_l000001?oooooo0000o`000?l0000Kooooo`;o
000000Coooooo`000?l0003ooooo0_l0000Qooooo`Ko00004Oooool5o`000003ooooool0003o0000
00;o00002Oooool2o`0001oooooo0ol0001Gooooo`007?ooool00ol0003oooooooooo`1Hooooo`Co
000000?oooooo`000?l000000_l0000Jooooo`So00008_ooool2o`000003ooooool0003o000000Oo
oooo0_l00008ooooo`Go000000?oooooo`000?l000000_l00004ooooo`Co000000Coooooo`000?l0
003o00006oooool2o`0000;ooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o
00001Oooool2o`0001cooooo1Ol0000Mooooo`Co00001Oooool2o`0000Oooooo0_l00003ooooo`;o
00004Oooool4o`0000;ooooo0_l0000Kooooo`?o000000?oooooo`000?l00000Eoooool001cooooo
00?o0000ooooooooool0NOooool2o`0000?ooooo0ol00003ooooo`;o00006Oooool4o`0000?ooooo
0_l00005ooooo`;o00001oooool2o`000005ooooool0003o0000o`000?ooool00_l00002ooooo`;o
00001_ooool3o`00027ooooo1_l0001Fooooo`007?ooool00ol0003oooooooooo`1iooooo`;o0000
0oooool2o`0000Cooooo0ol0000Gooooo`[o00001Oooool2o`0000[ooooo0ol000000ooooooo0000
o`000002ooooo`?o00001_ooool2o`0000?ooooo0_l0000Nooooo`Co0000E_ooool001cooooo00?o
0000ooooooooool0EOooool3o`0001[ooooo1Ol000000ooooooo0000o`000002ooooo`Go00000ooo
ool3o`0001Gooooo2_l00004ooooo`?o00001_ooool2o`0000Cooooo0ol000001?oooooo0000o`00
0?l00002ooooo`;o00002oooool2o`0001gooooo1Ol0001Fooooo`007?ooool00ol0003ooooooooo
o`1Eooooo`?o00006_ooool5o`000003ooooool0003o000000;ooooo1Ol00003ooooo`;o00005_oo
ool4o`000003ooooool0003o000000;o000000?oooooo`000?l000000_ooool3o`0000Kooooo0_l0
0004ooooo`?o000000Coooooo`000?l0003o00001?ooool4o`0002Gooooo0ol000000ooooooo0000
o`00001Fooooo`007?ooool00ol0003oooooooooo`1booooo`Co000000Goooooo`000?l0003o0000
ooooo`02o`0000[ooooo0ol0000Eooooo`;o00001Oooool2o`0000Gooooo0_l00002ooooo`co0000
00?oooooo`000?l000001?ooool4o`0000Wooooo0_l0000Jooooo`?o000000?oooooo`000?l00000
E_ooool001cooooo0_l0001aooooo`Ko000000?oooooo`000?l000000_ooool2o`0000;ooooo1_l0
0002ooooo`Co00003oooool7o`0000cooooo4ol00004ooooo`;o00002oooool2o`0001[ooooo1_l0
001Fooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00007?ooool4o`0000Oooooo0ol00000
0ooooooo0000o`000006o`0000Cooooo0_l0000?ooooo`Go00000_ooool2o`0000[ooooo5?l00004
ooooo`?o00001_ooool2o`0001gooooo1_l0001Fooooo`007?ooool00ol0003oooooooooo`1@oooo
o`;o00007?ooool2o`0000Gooooo3?l000000ooooooo0000o`000005ooooo`?o00005Oooool2o`00
00Sooooo5_l00004ooooo`?o00001_ooool3o`0001_ooooo1ol0001Fooooo`007?ooool00ol0003o
ooooooooo`1/ooooo`Co00001?ooool=o`0000Wooooo0_l0000?ooooo`;o00003Oooool8o`000003
ooooool0003o000000ko00000oooool3o`0000Kooooo0_l0000Kooooo`Go0000F?ooool001cooooo
00?o0000ooooooooool0K?ooool2o`0000Gooooo0ol00003ooooo`So00001?ooool2o`0000?ooooo
0_l00002ooooo`;o00002oooool2o`0000Sooooo1?l000000ooooooo0000o`000004o`0000?ooooo
0_l000000ooooooo0000o`00000=o`000003ooooool0003o000000?o00001?ooool2o`0001Wooooo
0_l000000ooooooo0000o`000002o`0005Sooooo000Looooo`03o`000?oooooooooo07?ooooo3ol0
0003ooooo`;o00000oooool2o`0000;ooooo0_l0000Eooooo`Oo00002OoooolAo`0000;ooooo0ol0
0005ooooo`;o000000Coooooo`000?l0003o00005?ooool2o`000003ooooool0003o000005[ooooo
000Looooo`03o`000?oooooooooo06Wooooo0_l00007ooooo`;o000000?oooooo`000?l000001_l0
00000ooooooo0000o`000002o`0000Gooooo0_l00005ooooo`Ko00000_ooool2o`000003ooooool0
003o000000gooooo1?l00009oooooa;o000000?oooooo`000?l000001_ooool2o`000004ooooool0
003o0000o`0001Cooooo1Ol0001Jooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00006_oo
ool3o`0000Kooooo4ol00003ooooo`;o00001Oooool6o`0000;ooooo1ol0000;ooooo`Co00000_oo
ool2o`000003ooooool0003o000000;ooooo3ol000000ooooooo0000o`000002o`000003ooooool0
003o000001kooooo1Ol0001Jooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00006_ooool2
o`0000Kooooo5?l00003ooooo`;o00002_ooool2o`0000;ooooo0_l00002ooooo`;o00002Oooool5
o`0000?ooooo1Ol000000ooooooo0000o`00000Fo`0001kooooo1Ol0001Jooooo`007?ooool00ol0
003oooooooooo`1`oooooaGo00003_ooool2o`00013ooooo0ol000000ooooooo0000o`000003oooo
o`Go000000?oooooo`000?l000003Ol000000ooooooo0000o`000008o`0001_ooooo1Ol0001Koooo
o`007?ooool00ol0003oooooooooo`1Vooooo`;o00002OoooolDo`0000_ooooo0_l0000Booooo`Co
00001_oooolMo`000003ooooool0003o000000;o00000oooool2o`0001Cooooo1Ol000001?oooooo
0000o`000?l0001Gooooo`007?ooool00ol0003oooooooooo`1Vooooo`;o00001ooooolFo`0000Go
oooo0_l00004ooooo`Co00004?ooool4o`0000Kooooo1?l000000ooooooo0000o`00000Ho`000004
ooooool0003o0000o`0000;ooooo0_l0000Cooooo`Ko000000Coooooo`000?l0003o0000Eoooool0
01cooooo00?o0000ooooooooool0IOooool3o`0000Oooooo6?l00003ooooo`;o00001_ooool2o`00
0003ooooool0003o000000oooooo0_l00006oooooaSo000000Goooooo`000?l0003o0000ooooo`02
o`0000;ooooo0_l000000ooooooo0000o`00000Dooooo`;o00000_ooool2o`0005_ooooo000Loooo
o`03o`000?oooooooooo06Gooooo1?l00006oooooaCo00000_ooool2o`0000Sooooo0_l000001?oo
oooo0000o`000?ooool2o`0000oooooo0_l00006oooooaSo000000Coooooo`000?l0003o00001ooo
ool3o`0001Cooooo0_l000001?oooooo0000o`000?l00003ooooo`;o0000E_ooool001cooooo00?o
0000ooooooooool0I?ooool5o`0000Kooooo5Ol000000ooooooo0000o`000008ooooo`;o00000ooo
ool2o`0001Wooooo5_l00003ooooo`;o00001oooool2o`0001Gooooo0_l000000ooooooo0000o`00
0004ooooo`Co0000E?ooool001cooooo00?o0000ooooooooool0I?ooool4o`0000Sooooo5Ol0000:
ooooo`;o00000oooool2o`000003ooooool0003o000000Oooooo0_l00003ooooo`;o000000?ooooo
o`000?l000001_ooool;o`000003ooooool0003o000000Oo000000?oooooo`000?l000007oooool2
o`0000;ooooo0_l00006ooooo`;o000000?oooooo`000?l00000DOooool001cooooo0_l0001Uoooo
o`?o00002OoooolEo`0001;ooooo0_l00007ooooo`;o00000oooool2o`000003ooooool0003o0000
00Kooooo5Ol000000ooooooo0000o`000006ooooo`;o00005oooool3o`0000cooooo0_l0001Aoooo
o`007?ooool00ol0003oooooooooo`13ooooo`;o00007oooool3o`0000Sooooo5Ol00009ooooo`;o
00006Oooool2o`0000Kooooo5_l00008ooooo`;o00005oooool3o`0005oooooo000Looooo`03o`00
0?oooooooooo04?ooooo0_l0000Oooooo`?o00002?oooolEo`0000Cooooo1?l000000ooooooo0000
o`00000Cooooo`;o00000oooool3o`0000Kooooo6?l000000ooooooo0000o`000002ooooo`Co0000
5_ooool2o`00063ooooo000Looooo`03o`000?oooooooooo06Cooooo0ol00008oooooa?o00001_oo
ool4o`0000Cooooo1Ol0000=ooooo`;o00000oooool2o`0000Sooooo5ol000001?oooooo0000o`00
0?ooool6o`0001Gooooo1?l0000:ooooo`Co000000?oooooo`000?l000000oooool2o`0004Sooooo
000Looooo`03o`000?oooooooooo06Cooooo0_l00009ooooo`;o000000?oooooo`000?l000004?l0
000<ooooo`Go00004_ooool2o`0000Sooooo5_l00005ooooo`;o000000Coooooo`000?l0003o0000
5Oooool4o`0000[ooooo1?l000000ooooooo0000o`000003ooooo`;o0000B?ooool001cooooo00?o
0000ooooooooool0@Oooool2o`00027ooooo0_l0000=oooooa;o00002oooool2o`00017ooooo0_l0
0002ooooo`;o000000?oooooo`000?l000001?ooool6o`000003ooooool0003o000000ko000000?o
ooooo`000?l000001_ooool2o`0001Gooooo0_l0000Cooooo`;o0000Boooool001cooooo00?o0000
ooooooooool0@Oooool2o`0002;ooooo0_l00009ooooo`;o000000?oooooo`000?l000004?l00009
ooooo`?o00004_ooool2o`0000;ooooo1Ol00004ooooo`;o000000?oooooo`000?l000005Ol00003
ooooo`Go00005?ooool3o`0000Kooooo0_l0000;ooooo`;o0000Boooool001cooooo00?o0000oooo
ooooool0I?ooool5o`0000Oooooo5ol00007ooooo`?o00006?ooool2o`0000Gooooo6Ol00004oooo
o`Co000000?oooooo`000?l000004_ooool2o`0000Oooooo0_l0000>ooooo`;o0000B?ooool001co
oooo00?o0000ooooooooool0I?ooool5o`0000Kooooo4_l00002ooooo`Co000000?oooooo`000?l0
00002?ooool2o`0001Gooooo0ol00004ooooo`Co000000?oooooo`000?l000004Ol00005ooooo`?o
00000_ooool2o`0001;ooooo0_l00007ooooo`;o000000?oooooo`000?l000002oooool2o`0004So
oooo000Looooo`03o`000?oooooooooo03oooooo0_l0000Uooooo`?o00001_oooolCo`0000Kooooo
0_l00008ooooo`;o00005_ooool2o`0000Oooooo0_l000000ooooooo0000o`00000Ao`0000Sooooo
0ol0000Booooo`Go00001oooool2o`0000Gooooo0_l0001>ooooo`007?ooool00ol0003ooooooooo
o`0oooooo`;o00009?ooool4o`0000Kooooo0_l00002ooooo`[o00000_ooool3o`00033ooooo0ol0
0004oooooa3o00000_ooool4o`0000;ooooo0_l0000Dooooo`Co00000oooool2o`0000Wooooo0_l0
0008ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0IOooool4o`0000[ooooo0_l00000
0ooooooo0000o`000004o`0000?ooooo1?l00002ooooo`;o00001_ooool2o`000003ooooool0003o
0000023ooooo0_l00005oooooa3o00000_ooool4o`000003ooooool0003o000001Gooooo0_l00005
ooooo`;o00002?ooool2o`0000Wooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0loooo
o`;o0000@Oooool4o`0000;ooooo1?l00004ooooo`;o000000?oooooo`000?l000007?ooool2o`00
00Oooooo1?l000000ooooooo0000o`000007o`0000;ooooo0ol000000ooooooo0000o`000002o`00
0003ooooool0003o000001Gooooo0_l0000?ooooo`;o00001Oooool2o`0004Sooooo000Looooo`03
o`000?oooooooooo03cooooo0_l0000[ooooo`;o000000Coooooo`000?l0003ooooo0_l00007oooo
o`;o00002oooool4o`0002Gooooo0_l00007ooooo`Co00000oooool>o`0001gooooo0_l00008oooo
o`;o00001?ooool2o`0000Cooooo0_l00018ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5
ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0J?ooool3
o`000003ooooool0003o000000Wo000000?oooooo`000?l000002?ooool2o`000004ooooool0003o
0000o`00037ooooo1?l000000ooooooo0000o`00000<o`0001gooooo0_l00008ooooo`;o00000ooo
ool3o`0004kooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0J?ooool3o`0000;ooooo0_l000000ooooooo0000
o`000005o`0000Kooooo0_l00003ooooo`;o0000:?ooool3o`0000Kooooo1?l00002ooooo`;o0000
00?oooooo`000?l000001Oooool3o`0000;ooooo0_l0000Mooooo`;o00003Oooool2o`0000Kooooo
0_l00017ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`Go00001_oo
ool00ol0003oooooooooo`1_ooooo`?o000000?oooooo`000?l000000oooool2o`0000;ooooo0ol0
0002ooooo`;o00000oooool2o`0001?ooooo0_l00008ooooo`;o00001Oooool3o`0000Kooooo1?l0
000>ooooo`;o00008?ooool3o`00017ooooo0_l000000ooooooo0000o`000017ooooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0
000jooooo`;o0000<oooool2o`0000Oooooo0_l00002ooooo`;o00000oooool2o`0000?ooooo0_l0
00000ooooooo0000o`00000@ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Sooooo0_l0
0007ooooo`;o00003Oooool2o`00027ooooo0_l0000Aooooo`;o00000_ooool2o`0004Kooooo0000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo00001ooo
ool00ol0003oooooooooo`0jooooo`;o0000;Oooool3o`0000?ooooo0ol00006ooooo`;o00000_oo
ool2o`0000Cooooo0_l00005ooooo`;o00004oooool2o`000003ooooool0003o000000[ooooo1?l0
0003ooooo`;o00000_ooool2o`000003ooooool0003o000003Gooooo0_l00002ooooo`?o00002?oo
ool2o`0004Kooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oMgMg
olc<c?l000001oooool00ol0003oooooooooo`0jooooo`;o0000;Oooool3o`0000?ooooo0ol00005
ooooo`;o00002Oooool2o`0001gooooo0_l0000:ooooo`;o00001Oooool2o`0000Gooooo0_l0000<
ooooo`;o00009oooool2o`0000;ooooo0ol0000=ooooo`;o0000@Oooool00006oooooomgMgOoV9RH
oooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo03Oooooo0_l0
000aooooo`;o00001Oooool3o`0000?ooooo0_l0000@ooooo`;o00004Oooool2o`0001;ooooo0_l0
000?ooooo`;o00001Oooool3o`0003Kooooo0_l00003ooooo`;o0000@Oooool00006ooooooo^k^ko
<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo03Oooooo
0_l0000aooooo`;o00001Oooool3o`0000Kooooo0_l0000=ooooo`Co00002?ooool2o`0000Gooooo
0_l0000Booooo`;o00003oooool2o`0000Gooooo0_l0000Xooooo`;o00001?ooool2o`0000Gooooo
1?l00016ooooo`007?ooool00ol0003oooooooooo`1Zooooo`;o00001Oooool3o`0000Kooooo0_l0
000?ooooo`;o00002?ooool2o`0000Gooooo0_l0000Sooooo`;o0000;oooool3o`0000?ooooo0_l0
0005ooooo`Co0000A_ooool001cooooo00?o0000ooooooooool0=Oooool2o`0003?ooooo0ol00004
ooooo`;o0000:Oooool2o`0001Kooooo0_l00004ooooo`;o00001Oooool3o`0002oooooo1?l00003
ooooo`;o000000?oooooo`000?l000000_ooool2o`0004Kooooo000Looooo`03o`000?oooooooooo
03Gooooo0_l0000Uooooo`;o00001Oooool5o`0000?ooooo0_l00003ooooo`?o0000=_ooool2o`00
00Wooooo0ol00003ooooo`;o00001_ooool2o`00037ooooo0_l00003ooooo`;o000000Goooooo`00
0?l0003o0000ooooo`02o`0004Kooooo000Looooo`03o`000?oooooooooo03Kooooo0_l0000Qoooo
o`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000006o`0000;ooooo0_l00003oooo
o`?o00002oooool2o`0002Kooooo0_l000000ooooooo0000o`000008ooooo`Go00002Oooool2o`00
00[ooooo0_l0000Pooooo`;o00003?ooool3o`000004ooooool0003o0000o`0004Gooooo000Loooo
o`03o`000?oooooooooo03Kooooo0_l0000Qooooo`;o00000oooool2o`000003ooooool0003o0000
00;ooooo1?l00002ooooo`;o00000oooool3o`0000Gooooo0_l00004ooooo`;o00000oooool2o`00
027ooooo0_l0000;ooooo`Go00002Oooool2o`0000[ooooo0_l0000Pooooo`;o00001?ooool2o`00
00_ooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o000000?oooooo`000?l0
00000_ooool2o`000003ooooool0003o000000?o00001?ooool2o`0000;ooooo0_l000000ooooooo
0000o`000009ooooo`;o00005?ooool2o`0000Oooooo0_l0000Aooooo`;o00003Oooool4o`0000Go
oooo0ol0000Oooooo`;o00001?ooool2o`0000_ooooo0_l00015ooooo`007?ooool00ol0003ooooo
ooooo`0hooooo`;o00007_ooool8o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000
o`000003o`0000Sooooo0_l0000Rooooo`;o00001oooool2o`0000?ooooo0_l00008ooooo`;o0000
4Oooool4o`0000Kooooo0_l0000Oooooo`;o00001?ooool2o`0000Cooooo0_l00006ooooo`;o0000
A?ooool001cooooo00?o0000ooooooooool0>?ooool2o`0001kooooo2?l000000ooooooo0000o`00
0005ooooo`Go00000_ooool3o`0002[ooooo0_l00005ooooo`;o00000_ooool2o`000003ooooool0
003o000000Gooooo0_l0000;ooooo`;o00002?ooool2o`0000Oooooo0_l0000Looooo`?o00000ooo
ool2o`0000?ooooo0ol00006ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0=Oooool2
o`0001Cooooo0_l0000@ooooo`?o00000oooool2o`0000Cooooo1Ol000001?oooooo0000o`000?l0
000Vooooo`Ko00001Oooool2o`0000Gooooo1?l0000<ooooo`;o00000_ooool2o`0000?ooooo0_l0
00000ooooooo0000o`000002o`0000Oooooo1?l0000Jooooo`?o00000oooool2o`0000?ooooo0_l0
00000ooooooo0000o`000002o`000004ooooool0003o0000o`0004Cooooo000Looooo`03o`000?oo
oooooooo03Gooooo0_l000000ooooooo0000o`00000Aooooo`;o00004?ooool5o`000003ooooool0
003o000000Cooooo1Ol0000Zooooo`Co00004?ooool2o`0000cooooo0_l00007ooooo`Go00002ooo
ool4o`000004ooooool0003o0000o`0001Cooooo0_l00009ooooo`Oo000000Coooooo`000?l0003o
0000A?ooool001cooooo00?o0000ooooooooool0=?ooool3o`000003ooooool0003o0000023ooooo
0ol00003ooooo`?o0000=?ooool5o`0000Oooooo0_l00002ooooo`;o00005Oooool2o`0000Cooooo
0_l0000?ooooo`;o000000Coooooo`000?l0003o00005?ooool2o`0000Oooooo0_l00002ooooo`;o
00001Oooool2o`0004Cooooo000Looooo`;o0000<oooool5o`000003ooooool0003o000000gooooo
0_l0000Aooooo`Go000000Coooooo`000?l0003o00001_ooool5o`0002Wooooo0_l000000ooooooo
0000o`000007ooooo`;o00000_ooool2o`0000?ooooo0_l0000@ooooo`;o00003oooool4o`0000Ko
oooo0_l0000Kooooo`Co00001_ooool6o`0004?ooooo000Looooo`03o`000?oooooooooo03;ooooo
0_l00004ooooo`;o00003Oooool2o`0000kooooo2_l00008ooooo`Wo00001_ooool2o`0003;ooooo
0_l0000Kooooo`;o00001?ooool6o`0000;ooooo1?l0000Kooooo`;o00001?ooool2o`0000;ooooo
1_l00013ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00002Oooool2o`00017ooooo3Ol0
0006ooooo`Wo000000?oooooo`000?l000000oooool2o`0000kooooo0_l0000Booooo`;o00003_oo
ool2o`0000cooooo0_l00004ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Sooooo1ol0
000Looooo`;o00001?ooool4o`000003ooooool0003o000000?o0000@oooool001cooooo00?o0000
ooooooooool0=oooool2o`0000[ooooo0_l0000>oooooa3o00001_ooool9o`000003ooooool0003o
000000kooooo0_l00003ooooo`;o00004_ooool2o`0000Kooooo0_l0000Dooooo`;o00000oooool7
o`0000Sooooo1Ol00002ooooo`;o00009Oooool4o`000003ooooool0003o000000?o0000@oooool0
01cooooo00?o0000ooooooooool0=oooool2o`0000Sooooo1?l0000=ooooo`Co00000_ooool;o`00
0003ooooool0003o000000Cooooo2_l0000?ooooo`;o00004oooool2o`0000Kooooo0_l00002oooo
o`;o00000_ooool2o`0001Gooooo0_l000000ooooooo0000o`000002o`0000Sooooo1Ol00005oooo
o`;o00001?ooool2o`0001cooooo0ol00004ooooo`;o0000A?ooool001cooooo00?o0000oooooooo
ool0<oooool2o`000003ooooool0003o000000Wooooo0_l0000<ooooo`;o000000?oooooo`000?l0
00002Ol000000ooooooo0000o`000003o`000003ooooool0003o000000?ooooo0ol00002ooooo`;o
00000_ooool2o`0001Wooooo0ol00008ooooo`;o00001_ooool2o`0000Kooooo0_l0000Cooooo`;o
00000oooool2o`0000Sooooo1?l00008ooooo`So00007?ooool3o`0000Cooooo0ol00013ooooo`00
7?ooool00ol0003oooooooooo`0cooooo`;o000000?oooooo`000?l000001oooool2o`0000gooooo
5Ol000000ooooooo0000o`000003ooooo`;o00002Oooool2o`00017ooooo1?l00002ooooo`?o0000
1oooool3o`0000Kooooo1?l00006ooooo`;o00000_ooool2o`0000gooooo0_l00003ooooo`;o0000
1oooool6o`0000?ooooo0ol00003ooooo`Oo00004oooool2o`0000Kooooo0_l00005ooooo`?o0000
@oooool001cooooo00?o0000ooooooooool0?oooool2o`0000gooooo5?l000001Ooooooo0000o`00
0?l0003ooooo00;o00002?ooool2o`000003ooooool0003o000000gooooo0_l00002ooooo`Ko0000
2_ooool3o`0000Kooooo1?l00005ooooo`?o00000_ooool2o`0001Sooooo0_l000000ooooooo0000
o`000005o`0000;ooooo0ol00004ooooo`;o00000_ooool2o`0001?ooooo0_l0001Cooooo`007?oo
ool00ol0003oooooooooo`0booooo`Co00002?ooool2o`0000gooooo5Ol000000ooooooo0000o`00
0004o`0000?ooooo0_l00003ooooo`;o00004?ooool2o`000003ooooool0003o000000?ooooo0_l0
0008ooooo`;o00001_ooool2o`0000;ooooo0_l00006ooooo`;o00007Oooool2o`0000;ooooo1ol0
0008ooooo`Ko00004oooool4o`0000_ooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0`
ooooo`Ko00002?ooool3o`0000cooooo6_l00004ooooo`?o00005Oooool2o`000003ooooool0003o
000000gooooo1?l00004ooooo`;o00000_ooool3o`0000Gooooo0_l0000Mooooo`;o00000_ooool9
o`0000Oooooo1?l0000Fooooo`;o00002oooool2o`0004Cooooo000Looooo`03o`000?oooooooooo
033ooooo0_l0000=ooooo`;o00002Oooool3o`000003ooooool0003o000001Oo00001?ooool2o`00
00_ooooo0_l00004ooooo`;o00000oooool2o`0000gooooo1ol00004ooooo`;o000000?oooooo`00
0?l000000ol0000Wooooo`Go00000_ooool3o`0000Kooooo1Ol0000Looooo`;o00001?ooool2o`00
04Cooooo000Looooo`03o`000?oooooooooo04[ooooo7ol0000=ooooo`Co000000?oooooo`000?l0
00000ol0000Booooo`Go00001_ooool2o`000004ooooool0003o0000ooooo`;o0000:_ooool4o`00
0003ooooool0003o000000?o00001_ooool2o`0001cooooo0_l00004ooooo`;o00007Oooool2o`00
02Gooooo000Looooo`03o`000?oooooooooo04Sooooo8Ol00002ooooo`?o00002?ooool2o`0000?o
oooo1?l00008ooooo`;o00002Oooool7o`0001;ooooo0_l0000Sooooo`Co00000_ooool3o`0002Co
oooo0_l00004ooooo`;o00007Oooool2o`0002Gooooo000Looooo`03o`000?oooooooooo03cooooo
0_l0000:oooooaoo00001?ooool3o`0001Wooooo0_l00009ooooo`Oo00002oooool2o`0000Gooooo
0_l0000Uooooo`;o000000?oooooo`000?l000000ol0000Eooooo`;o00001Oooool2o`0000Gooooo
0ol00019ooooo`007?ooool00ol0003oooooooooo`0jooooo`Co00002Oooool2o`000003ooooool0
003o000001_o00005Oooool2o`0000kooooo0_l0000Fooooo`;o0000;?ooool2o`000003ooooool0
003o000000?o00005Oooool2o`0000Gooooo1?l00004ooooo`;o00008Oooool2o`0002Kooooo000L
ooooo`03o`000?oooooooooo03[ooooo0_l0000;ooooob3o00005?ooool3o`0000kooooo0_l0000I
ooooo`;o00003oooool2o`0001Wooooo1ol0000Nooooo`;o00009Oooool4o`0002Kooooo000Loooo
o`;o0000BOoooolNo`000003ooooool0003o000001;ooooo0ol0000Yooooo`;o00003oooool2o`00
01Kooooo0_l000001Ooooooo0000o`000?l0003ooooo00Go00000oooool2o`0001gooooo0_l0000O
ooooo`Co00009_ooool001cooooo00?o0000ooooooooool0A_oooolPo`000003ooooool0003o0000
01?ooooo0_l000000ooooooo0000o`00000Uooooo`?o00008?ooool2o`000003ooooool0003o0000
00Co000000?oooooo`000?l000000_l000000ooooooo0000o`000002o`0000?ooooo0_l0000Moooo
o`;o00001?ooool2o`0001Wooooo0ol0000Wooooo`007?ooool00ol0003oooooooooo`16oooooaco
000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000cooooo0_l000000ooooooo
0000o`000002ooooo`;o00009Oooool5o`000004ooooool0003o0000ooooo`;o000000?oooooo`00
0?l000005Oooool2o`000003ooooool0003o000000Wo000000?oooooo`000?l000000ol00002oooo
o`;o00007Oooool2o`0000Cooooo0_l0000Iooooo`?o00009oooool001cooooo00?o0000oooooooo
ool0AooooolJo`0000Sooooo1?l00004ooooo`;o00001Oooool2o`000003ooooool0003o000000?o
oooo0_l0000Kooooo`Co00001oooool3o`000004ooooool0003o0000ooooo`Ko00005?ooool?o`00
0003ooooool0003o000000;o000000?oooooo`000?l000000ol0000Kooooo`;o00001?ooool2o`00
04?ooooo000Looooo`03o`000?oooooooooo04Gooooo0_l00002oooooaSo00002?ooool4o`000004
ooooool0003o0000ooooo`;o00003Oooool2o`0001Sooooo1ol000000ooooooo0000o`000008oooo
o`;o00000oooool4o`00017ooooo5Ol00002ooooo`Ko00003oooool2o`0000_ooooo0ol00017oooo
o`007?ooool00ol0003oooooooooo`15ooooo`;o00000_oooolIo`0000;ooooo0_l00005ooooo`;o
000000?oooooo`000?l000002_ooool2o`0001kooooo1?l00004ooooo`?o00000oooool3o`0000Oo
oooo0_l0000Aoooooa[o000000Coooooo`000?l0003ooooo0_l00009ooooo`;o00000_ooool2o`00
0003ooooool0003o000000Sooooo0ol00017ooooo`007?ooool00ol0003oooooooooo`0gooooo`;o
00004oooool7o`000003ooooool0003o000000co00000_ooool2o`0000;ooooo0_l000000ooooooo
0000o`00000=ooooo`;o00008oooool2o`0000;ooooo1?l000001?oooooo0000o`000?l00007oooo
o`;o00004?ooool7o`000003ooooool0003o000000co000000?oooooo`000?l000001_ooool2o`00
00Wooooo0_l00005ooooo`;o00002Oooool2o`0001[ooooo0_l0000[ooooo`007?ooool00ol0003o
ooooooooo`0fooooo`Go00000_ooool2o`0000Kooooo0_l00003ooooo`;o000000?oooooo`000?l0
00002Ol000000ooooooo0000o`000007o`0000Kooooo0_l00005ooooo`?o0000;Oooool8o`000003
ooooool0003o000000?o00001Oooool2o`00013ooooo1ol000000ooooooo0000o`000009o`000003
ooooool0003o000001_ooooo0_l0000Tooooo`?o0000:oooool001cooooo00?o0000ooooooooool0
=_ooool2o`000003ooooool0003o000000;ooooo0_l00006ooooo`;o00000_oooolHo`0000Wooooo
1?l000000ooooooo0000o`000003o`0002[ooooo1Ol00002ooooo`So00001Oooool2o`0000kooooo
2Ol000000ooooooo0000o`000005o`000003ooooool0003o000000Oo00002?ooool2o`0000_ooooo
0_l000000ooooooo0000o`00000Tooooo`?o0000:oooool001cooooo00?o0000ooooooooool0AOoo
ool3o`000003ooooool0003o0000017o00003_ooool4o`0000;ooooo1?l0000Vooooo`;o00000_oo
ool5o`000003ooooool0003o000000?o00006?oooolBo`000003ooooool0003o000000;o00000_oo
ool4o`0000?ooooo0_l00002ooooo`;o00002oooool5o`0000Wooooo0_l0000Iooooo`?o0000:ooo
ool001cooooo00?o0000ooooooooool0A_ooool2o`000003ooooool0003o000000?ooooo3?l00005
ooooo`;o000000?oooooo`000?l000003Oooool2o`0002Oooooo4?l00004ooooo`;o00004OoooolG
o`000003ooooool0003o000000?o00000oooool2o`0000Wooooo0_l00006ooooo`;o00002Oooool3
o`0001Sooooo0_l0000]ooooo`007?ooool00ol0003oooooooooo`16ooooo`Co00001Oooool3o`00
00;ooooo1?l00007ooooo`;o000000?oooooo`000?l000002oooool4o`0002Sooooo0ol000000ooo
oooo0000o`000004o`000003ooooool0003o000000?o00000oooool2o`00013ooooo1?l000000ooo
oooo0000o`00000Go`0000kooooo0_l0000Aooooo`Go00005_ooool2o`0002gooooo000Looooo`03
o`000?oooooooooo03[ooooo0_l0000;ooooo`?o00001?ooool6o`000003ooooool0003o000001Ko
oooo1?l0000Wooooo`oo00000_ooool2o`000003ooooool0003o0000017ooooo7ol00002ooooo`;o
00004Oooool2o`0000_ooooo1?l00015ooooo`007?ooool00ol0003oooooooooo`0eooooo`;o0000
0oooool2o`0000_ooooo0ol00002ooooo`So000000?oooooo`000?l000004_ooool2o`0000;ooooo
0_l0000Xooooo`So000000Coooooo`000?l0003ooooo1?l00002ooooo`;o000000?oooooo`000?l0
00004?oooolPo`0000;ooooo0_l0000>ooooo`Go00002Oooool3o`0001Oooooo0_l0000_ooooo`00
7?ooool00ol0003oooooooooo`0eooooo`;o00004Oooool2o`0000;ooooo0_l00002ooooo`;o0000
5oooool2o`0002Wooooo2ol00004ooooo`Co00000_ooool7o`0000kooooo8?l0000Booooo`Go0000
2?ooool4o`0001Oooooo0_l0000_ooooo`007?ooool00ol0003oooooooooo`18ooooo`?o000000Co
ooooo`000?l0003ooooo0_l0000Jooooo`;o00009_ooool>o`000003ooooool0003o000000?o0000
0_ooool7o`0000gooooo1?l000000ooooooo0000o`00000Jo`0000;ooooo0_l00006ooooo`;o0000
1oooool3o`000003ooooool0003o000000Gooooo0ol0000Gooooo`Co0000;oooool001cooooo0_l0
001:ooooo`;o000000Coooooo`000?l0003ooooo1_l0000Fooooo`;o00009?oooolEo`000003oooo
ool0003o000000Co00004?oooolQo`0000;ooooo0_l00006ooooo`;o00001oooool6o`0000Gooooo
0ol0000Fooooo`?o0000<Oooool001cooooo00?o0000ooooooooool0=Oooool2o`0001Sooooo1ol0
000=ooooo`?o0000:ooooolAo`000005ooooool0003o0000o`000?ooool00_l000000ooooooo0000
o`00000?ooooobCo00002Oooool2o`0000Oooooo1?l00007ooooo`;o00005oooool2o`0003;ooooo
000Looooo`03o`000?oooooooooo03Cooooo0ol0000Mooooo`Co00002oooool3o`0002Wooooo5_l0
00000ooooooo0000o`00000Cooooob7o000000?oooooo`000?l000004Oooool3o`0000Sooooo1?l0
001:ooooo`007?ooool00ol0003oooooooooo`0dooooo`;o00008?ooool2o`000003ooooool0003o
000000Cooooo0_l0000^oooooaKo000000?oooooo`000?l000004ooooolQo`0000?ooooo0_l0000?
ooooo`?o00002?ooool4o`0001Cooooo0ol0000cooooo`007?ooool00ol0003oooooooooo`0doooo
o`;o00008oooool2o`0000Cooooo0_l0000^oooooaGo00005ooooolPo`0000Cooooo0_l00004oooo
o`;o00000oooool2o`0000oooooo0ol0000Eooooo`?o0000<oooool001cooooo00?o0000oooooooo
ool0=?ooool2o`0005Wooooo5Ol000000ooooooo0000o`00000Cooooob7o00000oooool2o`0000?o
oooo1?l00003ooooo`;o00000oooool2o`0000Sooooo0ol0000Fooooo`;o0000=Oooool001cooooo
00?o0000ooooooooool0=?ooool2o`0005Sooooo5?l00002ooooo`Co00004OoooolRo`0000?ooooo
0_l00003ooooo`;o00002_ooool2o`0000Oooooo1?l0000Fooooo`;o0000=Oooool001cooooo00?o
0000ooooooooool0=?ooool2o`0005Sooooo5?l00002ooooo`Co00004OoooolPo`00017ooooo0_l0
000<ooooo`;o00006?ooool2o`0003Gooooo000Looooo`03o`000?oooooooooo03Cooooo0_l0001G
oooooaKo00000oooool2o`00017ooooo7ol0000Booooo`;o00000oooool2o`0005Sooooo000Loooo
o`03o`000?oooooooooo08_ooooo5Ol000000ooooooo0000o`000003ooooo`;o00004OoooolPo`00
017ooooo0_l00003ooooo`Co00000oooool2o`0001Sooooo0_l0000gooooo`007?ooool00ol0003o
ooooooooo`0dooooo`;o0000E?oooolFo`000004ooooool0003o0000o`0001Gooooo7Ol000000ooo
oooo0000o`000003ooooo`;o00000_ooool2o`0000Sooooo0_l00005ooooo`;o00000_ooool3o`00
01Sooooo0_l0000gooooo`007?ooool00ol0003oooooooooo`0dooooo`;o0000E?oooolDo`0000?o
oooo0ol0000Doooooaoo00001Oooool2o`0000;ooooo0_l00009ooooo`;o00000_ooool2o`0000?o
oooo0ol0001Booooo`007?ooool00ol0003oooooooooo`0dooooo`;o0000D_ooool2o`000003oooo
ool0003o0000013o00001Oooool2o`0001Cooooo2?l00002oooooaOo00001?ooool2o`0000Oooooo
0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l0001Cooooo`007?ooool00ol0003ooooooooo
o`0dooooo`;o0000C?ooool2o`0000Cooooo0_l000000ooooooo0000o`00000@o`000003ooooool0
003o000001Sooooo1?l000000ooooooo0000o`000004o`000003ooooool0003o000001?o00001?oo
ool2o`0000Oooooo0_l0000Sooooo`;o000000?oooooo`000?l00000>Oooool00006ooooooo^k^ko
<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03
o`000?oooooooooo03Cooooo1?l0001:ooooo`;o00001ooooolEo`0001Sooooo1Ol000000ooooooo
0000o`00000Bo`000004ooooool0003o0000o`0001Cooooo0_l00006ooooo`;o00005oooool2o`00
0003ooooool0003o000003Wooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44
ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0fooooo`;o0000?_oo
ool4o`0000Gooooo0ol00004ooooo`;o00000_oooolFo`0001Sooooo1Ol000000ooooooo0000o`00
000Ao`0000;ooooo0ol000000ooooooo0000o`000005ooooo`;o00002_ooool2o`0000Kooooo0_l0
000Gooooo`;o0000??ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0M_ooool4o`0000Cooooo1?l0
00001?oooooo0000o`000?ooool2o`0000;ooooo3Ol000000ooooooo0000o`000002ooooo`Co0000
6?ooool:o`000004ooooool0003o0000ooooo`[o00001?ooool2o`000003ooooool0003o000000Go
oooo0_l00009ooooo`Co00000oooool5o`0001Kooooo0_l0000looooo`0000?oooooo`000?ooool0
0_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`00077o
oooo0_l0000;ooooo`Co000000?oooooo`000?l000000_l00003ooooo`[o00001?ooool2o`0000;o
oooo0_l0000Jooooo`So00003?ooool2o`0000Gooooo0_l0000Dooooo`Co00000oooool2o`000003
ooooool0003o000001?ooooo1Ol0000looooo`0000?oooooo`000?ooool00_ooool00ol0003ooooo
ooooo`09ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`1aooooo`;o
00001Oooool4o`0000;ooooo0_l00003ooooo`Co00001?ooool8o`0000Gooooo0_l0000Aooooo`;o
00002oooool8o`0000Kooooo0_l0000:ooooo`?o00006_ooool2o`0001Oooooo1?l0000mooooo`00
00?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo
00?o0000ooooooooool0Moooool:o`0000;ooooo0ol00003ooooo`Oo000000?oooooo`000?l00000
5oooool3o`0000_ooooo2?l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000Oooooo
0_l0000Kooooo`;o0000F?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo
410@oiRHV008ooooo`03o`000?oooooooooo03Kooooo0_l0000mooooo`go000000?oooooo`000?l0
00000ol000000ooooooo0000o`000003o`0001cooooo0_l0000<ooooo`So000000Coooooo`000?l0
003o00001Oooool2o`0000Sooooo0_l0000booooo`?o0000?oooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo03Kooooo0ol0
000eooooo`;o00001Oooool>o`000003ooooool0003o000000?o00002?ooool4o`0001Gooooo0_l0
0002ooooo`;o00002Oooool3o`0000?ooooo1?l00008ooooo`;o00000_ooool2o`0000;ooooo0_l0
000Aooooo`;o00007_ooool4o`0003oooooo000Looooo`03o`000?oooooooooo03Oooooo0_l0000d
ooooo`?o00001OoooolAo`000003ooooool0003o000000Sooooo1?l0000Eooooo`;o00000_ooool2
o`0000[ooooo0_l00003ooooo`?o00000_ooool2o`0000Gooooo0_l00002ooooo`;o00001Oooool2
o`0000kooooo0_l0000Jooooo`;o00000_ooool2o`00047ooooo000Looooo`03o`000?oooooooooo
06gooooo0_l00006oooooa7o00000oooool2o`0002oooooo0ol00003ooooo`;o00000_ooool2o`00
00Cooooo0_l0000:ooooo`;o0000:Oooool5o`0004?ooooo000Looooo`03o`000?oooooooooo03_o
oooo0_l0000foooooa?o000000?oooooo`000?l000001?l0000]ooooo`Co00003?ooool2o`0001_o
oooo0_l0000Hooooo`;o000000Coooooo`000?l0003o0000@_ooool001cooooo00?o0000oooooooo
ool0>oooool2o`0003;ooooo0_l000000ooooooo0000o`00000Ao`0000;ooooo0_l00002ooooo`;o
000000?oooooo`000?l000008_ooool2o`0000Oooooo1Ol0000:ooooo`Co00005?ooool3o`0000;o
oooo0_l0000Looooo`Go0000?oooool001cooooo00?o0000ooooooooool0>Oooool2o`000003oooo
ool0003o0000037ooooo0_l000000ooooooo0000o`00000Ao`0000?ooooo1?l000001?oooooo0000
o`000?l0000Rooooo`;o00001oooool6o`0000_ooooo0_l0000:ooooo`;o00002?ooool3o`0000Ko
oooo0_l0000@ooooo`?o00001Oooool6o`0003kooooo000Looooo`03o`000?oooooooooo03Wooooo
0_l000000ooooooo0000o`00000aooooo`;o000000?oooooo`000?l000004Ol00003ooooo`Oo0000
;Oooool5o`000003ooooool0003o000000Oooooo0ol00003ooooo`Go00000_ooool2o`000003oooo
ool0003o000000kooooo0_l0000@ooooo`?o00001Oooool3o`000003ooooool0003o000003kooooo
000Looooo`03o`000?oooooooooo03[ooooo0_l0000`ooooo`;o000000Coooooo`000?l0003ooooo
4ol00005ooooo`Co0000;_ooool8o`0000Oooooo0ol00003ooooo`Go00001Oooool2o`0000Oooooo
0_l0000Eooooo`;o00002Oooool2o`000003ooooool0003o000003kooooo000Looooo`03o`000?oo
oooooooo03[ooooo0ol00002ooooo`;o0000:oooool4o`000003ooooool0003o000001;o0000>Ooo
ool4o`000003ooooool0003o000000Kooooo0ol00003ooooo`;o00004Oooool2o`0001Gooooo0_l0
0009ooooo`;o000000?oooooo`000?l00000?_ooool001cooooo00?o0000ooooooooool0>oooool2
o`0000;ooooo0ol0000/ooooo`;o000000?oooooo`000?l000004_l0000/ooooo`;o00002oooool9
o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0002Kooooo0_l0001>ooooo`007?ooool0
0ol0003oooooooooo`0oooooo`?o0000;?ooool2o`0000;ooooo4Ol00005ooooo`;o00009oooool2
o`0000cooooo2?l00007ooooo`Co00000_ooool2o`0000Cooooo0_l00006ooooo`;o00005Oooool2
o`0004kooooo000Looooo`03o`000?oooooooooo03oooooo0_l0000]ooooo`;o000000?oooooo`00
0?l000004Ol00003ooooo`?o0000=oooool7o`0000;ooooo0ol00002ooooo`?o00000_ooool2o`00
00?ooooo1Ol000001?oooooo0000o`000?ooool2o`0001Sooooo0_l0001;ooooo`007?ooool2o`00
06[ooooo0_l00003oooooaKo000000?oooooo`000?l000000_l0000hooooo`Oo00000_ooool3o`00
0004ooooool0003o0000o`0000Sooooo0_l000001?oooooo0000o`000?ooool2o`0001_ooooo0_l0
001;ooooo`007?ooool00ol0003oooooooooo`0oooooo`;o0000:?ooool2o`0000Cooooo4ol00003
ooooo`;o0000??ooool6o`0000;ooooo0_l000000ooooooo0000o`00000<ooooo`Co00005oooool2
o`0000[ooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0oooooo`;o0000:ooooolFo`00
00Kooooo0_l0000[ooooo`;o00003Oooool6o`0000cooooo0_l00004ooooo`Co00005oooool2o`00
00[ooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0oooooo`;o0000:_oooolEo`0000So
oooo0_l0000[ooooo`;o00003_ooool9o`0000Gooooo0_l000000ooooooo0000o`000002o`0002Wo
oooo0_l00014ooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00000oooool2o`0002;ooooo
0_l00004ooooo`ko00002?ooool2o`00043ooooo1_l00004ooooo`;o00000oooool2o`0001gooooo
0_l0001@ooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00000oooool2o`0000?ooooo0_l0
000Oooooo`;o00000oooool=o`0000Oooooo0ol0000Vooooo`;o00001oooool2o`00013ooooo1Ol0
000Rooooo`;o00001?ooool2o`0000Oooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`1<
ooooo`Go00007?ooool2o`0000Gooooo1_l000000ooooooo0000o`000009ooooo`?o00009Oooool4
o`0000Gooooo0ol0000gooooo`?o00002?ooool2o`0000;ooooo0_l00017ooooo`007?ooool00ol0
003oooooooooo`1<ooooo`Go00006oooool4o`0000Kooooo1_l00004ooooo`;o00001oooool2o`00
02?ooooo1?l00005ooooo`;o0000>?ooool4o`0000Oooooo0_l0001;ooooo`007?ooool00ol0003o
ooooooooo`17ooooo`?o00002Oooool4o`0001Gooooo1?l00007ooooo`;o000000?oooooo`000?l0
00000_ooool4o`0000Kooooo1?l0000Xooooo`;o000000?oooooo`000?l00000>?ooool4o`0000Go
oooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`17ooooo`?o00002Oooool4o`0001?ooooo
0_l00003ooooo`;o000000?oooooo`000?l000001?l00006ooooo`;o00002?ooool6o`0001Kooooo
0_l0000=ooooo`?o000000?oooooo`000?l000000_l0000booooo`;o00000oooool2o`0000Kooooo
0ol0001<ooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o00003oooool2o`0000gooooo1?l0
00001?oooooo0000o`000?ooool6o`0000Kooooo0_l0000:ooooo`Co00000_ooool2o`0000?ooooo
0_l0000=ooooo`;o00003Oooool3o`0000?ooooo0_l0000booooo`;o00001_ooool2o`0000Cooooo
0_l0001<ooooo`007?ooool00ol0003oooooooooo`1:ooooo`Co00000_ooool2o`0000Gooooo0_l0
0002ooooo`?o00001oooool2o`0000Gooooo0_l00004ooooo`?o00001Oooool3o`0000Sooooo0_l0
0003ooooo`;o00001?ooool2o`0000?ooooo1?l0000@ooooo`;o00002Oooool3o`0000;ooooo0_l0
000eooooo`;o00000oooool2o`0005;ooooo000Looooo`03o`000?oooooooooo04[ooooo1?l00002
ooooo`;o00001Oooool2o`0000?ooooo0_l00007ooooo`;o00004oooool3o`000003ooooool0003o
000000Gooooo0_l00006ooooo`;o00002?ooool2o`0000Gooooo0ol00008ooooo`;o00002Oooool3
o`0000Gooooo0_l0000booooo`Co0000EOooool001cooooo00?o0000ooooooooool0Boooool3o`00
00Cooooo0_l00003ooooo`;o00001_ooool2o`0001Wooooo0_l00002ooooo`;o00003Oooool3o`00
00Gooooo1?l00005ooooo`?o00004oooool2o`0000?ooooo0_l000001?oooooo0000o`000?l0000]
ooooo`;o00000oooool6o`0000Cooooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`1;oooo
o`?o00001?ooool2o`0000;ooooo0_l00007ooooo`?o00003_ooool3o`0001_ooooo0_l00005oooo
o`Co00000_ooool3o`0000Kooooo0_l0000@ooooo`;o000000?oooooo`000?l000000_ooool2o`00
02gooooo0_l00002ooooo`Oo00001?ooool2o`0004cooooo000Looooo`03o`000?oooooooooo04co
oooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l00006ooooo`Co00003?ooool7o`0000;o
oooo0_l00002ooooo`Co00003oooool2o`0000;ooooo0_l00007ooooo`Go00001?ooool3o`0000oo
oooo0_l00005ooooo`?o0000<?ooool4o`000004ooooool0003o0000ooooo`;o0000Coooool001co
oooo0_l0001@ooooo`Co00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000go
oooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo1Ol0000:ooooo`;o00000_ooool6o`0000So
oooo1?l00005ooooo`Co00003Oooool4o`0000?ooooo0ol0000eooooo`;o000000?oooooo`000?l0
0000Coooool001cooooo00?o0000ooooooooool0DOooool2o`0000Oooooo0_l000000ooooooo0000
o`00000Eooooo`;o00001Oooool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`Co0000
1?ooool2o`0000Sooooo1Ol00007ooooo`?o00003Oooool4o`0003[ooooo0_l0001Cooooo`007?oo
ool00ol0003oooooooooo`1Jooooo`?o00005oooool2o`0000?ooooo1?l00007ooooo`Ko00003Ooo
ool5o`0000cooooo0_l0000<ooooo`?o00001Oooool2o`0003Cooooo0_l0001Cooooo`007?ooool0
0ol0003oooooooooo`1Fooooo`;o00000oooool2o`0001;ooooo0_l00008ooooo`;o00002?ooool6
o`0000kooooo1?l0000=ooooo`;o00003Oooool2o`0000Cooooo0ol0000Uooooo`;o00003Oooool2
o`0005?ooooo000Looooo`03o`000?oooooooooo05Kooooo0_l00006ooooo`;o000000Coooooo`00
0?l0003ooooo0_l00009ooooo`;o00004_ooool3o`0000?ooooo0_l000001?oooooo0000o`000?l0
0006ooooo`;o00004Oooool2o`0000gooooo0_l00004ooooo`;o00009_ooool2o`000003ooooool0
003o000000[ooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o000000Cooooo
o`000?l0003ooooo0_l00002ooooo`;o00005_ooool2o`0000;ooooo0_l00003ooooo`;o000000Co
ooooo`000?l0003o00000oooool2o`000003ooooool0003o000000Gooooo1ol00005ooooo`;o0000
2?ooool3o`0000Sooooo0_l0000Vooooo`;o000000?oooooo`000?l000000_ooool2o`0005_ooooo
000Looooo`03o`000?oooooooooo05_ooooo0_l0000;ooooo`;o00005Oooool7o`0000?ooooo2?l0
00000ooooooo0000o`000002o`0000Cooooo2_l00004ooooo`?o00001oooool7o`0000Cooooo0_l0
000Rooooo`;o00002?ooool3o`0005_ooooo000Looooo`03o`000?oooooooooo05_ooooo0ol00003
ooooo`;o00001Oooool3o`0001Cooooo1Ol00007ooooo`_o00000oooool;o`0000Cooooo0ol00007
ooooo`Oo00000_ooool3o`0002;ooooo1Ol00006ooooo`?o000000?oooooo`000?l00000F?ooool0
01cooooo00?o0000ooooooooool0G?ooool2o`0000?ooooo0_l00006ooooo`?o00005Oooool3o`00
00gooooo1?l00004ooooo`Go00000_ooool5o`000003ooooool0003o000000;o00002?ooool6o`00
00;ooooo1?l0000Rooooo`;o000000?oooooo`000?l000001oooool2o`000003ooooool0003o0000
05Sooooo000Looooo`03o`000?oooooooooo063ooooo0_l00006ooooo`Co00005Oooool5o`0000co
oooo0ol00004ooooo`Go00000_ooool9o`0000Oooooo0_l000000ooooooo0000o`000003o`0000;o
oooo0_l0000`ooooo`;o000000?oooooo`000?l00000F?ooool001cooooo00?o0000ooooooooool0
Goooool3o`0000Kooooo1?l0000Fooooo`Co00003?ooool2o`0000Gooooo1Ol000000ooooooo0000
o`000008o`0000Kooooo2?l00002ooooo`;o0000=?ooool2o`0005Sooooo000Looooo`03o`000?oo
oooooooo05kooooo1?l0000Pooooo`Co00003?ooool2o`0000Gooooo0ol00002ooooo`_o00001_oo
ool4o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000007_ooool2o`0000oooooo0_l0
001Jooooo`007?ooool00ol0003oooooooooo`1Nooooo`?o00001?ooool3o`0001_ooooo0ol00005
ooooo`Go00002Oooool=o`0000Oooooo1Ol0000:ooooo`;o00007_ooool2o`0000Sooooo0_l00005
ooooo`;o0000F_ooool001cooooo00?o0000ooooooooool0HOooool3o`000003ooooool0003o0000
00;o00006_ooool5o`0000?ooooo1ol000000ooooooo0000o`000004ooooo`co00002?ooool5o`00
0003ooooool0003o000000;o0000;oooool2o`00067ooooo000Looooo`03o`000?oooooooooo063o
oooo1?l00003ooooo`;o00003Oooool2o`0000cooooo1Ol00003ooooo`;o00000_ooool2o`000003
ooooool0003o000000Gooooo0_l000000ooooooo0000o`000002o`0000_ooooo0ol00004ooooo`Co
0000;Oooool2o`0006?ooooo000Looooo`03o`000?oooooooooo063ooooo0ol0000Cooooo`;o0000
00?oooooo`000?l000002Oooool5o`0000?ooooo0_l00005ooooo`;o00001Oooool8o`0000Sooooo
1?l00004ooooo`Oo0000:oooool2o`0006?ooooo000Looooo`;o0000H_ooool3o`0001Gooooo0_l0
000;ooooo`Co00002_ooool2o`0000Kooooo0ol000000ooooooo0000o`000002o`0000Kooooo0_l0
0003ooooo`[o00009_ooool2o`0000Kooooo0ol0001Oooooo`007?ooool00ol0003oooooooooo`1R
ooooo`;o000000Coooooo`000?l0003o00003?ooool2o`0000_ooooo0_l00005ooooo`?o00000ooo
ool2o`0000Cooooo0ol00007ooooo`Oo00000_ooool2o`000004ooooool0003o0000ooooo`Go0000
0_ooool2o`0002Wooooo0_l00005ooooo`Co0000Goooool001cooooo00?o0000ooooooooool0IOoo
ool5o`0000[ooooo0_l00009ooooo`Co00001_ooool3o`0000;ooooo0_l00004ooooo`Co00001_oo
ool7o`0000;ooooo0_l00004ooooo`;o0000=oooool2o`00067ooooo000Looooo`03o`000?oooooo
oooo06Cooooo0_l00002ooooo`;o00002?ooool2o`0000_ooooo0_l00007ooooo`Co00002_ooool2
o`0000Sooooo1?l00002ooooo`Wo0000V_ooool001cooooo00?o0000ooooooooool0I?ooool2o`00
00Oooooo0_l00003ooooo`;o00005?ooool6o`0000;ooooo0_l0000@ooooo`;o00000_ooool8o`00
09_ooooo000Looooo`03o`000?oooooooooo06Sooooo1?l000000ooooooo0000o`000004ooooo`;o
00002_ooool4o`0000;ooooo0_l00003ooooo`So00005Oooool2o`0003;ooooo0_l00002ooooo`;o
00000_ooool2o`0006Cooooo000Looooo`03o`000?oooooooooo06Kooooo2_l00003ooooo`;o0000
0oooool2o`0000Cooooo1Ol00002ooooo`;o00001Oooool5o`0004[ooooo0_l000001Ooooooo0000
o`000?l0003ooooo00?o0000I?ooool001cooooo00?o0000ooooooooool0I_ooool2o`000003oooo
ool0003o000000Go00002?ooool2o`0000Cooooo0_l0000<ooooo`Co0000C_ooool2o`0000;ooooo
0_l0001Uooooo`007?ooool00ol0003oooooooooo`1Vooooo`;o00001Oooool2o`0000oooooo0ol0
00001?oooooo0000o`000?ooool2o`0000Gooooo1Ol00017ooooo`;o00001Oooool2o`0006Sooooo
000Looooo`03o`000?oooooooooo06[ooooo0_l000000ooooooo0000o`000005ooooo`;o00002Ooo
ool2o`000004ooooool0003o0000ooooo`;o00002?ooool4o`0000Kooooo0_l00002ooooo`;o0000
0oooool2o`0002oooooo0_l00002ooooo`?o00001Oooool2o`0006Sooooo000Looooo`03o`000?oo
oooooooo06[ooooo0_l00005ooooo`;o000000?oooooo`000?l000006oooool2o`000003ooooool0
003o000000?ooooo0_l00002ooooo`?o00000_ooool2o`0002oooooo0_l00002ooooo`;o0000L?oo
ool001cooooo00?o0000ooooooooool0J_ooool2o`000003ooooool0003o000000Ko00007?ooool5
o`000004ooooool0003o0000o`0000Cooooo0_l0000aooooo`Co00000oooool4o`0006gooooo000L
ooooo`03o`000?oooooooooo06gooooo2Ol000000ooooooo0000o`00000Jooooo`Wo00002_ooool2
o`0000;ooooo0_l0000Uooooo`;o00001Oooool4o`0006gooooo000Looooo`03o`000?oooooooooo
06_ooooo0_l00004ooooo`Go000000?oooooo`000?l000007Oooool6o`000004ooooool0003o0000
o`0000;ooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00009?ooool4o`0000Cooooo0_l0
001_ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Q
o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0Joooool2o`0000Cooooo0ol0000Aooooo`;o
00002?ooool2o`0000Oooooo1?l000000ooooooo0000o`000008o`0000gooooo0_l00003ooooo`?o
00005?ooool5o`0000;ooooo0_l0001`ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5oooo
o`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0LOooool2
o`0000Oooooo0_l00009ooooo`;o00002?ooool3o`0000cooooo2ol0000;ooooo`;o00000_ooool4
o`00013ooooo0_l00003ooooo`Co00000_ooool2o`00073ooooo00000ooooooo410@ooooo`02oooo
o`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo06gooooo0_l00002ooooo`;o00001oooool3o`0000?ooooo0_l0000;ooooo`Go00004oooool=
o`0000;ooooo0ol000000ooooooo0000o`00000@ooooo`Co00000oooool2o`0007Kooooo00000ooo
oooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06
ooooo`?o0000KOooool7o`0000Oooooo0_l00003ooooo`;o00002oooool2o`0000Kooooo0_l0000B
ooooo`[o000000Coooooo`000?l0003o00004?ooool2o`000003ooooool0003o000007gooooo0000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Goc<c<o`000?l0003o0000olc<
c006ooooo`03o`000?oooooooooo06oooooo0_l000000ooooooo0000o`000007ooooo`;o00000_oo
ool4o`0000Oooooo0_l00009ooooo`;o00005Oooool2o`000003ooooool0003o000000;o000000?o
ooooo`000?l000004Oooool2o`00083ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooo
oooo00Wooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo07;ooooo0_l0
0007ooooo`;o00000_ooool4o`0000Oooooo1?l0000kooooo`;o0000O_ooool00006oooooomgMgOo
V9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000oooooooo
ool0P?ooool2o`0000[ooooo0_l0000dooooo`;o00001Oooool2o`0000;ooooo0_l0001jooooo`00
00Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool0
0ol0003oooooooooo`1oooooo`;o00006?ooool2o`0000;ooooo0_l0000Rooooo`Go00001oooool2
o`0007[ooooo000Looooo`03o`000?oooooooooo07oooooo0_l0000@ooooo`?o000000?oooooo`00
0?l000000_ooool2o`0000;ooooo0_l00002ooooo`;o00001_ooool2o`0000oooooo0_l00005oooo
o`;o000000?oooooo`000?l00000Poooool001cooooo00?o0000ooooooooool0P_ooool2o`0000?o
oooo0_l00008ooooo`?o000000?oooooo`000?l000002?ooool4o`000003ooooool0003o000000?o
oooo0_l00008ooooo`;o00001Oooool2o`0000Cooooo1?l00003ooooo`;o0000P?ooool001cooooo
00?o0000ooooooooool0N_ooool2o`0000Cooooo1Ol00002ooooo`;o00005_ooool2o`0000?ooooo
0_l0000;ooooo`Co00000_ooool5o`0000Cooooo1?l00003ooooo`;o0000P?ooool001cooooo00?o
0000ooooooooool0N_ooool2o`000004ooooool0003o0000ooooo`Go00004_ooool2o`0000_ooooo
0_l000000ooooooo0000o`000008ooooo`;o00000oooool6o`0000Gooooo0_l00026ooooo`007?oo
ool00ol0003oooooooooo`1looooo`?o00000_ooool2o`0000;ooooo0_l0000@ooooo`;o00001_oo
ool2o`0000Kooooo0_l0000=ooooo`;o000000?oooooo`000?l000001_ooool2o`0008Kooooo000L
ooooo`03o`000?oooooooooo07cooooo0_l000000ooooooo0000o`000004ooooo`?o00005oooool2
o`000003ooooool0003o000000Cooooo0_l0000Eooooo`;o0000R?ooool001cooooo00?o0000oooo
ooooool0Ooooool2o`0000Gooooo0_l0000Jooooo`;o00001?ooool2o`000004ooooool0003o0000
o`00017ooooo0_l00028ooooo`007?ooool00ol0003oooooooooo`1oooooo`;o00002Oooool4o`00
01gooooo0ol000001Ooooooo0000o`000?l0003ooooo00;o0000U?ooool001cooooo00?o0000oooo
ooooool0R_ooool4o`00027ooooo0ol000000ooooooo0000o`00002Dooooo`007?ooool00ol0003o
ooooooooo`2?ooooo`?o0000]oooool001cooooo00?o0000ooooooooool0Soooool4o`000003oooo
ool0003o00000;?ooooo000Looooo`;o0000TOooool3o`000003ooooool0003o000000;o0000/Ooo
ool001cooooo00?o0000ooooooooool0UOooool3o`000;7ooooo000Looooo`03o`000?oooooooooo
09Gooooo0_l0002booooo`007?ooool00ol0003oooooooooo`2Oooooo`;o0000Z?ooool001cooooo
00?o0000ooooooooool0Woooool2o`000:Sooooo000Looooo`03o`000?oooooooooo09oooooo0_l0
002Xooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`00
0?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom:
ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool001Co
oooo00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o0000ooooooooool0
oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooo
oooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`004_ooool00omEEEGo
IVIVo`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Uoooo
o`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05Oooool5o`0000Gooooo0_l00000
2Ol@413oooooooooooooooook^k^oc8b<_l0003o410@olc<c02@ooooo`00Y_ooool01Ol0003ooooo
oooooooooooo000000Wooooo1_l00009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0
003oooooooooo`02ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40T?ooool00:Kooooo00Go0000oooo
ooooooooooooo`00000Iooooo`03oiRHV?lQ8B7ok^k^00Cooooo1Ol00003ooooo`05o`000?oooooo
ooooooooool00000T?ooool00:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00002ooo
ool00onHV9So8B4Qonk^kP03ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000oiRHV?oooooo
V9RHob4Q8@2@ooooo`00Y_ooool01Ol0003oQhN7oooooonYZJWo000001_ooooo00?oMgMgofIVI_oo
ool00_ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0T?ooool0
0:Gooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Jooooo`03o`000?oooooooooo
00;ooooo00?oMgMgolc<c?l000001?ooool00omEEEGoQhN7ooooo`2Booooo`00`oooool01Ol0003o
^[ZjoooooonHV9So410@00Cooooo00?ok^k^odA4A?l000001?ooool00ooMgMgo410@oiRHV02Boooo
o`00`oooool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo00?oMgMgo`000?ooool01?ooool01?o<
c<coA4A4o`000?l@412@ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(252) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.63229 .37825 Mdot
.6139 .35812 Mdot
.26468 .49484 Mdot
.64445 .56235 Mdot
.36599 .58539 Mdot
.25318 .4531 Mdot
.4108 .33092 Mdot
.40153 .33804 Mdot
.31373 .4586 Mdot
.74572 .58883 Mdot
.42082 .35015 Mdot
.57021 .58305 Mdot
.40366 .32148 Mdot
.62395 .58237 Mdot
.47328 .69672 Mdot
.67079 .5687 Mdot
.63751 .34415 Mdot
.37783 .6309 Mdot
.67109 .56265 Mdot
.31299 .43543 Mdot
.51371 .50577 Mdot
.61007 .57859 Mdot
.58909 .38371 Mdot
.62086 .58394 Mdot
.6443 .5389 Mdot
.61029 .34729 Mdot
.63133 .37928 Mdot
.59199 .55234 Mdot
.64499 .55526 Mdot
.43691 .31669 Mdot
.55972 .64541 Mdot
.49026 .80011 Mdot
.43288 .56501 Mdot
.7567 .4671 Mdot
.43241 .30666 Mdot
.43367 .28286 Mdot
.25131 .47859 Mdot
.43124 .29946 Mdot
.40487 .36177 Mdot
.40937 .35018 Mdot
.41276 .34826 Mdot
.61255 .34425 Mdot
.41417 .29356 Mdot
.23869 .32588 Mdot
.61782 .59195 Mdot
.75516 .35916 Mdot
.31356 .48773 Mdot
.58457 .56883 Mdot
.58535 .36687 Mdot
.3198 .45975 Mdot
.38149 .71542 Mdot
.39208 .33876 Mdot
.46923 .55722 Mdot
.70839 .22293 Mdot
.40143 .33129 Mdot
.66558 .54514 Mdot
.28952 .44974 Mdot
.63418 .60486 Mdot
.58388 .60181 Mdot
.74021 .42555 Mdot
.64377 .59767 Mdot
.37116 .61719 Mdot
.61522 .29965 Mdot
.32113 .46913 Mdot
.31009 .46776 Mdot
.41884 .29365 Mdot
.63366 .32415 Mdot
.4211 .30597 Mdot
.63699 .55687 Mdot
.30883 .4417 Mdot
.64147 .54653 Mdot
.42195 .34913 Mdot
.63007 .37499 Mdot
.60435 .57419 Mdot
.55049 .31736 Mdot
.39542 .27612 Mdot
.3529 .64241 Mdot
.651 .40955 Mdot
.32597 .42355 Mdot
.48973 .6814 Mdot
.60521 .5762 Mdot
.38331 .20529 Mdot
.4513 .73662 Mdot
.59743 .38119 Mdot
.67615 .59334 Mdot
.47375 .20534 Mdot
.61082 .54896 Mdot
.55855 .64016 Mdot
.5621 .57508 Mdot
.39235 .65919 Mdot
.2871 .44568 Mdot
.5901 .34217 Mdot
.60441 .58634 Mdot
.61701 .55979 Mdot
.7611 .5655 Mdot
.65752 .55809 Mdot
.58145 .55859 Mdot
.44369 .58209 Mdot
.38985 .34608 Mdot
.45054 .55522 Mdot
.35436 .41271 Mdot
.4771 .5451 Mdot
.63424 .54551 Mdot
.26667 .45495 Mdot
.60964 .30091 Mdot
.44587 .55291 Mdot
.42634 .30996 Mdot
.60787 .58504 Mdot
.35771 .35555 Mdot
.58653 .37317 Mdot
.64078 .5349 Mdot
.37462 .60108 Mdot
.47739 .47887 Mdot
.61955 .38694 Mdot
.81342 .4791 Mdot
.64112 .56884 Mdot
.60636 .60657 Mdot
.61597 .35538 Mdot
.29676 .43155 Mdot
.33308 .25296 Mdot
.63112 .3604 Mdot
.39435 .35216 Mdot
.63524 .33512 Mdot
.42837 .57839 Mdot
.30714 .43151 Mdot
.49721 .55643 Mdot
.48227 .57494 Mdot
.444 .78041 Mdot
.65098 .5695 Mdot
.51987 .52399 Mdot
.25917 .45963 Mdot
.62804 .36445 Mdot
.40151 .31457 Mdot
.62373 .61892 Mdot
.59716 .35718 Mdot
.40902 .33545 Mdot
.34974 .63208 Mdot
.39154 .6186 Mdot
.60737 .38928 Mdot
.81598 .46633 Mdot
.3745 .32581 Mdot
.38192 .32523 Mdot
.38369 .7166 Mdot
.59885 .38215 Mdot
.35386 .61874 Mdot
.42378 .31501 Mdot
.19497 .61508 Mdot
.66089 .53642 Mdot
.39678 .7455 Mdot
.38738 .20838 Mdot
.38137 .71459 Mdot
.52907 .51411 Mdot
.36219 .60581 Mdot
.40902 .3359 Mdot
.58919 .57745 Mdot
.60456 .37632 Mdot
.5994 .3551 Mdot
.63431 .54909 Mdot
.46138 .54321 Mdot
.63415 .58596 Mdot
.44182 .56442 Mdot
.49914 .56793 Mdot
.60846 .58779 Mdot
.76355 .32896 Mdot
.59255 .36857 Mdot
.66414 .60415 Mdot
.25754 .47872 Mdot
.49224 .5334 Mdot
.41117 .2949 Mdot
.62562 .61518 Mdot
.68825 .56137 Mdot
.56766 .58648 Mdot
.37834 .3393 Mdot
.59577 .25946 Mdot
.32919 .42771 Mdot
.40746 .35566 Mdot
.35229 .38887 Mdot
.26808 .46993 Mdot
.58027 .59272 Mdot
.36698 .59649 Mdot
.45435 .56433 Mdot
.59959 .56955 Mdot
.37728 .71166 Mdot
.58527 .60185 Mdot
.54724 .50757 Mdot
.5504 .52575 Mdot
.4364 .21454 Mdot
.60986 .26536 Mdot
.63388 .5604 Mdot
.67195 .50961 Mdot
.3958 .73584 Mdot
.46271 .2946 Mdot
.40278 .31173 Mdot
.2664 .4373 Mdot
.28518 .43252 Mdot
.35615 .30023 Mdot
.79291 .48379 Mdot
.74884 .6192 Mdot
.6454 .60839 Mdot
.47305 .54908 Mdot
.64425 .37207 Mdot
.36184 .60772 Mdot
.61732 .38343 Mdot
.3762 .2042 Mdot
.52037 .67353 Mdot
.57479 .66805 Mdot
.21249 .43334 Mdot
.31247 .47438 Mdot
.48286 .5457 Mdot
.34793 .61556 Mdot
.62851 .59941 Mdot
.59017 .37772 Mdot
.39268 .72937 Mdot
.47642 .53878 Mdot
.6814 .7862 Mdot
.63436 .35751 Mdot
.5253 .73114 Mdot
.40341 .3288 Mdot
.29531 .46605 Mdot
.61605 .54733 Mdot
.6277 .57178 Mdot
.58223 .3532 Mdot
.58477 .58535 Mdot
.59373 .68334 Mdot
.65213 .5366 Mdot
.3228 .44244 Mdot
.35289 .44555 Mdot
.39715 .36097 Mdot
.21719 .43382 Mdot
.61972 .38801 Mdot
.7717 .31249 Mdot
.27908 .46058 Mdot
.5447 .51797 Mdot
.42616 .34362 Mdot
.35631 .63167 Mdot
.27753 .45489 Mdot
.37291 .58478 Mdot
.59495 .61366 Mdot
.2737 .47898 Mdot
.37617 .60882 Mdot
.59106 .65209 Mdot
.44789 .55181 Mdot
.38793 .77929 Mdot
.41799 .32773 Mdot
.60772 .32889 Mdot
.59516 .57223 Mdot
.46308 .55609 Mdot
.47809 .53792 Mdot
.50014 .72167 Mdot
.48343 .57134 Mdot
.48584 .54173 Mdot
.44887 .67998 Mdot
.36373 .63577 Mdot
.55801 .21376 Mdot
.55219 .63103 Mdot
.63823 .34656 Mdot
.61085 .56261 Mdot
.34945 .36062 Mdot
.41245 .33545 Mdot
.63402 .59885 Mdot
.42152 .21245 Mdot
.42118 .31573 Mdot
.6168 .60718 Mdot
.41824 .35583 Mdot
.59601 .36778 Mdot
.53409 .69354 Mdot
.63805 .36121 Mdot
.6064 .59121 Mdot
.42131 .35278 Mdot
.26028 .43976 Mdot
.60864 .34825 Mdot
.60779 .5824 Mdot
.65011 .58853 Mdot
.47317 .55168 Mdot
.65641 .53651 Mdot
.43822 .26855 Mdot
.58704 .56401 Mdot
.24435 .49133 Mdot
.6533 .55683 Mdot
.40955 .58016 Mdot
.27148 .6512 Mdot
.60321 .38787 Mdot
.4841 .57047 Mdot
.28335 .45182 Mdot
.6014 .67441 Mdot
.53383 .73154 Mdot
.61879 .58941 Mdot
.49032 .55984 Mdot
.49342 .76489 Mdot
.38767 .31896 Mdot
.56197 .57346 Mdot
.4133 .62826 Mdot
.28137 .44588 Mdot
.47734 .54667 Mdot
.67488 .58881 Mdot
.61217 .41103 Mdot
.66905 .56049 Mdot
.2779 .47474 Mdot
.63472 .34299 Mdot
.65953 .55276 Mdot
.43573 .278 Mdot
.50628 .54193 Mdot
.38157 .33365 Mdot
.5489 .60167 Mdot
.58027 .58904 Mdot
.31103 .44324 Mdot
.61095 .34146 Mdot
.40063 .33445 Mdot
.62341 .38471 Mdot
.39209 .69305 Mdot
.51039 .74622 Mdot
.57359 .30259 Mdot
.34341 .63246 Mdot
.22403 .66274 Mdot
.39816 .35439 Mdot
.44649 .57248 Mdot
.24594 .49846 Mdot
.62933 .41641 Mdot
.26932 .45185 Mdot
.81325 .45288 Mdot
.28942 .44703 Mdot
.67338 .55181 Mdot
.2782 .43796 Mdot
.77491 .59198 Mdot
.60354 .61203 Mdot
.30487 .47613 Mdot
.44561 .58277 Mdot
.62052 .6137 Mdot
.59723 .35526 Mdot
.51985 .80877 Mdot
.77683 .48085 Mdot
.79173 .49092 Mdot
.29067 .45327 Mdot
.81272 .44214 Mdot
.64106 .53574 Mdot
.55269 .58801 Mdot
.60637 .37195 Mdot
.44687 .57071 Mdot
.39499 .60408 Mdot
.39698 .59331 Mdot
.3041 .68852 Mdot
.55286 .75108 Mdot
.80888 .49029 Mdot
.60115 .35673 Mdot
.34668 .44137 Mdot
.55239 .31583 Mdot
.47934 .53911 Mdot
.40163 .33829 Mdot
.58411 .25738 Mdot
.56273 .58052 Mdot
.52146 .55931 Mdot
.59604 .68387 Mdot
.61297 .33001 Mdot
.58717 .30083 Mdot
.40116 .33583 Mdot
.79266 .49358 Mdot
.74047 .59633 Mdot
.63461 .58835 Mdot
.41098 .3407 Mdot
.47637 .5382 Mdot
.56126 .63973 Mdot
.44517 .78641 Mdot
.18283 .41386 Mdot
.61151 .59311 Mdot
.55259 .28575 Mdot
.59691 .57179 Mdot
.43315 .77434 Mdot
.62579 .6017 Mdot
.60557 .34184 Mdot
.60486 .54353 Mdot
.55713 .62963 Mdot
.16247 .53758 Mdot
.5143 .66986 Mdot
.36932 .5876 Mdot
.62169 .58039 Mdot
.63737 .57997 Mdot
.35856 .62538 Mdot
.59917 .33755 Mdot
.60922 .5579 Mdot
.57301 .21729 Mdot
.60353 .58429 Mdot
.40942 .29673 Mdot
.47552 .71863 Mdot
.48615 .79741 Mdot
.64015 .53673 Mdot
.61249 .41145 Mdot
.38121 .32859 Mdot
.42998 .33372 Mdot
.46934 .5731 Mdot
.41378 .33512 Mdot
.58875 .58516 Mdot
.47653 .71973 Mdot
.63002 .31834 Mdot
.46828 .54222 Mdot
.6091 .33229 Mdot
.24217 .51944 Mdot
.41586 .32774 Mdot
.47967 .55885 Mdot
.79052 .47009 Mdot
.41534 .31156 Mdot
.35887 .49816 Mdot
.62606 .53761 Mdot
.47997 .53826 Mdot
.62275 .39524 Mdot
.30633 .4415 Mdot
.494 .54746 Mdot
.40157 .33228 Mdot
.619 .59095 Mdot
.66262 .5415 Mdot
.41407 .33577 Mdot
.67744 .37883 Mdot
.55831 .64395 Mdot
.60109 .58795 Mdot
.59399 .35286 Mdot
.62713 .35656 Mdot
.64805 .61141 Mdot
.59755 .56848 Mdot
.25198 .45189 Mdot
.49017 .56089 Mdot
.49196 .55989 Mdot
.48748 .57248 Mdot
.29482 .45806 Mdot
.19933 .63797 Mdot
.39045 .30817 Mdot
.48984 .79858 Mdot
.51104 .31734 Mdot
.46466 .55932 Mdot
.24538 .45786 Mdot
.63497 .5702 Mdot
.60444 .55393 Mdot
.43074 .34309 Mdot
.29966 .74755 Mdot
.55712 .59348 Mdot
.63736 .35804 Mdot
.40273 .34249 Mdot
.69182 .5591 Mdot
.34554 .32995 Mdot
.3882 .60172 Mdot
.81163 .48572 Mdot
.39899 .34169 Mdot
.59541 .31908 Mdot
.398 .34162 Mdot
.6362 .58098 Mdot
.6727 .59188 Mdot
.61998 .33125 Mdot
.36152 .5882 Mdot
.6283 .55127 Mdot
.6162 .60556 Mdot
.34341 .40358 Mdot
.54718 .32599 Mdot
.39087 .58264 Mdot
.59649 .56055 Mdot
.43587 .57613 Mdot
.35009 .59379 Mdot
.595 .59076 Mdot
.64982 .55162 Mdot
.52343 .52281 Mdot
.44168 .30653 Mdot
.33561 .6231 Mdot
.16115 .5594 Mdot
.63453 .35974 Mdot
.44571 .27171 Mdot
.49946 .54357 Mdot
.39989 .35399 Mdot
.61933 .68602 Mdot
.48445 .55233 Mdot
.51831 .29649 Mdot
.87814 .5511 Mdot
.4919 .54887 Mdot
.23887 .46712 Mdot
.76552 .55416 Mdot
.64616 .55155 Mdot
.60074 .58947 Mdot
.39346 .60805 Mdot
.62039 .36309 Mdot
.60833 .26514 Mdot
.40744 .35654 Mdot
.62251 .56692 Mdot
.6174 .39258 Mdot
.44725 .2102 Mdot
.47814 .55088 Mdot
.37957 .59408 Mdot
.3389 .62302 Mdot
.59451 .58153 Mdot
.51516 .7591 Mdot
.60641 .3485 Mdot
.60792 .58257 Mdot
.59858 .60339 Mdot
.24676 .44659 Mdot
.59754 .38406 Mdot
.27065 .47779 Mdot
.54845 .5965 Mdot
.79826 .56757 Mdot
.35297 .38497 Mdot
.4224 .31962 Mdot
.47973 .56789 Mdot
.39596 .36135 Mdot
.3001 .49314 Mdot
.49031 .56133 Mdot
.60917 .58177 Mdot
.62794 .31581 Mdot
.6071 .58343 Mdot
.60355 .585 Mdot
.62078 .59428 Mdot
.81012 .49056 Mdot
.32721 .42311 Mdot
.37262 .59365 Mdot
.57883 .57743 Mdot
.28587 .47067 Mdot
.34394 .32125 Mdot
.75034 .58197 Mdot
.62204 .57611 Mdot
.608 .60662 Mdot
.6196 .40832 Mdot
.66341 .53706 Mdot
.4163 .31535 Mdot
.61571 .32938 Mdot
.63751 .54415 Mdot
.32777 .41061 Mdot
.60291 .56014 Mdot
.58024 .30046 Mdot
.40503 .30154 Mdot
.71139 .57929 Mdot
.46484 .53825 Mdot
.48837 .56474 Mdot
.49273 .547 Mdot
.4906 .57073 Mdot
.41381 .29493 Mdot
.24022 .46814 Mdot
.20159 .44808 Mdot
.56562 .60861 Mdot
.5877 .57826 Mdot
.67381 .59183 Mdot
.23012 .47142 Mdot
.44141 .58357 Mdot
.80429 .45524 Mdot
.6928 .55492 Mdot
.30187 .46186 Mdot
.46065 .58094 Mdot
.63299 .43607 Mdot
.60574 .33095 Mdot
.32876 .45767 Mdot
.43447 .3276 Mdot
.37958 .60812 Mdot
.33779 .73195 Mdot
.62696 .34581 Mdot
.64377 .38465 Mdot
.2546 .47079 Mdot
.48347 .73326 Mdot
.70299 .21341 Mdot
.26108 .45214 Mdot
.58112 .67316 Mdot
.60238 .36847 Mdot
.4364 .56614 Mdot
.48643 .76321 Mdot
.47415 .72704 Mdot
.30704 .46613 Mdot
.65045 .58652 Mdot
.21612 .49898 Mdot
.25424 .44812 Mdot
.45931 .57079 Mdot
.29093 .45481 Mdot
.38389 .32525 Mdot
.26362 .46026 Mdot
.59 .39545 Mdot
.648 .56572 Mdot
.70627 .21983 Mdot
.43745 .70941 Mdot
.6369 .56327 Mdot
.38878 .32119 Mdot
.44716 .28438 Mdot
.63654 .59159 Mdot
.39292 .59378 Mdot
.23871 .46881 Mdot
.33247 .50334 Mdot
.67101 .55569 Mdot
.28335 .43799 Mdot
.61782 .4145 Mdot
.34592 .47007 Mdot
.3542 .4104 Mdot
.49458 .55007 Mdot
.59676 .37214 Mdot
.39033 .27837 Mdot
.39327 .35169 Mdot
.50896 .54202 Mdot
.58833 .59909 Mdot
.58969 .36311 Mdot
.59953 .6653 Mdot
.54396 .54678 Mdot
.60435 .58262 Mdot
.26688 .47576 Mdot
.32224 .45592 Mdot
.46863 .69955 Mdot
.28096 .46175 Mdot
.45981 .57181 Mdot
.59247 .36023 Mdot
.67132 .55999 Mdot
.62938 .35965 Mdot
.60905 .56256 Mdot
.34782 .33674 Mdot
.59325 .33709 Mdot
.54496 .51821 Mdot
.64702 .60145 Mdot
.76113 .33646 Mdot
.57675 .57621 Mdot
.6012 .58655 Mdot
.31855 .44112 Mdot
.35578 .62426 Mdot
.5345 .55163 Mdot
.34857 .31427 Mdot
.37762 .61668 Mdot
.66494 .40541 Mdot
.29908 .43115 Mdot
.35549 .63024 Mdot
.30812 .7017 Mdot
.48612 .56939 Mdot
.34281 .6085 Mdot
.67271 .59704 Mdot
.42304 .32303 Mdot
.61916 .31162 Mdot
.62172 .61402 Mdot
.79225 .56999 Mdot
.55529 .64081 Mdot
.47493 .55367 Mdot
.59933 .59248 Mdot
.63969 .5741 Mdot
.61835 .39181 Mdot
.37702 .20588 Mdot
.27916 .49659 Mdot
.44598 .56286 Mdot
.63103 .35094 Mdot
.38588 .20578 Mdot
.30366 .47533 Mdot
.38065 .62543 Mdot
.39894 .3641 Mdot
.58526 .31297 Mdot
.46979 .55507 Mdot
.41427 .33049 Mdot
.21669 .47325 Mdot
.37669 .70712 Mdot
.6679 .56033 Mdot
.24561 .4723 Mdot
.38053 .71387 Mdot
.62168 .53841 Mdot
.35799 .29589 Mdot
.46703 .304 Mdot
.586 .36267 Mdot
.4126 .33739 Mdot
.37661 .59052 Mdot
.6404 .34413 Mdot
.60788 .33212 Mdot
.42096 .31215 Mdot
.81039 .38842 Mdot
.49412 .76379 Mdot
.40983 .36308 Mdot
.49938 .71299 Mdot
.3803 .7114 Mdot
.46891 .55312 Mdot
.37149 .59577 Mdot
.3531 .4443 Mdot
.61262 .3448 Mdot
.57952 .26241 Mdot
.3807 .71569 Mdot
.60941 .54349 Mdot
.37606 .61116 Mdot
.45089 .21282 Mdot
.3679 .33268 Mdot
.41679 .32094 Mdot
.34434 .40293 Mdot
.37036 .62045 Mdot
.62974 .61502 Mdot
.32021 .77886 Mdot
.60113 .60993 Mdot
.42477 .31611 Mdot
.59517 .68364 Mdot
.61777 .37924 Mdot
.39545 .3055 Mdot
.59297 .6838 Mdot
.59584 .56014 Mdot
.64442 .57167 Mdot
.32504 .42057 Mdot
.58431 .34447 Mdot
.49578 .53868 Mdot
.63398 .56211 Mdot
.62504 .60697 Mdot
.45094 .54642 Mdot
.47842 .79383 Mdot
.49223 .4705 Mdot
.43706 .56045 Mdot
.29108 .47611 Mdot
.46336 .54334 Mdot
.44666 .56414 Mdot
.61643 .40383 Mdot
.35053 .41695 Mdot
.4886 .539 Mdot
.60748 .59414 Mdot
.60419 .59025 Mdot
.40293 .36354 Mdot
.49243 .76463 Mdot
.4788 .73315 Mdot
.25389 .49631 Mdot
.40046 .62726 Mdot
.65556 .58223 Mdot
.59656 .37645 Mdot
.3361 .59742 Mdot
.46252 .57446 Mdot
.63659 .355 Mdot
.64794 .56117 Mdot
.24407 .44832 Mdot
.49111 .55218 Mdot
.42451 .57613 Mdot
.37205 .60912 Mdot
.38892 .36092 Mdot
.66379 .39819 Mdot
.24887 .4525 Mdot
.64461 .53967 Mdot
.40541 .62782 Mdot
.28071 .44099 Mdot
.4691 .55181 Mdot
.45602 .54765 Mdot
.59693 .36469 Mdot
.58796 .32596 Mdot
.43027 .58558 Mdot
.29261 .46235 Mdot
.19896 .37996 Mdot
.3948 .34584 Mdot
.57988 .58499 Mdot
.38624 .35411 Mdot
.58722 .37745 Mdot
.44256 .7807 Mdot
.34623 .62808 Mdot
.41854 .31626 Mdot
.47701 .53944 Mdot
.60071 .33318 Mdot
.58459 .3741 Mdot
.6092 .58879 Mdot
.61432 .57766 Mdot
.33064 .4678 Mdot
.39846 .74303 Mdot
.42824 .34689 Mdot
.38624 .61641 Mdot
.26507 .49618 Mdot
.66846 .54911 Mdot
.60715 .38203 Mdot
.4288 .8119 Mdot
.57857 .58586 Mdot
.28729 .46814 Mdot
.61177 .35814 Mdot
.39325 .60577 Mdot
.3696 .5928 Mdot
.61872 .56339 Mdot
.5301 .51502 Mdot
.41672 .30963 Mdot
.59912 .35081 Mdot
.65076 .31633 Mdot
.58027 .5717 Mdot
.61903 .57839 Mdot
.62754 .53666 Mdot
.40703 .36535 Mdot
.65564 .60821 Mdot
.36246 .58853 Mdot
.61391 .38826 Mdot
.62189 .56442 Mdot
.36697 .62111 Mdot
.50308 .55441 Mdot
.48681 .55362 Mdot
.31665 .45922 Mdot
.39471 .59382 Mdot
.35966 .62026 Mdot
.37948 .61728 Mdot
.58351 .25723 Mdot
.66467 .61061 Mdot
.44455 .59164 Mdot
.65086 .58862 Mdot
.38023 .71024 Mdot
.66874 .57497 Mdot
.38664 .33544 Mdot
.31213 .44482 Mdot
.62687 .59202 Mdot
.65037 .59191 Mdot
.6532 .41162 Mdot
.67355 .56501 Mdot
.64492 .61217 Mdot
.61521 .38235 Mdot
.6566 .33408 Mdot
.27828 .43395 Mdot
.39066 .2092 Mdot
.37503 .82292 Mdot
.60964 .61933 Mdot
.48199 .72931 Mdot
.59691 .3377 Mdot
.40082 .36398 Mdot
.498 .72368 Mdot
.3797 .35076 Mdot
.62378 .35602 Mdot
.67542 .55506 Mdot
.679 .34843 Mdot
.37618 .61604 Mdot
.6344 .58286 Mdot
.41424 .30608 Mdot
.63438 .58441 Mdot
.39429 .30854 Mdot
.80398 .42718 Mdot
.46223 .75025 Mdot
.59455 .60931 Mdot
.65677 .55754 Mdot
.50525 .50595 Mdot
.6188 .57669 Mdot
.1924 .45272 Mdot
.60948 .36352 Mdot
.50356 .53758 Mdot
.67731 .55433 Mdot
.77575 .48493 Mdot
.59984 .5992 Mdot
.63832 .68846 Mdot
.62254 .61089 Mdot
.28549 .72607 Mdot
.59317 .61164 Mdot
.59095 .6023 Mdot
.39583 .31702 Mdot
.41474 .35249 Mdot
.622 .41758 Mdot
.47232 .54316 Mdot
.44287 .21314 Mdot
.61278 .60576 Mdot
.29716 .48844 Mdot
.57909 .5105 Mdot
.35952 .62225 Mdot
.62178 .38272 Mdot
.90219 .51276 Mdot
.41024 .29347 Mdot
.2728 .48216 Mdot
.56726 .65621 Mdot
.28319 .4787 Mdot
.31937 .47457 Mdot
.65037 .30257 Mdot
.37312 .59577 Mdot
.60192 .56173 Mdot
.75733 .45963 Mdot
.54492 .32007 Mdot
.58096 .57097 Mdot
.22359 .46009 Mdot
.52443 .52492 Mdot
.50249 .61341 Mdot
.36797 .63587 Mdot
.356 .61008 Mdot
.40556 .33216 Mdot
.29362 .48895 Mdot
.44805 .56 Mdot
.35335 .63039 Mdot
.28019 .43498 Mdot
.48024 .57109 Mdot
.348 .42103 Mdot
.60562 .34808 Mdot
.81313 .44518 Mdot
.75743 .35554 Mdot
.38194 .3383 Mdot
.34922 .30756 Mdot
.62619 .31359 Mdot
.63947 .35762 Mdot
.4679 .54739 Mdot
.3046 .45943 Mdot
.61126 .31131 Mdot
.62476 .56283 Mdot
.46394 .54345 Mdot
.5946 .57719 Mdot
.37175 .633 Mdot
.60324 .59751 Mdot
.27956 .43621 Mdot
.39642 .31355 Mdot
.28249 .44721 Mdot
.40894 .33296 Mdot
.50108 .80333 Mdot
.64557 .60475 Mdot
.61833 .58053 Mdot
.47635 .72047 Mdot
.59618 .38728 Mdot
.75629 .47535 Mdot
.29016 .46319 Mdot
.28781 .44984 Mdot
.67752 .55648 Mdot
.63414 .33056 Mdot
.42325 .59537 Mdot
.49744 .70571 Mdot
.61778 .61075 Mdot
.61077 .36423 Mdot
.67887 .56601 Mdot
.42313 .24836 Mdot
.44983 .72974 Mdot
.59992 .3932 Mdot
.16246 .53341 Mdot
.63584 .61136 Mdot
.44323 .57202 Mdot
.52148 .5307 Mdot
.52831 .76063 Mdot
.54054 .54619 Mdot
.63493 .35655 Mdot
.44722 .55741 Mdot
.60491 .38006 Mdot
.27267 .44333 Mdot
.39639 .30369 Mdot
.60884 .37545 Mdot
.6348 .60954 Mdot
.37517 .82221 Mdot
.4061 .30386 Mdot
.63095 .58364 Mdot
.41949 .30407 Mdot
.60331 .3034 Mdot
.62194 .37094 Mdot
.47973 .57121 Mdot
.57989 .67243 Mdot
.41818 .31234 Mdot
.58681 .58197 Mdot
.57128 .27811 Mdot
.66906 .56143 Mdot
.39924 .62301 Mdot
.65881 .57072 Mdot
.64944 .5611 Mdot
.17772 .61181 Mdot
.60691 .67103 Mdot
.35171 .37818 Mdot
.4132 .3713 Mdot
.59892 .25907 Mdot
.61665 .40022 Mdot
.38228 .62682 Mdot
.64035 .41943 Mdot
.49264 .56111 Mdot
.2924 .47683 Mdot
.62249 .5917 Mdot
.49633 .56663 Mdot
.43023 .34691 Mdot
.34305 .61098 Mdot
.5852 .60174 Mdot
.24943 .48577 Mdot
.44756 .57951 Mdot
.41547 .32638 Mdot
.61438 .34386 Mdot
.62577 .37401 Mdot
.34941 .43095 Mdot
.62472 .56409 Mdot
.6118 .57936 Mdot
.42531 .30279 Mdot
.54302 .52465 Mdot
.38435 .61189 Mdot
.44563 .58281 Mdot
.42447 .3058 Mdot
.44979 .73164 Mdot
.58395 .34421 Mdot
.63776 .57185 Mdot
.47304 .71512 Mdot
.60664 .26226 Mdot
.71135 .51445 Mdot
.36022 .61147 Mdot
.52827 .74006 Mdot
.63475 .35646 Mdot
.39993 .31671 Mdot
.30475 .69352 Mdot
.64128 .53386 Mdot
.64294 .58497 Mdot
.53614 .73688 Mdot
.49901 .70662 Mdot
.56936 .65708 Mdot
.48964 .53776 Mdot
.48694 .7567 Mdot
.67845 .55908 Mdot
.65681 .54107 Mdot
.65483 .58627 Mdot
.65948 .56866 Mdot
.61434 .36926 Mdot
.79065 .49913 Mdot
.2587 .46831 Mdot
.66917 .50126 Mdot
.37263 .63836 Mdot
.602 .54699 Mdot
.6223 .54869 Mdot
.65676 .45508 Mdot
.55655 .71242 Mdot
.60431 .36074 Mdot
.60513 .40397 Mdot
.38347 .34378 Mdot
.6703 .56495 Mdot
.28969 .4655 Mdot
.52299 .54587 Mdot
.3092 .44725 Mdot
.61441 .36681 Mdot
.26189 .43556 Mdot
.40441 .29334 Mdot
.24558 .47291 Mdot
.29926 .46682 Mdot
.39172 .31957 Mdot
.59096 .3343 Mdot
.57559 .5771 Mdot
.39117 .31992 Mdot
.41944 .59058 Mdot
.38292 .62476 Mdot
.65196 .37018 Mdot
.43594 .56412 Mdot
.5631 .58339 Mdot
.21699 .35798 Mdot
.2505 .47882 Mdot
.53828 .70479 Mdot
.5898 .3386 Mdot
.33056 .61872 Mdot
.61158 .37641 Mdot
.43011 .58668 Mdot
.36398 .61232 Mdot
.67552 .59385 Mdot
.37 .7589 Mdot
.46859 .31166 Mdot
.56819 .57161 Mdot
.65622 .33212 Mdot
.30724 .4469 Mdot
.39003 .31655 Mdot
.38102 .2465 Mdot
.44515 .56315 Mdot
.61969 .41554 Mdot
.57905 .33469 Mdot
.49204 .56065 Mdot
.40233 .31384 Mdot
.75238 .34607 Mdot
.63329 .56377 Mdot
.38529 .351 Mdot
.65839 .57081 Mdot
.81425 .47402 Mdot
.33093 .64468 Mdot
.49481 .56978 Mdot
.67449 .55266 Mdot
.30296 .47562 Mdot
.67678 .55579 Mdot
.79736 .54549 Mdot
.41732 .76647 Mdot
.6514 .59892 Mdot
.54009 .71805 Mdot
.28344 .49875 Mdot
.60359 .38288 Mdot
.47064 .56438 Mdot
.47147 .55265 Mdot
.671 .54109 Mdot
.4764 .86465 Mdot
.34758 .62423 Mdot
.24112 .41667 Mdot
.64011 .60665 Mdot
.60599 .57624 Mdot
.65824 .40831 Mdot
.8024 .42797 Mdot
.43857 .58012 Mdot
.64235 .59157 Mdot
.55822 .72586 Mdot
.39423 .3285 Mdot
.66006 .5549 Mdot
.59726 .57657 Mdot
.34336 .48213 Mdot
.39698 .31697 Mdot
.2499 .44656 Mdot
.48796 .5678 Mdot
.31992 .44812 Mdot
.36542 .58589 Mdot
.52725 .73087 Mdot
.46213 .78797 Mdot
.45194 .7238 Mdot
.3895 .59061 Mdot
.64736 .53567 Mdot
.56004 .61078 Mdot
.64865 .57457 Mdot
.35308 .61049 Mdot
.43727 .31838 Mdot
.61015 .36709 Mdot
.81628 .4606 Mdot
.47162 .55081 Mdot
.60768 .54725 Mdot
.33577 .63588 Mdot
.60367 .37496 Mdot
.76399 .32595 Mdot
.61917 .36413 Mdot
.41293 .32368 Mdot
.35602 .29803 Mdot
.36672 .61512 Mdot
.61147 .37701 Mdot
.31771 .4426 Mdot
.36155 .29896 Mdot
.69339 .53969 Mdot
.40603 .29264 Mdot
.57884 .3575 Mdot
.59895 .39547 Mdot
.63615 .32364 Mdot
.67183 .5477 Mdot
.53964 .71313 Mdot
.47588 .5693 Mdot
.41608 .30146 Mdot
.27365 .48706 Mdot
.40292 .7488 Mdot
.73982 .3813 Mdot
.4638 .74129 Mdot
.67607 .59053 Mdot
.60343 .59675 Mdot
.59487 .58452 Mdot
.44644 .54817 Mdot
.56071 .61727 Mdot
.651 .59569 Mdot
.43087 .34309 Mdot
.26595 .44172 Mdot
.63511 .60668 Mdot
.48612 .55782 Mdot
.50292 .57421 Mdot
.33172 .61525 Mdot
.81465 .4876 Mdot
.65156 .37659 Mdot
.60566 .37432 Mdot
.2779 .47393 Mdot
.30058 .43037 Mdot
.35176 .63222 Mdot
.40458 .33937 Mdot
.62123 .36216 Mdot
.28175 .71851 Mdot
.38095 .61172 Mdot
.60998 .59549 Mdot
.47558 .71931 Mdot
.55461 .73842 Mdot
.63748 .55032 Mdot
.62103 .59531 Mdot
.47994 .54068 Mdot
.2901 .46775 Mdot
.76177 .60613 Mdot
.76245 .33073 Mdot
.36536 .6203 Mdot
.37353 .62712 Mdot
.63848 .33028 Mdot
.58542 .59206 Mdot
.4179 .30828 Mdot
.49689 .76509 Mdot
.44751 .28152 Mdot
.47852 .20661 Mdot
.21846 .487 Mdot
.60027 .5618 Mdot
.77022 .52718 Mdot
.55825 .58729 Mdot
.61097 .30138 Mdot
.59739 .32041 Mdot
.60217 .3583 Mdot
.39549 .33236 Mdot
.37826 .70193 Mdot
.41664 .34644 Mdot
.45745 .58134 Mdot
.62398 .33918 Mdot
.58906 .66651 Mdot
.28864 .45119 Mdot
.67079 .57092 Mdot
.36556 .5988 Mdot
.394 .65233 Mdot
.46563 .56238 Mdot
.52787 .73691 Mdot
.24527 .45821 Mdot
.60933 .32659 Mdot
.67231 .57093 Mdot
.3449 .33587 Mdot
.47399 .75216 Mdot
.2443 .50011 Mdot
.49743 .56566 Mdot
.37172 .61712 Mdot
.74429 .58969 Mdot
.3847 .60406 Mdot
.41955 .31548 Mdot
.64652 .60278 Mdot
.5873 .59478 Mdot
.59988 .5857 Mdot
.64195 .61175 Mdot
.39915 .33144 Mdot
.57183 .56637 Mdot
.42519 .58453 Mdot
.48787 .57118 Mdot
.54885 .62143 Mdot
.35987 .59512 Mdot
.39207 .34398 Mdot
.27512 .44041 Mdot
.48804 .54159 Mdot
.33406 .62648 Mdot
.66957 .58228 Mdot
.64715 .59527 Mdot
.45993 .57965 Mdot
.6709 .59866 Mdot
.55892 .57992 Mdot
.25217 .46273 Mdot
.55616 .63604 Mdot
.33296 .61309 Mdot
.36842 .60221 Mdot
.41814 .3326 Mdot
.61065 .37758 Mdot
.33955 .62645 Mdot
.24999 .49199 Mdot
.66233 .55565 Mdot
.65794 .57495 Mdot
.58126 .37534 Mdot
.37844 .71321 Mdot
.3315 .61428 Mdot
.65356 .60925 Mdot
.60484 .39263 Mdot
.57982 .33109 Mdot
.64203 .58801 Mdot
.57994 .55908 Mdot
.61963 .40139 Mdot
.36761 .63122 Mdot
.41264 .33989 Mdot
.42958 .72039 Mdot
.38748 .31368 Mdot
.61299 .34194 Mdot
.45445 .55134 Mdot
.59705 .33112 Mdot
.44489 .56228 Mdot
.55656 .19327 Mdot
.65217 .59293 Mdot
.6526 .28465 Mdot
.44037 .58402 Mdot
.29171 .45281 Mdot
.30063 .45311 Mdot
.49097 .55531 Mdot
.6354 .34738 Mdot
.46191 .57136 Mdot
.38315 .59573 Mdot
.59601 .26049 Mdot
.61581 .4045 Mdot
.30061 .46499 Mdot
.25038 .48089 Mdot
.42369 .30496 Mdot
.60145 .59775 Mdot
.63808 .57111 Mdot
.24473 .4706 Mdot
.44461 .27627 Mdot
.58683 .35483 Mdot
.61194 .57983 Mdot
.43908 .55731 Mdot
.25593 .46481 Mdot
.46926 .35119 Mdot
.61591 .31233 Mdot
.67452 .54923 Mdot
.4237 .77188 Mdot
.40112 .30104 Mdot
.61813 .54698 Mdot
.56908 .56841 Mdot
.35099 .62201 Mdot
.53023 .7416 Mdot
.38349 .71582 Mdot
.41007 .2929 Mdot
.4861 .56585 Mdot
.63392 .54967 Mdot
.29516 .45019 Mdot
.66269 .58872 Mdot
.81136 .6385 Mdot
.47746 .57597 Mdot
.62434 .56542 Mdot
.52216 .54233 Mdot
.62961 .36007 Mdot
.60747 .57887 Mdot
.34844 .3383 Mdot
.27426 .47148 Mdot
.62845 .56479 Mdot
.519 .50741 Mdot
.41939 .30451 Mdot
.46677 .5622 Mdot
.37295 .61842 Mdot
.57615 .66539 Mdot
.5179 .80829 Mdot
.23066 .47176 Mdot
.36138 .59254 Mdot
.60315 .60163 Mdot
.272 .49615 Mdot
.41193 .35318 Mdot
.47692 .56441 Mdot
.62947 .54277 Mdot
.38912 .34672 Mdot
.39191 .32834 Mdot
.37047 .61294 Mdot
.76476 .285 Mdot
.60931 .61847 Mdot
.63001 .57771 Mdot
.76632 .30772 Mdot
.56891 .35416 Mdot
.63224 .58508 Mdot
.59511 .60169 Mdot
.41787 .32815 Mdot
.37304 .69762 Mdot
.52866 .73785 Mdot
.50263 .56787 Mdot
.38774 .32093 Mdot
.21664 .47868 Mdot
.26068 .47795 Mdot
.35645 .59341 Mdot
.61233 .3572 Mdot
.34755 .63287 Mdot
.26481 .46361 Mdot
.6094 .59175 Mdot
.42377 .33323 Mdot
.74039 .63461 Mdot
.4019 .30293 Mdot
.2464 .48803 Mdot
.60888 .30158 Mdot
.77841 .58844 Mdot
.82275 .62684 Mdot
.48363 .46817 Mdot
.36027 .292 Mdot
.35865 .62248 Mdot
.76253 .32995 Mdot
.62844 .60931 Mdot
.79352 .53906 Mdot
.63332 .58041 Mdot
.40614 .57283 Mdot
.30067 .44007 Mdot
.48012 .57108 Mdot
.44465 .56444 Mdot
.53092 .73212 Mdot
.39232 .33356 Mdot
.4352 .31824 Mdot
.44974 .55239 Mdot
.41397 .31894 Mdot
.62818 .56783 Mdot
.25617 .45172 Mdot
.60723 .21722 Mdot
.62545 .611 Mdot
.49028 .53448 Mdot
.37742 .31758 Mdot
.56599 .30809 Mdot
.21712 .47637 Mdot
.77197 .50955 Mdot
.428 .21612 Mdot
.41373 .30979 Mdot
.81272 .49109 Mdot
.28194 .47076 Mdot
.48746 .54148 Mdot
.28325 .49519 Mdot
.63289 .5747 Mdot
.59919 .56226 Mdot
.46047 .54136 Mdot
.60269 .60426 Mdot
.7512 .52971 Mdot
.56397 .57117 Mdot
.61285 .47052 Mdot
.65107 .58648 Mdot
.67132 .31784 Mdot
.41798 .35282 Mdot
.45248 .55071 Mdot
.44049 .67856 Mdot
.64956 .56426 Mdot
.62137 .39624 Mdot
.38564 .3389 Mdot
.40737 .218 Mdot
.39613 .32992 Mdot
.28547 .44669 Mdot
.40025 .3385 Mdot
.57321 .56857 Mdot
.62472 .3513 Mdot
.27465 .45847 Mdot
.46638 .55834 Mdot
.28379 .48418 Mdot
.63643 .56325 Mdot
.42044 .38505 Mdot
.27149 .4817 Mdot
.62373 .53804 Mdot
.62591 .35473 Mdot
.4028 .79438 Mdot
.63469 .31452 Mdot
.61631 .58707 Mdot
.62479 .58713 Mdot
.43755 .58057 Mdot
.40875 .33606 Mdot
.5958 .32969 Mdot
.34165 .40241 Mdot
.33027 .6186 Mdot
.60739 .35647 Mdot
.53464 .52512 Mdot
.4848 .73358 Mdot
.61989 .38672 Mdot
.55763 .73114 Mdot
.42227 .31601 Mdot
.63263 .36404 Mdot
.57291 .52199 Mdot
.6666 .50284 Mdot
.37655 .59994 Mdot
.31926 .4429 Mdot
.49309 .73015 Mdot
.26594 .47783 Mdot
.34775 .34111 Mdot
.32277 .44324 Mdot
.40632 .30641 Mdot
.53559 .51928 Mdot
.59479 .68313 Mdot
.434 .30345 Mdot
.38064 .39319 Mdot
.26338 .47179 Mdot
.43986 .56251 Mdot
.55252 .62861 Mdot
.42461 .57537 Mdot
.44055 .57345 Mdot
.41227 .29311 Mdot
.63343 .36353 Mdot
.63824 .33981 Mdot
.51436 .53896 Mdot
.62059 .37959 Mdot
.26457 .45257 Mdot
.45482 .71397 Mdot
.79019 .46998 Mdot
.42868 .34356 Mdot
.55963 .6415 Mdot
.6308 .5465 Mdot
.28328 .43727 Mdot
.26675 .44926 Mdot
.3936 .33256 Mdot
.68227 .48694 Mdot
.44589 .57583 Mdot
.59176 .30162 Mdot
.62753 .34521 Mdot
.63023 .36182 Mdot
.58539 .37125 Mdot
.37615 .70466 Mdot
.38822 .32225 Mdot
.63471 .34788 Mdot
.64511 .60996 Mdot
.59365 .59672 Mdot
.49254 .54414 Mdot
.37385 .63127 Mdot
.56568 .57079 Mdot
.46117 .57199 Mdot
.64176 .58446 Mdot
.29086 .45577 Mdot
.57707 .50824 Mdot
.49524 .55985 Mdot
.29088 .46524 Mdot
.29361 .45907 Mdot
.48778 .56568 Mdot
.5745 .50935 Mdot
.74304 .55737 Mdot
.67525 .5396 Mdot
.64051 .2965 Mdot
.30464 .45481 Mdot
.36813 .40544 Mdot
.65531 .28731 Mdot
.58779 .5869 Mdot
.45221 .58301 Mdot
.26089 .44771 Mdot
.61123 .40296 Mdot
.62409 .57458 Mdot
.46522 .54809 Mdot
.37984 .60349 Mdot
.47088 .56029 Mdot
.47817 .54098 Mdot
.59332 .37697 Mdot
.2079 .37127 Mdot
.61651 .39292 Mdot
.32769 .43463 Mdot
.45895 .55946 Mdot
.70393 .21617 Mdot
.30377 .44507 Mdot
.5918 .25986 Mdot
.59191 .68201 Mdot
.6459 .581 Mdot
.27568 .47419 Mdot
.61613 .41349 Mdot
.42108 .29308 Mdot
.55713 .70783 Mdot
.6125 .37828 Mdot
.49865 .54252 Mdot
.48859 .54626 Mdot
.25731 .46758 Mdot
.6089 .33739 Mdot
.57051 .56704 Mdot
.62646 .3708 Mdot
.4272 .33505 Mdot
.68562 .56836 Mdot
.44112 .21353 Mdot
.44968 .55823 Mdot
.61688 .38462 Mdot
.26617 .48881 Mdot
.36013 .58892 Mdot
.60336 .61152 Mdot
.41674 .21298 Mdot
.6016 .60105 Mdot
.43236 .30941 Mdot
.50007 .57932 Mdot
.67882 .5213 Mdot
.62257 .60144 Mdot
.61131 .55201 Mdot
.43077 .28625 Mdot
.62677 .60112 Mdot
.64286 .5556 Mdot
.75767 .34774 Mdot
.61242 .39133 Mdot
.63273 .6075 Mdot
.24763 .46267 Mdot
.55422 .49051 Mdot
.6062 .57071 Mdot
.34717 .3141 Mdot
.52451 .75919 Mdot
.44668 .58526 Mdot
.49817 .53411 Mdot
.44005 .7796 Mdot
.62696 .58378 Mdot
.585 .58591 Mdot
.68514 .57068 Mdot
.77556 .53082 Mdot
.26769 .46718 Mdot
.29956 .48101 Mdot
.36218 .58932 Mdot
.53849 .73485 Mdot
.36924 .60578 Mdot
.4112 .35343 Mdot
.56939 .6612 Mdot
.49254 .56721 Mdot
.60858 .37904 Mdot
.60042 .5831 Mdot
.27771 .48864 Mdot
.63284 .5708 Mdot
.66039 .53974 Mdot
.26149 .45572 Mdot
.26719 .44561 Mdot
.31857 .42923 Mdot
.37108 .62155 Mdot
.60402 .3671 Mdot
.60877 .61552 Mdot
.37575 .61865 Mdot
.45119 .54595 Mdot
.43143 .73254 Mdot
.60316 .36419 Mdot
.61371 .38633 Mdot
.62773 .33164 Mdot
.59046 .60295 Mdot
.68772 .5651 Mdot
.41129 .34833 Mdot
.58116 .37521 Mdot
.42308 .31087 Mdot
.27379 .47563 Mdot
.25715 .44519 Mdot
.63367 .5753 Mdot
.53684 .52843 Mdot
.36496 .59471 Mdot
.26368 .48275 Mdot
.5156 .55235 Mdot
.33949 .60804 Mdot
.5962 .57006 Mdot
.26926 .47776 Mdot
.39373 .5972 Mdot
.68784 .4935 Mdot
.47295 .23463 Mdot
.35149 .5939 Mdot
.44387 .56858 Mdot
.73674 .39663 Mdot
.41379 .76075 Mdot
.33383 .60156 Mdot
.42003 .35122 Mdot
.57876 .58852 Mdot
.50525 .56287 Mdot
.33494 .618 Mdot
.38521 .72873 Mdot
.26563 .45885 Mdot
.44441 .57287 Mdot
.48248 .47924 Mdot
.7893 .47223 Mdot
.35613 .59037 Mdot
.61647 .38568 Mdot
.58026 .34939 Mdot
.61514 .5976 Mdot
.57336 .665 Mdot
.43688 .33554 Mdot
.30871 .43075 Mdot
.29216 .48515 Mdot
.59469 .31743 Mdot
.45078 .72623 Mdot
.24857 .46894 Mdot
.58117 .58654 Mdot
.34749 .6413 Mdot
.64914 .60881 Mdot
.47703 .58969 Mdot
.67919 .52319 Mdot
.5098 .53255 Mdot
.35608 .59083 Mdot
.43945 .32867 Mdot
.39774 .3126 Mdot
.40501 .33475 Mdot
.25132 .46737 Mdot
.49772 .72665 Mdot
.28948 .48878 Mdot
.77178 .31563 Mdot
.34668 .62418 Mdot
.21283 .64753 Mdot
.55814 .59352 Mdot
.64574 .57595 Mdot
.66757 .56393 Mdot
.44616 .55167 Mdot
.62566 .58311 Mdot
.39137 .34889 Mdot
.31771 .44601 Mdot
.47867 .32499 Mdot
.5931 .35343 Mdot
.7688 .32678 Mdot
.28824 .45236 Mdot
.50816 .54324 Mdot
.36309 .59705 Mdot
.4627 .79216 Mdot
.40388 .59598 Mdot
.24105 .46127 Mdot
.62436 .55795 Mdot
.64117 .3365 Mdot
.29186 .73527 Mdot
.60431 .5814 Mdot
.25156 .47962 Mdot
.23585 .49073 Mdot
.66416 .49605 Mdot
.68878 .65324 Mdot
.46179 .29186 Mdot
.46959 .71674 Mdot
.39184 .5876 Mdot
.43271 .56316 Mdot
.50351 .76555 Mdot
.26382 .46491 Mdot
.31143 .4626 Mdot
.39102 .58152 Mdot
.56357 .30927 Mdot
.62827 .33813 Mdot
.64167 .31244 Mdot
.39705 .34908 Mdot
.6477 .58224 Mdot
.26375 .47489 Mdot
.61872 .30661 Mdot
.42416 .67494 Mdot
.40588 .32763 Mdot
.2712 .48273 Mdot
.59992 .60147 Mdot
.61967 .60224 Mdot
.37082 .60661 Mdot
.49648 .57784 Mdot
.42615 .57559 Mdot
.59393 .26103 Mdot
.47488 .73769 Mdot
.5903 .68229 Mdot
.64303 .58498 Mdot
.58777 .37465 Mdot
.48926 .56322 Mdot
.37261 .59524 Mdot
.66192 .58935 Mdot
.79046 .56651 Mdot
.60281 .40204 Mdot
.4202 .31053 Mdot
.46505 .55407 Mdot
.52963 .72592 Mdot
.60139 .60245 Mdot
.63315 .57978 Mdot
.67189 .54808 Mdot
.77309 .59644 Mdot
.31132 .44451 Mdot
.60074 .38658 Mdot
.3709 .61945 Mdot
.62196 .36897 Mdot
.34519 .44916 Mdot
.55455 .63776 Mdot
.58903 .60754 Mdot
.61275 .39913 Mdot
.62179 .35742 Mdot
.43287 .31043 Mdot
.39524 .31238 Mdot
.2252 .4738 Mdot
.59514 .60296 Mdot
.48448 .57408 Mdot
.63384 .35009 Mdot
.31799 .43661 Mdot
.36867 .60767 Mdot
.34574 .31307 Mdot
.64944 .59459 Mdot
.2615 .46874 Mdot
.46832 .56576 Mdot
.59273 .36556 Mdot
.28658 .46546 Mdot
.48679 .5412 Mdot
.3762 .62763 Mdot
.61344 .55414 Mdot
.27852 .50205 Mdot
.46701 .54553 Mdot
.60844 .61215 Mdot
.59828 .50032 Mdot
.57287 .66389 Mdot
.51658 .55533 Mdot
.2653 .43746 Mdot
.47181 .54724 Mdot
.58229 .34324 Mdot
.67696 .50814 Mdot
.31348 .46223 Mdot
.67869 .34492 Mdot
.59785 .68531 Mdot
.44636 .55924 Mdot
.60454 .38261 Mdot
.34772 .42313 Mdot
.54936 .33787 Mdot
.41312 .75637 Mdot
.61626 .56938 Mdot
.26547 .47775 Mdot
.37701 .60199 Mdot
.43477 .3179 Mdot
.3683 .36467 Mdot
.36363 .45066 Mdot
.29923 .46137 Mdot
.60001 .58219 Mdot
.63329 .36178 Mdot
.41643 .31284 Mdot
.66397 .40072 Mdot
.27191 .49523 Mdot
.24664 .46086 Mdot
.66653 .55026 Mdot
.36834 .60537 Mdot
.55958 .61295 Mdot
.31706 .45657 Mdot
.32058 .45858 Mdot
.75625 .34975 Mdot
.39139 .58813 Mdot
.67203 .54643 Mdot
.51386 .53755 Mdot
.66177 .56117 Mdot
.7648 .32105 Mdot
.48224 .54355 Mdot
.5926 .35252 Mdot
.62937 .59044 Mdot
.18989 .42506 Mdot
.29776 .44192 Mdot
.46933 .7169 Mdot
.46957 .31493 Mdot
.39003 .32717 Mdot
.27527 .4685 Mdot
.61883 .57278 Mdot
.34999 .30475 Mdot
.35189 .59643 Mdot
.67808 .55237 Mdot
.4469 .55591 Mdot
.58896 .31958 Mdot
.42262 .33544 Mdot
.54287 .49949 Mdot
.43358 .32652 Mdot
.41513 .33439 Mdot
.56717 .39985 Mdot
.61381 .59714 Mdot
.2861 .45605 Mdot
.24487 .48239 Mdot
.44257 .54829 Mdot
.31457 .40716 Mdot
.61474 .33031 Mdot
.1977 .41715 Mdot
.78549 .57576 Mdot
.6506 .6023 Mdot
.49089 .53807 Mdot
.44596 .58187 Mdot
.35714 .29635 Mdot
.62416 .59869 Mdot
.60054 .37965 Mdot
.31843 .45409 Mdot
.25737 .47575 Mdot
.62356 .53818 Mdot
.39711 .31275 Mdot
.39129 .61377 Mdot
.2686 .4505 Mdot
.43141 .7163 Mdot
.62363 .56513 Mdot
.37204 .33474 Mdot
.27106 .45131 Mdot
.39542 .82214 Mdot
.19176 .38965 Mdot
.62754 .37972 Mdot
.60183 .55722 Mdot
.61758 .31401 Mdot
.37022 .58781 Mdot
.31234 .47983 Mdot
.43548 .31138 Mdot
.46199 .55876 Mdot
.36575 .24161 Mdot
.25572 .47163 Mdot
.6135 .36695 Mdot
.61582 .59286 Mdot
.81106 .49781 Mdot
.62285 .61075 Mdot
.37258 .69625 Mdot
.3322 .61124 Mdot
.37103 .37125 Mdot
.42419 .30257 Mdot
.59775 .55894 Mdot
.38181 .61548 Mdot
.23738 .47649 Mdot
.26118 .45695 Mdot
.40166 .2107 Mdot
.48036 .54135 Mdot
.31428 .48099 Mdot
.60454 .61056 Mdot
.32084 .43363 Mdot
.73997 .3804 Mdot
.39149 .32381 Mdot
.65878 .55839 Mdot
.2794 .48001 Mdot
.55271 .3319 Mdot
.47579 .72307 Mdot
.61794 .5672 Mdot
.52265 .53475 Mdot
.40555 .30767 Mdot
.76839 .33043 Mdot
.29553 .43807 Mdot
.66468 .59643 Mdot
.39107 .35215 Mdot
.53547 .51988 Mdot
.48222 .32542 Mdot
.60364 .36688 Mdot
.25096 .48263 Mdot
.41324 .34013 Mdot
.4532 .56591 Mdot
.39253 .59848 Mdot
.24753 .49195 Mdot
.28556 .48004 Mdot
.64984 .53645 Mdot
.51356 .54437 Mdot
.53494 .52808 Mdot
.59003 .34314 Mdot
.42088 .32315 Mdot
.66468 .54084 Mdot
.4289 .73393 Mdot
.67588 .57982 Mdot
.4222 .32601 Mdot
.72177 .23975 Mdot
.62091 .55701 Mdot
.6498 .5904 Mdot
.80909 .51083 Mdot
.60861 .32504 Mdot
.58858 .38196 Mdot
.4673 .74618 Mdot
.59991 .54896 Mdot
.59301 .66748 Mdot
.60659 .36914 Mdot
.61586 .36454 Mdot
.59172 .66719 Mdot
.65002 .53727 Mdot
.6426 .31816 Mdot
.41515 .31453 Mdot
.39003 .32457 Mdot
.62969 .36169 Mdot
.66776 .5716 Mdot
.4015 .3633 Mdot
.6853 .47827 Mdot
.24097 .47382 Mdot
.51395 .75887 Mdot
.62513 .36181 Mdot
.47843 .71965 Mdot
.41985 .31616 Mdot
.50219 .79361 Mdot
.53032 .75971 Mdot
.61587 .61897 Mdot
.61853 .59947 Mdot
.35544 .62106 Mdot
.46822 .56128 Mdot
.48936 .56482 Mdot
.4051 .33528 Mdot
.56099 .61768 Mdot
.60265 .35662 Mdot
.58078 .56212 Mdot
.40042 .74614 Mdot
.53265 .80336 Mdot
.72893 .6379 Mdot
.61339 .35829 Mdot
.61147 .34611 Mdot
.25071 .44735 Mdot
.26183 .43499 Mdot
.59789 .61334 Mdot
.40164 .30906 Mdot
.63102 .36922 Mdot
.42523 .32619 Mdot
.26363 .46359 Mdot
.28567 .45126 Mdot
.49728 .55266 Mdot
.44558 .57366 Mdot
.27324 .4637 Mdot
.34776 .31253 Mdot
.42948 .73388 Mdot
.58029 .33712 Mdot
.77348 .31182 Mdot
.48865 .79907 Mdot
.81528 .47028 Mdot
.3789 .60251 Mdot
.57734 .5099 Mdot
.39207 .3516 Mdot
.59903 .55778 Mdot
.63707 .58597 Mdot
.47858 .55107 Mdot
.38568 .34894 Mdot
.34699 .60926 Mdot
.39065 .32603 Mdot
.39125 .6016 Mdot
.30031 .47807 Mdot
.60242 .57834 Mdot
.63408 .56013 Mdot
.43362 .31414 Mdot
.24616 .45143 Mdot
.27628 .47914 Mdot
.37896 .59775 Mdot
.46913 .79113 Mdot
.25844 .46705 Mdot
.62436 .36133 Mdot
.68917 .35524 Mdot
.48633 .54661 Mdot
.62289 .57493 Mdot
.44213 .78142 Mdot
.67897 .51095 Mdot
.45665 .54286 Mdot
.46598 .55348 Mdot
.76249 .28228 Mdot
.62121 .56321 Mdot
.38322 .20822 Mdot
.49691 .55745 Mdot
.59783 .33067 Mdot
.28385 .46091 Mdot
.48962 .53856 Mdot
.51667 .52558 Mdot
.34637 .64798 Mdot
.47677 .53651 Mdot
.62987 .33955 Mdot
.62147 .32665 Mdot
.55609 .63749 Mdot
.77508 .32251 Mdot
.37274 .6177 Mdot
.34524 .6063 Mdot
.31176 .44892 Mdot
.34772 .3442 Mdot
.57663 .61044 Mdot
.34105 .61453 Mdot
.65046 .36944 Mdot
.66441 .54577 Mdot
.57148 .65993 Mdot
.55005 .62462 Mdot
.58209 .36024 Mdot
.68926 .54398 Mdot
.30783 .44508 Mdot
.61206 .36605 Mdot
.55477 .63262 Mdot
.66166 .55269 Mdot
.60242 .36169 Mdot
.41458 .33227 Mdot
.65702 .68287 Mdot
.62548 .37364 Mdot
.55748 .70623 Mdot
.41532 .30779 Mdot
.56822 .65392 Mdot
.25567 .66895 Mdot
.42965 .84429 Mdot
.39305 .32379 Mdot
.26698 .48199 Mdot
.2647 .474 Mdot
.25436 .46052 Mdot
.58551 .35791 Mdot
.27788 .44219 Mdot
.602 .33928 Mdot
.36125 .29209 Mdot
.5349 .73319 Mdot
.36518 .61404 Mdot
.3245 .41462 Mdot
.62897 .36408 Mdot
.76843 .31719 Mdot
.88277 .5445 Mdot
.66716 .59701 Mdot
.43279 .30213 Mdot
.34014 .62299 Mdot
.46502 .71222 Mdot
.35117 .62167 Mdot
.28138 .47131 Mdot
.5299 .72936 Mdot
.63134 .56795 Mdot
.45439 .23261 Mdot
.37522 .60192 Mdot
.61705 .36476 Mdot
.64367 .53527 Mdot
.24515 .44553 Mdot
.36354 .59081 Mdot
.36788 .6009 Mdot
.6252 .58155 Mdot
.60848 .32672 Mdot
.28094 .47434 Mdot
.38102 .33852 Mdot
.3485 .50896 Mdot
.55119 .54295 Mdot
.61104 .56547 Mdot
.65511 .57856 Mdot
.48047 .7308 Mdot
.34483 .31612 Mdot
.409 .31138 Mdot
.38726 .72518 Mdot
.27875 .43684 Mdot
.4077 .75642 Mdot
.55155 .31936 Mdot
.32672 .41896 Mdot
.48155 .54394 Mdot
.48986 .54205 Mdot
.60992 .58144 Mdot
.8481 .59328 Mdot
.67621 .66261 Mdot
.40277 .3614 Mdot
.4842 .55097 Mdot
.24241 .45339 Mdot
.59335 .39423 Mdot
.45557 .48286 Mdot
.55608 .58291 Mdot
.38065 .33852 Mdot
.25868 .46122 Mdot
.81032 .65384 Mdot
.36108 .62424 Mdot
.46278 .71633 Mdot
.59921 .60463 Mdot
.61477 .58078 Mdot
.40156 .32651 Mdot
.43874 .32298 Mdot
.75935 .35157 Mdot
.40594 .57789 Mdot
.44637 .21081 Mdot
.44108 .29554 Mdot
.81007 .66119 Mdot
.45825 .58085 Mdot
.60532 .34462 Mdot
.48452 .56782 Mdot
.44026 .31811 Mdot
.63167 .58732 Mdot
.60738 .32612 Mdot
.47741 .5652 Mdot
.64389 .37695 Mdot
.57662 .66649 Mdot
.4301 .72104 Mdot
.60427 .59768 Mdot
.62556 .31886 Mdot
.60808 .36514 Mdot
.5983 .30061 Mdot
.49297 .551 Mdot
.64299 .59142 Mdot
.66356 .5982 Mdot
.65271 .58259 Mdot
.75556 .36201 Mdot
.60754 .57706 Mdot
.55477 .31249 Mdot
.45707 .74265 Mdot
.17967 .4387 Mdot
.6373 .56153 Mdot
.40766 .33924 Mdot
.60457 .5868 Mdot
.38189 .617 Mdot
.62733 .55149 Mdot
.58184 .67201 Mdot
.41117 .31553 Mdot
.79723 .54941 Mdot
.36484 .64067 Mdot
.60923 .56506 Mdot
.39043 .59136 Mdot
.57272 .25589 Mdot
.38974 .72554 Mdot
.75153 .34794 Mdot
.62658 .36978 Mdot
.29005 .49237 Mdot
.43786 .33463 Mdot
.28647 .44729 Mdot
.59929 .54653 Mdot
.48707 .57019 Mdot
.19901 .63777 Mdot
.43853 .75099 Mdot
.63024 .58896 Mdot
.43391 .57547 Mdot
.60813 .38777 Mdot
.30172 .44316 Mdot
.80452 .42954 Mdot
.66782 .55926 Mdot
.36331 .63261 Mdot
.35776 .62889 Mdot
.41653 .62409 Mdot
.5781 .3023 Mdot
.74316 .36785 Mdot
.40232 .32455 Mdot
.25172 .46987 Mdot
.33477 .61269 Mdot
.6562 .34254 Mdot
.43658 .30843 Mdot
.35621 .29953 Mdot
.41981 .33774 Mdot
.64637 .56811 Mdot
.50047 .54777 Mdot
.60807 .2756 Mdot
.47364 .54415 Mdot
.66202 .57182 Mdot
.28605 .4793 Mdot
.4816 .54263 Mdot
.35829 .61658 Mdot
.41356 .33819 Mdot
.29 .45388 Mdot
.62106 .58803 Mdot
.60454 .37281 Mdot
.50432 .6065 Mdot
.3039 .49295 Mdot
.57201 .66376 Mdot
.57193 .66367 Mdot
.57491 .3522 Mdot
.51264 .56016 Mdot
.41111 .38926 Mdot
.67061 .50063 Mdot
.35542 .45169 Mdot
.53442 .54584 Mdot
.27333 .40415 Mdot
.2888 .48963 Mdot
.27276 .45722 Mdot
.63856 .56803 Mdot
.31823 .43464 Mdot
.58051 .5928 Mdot
.26802 .43618 Mdot
.60681 .26059 Mdot
.56617 .57379 Mdot
.26562 .45407 Mdot
.4734 .57056 Mdot
.60577 .61219 Mdot
.60366 .38632 Mdot
.30193 .48399 Mdot
.61674 .61893 Mdot
.17473 .48576 Mdot
.43324 .31115 Mdot
.49326 .54937 Mdot
.47437 .68742 Mdot
.41599 .32293 Mdot
.61955 .33422 Mdot
.57757 .58089 Mdot
.33929 .61617 Mdot
.61146 .34214 Mdot
.40814 .62074 Mdot
.36722 .60402 Mdot
.45226 .71511 Mdot
.6235 .34521 Mdot
.48321 .5458 Mdot
.36903 .62987 Mdot
.43955 .55076 Mdot
.2694 .45724 Mdot
.246 .4995 Mdot
.46289 .54745 Mdot
.63402 .56948 Mdot
.24226 .45082 Mdot
.3946 .33641 Mdot
.59634 .57638 Mdot
.26251 .47571 Mdot
.48518 .55941 Mdot
.63275 .61129 Mdot
.59468 .55126 Mdot
.7622 .33341 Mdot
.45697 .58405 Mdot
.36235 .61527 Mdot
.60749 .30199 Mdot
.65449 .59756 Mdot
.38405 .61056 Mdot
.27584 .49973 Mdot
.67171 .59145 Mdot
.63512 .36457 Mdot
.67504 .48091 Mdot
.30099 .43056 Mdot
.40443 .30466 Mdot
.24987 .48827 Mdot
.37467 .58524 Mdot
.89672 .52278 Mdot
.49122 .56256 Mdot
.68139 .54208 Mdot
.65116 .55819 Mdot
.29899 .48898 Mdot
.60646 .36261 Mdot
.46311 .20763 Mdot
.61363 .55382 Mdot
.67273 .5934 Mdot
.6237 .57783 Mdot
.33209 .50258 Mdot
.58735 .34381 Mdot
.62388 .5761 Mdot
.53209 .55389 Mdot
.6581 .56842 Mdot
.37785 .59001 Mdot
.2263 .66003 Mdot
.471 .53901 Mdot
.69611 .20536 Mdot
.48238 .56418 Mdot
.25923 .45385 Mdot
.55763 .70559 Mdot
.47029 .68541 Mdot
.24203 .51951 Mdot
.61686 .3322 Mdot
.6425 .29801 Mdot
.28415 .45132 Mdot
.3479 .42795 Mdot
.54956 .60333 Mdot
.64138 .53605 Mdot
.59035 .59895 Mdot
.2815 .47114 Mdot
.31432 .43695 Mdot
.47898 .57323 Mdot
.43469 .56907 Mdot
.69241 .56443 Mdot
.27192 .48794 Mdot
.60579 .57668 Mdot
.67485 .51318 Mdot
.43559 .30288 Mdot
.62435 .38329 Mdot
.43541 .32379 Mdot
.42794 .29576 Mdot
.81566 .45987 Mdot
.47696 .73863 Mdot
.39663 .34944 Mdot
.40088 .35655 Mdot
.35301 .42425 Mdot
.79546 .47661 Mdot
.38161 .59061 Mdot
.67338 .66302 Mdot
.25825 .44571 Mdot
.6424 .59331 Mdot
.5864 .34467 Mdot
.42754 .58812 Mdot
.49252 .19942 Mdot
.66062 .75426 Mdot
.66336 .54338 Mdot
.27728 .43892 Mdot
.46371 .54621 Mdot
.45285 .5501 Mdot
.41213 .75937 Mdot
.61132 .57526 Mdot
.30659 .43043 Mdot
.79046 .47089 Mdot
.42328 .27684 Mdot
.35069 .30493 Mdot
.58851 .30164 Mdot
.6032 .58629 Mdot
.58774 .35401 Mdot
.38864 .31346 Mdot
.38194 .60986 Mdot
.36142 .62175 Mdot
.60903 .56477 Mdot
.59237 .68182 Mdot
.35553 .45805 Mdot
.61147 .5437 Mdot
.64847 .53805 Mdot
.47138 .5482 Mdot
.66866 .53876 Mdot
.66371 .59606 Mdot
.64621 .54139 Mdot
.44675 .54889 Mdot
.436 .30838 Mdot
.8019 .45049 Mdot
.44783 .55704 Mdot
.57093 .5833 Mdot
.39248 .30876 Mdot
.58099 .55796 Mdot
.39656 .33127 Mdot
.34284 .32369 Mdot
.40656 .34904 Mdot
.36532 .61912 Mdot
.28833 .4292 Mdot
.76692 .33738 Mdot
.6314 .36557 Mdot
.38933 .32099 Mdot
.38109 .62526 Mdot
.39816 .33587 Mdot
.25248 .44983 Mdot
.39782 .27596 Mdot
.56783 .36443 Mdot
.43377 .71303 Mdot
.80965 .48266 Mdot
.43222 .28315 Mdot
.2987 .43132 Mdot
.63051 .36046 Mdot
.34821 .3385 Mdot
.59375 .56158 Mdot
.36371 .62375 Mdot
.61089 .58218 Mdot
.41424 .33665 Mdot
.26421 .44178 Mdot
.75411 .34027 Mdot
.36159 .61637 Mdot
.7727 .30557 Mdot
.27443 .48944 Mdot
.63467 .55511 Mdot
.39612 .30382 Mdot
.36474 .36474 Mdot
.42746 .30568 Mdot
.53168 .74325 Mdot
.49504 .56973 Mdot
.34629 .57536 Mdot
.61652 .34438 Mdot
.4699 .57892 Mdot
.52368 .84472 Mdot
.53021 .29363 Mdot
.59659 .37144 Mdot
.31725 .47975 Mdot
.62247 .56449 Mdot
.67228 .54488 Mdot
.4526 .57289 Mdot
.63573 .33219 Mdot
.67176 .54811 Mdot
.49614 .54755 Mdot
.46526 .75112 Mdot
.58733 .30105 Mdot
.24848 .49373 Mdot
.59818 .60636 Mdot
.41086 .29351 Mdot
.40025 .30356 Mdot
.50113 .55238 Mdot
.43016 .33302 Mdot
.57278 .58343 Mdot
.62643 .35186 Mdot
.55241 .62916 Mdot
.36635 .5886 Mdot
.56415 .28232 Mdot
.41797 .59988 Mdot
.37733 .63203 Mdot
.64173 .61117 Mdot
.28595 .45328 Mdot
.3606 .24186 Mdot
.61845 .54922 Mdot
.60918 .36864 Mdot
.64561 .55581 Mdot
.67062 .54307 Mdot
.63088 .53753 Mdot
.25196 .46976 Mdot
.47743 .72281 Mdot
.60535 .57745 Mdot
.38215 .32923 Mdot
.59294 .66993 Mdot
.56185 .58653 Mdot
.40426 .57365 Mdot
.58001 .66986 Mdot
.37799 .35241 Mdot
.58273 .33119 Mdot
.28509 .4569 Mdot
.60436 .35203 Mdot
.62427 .40322 Mdot
.61876 .33411 Mdot
.57184 .30937 Mdot
.67373 .50367 Mdot
.38266 .20531 Mdot
.74081 .37712 Mdot
.81282 .48328 Mdot
.61765 .40566 Mdot
.28129 .27611 Mdot
.59669 .37473 Mdot
.61873 .33356 Mdot
.58482 .2045 Mdot
.60782 .32976 Mdot
.63444 .57512 Mdot
.64926 .56334 Mdot
.77671 .58852 Mdot
.35185 .50888 Mdot
.63099 .61044 Mdot
.44759 .54772 Mdot
.34281 .626 Mdot
.56443 .30777 Mdot
.46396 .55652 Mdot
.46307 .71098 Mdot
.50048 .54187 Mdot
.62491 .58215 Mdot
.59513 .58733 Mdot
.56225 .57368 Mdot
.55419 .80544 Mdot
.36079 .51151 Mdot
.62643 .32879 Mdot
.55814 .59837 Mdot
.48045 .33502 Mdot
.59029 .59104 Mdot
.64522 .55187 Mdot
.6881 .53776 Mdot
.28614 .45597 Mdot
.59506 .39786 Mdot
.44477 .57677 Mdot
.55518 .28414 Mdot
.60511 .60317 Mdot
.42794 .59491 Mdot
.34273 .63447 Mdot
.62023 .57229 Mdot
.61669 .32866 Mdot
.67106 .54494 Mdot
.5945 .39057 Mdot
.61973 .34198 Mdot
.67297 .59163 Mdot
.57201 .30365 Mdot
.59593 .39642 Mdot
.64038 .53635 Mdot
.25282 .44331 Mdot
.59375 .26024 Mdot
.63088 .56929 Mdot
.35835 .61281 Mdot
.62166 .5974 Mdot
.38009 .58898 Mdot
.48353 .53699 Mdot
.47097 .54622 Mdot
.73776 .59776 Mdot
.30995 .46573 Mdot
.4048 .5989 Mdot
.32258 .43506 Mdot
.569 .60549 Mdot
.64607 .38124 Mdot
.41331 .27617 Mdot
.33559 .42722 Mdot
.47306 .54749 Mdot
.37992 .70367 Mdot
.59404 .65715 Mdot
.41369 .34816 Mdot
.59759 .38517 Mdot
.79137 .44862 Mdot
.45091 .5828 Mdot
.24601 .49238 Mdot
.24264 .47649 Mdot
.48799 .34641 Mdot
.60688 .21704 Mdot
.63686 .56191 Mdot
.44196 .5824 Mdot
.60686 .47595 Mdot
.46941 .56197 Mdot
.46838 .57577 Mdot
.28428 .48131 Mdot
.62714 .61151 Mdot
.47188 .75742 Mdot
.26493 .47135 Mdot
.35516 .5989 Mdot
.59208 .35201 Mdot
.38854 .60553 Mdot
.49488 .23107 Mdot
.76071 .34926 Mdot
.27066 .46595 Mdot
.45191 .54679 Mdot
.64572 .59573 Mdot
.60047 .32818 Mdot
.66287 .402 Mdot
.61103 .39188 Mdot
.34311 .60434 Mdot
.31271 .46557 Mdot
.16368 .52617 Mdot
.61359 .59307 Mdot
.62036 .35766 Mdot
.34784 .64291 Mdot
.62146 .60292 Mdot
.39747 .31157 Mdot
.67074 .5479 Mdot
.62148 .36489 Mdot
.6821 .54389 Mdot
.61679 .34372 Mdot
.24544 .465 Mdot
.61851 .56202 Mdot
.5954 .57346 Mdot
.38552 .72034 Mdot
.34691 .61033 Mdot
.60112 .39726 Mdot
.49091 .73629 Mdot
.6618 .56122 Mdot
.42343 .76947 Mdot
.60396 .57477 Mdot
.80829 .4866 Mdot
.51849 .53745 Mdot
.49653 .54555 Mdot
.64827 .55641 Mdot
.62804 .56889 Mdot
.65866 .40766 Mdot
.73936 .38478 Mdot
.75626 .3612 Mdot
.40233 .30437 Mdot
.59851 .38255 Mdot
.26931 .47249 Mdot
.30693 .48049 Mdot
.28046 .44385 Mdot
.35753 .5881 Mdot
.55003 .59612 Mdot
.64193 .57532 Mdot
.39374 .36333 Mdot
.34385 .62151 Mdot
.61501 .35385 Mdot
.3702 .61257 Mdot
.47408 .73161 Mdot
.35522 .61361 Mdot
.48649 .56831 Mdot
.21586 .35886 Mdot
.6738 .51136 Mdot
.35981 .60135 Mdot
.62783 .37791 Mdot
.60192 .67494 Mdot
.66856 .60218 Mdot
.76738 .32472 Mdot
.35715 .6326 Mdot
.31585 .48246 Mdot
.62609 .61373 Mdot
.53959 .71025 Mdot
.40008 .33218 Mdot
.38884 .60671 Mdot
.42089 .33762 Mdot
.66447 .54291 Mdot
.65528 .30211 Mdot
.61382 .37291 Mdot
.4365 .30255 Mdot
.65133 .554 Mdot
.38844 .6075 Mdot
.27059 .46233 Mdot
.79451 .47665 Mdot
.35309 .30647 Mdot
.45641 .58715 Mdot
.41081 .75596 Mdot
.30929 .44493 Mdot
.79428 .49656 Mdot
.41604 .3436 Mdot
.5554 .59525 Mdot
.68192 .53262 Mdot
.6587 .59262 Mdot
.27864 .47746 Mdot
.27364 .45694 Mdot
.32802 .40006 Mdot
.59484 .57236 Mdot
.68977 .55004 Mdot
.58484 .32129 Mdot
.31651 .45842 Mdot
.61875 .33465 Mdot
.6263 .3175 Mdot
.26734 .48161 Mdot
.60211 .39417 Mdot
.36828 .60267 Mdot
.49875 .75419 Mdot
.41342 .34509 Mdot
.41666 .30172 Mdot
.27284 .465 Mdot
.30526 .46221 Mdot
.28649 .45282 Mdot
.67053 .55622 Mdot
.62064 .34026 Mdot
.58854 .5718 Mdot
.60672 .58866 Mdot
.67323 .59744 Mdot
.61449 .31148 Mdot
.60357 .55698 Mdot
.55546 .62495 Mdot
.33682 .62735 Mdot
.26382 .45143 Mdot
.4253 .32113 Mdot
.50225 .61173 Mdot
.38063 .33304 Mdot
.65948 .56814 Mdot
.60687 .26311 Mdot
.59479 .37897 Mdot
.35274 .62153 Mdot
.58006 .6716 Mdot
.35961 .61886 Mdot
.43537 .30213 Mdot
.58293 .32012 Mdot
.45088 .72098 Mdot
.5983 .56582 Mdot
.48182 .73442 Mdot
.30461 .69178 Mdot
.54468 .34277 Mdot
.41928 .32469 Mdot
.6817 .55898 Mdot
.50403 .54743 Mdot
.67363 .49978 Mdot
.64011 .57121 Mdot
.55951 .58939 Mdot
.53192 .68813 Mdot
.65648 .56635 Mdot
.63904 .35869 Mdot
.57328 .65356 Mdot
.43469 .56284 Mdot
.64676 .61129 Mdot
.40148 .21442 Mdot
.63794 .60804 Mdot
.59967 .56683 Mdot
.63987 .58619 Mdot
.63851 .5453 Mdot
.61543 .31397 Mdot
.55921 .64413 Mdot
.38702 .31786 Mdot
.49837 .75477 Mdot
.40883 .34561 Mdot
.27853 .46689 Mdot
.43442 .58528 Mdot
.58049 .36104 Mdot
.35889 .61894 Mdot
.3957 .48403 Mdot
.54035 .72107 Mdot
.25018 .44774 Mdot
.37378 .70565 Mdot
.3921 .61157 Mdot
.46501 .57497 Mdot
.37798 .58452 Mdot
.28123 .47983 Mdot
.39524 .31607 Mdot
.62427 .55768 Mdot
.6314 .34561 Mdot
.62498 .37553 Mdot
.64265 .61212 Mdot
.58041 .25965 Mdot
.40824 .30204 Mdot
.31796 .40808 Mdot
.64322 .56708 Mdot
.65886 .55835 Mdot
.59169 .38605 Mdot
.2908 .4411 Mdot
.59175 .65718 Mdot
.37688 .59318 Mdot
.59132 .59379 Mdot
.43809 .56007 Mdot
.47541 .73218 Mdot
.39981 .30541 Mdot
.48827 .55458 Mdot
.64177 .60143 Mdot
.4672 .73385 Mdot
.67765 .55574 Mdot
.53752 .54957 Mdot
.26393 .43493 Mdot
.67171 .59451 Mdot
.59208 .57824 Mdot
.58855 .3012 Mdot
.4196 .34162 Mdot
.60473 .36518 Mdot
.57114 .35429 Mdot
.47175 .54652 Mdot
.43061 .30913 Mdot
.64648 .54534 Mdot
.4106 .363 Mdot
.66868 .54314 Mdot
.61414 .58815 Mdot
.41752 .32766 Mdot
.61078 .33537 Mdot
.45067 .21264 Mdot
.8011 .44936 Mdot
.6602 .53987 Mdot
.62328 .59929 Mdot
.35172 .50917 Mdot
.4271 .58869 Mdot
.60067 .56138 Mdot
.6302 .36998 Mdot
.61859 .60208 Mdot
.4169 .3571 Mdot
.37506 .61478 Mdot
.60832 .37316 Mdot
.29171 .43878 Mdot
.24641 .46842 Mdot
.24306 .44185 Mdot
.48556 .56942 Mdot
.66801 .53798 Mdot
.60721 .30212 Mdot
.62225 .31183 Mdot
.50047 .71652 Mdot
.26001 .45365 Mdot
.37882 .60592 Mdot
.59621 .60701 Mdot
.43409 .57827 Mdot
.40444 .29874 Mdot
.6911 .19965 Mdot
.45226 .72396 Mdot
.33294 .62473 Mdot
.49543 .58344 Mdot
.4728 .55091 Mdot
.64876 .59026 Mdot
.38496 .6118 Mdot
.26619 .48036 Mdot
.67468 .54634 Mdot
.52899 .55376 Mdot
.32006 .47869 Mdot
.2997 .45428 Mdot
.40577 .36545 Mdot
.28134 .43471 Mdot
.39345 .59751 Mdot
.49022 .56355 Mdot
.61358 .38096 Mdot
.61554 .57287 Mdot
.4494 .5599 Mdot
.25572 .45218 Mdot
.45647 .58024 Mdot
.64416 .56176 Mdot
.58929 .37483 Mdot
.26883 .44432 Mdot
.62926 .58141 Mdot
.66114 .49418 Mdot
.76108 .33635 Mdot
.26589 .44015 Mdot
.57961 .58432 Mdot
.48599 .47973 Mdot
.29662 .45475 Mdot
.28334 .47775 Mdot
.66941 .59215 Mdot
.38513 .61662 Mdot
.60129 .59612 Mdot
.40034 .31121 Mdot
.48272 .72749 Mdot
.43348 .31321 Mdot
.41142 .76035 Mdot
.6611 .6048 Mdot
.69276 .53648 Mdot
.64436 .37884 Mdot
.40708 .60205 Mdot
.48451 .79794 Mdot
.65329 .59825 Mdot
.62576 .41746 Mdot
.47934 .72098 Mdot
.44234 .70537 Mdot
.61144 .43513 Mdot
.38778 .59606 Mdot
.40423 .33513 Mdot
.603 .56876 Mdot
.42084 .22363 Mdot
.38314 .59494 Mdot
.41339 .76119 Mdot
.58306 .56545 Mdot
.61399 .36162 Mdot
.63871 .56447 Mdot
.61671 .37708 Mdot
.63302 .60112 Mdot
.75892 .33262 Mdot
.3556 .4573 Mdot
.53214 .74243 Mdot
.4678 .57177 Mdot
.36479 .36473 Mdot
.8101 .48267 Mdot
.37174 .60442 Mdot
.68288 .54587 Mdot
.47673 .55421 Mdot
.39061 .32661 Mdot
.45015 .27685 Mdot
.28461 .45051 Mdot
.38208 .33268 Mdot
.60125 .34649 Mdot
.23848 .45773 Mdot
.47048 .57849 Mdot
.69269 .53322 Mdot
.38713 .61081 Mdot
.42999 .3084 Mdot
.62219 .56992 Mdot
.66081 .58336 Mdot
.33135 .50094 Mdot
.23414 .66874 Mdot
.63211 .3179 Mdot
.77217 .29743 Mdot
.58331 .32025 Mdot
.34563 .60792 Mdot
.24961 .445 Mdot
.63284 .58865 Mdot
.60842 .60848 Mdot
.30104 .45364 Mdot
.59598 .32987 Mdot
.39972 .60623 Mdot
.34357 .57643 Mdot
.4026 .36191 Mdot
.26992 .69437 Mdot
.60882 .37572 Mdot
.2683 .69265 Mdot
.2313 .42135 Mdot
.66318 .26984 Mdot
.47475 .79373 Mdot
.41565 .31847 Mdot
.26923 .69416 Mdot
.61678 .35996 Mdot
.65137 .5742 Mdot
.48122 .54708 Mdot
.48872 .56995 Mdot
.58853 .36038 Mdot
.2839 .46804 Mdot
.39341 .60633 Mdot
.63556 .56479 Mdot
.57269 .51236 Mdot
.66424 .40028 Mdot
.30249 .47651 Mdot
.46168 .56328 Mdot
.42325 .31361 Mdot
.62265 .60174 Mdot
.33674 .61894 Mdot
.41431 .31852 Mdot
.48714 .54067 Mdot
.52783 .73049 Mdot
.5777 .58135 Mdot
.58569 .67762 Mdot
.39912 .3297 Mdot
.4614 .59801 Mdot
.59448 .57709 Mdot
.41626 .34342 Mdot
.50411 .54031 Mdot
.42562 .38945 Mdot
.58482 .63952 Mdot
.52977 .29408 Mdot
.23631 .48336 Mdot
.26594 .43709 Mdot
.18226 .50018 Mdot
.25962 .52904 Mdot
.39517 .34573 Mdot
.45935 .55387 Mdot
.22 .65573 Mdot
.42548 .33683 Mdot
.63071 .54889 Mdot
.61181 .5662 Mdot
.79011 .47026 Mdot
.47912 .5388 Mdot
.48349 .56447 Mdot
.6597 .29261 Mdot
.58133 .55936 Mdot
.4606 .56186 Mdot
.59743 .577 Mdot
.62301 .32643 Mdot
.41929 .31276 Mdot
.68626 .78285 Mdot
.44219 .31593 Mdot
.65275 .52996 Mdot
.25913 .44493 Mdot
.23524 .47906 Mdot
.61908 .57342 Mdot
.47503 .47168 Mdot
.81271 .65714 Mdot
.6095 .56676 Mdot
.58056 .67195 Mdot
.40656 .75501 Mdot
.65615 .60799 Mdot
.62123 .39221 Mdot
.46703 .54116 Mdot
.61311 .30853 Mdot
.41356 .3243 Mdot
.3874 .59603 Mdot
.40481 .60752 Mdot
.40383 .33424 Mdot
.61796 .60916 Mdot
.41527 .59904 Mdot
.61749 .58021 Mdot
.64752 .57983 Mdot
.46695 .72909 Mdot
.33603 .61144 Mdot
.28841 .45875 Mdot
.36266 .62031 Mdot
.61507 .33112 Mdot
.73523 .25242 Mdot
.37197 .60771 Mdot
.79511 .47621 Mdot
.48898 .73245 Mdot
.22541 .65748 Mdot
.62165 .37896 Mdot
.36897 .58767 Mdot
.4048 .33712 Mdot
.47361 .69535 Mdot
.79077 .51622 Mdot
.38097 .33549 Mdot
.64449 .58447 Mdot
.6206 .31408 Mdot
.5772 .33937 Mdot
.38745 .31149 Mdot
.60819 .38533 Mdot
.58087 .61842 Mdot
.63102 .53994 Mdot
.38609 .31886 Mdot
.52148 .80731 Mdot
.42409 .30227 Mdot
.81276 .44856 Mdot
.66328 .53788 Mdot
.60886 .37055 Mdot
.8133 .4913 Mdot
.57764 .32318 Mdot
.49579 .55487 Mdot
.62089 .55404 Mdot
.37568 .60651 Mdot
.4977 .72687 Mdot
.28099 .43788 Mdot
.5529 .33041 Mdot
.62627 .36545 Mdot
.3921 .3039 Mdot
.60864 .38469 Mdot
.59752 .38648 Mdot
.43499 .30003 Mdot
.59707 .38006 Mdot
.60585 .60401 Mdot
.77323 .33213 Mdot
.60937 .38914 Mdot
.40514 .32275 Mdot
.34408 .60389 Mdot
.6278 .3791 Mdot
.34678 .40828 Mdot
.60181 .60926 Mdot
.27021 .49491 Mdot
.34351 .58866 Mdot
.61847 .31754 Mdot
.37393 .60375 Mdot
.25865 .44958 Mdot
.36871 .6327 Mdot
.41388 .37113 Mdot
.40071 .37128 Mdot
.51688 .52418 Mdot
.40843 .39429 Mdot
.6089 .32992 Mdot
.23776 .45737 Mdot
.58678 .59515 Mdot
.64615 .57062 Mdot
.33422 .60557 Mdot
.60456 .403 Mdot
.57873 .25694 Mdot
.46257 .55768 Mdot
.56337 .28291 Mdot
.40323 .30339 Mdot
.32172 .41119 Mdot
.44909 .72182 Mdot
.37086 .286 Mdot
.43372 .56387 Mdot
.47443 .55099 Mdot
.62435 .57739 Mdot
.38978 .72705 Mdot
.39235 .59663 Mdot
.26688 .29362 Mdot
.66933 .56771 Mdot
.3041 .45361 Mdot
.63642 .59636 Mdot
.5499 .60804 Mdot
.65812 .59744 Mdot
.33274 .62111 Mdot
.38838 .3511 Mdot
.63131 .36663 Mdot
.3743 .58756 Mdot
.24601 .46997 Mdot
.55775 .73 Mdot
.59615 .56384 Mdot
.58236 .5989 Mdot
.29278 .46197 Mdot
.6249 .33712 Mdot
.27789 .46168 Mdot
.41317 .34502 Mdot
.36936 .60976 Mdot
.67186 .55109 Mdot
.47739 .53877 Mdot
.3011 .48773 Mdot
.38786 .32405 Mdot
.24548 .44666 Mdot
.43332 .34322 Mdot
.47508 .54847 Mdot
.6074 .6214 Mdot
.3098 .42972 Mdot
.43841 .56559 Mdot
.75689 .46027 Mdot
.5302 .72472 Mdot
.63168 .43564 Mdot
.28531 .46917 Mdot
.23951 .51558 Mdot
.41107 .31999 Mdot
.43616 .33206 Mdot
.81372 .44438 Mdot
.84139 .60254 Mdot
.59268 .66719 Mdot
.5556 .26371 Mdot
.41241 .34552 Mdot
.39736 .32381 Mdot
.28128 .46028 Mdot
.60602 .33502 Mdot
.64622 .35914 Mdot
.23828 .46716 Mdot
.44937 .78268 Mdot
.61527 .35398 Mdot
.78193 .58106 Mdot
.28984 .48726 Mdot
.63324 .53669 Mdot
.75481 .33786 Mdot
.34067 .62978 Mdot
.40707 .74945 Mdot
.40459 .27515 Mdot
.63407 .58029 Mdot
.38675 .20575 Mdot
.28156 .45023 Mdot
.44384 .57966 Mdot
.46112 .36071 Mdot
.66304 .5564 Mdot
.63991 .59406 Mdot
.61118 .60313 Mdot
.37468 .57994 Mdot
.73531 .40858 Mdot
.63378 .58386 Mdot
.53189 .73176 Mdot
.57617 .5602 Mdot
.2826 .50109 Mdot
.36343 .61989 Mdot
.37016 .7003 Mdot
.34332 .45821 Mdot
.5505 .2855 Mdot
.55841 .59229 Mdot
.42001 .35171 Mdot
.54981 .61645 Mdot
.41789 .3295 Mdot
.37933 .35048 Mdot
.28397 .72207 Mdot
.63802 .35403 Mdot
.6693 .56186 Mdot
.29709 .47778 Mdot
.64666 .35856 Mdot
.54974 .61894 Mdot
.74865 .26394 Mdot
.3966 .29779 Mdot
.9019 .51426 Mdot
.43144 .33701 Mdot
.47118 .57657 Mdot
.59776 .35231 Mdot
.64428 .41725 Mdot
.48083 .73536 Mdot
.61709 .3344 Mdot
.30014 .52839 Mdot
.62074 .309 Mdot
.37593 .7841 Mdot
.57176 .38558 Mdot
.40733 .31594 Mdot
.38939 .30815 Mdot
.55014 .59446 Mdot
.59878 .59468 Mdot
.46763 .75391 Mdot
.46265 .55843 Mdot
.57681 .57448 Mdot
.26453 .47159 Mdot
.3411 .40177 Mdot
.39267 .23829 Mdot
.59611 .37788 Mdot
.38749 .33085 Mdot
.63849 .59445 Mdot
.66549 .54033 Mdot
.64716 .56001 Mdot
.35472 .43273 Mdot
.7822 .59065 Mdot
.60849 .58671 Mdot
.55233 .58893 Mdot
.24647 .45299 Mdot
.3312 .50255 Mdot
.62366 .2282 Mdot
.27711 .70814 Mdot
.63923 .61024 Mdot
.34306 .61478 Mdot
.34023 .60282 Mdot
.55261 .5949 Mdot
.60332 .44913 Mdot
.3918 .6561 Mdot
.62326 .56977 Mdot
.55863 .72248 Mdot
.25957 .49763 Mdot
.50328 .55076 Mdot
.25543 .4533 Mdot
.62224 .40751 Mdot
.49835 .54315 Mdot
.26628 .47682 Mdot
.51681 .75875 Mdot
.46468 .54768 Mdot
.42266 .38942 Mdot
.36532 .58848 Mdot
.59603 .57722 Mdot
.78904 .4229 Mdot
.31677 .45836 Mdot
.40164 .31256 Mdot
.59795 .36132 Mdot
.40203 .30515 Mdot
.21444 .48352 Mdot
.4313 .77622 Mdot
.49543 .5516 Mdot
.4197 .35252 Mdot
.58859 .67834 Mdot
.34447 .61985 Mdot
.42936 .33661 Mdot
.63796 .5337 Mdot
.565 .57443 Mdot
.80089 .6531 Mdot
.59133 .6056 Mdot
.33756 .39962 Mdot
.43384 .31106 Mdot
.5032 .54438 Mdot
.61407 .57364 Mdot
.27136 .49078 Mdot
.48698 .53262 Mdot
.61821 .58139 Mdot
.30355 .44124 Mdot
.61179 .56723 Mdot
.37629 .61797 Mdot
.59908 .30234 Mdot
.47746 .71624 Mdot
.36365 .56806 Mdot
.38541 .5926 Mdot
.5412 .71606 Mdot
.60561 .55819 Mdot
.28091 .53129 Mdot
.61159 .36053 Mdot
.65902 .56925 Mdot
.36593 .75233 Mdot
.59459 .34523 Mdot
.60659 .34897 Mdot
.66788 .53386 Mdot
.43019 .34494 Mdot
.29008 .46058 Mdot
.35011 .62302 Mdot
.35341 .30141 Mdot
.63061 .58294 Mdot
.68105 .55676 Mdot
.38131 .59099 Mdot
.40868 .30793 Mdot
.66777 .5488 Mdot
.50165 .32007 Mdot
.50481 .75052 Mdot
.43266 .30063 Mdot
.56096 .58618 Mdot
.79911 .568 Mdot
.58286 .34843 Mdot
.38545 .20637 Mdot
.35581 .45749 Mdot
.24342 .47425 Mdot
.45816 .56246 Mdot
.70018 .21124 Mdot
.34446 .60237 Mdot
.54803 .3162 Mdot
.64538 .56479 Mdot
.629 .59358 Mdot
.61713 .3266 Mdot
.58894 .57349 Mdot
.59598 .38055 Mdot
.34754 .41647 Mdot
.85526 .5836 Mdot
.61977 .37855 Mdot
.61951 .36986 Mdot
.67333 .67712 Mdot
.31702 .42774 Mdot
.59187 .35481 Mdot
.59106 .57769 Mdot
.21423 .49319 Mdot
.55897 .5311 Mdot
.39193 .61728 Mdot
.38724 .58074 Mdot
.62452 .38881 Mdot
.79227 .52005 Mdot
.62915 .53621 Mdot
.76563 .55341 Mdot
.38824 .65929 Mdot
.39743 .3471 Mdot
.68172 .57118 Mdot
.4676 .55522 Mdot
.26698 .44804 Mdot
.66436 .60515 Mdot
.59472 .58118 Mdot
.63569 .3562 Mdot
.35145 .63444 Mdot
.42642 .33414 Mdot
.43807 .56787 Mdot
.21621 .47869 Mdot
.36843 .59475 Mdot
.59983 .39126 Mdot
.81405 .47265 Mdot
.41904 .59545 Mdot
.43371 .57565 Mdot
.65078 .58891 Mdot
.6709 .59234 Mdot
.42524 .57724 Mdot
.40497 .33281 Mdot
.24404 .47974 Mdot
.44396 .57571 Mdot
.49094 .69636 Mdot
.48907 .76551 Mdot
.6509 .59926 Mdot
.62933 .37458 Mdot
.38926 .32791 Mdot
.4906 .56019 Mdot
.21497 .64968 Mdot
.61256 .61526 Mdot
.78257 .582 Mdot
.40165 .57861 Mdot
.46631 .55262 Mdot
.64671 .35597 Mdot
.35591 .62142 Mdot
.66328 .53808 Mdot
.53134 .73615 Mdot
.5782 .57087 Mdot
.55538 .59558 Mdot
.27074 .48111 Mdot
.41968 .33516 Mdot
.51975 .52403 Mdot
.26656 .45093 Mdot
.60509 .35092 Mdot
.75973 .56826 Mdot
.62808 .32132 Mdot
.62878 .31817 Mdot
.56682 .31155 Mdot
.40977 .30382 Mdot
.69903 .2093 Mdot
.42218 .58772 Mdot
.62958 .5596 Mdot
.3922 .3507 Mdot
.592 .36316 Mdot
.60942 .55451 Mdot
.59493 .37926 Mdot
.60415 .40046 Mdot
.57451 .57561 Mdot
.59724 .55005 Mdot
.53532 .73496 Mdot
.79443 .56178 Mdot
.36556 .62267 Mdot
.59698 .33069 Mdot
.7937 .5465 Mdot
.63138 .58856 Mdot
.59532 .58897 Mdot
.54787 .61424 Mdot
.38194 .58722 Mdot
.74155 .59282 Mdot
.6471 .56937 Mdot
.3822 .72064 Mdot
.62236 .55112 Mdot
.6078 .40607 Mdot
.36911 .36622 Mdot
.64994 .53083 Mdot
.24162 .45553 Mdot
.59815 .32877 Mdot
.34136 .63101 Mdot
.61403 .416 Mdot
.67739 .50924 Mdot
.396 .33549 Mdot
.62136 .36499 Mdot
.23801 .4752 Mdot
.40685 .31065 Mdot
.42422 .30263 Mdot
.54845 .61947 Mdot
.25131 .48621 Mdot
.3506 .63492 Mdot
.4292 .31944 Mdot
.66328 .49077 Mdot
.40667 .31473 Mdot
.70833 .52315 Mdot
.59387 .61236 Mdot
.53054 .7339 Mdot
.44913 .57117 Mdot
.51881 .53378 Mdot
.43227 .31524 Mdot
.3766 .59218 Mdot
.66806 .55011 Mdot
.60542 .3886 Mdot
.34158 .60953 Mdot
.75122 .3466 Mdot
.23491 .47361 Mdot
.5798 .3344 Mdot
.3551 .30213 Mdot
.59493 .33715 Mdot
.40965 .75356 Mdot
.33664 .63142 Mdot
.43991 .58307 Mdot
.46829 .71676 Mdot
.46776 .56466 Mdot
.63879 .61544 Mdot
.66843 .55216 Mdot
.60948 .60592 Mdot
.25884 .44472 Mdot
.38267 .58066 Mdot
.6161 .38983 Mdot
.54554 .50711 Mdot
.40842 .30625 Mdot
.57622 .6605 Mdot
.44474 .57849 Mdot
.6648 .54233 Mdot
.59373 .36705 Mdot
.59659 .39784 Mdot
.73827 .39054 Mdot
.296 .45175 Mdot
.54254 .52479 Mdot
.65179 .6001 Mdot
.55614 .51001 Mdot
.4323 .31355 Mdot
.52143 .30348 Mdot
.27244 .49608 Mdot
.90309 .51095 Mdot
.26463 .45273 Mdot
.50187 .57653 Mdot
.58617 .36213 Mdot
.35981 .6092 Mdot
.62171 .61045 Mdot
.5822 .30228 Mdot
.6436 .33025 Mdot
.33474 .64722 Mdot
.3574 .61794 Mdot
.34921 .35817 Mdot
.39927 .35025 Mdot
.43623 .56734 Mdot
.6245 .55049 Mdot
.59021 .56209 Mdot
.58652 .5882 Mdot
.38817 .3405 Mdot
.60423 .5476 Mdot
.36328 .3589 Mdot
.67329 .51002 Mdot
.36759 .75452 Mdot
.29159 .47427 Mdot
.18583 .42957 Mdot
.61824 .31575 Mdot
.748 .58513 Mdot
.70483 .52669 Mdot
.52724 .7271 Mdot
.39124 .3566 Mdot
.50017 .53793 Mdot
.28487 .46154 Mdot
.38631 .24476 Mdot
.29268 .47458 Mdot
.73955 .73216 Mdot
.79027 .46858 Mdot
.38014 .38355 Mdot
.58566 .56609 Mdot
.26819 .48389 Mdot
.795 .52461 Mdot
.44308 .57409 Mdot
.41539 .5982 Mdot
.66735 .50482 Mdot
.75665 .35736 Mdot
.36781 .62225 Mdot
.63079 .61014 Mdot
.61675 .31174 Mdot
.61629 .61007 Mdot
.62267 .61088 Mdot
.64659 .56348 Mdot
.42448 .29227 Mdot
.59444 .61348 Mdot
.60071 .59914 Mdot
.16055 .56202 Mdot
.40695 .63045 Mdot
.27547 .43438 Mdot
.646 .41758 Mdot
.34391 .62162 Mdot
.62112 .40788 Mdot
.47364 .71621 Mdot
.43833 .32544 Mdot
.73702 .39321 Mdot
.64485 .53677 Mdot
.5543 .31541 Mdot
.44012 .32745 Mdot
.38527 .61829 Mdot
.47165 .55489 Mdot
.4987 .19599 Mdot
.32223 .43345 Mdot
.48189 .56133 Mdot
.29743 .44108 Mdot
.69064 .52921 Mdot
.61101 .38078 Mdot
.467 .56409 Mdot
.42774 .33069 Mdot
.28634 .4805 Mdot
.54068 .72331 Mdot
.61343 .59885 Mdot
.2835 .47208 Mdot
.45243 .55826 Mdot
.49663 .72833 Mdot
.47946 .72246 Mdot
.27274 .48464 Mdot
.3941 .36474 Mdot
.42445 .30735 Mdot
.34032 .6213 Mdot
.58577 .37245 Mdot
.62929 .34098 Mdot
.41456 .30881 Mdot
.36884 .24576 Mdot
.63062 .58111 Mdot
.61333 .59032 Mdot
.45726 .71391 Mdot
.65013 .54924 Mdot
.34836 .51762 Mdot
.47777 .56168 Mdot
.63301 .3514 Mdot
.66808 .5511 Mdot
.66575 .54749 Mdot
.63877 .60841 Mdot
.45189 .78546 Mdot
.26091 .44514 Mdot
.60536 .54514 Mdot
.38647 .61 Mdot
.75591 .35106 Mdot
.59104 .59727 Mdot
.41744 .57203 Mdot
.58548 .36198 Mdot
.479 .31997 Mdot
.40026 .31377 Mdot
.30486 .47144 Mdot
.3 .47577 Mdot
.30695 .69818 Mdot
.6213 .32162 Mdot
.48068 .56183 Mdot
.32012 .47915 Mdot
.48661 .56705 Mdot
.35508 .61713 Mdot
.59124 .64449 Mdot
.33909 .52034 Mdot
.27711 .43442 Mdot
.44577 .30851 Mdot
.66203 .57036 Mdot
.59213 .59621 Mdot
.56415 .27202 Mdot
.60207 .57611 Mdot
.37614 .61041 Mdot
.41666 .34857 Mdot
.61977 .36441 Mdot
.37047 .62389 Mdot
.42757 .34436 Mdot
.621 .33561 Mdot
.57282 .56372 Mdot
.61384 .55316 Mdot
.60115 .35431 Mdot
.59548 .38758 Mdot
.63439 .57338 Mdot
.29921 .74661 Mdot
.63305 .36145 Mdot
.59786 .35699 Mdot
.75574 .35282 Mdot
.30635 .43102 Mdot
.47956 .53259 Mdot
.42057 .35418 Mdot
.60327 .59989 Mdot
.29439 .46994 Mdot
.353 .60853 Mdot
.62807 .36085 Mdot
.6677 .59678 Mdot
.62659 .58599 Mdot
.34353 .61691 Mdot
.38688 .58432 Mdot
.36398 .59129 Mdot
.38723 .3122 Mdot
.64295 .53583 Mdot
.59441 .3541 Mdot
.38252 .33806 Mdot
.33576 .62021 Mdot
.39213 .58898 Mdot
.40965 .79895 Mdot
.6331 .57767 Mdot
.38008 .58222 Mdot
.72357 .24163 Mdot
.52664 .7586 Mdot
.4962 .56046 Mdot
.23401 .45289 Mdot
.21799 .504 Mdot
.45435 .59707 Mdot
.4163 .33738 Mdot
.57394 .66251 Mdot
.38828 .61968 Mdot
.44504 .56539 Mdot
.61158 .594 Mdot
.68192 .58392 Mdot
.34389 .60714 Mdot
.42922 .77573 Mdot
.6372 .34785 Mdot
.66873 .41323 Mdot
.34476 .62229 Mdot
.27389 .48617 Mdot
.27508 .49717 Mdot
.27005 .45594 Mdot
.65774 .59923 Mdot
.73692 .6305 Mdot
.64854 .47614 Mdot
.73341 .57512 Mdot
.40306 .3501 Mdot
.59798 .39882 Mdot
.76024 .34321 Mdot
.60832 .34747 Mdot
.28697 .44315 Mdot
.37767 .59252 Mdot
.6214 .32888 Mdot
.41335 .30173 Mdot
.42741 .30923 Mdot
.31085 .43023 Mdot
.25718 .45516 Mdot
.27055 .46423 Mdot
.58853 .3328 Mdot
.58857 .37126 Mdot
.59609 .56054 Mdot
.62188 .38252 Mdot
.34696 .43103 Mdot
.34783 .42294 Mdot
.31982 .44072 Mdot
.4067 .32752 Mdot
.61991 .34269 Mdot
.59717 .57286 Mdot
.52854 .68232 Mdot
.30771 .4865 Mdot
.34735 .63154 Mdot
.77363 .33019 Mdot
.83224 .61514 Mdot
.67629 .57115 Mdot
.39595 .34216 Mdot
.47821 .56866 Mdot
.61842 .60615 Mdot
.24249 .47466 Mdot
.45202 .58939 Mdot
.47726 .54039 Mdot
.58277 .59415 Mdot
.57079 .58938 Mdot
.39149 .32918 Mdot
.47219 .7132 Mdot
.44277 .56734 Mdot
.55142 .63163 Mdot
.41121 .35222 Mdot
.29563 .48909 Mdot
.18285 .48396 Mdot
.64409 .28537 Mdot
.39379 .6925 Mdot
.49135 .54172 Mdot
.60996 .61554 Mdot
.2604 .47189 Mdot
.37664 .62215 Mdot
.26126 .46748 Mdot
.61869 .40542 Mdot
.30168 .43057 Mdot
.60449 .57024 Mdot
.59409 .3514 Mdot
.42641 .30645 Mdot
.46126 .68958 Mdot
.5159 .50624 Mdot
.27577 .49061 Mdot
.4329 .58047 Mdot
.58815 .55576 Mdot
.67003 .49395 Mdot
.51842 .53442 Mdot
.59213 .58391 Mdot
.4182 .32725 Mdot
.59504 .37444 Mdot
.39536 .31146 Mdot
.50028 .5345 Mdot
.61021 .44186 Mdot
.39804 .31554 Mdot
.72222 .64319 Mdot
.39434 .60448 Mdot
.43787 .78024 Mdot
.62297 .56714 Mdot
.42554 .33179 Mdot
.5816 .59616 Mdot
.6027 .32846 Mdot
.50579 .76236 Mdot
.51141 .74432 Mdot
.42028 .31446 Mdot
.49584 .56979 Mdot
.49084 .73153 Mdot
.47206 .53321 Mdot
.41046 .34539 Mdot
.53902 .76034 Mdot
.4842 .55601 Mdot
.36509 .59672 Mdot
.39163 .58663 Mdot
.37557 .59737 Mdot
.60767 .58954 Mdot
.81083 .53602 Mdot
.3383 .60877 Mdot
.46402 .30634 Mdot
.38187 .60949 Mdot
.47937 .58812 Mdot
.58322 .25662 Mdot
.39319 .59889 Mdot
.61266 .57082 Mdot
.68224 .53052 Mdot
.57741 .66741 Mdot
.24683 .48928 Mdot
.4794 .20453 Mdot
.16054 .55278 Mdot
.63343 .58855 Mdot
.76687 .33325 Mdot
.59344 .30052 Mdot
.442 .58423 Mdot
.5169 .73886 Mdot
.59915 .68589 Mdot
.60727 .34316 Mdot
.47001 .71545 Mdot
.58393 .33111 Mdot
.45862 .57504 Mdot
.61203 .58751 Mdot
.60032 .32778 Mdot
.5533 .3305 Mdot
.48709 .79876 Mdot
.56973 .2785 Mdot
.62198 .34067 Mdot
.41993 .34148 Mdot
.41088 .33856 Mdot
.42012 .32351 Mdot
.25023 .46113 Mdot
.62188 .36918 Mdot
.57475 .56547 Mdot
.24408 .46943 Mdot
.64552 .58129 Mdot
.41825 .31091 Mdot
.5204 .73741 Mdot
.61924 .36896 Mdot
.62531 .56903 Mdot
.79221 .53513 Mdot
.30778 .44488 Mdot
.34212 .61562 Mdot
.76958 .3306 Mdot
.23699 .45256 Mdot
.41049 .36261 Mdot
.62217 .40065 Mdot
.40354 .62985 Mdot
.55852 .64547 Mdot
.65295 .59303 Mdot
.62038 .55797 Mdot
.57134 .66363 Mdot
.79404 .46538 Mdot
.44596 .553 Mdot
.24625 .4693 Mdot
.3019 .4317 Mdot
.6024 .61077 Mdot
.62322 .37126 Mdot
.34163 .63888 Mdot
.41054 .58752 Mdot
.53607 .545 Mdot
.4814 .73066 Mdot
.5317 .73166 Mdot
.64146 .54574 Mdot
.70642 .63281 Mdot
.23951 .47744 Mdot
.49463 .56434 Mdot
.47501 .73044 Mdot
.3702 .60195 Mdot
.65065 .57471 Mdot
.66093 .39845 Mdot
.62551 .36101 Mdot
.28659 .4673 Mdot
.41175 .29354 Mdot
.4178 .597 Mdot
.31985 .43846 Mdot
.60287 .61093 Mdot
.66645 .548 Mdot
.42936 .33395 Mdot
.61907 .40108 Mdot
.35535 .59825 Mdot
.24394 .4654 Mdot
.36332 .60667 Mdot
.60579 .38212 Mdot
.62894 .35945 Mdot
.65531 .56952 Mdot
.54544 .52132 Mdot
.28257 .49007 Mdot
.65667 .60314 Mdot
.27646 .47368 Mdot
.33091 .50039 Mdot
.40293 .29977 Mdot
.65866 .56751 Mdot
.64491 .37232 Mdot
.41896 .30936 Mdot
.63594 .58941 Mdot
.56828 .65732 Mdot
.66634 .54595 Mdot
.26742 .48446 Mdot
.41035 .58295 Mdot
.36434 .59957 Mdot
.71004 .56831 Mdot
.74383 .36224 Mdot
.65413 .54785 Mdot
.31755 .45372 Mdot
.65029 .4909 Mdot
.39439 .32729 Mdot
.58784 .34734 Mdot
.19248 .39602 Mdot
.40451 .32097 Mdot
.62045 .56548 Mdot
.37247 .60826 Mdot
.59919 .39356 Mdot
.50095 .54604 Mdot
.43364 .74061 Mdot
.52104 .54494 Mdot
.54639 .52502 Mdot
.4436 .55789 Mdot
.56032 .26276 Mdot
.26776 .46554 Mdot
.59302 .3646 Mdot
.39957 .34353 Mdot
.3945 .33226 Mdot
.29374 .44147 Mdot
.74842 .3554 Mdot
.65325 .25605 Mdot
.71697 .23066 Mdot
.32374 .45164 Mdot
.38132 .59989 Mdot
.50849 .76006 Mdot
.27205 .45537 Mdot
.27822 .43705 Mdot
.35103 .45585 Mdot
.5595 .27441 Mdot
.61198 .33701 Mdot
.62687 .58698 Mdot
.76132 .33487 Mdot
.64092 .56151 Mdot
.39827 .69079 Mdot
.41629 .31148 Mdot
.58802 .34657 Mdot
.36753 .41716 Mdot
.64944 .60945 Mdot
.63574 .60349 Mdot
.34545 .40663 Mdot
.46596 .55878 Mdot
.23999 .66945 Mdot
.63908 .55621 Mdot
.25408 .46311 Mdot
.65732 .34285 Mdot
.45152 .57491 Mdot
.79334 .53553 Mdot
.43456 .31487 Mdot
.49449 .5547 Mdot
.45113 .57587 Mdot
.70205 .63862 Mdot
.58847 .32229 Mdot
.62812 .33394 Mdot
.37934 .58412 Mdot
.61068 .26528 Mdot
.43591 .31713 Mdot
.52558 .28746 Mdot
.59189 .57814 Mdot
.38002 .35508 Mdot
.34736 .57484 Mdot
.63851 .58618 Mdot
.5504 .62198 Mdot
.73804 .38987 Mdot
.6752 .58111 Mdot
.68441 .51909 Mdot
.40907 .32041 Mdot
.3695 .7486 Mdot
.58732 .55914 Mdot
.28398 .47058 Mdot
.60342 .33573 Mdot
.58218 .32689 Mdot
.36731 .62747 Mdot
.36111 .45457 Mdot
.87672 .55309 Mdot
.58897 .3448 Mdot
.61065 .59815 Mdot
.39629 .32388 Mdot
.4989 .5494 Mdot
.45081 .56958 Mdot
.49311 .57244 Mdot
.62446 .35718 Mdot
.44878 .57406 Mdot
.55924 .30434 Mdot
.47112 .71523 Mdot
.75152 .58037 Mdot
.42326 .31839 Mdot
.37959 .60366 Mdot
.54647 .5408 Mdot
.3372 .48428 Mdot
.62697 .54948 Mdot
.39685 .69131 Mdot
.59209 .3052 Mdot
.37804 .60749 Mdot
.62157 .60857 Mdot
.43727 .56274 Mdot
.55958 .71054 Mdot
.36785 .63671 Mdot
.44546 .5552 Mdot
.67522 .56478 Mdot
.61135 .33023 Mdot
.48068 .56326 Mdot
.61923 .36055 Mdot
.62671 .60922 Mdot
.39713 .66457 Mdot
.59468 .33325 Mdot
.4654 .20913 Mdot
.42251 .59157 Mdot
.43546 .33486 Mdot
.68757 .57617 Mdot
.64013 .61017 Mdot
.76206 .60519 Mdot
.495 .55789 Mdot
.4053 .21486 Mdot
.28231 .47597 Mdot
.22638 .66646 Mdot
.25104 .4373 Mdot
.35362 .39636 Mdot
.49093 .32803 Mdot
.677 .58791 Mdot
.74805 .35738 Mdot
.74544 .62241 Mdot
.3942 .36321 Mdot
.75448 .61433 Mdot
.59887 .59486 Mdot
.65004 .58978 Mdot
.27815 .47365 Mdot
.37327 .33648 Mdot
.66042 .52965 Mdot
.47607 .73091 Mdot
.38677 .61771 Mdot
.60571 .36229 Mdot
.60219 .58922 Mdot
.55029 .34996 Mdot
.28061 .48535 Mdot
.63701 .43572 Mdot
.61877 .57005 Mdot
.46651 .55865 Mdot
.37719 .34493 Mdot
.42811 .30711 Mdot
.25944 .48585 Mdot
.26197 .48783 Mdot
.63728 .61077 Mdot
.38516 .32355 Mdot
.60241 .55508 Mdot
.49231 .73095 Mdot
.45309 .55642 Mdot
.35109 .61692 Mdot
.59575 .56901 Mdot
.68162 .30622 Mdot
.50834 .84107 Mdot
.65648 .59953 Mdot
.62359 .31729 Mdot
.27476 .46541 Mdot
.27076 .44138 Mdot
.62918 .34221 Mdot
.27287 .44112 Mdot
.67169 .40986 Mdot
.81019 .53982 Mdot
.35695 .6149 Mdot
.62503 .47889 Mdot
.38721 .59645 Mdot
.49358 .55726 Mdot
.63343 .57609 Mdot
.30165 .26305 Mdot
.32315 .45221 Mdot
.50245 .61142 Mdot
.41151 .311 Mdot
.48874 .56952 Mdot
.62258 .54105 Mdot
.33934 .59334 Mdot
.27582 .44857 Mdot
.42293 .57813 Mdot
.64938 .56659 Mdot
.59126 .33186 Mdot
.68081 .55301 Mdot
.46561 .5766 Mdot
.48332 .56521 Mdot
.4412 .55274 Mdot
.42757 .34439 Mdot
.59946 .38365 Mdot
.34955 .3612 Mdot
.31128 .44622 Mdot
.57565 .57676 Mdot
.61178 .60074 Mdot
.59182 .38948 Mdot
.62321 .56028 Mdot
.38406 .32377 Mdot
.66399 .17631 Mdot
.37042 .59009 Mdot
.49944 .55353 Mdot
.49473 .23114 Mdot
.44174 .55167 Mdot
.6734 .55799 Mdot
.63508 .68706 Mdot
.66332 .4015 Mdot
.43135 .34171 Mdot
.56035 .60174 Mdot
.27541 .43334 Mdot
.35807 .59754 Mdot
.41259 .30102 Mdot
.62625 .54139 Mdot
.60839 .57024 Mdot
.37751 .6063 Mdot
.36799 .4081 Mdot
.40298 .59718 Mdot
.40214 .34613 Mdot
.51015 .55452 Mdot
.53103 .68153 Mdot
.62382 .57888 Mdot
.4741 .5603 Mdot
.59946 .37538 Mdot
.39508 .34794 Mdot
.73627 .41328 Mdot
.4562 .57593 Mdot
.35632 .29742 Mdot
.43112 .30957 Mdot
.65357 .58922 Mdot
.61448 .32213 Mdot
.56936 .34665 Mdot
.59618 .3717 Mdot
.3337 .73801 Mdot
.34169 .34365 Mdot
.27146 .46743 Mdot
.40544 .32666 Mdot
.29777 .46479 Mdot
.3955 .60179 Mdot
.48754 .76293 Mdot
.26782 .48946 Mdot
.64104 .34747 Mdot
.29797 .47 Mdot
.603 .55524 Mdot
.43877 .32819 Mdot
.29143 .48748 Mdot
.59014 .57563 Mdot
.56221 .57356 Mdot
.47309 .56725 Mdot
.34065 .63683 Mdot
.47625 .72292 Mdot
.6307 .56465 Mdot
.47571 .55673 Mdot
.62674 .57141 Mdot
.38477 .32247 Mdot
.4496 .68613 Mdot
.57351 .58321 Mdot
.32332 .45384 Mdot
.51592 .18749 Mdot
.31209 .4337 Mdot
.49299 .48077 Mdot
.64396 .58066 Mdot
.62725 .57843 Mdot
.58992 .55436 Mdot
.76734 .36139 Mdot
.3967 .3678 Mdot
.61479 .6231 Mdot
.24253 .45153 Mdot
.61297 .3446 Mdot
.62312 .32463 Mdot
.60559 .67182 Mdot
.4785 .5604 Mdot
.3884 .31209 Mdot
.62882 .57955 Mdot
.47817 .57175 Mdot
.45927 .73795 Mdot
.59516 .26241 Mdot
.34672 .44321 Mdot
.29546 .43804 Mdot
.58258 .36269 Mdot
.25316 .44743 Mdot
.62251 .542 Mdot
.45259 .57339 Mdot
.34135 .33071 Mdot
.44667 .292 Mdot
.35766 .59838 Mdot
.64561 .58951 Mdot
.4612 .7891 Mdot
.24633 .4534 Mdot
.24846 .4844 Mdot
.59936 .55659 Mdot
.63529 .29387 Mdot
.4696 .82935 Mdot
.38988 .34979 Mdot
.69308 .48944 Mdot
.80317 .42926 Mdot
.67582 .73867 Mdot
.40195 .33529 Mdot
.55186 .62539 Mdot
.2417 .48837 Mdot
.2838 .66565 Mdot
.6095 .34443 Mdot
.35491 .5993 Mdot
.59128 .57354 Mdot
.64025 .34641 Mdot
.32477 .44755 Mdot
.60922 .39504 Mdot
.45985 .5609 Mdot
.44014 .32595 Mdot
.26511 .44702 Mdot
.40969 .29242 Mdot
.64333 .382 Mdot
.38075 .59434 Mdot
.3858 .71961 Mdot
.66449 .49719 Mdot
.73889 .38517 Mdot
.63382 .53703 Mdot
.4106 .62951 Mdot
.61545 .54186 Mdot
.58048 .32651 Mdot
.62145 .56734 Mdot
.56225 .58373 Mdot
.23577 .48167 Mdot
.65167 .59751 Mdot
.59321 .5749 Mdot
.79242 .53972 Mdot
.64083 .59062 Mdot
.63313 .6102 Mdot
.65413 .59199 Mdot
.63206 .32803 Mdot
.65198 .56444 Mdot
.592 .37988 Mdot
.54907 .32149 Mdot
.31051 .44592 Mdot
.39478 .59783 Mdot
.39318 .59699 Mdot
.40924 .67055 Mdot
.45881 .78804 Mdot
.76056 .33818 Mdot
.61585 .35087 Mdot
.43154 .31361 Mdot
.59529 .56035 Mdot
.42518 .81112 Mdot
.39848 .66534 Mdot
.25462 .49442 Mdot
.29026 .48383 Mdot
.58527 .59103 Mdot
.8221 .62772 Mdot
.63258 .55457 Mdot
.45205 .7227 Mdot
.60693 .58891 Mdot
.65877 .56313 Mdot
.25385 .43732 Mdot
.40856 .75261 Mdot
.59977 .54758 Mdot
.59387 .31737 Mdot
.35321 .60231 Mdot
.47624 .56349 Mdot
.4009 .66753 Mdot
.81561 .45812 Mdot
.669 .30858 Mdot
.58678 .55587 Mdot
.24229 .46666 Mdot
.63141 .35406 Mdot
.45921 .71475 Mdot
.38317 .33883 Mdot
.43526 .74512 Mdot
.7114 .52835 Mdot
.3911 .35327 Mdot
.36374 .59637 Mdot
.30341 .48825 Mdot
.64552 .60463 Mdot
.25742 .47336 Mdot
.65531 .60703 Mdot
.45101 .73673 Mdot
.35384 .61534 Mdot
.62093 .3078 Mdot
.42165 .34123 Mdot
.63779 .34224 Mdot
.63037 .43663 Mdot
.39469 .66798 Mdot
.1907 .62943 Mdot
.31843 .43736 Mdot
.54352 .49923 Mdot
.58875 .3573 Mdot
.61529 .61551 Mdot
.71343 .22976 Mdot
.6075 .37623 Mdot
.5946 .33034 Mdot
.43035 .71812 Mdot
.40813 .75965 Mdot
.66126 .59576 Mdot
.63255 .37059 Mdot
.30909 .48431 Mdot
.36127 .61829 Mdot
.58843 .58654 Mdot
.46009 .57213 Mdot
.61985 .32771 Mdot
.28125 .44518 Mdot
.40321 .74316 Mdot
.25505 .45877 Mdot
.60643 .33849 Mdot
.31014 .46569 Mdot
.35063 .35517 Mdot
.26935 .48964 Mdot
.60415 .56453 Mdot
.62775 .57954 Mdot
.56759 .36564 Mdot
.62896 .35962 Mdot
.67335 .55753 Mdot
.63731 .56201 Mdot
.59204 .35719 Mdot
.3224 .47245 Mdot
.67916 .35649 Mdot
.66949 .55774 Mdot
.62931 .58364 Mdot
.37691 .58796 Mdot
.49651 .70448 Mdot
.46012 .69993 Mdot
.60352 .55722 Mdot
.38036 .59726 Mdot
.58594 .33729 Mdot
.63201 .57176 Mdot
.40438 .75159 Mdot
.24761 .4966 Mdot
.60874 .54962 Mdot
.49808 .54495 Mdot
.6564 .53249 Mdot
.55185 .80451 Mdot
.59029 .5545 Mdot
.6006 .34818 Mdot
.59693 .34289 Mdot
.26989 .49993 Mdot
.60207 .35625 Mdot
.49827 .55462 Mdot
.42023 .30663 Mdot
.71077 .50842 Mdot
.49268 .5667 Mdot
.45364 .54618 Mdot
.42226 .58778 Mdot
.43857 .57641 Mdot
.41282 .5648 Mdot
.34761 .44262 Mdot
.48715 .54244 Mdot
.59232 .37356 Mdot
.57574 .43299 Mdot
.50403 .53887 Mdot
.38427 .31997 Mdot
.4496 .57543 Mdot
.61319 .54812 Mdot
.55729 .58231 Mdot
.64182 .41632 Mdot
.38248 .34052 Mdot
.51547 .5288 Mdot
.58831 .58594 Mdot
.66205 .40122 Mdot
.6009 .58981 Mdot
.36402 .63282 Mdot
.61773 .36745 Mdot
.24838 .45963 Mdot
.35214 .61921 Mdot
.44232 .56349 Mdot
.34052 .61731 Mdot
.26468 .47343 Mdot
.42915 .32543 Mdot
.60446 .56612 Mdot
.38596 .62432 Mdot
.39314 .60243 Mdot
.68759 .55806 Mdot
.59617 .34096 Mdot
.52325 .54549 Mdot
.63624 .57395 Mdot
.59182 .55297 Mdot
.6294 .34014 Mdot
.37723 .20492 Mdot
.64517 .60225 Mdot
.54837 .62312 Mdot
.58516 .31742 Mdot
.47845 .57293 Mdot
.2466 .46375 Mdot
.66524 .59969 Mdot
.39867 .31141 Mdot
.41391 .30814 Mdot
.3218 .45517 Mdot
.6256 .33227 Mdot
.27063 .44334 Mdot
.6432 .61299 Mdot
.44657 .57542 Mdot
.59237 .59084 Mdot
.33366 .40363 Mdot
.43388 .20853 Mdot
.59965 .39225 Mdot
.31076 .44265 Mdot
.47393 .751 Mdot
.42776 .34763 Mdot
.33006 .43354 Mdot
.59072 .31786 Mdot
.63637 .36161 Mdot
.62695 .34221 Mdot
.38968 .60516 Mdot
.26123 .45307 Mdot
.61468 .41389 Mdot
.61699 .41497 Mdot
.65599 .53988 Mdot
.58706 .58284 Mdot
.58302 .3474 Mdot
.34188 .47314 Mdot
.36182 .59955 Mdot
.2497 .44535 Mdot
.47902 .83296 Mdot
.39265 .34982 Mdot
.79386 .53733 Mdot
.62019 .55056 Mdot
.90715 .50269 Mdot
.63332 .55499 Mdot
.60595 .59475 Mdot
.62221 .40752 Mdot
.39725 .58856 Mdot
.36513 .61645 Mdot
.58919 .35447 Mdot
.60817 .39941 Mdot
.36333 .63043 Mdot
.50456 .68976 Mdot
.52497 .80887 Mdot
.46264 .73125 Mdot
.6091 .3929 Mdot
.70042 .50892 Mdot
.41604 .32461 Mdot
.59829 .30141 Mdot
.35855 .361 Mdot
.31037 .46966 Mdot
.27502 .49 Mdot
.43226 .3285 Mdot
.6422 .60497 Mdot
.26261 .43454 Mdot
.6373 .53499 Mdot
.38204 .38616 Mdot
.55035 .60522 Mdot
.31243 .76812 Mdot
.61447 .56229 Mdot
.48831 .47072 Mdot
.57178 .25861 Mdot
.67259 .54779 Mdot
.80896 .50688 Mdot
.35179 .59963 Mdot
.57787 .3332 Mdot
.37932 .34113 Mdot
.76201 .33241 Mdot
.62536 .57875 Mdot
.62825 .37786 Mdot
.41422 .34792 Mdot
.4168 .21484 Mdot
.55198 .63165 Mdot
.66465 .54148 Mdot
.70491 .21885 Mdot
.63099 .31661 Mdot
.2484 .46213 Mdot
.68147 .47453 Mdot
.60661 .40286 Mdot
.5568 .64055 Mdot
.32219 .46824 Mdot
.5564 .70384 Mdot
.62221 .38797 Mdot
.40374 .59416 Mdot
.60958 .36104 Mdot
.3537 .62832 Mdot
.61269 .41268 Mdot
.30979 .45013 Mdot
.64281 .59552 Mdot
.30927 .44703 Mdot
.34144 .62908 Mdot
.31561 .43901 Mdot
.38045 .34317 Mdot
.47202 .54655 Mdot
.41963 .31075 Mdot
.49656 .76407 Mdot
.74383 .43013 Mdot
.4209 .33354 Mdot
.63994 .67737 Mdot
.60473 .57112 Mdot
.60489 .4068 Mdot
.24985 .456 Mdot
.23029 .47102 Mdot
.47795 .72515 Mdot
.61348 .3343 Mdot
.29132 .44475 Mdot
.67441 .50106 Mdot
.37646 .23848 Mdot
.56502 .5697 Mdot
.1872 .40981 Mdot
.59497 .35523 Mdot
.23161 .46823 Mdot
.45482 .71805 Mdot
.63513 .37372 Mdot
.28608 .48929 Mdot
.41583 .34217 Mdot
.39923 .31127 Mdot
.61313 .56051 Mdot
.3927 .30017 Mdot
.24847 .49044 Mdot
.6239 .45058 Mdot
.58678 .34426 Mdot
.44371 .20649 Mdot
.37434 .59187 Mdot
.25538 .4474 Mdot
.44799 .56325 Mdot
.64443 .37401 Mdot
.29925 .46569 Mdot
.86837 .56515 Mdot
.47581 .8612 Mdot
.28809 .4452 Mdot
.61761 .36539 Mdot
.62608 .35374 Mdot
.67322 .57345 Mdot
.4786 .72996 Mdot
.27825 .44875 Mdot
.2975 .26492 Mdot
.53371 .73411 Mdot
.47575 .54753 Mdot
.16042 .55801 Mdot
.57694 .56338 Mdot
.63078 .53824 Mdot
.39293 .34541 Mdot
.63502 .60272 Mdot
.60861 .39824 Mdot
.63473 .55501 Mdot
.39866 .30627 Mdot
.32073 .45548 Mdot
.6276 .5754 Mdot
.36048 .59643 Mdot
.38943 .3309 Mdot
.38839 .32223 Mdot
.30793 .46623 Mdot
.62467 .33276 Mdot
.76347 .32455 Mdot
.2557 .45586 Mdot
.64722 .53504 Mdot
.47393 .55369 Mdot
.65361 .59263 Mdot
.57502 .30263 Mdot
.57751 .34102 Mdot
.25111 .45027 Mdot
.68002 .58902 Mdot
.40059 .3283 Mdot
.23706 .48498 Mdot
.57726 .56221 Mdot
.28686 .49157 Mdot
.47735 .58072 Mdot
.21621 .49698 Mdot
.64614 .3814 Mdot
.43716 .58338 Mdot
.63734 .3628 Mdot
.48562 .54376 Mdot
.30947 .70527 Mdot
.3645 .59729 Mdot
.29472 .43133 Mdot
.45818 .21005 Mdot
.30828 .44342 Mdot
.63931 .59055 Mdot
.61073 .56751 Mdot
.27457 .47676 Mdot
.3819 .59543 Mdot
.48039 .58709 Mdot
.40267 .60346 Mdot
.6224 .36551 Mdot
.59162 .68134 Mdot
.42246 .83951 Mdot
.23447 .48772 Mdot
.43491 .32383 Mdot
.64645 .28377 Mdot
.45096 .54803 Mdot
.38169 .34304 Mdot
.38727 .32664 Mdot
.33868 .62353 Mdot
.28185 .43688 Mdot
.61055 .30789 Mdot
.43621 .31032 Mdot
.62389 .39372 Mdot
.39815 .74298 Mdot
.44598 .578 Mdot
.56629 .50916 Mdot
.43682 .56375 Mdot
.47275 .71821 Mdot
.44018 .31614 Mdot
.60773 .57785 Mdot
.53749 .53564 Mdot
.4102 .34672 Mdot
.33526 .61701 Mdot
.55045 .60198 Mdot
.29448 .4455 Mdot
.73952 .26132 Mdot
.60252 .56448 Mdot
.64127 .57888 Mdot
.40207 .35059 Mdot
.81552 .48366 Mdot
.58996 .32185 Mdot
.60936 .32967 Mdot
.26811 .465 Mdot
.43416 .71244 Mdot
.64864 .56276 Mdot
.60297 .56912 Mdot
.27521 .47925 Mdot
.48342 .55862 Mdot
.17286 .60252 Mdot
.62503 .5857 Mdot
.41009 .32439 Mdot
.54927 .61627 Mdot
.39494 .36486 Mdot
.56099 .59676 Mdot
.63563 .59361 Mdot
.66059 .53622 Mdot
.5869 .55435 Mdot
.42074 .31326 Mdot
.44185 .55962 Mdot
.47189 .53719 Mdot
.59728 .37662 Mdot
.59041 .60473 Mdot
.53508 .73203 Mdot
.62345 .58292 Mdot
.35555 .5969 Mdot
.45599 .70105 Mdot
.57571 .57212 Mdot
.58472 .59993 Mdot
.53187 .73788 Mdot
.61202 .60743 Mdot
.40394 .35135 Mdot
.62422 .34904 Mdot
.39889 .32847 Mdot
.4341 .33089 Mdot
.30108 .46722 Mdot
.34051 .60401 Mdot
.65452 .60562 Mdot
.37776 .62338 Mdot
.66555 .57738 Mdot
.50688 .53389 Mdot
.49635 .72942 Mdot
.45274 .72383 Mdot
.35632 .63864 Mdot
.60119 .57163 Mdot
.26624 .47015 Mdot
.2657 .43787 Mdot
.57304 .66128 Mdot
.66604 .60418 Mdot
.38372 .30886 Mdot
.42491 .33251 Mdot
.348 .42239 Mdot
.19427 .47827 Mdot
.37732 .62885 Mdot
.47402 .58642 Mdot
.57692 .56049 Mdot
.64798 .58357 Mdot
.45594 .54816 Mdot
.29289 .46565 Mdot
.48532 .54237 Mdot
.34507 .45081 Mdot
.38508 .3529 Mdot
.39567 .33767 Mdot
.60879 .56351 Mdot
.8099 .66146 Mdot
.61038 .38275 Mdot
.62665 .35267 Mdot
.40184 .30356 Mdot
.31124 .43327 Mdot
.45666 .5639 Mdot
.77205 .29614 Mdot
.57739 .34824 Mdot
.39689 .59607 Mdot
.60158 .60644 Mdot
.31383 .46389 Mdot
.59532 .3805 Mdot
.38871 .62128 Mdot
.58964 .60973 Mdot
.32582 .46131 Mdot
.611 .58018 Mdot
.61728 .47039 Mdot
.5874 .36586 Mdot
.50006 .71701 Mdot
.63888 .33395 Mdot
.41806 .31381 Mdot
.43788 .322 Mdot
.63597 .59028 Mdot
.76675 .28888 Mdot
.65355 .32171 Mdot
.43489 .30156 Mdot
.38304 .58485 Mdot
.46615 .54739 Mdot
.33861 .60777 Mdot
.27826 .47168 Mdot
.36292 .59695 Mdot
.30019 .46554 Mdot
.31179 .48596 Mdot
.61666 .31288 Mdot
.3771 .60676 Mdot
.79102 .49471 Mdot
.45307 .57271 Mdot
.3802 .58159 Mdot
.57989 .57993 Mdot
.66993 .56761 Mdot
.28636 .45084 Mdot
.38352 .61906 Mdot
.66869 .59481 Mdot
.48796 .23277 Mdot
.43542 .33324 Mdot
.38003 .34335 Mdot
.45945 .56181 Mdot
.23867 .47847 Mdot
.61615 .31351 Mdot
.47739 .75378 Mdot
.63212 .31057 Mdot
.60126 .56929 Mdot
.65406 .60535 Mdot
.64707 .35692 Mdot
.61789 .31583 Mdot
.63266 .59432 Mdot
.7631 .561 Mdot
.44637 .56357 Mdot
.40269 .3081 Mdot
.62204 .36831 Mdot
.62843 .36548 Mdot
.25239 .49053 Mdot
.61463 .32704 Mdot
.55038 .52315 Mdot
.38416 .35049 Mdot
.4759 .5362 Mdot
.40323 .32568 Mdot
.3828 .64415 Mdot
.29664 .45139 Mdot
.4384 .21397 Mdot
.60828 .32878 Mdot
.66913 .55194 Mdot
.60589 .32755 Mdot
.36253 .59128 Mdot
.62266 .38365 Mdot
.59079 .30037 Mdot
.59225 .57362 Mdot
.44466 .55716 Mdot
.48894 .56113 Mdot
.47399 .72434 Mdot
.60788 .37997 Mdot
.65331 .60342 Mdot
.6481 .55506 Mdot
.63427 .5614 Mdot
.49049 .73338 Mdot
.62961 .32613 Mdot
.81578 .46057 Mdot
.61954 .41704 Mdot
.58835 .37065 Mdot
.53591 .84601 Mdot
.49037 .56288 Mdot
.47299 .5409 Mdot
.47165 .34805 Mdot
.62774 .5861 Mdot
.28022 .44123 Mdot
.64804 .5357 Mdot
.45028 .55465 Mdot
.57702 .58683 Mdot
.36658 .62278 Mdot
.63717 .61257 Mdot
.48157 .55088 Mdot
.25425 .45365 Mdot
.66635 .54534 Mdot
.63195 .57926 Mdot
.48347 .56128 Mdot
.60251 .32681 Mdot
.63653 .35015 Mdot
.64521 .32217 Mdot
.34945 .62996 Mdot
.41565 .33252 Mdot
.64297 .53657 Mdot
.26744 .46714 Mdot
.28432 .44026 Mdot
.64055 .34286 Mdot
.25872 .48201 Mdot
.3954 .34005 Mdot
.61176 .59669 Mdot
.41927 .31299 Mdot
.36236 .62493 Mdot
.61763 .36891 Mdot
.61268 .54466 Mdot
.68109 .54606 Mdot
.59677 .34301 Mdot
.44413 .56775 Mdot
.36973 .58705 Mdot
.27509 .48288 Mdot
.59393 .38689 Mdot
.41683 .30678 Mdot
.25881 .49049 Mdot
.66917 .54863 Mdot
.64925 .80868 Mdot
.63508 .60202 Mdot
.64209 .56104 Mdot
.65684 .36276 Mdot
.55846 .59111 Mdot
.31167 .44642 Mdot
.61994 .32418 Mdot
.66966 .56293 Mdot
.52125 .75868 Mdot
.33892 .64129 Mdot
.22252 .4792 Mdot
.60536 .60186 Mdot
.7604 .60684 Mdot
.65522 .5491 Mdot
.47264 .20798 Mdot
.4962 .72837 Mdot
.34858 .31074 Mdot
.55768 .51063 Mdot
.43109 .29895 Mdot
.47791 .55668 Mdot
.30536 .46275 Mdot
.77028 .5273 Mdot
.6294 .59932 Mdot
.73498 .39821 Mdot
.61892 .54342 Mdot
.39924 .33536 Mdot
.80749 .48931 Mdot
.24164 .46975 Mdot
.22093 .65803 Mdot
.60074 .61262 Mdot
.58512 .32809 Mdot
.34564 .50085 Mdot
.46612 .54444 Mdot
.45182 .54869 Mdot
.36913 .6317 Mdot
.32511 .41726 Mdot
.52189 .53642 Mdot
.40063 .32634 Mdot
.65062 .57881 Mdot
.69152 .54987 Mdot
.39273 .21144 Mdot
.59403 .36845 Mdot
.42559 .34013 Mdot
.22338 .50479 Mdot
.60395 .57695 Mdot
.63678 .35926 Mdot
.60953 .34485 Mdot
.37711 .62064 Mdot
.35264 .30619 Mdot
.32328 .41269 Mdot
.79928 .65001 Mdot
.51995 .51869 Mdot
.29129 .46851 Mdot
.4361 .58117 Mdot
.65285 .53515 Mdot
.39767 .6651 Mdot
.43589 .32157 Mdot
.64294 .58392 Mdot
.74038 .37706 Mdot
.59714 .35872 Mdot
.61501 .58517 Mdot
.35818 .60205 Mdot
.77552 .31972 Mdot
.67636 .50726 Mdot
.75428 .57789 Mdot
.30995 .48363 Mdot
.65651 .60362 Mdot
.54864 .52397 Mdot
.48023 .57111 Mdot
.55768 .59361 Mdot
.24938 .46017 Mdot
.43393 .58229 Mdot
.36087 .60502 Mdot
.59867 .3836 Mdot
.47522 .55745 Mdot
.61687 .54409 Mdot
.65772 .60533 Mdot
.37989 .58519 Mdot
.66016 .53764 Mdot
.69796 .48114 Mdot
.47157 .57852 Mdot
.27439 .48823 Mdot
.59758 .39295 Mdot
.65767 .59999 Mdot
.46398 .54769 Mdot
.59317 .58907 Mdot
.68297 .31022 Mdot
.64493 .58342 Mdot
.45356 .23089 Mdot
.60437 .33507 Mdot
.4027 .31358 Mdot
.57735 .56161 Mdot
.61561 .57897 Mdot
.44457 .58411 Mdot
.45709 .5662 Mdot
.59536 .60608 Mdot
.63991 .35502 Mdot
.60403 .38542 Mdot
.58473 .32997 Mdot
.26539 .49311 Mdot
.4673 .73401 Mdot
.41252 .31376 Mdot
.457 .54736 Mdot
.43609 .31004 Mdot
.73429 .63336 Mdot
.34628 .62577 Mdot
.41652 .22116 Mdot
.6175 .59785 Mdot
.61859 .3367 Mdot
.51452 .80673 Mdot
.63883 .3378 Mdot
.43564 .37917 Mdot
.43586 .31771 Mdot
.61019 .37338 Mdot
.61138 .60509 Mdot
.46731 .71415 Mdot
.76706 .60132 Mdot
.43294 .34055 Mdot
.4872 .53753 Mdot
.35662 .65854 Mdot
.30241 .48497 Mdot
.52264 .84514 Mdot
.42384 .30245 Mdot
.57366 .2571 Mdot
.66954 .55816 Mdot
.59799 .33298 Mdot
.42335 .32084 Mdot
.38585 .32556 Mdot
.24008 .47071 Mdot
.6587 .54047 Mdot
.6154 .58068 Mdot
.49758 .54532 Mdot
.42928 .31694 Mdot
.67219 .59736 Mdot
.67213 .54404 Mdot
.32235 .39704 Mdot
.58274 .32873 Mdot
.3756 .20385 Mdot
.66393 .67962 Mdot
.74064 .37838 Mdot
.33321 .25339 Mdot
.58669 .37827 Mdot
.63671 .60913 Mdot
.45365 .55968 Mdot
.26928 .48446 Mdot
.61664 .60259 Mdot
.30929 .44166 Mdot
.40594 .33653 Mdot
.47034 .23485 Mdot
.65033 .68355 Mdot
.39067 .38904 Mdot
.64036 .59708 Mdot
.66869 .5046 Mdot
.36869 .60599 Mdot
.37877 .3429 Mdot
.60067 .3179 Mdot
.65397 .59715 Mdot
.24542 .47885 Mdot
.29755 .48643 Mdot
.59777 .3633 Mdot
.55186 .28512 Mdot
.44623 .21132 Mdot
.44682 .5682 Mdot
.2528 .47695 Mdot
.45844 .55084 Mdot
.74804 .58589 Mdot
.4356 .30568 Mdot
.36097 .60605 Mdot
.30375 .47329 Mdot
.38825 .31052 Mdot
.67037 .56786 Mdot
.60299 .36861 Mdot
.64371 .33077 Mdot
.56653 .65627 Mdot
.29032 .44411 Mdot
.34795 .62138 Mdot
.56778 .64732 Mdot
.58571 .67721 Mdot
.35102 .61521 Mdot
.25603 .4938 Mdot
.62349 .37648 Mdot
.60534 .341 Mdot
.62211 .34695 Mdot
.79355 .53521 Mdot
.57694 .34453 Mdot
.37501 .70388 Mdot
.55695 .59248 Mdot
.69476 .50352 Mdot
.6625 .56589 Mdot
.37964 .34136 Mdot
.58671 .35489 Mdot
.49718 .72746 Mdot
.58725 .55326 Mdot
.76895 .60142 Mdot
.63656 .56549 Mdot
.54846 .61878 Mdot
.62868 .58547 Mdot
.64004 .45974 Mdot
.57466 .3449 Mdot
.59722 .61302 Mdot
.39777 .36066 Mdot
.34261 .60857 Mdot
.61715 .4053 Mdot
.62416 .61173 Mdot
.54613 .3549 Mdot
.57974 .57791 Mdot
.46654 .23315 Mdot
.56068 .64585 Mdot
.35362 .51538 Mdot
.65552 .57479 Mdot
.3109 .42983 Mdot
.68119 .53198 Mdot
.71189 .51709 Mdot
.43809 .33038 Mdot
.6726 .50286 Mdot
.28292 .43082 Mdot
.80771 .48719 Mdot
.44873 .56953 Mdot
.36508 .60066 Mdot
.42715 .58073 Mdot
.40903 .30497 Mdot
.62289 .59903 Mdot
.62682 .61354 Mdot
.5605 .61351 Mdot
.74581 .58861 Mdot
.47704 .5689 Mdot
.36082 .63805 Mdot
.70688 .52092 Mdot
.60002 .60826 Mdot
.21848 .47119 Mdot
.63192 .3379 Mdot
.79771 .48737 Mdot
.79684 .47181 Mdot
.67406 .5473 Mdot
.60649 .37502 Mdot
.62534 .3322 Mdot
.44624 .82274 Mdot
.37595 .60073 Mdot
.64378 .57606 Mdot
.38947 .56943 Mdot
.63777 .53782 Mdot
.40898 .3314 Mdot
.56745 .57791 Mdot
.29629 .45015 Mdot
.45672 .71243 Mdot
.26287 .49419 Mdot
.63235 .56132 Mdot
.61091 .35967 Mdot
.42076 .3528 Mdot
.30873 .48861 Mdot
.35249 .30774 Mdot
.37411 .70601 Mdot
.32733 .42009 Mdot
.38018 .62669 Mdot
.33759 .61895 Mdot
.37887 .34267 Mdot
.60669 .59909 Mdot
.48629 .73329 Mdot
.70563 .66321 Mdot
.62424 .5899 Mdot
.63728 .6058 Mdot
.4668 .32124 Mdot
.43331 .31256 Mdot
.31331 .46104 Mdot
.63118 .59551 Mdot
.64477 .61108 Mdot
.61155 .36517 Mdot
.38871 .61648 Mdot
.2895 .4784 Mdot
.35493 .63254 Mdot
.25624 .4662 Mdot
.55298 .80473 Mdot
.44608 .57716 Mdot
.34266 .6212 Mdot
.42301 .30021 Mdot
.62576 .34424 Mdot
.49314 .56104 Mdot
.28074 .46448 Mdot
.25384 .4801 Mdot
.6683 .58033 Mdot
.59587 .38017 Mdot
.60859 .32956 Mdot
.36018 .63147 Mdot
.42394 .33232 Mdot
.62836 .53667 Mdot
.43804 .56162 Mdot
.23717 .49825 Mdot
.25107 .48354 Mdot
.70324 .51496 Mdot
.65059 .37747 Mdot
.59519 .58679 Mdot
.63626 .35347 Mdot
.62299 .57388 Mdot
.591 .29623 Mdot
.63239 .31809 Mdot
.56254 .59205 Mdot
.71313 .59704 Mdot
.29494 .465 Mdot
.37846 .81405 Mdot
.55888 .57644 Mdot
.4139 .36754 Mdot
.65086 .53614 Mdot
.19001 .63002 Mdot
.50732 .80521 Mdot
.59 .59399 Mdot
.64174 .60925 Mdot
.77991 .69193 Mdot
.65017 .54878 Mdot
.48626 .54572 Mdot
.44924 .57049 Mdot
.63589 .35781 Mdot
.42503 .58191 Mdot
.47483 .72146 Mdot
.38232 .60362 Mdot
.26903 .46553 Mdot
.40884 .75696 Mdot
.35135 .62838 Mdot
.59826 .35135 Mdot
.63453 .5351 Mdot
.65596 .35126 Mdot
.24559 .44114 Mdot
.47279 .56154 Mdot
.40289 .33578 Mdot
.48266 .72796 Mdot
.24235 .47571 Mdot
.42222 .30683 Mdot
.6485 .55156 Mdot
.341 .46098 Mdot
.39569 .36287 Mdot
.39036 .81871 Mdot
.38648 .34065 Mdot
.41782 .30483 Mdot
.47485 .73302 Mdot
.38251 .6037 Mdot
.46684 .58107 Mdot
.48497 .53257 Mdot
.41653 .35345 Mdot
.25438 .68248 Mdot
.23856 .47449 Mdot
.4544 .74149 Mdot
.57613 .33688 Mdot
.45308 .57541 Mdot
.64168 .60053 Mdot
.39293 .34682 Mdot
.6787 .59292 Mdot
.44119 .58409 Mdot
.3919 .32903 Mdot
.6814 .53381 Mdot
.43719 .7103 Mdot
.46302 .55028 Mdot
.49258 .55828 Mdot
.3949 .61192 Mdot
.29606 .52891 Mdot
.62013 .33294 Mdot
.39476 .59396 Mdot
.50824 .74854 Mdot
.64122 .56513 Mdot
.42125 .31457 Mdot
.4746 .55805 Mdot
.40953 .31033 Mdot
.36534 .61213 Mdot
.37594 .5843 Mdot
.59645 .37537 Mdot
.58707 .32692 Mdot
.50183 .55823 Mdot
.53904 .73379 Mdot
.60327 .55232 Mdot
.73494 .41543 Mdot
.62249 .31627 Mdot
.80965 .51846 Mdot
.38694 .60517 Mdot
.38846 .61522 Mdot
.678 .51958 Mdot
.59559 .56087 Mdot
.54831 .61633 Mdot
.57522 .57358 Mdot
.24483 .66233 Mdot
.60921 .5461 Mdot
.26953 .48213 Mdot
.57299 .58416 Mdot
.61118 .26273 Mdot
.67691 .57122 Mdot
.60995 .61009 Mdot
.26678 .4551 Mdot
.66314 .58727 Mdot
.29035 .44994 Mdot
.64705 .59741 Mdot
.23088 .42174 Mdot
.26724 .46673 Mdot
.42897 .60788 Mdot
.58608 .63884 Mdot
.49043 .54976 Mdot
.37624 .61695 Mdot
.37196 .6321 Mdot
.40048 .7392 Mdot
.61806 .37942 Mdot
.7698 .37087 Mdot
.60477 .60738 Mdot
.24 .47801 Mdot
.40804 .33811 Mdot
.67954 .55338 Mdot
.63307 .55772 Mdot
.55917 .57699 Mdot
.60308 .37816 Mdot
.24114 .48637 Mdot
.37193 .6137 Mdot
.28947 .4361 Mdot
.22107 .42714 Mdot
.29646 .45431 Mdot
.70553 .63515 Mdot
.66984 .57139 Mdot
.54904 .52438 Mdot
.75749 .4578 Mdot
.34868 .58401 Mdot
.59987 .36715 Mdot
.47713 .55472 Mdot
.33714 .61498 Mdot
.46124 .68995 Mdot
.62752 .3388 Mdot
.27402 .47908 Mdot
.61083 .57976 Mdot
.43832 .57773 Mdot
.48883 .53281 Mdot
.61429 .40081 Mdot
.36082 .58675 Mdot
.27529 .46144 Mdot
.47143 .54925 Mdot
.46339 .73406 Mdot
.80438 .42989 Mdot
.4893 .76497 Mdot
.61818 .5765 Mdot
.36189 .63059 Mdot
.59609 .38108 Mdot
.54762 .60965 Mdot
.40666 .34689 Mdot
.47768 .72801 Mdot
.63886 .60028 Mdot
.43132 .38652 Mdot
.61006 .35855 Mdot
.37922 .59422 Mdot
.39055 .34565 Mdot
.37481 .5988 Mdot
.47596 .54119 Mdot
.62564 .41305 Mdot
.45247 .54834 Mdot
.58962 .55485 Mdot
.40969 .33588 Mdot
.61669 .33131 Mdot
.24088 .41683 Mdot
.51138 .56151 Mdot
.27478 .47598 Mdot
.46682 .69174 Mdot
.6015 .38451 Mdot
.35485 .40044 Mdot
.29166 .43617 Mdot
.44929 .29195 Mdot
.49379 .69998 Mdot
.39189 .33768 Mdot
.61548 .61136 Mdot
.62 .35174 Mdot
.43293 .34081 Mdot
.33037 .49809 Mdot
.78078 .58278 Mdot
.49613 .56897 Mdot
.60626 .56978 Mdot
.48247 .2037 Mdot
.58277 .2599 Mdot
.56819 .35213 Mdot
.4142 .30106 Mdot
.63812 .58136 Mdot
.44571 .56928 Mdot
.59662 .6109 Mdot
.42313 .34822 Mdot
.42019 .27864 Mdot
.2533 .44321 Mdot
.60703 .57934 Mdot
.36478 .59417 Mdot
.30316 .45158 Mdot
.31369 .47607 Mdot
.30229 .47577 Mdot
.59878 .31901 Mdot
.45835 .57677 Mdot
.44786 .57162 Mdot
.49152 .80008 Mdot
.4064 .30921 Mdot
.49001 .54981 Mdot
.63524 .61264 Mdot
.37711 .70575 Mdot
.61708 .33923 Mdot
.27782 .45756 Mdot
.64118 .5776 Mdot
.56378 .65364 Mdot
.47857 .5635 Mdot
.25904 .45436 Mdot
.61809 .31514 Mdot
.59161 .44806 Mdot
.61636 .60131 Mdot
.64149 .53916 Mdot
.59513 .34918 Mdot
.64302 .24482 Mdot
.45783 .73344 Mdot
.62407 .57504 Mdot
.41224 .30733 Mdot
.59183 .21171 Mdot
.65202 .55292 Mdot
.6314 .30403 Mdot
.49619 .54202 Mdot
.57374 .42367 Mdot
.69836 .48925 Mdot
.69449 .57255 Mdot
.49143 .44004 Mdot
.5046 .61311 Mdot
.51946 .46047 Mdot
.27458 .67168 Mdot
.42345 .45086 Mdot
.41367 .83186 Mdot
.37433 .33445 Mdot
.62691 .47133 Mdot
.8618 .56903 Mdot
.55716 .2712 Mdot
.38574 .47305 Mdot
.41442 .27219 Mdot
.32048 .63425 Mdot
.16585 .58624 Mdot
.34493 .44853 Mdot
.27729 .66924 Mdot
.58842 .55636 Mdot
.62613 .24675 Mdot
.63249 .4768 Mdot
.35818 .44853 Mdot
.34403 .33001 Mdot
.56383 .64783 Mdot
.73659 .71544 Mdot
.39409 .384 Mdot
.6132 .81052 Mdot
.75103 .3728 Mdot
.27595 .50808 Mdot
.53651 .6924 Mdot
.3871 .75032 Mdot
.64985 .49477 Mdot
.54586 .43782 Mdot
.37284 .34657 Mdot
.67411 .38383 Mdot
.3446 .24281 Mdot
.26266 .47709 Mdot
.61677 .39726 Mdot
.48887 .32287 Mdot
.68794 .76195 Mdot
.43916 .36527 Mdot
.48962 .44089 Mdot
.51148 .55975 Mdot
.63572 .4628 Mdot
.50094 .72469 Mdot
.63231 .45384 Mdot
.34168 .41534 Mdot
.16866 .5874 Mdot
.65899 .36915 Mdot
.32697 .50961 Mdot
.44257 .68535 Mdot
.37753 .4751 Mdot
.66141 .46015 Mdot
.3281 .61209 Mdot
.42548 .60949 Mdot
.62114 .31475 Mdot
.73242 .69537 Mdot
.64765 .66556 Mdot
.51389 .74597 Mdot
.347 .45223 Mdot
.66955 .31785 Mdot
.7661 .31956 Mdot
.56333 .28072 Mdot
.33351 .78827 Mdot
.65019 .80419 Mdot
.30051 .71752 Mdot
.58522 .629 Mdot
.44575 .36434 Mdot
.4028 .67308 Mdot
.47997 .47292 Mdot
.31915 .74521 Mdot
.68147 .30703 Mdot
.76743 .67542 Mdot
.5307 .35614 Mdot
.6958 .77102 Mdot
.65017 .40117 Mdot
.53218 .53623 Mdot
.57707 .39852 Mdot
.60787 .4602 Mdot
.47511 .77995 Mdot
.71281 .7469 Mdot
.36119 .46731 Mdot
.52096 .5512 Mdot
.54605 .27863 Mdot
.69536 .48086 Mdot
.34137 .40931 Mdot
.41849 .6008 Mdot
.77487 .45809 Mdot
.73714 .72653 Mdot
.5044 .43416 Mdot
.68957 .73496 Mdot
.3149 .39679 Mdot
.20692 .37511 Mdot
.31968 .46766 Mdot
.42217 .29283 Mdot
.63237 .80461 Mdot
.61604 .34834 Mdot
.36649 .8147 Mdot
.42442 .46137 Mdot
.40919 .49094 Mdot
.74091 .72115 Mdot
.30978 .75815 Mdot
.67361 .49158 Mdot
.46352 .59073 Mdot
.379 .23957 Mdot
.54634 .47182 Mdot
.36966 .39428 Mdot
.39228 .6436 Mdot
.47049 .22142 Mdot
.65188 .79129 Mdot
.29422 .73035 Mdot
.80696 .63834 Mdot
.51941 .7364 Mdot
.31824 .66674 Mdot
.66005 .35643 Mdot
.44772 .41183 Mdot
.36673 .40629 Mdot
.68404 .78241 Mdot
.67995 .50959 Mdot
.55208 .19452 Mdot
.28439 .68346 Mdot
.80268 .47259 Mdot
.51806 .22 Mdot
.49172 .3383 Mdot
.59552 .46377 Mdot
.54491 .3474 Mdot
.43068 .55699 Mdot
.45933 .77529 Mdot
.76893 .43562 Mdot
.3524 .51086 Mdot
.46088 .72306 Mdot
.51647 .31859 Mdot
.34948 .7507 Mdot
.56529 .21412 Mdot
.77589 .44935 Mdot
.64631 .35711 Mdot
.31996 .7444 Mdot
.28605 .69475 Mdot
.53411 .20048 Mdot
.22992 .50842 Mdot
.68413 .74166 Mdot
.41299 .39882 Mdot
.70029 .57143 Mdot
.62437 .47394 Mdot
.64893 .49107 Mdot
.18976 .61314 Mdot
.70862 .62103 Mdot
.43947 .8136 Mdot
.36513 .37034 Mdot
.75574 .47702 Mdot
.41783 .78599 Mdot
.75958 .46892 Mdot
.70969 .50641 Mdot
.58796 .28576 Mdot
.37469 .37039 Mdot
.69518 .61286 Mdot
.74112 .71552 Mdot
.31085 .45794 Mdot
.31742 .74647 Mdot
.42281 .37591 Mdot
.31929 .49287 Mdot
.39364 .49277 Mdot
.38268 .49468 Mdot
.5749 .83136 Mdot
.53547 .28293 Mdot
.32643 .64446 Mdot
.60621 .43155 Mdot
.4501 .46421 Mdot
.74079 .42091 Mdot
.68084 .66844 Mdot
.67229 .31144 Mdot
.37016 .58684 Mdot
.7669 .50778 Mdot
.55512 .37363 Mdot
.22927 .51143 Mdot
.70753 .63959 Mdot
.54512 .69171 Mdot
.5033 .54803 Mdot
.41072 .72529 Mdot
.54687 .80693 Mdot
.69779 .58592 Mdot
.31951 .7629 Mdot
.54909 .28223 Mdot
.4109 .73128 Mdot
.36561 .40778 Mdot
.77531 .37574 Mdot
.69921 .76855 Mdot
.50993 .83936 Mdot
.64678 .25277 Mdot
.50735 .21423 Mdot
.16281 .44605 Mdot
.34858 .33163 Mdot
.39596 .80916 Mdot
.42325 .37578 Mdot
.66409 .17765 Mdot
.3137 .44646 Mdot
.38693 .67204 Mdot
.6527 .40713 Mdot
.53945 .68046 Mdot
.71154 .73722 Mdot
.66922 .48075 Mdot
.38373 .58157 Mdot
.574 .38688 Mdot
.71018 .6009 Mdot
.73159 .7124 Mdot
.74955 .69105 Mdot
.73665 .69921 Mdot
.48202 .33954 Mdot
.75434 .56611 Mdot
.76392 .70417 Mdot
.38183 .69327 Mdot
.65407 .63778 Mdot
.69234 .55939 Mdot
.53167 .75395 Mdot
.37649 .79635 Mdot
.33299 .59115 Mdot
.55062 .47179 Mdot
.6582 .37065 Mdot
.75143 .72098 Mdot
.53336 .81195 Mdot
.62358 .4581 Mdot
.5825 .82358 Mdot
.30903 .6404 Mdot
.43689 .79722 Mdot
.54613 .83365 Mdot
.52497 .43353 Mdot
.46961 .36273 Mdot
.76364 .7174 Mdot
.30365 .70353 Mdot
.4185 .27266 Mdot
.54838 .3595 Mdot
.37412 .80151 Mdot
.50765 .22229 Mdot
.45008 .27903 Mdot
.65537 .39884 Mdot
.79574 .38848 Mdot
.38602 .44757 Mdot
.55043 .44082 Mdot
.5689 .62358 Mdot
.4132 .78912 Mdot
.3158 .44182 Mdot
.3401 .76012 Mdot
.37851 .42373 Mdot
.66361 .6296 Mdot
.42029 .75304 Mdot
.27716 .7055 Mdot
.53152 .39004 Mdot
.75563 .58595 Mdot
.54282 .28594 Mdot
.58233 .215 Mdot
.53175 .21382 Mdot
.76995 .4051 Mdot
.66101 .5925 Mdot
.69466 .75726 Mdot
.44641 .84861 Mdot
.55347 .83586 Mdot
.54782 .2043 Mdot
.1996 .4033 Mdot
.38326 .31187 Mdot
.38648 .70029 Mdot
.54209 .67099 Mdot
.50572 .40748 Mdot
.51557 .60971 Mdot
.44407 .31253 Mdot
.76647 .31773 Mdot
.39934 .48799 Mdot
.38395 .69405 Mdot
.68245 .37266 Mdot
.43674 .47555 Mdot
.7489 .58963 Mdot
.64603 .35231 Mdot
.51304 .19103 Mdot
.32247 .74719 Mdot
.309 .46252 Mdot
.22475 .49387 Mdot
.69004 .63039 Mdot
.53738 .53847 Mdot
.34704 .66113 Mdot
.68014 .60544 Mdot
.74182 .38102 Mdot
.19715 .41346 Mdot
.48498 .82427 Mdot
.37585 .81083 Mdot
.54183 .83424 Mdot
.29477 .71304 Mdot
.32333 .49861 Mdot
.42037 .73088 Mdot
.45296 .33454 Mdot
.40366 .3775 Mdot
.42704 .71206 Mdot
.28101 .70157 Mdot
.67889 .49345 Mdot
.57155 .38571 Mdot
.67748 .58443 Mdot
.52062 .8067 Mdot
.37616 .73543 Mdot
.4138 .7091 Mdot
.78824 .41273 Mdot
.60144 .30474 Mdot
.33437 .67666 Mdot
.56464 .43701 Mdot
.66111 .52759 Mdot
.5106 .21007 Mdot
.43855 .33392 Mdot
.64393 .33944 Mdot
.27663 .70636 Mdot
.17607 .432 Mdot
.49276 .46343 Mdot
.64466 .67445 Mdot
.65796 .78236 Mdot
.59391 .65071 Mdot
.49159 .22202 Mdot
.81081 .39928 Mdot
.35039 .37677 Mdot
.65849 .37859 Mdot
.6478 .63251 Mdot
.38945 .50082 Mdot
.65098 .26422 Mdot
.63393 .38748 Mdot
.66769 .50708 Mdot
.6291 .81188 Mdot
.56543 .6404 Mdot
.53822 .44477 Mdot
.47508 .75336 Mdot
.41998 .42268 Mdot
.43593 .46141 Mdot
.41714 .75608 Mdot
.50691 .45284 Mdot
.7163 .70402 Mdot
.76352 .30341 Mdot
.56169 .47303 Mdot
.35532 .6829 Mdot
.38847 .69402 Mdot
.75092 .37171 Mdot
.65852 .45746 Mdot
.36318 .37424 Mdot
.57939 .56226 Mdot
.61602 .8241 Mdot
.52481 .33731 Mdot
.41616 .74339 Mdot
.45495 .3839 Mdot
.65475 .54515 Mdot
.52852 .5332 Mdot
.55605 .83304 Mdot
.56891 .42122 Mdot
.88268 .53912 Mdot
.2654 .67268 Mdot
.64981 .28012 Mdot
.69558 .49104 Mdot
.33065 .76827 Mdot
.62722 .27145 Mdot
.43996 .45018 Mdot
.38421 .41893 Mdot
.36015 .78845 Mdot
.55818 .40614 Mdot
.5673 .425 Mdot
.50136 .19956 Mdot
.7661 .69551 Mdot
.54268 .46296 Mdot
.45927 .29761 Mdot
.3131 .64514 Mdot
.64481 .56174 Mdot
.55481 .28243 Mdot
.42462 .21562 Mdot
.46626 .38388 Mdot
.52547 .46764 Mdot
.44199 .85024 Mdot
.70371 .55668 Mdot
.53404 .29218 Mdot
.8797 .54489 Mdot
.89629 .52082 Mdot
.5896 .27398 Mdot
.6731 .79215 Mdot
.57605 .4297 Mdot
.49175 .22466 Mdot
.37953 .3668 Mdot
.59524 .67993 Mdot
.7345 .40536 Mdot
.57798 .83898 Mdot
.17632 .41824 Mdot
.3672 .39495 Mdot
.66956 .37784 Mdot
.57322 .84193 Mdot
.70641 .56506 Mdot
.36027 .67868 Mdot
.20874 .37444 Mdot
.22672 .66422 Mdot
.3325 .78435 Mdot
.7929 .40735 Mdot
.18958 .61787 Mdot
.24948 .64551 Mdot
.36602 .45875 Mdot
.38094 .8098 Mdot
.5078 .52259 Mdot
.78566 .37721 Mdot
.31831 .74209 Mdot
.48941 .21106 Mdot
.16851 .50696 Mdot
.44385 .4589 Mdot
.66899 .616 Mdot
.57999 .28808 Mdot
.46727 .22395 Mdot
.50314 .32157 Mdot
.6246 .64876 Mdot
.46862 .69636 Mdot
.70913 .50965 Mdot
.58875 .20781 Mdot
.82271 .41002 Mdot
.66044 .61874 Mdot
.75759 .67106 Mdot
.38139 .38258 Mdot
.42627 .6929 Mdot
.67517 .47029 Mdot
.38534 .72799 Mdot
.32696 .65017 Mdot
.57559 .58091 Mdot
.63637 .80739 Mdot
.32845 .65088 Mdot
.74918 .68227 Mdot
.36641 .81781 Mdot
.59705 .81506 Mdot
.41408 .49474 Mdot
.36386 .65605 Mdot
.37299 .79009 Mdot
.37883 .792 Mdot
.77596 .65827 Mdot
.2808 .66657 Mdot
.43127 .70744 Mdot
.61102 .64019 Mdot
.64943 .68103 Mdot
.73076 .60869 Mdot
.3343 .77143 Mdot
.75443 .35748 Mdot
.41836 .78296 Mdot
.64732 .25546 Mdot
.28002 .70454 Mdot
.66904 .48836 Mdot
.39067 .73074 Mdot
.43867 .4001 Mdot
.44152 .59678 Mdot
.23675 .47259 Mdot
.80182 .6636 Mdot
.5262 .20288 Mdot
.46216 .81104 Mdot
.54417 .19415 Mdot
.54352 .35175 Mdot
.2583 .6599 Mdot
.5835 .40581 Mdot
.53296 .49014 Mdot
.28821 .51076 Mdot
.36915 .75768 Mdot
.68726 .50762 Mdot
.47295 .20711 Mdot
.80017 .45277 Mdot
.58381 .83113 Mdot
.42084 .78913 Mdot
.82332 .61938 Mdot
.32227 .66261 Mdot
.76665 .50411 Mdot
.73081 .69342 Mdot
.61607 .22955 Mdot
.41235 .7022 Mdot
.74374 .70861 Mdot
.5722 .36257 Mdot
.656 .80056 Mdot
.40682 .34412 Mdot
.34115 .67206 Mdot
.44991 .21393 Mdot
.40011 .70258 Mdot
.4016 .69985 Mdot
.46845 .81987 Mdot
.54119 .28247 Mdot
.56948 .27284 Mdot
.41063 .39897 Mdot
.34324 .45113 Mdot
.62759 .68403 Mdot
.5254 .44391 Mdot
.80263 .64252 Mdot
.65969 .59385 Mdot
.296 .65359 Mdot
.31798 .75319 Mdot
.45433 .33197 Mdot
.609 .63112 Mdot
.46593 .21321 Mdot
.81088 .41626 Mdot
.47592 .79029 Mdot
.7603 .7019 Mdot
.60422 .63042 Mdot
.53445 .66041 Mdot
.81478 .49085 Mdot
.45186 .27495 Mdot
.36426 .38375 Mdot
.49837 .44217 Mdot
.60886 .65845 Mdot
.45963 .73628 Mdot
.29864 .71188 Mdot
.42813 .84222 Mdot
.76527 .66464 Mdot
.362 .38266 Mdot
.40603 .70808 Mdot
.63152 .30226 Mdot
.37942 .75728 Mdot
.81914 .62823 Mdot
.17646 .60904 Mdot
.54764 .35711 Mdot
.28698 .7138 Mdot
.48731 .34582 Mdot
.36208 .68016 Mdot
.41984 .71044 Mdot
.72862 .69827 Mdot
.64802 .41742 Mdot
.58572 .4266 Mdot
.49571 .34686 Mdot
.48024 .71945 Mdot
.40192 .4734 Mdot
.78675 .38872 Mdot
.53784 .27818 Mdot
.82428 .61779 Mdot
.23514 .64022 Mdot
.80362 .48386 Mdot
.85064 .5836 Mdot
.61416 .31311 Mdot
.39558 .47544 Mdot
.22578 .34868 Mdot
.40701 .72514 Mdot
.30689 .47783 Mdot
.67344 .59572 Mdot
.44888 .69943 Mdot
.63563 .26066 Mdot
.31602 .6333 Mdot
.34627 .59539 Mdot
.6444 .3508 Mdot
.25967 .65388 Mdot
.64447 .33811 Mdot
.42664 .83935 Mdot
.52297 .42875 Mdot
.70438 .50869 Mdot
.82799 .4367 Mdot
.31898 .50499 Mdot
.59389 .21889 Mdot
.60732 .81352 Mdot
.52657 .75169 Mdot
.62827 .39358 Mdot
.63092 .4028 Mdot
.624 .42313 Mdot
.44997 .30833 Mdot
.67254 .76972 Mdot
.31065 .75599 Mdot
.23409 .49791 Mdot
.58429 .39115 Mdot
.58452 .63352 Mdot
.68714 .59844 Mdot
.50072 .82207 Mdot
.29092 .43749 Mdot
.71605 .75576 Mdot
.76346 .36298 Mdot
.61372 .23821 Mdot
.51076 .39688 Mdot
.5535 .70139 Mdot
.41871 .68419 Mdot
.3333 .51085 Mdot
.69919 .56788 Mdot
.63018 .27968 Mdot
.5828 .33863 Mdot
.39681 .48277 Mdot
.38996 .59671 Mdot
.2355 .51369 Mdot
.43327 .35404 Mdot
.76191 .40168 Mdot
.3296 .77298 Mdot
.64767 .36436 Mdot
.34607 .66469 Mdot
.32116 .52068 Mdot
.71281 .62621 Mdot
.55041 .73747 Mdot
.79082 .68323 Mdot
.63373 .79594 Mdot
.64124 .34904 Mdot
.57728 .21732 Mdot
.25768 .41082 Mdot
.4834 .82301 Mdot
.55689 .39418 Mdot
.33073 .76314 Mdot
.773 .46949 Mdot
.53205 .82939 Mdot
.69695 .4887 Mdot
.49676 .42857 Mdot
.30406 .73429 Mdot
.38332 .56779 Mdot
.28438 .7164 Mdot
.81482 .43175 Mdot
.62152 .67173 Mdot
.2387 .67368 Mdot
.47264 .37484 Mdot
.62548 .46059 Mdot
.63373 .53279 Mdot
.50508 .4118 Mdot
.36013 .78482 Mdot
.61605 .32182 Mdot
.32069 .62258 Mdot
.68745 .35591 Mdot
.36731 .393 Mdot
.64753 .79349 Mdot
.54637 .20793 Mdot
.30564 .74694 Mdot
.65184 .67841 Mdot
.34469 .7238 Mdot
.75181 .35901 Mdot
.52243 .74117 Mdot
.43287 .56948 Mdot
.76963 .44796 Mdot
.45147 .58548 Mdot
.49972 .80432 Mdot
.72836 .61536 Mdot
.71129 .74301 Mdot
.53711 .80743 Mdot
.57658 .2886 Mdot
.50994 .56795 Mdot
.59904 .40213 Mdot
.72363 .7435 Mdot
.48385 .79201 Mdot
.46279 .22071 Mdot
.33195 .78276 Mdot
.28251 .66127 Mdot
.85744 .57452 Mdot
.5263 .29585 Mdot
.68467 .61703 Mdot
.38614 .81404 Mdot
.52887 .3462 Mdot
.25279 .64622 Mdot
.688 .50887 Mdot
.65815 .35132 Mdot
.74378 .71612 Mdot
.51319 .50999 Mdot
.56073 .28917 Mdot
.75285 .61614 Mdot
.66058 .37488 Mdot
.48886 .79027 Mdot
.61057 .62745 Mdot
.27529 .48052 Mdot
.54493 .68532 Mdot
.18297 .60444 Mdot
.63542 .42435 Mdot
.32554 .76388 Mdot
.33553 .76453 Mdot
.32246 .68261 Mdot
.32801 .52634 Mdot
.85806 .57253 Mdot
.75479 .55313 Mdot
.62219 .62503 Mdot
.64215 .3677 Mdot
.3367 .60757 Mdot
.29209 .68517 Mdot
.65074 .54296 Mdot
.54469 .71159 Mdot
.77429 .46188 Mdot
.59799 .83189 Mdot
.44017 .40934 Mdot
.36727 .33958 Mdot
.57591 .37742 Mdot
.46699 .22161 Mdot
.66482 .2755 Mdot
.56739 .26273 Mdot
.35844 .78172 Mdot
.49418 .46325 Mdot
.49276 .4368 Mdot
.55499 .30389 Mdot
.33542 .7466 Mdot
.36353 .4297 Mdot
.4064 .3619 Mdot
.73976 .38887 Mdot
.79131 .64507 Mdot
.54177 .33329 Mdot
.4566 .45732 Mdot
.54314 .41938 Mdot
.60942 .66577 Mdot
.36856 .39775 Mdot
.54351 .2837 Mdot
.6399 .39693 Mdot
.71108 .7155 Mdot
.55456 .45497 Mdot
.35915 .65831 Mdot
.27715 .68612 Mdot
.53425 .4234 Mdot
.33783 .77026 Mdot
.71356 .59631 Mdot
.73202 .70333 Mdot
.41375 .74165 Mdot
.31571 .6076 Mdot
.67969 .57693 Mdot
.68309 .32269 Mdot
.55463 .83355 Mdot
.5502 .38392 Mdot
.51074 .47273 Mdot
.60279 .42457 Mdot
.35823 .80774 Mdot
.40596 .61855 Mdot
.19957 .41062 Mdot
.45799 .59163 Mdot
.5467 .70104 Mdot
.53835 .67353 Mdot
.45198 .31216 Mdot
.70187 .56121 Mdot
.37307 .46288 Mdot
.62033 .66247 Mdot
.74302 .38938 Mdot
.42567 .81058 Mdot
.80007 .66112 Mdot
.66776 .31365 Mdot
.32538 .78402 Mdot
.6783 .34088 Mdot
.66158 .32983 Mdot
.23791 .64046 Mdot
.51122 .47633 Mdot
.70983 .61777 Mdot
.31735 .61675 Mdot
.60949 .31147 Mdot
.79778 .6572 Mdot
.51961 .46666 Mdot
.32269 .61274 Mdot
.33285 .40601 Mdot
.43251 .46495 Mdot
.3297 .2468 Mdot
.39638 .37555 Mdot
.36884 .81388 Mdot
.31941 .74574 Mdot
.37284 .36746 Mdot
.57469 .4283 Mdot
.5227 .47373 Mdot
.72921 .71261 Mdot
.4758 .58384 Mdot
.62496 .80506 Mdot
.48186 .34154 Mdot
.75866 .41044 Mdot
.53467 .80539 Mdot
.46335 .77825 Mdot
.51898 .74701 Mdot
.78229 .43317 Mdot
.67485 .7411 Mdot
.48978 .56693 Mdot
.23135 .50628 Mdot
.16539 .52268 Mdot
.80981 .63778 Mdot
.6197 .23802 Mdot
.52072 .54306 Mdot
.38689 .76053 Mdot
.55345 .45175 Mdot
.43056 .69093 Mdot
.38984 .40412 Mdot
.34962 .66195 Mdot
.47783 .32223 Mdot
.5739 .20488 Mdot
.61536 .82359 Mdot
.68643 .565 Mdot
.51035 .60262 Mdot
.35869 .45422 Mdot
.31863 .45618 Mdot
.65929 .42125 Mdot
.78978 .6815 Mdot
.41376 .35864 Mdot
.23358 .33805 Mdot
.45107 .3276 Mdot
.4748 .81675 Mdot
.18761 .41322 Mdot
.44346 .29035 Mdot
.42337 .83987 Mdot
.62791 .25325 Mdot
.8092 .44355 Mdot
.55018 .19232 Mdot
.50824 .80712 Mdot
.76749 .44411 Mdot
.39588 .64233 Mdot
.66906 .78631 Mdot
.41691 .68877 Mdot
.32095 .64334 Mdot
.68862 .73098 Mdot
.29858 .72923 Mdot
.26972 .67755 Mdot
.37501 .28363 Mdot
.66799 .37519 Mdot
.17166 .44004 Mdot
.30068 .50282 Mdot
.77323 .29782 Mdot
.63466 .79402 Mdot
.78936 .57633 Mdot
.55272 .38638 Mdot
.42706 .39605 Mdot
.7247 .71942 Mdot
.34762 .76984 Mdot
.60471 .45075 Mdot
.21626 .49499 Mdot
.44588 .77245 Mdot
.37424 .74747 Mdot
.46374 .372 Mdot
.5572 .82614 Mdot
.32896 .51108 Mdot
.52972 .51885 Mdot
.30972 .74435 Mdot
.68484 .3316 Mdot
.5255 .73076 Mdot
.78815 .648 Mdot
.54324 .74659 Mdot
.26817 .68979 Mdot
.48296 .33825 Mdot
.21305 .43329 Mdot
.79592 .64835 Mdot
.65876 .27856 Mdot
.78139 .47963 Mdot
.87999 .54233 Mdot
.69484 .77151 Mdot
.52575 .47513 Mdot
.56801 .57342 Mdot
.40781 .82967 Mdot
.2331 .44997 Mdot
.44916 .81005 Mdot
.76645 .3212 Mdot
.25579 .66529 Mdot
.72672 .62497 Mdot
.58797 .55791 Mdot
.38393 .6877 Mdot
.56568 .30653 Mdot
.66002 .3927 Mdot
.32631 .48192 Mdot
.28124 .70061 Mdot
.76267 .3975 Mdot
.76343 .30359 Mdot
.81152 .42412 Mdot
.63197 .37608 Mdot
.64969 .79969 Mdot
.54065 .5033 Mdot
.75429 .3682 Mdot
.72538 .71058 Mdot
.52534 .62202 Mdot
.3707 .44948 Mdot
.74825 .35826 Mdot
.4175 .72802 Mdot
.17936 .5976 Mdot
.84914 .5897 Mdot
.74198 .40838 Mdot
.72303 .74955 Mdot
.51191 .84109 Mdot
.62154 .39151 Mdot
.64991 .42034 Mdot
.41377 .68024 Mdot
.53196 .45979 Mdot
.46014 .28692 Mdot
.31605 .49521 Mdot
.27333 .65514 Mdot
.25024 .52467 Mdot
.58756 .59425 Mdot
.47747 .36138 Mdot
.59005 .82752 Mdot
.35297 .67664 Mdot
.60375 .82215 Mdot
.77183 .41981 Mdot
.66387 .59355 Mdot
.8961 .51731 Mdot
.4889 .22461 Mdot
.69188 .65962 Mdot
.46926 .53495 Mdot
.52065 .54534 Mdot
.57716 .58931 Mdot
.41712 .27641 Mdot
.38337 .71077 Mdot
.23734 .65632 Mdot
.6713 .7824 Mdot
.58081 .38233 Mdot
.4161 .68571 Mdot
.38391 .36164 Mdot
.49834 .70335 Mdot
.7346 .61741 Mdot
.42026 .35727 Mdot
.21462 .63591 Mdot
.32705 .2503 Mdot
.36565 .41549 Mdot
.40499 .47101 Mdot
.46747 .69932 Mdot
.5112 .55555 Mdot
.22792 .63908 Mdot
.45449 .3092 Mdot
.36285 .44885 Mdot
.30287 .74334 Mdot
.78678 .44439 Mdot
.45932 .37314 Mdot
.17903 .4799 Mdot
.41474 .70395 Mdot
.4782 .36284 Mdot
.54758 .47597 Mdot
.80146 .39298 Mdot
.69935 .73467 Mdot
.33245 .41831 Mdot
.49279 .56571 Mdot
.8144 .49725 Mdot
.70807 .74154 Mdot
.40034 .3043 Mdot
.44004 .84323 Mdot
.52948 .48149 Mdot
.66508 .41511 Mdot
.77795 .59623 Mdot
.62359 .63337 Mdot
.67571 .50475 Mdot
.55652 .6 Mdot
.51852 .66966 Mdot
.31081 .25273 Mdot
.64362 .62738 Mdot
.42204 .46968 Mdot
.49286 .45823 Mdot
.3492 .68356 Mdot
.6863 .5238 Mdot
.64099 .57015 Mdot
.41402 .59786 Mdot
.43303 .74445 Mdot
.36022 .66922 Mdot
.33001 .66877 Mdot
.46674 .36542 Mdot
.22789 .64039 Mdot
.26713 .67374 Mdot
.74315 .58236 Mdot
.73235 .718 Mdot
.64734 .53031 Mdot
.62714 .79861 Mdot
.40189 .41972 Mdot
.50527 .32155 Mdot
.54677 .74003 Mdot
.84604 .59306 Mdot
.60561 .28577 Mdot
.57563 .51564 Mdot
.49792 .8363 Mdot
.57969 .82601 Mdot
.39261 .3887 Mdot
.4893 .20652 Mdot
.16277 .54187 Mdot
.40351 .69021 Mdot
.58078 .20672 Mdot
.22974 .49363 Mdot
.49526 .82856 Mdot
.6352 .66047 Mdot
.52063 .47766 Mdot
.77972 .39008 Mdot
.7079 .63299 Mdot
.26897 .44248 Mdot
.80975 .39846 Mdot
.7836 .43311 Mdot
.67151 .74327 Mdot
.60968 .6234 Mdot
.48055 .40891 Mdot
.63444 .30571 Mdot
.81197 .6309 Mdot
.24706 .49567 Mdot
.53348 .65728 Mdot
.77578 .3131 Mdot
.31699 .24983 Mdot
.25338 .64466 Mdot
.77245 .65865 Mdot
.39954 .37719 Mdot
.61583 .66083 Mdot
.3963 .21021 Mdot
.62355 .29458 Mdot
.64055 .3767 Mdot
.43498 .35129 Mdot
.35219 .72677 Mdot
.54018 .29595 Mdot
.86905 .56385 Mdot
.52759 .8303 Mdot
.71447 .60886 Mdot
.7564 .26994 Mdot
.31313 .74791 Mdot
.52068 .63817 Mdot
.53342 .28659 Mdot
.63335 .80828 Mdot
.47048 .30688 Mdot
.39167 .81859 Mdot
.53663 .43386 Mdot
.63592 .42237 Mdot
.36882 .737 Mdot
.54635 .19652 Mdot
.59629 .63518 Mdot
.76229 .29262 Mdot
.51334 .20805 Mdot
.38764 .75098 Mdot
.55065 .39871 Mdot
.65273 .30291 Mdot
.64441 .28275 Mdot
.51826 .40056 Mdot
.48546 .47362 Mdot
.45924 .45688 Mdot
.50047 .43617 Mdot
.36439 .42787 Mdot
.50286 .39535 Mdot
.48068 .22648 Mdot
.45643 .34653 Mdot
.79304 .41777 Mdot
.1657 .56418 Mdot
.32526 .66567 Mdot
.31216 .44007 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3Dooooo`;o0000Loooool001cooooo00?o0000ooooooooool0
e?ooool2o`0007?ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0Y?ooool2o`000:?ooooo000Looooo`03o`000?oooooooooo0:Cooooo0_l0002Soooo
o`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000
ooooooooool0Xoooool2o`0000[ooooo1?l0002Fooooo`0000KoooooogMgMonHV9SooooooiRHV?mg
MgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0
W_ooool2o`0000?ooooo0_l00008ooooo`Ko0000U_ooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo09cooooo1Ol0
000<ooooo`Go0000:oooool2o`0006[ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0009cooooo0_l000000ooooooo0000o`000006
ooooo`;o000000?oooooo`000?l00000<Oooool2o`0006[ooooo00000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`1foooo
o`Ko00006_ooool5o`0000cooooo0_l000000ooooooo0000o`000002ooooo`;o00001oooool2o`00
0003ooooool0003o000002;ooooo0_l0001Yooooo`0000?ooooooa0@4?ooool00_ooool00ol@413o
ooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0M_ooool7o`0000co
oooo0_l000000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l000001Ol00006ooooo`;o
00002Oooool2o`0000Oooooo1_l0000Qooooo`;o0000JOooool00006oooooomgMgOoV9RHoooooonH
V9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0NOooool8
o`0000Sooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000;o000000?ooooo
o`000?l000000_l000000ooooooo0000o`000005ooooo`?o00002Oooool2o`0000Wooooo1Ol0000Q
ooooo`?o0000Ioooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`00
0?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0O?ooool6o`0000;ooooo0ol00003ooooo`Wo0000
00?oooooo`000?l000001Oooool2o`0000Cooooo0ol00005ooooo`;o00001_ooool2o`000003oooo
ool0003o000000?ooooo0_l000000ooooooo0000o`00000Qooooo`Co0000I_ooool001cooooo00?o
0000ooooooooool0Ooooool4o`000003ooooool0003o000000?o000000?oooooo`000?l000001Ol0
0003ooooo`;o00002oooool2o`0000Kooooo0_l00006ooooo`;o000000?oooooo`000?l000001Ol0
0006ooooo`;o00007_ooool2o`0006Kooooo000Looooo`03o`000?oooooooooo087ooooo0_l00000
0ooooooo0000o`000003o`0000[ooooo1?l0000>ooooo`;o00003oooool4o`0000?ooooo0_l00002
ooooo`;o00007_ooool3o`0006Gooooo000Looooo`03o`000?oooooooooo08Cooooo0ol0000<oooo
o`Co00001?ooool3o`0000?ooooo0_l00002ooooo`;o00005_ooool2o`0002;ooooo0ol0001Uoooo
o`007?ooool00ol0003oooooooooo`25ooooo`;o00003Oooool2o`0000;ooooo0_l000001?oooooo
0000o`000?l00003ooooo`;o0000?oooool2o`0006Gooooo000Looooo`03o`000?oooooooooo09So
oooo0_l0000Zooooo`;o000000?oooooo`000?l000006oooool3o`0006;ooooo000Looooo`03o`00
0?oooooooooo093ooooo0_l00002ooooo`;o00001Oooool4o`0002Gooooo0_l000000ooooooo0000
o`00000Kooooo`?o0000H_ooool001cooooo00?o0000ooooooooool0T?ooool2o`0000;ooooo1?l0
0003ooooo`Co0000Z_ooool001cooooo00?o0000ooooooooool0Moooool2o`0000?ooooo0_l0000G
ooooo`?o0000;?ooool4o`0001oooooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`1/oooo
o`;o00000oooool4o`0000;ooooo0_l00003ooooo`;o0000A_ooool4o`0001oooooo0_l0001Poooo
o`007?ooool00ol0003oooooooooo`1/ooooo`;o00000oooool5o`0000Cooooo0_l0001Aooooo`;o
00006?ooool2o`00063ooooo000Looooo`03o`000?oooooooooo06Oooooo0_l0000;ooooo`;o0000
0_ooool4o`0000[ooooo0_l00010ooooo`;o00000oooool2o`0007[ooooo000Looooo`;o0000I?oo
ool2o`0000;ooooo0_l0000?ooooo`;o00003?ooool2o`00043ooooo0_l0001oooooo`007?ooool0
0ol0003oooooooooo`1Qooooo`Co00000_ooool4o`0005gooooo0_l00004ooooo`;o00006oooool2
o`0005cooooo000Looooo`03o`000?oooooooooo067ooooo0_l00005ooooo`?o0000Boooool6o`00
00cooooo0_l00004ooooo`Co00006Oooool2o`0005cooooo000Looooo`03o`000?oooooooooo0;Ko
oooo3Ol00008ooooo`;o00000oooool2o`0001[ooooo0_l0001Kooooo`007?ooool00ol0003ooooo
ooooo`1Nooooo`;o0000DOooool3o`000003ooooool0003o000000ko00001_ooool2o`0000?ooooo
0_l0000Jooooo`;o000000?oooooo`000?l00000F?ooool001cooooo00?o0000ooooooooool0GOoo
ool3o`00057ooooo0ol000001?oooooo0000o`000?ooool2o`0000Cooooo0_l000000ooooooo0000
o`000002o`0000_ooooo0_l0000Mooooo`;o0000F?ooool001cooooo00?o0000ooooooooool0GOoo
ool2o`0002cooooo0_l0000eooooo`?o00003oooool2o`0001cooooo0_l0001Eooooo`007?ooool0
0ol0003oooooooooo`23ooooo`?o00001Oooool4o`0002;ooooo1_l00005ooooo`;o00002_ooool2
o`0000[ooooo0_l0000Looooo`;o0000EOooool001cooooo00?o0000ooooooooool0F?ooool2o`00
02?ooooo0_l000001?oooooo0000o`000?ooool5o`0000Gooooo1?l0000Pooooo`Ko00001Oooool2
o`0000Cooooo0_l00004ooooo`;o00002_ooool2o`0007?ooooo000Looooo`03o`000?oooooooooo
05Sooooo0_l0000Qooooo`Co000000Coooooo`000?l0003ooooo1Ol00002ooooo`;o000000?ooooo
o`000?l000000_l0000Jooooo`;o000000?oooooo`000?l000000_ooool2o`000004ooooool0003o
0000o`0000[ooooo0_l00005ooooo`;o00001?ooool2o`000003ooooool0003o000000;o0000Looo
ool001cooooo00?o0000ooooooooool0Noooool2o`0000Sooooo0_l00002ooooo`?o00000_ooool2
o`0001[ooooo2?l000000ooooooo0000o`000003o`00017ooooo0_l00003ooooo`?o000000?ooooo
o`000?l000008?ooool2o`0005?ooooo000Looooo`03o`000?oooooooooo07Gooooo0ol0000@oooo
o`?o00000oooool2o`0001[ooooo2ol00006ooooo`;o00001?ooool2o`0000[ooooo1Ol0000Roooo
o`?o0000D_ooool001cooooo00?o0000ooooooooool0MOooool3o`00013ooooo0_l00004ooooo`;o
00000_ooool2o`0001?ooooo0_l000001?oooooo0000o`000?ooool7o`0000Cooooo1Ol00004oooo
o`;o00002_ooool6o`0002;ooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`1aooooo`?o
00003Oooool2o`0000?ooooo0_l00004ooooo`Co00000_ooool2o`0001?ooooo0_l000000ooooooo
0000o`000006ooooo`;o00001?ooool3o`0001Kooooo0_l0000Rooooo`;o0000D_ooool001cooooo
00?o0000ooooooooool0Doooool2o`0001cooooo0ol0000<ooooo`So00001?ooool4o`0000;ooooo
0ol0000Cooooo`Co00006oooool2o`0000;ooooo0_l00005ooooo`;o00008?ooool2o`0005?ooooo
000Looooo`03o`000?oooooooooo05?ooooo0_l0000Kooooo`?o00002_ooool2o`000003ooooool0
003o000000Oo00000oooool2o`0000?ooooo1?l0000@ooooo`Go00000_ooool2o`0000kooooo0_l0
0009ooooo`;o00000_ooool4o`0000?ooooo0_l0000Pooooo`;o000000?oooooo`000?l00000D?oo
ool001cooooo0_l0001`ooooo`Go00002?ooool9o`000003ooooool0003o000000Co00001Oooool2
o`0001;ooooo1?l00003ooooo`;o00002oooool8o`000003ooooool0003o000000;o00001_ooool3
o`0002Sooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`1^ooooo`Ko00002?ooool@o`00
00Sooooo0_l0000@ooooo`;o00002Oooool3o`0000;ooooo4?l00003ooooo`;o00001?ooool4o`00
027ooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`1^ooooo`Co00002_oooolBo`0000Go
oooo1?l0000?ooooo`;o00002Oooool:o`0000;ooooo1ol000001Ooooooo0000o`000?l0003ooooo
00?o00000oooool4o`0000Oooooo0_l0000Hooooo`Go0000D?ooool001cooooo00?o0000oooooooo
ool0K_ooool3o`0000Sooooo6Ol000000ooooooo0000o`000002o`0001cooooo1Ol00005ooooo`;o
00001?ooool5o`0000;ooooo0_l0000:ooooo`;o00000_ooool2o`0001Wooooo1?l0001@ooooo`00
7?ooool00ol0003oooooooooo`1]ooooo`?o00002OoooolIo`0000;ooooo0_l0000Jooooo`;o0000
00?oooooo`000?l000000ol00002ooooo`;o00001_ooool:o`000003ooooool0003o000000Kooooo
1?l000000ooooooo0000o`00000Kooooo`?o0000Coooool001cooooo00?o0000ooooooooool0K?oo
ool3o`0000[ooooo5Ol000000ooooooo0000o`000003ooooo`?o00005oooool4o`0000;ooooo0_l0
0004ooooo`;o00001_ooool:o`000004ooooool0003o0000ooooo`;o00000oooool4o`0001kooooo
0ol0001?ooooo`007?ooool00ol0003oooooooooo`1/ooooo`?o00002?oooolGo`0000Oooooo0_l0
00000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l000000_l00007ooooo`Go00002?oo
ool7o`0000Cooooo1ol000001?oooooo0000o`000?ooool2o`0000Cooooo0_l0000Mooooo`Go0000
Coooool001cooooo00?o0000ooooooooool0K?ooool2o`0000Wooooo1ol000000ooooooo0000o`00
000<o`0000Oooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00000_ooool7o`0000Oooooo
1?l00007ooooo`Wo00000oooool8o`000005ooooool0003o0000o`000?ooool00_l00003ooooo`;o
00000_ooool2o`0001Wooooo1Ol0001?ooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o0000
8?ooool2o`0000Sooooo5ol00007ooooo`;o000000?oooooo`000?l000001?l00003ooooo`;o0000
3?ooool3o`0000Oooooo2?l00002ooooo`_o000000Coooooo`000?l0003ooooo0_l00007ooooo`;o
00006?ooool3o`000003ooooool0003o000004oooooo000Looooo`03o`000?oooooooooo04[ooooo
0_l0000Pooooo`;o00002?oooolGo`0000;ooooo0_l00007ooooo`?o000000?oooooo`000?l00000
4?ooool2o`0000Wooooo1?l00002ooooo`ko00009oooool4o`00057ooooo000Looooo`03o`000?oo
oooooooo06_ooooo1Ol00008oooooaGo00000_ooool3o`0000[ooooo0_l0000Booooo`;o00001ooo
oolFo`0000;ooooo1?l00006ooooo`;o00005oooool5o`00053ooooo000Looooo`03o`000?oooooo
oooo06_ooooo1Ol00004oooooaWo00000_ooool3o`0000Kooooo0_l0000Booooo`;o00000_ooool2
o`0000Kooooo5ol00002ooooo`Co00001_ooool2o`0001Kooooo1_l0001@ooooo`007?ooool00ol0
003oooooooooo`18ooooo`;o00008_ooool3o`0000Gooooo6Ol00002ooooo`;o00001oooool3o`00
0003ooooool0003o000000Wooooo0_l00003ooooo`;o000000?oooooo`000?l000001_oooolIo`00
0003ooooool0003o000001kooooo1_l0001Booooo`007?ooool00ol0003oooooooooo`18ooooo`;o
00008_ooool3o`0000Gooooo5ol0000>ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Ko
oooo0_l00006oooooaCo000000?oooooo`000?l000000_l00009ooooo`;o00005_ooool6o`0005;o
oooo000Looooo`03o`000?oooooooooo06_ooooo1?l00005ooooo`;o000000?oooooo`000?l00000
4_l0000>ooooo`;o00004_ooool2o`0000Wooooo5ol00002ooooo`?o00001Oooool2o`0001Kooooo
1?l0001Dooooo`007?ooool00ol0003oooooooooo`1[ooooo`Co00001_oooolAo`000003ooooool0
003o000000;o00001_ooool2o`0000Sooooo1?l00009ooooo`;o00000oooool2o`0000Kooooo6Ol0
0003ooooo`?o00001Oooool2o`0001Gooooo1Ol0001Dooooo`007?ooool2o`0004Oooooo0_l0000]
oooooaGo00001oooool2o`0000;ooooo0_l00004ooooo`Co00002Oooool2o`0000?ooooo1?l00004
oooooa_o00002Oooool2o`0001Gooooo1Ol0001Dooooo`007?ooool00ol0003oooooooooo`16oooo
o`;o0000;ooooolAo`000004ooooool0003o0000o`0000Wooooo0_l0000Fooooo`Co00001?oooolK
o`000004ooooool0003o0000o`0000Gooooo0_l0000Eooooo`Go0000E?ooool001cooooo00?o0000
ooooooooool0K_ooool4o`0000Gooooo4?l00002ooooo`?o00002Oooool2o`0001;ooooo0_l00002
ooooo`?o00001OoooolKo`000003ooooool0003o000000;o00001?ooool2o`000003ooooool0003o
0000017ooooo0_l000001?oooooo0000o`000?l0001Dooooo`007?ooool00ol0003oooooooooo`12
ooooo`?o0000:Oooool6o`0000Cooooo1Ol000001?oooooo0000o`000?ooool6o`0002;ooooo0_l0
0003ooooo`;o00001OoooolKo`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l000004Ooo
ool5o`0005Gooooo000Looooo`03o`000?oooooooooo04;ooooo0ol0000Yooooo`;o000000Cooooo
o`000?l0003o00001Oooool>o`0000_ooooo0_l000000ooooooo0000o`000003o`0001Cooooo0_l0
0006oooooa[o00000_ooool2o`0001[ooooo2Ol0001Booooo`007?ooool00ol0003oooooooooo`1^
ooooo`;o000000?oooooo`000?l000000ol00003ooooo`_o00001oooool4o`0000?ooooo2?l0000K
ooooo`?o000000?oooooo`000?l000004_l00002ooooo`;o000000?oooooo`000?l000006_ooool2
o`0000;ooooo1Ol0001Booooo`007?ooool00ol0003oooooooooo`1cooooo`Co000000?oooooo`00
0?l000000_ooool6o`000003ooooool0003o000000Kooooo1?l00005ooooo`;o00007oooool2o`00
00?ooooo5ol000000ooooooo0000o`00000Jooooo`;o000000?oooooo`000?l00000E_ooool001co
oooo00?o0000ooooooooool0@?ooool2o`00037ooooo1ol00003ooooo`?o00000_ooool3o`0000ko
oooo0_l0000Uoooooa;o000000?oooooo`000?l000001Ol0000Jooooo`Go00000oooool2o`00057o
oooo000Looooo`03o`000?oooooooooo043ooooo0_l0000`ooooo`Ko00001Oooool3o`0000;ooooo
0ol0000<ooooo`Co000000?oooooo`000?l000006Oooool2o`0000Kooooo7_l00003ooooo`;o0000
5?ooool2o`0000Cooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`10ooooo`;o0000;?oo
ool3o`000003ooooool0003o000000Wooooo1?l00005ooooo`;o00002Oooool2o`0000?ooooo0_l0
000Iooooo`;o00001?oooolQo`0000;ooooo0_l0000Aooooo`;o000000?oooooo`000?l000001_oo
ool2o`000003ooooool0003o000004cooooo000Looooo`03o`000?oooooooooo03gooooo0_l0000_
ooooo`?o00003Oooool3o`0000Gooooo0_l00002ooooo`;o0000:oooool2o`0000;ooooo6Ol00002
ooooo`Co00004oooool2o`0000Wooooo0_l000000ooooooo0000o`00001<ooooo`007?ooool00ol0
003oooooooooo`0mooooo`;o0000<oooool3o`0000?ooooo0_l00002ooooo`;o00003?ooool2o`00
00Cooooo0_l00002ooooo`;o00006Oooool2o`0000Sooooo4_l00002ooooo`?o00001oooool3o`00
01;ooooo0ol0001Jooooo`007?ooool00ol0003oooooooooo`1_ooooo`;o000000Coooooo`000?l0
003o00000oooool2o`0000;ooooo0_l00007ooooo`;o000000?oooooo`000?l000001_ooool2o`00
00;ooooo0_l0000Iooooo`?o00001?oooolCo`000004ooooool0003o0000ooooo`;o00002?ooool2
o`0001?ooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`0kooooo`;o0000<_ooool2o`00
00Oooooo0_l000001?oooooo0000o`000?l00004ooooo`;o000000?oooooo`000?l000000ol0000O
ooooo`;o00001Oooool2o`0000Cooooo0ol00003ooooo`go000000?oooooo`000?l000008?ooool4
o`0000Wooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00014ooooo`0000Kooooo
onk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo
00?o0000ooooooooool0>oooool2o`0003;ooooo0_l00003ooooo`;o00000_ooool2o`000004oooo
ool0003o0000o`0000Cooooo0_l00002ooooo`?o00008?ooool2o`0000oooooo4?l00009ooooo`;o
00005oooool4o`0000Wooooo0_l000001?oooooo0000o`000?ooool6o`0004Cooooo00001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0>oooool2o`0002Kooooo1?l00008ooooo`;o00000oooool2o`0000;ooooo0_l00007
ooooo`;o00001?ooool2o`0001Oooooo1?l0000=ooooo`;o00001oooool@o`0000;ooooo0_l00005
ooooo`;o00005oooool2o`0001?ooooo0_l00016ooooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`09ooooo`Go00001_ooool00ol0003oooooooooo`0kooooo`;o00009_ooool6o`00
0003ooooool0003o000000?ooooo0_l00003ooooo`;o00002oooool3o`0000?ooooo0_l00002oooo
o`;o00004oooool4o`0000_ooooo1?l000000ooooooo0000o`000002ooooo`;o00000_ooool=o`00
00?ooooo0_l00003ooooo`Go00005Oooool3o`0000Kooooo0_l0000=ooooo`?o0000@oooool00003
ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?m4A4CogMgMooooool00007oooo
o`?o0000?Oooool2o`0002Sooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00002oooo
o`;o00003?ooool2o`0000Oooooo0_l0000Hooooo`;o00002?ooool2o`0000?ooooo0_l00002oooo
o`;o00001?ooool=o`0000Cooooo1ol0000Eooooo`;o00001oooool2o`0000gooooo0ol00013oooo
o`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`00
00Oooooo00?o0000ooooooooool0?Oooool2o`0001Kooooo0_l0000Aooooo`Ko00000_ooool2o`00
0004ooooool0003o0000o`0000Gooooo0_l0000Xooooo`;o00002oooool2o`0000Kooooo0_l00003
ooooo`co00001?ooool2o`0000;ooooo0ol0000Eooooo`;o00001oooool4o`00057ooooo00000ooo
oooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oMgMgolc<c?l000001oooool00ol0
003oooooooooo`1Eooooo`;o00002oooool4o`0000;ooooo1ol00004ooooo`?o00001Oooool2o`00
00kooooo0_l0000;ooooo`;o00001oooool2o`0000oooooo0_l00006ooooo`;o00001Oooool7o`00
00Sooooo1_l0000Eooooo`Co00001oooool2o`0000Kooooo0_l00019ooooo`0000KoooooogMgMonH
V9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0>Oooool2
o`0000;ooooo0_l0000Aooooo`;o00004?ooool7o`0000;ooooo1_l00002ooooo`?o00005Oooool2
o`000003ooooool0003o000000Sooooo0_l00006ooooo`?o00007_ooool7o`0000Sooooo1?l00002
ooooo`;o00004oooool4o`0000Cooooo0_l00009ooooo`;o00001oooool2o`00043ooooo00001_oo
ooook^k^oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooooooo
o`0hooooo`?o000000Coooooo`000?l0003o00004Oooool2o`0001?ooooo1?l00002ooooo`;o0000
0_ooool2o`0000;ooooo0_l0000Iooooo`;o00004?ooool2o`00027ooooo1_l00007ooooo`;o0000
0_ooool4o`0001?ooooo0_l00006ooooo`;o00001oooool2o`0000Wooooo0_l00010ooooo`007?oo
ool00ol0003oooooooooo`0fooooo`Go000000Coooooo`000?l0003o00003?ooool2o`0001Sooooo
1Ol000000ooooooo0000o`000004o`0000;ooooo0ol0001=ooooo`So00000_ooool4o`0000?ooooo
0ol0000Dooooo`;o00003oooool4o`0000Cooooo0_l00013ooooo`007?ooool00ol0003ooooooooo
o`0fooooo`;o00001Oooool2o`0000Sooooo0_l00002ooooo`;o00006Oooool4o`0000?ooooo0ol0
0004ooooo`;o00000oooool2o`0000Cooooo0_l0000/ooooo`;o00001_ooool2o`0000gooooo1ol0
00000ooooooo0000o`000003o`000003ooooool0003o000001Wooooo0_l00008ooooo`;o00001Ooo
ool2o`0000Cooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`17ooooo`;o00007Oooool3
o`0000Cooooo1?l00006ooooo`Co00001?ooool2o`0000Cooooo0_l0000Sooooo`;o000000?ooooo
o`000?l000001_ooool4o`0000Oooooo0_l00005ooooo`;o00000_ooool3o`000004ooooool0003o
0000ooooo`;o00006Oooool2o`0000Sooooo0_l00003ooooo`;o00001_ooool2o`0004?ooooo000L
ooooo`03o`000?oooooooooo03[ooooo0_l00008ooooo`;o00007Oooool2o`000003ooooool0003o
000000?o00000_ooool4o`0000;ooooo0_l00002ooooo`;o00003?ooool2o`0002?ooooo0_l00009
ooooo`Co000000?oooooo`000?l000001?ooool2o`0000Gooooo0_l00002ooooo`;o00008?ooool2
o`0000gooooo0_l00003ooooo`;o000000?oooooo`000?l00000@oooool001cooooo00?o0000oooo
ooooool0>Oooool3o`0000Sooooo0_l0000Booooo`Co00000_ooool8o`000003ooooool0003o0000
00;o00000_ooool3o`0000;ooooo0ol0000Yooooo`;o00001_ooool2o`0000gooooo1?l000000ooo
oooo0000o`00000aooooo`?o00004Oooool3o`0004Gooooo000Looooo`03o`000?oooooooooo03Go
oooo0_l00002ooooo`;o00001_ooool4o`00017ooooo4ol00004ooooo`Co000000?oooooo`000?l0
0000:_ooool4o`0000Cooooo0ol00002ooooo`;o00002_ooool2o`0000Sooooo0_l0000[ooooo`;o
00002_ooool3o`0000Cooooo0ol000000ooooooo0000o`000012ooooo`007?ooool00ol0003ooooo
ooooo`0eooooo`;o00002_ooool4o`0000cooooo1?l000000ooooooo0000o`00000Ao`0000Kooooo
0_l0000[ooooo`;o000000Coooooo`000?l0003o00001Oooool2o`0000;ooooo0_l00007ooooo`;o
000000?oooooo`000?l000002?ooool4o`0000Cooooo1?l0000Yooooo`;o00000_ooool3o`0000So
oooo0_l00002ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0=?ooool2o`000003oooo
ool0003o000001Gooooo1ol000000ooooooo0000o`000008o`0000;ooooo1ol0000cooooo`;o0000
00?oooooo`000?l000003Oooool2o`0000Cooooo0_l0000=ooooo`;o00001?ooool4o`0002Wooooo
0_l0000Aooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0=?ooool2o`000003ooooool0
003o000001;ooooo7?l00006ooooo`;o0000;?ooool5o`0000kooooo0ol0000Aooooo`;o0000@?oo
ool2o`0004?ooooo000Looooo`03o`000?oooooooooo037ooooo0_l0000Hoooooaco00001_ooool4
o`0002[ooooo0_l000000ooooooo0000o`000007ooooo`;o00000_ooool2o`0000;ooooo0_l0000A
ooooo`;o0000<Oooool2o`0000Gooooo0_l00005ooooo`?o0000@oooool001cooooo00?o0000oooo
ooooool0<Oooool2o`0000_ooooo0_l0000<oooooa;o000000?oooooo`000?l000001ol00004oooo
o`;o000000?oooooo`000?l000000ol000000ooooooo0000o`000003ooooo`;o0000:oooool2o`00
00;ooooo0_l0000?ooooo`;o00000_ooool2o`0003?ooooo1Ol00002ooooo`?o000000Coooooo`00
0?l0003ooooo0ol00013ooooo`007?ooool2o`0003oooooo0_l00008ooooob3o00001?ooool3o`00
0003ooooool0003o000000;o000000?oooooo`000?l000000oooool2o`0000[ooooo0_l00003oooo
o`;o00008oooool2o`0000[ooooo0_l00002ooooo`?o00001?ooool2o`0002gooooo1?l00003oooo
o`;o000000Goooooo`000?l0003o0000ooooo`02o`0004?ooooo000Looooo`03o`000?oooooooooo
03_ooooo0_l0000;oooooaoo00001Oooool3o`000003ooooool0003o000000;o00004_ooool2o`00
00?ooooo0_l0000Dooooo`;o00003Oooool2o`0000oooooo0_l00004ooooo`;o000000?oooooo`00
0?l000001_ooool2o`0002cooooo0ol000000ooooooo0000o`000013ooooo`007?ooool00ol0003o
ooooooooo`0kooooo`;o00002ooooolQo`0000?ooooo2Ol0000Looooo`;o00002Oooool2o`0000?o
oooo0_l0000=ooooo`;o00005Oooool2o`000003ooooool0003o000000Kooooo0_l0000Nooooo`;o
00001?ooool2o`0000Kooooo0ol000001?oooooo0000o`000?l00012ooooo`007?ooool00ol0003o
ooooooooo`15ooooo`;o00000ooooolOo`0000;ooooo1ol000000ooooooo0000o`00000Aooooo`;o
00000_ooool4o`0000?ooooo0_l00009ooooo`;o00001oooool2o`0000;ooooo0_l0000Gooooo`;o
00000oooool2o`0000?ooooo0_l00004ooooo`?o00007Oooool2o`0000Cooooo0_l0000;ooooo`;o
0000@_ooool001cooooo00?o0000ooooooooool0AOooool2o`0000Cooooo7Ol00003ooooo`;o0000
2?ooool2o`0000oooooo0_l000000ooooooo0000o`000005o`0000cooooo0ol00006ooooo`;o0000
0_ooool2o`0000;ooooo0_l0000?ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`?o0000
1Oooool2o`0001gooooo0_l00004ooooo`;o00002oooool2o`0004;ooooo000Looooo`03o`000?oo
oooooooo04[ooooo7?l00002ooooo`;o00002?ooool2o`000003ooooool0003o000001;ooooo0_l0
0003ooooo`;o00003?ooool3o`0000Kooooo1?l00004ooooo`;o00003oooool2o`0000_ooooo0_l0
000Uooooo`;o00002_ooool2o`0000Gooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`17
ooooob3o000000?oooooo`000?l000000oooool2o`0000?ooooo0_l0000<ooooo`;o00000oooool2
o`0001;ooooo1Ol00007ooooo`Co00006_ooool4o`00017ooooo0_l0000Hooooo`?o00000_ooool2
o`0000Cooooo0ol00005ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0@ooooolPo`00
00;ooooo0_l00004ooooo`Co00002oooool2o`0000?ooooo0ol00003ooooo`;o00004?ooool7o`00
00Cooooo0_l00002ooooo`;o00001_ooool3o`0000;ooooo0_l0000>ooooo`Oo00003_ooool2o`00
01Wooooo0_l00002ooooo`;o00001?ooool6o`0000;ooooo0_l00012ooooo`007?ooool00ol0003o
ooooooooo`13oooooaOo000000Coooooo`000?l0003ooooo0ol000000ooooooo0000o`000003o`00
00Cooooo0_l0000:ooooo`;o000000Coooooo`000?l0003ooooo1?l00009ooooo`;o00002oooool5
o`0000Kooooo0_l00002ooooo`?o00001Oooool3o`0000;ooooo0_l0000<ooooo`;o00001?ooool5
o`0000?ooooo0_l00009ooooo`;o00005_ooool2o`0000Wooooo1_l00002ooooo`;o0000@_ooool0
01cooooo00?o0000ooooooooool0=_ooool2o`0000?ooooo0_l00006ooooo`Co00000_oooolMo`00
017ooooo0_l00004ooooo`;o00002oooool2o`0000_ooooo1Ol00006ooooo`;o000000?oooooo`00
0?l000000_l00005ooooo`;o00004Oooool2o`0000Cooooo0_l000000ooooooo0000o`000003oooo
o`;o00002Oooool3o`0001Gooooo0_l00006ooooo`;o00000_ooool3o`0000?ooooo0_l00013oooo
o`007?ooool00ol0003oooooooooo`0fooooo`;o00000oooool2o`0000Kooooo1?l00002oooooa?o
000000?oooooo`000?l000002Ol00004ooooo`;o00003oooool2o`00017ooooo0_l00005ooooo`Oo
00001oooool2o`000003ooooool0003o000001gooooo0_l0000=ooooo`?o00000_ooool2o`000004
ooooool0003o0000o`0001Sooooo0ol00007ooooo`?o0000@oooool001cooooo00?o0000oooooooo
ool0=Oooool2o`000003ooooool0003o000000Sooooo0_l00005oooooaco000000?oooooo`000?l0
00000_ooool4o`0000oooooo0_l0000Aooooo`;o00002_ooool2o`0000[ooooo0_l0000/ooooo`?o
00001Oooool3o`0001Oooooo0ol00003ooooo`;o000000?oooooo`000?l000001?l00012ooooo`00
7?ooool00ol0003oooooooooo`0eooooo`;o000000?oooooo`000?l000002?ooool3o`0000?ooooo
2?l000000ooooooo0000o`00000Ao`0000Kooooo0_l0000Aooooo`?o0000E_ooool2o`0000;ooooo
0_l000000ooooooo0000o`000002o`0001Oooooo0_l00004ooooo`Wo0000@_ooool001cooooo00?o
0000ooooooooool0@oooool2o`0000?ooooo7?l0000Jooooo`;o000000?oooooo`000?l000009_oo
ool2o`0000Gooooo0_l0000Mooooo`;o00000oooool5o`000004ooooool0003o0000ooooo`Co0000
7?ooool4o`000003ooooool0003o000000?o0000@_ooool001cooooo00?o0000ooooooooool0@_oo
ool9o`000003ooooool0003o000000ko00000_ooool3o`0000;ooooo0ol0000Cooooo`;o000000?o
ooooo`000?l000000oooool4o`0002Cooooo0_l00005ooooo`;o00007Oooool2o`0000;ooooo2?l0
00000ooooooo0000o`000002o`0001gooooo0ol00003ooooo`Co0000@_ooool001cooooo00?o0000
ooooooooool0@_ooool9o`000003ooooool0003o000000co00001?ooool3o`0000;ooooo1?l00000
0ooooooo0000o`000007ooooo`;o00001_ooool2o`000003ooooool0003o000000Gooooo0_l0001:
ooooo`;o00000_ooool5o`000004ooooool0003o0000ooooo`;o00007oooool3o`0000Cooooo0ol0
0012ooooo`007?ooool2o`0003Wooooo0_l00008ooooo`?o00000oooool3o`000003ooooool0003o
000000co00002oooool2o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o00002?ooool2
o`00033ooooo0_l0000@ooooo`;o00004oooool5o`0002Cooooo0ol00004ooooo`?o0000@_ooool0
01cooooo00?o0000ooooooooool0>?ooool2o`0000Sooooo1Ol00005ooooo`;o00001_ooool6o`00
00Cooooo0_l00004ooooo`;o00000_ooool2o`0000?ooooo0_l0000<ooooo`;o0000;oooool3o`00
013ooooo0_l0000Dooooo`Go00001?ooool2o`0001Gooooo0_l00006ooooo`;o00009?ooool2o`00
02Cooooo000Looooo`03o`000?oooooooooo03?ooooo0_l0000>ooooo`Ko00003Oooool3o`0000Go
oooo0_l00004ooooo`;o00000_ooool2o`0003Kooooo0_l000000ooooooo0000o`000002o`0000Go
oooo1?l0000Uooooo`Go000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00004?ooool2o`00
00cooooo0_l0000Nooooo`;o00009?ooool001cooooo00?o0000ooooooooool0<oooool2o`0001;o
oooo0_l0000=ooooo`;o00000_ooool2o`0000[ooooo1Ol00002ooooo`Co0000;oooool2o`000003
ooooool0003o000000;o00001_ooool3o`000004ooooool0003o0000ooooo`;o000000Coooooo`00
0?l0003o00006oooool9o`0000;ooooo1Ol0000@ooooo`Co00002_ooool2o`0001gooooo0_l0000U
ooooo`007?ooool00ol0003oooooooooo`17ooooo`Co00003oooool2o`0000[ooooo1Ol00002oooo
o`Ko0000<?ooool2o`0000?ooooo0_l00007ooooo`;o000000?oooooo`000?l000001?l0000Loooo
o`Go000000?oooooo`000?l000000_ooool5o`0001;ooooo0_l0000:ooooo`;o00007?ooool3o`00
02Gooooo000Looooo`03o`000?oooooooooo04Oooooo1Ol0000Sooooo`Co0000=Oooool2o`0000co
oooo0ol0000Nooooo`;o00002?ooool4o`0001Sooooo0_l0000Pooooo`Co00009_ooool001cooooo
00?o0000ooooooooool0B_ooool3o`0001gooooo0_l000000ooooooo0000o`000002o`0003Cooooo
0_l000000ooooooo0000o`000002o`000003ooooool0003o000000Sooooo0_l0000Oooooo`;o0000
00?oooooo`000?l000001?ooool4o`0001Sooooo0ol00003ooooo`;o00006_ooool4o`0002Kooooo
000Looooo`03o`000?oooooooooo03;ooooo0_l0000Gooooo`;o00006?ooool2o`0000?ooooo0_l0
00000ooooooo0000o`00000booooo`;o00000_ooool7o`000003ooooool0003o000000;o00001Ooo
ool2o`00023ooooo1Ol00005ooooo`;o00006_ooool2o`0000?ooooo0_l0000Jooooo`;o0000:?oo
ool001cooooo00?o0000ooooooooool0<Oooool3o`0001[ooooo0_l0000Eooooo`Co0000>?ooool2
o`000003ooooool0003o000000?o000000?oooooo`000?l000001Ol00005ooooo`;o00008Oooool4
o`0000Gooooo0_l0000Jooooo`;o00007oooool2o`0002Sooooo000Looooo`03o`000?oooooooooo
037ooooo0_l0000Kooooo`;o000000?oooooo`000?l000002Oooool4o`0000Oooooo0_l0000koooo
o`Go000000?oooooo`000?l000001Ol0000Rooooo`;o00001_ooool4o`0000;ooooo1?l0000Aoooo
o`;o00001_ooool2o`0004Wooooo000Looooo`03o`000?oooooooooo057ooooo0_l00005ooooo`;o
00000_ooool4o`0003Sooooo1?l00006ooooo`Ko00000_ooool3o`0000Gooooo0_l0000Jooooo`Oo
00001?ooool3o`000003ooooool0003o000000;ooooo1?l0000;ooooo`;o00001?ooool4o`0004oo
oooo000Looooo`03o`000?oooooooooo037ooooo0_l0000Uooooo`;o0000>oooool?o`000003oooo
ool0003o000000?o000000?oooooo`000?l000001Oooool2o`0001Kooooo2Ol00002ooooo`;o0000
0_ooool3o`000003ooooool0003o0000017ooooo0_l00006ooooo`;o00001?ooool2o`0004Wooooo
000Looooo`03o`000?oooooooooo037ooooo0_l0001Poooooa[o00006OoooolAo`0000?ooooo1Ol0
000Oooooo`;o00001?ooool2o`0004?ooooo000Looooo`03o`000?oooooooooo037ooooo0_l0001O
oooooaKo000000?oooooo`000?l000000_l000000ooooooo0000o`00000DoooooaKo00000_ooool3
o`0001oooooo0_l00003ooooo`?o00005Oooool2o`0002cooooo000Looooo`03o`000?oooooooooo
037ooooo0_l0001NoooooaOo00000_ooool2o`0000;ooooo0ol0000@oooooako00007oooool2o`00
00?ooooo0_l0000Eooooo`?o0000;?ooool001cooooo00?o0000ooooooooool0S_oooolJo`0000;o
oooo1ol0000>ooooo`Wo000000?oooooo`000?l000002?l000000ooooooo0000o`000008o`00023o
oooo0ol0000Iooooo`?o0000;?ooool001cooooo0_l0002<oooooaOo00000oooool3o`0000;ooooo
1Ol0000?oooooaGo000000?oooooo`000?l000002Ol0000Oooooo`?o00006?ooool2o`0002kooooo
000Looooo`03o`000?oooooooooo033ooooo0_l0001IoooooaOo00000_ooool3o`000003ooooool0
003o000000?o00003_oooolBo`000003ooooool0003o000000_o000000Coooooo`000?l0003o0000
4_ooool2o`0000;ooooo0_l00008ooooo`;o00006?ooool2o`0002kooooo000Looooo`03o`000?oo
oooooooo033ooooo0_l0001Fooooo`;o000000?oooooo`000?l000003?l000000ooooooo0000o`00
000:o`0000;ooooo1?l0000?ooooob3o00000_ooool2o`0000;ooooo0_l0000;ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0002;ooooo0_l0000^ooooo`007?ooool00ol0003oooooooooo`0`
ooooo`?o0000EOoooolPo`0000oooooo3Ol000000ooooooo0000o`00000Ho`0000;ooooo0_l0000;
ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0<?ooool3o`0005Kooooo7?l000000ooo
oooo0000o`00000?ooooobSo000000?oooooo`000?l000004_ooool2o`0000Sooooo0_l00019oooo
o`007?ooool00ol0003oooooooooo`0`ooooo`Co0000C_ooool2o`0000Gooooo6ol0000BooooobWo
000000?oooooo`000?l000000_l0000=ooooo`Go00001oooool3o`0001Kooooo0_l0000aooooo`00
7?ooool00ol0003oooooooooo`0booooo`;o0000?_ooool2o`0000Gooooo1?l00005ooooo`;o0000
1Oooool:o`000003ooooool0003o000000ko00004?ooool5o`000005ooooool0003o0000o`000?oo
ool08ol000001?oooooo0000o`000?l0000<ooooo`Co00002?ooool5o`0001;ooooo1?l0000aoooo
o`007?ooool00ol0003oooooooooo`1booooo`;o00001Oooool4o`0000Oooooo0_l00003oooooa_o
00003ooooolZo`000003ooooool0003o000000;o000000?oooooo`000?l000003_ooool2o`0000Wo
oooo1?l0000Aooooo`?o0000<oooool001cooooo00?o0000ooooooooool0KOooool2o`00017ooooo
0_l00002oooooa_o000000?oooooo`000?l000004OoooolZo`000003ooooool0003o000000;o0000
2?ooool2o`0000oooooo0_l000000ooooooo0000o`00000Cooooo`;o0000=?ooool001cooooo00?o
0000ooooooooool0K?ooool3o`00013ooooo0ol00004oooooaKo00000_ooool4o`00013ooooo:Ol0
00000ooooooo0000o`00000<ooooo`;o00001Oooool2o`0000Sooooo1?l0000Dooooo`;o0000=?oo
ool001cooooo00?o0000ooooooooool0K?ooool2o`0000Sooooo1ol00002ooooo`Co00000ooooolC
o`0000Gooooo0ol0000Aooooob7o000000Goooooo`000?l0003o0000ooooo`03o`000003ooooool0
003o000000Gooooo0_l0000;ooooo`?o00001oooool2o`000003ooooool0003o000004[ooooo000L
ooooo`03o`000?oooooooooo06kooooo0_l00005ooooo`So00001?ooool3o`0000;ooooo4?l00000
0ooooooo0000o`000004ooooo`Co00004?ooool[o`0000Oooooo0_l00009ooooo`Co00002?ooool2
o`0001Cooooo1?l0000eooooo`007?ooool00ol0003oooooooooo`0booooo`?o0000>Oooool@o`00
00Cooooo0_l000000ooooooo0000o`00000<o`0000?ooooo1?l00003ooooo`;o00004Oooool/o`00
00?ooooo0_l0000=ooooo`?o000000?oooooo`000?l000001_ooool2o`0001Cooooo1?l0000eoooo
o`007?ooool00ol0003oooooooooo`0booooo`?o0000<oooool2o`0000;ooooo0_l00002ooooo`[o
000000?oooooo`000?l000000_l00003ooooo`;o000000?oooooo`000?l000001?l00002ooooo`So
000000?oooooo`000?l000000_l0000FooooobKo000000?oooooo`000?l000000_l00004ooooo`;o
00003Oooool3o`000003ooooool0003o000000Cooooo1?l0000Dooooo`;o0000=oooool00006oooo
ooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006
ooooo`03o`000?oooooooooo06Sooooo0_l000000ooooooo0000o`00000Do`0000Cooooo1?l00004
ooooo`So00000_ooool2o`0001Oooooo1Ol000000ooooooo0000o`00000So`0001;ooooo1?l00007
ooooo`Co00004oooool3o`0003Oooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ
8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1YoooooaSo0000
0oooool5o`0000?ooooo0ol000001?oooooo0000o`000?l0000Kooooo`Oo00001?oooolRo`0000Wo
oooo0_l00007ooooo`;o00002?ooool4o`0001Cooooo0ol0000gooooo`0000?ooooooa0@4?ooool0
0_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`0gooooo`;o0000<?ooool2o`0000;ooooo5Ol000000ooooooo0000o`000004o`0000?o
oooo0_l00002ooooo`Co00006_ooool6o`0000Gooooo8?l00002ooooo`;o00001oooool2o`0000Ko
oooo0ol00008ooooo`Co0000C_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
2Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0000dooooo`;o000000?oooooo`000?l0
0000<?ooool5o`000003ooooool0003o0000017o000000Coooooo`000?l0003o00003?ooool2o`00
00kooooo0_l0000;ooooo`Go00001OoooolPo`0000;ooooo0_l00006ooooo`;o00001oooool2o`00
00Oooooo0ol0000Eooooo`;o0000>_ooool00003ooooool0003ooooo00;ooooo00?o0000oooooooo
ool02Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0=?ooool2o`00
00;ooooo0_l0000_ooooo`Go000000?oooooo`000?l000004Ol00002ooooo`;o00006_ooool4o`00
00_ooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo7Ol00002ooooo`;o00002?ooool2
o`0000oooooo1?l0000Eooooo`;o0000>_ooool00003ooooool@413ooooo00;ooooo00?o410@oooo
ooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo03Kooooo1?l0000Yoooo
o`;o00001?oooolIo`0000Cooooo1?l0000Fooooo`;o00000_ooool2o`0000Sooooo0ol00003oooo
o`?o00001OoooolKo`0000;ooooo0_l00009ooooo`;o00001?ooool2o`0000Oooooo0ol0001Coooo
o`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000
ooooooooool0=_ooool2o`0002_ooooo7?l000000ooooooo0000o`000004ooooo`Co00005Oooool2
o`0000?ooooo0_l00008ooooo`?o000000?oooooo`000?l000000_l00002ooooo`;o00000_oooolG
o`000003ooooool0003o000000kooooo0_l00004ooooo`;o00001oooool2o`0005Cooooo00001_oo
ooook^k^oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003ooooo
ooooo`0fooooo`;o00000_ooool4o`0002Oooooo6_l0000Pooooo`?o00003?ooool2o`0000;ooooo
0_l00004ooooo`;o00000ooooolDo`0000?ooooo0_l00008ooooo`;o00002Oooool2o`0000Kooooo
0_l0000Hooooo`;o0000??ooool001cooooo00?o0000ooooooooool0>_ooool4o`0002Gooooo0_l0
0003oooooaKo00000_ooool2o`0001gooooo0ol0000<ooooo`?o000000?oooooo`000?l000001Ooo
ool2o`0000;ooooo0ol00002ooooo`Wo000000Coooooo`000?l0003o00001?ooool2o`000003oooo
ool0003o000000?ooooo0_l000000ooooooo0000o`000003ooooo`;o00001?ooool4o`0000Cooooo
0_l0000Eooooo`;o000000?oooooo`000?l00000??ooool001cooooo00?o0000ooooooooool0>_oo
ool2o`0002Oooooo0_l00003oooooaKo00000_ooool3o`0002Cooooo0_l00005ooooo`?o000000?o
ooooo`000?l000001Oooool2o`0000Oooooo1ol0000:ooooo`;o000000?oooooo`000?l000000ooo
ool2o`0000Gooooo0ol00006ooooo`;o00000_ooool4o`0001Gooooo0_l0000oooooo`007?ooool0
0ol0003oooooooooo`1Tooooo`;o00000_oooolEo`000004ooooool0003o0000ooooo`;o000000?o
ooooo`000?l000008Oooool2o`0000Gooooo1Ol00002ooooo`;o00002oooool6o`0001[ooooo0_l0
0004ooooo`;o00001?ooool3o`0001Oooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`1T
ooooo`;o00000_oooolDo`0000;ooooo1?l00002ooooo`;o0000:?ooool5o`0000;ooooo0_l0000;
ooooo`Ko00001Oooool2o`0001Gooooo0_l00002ooooo`;o00001?ooool2o`0001Oooooo0_l00010
ooooo`007?ooool00ol0003oooooooooo`0jooooo`;o0000;OoooolAo`0000Cooooo1ol0000Zoooo
o`Co00001oooool2o`0000Cooooo1Ol00008ooooo`;o00001Oooool2o`0000Kooooo0_l00006oooo
o`;o00001_ooool2o`0001Kooooo1Ol00010ooooo`007?ooool00ol0003oooooooooo`0jooooo`;o
00009oooool3o`0000Cooooo3ol00006ooooo`Ko0000:_ooool4o`0000Oooooo0_l00004ooooo`Co
00000oooool2o`0000Kooooo0_l00003ooooo`;o00001_ooool2o`0000Cooooo0_l00007ooooo`?o
00005_ooool4o`00047ooooo000Looooo`03o`000?oooooooooo04;ooooo0_l0000Oooooo`?o0000
0oooool@o`0003Kooooo1?l00007ooooo`;o00000_ooool2o`0000Oooooo0_l00006ooooo`;o0000
4?ooool3o`0000Oooooo1?l0001Jooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00000ooo
ool2o`0000;ooooo0_l000001?oooooo0000o`000?l0000Eooooo`;o00001_ooool>o`0002kooooo
0_l00009ooooo`Ko00001?ooool3o`000003ooooool0003o000000?ooooo0_l0000<ooooo`;o0000
3Oooool4o`0000Gooooo0_l00002ooooo`;o00004oooool4o`0004?ooooo000Looooo`03o`000?oo
oooooooo03gooooo0_l00007ooooo`;o000000Coooooo`000?l0003o00005Oooool2o`0000;ooooo
0_l00003ooooo`go00001Oooool3o`0002Kooooo0_l00009ooooo`Ko00001?ooool3o`0000Kooooo
0_l0000<ooooo`;o00003Oooool4o`0000?ooooo1?l0000Fooooo`Go0000@oooool001cooooo00?o
0000ooooooooool0COooool4o`00017ooooo0_l000000ooooooo0000o`000005o`000003ooooool0
003o000000;o00000_ooool2o`0000Cooooo0_l000001?oooooo0000o`000?l0000booooo`?o0000
2?ooool2o`0002Wooooo0_l0000Dooooo`;o00000_ooool2o`0004Kooooo000Looooo`03o`000?oo
oooooooo047ooooo0ol00009ooooo`Co00004Oooool2o`0000;ooooo1Ol00002ooooo`;o00002_oo
ool2o`0003Oooooo1Ol00005ooooo`;o00002Oooool2o`0003?ooooo1Ol00018ooooo`007?ooool2
o`0004;ooooo0ol0000@ooooo`;o00004?ooool5o`0000;ooooo0_l0000=ooooo`;o0000=Oooool4
o`0000Gooooo0ol00008ooooo`;o0000<oooool2o`000004ooooool0003o0000o`0004Oooooo000L
ooooo`03o`000?oooooooooo04Cooooo0_l0000;ooooo`;o000000Coooooo`000?l0003o00001Ooo
ool2o`0000Sooooo0ol0000Cooooo`;o0000=Oooool5o`0000Cooooo0ol0000Mooooo`;o00008_oo
ool2o`000003ooooool0003o000004Cooooo000Looooo`03o`000?oooooooooo04Cooooo1?l00000
0ooooooo0000o`000006ooooo`;o00000_ooool2o`0000Gooooo0_l0000Booooo`Co00002?ooool2
o`0002cooooo0_l00007ooooo`Go00001?ooool3o`0000?ooooo0_l0000Hooooo`;o00006Oooool3
o`0000Gooooo0ol000001?oooooo0000o`000?l00013ooooo`007?ooool00ol0003oooooooooo`14
ooooo`Co000000?oooooo`000?l000001Oooool2o`0000Kooooo0_l0000Cooooo`Oo00001_ooool4
o`0002cooooo0_l00008ooooo`Go00000oooool3o`0000?ooooo1?l00005ooooo`;o00004?ooool2
o`0001Sooooo0ol00005ooooo`?o000000Coooooo`000?l0003o0000@oooool001cooooo00?o0000
ooooooooool0AOooool3o`0000Cooooo0_l00002ooooo`;o00001_ooool2o`0000_ooooo0_l00006
ooooo`?o00002_ooool5o`0002_ooooo0_l00009ooooo`Co00002oooool4o`0000?ooooo0_l0000:
ooooo`?o00000oooool2o`0000;ooooo0_l0000Booooo`;o00002Oooool5o`0004Cooooo000Loooo
o`03o`000?oooooooooo04Gooooo0ol00004ooooo`;o000000?oooooo`000?l000001_ooool3o`00
00[ooooo1?l00005ooooo`;o00003Oooool4o`0003Kooooo1?l00002ooooo`Go000000?oooooo`00
0?l000000_ooool2o`0000Oooooo0_l00006ooooo`?o00001oooool2o`0001;ooooo0_l0000:oooo
o`;o0000A_ooool001cooooo00?o0000ooooooooool0A_ooool6o`0000?ooooo0_l00005ooooo`Co
00002_ooool5o`0000Sooooo0_l00009ooooo`Co000000?oooooo`000?l000008?ooool4o`0000Go
oooo0_l00009ooooo`Co000000?oooooo`000?l000001_l0000;ooooo`;o00002?ooool2o`0001Oo
oooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`18ooooo`Co00000oooool2o`000003oooo
ool0003o000000Co00003oooool2o`0000;ooooo0_l00004ooooo`;o00001oooool2o`0000?ooooo
1?l0000Pooooo`Co00001?ooool3o`0000_ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o
00000oooool2o`00017ooooo0_l0000Gooooo`;o0000EOooool001cooooo00?o0000ooooooooool0
B_ooool2o`0000Kooooo1Ol0000Booooo`Co00000_ooool2o`0000Wooooo0_l00003ooooo`;o0000
1Oooool2o`0001gooooo0_l00004ooooo`;o00003?ooool3o`0000Cooooo0ol00003ooooo`;o0000
1?ooool4o`0000Oooooo0_l0000Looooo`;o0000D_ooool001cooooo00?o0000ooooooooool0E?oo
ool2o`0001?ooooo0_l00004ooooo`Go00003oooool2o`000003ooooool0003o000000?ooooo0_l0
00000ooooooo0000o`00000Kooooo`;o00003Oooool3o`000003ooooool0003o000000;o00002_oo
ool6o`0000;ooooo0_l000000ooooooo0000o`00000Looooo`;o0000D_ooool001cooooo00?o0000
ooooooooool0Coooool2o`0000?ooooo0_l00003ooooo`;o00002_ooool2o`0000Oooooo1_l0000?
ooooo`;o00001_ooool2o`000003ooooool0003o000000_ooooo0_l0000;ooooo`Go00003Oooool6
o`0000oooooo1ol0000Jooooo`;o00002oooool2o`0004[ooooo000Looooo`03o`000?oooooooooo
04oooooo0_l00005ooooo`;o000000?oooooo`000?l000000_l00008ooooo`;o00001oooool4o`00
017ooooo0ol00006ooooo`Co00001Oooool2o`0000Cooooo0_l0000;ooooo`?o00000_ooool2o`00
00gooooo1Ol00004ooooo`;o000000?oooooo`000?l000001Oooool2o`000003ooooool0003o0000
01cooooo0_l0000;ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0Doooool2o`000003
ooooool0003o000000?ooooo0_l00002ooooo`;o00006?ooool2o`0000Sooooo0ol00006ooooo`Co
00000_ooool2o`000004ooooool0003o0000o`0000Sooooo0_l00007ooooo`;o00000_ooool2o`00
00kooooo1?l00004ooooo`;o000000Coooooo`000?l0003ooooo0ol0001kooooo`007?ooool00ol0
003oooooooooo`1Cooooo`;o00002_ooool2o`0001Sooooo0_l000000ooooooo0000o`000003o`00
00?ooooo0_l000001?oooooo0000o`000?l00008ooooo`Ko00002?ooool2o`0000Oooooo1_l0000L
ooooo`?o00008_ooool2o`0000Sooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`1Coooo
o`?o00000oooool2o`0000Cooooo0_l0000Gooooo`Wo00001_ooool3o`0000Sooooo1_l0000Boooo
o`Go0000>oooool2o`0000Cooooo0_l00003ooooo`;o00000oooool2o`0004gooooo000Looooo`03
o`000?oooooooooo05Cooooo0_l00003ooooo`;o00001?ooool3o`0001?ooooo0_l000000ooooooo
0000o`000004o`0001Kooooo1?l00004ooooo`;o00003?ooool2o`0003gooooo0ol00009ooooo`;o
0000D_ooool001cooooo0_l0001Iooooo`;o00001_ooool2o`0001?ooooo1?l000000ooooooo0000
o`000003ooooo`;o00003Oooool:o`0000Cooooo0ol0000?ooooo`Co0000=oooool4o`0000Kooooo
0_l0001Dooooo`007?ooool00ol0003oooooooooo`1Gooooo`?o00001Oooool3o`0001?ooooo1ol0
0002ooooo`?o000000Coooooo`000?l0003o00002Oooool8o`0000Oooooo0ol0000;ooooo`;o0000
00?oooooo`000?l000000ol0000booooo`;o00000oooool3o`0000Kooooo0ol0001Cooooo`007?oo
ool00ol0003oooooooooo`1Fooooo`?o00001_ooool4o`0001?ooooo1?l00004ooooo`Oo00000ooo
ool2o`0000;ooooo0_l0000@ooooo`;o00002oooool2o`0000Cooooo0_l0000booooo`;o00000ooo
ool2o`0000Sooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`1Fooooo`;o00002Oooool2
o`0001?ooooo1Ol00005ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000004
o`0000Gooooo0_l00009ooooo`;o00003?ooool2o`0000?ooooo0ol0000dooooo`;o00001?ooool2
o`0005Wooooo000Looooo`03o`000?oooooooooo05[ooooo1Ol0000Hooooo`Co00002?ooool9o`00
00Cooooo2?l00006ooooo`;o00003?ooool3o`0000;ooooo0ol0000dooooo`Co00000_ooool2o`00
05Wooooo000Looooo`03o`000?oooooooooo05Wooooo1ol0000Gooooo`Co00003?ooool4o`0000Co
oooo2_l00005ooooo`?o00002oooool3o`0000;ooooo0_l0000`ooooo`;o00001?ooool7o`0000Co
oooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`1Hooooo`?o00000oooool2o`0001Sooooo
1?l0000<ooooo`;o00001Oooool;o`0000Gooooo0_l0000;ooooo`;o0000=Oooool2o`0000?ooooo
2?l00004ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0F?ooool3o`0001gooooo1?l0
000<ooooo`;o00001?ooool6o`0000;ooooo1?l00004ooooo`?o00002oooool2o`0000Cooooo0_l0
000dooooo`Co000000Coooooo`000?l0003ooooo0_l0001Gooooo`007?ooool00ol0003ooooooooo
o`1Iooooo`;o00004Oooool2o`000003ooooool0003o000000Wooooo0ol00003ooooo`Co00001?oo
ool2o`0000Cooooo0ol000000ooooooo0000o`000002ooooo`Co00001?ooool3o`0000Oooooo0_l0
0002ooooo`;o00001?ooool2o`0003Sooooo0ol000000ooooooo0000o`00001Gooooo`007?ooool0
0ol0003oooooooooo`1Iooooo`;o00000_ooool2o`0000gooooo0_l000000ooooooo0000o`000008
ooooo`Go00000_ooool6o`0000Sooooo0ol00003ooooo`Oo00000_ooool4o`0000Kooooo0ol00008
ooooo`;o0000>?ooool2o`0005_ooooo000Looooo`03o`000?oooooooooo05cooooo0ol0000;oooo
o`;o00003Oooool5o`0000Cooooo1Ol000000ooooooo0000o`000004ooooo`;o00000oooool=o`00
00Oooooo1Ol00005ooooo`;o0000:Oooool2o`0000kooooo0_l0001Kooooo`007?ooool00ol0003o
ooooooooo`1Kooooo`?o000000?oooooo`000?l000002Oooool2o`0000[ooooo0_l00003ooooo`Co
00000oooool2o`000004ooooool0003o0000ooooo`;o00001?ooool2o`000003ooooool0003o0000
00_o00002Oooool6o`0000Cooooo0_l0000Yooooo`;o000000?oooooo`000?l000002oooool2o`00
05_ooooo000Looooo`03o`000?oooooooooo05_ooooo0_l00002ooooo`;o00002?ooool2o`0000Wo
oooo1?l00005ooooo`;o00002Oooool2o`0000Gooooo3ol00006ooooo`?o000000?oooooo`000?l0
00000ol00002ooooo`?o00009_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o
0000I?ooool001cooooo00?o0000ooooooooool0I?ooool2o`0000?ooooo0_l00009ooooo`;o0000
2?ooool2o`0000?ooooo0_l00004ooooo`;o00001?ooool6o`0000;ooooo0_l00003ooooo`;o0000
1_ooool8o`0000;ooooo1?l0000Uooooo`Go00001_ooool3o`0006Cooooo000Looooo`03o`000?oo
oooooooo05oooooo1?l000000ooooooo0000o`00000Hooooo`?o00000_ooool2o`0000Cooooo0ol0
0004ooooo`Go00003Oooool2o`0000;ooooo1Ol00003ooooo`;o00009_ooool3o`000003ooooool0
003o000000Kooooo0ol00002ooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0GOooool:
o`0000;ooooo0_l0000;ooooo`;o00001Oooool4o`0000;ooooo0_l00004ooooo`?o00001Oooool2
o`000003ooooool0003o000000cooooo1Ol00002ooooo`;o00000_ooool2o`0002Oooooo0_l0000;
ooooo`?o000000?oooooo`000?l00000H?ooool001cooooo0_l0001Nooooo`[o00000_ooool2o`00
00?ooooo0_l00004ooooo`Co00000_ooool2o`000003ooooool0003o000000?o00002Oooool2o`00
00Gooooo1_l00008ooooo`Oo00001_ooool2o`000003ooooool0003o000003;ooooo0_l000000ooo
oooo0000o`00001Pooooo`007?ooool00ol0003oooooooooo`1Tooooo`;o00002?ooool2o`0000?o
oooo0ol00004ooooo`;o00000oooool4o`0000;ooooo0_l00004ooooo`;o00001Oooool7o`0000Go
oooo1Ol00004ooooo`Co00001Oooool2o`00027ooooo0_l0000Booooo`;o0000H?ooool001cooooo
00?o0000ooooooooool0HOooool2o`000003ooooool0003o000000gooooo0ol00002ooooo`;o0000
1_ooool7o`0000gooooo1Ol000000ooooooo0000o`000002ooooo`;o00001oooool4o`0002Sooooo
0_l00009ooooo`;o00001Oooool2o`0006;ooooo000Looooo`03o`000?oooooooooo067ooooo0_l0
0008ooooo`;o00001oooool2o`0000;ooooo1?l00004ooooo`Ko00004?ooool2o`0000;ooooo0_l0
0002ooooo`;o000000?oooooo`000?l000001ol000000ooooooo0000o`00000aooooo`;o00001Ooo
ool2o`0006;ooooo000Looooo`03o`000?oooooooooo067ooooo0_l000000ooooooo0000o`000002
ooooo`;o000000?oooooo`000?l000001oooool2o`0000Cooooo0_l00005ooooo`Co00005Oooool3
o`0000Cooooo2Ol000000ooooooo0000o`00000_ooooo`;o0000Joooool001cooooo00?o0000oooo
ooooool0I?ooool7o`0001Sooooo0ol0000Dooooo`Wo0000>Oooool2o`0006_ooooo000Looooo`03
o`000?oooooooooo06;ooooo0_l00002ooooo`Go00000_ooool2o`0001Gooooo1?l0000Cooooo`Oo
0000=Oooool2o`0000Kooooo0_l0001Xooooo`007?ooool00ol0003oooooooooo`1Rooooo`;o0000
0oooool5o`000003ooooool0003o000001Oooooo0_l00005ooooo`;o0000B?ooool2o`0000Gooooo
0ol0001Xooooo`007?ooool00ol0003oooooooooo`1Wooooo`Go00006_ooool5o`0000;ooooo0_l0
0002ooooo`;o0000Boooool2o`0006Wooooo000Looooo`03o`000?oooooooooo06Cooooo0_l0000R
ooooo`?o00001_ooool4o`000;Cooooo000Looooo`03o`000?oooooooooo06Cooooo0_l0000;oooo
o`;o00001oooool2o`0000cooooo1_l00005ooooo`;o00000_ooool2o`000;3ooooo000Looooo`03
o`000?oooooooooo06Kooooo1?l00007ooooo`;o00000oooool2o`0000;ooooo0_l00008ooooo`;o
00001?ooool6o`0000Oooooo0_l0000iooooo`;o00000_ooool2o`0000;ooooo0ol0001/ooooo`00
7?ooool00ol0003oooooooooo`1Vooooo`Go00001_ooool2o`0000?ooooo0_l0000<ooooo`;o0000
1oooool7o`0003kooooo0_l00002ooooo`;o00000_ooool3o`0006cooooo000Looooo`03o`000?oo
oooooooo06Wooooo0_l00006ooooo`;o00000_ooool2o`0000_ooooo1Ol00006ooooo`Oo000000?o
ooooo`000?l000000_l00002ooooo`;o0000<oooool2o`0000Cooooo0_l00002ooooo`;o0000KOoo
ool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o
8B4Qolc<c006ooooo`03o`000?oooooooooo077ooooo0_l00002ooooo`Co00001_ooool2o`000004
ooooool0003o0000ooooo`;o00002oooool;o`0000;ooooo0_l0000Yooooo`;o00000oooool3o`00
00Gooooo0_l0001`ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool0
1OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0Moooool2o`0000Kooooo0_l0
0009ooooo`;o00001oooool2o`000003ooooool0003o000000Co00000oooool2o`0002Wooooo0_l0
0003ooooo`;o00001_ooool2o`00073ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooo
oooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo07Oooooo0_l0
0008ooooo`;o00001oooool2o`0000kooooo1?l0000Zooooo`Co00000oooool4o`0007Kooooo0000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`?o0000M_ooool2o`0000Wooooo0_l0000Gooooo`Co000000?oooooo`000?l000002?oo
ool2o`0001gooooo0_l00005ooooo`Co0000M_ooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool02Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0M_oo
ool2o`0002Oooooo2?l00002ooooo`?o00000oooool3o`0001Gooooo0_l000000ooooooo0000o`00
0003ooooo`;o0000N?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool0
1Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0LOooool2o`0000Gooooo0_l0
0003ooooo`;o00008?ooool:o`000005ooooool0003o0000o`000?ooool01?l0000Eooooo`;o0000
00Coooooo`000?l0003o00000_ooool2o`0007Sooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMg
M`_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo077ooooo0_l00003
ooooo`Co00000oooool2o`0000Oooooo1?l00004ooooo`;o00000_ooool2o`0000gooooo0_l00000
0ooooooo0000o`000007o`000003ooooool0003o000001?ooooo0_l00004ooooo`Co00000_ooool2
o`0007Sooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@06ooooo`03o`000?oooooooooo07?ooooo1_l000000ooooooo0000o`00000:ooooo`Co0000
00Coooooo`000?l0003ooooo0_l00002ooooo`;o00005Oooool2o`0001?ooooo0_l000000ooooooo
0000o`000002o`0000Cooooo0_l0001nooooo`007?ooool00ol0003oooooooooo`1cooooo`?o0000
00Coooooo`000?l0003ooooo0ol0000>ooooo`;o00002Oooool2o`0002Kooooo0_l000000ooooooo
0000o`000026ooooo`007?ooool00ol0003oooooooooo`1cooooo`;o000000?oooooo`000?l00000
0oooool4o`0001Gooooo1?l00007ooooo`;o00007oooool2o`0008Oooooo000Looooo`03o`000?oo
oooooooo07Kooooo0_l00005ooooo`;o00003_ooool2o`0000Gooooo0_l00003ooooo`?o00000ooo
ool2o`0001Sooooo0_l00005ooooo`;o00000_ooool2o`0008?ooooo000Looooo`03o`000?oooooo
oooo07Kooooo0_l0000Eooooo`;o00002_ooool3o`0001Gooooo0_l00006ooooo`;o000000?ooooo
o`000?l000001_ooool2o`0008?ooooo000Looooo`03o`000?oooooooooo087ooooo0_l0000Boooo
o`;o00001_ooool2o`0000Wooooo0ol00006ooooo`;o00001?ooool7o`0008_ooooo000Looooo`03
o`000?oooooooooo087ooooo1?l0000@ooooo`;o000000?oooooo`000?l000000oooool2o`0000Wo
oooo0ol000000ooooooo0000o`000005o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o
0000ROooool001cooooo00?o0000ooooooooool0Poooool2o`0001?ooooo0_l00004ooooo`;o0000
3?ooool7o`0000_ooooo0_l00029ooooo`007?ooool00ol0003oooooooooo`25ooooo`Co00005Ooo
ool2o`0000;ooooo0_l0000<ooooo`;o00001_ooool2o`0008oooooo000Looooo`03o`000?oooooo
oooo08Gooooo1?l00002ooooo`;o00005?ooool4o`00017ooooo1?l0002?ooooo`007?ooool00ol0
003oooooooooo`27ooooo`?o000000?oooooo`000?l000005?ooool4o`000003ooooool0003o0000
00;ooooo0_l0000:ooooo`;o0000TOooool001cooooo00?o0000ooooooooool0R?ooool2o`0000?o
oooo0_l0000Gooooo`;o00000_ooool2o`0009gooooo000Looooo`;o0000SOooool3o`000;[ooooo
000Looooo`03o`000?oooooooooo08cooooo0_l0002kooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo09Oooooo0_l0002`ooooo`007?ooool00ol0003o
ooooooooo`2Gooooo`;o0000/?ooool001cooooo00?o0000ooooooooool0Uoooool2o`000;3ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Booooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooood[ooooo000D
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0
003oooooooooo`05ooooo`?o0000oooooom:ooooo`005?ooool00ol0003oooooooooo`3ooooooe;o
oooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooo
oomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Booooo`03oeEEEOmVIVKo0000
0?ooooooE?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Gooooo00Co410@
o`000?l0003ooooo0_l000000ol@413oooooooooo`0Eooooo`Go00001?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00;ooooo1Ol0002@ooooo`00Y_ooool01Ol0003ooooooooooooooooo000000Wooooo
1_l00009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool02OmgMgOo<S8booooooooooooV9RH
ob4Q8Oo^k^koooooodA4A02@ooooo`00Y_ooool01Ol0003ooooooooooooooooo000001Wooooo00?o
V9RHob4Q8Oo^k^h02Oooool01ol0003oooooooooooooooooV9RHob4Q8Oo^k^h0TOooool00:Kooooo
00Go0000ooooooooooooooooo`000009ooooo`Ko00002oooool00onHV9So8B4Qonk^kP07ooooo`03
ogMgMolb<S;ooooo00?ooooo00?oV9RHob4Q8Oo^k^h0T?ooool00:Kooooo00Go0000ohN7Qooooooo
ZJVYo`00000Kooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005oooo
o`03ogMgMomVIVKooooo08oooooo002Uooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHoooooooo
ool06_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0S_ooool00<?ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Co
oooo00Go0000okZj^_ooooooV9RHoa0@402@ooooo`00`oooool01OnHV9So410@o`000?lQ8B7oc<c<
00Cooooo1?l00003ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0T?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(258) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.62885 .40717 Mdot
.63255 .37768 Mdot
.24771 .45157 Mdot
.63607 .6048 Mdot
.37189 .56157 Mdot
.28044 .41247 Mdot
.4319 .32007 Mdot
.42324 .31541 Mdot
.31299 .45045 Mdot
.72873 .62906 Mdot
.42095 .3429 Mdot
.56812 .56998 Mdot
.43961 .30867 Mdot
.60499 .60073 Mdot
.4481 .691 Mdot
.64413 .62181 Mdot
.65549 .38905 Mdot
.33963 .60774 Mdot
.65027 .61707 Mdot
.33279 .42731 Mdot
.53287 .5069 Mdot
.60605 .58903 Mdot
.6012 .37154 Mdot
.6023 .5987 Mdot
.6609 .58102 Mdot
.63935 .36786 Mdot
.6276 .40699 Mdot
.61852 .56253 Mdot
.64505 .5986 Mdot
.45697 .33205 Mdot
.52165 .63889 Mdot
.45628 .79826 Mdot
.43821 .53809 Mdot
.76139 .49806 Mdot
.46335 .32226 Mdot
.47965 .29188 Mdot
.25323 .42948 Mdot
.46967 .3144 Mdot
.40679 .341 Mdot
.41484 .33254 Mdot
.41727 .33393 Mdot
.64241 .36843 Mdot
.46444 .29664 Mdot
.26367 .30034 Mdot
.59164 .59841 Mdot
.76883 .39005 Mdot
.29662 .47046 Mdot
.59975 .56771 Mdot
.61099 .35628 Mdot
.31696 .454 Mdot
.35099 .69378 Mdot
.41915 .30853 Mdot
.46937 .54622 Mdot
.73312 .24308 Mdot
.42986 .31152 Mdot
.66573 .59831 Mdot
.30561 .43223 Mdot
.5852 .61759 Mdot
.56122 .58622 Mdot
.74735 .45743 Mdot
.59606 .62182 Mdot
.34459 .59123 Mdot
.66317 .32646 Mdot
.31345 .46097 Mdot
.30234 .45566 Mdot
.46736 .30057 Mdot
.66632 .36771 Mdot
.45884 .3144 Mdot
.64025 .59588 Mdot
.32498 .43413 Mdot
.65326 .58796 Mdot
.42242 .34298 Mdot
.62852 .4031 Mdot
.60909 .58319 Mdot
.58582 .31373 Mdot
.44734 .26413 Mdot
.31835 .60569 Mdot
.65007 .44204 Mdot
.34791 .41267 Mdot
.46217 .6764 Mdot
.60729 .58453 Mdot
.41625 .19284 Mdot
.41805 .72391 Mdot
.60841 .37381 Mdot
.6322 .64077 Mdot
.50839 .20632 Mdot
.63549 .57202 Mdot
.52146 .63258 Mdot
.56435 .56396 Mdot
.3573 .64155 Mdot
.30848 .42763 Mdot
.63045 .34442 Mdot
.59454 .58717 Mdot
.63004 .58572 Mdot
.75147 .60401 Mdot
.64655 .60779 Mdot
.60449 .56049 Mdot
.42582 .56245 Mdot
.41107 .31273 Mdot
.46205 .53496 Mdot
.36991 .4006 Mdot
.48946 .54267 Mdot
.65077 .58265 Mdot
.28738 .42224 Mdot
.65839 .32472 Mdot
.46049 .53149 Mdot
.45693 .32097 Mdot
.59745 .58912 Mdot
.3806 .3177 Mdot
.60724 .36154 Mdot
.66165 .57403 Mdot
.3628 .58149 Mdot
.4945 .47335 Mdot
.61498 .40169 Mdot
.81449 .51076 Mdot
.62648 .60752 Mdot
.57095 .59887 Mdot
.6354 .37835 Mdot
.32643 .41729 Mdot
.36552 .23102 Mdot
.63846 .39587 Mdot
.40796 .3215 Mdot
.6604 .38005 Mdot
.42057 .5548 Mdot
.33246 .42053 Mdot
.48401 .56089 Mdot
.45572 .56694 Mdot
.40976 .77011 Mdot
.63006 .61376 Mdot
.53562 .52782 Mdot
.27853 .42026 Mdot
.63409 .39508 Mdot
.44547 .30294 Mdot
.57009 .62184 Mdot
.62652 .35967 Mdot
.42724 .32084 Mdot
.32172 .59065 Mdot
.35699 .60567 Mdot
.60776 .39096 Mdot
.81936 .49784 Mdot
.41581 .29039 Mdot
.4246 .29333 Mdot
.35311 .69547 Mdot
.6085 .37561 Mdot
.33601 .57993 Mdot
.45052 .32283 Mdot
.18336 .58785 Mdot
.6711 .58616 Mdot
.36481 .72688 Mdot
.42104 .1965 Mdot
.35092 .69293 Mdot
.54683 .51759 Mdot
.35356 .57634 Mdot
.4268 .32109 Mdot
.59493 .57416 Mdot
.615 .3778 Mdot
.62917 .36077 Mdot
.64776 .58658 Mdot
.48157 .53194 Mdot
.6039 .6098 Mdot
.44641 .53911 Mdot
.47622 .56898 Mdot
.59408 .59043 Mdot
.78205 .35775 Mdot
.61528 .36238 Mdot
.61151 .64125 Mdot
.25696 .43227 Mdot
.50807 .53792 Mdot
.46207 .29571 Mdot
.57246 .61856 Mdot
.66802 .61936 Mdot
.56142 .5717 Mdot
.40961 .30134 Mdot
.63772 .274 Mdot
.34825 .41947 Mdot
.41091 .33638 Mdot
.37071 .36545 Mdot
.27202 .4324 Mdot
.56928 .5783 Mdot
.36436 .57238 Mdot
.45322 .54423 Mdot
.61129 .57784 Mdot
.34707 .68905 Mdot
.56237 .58654 Mdot
.56514 .51346 Mdot
.56709 .53086 Mdot
.47244 .21032 Mdot
.6522 .28417 Mdot
.63489 .59691 Mdot
.68612 .55036 Mdot
.36452 .71699 Mdot
.4972 .30909 Mdot
.44845 .30257 Mdot
.30165 .409 Mdot
.31801 .41363 Mdot
.39737 .27053 Mdot
.79379 .51423 Mdot
.72544 .65571 Mdot
.5905 .62931 Mdot
.4824 .54322 Mdot
.64405 .41166 Mdot
.35125 .57749 Mdot
.61585 .3967 Mdot
.4083 .19057 Mdot
.48808 .66877 Mdot
.53269 .66935 Mdot
.2347 .39153 Mdot
.30117 .46107 Mdot
.49108 .54592 Mdot
.33636 .57383 Mdot
.58766 .60987 Mdot
.60643 .36693 Mdot
.36166 .70998 Mdot
.49482 .53685 Mdot
.65467 .80217 Mdot
.64261 .39682 Mdot
.49132 .73565 Mdot
.43264 .31208 Mdot
.29156 .44699 Mdot
.63975 .57365 Mdot
.61909 .59991 Mdot
.616 .34561 Mdot
.58333 .5746 Mdot
.54907 .69267 Mdot
.66638 .58234 Mdot
.3342 .4384 Mdot
.36023 .44146 Mdot
.40287 .33388 Mdot
.24141 .39133 Mdot
.61465 .40274 Mdot
.79179 .34017 Mdot
.28763 .43383 Mdot
.56217 .52347 Mdot
.42826 .34208 Mdot
.3256 .59393 Mdot
.29325 .42906 Mdot
.37669 .56521 Mdot
.5579 .60176 Mdot
.26573 .44196 Mdot
.3549 .58879 Mdot
.54682 .65589 Mdot
.46324 .53137 Mdot
.35657 .76193 Mdot
.43662 .32512 Mdot
.64957 .35208 Mdot
.60542 .57573 Mdot
.46842 .54178 Mdot
.4963 .53684 Mdot
.46894 .72319 Mdot
.45998 .56448 Mdot
.49745 .54447 Mdot
.42233 .67007 Mdot
.32794 .60333 Mdot
.59176 .22117 Mdot
.51797 .62107 Mdot
.65426 .39124 Mdot
.62431 .5833 Mdot
.37198 .32517 Mdot
.42789 .32409 Mdot
.5905 .61414 Mdot
.45752 .20603 Mdot
.44876 .32133 Mdot
.5753 .60607 Mdot
.41708 .34605 Mdot
.61802 .36477 Mdot
.50048 .69406 Mdot
.643 .40161 Mdot
.58892 .59024 Mdot
.42028 .34565 Mdot
.29563 .40748 Mdot
.63798 .36666 Mdot
.60076 .5883 Mdot
.60855 .62345 Mdot
.47873 .54495 Mdot
.66864 .58432 Mdot
.4832 .27314 Mdot
.60729 .56696 Mdot
.23732 .44019 Mdot
.64632 .60447 Mdot
.40449 .56152 Mdot
.25414 .61819 Mdot
.60673 .38515 Mdot
.46126 .56411 Mdot
.29989 .43031 Mdot
.55582 .68526 Mdot
.49879 .73806 Mdot
.59504 .59843 Mdot
.47517 .55995 Mdot
.45622 .76284 Mdot
.43409 .29346 Mdot
.56559 .563 Mdot
.37851 .61979 Mdot
.30505 .42481 Mdot
.48743 .54391 Mdot
.63307 .63747 Mdot
.60545 .41981 Mdot
.651 .61457 Mdot
.27218 .44195 Mdot
.65426 .38657 Mdot
.65367 .60386 Mdot
.48218 .28527 Mdot
.51107 .54926 Mdot
.41721 .29887 Mdot
.52671 .58879 Mdot
.57393 .57568 Mdot
.32494 .43672 Mdot
.64371 .36503 Mdot
.4266 .31248 Mdot
.61872 .4036 Mdot
.36218 .67437 Mdot
.47452 .74781 Mdot
.61743 .3068 Mdot
.31779 .58815 Mdot
.20721 .63392 Mdot
.40791 .3264 Mdot
.43882 .54936 Mdot
.23336 .45015 Mdot
.62405 .43744 Mdot
.29211 .42194 Mdot
.81891 .48362 Mdot
.30844 .43 Mdot
.66333 .60818 Mdot
.31011 .41619 Mdot
.7599 .62825 Mdot
.56438 .60308 Mdot
.2917 .45893 Mdot
.42615 .5639 Mdot
.57096 .61384 Mdot
.62772 .35869 Mdot
.48799 .81181 Mdot
.77887 .51089 Mdot
.79128 .52162 Mdot
.30235 .43551 Mdot
.81974 .47244 Mdot
.66139 .57528 Mdot
.54073 .57493 Mdot
.61898 .37725 Mdot
.44126 .54748 Mdot
.37002 .59571 Mdot
.38321 .58345 Mdot
.27965 .65942 Mdot
.51558 .76142 Mdot
.80784 .52162 Mdot
.62902 .36351 Mdot
.35568 .43784 Mdot
.58841 .31257 Mdot
.49649 .53879 Mdot
.42302 .31565 Mdot
.62567 .26858 Mdot
.56064 .56727 Mdot
.51091 .5643 Mdot
.5512 .6939 Mdot
.6518 .35821 Mdot
.63479 .31154 Mdot
.42536 .31373 Mdot
.79167 .52443 Mdot
.72057 .63673 Mdot
.60145 .61085 Mdot
.42255 .32582 Mdot
.49505 .53622 Mdot
.52386 .63257 Mdot
.41105 .77655 Mdot
.19979 .37994 Mdot
.5883 .59432 Mdot
.59206 .28799 Mdot
.60721 .57675 Mdot
.39922 .76229 Mdot
.58442 .60912 Mdot
.64076 .35957 Mdot
.63329 .56312 Mdot
.52254 .61987 Mdot
.15716 .50934 Mdot
.48269 .66426 Mdot
.37252 .5658 Mdot
.60683 .59851 Mdot
.61175 .61047 Mdot
.33161 .58875 Mdot
.63995 .3501 Mdot
.62812 .57905 Mdot
.6078 .22636 Mdot
.59694 .58584 Mdot
.4603 .29625 Mdot
.44629 .71353 Mdot
.45182 .79474 Mdot
.66034 .57597 Mdot
.60568 .42057 Mdot
.42138 .29511 Mdot
.43617 .33882 Mdot
.44976 .55951 Mdot
.42847 .32517 Mdot
.58663 .57688 Mdot
.44698 .71499 Mdot
.66747 .35865 Mdot
.48741 .53535 Mdot
.64849 .35634 Mdot
.22591 .47877 Mdot
.436 .32319 Mdot
.47105 .55335 Mdot
.79418 .50016 Mdot
.4514 .31377 Mdot
.35863 .48522 Mdot
.65135 .5689 Mdot
.4973 .53823 Mdot
.61526 .41207 Mdot
.32367 .43289 Mdot
.49413 .5526 Mdot
.4289 .31218 Mdot
.59321 .59899 Mdot
.66776 .59305 Mdot
.4279 .32581 Mdot
.68549 .42139 Mdot
.52061 .63694 Mdot
.59089 .58562 Mdot
.62694 .35423 Mdot
.63919 .39006 Mdot
.5915 .63374 Mdot
.61107 .57591 Mdot
.28027 .41105 Mdot
.4742 .56053 Mdot
.47639 .56079 Mdot
.46196 .56726 Mdot
.29958 .44125 Mdot
.18581 .61057 Mdot
.44198 .289 Mdot
.45569 .79666 Mdot
.54033 .3196 Mdot
.46472 .54491 Mdot
.26976 .4113 Mdot
.62293 .60402 Mdot
.62828 .57241 Mdot
.43254 .34541 Mdot
.27424 .72227 Mdot
.54188 .57915 Mdot
.64467 .39908 Mdot
.41922 .31959 Mdot
.67416 .61737 Mdot
.37715 .29304 Mdot
.36791 .59059 Mdot
.81145 .51722 Mdot
.41909 .31554 Mdot
.64375 .33271 Mdot
.41886 .31467 Mdot
.61022 .60993 Mdot
.62852 .63865 Mdot
.65454 .36569 Mdot
.36724 .56162 Mdot
.64306 .58531 Mdot
.5766 .60446 Mdot
.36377 .38576 Mdot
.58011 .32086 Mdot
.38936 .56711 Mdot
.61851 .57168 Mdot
.42779 .5525 Mdot
.35424 .55982 Mdot
.58371 .58301 Mdot
.65108 .59769 Mdot
.53955 .52646 Mdot
.47018 .32502 Mdot
.3196 .5756 Mdot
.15384 .53301 Mdot
.64096 .39844 Mdot
.48895 .27872 Mdot
.50259 .55113 Mdot
.40889 .32732 Mdot
.57419 .70115 Mdot
.48263 .55156 Mdot
.5524 .29778 Mdot
.87283 .5726 Mdot
.49119 .55264 Mdot
.25563 .41526 Mdot
.75818 .59167 Mdot
.64976 .59565 Mdot
.58872 .58597 Mdot
.3658 .5984 Mdot
.6311 .38695 Mdot
.65071 .28352 Mdot
.41053 .33733 Mdot
.62362 .59375 Mdot
.61151 .40429 Mdot
.48283 .20754 Mdot
.48184 .54734 Mdot
.37189 .57892 Mdot
.32246 .57652 Mdot
.59502 .57903 Mdot
.47736 .76201 Mdot
.63685 .36441 Mdot
.60058 .58844 Mdot
.57006 .59208 Mdot
.27869 .40491 Mdot
.60641 .37619 Mdot
.2652 .4391 Mdot
.52943 .58394 Mdot
.78843 .6013 Mdot
.37132 .3597 Mdot
.4455 .32469 Mdot
.46082 .55986 Mdot
.40208 .33378 Mdot
.27915 .46837 Mdot
.47394 .56087 Mdot
.6019 .58919 Mdot
.66759 .35431 Mdot
.59929 .58806 Mdot
.59599 .58611 Mdot
.58976 .60133 Mdot
.80901 .52197 Mdot
.34884 .41219 Mdot
.36939 .57373 Mdot
.58529 .56847 Mdot
.28085 .4444 Mdot
.37759 .2858 Mdot
.73588 .62192 Mdot
.61225 .59763 Mdot
.57175 .5999 Mdot
.61173 .42271 Mdot
.67202 .58802 Mdot
.44782 .31697 Mdot
.65354 .36006 Mdot
.65348 .58306 Mdot
.35232 .39327 Mdot
.62271 .57619 Mdot
.62628 .30781 Mdot
.45616 .29728 Mdot
.68887 .62983 Mdot
.48679 .52986 Mdot
.46956 .56211 Mdot
.49406 .55165 Mdot
.4661 .56734 Mdot
.46378 .29808 Mdot
.25586 .41656 Mdot
.21626 .40469 Mdot
.53884 .59373 Mdot
.59286 .57358 Mdot
.62997 .63905 Mdot
.24176 .4181 Mdot
.42302 .56442 Mdot
.81007 .48557 Mdot
.67869 .61326 Mdot
.30022 .44775 Mdot
.43623 .56543 Mdot
.63404 .45932 Mdot
.64743 .35189 Mdot
.32901 .45308 Mdot
.44451 .33837 Mdot
.35679 .59078 Mdot
.31051 .7078 Mdot
.6474 .38297 Mdot
.6399 .42017 Mdot
.26381 .42472 Mdot
.44951 .72976 Mdot
.72788 .23235 Mdot
.28709 .41676 Mdot
.53774 .67709 Mdot
.62026 .37131 Mdot
.44001 .53967 Mdot
.44903 .75933 Mdot
.44245 .72085 Mdot
.30062 .45321 Mdot
.61075 .62294 Mdot
.21055 .45297 Mdot
.28532 .40995 Mdot
.44724 .55269 Mdot
.30078 .43676 Mdot
.42638 .29452 Mdot
.28026 .42359 Mdot
.59453 .38576 Mdot
.63329 .60936 Mdot
.7311 .23959 Mdot
.40946 .69593 Mdot
.63219 .60097 Mdot
.43351 .29551 Mdot
.48804 .29668 Mdot
.59872 .61346 Mdot
.38008 .58331 Mdot
.25385 .41655 Mdot
.32239 .4863 Mdot
.65763 .61098 Mdot
.31333 .4187 Mdot
.61087 .42791 Mdot
.34495 .46364 Mdot
.37019 .39736 Mdot
.49102 .55485 Mdot
.61499 .36795 Mdot
.44188 .26396 Mdot
.40786 .32034 Mdot
.51346 .54933 Mdot
.56826 .58525 Mdot
.61724 .35683 Mdot
.55393 .67444 Mdot
.55232 .54776 Mdot
.59949 .58581 Mdot
.26534 .43525 Mdot
.32327 .45085 Mdot
.44367 .69288 Mdot
.28733 .43569 Mdot
.44621 .55401 Mdot
.62133 .35727 Mdot
.65323 .61492 Mdot
.63811 .39383 Mdot
.62347 .58195 Mdot
.3776 .29889 Mdot
.63567 .34389 Mdot
.56241 .52373 Mdot
.59564 .62639 Mdot
.77858 .3658 Mdot
.58384 .56722 Mdot
.59281 .58516 Mdot
.33191 .43625 Mdot
.33136 .58595 Mdot
.53635 .55324 Mdot
.38479 .28014 Mdot
.3479 .59571 Mdot
.6673 .44236 Mdot
.32811 .41762 Mdot
.32612 .59185 Mdot
.28281 .6745 Mdot
.46374 .56428 Mdot
.33899 .566 Mdot
.62593 .6417 Mdot
.44272 .32708 Mdot
.66412 .34383 Mdot
.5712 .61484 Mdot
.78206 .60446 Mdot
.51851 .6328 Mdot
.4766 .54727 Mdot
.58407 .58626 Mdot
.61949 .60958 Mdot
.61244 .40459 Mdot
.40941 .19225 Mdot
.2577 .46041 Mdot
.45059 .53943 Mdot
.64561 .38989 Mdot
.41911 .19378 Mdot
.29093 .45782 Mdot
.34389 .60473 Mdot
.40253 .33936 Mdot
.63285 .3203 Mdot
.47258 .54512 Mdot
.43303 .32314 Mdot
.22506 .42162 Mdot
.34667 .68434 Mdot
.65032 .61405 Mdot
.25587 .42205 Mdot
.35014 .69201 Mdot
.64823 .56731 Mdot
.40005 .26766 Mdot
.49732 .31873 Mdot
.6142 .35401 Mdot
.42605 .32533 Mdot
.37413 .57363 Mdot
.65783 .39059 Mdot
.64795 .35499 Mdot
.4524 .31878 Mdot
.82162 .41728 Mdot
.45683 .76183 Mdot
.40939 .34699 Mdot
.46967 .71391 Mdot
.35005 .68949 Mdot
.47496 .54332 Mdot
.36693 .57481 Mdot
.36082 .44028 Mdot
.64206 .36884 Mdot
.62138 .27236 Mdot
.35019 .69386 Mdot
.63718 .56569 Mdot
.35244 .59047 Mdot
.48644 .21077 Mdot
.40307 .29405 Mdot
.44244 .32065 Mdot
.36446 .38498 Mdot
.34107 .59305 Mdot
.57557 .62183 Mdot
.2932 .75713 Mdot
.56492 .59963 Mdot
.44989 .32426 Mdot
.55039 .69341 Mdot
.61841 .39398 Mdot
.44772 .29138 Mdot
.5484 .69297 Mdot
.61841 .57099 Mdot
.62432 .61137 Mdot
.34825 .4079 Mdot
.62349 .34138 Mdot
.5061 .54547 Mdot
.63279 .59818 Mdot
.57923 .61195 Mdot
.47017 .52875 Mdot
.44375 .78965 Mdot
.50856 .46708 Mdot
.44698 .53408 Mdot
.2795 .45112 Mdot
.48302 .53329 Mdot
.44945 .54086 Mdot
.60937 .41517 Mdot
.36639 .40607 Mdot
.50171 .54353 Mdot
.58558 .592 Mdot
.58931 .58843 Mdot
.40499 .3416 Mdot
.4552 .76232 Mdot
.44497 .72812 Mdot
.23992 .44922 Mdot
.36325 .61636 Mdot
.61845 .62432 Mdot
.61154 .37028 Mdot
.33771 .55605 Mdot
.44452 .55813 Mdot
.6464 .39651 Mdot
.63894 .60559 Mdot
.27478 .40478 Mdot
.48628 .55473 Mdot
.42026 .55118 Mdot
.35319 .58601 Mdot
.39887 .33016 Mdot
.66606 .43634 Mdot
.27695 .40974 Mdot
.66051 .58213 Mdot
.36918 .61824 Mdot
.30928 .4203 Mdot
.47689 .54258 Mdot
.4738 .53204 Mdot
.62103 .3638 Mdot
.63378 .33196 Mdot
.41447 .56701 Mdot
.29361 .44291 Mdot
.22127 .34997 Mdot
.41368 .31555 Mdot
.57837 .57292 Mdot
.40232 .31981 Mdot
.6045 .36513 Mdot
.40839 .7702 Mdot
.32299 .58446 Mdot
.44741 .3195 Mdot
.49487 .53786 Mdot
.6432 .34845 Mdot
.605 .36118 Mdot
.59303 .59129 Mdot
.6083 .59205 Mdot
.32612 .46142 Mdot
.36669 .72468 Mdot
.42905 .34626 Mdot
.35395 .60127 Mdot
.24731 .45329 Mdot
.66313 .60354 Mdot
.61221 .38466 Mdot
.39727 .80144 Mdot
.57569 .57327 Mdot
.28432 .4436 Mdot
.63181 .37546 Mdot
.36726 .59646 Mdot
.36868 .5709 Mdot
.6266 .58915 Mdot
.54776 .51868 Mdot
.45373 .31362 Mdot
.63165 .35806 Mdot
.68217 .36083 Mdot
.5927 .56653 Mdot
.60863 .59592 Mdot
.65275 .5686 Mdot
.40704 .34761 Mdot
.60039 .63766 Mdot
.36765 .56247 Mdot
.61144 .39703 Mdot
.62638 .59183 Mdot
.33903 .59101 Mdot
.4913 .56178 Mdot
.48195 .55369 Mdot
.31478 .45222 Mdot
.38119 .5837 Mdot
.33689 .58496 Mdot
.3485 .59751 Mdot
.62503 .26827 Mdot
.6101 .64542 Mdot
.41829 .5772 Mdot
.60896 .62407 Mdot
.35005 .68832 Mdot
.63621 .62616 Mdot
.41925 .30291 Mdot
.3242 .43873 Mdot
.59451 .60551 Mdot
.60562 .62492 Mdot
.65298 .44453 Mdot
.65008 .61969 Mdot
.5885 .63186 Mdot
.61552 .39365 Mdot
.6787 .38257 Mdot
.31236 .41207 Mdot
.42469 .1979 Mdot
.34727 .80784 Mdot
.56147 .61383 Mdot
.4493 .72575 Mdot
.63826 .34792 Mdot
.40357 .34028 Mdot
.46644 .72461 Mdot
.40124 .31283 Mdot
.63807 .3865 Mdot
.66152 .61176 Mdot
.69546 .39295 Mdot
.34785 .59415 Mdot
.60751 .60909 Mdot
.45657 .30919 Mdot
.60574 .60953 Mdot
.44546 .2925 Mdot
.8126 .45694 Mdot
.42602 .74036 Mdot
.56131 .59648 Mdot
.64688 .60691 Mdot
.5252 .50597 Mdot
.61067 .59528 Mdot
.20335 .4112 Mdot
.62674 .37589 Mdot
.51331 .54481 Mdot
.66364 .61169 Mdot
.7772 .51535 Mdot
.57591 .5895 Mdot
.59454 .70647 Mdot
.57439 .61287 Mdot
.26103 .69924 Mdot
.55837 .59883 Mdot
.56621 .58855 Mdot
.44131 .29902 Mdot
.4163 .33983 Mdot
.6155 .43396 Mdot
.48948 .5386 Mdot
.47867 .20988 Mdot
.57483 .60223 Mdot
.27743 .46326 Mdot
.59996 .52201 Mdot
.33489 .58654 Mdot
.61843 .40055 Mdot
.90113 .53044 Mdot
.46186 .29315 Mdot
.26223 .44367 Mdot
.52705 .6533 Mdot
.27149 .44798 Mdot
.30912 .46388 Mdot
.68617 .34157 Mdot
.36759 .57594 Mdot
.62051 .57622 Mdot
.76293 .49026 Mdot
.57864 .31617 Mdot
.59408 .5666 Mdot
.24179 .40886 Mdot
.53948 .52892 Mdot
.46857 .60564 Mdot
.33071 .60613 Mdot
.34593 .57518 Mdot
.42976 .31577 Mdot
.27371 .46175 Mdot
.45529 .53776 Mdot
.32494 .59081 Mdot
.31319 .4141 Mdot
.45807 .5627 Mdot
.36372 .4116 Mdot
.63677 .36332 Mdot
.81977 .47561 Mdot
.77151 .38638 Mdot
.41337 .30226 Mdot
.38713 .27511 Mdot
.66758 .35054 Mdot
.64704 .39993 Mdot
.48257 .53902 Mdot
.30494 .44707 Mdot
.65865 .33776 Mdot
.62911 .59262 Mdot
.48338 .53372 Mdot
.59967 .57739 Mdot
.33438 .60554 Mdot
.57957 .59058 Mdot
.31212 .41511 Mdot
.4442 .29762 Mdot
.30434 .42646 Mdot
.4296 .31939 Mdot
.46775 .80359 Mdot
.59251 .62706 Mdot
.60581 .59593 Mdot
.44661 .71563 Mdot
.60335 .37846 Mdot
.75999 .50684 Mdot
.29122 .44203 Mdot
.30454 .43138 Mdot
.66171 .61361 Mdot
.66266 .37509 Mdot
.40171 .58442 Mdot
.46896 .70531 Mdot
.57242 .60962 Mdot
.62661 .37762 Mdot
.65392 .62193 Mdot
.46573 .24415 Mdot
.4182 .71644 Mdot
.60166 .38691 Mdot
.15759 .50479 Mdot
.58159 .62349 Mdot
.43769 .54779 Mdot
.53365 .53605 Mdot
.49031 .76644 Mdot
.54758 .54779 Mdot
.64384 .39653 Mdot
.45741 .53538 Mdot
.61245 .38045 Mdot
.30242 .41785 Mdot
.44917 .29084 Mdot
.61718 .38173 Mdot
.58183 .62113 Mdot
.34735 .80709 Mdot
.45594 .30056 Mdot
.60549 .60658 Mdot
.46015 .31187 Mdot
.65264 .3235 Mdot
.62616 .39279 Mdot
.45763 .56254 Mdot
.53673 .67588 Mdot
.45137 .31664 Mdot
.58845 .57447 Mdot
.61354 .28557 Mdot
.64997 .61539 Mdot
.36248 .61253 Mdot
.63301 .61881 Mdot
.63962 .60631 Mdot
.16663 .58597 Mdot
.56069 .68315 Mdot
.37091 .34957 Mdot
.41128 .35968 Mdot
.6408 .27448 Mdot
.60968 .41122 Mdot
.34458 .60699 Mdot
.63846 .44664 Mdot
.47599 .56185 Mdot
.27995 .45238 Mdot
.59333 .60187 Mdot
.47468 .56698 Mdot
.43091 .34779 Mdot
.33699 .56804 Mdot
.56243 .58644 Mdot
.2452 .43536 Mdot
.4308 .55934 Mdot
.43716 .32214 Mdot
.64344 .37015 Mdot
.62636 .39841 Mdot
.36194 .4247 Mdot
.62761 .59341 Mdot
.60556 .59057 Mdot
.4637 .31472 Mdot
.55885 .52943 Mdot
.35576 .59688 Mdot
.42613 .56397 Mdot
.46037 .31653 Mdot
.41772 .7184 Mdot
.62326 .34094 Mdot
.62169 .60692 Mdot
.44482 .70926 Mdot
.6487 .27995 Mdot
.71493 .55992 Mdot
.34644 .57906 Mdot
.49242 .74559 Mdot
.64376 .39635 Mdot
.44315 .30259 Mdot
.28005 .66515 Mdot
.6624 .57295 Mdot
.60841 .61655 Mdot
.50002 .74436 Mdot
.4702 .70658 Mdot
.52878 .65496 Mdot
.50336 .54261 Mdot
.44963 .75291 Mdot
.65985 .61616 Mdot
.66525 .59018 Mdot
.61413 .62582 Mdot
.6357 .61747 Mdot
.62384 .38403 Mdot
.789 .53038 Mdot
.26906 .42524 Mdot
.68443 .5385 Mdot
.33333 .61167 Mdot
.62991 .56458 Mdot
.64232 .57899 Mdot
.6657 .4858 Mdot
.51976 .72063 Mdot
.62716 .36902 Mdot
.60027 .40406 Mdot
.40945 .30744 Mdot
.64741 .61865 Mdot
.28853 .44329 Mdot
.52485 .55164 Mdot
.32013 .43975 Mdot
.62577 .38283 Mdot
.29859 .40488 Mdot
.45798 .28799 Mdot
.25524 .4225 Mdot
.29348 .44985 Mdot
.43692 .29687 Mdot
.63434 .33999 Mdot
.58131 .56746 Mdot
.43627 .29665 Mdot
.40256 .57751 Mdot
.34596 .60564 Mdot
.65541 .41379 Mdot
.4421 .53725 Mdot
.5586 .56936 Mdot
.24138 .33024 Mdot
.25248 .42932 Mdot
.50446 .70821 Mdot
.63178 .34187 Mdot
.31838 .57029 Mdot
.61761 .38533 Mdot
.41334 .56895 Mdot
.34697 .58237 Mdot
.63114 .6409 Mdot
.33946 .73824 Mdot
.49539 .3266 Mdot
.57645 .56293 Mdot
.67933 .38037 Mdot
.31915 .4386 Mdot
.43749 .29383 Mdot
.42028 .23136 Mdot
.44977 .53936 Mdot
.6128 .43029 Mdot
.62041 .33181 Mdot
.47586 .56129 Mdot
.44635 .30332 Mdot
.76911 .37552 Mdot
.63051 .59884 Mdot
.40429 .31539 Mdot
.63266 .61866 Mdot
.8163 .50568 Mdot
.30352 .60313 Mdot
.47065 .56846 Mdot
.66318 .60939 Mdot
.29005 .45764 Mdot
.66183 .6128 Mdot
.79046 .57898 Mdot
.38369 .75192 Mdot
.60101 .62881 Mdot
.50608 .72439 Mdot
.26075 .46475 Mdot
.6101 .38131 Mdot
.46029 .55202 Mdot
.47667 .54455 Mdot
.67268 .59598 Mdot
.451 .86169 Mdot
.32727 .58132 Mdot
.27627 .38117 Mdot
.58727 .62362 Mdot
.60753 .58516 Mdot
.65906 .44361 Mdot
.81097 .45772 Mdot
.425 .55863 Mdot
.60125 .61829 Mdot
.52104 .7365 Mdot
.43019 .30384 Mdot
.65138 .60618 Mdot
.60246 .57885 Mdot
.33942 .47304 Mdot
.44181 .30004 Mdot
.28206 .40649 Mdot
.46658 .56402 Mdot
.3275 .44343 Mdot
.37119 .56173 Mdot
.49312 .73579 Mdot
.42737 .78087 Mdot
.42173 .71105 Mdot
.38131 .57864 Mdot
.6646 .57867 Mdot
.53257 .59691 Mdot
.62292 .61573 Mdot
.34402 .57349 Mdot
.45575 .33337 Mdot
.62412 .37845 Mdot
.82064 .49187 Mdot
.47935 .54347 Mdot
.63415 .56837 Mdot
.31042 .59079 Mdot
.61571 .37617 Mdot
.78299 .35444 Mdot
.62975 .3863 Mdot
.43911 .31842 Mdot
.3973 .26891 Mdot
.34497 .5864 Mdot
.61717 .3856 Mdot
.33006 .43785 Mdot
.40489 .27047 Mdot
.69037 .59601 Mdot
.45927 .28857 Mdot
.6099 .34642 Mdot
.59967 .38928 Mdot
.6682 .36815 Mdot
.66666 .60334 Mdot
.50585 .71848 Mdot
.45723 .55894 Mdot
.46159 .3074 Mdot
.25868 .4482 Mdot
.37067 .73134 Mdot
.75139 .41306 Mdot
.42835 .73119 Mdot
.63356 .63892 Mdot
.58061 .5904 Mdot
.59182 .5804 Mdot
.46476 .52819 Mdot
.52999 .60509 Mdot
.603 .62701 Mdot
.43265 .34551 Mdot
.29894 .41249 Mdot
.58396 .61937 Mdot
.47536 .55636 Mdot
.47521 .57436 Mdot
.32187 .56791 Mdot
.81401 .51929 Mdot
.65275 .41779 Mdot
.61691 .37783 Mdot
.27299 .44143 Mdot
.32948 .41709 Mdot
.3227 .59188 Mdot
.42257 .31906 Mdot
.63223 .38726 Mdot
.25768 .69101 Mdot
.35397 .5945 Mdot
.58479 .59411 Mdot
.44618 .71422 Mdot
.5174 .7495 Mdot
.64789 .58967 Mdot
.58871 .60191 Mdot
.496 .54077 Mdot
.28652 .44502 Mdot
.74254 .64274 Mdot
.78079 .35959 Mdot
.33909 .58914 Mdot
.33831 .60112 Mdot
.66571 .37664 Mdot
.57527 .57909 Mdot
.45541 .31368 Mdot
.45975 .76389 Mdot
.48918 .29243 Mdot
.51293 .20823 Mdot
.21887 .43634 Mdot
.61958 .57503 Mdot
.7669 .56236 Mdot
.54865 .5733 Mdot
.65955 .32606 Mdot
.64521 .33544 Mdot
.6283 .36547 Mdot
.42705 .30695 Mdot
.34839 .67956 Mdot
.41978 .33588 Mdot
.43408 .56493 Mdot
.65103 .37561 Mdot
.54499 .67231 Mdot
.30352 .43285 Mdot
.64186 .62364 Mdot
.36184 .57335 Mdot
.35765 .63562 Mdot
.46097 .54762 Mdot
.49259 .74224 Mdot
.26938 .41146 Mdot
.65168 .35162 Mdot
.64324 .62408 Mdot
.37472 .29853 Mdot
.43703 .7451 Mdot
.23131 .45233 Mdot
.47649 .56679 Mdot
.3449 .5916 Mdot
.72685 .63009 Mdot
.36337 .59077 Mdot
.44847 .31987 Mdot
.5944 .6267 Mdot
.57312 .58171 Mdot
.5933 .584 Mdot
.58622 .6291 Mdot
.42916 .30957 Mdot
.58737 .5606 Mdot
.41234 .56528 Mdot
.46344 .56645 Mdot
.51765 .61013 Mdot
.36181 .56663 Mdot
.41417 .31223 Mdot
.30645 .41688 Mdot
.49858 .54541 Mdot
.31568 .57878 Mdot
.63097 .63165 Mdot
.60038 .62369 Mdot
.43721 .56347 Mdot
.62276 .64182 Mdot
.55572 .56749 Mdot
.27077 .41799 Mdot
.5203 .62736 Mdot
.32461 .5667 Mdot
.35961 .57808 Mdot
.43204 .32783 Mdot
.61645 .38509 Mdot
.32 .58008 Mdot
.24045 .44243 Mdot
.65185 .60782 Mdot
.62779 .62133 Mdot
.60126 .361 Mdot
.34812 .69086 Mdot
.32227 .56715 Mdot
.59793 .63669 Mdot
.60446 .39114 Mdot
.62254 .32986 Mdot
.60474 .61683 Mdot
.60241 .55995 Mdot
.61201 .41536 Mdot
.33246 .60091 Mdot
.42363 .32683 Mdot
.39974 .70546 Mdot
.43659 .29022 Mdot
.64424 .36749 Mdot
.46911 .5338 Mdot
.64124 .34325 Mdot
.45065 .53847 Mdot
.58849 .20084 Mdot
.60609 .62674 Mdot
.68965 .3167 Mdot
.42199 .56497 Mdot
.30344 .43574 Mdot
.30867 .44042 Mdot
.48172 .55703 Mdot
.65138 .39029 Mdot
.44779 .55439 Mdot
.37178 .58249 Mdot
.63809 .27514 Mdot
.60883 .41536 Mdot
.29612 .44939 Mdot
.25034 .43103 Mdot
.4609 .31536 Mdot
.57847 .58957 Mdot
.6227 .60673 Mdot
.25695 .42034 Mdot
.48827 .28473 Mdot
.61961 .34972 Mdot
.60502 .59081 Mdot
.45138 .53228 Mdot
.27111 .42144 Mdot
.48132 .35911 Mdot
.66177 .3424 Mdot
.66676 .60593 Mdot
.38995 .75843 Mdot
.45367 .29288 Mdot
.64119 .57458 Mdot
.58109 .56114 Mdot
.33131 .58107 Mdot
.49399 .74765 Mdot
.35296 .69466 Mdot
.46192 .29232 Mdot
.46689 .56172 Mdot
.64708 .58697 Mdot
.30829 .43556 Mdot
.61902 .63195 Mdot
.79516 .66637 Mdot
.45165 .56591 Mdot
.62592 .594 Mdot
.52667 .54854 Mdot
.63792 .39426 Mdot
.605 .58711 Mdot
.37776 .30024 Mdot
.27352 .43748 Mdot
.62786 .59628 Mdot
.53773 .50933 Mdot
.45968 .31212 Mdot
.46166 .54815 Mdot
.34418 .59348 Mdot
.53404 .66674 Mdot
.48589 .81107 Mdot
.24208 .41836 Mdot
.36437 .56539 Mdot
.57453 .59281 Mdot
.25234 .45638 Mdot
.41444 .33797 Mdot
.46293 .55565 Mdot
.65026 .57681 Mdot
.41014 .31287 Mdot
.42921 .30189 Mdot
.34857 .58763 Mdot
.78688 .30965 Mdot
.56187 .61262 Mdot
.61225 .60409 Mdot
.78758 .33448 Mdot
.59932 .34174 Mdot
.60425 .60801 Mdot
.5698 .58944 Mdot
.4362 .32522 Mdot
.34293 .67397 Mdot
.49314 .74341 Mdot
.48001 .57004 Mdot
.43291 .29459 Mdot
.22184 .42708 Mdot
.25968 .43298 Mdot
.36021 .56322 Mdot
.63274 .37555 Mdot
.31989 .59048 Mdot
.27723 .4264 Mdot
.58933 .59241 Mdot
.43382 .3331 Mdot
.71373 .6695 Mdot
.45361 .29539 Mdot
.24136 .43641 Mdot
.65771 .32501 Mdot
.76435 .62443 Mdot
.80835 .65438 Mdot
.49978 .46362 Mdot
.40316 .26516 Mdot
.33432 .58617 Mdot
.781 .35873 Mdot
.57855 .616 Mdot
.78758 .57264 Mdot
.60994 .60751 Mdot
.40728 .5508 Mdot
.32163 .42889 Mdot
.458 .56263 Mdot
.44796 .54032 Mdot
.49615 .73797 Mdot
.42441 .30535 Mdot
.4541 .33233 Mdot
.46423 .53253 Mdot
.44377 .31702 Mdot
.62408 .59799 Mdot
.28402 .41338 Mdot
.64204 .23129 Mdot
.57563 .61497 Mdot
.50605 .5387 Mdot
.42369 .2865 Mdot
.60697 .30849 Mdot
.22377 .42452 Mdot
.77067 .543 Mdot
.4643 .21062 Mdot
.45276 .31126 Mdot
.81146 .52264 Mdot
.2783 .44208 Mdot
.49846 .54505 Mdot
.26178 .46135 Mdot
.61674 .60499 Mdot
.61847 .57444 Mdot
.48188 .52991 Mdot
.57136 .59479 Mdot
.74849 .56858 Mdot
.57062 .56199 Mdot
.62327 .4883 Mdot
.61117 .62339 Mdot
.69837 .36003 Mdot
.41804 .34297 Mdot
.46815 .53247 Mdot
.41321 .66782 Mdot
.6358 .60906 Mdot
.6139 .41175 Mdot
.41529 .30475 Mdot
.44349 .20919 Mdot
.42966 .30617 Mdot
.30654 .42763 Mdot
.42251 .31455 Mdot
.58704 .56217 Mdot
.64205 .3848 Mdot
.28774 .42969 Mdot
.46672 .54527 Mdot
.26748 .45231 Mdot
.63209 .60062 Mdot
.41984 .37835 Mdot
.26191 .44246 Mdot
.64969 .56807 Mdot
.64 .38791 Mdot
.37127 .77983 Mdot
.67213 .35577 Mdot
.59724 .59597 Mdot
.59947 .60252 Mdot
.42389 .55927 Mdot
.42659 .32093 Mdot
.64056 .34105 Mdot
.3627 .38379 Mdot
.31818 .57014 Mdot
.63158 .36995 Mdot
.54943 .52943 Mdot
.45074 .73045 Mdot
.61528 .40187 Mdot
.52038 .74239 Mdot
.44891 .32233 Mdot
.63697 .39921 Mdot
.59486 .53099 Mdot
.68242 .53968 Mdot
.36464 .5819 Mdot
.33099 .43845 Mdot
.46002 .72943 Mdot
.26268 .43595 Mdot
.37614 .30306 Mdot
.33358 .43924 Mdot
.45422 .30265 Mdot
.55253 .52374 Mdot
.55003 .69274 Mdot
.46746 .31971 Mdot
.38918 .37679 Mdot
.26773 .43041 Mdot
.44737 .53659 Mdot
.51878 .6183 Mdot
.42101 .55019 Mdot
.43416 .54923 Mdot
.46335 .29446 Mdot
.63775 .39968 Mdot
.65923 .38598 Mdot
.5211 .5465 Mdot
.61951 .39707 Mdot
.28869 .41935 Mdot
.42694 .70287 Mdot
.79387 .50004 Mdot
.43052 .34411 Mdot
.52213 .63434 Mdot
.64826 .58172 Mdot
.31387 .41797 Mdot
.29322 .41852 Mdot
.42599 .30563 Mdot
.6954 .52465 Mdot
.43432 .55358 Mdot
.64018 .3147 Mdot
.64819 .38297 Mdot
.63702 .39577 Mdot
.60782 .35945 Mdot
.34619 .68175 Mdot
.43232 .29564 Mdot
.65051 .39021 Mdot
.58959 .63028 Mdot
.57525 .5854 Mdot
.49756 .54943 Mdot
.33656 .60529 Mdot
.57352 .56204 Mdot
.44666 .55478 Mdot
.60844 .61545 Mdot
.29969 .43738 Mdot
.59725 .5193 Mdot
.47916 .56221 Mdot
.28954 .44382 Mdot
.29776 .44125 Mdot
.46831 .56245 Mdot
.5946 .51987 Mdot
.7348 .59948 Mdot
.67633 .59598 Mdot
.68066 .33149 Mdot
.30981 .44349 Mdot
.38041 .39235 Mdot
.69159 .32053 Mdot
.58398 .57697 Mdot
.42957 .56582 Mdot
.29094 .41373 Mdot
.60525 .40916 Mdot
.61469 .59867 Mdot
.48011 .53782 Mdot
.36185 .5872 Mdot
.46581 .54923 Mdot
.49473 .54006 Mdot
.60916 .3683 Mdot
.23145 .34215 Mdot
.61076 .40367 Mdot
.34319 .42879 Mdot
.46208 .5418 Mdot
.72884 .23544 Mdot
.31877 .43536 Mdot
.63381 .27329 Mdot
.54738 .69066 Mdot
.6141 .61729 Mdot
.27156 .44014 Mdot
.60914 .42562 Mdot
.46888 .30128 Mdot
.51999 .71507 Mdot
.61678 .38763 Mdot
.50329 .54997 Mdot
.49297 .5491 Mdot
.26901 .42397 Mdot
.64539 .36021 Mdot
.58474 .56059 Mdot
.6289 .39714 Mdot
.43364 .33716 Mdot
.65922 .62477 Mdot
.47699 .21002 Mdot
.45832 .53695 Mdot
.61498 .39717 Mdot
.25277 .44576 Mdot
.36593 .56146 Mdot
.56473 .60245 Mdot
.45271 .20586 Mdot
.57447 .59156 Mdot
.46062 .32441 Mdot
.46765 .57721 Mdot
.68881 .56922 Mdot
.5833 .60641 Mdot
.63386 .57528 Mdot
.47679 .29602 Mdot
.58535 .60952 Mdot
.64386 .59781 Mdot
.77332 .37788 Mdot
.60889 .39802 Mdot
.58219 .61807 Mdot
.26735 .41557 Mdot
.57104 .49722 Mdot
.61354 .58335 Mdot
.38312 .28004 Mdot
.48639 .76423 Mdot
.42434 .56796 Mdot
.51185 .54027 Mdot
.40596 .76868 Mdot
.60411 .60344 Mdot
.58292 .57496 Mdot
.65669 .62659 Mdot
.77146 .56555 Mdot
.27478 .43047 Mdot
.28321 .45931 Mdot
.367 .56302 Mdot
.50241 .74284 Mdot
.35597 .58146 Mdot
.41393 .33755 Mdot
.52847 .65983 Mdot
.47083 .56575 Mdot
.61465 .38385 Mdot
.59712 .58337 Mdot
.26021 .45216 Mdot
.62162 .60288 Mdot
.66828 .59018 Mdot
.28376 .41935 Mdot
.29701 .41623 Mdot
.34074 .42009 Mdot
.34042 .59447 Mdot
.62195 .37217 Mdot
.56408 .60923 Mdot
.3453 .59574 Mdot
.47071 .52852 Mdot
.39987 .71778 Mdot
.62398 .36965 Mdot
.61251 .39526 Mdot
.65825 .37182 Mdot
.56508 .58897 Mdot
.66448 .62229 Mdot
.41667 .33259 Mdot
.60127 .36085 Mdot
.45458 .3194 Mdot
.26912 .43981 Mdot
.28978 .40966 Mdot
.61625 .60583 Mdot
.55053 .53283 Mdot
.36479 .56952 Mdot
.25655 .43865 Mdot
.50943 .55919 Mdot
.33582 .56461 Mdot
.60847 .57558 Mdot
.2645 .43815 Mdot
.37678 .58787 Mdot
.69957 .53372 Mdot
.50796 .23697 Mdot
.35546 .5607 Mdot
.44243 .54401 Mdot
.74624 .42873 Mdot
.38044 .74548 Mdot
.33286 .55849 Mdot
.41981 .34323 Mdot
.57276 .57507 Mdot
.48675 .56755 Mdot
.32308 .57096 Mdot
.35395 .70784 Mdot
.28279 .42406 Mdot
.43724 .54923 Mdot
.4996 .47447 Mdot
.79257 .50229 Mdot
.36196 .56054 Mdot
.61416 .39759 Mdot
.61618 .34183 Mdot
.58392 .59833 Mdot
.53169 .66546 Mdot
.44048 .34515 Mdot
.33395 .41994 Mdot
.274 .45805 Mdot
.64335 .33072 Mdot
.41998 .71312 Mdot
.26156 .42061 Mdot
.57802 .57421 Mdot
.31534 .60165 Mdot
.59375 .6328 Mdot
.44304 .58021 Mdot
.68838 .57223 Mdot
.52189 .53894 Mdot
.36165 .5609 Mdot
.44831 .34139 Mdot
.44574 .2983 Mdot
.42714 .31667 Mdot
.26525 .42066 Mdot
.46548 .72722 Mdot
.26987 .45933 Mdot
.79147 .3437 Mdot
.3268 .58083 Mdot
.19828 .61901 Mdot
.54312 .57898 Mdot
.61984 .61465 Mdot
.64624 .61693 Mdot
.46183 .53064 Mdot
.60453 .60224 Mdot
.40933 .31625 Mdot
.32732 .44116 Mdot
.50165 .33569 Mdot
.62591 .35376 Mdot
.78694 .35593 Mdot
.30201 .43349 Mdot
.51141 .55055 Mdot
.36211 .57026 Mdot
.42816 .78517 Mdot
.38536 .58808 Mdot
.26288 .41171 Mdot
.63466 .58889 Mdot
.6637 .38414 Mdot
.267 .70913 Mdot
.60107 .58539 Mdot
.25233 .43043 Mdot
.23125 .43945 Mdot
.68025 .53052 Mdot
.64826 .68375 Mdot
.49735 .30593 Mdot
.44106 .70958 Mdot
.38573 .57476 Mdot
.44005 .53602 Mdot
.46642 .76594 Mdot
.27534 .42652 Mdot
.30733 .45254 Mdot
.39028 .56543 Mdot
.60363 .30889 Mdot
.65404 .37805 Mdot
.67742 .35477 Mdot
.41173 .32009 Mdot
.61371 .61912 Mdot
.26462 .43257 Mdot
.66494 .3372 Mdot
.39525 .66296 Mdot
.43421 .31378 Mdot
.26079 .44304 Mdot
.5731 .59109 Mdot
.5813 .60472 Mdot
.35555 .58323 Mdot
.4652 .57489 Mdot
.42186 .55065 Mdot
.63609 .2751 Mdot
.43975 .73099 Mdot
.54592 .69049 Mdot
.60844 .61662 Mdot
.60705 .36334 Mdot
.47155 .56156 Mdot
.3679 .57512 Mdot
.61776 .63182 Mdot
.78078 .60114 Mdot
.59865 .39932 Mdot
.4538 .3171 Mdot
.47203 .54161 Mdot
.4961 .73106 Mdot
.5727 .59259 Mdot
.61063 .60718 Mdot
.66631 .60375 Mdot
.75703 .63266 Mdot
.32396 .43815 Mdot
.60643 .38119 Mdot
.34226 .59269 Mdot
.6276 .39168 Mdot
.35117 .44547 Mdot
.51854 .62915 Mdot
.55918 .59295 Mdot
.60666 .40605 Mdot
.6361 .38532 Mdot
.45991 .32549 Mdot
.44412 .29585 Mdot
.23433 .42088 Mdot
.56831 .59051 Mdot
.45812 .5672 Mdot
.64814 .39126 Mdot
.33507 .43005 Mdot
.35369 .58245 Mdot
.38162 .27925 Mdot
.60261 .62529 Mdot
.27009 .4273 Mdot
.45758 .55182 Mdot
.61784 .36065 Mdot
.28667 .44142 Mdot
.4985 .54453 Mdot
.33982 .60355 Mdot
.63346 .57865 Mdot
.25546 .46571 Mdot
.48394 .53718 Mdot
.56685 .60557 Mdot
.61784 .51655 Mdot
.53134 .66404 Mdot
.50743 .56196 Mdot
.30069 .40851 Mdot
.48447 .54126 Mdot
.6218 .33916 Mdot
.68986 .54978 Mdot
.3094 .45316 Mdot
.69628 .38944 Mdot
.55292 .69593 Mdot
.45509 .53644 Mdot
.61069 .38217 Mdot
.36301 .41457 Mdot
.57966 .3301 Mdot
.38008 .74086 Mdot
.61892 .59082 Mdot
.26252 .43558 Mdot
.36259 .58391 Mdot
.4541 .33186 Mdot
.38495 .32999 Mdot
.36989 .44549 Mdot
.29873 .44615 Mdot
.59817 .58276 Mdot
.63877 .39863 Mdot
.45039 .31552 Mdot
.66614 .43838 Mdot
.25271 .45535 Mdot
.26833 .41383 Mdot
.66071 .60403 Mdot
.35615 .5805 Mdot
.53108 .5997 Mdot
.31758 .45034 Mdot
.31895 .45319 Mdot
.77166 .37995 Mdot
.38495 .57546 Mdot
.66811 .60211 Mdot
.52182 .54509 Mdot
.64525 .61238 Mdot
.78459 .34907 Mdot
.49362 .54407 Mdot
.62607 .35277 Mdot
.59718 .60713 Mdot
.20642 .38842 Mdot
.31824 .42946 Mdot
.44076 .70964 Mdot
.495 .32948 Mdot
.42931 .29975 Mdot
.27708 .43632 Mdot
.61555 .59408 Mdot
.3886 .27309 Mdot
.35436 .56283 Mdot
.66603 .61026 Mdot
.45862 .53413 Mdot
.63688 .3282 Mdot
.43119 .33332 Mdot
.561 .50466 Mdot
.44492 .3371 Mdot
.42947 .32604 Mdot
.5763 .3884 Mdot
.58403 .59723 Mdot
.29665 .4348 Mdot
.24542 .43005 Mdot
.4609 .52695 Mdot
.34366 .38626 Mdot
.65251 .36005 Mdot
.21733 .38102 Mdot
.77425 .61107 Mdot
.59829 .62993 Mdot
.50379 .54341 Mdot
.4273 .5626 Mdot
.39889 .26786 Mdot
.58655 .60604 Mdot
.61106 .37554 Mdot
.32099 .44872 Mdot
.26003 .42978 Mdot
.6495 .56813 Mdot
.44522 .29778 Mdot
.36019 .60181 Mdot
.29307 .42055 Mdot
.40214 .70178 Mdot
.62606 .59336 Mdot
.40671 .29601 Mdot
.29365 .42267 Mdot
.3665 .80907 Mdot
.21262 .35864 Mdot
.62424 .40382 Mdot
.6245 .57329 Mdot
.66238 .34561 Mdot
.37292 .56659 Mdot
.2979 .46468 Mdot
.46075 .32759 Mdot
.4644 .54294 Mdot
.40196 .22396 Mdot
.2636 .42588 Mdot
.62534 .38194 Mdot
.58994 .59724 Mdot
.80871 .52927 Mdot
.57467 .61299 Mdot
.34237 .6725 Mdot
.3251 .56512 Mdot
.38487 .34039 Mdot
.46343 .31385 Mdot
.62061 .57155 Mdot
.3514 .59781 Mdot
.24507 .42268 Mdot
.28235 .41991 Mdot
.43669 .20133 Mdot
.49563 .5416 Mdot
.29972 .46621 Mdot
.56623 .60202 Mdot
.33917 .42648 Mdot
.75165 .41214 Mdot
.43319 .29904 Mdot
.64675 .60869 Mdot
.26795 .44641 Mdot
.58539 .32502 Mdot
.4453 .71784 Mdot
.62202 .59098 Mdot
.53265 .541 Mdot
.45287 .30271 Mdot
.78589 .35998 Mdot
.32035 .42434 Mdot
.6161 .63725 Mdot
.40638 .31969 Mdot
.55223 .52432 Mdot
.5057 .3351 Mdot
.62199 .37167 Mdot
.24903 .43291 Mdot
.42351 .32753 Mdot
.45058 .54524 Mdot
.37447 .58898 Mdot
.23895 .4416 Mdot
.27195 .45038 Mdot
.66532 .58097 Mdot
.51552 .55151 Mdot
.54859 .53243 Mdot
.62977 .34495 Mdot
.44174 .32535 Mdot
.66948 .59312 Mdot
.39726 .71914 Mdot
.63968 .63168 Mdot
.43974 .32791 Mdot
.74585 .26179 Mdot
.63449 .58601 Mdot
.60658 .62392 Mdot
.8053 .54251 Mdot
.65201 .34954 Mdot
.60208 .36964 Mdot
.43079 .73716 Mdot
.62755 .56497 Mdot
.54835 .67474 Mdot
.62126 .37591 Mdot
.62809 .38318 Mdot
.54725 .67396 Mdot
.66486 .58211 Mdot
.67552 .36269 Mdot
.44838 .31547 Mdot
.43169 .29829 Mdot
.63683 .39519 Mdot
.63855 .6232 Mdot
.40421 .33994 Mdot
.69777 .51506 Mdot
.25096 .4213 Mdot
.47619 .76149 Mdot
.63443 .39086 Mdot
.44884 .71566 Mdot
.44783 .32057 Mdot
.46784 .79425 Mdot
.49222 .76597 Mdot
.56497 .61662 Mdot
.58342 .60198 Mdot
.33434 .58291 Mdot
.46347 .54836 Mdot
.47025 .56266 Mdot
.42664 .31705 Mdot
.53003 .6056 Mdot
.6297 .36504 Mdot
.60257 .56227 Mdot
.36841 .72819 Mdot
.50107 .80845 Mdot
.69949 .67289 Mdot
.63224 .37725 Mdot
.64065 .36841 Mdot
.28249 .40744 Mdot
.29873 .40435 Mdot
.55997 .60235 Mdot
.45043 .29988 Mdot
.63269 .40054 Mdot
.44083 .33061 Mdot
.27666 .42561 Mdot
.30182 .43125 Mdot
.48907 .55813 Mdot
.43686 .55058 Mdot
.28121 .43207 Mdot
.38422 .27883 Mdot
.39782 .71912 Mdot
.62129 .33402 Mdot
.79342 .33956 Mdot
.45452 .79689 Mdot
.81799 .5019 Mdot
.36262 .58571 Mdot
.59786 .52101 Mdot
.40736 .31957 Mdot
.62235 .57167 Mdot
.60498 .61214 Mdot
.48174 .54771 Mdot
.40626 .31327 Mdot
.34146 .5688 Mdot
.43071 .29961 Mdot
.36998 .59183 Mdot
.28587 .45778 Mdot
.60398 .58307 Mdot
.63529 .59685 Mdot
.45685 .3286 Mdot
.27502 .40771 Mdot
.26703 .44378 Mdot
.36775 .58166 Mdot
.43437 .78522 Mdot
.27025 .4243 Mdot
.63439 .38985 Mdot
.70432 .39695 Mdot
.49145 .54827 Mdot
.61395 .59791 Mdot
.40799 .77088 Mdot
.69094 .55405 Mdot
.47773 .5289 Mdot
.47324 .54178 Mdot
.78476 .3067 Mdot
.62758 .59063 Mdot
.41647 .19554 Mdot
.4827 .56142 Mdot
.64213 .34366 Mdot
.28994 .43682 Mdot
.50264 .54348 Mdot
.53185 .52977 Mdot
.31283 .6109 Mdot
.49623 .53465 Mdot
.65391 .38044 Mdot
.65808 .36231 Mdot
.51992 .62905 Mdot
.79319 .3517 Mdot
.34479 .5928 Mdot
.34252 .56578 Mdot
.32043 .44214 Mdot
.37516 .3062 Mdot
.54702 .59519 Mdot
.33195 .57007 Mdot
.65369 .41267 Mdot
.66441 .59853 Mdot
.53037 .65901 Mdot
.51768 .61365 Mdot
.61185 .34997 Mdot
.68389 .60153 Mdot
.32125 .43735 Mdot
.62558 .37993 Mdot
.51985 .62319 Mdot
.65498 .60468 Mdot
.62572 .36757 Mdot
.43139 .32438 Mdot
.61445 .7045 Mdot
.62643 .39791 Mdot
.52019 .71315 Mdot
.45518 .31123 Mdot
.52811 .6509 Mdot
.23687 .63854 Mdot
.40184 .83569 Mdot
.43406 .30029 Mdot
.25911 .43974 Mdot
.26605 .43265 Mdot
.27458 .41783 Mdot
.61653 .35074 Mdot
.30655 .41986 Mdot
.6406 .35423 Mdot
.40452 .26542 Mdot
.49947 .74013 Mdot
.34554 .58447 Mdot
.34945 .39869 Mdot
.63486 .39577 Mdot
.78836 .34515 Mdot
.87825 .56533 Mdot
.6188 .639 Mdot
.46797 .3179 Mdot
.32352 .57687 Mdot
.43778 .70393 Mdot
.33175 .58084 Mdot
.27743 .44207 Mdot
.49574 .73478 Mdot
.62478 .60018 Mdot
.49092 .23234 Mdot
.36209 .5826 Mdot
.62837 .38452 Mdot
.66303 .57618 Mdot
.27744 .40347 Mdot
.36686 .56519 Mdot
.36082 .57664 Mdot
.6063 .60152 Mdot
.65113 .35092 Mdot
.27423 .44369 Mdot
.41251 .30194 Mdot
.34508 .49273 Mdot
.56428 .54458 Mdot
.6215 .58504 Mdot
.62211 .62196 Mdot
.44735 .72657 Mdot
.37983 .28165 Mdot
.45009 .30806 Mdot
.35622 .70473 Mdot
.31119 .41536 Mdot
.37478 .73999 Mdot
.58685 .31534 Mdot
.34973 .40572 Mdot
.49282 .54403 Mdot
.49884 .54661 Mdot
.6025 .58968 Mdot
.83779 .61854 Mdot
.63373 .68978 Mdot
.4057 .33859 Mdot
.48446 .55043 Mdot
.26981 .4072 Mdot
.59722 .38558 Mdot
.47187 .47446 Mdot
.54924 .57024 Mdot
.41223 .30176 Mdot
.27664 .42092 Mdot
.79228 .68077 Mdot
.33372 .58937 Mdot
.43448 .70696 Mdot
.56907 .59344 Mdot
.60458 .59323 Mdot
.43448 .30923 Mdot
.45294 .33708 Mdot
.774 .38227 Mdot
.40338 .55883 Mdot
.48198 .20803 Mdot
.47884 .31219 Mdot
.79131 .68754 Mdot
.43502 .56453 Mdot
.63883 .36097 Mdot
.46401 .56232 Mdot
.45865 .3345 Mdot
.60149 .60816 Mdot
.65075 .34933 Mdot
.46228 .55653 Mdot
.6418 .41481 Mdot
.53436 .66815 Mdot
.40018 .70611 Mdot
.57981 .59128 Mdot
.66472 .35693 Mdot
.62497 .37526 Mdot
.64739 .31767 Mdot
.48889 .55476 Mdot
.60171 .61878 Mdot
.61378 .63755 Mdot
.61627 .62265 Mdot
.76869 .39312 Mdot
.60713 .58663 Mdot
.59183 .31008 Mdot
.422 .73123 Mdot
.19167 .40205 Mdot
.63452 .60003 Mdot
.42331 .32179 Mdot
.594 .58744 Mdot
.35032 .59894 Mdot
.64242 .58496 Mdot
.53844 .67603 Mdot
.44656 .31248 Mdot
.78982 .58299 Mdot
.32677 .6097 Mdot
.62098 .58339 Mdot
.38109 .57976 Mdot
.6137 .26417 Mdot
.35878 .70561 Mdot
.76796 .37751 Mdot
.62963 .39664 Mdot
.269 .46256 Mdot
.4421 .34495 Mdot
.3065 .42866 Mdot
.62756 .56247 Mdot
.46373 .56533 Mdot
.1855 .6104 Mdot
.4045 .73825 Mdot
.59914 .60743 Mdot
.42722 .55134 Mdot
.60906 .39051 Mdot
.31939 .43258 Mdot
.81295 .45933 Mdot
.65147 .61308 Mdot
.32915 .59949 Mdot
.32831 .59179 Mdot
.38231 .61652 Mdot
.62348 .30832 Mdot
.7566 .39891 Mdot
.43649 .30897 Mdot
.26283 .42268 Mdot
.32683 .56693 Mdot
.67384 .39178 Mdot
.46436 .32563 Mdot
.39749 .27003 Mdot
.42752 .3322 Mdot
.62961 .61018 Mdot
.49765 .55563 Mdot
.65238 .29494 Mdot
.48936 .54016 Mdot
.63378 .62123 Mdot
.27295 .4502 Mdot
.49452 .54311 Mdot
.34014 .58134 Mdot
.42546 .32669 Mdot
.30129 .43558 Mdot
.59734 .59981 Mdot
.61767 .37587 Mdot
.47048 .59941 Mdot
.28353 .47003 Mdot
.53061 .66362 Mdot
.53055 .6635 Mdot
.60818 .34117 Mdot
.49808 .56633 Mdot
.4122 .37983 Mdot
.68558 .53817 Mdot
.3609 .44696 Mdot
.53959 .54858 Mdot
.30966 .37668 Mdot
.26891 .45964 Mdot
.28817 .42766 Mdot
.62664 .60527 Mdot
.33673 .42741 Mdot
.56941 .57842 Mdot
.3035 .40894 Mdot
.6486 .2782 Mdot
.57136 .56389 Mdot
.28771 .42099 Mdot
.45459 .55883 Mdot
.56543 .60434 Mdot
.60793 .38431 Mdot
.28407 .46265 Mdot
.56547 .61709 Mdot
.1759 .4494 Mdot
.45945 .32624 Mdot
.49124 .55368 Mdot
.44869 .68126 Mdot
.44044 .3209 Mdot
.65241 .36789 Mdot
.57996 .57002 Mdot
.32885 .57077 Mdot
.64345 .36598 Mdot
.37333 .61312 Mdot
.35729 .57865 Mdot
.42403 .70333 Mdot
.64624 .3796 Mdot
.4911 .54617 Mdot
.33402 .6005 Mdot
.45635 .52771 Mdot
.28645 .4255 Mdot
.23276 .4516 Mdot
.47924 .53595 Mdot
.62359 .60295 Mdot
.27126 .40551 Mdot
.42266 .30879 Mdot
.60194 .57817 Mdot
.26313 .43224 Mdot
.47259 .55688 Mdot
.57947 .62086 Mdot
.62172 .56345 Mdot
.78007 .36254 Mdot
.43127 .56858 Mdot
.34319 .58329 Mdot
.65647 .32463 Mdot
.60474 .63066 Mdot
.35676 .59565 Mdot
.25391 .46198 Mdot
.6275 .63801 Mdot
.6381 .40178 Mdot
.68902 .51624 Mdot
.32962 .41747 Mdot
.45455 .29949 Mdot
.24333 .4382 Mdot
.37741 .56686 Mdot
.89448 .54139 Mdot
.47363 .56209 Mdot
.67866 .5999 Mdot
.64385 .60459 Mdot
.27911 .46466 Mdot
.62643 .37224 Mdot
.49817 .20724 Mdot
.6338 .57847 Mdot
.62771 .63957 Mdot
.6105 .5994 Mdot
.32183 .4857 Mdot
.62698 .34311 Mdot
.61272 .59904 Mdot
.53142 .55598 Mdot
.63518 .61663 Mdot
.37519 .57403 Mdot
.20974 .63092 Mdot
.49105 .53403 Mdot
.7212 .22317 Mdot
.46586 .55856 Mdot
.28438 .41667 Mdot
.52028 .71238 Mdot
.44474 .67848 Mdot
.2258 .47886 Mdot
.65243 .36369 Mdot
.68177 .33399 Mdot
.3009 .43041 Mdot
.36174 .42096 Mdot
.52646 .59031 Mdot
.66139 .57586 Mdot
.57003 .58574 Mdot
.27767 .44204 Mdot
.3324 .42968 Mdot
.45523 .56395 Mdot
.43509 .54306 Mdot
.67092 .62172 Mdot
.25696 .44799 Mdot
.60698 .58515 Mdot
.68778 .55619 Mdot
.46901 .31966 Mdot
.6201 .40342 Mdot
.4491 .33615 Mdot
.47099 .30846 Mdot
.82018 .49108 Mdot
.44143 .73254 Mdot
.41125 .32016 Mdot
.40747 .33103 Mdot
.36672 .41647 Mdot
.79775 .50694 Mdot
.37651 .57696 Mdot
.6303 .68969 Mdot
.2904 .4107 Mdot
.59948 .61892 Mdot
.62547 .343 Mdot
.41037 .57165 Mdot
.52627 .20226 Mdot
.63007 .76961 Mdot
.66632 .59548 Mdot
.30888 .41662 Mdot
.48098 .53561 Mdot
.46898 .53221 Mdot
.37891 .74378 Mdot
.61036 .58899 Mdot
.33299 .41897 Mdot
.79397 .50097 Mdot
.47372 .2793 Mdot
.38949 .27329 Mdot
.63641 .31294 Mdot
.59413 .58634 Mdot
.62093 .34988 Mdot
.43784 .29094 Mdot
.35616 .59376 Mdot
.33614 .58741 Mdot
.62118 .5831 Mdot
.54779 .69057 Mdot
.35901 .45285 Mdot
.63862 .56712 Mdot
.66356 .58226 Mdot
.48297 .54164 Mdot
.67342 .59228 Mdot
.61517 .63648 Mdot
.65997 .58506 Mdot
.46449 .52883 Mdot
.46399 .32538 Mdot
.80834 .48058 Mdot
.45821 .53534 Mdot
.56878 .57027 Mdot
.44376 .29105 Mdot
.60399 .55983 Mdot
.4285 .30725 Mdot
.37573 .28793 Mdot
.4147 .32877 Mdot
.34024 .58822 Mdot
.32184 .41092 Mdot
.78328 .36756 Mdot
.63527 .39887 Mdot
.43407 .29581 Mdot
.34431 .60486 Mdot
.42454 .31118 Mdot
.28236 .41003 Mdot
.45008 .26517 Mdot
.59297 .34971 Mdot
.40505 .69893 Mdot
.81014 .51403 Mdot
.47866 .29186 Mdot
.32776 .41771 Mdot
.63811 .39533 Mdot
.37745 .30046 Mdot
.61547 .57023 Mdot
.33525 .59078 Mdot
.60185 .59061 Mdot
.42709 .32646 Mdot
.29755 .41148 Mdot
.77183 .36923 Mdot
.34171 .58353 Mdot
.79338 .3325 Mdot
.25746 .45085 Mdot
.64154 .59289 Mdot
.44892 .2907 Mdot
.38244 .32999 Mdot
.46185 .31831 Mdot
.49508 .74969 Mdot
.47089 .56852 Mdot
.35374 .5439 Mdot
.64392 .3726 Mdot
.44402 .56619 Mdot
.49561 .84689 Mdot
.56571 .29382 Mdot
.61544 .3674 Mdot
.30406 .46651 Mdot
.62647 .59224 Mdot
.66982 .60061 Mdot
.44133 .55225 Mdot
.66266 .37757 Mdot
.6662 .60373 Mdot
.49513 .55371 Mdot
.42878 .74189 Mdot
.635 .31181 Mdot
.23823 .44416 Mdot
.56656 .59469 Mdot
.46229 .29374 Mdot
.45223 .2943 Mdot
.49194 .5597 Mdot
.43689 .33858 Mdot
.57102 .5707 Mdot
.64239 .38674 Mdot
.51857 .61892 Mdot
.37004 .56489 Mdot
.6055 .28738 Mdot
.39363 .59256 Mdot
.33887 .60846 Mdot
.58628 .62843 Mdot
.29969 .43281 Mdot
.39618 .22346 Mdot
.63988 .57709 Mdot
.62255 .37825 Mdot
.64462 .59945 Mdot
.67065 .59808 Mdot
.65441 .57153 Mdot
.26312 .4227 Mdot
.44696 .71824 Mdot
.60598 .58505 Mdot
.42168 .29606 Mdot
.54823 .67747 Mdot
.55414 .57203 Mdot
.40512 .55254 Mdot
.53701 .67302 Mdot
.39884 .31427 Mdot
.62613 .33172 Mdot
.29512 .4348 Mdot
.63354 .36426 Mdot
.61601 .42121 Mdot
.65213 .36709 Mdot
.61486 .31117 Mdot
.68785 .54302 Mdot
.41554 .19273 Mdot
.75293 .40872 Mdot
.81308 .51488 Mdot
.61022 .41827 Mdot
.30764 .25214 Mdot
.61295 .36936 Mdot
.65248 .36659 Mdot
.61819 .21513 Mdot
.64917 .35293 Mdot
.61669 .60629 Mdot
.63677 .60815 Mdot
.76254 .62472 Mdot
.34952 .49296 Mdot
.57874 .61864 Mdot
.46617 .52831 Mdot
.32266 .58087 Mdot
.60491 .30794 Mdot
.46819 .5426 Mdot
.43618 .70224 Mdot
.50573 .54931 Mdot
.6055 .60143 Mdot
.58823 .5817 Mdot
.56581 .56318 Mdot
.52419 .81279 Mdot
.36147 .49576 Mdot
.6594 .36824 Mdot
.53905 .58382 Mdot
.49982 .34412 Mdot
.58062 .58019 Mdot
.64905 .59546 Mdot
.68739 .59375 Mdot
.29676 .43477 Mdot
.59607 .39071 Mdot
.43256 .55461 Mdot
.59515 .28708 Mdot
.57377 .59513 Mdot
.40546 .58292 Mdot
.31591 .59033 Mdot
.61656 .59503 Mdot
.65445 .36028 Mdot
.66905 .60021 Mdot
.60015 .38157 Mdot
.64698 .3741 Mdot
.62901 .63861 Mdot
.61529 .30702 Mdot
.5974 .38928 Mdot
.66068 .57564 Mdot
.28685 .40586 Mdot
.63581 .27424 Mdot
.623 .60067 Mdot
.34416 .57873 Mdot
.58677 .60334 Mdot
.37725 .5746 Mdot
.50021 .53866 Mdot
.48555 .54008 Mdot
.71701 .63848 Mdot
.30359 .45417 Mdot
.38303 .59211 Mdot
.33938 .42864 Mdot
.54413 .58983 Mdot
.64371 .41868 Mdot
.46559 .27382 Mdot
.35279 .41948 Mdot
.48462 .54215 Mdot
.35004 .68171 Mdot
.54939 .66341 Mdot
.41769 .33472 Mdot
.60565 .37723 Mdot
.79819 .47838 Mdot
.42904 .56519 Mdot
.23762 .44184 Mdot
.2496 .42406 Mdot
.50574 .35235 Mdot
.64166 .23106 Mdot
.6339 .6 Mdot
.42452 .56266 Mdot
.61894 .49246 Mdot
.46299 .54953 Mdot
.44643 .56202 Mdot
.27007 .4505 Mdot
.57593 .61649 Mdot
.43489 .74997 Mdot
.26897 .43117 Mdot
.35547 .56666 Mdot
.62597 .35202 Mdot
.36413 .59408 Mdot
.52883 .23525 Mdot
.77566 .37989 Mdot
.27753 .4317 Mdot
.47083 .52945 Mdot
.59901 .62269 Mdot
.64529 .34431 Mdot
.66476 .43927 Mdot
.60789 .39704 Mdot
.34215 .56323 Mdot
.30627 .45524 Mdot
.15948 .49668 Mdot
.589 .59574 Mdot
.63527 .38406 Mdot
.31499 .60413 Mdot
.58146 .60655 Mdot
.44624 .29743 Mdot
.66579 .60314 Mdot
.63032 .38896 Mdot
.67762 .60202 Mdot
.6445 .37242 Mdot
.26327 .41623 Mdot
.62806 .58813 Mdot
.6043 .57639 Mdot
.3547 .69958 Mdot
.3405 .56946 Mdot
.5997 .39227 Mdot
.45612 .73448 Mdot
.64521 .61244 Mdot
.38968 .75594 Mdot
.60832 .58309 Mdot
.80802 .51787 Mdot
.52626 .54465 Mdot
.49784 .55239 Mdot
.64489 .60141 Mdot
.62274 .59852 Mdot
.65957 .44322 Mdot
.75045 .41664 Mdot
.76946 .39231 Mdot
.45334 .29708 Mdot
.60803 .37565 Mdot
.26995 .4348 Mdot
.29121 .46276 Mdot
.30652 .42266 Mdot
.36446 .55933 Mdot
.53154 .58321 Mdot
.61886 .61178 Mdot
.40003 .33578 Mdot
.32762 .57694 Mdot
.63624 .37652 Mdot
.34886 .58715 Mdot
.44093 .72504 Mdot
.3419 .57716 Mdot
.46499 .56367 Mdot
.24014 .33105 Mdot
.68725 .55336 Mdot
.35684 .57146 Mdot
.62535 .40289 Mdot
.55631 .68598 Mdot
.61806 .64263 Mdot
.78612 .35346 Mdot
.32557 .59553 Mdot
.30112 .46779 Mdot
.57351 .61744 Mdot
.50572 .71499 Mdot
.4287 .31077 Mdot
.36324 .59522 Mdot
.42817 .33307 Mdot
.66739 .59538 Mdot
.68976 .34107 Mdot
.62093 .38552 Mdot
.46993 .31954 Mdot
.64892 .60076 Mdot
.36231 .59565 Mdot
.28145 .42947 Mdot
.79682 .50695 Mdot
.39237 .27464 Mdot
.42863 .5727 Mdot
.37785 .74006 Mdot
.32229 .4378 Mdot
.79272 .52762 Mdot
.42129 .33281 Mdot
.53836 .58124 Mdot
.68601 .58682 Mdot
.61213 .63149 Mdot
.27 .44421 Mdot
.28893 .42803 Mdot
.35343 .37837 Mdot
.60503 .57557 Mdot
.67931 .60868 Mdot
.63176 .32652 Mdot
.31543 .45154 Mdot
.65176 .36753 Mdot
.66585 .35564 Mdot
.25967 .43962 Mdot
.60217 .38954 Mdot
.35908 .57836 Mdot
.46184 .75329 Mdot
.41953 .33166 Mdot
.46152 .30802 Mdot
.27959 .43258 Mdot
.30257 .44952 Mdot
.30051 .43281 Mdot
.65672 .61131 Mdot
.64867 .37366 Mdot
.60026 .57137 Mdot
.59236 .58953 Mdot
.62644 .64214 Mdot
.66096 .34035 Mdot
.6257 .57436 Mdot
.5223 .61429 Mdot
.31714 .58028 Mdot
.28937 .4181 Mdot
.44545 .32773 Mdot
.46824 .6041 Mdot
.41706 .29789 Mdot
.63625 .61706 Mdot
.64903 .28092 Mdot
.60854 .37057 Mdot
.33265 .58165 Mdot
.53694 .67499 Mdot
.33832 .58389 Mdot
.46958 .31877 Mdot
.62978 .32446 Mdot
.42133 .70825 Mdot
.61429 .57536 Mdot
.44751 .73028 Mdot
.27998 .66316 Mdot
.57266 .33491 Mdot
.43981 .32473 Mdot
.66282 .61683 Mdot
.50206 .5551 Mdot
.68799 .53804 Mdot
.6232 .60825 Mdot
.54854 .57486 Mdot
.49839 .68721 Mdot
.63663 .61418 Mdot
.64583 .40043 Mdot
.53248 .65199 Mdot
.44234 .53577 Mdot
.59039 .6326 Mdot
.43688 .20479 Mdot
.58489 .6227 Mdot
.61408 .5768 Mdot
.60576 .61449 Mdot
.65297 .5849 Mdot
.66098 .344 Mdot
.52136 .63731 Mdot
.43409 .29235 Mdot
.46139 .75377 Mdot
.41793 .32781 Mdot
.28038 .4375 Mdot
.41724 .56662 Mdot
.60972 .34957 Mdot
.33794 .58343 Mdot
.40335 .47288 Mdot
.50592 .72787 Mdot
.28171 .40742 Mdot
.34378 .68217 Mdot
.36238 .60051 Mdot
.44535 .55976 Mdot
.37992 .56817 Mdot
.2692 .44748 Mdot
.44164 .29797 Mdot
.63494 .58863 Mdot
.65002 .38633 Mdot
.62489 .39862 Mdot
.58664 .62999 Mdot
.62207 .26984 Mdot
.45801 .301 Mdot
.346 .38804 Mdot
.6295 .60767 Mdot
.64683 .60869 Mdot
.60133 .37504 Mdot
.31496 .4253 Mdot
.54755 .66268 Mdot
.37172 .57627 Mdot
.5776 .58244 Mdot
.44831 .53403 Mdot
.44202 .72605 Mdot
.45117 .2954 Mdot
.48132 .55514 Mdot
.59171 .62179 Mdot
.43366 .72477 Mdot
.66254 .613 Mdot
.5416 .5507 Mdot
.30051 .40546 Mdot
.62585 .6398 Mdot
.59652 .57625 Mdot
.63644 .31259 Mdot
.42404 .33463 Mdot
.62375 .37179 Mdot
.60218 .34198 Mdot
.48545 .54073 Mdot
.4599 .32314 Mdot
.65644 .58951 Mdot
.40989 .34752 Mdot
.66949 .59738 Mdot
.59531 .59463 Mdot
.43654 .32466 Mdot
.64753 .36051 Mdot
.48623 .21056 Mdot
.8077 .47939 Mdot
.66807 .59025 Mdot
.5856 .60566 Mdot
.34936 .49317 Mdot
.40958 .57271 Mdot
.62023 .57512 Mdot
.63171 .40022 Mdot
.58098 .6038 Mdot
.41581 .3462 Mdot
.34852 .59239 Mdot
.61872 .37989 Mdot
.31753 .42335 Mdot
.26049 .41929 Mdot
.27676 .40013 Mdot
.4633 .56403 Mdot
.67374 .59106 Mdot
.65623 .3246 Mdot
.66601 .34615 Mdot
.4702 .7181 Mdot
.28506 .41704 Mdot
.35888 .58844 Mdot
.56461 .59467 Mdot
.42426 .55533 Mdot
.45659 .29385 Mdot
.71616 .21674 Mdot
.42201 .71127 Mdot
.3161 .57665 Mdot
.4616 .57914 Mdot
.47968 .54425 Mdot
.606 .62306 Mdot
.35631 .59714 Mdot
.2602 .43786 Mdot
.6698 .60301 Mdot
.52693 .55701 Mdot
.30809 .46688 Mdot
.30682 .4409 Mdot
.4062 .34669 Mdot
.31412 .41435 Mdot
.37623 .58818 Mdot
.47202 .56224 Mdot
.61561 .39083 Mdot
.6145 .59152 Mdot
.45619 .53823 Mdot
.28327 .4134 Mdot
.43472 .5631 Mdot
.63672 .60415 Mdot
.60805 .36431 Mdot
.29911 .41628 Mdot
.60758 .60465 Mdot
.6775 .52736 Mdot
.77855 .36568 Mdot
.29985 .41119 Mdot
.57879 .57246 Mdot
.50312 .47548 Mdot
.30429 .43979 Mdot
.2725 .44745 Mdot
.62431 .63738 Mdot
.35291 .60077 Mdot
.58043 .58885 Mdot
.4483 .3 Mdot
.45059 .72435 Mdot
.45763 .32786 Mdot
.37815 .74466 Mdot
.60765 .63961 Mdot
.69174 .59186 Mdot
.64178 .4163 Mdot
.38186 .59631 Mdot
.45021 .79493 Mdot
.60316 .63003 Mdot
.6198 .43623 Mdot
.44936 .7173 Mdot
.41522 .69282 Mdot
.61061 .44847 Mdot
.37417 .58477 Mdot
.42662 .31617 Mdot
.61388 .5801 Mdot
.45792 .21697 Mdot
.37266 .58176 Mdot
.38003 .74587 Mdot
.60193 .56527 Mdot
.62978 .37966 Mdot
.6312 .60301 Mdot
.61929 .39132 Mdot
.58802 .6145 Mdot
.77744 .36126 Mdot
.35933 .45215 Mdot
.49562 .74896 Mdot
.45025 .55741 Mdot
.38247 .32999 Mdot
.81057 .51407 Mdot
.35829 .5822 Mdot
.67646 .60431 Mdot
.47652 .54868 Mdot
.43014 .2999 Mdot
.49216 .28602 Mdot
.30204 .4301 Mdot
.4185 .29847 Mdot
.63555 .35779 Mdot
.26285 .40839 Mdot
.44483 .56591 Mdot
.69341 .5875 Mdot
.35871 .59757 Mdot
.46033 .32215 Mdot
.61997 .59527 Mdot
.62151 .62807 Mdot
.32077 .48446 Mdot
.21616 .63959 Mdot
.66888 .35925 Mdot
.79348 .32339 Mdot
.63023 .3248 Mdot
.34169 .56708 Mdot
.28262 .4053 Mdot
.60045 .60948 Mdot
.57021 .60188 Mdot
.30843 .441 Mdot
.64067 .34135 Mdot
.37237 .59927 Mdot
.35027 .54372 Mdot
.40539 .33909 Mdot
.248 .66492 Mdot
.61698 .38187 Mdot
.24659 .66309 Mdot
.26316 .38303 Mdot
.69764 .29834 Mdot
.44011 .78886 Mdot
.44456 .31827 Mdot
.24736 .6647 Mdot
.63208 .38168 Mdot
.62481 .6171 Mdot
.4885 .54613 Mdot
.46525 .56593 Mdot
.61791 .35432 Mdot
.28227 .4415 Mdot
.36696 .59699 Mdot
.62988 .60103 Mdot
.59306 .52246 Mdot
.66648 .43806 Mdot
.28901 .45797 Mdot
.45819 .54627 Mdot
.45171 .32153 Mdot
.58305 .60668 Mdot
.32407 .57222 Mdot
.44423 .31712 Mdot
.49931 .54431 Mdot
.49372 .73551 Mdot
.57964 .57032 Mdot
.54161 .68366 Mdot
.43084 .30862 Mdot
.42815 .58695 Mdot
.59968 .57728 Mdot
.42147 .33286 Mdot
.51094 .54765 Mdot
.42679 .38435 Mdot
.5421 .63774 Mdot
.56516 .29427 Mdot
.23752 .43005 Mdot
.30138 .40855 Mdot
.17998 .46366 Mdot
.24088 .49194 Mdot
.41394 .31572 Mdot
.46982 .538 Mdot
.20426 .6269 Mdot
.43114 .33666 Mdot
.64621 .58424 Mdot
.62098 .58596 Mdot
.79374 .50032 Mdot
.4965 .53834 Mdot
.46633 .55938 Mdot
.69457 .32786 Mdot
.6042 .56092 Mdot
.45965 .54453 Mdot
.60214 .57913 Mdot
.65901 .36324 Mdot
.45124 .31785 Mdot
.65952 .79923 Mdot
.46246 .3336 Mdot
.67042 .57358 Mdot
.29165 .41068 Mdot
.2404 .42531 Mdot
.61482 .5945 Mdot
.49142 .46601 Mdot
.79453 .68371 Mdot
.61933 .58436 Mdot
.53734 .67555 Mdot
.37376 .73835 Mdot
.601 .63792 Mdot
.61452 .40787 Mdot
.4871 .5337 Mdot
.66056 .33586 Mdot
.43863 .31932 Mdot
.37396 .58459 Mdot
.37655 .60135 Mdot
.42741 .31531 Mdot
.57393 .60839 Mdot
.39208 .59168 Mdot
.60597 .5952 Mdot
.61619 .61788 Mdot
.43488 .72006 Mdot
.32915 .56634 Mdot
.29498 .43801 Mdot
.338 .58714 Mdot
.6522 .36109 Mdot
.75859 .27532 Mdot
.3547 .5849 Mdot
.79749 .50652 Mdot
.45527 .7306 Mdot
.20926 .62834 Mdot
.62059 .39768 Mdot
.37225 .56565 Mdot
.42482 .31785 Mdot
.44834 .6896 Mdot
.78742 .54885 Mdot
.4151 .29978 Mdot
.60967 .61758 Mdot
.66423 .34787 Mdot
.61665 .33386 Mdot
.4376 .28884 Mdot
.61061 .38853 Mdot
.54508 .60616 Mdot
.65325 .5745 Mdot
.43268 .29228 Mdot
.48958 .81066 Mdot
.46369 .31355 Mdot
.81899 .47911 Mdot
.67135 .58903 Mdot
.62093 .379 Mdot
.81199 .52288 Mdot
.62208 .32365 Mdot
.48513 .55909 Mdot
.63723 .58334 Mdot
.35723 .58667 Mdot
.46541 .72741 Mdot
.312 .41749 Mdot
.58602 .32387 Mdot
.63245 .39393 Mdot
.44528 .28726 Mdot
.61121 .3885 Mdot
.60472 .37841 Mdot
.47132 .31632 Mdot
.60906 .3728 Mdot
.57324 .59627 Mdot
.78978 .36237 Mdot
.60878 .39299 Mdot
.43869 .31071 Mdot
.34321 .5635 Mdot
.62475 .40365 Mdot
.36544 .39317 Mdot
.56592 .59924 Mdot
.25159 .45418 Mdot
.34946 .55266 Mdot
.66147 .3504 Mdot
.35971 .5832 Mdot
.28771 .41354 Mdot
.33242 .6032 Mdot
.41183 .3599 Mdot
.4017 .35093 Mdot
.53281 .52799 Mdot
.41073 .3848 Mdot
.64969 .35413 Mdot
.26223 .40794 Mdot
.57217 .58183 Mdot
.62638 .61177 Mdot
.33103 .56149 Mdot
.59988 .40213 Mdot
.62007 .26669 Mdot
.46606 .54255 Mdot
.60459 .2877 Mdot
.45435 .29717 Mdot
.34827 .39309 Mdot
.41932 .70867 Mdot
.41736 .26308 Mdot
.44026 .53685 Mdot
.48023 .54528 Mdot
.61122 .59977 Mdot
.35874 .70711 Mdot
.3765 .58684 Mdot
.29251 .26896 Mdot
.64389 .62055 Mdot
.31063 .44233 Mdot
.59385 .61504 Mdot
.52434 .59507 Mdot
.60823 .63342 Mdot
.31872 .57287 Mdot
.40587 .31706 Mdot
.63452 .39937 Mdot
.37547 .56908 Mdot
.25855 .42037 Mdot
.52051 .74115 Mdot
.61485 .57295 Mdot
.5634 .58358 Mdot
.29412 .44275 Mdot
.65301 .3746 Mdot
.28577 .43381 Mdot
.4195 .33135 Mdot
.3516 .58449 Mdot
.66311 .60691 Mdot
.49543 .53736 Mdot
.28178 .46486 Mdot
.43075 .29631 Mdot
.27723 .40435 Mdot
.43487 .34747 Mdot
.48406 .54397 Mdot
.55929 .61568 Mdot
.33533 .41885 Mdot
.4425 .53921 Mdot
.76242 .49095 Mdot
.4968 .72989 Mdot
.63242 .45828 Mdot
.28202 .44308 Mdot
.2241 .47365 Mdot
.44231 .31488 Mdot
.44187 .34243 Mdot
.82043 .4748 Mdot
.82995 .62854 Mdot
.54807 .6743 Mdot
.59589 .26841 Mdot
.41894 .33108 Mdot
.43584 .30405 Mdot
.28917 .43491 Mdot
.64535 .35545 Mdot
.65354 .40409 Mdot
.25498 .41513 Mdot
.41493 .77333 Mdot
.63623 .37687 Mdot
.76957 .61678 Mdot
.27082 .45832 Mdot
.6563 .57186 Mdot
.77292 .36663 Mdot
.31809 .58395 Mdot
.37471 .73274 Mdot
.45702 .26787 Mdot
.61032 .60806 Mdot
.42006 .19392 Mdot
.30063 .42817 Mdot
.42858 .55869 Mdot
.4688 .36663 Mdot
.6514 .60881 Mdot
.59751 .61709 Mdot
.57666 .59898 Mdot
.38099 .56074 Mdot
.74346 .44074 Mdot
.60616 .6089 Mdot
.49707 .73782 Mdot
.597 .5588 Mdot
.25926 .46661 Mdot
.33871 .58739 Mdot
.34008 .67592 Mdot
.34522 .45409 Mdot
.58971 .28748 Mdot
.54454 .57771 Mdot
.41962 .34366 Mdot
.52055 .60455 Mdot
.43494 .32595 Mdot
.4012 .31242 Mdot
.25965 .69492 Mdot
.64845 .39661 Mdot
.64968 .61584 Mdot
.28313 .45575 Mdot
.65441 .4039 Mdot
.51946 .60736 Mdot
.77134 .28731 Mdot
.45086 .28585 Mdot
.90066 .532 Mdot
.43506 .34188 Mdot
.44727 .56403 Mdot
.62985 .35756 Mdot
.64279 .44615 Mdot
.44623 .73081 Mdot
.65117 .36582 Mdot
.2823 .49842 Mdot
.66577 .34155 Mdot
.34592 .76626 Mdot
.58609 .36929 Mdot
.44539 .30921 Mdot
.44093 .28817 Mdot
.53281 .58156 Mdot
.58096 .58679 Mdot
.43095 .74538 Mdot
.46511 .54311 Mdot
.58574 .56634 Mdot
.26852 .43105 Mdot
.36238 .38277 Mdot
.43145 .22614 Mdot
.61018 .37079 Mdot
.42414 .3004 Mdot
.59656 .61604 Mdot
.67039 .59286 Mdot
.64007 .60418 Mdot
.36583 .42683 Mdot
.76796 .6261 Mdot
.59548 .59009 Mdot
.53959 .57578 Mdot
.27424 .40883 Mdot
.32053 .48552 Mdot
.65926 .24521 Mdot
.25387 .67973 Mdot
.58463 .62547 Mdot
.33358 .57095 Mdot
.34043 .56086 Mdot
.53541 .58145 Mdot
.60744 .46156 Mdot
.35594 .63847 Mdot
.62043 .59587 Mdot
.52148 .7327 Mdot
.24283 .45287 Mdot
.49643 .55873 Mdot
.28217 .41393 Mdot
.61411 .4239 Mdot
.50218 .55063 Mdot
.26392 .43553 Mdot
.47893 .76205 Mdot
.48021 .53722 Mdot
.42337 .38351 Mdot
.36948 .56414 Mdot
.60079 .57831 Mdot
.79794 .45275 Mdot
.31569 .4516 Mdot
.44741 .30198 Mdot
.62426 .36281 Mdot
.45279 .29741 Mdot
.21666 .43348 Mdot
.39745 .76395 Mdot
.48944 .55642 Mdot
.41915 .34414 Mdot
.54423 .68543 Mdot
.32967 .57572 Mdot
.43355 .33991 Mdot
.66054 .57083 Mdot
.56908 .56407 Mdot
.78215 .68046 Mdot
.56277 .59168 Mdot
.36015 .37913 Mdot
.4599 .32653 Mdot
.50522 .55185 Mdot
.61311 .59062 Mdot
.25456 .45043 Mdot
.50504 .53506 Mdot
.60472 .59605 Mdot
.32228 .43143 Mdot
.61978 .58638 Mdot
.34616 .59566 Mdot
.64833 .3198 Mdot
.44877 .71192 Mdot
.37373 .54343 Mdot
.37661 .58031 Mdot
.50714 .72228 Mdot
.62594 .57677 Mdot
.26143 .49748 Mdot
.62986 .37654 Mdot
.63478 .61774 Mdot
.33578 .73077 Mdot
.63215 .35034 Mdot
.6366 .36488 Mdot
.67652 .5856 Mdot
.43148 .34632 Mdot
.29399 .44023 Mdot
.32986 .5815 Mdot
.39354 .27101 Mdot
.60617 .60613 Mdot
.66435 .61476 Mdot
.37593 .57722 Mdot
.45331 .30571 Mdot
.66305 .60296 Mdot
.52937 .32478 Mdot
.46839 .75099 Mdot
.46931 .31629 Mdot
.55329 .57188 Mdot
.78922 .60164 Mdot
.61953 .34291 Mdot
.4187 .19425 Mdot
.3595 .45231 Mdot
.25235 .42263 Mdot
.45762 .54407 Mdot
.72522 .22983 Mdot
.34454 .5627 Mdot
.58299 .31285 Mdot
.63328 .60724 Mdot
.59365 .6078 Mdot
.65588 .35873 Mdot
.59882 .57236 Mdot
.60804 .37237 Mdot
.36437 .40501 Mdot
.84616 .60811 Mdot
.61967 .39558 Mdot
.62559 .3898 Mdot
.63255 .70188 Mdot
.34071 .41768 Mdot
.62408 .35355 Mdot
.59625 .57539 Mdot
.21146 .44586 Mdot
.57736 .5361 Mdot
.35831 .60481 Mdot
.38845 .56391 Mdot
.61831 .40798 Mdot
.78847 .55286 Mdot
.65398 .56896 Mdot
.75842 .59086 Mdot
.3526 .6403 Mdot
.4136 .31858 Mdot
.65221 .62665 Mdot
.47148 .54392 Mdot
.29456 .41782 Mdot
.61143 .64197 Mdot
.59557 .57903 Mdot
.64472 .39677 Mdot
.32125 .59444 Mdot
.43414 .33596 Mdot
.43931 .54187 Mdot
.22135 .42726 Mdot
.36643 .57185 Mdot
.60289 .3848 Mdot
.81637 .50426 Mdot
.39842 .58543 Mdot
.42689 .55156 Mdot
.60864 .62412 Mdot
.62602 .63817 Mdot
.41968 .55282 Mdot
.42903 .31557 Mdot
.24737 .42734 Mdot
.43341 .55294 Mdot
.46404 .69377 Mdot
.45188 .76245 Mdot
.60033 .62855 Mdot
.62827 .40214 Mdot
.42821 .29955 Mdot
.4751 .5603 Mdot
.20013 .62105 Mdot
.5661 .61086 Mdot
.77005 .61762 Mdot
.39932 .56139 Mdot
.47458 .54142 Mdot
.65605 .40214 Mdot
.33419 .58352 Mdot
.67121 .58929 Mdot
.49583 .74235 Mdot
.59118 .56517 Mdot
.53809 .58156 Mdot
.26203 .4415 Mdot
.43005 .33063 Mdot
.53549 .52788 Mdot
.29146 .41953 Mdot
.63462 .36441 Mdot
.74944 .60705 Mdot
.66476 .36128 Mdot
.66686 .35776 Mdot
.60784 .31125 Mdot
.45752 .30396 Mdot
.72409 .22763 Mdot
.40715 .57166 Mdot
.63453 .59352 Mdot
.40818 .31863 Mdot
.61908 .35864 Mdot
.63094 .57631 Mdot
.6084 .37085 Mdot
.59972 .39819 Mdot
.5814 .56637 Mdot
.62472 .56418 Mdot
.49957 .74214 Mdot
.78541 .5959 Mdot
.33701 .59121 Mdot
.64133 .34287 Mdot
.78677 .58031 Mdot
.60001 .60826 Mdot
.5862 .58249 Mdot
.51963 .60218 Mdot
.38004 .57272 Mdot
.72278 .63341 Mdot
.62838 .61147 Mdot
.35139 .69914 Mdot
.64036 .58146 Mdot
.60227 .40964 Mdot
.38495 .33233 Mdot
.66849 .57344 Mdot
.26763 .40817 Mdot
.64306 .34255 Mdot
.31759 .58565 Mdot
.60764 .42697 Mdot
.69004 .55138 Mdot
.42417 .30925 Mdot
.63019 .3889 Mdot
.24694 .42164 Mdot
.45031 .30568 Mdot
.46339 .31392 Mdot
.51805 .60797 Mdot
.24598 .43664 Mdot
.32047 .59461 Mdot
.449 .32954 Mdot
.67907 .52416 Mdot
.4464 .30794 Mdot
.71006 .57124 Mdot
.55825 .59989 Mdot
.49551 .73977 Mdot
.44181 .54892 Mdot
.52916 .54036 Mdot
.45492 .32858 Mdot
.37259 .57518 Mdot
.6618 .60445 Mdot
.60729 .38825 Mdot
.33692 .56636 Mdot
.76798 .37601 Mdot
.24518 .41998 Mdot
.62149 .332 Mdot
.39571 .27175 Mdot
.63703 .34555 Mdot
.37687 .73739 Mdot
.31404 .58504 Mdot
.42266 .56341 Mdot
.43979 .70914 Mdot
.45876 .55059 Mdot
.58219 .62971 Mdot
.65973 .60674 Mdot
.57314 .60024 Mdot
.29153 .41036 Mdot
.3856 .56342 Mdot
.61157 .40053 Mdot
.56343 .51275 Mdot
.45485 .30444 Mdot
.53444 .66121 Mdot
.43046 .55712 Mdot
.66813 .59487 Mdot
.61728 .36238 Mdot
.59693 .39125 Mdot
.74857 .42254 Mdot
.3071 .4372 Mdot
.55826 .52953 Mdot
.60051 .62968 Mdot
.57442 .51725 Mdot
.45656 .32741 Mdot
.55461 .30399 Mdot
.2527 .45651 Mdot
.90225 .52846 Mdot
.28857 .41948 Mdot
.47207 .57566 Mdot
.6147 .35378 Mdot
.34873 .57714 Mdot
.57442 .61197 Mdot
.62881 .31013 Mdot
.6696 .37773 Mdot
.30537 .60735 Mdot
.33836 .58167 Mdot
.37241 .3221 Mdot
.41158 .32299 Mdot
.43841 .54109 Mdot
.64189 .58218 Mdot
.6121 .56809 Mdot
.58152 .57679 Mdot
.41536 .30731 Mdot
.63142 .56656 Mdot
.38361 .32179 Mdot
.68704 .55135 Mdot
.33727 .73327 Mdot
.28144 .4502 Mdot
.20073 .39288 Mdot
.66216 .34817 Mdot
.73237 .62527 Mdot
.70584 .57662 Mdot
.49381 .73183 Mdot
.40302 .32519 Mdot
.51014 .54517 Mdot
.28986 .43783 Mdot
.4259 .23097 Mdot
.28202 .45106 Mdot
.71294 .75439 Mdot
.79421 .49862 Mdot
.38876 .36213 Mdot
.60379 .56707 Mdot
.25803 .44211 Mdot
.79059 .55752 Mdot
.43493 .55052 Mdot
.393 .59037 Mdot
.68299 .54251 Mdot
.77049 .38826 Mdot
.33836 .59258 Mdot
.57888 .61828 Mdot
.66246 .34228 Mdot
.57239 .60812 Mdot
.57445 .61296 Mdot
.63547 .60688 Mdot
.47113 .30208 Mdot
.55771 .60141 Mdot
.5764 .58993 Mdot
.15306 .53587 Mdot
.37107 .62072 Mdot
.31009 .41116 Mdot
.64493 .44707 Mdot
.32757 .57706 Mdot
.61306 .42342 Mdot
.44511 .71052 Mdot
.45025 .33862 Mdot
.74697 .42527 Mdot
.6626 .57871 Mdot
.59085 .31232 Mdot
.4502 .34077 Mdot
.35178 .60205 Mdot
.47358 .54611 Mdot
.53188 .19922 Mdot
.34023 .42642 Mdot
.46859 .55627 Mdot
.31881 .42844 Mdot
.69368 .58172 Mdot
.61462 .38789 Mdot
.45921 .54969 Mdot
.43789 .33521 Mdot
.27216 .4512 Mdot
.5059 .73048 Mdot
.58191 .59765 Mdot
.27792 .44388 Mdot
.45994 .53811 Mdot
.464 .72853 Mdot
.44903 .71872 Mdot
.25994 .44553 Mdot
.39974 .33811 Mdot
.45881 .31769 Mdot
.32518 .57539 Mdot
.6072 .36057 Mdot
.65248 .38119 Mdot
.45397 .31128 Mdot
.40625 .22821 Mdot
.60833 .60562 Mdot
.59238 .59468 Mdot
.42949 .70337 Mdot
.65382 .5955 Mdot
.34541 .49916 Mdot
.46655 .55415 Mdot
.64649 .39167 Mdot
.66071 .60551 Mdot
.66328 .60082 Mdot
.5853 .62371 Mdot
.41743 .77664 Mdot
.29286 .41193 Mdot
.63331 .56494 Mdot
.35886 .59659 Mdot
.77109 .38135 Mdot
.5727 .58479 Mdot
.41809 .54636 Mdot
.61414 .35324 Mdot
.50408 .33108 Mdot
.44594 .30132 Mdot
.29462 .4559 Mdot
.28706 .45614 Mdot
.28184 .6705 Mdot
.6609 .357 Mdot
.46749 .55592 Mdot
.30796 .46721 Mdot
.4662 .56282 Mdot
.3382 .57952 Mdot
.54663 .64585 Mdot
.33291 .49983 Mdot
.31126 .41201 Mdot
.47238 .32724 Mdot
.63537 .62006 Mdot
.57489 .58445 Mdot
.6054 .27797 Mdot
.60609 .58208 Mdot
.35324 .58997 Mdot
.41884 .33785 Mdot
.6298 .38706 Mdot
.3384 .59596 Mdot
.42927 .34381 Mdot
.65215 .37031 Mdot
.59073 .55948 Mdot
.63443 .57799 Mdot
.63063 .36211 Mdot
.60271 .37838 Mdot
.6188 .60536 Mdot
.27384 .72125 Mdot
.63884 .39824 Mdot
.62708 .36027 Mdot
.77058 .38326 Mdot
.3324 .41967 Mdot
.50027 .53177 Mdot
.41911 .34638 Mdot
.57663 .59168 Mdot
.28735 .44901 Mdot
.34577 .57213 Mdot
.6366 .3932 Mdot
.6196 .63916 Mdot
.60136 .60368 Mdot
.33199 .5728 Mdot
.38555 .56917 Mdot
.36676 .56589 Mdot
.43703 .28913 Mdot
.66232 .57647 Mdot
.6265 .35532 Mdot
.41396 .30245 Mdot
.3221 .57301 Mdot
.38458 .57682 Mdot
.37798 .78551 Mdot
.6132 .60636 Mdot
.38289 .56544 Mdot
.74756 .26382 Mdot
.48842 .76411 Mdot
.47951 .56298 Mdot
.25998 .40422 Mdot
.21044 .45931 Mdot
.423 .58525 Mdot
.42681 .3288 Mdot
.53235 .66275 Mdot
.35321 .60483 Mdot
.44698 .54139 Mdot
.5872 .59466 Mdot
.64439 .63587 Mdot
.34097 .56553 Mdot
.39543 .76315 Mdot
.65245 .39164 Mdot
.67197 .44945 Mdot
.32747 .57808 Mdot
.25949 .44759 Mdot
.25422 .45892 Mdot
.28817 .42508 Mdot
.60678 .63404 Mdot
.70992 .66636 Mdot
.66193 .50483 Mdot
.71866 .61943 Mdot
.41282 .32641 Mdot
.59711 .39296 Mdot
.77647 .37317 Mdot
.63838 .36585 Mdot
.31087 .42535 Mdot
.37271 .57623 Mdot
.65672 .3645 Mdot
.46049 .30549 Mdot
.45816 .32117 Mdot
.33555 .41981 Mdot
.28179 .41618 Mdot
.27936 .43059 Mdot
.63223 .337 Mdot
.61034 .36132 Mdot
.61823 .5714 Mdot
.61861 .40049 Mdot
.35994 .42479 Mdot
.36314 .41431 Mdot
.33317 .43597 Mdot
.43444 .31448 Mdot
.64652 .37474 Mdot
.60629 .57735 Mdot
.49527 .67982 Mdot
.28963 .46719 Mdot
.32083 .58889 Mdot
.79049 .36023 Mdot
.8194 .64202 Mdot
.64674 .62536 Mdot
.41761 .3135 Mdot
.45922 .55966 Mdot
.57702 .60653 Mdot
.25128 .42256 Mdot
.42443 .57495 Mdot
.49453 .53897 Mdot
.56988 .57998 Mdot
.56221 .57425 Mdot
.42823 .30202 Mdot
.4445 .70714 Mdot
.44337 .54232 Mdot
.51717 .62169 Mdot
.41441 .33632 Mdot
.27565 .46294 Mdot
.18436 .44511 Mdot
.68343 .31652 Mdot
.36387 .67426 Mdot
.49993 .54708 Mdot
.56464 .60985 Mdot
.26616 .4285 Mdot
.34315 .59909 Mdot
.27132 .42637 Mdot
.61108 .4189 Mdot
.33002 .41769 Mdot
.61316 .58183 Mdot
.62791 .35349 Mdot
.46054 .31834 Mdot
.436 .68121 Mdot
.53489 .5077 Mdot
.25753 .45268 Mdot
.4212 .55857 Mdot
.61329 .56259 Mdot
.68519 .52987 Mdot
.52837 .54127 Mdot
.59056 .57846 Mdot
.43714 .32506 Mdot
.6122 .3679 Mdot
.44479 .29539 Mdot
.5132 .54105 Mdot
.61168 .45578 Mdot
.44352 .3002 Mdot
.69087 .67734 Mdot
.3692 .59579 Mdot
.40387 .76902 Mdot
.6235 .59418 Mdot
.43592 .33388 Mdot
.56612 .58128 Mdot
.64676 .34679 Mdot
.46847 .76314 Mdot
.47581 .74608 Mdot
.44976 .31979 Mdot
.47158 .56888 Mdot
.4574 .73021 Mdot
.49471 .52883 Mdot
.4185 .32913 Mdot
.50138 .76821 Mdot
.47706 .5541 Mdot
.36331 .5713 Mdot
.38649 .57328 Mdot
.36696 .579 Mdot
.59157 .59047 Mdot
.80496 .56813 Mdot
.33381 .56489 Mdot
.49286 .32249 Mdot
.35648 .59342 Mdot
.44523 .57919 Mdot
.62467 .26757 Mdot
.37444 .58967 Mdot
.61599 .58851 Mdot
.68727 .58364 Mdot
.53497 .66944 Mdot
.24063 .43803 Mdot
.51378 .20616 Mdot
.15385 .526 Mdot
.60078 .60994 Mdot
.78404 .36296 Mdot
.64203 .3147 Mdot
.42271 .56555 Mdot
.482 .74166 Mdot
.55418 .69688 Mdot
.64077 .36217 Mdot
.44181 .70852 Mdot
.62763 .33244 Mdot
.44177 .55723 Mdot
.59552 .5929 Mdot
.6453 .34386 Mdot
.58652 .32392 Mdot
.4529 .79627 Mdot
.61182 .28553 Mdot
.64898 .37507 Mdot
.42431 .33482 Mdot
.4246 .3244 Mdot
.44113 .32488 Mdot
.27093 .41588 Mdot
.6274 .39172 Mdot
.59233 .56111 Mdot
.25765 .41914 Mdot
.6136 .61716 Mdot
.45285 .31575 Mdot
.48561 .74095 Mdot
.62611 .38902 Mdot
.62186 .59679 Mdot
.7868 .56865 Mdot
.32141 .43713 Mdot
.33198 .57126 Mdot
.78688 .3603 Mdot
.26411 .4046 Mdot
.40994 .34695 Mdot
.61416 .41684 Mdot
.36696 .61942 Mdot
.52061 .63874 Mdot
.60662 .6274 Mdot
.63332 .58646 Mdot
.53004 .66327 Mdot
.79854 .49547 Mdot
.46049 .53158 Mdot
.25944 .41993 Mdot
.32939 .41925 Mdot
.56488 .60117 Mdot
.62668 .39426 Mdot
.31266 .59617 Mdot
.39856 .57461 Mdot
.54209 .54756 Mdot
.44829 .72676 Mdot
.49692 .73766 Mdot
.65393 .58709 Mdot
.67075 .66929 Mdot
.24626 .42375 Mdot
.47504 .56479 Mdot
.4422 .7243 Mdot
.36045 .57911 Mdot
.62382 .617 Mdot
.66249 .43618 Mdot
.6352 .39081 Mdot
.28472 .44262 Mdot
.46287 .29455 Mdot
.39613 .58814 Mdot
.33493 .43293 Mdot
.565 .60157 Mdot
.66313 .60162 Mdot
.43567 .33841 Mdot
.61158 .41449 Mdot
.35611 .56629 Mdot
.26161 .41593 Mdot
.353 .57778 Mdot
.61156 .38319 Mdot
.63802 .3933 Mdot
.63238 .61607 Mdot
.56233 .52658 Mdot
.26326 .45639 Mdot
.60369 .63538 Mdot
.27248 .44033 Mdot
.32015 .48401 Mdot
.45534 .29345 Mdot
.63648 .61617 Mdot
.64486 .41212 Mdot
.45463 .31529 Mdot
.60077 .61225 Mdot
.52783 .65491 Mdot
.6653 .59944 Mdot
.25708 .44217 Mdot
.40262 .56627 Mdot
.3607 .57315 Mdot
.69204 .62134 Mdot
.75822 .39287 Mdot
.6569 .59631 Mdot
.32055 .4482 Mdot
.66688 .52061 Mdot
.43142 .30332 Mdot
.62517 .34575 Mdot
.21311 .36401 Mdot
.44022 .30922 Mdot
.62474 .59159 Mdot
.35426 .58568 Mdot
.60101 .38708 Mdot
.50066 .55377 Mdot
.40085 .72663 Mdot
.52306 .55131 Mdot
.56257 .52993 Mdot
.45435 .53439 Mdot
.601 .26825 Mdot
.27658 .42952 Mdot
.61883 .36028 Mdot
.41751 .31742 Mdot
.42673 .3061 Mdot
.31632 .42707 Mdot
.76365 .38553 Mdot
.68872 .28084 Mdot
.7412 .25182 Mdot
.32837 .44704 Mdot
.36635 .58518 Mdot
.47095 .7614 Mdot
.28983 .426 Mdot
.31071 .41531 Mdot
.35479 .45121 Mdot
.6003 .27924 Mdot
.6471 .36301 Mdot
.60028 .60415 Mdot
.77905 .36405 Mdot
.6358 .60219 Mdot
.36835 .67369 Mdot
.45174 .3145 Mdot
.62585 .34539 Mdot
.37903 .40784 Mdot
.59375 .63349 Mdot
.58703 .61804 Mdot
.36477 .39055 Mdot
.46596 .54532 Mdot
.22169 .63998 Mdot
.6418 .59639 Mdot
.27174 .4193 Mdot
.67484 .392 Mdot
.43829 .5542 Mdot
.78785 .569 Mdot
.45677 .32967 Mdot
.48461 .55831 Mdot
.43693 .55528 Mdot
.66476 .6735 Mdot
.63553 .32979 Mdot
.65694 .3743 Mdot
.38106 .568 Mdot
.65296 .28431 Mdot
.45573 .33189 Mdot
.56147 .28843 Mdot
.59647 .57608 Mdot
.3982 .31847 Mdot
.3551 .5439 Mdot
.60527 .61338 Mdot
.51885 .61076 Mdot
.74844 .42186 Mdot
.63799 .63246 Mdot
.69316 .56638 Mdot
.44156 .31323 Mdot
.33899 .72686 Mdot
.61129 .56442 Mdot
.27973 .44322 Mdot
.64348 .35321 Mdot
.62682 .32853 Mdot
.33429 .59687 Mdot
.3662 .44923 Mdot
.87118 .57479 Mdot
.62786 .345 Mdot
.58171 .59549 Mdot
.43541 .30311 Mdot
.49429 .55644 Mdot
.44466 .54792 Mdot
.46677 .56964 Mdot
.63751 .38776 Mdot
.43799 .55211 Mdot
.59845 .30439 Mdot
.44294 .7087 Mdot
.73762 .62023 Mdot
.44705 .32459 Mdot
.36158 .58716 Mdot
.55844 .54356 Mdot
.33046 .47401 Mdot
.64391 .58263 Mdot
.36692 .67385 Mdot
.64073 .31802 Mdot
.35694 .58915 Mdot
.57613 .61054 Mdot
.44493 .53608 Mdot
.52216 .71882 Mdot
.3303 .60698 Mdot
.45813 .53307 Mdot
.65175 .61999 Mdot
.65084 .35683 Mdot
.46589 .55693 Mdot
.63256 .38447 Mdot
.57787 .61467 Mdot
.36398 .6481 Mdot
.63835 .34255 Mdot
.50037 .20912 Mdot
.404 .57849 Mdot
.43939 .34386 Mdot
.65629 .63085 Mdot
.58536 .62621 Mdot
.74305 .64186 Mdot
.48072 .56088 Mdot
.44097 .20586 Mdot
.27356 .44563 Mdot
.20901 .63769 Mdot
.28763 .40058 Mdot
.37122 .37682 Mdot
.51483 .33519 Mdot
.6362 .63746 Mdot
.76292 .38767 Mdot
.72106 .65881 Mdot
.40032 .3358 Mdot
.73267 .65087 Mdot
.58078 .58691 Mdot
.60732 .62388 Mdot
.2734 .44142 Mdot
.40677 .29763 Mdot
.67473 .57654 Mdot
.44305 .72511 Mdot
.35344 .60252 Mdot
.62642 .37129 Mdot
.58974 .58679 Mdot
.57723 .34 Mdot
.26446 .45124 Mdot
.63851 .46078 Mdot
.61892 .59308 Mdot
.46635 .54556 Mdot
.404 .3059 Mdot
.46072 .31988 Mdot
.25122 .43969 Mdot
.251 .44277 Mdot
.5829 .62418 Mdot
.42881 .29422 Mdot
.62627 .57197 Mdot
.45903 .72999 Mdot
.46257 .53687 Mdot
.3366 .5768 Mdot
.60924 .57484 Mdot
.70993 .34356 Mdot
.47922 .8413 Mdot
.60533 .63321 Mdot
.66447 .35379 Mdot
.28005 .43412 Mdot
.30268 .41514 Mdot
.65146 .38203 Mdot
.30437 .4162 Mdot
.67551 .44707 Mdot
.80393 .57202 Mdot
.34132 .57927 Mdot
.6382 .50112 Mdot
.37335 .58495 Mdot
.48036 .55981 Mdot
.61522 .60599 Mdot
.32984 .2396 Mdot
.32734 .4475 Mdot
.46845 .60382 Mdot
.45103 .31011 Mdot
.46565 .56562 Mdot
.64738 .57083 Mdot
.34358 .55397 Mdot
.29917 .42367 Mdot
.41725 .55421 Mdot
.63287 .61073 Mdot
.63544 .33857 Mdot
.66762 .61149 Mdot
.44394 .56188 Mdot
.46555 .5598 Mdot
.45658 .52972 Mdot
.42926 .34383 Mdot
.60776 .37731 Mdot
.37192 .32591 Mdot
.32244 .43971 Mdot
.58175 .56727 Mdot
.57928 .59766 Mdot
.59917 .37908 Mdot
.63161 .58995 Mdot
.42763 .29371 Mdot
.68835 .1905 Mdot
.37129 .56893 Mdot
.48916 .55986 Mdot
.52868 .23531 Mdot
.45777 .52913 Mdot
.65698 .61377 Mdot
.59084 .70461 Mdot
.66533 .43893 Mdot
.43347 .34491 Mdot
.53872 .58683 Mdot
.31051 .41003 Mdot
.35873 .56746 Mdot
.46074 .30418 Mdot
.64941 .5734 Mdot
.61501 .58489 Mdot
.35805 .58779 Mdot
.38014 .39601 Mdot
.38335 .5897 Mdot
.41583 .32196 Mdot
.4998 .56214 Mdot
.49731 .67907 Mdot
.60923 .59977 Mdot
.46701 .55111 Mdot
.61382 .37219 Mdot
.4119 .31763 Mdot
.74397 .4454 Mdot
.4395 .55732 Mdot
.39773 .26851 Mdot
.45975 .32378 Mdot
.6105 .62627 Mdot
.65691 .35203 Mdot
.60351 .33611 Mdot
.61502 .36719 Mdot
.30682 .71443 Mdot
.36926 .3067 Mdot
.27632 .43313 Mdot
.43505 .3129 Mdot
.29436 .44761 Mdot
.37273 .59365 Mdot
.45013 .75929 Mdot
.25332 .44727 Mdot
.65601 .39335 Mdot
.28988 .45117 Mdot
.62655 .57255 Mdot
.44802 .34079 Mdot
.27219 .45939 Mdot
.59761 .57398 Mdot
.56585 .5631 Mdot
.45788 .55569 Mdot
.31313 .5929 Mdot
.44579 .71789 Mdot
.62867 .59768 Mdot
.47257 .5497 Mdot
.61931 .59907 Mdot
.42924 .29337 Mdot
.42356 .67605 Mdot
.5722 .57069 Mdot
.32619 .44903 Mdot
.54763 .19167 Mdot
.33361 .42478 Mdot
.51015 .4776 Mdot
.61349 .61579 Mdot
.61065 .60226 Mdot
.61567 .5627 Mdot
.77983 .39334 Mdot
.4002 .34394 Mdot
.56351 .62215 Mdot
.27115 .40607 Mdot
.64234 .36909 Mdot
.66013 .36148 Mdot
.55954 .68364 Mdot
.46849 .5537 Mdot
.43826 .28992 Mdot
.60966 .60378 Mdot
.45619 .56223 Mdot
.42513 .72676 Mdot
.63751 .27688 Mdot
.35498 .43979 Mdot
.32035 .42427 Mdot
.61092 .3519 Mdot
.28485 .40888 Mdot
.64679 .57186 Mdot
.44071 .55283 Mdot
.37231 .29424 Mdot
.48488 .30782 Mdot
.35775 .56785 Mdot
.60497 .62028 Mdot
.42654 .78185 Mdot
.27381 .40901 Mdot
.24582 .43351 Mdot
.62336 .571 Mdot
.67748 .32642 Mdot
.43859 .8246 Mdot
.40777 .31635 Mdot
.70406 .52972 Mdot
.81163 .45903 Mdot
.64471 .7562 Mdot
.42604 .31416 Mdot
.51906 .6146 Mdot
.23775 .43603 Mdot
.26347 .63359 Mdot
.64101 .36531 Mdot
.355 .56681 Mdot
.60081 .5738 Mdot
.65606 .39222 Mdot
.33235 .44341 Mdot
.60509 .3979 Mdot
.46061 .54337 Mdot
.45164 .33971 Mdot
.29443 .41594 Mdot
.4618 .29142 Mdot
.63966 .4181 Mdot
.37209 .57995 Mdot
.35502 .69893 Mdot
.6806 .53197 Mdot
.74996 .41704 Mdot
.65648 .57261 Mdot
.37538 .62059 Mdot
.64234 .56753 Mdot
.6248 .32726 Mdot
.62283 .59332 Mdot
.55719 .56972 Mdot
.23852 .42818 Mdot
.60225 .62838 Mdot
.60098 .57558 Mdot
.78644 .5734 Mdot
.60151 .61672 Mdot
.58031 .62025 Mdot
.60845 .62782 Mdot
.66301 .37124 Mdot
.63668 .61042 Mdot
.60602 .36949 Mdot
.58343 .3171 Mdot
.32217 .4392 Mdot
.37677 .5889 Mdot
.37665 .58749 Mdot
.37844 .65663 Mdot
.42418 .7804 Mdot
.77775 .36764 Mdot
.63882 .37574 Mdot
.45603 .327 Mdot
.61782 .57072 Mdot
.39374 .80021 Mdot
.36566 .64921 Mdot
.24162 .4472 Mdot
.27294 .45596 Mdot
.57658 .57828 Mdot
.80757 .65528 Mdot
.64137 .59114 Mdot
.4221 .71006 Mdot
.59212 .58976 Mdot
.6414 .61266 Mdot
.29053 .402 Mdot
.37588 .73623 Mdot
.62776 .56368 Mdot
.64252 .33002 Mdot
.35131 .56794 Mdot
.4637 .55458 Mdot
.36875 .65193 Mdot
.8204 .48924 Mdot
.699 .34861 Mdot
.61163 .56182 Mdot
.259 .41625 Mdot
.6433 .39237 Mdot
.43128 .70456 Mdot
.41372 .30334 Mdot
.40183 .73162 Mdot
.71105 .57726 Mdot
.40548 .321 Mdot
.36293 .57013 Mdot
.28412 .4664 Mdot
.59252 .62693 Mdot
.26274 .42795 Mdot
.60048 .63664 Mdot
.41776 .72398 Mdot
.33951 .5774 Mdot
.66618 .34012 Mdot
.42557 .33616 Mdot
.65709 .38774 Mdot
.63122 .4587 Mdot
.36192 .65062 Mdot
.17792 .60278 Mdot
.3348 .43115 Mdot
.56163 .5045 Mdot
.61989 .35266 Mdot
.56711 .61249 Mdot
.73793 .25076 Mdot
.61611 .38075 Mdot
.63921 .34042 Mdot
.4008 .70341 Mdot
.37497 .74339 Mdot
.61256 .63484 Mdot
.63283 .40275 Mdot
.29197 .46631 Mdot
.33957 .58467 Mdot
.58485 .57722 Mdot
.44596 .55448 Mdot
.65661 .36216 Mdot
.30569 .42418 Mdot
.37148 .72566 Mdot
.27678 .41713 Mdot
.64341 .35838 Mdot
.3038 .45422 Mdot
.37454 .31819 Mdot
.25413 .44823 Mdot
.61883 .57918 Mdot
.60939 .60297 Mdot
.59211 .35072 Mdot
.63791 .39341 Mdot
.65743 .61334 Mdot
.63392 .60038 Mdot
.62279 .35513 Mdot
.31369 .46357 Mdot
.69309 .40095 Mdot
.65432 .61234 Mdot
.60497 .60527 Mdot
.37653 .57131 Mdot
.46833 .70378 Mdot
.43497 .69122 Mdot
.62548 .57452 Mdot
.36877 .58222 Mdot
.62805 .33791 Mdot
.62021 .60283 Mdot
.37187 .73446 Mdot
.23566 .44786 Mdot
.63373 .57133 Mdot
.49949 .55254 Mdot
.67116 .57891 Mdot
.52162 .81171 Mdot
.61605 .56304 Mdot
.63413 .3581 Mdot
.6352 .35127 Mdot
.24918 .45963 Mdot
.62974 .3642 Mdot
.48696 .56012 Mdot
.45783 .31432 Mdot
.71579 .55264 Mdot
.47137 .56547 Mdot
.47282 .52981 Mdot
.40715 .57174 Mdot
.42926 .55313 Mdot
.41887 .53841 Mdot
.35607 .43913 Mdot
.49715 .5456 Mdot
.61116 .36539 Mdot
.58067 .43401 Mdot
.51244 .54619 Mdot
.43037 .29164 Mdot
.43671 .55418 Mdot
.63749 .57267 Mdot
.55141 .56956 Mdot
.6396 .44442 Mdot
.4117 .30427 Mdot
.52893 .53397 Mdot
.58545 .57692 Mdot
.66376 .43852 Mdot
.58834 .5862 Mdot
.32945 .60017 Mdot
.62656 .38665 Mdot
.27097 .41389 Mdot
.33472 .57925 Mdot
.44775 .53849 Mdot
.32905 .57203 Mdot
.26664 .43228 Mdot
.44328 .33337 Mdot
.61735 .58012 Mdot
.34857 .6072 Mdot
.37035 .59342 Mdot
.6701 .61651 Mdot
.63591 .34935 Mdot
.5255 .55121 Mdot
.61864 .607 Mdot
.61817 .5629 Mdot
.65319 .38062 Mdot
.40952 .1914 Mdot
.59366 .62522 Mdot
.51664 .61195 Mdot
.63271 .3238 Mdot
.45521 .56344 Mdot
.26545 .4158 Mdot
.61496 .63938 Mdot
.44714 .29849 Mdot
.45445 .31031 Mdot
.32346 .4501 Mdot
.65672 .37084 Mdot
.30112 .41663 Mdot
.58674 .63115 Mdot
.43518 .55321 Mdot
.5821 .58139 Mdot
.35712 .38423 Mdot
.46959 .20387 Mdot
.60213 .38576 Mdot
.3253 .43596 Mdot
.437 .7439 Mdot
.42835 .34646 Mdot
.34552 .42755 Mdot
.63907 .32806 Mdot
.64113 .4009 Mdot
.65028 .38026 Mdot
.36522 .59435 Mdot
.28629 .41747 Mdot
.60787 .42503 Mdot
.61019 .42786 Mdot
.66597 .58843 Mdot
.58777 .57497 Mdot
.62036 .34234 Mdot
.33944 .46624 Mdot
.35966 .57146 Mdot
.28252 .40558 Mdot
.44836 .82946 Mdot
.40913 .31797 Mdot
.78812 .57083 Mdot
.6398 .57953 Mdot
.90718 .51945 Mdot
.64118 .59198 Mdot
.58423 .59122 Mdot
.61409 .42389 Mdot
.38812 .57706 Mdot
.343 .58617 Mdot
.62197 .35125 Mdot
.60297 .40135 Mdot
.33032 .59708 Mdot
.47534 .68723 Mdot
.49342 .81263 Mdot
.43013 .72082 Mdot
.60634 .3959 Mdot
.70707 .55415 Mdot
.43894 .32177 Mdot
.64741 .31841 Mdot
.37923 .32482 Mdot
.30137 .4571 Mdot
.25744 .4517 Mdot
.44203 .33766 Mdot
.58976 .62428 Mdot
.29954 .40438 Mdot
.65956 .57209 Mdot
.38996 .36673 Mdot
.52622 .59209 Mdot
.28588 .74502 Mdot
.62634 .58566 Mdot
.50468 .46677 Mdot
.613 .26662 Mdot
.66704 .60372 Mdot
.80557 .53846 Mdot
.35236 .56513 Mdot
.6193 .33027 Mdot
.40888 .30322 Mdot
.78009 .3614 Mdot
.60977 .60092 Mdot
.62571 .40325 Mdot
.41803 .33498 Mdot
.45295 .20767 Mdot
.51765 .62177 Mdot
.66886 .59384 Mdot
.72982 .23844 Mdot
.6689 .35697 Mdot
.26851 .41558 Mdot
.69421 .51022 Mdot
.60153 .40418 Mdot
.51987 .63275 Mdot
.31507 .46071 Mdot
.51919 .71002 Mdot
.61654 .40515 Mdot
.38709 .58557 Mdot
.62877 .37469 Mdot
.32682 .58881 Mdot
.60591 .42215 Mdot
.31797 .44219 Mdot
.59755 .62013 Mdot
.32038 .43961 Mdot
.31914 .58349 Mdot
.33157 .4328 Mdot
.40799 .30545 Mdot
.48551 .54091 Mdot
.4534 .31678 Mdot
.45933 .76273 Mdot
.75093 .46177 Mdot
.43218 .33078 Mdot
.59446 .69627 Mdot
.61239 .58235 Mdot
.59988 .40765 Mdot
.27535 .4124 Mdot
.2423 .41769 Mdot
.44671 .72056 Mdot
.6495 .36237 Mdot
.31181 .42899 Mdot
.68853 .53985 Mdot
.41338 .22285 Mdot
.5736 .56129 Mdot
.20552 .37601 Mdot
.62623 .35648 Mdot
.24637 .41505 Mdot
.42599 .70648 Mdot
.63313 .40686 Mdot
.2666 .45779 Mdot
.42227 .33144 Mdot
.4476 .29895 Mdot
.62752 .5836 Mdot
.44692 .28483 Mdot
.24073 .44004 Mdot
.62864 .4708 Mdot
.62611 .343 Mdot
.47922 .20324 Mdot
.3718 .5733 Mdot
.28691 .41013 Mdot
.45125 .54062 Mdot
.64358 .41305 Mdot
.29452 .44908 Mdot
.8615 .58798 Mdot
.44978 .8581 Mdot
.30952 .42774 Mdot
.62808 .38542 Mdot
.6408 .38755 Mdot
.64183 .6263 Mdot
.4458 .72516 Mdot
.30037 .42524 Mdot
.32523 .24138 Mdot
.49827 .74082 Mdot
.48563 .54368 Mdot
.15327 .53161 Mdot
.59677 .56094 Mdot
.65399 .57232 Mdot
.41325 .31391 Mdot
.58742 .61703 Mdot
.60345 .40043 Mdot
.64168 .59282 Mdot
.44993 .29497 Mdot
.32204 .45031 Mdot
.61452 .60151 Mdot
.36132 .56807 Mdot
.42541 .30166 Mdot
.43246 .29576 Mdot
.30136 .45366 Mdot
.65591 .3706 Mdot
.78279 .35283 Mdot
.28009 .4157 Mdot
.66495 .5778 Mdot
.47617 .54669 Mdot
.60749 .62771 Mdot
.61934 .30737 Mdot
.61655 .33504 Mdot
.28075 .40954 Mdot
.6394 .63892 Mdot
.43259 .30922 Mdot
.23678 .43193 Mdot
.5978 .56045 Mdot
.26638 .46016 Mdot
.44692 .57084 Mdot
.21149 .45026 Mdot
.64378 .41882 Mdot
.42072 .56372 Mdot
.64113 .40229 Mdot
.49481 .54584 Mdot
.28399 .67847 Mdot
.36259 .57139 Mdot
.32526 .41627 Mdot
.49344 .20902 Mdot
.32308 .43586 Mdot
.6009 .61543 Mdot
.61903 .58565 Mdot
.26837 .44105 Mdot
.37146 .58156 Mdot
.44625 .57843 Mdot
.37678 .59745 Mdot
.63035 .39018 Mdot
.54709 .68981 Mdot
.39433 .82979 Mdot
.23231 .43555 Mdot
.44867 .33591 Mdot
.68508 .31477 Mdot
.46905 .52991 Mdot
.40892 .30598 Mdot
.42806 .29742 Mdot
.32181 .57695 Mdot
.31319 .41687 Mdot
.65865 .33331 Mdot
.46229 .32715 Mdot
.61658 .41171 Mdot
.36639 .72457 Mdot
.43172 .55667 Mdot
.58553 .5181 Mdot
.44333 .537 Mdot
.44372 .7121 Mdot
.46026 .33315 Mdot
.60627 .58701 Mdot
.54843 .54007 Mdot
.41746 .33008 Mdot
.32414 .5703 Mdot
.52817 .58883 Mdot
.31287 .43126 Mdot
.76274 .2848 Mdot
.61799 .57793 Mdot
.61439 .61304 Mdot
.41214 .32594 Mdot
.81562 .51546 Mdot
.63727 .33057 Mdot
.65007 .35437 Mdot
.27734 .42943 Mdot
.40555 .69842 Mdot
.63722 .60735 Mdot
.6135 .58022 Mdot
.26631 .44314 Mdot
.4729 .55537 Mdot
.16254 .57683 Mdot
.60125 .60237 Mdot
.43797 .31613 Mdot
.52012 .60438 Mdot
.40014 .33865 Mdot
.54364 .58172 Mdot
.59628 .61335 Mdot
.67106 .58579 Mdot
.61213 .56085 Mdot
.45118 .31934 Mdot
.45159 .53503 Mdot
.49249 .53275 Mdot
.61182 .37093 Mdot
.56305 .59059 Mdot
.49981 .73891 Mdot
.60419 .60048 Mdot
.3572 .56539 Mdot
.43049 .69141 Mdot
.58674 .56479 Mdot
.5642 .58487 Mdot
.49603 .74427 Mdot
.57291 .60322 Mdot
.4122 .32852 Mdot
.64359 .38288 Mdot
.43198 .30778 Mdot
.44086 .34054 Mdot
.2945 .45115 Mdot
.33988 .56184 Mdot
.6003 .63512 Mdot
.34305 .60095 Mdot
.63097 .62685 Mdot
.5188 .54055 Mdot
.46346 .72945 Mdot
.42253 .71125 Mdot
.32196 .60247 Mdot
.61007 .57983 Mdot
.27089 .43131 Mdot
.30082 .4091 Mdot
.53164 .66107 Mdot
.61395 .64238 Mdot
.43465 .28455 Mdot
.43499 .33372 Mdot
.3634 .41355 Mdot
.19767 .43504 Mdot
.33999 .60546 Mdot
.44138 .57605 Mdot
.59794 .5593 Mdot
.61242 .61991 Mdot
.47329 .53235 Mdot
.29037 .44529 Mdot
.49643 .54469 Mdot
.35037 .44702 Mdot
.40264 .31777 Mdot
.42185 .31034 Mdot
.62237 .58229 Mdot
.79111 .68779 Mdot
.61319 .38882 Mdot
.64187 .38744 Mdot
.45335 .29589 Mdot
.33346 .42396 Mdot
.45494 .54478 Mdot
.79342 .32196 Mdot
.61348 .33953 Mdot
.38021 .58705 Mdot
.5685 .59625 Mdot
.30848 .45452 Mdot
.60768 .37191 Mdot
.3525 .60629 Mdot
.55757 .59551 Mdot
.32271 .45615 Mdot
.60435 .59017 Mdot
.62773 .48956 Mdot
.61344 .35697 Mdot
.46974 .71862 Mdot
.66368 .38071 Mdot
.44981 .31753 Mdot
.45302 .33605 Mdot
.59986 .61255 Mdot
.78873 .31387 Mdot
.682 .36802 Mdot
.46981 .31799 Mdot
.38274 .56948 Mdot
.48149 .53793 Mdot
.33495 .5642 Mdot
.27541 .44026 Mdot
.36211 .57007 Mdot
.2953 .44953 Mdot
.29478 .46856 Mdot
.6621 .34358 Mdot
.35743 .58787 Mdot
.78995 .52562 Mdot
.4418 .55224 Mdot
.3834 .56456 Mdot
.58405 .56998 Mdot
.64449 .62066 Mdot
.30266 .43134 Mdot
.34989 .6015 Mdot
.62187 .63859 Mdot
.52215 .23649 Mdot
.44023 .34287 Mdot
.40755 .30539 Mdot
.45915 .54402 Mdot
.24439 .42463 Mdot
.66159 .34397 Mdot
.44028 .74762 Mdot
.67219 .34938 Mdot
.61244 .57899 Mdot
.6 .63459 Mdot
.65585 .40297 Mdot
.66192 .34801 Mdot
.59434 .61108 Mdot
.75446 .59911 Mdot
.44997 .54023 Mdot
.45162 .30028 Mdot
.62812 .39138 Mdot
.63363 .39602 Mdot
.24307 .44177 Mdot
.65433 .35691 Mdot
.5675 .52864 Mdot
.40408 .3143 Mdot
.49581 .53386 Mdot
.43558 .31037 Mdot
.34296 .62322 Mdot
.30788 .43725 Mdot
.47436 .21004 Mdot
.64994 .35253 Mdot
.66043 .60677 Mdot
.6492 .34914 Mdot
.36593 .56498 Mdot
.61859 .40209 Mdot
.639 .31309 Mdot
.60155 .57443 Mdot
.45579 .53424 Mdot
.47307 .56006 Mdot
.44316 .7183 Mdot
.61376 .38375 Mdot
.60025 .63283 Mdot
.64644 .60006 Mdot
.63377 .59787 Mdot
.45652 .73178 Mdot
.66277 .36761 Mdot
.82018 .49181 Mdot
.61297 .4318 Mdot
.61066 .36076 Mdot
.50857 .84957 Mdot
.4727 .56188 Mdot
.49147 .537 Mdot
.48525 .35645 Mdot
.60159 .60464 Mdot
.30878 .42026 Mdot
.66492 .57907 Mdot
.46249 .53441 Mdot
.57262 .57365 Mdot
.33735 .59207 Mdot
.58207 .62572 Mdot
.48335 .54907 Mdot
.28093 .41344 Mdot
.66595 .59882 Mdot
.61093 .60608 Mdot
.46942 .55716 Mdot
.64739 .34525 Mdot
.65011 .39301 Mdot
.67542 .36816 Mdot
.32326 .58817 Mdot
.43142 .32551 Mdot
.66183 .57739 Mdot
.27471 .43027 Mdot
.31198 .42136 Mdot
.65885 .38967 Mdot
.25433 .43568 Mdot
.41943 .31162 Mdot
.58392 .59569 Mdot
.451 .31798 Mdot
.33365 .59089 Mdot
.6254 .38734 Mdot
.63899 .56882 Mdot
.67461 .60452 Mdot
.63501 .35118 Mdot
.4436 .54328 Mdot
.37314 .56551 Mdot
.26291 .44571 Mdot
.60219 .37691 Mdot
.45661 .31178 Mdot
.24704 .4443 Mdot
.66407 .60331 Mdot
.62298 .82188 Mdot
.58805 .61667 Mdot
.63685 .60245 Mdot
.66453 .40991 Mdot
.54564 .57661 Mdot
.32253 .44001 Mdot
.65871 .35868 Mdot
.64885 .61684 Mdot
.48319 .763 Mdot
.3099 .59911 Mdot
.22779 .42643 Mdot
.57532 .59422 Mdot
.74083 .64353 Mdot
.65597 .59814 Mdot
.50731 .20893 Mdot
.46358 .72848 Mdot
.38563 .27747 Mdot
.5761 .5181 Mdot
.47004 .3138 Mdot
.47347 .55095 Mdot
.30212 .44998 Mdot
.76694 .56248 Mdot
.58813 .61057 Mdot
.7443 .43036 Mdot
.64381 .57129 Mdot
.42537 .31174 Mdot
.80668 .52056 Mdot
.25542 .4184 Mdot
.20485 .62921 Mdot
.56229 .60251 Mdot
.62994 .3313 Mdot
.34123 .48658 Mdot
.48426 .53582 Mdot
.46926 .53075 Mdot
.33316 .60244 Mdot
.34914 .40285 Mdot
.53077 .54298 Mdot
.43445 .30828 Mdot
.61909 .61935 Mdot
.68124 .60827 Mdot
.42718 .2004 Mdot
.61633 .36348 Mdot
.42888 .33893 Mdot
.21464 .45929 Mdot
.60601 .5838 Mdot
.64322 .39957 Mdot
.64073 .36559 Mdot
.34449 .59824 Mdot
.39185 .2744 Mdot
.34907 .39556 Mdot
.78074 .67768 Mdot
.53814 .52153 Mdot
.28656 .44623 Mdot
.42237 .5601 Mdot
.66771 .58081 Mdot
.3647 .64875 Mdot
.45158 .33489 Mdot
.60953 .61618 Mdot
.75255 .40864 Mdot
.62561 .3605 Mdot
.59925 .5945 Mdot
.35505 .57093 Mdot
.79407 .3486 Mdot
.68953 .54842 Mdot
.74125 .61744 Mdot
.29326 .46622 Mdot
.60329 .63553 Mdot
.56536 .52918 Mdot
.45804 .5627 Mdot
.54246 .57917 Mdot
.27125 .41479 Mdot
.41993 .56163 Mdot
.35378 .57485 Mdot
.60738 .37662 Mdot
.47138 .54988 Mdot
.64213 .57077 Mdot
.6037 .63744 Mdot
.38053 .56959 Mdot
.66986 .58747 Mdot
.7085 .51991 Mdot
.44548 .56636 Mdot
.2583 .44972 Mdot
.60048 .38572 Mdot
.60626 .63438 Mdot
.47974 .53679 Mdot
.58483 .58116 Mdot
.71033 .34826 Mdot
.61102 .61754 Mdot
.49002 .23035 Mdot
.64439 .35373 Mdot
.44668 .30354 Mdot
.59816 .56015 Mdot
.60703 .59341 Mdot
.42427 .56576 Mdot
.45211 .54711 Mdot
.56503 .59346 Mdot
.64945 .39833 Mdot
.60867 .38396 Mdot
.62891 .33225 Mdot
.24924 .44995 Mdot
.4337 .72495 Mdot
.44856 .31267 Mdot
.47488 .53236 Mdot
.46246 .32689 Mdot
.70641 .6689 Mdot
.32506 .58216 Mdot
.45326 .21378 Mdot
.5846 .60024 Mdot
.65029 .36907 Mdot
.48217 .80908 Mdot
.66105 .38453 Mdot
.4365 .37757 Mdot
.45515 .33227 Mdot
.6192 .38195 Mdot
.57483 .60074 Mdot
.43952 .70642 Mdot
.74942 .63782 Mdot
.43517 .34535 Mdot
.50217 .54126 Mdot
.32081 .62847 Mdot
.28413 .46358 Mdot
.49459 .84718 Mdot
.46342 .31353 Mdot
.61481 .26558 Mdot
.65391 .61272 Mdot
.64128 .34556 Mdot
.44482 .3261 Mdot
.42793 .29584 Mdot
.25325 .41854 Mdot
.66676 .59031 Mdot
.60487 .59369 Mdot
.49867 .55272 Mdot
.45142 .32793 Mdot
.6251 .64166 Mdot
.67056 .5997 Mdot
.34939 .37365 Mdot
.62692 .3301 Mdot
.4076 .19015 Mdot
.6219 .70271 Mdot
.75257 .41004 Mdot
.36571 .2314 Mdot
.60348 .36564 Mdot
.5834 .62243 Mdot
.45889 .5398 Mdot
.25811 .44323 Mdot
.57967 .6027 Mdot
.3253 .43425 Mdot
.4256 .31858 Mdot
.50556 .2369 Mdot
.60699 .70395 Mdot
.39576 .37331 Mdot
.59484 .61867 Mdot
.684 .54266 Mdot
.35557 .58122 Mdot
.40693 .30449 Mdot
.64892 .33604 Mdot
.60456 .63007 Mdot
.24915 .42718 Mdot
.27857 .46198 Mdot
.62255 .36379 Mdot
.59129 .28736 Mdot
.48187 .20854 Mdot
.44442 .54486 Mdot
.25587 .42878 Mdot
.47272 .5355 Mdot
.73219 .62596 Mdot
.46632 .32264 Mdot
.35277 .57565 Mdot
.29228 .45657 Mdot
.43886 .28885 Mdot
.64461 .621 Mdot
.62038 .372 Mdot
.66938 .37833 Mdot
.52642 .65318 Mdot
.31188 .4279 Mdot
.33034 .57876 Mdot
.52841 .64302 Mdot
.54163 .6832 Mdot
.33836 .57541 Mdot
.24297 .44702 Mdot
.62336 .3978 Mdot
.6412 .35881 Mdot
.64427 .37958 Mdot
.78808 .56865 Mdot
.6146 .33693 Mdot
.34506 .68068 Mdot
.54253 .5782 Mdot
.70362 .54733 Mdot
.64053 .6166 Mdot
.40894 .30355 Mdot
.61946 .34967 Mdot
.46476 .72784 Mdot
.61282 .5603 Mdot
.7515 .6377 Mdot
.62929 .60219 Mdot
.51834 .6072 Mdot
.60263 .60524 Mdot
.64872 .48592 Mdot
.61144 .33621 Mdot
.55983 .60175 Mdot
.40336 .33378 Mdot
.33874 .56599 Mdot
.60985 .41744 Mdot
.57436 .6146 Mdot
.57064 .34525 Mdot
.58594 .56901 Mdot
.50204 .23461 Mdot
.52244 .63962 Mdot
.35226 .49804 Mdot
.62648 .6199 Mdot
.33588 .4193 Mdot
.68581 .58591 Mdot
.71476 .56308 Mdot
.44531 .34207 Mdot
.68704 .54164 Mdot
.31723 .41065 Mdot
.80733 .51844 Mdot
.44368 .54702 Mdot
.35999 .57453 Mdot
.41746 .55842 Mdot
.45623 .3041 Mdot
.5857 .60521 Mdot
.57406 .61781 Mdot
.53162 .60034 Mdot
.72889 .62884 Mdot
.45831 .55923 Mdot
.32505 .60423 Mdot
.70952 .56859 Mdot
.5658 .59727 Mdot
.22846 .41925 Mdot
.65636 .3804 Mdot
.79761 .51805 Mdot
.8001 .5021 Mdot
.66845 .60377 Mdot
.61666 .37905 Mdot
.65663 .37059 Mdot
.41523 .81494 Mdot
.36361 .58213 Mdot
.61881 .61341 Mdot
.39574 .54836 Mdot
.65834 .57589 Mdot
.43109 .31859 Mdot
.56933 .5665 Mdot
.30899 .4361 Mdot
.42929 .70193 Mdot
.24699 .45008 Mdot
.63328 .59654 Mdot
.63032 .37537 Mdot
.41978 .34523 Mdot
.2903 .4691 Mdot
.39135 .27551 Mdot
.3441 .68261 Mdot
.34983 .40755 Mdot
.34297 .60551 Mdot
.32487 .57247 Mdot
.4072 .30434 Mdot
.5791 .59328 Mdot
.45231 .73064 Mdot
.67048 .6931 Mdot
.59601 .60275 Mdot
.58585 .62063 Mdot
.48871 .33594 Mdot
.45814 .3273 Mdot
.31028 .45219 Mdot
.59252 .61029 Mdot
.58883 .63088 Mdot
.62612 .37894 Mdot
.35599 .60264 Mdot
.2763 .4517 Mdot
.32433 .59416 Mdot
.26982 .42249 Mdot
.52283 .81201 Mdot
.43279 .55547 Mdot
.32704 .5762 Mdot
.46522 .31124 Mdot
.64806 .38081 Mdot
.47645 .56204 Mdot
.28421 .43733 Mdot
.25327 .43181 Mdot
.63112 .62995 Mdot
.60826 .37205 Mdot
.64971 .35352 Mdot
.32793 .59614 Mdot
.43475 .33275 Mdot
.65328 .56906 Mdot
.44677 .53528 Mdot
.22731 .44965 Mdot
.24823 .43383 Mdot
.70804 .56145 Mdot
.6511 .41797 Mdot
.58899 .58152 Mdot
.64731 .39525 Mdot
.61529 .59763 Mdot
.6388 .30941 Mdot
.66895 .35965 Mdot
.54985 .57681 Mdot
.68543 .64287 Mdot
.29233 .44607 Mdot
.34993 .79869 Mdot
.55835 .56512 Mdot
.41156 .35569 Mdot
.66605 .58109 Mdot
.17719 .60344 Mdot
.47445 .80651 Mdot
.57634 .58208 Mdot
.58714 .6269 Mdot
.75743 .71739 Mdot
.65434 .59507 Mdot
.49258 .54758 Mdot
.44274 .54822 Mdot
.64359 .39802 Mdot
.41488 .56055 Mdot
.44486 .71597 Mdot
.36267 .58898 Mdot
.27721 .43036 Mdot
.37586 .74074 Mdot
.32558 .58749 Mdot
.63076 .35751 Mdot
.65784 .57063 Mdot
.6689 .40025 Mdot
.2801 .40076 Mdot
.46484 .5512 Mdot
.42574 .3153 Mdot
.45038 .72475 Mdot
.25017 .42332 Mdot
.45842 .3158 Mdot
.65065 .59692 Mdot
.34125 .45684 Mdot
.40124 .33593 Mdot
.36144 .80493 Mdot
.41419 .30649 Mdot
.45883 .31121 Mdot
.44121 .72662 Mdot
.36266 .58917 Mdot
.43981 .56772 Mdot
.50376 .53415 Mdot
.41697 .34233 Mdot
.23411 .65274 Mdot
.24818 .42113 Mdot
.4198 .72958 Mdot
.61593 .33176 Mdot
.43846 .5554 Mdot
.59232 .62125 Mdot
.41195 .31518 Mdot
.63574 .64122 Mdot
.42238 .56521 Mdot
.42857 .30226 Mdot
.68497 .58866 Mdot
.40907 .69672 Mdot
.47622 .53789 Mdot
.47842 .56004 Mdot
.36466 .60196 Mdot
.27755 .49803 Mdot
.65354 .36731 Mdot
.38107 .58389 Mdot
.47206 .74971 Mdot
.63118 .60509 Mdot
.44999 .32062 Mdot
.47031 .54991 Mdot
.45122 .30791 Mdot
.34766 .58323 Mdot
.37889 .56667 Mdot
.61231 .36956 Mdot
.63249 .33196 Mdot
.48626 .56392 Mdot
.50304 .74186 Mdot
.62848 .57022 Mdot
.74249 .44761 Mdot
.66434 .35181 Mdot
.80523 .5503 Mdot
.36344 .59297 Mdot
.3567 .60155 Mdot
.68875 .56641 Mdot
.61752 .5712 Mdot
.5192 .60449 Mdot
.58452 .5654 Mdot
.22728 .63225 Mdot
.63582 .56818 Mdot
.2604 .44147 Mdot
.57051 .57119 Mdot
.65302 .28165 Mdot
.6473 .62556 Mdot
.56947 .60434 Mdot
.28729 .42241 Mdot
.62053 .63148 Mdot
.30585 .43283 Mdot
.59851 .62448 Mdot
.26255 .38326 Mdot
.27504 .42989 Mdot
.39911 .60048 Mdot
.54301 .63707 Mdot
.48924 .55259 Mdot
.34703 .59487 Mdot
.33487 .60477 Mdot
.36908 .7212 Mdot
.61842 .3944 Mdot
.78129 .40298 Mdot
.5693 .59885 Mdot
.24619 .4243 Mdot
.42449 .32149 Mdot
.66619 .61154 Mdot
.63791 .5943 Mdot
.55836 .56544 Mdot
.61309 .3773 Mdot
.23907 .43341 Mdot
.34832 .58927 Mdot
.31845 .41954 Mdot
.24806 .38657 Mdot
.30466 .43938 Mdot
.66947 .67102 Mdot
.64054 .62373 Mdot
.56574 .52957 Mdot
.76328 .48839 Mdot
.35662 .55165 Mdot
.62041 .36803 Mdot
.47595 .54924 Mdot
.3276 .5693 Mdot
.43597 .68156 Mdot
.65315 .37801 Mdot
.26581 .44224 Mdot
.60482 .58994 Mdot
.42753 .55499 Mdot
.50615 .53598 Mdot
.60777 .40959 Mdot
.36764 .55992 Mdot
.28473 .43201 Mdot
.48151 .54237 Mdot
.43003 .72384 Mdot
.81279 .45968 Mdot
.45207 .76192 Mdot
.61074 .59473 Mdot
.3294 .59629 Mdot
.60771 .37283 Mdot
.52131 .59707 Mdot
.41637 .3269 Mdot
.44554 .72305 Mdot
.59114 .61877 Mdot
.43277 .38308 Mdot
.63091 .37387 Mdot
.3716 .57881 Mdot
.41183 .31275 Mdot
.36523 .57971 Mdot
.49322 .539 Mdot
.61862 .43172 Mdot
.47013 .53079 Mdot
.61522 .56287 Mdot
.42695 .32172 Mdot
.65289 .36275 Mdot
.27598 .38124 Mdot
.4955 .5673 Mdot
.26928 .44069 Mdot
.4416 .68442 Mdot
.60812 .38027 Mdot
.37172 .38309 Mdot
.31969 .42056 Mdot
.4869 .30766 Mdot
.46664 .69835 Mdot
.42012 .3077 Mdot
.57086 .6088 Mdot
.63972 .38048 Mdot
.43511 .34552 Mdot
.31949 .48239 Mdot
.76802 .6186 Mdot
.47255 .56844 Mdot
.61453 .58303 Mdot
.51671 .20565 Mdot
.62455 .27075 Mdot
.59938 .34014 Mdot
.46133 .30566 Mdot
.61042 .61154 Mdot
.44248 .5455 Mdot
.56125 .59906 Mdot
.42386 .3432 Mdot
.47188 .28036 Mdot
.28737 .40605 Mdot
.60433 .58691 Mdot
.36513 .56894 Mdot
.31199 .44036 Mdot
.30167 .46267 Mdot
.28928 .45739 Mdot
.64697 .33546 Mdot
.4397 .55923 Mdot
.4406 .54889 Mdot
.45757 .79849 Mdot
.45159 .3044 Mdot
.48897 .55242 Mdot
.58063 .62419 Mdot
.34713 .68308 Mdot
.64786 .36965 Mdot
.2904 .43104 Mdot
.61588 .61236 Mdot
.52434 .64941 Mdot
.46468 .55592 Mdot
.28376 .41687 Mdot
.66233 .34734 Mdot
.59644 .45673 Mdot
.58075 .60154 Mdot
.65934 .57965 Mdot
.63005 .35317 Mdot
.67881 .26652 Mdot
.42497 .72183 Mdot
.6141 .59882 Mdot
.4548 .3084 Mdot
.62609 .22347 Mdot
.65046 .6001 Mdot
.67353 .33976 Mdot
.50215 .54907 Mdot
.57836 .42131 Mdot
.70839 .52982 Mdot
.66794 .62799 Mdot
.50591 .43639 Mdot
.47095 .60538 Mdot
.53438 .46016 Mdot
.25453 .64072 Mdot
.43358 .44328 Mdot
.38502 .82092 Mdot
.40955 .29635 Mdot
.638 .49376 Mdot
.85445 .59273 Mdot
.59767 .27575 Mdot
.39214 .46387 Mdot
.46538 .2694 Mdot
.29986 .58818 Mdot
.15663 .56068 Mdot
.35115 .4449 Mdot
.25729 .63796 Mdot
.61346 .56317 Mdot
.66422 .26658 Mdot
.64531 .50119 Mdot
.36469 .44382 Mdot
.37545 .29327 Mdot
.52497 .64265 Mdot
.70971 .73885 Mdot
.39764 .36708 Mdot
.58625 .82085 Mdot
.76276 .40439 Mdot
.25266 .4714 Mdot
.50246 .69292 Mdot
.35504 .73027 Mdot
.66726 .52467 Mdot
.55683 .43727 Mdot
.39888 .30686 Mdot
.68067 .42588 Mdot
.378 .22283 Mdot
.26174 .43327 Mdot
.61008 .40819 Mdot
.51429 .33095 Mdot
.65974 .77916 Mdot
.43859 .36742 Mdot
.50412 .4371 Mdot
.49675 .56623 Mdot
.64488 .48776 Mdot
.46907 .72601 Mdot
.63868 .47741 Mdot
.36055 .40262 Mdot
.15932 .56161 Mdot
.66504 .41457 Mdot
.3147 .48958 Mdot
.41596 .67444 Mdot
.38239 .46591 Mdot
.67188 .4917 Mdot
.32001 .56462 Mdot
.39573 .60255 Mdot
.66425 .34905 Mdot
.70529 .72058 Mdot
.60056 .68669 Mdot
.47793 .74832 Mdot
.35183 .44818 Mdot
.69684 .36041 Mdot
.78596 .34755 Mdot
.6046 .28587 Mdot
.30598 .7681 Mdot
.62372 .81753 Mdot
.27564 .69122 Mdot
.54395 .62184 Mdot
.44755 .36789 Mdot
.37163 .65765 Mdot
.49655 .46785 Mdot
.29311 .72137 Mdot
.70966 .34461 Mdot
.74418 .70268 Mdot
.55267 .3503 Mdot
.66864 .78851 Mdot
.64831 .43494 Mdot
.54203 .54112 Mdot
.5848 .38537 Mdot
.61532 .4756 Mdot
.43943 .77507 Mdot
.68503 .7667 Mdot
.36352 .46045 Mdot
.51722 .55741 Mdot
.5853 .28092 Mdot
.70634 .51948 Mdot
.36161 .39376 Mdot
.39329 .59381 Mdot
.7805 .48788 Mdot
.71024 .74906 Mdot
.51854 .43132 Mdot
.65942 .75385 Mdot
.34375 .37262 Mdot
.23038 .34554 Mdot
.31236 .45949 Mdot
.4696 .3016 Mdot
.60547 .81645 Mdot
.64081 .37451 Mdot
.33877 .7981 Mdot
.43532 .45298 Mdot
.41919 .47898 Mdot
.71435 .74437 Mdot
.28355 .73414 Mdot
.68822 .52812 Mdot
.43179 .57859 Mdot
.41645 .2244 Mdot
.56079 .47601 Mdot
.38187 .37634 Mdot
.3537 .62689 Mdot
.50529 .22269 Mdot
.62474 .80493 Mdot
.26934 .70416 Mdot
.79048 .66648 Mdot
.48486 .73972 Mdot
.29166 .63289 Mdot
.67112 .40459 Mdot
.45548 .40863 Mdot
.37939 .39334 Mdot
.65715 .79866 Mdot
.69182 .55244 Mdot
.58413 .2017 Mdot
.26244 .65349 Mdot
.80555 .5033 Mdot
.55147 .22525 Mdot
.51225 .34446 Mdot
.60431 .47571 Mdot
.57159 .3389 Mdot
.44276 .53034 Mdot
.42398 .76701 Mdot
.77657 .46575 Mdot
.35033 .4945 Mdot
.43083 .71242 Mdot
.54599 .31942 Mdot
.32095 .72863 Mdot
.59937 .22231 Mdot
.78251 .47909 Mdot
.65489 .40274 Mdot
.29392 .72058 Mdot
.26315 .66579 Mdot
.56662 .20619 Mdot
.21849 .46391 Mdot
.65407 .75964 Mdot
.41582 .39101 Mdot
.67677 .62646 Mdot
.6361 .49569 Mdot
.6656 .52043 Mdot
.17837 .58631 Mdot
.67469 .66072 Mdot
.40762 .80447 Mdot
.38117 .33847 Mdot
.75929 .50874 Mdot
.38467 .77222 Mdot
.76395 .49974 Mdot
.71531 .55028 Mdot
.63354 .29796 Mdot
.38735 .33953 Mdot
.6559 .65543 Mdot
.71468 .73926 Mdot
.31134 .44867 Mdot
.29139 .72253 Mdot
.42065 .36978 Mdot
.30373 .47596 Mdot
.40081 .48026 Mdot
.3878 .48198 Mdot
.54818 .83895 Mdot
.57302 .28395 Mdot
.30052 .60247 Mdot
.60452 .44168 Mdot
.46386 .457 Mdot
.74812 .45282 Mdot
.64035 .6954 Mdot
.70099 .35174 Mdot
.37355 .56557 Mdot
.76617 .54164 Mdot
.57457 .36043 Mdot
.21734 .468 Mdot
.67201 .67447 Mdot
.50952 .69313 Mdot
.50041 .55582 Mdot
.38047 .70888 Mdot
.51656 .81355 Mdot
.6664 .6374 Mdot
.29261 .73994 Mdot
.58844 .28449 Mdot
.3802 .71481 Mdot
.3785 .39524 Mdot
.78658 .40765 Mdot
.67203 .7864 Mdot
.48061 .8398 Mdot
.68294 .2763 Mdot
.54068 .21885 Mdot
.17145 .41278 Mdot
.38006 .29414 Mdot
.36606 .79533 Mdot
.42115 .36984 Mdot
.68861 .19195 Mdot
.32392 .44066 Mdot
.35424 .65236 Mdot
.65206 .44067 Mdot
.50425 .67851 Mdot
.68321 .75749 Mdot
.68363 .51473 Mdot
.38564 .56481 Mdot
.58755 .37059 Mdot
.68025 .64619 Mdot
.70426 .73571 Mdot
.7244 .7173 Mdot
.71012 .72422 Mdot
.50031 .34768 Mdot
.74438 .6059 Mdot
.73989 .72933 Mdot
.35183 .6719 Mdot
.5992 .66183 Mdot
.67454 .61762 Mdot
.49342 .76059 Mdot
.34722 .77947 Mdot
.33502 .55111 Mdot
.56478 .47665 Mdot
.66358 .41568 Mdot
.72598 .74464 Mdot
.50265 .81667 Mdot
.63069 .47868 Mdot
.55566 .83189 Mdot
.28817 .59859 Mdot
.40362 .78675 Mdot
.51796 .83873 Mdot
.53818 .43142 Mdot
.47981 .36804 Mdot
.73949 .74143 Mdot
.27878 .67638 Mdot
.46901 .2719 Mdot
.57178 .34876 Mdot
.34525 .78477 Mdot
.5412 .22707 Mdot
.49172 .28902 Mdot
.65523 .43501 Mdot
.80703 .41854 Mdot
.39381 .44119 Mdot
.56091 .44121 Mdot
.53374 .61315 Mdot
.38051 .7751 Mdot
.32936 .4365 Mdot
.31216 .73857 Mdot
.3875 .41653 Mdot
.60916 .65895 Mdot
.38725 .73862 Mdot
.25407 .67689 Mdot
.54659 .38369 Mdot
.74051 .62491 Mdot
.58093 .28705 Mdot
.61701 .22543 Mdot
.56492 .21955 Mdot
.77921 .43625 Mdot
.61454 .63295 Mdot
.66647 .77521 Mdot
.41878 .8422 Mdot
.52589 .8415 Mdot
.5806 .21104 Mdot
.22115 .36969 Mdot
.43299 .28617 Mdot
.3567 .68009 Mdot
.50616 .66693 Mdot
.51941 .4046 Mdot
.48403 .60177 Mdot
.46731 .33097 Mdot
.78658 .34555 Mdot
.40754 .47628 Mdot
.35403 .67323 Mdot
.69245 .41507 Mdot
.44996 .46637 Mdot
.73209 .62927 Mdot
.65767 .39919 Mdot
.54518 .19514 Mdot
.29618 .72372 Mdot
.30534 .45142 Mdot
.22064 .44394 Mdot
.64776 .66657 Mdot
.54701 .54265 Mdot
.31341 .62896 Mdot
.63373 .64925 Mdot
.75326 .41282 Mdot
.21709 .37811 Mdot
.45303 .82144 Mdot
.34731 .79494 Mdot
.51346 .83885 Mdot
.27029 .68605 Mdot
.30924 .48105 Mdot
.38944 .71534 Mdot
.46291 .34875 Mdot
.40396 .3617 Mdot
.39813 .69749 Mdot
.25796 .67284 Mdot
.6925 .5317 Mdot
.58581 .36947 Mdot
.63866 .63524 Mdot
.48861 .80996 Mdot
.34511 .71332 Mdot
.38451 .69366 Mdot
.79779 .44279 Mdot
.65087 .32364 Mdot
.30451 .64606 Mdot
.57223 .43805 Mdot
.67598 .57372 Mdot
.54378 .21474 Mdot
.44342 .34469 Mdot
.66406 .3878 Mdot
.25352 .6778 Mdot
.18884 .39682 Mdot
.5085 .45998 Mdot
.59909 .69443 Mdot
.63027 .79657 Mdot
.54892 .65496 Mdot
.52546 .22577 Mdot
.82136 .42835 Mdot
.37014 .34746 Mdot
.66191 .42132 Mdot
.59028 .65329 Mdot
.39584 .48707 Mdot
.68753 .29051 Mdot
.62816 .41532 Mdot
.68322 .54553 Mdot
.60247 .8234 Mdot
.52728 .63429 Mdot
.55063 .44466 Mdot
.43806 .74661 Mdot
.42665 .41644 Mdot
.44798 .45349 Mdot
.38402 .74125 Mdot
.52187 .45079 Mdot
.68696 .72721 Mdot
.78538 .3296 Mdot
.57525 .47978 Mdot
.32357 .65583 Mdot
.35858 .67439 Mdot
.76284 .40321 Mdot
.66819 .48851 Mdot
.37912 .34439 Mdot
.60069 .56155 Mdot
.59004 .83452 Mdot
.55073 .33456 Mdot
.38408 .72794 Mdot
.46096 .38479 Mdot
.6601 .59379 Mdot
.53958 .53825 Mdot
.52843 .83905 Mdot
.5746 .4178 Mdot
.8788 .55988 Mdot
.24578 .64206 Mdot
.68754 .31028 Mdot
.70595 .53192 Mdot
.30304 .74655 Mdot
.66877 .2954 Mdot
.45157 .4434 Mdot
.39255 .4108 Mdot
.33137 .76974 Mdot
.56779 .39767 Mdot
.57356 .42266 Mdot
.53471 .20319 Mdot
.74238 .72126 Mdot
.55623 .46574 Mdot
.49256 .31362 Mdot
.29035 .60439 Mdot
.63699 .60447 Mdot
.59486 .28556 Mdot
.46089 .20961 Mdot
.47467 .38514 Mdot
.54072 .46842 Mdot
.4147 .84339 Mdot
.69004 .61309 Mdot
.57018 .29235 Mdot
.87512 .56612 Mdot
.89429 .53946 Mdot
.63337 .28707 Mdot
.64651 .80739 Mdot
.58063 .42959 Mdot
.52566 .22849 Mdot
.39121 .33494 Mdot
.55032 .68936 Mdot
.74301 .43756 Mdot
.55199 .84654 Mdot
.19152 .38461 Mdot
.38023 .37693 Mdot
.67608 .42102 Mdot
.54734 .849 Mdot
.68886 .61975 Mdot
.32765 .65221 Mdot
.23246 .34492 Mdot
.20958 .63529 Mdot
.30487 .76384 Mdot
.80294 .43732 Mdot
.1778 .59115 Mdot
.23419 .61419 Mdot
.3707 .4528 Mdot
.35204 .79441 Mdot
.52616 .52534 Mdot
.79732 .40831 Mdot
.29244 .71802 Mdot
.52332 .21413 Mdot
.16617 .47445 Mdot
.45653 .45169 Mdot
.6155 .65123 Mdot
.62457 .29697 Mdot
.50234 .2249 Mdot
.53057 .32579 Mdot
.57282 .6623 Mdot
.44354 .68957 Mdot
.71417 .55427 Mdot
.62251 .21902 Mdot
.83209 .43836 Mdot
.60341 .64834 Mdot
.73333 .69917 Mdot
.38956 .36102 Mdot
.39831 .67981 Mdot
.68797 .50468 Mdot
.35411 .70712 Mdot
.29957 .61077 Mdot
.57732 .56968 Mdot
.60967 .81956 Mdot
.30046 .61192 Mdot
.72396 .70935 Mdot
.3389 .80146 Mdot
.57009 .82435 Mdot
.4252 .48223 Mdot
.32655 .62794 Mdot
.34358 .77246 Mdot
.34917 .77503 Mdot
.75431 .68654 Mdot
.26072 .63482 Mdot
.40308 .69358 Mdot
.55996 .64594 Mdot
.60554 .70147 Mdot
.70595 .64893 Mdot
.30645 .7502 Mdot
.76851 .38819 Mdot
.38502 .76907 Mdot
.68369 .27957 Mdot
.25683 .67596 Mdot
.68412 .52314 Mdot
.35947 .71093 Mdot
.4435 .39718 Mdot
.41377 .58448 Mdot
.24813 .41926 Mdot
.78216 .69009 Mdot
.55891 .20816 Mdot
.42914 .80445 Mdot
.57616 .20059 Mdot
.56856 .34307 Mdot
.24061 .62882 Mdot
.58639 .39698 Mdot
.55032 .49329 Mdot
.26491 .47873 Mdot
.33869 .73685 Mdot
.69734 .55122 Mdot
.50761 .20806 Mdot
.80643 .48283 Mdot
.55745 .83936 Mdot
.38775 .77596 Mdot
.80972 .64714 Mdot
.29494 .62756 Mdot
.76633 .53757 Mdot
.70339 .7188 Mdot
.6525 .24564 Mdot
.38322 .68704 Mdot
.71775 .73313 Mdot
.59924 .34835 Mdot
.62949 .81441 Mdot
.41868 .32467 Mdot
.30966 .64125 Mdot
.48551 .21177 Mdot
.3704 .6857 Mdot
.37192 .68332 Mdot
.4362 .81455 Mdot
.57949 .28384 Mdot
.61129 .28007 Mdot
.41368 .39067 Mdot
.3483 .44748 Mdot
.58246 .70053 Mdot
.53895 .44279 Mdot
.7853 .6706 Mdot
.61223 .63281 Mdot
.27517 .61784 Mdot
.29159 .72961 Mdot
.466 .34681 Mdot
.55856 .63167 Mdot
.5009 .21344 Mdot
.82027 .44576 Mdot
.441 .78567 Mdot
.73597 .72733 Mdot
.55571 .62867 Mdot
.49972 .65358 Mdot
.81352 .52251 Mdot
.49356 .28366 Mdot
.37873 .35932 Mdot
.51297 .43902 Mdot
.56145 .66933 Mdot
.42591 .72512 Mdot
.27399 .68509 Mdot
.40011 .83332 Mdot
.74208 .69305 Mdot
.37733 .35731 Mdot
.37644 .69196 Mdot
.67395 .33728 Mdot
.34794 .73696 Mdot
.80441 .65603 Mdot
.16561 .58324 Mdot
.5717 .34685 Mdot
.26289 .6863 Mdot
.50508 .35198 Mdot
.3297 .65412 Mdot
.39074 .69542 Mdot
.70099 .7229 Mdot
.64734 .44766 Mdot
.58728 .42775 Mdot
.51479 .3511 Mdot
.45064 .71615 Mdot
.41074 .46368 Mdot
.79772 .41941 Mdot
.57607 .2798 Mdot
.81089 .64551 Mdot
.22105 .60977 Mdot
.80406 .5148 Mdot
.84147 .60867 Mdot
.66035 .34202 Mdot
.40351 .46551 Mdot
.25072 .32168 Mdot
.37676 .70835 Mdot
.29284 .46099 Mdot
.62755 .64121 Mdot
.42273 .68844 Mdot
.67437 .28424 Mdot
.29638 .58776 Mdot
.34983 .55887 Mdot
.657 .39729 Mdot
.24276 .62225 Mdot
.66542 .38648 Mdot
.39835 .83013 Mdot
.5362 .42617 Mdot
.71042 .55348 Mdot
.83485 .46589 Mdot
.30294 .48414 Mdot
.62927 .23111 Mdot
.58047 .82344 Mdot
.48894 .7571 Mdot
.62108 .41545 Mdot
.6237 .42584 Mdot
.61932 .44117 Mdot
.47664 .32718 Mdot
.64427 .78532 Mdot
.28446 .73194 Mdot
.22528 .44923 Mdot
.59331 .37791 Mdot
.54279 .62864 Mdot
.64593 .64613 Mdot
.46903 .82163 Mdot
.31815 .42163 Mdot
.68898 .77525 Mdot
.77596 .3947 Mdot
.65172 .25481 Mdot
.52506 .3939 Mdot
.51675 .70653 Mdot
.38999 .67089 Mdot
.32391 .49175 Mdot
.67751 .62374 Mdot
.67252 .30605 Mdot
.62392 .33662 Mdot
.40469 .47181 Mdot
.37482 .58619 Mdot
.22143 .47111 Mdot
.43174 .35519 Mdot
.77098 .43341 Mdot
.30198 .75149 Mdot
.6523 .40822 Mdot
.31297 .63326 Mdot
.30781 .49648 Mdot
.6798 .66432 Mdot
.5133 .74808 Mdot
.76932 .70876 Mdot
.60646 .80795 Mdot
.65507 .39464 Mdot
.6122 .227 Mdot
.29523 .38003 Mdot
.45126 .81994 Mdot
.56951 .38284 Mdot
.30325 .74112 Mdot
.77697 .49948 Mdot
.50276 .83308 Mdot
.70728 .52911 Mdot
.51074 .42537 Mdot
.27881 .70878 Mdot
.39152 .54646 Mdot
.26029 .6889 Mdot
.82287 .46168 Mdot
.57455 .68737 Mdot
.21999 .6445 Mdot
.48261 .37772 Mdot
.63344 .48199 Mdot
.65828 .56728 Mdot
.51873 .40888 Mdot
.33117 .76593 Mdot
.65795 .35307 Mdot
.30601 .57417 Mdot
.7023 .39809 Mdot
.38037 .37401 Mdot
.62044 .80674 Mdot
.57936 .21452 Mdot
.28 .722 Mdot
.60779 .69949 Mdot
.31658 .6987 Mdot
.76591 .38964 Mdot
.48686 .74529 Mdot
.43315 .54342 Mdot
.77634 .47795 Mdot
.42692 .56927 Mdot
.46642 .80429 Mdot
.70165 .65472 Mdot
.68323 .76294 Mdot
.5062 .81289 Mdot
.62047 .29625 Mdot
.48916 .57131 Mdot
.5963 .39759 Mdot
.69629 .76417 Mdot
.44902 .78892 Mdot
.49795 .22076 Mdot
.30429 .7621 Mdot
.2628 .62864 Mdot
.84938 .59882 Mdot
.56114 .29625 Mdot
.63928 .65705 Mdot
.35716 .79952 Mdot
.55316 .34162 Mdot
.23725 .61464 Mdot
.69766 .55298 Mdot
.67135 .40016 Mdot
.7176 .73996 Mdot
.53237 .51144 Mdot
.60126 .29233 Mdot
.73052 .65263 Mdot
.66547 .41873 Mdot
.45389 .78822 Mdot
.56015 .62669 Mdot
.26516 .44409 Mdot
.50897 .6851 Mdot
.17239 .57798 Mdot
.63372 .44877 Mdot
.29831 .74148 Mdot
.30774 .74296 Mdot
.29495 .65253 Mdot
.31813 .50227 Mdot
.85024 .59674 Mdot
.74768 .59266 Mdot
.56806 .62935 Mdot
.6436 .40784 Mdot
.33278 .56359 Mdot
.26928 .65548 Mdot
.66064 .58935 Mdot
.50995 .71752 Mdot
.77939 .49172 Mdot
.57209 .8411 Mdot
.4466 .40579 Mdot
.39788 .29981 Mdot
.59488 .36135 Mdot
.50198 .22237 Mdot
.69911 .30546 Mdot
.60858 .26967 Mdot
.32942 .76257 Mdot
.5099 .45997 Mdot
.5071 .43331 Mdot
.59322 .30344 Mdot
.30822 .72382 Mdot
.37414 .42322 Mdot
.40764 .34253 Mdot
.75023 .42084 Mdot
.7725 .67356 Mdot
.57163 .32743 Mdot
.47038 .45097 Mdot
.55426 .41537 Mdot
.56254 .67789 Mdot
.38103 .38127 Mdot
.58197 .28514 Mdot
.63425 .42733 Mdot
.68166 .73715 Mdot
.56595 .45833 Mdot
.32283 .62899 Mdot
.25552 .65627 Mdot
.54651 .42019 Mdot
.30979 .74923 Mdot
.68623 .64224 Mdot
.70485 .72761 Mdot
.38193 .72576 Mdot
.30677 .56167 Mdot
.64593 .63049 Mdot
.70741 .36322 Mdot
.52696 .83942 Mdot
.56596 .37246 Mdot
.52699 .47189 Mdot
.59943 .43038 Mdot
.33061 .78994 Mdot
.372 .6109 Mdot
.22045 .37565 Mdot
.42745 .57879 Mdot
.51128 .70498 Mdot
.50318 .66981 Mdot
.47597 .3308 Mdot
.68499 .61777 Mdot
.37814 .45612 Mdot
.5719 .67705 Mdot
.75324 .42142 Mdot
.39414 .79969 Mdot
.78046 .68788 Mdot
.69665 .35538 Mdot
.29818 .76305 Mdot
.69724 .38525 Mdot
.68526 .37705 Mdot
.22368 .60981 Mdot
.52776 .47568 Mdot
.67676 .6583 Mdot
.30511 .56911 Mdot
.65725 .33659 Mdot
.77834 .68435 Mdot
.53505 .46667 Mdot
.31335 .56497 Mdot
.35632 .38749 Mdot
.44445 .45655 Mdot
.36114 .22553 Mdot
.39877 .35555 Mdot
.34091 .79745 Mdot
.29333 .72194 Mdot
.38696 .33457 Mdot
.57946 .42759 Mdot
.53862 .47451 Mdot
.70163 .73571 Mdot
.44386 .57375 Mdot
.59793 .81628 Mdot
.4996 .34939 Mdot
.76709 .44206 Mdot
.50341 .81064 Mdot
.42795 .77092 Mdot
.48263 .7505 Mdot
.79036 .46294 Mdot
.64391 .75838 Mdot
.46875 .56429 Mdot
.22012 .46095 Mdot
.16141 .49258 Mdot
.7936 .66578 Mdot
.65718 .25559 Mdot
.52426 .54959 Mdot
.3548 .74116 Mdot
.56463 .45438 Mdot
.40301 .6784 Mdot
.39659 .39328 Mdot
.31555 .63066 Mdot
.50176 .33347 Mdot
.6073 .21421 Mdot
.58933 .83397 Mdot
.66302 .62213 Mdot
.47799 .59597 Mdot
.36364 .44904 Mdot
.31921 .45068 Mdot
.66127 .45488 Mdot
.76823 .70723 Mdot
.41335 .34517 Mdot
.25871 .31177 Mdot
.46387 .34364 Mdot
.44213 .81227 Mdot
.20553 .37882 Mdot
.4834 .30537 Mdot
.39524 .83027 Mdot
.66666 .27439 Mdot
.81616 .47377 Mdot
.58198 .19926 Mdot
.47558 .80848 Mdot
.7745 .47421 Mdot
.35799 .62713 Mdot
.64193 .80134 Mdot
.38819 .67495 Mdot
.29694 .60084 Mdot
.65804 .75011 Mdot
.27358 .70326 Mdot
.24934 .64713 Mdot
.42273 .2624 Mdot
.67473 .41895 Mdot
.18228 .40505 Mdot
.27837 .47619 Mdot
.79441 .32387 Mdot
.6073 .80614 Mdot
.7781 .61116 Mdot
.56775 .37447 Mdot
.42978 .3912 Mdot
.6967 .74155 Mdot
.31899 .7494 Mdot
.60932 .46395 Mdot
.21245 .44761 Mdot
.41136 .76204 Mdot
.34325 .72596 Mdot
.47171 .37544 Mdot
.52918 .83262 Mdot
.31767 .49108 Mdot
.547 .5226 Mdot
.28404 .71963 Mdot
.70659 .37306 Mdot
.49157 .7353 Mdot
.76869 .67641 Mdot
.5058 .75566 Mdot
.24669 .66007 Mdot
.50182 .34639 Mdot
.2355 .39143 Mdot
.77725 .6763 Mdot
.69439 .30915 Mdot
.78347 .50955 Mdot
.87572 .5635 Mdot
.66766 .78892 Mdot
.54167 .47639 Mdot
.57438 .56397 Mdot
.37912 .81807 Mdot
.2602 .40218 Mdot
.41643 .80182 Mdot
.78598 .34941 Mdot
.23745 .6347 Mdot
.69807 .66263 Mdot
.61242 .56398 Mdot
.35354 .66695 Mdot
.60665 .30728 Mdot
.66177 .43162 Mdot
.31526 .47095 Mdot
.25824 .67183 Mdot
.77201 .42931 Mdot
.78528 .32979 Mdot
.8203 .45384 Mdot
.62955 .40551 Mdot
.62297 .81306 Mdot
.55867 .50817 Mdot
.76649 .39961 Mdot
.69739 .73359 Mdot
.49372 .61185 Mdot
.37758 .44402 Mdot
.76292 .38863 Mdot
.38693 .71218 Mdot
.16929 .57122 Mdot
.83925 .61488 Mdot
.75019 .44041 Mdot
.69601 .7698 Mdot
.48291 .84179 Mdot
.61495 .40756 Mdot
.65007 .45093 Mdot
.38431 .66647 Mdot
.54606 .46084 Mdot
.49735 .29976 Mdot
.29892 .47642 Mdot
.25533 .62244 Mdot
.23251 .4858 Mdot
.57407 .58139 Mdot
.48979 .36637 Mdot
.56367 .83624 Mdot
.32048 .64861 Mdot
.57739 .83179 Mdot
.78042 .45027 Mdot
.61696 .63522 Mdot
.89451 .53592 Mdot
.52291 .22818 Mdot
.65289 .68927 Mdot
.49171 .52915 Mdot
.5222 .5518 Mdot
.56988 .57535 Mdot
.46886 .27604 Mdot
.35316 .68964 Mdot
.22094 .62641 Mdot
.64397 .79765 Mdot
.5961 .36699 Mdot
.3872 .67195 Mdot
.39591 .32907 Mdot
.47006 .70275 Mdot
.70894 .65571 Mdot
.41776 .34904 Mdot
.20129 .60709 Mdot
.35831 .2285 Mdot
.37777 .4055 Mdot
.4142 .46155 Mdot
.44249 .69235 Mdot
.50005 .56295 Mdot
.21418 .60917 Mdot
.48069 .32786 Mdot
.36948 .44386 Mdot
.27743 .71802 Mdot
.79397 .4741 Mdot
.46614 .37631 Mdot
.18157 .44194 Mdot
.38571 .68892 Mdot
.49052 .3675 Mdot
.56254 .48078 Mdot
.81247 .42258 Mdot
.67004 .75428 Mdot
.35357 .40569 Mdot
.47229 .56487 Mdot
.81208 .52882 Mdot
.67975 .76134 Mdot
.45203 .29502 Mdot
.4118 .83592 Mdot
.54591 .48368 Mdot
.66763 .45048 Mdot
.76236 .63187 Mdot
.56802 .64168 Mdot
.68926 .54496 Mdot
.53595 .58575 Mdot
.48636 .66414 Mdot
.33979 .23033 Mdot
.58492 .64555 Mdot
.43312 .46048 Mdot
.50829 .45474 Mdot
.31788 .65565 Mdot
.69293 .57354 Mdot
.62482 .60823 Mdot
.39213 .59008 Mdot
.39983 .73077 Mdot
.32582 .64191 Mdot
.3007 .63598 Mdot
.47589 .37023 Mdot
.21402 .61052 Mdot
.24731 .64313 Mdot
.72774 .62361 Mdot
.70503 .74086 Mdot
.6673 .57142 Mdot
.59984 .81004 Mdot
.4084 .41227 Mdot
.53292 .32519 Mdot
.50966 .74996 Mdot
.8357 .61859 Mdot
.6522 .30536 Mdot
.59704 .52616 Mdot
.46792 .83523 Mdot
.55287 .83409 Mdot
.39704 .37332 Mdot
.52322 .20936 Mdot
.15699 .51397 Mdot
.37377 .6743 Mdot
.61442 .21687 Mdot
.22456 .44348 Mdot
.46419 .82723 Mdot
.586 .67861 Mdot
.53698 .47836 Mdot
.79028 .4212 Mdot
.67272 .66946 Mdot
.30058 .41493 Mdot
.82036 .42758 Mdot
.79169 .46286 Mdot
.6405 .76012 Mdot
.56022 .61986 Mdot
.49233 .40672 Mdot
.67503 .34321 Mdot
.79662 .65915 Mdot
.23589 .44648 Mdot
.49896 .6499 Mdot
.79525 .34114 Mdot
.34668 .22781 Mdot
.238 .61291 Mdot
.75036 .68716 Mdot
.40073 .35902 Mdot
.56764 .67399 Mdot
.4309 .19992 Mdot
.66937 .32369 Mdot
.63726 .41309 Mdot
.4343 .35427 Mdot
.32341 .70205 Mdot
.57667 .29578 Mdot
.86233 .58658 Mdot
.49813 .83339 Mdot
.68463 .65137 Mdot
.77878 .29353 Mdot
.28718 .72365 Mdot
.48775 .62874 Mdot
.57024 .28725 Mdot
.60663 .82018 Mdot
.49973 .32083 Mdot
.36267 .80493 Mdot
.5488 .43212 Mdot
.63377 .44707 Mdot
.33844 .71419 Mdot
.57856 .2032 Mdot
.5501 .63384 Mdot
.7846 .31785 Mdot
.54641 .21281 Mdot
.35556 .73104 Mdot
.56285 .38977 Mdot
.68775 .34219 Mdot
.68358 .31304 Mdot
.53232 .39669 Mdot
.50209 .4693 Mdot
.4732 .45069 Mdot
.51477 .43314 Mdot
.37519 .42114 Mdot
.51676 .39319 Mdot
.51506 .22928 Mdot
.46475 .35671 Mdot
.8024 .4476 Mdot
.15781 .53762 Mdot
.29707 .63165 Mdot
.32847 .43326 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo087ooooo0_l0001Iooooo`;o0000Joooool00006
ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooo
oooo087ooooo1Ol0000Xooooo`;o0000;?ooool2o`0006_ooooo00001_ooooooMgMgoiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003ooooo
ooooo`21ooooo`Ko00009_ooool3o`0002cooooo0_l0001[ooooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0Q?oo
ool6o`0001oooooo0_l00002ooooo`;o00002_ooool2o`0008kooooo00000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0008Kooooo1_l0000K
ooooo`Co00003?ooool6o`0008cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`27ooooo`;o000000Coooooo`00
0?l0003o00000_ooool4o`0000;ooooo0_l000000ooooooo0000o`000009ooooo`?o000000Cooooo
o`000?l0003ooooo0_l00008ooooo`;o000000?oooooo`000?l000001?l0002<ooooo`0000?ooooo
oa0@4?ooool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0R_ooool4o`000003ooooool0003o000000;o00000_ooool2o`000004ooooool0003o
0000o`0000;ooooo2Ol00004ooooo`;o00001_ooool4o`0000;ooooo0_l0002?ooooo`0000Kooooo
ogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003o
ooooooooo`2<ooooo`;o000000Coooooo`000?l0003ooooo0ol000000ooooooo0000o`000004o`00
0003ooooool0003o000000Ko000000?oooooo`000?l000002_ooool2o`0000Gooooo0_l0002>oooo
o`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_oo
ool00ol0003oooooooooo`2?ooooo`;o000000Goooooo`000?l0003o0000ooooo`06o`0000?ooooo
0_l00005ooooo`;o00001Oooool3o`0000Sooooo0ol00006ooooo`;o00000_ooool2o`0008;ooooo
000Looooo`03o`000?oooooooooo08oooooo1?l0000<ooooo`;o00001Oooool2o`0000Gooooo0ol0
0008ooooo`;o00001oooool2o`000004ooooool0003o0000o`0001kooooo0_l0001Rooooo`007?oo
ool00ol0003oooooooooo`2Aooooo`;o00002oooool2o`0000cooooo0_l00006ooooo`;o00001_oo
ool2o`0000Kooooo1?l0000Mooooo`;o0000H_ooool001cooooo00?o0000ooooooooool0Moooool2
o`0000Cooooo1?l00002ooooo`?o00006?ooool4o`0000[ooooo0_l00006ooooo`;o00001_ooool2
o`000003ooooool0003o000000Gooooo1?l0000Looooo`;o0000HOooool001cooooo00?o0000oooo
ooooool0L_ooool2o`0000?ooooo0_l00004ooooo`Co00000_ooool3o`0000;ooooo0_l0000Eoooo
o`?o00001Oooool2o`0000?ooooo0_l000000ooooooo0000o`00000>ooooo`;o000000?oooooo`00
0?l000000ol000000ooooooo0000o`00000Looooo`?o0000H?ooool001cooooo00?o0000oooooooo
ool0Joooool4o`0000;ooooo0ol0000<ooooo`;o00001_ooool2o`00017ooooo0_l00002ooooo`;o
00000oooool5o`0000?ooooo0_l000000ooooooo0000o`00000Aooooo`Go00008?ooool3o`0005oo
oooo000Looooo`03o`000?oooooooooo06_ooooo1?l00002ooooo`Co00002oooool2o`0000?ooooo
1?l0000Booooo`?o00001_ooool5o`00023ooooo0_l00002ooooo`;o00006Oooool3o`0005kooooo
000Looooo`03o`000?oooooooooo07?ooooo0_l0000@ooooo`Co00004oooool2o`000003ooooool0
003o000000;o00000oooool4o`0001oooooo0_l00002ooooo`;o00006_ooool2o`0005kooooo000L
ooooo`03o`000?oooooooooo06Oooooo0_l0000fooooo`Co00000oooool4o`0003oooooo0ol0001M
ooooo`007?ooool00ol0003oooooooooo`1Vooooo`?o0000P?ooool3o`0005gooooo000Looooo`03
o`000?oooooooooo06Kooooo0_l0000/ooooo`;o0000>_ooool4o`0001Kooooo0_l0001Mooooo`00
7?ooool00ol0003oooooooooo`2Dooooo`;o0000>_ooool4o`0007Gooooo000Looooo`;o0000HOoo
ool2o`0008[ooooo0ol0001Jooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o0000K_ooool2
o`0001[ooooo0ol0001Jooooo`007?ooool00ol0003oooooooooo`3@ooooo`Co0000MOooool001co
oooo00?o0000ooooooooool0d_ooool2o`0007Gooooo000Looooo`03o`000?oooooooooo08Cooooo
1?l00004ooooo`Co0000=?ooool2o`0002Sooooo0ol0001Hooooo`007?ooool00ol0003ooooooooo
o`1nooooo`Co00000_ooool4o`0000Cooooo1?l0000cooooo`Ko00002oooool2o`0000?ooooo0_l0
000Cooooo`?o0000F?ooool001cooooo00?o0000ooooooooool0Foooool2o`00023ooooo1Ol0000<
ooooo`;o000000?oooooo`000?l000000_l0000Yooooo`?o000000?oooooo`000?l000001Ol0000;
ooooo`;o00000oooool2o`0006kooooo000Looooo`03o`000?oooooooooo05_ooooo0_l0000Moooo
o`So00003oooool6o`0000;ooooo0_l0000Sooooo`?o000000?oooooo`000?l000000_ooool3o`00
0003ooooool0003o000007gooooo000Looooo`03o`000?oooooooooo07[ooooo1Ol0000Dooooo`Co
00000_ooool2o`0002?ooooo0_l00006ooooo`;o00000_ooool4o`0000Oooooo0_l00003ooooo`;o
00005oooool2o`0005Cooooo000Looooo`03o`000?oooooooooo07Sooooo1_l0000Gooooo`?o0000
0oooool2o`0001[ooooo0_l00005ooooo`Oo00001_ooool3o`000003ooooool0003o000000Cooooo
0_l00003ooooo`;o00005oooool2o`0005Cooooo000Looooo`03o`000?oooooooooo07Sooooo1?l0
000Jooooo`;o00000oooool2o`0001[ooooo0_l000000ooooooo0000o`000003ooooo`Ko00002_oo
ool3o`0000Sooooo1?l0001[ooooo`007?ooool00ol0003oooooooooo`1gooooo`?o00003oooool2
o`0000;ooooo1?l00005ooooo`;o000000?oooooo`000?l000001?l0000Gooooo`Wo00000_ooool5
o`0000Wooooo0ol00005ooooo`;o00000oooool2o`0001Kooooo0_l0001Cooooo`007?ooool00ol0
003oooooooooo`1fooooo`?o00003Oooool2o`000003ooooool0003o000000So00001_ooool6o`00
01Cooooo3Ol000000ooooooo0000o`000003o`0000Cooooo0_l00004ooooo`;o00001Oooool2o`00
01_ooooo0_l000000ooooooo0000o`00001@ooooo`007?ooool00ol0003oooooooooo`1fooooo`;o
00002oooool2o`000003ooooool0003o000000So000000Coooooo`000?l0003o00001?ooool2o`00
0004ooooool0003o0000o`0001Gooooo1?l00002ooooo`;o000000?oooooo`000?l000001Ol00007
ooooo`;o00004?ooool2o`0001Wooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`1eoooo
o`Go00001Oooool2o`0000;ooooo4_l00003ooooo`;o000000?oooooo`000?l000005oooool3o`00
00Wooooo0_l0000>ooooo`;o00000oooool2o`0000Gooooo0_l0000Kooooo`;o0000C_ooool001co
oooo00?o0000ooooooooool0MOooool5o`0000Gooooo1?l000000ooooooo0000o`00000?o`0000;o
oooo0_l00002ooooo`;o00004oooool2o`000004ooooool0003o0000o`0000;ooooo0_l0000<oooo
o`?o000000?oooooo`000?l000001?ooool2o`0000?ooooo0_l00008ooooo`;o00006?ooool2o`00
04kooooo000Looooo`;o0000Doooool2o`0002;ooooo0ol00005oooooa_o00000_ooool2o`000003
ooooool0003o0000013ooooo0_l000000ooooooo0000o`000003ooooo`;o00003?ooool3o`000003
ooooool0003o000001?ooooo0_l0001Xooooo`007?ooool00ol0003oooooooooo`1Booooo`;o0000
8_ooool3o`0000Gooooo6Ol00007ooooo`;o00004?ooool2o`0000_ooooo1?l00028ooooo`007?oo
ool00ol0003oooooooooo`1dooooo`Co00001_oooolFo`000003ooooool0003o000000;ooooo0ol0
0002ooooo`;o00004?ooool2o`0000_ooooo1_l000001Ooooooo0000o`000?l0003ooooo00;o0000
1_ooool2o`0000Gooooo0_l00006ooooo`;o00006_ooool2o`0004cooooo000Looooo`03o`000?oo
oooooooo07Cooooo1?l00006oooooaKo000000?oooooo`000?l000000_ooool3o`0000;ooooo0_l0
000Looooo`;o00000_ooool3o`000003ooooool0003o000000Co00000_ooool2o`0000;ooooo0_l0
0005ooooo`;o00000oooool5o`0001[ooooo0ol0001;ooooo`007?ooool00ol0003oooooooooo`1@
ooooo`;o0000;OoooolHo`000003ooooool0003o000000;ooooo1?l0000Jooooo`Co00000_ooool6
o`000003ooooool0003o000000Go00003?ooool6o`0001cooooo0_l0001;ooooo`007?ooool00ol0
003oooooooooo`1@ooooo`;o0000;?oooolIo`000003ooooool0003o000000;ooooo0_l0000Joooo
o`Ko00001?ooool4o`0000Cooooo1Ol0000;ooooo`Co00007_ooool2o`0004_ooooo000Looooo`03
o`000?oooooooooo07Kooooo1?l00004oooooaWo00001oooool2o`0000cooooo1?l00008ooooo`Go
00003oooool5o`0000Wooooo1?l0000Mooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0
C_ooool2o`0002Gooooo1_l00003oooooaWo00001Oooool5o`0000_ooooo1?l00009ooooo`;o0000
3oooool4o`000003ooooool0003o000000cooooo0_l0000Looooo`;o000000?oooooo`000?l00000
BOooool001cooooo00?o0000ooooooooool0C_ooool2o`0002Gooooo1_l00004oooooaSo00001Ooo
ool2o`000003ooooool0003o000000Oooooo0ol0000>ooooo`Co00002Oooool2o`000004ooooool0
003o0000o`0000Cooooo1?l00002ooooo`;o00001Oooool2o`0001oooooo0_l00019ooooo`007?oo
ool00ol0003oooooooooo`1eooooo`Co00001?oooolMo`0000?ooooo0_l00009ooooo`?o00002ooo
ool2o`0000;ooooo0ol00009ooooo`So00000_ooool:o`0000Cooooo0_l0000Nooooo`;o0000BOoo
ool001cooooo00?o0000ooooooooool0B_ooool3o`0002_ooooo0ol00002ooooo`?o000000?ooooo
o`000?l000005ol00003ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Aooooo`;o000000?o
ooooo`000?l000002Oooool;o`0000Gooooo0_l00002ooooo`?o00000oooool2o`0001_ooooo0_l0
00000ooooooo0000o`000019ooooo`007?ooool00ol0003oooooooooo`1:ooooo`?o0000:oooool5
o`000003ooooool0003o000001Ko000000?oooooo`000?l000001?ooool8o`0000[ooooo0_l00005
ooooo`;o000000?oooooo`000?l000002Oooool<o`0000;ooooo0_l00005ooooo`?o00007oooool5
o`0004Wooooo000Looooo`03o`000?oooooooooo07Sooooo1Ol000000ooooooo0000o`00000Do`00
00Oooooo0_l00002ooooo`Ko00002_ooool2o`0000Gooooo0_l00008ooooo`;o000000?oooooo`00
0?l000003?l000000ooooooo0000o`000002o`000004ooooool0003o0000ooooo`;o00008?ooool2
o`0004_ooooo000Looooo`03o`000?oooooooooo07Sooooo1?l00002oooooa?o00002_ooool2o`00
00;ooooo0_l0000?ooooo`;o00001?ooool4o`0000Gooooo3ol000001?oooooo0000o`000?ooool7
o`0000;ooooo0ol0000Oooooo`Co0000B?ooool001cooooo00?o0000ooooooooool0Aoooool2o`00
02kooooo1Ol00002oooooa?o00000_ooool2o`0000[ooooo0_l00002ooooo`;o00002oooool2o`00
00?ooooo1Ol00005oooooa7o00000oooool6o`0000;ooooo0ol00005ooooo`;o00006?ooool4o`00
04Sooooo000Looooo`03o`000?oooooooooo04Oooooo0ol0000Zooooo`;o000000?oooooo`000?l0
00001OoooolAo`0000Cooooo0ol00009ooooo`;o00000_ooool2o`00013ooooo0ol00008oooooa7o
00000_ooool6o`0000?ooooo0_l00005ooooo`;o00005_ooool4o`0004[ooooo000Looooo`;o0000
AOooool2o`000004ooooool0003o0000o`0002[ooooo0ol00008ooooo`oo00001Oooool3o`0000Wo
oooo0_l0000?ooooo`;o00001?ooool2o`0000Gooooo1?l000000ooooooo0000o`00000>o`000003
ooooool0003o000000Co00001_ooool2o`0000;ooooo0_l0000Fooooo`Go0000BOooool001cooooo
00?o0000ooooooooool0A?ooool2o`0002oooooo0_l00008ooooo`;o00000oooool2o`0000gooooo
0_l0000:ooooo`Ko00002oooool2o`0000Cooooo0_l00005ooooo`Co000000?oooooo`000?l00000
5Ol00006ooooo`?o000000?oooooo`000?l000005Oooool6o`0004Wooooo000Looooo`03o`000?oo
oooooooo07kooooo0_l00002ooooo`;o00001?ooool3o`0000Sooooo0_l00005ooooo`;o00001?oo
ool5o`0001kooooo5ol00004ooooo`Co00006?ooool6o`0004Wooooo000Looooo`03o`000?oooooo
oooo047ooooo0_l0000booooo`Co00001Oooool2o`0000;ooooo0_l00004ooooo`?o00002?ooool2
o`0000Cooooo0ol0000VoooooaSo00001?ooool3o`0001Wooooo1Ol0001:ooooo`007?ooool00ol0
003oooooooooo`11ooooo`;o0000<_ooool4o`0000;ooooo0_l000001Ooooooo0000o`000?l0003o
oooo00;o00005Oooool2o`0001cooooo0_l00004ooooo`;o000000?oooooo`000?l000006_l00003
ooooo`;o000000?oooooo`000?l000005Oooool6o`0004[ooooo000Looooo`03o`000?oooooooooo
04;ooooo0_l0000aooooo`;o00001?ooool2o`0000;ooooo0_l0000Jooooo`;o00006_ooool2o`00
00Cooooo0_l000000ooooooo0000o`00000Do`0000;ooooo1?l00003ooooo`;o000000?oooooo`00
0?l000005Oooool6o`0004[ooooo000Looooo`03o`000?oooooooooo04;ooooo0_l0000aooooo`;o
00001?ooool4o`0000cooooo0_l000000ooooooo0000o`000005ooooo`;o000000Coooooo`000?l0
003ooooo0ol0000Mooooo`;o000000?oooooo`000?l000005ol000000ooooooo0000o`000002o`00
01_ooooo1_l0001<ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o0000=Oooool4o`0000Ko
oooo0_l00004ooooo`;o000000?oooooo`000?l000001Oooool5o`0000;ooooo0_l0000Fooooo`;o
00001Oooool2o`000003ooooool0003o000001Oo000000?oooooo`000?l000000_l0000Kooooo`Ko
0000C?ooool001cooooo00?o0000ooooooooool0A?ooool2o`0002Kooooo1?l00008ooooo`;o0000
0oooool2o`0000Kooooo0_l0000>ooooo`Co00006oooool3o`0000Cooooo0_l00003oooooaKo0000
3?ooool2o`0001;ooooo1?l0001?ooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00000_oo
ool3o`0001_ooooo0_l00009ooooo`Go00001?ooool2o`000004ooooool0003o0000ooooo`Co0000
1_ooool2o`0000?ooooo0_l00008ooooo`?o00000_ooool2o`0001[ooooo0_l00006ooooo`;o0000
00?oooooo`000?l000005_l00003ooooo`;o00001Oooool2o`0001;ooooo1?l0001?ooooo`007?oo
ool00ol0003oooooooooo`0mooooo`Co00000_ooool3o`00013ooooo0_l00004ooooo`;o00000ooo
ool2o`0000cooooo1?l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l00005ooooo`;o0000
00?oooooo`000?l000000oooool2o`0000Sooooo0_l00003ooooo`;o00008_oooolKo`000003oooo
ool0003o000000;o00006Oooool4o`0004oooooo000Looooo`03o`000?oooooooooo03_ooooo1_l0
0002ooooo`;o00003Oooool2o`0000;ooooo0_l00004ooooo`;o00004_ooool4o`000004ooooool0
003o0000ooooo`;o00002?ooool2o`0000;ooooo1Ol00007ooooo`;o00006_ooool2o`0000Gooooo
0_l00008oooooaOo00000oooool2o`0001_ooooo1?l0001?ooooo`007?ooool00ol0003ooooooooo
o`0kooooo`;o00004?ooool2o`0000?ooooo0_l0000Hooooo`;o00000_ooool7o`0000_ooooo0_l0
0002ooooo`Go00001oooool2o`0000;ooooo0_l0000Fooooo`;o00001Oooool2o`0000?ooooo0_l0
00000ooooooo0000o`00000Go`0000?ooooo0_l00004ooooo`;o00004oooool6o`0004oooooo000L
ooooo`03o`000?oooooooooo03oooooo0_l0000<ooooo`;o00007Oooool3o`000003ooooool0003o
000000?o00003_ooool2o`00017ooooo0_l0000Kooooo`;o00000_ooool2o`000004ooooool0003o
0000oooooaWo00002?ooool3o`0001?ooooo1Ol0001@ooooo`0000Koooooonk^k_lb<S;o0000oc8b
<_o^k^h5ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0
?_ooool3o`0000Sooooo1?l0000Pooooo`Co000000Coooooo`000?l0003o00000oooool2o`0000?o
oooo0_l00004ooooo`;o00000oooool2o`0001[ooooo0_l000000ooooooo0000o`00000:ooooo`;o
00000_ooool2o`0000Gooooo5_l00003ooooo`;o00001Oooool2o`0001;ooooo1_l000000ooooooo
0000o`00001>ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo03[ooooo0_l00002ooooo`;o00002Oooool4o`00
023ooooo1?l000001?oooooo0000o`000?l00002ooooo`?o00000oooool2o`0000Wooooo0_l00002
ooooo`;o00005_ooool2o`000003ooooool0003o000000;o00004?ooool2o`000003ooooool0003o
000001?o00001?ooool2o`0000Gooooo0_l000000ooooooo0000o`00000?ooooo`;o00000_ooool5
o`0004kooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006oooo
o`03o`000?oooooooooo03[ooooo0_l0000Jooooo`;o00005_ooool2o`0000Gooooo1Ol0000Boooo
o`;o00006oooool2o`0000[ooooo0_l00004ooooo`;o000000?oooooo`000?l000005?l000001?oo
oooo0000o`000?l00008ooooo`?o00003oooool2o`000004ooooool0003o0000ooooo`;o0000Cooo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?m4A4CogMgMooooool0
0007ooooo`?o0000>oooool2o`0001Cooooo0_l00003ooooo`?o000000Coooooo`000?l0003o0000
4Oooool2o`000004ooooool0003o0000ooooo`?o0000?_ooool2o`0000Oooooo5_l000001?oooooo
0000o`000?l00005ooooo`;o000000?oooooo`000?l000004?ooool5o`0000?ooooo0_l0001=oooo
o`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`00
00Oooooo00?o0000ooooooooool0>?ooool2o`000003ooooool0003o000000Kooooo0_l0000<oooo
o`oo00003_ooool8o`000003ooooool0003o000001Cooooo0_l0000Fooooo`;o00006?oooolDo`00
00?ooooo0_l00005ooooo`;o00005Oooool2o`0000Cooooo0_l0001=ooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooooooo
ool0>?ooool2o`0000Wooooo0_l00006ooooo`;o00001?ooool@o`0000cooooo1?l00002ooooo`;o
00000_ooool2o`0001Cooooo0_l000000ooooooo0000o`00000:ooooo`;o00001oooool2o`0001So
oooo3Ol000001?oooooo0000o`000?ooool3o`0000?ooooo0_l0000Iooooo`;o000000?oooooo`00
0?l000001_ooool2o`000003ooooool0003o000004Sooooo00001_ooooooMgMgoiRHV?ooooooV9RH
ogMgM`cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0nooooo`;o00002oooool2
o`0000Cooooo5_l00006ooooo`?o00000_ooool2o`0000?ooooo0_l00003ooooo`;o00000oooool2
o`0000gooooo0_l0000:ooooo`;o00001oooool2o`0001Sooooo2?l000000ooooooo0000o`000002
o`000003ooooool0003o000000?o00000_ooool2o`0001[ooooo0ol00009ooooo`;o000000?ooooo
o`000?l00000B?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000oooo
o`06ooooo`03o`000?oooooooooo03Cooooo0_l00008ooooo`;o00003?ooool2o`000004ooooool0
003o0000oooooaGo00001_ooool3o`0000;ooooo0_l00008ooooo`;o00000oooool2o`0002gooooo
0_l0000>ooooo`[o000000?oooooo`000?l000000ol000001?oooooo0000o`000?ooool2o`0000Oo
oooo0_l0000Aooooo`?o0000E_ooool001cooooo00?o0000ooooooooool0=?ooool2o`0001Gooooo
0ol000000ooooooo0000o`00000Ho`0000;ooooo1?l00003ooooo`?o00001Oooool2o`0000_ooooo
0_l0000Wooooo`;o00001Oooool2o`0000Wooooo2?l000000ooooooo0000o`000002o`000005oooo
ool0003o0000o`000?ooool00_l00007ooooo`;o00004Oooool3o`0000oooooo0_l00003ooooo`;o
0000@?ooool001cooooo00?o0000ooooooooool0AOooool5o`000003ooooool0003o000002Co0000
00Goooooo`000?l0003o0000ooooo`02o`0000;ooooo0_l0000;ooooo`;o00009Oooool2o`0000Oo
oooo0ol00007ooooo`Go00001_ooool3o`000004ooooool0003o0000ooooo`?o000000Goooooo`00
0?l0003o0000ooooo`02o`0001?ooooo0ol0000:ooooo`Co000000?oooooo`000?l000000oooool2
o`00043ooooo000Looooo`03o`000?oooooooooo04Gooooo1Ol00002oooooa[o000000?oooooo`00
0?l000002ol00002ooooo`;o0000=_ooool2o`0000Oooooo0ol00007ooooo`Go00001_ooool3o`00
00Cooooo0_l00002ooooo`?o000000?oooooo`000?l000004_ooool4o`0000[ooooo1?l00003oooo
o`;o0000@oooool001cooooo00?o0000ooooooooool0A?ooool4o`0000;ooooo1ol000000ooooooo
0000o`00000Bo`0000;ooooo1ol00002ooooo`Co000000?oooooo`000?l00000:_ooool2o`0000Ko
oooo0_l0000;ooooo`?o000000?oooooo`000?l000001?ooool5o`000004ooooool0003o0000oooo
o`;o00003Oooool2o`0001Cooooo0_l0000Cooooo`;o000000?oooooo`000?l00000@?ooool001co
oooo00?o0000ooooooooool0A?ooool4o`000003ooooool0003o000001co000000?oooooo`000?l0
00001Ol00004ooooo`;o0000;Oooool2o`0000Kooooo0_l0000<ooooo`Go00000_ooool2o`000004
ooooool0003o0000o`0000;ooooo0_l000000ooooooo0000o`00000=ooooo`;o00004oooool3o`00
00Kooooo0_l0000>ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0@oooool2o`0000Co
oooo9Ol0000cooooo`Ko00001?ooool2o`000003ooooool0003o000000Wooooo0_l00004ooooo`;o
00000_ooool4o`0000cooooo0_l0000Iooooo`?o00001_ooool2o`0000kooooo0_l00010ooooo`00
7?ooool00ol0003oooooooooo`0mooooo`;o00001?ooool2o`0000?ooooo8ol0000eooooo`Oo0000
1?ooool2o`000003ooooool0003o000000Wooooo0_l00008ooooo`Go00001oooool8o`00023ooooo
1?l0001>ooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00001?ooool2o`0000;ooooo7?l0
00000ooooooo0000o`000005o`0000Gooooo0ol0000]ooooo`Go00003?ooool2o`0000?ooooo0_l0
000>ooooo`?o00001_ooool8o`0001Oooooo0_l00009ooooo`;o00001_ooool2o`0000Oooooo0_l0
000mooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00003_ooool6o`000003ooooool0003o
000001_o00001Oooool3o`0000Wooooo0_l0000;ooooo`;o00001?ooool2o`0001;ooooo0_l00006
ooooo`;o00001?ooool3o`0000;ooooo0_l00009ooooo`;o00000_ooool4o`0000Kooooo2?l0000G
ooooo`Co00000oooool2o`0000Sooooo1?l00007ooooo`;o0000?Oooool001cooooo00?o0000oooo
ooooool0=oooool3o`0000Oooooo0_l000001?oooooo0000o`000?l00002ooooob7o00001?ooool2
o`000003ooooool0003o000000?o000000?oooooo`000?l000000oooool2o`0000_ooooo0_l00004
ooooo`;o00006_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000=ooooo`;o00000_ooool2
o`0000Gooooo2?l000000ooooooo0000o`00000Gooooo`Co00000oooool2o`0000Sooooo0_l00006
ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0=Oooool2o`000003ooooool0003o0000
00Oooooo0_l000001?oooooo0000o`000?l00002oooooa[o000000?oooooo`000?l000001?l00003
ooooo`Wo000000?oooooo`000?l00000=_ooool2o`0001;ooooo0_l00005ooooo`[o00000_ooool4
o`0001?ooooo0ol0000Aooooo`;o00001?ooool2o`00043ooooo000Looooo`;o0000=_ooool2o`00
00[ooooo0_l00002ooooobCo00001?ooool8o`0001cooooo0_l00002ooooo`?o00003_ooool2o`00
01_ooooo0_l00005ooooo`Oo00001?ooool5o`0001?ooooo0_l0000;ooooo`;o00001Oooool2o`00
04Kooooo000Looooo`03o`000?oooooooooo047ooooo0_l00003ooooo`Co000000?oooooo`000?l0
00007?l00003ooooo`;o00000_ooool3o`0000;ooooo0_l0000Cooooo`;o00000_ooool2o`000003
ooooool0003o000000;ooooo0ol00009ooooo`;o00000oooool2o`0000cooooo0_l0000Iooooo`;o
00000_ooool4o`0001Sooooo0_l00009ooooo`;o00000oooool2o`0000Kooooo0_l00010ooooo`00
7?ooool00ol0003oooooooooo`11ooooo`;o00002?ooool<o`000003ooooool0003o000000oo0000
0_ooool3o`0000?ooooo0_l00002ooooo`Co00004Oooool2o`000004ooooool0003o0000o`0000?o
oooo0_l0000<ooooo`;o00004Oooool2o`0000Sooooo0_l00003ooooo`;o00001?ooool3o`0000Oo
oooo0_l0000Jooooo`;o00003_ooool2o`0000?ooooo0_l000000ooooooo0000o`000010ooooo`00
7?ooool00ol0003oooooooooo`11ooooo`Go00001oooool:o`000003ooooool0003o000000Ko0000
0_ooool6o`0000?ooooo0_l00005ooooo`;o00000oooool2o`0000[ooooo0_l00004ooooo`;o0000
0_ooool2o`0000Cooooo0_l0000<ooooo`?o00001_ooool2o`0000;ooooo0_l00004ooooo`;o0000
2?ooool2o`0000;ooooo0ol00004ooooo`Go00008Oooool3o`0001;ooooo0_l000000ooooooo0000
o`000010ooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00002?ooool5o`0000Oooooo4ol0
00000ooooooo0000o`000002o`000003ooooool0003o000000Cooooo0_l00004ooooo`;o00002?oo
ool2o`0000Cooooo0ol00004ooooo`;o00005?ooool5o`0000Kooooo0_l00002ooooo`;o00004_oo
ool2o`0000Kooooo1?l0000Rooooo`;o00002oooool2o`0000Gooooo0_l000000ooooooo0000o`00
0010ooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00002_ooool2o`0000[ooooo1?l00000
0ooooooo0000o`00000>o`0000Oooooo0ol0000:ooooo`;o00000_ooool2o`000004ooooool0003o
0000ooooo`;o00002_ooool2o`0000cooooo1ol00007ooooo`;o00001Oooool2o`0000oooooo0_l0
000dooooo`;o00000oooool2o`0000cooooo0_l0000looooo`007?ooool00ol0003oooooooooo`13
ooooo`?o00002Oooool4o`0000Cooooo2ol000000ooooooo0000o`000006ooooo`;o00002oooool2
o`0000Gooooo0_l0000=ooooo`;o00003?ooool7o`0000Oooooo1?l00003ooooo`;o00005Oooool2
o`0002kooooo0_l0000Aooooo`;o0000??ooool001cooooo00?o0000ooooooooool0A?ooool3o`00
00Oooooo0_l00007ooooo`?o000000?oooooo`000?l000000_l00004ooooo`;o00000oooool2o`00
0003ooooool0003o000001;ooooo0ol0000Kooooo`Co00001_ooool2o`0000?ooooo0_l0000Joooo
o`;o0000=?ooool2o`0000Gooooo0ol00011ooooo`007?ooool00ol0003oooooooooo`0booooo`;o
00004Oooool2o`0000Oooooo0_l00007ooooo`;o00001?ooool4o`0000Oooooo0_l000000ooooooo
0000o`00000Booooo`Co00004oooool2o`0000Gooooo1Ol00005ooooo`?o000000Coooooo`000?l0
003o00001?ooool4o`0000_ooooo0_l000000ooooooo0000o`00000booooo`;o00001?ooool2o`00
00Gooooo1?l00010ooooo`007?ooool00ol0003oooooooooo`0booooo`;o00004_ooool2o`0000[o
oooo0_l00003ooooo`;o00001?ooool4o`0001gooooo0_l000001?oooooo0000o`000?ooool2o`00
013ooooo0_l00007ooooo`Go00001?ooool2o`000004ooooool0003o0000o`0000Cooooo1?l00000
0ooooooo0000o`000008ooooo`;o000000?oooooo`000?l000000oooool2o`000003ooooool0003o
000002[ooooo1?l00003ooooo`;o00000_ooool2o`000004ooooool0003o0000o`00043ooooo000L
ooooo`03o`000?oooooooooo04Kooooo0_l0000:ooooo`;o00003Oooool2o`000003ooooool0003o
000001Cooooo0_l00002ooooo`;o00001?ooool4o`0001[ooooo0_l00007ooooo`;o00001_ooool2
o`0000;ooooo0_l0000@ooooo`Go0000:_ooool4o`0000?ooooo0_l000001Ooooooo0000o`000?l0
003ooooo00;o0000@Oooool001cooooo00?o0000ooooooooool0B?ooool2o`0001Gooooo1?l00000
1?oooooo0000o`000?l0000:ooooo`;o00001oooool2o`0000[ooooo0_l0000Vooooo`;o00000ooo
ool2o`0001Gooooo0_l00003ooooo`;o00000oooool2o`0002cooooo0ol000000ooooooo0000o`00
0011ooooo`007?ooool00ol0003oooooooooo`18ooooo`;o00005Oooool2o`0000;ooooo1?l00004
ooooo`;o00001?ooool2o`0000[ooooo0_l0000_ooooo`;o00005oooool3o`0000Cooooo0ol00003
ooooo`?o00007Oooool2o`0000Cooooo0_l00007ooooo`;o000000Coooooo`000?l0003o0000@?oo
ool001cooooo00?o0000ooooooooool0<Oooool2o`0001Sooooo0_l0000Fooooo`Co00001?ooool2
o`00013ooooo0_l00016ooooo`Go00001?ooool2o`0000Gooooo0ol0000Looooo`;o00000oooool3
o`0000_ooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00006?ooool2o`00
01Kooooo1?l00005ooooo`Co00000_ooool2o`0003_ooooo0_l0000Dooooo`;o00001?ooool2o`00
00Wooooo0_l0000Looooo`;o00000oooool2o`0000Gooooo0_l00005ooooo`;o0000@?ooool001co
oooo00?o0000ooooooooool0<?ooool2o`0001oooooo0_l00003ooooo`Co00001_ooool2o`0000[o
oooo1Ol000000ooooooo0000o`00000kooooo`;o00001Oooool2o`0001?ooooo0_l0000Wooooo`;o
00002?ooool4o`0000Cooooo0_l00011ooooo`007?ooool2o`00037ooooo0_l0000Oooooo`;o0000
0oooool4o`0000Kooooo0_l00006ooooo`;o00000_ooool2o`000003ooooool0003o000004Gooooo
0_l0000Dooooo`Co00009?ooool2o`0000?ooooo0_l00003ooooo`;o00001_ooool2o`00047ooooo
000Looooo`03o`000?oooooooooo02oooooo0_l0000cooooo`;o00000_ooool2o`0000;ooooo0_l0
0014ooooo`?o00005oooool4o`0000?ooooo0_l00007ooooo`;o00005_ooool2o`0000?ooooo0_l0
0003ooooo`Ko000000Coooooo`000?l0003o0000@Oooool001cooooo00?o0000ooooooooool0;ooo
ool2o`0003?ooooo0_l00011ooooo`Go00001_ooool3o`0001kooooo0_l00007ooooo`;o00005Ooo
ool2o`0000Wooooo1_l000000ooooooo0000o`000012ooooo`007?ooool00ol0003oooooooooo`0_
ooooo`;o0000M_ooool6o`0000Gooooo0_l0000Zooooo`;o00004oooool2o`0000Cooooo1?l00002
ooooo`;o00001?ooool2o`0004;ooooo000Looooo`03o`000?oooooooooo02oooooo0_l0001hoooo
o`Co00001Oooool4o`0002Sooooo0_l0000Cooooo`;o00001?ooool4o`000003ooooool0003o0000
00?ooooo1?l00012ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o0000N?ooool2o`0000So
oooo0ol000000ooooooo0000o`00000<ooooo`;o00004oooool4o`000003ooooool0003o000001So
oooo0_l00003ooooo`;o000000?oooooo`000?l000001?l00012ooooo`007?ooool00ol0003ooooo
ooooo`2^ooooo`;o00001oooool2o`000004ooooool0003o0000ooooo`?o00001Oooool2o`0001?o
oooo1?l000001?oooooo0000o`000?ooool2o`0001Gooooo0_l00004ooooo`So00007?ooool2o`00
02Cooooo000Looooo`03o`000?oooooooooo0:_ooooo0_l000000ooooooo0000o`000003ooooo`;o
00000_ooool2o`000004ooooool0003o0000ooooo`Co00004oooool3o`0000?ooooo0_l00006oooo
o`;o00006Oooool4o`000003ooooool0003o000000?o00007?ooool2o`0002Cooooo000Looooo`03
o`000?oooooooooo02kooooo0_l0001gooooo`;o00000_ooool2o`000003ooooool0003o000000;o
000000?oooooo`000?l000002?ooool4o`0001?ooooo0ol00002ooooo`?o00000_ooool2o`0001go
oooo0_l00003ooooo`Co0000@oooool001cooooo00?o0000ooooooooool0;_ooool2o`00063ooooo
2Ol00003ooooo`?o00002?ooool6o`0000;ooooo2?l00007ooooo`;o00005Oooool2o`000005oooo
ool0003o0000o`000?ooool01?l00002ooooo`;o00006Oooool3o`0000?ooooo0ol0000Kooooo`;o
00009_ooool001cooooo00?o0000ooooooooool0;_ooool2o`0005cooooo0_l000000ooooooo0000
o`00000@o`0000Sooooo1?l000001Ooooooo0000o`000?l0003ooooo00Go00001_ooool2o`0001Wo
oooo1ol00002ooooo`?o00006?ooool4o`0000?ooooo0ol0000Kooooo`;o00009_ooool001cooooo
00?o0000ooooooooool0;_ooool2o`0005cooooo5_l00006ooooo`?o00000oooool3o`0000;ooooo
0ol00007ooooo`;o00006_ooool;o`0001Sooooo0_l0000Sooooo`;o00009_ooool001cooooo00?o
0000ooooooooool0;_ooool4o`0005;ooooo0_l00005oooooaSo00001Oooool6o`000003ooooool0
003o000000Oooooo0_l0000Qooooo`?o000000?oooooo`000?l000005?ooool2o`0000_ooooo0_l0
000Kooooo`;o0000:?ooool001cooooo00?o0000ooooooooool0;_ooool4o`0005;ooooo0_l00005
ooooobGo00002?ooool2o`00023ooooo1?l0000Gooooo`;o00002oooool2o`0001_ooooo0_l0000X
ooooo`007?ooool00ol0003oooooooooo`1^ooooo`Co00001?ooool2o`00017ooooo6Ol000000ooo
oooo0000o`000006o`000003ooooool0003o000000;o00000_ooool4o`0002Cooooo1?l0000Goooo
o`Co00002Oooool2o`0001_ooooo0_l0000Xooooo`007?ooool00ol0003oooooooooo`1^ooooo`Co
00001?ooool2o`0000?ooooo0_l00007ooooo`;o00000ooooolLo`000003ooooool0003o000000?o
000000?oooooo`000?l000002?l0000Tooooo`Co00000oooool2o`0001Cooooo0_l00009ooooo`;o
0000AOooool001cooooo0_l0001Zooooo`;o00004?ooool4o`0000;ooooo0_l000001?oooooo0000
o`000?l00002oooooaco000000Coooooo`000?l0003o00000oooool6o`0002Sooooo1?l00003oooo
o`;o00000_ooool2o`0001Gooooo0_l00004ooooo`;o0000AOooool001cooooo00?o0000oooooooo
ool0JOooool2o`000003ooooool0003o000000Co00002oooool2o`000005ooooool0003o0000o`00
0?ooool03?l000000ooooooo0000o`00000Fo`000003ooooool0003o000000;o0000;Oooool6o`00
0003ooooool0003o000000?o00005Oooool2o`0000Cooooo0_l00015ooooo`007?ooool00ol0003o
ooooooooo`1Zooooo`So00003_ooool2o`0000;ooooo3?l000000ooooooo0000o`00000?o`0000;o
oooo2?l0000_ooooo`Ko000000?oooooo`000?l000000ol0000Eooooo`;o0000Boooool001cooooo
00?o0000ooooooooool0J?ooool4o`0000;ooooo0ol00002ooooo`?o00002Oooool2o`0000?ooooo
7Ol000000ooooooo0000o`000002o`000003ooooool0003o000000;o00004Oooool6o`000003oooo
ool0003o000001Oooooo0_l00006ooooo`;o00005oooool2o`0001_ooooo0_l0000]ooooo`007?oo
ool00ol0003oooooooooo`0_ooooo`?o0000;_ooool2o`0000Kooooo0_l000000ooooooo0000o`00
000:o`000003ooooool0003o000000;o00000_ooool4o`000003ooooool0003o0000027o00003_oo
oolHo`0001Kooooo1?l0000?ooooo`;o00001_ooool2o`0001[ooooo0ol0000]ooooo`007?ooool0
0ol0003oooooooooo`0_ooooo`?o0000;_ooool>o`000003ooooool0003o000000co000000?ooooo
o`000?l000009?l0000>oooooa_o00003oooool3o`0000?ooooo1?l0000?ooooo`Co00007oooool3
o`0002kooooo000Looooo`03o`000?oooooooooo05oooooo0_l000000ooooooo0000o`00000Io`00
00;ooooo0_l000000ooooooo0000o`00000Eo`000004ooooool0003o0000ooooo`?o00000_ooool2
o`0000_ooooo5_l00002ooooo`go00002?ooool3o`0000Cooooo0_l0000:ooooo`;o00001_ooool2
o`0000?ooooo0_l00004ooooo`;o00005?ooool3o`0002kooooo000Looooo`03o`000?oooooooooo
03?ooooo0_l0000Zooooo`;o00000ooooolIo`0000Cooooo1?l000000ooooooo0000o`000002o`00
0003ooooool0003o000000;o000000?oooooo`000?l000003Ol0000@ooooo`ko00000_oooolHo`00
00Gooooo0_l00005ooooo`;o00002_ooool2o`0000_ooooo0_l00003ooooo`?o00005?ooool2o`00
02oooooo000Looooo`03o`000?oooooooooo03?ooooo0_l0000[ooooo`;o00000_oooolHo`0000;o
oooo0_l000001?oooooo0000o`000?l00002ooooo`?o00000oooool3o`0000Cooooo0_l000000ooo
oooo0000o`000002o`000003ooooool0003o000000oooooo;_l00002ooooo`?o00001?ooool2o`00
01Oooooo0_l00003ooooo`;o00005?ooool3o`0002oooooo000Looooo`03o`000?oooooooooo037o
oooo0_l000000ooooooo0000o`00000Zooooo`;o000000?oooooo`000?l000005ol00002ooooo`?o
00000oooool7o`000004ooooool0003o0000o`0000Cooooo1_l0000Cooooo`Go00000_oooolKo`00
0003ooooool0003o000000Wo00000oooool2o`0000;ooooo1?l0000Gooooo`;o00006Oooool2o`00
033ooooo000Looooo`03o`000?oooooooooo037ooooo0_l000000ooooooo0000o`00000]oooooaWo
00000oooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`000004ooooool0003o0000o`00
00?ooooo1?l0000Cooooo`So00000ooooolMo`000003ooooool0003o000000Go00001Oooool2o`00
0003ooooool0003o000000;o00005oooool3o`0004[ooooo000Looooo`03o`000?oooooooooo03;o
oooo0_l0000^oooooaWo00001?ooool3o`000003ooooool0003o000000Oooooo0ol00003ooooo`;o
00005?ooool7o`0000Cooooo5ol000000ooooooo0000o`00000:o`0000Cooooo0_l000000ooooooo
0000o`00000Looooo`?o0000B_ooool001cooooo00?o0000ooooooooool0<_ooool2o`0000;ooooo
1?l0000Sooooo`?o00000_oooolJo`000003ooooool0003o000000?o000000Coooooo`000?l0003o
oooo0ol0000Oooooo`Go00001_oooolWo`000003ooooool0003o000000;o00007_ooool2o`0001Go
oooo0_l0000cooooo`007?ooool00ol0003oooooooooo`0booooo`;o00000_ooool4o`0002?ooooo
0ol000000ooooooo0000o`00000Mo`0000Kooooo0ol0000Nooooo`So00001?oooolIo`000003oooo
ool0003o000000_o000000?oooooo`000?l000000_l0000Dooooo`;o00007oooool2o`0003?ooooo
00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@
4?o<c<`01_ooool00ol0003oooooooooo`0fooooo`;o0000:OoooolJo`000003ooooool0003o0000
02Wooooo0ol000000ooooooo0000o`000002o`0000?ooooo9ol00002ooooo`Co00004?ooool2o`00
0004ooooool0003o0000o`0001gooooo0_l0000eooooo`0000KoooooogMgMonHV9SooooooiRHV?mg
MgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0
H_oooolEo`000005ooooool0003o0000o`000?ooool00_l0000Jooooo`;o00003?ooool7o`000004
ooooool0003o0000ooooobWo000000?oooooo`000?l000000_l0000@ooooo`;o000000?oooooo`00
0?l000001oooool2o`0001?ooooo1?l0000eooooo`0000?ooooooa0@4?ooool00_ooool00ol@413o
ooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`1Joooo
o`;o00001OoooolIo`0000Cooooo0_l0000Eooooo`;o000000?oooooo`000?l000003?ooool5o`00
00?ooooo0_l000000ooooooo0000o`00000Xo`000003ooooool0003o000000gooooo0_l00004oooo
o`;o00002?ooool2o`0001?ooooo0_l0000gooooo`0000?oooooo`000?ooool00_ooool00ol0003o
ooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0003Kooooo0_l0000Roooo
o`;o000000?oooooo`000?l000006_l00004ooooo`?o00005Oooool2o`0000;ooooo0_l0000:oooo
o`;o00000_ooool2o`0000Kooooo8_l000000ooooooo0000o`000006o`0000oooooo0_l00004oooo
o`;o00001oooool5o`00017ooooo0_l0000gooooo`0000?oooooo`000?ooool00_ooool00ol0003o
ooooooooo`09ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0foooo
o`;o00008oooool6o`0000;ooooo4_l00002ooooo`;o00001?ooool2o`0001Gooooo0ol00002oooo
o`;o00002_ooool2o`000003ooooool0003o000000?ooooo0_l00002ooooob_o00004_ooool4o`00
00Sooooo1Ol0001:ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`03
oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0?_ooool2o`0000;ooooo0_l0000Gooooo`;o
00000_ooool2o`0000;ooooo4?l0000Qooooo`?o00003_ooool2o`000003ooooool0003o000000?o
oooo0_l00004ooooobSo00004oooool4o`0000Sooooo0_l0000Booooo`?o0000>?ooool00006oooo
oomgMgOoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo
03Wooooo0_l00003ooooo`;o00000_ooool5o`0001Oooooo0ol000000ooooooo0000o`000002oooo
o`Wo00000oooool2o`000003ooooool0003o000002Kooooo0_l00005ooooo`?o00003?oooolTo`00
00;ooooo0_l0000Eooooo`;o00001_ooool3o`0001?ooooo0ol0000hooooo`0000Koooooonk^k_lb
<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0>Ooo
ool2o`0000Oooooo1Ol000000ooooooo0000o`000002o`0001;ooooo0_l00002ooooo`;o00001Ooo
ool2o`0000Oooooo0_l000001?oooooo0000o`000?l0000Uooooo`;o00001Oooool4o`0000;ooooo
0_l00006ooooo`So000000?oooooo`000?l000006_l00002ooooo`;o000000?oooooo`000?l00000
6_ooool3o`0001;ooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`18ooooo`Co00000ooo
ool2o`0000Gooooo0_l0000Jooooo`So0000:_ooool4o`0000;ooooo0_l00006ooooobco00003ooo
ool2o`0000Oooooo0_l0000Dooooo`?o0000>_ooool001cooooo00?o0000ooooooooool0?Oooool2
o`00013ooooo0_l00005ooooo`;o00006_ooool8o`0002[ooooo1?l00005ooooo`;o00000ooooolW
o`0000;ooooo1?l00007ooooo`;o00000oooool4o`0000Oooooo0_l0000Dooooo`;o0000>oooool0
01cooooo00?o0000ooooooooool0?Oooool2o`0000cooooo0_l00002ooooo`;o00006oooool2o`00
00Gooooo1_l0000[ooooo`Co00001Oooool2o`0000?ooooo:?l00002ooooo`?o00001oooool2o`00
0003ooooool0003o000000Co00001Oooool2o`0005?ooooo000Looooo`03o`000?oooooooooo03oo
oooo0_l00003ooooo`;o00001Oooool2o`0000;ooooo0_l0000;ooooo`;o00002?ooool2o`0000Co
oooo0_l000000ooooooo0000o`000002o`0003;ooooo0_l0000;ooooo`?o00001?ooool?o`000003
ooooool0003o000000co000000?oooooo`000?l000003oooool3o`000003ooooool0003o000000Go
oooo1?l0001Aooooo`007?ooool00ol0003oooooooooo`0oooooo`?o00000_ooool2o`0000Cooooo
0_l00006ooooo`;o00002?ooool2o`0000Cooooo1_l00007ooooo`Co0000:?ooool2o`0000Sooooo
0_l00006ooooo`;o00000_ooool3o`000003ooooool0003o000000;ooooo3ol000000ooooooo0000
o`000009o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000[ooooo1?l00007ooooo`;o
000000?oooooo`000?l000004_ooool2o`0003gooooo000Looooo`03o`000?oooooooooo03oooooo
0ol00004ooooo`;o00000_ooool2o`0000Kooooo0_l00007ooooo`Co00000oooool5o`0003Cooooo
0_l00008ooooo`Go00000oooool7o`000003ooooool0003o000000;ooooo3ol000000ooooooo0000
o`000005o`000003ooooool0003o000000Wooooo0_l00009ooooo`Go00001_ooool4o`0001Cooooo
0_l0000mooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00001?ooool2o`000003ooooool0
003o000000Kooooo0ol00007ooooo`Go00000_ooool2o`0000cooooo0_l0000cooooo`Go00000ooo
ool4o`000003ooooool0003o000000Oooooo5Ol00005ooooo`;o00003oooool3o`0000Wooooo1?l0
001Cooooo`007?ooool00ol0003oooooooooo`10ooooo`;o000000Coooooo`000?l0003o00000ooo
ool2o`0000Gooooo0ol0000;ooooo`;o00003oooool3o`0003?ooooo0ol00004ooooo`?o00003ooo
oolBo`0000Gooooo0_l0000>ooooo`?o00002?ooool2o`0005Oooooo000Looooo`03o`000?oooooo
oooo043ooooo0_l000001?oooooo0000o`000?l00003ooooo`;o000000?oooooo`000?l000001?l0
000?ooooo`;o00000oooool2o`0000Oooooo0ol0000cooooo`Go00000_ooool2o`0000Oooooo0_l0
0008ooooo`;o000000?oooooo`000?l000002_l0000=ooooo`;o00002?ooool2o`0000Kooooo1Ol0
000Dooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0A?ooool2o`0000Kooooo1Ol0000>
ooooo`Co00000oooool2o`0000Sooooo0_l0000eooooo`?o00001?ooool2o`0000;ooooo0_l00000
0ooooooo0000o`000003ooooo`;o00001_ooool;o`000003ooooool0003o000000Wooooo1?l0000@
ooooo`?o00005?ooool4o`00047ooooo000Looooo`03o`000?oooooooooo04Cooooo0_l00007oooo
o`;o00004?ooool2o`0000?ooooo0_l0000<ooooo`?o0000<_ooool2o`0000Gooooo0_l00002oooo
o`;o00001_ooool2o`0000Cooooo1?l00006ooooo`;o00000_ooool2o`0000Wooooo0_l00007oooo
o`;o00007oooool3o`0004?ooooo000Looooo`;o0000BOooool2o`0000?ooooo0_l0000=ooooo`;o
00001_ooool2o`000003ooooool0003o000000Kooooo0_l000000ooooooo0000o`000002o`0002So
oooo0_l00007ooooo`Co00005Oooool2o`0000;ooooo0_l00004ooooo`;o00003oooool2o`0000Go
oooo0_l00005ooooo`?o00005oooool2o`0004Cooooo000Looooo`03o`000?oooooooooo04Sooooo
0_l00008ooooo`Co00001_ooool2o`0000Kooooo1Ol00006ooooo`;o000000?oooooo`000?l00000
0_l0000Xooooo`?o00001_ooool4o`0000?ooooo0ol0000;ooooo`;o00001_ooool2o`0000_ooooo
0_l00008ooooo`;o00000oooool4o`0000Cooooo1?l0000Gooooo`;o0000A?ooool001cooooo00?o
0000ooooooooool0Coooool2o`000003ooooool0003o000000;o00003_ooool5o`0000cooooo1?l0
000Vooooo`;o00001_ooool4o`0000?ooooo0ol0000;ooooo`;o00001?ooool2o`0000Sooooo0_l0
0003ooooo`;o00001Oooool2o`0000Kooooo1?l00002ooooo`Co00005oooool4o`0004Cooooo000L
ooooo`03o`000?oooooooooo04cooooo0_l000000ooooooo0000o`000006ooooo`;o00007?ooool4
o`0002oooooo1?l0000Cooooo`;o000000?oooooo`000?l000002?ooool2o`0000Wooooo0ol0000<
ooooo`;o00005oooool4o`0004Kooooo000Looooo`03o`000?oooooooooo04cooooo0ol00008oooo
o`;o00009?ooool2o`0001[ooooo0ol0000<ooooo`Co00000_ooool3o`0000Gooooo0_l00007oooo
o`;o00005_ooool4o`0000Cooooo0_l0000Nooooo`;o0000B?ooool001cooooo00?o0000oooooooo
ool0C?ooool3o`0000?ooooo0_l00003ooooo`;o00005_ooool2o`0000Sooooo0_l00002ooooo`;o
00000oooool2o`0001Gooooo0ol00005ooooo`;o00001Oooool4o`0000;ooooo0ol00005ooooo`;o
00005oooool2o`0000Sooooo0_l00004ooooo`;o00000_ooool2o`0001Sooooo0ol00019ooooo`00
7?ooool00ol0003oooooooooo`1Booooo`;o00001?ooool2o`0001Gooooo0_l00008ooooo`Co0000
1Oooool2o`000003ooooool0003o000001Cooooo0_l00003ooooo`?o00001_ooool3o`0000Oooooo
0_l0000Jooooo`;o00001Oooool3o`0000Wooooo1?l0000Eooooo`Go0000BOooool001cooooo00?o
0000ooooooooool0D?ooool2o`0000Kooooo0_l0000Aooooo`?o000000?oooooo`000?l000001ol0
0002ooooo`?o00002?ooool2o`0001Cooooo0_l00003ooooo`;o00001oooool7o`0000?ooooo1?l0
000Mooooo`Go00001_ooool2o`000003ooooool0003o000000;o00004Oooool2o`0000;ooooo0_l0
001<ooooo`007?ooool00ol0003oooooooooo`1?ooooo`?o00001Oooool3o`00017ooooo0ol00000
0ooooooo0000o`000007o`0000;ooooo0_l00007ooooo`;o000000?oooooo`000?l000002_ooool2
o`0001Oooooo1ol00003ooooo`?o00007?ooool4o`0000Gooooo1?l0000Eooooo`Go0000C_ooool0
01cooooo00?o0000ooooooooool0Coooool3o`0000Gooooo1?l0000@ooooo`Co000000?oooooo`00
0?l000002?ooool2o`0000;ooooo0ol00002ooooo`;o000000?oooooo`000?l000001Oooool2o`00
00?ooooo0_l00009ooooo`Go00002Oooool2o`000003ooooool0003o000000;o000000Coooooo`00
0?l0003ooooo0_l00003ooooo`;o00006Oooool2o`0000Gooooo0_l0000Gooooo`;o000000Cooooo
o`000?l0003o0000COooool001cooooo00?o0000ooooooooool0Coooool2o`0000Sooooo0_l0000A
ooooo`Ko00000oooool2o`0000Oooooo0ol00009ooooo`;o000000Coooooo`000?l0003o00003Ooo
ool5o`0000[ooooo0_l00004ooooo`?o00001_ooool2o`0003gooooo0_l00002ooooo`;o0000BOoo
ool001cooooo00?o0000ooooooooool0D_ooool5o`0001Gooooo1?l00005ooooo`;o00004oooool6
o`0001;ooooo0_l00008ooooo`?o00000_ooool3o`0000_ooooo0_l0000>ooooo`;o00008?ooool2
o`0000Kooooo0_l00003ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0DOooool6o`00
01Kooooo1?l00004ooooo`;o00000_ooool3o`0000[ooooo0_l00004ooooo`Co00001oooool2o`00
00Gooooo0_l00002ooooo`;o00002Oooool6o`0000Cooooo0_l00006ooooo`;o00002?ooool3o`00
00?ooooo0ol0000Nooooo`?o00001_ooool3o`000004ooooool0003o0000o`0004Wooooo000Loooo
o`03o`000?oooooooooo053ooooo0ol00003ooooo`;o00005Oooool4o`0000Kooooo1Ol00007oooo
o`;o000000?oooooo`000?l000002?l00007ooooo`;o00001Oooool2o`0000kooooo0ol00006oooo
o`;o00004?ooool3o`0000Cooooo0_l0000Nooooo`;o00002?ooool2o`000003ooooool0003o0000
04[ooooo000Looooo`03o`000?oooooooooo053ooooo0ol00003ooooo`;o00005Oooool4o`0000Ko
oooo1_l00002ooooo`Ko00000oooool8o`0000?ooooo0_l0000:ooooo`;o000000?oooooo`000?l0
00002_ooool4o`0000gooooo0_l0000;ooooo`;o00002?ooool2o`0001Gooooo0_l0000;ooooo`;o
0000COooool001cooooo00?o0000ooooooooool0DOooool2o`00013ooooo0_l00009ooooo`Co0000
1oooool4o`000003ooooool0003o000000?o00004?ooool3o`0000Wooooo0_l000000ooooooo0000
o`00000:ooooo`Co00002oooool4o`0000_ooooo0_l00008ooooo`;o00005Oooool2o`0005[ooooo
000Looooo`;o0000D_ooool2o`00013ooooo1?l00007ooooo`Co00003?ooool5o`0000Gooooo0_l0
000:ooooo`;o00006_ooool2o`0000Gooooo1?l00002ooooo`;o00000_ooool3o`0000Kooooo0_l0
000Nooooo`;o0000GOooool001cooooo00?o0000ooooooooool0DOooool2o`000004ooooool0003o
0000o`0000kooooo0_l00007ooooo`Co00003?ooool3o`0000Gooooo1_l00008ooooo`?o00002ooo
ool2o`0001?ooooo1?l000000ooooooo0000o`000003ooooo`Oo00000_ooool2o`0001kooooo0_l0
0002ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0E?ooool3o`0000[ooooo0_l0000<
ooooo`Co00002oooool2o`0000Gooooo2_l00005ooooo`?o00002Oooool6o`0001Kooooo0ol00002
ooooo`;o000000?oooooo`000?l000000_l0000Vooooo`;o00001_ooool2o`00057ooooo000Loooo
o`03o`000?oooooooooo05?ooooo0_l00002ooooo`;o00002?ooool2o`0000cooooo1Ol00003oooo
o`?o00001?ooool2o`0000Cooooo2ol00006ooooo`;o00002Oooool2o`0000;ooooo0ol0000Foooo
o`;o0000:?ooool2o`0000gooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o
00000_ooool2o`0000Oooooo0_l00008ooooo`Co00000oooool3o`0000?ooooo1Ol00008ooooo`Ko
000000?oooooo`000?l000000ol00005ooooo`;o00003_ooool2o`00043ooooo0_l0000=ooooo`;o
0000DOooool001cooooo00?o0000ooooooooool0H?ooool2o`0000Sooooo1?l00005ooooo`;o0000
0oooool5o`0000Oooooo0ol000000ooooooo0000o`000002ooooo`Go00001?ooool2o`0000[ooooo
0ol000000ooooooo0000o`000011ooooo`;o00002?ooool2o`0005Gooooo000Looooo`03o`000?oo
oooooooo05Kooooo0_l000000ooooooo0000o`000003o`0001Gooooo0_l00003ooooo`;o000000?o
ooooo`000?l000000ol00004ooooo`;o00001?ooool7o`0000Cooooo0_l0000:ooooo`?o000000Co
ooooo`000?l0003o0000>Oooool2o`0000Gooooo0_l00008ooooo`;o0000EOooool001cooooo00?o
0000ooooooooool0EOooool9o`0001Kooooo0_l00007ooooo`?o00001?ooool<o`0000Gooooo0_l0
000:ooooo`;o00000_ooool3o`0003Sooooo0ol0000:ooooo`;o0000F_ooool001cooooo00?o0000
ooooooooool0EOooool4o`000003ooooool0003o000000;o00000_ooool2o`0000[ooooo0_l00005
ooooo`Co000000?oooooo`000?l000001?ooool2o`0000Cooooo3Ol00003ooooo`?o00002_ooool2
o`0003gooooo0_l000000ooooooo0000o`000008ooooo`;o0000F_ooool001cooooo00?o0000oooo
ooooool0Foooool2o`0000?ooooo0_l00003ooooo`;o00000oooool4o`0000Gooooo1?l000001?oo
oooo0000o`000?l00003ooooo`;o00001?ooool=o`000003ooooool0003o000000?o00002_ooool2
o`0003Sooooo0_l00004ooooo`Co00001_ooool4o`0005[ooooo000Looooo`03o`000?oooooooooo
05Wooooo1?l00008ooooo`;o00000_ooool3o`0000Cooooo0_l000000ooooooo0000o`000003o`00
0003ooooool0003o000000?ooooo0ol00004ooooo`Co00000_ooool:o`0000Sooooo0ol000000ooo
oooo0000o`000003ooooo`;o0000<oooool2o`0000Cooooo0_l00008ooooo`Co0000F_ooool001co
oooo00?o0000ooooooooool0F?ooool3o`0000kooooo0ol00004ooooo`;o00000oooool3o`0000Ko
oooo0ol00004ooooo`Co00000_ooool8o`0000Wooooo1?l000000ooooooo0000o`000003ooooo`;o
0000=oooool4o`0000;ooooo0_l0001Rooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o0000
2?ooool2o`0000Kooooo1Ol00006ooooo`Co000000?oooooo`000?l000001?ooool2o`0000Kooooo
0_l00006ooooo`;o00002_ooool5o`0000Cooooo0_l0000cooooo`;o00000oooool8o`0006;ooooo
000Looooo`03o`000?oooooooooo05_ooooo1_l000000ooooooo0000o`000006ooooo`Go000000?o
ooooo`000?l000001?ooool6o`0000Cooooo0_l00005ooooo`?o00003oooool3o`000003ooooool0
003o000000?o00000oooool2o`0003?ooooo0_l00003ooooo`So00001Oooool2o`0005_ooooo000L
ooooo`03o`000?oooooooooo05Wooooo2Ol0000>ooooo`;o00001?ooool5o`0000cooooo1Ol0000=
ooooo`Wo00000oooool2o`0003Sooooo1?l000001Ooooooo0000o`000?l0003ooooo00;o00000_oo
ool2o`0005_ooooo000Looooo`03o`000?oooooooooo05Wooooo0_l00004ooooo`?o00005?ooool4
o`0000kooooo1Ol00009ooooo`?o000000?oooooo`000?l000001Ol00002ooooo`Co0000?Oooool2
o`0000;ooooo0_l0001Oooooo`007?ooool2o`00063ooooo1?l000000ooooooo0000o`00000Boooo
o`;o00003_ooool5o`0000Oooooo2ol00003ooooo`Co0000;?ooool2o`0000oooooo0_l0001Toooo
o`007?ooool00ol0003oooooooooo`1Nooooo`Go000000?oooooo`000?l000004oooool2o`0000oo
oooo0_l00002ooooo`;o00000_ooool6o`000003ooooool0003o000000;ooooo0_l00003ooooo`Co
0000;?ooool2o`0000;ooooo0_l0000;ooooo`?o0000Hoooool001cooooo00?o0000ooooooooool0
G?ooool4o`0001Wooooo1?l0000Aooooo`;o00000_ooool2o`0000Oooooo0_l00004ooooo`;o0000
:oooool2o`0000;ooooo0_l00002ooooo`;o00000_ooool2o`0000Sooooo0_l0001Sooooo`007?oo
ool00ol0003oooooooooo`1Looooo`;o00007Oooool2o`00017ooooo0_l0000;ooooo`Co00000_oo
ool2o`0002Wooooo1?l000000ooooooo0000o`000007ooooo`;o0000KOooool001cooooo00?o0000
ooooooooool0GOooool4o`0000Kooooo0_l00007ooooo`;o00002Oooool5o`0000;ooooo0_l0000:
ooooo`Go000000?oooooo`000?l000001Ol00002ooooo`;o00001Oooool2o`0002Kooooo0ol00002
ooooo`;o00001_ooool3o`0006gooooo000Looooo`03o`000?oooooooooo05gooooo1?l00006oooo
o`?o00000oooool2o`000003ooooool0003o000000_ooooo0ol00002ooooo`;o00002oooool?o`00
00Kooooo0_l0000cooooo`Co000000?oooooo`000?l00000JOooool001cooooo00?o0000oooooooo
ool0Goooool3o`0000Kooooo0_l00003ooooo`;o00002_ooool2o`0000;ooooo1Ol00004ooooo`;o
00002_ooool4o`0000Cooooo1?l000000ooooooo0000o`00000Xooooo`;o00004?ooool2o`000003
ooooool0003o000006Wooooo000Looooo`03o`000?oooooooooo063ooooo0_l00006ooooo`;o0000
0_ooool2o`0000_ooooo0_l00004ooooo`Co00000oooool3o`0001Kooooo0_l0000Xooooo`;o0000
4oooool2o`0006Wooooo000Looooo`03o`000?oooooooooo06cooooo1?l00008ooooo`Co00001Ooo
ool4o`0000;ooooo0_l00002ooooo`;o0000B?ooool2o`0000Gooooo0_l0001[ooooo`007?ooool0
0ol0003oooooooooo`1^ooooo`;o00002?ooool4o`0000Kooooo1?l00005ooooo`;o0000A_ooool4
o`0000Gooooo0_l0001[ooooo`007?ooool00ol0003oooooooooo`1]ooooo`;o00001_ooool2o`00
00_ooooo1ol0001:ooooo`;o0000M?ooool001cooooo00?o0000ooooooooool0K?ooool3o`0000Ko
oooo0_l0000?ooooo`Go0000@_ooool2o`0007[ooooo000Looooo`03o`000?oooooooooo06cooooo
0_l00009ooooo`;o00001_ooool2o`0000Kooooo1?l000000ooooooo0000o`000002ooooo`;o0000
>oooool2o`0000Sooooo0_l0001`ooooo`007?ooool00ol0003oooooooooo`1Xooooo`;o00003Ooo
ool2o`0000Kooooo0_l0000:ooooo`Oo0000@oooool4o`00073ooooo00001_ooooook^k^oc8b<_l0
003o<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003o
ooooooooo`1Xooooo`;o00001Oooool2o`0001[ooooo1Ol00004ooooo`;o0000?oooool2o`0007;o
oooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B401_ooool00ol0003oooooooooo`1[ooooo`Ko00000_ooool2o`0001Wooooo1?l00002
ooooo`;o0000<oooool2o`0000;ooooo0_l0001jooooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`1Z
ooooo`So000000?oooooo`000?l000001oooool2o`00013ooooo1Ol0000fooooo`;o00000_ooool2
o`0000?ooooo0_l0001eooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09oooo
o`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`0006[ooooo0_l00002ooooo`Co00002_ooool3
o`0000Gooooo0_l0000:ooooo`?o000000?oooooo`000?l00000=oooool2o`0000;ooooo0ol0001e
ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05olc<c?l0003o0000
o`000?o<c<`01_ooool00ol0003oooooooooo`1Zooooo`;o00001_ooool2o`0000Wooooo0_l00002
ooooo`;o000000?oooooo`000?l000000_ooool2o`0000[ooooo1?l0000Yooooo`;o00000oooool3
o`0000Cooooo0_l00002ooooo`;o0000M_ooool00003ooooool@413ooooo00;ooooo00?o410@oooo
ooooool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0KOooool2
o`0000?ooooo0ol0000<ooooo`;o00001Oooool2o`0000[ooooo2Ol00002ooooo`;o00008?ooool2
o`0000?ooooo0ol00005ooooo`;o0000NOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2ooo
ool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0KOooool2o`0000Cooooo
0_l0000Gooooo`;o00002Oooool<o`0000?ooooo0ol0000Fooooo`Co00002oooool2o`0007Wooooo
00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06oooo
o`03o`000?oooooooooo08?ooooo0_l00005ooooo`Co00003?ooool5o`000005ooooool0003o0000
o`000?ooool01Ol0000Fooooo`;o00001_ooool4o`0007kooooo000Looooo`03o`000?oooooooooo
07Oooooo0_l0000:ooooo`;o00001Oooool2o`0001Cooooo0_l00002ooooo`;o00006?ooool2o`00
0003ooooool0003o000000Cooooo1?l0001nooooo`007?ooool00ol0003oooooooooo`1gooooo`Co
00005?ooool2o`0000Cooooo0_l00009ooooo`;o00006Oooool2o`000004ooooool0003o0000oooo
o`?o00000oooool2o`00083ooooo000Looooo`03o`000?oooooooooo07Wooooo0_l0000@ooooo`;o
00000_ooool2o`0000Cooooo0_l0000Nooooo`;o00000_ooool4o`0000?ooooo1?l00003ooooo`;o
0000P?ooool001cooooo00?o0000ooooooooool0Roooool2o`0000Kooooo0_l0000Pooooo`;o0000
0_ooool2o`0000Gooooo0_l00027ooooo`007?ooool00ol0003oooooooooo`1looooo`Co00003_oo
ool2o`0000?ooooo0_l0002dooooo`007?ooool00ol0003oooooooooo`1looooo`Co00003_ooool2
o`0000kooooo1?l00006ooooo`;o00001_ooool3o`0000Gooooo0_l00002ooooo`;o0000Roooool0
01cooooo00?o0000ooooooooool0O_ooool3o`000003ooooool0003o0000013ooooo0_l00008oooo
o`Co00001_ooool2o`0000Kooooo1Ol00003ooooo`;o00000_ooool2o`0008_ooooo000Looooo`03
o`000?oooooooooo07oooooo0_l000000ooooooo0000o`00000@ooooo`;o00000_ooool2o`0000Wo
oooo0ol000001?oooooo0000o`000?l00004ooooo`;o000000?oooooo`000?l000000_l0002Doooo
o`007?ooool00ol0003oooooooooo`23ooooo`?o00004_ooool3o`0000Sooooo0ol000001?oooooo
0000o`000?l00004ooooo`;o000000?oooooo`000?l000000oooool2o`00097ooooo000Looooo`03
o`000?oooooooooo08?ooooo0ol0000Booooo`?o00000_ooool2o`0000Sooooo0_l00007ooooo`;o
00001?ooool2o`00097ooooo000Looooo`03o`000?oooooooooo09gooooo0_l00002ooooo`;o0000
2oooool4o`0009Oooooo000Looooo`;o0000W_ooool2o`0000;ooooo0_l0000;ooooo`;o0000VOoo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2>oooo
o`;o0000^Oooool001cooooo00?o0000ooooooooool0S_ooool3o`000;Sooooo000Looooo`03o`00
0?oooooooooo08oooooo0_l0002hooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000B
ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooood[ooooo000Doooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003o
ooooooooo`05ooooo`?o0000oooooom:ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo
000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomB
ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Booooo`03oeEEEOmVIVKo00000?oo
ooooE?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Gooooo00Co410@o`00
0?l0003ooooo0_l000000ol@413oooooooooo`0Eooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00;ooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c02@ooooo`00Y_ooool01Ol0003ooooooooo
oooooooo000000Wooooo1_l00009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool02OmgMgOo
<S8boooooooooooo8B4QoiRHV?ooooooV9RHob4Q8@2@ooooo`00Y_ooool01Ol0003ooooooooooooo
oooo000001Wooooo00?oV9RHob4Q8Oo^k^h02Oooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo08kooooo002Vooooo`05o`000?ooooooooooooooool000002Oooool6o`0000_ooooo
00?oV9RHob4Q8Oo^k^h01oooool02OmgMgOo<S8boooooooooooo<S8boiRHV?ooooooV9RHoc8b<P2@
ooooo`00Y_ooool01Ol0003oQhN7oooooonYZJWo000001_ooooo00?oMgMgofIVI_ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Goc<c<o`000?l0003o0000olc<c02@ooooo`00YOoo
ool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo01[ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`05oa0@4?nj^[[ooooookZj^_l@4100T?ooool00<?ooooo00Go
0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Cooooo00Go0000okZj^_oooooo
^[Zjo`00002@ooooo`00`oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00003ooooo`05
ojVYZOl@413o0000oa0@4?nYZJT0T?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(264) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.6234 .41489 Mdot
.646 .39751 Mdot
.25102 .4003 Mdot
.59888 .63686 Mdot
.37288 .54784 Mdot
.31495 .39043 Mdot
.45883 .30805 Mdot
.46102 .29944 Mdot
.30465 .43101 Mdot
.70518 .66717 Mdot
.43211 .31696 Mdot
.58619 .57557 Mdot
.47348 .31082 Mdot
.58594 .61358 Mdot
.42381 .68095 Mdot
.59055 .64929 Mdot
.65033 .42529 Mdot
.31017 .56772 Mdot
.60073 .65051 Mdot
.34335 .42429 Mdot
.55146 .51325 Mdot
.60071 .61239 Mdot
.63496 .36626 Mdot
.58746 .61116 Mdot
.64937 .63524 Mdot
.65679 .39774 Mdot
.62284 .41345 Mdot
.63452 .60469 Mdot
.61422 .64001 Mdot
.45875 .33536 Mdot
.48909 .62387 Mdot
.42251 .79186 Mdot
.45639 .51822 Mdot
.76099 .52818 Mdot
.47306 .33441 Mdot
.51389 .31407 Mdot
.27814 .38446 Mdot
.4855 .33398 Mdot
.42596 .30844 Mdot
.43871 .30346 Mdot
.43861 .30595 Mdot
.65747 .40076 Mdot
.49821 .31829 Mdot
.29207 .2772 Mdot
.58309 .60249 Mdot
.77828 .42233 Mdot
.28011 .437 Mdot
.61834 .59872 Mdot
.6527 .36308 Mdot
.30694 .43568 Mdot
.32402 .66841 Mdot
.465 .29338 Mdot
.47415 .53825 Mdot
.7568 .26483 Mdot
.46757 .30362 Mdot
.63457 .64908 Mdot
.31359 .41646 Mdot
.55667 .60385 Mdot
.56818 .57817 Mdot
.74906 .48933 Mdot
.55785 .61291 Mdot
.32638 .55535 Mdot
.6984 .36848 Mdot
.30026 .43841 Mdot
.29121 .42819 Mdot
.49658 .32285 Mdot
.67348 .41529 Mdot
.4754 .32791 Mdot
.6133 .63654 Mdot
.32963 .42662 Mdot
.63485 .63802 Mdot
.43274 .31811 Mdot
.62555 .41045 Mdot
.60897 .61313 Mdot
.6244 .3192 Mdot
.49717 .26866 Mdot
.2975 .55848 Mdot
.64416 .46806 Mdot
.36612 .40828 Mdot
.43579 .66576 Mdot
.60657 .61217 Mdot
.4496 .18451 Mdot
.38761 .70538 Mdot
.63907 .37277 Mdot
.57198 .65614 Mdot
.54295 .21215 Mdot
.63851 .62036 Mdot
.49006 .61692 Mdot
.58394 .5702 Mdot
.32624 .61609 Mdot
.32073 .41574 Mdot
.67031 .37119 Mdot
.59715 .60312 Mdot
.61824 .62711 Mdot
.73667 .64103 Mdot
.60514 .64417 Mdot
.62597 .59576 Mdot
.4196 .53829 Mdot
.45456 .28901 Mdot
.48007 .52772 Mdot
.38655 .39206 Mdot
.49352 .54592 Mdot
.63914 .63348 Mdot
.31092 .40083 Mdot
.69568 .36503 Mdot
.48198 .52468 Mdot
.46805 .3295 Mdot
.59665 .60585 Mdot
.41586 .28318 Mdot
.64759 .36382 Mdot
.65712 .6285 Mdot
.346 .56177 Mdot
.51209 .47223 Mdot
.61944 .39711 Mdot
.81116 .54177 Mdot
.58817 .63118 Mdot
.56604 .58824 Mdot
.64624 .40067 Mdot
.34558 .41368 Mdot
.3991 .21355 Mdot
.63451 .41434 Mdot
.44473 .29176 Mdot
.6592 .42288 Mdot
.42273 .52963 Mdot
.34817 .41843 Mdot
.46423 .55335 Mdot
.43837 .54627 Mdot
.37673 .75478 Mdot
.58441 .63579 Mdot
.55271 .5351 Mdot
.3071 .39436 Mdot
.63288 .4093 Mdot
.48165 .3133 Mdot
.54003 .60177 Mdot
.65893 .38026 Mdot
.4565 .30464 Mdot
.31109 .54292 Mdot
.32295 .57575 Mdot
.62503 .38356 Mdot
.81823 .52906 Mdot
.47123 .27956 Mdot
.47735 .28851 Mdot
.32597 .67059 Mdot
.63785 .37392 Mdot
.33222 .54342 Mdot
.46261 .32529 Mdot
.17527 .56025 Mdot
.65294 .64141 Mdot
.33561 .70406 Mdot
.45517 .1889 Mdot
.32401 .66754 Mdot
.56596 .52686 Mdot
.34667 .55257 Mdot
.45607 .30441 Mdot
.61041 .59927 Mdot
.64033 .3805 Mdot
.65916 .38358 Mdot
.63179 .63512 Mdot
.49797 .53497 Mdot
.57448 .61447 Mdot
.46364 .5223 Mdot
.45162 .55558 Mdot
.59325 .60325 Mdot
.79701 .38787 Mdot
.65204 .37133 Mdot
.5535 .64158 Mdot
.27886 .38779 Mdot
.51754 .54661 Mdot
.49742 .31668 Mdot
.54568 .59957 Mdot
.62078 .66118 Mdot
.57608 .57224 Mdot
.46011 .28206 Mdot
.67689 .29539 Mdot
.36308 .41751 Mdot
.43267 .30513 Mdot
.39254 .34193 Mdot
.28987 .39638 Mdot
.58382 .58035 Mdot
.35735 .5567 Mdot
.46491 .52863 Mdot
.61634 .61312 Mdot
.32054 .6627 Mdot
.56941 .57901 Mdot
.58401 .52732 Mdot
.58814 .54569 Mdot
.50871 .21124 Mdot
.69064 .31032 Mdot
.60738 .63387 Mdot
.68646 .59482 Mdot
.33613 .69406 Mdot
.52339 .32827 Mdot
.48314 .3153 Mdot
.33355 .39913 Mdot
.3418 .40813 Mdot
.44473 .2533 Mdot
.79038 .54382 Mdot
.69647 .6898 Mdot
.54796 .61576 Mdot
.48704 .54321 Mdot
.63283 .43298 Mdot
.34423 .55176 Mdot
.62398 .39285 Mdot
.44068 .18095 Mdot
.45761 .6567 Mdot
.49439 .66094 Mdot
.26875 .35452 Mdot
.28709 .43146 Mdot
.4908 .54815 Mdot
.33781 .5403 Mdot
.56722 .60254 Mdot
.64269 .36691 Mdot
.33366 .68666 Mdot
.5047 .54455 Mdot
.62691 .81558 Mdot
.63624 .41903 Mdot
.45704 .73467 Mdot
.46778 .30611 Mdot
.28804 .41591 Mdot
.64011 .62296 Mdot
.59238 .62403 Mdot
.6601 .35899 Mdot
.6013 .59024 Mdot
.50616 .69239 Mdot
.65266 .63741 Mdot
.33562 .43269 Mdot
.36529 .4378 Mdot
.42951 .29976 Mdot
.27835 .35553 Mdot
.61858 .39822 Mdot
.80871 .36885 Mdot
.29847 .40664 Mdot
.58196 .53673 Mdot
.43605 .32124 Mdot
.31134 .54695 Mdot
.30748 .40778 Mdot
.37303 .55357 Mdot
.54703 .585 Mdot
.27487 .39802 Mdot
.33442 .56086 Mdot
.508 .64726 Mdot
.48413 .52605 Mdot
.32688 .74076 Mdot
.45471 .31408 Mdot
.67471 .39337 Mdot
.61551 .60787 Mdot
.47875 .53548 Mdot
.50605 .54483 Mdot
.43737 .71964 Mdot
.4441 .54536 Mdot
.49831 .54993 Mdot
.3982 .65517 Mdot
.30547 .55771 Mdot
.6245 .23279 Mdot
.48922 .60507 Mdot
.64831 .42566 Mdot
.61725 .62325 Mdot
.40353 .29056 Mdot
.45313 .30658 Mdot
.56367 .606 Mdot
.49392 .20463 Mdot
.46297 .323 Mdot
.56252 .59321 Mdot
.42801 .31868 Mdot
.65159 .37541 Mdot
.46755 .68806 Mdot
.63413 .42311 Mdot
.59011 .59897 Mdot
.42992 .31989 Mdot
.33014 .39522 Mdot
.65735 .39573 Mdot
.59934 .60841 Mdot
.56306 .62409 Mdot
.48175 .54248 Mdot
.65258 .63946 Mdot
.52371 .28794 Mdot
.62387 .60325 Mdot
.25116 .3878 Mdot
.60853 .64283 Mdot
.40034 .54273 Mdot
.24069 .58357 Mdot
.62976 .3785 Mdot
.4454 .54551 Mdot
.31101 .41226 Mdot
.51223 .68513 Mdot
.46327 .7391 Mdot
.58469 .60528 Mdot
.45935 .54837 Mdot
.41968 .75432 Mdot
.48396 .29678 Mdot
.58606 .57047 Mdot
.34328 .60093 Mdot
.32102 .41231 Mdot
.49024 .54568 Mdot
.57347 .65374 Mdot
.60482 .41674 Mdot
.60351 .64969 Mdot
.2792 .40158 Mdot
.65064 .42258 Mdot
.61641 .64648 Mdot
.51945 .30502 Mdot
.51044 .55433 Mdot
.46907 .2864 Mdot
.51081 .57754 Mdot
.59105 .58265 Mdot
.32711 .42834 Mdot
.66091 .39964 Mdot
.46545 .30123 Mdot
.6202 .40161 Mdot
.33566 .6516 Mdot
.43869 .74293 Mdot
.66161 .32333 Mdot
.30939 .53995 Mdot
.19334 .60444 Mdot
.44031 .29506 Mdot
.44647 .5261 Mdot
.23894 .39856 Mdot
.61762 .44972 Mdot
.31441 .40347 Mdot
.82003 .51424 Mdot
.31822 .41695 Mdot
.62279 .65325 Mdot
.33332 .4081 Mdot
.74084 .66308 Mdot
.55447 .58695 Mdot
.2795 .42405 Mdot
.41831 .54024 Mdot
.54963 .59563 Mdot
.66014 .3807 Mdot
.45644 .81067 Mdot
.77642 .54 Mdot
.78663 .55134 Mdot
.3075 .41624 Mdot
.8224 .50259 Mdot
.65574 .62981 Mdot
.54059 .56799 Mdot
.64255 .38387 Mdot
.45082 .5257 Mdot
.33853 .57573 Mdot
.35857 .57315 Mdot
.259 .62867 Mdot
.47812 .76569 Mdot
.80258 .55212 Mdot
.65696 .38527 Mdot
.36159 .43463 Mdot
.62753 .3187 Mdot
.50413 .54635 Mdot
.46068 .29934 Mdot
.66504 .28656 Mdot
.57705 .56971 Mdot
.49659 .56359 Mdot
.50793 .69428 Mdot
.67058 .40032 Mdot
.67947 .33714 Mdot
.4636 .30062 Mdot
.78656 .55433 Mdot
.69351 .67454 Mdot
.57234 .61288 Mdot
.44931 .30351 Mdot
.50554 .54409 Mdot
.49235 .61707 Mdot
.37799 .76177 Mdot
.22214 .34585 Mdot
.58537 .59914 Mdot
.63161 .29762 Mdot
.61541 .60966 Mdot
.36679 .7452 Mdot
.56623 .59999 Mdot
.66449 .3933 Mdot
.6444 .61057 Mdot
.49434 .60407 Mdot
.15534 .48204 Mdot
.45301 .65146 Mdot
.36967 .55287 Mdot
.58936 .61461 Mdot
.57656 .62049 Mdot
.32052 .54555 Mdot
.67162 .38461 Mdot
.6255 .62245 Mdot
.64129 .23955 Mdot
.60018 .60493 Mdot
.49568 .31679 Mdot
.41795 .70385 Mdot
.41772 .78742 Mdot
.65421 .63041 Mdot
.60472 .41795 Mdot
.47405 .28714 Mdot
.44204 .32328 Mdot
.44289 .53762 Mdot
.45214 .30755 Mdot
.6024 .59415 Mdot
.4181 .70544 Mdot
.68073 .40861 Mdot
.4999 .54062 Mdot
.67061 .39641 Mdot
.22069 .43623 Mdot
.45656 .31261 Mdot
.46571 .5427 Mdot
.7937 .52973 Mdot
.47134 .3222 Mdot
.36015 .47141 Mdot
.65343 .62067 Mdot
.50553 .54606 Mdot
.61372 .41093 Mdot
.32946 .42535 Mdot
.48486 .55279 Mdot
.46658 .30302 Mdot
.5832 .60387 Mdot
.64211 .64622 Mdot
.45125 .30744 Mdot
.68307 .46057 Mdot
.48847 .62164 Mdot
.59643 .59982 Mdot
.66285 .37655 Mdot
.63851 .41116 Mdot
.54532 .62124 Mdot
.61836 .61216 Mdot
.31589 .38926 Mdot
.45797 .54822 Mdot
.45905 .5495 Mdot
.4425 .54856 Mdot
.29948 .41754 Mdot
.1752 .58262 Mdot
.49124 .29844 Mdot
.42175 .79012 Mdot
.57028 .32614 Mdot
.47272 .5351 Mdot
.30739 .38291 Mdot
.58963 .62771 Mdot
.63296 .61774 Mdot
.43601 .32805 Mdot
.25125 .69512 Mdot
.54016 .57021 Mdot
.63639 .42258 Mdot
.45487 .29781 Mdot
.6305 .66252 Mdot
.41741 .26453 Mdot
.3405 .57081 Mdot
.80694 .54797 Mdot
.45875 .29619 Mdot
.68378 .36897 Mdot
.45944 .29568 Mdot
.57662 .61922 Mdot
.56876 .65162 Mdot
.66542 .40832 Mdot
.36967 .54659 Mdot
.62935 .6326 Mdot
.56543 .59347 Mdot
.38509 .37089 Mdot
.61722 .32423 Mdot
.3817 .55568 Mdot
.62699 .61309 Mdot
.43207 .52773 Mdot
.36206 .5408 Mdot
.59432 .59344 Mdot
.62098 .64248 Mdot
.55725 .53421 Mdot
.4782 .3401 Mdot
.32096 .53103 Mdot
.15006 .50728 Mdot
.63435 .41874 Mdot
.52712 .29508 Mdot
.49587 .55489 Mdot
.44015 .29624 Mdot
.52891 .70612 Mdot
.47559 .54764 Mdot
.58698 .30413 Mdot
.86559 .59426 Mdot
.48188 .55172 Mdot
.29212 .37718 Mdot
.74594 .62789 Mdot
.62221 .64092 Mdot
.59459 .59809 Mdot
.33327 .57509 Mdot
.6376 .4012 Mdot
.6893 .3092 Mdot
.43153 .30591 Mdot
.60269 .62607 Mdot
.61602 .39849 Mdot
.51857 .20992 Mdot
.48084 .54508 Mdot
.35477 .56497 Mdot
.3236 .53286 Mdot
.60625 .60165 Mdot
.43982 .75842 Mdot
.65888 .39321 Mdot
.5991 .60832 Mdot
.57217 .5857 Mdot
.31862 .3832 Mdot
.63591 .37276 Mdot
.27766 .39601 Mdot
.51751 .57419 Mdot
.77493 .63395 Mdot
.39375 .3335 Mdot
.45871 .32187 Mdot
.45039 .54192 Mdot
.42901 .2994 Mdot
.26472 .42681 Mdot
.45737 .54832 Mdot
.59879 .60943 Mdot
.68428 .40418 Mdot
.59888 .60723 Mdot
.59927 .60417 Mdot
.5788 .60148 Mdot
.80367 .55253 Mdot
.36706 .4076 Mdot
.35915 .55966 Mdot
.60664 .58844 Mdot
.28233 .40775 Mdot
.4188 .25916 Mdot
.71537 .66006 Mdot
.59243 .61856 Mdot
.56575 .58902 Mdot
.60821 .42398 Mdot
.65187 .64316 Mdot
.46642 .32036 Mdot
.66987 .40303 Mdot
.64088 .63464 Mdot
.37555 .3808 Mdot
.62499 .61819 Mdot
.67112 .32853 Mdot
.49232 .31599 Mdot
.64963 .67276 Mdot
.50405 .53532 Mdot
.45317 .54717 Mdot
.48608 .55225 Mdot
.44533 .55011 Mdot
.49634 .31954 Mdot
.29149 .37811 Mdot
.24042 .36325 Mdot
.5258 .57981 Mdot
.60942 .59738 Mdot
.57001 .65299 Mdot
.27372 .37325 Mdot
.41507 .54144 Mdot
.81135 .51575 Mdot
.6393 .66147 Mdot
.29461 .42167 Mdot
.42508 .54219 Mdot
.63259 .48082 Mdot
.67381 .39168 Mdot
.322 .44076 Mdot
.44672 .32956 Mdot
.33353 .56348 Mdot
.28625 .68078 Mdot
.64838 .41419 Mdot
.62884 .43863 Mdot
.29202 .38751 Mdot
.41603 .72 Mdot
.75187 .25281 Mdot
.31619 .39749 Mdot
.49766 .67117 Mdot
.6477 .3816 Mdot
.45711 .51997 Mdot
.41265 .74908 Mdot
.41181 .70921 Mdot
.29119 .42548 Mdot
.56467 .62551 Mdot
.215 .40765 Mdot
.32055 .39154 Mdot
.44974 .53168 Mdot
.3049 .41596 Mdot
.47801 .29093 Mdot
.30492 .39722 Mdot
.61896 .37318 Mdot
.5914 .63648 Mdot
.75493 .26091 Mdot
.38425 .67825 Mdot
.60004 .63333 Mdot
.4825 .29808 Mdot
.51943 .318 Mdot
.56825 .6116 Mdot
.35589 .57208 Mdot
.2894 .37706 Mdot
.31181 .46274 Mdot
.61383 .65176 Mdot
.33358 .41149 Mdot
.6074 .43112 Mdot
.341 .45259 Mdot
.3874 .3876 Mdot
.47856 .55291 Mdot
.64769 .37455 Mdot
.49274 .26638 Mdot
.44559 .29098 Mdot
.51378 .55449 Mdot
.57766 .58245 Mdot
.6567 .36922 Mdot
.51141 .67176 Mdot
.56971 .55419 Mdot
.60153 .60689 Mdot
.28213 .39392 Mdot
.31533 .43711 Mdot
.41974 .68211 Mdot
.29624 .40735 Mdot
.44727 .53221 Mdot
.65852 .37348 Mdot
.60575 .65121 Mdot
.63559 .41255 Mdot
.61845 .62217 Mdot
.41718 .26889 Mdot
.67339 .37513 Mdot
.58223 .53705 Mdot
.55333 .61603 Mdot
.79232 .39651 Mdot
.60603 .58651 Mdot
.59823 .60135 Mdot
.33501 .43042 Mdot
.32298 .54373 Mdot
.54494 .55544 Mdot
.42856 .25641 Mdot
.32407 .5608 Mdot
.66305 .47544 Mdot
.3467 .4143 Mdot
.31367 .54527 Mdot
.26101 .64541 Mdot
.4469 .54653 Mdot
.34645 .53702 Mdot
.56598 .65282 Mdot
.4554 .32069 Mdot
.68983 .39155 Mdot
.54873 .5964 Mdot
.76806 .63777 Mdot
.48721 .61696 Mdot
.47724 .54254 Mdot
.59109 .59433 Mdot
.58144 .62642 Mdot
.61635 .39942 Mdot
.44212 .18271 Mdot
.25171 .41135 Mdot
.4672 .52448 Mdot
.64264 .41699 Mdot
.45277 .18595 Mdot
.27957 .42277 Mdot
.31439 .56633 Mdot
.42458 .3053 Mdot
.67838 .34636 Mdot
.47759 .53944 Mdot
.45579 .31016 Mdot
.24807 .37401 Mdot
.32044 .65779 Mdot
.60316 .64901 Mdot
.28766 .3814 Mdot
.32331 .66642 Mdot
.65233 .61823 Mdot
.44782 .25195 Mdot
.51928 .33655 Mdot
.65609 .36413 Mdot
.45114 .3058 Mdot
.36249 .56112 Mdot
.65181 .42826 Mdot
.67152 .39487 Mdot
.46697 .32495 Mdot
.82909 .44642 Mdot
.42025 .75339 Mdot
.42314 .31714 Mdot
.43976 .7101 Mdot
.3234 .66384 Mdot
.48143 .53983 Mdot
.35622 .55966 Mdot
.36639 .43679 Mdot
.65697 .40072 Mdot
.66121 .28946 Mdot
.32323 .66831 Mdot
.64519 .61434 Mdot
.33151 .56027 Mdot
.52212 .21378 Mdot
.45372 .27338 Mdot
.46098 .31699 Mdot
.38569 .36984 Mdot
.32249 .55428 Mdot
.54474 .60297 Mdot
.26791 .73323 Mdot
.55903 .5852 Mdot
.46114 .32547 Mdot
.50726 .69354 Mdot
.62759 .39272 Mdot
.49317 .30514 Mdot
.50558 .69262 Mdot
.6276 .61249 Mdot
.58267 .63075 Mdot
.36852 .40179 Mdot
.66739 .36207 Mdot
.5077 .55154 Mdot
.60402 .63296 Mdot
.55931 .59762 Mdot
.49169 .52743 Mdot
.40942 .7807 Mdot
.52477 .46736 Mdot
.46818 .51937 Mdot
.27518 .41149 Mdot
.49798 .53673 Mdot
.46493 .52482 Mdot
.60911 .41217 Mdot
.38265 .39927 Mdot
.50431 .54999 Mdot
.58605 .59656 Mdot
.59232 .59899 Mdot
.42438 .30858 Mdot
.41868 .75354 Mdot
.41193 .71685 Mdot
.24628 .39646 Mdot
.32688 .59075 Mdot
.56778 .63259 Mdot
.64386 .37301 Mdot
.34887 .52831 Mdot
.44073 .53458 Mdot
.63907 .42227 Mdot
.60047 .63889 Mdot
.31551 .38079 Mdot
.47427 .55094 Mdot
.42582 .52607 Mdot
.33634 .55798 Mdot
.42956 .29478 Mdot
.66083 .46946 Mdot
.31426 .38618 Mdot
.6478 .6361 Mdot
.33274 .59553 Mdot
.32891 .4113 Mdot
.48375 .54042 Mdot
.49163 .53156 Mdot
.65363 .37767 Mdot
.67738 .36081 Mdot
.40449 .54791 Mdot
.29318 .4148 Mdot
.24901 .32082 Mdot
.45473 .2921 Mdot
.59763 .58502 Mdot
.44063 .28816 Mdot
.6425 .36432 Mdot
.37546 .7547 Mdot
.31776 .53821 Mdot
.46382 .32093 Mdot
.5037 .54535 Mdot
.67438 .38549 Mdot
.64566 .36195 Mdot
.59165 .60252 Mdot
.59794 .61469 Mdot
.31537 .44534 Mdot
.3377 .7021 Mdot
.43384 .32677 Mdot
.32316 .56944 Mdot
.24919 .40202 Mdot
.62665 .65087 Mdot
.63326 .38218 Mdot
.36641 .78714 Mdot
.59434 .58289 Mdot
.28567 .40947 Mdot
.64773 .39551 Mdot
.33578 .57456 Mdot
.36187 .55683 Mdot
.61097 .62679 Mdot
.56688 .52815 Mdot
.47276 .32391 Mdot
.66222 .384 Mdot
.69403 .41138 Mdot
.61393 .59279 Mdot
.59322 .61558 Mdot
.65477 .62063 Mdot
.42142 .31744 Mdot
.54755 .62988 Mdot
.3693 .54767 Mdot
.62154 .39083 Mdot
.60719 .62741 Mdot
.32319 .55164 Mdot
.47045 .55706 Mdot
.47221 .54842 Mdot
.30553 .43323 Mdot
.35653 .57274 Mdot
.32789 .54671 Mdot
.32281 .56259 Mdot
.66439 .28607 Mdot
.55202 .64586 Mdot
.39934 .56175 Mdot
.5628 .62485 Mdot
.32348 .66265 Mdot
.58044 .64689 Mdot
.46881 .29059 Mdot
.32436 .42943 Mdot
.57584 .60628 Mdot
.56024 .62272 Mdot
.64783 .47211 Mdot
.59851 .65176 Mdot
.54481 .61752 Mdot
.6266 .39047 Mdot
.67927 .43054 Mdot
.33873 .40508 Mdot
.45923 .19096 Mdot
.32009 .79004 Mdot
.53959 .59351 Mdot
.41681 .71626 Mdot
.67225 .38114 Mdot
.42452 .30662 Mdot
.43455 .72053 Mdot
.44394 .2834 Mdot
.64056 .40791 Mdot
.61763 .65413 Mdot
.69833 .43706 Mdot
.32551 .55964 Mdot
.57663 .61702 Mdot
.47922 .32419 Mdot
.57545 .61577 Mdot
.49131 .30489 Mdot
.81709 .4868 Mdot
.39202 .72395 Mdot
.55765 .58269 Mdot
.60639 .64403 Mdot
.54408 .51141 Mdot
.59481 .61701 Mdot
.22162 .37023 Mdot
.64596 .39077 Mdot
.51774 .55152 Mdot
.62023 .65513 Mdot
.7741 .54471 Mdot
.58085 .58879 Mdot
.54882 .71458 Mdot
.55401 .5961 Mdot
.23934 .67091 Mdot
.55073 .58344 Mdot
.57191 .58213 Mdot
.48443 .30815 Mdot
.43242 .31088 Mdot
.61036 .44178 Mdot
.49844 .54394 Mdot
.51466 .21172 Mdot
.5662 .59169 Mdot
.26545 .4208 Mdot
.61854 .54697 Mdot
.32495 .5463 Mdot
.62189 .39755 Mdot
.89843 .54818 Mdot
.49953 .31383 Mdot
.27067 .39717 Mdot
.49171 .64088 Mdot
.27252 .40511 Mdot
.2945 .4382 Mdot
.70877 .38928 Mdot
.35533 .5608 Mdot
.62344 .61735 Mdot
.76338 .52027 Mdot
.61564 .32018 Mdot
.61491 .59381 Mdot
.27724 .36759 Mdot
.55673 .53663 Mdot
.43706 .58987 Mdot
.30548 .56213 Mdot
.34345 .54705 Mdot
.46287 .3049 Mdot
.26324 .41757 Mdot
.47249 .52583 Mdot
.31368 .54398 Mdot
.3376 .40723 Mdot
.44483 .54321 Mdot
.37907 .40635 Mdot
.65978 .39242 Mdot
.82201 .50586 Mdot
.78147 .41853 Mdot
.46369 .28535 Mdot
.43146 .25323 Mdot
.68726 .39999 Mdot
.63805 .42531 Mdot
.49237 .54107 Mdot
.29926 .42405 Mdot
.69027 .38258 Mdot
.60824 .62925 Mdot
.4979 .53726 Mdot
.61066 .60444 Mdot
.30812 .56282 Mdot
.58324 .59158 Mdot
.33587 .40783 Mdot
.48678 .30926 Mdot
.31869 .41278 Mdot
.45884 .306 Mdot
.43471 .7994 Mdot
.55104 .61478 Mdot
.59217 .61344 Mdot
.41754 .70592 Mdot
.63201 .37207 Mdot
.75856 .53741 Mdot
.29228 .41288 Mdot
.3136 .41542 Mdot
.61648 .65518 Mdot
.66498 .41965 Mdot
.37754 .57501 Mdot
.44053 .70062 Mdot
.55592 .59338 Mdot
.64442 .39161 Mdot
.60182 .65546 Mdot
.50723 .24797 Mdot
.38963 .6982 Mdot
.62475 .37674 Mdot
.1562 .47716 Mdot
.54767 .60617 Mdot
.44709 .52464 Mdot
.54841 .54319 Mdot
.4526 .76599 Mdot
.56316 .55303 Mdot
.63722 .41993 Mdot
.47617 .52547 Mdot
.63699 .37986 Mdot
.32593 .40638 Mdot
.49427 .30538 Mdot
.63803 .38471 Mdot
.55038 .60442 Mdot
.32012 .78923 Mdot
.48863 .31871 Mdot
.57892 .61501 Mdot
.47884 .32774 Mdot
.69212 .36147 Mdot
.6311 .39947 Mdot
.44472 .54294 Mdot
.49697 .66952 Mdot
.4684 .32323 Mdot
.6056 .59447 Mdot
.65434 .30086 Mdot
.6017 .64947 Mdot
.3263 .5863 Mdot
.582 .64002 Mdot
.60022 .63953 Mdot
.15856 .55991 Mdot
.51639 .68372 Mdot
.39537 .31912 Mdot
.41887 .33772 Mdot
.67975 .29667 Mdot
.6113 .4069 Mdot
.31364 .56933 Mdot
.6334 .46777 Mdot
.45755 .54998 Mdot
.27441 .41263 Mdot
.57974 .60451 Mdot
.4519 .55328 Mdot
.43405 .32993 Mdot
.3432 .53724 Mdot
.56957 .57902 Mdot
.26394 .38528 Mdot
.4274 .53478 Mdot
.458 .31313 Mdot
.6564 .40274 Mdot
.62706 .40344 Mdot
.37333 .42228 Mdot
.60601 .62857 Mdot
.59867 .61239 Mdot
.47936 .33119 Mdot
.57855 .54155 Mdot
.32772 .56711 Mdot
.41821 .54034 Mdot
.47469 .32986 Mdot
.38864 .7 Mdot
.66738 .36147 Mdot
.5856 .62743 Mdot
.41805 .6994 Mdot
.68721 .30461 Mdot
.70839 .6044 Mdot
.34003 .54962 Mdot
.45631 .74512 Mdot
.63727 .41973 Mdot
.4813 .31136 Mdot
.25902 .63514 Mdot
.65859 .62722 Mdot
.56867 .61973 Mdot
.46346 .74587 Mdot
.44142 .70209 Mdot
.49298 .64313 Mdot
.50741 .54947 Mdot
.41307 .74253 Mdot
.61225 .65557 Mdot
.64282 .64345 Mdot
.56422 .63015 Mdot
.58533 .64123 Mdot
.63803 .39244 Mdot
.78323 .56062 Mdot
.29555 .39101 Mdot
.68784 .57953 Mdot
.3045 .57048 Mdot
.64094 .61129 Mdot
.63659 .62819 Mdot
.66931 .51869 Mdot
.48314 .72306 Mdot
.65188 .38706 Mdot
.61026 .39243 Mdot
.45657 .28522 Mdot
.59633 .64958 Mdot
.28905 .4119 Mdot
.5287 .55561 Mdot
.31887 .42867 Mdot
.63964 .39368 Mdot
.33385 .39367 Mdot
.50097 .30624 Mdot
.28666 .38132 Mdot
.2874 .41888 Mdot
.48406 .30251 Mdot
.67487 .37019 Mdot
.60346 .5846 Mdot
.48375 .30169 Mdot
.38432 .56649 Mdot
.31517 .56849 Mdot
.64521 .44372 Mdot
.46087 .51928 Mdot
.57316 .56955 Mdot
.27059 .30433 Mdot
.27751 .38405 Mdot
.47091 .70576 Mdot
.67236 .36995 Mdot
.32215 .52742 Mdot
.63496 .38713 Mdot
.40163 .55126 Mdot
.33692 .55177 Mdot
.57091 .65554 Mdot
.31125 .71405 Mdot
.51333 .34285 Mdot
.5998 .57786 Mdot
.68077 .42877 Mdot
.31909 .42754 Mdot
.48603 .30012 Mdot
.46069 .2232 Mdot
.46654 .52403 Mdot
.60857 .43541 Mdot
.66722 .34986 Mdot
.4581 .54955 Mdot
.48152 .31412 Mdot
.78176 .40677 Mdot
.60132 .63172 Mdot
.44567 .2864 Mdot
.58187 .63971 Mdot
.81389 .5368 Mdot
.28725 .55536 Mdot
.44767 .55287 Mdot
.62162 .65376 Mdot
.2789 .42209 Mdot
.61722 .65481 Mdot
.77978 .61136 Mdot
.35198 .73257 Mdot
.55445 .62201 Mdot
.47165 .72536 Mdot
.25177 .41696 Mdot
.63494 .37848 Mdot
.46077 .5363 Mdot
.48087 .54129 Mdot
.64454 .64945 Mdot
.42565 .85619 Mdot
.32412 .53853 Mdot
.31871 .35704 Mdot
.55128 .60877 Mdot
.60594 .61251 Mdot
.65407 .47393 Mdot
.81537 .48757 Mdot
.423 .53378 Mdot
.56375 .61483 Mdot
.48346 .74193 Mdot
.47584 .30132 Mdot
.61177 .64631 Mdot
.61071 .60704 Mdot
.3337 .45823 Mdot
.48366 .30928 Mdot
.3203 .38659 Mdot
.44907 .54742 Mdot
.32408 .43375 Mdot
.37228 .54782 Mdot
.45861 .73525 Mdot
.39335 .76856 Mdot
.39463 .69379 Mdot
.36199 .56824 Mdot
.65497 .63362 Mdot
.51498 .58314 Mdot
.57754 .63131 Mdot
.34375 .54485 Mdot
.45708 .33519 Mdot
.64301 .38961 Mdot
.82047 .52281 Mdot
.48431 .54201 Mdot
.64081 .61646 Mdot
.3002 .54087 Mdot
.6419 .38018 Mdot
.79846 .38429 Mdot
.63776 .3995 Mdot
.46253 .31345 Mdot
.44439 .25191 Mdot
.33156 .55266 Mdot
.63455 .38689 Mdot
.33155 .43087 Mdot
.4547 .25656 Mdot
.66648 .65 Mdot
.50136 .30752 Mdot
.65425 .35468 Mdot
.62137 .37777 Mdot
.67493 .41639 Mdot
.63084 .65223 Mdot
.47212 .71842 Mdot
.44909 .53999 Mdot
.48453 .32631 Mdot
.26322 .39884 Mdot
.34102 .70945 Mdot
.75761 .44603 Mdot
.39565 .71449 Mdot
.57364 .65538 Mdot
.58434 .5923 Mdot
.60278 .59962 Mdot
.48804 .52459 Mdot
.50786 .58985 Mdot
.55705 .62218 Mdot
.43601 .32824 Mdot
.32849 .40092 Mdot
.55385 .60419 Mdot
.46438 .54651 Mdot
.44774 .55988 Mdot
.32752 .52777 Mdot
.80908 .55019 Mdot
.64222 .44541 Mdot
.64128 .38222 Mdot
.28029 .4017 Mdot
.34825 .41386 Mdot
.31091 .54422 Mdot
.45677 .30029 Mdot
.63771 .40249 Mdot
.23652 .66213 Mdot
.32867 .56409 Mdot
.58332 .59628 Mdot
.41761 .70445 Mdot
.47971 .75438 Mdot
.628 .63697 Mdot
.57759 .6008 Mdot
.50133 .54754 Mdot
.28585 .41161 Mdot
.71859 .67762 Mdot
.79556 .3898 Mdot
.32513 .55053 Mdot
.31355 .55944 Mdot
.6671 .42205 Mdot
.59075 .58535 Mdot
.47366 .32521 Mdot
.4231 .75623 Mdot
.5226 .31281 Mdot
.54725 .21471 Mdot
.23214 .38711 Mdot
.62424 .61617 Mdot
.75887 .59626 Mdot
.55509 .56838 Mdot
.69614 .3673 Mdot
.68349 .37326 Mdot
.65513 .38586 Mdot
.47145 .29976 Mdot
.32226 .65333 Mdot
.43788 .30921 Mdot
.42383 .54155 Mdot
.65562 .4128 Mdot
.50433 .66716 Mdot
.31124 .41558 Mdot
.58735 .64903 Mdot
.35457 .55615 Mdot
.32505 .60966 Mdot
.46697 .53442 Mdot
.45703 .74172 Mdot
.30697 .3828 Mdot
.67618 .39429 Mdot
.58859 .65025 Mdot
.41356 .26842 Mdot
.4013 .73143 Mdot
.23546 .40162 Mdot
.45339 .55391 Mdot
.32621 .55583 Mdot
.70269 .66828 Mdot
.33728 .56802 Mdot
.46401 .32205 Mdot
.55239 .61557 Mdot
.58663 .58472 Mdot
.59985 .60157 Mdot
.5455 .6135 Mdot
.4695 .30242 Mdot
.6121 .58449 Mdot
.4042 .54593 Mdot
.44438 .54833 Mdot
.49189 .59482 Mdot
.3618 .55043 Mdot
.45791 .29098 Mdot
.32987 .40729 Mdot
.49825 .5508 Mdot
.31412 .53224 Mdot
.573 .64719 Mdot
.55827 .61749 Mdot
.42812 .53978 Mdot
.56306 .6507 Mdot
.56973 .56735 Mdot
.30339 .38802 Mdot
.49005 .6114 Mdot
.33113 .52867 Mdot
.34798 .55762 Mdot
.45044 .31176 Mdot
.63473 .38596 Mdot
.31844 .53409 Mdot
.25259 .39004 Mdot
.61068 .64725 Mdot
.57603 .63774 Mdot
.64161 .35922 Mdot
.32143 .6648 Mdot
.32828 .52755 Mdot
.5469 .6276 Mdot
.62288 .38197 Mdot
.6692 .34949 Mdot
.5667 .6169 Mdot
.6248 .59406 Mdot
.61035 .41376 Mdot
.31002 .5565 Mdot
.44862 .30487 Mdot
.37276 .68609 Mdot
.4873 .29575 Mdot
.65901 .40169 Mdot
.48641 .53061 Mdot
.67677 .37894 Mdot
.46799 .52391 Mdot
.61959 .21214 Mdot
.55901 .62442 Mdot
.71952 .35565 Mdot
.41358 .54247 Mdot
.30821 .41699 Mdot
.30815 .42245 Mdot
.46754 .55008 Mdot
.64646 .42249 Mdot
.44806 .53309 Mdot
.35062 .56753 Mdot
.67735 .29674 Mdot
.60873 .41216 Mdot
.28996 .42022 Mdot
.27359 .38419 Mdot
.47623 .3297 Mdot
.58327 .59058 Mdot
.58643 .62816 Mdot
.29002 .38103 Mdot
.5248 .30333 Mdot
.66157 .36568 Mdot
.59817 .61205 Mdot
.47376 .52041 Mdot
.30068 .39026 Mdot
.48668 .36515 Mdot
.68929 .38932 Mdot
.62871 .65359 Mdot
.35788 .74006 Mdot
.49506 .31023 Mdot
.64031 .62414 Mdot
.60568 .58033 Mdot
.32757 .54099 Mdot
.45741 .74765 Mdot
.32588 .66973 Mdot
.50025 .3129 Mdot
.45195 .54571 Mdot
.63071 .6351 Mdot
.31261 .41971 Mdot
.56203 .63806 Mdot
.7766 .69398 Mdot
.43656 .54412 Mdot
.60397 .62764 Mdot
.53336 .55314 Mdot
.63523 .41266 Mdot
.60253 .61117 Mdot
.41718 .26989 Mdot
.28503 .39978 Mdot
.60245 .62941 Mdot
.55637 .51654 Mdot
.47825 .32753 Mdot
.46673 .53505 Mdot
.324 .55667 Mdot
.49584 .65813 Mdot
.45417 .80966 Mdot
.27402 .37352 Mdot
.36462 .5499 Mdot
.57583 .58883 Mdot
.25064 .40614 Mdot
.43319 .3082 Mdot
.45757 .53979 Mdot
.64524 .62854 Mdot
.45351 .28845 Mdot
.47644 .29923 Mdot
.33225 .5558 Mdot
.80645 .33528 Mdot
.54124 .59268 Mdot
.58447 .61968 Mdot
.80574 .36242 Mdot
.64307 .34464 Mdot
.57673 .61434 Mdot
.57473 .58474 Mdot
.45447 .31378 Mdot
.31685 .64634 Mdot
.45733 .74308 Mdot
.45419 .55805 Mdot
.48256 .29672 Mdot
.24077 .37862 Mdot
.28041 .38957 Mdot
.36368 .54645 Mdot
.64792 .39646 Mdot
.30959 .54234 Mdot
.29994 .39672 Mdot
.58806 .59967 Mdot
.44587 .31674 Mdot
.68146 .70128 Mdot
.49284 .31291 Mdot
.25887 .38536 Mdot
.69515 .36522 Mdot
.74644 .659 Mdot
.79175 .68175 Mdot
.51624 .46262 Mdot
.45128 .25108 Mdot
.3249 .54573 Mdot
.79591 .38887 Mdot
.55391 .59968 Mdot
.77774 .60511 Mdot
.57943 .61856 Mdot
.41191 .528 Mdot
.33117 .42204 Mdot
.44486 .54313 Mdot
.46409 .52379 Mdot
.46093 .73829 Mdot
.47103 .29657 Mdot
.45698 .33333 Mdot
.48385 .52733 Mdot
.46529 .31694 Mdot
.59758 .62725 Mdot
.31689 .39335 Mdot
.67529 .24887 Mdot
.55267 .59787 Mdot
.5146 .54706 Mdot
.47996 .28232 Mdot
.6497 .3207 Mdot
.24475 .37624 Mdot
.76482 .57548 Mdot
.5009 .21034 Mdot
.47483 .32228 Mdot
.80599 .55334 Mdot
.28307 .405 Mdot
.49856 .55059 Mdot
.25426 .41295 Mdot
.58522 .62322 Mdot
.6242 .61528 Mdot
.49999 .5334 Mdot
.57061 .58734 Mdot
.73997 .60625 Mdot
.59308 .57315 Mdot
.63017 .5117 Mdot
.56456 .62616 Mdot
.71221 .4072 Mdot
.43062 .31517 Mdot
.48686 .52921 Mdot
.38855 .65217 Mdot
.59388 .63801 Mdot
.6132 .40981 Mdot
.46422 .28827 Mdot
.48026 .20562 Mdot
.47337 .30179 Mdot
.31918 .41464 Mdot
.46167 .29852 Mdot
.61124 .58546 Mdot
.64399 .41051 Mdot
.3031 .40475 Mdot
.47364 .53637 Mdot
.26578 .4062 Mdot
.60037 .63317 Mdot
.42493 .36686 Mdot
.27175 .39621 Mdot
.65283 .61937 Mdot
.64048 .41058 Mdot
.3411 .76145 Mdot
.68693 .40658 Mdot
.58861 .60671 Mdot
.58158 .6096 Mdot
.42135 .53441 Mdot
.45618 .30419 Mdot
.67777 .37622 Mdot
.38466 .36799 Mdot
.32196 .52726 Mdot
.65245 .39193 Mdot
.5679 .5389 Mdot
.41713 .72106 Mdot
.61947 .39748 Mdot
.48277 .74778 Mdot
.46222 .32364 Mdot
.6319 .41544 Mdot
.61649 .556 Mdot
.68601 .58077 Mdot
.34663 .56316 Mdot
.33203 .4316 Mdot
.42693 .7231 Mdot
.27947 .39282 Mdot
.41457 .27193 Mdot
.3342 .43305 Mdot
.48539 .31921 Mdot
.57156 .5342 Mdot
.50698 .69268 Mdot
.47897 .33589 Mdot
.40342 .3601 Mdot
.28915 .39279 Mdot
.46644 .52116 Mdot
.49086 .60249 Mdot
.42747 .52519 Mdot
.44189 .52508 Mdot
.49942 .31571 Mdot
.63203 .41659 Mdot
.6548 .42647 Mdot
.52683 .55242 Mdot
.62531 .3954 Mdot
.31477 .40001 Mdot
.4019 .68775 Mdot
.79341 .5296 Mdot
.43574 .32514 Mdot
.49037 .6189 Mdot
.6382 .63201 Mdot
.33466 .41101 Mdot
.31864 .40208 Mdot
.47186 .29821 Mdot
.69914 .56427 Mdot
.4372 .52916 Mdot
.68421 .34391 Mdot
.64887 .41489 Mdot
.63385 .41281 Mdot
.649 .36278 Mdot
.32008 .65502 Mdot
.48161 .2971 Mdot
.64588 .42165 Mdot
.54662 .61626 Mdot
.5848 .58724 Mdot
.49239 .55238 Mdot
.3096 .5634 Mdot
.59666 .57519 Mdot
.44668 .53293 Mdot
.56972 .61928 Mdot
.30335 .41563 Mdot
.61543 .54297 Mdot
.45929 .55183 Mdot
.28925 .41281 Mdot
.29801 .41644 Mdot
.45199 .54689 Mdot
.61322 .54288 Mdot
.71954 .63986 Mdot
.64875 .65022 Mdot
.70866 .3767 Mdot
.30645 .42482 Mdot
.39574 .38142 Mdot
.72033 .36061 Mdot
.60022 .59192 Mdot
.41908 .54268 Mdot
.32173 .3978 Mdot
.61003 .40163 Mdot
.5921 .62055 Mdot
.49146 .53896 Mdot
.3396 .56467 Mdot
.46798 .53782 Mdot
.5011 .5468 Mdot
.64374 .36984 Mdot
.26035 .31452 Mdot
.61602 .3973 Mdot
.35281 .42628 Mdot
.47419 .53198 Mdot
.75281 .25626 Mdot
.32204 .42533 Mdot
.67322 .29367 Mdot
.50482 .68965 Mdot
.571 .62488 Mdot
.28072 .40012 Mdot
.60643 .427 Mdot
.49714 .32386 Mdot
.48337 .71621 Mdot
.63259 .38769 Mdot
.49837 .55437 Mdot
.4884 .5505 Mdot
.29676 .39031 Mdot
.66584 .39738 Mdot
.6095 .58261 Mdot
.62908 .40524 Mdot
.44232 .31999 Mdot
.6067 .66012 Mdot
.51305 .21161 Mdot
.47552 .52693 Mdot
.62315 .3927 Mdot
.26071 .39537 Mdot
.36889 .54605 Mdot
.55559 .5867 Mdot
.48913 .20373 Mdot
.57713 .58843 Mdot
.46852 .33375 Mdot
.43964 .5603 Mdot
.68138 .62064 Mdot
.56876 .59831 Mdot
.63397 .62228 Mdot
.50867 .31933 Mdot
.56635 .60077 Mdot
.61409 .63911 Mdot
.78497 .40951 Mdot
.61939 .3905 Mdot
.55418 .60256 Mdot
.30234 .38429 Mdot
.58679 .51061 Mdot
.61083 .61644 Mdot
.42635 .25589 Mdot
.44858 .76289 Mdot
.4125 .54644 Mdot
.51982 .54849 Mdot
.37318 .75279 Mdot
.58226 .61339 Mdot
.60069 .59005 Mdot
.60299 .65996 Mdot
.7629 .59914 Mdot
.29382 .39713 Mdot
.27212 .41977 Mdot
.36844 .5481 Mdot
.46585 .74493 Mdot
.3425 .55718 Mdot
.43331 .30757 Mdot
.49201 .64881 Mdot
.45017 .55061 Mdot
.63511 .3837 Mdot
.60297 .60449 Mdot
.26062 .40282 Mdot
.59015 .62649 Mdot
.64577 .64421 Mdot
.31155 .39709 Mdot
.32354 .4027 Mdot
.35587 .4184 Mdot
.32075 .55491 Mdot
.64764 .38382 Mdot
.54735 .59072 Mdot
.32251 .55907 Mdot
.49232 .52749 Mdot
.37098 .69813 Mdot
.65032 .3843 Mdot
.62366 .38979 Mdot
.66307 .41531 Mdot
.57026 .58152 Mdot
.6146 .66124 Mdot
.43963 .30451 Mdot
.64166 .35913 Mdot
.46774 .32698 Mdot
.27948 .39858 Mdot
.32424 .39411 Mdot
.584 .623 Mdot
.56894 .54244 Mdot
.36082 .55423 Mdot
.2717 .39119 Mdot
.4965 .56072 Mdot
.34424 .53419 Mdot
.6173 .61004 Mdot
.27825 .39507 Mdot
.34945 .57384 Mdot
.70122 .57522 Mdot
.54251 .24464 Mdot
.36229 .54222 Mdot
.45552 .52387 Mdot
.75017 .46158 Mdot
.34922 .72547 Mdot
.34324 .52783 Mdot
.43133 .31649 Mdot
.58986 .58142 Mdot
.46241 .55905 Mdot
.32717 .53022 Mdot
.32606 .68323 Mdot
.30604 .399 Mdot
.44505 .5256 Mdot
.51694 .47407 Mdot
.79163 .5318 Mdot
.36686 .544 Mdot
.6224 .39263 Mdot
.66146 .35599 Mdot
.57828 .59648 Mdot
.49401 .65611 Mdot
.44022 .33279 Mdot
.34989 .41789 Mdot
.26579 .41425 Mdot
.68424 .36629 Mdot
.39229 .69533 Mdot
.29401 .38388 Mdot
.59653 .58535 Mdot
.29746 .55295 Mdot
.54731 .62129 Mdot
.41788 .56144 Mdot
.6795 .62495 Mdot
.53287 .54684 Mdot
.36638 .54431 Mdot
.44723 .3352 Mdot
.48675 .31086 Mdot
.46099 .30309 Mdot
.29689 .38616 Mdot
.43303 .72255 Mdot
.26164 .41329 Mdot
.80781 .37282 Mdot
.32414 .53796 Mdot
.18674 .58986 Mdot
.54238 .57025 Mdot
.57657 .62843 Mdot
.59638 .64793 Mdot
.48374 .52487 Mdot
.5839 .6135 Mdot
.45026 .28955 Mdot
.32548 .43216 Mdot
.51861 .3487 Mdot
.66268 .37517 Mdot
.80154 .38626 Mdot
.30933 .41503 Mdot
.50957 .55519 Mdot
.35826 .55405 Mdot
.39427 .77325 Mdot
.35745 .57733 Mdot
.30108 .37899 Mdot
.61768 .63073 Mdot
.66065 .42717 Mdot
.24476 .68134 Mdot
.60273 .60791 Mdot
.27626 .38464 Mdot
.24463 .38747 Mdot
.68562 .56942 Mdot
.60009 .70371 Mdot
.52498 .3252 Mdot
.41444 .69848 Mdot
.37037 .56528 Mdot
.45973 .51758 Mdot
.4296 .75997 Mdot
.2986 .3956 Mdot
.29783 .42899 Mdot
.38416 .55289 Mdot
.64574 .31982 Mdot
.65563 .41694 Mdot
.69268 .40567 Mdot
.44922 .29293 Mdot
.56925 .62553 Mdot
.28456 .39207 Mdot
.69472 .38329 Mdot
.36924 .64583 Mdot
.46636 .30794 Mdot
.27035 .39596 Mdot
.57629 .58739 Mdot
.56919 .59647 Mdot
.34041 .55793 Mdot
.43877 .55715 Mdot
.42791 .52567 Mdot
.6755 .2962 Mdot
.40625 .71775 Mdot
.50361 .68915 Mdot
.56862 .61979 Mdot
.64601 .36493 Mdot
.45505 .54766 Mdot
.35651 .56031 Mdot
.56136 .63701 Mdot
.76721 .63462 Mdot
.61249 .38692 Mdot
.46932 .32536 Mdot
.48147 .53738 Mdot
.46207 .73095 Mdot
.57426 .58756 Mdot
.58009 .61902 Mdot
.63008 .6523 Mdot
.73685 .66743 Mdot
.32468 .42895 Mdot
.63249 .37579 Mdot
.32357 .55482 Mdot
.63249 .4003 Mdot
.353 .44036 Mdot
.48793 .61313 Mdot
.55837 .58035 Mdot
.61244 .39811 Mdot
.64066 .40526 Mdot
.46686 .33385 Mdot
.48825 .30752 Mdot
.26188 .37349 Mdot
.57205 .58409 Mdot
.43983 .54726 Mdot
.64354 .42022 Mdot
.34345 .42685 Mdot
.34029 .55621 Mdot
.42436 .25493 Mdot
.55824 .62056 Mdot
.29417 .39269 Mdot
.459 .53512 Mdot
.65458 .37259 Mdot
.28957 .40975 Mdot
.4992 .55036 Mdot
.31274 .56281 Mdot
.62992 .62451 Mdot
.24741 .41772 Mdot
.49527 .54035 Mdot
.55463 .58909 Mdot
.63233 .545 Mdot
.4939 .65436 Mdot
.49194 .56187 Mdot
.33323 .39835 Mdot
.49127 .54316 Mdot
.66696 .35851 Mdot
.68954 .59413 Mdot
.29947 .43062 Mdot
.70021 .43408 Mdot
.50931 .69699 Mdot
.47336 .5249 Mdot
.63467 .37944 Mdot
.37759 .41021 Mdot
.61604 .3314 Mdot
.34926 .72063 Mdot
.60391 .62213 Mdot
.27976 .39254 Mdot
.34329 .56312 Mdot
.45734 .33307 Mdot
.4154 .29384 Mdot
.37575 .44091 Mdot
.29462 .4198 Mdot
.60424 .60512 Mdot
.63312 .41676 Mdot
.46904 .322 Mdot
.66117 .47137 Mdot
.25178 .40507 Mdot
.30438 .38376 Mdot
.62356 .65002 Mdot
.34362 .55673 Mdot
.51163 .5854 Mdot
.30935 .43365 Mdot
.30946 .43631 Mdot
.78301 .41168 Mdot
.36885 .56592 Mdot
.63353 .65212 Mdot
.5288 .55131 Mdot
.59918 .64516 Mdot
.80082 .37847 Mdot
.49536 .54826 Mdot
.66337 .37454 Mdot
.57504 .60874 Mdot
.22959 .35214 Mdot
.32738 .42129 Mdot
.41414 .69844 Mdot
.51164 .34504 Mdot
.47765 .29779 Mdot
.28867 .40134 Mdot
.59828 .62036 Mdot
.43329 .25212 Mdot
.35996 .54363 Mdot
.62434 .65551 Mdot
.4782 .52533 Mdot
.68038 .35869 Mdot
.44463 .31491 Mdot
.57862 .51657 Mdot
.44804 .329 Mdot
.45151 .30877 Mdot
.59681 .37623 Mdot
.57955 .59629 Mdot
.3037 .41257 Mdot
.2691 .38188 Mdot
.48624 .5219 Mdot
.37067 .37053 Mdot
.66932 .40238 Mdot
.24437 .34597 Mdot
.75918 .64512 Mdot
.55207 .62109 Mdot
.50704 .55004 Mdot
.4207 .5385 Mdot
.44632 .25166 Mdot
.57129 .60045 Mdot
.63962 .37587 Mdot
.31367 .43459 Mdot
.28417 .38799 Mdot
.65263 .6194 Mdot
.48702 .31006 Mdot
.32684 .57419 Mdot
.31652 .40324 Mdot
.37573 .68283 Mdot
.60492 .62758 Mdot
.45853 .27691 Mdot
.31471 .40476 Mdot
.33812 .79296 Mdot
.23891 .32803 Mdot
.62291 .40656 Mdot
.62945 .61687 Mdot
.68731 .39324 Mdot
.36918 .55386 Mdot
.28247 .43247 Mdot
.46596 .33548 Mdot
.47469 .53389 Mdot
.43925 .2117 Mdot
.29081 .388 Mdot
.6403 .39275 Mdot
.58336 .60092 Mdot
.80214 .55984 Mdot
.55413 .59627 Mdot
.31627 .64473 Mdot
.33219 .52793 Mdot
.40978 .30532 Mdot
.47985 .33065 Mdot
.62849 .61388 Mdot
.32431 .56481 Mdot
.27484 .3772 Mdot
.31006 .39656 Mdot
.47227 .19658 Mdot
.50005 .5479 Mdot
.28391 .43488 Mdot
.55794 .58686 Mdot
.35019 .42421 Mdot
.75804 .44508 Mdot
.48057 .3009 Mdot
.60446 .64464 Mdot
.27168 .40213 Mdot
.62374 .32824 Mdot
.41554 .70751 Mdot
.60529 .62439 Mdot
.54527 .54701 Mdot
.48467 .31847 Mdot
.79982 .39067 Mdot
.33415 .41865 Mdot
.5579 .64068 Mdot
.4447 .28991 Mdot
.57122 .53468 Mdot
.52422 .34767 Mdot
.64806 .38355 Mdot
.27042 .38484 Mdot
.44781 .30521 Mdot
.4615 .52805 Mdot
.34674 .57341 Mdot
.25175 .38912 Mdot
.27065 .40712 Mdot
.65322 .63599 Mdot
.51473 .55602 Mdot
.56672 .54159 Mdot
.66967 .37107 Mdot
.45636 .31879 Mdot
.64381 .64671 Mdot
.36827 .69939 Mdot
.58172 .65351 Mdot
.45317 .31845 Mdot
.76853 .28541 Mdot
.62134 .62923 Mdot
.5616 .62281 Mdot
.79724 .57335 Mdot
.67802 .39251 Mdot
.63707 .36562 Mdot
.39684 .72148 Mdot
.639 .61081 Mdot
.50682 .67083 Mdot
.64441 .38531 Mdot
.64 .39615 Mdot
.506 .66966 Mdot
.65159 .63696 Mdot
.68545 .41365 Mdot
.46823 .32035 Mdot
.47992 .2988 Mdot
.63412 .4122 Mdot
.58416 .64648 Mdot
.4252 .30639 Mdot
.70198 .55328 Mdot
.28292 .37861 Mdot
.43872 .75758 Mdot
.63585 .40684 Mdot
.41962 .7067 Mdot
.46314 .32181 Mdot
.43363 .79002 Mdot
.45443 .76593 Mdot
.54059 .59624 Mdot
.57393 .59706 Mdot
.32804 .54395 Mdot
.46765 .53613 Mdot
.45298 .54789 Mdot
.4604 .30282 Mdot
.5077 .59028 Mdot
.65595 .38693 Mdot
.62356 .59623 Mdot
.33909 .7059 Mdot
.46978 .80929 Mdot
.66335 .70359 Mdot
.64629 .39697 Mdot
.65679 .39924 Mdot
.32005 .38769 Mdot
.33422 .39311 Mdot
.54942 .58563 Mdot
.48685 .31507 Mdot
.62901 .41226 Mdot
.45141 .32113 Mdot
.30045 .39599 Mdot
.31153 .4138 Mdot
.47208 .554 Mdot
.44311 .5266 Mdot
.29618 .40186 Mdot
.42777 .25521 Mdot
.3688 .69939 Mdot
.6677 .35287 Mdot
.81022 .36819 Mdot
.42062 .79014 Mdot
.81621 .53311 Mdot
.34147 .56424 Mdot
.61641 .54517 Mdot
.44572 .29028 Mdot
.62956 .61467 Mdot
.57214 .61583 Mdot
.48023 .54524 Mdot
.44922 .28623 Mdot
.34605 .54032 Mdot
.47867 .299 Mdot
.34115 .57291 Mdot
.27526 .41987 Mdot
.60671 .60938 Mdot
.60778 .63409 Mdot
.46144 .33338 Mdot
.31398 .38336 Mdot
.27383 .39991 Mdot
.34883 .56482 Mdot
.40016 .77439 Mdot
.29733 .39126 Mdot
.63654 .40617 Mdot
.70824 .43879 Mdot
.48808 .54948 Mdot
.59276 .61988 Mdot
.37509 .75538 Mdot
.68915 .59963 Mdot
.49751 .53082 Mdot
.48215 .53813 Mdot
.80453 .33216 Mdot
.60974 .62778 Mdot
.45018 .18709 Mdot
.46268 .55307 Mdot
.677 .37998 Mdot
.29679 .40947 Mdot
.50553 .55001 Mdot
.54815 .53687 Mdot
.29121 .56563 Mdot
.50814 .54292 Mdot
.654 .41834 Mdot
.67066 .40753 Mdot
.48931 .61311 Mdot
.80782 .3819 Mdot
.325 .5566 Mdot
.3492 .53885 Mdot
.31706 .43021 Mdot
.41268 .27431 Mdot
.53688 .57991 Mdot
.33701 .53526 Mdot
.64326 .44153 Mdot
.63293 .64878 Mdot
.49376 .64821 Mdot
.49097 .59805 Mdot
.65522 .35896 Mdot
.6539 .65519 Mdot
.32258 .42747 Mdot
.64211 .39188 Mdot
.49062 .60722 Mdot
.617 .64751 Mdot
.65256 .38472 Mdot
.45394 .30941 Mdot
.56825 .7162 Mdot
.62739 .40308 Mdot
.4835 .71379 Mdot
.47611 .32407 Mdot
.49299 .63822 Mdot
.22145 .60722 Mdot
.37419 .82417 Mdot
.48043 .30279 Mdot
.27271 .39299 Mdot
.28551 .39294 Mdot
.30636 .39035 Mdot
.65899 .36364 Mdot
.32719 .40976 Mdot
.66881 .3888 Mdot
.45306 .2519 Mdot
.46355 .74144 Mdot
.33391 .55196 Mdot
.37225 .38857 Mdot
.63281 .41059 Mdot
.80483 .37431 Mdot
.87181 .58635 Mdot
.55986 .64469 Mdot
.48081 .33536 Mdot
.32439 .5337 Mdot
.41279 .69207 Mdot
.32813 .54116 Mdot
.2825 .4045 Mdot
.46111 .73482 Mdot
.59531 .6282 Mdot
.52711 .23762 Mdot
.3444 .56199 Mdot
.63892 .39716 Mdot
.65615 .6309 Mdot
.31832 .38114 Mdot
.36646 .55043 Mdot
.35021 .55754 Mdot
.58545 .61472 Mdot
.67646 .39327 Mdot
.2787 .40377 Mdot
.463 .2845 Mdot
.34394 .47475 Mdot
.58606 .55657 Mdot
.61281 .62245 Mdot
.57173 .63388 Mdot
.41464 .71629 Mdot
.42196 .25636 Mdot
.47748 .31894 Mdot
.32849 .6805 Mdot
.33492 .40776 Mdot
.34419 .71897 Mdot
.62563 .32076 Mdot
.3705 .39877 Mdot
.49471 .54792 Mdot
.49707 .55147 Mdot
.59846 .60997 Mdot
.82535 .64381 Mdot
.58518 .70585 Mdot
.42731 .30546 Mdot
.47867 .54786 Mdot
.30996 .37987 Mdot
.62188 .37375 Mdot
.49035 .47053 Mdot
.55774 .56693 Mdot
.46281 .28419 Mdot
.30516 .39353 Mdot
.7721 .70746 Mdot
.32132 .54731 Mdot
.40874 .69386 Mdot
.56976 .58546 Mdot
.59502 .61212 Mdot
.47146 .30679 Mdot
.4526 .33534 Mdot
.7846 .41426 Mdot
.40156 .5392 Mdot
.51778 .21031 Mdot
.49837 .33419 Mdot
.77053 .71362 Mdot
.42507 .54105 Mdot
.66255 .39273 Mdot
.44936 .54502 Mdot
.45784 .33797 Mdot
.57552 .61227 Mdot
.67753 .39151 Mdot
.45595 .54012 Mdot
.63051 .43428 Mdot
.49595 .65987 Mdot
.37313 .68673 Mdot
.5827 .59191 Mdot
.68001 .40591 Mdot
.64601 .38865 Mdot
.68939 .35121 Mdot
.47661 .55204 Mdot
.56343 .61537 Mdot
.55588 .63907 Mdot
.56783 .62979 Mdot
.77754 .42554 Mdot
.60403 .61259 Mdot
.63159 .31735 Mdot
.38976 .71335 Mdot
.20892 .3652 Mdot
.60311 .63451 Mdot
.45404 .30204 Mdot
.59649 .60271 Mdot
.32264 .56495 Mdot
.62925 .63216 Mdot
.49838 .67007 Mdot
.47118 .31781 Mdot
.77863 .61546 Mdot
.30118 .56566 Mdot
.6147 .62164 Mdot
.36048 .56926 Mdot
.65285 .27905 Mdot
.33098 .68184 Mdot
.78023 .40893 Mdot
.62975 .40567 Mdot
.25905 .41617 Mdot
.44138 .33375 Mdot
.31805 .41515 Mdot
.64094 .60826 Mdot
.44574 .54742 Mdot
.17491 .58249 Mdot
.37273 .72005 Mdot
.57547 .61031 Mdot
.43264 .52663 Mdot
.62617 .38404 Mdot
.32543 .42374 Mdot
.81722 .48921 Mdot
.60521 .64924 Mdot
.30901 .5536 Mdot
.31531 .54611 Mdot
.34724 .59931 Mdot
.66846 .3277 Mdot
.76543 .43119 Mdot
.47229 .30835 Mdot
.2931 .38581 Mdot
.33349 .53016 Mdot
.67078 .43593 Mdot
.47151 .33675 Mdot
.44482 .25294 Mdot
.44433 .31131 Mdot
.58769 .63422 Mdot
.4844 .55571 Mdot
.69192 .32333 Mdot
.49654 .54471 Mdot
.58076 .64183 Mdot
.27152 .40751 Mdot
.49731 .54816 Mdot
.33387 .54681 Mdot
.44944 .30609 Mdot
.30656 .41566 Mdot
.58404 .60739 Mdot
.64313 .3818 Mdot
.43853 .58378 Mdot
.26786 .43033 Mdot
.49334 .65372 Mdot
.49329 .65356 Mdot
.65385 .34937 Mdot
.47654 .56208 Mdot
.41942 .36752 Mdot
.68883 .57924 Mdot
.36493 .44203 Mdot
.55151 .55251 Mdot
.34574 .35786 Mdot
.26067 .41308 Mdot
.3056 .40405 Mdot
.59075 .63071 Mdot
.34709 .42485 Mdot
.58394 .58051 Mdot
.33493 .39969 Mdot
.68697 .3026 Mdot
.59317 .57468 Mdot
.31244 .40037 Mdot
.44732 .53894 Mdot
.55432 .58798 Mdot
.63122 .37878 Mdot
.27102 .4232 Mdot
.54062 .59671 Mdot
.1812 .41397 Mdot
.46578 .33392 Mdot
.48048 .55232 Mdot
.42449 .67014 Mdot
.46018 .31539 Mdot
.6623 .40871 Mdot
.60087 .58489 Mdot
.33336 .53368 Mdot
.65999 .40003 Mdot
.33687 .59241 Mdot
.34616 .5564 Mdot
.39875 .68738 Mdot
.65011 .41108 Mdot
.4905 .54828 Mdot
.3113 .55673 Mdot
.48201 .52012 Mdot
.30684 .40196 Mdot
.23735 .40045 Mdot
.49247 .53711 Mdot
.59126 .62796 Mdot
.31219 .37938 Mdot
.46724 .29656 Mdot
.6112 .60642 Mdot
.28379 .39107 Mdot
.46191 .54537 Mdot
.54901 .60323 Mdot
.63609 .60695 Mdot
.79432 .39301 Mdot
.41761 .5464 Mdot
.33383 .54979 Mdot
.69442 .36429 Mdot
.5551 .62638 Mdot
.32932 .56689 Mdot
.24798 .41285 Mdot
.56795 .65028 Mdot
.63114 .41875 Mdot
.69419 .55385 Mdot
.34808 .41434 Mdot
.48911 .3172 Mdot
.2593 .38709 Mdot
.3719 .55564 Mdot
.89052 .5601 Mdot
.45577 .54903 Mdot
.64816 .65345 Mdot
.60607 .6415 Mdot
.26606 .4229 Mdot
.64898 .38831 Mdot
.53327 .2118 Mdot
.63039 .62454 Mdot
.56783 .65191 Mdot
.58959 .61752 Mdot
.31094 .46204 Mdot
.66898 .36682 Mdot
.59087 .61914 Mdot
.53603 .55785 Mdot
.5857 .64051 Mdot
.36279 .56184 Mdot
.19626 .60112 Mdot
.50415 .54099 Mdot
.74548 .24249 Mdot
.4555 .54304 Mdot
.31435 .39579 Mdot
.48356 .71282 Mdot
.42082 .66655 Mdot
.22059 .43634 Mdot
.66595 .40537 Mdot
.7085 .37995 Mdot
.3117 .41287 Mdot
.37436 .4186 Mdot
.50973 .57866 Mdot
.65515 .63041 Mdot
.57901 .58377 Mdot
.28269 .40462 Mdot
.3411 .42605 Mdot
.44133 .54335 Mdot
.44904 .52056 Mdot
.62365 .66368 Mdot
.26199 .39824 Mdot
.60571 .6121 Mdot
.68601 .6026 Mdot
.48055 .33684 Mdot
.62101 .40211 Mdot
.45117 .33177 Mdot
.49225 .33016 Mdot
.82013 .52201 Mdot
.40752 .71985 Mdot
.44879 .29265 Mdot
.43548 .29873 Mdot
.38015 .41245 Mdot
.79584 .53669 Mdot
.36039 .56498 Mdot
.58144 .70491 Mdot
.32392 .39531 Mdot
.56229 .61381 Mdot
.66818 .36536 Mdot
.39662 .55632 Mdot
.55974 .20968 Mdot
.59788 .78104 Mdot
.63805 .64748 Mdot
.33197 .40801 Mdot
.49422 .53767 Mdot
.48774 .52942 Mdot
.34787 .7235 Mdot
.60256 .61551 Mdot
.34977 .41656 Mdot
.79332 .53053 Mdot
.51532 .29646 Mdot
.43447 .25257 Mdot
.68102 .33971 Mdot
.59779 .60265 Mdot
.6623 .36709 Mdot
.48775 .29752 Mdot
.33055 .56509 Mdot
.32493 .54764 Mdot
.61524 .62163 Mdot
.50518 .68963 Mdot
.36155 .44644 Mdot
.64509 .61617 Mdot
.65028 .63685 Mdot
.48959 .54269 Mdot
.64883 .64699 Mdot
.55729 .63908 Mdot
.64393 .63818 Mdot
.48729 .52492 Mdot
.47132 .33639 Mdot
.81035 .51053 Mdot
.47683 .52587 Mdot
.58694 .57616 Mdot
.49126 .30207 Mdot
.62599 .59484 Mdot
.47183 .30114 Mdot
.41619 .26051 Mdot
.44248 .30031 Mdot
.32684 .55068 Mdot
.34691 .4058 Mdot
.79602 .39881 Mdot
.63123 .41347 Mdot
.48272 .29889 Mdot
.31456 .56671 Mdot
.46609 .29907 Mdot
.31824 .38978 Mdot
.49952 .27106 Mdot
.63273 .34783 Mdot
.37917 .6805 Mdot
.80628 .54471 Mdot
.51307 .3141 Mdot
.34635 .41435 Mdot
.63465 .41359 Mdot
.41674 .27004 Mdot
.62653 .61055 Mdot
.32094 .54919 Mdot
.59708 .60964 Mdot
.45026 .30717 Mdot
.32849 .39957 Mdot
.78566 .39992 Mdot
.33268 .54896 Mdot
.81105 .36031 Mdot
.25967 .40115 Mdot
.61825 .63588 Mdot
.49423 .30507 Mdot
.41275 .29399 Mdot
.4746 .33161 Mdot
.45807 .75002 Mdot
.44779 .55302 Mdot
.366 .52372 Mdot
.65447 .40472 Mdot
.43061 .54325 Mdot
.46793 .8459 Mdot
.60208 .3 Mdot
.64834 .37463 Mdot
.28845 .43759 Mdot
.60671 .62758 Mdot
.63688 .65173 Mdot
.44546 .52903 Mdot
.66331 .42163 Mdot
.62997 .65224 Mdot
.48438 .55376 Mdot
.39427 .72612 Mdot
.67968 .33757 Mdot
.24881 .39132 Mdot
.56595 .58422 Mdot
.49932 .31462 Mdot
.49313 .31111 Mdot
.47264 .55603 Mdot
.44256 .32358 Mdot
.58965 .57796 Mdot
.6428 .41203 Mdot
.49045 .60307 Mdot
.36886 .55108 Mdot
.646 .30037 Mdot
.36479 .58209 Mdot
.30936 .56832 Mdot
.5461 .61282 Mdot
.30816 .41338 Mdot
.43285 .21018 Mdot
.63668 .62599 Mdot
.64274 .38796 Mdot
.61279 .64016 Mdot
.64026 .65036 Mdot
.65365 .6244 Mdot
.29331 .38599 Mdot
.41697 .70847 Mdot
.60538 .61136 Mdot
.47386 .28808 Mdot
.50638 .67408 Mdot
.56507 .56884 Mdot
.40828 .53055 Mdot
.49757 .66621 Mdot
.44017 .28333 Mdot
.67183 .3544 Mdot
.30256 .41164 Mdot
.65789 .39007 Mdot
.61092 .42385 Mdot
.6628 .40788 Mdot
.65948 .32646 Mdot
.68965 .58547 Mdot
.44882 .18427 Mdot
.75996 .44152 Mdot
.80898 .54579 Mdot
.60798 .41689 Mdot
.33559 .23144 Mdot
.64544 .37362 Mdot
.66342 .40773 Mdot
.65036 .2293 Mdot
.67381 .39391 Mdot
.58365 .62342 Mdot
.59571 .63835 Mdot
.7444 .65947 Mdot
.34966 .47584 Mdot
.55099 .60147 Mdot
.48901 .52531 Mdot
.32059 .53546 Mdot
.64719 .31941 Mdot
.47771 .5358 Mdot
.41151 .68991 Mdot
.50273 .55408 Mdot
.58526 .61409 Mdot
.59891 .59693 Mdot
.58627 .57069 Mdot
.4946 .81619 Mdot
.36514 .48033 Mdot
.66687 .41291 Mdot
.53281 .57315 Mdot
.51414 .35515 Mdot
.59504 .59032 Mdot
.62179 .6405 Mdot
.66404 .64862 Mdot
.30382 .41262 Mdot
.61706 .3778 Mdot
.43433 .53008 Mdot
.63493 .29742 Mdot
.5726 .589 Mdot
.3825 .57267 Mdot
.30582 .54157 Mdot
.59748 .62128 Mdot
.67018 .40379 Mdot
.63636 .65127 Mdot
.62736 .37202 Mdot
.65467 .40834 Mdot
.56922 .65192 Mdot
.6592 .32263 Mdot
.6194 .3769 Mdot
.65481 .63012 Mdot
.32441 .38893 Mdot
.67516 .29519 Mdot
.59351 .62705 Mdot
.33904 .54801 Mdot
.57476 .59976 Mdot
.3636 .56305 Mdot
.50807 .54669 Mdot
.49362 .54306 Mdot
.68861 .67641 Mdot
.2933 .42791 Mdot
.353 .57972 Mdot
.34889 .42605 Mdot
.53669 .57648 Mdot
.63219 .4398 Mdot
.51126 .28744 Mdot
.36701 .41734 Mdot
.49023 .54364 Mdot
.32383 .65593 Mdot
.50897 .65739 Mdot
.43805 .30689 Mdot
.6346 .37289 Mdot
.8008 .50782 Mdot
.41932 .54185 Mdot
.25008 .38926 Mdot
.27919 .37973 Mdot
.5201 .36081 Mdot
.67491 .24858 Mdot
.60263 .63413 Mdot
.41827 .53867 Mdot
.62736 .51546 Mdot
.46582 .53646 Mdot
.43733 .53882 Mdot
.26924 .4062 Mdot
.55111 .59906 Mdot
.39922 .73625 Mdot
.28922 .39392 Mdot
.35754 .54743 Mdot
.66379 .37384 Mdot
.33509 .57082 Mdot
.56219 .24455 Mdot
.7866 .41181 Mdot
.2942 .39942 Mdot
.4916 .52825 Mdot
.55846 .61571 Mdot
.67825 .38285 Mdot
.65967 .47182 Mdot
.61968 .38913 Mdot
.35067 .53673 Mdot
.29522 .4302 Mdot
.15887 .46826 Mdot
.58433 .59993 Mdot
.64138 .40374 Mdot
.29584 .55621 Mdot
.56723 .59715 Mdot
.48774 .3104 Mdot
.63001 .65177 Mdot
.63566 .40152 Mdot
.64525 .65458 Mdot
.65486 .40512 Mdot
.29849 .3822 Mdot
.61348 .62723 Mdot
.61427 .60738 Mdot
.32727 .67504 Mdot
.34486 .5402 Mdot
.61884 .38059 Mdot
.42179 .72635 Mdot
.59908 .64516 Mdot
.35766 .73744 Mdot
.60874 .61254 Mdot
.80345 .54838 Mdot
.53512 .55037 Mdot
.4889 .55401 Mdot
.61074 .641 Mdot
.59603 .62644 Mdot
.65455 .47376 Mdot
.75609 .44964 Mdot
.7784 .42472 Mdot
.49105 .31446 Mdot
.6375 .37358 Mdot
.28577 .39633 Mdot
.27696 .42689 Mdot
.32441 .41178 Mdot
.3694 .54327 Mdot
.52125 .57356 Mdot
.57879 .62656 Mdot
.42584 .30062 Mdot
.32788 .53636 Mdot
.64811 .40039 Mdot
.33289 .5557 Mdot
.40898 .71248 Mdot
.33921 .54573 Mdot
.44843 .54651 Mdot
.26929 .305 Mdot
.68648 .59879 Mdot
.35372 .5517 Mdot
.62403 .40682 Mdot
.51262 .68607 Mdot
.55888 .64825 Mdot
.80132 .38345 Mdot
.30988 .5484 Mdot
.28509 .43706 Mdot
.54789 .59905 Mdot
.47199 .71415 Mdot
.46805 .30241 Mdot
.33367 .57105 Mdot
.44371 .31246 Mdot
.63927 .64772 Mdot
.71218 .38798 Mdot
.63589 .39038 Mdot
.48164 .33721 Mdot
.61527 .6428 Mdot
.33272 .57073 Mdot
.29924 .40079 Mdot
.79491 .53665 Mdot
.43841 .25467 Mdot
.41154 .55272 Mdot
.34716 .71948 Mdot
.32324 .42813 Mdot
.78708 .55774 Mdot
.44147 .30758 Mdot
.53329 .57171 Mdot
.66763 .64224 Mdot
.55857 .6326 Mdot
.27535 .40182 Mdot
.30569 .4047 Mdot
.37879 .35986 Mdot
.61546 .6075 Mdot
.64306 .65893 Mdot
.67688 .35289 Mdot
.30654 .43316 Mdot
.66222 .40799 Mdot
.68186 .4051 Mdot
.27327 .3932 Mdot
.62287 .37931 Mdot
.34741 .55742 Mdot
.42542 .74573 Mdot
.44193 .30545 Mdot
.48384 .32664 Mdot
.29454 .40111 Mdot
.29538 .4242 Mdot
.30883 .41384 Mdot
.61252 .65142 Mdot
.65583 .40954 Mdot
.61606 .60156 Mdot
.59312 .60168 Mdot
.56641 .65363 Mdot
.69018 .38662 Mdot
.62914 .61816 Mdot
.49591 .59872 Mdot
.31487 .53364 Mdot
.31643 .39964 Mdot
.45618 .32353 Mdot
.43665 .58831 Mdot
.46933 .28562 Mdot
.58617 .64141 Mdot
.6876 .30581 Mdot
.64155 .37084 Mdot
.32802 .54218 Mdot
.49726 .66852 Mdot
.32997 .54702 Mdot
.48184 .33661 Mdot
.67556 .34907 Mdot
.39489 .69118 Mdot
.6207 .6139 Mdot
.4139 .71979 Mdot
.25907 .6329 Mdot
.60665 .33487 Mdot
.45611 .31668 Mdot
.61549 .6574 Mdot
.49005 .55689 Mdot
.69082 .57933 Mdot
.58514 .62894 Mdot
.55403 .56914 Mdot
.46579 .67942 Mdot
.58917 .6404 Mdot
.63683 .42464 Mdot
.49663 .64018 Mdot
.46222 .51841 Mdot
.54546 .61937 Mdot
.47295 .20002 Mdot
.55071 .60698 Mdot
.61896 .61473 Mdot
.56972 .61697 Mdot
.63827 .6358 Mdot
.68757 .39102 Mdot
.4891 .62211 Mdot
.48454 .29575 Mdot
.42493 .74611 Mdot
.44523 .30145 Mdot
.2895 .40392 Mdot
.40743 .54642 Mdot
.65323 .35698 Mdot
.33014 .54655 Mdot
.41388 .46303 Mdot
.47103 .72935 Mdot
.31947 .38721 Mdot
.31772 .65487 Mdot
.32921 .57449 Mdot
.43931 .53623 Mdot
.37226 .55787 Mdot
.27146 .40353 Mdot
.48551 .30764 Mdot
.61826 .63073 Mdot
.64789 .41865 Mdot
.62621 .40194 Mdot
.54505 .61463 Mdot
.66166 .28699 Mdot
.48927 .32005 Mdot
.37212 .37309 Mdot
.59023 .63337 Mdot
.60455 .64469 Mdot
.63269 .36856 Mdot
.32852 .41734 Mdot
.50764 .65618 Mdot
.35779 .56274 Mdot
.59028 .58835 Mdot
.46946 .51998 Mdot
.40971 .71382 Mdot
.49164 .31167 Mdot
.46981 .54887 Mdot
.55561 .60998 Mdot
.40227 .70974 Mdot
.61794 .65527 Mdot
.55371 .55423 Mdot
.33503 .39513 Mdot
.56609 .6508 Mdot
.60974 .60155 Mdot
.681 .3393 Mdot
.4407 .311 Mdot
.64853 .3854 Mdot
.64673 .34621 Mdot
.49271 .54332 Mdot
.46883 .33264 Mdot
.63569 .64016 Mdot
.42309 .31809 Mdot
.63963 .64958 Mdot
.58923 .60492 Mdot
.45515 .31377 Mdot
.66648 .39928 Mdot
.52191 .21353 Mdot
.80988 .50928 Mdot
.64548 .64422 Mdot
.57122 .59964 Mdot
.34949 .47598 Mdot
.39502 .55811 Mdot
.62455 .6165 Mdot
.62869 .41094 Mdot
.56997 .59599 Mdot
.42722 .31835 Mdot
.32755 .55887 Mdot
.64018 .38513 Mdot
.33266 .41695 Mdot
.29408 .38243 Mdot
.31938 .37769 Mdot
.44689 .54616 Mdot
.6504 .64605 Mdot
.69426 .36417 Mdot
.68946 .39461 Mdot
.43957 .71474 Mdot
.3145 .39645 Mdot
.33681 .56343 Mdot
.564 .58297 Mdot
.42571 .53035 Mdot
.49578 .3127 Mdot
.7405 .23531 Mdot
.39486 .69405 Mdot
.31585 .53092 Mdot
.43352 .56101 Mdot
.48347 .54255 Mdot
.56198 .62172 Mdot
.32781 .56768 Mdot
.2756 .3925 Mdot
.63479 .65314 Mdot
.52822 .55917 Mdot
.29278 .44007 Mdot
.3061 .42162 Mdot
.42149 .31581 Mdot
.3381 .40775 Mdot
.34877 .57376 Mdot
.45458 .54839 Mdot
.62921 .38867 Mdot
.60113 .61907 Mdot
.47285 .5266 Mdot
.31633 .3929 Mdot
.42644 .53929 Mdot
.6002 .63707 Mdot
.64604 .36633 Mdot
.32499 .40374 Mdot
.58205 .61625 Mdot
.68363 .56537 Mdot
.79233 .39637 Mdot
.33033 .40029 Mdot
.59832 .58515 Mdot
.52027 .47559 Mdot
.30493 .41954 Mdot
.27371 .40528 Mdot
.56514 .64731 Mdot
.32279 .56825 Mdot
.58586 .59187 Mdot
.48593 .31378 Mdot
.41849 .71547 Mdot
.4627 .33354 Mdot
.34707 .7243 Mdot
.55067 .63663 Mdot
.67086 .64608 Mdot
.63044 .43583 Mdot
.34979 .58231 Mdot
.41615 .7873 Mdot
.55471 .62468 Mdot
.6139 .44641 Mdot
.41957 .70844 Mdot
.39083 .67614 Mdot
.60935 .45906 Mdot
.35004 .57033 Mdot
.46135 .3025 Mdot
.61499 .61587 Mdot
.4953 .21587 Mdot
.35202 .56748 Mdot
.3488 .72581 Mdot
.62137 .59842 Mdot
.6435 .39588 Mdot
.59684 .63323 Mdot
.63029 .39195 Mdot
.56192 .60441 Mdot
.79234 .39139 Mdot
.36208 .44593 Mdot
.4587 .74942 Mdot
.44604 .53621 Mdot
.41279 .29398 Mdot
.80669 .54478 Mdot
.34287 .55918 Mdot
.64213 .65567 Mdot
.47533 .54318 Mdot
.47816 .2987 Mdot
.52775 .30435 Mdot
.31294 .41335 Mdot
.47032 .28717 Mdot
.66396 .38747 Mdot
.30309 .37668 Mdot
.43155 .543 Mdot
.67567 .64126 Mdot
.3289 .5697 Mdot
.47004 .33244 Mdot
.59861 .62382 Mdot
.56662 .63727 Mdot
.3093 .4606 Mdot
.20115 .60966 Mdot
.68149 .40956 Mdot
.81188 .3502 Mdot
.67589 .34977 Mdot
.34758 .53927 Mdot
.32145 .38586 Mdot
.57356 .6118 Mdot
.56229 .58863 Mdot
.30741 .42262 Mdot
.67765 .37659 Mdot
.33884 .57966 Mdot
.36254 .52238 Mdot
.42668 .30588 Mdot
.2292 .63434 Mdot
.63782 .38461 Mdot
.22802 .63243 Mdot
.30518 .35477 Mdot
.72754 .3315 Mdot
.40585 .77921 Mdot
.46408 .31799 Mdot
.2286 .6341 Mdot
.64241 .39926 Mdot
.57761 .63341 Mdot
.48825 .54722 Mdot
.44617 .54854 Mdot
.65837 .36787 Mdot
.28636 .40708 Mdot
.33516 .57476 Mdot
.59811 .63185 Mdot
.61251 .54542 Mdot
.66153 .47117 Mdot
.27779 .42174 Mdot
.46662 .53225 Mdot
.46431 .32566 Mdot
.56826 .59824 Mdot
.32752 .53153 Mdot
.4653 .31735 Mdot
.50033 .55039 Mdot
.45918 .73511 Mdot
.60036 .58476 Mdot
.50025 .67991 Mdot
.47104 .30354 Mdot
.40194 .57212 Mdot
.61077 .60439 Mdot
.44148 .30776 Mdot
.51191 .55325 Mdot
.43176 .37611 Mdot
.50771 .62362 Mdot
.60144 .30041 Mdot
.25975 .38014 Mdot
.3337 .39863 Mdot
.18235 .42835 Mdot
.23185 .451 Mdot
.45481 .29235 Mdot
.48314 .53386 Mdot
.19152 .59739 Mdot
.44166 .31778 Mdot
.63344 .63312 Mdot
.61122 .62243 Mdot
.79322 .52987 Mdot
.50464 .54602 Mdot
.45465 .54379 Mdot
.72092 .36997 Mdot
.62551 .59599 Mdot
.46966 .53212 Mdot
.61025 .60691 Mdot
.67058 .40873 Mdot
.46718 .3236 Mdot
.63163 .81316 Mdot
.46274 .33986 Mdot
.66406 .62822 Mdot
.3249 .39603 Mdot
.26718 .37733 Mdot
.59745 .61991 Mdot
.50845 .46413 Mdot
.77435 .71004 Mdot
.61228 .62095 Mdot
.49753 .66927 Mdot
.34335 .71712 Mdot
.54769 .63051 Mdot
.61562 .40494 Mdot
.50108 .53904 Mdot
.69253 .38073 Mdot
.46145 .31334 Mdot
.35005 .5701 Mdot
.34192 .58352 Mdot
.46257 .30284 Mdot
.55879 .59333 Mdot
.36339 .5812 Mdot
.59314 .61347 Mdot
.57162 .62692 Mdot
.40491 .70581 Mdot
.33629 .53122 Mdot
.29912 .41311 Mdot
.32646 .54865 Mdot
.66821 .40306 Mdot
.7803 .29968 Mdot
.33825 .55835 Mdot
.79567 .53625 Mdot
.42177 .72266 Mdot
.1962 .59847 Mdot
.62518 .39661 Mdot
.36964 .55262 Mdot
.45892 .30161 Mdot
.42413 .67944 Mdot
.78015 .58043 Mdot
.46673 .28528 Mdot
.5684 .6213 Mdot
.68684 .39626 Mdot
.66352 .34895 Mdot
.48863 .29507 Mdot
.62887 .38356 Mdot
.52594 .58836 Mdot
.65 .62721 Mdot
.4836 .29444 Mdot
.45799 .8098 Mdot
.48035 .33067 Mdot
.82077 .50952 Mdot
.65011 .64392 Mdot
.64164 .38678 Mdot
.80648 .5536 Mdot
.66891 .34272 Mdot
.46733 .55282 Mdot
.62701 .62903 Mdot
.33771 .56115 Mdot
.43292 .72269 Mdot
.33361 .40993 Mdot
.62457 .32745 Mdot
.63283 .40674 Mdot
.49401 .2985 Mdot
.6292 .38397 Mdot
.63309 .37296 Mdot
.48577 .33573 Mdot
.64026 .37264 Mdot
.5709 .58899 Mdot
.80267 .3936 Mdot
.62374 .38584 Mdot
.47095 .31074 Mdot
.35128 .53752 Mdot
.62328 .40695 Mdot
.38484 .38145 Mdot
.56069 .58531 Mdot
.25189 .40365 Mdot
.36098 .53127 Mdot
.6829 .39833 Mdot
.3425 .56076 Mdot
.31952 .39576 Mdot
.30844 .55923 Mdot
.41916 .33823 Mdot
.41662 .3211 Mdot
.54965 .53507 Mdot
.41865 .3739 Mdot
.67308 .39536 Mdot
.30276 .376 Mdot
.58548 .58405 Mdot
.58365 .63244 Mdot
.34033 .52906 Mdot
.61132 .39014 Mdot
.65942 .28317 Mdot
.47627 .5346 Mdot
.64504 .30043 Mdot
.49148 .31503 Mdot
.37273 .38042 Mdot
.39269 .69119 Mdot
.46801 .25523 Mdot
.45938 .51822 Mdot
.48245 .54331 Mdot
.5894 .61813 Mdot
.33086 .68332 Mdot
.35004 .57297 Mdot
.32031 .24733 Mdot
.59104 .64836 Mdot
.30814 .42464 Mdot
.56427 .60865 Mdot
.50479 .58243 Mdot
.55486 .6311 Mdot
.3212 .52911 Mdot
.44619 .28811 Mdot
.63057 .41311 Mdot
.36833 .55729 Mdot
.29155 .38195 Mdot
.4829 .74659 Mdot
.62347 .61237 Mdot
.57295 .57864 Mdot
.29374 .41503 Mdot
.65742 .41389 Mdot
.29723 .40549 Mdot
.44223 .30519 Mdot
.33708 .55598 Mdot
.6236 .65253 Mdot
.50471 .54508 Mdot
.26806 .42424 Mdot
.48017 .29625 Mdot
.31771 .38183 Mdot
.43631 .33204 Mdot
.48738 .54429 Mdot
.53547 .59497 Mdot
.35187 .41658 Mdot
.45981 .52074 Mdot
.7628 .52098 Mdot
.46289 .72983 Mdot
.63083 .47898 Mdot
.28452 .40776 Mdot
.22033 .42998 Mdot
.46728 .31506 Mdot
.44229 .33088 Mdot
.82277 .50498 Mdot
.81644 .65446 Mdot
.50664 .67024 Mdot
.63502 .27963 Mdot
.44225 .30462 Mdot
.4775 .30616 Mdot
.29834 .40809 Mdot
.66992 .39341 Mdot
.64394 .43433 Mdot
.29155 .37675 Mdot
.38157 .75885 Mdot
.64781 .40058 Mdot
.75337 .65117 Mdot
.26312 .41288 Mdot
.6549 .62528 Mdot
.78721 .39707 Mdot
.3131 .53662 Mdot
.34485 .71147 Mdot
.50514 .27712 Mdot
.5789 .61894 Mdot
.4538 .18627 Mdot
.3139 .4116 Mdot
.42614 .534 Mdot
.47102 .36857 Mdot
.60925 .6474 Mdot
.56354 .61186 Mdot
.57128 .59195 Mdot
.38011 .54853 Mdot
.74609 .47332 Mdot
.57637 .61597 Mdot
.46177 .73838 Mdot
.6212 .58954 Mdot
.24985 .41913 Mdot
.32669 .54924 Mdot
.31408 .64776 Mdot
.34331 .44593 Mdot
.62905 .29667 Mdot
.54554 .56989 Mdot
.43093 .31689 Mdot
.49682 .59002 Mdot
.45333 .31308 Mdot
.44415 .28313 Mdot
.23822 .66632 Mdot
.6408 .42421 Mdot
.60104 .64953 Mdot
.27452 .41688 Mdot
.64493 .4349 Mdot
.49474 .5924 Mdot
.79209 .31194 Mdot
.49794 .29995 Mdot
.89778 .54982 Mdot
.43925 .32565 Mdot
.43554 .54116 Mdot
.66185 .38191 Mdot
.63741 .46909 Mdot
.41252 .71983 Mdot
.66335 .40622 Mdot
.26836 .46128 Mdot
.69265 .38903 Mdot
.31743 .74498 Mdot
.61786 .35985 Mdot
.4746 .31566 Mdot
.49102 .29672 Mdot
.52424 .57245 Mdot
.58838 .59191 Mdot
.39588 .73041 Mdot
.47501 .53437 Mdot
.60816 .58742 Mdot
.28902 .39359 Mdot
.3846 .36651 Mdot
.47082 .2205 Mdot
.64257 .37224 Mdot
.47381 .29342 Mdot
.56433 .61086 Mdot
.64503 .64674 Mdot
.60309 .63916 Mdot
.37638 .42403 Mdot
.7501 .66015 Mdot
.59444 .60436 Mdot
.53827 .56857 Mdot
.31266 .38379 Mdot
.30919 .46137 Mdot
.69294 .26604 Mdot
.23359 .65004 Mdot
.54772 .60924 Mdot
.3378 .53684 Mdot
.35031 .5339 Mdot
.52844 .57213 Mdot
.60974 .47486 Mdot
.32414 .61226 Mdot
.59808 .62427 Mdot
.48402 .73757 Mdot
.24585 .40086 Mdot
.47875 .55707 Mdot
.31506 .39256 Mdot
.60966 .42682 Mdot
.49597 .55453 Mdot
.28083 .39327 Mdot
.4413 .75885 Mdot
.4921 .53855 Mdot
.42867 .37435 Mdot
.36914 .55008 Mdot
.6104 .60564 Mdot
.8025 .48262 Mdot
.30678 .43336 Mdot
.48342 .31428 Mdot
.65564 .38019 Mdot
.49044 .31452 Mdot
.23088 .38514 Mdot
.36507 .74673 Mdot
.47478 .55319 Mdot
.43037 .31722 Mdot
.50241 .68267 Mdot
.33059 .53701 Mdot
.44004 .32256 Mdot
.65889 .62451 Mdot
.59018 .57322 Mdot
.76105 .70741 Mdot
.56506 .58088 Mdot
.38356 .36119 Mdot
.46595 .33438 Mdot
.49876 .55575 Mdot
.60168 .61787 Mdot
.25769 .40026 Mdot
.51669 .54404 Mdot
.59163 .61263 Mdot
.32944 .42391 Mdot
.60994 .62176 Mdot
.32311 .55959 Mdot
.68982 .35449 Mdot
.42078 .70314 Mdot
.38342 .52611 Mdot
.35652 .56813 Mdot
.47279 .72309 Mdot
.62658 .61993 Mdot
.24931 .45765 Mdot
.64625 .39422 Mdot
.58435 .64074 Mdot
.30817 .70587 Mdot
.66773 .37812 Mdot
.6584 .39331 Mdot
.65872 .64134 Mdot
.435 .32845 Mdot
.29609 .4136 Mdot
.32605 .54029 Mdot
.43966 .2522 Mdot
.57973 .61545 Mdot
.61886 .65705 Mdot
.35967 .56503 Mdot
.48146 .32038 Mdot
.62708 .65054 Mdot
.55636 .33338 Mdot
.43218 .74482 Mdot
.4835 .33503 Mdot
.56377 .5685 Mdot
.77571 .63419 Mdot
.66392 .35982 Mdot
.4524 .18631 Mdot
.36225 .44605 Mdot
.28343 .38003 Mdot
.46863 .53078 Mdot
.7494 .24994 Mdot
.35282 .53766 Mdot
.62101 .31796 Mdot
.59373 .63578 Mdot
.57273 .60625 Mdot
.67238 .4033 Mdot
.61437 .6011 Mdot
.63985 .37159 Mdot
.38141 .39785 Mdot
.83499 .63262 Mdot
.6267 .39464 Mdot
.63351 .3973 Mdot
.58681 .71731 Mdot
.35738 .4152 Mdot
.662 .37322 Mdot
.61032 .60094 Mdot
.21902 .39918 Mdot
.60051 .55486 Mdot
.32424 .57576 Mdot
.38396 .5511 Mdot
.6175 .4071 Mdot
.78082 .58464 Mdot
.65544 .62132 Mdot
.74632 .62704 Mdot
.3214 .61325 Mdot
.45207 .29344 Mdot
.59765 .65748 Mdot
.47843 .53828 Mdot
.32025 .4024 Mdot
.55339 .64244 Mdot
.60659 .60206 Mdot
.63769 .42092 Mdot
.30744 .54623 Mdot
.44356 .31932 Mdot
.45448 .52115 Mdot
.24004 .37885 Mdot
.35933 .55698 Mdot
.62727 .37588 Mdot
.81423 .53537 Mdot
.37332 .57629 Mdot
.4321 .52681 Mdot
.56258 .62462 Mdot
.56656 .64935 Mdot
.42376 .52762 Mdot
.46284 .30424 Mdot
.27378 .38086 Mdot
.43706 .52849 Mdot
.43723 .68667 Mdot
.41548 .75295 Mdot
.55427 .62125 Mdot
.62593 .4092 Mdot
.47699 .29663 Mdot
.45884 .54855 Mdot
.18831 .59175 Mdot
.54788 .59228 Mdot
.75373 .65193 Mdot
.39572 .54416 Mdot
.48355 .53863 Mdot
.64694 .43487 Mdot
.32734 .5442 Mdot
.64967 .64412 Mdot
.45994 .74272 Mdot
.61338 .59064 Mdot
.53267 .57192 Mdot
.27286 .39568 Mdot
.44686 .31202 Mdot
.55256 .53514 Mdot
.31644 .40172 Mdot
.65812 .39118 Mdot
.73387 .64425 Mdot
.67674 .40959 Mdot
.68096 .40754 Mdot
.65114 .32358 Mdot
.4856 .32199 Mdot
.74829 .24748 Mdot
.3937 .55733 Mdot
.61142 .6326 Mdot
.44725 .2901 Mdot
.65659 .37235 Mdot
.63069 .62176 Mdot
.64123 .37091 Mdot
.61411 .38625 Mdot
.60401 .58401 Mdot
.63771 .60893 Mdot
.46336 .7435 Mdot
.77251 .6289 Mdot
.32166 .55054 Mdot
.67706 .37861 Mdot
.77594 .61298 Mdot
.57483 .61117 Mdot
.59663 .59539 Mdot
.49633 .58812 Mdot
.36758 .56228 Mdot
.69695 .67154 Mdot
.58545 .63378 Mdot
.32403 .67393 Mdot
.63193 .62927 Mdot
.60817 .40065 Mdot
.41413 .29626 Mdot
.66272 .62799 Mdot
.30753 .37934 Mdot
.67822 .37949 Mdot
.31117 .53789 Mdot
.60538 .42827 Mdot
.68924 .59617 Mdot
.46777 .29807 Mdot
.63565 .40136 Mdot
.27794 .3772 Mdot
.48032 .31808 Mdot
.47975 .33065 Mdot
.4929 .59293 Mdot
.26352 .38638 Mdot
.30666 .5462 Mdot
.45649 .32762 Mdot
.68514 .56186 Mdot
.47636 .31598 Mdot
.69997 .61816 Mdot
.54947 .58398 Mdot
.46005 .74 Mdot
.4497 .52691 Mdot
.54118 .54686 Mdot
.46029 .33188 Mdot
.35967 .56203 Mdot
.62438 .65074 Mdot
.62726 .38117 Mdot
.34448 .5361 Mdot
.78061 .4073 Mdot
.277 .37557 Mdot
.66811 .35092 Mdot
.44265 .25364 Mdot
.67314 .37787 Mdot
.34647 .71658 Mdot
.30784 .53662 Mdot
.41584 .54003 Mdot
.41338 .69766 Mdot
.46159 .53482 Mdot
.54234 .61251 Mdot
.61999 .65081 Mdot
.5667 .59001 Mdot
.32506 .39571 Mdot
.38188 .55118 Mdot
.61866 .39411 Mdot
.58222 .52609 Mdot
.48366 .32076 Mdot
.49693 .65165 Mdot
.42959 .53246 Mdot
.64059 .64758 Mdot
.65302 .37318 Mdot
.61743 .37855 Mdot
.75334 .45549 Mdot
.30996 .41986 Mdot
.57789 .54147 Mdot
.55348 .62235 Mdot
.59361 .53396 Mdot
.46228 .33252 Mdot
.58874 .30955 Mdot
.25082 .40635 Mdot
.8998 .54602 Mdot
.31455 .40002 Mdot
.44429 .56007 Mdot
.65652 .36441 Mdot
.34316 .54995 Mdot
.55508 .59557 Mdot
.67393 .33238 Mdot
.67066 .42431 Mdot
.28697 .56093 Mdot
.33221 .54587 Mdot
.40493 .28763 Mdot
.44637 .29444 Mdot
.45427 .52029 Mdot
.63233 .63026 Mdot
.62623 .60701 Mdot
.59821 .58968 Mdot
.46255 .28962 Mdot
.64045 .61386 Mdot
.41777 .28645 Mdot
.6869 .59612 Mdot
.30942 .70861 Mdot
.27732 .41184 Mdot
.2217 .35623 Mdot
.68513 .39613 Mdot
.71045 .66346 Mdot
.69371 .62555 Mdot
.4599 .7313 Mdot
.43714 .29223 Mdot
.51329 .55158 Mdot
.29562 .4099 Mdot
.46647 .22425 Mdot
.27695 .41272 Mdot
.68435 .77482 Mdot
.79401 .52819 Mdot
.40496 .33747 Mdot
.62154 .60118 Mdot
.26922 .39401 Mdot
.78238 .58943 Mdot
.44123 .52632 Mdot
.36498 .58029 Mdot
.68587 .58445 Mdot
.78015 .42049 Mdot
.32119 .55219 Mdot
.55152 .60129 Mdot
.68984 .38933 Mdot
.55763 .5925 Mdot
.55397 .59617 Mdot
.59599 .63709 Mdot
.49839 .32501 Mdot
.54711 .58477 Mdot
.58086 .58924 Mdot
.14908 .51033 Mdot
.33509 .5988 Mdot
.3378 .4036 Mdot
.63986 .4711 Mdot
.32774 .53639 Mdot
.60901 .42564 Mdot
.41789 .70066 Mdot
.44981 .3343 Mdot
.75137 .4582 Mdot
.65327 .63341 Mdot
.63046 .31906 Mdot
.4488 .33612 Mdot
.32121 .56868 Mdot
.4769 .54043 Mdot
.56496 .20695 Mdot
.35129 .4242 Mdot
.46024 .54295 Mdot
.3289 .42083 Mdot
.67932 .63511 Mdot
.63142 .3861 Mdot
.46312 .53454 Mdot
.44591 .32165 Mdot
.27006 .40783 Mdot
.47065 .73233 Mdot
.57745 .59496 Mdot
.2809 .40583 Mdot
.47583 .52854 Mdot
.43124 .72332 Mdot
.41878 .70966 Mdot
.26709 .39717 Mdot
.42373 .30312 Mdot
.47237 .32931 Mdot
.32697 .53395 Mdot
.64804 .36311 Mdot
.65265 .41756 Mdot
.4754 .32319 Mdot
.44485 .21668 Mdot
.58114 .617 Mdot
.58757 .6025 Mdot
.40445 .68893 Mdot
.62613 .64263 Mdot
.34563 .48 Mdot
.46184 .54073 Mdot
.64211 .41899 Mdot
.62221 .65072 Mdot
.62933 .64956 Mdot
.54991 .60798 Mdot
.38395 .76266 Mdot
.32478 .39769 Mdot
.64298 .61261 Mdot
.32972 .56904 Mdot
.78219 .41315 Mdot
.58291 .58527 Mdot
.42747 .52168 Mdot
.65635 .36345 Mdot
.52339 .3448 Mdot
.48362 .31294 Mdot
.28418 .42369 Mdot
.27736 .41924 Mdot
.26033 .64103 Mdot
.67712 .40435 Mdot
.46002 .54217 Mdot
.29259 .44027 Mdot
.45021 .5463 Mdot
.33424 .54462 Mdot
.50936 .634 Mdot
.32927 .4771 Mdot
.33794 .40472 Mdot
.47929 .34249 Mdot
.58295 .64228 Mdot
.5855 .58675 Mdot
.64556 .29108 Mdot
.60887 .61065 Mdot
.33242 .56049 Mdot
.43557 .31033 Mdot
.63712 .39997 Mdot
.318 .55473 Mdot
.43537 .32395 Mdot
.66015 .4104 Mdot
.6157 .58595 Mdot
.63141 .62449 Mdot
.65865 .38588 Mdot
.63155 .37162 Mdot
.58576 .62488 Mdot
.2509 .69405 Mdot
.63337 .41653 Mdot
.6587 .38122 Mdot
.7813 .41518 Mdot
.34876 .41738 Mdot
.51437 .54038 Mdot
.42885 .32009 Mdot
.57913 .5899 Mdot
.28289 .41451 Mdot
.34612 .54506 Mdot
.63526 .41058 Mdot
.56049 .64547 Mdot
.58091 .6113 Mdot
.33493 .53688 Mdot
.37611 .55934 Mdot
.36578 .55115 Mdot
.48814 .29497 Mdot
.6553 .63112 Mdot
.66197 .37699 Mdot
.46418 .28592 Mdot
.32507 .53077 Mdot
.36698 .56724 Mdot
.34744 .76821 Mdot
.58204 .6208 Mdot
.37753 .5549 Mdot
.77012 .2876 Mdot
.45053 .76322 Mdot
.45879 .55253 Mdot
.30174 .37192 Mdot
.21241 .41523 Mdot
.39809 .57119 Mdot
.44762 .30841 Mdot
.49493 .65305 Mdot
.32046 .57234 Mdot
.46217 .52404 Mdot
.58431 .59831 Mdot
.58554 .65976 Mdot
.34826 .53779 Mdot
.36312 .74565 Mdot
.64652 .42436 Mdot
.66931 .48326 Mdot
.32687 .53688 Mdot
.26454 .39854 Mdot
.25017 .40926 Mdot
.30843 .40279 Mdot
.55358 .63059 Mdot
.67679 .69881 Mdot
.6686 .53859 Mdot
.69522 .66094 Mdot
.44382 .29747 Mdot
.61618 .38027 Mdot
.78883 .40453 Mdot
.65819 .39557 Mdot
.32507 .4156 Mdot
.35854 .56303 Mdot
.66786 .4086 Mdot
.48575 .32458 Mdot
.4689 .33047 Mdot
.35139 .41784 Mdot
.31295 .39386 Mdot
.29662 .40002 Mdot
.67496 .36533 Mdot
.64988 .36629 Mdot
.62709 .61274 Mdot
.62201 .39757 Mdot
.37139 .42251 Mdot
.37778 .40986 Mdot
.3366 .43066 Mdot
.46565 .30835 Mdot
.65395 .40834 Mdot
.61428 .60922 Mdot
.46334 .67021 Mdot
.27395 .43018 Mdot
.31179 .54117 Mdot
.80372 .3913 Mdot
.80442 .66881 Mdot
.59182 .65337 Mdot
.45958 .29422 Mdot
.44954 .5412 Mdot
.56356 .59439 Mdot
.2823 .37952 Mdot
.40618 .5569 Mdot
.50218 .54606 Mdot
.58389 .58158 Mdot
.576 .57389 Mdot
.47571 .29839 Mdot
.41842 .6973 Mdot
.45793 .52315 Mdot
.48822 .60562 Mdot
.43478 .30665 Mdot
.2642 .41968 Mdot
.19078 .40703 Mdot
.71486 .35575 Mdot
.33734 .65189 Mdot
.49756 .55209 Mdot
.54736 .59123 Mdot
.29007 .3909 Mdot
.31809 .56026 Mdot
.296 .393 Mdot
.60812 .41817 Mdot
.34824 .41465 Mdot
.61253 .61578 Mdot
.66377 .37688 Mdot
.47331 .33078 Mdot
.41281 .66824 Mdot
.55347 .51438 Mdot
.25801 .40298 Mdot
.41963 .53372 Mdot
.63081 .60234 Mdot
.68985 .56922 Mdot
.53973 .54762 Mdot
.60389 .598 Mdot
.45493 .31449 Mdot
.6461 .37205 Mdot
.48891 .3075 Mdot
.52076 .54907 Mdot
.61187 .46873 Mdot
.48403 .31068 Mdot
.65237 .70642 Mdot
.33778 .57528 Mdot
.3712 .75289 Mdot
.60206 .62607 Mdot
.44616 .31904 Mdot
.57805 .57955 Mdot
.67736 .38637 Mdot
.43143 .75744 Mdot
.44022 .74143 Mdot
.46471 .32315 Mdot
.448 .5536 Mdot
.42404 .72299 Mdot
.51148 .53628 Mdot
.4441 .30279 Mdot
.46398 .76997 Mdot
.46847 .54619 Mdot
.35791 .55541 Mdot
.3727 .56378 Mdot
.35132 .56263 Mdot
.59159 .60118 Mdot
.79526 .59951 Mdot
.34205 .53321 Mdot
.51169 .3403 Mdot
.33101 .56507 Mdot
.42032 .56 Mdot
.66397 .28523 Mdot
.34626 .57389 Mdot
.60556 .61949 Mdot
.67135 .63884 Mdot
.4963 .66154 Mdot
.25668 .38644 Mdot
.54803 .21261 Mdot
.15062 .49998 Mdot
.57316 .61216 Mdot
.79763 .39379 Mdot
.68563 .34487 Mdot
.4136 .54318 Mdot
.44714 .73831 Mdot
.51034 .69834 Mdot
.66223 .39524 Mdot
.41551 .69776 Mdot
.67279 .35644 Mdot
.43971 .53314 Mdot
.59129 .60483 Mdot
.67858 .38241 Mdot
.62521 .32757 Mdot
.41894 .78919 Mdot
.65254 .30031 Mdot
.65488 .41069 Mdot
.44062 .31135 Mdot
.45165 .30422 Mdot
.45648 .31797 Mdot
.30508 .38677 Mdot
.6324 .40012 Mdot
.61633 .58835 Mdot
.29155 .38069 Mdot
.57086 .62439 Mdot
.47007 .32408 Mdot
.45078 .7385 Mdot
.63435 .39739 Mdot
.59772 .62547 Mdot
.77748 .60107 Mdot
.32297 .42739 Mdot
.3361 .53598 Mdot
.8006 .3911 Mdot
.30591 .37457 Mdot
.42347 .31724 Mdot
.61068 .41683 Mdot
.33055 .59569 Mdot
.48815 .62361 Mdot
.55878 .62532 Mdot
.61982 .62893 Mdot
.49289 .65318 Mdot
.79903 .52514 Mdot
.48189 .52474 Mdot
.29273 .3822 Mdot
.34651 .41645 Mdot
.55721 .58602 Mdot
.63004 .4008 Mdot
.29873 .5464 Mdot
.38309 .56355 Mdot
.55542 .55215 Mdot
.41554 .71681 Mdot
.46167 .73817 Mdot
.63645 .63764 Mdot
.62476 .69681 Mdot
.2755 .37826 Mdot
.45399 .55168 Mdot
.41042 .71226 Mdot
.3473 .55881 Mdot
.57702 .63261 Mdot
.65665 .46815 Mdot
.63623 .40759 Mdot
.28694 .40919 Mdot
.49902 .31568 Mdot
.36939 .57864 Mdot
.34103 .4291 Mdot
.55691 .58628 Mdot
.6284 .6499 Mdot
.44217 .32255 Mdot
.61058 .41236 Mdot
.35831 .54755 Mdot
.29728 .381 Mdot
.34485 .55307 Mdot
.6343 .38074 Mdot
.63587 .4121 Mdot
.58403 .63837 Mdot
.58237 .53987 Mdot
.25907 .40778 Mdot
.55093 .62976 Mdot
.28113 .40074 Mdot
.30838 .45997 Mdot
.49547 .31167 Mdot
.58718 .64116 Mdot
.63356 .43409 Mdot
.47158 .32525 Mdot
.57045 .61275 Mdot
.49216 .6429 Mdot
.63294 .64963 Mdot
.26834 .39366 Mdot
.3944 .55059 Mdot
.35409 .55534 Mdot
.65651 .66755 Mdot
.76813 .42488 Mdot
.62803 .6444 Mdot
.31344 .43402 Mdot
.67456 .55658 Mdot
.47687 .30218 Mdot
.6667 .36762 Mdot
.23949 .33249 Mdot
.47303 .31151 Mdot
.60633 .62632 Mdot
.33722 .55852 Mdot
.62413 .37655 Mdot
.49006 .55574 Mdot
.37056 .70733 Mdot
.52624 .5556 Mdot
.58291 .54328 Mdot
.47452 .52324 Mdot
.64035 .28043 Mdot
.29604 .3978 Mdot
.65533 .37328 Mdot
.45593 .29568 Mdot
.47191 .2991 Mdot
.32793 .41904 Mdot
.77454 .41738 Mdot
.72045 .31014 Mdot
.7642 .27451 Mdot
.32328 .43648 Mdot
.3442 .56628 Mdot
.43379 .75618 Mdot
.30852 .40424 Mdot
.33459 .40756 Mdot
.35645 .44486 Mdot
.64031 .29109 Mdot
.66407 .40092 Mdot
.5799 .61053 Mdot
.79311 .39461 Mdot
.60168 .63592 Mdot
.34181 .6523 Mdot
.47073 .32273 Mdot
.66726 .36792 Mdot
.39236 .40158 Mdot
.54681 .62205 Mdot
.55731 .60505 Mdot
.38492 .37775 Mdot
.47307 .53598 Mdot
.20646 .60967 Mdot
.61403 .63752 Mdot
.30305 .38944 Mdot
.67201 .43639 Mdot
.44025 .52999 Mdot
.77846 .60137 Mdot
.46047 .33389 Mdot
.46799 .55215 Mdot
.43769 .53096 Mdot
.61782 .69882 Mdot
.67908 .35958 Mdot
.66012 .41667 Mdot
.3733 .55797 Mdot
.69129 .31066 Mdot
.4582 .33433 Mdot
.59759 .29506 Mdot
.60986 .60143 Mdot
.43706 .28571 Mdot
.36729 .52406 Mdot
.57082 .61634 Mdot
.49312 .59541 Mdot
.75331 .45483 Mdot
.57968 .65297 Mdot
.68639 .61589 Mdot
.46893 .31392 Mdot
.31121 .70166 Mdot
.62828 .60317 Mdot
.28279 .40643 Mdot
.67089 .39009 Mdot
.67278 .35143 Mdot
.31456 .5533 Mdot
.37084 .44379 Mdot
.86371 .59663 Mdot
.66856 .36939 Mdot
.57966 .59425 Mdot
.4784 .30548 Mdot
.4797 .555 Mdot
.45335 .52739 Mdot
.44378 .55248 Mdot
.63938 .40808 Mdot
.4425 .52804 Mdot
.63915 .31414 Mdot
.41651 .69829 Mdot
.71777 .65831 Mdot
.45952 .32318 Mdot
.33949 .56446 Mdot
.57824 .55335 Mdot
.32097 .45611 Mdot
.6335 .63126 Mdot
.34038 .65216 Mdot
.6846 .34845 Mdot
.33515 .56252 Mdot
.55832 .59543 Mdot
.46452 .5197 Mdot
.48515 .72122 Mdot
.30473 .56306 Mdot
.47875 .52441 Mdot
.60023 .65296 Mdot
.6713 .39848 Mdot
.45769 .54197 Mdot
.64015 .40128 Mdot
.55493 .59856 Mdot
.33434 .62501 Mdot
.67562 .37602 Mdot
.53539 .21407 Mdot
.38483 .56744 Mdot
.44016 .33064 Mdot
.60092 .66257 Mdot
.5475 .61026 Mdot
.71933 .67682 Mdot
.46178 .55175 Mdot
.47729 .20183 Mdot
.27622 .40463 Mdot
.19452 .60824 Mdot
.32759 .38382 Mdot
.39145 .35866 Mdot
.53594 .34602 Mdot
.5766 .65592 Mdot
.77344 .41961 Mdot
.69092 .69255 Mdot
.42603 .30074 Mdot
.70565 .6853 Mdot
.58813 .59179 Mdot
.56204 .62339 Mdot
.28056 .40192 Mdot
.45822 .27793 Mdot
.66504 .63178 Mdot
.41097 .71334 Mdot
.32201 .57025 Mdot
.64977 .38772 Mdot
.59438 .59907 Mdot
.61206 .33903 Mdot
.2646 .40373 Mdot
.63705 .48416 Mdot
.60101 .62259 Mdot
.47304 .53631 Mdot
.45126 .28087 Mdot
.47218 .3316 Mdot
.26563 .38994 Mdot
.26224 .3923 Mdot
.54785 .60734 Mdot
.47982 .29278 Mdot
.632 .61656 Mdot
.42578 .72328 Mdot
.47876 .52921 Mdot
.33543 .54208 Mdot
.61846 .61023 Mdot
.73006 .38559 Mdot
.4504 .83824 Mdot
.55343 .62888 Mdot
.68235 .40276 Mdot
.29311 .40211 Mdot
.32868 .40442 Mdot
.6515 .4172 Mdot
.32894 .4059 Mdot
.67303 .48189 Mdot
.79389 .60352 Mdot
.33677 .54647 Mdot
.64619 .53054 Mdot
.34928 .57004 Mdot
.46284 .55093 Mdot
.58333 .62225 Mdot
.35918 .21981 Mdot
.32179 .43643 Mdot
.43684 .58804 Mdot
.47543 .3205 Mdot
.44676 .54843 Mdot
.64867 .6219 Mdot
.35492 .52943 Mdot
.31767 .40844 Mdot
.41974 .52953 Mdot
.58964 .63666 Mdot
.6762 .36957 Mdot
.62536 .65681 Mdot
.4356 .53826 Mdot
.45358 .54373 Mdot
.48044 .5215 Mdot
.43535 .32397 Mdot
.63614 .37439 Mdot
.40324 .29127 Mdot
.32143 .42946 Mdot
.60403 .58488 Mdot
.57515 .59325 Mdot
.62806 .3699 Mdot
.61383 .62975 Mdot
.47926 .29133 Mdot
.71231 .20624 Mdot
.36572 .55575 Mdot
.46974 .55502 Mdot
.56205 .2446 Mdot
.48191 .52176 Mdot
.61084 .6528 Mdot
.545 .71205 Mdot
.66029 .47166 Mdot
.43673 .32806 Mdot
.53033 .57505 Mdot
.33909 .40266 Mdot
.35898 .55018 Mdot
.48737 .32374 Mdot
.64796 .62507 Mdot
.60964 .61793 Mdot
.337 .56242 Mdot
.39504 .38633 Mdot
.35443 .57812 Mdot
.45047 .29649 Mdot
.48067 .56015 Mdot
.46506 .66931 Mdot
.58866 .61662 Mdot
.46622 .5394 Mdot
.6438 .37614 Mdot
.45141 .29189 Mdot
.74627 .47782 Mdot
.43761 .53307 Mdot
.4449 .25174 Mdot
.46817 .33286 Mdot
.56187 .6276 Mdot
.67875 .39778 Mdot
.64872 .34229 Mdot
.64827 .37412 Mdot
.28268 .68816 Mdot
.40539 .27491 Mdot
.29181 .39935 Mdot
.46757 .30837 Mdot
.28984 .41801 Mdot
.34216 .57578 Mdot
.41369 .74928 Mdot
.25965 .39691 Mdot
.64903 .42855 Mdot
.28336 .41751 Mdot
.63162 .61713 Mdot
.44723 .33438 Mdot
.26342 .41452 Mdot
.61234 .60119 Mdot
.58637 .57067 Mdot
.45398 .53788 Mdot
.30138 .54333 Mdot
.41599 .70773 Mdot
.60132 .63026 Mdot
.47153 .54164 Mdot
.59352 .62406 Mdot
.48056 .29243 Mdot
.39983 .66119 Mdot
.59117 .57883 Mdot
.31964 .43706 Mdot
.57925 .19996 Mdot
.34605 .42235 Mdot
.52693 .47873 Mdot
.57202 .62365 Mdot
.58611 .61814 Mdot
.63244 .60364 Mdot
.78801 .4261 Mdot
.41975 .31036 Mdot
.53387 .60135 Mdot
.31179 .37978 Mdot
.65687 .40113 Mdot
.67279 .40788 Mdot
.51542 .68405 Mdot
.46365 .54152 Mdot
.48851 .29672 Mdot
.58389 .61768 Mdot
.44407 .5422 Mdot
.3937 .70922 Mdot
.67697 .29851 Mdot
.35975 .43632 Mdot
.3342 .4186 Mdot
.6538 .3597 Mdot
.32096 .39038 Mdot
.64732 .62285 Mdot
.44424 .52919 Mdot
.4111 .26506 Mdot
.50915 .33015 Mdot
.35796 .54982 Mdot
.56359 .61888 Mdot
.3926 .76948 Mdot
.3122 .38367 Mdot
.26639 .38421 Mdot
.63088 .61452 Mdot
.70814 .36983 Mdot
.40778 .81623 Mdot
.44868 .28866 Mdot
.7058 .57032 Mdot
.81592 .48889 Mdot
.61143 .76974 Mdot
.46337 .30133 Mdot
.49225 .59899 Mdot
.25518 .38452 Mdot
.24702 .60003 Mdot
.65961 .39752 Mdot
.35709 .54722 Mdot
.61454 .60346 Mdot
.64951 .42784 Mdot
.32984 .43544 Mdot
.61745 .38857 Mdot
.47157 .53203 Mdot
.45014 .33627 Mdot
.32198 .40113 Mdot
.50089 .31184 Mdot
.62863 .43615 Mdot
.35369 .56587 Mdot
.32763 .67445 Mdot
.68573 .57118 Mdot
.75553 .45005 Mdot
.65435 .62614 Mdot
.33988 .60043 Mdot
.64759 .61733 Mdot
.67129 .34846 Mdot
.60274 .62544 Mdot
.5709 .56902 Mdot
.26254 .37891 Mdot
.55551 .62266 Mdot
.61306 .6045 Mdot
.77653 .60596 Mdot
.56562 .61455 Mdot
.55033 .60311 Mdot
.55945 .62707 Mdot
.66799 .41671 Mdot
.59314 .63906 Mdot
.64045 .36827 Mdot
.62143 .32168 Mdot
.32168 .42902 Mdot
.34872 .57456 Mdot
.34965 .5735 Mdot
.3508 .63729 Mdot
.39034 .76758 Mdot
.7912 .3985 Mdot
.64968 .40228 Mdot
.46226 .3319 Mdot
.6275 .61202 Mdot
.363 .7855 Mdot
.33627 .62663 Mdot
.2495 .39465 Mdot
.26648 .41193 Mdot
.59263 .58606 Mdot
.79085 .68267 Mdot
.62033 .63497 Mdot
.39526 .69297 Mdot
.59272 .60152 Mdot
.5949 .64286 Mdot
.32911 .38677 Mdot
.34563 .71523 Mdot
.64022 .60966 Mdot
.68385 .36483 Mdot
.3536 .54569 Mdot
.45951 .53944 Mdot
.34001 .63025 Mdot
.82064 .52006 Mdot
.71762 .39459 Mdot
.63011 .60076 Mdot
.29474 .37966 Mdot
.63944 .41652 Mdot
.40606 .6906 Mdot
.46348 .28623 Mdot
.37085 .71272 Mdot
.69895 .62469 Mdot
.44281 .29032 Mdot
.35896 .55423 Mdot
.26943 .42682 Mdot
.55115 .61467 Mdot
.28814 .38861 Mdot
.54832 .62893 Mdot
.38731 .70542 Mdot
.33724 .54431 Mdot
.69387 .3873 Mdot
.43986 .31344 Mdot
.65228 .42581 Mdot
.62983 .47902 Mdot
.33281 .62705 Mdot
.16816 .57571 Mdot
.34232 .42769 Mdot
.5792 .51655 Mdot
.66042 .36841 Mdot
.54719 .59366 Mdot
.76122 .27337 Mdot
.63849 .38319 Mdot
.67742 .3746 Mdot
.37414 .68424 Mdot
.3441 .72253 Mdot
.55616 .63542 Mdot
.62795 .41452 Mdot
.27632 .43052 Mdot
.33009 .54822 Mdot
.60072 .59276 Mdot
.44649 .53244 Mdot
.66979 .40663 Mdot
.32219 .41231 Mdot
.34241 .70377 Mdot
.30854 .3913 Mdot
.66658 .3944 Mdot
.29346 .42806 Mdot
.40855 .28396 Mdot
.25938 .39798 Mdot
.6188 .61858 Mdot
.58478 .61732 Mdot
.63133 .34827 Mdot
.63576 .41206 Mdot
.61169 .65283 Mdot
.60218 .63424 Mdot
.66046 .37321 Mdot
.29986 .44049 Mdot
.6938 .44363 Mdot
.60899 .65056 Mdot
.58034 .61438 Mdot
.36669 .55976 Mdot
.44024 .6989 Mdot
.41165 .6784 Mdot
.62881 .61819 Mdot
.34885 .56577 Mdot
.67173 .36272 Mdot
.58936 .62542 Mdot
.34188 .71283 Mdot
.24296 .39535 Mdot
.63789 .61915 Mdot
.49039 .55468 Mdot
.66015 .6343 Mdot
.49177 .81489 Mdot
.63246 .60414 Mdot
.66319 .38642 Mdot
.66855 .38167 Mdot
.24578 .40946 Mdot
.65664 .38642 Mdot
.46748 .55422 Mdot
.47475 .32717 Mdot
.71115 .59616 Mdot
.45082 .5506 Mdot
.49283 .52943 Mdot
.39363 .55745 Mdot
.43282 .52844 Mdot
.43329 .51525 Mdot
.36142 .43579 Mdot
.49669 .55035 Mdot
.64735 .36957 Mdot
.58646 .43309 Mdot
.51536 .55237 Mdot
.48227 .29189 Mdot
.43877 .52988 Mdot
.63937 .62151 Mdot
.56182 .56693 Mdot
.63388 .46573 Mdot
.46092 .2852 Mdot
.5437 .54138 Mdot
.60144 .59316 Mdot
.6584 .47082 Mdot
.59408 .59782 Mdot
.30866 .55445 Mdot
.63654 .39654 Mdot
.3065 .38545 Mdot
.33186 .54221 Mdot
.46534 .52253 Mdot
.33281 .53454 Mdot
.28634 .3931 Mdot
.45033 .32509 Mdot
.61672 .61837 Mdot
.3161 .57188 Mdot
.34036 .57426 Mdot
.62532 .6605 Mdot
.67015 .38054 Mdot
.52995 .55522 Mdot
.58382 .6251 Mdot
.63401 .60491 Mdot
.65344 .41782 Mdot
.44213 .18193 Mdot
.5533 .61383 Mdot
.49024 .59644 Mdot
.67795 .35037 Mdot
.44191 .54289 Mdot
.30059 .38328 Mdot
.55657 .64209 Mdot
.48708 .31189 Mdot
.47672 .32318 Mdot
.31582 .43671 Mdot
.66259 .41375 Mdot
.3261 .4049 Mdot
.54416 .61591 Mdot
.43845 .52885 Mdot
.59491 .59181 Mdot
.38067 .36819 Mdot
.5056 .20423 Mdot
.626 .37608 Mdot
.32824 .42795 Mdot
.40137 .73015 Mdot
.43339 .32656 Mdot
.35602 .42528 Mdot
.68194 .36005 Mdot
.63313 .42083 Mdot
.65189 .41505 Mdot
.33569 .57174 Mdot
.315 .39747 Mdot
.60566 .42554 Mdot
.60697 .43074 Mdot
.6455 .64229 Mdot
.60473 .59419 Mdot
.66476 .36006 Mdot
.3334 .45319 Mdot
.35537 .55357 Mdot
.32121 .38605 Mdot
.41795 .82249 Mdot
.4487 .29026 Mdot
.7785 .60323 Mdot
.63384 .6278 Mdot
.90569 .53617 Mdot
.61908 .63529 Mdot
.58597 .59533 Mdot
.60965 .42679 Mdot
.37018 .56784 Mdot
.33068 .55125 Mdot
.66223 .36927 Mdot
.6136 .39081 Mdot
.3118 .55163 Mdot
.44681 .67905 Mdot
.46221 .81224 Mdot
.40014 .7049 Mdot
.61979 .38733 Mdot
.70266 .59876 Mdot
.45886 .31448 Mdot
.68934 .35222 Mdot
.41153 .2893 Mdot
.28945 .42862 Mdot
.25885 .40199 Mdot
.44593 .32696 Mdot
.55204 .61069 Mdot
.33482 .39349 Mdot
.6572 .62608 Mdot
.40499 .34491 Mdot
.50861 .58004 Mdot
.26119 .71976 Mdot
.61551 .62534 Mdot
.5211 .46656 Mdot
.6524 .28141 Mdot
.63095 .65258 Mdot
.79779 .56919 Mdot
.35674 .54426 Mdot
.6663 .34742 Mdot
.45837 .28258 Mdot
.79458 .39174 Mdot
.58744 .61723 Mdot
.62401 .40759 Mdot
.43796 .30732 Mdot
.48956 .20562 Mdot
.48871 .60572 Mdot
.64242 .64707 Mdot
.75375 .25962 Mdot
.68321 .40731 Mdot
.30331 .38502 Mdot
.69893 .54754 Mdot
.61088 .39319 Mdot
.48851 .61699 Mdot
.30224 .43914 Mdot
.48266 .70968 Mdot
.61818 .40243 Mdot
.36083 .57571 Mdot
.64756 .39208 Mdot
.31699 .54302 Mdot
.60466 .42038 Mdot
.31476 .42885 Mdot
.56018 .613 Mdot
.31929 .42868 Mdot
.31463 .53647 Mdot
.33765 .42794 Mdot
.4562 .2832 Mdot
.49253 .54343 Mdot
.46937 .32493 Mdot
.42267 .75489 Mdot
.75263 .49332 Mdot
.44747 .31379 Mdot
.54715 .70382 Mdot
.61152 .61534 Mdot
.6079 .39659 Mdot
.31107 .38716 Mdot
.27462 .37319 Mdot
.41594 .71053 Mdot
.66572 .40222 Mdot
.32207 .41827 Mdot
.6909 .58158 Mdot
.45122 .21301 Mdot
.59708 .57482 Mdot
.22958 .34232 Mdot
.66106 .37762 Mdot
.28123 .37297 Mdot
.40015 .69078 Mdot
.62588 .41873 Mdot
.26031 .41024 Mdot
.4432 .30711 Mdot
.48678 .31255 Mdot
.6192 .62482 Mdot
.49612 .29635 Mdot
.25498 .38806 Mdot
.6306 .4926 Mdot
.66856 .36593 Mdot
.51495 .20498 Mdot
.36127 .56006 Mdot
.32165 .3927 Mdot
.46676 .52553 Mdot
.63226 .43395 Mdot
.28883 .41903 Mdot
.85256 .61098 Mdot
.42385 .85233 Mdot
.32146 .41637 Mdot
.63805 .39738 Mdot
.64124 .41108 Mdot
.58615 .65088 Mdot
.41357 .71442 Mdot
.31689 .40996 Mdot
.35419 .22142 Mdot
.46238 .74181 Mdot
.48905 .54481 Mdot
.1496 .50589 Mdot
.62 .59128 Mdot
.65262 .62516 Mdot
.45577 .29105 Mdot
.55867 .60492 Mdot
.61455 .39014 Mdot
.61845 .63592 Mdot
.49148 .3105 Mdot
.31409 .43616 Mdot
.5885 .62091 Mdot
.36005 .55171 Mdot
.47399 .29542 Mdot
.48165 .29733 Mdot
.29157 .42624 Mdot
.66218 .41311 Mdot
.79859 .3825 Mdot
.3121 .39246 Mdot
.65612 .63278 Mdot
.47774 .54205 Mdot
.55901 .62624 Mdot
.66386 .32475 Mdot
.66334 .35003 Mdot
.31738 .38842 Mdot
.57948 .65931 Mdot
.47091 .30519 Mdot
.25728 .38145 Mdot
.62108 .59159 Mdot
.25837 .41258 Mdot
.42804 .54917 Mdot
.21711 .40417 Mdot
.63225 .44 Mdot
.41374 .54093 Mdot
.63251 .42201 Mdot
.49425 .54957 Mdot
.26194 .64976 Mdot
.35732 .55518 Mdot
.34543 .41232 Mdot
.52878 .213 Mdot
.326 .42712 Mdot
.56685 .61374 Mdot
.61051 .62103 Mdot
.27762 .39892 Mdot
.35142 .56673 Mdot
.42163 .55899 Mdot
.34409 .58072 Mdot
.63468 .40223 Mdot
.50462 .68858 Mdot
.36638 .81714 Mdot
.2489 .38408 Mdot
.45113 .33127 Mdot
.71641 .35326 Mdot
.48981 .5278 Mdot
.45691 .2841 Mdot
.47779 .29475 Mdot
.3227 .53268 Mdot
.33512 .40978 Mdot
.69271 .37681 Mdot
.46805 .33621 Mdot
.61459 .41113 Mdot
.3374 .70194 Mdot
.43126 .53206 Mdot
.60448 .53824 Mdot
.46226 .51963 Mdot
.41607 .70168 Mdot
.46038 .33824 Mdot
.60319 .61206 Mdot
.56569 .54795 Mdot
.44262 .30288 Mdot
.32866 .53049 Mdot
.51293 .57748 Mdot
.32077 .42011 Mdot
.78407 .30975 Mdot
.6198 .6174 Mdot
.57513 .62332 Mdot
.44391 .29672 Mdot
.81135 .54654 Mdot
.68014 .36185 Mdot
.67307 .39582 Mdot
.29663 .39822 Mdot
.37977 .68009 Mdot
.59696 .63837 Mdot
.61466 .61562 Mdot
.27401 .39911 Mdot
.46415 .54472 Mdot
.15538 .55109 Mdot
.58249 .61098 Mdot
.46475 .31179 Mdot
.49635 .5899 Mdot
.42359 .30384 Mdot
.54163 .57167 Mdot
.56734 .60982 Mdot
.6533 .64108 Mdot
.63106 .59998 Mdot
.46581 .32419 Mdot
.47159 .52222 Mdot
.50646 .54011 Mdot
.64355 .37365 Mdot
.56645 .58072 Mdot
.46403 .74029 Mdot
.58597 .61292 Mdot
.35985 .54757 Mdot
.40712 .67758 Mdot
.60983 .58711 Mdot
.57308 .57964 Mdot
.45982 .74473 Mdot
.5634 .59077 Mdot
.44121 .29879 Mdot
.64628 .41074 Mdot
.47231 .30424 Mdot
.4428 .32819 Mdot
.28731 .42037 Mdot
.34937 .53436 Mdot
.54931 .62734 Mdot
.31653 .56188 Mdot
.57511 .64348 Mdot
.52788 .54846 Mdot
.43049 .72398 Mdot
.3954 .69413 Mdot
.30193 .55495 Mdot
.61349 .61299 Mdot
.29037 .39516 Mdot
.33286 .39892 Mdot
.49456 .65091 Mdot
.55548 .64493 Mdot
.48884 .28843 Mdot
.44586 .31817 Mdot
.37823 .40886 Mdot
.20787 .39267 Mdot
.31153 .56502 Mdot
.41921 .55594 Mdot
.62172 .59065 Mdot
.5679 .62488 Mdot
.49094 .53156 Mdot
.28848 .41415 Mdot
.49713 .54964 Mdot
.35162 .44141 Mdot
.44241 .28698 Mdot
.46539 .29647 Mdot
.61722 .62188 Mdot
.77029 .71385 Mdot
.62989 .38562 Mdot
.64198 .41199 Mdot
.49225 .31332 Mdot
.34651 .42166 Mdot
.46574 .52979 Mdot
.81193 .34861 Mdot
.65972 .35185 Mdot
.35295 .57492 Mdot
.56631 .58593 Mdot
.29781 .431 Mdot
.63992 .37103 Mdot
.31925 .57339 Mdot
.55298 .58153 Mdot
.31286 .44031 Mdot
.59865 .61142 Mdot
.63442 .51443 Mdot
.65437 .36578 Mdot
.43902 .71525 Mdot
.66247 .4245 Mdot
.46674 .32227 Mdot
.45346 .33475 Mdot
.56974 .61217 Mdot
.80804 .33982 Mdot
.68991 .41791 Mdot
.48271 .33624 Mdot
.37322 .55968 Mdot
.4925 .53972 Mdot
.34356 .53339 Mdot
.28312 .40232 Mdot
.35848 .55389 Mdot
.28916 .41981 Mdot
.27839 .43415 Mdot
.68864 .39079 Mdot
.3366 .56203 Mdot
.78478 .55554 Mdot
.44585 .52921 Mdot
.37886 .55355 Mdot
.60472 .58835 Mdot
.59163 .64882 Mdot
.31212 .41432 Mdot
.32032 .56687 Mdot
.56264 .64663 Mdot
.55578 .24539 Mdot
.44105 .33007 Mdot
.45573 .28288 Mdot
.46984 .53157 Mdot
.27259 .37815 Mdot
.688 .39113 Mdot
.40409 .73483 Mdot
.6918 .39936 Mdot
.6156 .61442 Mdot
.54954 .62662 Mdot
.64664 .43535 Mdot
.68508 .39589 Mdot
.56913 .60774 Mdot
.74078 .63584 Mdot
.46601 .52467 Mdot
.48687 .31611 Mdot
.6329 .40065 Mdot
.63206 .40948 Mdot
.25572 .38996 Mdot
.67308 .40077 Mdot
.58827 .54363 Mdot
.44615 .28567 Mdot
.50847 .54208 Mdot
.4705 .30806 Mdot
.30948 .58941 Mdot
.3106 .42034 Mdot
.51054 .21125 Mdot
.67453 .39403 Mdot
.62073 .65117 Mdot
.67689 .39034 Mdot
.36602 .54993 Mdot
.62101 .39957 Mdot
.68314 .34126 Mdot
.61442 .60433 Mdot
.47584 .5239 Mdot
.45786 .54737 Mdot
.41336 .70715 Mdot
.63479 .38291 Mdot
.55096 .62511 Mdot
.61376 .6413 Mdot
.60523 .63346 Mdot
.42279 .7241 Mdot
.67037 .41375 Mdot
.82002 .52279 Mdot
.60862 .43765 Mdot
.6505 .3662 Mdot
.48162 .85002 Mdot
.45541 .54843 Mdot
.50172 .54372 Mdot
.49206 .36354 Mdot
.57982 .61165 Mdot
.32855 .41107 Mdot
.65483 .63407 Mdot
.48088 .52761 Mdot
.59034 .58062 Mdot
.32103 .55128 Mdot
.54579 .60836 Mdot
.47967 .54665 Mdot
.31458 .39145 Mdot
.63429 .64946 Mdot
.58154 .61904 Mdot
.45955 .54387 Mdot
.67873 .38528 Mdot
.6439 .42319 Mdot
.68204 .41855 Mdot
.31465 .5412 Mdot
.45273 .30999 Mdot
.65397 .632 Mdot
.294 .39699 Mdot
.33005 .41327 Mdot
.6531 .42852 Mdot
.27286 .3885 Mdot
.46268 .29491 Mdot
.58112 .59585 Mdot
.46693 .32345 Mdot
.31976 .54825 Mdot
.6356 .39578 Mdot
.64397 .61808 Mdot
.63956 .65537 Mdot
.66852 .38142 Mdot
.45726 .52387 Mdot
.37037 .55274 Mdot
.26899 .3989 Mdot
.63213 .37034 Mdot
.47647 .32528 Mdot
.25707 .39293 Mdot
.62788 .65116 Mdot
.59617 .83227 Mdot
.55942 .60523 Mdot
.60229 .63663 Mdot
.6565 .44636 Mdot
.54805 .56953 Mdot
.32121 .42969 Mdot
.67422 .40475 Mdot
.59934 .64953 Mdot
.44542 .76087 Mdot
.29461 .54965 Mdot
.24924 .37731 Mdot
.57507 .58976 Mdot
.71648 .67844 Mdot
.625 .64493 Mdot
.54195 .21477 Mdot
.43081 .72318 Mdot
.42958 .25459 Mdot
.5954 .53537 Mdot
.48644 .33369 Mdot
.47043 .54273 Mdot
.29465 .42422 Mdot
.75889 .59638 Mdot
.56664 .6031 Mdot
.74803 .46322 Mdot
.64549 .62157 Mdot
.46583 .29996 Mdot
.80161 .55098 Mdot
.28985 .379 Mdot
.19175 .59973 Mdot
.55237 .58618 Mdot
.67474 .35703 Mdot
.33788 .46912 Mdot
.49677 .53941 Mdot
.48924 .52851 Mdot
.30942 .55862 Mdot
.37099 .39461 Mdot
.54197 .54852 Mdot
.47249 .30646 Mdot
.57196 .63004 Mdot
.64603 .65909 Mdot
.46219 .19385 Mdot
.65174 .37301 Mdot
.43883 .31839 Mdot
.2164 .41402 Mdot
.60686 .61107 Mdot
.63508 .42165 Mdot
.65926 .39747 Mdot
.31968 .56043 Mdot
.43769 .25428 Mdot
.37271 .38403 Mdot
.75975 .70491 Mdot
.55665 .52914 Mdot
.28474 .41235 Mdot
.41917 .5354 Mdot
.65545 .63616 Mdot
.33519 .62589 Mdot
.45358 .33291 Mdot
.5696 .62053 Mdot
.75959 .44147 Mdot
.65793 .37996 Mdot
.59129 .60813 Mdot
.35318 .55017 Mdot
.80919 .37842 Mdot
.68963 .5924 Mdot
.72256 .65525 Mdot
.27752 .43113 Mdot
.55061 .62965 Mdot
.58599 .54346 Mdot
.4448 .54321 Mdot
.54112 .57023 Mdot
.30611 .38624 Mdot
.41522 .53812 Mdot
.34833 .55181 Mdot
.63634 .3737 Mdot
.47055 .5411 Mdot
.64464 .62067 Mdot
.54946 .63172 Mdot
.37125 .55944 Mdot
.65033 .64235 Mdot
.71081 .55867 Mdot
.43154 .54358 Mdot
.26143 .40017 Mdot
.62477 .37515 Mdot
.55303 .6305 Mdot
.49211 .538 Mdot
.59711 .59401 Mdot
.72899 .39079 Mdot
.56916 .62243 Mdot
.52621 .23531 Mdot
.6709 .39121 Mdot
.4814 .31445 Mdot
.62153 .5916 Mdot
.59575 .61399 Mdot
.41473 .54318 Mdot
.46067 .52989 Mdot
.56563 .58287 Mdot
.641 .42632 Mdot
.63196 .37908 Mdot
.67379 .35731 Mdot
.2537 .39887 Mdot
.40226 .70993 Mdot
.47157 .3195 Mdot
.4922 .5323 Mdot
.46846 .33618 Mdot
.67228 .70077 Mdot
.32161 .53758 Mdot
.4905 .21189 Mdot
.57671 .59741 Mdot
.66022 .40804 Mdot
.4501 .80717 Mdot
.65731 .42654 Mdot
.43878 .37031 Mdot
.45759 .3341 Mdot
.63852 .38674 Mdot
.56775 .59126 Mdot
.41391 .69502 Mdot
.72736 .67276 Mdot
.43734 .32967 Mdot
.50748 .5485 Mdot
.29347 .59134 Mdot
.27059 .42408 Mdot
.46692 .84607 Mdot
.48013 .3305 Mdot
.65409 .28076 Mdot
.60824 .65051 Mdot
.67533 .38128 Mdot
.45723 .32203 Mdot
.47841 .29334 Mdot
.28747 .37798 Mdot
.64412 .64395 Mdot
.59457 .6124 Mdot
.48933 .55448 Mdot
.45901 .32872 Mdot
.56522 .65219 Mdot
.63859 .65138 Mdot
.37626 .3534 Mdot
.67266 .35325 Mdot
.43985 .18045 Mdot
.57559 .71594 Mdot
.75935 .44289 Mdot
.39935 .21389 Mdot
.64132 .36389 Mdot
.55001 .6061 Mdot
.47371 .52904 Mdot
.26806 .3948 Mdot
.5701 .59482 Mdot
.32985 .42681 Mdot
.4584 .3025 Mdot
.54034 .2443 Mdot
.56059 .71417 Mdot
.40799 .35567 Mdot
.56058 .61053 Mdot
.68665 .58472 Mdot
.34255 .55676 Mdot
.45548 .28198 Mdot
.68539 .3761 Mdot
.55547 .62578 Mdot
.27594 .3814 Mdot
.26699 .42006 Mdot
.65424 .37915 Mdot
.63077 .29687 Mdot
.51768 .21081 Mdot
.45643 .52526 Mdot
.28146 .3853 Mdot
.48764 .53359 Mdot
.71006 .66409 Mdot
.4758 .33652 Mdot
.34692 .55164 Mdot
.28165 .42271 Mdot
.48942 .29599 Mdot
.59155 .6491 Mdot
.64723 .38213 Mdot
.6701 .4247 Mdot
.49118 .64063 Mdot
.32323 .41765 Mdot
.32872 .5391 Mdot
.49451 .62917 Mdot
.50029 .67935 Mdot
.33806 .54248 Mdot
.25087 .39473 Mdot
.62599 .39947 Mdot
.6653 .39305 Mdot
.64907 .40933 Mdot
.77873 .601 Mdot
.6612 .35032 Mdot
.31899 .65365 Mdot
.54177 .56978 Mdot
.70145 .59111 Mdot
.59051 .64407 Mdot
.45827 .2828 Mdot
.6615 .36549 Mdot
.43217 .72291 Mdot
.63188 .59973 Mdot
.72976 .67247 Mdot
.59622 .63175 Mdot
.49344 .59226 Mdot
.57948 .61257 Mdot
.65288 .51564 Mdot
.65804 .34732 Mdot
.54986 .58527 Mdot
.42996 .29981 Mdot
.34627 .53687 Mdot
.60821 .41556 Mdot
.55196 .59722 Mdot
.60253 .34305 Mdot
.60693 .5893 Mdot
.53708 .24141 Mdot
.48967 .62474 Mdot
.35407 .48059 Mdot
.57626 .63599 Mdot
.35203 .4172 Mdot
.6681 .64137 Mdot
.70729 .60798 Mdot
.44484 .33342 Mdot
.68931 .58368 Mdot
.34367 .40494 Mdot
.80266 .54889 Mdot
.45346 .52639 Mdot
.35212 .55573 Mdot
.41598 .53453 Mdot
.48476 .32133 Mdot
.57183 .59956 Mdot
.54795 .59949 Mdot
.51201 .58583 Mdot
.70543 .66696 Mdot
.44947 .54058 Mdot
.303 .55791 Mdot
.70032 .61525 Mdot
.56264 .58452 Mdot
.25416 .3722 Mdot
.65562 .42044 Mdot
.7933 .5479 Mdot
.79927 .53192 Mdot
.63254 .65317 Mdot
.64019 .38271 Mdot
.66272 .41349 Mdot
.38456 .8034 Mdot
.34577 .56266 Mdot
.5772 .62712 Mdot
.40131 .52789 Mdot
.65269 .62997 Mdot
.46019 .30691 Mdot
.58939 .57465 Mdot
.31269 .42039 Mdot
.40451 .68752 Mdot
.25169 .3986 Mdot
.60652 .63281 Mdot
.64739 .394 Mdot
.42995 .31901 Mdot
.27395 .43234 Mdot
.4371 .25498 Mdot
.31802 .65539 Mdot
.36983 .40127 Mdot
.31335 .5667 Mdot
.32823 .53216 Mdot
.45587 .28207 Mdot
.57977 .59195 Mdot
.4187 .72174 Mdot
.62879 .7165 Mdot
.57982 .60687 Mdot
.55361 .60589 Mdot
.50033 .3501 Mdot
.46361 .33361 Mdot
.30093 .43051 Mdot
.56922 .60617 Mdot
.54572 .61652 Mdot
.64313 .39185 Mdot
.32358 .57209 Mdot
.27248 .41032 Mdot
.31016 .54676 Mdot
.29873 .39002 Mdot
.49308 .8153 Mdot
.4336 .53093 Mdot
.32796 .53559 Mdot
.48389 .33022 Mdot
.65025 .41344 Mdot
.45763 .55033 Mdot
.29228 .40621 Mdot
.27588 .38583 Mdot
.57378 .6459 Mdot
.64024 .37156 Mdot
.6736 .39481 Mdot
.31103 .5498 Mdot
.44661 .31724 Mdot
.65481 .62129 Mdot
.46694 .52004 Mdot
.23332 .39925 Mdot
.26866 .38514 Mdot
.7013 .60719 Mdot
.64019 .44442 Mdot
.59964 .59752 Mdot
.64048 .42219 Mdot
.59365 .62083 Mdot
.68264 .33662 Mdot
.68126 .40995 Mdot
.55522 .57033 Mdot
.643 .68057 Mdot
.28944 .41584 Mdot
.3222 .78034 Mdot
.57476 .56745 Mdot
.42012 .33131 Mdot
.65371 .6362 Mdot
.16736 .57646 Mdot
.44187 .80343 Mdot
.58952 .58729 Mdot
.54802 .6117 Mdot
.73273 .74197 Mdot
.62712 .64264 Mdot
.49002 .54957 Mdot
.45133 .5268 Mdot
.63622 .42082 Mdot
.41132 .53812 Mdot
.41579 .70564 Mdot
.33841 .56636 Mdot
.2955 .39858 Mdot
.34518 .71991 Mdot
.31724 .54146 Mdot
.66227 .38275 Mdot
.65709 .62411 Mdot
.66275 .44062 Mdot
.32178 .38007 Mdot
.46477 .53827 Mdot
.462 .30147 Mdot
.41818 .71576 Mdot
.28043 .37952 Mdot
.4738 .32821 Mdot
.6215 .64193 Mdot
.33741 .44727 Mdot
.42656 .30122 Mdot
.33315 .78814 Mdot
.46201 .28827 Mdot
.47857 .32657 Mdot
.40878 .71406 Mdot
.33822 .56648 Mdot
.42557 .54498 Mdot
.5161 .54311 Mdot
.4306 .31393 Mdot
.21701 .62211 Mdot
.27979 .37739 Mdot
.38804 .71136 Mdot
.66289 .34637 Mdot
.43899 .53115 Mdot
.5565 .61 Mdot
.45351 .29078 Mdot
.57546 .65894 Mdot
.41367 .54275 Mdot
.47581 .29887 Mdot
.66497 .64418 Mdot
.38373 .67892 Mdot
.48821 .53706 Mdot
.46129 .55008 Mdot
.33048 .57723 Mdot
.26389 .46012 Mdot
.66344 .40899 Mdot
.35625 .57287 Mdot
.43602 .74433 Mdot
.59444 .6338 Mdot
.46415 .32374 Mdot
.46985 .54056 Mdot
.47809 .31974 Mdot
.33636 .55268 Mdot
.37308 .55594 Mdot
.64489 .3732 Mdot
.67647 .35981 Mdot
.46387 .55637 Mdot
.46655 .7441 Mdot
.63519 .61599 Mdot
.7446 .48001 Mdot
.68383 .40066 Mdot
.79674 .58136 Mdot
.3355 .56958 Mdot
.32473 .57158 Mdot
.6827 .61677 Mdot
.62684 .61227 Mdot
.49517 .58998 Mdot
.6076 .5859 Mdot
.21309 .60126 Mdot
.64216 .61669 Mdot
.27177 .39475 Mdot
.58876 .57784 Mdot
.69109 .30753 Mdot
.59237 .65386 Mdot
.55895 .58923 Mdot
.31068 .40087 Mdot
.56348 .63891 Mdot
.31316 .41691 Mdot
.55655 .61657 Mdot
.30452 .35479 Mdot
.29464 .39702 Mdot
.36805 .58895 Mdot
.50867 .62276 Mdot
.48005 .55095 Mdot
.32436 .55961 Mdot
.30892 .56208 Mdot
.34044 .69893 Mdot
.62722 .39298 Mdot
.78831 .4357 Mdot
.56449 .58718 Mdot
.275 .37857 Mdot
.4548 .30281 Mdot
.62348 .65625 Mdot
.61331 .6347 Mdot
.57463 .5676 Mdot
.63964 .37856 Mdot
.25889 .38276 Mdot
.33044 .55664 Mdot
.33704 .41405 Mdot
.2872 .35343 Mdot
.30567 .41955 Mdot
.62339 .69791 Mdot
.58595 .64821 Mdot
.58647 .54397 Mdot
.76392 .5184 Mdot
.36761 .53288 Mdot
.65022 .37974 Mdot
.47424 .54316 Mdot
.33291 .53204 Mdot
.41281 .66861 Mdot
.65514 .41615 Mdot
.27463 .39824 Mdot
.59912 .61171 Mdot
.42916 .53018 Mdot
.51711 .54493 Mdot
.61115 .40362 Mdot
.37122 .54474 Mdot
.29856 .404 Mdot
.48749 .5424 Mdot
.39912 .70768 Mdot
.81702 .48956 Mdot
.41564 .75243 Mdot
.59552 .61697 Mdot
.31189 .55053 Mdot
.63928 .37162 Mdot
.49999 .58412 Mdot
.44542 .29983 Mdot
.41398 .71238 Mdot
.55863 .60811 Mdot
.4368 .3759 Mdot
.64887 .3937 Mdot
.35471 .56476 Mdot
.45529 .28952 Mdot
.34941 .56214 Mdot
.50105 .5457 Mdot
.61245 .43994 Mdot
.48987 .52894 Mdot
.63201 .60359 Mdot
.45544 .30479 Mdot
.66707 .40488 Mdot
.31844 .35703 Mdot
.47284 .5619 Mdot
.27862 .39919 Mdot
.41829 .67259 Mdot
.63433 .37642 Mdot
.39097 .36782 Mdot
.33717 .41543 Mdot
.51171 .32958 Mdot
.43923 .69237 Mdot
.46642 .29386 Mdot
.55531 .59233 Mdot
.64605 .40591 Mdot
.43723 .32984 Mdot
.30722 .45837 Mdot
.75142 .65309 Mdot
.44908 .5536 Mdot
.61169 .6171 Mdot
.55079 .21239 Mdot
.66415 .28859 Mdot
.64335 .34349 Mdot
.48624 .325 Mdot
.57477 .61969 Mdot
.45399 .52488 Mdot
.55471 .58405 Mdot
.43325 .31943 Mdot
.51361 .29798 Mdot
.3247 .38942 Mdot
.60248 .61064 Mdot
.36167 .55377 Mdot
.3111 .42435 Mdot
.28686 .43302 Mdot
.27841 .42145 Mdot
.68453 .37435 Mdot
.4354 .535 Mdot
.44868 .52639 Mdot
.42382 .79234 Mdot
.48227 .31848 Mdot
.48002 .55075 Mdot
.54628 .6064 Mdot
.32094 .6566 Mdot
.65862 .4063 Mdot
.30336 .40701 Mdot
.57663 .62433 Mdot
.48986 .63595 Mdot
.45831 .54076 Mdot
.31374 .39553 Mdot
.6859 .39521 Mdot
.59966 .46592 Mdot
.57225 .59519 Mdot
.64955 .6337 Mdot
.66495 .37869 Mdot
.71169 .29259 Mdot
.39486 .70435 Mdot
.59167 .62014 Mdot
.47904 .32267 Mdot
.65899 .23879 Mdot
.61747 .64327 Mdot
.69932 .38788 Mdot
.49794 .55366 Mdot
.58659 .41523 Mdot
.70949 .57029 Mdot
.6175 .66616 Mdot
.5207 .43513 Mdot
.43937 .58973 Mdot
.54862 .46282 Mdot
.23799 .60861 Mdot
.44586 .43719 Mdot
.35665 .80683 Mdot
.46206 .27904 Mdot
.64447 .52197 Mdot
.84495 .61653 Mdot
.63743 .28711 Mdot
.40069 .45529 Mdot
.5112 .2812 Mdot
.29081 .5389 Mdot
.15086 .53542 Mdot
.35311 .43995 Mdot
.24086 .60541 Mdot
.63056 .60304 Mdot
.69941 .29152 Mdot
.6527 .53198 Mdot
.36991 .43963 Mdot
.4152 .26453 Mdot
.49147 .62837 Mdot
.68034 .76028 Mdot
.40973 .34637 Mdot
.55907 .82771 Mdot
.7702 .43695 Mdot
.24338 .42491 Mdot
.46916 .68671 Mdot
.32592 .7064 Mdot
.675 .56135 Mdot
.56763 .4372 Mdot
.44422 .27877 Mdot
.67752 .46432 Mdot
.41235 .20731 Mdot
.28164 .39087 Mdot
.61312 .40296 Mdot
.5365 .34258 Mdot
.63002 .79347 Mdot
.43806 .359 Mdot
.51894 .43573 Mdot
.47491 .56161 Mdot
.64965 .51677 Mdot
.43695 .7221 Mdot
.64137 .50349 Mdot
.3792 .39445 Mdot
.15346 .53605 Mdot
.65721 .45018 Mdot
.30249 .46243 Mdot
.39183 .65882 Mdot
.38881 .45706 Mdot
.67641 .52572 Mdot
.32637 .52466 Mdot
.3633 .59029 Mdot
.68594 .3976 Mdot
.67501 .74342 Mdot
.5509 .69437 Mdot
.44206 .74426 Mdot
.35326 .44238 Mdot
.71038 .40807 Mdot
.80229 .37686 Mdot
.64499 .29863 Mdot
.27987 .74555 Mdot
.59656 .82808 Mdot
.25374 .66309 Mdot
.51513 .6044 Mdot
.44694 .36287 Mdot
.34391 .63677 Mdot
.51353 .46669 Mdot
.26951 .69518 Mdot
.72949 .3869 Mdot
.71808 .72887 Mdot
.57888 .34973 Mdot
.64011 .80357 Mdot
.64043 .45966 Mdot
.5572 .54772 Mdot
.60796 .37212 Mdot
.61991 .49421 Mdot
.40441 .76433 Mdot
.65537 .78405 Mdot
.36567 .45231 Mdot
.51167 .55997 Mdot
.62432 .28978 Mdot
.70901 .55822 Mdot
.382 .38199 Mdot
.36388 .58303 Mdot
.78152 .51718 Mdot
.68115 .76969 Mdot
.53292 .43054 Mdot
.62702 .76921 Mdot
.37201 .35214 Mdot
.25937 .31743 Mdot
.29952 .43672 Mdot
.49746 .32429 Mdot
.57805 .82502 Mdot
.65152 .40328 Mdot
.31184 .77878 Mdot
.44855 .44642 Mdot
.43265 .46902 Mdot
.68558 .76575 Mdot
.25945 .70803 Mdot
.69263 .5675 Mdot
.40971 .56062 Mdot
.45478 .21524 Mdot
.57359 .48421 Mdot
.39861 .35881 Mdot
.31914 .59812 Mdot
.54006 .22904 Mdot
.59668 .8155 Mdot
.24722 .67627 Mdot
.77155 .69431 Mdot
.45029 .73711 Mdot
.27093 .59655 Mdot
.6653 .44442 Mdot
.46391 .40558 Mdot
.39485 .38269 Mdot
.62914 .81238 Mdot
.69033 .59752 Mdot
.61535 .21268 Mdot
.24395 .62222 Mdot
.80416 .53355 Mdot
.58429 .23514 Mdot
.5304 .35394 Mdot
.61052 .49172 Mdot
.60483 .33813 Mdot
.46602 .51497 Mdot
.38982 .75322 Mdot
.7794 .49578 Mdot
.35096 .47726 Mdot
.40349 .6976 Mdot
.57688 .3249 Mdot
.29486 .70355 Mdot
.63236 .23458 Mdot
.7846 .50857 Mdot
.6456 .43439 Mdot
.27034 .69441 Mdot
.24353 .63549 Mdot
.59842 .21617 Mdot
.21835 .41877 Mdot
.62194 .77409 Mdot
.42298 .38199 Mdot
.63102 .66856 Mdot
.64316 .52373 Mdot
.67342 .55625 Mdot
.17039 .55918 Mdot
.62858 .69098 Mdot
.37636 .79137 Mdot
.40747 .30335 Mdot
.75766 .53951 Mdot
.35296 .75408 Mdot
.76335 .52973 Mdot
.71129 .59355 Mdot
.67626 .32082 Mdot
.41239 .30416 Mdot
.60195 .68115 Mdot
.68585 .76113 Mdot
.30412 .42888 Mdot
.26778 .6963 Mdot
.42445 .35572 Mdot
.28741 .44572 Mdot
.411 .46919 Mdot
.3955 .47031 Mdot
.52172 .84318 Mdot
.61068 .2912 Mdot
.28491 .55507 Mdot
.60338 .44799 Mdot
.47944 .45263 Mdot
.75006 .48483 Mdot
.59387 .71277 Mdot
.71838 .39751 Mdot
.37058 .55295 Mdot
.76069 .57446 Mdot
.60458 .35369 Mdot
.21596 .4242 Mdot
.62729 .70124 Mdot
.47486 .68736 Mdot
.48709 .55677 Mdot
.35304 .68812 Mdot
.48667 .81613 Mdot
.6139 .67158 Mdot
.26771 .71465 Mdot
.6277 .29361 Mdot
.35227 .69396 Mdot
.39391 .38522 Mdot
.79349 .44002 Mdot
.64345 .80182 Mdot
.45162 .83692 Mdot
.71558 .30452 Mdot
.57363 .22821 Mdot
.1836 .37928 Mdot
.421 .26566 Mdot
.33704 .77817 Mdot
.42484 .35599 Mdot
.71271 .20783 Mdot
.32212 .43062 Mdot
.32561 .62674 Mdot
.646 .46758 Mdot
.47079 .66875 Mdot
.65277 .77506 Mdot
.68942 .5516 Mdot
.38061 .55328 Mdot
.61917 .36093 Mdot
.63516 .68184 Mdot
.67426 .75684 Mdot
.69635 .74194 Mdot
.68058 .74711 Mdot
.51401 .35771 Mdot
.72866 .64396 Mdot
.71358 .7532 Mdot
.32552 .64639 Mdot
.54403 .66303 Mdot
.63091 .66279 Mdot
.45505 .76081 Mdot
.31918 .75932 Mdot
.34643 .52264 Mdot
.5772 .4856 Mdot
.65545 .45046 Mdot
.69849 .76679 Mdot
.47235 .81742 Mdot
.63445 .50254 Mdot
.52885 .83677 Mdot
.27497 .55326 Mdot
.37124 .77178 Mdot
.49009 .84037 Mdot
.55154 .43077 Mdot
.48553 .37227 Mdot
.71341 .76417 Mdot
.25725 .64743 Mdot
.5137 .28526 Mdot
.60329 .34553 Mdot
.3175 .76488 Mdot
.57422 .2367 Mdot
.52633 .30815 Mdot
.64836 .46344 Mdot
.8142 .44904 Mdot
.4034 .43587 Mdot
.57076 .44211 Mdot
.50864 .59679 Mdot
.34922 .75686 Mdot
.33203 .42972 Mdot
.28626 .71415 Mdot
.39867 .41143 Mdot
.55115 .66277 Mdot
.35639 .71918 Mdot
.23401 .64704 Mdot
.5649 .38007 Mdot
.71994 .66212 Mdot
.61939 .29483 Mdot
.65037 .2397 Mdot
.59735 .22978 Mdot
.78376 .4678 Mdot
.55873 .63548 Mdot
.63668 .79034 Mdot
.3912 .83284 Mdot
.4987 .84384 Mdot
.61241 .22195 Mdot
.24944 .33723 Mdot
.48692 .28893 Mdot
.33035 .65603 Mdot
.47289 .65449 Mdot
.53368 .40398 Mdot
.45254 .58701 Mdot
.47075 .34139 Mdot
.8032 .37467 Mdot
.41888 .46607 Mdot
.32768 .64832 Mdot
.69157 .45516 Mdot
.46585 .46024 Mdot
.70912 .66695 Mdot
.64916 .434 Mdot
.5773 .2035 Mdot
.27229 .69785 Mdot
.29664 .42707 Mdot
.22996 .39422 Mdot
.59461 .68788 Mdot
.5634 .5494 Mdot
.28804 .5914 Mdot
.57359 .66525 Mdot
.75953 .44569 Mdot
.24415 .34373 Mdot
.4215 .81485 Mdot
.31965 .77604 Mdot
.4854 .84 Mdot
.24881 .65742 Mdot
.29386 .45267 Mdot
.36125 .69518 Mdot
.46132 .35154 Mdot
.41425 .33916 Mdot
.37202 .67858 Mdot
.23804 .64284 Mdot
.69569 .57223 Mdot
.61737 .35999 Mdot
.57954 .65571 Mdot
.4569 .80899 Mdot
.3173 .68759 Mdot
.3581 .67398 Mdot
.80299 .47307 Mdot
.69089 .36088 Mdot
.28045 .61242 Mdot
.57974 .43828 Mdot
.66814 .62856 Mdot
.57657 .22405 Mdot
.4425 .33458 Mdot
.65972 .42998 Mdot
.23341 .648 Mdot
.20642 .3613 Mdot
.52427 .45983 Mdot
.55117 .70267 Mdot
.60161 .80758 Mdot
.50971 .64624 Mdot
.55902 .23443 Mdot
.82803 .45758 Mdot
.39523 .31634 Mdot
.65393 .4544 Mdot
.53783 .64805 Mdot
.40529 .47473 Mdot
.71962 .32188 Mdot
.61936 .42309 Mdot
.6854 .58836 Mdot
.57547 .83174 Mdot
.49522 .6192 Mdot
.56243 .446 Mdot
.40212 .73326 Mdot
.43567 .41084 Mdot
.46222 .4479 Mdot
.35303 .72156 Mdot
.5366 .45137 Mdot
.65433 .74728 Mdot
.80417 .35703 Mdot
.58693 .49104 Mdot
.29696 .62468 Mdot
.33213 .6507 Mdot
.77047 .43575 Mdot
.67226 .52188 Mdot
.40337 .31083 Mdot
.62272 .5945 Mdot
.56371 .842 Mdot
.57965 .33696 Mdot
.35455 .70773 Mdot
.46549 .38339 Mdot
.63387 .64433 Mdot
.55486 .54538 Mdot
.50111 .84167 Mdot
.5846 .411 Mdot
.87293 .58084 Mdot
.22958 .61044 Mdot
.71883 .34718 Mdot
.70707 .57284 Mdot
.27732 .7223 Mdot
.70482 .32685 Mdot
.46501 .43863 Mdot
.40362 .40475 Mdot
.30396 .74809 Mdot
.58401 .38848 Mdot
.58257 .41736 Mdot
.5677 .21138 Mdot
.71621 .7458 Mdot
.56845 .47148 Mdot
.51544 .33355 Mdot
.27524 .5599 Mdot
.60007 .63733 Mdot
.63462 .29592 Mdot
.49754 .2088 Mdot
.48118 .38603 Mdot
.5549 .47259 Mdot
.38744 .83367 Mdot
.65662 .66247 Mdot
.60717 .29872 Mdot
.86856 .58754 Mdot
.89054 .55818 Mdot
.67434 .30856 Mdot
.61894 .82004 Mdot
.58695 .42684 Mdot
.55918 .23728 Mdot
.41875 .29891 Mdot
.50738 .68872 Mdot
.74592 .47024 Mdot
.5263 .8509 Mdot
.21149 .35062 Mdot
.39746 .35954 Mdot
.67165 .45889 Mdot
.52175 .85294 Mdot
.65194 .66677 Mdot
.30039 .62114 Mdot
.26172 .31701 Mdot
.19543 .60568 Mdot
.27873 .74092 Mdot
.80866 .46762 Mdot
.16931 .56407 Mdot
.22252 .58154 Mdot
.37573 .44661 Mdot
.32404 .77591 Mdot
.54345 .53222 Mdot
.80486 .44003 Mdot
.26907 .69162 Mdot
.55711 .22205 Mdot
.16763 .44318 Mdot
.47114 .44693 Mdot
.55589 .65656 Mdot
.66737 .31628 Mdot
.53733 .23103 Mdot
.55751 .33396 Mdot
.52601 .65885 Mdot
.41992 .67849 Mdot
.70922 .59814 Mdot
.65499 .23378 Mdot
.8377 .46671 Mdot
.54689 .64598 Mdot
.70579 .72581 Mdot
.40565 .33572 Mdot
.37321 .66223 Mdot
.69302 .5409 Mdot
.32625 .68253 Mdot
.28114 .56644 Mdot
.59793 .58238 Mdot
.58249 .82861 Mdot
.28152 .56789 Mdot
.69556 .73477 Mdot
.31209 .78244 Mdot
.54301 .83017 Mdot
.44002 .4723 Mdot
.29762 .59153 Mdot
.31556 .75154 Mdot
.32081 .75464 Mdot
.7296 .71405 Mdot
.24439 .60166 Mdot
.37767 .67542 Mdot
.51898 .63378 Mdot
.55871 .71133 Mdot
.6727 .68541 Mdot
.28039 .72638 Mdot
.77837 .42035 Mdot
.35319 .75071 Mdot
.7163 .3085 Mdot
.2367 .64611 Mdot
.68956 .56124 Mdot
.33137 .68725 Mdot
.44951 .39275 Mdot
.38982 .57255 Mdot
.28106 .37624 Mdot
.76028 .71617 Mdot
.59098 .21782 Mdot
.39654 .79373 Mdot
.60747 .21099 Mdot
.60033 .34161 Mdot
.22654 .59663 Mdot
.60297 .38368 Mdot
.56683 .50174 Mdot
.2512 .43519 Mdot
.31058 .71252 Mdot
.69499 .59601 Mdot
.54223 .21389 Mdot
.80823 .51273 Mdot
.53125 .84427 Mdot
.35599 .75847 Mdot
.79384 .67475 Mdot
.2741 .58964 Mdot
.76126 .57004 Mdot
.6727 .74168 Mdot
.68701 .26582 Mdot
.35703 .66766 Mdot
.68921 .75586 Mdot
.64157 .34932 Mdot
.60218 .82554 Mdot
.44901 .29998 Mdot
.28478 .6068 Mdot
.52126 .21467 Mdot
.34383 .66461 Mdot
.34545 .66255 Mdot
.40438 .80536 Mdot
.61787 .29168 Mdot
.65168 .2947 Mdot
.42124 .38139 Mdot
.34885 .44156 Mdot
.53654 .70654 Mdot
.5521 .44348 Mdot
.76547 .69833 Mdot
.55758 .63365 Mdot
.25927 .57995 Mdot
.26745 .70373 Mdot
.46569 .3515 Mdot
.52331 .61343 Mdot
.53592 .21864 Mdot
.82566 .47529 Mdot
.40649 .77607 Mdot
.70923 .75133 Mdot
.52246 .61008 Mdot
.46808 .63884 Mdot
.80807 .55331 Mdot
.5296 .30105 Mdot
.39896 .3327 Mdot
.52777 .4382 Mdot
.51768 .66677 Mdot
.39485 .70772 Mdot
.25235 .65659 Mdot
.37227 .82148 Mdot
.71567 .72035 Mdot
.39843 .32969 Mdot
.34981 .67148 Mdot
.70097 .38467 Mdot
.319 .71295 Mdot
.78743 .68363 Mdot
.15782 .55724 Mdot
.60358 .34413 Mdot
.24173 .65731 Mdot
.51931 .36057 Mdot
.30245 .62352 Mdot
.3645 .67611 Mdot
.67017 .74502 Mdot
.64256 .47287 Mdot
.59173 .42485 Mdot
.53212 .35881 Mdot
.42115 .70779 Mdot
.42224 .4553 Mdot
.80448 .45057 Mdot
.61421 .28763 Mdot
.79522 .67307 Mdot
.21049 .57827 Mdot
.80021 .54499 Mdot
.83009 .63373 Mdot
.68863 .38854 Mdot
.41396 .45676 Mdot
.28004 .29688 Mdot
.34931 .68718 Mdot
.27924 .42631 Mdot
.5675 .65343 Mdot
.39922 .67316 Mdot
.70883 .31371 Mdot
.28711 .5394 Mdot
.35935 .53746 Mdot
.64894 .43212 Mdot
.22959 .58936 Mdot
.66187 .42945 Mdot
.37023 .81791 Mdot
.54981 .42504 Mdot
.70597 .59764 Mdot
.83772 .49501 Mdot
.28685 .4528 Mdot
.6631 .24716 Mdot
.55342 .82992 Mdot
.45109 .75616 Mdot
.61479 .4183 Mdot
.61597 .43415 Mdot
.61462 .45255 Mdot
.48541 .34359 Mdot
.61459 .79783 Mdot
.26045 .70573 Mdot
.23159 .39919 Mdot
.62238 .36706 Mdot
.51111 .61228 Mdot
.58735 .66915 Mdot
.43772 .81738 Mdot
.33487 .41583 Mdot
.66024 .79256 Mdot
.78396 .42743 Mdot
.68751 .27622 Mdot
.54014 .3936 Mdot
.48069 .70497 Mdot
.3642 .65297 Mdot
.31507 .46774 Mdot
.63271 .66716 Mdot
.7078 .34131 Mdot
.6692 .35778 Mdot
.41543 .46216 Mdot
.34923 .57165 Mdot
.21876 .42718 Mdot
.43276 .34015 Mdot
.77519 .46543 Mdot
.27614 .72753 Mdot
.642 .43666 Mdot
.28754 .59696 Mdot
.29547 .46602 Mdot
.63621 .69484 Mdot
.4757 .7524 Mdot
.7457 .73367 Mdot
.57845 .81664 Mdot
.6477 .42863 Mdot
.64578 .2407 Mdot
.33504 .36053 Mdot
.41958 .81305 Mdot
.59094 .37288 Mdot
.27776 .71651 Mdot
.77637 .52869 Mdot
.47383 .83323 Mdot
.70865 .56949 Mdot
.52501 .42427 Mdot
.25632 .68138 Mdot
.39842 .52661 Mdot
.23912 .65996 Mdot
.8267 .49137 Mdot
.5282 .69084 Mdot
.2042 .6145 Mdot
.48988 .3804 Mdot
.63772 .50721 Mdot
.65994 .61983 Mdot
.53293 .40816 Mdot
.30365 .74405 Mdot
.67852 .39931 Mdot
.30376 .52694 Mdot
.70562 .44015 Mdot
.39788 .35523 Mdot
.59247 .8169 Mdot
.61139 .22538 Mdot
.25679 .69502 Mdot
.56057 .70975 Mdot
.2919 .67047 Mdot
.77573 .42178 Mdot
.4512 .74333 Mdot
.44661 .52035 Mdot
.77834 .50756 Mdot
.41335 .54794 Mdot
.43341 .79986 Mdot
.66634 .68981 Mdot
.6532 .78027 Mdot
.47568 .81425 Mdot
.66292 .31398 Mdot
.46338 .56252 Mdot
.6119 .38465 Mdot
.66702 .78267 Mdot
.41444 .78096 Mdot
.5332 .22596 Mdot
.27817 .73903 Mdot
.24704 .59444 Mdot
.83922 .62311 Mdot
.5968 .30222 Mdot
.58149 .67572 Mdot
.32895 .78193 Mdot
.58129 .34246 Mdot
.22539 .5817 Mdot
.69472 .59815 Mdot
.66598 .44127 Mdot
.68909 .76203 Mdot
.5513 .518 Mdot
.6416 .30399 Mdot
.70288 .68692 Mdot
.65804 .45376 Mdot
.4191 .78121 Mdot
.52756 .60681 Mdot
.27223 .39908 Mdot
.47436 .67715 Mdot
.16515 .55131 Mdot
.62955 .46821 Mdot
.27306 .71663 Mdot
.28191 .71868 Mdot
.27237 .6202 Mdot
.31023 .47456 Mdot
.8403 .62097 Mdot
.73491 .63065 Mdot
.53225 .60965 Mdot
.63303 .42905 Mdot
.34157 .53166 Mdot
.25003 .62434 Mdot
.63949 .64147 Mdot
.47542 .71783 Mdot
.77989 .52093 Mdot
.54628 .84713 Mdot
.45421 .40182 Mdot
.44537 .27416 Mdot
.6334 .35615 Mdot
.53697 .22826 Mdot
.72821 .34044 Mdot
.64825 .2835 Mdot
.30191 .74044 Mdot
.52559 .45999 Mdot
.52172 .43212 Mdot
.63306 .31191 Mdot
.28352 .69836 Mdot
.38511 .41996 Mdot
.42526 .31058 Mdot
.75524 .45378 Mdot
.75087 .7015 Mdot
.6062 .32883 Mdot
.48564 .44736 Mdot
.56742 .41143 Mdot
.51805 .67794 Mdot
.39753 .366 Mdot
.62058 .29321 Mdot
.62475 .44328 Mdot
.64939 .75571 Mdot
.57573 .46379 Mdot
.29493 .59232 Mdot
.23722 .62522 Mdot
.55963 .41763 Mdot
.28358 .7255 Mdot
.64424 .68029 Mdot
.67474 .74962 Mdot
.35275 .70524 Mdot
.30819 .51887 Mdot
.58883 .65655 Mdot
.7209 .40758 Mdot
.4996 .84189 Mdot
.58991 .36508 Mdot
.54249 .47473 Mdot
.59979 .42996 Mdot
.30398 .76952 Mdot
.33548 .58966 Mdot
.24856 .34187 Mdot
.40595 .56172 Mdot
.47637 .70243 Mdot
.4703 .65792 Mdot
.48256 .34574 Mdot
.64665 .66528 Mdot
.38435 .44928 Mdot
.52557 .67857 Mdot
.75817 .45425 Mdot
.36334 .78498 Mdot
.75859 .7142 Mdot
.71235 .4028 Mdot
.27252 .73986 Mdot
.70239 .4304 Mdot
.68976 .42528 Mdot
.21304 .57803 Mdot
.54344 .47891 Mdot
.63111 .68965 Mdot
.30411 .52338 Mdot
.69006 .38059 Mdot
.75654 .71103 Mdot
.54965 .47 Mdot
.31709 .52262 Mdot
.37957 .37275 Mdot
.4587 .45051 Mdot
.39344 .20836 Mdot
.41299 .3277 Mdot
.31379 .77822 Mdot
.26968 .69581 Mdot
.41486 .29861 Mdot
.58638 .4239 Mdot
.55344 .47907 Mdot
.67135 .75654 Mdot
.42302 .5528 Mdot
.57047 .82408 Mdot
.5127 .359 Mdot
.7705 .47376 Mdot
.47249 .81171 Mdot
.39357 .75799 Mdot
.44628 .7477 Mdot
.79391 .49269 Mdot
.61088 .77172 Mdot
.45022 .54854 Mdot
.22098 .41455 Mdot
.16115 .46356 Mdot
.77498 .69351 Mdot
.69239 .27782 Mdot
.52922 .55421 Mdot
.32517 .7179 Mdot
.57436 .45875 Mdot
.3782 .66135 Mdot
.40774 .38343 Mdot
.28953 .59383 Mdot
.51946 .347 Mdot
.63949 .22726 Mdot
.56296 .84139 Mdot
.61274 .66047 Mdot
.4457 .58122 Mdot
.36782 .44362 Mdot
.31088 .43483 Mdot
.65821 .48603 Mdot
.74452 .73231 Mdot
.42654 .31592 Mdot
.28777 .28787 Mdot
.46277 .348 Mdot
.40985 .80376 Mdot
.22939 .34458 Mdot
.50891 .32822 Mdot
.3673 .81774 Mdot
.70197 .30106 Mdot
.81875 .50394 Mdot
.61309 .21004 Mdot
.44323 .80553 Mdot
.77672 .50401 Mdot
.32319 .60015 Mdot
.61376 .81355 Mdot
.3624 .65668 Mdot
.28228 .55385 Mdot
.62504 .76555 Mdot
.25141 .6755 Mdot
.23234 .61568 Mdot
.47373 .25676 Mdot
.66987 .45676 Mdot
.19733 .36974 Mdot
.26258 .43531 Mdot
.81266 .35071 Mdot
.57916 .81492 Mdot
.76313 .64479 Mdot
.59148 .36632 Mdot
.43534 .38435 Mdot
.66616 .76134 Mdot
.29221 .72605 Mdot
.61189 .47836 Mdot
.2193 .4008 Mdot
.37821 .74633 Mdot
.31511 .70084 Mdot
.4763 .37694 Mdot
.50143 .83559 Mdot
.30673 .46489 Mdot
.56579 .53177 Mdot
.26086 .6928 Mdot
.71684 .41725 Mdot
.45732 .73438 Mdot
.74635 .70419 Mdot
.46753 .75859 Mdot
.22839 .62927 Mdot
.51628 .35665 Mdot
.26992 .35456 Mdot
.756 .70375 Mdot
.72417 .34547 Mdot
.78116 .53862 Mdot
.86943 .58485 Mdot
.63913 .80387 Mdot
.55638 .48162 Mdot
.59686 .5769 Mdot
.3508 .80336 Mdot
.30242 .37045 Mdot
.38432 .78943 Mdot
.80197 .37895 Mdot
.22258 .60312 Mdot
.66127 .69565 Mdot
.62933 .60334 Mdot
.32694 .64176 Mdot
.64917 .31946 Mdot
.65522 .46361 Mdot
.30101 .44716 Mdot
.23839 .64178 Mdot
.77657 .4615 Mdot
.80407 .35723 Mdot
.82502 .48351 Mdot
.62473 .41391 Mdot
.59548 .82356 Mdot
.57687 .51984 Mdot
.77442 .43217 Mdot
.66658 .75413 Mdot
.46381 .59612 Mdot
.38486 .4396 Mdot
.77324 .42062 Mdot
.35916 .69187 Mdot
.16262 .54475 Mdot
.82719 .64007 Mdot
.75295 .47279 Mdot
.6672 .78796 Mdot
.4542 .8392 Mdot
.61602 .40476 Mdot
.64614 .47762 Mdot
.35793 .64801 Mdot
.55909 .46471 Mdot
.52768 .31885 Mdot
.28221 .44383 Mdot
.24118 .58821 Mdot
.22519 .44428 Mdot
.58792 .58534 Mdot
.49839 .37192 Mdot
.53732 .84166 Mdot
.2938 .61629 Mdot
.55086 .83823 Mdot
.78429 .48091 Mdot
.55913 .63933 Mdot
.89114 .5546 Mdot
.55655 .23675 Mdot
.60685 .70983 Mdot
.50868 .53602 Mdot
.52458 .55607 Mdot
.58599 .5794 Mdot
.51299 .29113 Mdot
.32642 .66473 Mdot
.20788 .59562 Mdot
.61552 .81004 Mdot
.63287 .36037 Mdot
.36127 .65369 Mdot
.42753 .29308 Mdot
.44185 .69781 Mdot
.67599 .6905 Mdot
.42657 .32314 Mdot
.19142 .57754 Mdot
.3905 .21081 Mdot
.39171 .39879 Mdot
.42607 .45348 Mdot
.41872 .68128 Mdot
.48065 .56068 Mdot
.20389 .57834 Mdot
.49119 .34441 Mdot
.3755 .43963 Mdot
.25452 .6908 Mdot
.79684 .50356 Mdot
.4698 .37651 Mdot
.18866 .40461 Mdot
.35958 .66965 Mdot
.49938 .3729 Mdot
.57593 .48997 Mdot
.81954 .45262 Mdot
.6385 .77074 Mdot
.37326 .39868 Mdot
.45203 .55054 Mdot
.80562 .55947 Mdot
.64942 .7784 Mdot
.49238 .31177 Mdot
.38372 .82545 Mdot
.56126 .49032 Mdot
.66458 .48323 Mdot
.74293 .66616 Mdot
.52572 .62717 Mdot
.69033 .58801 Mdot
.52668 .57467 Mdot
.45618 .65127 Mdot
.36964 .2116 Mdot
.53515 .63439 Mdot
.4468 .45333 Mdot
.52386 .45431 Mdot
.29188 .6241 Mdot
.68292 .6255 Mdot
.58618 .63016 Mdot
.36411 .57995 Mdot
.36907 .71173 Mdot
.29792 .60907 Mdot
.2779 .59998 Mdot
.48063 .37349 Mdot
.20356 .57975 Mdot
.2309 .61152 Mdot
.70537 .66271 Mdot
.6752 .76162 Mdot
.66334 .62538 Mdot
.57192 .81805 Mdot
.41784 .40604 Mdot
.56041 .33281 Mdot
.47197 .75365 Mdot
.82319 .6441 Mdot
.69278 .33667 Mdot
.6171 .55101 Mdot
.43827 .8308 Mdot
.52616 .83875 Mdot
.40882 .35585 Mdot
.55696 .21697 Mdot
.15474 .48696 Mdot
.34732 .654 Mdot
.64686 .23069 Mdot
.23439 .39285 Mdot
.43344 .82229 Mdot
.53707 .68267 Mdot
.55225 .48308 Mdot
.79644 .45279 Mdot
.62738 .69738 Mdot
.32734 .40343 Mdot
.82711 .45691 Mdot
.79529 .49258 Mdot
.60747 .773 Mdot
.53273 .59901 Mdot
.50403 .40628 Mdot
.69833 .39228 Mdot
.77885 .68711 Mdot
.24431 .39379 Mdot
.46754 .63466 Mdot
.81157 .37 Mdot
.37722 .2096 Mdot
.22634 .57975 Mdot
.72511 .71481 Mdot
.41291 .3339 Mdot
.52222 .67378 Mdot
.46605 .19414 Mdot
.70328 .36549 Mdot
.62695 .42873 Mdot
.43461 .34034 Mdot
.29803 .67407 Mdot
.61437 .30237 Mdot
.85354 .60948 Mdot
.46904 .83293 Mdot
.64193 .68614 Mdot
.79905 .31824 Mdot
.26364 .69719 Mdot
.45726 .61252 Mdot
.60745 .29407 Mdot
.57946 .82891 Mdot
.5216 .33764 Mdot
.33431 .78825 Mdot
.56107 .43123 Mdot
.62914 .46623 Mdot
.31118 .68796 Mdot
.60996 .21382 Mdot
.5155 .61786 Mdot
.80412 .34424 Mdot
.57907 .22214 Mdot
.32636 .70726 Mdot
.58124 .38167 Mdot
.70986 .38975 Mdot
.7155 .35101 Mdot
.54778 .39538 Mdot
.51886 .46891 Mdot
.48854 .44727 Mdot
.52931 .43229 Mdot
.38651 .41765 Mdot
.53103 .39371 Mdot
.5491 .23719 Mdot
.46368 .35854 Mdot
.80741 .47761 Mdot
.15357 .51161 Mdot
.27534 .5947 Mdot
.33403 .42721 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo08_ooooo
0_l0002looooo`007?ooool00ol0003oooooooooo`2;ooooo`Go0000^Oooool001cooooo00?o0000
ooooooooool0S?ooool6o`000;Oooooo000Looooo`03o`000?oooooooooo08kooooo1?l0002goooo
o`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000
ooooooooool0T?ooool4o`000;Gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ
8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`2Aooooo`Oo0000
/Oooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^
kP07ooooo`03o`000?oooooooooo09Cooooo1?l0000Pooooo`;o0000Soooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06ooooo`?o0000U_ooool3
o`0001oooooo0_l0002?ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<oooo
o`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0Uoooool3o`000003ooooool0003o0000
00;o000000?oooooo`000?l000000_ooool2o`0001;ooooo0_l0002?ooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0O?ooool2o`0000Cooooo0_l0000Dooooo`;o000000?oooooo`000?l000001Ol00002ooooo`;o
00003_ooool2o`0000;ooooo0_l0000Zooooo`;o0000Hoooool00006oooooomgMgOoV9RHoooooonH
V9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0M?ooool2
o`000003ooooool0003o000000;ooooo0ol00004ooooo`;o00001Oooool4o`0000oooooo2ol00002
ooooo`;o00000_ooool2o`0000?ooooo1Ol0000;ooooo`Go00007Oooool2o`0006?ooooo00001_oo
ooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`00
0?oooooooooo07Cooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l00000
2Oooool4o`0000;ooooo0ol0000:ooooo`;o000000?oooooo`000?l000004?l000001?oooooo0000
o`000?ooool2o`0000_ooooo1Ol00022ooooo`007?ooool00ol0003oooooooooo`1nooooo`;o0000
3Oooool5o`0000_ooooo0_l00007ooooo`go00002Oooool2o`000004ooooool0003o0000ooooo`Co
0000Poooool001cooooo00?o0000ooooooooool0Koooool4o`0001[ooooo0_l00006ooooo`;o0000
1_ooool2o`0000_ooooo0_l00005ooooo`;o00002Oooool2o`000003ooooool0003o000008Sooooo
000Looooo`03o`000?oooooooooo06oooooo1?l0000Oooooo`Go00004oooool2o`0000Gooooo0_l0
0005ooooo`;o00002Oooool2o`0008Cooooo000Looooo`03o`000?oooooooooo09;ooooo1?l0000C
ooooo`;o00001_ooool2o`0000Gooooo0_l00009ooooo`;o00001oooool2o`0007_ooooo000Loooo
o`03o`000?oooooooooo0:Wooooo1Ol00009ooooo`;o00001Oooool2o`0000?ooooo0_l00007oooo
o`Go0000N?ooool001cooooo00?o0000ooooooooool0JOooool2o`00043ooooo0ol00009ooooo`;o
00001Oooool2o`0000Oooooo0_l00005ooooo`Go0000M_ooool001cooooo00?o0000ooooooooool0
JOooool2o`0003cooooo0_l00002ooooo`;o00001?ooool3o`0000?ooooo0_l000000ooooooo0000
o`00000;ooooo`;o000000?oooooo`000?l000001Oooool2o`0001[ooooo0_l0001Jooooo`007?oo
ool00ol0003oooooooooo`2Wooooo`;o00001_ooool5o`0000?ooooo0_l000000ooooooo0000o`00
000>ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`00000Iooooo`;o0000F_oo
ool001cooooo00?o0000ooooooooool0Yoooool2o`0000;ooooo0_l00002ooooo`;o000000?ooooo
o`000?l000006Oooool4o`000003ooooool0003o000001[ooooo0_l0001Iooooo`007?ooool00ol0
003oooooooooo`2[ooooo`?o00000oooool4o`0001Wooooo0_l0000Nooooo`;o0000FOooool001co
oooo00?o0000ooooooooool0I?ooool2o`0003_ooooo0_l00009ooooo`;o00000oooool4o`0001oo
oooo0_l000001?oooooo0000o`000?l0000Eooooo`;o0000F?ooool001cooooo0_l0001Uooooo`;o
00008oooool8o`00013ooooo0_l0000aooooo`;o000000Coooooo`000?l0003o00005Oooool3o`00
05Oooooo000Looooo`03o`000?oooooooooo08Kooooo2ol00003ooooo`;o0000F_ooool2o`0005Oo
oooo000Looooo`03o`000?oooooooooo08Gooooo2_l000000ooooooo0000o`000002ooooo`Co0000
F?ooool3o`0005Kooooo000Looooo`03o`000?oooooooooo08?ooooo1_l00007ooooo`;o00001?oo
ool2o`0005Wooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`23ooooo`?o0000Joooool2
o`0005Kooooo000Looooo`03o`000?oooooooooo08;ooooo1Ol0000Eooooo`;o0000?Oooool4o`00
01?ooooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`22ooooo`Go00005Oooool4o`0003_o
oooo1?l0000Cooooo`;o0000EOooool001cooooo00?o0000ooooooooool0Poooool3o`0000[ooooo
0_l0000<ooooo`?o0000D_ooool2o`0005Cooooo000Looooo`03o`000?oooooooooo083ooooo1Ol0
0008ooooo`;o000000Coooooo`000?l0003o00003?ooool2o`0003_ooooo0_l0000Eooooo`?o0000
Doooool001cooooo00?o0000ooooooooool0Foooool2o`0002?ooooo1?l00009ooooo`;o00000_oo
ool3o`000003ooooool0003o000000Wooooo0_l0000Xooooo`;o00001?ooool2o`0000[ooooo0ol0
000Eooooo`;o0000Doooool001cooooo00?o0000ooooooooool0Foooool2o`0002Kooooo0_l00008
ooooo`Oo000000Coooooo`000?l0003ooooo0_l00006ooooo`Co00009_ooool4o`0000;ooooo1?l0
0009ooooo`;o0000J_ooool001cooooo00?o0000ooooooooool0POooool4o`0000Gooooo3Ol00000
0ooooooo0000o`000008ooooo`?o00009oooool2o`000003ooooool0003o000000Go00008?ooool2
o`00057ooooo000Looooo`03o`000?oooooooooo05[ooooo0_l0000Tooooo`Ko00001?ooool?o`00
0004ooooool0003o0000o`0000Gooooo0ol000000ooooooo0000o`00000Looooo`;o00001Oooool2
o`0000;ooooo0_l00002ooooo`?o00008?ooool2o`00057ooooo000Looooo`03o`000?oooooooooo
05[ooooo0_l0000Sooooo`Oo00001?oooolCo`0000Gooooo0ol000000ooooooo0000o`00000Koooo
o`Ko00000_ooool5o`0000?ooooo0ol00009ooooo`;o00005Oooool2o`00057ooooo000Looooo`03
o`000?oooooooooo07oooooo0_l000001?oooooo0000o`000?l00002oooooaKo00001_ooool2o`00
00;ooooo0_l0000Eooooo`;o00000_ooool8o`0000;ooooo1_l000000ooooooo0000o`000002oooo
o`?o00001Oooool2o`0000;ooooo0_l0001Tooooo`007?ooool00ol0003oooooooooo`1Gooooo`;o
0000:Oooool3o`0000;ooooo0ol000000ooooooo0000o`00000Bo`0000Cooooo0ol000000ooooooo
0000o`00000Eooooo`;o00000_ooool2o`000003ooooool0003o000000Go00001?ooool2o`0000Go
oooo1?l00008ooooo`;o0000I?ooool001cooooo0_l0001Hooooo`;o0000:_ooool3o`000003oooo
ool0003o000001Oo00000oooool3o`0000;ooooo0_l0000Fooooo`?o00001_ooool3o`0000;ooooo
1Ol00005ooooo`?o00001Oooool2o`0001Sooooo0_l0001=ooooo`007?ooool00ol0003ooooooooo
o`1Dooooo`;o0000:ooooolOo`0000Oooooo0ol0000Aooooo`;o000000?oooooo`000?l000000ol0
00000ooooooo0000o`000007ooooo`Ko00002?ooool2o`0000?ooooo0_l00003ooooo`;o00004ooo
ool2o`0004gooooo000Looooo`03o`000?oooooooooo05Cooooo0_l0000[ooooo`?o00000_oooolK
o`0000Cooooo1Ol0000Aooooo`;o000000?oooooo`000?l000001?ooool2o`0000Oooooo0_l0000<
ooooo`Co00001_ooool2o`0006;ooooo000Looooo`03o`000?oooooooooo05Cooooo0_l0000Yoooo
o`Co00000_oooolLo`0000Cooooo1?l0000Booooo`;o00006_ooool2o`0000?ooooo0ol00006oooo
o`?o00004oooool2o`0004cooooo000Looooo`03o`000?oooooooooo07oooooo0_l00004oooooa?o
000000?oooooo`000?l000001_l00005ooooo`?o00004_ooool2o`0000gooooo0_l00008ooooo`;o
000000?oooooo`000?l000000oooool3o`0000?ooooo0_l000001?oooooo0000o`000?l0000Coooo
o`Co0000B_ooool001cooooo00?o0000ooooooooool0DOooool2o`0002[ooooo0_l00006oooooaco
00000_ooool2o`000003ooooool0003o000002;ooooo1?l00006ooooo`?o00002oooool2o`0001Wo
oooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o0000:_ooool2o`0000Kooooo
6ol000000ooooooo0000o`000004o`000003ooooool0003o000001[ooooo1ol000000ooooooo0000
o`000003o`0000Cooooo0_l0000Yooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0COoo
ool2o`0000;ooooo0_l0000Zooooo`;o00001OoooolLo`000003ooooool0003o000000;ooooo0_l0
00000ooooooo0000o`00000Jooooo`Oo00000oooool3o`000003ooooool0003o000000Cooooo0_l0
000<ooooo`;o00006?ooool2o`0004Oooooo000Looooo`03o`000?oooooooooo04gooooo0_l0000e
ooooo`;o000000Coooooo`000?l0003ooooo4ol000000ooooooo0000o`000007ooooo`;o00003?oo
ool2o`000003ooooool0003o000000_ooooo1?l00006ooooo`Oo00000_ooool2o`0000?ooooo0_l0
0007ooooo`;o0000HOooool001cooooo00?o0000ooooooooool0B_ooool2o`0003Kooooo0_l00005
oooooaCo000000?oooooo`000?l000000_ooool2o`0000;ooooo0ol0000<ooooo`;o000000?ooooo
o`000?l000001oooool2o`0000;ooooo1?l00007ooooo`So00001Oooool2o`0000;ooooo0_l0001V
ooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o0000<_ooool2o`0000;ooooo0_l000000ooo
oooo0000o`000002oooooa;o000000?oooooo`000?l000001?ooool2o`0000;ooooo0_l0000Ioooo
o`;o000000Coooooo`000?l0003ooooo0_l00009ooooo`;o000000?oooooo`000?l000000_l00008
ooooo`;o00001_ooool2o`0001Oooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`1:oooo
o`;o0000<?ooool4o`0000;ooooo0_l000000ooooooo0000o`000002oooooaOo00000_ooool4o`00
00_ooooo0ol0000=ooooo`;o000000?oooooo`000?l000004Oooool2o`00013ooooo0_l0000Goooo
o`;o0000AOooool001cooooo00?o0000ooooooooool0COooool2o`0002gooooo2_l00005oooooa7o
00000_ooool2o`0000Cooooo1?l00009ooooo`?o00001Oooool2o`0000Kooooo0_l0000Fooooo`?o
000000?oooooo`000?l000008oooool2o`0004Gooooo000Looooo`03o`000?oooooooooo04gooooo
0_l0000aooooo`;o000000Coooooo`000?l0003o00000oooool2o`0000?ooooo0_l000000ooooooo
0000o`000009o`0000Kooooo0_l000001?oooooo0000o`000?l0000Aooooo`;o00001?ooool6o`00
01Cooooo0ol000000ooooooo0000o`000003ooooo`;o00001Oooool2o`0001Sooooo0_l00014oooo
o`007?ooool00ol0003oooooooooo`17ooooo`;o00000oooool3o`0002gooooo0_l00005ooooo`;o
00001?ooool2o`0000Sooooo1?l000000ooooooo0000o`000004o`0000Cooooo0ol000000ooooooo
0000o`000003ooooo`;o00003?ooool2o`0000Cooooo0ol000000ooooooo0000o`000008ooooo`Co
00001?ooool2o`0000;ooooo0ol00006ooooo`;o00001Oooool2o`0001Kooooo1?l00014ooooo`00
7?ooool00ol0003oooooooooo`14ooooo`;o000000?oooooo`000?l000000oooool3o`0002gooooo
0_l00002ooooo`?o00005Oooool6o`0000Cooooo1ol000001?oooooo0000o`000?l0000<ooooo`;o
00001Oooool2o`0000Sooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000?o
00000_ooool4o`0000Wooooo0ol0000Hooooo`;o0000A_ooool001cooooo0_l00012ooooo`;o0000
00?oooooo`000?l000001_ooool2o`0003;ooooo0ol0000@ooooo`;o00001?ooool2o`0000Cooooo
0_l000001?oooooo0000o`000?ooool4o`000003ooooool0003o000000cooooo0_l00006ooooo`;o
00001oooool3o`000005ooooool0003o0000o`000?ooool03?l00009ooooo`?o00006oooool2o`00
04?ooooo000Looooo`03o`000?oooooooooo047ooooo0_l00004ooooo`;o00004Oooool2o`0001Wo
oooo0ol0000Jooooo`Co00002Oooool2o`0000Cooooo0_l00002ooooo`;o00003Oooool2o`0000Oo
oooo0_l00006ooooo`;o00000_ooool2o`0000;ooooo2Ol000001?oooooo0000o`000?l00007oooo
o`;o00007Oooool2o`0004?ooooo000Looooo`03o`000?oooooooooo04Cooooo0_l000000ooooooo
0000o`00000;ooooo`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00000oooool2o`00
00oooooo0ol00006ooooo`;o000000?oooooo`000?l000000oooool2o`0000[ooooo1?l0000=oooo
o`?o00000oooool2o`0001Kooooo0_l00007ooooo`;o00001?ooool:o`0000;ooooo0_l00006oooo
o`Co00006Oooool2o`0004Kooooo000Looooo`03o`000?oooooooooo04Cooooo0_l0000>ooooo`;o
000000?oooooo`000?l000001_ooool2o`0000?ooooo0_l00007ooooo`;o00002?ooool2o`0000;o
oooo2?l00003ooooo`;o00000oooool2o`0000Kooooo0_l0000>ooooo`?o00000oooool2o`0001[o
oooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo3_l00006ooooo`Co00006Oooool2o`00
04Kooooo000Looooo`03o`000?oooooooooo03oooooo0_l00009ooooo`;o00007Oooool2o`0000;o
oooo0_l00008ooooo`[o00002_ooool4o`0000Cooooo0_l0000>ooooo`Co00000_ooool2o`0001[o
oooo0_l00003ooooo`;o000000?oooooo`000?l000003Ol000000ooooooo0000o`000007ooooo`;o
00006Oooool5o`0004?ooooo000Looooo`03o`000?oooooooooo03oooooo0ol00008ooooo`;o0000
7Oooool2o`0000kooooo0_l00002ooooo`;o00003_ooool2o`0000_ooooo1?l00007ooooo`;o0000
5Oooool2o`0000Oooooo0_l00003oooooa;o000000Goooooo`000?l0003o0000ooooo`02o`0000?o
oooo0_l0000Jooooo`Co0000@oooool001cooooo00?o0000ooooooooool0@?ooool2o`0001Cooooo
0_l0000Pooooo`Oo00001Oooool4o`0000gooooo0_l00003ooooo`Co00007_ooool2o`0000Sooooo
0_l00002ooooo`oo000000?oooooo`000?l000000_ooool5o`00023ooooo0_l00014ooooo`007?oo
ool00ol0003oooooooooo`0looooo`;o00001_ooool2o`0000Wooooo0_l00005ooooo`;o00001_oo
ool3o`0001Cooooo0_l000000ooooooo0000o`000003o`0000Oooooo1?l00003ooooo`;o00002?oo
ool2o`0000?ooooo0_l00002ooooo`;o00008_ooool2o`0000;ooooo5_l00002ooooo`?o000000?o
ooooo`000?l000000_ooool2o`0001_ooooo0ol00013ooooo`007?ooool00ol0003oooooooooo`0l
ooooo`;o00001_ooool2o`0000Oooooo1_l00002ooooo`Go00001?ooool4o`0001?ooooo0_l00000
0ooooooo0000o`000002o`0000Sooooo0_l000000ooooooo0000o`000002ooooo`;o00002oooool4
o`0000;ooooo0_l0000Looooo`;o00001?ooool2o`000003ooooool0003o000001Ko00001Oooool2
o`0000;ooooo0_l0000Iooooo`Go0000@oooool001cooooo00?o0000ooooooooool0Boooool4o`00
00;ooooo3?l00002ooooo`?o00000_ooool2o`0000oooooo0_l000001?oooooo0000o`000?l00009
ooooo`;o000000?oooooo`000?l000000ol00009ooooo`Go00001?ooool2o`0001cooooo1?l00005
oooooa[o00000oooool2o`0001cooooo1Ol00014ooooo`007?ooool00ol0003oooooooooo`0hoooo
o`;o00004?ooool5o`000003ooooool0003o000001Go00003_ooool3o`000003ooooool0003o0000
00;ooooo0_l00006ooooo`;o00000_ooool3o`0000Wooooo1?l00002ooooo`;o00005oooool2o`00
00?ooooo0_l00003ooooo`;o00001?oooolKo`0000?ooooo0_l0000Looooo`Go0000A?ooool001co
oooo00?o0000ooooooooool0>?ooool2o`00013ooooo0_l000000ooooooo0000o`00000Jo`0000co
oooo1_l00002ooooo`;o00000_ooool2o`0000;ooooo0ol00002ooooo`;o00001oooool2o`0000Ko
oooo0_l0000Gooooo`;o00000oooool2o`0000Gooooo0_l000000ooooooo0000o`00000Fo`000003
ooooool0003o000000Ko00007?ooool5o`0004Cooooo000Looooo`03o`000?oooooooooo04Oooooo
0ol00002ooooo`ko000000?oooooo`000?l000003?l0000<ooooo`;o000000?oooooo`000?l00000
1Ol00002ooooo`;o00000oooool2o`0000;ooooo0_l00007ooooo`;o00001?ooool2o`0002Gooooo
0_l000000ooooooo0000o`00000Fo`000003ooooool0003o000000Co00001oooool2o`0001Cooooo
1_l00014ooooo`007?ooool00ol0003oooooooooo`17ooooo`?o00000_oooolMo`0000cooooo0_l0
0003ooooo`Go00006_ooool2o`0001oooooo0_l00007oooooaSo000000?oooooo`000?l000000ol0
00000ooooooo0000o`000002o`0000?ooooo0_l0000Dooooo`Co0000A_ooool00006ooooooo^k^ko
<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`00
0?oooooooooo043ooooo0_l00006ooooo`;o00000_oooolLo`000003ooooool0003o000000[ooooo
0_l00003ooooo`;o00004_ooool2o`0001Wooooo0_l000000ooooooo0000o`00000<ooooo`;o0000
1_oooolHo`000003ooooool0003o000000Co000000?oooooo`000?l000000_l00003ooooo`;o0000
4oooool5o`0004Kooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0@?ooool2o`0000Gooooo0ol000000ooooooo
0000o`00000No`0000[ooooo1?l000000ooooooo0000o`00000Booooo`;o00006Oooool2o`000003
ooooool0003o000000;o00004_oooolHo`000005ooooool0003o0000o`000?ooool00_l00004oooo
o`;o00005Oooool7o`0004Kooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wo
oooo1Ol00006ooooo`03o`000?oooooooooo04?ooooo0_l00002ooooobCo00002_ooool6o`000003
ooooool0003o0000033ooooo0_l0000Booooo`oo000000?oooooo`000?l000002ol00006ooooo`?o
00004oooool6o`0004Sooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo
00CoA4A4omgMgOoooooo00001oooool3o`0004?ooooo0ol00002ooooobCo00002?ooool7o`000003
ooooool0003o000001;ooooo0_l0000`oooooago00001Oooool4o`0001?ooooo1_l00018ooooo`00
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oo
oooo00?o0000ooooooooool0>_ooool2o`0000Oooooo0ol00003ooooo`;o000000?oooooo`000?l0
00008Ol00005ooooo`;o000000?oooooo`000?l000000oooool2o`000003ooooool0003o000000?o
oooo0_l0000:ooooo`;o000000?oooooo`000?l000002oooool2o`0000Sooooo0_l0000Foooooa[o
000000?oooooo`000?l000001Oooool2o`0001Kooooo0_l0001;ooooo`0000?ooooooa0@4?ooool0
0_ooool00ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0
>_ooool2o`0000Kooooo0ol00007oooooaWo000000?oooooo`000?l000001ol00004ooooo`;o0000
0_ooool2o`0000Kooooo0_l00003ooooo`;o00003Oooool2o`0000_ooooo0_l00007ooooo`?o0000
5ooooolLo`0000Cooooo1Ol0000Booooo`Co0000Boooool00006oooooomgMgOoV9RHoooooonHV9So
MgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo03[ooooo0_l00006ooooo`;o
00002?oooolRo`0000Gooooo0_l00002ooooo`?o00001?ooool2o`0000[ooooo0_l0000Mooooo`;o
00002_ooool2o`0000?ooooo0_l00006oooooa_o000000?oooooo`000?l000000oooool5o`0001;o
oooo1?l0001;ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo
00Kooooo00?o0000ooooooooool0=oooool2o`0000Sooooo1Ol00007ooooob;o000000?oooooo`00
0?l000001Oooool3o`0000Cooooo0_l0000:ooooo`;o0000:Oooool2o`0000?ooooo0ol00005oooo
o`Co000000?oooooo`000?l000005?l000000ooooooo0000o`00000Jooooo`Co0000Boooool001co
oooo00?o0000ooooooooool0=oooool2o`0000Sooooo1Ol00007oooooaoo000000?oooooo`000?l0
00001_l000000ooooooo0000o`000002ooooo`;o0000=_ooool2o`0000Gooooo1?l00004ooooo`Go
000000?oooooo`000?l000004?l000000ooooooo0000o`000002o`0000Oooooo0_l0000Aooooo`Go
0000C?ooool001cooooo00?o0000ooooooooool0@oooool2o`0000Sooooo7_l00002ooooo`So0000
00Coooooo`000?l0003ooooo0ol0000fooooo`;o00001Oooool2o`0000Kooooo1Ol00002oooooa7o
000000?oooooo`000?l000000_l00007ooooo`;o00004?ooool5o`0004gooooo000Looooo`03o`00
0?oooooooooo04;ooooo0ol00006ooooo`Co00000ooooolHo`0000;ooooo1?l00005ooooo`Ko0000
;?ooool2o`0001;ooooo0ol00003ooooo`Ko00000oooool>o`0001kooooo1_l0001=ooooo`007?oo
ool00ol0003oooooooooo`12ooooo`?o00001_ooool2o`0000Gooooo3Ol000001Ooooooo0000o`00
0?l0003ooooo00ko00000oooool4o`0002kooooo0_l00006ooooo`;o00002_ooool3o`0000?ooooo
1_l00003ooooo`ko00001?ooool2o`0001Sooooo0_l000000ooooooo0000o`000003o`0004_ooooo
000Looooo`03o`000?oooooooooo03Sooooo0_l00009ooooo`?o00003?ooool7o`000003ooooool0
003o000000Go00000_ooool?o`0003Oooooo0_l00004ooooo`;o00002_ooool2o`0000;ooooo1Ol0
0004ooooo`Ko000000?oooooo`000?l000001?l00004ooooo`;o000000?oooooo`000?l000000_oo
ool2o`0001Oooooo1Ol0001;ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00002_ooool2
o`0000gooooo6_l0000iooooo`Go00001?ooool2o`000003ooooool0003o000000Oooooo0_l00002
ooooo`Oo00000_ooool4o`0000?ooooo0ol000000ooooooo0000o`000004ooooo`;o00001Oooool2
o`0001?ooooo0_l000000ooooooo0000o`00001?ooooo`007?ooool00ol0003oooooooooo`14oooo
o`;o00002?ooool2o`0000;ooooo0_l000000ooooooo0000o`000005o`0000;ooooo3Ol00006oooo
o`Co00002_ooool2o`0000cooooo0_l0000Fooooo`Go00002?ooool2o`000003ooooool0003o0000
00Cooooo0_l00005ooooo`Co00000_ooool4o`000003ooooool0003o000000;o00001Oooool2o`00
00Oooooo0ol0000Cooooo`Go00000_ooool2o`0004_ooooo000Looooo`03o`000?oooooooooo04Co
oooo0_l00008ooooo`;o00000_ooool2o`0000?ooooo4_l00006ooooo`Wo000000?oooooo`000?l0
00001?ooool2o`0000cooooo0_l00004ooooo`;o00004?ooool2o`000003ooooool0003o000000_o
oooo0_l00002ooooo`;o00001oooool3o`0000?ooooo1?l000001?oooooo0000o`000?l00006oooo
o`;o00001oooool5o`0001;ooooo0_l00004ooooo`Co00000_ooool2o`0004Gooooo000Looooo`03
o`000?oooooooooo03?ooooo0_l0000Uooooo`Ko00000_ooool2o`000003ooooool0003o000000Oo
oooo0ol00002ooooo`Go000000?oooooo`000?l000006?ooool2o`0001?ooooo0_l0000<ooooo`;o
000000?oooooo`000?l000001oooool3o`0000;ooooo1Ol000000ooooooo0000o`000004ooooo`Co
00002_ooool3o`0000oooooo0_l00009ooooo`;o00000_ooool2o`0004Gooooo000Looooo`03o`00
0?oooooooooo03?ooooo0_l0000@ooooo`;o00004Oooool4o`0000;ooooo0_l00003ooooo`Co0000
1Oooool<o`0001Kooooo0_l0000Pooooo`;o000000Coooooo`000?l0003ooooo0_l0000:ooooo`Co
000000?oooooo`000?l000000oooool4o`000003ooooool0003o000000Co00001oooool2o`0001;o
oooo0ol0000Dooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0AOooool2o`00017ooooo
1?l00002ooooo`;o00000oooool2o`0000Gooooo1?l00002ooooo`So000000?oooooo`000?l00000
4oooool2o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`?o00004oooool2o`000003oooo
ool0003o000000_ooooo0_l00002ooooo`;o00001_ooool4o`000004ooooool0003o0000ooooo`;o
00002?ooool2o`0001;ooooo0ol0000@ooooo`;o00000_ooool2o`0003kooooo000Looooo`;o0000
BOooool2o`0001Cooooo0_l0000:ooooo`?o00001_ooool2o`000004ooooool0003o0000ooooo`;o
00005_ooool3o`000004ooooool0003o0000ooooo`Go00003_ooool2o`0001?ooooo0_l00002oooo
o`?o00002_ooool3o`0001kooooo0_l0000=ooooo`;o00000_ooool3o`00047ooooo000Looooo`03
o`000?oooooooooo04Sooooo0_l0000?ooooo`;o000000?oooooo`000?l000002oooool4o`0000Ko
oooo0_l00009ooooo`;o00001Oooool4o`0000Cooooo0_l00002ooooo`;o00001Oooool2o`0000co
oooo0_l00003ooooo`;o00005oooool3o`0000[ooooo0ol00009ooooo`;o00004_ooool3o`0000_o
oooo1?l00003ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0COooool2o`0000[ooooo
0_l000000ooooooo0000o`000002ooooo`;o00000oooool2o`0000;ooooo0_l0000@ooooo`;o0000
00?oooooo`000?l000000oooool6o`0000Cooooo0_l0000Gooooo`;o00003oooool2o`0001Sooooo
0ol00002ooooo`;o00001Oooool2o`00017ooooo1?l0000;ooooo`;o00002?ooool2o`0003kooooo
000Looooo`03o`000?oooooooooo04gooooo0_l00003ooooo`?o00002oooool3o`0000;ooooo0_l0
0002ooooo`;o00004?ooool2o`0000Kooooo0_l0000?ooooo`;o00004Oooool2o`0000kooooo0_l0
0009ooooo`;o00002?ooool2o`0000Sooooo0_l00002ooooo`;o00005?ooool2o`0000Kooooo0_l0
000?ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0<Oooool2o`0001oooooo0ol0000:
ooooo`Go00007oooool2o`0000oooooo0_l0000;ooooo`;o000000Coooooo`000?l0003ooooo0_l0
0005ooooo`;o00000_ooool2o`0000?ooooo0_l00009ooooo`;o00002?ooool2o`000003ooooool0
003o000000;o00000oooool6o`0001?ooooo0ol00006ooooo`;o0000Coooool001cooooo00?o0000
ooooooooool0<Oooool2o`0002Wooooo0_l000000ooooooo0000o`000004o`0001kooooo0ol0000K
ooooo`So00001Oooool2o`0000;ooooo0_l00003ooooo`;o00001_ooool2o`0000Sooooo0ol00002
ooooo`Go00001Oooool2o`0001Gooooo0_l00007ooooo`;o000000?oooooo`000?l000001_ooool2
o`0000Oooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o0000:_ooool2o`00
00Gooooo0_l00005ooooo`;o00004Oooool2o`0000?ooooo1?l00003ooooo`;o00004Oooool2o`00
00Gooooo1_l00006ooooo`;o00003_ooool2o`0000;ooooo0_l00004ooooo`Oo00000_ooool3o`00
01Wooooo0_l00008ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Oooooo0_l0000koooo
o`007?ooool00ol0003oooooooooo`0`ooooo`;o0000>?ooool2o`0000Gooooo0_l0000:ooooo`;o
00000oooool2o`0000Gooooo1?l0000?ooooo`;o00001Oooool4o`0000Sooooo0ol00003ooooo`;o
00003?ooool2o`0000Cooooo3?l0000Iooooo`Go00000oooool2o`0000Wooooo0_l00016ooooo`00
7?ooool00ol0003oooooooooo`0_ooooo`;o0000<?ooool2o`0000Cooooo0_l00003ooooo`Co0000
00?oooooo`000?l000003Oooool2o`0000Wooooo0_l0000Fooooo`Co00001Oooool2o`0000;ooooo
0_l00003ooooo`;o00002oooool2o`0000Wooooo2Ol0000Iooooo`Co00000oooool2o`0000Wooooo
0_l00005ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0;oooool2o`00033ooooo0_l0
0004ooooo`;o00000oooool4o`0000?ooooo0_l0000;ooooo`;o00008oooool4o`0000?ooooo0ol0
00000ooooooo0000o`00000@ooooo`?o00001?ooool2o`0000?ooooo0_l00004ooooo`;o00006?oo
ool3o`00017ooooo0_l00004ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0;oooool2
o`0003cooooo1?l00002ooooo`;o0000<_ooool2o`0000Cooooo0_l000001?oooooo0000o`000?l0
000@ooooo`;o00001?ooool3o`0000;ooooo0_l00004ooooo`Go00005Oooool3o`0000[ooooo0_l0
0004ooooo`?o0000AOooool001cooooo00?o0000ooooooooool0;oooool2o`0003kooooo0_l0000o
ooooo`?o00001?ooool3o`00013ooooo0ol00005ooooo`Oo00005oooool2o`0000Wooooo0_l00004
ooooo`;o00001Oooool2o`0003oooooo000Looooo`03o`000?oooooooooo02oooooo0_l00026oooo
o`?o00004Oooool2o`0000Gooooo0_l0000Looooo`;o00004oooool5o`0003oooooo000Looooo`03
o`000?oooooooooo02oooooo0_l00022ooooo`;o00000_ooool2o`0000;ooooo0_l00006ooooo`;o
00001?ooool2o`0002Gooooo0_l0000<ooooo`?o00001?ooool3o`000003ooooool0003o000003ko
oooo000Looooo`03o`000?oooooooooo0;?ooooo0_l00002ooooo`;o00000_ooool2o`0000Kooooo
0_l000001?oooooo0000o`000?ooool2o`0002Kooooo0_l0000;ooooo`?o00002?ooool2o`000003
ooooool0003o000003_ooooo000Looooo`03o`000?oooooooooo0<Kooooo0_l0000Yooooo`;o0000
1_ooool2o`00017ooooo0_l0000kooooo`007?ooool2o`0002kooooo0_l00025ooooo`;o0000@ooo
ool2o`0004kooooo000Looooo`03o`000?oooooooooo02gooooo0_l00025ooooo`;o00005?ooool2
o`000003ooooool0003o000002Wooooo0_l00005ooooo`;o00001Oooool3o`00043ooooo000Loooo
o`03o`000?oooooooooo02gooooo0_l0002Kooooo`Go0000:Oooool3o`0000Cooooo0ol00004oooo
o`?o0000@?ooool001cooooo00?o0000ooooooooool0;Oooool2o`0008cooooo0_l0000>ooooo`;o
0000;?ooool4o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o0000@?ooool001cooooo
00?o0000ooooooooool0;Oooool3o`0007gooooo1?l0000:ooooo`;o00003?ooool2o`00033ooooo
0_l00006ooooo`;o00000_ooool2o`00043ooooo000Looooo`03o`000?oooooooooo02kooooo0_l0
001Iooooo`;o00002Oooool2o`0001Oooooo1_l00005ooooo`;o00003_ooool4o`0000?ooooo0ol0
000Xooooo`;o00001oooool3o`000003ooooool0003o0000043ooooo000Looooo`03o`000?oooooo
oooo063ooooo0_l0000Wooooo`;o00000_ooool2o`000003ooooool0003o000000Ko000000?ooooo
o`000?l000005?ooool4o`0000Gooooo0_l0000>ooooo`Co00000oooool3o`0000Cooooo0_l0000L
ooooo`;o00001?ooool2o`0000Sooooo0_l000000ooooooo0000o`000010ooooo`007?ooool00ol0
003oooooooooo`1Oooooo`?o000000?oooooo`000?l000002?ooool2o`0000?ooooo0_l0000Coooo
o`;o00001?ooool?o`0001?ooooo0_l00007ooooo`;o00005?ooool2o`0000Kooooo0ol0000Koooo
o`;o00001?ooool2o`0000_ooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`1Oooooo`;o
00000_ooool2o`000003ooooool0003o000000Gooooo0_l00003ooooo`Co00000oooool2o`0000co
oooo0_l00003oooooa7o00007?ooool2o`0001;ooooo0ol00007ooooo`?o00006_ooool2o`0000Co
oooo0_l00004ooooo`;o00001Oooool2o`00043ooooo000Looooo`03o`000?oooooooooo05oooooo
0_l00004ooooo`Go000000?oooooo`000?l000001Ol000001?oooooo0000o`000?l00003ooooo`;o
00000oooool3o`000004ooooool0003o0000oooooaWo00004oooool2o`000003ooooool0003o0000
00?ooooo0ol0000Aooooo`;o00002Oooool2o`0001Wooooo0_l00003ooooo`;o00001?ooool4o`00
00Cooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`1Oooooo`;o000000?oooooo`000?l0
00004?l0000:ooooo`Ko000000?oooooo`000?l000006Ol0000=ooooo`;o00000_ooool2o`000003
ooooool0003o000000Cooooo0_l0000Booooo`Co00008Oooool3o`0000;ooooo0_l00003ooooo`Go
00001?ooool2o`00047ooooo000Looooo`03o`000?oooooooooo02gooooo0_l0000cooooo`ko0000
0_ooool4o`0000_ooooo3ol000000ooooooo0000o`00000?o`0000_ooooo1_l000000ooooooo0000
o`000002o`0000Gooooo0ol0000>ooooo`Co00008_ooool2o`0000Oooooo1_l00002ooooo`;o0000
@_ooool001cooooo00?o0000ooooooooool0;Oooool3o`00033ooooo4ol000000ooooooo0000o`00
000<ooooo`Oo000000?oooooo`000?l000006?l0000:ooooo`Go00000oooool2o`000003ooooool0
003o000000;ooooo0ol000000ooooooo0000o`00000Booooo`;o00007?ooool2o`0000Gooooo0_l0
0002ooooo`Go00000_ooool2o`0001_ooooo0_l0000Uooooo`007?ooool00ol0003oooooooooo`0^
ooooo`;o0000:_ooool3o`000003ooooool0003o000001Co00002oooool2o`000003ooooool0003o
000000Go000000?oooooo`000?l000006Ol00008ooooo`?o000000Coooooo`000?l0003ooooo0ol0
00001?oooooo0000o`000?l00006ooooo`;o00004_ooool2o`0000Kooooo0_l0000Cooooo`?o0000
0oooool4o`0000;ooooo0ol00003ooooo`?o00006oooool2o`0002Gooooo000Looooo`03o`000?oo
oooooooo037ooooo0_l0000Wooooo`?o000000?oooooo`000?l000003ol000000ooooooo0000o`00
0005o`0000Kooooo1?l00002ooooob?o00001oooool3o`0000Cooooo0ol000000ooooooo0000o`00
0003o`0000Kooooo0ol00004ooooo`;o00004Oooool2o`0001?ooooo0_l00004ooooo`;o00000ooo
ool2o`000003ooooool0003o000000Co0000@oooool001cooooo00?o0000ooooooooool0<Oooool2
o`0002[ooooo6_l00006ooooobWo00000oooool2o`000003ooooool0003o000000Go000000Cooooo
o`000?l0003o00000oooool3o`0000Kooooo1?l00003ooooo`;o00004oooool2o`0001Oooooo0_l0
0003ooooo`Wo00006_ooool2o`0002Oooooo000Looooo`;o0000<?ooool2o`0002_ooooo0ol00000
0ooooooo0000o`00000Eo`000005ooooool0003o0000o`000?ooool00_l00002ooooo`Ko000000?o
ooooo`000?l000000_ooool?o`000003ooooool0003o000000[o000000?oooooo`000?l000001Ol0
00000ooooooo0000o`000004o`0000Gooooo0_l00006ooooo`Co00006?ooool2o`0001gooooo0_l0
00000ooooooo0000o`000003o`0001[ooooo0_l0000Wooooo`007?ooool00ol0003oooooooooo`0_
ooooo`;o000000?oooooo`000?l000008_ooool4o`0000;ooooo0ol00002oooooa[o000000Cooooo
o`000?l0003ooooo0_l000000ooooooo0000o`000002ooooo`?o00000ooooolRo`000003ooooool0
003o000000Ko000000?oooooo`000?l000002oooool2o`0001Gooooo1_l0000Jooooo`;o00000ooo
ool4o`0001_ooooo0_l0000Wooooo`007?ooool00ol0003oooooooooo`0`ooooo`Co00008_ooool:
o`000003ooooool0003o000001So000000?oooooo`000?l000002_l00003oooooa_o000000?ooooo
o`000?l000000_l00002ooooo`[o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00000ooo
ool2o`00017ooooo0_l00003ooooo`Ko00006Oooool3o`0000?ooooo1?l0000Iooooo`;o0000:Ooo
ool001cooooo00?o0000ooooooooool0<?ooool2o`0000;ooooo0ol0000Oooooo`;o000000?ooooo
o`000?l000007ol00002ooooo`?o000000?oooooo`000?l000000_ooool3o`0000Cooooo5Ol00002
ooooo`?o00000_ooool5o`000003ooooool0003o000000cooooo0_l00002ooooo`;o00000oooool2
o`00017ooooo0_l0000:ooooo`;o00005_ooool3o`0000?ooooo0ol0000Iooooo`?o0000:Oooool0
01cooooo00?o0000ooooooooool0<?ooool2o`0000;ooooo0ol0000Oooooo`;o000000?oooooo`00
0?l000000_oooolKo`0000Cooooo1ol000001?oooooo0000o`000?l00002ooooo`co000000?ooooo
o`000?l000000_l00002ooooo`Co00000_ooool2o`0000Cooooo1?l0000[ooooo`;o00000_ooool3
o`0000Gooooo0_l0000Fooooo`?o00000oooool3o`0001Wooooo0_l0000Zooooo`007?ooool00ol0
003oooooooooo`0cooooo`;o00008oooool5o`000003ooooool0003o000001Oo00000_ooool2o`00
00?ooooo1Ol000000ooooooo0000o`000003ooooo`;o00002?ooool2o`000003ooooool0003o0000
00;o00000_ooool4o`0003Oooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o0000
01[ooooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00008oooool2o`000004
ooooool0003o0000ooooo`;o000000?oooooo`000?l000005?l00002ooooo`;o00008oooool2o`00
00_ooooo3_l0000Qooooo`Oo000000?oooooo`000?l000006oooool2o`0004Sooooo000Looooo`03
o`000?oooooooooo05Sooooo0_l00005ooooo`ko000000?oooooo`000?l000001ol00002ooooo`Co
000000Coooooo`000?l0003o00009_oooolFo`0001kooooo1Ol000000ooooooo0000o`000002o`00
00kooooo0_l0000:ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0<oooool2o`0002[o
oooo0_l00002oooooa3o00001?ooool6o`000004ooooool0003o0000o`0002?ooooo1ol000001?oo
oooo0000o`000?l00002ooooo`;o00001?ooool9o`0001_ooooo0_l000000ooooooo0000o`000005
o`0000kooooo1?l00008ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0<oooool2o`00
00Gooooo0_l00003ooooo`Co00008Oooool?o`000003ooooool0003o000000?o0000:Oooool;o`00
00Sooooo1?l00002ooooo`Ko00007oooool4o`0000oooooo1?l00008ooooo`;o0000B?ooool001co
oooo00?o0000ooooooooool0<oooool2o`0000Gooooo0_l00002ooooo`Go00000_ooool3o`0000Wo
oooo0_l0000Eooooo`Ko000000?oooooo`000?l000001ol0000Eooooo`;o00004_ooool4o`0000;o
oooo0_l00002ooooo`;o00000ooooolCo`0001Sooooo1?l0000Kooooo`;o00000oooool2o`0001Oo
oooo0_l0000_ooooo`007?ooool00ol0003oooooooooo`0eooooo`;o00001oooool2o`0000Gooooo
0ol00002ooooo`;o00001Oooool2o`0001Oooooo1ol000001?oooooo0000o`000?l0000Fooooo`Co
00004?ooool4o`000004ooooool0003o0000ooooo`;o00000_ooool2o`000003ooooool0003o0000
01Go00005_ooool4o`0001_ooooo0_l00003ooooo`;o00005_ooool3o`0002oooooo000Looooo`03
o`000?oooooooooo03Gooooo0_l0000Cooooo`;o00006_ooool2o`0000?ooooo0_l000000ooooooo
0000o`000002ooooo`?o00005Oooool3o`0000;ooooo0_l0000<ooooo`Wo00002?oooolHo`0001Go
oooo0ol0000Looooo`;o00006_ooool3o`00033ooooo000Looooo`03o`000?oooooooooo03Wooooo
0_l0000<ooooo`;o00000_ooool2o`0000Sooooo0_l0000:ooooo`;o00000oooool2o`000003oooo
ool0003o000000Oooooo1?l0000Dooooo`?o00000_ooool2o`0000cooooo0ol000000ooooooo0000
o`000002o`0000;ooooo0_l00005oooooa[o00004oooool3o`0000;ooooo0_l0000Hooooo`;o0000
6_ooool3o`00033ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05
onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0iooooo`;o00003?ooool2o`00
00;ooooo0_l00008ooooo`;o00000oooool5o`0000;ooooo0_l00003ooooo`;o000000Coooooo`00
0?l0003o00001_ooool4o`0001Cooooo0ol0000?ooooo`Co000000?oooooo`000?l000001?ooool2
o`0000?ooooo7Ol0000Booooo`?o00000_ooool2o`000003ooooool0003o000001Gooooo0_l0000I
ooooo`;o0000<_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go
EEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo03Wooooo1?l00003ooooo`;o0000
1?ooool2o`0000Gooooo0_l00005ooooo`Co00000_ooool5o`0000Wooooo1?l0000Wooooo`;o0000
1_ooool4o`0000;ooooo0_l00007ooooob3o00004Oooool5o`0000?ooooo0_l0000>ooooo`;o0000
8?ooool2o`0003;ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo03_ooooo0ol00002ooooo`;o0000
1?ooool2o`0000Gooooo0_l00005ooooo`Go000000?oooooo`000?l000002?ooool3o`000003oooo
ool0003o000000Go00009?ooool2o`0000Kooooo1?l00002ooooo`;o00001_oooolKo`000003oooo
ool0003o000000Co00004?ooool:o`0000kooooo0ol00009ooooo`;o00005?ooool2o`0003;ooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oiRHV?ooooooV9RH
ob4Q8@06ooooo`?o0000>oooool3o`0000Cooooo0_l000000ooooooo0000o`000005ooooo`?o0000
2?ooool2o`0000_ooooo0ol00002ooooo`Ko0000;Oooool3o`0000[ooooo8_l0000@ooooo`[o0000
3oooool2o`0000?ooooo0_l00003ooooo`?o0000B?ooool00003ooooool0003ooooo00;ooooo00?o
0000ooooooooool02Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0
>oooool3o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`?o00007_ooool2o`0002gooooo
1?l00005ooooo`;o00001?oooolRo`0000oooooo0_l00005ooooo`;o00002Oooool2o`0000Wooooo
0ol00003ooooo`;o0000BOooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Ooo
ool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo03_ooooo1_l00003ooooo`;o00001?oo
ool3o`0000cooooo0_l00002ooooo`;o00001oooool2o`0003?ooooo1?l00005ooooo`;o00000_oo
ool3o`0000?ooooo6?l00002ooooo`Ko00004_ooool4o`0000Wooooo0_l00009ooooo`?o00005_oo
ool2o`0003Kooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P0
2?ooool00ol0003oooooooooo`0kooooo`;o000000Coooooo`000?l0003o00000oooool2o`000004
ooooool0003o0000ooooo`;o00002oooool4o`0000;ooooo0_l00007ooooo`;o0000:Oooool2o`00
00Sooooo0ol00004ooooo`;o00000_ooool5o`000003ooooool0003o000001co000000?oooooo`00
0?l000000ol0000@ooooo`Co00005Oooool2o`0001Kooooo0_l0000fooooo`0000Koooooonk^k_lb
<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0?ooo
ool2o`0000Kooooo0ol0000=ooooo`;o00003?ooool3o`0002Wooooo0_l00008ooooo`;o00001Ooo
ool2o`0000;ooooo0_l00004oooooaoo000000?oooooo`000?l000000_l0000;ooooo`;o00000ooo
ool2o`0001Kooooo0ol0000Fooooo`;o0000=_ooool001cooooo00?o0000ooooooooool0?oooool2
o`0000Oooooo0_l0000Booooo`;o00001oooool3o`0003?ooooo0ol00006ooooo`Co00001OoooolU
o`0000Sooooo0ol00003ooooo`;o00005_ooool3o`0001Cooooo0_l0000hooooo`007?ooool00ol0
003oooooooooo`1Eooooo`;o00001Oooool4o`0000Kooooo0_l0000cooooo`Co00001Oooool2o`00
00Oooooo:?l00005ooooo`;o00001?ooool2o`0002_ooooo1?l0000hooooo`007?ooool00ol0003o
ooooooooo`13ooooo`;o00001oooool4o`0000Gooooo0_l00004ooooo`Ko00002?ooool2o`00033o
oooo1?l00002ooooo`;o00002_oooolXo`0000Cooooo0ol00003ooooo`;o0000;?ooool2o`0003[o
oooo000Looooo`03o`000?oooooooooo04?ooooo0_l00004ooooo`;o000000?oooooo`000?l00000
0_l0000;ooooo`Ko00001Oooool6o`0002oooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo
:?l00003ooooo`?o00000_ooool3o`0000gooooo0ol0000Looooo`;o0000>_ooool001cooooo00?o
0000ooooooooool0A_ooool2o`000003ooooool0003o000000Gooooo0_l0000Dooooo`Oo0000;ooo
ool3o`0000Sooooo0_l00005oooooaoo000000?oooooo`000?l000001ol00003ooooo`;o00000_oo
ool2o`0000_ooooo0_l000001?oooooo0000o`000?l00006ooooo`;o0000D?ooool001cooooo00?o
0000ooooooooool0A_ooool3o`0000Oooooo0_l0000Iooooo`;o0000;oooool3o`0000?ooooo0_l0
00000ooooooo0000o`000007ooooobWo00005?ooool2o`0000[ooooo0ol0000@ooooo`?o0000??oo
ool001cooooo00?o0000ooooooooool0A_ooool3o`0000;ooooo0_l00003ooooo`;o00006_ooool4
o`0002Cooooo0_l00005ooooo`;o00001Oooool2o`000003ooooool0003o000000?ooooo0_l00003
oooooaoo000000?oooooo`000?l000001Ol00003ooooo`;o00004_ooool2o`0000Kooooo0_l00000
0ooooooo0000o`00000@ooooo`?o0000??ooool001cooooo00?o0000ooooooooool0Boooool2o`00
00?ooooo0_l0000Jooooo`Co00009?ooool2o`0000Gooooo1Ol0000:ooooo`;o00000oooool7o`00
0003ooooool0003o000000Wo000000?oooooo`000?l000003_l00003ooooo`;o000000?oooooo`00
0?l000002oooool2o`0000Gooooo0_l00006ooooo`?o00004Oooool2o`0003kooooo000Looooo`03
o`000?oooooooooo04[ooooo0_l00005ooooo`;o00004oooool2o`0002cooooo0_l00006ooooo`Co
00004?ooool5o`0000;ooooo7Ol000000ooooooo0000o`000003o`0000cooooo0_l00003ooooo`;o
00002Oooool2o`00017ooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`19ooooo`?o0000
1Oooool2o`00013ooooo0_l000000ooooooo0000o`00000<ooooo`;o00009_ooool2o`0000Cooooo
0_l0000:ooooo`Oo00000_oooolSo`0000oooooo1?l00006ooooo`?o00004_ooool2o`0003oooooo
000Looooo`03o`000?oooooooooo04Sooooo0ol00005ooooo`?o00003oooool3o`000004ooooool0
003o0000o`0000Sooooo0_l000000ooooooo0000o`00000Vooooo`?o00000_ooool3o`0000Oooooo
0_l000000ooooooo0000o`00000Qo`0000?ooooo1?l0000Aooooo`Co00001_ooool3o`0001;ooooo
0_l0000oooooo`007?ooool2o`0004Wooooo0_l00006ooooo`?o00003oooool2o`0000?ooooo1_l0
0004ooooo`;o00001oooool2o`0001?ooooo0ol0000:ooooo`Co000000?oooooo`000?l000002?oo
ool2o`0000Gooooo1_l000000ooooooo0000o`00000Fo`0000?ooooo0ol0000Jooooo`;o0000E_oo
ool001cooooo00?o0000ooooooooool0B?ooool2o`0001Wooooo1?l000000ooooooo0000o`000005
o`0000?ooooo0ol00005ooooo`;o00000_ooool2o`0000oooooo0ol00004ooooo`;o00001?ooool4
o`0001?ooooo8?l00002ooooo`;o00004?ooool2o`0000Oooooo0ol0000Booooo`;o0000@_ooool0
01cooooo00?o0000ooooooooool0Boooool5o`0001?ooooo1?l000000ooooooo0000o`000003oooo
o`;o00000oooool3o`0000Oooooo1?l0000Aooooo`;o00000_ooool3o`0000Cooooo0ol00002oooo
o`?o00000oooool2o`0000Sooooo0_l000000ooooooo0000o`00000<o`000003ooooool0003o0000
00ko00004_ooool4o`0000Kooooo0ol0000Cooooo`;o0000@_ooool001cooooo00?o0000oooooooo
ool0B_ooool6o`0001Cooooo0ol000000ooooooo0000o`000008ooooo`;o00000oooool2o`0000?o
oooo1?l0000Aooooo`;o00000_ooool2o`0000Kooooo0_l00002ooooo`?o00000oooool2o`0000So
oooo0_l00003ooooo`Oo000000?oooooo`000?l000002Ol00003ooooo`Co00003_ooool2o`0000Go
oooo0_l00007ooooo`Co0000Eoooool001cooooo00?o0000ooooooooool0BOooool3o`0000?ooooo
0_l0000Cooooo`Co00001?ooool2o`0000Oooooo1?l00005ooooo`;o00007Oooool2o`0000kooooo
1?l00007ooooo`Co00000oooool<o`000003ooooool0003o000000;o000000?oooooo`000?l00000
2oooool2o`000003ooooool0003o000000Go00001Oooool5o`0005Oooooo000Looooo`03o`000?oo
oooooooo04Wooooo0ol00003ooooo`;o00004oooool4o`0000Cooooo0_l00002ooooo`;o00000ooo
ool2o`0000_ooooo0_l000000ooooooo0000o`000003ooooo`;o00004_ooool4o`0000;ooooo0_l0
0007ooooo`Co00001_ooool2o`0000Kooooo0_l00004ooooo`Oo00000_ooool5o`0000kooooo1?l0
00000ooooooo0000o`000004ooooo`Co0000FOooool001cooooo00?o0000ooooooooool0B_ooool2
o`0000oooooo0_l00008ooooo`?o00002?ooool3o`0000oooooo0_l000001?oooooo0000o`000?l0
0002ooooo`;o00001oooool4o`0000Oooooo1Ol000000ooooooo0000o`00000Aooooo`;o00000_oo
ool2o`0000Sooooo0_l00002ooooo`?o00000_ooool5o`0000gooooo1Ol00007ooooo`Co00004Ooo
ool2o`0004Kooooo000Looooo`03o`000?oooooooooo04[ooooo0_l0000?ooooo`Co00001_ooool3
o`0000Kooooo0_l000000ooooooo0000o`00000;ooooo`;o00000_ooool6o`0000_ooooo1?l00007
ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0001?ooooo0_l00007ooooo`;o00000ooo
ool2o`0000Cooooo0_l0000>ooooo`?o00001_ooool3o`0001?ooooo0_l000000ooooooo0000o`00
0016ooooo`007?ooool00ol0003oooooooooo`1=ooooo`?o00003Oooool2o`0000Oooooo0ol00005
ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00000_ooool2o`000003ooooool0003o
000000Cooooo0_l0000@ooooo`;o00002Oooool3o`0000;ooooo0_l0000Aooooo`;o00002Oooool2
o`0000Wooooo0_l0000;ooooo`Go00001Oooool5o`0001?ooooo0_l00019ooooo`007?ooool00ol0
003oooooooooo`1=ooooo`?o00005oooool2o`0000[ooooo2_l00004ooooo`?o000000Coooooo`00
0?l0003o00001Oooool2o`0000Gooooo1?l00007ooooo`;o00001?ooool4o`00013ooooo0_l0000B
ooooo`;o00003Oooool3o`0000Kooooo0ol0000Fooooo`;o0000BOooool001cooooo00?o0000oooo
ooooool0C?ooool2o`0000;ooooo0_l00007ooooo`;o00002oooool4o`0000_ooooo1_l00006oooo
o`Oo00001Oooool2o`0000Gooooo0_l00009ooooo`;o00001?ooool4o`0000;ooooo0_l0000Coooo
o`;o00002Oooool4o`0001Kooooo0ol0000Dooooo`?o0000B_ooool001cooooo00?o0000oooooooo
ool0C?ooool2o`0000;ooooo0_l00007ooooo`;o00002oooool5o`0000[ooooo0ol0000<ooooo`Co
00000_ooool2o`0000Wooooo0_l00008ooooo`;o00000_ooool3o`0000Gooooo0_l0000Cooooo`;o
00002Oooool4o`0000Sooooo0_l00008ooooo`;o00006Oooool3o`0004[ooooo000Looooo`03o`00
0?oooooooooo05Sooooo0_l00007ooooo`Co00000oooool3o`0000?ooooo0ol00004ooooo`?o0000
1_ooool4o`0000Sooooo0_l00008ooooo`Co00002?ooool6o`0001Oooooo0_l0000:ooooo`;o0000
0_ooool2o`0000Kooooo1?l00005ooooo`;o000000?oooooo`000?l000005_ooool2o`0004kooooo
000Looooo`03o`000?oooooooooo04oooooo1?l000000ooooooo0000o`000002ooooo`;o00001ooo
ool4o`0000?ooooo0_l00004ooooo`Go00002Oooool8o`0000Oooooo0_l00007ooooo`Co00002?oo
ool3o`0000Gooooo0_l0000Cooooo`;o00002Oooool3o`0000[ooooo0_l000000ooooooo0000o`00
0003ooooo`?o000000?oooooo`000?l000005_ooool2o`0004kooooo000Looooo`03o`000?oooooo
oooo04kooooo1Ol000000ooooooo0000o`00000Cooooo`;o00001?ooool5o`0000Sooooo2Ol00006
ooooo`;o00004oooool3o`0000Gooooo0_l00005ooooo`;o00005oooool2o`000003ooooool0003o
000000Kooooo0_l00003ooooo`;o00000oooool2o`0001Sooooo0ol0001?ooooo`007?ooool00ol0
003oooooooooo`1>ooooo`Wo000000?oooooo`000?l000003oooool4o`0000;ooooo0_l000001?oo
oooo0000o`000?ooool2o`0000Cooooo2ol00005ooooo`?o00004oooool3o`0000_ooooo0_l0000D
ooooo`Go000000?oooooo`000?l000001_ooool2o`0000?ooooo0_l0000Kooooo`Go0000Coooool0
01cooooo0_l0001Cooooo`Go000000?oooooo`000?l000001oooool4o`0000Gooooo0ol00007oooo
o`?o00001?ooool2o`0000;ooooo0_l00002ooooo`?o00001Oooool3o`0001Cooooo0_l0000Qoooo
o`Go00003Oooool5o`0001Cooooo0_l00003ooooo`;o0000D_ooool001cooooo00?o0000oooooooo
ool0Doooool2o`0000Oooooo0_l00003ooooo`Co00001?ooool4o`0000Oooooo0_l00005ooooo`Go
00000oooool4o`0000Cooooo0ol00009ooooo`?o00005?ooool3o`0000Sooooo0_l00004ooooo`;o
00001oooool2o`0000[ooooo0_l000001?oooooo0000o`000?ooool2o`0001?ooooo1_l0001Doooo
o`007?ooool00ol0003oooooooooo`1Aooooo`Co00001oooool2o`0000;ooooo0_l00004ooooo`;o
000000?oooooo`000?l000000_l00002ooooo`;o00001?ooool2o`0000?ooooo0_l000000ooooooo
0000o`000003o`000003ooooool0003o000000;o00003_ooool5o`0000kooooo0_l000001?oooooo
0000o`000?ooool3o`0000Sooooo0ol00003ooooo`;o00003oooool2o`0000;ooooo0_l0000Ioooo
o`;o000000Coooooo`000?l0003o00000_ooool2o`00053ooooo000Looooo`03o`000?oooooooooo
057ooooo0_l0000=ooooo`?o00000oooool2o`0000;ooooo0ol00002ooooo`;o00001?ooool2o`00
00?ooooo3Ol00004ooooo`;o00002?ooool2o`0000;ooooo0_l0000=ooooo`;o000000?oooooo`00
0?l000001Oooool2o`0000Kooooo0_l00005ooooo`;o00003Oooool2o`00023ooooo0ol00002oooo
o`?o0000Coooool001cooooo00?o0000ooooooooool0FOooool2o`0000Kooooo0_l000000ooooooo
0000o`000005ooooo`?o00001_ooool3o`0000?ooooo1?l000000ooooooo0000o`000006o`0000Co
oooo0_l00009ooooo`;o000000?oooooo`000?l000004_ooool2o`0000?ooooo0_l00009ooooo`;o
00000_ooool2o`0002Kooooo0_l00007ooooo`?o000000?oooooo`000?l000000_l0001?ooooo`00
7?ooool00ol0003oooooooooo`1Cooooo`So00001_ooool2o`000003ooooool0003o000000Gooooo
1?l00005ooooo`?o00001?ooool4o`0000;ooooo1Ol00005ooooo`;o00002Oooool2o`000003oooo
ool0003o000001;ooooo1?l000001?oooooo0000o`000?ooool4o`0000;ooooo1?l00009ooooo`;o
00007_ooool3o`0000Sooooo0_l000000ooooooo0000o`00001Aooooo`007?ooool00ol0003ooooo
ooooo`1Aooooo`Wo00003?ooool2o`0000Cooooo1_l00003ooooo`;o00001_ooool2o`000003oooo
ool0003o000000Co00000oooool4o`0000Wooooo1Ol0000Dooooo`;o00001?ooool4o`0000;ooooo
0_l0000;ooooo`;o00006oooool2o`000003ooooool0003o000000Wooooo0_l0001Dooooo`007?oo
ool00ol0003oooooooooo`1Aooooo`;o00000oooool4o`0000cooooo0_l00004ooooo`Ko00000ooo
ool2o`0000Kooooo0_l000000ooooooo0000o`00000:o`0000[ooooo1_l00019ooooo`;o0000H_oo
ool001cooooo00?o0000ooooooooool0E_ooool4o`000003ooooool0003o000000oooooo1Ol0000;
ooooo`?o00001Oooool8o`0000Wooooo0ol000001?oooooo0000o`000?l00015ooooo`;o0000I_oo
ool001cooooo00?o0000ooooooooool0E_ooool4o`000003ooooool0003o0000013ooooo0ol0000<
ooooo`;o00001oooool5o`0000Wooooo1?l0001:ooooo`;o00000_ooool2o`0006;ooooo000Loooo
o`03o`000?oooooooooo05Kooooo0_l0000Gooooo`;o00003?ooool4o`00017ooooo1Ol0001>oooo
o`;o00001oooool2o`0005Wooooo000Looooo`03o`000?oooooooooo05?ooooo0_l0000Jooooo`;o
00003?ooool5o`0000oooooo0ol000000ooooooo0000o`000017ooooo`;o00003_ooool2o`0005Wo
oooo000Looooo`03o`000?oooooooooo05?ooooo0_l00002ooooo`;o00005oooool2o`0000cooooo
1?l0000;ooooo`So00001?ooool2o`0004?ooooo0_l0000>ooooo`;o0000FOooool001cooooo00?o
0000ooooooooool0EOooool4o`0000Gooooo0_l00006ooooo`;o00002?ooool3o`0000_ooooo0_l0
000;ooooo`[o00001?ooool2o`0003cooooo0_l00005ooooo`;o00002_ooool2o`0005gooooo000L
ooooo`03o`000?oooooooooo05Gooooo1?l00005ooooo`?o00000_ooool2o`000003ooooool0003o
000000Wooooo1?l0000=ooooo`;o00001Oooool5o`000003ooooool0003o000000Go00000oooool2
o`0003_ooooo0ol00005ooooo`;o00002_ooool2o`0005gooooo000Looooo`03o`000?oooooooooo
05Oooooo0_l00006ooooo`;o00000_ooool2o`0000gooooo0ol00002ooooo`;o00002Oooool2o`00
00;ooooo0_l000000ooooooo0000o`00000;o`0000?ooooo0_l0000fooooo`;o00000oooool5o`00
00[ooooo0_l0001Rooooo`007?ooool2o`0005Sooooo0_l00006ooooo`;o00003_ooool2o`000004
ooooool0003o0000o`0000;ooooo0_l00009ooooo`?o000000?oooooo`000?l000001Oooool2o`00
00;ooooo1?l00004ooooo`;o0000=_ooool2o`0000Cooooo1?l00008ooooo`Co0000H_ooool001co
oooo00?o0000ooooooooool0Hoooool2o`0000[ooooo0_l00004ooooo`;o00001?ooool2o`0000Go
oooo1Ol0000:ooooo`;o00000oooool4o`0003_ooooo1?l0000:ooooo`?o0000Hoooool001cooooo
00?o0000ooooooooool0Hoooool3o`0000Sooooo0ol00004ooooo`Co00000_ooool2o`0000Kooooo
2_l00002ooooo`;o00001Oooool4o`0003Gooooo0_l00004ooooo`Co00000oooool2o`0000Kooooo
0_l0001Sooooo`007?ooool00ol0003oooooooooo`1Tooooo`;o00002?ooool4o`0000Cooooo1?l0
0002ooooo`;o00002?ooool8o`000003ooooool0003o000000?ooooo0_l0000iooooo`;o00001Ooo
ool5o`000003ooooool0003o000006_ooooo000Looooo`03o`000?oooooooooo06Cooooo0_l00005
ooooo`;o00000oooool2o`0000Gooooo1?l000000ooooooo0000o`00000:ooooo`;o000000?ooooo
o`000?l000001Ol00002ooooo`;o0000?oooool2o`000003ooooool0003o000000Co0000Joooool0
01cooooo00?o0000ooooooooool0Hoooool2o`0000Kooooo0_l0000:ooooo`Co00001Oooool2o`00
00_ooooo1Ol00006ooooo`;o0000;Oooool2o`0000cooooo0_l000001?oooooo0000o`000?ooool3
o`000003ooooool0003o000000?ooooo0_l0001Sooooo`007?ooool00ol0003oooooooooo`1Ooooo
o`;o00000_ooool2o`0000Sooooo0_l0000<ooooo`?o00000_ooool2o`0000gooooo0ol00006oooo
o`;o0000:Oooool2o`0000;ooooo0ol0000?ooooo`Co00000_ooool2o`0000?ooooo0_l0001Soooo
o`007?ooool00ol0003oooooooooo`1Oooooo`;o00003?ooool2o`0000Kooooo0_l00004ooooo`?o
00005Oooool2o`0002gooooo0ol00003ooooo`;o00000_ooool2o`0000_ooooo0_l0001^ooooo`00
7?ooool00ol0003oooooooooo`1Tooooo`Co00003Oooool2o`0000Gooooo1_l0000Aooooo`;o0000
;Oooool3o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o00002Oooool2o`0006cooooo
000Looooo`03o`000?oooooooooo06;ooooo1_l00002ooooo`;o00004?ooool6o`0004Cooooo0_l0
0007ooooo`?o00002Oooool2o`0006cooooo000Looooo`03o`000?oooooooooo06;ooooo0_l00000
0ooooooo0000o`000002o`000003ooooool0003o000001Cooooo1_l0000hooooo`;o00003oooool3
o`0007Oooooo000Looooo`03o`000?oooooooooo06;ooooo0_l000000ooooooo0000o`000002o`00
00Wooooo0_l0000<ooooo`Ko0000>?ooool2o`00013ooooo0ol00002ooooo`;o0000L_ooool001co
oooo00?o0000ooooooooool0H_ooool2o`0000Cooooo0ol00007ooooo`?o00003_ooool3o`0004_o
oooo0_l00002ooooo`;o0000L_ooool001cooooo00?o0000ooooooooool0I?ooool2o`0000;ooooo
0ol00007ooooo`?o00000_ooool4o`0000Sooooo1?l00002ooooo`;o0000@?ooool2o`0000Sooooo
0_l0001booooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co
8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0I?ooool2o`0000Cooooo0_l0000;oooo
o`Co00000_ooool2o`0000Gooooo1?l000000ooooooo0000o`00000nooooo`Co00001_ooool2o`00
07Cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9So
oooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1Zooooo`;o00004Oooool2o`0000Oooooo0_l0
0011ooooo`;o00002?ooool2o`0007Cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooo
oooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo08Wooooo0_l0
000iooooo`;o0000Poooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool0
1Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0001^ooooo`;o00002Oooool2o`0000Kooooo0_l0
0006ooooo`;o000000?oooooo`000?l00000=_ooool2o`0000Kooooo0ol0001jooooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_oo
ool00ol0003oooooooooo`1^ooooo`Co00001oooool2o`0000Gooooo0ol00009ooooo`;o0000?_oo
ool3o`0007[ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go410@
okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo073ooooo0_l0000>ooooo`;o00002_oo
ool7o`0000;ooooo0_l0000Yooooo`;o00002_ooool2o`0007_ooooo00001_ooooooMgMgoiRHV?oo
ooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo08Go
oooo0_l00007ooooo`Ko000000Coooooo`000?l0003o0000:?ooool2o`0000;ooooo0_l00003oooo
o`;o0000O_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@
413oZJVY00Kooooo00?o0000ooooooooool0QOooool2o`0000[ooooo0ol00002ooooo`?o000000?o
ooooo`000?l000000_l0000Jooooo`;o00001?ooool2o`0000Cooooo0_l00002ooooo`?o0000O_oo
ool001cooooo00?o0000ooooooooool0Loooool4o`0000[ooooo0_l00002ooooo`;o00000oooool2
o`0000[ooooo0ol000000ooooooo0000o`000003o`0001Oooooo1?l00003ooooo`?o00001?ooool2
o`0000;ooooo0ol0001nooooo`007?ooool00ol0003oooooooooo`1cooooo`Co00002_ooool2o`00
00Kooooo0ol0000:ooooo`;o00001Oooool2o`0001Oooooo1?l00003ooooo`;o00001_ooool2o`00
08;ooooo000Looooo`03o`000?oooooooooo07Gooooo0ol0000<ooooo`;o00000oooool2o`0002_o
oooo1?l00004ooooo`;o00001Oooool2o`0008;ooooo000Looooo`03o`000?oooooooooo07Kooooo
0_l000000ooooooo0000o`000009ooooo`;o0000;?ooool2o`0000;ooooo1?l00004ooooo`Co0000
Qoooool001cooooo00?o0000ooooooooool0NOooool2o`00013ooooo0_l0000Pooooo`;o000000?o
ooooo`000?l000000_l00004ooooo`?o00000oooool4o`0008Oooooo000Looooo`03o`000?oooooo
oooo07[ooooo0ol0000>ooooo`;o00002?ooool3o`0001Gooooo0_l000000ooooooo0000o`000005
ooooo`Co00000oooool2o`0008Wooooo000Looooo`03o`000?oooooooooo07[ooooo0ol0000Boooo
o`;o00001?ooool3o`0000Oooooo0_l00007ooooo`;o00003Oooool2o`0000Gooooo0_l00029oooo
o`007?ooool00ol0003oooooooooo`2?ooooo`?o00002?ooool3o`0000;ooooo0_l00006ooooo`?o
00001Oooool2o`0009Sooooo000Looooo`03o`000?oooooooooo08oooooo0ol00008ooooo`?o0000
00Coooooo`000?l0003o00001Oooool3o`0000;ooooo0_l00002ooooo`;o00000_ooool2o`0009Co
oooo000Looooo`03o`000?oooooooooo09Cooooo0_l00008ooooo`?o00001Oooool2o`000003oooo
ool0003o000000;o00001_ooool2o`0009Cooooo000Looooo`03o`000?oooooooooo09Cooooo0_l0
000Cooooo`;o00000oooool2o`0009Wooooo000Looooo`;o0000Qoooool2o`00017ooooo0_l0000;
ooooo`?o00001Oooool2o`0009Wooooo000Looooo`03o`000?oooooooooo08Kooooo0_l0000Aoooo
o`;o00002oooool3o`000:3ooooo000Looooo`03o`000?oooooooooo08Oooooo0_l00030ooooo`00
7?ooool00ol0003oooooooooo`27ooooo`;o0000`?ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Booooo`Co000000?o410@oooo
ooooool00oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`?o0000
oooooom:ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooo
oooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003o
ooooooooo`3ooooooe;ooooo000Booooo`03oeEEEOmVIVKo00000?ooooooE?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00:Gooooo00Co410@o`000?l0003ooooo0_l000000ol@
413oooooooooo`0Eooooo`Go00000oooool01Oo^k^ko<S8bo`000?l@413oc<c<00Gooooo0_l00000
0ol@413oooooooooo`2>ooooo`00Y_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l00009
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo
00?o0000ooooooooool0Soooool00:Kooooo00Go0000ooooooooooooooooo`00000Iooooo`03oiRH
V?lQ8B7ok^k^00Cooooo00Go0000ooooooooooooooooo`000003ooooo`Go0000T?ooool00:Kooooo
00Go0000ooooooooooooooooo`000009ooooo`Ko00002oooool00onHV9So8B4Qonk^kP03ooooo`05
o`000?nHV9SooooooiRHV?lQ8B400oooool01?m4A4CogMgMooooool0002Aooooo`00Y_ooool01Ol0
003oQhN7oooooonYZJWo000001_ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003oEEEEo`000?l@
413oc<c<00?ooooo00CogMgMoeEEEOoooooo0000TOooool00:Gooooo00?o410@o`000?mgMgL00_l0
00000onHV9Soooooooooo`0Jooooo`06o`000?oooooooooooooooomEEEGoQhN71oooool00omgMgOo
c<c<o`00002Aooooo`00`oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00?ogMgMoa0@4?nH
V9P01_ooool00oo^k^koA4A4o`00002Aooooo`00`oooool01OnHV9So410@o`000?lQ8B7oc<c<00Co
oooo00Coc<c<odA4A?l0003o410@1Oooool00omgMgOo0000ooooo`2@ooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(270) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.63313 .4099 Mdot
.65806 .41429 Mdot
.27421 .35128 Mdot
.55234 .63851 Mdot
.36452 .53794 Mdot
.3437 .38347 Mdot
.49255 .30501 Mdot
.50204 .30519 Mdot
.29937 .39493 Mdot
.67637 .70167 Mdot
.46527 .28848 Mdot
.6019 .61251 Mdot
.49543 .31854 Mdot
.56919 .62495 Mdot
.40105 .66695 Mdot
.53828 .64047 Mdot
.6394 .43969 Mdot
.29766 .51766 Mdot
.54495 .64839 Mdot
.34353 .41633 Mdot
.56849 .52644 Mdot
.57894 .63859 Mdot
.67795 .38379 Mdot
.5727 .62643 Mdot
.60872 .67894 Mdot
.66095 .42429 Mdot
.6341 .40823 Mdot
.61975 .65774 Mdot
.56316 .65438 Mdot
.4665 .31671 Mdot
.46228 .60267 Mdot
.38928 .7811 Mdot
.48116 .51287 Mdot
.75541 .55733 Mdot
.47588 .32852 Mdot
.53466 .33868 Mdot
.31802 .35606 Mdot
.48531 .33805 Mdot
.4657 .28083 Mdot
.48305 .28596 Mdot
.48106 .28704 Mdot
.65872 .42663 Mdot
.50998 .33888 Mdot
.32354 .2572 Mdot
.57922 .6223 Mdot
.78319 .45572 Mdot
.27552 .38977 Mdot
.60831 .64912 Mdot
.68979 .39565 Mdot
.2995 .40023 Mdot
.30107 .64006 Mdot
.50874 .30526 Mdot
.47778 .53222 Mdot
.77898 .28775 Mdot
.50048 .31207 Mdot
.5804 .67562 Mdot
.31789 .39321 Mdot
.55742 .59862 Mdot
.58587 .59929 Mdot
.74501 .52089 Mdot
.54912 .60128 Mdot
.32087 .51684 Mdot
.71481 .41949 Mdot
.29239 .39923 Mdot
.28957 .38584 Mdot
.50441 .34062 Mdot
.66073 .44957 Mdot
.48162 .32621 Mdot
.56509 .65251 Mdot
.3261 .40945 Mdot
.58766 .67104 Mdot
.46481 .28946 Mdot
.6382 .40714 Mdot
.58414 .64591 Mdot
.6631 .33356 Mdot
.54021 .28773 Mdot
.29221 .50761 Mdot
.63656 .48936 Mdot
.38037 .40754 Mdot
.41179 .64961 Mdot
.58324 .64379 Mdot
.48324 .18034 Mdot
.36091 .68261 Mdot
.67717 .39287 Mdot
.52168 .63911 Mdot
.57729 .22306 Mdot
.60894 .6676 Mdot
.46423 .59596 Mdot
.60182 .60497 Mdot
.30087 .58473 Mdot
.32496 .39805 Mdot
.69158 .41592 Mdot
.58671 .63498 Mdot
.57837 .65522 Mdot
.7175 .67552 Mdot
.55243 .64803 Mdot
.61888 .64945 Mdot
.42304 .51325 Mdot
.50462 .29244 Mdot
.49518 .53158 Mdot
.40342 .38685 Mdot
.49128 .54641 Mdot
.59695 .67243 Mdot
.33046 .3856 Mdot
.71448 .4157 Mdot
.50007 .53113 Mdot
.47627 .32084 Mdot
.58352 .63467 Mdot
.46183 .26097 Mdot
.68693 .39232 Mdot
.62505 .67774 Mdot
.32712 .53463 Mdot
.52887 .47557 Mdot
.646 .39257 Mdot
.80372 .57207 Mdot
.55155 .62848 Mdot
.57808 .60228 Mdot
.65534 .41635 Mdot
.35418 .41065 Mdot
.43298 .20052 Mdot
.63888 .41605 Mdot
.49551 .28504 Mdot
.64608 .44524 Mdot
.43416 .50747 Mdot
.35387 .41454 Mdot
.45184 .53412 Mdot
.43539 .52178 Mdot
.34552 .73475 Mdot
.54447 .62706 Mdot
.57135 .55013 Mdot
.33377 .38035 Mdot
.64285 .41062 Mdot
.49773 .3261 Mdot
.53676 .58631 Mdot
.67817 .41577 Mdot
.49514 .30237 Mdot
.31716 .50095 Mdot
.30134 .5306 Mdot
.66113 .38828 Mdot
.8127 .55965 Mdot
.52067 .29674 Mdot
.5195 .30991 Mdot
.30278 .64267 Mdot
.6758 .39268 Mdot
.33573 .51687 Mdot
.47657 .3131 Mdot
.17062 .53225 Mdot
.60877 .68355 Mdot
.3099 .67785 Mdot
.48974 .18582 Mdot
.30114 .63916 Mdot
.5834 .5454 Mdot
.33664 .53126 Mdot
.4952 .30195 Mdot
.60081 .64418 Mdot
.6717 .3996 Mdot
.67517 .41793 Mdot
.5862 .66783 Mdot
.50679 .54478 Mdot
.56057 .61447 Mdot
.48739 .52092 Mdot
.43779 .53188 Mdot
.5843 .63144 Mdot
.80813 .41916 Mdot
.68356 .40341 Mdot
.51713 .61712 Mdot
.31608 .35817 Mdot
.52505 .55495 Mdot
.51018 .33773 Mdot
.54666 .58852 Mdot
.55989 .67227 Mdot
.59471 .60077 Mdot
.51244 .29197 Mdot
.71175 .32248 Mdot
.37281 .41635 Mdot
.47582 .28247 Mdot
.41854 .31872 Mdot
.31757 .3692 Mdot
.59766 .61451 Mdot
.34085 .53962 Mdot
.4813 .52396 Mdot
.59083 .65182 Mdot
.29821 .63348 Mdot
.58667 .60097 Mdot
.59903 .55159 Mdot
.60482 .57599 Mdot
.54496 .21756 Mdot
.72343 .34215 Mdot
.56199 .64621 Mdot
.67426 .63747 Mdot
.31135 .66786 Mdot
.54151 .34791 Mdot
.49715 .32787 Mdot
.35181 .39787 Mdot
.3538 .40609 Mdot
.49475 .24966 Mdot
.78284 .57247 Mdot
.66309 .7202 Mdot
.53585 .59563 Mdot
.48583 .54163 Mdot
.62636 .43693 Mdot
.33571 .52937 Mdot
.65255 .39308 Mdot
.47314 .175 Mdot
.43072 .638 Mdot
.46158 .644 Mdot
.31314 .32735 Mdot
.28414 .38649 Mdot
.48583 .54541 Mdot
.3421 .51969 Mdot
.5683 .60769 Mdot
.68265 .39105 Mdot
.30933 .66012 Mdot
.50741 .5508 Mdot
.59811 .8264 Mdot
.63588 .4216 Mdot
.42319 .72835 Mdot
.498 .31269 Mdot
.29669 .37598 Mdot
.60833 .66941 Mdot
.56173 .63126 Mdot
.69606 .39632 Mdot
.60248 .63389 Mdot
.46676 .68339 Mdot
.61139 .68151 Mdot
.33062 .41721 Mdot
.36893 .4316 Mdot
.47578 .2778 Mdot
.32461 .33189 Mdot
.64442 .39291 Mdot
.82211 .39828 Mdot
.31448 .37876 Mdot
.59848 .56253 Mdot
.46483 .29285 Mdot
.31473 .50355 Mdot
.32084 .38559 Mdot
.35933 .54318 Mdot
.55802 .58448 Mdot
.30298 .35987 Mdot
.32057 .52536 Mdot
.47598 .62881 Mdot
.50073 .53295 Mdot
.29947 .71629 Mdot
.48445 .30266 Mdot
.67498 .43573 Mdot
.5958 .65018 Mdot
.48525 .53385 Mdot
.50913 .55128 Mdot
.40612 .71013 Mdot
.4421 .52201 Mdot
.49358 .55028 Mdot
.37724 .63612 Mdot
.30096 .50718 Mdot
.65564 .24827 Mdot
.46489 .5847 Mdot
.6381 .43827 Mdot
.5812 .65383 Mdot
.44405 .26367 Mdot
.49159 .29971 Mdot
.5622 .60471 Mdot
.53064 .20866 Mdot
.47878 .31222 Mdot
.57139 .60067 Mdot
.45973 .28841 Mdot
.68 .4063 Mdot
.43648 .67587 Mdot
.63247 .42525 Mdot
.58697 .62824 Mdot
.46056 .28983 Mdot
.35193 .3933 Mdot
.66299 .42359 Mdot
.58236 .6372 Mdot
.54142 .60739 Mdot
.48014 .53789 Mdot
.60965 .68245 Mdot
.55736 .31044 Mdot
.6094 .65385 Mdot
.28316 .34357 Mdot
.55616 .6504 Mdot
.39774 .52364 Mdot
.23184 .54784 Mdot
.66836 .38889 Mdot
.44314 .5226 Mdot
.3195 .38973 Mdot
.47239 .67527 Mdot
.42805 .7345 Mdot
.57734 .62388 Mdot
.45263 .52932 Mdot
.38456 .73981 Mdot
.51672 .3203 Mdot
.6035 .60685 Mdot
.31239 .57155 Mdot
.32816 .39694 Mdot
.48745 .54435 Mdot
.52375 .63651 Mdot
.61782 .40762 Mdot
.54759 .64997 Mdot
.3034 .36398 Mdot
.64105 .43717 Mdot
.56055 .65888 Mdot
.54624 .33014 Mdot
.50784 .55657 Mdot
.51569 .3025 Mdot
.4962 .56854 Mdot
.60129 .62224 Mdot
.32245 .40871 Mdot
.66137 .42881 Mdot
.50211 .30975 Mdot
.64314 .39609 Mdot
.31324 .6256 Mdot
.40374 .73175 Mdot
.70071 .35086 Mdot
.31689 .49819 Mdot
.18257 .57459 Mdot
.48983 .283 Mdot
.46593 .513 Mdot
.25977 .34992 Mdot
.61428 .45491 Mdot
.3307 .38904 Mdot
.81669 .54454 Mdot
.32148 .39668 Mdot
.56432 .66814 Mdot
.34406 .40334 Mdot
.71852 .69548 Mdot
.56663 .59102 Mdot
.2824 .37646 Mdot
.41986 .51515 Mdot
.55434 .59027 Mdot
.67824 .41701 Mdot
.42537 .80552 Mdot
.76957 .56829 Mdot
.77782 .57969 Mdot
.31289 .38881 Mdot
.82067 .53259 Mdot
.62205 .67822 Mdot
.55354 .57167 Mdot
.66947 .40355 Mdot
.47111 .51503 Mdot
.31195 .53899 Mdot
.3291 .55061 Mdot
.24251 .5967 Mdot
.4412 .76396 Mdot
.79306 .58184 Mdot
.6727 .41712 Mdot
.36532 .42886 Mdot
.66644 .33399 Mdot
.50498 .55139 Mdot
.50197 .30481 Mdot
.70094 .31031 Mdot
.59605 .59895 Mdot
.47987 .55419 Mdot
.46805 .6859 Mdot
.66704 .43685 Mdot
.71505 .37505 Mdot
.50203 .30801 Mdot
.77727 .58276 Mdot
.66037 .70812 Mdot
.56081 .61256 Mdot
.49155 .29521 Mdot
.50902 .55083 Mdot
.4665 .59637 Mdot
.34654 .74242 Mdot
.25006 .3127 Mdot
.58398 .62399 Mdot
.6696 .31422 Mdot
.59374 .65055 Mdot
.33651 .72359 Mdot
.57013 .60656 Mdot
.66891 .42781 Mdot
.62561 .66387 Mdot
.4704 .5846 Mdot
.15699 .45542 Mdot
.42701 .63218 Mdot
.35645 .54241 Mdot
.57007 .62815 Mdot
.55548 .61647 Mdot
.3252 .50816 Mdot
.68019 .42819 Mdot
.59084 .66035 Mdot
.67297 .25635 Mdot
.58656 .63781 Mdot
.50786 .33709 Mdot
.39097 .69007 Mdot
.38433 .77562 Mdot
.61948 .67822 Mdot
.61693 .40903 Mdot
.5184 .30661 Mdot
.46722 .29733 Mdot
.45018 .51737 Mdot
.49007 .29903 Mdot
.59976 .63689 Mdot
.39062 .69165 Mdot
.67045 .44963 Mdot
.50408 .54798 Mdot
.67005 .43444 Mdot
.22467 .39458 Mdot
.48686 .30384 Mdot
.46497 .52933 Mdot
.78884 .55884 Mdot
.48338 .31936 Mdot
.36327 .4575 Mdot
.62737 .67221 Mdot
.50732 .55166 Mdot
.63004 .40172 Mdot
.32663 .40861 Mdot
.47421 .54353 Mdot
.5007 .31107 Mdot
.57789 .62247 Mdot
.59135 .67973 Mdot
.4896 .2982 Mdot
.67331 .49527 Mdot
.46199 .60038 Mdot
.58983 .63416 Mdot
.68327 .41615 Mdot
.64356 .4159 Mdot
.52725 .59782 Mdot
.59383 .65322 Mdot
.34547 .3832 Mdot
.45155 .52878 Mdot
.45109 .5299 Mdot
.43692 .52404 Mdot
.30477 .38353 Mdot
.16772 .55441 Mdot
.52088 .32463 Mdot
.3884 .77918 Mdot
.60066 .33665 Mdot
.48029 .53034 Mdot
.34391 .37418 Mdot
.55608 .62905 Mdot
.60476 .66372 Mdot
.45847 .29875 Mdot
.23104 .66652 Mdot
.55236 .57259 Mdot
.63395 .42604 Mdot
.49924 .29793 Mdot
.57049 .68052 Mdot
.46379 .24729 Mdot
.31617 .53595 Mdot
.79827 .57802 Mdot
.50301 .30102 Mdot
.702 .41915 Mdot
.50382 .30143 Mdot
.5569 .61643 Mdot
.52161 .63231 Mdot
.65776 .43836 Mdot
.36252 .53675 Mdot
.58542 .66529 Mdot
.57418 .60371 Mdot
.40726 .35919 Mdot
.65575 .33633 Mdot
.36675 .54533 Mdot
.60242 .65893 Mdot
.44767 .50806 Mdot
.36057 .53091 Mdot
.59488 .63082 Mdot
.56787 .66131 Mdot
.57575 .55056 Mdot
.47555 .33668 Mdot
.33311 .49974 Mdot
.14957 .48191 Mdot
.63508 .41998 Mdot
.55855 .31771 Mdot
.48598 .55041 Mdot
.48903 .28348 Mdot
.48576 .70145 Mdot
.46878 .53656 Mdot
.62134 .31549 Mdot
.85629 .61607 Mdot
.47176 .54157 Mdot
.33483 .36018 Mdot
.72949 .66189 Mdot
.5702 .66178 Mdot
.59052 .63221 Mdot
.30878 .53518 Mdot
.65235 .40876 Mdot
.72235 .34061 Mdot
.47392 .28221 Mdot
.56576 .64077 Mdot
.64189 .39199 Mdot
.55422 .21754 Mdot
.47658 .53827 Mdot
.33128 .54263 Mdot
.33476 .50311 Mdot
.59479 .64232 Mdot
.40353 .74837 Mdot
.66601 .42337 Mdot
.58232 .63697 Mdot
.58549 .6072 Mdot
.35255 .3799 Mdot
.67544 .38999 Mdot
.30747 .36076 Mdot
.50949 .5682 Mdot
.75843 .66499 Mdot
.42155 .3072 Mdot
.47807 .30808 Mdot
.45209 .52252 Mdot
.47531 .27731 Mdot
.26784 .37612 Mdot
.45089 .52864 Mdot
.58095 .63674 Mdot
.67633 .44841 Mdot
.58336 .63674 Mdot
.58683 .63698 Mdot
.57754 .61835 Mdot
.79405 .58233 Mdot
.38161 .40679 Mdot
.3394 .54238 Mdot
.60793 .63548 Mdot
.29981 .36858 Mdot
.46486 .24323 Mdot
.68992 .69499 Mdot
.56756 .63102 Mdot
.5773 .60232 Mdot
.61584 .41637 Mdot
.60614 .68388 Mdot
.48268 .314 Mdot
.6647 .43811 Mdot
.59819 .67394 Mdot
.39769 .37292 Mdot
.59465 .6591 Mdot
.70921 .36069 Mdot
.50459 .33506 Mdot
.59581 .70067 Mdot
.51414 .54636 Mdot
.44835 .52647 Mdot
.47614 .54393 Mdot
.43781 .52582 Mdot
.50646 .33882 Mdot
.3338 .36058 Mdot
.27447 .32624 Mdot
.52239 .57254 Mdot
.60194 .64266 Mdot
.52174 .6344 Mdot
.31835 .34556 Mdot
.41509 .51738 Mdot
.80827 .54566 Mdot
.58176 .68641 Mdot
.29713 .38297 Mdot
.42566 .51701 Mdot
.62927 .50148 Mdot
.67568 .43405 Mdot
.31205 .41416 Mdot
.46398 .30482 Mdot
.31756 .52598 Mdot
.26544 .65152 Mdot
.64494 .42712 Mdot
.62218 .44229 Mdot
.32766 .36704 Mdot
.38428 .70426 Mdot
.77455 .27438 Mdot
.3379 .38767 Mdot
.46261 .65649 Mdot
.67311 .40692 Mdot
.48155 .51485 Mdot
.37795 .73286 Mdot
.38345 .69271 Mdot
.29134 .3837 Mdot
.54116 .60894 Mdot
.22767 .36468 Mdot
.34699 .38683 Mdot
.46394 .51739 Mdot
.31095 .38685 Mdot
.51805 .31259 Mdot
.32924 .38001 Mdot
.65995 .37699 Mdot
.54811 .63236 Mdot
.77732 .2834 Mdot
.36251 .65709 Mdot
.55638 .63877 Mdot
.51427 .32052 Mdot
.54009 .34106 Mdot
.55938 .60895 Mdot
.32749 .54804 Mdot
.33267 .35855 Mdot
.30313 .43038 Mdot
.5548 .65915 Mdot
.34148 .40523 Mdot
.61181 .42644 Mdot
.33563 .43465 Mdot
.40515 .38127 Mdot
.4671 .54049 Mdot
.67926 .40214 Mdot
.53723 .28419 Mdot
.49668 .28539 Mdot
.51336 .55773 Mdot
.59173 .61027 Mdot
.68707 .40521 Mdot
.47394 .65882 Mdot
.58982 .5775 Mdot
.58535 .6391 Mdot
.31332 .36293 Mdot
.30699 .40711 Mdot
.3975 .66768 Mdot
.31188 .37742 Mdot
.46079 .51656 Mdot
.6842 .41051 Mdot
.54833 .65253 Mdot
.641 .41512 Mdot
.58346 .65472 Mdot
.46383 .25075 Mdot
.68992 .42119 Mdot
.59875 .56303 Mdot
.54133 .59863 Mdot
.80185 .42859 Mdot
.60899 .63369 Mdot
.58926 .6359 Mdot
.3306 .4154 Mdot
.32844 .50931 Mdot
.56222 .56601 Mdot
.47649 .24484 Mdot
.31409 .51823 Mdot
.65504 .50553 Mdot
.35515 .4114 Mdot
.31841 .50377 Mdot
.24307 .61502 Mdot
.44332 .52378 Mdot
.35096 .52125 Mdot
.51904 .63302 Mdot
.47773 .30506 Mdot
.69075 .44064 Mdot
.55263 .58982 Mdot
.75101 .66934 Mdot
.46137 .59567 Mdot
.4756 .53541 Mdot
.59207 .62811 Mdot
.55232 .6218 Mdot
.64152 .39274 Mdot
.47498 .17698 Mdot
.26609 .36022 Mdot
.48787 .52362 Mdot
.64035 .42373 Mdot
.4868 .18243 Mdot
.28339 .37539 Mdot
.30196 .518 Mdot
.46637 .27832 Mdot
.71231 .3882 Mdot
.47944 .53447 Mdot
.4891 .30271 Mdot
.28455 .33464 Mdot
.29843 .6284 Mdot
.54775 .64928 Mdot
.32863 .36066 Mdot
.30056 .63788 Mdot
.6282 .67036 Mdot
.49767 .24973 Mdot
.53313 .35364 Mdot
.69061 .39937 Mdot
.49099 .29767 Mdot
.34095 .54514 Mdot
.6392 .44419 Mdot
.67182 .43421 Mdot
.47892 .31685 Mdot
.83268 .47592 Mdot
.38507 .73889 Mdot
.45609 .28605 Mdot
.41026 .70153 Mdot
.30087 .63525 Mdot
.48273 .53692 Mdot
.337 .54062 Mdot
.37058 .43106 Mdot
.65858 .42617 Mdot
.69757 .31273 Mdot
.30032 .6398 Mdot
.62311 .66666 Mdot
.31933 .52281 Mdot
.55766 .22204 Mdot
.5085 .27734 Mdot
.48409 .30857 Mdot
.40794 .35777 Mdot
.31933 .51359 Mdot
.54317 .58883 Mdot
.24471 .70751 Mdot
.5729 .59431 Mdot
.47571 .31185 Mdot
.46755 .68492 Mdot
.655 .39564 Mdot
.51594 .32955 Mdot
.46627 .6836 Mdot
.60379 .65911 Mdot
.54853 .62405 Mdot
.38524 .40071 Mdot
.69742 .4045 Mdot
.50582 .55457 Mdot
.55995 .64267 Mdot
.56526 .59906 Mdot
.50669 .5373 Mdot
.37602 .7669 Mdot
.53999 .47142 Mdot
.49316 .52128 Mdot
.2899 .36633 Mdot
.50519 .54573 Mdot
.48572 .5226 Mdot
.62492 .4023 Mdot
.39832 .39616 Mdot
.50191 .55292 Mdot
.58686 .62409 Mdot
.58824 .63026 Mdot
.46376 .28037 Mdot
.3836 .73878 Mdot
.38128 .69984 Mdot
.27069 .34824 Mdot
.29897 .55204 Mdot
.53607 .61414 Mdot
.67901 .39741 Mdot
.35875 .51471 Mdot
.45137 .51495 Mdot
.63547 .42733 Mdot
.55209 .64089 Mdot
.35148 .37608 Mdot
.4642 .53733 Mdot
.44083 .50554 Mdot
.32452 .52569 Mdot
.47788 .27506 Mdot
.65205 .4982 Mdot
.34698 .38051 Mdot
.60589 .67849 Mdot
.30337 .56073 Mdot
.33691 .40209 Mdot
.48454 .53866 Mdot
.50288 .5402 Mdot
.67864 .40966 Mdot
.70374 .40807 Mdot
.39814 .52871 Mdot
.30201 .3784 Mdot
.28237 .294 Mdot
.50278 .2945 Mdot
.60416 .62829 Mdot
.49399 .27945 Mdot
.68396 .38844 Mdot
.34434 .73456 Mdot
.32716 .50211 Mdot
.48112 .31205 Mdot
.50524 .55086 Mdot
.68117 .43042 Mdot
.687 .38879 Mdot
.58417 .62998 Mdot
.57483 .63612 Mdot
.30487 .4143 Mdot
.31223 .6761 Mdot
.45792 .29684 Mdot
.30597 .52439 Mdot
.27053 .35235 Mdot
.56976 .67004 Mdot
.66722 .39425 Mdot
.33651 .7692 Mdot
.60339 .62469 Mdot
.30087 .37139 Mdot
.66033 .41478 Mdot
.31078 .5362 Mdot
.34456 .54229 Mdot
.57172 .64865 Mdot
.58438 .54718 Mdot
.48296 .32162 Mdot
.67616 .42057 Mdot
.68583 .45618 Mdot
.61012 .64294 Mdot
.5712 .63175 Mdot
.62906 .67238 Mdot
.45415 .28584 Mdot
.52162 .60486 Mdot
.3611 .53781 Mdot
.65256 .39006 Mdot
.56787 .6451 Mdot
.32222 .51286 Mdot
.45467 .53892 Mdot
.46459 .5351 Mdot
.29924 .39733 Mdot
.32764 .54896 Mdot
.3299 .51473 Mdot
.31155 .5188 Mdot
.70034 .30963 Mdot
.51305 .62212 Mdot
.3823 .54787 Mdot
.54037 .60746 Mdot
.30103 .63405 Mdot
.53235 .63175 Mdot
.51283 .30623 Mdot
.31885 .40744 Mdot
.57029 .61563 Mdot
.54061 .60503 Mdot
.64057 .49586 Mdot
.54256 .6477 Mdot
.53022 .59552 Mdot
.65625 .39357 Mdot
.66472 .46572 Mdot
.35259 .40342 Mdot
.49426 .18869 Mdot
.29382 .76977 Mdot
.54169 .58248 Mdot
.38614 .70111 Mdot
.68373 .4259 Mdot
.46533 .27915 Mdot
.40297 .71031 Mdot
.49878 .27903 Mdot
.64724 .41553 Mdot
.55807 .66413 Mdot
.68874 .47629 Mdot
.31616 .51833 Mdot
.55929 .61636 Mdot
.48714 .32788 Mdot
.55984 .61534 Mdot
.51435 .32861 Mdot
.81722 .51682 Mdot
.36117 .70206 Mdot
.573 .59207 Mdot
.55355 .64905 Mdot
.56136 .52338 Mdot
.57057 .63322 Mdot
.24684 .33115 Mdot
.66415 .41057 Mdot
.52223 .55758 Mdot
.5606 .66705 Mdot
.76657 .57321 Mdot
.5898 .61648 Mdot
.50378 .71234 Mdot
.55978 .59395 Mdot
.22083 .6415 Mdot
.56426 .58668 Mdot
.58737 .60508 Mdot
.50481 .32669 Mdot
.47092 .28526 Mdot
.60981 .44205 Mdot
.49913 .54874 Mdot
.55056 .21886 Mdot
.57609 .60383 Mdot
.2724 .37026 Mdot
.62729 .58509 Mdot
.32806 .51214 Mdot
.6474 .39451 Mdot
.89403 .56616 Mdot
.51535 .33694 Mdot
.2997 .35708 Mdot
.46242 .62084 Mdot
.29373 .36173 Mdot
.28739 .39646 Mdot
.71417 .43904 Mdot
.33523 .54069 Mdot
.59372 .65789 Mdot
.75873 .54944 Mdot
.65361 .33217 Mdot
.61001 .64419 Mdot
.32362 .34297 Mdot
.5754 .55291 Mdot
.41245 .56893 Mdot
.29785 .51095 Mdot
.33995 .52674 Mdot
.49735 .3081 Mdot
.27297 .36689 Mdot
.49064 .52683 Mdot
.31933 .50299 Mdot
.34956 .40442 Mdot
.44535 .52105 Mdot
.39328 .40431 Mdot
.66715 .42364 Mdot
.81982 .53595 Mdot
.78706 .4519 Mdot
.51283 .29752 Mdot
.47926 .24316 Mdot
.68221 .44629 Mdot
.63321 .43045 Mdot
.49433 .54442 Mdot
.29908 .3869 Mdot
.69741 .43379 Mdot
.56699 .6463 Mdot
.50461 .54597 Mdot
.59525 .64612 Mdot
.29962 .51218 Mdot
.58925 .61983 Mdot
.3471 .40419 Mdot
.50564 .32861 Mdot
.32556 .39546 Mdot
.49468 .30469 Mdot
.40205 .79093 Mdot
.54027 .5966 Mdot
.57291 .63079 Mdot
.38994 .69188 Mdot
.67327 .38602 Mdot
.75202 .56685 Mdot
.30304 .37693 Mdot
.31881 .39279 Mdot
.55648 .66386 Mdot
.6514 .44704 Mdot
.34944 .56032 Mdot
.41249 .69172 Mdot
.56412 .5946 Mdot
.66296 .40961 Mdot
.54279 .65257 Mdot
.54657 .26012 Mdot
.36478 .67622 Mdot
.66534 .38351 Mdot
.15829 .45028 Mdot
.5444 .59194 Mdot
.4677 .51244 Mdot
.56702 .55664 Mdot
.41524 .7594 Mdot
.5832 .57268 Mdot
.63583 .42329 Mdot
.49409 .52856 Mdot
.67096 .3962 Mdot
.33801 .39815 Mdot
.51681 .33016 Mdot
.6671 .39993 Mdot
.54914 .59359 Mdot
.29384 .76888 Mdot
.49898 .33371 Mdot
.56301 .61841 Mdot
.48407 .32923 Mdot
.71379 .41132 Mdot
.65147 .40216 Mdot
.44557 .52085 Mdot
.4623 .65444 Mdot
.48099 .31714 Mdot
.60182 .63885 Mdot
.6916 .32342 Mdot
.54634 .64845 Mdot
.29924 .54552 Mdot
.53872 .62719 Mdot
.55144 .64097 Mdot
.15358 .53374 Mdot
.47601 .67409 Mdot
.42719 .28949 Mdot
.43941 .30929 Mdot
.71425 .32442 Mdot
.63126 .39712 Mdot
.29915 .52044 Mdot
.62786 .48505 Mdot
.44919 .52972 Mdot
.28806 .36664 Mdot
.57494 .61925 Mdot
.44039 .53013 Mdot
.45538 .30018 Mdot
.34838 .51993 Mdot
.58682 .60112 Mdot
.30168 .3476 Mdot
.43544 .51178 Mdot
.48692 .3052 Mdot
.6568 .42689 Mdot
.64574 .40192 Mdot
.38257 .42083 Mdot
.5657 .64404 Mdot
.57772 .63673 Mdot
.48176 .33143 Mdot
.59624 .56698 Mdot
.31084 .52471 Mdot
.41967 .51527 Mdot
.47985 .3268 Mdot
.36331 .67769 Mdot
.69788 .4038 Mdot
.5539 .62553 Mdot
.39236 .68568 Mdot
.72062 .33482 Mdot
.69297 .64578 Mdot
.33498 .5256 Mdot
.42058 .73871 Mdot
.63598 .42309 Mdot
.49928 .32537 Mdot
.242 .60384 Mdot
.62812 .67726 Mdot
.55065 .6103 Mdot
.42719 .74147 Mdot
.41308 .69345 Mdot
.46325 .62343 Mdot
.50719 .55362 Mdot
.37841 .72592 Mdot
.55168 .66031 Mdot
.594 .67887 Mdot
.53588 .61078 Mdot
.53989 .63019 Mdot
.66037 .40419 Mdot
.77331 .58937 Mdot
.32758 .37113 Mdot
.68031 .62026 Mdot
.29134 .52026 Mdot
.62088 .6638 Mdot
.59861 .66902 Mdot
.66737 .55349 Mdot
.44738 .71979 Mdot
.66927 .41382 Mdot
.64012 .38578 Mdot
.50833 .29168 Mdot
.54232 .64467 Mdot
.30125 .37451 Mdot
.53822 .56144 Mdot
.31394 .4033 Mdot
.65978 .40633 Mdot
.35663 .39304 Mdot
.52363 .33281 Mdot
.32788 .36002 Mdot
.29339 .3772 Mdot
.51051 .32389 Mdot
.69497 .4172 Mdot
.60852 .63079 Mdot
.51119 .32332 Mdot
.36138 .55473 Mdot
.30091 .52029 Mdot
.63311 .45872 Mdot
.48573 .51656 Mdot
.59261 .5958 Mdot
.30441 .28154 Mdot
.31765 .3554 Mdot
.43841 .69782 Mdot
.69375 .41571 Mdot
.33548 .49792 Mdot
.6637 .39856 Mdot
.39248 .53432 Mdot
.33093 .52389 Mdot
.5212 .63799 Mdot
.28596 .68697 Mdot
.52301 .35742 Mdot
.61015 .62284 Mdot
.66634 .46498 Mdot
.31473 .40271 Mdot
.51476 .32355 Mdot
.50195 .22204 Mdot
.48785 .52311 Mdot
.61066 .43268 Mdot
.70446 .38838 Mdot
.45017 .52962 Mdot
.4969 .32619 Mdot
.79004 .43953 Mdot
.55894 .6398 Mdot
.49958 .28282 Mdot
.53894 .62696 Mdot
.80728 .56727 Mdot
.2827 .50551 Mdot
.43698 .52867 Mdot
.56276 .66744 Mdot
.28334 .37464 Mdot
.55741 .66425 Mdot
.76556 .64226 Mdot
.32282 .70906 Mdot
.53608 .60155 Mdot
.43776 .72104 Mdot
.26182 .36559 Mdot
.67122 .39344 Mdot
.46852 .52444 Mdot
.48045 .53697 Mdot
.59275 .68289 Mdot
.4004 .84816 Mdot
.33267 .50742 Mdot
.35963 .3451 Mdot
.54643 .59538 Mdot
.58238 .64326 Mdot
.64657 .50055 Mdot
.81538 .51756 Mdot
.43101 .51041 Mdot
.55231 .60589 Mdot
.44629 .74147 Mdot
.50657 .31819 Mdot
.55665 .6549 Mdot
.59234 .64662 Mdot
.32745 .4362 Mdot
.50306 .32663 Mdot
.35105 .38311 Mdot
.44429 .52513 Mdot
.31663 .41018 Mdot
.36394 .53793 Mdot
.42454 .72931 Mdot
.36066 .75148 Mdot
.37111 .6732 Mdot
.33504 .54935 Mdot
.61768 .68022 Mdot
.50126 .57249 Mdot
.54448 .62039 Mdot
.34231 .52559 Mdot
.46554 .31542 Mdot
.66441 .40721 Mdot
.8158 .55336 Mdot
.48362 .53949 Mdot
.61572 .66686 Mdot
.30517 .49393 Mdot
.67252 .40084 Mdot
.81027 .41524 Mdot
.65393 .40785 Mdot
.48838 .30923 Mdot
.49393 .24801 Mdot
.32671 .51998 Mdot
.66371 .39807 Mdot
.32637 .41337 Mdot
.50654 .2584 Mdot
.62478 .69236 Mdot
.52306 .33376 Mdot
.69537 .38673 Mdot
.66169 .38158 Mdot
.66185 .45141 Mdot
.57429 .67426 Mdot
.43881 .71303 Mdot
.45324 .52103 Mdot
.49019 .3335 Mdot
.29029 .35398 Mdot
.31459 .68394 Mdot
.75835 .47966 Mdot
.36652 .69278 Mdot
.52316 .63865 Mdot
.58942 .62114 Mdot
.59434 .63938 Mdot
.5057 .53385 Mdot
.48842 .57565 Mdot
.53829 .60286 Mdot
.4583 .29895 Mdot
.34528 .39714 Mdot
.55364 .59634 Mdot
.45926 .53016 Mdot
.4303 .53548 Mdot
.34042 .50233 Mdot
.79997 .58029 Mdot
.63095 .45927 Mdot
.67049 .40145 Mdot
.30421 .3647 Mdot
.35748 .41161 Mdot
.31608 .50166 Mdot
.49908 .30132 Mdot
.65121 .40967 Mdot
.2186 .6323 Mdot
.31408 .52314 Mdot
.58538 .62153 Mdot
.39047 .69052 Mdot
.44231 .75318 Mdot
.58006 .66544 Mdot
.57742 .6172 Mdot
.49972 .5511 Mdot
.2989 .37249 Mdot
.69087 .70974 Mdot
.80638 .42126 Mdot
.32458 .51399 Mdot
.30698 .51221 Mdot
.65276 .45083 Mdot
.59926 .6239 Mdot
.48255 .32316 Mdot
.38779 .74252 Mdot
.54648 .33638 Mdot
.58127 .22626 Mdot
.25643 .34207 Mdot
.59591 .65811 Mdot
.74654 .62861 Mdot
.57374 .58064 Mdot
.71344 .41831 Mdot
.6986 .42338 Mdot
.67148 .41594 Mdot
.50612 .31436 Mdot
.3004 .62422 Mdot
.47775 .28794 Mdot
.42493 .5163 Mdot
.64932 .43308 Mdot
.46892 .6525 Mdot
.31664 .39118 Mdot
.53602 .63803 Mdot
.33908 .53771 Mdot
.29886 .57669 Mdot
.47611 .52706 Mdot
.4218 .73546 Mdot
.34364 .37383 Mdot
.67527 .43739 Mdot
.53626 .63995 Mdot
.459 .2492 Mdot
.36843 .71158 Mdot
.25364 .35303 Mdot
.44111 .53107 Mdot
.3203 .51688 Mdot
.67306 .70272 Mdot
.31601 .53156 Mdot
.48011 .31267 Mdot
.5409 .59779 Mdot
.59669 .61959 Mdot
.59001 .6374 Mdot
.53497 .59363 Mdot
.50252 .3135 Mdot
.61515 .63535 Mdot
.39939 .52624 Mdot
.43892 .52415 Mdot
.46861 .57614 Mdot
.35079 .53858 Mdot
.50572 .2969 Mdot
.34114 .40118 Mdot
.49272 .55049 Mdot
.32571 .49576 Mdot
.52718 .62872 Mdot
.54452 .60251 Mdot
.43151 .51543 Mdot
.51815 .62967 Mdot
.58977 .59108 Mdot
.33672 .37504 Mdot
.46497 .5907 Mdot
.34346 .50593 Mdot
.33248 .53426 Mdot
.48485 .29856 Mdot
.66462 .3977 Mdot
.32956 .49995 Mdot
.28368 .34526 Mdot
.55501 .65435 Mdot
.53691 .62217 Mdot
.68567 .38272 Mdot
.2989 .63583 Mdot
.34122 .50276 Mdot
.52298 .60283 Mdot
.66115 .38555 Mdot
.70571 .3889 Mdot
.55231 .60842 Mdot
.61912 .64778 Mdot
.62474 .4042 Mdot
.30615 .50865 Mdot
.49001 .29504 Mdot
.34927 .6632 Mdot
.52027 .32088 Mdot
.65862 .4286 Mdot
.49836 .53653 Mdot
.68871 .42621 Mdot
.48912 .52379 Mdot
.64964 .2271 Mdot
.53769 .60489 Mdot
.73986 .40001 Mdot
.4125 .519 Mdot
.31278 .3896 Mdot
.30807 .39203 Mdot
.45826 .53343 Mdot
.63894 .43313 Mdot
.46059 .51732 Mdot
.32609 .54127 Mdot
.71217 .32408 Mdot
.62459 .40224 Mdot
.29437 .37944 Mdot
.31357 .35286 Mdot
.48082 .32793 Mdot
.59006 .61944 Mdot
.55365 .62637 Mdot
.33082 .36185 Mdot
.55305 .32703 Mdot
.6919 .405 Mdot
.57779 .63626 Mdot
.49731 .52507 Mdot
.33252 .37433 Mdot
.48747 .3663 Mdot
.69176 .43871 Mdot
.57104 .67327 Mdot
.32815 .71742 Mdot
.51301 .33328 Mdot
.60741 .66993 Mdot
.61311 .62819 Mdot
.3341 .5118 Mdot
.42127 .74161 Mdot
.30277 .64179 Mdot
.51708 .33667 Mdot
.44896 .52518 Mdot
.5849 .66701 Mdot
.31414 .39384 Mdot
.52672 .61567 Mdot
.75622 .72073 Mdot
.43594 .51982 Mdot
.56507 .64203 Mdot
.54669 .56065 Mdot
.64074 .415 Mdot
.58141 .64019 Mdot
.46389 .25155 Mdot
.31011 .3671 Mdot
.56214 .64071 Mdot
.57343 .53108 Mdot
.48378 .32858 Mdot
.47514 .52716 Mdot
.31803 .51579 Mdot
.46334 .64087 Mdot
.42294 .8042 Mdot
.31859 .34596 Mdot
.35413 .53923 Mdot
.58628 .61205 Mdot
.26901 .35566 Mdot
.47392 .28433 Mdot
.46133 .52417 Mdot
.6094 .67404 Mdot
.50421 .29111 Mdot
.50919 .31769 Mdot
.32409 .52167 Mdot
.8233 .36151 Mdot
.54496 .58303 Mdot
.56157 .62354 Mdot
.82042 .39117 Mdot
.68779 .36731 Mdot
.56224 .61647 Mdot
.58811 .609 Mdot
.48467 .30238 Mdot
.29544 .61593 Mdot
.42185 .73693 Mdot
.43774 .53461 Mdot
.51575 .31961 Mdot
.27219 .33622 Mdot
.31588 .35998 Mdot
.35673 .53651 Mdot
.65953 .41547 Mdot
.31582 .49979 Mdot
.32574 .37641 Mdot
.58508 .62651 Mdot
.47671 .29673 Mdot
.6445 .72871 Mdot
.50795 .33377 Mdot
.29518 .345 Mdot
.71391 .41592 Mdot
.7253 .69132 Mdot
.77334 .70832 Mdot
.53211 .46533 Mdot
.50107 .25042 Mdot
.32845 .51184 Mdot
.80692 .42023 Mdot
.55722 .59508 Mdot
.76421 .63612 Mdot
.55953 .6188 Mdot
.4214 .50563 Mdot
.33049 .40806 Mdot
.44547 .52102 Mdot
.48622 .5218 Mdot
.42608 .73303 Mdot
.50909 .31242 Mdot
.46693 .31374 Mdot
.49919 .53343 Mdot
.4858 .31229 Mdot
.56136 .63616 Mdot
.34247 .38609 Mdot
.70644 .26949 Mdot
.55682 .59346 Mdot
.52032 .55467 Mdot
.52513 .30448 Mdot
.68929 .34363 Mdot
.27891 .33538 Mdot
.75467 .60645 Mdot
.53762 .21556 Mdot
.48548 .32283 Mdot
.79621 .58327 Mdot
.3032 .36781 Mdot
.4933 .5506 Mdot
.26764 .36163 Mdot
.5582 .62456 Mdot
.59683 .65786 Mdot
.51062 .5443 Mdot
.58315 .60655 Mdot
.72624 .64174 Mdot
.60762 .6142 Mdot
.63273 .5402 Mdot
.54037 .6091 Mdot
.7111 .45346 Mdot
.4654 .28678 Mdot
.50026 .53612 Mdot
.36721 .63245 Mdot
.54804 .6347 Mdot
.63057 .40043 Mdot
.5115 .30047 Mdot
.51764 .20753 Mdot
.50483 .31657 Mdot
.32435 .39651 Mdot
.50307 .30535 Mdot
.61379 .63572 Mdot
.64595 .42028 Mdot
.32023 .38144 Mdot
.47958 .53128 Mdot
.2859 .35919 Mdot
.55678 .63907 Mdot
.43686 .35409 Mdot
.30171 .35726 Mdot
.62779 .67124 Mdot
.64482 .41709 Mdot
.31265 .73955 Mdot
.67851 .45096 Mdot
.57807 .62749 Mdot
.5707 .62093 Mdot
.42843 .51062 Mdot
.49547 .302 Mdot
.69183 .42416 Mdot
.40758 .35526 Mdot
.33536 .49766 Mdot
.66489 .4171 Mdot
.58642 .55969 Mdot
.38506 .70564 Mdot
.64575 .39283 Mdot
.44554 .74709 Mdot
.47788 .31188 Mdot
.63673 .41548 Mdot
.6259 .59755 Mdot
.67829 .62164 Mdot
.32641 .5358 Mdot
.32666 .41416 Mdot
.39436 .71073 Mdot
.31212 .3607 Mdot
.46048 .25229 Mdot
.32873 .41651 Mdot
.49591 .33114 Mdot
.58924 .55578 Mdot
.46739 .68383 Mdot
.4782 .33398 Mdot
.42259 .34416 Mdot
.32041 .36735 Mdot
.49073 .5218 Mdot
.46689 .58263 Mdot
.44361 .50525 Mdot
.46141 .51024 Mdot
.51362 .33795 Mdot
.63578 .41658 Mdot
.64197 .44498 Mdot
.53654 .55916 Mdot
.6514 .39552 Mdot
.33433 .38792 Mdot
.37994 .6693 Mdot
.78857 .55869 Mdot
.46092 .29583 Mdot
.46424 .5979 Mdot
.59699 .67128 Mdot
.34305 .40549 Mdot
.33553 .39143 Mdot
.50788 .31397 Mdot
.69377 .60347 Mdot
.4527 .51061 Mdot
.71675 .38599 Mdot
.6447 .42818 Mdot
.63999 .4143 Mdot
.68824 .39236 Mdot
.29823 .62547 Mdot
.51467 .31946 Mdot
.63911 .43166 Mdot
.53372 .59544 Mdot
.59364 .6193 Mdot
.48389 .54764 Mdot
.30041 .51329 Mdot
.6093 .61845 Mdot
.45935 .51665 Mdot
.55194 .61104 Mdot
.30992 .3856 Mdot
.62483 .57937 Mdot
.4488 .53148 Mdot
.30058 .37509 Mdot
.3045 .38207 Mdot
.44759 .52587 Mdot
.6232 .57892 Mdot
.69852 .67679 Mdot
.59815 .68581 Mdot
.72059 .42705 Mdot
.30475 .39208 Mdot
.41299 .37328 Mdot
.73898 .40587 Mdot
.60023 .63442 Mdot
.41853 .51757 Mdot
.34224 .39137 Mdot
.63369 .39243 Mdot
.56524 .63078 Mdot
.49522 .54333 Mdot
.3203 .5312 Mdot
.47287 .52879 Mdot
.50008 .55074 Mdot
.68123 .39462 Mdot
.29459 .28976 Mdot
.64277 .39114 Mdot
.35644 .42118 Mdot
.48521 .53006 Mdot
.77541 .27822 Mdot
.31872 .40331 Mdot
.70851 .31987 Mdot
.46589 .67985 Mdot
.54667 .61322 Mdot
.30618 .36436 Mdot
.61303 .42048 Mdot
.50443 .34139 Mdot
.44791 .71139 Mdot
.66205 .39683 Mdot
.48964 .55161 Mdot
.48061 .54465 Mdot
.32922 .37166 Mdot
.66629 .43133 Mdot
.61441 .63219 Mdot
.64498 .40479 Mdot
.47088 .29559 Mdot
.54555 .6604 Mdot
.54905 .21853 Mdot
.49198 .52884 Mdot
.65212 .3924 Mdot
.29036 .35103 Mdot
.36227 .53622 Mdot
.56814 .59187 Mdot
.52596 .207 Mdot
.58748 .613 Mdot
.47367 .32428 Mdot
.42281 .53589 Mdot
.65952 .66805 Mdot
.57346 .60855 Mdot
.60122 .66569 Mdot
.52441 .34239 Mdot
.56955 .60681 Mdot
.56377 .65399 Mdot
.79227 .44257 Mdot
.65115 .38838 Mdot
.55542 .59618 Mdot
.33874 .37198 Mdot
.59865 .53107 Mdot
.58216 .64771 Mdot
.47367 .24337 Mdot
.41131 .75518 Mdot
.40786 .52408 Mdot
.5274 .55619 Mdot
.34227 .73229 Mdot
.56705 .62149 Mdot
.60221 .63346 Mdot
.54205 .65752 Mdot
.7502 .63104 Mdot
.32021 .37226 Mdot
.27918 .3709 Mdot
.35982 .53823 Mdot
.42953 .74117 Mdot
.32913 .53012 Mdot
.47456 .28408 Mdot
.46152 .62971 Mdot
.44165 .5276 Mdot
.66679 .39674 Mdot
.58898 .64018 Mdot
.28372 .35516 Mdot
.55772 .62941 Mdot
.59733 .68104 Mdot
.33458 .38444 Mdot
.33919 .39499 Mdot
.3641 .41681 Mdot
.3173 .51299 Mdot
.67104 .40817 Mdot
.55458 .5868 Mdot
.31462 .51631 Mdot
.50726 .53756 Mdot
.34554 .6746 Mdot
.67139 .41084 Mdot
.65482 .39103 Mdot
.65174 .44184 Mdot
.58617 .60322 Mdot
.55338 .66756 Mdot
.48321 .28715 Mdot
.68573 .38266 Mdot
.47784 .31885 Mdot
.30663 .36295 Mdot
.34774 .39012 Mdot
.55766 .6234 Mdot
.58777 .56397 Mdot
.34617 .54026 Mdot
.30629 .35501 Mdot
.48148 .55271 Mdot
.35155 .51798 Mdot
.59511 .65196 Mdot
.30889 .36078 Mdot
.32117 .54498 Mdot
.69347 .61562 Mdot
.57597 .25797 Mdot
.35958 .53243 Mdot
.47773 .51668 Mdot
.74816 .49467 Mdot
.32065 .70135 Mdot
.35414 .51161 Mdot
.46495 .28787 Mdot
.60127 .62042 Mdot
.44479 .53773 Mdot
.33923 .50408 Mdot
.30187 .65555 Mdot
.32838 .38149 Mdot
.46469 .51201 Mdot
.53325 .4781 Mdot
.78637 .56073 Mdot
.36227 .53415 Mdot
.65168 .39179 Mdot
.69853 .39329 Mdot
.5821 .61718 Mdot
.4621 .6383 Mdot
.45742 .30526 Mdot
.35662 .4148 Mdot
.27832 .36492 Mdot
.70434 .41625 Mdot
.36826 .67411 Mdot
.3322 .36633 Mdot
.60317 .62792 Mdot
.29548 .5028 Mdot
.52944 .59847 Mdot
.40183 .54155 Mdot
.65557 .67277 Mdot
.54769 .55608 Mdot
.36152 .53449 Mdot
.45977 .31095 Mdot
.504 .32931 Mdot
.49851 .30613 Mdot
.33281 .36958 Mdot
.40095 .7118 Mdot
.2752 .36304 Mdot
.8207 .40269 Mdot
.33299 .50707 Mdot
.17842 .56034 Mdot
.55566 .57382 Mdot
.54683 .61857 Mdot
.54333 .64344 Mdot
.50152 .53212 Mdot
.568 .62303 Mdot
.5011 .28876 Mdot
.31881 .41002 Mdot
.52962 .36165 Mdot
.68442 .41497 Mdot
.81255 .41747 Mdot
.31553 .38962 Mdot
.50561 .55665 Mdot
.34419 .53868 Mdot
.36158 .75667 Mdot
.32617 .55312 Mdot
.34103 .3668 Mdot
.57435 .65533 Mdot
.64643 .45086 Mdot
.22555 .65226 Mdot
.58506 .64022 Mdot
.31601 .35487 Mdot
.27393 .34229 Mdot
.68072 .60893 Mdot
.54742 .7091 Mdot
.54475 .3455 Mdot
.38925 .6835 Mdot
.3456 .55123 Mdot
.48492 .51426 Mdot
.39387 .74785 Mdot
.32573 .37506 Mdot
.29468 .38984 Mdot
.37199 .54243 Mdot
.6853 .3413 Mdot
.64678 .4365 Mdot
.68621 .45182 Mdot
.4982 .28977 Mdot
.54466 .61219 Mdot
.31716 .36388 Mdot
.70121 .43534 Mdot
.34681 .62473 Mdot
.49555 .31172 Mdot
.30053 .35636 Mdot
.58763 .61179 Mdot
.57527 .60845 Mdot
.32708 .52881 Mdot
.42472 .53241 Mdot
.44384 .50566 Mdot
.71056 .32314 Mdot
.37561 .69861 Mdot
.46496 .67908 Mdot
.55055 .61027 Mdot
.68553 .39216 Mdot
.44952 .52744 Mdot
.33662 .54116 Mdot
.52717 .61455 Mdot
.75047 .66634 Mdot
.64706 .38228 Mdot
.47991 .31929 Mdot
.48574 .53615 Mdot
.42857 .72558 Mdot
.58595 .61003 Mdot
.55947 .61938 Mdot
.57333 .67368 Mdot
.71345 .6997 Mdot
.31942 .40735 Mdot
.67166 .3893 Mdot
.31957 .51455 Mdot
.65129 .40382 Mdot
.35195 .43004 Mdot
.46259 .59207 Mdot
.5752 .59173 Mdot
.63856 .39051 Mdot
.64965 .41401 Mdot
.47261 .3229 Mdot
.50875 .32858 Mdot
.30412 .33931 Mdot
.58643 .60629 Mdot
.43579 .52268 Mdot
.63877 .42799 Mdot
.34265 .41792 Mdot
.32868 .5281 Mdot
.47107 .24163 Mdot
.54116 .60311 Mdot
.32488 .37089 Mdot
.46846 .5231 Mdot
.68352 .40671 Mdot
.30378 .37385 Mdot
.4943 .55088 Mdot
.30346 .51433 Mdot
.59394 .66379 Mdot
.25691 .36716 Mdot
.4985 .54602 Mdot
.56542 .59196 Mdot
.63719 .58334 Mdot
.4623 .63625 Mdot
.47481 .55093 Mdot
.35217 .39707 Mdot
.49106 .54429 Mdot
.69967 .39987 Mdot
.67737 .63645 Mdot
.29503 .39188 Mdot
.69114 .4742 Mdot
.46899 .68936 Mdot
.49234 .52689 Mdot
.67033 .39385 Mdot
.39079 .40847 Mdot
.65512 .3427 Mdot
.32113 .69631 Mdot
.57065 .64175 Mdot
.31265 .36079 Mdot
.32408 .53324 Mdot
.46735 .31377 Mdot
.45898 .26799 Mdot
.38124 .43569 Mdot
.29864 .3818 Mdot
.58921 .64127 Mdot
.63612 .41737 Mdot
.48229 .31704 Mdot
.65265 .50045 Mdot
.27128 .35489 Mdot
.34081 .37289 Mdot
.56659 .66695 Mdot
.3303 .53079 Mdot
.49486 .57335 Mdot
.30269 .40033 Mdot
.30173 .40254 Mdot
.79001 .44481 Mdot
.34351 .55107 Mdot
.57762 .67634 Mdot
.54024 .55866 Mdot
.54712 .64365 Mdot
.81362 .40885 Mdot
.49141 .54814 Mdot
.6853 .4149 Mdot
.56708 .61493 Mdot
.25963 .31755 Mdot
.32709 .40506 Mdot
.38899 .68335 Mdot
.52007 .35848 Mdot
.51141 .31766 Mdot
.31162 .37013 Mdot
.56901 .6365 Mdot
.48118 .24293 Mdot
.35598 .53351 Mdot
.56527 .67088 Mdot
.49599 .52953 Mdot
.70701 .40629 Mdot
.47777 .29519 Mdot
.59305 .53677 Mdot
.46528 .30501 Mdot
.48851 .29874 Mdot
.62887 .37254 Mdot
.58307 .61823 Mdot
.31306 .38465 Mdot
.30991 .34869 Mdot
.5064 .53127 Mdot
.39642 .35939 Mdot
.66476 .43725 Mdot
.27951 .31431 Mdot
.74096 .6772 Mdot
.53474 .60001 Mdot
.50612 .55375 Mdot
.42416 .5135 Mdot
.49596 .24869 Mdot
.57334 .61131 Mdot
.67525 .3958 Mdot
.30642 .40406 Mdot
.32048 .36185 Mdot
.62752 .67123 Mdot
.50501 .32913 Mdot
.30498 .53073 Mdot
.33263 .39044 Mdot
.35284 .66041 Mdot
.56585 .64294 Mdot
.51299 .28521 Mdot
.32969 .38973 Mdot
.31061 .77397 Mdot
.27092 .29903 Mdot
.64046 .40192 Mdot
.60138 .66149 Mdot
.68692 .44114 Mdot
.35493 .54306 Mdot
.27964 .38535 Mdot
.47098 .32336 Mdot
.48344 .53099 Mdot
.47729 .20475 Mdot
.32624 .36649 Mdot
.66081 .40643 Mdot
.58097 .62241 Mdot
.79132 .58949 Mdot
.55981 .5941 Mdot
.29489 .61416 Mdot
.34465 .50598 Mdot
.44779 .27468 Mdot
.4826 .33157 Mdot
.60338 .66003 Mdot
.3106 .5212 Mdot
.31844 .34928 Mdot
.33392 .38321 Mdot
.50844 .1968 Mdot
.49757 .55067 Mdot
.27957 .38823 Mdot
.57069 .59397 Mdot
.35334 .41889 Mdot
.75899 .4787 Mdot
.50978 .32118 Mdot
.55154 .64767 Mdot
.29593 .35988 Mdot
.66359 .34211 Mdot
.38754 .69259 Mdot
.56937 .64312 Mdot
.56332 .55909 Mdot
.49588 .33024 Mdot
.80997 .4223 Mdot
.33621 .40859 Mdot
.52127 .617 Mdot
.49666 .28399 Mdot
.58899 .55621 Mdot
.5377 .36124 Mdot
.67141 .40839 Mdot
.30971 .35118 Mdot
.48916 .2944 Mdot
.47918 .52197 Mdot
.31924 .54265 Mdot
.28313 .34451 Mdot
.28989 .36183 Mdot
.61329 .68094 Mdot
.51376 .55871 Mdot
.58559 .56211 Mdot
.69134 .41546 Mdot
.48021 .30526 Mdot
.59332 .68106 Mdot
.34262 .67576 Mdot
.52963 .63954 Mdot
.47902 .30267 Mdot
.78944 .3102 Mdot
.57955 .65824 Mdot
.54163 .60599 Mdot
.78544 .60304 Mdot
.6779 .43753 Mdot
.67991 .385 Mdot
.36599 .7001 Mdot
.61904 .66295 Mdot
.47032 .65719 Mdot
.66872 .40609 Mdot
.65765 .408 Mdot
.46986 .65568 Mdot
.61028 .68082 Mdot
.6739 .45546 Mdot
.48339 .31554 Mdot
.51165 .3197 Mdot
.64068 .41393 Mdot
.53522 .63363 Mdot
.46631 .27926 Mdot
.69791 .59117 Mdot
.32618 .35575 Mdot
.40255 .74722 Mdot
.64651 .41093 Mdot
.39166 .69341 Mdot
.47999 .31184 Mdot
.39991 .78124 Mdot
.417 .75973 Mdot
.54156 .58399 Mdot
.5785 .61327 Mdot
.3322 .51362 Mdot
.47463 .52802 Mdot
.44735 .52685 Mdot
.49858 .30557 Mdot
.48811 .57593 Mdot
.67076 .41726 Mdot
.61613 .64962 Mdot
.31315 .68012 Mdot
.43899 .80599 Mdot
.62111 .72812 Mdot
.65863 .41425 Mdot
.6597 .42516 Mdot
.34994 .38387 Mdot
.3574 .39262 Mdot
.56096 .58651 Mdot
.5003 .33097 Mdot
.63824 .4109 Mdot
.47521 .30228 Mdot
.32687 .37649 Mdot
.3185 .39068 Mdot
.45905 .53774 Mdot
.46171 .51171 Mdot
.31742 .37554 Mdot
.47528 .24338 Mdot
.34315 .67577 Mdot
.7033 .39279 Mdot
.82354 .39753 Mdot
.38731 .77898 Mdot
.81013 .56368 Mdot
.32188 .5324 Mdot
.62566 .58244 Mdot
.49723 .28512 Mdot
.60383 .66086 Mdot
.5575 .6125 Mdot
.47579 .53801 Mdot
.50237 .28581 Mdot
.3481 .52371 Mdot
.51071 .31899 Mdot
.31538 .5382 Mdot
.28186 .37169 Mdot
.5864 .64374 Mdot
.56216 .64664 Mdot
.46956 .31748 Mdot
.34889 .3782 Mdot
.30018 .36006 Mdot
.32676 .53836 Mdot
.36709 .75866 Mdot
.32885 .37249 Mdot
.64742 .41101 Mdot
.70114 .47817 Mdot
.48118 .54414 Mdot
.56634 .63136 Mdot
.34398 .73525 Mdot
.67518 .6426 Mdot
.50992 .5419 Mdot
.48555 .53685 Mdot
.82164 .35827 Mdot
.56971 .64759 Mdot
.48424 .18298 Mdot
.45065 .53339 Mdot
.68794 .42724 Mdot
.31021 .37854 Mdot
.50379 .55329 Mdot
.56679 .55078 Mdot
.28196 .51563 Mdot
.51372 .55102 Mdot
.64513 .4362 Mdot
.66226 .4418 Mdot
.46399 .59223 Mdot
.81903 .41278 Mdot
.31877 .51639 Mdot
.35163 .5241 Mdot
.31151 .40312 Mdot
.45795 .25351 Mdot
.54444 .57557 Mdot
.34512 .51541 Mdot
.63158 .45452 Mdot
.57856 .67415 Mdot
.46319 .62919 Mdot
.46736 .57876 Mdot
.69372 .39279 Mdot
.60357 .69128 Mdot
.31806 .405 Mdot
.6621 .40763 Mdot
.46611 .58689 Mdot
.56037 .65978 Mdot
.6717 .41306 Mdot
.48906 .30096 Mdot
.52118 .71668 Mdot
.64626 .40188 Mdot
.4481 .70837 Mdot
.48496 .32492 Mdot
.46401 .61804 Mdot
.20976 .57537 Mdot
.3468 .80985 Mdot
.50755 .32197 Mdot
.30568 .35642 Mdot
.31713 .36486 Mdot
.33707 .37814 Mdot
.69227 .40099 Mdot
.33646 .40032 Mdot
.67515 .42855 Mdot
.5032 .25219 Mdot
.42787 .73704 Mdot
.32886 .52159 Mdot
.3929 .38347 Mdot
.6416 .41172 Mdot
.81787 .40431 Mdot
.86339 .6076 Mdot
.51966 .62174 Mdot
.47977 .33493 Mdot
.33508 .50433 Mdot
.38957 .67663 Mdot
.3344 .51235 Mdot
.30322 .36726 Mdot
.42693 .72945 Mdot
.559 .6342 Mdot
.56209 .24875 Mdot
.32585 .53354 Mdot
.6564 .40757 Mdot
.62164 .67896 Mdot
.35345 .37754 Mdot
.3555 .54003 Mdot
.33418 .53572 Mdot
.56763 .62447 Mdot
.67619 .43698 Mdot
.30074 .36461 Mdot
.51288 .29625 Mdot
.34514 .45537 Mdot
.60434 .58916 Mdot
.57774 .64989 Mdot
.53766 .61742 Mdot
.38404 .70034 Mdot
.46839 .24192 Mdot
.48976 .32398 Mdot
.30448 .65315 Mdot
.34609 .40382 Mdot
.31641 .69404 Mdot
.66466 .33543 Mdot
.38805 .39677 Mdot
.49092 .54767 Mdot
.49062 .55003 Mdot
.58019 .63646 Mdot
.81093 .66864 Mdot
.53442 .70787 Mdot
.46952 .27957 Mdot
.47175 .53826 Mdot
.34766 .37254 Mdot
.66317 .37929 Mdot
.50923 .47139 Mdot
.57707 .58149 Mdot
.51293 .29584 Mdot
.33308 .37875 Mdot
.75034 .73324 Mdot
.32454 .50963 Mdot
.38528 .67714 Mdot
.58355 .60484 Mdot
.57592 .63343 Mdot
.49881 .31604 Mdot
.46275 .31321 Mdot
.79087 .44758 Mdot
.40162 .51892 Mdot
.55348 .21783 Mdot
.5008 .34773 Mdot
.74821 .73884 Mdot
.42681 .51603 Mdot
.66833 .42597 Mdot
.44739 .52382 Mdot
.46425 .31866 Mdot
.56363 .61539 Mdot
.67831 .43657 Mdot
.45944 .52373 Mdot
.62451 .43726 Mdot
.46311 .64292 Mdot
.34956 .66383 Mdot
.58864 .61948 Mdot
.67086 .44744 Mdot
.66611 .40944 Mdot
.71732 .39738 Mdot
.46578 .5391 Mdot
.55143 .60576 Mdot
.52106 .61493 Mdot
.53901 .61278 Mdot
.78175 .459 Mdot
.58091 .64157 Mdot
.67052 .33391 Mdot
.36116 .69069 Mdot
.23129 .32905 Mdot
.5578 .64204 Mdot
.49602 .29924 Mdot
.58676 .63437 Mdot
.30932 .52047 Mdot
.58572 .66512 Mdot
.46339 .65526 Mdot
.48712 .31758 Mdot
.76398 .64641 Mdot
.29146 .51458 Mdot
.58031 .65147 Mdot
.33304 .54912 Mdot
.68934 .29961 Mdot
.30691 .6549 Mdot
.78818 .44179 Mdot
.64488 .4056 Mdot
.2701 .36471 Mdot
.4574 .3069 Mdot
.32285 .39587 Mdot
.62363 .66161 Mdot
.44118 .52388 Mdot
.16744 .55432 Mdot
.34377 .69701 Mdot
.5657 .61533 Mdot
.44922 .50755 Mdot
.66147 .38946 Mdot
.32333 .40488 Mdot
.81712 .5192 Mdot
.54916 .65094 Mdot
.3074 .50638 Mdot
.31961 .50517 Mdot
.31558 .5711 Mdot
.70703 .35873 Mdot
.7688 .46496 Mdot
.49752 .31706 Mdot
.32994 .36685 Mdot
.34492 .50887 Mdot
.65559 .46637 Mdot
.47344 .32899 Mdot
.49473 .24932 Mdot
.48111 .29367 Mdot
.54814 .62888 Mdot
.47108 .54459 Mdot
.72442 .35874 Mdot
.4961 .54785 Mdot
.5363 .62755 Mdot
.29034 .36244 Mdot
.49393 .54922 Mdot
.33374 .51963 Mdot
.48957 .29618 Mdot
.31263 .38791 Mdot
.57471 .62327 Mdot
.67148 .40289 Mdot
.41438 .56259 Mdot
.26871 .38059 Mdot
.46191 .63545 Mdot
.4619 .63527 Mdot
.69612 .3796 Mdot
.45684 .54454 Mdot
.43283 .35478 Mdot
.68129 .61995 Mdot
.36734 .43453 Mdot
.57049 .56625 Mdot
.37921 .34544 Mdot
.27443 .36261 Mdot
.32299 .38298 Mdot
.5536 .6305 Mdot
.34863 .4181 Mdot
.59765 .61472 Mdot
.35274 .39886 Mdot
.72039 .3324 Mdot
.60717 .6161 Mdot
.33212 .38648 Mdot
.45284 .51982 Mdot
.56577 .59129 Mdot
.66903 .39036 Mdot
.27563 .37381 Mdot
.54129 .58421 Mdot
.19029 .37997 Mdot
.4719 .32199 Mdot
.46968 .54115 Mdot
.40223 .6544 Mdot
.48545 .30752 Mdot
.6554 .4361 Mdot
.60647 .62981 Mdot
.3431 .51177 Mdot
.66046 .42834 Mdot
.30628 .55817 Mdot
.33239 .53251 Mdot
.37681 .66817 Mdot
.64792 .42648 Mdot
.48534 .54526 Mdot
.30715 .50943 Mdot
.50437 .52858 Mdot
.3261 .38315 Mdot
.25669 .35165 Mdot
.49827 .54339 Mdot
.55681 .63053 Mdot
.34959 .37304 Mdot
.50733 .30933 Mdot
.59346 .64688 Mdot
.31746 .36296 Mdot
.4584 .52854 Mdot
.5484 .59218 Mdot
.61935 .65958 Mdot
.80448 .42477 Mdot
.41346 .52237 Mdot
.33091 .52073 Mdot
.71389 .41481 Mdot
.53215 .60438 Mdot
.31201 .52548 Mdot
.26083 .36201 Mdot
.5218 .63044 Mdot
.63354 .41798 Mdot
.69077 .59182 Mdot
.3569 .41186 Mdot
.50048 .33355 Mdot
.29476 .34613 Mdot
.3561 .54491 Mdot
.88478 .57907 Mdot
.44861 .52852 Mdot
.59579 .68722 Mdot
.55495 .64746 Mdot
.27145 .37239 Mdot
.66724 .41195 Mdot
.5682 .22151 Mdot
.59448 .66409 Mdot
.52081 .63239 Mdot
.56702 .62835 Mdot
.30203 .42922 Mdot
.69451 .41077 Mdot
.56603 .62958 Mdot
.54934 .56447 Mdot
.5407 .62991 Mdot
.34056 .54572 Mdot
.18598 .57092 Mdot
.50963 .54917 Mdot
.76858 .26293 Mdot
.45542 .52501 Mdot
.33808 .38568 Mdot
.44818 .70717 Mdot
.39913 .65005 Mdot
.22455 .39473 Mdot
.66029 .43668 Mdot
.71872 .43036 Mdot
.31951 .39045 Mdot
.38479 .41743 Mdot
.49408 .56888 Mdot
.62074 .67844 Mdot
.59194 .61225 Mdot
.30327 .36742 Mdot
.33959 .41653 Mdot
.44188 .51977 Mdot
.47223 .51073 Mdot
.56282 .67664 Mdot
.28948 .3531 Mdot
.58265 .64303 Mdot
.67115 .64643 Mdot
.47852 .33571 Mdot
.6433 .39696 Mdot
.46473 .30905 Mdot
.4947 .34141 Mdot
.81561 .55253 Mdot
.37622 .70107 Mdot
.49805 .28922 Mdot
.48295 .28125 Mdot
.39261 .41062 Mdot
.78972 .5659 Mdot
.3358 .54634 Mdot
.53094 .706 Mdot
.34639 .39087 Mdot
.55222 .60467 Mdot
.69528 .40871 Mdot
.38331 .54253 Mdot
.59286 .22195 Mdot
.56407 .78801 Mdot
.5856 .67747 Mdot
.3427 .40266 Mdot
.49978 .54466 Mdot
.50094 .53676 Mdot
.3195 .69914 Mdot
.57675 .64035 Mdot
.35746 .41388 Mdot
.78832 .55961 Mdot
.54599 .32246 Mdot
.48269 .24391 Mdot
.71566 .37918 Mdot
.5876 .63556 Mdot
.69116 .40704 Mdot
.51889 .32247 Mdot
.31433 .52494 Mdot
.32691 .51267 Mdot
.58085 .65193 Mdot
.46618 .67988 Mdot
.36266 .43717 Mdot
.62124 .66782 Mdot
.60863 .68012 Mdot
.48944 .54312 Mdot
.59982 .68417 Mdot
.52214 .61527 Mdot
.59914 .67718 Mdot
.50473 .5338 Mdot
.47357 .32856 Mdot
.80794 .54034 Mdot
.49424 .52908 Mdot
.60219 .61369 Mdot
.51723 .32695 Mdot
.61963 .6486 Mdot
.50483 .31514 Mdot
.46172 .24355 Mdot
.48861 .2876 Mdot
.32561 .51544 Mdot
.36167 .40582 Mdot
.80458 .4312 Mdot
.63819 .41333 Mdot
.51356 .32116 Mdot
.30179 .5184 Mdot
.50452 .30977 Mdot
.34676 .3846 Mdot
.54164 .29115 Mdot
.67807 .36475 Mdot
.3568 .65858 Mdot
.79832 .57475 Mdot
.53357 .33877 Mdot
.35464 .41132 Mdot
.63963 .41547 Mdot
.46332 .25152 Mdot
.60457 .65786 Mdot
.32266 .51009 Mdot
.57974 .6352 Mdot
.48921 .29724 Mdot
.34651 .39614 Mdot
.79512 .43224 Mdot
.33096 .51949 Mdot
.82544 .3887 Mdot
.28423 .35374 Mdot
.57028 .65691 Mdot
.51709 .32996 Mdot
.45533 .26735 Mdot
.47862 .32785 Mdot
.42159 .74421 Mdot
.43695 .52882 Mdot
.37454 .51092 Mdot
.65456 .42638 Mdot
.43056 .51853 Mdot
.44061 .84174 Mdot
.63817 .31176 Mdot
.67944 .40279 Mdot
.28223 .39299 Mdot
.56729 .64465 Mdot
.58187 .67874 Mdot
.4622 .51413 Mdot
.64956 .44756 Mdot
.57322 .67356 Mdot
.47278 .5437 Mdot
.36287 .70473 Mdot
.71512 .37575 Mdot
.27753 .34531 Mdot
.58045 .60048 Mdot
.5144 .3373 Mdot
.51001 .33292 Mdot
.45785 .53915 Mdot
.46723 .29784 Mdot
.60319 .61733 Mdot
.64424 .42011 Mdot
.4664 .58308 Mdot
.35737 .54091 Mdot
.6837 .32071 Mdot
.33193 .56106 Mdot
.29662 .51818 Mdot
.53642 .59347 Mdot
.31607 .38815 Mdot
.47004 .20194 Mdot
.60092 .6684 Mdot
.66583 .40605 Mdot
.56179 .65312 Mdot
.58678 .68051 Mdot
.62421 .67459 Mdot
.32997 .36709 Mdot
.38859 .69404 Mdot
.58323 .64271 Mdot
.51764 .30742 Mdot
.46938 .66108 Mdot
.58499 .58892 Mdot
.41533 .5085 Mdot
.46337 .65057 Mdot
.49439 .27555 Mdot
.70474 .39713 Mdot
.31299 .38349 Mdot
.66854 .42071 Mdot
.61791 .41629 Mdot
.6563 .43594 Mdot
.69944 .35383 Mdot
.68023 .62691 Mdot
.48238 .17994 Mdot
.76163 .47516 Mdot
.80077 .57594 Mdot
.62033 .4078 Mdot
.36464 .21431 Mdot
.67917 .39936 Mdot
.65681 .43633 Mdot
.68088 .24661 Mdot
.674 .43537 Mdot
.55697 .62311 Mdot
.54895 .63637 Mdot
.72298 .69192 Mdot
.35215 .45834 Mdot
.55219 .59324 Mdot
.50597 .53472 Mdot
.33096 .50251 Mdot
.68665 .34137 Mdot
.4839 .53334 Mdot
.3889 .67411 Mdot
.49563 .55379 Mdot
.5682 .6243 Mdot
.59435 .63587 Mdot
.60365 .60728 Mdot
.46535 .81548 Mdot
.37088 .46634 Mdot
.65578 .44294 Mdot
.53899 .5711 Mdot
.52237 .36566 Mdot
.59825 .63037 Mdot
.57002 .66126 Mdot
.6216 .69108 Mdot
.31311 .38475 Mdot
.65665 .37886 Mdot
.44842 .51014 Mdot
.6729 .31481 Mdot
.58368 .60917 Mdot
.35643 .55947 Mdot
.31171 .49729 Mdot
.5676 .6358 Mdot
.66441 .43886 Mdot
.58147 .67811 Mdot
.66936 .38217 Mdot
.65193 .42891 Mdot
.52177 .63282 Mdot
.69849 .34917 Mdot
.65966 .3797 Mdot
.62054 .67819 Mdot
.35232 .38622 Mdot
.71024 .32194 Mdot
.55917 .6325 Mdot
.33592 .52425 Mdot
.57653 .61451 Mdot
.34031 .54688 Mdot
.51058 .55263 Mdot
.49402 .54569 Mdot
.65382 .70972 Mdot
.29153 .3867 Mdot
.3211 .55219 Mdot
.35084 .41954 Mdot
.54511 .5739 Mdot
.62426 .44594 Mdot
.54619 .31245 Mdot
.37728 .41625 Mdot
.48934 .54378 Mdot
.30177 .62724 Mdot
.47475 .64105 Mdot
.47976 .28704 Mdot
.67464 .38893 Mdot
.79898 .53722 Mdot
.41956 .51658 Mdot
.28066 .34426 Mdot
.3221 .35404 Mdot
.53049 .37053 Mdot
.70606 .26914 Mdot
.55772 .64147 Mdot
.42109 .51369 Mdot
.63114 .54449 Mdot
.47265 .52717 Mdot
.44294 .51602 Mdot
.28941 .36067 Mdot
.55403 .59259 Mdot
.36617 .71657 Mdot
.3194 .36783 Mdot
.35026 .53457 Mdot
.68613 .41454 Mdot
.3125 .53219 Mdot
.59443 .25882 Mdot
.79321 .44508 Mdot
.31824 .37333 Mdot
.50589 .53787 Mdot
.54664 .60228 Mdot
.68643 .43005 Mdot
.65135 .50037 Mdot
.65257 .38767 Mdot
.35434 .52302 Mdot
.29177 .38954 Mdot
.16177 .4407 Mdot
.58257 .62319 Mdot
.65122 .41376 Mdot
.29176 .50568 Mdot
.57313 .60673 Mdot
.50532 .32973 Mdot
.5735 .67335 Mdot
.65137 .40729 Mdot
.59135 .68614 Mdot
.65441 .427 Mdot
.337 .36796 Mdot
.57364 .651 Mdot
.59518 .64925 Mdot
.30368 .64743 Mdot
.34731 .52304 Mdot
.6582 .38172 Mdot
.38841 .71214 Mdot
.54705 .64357 Mdot
.32806 .71466 Mdot
.58458 .64568 Mdot
.79471 .5782 Mdot
.54986 .55905 Mdot
.47793 .54612 Mdot
.55939 .65161 Mdot
.56133 .63474 Mdot
.64697 .50054 Mdot
.75607 .48322 Mdot
.78277 .45817 Mdot
.50464 .33362 Mdot
.67583 .39208 Mdot
.31415 .36635 Mdot
.27829 .37864 Mdot
.33202 .39915 Mdot
.36536 .53328 Mdot
.51651 .5687 Mdot
.55038 .61969 Mdot
.47073 .27618 Mdot
.33699 .50914 Mdot
.65611 .41791 Mdot
.32459 .52215 Mdot
.37973 .69464 Mdot
.33818 .52352 Mdot
.44476 .52434 Mdot
.3031 .28203 Mdot
.67294 .64199 Mdot
.3429 .53481 Mdot
.64083 .40287 Mdot
.47261 .67647 Mdot
.51661 .62571 Mdot
.81299 .41436 Mdot
.31216 .50366 Mdot
.27948 .39089 Mdot
.54986 .59005 Mdot
.43889 .70791 Mdot
.50192 .31225 Mdot
.31148 .53151 Mdot
.47953 .29362 Mdot
.587 .6785 Mdot
.7189 .43733 Mdot
.66132 .40116 Mdot
.47912 .33671 Mdot
.56215 .65643 Mdot
.31114 .53066 Mdot
.32107 .37736 Mdot
.78879 .56578 Mdot
.48799 .24793 Mdot
.40166 .53247 Mdot
.31923 .69488 Mdot
.31835 .40585 Mdot
.77728 .58636 Mdot
.48228 .28993 Mdot
.54046 .57051 Mdot
.63006 .68798 Mdot
.52907 .61001 Mdot
.29973 .36179 Mdot
.32243 .38326 Mdot
.40485 .34437 Mdot
.59615 .65005 Mdot
.58717 .6873 Mdot
.70839 .39714 Mdot
.30023 .39797 Mdot
.65586 .43553 Mdot
.67316 .44795 Mdot
.30605 .35686 Mdot
.66269 .38379 Mdot
.33226 .53379 Mdot
.39004 .73169 Mdot
.48438 .28945 Mdot
.48933 .33306 Mdot
.31681 .37413 Mdot
.29577 .38501 Mdot
.3162 .3888 Mdot
.55365 .65779 Mdot
.6516 .43084 Mdot
.60327 .64874 Mdot
.58591 .63127 Mdot
.51891 .63414 Mdot
.6945 .43692 Mdot
.59965 .66167 Mdot
.47268 .58026 Mdot
.32609 .4972 Mdot
.33604 .38887 Mdot
.47522 .30679 Mdot
.41219 .56738 Mdot
.51628 .3019 Mdot
.5403 .63089 Mdot
.72095 .3363 Mdot
.6796 .39351 Mdot
.33354 .51275 Mdot
.46271 .65328 Mdot
.33104 .51655 Mdot
.47972 .33648 Mdot
.70945 .39115 Mdot
.37197 .67086 Mdot
.59436 .65523 Mdot
.38232 .7033 Mdot
.24223 .60137 Mdot
.64428 .34365 Mdot
.48234 .30449 Mdot
.55487 .66478 Mdot
.47672 .54784 Mdot
.68307 .62006 Mdot
.55201 .62548 Mdot
.57234 .58043 Mdot
.43568 .6652 Mdot
.54305 .63233 Mdot
.63298 .42887 Mdot
.46708 .62047 Mdot
.48727 .51655 Mdot
.52925 .59669 Mdot
.50963 .20034 Mdot
.54738 .5945 Mdot
.59172 .65408 Mdot
.55449 .61072 Mdot
.59381 .67271 Mdot
.68878 .4395 Mdot
.46254 .60091 Mdot
.51815 .31974 Mdot
.38956 .73199 Mdot
.48997 .29057 Mdot
.30966 .37159 Mdot
.40243 .52576 Mdot
.69376 .38893 Mdot
.3316 .51651 Mdot
.42699 .45479 Mdot
.43663 .72546 Mdot
.34991 .3833 Mdot
.29599 .62487 Mdot
.30633 .53219 Mdot
.44805 .5152 Mdot
.35424 .54667 Mdot
.2943 .36041 Mdot
.50624 .32709 Mdot
.57492 .65585 Mdot
.64185 .43056 Mdot
.64679 .40012 Mdot
.53331 .59407 Mdot
.69789 .3101 Mdot
.49857 .33473 Mdot
.39692 .36273 Mdot
.55056 .63067 Mdot
.55158 .64777 Mdot
.67532 .38381 Mdot
.33153 .4042 Mdot
.47388 .63952 Mdot
.33548 .54333 Mdot
.59662 .62498 Mdot
.4941 .52262 Mdot
.38 .69616 Mdot
.50785 .33252 Mdot
.46174 .53403 Mdot
.55008 .59904 Mdot
.37421 .68974 Mdot
.55803 .66518 Mdot
.57301 .56879 Mdot
.35659 .39473 Mdot
.5202 .6305 Mdot
.59776 .64461 Mdot
.71572 .37858 Mdot
.4786 .29075 Mdot
.66983 .40989 Mdot
.69095 .37128 Mdot
.49268 .54522 Mdot
.4746 .32375 Mdot
.587 .67239 Mdot
.45532 .28678 Mdot
.58642 .67968 Mdot
.58027 .62793 Mdot
.485 .30293 Mdot
.66515 .43301 Mdot
.55746 .22174 Mdot
.80762 .53906 Mdot
.59694 .68086 Mdot
.57412 .61117 Mdot
.352 .45841 Mdot
.38017 .54517 Mdot
.59592 .65839 Mdot
.63931 .40951 Mdot
.57628 .60908 Mdot
.45923 .28794 Mdot
.31822 .51924 Mdot
.66757 .40212 Mdot
.33607 .40689 Mdot
.33323 .36536 Mdot
.35565 .37343 Mdot
.44375 .52356 Mdot
.60243 .68455 Mdot
.71384 .41467 Mdot
.68827 .44287 Mdot
.40928 .70594 Mdot
.33755 .38608 Mdot
.31966 .52844 Mdot
.57922 .59803 Mdot
.43736 .50844 Mdot
.51155 .33495 Mdot
.76373 .25502 Mdot
.37129 .67349 Mdot
.32808 .49597 Mdot
.41683 .53724 Mdot
.48207 .53908 Mdot
.54315 .60598 Mdot
.31042 .52522 Mdot
.30891 .35802 Mdot
.57863 .67786 Mdot
.53575 .56336 Mdot
.28516 .39754 Mdot
.30693 .39013 Mdot
.45539 .28461 Mdot
.34972 .40488 Mdot
.32067 .54443 Mdot
.44825 .52772 Mdot
.65934 .3946 Mdot
.57206 .6391 Mdot
.4901 .52733 Mdot
.34245 .38552 Mdot
.43006 .51485 Mdot
.55319 .63981 Mdot
.68461 .39351 Mdot
.3395 .39644 Mdot
.5638 .62124 Mdot
.67969 .6044 Mdot
.80189 .42844 Mdot
.3476 .39756 Mdot
.60454 .62876 Mdot
.53625 .48011 Mdot
.30761 .38826 Mdot
.29467 .36244 Mdot
.52165 .62609 Mdot
.30664 .52318 Mdot
.59078 .62236 Mdot
.50063 .32979 Mdot
.38798 .70101 Mdot
.47024 .31883 Mdot
.31865 .6999 Mdot
.51883 .61164 Mdot
.63343 .69051 Mdot
.62367 .43924 Mdot
.31737 .55265 Mdot
.38282 .7752 Mdot
.53354 .60316 Mdot
.61193 .44938 Mdot
.39107 .69502 Mdot
.36976 .65599 Mdot
.60864 .46709 Mdot
.32377 .54277 Mdot
.49926 .30635 Mdot
.5866 .65112 Mdot
.53277 .22052 Mdot
.32723 .54225 Mdot
.3202 .70167 Mdot
.61169 .65039 Mdot
.65884 .41109 Mdot
.55454 .63596 Mdot
.65719 .39733 Mdot
.56267 .6031 Mdot
.80311 .42295 Mdot
.36334 .43688 Mdot
.42225 .74377 Mdot
.45489 .51799 Mdot
.45538 .26735 Mdot
.79871 .57485 Mdot
.32745 .53117 Mdot
.58685 .68468 Mdot
.47313 .53464 Mdot
.51073 .31849 Mdot
.55593 .32719 Mdot
.32009 .3915 Mdot
.51611 .30422 Mdot
.67379 .42396 Mdot
.3438 .36559 Mdot
.43184 .51842 Mdot
.64257 .68698 Mdot
.30957 .52761 Mdot
.47545 .32464 Mdot
.56562 .63695 Mdot
.53079 .61684 Mdot
.29997 .42686 Mdot
.18946 .57931 Mdot
.6708 .45071 Mdot
.82725 .3775 Mdot
.70931 .3923 Mdot
.35008 .52364 Mdot
.35253 .38288 Mdot
.5628 .61363 Mdot
.57403 .59873 Mdot
.30728 .39159 Mdot
.69142 .42445 Mdot
.31009 .54313 Mdot
.37194 .50961 Mdot
.46846 .27949 Mdot
.21397 .60307 Mdot
.6671 .39969 Mdot
.21302 .60111 Mdot
.34917 .33982 Mdot
.75186 .36832 Mdot
.37261 .76468 Mdot
.48424 .31146 Mdot
.21342 .60284 Mdot
.6555 .41198 Mdot
.54236 .62129 Mdot
.48352 .54355 Mdot
.4403 .52479 Mdot
.68882 .40509 Mdot
.30382 .37072 Mdot
.31026 .53601 Mdot
.55678 .63696 Mdot
.62283 .58222 Mdot
.65296 .50036 Mdot
.28264 .37399 Mdot
.47842 .52612 Mdot
.47703 .31483 Mdot
.57311 .60804 Mdot
.33896 .50535 Mdot
.48537 .31239 Mdot
.49569 .55151 Mdot
.4251 .7293 Mdot
.60621 .62948 Mdot
.46335 .6673 Mdot
.50201 .31506 Mdot
.38009 .5572 Mdot
.59541 .64618 Mdot
.48215 .29001 Mdot
.51121 .55659 Mdot
.44162 .36649 Mdot
.48099 .60312 Mdot
.63745 .31209 Mdot
.2993 .3425 Mdot
.3524 .39747 Mdot
.18903 .39455 Mdot
.23239 .40935 Mdot
.50268 .29473 Mdot
.49151 .53592 Mdot
.18193 .56752 Mdot
.47273 .29416 Mdot
.58994 .66844 Mdot
.5763 .64847 Mdot
.78833 .55895 Mdot
.50603 .55139 Mdot
.45374 .5251 Mdot
.73613 .41644 Mdot
.61823 .64962 Mdot
.48118 .52768 Mdot
.59208 .64627 Mdot
.66142 .44261 Mdot
.4801 .31624 Mdot
.60269 .82453 Mdot
.46613 .32414 Mdot
.63457 .67845 Mdot
.34657 .39179 Mdot
.30966 .34469 Mdot
.569 .63571 Mdot
.52508 .46623 Mdot
.75266 .73553 Mdot
.57877 .6493 Mdot
.46281 .6542 Mdot
.31583 .69204 Mdot
.52121 .60543 Mdot
.6368 .39658 Mdot
.50711 .5476 Mdot
.7008 .43279 Mdot
.48807 .30825 Mdot
.32393 .54261 Mdot
.31083 .54924 Mdot
.49936 .30749 Mdot
.56749 .59711 Mdot
.33064 .55963 Mdot
.57342 .63168 Mdot
.54491 .61435 Mdot
.37799 .68699 Mdot
.34685 .51157 Mdot
.30868 .38157 Mdot
.32718 .51433 Mdot
.66352 .43684 Mdot
.80001 .32508 Mdot
.32534 .52731 Mdot
.78964 .56545 Mdot
.38919 .70871 Mdot
.18638 .56821 Mdot
.65038 .39612 Mdot
.35667 .54222 Mdot
.49923 .30403 Mdot
.40143 .66522 Mdot
.76886 .61078 Mdot
.5148 .29975 Mdot
.54869 .6104 Mdot
.68428 .44331 Mdot
.70251 .38498 Mdot
.52196 .3208 Mdot
.66363 .39132 Mdot
.51843 .57662 Mdot
.61686 .67526 Mdot
.51872 .31827 Mdot
.42687 .80489 Mdot
.48305 .33202 Mdot
.81807 .53974 Mdot
.60326 .68333 Mdot
.6666 .40438 Mdot
.79665 .58355 Mdot
.70715 .37906 Mdot
.45533 .53493 Mdot
.58602 .66272 Mdot
.32232 .52802 Mdot
.4008 .71191 Mdot
.34282 .40445 Mdot
.66442 .34162 Mdot
.64529 .40862 Mdot
.52332 .32575 Mdot
.66347 .39184 Mdot
.67368 .38767 Mdot
.48437 .33923 Mdot
.67787 .39387 Mdot
.58228 .60755 Mdot
.81191 .42554 Mdot
.65828 .38866 Mdot
.49445 .31629 Mdot
.35421 .524 Mdot
.6403 .40251 Mdot
.40463 .37339 Mdot
.5745 .5959 Mdot
.27259 .35381 Mdot
.36677 .52035 Mdot
.67839 .4437 Mdot
.32574 .53155 Mdot
.34232 .38895 Mdot
.30258 .50963 Mdot
.43935 .31001 Mdot
.44692 .28838 Mdot
.56828 .54934 Mdot
.43169 .36325 Mdot
.67244 .43569 Mdot
.34389 .36474 Mdot
.5963 .61812 Mdot
.5474 .62535 Mdot
.35121 .51156 Mdot
.64312 .38432 Mdot
.69569 .30543 Mdot
.48401 .53211 Mdot
.68277 .32051 Mdot
.50457 .33413 Mdot
.39562 .37266 Mdot
.36962 .6704 Mdot
.51787 .2623 Mdot
.48442 .51465 Mdot
.4801 .53861 Mdot
.56626 .62817 Mdot
.30669 .65636 Mdot
.32214 .5447 Mdot
.34985 .22915 Mdot
.53918 .64004 Mdot
.30636 .39318 Mdot
.55975 .60542 Mdot
.48586 .56969 Mdot
.52729 .60777 Mdot
.33401 .4985 Mdot
.49892 .28429 Mdot
.63821 .41261 Mdot
.35056 .54525 Mdot
.33145 .36342 Mdot
.44569 .74595 Mdot
.59907 .65665 Mdot
.59005 .60382 Mdot
.30225 .37882 Mdot
.6495 .43562 Mdot
.31459 .37749 Mdot
.48483 .28959 Mdot
.32692 .52554 Mdot
.56555 .66842 Mdot
.50696 .55102 Mdot
.27231 .37416 Mdot
.51451 .31817 Mdot
.35264 .3781 Mdot
.45537 .30312 Mdot
.48522 .54215 Mdot
.533 .58214 Mdot
.36024 .41462 Mdot
.48421 .51718 Mdot
.75804 .55015 Mdot
.42952 .72455 Mdot
.6276 .49858 Mdot
.30162 .36991 Mdot
.22589 .3876 Mdot
.48851 .3137 Mdot
.46023 .3042 Mdot
.8207 .535 Mdot
.80096 .67985 Mdot
.47028 .65646 Mdot
.67218 .29674 Mdot
.48532 .28938 Mdot
.50225 .32114 Mdot
.31291 .37917 Mdot
.67191 .43211 Mdot
.63227 .44529 Mdot
.3346 .35953 Mdot
.3499 .7396 Mdot
.65586 .41775 Mdot
.73395 .68347 Mdot
.27701 .36313 Mdot
.62499 .67536 Mdot
.79717 .42916 Mdot
.32282 .49803 Mdot
.31808 .68642 Mdot
.5447 .29934 Mdot
.55875 .61833 Mdot
.48793 .18297 Mdot
.32252 .39154 Mdot
.43464 .51105 Mdot
.47218 .36462 Mdot
.55362 .65315 Mdot
.55549 .60528 Mdot
.58055 .60913 Mdot
.37115 .53861 Mdot
.74273 .5058 Mdot
.56025 .61614 Mdot
.42683 .73334 Mdot
.61903 .64296 Mdot
.25843 .36826 Mdot
.32684 .51476 Mdot
.29273 .61693 Mdot
.33791 .43024 Mdot
.66701 .31269 Mdot
.56051 .57542 Mdot
.46418 .28802 Mdot
.47462 .57319 Mdot
.48487 .30128 Mdot
.49904 .27901 Mdot
.21997 .6367 Mdot
.63521 .43079 Mdot
.5458 .64797 Mdot
.28396 .36929 Mdot
.63292 .44671 Mdot
.472 .57468 Mdot
.81066 .33743 Mdot
.52579 .32758 Mdot
.89318 .56788 Mdot
.46304 .29769 Mdot
.43826 .5174 Mdot
.6779 .41907 Mdot
.63125 .48814 Mdot
.38098 .70284 Mdot
.65787 .43523 Mdot
.26314 .41825 Mdot
.69539 .43956 Mdot
.29096 .72068 Mdot
.66161 .36739 Mdot
.4908 .32031 Mdot
.52239 .3232 Mdot
.52271 .56883 Mdot
.59248 .62479 Mdot
.36376 .70963 Mdot
.48316 .53133 Mdot
.60989 .63555 Mdot
.31954 .36756 Mdot
.40785 .35325 Mdot
.51083 .22137 Mdot
.67908 .3956 Mdot
.51345 .31209 Mdot
.55726 .60575 Mdot
.59492 .68183 Mdot
.55408 .64354 Mdot
.38555 .42218 Mdot
.72921 .69208 Mdot
.58381 .63258 Mdot
.54991 .57083 Mdot
.34757 .37792 Mdot
.30001 .42764 Mdot
.72398 .28999 Mdot
.21672 .61949 Mdot
.54183 .59277 Mdot
.34473 .51712 Mdot
.35636 .52049 Mdot
.53094 .56962 Mdot
.61068 .48822 Mdot
.29849 .57961 Mdot
.56484 .63649 Mdot
.447 .73688 Mdot
.26712 .35133 Mdot
.4636 .54264 Mdot
.34175 .38461 Mdot
.61544 .42039 Mdot
.48644 .55035 Mdot
.31285 .36179 Mdot
.40488 .74918 Mdot
.49639 .54361 Mdot
.43928 .36413 Mdot
.35863 .54002 Mdot
.59365 .64616 Mdot
.80254 .51275 Mdot
.30037 .3983 Mdot
.49824 .32782 Mdot
.67701 .41305 Mdot
.50397 .33329 Mdot
.25548 .3408 Mdot
.33484 .72509 Mdot
.46275 .53873 Mdot
.46333 .28808 Mdot
.46469 .67095 Mdot
.33893 .51189 Mdot
.46668 .29556 Mdot
.6308 .6755 Mdot
.60558 .61262 Mdot
.73816 .7333 Mdot
.58155 .5981 Mdot
.40815 .346 Mdot
.47171 .3225 Mdot
.48886 .55224 Mdot
.57367 .6396 Mdot
.28274 .35256 Mdot
.52537 .55345 Mdot
.57347 .63029 Mdot
.32743 .4078 Mdot
.57583 .64727 Mdot
.31456 .51693 Mdot
.71601 .40195 Mdot
.39384 .69039 Mdot
.38974 .5106 Mdot
.33043 .54575 Mdot
.43901 .7186 Mdot
.5947 .66057 Mdot
.24712 .41476 Mdot
.66108 .41271 Mdot
.53963 .62919 Mdot
.28372 .6782 Mdot
.6841 .42069 Mdot
.66571 .42303 Mdot
.61694 .68569 Mdot
.45735 .29883 Mdot
.3056 .37967 Mdot
.33328 .51012 Mdot
.48872 .24603 Mdot
.56309 .61913 Mdot
.55858 .66734 Mdot
.33515 .54591 Mdot
.49176 .32817 Mdot
.57043 .67024 Mdot
.58261 .3453 Mdot
.39686 .73217 Mdot
.48258 .33698 Mdot
.5837 .58761 Mdot
.75922 .66515 Mdot
.69736 .39967 Mdot
.48646 .1827 Mdot
.36356 .43701 Mdot
.32598 .35713 Mdot
.48189 .52667 Mdot
.77229 .27119 Mdot
.35529 .52489 Mdot
.6593 .33139 Mdot
.55016 .634 Mdot
.56815 .61279 Mdot
.66633 .44019 Mdot
.60224 .6475 Mdot
.67832 .39261 Mdot
.39766 .39445 Mdot
.82176 .65688 Mdot
.65287 .3961 Mdot
.65442 .40289 Mdot
.53841 .72139 Mdot
.36772 .41425 Mdot
.68585 .4128 Mdot
.59893 .64477 Mdot
.23523 .35503 Mdot
.61496 .5923 Mdot
.30219 .53113 Mdot
.37326 .5407 Mdot
.63662 .39919 Mdot
.76917 .61513 Mdot
.62927 .67292 Mdot
.73001 .66101 Mdot
.29637 .58017 Mdot
.50003 .2927 Mdot
.53871 .65179 Mdot
.48161 .53455 Mdot
.33658 .39266 Mdot
.5164 .61807 Mdot
.59459 .64264 Mdot
.63553 .42481 Mdot
.3109 .50104 Mdot
.47244 .29606 Mdot
.4781 .51418 Mdot
.27101 .33627 Mdot
.34219 .54096 Mdot
.66794 .38489 Mdot
.80787 .56586 Mdot
.34386 .56 Mdot
.4484 .5075 Mdot
.54044 .60723 Mdot
.52139 .62892 Mdot
.43709 .50625 Mdot
.49803 .30797 Mdot
.31578 .35108 Mdot
.45312 .51018 Mdot
.41159 .67492 Mdot
.38063 .73758 Mdot
.5367 .60108 Mdot
.63956 .40623 Mdot
.51222 .31647 Mdot
.45197 .52926 Mdot
.17967 .5621 Mdot
.55425 .58775 Mdot
.73424 .68416 Mdot
.39167 .52753 Mdot
.48644 .53795 Mdot
.63439 .4481 Mdot
.33148 .51315 Mdot
.60254 .6832 Mdot
.42434 .73732 Mdot
.61144 .64102 Mdot
.53918 .57047 Mdot
.3033 .35768 Mdot
.48221 .29587 Mdot
.5712 .55014 Mdot
.33404 .38979 Mdot
.6676 .42155 Mdot
.71387 .67883 Mdot
.66627 .44763 Mdot
.67115 .44906 Mdot
.69125 .34733 Mdot
.49419 .33248 Mdot
.77125 .26846 Mdot
.3793 .54474 Mdot
.56673 .64987 Mdot
.49848 .28639 Mdot
.68447 .40805 Mdot
.59776 .66358 Mdot
.67941 .39328 Mdot
.64942 .38262 Mdot
.60935 .63058 Mdot
.61929 .66129 Mdot
.42738 .73907 Mdot
.75645 .66022 Mdot
.32203 .51121 Mdot
.68922 .42603 Mdot
.76157 .6441 Mdot
.56434 .61476 Mdot
.59449 .63361 Mdot
.47424 .57149 Mdot
.34495 .54821 Mdot
.6652 .70562 Mdot
.54717 .62712 Mdot
.3006 .64571 Mdot
.59169 .66638 Mdot
.63232 .39136 Mdot
.45659 .26918 Mdot
.63297 .67827 Mdot
.34606 .37079 Mdot
.68929 .42729 Mdot
.31993 .4978 Mdot
.61169 .42224 Mdot
.67641 .63874 Mdot
.5062 .31066 Mdot
.65152 .40718 Mdot
.32173 .35131 Mdot
.49256 .3263 Mdot
.48252 .33149 Mdot
.46987 .57472 Mdot
.30053 .34795 Mdot
.31004 .50061 Mdot
.47147 .30922 Mdot
.68158 .60053 Mdot
.49153 .32202 Mdot
.68034 .66069 Mdot
.56219 .58591 Mdot
.42494 .73456 Mdot
.46883 .51508 Mdot
.55825 .55785 Mdot
.46996 .31523 Mdot
.3376 .5441 Mdot
.5672 .66805 Mdot
.66477 .38858 Mdot
.35019 .51959 Mdot
.7889 .44006 Mdot
.32132 .34946 Mdot
.70444 .39033 Mdot
.49253 .24898 Mdot
.68729 .42357 Mdot
.31895 .69183 Mdot
.31637 .49521 Mdot
.41722 .51559 Mdot
.3885 .68232 Mdot
.47102 .52436 Mdot
.53154 .59219 Mdot
.56203 .66419 Mdot
.57766 .60369 Mdot
.347 .39163 Mdot
.37084 .54105 Mdot
.64763 .39024 Mdot
.5974 .54951 Mdot
.49338 .33025 Mdot
.46545 .63342 Mdot
.44034 .51049 Mdot
.58871 .67937 Mdot
.68241 .40581 Mdot
.65695 .37956 Mdot
.75224 .48887 Mdot
.31173 .39203 Mdot
.59567 .56662 Mdot
.53479 .60131 Mdot
.60769 .56284 Mdot
.47067 .31762 Mdot
.62315 .32035 Mdot
.26907 .35585 Mdot
.89565 .56382 Mdot
.33415 .38777 Mdot
.42711 .53553 Mdot
.69062 .40001 Mdot
.33678 .52795 Mdot
.56157 .59466 Mdot
.71161 .36669 Mdot
.65588 .45535 Mdot
.27997 .51083 Mdot
.33356 .51792 Mdot
.44637 .26158 Mdot
.49508 .288 Mdot
.47825 .5134 Mdot
.59124 .66692 Mdot
.60801 .65639 Mdot
.60084 .63191 Mdot
.50963 .30018 Mdot
.61784 .66526 Mdot
.464 .2638 Mdot
.67423 .6389 Mdot
.28466 .68113 Mdot
.29151 .3676 Mdot
.24879 .32068 Mdot
.68246 .44269 Mdot
.68342 .69827 Mdot
.67144 .66929 Mdot
.42653 .72551 Mdot
.48844 .27898 Mdot
.51485 .5563 Mdot
.30878 .37789 Mdot
.50773 .22476 Mdot
.29031 .36788 Mdot
.65419 .79322 Mdot
.78942 .55733 Mdot
.42924 .31065 Mdot
.60903 .6519 Mdot
.3012 .35486 Mdot
.7703 .62002 Mdot
.45978 .51069 Mdot
.33256 .55967 Mdot
.67706 .62581 Mdot
.78538 .45387 Mdot
.32015 .51174 Mdot
.553 .59362 Mdot
.69232 .4389 Mdot
.56672 .59578 Mdot
.55968 .59394 Mdot
.55019 .63607 Mdot
.50548 .34247 Mdot
.55829 .58445 Mdot
.58949 .61671 Mdot
.14836 .48513 Mdot
.30543 .56586 Mdot
.35272 .40226 Mdot
.63351 .49148 Mdot
.33686 .50904 Mdot
.61555 .41864 Mdot
.39186 .68691 Mdot
.46191 .31097 Mdot
.74981 .49147 Mdot
.61556 .67957 Mdot
.66957 .33527 Mdot
.46004 .31264 Mdot
.30521 .52285 Mdot
.47766 .53447 Mdot
.59758 .21928 Mdot
.35496 .4193 Mdot
.45985 .52667 Mdot
.32902 .40591 Mdot
.65058 .68176 Mdot
.66283 .39493 Mdot
.47267 .52507 Mdot
.47144 .29875 Mdot
.28861 .36191 Mdot
.43583 .72876 Mdot
.58282 .61596 Mdot
.30054 .36683 Mdot
.4905 .52966 Mdot
.39887 .71208 Mdot
.38995 .69584 Mdot
.29603 .35512 Mdot
.46669 .27664 Mdot
.47892 .32451 Mdot
.33728 .50663 Mdot
.68756 .39193 Mdot
.6449 .43421 Mdot
.48516 .32382 Mdot
.48449 .21107 Mdot
.56237 .62038 Mdot
.58182 .62627 Mdot
.38228 .67113 Mdot
.57373 .66582 Mdot
.34875 .46088 Mdot
.46399 .52654 Mdot
.63883 .42549 Mdot
.56466 .66612 Mdot
.57372 .67162 Mdot
.54552 .59413 Mdot
.35202 .74397 Mdot
.34494 .39292 Mdot
.62209 .66513 Mdot
.31059 .52753 Mdot
.78893 .44635 Mdot
.59365 .61649 Mdot
.4457 .50298 Mdot
.69119 .3988 Mdot
.53714 .35925 Mdot
.49958 .32764 Mdot
.28676 .37853 Mdot
.28433 .37189 Mdot
.24274 .6103 Mdot
.66915 .44439 Mdot
.46061 .5262 Mdot
.28495 .39768 Mdot
.44665 .52488 Mdot
.33602 .51907 Mdot
.48022 .61357 Mdot
.32836 .45192 Mdot
.35199 .40299 Mdot
.47644 .34002 Mdot
.53743 .62937 Mdot
.59449 .61969 Mdot
.68301 .31085 Mdot
.58678 .64562 Mdot
.31969 .52363 Mdot
.47463 .2868 Mdot
.6533 .40756 Mdot
.31499 .51156 Mdot
.46172 .29469 Mdot
.65307 .43549 Mdot
.61701 .63864 Mdot
.59577 .66472 Mdot
.67281 .41885 Mdot
.67312 .38528 Mdot
.55674 .62521 Mdot
.23078 .6654 Mdot
.63644 .41731 Mdot
.6772 .41615 Mdot
.78766 .44843 Mdot
.35548 .41407 Mdot
.52437 .55129 Mdot
.45938 .28967 Mdot
.58784 .61547 Mdot
.29363 .37213 Mdot
.34388 .52693 Mdot
.64271 .41324 Mdot
.51956 .62277 Mdot
.56839 .62028 Mdot
.34254 .51538 Mdot
.35708 .54846 Mdot
.35407 .54039 Mdot
.52166 .32052 Mdot
.62028 .6789 Mdot
.68247 .41588 Mdot
.51282 .2984 Mdot
.33706 .50279 Mdot
.34071 .55117 Mdot
.31847 .7474 Mdot
.55882 .62134 Mdot
.3629 .54449 Mdot
.79086 .31253 Mdot
.4131 .75599 Mdot
.44758 .53179 Mdot
.34533 .36023 Mdot
.22238 .37338 Mdot
.37607 .55723 Mdot
.48627 .2953 Mdot
.46343 .63484 Mdot
.30201 .52603 Mdot
.48447 .52092 Mdot
.58413 .62289 Mdot
.52928 .64819 Mdot
.35173 .52275 Mdot
.33301 .72377 Mdot
.63795 .43528 Mdot
.66244 .51527 Mdot
.33586 .50864 Mdot
.29201 .35445 Mdot
.26595 .35835 Mdot
.32655 .38456 Mdot
.52664 .60702 Mdot
.63822 .7263 Mdot
.66764 .5754 Mdot
.66468 .69778 Mdot
.4913 .28731 Mdot
.65516 .37987 Mdot
.79685 .43731 Mdot
.66347 .4242 Mdot
.32948 .4011 Mdot
.33584 .544 Mdot
.6594 .44047 Mdot
.49253 .33374 Mdot
.47611 .32227 Mdot
.35868 .4153 Mdot
.33883 .38389 Mdot
.31967 .37525 Mdot
.69892 .41221 Mdot
.68637 .3967 Mdot
.60292 .65889 Mdot
.64747 .39461 Mdot
.38033 .42095 Mdot
.39107 .40809 Mdot
.33238 .41658 Mdot
.49485 .31115 Mdot
.6516 .42823 Mdot
.59318 .64962 Mdot
.43446 .65391 Mdot
.27388 .38149 Mdot
.31908 .50025 Mdot
.81338 .42304 Mdot
.78761 .69492 Mdot
.53692 .6449 Mdot
.50484 .30066 Mdot
.45219 .52183 Mdot
.57169 .60213 Mdot
.32516 .35598 Mdot
.39318 .53974 Mdot
.50237 .55074 Mdot
.59686 .61528 Mdot
.5943 .60235 Mdot
.50969 .31676 Mdot
.39326 .68364 Mdot
.48087 .51773 Mdot
.46379 .58505 Mdot
.47681 .28457 Mdot
.27212 .36895 Mdot
.20165 .3705 Mdot
.73573 .40124 Mdot
.31485 .62628 Mdot
.49068 .55049 Mdot
.55424 .58699 Mdot
.32301 .36725 Mdot
.31004 .51494 Mdot
.3261 .37227 Mdot
.61953 .4093 Mdot
.35687 .41212 Mdot
.5844 .64907 Mdot
.68337 .41704 Mdot
.47846 .32626 Mdot
.39195 .65114 Mdot
.5705 .52807 Mdot
.28063 .35448 Mdot
.42692 .50986 Mdot
.61797 .65543 Mdot
.68455 .60879 Mdot
.55634 .55805 Mdot
.59693 .63958 Mdot
.48412 .30294 Mdot
.6806 .39866 Mdot
.50936 .32892 Mdot
.52853 .55657 Mdot
.61152 .48043 Mdot
.50196 .32738 Mdot
.6072 .72815 Mdot
.31172 .53812 Mdot
.34042 .73221 Mdot
.56536 .64019 Mdot
.47441 .29776 Mdot
.59382 .60887 Mdot
.6826 .4325 Mdot
.39565 .74547 Mdot
.40552 .73066 Mdot
.47938 .3138 Mdot
.43654 .52938 Mdot
.39142 .70975 Mdot
.52312 .54859 Mdot
.48819 .29015 Mdot
.42702 .76587 Mdot
.46339 .53216 Mdot
.34257 .53922 Mdot
.34927 .55099 Mdot
.33045 .53896 Mdot
.58555 .62984 Mdot
.78223 .62954 Mdot
.35046 .51614 Mdot
.52082 .35554 Mdot
.31463 .52523 Mdot
.40509 .53892 Mdot
.69993 .30861 Mdot
.31859 .54269 Mdot
.57458 .64318 Mdot
.63752 .68574 Mdot
.46312 .64491 Mdot
.29163 .34461 Mdot
.58203 .2241 Mdot
.15072 .47442 Mdot
.56214 .61327 Mdot
.80724 .42571 Mdot
.71744 .38766 Mdot
.41191 .5198 Mdot
.41303 .72947 Mdot
.46974 .69109 Mdot
.66597 .42719 Mdot
.39044 .68314 Mdot
.70398 .40038 Mdot
.4518 .51377 Mdot
.58153 .62977 Mdot
.68707 .42982 Mdot
.66515 .34194 Mdot
.38563 .77769 Mdot
.68989 .32238 Mdot
.65035 .43076 Mdot
.47822 .29083 Mdot
.49266 .29767 Mdot
.48115 .30514 Mdot
.33914 .37541 Mdot
.65141 .40363 Mdot
.6157 .64102 Mdot
.33231 .36257 Mdot
.5471 .61297 Mdot
.48125 .31918 Mdot
.41654 .73057 Mdot
.65467 .40365 Mdot
.56335 .6362 Mdot
.76439 .63208 Mdot
.3185 .40521 Mdot
.34398 .51545 Mdot
.81058 .42279 Mdot
.34713 .36482 Mdot
.45635 .28622 Mdot
.62261 .40772 Mdot
.30172 .56011 Mdot
.46141 .6023 Mdot
.53654 .60523 Mdot
.5782 .6569 Mdot
.46161 .63479 Mdot
.7951 .55457 Mdot
.49992 .53112 Mdot
.33227 .36435 Mdot
.35321 .41271 Mdot
.57043 .59301 Mdot
.64975 .4022 Mdot
.30069 .49743 Mdot
.36166 .55243 Mdot
.57485 .56767 Mdot
.38475 .70115 Mdot
.42678 .7331 Mdot
.58996 .6721 Mdot
.57022 .71027 Mdot
.31873 .35047 Mdot
.44405 .52968 Mdot
.38116 .69499 Mdot
.33082 .53427 Mdot
.54277 .62054 Mdot
.648 .49498 Mdot
.64596 .41174 Mdot
.30219 .37202 Mdot
.51311 .33778 Mdot
.33829 .56033 Mdot
.33845 .41836 Mdot
.56994 .59284 Mdot
.57238 .67103 Mdot
.46807 .29697 Mdot
.62608 .40268 Mdot
.35073 .53508 Mdot
.33677 .36627 Mdot
.33482 .5303 Mdot
.66902 .39431 Mdot
.64155 .41489 Mdot
.54166 .62777 Mdot
.59923 .5665 Mdot
.27749 .35812 Mdot
.52498 .60563 Mdot
.30588 .36486 Mdot
.2989 .42571 Mdot
.51209 .33427 Mdot
.54116 .63144 Mdot
.62614 .43876 Mdot
.48129 .32128 Mdot
.55967 .61089 Mdot
.46253 .6231 Mdot
.57814 .67458 Mdot
.30053 .3542 Mdot
.38517 .53656 Mdot
.33947 .53699 Mdot
.60587 .70012 Mdot
.77271 .45862 Mdot
.57497 .66815 Mdot
.30641 .40345 Mdot
.67252 .59502 Mdot
.50619 .31926 Mdot
.6928 .41023 Mdot
.27197 .30277 Mdot
.49451 .31826 Mdot
.56825 .6442 Mdot
.32455 .52658 Mdot
.66487 .38288 Mdot
.47778 .5474 Mdot
.34355 .68378 Mdot
.53398 .56105 Mdot
.60014 .57085 Mdot
.49505 .52675 Mdot
.67748 .29856 Mdot
.32142 .37406 Mdot
.6832 .40788 Mdot
.50135 .29781 Mdot
.50701 .31444 Mdot
.3295 .40448 Mdot
.78077 .45068 Mdot
.74765 .34305 Mdot
.78559 .29832 Mdot
.31486 .4117 Mdot
.32215 .53571 Mdot
.39793 .74462 Mdot
.32519 .38513 Mdot
.3459 .40358 Mdot
.35595 .43444 Mdot
.67799 .3096 Mdot
.66233 .43216 Mdot
.56853 .61935 Mdot
.80302 .42651 Mdot
.55541 .64099 Mdot
.31921 .62766 Mdot
.48261 .31904 Mdot
.69281 .41086 Mdot
.4062 .39837 Mdot
.52812 .59882 Mdot
.55708 .59943 Mdot
.40555 .36842 Mdot
.47954 .53084 Mdot
.19465 .57887 Mdot
.56497 .65347 Mdot
.33521 .37556 Mdot
.65695 .46746 Mdot
.45554 .51233 Mdot
.76531 .63234 Mdot
.46859 .31694 Mdot
.45662 .5348 Mdot
.4517 .51181 Mdot
.56345 .70965 Mdot
.7056 .4071 Mdot
.64925 .44043 Mdot
.3553 .54695 Mdot
.72396 .34266 Mdot
.46686 .3154 Mdot
.63319 .30701 Mdot
.59799 .64464 Mdot
.49029 .27477 Mdot
.37553 .51121 Mdot
.55598 .6115 Mdot
.46992 .5769 Mdot
.7523 .48825 Mdot
.52844 .63791 Mdot
.66669 .66141 Mdot
.49032 .31497 Mdot
.28678 .67368 Mdot
.61444 .65546 Mdot
.30151 .36825 Mdot
.67524 .43089 Mdot
.70676 .39338 Mdot
.31298 .50903 Mdot
.37465 .43696 Mdot
.85412 .61862 Mdot
.69221 .41311 Mdot
.58483 .61767 Mdot
.50344 .32163 Mdot
.46644 .54204 Mdot
.47235 .5173 Mdot
.43388 .52771 Mdot
.64672 .41457 Mdot
.45976 .51225 Mdot
.67788 .33306 Mdot
.39123 .68402 Mdot
.69308 .69324 Mdot
.47713 .30931 Mdot
.32042 .53101 Mdot
.59751 .58102 Mdot
.3116 .4281 Mdot
.59172 .66797 Mdot
.3178 .62724 Mdot
.71535 .39264 Mdot
.31944 .52669 Mdot
.56558 .59741 Mdot
.48937 .5193 Mdot
.44914 .71778 Mdot
.29652 .51179 Mdot
.49743 .52938 Mdot
.54307 .64967 Mdot
.6689 .43625 Mdot
.45873 .52528 Mdot
.65308 .41111 Mdot
.55928 .59556 Mdot
.30972 .59696 Mdot
.6905 .42311 Mdot
.5702 .22419 Mdot
.36149 .55547 Mdot
.45915 .30295 Mdot
.54028 .65933 Mdot
.5407 .59286 Mdot
.69184 .70903 Mdot
.45117 .53222 Mdot
.51423 .20304 Mdot
.29767 .36353 Mdot
.18319 .57845 Mdot
.35877 .38251 Mdot
.41438 .34228 Mdot
.5541 .35942 Mdot
.52495 .64026 Mdot
.77912 .45305 Mdot
.65614 .72234 Mdot
.47091 .27635 Mdot
.67466 .71646 Mdot
.59241 .6245 Mdot
.54136 .60647 Mdot
.30422 .36496 Mdot
.51264 .28621 Mdot
.63318 .68109 Mdot
.38135 .69619 Mdot
.30457 .52465 Mdot
.66801 .41233 Mdot
.5894 .63219 Mdot
.65137 .34837 Mdot
.28711 .35726 Mdot
.63336 .50702 Mdot
.56832 .63908 Mdot
.47913 .53094 Mdot
.50675 .28375 Mdot
.47725 .32587 Mdot
.30041 .35093 Mdot
.29451 .35028 Mdot
.54363 .59238 Mdot
.51759 .31518 Mdot
.60481 .6628 Mdot
.39313 .71057 Mdot
.49238 .53151 Mdot
.33899 .51888 Mdot
.59601 .65278 Mdot
.74021 .42999 Mdot
.42205 .83205 Mdot
.52812 .60568 Mdot
.67483 .44663 Mdot
.31457 .37346 Mdot
.34232 .39919 Mdot
.64453 .43277 Mdot
.34135 .40002 Mdot
.66599 .51453 Mdot
.78054 .63357 Mdot
.33591 .52183 Mdot
.64776 .56562 Mdot
.32336 .54201 Mdot
.45302 .53207 Mdot
.55806 .6227 Mdot
.38909 .20392 Mdot
.31335 .41072 Mdot
.41239 .56709 Mdot
.48717 .3226 Mdot
.44098 .52493 Mdot
.62025 .67206 Mdot
.36315 .51813 Mdot
.32864 .39315 Mdot
.43042 .5069 Mdot
.54686 .63111 Mdot
.69631 .41714 Mdot
.56607 .67262 Mdot
.44155 .51533 Mdot
.45283 .52467 Mdot
.50178 .52877 Mdot
.46169 .2947 Mdot
.67461 .3915 Mdot
.44353 .26419 Mdot
.31586 .40551 Mdot
.60871 .63129 Mdot
.58259 .6133 Mdot
.67058 .38117 Mdot
.5715 .65163 Mdot
.51852 .31362 Mdot
.73553 .22334 Mdot
.34939 .54335 Mdot
.45567 .53727 Mdot
.5943 .25888 Mdot
.50284 .52959 Mdot
.55121 .65704 Mdot
.50025 .70914 Mdot
.65189 .50043 Mdot
.459 .299 Mdot
.53341 .57143 Mdot
.35489 .402 Mdot
.34859 .53695 Mdot
.49454 .33473 Mdot
.61628 .67357 Mdot
.57956 .64676 Mdot
.3207 .52808 Mdot
.41148 .37957 Mdot
.32316 .55178 Mdot
.4969 .2929 Mdot
.46284 .54508 Mdot
.43597 .65273 Mdot
.56746 .62747 Mdot
.46942 .52841 Mdot
.67656 .3998 Mdot
.50051 .29119 Mdot
.7426 .51007 Mdot
.44946 .51291 Mdot
.49443 .24808 Mdot
.47405 .32332 Mdot
.53669 .60806 Mdot
.67456 .4414 Mdot
.69241 .36779 Mdot
.67984 .40233 Mdot
.2617 .65969 Mdot
.4482 .25217 Mdot
.31629 .37163 Mdot
.49557 .31287 Mdot
.29624 .37813 Mdot
.31448 .54143 Mdot
.37893 .73326 Mdot
.28788 .35133 Mdot
.63707 .44209 Mdot
.29122 .37403 Mdot
.60375 .66278 Mdot
.46037 .31002 Mdot
.27581 .36448 Mdot
.60038 .64617 Mdot
.60372 .60733 Mdot
.46036 .52193 Mdot
.30548 .49607 Mdot
.38789 .69297 Mdot
.56044 .63969 Mdot
.47141 .53204 Mdot
.56239 .63231 Mdot
.5184 .31521 Mdot
.37924 .64236 Mdot
.60373 .61913 Mdot
.31106 .40984 Mdot
.61051 .21242 Mdot
.34827 .41619 Mdot
.54231 .48432 Mdot
.54876 .61365 Mdot
.56427 .62507 Mdot
.61848 .65662 Mdot
.79194 .45966 Mdot
.45722 .2801 Mdot
.52624 .58469 Mdot
.34911 .37331 Mdot
.65822 .42632 Mdot
.6637 .44364 Mdot
.47516 .67438 Mdot
.46458 .52779 Mdot
.52032 .32217 Mdot
.56341 .62294 Mdot
.44585 .5202 Mdot
.36602 .68727 Mdot
.7119 .32603 Mdot
.36253 .42975 Mdot
.33631 .4086 Mdot
.6926 .39269 Mdot
.34834 .38617 Mdot
.61762 .67223 Mdot
.46071 .51368 Mdot
.45557 .24579 Mdot
.51982 .34877 Mdot
.34815 .53617 Mdot
.54765 .6065 Mdot
.35997 .75238 Mdot
.34729 .37757 Mdot
.30535 .34839 Mdot
.6056 .66151 Mdot
.72357 .41961 Mdot
.37743 .80449 Mdot
.50045 .28681 Mdot
.69871 .60994 Mdot
.81582 .51887 Mdot
.57604 .77872 Mdot
.50122 .30793 Mdot
.46867 .5798 Mdot
.29068 .34294 Mdot
.23498 .56556 Mdot
.66247 .42651 Mdot
.35012 .5342 Mdot
.5998 .64835 Mdot
.63765 .44168 Mdot
.32265 .41523 Mdot
.65097 .38596 Mdot
.48291 .52866 Mdot
.4607 .31333 Mdot
.33931 .39326 Mdot
.51882 .33626 Mdot
.62259 .43864 Mdot
.32973 .54241 Mdot
.30409 .6469 Mdot
.68046 .61089 Mdot
.7554 .48364 Mdot
.62352 .67576 Mdot
.30941 .56969 Mdot
.62323 .66905 Mdot
.70733 .38844 Mdot
.56646 .64078 Mdot
.5906 .59354 Mdot
.30335 .34317 Mdot
.53639 .60234 Mdot
.5973 .64771 Mdot
.76291 .63703 Mdot
.55411 .60725 Mdot
.55015 .5932 Mdot
.53531 .60649 Mdot
.65505 .44683 Mdot
.5467 .63458 Mdot
.68072 .3903 Mdot
.66017 .33505 Mdot
.31634 .40539 Mdot
.3202 .54504 Mdot
.32152 .54484 Mdot
.32727 .61382 Mdot
.35787 .75003 Mdot
.80036 .43077 Mdot
.65492 .4205 Mdot
.47108 .31712 Mdot
.60417 .6589 Mdot
.33327 .76721 Mdot
.31176 .59922 Mdot
.27626 .34746 Mdot
.28117 .36336 Mdot
.60002 .62589 Mdot
.77231 .70925 Mdot
.57312 .65854 Mdot
.37196 .67259 Mdot
.58585 .6309 Mdot
.54536 .6386 Mdot
.35781 .38557 Mdot
.31831 .69036 Mdot
.62151 .66246 Mdot
.70515 .41451 Mdot
.34896 .53133 Mdot
.46356 .52487 Mdot
.31579 .60408 Mdot
.81639 .55053 Mdot
.72252 .44217 Mdot
.61869 .6541 Mdot
.33555 .3637 Mdot
.63915 .42094 Mdot
.3835 .67319 Mdot
.51219 .29812 Mdot
.34299 .68935 Mdot
.67754 .66723 Mdot
.49487 .28257 Mdot
.34459 .53918 Mdot
.27191 .37711 Mdot
.5405 .59666 Mdot
.3234 .3649 Mdot
.5232 .60428 Mdot
.36059 .68261 Mdot
.33823 .52138 Mdot
.69774 .43862 Mdot
.47568 .29112 Mdot
.64034 .44199 Mdot
.62681 .49833 Mdot
.30864 .59882 Mdot
.16136 .54835 Mdot
.34073 .418 Mdot
.59353 .53689 Mdot
.6893 .40717 Mdot
.5524 .5877 Mdot
.78288 .29716 Mdot
.66861 .39949 Mdot
.69298 .42251 Mdot
.35097 .66159 Mdot
.31594 .69773 Mdot
.52446 .61172 Mdot
.6357 .4123 Mdot
.27564 .38225 Mdot
.33 .51711 Mdot
.59983 .63521 Mdot
.45971 .51634 Mdot
.66215 .4405 Mdot
.32934 .39777 Mdot
.31675 .67833 Mdot
.33787 .37996 Mdot
.66914 .43011 Mdot
.29157 .38691 Mdot
.4518 .25958 Mdot
.28666 .35177 Mdot
.58746 .65454 Mdot
.56436 .6238 Mdot
.67663 .36443 Mdot
.64153 .41479 Mdot
.55201 .65781 Mdot
.55725 .64105 Mdot
.68519 .41174 Mdot
.29137 .40109 Mdot
.68345 .48113 Mdot
.55116 .6544 Mdot
.56467 .6197 Mdot
.34635 .54626 Mdot
.41246 .68966 Mdot
.39049 .66202 Mdot
.59923 .66148 Mdot
.32606 .53893 Mdot
.69917 .40769 Mdot
.55839 .62859 Mdot
.31498 .68748 Mdot
.26691 .34733 Mdot
.60937 .66681 Mdot
.47919 .54721 Mdot
.62425 .68201 Mdot
.46229 .81393 Mdot
.61803 .65698 Mdot
.67439 .42273 Mdot
.68124 .42403 Mdot
.26081 .35896 Mdot
.67149 .41754 Mdot
.45408 .53585 Mdot
.48176 .32521 Mdot
.69793 .63712 Mdot
.44225 .52783 Mdot
.50609 .53921 Mdot
.37914 .5449 Mdot
.44799 .5087 Mdot
.45557 .50035 Mdot
.36475 .42963 Mdot
.49117 .5495 Mdot
.68298 .39768 Mdot
.59505 .43006 Mdot
.51768 .5573 Mdot
.52005 .31546 Mdot
.45394 .51163 Mdot
.60886 .66848 Mdot
.58181 .5847 Mdot
.62789 .4826 Mdot
.51116 .29522 Mdot
.5618 .55388 Mdot
.59999 .63583 Mdot
.65004 .49872 Mdot
.59049 .63169 Mdot
.30641 .50672 Mdot
.65621 .40509 Mdot
.34136 .37553 Mdot
.33646 .516 Mdot
.48856 .52193 Mdot
.34215 .51199 Mdot
.31769 .3655 Mdot
.47045 .30356 Mdot
.58565 .65281 Mdot
.29921 .52397 Mdot
.31404 .53884 Mdot
.56507 .67524 Mdot
.6831 .42423 Mdot
.54056 .5614 Mdot
.55527 .62356 Mdot
.61899 .65779 Mdot
.64514 .4352 Mdot
.47486 .17623 Mdot
.5436 .59806 Mdot
.46668 .57722 Mdot
.71027 .39385 Mdot
.44298 .51971 Mdot
.33804 .37017 Mdot
.51913 .61819 Mdot
.50329 .32997 Mdot
.48605 .32509 Mdot
.30763 .40712 Mdot
.65234 .44017 Mdot
.33946 .3977 Mdot
.53096 .59448 Mdot
.45447 .51092 Mdot
.59678 .63085 Mdot
.4046 .35559 Mdot
.54175 .2099 Mdot
.66674 .38404 Mdot
.32389 .40927 Mdot
.36864 .71018 Mdot
.45774 .29651 Mdot
.36135 .4217 Mdot
.7072 .40839 Mdot
.63324 .42172 Mdot
.64604 .43128 Mdot
.31231 .5334 Mdot
.33695 .38687 Mdot
.61317 .41834 Mdot
.61168 .42587 Mdot
.59824 .67998 Mdot
.60145 .63821 Mdot
.6976 .4005 Mdot
.32605 .43153 Mdot
.34226 .53676 Mdot
.35219 .38296 Mdot
.3879 .81223 Mdot
.49947 .28778 Mdot
.76516 .6342 Mdot
.59553 .6672 Mdot
.90263 .55307 Mdot
.57158 .65751 Mdot
.58789 .62365 Mdot
.61544 .42034 Mdot
.34379 .55287 Mdot
.32754 .51876 Mdot
.68938 .4092 Mdot
.64521 .38555 Mdot
.3117 .50664 Mdot
.42015 .66563 Mdot
.43146 .80786 Mdot
.37365 .68464 Mdot
.65417 .38662 Mdot
.68858 .64069 Mdot
.48586 .3062 Mdot
.71682 .39877 Mdot
.45485 .26391 Mdot
.28779 .38526 Mdot
.2825 .35406 Mdot
.46592 .30221 Mdot
.54544 .59641 Mdot
.35767 .39314 Mdot
.62728 .67631 Mdot
.42698 .32163 Mdot
.4919 .56933 Mdot
.23887 .69278 Mdot
.57744 .65258 Mdot
.53667 .47017 Mdot
.68907 .30208 Mdot
.57426 .67453 Mdot
.78627 .59878 Mdot
.3528 .53217 Mdot
.70453 .38447 Mdot
.511 .29101 Mdot
.80503 .42338 Mdot
.56608 .62632 Mdot
.64008 .40356 Mdot
.47932 .28717 Mdot
.52656 .20903 Mdot
.46429 .58522 Mdot
.5913 .68036 Mdot
.77626 .28196 Mdot
.67372 .45006 Mdot
.33902 .37311 Mdot
.69562 .58489 Mdot
.64031 .38649 Mdot
.46267 .59585 Mdot
.2939 .40082 Mdot
.44759 .70317 Mdot
.64092 .39568 Mdot
.32997 .55396 Mdot
.66338 .41275 Mdot
.32358 .50436 Mdot
.61528 .41185 Mdot
.31008 .40063 Mdot
.5513 .60299 Mdot
.31431 .40358 Mdot
.32462 .49887 Mdot
.33462 .41566 Mdot
.50924 .2898 Mdot
.49236 .54514 Mdot
.48025 .31906 Mdot
.38737 .74098 Mdot
.74868 .5245 Mdot
.48083 .2969 Mdot
.50153 .69995 Mdot
.58396 .6482 Mdot
.63456 .38833 Mdot
.34377 .37951 Mdot
.31936 .34607 Mdot
.38697 .69554 Mdot
.66238 .43432 Mdot
.32418 .4 Mdot
.68251 .62257 Mdot
.49017 .20891 Mdot
.60975 .61823 Mdot
.25976 .31003 Mdot
.6815 .4157 Mdot
.32652 .35004 Mdot
.37757 .67169 Mdot
.63113 .4149 Mdot
.27662 .36034 Mdot
.48405 .2912 Mdot
.50243 .33002 Mdot
.58159 .65572 Mdot
.52712 .32408 Mdot
.28837 .34483 Mdot
.62965 .5161 Mdot
.695 .40956 Mdot
.55067 .21194 Mdot
.34083 .54384 Mdot
.34684 .38809 Mdot
.48637 .5238 Mdot
.62556 .43784 Mdot
.29446 .3781 Mdot
.84154 .63393 Mdot
.39802 .84394 Mdot
.32517 .39881 Mdot
.65595 .4069 Mdot
.6446 .4181 Mdot
.53412 .63905 Mdot
.38354 .6982 Mdot
.32656 .39313 Mdot
.3838 .20528 Mdot
.42673 .73709 Mdot
.48679 .54336 Mdot
.14924 .48056 Mdot
.61676 .64479 Mdot
.62216 .67484 Mdot
.50419 .29488 Mdot
.55887 .60053 Mdot
.64681 .3854 Mdot
.57045 .65711 Mdot
.50885 .33184 Mdot
.30621 .40557 Mdot
.56273 .62745 Mdot
.34793 .53843 Mdot
.51173 .31373 Mdot
.51445 .31963 Mdot
.29109 .38443 Mdot
.6525 .43934 Mdot
.81079 .41326 Mdot
.33952 .38271 Mdot
.61998 .68005 Mdot
.4766 .53549 Mdot
.53578 .6058 Mdot
.70285 .35339 Mdot
.70218 .38636 Mdot
.34732 .38331 Mdot
.52539 .64535 Mdot
.50024 .31527 Mdot
.29529 .34212 Mdot
.61754 .64517 Mdot
.27251 .36169 Mdot
.42174 .52383 Mdot
.23122 .36052 Mdot
.6243 .44626 Mdot
.41403 .5172 Mdot
.63226 .42281 Mdot
.48883 .54787 Mdot
.24369 .61962 Mdot
.34231 .53876 Mdot
.35505 .40974 Mdot
.56397 .22216 Mdot
.32188 .40719 Mdot
.55595 .60807 Mdot
.57708 .64773 Mdot
.30466 .3619 Mdot
.32729 .54134 Mdot
.40706 .5372 Mdot
.31334 .54739 Mdot
.65035 .40692 Mdot
.46581 .6785 Mdot
.33883 .80159 Mdot
.28194 .34091 Mdot
.46513 .30859 Mdot
.73792 .39776 Mdot
.50453 .53681 Mdot
.50919 .29107 Mdot
.51455 .3157 Mdot
.33403 .50228 Mdot
.34461 .40503 Mdot
.70369 .4289 Mdot
.47176 .32574 Mdot
.63061 .40212 Mdot
.31195 .67591 Mdot
.44278 .5105 Mdot
.61642 .57088 Mdot
.48708 .51778 Mdot
.38985 .68725 Mdot
.46568 .32058 Mdot
.58091 .64081 Mdot
.58526 .56854 Mdot
.4869 .28892 Mdot
.34051 .50553 Mdot
.4999 .56898 Mdot
.32122 .39976 Mdot
.80322 .33573 Mdot
.58972 .65515 Mdot
.55136 .61591 Mdot
.49179 .28699 Mdot
.803 .57677 Mdot
.70466 .41027 Mdot
.6721 .43596 Mdot
.32149 .37462 Mdot
.35749 .65827 Mdot
.54977 .63743 Mdot
.58655 .65082 Mdot
.30112 .35983 Mdot
.46114 .52926 Mdot
.15136 .52531 Mdot
.56983 .62175 Mdot
.49094 .31092 Mdot
.47408 .57296 Mdot
.46608 .27703 Mdot
.55422 .57416 Mdot
.56067 .60808 Mdot
.60949 .68355 Mdot
.62036 .65361 Mdot
.47898 .31534 Mdot
.49373 .52487 Mdot
.51355 .5494 Mdot
.67842 .39765 Mdot
.58302 .59932 Mdot
.42851 .73596 Mdot
.56992 .62499 Mdot
.35193 .53597 Mdot
.38626 .66026 Mdot
.61141 .63625 Mdot
.58972 .60464 Mdot
.42393 .73933 Mdot
.57381 .60064 Mdot
.48847 .28573 Mdot
.64657 .42255 Mdot
.50182 .31632 Mdot
.46286 .30173 Mdot
.29198 .378 Mdot
.35527 .52044 Mdot
.52565 .60327 Mdot
.30733 .51542 Mdot
.53122 .62592 Mdot
.53995 .55669 Mdot
.39795 .71249 Mdot
.37183 .67368 Mdot
.29934 .50423 Mdot
.58826 .6496 Mdot
.3192 .36911 Mdot
.3513 .39745 Mdot
.46346 .63234 Mdot
.51625 .6212 Mdot
.52739 .314 Mdot
.4752 .29722 Mdot
.39179 .40701 Mdot
.22423 .35224 Mdot
.30072 .51557 Mdot
.40703 .53394 Mdot
.61875 .64415 Mdot
.54436 .61101 Mdot
.50216 .53983 Mdot
.29872 .37534 Mdot
.49237 .54954 Mdot
.34976 .4302 Mdot
.49634 .28027 Mdot
.50653 .30777 Mdot
.58253 .65362 Mdot
.74793 .73905 Mdot
.66242 .39338 Mdot
.64402 .41934 Mdot
.50693 .33369 Mdot
.34928 .41594 Mdot
.48063 .5248 Mdot
.82743 .37576 Mdot
.69952 .38669 Mdot
.32345 .54822 Mdot
.57979 .60159 Mdot
.29345 .39142 Mdot
.67872 .39221 Mdot
.30043 .52664 Mdot
.56835 .58768 Mdot
.30339 .40805 Mdot
.57874 .63668 Mdot
.63652 .54435 Mdot
.68872 .39989 Mdot
.40865 .70631 Mdot
.64828 .44965 Mdot
.48104 .31514 Mdot
.46371 .31303 Mdot
.5598 .61026 Mdot
.82453 .36635 Mdot
.67846 .45996 Mdot
.48086 .337 Mdot
.35346 .54825 Mdot
.49574 .54418 Mdot
.35154 .51698 Mdot
.30594 .36678 Mdot
.34453 .53871 Mdot
.29403 .37871 Mdot
.27548 .38644 Mdot
.69006 .43967 Mdot
.3208 .52758 Mdot
.77538 .58395 Mdot
.46245 .5144 Mdot
.36554 .54329 Mdot
.60656 .63436 Mdot
.53936 .64085 Mdot
.31851 .3913 Mdot
.30602 .52088 Mdot
.52034 .62469 Mdot
.58827 .25947 Mdot
.46017 .30281 Mdot
.50912 .28919 Mdot
.48198 .52758 Mdot
.31567 .34853 Mdot
.68915 .43973 Mdot
.37057 .71583 Mdot
.68795 .44714 Mdot
.58872 .65143 Mdot
.52656 .60281 Mdot
.63413 .4485 Mdot
.68258 .44249 Mdot
.5641 .60959 Mdot
.72283 .67015 Mdot
.48674 .5231 Mdot
.49947 .33131 Mdot
.65113 .4044 Mdot
.6423 .41028 Mdot
.28806 .34613 Mdot
.6685 .43906 Mdot
.60465 .57343 Mdot
.50038 .28279 Mdot
.51484 .55074 Mdot
.49707 .31543 Mdot
.2873 .54667 Mdot
.31188 .39271 Mdot
.54667 .21782 Mdot
.67438 .43599 Mdot
.56272 .66504 Mdot
.67875 .4354 Mdot
.35555 .53958 Mdot
.6453 .39513 Mdot
.71676 .38186 Mdot
.59872 .64853 Mdot
.49546 .5277 Mdot
.45243 .52825 Mdot
.38559 .69142 Mdot
.66734 .396 Mdot
.52948 .60213 Mdot
.56184 .65447 Mdot
.56051 .64398 Mdot
.38989 .71037 Mdot
.65839 .44619 Mdot
.81537 .55332 Mdot
.6097 .43588 Mdot
.68671 .39712 Mdot
.45504 .84736 Mdot
.44896 .52803 Mdot
.50385 .54966 Mdot
.49365 .3667 Mdot
.56727 .61927 Mdot
.33674 .40175 Mdot
.61711 .68042 Mdot
.49605 .53196 Mdot
.60212 .62016 Mdot
.32085 .51115 Mdot
.54023 .59122 Mdot
.47388 .53827 Mdot
.34243 .38376 Mdot
.57987 .67559 Mdot
.56041 .62072 Mdot
.45811 .5269 Mdot
.68472 .43216 Mdot
.63731 .43178 Mdot
.66859 .45743 Mdot
.3224 .50186 Mdot
.4879 .30004 Mdot
.61774 .67903 Mdot
.32049 .37233 Mdot
.33643 .40364 Mdot
.64012 .44564 Mdot
.30967 .35454 Mdot
.50639 .30432 Mdot
.5844 .61947 Mdot
.4801 .31593 Mdot
.32249 .50888 Mdot
.65657 .40384 Mdot
.61805 .66868 Mdot
.58357 .68269 Mdot
.68145 .42384 Mdot
.47967 .51778 Mdot
.35732 .5424 Mdot
.29637 .35692 Mdot
.67418 .38477 Mdot
.48427 .32584 Mdot
.28763 .34823 Mdot
.57114 .67126 Mdot
.56857 .83976 Mdot
.55945 .6012 Mdot
.55532 .6418 Mdot
.64337 .46938 Mdot
.56432 .57673 Mdot
.31553 .40552 Mdot
.66671 .44254 Mdot
.5445 .64666 Mdot
.40849 .75229 Mdot
.29393 .5002 Mdot
.28528 .33687 Mdot
.58507 .61178 Mdot
.68824 .7105 Mdot
.57093 .66579 Mdot
.57633 .22574 Mdot
.39844 .71185 Mdot
.47733 .2436 Mdot
.60927 .56512 Mdot
.48643 .33865 Mdot
.46915 .53186 Mdot
.29516 .38465 Mdot
.74654 .62873 Mdot
.5673 .60719 Mdot
.74573 .49625 Mdot
.61657 .67104 Mdot
.50355 .30987 Mdot
.79235 .58063 Mdot
.33195 .3603 Mdot
.18175 .56989 Mdot
.56454 .58902 Mdot
.7047 .40202 Mdot
.33597 .44793 Mdot
.50119 .54656 Mdot
.50331 .53703 Mdot
.30394 .50971 Mdot
.3899 .39137 Mdot
.55904 .55944 Mdot
.49959 .31689 Mdot
.54182 .61581 Mdot
.59117 .68936 Mdot
.49774 .19212 Mdot
.68207 .40452 Mdot
.46997 .29264 Mdot
.22695 .371 Mdot
.58467 .64398 Mdot
.6338 .42404 Mdot
.66234 .4262 Mdot
.31117 .51576 Mdot
.487 .24717 Mdot
.39466 .37754 Mdot
.73691 .73106 Mdot
.57482 .54494 Mdot
.29728 .37218 Mdot
.42493 .51105 Mdot
.61624 .68175 Mdot
.31064 .59814 Mdot
.4652 .31132 Mdot
.55045 .61112 Mdot
.76128 .47511 Mdot
.67808 .41477 Mdot
.57807 .62994 Mdot
.34406 .53368 Mdot
.8209 .40895 Mdot
.67803 .63455 Mdot
.6992 .69005 Mdot
.27629 .38308 Mdot
.52477 .60546 Mdot
.60275 .57236 Mdot
.44532 .52103 Mdot
.55379 .57312 Mdot
.34041 .37577 Mdot
.41798 .51394 Mdot
.33866 .53189 Mdot
.67513 .39113 Mdot
.47118 .53133 Mdot
.61638 .67032 Mdot
.52183 .60687 Mdot
.35153 .54759 Mdot
.60461 .68269 Mdot
.7052 .59649 Mdot
.4312 .5189 Mdot
.2871 .35386 Mdot
.66589 .38241 Mdot
.52623 .6068 Mdot
.49694 .54345 Mdot
.59612 .63361 Mdot
.73726 .43535 Mdot
.548 .61122 Mdot
.56125 .24602 Mdot
.6743 .43155 Mdot
.4965 .32616 Mdot
.61794 .64517 Mdot
.57433 .6341 Mdot
.41318 .51945 Mdot
.47628 .52216 Mdot
.58094 .59956 Mdot
.63408 .43347 Mdot
.66922 .39122 Mdot
.70398 .40203 Mdot
.27879 .35079 Mdot
.37413 .68992 Mdot
.48559 .31829 Mdot
.50278 .54097 Mdot
.47203 .32605 Mdot
.63249 .72732 Mdot
.33098 .50475 Mdot
.528 .2157 Mdot
.58024 .61604 Mdot
.65468 .43385 Mdot
.41853 .80115 Mdot
.64388 .44726 Mdot
.44675 .35951 Mdot
.46669 .31479 Mdot
.66554 .40151 Mdot
.57787 .60525 Mdot
.38976 .67989 Mdot
.70178 .70512 Mdot
.45803 .30082 Mdot
.50815 .55324 Mdot
.27546 .54949 Mdot
.27463 .37456 Mdot
.43962 .84181 Mdot
.48298 .33174 Mdot
.69062 .30171 Mdot
.5506 .65382 Mdot
.68556 .42759 Mdot
.47722 .30695 Mdot
.5162 .31492 Mdot
.33057 .35814 Mdot
.59537 .67991 Mdot
.57536 .63301 Mdot
.47803 .54653 Mdot
.47184 .3119 Mdot
.51884 .63203 Mdot
.58417 .67982 Mdot
.40403 .33592 Mdot
.70582 .39593 Mdot
.47216 .17434 Mdot
.52776 .71764 Mdot
.76078 .47651 Mdot
.43332 .20085 Mdot
.68352 .38701 Mdot
.54732 .59374 Mdot
.48814 .52872 Mdot
.29929 .35456 Mdot
.57731 .60886 Mdot
.32624 .40971 Mdot
.49811 .30372 Mdot
.57399 .25746 Mdot
.5141 .71318 Mdot
.42658 .33753 Mdot
.55445 .60287 Mdot
.6777 .62609 Mdot
.32957 .53001 Mdot
.50947 .28828 Mdot
.69791 .42663 Mdot
.53311 .60413 Mdot
.31778 .35287 Mdot
.27435 .36995 Mdot
.67748 .41119 Mdot
.66874 .31327 Mdot
.5534 .21834 Mdot
.47764 .51803 Mdot
.32048 .35875 Mdot
.49652 .5387 Mdot
.68284 .69882 Mdot
.47603 .33212 Mdot
.33779 .53101 Mdot
.28527 .37629 Mdot
.52176 .32192 Mdot
.53914 .64103 Mdot
.67248 .40681 Mdot
.65528 .45534 Mdot
.46196 .62052 Mdot
.32589 .4006 Mdot
.33621 .51168 Mdot
.46679 .60853 Mdot
.46347 .66664 Mdot
.34037 .52118 Mdot
.27805 .34774 Mdot
.64865 .39839 Mdot
.66957 .42831 Mdot
.6488 .42429 Mdot
.76562 .63196 Mdot
.70081 .38549 Mdot
.29726 .62385 Mdot
.55487 .57324 Mdot
.68955 .6328 Mdot
.54137 .63612 Mdot
.51081 .29111 Mdot
.692 .40475 Mdot
.39995 .71193 Mdot
.6214 .65349 Mdot
.7046 .7047 Mdot
.55575 .63529 Mdot
.47054 .57427 Mdot
.56604 .61895 Mdot
.65226 .54859 Mdot
.6993 .37954 Mdot
.56183 .5867 Mdot
.47633 .2781 Mdot
.35094 .52104 Mdot
.6215 .40622 Mdot
.55632 .59266 Mdot
.63954 .34959 Mdot
.60745 .63629 Mdot
.57099 .25395 Mdot
.46273 .6036 Mdot
.35843 .46425 Mdot
.53881 .62149 Mdot
.36001 .41509 Mdot
.63123 .68752 Mdot
.6909 .64944 Mdot
.45972 .30801 Mdot
.68044 .62491 Mdot
.35846 .40445 Mdot
.79382 .57864 Mdot
.47343 .51687 Mdot
.33748 .53607 Mdot
.42167 .5105 Mdot
.49392 .33147 Mdot
.57463 .61173 Mdot
.54966 .59023 Mdot
.49534 .57369 Mdot
.67671 .70149 Mdot
.45288 .52148 Mdot
.29844 .50682 Mdot
.68152 .65771 Mdot
.57691 .5974 Mdot
.29384 .33522 Mdot
.64478 .43962 Mdot
.78492 .57682 Mdot
.79413 .56143 Mdot
.57592 .6761 Mdot
.6697 .40075 Mdot
.65258 .44009 Mdot
.35453 .78829 Mdot
.3262 .53489 Mdot
.54868 .61857 Mdot
.40845 .5075 Mdot
.61786 .67752 Mdot
.49427 .30604 Mdot
.60453 .61378 Mdot
.31363 .39421 Mdot
.38261 .66977 Mdot
.27636 .35029 Mdot
.56216 .64513 Mdot
.66159 .41364 Mdot
.46135 .28921 Mdot
.27276 .38383 Mdot
.4865 .24758 Mdot
.29625 .62546 Mdot
.38658 .4 Mdot
.30087 .51786 Mdot
.3393 .5064 Mdot
.50967 .28865 Mdot
.58674 .61691 Mdot
.3864 .70682 Mdot
.58112 .73098 Mdot
.57244 .61931 Mdot
.55183 .59655 Mdot
.50282 .35884 Mdot
.47078 .31975 Mdot
.29629 .39247 Mdot
.56582 .60962 Mdot
.53233 .59529 Mdot
.6624 .40856 Mdot
.30432 .52712 Mdot
.28851 .36443 Mdot
.31357 .5028 Mdot
.33113 .3729 Mdot
.46368 .81446 Mdot
.44677 .51043 Mdot
.33748 .50869 Mdot
.48668 .33482 Mdot
.64633 .42836 Mdot
.44888 .52998 Mdot
.30966 .37428 Mdot
.31485 .35525 Mdot
.52855 .62764 Mdot
.67855 .39295 Mdot
.6732 .43576 Mdot
.31236 .50512 Mdot
.47668 .29741 Mdot
.62852 .67284 Mdot
.4918 .52122 Mdot
.25226 .35135 Mdot
.30758 .35023 Mdot
.6848 .64942 Mdot
.62953 .45681 Mdot
.59423 .63656 Mdot
.6362 .42814 Mdot
.56587 .63223 Mdot
.71723 .37505 Mdot
.67038 .45084 Mdot
.57373 .58217 Mdot
.58753 .70356 Mdot
.29793 .37677 Mdot
.2956 .7593 Mdot
.59431 .59481 Mdot
.44373 .30025 Mdot
.6138 .68122 Mdot
.16043 .54919 Mdot
.40976 .79617 Mdot
.59689 .62371 Mdot
.53993 .5937 Mdot
.70641 .76518 Mdot
.57493 .66667 Mdot
.48353 .54536 Mdot
.47073 .5159 Mdot
.63483 .42373 Mdot
.41349 .51496 Mdot
.38836 .69094 Mdot
.31808 .53128 Mdot
.32018 .37396 Mdot
.31724 .69511 Mdot
.32491 .50368 Mdot
.67733 .41987 Mdot
.62886 .675 Mdot
.64808 .46673 Mdot
.35656 .37724 Mdot
.46952 .52724 Mdot
.50056 .30675 Mdot
.38759 .70116 Mdot
.3234 .35472 Mdot
.48048 .32502 Mdot
.56878 .66155 Mdot
.33046 .42846 Mdot
.47133 .27688 Mdot
.30582 .76849 Mdot
.51009 .29863 Mdot
.48477 .32841 Mdot
.37905 .69604 Mdot
.31786 .53121 Mdot
.42336 .51956 Mdot
.5251 .55289 Mdot
.46643 .28596 Mdot
.20334 .59099 Mdot
.32361 .35268 Mdot
.35993 .68849 Mdot
.70261 .38106 Mdot
.453 .51242 Mdot
.55101 .59973 Mdot
.50274 .29253 Mdot
.52285 .64375 Mdot
.41235 .51929 Mdot
.50923 .31709 Mdot
.62499 .68881 Mdot
.36187 .65765 Mdot
.49335 .54059 Mdot
.45252 .53101 Mdot
.30564 .53586 Mdot
.25943 .41661 Mdot
.65595 .43726 Mdot
.32734 .54886 Mdot
.40083 .73253 Mdot
.55257 .63407 Mdot
.47861 .31361 Mdot
.47121 .53076 Mdot
.48957 .32485 Mdot
.32969 .52378 Mdot
.35708 .5453 Mdot
.67927 .39851 Mdot
.70392 .40644 Mdot
.44855 .53607 Mdot
.43028 .74051 Mdot
.60932 .66424 Mdot
.74072 .51219 Mdot
.67778 .44578 Mdot
.78458 .6112 Mdot
.31371 .53149 Mdot
.30545 .52715 Mdot
.66253 .66344 Mdot
.60311 .6586 Mdot
.4727 .57274 Mdot
.61062 .63404 Mdot
.20253 .56973 Mdot
.61715 .6674 Mdot
.30315 .35664 Mdot
.60266 .61661 Mdot
.7238 .33888 Mdot
.53704 .64567 Mdot
.57031 .5958 Mdot
.33024 .38545 Mdot
.52702 .61699 Mdot
.31714 .3931 Mdot
.54387 .60111 Mdot
.34864 .33968 Mdot
.32102 .3728 Mdot
.33517 .56855 Mdot
.4822 .60224 Mdot
.47043 .54032 Mdot
.31541 .51765 Mdot
.30087 .5119 Mdot
.31533 .67325 Mdot
.65455 .39552 Mdot
.79082 .46908 Mdot
.57715 .6003 Mdot
.31808 .35036 Mdot
.49594 .3003 Mdot
.56409 .67069 Mdot
.5666 .65205 Mdot
.59417 .59487 Mdot
.67313 .39774 Mdot
.29671 .34358 Mdot
.32216 .52055 Mdot
.34312 .40817 Mdot
.33313 .3329 Mdot
.30824 .38879 Mdot
.5691 .71086 Mdot
.53541 .63635 Mdot
.60321 .57318 Mdot
.75946 .54763 Mdot
.37139 .5216 Mdot
.67563 .40808 Mdot
.47213 .53405 Mdot
.34356 .51009 Mdot
.39195 .65154 Mdot
.64699 .43534 Mdot
.30253 .35983 Mdot
.57871 .63712 Mdot
.44186 .50887 Mdot
.52544 .55399 Mdot
.63351 .39423 Mdot
.36578 .53481 Mdot
.31722 .37794 Mdot
.48714 .5417 Mdot
.3718 .68693 Mdot
.81688 .51955 Mdot
.38076 .73703 Mdot
.57101 .63388 Mdot
.3127 .50601 Mdot
.67799 .39211 Mdot
.47924 .56942 Mdot
.49121 .28999 Mdot
.38453 .69648 Mdot
.55533 .60102 Mdot
.44547 .36649 Mdot
.66226 .41484 Mdot
.3314 .54246 Mdot
.50481 .29345 Mdot
.3294 .53735 Mdot
.50105 .55028 Mdot
.61131 .43956 Mdot
.50354 .53762 Mdot
.61806 .65651 Mdot
.49456 .30144 Mdot
.66143 .43721 Mdot
.35943 .34505 Mdot
.45308 .54315 Mdot
.30529 .36263 Mdot
.39683 .65664 Mdot
.67239 .39141 Mdot
.41223 .35501 Mdot
.34206 .40899 Mdot
.52413 .34891 Mdot
.41251 .68184 Mdot
.50915 .30681 Mdot
.56408 .5937 Mdot
.65067 .41938 Mdot
.45781 .30098 Mdot
.29748 .42345 Mdot
.73156 .68545 Mdot
.4375 .52958 Mdot
.58221 .64849 Mdot
.58459 .22414 Mdot
.7002 .31238 Mdot
.68793 .36617 Mdot
.49265 .33434 Mdot
.55511 .61498 Mdot
.47529 .51636 Mdot
.56881 .5901 Mdot
.46409 .29051 Mdot
.54344 .32455 Mdot
.35215 .3867 Mdot
.58195 .64012 Mdot
.34737 .54045 Mdot
.30927 .39516 Mdot
.28306 .38778 Mdot
.28342 .37396 Mdot
.69858 .42472 Mdot
.44487 .51331 Mdot
.46814 .51428 Mdot
.3906 .78184 Mdot
.49387 .32815 Mdot
.47058 .54022 Mdot
.5425 .59095 Mdot
.29897 .6273 Mdot
.65514 .43121 Mdot
.31819 .38239 Mdot
.55131 .61734 Mdot
.46142 .61533 Mdot
.46081 .52491 Mdot
.33784 .38517 Mdot
.68395 .44223 Mdot
.60227 .47473 Mdot
.5788 .61114 Mdot
.61032 .67836 Mdot
.68228 .41926 Mdot
.74091 .3221 Mdot
.36853 .68292 Mdot
.56542 .63036 Mdot
.48817 .32702 Mdot
.69005 .25731 Mdot
.56386 .65857 Mdot
.70345 .43926 Mdot
.48974 .55117 Mdot
.60153 .40817 Mdot
.70214 .60954 Mdot
.55601 .6745 Mdot
.53519 .43634 Mdot
.41466 .56862 Mdot
.56128 .46818 Mdot
.22536 .5758 Mdot
.45975 .43299 Mdot
.32884 .78983 Mdot
.51508 .29046 Mdot
.64565 .55506 Mdot
.8333 .6402 Mdot
.67501 .30485 Mdot
.41126 .44773 Mdot
.54841 .30434 Mdot
.29359 .4919 Mdot
.14823 .51019 Mdot
.35221 .42982 Mdot
.22851 .57213 Mdot
.61705 .65588 Mdot
.73071 .32061 Mdot
.65331 .56768 Mdot
.37418 .43368 Mdot
.46089 .24658 Mdot
.46398 .60746 Mdot
.64903 .77937 Mdot
.42992 .32339 Mdot
.53135 .83115 Mdot
.77236 .47062 Mdot
.24934 .37606 Mdot
.43787 .67415 Mdot
.3001 .67924 Mdot
.6724 .60032 Mdot
.57841 .43738 Mdot
.49895 .27501 Mdot
.66809 .49766 Mdot
.44693 .19626 Mdot
.31578 .36138 Mdot
.63589 .39425 Mdot
.55554 .35673 Mdot
.59893 .80461 Mdot
.44635 .34312 Mdot
.53351 .43688 Mdot
.45547 .54363 Mdot
.64959 .54947 Mdot
.40522 .71233 Mdot
.64036 .53216 Mdot
.39677 .39029 Mdot
.15083 .51051 Mdot
.64488 .47429 Mdot
.29341 .42605 Mdot
.37097 .63927 Mdot
.39689 .4489 Mdot
.67446 .56145 Mdot
.34032 .49878 Mdot
.33005 .56807 Mdot
.68236 .44406 Mdot
.642 .76338 Mdot
.50411 .68892 Mdot
.40697 .73387 Mdot
.35187 .43149 Mdot
.70843 .45436 Mdot
.81521 .4071 Mdot
.68267 .31862 Mdot
.25559 .72096 Mdot
.56862 .83556 Mdot
.23522 .6336 Mdot
.49496 .58626 Mdot
.45226 .35087 Mdot
.32044 .61194 Mdot
.52986 .46957 Mdot
.24876 .66708 Mdot
.73914 .43142 Mdot
.68977 .75337 Mdot
.60848 .35471 Mdot
.61038 .81597 Mdot
.63182 .4772 Mdot
.57655 .56416 Mdot
.64574 .37138 Mdot
.62136 .51552 Mdot
.37074 .74836 Mdot
.62411 .79866 Mdot
.3681 .44265 Mdot
.50489 .55932 Mdot
.66189 .30497 Mdot
.70363 .59614 Mdot
.40233 .37419 Mdot
.33079 .56144 Mdot
.77807 .54609 Mdot
.65035 .78813 Mdot
.54697 .432 Mdot
.59243 .78058 Mdot
.40081 .33472 Mdot
.29391 .29228 Mdot
.29244 .39733 Mdot
.50454 .34175 Mdot
.54994 .83031 Mdot
.65461 .42279 Mdot
.2861 .75701 Mdot
.4637 .44215 Mdot
.44943 .46179 Mdot
.65504 .78502 Mdot
.23797 .68021 Mdot
.6874 .60693 Mdot
.39416 .54318 Mdot
.49433 .2121 Mdot
.5837 .49583 Mdot
.41945 .34234 Mdot
.29343 .56025 Mdot
.57388 .24061 Mdot
.56772 .82282 Mdot
.22821 .64706 Mdot
.75072 .7212 Mdot
.41632 .72912 Mdot
.25641 .55842 Mdot
.65141 .47238 Mdot
.47316 .40297 Mdot
.41204 .37496 Mdot
.60005 .82347 Mdot
.67699 .64014 Mdot
.64557 .22743 Mdot
.22934 .59016 Mdot
.79864 .56344 Mdot
.61592 .24971 Mdot
.54519 .36585 Mdot
.61369 .51061 Mdot
.64226 .34613 Mdot
.49192 .51541 Mdot
.35748 .73432 Mdot
.77739 .52572 Mdot
.35405 .46011 Mdot
.37912 .67897 Mdot
.60863 .3347 Mdot
.27173 .67597 Mdot
.66367 .25056 Mdot
.78205 .53785 Mdot
.63345 .44653 Mdot
.24962 .66629 Mdot
.22761 .60432 Mdot
.62937 .23028 Mdot
.22731 .37561 Mdot
.58787 .78455 Mdot
.4345 .37391 Mdot
.57092 .68584 Mdot
.64468 .55708 Mdot
.6715 .59474 Mdot
.16572 .5317 Mdot
.57263 .70608 Mdot
.34594 .77452 Mdot
.4457 .27316 Mdot
.75093 .56912 Mdot
.32334 .73207 Mdot
.75763 .55869 Mdot
.69871 .63443 Mdot
.71251 .3524 Mdot
.45152 .27419 Mdot
.54252 .68271 Mdot
.65516 .78084 Mdot
.29992 .39295 Mdot
.24699 .66818 Mdot
.43766 .33743 Mdot
.27919 .40162 Mdot
.42398 .45983 Mdot
.40545 .45998 Mdot
.49536 .84398 Mdot
.64745 .30432 Mdot
.28024 .50541 Mdot
.60472 .45026 Mdot
.49608 .4516 Mdot
.74624 .5166 Mdot
.54397 .71782 Mdot
.72229 .44458 Mdot
.35733 .54259 Mdot
.75076 .60584 Mdot
.64279 .35817 Mdot
.22325 .38224 Mdot
.57458 .71577 Mdot
.44242 .67485 Mdot
.47327 .54634 Mdot
.32894 .66382 Mdot
.45719 .81467 Mdot
.55189 .6774 Mdot
.24534 .68746 Mdot
.66555 .30937 Mdot
.32758 .66951 Mdot
.4108 .3782 Mdot
.79581 .47304 Mdot
.61364 .81463 Mdot
.42314 .83087 Mdot
.74386 .33649 Mdot
.60558 .24228 Mdot
.19892 .34618 Mdot
.46861 .24958 Mdot
.30919 .7579 Mdot
.43789 .33785 Mdot
.73604 .22507 Mdot
.31601 .40676 Mdot
.30203 .5968 Mdot
.6381 .48957 Mdot
.44076 .65191 Mdot
.62049 .7896 Mdot
.68659 .58932 Mdot
.36764 .5431 Mdot
.6631 .3688 Mdot
.57786 .70059 Mdot
.64214 .77536 Mdot
.66603 .76437 Mdot
.64867 .76748 Mdot
.52208 .36754 Mdot
.70813 .67918 Mdot
.6856 .77534 Mdot
.30369 .6178 Mdot
.50033 .64634 Mdot
.57099 .68105 Mdot
.41736 .7545 Mdot
.29282 .73619 Mdot
.35825 .50737 Mdot
.5868 .49798 Mdot
.64327 .4736 Mdot
.66946 .78707 Mdot
.44249 .81422 Mdot
.63456 .52957 Mdot
.50202 .8381 Mdot
.27029 .50603 Mdot
.34027 .75272 Mdot
.4626 .83857 Mdot
.56478 .43167 Mdot
.4881 .37299 Mdot
.68596 .78523 Mdot
.23945 .61718 Mdot
.54912 .30928 Mdot
.64064 .35163 Mdot
.29127 .74216 Mdot
.60606 .25113 Mdot
.55287 .33122 Mdot
.63947 .48561 Mdot
.81723 .48006 Mdot
.41442 .43123 Mdot
.58053 .44311 Mdot
.48811 .58078 Mdot
.31992 .73489 Mdot
.32736 .41296 Mdot
.26295 .68742 Mdot
.41079 .40829 Mdot
.50523 .64576 Mdot
.32823 .69553 Mdot
.21739 .61633 Mdot
.58627 .38092 Mdot
.69495 .69635 Mdot
.65692 .30897 Mdot
.68184 .25741 Mdot
.62857 .24435 Mdot
.7834 .49966 Mdot
.52651 .61243 Mdot
.60543 .8024 Mdot
.36381 .82067 Mdot
.47184 .8428 Mdot
.64308 .23679 Mdot
.28506 .308 Mdot
.52569 .31424 Mdot
.30801 .62887 Mdot
.44407 .63504 Mdot
.54785 .40608 Mdot
.42721 .56539 Mdot
.47031 .33233 Mdot
.81641 .40469 Mdot
.43301 .45782 Mdot
.30572 .62031 Mdot
.68201 .49114 Mdot
.4834 .4577 Mdot
.68119 .70125 Mdot
.63616 .44869 Mdot
.60886 .21616 Mdot
.25118 .66994 Mdot
.29487 .38775 Mdot
.25037 .3479 Mdot
.53816 .68856 Mdot
.58313 .56898 Mdot
.27126 .54998 Mdot
.51974 .65185 Mdot
.76045 .47922 Mdot
.27898 .3125 Mdot
.39048 .80468 Mdot
.29325 .75444 Mdot
.45775 .83774 Mdot
.23079 .62758 Mdot
.28437 .41223 Mdot
.33628 .67137 Mdot
.46159 .3379 Mdot
.43547 .31178 Mdot
.3494 .65616 Mdot
.22165 .61199 Mdot
.68918 .61224 Mdot
.66095 .36727 Mdot
.52706 .64106 Mdot
.42567 .80394 Mdot
.29325 .65903 Mdot
.33515 .65075 Mdot
.80368 .50365 Mdot
.71319 .41054 Mdot
.26238 .57673 Mdot
.58832 .43746 Mdot
.63963 .6783 Mdot
.60847 .238 Mdot
.45746 .30833 Mdot
.64524 .45297 Mdot
.21673 .61734 Mdot
.22869 .32628 Mdot
.5393 .46301 Mdot
.50489 .699 Mdot
.57174 .81533 Mdot
.47767 .6275 Mdot
.59144 .24805 Mdot
.83069 .48709 Mdot
.42786 .28666 Mdot
.64273 .47745 Mdot
.50084 .62559 Mdot
.41751 .46419 Mdot
.74623 .35736 Mdot
.62451 .41598 Mdot
.67539 .63026 Mdot
.54781 .83695 Mdot
.46903 .59868 Mdot
.57332 .44839 Mdot
.36896 .71373 Mdot
.44653 .40619 Mdot
.47803 .44504 Mdot
.32472 .69766 Mdot
.55043 .4546 Mdot
.61873 .76372 Mdot
.81966 .38528 Mdot
.59522 .50607 Mdot
.27603 .59081 Mdot
.30988 .62383 Mdot
.77282 .46943 Mdot
.67037 .55712 Mdot
.4382 .27984 Mdot
.61682 .64807 Mdot
.53709 .84625 Mdot
.61086 .3446 Mdot
.32804 .68353 Mdot
.47077 .37977 Mdot
.5822 .67285 Mdot
.57397 .56089 Mdot
.4741 .84086 Mdot
.60123 .40405 Mdot
.86502 .60206 Mdot
.21719 .57826 Mdot
.7417 .38956 Mdot
.69941 .61262 Mdot
.25392 .69593 Mdot
.73408 .36413 Mdot
.47963 .43618 Mdot
.41615 .40108 Mdot
.27842 .72383 Mdot
.60819 .38358 Mdot
.59673 .41142 Mdot
.60027 .22426 Mdot
.68822 .76865 Mdot
.57831 .47976 Mdot
.52837 .35162 Mdot
.26862 .51263 Mdot
.55286 .63976 Mdot
.67256 .31321 Mdot
.53437 .2135 Mdot
.48662 .3856 Mdot
.56696 .47996 Mdot
.36035 .82123 Mdot
.60625 .69692 Mdot
.64378 .31099 Mdot
.85996 .60914 Mdot
.88499 .57716 Mdot
.71004 .3371 Mdot
.59048 .82993 Mdot
.59745 .42167 Mdot
.59154 .25107 Mdot
.46206 .27217 Mdot
.46804 .67902 Mdot
.74283 .5029 Mdot
.50062 .85203 Mdot
.23615 .31708 Mdot
.4185 .34341 Mdot
.66108 .49038 Mdot
.49622 .8537 Mdot
.59914 .69759 Mdot
.27901 .58687 Mdot
.2965 .29222 Mdot
.18444 .57569 Mdot
.25451 .71595 Mdot
.81 .49825 Mdot
.16404 .53667 Mdot
.21511 .54802 Mdot
.38081 .44011 Mdot
.29729 .75457 Mdot
.56184 .54536 Mdot
.80794 .47229 Mdot
.24864 .66333 Mdot
.59018 .23493 Mdot
.17268 .41316 Mdot
.48703 .44508 Mdot
.5104 .63655 Mdot
.70463 .34433 Mdot
.57126 .24243 Mdot
.58393 .34554 Mdot
.48816 .64234 Mdot
.39791 .66359 Mdot
.69544 .6394 Mdot
.68574 .25169 Mdot
.83952 .49534 Mdot
.50908 .62205 Mdot
.67569 .75042 Mdot
.4304 .30811 Mdot
.35157 .64098 Mdot
.69039 .57764 Mdot
.30212 .65486 Mdot
.27226 .51853 Mdot
.60622 .62628 Mdot
.55456 .83451 Mdot
.27211 .52018 Mdot
.66468 .75785 Mdot
.28639 .76103 Mdot
.51562 .83243 Mdot
.45838 .46569 Mdot
.27852 .54951 Mdot
.28933 .7277 Mdot
.29426 .73118 Mdot
.70255 .74006 Mdot
.23234 .56766 Mdot
.35568 .65374 Mdot
.48965 .61188 Mdot
.51216 .70967 Mdot
.63159 .71584 Mdot
.2566 .70039 Mdot
.78373 .4537 Mdot
.32353 .72843 Mdot
.74429 .34127 Mdot
.22006 .6154 Mdot
.68566 .59992 Mdot
.30695 .66038 Mdot
.45757 .38768 Mdot
.36567 .55931 Mdot
.32529 .35263 Mdot
.73673 .74125 Mdot
.62228 .23177 Mdot
.36479 .779 Mdot
.6379 .22528 Mdot
.63665 .34819 Mdot
.21644 .56377 Mdot
.63609 .37797 Mdot
.58038 .51598 Mdot
.25241 .38713 Mdot
.28546 .68532 Mdot
.68197 .63824 Mdot
.57661 .22484 Mdot
.80567 .54245 Mdot
.50504 .84579 Mdot
.32616 .73704 Mdot
.77603 .70155 Mdot
.26018 .54952 Mdot
.75169 .60107 Mdot
.63914 .76151 Mdot
.71881 .28932 Mdot
.33438 .64474 Mdot
.65869 .77639 Mdot
.6868 .3717 Mdot
.57407 .83362 Mdot
.4938 .29343 Mdot
.26653 .56977 Mdot
.55685 .22285 Mdot
.32095 .64029 Mdot
.32268 .63854 Mdot
.37306 .79244 Mdot
.6552 .30572 Mdot
.6889 .31618 Mdot
.43313 .37313 Mdot
.34587 .42925 Mdot
.49252 .7023 Mdot
.56451 .44582 Mdot
.74375 .72502 Mdot
.52724 .6106 Mdot
.24916 .54034 Mdot
.246 .67593 Mdot
.46531 .34099 Mdot
.5031 .59198 Mdot
.57058 .2291 Mdot
.82681 .50491 Mdot
.37306 .76141 Mdot
.68069 .77357 Mdot
.50338 .58957 Mdot
.4412 .61746 Mdot
.79832 .58334 Mdot
.55915 .32341 Mdot
.42611 .30515 Mdot
.5421 .43976 Mdot
.4799 .65303 Mdot
.36756 .68608 Mdot
.23425 .62679 Mdot
.34474 .80677 Mdot
.68675 .74576 Mdot
.42663 .30132 Mdot
.32675 .64764 Mdot
.70735 .43607 Mdot
.29312 .68572 Mdot
.76859 .7104 Mdot
.15314 .53117 Mdot
.64095 .35061 Mdot
.22397 .62728 Mdot
.5294 .37029 Mdot
.28087 .58974 Mdot
.34167 .65325 Mdot
.63657 .7641 Mdot
.63602 .49463 Mdot
.60239 .41808 Mdot
.54695 .3694 Mdot
.39279 .69496 Mdot
.43617 .44854 Mdot
.80675 .48222 Mdot
.6511 .30136 Mdot
.7776 .69985 Mdot
.20388 .54595 Mdot
.79227 .57456 Mdot
.81661 .65843 Mdot
.69165 .43789 Mdot
.42687 .44935 Mdot
.31344 .27536 Mdot
.32528 .66258 Mdot
.2806 .3785 Mdot
.51977 .63419 Mdot
.3787 .65436 Mdot
.73797 .34757 Mdot
.28867 .49229 Mdot
.3606 .52742 Mdot
.63621 .44622 Mdot
.22056 .55559 Mdot
.64712 .45415 Mdot
.3425 .80275 Mdot
.56359 .42556 Mdot
.69223 .63924 Mdot
.83669 .52405 Mdot
.27816 .40995 Mdot
.69486 .26651 Mdot
.52592 .83298 Mdot
.41426 .74868 Mdot
.62474 .40977 Mdot
.61619 .43152 Mdot
.61209 .45869 Mdot
.48344 .34559 Mdot
.58366 .80696 Mdot
.2391 .6778 Mdot
.25013 .35164 Mdot
.66539 .37503 Mdot
.48771 .59271 Mdot
.52957 .66134 Mdot
.40695 .8095 Mdot
.33924 .40792 Mdot
.63007 .80749 Mdot
.7877 .46096 Mdot
.72015 .30157 Mdot
.55537 .39647 Mdot
.44623 .69718 Mdot
.34198 .63131 Mdot
.30808 .43701 Mdot
.57309 .68594 Mdot
.73427 .38338 Mdot
.70128 .40018 Mdot
.42875 .45415 Mdot
.32226 .54312 Mdot
.22513 .38484 Mdot
.44746 .31299 Mdot
.77431 .4978 Mdot
.25254 .7015 Mdot
.63073 .44711 Mdot
.27001 .55727 Mdot
.28745 .42794 Mdot
.58304 .71316 Mdot
.43836 .75059 Mdot
.72051 .75743 Mdot
.54976 .82174 Mdot
.63619 .44107 Mdot
.67748 .25798 Mdot
.37113 .35015 Mdot
.38841 .80256 Mdot
.62124 .37059 Mdot
.25476 .68978 Mdot
.77118 .55725 Mdot
.44537 .82985 Mdot
.70152 .60874 Mdot
.539 .42544 Mdot
.23693 .65242 Mdot
.40563 .50688 Mdot
.22124 .63003 Mdot
.82627 .52099 Mdot
.48538 .68361 Mdot
.19175 .58404 Mdot
.49509 .38197 Mdot
.63798 .53601 Mdot
.63596 .67202 Mdot
.54701 .41001 Mdot
.27809 .71956 Mdot
.67337 .44218 Mdot
.31272 .48661 Mdot
.69786 .47938 Mdot
.41962 .3372 Mdot
.56368 .82373 Mdot
.64219 .24024 Mdot
.23642 .6665 Mdot
.5136 .7081 Mdot
.27107 .63987 Mdot
.78085 .45518 Mdot
.41606 .7354 Mdot
.46956 .50937 Mdot
.77553 .53693 Mdot
.40748 .52566 Mdot
.4008 .79117 Mdot
.62298 .71812 Mdot
.62147 .79471 Mdot
.44561 .81155 Mdot
.7005 .34033 Mdot
.44304 .54098 Mdot
.64811 .38049 Mdot
.63619 .79872 Mdot
.38076 .7681 Mdot
.56771 .23657 Mdot
.25403 .71391 Mdot
.23589 .55921 Mdot
.82688 .64722 Mdot
.63229 .31355 Mdot
.52543 .66866 Mdot
.30182 .76148 Mdot
.61236 .34881 Mdot
.21783 .54785 Mdot
.68104 .64056 Mdot
.65141 .46931 Mdot
.65878 .78198 Mdot
.56892 .53167 Mdot
.67958 .32325 Mdot
.67116 .71783 Mdot
.64648 .47895 Mdot
.38518 .76924 Mdot
.51254 .58679 Mdot
.29943 .3588 Mdot
.44286 .66219 Mdot
.16124 .52442 Mdot
.62491 .48424 Mdot
.25027 .68974 Mdot
.25851 .6922 Mdot
.25492 .58633 Mdot
.30494 .4419 Mdot
.82816 .64502 Mdot
.71727 .66609 Mdot
.51822 .58856 Mdot
.62858 .43203 Mdot
.35096 .51455 Mdot
.23477 .59229 Mdot
.59096 .6758 Mdot
.44147 .71266 Mdot
.77591 .5497 Mdot
.52031 .84991 Mdot
.46314 .39801 Mdot
.49967 .27137 Mdot
.67924 .37357 Mdot
.57107 .23945 Mdot
.7511 .37924 Mdot
.68528 .30345 Mdot
.27645 .71573 Mdot
.5405 .46331 Mdot
.53604 .43332 Mdot
.67151 .32888 Mdot
.26171 .67063 Mdot
.39563 .41813 Mdot
.46336 .28197 Mdot
.75449 .4872 Mdot
.72709 .72819 Mdot
.6434 .33825 Mdot
.50158 .44682 Mdot
.58309 .40883 Mdot
.47829 .66713 Mdot
.41733 .35252 Mdot
.65813 .30762 Mdot
.61939 .44694 Mdot
.61451 .77072 Mdot
.58398 .47058 Mdot
.27639 .55075 Mdot
.22263 .59348 Mdot
.57407 .41642 Mdot
.25965 .69953 Mdot
.58908 .70394 Mdot
.64221 .76888 Mdot
.32665 .68085 Mdot
.31857 .48259 Mdot
.53307 .64611 Mdot
.72221 .45234 Mdot
.47256 .84095 Mdot
.62123 .36528 Mdot
.55604 .48132 Mdot
.607 .42428 Mdot
.27871 .74667 Mdot
.30512 .55395 Mdot
.28457 .31169 Mdot
.38955 .54569 Mdot
.44292 .69386 Mdot
.44151 .63901 Mdot
.47989 .34551 Mdot
.59154 .69393 Mdot
.39144 .44262 Mdot
.48427 .66848 Mdot
.75752 .48756 Mdot
.33355 .76666 Mdot
.73498 .73947 Mdot
.71268 .45004 Mdot
.24882 .71477 Mdot
.69408 .47158 Mdot
.67724 .46543 Mdot
.20639 .54542 Mdot
.55711 .48617 Mdot
.57523 .70597 Mdot
.3131 .48415 Mdot
.69863 .4321 Mdot
.7329 .73662 Mdot
.56233 .47653 Mdot
.33071 .49053 Mdot
.40271 .36179 Mdot
.47477 .4472 Mdot
.42592 .19533 Mdot
.43993 .29609 Mdot
.28787 .7565 Mdot
.24886 .66773 Mdot
.45688 .27088 Mdot
.59794 .41792 Mdot
.56601 .48736 Mdot
.63889 .77465 Mdot
.41345 .52864 Mdot
.54238 .8285 Mdot
.52027 .36827 Mdot
.76865 .50563 Mdot
.44204 .80868 Mdot
.36082 .73997 Mdot
.41071 .73851 Mdot
.79287 .5225 Mdot
.57583 .78056 Mdot
.44406 .52627 Mdot
.23146 .37025 Mdot
.16443 .43549 Mdot
.7545 .72034 Mdot
.72442 .30387 Mdot
.53972 .56063 Mdot
.2985 .69117 Mdot
.58269 .46415 Mdot
.35685 .64056 Mdot
.42214 .37578 Mdot
.27201 .55307 Mdot
.53116 .36058 Mdot
.67017 .24368 Mdot
.53628 .84557 Mdot
.5514 .66521 Mdot
.42118 .55954 Mdot
.37081 .43625 Mdot
.30365 .40232 Mdot
.65222 .51572 Mdot
.71919 .75621 Mdot
.46057 .286 Mdot
.32034 .26725 Mdot
.463 .33401 Mdot
.37809 .79146 Mdot
.25953 .3118 Mdot
.52034 .34762 Mdot
.33974 .80232 Mdot
.73277 .33211 Mdot
.81688 .53401 Mdot
.64325 .22456 Mdot
.41136 .79848 Mdot
.77404 .5336 Mdot
.29647 .56389 Mdot
.58457 .82285 Mdot
.34018 .63476 Mdot
.27788 .50474 Mdot
.58968 .77675 Mdot
.23237 .64632 Mdot
.21913 .5836 Mdot
.52266 .26631 Mdot
.6588 .48759 Mdot
.21639 .33488 Mdot
.26204 .38544 Mdot
.82791 .37802 Mdot
.55029 .82008 Mdot
.74514 .67655 Mdot
.62317 .36602 Mdot
.44451 .37705 Mdot
.63351 .77832 Mdot
.26774 .70027 Mdot
.61276 .49318 Mdot
.23495 .3565 Mdot
.34715 .72572 Mdot
.29039 .67288 Mdot
.47933 .37516 Mdot
.47395 .83496 Mdot
.29818 .43029 Mdot
.58373 .55094 Mdot
.24057 .66431 Mdot
.71452 .46071 Mdot
.42352 .72812 Mdot
.72181 .73073 Mdot
.42959 .75515 Mdot
.21371 .59783 Mdot
.5253 .36704 Mdot
.31459 .3278 Mdot
.73277 .73007 Mdot
.74666 .38631 Mdot
.77457 .56672 Mdot
.8611 .60642 Mdot
.60941 .81615 Mdot
.56879 .49062 Mdot
.60859 .62037 Mdot
.3231 .78577 Mdot
.34655 .35899 Mdot
.35312 .77305 Mdot
.81452 .40939 Mdot
.21152 .571 Mdot
.61676 .72153 Mdot
.61545 .65589 Mdot
.30491 .61327 Mdot
.68857 .3421 Mdot
.64589 .48908 Mdot
.29107 .40862 Mdot
.22209 .61087 Mdot
.77603 .49415 Mdot
.81955 .38551 Mdot
.82542 .51319 Mdot
.63466 .4098 Mdot
.56718 .83085 Mdot
.59211 .54036 Mdot
.77727 .46581 Mdot
.63339 .77173 Mdot
.43832 .57416 Mdot
.39252 .43488 Mdot
.77868 .4541 Mdot
.33463 .66796 Mdot
.15939 .51815 Mdot
.8131 .66486 Mdot
.74991 .50518 Mdot
.63692 .80381 Mdot
.42596 .83344 Mdot
.63729 .3966 Mdot
.63993 .50182 Mdot
.33531 .62579 Mdot
.57033 .47091 Mdot
.55046 .34012 Mdot
.27521 .3981 Mdot
.23155 .55295 Mdot
.22726 .40286 Mdot
.59722 .6212 Mdot
.50317 .37627 Mdot
.51089 .84364 Mdot
.27342 .58099 Mdot
.52401 .84132 Mdot
.78331 .51174 Mdot
.52337 .61594 Mdot
.88595 .57352 Mdot
.58904 .25033 Mdot
.55572 .71792 Mdot
.51963 .54787 Mdot
.53086 .56105 Mdot
.59988 .61582 Mdot
.54618 .31671 Mdot
.30371 .63683 Mdot
.19844 .56426 Mdot
.58596 .8195 Mdot
.67801 .3772 Mdot
.33896 .63176 Mdot
.47583 .27285 Mdot
.41404 .68845 Mdot
.63652 .71987 Mdot
.45474 .29177 Mdot
.18499 .54747 Mdot
.42292 .19731 Mdot
.40621 .39501 Mdot
.44034 .44711 Mdot
.39668 .66657 Mdot
.46239 .54538 Mdot
.19742 .54679 Mdot
.49085 .35026 Mdot
.38121 .43466 Mdot
.23452 .66208 Mdot
.79521 .53299 Mdot
.47315 .37312 Mdot
.1999 .36865 Mdot
.33693 .64683 Mdot
.50458 .37731 Mdot
.58627 .50319 Mdot
.82257 .48308 Mdot
.60492 .78361 Mdot
.39046 .39627 Mdot
.44345 .5282 Mdot
.79483 .58928 Mdot
.61733 .79242 Mdot
.50851 .33295 Mdot
.35588 .8121 Mdot
.5738 .5014 Mdot
.65768 .51434 Mdot
.7205 .69807 Mdot
.49942 .60356 Mdot
.68006 .6297 Mdot
.52643 .5704 Mdot
.42981 .63177 Mdot
.3998 .19673 Mdot
.50574 .60935 Mdot
.46271 .44867 Mdot
.53879 .45696 Mdot
.27156 .59011 Mdot
.65921 .67232 Mdot
.55138 .62661 Mdot
.33172 .55896 Mdot
.34143 .68832 Mdot
.2771 .57238 Mdot
.26169 .56191 Mdot
.48273 .37273 Mdot
.19691 .54827 Mdot
.2183 .57931 Mdot
.67739 .69806 Mdot
.64344 .77989 Mdot
.63577 .67632 Mdot
.54341 .82244 Mdot
.4294 .40156 Mdot
.58771 .34401 Mdot
.43453 .75118 Mdot
.80865 .66914 Mdot
.72401 .37703 Mdot
.62634 .59053 Mdot
.40903 .82313 Mdot
.49947 .83989 Mdot
.42712 .33777 Mdot
.59026 .22958 Mdot
.15595 .46056 Mdot
.32469 .63034 Mdot
.6776 .24777 Mdot
.25681 .34611 Mdot
.40316 .81388 Mdot
.49298 .67419 Mdot
.56532 .49185 Mdot
.79799 .48484 Mdot
.5734 .71194 Mdot
.3419 .39792 Mdot
.82983 .48651 Mdot
.79434 .52237 Mdot
.57252 .78131 Mdot
.5256 .58331 Mdot
.51517 .40761 Mdot
.69955 .44339 Mdot
.75915 .7142 Mdot
.2697 .34633 Mdot
.44097 .61294 Mdot
.82447 .39952 Mdot
.40795 .19528 Mdot
.21902 .54563 Mdot
.69743 .74086 Mdot
.43683 .3044 Mdot
.48232 .66215 Mdot
.50174 .19318 Mdot
.72118 .41553 Mdot
.62561 .42786 Mdot
.44857 .31343 Mdot
.27654 .64353 Mdot
.65168 .31527 Mdot
.84266 .63236 Mdot
.44044 .82899 Mdot
.58763 .70787 Mdot
.81701 .34366 Mdot
.2429 .66896 Mdot
.43173 .59029 Mdot
.64402 .30669 Mdot
.55158 .83447 Mdot
.53614 .35436 Mdot
.30689 .76868 Mdot
.57352 .43118 Mdot
.62427 .48149 Mdot
.28767 .65905 Mdot
.64042 .22834 Mdot
.49123 .59694 Mdot
.8206 .37137 Mdot
.61088 .23606 Mdot
.30046 .68017 Mdot
.60658 .37861 Mdot
.71525 .4393 Mdot
.73783 .39511 Mdot
.56404 .39726 Mdot
.53474 .47257 Mdot
.50445 .44697 Mdot
.54348 .43374 Mdot
.39765 .4156 Mdot
.54479 .39709 Mdot
.582 .25022 Mdot
.46403 .3493 Mdot
.80798 .50789 Mdot
.15274 .48589 Mdot
.26037 .55563 Mdot
.33074 .41282 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0U_ooool2o`00
0;7ooooo000Looooo`03o`000?oooooooooo09Kooooo0ol0002`ooooo`007?ooool00ol0003ooooo
ooooo`2Fooooo`Go0000[_ooool001cooooo00?o0000ooooooooool0VOooool4o`000:cooooo000L
ooooo`03o`000?oooooooooo09[ooooo0ol0002/ooooo`007?ooool00ol0003oooooooooo`2Koooo
o`Co0000Z_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006
ooooo`03o`000?oooooooooo09gooooo1?l0002Xooooo`0000KoooooogMgMonHV9SooooooiRHV?mg
MgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0
O_ooool2o`000003ooooool0003o000000Cooooo0_l00004ooooo`;o00003oooool5o`000:Kooooo
00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00ol0003oooooooooo`1nooooo`;o000000?oooooo`000?l000000oooool3o`0000Cooooo0_l0
000Booooo`;o0000Y_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool0
0onHV9So8B4Qonk^kP06ooooo`?o0000Q_ooool2o`000003ooooool0003o000000[ooooo0_l0000;
ooooo`?o0000Y?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00omg
MgOoIVIVooooo`05ooooo`03o`000?oooooooooo07Wooooo1?l0000<ooooo`;o00002_ooool4o`00
00Wooooo0ol0002Tooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0=ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0NOooool4o`0001[ooooo0_l00002ooooo`;o
00001oooool2o`000003ooooool0003o000000;o0000W_ooool00006oooooomgMgOoV9RHoooooonH
V9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0V_ooool5
o`0000Gooooo0_l000000ooooooo0000o`000002o`000004ooooool0003o0000ooooo`;o0000V?oo
ool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Ko
oooo00?o0000ooooooooool0Loooool2o`0002Gooooo0_l000000ooooooo0000o`00000;ooooo`Co
000000?oooooo`000?l000004_ooool2o`0008Cooooo000Looooo`03o`000?oooooooooo07?ooooo
0_l0000cooooo`[o00004?ooool3o`0008Cooooo000Looooo`03o`000?oooooooooo0:;ooooo0_l0
0004ooooo`[o00000oooool2o`0000Oooooo0_l00002ooooo`;o0000QOooool001cooooo00?o0000
ooooooooool0Woooool2o`000003ooooool0003o000000Gooooo0_l00004ooooo`So000000?ooooo
o`000?l000000_l000000ooooooo0000o`000002o`0000cooooo0_l0000Looooo`;o0000G?ooool0
01cooooo00?o0000ooooooooool0Woooool4o`0000kooooo2ol000000ooooooo0000o`000002o`00
00[ooooo1_l0000Jooooo`;o0000G?ooool001cooooo00?o0000ooooooooool0K_ooool2o`00037o
oooo0_l0000Cooooo`Go000000?oooooo`000?l000002oooool8o`0001[ooooo0_l0001Looooo`00
7?ooool00ol0003oooooooooo`1^ooooo`;o0000A_ooool2o`0000Cooooo0_l00008ooooo`;o0000
00Coooooo`000?l0003ooooo0_l0001kooooo`007?ooool00ol0003oooooooooo`2eooooo`;o0000
1Oooool2o`0000Gooooo0_l000000ooooooo0000o`000005ooooo`;o0000N_ooool001cooooo00?o
0000ooooooooool0]Oooool3o`0000Cooooo0_l00004ooooo`?o00002?ooool2o`0007[ooooo000L
ooooo`03o`000?oooooooooo09Cooooo0ol000001?oooooo0000o`000?l0000Kooooo`?o00002?oo
ool3o`0000Wooooo0_l0001jooooo`007?ooool00ol0003oooooooooo`2@ooooo`go00005_ooool2
o`000004ooooool0003o0000o`0000Sooooo0_l00005ooooo`;o00000oooool2o`0000Oooooo0_l0
001aooooo`007?ooool00ol0003oooooooooo`2@ooooo`Go000000?oooooo`000?l000001ol0000D
ooooo`;o00001oooool2o`0000[ooooo0_l00007ooooo`;o00000oooool5o`0006kooooo000Loooo
o`;o0000Soooool2o`000003ooooool0003o000000?o00001?ooool8o`00017ooooo0_l00004oooo
o`;o000000?oooooo`000?l000000oooool2o`000003ooooool0003o000000_ooooo0_l000000ooo
oooo0000o`000002ooooo`Go0000K?ooool001cooooo00?o0000ooooooooool0S_ooool2o`000003
ooooool0003o000000?o00001oooool5o`0001Cooooo0_l000001?oooooo0000o`000?ooool2o`00
00?ooooo0_l000000ooooooo0000o`00000>ooooo`;o00001Oooool2o`0001Oooooo0_l0001Coooo
o`007?ooool00ol0003oooooooooo`1Uooooo`;o0000:_ooool2o`0000kooooo0_l0000Cooooo`?o
00007_ooool7o`0001Kooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o0000
9_ooool4o`000003ooooool0003o000000gooooo0_l0000;ooooo`;o00001oooool2o`0000;ooooo
1?l0000Hooooo`Oo0000Joooool001cooooo00?o0000ooooooooool0S?ooool9o`0000oooooo0_l0
0008ooooo`;o00002oooool4o`0003Oooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`1T
ooooo`;o00009_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000?ooooo`Co0000=_ooool2
o`0001Kooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`1Tooooo`;o0000:_ooool3o`00
01?ooooo0_l0000fooooo`;o00000_ooool2o`0001?ooooo0_l0001@ooooo`007?ooool00ol0003o
ooooooooo`2=ooooo`;o00000_ooool3o`0000?ooooo0_l00006ooooo`;o0000@Oooool2o`0001?o
oooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`1Rooooo`;o0000:Oooool4o`000003oooo
ool0003o000000Go00000oooool5o`0005Kooooo0ol0001?ooooo`007?ooool00ol0003ooooooooo
o`1Rooooo`;o00009oooool2o`000003ooooool0003o000000Wo00000_ooool5o`000003ooooool0
003o000005Gooooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`1Oooooo`;o0000:_ooool2
o`0000Cooooo4_l0001Eooooo`;o0000Coooool001cooooo00?o0000ooooooooool0Goooool2o`00
02oooooo5Ol00006ooooo`;o0000Boooool3o`0004kooooo000Looooo`03o`000?oooooooooo08Oo
oooo0_l00004ooooo`;o000000?oooooo`000?l000004ol00006ooooo`?o0000>?ooool2o`00017o
oooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`1Looooo`?o0000:?ooool2o`0000Cooooo
0_l000000ooooooo0000o`000003o`000003ooooool0003o000000ko00001_ooool2o`0003Sooooo
0ol0000@ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0F?ooool2o`0000;ooooo0ol0
000Xooooo`;o00001ooooolFo`0000Kooooo0_l0000iooooo`;o0000H?ooool001cooooo00?o0000
ooooooooool0F?ooool2o`00037ooooo0_l00004oooooaKo0000<?ooool3o`00023ooooo0ol0001<
ooooo`007?ooool2o`0005Gooooo0_l0000aooooo`;o00000_ooool3o`0000;ooooo5ol00006oooo
o`;o00008Oooool2o`0000Gooooo0ol00002ooooo`;o00002?ooool2o`0001;ooooo0ol0001<oooo
o`007?ooool00ol0003oooooooooo`1Dooooo`?o0000<?ooool2o`000003ooooool0003o000000;o
00000_oooolFo`000003ooooool0003o000000Cooooo0ol0000Oooooo`?o00002Oooool4o`0000Oo
oooo1?l0001Oooooo`007?ooool00ol0003oooooooooo`1Eooooo`;o0000;_ooool4o`000003oooo
ool0003o000000Cooooo6Ol00005ooooo`;o00006_ooool2o`000003ooooool0003o000000Ko0000
0_ooool2o`0000;ooooo1Ol00008ooooo`;o0000Goooool001cooooo00?o0000ooooooooool0DOoo
ool2o`0000Kooooo0_l0000Zooooo`Go000000?oooooo`000?l000001?oooolFo`0000Sooooo1?l0
000Gooooo`;o000000?oooooo`000?l000000_ooool5o`000003ooooool0003o000000?o00000_oo
ool4o`0001_ooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o000000?ooooo
o`000?l000001?ooool4o`0002gooooo1Ol000001?oooooo0000o`000?oooolFo`000003ooooool0
003o000000Cooooo1Ol0000Gooooo`Go00000oooool:o`0000?ooooo0ol0000Kooooo`;o0000B_oo
ool001cooooo00?o0000ooooooooool0BOooool2o`0000?ooooo0_l000000ooooooo0000o`000004
ooooo`Co0000;oooool2o`0000;ooooo0_l00002oooooaSo00001?ooool2o`0001Kooooo0_l00002
ooooo`Go000000?oooooo`000?l000000oooool4o`0000?ooooo0_l000001?oooooo0000o`000?l0
000Kooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0BOooool2o`0000Kooooo0_l00004
ooooo`;o0000:oooool2o`0000gooooo5_l00005ooooo`;o00000_ooool2o`0001;ooooo0_l00008
ooooo`;o00001?ooool3o`000003ooooool0003o000000;o00001?ooool2o`0006Gooooo000Loooo
o`03o`000?oooooooooo04gooooo0_l00002ooooo`;o0000<Oooool2o`000003ooooool0003o0000
00[ooooo5Ol00006ooooo`;o00000_ooool2o`0001?ooooo0_l0000@ooooo`Go00001?ooool3o`00
00Gooooo0_l000000ooooooo0000o`00001Jooooo`007?ooool00ol0003oooooooooo`17ooooo`;o
00001?ooool2o`0000Kooooo0_l0000`ooooo`?o00002_oooolEo`0000Cooooo0ol00002ooooo`;o
00004oooool2o`00013ooooo1_l00004ooooo`?o00001?ooool2o`000003ooooool0003o0000017o
oooo0_l00017ooooo`007?ooool00ol0003oooooooooo`17ooooo`;o00003?ooool2o`0000_ooooo
0_l0000Tooooo`;o00002_oooolEo`0000Cooooo0_l000000ooooooo0000o`000002o`0002;ooooo
0_l00005ooooo`;o00001?ooool3o`0001[ooooo0_l00017ooooo`007?ooool00ol0003ooooooooo
o`17ooooo`;o00000oooool2o`0001Cooooo0_l00002ooooo`;o0000;OoooolAo`000003ooooool0
003o000000Gooooo1Ol0000Nooooo`?o00000_ooool2o`0000kooooo0_l00002ooooo`;o0000GOoo
ool001cooooo00?o0000ooooooooool0@oooool2o`0000Oooooo0_l00009ooooo`Co000000?ooooo
o`000?l000002?ooool4o`0001Cooooo0_l0000CoooooaGo00001_ooool4o`00013ooooo0_l0000=
ooooo`Wo00003?ooool2o`0000;ooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`13oooo
o`;o00003oooool7o`000003ooooool0003o000000[ooooo0_l0000Dooooo`Co00000oooool4o`00
0003ooooool0003o000000Kooooo0ol00002oooooa7o00001_ooool2o`0000oooooo0_l000000ooo
oooo0000o`000009ooooo`;o00000_ooool9o`0000Wooooo0_l000000ooooooo0000o`000006oooo
o`;o00004Oooool2o`000003ooooool0003o000004?ooooo000Looooo`03o`000?oooooooooo04oo
oooo0_l00003ooooo`?o000000Coooooo`000?l0003o00001?ooool2o`0000gooooo0_l0000@oooo
o`;o00000oooool4o`000003ooooool0003o000000Kooooo0ol00002ooooo`Go000000Coooooo`00
0?l0003ooooo1ol00003ooooo`Oo00003_ooool2o`0000cooooo0_l00002ooooo`;o000000?ooooo
o`000?l000001Oooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool3o`0000Gooooo0_l0
000Aooooo`;o000000?oooooo`000?l00000@oooool001cooooo00?o0000ooooooooool0Coooool3
o`0000?ooooo1Ol000000ooooooo0000o`000006o`0000;ooooo0_l00007ooooo`;o00004?ooool2
o`000003ooooool0003o000000?o00001Oooool2o`0000Cooooo0_l00002ooooo`;o000000Cooooo
o`000?l0003ooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l000000ooooooo0000o`00
0002o`000003ooooool0003o000000[ooooo0_l00006ooooo`;o00002?ooool2o`0000;ooooo0_l0
00000ooooooo0000o`000005ooooo`?o00000_ooool3o`0000Cooooo0_l00005ooooo`?o00005Ooo
ool2o`00047ooooo000Looooo`03o`000?oooooooooo03gooooo0_l0000?ooooo`Co000000?ooooo
o`000?l000003_l000001?oooooo0000o`000?l0000:ooooo`;o00001?ooool2o`0000Oooooo2?l0
0005ooooo`;o00002Oooool3o`0000Cooooo0ol00003ooooo`Co00000oooool3o`0000[ooooo1?l0
0006ooooo`;o00002?ooool2o`0000;ooooo0_l000000ooooooo0000o`000006ooooo`?o00000_oo
ool2o`0000Cooooo0_l00003ooooo`;o000000?oooooo`000?l000005Oooool2o`00047ooooo000L
ooooo`;o0000?_ooool2o`0000oooooo6_l00009ooooo`;o00000_ooool4o`0000Sooooo0_l0000<
ooooo`;o00000_ooool2o`0000?ooooo0ol000001?oooooo0000o`000?ooool2o`0000Cooooo0ol0
0004ooooo`?o00002_ooool3o`0000Oooooo0_l00006ooooo`Co000000?oooooo`000?l000002ooo
ool5o`0000[ooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00001ooooolJ
o`0000gooooo0_l0000:ooooo`;o000000?oooooo`000?l000002Oooool2o`0000;ooooo0_l00007
ooooo`;o00001oooool6o`0001Sooooo0_l00006ooooo`?o00000_ooool2o`0000gooooo1?l00000
0ooooooo0000o`00001Sooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00000_ooool2o`00
00?ooooo1?l000000ooooooo0000o`00000Co`0001Sooooo1_l00003ooooo`?o00006Oooool2o`00
0003ooooool0003o000000;o00001Oooool2o`0000oooooo0_l00008ooooo`;o00004Oooool4o`00
0003ooooool0003o000006?ooooo000Looooo`03o`000?oooooooooo04Wooooo0_l00006oooooa[o
000000Coooooo`000?l0003o00003_ooool2o`000003ooooool0003o000000;o00001Oooool3o`00
0003ooooool0003o0000017ooooo0_l00003ooooo`?o00000_ooool3o`0000?ooooo0ol0000?oooo
o`;o00002Oooool2o`0001?ooooo0_l00004ooooo`;o00001Oooool2o`0001Kooooo0_l00010oooo
o`007?ooool00ol0003oooooooooo`17ooooo`;o00002?ooool7o`000003ooooool0003o000000_o
000000?oooooo`000?l000000_l000001?oooooo0000o`000?l0000>ooooo`Ko00001Oooool2o`00
00?ooooo0_l0000Aooooo`;o00000oooool8o`0000?ooooo0_l0000Kooooo`;o00004oooool3o`00
00?ooooo0_l00005ooooo`;o00005_ooool3o`0003oooooo000Looooo`03o`000?oooooooooo04Ko
oooo0ol00008oooooako00003_ooool4o`0000Oooooo0_l000000ooooooo0000o`000009ooooo`;o
00000oooool2o`0000Wooooo2Ol0000Gooooo`?o00003oooool2o`0000;ooooo0_l00005ooooo`;o
00001_ooool2o`0001_ooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0mooooo`;o0000
1oooool2o`0000Sooooo0ol000000ooooooo0000o`00000Io`00017ooooo0_l00009ooooo`Co0000
1oooool2o`0000?ooooo1?l00006ooooo`Co00001?ooool3o`0001Kooooo0ol0000:ooooo`?o0000
0_ooool2o`0000;ooooo0ol00004ooooo`;o00001_ooool2o`0000?ooooo0_l0000Fooooo`;o0000
?oooool001cooooo00?o0000ooooooooool0?Oooool3o`0000Kooooo0ol00007ooooo`;o00000_oo
oolKo`00017ooooo0_l0000:ooooo`?o00003_ooool2o`0000Kooooo1_l00003ooooo`;o00005_oo
ool4o`0000Cooooo0_l00003ooooo`?o00001Oooool4o`0000Cooooo0_l0000;ooooo`;o00005Ooo
ool2o`00043ooooo000Looooo`03o`000?oooooooooo03kooooo0_l00005ooooo`Co00002ooooolN
o`0000_ooooo1ol00005ooooo`;o00002oooool7o`0000_ooooo0ol0000Kooooo`Co00001?ooool2
o`0000Cooooo0_l00003ooooo`Ko00001Oooool3o`00023ooooo0_l00010ooooo`007?ooool00ol0
003oooooooooo`15ooooo`?o00001Oooool2o`0000Cooooo7ol0000:ooooo`So000000?oooooo`00
0?l000000_ooool2o`0000;ooooo0_l00007ooooo`Oo00000oooool2o`0001oooooo0_l00008oooo
o`;o00001_ooool3o`0000;ooooo0ol00009ooooo`Go00008?ooool2o`0003kooooo000Looooo`03
o`000?oooooooooo03[ooooo0_l0000Aooooo`;o00001?oooolOo`0000[ooooo0_l00002ooooo`Co
000000?oooooo`000?l000001_ooool2o`0000Kooooo0_l00009ooooo`;o00006Oooool2o`0000Co
oooo0_l00008ooooo`;o00000_ooool;o`0000Cooooo2ol00007ooooo`;o00005oooool2o`0003ko
oooo000Looooo`03o`000?oooooooooo03[ooooo0_l00009ooooo`;o00003Oooool4o`0000?ooooo
6?l00009ooooo`;o00000_ooool4o`00017ooooo0_l00006ooooo`;o00007?ooool2o`0000Gooooo
0_l00009ooooo`go000000Coooooo`000?l0003ooooo1_l000000ooooooo0000o`000004ooooo`;o
00000oooool2o`0005Oooooo000Looooo`03o`000?oooooooooo04Gooooo0ol00006ooooo`;o0000
00?oooooo`000?l000000_oooolNo`0000Wooooo0_l000000ooooooo0000o`00000@ooooo`;o0000
1oooool2o`000003ooooool0003o000002?ooooo0_l00008oooooa7o000000?oooooo`000?l00000
0ol00002ooooo`;o00001?ooool2o`0000;ooooo0_l0000Eooooo`;o0000@Oooool001cooooo00?o
0000ooooooooool0A_ooool2o`0000Kooooo0_l000000ooooooo0000o`000003ooooo`Wo000000?o
ooooo`000?l000004?l0000;ooooo`Co00004?ooool2o`0000Oooooo0_l0000^oooooa?o000000?o
ooooo`000?l000001ol00006ooooo`Co00005Oooool4o`0003oooooo00001_ooooook^k^oc8b<_l0
003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003ooooo
ooooo`1Fooooo`Co000000?oooooo`000?l000005Ol00009ooooo`Co0000BooooolMo`0000Kooooo
0_l0000Hooooo`?o0000?oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0jooooo`;o00002Oooool2o`00017o
oooo6_l00008ooooo`So0000:oooool2o`0000;ooooo0_l0000Foooooako00001Oooool2o`0001Wo
oooo0_l00010ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`Go0000
1_ooool00ol0003oooooooooo`0jooooo`;o00002Oooool2o`0000oooooo0_l000000ooooooo0000
o`000005o`000005ooooool0003o0000o`000?ooool03Ol00008ooooo`So00004Oooool2o`0001So
oooo0_l00002ooooo`Co00005?oooolKo`000003ooooool0003o000000Gooooo0ol0000Hooooo`?o
0000?oooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?m4A4CogMgM
ooooool00007ooooo`?o0000A_ooool2o`0000kooooo7?l00007ooooo`?o00001?ooool2o`000003
ooooool0003o000000?ooooo0_l00009ooooo`;o000000?oooooo`000?l000006oooool2o`0001;o
oooo7?l00002ooooo`;o00001?ooool4o`0001Sooooo0ol0000oooooo`0000?oooooo`000?ooool0
0_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000oooooooo
ool0A_ooool2o`0000oooooo0_l00002oooooaWo00001Oooool2o`000003ooooool0003o000000Go
oooo0_l00003ooooo`;o00000oooool2o`0000Oooooo0_l0000Fooooo`;o00004?ooool2o`0000Co
oooo1Ol000000ooooooo0000o`00000Fo`000003ooooool0003o000000Cooooo0ol0000Gooooo`Co
0000@?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00omgMgOoc<c<
o`000007ooooo`03o`000?oooooooooo04Sooooo0_l0000Aooooo`;o00000_oooolEo`0000Cooooo
0_l000001?oooooo0000o`000?l00004ooooo`;o00002Oooool2o`0001Gooooo0_l00008ooooo`;o
00002_ooool2o`0000Cooooo0_l00003ooooo`Co000000?oooooo`000?l000006?l00008ooooo`;o
00005_ooool5o`00043ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4
A?l000001oooool00ol0003oooooooooo`18ooooo`;o00003Oooool6o`0000;ooooo3ol000001?oo
oooo0000o`000?l00006ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`00023ooooo0_l0
0008ooooo`;o00002_ooool2o`0000;ooooo1?l00002ooooo`Go000000?oooooo`000?l000006_l0
000Nooooo`Go0000@?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000
ooooo`06ooooo`03o`000?oooooooooo03Cooooo0_l0000Gooooo`;o00002?ooool4o`0000Cooooo
3?l00004ooooo`Co000000?oooooo`000?l000001_ooool3o`0002oooooo0_l0000>ooooo`;o0000
1?ooool2o`000003ooooool0003o000001[o000000?oooooo`000?l000000_l0000Kooooo`Go0000
@Oooool001cooooo00?o0000ooooooooool0=?ooool2o`0001Oooooo0_l00002ooooo`?o00002ooo
ool2o`000004ooooool0003o0000oooooaKo00000_ooool2o`0003Sooooo0_l00005ooooo`Co0000
00?oooooo`000?l000006ol000001?oooooo0000o`000?ooool4o`0000?ooooo0_l0000Fooooo`Go
0000@Oooool001cooooo00?o0000ooooooooool0DOooool3o`0001?ooooo5?l00002ooooo`;o0000
>?ooool2o`0000Gooooo1?l000000ooooooo0000o`000004o`000003ooooool0003o000000Oo0000
00?oooooo`000?l000003Ol000001?oooooo0000o`000?ooool2o`0000;ooooo0_l0000Eooooo`Co
0000@oooool001cooooo00?o0000ooooooooool0GOooool2o`0000oooooo1_l00004ooooo`Co0000
@_ooool2o`000003ooooool0003o000000?o00001?oooolHo`0000;ooooo0_l000000ooooooo0000
o`00000Hooooo`Go0000@oooool001cooooo00?o0000ooooooooool0F_ooool6o`0001[ooooo0_l0
000_ooooo`;o00001_ooool2o`0000cooooo1?l00002ooooo`;o000000?oooooo`000?l000005Ol0
0005ooooo`;o00006Oooool5o`0004?ooooo000Looooo`03o`000?oooooooooo05[ooooo2Ol00005
ooooo`Co000000?oooooo`000?l000000_l000000ooooooo0000o`000003o`0003Cooooo0_l00006
ooooo`;o00002Oooool2o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000004_l00000
0ooooooo0000o`000002o`0000?ooooo0_l00005ooooo`;o00004?ooool7o`0004?ooooo000Loooo
o`03o`000?oooooooooo05gooooo1_l00003ooooo`Ko000000?oooooo`000?l000000_l000000ooo
oooo0000o`000004o`0000_ooooo0_l0000=ooooo`;o00005_ooool2o`000004ooooool0003o0000
o`0000Cooooo0_l000000ooooooo0000o`000005ooooo`;o00000oooool3o`0000;ooooo5Ol00002
ooooo`Co00000oooool2o`0000Cooooo0ol0000?ooooo`Ko0000AOooool001cooooo00?o0000oooo
ooooool0<_ooool2o`0002cooooo0_l00004ooooo`Go00001?ooool;o`0000;ooooo0_l00005oooo
o`;o00003Oooool2o`0000Cooooo0_l0000@ooooo`;o000000Coooooo`000?l0003o00001?ooool2
o`000003ooooool0003o000000Wooooo1?l00002oooooaGo000000?oooooo`000?l000001?l00008
ooooo`;o00004?ooool2o`0000;ooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`0boooo
o`;o0000;?ooool2o`0000Gooooo1?l00005ooooo`[o00000_ooool2o`0001[ooooo0_l0000@oooo
o`Co00002_ooool2o`000003ooooool0003o000000Gooooo0ol000000ooooooo0000o`000002o`00
0003ooooool0003o000000ko000000?oooooo`000?l000002_l00004ooooo`;o00003_ooool5o`00
04Sooooo000Looooo`03o`000?oooooooooo037ooooo0_l0000/ooooo`;o00004oooool2o`0000;o
oooo0_l000000ooooooo0000o`00000Fooooo`;o00005oooool2o`0000[ooooo1Ol00005ooooo`?o
000000?oooooo`000?l000000_l000000ooooooo0000o`00000Fo`000003ooooool0003o000000?o
00004oooool5o`0004Sooooo000Looooo`03o`000?oooooooooo037ooooo0_l0000/ooooo`;o0000
4oooool2o`0000Gooooo0_l0000Fooooo`;o00000oooool4o`0001Sooooo0_l00003ooooo`;o0000
1oooool2o`0000;ooooo0ol000000ooooooo0000o`00000Eo`0000Kooooo0_l0000Cooooo`Co0000
BOooool001cooooo00?o0000ooooooooool0JOooool2o`0001;ooooo0_l00003ooooo`;o00000ooo
ool2o`000004ooooool0003o0000o`0000Kooooo0_l000000ooooooo0000o`000004o`0000?ooooo
0ol0000Booooo`Co00002ooooolKo`0000Wooooo0_l0000Cooooo`Co0000BOooool001cooooo0_l0
000aooooo`;o0000=Oooool4o`0001;ooooo0_l00003ooooo`;o00000oooool2o`000004ooooool0
003o0000o`0000Kooooo0_l000000ooooooo0000o`000005ooooo`Go00005?ooool2o`0000Wooooo
1_l00002oooooaGo00001_ooool2o`000003ooooool0003o0000017ooooo1Ol0001:ooooo`007?oo
ool00ol0003oooooooooo`0_ooooo`?o0000=Oooool2o`0000?ooooo0_l0000Iooooo`?o00004ooo
ool2o`00013ooooo0_l0000@ooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo1ol0
00000ooooooo0000o`000005o`0000Gooooo1?l000000ooooooo0000o`00000@ooooo`Go0000Booo
ool001cooooo00?o0000ooooooooool0;oooool2o`0003_ooooo0_l000001?oooooo0000o`000?oo
ool2o`0001?ooooo1?l0000>ooooo`;o00004?ooool2o`0000;ooooo0_l0000Booooo`?o00000ooo
ool3o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`Co00000_ooool2o`0000Gooooo0ol0
000Booooo`Ko0000C?ooool001cooooo00?o0000ooooooooool0;oooool2o`0003gooooo0ol00000
0ooooooo0000o`00000<ooooo`;o00001?ooool2o`000003ooooool0003o000000?ooooo0_l00009
ooooo`;o00004?ooool2o`0001Kooooo0_l00004ooooo`?o00002Oooool2o`0000;ooooo1?l00007
ooooo`;o00004Oooool2o`000003ooooool0003o000000?o0000B_ooool001cooooo00?o0000oooo
ooooool0;oooool2o`0003gooooo1Ol0000=ooooo`;o00000_ooool4o`0000Kooooo0_l0000Koooo
o`?o00002oooool2o`0000kooooo0_l0000>ooooo`;o00002Oooool2o`00013ooooo0_l00002oooo
o`Go0000B_ooool001cooooo00?o0000ooooooooool0LOooool2o`0000;ooooo0_l0000=ooooo`;o
00002oooool2o`0001Cooooo1ol0000;ooooo`;o00001oooool2o`0000_ooooo2?l000000ooooooo
0000o`00000Looooo`;o000000?oooooo`000?l00000C_ooool001cooooo00?o0000ooooooooool0
MOooool2o`0001[ooooo0_l0000Dooooo`Ko00001_ooool4o`0000?ooooo0_l00006ooooo`;o0000
2Oooool:o`000003ooooool0003o000001gooooo1?l00002ooooo`;o0000B_ooool001cooooo00?o
0000ooooooooool0X_ooool2o`0000Cooooo1_l00005ooooo`Co00000oooool2o`00017ooooo0_l0
00000ooooooo0000o`00000;ooooo`?o00005oooool2o`0000Cooooo1?l00002ooooo`;o0000A?oo
ool001cooooo00?o0000ooooooooool0;Oooool2o`0007?ooooo0_l00004ooooo`Ko00001Oooool2
o`0000_ooooo0_l00007ooooo`;o00000_ooool5o`0000[ooooo1?l0000Cooooo`?o00002Oooool2
o`0000;ooooo0_l00006ooooo`;o0000??ooool001cooooo00?o0000ooooooooool0;Oooool2o`00
07Wooooo1?l00007ooooo`?o00000_ooool2o`0000Kooooo0_l00007ooooo`;o00000_ooool3o`00
00cooooo0_l000001?oooooo0000o`000?l0000Aooooo`?o00004?ooool2o`0000?ooooo0_l0000l
ooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o0000=Oooool2o`0004?ooooo0ol00005oooo
o`;o000000?oooooo`000?l000000_ooool2o`0000Wooooo0_l00002ooooo`?o00000oooool3o`00
00[ooooo0_l00003ooooo`?o00004?ooool3o`0000gooooo0_l00002ooooo`?o0000@?ooool001co
oooo00?o0000ooooooooool0;Oooool3o`0003;ooooo1?l00016ooooo`;o00000oooool2o`00013o
oooo0_l00002ooooo`?o00000_ooool2o`0000cooooo0_l0000Fooooo`;o00002oooool2o`000003
ooooool0003o000000?ooooo0_l000000ooooooo0000o`00000mooooo`007?ooool00ol0003ooooo
ooooo`0]ooooo`?o0000<_ooool2o`0004Sooooo0_l00003ooooo`;o000000?oooooo`000?l00000
3Oooool2o`0000;ooooo2Ol00002ooooo`;o00007Oooool3o`0000_ooooo0_l00009ooooo`;o0000
?Oooool001cooooo00?o0000ooooooooool0F_ooool4o`0000Cooooo0_l00004ooooo`;o0000B_oo
ool3o`0000cooooo0_l00004ooooo`Co000000?oooooo`000?l000000_ooool3o`0000Gooooo0_l0
000Dooooo`Co00005_ooool2o`0003gooooo000Looooo`03o`000?oooooooooo05[ooooo1?l00000
0ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000_l0001:ooooo`?o00003?ooool2
o`0000Gooooo0ol00002ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000C
ooooo`?o00001_ooool2o`0001?ooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`1Noooo
o`oo0000COooool3o`0000Kooooo0_l00003ooooo`;o000000Goooooo`000?l0003o0000ooooo`03
o`0000?ooooo1?l0000Eooooo`?o00001oooool2o`0000Wooooo0_l00008ooooo`;o0000>_ooool0
01cooooo0_l0001Moooooa7o00008oooool2o`0002Gooooo0_l000001?oooooo0000o`000?l0000;
ooooo`?o000000?oooooo`000?l000001?l00003ooooo`;o00005oooool2o`0000Sooooo0_l00000
0ooooooo0000o`000006ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0Eoooool2o`00
00?ooooo1?l000000ooooooo0000o`00000:o`00023ooooo0_l000000ooooooo0000o`00000Uoooo
o`;o00000_ooool2o`0000cooooo0_l000000ooooooo0000o`000004o`0001_ooooo0_l0000<oooo
o`;o00001?ooool2o`0000Kooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o
000000Goooooo`000?l0003o0000ooooo`0Co`0000?ooooo0_l0000=ooooo`?o00000_ooool2o`00
0003ooooool0003o000000Ko0000:oooool2o`000003ooooool0003o000000[ooooo0_l00005oooo
o`;o00006_ooool2o`000003ooooool0003o000000Cooooo0_l00009ooooo`Co00001?ooool2o`00
03kooooo000Looooo`03o`000?oooooooooo02cooooo0ol0000Uooooo`;o000000Goooooo`000?l0
003o0000ooooo`0Co`0000?ooooo0_l00002ooooo`?o00000oooool2o`0000?ooooo5?l000001?oo
oooo0000o`000?l0000Vooooo`;o00001?ooool2o`0000Cooooo0_l00005ooooo`;o00006_ooool2
o`000003ooooool0003o000000Cooooo0_l0000;ooooo`;o0000A?ooool001cooooo00?o0000oooo
ooooool0;?ooool3o`0002Gooooo0_l000000ooooooo0000o`000004oooooaCo00001?ooool3o`00
00?ooooo0_l00006oooooaSo0000:Oooool2o`0002Oooooo0_l0000<ooooo`;o00001?ooool2o`00
00Gooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o00000_ooool2o`000003
ooooool0003o000001Ko00000oooool2o`0000_ooooo6ol0000Kooooo`;o00002oooool2o`000003
ooooool0003o000000Gooooo1ol0000Fooooo`Co00002_ooool2o`0000Cooooo0_l00003ooooo`Co
0000?oooool001cooooo00?o0000ooooooooool0<?ooool2o`0002?ooooo0_l000001?oooooo0000
o`000?oooolEo`000003ooooool0003o000000;o00002_ooool2o`000003ooooool0003o000001[o
00006oooool2o`0000_ooooo0_l000000ooooooo0000o`000005ooooo`Oo00006?ooool2o`0001Co
oooo0ol00011ooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00008oooool2o`0000Cooooo
7?l00008ooooo`;o000000?oooooo`000?l000004_l000000ooooooo0000o`000006o`0001Cooooo
0_l0000iooooo`;o00003_ooool2o`0000Gooooo0ol000000ooooooo0000o`00000nooooo`007?oo
ool00ol0003oooooooooo`0]ooooo`;o00000_ooool2o`0002[ooooo5Ol00003ooooo`;o00001_oo
ool:o`0000?ooooo5_l0000Cooooo`Co0000=oooool3o`0000Sooooo0_l00003ooooo`;o00002Ooo
ool2o`000003ooooool0003o000003_ooooo000Looooo`03o`000?oooooooooo02gooooo0_l00002
ooooo`;o0000:_oooolFo`0000Sooooo3?l00002oooooaWo00004oooool3o`0001;ooooo0_l0000S
ooooo`;o00002?ooool2o`00017ooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0^oooo
o`;o00000_ooool4o`0002Sooooo5Ol00008ooooo`;o000000Coooooo`000?l0003o00000_ooool2
o`000004ooooool0003o0000oooooa[o00004_ooool3o`0000Oooooo0_l00009ooooo`Co0000>Ooo
ool2o`00043ooooo000Looooo`03o`000?oooooooooo02kooooo0_l00002ooooo`Co0000:?oooolG
o`0000Oooooo0_l000001?oooooo0000o`000?l00004oooooago00004_ooool3o`0000Oooooo0_l0
000;ooooo`;o0000:_ooool2o`0000Cooooo0_l00006ooooo`?o0000@?ooool001cooooo00?o0000
ooooooooool0;_ooool2o`0000;ooooo0_l0000/oooooaOo00000_ooool2o`000003ooooool0003o
000000;ooooo0_l00002ooooo`So000000?oooooo`000?l000005?l0000Jooooo`;o00003?ooool2
o`0002_ooooo1?l00002ooooo`Co00001?ooool3o`00043ooooo000Looooo`03o`000?oooooooooo
03;ooooo0_l0000Iooooo`;o00004Oooool5o`000003ooooool0003o0000013o000000Coooooo`00
0?l0003ooooo0_l000001?oooooo0000o`000?l00002ooooo`Co00001?oooolHo`0001Wooooo0_l0
000;ooooo`?o0000:oooool4o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`00047ooooo
000Looooo`03o`000?oooooooooo04gooooo0_l0000Boooooa[o000000Coooooo`000?l0003ooooo
0ol0000:ooooo`;o000000?oooooo`000?l000004ol0000Cooooo`;o00001?ooool2o`0000[ooooo
1?l0000eooooo`Ko0000@Oooool001cooooo00?o0000ooooooooool0>?ooool2o`0000;ooooo0_l0
00001?oooooo0000o`000?ooool3o`0000?ooooo0_l0000@ooooo`;o000000?oooooo`000?l00000
0_oooolMo`00017ooooo6?l0000<ooooo`;o00000_ooool2o`000003ooooool0003o000000gooooo
1?l0000Vooooo`;o00001?ooool2o`0000Oooooo1Ol00012ooooo`007?ooool2o`00037ooooo0ol0
0005ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`?o00000oooool2o`0000Oooooo
0_l000000ooooooo0000o`000003o`000004ooooool0003o0000ooooo`;o00000_ooool3o`000003
ooooool0003o000000_o000000?oooooo`000?l000000oooool2o`000003ooooool0003o000001Go
oooo0ol000000ooooooo0000o`00000@o`0000_ooooo1_l000000ooooooo0000o`000002ooooo`;o
00003oooool3o`00023ooooo0ol00003ooooo`?o00002?ooool4o`0004;ooooo000Looooo`03o`00
0?oooooooooo033ooooo0ol00009ooooo`;o00002_ooool2o`0000Oooooo0_l000000ooooooo0000
o`000003o`0000Cooooo5ol0000Rooooo`oo000000Coooooo`000?l0003o00002_ooool6o`000003
ooooool0003o000000;ooooo0ol0000>ooooo`?o00000oooool2o`0001_ooooo0ol00003ooooo`;o
00002oooool2o`0001[ooooo0_l0000Vooooo`007?ooool00ol0003oooooooooo`0cooooo`;o0000
3oooool2o`0000;ooooo0_l00007ooooo`;o000000Coooooo`000?l0003o00001_ooool4o`0000;o
oooo1_l00003ooooo`?o00000oooool2o`0000;ooooo1?l0000Noooooa;o00000_ooool4o`0000?o
oooo0ol000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000003Oooool2o`0000Go
oooo0ol0000Jooooo`;o00000oooool2o`0000Cooooo0ol00005ooooo`;o00006_ooool2o`0002Ko
oooo000Looooo`03o`000?oooooooooo03?ooooo0_l000000ooooooo0000o`00000<ooooo`;o0000
0oooool2o`0000Gooooo0ol000000ooooooo0000o`000006ooooo`Ko00001_ooool=o`000003oooo
ool0003o000000;o00002oooool2o`0001Wooooo2_l000000ooooooo0000o`000009o`0000Gooooo
0ol0000@ooooo`;o00001_ooool2o`0001[ooooo0_l00003ooooo`;o00000oooool4o`0000Cooooo
0_l00013ooooo`007?ooool00ol0003oooooooooo`0fooooo`?o00004?ooool2o`0000Gooooo0ol0
0009ooooo`Ko00001_ooool:o`000003ooooool0003o000000kooooo1?l0000Iooooo`;o000000Co
ooooo`000?l0003ooooo0_l000000ooooooo0000o`00000:o`0000;ooooo0_l000001?oooooo0000
o`000?l00002ooooo`;o000000?oooooo`000?l000004oooool2o`0001Wooooo0_l00008ooooo`Ko
00000_ooool2o`0004?ooooo000Looooo`03o`000?oooooooooo03Oooooo0_l00004ooooo`;o0000
1?ooool2o`0000Cooooo0_l00006ooooo`;o00002_ooool4o`0000Oooooo0_l0000Iooooo`;o0000
0_ooool2o`00023ooooo2?l00002ooooo`;o000000?oooooo`000?l000001Ol000001Ooooooo0000
o`000?l0003ooooo00;o00002oooool2o`0000Kooooo0_l0000Sooooo`Ko000000?oooooo`000?l0
00006_ooool2o`0002Sooooo000Looooo`03o`000?oooooooooo03Oooooo1?l00002ooooo`;o0000
1?ooool2o`0000?ooooo0ol0000Booooo`Ko00001?ooool4o`0001Oooooo0ol00002ooooo`;o0000
3oooool9o`000003ooooool0003o000000Co000000?oooooo`000?l000001?ooool2o`0000;ooooo
0_l000000ooooooo0000o`000005o`000005ooooool0003o0000o`000?ooool00_l0000;ooooo`?o
00007_ooool2o`0000Cooooo1?l00002ooooo`?o00000oooool3o`0001Wooooo0ol0000Xooooo`00
7?ooool00ol0003oooooooooo`0gooooo`Co00000oooool2o`000003ooooool0003o000000Cooooo
0ol00009ooooo`;o000000?oooooo`000?l000002Oooool4o`0000;ooooo1?l0000Gooooo`?o0000
4Oooool;o`000003ooooool0003o000000[o000000Coooooo`000?l0003o00001?ooool3o`000003
ooooool0003o000000;ooooo1?l00002ooooo`;o00002_ooool2o`0001kooooo0_l00004ooooo`Ko
00001Oooool3o`0001[ooooo0_l0000Yooooo`007?ooool00ol0003oooooooooo`0gooooo`Co0000
0oooool5o`0000;ooooo1?l0000:ooooo`;o000000?oooooo`000?l000002_ooool3o`0002Kooooo
0_l00008ooooo`?o00000oooool6o`0000Gooooo0ol000000ooooooo0000o`000008o`0000Kooooo
0_l00003ooooo`Co000000?oooooo`000?l000003oooool2o`0001kooooo0_l00003ooooo`;o0000
0_ooool5o`0001Wooooo0_l0000[ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00000_oo
ool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000_ooooo0_l00009ooooo`;o0000;?oo
ool2o`0000Oooooo1?l00003ooooo`Co00001_ooool2o`0000Kooooo0_l000000ooooooo0000o`00
0004o`0000Kooooo0_l00002ooooo`?o00001?ooool2o`0000cooooo0_l00005ooooo`;o00005ooo
ool2o`0000Cooooo0_l000000ooooooo0000o`000003o`0001Wooooo0_l0000[ooooo`007?ooool0
0ol0003oooooooooo`0hooooo`Ko00001Oooool2o`0000gooooo0_l000000ooooooo0000o`000006
ooooo`;o0000=Oooool4o`0000?ooooo0_l00008ooooo`;o00003Oooool6o`0000;ooooo1?l00000
0ooooooo0000o`000004ooooo`;o00004oooool2o`0001_ooooo1?l000000ooooooo0000o`000003
o`0001Wooooo0_l0000[ooooo`007?ooool00ol0003oooooooooo`0jooooo`?o00001_ooool2o`00
013ooooo0_l00006ooooo`?o0000<oooool5o`0000?ooooo0_l0000:ooooo`Co000000Coooooo`00
0?l0003o00000_ooool3o`0000;ooooo1Ol00003ooooo`;o00001oooool3o`000003ooooool0003o
0000017ooooo0_l0000Hooooo`?o00000oooool4o`0001[ooooo0_l0000[ooooo`007?ooool00ol0
003oooooooooo`0kooooo`;o00001_ooool2o`0000[ooooo0_l00006ooooo`;o00001Oooool2o`00
03?ooooo1?l00006ooooo`;o00001?ooool2o`0000;ooooo2?l000000ooooooo0000o`00000:o`00
00_ooooo0ol000000ooooooo0000o`00000Aooooo`;o00006?ooool3o`0000?ooooo0ol00018oooo
o`007?ooool00ol0003oooooooooo`0nooooo`;o00001oooool2o`0000Kooooo0_l00003ooooo`Ko
0000;_ooool2o`0000Wooooo0ol00007ooooo`;o000000Coooooo`000?l0003ooooo1?l00004oooo
o`co00000oooool4o`0000?ooooo0_l00005ooooo`;o00004Oooool2o`0000;ooooo0_l0000Foooo
o`Co00000_ooool3o`0004Wooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0nooooo`;o00001Ooo
ool6o`0000Wooooo1_l0000^ooooo`;o00002Oooool2o`0000Kooooo0_l00003ooooo`;o00000ooo
ool2o`0000;ooooo4?l000000ooooooo0000o`000002o`0000?ooooo0_l000000ooooooo0000o`00
0002ooooo`;o00004Oooool6o`0001Kooooo0_l00004ooooo`?o0000BOooool00006oooooomgMgOo
V9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03
o`000?oooooooooo04Gooooo0_l00002ooooo`Co00004Oooool2o`000003ooooool0003o000002oo
oooo1?l00005ooooo`?o00000_ooool2o`0000Kooooo4_l00002ooooo`?o00001Oooool2o`00013o
oooo0ol00004ooooo`;o00000_ooool2o`0006Kooooo00000ooooooo410@ooooo`02ooooo`03oa0@
4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo04;o
oooo0_l00007ooooo`;o00004Oooool2o`000004ooooool0003o0000o`0002kooooo1Ol00005oooo
o`;o00002_oooolHo`0000Sooooo0_l0000<ooooo`?o00000_ooool2o`0000Cooooo0_l0000Ioooo
o`;o0000Boooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003o
V9RHoooooonHV9So8B4Q00Kooooo0ol00011ooooo`?o00001oooool2o`0001Cooooo0ol0000^oooo
o`Go000000Coooooo`000?l0003o00000oooool2o`0000Kooooo6_l00008ooooo`;o00003Oooool2
o`000005ooooool0003o0000o`000?ooool00_l0000@ooooo`;o00002Oooool3o`0001Oooooo0_l0
000booooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?mEEEGo
0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`11ooooo`?o00000_ooool2o`0000?ooooo0_l0
000Fooooo`;o0000;Oooool3o`0000?ooooo0ol00003ooooo`;o00001_oooolIo`000003ooooool0
003o000001Oooooo0ol00002ooooo`;o00004?ooool3o`0000Sooooo0_l0000Gooooo`?o0000<_oo
ool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08
ooooo`03o`000?oooooooooo04Kooooo0_l00003ooooo`;o00005_ooool2o`0002kooooo0ol0000;
ooooo`;o00000ooooolIo`000003ooooool0003o000001Oooooo1?l00003ooooo`;o00003_ooool3
o`00027ooooo0ol0000booooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@
413oV9RH00Sooooo00?o0000ooooooooool0A?ooool2o`0000Gooooo0_l0000Gooooo`;o0000;Ooo
ool3o`0000Gooooo0_l00004ooooo`;o00000_oooolJo`000004ooooool0003o0000o`0001Kooooo
1Ol000001?oooooo0000o`000?l0000Dooooo`;o00000oooool2o`0001Oooooo0ol0000booooo`00
00Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000
ooooooooool0A?ooool2o`0000Gooooo0_l0000?ooooo`;o000000?oooooo`000?l000000oooool2
o`000003ooooool0003o000002;ooooo0_l00005ooooo`;o00001?ooool2o`000003ooooool0003o
000000Sooooo7ol0000Eooooo`;o000000?oooooo`000?l000000ol0000Eooooo`;o00000oooool2
o`0004cooooo000Looooo`03o`000?oooooooooo04?ooooo0ol00004ooooo`?o00003_ooool3o`00
0003ooooool0003o000000Kooooo0_l0000Rooooo`?o00001?ooool3o`0000?ooooo0_l0000:oooo
ob3o00006Oooool2o`0001Oooooo0_l0000Jooooo`;o0000=Oooool001cooooo00?o0000oooooooo
ool0@oooool2o`0000Gooooo0ol0000>ooooo`?o000000Coooooo`000?l0003o0000:_ooool2o`00
00Cooooo1?l0000<ooooob;o00005Oooool3o`0001[ooooo0_l0000Jooooo`;o0000=Oooool001co
oooo00?o0000ooooooooool0@oooool2o`0000Kooooo0_l0000?ooooo`Oo00002_ooool2o`0002?o
oooo1?l0000<ooooo`Go00001?oooolIo`0001Gooooo0ol0000Jooooo`;o0000DOooool001cooooo
00?o0000ooooooooool0AOooool5o`0001;ooooo1?l000000ooooooo0000o`000003o`0000?ooooo
0_l00002ooooo`;o00008oooool3o`0000;ooooo0_l00006ooooo`;o00000_oooolRo`0001?ooooo
1?l0001]ooooo`007?ooool00ol0003oooooooooo`14ooooo`Ko00004oooool;o`000003ooooool0
003o000002Oooooo0ol00002ooooo`;o00001_ooool2o`0000?ooooo8Ol0000Cooooo`?o00005?oo
ool3o`0000Sooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`13ooooo`?o00000oooool2
o`0001;ooooo1Ol00004ooooo`;o00000_ooool3o`0000Oooooo0_l0000Aooooo`?o00002?ooool3
o`0000;ooooo0_l0000<ooooob7o00004_ooool3o`000003ooooool0003o0000017ooooo0ol00002
ooooo`?o00000oooool2o`0001;ooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`13oooo
o`?o00000oooool2o`0001;ooooo1?l00009ooooo`?o00001oooool2o`000003ooooool0003o0000
00kooooo0ol00002ooooo`;o00001?ooool3o`0000gooooo0_l000001Ooooooo0000o`000?l0003o
oooo01go00004_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000Cooooo`?o00000oooool2
o`0001;ooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00003_ooool2o`00
00Oooooo1?l00004ooooo`;o00001?ooool2o`0000Sooooo1?l0000?ooooo`;o00000_ooool2o`00
00Cooooo0ol000000ooooooo0000o`00000:ooooo`;o00000_oooolQo`00013ooooo1Ol000000ooo
oooo0000o`000002o`0001?ooooo0_l0000Eooooo`;o0000??ooool001cooooo00?o0000oooooooo
ool0A?ooool2o`0000kooooo1?l00006ooooo`?o00001?ooool2o`0000Oooooo1?l00003ooooo`Co
00003oooool2o`0000;ooooo0_l00004ooooo`?o000000?oooooo`000?l000000oooool2o`0000Wo
oooo8Ol0000@ooooo`Wo00002?ooool2o`0000_ooooo0_l0000Dooooo`;o0000??ooool001cooooo
00?o0000ooooooooool0A?ooool2o`0000;ooooo0_l0000<ooooo`;o00001_ooool3o`0000Sooooo
0_l00003ooooo`Co00001Oooool2o`0001Wooooo0ol000000ooooooo0000o`000003ooooo`;o0000
0_ooool3o`0000Cooooo8Ol0000?ooooo`Go000000Coooooo`000?l0003o00002Oooool2o`0000[o
oooo0ol0000Booooo`;o0000?_ooool001cooooo00?o0000ooooooooool0A_ooool4o`0001Cooooo
0ol00005ooooo`;o000000Coooooo`000?l0003o00005_ooool2o`0000kooooo0ol0000:ooooo`?o
00001?oooolQo`0000oooooo0_l00003ooooo`Co00005Oooool2o`0001?ooooo0_l0000nooooo`00
7?ooool2o`0004Oooooo0_l000000ooooooo0000o`000008ooooo`;o00002_ooool2o`0000Gooooo
0_l000001?oooooo0000o`000?l0000@ooooo`Co00000_ooool2o`0000Kooooo0ol00006ooooo`Co
00003_ooool2o`000004ooooool0003o0000oooooaco00005?ooool4o`0002[ooooo0_l0000noooo
o`007?ooool00ol0003oooooooooo`16ooooo`;o000000?oooooo`000?l000002?ooool2o`0000Wo
oooo1?l00007ooooo`Co00000oooool2o`0000Gooooo0_l00003ooooo`Go00002?ooool4o`0000Go
oooo1Ol000000ooooooo0000o`00000;ooooo`;o00001?oooolEo`0000;ooooo1_l00021ooooo`00
7?ooool00ol0003oooooooooo`1Looooo`Ko00002Oooool2o`000003ooooool0003o000000Ko0000
00?oooooo`000?l000001?ooool4o`0000Sooooo0_l00007ooooo`So00004_ooool2o`000003oooo
ool0003o000001Oo00004_ooool2o`0002Wooooo1?l00010ooooo`007?ooool00ol0003ooooooooo
o`18ooooo`;o00001oooool2o`0000Oooooo1?l00002ooooo`?o00002oooool8o`0000Cooooo1Ol0
000Dooooo`Go00004?ooool2o`0000;ooooo3_l00002ooooo`So000000?oooooo`000?l000000_l0
000<ooooo`;o00000_ooool3o`0000gooooo0_l00007ooooo`;o00004Oooool4o`00043ooooo000L
ooooo`03o`000?oooooooooo04Sooooo1?l000000ooooooo0000o`000002ooooo`;o00001oooool2
o`0000Cooooo0ol00003ooooo`?o00001Oooool3o`0000Wooooo0ol000000ooooooo0000o`00000<
ooooo`;o00001oooool2o`0000;ooooo0_l0000=ooooo`;o00000_ooool;o`0000?ooooo2_l00000
0ooooooo0000o`000002o`0000[ooooo1?l00002ooooo`;o00003_ooool2o`0000Oooooo0ol0000?
ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0Aoooool5o`000003ooooool0003o0000
01;ooooo0_l00003ooooo`Go00000oooool2o`0000Oooooo0_l00004ooooo`Co00001?ooool2o`00
00?ooooo1?l00005ooooo`;o00000oooool3o`0001Cooooo6_l00009ooooo`?o00000oooool2o`00
00_ooooo0_l00009ooooo`;o000000?oooooo`000?l000003oooool2o`0004?ooooo000Looooo`03
o`000?oooooooooo04Oooooo2Ol000000ooooooo0000o`00000>ooooo`;o00001?ooool4o`0000Wo
oooo1ol00002ooooo`Co00001?ooool2o`0000?ooooo0_l00007ooooo`;o00000oooool4o`0000_o
oooo0_l00006oooooa_o00002?ooool2o`0000;ooooo1?l0000;ooooo`Co00001oooool2o`00017o
oooo0ol00013ooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o000000Coooooo`000?l0003o
oooo0_l00006ooooo`Co00001_ooool2o`0000;ooooo0_l000000ooooooo0000o`000008ooooo`Wo
00003Oooool2o`0000Oooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l00009ooooo`;o
00002Oooool?o`000003ooooool0003o000000Wo00001?ooool3o`0000;ooooo0_l0000?ooooo`;o
00001oooool2o`00017ooooo0ol00013ooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o0000
1oooool2o`0000;ooooo1?l00005ooooo`?o00001Oooool5o`0000Cooooo2_l00005ooooo`;o0000
1_ooool4o`0000Sooooo0ol00003ooooo`;o00004_oooolAo`000003ooooool0003o000000Wo0000
1?ooool3o`0000_ooooo0_l00004ooooo`;o00001_ooool3o`0005Wooooo000Looooo`03o`000?oo
oooooooo04[ooooo1?l00007ooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0
003o000000;o00001oooool3o`0000?ooooo0ol00002ooooo`Ko00001Oooool2o`0000Kooooo1?l0
0005ooooo`Go00006?oooolNo`00017ooooo0_l000000ooooooo0000o`000003o`0000Kooooo0ol0
000@ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0B_ooool2o`0000cooooo0ol00003
ooooo`;o000000?oooooo`000?l000000_l000001?oooooo0000o`000?l00008ooooo`Go000000Co
ooooo`000?l0003ooooo1?l00004ooooo`;o00003oooool3o`0000Cooooo0_l0000@ooooo`;o0000
2?oooolCo`000003ooooool0003o000000;o00000_ooool2o`00013ooooo1?l00005ooooo`;o0000
4oooool2o`0004Oooooo000Looooo`03o`000?oooooooooo05Wooooo1?l00005ooooo`Oo00000ooo
ool2o`0000?ooooo1ol00002ooooo`Co00001?ooool2o`00013ooooo0_l00004ooooo`;o00004?oo
ool2o`0000Sooooo0_l000000ooooooo0000o`00000>o`000004ooooool0003o0000o`0000?ooooo
0_l0000Hooooo`?o0000G?ooool001cooooo00?o0000ooooooooool0C?ooool5o`000003ooooool0
003o000000Gooooo1?l00005ooooo`Co00001Oooool3o`0000?ooooo2?l00002ooooo`?o00001?oo
ool3o`0000oooooo0ol00009ooooo`;o00002Oooool2o`0000Wooooo0_l000000ooooooo0000o`00
0008o`0000;ooooo2_l0000Kooooo`?o0000G?ooool001cooooo00?o0000ooooooooool0B_ooool:
o`0000Gooooo0_l00002ooooo`;o00001?ooool3o`0000Gooooo0ol00003ooooo`go00001?ooool3
o`00013ooooo0_l00009ooooo`;o00002Oooool2o`0000kooooo1ol00004ooooo`Ko000000?ooooo
o`000?l000004?ooool2o`0000Kooooo1?l0001Nooooo`007?ooool00ol0003oooooooooo`1:oooo
o`;o00000oooool3o`0000_ooooo0_l00004ooooo`?o000000?oooooo`000?l000002Oooool3o`00
0003ooooool0003o000000Ko00001?ooool2o`0000Sooooo0_l00007ooooo`;o00009Oooool2o`00
00;ooooo0_l00004ooooo`?o000000?oooooo`000?l000004?ooool5o`0000Gooooo1Ol0000Aoooo
o`;o0000Boooool001cooooo00?o0000ooooooooool0Coooool2o`0001;ooooo1_l00003ooooo`;o
00002?ooool8o`0000Cooooo0_l00007ooooo`Co00004Oooool2o`0001[ooooo0_l000000ooooooo
0000o`000002o`00017ooooo0_l00002ooooo`So00001_ooool2o`0001Cooooo0_l0001;ooooo`00
7?ooool2o`0004oooooo1ol0000>ooooo`Go00001?ooool2o`0000Cooooo0ol000000ooooooo0000
o`000004o`0000Kooooo0_l00007ooooo`Co00002oooool2o`0000?ooooo0ol0000Fooooo`;o0000
1?ooool5o`00017ooooo0_l00002ooooo`Co00000_ooool2o`0000Cooooo1?l0000@ooooo`?o0000
C_ooool001cooooo00?o0000ooooooooool0C_ooool7o`0000oooooo0_l0000<ooooo`?o000000?o
ooooo`000?l000001?l00006ooooo`;o00002_ooool2o`0000[ooooo1?l000000ooooooo0000o`00
000Gooooo`;o000000?oooooo`000?l000000ol000000ooooooo0000o`00000Dooooo`Co00001Ooo
ool3o`000003ooooool0003o000001;ooooo0ol0001>ooooo`007?ooool00ol0003oooooooooo`1<
ooooo`;o00009?ooool2o`0000Cooooo1?l00005ooooo`;o00002?ooool2o`000003ooooool0003o
000000cooooo0_l00005ooooo`;o00001?ooool3o`0000[ooooo0ol00002ooooo`?o00005Oooool3
o`000003ooooool0003o000000Oooooo0ol0001Vooooo`007?ooool00ol0003oooooooooo`1<oooo
o`;o00005oooool2o`0000_ooooo1?l00003ooooo`Go000000?oooooo`000?l000000_l00008oooo
o`;o000000?oooooo`000?l000003oooool2o`0000;ooooo0_l00004ooooo`?o00000_ooool2o`00
00?ooooo1_l00002ooooo`;o00005?ooool5o`0000Kooooo0ol0000Gooooo`?o0000D?ooool001co
oooo00?o0000ooooooooool0Coooool2o`0001Cooooo0_l0000;ooooo`Co00001?ooool8o`0000Wo
oooo1Ol0000?ooooo`?o000000?oooooo`000?l000002Oooool2o`0000?ooooo1Ol00002ooooo`;o
00005Oooool2o`0000Wooooo0ol0000Dooooo`;o000000Coooooo`000?l0003o0000D?ooool001co
oooo00?o0000ooooooooool0COooool4o`0000Gooooo0_l00006ooooo`;o00001oooool2o`0000[o
oooo1?l00003ooooo`;o00000_ooool4o`0000Wooooo0ol0000Booooo`;o000000Coooooo`000?l0
003ooooo0_l0000>ooooo`?o000000?oooooo`000?l000003Oooool2o`0000cooooo0_l0000Joooo
o`;o0000E?ooool001cooooo00?o0000ooooooooool0COooool4o`0000Gooooo0ol00005ooooo`;o
00001oooool2o`0000[ooooo1?l0000Dooooo`;o000000?oooooo`000?l000005_ooool4o`0000?o
oooo0_l00002ooooo`;o00001?ooool2o`0000kooooo1_l00007ooooo`Go00006?ooool2o`0005Ko
oooo000Looooo`03o`000?oooooooooo04oooooo0_l00006ooooo`;o00000_ooool2o`0000gooooo
0_l0000Nooooo`?o000000?oooooo`000?l000006?ooool2o`000003ooooool0003o000000;o0000
0_ooool2o`0001;ooooo1?l00002ooooo`;o00001?ooool2o`000003ooooool0003o000000;o0000
6?ooool4o`0005Gooooo000Looooo`03o`000?oooooooooo04oooooo0_l00006ooooo`;o00000_oo
ool2o`0000_ooooo1?l000000ooooooo0000o`000008ooooo`;o00003_ooool5o`0001oooooo0_l0
000Hooooo`;o00001Oooool2o`0000?ooooo0_l0000Kooooo`Ko0000EOooool001cooooo00?o0000
ooooooooool0Eoooool2o`000003ooooool0003o000000Wooooo0_l000001?oooooo0000o`000?l0
0002ooooo`;o00002?ooool2o`0000Wooooo0ol000000ooooooo0000o`000004o`0003Gooooo0_l0
0003ooooo`;o00000_ooool6o`0001Sooooo0_l00004ooooo`;o0000FOooool001cooooo00?o0000
ooooooooool0F_ooool4o`0000Oooooo0_l00004ooooo`;o00002_ooool2o`0000;ooooo3_l00000
0ooooooo0000o`00000]ooooo`;o00001_ooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool2
o`0001Oooooo1ol0001Kooooo`007?ooool00ol0003oooooooooo`1Looooo`;o00001_ooool3o`00
00Cooooo1?l000000ooooooo0000o`000005ooooo`;o00000_ooool7o`000003ooooool0003o0000
00Co0000<?ooool2o`0002cooooo0_l000000ooooooo0000o`000002o`0000;ooooo0ol0001Foooo
o`007?ooool00ol0003oooooooooo`1Kooooo`;o00001oooool4o`0000Cooooo0ol000000ooooooo
0000o`000005ooooo`Co00001Oooool9o`0000Cooooo0_l0001Kooooo`Co000000?oooooo`000?l0
00000_l0001Fooooo`007?ooool00ol0003oooooooooo`1Kooooo`;o00001Oooool2o`0000;ooooo
0_l00006ooooo`;o000000?oooooo`000?l000001Oooool4o`0000Kooooo0_l000000ooooooo0000
o`000003o`0000?ooooo0_l0001@ooooo`?o00002?ooool4o`000003ooooool0003o000005Sooooo
000Looooo`03o`000?oooooooooo05_ooooo0_l00005ooooo`;o00002Oooool6o`0000Kooooo0ol0
0002ooooo`;o00001Oooool5o`0000?ooooo0_l0001@ooooo`?o00002Oooool3o`0005_ooooo000L
ooooo`03o`000?oooooooooo05Oooooo0_l0000;ooooo`;o00001oooool4o`0000Cooooo0_l00003
ooooo`Oo00001?ooool2o`0000Kooooo0_l0001<ooooo`;o0000K?ooool001cooooo0_l0001Hoooo
o`;o00002oooool2o`0000_ooooo0_l00002ooooo`;o00001Oooool6o`000003ooooool0003o0000
00Cooooo1_l00019ooooo`;o000000?oooooo`000?l00000K?ooool001cooooo00?o0000oooooooo
ool0G?ooool2o`0000gooooo0_l00004ooooo`;o00003?ooool7o`0000?ooooo1Ol0001:ooooo`;o
00000_ooool2o`0006_ooooo000Looooo`03o`000?oooooooooo05Wooooo1_l0000<ooooo`;o0000
1?ooool3o`0000gooooo1Ol00002ooooo`;o00000_ooool2o`0004kooooo0_l00008ooooo`;o0000
HOooool001cooooo00?o0000ooooooooool0FOooool6o`0000;ooooo0_l0000?ooooo`Co00003?oo
ool4o`0000;ooooo0_l0001:ooooo`;o00004?ooool2o`00067ooooo000Looooo`03o`000?oooooo
oooo05Wooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o0000017ooooo0ol0000<
ooooo`?o0000?oooool2o`0000Gooooo0ol00005ooooo`;o0000Loooool001cooooo00?o0000oooo
ooooool0FOooool2o`0000?ooooo0_l00009ooooo`;o00002_ooool2o`00013ooooo0_l00003oooo
o`;o0000=oooool2o`0000Cooooo1?l00006ooooo`;o00002oooool2o`0006Gooooo000Looooo`03
o`000?oooooooooo05cooooo0_l00002ooooo`;o00001oooool3o`0000Wooooo1_l0000<ooooo`;o
00000oooool2o`0003gooooo1_l00004ooooo`;o00001Oooool2o`0000Cooooo0_l0001Uooooo`00
7?ooool00ol0003oooooooooo`1Looooo`;o00000_ooool2o`0000Oooooo0ol0000:ooooo`Go0000
BOooool2o`0000Cooooo0_l000000ooooooo0000o`000002o`0000_ooooo0_l0001[ooooo`007?oo
ool00ol0003oooooooooo`1Qooooo`;o00002_ooool4o`0000Sooooo0_l00019ooooo`;o00001?oo
ool5o`0000[ooooo1?l0001/ooooo`007?ooool00ol0003oooooooooo`1Qooooo`;o00002_ooool4
o`0000;ooooo0_l00004ooooo`?o0000>oooool2o`0000?ooooo0_l0000<ooooo`Go00000oooool2
o`0000Gooooo1?l0001/ooooo`007?ooool00ol0003oooooooooo`1cooooo`;o00001Oooool3o`00
0003ooooool0003o000003Kooooo0ol00003ooooo`?o00002oooool2o`000003ooooool0003o0000
00Go0000MOooool001cooooo00?o0000ooooooooool0N_ooool3o`000003ooooool0003o000003Ko
oooo0ol00002ooooo`Co00000_ooool2o`0000[ooooo1ol00007ooooo`;o0000K?ooool001cooooo
00?o0000ooooooooool0IOooool2o`0000Sooooo0_l00012ooooo`;o00001_ooool2o`0000Cooooo
0_l0000<ooooo`Co00000oooool2o`0000?ooooo0_l0001/ooooo`007?ooool00ol0003ooooooooo
o`1Uooooo`Co00001_ooool2o`0000Kooooo0_l00005ooooo`?o0000<_ooool2o`00017ooooo0_l0
0007ooooo`;o00001Oooool2o`00077ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Wooooo`;o
00003?ooool4o`0000Gooooo0ol00014ooooo`?o00002Oooool2o`0007Kooooo00001_ooooooMgMg
oiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool0
0ol0003oooooooooo`1eooooo`;o00002_ooool2o`0004;ooooo0ol00009ooooo`;o0000M_ooool0
0003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool0POooool3o`0004;ooooo0ol00002ooooo`;o0000O?ooool0
0003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Olb<S;oV9RHoooooonHV9So
<S8b00Kooooo0ol0001Zooooo`Co00003?ooool2o`0000Kooooo1?l0000kooooo`;o00001?ooool2
o`0000;ooooo0_l0001looooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09oooo
o`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`1Zooooo`Co00002Oooool2
o`000004ooooool0003o0000o`0000Oooooo1Ol00002ooooo`;o0000<_ooool4o`0000Sooooo0_l0
001looooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[o
oooookZj^_l@41001_ooool00ol0003oooooooooo`1/ooooo`?o00002?ooool2o`0000;ooooo0_l0
0003ooooo`;o00001?ooool4o`000004ooooool0003o0000o`0002cooooo0_l00003ooooo`;o0000
2?ooool2o`0007kooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oo
oooo^[Zjo`000006ooooo`03o`000?oooooooooo06gooooo0_l000000ooooooo0000o`000008oooo
o`;o00001?ooool2o`0000Kooooo0_l00002ooooo`?o0000:oooool2o`0000gooooo0_l0001noooo
o`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_oo
ool00ol0003oooooooooo`1`ooooo`;o00002?ooool2o`0000?ooooo0_l0000;ooooo`?o00000_oo
ool4o`00027ooooo0_l0000:ooooo`Co0000Poooool001cooooo00?o0000ooooooooool0Ooooool2
o`0000_ooooo0_l00003ooooo`Co00008Oooool2o`0000[ooooo1?l00023ooooo`007?ooool00ol0
003oooooooooo`1aooooo`?o0000>oooool2o`0000[ooooo0_l00005ooooo`;o0000QOooool001co
oooo00?o0000ooooooooool0LOooool3o`0000gooooo0_l0000Zooooo`Co00000_ooool4o`0000?o
oooo0ol00002ooooo`?o0000Qoooool001cooooo00?o0000ooooooooool0POooool2o`0002[ooooo
0_l00004ooooo`Co00000oooool2o`0000?ooooo0ol00027ooooo`007?ooool00ol0003ooooooooo
o`26ooooo`;o00000oooool4o`0001[ooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo
0_l00006ooooo`;o000000?oooooo`000?l00000R?ooool001cooooo00?o0000ooooooooool0QOoo
ool4o`0000;ooooo1?l0000Eooooo`;o000000?oooooo`000?l000000_l000001?oooooo0000o`00
0?ooool3o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o0000Roooool001cooooo00?o
0000ooooooooool0QOooool4o`0000gooooo0_l0000<ooooo`;o000000?oooooo`000?l000001Ooo
ool4o`0000?ooooo1?l0002@ooooo`007?ooool00ol0003oooooooooo`2Aooooo`Co000000?ooooo
o`000?l000001_ooool3o`0000gooooo0_l00005ooooo`;o0000T_ooool001cooooo00?o0000oooo
ooooool0Roooool2o`0000Cooooo1?l000000ooooooo0000o`000006ooooo`?o000000?oooooo`00
0?l000000_ooool2o`0000gooooo0_l0002Booooo`007?ooool00ol0003oooooooooo`1nooooo`;o
00002oooool2o`0000Wooooo0_l00005ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o
00000_ooool3o`0009cooooo000Looooo`03o`000?oooooooooo07kooooo0_l0000@ooooo`;o0000
2oooool2o`000003ooooool0003o000000?ooooo0_l00003ooooo`?o0000W?ooool001cooooo0_l0
001oooooo`;o00004?ooool2o`0000gooooo0_l00004ooooo`;o0000X_ooool001cooooo00?o0000
ooooooooool0WOooool4o`000:Sooooo000Looooo`03o`000?oooooooooo09gooooo0_l0002Zoooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`004_ooool4o`000003oa0@4?oooooo
oooo00?ooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool3o`000?oo
ooooB_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003ooooooooo
o`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000oooo
ooooool0oooooomBooooo`004_ooool00omEEEGoIVIVo`00003ooooooeCooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo002Uooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@
ooooooooool05Oooool5o`0000Gooooo00?o0000onk^k_ooool00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^093ooooo002Vooooo`05o`000?ooooooooooooooool000002Oooool6o`0000Wooooo00Go
V9RHob4Q8Oo^k^koooooodA4A005ooooo`03oeEEEOnYZJWooooo00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`2@ooooo`00Y_ooool01Ol0003ooooooooooooooooo000001Wooooo00?oV9RHob4Q8Oo^
k^h01_ooool00onYZJWoEEEEooooo`03ooooo`05oa0@4?ooooooooooooooool@4100T?ooool00:Ko
oooo00Go0000ooooooooooooooooo`000009ooooo`Ko00002oooool00onHV9So8B4Qonk^kP06oooo
o`03ob4Q8Ooooooooooo00;ooooo00Go0000ooooooooooooooooo`00002@ooooo`00Y_ooool01Ol0
003oQhN7oooooonYZJWo000001_ooooo00?oMgMgofIVI_ooool01Oooool00omEEEGoc<c<ooooo`02
ooooo`05o`000?ooooooooooooooool00000T?ooool00:Gooooo00?o410@o`000?mgMgL00_l00000
0onHV9Soooooooooo`0Jooooo`03o`000?oooooooooo00Cooooo00?oZJVYogMgMoooool00_ooool0
1Ol@413ooooooooooooooooo410@093ooooo0033ooooo`05o`000?nj^[[ooooooiRHV?l@41000ooo
ool01Ol@413ooooooooooooooooo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`2@ooooo`00
`oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h0T?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(276) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.66261 .41092 Mdot
.67314 .43168 Mdot
.31319 .31349 Mdot
.52787 .62257 Mdot
.34688 .52575 Mdot
.35907 .37995 Mdot
.52288 .31381 Mdot
.52733 .32288 Mdot
.31051 .34947 Mdot
.64399 .73101 Mdot
.51519 .27939 Mdot
.58546 .66483 Mdot
.51124 .31881 Mdot
.5509 .63873 Mdot
.38025 .64939 Mdot
.51333 .61359 Mdot
.64088 .43702 Mdot
.30378 .46858 Mdot
.51307 .62169 Mdot
.33987 .39572 Mdot
.58058 .54716 Mdot
.5452 .65041 Mdot
.70905 .42591 Mdot
.55172 .64281 Mdot
.54933 .69626 Mdot
.66439 .44013 Mdot
.6649 .41028 Mdot
.57581 .69771 Mdot
.52228 .63778 Mdot
.4968 .2938 Mdot
.44225 .5773 Mdot
.35711 .76612 Mdot
.50466 .52248 Mdot
.74495 .58552 Mdot
.49329 .30701 Mdot
.54441 .35933 Mdot
.35788 .34677 Mdot
.49207 .3228 Mdot
.51776 .27477 Mdot
.53137 .29531 Mdot
.52942 .29412 Mdot
.66134 .43975 Mdot
.50952 .34337 Mdot
.35772 .24112 Mdot
.55948 .65011 Mdot
.78309 .49014 Mdot
.29012 .33929 Mdot
.56506 .68537 Mdot
.70469 .4437 Mdot
.30704 .3531 Mdot
.28254 .60959 Mdot
.53177 .32822 Mdot
.48504 .5274 Mdot
.79931 .3114 Mdot
.52001 .32309 Mdot
.52275 .66709 Mdot
.32822 .36103 Mdot
.56411 .6212 Mdot
.58254 .64563 Mdot
.73507 .5517 Mdot
.5558 .61261 Mdot
.32632 .4849 Mdot
.70959 .46911 Mdot
.30095 .35036 Mdot
.30737 .33923 Mdot
.50302 .33886 Mdot
.6461 .46258 Mdot
.49841 .30965 Mdot
.52505 .63871 Mdot
.32478 .37699 Mdot
.53055 .67054 Mdot
.51422 .27942 Mdot
.66925 .41214 Mdot
.54309 .65732 Mdot
.6988 .35595 Mdot
.57269 .31709 Mdot
.30155 .4607 Mdot
.62909 .50799 Mdot
.39067 .40698 Mdot
.39128 .62893 Mdot
.54412 .65603 Mdot
.51695 .18008 Mdot
.33861 .65644 Mdot
.70106 .43426 Mdot
.49595 .60838 Mdot
.61072 .23909 Mdot
.55462 .69147 Mdot
.44485 .57091 Mdot
.59068 .65824 Mdot
.28193 .54937 Mdot
.33053 .36928 Mdot
.68729 .45876 Mdot
.5537 .65924 Mdot
.53177 .65248 Mdot
.69474 .70652 Mdot
.51958 .62627 Mdot
.57972 .69325 Mdot
.43425 .4924 Mdot
.54033 .31808 Mdot
.50403 .54081 Mdot
.41969 .38471 Mdot
.48735 .54128 Mdot
.53814 .68079 Mdot
.34486 .3697 Mdot
.71131 .4662 Mdot
.51004 .54341 Mdot
.50028 .30221 Mdot
.55164 .65557 Mdot
.51361 .25462 Mdot
.70642 .43924 Mdot
.57328 .70974 Mdot
.31534 .49805 Mdot
.54373 .48315 Mdot
.68515 .40895 Mdot
.79192 .60197 Mdot
.53639 .61924 Mdot
.57515 .64397 Mdot
.6702 .43054 Mdot
.35516 .40109 Mdot
.46657 .19197 Mdot
.66243 .41805 Mdot
.54016 .30545 Mdot
.6411 .44764 Mdot
.45358 .49228 Mdot
.35379 .40313 Mdot
.45173 .51253 Mdot
.444 .49957 Mdot
.3168 .71059 Mdot
.53136 .61253 Mdot
.58498 .57765 Mdot
.35223 .37082 Mdot
.66941 .41752 Mdot
.50715 .32419 Mdot
.54949 .59152 Mdot
.67824 .4497 Mdot
.52649 .3157 Mdot
.33282 .47254 Mdot
.29933 .4791 Mdot
.69714 .41818 Mdot
.80311 .58971 Mdot
.54923 .32888 Mdot
.53779 .33746 Mdot
.28392 .61256 Mdot
.70061 .43314 Mdot
.33544 .49852 Mdot
.50766 .29935 Mdot
.16942 .50389 Mdot
.54829 .69923 Mdot
.28799 .64896 Mdot
.52462 .18706 Mdot
.2827 .60868 Mdot
.59386 .57468 Mdot
.32392 .50496 Mdot
.52691 .31564 Mdot
.55941 .67647 Mdot
.69217 .43489 Mdot
.67519 .44843 Mdot
.53096 .66731 Mdot
.50976 .55246 Mdot
.5547 .62845 Mdot
.5053 .53133 Mdot
.43757 .50648 Mdot
.55497 .65632 Mdot
.81517 .45148 Mdot
.6935 .44553 Mdot
.50496 .59277 Mdot
.35496 .34683 Mdot
.53525 .56605 Mdot
.50994 .34269 Mdot
.56003 .60309 Mdot
.50871 .64988 Mdot
.58784 .65137 Mdot
.54589 .32215 Mdot
.74122 .35392 Mdot
.37895 .41286 Mdot
.52809 .28666 Mdot
.44999 .29705 Mdot
.34808 .35348 Mdot
.58019 .66385 Mdot
.32017 .51228 Mdot
.49652 .52837 Mdot
.5442 .66614 Mdot
.28051 .60231 Mdot
.58199 .6475 Mdot
.60518 .58671 Mdot
.60546 .62058 Mdot
.58099 .22981 Mdot
.74946 .37806 Mdot
.52799 .63327 Mdot
.65244 .67543 Mdot
.2905 .63907 Mdot
.55278 .36579 Mdot
.5055 .32434 Mdot
.35761 .39238 Mdot
.35582 .39816 Mdot
.54306 .26052 Mdot
.77109 .60018 Mdot
.627 .74569 Mdot
.54467 .59519 Mdot
.48442 .53468 Mdot
.63422 .43153 Mdot
.32492 .50339 Mdot
.68925 .41474 Mdot
.50542 .17269 Mdot
.40901 .61394 Mdot
.43565 .62066 Mdot
.36152 .31454 Mdot
.30123 .33803 Mdot
.48132 .53561 Mdot
.33742 .50513 Mdot
.56467 .63517 Mdot
.70538 .43594 Mdot
.28909 .63111 Mdot
.50665 .55491 Mdot
.56845 .83447 Mdot
.65591 .41995 Mdot
.39074 .71668 Mdot
.51807 .32062 Mdot
.32317 .33817 Mdot
.55282 .69149 Mdot
.54076 .63039 Mdot
.70816 .44676 Mdot
.56909 .67593 Mdot
.43244 .66678 Mdot
.55212 .70023 Mdot
.32658 .38706 Mdot
.37179 .4228 Mdot
.5291 .28239 Mdot
.37083 .32363 Mdot
.68378 .40788 Mdot
.83232 .42808 Mdot
.33725 .35341 Mdot
.60358 .60175 Mdot
.51222 .28102 Mdot
.32961 .47242 Mdot
.33687 .36105 Mdot
.33667 .52708 Mdot
.57135 .61117 Mdot
.34282 .3375 Mdot
.31926 .48823 Mdot
.45179 .60463 Mdot
.50943 .54461 Mdot
.27488 .68897 Mdot
.52155 .30519 Mdot
.66175 .46033 Mdot
.54996 .6718 Mdot
.49128 .53315 Mdot
.50927 .5562 Mdot
.37606 .69557 Mdot
.45203 .50269 Mdot
.48759 .54467 Mdot
.36005 .61388 Mdot
.31267 .46442 Mdot
.68493 .26725 Mdot
.44687 .55968 Mdot
.64132 .43531 Mdot
.53476 .65515 Mdot
.49055 .24784 Mdot
.52739 .31163 Mdot
.56305 .62801 Mdot
.5675 .21828 Mdot
.50974 .30125 Mdot
.57182 .63596 Mdot
.50864 .27402 Mdot
.68861 .44496 Mdot
.40883 .6582 Mdot
.64975 .42138 Mdot
.55973 .65903 Mdot
.50913 .27555 Mdot
.36095 .39051 Mdot
.66572 .44145 Mdot
.54872 .65434 Mdot
.54497 .605 Mdot
.48204 .52968 Mdot
.5496 .69925 Mdot
.58383 .33582 Mdot
.56331 .68772 Mdot
.32848 .31408 Mdot
.52045 .63016 Mdot
.39652 .50535 Mdot
.22796 .51104 Mdot
.70037 .42449 Mdot
.45271 .50347 Mdot
.33234 .36117 Mdot
.43865 .65723 Mdot
.394 .72418 Mdot
.55688 .64804 Mdot
.45722 .51083 Mdot
.35171 .71991 Mdot
.52638 .3406 Mdot
.59089 .66026 Mdot
.28994 .53374 Mdot
.33415 .37176 Mdot
.48401 .53682 Mdot
.50025 .60677 Mdot
.64705 .40397 Mdot
.51409 .62411 Mdot
.33998 .33942 Mdot
.64423 .43521 Mdot
.51699 .63808 Mdot
.56382 .35402 Mdot
.50318 .55711 Mdot
.54005 .33145 Mdot
.48095 .55569 Mdot
.57724 .67071 Mdot
.32152 .37307 Mdot
.66027 .4433 Mdot
.52316 .32428 Mdot
.68124 .40907 Mdot
.29538 .5973 Mdot
.37073 .71522 Mdot
.73142 .38656 Mdot
.33304 .46989 Mdot
.17514 .54469 Mdot
.53744 .29898 Mdot
.48736 .51281 Mdot
.29269 .30856 Mdot
.61567 .45457 Mdot
.34224 .37101 Mdot
.80906 .57447 Mdot
.32863 .3656 Mdot
.5138 .64821 Mdot
.34531 .38825 Mdot
.69359 .72458 Mdot
.57457 .62472 Mdot
.30693 .33051 Mdot
.42869 .49309 Mdot
.56627 .6127 Mdot
.67722 .45051 Mdot
.39503 .79642 Mdot
.75832 .59555 Mdot
.76488 .60712 Mdot
.32733 .35522 Mdot
.81452 .56259 Mdot
.56832 .70787 Mdot
.57078 .59475 Mdot
.6873 .43545 Mdot
.49219 .5175 Mdot
.30168 .49074 Mdot
.30547 .51203 Mdot
.2305 .56407 Mdot
.40521 .75635 Mdot
.77954 .61041 Mdot
.675 .44586 Mdot
.36681 .41915 Mdot
.70186 .35744 Mdot
.50213 .55354 Mdot
.52764 .32268 Mdot
.73235 .33864 Mdot
.58995 .6503 Mdot
.46858 .53607 Mdot
.43313 .66982 Mdot
.65675 .45435 Mdot
.73777 .42183 Mdot
.52472 .32374 Mdot
.76393 .61027 Mdot
.62364 .73601 Mdot
.55641 .62854 Mdot
.5311 .3095 Mdot
.50938 .55597 Mdot
.44694 .57169 Mdot
.31729 .71895 Mdot
.28322 .2818 Mdot
.56126 .6555 Mdot
.70429 .33668 Mdot
.54775 .6694 Mdot
.30908 .69805 Mdot
.56668 .63676 Mdot
.66441 .44931 Mdot
.58105 .70372 Mdot
.45206 .56074 Mdot
.16201 .42918 Mdot
.40616 .60787 Mdot
.33379 .52505 Mdot
.54856 .63975 Mdot
.54935 .62252 Mdot
.33516 .48441 Mdot
.66968 .45941 Mdot
.53898 .66883 Mdot
.7024 .27635 Mdot
.55125 .65927 Mdot
.50751 .33973 Mdot
.36582 .67225 Mdot
.3521 .75938 Mdot
.56441 .70575 Mdot
.64501 .40489 Mdot
.53927 .33511 Mdot
.51174 .28521 Mdot
.46549 .50502 Mdot
.52734 .30991 Mdot
.56372 .67395 Mdot
.36498 .67365 Mdot
.65267 .4696 Mdot
.50323 .55188 Mdot
.65995 .455 Mdot
.23608 .35522 Mdot
.52147 .30785 Mdot
.47248 .51839 Mdot
.77975 .58745 Mdot
.50522 .30747 Mdot
.36789 .44439 Mdot
.57938 .70843 Mdot
.50588 .55514 Mdot
.6664 .40378 Mdot
.32564 .37683 Mdot
.46977 .52756 Mdot
.52107 .32314 Mdot
.55848 .64861 Mdot
.53037 .67996 Mdot
.52782 .3091 Mdot
.65992 .52563 Mdot
.44223 .57497 Mdot
.55679 .66268 Mdot
.68118 .45349 Mdot
.66552 .42102 Mdot
.53029 .58886 Mdot
.54607 .67011 Mdot
.36114 .38123 Mdot
.4565 .51012 Mdot
.45489 .51035 Mdot
.44386 .50115 Mdot
.32439 .34693 Mdot
.16323 .52597 Mdot
.52895 .34509 Mdot
.35614 .76389 Mdot
.63129 .35121 Mdot
.48948 .52889 Mdot
.36662 .37481 Mdot
.53901 .62409 Mdot
.55105 .68566 Mdot
.50189 .27889 Mdot
.21395 .63677 Mdot
.56964 .59487 Mdot
.65011 .42268 Mdot
.53256 .31772 Mdot
.51339 .6645 Mdot
.51294 .242 Mdot
.30707 .49136 Mdot
.78538 .60722 Mdot
.53182 .32215 Mdot
.69387 .46678 Mdot
.53194 .32292 Mdot
.55045 .62425 Mdot
.50077 .60337 Mdot
.65123 .44864 Mdot
.34518 .5244 Mdot
.53159 .66507 Mdot
.57141 .64018 Mdot
.4299 .35077 Mdot
.69226 .35679 Mdot
.3451 .53109 Mdot
.55091 .68162 Mdot
.47068 .50003 Mdot
.34708 .52016 Mdot
.56399 .66765 Mdot
.52039 .64544 Mdot
.58835 .57954 Mdot
.48696 .31497 Mdot
.34527 .48446 Mdot
.15228 .45666 Mdot
.65651 .41848 Mdot
.58325 .34206 Mdot
.47781 .53762 Mdot
.53664 .29871 Mdot
.44673 .68778 Mdot
.46996 .52241 Mdot
.65471 .33172 Mdot
.84481 .63803 Mdot
.46858 .52543 Mdot
.36949 .36099 Mdot
.70939 .69303 Mdot
.52173 .64781 Mdot
.55903 .66325 Mdot
.30219 .48601 Mdot
.67631 .42381 Mdot
.74872 .37615 Mdot
.52666 .28466 Mdot
.53484 .63533 Mdot
.68206 .4051 Mdot
.58949 .23093 Mdot
.47759 .5276 Mdot
.3116 .50622 Mdot
.34483 .48891 Mdot
.55466 .66925 Mdot
.36898 .73239 Mdot
.66699 .44391 Mdot
.54887 .65428 Mdot
.57665 .65162 Mdot
.37074 .38272 Mdot
.70293 .43077 Mdot
.34617 .34163 Mdot
.50246 .56366 Mdot
.73916 .69392 Mdot
.45597 .28365 Mdot
.51331 .29957 Mdot
.46317 .50804 Mdot
.5286 .28139 Mdot
.28968 .32742 Mdot
.45587 .50976 Mdot
.5481 .65265 Mdot
.65753 .47281 Mdot
.5498 .65548 Mdot
.55214 .65952 Mdot
.56186 .64788 Mdot
.78047 .61098 Mdot
.39223 .4063 Mdot
.31705 .51255 Mdot
.5744 .68081 Mdot
.33282 .33795 Mdot
.5132 .23847 Mdot
.66084 .72524 Mdot
.54449 .63686 Mdot
.5746 .64325 Mdot
.63927 .41057 Mdot
.54537 .69737 Mdot
.50995 .30544 Mdot
.65475 .4536 Mdot
.53887 .68293 Mdot
.41829 .36908 Mdot
.54313 .67276 Mdot
.73704 .40117 Mdot
.50591 .33532 Mdot
.53403 .70503 Mdot
.52089 .55763 Mdot
.45507 .50766 Mdot
.47167 .52883 Mdot
.44325 .50233 Mdot
.50552 .33948 Mdot
.36844 .36091 Mdot
.31777 .29707 Mdot
.52804 .57368 Mdot
.56179 .67742 Mdot
.49941 .60485 Mdot
.3644 .33871 Mdot
.42092 .49465 Mdot
.80074 .57549 Mdot
.52125 .67922 Mdot
.31755 .34152 Mdot
.43519 .49517 Mdot
.62417 .52203 Mdot
.66321 .45965 Mdot
.31108 .37271 Mdot
.50373 .28599 Mdot
.31643 .48651 Mdot
.24842 .62057 Mdot
.65527 .43028 Mdot
.62741 .4364 Mdot
.35835 .36073 Mdot
.35512 .68326 Mdot
.79556 .29667 Mdot
.3499 .37693 Mdot
.43403 .6349 Mdot
.68507 .44029 Mdot
.50411 .52445 Mdot
.34592 .71151 Mdot
.35794 .67203 Mdot
.31094 .3387 Mdot
.54358 .60499 Mdot
.24669 .32514 Mdot
.36018 .38391 Mdot
.48197 .51389 Mdot
.32722 .35293 Mdot
.5341 .3379 Mdot
.34861 .36685 Mdot
.7021 .4062 Mdot
.53 .61714 Mdot
.79791 .30662 Mdot
.34476 .63322 Mdot
.53063 .62604 Mdot
.52356 .33891 Mdot
.55204 .36131 Mdot
.55822 .62638 Mdot
.30589 .50845 Mdot
.36853 .35814 Mdot
.30156 .38786 Mdot
.51256 .63461 Mdot
.34137 .38699 Mdot
.6288 .41921 Mdot
.33196 .40757 Mdot
.42245 .3784 Mdot
.46388 .52213 Mdot
.69263 .44193 Mdot
.57111 .31346 Mdot
.54064 .30662 Mdot
.51281 .56135 Mdot
.57883 .65724 Mdot
.69367 .44896 Mdot
.44341 .63791 Mdot
.59471 .62061 Mdot
.54928 .65796 Mdot
.34945 .3474 Mdot
.30989 .36324 Mdot
.37716 .64991 Mdot
.33615 .35077 Mdot
.47866 .51124 Mdot
.68698 .45034 Mdot
.51266 .62631 Mdot
.66461 .41879 Mdot
.53571 .65783 Mdot
.51372 .24551 Mdot
.68192 .46139 Mdot
.6037 .60246 Mdot
.55031 .6024 Mdot
.80725 .46165 Mdot
.57705 .68052 Mdot
.55487 .66222 Mdot
.32712 .38557 Mdot
.33664 .48811 Mdot
.57793 .59354 Mdot
.52561 .24617 Mdot
.31996 .48009 Mdot
.64497 .53343 Mdot
.35621 .40229 Mdot
.33285 .47563 Mdot
.22925 .58374 Mdot
.45182 .50403 Mdot
.34449 .51002 Mdot
.49709 .60339 Mdot
.5157 .29861 Mdot
.67247 .47622 Mdot
.56515 .61069 Mdot
.7312 .6986 Mdot
.4422 .57016 Mdot
.47934 .52647 Mdot
.56384 .66434 Mdot
.54271 .61928 Mdot
.68146 .40535 Mdot
.5077 .17497 Mdot
.29731 .31612 Mdot
.50351 .53272 Mdot
.65653 .4244 Mdot
.521 .18299 Mdot
.30895 .33037 Mdot
.30848 .4711 Mdot
.5186 .27326 Mdot
.72836 .43998 Mdot
.48464 .52883 Mdot
.52355 .30993 Mdot
.33126 .30826 Mdot
.28121 .59711 Mdot
.51478 .62375 Mdot
.36406 .35789 Mdot
.28228 .60726 Mdot
.58169 .70799 Mdot
.54543 .26173 Mdot
.53961 .36816 Mdot
.70126 .44742 Mdot
.52889 .31021 Mdot
.31665 .5157 Mdot
.63774 .44303 Mdot
.66104 .45639 Mdot
.50545 .30262 Mdot
.83238 .50599 Mdot
.3522 .71901 Mdot
.50466 .26994 Mdot
.38175 .68811 Mdot
.28284 .60461 Mdot
.48567 .53157 Mdot
.31666 .50944 Mdot
.374 .42298 Mdot
.66175 .43932 Mdot
.72933 .34089 Mdot
.28185 .60919 Mdot
.57554 .70351 Mdot
.32053 .48616 Mdot
.59252 .23611 Mdot
.5522 .30382 Mdot
.51575 .30581 Mdot
.43084 .34884 Mdot
.32756 .48202 Mdot
.55597 .59929 Mdot
.22395 .68041 Mdot
.57712 .63378 Mdot
.50833 .2982 Mdot
.43286 .66863 Mdot
.6889 .41862 Mdot
.5192 .34406 Mdot
.432 .66703 Mdot
.5525 .68318 Mdot
.53782 .61533 Mdot
.39773 .40089 Mdot
.70127 .45428 Mdot
.50113 .5551 Mdot
.52964 .63015 Mdot
.56894 .62888 Mdot
.51438 .54973 Mdot
.34398 .74867 Mdot
.55329 .47905 Mdot
.51042 .53437 Mdot
.32396 .32982 Mdot
.50659 .55182 Mdot
.50232 .53104 Mdot
.65982 .40215 Mdot
.41265 .39503 Mdot
.49616 .55196 Mdot
.56332 .6585 Mdot
.55896 .66058 Mdot
.51551 .27246 Mdot
.35087 .71867 Mdot
.35355 .67795 Mdot
.30948 .31029 Mdot
.28507 .50416 Mdot
.53319 .60221 Mdot
.69737 .43874 Mdot
.35701 .50806 Mdot
.46896 .50475 Mdot
.64997 .42445 Mdot
.52553 .62302 Mdot
.37226 .37932 Mdot
.4634 .51947 Mdot
.46385 .49476 Mdot
.32143 .49165 Mdot
.53108 .28129 Mdot
.6418 .52381 Mdot
.36458 .38081 Mdot
.54627 .69349 Mdot
.28523 .51675 Mdot
.33848 .38157 Mdot
.48587 .5332 Mdot
.5069 .54862 Mdot
.6845 .44611 Mdot
.70462 .45836 Mdot
.39407 .51067 Mdot
.32624 .3429 Mdot
.32116 .27119 Mdot
.53756 .31828 Mdot
.57541 .67518 Mdot
.54201 .29908 Mdot
.70844 .43394 Mdot
.31573 .71031 Mdot
.34002 .48195 Mdot
.51111 .30345 Mdot
.50296 .55353 Mdot
.66873 .4618 Mdot
.7098 .43561 Mdot
.55615 .65609 Mdot
.5445 .64536 Mdot
.3052 .36923 Mdot
.29052 .64743 Mdot
.50232 .27751 Mdot
.30805 .47746 Mdot
.3075 .3125 Mdot
.51689 .65394 Mdot
.6956 .42783 Mdot
.30801 .74796 Mdot
.57747 .67307 Mdot
.3314 .33973 Mdot
.67336 .43391 Mdot
.30293 .48804 Mdot
.32154 .51684 Mdot
.53245 .6439 Mdot
.59461 .57734 Mdot
.50297 .30804 Mdot
.67342 .4509 Mdot
.66511 .48694 Mdot
.57178 .68535 Mdot
.54601 .64106 Mdot
.58204 .70937 Mdot
.50211 .26857 Mdot
.51857 .58771 Mdot
.34262 .52451 Mdot
.69097 .41243 Mdot
.53267 .63875 Mdot
.32996 .48422 Mdot
.4505 .51588 Mdot
.46612 .51926 Mdot
.30871 .35095 Mdot
.30547 .50948 Mdot
.33357 .49217 Mdot
.31725 .47853 Mdot
.73184 .33778 Mdot
.49622 .59486 Mdot
.36487 .53369 Mdot
.544 .60392 Mdot
.28312 .60341 Mdot
.51415 .60631 Mdot
.53426 .33155 Mdot
.3193 .36985 Mdot
.55969 .63934 Mdot
.54609 .60371 Mdot
.63239 .51752 Mdot
.51145 .62017 Mdot
.53591 .59025 Mdot
.69098 .41823 Mdot
.64712 .48646 Mdot
.35526 .39565 Mdot
.5297 .19094 Mdot
.2689 .74729 Mdot
.55663 .59401 Mdot
.35776 .68092 Mdot
.67357 .46065 Mdot
.51742 .27299 Mdot
.37269 .695 Mdot
.54535 .30184 Mdot
.66778 .42352 Mdot
.51159 .64057 Mdot
.67123 .50832 Mdot
.32171 .48166 Mdot
.55226 .6271 Mdot
.49978 .31551 Mdot
.55348 .62766 Mdot
.5181 .34219 Mdot
.81294 .54696 Mdot
.33431 .67511 Mdot
.5785 .63203 Mdot
.51959 .62754 Mdot
.57416 .54244 Mdot
.54431 .64033 Mdot
.27835 .29547 Mdot
.67866 .43486 Mdot
.52977 .56627 Mdot
.51172 .64479 Mdot
.75461 .60035 Mdot
.57231 .65943 Mdot
.46177 .69986 Mdot
.56839 .62062 Mdot
.2058 .61137 Mdot
.5748 .61849 Mdot
.57955 .65105 Mdot
.51199 .33207 Mdot
.52238 .28334 Mdot
.61717 .43689 Mdot
.49552 .54873 Mdot
.58608 .23191 Mdot
.57259 .64237 Mdot
.29942 .32377 Mdot
.62027 .63095 Mdot
.33436 .48925 Mdot
.68515 .41147 Mdot
.88788 .58458 Mdot
.51583 .34723 Mdot
.34133 .33344 Mdot
.44035 .5958 Mdot
.33178 .33071 Mdot
.29795 .34711 Mdot
.70157 .48326 Mdot
.31545 .508 Mdot
.54301 .67128 Mdot
.74904 .57784 Mdot
.68977 .35176 Mdot
.57073 .68567 Mdot
.36931 .33808 Mdot
.58813 .58255 Mdot
.39501 .54673 Mdot
.30729 .46471 Mdot
.32972 .50628 Mdot
.52216 .31921 Mdot
.30247 .32171 Mdot
.50349 .53577 Mdot
.33393 .47585 Mdot
.35124 .3936 Mdot
.45672 .50399 Mdot
.40568 .4034 Mdot
.66718 .44507 Mdot
.81324 .56592 Mdot
.78775 .4864 Mdot
.54178 .32703 Mdot
.52793 .2457 Mdot
.66302 .47537 Mdot
.6452 .42637 Mdot
.49259 .54352 Mdot
.31625 .34468 Mdot
.68209 .47467 Mdot
.53116 .63813 Mdot
.50551 .55154 Mdot
.55233 .67039 Mdot
.3089 .46639 Mdot
.56894 .66018 Mdot
.34844 .39135 Mdot
.51127 .33368 Mdot
.33303 .36883 Mdot
.52414 .31592 Mdot
.37024 .77851 Mdot
.54984 .60018 Mdot
.54793 .64304 Mdot
.36427 .67363 Mdot
.705 .42551 Mdot
.7406 .59513 Mdot
.32853 .34326 Mdot
.32934 .36167 Mdot
.51062 .63961 Mdot
.64273 .45358 Mdot
.31947 .53429 Mdot
.38553 .67827 Mdot
.57094 .62509 Mdot
.67925 .43333 Mdot
.50782 .62405 Mdot
.58242 .2805 Mdot
.34423 .65129 Mdot
.70228 .41712 Mdot
.16376 .42384 Mdot
.55623 .6025 Mdot
.48969 .51353 Mdot
.58181 .58441 Mdot
.37951 .74702 Mdot
.59168 .61187 Mdot
.65427 .42126 Mdot
.50551 .53871 Mdot
.69526 .43211 Mdot
.34215 .38081 Mdot
.51981 .34509 Mdot
.69021 .43147 Mdot
.56041 .60928 Mdot
.2689 .74631 Mdot
.50253 .32888 Mdot
.55303 .63159 Mdot
.49722 .31393 Mdot
.71326 .46271 Mdot
.68163 .41956 Mdot
.45716 .50403 Mdot
.43418 .63253 Mdot
.50622 .30465 Mdot
.56443 .67655 Mdot
.72378 .35184 Mdot
.51425 .62245 Mdot
.28814 .49532 Mdot
.5252 .60817 Mdot
.52493 .62255 Mdot
.15158 .50735 Mdot
.442 .6559 Mdot
.46653 .26626 Mdot
.474 .28217 Mdot
.74323 .35644 Mdot
.66938 .40145 Mdot
.30396 .47078 Mdot
.62263 .49971 Mdot
.45287 .5094 Mdot
.32155 .32881 Mdot
.55947 .64506 Mdot
.44224 .50535 Mdot
.49747 .27779 Mdot
.34309 .50801 Mdot
.58199 .64769 Mdot
.34845 .32953 Mdot
.45247 .49506 Mdot
.52021 .30813 Mdot
.66036 .43855 Mdot
.67861 .41482 Mdot
.38989 .41771 Mdot
.53212 .63613 Mdot
.5459 .64882 Mdot
.49439 .31373 Mdot
.60129 .60765 Mdot
.31201 .48114 Mdot
.42833 .49315 Mdot
.49707 .30851 Mdot
.34232 .65235 Mdot
.70235 .45382 Mdot
.54065 .62139 Mdot
.36845 .66841 Mdot
.74779 .36909 Mdot
.67043 .68232 Mdot
.32768 .50133 Mdot
.38616 .7266 Mdot
.65458 .42117 Mdot
.50874 .32557 Mdot
.22928 .57189 Mdot
.57853 .71126 Mdot
.55019 .6159 Mdot
.39176 .73116 Mdot
.38583 .68008 Mdot
.44075 .59856 Mdot
.50424 .55571 Mdot
.34659 .70411 Mdot
.50939 .634 Mdot
.53329 .68208 Mdot
.53586 .60101 Mdot
.52391 .61001 Mdot
.68371 .42822 Mdot
.7594 .61708 Mdot
.35482 .36228 Mdot
.66354 .65821 Mdot
.29489 .4698 Mdot
.57378 .701 Mdot
.54132 .68093 Mdot
.65943 .58947 Mdot
.41313 .71102 Mdot
.67699 .44104 Mdot
.68192 .39916 Mdot
.54333 .31977 Mdot
.51377 .61794 Mdot
.32899 .34106 Mdot
.55461 .57595 Mdot
.3177 .36401 Mdot
.68147 .42885 Mdot
.36662 .39259 Mdot
.5288 .35074 Mdot
.36379 .35683 Mdot
.31863 .33656 Mdot
.51815 .33681 Mdot
.6889 .46175 Mdot
.5786 .67881 Mdot
.51902 .33727 Mdot
.33448 .5357 Mdot
.30604 .47153 Mdot
.62663 .46236 Mdot
.507 .52792 Mdot
.58926 .64522 Mdot
.34231 .26329 Mdot
.35802 .34604 Mdot
.40797 .68451 Mdot
.68908 .45999 Mdot
.3476 .48375 Mdot
.69031 .42783 Mdot
.38422 .51883 Mdot
.32674 .49696 Mdot
.4962 .60744 Mdot
.26411 .65756 Mdot
.5241 .36656 Mdot
.58636 .67485 Mdot
.64826 .4863 Mdot
.31869 .36401 Mdot
.52182 .34056 Mdot
.54362 .22826 Mdot
.50392 .53251 Mdot
.62334 .42615 Mdot
.72197 .44013 Mdot
.45409 .50981 Mdot
.50654 .32334 Mdot
.79344 .47382 Mdot
.53146 .62852 Mdot
.54395 .30633 Mdot
.52563 .60825 Mdot
.7964 .59738 Mdot
.28972 .45791 Mdot
.43955 .50403 Mdot
.51303 .64649 Mdot
.3095 .32996 Mdot
.51104 .6404 Mdot
.74809 .67133 Mdot
.29677 .68201 Mdot
.54267 .59806 Mdot
.40484 .71155 Mdot
.28833 .3193 Mdot
.69794 .43033 Mdot
.48218 .52011 Mdot
.48326 .52983 Mdot
.53152 .68462 Mdot
.37523 .83758 Mdot
.34083 .4911 Mdot
.39448 .34231 Mdot
.55691 .60691 Mdot
.54392 .65497 Mdot
.63741 .52514 Mdot
.81098 .54768 Mdot
.44728 .4925 Mdot
.55489 .61719 Mdot
.41 .73487 Mdot
.51915 .33087 Mdot
.5172 .6328 Mdot
.54925 .66705 Mdot
.32408 .40485 Mdot
.51072 .33018 Mdot
.36708 .38421 Mdot
.45165 .50508 Mdot
.31623 .37111 Mdot
.34613 .52557 Mdot
.39182 .71799 Mdot
.32989 .72987 Mdot
.35165 .64986 Mdot
.31018 .51475 Mdot
.56103 .70516 Mdot
.48744 .56126 Mdot
.53722 .61069 Mdot
.33237 .50788 Mdot
.49704 .29257 Mdot
.68205 .43329 Mdot
.80704 .58335 Mdot
.48408 .53252 Mdot
.56443 .69785 Mdot
.3205 .45763 Mdot
.6912 .43626 Mdot
.81801 .44723 Mdot
.67781 .42466 Mdot
.51702 .31026 Mdot
.54204 .25811 Mdot
.32751 .49157 Mdot
.69078 .42754 Mdot
.32359 .3804 Mdot
.55315 .27614 Mdot
.56986 .7178 Mdot
.52754 .35093 Mdot
.71665 .43643 Mdot
.7013 .41241 Mdot
.64623 .46554 Mdot
.5187 .66146 Mdot
.40672 .70237 Mdot
.46589 .50819 Mdot
.49773 .32241 Mdot
.33246 .32462 Mdot
.2919 .65554 Mdot
.75283 .51366 Mdot
.34169 .66694 Mdot
.49792 .60817 Mdot
.56792 .66058 Mdot
.55646 .66832 Mdot
.51527 .54762 Mdot
.47057 .55764 Mdot
.54499 .60075 Mdot
.50157 .27889 Mdot
.35088 .38661 Mdot
.56275 .61612 Mdot
.46424 .51445 Mdot
.4261 .50971 Mdot
.34941 .49081 Mdot
.78669 .60959 Mdot
.62523 .46268 Mdot
.68983 .43505 Mdot
.34014 .34037 Mdot
.35913 .40421 Mdot
.33158 .47218 Mdot
.52933 .31897 Mdot
.67495 .42337 Mdot
.20431 .60185 Mdot
.316 .48262 Mdot
.56448 .65674 Mdot
.36521 .67251 Mdot
.40601 .7459 Mdot
.5271 .65966 Mdot
.56277 .64758 Mdot
.49461 .54984 Mdot
.32852 .33853 Mdot
.66064 .7378 Mdot
.81311 .45374 Mdot
.33071 .48691 Mdot
.31709 .47164 Mdot
.64112 .45885 Mdot
.57392 .67007 Mdot
.50143 .30854 Mdot
.3546 .7233 Mdot
.56234 .3584 Mdot
.61429 .24281 Mdot
.29018 .30309 Mdot
.54491 .67393 Mdot
.73026 .65876 Mdot
.58363 .61925 Mdot
.70848 .46805 Mdot
.68796 .46808 Mdot
.67561 .44411 Mdot
.52177 .32937 Mdot
.28338 .59315 Mdot
.52644 .29143 Mdot
.43471 .49463 Mdot
.65147 .43786 Mdot
.44038 .63054 Mdot
.32872 .35919 Mdot
.51301 .61132 Mdot
.32033 .50986 Mdot
.28021 .53878 Mdot
.48823 .52553 Mdot
.38797 .72361 Mdot
.36664 .37444 Mdot
.66085 .46186 Mdot
.51162 .61249 Mdot
.5079 .24143 Mdot
.33932 .68663 Mdot
.28272 .31039 Mdot
.44217 .50612 Mdot
.32593 .48442 Mdot
.63986 .73186 Mdot
.31054 .48862 Mdot
.51004 .30262 Mdot
.55011 .60148 Mdot
.57523 .66625 Mdot
.55424 .66319 Mdot
.54422 .59344 Mdot
.52007 .32545 Mdot
.58368 .68424 Mdot
.39699 .50747 Mdot
.44627 .50192 Mdot
.4512 .55172 Mdot
.33019 .5196 Mdot
.53731 .32198 Mdot
.34327 .38468 Mdot
.48635 .54399 Mdot
.34122 .47478 Mdot
.51042 .60256 Mdot
.55114 .60756 Mdot
.44418 .49524 Mdot
.49824 .60079 Mdot
.58969 .6385 Mdot
.35941 .37093 Mdot
.44621 .56576 Mdot
.34983 .49538 Mdot
.31879 .50239 Mdot
.52522 .30441 Mdot
.69144 .42807 Mdot
.34279 .48217 Mdot
.3287 .3155 Mdot
.5164 .63134 Mdot
.52741 .60525 Mdot
.71418 .4282 Mdot
.28092 .60486 Mdot
.34982 .4915 Mdot
.52167 .58756 Mdot
.69873 .41573 Mdot
.72254 .44084 Mdot
.55296 .61759 Mdot
.58113 .69259 Mdot
.65811 .40345 Mdot
.31817 .46903 Mdot
.53041 .30782 Mdot
.32982 .63749 Mdot
.53039 .3431 Mdot
.65937 .44111 Mdot
.50349 .54482 Mdot
.67721 .46434 Mdot
.50458 .53355 Mdot
.67836 .24546 Mdot
.543 .60081 Mdot
.7491 .44757 Mdot
.41685 .49654 Mdot
.32659 .35544 Mdot
.32051 .35335 Mdot
.45979 .51487 Mdot
.64672 .43092 Mdot
.47782 .51146 Mdot
.30944 .50149 Mdot
.74148 .3558 Mdot
.65945 .40198 Mdot
.31769 .33812 Mdot
.35644 .34157 Mdot
.4966 .31016 Mdot
.56992 .66078 Mdot
.53975 .62116 Mdot
.36524 .36037 Mdot
.57378 .35068 Mdot
.69675 .45199 Mdot
.54635 .6489 Mdot
.51167 .53854 Mdot
.35631 .36741 Mdot
.48968 .36098 Mdot
.67412 .47532 Mdot
.51653 .65796 Mdot
.30138 .69108 Mdot
.51452 .34294 Mdot
.5513 .69072 Mdot
.58598 .67915 Mdot
.33859 .49484 Mdot
.38624 .72974 Mdot
.28399 .61165 Mdot
.51779 .34862 Mdot
.45701 .50745 Mdot
.53033 .66558 Mdot
.32449 .35838 Mdot
.52011 .59527 Mdot
.73446 .74583 Mdot
.44654 .49883 Mdot
.53336 .63493 Mdot
.56439 .57961 Mdot
.66455 .41854 Mdot
.54561 .65345 Mdot
.51395 .24635 Mdot
.34345 .34628 Mdot
.53269 .63165 Mdot
.58522 .55379 Mdot
.49757 .31319 Mdot
.48708 .5249 Mdot
.32507 .48195 Mdot
.43785 .61727 Mdot
.39245 .79477 Mdot
.36448 .33926 Mdot
.33334 .52201 Mdot
.57337 .65485 Mdot
.3039 .31401 Mdot
.52549 .28582 Mdot
.47294 .51463 Mdot
.55211 .69447 Mdot
.54111 .31674 Mdot
.52138 .33341 Mdot
.32457 .4898 Mdot
.83731 .38801 Mdot
.56008 .5976 Mdot
.54756 .63002 Mdot
.83182 .42041 Mdot
.72189 .40712 Mdot
.55418 .63057 Mdot
.57714 .65427 Mdot
.52191 .30536 Mdot
.2789 .58358 Mdot
.38771 .72512 Mdot
.43513 .50871 Mdot
.52584 .33961 Mdot
.31431 .30332 Mdot
.35364 .34791 Mdot
.33837 .52184 Mdot
.67244 .43361 Mdot
.33181 .47048 Mdot
.34875 .36262 Mdot
.55985 .65685 Mdot
.52034 .29448 Mdot
.60443 .75068 Mdot
.50945 .33812 Mdot
.34252 .32296 Mdot
.71048 .46628 Mdot
.70163 .72052 Mdot
.7534 .73349 Mdot
.54648 .47167 Mdot
.54823 .26383 Mdot
.33485 .48947 Mdot
.81383 .45264 Mdot
.56603 .61898 Mdot
.74728 .66533 Mdot
.55043 .62758 Mdot
.43635 .48726 Mdot
.3296 .37983 Mdot
.45689 .50405 Mdot
.50347 .53102 Mdot
.39248 .72219 Mdot
.5256 .33148 Mdot
.49962 .29245 Mdot
.5071 .54403 Mdot
.51298 .30819 Mdot
.53619 .63026 Mdot
.35587 .38001 Mdot
.73496 .29248 Mdot
.56657 .61745 Mdot
.52739 .56411 Mdot
.54829 .33564 Mdot
.72229 .37499 Mdot
.32374 .3058 Mdot
.74033 .63586 Mdot
.57428 .22665 Mdot
.50299 .31078 Mdot
.7825 .6121 Mdot
.33662 .34055 Mdot
.487 .54453 Mdot
.29863 .31732 Mdot
.54442 .62624 Mdot
.54596 .67495 Mdot
.51617 .55463 Mdot
.57547 .64975 Mdot
.70798 .67445 Mdot
.58977 .66781 Mdot
.62994 .57329 Mdot
.54267 .60426 Mdot
.69562 .49351 Mdot
.51601 .27858 Mdot
.50629 .54573 Mdot
.34979 .60965 Mdot
.52784 .61781 Mdot
.66772 .40322 Mdot
.53826 .32788 Mdot
.55548 .21513 Mdot
.51915 .32858 Mdot
.33121 .36815 Mdot
.52783 .32378 Mdot
.58169 .68389 Mdot
.66254 .42574 Mdot
.33986 .35927 Mdot
.48785 .52853 Mdot
.32428 .32418 Mdot
.53064 .62646 Mdot
.45436 .34094 Mdot
.34326 .33519 Mdot
.58058 .70819 Mdot
.66517 .42265 Mdot
.28645 .71447 Mdot
.65881 .47709 Mdot
.55417 .64903 Mdot
.55542 .64043 Mdot
.44351 .49175 Mdot
.52699 .31591 Mdot
.68131 .46472 Mdot
.43124 .34562 Mdot
.34762 .4834 Mdot
.67249 .43916 Mdot
.59558 .59492 Mdot
.35549 .68485 Mdot
.68483 .40892 Mdot
.40917 .74037 Mdot
.50956 .3003 Mdot
.66126 .41645 Mdot
.61485 .647 Mdot
.66111 .65969 Mdot
.31394 .49815 Mdot
.32358 .38129 Mdot
.36363 .69286 Mdot
.35004 .34532 Mdot
.51022 .24516 Mdot
.32496 .38502 Mdot
.50243 .32488 Mdot
.59788 .59042 Mdot
.43289 .66732 Mdot
.49049 .31324 Mdot
.4461 .32912 Mdot
.35198 .35522 Mdot
.50772 .53348 Mdot
.44897 .55797 Mdot
.46754 .49623 Mdot
.48412 .50854 Mdot
.51373 .34628 Mdot
.65963 .41666 Mdot
.639 .44493 Mdot
.55251 .57356 Mdot
.68699 .41549 Mdot
.34633 .37391 Mdot
.36131 .64824 Mdot
.7795 .58728 Mdot
.50642 .27904 Mdot
.44463 .57283 Mdot
.53863 .68022 Mdot
.34309 .38853 Mdot
.34466 .37619 Mdot
.52334 .33096 Mdot
.68048 .64055 Mdot
.47409 .50372 Mdot
.7336 .43675 Mdot
.65414 .43092 Mdot
.66465 .4176 Mdot
.70713 .43986 Mdot
.28127 .59405 Mdot
.52479 .33877 Mdot
.64822 .4298 Mdot
.54161 .59316 Mdot
.57295 .66376 Mdot
.47741 .5348 Mdot
.30925 .46752 Mdot
.58857 .6715 Mdot
.47684 .51031 Mdot
.55066 .61753 Mdot
.32733 .35162 Mdot
.61978 .6241 Mdot
.45072 .50998 Mdot
.32783 .3407 Mdot
.32539 .34617 Mdot
.45476 .50704 Mdot
.61853 .62379 Mdot
.67286 .70904 Mdot
.53644 .69211 Mdot
.71395 .47517 Mdot
.31755 .3513 Mdot
.4311 .3679 Mdot
.74582 .45366 Mdot
.56617 .67391 Mdot
.4253 .49455 Mdot
.35175 .38183 Mdot
.67324 .39968 Mdot
.54333 .63426 Mdot
.49446 .54402 Mdot
.31394 .49111 Mdot
.4829 .52365 Mdot
.49529 .55001 Mdot
.70121 .43831 Mdot
.33375 .26967 Mdot
.68313 .40519 Mdot
.35538 .40897 Mdot
.49484 .53245 Mdot
.79629 .30091 Mdot
.32145 .36653 Mdot
.73857 .35055 Mdot
.43232 .66251 Mdot
.54476 .61171 Mdot
.34218 .34193 Mdot
.63367 .41377 Mdot
.50307 .33974 Mdot
.41441 .70087 Mdot
.69129 .42539 Mdot
.48167 .5416 Mdot
.47617 .5316 Mdot
.35576 .36378 Mdot
.66036 .44937 Mdot
.58484 .68211 Mdot
.67566 .41582 Mdot
.51612 .28796 Mdot
.50452 .63191 Mdot
.5847 .23137 Mdot
.5031 .53747 Mdot
.6894 .41386 Mdot
.3342 .32319 Mdot
.34526 .524 Mdot
.57527 .62698 Mdot
.56308 .21585 Mdot
.57349 .6562 Mdot
.49548 .30252 Mdot
.41756 .51062 Mdot
.62803 .70591 Mdot
.56727 .64104 Mdot
.54596 .68258 Mdot
.52752 .35691 Mdot
.56611 .63622 Mdot
.523 .63812 Mdot
.79488 .47689 Mdot
.69091 .40994 Mdot
.56416 .6179 Mdot
.36379 .37083 Mdot
.6043 .55826 Mdot
.54024 .65528 Mdot
.52243 .24304 Mdot
.37596 .74157 Mdot
.40816 .50255 Mdot
.53901 .56773 Mdot
.31396 .70774 Mdot
.55271 .63626 Mdot
.56913 .67556 Mdot
.50363 .62817 Mdot
.73371 .66087 Mdot
.3477 .35669 Mdot
.30756 .32605 Mdot
.34071 .52425 Mdot
.39401 .73144 Mdot
.32029 .49758 Mdot
.52615 .28631 Mdot
.43819 .60508 Mdot
.44617 .50476 Mdot
.69316 .42919 Mdot
.55114 .66224 Mdot
.32382 .32083 Mdot
.5398 .62591 Mdot
.53631 .68722 Mdot
.34943 .37295 Mdot
.34572 .38069 Mdot
.36673 .41006 Mdot
.3265 .48002 Mdot
.6831 .43937 Mdot
.56792 .61018 Mdot
.3219 .47949 Mdot
.51503 .55016 Mdot
.32405 .64802 Mdot
.68053 .44119 Mdot
.69186 .41512 Mdot
.6461 .44789 Mdot
.58006 .64903 Mdot
.50637 .6422 Mdot
.53084 .29622 Mdot
.71426 .42816 Mdot
.50305 .30251 Mdot
.3437 .34178 Mdot
.35865 .38584 Mdot
.54508 .62559 Mdot
.59602 .60118 Mdot
.32433 .51702 Mdot
.34899 .3377 Mdot
.47126 .53603 Mdot
.34767 .50776 Mdot
.54812 .67136 Mdot
.34732 .34277 Mdot
.30378 .50155 Mdot
.67771 .65312 Mdot
.60737 .27687 Mdot
.34478 .52066 Mdot
.49904 .52339 Mdot
.74001 .52735 Mdot
.29534 .67381 Mdot
.35483 .50382 Mdot
.51509 .27873 Mdot
.57871 .66976 Mdot
.44009 .51136 Mdot
.34758 .49212 Mdot
.282 .62557 Mdot
.3466 .36656 Mdot
.48657 .51145 Mdot
.54744 .48642 Mdot
.77696 .58906 Mdot
.34679 .52273 Mdot
.68944 .41302 Mdot
.71306 .44441 Mdot
.5659 .65279 Mdot
.43723 .6144 Mdot
.49648 .28188 Mdot
.35721 .40536 Mdot
.31083 .3225 Mdot
.69873 .46513 Mdot
.34843 .65005 Mdot
.36279 .36363 Mdot
.57459 .67442 Mdot
.30732 .4585 Mdot
.53364 .59095 Mdot
.3913 .52321 Mdot
.62173 .7106 Mdot
.56525 .57579 Mdot
.3456 .52268 Mdot
.49506 .28651 Mdot
.50953 .33226 Mdot
.52457 .31992 Mdot
.3606 .36557 Mdot
.3703 .69585 Mdot
.3081 .32011 Mdot
.83024 .43304 Mdot
.34128 .49112 Mdot
.17345 .53072 Mdot
.57226 .59856 Mdot
.54086 .61261 Mdot
.51576 .61771 Mdot
.51105 .5446 Mdot
.5519 .63735 Mdot
.54098 .31273 Mdot
.31798 .37201 Mdot
.53463 .37272 Mdot
.68302 .45345 Mdot
.81955 .44962 Mdot
.329 .35767 Mdot
.49912 .55562 Mdot
.32356 .51469 Mdot
.33064 .73569 Mdot
.30251 .51317 Mdot
.36969 .36823 Mdot
.52909 .6486 Mdot
.63788 .45501 Mdot
.20967 .62227 Mdot
.54816 .65771 Mdot
.35704 .34453 Mdot
.31595 .30812 Mdot
.66674 .64667 Mdot
.4963 .69751 Mdot
.55785 .3644 Mdot
.36632 .66521 Mdot
.3182 .52402 Mdot
.50752 .52561 Mdot
.36009 .73007 Mdot
.3499 .36218 Mdot
.30963 .34398 Mdot
.35371 .53014 Mdot
.71883 .37114 Mdot
.6473 .43864 Mdot
.66571 .48306 Mdot
.53859 .31148 Mdot
.54394 .60931 Mdot
.35193 .35102 Mdot
.6858 .47766 Mdot
.32851 .60069 Mdot
.51782 .31795 Mdot
.34262 .33376 Mdot
.5746 .65572 Mdot
.56852 .64306 Mdot
.32024 .49515 Mdot
.4221 .50691 Mdot
.46764 .49662 Mdot
.74016 .35454 Mdot
.34866 .67496 Mdot
.43169 .66157 Mdot
.55013 .61577 Mdot
.70583 .43838 Mdot
.45546 .50862 Mdot
.31605 .50948 Mdot
.52149 .59518 Mdot
.73086 .69573 Mdot
.68964 .40162 Mdot
.50374 .30438 Mdot
.48957 .53389 Mdot
.39621 .71498 Mdot
.57476 .65356 Mdot
.54991 .62755 Mdot
.51818 .6602 Mdot
.68748 .72854 Mdot
.31979 .37005 Mdot
.70184 .42746 Mdot
.32706 .48267 Mdot
.68007 .42032 Mdot
.34975 .41296 Mdot
.4438 .56672 Mdot
.58006 .63325 Mdot
.67912 .40155 Mdot
.67028 .42452 Mdot
.49598 .30095 Mdot
.51365 .33682 Mdot
.35308 .32391 Mdot
.57798 .65146 Mdot
.44368 .50014 Mdot
.65153 .42669 Mdot
.33844 .39612 Mdot
.32179 .4964 Mdot
.51935 .23984 Mdot
.54795 .60394 Mdot
.35275 .36009 Mdot
.48348 .51986 Mdot
.69019 .44749 Mdot
.33195 .34292 Mdot
.48807 .54549 Mdot
.3121 .47025 Mdot
.53991 .67386 Mdot
.28106 .3207 Mdot
.49665 .54752 Mdot
.57326 .62435 Mdot
.62925 .62692 Mdot
.43779 .61218 Mdot
.46499 .53145 Mdot
.35857 .39234 Mdot
.48853 .54038 Mdot
.7077 .45095 Mdot
.65597 .67422 Mdot
.3085 .34547 Mdot
.67338 .50681 Mdot
.43343 .67398 Mdot
.50514 .53687 Mdot
.69721 .42996 Mdot
.40214 .4073 Mdot
.6926 .36353 Mdot
.2965 .66867 Mdot
.53714 .64108 Mdot
.35043 .3458 Mdot
.31466 .4949 Mdot
.49995 .29274 Mdot
.51075 .25883 Mdot
.38722 .42941 Mdot
.32004 .34192 Mdot
.55051 .66264 Mdot
.65929 .41735 Mdot
.5069 .30587 Mdot
.64251 .52673 Mdot
.30753 .3142 Mdot
.36485 .3725 Mdot
.5161 .64881 Mdot
.32043 .49895 Mdot
.47858 .55855 Mdot
.30989 .35511 Mdot
.30775 .35623 Mdot
.79221 .47924 Mdot
.31627 .5224 Mdot
.52037 .66568 Mdot
.55702 .57483 Mdot
.519 .62019 Mdot
.8225 .44018 Mdot
.48632 .54198 Mdot
.68369 .45399 Mdot
.55838 .63577 Mdot
.29649 .28652 Mdot
.32779 .37482 Mdot
.36613 .66498 Mdot
.51973 .36614 Mdot
.52317 .33543 Mdot
.34223 .34854 Mdot
.54045 .63857 Mdot
.52966 .24633 Mdot
.33976 .51975 Mdot
.51314 .65147 Mdot
.5067 .54035 Mdot
.70951 .45754 Mdot
.52215 .29494 Mdot
.6007 .56521 Mdot
.50486 .28706 Mdot
.52689 .30829 Mdot
.66933 .38294 Mdot
.56569 .65393 Mdot
.33093 .35386 Mdot
.35577 .33626 Mdot
.51788 .54663 Mdot
.42103 .35245 Mdot
.65535 .45286 Mdot
.32243 .28886 Mdot
.72003 .70673 Mdot
.54144 .59619 Mdot
.50229 .55504 Mdot
.43563 .49274 Mdot
.54386 .25978 Mdot
.56506 .64176 Mdot
.69737 .43506 Mdot
.31104 .36037 Mdot
.35619 .35268 Mdot
.58015 .70805 Mdot
.51043 .33323 Mdot
.30248 .48059 Mdot
.34278 .37322 Mdot
.33403 .63524 Mdot
.53311 .63598 Mdot
.55086 .31502 Mdot
.34086 .37036 Mdot
.28434 .75238 Mdot
.30856 .27343 Mdot
.67542 .4107 Mdot
.54829 .68125 Mdot
.66852 .47419 Mdot
.33169 .52458 Mdot
.29732 .33595 Mdot
.49442 .30031 Mdot
.49211 .53128 Mdot
.51545 .20313 Mdot
.35763 .35944 Mdot
.6817 .42979 Mdot
.56054 .65211 Mdot
.7767 .61788 Mdot
.56833 .62077 Mdot
.27837 .58161 Mdot
.35077 .49587 Mdot
.49549 .25769 Mdot
.49474 .31459 Mdot
.55138 .68297 Mdot
.3146 .47908 Mdot
.36254 .342 Mdot
.34989 .37197 Mdot
.54521 .20213 Mdot
.49227 .54808 Mdot
.29534 .33834 Mdot
.57579 .63116 Mdot
.35206 .40534 Mdot
.75369 .51276 Mdot
.51938 .33513 Mdot
.51918 .62545 Mdot
.33555 .3317 Mdot
.7003 .36573 Mdot
.3618 .67344 Mdot
.53518 .63986 Mdot
.57899 .58576 Mdot
.50303 .32432 Mdot
.8161 .45484 Mdot
.33478 .38488 Mdot
.51132 .59385 Mdot
.54149 .30535 Mdot
.59767 .59093 Mdot
.54628 .37471 Mdot
.68299 .4398 Mdot
.35436 .33796 Mdot
.53043 .30661 Mdot
.49623 .52656 Mdot
.30411 .49829 Mdot
.32819 .31467 Mdot
.32729 .32791 Mdot
.5548 .70162 Mdot
.51314 .562 Mdot
.59476 .59798 Mdot
.6875 .4583 Mdot
.51718 .30127 Mdot
.53227 .68336 Mdot
.32085 .64905 Mdot
.50465 .61026 Mdot
.51853 .2994 Mdot
.80824 .3357 Mdot
.53036 .65463 Mdot
.54619 .60499 Mdot
.76989 .63145 Mdot
.66249 .46424 Mdot
.70924 .42841 Mdot
.33927 .67386 Mdot
.57154 .69939 Mdot
.44059 .63596 Mdot
.68449 .43627 Mdot
.67913 .4279 Mdot
.44052 .63421 Mdot
.55083 .6988 Mdot
.65419 .47868 Mdot
.50882 .30651 Mdot
.52178 .3364 Mdot
.66539 .41783 Mdot
.51587 .60859 Mdot
.51854 .27405 Mdot
.68636 .62746 Mdot
.36484 .35189 Mdot
.36814 .73093 Mdot
.67131 .42038 Mdot
.36541 .67569 Mdot
.51078 .3023 Mdot
.36721 .76808 Mdot
.38111 .74774 Mdot
.55593 .59479 Mdot
.56676 .6481 Mdot
.33593 .49386 Mdot
.48568 .5247 Mdot
.45354 .50732 Mdot
.52513 .31982 Mdot
.47022 .55778 Mdot
.67417 .44428 Mdot
.57561 .69172 Mdot
.29098 .65155 Mdot
.4089 .79864 Mdot
.57333 .74446 Mdot
.67336 .43214 Mdot
.66314 .43957 Mdot
.36539 .3842 Mdot
.36784 .39258 Mdot
.57258 .61548 Mdot
.50545 .32897 Mdot
.66617 .41439 Mdot
.51577 .29512 Mdot
.34963 .36361 Mdot
.33073 .36062 Mdot
.45672 .51693 Mdot
.48344 .5095 Mdot
.34255 .35518 Mdot
.52405 .2439 Mdot
.32139 .64908 Mdot
.71744 .44484 Mdot
.83372 .42717 Mdot
.35511 .7635 Mdot
.7999 .59378 Mdot
.31398 .49281 Mdot
.61964 .62793 Mdot
.54112 .30678 Mdot
.55146 .68372 Mdot
.55399 .62451 Mdot
.47694 .52709 Mdot
.54378 .311 Mdot
.33945 .51048 Mdot
.52156 .33529 Mdot
.30474 .49237 Mdot
.31015 .32775 Mdot
.54642 .65964 Mdot
.52774 .63359 Mdot
.49864 .29601 Mdot
.36814 .38013 Mdot
.33994 .33524 Mdot
.31204 .49988 Mdot
.33567 .73845 Mdot
.35473 .3638 Mdot
.67177 .42112 Mdot
.68529 .51268 Mdot
.47723 .53172 Mdot
.54347 .6355 Mdot
.31535 .71104 Mdot
.65197 .68029 Mdot
.51646 .55332 Mdot
.4887 .53383 Mdot
.83601 .38466 Mdot
.53195 .64147 Mdot
.51844 .18294 Mdot
.45106 .51169 Mdot
.67588 .46459 Mdot
.33368 .34962 Mdot
.49868 .55336 Mdot
.58143 .57696 Mdot
.28556 .46546 Mdot
.51754 .55914 Mdot
.64688 .43728 Mdot
.65124 .45536 Mdot
.4451 .56711 Mdot
.8266 .44429 Mdot
.32521 .48286 Mdot
.34268 .51221 Mdot
.31584 .36255 Mdot
.50744 .245 Mdot
.56152 .59145 Mdot
.34386 .50334 Mdot
.62726 .45585 Mdot
.52199 .66456 Mdot
.43981 .60464 Mdot
.44979 .55413 Mdot
.71009 .44248 Mdot
.5412 .70084 Mdot
.31994 .36744 Mdot
.68093 .43152 Mdot
.44776 .56212 Mdot
.51617 .63844 Mdot
.67845 .44268 Mdot
.52519 .30959 Mdot
.47624 .70522 Mdot
.67894 .41521 Mdot
.41486 .6972 Mdot
.50102 .31162 Mdot
.44216 .59307 Mdot
.20208 .54338 Mdot
.31992 .79286 Mdot
.51727 .33315 Mdot
.34762 .33804 Mdot
.35117 .35146 Mdot
.35708 .37258 Mdot
.70073 .44951 Mdot
.33916 .38034 Mdot
.66684 .45528 Mdot
.5501 .26676 Mdot
.39331 .72675 Mdot
.32746 .49417 Mdot
.41101 .38233 Mdot
.66774 .41723 Mdot
.82735 .43499 Mdot
.8529 .62911 Mdot
.50589 .59604 Mdot
.49077 .31519 Mdot
.34437 .49025 Mdot
.36848 .65821 Mdot
.33837 .49539 Mdot
.33712 .34039 Mdot
.39401 .71869 Mdot
.53642 .62765 Mdot
.59548 .26619 Mdot
.31549 .49645 Mdot
.67908 .4266 Mdot
.56742 .70788 Mdot
.37318 .38115 Mdot
.33428 .5232 Mdot
.31869 .5046 Mdot
.5504 .63693 Mdot
.66163 .46234 Mdot
.33701 .33741 Mdot
.54284 .32629 Mdot
.34884 .43516 Mdot
.60083 .63902 Mdot
.53546 .65064 Mdot
.53229 .60441 Mdot
.35599 .67941 Mdot
.51664 .23885 Mdot
.504 .31514 Mdot
.28472 .62347 Mdot
.34745 .39028 Mdot
.29222 .66598 Mdot
.70038 .35851 Mdot
.40213 .39676 Mdot
.48601 .54135 Mdot
.48401 .54192 Mdot
.54779 .65174 Mdot
.79454 .69273 Mdot
.48652 .6948 Mdot
.52223 .27763 Mdot
.47187 .52466 Mdot
.37126 .37493 Mdot
.70335 .41116 Mdot
.5269 .47709 Mdot
.58553 .62194 Mdot
.54322 .32605 Mdot
.353 .36962 Mdot
.72743 .75744 Mdot
.33379 .48468 Mdot
.36455 .65755 Mdot
.57706 .64893 Mdot
.54754 .64659 Mdot
.51539 .322 Mdot
.49626 .28973 Mdot
.79242 .48206 Mdot
.40365 .49927 Mdot
.58879 .23115 Mdot
.49904 .34325 Mdot
.72484 .76253 Mdot
.43742 .49474 Mdot
.6657 .4476 Mdot
.45651 .50614 Mdot
.49323 .29371 Mdot
.55593 .63206 Mdot
.66325 .46384 Mdot
.47095 .51311 Mdot
.6326 .4315 Mdot
.43724 .61954 Mdot
.33004 .6381 Mdot
.56877 .65951 Mdot
.65358 .46753 Mdot
.68036 .43593 Mdot
.72652 .4503 Mdot
.46358 .5209 Mdot
.55428 .61612 Mdot
.51225 .59268 Mdot
.53787 .60412 Mdot
.78092 .49335 Mdot
.54418 .65304 Mdot
.70553 .35857 Mdot
.33687 .66399 Mdot
.25796 .29483 Mdot
.52871 .62806 Mdot
.52981 .31556 Mdot
.55427 .65926 Mdot
.314 .47777 Mdot
.53194 .6653 Mdot
.43495 .63352 Mdot
.50858 .31047 Mdot
.74612 .67546 Mdot
.29771 .46559 Mdot
.53597 .65375 Mdot
.30881 .51312 Mdot
.72224 .32473 Mdot
.287 .62557 Mdot
.79113 .4762 Mdot
.6749 .41621 Mdot
.3001 .31975 Mdot
.49535 .28282 Mdot
.33043 .36655 Mdot
.57936 .70159 Mdot
.44923 .50296 Mdot
.16295 .52591 Mdot
.31851 .67014 Mdot
.55724 .63435 Mdot
.47279 .5006 Mdot
.69649 .41942 Mdot
.32447 .37127 Mdot
.81259 .54929 Mdot
.51458 .62568 Mdot
.32073 .46857 Mdot
.33316 .47763 Mdot
.29216 .53384 Mdot
.73566 .39818 Mdot
.76634 .49959 Mdot
.51371 .3208 Mdot
.36044 .36229 Mdot
.349 .4984 Mdot
.64074 .48269 Mdot
.49131 .30612 Mdot
.54298 .26008 Mdot
.52566 .29784 Mdot
.53319 .61616 Mdot
.46515 .52608 Mdot
.74854 .39895 Mdot
.4924 .54605 Mdot
.52219 .60658 Mdot
.32738 .32848 Mdot
.48875 .54462 Mdot
.33199 .49794 Mdot
.52937 .30803 Mdot
.32782 .35467 Mdot
.55579 .64507 Mdot
.68869 .43665 Mdot
.3982 .54058 Mdot
.28792 .33102 Mdot
.43758 .61129 Mdot
.43761 .61109 Mdot
.72262 .42767 Mdot
.44863 .52004 Mdot
.45114 .34237 Mdot
.66461 .65785 Mdot
.36974 .4246 Mdot
.58401 .59832 Mdot
.41023 .33815 Mdot
.30734 .31957 Mdot
.34085 .3622 Mdot
.53603 .6217 Mdot
.34622 .40121 Mdot
.58002 .66399 Mdot
.35795 .39357 Mdot
.74781 .36621 Mdot
.58801 .66917 Mdot
.34554 .37146 Mdot
.46652 .50752 Mdot
.57382 .6241 Mdot
.69968 .42632 Mdot
.30095 .32676 Mdot
.55557 .59466 Mdot
.20285 .3477 Mdot
.49631 .29996 Mdot
.46645 .524 Mdot
.38275 .63475 Mdot
.51735 .30702 Mdot
.65163 .44474 Mdot
.57689 .67726 Mdot
.3452 .49993 Mdot
.66034 .44225 Mdot
.28787 .51324 Mdot
.32023 .50158 Mdot
.35844 .64639 Mdot
.65718 .43191 Mdot
.48087 .53512 Mdot
.31885 .47021 Mdot
.51706 .54402 Mdot
.34328 .36503 Mdot
.28752 .3094 Mdot
.49821 .54668 Mdot
.5382 .62498 Mdot
.37266 .376 Mdot
.52702 .32883 Mdot
.5501 .66841 Mdot
.35287 .35083 Mdot
.4648 .51351 Mdot
.56034 .6075 Mdot
.57406 .69827 Mdot
.81056 .45752 Mdot
.4159 .49936 Mdot
.32941 .49576 Mdot
.71113 .46543 Mdot
.53525 .59569 Mdot
.31237 .48239 Mdot
.28894 .31664 Mdot
.50238 .60214 Mdot
.65666 .41648 Mdot
.67956 .62852 Mdot
.35833 .40391 Mdot
.50374 .33031 Mdot
.34155 .3234 Mdot
.33197 .52634 Mdot
.87713 .59848 Mdot
.45337 .50862 Mdot
.53393 .69141 Mdot
.522 .62787 Mdot
.29673 .32505 Mdot
.67821 .43826 Mdot
.60236 .23664 Mdot
.5402 .67456 Mdot
.49972 .60324 Mdot
.54656 .63623 Mdot
.30062 .38597 Mdot
.69356 .45722 Mdot
.54487 .63513 Mdot
.56728 .5846 Mdot
.525 .61053 Mdot
.31599 .51581 Mdot
.17922 .54065 Mdot
.51153 .55578 Mdot
.79015 .28411 Mdot
.46469 .51075 Mdot
.35165 .37635 Mdot
.41504 .69575 Mdot
.3804 .62967 Mdot
.23593 .3554 Mdot
.65353 .44889 Mdot
.71033 .47742 Mdot
.33178 .36144 Mdot
.39325 .41505 Mdot
.47808 .55461 Mdot
.56622 .7069 Mdot
.57748 .65874 Mdot
.33702 .34048 Mdot
.33553 .39299 Mdot
.45383 .50168 Mdot
.49565 .51506 Mdot
.50914 .65637 Mdot
.33197 .32361 Mdot
.54428 .65525 Mdot
.64662 .68436 Mdot
.48947 .31518 Mdot
.68091 .40981 Mdot
.50133 .28863 Mdot
.49561 .33235 Mdot
.80696 .58251 Mdot
.34854 .67754 Mdot
.53889 .31092 Mdot
.53382 .29203 Mdot
.40368 .40916 Mdot
.77926 .59442 Mdot
.31219 .51261 Mdot
.48386 .69227 Mdot
.35665 .38504 Mdot
.55575 .61689 Mdot
.69577 .4564 Mdot
.36854 .5293 Mdot
.62507 .23892 Mdot
.52857 .7902 Mdot
.52598 .67291 Mdot
.34414 .38673 Mdot
.49917 .5482 Mdot
.5067 .54633 Mdot
.29451 .67145 Mdot
.5423 .64799 Mdot
.3585 .40546 Mdot
.7791 .58815 Mdot
.56601 .34846 Mdot
.5313 .24819 Mdot
.73658 .42772 Mdot
.55389 .6603 Mdot
.69449 .45273 Mdot
.52756 .34295 Mdot
.31471 .48373 Mdot
.33321 .48843 Mdot
.53599 .65443 Mdot
.43255 .66255 Mdot
.36373 .42507 Mdot
.57198 .70287 Mdot
.54884 .69684 Mdot
.48733 .5384 Mdot
.53834 .69211 Mdot
.51369 .59322 Mdot
.5389 .68594 Mdot
.514 .54708 Mdot
.49175 .30579 Mdot
.80108 .57007 Mdot
.50522 .53905 Mdot
.58485 .66585 Mdot
.52234 .34387 Mdot
.58136 .69326 Mdot
.52028 .32821 Mdot
.50982 .23729 Mdot
.53422 .30158 Mdot
.33031 .48852 Mdot
.3666 .40226 Mdot
.80913 .46442 Mdot
.66413 .41589 Mdot
.5224 .33862 Mdot
.30807 .47119 Mdot
.5247 .32652 Mdot
.36152 .38282 Mdot
.57299 .32072 Mdot
.71559 .39993 Mdot
.33849 .63396 Mdot
.786 .60405 Mdot
.54267 .35916 Mdot
.35558 .40185 Mdot
.66343 .41813 Mdot
.51331 .24599 Mdot
.55431 .68371 Mdot
.33221 .48323 Mdot
.54855 .65116 Mdot
.52839 .30824 Mdot
.35297 .38726 Mdot
.80009 .4658 Mdot
.33046 .4953 Mdot
.83663 .41738 Mdot
.32526 .32045 Mdot
.52523 .64536 Mdot
.52029 .3452 Mdot
.5061 .25604 Mdot
.49552 .30826 Mdot
.38612 .7325 Mdot
.43937 .50414 Mdot
.37611 .50082 Mdot
.65999 .43656 Mdot
.44057 .49678 Mdot
.41355 .83437 Mdot
.67267 .32901 Mdot
.69203 .44245 Mdot
.29512 .3431 Mdot
.53264 .63799 Mdot
.52256 .67068 Mdot
.48224 .51105 Mdot
.64147 .45291 Mdot
.51814 .66001 Mdot
.46792 .52677 Mdot
.33541 .67813 Mdot
.73757 .42284 Mdot
.32022 .31186 Mdot
.57812 .64426 Mdot
.5147 .34657 Mdot
.51165 .33977 Mdot
.45403 .51716 Mdot
.51146 .28544 Mdot
.58305 .66879 Mdot
.66196 .42437 Mdot
.44848 .55832 Mdot
.33579 .52473 Mdot
.7169 .34698 Mdot
.30428 .52592 Mdot
.30224 .46863 Mdot
.54629 .59472 Mdot
.33068 .35761 Mdot
.50706 .19867 Mdot
.54425 .68326 Mdot
.68363 .43384 Mdot
.52227 .63596 Mdot
.52614 .67674 Mdot
.57316 .70771 Mdot
.36026 .36242 Mdot
.36231 .67519 Mdot
.54494 .65588 Mdot
.53786 .33509 Mdot
.43895 .64045 Mdot
.58756 .63404 Mdot
.42633 .48829 Mdot
.43589 .62816 Mdot
.54371 .29486 Mdot
.71491 .44937 Mdot
.33187 .35346 Mdot
.67026 .44444 Mdot
.6418 .41061 Mdot
.65218 .44527 Mdot
.73045 .39036 Mdot
.66158 .66484 Mdot
.51598 .17948 Mdot
.75718 .50937 Mdot
.78823 .60548 Mdot
.65015 .40463 Mdot
.39448 .201 Mdot
.69546 .44016 Mdot
.65215 .44601 Mdot
.70941 .26671 Mdot
.66143 .45919 Mdot
.54487 .6248 Mdot
.52708 .6191 Mdot
.69898 .72116 Mdot
.35669 .44152 Mdot
.56322 .61262 Mdot
.51506 .54818 Mdot
.34248 .48563 Mdot
.71995 .37156 Mdot
.49035 .53201 Mdot
.36853 .65539 Mdot
.48774 .54758 Mdot
.55088 .63759 Mdot
.55927 .66788 Mdot
.59072 .66068 Mdot
.4363 .81068 Mdot
.37747 .45471 Mdot
.64746 .45205 Mdot
.55556 .58349 Mdot
.52489 .37347 Mdot
.56747 .67091 Mdot
.52193 .64729 Mdot
.56528 .7149 Mdot
.33089 .35393 Mdot
.69903 .40576 Mdot
.46976 .50126 Mdot
.70734 .33804 Mdot
.57377 .6515 Mdot
.32748 .53701 Mdot
.32791 .46509 Mdot
.54025 .63699 Mdot
.65412 .45405 Mdot
.52251 .66988 Mdot
.70541 .41873 Mdot
.65647 .43659 Mdot
.50059 .60376 Mdot
.72974 .38397 Mdot
.7009 .40895 Mdot
.56601 .70662 Mdot
.36634 .38665 Mdot
.73995 .35313 Mdot
.53803 .62764 Mdot
.32939 .50171 Mdot
.56449 .64614 Mdot
.31525 .51652 Mdot
.5109 .55763 Mdot
.49131 .5436 Mdot
.61496 .73699 Mdot
.30875 .34058 Mdot
.29966 .50932 Mdot
.3487 .40384 Mdot
.56249 .59058 Mdot
.6269 .44185 Mdot
.56996 .34039 Mdot
.38484 .41382 Mdot
.48671 .53849 Mdot
.28446 .59655 Mdot
.44813 .61775 Mdot
.52852 .29293 Mdot
.70354 .42937 Mdot
.79254 .56668 Mdot
.42733 .49399 Mdot
.32489 .31297 Mdot
.3625 .34788 Mdot
.53679 .38001 Mdot
.73459 .29209 Mdot
.52916 .62783 Mdot
.43129 .49237 Mdot
.62878 .57873 Mdot
.48429 .52327 Mdot
.45827 .50071 Mdot
.32756 .3271 Mdot
.56498 .61413 Mdot
.33667 .69183 Mdot
.35074 .35456 Mdot
.33248 .51738 Mdot
.68456 .4543 Mdot
.3074 .48666 Mdot
.62479 .27806 Mdot
.79524 .47946 Mdot
.34515 .3553 Mdot
.51284 .54951 Mdot
.55303 .60992 Mdot
.6729 .46555 Mdot
.6414 .52627 Mdot
.69229 .41055 Mdot
.34643 .51265 Mdot
.30688 .34255 Mdot
.16805 .41372 Mdot
.56096 .65393 Mdot
.6712 .42562 Mdot
.3016 .45928 Mdot
.56845 .64008 Mdot
.51024 .3338 Mdot
.51845 .66004 Mdot
.67709 .42224 Mdot
.52971 .68649 Mdot
.65933 .43692 Mdot
.36548 .36735 Mdot
.53191 .64655 Mdot
.55002 .67087 Mdot
.28437 .61755 Mdot
.33929 .50972 Mdot
.6989 .40981 Mdot
.3574 .69232 Mdot
.51901 .62009 Mdot
.30148 .68816 Mdot
.54359 .6578 Mdot
.78179 .60701 Mdot
.56756 .57963 Mdot
.47196 .53073 Mdot
.5218 .63326 Mdot
.53742 .63008 Mdot
.63774 .52524 Mdot
.74982 .51696 Mdot
.78213 .49254 Mdot
.50697 .33474 Mdot
.70117 .4327 Mdot
.34752 .34952 Mdot
.30055 .33055 Mdot
.33591 .37604 Mdot
.35139 .52296 Mdot
.5172 .56851 Mdot
.54283 .6168 Mdot
.52353 .27553 Mdot
.34254 .4955 Mdot
.66893 .4321 Mdot
.32446 .49043 Mdot
.3538 .6725 Mdot
.33136 .50351 Mdot
.45295 .505 Mdot
.34106 .26357 Mdot
.64977 .67991 Mdot
.32542 .51195 Mdot
.67481 .41153 Mdot
.43862 .65866 Mdot
.49889 .59782 Mdot
.82068 .44624 Mdot
.32702 .47043 Mdot
.29366 .34069 Mdot
.56268 .60786 Mdot
.4074 .69639 Mdot
.52078 .3246 Mdot
.30716 .48553 Mdot
.52449 .2961 Mdot
.52675 .67495 Mdot
.70848 .48246 Mdot
.68698 .42737 Mdot
.48916 .31657 Mdot
.51998 .63802 Mdot
.30758 .48476 Mdot
.34404 .35889 Mdot
.77837 .59421 Mdot
.53694 .25543 Mdot
.39603 .51345 Mdot
.29485 .66707 Mdot
.31972 .36828 Mdot
.76351 .61402 Mdot
.52866 .29703 Mdot
.55735 .58408 Mdot
.57912 .71792 Mdot
.52724 .59512 Mdot
.33818 .33553 Mdot
.34014 .36177 Mdot
.43194 .33184 Mdot
.55038 .67219 Mdot
.52596 .68457 Mdot
.71822 .4501 Mdot
.30918 .35189 Mdot
.65226 .44458 Mdot
.65517 .46986 Mdot
.34768 .33856 Mdot
.70062 .4153 Mdot
.31906 .50199 Mdot
.35712 .7123 Mdot
.53037 .29878 Mdot
.49752 .32141 Mdot
.34326 .35427 Mdot
.31449 .34174 Mdot
.33026 .35794 Mdot
.51276 .63305 Mdot
.6545 .43779 Mdot
.55897 .68009 Mdot
.55632 .65811 Mdot
.49621 .60427 Mdot
.67773 .47549 Mdot
.54642 .6794 Mdot
.45466 .55694 Mdot
.34126 .47658 Mdot
.34715 .37575 Mdot
.51241 .29642 Mdot
.39496 .54535 Mdot
.5411 .33148 Mdot
.52374 .61055 Mdot
.74794 .37088 Mdot
.70155 .43648 Mdot
.33749 .49475 Mdot
.43476 .63122 Mdot
.33285 .49406 Mdot
.48969 .31671 Mdot
.72384 .44377 Mdot
.35304 .64786 Mdot
.54522 .67123 Mdot
.35354 .68165 Mdot
.22975 .56921 Mdot
.6819 .36121 Mdot
.5189 .30332 Mdot
.50892 .63977 Mdot
.46926 .53081 Mdot
.66635 .6579 Mdot
.5394 .61921 Mdot
.58278 .61823 Mdot
.40966 .64541 Mdot
.52527 .61312 Mdot
.64657 .42481 Mdot
.44475 .59575 Mdot
.50838 .52864 Mdot
.5339 .58999 Mdot
.54695 .20608 Mdot
.55826 .6076 Mdot
.54353 .66777 Mdot
.55298 .62057 Mdot
.53491 .6776 Mdot
.67082 .4741 Mdot
.44268 .57558 Mdot
.52852 .34128 Mdot
.35664 .71252 Mdot
.53341 .305 Mdot
.33925 .34725 Mdot
.40081 .50587 Mdot
.71372 .43837 Mdot
.33323 .49456 Mdot
.44267 .44822 Mdot
.40324 .71634 Mdot
.36574 .38386 Mdot
.27917 .59301 Mdot
.30254 .48245 Mdot
.46496 .50303 Mdot
.3291 .52636 Mdot
.33339 .33062 Mdot
.51279 .33371 Mdot
.52907 .64931 Mdot
.65062 .43073 Mdot
.68082 .41464 Mdot
.54154 .59217 Mdot
.72969 .33796 Mdot
.50158 .32913 Mdot
.4205 .35665 Mdot
.53362 .61881 Mdot
.51913 .62553 Mdot
.70761 .42443 Mdot
.33244 .37825 Mdot
.44768 .61606 Mdot
.31383 .50999 Mdot
.57055 .66808 Mdot
.51031 .53556 Mdot
.35355 .67402 Mdot
.51024 .3375 Mdot
.4635 .517 Mdot
.5582 .61317 Mdot
.35014 .66613 Mdot
.51094 .64158 Mdot
.58557 .60291 Mdot
.36538 .39366 Mdot
.50032 .60178 Mdot
.55587 .67309 Mdot
.73688 .42686 Mdot
.52546 .29372 Mdot
.681 .43934 Mdot
.72291 .41401 Mdot
.48995 .54223 Mdot
.49658 .30271 Mdot
.52939 .67079 Mdot
.5034 .26991 Mdot
.526 .67556 Mdot
.55521 .65159 Mdot
.52153 .30579 Mdot
.65853 .44961 Mdot
.59234 .23577 Mdot
.80092 .56878 Mdot
.53595 .6867 Mdot
.56566 .6426 Mdot
.35656 .44154 Mdot
.36319 .53184 Mdot
.54474 .67402 Mdot
.66809 .4143 Mdot
.5687 .64446 Mdot
.50818 .27336 Mdot
.32269 .48371 Mdot
.68814 .4331 Mdot
.33535 .38367 Mdot
.36446 .36386 Mdot
.37814 .37782 Mdot
.45254 .50417 Mdot
.54116 .69474 Mdot
.71115 .46532 Mdot
.66947 .47653 Mdot
.38003 .69222 Mdot
.35082 .37606 Mdot
.31588 .48921 Mdot
.5789 .64149 Mdot
.45749 .49443 Mdot
.51231 .34236 Mdot
.78552 .27552 Mdot
.35178 .65017 Mdot
.34316 .47691 Mdot
.41008 .5139 Mdot
.48288 .53125 Mdot
.54741 .60665 Mdot
.31125 .48112 Mdot
.34922 .34132 Mdot
.52049 .66763 Mdot
.55143 .57607 Mdot
.29523 .34775 Mdot
.32099 .35163 Mdot
.50415 .26856 Mdot
.35124 .39399 Mdot
.30384 .50075 Mdot
.45373 .50812 Mdot
.6918 .42157 Mdot
.54017 .64227 Mdot
.50251 .53557 Mdot
.35626 .37978 Mdot
.44266 .49452 Mdot
.52733 .62363 Mdot
.70402 .43922 Mdot
.34496 .38148 Mdot
.55099 .63253 Mdot
.66664 .64211 Mdot
.80733 .46149 Mdot
.35315 .38874 Mdot
.57548 .67563 Mdot
.55001 .48901 Mdot
.32307 .35109 Mdot
.33236 .33172 Mdot
.50542 .59927 Mdot
.30955 .47728 Mdot
.5679 .66211 Mdot
.50657 .32883 Mdot
.35957 .6815 Mdot
.49799 .29709 Mdot
.29359 .67217 Mdot
.51062 .59023 Mdot
.58437 .72084 Mdot
.63052 .43337 Mdot
.29713 .50821 Mdot
.35067 .7587 Mdot
.53806 .59644 Mdot
.61599 .44686 Mdot
.36435 .67701 Mdot
.35256 .63314 Mdot
.60945 .4724 Mdot
.30694 .50115 Mdot
.52473 .3207 Mdot
.54092 .66089 Mdot
.57009 .23162 Mdot
.30944 .50305 Mdot
.29488 .67411 Mdot
.56881 .68888 Mdot
.67654 .43058 Mdot
.53181 .62377 Mdot
.68867 .4216 Mdot
.56446 .6279 Mdot
.80976 .45558 Mdot
.36461 .42507 Mdot
.3868 .73223 Mdot
.47042 .50801 Mdot
.50618 .25608 Mdot
.78637 .60419 Mdot
.31841 .49649 Mdot
.52591 .68146 Mdot
.47719 .52481 Mdot
.52195 .33514 Mdot
.57744 .3503 Mdot
.33145 .36235 Mdot
.53896 .33255 Mdot
.66969 .45105 Mdot
.37288 .36804 Mdot
.44232 .49688 Mdot
.60004 .72105 Mdot
.30867 .48183 Mdot
.49635 .30383 Mdot
.53807 .6348 Mdot
.52457 .5988 Mdot
.29895 .38267 Mdot
.18119 .54891 Mdot
.65263 .47104 Mdot
.83958 .40501 Mdot
.72284 .44515 Mdot
.34151 .51127 Mdot
.3688 .38464 Mdot
.55685 .63094 Mdot
.57498 .63786 Mdot
.32017 .35262 Mdot
.68075 .46468 Mdot
.29756 .49373 Mdot
.37411 .50015 Mdot
.521 .27646 Mdot
.20254 .57153 Mdot
.69044 .43132 Mdot
.20182 .56954 Mdot
.38794 .33637 Mdot
.7699 .40752 Mdot
.34078 .74578 Mdot
.51307 .3065 Mdot
.20202 .57131 Mdot
.67453 .42822 Mdot
.53424 .60914 Mdot
.48025 .53307 Mdot
.44732 .50287 Mdot
.69482 .45004 Mdot
.33472 .342 Mdot
.30268 .48756 Mdot
.53249 .62602 Mdot
.61729 .62816 Mdot
.64276 .52671 Mdot
.3092 .32931 Mdot
.49155 .5269 Mdot
.50629 .30026 Mdot
.56744 .64049 Mdot
.34663 .49323 Mdot
.5127 .30778 Mdot
.48938 .54685 Mdot
.39235 .71811 Mdot
.57684 .67696 Mdot
.43252 .64753 Mdot
.51838 .32523 Mdot
.3591 .54093 Mdot
.55244 .67058 Mdot
.52853 .29695 Mdot
.5094 .55944 Mdot
.45546 .35753 Mdot
.46058 .58026 Mdot
.67193 .32926 Mdot
.34779 .32391 Mdot
.35854 .3927 Mdot
.19962 .36246 Mdot
.24118 .36897 Mdot
.5373 .31837 Mdot
.49601 .5389 Mdot
.17576 .53757 Mdot
.51862 .28917 Mdot
.53384 .67156 Mdot
.53561 .64878 Mdot
.77923 .58751 Mdot
.50389 .55422 Mdot
.4626 .50981 Mdot
.73829 .46426 Mdot
.57867 .69297 Mdot
.49291 .52905 Mdot
.54927 .66668 Mdot
.65036 .45562 Mdot
.50665 .30355 Mdot
.57289 .83319 Mdot
.49017 .29858 Mdot
.58886 .71473 Mdot
.35617 .38556 Mdot
.35697 .33259 Mdot
.54114 .63855 Mdot
.54033 .47226 Mdot
.72986 .75953 Mdot
.53663 .65169 Mdot
.43466 .63228 Mdot
.29195 .66388 Mdot
.51761 .58783 Mdot
.67563 .40457 Mdot
.50837 .55363 Mdot
.68618 .47567 Mdot
.51782 .3098 Mdot
.30715 .50111 Mdot
.29462 .50157 Mdot
.52371 .3211 Mdot
.57169 .63005 Mdot
.30362 .52346 Mdot
.54745 .64363 Mdot
.54251 .6099 Mdot
.35476 .66477 Mdot
.34851 .50113 Mdot
.32967 .34926 Mdot
.33214 .48946 Mdot
.655 .45152 Mdot
.81746 .35107 Mdot
.32052 .49299 Mdot
.77928 .59398 Mdot
.35881 .68925 Mdot
.1801 .53787 Mdot
.68601 .41506 Mdot
.33415 .52506 Mdot
.52687 .32001 Mdot
.38083 .64738 Mdot
.75391 .63959 Mdot
.54158 .32953 Mdot
.54853 .61362 Mdot
.66556 .47421 Mdot
.72314 .43579 Mdot
.5328 .344 Mdot
.69627 .42268 Mdot
.51994 .57329 Mdot
.56171 .70213 Mdot
.53039 .34097 Mdot
.3965 .79599 Mdot
.49465 .31535 Mdot
.81103 .56967 Mdot
.54229 .69452 Mdot
.68553 .43355 Mdot
.78291 .61241 Mdot
.73041 .42779 Mdot
.45503 .51434 Mdot
.53343 .66437 Mdot
.31806 .49083 Mdot
.37012 .6959 Mdot
.34332 .38775 Mdot
.70095 .36544 Mdot
.67255 .4182 Mdot
.53191 .34697 Mdot
.69583 .42297 Mdot
.70407 .42751 Mdot
.49078 .32323 Mdot
.70044 .43555 Mdot
.57405 .64973 Mdot
.81712 .4583 Mdot
.69525 .41609 Mdot
.51296 .31748 Mdot
.34546 .51324 Mdot
.67479 .41091 Mdot
.42407 .3688 Mdot
.57725 .63669 Mdot
.30986 .31418 Mdot
.36238 .51233 Mdot
.66045 .46993 Mdot
.31709 .49523 Mdot
.35362 .38098 Mdot
.31358 .46704 Mdot
.4736 .28285 Mdot
.49171 .26667 Mdot
.58255 .57565 Mdot
.44824 .35403 Mdot
.66037 .45808 Mdot
.37355 .36732 Mdot
.57614 .66513 Mdot
.53568 .61458 Mdot
.35227 .5027 Mdot
.68533 .40027 Mdot
.72786 .33231 Mdot
.49163 .5319 Mdot
.71609 .34654 Mdot
.50655 .33489 Mdot
.41657 .36909 Mdot
.35064 .6469 Mdot
.56113 .28409 Mdot
.50688 .52573 Mdot
.48129 .52972 Mdot
.54626 .63537 Mdot
.28668 .62701 Mdot
.30458 .50186 Mdot
.3808 .21482 Mdot
.51466 .61368 Mdot
.31814 .35292 Mdot
.56107 .62591 Mdot
.46862 .5512 Mdot
.526 .59288 Mdot
.34637 .4836 Mdot
.54265 .30724 Mdot
.66474 .41544 Mdot
.32584 .52309 Mdot
.36458 .36172 Mdot
.4093 .73927 Mdot
.54888 .67721 Mdot
.58236 .65149 Mdot
.32609 .34324 Mdot
.64922 .43988 Mdot
.33846 .35318 Mdot
.53059 .2993 Mdot
.32298 .49381 Mdot
.51456 .64936 Mdot
.50573 .5547 Mdot
.29656 .3264 Mdot
.52568 .3381 Mdot
.37199 .38139 Mdot
.49557 .27946 Mdot
.4833 .53423 Mdot
.54588 .5862 Mdot
.36201 .40736 Mdot
.50521 .52762 Mdot
.74826 .57855 Mdot
.39723 .71406 Mdot
.62281 .51779 Mdot
.33336 .33989 Mdot
.23885 .34786 Mdot
.51285 .3111 Mdot
.50029 .28294 Mdot
.81423 .56499 Mdot
.78362 .7043 Mdot
.44072 .63512 Mdot
.70626 .31881 Mdot
.53103 .29962 Mdot
.51396 .3272 Mdot
.33553 .35213 Mdot
.66261 .45496 Mdot
.63256 .44292 Mdot
.36964 .36017 Mdot
.32052 .7161 Mdot
.669 .4318 Mdot
.71194 .71293 Mdot
.31041 .32098 Mdot
.57409 .70854 Mdot
.80281 .46235 Mdot
.33834 .47466 Mdot
.29499 .65837 Mdot
.57331 .32865 Mdot
.55027 .62664 Mdot
.52227 .18379 Mdot
.33346 .36458 Mdot
.45189 .49435 Mdot
.47816 .35551 Mdot
.51629 .62972 Mdot
.55796 .62099 Mdot
.57152 .64911 Mdot
.35513 .52729 Mdot
.73333 .53763 Mdot
.55313 .62823 Mdot
.39311 .72269 Mdot
.58404 .69017 Mdot
.28246 .32142 Mdot
.3316 .48934 Mdot
.27632 .58418 Mdot
.33339 .40415 Mdot
.70183 .33454 Mdot
.57574 .60376 Mdot
.51412 .27804 Mdot
.45718 .55032 Mdot
.52305 .30539 Mdot
.54553 .30199 Mdot
.20531 .60641 Mdot
.64639 .42736 Mdot
.51416 .62185 Mdot
.31457 .32764 Mdot
.6322 .44508 Mdot
.45455 .55107 Mdot
.82685 .36338 Mdot
.53463 .34934 Mdot
.88685 .58638 Mdot
.50747 .28167 Mdot
.45152 .49883 Mdot
.67538 .45146 Mdot
.62517 .5049 Mdot
.35243 .68075 Mdot
.65345 .44583 Mdot
.26902 .37281 Mdot
.6778 .47791 Mdot
.26699 .69385 Mdot
.7034 .39531 Mdot
.5076 .31456 Mdot
.53198 .34529 Mdot
.5291 .57205 Mdot
.5671 .66421 Mdot
.33544 .68365 Mdot
.49149 .53112 Mdot
.57683 .68189 Mdot
.35107 .35457 Mdot
.43201 .34297 Mdot
.55122 .22935 Mdot
.69923 .43756 Mdot
.52971 .33469 Mdot
.55907 .62329 Mdot
.53381 .68568 Mdot
.52469 .62559 Mdot
.39317 .41897 Mdot
.70592 .72104 Mdot
.55363 .65583 Mdot
.56757 .59132 Mdot
.3671 .3793 Mdot
.29895 .38365 Mdot
.75179 .31633 Mdot
.20355 .58851 Mdot
.55302 .6 Mdot
.34204 .50444 Mdot
.35057 .51173 Mdot
.54404 .57733 Mdot
.61016 .50152 Mdot
.27991 .54262 Mdot
.53801 .63395 Mdot
.41113 .73001 Mdot
.30295 .311 Mdot
.45773 .52089 Mdot
.35619 .37891 Mdot
.63657 .41365 Mdot
.47841 .53799 Mdot
.34987 .34646 Mdot
.37018 .73355 Mdot
.49572 .54513 Mdot
.45402 .3546 Mdot
.33791 .52479 Mdot
.5508 .66852 Mdot
.7981 .54307 Mdot
.30909 .35219 Mdot
.50625 .32544 Mdot
.6803 .44708 Mdot
.50668 .3339 Mdot
.28912 .30217 Mdot
.30738 .69958 Mdot
.46008 .51874 Mdot
.51308 .27723 Mdot
.43294 .65188 Mdot
.34169 .49855 Mdot
.51228 .28394 Mdot
.58364 .7117 Mdot
.5889 .666 Mdot
.71399 .75741 Mdot
.58037 .64256 Mdot
.43419 .33349 Mdot
.49571 .30015 Mdot
.48024 .54113 Mdot
.54085 .64427 Mdot
.32401 .31891 Mdot
.53614 .56533 Mdot
.54873 .6437 Mdot
.32679 .37697 Mdot
.53624 .64804 Mdot
.32137 .47976 Mdot
.72196 .45514 Mdot
.36837 .67354 Mdot
.39356 .49529 Mdot
.30906 .50818 Mdot
.4062 .70888 Mdot
.54231 .67332 Mdot
.25468 .37179 Mdot
.67563 .4334 Mdot
.52448 .60949 Mdot
.2629 .64833 Mdot
.67776 .45727 Mdot
.66718 .44344 Mdot
.55911 .70789 Mdot
.50056 .27825 Mdot
.32849 .34614 Mdot
.33935 .49325 Mdot
.53715 .25344 Mdot
.55246 .63171 Mdot
.51016 .64401 Mdot
.31202 .51177 Mdot
.50203 .31952 Mdot
.5173 .65469 Mdot
.60842 .36015 Mdot
.36379 .71415 Mdot
.49112 .3196 Mdot
.58735 .63202 Mdot
.73996 .69402 Mdot
.7059 .45019 Mdot
.5207 .18318 Mdot
.3649 .42526 Mdot
.36383 .35295 Mdot
.49459 .52934 Mdot
.79354 .29317 Mdot
.34582 .51426 Mdot
.69513 .35246 Mdot
.53026 .61937 Mdot
.56069 .63642 Mdot
.65423 .45677 Mdot
.55866 .67869 Mdot
.70182 .43488 Mdot
.41247 .39327 Mdot
.80646 .68063 Mdot
.68743 .41713 Mdot
.68248 .42243 Mdot
.49038 .71229 Mdot
.37252 .40966 Mdot
.68586 .45294 Mdot
.55694 .67446 Mdot
.25814 .31483 Mdot
.60771 .64228 Mdot
.29976 .4797 Mdot
.35648 .52894 Mdot
.67439 .40621 Mdot
.75398 .64408 Mdot
.58213 .70974 Mdot
.71004 .69216 Mdot
.27827 .54316 Mdot
.53739 .3151 Mdot
.50466 .62215 Mdot
.4868 .53043 Mdot
.34476 .37757 Mdot
.50331 .59311 Mdot
.55424 .66907 Mdot
.6525 .42238 Mdot
.32644 .46754 Mdot
.51721 .28971 Mdot
.50076 .52169 Mdot
.31261 .3029 Mdot
.32023 .51413 Mdot
.70294 .42051 Mdot
.79724 .59599 Mdot
.31397 .53093 Mdot
.47194 .50017 Mdot
.54425 .60395 Mdot
.50297 .60103 Mdot
.45838 .49309 Mdot
.52261 .31987 Mdot
.35932 .34175 Mdot
.47491 .50377 Mdot
.38775 .65913 Mdot
.3482 .71695 Mdot
.54376 .59847 Mdot
.67107 .41253 Mdot
.52482 .33563 Mdot
.45652 .5105 Mdot
.17444 .53235 Mdot
.56729 .61066 Mdot
.71219 .71355 Mdot
.38711 .51197 Mdot
.48858 .53471 Mdot
.63237 .4474 Mdot
.33583 .49296 Mdot
.5415 .69377 Mdot
.38996 .72616 Mdot
.57491 .68531 Mdot
.55579 .58315 Mdot
.34453 .33671 Mdot
.52514 .30011 Mdot
.58486 .5776 Mdot
.34456 .37428 Mdot
.66918 .44415 Mdot
.69025 .70975 Mdot
.65032 .46428 Mdot
.65334 .4695 Mdot
.72411 .38009 Mdot
.50059 .32453 Mdot
.79261 .29017 Mdot
.36224 .53158 Mdot
.52821 .63915 Mdot
.54107 .30885 Mdot
.68949 .44896 Mdot
.54348 .67797 Mdot
.70168 .43617 Mdot
.69174 .4037 Mdot
.57977 .67911 Mdot
.57293 .69891 Mdot
.39243 .72873 Mdot
.73739 .68942 Mdot
.33103 .48326 Mdot
.67777 .46451 Mdot
.74389 .67329 Mdot
.55687 .63277 Mdot
.56127 .6677 Mdot
.45702 .54848 Mdot
.31883 .52115 Mdot
.62993 .73414 Mdot
.5339 .61483 Mdot
.28153 .61532 Mdot
.53653 .67254 Mdot
.6718 .3982 Mdot
.50774 .25822 Mdot
.58624 .71401 Mdot
.37109 .37296 Mdot
.67703 .4655 Mdot
.33589 .47201 Mdot
.63116 .41528 Mdot
.65432 .6765 Mdot
.52501 .32831 Mdot
.67727 .4223 Mdot
.36388 .34543 Mdot
.50381 .31909 Mdot
.49475 .31444 Mdot
.45254 .55055 Mdot
.34714 .32892 Mdot
.32564 .46657 Mdot
.50732 .29359 Mdot
.66932 .638 Mdot
.50648 .31591 Mdot
.65354 .69657 Mdot
.57365 .61594 Mdot
.3911 .72348 Mdot
.48947 .51599 Mdot
.57498 .58205 Mdot
.50094 .29519 Mdot
.3147 .51221 Mdot
.51596 .65021 Mdot
.69876 .42131 Mdot
.34511 .50849 Mdot
.79223 .4744 Mdot
.36466 .34367 Mdot
.72043 .44239 Mdot
.54108 .25874 Mdot
.67802 .46148 Mdot
.29502 .66393 Mdot
.33277 .46666 Mdot
.42479 .49318 Mdot
.366 .6638 Mdot
.48523 .52177 Mdot
.53941 .58981 Mdot
.51434 .64297 Mdot
.57376 .64413 Mdot
.35676 .38585 Mdot
.35301 .52905 Mdot
.6875 .40849 Mdot
.60406 .58365 Mdot
.50156 .32229 Mdot
.44116 .60928 Mdot
.45997 .49707 Mdot
.52799 .67725 Mdot
.69041 .44624 Mdot
.69905 .40673 Mdot
.74497 .52212 Mdot
.32374 .35576 Mdot
.60094 .60704 Mdot
.5409 .59678 Mdot
.61022 .60266 Mdot
.4994 .29678 Mdot
.65687 .33627 Mdot
.30388 .31413 Mdot
.88976 .58205 Mdot
.34628 .3737 Mdot
.42252 .50988 Mdot
.70059 .44796 Mdot
.32678 .50384 Mdot
.56917 .62272 Mdot
.73779 .40988 Mdot
.64157 .46675 Mdot
.28458 .46159 Mdot
.3333 .49702 Mdot
.49356 .24704 Mdot
.53804 .30752 Mdot
.50124 .5211 Mdot
.53584 .67229 Mdot
.55976 .68702 Mdot
.56883 .67386 Mdot
.53709 .32652 Mdot
.56841 .69921 Mdot
.51655 .25882 Mdot
.652 .67682 Mdot
.26347 .6514 Mdot
.32479 .33138 Mdot
.28172 .28785 Mdot
.66404 .47232 Mdot
.65283 .72815 Mdot
.64213 .70508 Mdot
.39441 .7145 Mdot
.53848 .29438 Mdot
.5166 .56188 Mdot
.33297 .34823 Mdot
.54912 .23295 Mdot
.32318 .33073 Mdot
.62322 .80924 Mdot
.78057 .58603 Mdot
.46268 .2854 Mdot
.56411 .68682 Mdot
.34414 .33351 Mdot
.75474 .64904 Mdot
.48195 .5078 Mdot
.30503 .52452 Mdot
.65869 .66389 Mdot
.78567 .48834 Mdot
.32945 .48187 Mdot
.56369 .61375 Mdot
.67463 .47578 Mdot
.57204 .62847 Mdot
.56832 .62052 Mdot
.52839 .62 Mdot
.50427 .34205 Mdot
.57155 .61137 Mdot
.57186 .65928 Mdot
.1508 .46 Mdot
.28564 .52446 Mdot
.3559 .39514 Mdot
.62695 .50997 Mdot
.34252 .49534 Mdot
.63765 .41233 Mdot
.36763 .66947 Mdot
.49715 .28788 Mdot
.74208 .52445 Mdot
.55825 .70294 Mdot
.70478 .35984 Mdot
.49413 .28767 Mdot
.30847 .47606 Mdot
.48269 .5276 Mdot
.62945 .23622 Mdot
.35398 .40677 Mdot
.46856 .51411 Mdot
.32921 .37712 Mdot
.61299 .71784 Mdot
.69314 .42474 Mdot
.48639 .52296 Mdot
.51475 .28988 Mdot
.32569 .3271 Mdot
.40202 .71972 Mdot
.56748 .65325 Mdot
.33499 .338 Mdot
.50083 .53662 Mdot
.36809 .69551 Mdot
.36303 .67738 Mdot
.33847 .32951 Mdot
.51895 .27204 Mdot
.49853 .30626 Mdot
.34454 .49359 Mdot
.70716 .43912 Mdot
.64858 .43562 Mdot
.50202 .31109 Mdot
.52466 .21156 Mdot
.55091 .63091 Mdot
.55771 .65325 Mdot
.36318 .65066 Mdot
.52199 .65398 Mdot
.35425 .44297 Mdot
.47406 .51715 Mdot
.65401 .42474 Mdot
.51512 .64663 Mdot
.51933 .65873 Mdot
.55656 .60509 Mdot
.32225 .721 Mdot
.35359 .38467 Mdot
.57482 .70226 Mdot
.30958 .48251 Mdot
.79082 .48081 Mdot
.57534 .66243 Mdot
.47105 .4959 Mdot
.70223 .44719 Mdot
.54542 .37316 Mdot
.50732 .3268 Mdot
.31021 .33354 Mdot
.3129 .32909 Mdot
.22936 .57876 Mdot
.6535 .46307 Mdot
.47 .51457 Mdot
.29495 .34784 Mdot
.45463 .50618 Mdot
.3338 .49977 Mdot
.45849 .58971 Mdot
.33053 .42348 Mdot
.35472 .3949 Mdot
.48542 .31939 Mdot
.52191 .60801 Mdot
.57331 .66465 Mdot
.71651 .33597 Mdot
.54523 .66029 Mdot
.3201 .48679 Mdot
.52461 .28774 Mdot
.67782 .42397 Mdot
.32562 .4774 Mdot
.50799 .2791 Mdot
.65097 .44243 Mdot
.58398 .68689 Mdot
.54097 .6762 Mdot
.6735 .44697 Mdot
.70543 .42463 Mdot
.54285 .62462 Mdot
.21379 .6356 Mdot
.65959 .41748 Mdot
.67753 .44911 Mdot
.78911 .48294 Mdot
.35595 .40409 Mdot
.53503 .56373 Mdot
.50769 .27449 Mdot
.57166 .65748 Mdot
.32337 .33461 Mdot
.33253 .5096 Mdot
.66715 .41892 Mdot
.50504 .59663 Mdot
.55462 .6378 Mdot
.34163 .50234 Mdot
.33145 .52917 Mdot
.33243 .52259 Mdot
.53254 .34371 Mdot
.56535 .70674 Mdot
.68087 .45277 Mdot
.54105 .32756 Mdot
.34666 .48987 Mdot
.31385 .52055 Mdot
.29151 .72334 Mdot
.54772 .62686 Mdot
.34046 .52935 Mdot
.80947 .33815 Mdot
.37761 .74287 Mdot
.44902 .50956 Mdot
.37771 .36348 Mdot
.23856 .33455 Mdot
.35369 .54086 Mdot
.52822 .30421 Mdot
.43907 .61071 Mdot
.30329 .47554 Mdot
.50256 .52969 Mdot
.56234 .6556 Mdot
.49779 .61711 Mdot
.34397 .51137 Mdot
.3057 .69807 Mdot
.64402 .43239 Mdot
.65226 .54621 Mdot
.34214 .49444 Mdot
.33424 .32609 Mdot
.2981 .31494 Mdot
.34246 .36586 Mdot
.52547 .59208 Mdot
.59568 .7476 Mdot
.65862 .61319 Mdot
.62979 .72805 Mdot
.5362 .30378 Mdot
.69756 .40565 Mdot
.8005 .47118 Mdot
.6653 .44224 Mdot
.33228 .3747 Mdot
.31362 .51074 Mdot
.65066 .45193 Mdot
.49887 .32432 Mdot
.49888 .30284 Mdot
.35966 .40714 Mdot
.35384 .37632 Mdot
.34469 .35709 Mdot
.69577 .46074 Mdot
.70169 .44289 Mdot
.55154 .68215 Mdot
.68515 .4116 Mdot
.38729 .41769 Mdot
.40253 .40695 Mdot
.3285 .38788 Mdot
.51805 .31715 Mdot
.657 .43584 Mdot
.54788 .66856 Mdot
.41027 .63203 Mdot
.29339 .33196 Mdot
.33472 .47358 Mdot
.81901 .45562 Mdot
.76914 .71987 Mdot
.50821 .61606 Mdot
.53332 .32336 Mdot
.46393 .50785 Mdot
.57093 .63681 Mdot
.36384 .35141 Mdot
.38208 .52417 Mdot
.4984 .55165 Mdot
.57892 .66381 Mdot
.58648 .65255 Mdot
.52244 .33357 Mdot
.36985 .66658 Mdot
.50164 .52612 Mdot
.44579 .55982 Mdot
.52766 .28874 Mdot
.29997 .32284 Mdot
.21648 .33617 Mdot
.74415 .45014 Mdot
.29687 .59833 Mdot
.48377 .54215 Mdot
.56758 .61002 Mdot
.35426 .3573 Mdot
.31871 .47541 Mdot
.3526 .36155 Mdot
.64813 .40555 Mdot
.35822 .40403 Mdot
.54078 .65802 Mdot
.68045 .45418 Mdot
.49676 .30698 Mdot
.37409 .63063 Mdot
.58246 .5495 Mdot
.32032 .31857 Mdot
.44191 .49095 Mdot
.57461 .69551 Mdot
.67054 .64637 Mdot
.57341 .58145 Mdot
.55878 .67127 Mdot
.52113 .30489 Mdot
.69683 .44066 Mdot
.51388 .33755 Mdot
.5409 .56845 Mdot
.61081 .49112 Mdot
.50936 .32929 Mdot
.55628 .73971 Mdot
.30217 .48999 Mdot
.31223 .70756 Mdot
.53507 .63478 Mdot
.51786 .29248 Mdot
.58145 .65745 Mdot
.66835 .46442 Mdot
.36182 .72778 Mdot
.37268 .71456 Mdot
.50857 .30222 Mdot
.43837 .50455 Mdot
.36083 .69099 Mdot
.53383 .56177 Mdot
.53254 .30295 Mdot
.39095 .75613 Mdot
.46752 .51779 Mdot
.32182 .51358 Mdot
.32199 .52632 Mdot
.31382 .50311 Mdot
.55728 .65761 Mdot
.76589 .65822 Mdot
.3481 .50593 Mdot
.52052 .36407 Mdot
.31471 .48409 Mdot
.39635 .51939 Mdot
.73151 .33657 Mdot
.30366 .49796 Mdot
.53865 .64593 Mdot
.59215 .71968 Mdot
.43683 .62177 Mdot
.3386 .32025 Mdot
.61506 .24055 Mdot
.15406 .44904 Mdot
.55671 .63014 Mdot
.81284 .45851 Mdot
.73313 .43877 Mdot
.41566 .49739 Mdot
.38049 .71525 Mdot
.43384 .67606 Mdot
.66364 .44631 Mdot
.36749 .66522 Mdot
.71142 .45212 Mdot
.47045 .50452 Mdot
.55446 .6531 Mdot
.67359 .46583 Mdot
.70168 .36607 Mdot
.35345 .76183 Mdot
.72231 .35027 Mdot
.65406 .43686 Mdot
.52511 .29336 Mdot
.52964 .31185 Mdot
.51773 .30221 Mdot
.3613 .37292 Mdot
.68031 .42031 Mdot
.58068 .68757 Mdot
.36588 .36163 Mdot
.5453 .61216 Mdot
.50444 .30551 Mdot
.38383 .71726 Mdot
.68192 .42305 Mdot
.53736 .63233 Mdot
.74785 .66131 Mdot
.32017 .36782 Mdot
.34283 .50294 Mdot
.81654 .45536 Mdot
.37617 .36797 Mdot
.50496 .27021 Mdot
.6529 .40527 Mdot
.28425 .51578 Mdot
.44147 .57682 Mdot
.5412 .59984 Mdot
.53041 .6528 Mdot
.43742 .61056 Mdot
.78663 .5838 Mdot
.50988 .54333 Mdot
.3645 .36273 Mdot
.35339 .40153 Mdot
.57618 .63014 Mdot
.68068 .41817 Mdot
.31475 .45757 Mdot
.33555 .5342 Mdot
.58697 .60216 Mdot
.35642 .68044 Mdot
.39311 .72242 Mdot
.53189 .67334 Mdot
.51374 .70438 Mdot
.36203 .3431 Mdot
.44695 .50691 Mdot
.35503 .67333 Mdot
.31779 .50094 Mdot
.53534 .60926 Mdot
.63818 .51856 Mdot
.67033 .4204 Mdot
.33208 .34103 Mdot
.51319 .34568 Mdot
.30918 .52828 Mdot
.33395 .39355 Mdot
.57594 .62952 Mdot
.51851 .65708 Mdot
.51273 .28587 Mdot
.66093 .40287 Mdot
.33262 .51792 Mdot
.36659 .36613 Mdot
.3236 .50293 Mdot
.69625 .42931 Mdot
.66513 .41902 Mdot
.52784 .61055 Mdot
.60352 .60731 Mdot
.31417 .31864 Mdot
.52359 .59021 Mdot
.34152 .34187 Mdot
.29817 .38113 Mdot
.51315 .34253 Mdot
.52414 .6114 Mdot
.63264 .43338 Mdot
.50255 .30647 Mdot
.55691 .62698 Mdot
.44013 .59817 Mdot
.5215 .66462 Mdot
.34387 .33263 Mdot
.3743 .52342 Mdot
.32116 .5099 Mdot
.545 .71114 Mdot
.77161 .49339 Mdot
.52179 .65688 Mdot
.31138 .35988 Mdot
.66116 .63311 Mdot
.51811 .3308 Mdot
.69281 .45579 Mdot
.31055 .27687 Mdot
.5111 .31782 Mdot
.53361 .63892 Mdot
.32068 .492 Mdot
.70238 .41612 Mdot
.47079 .5312 Mdot
.32041 .65688 Mdot
.54904 .57366 Mdot
.60328 .6134 Mdot
.50801 .53835 Mdot
.71136 .32161 Mdot
.34717 .35826 Mdot
.68889 .448 Mdot
.53382 .31935 Mdot
.52234 .33026 Mdot
.33038 .37662 Mdot
.78186 .48518 Mdot
.76967 .37843 Mdot
.80505 .32282 Mdot
.31415 .37161 Mdot
.31137 .49501 Mdot
.36398 .72726 Mdot
.34087 .36483 Mdot
.34734 .38998 Mdot
.35519 .41943 Mdot
.71202 .33357 Mdot
.65787 .44663 Mdot
.55551 .63791 Mdot
.80882 .4594 Mdot
.52792 .6258 Mdot
.301 .60056 Mdot
.50517 .30668 Mdot
.6923 .4562 Mdot
.41975 .39696 Mdot
.53141 .59001 Mdot
.56335 .62122 Mdot
.42611 .36258 Mdot
.48824 .52844 Mdot
.18649 .54807 Mdot
.52423 .63902 Mdot
.35762 .37004 Mdot
.64176 .48496 Mdot
.47587 .50605 Mdot
.74875 .66154 Mdot
.49833 .29512 Mdot
.45665 .5148 Mdot
.47199 .50368 Mdot
.50832 .70139 Mdot
.7074 .45792 Mdot
.64568 .44435 Mdot
.33014 .52717 Mdot
.74984 .37871 Mdot
.49821 .29327 Mdot
.66716 .32413 Mdot
.55607 .67336 Mdot
.54107 .29107 Mdot
.377 .50086 Mdot
.5536 .62252 Mdot
.45237 .5528 Mdot
.7451 .52156 Mdot
.5046 .60888 Mdot
.63812 .69886 Mdot
.51243 .31313 Mdot
.26622 .64354 Mdot
.56941 .69284 Mdot
.33468 .33926 Mdot
.66521 .457 Mdot
.71984 .44614 Mdot
.32541 .47442 Mdot
.37909 .42914 Mdot
.84238 .6407 Mdot
.69003 .45729 Mdot
.56747 .65553 Mdot
.51451 .32868 Mdot
.46161 .52216 Mdot
.49247 .51999 Mdot
.43672 .50322 Mdot
.66839 .42254 Mdot
.48076 .50855 Mdot
.71195 .35961 Mdot
.36793 .66636 Mdot
.66473 .72365 Mdot
.51157 .29893 Mdot
.31418 .4911 Mdot
.59871 .62781 Mdot
.30845 .38839 Mdot
.53568 .67328 Mdot
.29966 .59987 Mdot
.72792 .44522 Mdot
.31726 .48814 Mdot
.57025 .62835 Mdot
.50845 .53154 Mdot
.41481 .70866 Mdot
.30528 .46465 Mdot
.5084 .5411 Mdot
.51033 .62188 Mdot
.65809 .4554 Mdot
.46852 .51299 Mdot
.67445 .42569 Mdot
.56716 .62122 Mdot
.29069 .56525 Mdot
.68098 .46314 Mdot
.6041 .23965 Mdot
.33443 .53627 Mdot
.49992 .28159 Mdot
.50084 .62945 Mdot
.55171 .5988 Mdot
.66185 .7372 Mdot
.45276 .51139 Mdot
.55174 .2098 Mdot
.33472 .33449 Mdot
.17509 .54858 Mdot
.37583 .38597 Mdot
.44015 .32774 Mdot
.56916 .37441 Mdot
.49879 .60966 Mdot
.77966 .48751 Mdot
.61848 .74693 Mdot
.52374 .27587 Mdot
.641 .74315 Mdot
.5673 .66409 Mdot
.54561 .60478 Mdot
.33994 .34048 Mdot
.54999 .31614 Mdot
.58572 .71557 Mdot
.3548 .67454 Mdot
.30661 .4766 Mdot
.67807 .43913 Mdot
.55818 .66202 Mdot
.69007 .36848 Mdot
.32689 .32401 Mdot
.62758 .53026 Mdot
.53776 .63787 Mdot
.4877 .52816 Mdot
.54775 .31098 Mdot
.49638 .30587 Mdot
.34556 .3307 Mdot
.3394 .32578 Mdot
.5552 .60185 Mdot
.53145 .33885 Mdot
.55164 .68543 Mdot
.36242 .69232 Mdot
.50113 .53871 Mdot
.33572 .50238 Mdot
.54842 .67263 Mdot
.73911 .47461 Mdot
.39406 .82271 Mdot
.52843 .59279 Mdot
.65682 .46983 Mdot
.34193 .3521 Mdot
.34605 .38489 Mdot
.64974 .43428 Mdot
.34431 .38436 Mdot
.65536 .54585 Mdot
.76396 .66226 Mdot
.33142 .5008 Mdot
.6412 .60433 Mdot
.30722 .50025 Mdot
.45504 .51214 Mdot
.54598 .62602 Mdot
.41919 .19207 Mdot
.31343 .36999 Mdot
.39523 .54505 Mdot
.50391 .31206 Mdot
.44798 .50328 Mdot
.56812 .70377 Mdot
.35961 .511 Mdot
.33735 .37067 Mdot
.44863 .49036 Mdot
.53001 .61574 Mdot
.69002 .46253 Mdot
.51292 .65373 Mdot
.45726 .49972 Mdot
.46194 .50916 Mdot
.51386 .54293 Mdot
.50795 .27908 Mdot
.70116 .43138 Mdot
.48987 .24807 Mdot
.31792 .36667 Mdot
.57846 .67918 Mdot
.56957 .65235 Mdot
.70671 .41844 Mdot
.53003 .64458 Mdot
.53379 .33868 Mdot
.75768 .24161 Mdot
.32565 .52112 Mdot
.45323 .51551 Mdot
.62466 .27812 Mdot
.51453 .54386 Mdot
.5115 .63127 Mdot
.45884 .69612 Mdot
.64186 .52649 Mdot
.50234 .27934 Mdot
.54788 .57999 Mdot
.35858 .39685 Mdot
.32905 .51735 Mdot
.49937 .32648 Mdot
.56164 .70087 Mdot
.53916 .65217 Mdot
.31692 .48972 Mdot
.42834 .37577 Mdot
.30116 .50992 Mdot
.53558 .3127 Mdot
.4551 .52207 Mdot
.41175 .63048 Mdot
.54761 .63674 Mdot
.47909 .52132 Mdot
.69387 .43862 Mdot
.53885 .31431 Mdot
.73292 .54161 Mdot
.46856 .50291 Mdot
.54248 .2584 Mdot
.49659 .30209 Mdot
.53924 .60087 Mdot
.65833 .46459 Mdot
.72471 .40921 Mdot
.69269 .44245 Mdot
.24425 .62963 Mdot
.49471 .23971 Mdot
.34498 .35312 Mdot
.51672 .31814 Mdot
.32078 .33875 Mdot
.30172 .4944 Mdot
.34677 .71208 Mdot
.33107 .32162 Mdot
.63763 .4396 Mdot
.31906 .33387 Mdot
.5503 .68426 Mdot
.49635 .28633 Mdot
.30789 .32112 Mdot
.55747 .67636 Mdot
.59076 .66074 Mdot
.47382 .51327 Mdot
.32075 .45959 Mdot
.36201 .67392 Mdot
.53254 .62985 Mdot
.47777 .52324 Mdot
.54023 .63114 Mdot
.53236 .33937 Mdot
.36226 .62041 Mdot
.58225 .6702 Mdot
.312 .36801 Mdot
.64117 .22902 Mdot
.34618 .39968 Mdot
.55524 .49439 Mdot
.54611 .61416 Mdot
.54785 .6331 Mdot
.57461 .69639 Mdot
.79112 .49399 Mdot
.50753 .26672 Mdot
.53319 .58215 Mdot
.37202 .37608 Mdot
.66146 .43916 Mdot
.65089 .4583 Mdot
.44121 .65622 Mdot
.47356 .51783 Mdot
.52968 .3437 Mdot
.54924 .6321 Mdot
.45808 .50392 Mdot
.34271 .66166 Mdot
.74113 .35801 Mdot
.363 .41879 Mdot
.33486 .38497 Mdot
.70945 .44198 Mdot
.36209 .38459 Mdot
.56427 .70155 Mdot
.4808 .50984 Mdot
.503 .23681 Mdot
.51938 .35878 Mdot
.32914 .51668 Mdot
.55065 .6118 Mdot
.32925 .7308 Mdot
.3671 .37889 Mdot
.35164 .33276 Mdot
.55342 .68588 Mdot
.72079 .46927 Mdot
.34774 .78951 Mdot
.54195 .31065 Mdot
.68399 .64707 Mdot
.81129 .54896 Mdot
.53869 .78266 Mdot
.52431 .32297 Mdot
.45093 .55549 Mdot
.33806 .31848 Mdot
.22762 .53027 Mdot
.66281 .44281 Mdot
.33259 .51712 Mdot
.55524 .67613 Mdot
.63827 .43917 Mdot
.3194 .37899 Mdot
.69182 .40777 Mdot
.49377 .53046 Mdot
.49427 .2885 Mdot
.34715 .38015 Mdot
.5199 .34984 Mdot
.63018 .43254 Mdot
.31083 .50496 Mdot
.28481 .61708 Mdot
.66603 .6487 Mdot
.74903 .51736 Mdot
.57152 .70783 Mdot
.28798 .53053 Mdot
.57437 .70462 Mdot
.72416 .44036 Mdot
.53523 .63605 Mdot
.58905 .64176 Mdot
.35155 .32711 Mdot
.54274 .59867 Mdot
.55317 .67309 Mdot
.7459 .66627 Mdot
.55532 .61959 Mdot
.56155 .61029 Mdot
.53856 .59918 Mdot
.64469 .45583 Mdot
.52675 .61668 Mdot
.70506 .43423 Mdot
.69627 .35672 Mdot
.31836 .36683 Mdot
.30312 .50103 Mdot
.30409 .50163 Mdot
.30837 .58742 Mdot
.32739 .72805 Mdot
.80537 .46401 Mdot
.66596 .43272 Mdot
.50016 .29681 Mdot
.55312 .68354 Mdot
.30499 .74568 Mdot
.2928 .56825 Mdot
.31771 .31243 Mdot
.31554 .32323 Mdot
.57297 .67143 Mdot
.75226 .73443 Mdot
.52588 .64858 Mdot
.35268 .64949 Mdot
.55659 .65801 Mdot
.52193 .61694 Mdot
.3729 .3879 Mdot
.29461 .66238 Mdot
.57559 .70078 Mdot
.70094 .46386 Mdot
.3336 .51503 Mdot
.47517 .51648 Mdot
.29703 .57459 Mdot
.808 .5805 Mdot
.71234 .48613 Mdot
.57652 .69538 Mdot
.36756 .36386 Mdot
.65873 .42137 Mdot
.36391 .65308 Mdot
.5408 .32699 Mdot
.31892 .66241 Mdot
.6495 .7026 Mdot
.54104 .3027 Mdot
.32355 .51524 Mdot
.29401 .32841 Mdot
.55008 .60048 Mdot
.35646 .35657 Mdot
.52146 .5883 Mdot
.33827 .65639 Mdot
.33319 .50275 Mdot
.68079 .47835 Mdot
.52289 .29086 Mdot
.63987 .44022 Mdot
.62222 .51726 Mdot
.29002 .56719 Mdot
.15748 .52072 Mdot
.33624 .39481 Mdot
.60107 .56547 Mdot
.69323 .4516 Mdot
.56582 .60882 Mdot
.8026 .32167 Mdot
.69119 .4324 Mdot
.68347 .46422 Mdot
.33187 .63614 Mdot
.29127 .66973 Mdot
.51945 .59225 Mdot
.66296 .41383 Mdot
.29494 .33275 Mdot
.33178 .49335 Mdot
.56512 .67371 Mdot
.47753 .51041 Mdot
.65196 .45395 Mdot
.33455 .37313 Mdot
.29482 .6501 Mdot
.35626 .37403 Mdot
.66271 .45108 Mdot
.30863 .34073 Mdot
.50062 .24762 Mdot
.32937 .32103 Mdot
.53935 .66272 Mdot
.54904 .63318 Mdot
.71457 .39886 Mdot
.6652 .41894 Mdot
.51153 .63227 Mdot
.5292 .62731 Mdot
.68641 .4518 Mdot
.29899 .35198 Mdot
.66683 .51211 Mdot
.51344 .62926 Mdot
.55291 .63354 Mdot
.3211 .52076 Mdot
.38584 .67611 Mdot
.37198 .64259 Mdot
.54612 .67885 Mdot
.31116 .49973 Mdot
.69998 .4573 Mdot
.54097 .62661 Mdot
.29177 .65916 Mdot
.30437 .30853 Mdot
.55566 .69165 Mdot
.47252 .53187 Mdot
.57062 .71143 Mdot
.43307 .80887 Mdot
.5737 .69621 Mdot
.67095 .45076 Mdot
.67329 .45746 Mdot
.29047 .31452 Mdot
.67418 .44507 Mdot
.45275 .51427 Mdot
.49931 .30911 Mdot
.67758 .67411 Mdot
.44667 .50516 Mdot
.51226 .55012 Mdot
.36194 .53171 Mdot
.47049 .50045 Mdot
.48352 .49939 Mdot
.36607 .41957 Mdot
.48507 .54223 Mdot
.699 .44152 Mdot
.60867 .42664 Mdot
.52184 .56417 Mdot
.5341 .34049 Mdot
.47464 .50484 Mdot
.55403 .69169 Mdot
.58736 .62777 Mdot
.62259 .49633 Mdot
.54244 .32441 Mdot
.57761 .57887 Mdot
.5648 .67401 Mdot
.64016 .52387 Mdot
.55946 .66315 Mdot
.31942 .46806 Mdot
.68133 .42513 Mdot
.36324 .37447 Mdot
.3366 .49881 Mdot
.50558 .5324 Mdot
.34421 .49975 Mdot
.35116 .3522 Mdot
.51076 .2908 Mdot
.53892 .66007 Mdot
.30175 .47321 Mdot
.3033 .49196 Mdot
.51122 .65595 Mdot
.67438 .45902 Mdot
.55741 .57708 Mdot
.54332 .62286 Mdot
.57462 .69726 Mdot
.64778 .43654 Mdot
.50745 .17422 Mdot
.55285 .60483 Mdot
.44928 .55239 Mdot
.72245 .44699 Mdot
.45517 .50223 Mdot
.36463 .3693 Mdot
.50737 .59388 Mdot
.50852 .33178 Mdot
.50138 .31264 Mdot
.31041 .3636 Mdot
.64739 .44642 Mdot
.34398 .38191 Mdot
.53753 .59038 Mdot
.47579 .50483 Mdot
.56568 .6696 Mdot
.42876 .34641 Mdot
.57785 .22112 Mdot
.70277 .41875 Mdot
.32268 .37483 Mdot
.33973 .68513 Mdot
.50228 .27722 Mdot
.36156 .41218 Mdot
.7081 .45923 Mdot
.65363 .41883 Mdot
.65178 .43422 Mdot
.30627 .48727 Mdot
.3496 .37585 Mdot
.63495 .41211 Mdot
.62903 .41865 Mdot
.53735 .68713 Mdot
.56449 .67601 Mdot
.70532 .45097 Mdot
.3215 .39862 Mdot
.32347 .51226 Mdot
.36839 .38456 Mdot
.35844 .79873 Mdot
.54071 .31078 Mdot
.74841 .6634 Mdot
.53939 .67696 Mdot
.89791 .57039 Mdot
.52564 .64679 Mdot
.56449 .65952 Mdot
.63661 .41362 Mdot
.31587 .52416 Mdot
.32899 .49181 Mdot
.69141 .45293 Mdot
.68714 .40286 Mdot
.32539 .47204 Mdot
.39645 .6476 Mdot
.4014 .79954 Mdot
.35124 .66121 Mdot
.69389 .41098 Mdot
.66666 .67784 Mdot
.51879 .30722 Mdot
.72505 .45183 Mdot
.50526 .25295 Mdot
.30594 .33816 Mdot
.32292 .31951 Mdot
.50747 .28618 Mdot
.55544 .60623 Mdot
.36781 .39299 Mdot
.57752 .71036 Mdot
.4567 .29835 Mdot
.47532 .55376 Mdot
.21928 .66455 Mdot
.53315 .65082 Mdot
.55042 .47745 Mdot
.72201 .32745 Mdot
.51856 .66167 Mdot
.77086 .62712 Mdot
.33705 .51764 Mdot
.72503 .43522 Mdot
.54562 .32053 Mdot
.81139 .45603 Mdot
.54782 .63515 Mdot
.67375 .41135 Mdot
.52813 .29261 Mdot
.5638 .21809 Mdot
.44624 .56009 Mdot
.53025 .68053 Mdot
.79699 .30504 Mdot
.65501 .47251 Mdot
.36312 .37169 Mdot
.68487 .62094 Mdot
.68195 .39982 Mdot
.4434 .57055 Mdot
.30142 .35204 Mdot
.41495 .6909 Mdot
.67979 .40699 Mdot
.30489 .51641 Mdot
.67628 .43539 Mdot
.33633 .4805 Mdot
.64117 .40705 Mdot
.31614 .35985 Mdot
.55628 .6155 Mdot
.31782 .36442 Mdot
.33965 .47698 Mdot
.33091 .3888 Mdot
.54531 .31846 Mdot
.4896 .5419 Mdot
.50411 .30459 Mdot
.35425 .72158 Mdot
.73897 .55499 Mdot
.52351 .29907 Mdot
.46059 .68524 Mdot
.54116 .65741 Mdot
.67511 .39738 Mdot
.36222 .37829 Mdot
.36507 .33978 Mdot
.36029 .676 Mdot
.65623 .44845 Mdot
.32839 .36937 Mdot
.66511 .66043 Mdot
.52974 .21076 Mdot
.5892 .67145 Mdot
.29592 .28067 Mdot
.68036 .45199 Mdot
.36824 .34651 Mdot
.35855 .65004 Mdot
.65675 .41337 Mdot
.31172 .31935 Mdot
.52917 .29954 Mdot
.50782 .33088 Mdot
.53355 .65593 Mdot
.5384 .34842 Mdot
.33468 .31826 Mdot
.62548 .54152 Mdot
.6949 .45676 Mdot
.58621 .2245 Mdot
.31721 .51465 Mdot
.35912 .3843 Mdot
.50189 .53184 Mdot
.63292 .43232 Mdot
.31896 .3376 Mdot
.82834 .65678 Mdot
.37233 .83293 Mdot
.33015 .36979 Mdot
.67953 .42586 Mdot
.66413 .42314 Mdot
.51004 .61129 Mdot
.35619 .67721 Mdot
.33563 .36882 Mdot
.4137 .19312 Mdot
.39224 .72652 Mdot
.48404 .53593 Mdot
.15205 .45535 Mdot
.57968 .68989 Mdot
.5698 .70647 Mdot
.53809 .31952 Mdot
.56384 .62341 Mdot
.68867 .40399 Mdot
.5252 .6456 Mdot
.51148 .3382 Mdot
.31004 .36149 Mdot
.54478 .63138 Mdot
.32734 .51752 Mdot
.5267 .33413 Mdot
.52442 .33868 Mdot
.31008 .33901 Mdot
.648 .44566 Mdot
.81895 .44508 Mdot
.35546 .37645 Mdot
.56452 .70706 Mdot
.48042 .52708 Mdot
.53972 .59937 Mdot
.73294 .3903 Mdot
.72182 .43753 Mdot
.363 .38251 Mdot
.49569 .61397 Mdot
.51697 .32339 Mdot
.34354 .32089 Mdot
.58053 .69047 Mdot
.30531 .31844 Mdot
.4251 .49939 Mdot
.25192 .32048 Mdot
.62677 .44231 Mdot
.41971 .49474 Mdot
.65191 .41923 Mdot
.48318 .53937 Mdot
.22946 .58857 Mdot
.32197 .51316 Mdot
.35652 .40127 Mdot
.59838 .23689 Mdot
.32186 .37151 Mdot
.55621 .622 Mdot
.53672 .64954 Mdot
.34274 .3397 Mdot
.31013 .50236 Mdot
.39946 .51689 Mdot
.29722 .50005 Mdot
.67686 .42122 Mdot
.43249 .6609 Mdot
.31195 .78335 Mdot
.32752 .31158 Mdot
.50207 .28869 Mdot
.74796 .44578 Mdot
.51163 .54831 Mdot
.54435 .31973 Mdot
.52771 .33706 Mdot
.34471 .48762 Mdot
.34513 .38963 Mdot
.69109 .47409 Mdot
.4929 .30255 Mdot
.66668 .40434 Mdot
.29026 .64721 Mdot
.46303 .49845 Mdot
.61518 .6138 Mdot
.50744 .52947 Mdot
.36569 .66913 Mdot
.49284 .29564 Mdot
.54477 .65293 Mdot
.59379 .60673 Mdot
.53234 .30083 Mdot
.34771 .49398 Mdot
.48574 .55817 Mdot
.32602 .36654 Mdot
.81995 .36233 Mdot
.54102 .66566 Mdot
.54648 .6175 Mdot
.53671 .30398 Mdot
.79034 .60648 Mdot
.7038 .46032 Mdot
.66001 .45798 Mdot
.34674 .35848 Mdot
.33926 .63374 Mdot
.52681 .62011 Mdot
.54109 .66077 Mdot
.34105 .33592 Mdot
.46759 .5156 Mdot
.15035 .49931 Mdot
.55415 .63945 Mdot
.51654 .31313 Mdot
.45669 .54993 Mdot
.51828 .27182 Mdot
.57104 .5979 Mdot
.55973 .62757 Mdot
.54913 .69981 Mdot
.57932 .69612 Mdot
.50689 .30225 Mdot
.5082 .53664 Mdot
.51817 .55841 Mdot
.69687 .43848 Mdot
.5806 .64437 Mdot
.39412 .7258 Mdot
.5513 .63957 Mdot
.33329 .51909 Mdot
.36843 .64005 Mdot
.57828 .68306 Mdot
.58154 .65196 Mdot
.38916 .72811 Mdot
.57347 .6386 Mdot
.53511 .30003 Mdot
.6605 .42795 Mdot
.51721 .3253 Mdot
.5047 .28356 Mdot
.31641 .33609 Mdot
.3495 .51123 Mdot
.52579 .58985 Mdot
.31574 .47366 Mdot
.51769 .60259 Mdot
.55667 .57312 Mdot
.36706 .6956 Mdot
.35231 .65049 Mdot
.31171 .46145 Mdot
.54346 .66261 Mdot
.34952 .35486 Mdot
.35734 .39178 Mdot
.43954 .60802 Mdot
.50127 .59489 Mdot
.54447 .34297 Mdot
.5188 .29307 Mdot
.40355 .40594 Mdot
.24559 .3148 Mdot
.30846 .46894 Mdot
.40124 .51329 Mdot
.58291 .69062 Mdot
.54459 .6088 Mdot
.50612 .54809 Mdot
.32579 .33931 Mdot
.48656 .54334 Mdot
.34709 .41167 Mdot
.54316 .30149 Mdot
.52789 .32756 Mdot
.53586 .65658 Mdot
.72452 .76273 Mdot
.69418 .4233 Mdot
.66264 .42362 Mdot
.50871 .33708 Mdot
.34754 .40034 Mdot
.49506 .52811 Mdot
.83992 .4031 Mdot
.71957 .43745 Mdot
.30322 .50612 Mdot
.57687 .64473 Mdot
.30722 .34448 Mdot
.70238 .4348 Mdot
.30125 .47544 Mdot
.57731 .62324 Mdot
.30643 .36208 Mdot
.54663 .65004 Mdot
.63292 .57868 Mdot
.69964 .44682 Mdot
.3793 .69247 Mdot
.63955 .4545 Mdot
.50812 .30417 Mdot
.49729 .29018 Mdot
.55751 .62707 Mdot
.83808 .39313 Mdot
.65793 .48669 Mdot
.49007 .31818 Mdot
.32753 .52695 Mdot
.49452 .54472 Mdot
.34845 .507 Mdot
.33998 .34255 Mdot
.32382 .51499 Mdot
.31797 .3376 Mdot
.29203 .33626 Mdot
.67202 .47503 Mdot
.31744 .48953 Mdot
.76197 .61145 Mdot
.48234 .51135 Mdot
.34456 .52943 Mdot
.57355 .67948 Mdot
.51415 .61424 Mdot
.33026 .36085 Mdot
.31065 .47558 Mdot
.50472 .59801 Mdot
.61887 .27866 Mdot
.50114 .28212 Mdot
.54568 .31778 Mdot
.49383 .52959 Mdot
.36085 .33986 Mdot
.67109 .4745 Mdot
.34062 .69173 Mdot
.66827 .4799 Mdot
.54259 .66353 Mdot
.52742 .5904 Mdot
.63198 .44791 Mdot
.66419 .47224 Mdot
.56069 .63138 Mdot
.70127 .70125 Mdot
.50287 .53183 Mdot
.50457 .32824 Mdot
.67949 .42049 Mdot
.66936 .41691 Mdot
.33379 .31887 Mdot
.65607 .45746 Mdot
.606 .61701 Mdot
.54445 .30684 Mdot
.51973 .55978 Mdot
.51496 .32007 Mdot
.27819 .49776 Mdot
.32337 .35621 Mdot
.58255 .23031 Mdot
.66125 .46001 Mdot
.51435 .64424 Mdot
.66412 .46332 Mdot
.33466 .523 Mdot
.68327 .4102 Mdot
.73605 .43125 Mdot
.554 .67492 Mdot
.50766 .53908 Mdot
.45803 .51032 Mdot
.36038 .67161 Mdot
.69406 .42916 Mdot
.5323 .59255 Mdot
.52127 .63671 Mdot
.52889 .63109 Mdot
.35918 .69108 Mdot
.64674 .45735 Mdot
.80663 .58331 Mdot
.62044 .42991 Mdot
.70143 .44344 Mdot
.42863 .84149 Mdot
.45425 .50859 Mdot
.50159 .55227 Mdot
.4947 .36327 Mdot
.55484 .63648 Mdot
.33853 .38126 Mdot
.56015 .70477 Mdot
.50466 .54157 Mdot
.57978 .67007 Mdot
.33031 .4822 Mdot
.55181 .59745 Mdot
.47442 .52599 Mdot
.35752 .3791 Mdot
.52235 .66664 Mdot
.54935 .62867 Mdot
.4661 .51295 Mdot
.67024 .4658 Mdot
.64692 .42908 Mdot
.64991 .47761 Mdot
.33679 .47763 Mdot
.52555 .30826 Mdot
.56153 .70463 Mdot
.34788 .35696 Mdot
.33723 .38203 Mdot
.63745 .44525 Mdot
.35216 .33991 Mdot
.53096 .32599 Mdot
.56558 .65547 Mdot
.50695 .30347 Mdot
.33285 .48237 Mdot
.68264 .42477 Mdot
.56682 .70062 Mdot
.52314 .67643 Mdot
.67357 .45749 Mdot
.50038 .52539 Mdot
.33478 .52553 Mdot
.33778 .33065 Mdot
.70633 .42476 Mdot
.49995 .31164 Mdot
.33227 .31976 Mdot
.51742 .65622 Mdot
.54019 .84436 Mdot
.56376 .62419 Mdot
.52713 .62597 Mdot
.63255 .4816 Mdot
.57824 .60799 Mdot
.31765 .3665 Mdot
.65306 .45938 Mdot
.5141 .62032 Mdot
.37338 .73775 Mdot
.30595 .45614 Mdot
.33221 .3105 Mdot
.57268 .6538 Mdot
.65749 .73845 Mdot
.51992 .65143 Mdot
.60974 .24185 Mdot
.36767 .69516 Mdot
.52614 .24521 Mdot
.61105 .60586 Mdot
.49236 .3242 Mdot
.47517 .52173 Mdot
.31416 .34122 Mdot
.73024 .65888 Mdot
.56441 .63395 Mdot
.73727 .52877 Mdot
.56341 .70018 Mdot
.52398 .32565 Mdot
.77901 .60915 Mdot
.36706 .35963 Mdot
.17515 .53999 Mdot
.57399 .62092 Mdot
.71068 .45364 Mdot
.33643 .42236 Mdot
.49979 .54966 Mdot
.50978 .54772 Mdot
.31509 .46805 Mdot
.40579 .39103 Mdot
.5757 .58421 Mdot
.51516 .32301 Mdot
.53841 .60723 Mdot
.52916 .68959 Mdot
.53378 .19514 Mdot
.69157 .44522 Mdot
.5171 .2858 Mdot
.24421 .33126 Mdot
.54499 .6577 Mdot
.65203 .42087 Mdot
.66304 .44249 Mdot
.31915 .47666 Mdot
.53592 .25408 Mdot
.4143 .37521 Mdot
.7127 .75536 Mdot
.58748 .57188 Mdot
.32715 .33716 Mdot
.43832 .49134 Mdot
.55869 .70479 Mdot
.29167 .56679 Mdot
.50003 .29007 Mdot
.5494 .61578 Mdot
.7568 .50934 Mdot
.67913 .449 Mdot
.552 .64907 Mdot
.32724 .51243 Mdot
.82918 .43993 Mdot
.65718 .67237 Mdot
.6722 .72061 Mdot
.29513 .33351 Mdot
.52335 .58998 Mdot
.60486 .61551 Mdot
.4567 .50398 Mdot
.57082 .59648 Mdot
.36217 .37404 Mdot
.42685 .49209 Mdot
.3247 .50703 Mdot
.70174 .43145 Mdot
.47822 .52297 Mdot
.56352 .69973 Mdot
.51798 .58877 Mdot
.32576 .52529 Mdot
.5439 .69522 Mdot
.69254 .63258 Mdot
.44111 .49709 Mdot
.32875 .32235 Mdot
.70328 .41648 Mdot
.52496 .59166 Mdot
.49653 .54557 Mdot
.56277 .66941 Mdot
.73382 .47938 Mdot
.54735 .61294 Mdot
.59483 .263 Mdot
.66425 .45666 Mdot
.50631 .32292 Mdot
.58111 .69068 Mdot
.5459 .64472 Mdot
.41741 .49676 Mdot
.49306 .52476 Mdot
.57906 .64369 Mdot
.64297 .42948 Mdot
.6991 .42717 Mdot
.70997 .45351 Mdot
.31979 .31563 Mdot
.35001 .66627 Mdot
.50723 .30925 Mdot
.50624 .5488 Mdot
.49281 .30293 Mdot
.58818 .74708 Mdot
.3413 .48761 Mdot
.56561 .22545 Mdot
.56558 .65066 Mdot
.65302 .44227 Mdot
.38768 .79112 Mdot
.63868 .4489 Mdot
.4606 .34769 Mdot
.49855 .29284 Mdot
.6881 .43108 Mdot
.57269 .64491 Mdot
.3678 .66168 Mdot
.67375 .73369 Mdot
.50008 .27975 Mdot
.50619 .55622 Mdot
.26715 .50399 Mdot
.29916 .32704 Mdot
.41256 .83434 Mdot
.49481 .31505 Mdot
.7234 .3273 Mdot
.51346 .62855 Mdot
.67375 .46318 Mdot
.51376 .29848 Mdot
.5301 .33787 Mdot
.36704 .35656 Mdot
.53448 .68431 Mdot
.54754 .64593 Mdot
.47175 .53096 Mdot
.50535 .29495 Mdot
.4975 .60262 Mdot
.52409 .67371 Mdot
.43325 .32115 Mdot
.7169 .44847 Mdot
.50426 .17189 Mdot
.48159 .70672 Mdot
.75603 .51066 Mdot
.467 .19231 Mdot
.70948 .43228 Mdot
.55854 .60708 Mdot
.49918 .53445 Mdot
.34236 .33182 Mdot
.56956 .6456 Mdot
.32482 .37732 Mdot
.52662 .31886 Mdot
.60558 .27628 Mdot
.47042 .70083 Mdot
.4512 .31924 Mdot
.55896 .61932 Mdot
.65925 .66415 Mdot
.32065 .49795 Mdot
.54654 .317 Mdot
.68577 .46989 Mdot
.53684 .59643 Mdot
.35978 .34434 Mdot
.30215 .32398 Mdot
.68238 .44625 Mdot
.70348 .3355 Mdot
.58871 .23168 Mdot
.49805 .52421 Mdot
.35821 .35057 Mdot
.4994 .54413 Mdot
.65207 .72862 Mdot
.49052 .31029 Mdot
.32485 .50589 Mdot
.31039 .33167 Mdot
.53185 .34438 Mdot
.51376 .61426 Mdot
.68496 .43973 Mdot
.64119 .46634 Mdot
.43996 .59544 Mdot
.3295 .37126 Mdot
.34005 .49677 Mdot
.44585 .58374 Mdot
.43275 .64675 Mdot
.33468 .50459 Mdot
.3201 .31356 Mdot
.68338 .41508 Mdot
.66433 .45023 Mdot
.65971 .43087 Mdot
.74909 .66115 Mdot
.72149 .43629 Mdot
.28043 .59218 Mdot
.57168 .59735 Mdot
.66957 .67036 Mdot
.52032 .61319 Mdot
.54542 .32054 Mdot
.69704 .45191 Mdot
.36923 .69569 Mdot
.58095 .69659 Mdot
.67703 .73324 Mdot
.53326 .62474 Mdot
.45322 .55026 Mdot
.55438 .63508 Mdot
.64605 .5841 Mdot
.72471 .42817 Mdot
.57309 .61639 Mdot
.52962 .2832 Mdot
.34464 .50986 Mdot
.65268 .40382 Mdot
.56663 .61642 Mdot
.67788 .36577 Mdot
.57321 .68088 Mdot
.60307 .27231 Mdot
.44257 .5783 Mdot
.36425 .45025 Mdot
.53017 .60644 Mdot
.36155 .40758 Mdot
.58119 .71823 Mdot
.66737 .68576 Mdot
.49709 .28477 Mdot
.66237 .66283 Mdot
.36256 .40045 Mdot
.78082 .60735 Mdot
.49401 .52049 Mdot
.32059 .50773 Mdot
.43415 .49043 Mdot
.50108 .32358 Mdot
.56553 .64331 Mdot
.56243 .60778 Mdot
.47922 .55907 Mdot
.64442 .73086 Mdot
.46506 .50813 Mdot
.30973 .46254 Mdot
.65535 .69378 Mdot
.57784 .63974 Mdot
.34277 .31408 Mdot
.64388 .43986 Mdot
.77232 .60462 Mdot
.7845 .5905 Mdot
.51919 .66427 Mdot
.69027 .43402 Mdot
.64756 .44651 Mdot
.32547 .76982 Mdot
.31457 .49748 Mdot
.54232 .61471 Mdot
.41781 .48812 Mdot
.5623 .70404 Mdot
.52267 .31574 Mdot
.58705 .66671 Mdot
.32377 .35821 Mdot
.36376 .64937 Mdot
.31663 .31403 Mdot
.52899 .63305 Mdot
.67487 .43435 Mdot
.5103 .27595 Mdot
.29062 .33384 Mdot
.53557 .25434 Mdot
.27939 .59367 Mdot
.39938 .40013 Mdot
.30739 .47024 Mdot
.3462 .49432 Mdot
.54641 .31747 Mdot
.56956 .65703 Mdot
.3565 .68647 Mdot
.5293 .73357 Mdot
.55789 .64227 Mdot
.56122 .61422 Mdot
.50083 .35726 Mdot
.49754 .29791 Mdot
.30934 .34641 Mdot
.56171 .63315 Mdot
.53944 .59191 Mdot
.68012 .43228 Mdot
.30455 .47784 Mdot
.32371 .32813 Mdot
.32877 .47097 Mdot
.35633 .36576 Mdot
.43452 .80951 Mdot
.4677 .50052 Mdot
.34322 .49541 Mdot
.49489 .32085 Mdot
.65467 .43221 Mdot
.45227 .50936 Mdot
.33693 .34801 Mdot
.35586 .34399 Mdot
.51298 .60238 Mdot
.70161 .43531 Mdot
.66074 .45879 Mdot
.32667 .47157 Mdot
.51991 .29474 Mdot
.58094 .70931 Mdot
.50917 .53368 Mdot
.28139 .30931 Mdot
.35287 .3357 Mdot
.66056 .68604 Mdot
.62495 .45865 Mdot
.5586 .66784 Mdot
.64969 .42548 Mdot
.54241 .63498 Mdot
.73939 .42168 Mdot
.65229 .47087 Mdot
.58312 .62119 Mdot
.52675 .70352 Mdot
.32373 .33932 Mdot
.27059 .73586 Mdot
.59097 .64489 Mdot
.48324 .27435 Mdot
.55545 .70227 Mdot
.15643 .52168 Mdot
.37834 .7849 Mdot
.57189 .668 Mdot
.55054 .59838 Mdot
.67924 .78646 Mdot
.52244 .65567 Mdot
.47878 .53364 Mdot
.49127 .51784 Mdot
.65309 .42113 Mdot
.42033 .49306 Mdot
.36312 .67217 Mdot
.31229 .48978 Mdot
.34622 .35716 Mdot
.29289 .66714 Mdot
.33762 .48116 Mdot
.67447 .45146 Mdot
.58063 .71054 Mdot
.63575 .4794 Mdot
.37656 .38163 Mdot
.48045 .5212 Mdot
.52502 .32203 Mdot
.35915 .6815 Mdot
.36315 .34923 Mdot
.49888 .30785 Mdot
.52087 .64636 Mdot
.32548 .39786 Mdot
.52422 .27681 Mdot
.27986 .74628 Mdot
.53879 .32593 Mdot
.49818 .31389 Mdot
.3527 .67359 Mdot
.31219 .48961 Mdot
.43044 .49646 Mdot
.53581 .56491 Mdot
.5175 .27919 Mdot
.19347 .55971 Mdot
.36455 .34765 Mdot
.33616 .66173 Mdot
.72601 .43054 Mdot
.47294 .50465 Mdot
.55851 .61454 Mdot
.53913 .31683 Mdot
.49413 .61249 Mdot
.4165 .49683 Mdot
.52185 .33324 Mdot
.57058 .71576 Mdot
.34404 .63367 Mdot
.49405 .54158 Mdot
.45547 .51147 Mdot
.29925 .48477 Mdot
.26607 .37147 Mdot
.65107 .44621 Mdot
.30534 .5092 Mdot
.36772 .71534 Mdot
.53204 .62155 Mdot
.50833 .30145 Mdot
.47885 .52289 Mdot
.5032 .31543 Mdot
.32611 .49576 Mdot
.33292 .52713 Mdot
.69637 .43965 Mdot
.70613 .45709 Mdot
.4461 .51209 Mdot
.39483 .73093 Mdot
.55696 .69072 Mdot
.7308 .54362 Mdot
.65944 .4714 Mdot
.76886 .63977 Mdot
.30888 .48704 Mdot
.30552 .47867 Mdot
.63284 .70135 Mdot
.55195 .68229 Mdot
.45542 .54927 Mdot
.57883 .68156 Mdot
.19591 .53813 Mdot
.56622 .69934 Mdot
.34504 .33606 Mdot
.58306 .66811 Mdot
.75006 .37411 Mdot
.50771 .6167 Mdot
.57443 .63215 Mdot
.34479 .36945 Mdot
.51955 .59604 Mdot
.32765 .36036 Mdot
.55163 .60654 Mdot
.38757 .33623 Mdot
.34792 .35755 Mdot
.30656 .5368 Mdot
.46196 .57961 Mdot
.46815 .52424 Mdot
.32158 .48076 Mdot
.31046 .4671 Mdot
.29399 .64488 Mdot
.68877 .41815 Mdot
.78851 .50295 Mdot
.57602 .64211 Mdot
.36159 .34266 Mdot
.52879 .31589 Mdot
.51237 .65057 Mdot
.52644 .63992 Mdot
.59084 .6449 Mdot
.69459 .43477 Mdot
.34468 .32298 Mdot
.32428 .48761 Mdot
.34202 .39012 Mdot
.37703 .32652 Mdot
.32321 .35177 Mdot
.51295 .70473 Mdot
.51378 .61017 Mdot
.60501 .61664 Mdot
.74994 .5761 Mdot
.36689 .51242 Mdot
.68478 .44293 Mdot
.47659 .52407 Mdot
.34694 .49886 Mdot
.37407 .63108 Mdot
.64843 .43792 Mdot
.34242 .3371 Mdot
.54625 .65003 Mdot
.46314 .49718 Mdot
.53612 .56566 Mdot
.67265 .4008 Mdot
.35082 .52404 Mdot
.34031 .35563 Mdot
.4858 .53586 Mdot
.34866 .66278 Mdot
.81231 .54963 Mdot
.34833 .71639 Mdot
.54399 .64084 Mdot
.32665 .47243 Mdot
.70213 .43424 Mdot
.46209 .54826 Mdot
.5345 .30571 Mdot
.35767 .67597 Mdot
.56102 .61997 Mdot
.45847 .35731 Mdot
.67389 .43561 Mdot
.31179 .5062 Mdot
.53965 .31898 Mdot
.31444 .50134 Mdot
.49685 .55059 Mdot
.61982 .43372 Mdot
.50967 .54808 Mdot
.57406 .69604 Mdot
.52709 .3149 Mdot
.65373 .45025 Mdot
.39435 .34227 Mdot
.44523 .51792 Mdot
.34273 .34051 Mdot
.37795 .63711 Mdot
.70029 .42967 Mdot
.43501 .34477 Mdot
.34042 .38968 Mdot
.52604 .36095 Mdot
.38729 .66735 Mdot
.53069 .32921 Mdot
.57141 .62441 Mdot
.66544 .42863 Mdot
.49973 .2797 Mdot
.2972 .37815 Mdot
.70914 .71486 Mdot
.43932 .50473 Mdot
.53966 .65544 Mdot
.61742 .24077 Mdot
.73165 .3409 Mdot
.72203 .40548 Mdot
.49857 .32489 Mdot
.55021 .62189 Mdot
.49649 .52148 Mdot
.5766 .62605 Mdot
.51289 .27926 Mdot
.56185 .3503 Mdot
.36583 .38688 Mdot
.54604 .65407 Mdot
.32538 .51806 Mdot
.3193 .35597 Mdot
.29924 .3388 Mdot
.31013 .32964 Mdot
.68732 .46897 Mdot
.463 .50064 Mdot
.48913 .515 Mdot
.35841 .76713 Mdot
.50329 .32136 Mdot
.46843 .52431 Mdot
.55445 .59976 Mdot
.28182 .59607 Mdot
.65554 .44057 Mdot
.33732 .35771 Mdot
.54535 .61762 Mdot
.44007 .59007 Mdot
.47154 .51442 Mdot
.35184 .37597 Mdot
.66549 .47302 Mdot
.60424 .48307 Mdot
.5687 .64791 Mdot
.55168 .69748 Mdot
.67768 .45499 Mdot
.76581 .3542 Mdot
.34654 .65821 Mdot
.54381 .63446 Mdot
.50091 .31574 Mdot
.71877 .27854 Mdot
.51957 .64059 Mdot
.68739 .48134 Mdot
.4821 .54152 Mdot
.62493 .40517 Mdot
.68739 .64652 Mdot
.50517 .65107 Mdot
.54894 .44009 Mdot
.39745 .54613 Mdot
.57184 .47593 Mdot
.21712 .54262 Mdot
.47487 .43091 Mdot
.30194 .77008 Mdot
.54897 .3215 Mdot
.64014 .59179 Mdot
.81942 .66357 Mdot
.70928 .32791 Mdot
.42339 .44108 Mdot
.57555 .33241 Mdot
.30582 .44984 Mdot
.14863 .48481 Mdot
.35005 .41294 Mdot
.22059 .53832 Mdot
.57296 .69505 Mdot
.75735 .35272 Mdot
.646 .60625 Mdot
.37865 .42639 Mdot
.50957 .23984 Mdot
.44331 .58234 Mdot
.61654 .79579 Mdot
.4587 .29973 Mdot
.5029 .83104 Mdot
.76897 .50489 Mdot
.26782 .33015 Mdot
.41024 .65596 Mdot
.27814 .64956 Mdot
.66015 .6385 Mdot
.59013 .4382 Mdot
.54694 .29703 Mdot
.65546 .52737 Mdot
.48123 .18948 Mdot
.35259 .34863 Mdot
.67538 .40232 Mdot
.57132 .37237 Mdot
.56659 .81255 Mdot
.46444 .32345 Mdot
.54733 .44059 Mdot
.44766 .51899 Mdot
.64374 .58511 Mdot
.37478 .69741 Mdot
.63534 .56363 Mdot
.41274 .38898 Mdot
.15129 .48483 Mdot
.63396 .48951 Mdot
.2937 .38105 Mdot
.35398 .61673 Mdot
.40589 .44159 Mdot
.66594 .59775 Mdot
.35077 .48681 Mdot
.3024 .53422 Mdot
.66365 .47347 Mdot
.60723 .78008 Mdot
.46391 .67176 Mdot
.37373 .7181 Mdot
.34983 .41422 Mdot
.69215 .49377 Mdot
.82433 .43819 Mdot
.71603 .34441 Mdot
.23356 .69473 Mdot
.53976 .84011 Mdot
.22041 .60309 Mdot
.47798 .56861 Mdot
.46629 .33436 Mdot
.30184 .58419 Mdot
.54453 .47637 Mdot
.23124 .63756 Mdot
.73735 .47599 Mdot
.66021 .77546 Mdot
.64075 .36572 Mdot
.57966 .8257 Mdot
.62515 .48989 Mdot
.58847 .598 Mdot
.68916 .39026 Mdot
.61911 .5393 Mdot
.33912 .72747 Mdot
.59167 .81037 Mdot
.37093 .43153 Mdot
.49596 .55595 Mdot
.6967 .32561 Mdot
.69109 .63236 Mdot
.42191 .37003 Mdot
.30336 .52583 Mdot
.77013 .57462 Mdot
.61856 .80407 Mdot
.56031 .4358 Mdot
.55592 .78756 Mdot
.43084 .32018 Mdot
.33356 .27201 Mdot
.30216 .34869 Mdot
.50322 .34027 Mdot
.52091 .83224 Mdot
.66359 .43402 Mdot
.26193 .73305 Mdot
.48017 .4406 Mdot
.46887 .45806 Mdot
.62354 .80179 Mdot
.21934 .65113 Mdot
.67368 .64437 Mdot
.38153 .52723 Mdot
.53457 .2152 Mdot
.58971 .51 Mdot
.44417 .3271 Mdot
.27845 .51604 Mdot
.60645 .25759 Mdot
.53775 .82684 Mdot
.21265 .61692 Mdot
.72848 .74637 Mdot
.38388 .71575 Mdot
.24833 .51873 Mdot
.6384 .48938 Mdot
.48315 .40108 Mdot
.42991 .37004 Mdot
.57007 .83179 Mdot
.65453 .67781 Mdot
.67449 .24571 Mdot
.21894 .55766 Mdot
.78856 .59295 Mdot
.64593 .26868 Mdot
.55669 .37877 Mdot
.61314 .53177 Mdot
.68017 .36312 Mdot
.51314 .52964 Mdot
.32771 .71086 Mdot
.7705 .55552 Mdot
.35895 .44423 Mdot
.3584 .65755 Mdot
.6408 .34922 Mdot
.25198 .64647 Mdot
.69296 .26988 Mdot
.77511 .5668 Mdot
.63264 .44495 Mdot
.23216 .63676 Mdot
.21569 .57261 Mdot
.65908 .24838 Mdot
.24339 .33563 Mdot
.55191 .7907 Mdot
.44889 .36716 Mdot
.5126 .67129 Mdot
.63917 .59425 Mdot
.66018 .6329 Mdot
.16439 .5039 Mdot
.51474 .69973 Mdot
.31683 .75418 Mdot
.49275 .25571 Mdot
.7393 .5975 Mdot
.29622 .70655 Mdot
.74714 .58668 Mdot
.67893 .67154 Mdot
.74011 .39024 Mdot
.50055 .25907 Mdot
.49371 .65947 Mdot
.62342 .79797 Mdot
.31253 .34869 Mdot
.2294 .63868 Mdot
.45999 .31656 Mdot
.28762 .35099 Mdot
.43955 .45232 Mdot
.41699 .45104 Mdot
.46876 .84124 Mdot
.68204 .32288 Mdot
.2865 .45748 Mdot
.60997 .44912 Mdot
.51282 .45432 Mdot
.73651 .54768 Mdot
.49452 .70841 Mdot
.71164 .48786 Mdot
.33469 .52565 Mdot
.73654 .63553 Mdot
.68339 .37554 Mdot
.23734 .34306 Mdot
.51859 .7134 Mdot
.41395 .65642 Mdot
.46638 .52815 Mdot
.30873 .63676 Mdot
.42801 .80914 Mdot
.50136 .65361 Mdot
.22574 .65881 Mdot
.70038 .3308 Mdot
.30671 .64223 Mdot
.42809 .37414 Mdot
.79333 .5065 Mdot
.58283 .82481 Mdot
.395 .82161 Mdot
.76714 .37107 Mdot
.63615 .26089 Mdot
.21706 .31439 Mdot
.51861 .24703 Mdot
.283 .73482 Mdot
.46001 .31714 Mdot
.75827 .24349 Mdot
.31741 .36782 Mdot
.28399 .56375 Mdot
.63024 .5087 Mdot
.41603 .62913 Mdot
.58685 .80091 Mdot
.67593 .62615 Mdot
.34746 .52985 Mdot
.70474 .39805 Mdot
.51777 .69461 Mdot
.60865 .79099 Mdot
.63443 .78418 Mdot
.61527 .78486 Mdot
.52488 .37501 Mdot
.6837 .71043 Mdot
.65677 .79531 Mdot
.28663 .58707 Mdot
.47062 .61948 Mdot
.51361 .66543 Mdot
.38155 .74224 Mdot
.26852 .7105 Mdot
.36128 .50127 Mdot
.59222 .51289 Mdot
.63276 .48792 Mdot
.63968 .80506 Mdot
.41309 .80717 Mdot
.63061 .55978 Mdot
.47486 .83575 Mdot
.27462 .459 Mdot
.3112 .72987 Mdot
.43536 .83337 Mdot
.57785 .43431 Mdot
.49148 .36927 Mdot
.65787 .80426 Mdot
.22562 .58606 Mdot
.57464 .33683 Mdot
.67951 .36814 Mdot
.26699 .71696 Mdot
.63631 .27017 Mdot
.57239 .35393 Mdot
.631 .50376 Mdot
.81594 .51164 Mdot
.42652 .42716 Mdot
.59099 .44433 Mdot
.46997 .56211 Mdot
.29304 .7095 Mdot
.32471 .38091 Mdot
.24255 .6588 Mdot
.42319 .40645 Mdot
.47552 .61749 Mdot
.30355 .66831 Mdot
.20451 .58521 Mdot
.61015 .38692 Mdot
.66656 .72628 Mdot
.69195 .3288 Mdot
.71099 .27807 Mdot
.65822 .26305 Mdot
.77803 .53162 Mdot
.52197 .59391 Mdot
.57295 .8113 Mdot
.33676 .80583 Mdot
.44503 .83831 Mdot
.67225 .25538 Mdot
.32759 .28489 Mdot
.54211 .34272 Mdot
.29022 .59953 Mdot
.42149 .60999 Mdot
.5612 .41115 Mdot
.41123 .54118 Mdot
.48663 .30827 Mdot
.82594 .43548 Mdot
.44998 .45165 Mdot
.28852 .59016 Mdot
.6673 .52267 Mdot
.50168 .45936 Mdot
.64988 .73065 Mdot
.63315 .44866 Mdot
.63977 .23306 Mdot
.23325 .64056 Mdot
.31137 .34276 Mdot
.27995 .30698 Mdot
.48991 .6679 Mdot
.59234 .6067 Mdot
.26339 .50556 Mdot
.48655 .62139 Mdot
.75524 .51321 Mdot
.32134 .28711 Mdot
.36014 .79106 Mdot
.26854 .73044 Mdot
.4304 .83209 Mdot
.21647 .59689 Mdot
.28872 .36351 Mdot
.31512 .64454 Mdot
.47745 .31398 Mdot
.46867 .28522 Mdot
.33073 .63096 Mdot
.20911 .58062 Mdot
.67427 .64978 Mdot
.70284 .39476 Mdot
.50059 .61071 Mdot
.39519 .79488 Mdot
.27355 .62835 Mdot
.31614 .62482 Mdot
.79983 .53455 Mdot
.71313 .46199 Mdot
.25032 .5396 Mdot
.59942 .43617 Mdot
.59727 .71578 Mdot
.63908 .25641 Mdot
.49445 .2837 Mdot
.636 .45729 Mdot
.20377 .58627 Mdot
.25496 .29293 Mdot
.55284 .46938 Mdot
.46351 .6839 Mdot
.54089 .81963 Mdot
.45366 .60327 Mdot
.62236 .26665 Mdot
.82935 .51705 Mdot
.46787 .26386 Mdot
.63273 .49333 Mdot
.479 .59807 Mdot
.43215 .45531 Mdot
.76666 .39543 Mdot
.64926 .41174 Mdot
.6557 .66833 Mdot
.51932 .83889 Mdot
.44908 .57438 Mdot
.58381 .45183 Mdot
.33949 .68912 Mdot
.45876 .40308 Mdot
.49475 .44538 Mdot
.2998 .67028 Mdot
.56294 .4602 Mdot
.58062 .77607 Mdot
.83185 .41403 Mdot
.59923 .52394 Mdot
.26087 .55525 Mdot
.29231 .59477 Mdot
.76966 .50374 Mdot
.66217 .5933 Mdot
.48202 .25859 Mdot
.57762 .69145 Mdot
.50984 .84729 Mdot
.64357 .35743 Mdot
.3052 .65619 Mdot
.47827 .37446 Mdot
.52544 .6668 Mdot
.58689 .59265 Mdot
.44714 .83654 Mdot
.62631 .40189 Mdot
.85504 .62358 Mdot
.20886 .54586 Mdot
.75506 .43533 Mdot
.68415 .64981 Mdot
.23323 .6679 Mdot
.7554 .40532 Mdot
.49496 .43635 Mdot
.42904 .39933 Mdot
.2552 .6974 Mdot
.63992 .38707 Mdot
.61755 .40876 Mdot
.63186 .24169 Mdot
.65929 .78929 Mdot
.58559 .48991 Mdot
.53241 .36472 Mdot
.27128 .46515 Mdot
.52712 .62335 Mdot
.70704 .33626 Mdot
.57124 .22396 Mdot
.49263 .38367 Mdot
.57619 .49005 Mdot
.3336 .80618 Mdot
.54484 .7082 Mdot
.67855 .3289 Mdot
.84918 .63098 Mdot
.87752 .59657 Mdot
.73895 .37069 Mdot
.56113 .83708 Mdot
.61486 .4172 Mdot
.62229 .26984 Mdot
.51396 .26429 Mdot
.43425 .66159 Mdot
.73362 .53492 Mdot
.47466 .84985 Mdot
.2649 .28513 Mdot
.44311 .32867 Mdot
.64838 .51694 Mdot
.47046 .8512 Mdot
.53674 .70374 Mdot
.26366 .55062 Mdot
.33627 .27248 Mdot
.17681 .54563 Mdot
.2327 .68938 Mdot
.80686 .52925 Mdot
.16196 .50896 Mdot
.21203 .51386 Mdot
.38637 .43287 Mdot
.27224 .73073 Mdot
.57713 .56867 Mdot
.80648 .50506 Mdot
.23152 .63368 Mdot
.62205 .25265 Mdot
.1812 .38429 Mdot
.50342 .44653 Mdot
.48514 .60693 Mdot
.73442 .37883 Mdot
.60394 .25943 Mdot
.61006 .36017 Mdot
.4603 .61787 Mdot
.3781 .64521 Mdot
.67442 .67638 Mdot
.7143 .27233 Mdot
.83759 .52425 Mdot
.49098 .59467 Mdot
.64414 .7722 Mdot
.46479 .2825 Mdot
.33394 .61688 Mdot
.68054 .61367 Mdot
.28229 .6249 Mdot
.27376 .4696 Mdot
.57934 .67532 Mdot
.52576 .83721 Mdot
.27315 .47117 Mdot
.63239 .77813 Mdot
.26215 .73745 Mdot
.48771 .83098 Mdot
.47929 .46363 Mdot
.26981 .50331 Mdot
.26539 .70139 Mdot
.26992 .70511 Mdot
.67404 .76368 Mdot
.22483 .53295 Mdot
.33767 .62931 Mdot
.46913 .58788 Mdot
.46883 .6966 Mdot
.58392 .73761 Mdot
.23544 .6727 Mdot
.78407 .48816 Mdot
.29648 .70262 Mdot
.76699 .37667 Mdot
.20721 .58419 Mdot
.67342 .63718 Mdot
.28666 .63108 Mdot
.46778 .38274 Mdot
.33907 .54043 Mdot
.36595 .3486 Mdot
.7121 .7646 Mdot
.65233 .24987 Mdot
.3342 .76044 Mdot
.66714 .24325 Mdot
.67439 .36363 Mdot
.21048 .53055 Mdot
.67882 .39075 Mdot
.58874 .53551 Mdot
.26705 .3404 Mdot
.26379 .65582 Mdot
.66025 .67572 Mdot
.61002 .24092 Mdot
.79861 .57218 Mdot
.47848 .84384 Mdot
.2987 .71206 Mdot
.75658 .72697 Mdot
.25378 .50737 Mdot
.73777 .63055 Mdot
.60369 .7779 Mdot
.74737 .31553 Mdot
.31574 .61911 Mdot
.62706 .79435 Mdot
.72026 .41332 Mdot
.54502 .8388 Mdot
.53356 .31039 Mdot
.25495 .53084 Mdot
.59174 .23688 Mdot
.30214 .6134 Mdot
.30398 .61193 Mdot
.34272 .77608 Mdot
.69007 .32528 Mdot
.72159 .34309 Mdot
.44786 .36629 Mdot
.34208 .40805 Mdot
.45259 .68846 Mdot
.57612 .44966 Mdot
.72063 .74992 Mdot
.52423 .59385 Mdot
.24559 .49922 Mdot
.22755 .6467 Mdot
.47813 .31912 Mdot
.48886 .57466 Mdot
.60421 .24488 Mdot
.82383 .53483 Mdot
.34113 .74222 Mdot
.65123 .7935 Mdot
.48943 .5732 Mdot
.42077 .59126 Mdot
.78462 .61235 Mdot
.58249 .34667 Mdot
.4613 .2805 Mdot
.55558 .44371 Mdot
.45 .63124 Mdot
.34463 .66089 Mdot
.21987 .59608 Mdot
.31777 .78936 Mdot
.65635 .76856 Mdot
.46305 .27668 Mdot
.30768 .62117 Mdot
.69316 .48019 Mdot
.27087 .6561 Mdot
.74822 .73572 Mdot
.15146 .50487 Mdot
.67964 .36722 Mdot
.20988 .59655 Mdot
.53532 .37952 Mdot
.26516 .55393 Mdot
.32277 .62764 Mdot
.6011 .77975 Mdot
.62894 .51477 Mdot
.62195 .41315 Mdot
.55901 .3815 Mdot
.36601 .67757 Mdot
.4524 .44362 Mdot
.80444 .51437 Mdot
.68566 .32041 Mdot
.75833 .72526 Mdot
.2014 .51314 Mdot
.78004 .60317 Mdot
.80099 .68252 Mdot
.67432 .47464 Mdot
.44198 .44345 Mdot
.35038 .25834 Mdot
.30517 .63526 Mdot
.30329 .33108 Mdot
.49719 .60433 Mdot
.36164 .63272 Mdot
.76089 .38461 Mdot
.29941 .44897 Mdot
.34966 .51808 Mdot
.6346 .44519 Mdot
.21598 .52131 Mdot
.63631 .45971 Mdot
.31541 .78483 Mdot
.57737 .42822 Mdot
.67094 .67637 Mdot
.83185 .55299 Mdot
.28398 .36064 Mdot
.7241 .28867 Mdot
.49778 .83243 Mdot
.37886 .73526 Mdot
.65386 .40744 Mdot
.62985 .42438 Mdot
.61269 .46017 Mdot
.48712 .33026 Mdot
.55143 .81269 Mdot
.22067 .64859 Mdot
.27835 .30972 Mdot
.70639 .40774 Mdot
.46881 .57232 Mdot
.4905 .63137 Mdot
.37685 .79797 Mdot
.33783 .38678 Mdot
.59895 .81992 Mdot
.78658 .49525 Mdot
.74891 .33013 Mdot
.57002 .40259 Mdot
.41446 .68357 Mdot
.32385 .60681 Mdot
.30641 .39791 Mdot
.51429 .67288 Mdot
.75035 .43002 Mdot
.70895 .45151 Mdot
.44466 .44785 Mdot
.30574 .50053 Mdot
.23871 .34525 Mdot
.48063 .28528 Mdot
.7681 .5302 Mdot
.23153 .67387 Mdot
.63056 .44511 Mdot
.26047 .51496 Mdot
.28875 .38282 Mdot
.52527 .71351 Mdot
.40199 .74276 Mdot
.6944 .77937 Mdot
.52011 .82329 Mdot
.6377 .43802 Mdot
.70686 .27835 Mdot
.40213 .34637 Mdot
.35793 .7886 Mdot
.65858 .37918 Mdot
.23454 .66133 Mdot
.76157 .58503 Mdot
.41729 .82299 Mdot
.68693 .64572 Mdot
.55237 .42923 Mdot
.22093 .62235 Mdot
.41447 .48807 Mdot
.20702 .59943 Mdot
.82167 .55076 Mdot
.44844 .66715 Mdot
.18275 .55357 Mdot
.49952 .38133 Mdot
.63379 .56828 Mdot
.59341 .71157 Mdot
.56036 .41465 Mdot
.25497 .69288 Mdot
.65717 .46429 Mdot
.32907 .45574 Mdot
.68177 .51323 Mdot
.44577 .32014 Mdot
.53386 .82723 Mdot
.67142 .2589 Mdot
.21922 .63677 Mdot
.47009 .69469 Mdot
.25451 .60757 Mdot
.78088 .4896 Mdot
.38246 .72204 Mdot
.4934 .51248 Mdot
.76808 .56595 Mdot
.40673 .50427 Mdot
.36904 .77856 Mdot
.5723 .73652 Mdot
.58848 .80606 Mdot
.41604 .80489 Mdot
.73116 .37319 Mdot
.43545 .51392 Mdot
.69105 .40089 Mdot
.6043 .81217 Mdot
.34838 .75065 Mdot
.60108 .25267 Mdot
.23232 .6872 Mdot
.22961 .52302 Mdot
.81234 .6709 Mdot
.66649 .33026 Mdot
.48454 .64148 Mdot
.27624 .73849 Mdot
.64552 .36093 Mdot
.21472 .51332 Mdot
.65865 .67796 Mdot
.63807 .48487 Mdot
.6275 .79946 Mdot
.58163 .55373 Mdot
.71326 .34886 Mdot
.63678 .74414 Mdot
.63559 .49677 Mdot
.35249 .75256 Mdot
.50627 .57518 Mdot
.34 .33406 Mdot
.41621 .64119 Mdot
.16069 .49729 Mdot
.62053 .49776 Mdot
.23025 .66126 Mdot
.23791 .66393 Mdot
.24266 .5515 Mdot
.30459 .40271 Mdot
.8138 .66867 Mdot
.69554 .69806 Mdot
.51715 .57867 Mdot
.64006 .42686 Mdot
.34981 .50491 Mdot
.22375 .55964 Mdot
.53092 .67632 Mdot
.40899 .70212 Mdot
.76746 .57801 Mdot
.49382 .84944 Mdot
.47341 .39484 Mdot
.54824 .29242 Mdot
.71526 .41331 Mdot
.60396 .25611 Mdot
.76697 .4206 Mdot
.7186 .32829 Mdot
.25352 .68885 Mdot
.5539 .46979 Mdot
.54965 .43709 Mdot
.70615 .35313 Mdot
.24316 .6412 Mdot
.40548 .41592 Mdot
.51479 .27327 Mdot
.74761 .52061 Mdot
.7018 .7528 Mdot
.68011 .35554 Mdot
.51744 .44964 Mdot
.60162 .40941 Mdot
.44539 .64772 Mdot
.43969 .34095 Mdot
.6931 .32765 Mdot
.62307 .44224 Mdot
.57751 .78182 Mdot
.59047 .47815 Mdot
.26759 .5054 Mdot
.21215 .56141 Mdot
.5899 .41778 Mdot
.23839 .67179 Mdot
.52825 .70481 Mdot
.60814 .78507 Mdot
.30425 .65341 Mdot
.33419 .45498 Mdot
.50326 .61602 Mdot
.71058 .49355 Mdot
.44559 .83652 Mdot
.65802 .375 Mdot
.56698 .49143 Mdot
.62459 .41769 Mdot
.25523 .72176 Mdot
.28867 .50702 Mdot
.32797 .28814 Mdot
.37494 .53074 Mdot
.41209 .6796 Mdot
.41863 .61435 Mdot
.48491 .32786 Mdot
.52896 .69447 Mdot
.39906 .43597 Mdot
.45029 .64918 Mdot
.75086 .52095 Mdot
.30523 .74508 Mdot
.71022 .76297 Mdot
.69799 .49113 Mdot
.22749 .68822 Mdot
.67619 .50502 Mdot
.65768 .49238 Mdot
.20393 .51226 Mdot
.56783 .49719 Mdot
.51679 .70066 Mdot
.32892 .45341 Mdot
.68401 .47408 Mdot
.70802 .76036 Mdot
.57238 .48588 Mdot
.3461 .47251 Mdot
.42554 .35462 Mdot
.49191 .4472 Mdot
.45806 .18646 Mdot
.48017 .27089 Mdot
.26357 .73253 Mdot
.23127 .63824 Mdot
.50799 .25968 Mdot
.61673 .41391 Mdot
.57527 .49891 Mdot
.605 .78976 Mdot
.41176 .50557 Mdot
.51341 .82943 Mdot
.52253 .37507 Mdot
.76143 .53748 Mdot
.4122 .80166 Mdot
.33046 .71726 Mdot
.37676 .72376 Mdot
.78722 .55238 Mdot
.53885 .78451 Mdot
.45027 .50543 Mdot
.24947 .32946 Mdot
.17112 .40809 Mdot
.73263 .74552 Mdot
.75249 .33288 Mdot
.55643 .5761 Mdot
.27538 .66185 Mdot
.5899 .46999 Mdot
.33947 .6169 Mdot
.43826 .37033 Mdot
.26321 .50929 Mdot
.53673 .37243 Mdot
.69896 .26316 Mdot
.50898 .84651 Mdot
.50616 .63891 Mdot
.40606 .53641 Mdot
.37424 .42724 Mdot
.30958 .35727 Mdot
.64347 .54495 Mdot
.69292 .77825 Mdot
.51047 .27334 Mdot
.356 .25088 Mdot
.48067 .30882 Mdot
.3473 .77559 Mdot
.29579 .28202 Mdot
.52036 .35826 Mdot
.31284 .78419 Mdot
.7582 .36629 Mdot
.8106 .56392 Mdot
.67219 .24261 Mdot
.38018 .78744 Mdot
.7666 .56285 Mdot
.27982 .52118 Mdot
.55441 .82909 Mdot
.32203 .61002 Mdot
.28368 .45684 Mdot
.55229 .78325 Mdot
.21683 .61616 Mdot
.20999 .55132 Mdot
.5641 .29022 Mdot
.64613 .51274 Mdot
.23882 .30157 Mdot
.27801 .33644 Mdot
.84012 .40553 Mdot
.52051 .82163 Mdot
.72451 .70587 Mdot
.66072 .37601 Mdot
.45684 .37045 Mdot
.59946 .79225 Mdot
.24599 .67255 Mdot
.61173 .50828 Mdot
.25741 .31614 Mdot
.31892 .70088 Mdot
.26964 .64271 Mdot
.48457 .36969 Mdot
.44655 .8307 Mdot
.29749 .38679 Mdot
.59417 .58226 Mdot
.22353 .63456 Mdot
.69999 .49941 Mdot
.3911 .71652 Mdot
.69578 .75511 Mdot
.39318 .74563 Mdot
.20289 .56618 Mdot
.52928 .37564 Mdot
.36285 .31557 Mdot
.70813 .75446 Mdot
.76092 .43006 Mdot
.7637 .59423 Mdot
.85059 .62823 Mdot
.57869 .82575 Mdot
.57755 .50294 Mdot
.58647 .67273 Mdot
.29639 .76547 Mdot
.37932 .36225 Mdot
.32327 .75302 Mdot
.82321 .44075 Mdot
.20448 .53869 Mdot
.56539 .73713 Mdot
.57059 .69386 Mdot
.28771 .58247 Mdot
.72158 .37293 Mdot
.63606 .51036 Mdot
.29557 .35995 Mdot
.20965 .57946 Mdot
.77021 .52684 Mdot
.83172 .41429 Mdot
.82165 .54311 Mdot
.66409 .41162 Mdot
.53791 .83507 Mdot
.60017 .56995 Mdot
.77492 .50012 Mdot
.59858 .78608 Mdot
.4214 .54821 Mdot
.40066 .42978 Mdot
.77893 .48859 Mdot
.31395 .64115 Mdot
.15946 .49135 Mdot
.797 .68893 Mdot
.7411 .53708 Mdot
.60571 .81719 Mdot
.39811 .82454 Mdot
.67608 .40492 Mdot
.63223 .525 Mdot
.31695 .60085 Mdot
.57939 .47908 Mdot
.56696 .36074 Mdot
.2854 .3475 Mdot
.22676 .51674 Mdot
.23712 .36323 Mdot
.57431 .66744 Mdot
.50596 .3772 Mdot
.48403 .84214 Mdot
.25929 .54383 Mdot
.49662 .84094 Mdot
.77747 .54252 Mdot
.5151 .59398 Mdot
.87887 .59286 Mdot
.61996 .26896 Mdot
.50373 .71057 Mdot
.52877 .56042 Mdot
.54439 .57218 Mdot
.58102 .66617 Mdot
.56829 .344 Mdot
.28539 .60676 Mdot
.19282 .53283 Mdot
.55544 .82585 Mdot
.71305 .41771 Mdot
.32077 .60702 Mdot
.52903 .2771 Mdot
.38749 .67484 Mdot
.59194 .74212 Mdot
.50079 .27263 Mdot
.18234 .51717 Mdot
.45503 .18803 Mdot
.4205 .39333 Mdot
.45675 .44276 Mdot
.37665 .64854 Mdot
.4544 .52211 Mdot
.19487 .51486 Mdot
.49157 .3411 Mdot
.38725 .42859 Mdot
.21776 .63218 Mdot
.78901 .56244 Mdot
.47954 .36635 Mdot
.21488 .33477 Mdot
.31827 .62127 Mdot
.50773 .37877 Mdot
.59212 .51954 Mdot
.82135 .51405 Mdot
.56957 .79267 Mdot
.40482 .39594 Mdot
.4477 .50594 Mdot
.78028 .61787 Mdot
.58394 .80317 Mdot
.51045 .33833 Mdot
.32853 .79597 Mdot
.58219 .51647 Mdot
.64805 .54432 Mdot
.69562 .7268 Mdot
.48284 .5815 Mdot
.66063 .66757 Mdot
.53576 .57499 Mdot
.40878 .60715 Mdot
.42983 .18587 Mdot
.4907 .58576 Mdot
.48026 .44708 Mdot
.55248 .46248 Mdot
.25696 .55455 Mdot
.62663 .70951 Mdot
.53794 .6187 Mdot
.30461 .52324 Mdot
.31753 .66139 Mdot
.26334 .53313 Mdot
.25229 .52201 Mdot
.48699 .36754 Mdot
.19411 .51645 Mdot
.20979 .54689 Mdot
.64556 .72805 Mdot
.61042 .79541 Mdot
.59163 .71401 Mdot
.51397 .82322 Mdot
.4421 .39893 Mdot
.61496 .35845 Mdot
.39815 .7426 Mdot
.79213 .6934 Mdot
.74401 .42363 Mdot
.6177 .63801 Mdot
.38025 .81216 Mdot
.47249 .83738 Mdot
.45156 .31947 Mdot
.62244 .24696 Mdot
.16052 .43448 Mdot
.30631 .60416 Mdot
.70636 .26775 Mdot
.28965 .30576 Mdot
.37354 .80202 Mdot
.45671 .6552 Mdot
.57466 .50427 Mdot
.79478 .51731 Mdot
.5167 .70788 Mdot
.34654 .38405 Mdot
.82851 .51658 Mdot
.78878 .55225 Mdot
.53564 .78466 Mdot
.53252 .58103 Mdot
.52524 .41072 Mdot
.68187 .48278 Mdot
.73793 .73968 Mdot
.30881 .3088 Mdot
.42092 .58656 Mdot
.83423 .42931 Mdot
.43846 .18503 Mdot
.21624 .51081 Mdot
.66824 .76438 Mdot
.47335 .27784 Mdot
.44999 .64179 Mdot
.53796 .19706 Mdot
.71969 .46635 Mdot
.6414 .42188 Mdot
.48155 .28567 Mdot
.25934 .61128 Mdot
.68693 .33419 Mdot
.82959 .65515 Mdot
.41221 .82159 Mdot
.52801 .709 Mdot
.83251 .36943 Mdot
.22533 .63942 Mdot
.41323 .56443 Mdot
.67858 .32478 Mdot
.52283 .83679 Mdot
.54414 .36953 Mdot
.28084 .74652 Mdot
.58661 .43267 Mdot
.62004 .49378 Mdot
.26839 .6281 Mdot
.66958 .24654 Mdot
.47266 .57617 Mdot
.83405 .39888 Mdot
.64143 .25437 Mdot
.27838 .65053 Mdot
.63833 .3837 Mdot
.70299 .48354 Mdot
.74898 .44288 Mdot
.58049 .4026 Mdot
.54873 .48007 Mdot
.52015 .44997 Mdot
.5569 .43755 Mdot
.4082 .41359 Mdot
.55734 .4031 Mdot
.61332 .26854 Mdot
.47423 .3318 Mdot
.80408 .53844 Mdot
.15518 .46025 Mdot
.25251 .51464 Mdot
.328 .38357 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0:3ooooo0_l0002Wooooo`007?ooool00ol0003oooooooooo`2Poooo
o`?o0000Y_ooool001cooooo00?o0000ooooooooool0X?ooool3o`000:Kooooo000Looooo`03o`00
0?oooooooooo0:Cooooo0_l0002Sooooo`007?ooool00ol0003oooooooooo`2Tooooo`Co0000XOoo
ool001cooooo00?o0000ooooooooool0R?ooool2o`000003ooooool0003o000000Cooooo0_l0000B
ooooo`Co0000X?ooool001cooooo00?o0000ooooooooool0R?ooool2o`000003ooooool0003o0000
00?ooooo0ol00006ooooo`;o00003?ooool2o`000:3ooooo00001_ooooook^k^oc8b<_l0003o<S8b
onk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`23ooooo`?o00002_ooool2
o`0000;ooooo0_l00003ooooo`;o00003Oooool2o`0009oooooo00001_ooooooMgMgoiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003ooooo
ooooo`23ooooo`?o00003_ooool2o`0001;ooooo1?l0002Mooooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0XOoo
ool2o`0000Oooooo0ol0002Looooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0;
ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0001looooo`;o00008oooool2o`000003ooooool0003o
000000Gooooo1?l0002Jooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<oooo
o`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0O?ooool2o`0002Kooooo0_l00007oooo
o`?o0000VOooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool03Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo0:kooooo0_l0002Iooooo`0000KoooooogMgMonHV9So
oooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`2W
ooooo`?o00001Oooool2o`0009Sooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo07Sooooo0_l0000]ooooo`Go0000
0oooool4o`0009Kooooo000Looooo`03o`000?oooooooooo07Sooooo0_l0000`ooooo`;o00001Ooo
ool6o`0009;ooooo000Looooo`03o`000?oooooooooo0;?ooooo1?l000000ooooooo0000o`00002?
ooooo`007?ooool00ol0003oooooooooo`2fooooo`Co000000?oooooo`000?l00000S?ooool001co
oooo00?o0000ooooooooool0]?ooool5o`0000;ooooo0_l0002<ooooo`007?ooool00ol0003ooooo
ooooo`2]ooooo`Co00000oooool2o`000003ooooool0003o000000;o00004Oooool2o`0007_ooooo
000Looooo`03o`000?oooooooooo0:gooooo1?l00004ooooo`;o00000_ooool5o`0000kooooo0_l0
001kooooo`007?ooool00ol0003oooooooooo`2Pooooo`;o00003Oooool2o`0000Cooooo0_l00003
ooooo`So00001oooool2o`000003ooooool0003o000007_ooooo000Looooo`03o`000?oooooooooo
09gooooo0_l000000ooooooo0000o`000005o`0001Gooooo1_l000000ooooooo0000o`000002oooo
o`Co0000O_ooool001cooooo00?o0000ooooooooool0L?ooool2o`0002_ooooo0_l00002ooooo`Oo
00006?ooool;o`0000cooooo0_l0000Iooooo`;o0000EOooool001cooooo00?o0000ooooooooool0
L?ooool2o`0002oooooo1?l000000ooooooo0000o`000002o`0001Kooooo1ol00002ooooo`;o0000
2_ooool6o`0001Oooooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`2Koooooa3o00005Ooo
ool2o`0000Cooooo0_l0000:ooooo`;o000000?oooooo`000?l000001?l0000Gooooo`;o0000EOoo
ool001cooooo0_l0001aooooo`;o0000:Oooool6o`0000;ooooo1?l000001?oooooo0000o`000?l0
000Kooooo`;o00002?ooool4o`0000;ooooo0_l0001aooooo`007?ooool00ol0003oooooooooo`1`
ooooo`;o0000;_ooool2o`000003ooooool0003o000000Gooooo0ol0000Booooo`;o00001Oooool2
o`0000Gooooo0_l000000ooooooo0000o`000005ooooo`;o0000L?ooool001cooooo00?o0000oooo
ooooool0K_ooool2o`0002cooooo0ol000000ooooooo0000o`000003o`0000Gooooo1?l0000Aoooo
o`Co00000oooool2o`0000Cooooo0ol00008ooooo`;o0000L?ooool001cooooo00?o0000oooooooo
ool0K_ooool2o`0002Wooooo0_l000000ooooooo0000o`000008o`0000Kooooo0ol0000Aooooo`?o
00002?ooool3o`0000Sooooo0_l0001aooooo`007?ooool00ol0003oooooooooo`1[ooooo`;o0000
9oooool2o`0000?ooooo0_l00004ooooo`Oo00001_ooool4o`0000gooooo0_l000000ooooooo0000
o`000009ooooo`;o00001Oooool2o`0000;ooooo0_l00007ooooo`;o0000J?ooool001cooooo00?o
0000ooooooooool0Joooool2o`0002Oooooo0_l00006ooooo`;o00000oooool4o`0000Sooooo1?l0
000<ooooo`?o00001_ooool2o`0000[ooooo0_l00007ooooo`;o00000_ooool2o`000004ooooool0
003o0000o`0006Cooooo000Looooo`03o`000?oooooooooo06Wooooo0_l0000Yooooo`;o00000_oo
ool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000cooooo0_l0000=ooooo`;o00000ooo
ool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`00000;ooooo`Co00000ooo
ool3o`0006Cooooo000Looooo`03o`000?oooooooooo067ooooo0_l00002ooooo`;o00000_ooool3
o`0002cooooo0_l00005ooooo`So00006Oooool2o`000004ooooool0003o0000ooooo`;o00000ooo
ool2o`000003ooooool0003o000000gooooo0_l00005ooooo`;o0000Hoooool001cooooo00?o0000
ooooooooool0HOooool2o`0000;ooooo0_l00002ooooo`?o00009oooool2o`0000Cooooo0_l00004
ooooo`[o00001oooool2o`0000kooooo1?l0000Looooo`;o00000_ooool2o`0001Gooooo0_l0001<
ooooo`007?ooool00ol0003oooooooooo`1Qooooo`;o0000<?ooool2o`000004ooooool0003o0000
ooooo`;o00000_ooool=o`0000Kooooo0_l0000?ooooo`?o000000?oooooo`000?l000000_l0000G
ooooo`Go000000?oooooo`000?l000004oooool2o`0004cooooo000Looooo`03o`000?oooooooooo
05Sooooo0_l00002ooooo`;o0000=?ooool3o`000003ooooool0003o000000Gooooo3_l0000>oooo
o`;o00002_ooool4o`0001Wooooo0ol000000ooooooo0000o`00001Qooooo`007?ooool00ol0003o
ooooooooo`1Booooo`;o00001?ooool2o`0000;ooooo0_l00009ooooo`;o00009oooool;o`0000;o
oooo3_l00008ooooo`;o00001?ooool2o`0004;ooooo0_l0001:ooooo`007?ooool00ol0003ooooo
ooooo`1Booooo`;o00001?ooool2o`0000?ooooo0_l00006ooooo`Co00009oooool2o`000004oooo
ool0003o0000o`0000;ooooo0ol00002ooooo`go00002Oooool2o`0003;ooooo0_l0000Dooooo`;o
0000B_ooool001cooooo00?o0000ooooooooool0F?ooool2o`0000?ooooo0_l00006ooooo`Co0000
=?oooolCo`0000?ooooo0_l0000booooo`;o00000_ooool2o`00017ooooo0_l00019ooooo`007?oo
ool00ol0003oooooooooo`1?ooooo`?o00001Oooool2o`0004?ooooo5?l00003ooooo`;o0000=_oo
ool2o`00017ooooo0_l00019ooooo`007?ooool00ol0003oooooooooo`1?ooooo`?o00001Oooool2
o`0000[ooooo0_l0000Yooooo`;o000000?oooooo`000?l000002?oooolEo`0003_ooooo0_l0000A
ooooo`?o0000B?ooool001cooooo0_l0001;ooooo`;o00005oooool2o`0002Wooooo0_l000000ooo
oooo0000o`000008oooooaGo0000Coooool2o`0004Sooooo000Looooo`03o`000?oooooooooo04[o
oooo0_l0000>ooooo`?o00001Oooool2o`0002gooooo0_l00009oooooa?o000000?oooooo`000?l0
0000COooool2o`0004Sooooo000Looooo`03o`000?oooooooooo05Oooooo0_l000001?oooooo0000
o`000?l00005ooooo`;o000000?oooooo`000?l00000=OoooolCo`000003ooooool0003o000004go
oooo0_l00018ooooo`007?ooool00ol0003oooooooooo`1Gooooo`Ko00000_ooool8o`000003oooo
ool0003o000002kooooo5ol0001@ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0Eooo
ool6o`0000;ooooo2ol0000]oooooaWo00001_ooool2o`0004Sooooo0_l00017ooooo`007?ooool0
0ol0003oooooooooo`13ooooo`;o00001oooool2o`0000;ooooo0_l00008ooooo`oo00000oooool2
o`0000Cooooo0_l0000Nooooo`;o00000oooool2o`000003ooooool0003o000001Go00001Oooool2
o`0003Oooooo0ol0000>ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0@oooool2o`00
00Oooooo0_l00002ooooo`;o00002?oooolDo`0000Cooooo0_l0000Dooooo`;o00000oooool4o`00
0003ooooool0003o000000Cooooo6Ol00005ooooo`;o0000:_ooool2o`0000_ooooo0ol0001Goooo
o`007?ooool00ol0003oooooooooo`1>ooooo`;o00002?ooool4o`000003ooooool0003o000000oo
00006_ooool3o`0000;ooooo1?l000000ooooooo0000o`000004oooooaWo00001Oooool2o`0002;o
oooo0ol00005ooooo`?o00007?ooool3o`0004Gooooo000Looooo`03o`000?oooooooooo04cooooo
1?l00008ooooo`;o00000ooooolDo`0000Cooooo0_l0000Booooo`;o00002?ooool2o`0000Oooooo
5Ol00005ooooo`;o00007Oooool2o`0000;ooooo1Ol000000ooooooo0000o`000002ooooo`;o0000
0_ooool2o`0001Sooooo0ol00015ooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00003?oo
ool:o`000003ooooool0003o000000[o00001?ooool4o`0001;ooooo1?l00004ooooo`;o00001Ooo
oolGo`0000Gooooo0_l0000Mooooo`Ko000000?oooooo`000?l000000ol00002ooooo`;o000000Co
ooooo`000?l0003o0000H?ooool001cooooo00?o0000ooooooooool0C?ooool3o`0000Cooooo0_l0
0005ooooo`[o000000?oooooo`000?l000002Ol00007ooooo`;o00004?ooool6o`0000Oooooo0_l0
0002ooooo`;o000000?oooooo`000?l000003ol000000ooooooo0000o`000005ooooo`?o00006?oo
ool2o`0000;ooooo1_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000
o`000003o`0000Cooooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00001_oo
ool5o`0000Cooooo0_l00005ooooo`Wo000000?oooooo`000?l000003?l0000Gooooo`;o00002Ooo
ool4o`0000;ooooo0_l000001?oooooo0000o`000?ooool>o`0000Wooooo0_l0000Hooooo`;o0000
0_ooool2o`0000Cooooo0_l00003ooooo`Go00001?ooool2o`0000Cooooo1?l0001Fooooo`007?oo
ool00ol0003oooooooooo`12ooooo`?o00001Oooool3o`0000[ooooo0_l00002oooooaOo00000_oo
ool2o`0000Cooooo0_l00006ooooo`;o00001Oooool2o`0000Wooooo0_l0000;ooooo`co000000?o
ooooo`000?l000001oooool2o`000003ooooool0003o000001Kooooo0_l00007ooooo`;o00000ooo
ool7o`0000;ooooo0ol00005ooooo`;o00004?ooool2o`0004Cooooo000Looooo`03o`000?oooooo
oooo04?ooooo0_l00006ooooo`;o00001_ooool2o`0000;ooooo0_l00002oooooa_o00001?ooool2
o`0000Kooooo0_l00007ooooo`;o00000oooool2o`0000[ooooo0_l00002ooooo`go000000?ooooo
o`000?l000001Oooool4o`000003ooooool0003o000001Kooooo0_l0000=ooooo`?o000000?ooooo
o`000?l000000_ooool3o`0001Oooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`19oooo
o`;o00002?ooool2o`0000Kooooo1?l000000ooooooo0000o`00000Co`0000Oooooo0_l0000;oooo
o`Co00000_ooool3o`0000[ooooo4ol00006ooooo`;o00000oooool2o`0002Wooooo1ol0001Moooo
o`007?ooool00ol0003oooooooooo`0nooooo`;o00002Oooool3o`0000gooooo0_l000001Ooooooo
0000o`000?l0003ooooo01Ko00001_ooool2o`000003ooooool0003o000000Oooooo1?l00003oooo
o`;o000000?oooooo`000?l000002_ooool=o`000004ooooool0003o0000o`0000Kooooo0_l00002
ooooo`?o0000:Oooool4o`00063ooooo000Looooo`;o0000?oooool2o`0000[ooooo0_l0000=oooo
o`_o00000_ooool@o`0000Wooooo0_l00007ooooo`;o00002?ooool2o`0000oooooo1?l000000ooo
oooo0000o`000003o`0000Kooooo0ol000000ooooooo0000o`000002o`00017ooooo0_l0000Foooo
o`Go00000oooool2o`0005_ooooo000Looooo`03o`000?oooooooooo05[ooooo0_l000000ooooooo
0000o`00000Fo`00013ooooo0_l000000ooooooo0000o`000004ooooo`;o00005?ooool3o`000003
ooooool0003o000000?o00001_ooool7o`0000oooooo0_l000000ooooooo0000o`00000>ooooo`Co
00000_ooool4o`000003ooooool0003o000000?ooooo0ol00003ooooo`;o00004_ooool2o`00047o
oooo000Looooo`03o`000?oooooooooo04Wooooo0_l0000BoooooaSo00004?ooool3o`0000Kooooo
1?l00006ooooo`;o00003_ooool2o`0000Wooooo0_l000000ooooooo0000o`00000Aooooo`;o0000
3_ooool2o`000003ooooool0003o000000?o000000?oooooo`000?l000000oooool2o`0000Cooooo
0ol00002ooooo`;o000000?oooooo`000?l000003oooool2o`00047ooooo000Looooo`03o`000?oo
oooooooo04Wooooo0_l0000Aooooo`;o00000_oooolFo`0000oooooo0ol00008ooooo`?o00001Ooo
ool2o`0000Gooooo0_l00004ooooo`;o000000?oooooo`000?l000000oooool2o`0000Cooooo0_l0
000=ooooo`Co00001oooool2o`0000[ooooo0_l00002ooooo`So00002?ooool3o`0000Gooooo0_l0
001Booooo`007?ooool00ol0003oooooooooo`0mooooo`;o00002_ooool2o`0000kooooo0_l00000
0ooooooo0000o`000002oooooaKo000000?oooooo`000?l000003_ooool2o`0000Oooooo0ol00008
ooooo`Ko00001?ooool4o`0000Cooooo0_l000001?oooooo0000o`000?ooool3o`0000cooooo1?l0
0007ooooo`?o00002Oooool3o`0000Cooooo1Ol00008ooooo`;o00006?ooool2o`00043ooooo000L
ooooo`03o`000?oooooooooo03gooooo0_l0000:ooooo`;o00003_ooool3o`0000Cooooo1_l00000
0ooooooo0000o`00000=o`000003ooooool0003o000000kooooo0_l00005ooooo`;o00002?ooool2
o`000003ooooool0003o000000;o00001_ooool6o`0000Gooooo0ol000000ooooooo0000o`00000F
ooooo`Co00001oooool5o`000004ooooool0003o0000ooooo`;o00003Oooool2o`000003ooooool0
003o000001?ooooo1?l0000nooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o00003Oooool2
o`0000?ooooo6_l0000;ooooo`Ko00001?ooool2o`0000Sooooo1_l00007ooooo`?o000000Cooooo
o`000?l0003ooooo0_l00002ooooo`?o00006Oooool2o`0000Wooooo1?l000001Ooooooo0000o`00
0?l0003ooooo00;o00003Oooool2o`000003ooooool0003o000001Gooooo1?l0000looooo`007?oo
ool00ol0003oooooooooo`1;ooooo`;o00000_ooool2o`0000;ooooo0_l0000:ooooo`;o000000?o
ooooo`000?l000005?l0000<ooooo`Ko000000Coooooo`000?l0003ooooo0_l000000ooooooo0000
o`000007ooooo`Co00002?ooool2o`0000?ooooo1?l00007ooooo`;o00008Oooool2o`000003oooo
ool0003o000000Sooooo0_l00004ooooo`;o000000?oooooo`000?l000001?ooool2o`0001Cooooo
0_l0000looooo`007?ooool00ol0003oooooooooo`1?ooooo`;o00000_ooool3o`0000_ooooo5_l0
000<ooooo`Oo000000?oooooo`000?l000001?ooool2o`0000Gooooo1?l0000:ooooo`?o000000?o
ooooo`000?l000001?l00005ooooo`?o00006_ooool2o`0000Kooooo0_l0000:ooooo`?o000000?o
ooooo`000?l000000_l000001?oooooo0000o`000?l00003ooooo`;o0000D_ooool001cooooo00?o
0000ooooooooool0E?ooool2o`0000Oooooo0_l00002ooooo`;o00000_ooool6o`000003ooooool0
003o000000_o00002_ooool6o`0000oooooo0_l00007ooooo`;o00000oooool6o`000004ooooool0
003o0000o`0000Gooooo0_l0000Kooooo`?o00001Oooool2o`0000_ooooo0_l000000ooooooo0000
o`000003ooooo`?o00000oooool3o`00057ooooo000Looooo`03o`000?oooooooooo05cooooo0ol0
0005oooooaGo00003?ooool4o`0001Kooooo1?l00005ooooo`Go00001?ooool3o`0001kooooo0ol0
000Booooo`;o00000_ooool2o`0000;ooooo0ol00003ooooo`?o0000DOooool001cooooo00?o0000
ooooooooool0=oooool2o`00027ooooo1Ol00005oooooaGo00002Oooool2o`000003ooooool0003o
000000gooooo0_l00006ooooo`;o000000?oooooo`000?l000000_l00007ooooo`?o00001?ooool3
o`0001Sooooo0_l00004ooooo`;o00000_ooool2o`0000oooooo1_l00006ooooo`;o00005oooool2
o`0003_ooooo000Looooo`03o`000?oooooooooo03Oooooo0_l0000Qooooo`;o000000Coooooo`00
0?l0003o00001_oooolBo`0000[ooooo0_l000000ooooooo0000o`00000=ooooo`;o00001_ooool2
o`0002Cooooo0_l00008ooooo`;o00002?ooool2o`00017ooooo0ol00007ooooo`;o00005oooool2
o`0003_ooooo000Looooo`03o`000?oooooooooo05gooooo1Ol00004oooooa;o00002?ooool4o`00
03kooooo0_l00008ooooo`;o00002oooool2o`000003ooooool0003o000000_ooooo0ol000000ooo
oooo0000o`00000Mooooo`;o0000>oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2
ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo063ooooo0_l00006
ooooo`ko00002_ooool4o`000003ooooool0003o000005;ooooo0_l000000ooooooo0000o`00000;
ooooo`?o000000?oooooo`000?l000007Oooool2o`0003_ooooo00001_ooooooMgMgoiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0JOoo
ool=o`0000Wooooo1Ol000000ooooooo0000o`00000?ooooo`;o0000BOooool2o`0001;ooooo0_l0
000Eooooo`;o0000>oooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool5
o`0000Kooooo00?o0000ooooooooool0H?ooool2o`0000?ooooo0ol000000ooooooo0000o`000008
o`0000_ooooo1_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00008ooooo`;o0000?_oo
ool7o`0000Cooooo0_l000001?oooooo0000o`000?l00004ooooo`;o00000_ooool2o`0000Cooooo
0_l0000Dooooo`;o0000??ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Ooo
ool01?m4A4CogMgMooooool00007ooooo`?o0000Goooool3o`0000?ooooo0ol00005ooooo`So0000
2?ooool3o`0000Sooooo0_l00002ooooo`;o00000oooool2o`0000Kooooo0_l0000Fooooo`;o0000
0_ooool2o`0000;ooooo0_l0000=ooooo`;o00002?ooool=o`0000;ooooo0_l000001?oooooo0000
o`000?l00004ooooo`?o000000?oooooo`000?l000006_ooool4o`0003[ooooo00000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003o
ooooooooo`1Oooooo`;o00001Oooool2o`000003ooooool0003o000000;ooooo2?l00007ooooo`Ko
00003oooool2o`0000Kooooo0_l0000Fooooo`;o00000_ooool2o`0000;ooooo0_l0000<ooooo`?o
00001?oooolDo`0000Gooooo0_l00003ooooo`;o00001?ooool2o`0001Wooooo0_l0000jooooo`00
00?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo
00?o0000ooooooooool0=?ooool2o`00033ooooo1ol000000ooooooo0000o`000004o`0000Oooooo
0ol000001?oooooo0000o`000?l00004ooooo`;o0000>?ooool2o`0000?ooooo1?l00003ooooo`So
000000?oooooo`000?l000003Ol00003ooooo`?o00002?ooool2o`0000;ooooo0_l0000Eooooo`;o
0000>_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007oooo
o`03o`000?oooooooooo03Cooooo0_l0000booooo`;o000000?oooooo`000?l000002_l00004oooo
o`;o00000_ooool2o`0000Gooooo0_l0000Oooooo`;o00002_ooool2o`0000_ooooo0_l00003oooo
o`;o00000ooooolJo`0000?ooooo0ol00002ooooo`;o00002?ooool2o`00057ooooo00001_oooooo
k^k^oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`0c
ooooo`;o0000>?ooool3o`0000;ooooo2Ol000000ooooooo0000o`000003ooooo`;o00009?ooool2
o`0000Wooooo0ol0000@ooooo`?o000000?oooooo`000?l000001_l000000ooooooo0000o`00000?
o`0000;ooooo1?l00003ooooo`;o00007?ooool2o`0003gooooo000Looooo`03o`000?oooooooooo
03?ooooo0_l0000iooooo`;o00001oooool7o`0000;ooooo0ol0000_ooooo`;o00002?ooool2o`00
00Kooooo2Ol00004oooooaSo00008Oooool4o`0003_ooooo000Looooo`03o`000?oooooooooo073o
oooo1Ol00005ooooo`Co00000_ooool2o`0003[ooooo0_l00006ooooo`;o000000?oooooo`000?l0
00000_l00004oooooaOo00001_ooool2o`0000Oooooo0_l0000Cooooo`Co0000>oooool001cooooo
00?o0000ooooooooool0<_ooool2o`0003Cooooo1?l00004ooooo`So00001?ooool2o`0004[ooooo
0ol00002oooooaOo00002?ooool4o`0000Gooooo0_l0000Cooooo`;o0000?Oooool001cooooo00?o
0000ooooooooool0<_ooool2o`0003Cooooo1?l00006ooooo`Oo00003_ooool2o`0003Wooooo0_l0
0003ooooo`Co000000?oooooo`000?l000005ol00002ooooo`Wo00006oooool2o`0003cooooo000L
ooooo`03o`000?oooooooooo037ooooo0_l0000oooooo`?o000000Goooooo`000?l0003o0000oooo
o`02o`0000;ooooo0_l00007ooooo`;o00003Oooool2o`0001Sooooo0_l00006ooooo`;o00002?oo
ool2o`0000;ooooo0ol00003oooooa[o000000?oooooo`000?l000001Ol00002ooooo`;o000000?o
ooooo`000?l000005_ooool2o`0003cooooo000Looooo`03o`000?oooooooooo037ooooo0_l00012
ooooo`Co000000?oooooo`000?l000000_ooool2o`0001Kooooo0_l0000Hooooo`;o00001_ooool2
o`000003ooooool0003o000000Wooooo0_l000001Ooooooo0000o`000?l0003ooooo01Wo00000_oo
ool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`00000Eooooo`?o0000??oo
ool001cooooo00?o0000ooooooooool0<?ooool2o`0003cooooo0_l00005ooooo`;o00000oooool2
o`0000;ooooo0_l0000Mooooo`;o00004?ooool2o`000003ooooool0003o000000Cooooo0_l00000
0ooooooo0000o`000002ooooo`;o00001?oooolXo`0000Cooooo0_l0000Eooooo`Co0000?Oooool0
01cooooo00?o0000ooooooooool0<?ooool2o`0003cooooo0_l0000>ooooo`;o00007Oooool2o`00
013ooooo1Ol00004ooooo`;o00000_ooool2o`000003ooooool0003o000000Cooooo0_l000001?oo
oooo0000o`000?ooool;o`000003ooooool0003o000001?o00001Oooool2o`0001Cooooo1Ol0000m
ooooo`007?ooool00ol0003oooooooooo`1_ooooo`?o00003_ooool2o`0000Cooooo0_l00009oooo
o`;o00001Oooool2o`0001Cooooo1Ol00009ooooo`;o00002Oooool?o`000003ooooool0003o0000
01?o00000oooool2o`0001Kooooo1Ol0000mooooo`007?ooool00ol0003oooooooooo`1_ooooo`Co
000000?oooooo`000?l000002_ooool2o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l0
00000_l00005ooooo`;o00000oooool2o`0000oooooo0_l000000ooooooo0000o`000009ooooo`;o
00002OoooolTo`0000Cooooo0_l0000Eooooo`Go0000?_ooool001cooooo00?o0000ooooooooool0
;_ooool2o`0002kooooo0_l0000Aooooo`;o000000?oooooo`000?l000005_ooool5o`0000Oooooo
0_l00002ooooo`?o000000?oooooo`000?l000003oooool2o`0000Wooooo0_l00004ooooo`Co0000
0ooooolRo`0000Cooooo0ol0000Dooooo`Go0000?_ooool001cooooo0_l0000_ooooo`;o0000;_oo
ool4o`00017ooooo0_l0000?ooooo`;o00001Oooool5o`0000Sooooo0_l00002ooooo`;o00000_oo
ool2o`0000;ooooo0ol0000@ooooo`;o000000?oooooo`000?l000001_ooool4o`0000Cooooo8?l0
0004ooooo`Co00004oooool3o`00047ooooo000Looooo`03o`000?oooooooooo02kooooo0_l0000`
ooooo`;o00001Oooool4o`0000Sooooo0_l00002ooooo`;o00002oooool2o`0000?ooooo1?l00000
0ooooooo0000o`00000Cooooo`Co00004?ooool2o`000003ooooool0003o000000Sooooo0_l00005
oooooaoo00001?ooool2o`0001?ooooo1Ol00011ooooo`007?ooool00ol0003oooooooooo`0^oooo
o`;o0000:?ooool4o`0000Cooooo0_l000001Ooooooo0000o`000?l0003ooooo00Co00003?ooool2
o`00013ooooo0_l0000:ooooo`;o00003?ooool2o`0001oooooo0_l000001Ooooooo0000o`000?l0
003ooooo01[o00000_ooool2o`0000Gooooo0_l0000Cooooo`Go0000@Oooool001cooooo00?o0000
ooooooooool0;Oooool4o`0002Cooooo0_l000000ooooooo0000o`000002o`0000;ooooo2?l00000
0ooooooo0000o`00000/ooooo`;o00002?ooool2o`0001;ooooo0_l0000>ooooo`;o00000_ooool3
o`000003ooooool0003o000001So00007Oooool6o`00047ooooo000Looooo`03o`000?oooooooooo
02gooooo1?l0000Tooooo`;o00000_ooool2o`0000?ooooo2?l0000booooo`;o00001Oooool2o`00
00oooooo0_l000000ooooooo0000o`00000>ooooo`;o00000_ooool3o`000003ooooool0003o0000
01Wo00001_ooool2o`0001?ooooo1?l00014ooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o
00000oooool2o`0000;ooooo1ol00002ooooo`Co0000;_ooool2o`0001Kooooo0_l0000Eooooo`?o
00000_oooolFo`000003ooooool0003o000000?o00001?ooool2o`0001;ooooo1Ol00014ooooo`00
7?ooool00ol0003oooooooooo`1Dooooo`?o00000_ooool2o`000003ooooool0003o000000co0000
A_ooool2o`0000[ooooo0_l0000>ooooo`Wo000000?oooooo`000?l000000_l000000ooooooo0000
o`000004o`000005ooooool0003o0000o`000?ooool00_l0000Hooooo`;o0000Aoooool001cooooo
00?o0000ooooooooool0EOooool2o`0000Gooooo3ol00002ooooo`;o0000?Oooool6o`0000[ooooo
0_l00004ooooo`;o00003?ooool8o`0000;ooooo1Ol00003ooooo`?o000000?oooooo`000?l00000
5_ooool4o`0004Oooooo000Looooo`03o`000?oooooooooo05Gooooo0_l00007oooooa7o0000>?oo
ool2o`0000?ooooo1?l00006ooooo`;o00002_ooool2o`0000gooooo3_l00005ooooo`;o00001_oo
ool2o`0000oooooo1Ol00017ooooo`007?ooool00ol0003oooooooooo`1Noooooa3o0000>Oooool2
o`0000Cooooo1Ol00004ooooo`Co00000_ooool2o`0000gooooo0_l00002oooooa3o00001?ooool3
o`0000Gooooo0ol0000?ooooo`?o0000BOooool001cooooo00?o0000ooooooooool0G_oooolAo`00
03kooooo1Ol00006ooooo`;o00000_ooool2o`0000;ooooo0_l00008ooooo`Co000000?oooooo`00
0?l000000_l000001Ooooooo0000o`000?l0003ooooo00Oo000000?oooooo`000?l000000ol00006
ooooo`;o00004?ooool3o`0004Wooooo000Looooo`03o`000?oooooooooo02gooooo0_l0000^oooo
oa;o0000?_ooool3o`0000Kooooo0_l00008ooooo`;o00002?ooool7o`0000?ooooo0_l00004oooo
o`?o00000oooool6o`0001Cooooo1_l00019ooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o
0000;_oooolCo`0001?ooooo0ol000001?oooooo0000o`000?ooool2o`0002;ooooo0ol00005oooo
o`;o00004_ooool7o`000003ooooool0003o000000;o00002oooool5o`0001?ooooo1Ol0001;oooo
o`007?ooool00ol0003oooooooooo`0`ooooo`;o0000;?oooolBo`0001?ooooo0ol000000ooooooo
0000o`000009o`0001gooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l00007oooo
o`;o00000_ooool2o`000003ooooool0003o000000;o00001?ooool4o`0000Wooooo0_l00002oooo
o`;o00005?ooool4o`0004cooooo000Looooo`03o`000?oooooooooo033ooooo0_l0000Xooooo`;o
000000?oooooo`000?l000004Ol0000<ooooo`;o00001oooool@o`0001cooooo0_l000001?oooooo
0000o`000?ooool2o`000003ooooool0003o000000Oooooo0_l000001Ooooooo0000o`000?l0003o
oooo00;o00001_ooool2o`0000Wooooo1?l00002ooooo`;o00004_ooool2o`000003ooooool0003o
000000?o0000B_ooool001cooooo00?o0000ooooooooool0<Oooool2o`0002Cooooo0_l000001?oo
oooo0000o`000?oooolCo`0000cooooo0_l00005oooooaCo00006_ooool2o`0000;ooooo0_l0000?
ooooo`;o00000_ooool3o`00013ooooo0ol00003ooooo`;o00004_ooool2o`000003ooooool0003o
000000?o0000B_ooool001cooooo0_l0000^ooooo`;o00000_ooool2o`0001Wooooo0_l00009oooo
o`;o00000ooooolDo`0000;ooooo0_l00002ooooo`?o00001_ooool2o`0000;ooooo1ol000000ooo
oooo0000o`00000;o`000003ooooool0003o000001[ooooo1?l00009ooooo`;o00000_ooool2o`00
00?ooooo0_l0000Cooooo`;o00004oooool2o`000003ooooool0003o000004oooooo000Looooo`03
o`000?oooooooooo02gooooo0ol00002ooooo`?o00005oooool2o`0000Gooooo0ol00003ooooo`;o
000000?oooooo`000?l000005_l00002ooooo`?o00001_ooool6o`000003ooooool0003o000000;o
oooo4Ol0000Looooo`?o00002?ooool2o`0000;ooooo1Ol0000Eooooo`;o00004oooool5o`0000;o
oooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00000_ooool3o`0001[ooooo
0_l000000ooooooo0000o`000002o`0000?ooooo0ol00003oooooa?o00002oooool7o`000003oooo
ool0003o000000?ooooo4Ol0000Looooo`?o00003Oooool4o`0000cooooo0ol0000Looooo`;o0000
1?ooool4o`0000;ooooo0_l00007ooooo`;o0000??ooool001cooooo00?o0000ooooooooool0;_oo
ool2o`000003ooooool0003o0000013ooooo0_l000000ooooooo0000o`000007ooooo`;o000000Co
ooooo`000?l0003o00001Oooool2o`000003ooooool0003o0000013o000000Coooooo`000?l0003o
00002Oooool4o`0000;ooooo1ol000000ooooooo0000o`00000@o`00023ooooo0_l00005ooooo`;o
00000oooool5o`0000Wooooo1?l0000Hooooo`;o00002_ooool2o`0000;ooooo0_l00007ooooo`;o
0000??ooool001cooooo00?o0000ooooooooool0<Oooool2o`0000_ooooo1ol000000ooooooo0000
o`00000:ooooo`;o00001_ooool2o`000003ooooool0003o0000017o000000?oooooo`000?l00000
0_l00005ooooo`Wo000000?oooooo`000?l000000ol000000ooooooo0000o`00000Co`0001gooooo
0ol00004ooooo`;o00000oooool5o`000003ooooool0003o000000Gooooo0ol00002ooooo`?o0000
5?ooool3o`00017ooooo1?l00010ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o000000?o
ooooo`000?l000001ol00002ooooo`;o00001_ooool2o`000003ooooool0003o000000Cooooo1Ol0
0003oooooa7o00000_ooool3o`0000Gooooo0_l000000ooooooo0000o`000004o`0000Oooooo5Ol0
000Jooooo`;o00000_ooool2o`0000Oooooo0_l000000ooooooo0000o`000003ooooo`?o00001?oo
ool2o`0000?ooooo0ol0000Cooooo`Co00002_ooool2o`000003ooooool0003o000000;ooooo1ol0
000mooooo`007?ooool00ol0003oooooooooo`0hooooo`;o000000Coooooo`000?l0003o00002?oo
ool2o`0000Gooooo0ol000000ooooooo0000o`000004ooooo`Co00001?oooolAo`0000Wooooo0_l0
0002ooooo`?o00003OoooolBo`0001[ooooo0_l00002ooooo`;o00001oooool8o`000003ooooool0
003o000001kooooo0ol0000<ooooo`;o000000?oooooo`000?l000001_ooool3o`0003gooooo000L
ooooo`03o`000?oooooooooo02oooooo0_l0000Aooooo`;o00000oooool2o`0000Cooooo0ol00007
ooooo`;o00001_ooool2o`000003ooooool0003o000000co00001_ooool2o`000003ooooool0003o
000000Co00003_oooolEo`0001_ooooo0_l00008ooooo`;o000000?oooooo`000?l000000_l00007
ooooo`;o00005oooool4o`0005Oooooo000Looooo`03o`000?oooooooooo02oooooo1?l0000?oooo
o`;o00000oooool2o`0000Gooooo0_l00007ooooo`Co00001?ooool2o`000003ooooool0003o0000
00co00001_ooool4o`000003ooooool0003o000001?ooooo4ol0000Looooo`;o00001_ooool2o`00
0003ooooool0003o000000?o00001?ooool4o`0001Kooooo1Ol0000Jooooo`;o0000>oooool001co
oooo00?o0000ooooooooool0<Oooool2o`0002Kooooo0_l00004oooooa?o00000_ooool2o`0000;o
oooo0_l0000Ioooooa;o00006_ooool2o`0000Wooooo1Ol00002ooooo`Co00005oooool3o`0000Oo
oooo0_l0000:ooooo`;o00002?ooool2o`0003_ooooo000Looooo`03o`000?oooooooooo03Gooooo
0_l0000:ooooo`;o00000oooool2o`0000Oooooo0_l00009ooooo`;o00001Oooool3o`0000?ooooo
4ol0000Ioooooa;o00007_ooool2o`0000?ooooo0_l00003ooooo`;o00000_ooool2o`0001Wooooo
0ol00007ooooo`;o000000?oooooo`000?l000001oooool2o`0004Gooooo000Looooo`03o`000?oo
oooooooo03Gooooo0_l00004ooooo`;o00001?ooool2o`0000;ooooo0ol00007ooooo`;o000000?o
ooooo`000?l000001_ooool3o`0000;ooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l0
00000ooooooo0000o`000003o`000005ooooool0003o0000o`000?ooool00_l0000Koooooa7o0000
5oooool2o`0000Kooooo0_l00003ooooo`;o00001?ooool2o`0001[ooooo0_l0000:ooooo`;o0000
00?oooooo`000?l000001Oooool2o`0000Kooooo0_l0000oooooo`007?ooool00ol0003ooooooooo
o`0eooooo`Co00000_ooool3o`000003ooooool0003o000000?ooooo0ol0000;ooooo`;o00000ooo
ool2o`000004ooooool0003o0000o`0000;ooooo0ol00002ooooo`;o000000?oooooo`000?l00000
0_l00008ooooo`;o00002oooool2o`0001;ooooo4?l0000Gooooo`;o00004Oooool2o`0001[ooooo
0_l000000ooooooo0000o`000005ooooo`;o00002_ooool3o`0000Gooooo0_l0000oooooo`007?oo
ool00ol0003oooooooooo`0eooooo`Co00000oooool2o`000003ooooool0003o000000?ooooo0_l0
0008ooooo`;o00001oooool2o`0000Oooooo0_l00005ooooo`Go00000oooool4o`0000_ooooo1_l0
000@oooooa3o00008Oooool4o`00027ooooo0_l000000ooooooo0000o`000005ooooo`;o00002ooo
ool2o`0004Kooooo000Looooo`03o`000?oooooooooo03Gooooo1?l00005ooooo`;o00000oooool2
o`0000Wooooo0_l000000ooooooo0000o`000004ooooo`;o00004Oooool2o`0000?ooooo1?l0000:
ooooo`?o00000_ooool2o`0001Cooooo3_l0000Aooooo`;o00003?ooool4o`0000Cooooo1?l0000I
ooooo`;o00003Oooool2o`0000Cooooo0_l00006ooooo`;o0000@?ooool001cooooo00?o0000oooo
ooooool0=Oooool3o`000003ooooool0003o000000?ooooo1?l000000ooooooo0000o`00000<oooo
o`;o00001?ooool2o`0002Cooooo0_l0000Jooooo`go00004Oooool4o`0001;ooooo1_l0000Goooo
o`?o00003?ooool2o`0000Cooooo0_l00003ooooo`;o000000?oooooo`000?l00000@?ooool001co
oooo0_l0000fooooo`Ko00001Oooool2o`00013ooooo0_l00004ooooo`;o00008oooool2o`0000Ko
oooo0_l00008ooooo`Oo00001Oooool;o`0001?ooooo0_l0000Eooooo`?o00006?ooool2o`0001Oo
oooo0_l000000ooooooo0000o`000010ooooo`007?ooool00ol0003oooooooooo`0eooooo`Go0000
1oooool2o`0000Sooooo0_l00005ooooo`;o00001?ooool2o`0002_ooooo0_l00007ooooo`So0000
00?oooooo`000?l000001?ooool9o`0001?ooooo0ol0000_ooooo`;o00003oooool2o`0000Kooooo
0_l000001?oooooo0000o`000?ooool2o`0003gooooo000Looooo`03o`000?oooooooooo03Sooooo
0_l00007ooooo`;o00002?ooool2o`0000?ooooo1?l0000jooooo`Co00001Oooool3o`0000?ooooo
2Ol0000Cooooo`?o0000;oooool3o`0000Sooooo0_l00004ooooo`;o00003?ooool2o`0003gooooo
000Looooo`03o`000?oooooooooo03_ooooo0_l00006ooooo`Co00002Oooool3o`0003[ooooo1Ol0
0003ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000008o`000003ooooool0
003o000001Oooooo0_l00006ooooo`;o00008Oooool2o`0000Sooooo0_l0001Aooooo`007?ooool0
0ol0003oooooooooo`0kooooo`;o00001?ooool6o`0004Kooooo1?l00004ooooo`;o000000?ooooo
o`000?l000000ol00005ooooo`Go000000?oooooo`000?l000000_l0000Eooooo`;o00001_ooool2
o`0002[ooooo0_l00005ooooo`;o00001oooool2o`0004;ooooo000Looooo`03o`000?oooooooooo
03kooooo0_l000000ooooooo0000o`000004ooooo`;o00004?ooool4o`0002Gooooo0_l00009oooo
o`Co00001?ooool2o`0000Cooooo0_l00002ooooo`;o00000_ooool9o`0001?ooooo0_l0000:oooo
o`;o0000:?ooool3o`0000Cooooo0_l00005ooooo`Co0000@_ooool001cooooo00?o0000oooooooo
ool0?_ooool2o`0000Oooooo0_l0000@ooooo`Co00009Oooool2o`0000Sooooo0ol00009ooooo`;o
00001Oooool2o`0000?ooooo2_l0000:ooooo`;o00001Oooool2o`0000Wooooo0ol0000Yooooo`Co
00001?ooool4o`000003ooooool0003o000000;o0000@_ooool001cooooo00?o0000ooooooooool0
?_ooool2o`0000;ooooo0_l00003ooooo`;o00004Oooool3o`0002oooooo0ol00006ooooo`;o0000
00?oooooo`000?l000002_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000Wooooo
0_l000000ooooooo0000o`000002ooooo`;o00002Oooool2o`0002cooooo0_l00004ooooo`Co0000
0_ooool2o`0001[ooooo0_l0000Wooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00000_oo
ool2o`0000?ooooo0_l0000Dooooo`;o0000;Oooool4o`0000Gooooo0_l00004ooooo`;o00001?oo
ool2o`0000;ooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000Co000000?o
ooooo`000?l000000oooool8o`0000Sooooo0_l0000[ooooo`;o00002?ooool2o`000003ooooool0
003o000001_ooooo0_l0000Wooooo`007?ooool00ol0003oooooooooo`17ooooo`;o00005?ooool2
o`0002gooooo1?l00006ooooo`;o00000oooool2o`0000Cooooo0_l000001Ooooooo0000o`000?l0
003ooooo00Co000000?oooooo`000?l000001?l000000ooooooo0000o`000002ooooo`Co000000?o
ooooo`000?l000002Oooool4o`0002?ooooo0ol00003ooooo`?o00002?ooool2o`000003ooooool0
003o000004Cooooo000Looooo`03o`000?oooooooooo043ooooo0_l00005ooooo`;o00003_ooool2
o`0003?ooooo0_l00004ooooo`;o00000_ooool2o`000003ooooool0003o000000Wooooo0_l00003
ooooo`;o00000_ooool6o`000003ooooool0003o000000Wo00002Oooool4o`0002?ooooo0ol00003
ooooo`;o00003?ooool2o`0004Cooooo000Looooo`03o`000?oooooooooo043ooooo0_l00005oooo
o`;o00003Oooool3o`000003ooooool0003o000000;ooooo0_l0000/ooooo`?o00000oooool2o`00
00Gooooo0_l0000>ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`_o000000?ooooo
o`000?l000003?ooool2o`0002Cooooo0_l00006ooooo`;o00001?ooool3o`0001Sooooo0_l0000Z
ooooo`007?ooool00ol0003oooooooooo`0nooooo`Co00001?ooool3o`0000gooooo1_l00002oooo
o`Co00008oooool2o`0000Gooooo0ol00006ooooo`;o00001Oooool2o`0000Kooooo1?l000000ooo
oooo0000o`000003ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000006
o`000004ooooool0003o0000o`0000[ooooo0ol0000Nooooo`?o00000oooool2o`0000?ooooo1Ol0
0004ooooo`;o00006?ooool3o`0002[ooooo000Looooo`03o`000?oooooooooo03kooooo0ol00005
ooooo`?o00004?ooool3o`0000Cooooo0_l0000Sooooo`;o00001?ooool2o`0000Cooooo0_l00002
ooooo`;o00001Oooool2o`0000Cooooo2ol000000ooooooo0000o`000003ooooo`;o00000oooool2
o`0000Cooooo0_l000000ooooooo0000o`00000:ooooo`;o00000oooool2o`0001[ooooo0ol00008
ooooo`Co00001?ooool2o`0001Wooooo0_l0000[ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^
k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0
?_ooool2o`0000Oooooo0_l0000>ooooo`Go0000:Oooool2o`0000Cooooo0ol00003ooooo`;o0000
3OoooolGo`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000003?ooool2o`0000Co
oooo0ol0000Oooooo`;o00000oooool5o`0000;ooooo0ol0000Gooooo`;o0000;Oooool00006oooo
oomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06
ooooo`03o`000?oooooooooo043ooooo0_l000001?oooooo0000o`000?l0000Aooooo`Oo0000;Ooo
ool4o`0000gooooo7_l000001?oooooo0000o`000?ooool2o`0000cooooo0_l00005ooooo`;o0000
6?ooool2o`0000Cooooo0ol00003ooooo`;o000000Coooooo`000?l0003ooooo0ol0000Gooooo`?o
0000;Oooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool0@?ooool2o`000004ooooool0003o0000o`00
01;ooooo2?l0000[ooooo`Co00002Oooool2o`0000;ooooo1ol00002ooooo`Co000000?oooooo`00
0?l000002?l000001?oooooo0000o`000?l00002ooooo`Ko00005Oooool2o`0001Gooooo0ol00002
ooooo`Co00000_ooool4o`0000Cooooo0_l0000Hooooo`;o0000;_ooool00003ooooool0003ooooo
00;ooooo00?o0000ooooooooool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0000o
ooooo`?o00000_ooool2o`00017ooooo0ol000000ooooooo0000o`000003o`0000?ooooo0_l00002
ooooo`;o00008_ooool2o`0000?ooooo0_l00006ooooo`;o00001?ooool8o`000003ooooool0003o
000000_o00000_ooool2o`0000;ooooo2_l0000Aooooo`;o00005Oooool2o`0000?ooooo0_l00004
ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Jooooo`;o0000;_ooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o
0000ooooooooool0?oooool2o`0000?ooooo0_l0000Aooooo`?o00001?ooool4o`000003ooooool0
003o000000;ooooo0_l0000Rooooo`;o00000_ooool3o`0000_ooooo5ol00003ooooo`;o000000Go
ooooo`000?l0003o0000ooooo`07o`0000Oooooo1?l0000Wooooo`;o000000?oooooo`000?l00000
0ol0001:ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`03oeEEEOn7
QhOooooo00Sooooo00?o0000ooooooooool0?oooool2o`0000kooooo0_l00007ooooo`?o00001Ooo
ool2o`0000;ooooo0ol00007ooooo`;o00004?ooool3o`0000Sooooo0ol000000ooooooo0000o`00
0009ooooo`;o000000?oooooo`000?l000000ol000000ooooooo0000o`00000Ao`000004ooooool0
003o0000o`0000?ooooo1Ol000000ooooooo0000o`000007ooooo`Co00009Oooool:o`0004[ooooo
00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003o
ooooooooo`0oooooo`;o00003_ooool4o`0000Gooooo0ol00004ooooo`;o00000oooool3o`0000Oo
oooo0_l0000@ooooo`?o00000_ooool2o`0000?ooooo1?l0000<ooooo`;o000000?oooooo`000?l0
00006ol00002ooooo`Ko0000<_ooool3o`0000;ooooo1Ol0001;ooooo`0000Koooooonk^k_lb<S;o
0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0?oooool2
o`00013ooooo0_l00005ooooo`?o00000oooool3o`0000Cooooo0_l0000:ooooo`;o00003_ooool2
o`000004ooooool0003o0000o`0000?ooooo0ol0000@oooooa_o00001?ooool2o`0000;ooooo0ol0
00000ooooooo0000o`00000<ooooo`;o00001Oooool2o`0001Wooooo0_l00003ooooo`Co0000C?oo
ool001cooooo00?o0000ooooooooool0@Oooool4o`0001?ooooo0ol00003ooooo`;o00002Oooool4
o`0000;ooooo1?l0000>ooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo0_l00002
ooooo`;o00000oooool2o`0000Cooooo7?l000000ooooooo0000o`000004ooooo`?o000000?ooooo
o`000?l000003?ooool2o`0000Gooooo0_l0000Hooooo`?o00000_ooool4o`0004gooooo000Loooo
o`03o`000?oooooooooo047ooooo1?l00008ooooo`;o00002_ooool2o`0000Gooooo0_l000001?oo
oooo0000o`000?l00003ooooo`Co00000_ooool2o`000003ooooool0003o000001Kooooo0_l00002
ooooo`;o00000_ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000000_oooolK
o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0001Sooooo0_l0000Fooooo`;o00000ooo
ool4o`0004gooooo000Looooo`03o`000?oooooooooo043ooooo0_l00002ooooo`;o00001oooool2
o`0000Wooooo0ol00005ooooo`;o000000Coooooo`000?l0003o00003?ooool2o`0001Kooooo0_l0
0009ooooo`;o00000oooool2o`0000Cooooo7?l000000ooooooo0000o`000002ooooo`;o00000_oo
ool3o`0001?ooooo0_l0000eooooo`;o0000=Oooool001cooooo00?o0000ooooooooool0@?ooool2
o`0000;ooooo0_l0000=ooooo`;o00000oooool4o`0000Oooooo1?l0000Sooooo`;o00005?oooolJ
o`000003ooooool0003o000000;ooooo0_l00004ooooo`?o000000?oooooo`000?l000003Oooool2
o`000003ooooool0003o000001[ooooo0_l0000Iooooo`;o0000=Oooool001cooooo00?o0000oooo
ooooool0C?ooool2o`0000Gooooo1?l000000ooooooo0000o`000002o`0000Wooooo0_l000000ooo
oooo0000o`000002o`0000[ooooo1?l000000ooooooo0000o`000005ooooo`?o00001?ooool4o`00
0003ooooool0003o000000oooooo6ol000000ooooooo0000o`000002ooooo`;o00001?ooool3o`00
0003ooooool0003o000000gooooo1Ol0000?ooooo`;o00002Oooool2o`0001Oooooo0ol0000foooo
o`007?ooool00ol0003oooooooooo`13ooooo`;o00000_ooool2o`0000?ooooo0_l00007ooooo`;o
00000_ooool3o`0000cooooo1_l000001?oooooo0000o`000?ooool2o`0000;ooooo1?l000000ooo
oooo0000o`000005ooooo`?o00001?ooool4o`000003ooooool0003o000000cooooo0_l000000ooo
oooo0000o`00000Lo`0000Wooooo0_l0000;ooooo`;o00001?ooool2o`0000;ooooo0_l0000=oooo
o`;o00002?ooool2o`0001Sooooo0ol0000fooooo`007?ooool00ol0003oooooooooo`12ooooo`So
00005Oooool4o`0000Gooooo1_l000001?oooooo0000o`000?ooool2o`0000?ooooo1?l00007oooo
o`;o00001Oooool4o`0000oooooo0_l00002oooooago00005_ooool2o`0000;ooooo0_l00004oooo
o`;o00003?ooool4o`0000Oooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`12ooooo`So
00004Oooool2o`0000;ooooo1?l00004ooooo`Co00002Oooool2o`000003ooooool0003o000000;o
00003_ooool5o`0001?ooooo6Ol00002ooooo`;o000000?oooooo`000?l000001?ooool2o`0000co
oooo0_l000000ooooooo0000o`000003o`00013ooooo1?l00002ooooo`;o00000oooool2o`0001Oo
oooo0_l0000hooooo`007?ooool00ol0003oooooooooo`15ooooo`Go000000?oooooo`000?l00000
1_ooool3o`0000Gooooo0_l00003ooooo`Co00000oooool2o`0000_ooooo0ol0000<ooooo`;o0000
1_ooool5o`0000[ooooo0_l00005oooooa[o000000Coooooo`000?l0003ooooo0_l000001?oooooo
0000o`000?ooool2o`0000cooooo1Ol000000ooooooo0000o`00000Fooooo`;o00000oooool2o`00
01Kooooo0ol0000hooooo`007?ooool00ol0003oooooooooo`16ooooo`Co000000Coooooo`000?l0
003ooooo0_l00003ooooo`?o00001_ooool2o`0000;ooooo1Ol0000<ooooo`;o00000_ooool4o`00
00Sooooo1?l00009ooooo`;o00002_ooool2o`0000Gooooo6_l000000ooooooo0000o`000004oooo
o`;o00004Oooool4o`0000;ooooo0_l0000Dooooo`;o00006oooool2o`0003Wooooo000Looooo`03
o`000?oooooooooo04Cooooo1?l00006ooooo`;o00000_ooool2o`0000?ooooo0_l000000ooooooo
0000o`000002o`0000Gooooo1Ol00006ooooo`Ko00000oooool3o`0000?ooooo0_l00002ooooo`;o
00001_ooool2o`0000;ooooo1?l0000AoooooaWo000000?oooooo`000?l000001_ooool2o`0000oo
oooo1?l000001?oooooo0000o`000?l0000Dooooo`;o0000E_ooool001cooooo0_l00015ooooo`;o
00003?ooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`0000Kooooo1?l00003ooooo`Wo
00000oooool3o`0000?ooooo0_l0000:ooooo`;o00000_ooool4o`0000oooooo7_l00006ooooo`;o
00003oooool4o`000003ooooool0003o000001Gooooo0_l0001Fooooo`007?ooool00ol0003ooooo
ooooo`14ooooo`;o00003?ooool2o`0000?ooooo0_l00002ooooo`?o000000?oooooo`000?l00000
2_ooool;o`000003ooooool0003o0000013ooooo0_l000000ooooooo0000o`000003ooooo`;o0000
3?ooool9o`000003ooooool0003o000001?o00006_ooool4o`0002kooooo0_l0000mooooo`007?oo
ool00ol0003oooooooooo`16ooooo`;o00000oooool2o`0000Gooooo1?l00005ooooo`?o000000?o
ooooo`000?l000000oooool2o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`Go00002ooo
ool4o`0000Kooooo0ol00003ooooo`;o00003?ooool2o`000003ooooool0003o000000Co000000?o
ooooo`000?l000004?l000000ooooooo0000o`00000Fooooo`?o000000?oooooo`000?l000003ooo
ool2o`0000[ooooo0_l0000Booooo`?o0000?Oooool001cooooo00?o0000ooooooooool0A_ooool4
o`000003ooooool0003o000000Gooooo1_l00003ooooo`?o000000?oooooo`000?l000000_ooool3
o`0000?ooooo1ol000000ooooooo0000o`000003o`0000Cooooo0_l00005ooooo`Co00000oooool6
o`0000oooooo0_l00003ooooo`Oo000000?oooooo`000?l000003ol000000ooooooo0000o`00000E
ooooo`Co00004_ooool4o`0000;ooooo0ol00003ooooo`;o00004_ooool2o`0003kooooo000Loooo
o`03o`000?oooooooooo04Cooooo0_l000000ooooooo0000o`000003o`0000[ooooo0_l00003oooo
o`?o00001Oooool3o`0000?ooooo2Ol000001?oooooo0000o`000?l00004ooooo`;o00003?ooool3
o`0001;ooooo0_l00004oooooa_o00005?ooool4o`0001Gooooo0_l00002ooooo`?o00000_ooool2
o`00013ooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00000_ooool4o`00
00oooooo0ol00006ooooo`;o00001?ooool3o`000003ooooool0003o000000;o000000Coooooo`00
0?l0003o00001?ooool2o`0000gooooo0_l00003ooooo`;o00002oooool2o`0000Kooooo6ol0000D
ooooo`?o00006Oooool3o`0000?ooooo0_l0000@ooooo`;o0000@Oooool001cooooo00?o0000oooo
ooooool0B?ooool2o`00017ooooo1_l00003ooooo`;o00001Oooool2o`000003ooooool0003o0000
00?ooooo0ol00004ooooo`;o00003Oooool2o`0000?ooooo0_l0000;ooooo`;o00001_oooolKo`00
01?ooooo1?l000000ooooooo0000o`00000Fooooo`?o00004oooool3o`0004;ooooo000Looooo`03
o`000?oooooooooo04Sooooo1_l0000=ooooo`Ko00000oooool2o`0000Cooooo0_l00003ooooo`Oo
00004oooool2o`0000Sooooo0_l0000>ooooo`;o000000?oooooo`000?l000005_l0000Cooooo`?o
00000_ooool5o`0001?ooooo0ol0000Cooooo`?o0000@_ooool001cooooo00?o0000ooooooooool0
B?ooool6o`0000kooooo0_l0000;ooooo`?o00000_ooool8o`0000Cooooo0_l0000=ooooo`;o0000
2?ooool2o`0000kooooo0_l000000ooooooo0000o`00000Bo`000004ooooool0003o0000o`0001;o
oooo1Ol000000ooooooo0000o`000003o`0000Oooooo0_l0000:ooooo`?o0000F?ooool001cooooo
00?o0000ooooooooool0AOooool2o`0002;ooooo0_l00002ooooo`So00001?ooool3o`0000Kooooo
0_l00005ooooo`;o00006ooooolGo`0001;ooooo2_l00009ooooo`;o00002oooool2o`0005Sooooo
000Looooo`03o`000?oooooooooo04Gooooo0_l0000Fooooo`;o00002_ooool2o`0000;ooooo2?l0
0004ooooo`?o00001_ooool3o`00027ooooo3_l00002ooooo`Oo00004_ooool5o`000004ooooool0
003o0000o`0002Sooooo1?l00015ooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o00002_oo
ool4o`0000;ooooo1?l0000>ooooo`Co00003Oooool3o`0001;ooooo2ol00002ooooo`So00004_oo
ool2o`0000?ooooo1Ol0000Xooooo`Co0000AOooool001cooooo00?o0000ooooooooool0A_ooool4
o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000[ooooo0ol00003ooooo`?o00001Oooool2
o`0000Oooooo0_l0000:ooooo`Co000000Coooooo`000?l0003o00004_ooool6o`0000;ooooo3Ol0
000Booooo`;o00000oooool4o`0001Gooooo0_l0000Aooooo`;o0000B?ooool001cooooo00?o0000
ooooooooool0A_ooool4o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000[ooooo0ol00003
ooooo`Co00000oooool3o`0000Wooooo0_l00008ooooo`Co00002?ooool2o`0000gooooo1Ol00002
ooooo`go00009oooool2o`0000Oooooo0_l0000@ooooo`?o0000B?ooool001cooooo00?o0000oooo
ooooool0B?ooool2o`0000Gooooo0_l00002ooooo`;o00002Oooool2o`0000[ooooo0ol00003oooo
o`[o00002Oooool2o`00013ooooo0_l00002ooooo`?o00002?ooool2o`0000;ooooo2ol00002oooo
o`Oo00005Oooool2o`00013ooooo0_l00005ooooo`Go00003_ooool3o`0004Wooooo000Looooo`03
o`000?oooooooooo04Sooooo0_l00005ooooo`;o00000_ooool2o`0000_ooooo0ol0000@ooooo`Go
00002Oooool4o`0000cooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000000Go
oooo0_l00002ooooo`;o00000_ooool6o`0000;ooooo1ol0000@ooooo`;o00000oooool3o`0000_o
oooo0_l00003ooooo`;o00001Oooool5o`0000kooooo0_l0001:ooooo`007?ooool2o`00053ooooo
0_l000000ooooooo0000o`00000<ooooo`?o000000?oooooo`000?l000004?ooool2o`0000Wooooo
1?l0000<ooooo`?o000000?oooooo`000?l000001_ooool2o`0000;ooooo1Ol00006ooooo`Ko0000
00?oooooo`000?l000001_l0000?ooooo`?o00000oooool2o`0000cooooo1?l00008ooooo`;o0000
GOooool001cooooo00?o0000ooooooooool0D_ooool4o`0000Oooooo0_l000000ooooooo0000o`00
0002ooooo`;o00001oooool2o`00017ooooo1Ol0000=ooooo`;o000000?oooooo`000?l000000_l0
0008ooooo`Go000000?oooooo`000?l000004_l0000?ooooo`;o000000?oooooo`000?l000000_l0
000?ooooo`;o00006Oooool2o`0004cooooo000Looooo`03o`000?oooooooooo05Cooooo0_l00007
ooooo`;o00000oooool2o`0000Wooooo0_l0000Aooooo`;o00005Oooool4o`0000Sooooo0ol00000
0ooooooo0000o`000006o`0000;ooooo2_l0000=ooooo`;o00000oooool4o`0000gooooo0_l00006
ooooo`Co00004Oooool2o`0004cooooo000Looooo`03o`000?oooooooooo05Cooooo0_l00005oooo
o`Co00000oooool3o`0000;ooooo0_l0000Gooooo`Go00005?ooool2o`0000;ooooo0_l000000ooo
oooo0000o`000002ooooo`;o00000_ooool2o`0000?ooooo0_l00003ooooo`Wo00002oooool4o`00
00gooooo0_l000000ooooooo0000o`000004o`0000Kooooo1?l0001Oooooo`007?ooool00ol0003o
ooooooooo`1Dooooo`;o00000oooool6o`0000Cooooo0_l00002ooooo`;o00001?ooool2o`000003
ooooool0003o000000;o00002Oooool2o`000003ooooool0003o000000?o00005oooool3o`000003
ooooool0003o000000?ooooo1Ol00003ooooo`;o00001oooool9o`0000Oooooo1?l0000=ooooo`;o
000000?oooooo`000?l000000_l00005ooooo`?o0000Hoooool001cooooo00?o0000ooooooooool0
Doooool2o`0000Cooooo0_l00002ooooo`;o00001Oooool2o`0000;ooooo0_l00003ooooo`;o0000
00?oooooo`000?l000001Ol000000ooooooo0000o`000008o`0001[ooooo0_l00007ooooo`Co0000
2oooool4o`0000;ooooo1_l0000Sooooo`?o0000Hoooool001cooooo00?o0000ooooooooool0Dooo
ool2o`0000kooooo0ol00002ooooo`;o00000oooool4o`0000?ooooo3Ol0000cooooo`co00000ooo
ool2o`0001;ooooo0_l00007ooooo`;o000000?oooooo`000?l000004Oooool2o`00057ooooo000L
ooooo`03o`000?oooooooooo04oooooo0_l0000:ooooo`;o00001_ooool4o`0000Oooooo0ol00005
ooooo`So000000?oooooo`000?l00000=?ooool2o`000003ooooool0003o000000;o000000?ooooo
o`000?l000000_l00002ooooo`;o00003oooool2o`000003ooooool0003o000000Kooooo1Ol0000B
ooooo`;o0000DOooool001cooooo00?o0000ooooooooool0Coooool2o`0000[ooooo0_l00008oooo
o`;o00002?ooool2o`0000Kooooo1ol0000looooo`;o00000oooool2o`0001;ooooo1?l00007oooo
o`?o000000?oooooo`000?l000003oooool2o`0005Cooooo000Looooo`03o`000?oooooooooo067o
oooo0_l00004ooooo`;o000000?oooooo`000?l000001_ooool2o`0000?ooooo0_l000000ooooooo
0000o`000002o`0004_ooooo0_l00003ooooo`Co000000?oooooo`000?l000000_l00005ooooo`Co
00004_ooool3o`0005Cooooo000Looooo`03o`000?oooooooooo05;ooooo1Ol0000:ooooo`;o0000
1?ooool2o`000003ooooool0003o000000Gooooo1Ol00004ooooo`Go00000oooool2o`0004Gooooo
0_l000000ooooooo0000o`000004o`0000[ooooo0_l0000Dooooo`;o0000EOooool001cooooo00?o
0000ooooooooool0DOooool6o`000003ooooool0003o000000gooooo0ol00007ooooo`;o000000?o
ooooo`000?l000000ol000000ooooooo0000o`000003o`0000;ooooo0ol0000Tooooo`;o00007Ooo
ool4o`000003ooooool0003o000000?o00001_ooool3o`0001Gooooo1?l0001Fooooo`007?ooool0
0ol0003oooooooooo`1Aooooo`;o000000?oooooo`000?l000001?l0000>ooooo`?o00002_ooool4
o`0000Sooooo0_l0000Uooooo`;o00002_ooool4o`0000;ooooo0_l00008ooooo`;o000000?ooooo
o`000?l000000_l00007ooooo`?o00000_ooool3o`0001Gooooo1?l0001Fooooo`007?ooool00ol0
003oooooooooo`1Aooooo`;o00000oooool2o`00017ooooo0_l0000;ooooo`;o00002Oooool2o`00
02kooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l000000ooooooo0000o`000005oooo
o`;o00003?ooool3o`0001Oooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`1Oooooo`;o
00002_ooool2o`0000Wooooo1?l00004ooooo`Go0000;_ooool2o`0000?ooooo0_l00005ooooo`;o
00003?ooool3o`0001kooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o0000
00Coooooo`000?l0003o00001Oooool3o`0000Wooooo0_l0000:ooooo`?o00000_ooool6o`0003Co
oooo0_l00003ooooo`;o000000?oooooo`000?l000001Oooool2o`000004ooooool0003o0000oooo
o`?o00006oooool4o`0005cooooo000Looooo`;o0000EOooool2o`000004ooooool0003o0000o`00
00Gooooo0ol00009ooooo`Co00002Oooool2o`0000;ooooo0_l00002ooooo`;o0000>Oooool2o`00
0004ooooool0003o0000ooooo`;o00000_ooool2o`000003ooooool0003o000001cooooo0_l00000
0ooooooo0000o`000002o`0005cooooo000Looooo`03o`000?oooooooooo05Wooooo0_l00008oooo
o`Co00001Oooool5o`00053ooooo0_l0000Mooooo`Co00000_ooool2o`00067ooooo000Looooo`03
o`000?oooooooooo05Wooooo0_l00008ooooo`Co00002?ooool2o`0000[ooooo0_l00003ooooo`;o
0000G?ooool8o`0000;ooooo0_l0001Oooooo`007?ooool00ol0003oooooooooo`1Yooooo`;o0000
0oooool3o`0000[ooooo0_l00003ooooo`;o0000G?ooool2o`0000;ooooo1?l00002ooooo`?o0000
G_ooool001cooooo00?o0000ooooooooool0JOooool2o`0000?ooooo1?l0001Uooooo`;o00002Ooo
ool3o`0000?ooooo0ol0001Nooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o00004?ooool3
o`0006?ooooo1?l0000:ooooo`?o00000_ooool2o`0005oooooo000Looooo`03o`000?oooooooooo
05gooooo0_l00007ooooo`;o00002?ooool3o`000003ooooool0003o000005_ooooo0_l00002oooo
o`;o00003Oooool2o`0006?ooooo000Looooo`03o`000?oooooooooo05kooooo0_l00006ooooo`;o
00002Oooool2o`000003ooooool0003o000005Oooooo0_l00002ooooo`;o0000M_ooool001cooooo
00?o0000ooooooooool0G_ooool2o`0000cooooo0ol0001:ooooo`;o00004_ooool2o`0000Cooooo
0_l0001dooooo`007?ooool00ol0003oooooooooo`1/ooooo`?o00001Oooool3o`0004;ooooo0_l0
0005ooooo`;o00002?ooool2o`0000Oooooo0_l00008ooooo`;o0000J_ooool001cooooo00?o0000
ooooooooool0M?ooool3o`00047ooooo0_l00005ooooo`Co00001oooool2o`00017ooooo0ol0001Y
ooooo`007?ooool00ol0003oooooooooo`1Rooooo`?o00004_ooool2o`00037ooooo0ol00003oooo
o`;o00001_ooool2o`0000Gooooo1ol00004ooooo`;o00004_ooool2o`0006Wooooo000Looooo`03
o`000?oooooooooo06;ooooo0ol0000Booooo`?o0000<?ooool3o`0000?ooooo0ol0000<ooooo`;o
000000?oooooo`000?l000000_l00004ooooo`;o00003Oooool2o`0006kooooo000Looooo`03o`00
0?oooooooooo06?ooooo0_l00008ooooo`;o00000_ooool2o`0000Gooooo1?l0000/ooooo`;o0000
1_ooool3o`0000cooooo1Ol0000>ooooo`;o00001Oooool2o`0006kooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0
003oooooooooo`1Sooooo`?o00001oooool2o`0000;ooooo0_l00007ooooo`;o0000;?ooool2o`00
00Kooooo0_l00003ooooo`;o00002?ooool5o`0000Cooooo0_l00006ooooo`Co0000MOooool00006
oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q
8@06ooooo`03o`000?oooooooooo06Cooooo0_l000000ooooooo0000o`00000Cooooo`?o0000=_oo
ool2o`0000Sooooo0_l00002ooooo`?o00000_ooool2o`0000Kooooo1?l0001eooooo`0000?ooooo
oa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`1Wooooo`;o00002?ooool2o`0000Cooooo0_l00003ooooo`Oo0000@?oo
ool3o`000004ooooool0003o0000o`0000Sooooo0_l0001eooooo`0000?oooooo`000?ooool00_oo
ool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`00077ooooo
0_l00003ooooo`?o00001_ooool5o`0003Kooooo0ol0000:ooooo`?o0000Ooooool00003ooooool0
003ooooo00;ooooo00?o0000ooooooooool02Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo
00?o0000ooooooooool0JOooool3o`0000[ooooo0_l0000:ooooo`?o0000=Oooool3o`0000Sooooo
1?l00003ooooo`;o00001?ooool2o`0007Gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oo
oooooooo00Wooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo06Wooooo
0ol0000Fooooo`?o00000_ooool4o`00033ooooo0_l00008ooooo`Co00000oooool2o`0000Cooooo
0_l0001eooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj
^_l000001_ooool00ol0003oooooooooo`1hooooo`;o00002?ooool2o`0000?ooooo1Ol0000Soooo
o`;o00000oooool4o`0000Cooooo0_l00003ooooo`;o00001?ooool2o`00083ooooo00001_oooooo
k^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oo
oooooooo07Sooooo0_l0000@ooooo`;o00008oooool2o`0000?ooooo1?l00004ooooo`;o00000ooo
ool2o`0008Kooooo000Looooo`03o`000?oooooooooo0<7ooooo0_l00026ooooo`007?ooool00ol0
003oooooooooo`1mooooo`;o00000oooool2o`00027ooooo0_l00005ooooo`;o00004Oooool4o`00
08Kooooo000Looooo`03o`000?oooooooooo07cooooo1?l00002ooooo`Co00007Oooool4o`0000Go
oooo0_l0000<ooooo`;o00000oooool2o`0008Sooooo000Looooo`03o`000?oooooooooo07cooooo
1?l00004ooooo`;o00007Oooool4o`0000?ooooo0ol00004ooooo`;o00001Oooool4o`0008gooooo
000Looooo`03o`000?oooooooooo08gooooo0_l0000<ooooo`;o00000oooool2o`000003ooooool0
003o000000Gooooo0ol00003ooooo`?o00001Oooool3o`0008kooooo000Looooo`03o`000?oooooo
oooo07Gooooo0_l0000;ooooo`?o00000oooool4o`000003ooooool0003o000000cooooo0_l00000
0ooooooo0000o`000002o`000003ooooool0003o000000;o00002Oooool2o`0000?ooooo0ol0002A
ooooo`007?ooool00ol0003oooooooooo`1eooooo`?o00002_ooool3o`0000?ooooo1?l000000ooo
oooo0000o`000007ooooo`;o00001_ooool2o`0000Gooooo1?l00002ooooo`;o00001_ooool5o`00
097ooooo000Looooo`03o`000?oooooooooo07Kooooo0_l0000Eooooo`;o00001oooool2o`0000go
oooo1?l00002ooooo`Co00001?ooool2o`0009Cooooo000Looooo`03o`000?oooooooooo08Oooooo
0_l00004ooooo`;o00001_ooool2o`000004ooooool0003o0000o`0000?ooooo0_l00005ooooo`;o
00001Oooool3o`0009[ooooo000Looooo`03o`000?oooooooooo08Oooooo0_l0000<ooooo`;o0000
00Coooooo`000?l0003o00000oooool2o`0000;ooooo0_l00008ooooo`;o0000Voooool001cooooo
00?o0000ooooooooool0U_ooool2o`0000Gooooo0_l00003ooooo`;o00002?ooool2o`0009_ooooo
000Looooo`;o0000U_ooool3o`0000Gooooo0_l00003ooooo`;o0000YOooool001cooooo00?o0000
ooooooooool0UOooool2o`000;;ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2
o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001;ooooo1?l000000ol@413oooooooooo`03
ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo0ol0003ooooood[o
oooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooo
oomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo
0?ooooooD_ooool001;ooooo00?oEEEEofIVI_l00000oooooomDooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00YOooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooo
oooo01Gooooo1Ol00005ooooo`03o`000?o^k^kooooo00?ooooo00Gok^k^oc8b<_l0003o410@olc<
c02@ooooo`00Y_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l00009ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01Oooool00omEEEGoZJVYooooo`03ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B40T?ooool00:Kooooo00Go0000ooooooooooooooooo`00000Iooooo`03oiRHV?lQ8B7ok^k^00Ko
oooo00?oZJVYoeEEEOooool00oooool01Ol0003ooooooooooooooooo0000093ooooo002Vooooo`05
o`000?ooooooooooooooool000002Oooool6o`0000_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00olQ
8B7oooooooooo`02ooooo`05o`000?nHV9SooooooiRHV?lQ8B40T?ooool00:Kooooo00Go0000ohN7
QoooooooZJVYo`00000Kooooo`03ogMgMomVIVKooooo00Gooooo00?oEEEEolc<c?ooool00_ooool0
1Ol0003oEEEEo`000?l@413oc<c<093ooooo002Uooooo`03oa0@4?l0003oMgMg00;o000000?oV9RH
ooooooooool06_ooool00ol0003oooooooooo`04ooooo`03ojVYZOmgMgOooooo00;ooooo00?oEEEE
ohN7Qoooool0T_ooool00<?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05oa0@4?oooooo
oooooooooolb<S800oooool00ooMgMgo410@oiRHV02Booooo`00`oooool01OnHV9So410@o`000?lQ
8B7oc<c<00?ooooo1Ol00004ooooo`04olc<c?m4A4Co0000oa0@493ooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(282) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.69967 .43436 Mdot
.68867 .45567 Mdot
.36185 .29169 Mdot
.52579 .61893 Mdot
.32333 .50379 Mdot
.36522 .3678 Mdot
.54413 .32559 Mdot
.53948 .33401 Mdot
.34194 .30938 Mdot
.60955 .75409 Mdot
.56264 .29673 Mdot
.53616 .70024 Mdot
.5354 .31423 Mdot
.52656 .65097 Mdot
.36222 .62885 Mdot
.51322 .59998 Mdot
.6632 .43713 Mdot
.32304 .43057 Mdot
.50886 .60292 Mdot
.34268 .35942 Mdot
.58457 .57465 Mdot
.51577 .64643 Mdot
.71385 .47759 Mdot
.52385 .65299 Mdot
.49121 .68003 Mdot
.67666 .45352 Mdot
.70162 .43575 Mdot
.5154 .70991 Mdot
.51012 .61734 Mdot
.54418 .28741 Mdot
.43027 .54969 Mdot
.32638 .74728 Mdot
.51898 .54059 Mdot
.72968 .61237 Mdot
.53385 .29182 Mdot
.54548 .37245 Mdot
.38584 .34967 Mdot
.52064 .30141 Mdot
.56586 .29383 Mdot
.56339 .32497 Mdot
.56293 .32239 Mdot
.67578 .45109 Mdot
.51657 .33094 Mdot
.39431 .22972 Mdot
.52176 .66482 Mdot
.77753 .52517 Mdot
.32128 .29553 Mdot
.50755 .68824 Mdot
.69302 .48635 Mdot
.33542 .30967 Mdot
.26887 .57768 Mdot
.53774 .34108 Mdot
.49364 .52695 Mdot
.81755 .33538 Mdot
.53607 .32582 Mdot
.48974 .63354 Mdot
.35194 .32814 Mdot
.54538 .65976 Mdot
.54266 .68762 Mdot
.71961 .58107 Mdot
.54801 .64677 Mdot
.33329 .46299 Mdot
.68592 .50624 Mdot
.32967 .30543 Mdot
.34432 .30223 Mdot
.51615 .32196 Mdot
.64536 .46063 Mdot
.53614 .29768 Mdot
.51201 .62031 Mdot
.33829 .33503 Mdot
.49318 .64127 Mdot
.56206 .29582 Mdot
.70357 .44099 Mdot
.50978 .64616 Mdot
.72898 .38448 Mdot
.59449 .34863 Mdot
.32096 .42239 Mdot
.62109 .52505 Mdot
.39782 .40392 Mdot
.3753 .6049 Mdot
.51119 .64688 Mdot
.55044 .18361 Mdot
.32131 .62815 Mdot
.69889 .47899 Mdot
.48828 .58416 Mdot
.6428 .26029 Mdot
.49683 .68091 Mdot
.43393 .54333 Mdot
.54567 .69951 Mdot
.26997 .51105 Mdot
.34819 .33393 Mdot
.66978 .48324 Mdot
.51289 .65983 Mdot
.50699 .63207 Mdot
.66906 .73368 Mdot
.51488 .61096 Mdot
.5207 .71137 Mdot
.4506 .47637 Mdot
.55214 .34384 Mdot
.50801 .5489 Mdot
.43443 .38435 Mdot
.48565 .53201 Mdot
.49134 .65526 Mdot
.35983 .34821 Mdot
.68839 .50478 Mdot
.51507 .55565 Mdot
.54226 .29606 Mdot
.51443 .65596 Mdot
.56477 .26422 Mdot
.69872 .48479 Mdot
.51158 .71666 Mdot
.31693 .45962 Mdot
.55568 .4949 Mdot
.7143 .45026 Mdot
.7761 .63091 Mdot
.53456 .62863 Mdot
.53686 .68063 Mdot
.68861 .45281 Mdot
.35478 .37947 Mdot
.49945 .18791 Mdot
.69552 .43964 Mdot
.56195 .33738 Mdot
.65438 .44514 Mdot
.47701 .48636 Mdot
.35337 .38021 Mdot
.46229 .49404 Mdot
.46083 .48435 Mdot
.29127 .68293 Mdot
.5342 .61932 Mdot
.58536 .61731 Mdot
.36495 .35656 Mdot
.70016 .44519 Mdot
.52924 .31251 Mdot
.55764 .62288 Mdot
.6728 .46947 Mdot
.54435 .33022 Mdot
.34485 .45961 Mdot
.31535 .43502 Mdot
.71261 .46638 Mdot
.78912 .61949 Mdot
.55708 .35507 Mdot
.53846 .3524 Mdot
.26984 .58094 Mdot
.69967 .47811 Mdot
.32824 .47845 Mdot
.54812 .30362 Mdot
.1717 .47525 Mdot
.48962 .68246 Mdot
.27038 .61816 Mdot
.55947 .19234 Mdot
.26912 .57677 Mdot
.59242 .61352 Mdot
.31643 .47045 Mdot
.5446 .33066 Mdot
.50595 .67505 Mdot
.69322 .47284 Mdot
.67271 .46632 Mdot
.49563 .63903 Mdot
.51063 .55911 Mdot
.53572 .65285 Mdot
.51478 .54607 Mdot
.44775 .48467 Mdot
.51536 .66053 Mdot
.81805 .48466 Mdot
.68422 .47907 Mdot
.50282 .5802 Mdot
.38355 .34793 Mdot
.54797 .58761 Mdot
.51715 .33039 Mdot
.55701 .6436 Mdot
.48752 .61478 Mdot
.54546 .69396 Mdot
.55607 .34949 Mdot
.76477 .3884 Mdot
.38256 .40659 Mdot
.56671 .3146 Mdot
.4875 .28003 Mdot
.37352 .34495 Mdot
.53053 .69546 Mdot
.30896 .47278 Mdot
.50664 .53808 Mdot
.50407 .65144 Mdot
.26776 .56988 Mdot
.54103 .68816 Mdot
.59757 .62956 Mdot
.58258 .66891 Mdot
.61628 .24823 Mdot
.76829 .41671 Mdot
.51862 .62178 Mdot
.62354 .70688 Mdot
.27406 .60849 Mdot
.55843 .38093 Mdot
.52825 .31118 Mdot
.35873 .37456 Mdot
.35589 .37755 Mdot
.58493 .28603 Mdot
.75547 .62683 Mdot
.59005 .76515 Mdot
.55287 .62208 Mdot
.48716 .5277 Mdot
.65948 .43124 Mdot
.31818 .47039 Mdot
.71163 .45872 Mdot
.5371 .17396 Mdot
.39352 .58668 Mdot
.41777 .59362 Mdot
.40451 .31634 Mdot
.33691 .29816 Mdot
.48253 .52465 Mdot
.32477 .48347 Mdot
.53512 .66678 Mdot
.70097 .48221 Mdot
.27324 .60041 Mdot
.50487 .55684 Mdot
.53818 .83996 Mdot
.68968 .43573 Mdot
.36013 .70006 Mdot
.53705 .32253 Mdot
.3632 .31443 Mdot
.49542 .67902 Mdot
.52856 .63651 Mdot
.69432 .49012 Mdot
.51457 .68766 Mdot
.40473 .64396 Mdot
.49201 .68622 Mdot
.33478 .34452 Mdot
.37465 .4117 Mdot
.56957 .31069 Mdot
.40896 .32789 Mdot
.71436 .44822 Mdot
.83885 .45825 Mdot
.36521 .33404 Mdot
.59029 .64861 Mdot
.56018 .29519 Mdot
.34301 .45709 Mdot
.35931 .33636 Mdot
.3126 .49767 Mdot
.55788 .65648 Mdot
.38035 .33193 Mdot
.32702 .45762 Mdot
.43583 .57808 Mdot
.51369 .55556 Mdot
.25354 .6595 Mdot
.55005 .32107 Mdot
.6562 .46591 Mdot
.50344 .66134 Mdot
.4969 .53448 Mdot
.50816 .56007 Mdot
.34814 .67609 Mdot
.46984 .49075 Mdot
.4837 .53347 Mdot
.34709 .58945 Mdot
.33265 .43396 Mdot
.71193 .28942 Mdot
.43834 .53186 Mdot
.66485 .43621 Mdot
.50699 .6362 Mdot
.53902 .24379 Mdot
.54804 .32956 Mdot
.53952 .66203 Mdot
.60442 .23398 Mdot
.54774 .30687 Mdot
.5396 .67381 Mdot
.56018 .28373 Mdot
.68214 .4748 Mdot
.38574 .63629 Mdot
.68338 .43235 Mdot
.51637 .66786 Mdot
.56025 .28606 Mdot
.3625 .37632 Mdot
.67587 .45527 Mdot
.51425 .65197 Mdot
.54812 .63018 Mdot
.48808 .52432 Mdot
.49048 .68329 Mdot
.60436 .36139 Mdot
.50521 .6877 Mdot
.37809 .30284 Mdot
.51345 .61311 Mdot
.3963 .48859 Mdot
.22944 .47341 Mdot
.70845 .4726 Mdot
.47023 .49158 Mdot
.35544 .33198 Mdot
.41242 .63304 Mdot
.36165 .70859 Mdot
.5219 .66095 Mdot
.47084 .49746 Mdot
.3221 .69542 Mdot
.52791 .34249 Mdot
.54502 .70083 Mdot
.27814 .48951 Mdot
.34971 .33828 Mdot
.48498 .52768 Mdot
.49485 .58511 Mdot
.68624 .41827 Mdot
.50896 .60487 Mdot
.37697 .33072 Mdot
.66772 .43761 Mdot
.5041 .6127 Mdot
.57404 .37451 Mdot
.49867 .55412 Mdot
.54337 .3505 Mdot
.4712 .53568 Mdot
.52466 .69545 Mdot
.33779 .3302 Mdot
.67174 .45242 Mdot
.53663 .32992 Mdot
.71235 .44777 Mdot
.28222 .56744 Mdot
.3405 .69396 Mdot
.75246 .42793 Mdot
.34636 .45704 Mdot
.17107 .51483 Mdot
.56495 .33148 Mdot
.50642 .52416 Mdot
.33509 .27676 Mdot
.62459 .45144 Mdot
.3569 .34603 Mdot
.7972 .60426 Mdot
.34904 .33052 Mdot
.49402 .61551 Mdot
.34996 .35885 Mdot
.66669 .74979 Mdot
.54979 .66928 Mdot
.34851 .29752 Mdot
.44217 .47528 Mdot
.55343 .65548 Mdot
.67163 .46925 Mdot
.36548 .78345 Mdot
.74292 .62169 Mdot
.74816 .63315 Mdot
.35539 .32505 Mdot
.80422 .59238 Mdot
.50648 .71012 Mdot
.56867 .63794 Mdot
.69056 .46907 Mdot
.5092 .53042 Mdot
.31199 .44451 Mdot
.30045 .46256 Mdot
.22294 .53126 Mdot
.37091 .74331 Mdot
.76217 .63786 Mdot
.67512 .46457 Mdot
.36829 .40574 Mdot
.73147 .38696 Mdot
.49901 .55181 Mdot
.53976 .33427 Mdot
.75873 .37024 Mdot
.54857 .69433 Mdot
.46698 .51574 Mdot
.40469 .64734 Mdot
.65865 .45771 Mdot
.74522 .47307 Mdot
.53771 .33146 Mdot
.74681 .63628 Mdot
.58531 .75667 Mdot
.53629 .65483 Mdot
.55192 .33222 Mdot
.50843 .5601 Mdot
.43573 .54437 Mdot
.29093 .69189 Mdot
.32097 .25489 Mdot
.51944 .66871 Mdot
.7345 .36358 Mdot
.50373 .65734 Mdot
.28509 .66929 Mdot
.53525 .66947 Mdot
.66748 .45891 Mdot
.52134 .7199 Mdot
.44275 .53362 Mdot
.17028 .40305 Mdot
.39141 .58057 Mdot
.31066 .49369 Mdot
.52496 .6482 Mdot
.53815 .64452 Mdot
.33862 .47184 Mdot
.6607 .47044 Mdot
.49953 .64732 Mdot
.72919 .29905 Mdot
.51171 .65669 Mdot
.51785 .32572 Mdot
.34314 .65087 Mdot
.3215 .73916 Mdot
.50266 .70415 Mdot
.68355 .41795 Mdot
.54071 .35219 Mdot
.55788 .29824 Mdot
.48571 .50335 Mdot
.54939 .3288 Mdot
.5105 .67935 Mdot
.34191 .65196 Mdot
.64456 .47282 Mdot
.50143 .55227 Mdot
.65989 .45961 Mdot
.2533 .31896 Mdot
.54798 .32204 Mdot
.48438 .51254 Mdot
.7664 .61549 Mdot
.54125 .30403 Mdot
.37354 .43348 Mdot
.51884 .7217 Mdot
.50363 .55613 Mdot
.70544 .43108 Mdot
.33914 .33543 Mdot
.47402 .51287 Mdot
.53652 .32706 Mdot
.52227 .66314 Mdot
.48711 .64953 Mdot
.55033 .32892 Mdot
.64452 .55309 Mdot
.43066 .54728 Mdot
.51257 .6654 Mdot
.67075 .47448 Mdot
.69505 .44403 Mdot
.54185 .60345 Mdot
.5024 .65579 Mdot
.36646 .37034 Mdot
.47045 .49668 Mdot
.46812 .49544 Mdot
.45973 .48506 Mdot
.35864 .31914 Mdot
.16182 .49744 Mdot
.52911 .34964 Mdot
.32538 .74469 Mdot
.66166 .37007 Mdot
.49803 .53177 Mdot
.37548 .37189 Mdot
.5324 .6331 Mdot
.4963 .672 Mdot
.55463 .28182 Mdot
.20026 .60636 Mdot
.56793 .63767 Mdot
.68266 .43339 Mdot
.54603 .33725 Mdot
.48314 .62809 Mdot
.56179 .24864 Mdot
.31606 .4491 Mdot
.76857 .63539 Mdot
.54206 .33852 Mdot
.67122 .49511 Mdot
.54154 .33898 Mdot
.53728 .6464 Mdot
.49609 .58338 Mdot
.66083 .45063 Mdot
.32178 .50169 Mdot
.49762 .63807 Mdot
.53636 .67542 Mdot
.45273 .34551 Mdot
.72357 .38394 Mdot
.32037 .50693 Mdot
.49815 .66852 Mdot
.49442 .50534 Mdot
.32533 .5001 Mdot
.51414 .67697 Mdot
.50265 .61841 Mdot
.58723 .62014 Mdot
.52222 .29346 Mdot
.34654 .47668 Mdot
.15815 .43127 Mdot
.69116 .43521 Mdot
.60263 .36618 Mdot
.47703 .52277 Mdot
.56456 .33082 Mdot
.41349 .66619 Mdot
.47808 .51138 Mdot
.68595 .35267 Mdot
.83113 .66018 Mdot
.47402 .51112 Mdot
.38634 .36586 Mdot
.68633 .72094 Mdot
.50218 .62066 Mdot
.51353 .66861 Mdot
.31502 .44184 Mdot
.69763 .4546 Mdot
.76799 .41443 Mdot
.56693 .3117 Mdot
.52153 .63031 Mdot
.71485 .4439 Mdot
.6239 .25012 Mdot
.484 .51939 Mdot
.30839 .4623 Mdot
.34293 .47987 Mdot
.50752 .66572 Mdot
.33697 .71113 Mdot
.67389 .45763 Mdot
.51435 .65214 Mdot
.53338 .68566 Mdot
.3758 .37997 Mdot
.7041 .47772 Mdot
.38045 .3376 Mdot
.49555 .55687 Mdot
.7175 .72047 Mdot
.49675 .2674 Mdot
.55039 .31019 Mdot
.48069 .50215 Mdot
.56976 .30931 Mdot
.32578 .28752 Mdot
.4699 .49607 Mdot
.51524 .6507 Mdot
.645 .47896 Mdot
.51382 .65366 Mdot
.51195 .65795 Mdot
.52463 .66733 Mdot
.763 .63852 Mdot
.39993 .40363 Mdot
.30699 .47103 Mdot
.51785 .69729 Mdot
.37208 .3233 Mdot
.56127 .24461 Mdot
.62923 .75012 Mdot
.52556 .64231 Mdot
.53688 .67978 Mdot
.67552 .41922 Mdot
.4882 .67852 Mdot
.54477 .30852 Mdot
.65817 .45621 Mdot
.49053 .65786 Mdot
.43674 .36829 Mdot
.49917 .65411 Mdot
.75331 .44748 Mdot
.52011 .32044 Mdot
.47882 .68228 Mdot
.52718 .57215 Mdot
.47044 .49486 Mdot
.47557 .51489 Mdot
.45818 .48533 Mdot
.51702 .32421 Mdot
.38531 .36529 Mdot
.36718 .27982 Mdot
.53901 .58885 Mdot
.50738 .67875 Mdot
.49393 .58361 Mdot
.39657 .34541 Mdot
.43083 .47576 Mdot
.7888 .60511 Mdot
.48117 .64469 Mdot
.35524 .31078 Mdot
.45062 .47815 Mdot
.61657 .54278 Mdot
.65748 .466 Mdot
.32801 .3251 Mdot
.55296 .28974 Mdot
.3265 .45406 Mdot
.23559 .58855 Mdot
.68095 .44131 Mdot
.64796 .4332 Mdot
.37621 .35789 Mdot
.32985 .65786 Mdot
.81467 .31927 Mdot
.35949 .35692 Mdot
.41336 .60872 Mdot
.68483 .4694 Mdot
.51731 .54144 Mdot
.31749 .68573 Mdot
.33602 .64795 Mdot
.34914 .30429 Mdot
.54736 .6288 Mdot
.27058 .28972 Mdot
.36421 .37109 Mdot
.49932 .51997 Mdot
.35696 .32408 Mdot
.53515 .34899 Mdot
.36463 .35096 Mdot
.7253 .45567 Mdot
.53055 .61956 Mdot
.81646 .33016 Mdot
.33151 .60749 Mdot
.52572 .62321 Mdot
.5262 .33741 Mdot
.55692 .37724 Mdot
.53861 .65601 Mdot
.30327 .45978 Mdot
.38706 .3634 Mdot
.31339 .33992 Mdot
.501 .60747 Mdot
.347 .35362 Mdot
.65998 .42171 Mdot
.33497 .36964 Mdot
.43831 .37776 Mdot
.47031 .50592 Mdot
.68691 .47646 Mdot
.59362 .34598 Mdot
.56146 .33831 Mdot
.51369 .567 Mdot
.53237 .69068 Mdot
.68134 .48117 Mdot
.42139 .61189 Mdot
.57133 .67044 Mdot
.51186 .65376 Mdot
.37892 .34349 Mdot
.33228 .31732 Mdot
.35947 .62926 Mdot
.36621 .33198 Mdot
.49673 .5158 Mdot
.67636 .47669 Mdot
.50585 .6043 Mdot
.69628 .44195 Mdot
.50556 .63834 Mdot
.5632 .25322 Mdot
.66489 .48162 Mdot
.59006 .64942 Mdot
.55249 .63372 Mdot
.8081 .49567 Mdot
.52051 .70051 Mdot
.51179 .66269 Mdot
.33586 .34344 Mdot
.33674 .47514 Mdot
.57358 .63914 Mdot
.57309 .25999 Mdot
.33282 .45384 Mdot
.63247 .56054 Mdot
.35555 .38151 Mdot
.34297 .46253 Mdot
.21968 .55212 Mdot
.46867 .4911 Mdot
.3274 .49232 Mdot
.49069 .58165 Mdot
.55215 .3123 Mdot
.65229 .49144 Mdot
.55431 .65314 Mdot
.70907 .72525 Mdot
.43155 .54232 Mdot
.48718 .52096 Mdot
.51599 .67546 Mdot
.538 .63629 Mdot
.71439 .44381 Mdot
.53991 .17663 Mdot
.3403 .28356 Mdot
.51177 .54523 Mdot
.68656 .43878 Mdot
.55509 .18742 Mdot
.35108 .29889 Mdot
.32738 .43625 Mdot
.56683 .29275 Mdot
.72318 .49191 Mdot
.49201 .52682 Mdot
.54743 .32494 Mdot
.3819 .29905 Mdot
.26894 .56462 Mdot
.51007 .60541 Mdot
.38295 .36087 Mdot
.26889 .57525 Mdot
.52221 .7235 Mdot
.58633 .28818 Mdot
.54033 .37806 Mdot
.68735 .48608 Mdot
.55003 .33043 Mdot
.3046 .47337 Mdot
.65577 .43989 Mdot
.65914 .46133 Mdot
.54499 .30264 Mdot
.82815 .53661 Mdot
.3226 .69453 Mdot
.55732 .27523 Mdot
.35507 .67022 Mdot
.26972 .57262 Mdot
.49116 .52841 Mdot
.30902 .46837 Mdot
.37719 .41289 Mdot
.67638 .45114 Mdot
.75589 .37247 Mdot
.26826 .57717 Mdot
.51465 .71408 Mdot
.32925 .45787 Mdot
.62627 .25595 Mdot
.57536 .33936 Mdot
.54692 .31506 Mdot
.45416 .34303 Mdot
.33596 .46252 Mdot
.55746 .63716 Mdot
.20592 .65234 Mdot
.54536 .67677 Mdot
.54909 .3037 Mdot
.4047 .64602 Mdot
.70789 .46167 Mdot
.52123 .33761 Mdot
.40429 .64426 Mdot
.49838 .67162 Mdot
.53818 .62899 Mdot
.40738 .39957 Mdot
.68273 .49019 Mdot
.49687 .55156 Mdot
.52203 .62296 Mdot
.54254 .66777 Mdot
.51869 .5628 Mdot
.31395 .72626 Mdot
.56401 .48983 Mdot
.51963 .55201 Mdot
.36858 .31117 Mdot
.5063 .55561 Mdot
.51135 .54352 Mdot
.70039 .42457 Mdot
.42526 .39467 Mdot
.49195 .54595 Mdot
.519 .6725 Mdot
.51502 .66741 Mdot
.56507 .2888 Mdot
.32142 .69401 Mdot
.32997 .6521 Mdot
.35767 .28674 Mdot
.28764 .45258 Mdot
.54137 .61668 Mdot
.69213 .47869 Mdot
.34368 .49715 Mdot
.48971 .50589 Mdot
.68111 .4344 Mdot
.52335 .61627 Mdot
.37832 .37922 Mdot
.47179 .50481 Mdot
.48835 .49573 Mdot
.3256 .4614 Mdot
.57136 .31075 Mdot
.63005 .54801 Mdot
.37003 .37321 Mdot
.48998 .67499 Mdot
.28121 .46674 Mdot
.3473 .34713 Mdot
.49013 .52892 Mdot
.50828 .55469 Mdot
.67897 .47201 Mdot
.6837 .49525 Mdot
.39131 .4941 Mdot
.36312 .31931 Mdot
.36451 .25443 Mdot
.54933 .34184 Mdot
.52095 .69553 Mdot
.56866 .33337 Mdot
.70573 .48252 Mdot
.29029 .6826 Mdot
.34378 .47288 Mdot
.54669 .30913 Mdot
.50019 .55259 Mdot
.65842 .4721 Mdot
.70541 .48426 Mdot
.51614 .66204 Mdot
.51923 .64427 Mdot
.32404 .32078 Mdot
.27314 .61683 Mdot
.55504 .28085 Mdot
.32466 .4407 Mdot
.35481 .28705 Mdot
.49333 .62089 Mdot
.7018 .4721 Mdot
.28141 .72381 Mdot
.52387 .69692 Mdot
.36978 .32283 Mdot
.68653 .45687 Mdot
.31464 .44373 Mdot
.30679 .47748 Mdot
.51382 .62963 Mdot
.59228 .61728 Mdot
.53988 .30174 Mdot
.66966 .46658 Mdot
.64548 .503 Mdot
.51377 .6966 Mdot
.52302 .64522 Mdot
.52276 .72478 Mdot
.55521 .27145 Mdot
.52526 .59048 Mdot
.31895 .49996 Mdot
.71447 .4576 Mdot
.51776 .62846 Mdot
.3358 .46632 Mdot
.45836 .49517 Mdot
.47552 .50721 Mdot
.3388 .30925 Mdot
.30227 .46032 Mdot
.33191 .47385 Mdot
.3317 .45001 Mdot
.75836 .3692 Mdot
.48952 .5757 Mdot
.34623 .51612 Mdot
.54819 .62845 Mdot
.27011 .57142 Mdot
.51749 .59778 Mdot
.53766 .34531 Mdot
.33774 .32648 Mdot
.52941 .66238 Mdot
.54946 .63038 Mdot
.62301 .53828 Mdot
.50744 .60072 Mdot
.54765 .60997 Mdot
.70923 .46281 Mdot
.63492 .49591 Mdot
.35589 .37493 Mdot
.5653 .19748 Mdot
.24563 .72291 Mdot
.56097 .63149 Mdot
.33289 .65645 Mdot
.66153 .47466 Mdot
.56615 .29127 Mdot
.34462 .67471 Mdot
.56972 .3365 Mdot
.69409 .44726 Mdot
.49627 .60961 Mdot
.65205 .53354 Mdot
.33295 .45653 Mdot
.53582 .64951 Mdot
.53242 .30149 Mdot
.53586 .65115 Mdot
.52145 .33475 Mdot
.80421 .57721 Mdot
.31243 .64511 Mdot
.54775 .67657 Mdot
.51413 .61141 Mdot
.57946 .56819 Mdot
.52291 .64284 Mdot
.31491 .26448 Mdot
.68761 .46154 Mdot
.54104 .58437 Mdot
.49387 .61232 Mdot
.73851 .62629 Mdot
.52518 .68428 Mdot
.42511 .67786 Mdot
.54852 .66265 Mdot
.1943 .58074 Mdot
.55466 .66487 Mdot
.53644 .68812 Mdot
.52558 .322 Mdot
.56508 .30739 Mdot
.63507 .4338 Mdot
.49259 .5439 Mdot
.62075 .25094 Mdot
.53586 .6775 Mdot
.3412 .28924 Mdot
.5952 .67509 Mdot
.33459 .47336 Mdot
.71238 .4528 Mdot
.87996 .60356 Mdot
.5184 .33953 Mdot
.38173 .32812 Mdot
.42603 .56846 Mdot
.37571 .31864 Mdot
.3276 .30225 Mdot
.67647 .51491 Mdot
.30937 .46642 Mdot
.50007 .65306 Mdot
.73457 .60507 Mdot
.72134 .37756 Mdot
.51264 .69546 Mdot
.40099 .34558 Mdot
.58609 .62442 Mdot
.38283 .52481 Mdot
.3274 .42996 Mdot
.31879 .47658 Mdot
.53984 .3267 Mdot
.34623 .28981 Mdot
.50994 .54647 Mdot
.34345 .46352 Mdot
.35314 .36931 Mdot
.47531 .49521 Mdot
.4161 .40206 Mdot
.67281 .45844 Mdot
.80253 .59568 Mdot
.78323 .52159 Mdot
.54813 .34918 Mdot
.57478 .26036 Mdot
.64675 .48491 Mdot
.67513 .43279 Mdot
.49097 .53849 Mdot
.3518 .31102 Mdot
.65934 .49567 Mdot
.51722 .6266 Mdot
.50488 .55442 Mdot
.50557 .6634 Mdot
.32886 .43275 Mdot
.52197 .68044 Mdot
.35151 .36461 Mdot
.52401 .32262 Mdot
.35068 .33585 Mdot
.54311 .32771 Mdot
.33954 .76225 Mdot
.55363 .63158 Mdot
.52229 .64815 Mdot
.34126 .65171 Mdot
.71101 .47535 Mdot
.72453 .62183 Mdot
.365 .32163 Mdot
.35248 .3294 Mdot
.49569 .60855 Mdot
.65026 .45079 Mdot
.29783 .4953 Mdot
.36044 .66087 Mdot
.54678 .66715 Mdot
.6894 .46138 Mdot
.50055 .5987 Mdot
.61285 .30825 Mdot
.32849 .62438 Mdot
.71692 .46792 Mdot
.17245 .39757 Mdot
.5554 .64018 Mdot
.5086 .52628 Mdot
.5808 .62702 Mdot
.34555 .72936 Mdot
.57375 .6616 Mdot
.68734 .4353 Mdot
.51099 .54945 Mdot
.69723 .47417 Mdot
.35082 .35054 Mdot
.52135 .33927 Mdot
.69568 .46978 Mdot
.55258 .64926 Mdot
.24565 .72183 Mdot
.52305 .31215 Mdot
.53272 .65181 Mdot
.53211 .29855 Mdot
.69167 .50314 Mdot
.70394 .45687 Mdot
.47588 .49562 Mdot
.41399 .60617 Mdot
.54379 .30416 Mdot
.51003 .6817 Mdot
.74995 .38435 Mdot
.51004 .60438 Mdot
.29528 .4442 Mdot
.53026 .61015 Mdot
.52303 .61541 Mdot
.15255 .4807 Mdot
.4158 .63141 Mdot
.51107 .25363 Mdot
.52 .26629 Mdot
.7662 .39134 Mdot
.70837 .4309 Mdot
.32276 .43241 Mdot
.61747 .51258 Mdot
.46617 .49367 Mdot
.36657 .30848 Mdot
.52522 .66356 Mdot
.4549 .48628 Mdot
.55053 .27624 Mdot
.32727 .4901 Mdot
.54092 .68827 Mdot
.38941 .32987 Mdot
.47432 .48719 Mdot
.54716 .3208 Mdot
.6766 .44967 Mdot
.70682 .45102 Mdot
.39606 .41271 Mdot
.51931 .62722 Mdot
.51722 .64692 Mdot
.53009 .29626 Mdot
.58511 .65581 Mdot
.32636 .44678 Mdot
.44166 .47529 Mdot
.53598 .29586 Mdot
.32621 .62501 Mdot
.68393 .49064 Mdot
.53546 .63457 Mdot
.34679 .64788 Mdot
.76834 .40606 Mdot
.64258 .71341 Mdot
.32135 .47206 Mdot
.3539 .70914 Mdot
.68767 .43547 Mdot
.52895 .31474 Mdot
.22094 .53969 Mdot
.51788 .72302 Mdot
.54334 .64245 Mdot
.35833 .71522 Mdot
.36039 .66273 Mdot
.42608 .5713 Mdot
.50093 .55465 Mdot
.31866 .67785 Mdot
.49739 .60476 Mdot
.48768 .65329 Mdot
.54423 .61872 Mdot
.52806 .60948 Mdot
.69626 .46293 Mdot
.74165 .64315 Mdot
.37238 .35538 Mdot
.63967 .69154 Mdot
.31212 .42586 Mdot
.51273 .71003 Mdot
.49305 .65803 Mdot
.64518 .62524 Mdot
.38122 .69655 Mdot
.68067 .46315 Mdot
.71745 .43658 Mdot
.55438 .34661 Mdot
.51168 .60215 Mdot
.36689 .32117 Mdot
.56561 .60771 Mdot
.33999 .32166 Mdot
.69475 .46131 Mdot
.36875 .38294 Mdot
.52762 .35472 Mdot
.38347 .36 Mdot
.3593 .30958 Mdot
.52501 .33032 Mdot
.66924 .48704 Mdot
.52278 .70136 Mdot
.52508 .33138 Mdot
.30948 .50493 Mdot
.32493 .43459 Mdot
.63043 .45885 Mdot
.51872 .54565 Mdot
.55044 .6909 Mdot
.38349 .25106 Mdot
.38646 .34925 Mdot
.38041 .66651 Mdot
.67018 .48555 Mdot
.34908 .47685 Mdot
.69928 .46834 Mdot
.37626 .50348 Mdot
.32429 .46911 Mdot
.48881 .5837 Mdot
.24612 .62643 Mdot
.52301 .36801 Mdot
.53349 .70664 Mdot
.63564 .49599 Mdot
.34097 .3223 Mdot
.52434 .33672 Mdot
.58501 .24231 Mdot
.5124 .54547 Mdot
.64855 .42563 Mdot
.71489 .49226 Mdot
.46747 .49467 Mdot
.5296 .31149 Mdot
.79171 .50918 Mdot
.52441 .62478 Mdot
.56486 .33952 Mdot
.53066 .61067 Mdot
.78134 .62673 Mdot
.30635 .41475 Mdot
.45205 .48428 Mdot
.49428 .61403 Mdot
.35197 .29909 Mdot
.49573 .60922 Mdot
.72773 .6983 Mdot
.27443 .65219 Mdot
.55037 .62283 Mdot
.37392 .69692 Mdot
.32648 .28211 Mdot
.70058 .47501 Mdot
.49579 .52268 Mdot
.4895 .5256 Mdot
.48518 .65513 Mdot
.3502 .8245 Mdot
.33743 .47999 Mdot
.4222 .34548 Mdot
.55261 .64422 Mdot
.51188 .6463 Mdot
.62663 .54898 Mdot
.80214 .57792 Mdot
.46901 .48261 Mdot
.54423 .64826 Mdot
.37547 .72223 Mdot
.52992 .32828 Mdot
.50779 .61105 Mdot
.50596 .65789 Mdot
.329 .36324 Mdot
.52637 .31957 Mdot
.37124 .37764 Mdot
.46774 .49137 Mdot
.33399 .32571 Mdot
.32254 .50317 Mdot
.36086 .70164 Mdot
.30174 .70434 Mdot
.33653 .62464 Mdot
.30135 .46814 Mdot
.49919 .69985 Mdot
.47656 .5434 Mdot
.54059 .62601 Mdot
.31938 .48006 Mdot
.54508 .28685 Mdot
.69055 .46372 Mdot
.79397 .61314 Mdot
.48842 .52695 Mdot
.50295 .69638 Mdot
.33929 .43244 Mdot
.69149 .47264 Mdot
.82187 .4799 Mdot
.69743 .4563 Mdot
.54417 .31798 Mdot
.5845 .28234 Mdot
.32896 .46749 Mdot
.69975 .4686 Mdot
.3353 .33692 Mdot
.5889 .30813 Mdot
.50788 .72059 Mdot
.52643 .35373 Mdot
.71144 .48817 Mdot
.72028 .46304 Mdot
.6435 .46451 Mdot
.48997 .62703 Mdot
.37698 .68659 Mdot
.4839 .50448 Mdot
.52537 .30359 Mdot
.37927 .31531 Mdot
.2733 .62501 Mdot
.74072 .54704 Mdot
.32195 .63827 Mdot
.49122 .58492 Mdot
.52098 .6793 Mdot
.50906 .66751 Mdot
.5208 .56277 Mdot
.46044 .53375 Mdot
.55054 .62713 Mdot
.55435 .28148 Mdot
.35533 .36356 Mdot
.54859 .6557 Mdot
.47694 .50447 Mdot
.43074 .4867 Mdot
.34609 .48262 Mdot
.76951 .63781 Mdot
.62914 .45937 Mdot
.69202 .47099 Mdot
.3765 .33141 Mdot
.35791 .38581 Mdot
.34436 .4584 Mdot
.5432 .33457 Mdot
.6975 .45324 Mdot
.19361 .57101 Mdot
.32865 .45146 Mdot
.5208 .67343 Mdot
.34249 .65092 Mdot
.37092 .73282 Mdot
.4983 .6308 Mdot
.52537 .66842 Mdot
.49082 .54349 Mdot
.36807 .31959 Mdot
.62876 .76105 Mdot
.81551 .48715 Mdot
.33428 .46854 Mdot
.33436 .44443 Mdot
.64486 .45443 Mdot
.52168 .69104 Mdot
.53878 .3003 Mdot
.32447 .69934 Mdot
.57173 .37743 Mdot
.64577 .26445 Mdot
.33197 .27228 Mdot
.4994 .65676 Mdot
.71051 .68655 Mdot
.56125 .66874 Mdot
.68479 .50487 Mdot
.66598 .49248 Mdot
.67709 .46398 Mdot
.53228 .33058 Mdot
.27133 .56085 Mdot
.56282 .31788 Mdot
.45022 .47771 Mdot
.6721 .44322 Mdot
.42013 .60416 Mdot
.35373 .32783 Mdot
.51383 .59875 Mdot
.31082 .47112 Mdot
.26973 .49712 Mdot
.49911 .52983 Mdot
.35616 .70654 Mdot
.37571 .37172 Mdot
.65456 .46725 Mdot
.51122 .59782 Mdot
.5568 .24535 Mdot
.31472 .65725 Mdot
.32011 .27549 Mdot
.45431 .48662 Mdot
.33343 .46234 Mdot
.60469 .75451 Mdot
.32064 .45014 Mdot
.54687 .30768 Mdot
.55299 .63285 Mdot
.52466 .69086 Mdot
.51089 .66234 Mdot
.5532 .62001 Mdot
.53436 .32688 Mdot
.52754 .70991 Mdot
.39608 .49041 Mdot
.46256 .48662 Mdot
.44406 .52416 Mdot
.31058 .48611 Mdot
.54623 .34344 Mdot
.34969 .35405 Mdot
.48253 .53184 Mdot
.34896 .46569 Mdot
.51202 .59189 Mdot
.54956 .63836 Mdot
.4634 .48224 Mdot
.49257 .5806 Mdot
.55486 .68603 Mdot
.371 .36375 Mdot
.43631 .53811 Mdot
.3433 .48605 Mdot
.31559 .46492 Mdot
.55259 .32439 Mdot
.69951 .46936 Mdot
.34596 .47386 Mdot
.37796 .30428 Mdot
.50769 .6098 Mdot
.53397 .61137 Mdot
.71613 .48157 Mdot
.26787 .57257 Mdot
.34603 .48325 Mdot
.5298 .59337 Mdot
.71584 .46505 Mdot
.71513 .49279 Mdot
.54319 .64634 Mdot
.52266 .7124 Mdot
.69844 .42455 Mdot
.33603 .44311 Mdot
.55286 .33084 Mdot
.31486 .6098 Mdot
.53084 .34936 Mdot
.67357 .45047 Mdot
.50534 .54993 Mdot
.66055 .48092 Mdot
.51259 .54648 Mdot
.70548 .26699 Mdot
.54932 .62528 Mdot
.74624 .49463 Mdot
.42456 .47699 Mdot
.35455 .32447 Mdot
.35036 .31821 Mdot
.47091 .50057 Mdot
.67317 .43637 Mdot
.49559 .51517 Mdot
.31065 .45731 Mdot
.76477 .39056 Mdot
.70005 .42417 Mdot
.35737 .30945 Mdot
.38836 .34522 Mdot
.5345 .29618 Mdot
.52245 .68192 Mdot
.53514 .6334 Mdot
.3825 .36314 Mdot
.58869 .37288 Mdot
.68082 .48537 Mdot
.51734 .64752 Mdot
.51937 .55514 Mdot
.37037 .35919 Mdot
.4985 .35016 Mdot
.65363 .49127 Mdot
.49026 .62363 Mdot
.27817 .66177 Mdot
.51929 .33347 Mdot
.49449 .67672 Mdot
.53175 .70891 Mdot
.33301 .47983 Mdot
.35341 .71238 Mdot
.27001 .58002 Mdot
.51923 .34243 Mdot
.47321 .49648 Mdot
.49641 .63724 Mdot
.35048 .32373 Mdot
.52757 .59725 Mdot
.71163 .76885 Mdot
.46467 .4853 Mdot
.52093 .62845 Mdot
.57121 .61567 Mdot
.69643 .44173 Mdot
.5137 .64786 Mdot
.56358 .25436 Mdot
.37513 .33744 Mdot
.52288 .62695 Mdot
.58822 .58379 Mdot
.53292 .29849 Mdot
.49817 .52854 Mdot
.33462 .45999 Mdot
.42045 .59022 Mdot
.36279 .78151 Mdot
.3963 .34596 Mdot
.31164 .49065 Mdot
.52862 .68367 Mdot
.34987 .28575 Mdot
.5656 .31223 Mdot
.48764 .512 Mdot
.49388 .68092 Mdot
.55396 .34373 Mdot
.5291 .33204 Mdot
.32872 .46369 Mdot
.8486 .4145 Mdot
.56078 .63744 Mdot
.53187 .64469 Mdot
.83964 .44995 Mdot
.73875 .45794 Mdot
.53392 .6529 Mdot
.53231 .68746 Mdot
.5501 .32151 Mdot
.26763 .55019 Mdot
.35563 .70802 Mdot
.44304 .48538 Mdot
.52771 .34091 Mdot
.36387 .28401 Mdot
.38175 .34741 Mdot
.31558 .49456 Mdot
.68646 .45601 Mdot
.34531 .45684 Mdot
.36754 .3494 Mdot
.51773 .66726 Mdot
.55729 .31471 Mdot
.56351 .76627 Mdot
.51992 .32543 Mdot
.3889 .32132 Mdot
.68741 .50446 Mdot
.67592 .74616 Mdot
.73219 .75688 Mdot
.55876 .4812 Mdot
.58799 .29124 Mdot
.3347 .47395 Mdot
.81647 .48596 Mdot
.54831 .65991 Mdot
.72732 .69245 Mdot
.53478 .64748 Mdot
.45601 .47436 Mdot
.34074 .3399 Mdot
.47551 .49538 Mdot
.51273 .54444 Mdot
.36063 .70617 Mdot
.53249 .33589 Mdot
.54706 .28947 Mdot
.51071 .55307 Mdot
.54401 .31277 Mdot
.52603 .6309 Mdot
.36248 .36463 Mdot
.76047 .31727 Mdot
.54986 .65928 Mdot
.53728 .58093 Mdot
.55316 .35822 Mdot
.74694 .41203 Mdot
.37441 .29218 Mdot
.72233 .6633 Mdot
.61043 .24411 Mdot
.53773 .30284 Mdot
.76486 .63983 Mdot
.37357 .32816 Mdot
.48303 .53278 Mdot
.342 .28496 Mdot
.53345 .6401 Mdot
.49934 .65853 Mdot
.52017 .567 Mdot
.53344 .68361 Mdot
.68602 .70398 Mdot
.54052 .70476 Mdot
.62025 .60968 Mdot
.54726 .6274 Mdot
.67157 .52284 Mdot
.56348 .29667 Mdot
.50878 .55296 Mdot
.33673 .5848 Mdot
.52814 .61716 Mdot
.70659 .43151 Mdot
.5432 .34717 Mdot
.59363 .22872 Mdot
.53162 .32721 Mdot
.34955 .33397 Mdot
.53906 .33493 Mdot
.5251 .70766 Mdot
.68947 .44419 Mdot
.36302 .33878 Mdot
.49628 .53005 Mdot
.37138 .30809 Mdot
.52541 .62332 Mdot
.47702 .3284 Mdot
.38215 .3308 Mdot
.52057 .72264 Mdot
.69351 .44464 Mdot
.263 .68681 Mdot
.64382 .48543 Mdot
.52017 .65765 Mdot
.52697 .65718 Mdot
.46446 .48022 Mdot
.54443 .33084 Mdot
.66266 .48437 Mdot
.4555 .3391 Mdot
.34932 .47656 Mdot
.68086 .45883 Mdot
.58664 .64092 Mdot
.32979 .65959 Mdot
.71416 .45003 Mdot
.37425 .72765 Mdot
.54835 .30634 Mdot
.69582 .43755 Mdot
.58263 .69056 Mdot
.63674 .69289 Mdot
.31598 .45861 Mdot
.33485 .33768 Mdot
.33561 .67011 Mdot
.38087 .34297 Mdot
.55987 .25084 Mdot
.33432 .34182 Mdot
.52617 .30887 Mdot
.5904 .63503 Mdot
.40501 .64454 Mdot
.52708 .29339 Mdot
.47417 .3153 Mdot
.37523 .34947 Mdot
.51661 .54916 Mdot
.44064 .53033 Mdot
.49227 .49998 Mdot
.50458 .51885 Mdot
.51741 .33704 Mdot
.69459 .43638 Mdot
.6552 .44193 Mdot
.56417 .60389 Mdot
.70993 .4578 Mdot
.35836 .35167 Mdot
.34604 .62523 Mdot
.76617 .6153 Mdot
.55767 .28705 Mdot
.43334 .5453 Mdot
.49197 .65507 Mdot
.34791 .35666 Mdot
.35564 .35098 Mdot
.53183 .33312 Mdot
.66064 .67461 Mdot
.49586 .50912 Mdot
.73175 .48874 Mdot
.67958 .44092 Mdot
.69718 .4412 Mdot
.69879 .48554 Mdot
.26925 .56145 Mdot
.52709 .33885 Mdot
.67542 .43654 Mdot
.55141 .61747 Mdot
.52364 .68691 Mdot
.47847 .5214 Mdot
.329 .43398 Mdot
.53762 .70612 Mdot
.49512 .51391 Mdot
.54234 .6438 Mdot
.35799 .32369 Mdot
.59725 .66884 Mdot
.46291 .49251 Mdot
.3661 .31992 Mdot
.36009 .31979 Mdot
.47049 .49443 Mdot
.59596 .66885 Mdot
.64355 .73621 Mdot
.48451 .66661 Mdot
.69062 .51278 Mdot
.34877 .31489 Mdot
.44895 .36521 Mdot
.73988 .50038 Mdot
.5127 .68268 Mdot
.43689 .47598 Mdot
.35825 .36138 Mdot
.71179 .43173 Mdot
.52697 .64038 Mdot
.49338 .54078 Mdot
.32145 .45437 Mdot
.49389 .52407 Mdot
.49168 .54424 Mdot
.69496 .48127 Mdot
.37676 .2561 Mdot
.71539 .44468 Mdot
.35473 .38773 Mdot
.50182 .53793 Mdot
.81521 .32392 Mdot
.34189 .3257 Mdot
.76286 .38443 Mdot
.40557 .63916 Mdot
.54395 .6344 Mdot
.37711 .33413 Mdot
.66768 .41923 Mdot
.51557 .32285 Mdot
.38373 .68477 Mdot
.70213 .46783 Mdot
.47851 .52652 Mdot
.47921 .51933 Mdot
.37214 .35697 Mdot
.66576 .45604 Mdot
.52942 .70984 Mdot
.70473 .44942 Mdot
.55902 .30542 Mdot
.49221 .60129 Mdot
.61955 .25024 Mdot
.50846 .54678 Mdot
.71248 .45807 Mdot
.38144 .3156 Mdot
.32198 .50145 Mdot
.54867 .67116 Mdot
.60041 .23065 Mdot
.52798 .68436 Mdot
.53842 .29131 Mdot
.41945 .48855 Mdot
.59088 .73318 Mdot
.5327 .67182 Mdot
.49471 .66398 Mdot
.52492 .35963 Mdot
.53526 .66867 Mdot
.51059 .61812 Mdot
.79249 .51219 Mdot
.71638 .45497 Mdot
.54802 .65785 Mdot
.37513 .36738 Mdot
.60186 .59078 Mdot
.50997 .64213 Mdot
.57018 .25463 Mdot
.34257 .72264 Mdot
.41145 .48337 Mdot
.55196 .59096 Mdot
.28886 .6798 Mdot
.52907 .65269 Mdot
.51475 .68751 Mdot
.4928 .59867 Mdot
.71389 .68841 Mdot
.37093 .34595 Mdot
.35148 .29571 Mdot
.31703 .49832 Mdot
.36041 .71604 Mdot
.32029 .46306 Mdot
.56572 .31311 Mdot
.42282 .57773 Mdot
.4606 .48792 Mdot
.69914 .47123 Mdot
.50984 .65794 Mdot
.37202 .30529 Mdot
.53145 .63445 Mdot
.48674 .66076 Mdot
.36146 .3545 Mdot
.35384 .35431 Mdot
.36689 .39709 Mdot
.33671 .46022 Mdot
.68489 .46731 Mdot
.55643 .65406 Mdot
.33433 .4553 Mdot
.51958 .56369 Mdot
.30715 .61921 Mdot
.68195 .46602 Mdot
.71257 .46065 Mdot
.65793 .44766 Mdot
.53815 .68749 Mdot
.48918 .6085 Mdot
.56241 .32518 Mdot
.71624 .48158 Mdot
.54378 .29963 Mdot
.3784 .3354 Mdot
.36189 .37088 Mdot
.53421 .64071 Mdot
.5839 .64881 Mdot
.30835 .47957 Mdot
.38512 .3373 Mdot
.47032 .5177 Mdot
.33202 .49325 Mdot
.50271 .65887 Mdot
.38061 .33934 Mdot
.30692 .45298 Mdot
.65549 .68691 Mdot
.63586 .30114 Mdot
.32256 .4988 Mdot
.51259 .5377 Mdot
.7254 .55874 Mdot
.27399 .64369 Mdot
.3432 .49367 Mdot
.56287 .29596 Mdot
.52653 .69669 Mdot
.44816 .48828 Mdot
.3433 .483 Mdot
.26672 .59404 Mdot
.36328 .34871 Mdot
.50618 .52272 Mdot
.55848 .4988 Mdot
.76325 .61679 Mdot
.32407 .50157 Mdot
.71321 .45728 Mdot
.70149 .4912 Mdot
.52413 .67401 Mdot
.42039 .58722 Mdot
.54947 .279 Mdot
.35622 .38538 Mdot
.35693 .29609 Mdot
.67579 .49678 Mdot
.33321 .62409 Mdot
.37839 .36298 Mdot
.52045 .69407 Mdot
.32733 .42397 Mdot
.54534 .60853 Mdot
.38348 .5058 Mdot
.58252 .73685 Mdot
.57268 .6108 Mdot
.32275 .50072 Mdot
.54687 .281 Mdot
.52419 .32012 Mdot
.54037 .3297 Mdot
.37525 .36218 Mdot
.34198 .6749 Mdot
.35427 .29272 Mdot
.83616 .46377 Mdot
.33783 .48023 Mdot
.17178 .50112 Mdot
.56728 .6432 Mdot
.54158 .63098 Mdot
.5145 .60405 Mdot
.51598 .55716 Mdot
.52796 .65192 Mdot
.557 .34166 Mdot
.33515 .32728 Mdot
.53574 .38 Mdot
.67166 .47585 Mdot
.8227 .48239 Mdot
.3551 .3275 Mdot
.49408 .55014 Mdot
.30944 .47717 Mdot
.3021 .71083 Mdot
.29749 .46296 Mdot
.38222 .37089 Mdot
.50786 .62785 Mdot
.64523 .45033 Mdot
.1973 .59169 Mdot
.51162 .65229 Mdot
.38677 .34762 Mdot
.36581 .28936 Mdot
.64543 .68075 Mdot
.4549 .66927 Mdot
.56558 .38123 Mdot
.34592 .64405 Mdot
.30058 .48227 Mdot
.52057 .54468 Mdot
.32896 .70719 Mdot
.36871 .35044 Mdot
.34433 .30598 Mdot
.33102 .5106 Mdot
.7445 .40681 Mdot
.66813 .44124 Mdot
.64653 .49751 Mdot
.55585 .3393 Mdot
.54503 .63204 Mdot
.37821 .34743 Mdot
.66153 .50136 Mdot
.31472 .57468 Mdot
.53889 .32125 Mdot
.38253 .32934 Mdot
.52923 .68539 Mdot
.53224 .67392 Mdot
.32221 .46177 Mdot
.42691 .48475 Mdot
.49232 .50044 Mdot
.76378 .38909 Mdot
.3264 .64762 Mdot
.40523 .63814 Mdot
.5434 .64232 Mdot
.69901 .48395 Mdot
.47023 .49544 Mdot
.30864 .46797 Mdot
.52951 .59863 Mdot
.70883 .72252 Mdot
.72094 .44435 Mdot
.54297 .30132 Mdot
.4942 .53287 Mdot
.36551 .69937 Mdot
.53055 .68467 Mdot
.5346 .64685 Mdot
.49031 .62585 Mdot
.65959 .75334 Mdot
.33808 .32693 Mdot
.70652 .47513 Mdot
.33524 .46242 Mdot
.70262 .4561 Mdot
.35024 .38792 Mdot
.4338 .53889 Mdot
.54827 .67846 Mdot
.71479 .43779 Mdot
.69439 .44988 Mdot
.53968 .29094 Mdot
.52285 .32685 Mdot
.39577 .32645 Mdot
.53468 .68693 Mdot
.46008 .48448 Mdot
.68074 .43671 Mdot
.34139 .35901 Mdot
.32206 .46387 Mdot
.56713 .24925 Mdot
.55032 .63244 Mdot
.37231 .35242 Mdot
.49762 .52393 Mdot
.68066 .47751 Mdot
.36817 .32476 Mdot
.48385 .53435 Mdot
.33081 .43868 Mdot
.49671 .65138 Mdot
.31549 .28209 Mdot
.49472 .54449 Mdot
.54905 .66822 Mdot
.60718 .66901 Mdot
.4213 .58496 Mdot
.46519 .5105 Mdot
.35951 .37544 Mdot
.48781 .53305 Mdot
.69087 .49229 Mdot
.62771 .70587 Mdot
.34199 .30614 Mdot
.65359 .53209 Mdot
.4041 .65203 Mdot
.51146 .54837 Mdot
.70047 .47437 Mdot
.4117 .4053 Mdot
.72422 .39228 Mdot
.27581 .63849 Mdot
.51879 .63416 Mdot
.38082 .34354 Mdot
.31896 .45721 Mdot
.54714 .29002 Mdot
.56272 .2675 Mdot
.39286 .42238 Mdot
.35771 .31312 Mdot
.50929 .65731 Mdot
.6939 .43659 Mdot
.54318 .30531 Mdot
.63056 .55181 Mdot
.35458 .28827 Mdot
.37515 .36916 Mdot
.49599 .61704 Mdot
.31926 .46397 Mdot
.46802 .53734 Mdot
.33751 .31214 Mdot
.33428 .31183 Mdot
.78928 .51461 Mdot
.30026 .47946 Mdot
.4887 .63111 Mdot
.56749 .60718 Mdot
.51764 .60825 Mdot
.82779 .47197 Mdot
.48385 .53112 Mdot
.67153 .47676 Mdot
.53158 .65967 Mdot
.33928 .26146 Mdot
.34223 .3353 Mdot
.34582 .64376 Mdot
.51859 .36509 Mdot
.52845 .33506 Mdot
.37258 .33719 Mdot
.5224 .63765 Mdot
.57616 .26189 Mdot
.31772 .49421 Mdot
.49119 .61763 Mdot
.5118 .5512 Mdot
.68924 .49758 Mdot
.558 .31667 Mdot
.59867 .60051 Mdot
.55305 .2918 Mdot
.55045 .32766 Mdot
.70813 .4088 Mdot
.52328 .6741 Mdot
.35957 .32795 Mdot
.39115 .34014 Mdot
.52477 .56395 Mdot
.44427 .34919 Mdot
.65926 .45589 Mdot
.37049 .27335 Mdot
.69691 .73328 Mdot
.55026 .6201 Mdot
.49847 .55253 Mdot
.45252 .47707 Mdot
.58557 .28512 Mdot
.53073 .66951 Mdot
.69551 .47708 Mdot
.33534 .31585 Mdot
.38029 .352 Mdot
.51993 .72215 Mdot
.52391 .3216 Mdot
.31797 .43848 Mdot
.35594 .3476 Mdot
.31968 .60813 Mdot
.52002 .62837 Mdot
.56636 .34794 Mdot
.35621 .34427 Mdot
.25971 .72853 Mdot
.35112 .25323 Mdot
.70814 .44484 Mdot
.49679 .66522 Mdot
.65042 .48638 Mdot
.30926 .49167 Mdot
.33273 .29512 Mdot
.5388 .28906 Mdot
.49941 .53494 Mdot
.55355 .20666 Mdot
.37655 .35662 Mdot
.69391 .46192 Mdot
.52108 .66674 Mdot
.75834 .64495 Mdot
.54837 .66269 Mdot
.26716 .54804 Mdot
.34397 .4867 Mdot
.54761 .25571 Mdot
.52973 .29695 Mdot
.49777 .67015 Mdot
.32947 .44785 Mdot
.39289 .348 Mdot
.36242 .35454 Mdot
.58241 .21257 Mdot
.48836 .54024 Mdot
.32875 .29579 Mdot
.54606 .67423 Mdot
.35178 .38102 Mdot
.74176 .54626 Mdot
.52685 .33061 Mdot
.51486 .6103 Mdot
.37821 .32231 Mdot
.73037 .39691 Mdot
.33906 .65066 Mdot
.51852 .63163 Mdot
.57816 .62895 Mdot
.52694 .30906 Mdot
.81807 .48818 Mdot
.34238 .34667 Mdot
.51345 .58727 Mdot
.56325 .33789 Mdot
.59004 .6357 Mdot
.55066 .38587 Mdot
.68441 .46741 Mdot
.3891 .34111 Mdot
.55387 .33028 Mdot
.50756 .53717 Mdot
.30933 .45106 Mdot
.37768 .30319 Mdot
.3728 .31304 Mdot
.49391 .69032 Mdot
.51437 .56783 Mdot
.5845 .6449 Mdot
.67022 .48301 Mdot
.55088 .31498 Mdot
.48632 .6541 Mdot
.3036 .62009 Mdot
.50092 .58981 Mdot
.5529 .31564 Mdot
.82472 .36149 Mdot
.50439 .63162 Mdot
.54879 .63142 Mdot
.75095 .65838 Mdot
.6536 .47091 Mdot
.71168 .47929 Mdot
.31762 .64432 Mdot
.51026 .70598 Mdot
.41917 .60989 Mdot
.68856 .46708 Mdot
.69477 .45891 Mdot
.41948 .60804 Mdot
.49145 .68364 Mdot
.64079 .48586 Mdot
.54353 .30759 Mdot
.52706 .33398 Mdot
.69746 .44199 Mdot
.51938 .60057 Mdot
.56655 .29368 Mdot
.66854 .66122 Mdot
.38798 .35677 Mdot
.33631 .70939 Mdot
.6987 .44858 Mdot
.34165 .65407 Mdot
.5474 .30838 Mdot
.33582 .75081 Mdot
.34697 .73045 Mdot
.56017 .63204 Mdot
.52772 .67347 Mdot
.33202 .4769 Mdot
.49657 .52709 Mdot
.46865 .49352 Mdot
.54068 .3303 Mdot
.46005 .53375 Mdot
.67635 .46302 Mdot
.51608 .70549 Mdot
.27299 .62097 Mdot
.37945 .78709 Mdot
.52164 .75101 Mdot
.6883 .45606 Mdot
.67671 .45229 Mdot
.36942 .37607 Mdot
.37022 .38397 Mdot
.55543 .66112 Mdot
.52456 .31424 Mdot
.70023 .44017 Mdot
.55457 .31034 Mdot
.36753 .35073 Mdot
.35446 .33024 Mdot
.46523 .49859 Mdot
.50343 .51901 Mdot
.36809 .3401 Mdot
.57159 .25644 Mdot
.30416 .62014 Mdot
.70626 .4935 Mdot
.84027 .45716 Mdot
.32441 .74412 Mdot
.78534 .62341 Mdot
.32017 .45543 Mdot
.59561 .67245 Mdot
.56179 .33868 Mdot
.49746 .67085 Mdot
.53839 .65044 Mdot
.48356 .51865 Mdot
.56107 .34264 Mdot
.32276 .48827 Mdot
.52778 .33318 Mdot
.31356 .4479 Mdot
.35386 .29846 Mdot
.50954 .65077 Mdot
.5182 .62158 Mdot
.54441 .29064 Mdot
.37384 .37601 Mdot
.37953 .32818 Mdot
.31349 .45822 Mdot
.30655 .71422 Mdot
.37131 .35598 Mdot
.69823 .44936 Mdot
.66493 .54136 Mdot
.4804 .52012 Mdot
.52612 .64077 Mdot
.28986 .68337 Mdot
.62212 .71111 Mdot
.52098 .56667 Mdot
.49317 .53197 Mdot
.84767 .41108 Mdot
.51528 .62837 Mdot
.55248 .18681 Mdot
.46206 .49337 Mdot
.65974 .48018 Mdot
.365 .32909 Mdot
.49459 .54881 Mdot
.58305 .61617 Mdot
.30085 .42001 Mdot
.522 .57083 Mdot
.66872 .4402 Mdot
.65432 .45607 Mdot
.43496 .53942 Mdot
.83062 .47615 Mdot
.33409 .46067 Mdot
.32447 .49212 Mdot
.33905 .31967 Mdot
.55717 .24912 Mdot
.56507 .6304 Mdot
.33097 .48826 Mdot
.6348 .45156 Mdot
.49076 .63105 Mdot
.42438 .5774 Mdot
.44225 .52647 Mdot
.69961 .48861 Mdot
.48433 .67961 Mdot
.33988 .32522 Mdot
.69187 .46202 Mdot
.43857 .53449 Mdot
.5029 .61212 Mdot
.67961 .46519 Mdot
.54853 .32646 Mdot
.43672 .6823 Mdot
.70666 .45162 Mdot
.3846 .68051 Mdot
.53616 .30108 Mdot
.42805 .56583 Mdot
.19864 .51155 Mdot
.29387 .77341 Mdot
.52733 .32741 Mdot
.3838 .33641 Mdot
.37731 .34696 Mdot
.36795 .36238 Mdot
.68546 .48687 Mdot
.34858 .34707 Mdot
.66285 .46455 Mdot
.5888 .29539 Mdot
.36053 .71108 Mdot
.3269 .4686 Mdot
.42609 .38292 Mdot
.69937 .44357 Mdot
.83322 .46608 Mdot
.84026 .65095 Mdot
.50439 .58316 Mdot
.52587 .29495 Mdot
.3415 .48068 Mdot
.34995 .63732 Mdot
.33246 .47986 Mdot
.37407 .32854 Mdot
.36273 .70285 Mdot
.52813 .63064 Mdot
.62593 .28984 Mdot
.31827 .45877 Mdot
.69604 .45828 Mdot
.5056 .70927 Mdot
.37898 .38112 Mdot
.3118 .49239 Mdot
.31381 .46629 Mdot
.52773 .64991 Mdot
.65461 .46824 Mdot
.37581 .32679 Mdot
.54995 .34947 Mdot
.35518 .41537 Mdot
.56774 .68693 Mdot
.51082 .63512 Mdot
.53934 .61674 Mdot
.33173 .65437 Mdot
.56454 .24673 Mdot
.53479 .3056 Mdot
.26952 .5922 Mdot
.35107 .36275 Mdot
.27198 .63549 Mdot
.73027 .38796 Mdot
.41319 .39634 Mdot
.48392 .53062 Mdot
.48097 .52861 Mdot
.5158 .65007 Mdot
.77624 .71586 Mdot
.44767 .66758 Mdot
.56758 .30118 Mdot
.47887 .51366 Mdot
.37984 .37601 Mdot
.72255 .46222 Mdot
.54201 .48753 Mdot
.56126 .67143 Mdot
.55058 .3496 Mdot
.36629 .35685 Mdot
.70371 .77957 Mdot
.33764 .47055 Mdot
.34672 .63568 Mdot
.53533 .68476 Mdot
.5195 .6485 Mdot
.53484 .31994 Mdot
.54605 .28426 Mdot
.78891 .51735 Mdot
.40715 .48146 Mdot
.62326 .25031 Mdot
.51116 .32435 Mdot
.70081 .78416 Mdot
.45411 .4788 Mdot
.66969 .45883 Mdot
.47352 .49568 Mdot
.54124 .28397 Mdot
.53344 .6555 Mdot
.65429 .47088 Mdot
.4863 .50989 Mdot
.65748 .43081 Mdot
.41946 .59252 Mdot
.31505 .61038 Mdot
.52224 .67998 Mdot
.64643 .47065 Mdot
.6872 .46344 Mdot
.7148 .49942 Mdot
.47089 .50533 Mdot
.54479 .64706 Mdot
.51498 .58746 Mdot
.54434 .62271 Mdot
.7745 .52821 Mdot
.5134 .64601 Mdot
.7344 .38911 Mdot
.31772 .63474 Mdot
.28778 .26377 Mdot
.52295 .62139 Mdot
.54616 .33364 Mdot
.51317 .66058 Mdot
.32961 .44635 Mdot
.49768 .63853 Mdot
.41449 .60724 Mdot
.54046 .30865 Mdot
.72546 .70236 Mdot
.31605 .42408 Mdot
.5088 .63684 Mdot
.30172 .46582 Mdot
.75077 .35317 Mdot
.27157 .59461 Mdot
.78885 .51166 Mdot
.70409 .4491 Mdot
.34355 .28722 Mdot
.54816 .27866 Mdot
.34997 .33254 Mdot
.5192 .71671 Mdot
.46593 .48886 Mdot
.16153 .49741 Mdot
.29753 .64033 Mdot
.53221 .6578 Mdot
.49626 .50692 Mdot
.71103 .46707 Mdot
.34154 .33081 Mdot
.80364 .57945 Mdot
.50872 .60594 Mdot
.33806 .44502 Mdot
.34191 .46468 Mdot
.27964 .48969 Mdot
.75305 .44362 Mdot
.75762 .53426 Mdot
.53502 .31751 Mdot
.37703 .36047 Mdot
.3401 .488 Mdot
.63191 .4884 Mdot
.53255 .28984 Mdot
.58494 .28537 Mdot
.55794 .32167 Mdot
.53409 .62321 Mdot
.46903 .50834 Mdot
.76341 .44247 Mdot
.48947 .53941 Mdot
.52796 .6062 Mdot
.37261 .31345 Mdot
.48524 .53472 Mdot
.32653 .47482 Mdot
.55207 .32994 Mdot
.35624 .3253 Mdot
.52369 .65879 Mdot
.68997 .47074 Mdot
.38758 .51925 Mdot
.3218 .28972 Mdot
.42125 .58403 Mdot
.42131 .58383 Mdot
.72543 .48146 Mdot
.45317 .49659 Mdot
.47372 .33101 Mdot
.64087 .69123 Mdot
.37257 .41248 Mdot
.57539 .64599 Mdot
.43882 .33532 Mdot
.35338 .29181 Mdot
.36171 .34091 Mdot
.53248 .62885 Mdot
.34691 .3711 Mdot
.53029 .69538 Mdot
.35865 .37579 Mdot
.76878 .40272 Mdot
.53769 .70444 Mdot
.35926 .34972 Mdot
.4851 .50481 Mdot
.54967 .6684 Mdot
.70604 .47342 Mdot
.34223 .29178 Mdot
.56003 .63167 Mdot
.21853 .31731 Mdot
.5405 .29071 Mdot
.47229 .50881 Mdot
.36699 .61204 Mdot
.54672 .31725 Mdot
.66517 .44785 Mdot
.52161 .69851 Mdot
.33475 .48738 Mdot
.67284 .45185 Mdot
.28521 .46267 Mdot
.31706 .46543 Mdot
.34367 .6227 Mdot
.68106 .44357 Mdot
.48234 .52409 Mdot
.33621 .44485 Mdot
.52447 .56199 Mdot
.36169 .34458 Mdot
.32739 .27567 Mdot
.49724 .54567 Mdot
.53122 .63228 Mdot
.3806 .37775 Mdot
.53507 .33624 Mdot
.50558 .65966 Mdot
.37906 .34818 Mdot
.47839 .50475 Mdot
.55389 .64784 Mdot
.51331 .70822 Mdot
.81219 .49122 Mdot
.42222 .47921 Mdot
.32673 .47127 Mdot
.68835 .50411 Mdot
.54571 .61408 Mdot
.32596 .44789 Mdot
.32795 .28063 Mdot
.49866 .58359 Mdot
.69242 .43393 Mdot
.6616 .66275 Mdot
.35725 .38487 Mdot
.52261 .31423 Mdot
.388 .32121 Mdot
.30881 .4936 Mdot
.86753 .61846 Mdot
.46743 .49379 Mdot
.48331 .66455 Mdot
.51678 .61387 Mdot
.33685 .28866 Mdot
.68397 .46272 Mdot
.63528 .25716 Mdot
.49642 .65215 Mdot
.49454 .58277 Mdot
.52686 .64484 Mdot
.31313 .33772 Mdot
.67505 .48662 Mdot
.52701 .64245 Mdot
.57135 .62341 Mdot
.5289 .61091 Mdot
.30413 .47304 Mdot
.17597 .51039 Mdot
.51193 .56235 Mdot
.80993 .30567 Mdot
.48044 .50404 Mdot
.36126 .35849 Mdot
.38495 .67882 Mdot
.36553 .60636 Mdot
.2531 .31915 Mdot
.66213 .45189 Mdot
.68615 .51325 Mdot
.35477 .33155 Mdot
.40037 .41114 Mdot
.46877 .53376 Mdot
.50446 .70716 Mdot
.53026 .69 Mdot
.37393 .32849 Mdot
.33994 .35458 Mdot
.47285 .49175 Mdot
.51392 .53092 Mdot
.48398 .62013 Mdot
.37918 .31414 Mdot
.51183 .64683 Mdot
.61547 .71464 Mdot
.5246 .29448 Mdot
.7117 .44828 Mdot
.55018 .28887 Mdot
.51605 .31138 Mdot
.79401 .61231 Mdot
.32547 .65005 Mdot
.55656 .33925 Mdot
.56721 .3236 Mdot
.41326 .40698 Mdot
.76475 .62222 Mdot
.3041 .46777 Mdot
.44608 .66495 Mdot
.36058 .36834 Mdot
.54479 .64907 Mdot
.67717 .48762 Mdot
.35208 .51339 Mdot
.65598 .26058 Mdot
.49147 .7873 Mdot
.48845 .64047 Mdot
.34959 .35649 Mdot
.49776 .54715 Mdot
.50907 .55359 Mdot
.27348 .64122 Mdot
.51634 .64213 Mdot
.35733 .38653 Mdot
.76561 .61611 Mdot
.57777 .37093 Mdot
.5775 .26503 Mdot
.74069 .47971 Mdot
.51237 .66053 Mdot
.67866 .48411 Mdot
.52842 .34615 Mdot
.32704 .45088 Mdot
.33455 .47183 Mdot
.5083 .63715 Mdot
.40576 .6392 Mdot
.36575 .41007 Mdot
.51058 .7095 Mdot
.49071 .68032 Mdot
.48788 .53143 Mdot
.48564 .6676 Mdot
.51741 .5893 Mdot
.48892 .66101 Mdot
.51916 .56123 Mdot
.53317 .28998 Mdot
.78977 .59973 Mdot
.51043 .54931 Mdot
.53502 .70035 Mdot
.52373 .34089 Mdot
.52285 .71307 Mdot
.53242 .32835 Mdot
.55767 .24164 Mdot
.5605 .33107 Mdot
.33284 .4689 Mdot
.3666 .38996 Mdot
.80925 .49847 Mdot
.69797 .43954 Mdot
.52572 .33582 Mdot
.32697 .43598 Mdot
.53569 .33263 Mdot
.36606 .37161 Mdot
.59385 .35145 Mdot
.7377 .44811 Mdot
.32467 .60744 Mdot
.76976 .63239 Mdot
.54287 .37152 Mdot
.35506 .38055 Mdot
.69609 .44053 Mdot
.56293 .25357 Mdot
.49935 .67413 Mdot
.33777 .46808 Mdot
.51651 .65091 Mdot
.55134 .32909 Mdot
.35677 .36617 Mdot
.80034 .50033 Mdot
.32769 .47211 Mdot
.84453 .44621 Mdot
.37355 .30614 Mdot
.50713 .6228 Mdot
.52164 .33978 Mdot
.55837 .26079 Mdot
.53497 .29426 Mdot
.35284 .7152 Mdot
.45172 .48425 Mdot
.37266 .49027 Mdot
.6784 .44828 Mdot
.45748 .48123 Mdot
.38666 .82391 Mdot
.70418 .35116 Mdot
.68615 .47624 Mdot
.32601 .29874 Mdot
.51831 .62826 Mdot
.48726 .63664 Mdot
.50121 .51883 Mdot
.64995 .44966 Mdot
.4904 .62569 Mdot
.4722 .51104 Mdot
.31282 .64811 Mdot
.74447 .47426 Mdot
.37038 .29547 Mdot
.53922 .6833 Mdot
.51789 .33801 Mdot
.51983 .32834 Mdot
.46164 .49709 Mdot
.55759 .2981 Mdot
.5316 .70066 Mdot
.69021 .44297 Mdot
.44011 .53063 Mdot
.31243 .49488 Mdot
.74456 .37768 Mdot
.29078 .47924 Mdot
.32121 .42954 Mdot
.55418 .62313 Mdot
.3566 .32907 Mdot
.5436 .20015 Mdot
.49335 .66285 Mdot
.69061 .46531 Mdot
.51144 .61676 Mdot
.48621 .64423 Mdot
.51161 .71488 Mdot
.37679 .36039 Mdot
.33894 .65253 Mdot
.51165 .64782 Mdot
.5392 .35098 Mdot
.41665 .6147 Mdot
.55529 .68211 Mdot
.44083 .47198 Mdot
.41647 .60154 Mdot
.57309 .32989 Mdot
.7003 .49505 Mdot
.36068 .3287 Mdot
.67467 .4603 Mdot
.67875 .42043 Mdot
.66499 .44854 Mdot
.75096 .43322 Mdot
.63605 .69756 Mdot
.54933 .1828 Mdot
.74604 .5433 Mdot
.77176 .63399 Mdot
.6897 .42048 Mdot
.42497 .19176 Mdot
.6899 .47783 Mdot
.66419 .44904 Mdot
.73559 .28922 Mdot
.65693 .46446 Mdot
.53472 .64026 Mdot
.52681 .61676 Mdot
.67291 .74674 Mdot
.3626 .42714 Mdot
.55161 .65361 Mdot
.52029 .56283 Mdot
.34321 .47672 Mdot
.74534 .40747 Mdot
.49664 .53329 Mdot
.35075 .63432 Mdot
.48224 .53496 Mdot
.52741 .65069 Mdot
.51094 .67089 Mdot
.54463 .701 Mdot
.40728 .80171 Mdot
.38296 .44579 Mdot
.65492 .45167 Mdot
.56445 .61769 Mdot
.52544 .3763 Mdot
.51524 .68305 Mdot
.50273 .62061 Mdot
.50325 .71397 Mdot
.35948 .32793 Mdot
.72378 .45426 Mdot
.49274 .50521 Mdot
.73711 .36565 Mdot
.53093 .68277 Mdot
.30347 .50265 Mdot
.34418 .44769 Mdot
.52343 .63712 Mdot
.65734 .45629 Mdot
.48774 .63586 Mdot
.71768 .47063 Mdot
.67652 .44578 Mdot
.4958 .58352 Mdot
.75159 .42441 Mdot
.72265 .4589 Mdot
.50425 .70667 Mdot
.36977 .37861 Mdot
.76377 .38746 Mdot
.52909 .63263 Mdot
.32204 .47397 Mdot
.5274 .67015 Mdot
.30319 .47316 Mdot
.51029 .56248 Mdot
.4892 .5371 Mdot
.5746 .75661 Mdot
.34533 .30372 Mdot
.29797 .45834 Mdot
.34875 .37626 Mdot
.56607 .62961 Mdot
.64424 .43705 Mdot
.58485 .36575 Mdot
.39001 .40851 Mdot
.48704 .5308 Mdot
.27206 .56456 Mdot
.43007 .59107 Mdot
.56317 .32076 Mdot
.70601 .47711 Mdot
.7816 .59598 Mdot
.43991 .47575 Mdot
.37504 .29957 Mdot
.38882 .35269 Mdot
.53956 .38764 Mdot
.76011 .31684 Mdot
.52342 .62187 Mdot
.44625 .47542 Mdot
.61858 .61642 Mdot
.49595 .52541 Mdot
.47932 .49523 Mdot
.37345 .31281 Mdot
.55149 .6559 Mdot
.31148 .66289 Mdot
.37475 .34802 Mdot
.3135 .48634 Mdot
.67171 .47765 Mdot
.31934 .44638 Mdot
.65257 .30188 Mdot
.79231 .51474 Mdot
.36999 .34278 Mdot
.51646 .56109 Mdot
.54877 .64199 Mdot
.65756 .47897 Mdot
.6297 .55106 Mdot
.71664 .45647 Mdot
.32804 .49524 Mdot
.34172 .3037 Mdot
.17754 .3871 Mdot
.52022 .66784 Mdot
.69377 .45121 Mdot
.32092 .42111 Mdot
.53419 .67263 Mdot
.5234 .32192 Mdot
.49066 .62584 Mdot
.69951 .45451 Mdot
.48308 .65633 Mdot
.67773 .448 Mdot
.37873 .36707 Mdot
.51145 .62996 Mdot
.50404 .6609 Mdot
.26974 .58611 Mdot
.32309 .48768 Mdot
.72083 .45916 Mdot
.32991 .66777 Mdot
.5177 .60822 Mdot
.27848 .65869 Mdot
.50966 .6469 Mdot
.765 .63479 Mdot
.57319 .6167 Mdot
.47461 .51585 Mdot
.51287 .61543 Mdot
.5269 .63238 Mdot
.62689 .54917 Mdot
.73705 .54988 Mdot
.77598 .52742 Mdot
.52107 .3206 Mdot
.70061 .4781 Mdot
.37593 .34266 Mdot
.33987 .29368 Mdot
.34845 .34194 Mdot
.32956 .50449 Mdot
.52213 .57654 Mdot
.53977 .63527 Mdot
.56909 .29936 Mdot
.3356 .48333 Mdot
.68655 .45258 Mdot
.32818 .46388 Mdot
.33201 .64693 Mdot
.32189 .47679 Mdot
.46954 .49233 Mdot
.38238 .25112 Mdot
.61971 .71076 Mdot
.3123 .47648 Mdot
.70735 .44514 Mdot
.41205 .63462 Mdot
.49349 .57904 Mdot
.82464 .47865 Mdot
.34207 .45289 Mdot
.3253 .29688 Mdot
.55501 .64937 Mdot
.37835 .67984 Mdot
.53532 .32735 Mdot
.31976 .44546 Mdot
.55852 .31953 Mdot
.48774 .64279 Mdot
.68419 .51688 Mdot
.69839 .46534 Mdot
.52321 .29543 Mdot
.50756 .61528 Mdot
.32056 .44528 Mdot
.36657 .34301 Mdot
.76387 .62191 Mdot
.58125 .27718 Mdot
.39269 .49613 Mdot
.27441 .63677 Mdot
.33913 .32565 Mdot
.74595 .64007 Mdot
.5604 .32382 Mdot
.56547 .61929 Mdot
.51961 .72903 Mdot
.53724 .60494 Mdot
.37793 .32678 Mdot
.36144 .34 Mdot
.46056 .32206 Mdot
.50344 .66207 Mdot
.4816 .65228 Mdot
.70394 .49697 Mdot
.33877 .31003 Mdot
.66578 .44809 Mdot
.64572 .47429 Mdot
.38353 .33684 Mdot
.7174 .46556 Mdot
.31606 .46485 Mdot
.3275 .68831 Mdot
.56016 .32633 Mdot
.5261 .30271 Mdot
.36929 .34047 Mdot
.35162 .30835 Mdot
.35599 .32879 Mdot
.50213 .60703 Mdot
.67422 .44514 Mdot
.50399 .67671 Mdot
.51499 .66293 Mdot
.48932 .58176 Mdot
.65598 .49376 Mdot
.49683 .66197 Mdot
.44594 .52995 Mdot
.34797 .46762 Mdot
.35794 .35343 Mdot
.55209 .30749 Mdot
.38295 .52366 Mdot
.54481 .3512 Mdot
.52762 .60952 Mdot
.76818 .40817 Mdot
.69701 .48051 Mdot
.33236 .47876 Mdot
.4148 .60478 Mdot
.33004 .47396 Mdot
.52361 .29572 Mdot
.71491 .49486 Mdot
.33828 .62301 Mdot
.50126 .65544 Mdot
.32883 .65571 Mdot
.22167 .53681 Mdot
.71517 .3866 Mdot
.55015 .3176 Mdot
.49356 .60785 Mdot
.47112 .51374 Mdot
.6427 .6913 Mdot
.53645 .63249 Mdot
.56113 .66766 Mdot
.38909 .62156 Mdot
.5279 .61227 Mdot
.67765 .43259 Mdot
.43015 .56878 Mdot
.52 .54718 Mdot
.54575 .60793 Mdot
.58469 .21721 Mdot
.55272 .64627 Mdot
.50266 .65155 Mdot
.54097 .64772 Mdot
.49141 .65028 Mdot
.65188 .48764 Mdot
.43098 .54795 Mdot
.52959 .34565 Mdot
.32705 .68845 Mdot
.55715 .33205 Mdot
.37117 .33375 Mdot
.40134 .48792 Mdot
.70681 .48794 Mdot
.32987 .47454 Mdot
.46062 .44356 Mdot
.37163 .70203 Mdot
.36991 .37617 Mdot
.26734 .56009 Mdot
.31717 .43978 Mdot
.48652 .50241 Mdot
.30671 .49161 Mdot
.37715 .31993 Mdot
.52474 .32385 Mdot
.50731 .62812 Mdot
.67682 .43855 Mdot
.70795 .45262 Mdot
.55167 .61648 Mdot
.75649 .36917 Mdot
.52232 .3117 Mdot
.4424 .35416 Mdot
.5329 .62488 Mdot
.51474 .61027 Mdot
.71409 .47591 Mdot
.34406 .34048 Mdot
.42994 .58938 Mdot
.30696 .46681 Mdot
.51944 .68581 Mdot
.51892 .55248 Mdot
.33127 .64831 Mdot
.52074 .32534 Mdot
.47396 .50439 Mdot
.54856 .64975 Mdot
.33069 .63966 Mdot
.49492 .60991 Mdot
.57389 .65161 Mdot
.36701 .38264 Mdot
.49554 .58219 Mdot
.50588 .66906 Mdot
.74149 .47875 Mdot
.56075 .31884 Mdot
.68402 .46552 Mdot
.73575 .46673 Mdot
.48827 .53509 Mdot
.53918 .29251 Mdot
.49226 .64057 Mdot
.55626 .27402 Mdot
.48682 .64301 Mdot
.51867 .65963 Mdot
.54958 .32129 Mdot
.66453 .45504 Mdot
.62614 .25557 Mdot
.78976 .59845 Mdot
.48678 .65995 Mdot
.53056 .67045 Mdot
.36251 .42712 Mdot
.34412 .51458 Mdot
.49925 .65663 Mdot
.70154 .44173 Mdot
.53147 .67458 Mdot
.55992 .28248 Mdot
.33213 .45868 Mdot
.69322 .46875 Mdot
.34347 .34611 Mdot
.37978 .36442 Mdot
.38639 .38112 Mdot
.46955 .4917 Mdot
.48629 .67248 Mdot
.6884 .50403 Mdot
.65028 .49008 Mdot
.35277 .67383 Mdot
.36074 .35746 Mdot
.32421 .45496 Mdot
.54171 .68253 Mdot
.48089 .4905 Mdot
.51851 .33147 Mdot
.8056 .29647 Mdot
.33659 .62497 Mdot
.34925 .46848 Mdot
.40927 .49327 Mdot
.4879 .52547 Mdot
.54836 .6338 Mdot
.32576 .44607 Mdot
.38309 .34017 Mdot
.48756 .63287 Mdot
.5632 .60638 Mdot
.32383 .30212 Mdot
.35207 .31787 Mdot
.55695 .27326 Mdot
.35302 .36963 Mdot
.30753 .45244 Mdot
.46831 .49391 Mdot
.70631 .4658 Mdot
.51961 .63799 Mdot
.5088 .54554 Mdot
.36293 .36493 Mdot
.46169 .48117 Mdot
.52469 .61859 Mdot
.69648 .48349 Mdot
.35278 .35395 Mdot
.53126 .64956 Mdot
.64622 .67644 Mdot
.80821 .49549 Mdot
.35632 .3674 Mdot
.52084 .69585 Mdot
.56034 .50186 Mdot
.35442 .31958 Mdot
.37561 .31968 Mdot
.50379 .58477 Mdot
.32608 .44188 Mdot
.52012 .6799 Mdot
.52526 .31504 Mdot
.33438 .65766 Mdot
.54331 .29064 Mdot
.27249 .64191 Mdot
.51224 .58422 Mdot
.52804 .73547 Mdot
.65367 .43159 Mdot
.29644 .45716 Mdot
.32018 .73821 Mdot
.54779 .61733 Mdot
.62886 .44304 Mdot
.34023 .65499 Mdot
.33951 .60838 Mdot
.61264 .47532 Mdot
.30929 .45515 Mdot
.53989 .33019 Mdot
.50618 .64504 Mdot
.60668 .24941 Mdot
.30948 .4584 Mdot
.2735 .64397 Mdot
.50964 .69503 Mdot
.6911 .45793 Mdot
.52822 .62412 Mdot
.70487 .46363 Mdot
.54035 .6634 Mdot
.8119 .48923 Mdot
.36677 .41051 Mdot
.35351 .71509 Mdot
.48919 .50802 Mdot
.55845 .26088 Mdot
.7701 .63256 Mdot
.32003 .46102 Mdot
.48325 .64884 Mdot
.48568 .51845 Mdot
.52808 .33355 Mdot
.59373 .37252 Mdot
.35384 .33161 Mdot
.54148 .35039 Mdot
.66795 .46382 Mdot
.38576 .37226 Mdot
.45987 .48217 Mdot
.55256 .74257 Mdot
.32321 .44426 Mdot
.53834 .29287 Mdot
.5238 .63409 Mdot
.5335 .60469 Mdot
.31265 .33393 Mdot
.17652 .51847 Mdot
.64362 .47461 Mdot
.84893 .43251 Mdot
.71274 .49559 Mdot
.32397 .49057 Mdot
.37311 .37948 Mdot
.53465 .65628 Mdot
.5408 .67732 Mdot
.35055 .3176 Mdot
.66231 .48391 Mdot
.30643 .44389 Mdot
.37036 .49027 Mdot
.56726 .29881 Mdot
.19514 .5399 Mdot
.69592 .4699 Mdot
.19466 .53792 Mdot
.4184 .34063 Mdot
.78114 .448 Mdot
.31106 .72276 Mdot
.54528 .31234 Mdot
.19465 .53969 Mdot
.69266 .45522 Mdot
.53877 .62143 Mdot
.48316 .52308 Mdot
.46341 .48763 Mdot
.68109 .48272 Mdot
.37109 .32705 Mdot
.31466 .44322 Mdot
.52694 .62546 Mdot
.59276 .67327 Mdot
.63076 .55183 Mdot
.35192 .29854 Mdot
.50212 .53341 Mdot
.54694 .30253 Mdot
.53319 .67178 Mdot
.3415 .48351 Mdot
.54419 .31233 Mdot
.48485 .53643 Mdot
.36132 .70189 Mdot
.52168 .69828 Mdot
.40924 .62248 Mdot
.53377 .32484 Mdot
.33749 .52043 Mdot
.50552 .66363 Mdot
.56037 .32365 Mdot
.50721 .56162 Mdot
.47285 .34942 Mdot
.44724 .555 Mdot
.70344 .35135 Mdot
.39203 .32445 Mdot
.35938 .37569 Mdot
.21371 .33208 Mdot
.25663 .33119 Mdot
.54904 .34169 Mdot
.49828 .54057 Mdot
.17297 .50767 Mdot
.5597 .30907 Mdot
.49461 .64447 Mdot
.51228 .63464 Mdot
.76584 .6155 Mdot
.50118 .55377 Mdot
.47857 .50203 Mdot
.72626 .50892 Mdot
.51942 .71003 Mdot
.50211 .53524 Mdot
.50619 .65771 Mdot
.65354 .45588 Mdot
.54481 .30426 Mdot
.54254 .83927 Mdot
.53574 .28451 Mdot
.53382 .73367 Mdot
.35999 .36821 Mdot
.39407 .33685 Mdot
.52277 .63848 Mdot
.55344 .48185 Mdot
.70633 .7815 Mdot
.51073 .63674 Mdot
.41448 .60591 Mdot
.27202 .63335 Mdot
.52379 .58967 Mdot
.7113 .43871 Mdot
.50804 .55813 Mdot
.66227 .49935 Mdot
.54486 .31871 Mdot
.30945 .45529 Mdot
.29859 .45012 Mdot
.53916 .3292 Mdot
.5437 .67049 Mdot
.29154 .47578 Mdot
.52166 .64768 Mdot
.54399 .63099 Mdot
.33558 .63987 Mdot
.33739 .48985 Mdot
.3618 .32503 Mdot
.33317 .47123 Mdot
.66039 .45466 Mdot
.83244 .37725 Mdot
.32407 .4611 Mdot
.76484 .62179 Mdot
.33179 .66506 Mdot
.17741 .50755 Mdot
.70988 .45679 Mdot
.31094 .49396 Mdot
.54128 .33231 Mdot
.36314 .62654 Mdot
.73544 .66671 Mdot
.54653 .35041 Mdot
.54429 .63944 Mdot
.64864 .48469 Mdot
.71951 .48892 Mdot
.53275 .35254 Mdot
.7076 .46929 Mdot
.52682 .58182 Mdot
.49988 .69735 Mdot
.53124 .34743 Mdot
.36691 .78318 Mdot
.5291 .29727 Mdot
.79982 .59944 Mdot
.48708 .67311 Mdot
.69169 .46678 Mdot
.76522 .64017 Mdot
.73394 .48065 Mdot
.46514 .49668 Mdot
.49933 .63932 Mdot
.32435 .45775 Mdot
.34178 .67491 Mdot
.34844 .35635 Mdot
.73086 .39668 Mdot
.70123 .44833 Mdot
.53129 .3542 Mdot
.70704 .46923 Mdot
.70828 .47619 Mdot
.51918 .30136 Mdot
.69701 .4794 Mdot
.53228 .68224 Mdot
.81817 .49177 Mdot
.71346 .46357 Mdot
.53717 .31562 Mdot
.32669 .4949 Mdot
.70766 .44453 Mdot
.44228 .36715 Mdot
.54348 .67849 Mdot
.35758 .28984 Mdot
.34926 .50134 Mdot
.6484 .47667 Mdot
.32022 .45928 Mdot
.36018 .36282 Mdot
.33303 .43721 Mdot
.51937 .26672 Mdot
.54429 .26191 Mdot
.58423 .61432 Mdot
.46765 .3463 Mdot
.65727 .46266 Mdot
.38695 .37198 Mdot
.52603 .6914 Mdot
.53704 .6258 Mdot
.34074 .49213 Mdot
.71902 .44007 Mdot
.75533 .36245 Mdot
.49833 .53458 Mdot
.74392 .37703 Mdot
.52075 .32045 Mdot
.43508 .36857 Mdot
.33608 .62156 Mdot
.5931 .31729 Mdot
.51976 .54427 Mdot
.48709 .52355 Mdot
.52739 .64427 Mdot
.27115 .59602 Mdot
.30722 .45382 Mdot
.41299 .20471 Mdot
.51501 .60134 Mdot
.34825 .31608 Mdot
.54013 .65904 Mdot
.46025 .52671 Mdot
.53579 .60181 Mdot
.34809 .47632 Mdot
.56288 .33966 Mdot
.69864 .43973 Mdot
.30585 .48607 Mdot
.3811 .36343 Mdot
.37446 .72657 Mdot
.49953 .66319 Mdot
.53913 .69059 Mdot
.36275 .3193 Mdot
.66863 .44307 Mdot
.36632 .33518 Mdot
.5599 .32682 Mdot
.32473 .46392 Mdot
.49404 .61665 Mdot
.50362 .55581 Mdot
.33612 .28936 Mdot
.52806 .33945 Mdot
.37754 .38024 Mdot
.54866 .27604 Mdot
.48609 .52645 Mdot
.55658 .61402 Mdot
.36072 .39114 Mdot
.51679 .5441 Mdot
.73369 .60573 Mdot
.36662 .69858 Mdot
.61581 .53704 Mdot
.37134 .32478 Mdot
.25759 .31157 Mdot
.54182 .31355 Mdot
.5525 .28382 Mdot
.80365 .59475 Mdot
.76455 .72755 Mdot
.41947 .609 Mdot
.73642 .34471 Mdot
.55993 .32738 Mdot
.53025 .32082 Mdot
.36474 .33185 Mdot
.66128 .46096 Mdot
.6501 .43852 Mdot
.38697 .36533 Mdot
.2942 .68893 Mdot
.68688 .45248 Mdot
.68778 .73921 Mdot
.35692 .29489 Mdot
.51261 .71654 Mdot
.80374 .49658 Mdot
.34698 .46466 Mdot
.27591 .62805 Mdot
.59222 .35727 Mdot
.53543 .64701 Mdot
.55651 .1885 Mdot
.35396 .33439 Mdot
.47393 .4864 Mdot
.49183 .34249 Mdot
.50856 .60911 Mdot
.54255 .65349 Mdot
.53062 .67939 Mdot
.33336 .50917 Mdot
.71779 .56786 Mdot
.5353 .65091 Mdot
.36112 .70684 Mdot
.52691 .71383 Mdot
.31731 .2827 Mdot
.33295 .47061 Mdot
.26514 .55056 Mdot
.33611 .36593 Mdot
.73237 .36083 Mdot
.566 .65055 Mdot
.56258 .29426 Mdot
.44974 .52335 Mdot
.55067 .32269 Mdot
.56978 .33666 Mdot
.1942 .57567 Mdot
.67553 .43404 Mdot
.51024 .60406 Mdot
.35919 .30181 Mdot
.64797 .4403 Mdot
.44721 .52385 Mdot
.84055 .38943 Mdot
.53324 .35855 Mdot
.87872 .60546 Mdot
.55717 .29063 Mdot
.47126 .48854 Mdot
.66999 .4685 Mdot
.61863 .52012 Mdot
.32808 .65444 Mdot
.66527 .44962 Mdot
.28563 .3291 Mdot
.65547 .49685 Mdot
.24605 .665 Mdot
.73145 .43976 Mdot
.53696 .30897 Mdot
.53174 .35283 Mdot
.54048 .58849 Mdot
.51833 .67973 Mdot
.31168 .65376 Mdot
.49876 .53428 Mdot
.51986 .70104 Mdot
.37499 .34835 Mdot
.45701 .33573 Mdot
.59122 .24488 Mdot
.69413 .47961 Mdot
.5327 .34204 Mdot
.54125 .65569 Mdot
.48602 .65762 Mdot
.52113 .61602 Mdot
.39991 .41441 Mdot
.6807 .74661 Mdot
.51499 .65859 Mdot
.56864 .6324 Mdot
.3733 .37464 Mdot
.31235 .33503 Mdot
.77607 .34427 Mdot
.1942 .55722 Mdot
.55548 .63476 Mdot
.32859 .48738 Mdot
.33327 .49727 Mdot
.55664 .60328 Mdot
.60792 .51484 Mdot
.26894 .50231 Mdot
.52439 .63386 Mdot
.37688 .71745 Mdot
.3492 .28317 Mdot
.46328 .50044 Mdot
.36341 .36446 Mdot
.6716 .4202 Mdot
.47745 .52327 Mdot
.37992 .34339 Mdot
.33797 .71262 Mdot
.49462 .54258 Mdot
.47244 .34595 Mdot
.31428 .4966 Mdot
.50588 .66056 Mdot
.78901 .57356 Mdot
.33846 .31014 Mdot
.52776 .31251 Mdot
.67607 .46927 Mdot
.52152 .31961 Mdot
.33048 .27132 Mdot
.28332 .67089 Mdot
.46806 .50161 Mdot
.56225 .29224 Mdot
.4086 .62729 Mdot
.33252 .48423 Mdot
.55881 .29776 Mdot
.52535 .72784 Mdot
.54002 .7032 Mdot
.68894 .77913 Mdot
.54232 .68437 Mdot
.46202 .32358 Mdot
.53992 .29023 Mdot
.47732 .5255 Mdot
.51849 .63927 Mdot
.37273 .30393 Mdot
.54889 .58741 Mdot
.5221 .64934 Mdot
.34005 .33623 Mdot
.51321 .63507 Mdot
.33386 .45498 Mdot
.70608 .50156 Mdot
.34508 .65295 Mdot
.39607 .48043 Mdot
.30541 .46191 Mdot
.37556 .69399 Mdot
.49837 .65359 Mdot
.27062 .33137 Mdot
.68792 .45843 Mdot
.52889 .6099 Mdot
.24618 .61693 Mdot
.66613 .47489 Mdot
.67445 .4575 Mdot
.49742 .70114 Mdot
.55345 .27974 Mdot
.36294 .32271 Mdot
.33466 .47988 Mdot
.58152 .27442 Mdot
.53241 .65115 Mdot
.49259 .61112 Mdot
.3046 .46695 Mdot
.53031 .30553 Mdot
.49323 .6216 Mdot
.63389 .37781 Mdot
.33363 .69139 Mdot
.52253 .29841 Mdot
.55641 .68038 Mdot
.71832 .72054 Mdot
.68952 .49075 Mdot
.55482 .18755 Mdot
.36715 .41086 Mdot
.38633 .35719 Mdot
.50382 .53683 Mdot
.81291 .3155 Mdot
.32654 .49576 Mdot
.72597 .37955 Mdot
.52971 .62078 Mdot
.53203 .66276 Mdot
.65485 .45853 Mdot
.50436 .67539 Mdot
.69892 .47973 Mdot
.42542 .39303 Mdot
.78912 .70367 Mdot
.70862 .45944 Mdot
.70153 .45923 Mdot
.44717 .68966 Mdot
.37426 .40049 Mdot
.67354 .47763 Mdot
.50566 .67102 Mdot
.28598 .27951 Mdot
.57503 .68858 Mdot
.31559 .43574 Mdot
.33491 .51083 Mdot
.70987 .4396 Mdot
.73531 .67125 Mdot
.52293 .72514 Mdot
.68709 .7201 Mdot
.26753 .50314 Mdot
.55182 .34017 Mdot
.49696 .59572 Mdot
.49347 .52935 Mdot
.3549 .35175 Mdot
.50009 .57881 Mdot
.50739 .6651 Mdot
.68498 .43477 Mdot
.34257 .44933 Mdot
.55863 .30807 Mdot
.5154 .53786 Mdot
.36184 .28261 Mdot
.30781 .47435 Mdot
.71429 .47097 Mdot
.78239 .62542 Mdot
.29505 .48871 Mdot
.49565 .50622 Mdot
.54831 .62872 Mdot
.4997 .58338 Mdot
.48253 .49029 Mdot
.53956 .32746 Mdot
.39046 .34668 Mdot
.49672 .50971 Mdot
.36656 .64003 Mdot
.31914 .69186 Mdot
.55092 .62417 Mdot
.70455 .44291 Mdot
.5291 .33701 Mdot
.47018 .49679 Mdot
.17253 .50263 Mdot
.55566 .65429 Mdot
.68801 .73978 Mdot
.38231 .49695 Mdot
.49233 .53201 Mdot
.64615 .44251 Mdot
.33264 .47642 Mdot
.48689 .67165 Mdot
.35754 .70966 Mdot
.51686 .70062 Mdot
.56471 .61737 Mdot
.38219 .33287 Mdot
.55592 .32242 Mdot
.58529 .61724 Mdot
.35672 .34998 Mdot
.67453 .45935 Mdot
.66371 .73662 Mdot
.64678 .46498 Mdot
.64499 .47299 Mdot
.74787 .41888 Mdot
.52545 .3071 Mdot
.81212 .31223 Mdot
.34279 .51421 Mdot
.51429 .62366 Mdot
.56013 .33976 Mdot
.67894 .47781 Mdot
.49608 .65796 Mdot
.69743 .48043 Mdot
.72106 .44824 Mdot
.52401 .70287 Mdot
.51192 .70733 Mdot
.35937 .7129 Mdot
.71585 .71619 Mdot
.33708 .46688 Mdot
.66071 .4815 Mdot
.72334 .70028 Mdot
.53327 .65687 Mdot
.51229 .67337 Mdot
.45005 .52145 Mdot
.30249 .47962 Mdot
.59287 .75567 Mdot
.53544 .62356 Mdot
.26729 .58344 Mdot
.49564 .64724 Mdot
.71114 .42899 Mdot
.56015 .26449 Mdot
.52952 .7316 Mdot
.38081 .37478 Mdot
.65973 .48192 Mdot
.34696 .46082 Mdot
.66395 .41956 Mdot
.62544 .70783 Mdot
.53453 .33379 Mdot
.69952 .45469 Mdot
.39168 .35124 Mdot
.53162 .30693 Mdot
.52985 .29688 Mdot
.44553 .52311 Mdot
.38881 .32865 Mdot
.34222 .44753 Mdot
.55103 .29938 Mdot
.64974 .67245 Mdot
.5354 .30832 Mdot
.6218 .72531 Mdot
.55581 .66202 Mdot
.35911 .70719 Mdot
.50717 .52768 Mdot
.57705 .62256 Mdot
.54643 .2927 Mdot
.30587 .46918 Mdot
.49491 .61789 Mdot
.71057 .46964 Mdot
.32892 .49192 Mdot
.79035 .50983 Mdot
.39355 .34988 Mdot
.71137 .49336 Mdot
.58379 .28306 Mdot
.663 .47881 Mdot
.27505 .6336 Mdot
.34725 .45307 Mdot
.43677 .47505 Mdot
.3461 .64252 Mdot
.49832 .52606 Mdot
.55071 .6125 Mdot
.4979 .61259 Mdot
.53564 .67939 Mdot
.36032 .36898 Mdot
.33025 .5095 Mdot
.71574 .45134 Mdot
.5976 .62567 Mdot
.52779 .30656 Mdot
.42492 .58222 Mdot
.48303 .49436 Mdot
.48721 .64562 Mdot
.68194 .47699 Mdot
.72311 .45551 Mdot
.73125 .55427 Mdot
.35168 .32204 Mdot
.5851 .65517 Mdot
.54967 .62014 Mdot
.59618 .64842 Mdot
.54453 .29192 Mdot
.68851 .3572 Mdot
.34982 .28582 Mdot
.88214 .60085 Mdot
.35846 .35152 Mdot
.42603 .48717 Mdot
.68645 .4859 Mdot
.31884 .47237 Mdot
.5474 .66445 Mdot
.75076 .45865 Mdot
.63983 .46423 Mdot
.29992 .41688 Mdot
.32801 .47569 Mdot
.54251 .24423 Mdot
.55861 .33689 Mdot
.51625 .53782 Mdot
.49538 .64648 Mdot
.50232 .68273 Mdot
.5152 .68627 Mdot
.54286 .34551 Mdot
.50695 .70226 Mdot
.56717 .27173 Mdot
.62278 .70808 Mdot
.24632 .62007 Mdot
.36863 .31274 Mdot
.31942 .25929 Mdot
.64859 .48133 Mdot
.61989 .75222 Mdot
.60822 .7324 Mdot
.36394 .69851 Mdot
.56909 .32799 Mdot
.52059 .57169 Mdot
.36541 .32788 Mdot
.58981 .2491 Mdot
.36733 .31096 Mdot
.59224 .8226 Mdot
.76747 .61417 Mdot
.50465 .26832 Mdot
.50622 .68807 Mdot
.38388 .33039 Mdot
.73581 .67626 Mdot
.50252 .51686 Mdot
.29197 .47749 Mdot
.63308 .69671 Mdot
.78064 .52345 Mdot
.33712 .46434 Mdot
.551 .65478 Mdot
.65382 .49216 Mdot
.54511 .66985 Mdot
.54856 .66254 Mdot
.52764 .61871 Mdot
.51469 .32611 Mdot
.55787 .65676 Mdot
.52489 .68368 Mdot
.15635 .43472 Mdot
.27812 .47672 Mdot
.35655 .37511 Mdot
.61942 .52735 Mdot
.33571 .48323 Mdot
.67321 .41973 Mdot
.3457 .64872 Mdot
.54775 .28394 Mdot
.72786 .55622 Mdot
.4967 .69495 Mdot
.73377 .3905 Mdot
.54538 .28093 Mdot
.32557 .44003 Mdot
.49052 .5246 Mdot
.66011 .2577 Mdot
.35345 .3842 Mdot
.48268 .50812 Mdot
.34202 .33775 Mdot
.57073 .74194 Mdot
.70371 .46871 Mdot
.49884 .52746 Mdot
.55721 .30542 Mdot
.37159 .31115 Mdot
.3699 .7056 Mdot
.52501 .67609 Mdot
.37383 .3253 Mdot
.50604 .5445 Mdot
.33972 .67397 Mdot
.33888 .65489 Mdot
.38194 .3234 Mdot
.56735 .29145 Mdot
.53849 .29628 Mdot
.33908 .48313 Mdot
.69955 .48509 Mdot
.67141 .44019 Mdot
.53704 .30193 Mdot
.5651 .21802 Mdot
.53245 .64903 Mdot
.51876 .66332 Mdot
.34724 .62816 Mdot
.49805 .62377 Mdot
.36102 .42817 Mdot
.48726 .51367 Mdot
.68434 .4372 Mdot
.49644 .61514 Mdot
.49238 .62529 Mdot
.55374 .64249 Mdot
.29535 .69424 Mdot
.35834 .36501 Mdot
.51388 .71227 Mdot
.32359 .44548 Mdot
.78754 .51618 Mdot
.52647 .68917 Mdot
.49625 .50229 Mdot
.68831 .48664 Mdot
.54926 .38431 Mdot
.52724 .3143 Mdot
.351 .30136 Mdot
.35656 .30121 Mdot
.22028 .54693 Mdot
.64949 .46509 Mdot
.48409 .50945 Mdot
.32343 .30216 Mdot
.47094 .49406 Mdot
.32625 .47743 Mdot
.44431 .56393 Mdot
.33654 .39035 Mdot
.35566 .37381 Mdot
.5174 .29656 Mdot
.52698 .60649 Mdot
.52357 .68776 Mdot
.74526 .36503 Mdot
.50857 .64969 Mdot
.32856 .45776 Mdot
.56397 .31334 Mdot
.6981 .45596 Mdot
.3378 .45739 Mdot
.55857 .28885 Mdot
.66716 .44586 Mdot
.52742 .71178 Mdot
.49579 .65404 Mdot
.67343 .46413 Mdot
.71221 .47498 Mdot
.534 .63788 Mdot
.20022 .60516 Mdot
.69404 .43692 Mdot
.67304 .46852 Mdot
.78535 .51826 Mdot
.35522 .38307 Mdot
.54756 .58547 Mdot
.55945 .28327 Mdot
.5257 .68274 Mdot
.36539 .31299 Mdot
.31832 .4812 Mdot
.69772 .44416 Mdot
.503 .58269 Mdot
.52862 .6555 Mdot
.32969 .48601 Mdot
.30773 .49613 Mdot
.3107 .49043 Mdot
.53259 .35205 Mdot
.50359 .70612 Mdot
.67122 .47369 Mdot
.54688 .34898 Mdot
.34401 .48111 Mdot
.29972 .47593 Mdot
.2671 .69657 Mdot
.5343 .64411 Mdot
.31563 .50245 Mdot
.82574 .36406 Mdot
.34396 .72438 Mdot
.46103 .4915 Mdot
.39398 .3699 Mdot
.25962 .29937 Mdot
.3303 .51878 Mdot
.55444 .32714 Mdot
.42273 .58354 Mdot
.32076 .43552 Mdot
.51247 .54311 Mdot
.52007 .67018 Mdot
.48881 .59011 Mdot
.32618 .49267 Mdot
.28183 .66925 Mdot
.66954 .43579 Mdot
.6389 .57659 Mdot
.33606 .48253 Mdot
.38034 .31784 Mdot
.34167 .28318 Mdot
.36046 .34406 Mdot
.53509 .60063 Mdot
.55162 .76178 Mdot
.64196 .64963 Mdot
.59263 .75069 Mdot
.56017 .33361 Mdot
.72303 .45359 Mdot
.79942 .506 Mdot
.6749 .45544 Mdot
.34621 .33831 Mdot
.30629 .46725 Mdot
.65718 .45303 Mdot
.52454 .30579 Mdot
.54087 .29493 Mdot
.3583 .38913 Mdot
.36304 .3608 Mdot
.36836 .34301 Mdot
.6749 .49099 Mdot
.69122 .48395 Mdot
.49826 .66968 Mdot
.71228 .45292 Mdot
.39291 .41217 Mdot
.41219 .40501 Mdot
.33606 .3463 Mdot
.53957 .32126 Mdot
.67751 .44572 Mdot
.50431 .65702 Mdot
.3921 .60631 Mdot
.32909 .29137 Mdot
.34532 .46178 Mdot
.82063 .48886 Mdot
.74918 .7433 Mdot
.50461 .59589 Mdot
.54198 .34057 Mdot
.48178 .50276 Mdot
.53834 .67341 Mdot
.38745 .35599 Mdot
.37164 .50826 Mdot
.49505 .54785 Mdot
.52929 .69403 Mdot
.54321 .694 Mdot
.52948 .33333 Mdot
.34863 .64642 Mdot
.51366 .54072 Mdot
.43729 .53192 Mdot
.56527 .31647 Mdot
.34232 .28896 Mdot
.23461 .30423 Mdot
.73897 .49802 Mdot
.28358 .56881 Mdot
.48051 .52842 Mdot
.55634 .65376 Mdot
.37547 .35256 Mdot
.33412 .44905 Mdot
.37117 .35291 Mdot
.68729 .42002 Mdot
.35716 .3849 Mdot
.50821 .64378 Mdot
.66982 .47445 Mdot
.53673 .29485 Mdot
.35983 .60746 Mdot
.58605 .57786 Mdot
.36913 .3009 Mdot
.4627 .47905 Mdot
.51428 .70684 Mdot
.64942 .68043 Mdot
.57628 .62118 Mdot
.50865 .6718 Mdot
.55007 .32053 Mdot
.69019 .47917 Mdot
.52243 .32765 Mdot
.55376 .59251 Mdot
.60979 .50071 Mdot
.52635 .31775 Mdot
.50146 .73799 Mdot
.31285 .44439 Mdot
.28725 .67956 Mdot
.52206 .63048 Mdot
.55728 .31082 Mdot
.53501 .69309 Mdot
.65629 .47469 Mdot
.33071 .70498 Mdot
.34257 .69377 Mdot
.54657 .30592 Mdot
.45007 .484 Mdot
.3333 .66742 Mdot
.54599 .58324 Mdot
.55823 .33032 Mdot
.35674 .74122 Mdot
.47849 .5081 Mdot
.30911 .47503 Mdot
.30187 .48695 Mdot
.3121 .46176 Mdot
.51583 .66406 Mdot
.74653 .68525 Mdot
.33358 .49247 Mdot
.51878 .3629 Mdot
.32682 .45109 Mdot
.39092 .50143 Mdot
.75819 .36778 Mdot
.3092 .45051 Mdot
.51617 .63708 Mdot
.53992 .73869 Mdot
.41865 .59483 Mdot
.3863 .31616 Mdot
.64668 .26208 Mdot
.1606 .42358 Mdot
.5352 .65582 Mdot
.8141 .49217 Mdot
.72999 .49048 Mdot
.42267 .47772 Mdot
.35049 .6963 Mdot
.40405 .65436 Mdot
.67013 .45661 Mdot
.34696 .64439 Mdot
.69426 .49511 Mdot
.49147 .50688 Mdot
.51729 .65902 Mdot
.65766 .47974 Mdot
.73144 .39762 Mdot
.32282 .74205 Mdot
.74884 .38234 Mdot
.67478 .4443 Mdot
.56077 .31825 Mdot
.54913 .33186 Mdot
.55043 .31594 Mdot
.37156 .36632 Mdot
.70272 .45629 Mdot
.52305 .70882 Mdot
.38237 .36433 Mdot
.54388 .6352 Mdot
.5424 .3025 Mdot
.35344 .6991 Mdot
.70069 .45905 Mdot
.52519 .63276 Mdot
.72817 .68851 Mdot
.33985 .32563 Mdot
.33029 .48728 Mdot
.81835 .48871 Mdot
.38963 .37315 Mdot
.55754 .27579 Mdot
.69271 .42262 Mdot
.2809 .46556 Mdot
.42962 .54913 Mdot
.54861 .62291 Mdot
.50576 .63087 Mdot
.42123 .58327 Mdot
.77394 .61249 Mdot
.51488 .55546 Mdot
.38046 .36387 Mdot
.35317 .37828 Mdot
.5471 .67381 Mdot
.70486 .45517 Mdot
.33435 .42812 Mdot
.31053 .50396 Mdot
.57555 .65071 Mdot
.33179 .65551 Mdot
.36117 .70656 Mdot
.49223 .64455 Mdot
.46577 .67752 Mdot
.39173 .34872 Mdot
.4602 .48931 Mdot
.33288 .64816 Mdot
.31614 .46326 Mdot
.53978 .62292 Mdot
.62737 .54066 Mdot
.69822 .44775 Mdot
.36952 .32407 Mdot
.51736 .33596 Mdot
.29292 .48355 Mdot
.33854 .35445 Mdot
.54735 .67325 Mdot
.49276 .62378 Mdot
.55813 .29987 Mdot
.70126 .42602 Mdot
.31326 .48685 Mdot
.38046 .3674 Mdot
.31783 .46894 Mdot
.70059 .4734 Mdot
.69641 .44253 Mdot
.53173 .6142 Mdot
.58746 .65503 Mdot
.36213 .2962 Mdot
.5325 .59724 Mdot
.37663 .33351 Mdot
.31241 .33223 Mdot
.51883 .33217 Mdot
.52762 .61031 Mdot
.65629 .43207 Mdot
.54091 .3007 Mdot
.53765 .65476 Mdot
.42555 .57085 Mdot
.49031 .63084 Mdot
.38422 .32957 Mdot
.36143 .50887 Mdot
.31125 .47174 Mdot
.48563 .69526 Mdot
.76429 .52848 Mdot
.49586 .62541 Mdot
.33603 .3157 Mdot
.64196 .66832 Mdot
.52949 .32708 Mdot
.67543 .48499 Mdot
.35436 .25702 Mdot
.53607 .31376 Mdot
.51824 .62959 Mdot
.32493 .46081 Mdot
.71787 .46708 Mdot
.47282 .51512 Mdot
.30175 .62753 Mdot
.56126 .60232 Mdot
.58404 .66182 Mdot
.51451 .55161 Mdot
.74116 .3484 Mdot
.36941 .34602 Mdot
.67948 .47675 Mdot
.54549 .33919 Mdot
.53188 .33165 Mdot
.34331 .33807 Mdot
.77739 .52052 Mdot
.78608 .41542 Mdot
.82236 .3476 Mdot
.33165 .32521 Mdot
.31676 .45469 Mdot
.33276 .70475 Mdot
.3599 .34196 Mdot
.35108 .3624 Mdot
.35596 .3992 Mdot
.74145 .36159 Mdot
.66719 .45276 Mdot
.52887 .65667 Mdot
.8101 .49325 Mdot
.52393 .61991 Mdot
.28742 .57194 Mdot
.54183 .30372 Mdot
.67481 .48492 Mdot
.43238 .39632 Mdot
.54307 .60555 Mdot
.54492 .65913 Mdot
.44567 .35999 Mdot
.49683 .53042 Mdot
.18206 .51725 Mdot
.51107 .61957 Mdot
.36994 .36169 Mdot
.63203 .49226 Mdot
.49649 .5114 Mdot
.72906 .68873 Mdot
.54466 .28977 Mdot
.46689 .49795 Mdot
.49365 .50767 Mdot
.46273 .67333 Mdot
.68674 .49664 Mdot
.66118 .44458 Mdot
.30717 .49317 Mdot
.76851 .41747 Mdot
.54558 .2885 Mdot
.69829 .34597 Mdot
.50583 .66944 Mdot
.57319 .32559 Mdot
.37378 .49005 Mdot
.53973 .64919 Mdot
.44486 .52538 Mdot
.73143 .55377 Mdot
.50122 .58912 Mdot
.60374 .72731 Mdot
.54016 .3137 Mdot
.24995 .61184 Mdot
.50888 .69837 Mdot
.37281 .32571 Mdot
.66063 .46463 Mdot
.7083 .49534 Mdot
.33916 .45478 Mdot
.38348 .42066 Mdot
.8284 .66293 Mdot
.67256 .48407 Mdot
.5236 .6769 Mdot
.52939 .32219 Mdot
.4673 .50385 Mdot
.50799 .53186 Mdot
.44852 .4827 Mdot
.69527 .44724 Mdot
.50073 .51631 Mdot
.73953 .39165 Mdot
.34698 .64567 Mdot
.63374 .74886 Mdot
.55009 .30795 Mdot
.32163 .45455 Mdot
.57135 .67698 Mdot
.31905 .34073 Mdot
.49463 .64717 Mdot
.28616 .57098 Mdot
.71947 .49589 Mdot
.32591 .45567 Mdot
.54389 .66845 Mdot
.51856 .54882 Mdot
.383 .69381 Mdot
.32521 .42838 Mdot
.51379 .55311 Mdot
.50505 .60029 Mdot
.65842 .45914 Mdot
.48346 .50781 Mdot
.69506 .45394 Mdot
.54726 .66211 Mdot
.27763 .5311 Mdot
.66332 .48257 Mdot
.63663 .2605 Mdot
.30939 .5055 Mdot
.55267 .28229 Mdot
.48845 .5985 Mdot
.55549 .63232 Mdot
.63015 .76059 Mdot
.4645 .49424 Mdot
.58966 .22213 Mdot
.37578 .32315 Mdot
.17042 .51878 Mdot
.38125 .38599 Mdot
.46931 .3151 Mdot
.58116 .38997 Mdot
.49219 .58616 Mdot
.7744 .5228 Mdot
.58007 .76525 Mdot
.5691 .29992 Mdot
.6062 .76426 Mdot
.51855 .67993 Mdot
.54859 .63067 Mdot
.37628 .33128 Mdot
.56455 .34849 Mdot
.52893 .73232 Mdot
.33226 .64924 Mdot
.32369 .43885 Mdot
.68303 .46301 Mdot
.51374 .66696 Mdot
.72261 .39778 Mdot
.37402 .31017 Mdot
.61889 .55406 Mdot
.52141 .6343 Mdot
.49638 .52982 Mdot
.56531 .34426 Mdot
.53715 .29394 Mdot
.38668 .32939 Mdot
.38498 .32163 Mdot
.55533 .63853 Mdot
.53264 .34685 Mdot
.49681 .67249 Mdot
.33456 .66922 Mdot
.5052 .54549 Mdot
.32557 .48052 Mdot
.5021 .65995 Mdot
.7258 .51623 Mdot
.3665 .81016 Mdot
.53905 .60448 Mdot
.64661 .47499 Mdot
.36981 .3383 Mdot
.35204 .35727 Mdot
.67343 .44008 Mdot
.35074 .35498 Mdot
.64159 .57633 Mdot
.74443 .68923 Mdot
.32397 .47557 Mdot
.62542 .64353 Mdot
.31013 .45474 Mdot
.4669 .49603 Mdot
.53425 .64185 Mdot
.44927 .18442 Mdot
.33188 .32367 Mdot
.38331 .52338 Mdot
.53716 .30431 Mdot
.46402 .48821 Mdot
.50651 .70618 Mdot
.34591 .49983 Mdot
.35313 .34079 Mdot
.47185 .48227 Mdot
.53126 .61899 Mdot
.66971 .48855 Mdot
.48952 .61926 Mdot
.47843 .49373 Mdot
.47826 .50131 Mdot
.52064 .55922 Mdot
.55855 .28877 Mdot
.70196 .47729 Mdot
.53824 .24374 Mdot
.33842 .32347 Mdot
.52251 .70141 Mdot
.52713 .6783 Mdot
.71887 .47098 Mdot
.51157 .6273 Mdot
.53469 .34922 Mdot
.77855 .26083 Mdot
.30678 .48406 Mdot
.46192 .49603 Mdot
.65244 .30194 Mdot
.5212 .56026 Mdot
.50157 .60513 Mdot
.42316 .67392 Mdot
.63005 .55141 Mdot
.55495 .28281 Mdot
.55966 .60878 Mdot
.35856 .379 Mdot
.31119 .48349 Mdot
.5231 .30783 Mdot
.49985 .6959 Mdot
.51175 .63975 Mdot
.32449 .45615 Mdot
.4446 .3743 Mdot
.29881 .45912 Mdot
.55235 .33759 Mdot
.45939 .50002 Mdot
.39372 .60445 Mdot
.52687 .64629 Mdot
.4909 .51977 Mdot
.69054 .47585 Mdot
.55375 .3409 Mdot
.71732 .57157 Mdot
.49048 .505 Mdot
.58477 .28286 Mdot
.53953 .29218 Mdot
.5468 .62183 Mdot
.65112 .46929 Mdot
.73998 .46029 Mdot
.68648 .47678 Mdot
.23069 .59844 Mdot
.54198 .2376 Mdot
.37142 .34174 Mdot
.53829 .32005 Mdot
.36042 .31246 Mdot
.3099 .4468 Mdot
.31821 .68646 Mdot
.37889 .31173 Mdot
.65808 .43751 Mdot
.36123 .30872 Mdot
.49647 .66995 Mdot
.548 .28212 Mdot
.35365 .29315 Mdot
.50482 .67258 Mdot
.54465 .70105 Mdot
.48964 .51237 Mdot
.3397 .43519 Mdot
.33909 .6512 Mdot
.52411 .62638 Mdot
.48768 .51876 Mdot
.52772 .63601 Mdot
.53327 .34822 Mdot
.34943 .59628 Mdot
.53004 .70076 Mdot
.33159 .32163 Mdot
.67085 .2497 Mdot
.34714 .36949 Mdot
.56419 .50823 Mdot
.5429 .6372 Mdot
.52969 .64577 Mdot
.51416 .70748 Mdot
.78524 .52874 Mdot
.55975 .27421 Mdot
.54581 .6005 Mdot
.37992 .37727 Mdot
.67643 .45084 Mdot
.65148 .45829 Mdot
.415 .63181 Mdot
.48615 .51338 Mdot
.53008 .34914 Mdot
.53094 .64725 Mdot
.47721 .49646 Mdot
.32449 .63359 Mdot
.76418 .39309 Mdot
.36359 .40323 Mdot
.3424 .34678 Mdot
.69932 .488 Mdot
.36586 .37327 Mdot
.50257 .69976 Mdot
.50009 .51698 Mdot
.55052 .23802 Mdot
.51764 .356 Mdot
.31165 .48305 Mdot
.54643 .64061 Mdot
.30109 .70534 Mdot
.37355 .37444 Mdot
.38996 .33466 Mdot
.49784 .6749 Mdot
.70039 .51067 Mdot
.31908 .77154 Mdot
.55957 .34126 Mdot
.66309 .68084 Mdot
.80235 .57915 Mdot
.49948 .78118 Mdot
.53809 .33066 Mdot
.44296 .52801 Mdot
.38607 .31379 Mdot
.22521 .49463 Mdot
.6733 .45397 Mdot
.31373 .48625 Mdot
.50369 .66987 Mdot
.65906 .43747 Mdot
.33234 .33325 Mdot
.71845 .45314 Mdot
.50205 .53641 Mdot
.54503 .2816 Mdot
.35531 .35553 Mdot
.52019 .34509 Mdot
.65376 .43096 Mdot
.30888 .46082 Mdot
.27021 .58569 Mdot
.6443 .68267 Mdot
.73614 .5502 Mdot
.50973 .71321 Mdot
.2777 .48499 Mdot
.51324 .7137 Mdot
.71754 .49257 Mdot
.52125 .63094 Mdot
.55214 .6885 Mdot
.393 .32922 Mdot
.55014 .62339 Mdot
.5044 .66585 Mdot
.72585 .69339 Mdot
.54258 .64991 Mdot
.55244 .65071 Mdot
.5471 .62001 Mdot
.64968 .45353 Mdot
.52763 .61541 Mdot
.70243 .48099 Mdot
.7269 .38481 Mdot
.33875 .32384 Mdot
.30683 .45209 Mdot
.30706 .45328 Mdot
.29444 .55922 Mdot
.29955 .7022 Mdot
.80577 .49821 Mdot
.6847 .45062 Mdot
.54505 .29279 Mdot
.49861 .67261 Mdot
.27868 .7213 Mdot
.27958 .53493 Mdot
.36748 .2942 Mdot
.36222 .30017 Mdot
.5202 .69047 Mdot
.73095 .7578 Mdot
.50531 .6247 Mdot
.33762 .62452 Mdot
.5152 .66327 Mdot
.52279 .61 Mdot
.37728 .38505 Mdot
.27489 .63202 Mdot
.51484 .71196 Mdot
.6782 .49718 Mdot
.31567 .48568 Mdot
.48913 .51452 Mdot
.28356 .54291 Mdot
.79533 .6103 Mdot
.68915 .52131 Mdot
.51651 .70908 Mdot
.3827 .36679 Mdot
.69057 .4387 Mdot
.34731 .63085 Mdot
.54686 .34851 Mdot
.29923 .63284 Mdot
.61687 .73039 Mdot
.56496 .33593 Mdot
.30907 .47759 Mdot
.33158 .28945 Mdot
.55359 .63205 Mdot
.3777 .35419 Mdot
.52949 .59369 Mdot
.32095 .62806 Mdot
.32364 .47823 Mdot
.65748 .49921 Mdot
.5611 .31436 Mdot
.66001 .43873 Mdot
.6154 .53627 Mdot
.27721 .5333 Mdot
.15669 .49302 Mdot
.34006 .35678 Mdot
.59891 .60086 Mdot
.67881 .48243 Mdot
.55617 .65183 Mdot
.82016 .34653 Mdot
.69518 .47097 Mdot
.66431 .48547 Mdot
.31723 .60874 Mdot
.27053 .63927 Mdot
.5266 .59447 Mdot
.69843 .43699 Mdot
.33092 .29234 Mdot
.32996 .47258 Mdot
.51184 .68112 Mdot
.49587 .51451 Mdot
.65609 .45525 Mdot
.34918 .33932 Mdot
.27707 .61982 Mdot
.36638 .36226 Mdot
.66506 .45871 Mdot
.34509 .30373 Mdot
.55086 .2482 Mdot
.3774 .30987 Mdot
.50402 .64426 Mdot
.53006 .64728 Mdot
.73739 .44645 Mdot
.69651 .44254 Mdot
.50104 .60556 Mdot
.52383 .6218 Mdot
.67481 .47725 Mdot
.32635 .30584 Mdot
.649 .53751 Mdot
.50522 .60619 Mdot
.53119 .65224 Mdot
.30411 .48063 Mdot
.36113 .65867 Mdot
.3565 .6207 Mdot
.497 .66129 Mdot
.31305 .45745 Mdot
.68004 .49138 Mdot
.53155 .63603 Mdot
.27259 .6286 Mdot
.35135 .28225 Mdot
.49757 .68212 Mdot
.47453 .51674 Mdot
.50851 .7154 Mdot
.40401 .79962 Mdot
.51312 .70621 Mdot
.66875 .46459 Mdot
.66393 .47158 Mdot
.33067 .27982 Mdot
.67557 .4635 Mdot
.46226 .49528 Mdot
.53713 .29832 Mdot
.65176 .70642 Mdot
.461 .48835 Mdot
.51535 .56075 Mdot
.34235 .51424 Mdot
.49398 .50538 Mdot
.5075 .51201 Mdot
.36744 .40571 Mdot
.4821 .52986 Mdot
.69062 .48129 Mdot
.6284 .42687 Mdot
.52899 .57709 Mdot
.53452 .3509 Mdot
.49582 .50998 Mdot
.49629 .68048 Mdot
.5592 .67672 Mdot
.61787 .50779 Mdot
.55055 .34826 Mdot
.5798 .6187 Mdot
.51142 .68082 Mdot
.62878 .54782 Mdot
.51384 .66914 Mdot
.33724 .44333 Mdot
.69838 .45951 Mdot
.37247 .36874 Mdot
.32878 .47969 Mdot
.5145 .54681 Mdot
.33391 .48667 Mdot
.37677 .34731 Mdot
.55448 .30158 Mdot
.50573 .64254 Mdot
.31969 .43264 Mdot
.31267 .44652 Mdot
.48637 .62037 Mdot
.66318 .4738 Mdot
.56735 .61021 Mdot
.53555 .63801 Mdot
.51408 .70814 Mdot
.67006 .44026 Mdot
.5395 .17584 Mdot
.55217 .63823 Mdot
.44219 .52465 Mdot
.71119 .49665 Mdot
.47432 .49315 Mdot
.3768 .36733 Mdot
.50684 .58328 Mdot
.52402 .3189 Mdot
.53552 .30188 Mdot
.33261 .31778 Mdot
.66035 .44706 Mdot
.35174 .35315 Mdot
.54904 .61148 Mdot
.4971 .51081 Mdot
.51429 .68002 Mdot
.45309 .34054 Mdot
.61367 .23831 Mdot
.71578 .46952 Mdot
.33772 .33214 Mdot
.31537 .65562 Mdot
.55501 .28051 Mdot
.36059 .39567 Mdot
.68693 .49797 Mdot
.68865 .43334 Mdot
.67519 .44129 Mdot
.31802 .44588 Mdot
.35986 .35606 Mdot
.66963 .41855 Mdot
.6604 .42137 Mdot
.4874 .66133 Mdot
.51031 .68149 Mdot
.68841 .49083 Mdot
.32744 .35449 Mdot
.31094 .47519 Mdot
.37264 .37906 Mdot
.32986 .78222 Mdot
.55828 .3405 Mdot
.7286 .69055 Mdot
.49443 .65296 Mdot
.89151 .58829 Mdot
.50642 .62376 Mdot
.51917 .67441 Mdot
.67165 .42019 Mdot
.29907 .48113 Mdot
.3296 .4691 Mdot
.67659 .48188 Mdot
.71885 .44448 Mdot
.34024 .45275 Mdot
.37678 .62579 Mdot
.37208 .78727 Mdot
.33337 .63536 Mdot
.71713 .45787 Mdot
.63893 .70939 Mdot
.54721 .31892 Mdot
.71194 .50022 Mdot
.5569 .25675 Mdot
.34305 .30086 Mdot
.37149 .30358 Mdot
.55493 .29422 Mdot
.55243 .64209 Mdot
.37009 .38422 Mdot
.51655 .72137 Mdot
.49468 .27993 Mdot
.46631 .53198 Mdot
.20266 .63544 Mdot
.50915 .63286 Mdot
.56172 .48794 Mdot
.75049 .35623 Mdot
.4897 .62716 Mdot
.75204 .65395 Mdot
.31671 .49043 Mdot
.72225 .48826 Mdot
.55659 .34853 Mdot
.81333 .48963 Mdot
.52813 .64619 Mdot
.70681 .44408 Mdot
.56314 .32019 Mdot
.60116 .23327 Mdot
.43766 .53223 Mdot
.4867 .65004 Mdot
.81568 .32846 Mdot
.64392 .47751 Mdot
.374 .36723 Mdot
.66786 .65475 Mdot
.71723 .43748 Mdot
.43262 .54282 Mdot
.3293 .30674 Mdot
.38552 .67323 Mdot
.71261 .44441 Mdot
.29682 .46722 Mdot
.68616 .45985 Mdot
.34205 .46976 Mdot
.67843 .41761 Mdot
.34121 .31823 Mdot
.54605 .64895 Mdot
.33984 .32199 Mdot
.34652 .4676 Mdot
.33768 .34838 Mdot
.55753 .34732 Mdot
.48804 .5346 Mdot
.54297 .30181 Mdot
.32428 .6975 Mdot
.72382 .58415 Mdot
.55578 .32035 Mdot
.42691 .66125 Mdot
.50883 .64398 Mdot
.71362 .43008 Mdot
.36923 .36976 Mdot
.39646 .34655 Mdot
.33681 .65261 Mdot
.66434 .45296 Mdot
.34625 .33232 Mdot
.64083 .69362 Mdot
.56971 .21847 Mdot
.53849 .70648 Mdot
.33747 .25646 Mdot
.67166 .47272 Mdot
.39475 .35329 Mdot
.34306 .62643 Mdot
.69398 .4317 Mdot
.35901 .29483 Mdot
.5588 .32577 Mdot
.52434 .31761 Mdot
.50565 .63531 Mdot
.53688 .36081 Mdot
.38304 .31123 Mdot
.61721 .56866 Mdot
.6763 .48724 Mdot
.6212 .24282 Mdot
.30564 .47285 Mdot
.36301 .37035 Mdot
.51034 .54354 Mdot
.65735 .43142 Mdot
.35909 .31033 Mdot
.81292 .67945 Mdot
.34686 .81934 Mdot
.34751 .33387 Mdot
.69695 .45833 Mdot
.69248 .44406 Mdot
.50923 .59573 Mdot
.33263 .65231 Mdot
.3529 .33827 Mdot
.44371 .18512 Mdot
.35958 .71059 Mdot
.4857 .52754 Mdot
.15801 .43001 Mdot
.52127 .70917 Mdot
.50801 .71028 Mdot
.54877 .34286 Mdot
.54351 .66061 Mdot
.71913 .4468 Mdot
.50693 .62285 Mdot
.52085 .32677 Mdot
.33353 .31616 Mdot
.52975 .64161 Mdot
.30995 .48225 Mdot
.53109 .33835 Mdot
.52686 .33831 Mdot
.34792 .30379 Mdot
.66158 .44673 Mdot
.82331 .47751 Mdot
.36427 .36256 Mdot
.50273 .70555 Mdot
.48807 .52218 Mdot
.54784 .62121 Mdot
.75285 .43302 Mdot
.71661 .49038 Mdot
.36767 .37278 Mdot
.48667 .58746 Mdot
.53451 .32239 Mdot
.39028 .31969 Mdot
.52226 .71045 Mdot
.35096 .28963 Mdot
.43452 .47915 Mdot
.27753 .28497 Mdot
.64379 .43742 Mdot
.42912 .47572 Mdot
.68693 .43242 Mdot
.48189 .5272 Mdot
.21944 .55708 Mdot
.30947 .47479 Mdot
.35595 .38084 Mdot
.63159 .25717 Mdot
.33907 .32933 Mdot
.54112 .65192 Mdot
.51239 .63609 Mdot
.37897 .33332 Mdot
.31042 .45844 Mdot
.39564 .49846 Mdot
.30221 .44866 Mdot
.70042 .45381 Mdot
.40609 .63735 Mdot
.28607 .76265 Mdot
.37782 .30002 Mdot
.55058 .28975 Mdot
.74545 .49347 Mdot
.51521 .55932 Mdot
.5556 .34727 Mdot
.53011 .3412 Mdot
.34376 .47891 Mdot
.34931 .35977 Mdot
.66665 .50054 Mdot
.53626 .28894 Mdot
.70549 .43186 Mdot
.27291 .61659 Mdot
.48633 .49807 Mdot
.59644 .65958 Mdot
.51842 .54687 Mdot
.34406 .64777 Mdot
.53983 .28483 Mdot
.51373 .64669 Mdot
.57879 .65559 Mdot
.55982 .32915 Mdot
.34206 .48439 Mdot
.47554 .53999 Mdot
.34604 .32892 Mdot
.83405 .38913 Mdot
.50282 .6476 Mdot
.54073 .63935 Mdot
.56039 .33409 Mdot
.77376 .63513 Mdot
.68203 .49616 Mdot
.65715 .46236 Mdot
.36893 .34566 Mdot
.32552 .60733 Mdot
.52607 .61682 Mdot
.50635 .64519 Mdot
.37996 .32948 Mdot
.4803 .50764 Mdot
.15231 .47301 Mdot
.52722 .65531 Mdot
.54188 .31832 Mdot
.4494 .52289 Mdot
.56698 .29056 Mdot
.56695 .6419 Mdot
.53829 .65826 Mdot
.49 .68359 Mdot
.51974 .71283 Mdot
.54588 .30409 Mdot
.51559 .55104 Mdot
.52306 .57091 Mdot
.69211 .47818 Mdot
.54141 .6855 Mdot
.36146 .71029 Mdot
.52608 .6517 Mdot
.31302 .48822 Mdot
.35384 .61759 Mdot
.52117 .70343 Mdot
.53799 .69022 Mdot
.35642 .71145 Mdot
.53905 .67651 Mdot
.56242 .33093 Mdot
.68647 .44378 Mdot
.53319 .32351 Mdot
.55473 .28907 Mdot
.35706 .30745 Mdot
.3322 .49638 Mdot
.53559 .59928 Mdot
.33251 .44476 Mdot
.52405 .59966 Mdot
.56737 .6049 Mdot
.33864 .67378 Mdot
.33705 .62539 Mdot
.33189 .43023 Mdot
.50613 .64875 Mdot
.37362 .34695 Mdot
.35869 .37384 Mdot
.42361 .58083 Mdot
.49687 .57844 Mdot
.54598 .36061 Mdot
.5574 .31228 Mdot
.41344 .40418 Mdot
.2708 .28109 Mdot
.32795 .43449 Mdot
.39911 .49471 Mdot
.52534 .71297 Mdot
.54566 .63237 Mdot
.50742 .55371 Mdot
.3651 .31741 Mdot
.48321 .53182 Mdot
.34774 .38416 Mdot
.5679 .33565 Mdot
.53638 .33662 Mdot
.50659 .63794 Mdot
.70046 .78432 Mdot
.70576 .46846 Mdot
.69121 .44311 Mdot
.52029 .32397 Mdot
.34819 .37151 Mdot
.50521 .53682 Mdot
.84948 .4304 Mdot
.71386 .49006 Mdot
.30328 .45592 Mdot
.53782 .68244 Mdot
.34098 .30491 Mdot
.69949 .47996 Mdot
.3187 .43392 Mdot
.55299 .66999 Mdot
.32921 .31525 Mdot
.51661 .64816 Mdot
.62216 .61591 Mdot
.6866 .48454 Mdot
.35197 .67391 Mdot
.64716 .4502 Mdot
.54497 .30606 Mdot
.54659 .28559 Mdot
.53782 .65549 Mdot
.84884 .4199 Mdot
.64117 .49995 Mdot
.52281 .29694 Mdot
.30539 .49118 Mdot
.49313 .54114 Mdot
.33333 .49329 Mdot
.37496 .33238 Mdot
.30941 .47761 Mdot
.35798 .30947 Mdot
.32527 .29364 Mdot
.65236 .4896 Mdot
.32496 .45653 Mdot
.74472 .6374 Mdot
.50117 .51907 Mdot
.31999 .50523 Mdot
.51751 .69541 Mdot
.51402 .60105 Mdot
.35388 .32988 Mdot
.32765 .44159 Mdot
.50256 .58326 Mdot
.64671 .30262 Mdot
.55341 .28413 Mdot
.55839 .34725 Mdot
.50277 .53622 Mdot
.39295 .34572 Mdot
.65193 .48834 Mdot
.31504 .66311 Mdot
.64871 .49412 Mdot
.50508 .6482 Mdot
.53783 .60147 Mdot
.6453 .44298 Mdot
.64872 .4813 Mdot
.53583 .66094 Mdot
.67685 .72877 Mdot
.51151 .54431 Mdot
.52467 .31301 Mdot
.70222 .45571 Mdot
.70059 .44475 Mdot
.38211 .31121 Mdot
.65529 .4599 Mdot
.58502 .66509 Mdot
.56497 .34006 Mdot
.52551 .57283 Mdot
.53611 .31865 Mdot
.28337 .44653 Mdot
.351 .32188 Mdot
.61765 .2489 Mdot
.65617 .46526 Mdot
.4971 .61331 Mdot
.65513 .47078 Mdot
.31218 .49251 Mdot
.71248 .4503 Mdot
.73802 .48344 Mdot
.50375 .6678 Mdot
.51368 .55159 Mdot
.47234 .49805 Mdot
.33839 .6484 Mdot
.69958 .47189 Mdot
.54366 .60859 Mdot
.50984 .61606 Mdot
.52086 .62229 Mdot
.33175 .66701 Mdot
.64973 .45568 Mdot
.79357 .61311 Mdot
.64258 .42823 Mdot
.69054 .48405 Mdot
.40211 .83235 Mdot
.46863 .49445 Mdot
.49891 .55085 Mdot
.50158 .35347 Mdot
.52968 .65545 Mdot
.34752 .347 Mdot
.49834 .69862 Mdot
.50851 .54978 Mdot
.52748 .69811 Mdot
.33738 .46544 Mdot
.55633 .63117 Mdot
.48114 .51612 Mdot
.36439 .3659 Mdot
.48971 .63296 Mdot
.53355 .64652 Mdot
.48049 .50575 Mdot
.65613 .47743 Mdot
.67474 .43538 Mdot
.63865 .48228 Mdot
.34413 .46705 Mdot
.54975 .32632 Mdot
.49969 .69981 Mdot
.37088 .34624 Mdot
.34597 .34635 Mdot
.6534 .44164 Mdot
.38626 .34147 Mdot
.53889 .33925 Mdot
.52228 .67446 Mdot
.54499 .30456 Mdot
.33871 .46819 Mdot
.69926 .46045 Mdot
.50523 .70175 Mdot
.48422 .64248 Mdot
.66403 .47182 Mdot
.51276 .53956 Mdot
.31137 .49488 Mdot
.38069 .3236 Mdot
.71278 .4755 Mdot
.53564 .29996 Mdot
.38053 .311 Mdot
.49231 .6227 Mdot
.5111 .84607 Mdot
.54285 .66093 Mdot
.52312 .619 Mdot
.62695 .48635 Mdot
.56471 .6561 Mdot
.33826 .32321 Mdot
.6519 .46033 Mdot
.51097 .60342 Mdot
.34054 .71789 Mdot
.32547 .42054 Mdot
.38234 .30178 Mdot
.52861 .68248 Mdot
.62513 .76142 Mdot
.49797 .62081 Mdot
.64164 .26319 Mdot
.33934 .67352 Mdot
.57336 .25897 Mdot
.59561 .65186 Mdot
.51971 .30272 Mdot
.48541 .51585 Mdot
.35154 .30786 Mdot
.71049 .68667 Mdot
.53584 .66601 Mdot
.72228 .5599 Mdot
.50164 .69729 Mdot
.536 .33144 Mdot
.76186 .63656 Mdot
.3847 .36375 Mdot
.1719 .51012 Mdot
.55219 .66635 Mdot
.6926 .49569 Mdot
.34076 .39107 Mdot
.49784 .54827 Mdot
.5128 .5572 Mdot
.33392 .43942 Mdot
.41853 .39136 Mdot
.57667 .62586 Mdot
.53398 .3201 Mdot
.54327 .62523 Mdot
.48123 .65988 Mdot
.57012 .20275 Mdot
.68346 .47737 Mdot
.56076 .30467 Mdot
.26663 .29551 Mdot
.51035 .64846 Mdot
.6858 .43352 Mdot
.67372 .45395 Mdot
.33387 .45045 Mdot
.58065 .27488 Mdot
.43121 .37534 Mdot
.68755 .77722 Mdot
.58851 .60923 Mdot
.36771 .3177 Mdot
.45724 .47751 Mdot
.49701 .69737 Mdot
.27855 .53304 Mdot
.54865 .28837 Mdot
.5431 .64154 Mdot
.74562 .54327 Mdot
.67382 .46967 Mdot
.51934 .65484 Mdot
.31311 .47836 Mdot
.83391 .4713 Mdot
.62945 .70425 Mdot
.64242 .74628 Mdot
.33085 .29285 Mdot
.53216 .59681 Mdot
.58458 .66377 Mdot
.4753 .49519 Mdot
.56767 .64008 Mdot
.37172 .3676 Mdot
.44008 .4745 Mdot
.31531 .47246 Mdot
.70238 .4776 Mdot
.48849 .51918 Mdot
.50179 .697 Mdot
.52436 .59065 Mdot
.30479 .48821 Mdot
.48785 .6751 Mdot
.67408 .66585 Mdot
.45808 .48166 Mdot
.37642 .31047 Mdot
.71816 .46778 Mdot
.53438 .59976 Mdot
.49552 .54359 Mdot
.51226 .67605 Mdot
.71781 .51973 Mdot
.54424 .63779 Mdot
.62566 .28623 Mdot
.6605 .46358 Mdot
.52982 .31105 Mdot
.52297 .71117 Mdot
.52026 .64594 Mdot
.42521 .47713 Mdot
.50538 .53407 Mdot
.54041 .68384 Mdot
.67064 .43348 Mdot
.70474 .47363 Mdot
.69185 .49522 Mdot
.3693 .29824 Mdot
.33051 .63976 Mdot
.54079 .30679 Mdot
.50725 .5541 Mdot
.53595 .2891 Mdot
.54159 .75918 Mdot
.34062 .47785 Mdot
.60295 .2419 Mdot
.52523 .67291 Mdot
.66872 .44699 Mdot
.35777 .7773 Mdot
.65123 .44516 Mdot
.47997 .33559 Mdot
.54607 .28858 Mdot
.69519 .46787 Mdot
.53427 .67873 Mdot
.34834 .64082 Mdot
.64381 .75784 Mdot
.55303 .28076 Mdot
.50355 .55685 Mdot
.26956 .45607 Mdot
.33957 .291 Mdot
.38569 .8238 Mdot
.52945 .29724 Mdot
.7517 .35621 Mdot
.50565 .60595 Mdot
.65974 .47725 Mdot
.55135 .31019 Mdot
.53177 .34458 Mdot
.38662 .36149 Mdot
.48716 .65642 Mdot
.51999 .64833 Mdot
.47419 .51578 Mdot
.54922 .29785 Mdot
.49135 .58137 Mdot
.48654 .64027 Mdot
.46494 .30904 Mdot
.70332 .4954 Mdot
.53575 .17297 Mdot
.44094 .68344 Mdot
.74461 .54444 Mdot
.49996 .18828 Mdot
.70825 .48199 Mdot
.55323 .64617 Mdot
.50541 .54239 Mdot
.38354 .32785 Mdot
.53135 .67596 Mdot
.33813 .3353 Mdot
.54201 .3316 Mdot
.63424 .30059 Mdot
.43251 .67776 Mdot
.48234 .30235 Mdot
.54421 .65387 Mdot
.63365 .69693 Mdot
.3202 .46355 Mdot
.55985 .34747 Mdot
.6636 .49286 Mdot
.54683 .6162 Mdot
.38903 .34892 Mdot
.34499 .29094 Mdot
.67779 .47036 Mdot
.73382 .36216 Mdot
.62314 .25088 Mdot
.51105 .53745 Mdot
.3834 .35246 Mdot
.50015 .54588 Mdot
.61901 .75258 Mdot
.52915 .29161 Mdot
.31624 .47184 Mdot
.35221 .3006 Mdot
.53183 .35193 Mdot
.51348 .60068 Mdot
.68532 .46903 Mdot
.6398 .4636 Mdot
.42572 .56806 Mdot
.34596 .3342 Mdot
.33256 .48201 Mdot
.43266 .55667 Mdot
.40962 .62162 Mdot
.3233 .4806 Mdot
.37002 .29681 Mdot
.70875 .45495 Mdot
.66655 .45939 Mdot
.68347 .44483 Mdot
.72944 .68835 Mdot
.7171 .48946 Mdot
.26862 .5594 Mdot
.56766 .64148 Mdot
.64351 .70284 Mdot
.52288 .60686 Mdot
.55634 .3484 Mdot
.68108 .48554 Mdot
.34088 .67446 Mdot
.52183 .71484 Mdot
.64757 .75748 Mdot
.5284 .6261 Mdot
.44621 .52288 Mdot
.53057 .6545 Mdot
.63307 .62067 Mdot
.72736 .48169 Mdot
.55507 .6622 Mdot
.56948 .3119 Mdot
.32763 .49236 Mdot
.69269 .42131 Mdot
.55071 .65858 Mdot
.71237 .39097 Mdot
.51668 .69578 Mdot
.63225 .29633 Mdot
.4304 .55074 Mdot
.37074 .43989 Mdot
.53615 .61513 Mdot
.36016 .39101 Mdot
.52269 .73096 Mdot
.63866 .71627 Mdot
.5494 .2818 Mdot
.63735 .69576 Mdot
.36191 .38525 Mdot
.76398 .63501 Mdot
.50927 .53315 Mdot
.31253 .46977 Mdot
.45137 .47526 Mdot
.52649 .30685 Mdot
.52999 .67051 Mdot
.55493 .64915 Mdot
.46848 .53799 Mdot
.61006 .754 Mdot
.48297 .50379 Mdot
.32995 .42978 Mdot
.62409 .72293 Mdot
.54196 .68066 Mdot
.39062 .31116 Mdot
.66413 .44023 Mdot
.75598 .63132 Mdot
.77075 .61895 Mdot
.48858 .6295 Mdot
.69321 .47091 Mdot
.66039 .44721 Mdot
.29777 .74828 Mdot
.31689 .45869 Mdot
.54094 .63364 Mdot
.42898 .47098 Mdot
.5005 .70006 Mdot
.54257 .32603 Mdot
.53738 .70242 Mdot
.34993 .32306 Mdot
.34804 .62693 Mdot
.36595 .29465 Mdot
.51951 .62285 Mdot
.68666 .45826 Mdot
.5609 .28779 Mdot
.32439 .29186 Mdot
.5804 .27512 Mdot
.26749 .5608 Mdot
.4094 .39901 Mdot
.3266 .43467 Mdot
.34023 .48416 Mdot
.55941 .3476 Mdot
.5243 .68002 Mdot
.33033 .66155 Mdot
.47703 .72073 Mdot
.52654 .66085 Mdot
.54919 .65336 Mdot
.50686 .34532 Mdot
.54253 .2907 Mdot
.34247 .3071 Mdot
.53495 .66283 Mdot
.55023 .6145 Mdot
.69079 .46166 Mdot
.32114 .43815 Mdot
.36914 .31003 Mdot
.34307 .45494 Mdot
.37137 .35845 Mdot
.40546 .80039 Mdot
.49108 .50359 Mdot
.33632 .4837 Mdot
.52458 .30098 Mdot
.67901 .44201 Mdot
.4654 .49324 Mdot
.36879 .33173 Mdot
.38625 .34657 Mdot
.51635 .59451 Mdot
.69827 .47989 Mdot
.65688 .46364 Mdot
.34137 .45362 Mdot
.55687 .3145 Mdot
.52113 .72378 Mdot
.51837 .55054 Mdot
.31833 .27457 Mdot
.38923 .33816 Mdot
.6309 .7163 Mdot
.63103 .45473 Mdot
.51058 .67002 Mdot
.68003 .43486 Mdot
.52599 .63938 Mdot
.74695 .47244 Mdot
.64354 .47424 Mdot
.55945 .6704 Mdot
.47453 .67781 Mdot
.36306 .31545 Mdot
.24755 .71037 Mdot
.5527 .69106 Mdot
.53311 .26338 Mdot
.49438 .69166 Mdot
.15547 .49411 Mdot
.34799 .76989 Mdot
.52072 .6875 Mdot
.55507 .63072 Mdot
.65184 .80518 Mdot
.49727 .62511 Mdot
.48087 .52186 Mdot
.50806 .53 Mdot
.68648 .43441 Mdot
.43067 .4746 Mdot
.3407 .64989 Mdot
.32116 .45225 Mdot
.36948 .34461 Mdot
.27247 .63672 Mdot
.34249 .4711 Mdot
.6696 .4678 Mdot
.52074 .7244 Mdot
.62945 .48295 Mdot
.3832 .38337 Mdot
.49275 .52116 Mdot
.53907 .33108 Mdot
.334 .65751 Mdot
.38842 .354 Mdot
.53769 .29736 Mdot
.50243 .61926 Mdot
.33078 .35537 Mdot
.56906 .3014 Mdot
.25567 .72186 Mdot
.54513 .34653 Mdot
.53276 .29935 Mdot
.33062 .6476 Mdot
.32121 .45206 Mdot
.44308 .47755 Mdot
.5485 .58688 Mdot
.56409 .29875 Mdot
.18737 .5285 Mdot
.39073 .35327 Mdot
.31748 .6326 Mdot
.72699 .48387 Mdot
.4941 .50872 Mdot
.54765 .65093 Mdot
.55195 .34234 Mdot
.48472 .58587 Mdot
.42397 .47723 Mdot
.52945 .3325 Mdot
.5083 .71918 Mdot
.3307 .60783 Mdot
.49401 .53932 Mdot
.46801 .49619 Mdot
.31287 .43878 Mdot
.28278 .32847 Mdot
.66324 .4486 Mdot
.30239 .45999 Mdot
.33744 .6934 Mdot
.53003 .62385 Mdot
.54704 .30539 Mdot
.48937 .51982 Mdot
.53419 .30493 Mdot
.3249 .46795 Mdot
.30939 .49505 Mdot
.69081 .47832 Mdot
.68588 .49533 Mdot
.45552 .49142 Mdot
.36126 .71572 Mdot
.49889 .68267 Mdot
.71504 .5734 Mdot
.64688 .47801 Mdot
.74979 .66684 Mdot
.32042 .44782 Mdot
.32178 .43951 Mdot
.59711 .72949 Mdot
.49845 .67027 Mdot
.44841 .52209 Mdot
.52221 .70318 Mdot
.19333 .50658 Mdot
.50465 .69986 Mdot
.383 .33287 Mdot
.53191 .70027 Mdot
.76948 .41196 Mdot
.50362 .59565 Mdot
.54431 .67378 Mdot
.35994 .34803 Mdot
.52679 .59721 Mdot
.35192 .32736 Mdot
.55047 .63818 Mdot
.41812 .34057 Mdot
.37048 .34651 Mdot
.28869 .49497 Mdot
.44868 .55452 Mdot
.47434 .51037 Mdot
.33341 .45584 Mdot
.33027 .43462 Mdot
.27699 .61457 Mdot
.70827 .4612 Mdot
.78103 .53703 Mdot
.53884 .68041 Mdot
.39167 .34822 Mdot
.54536 .33272 Mdot
.49099 .61664 Mdot
.51226 .62207 Mdot
.55254 .69105 Mdot
.69447 .47474 Mdot
.3904 .32232 Mdot
.33019 .46232 Mdot
.34636 .35675 Mdot
.4127 .33079 Mdot
.35406 .31998 Mdot
.46515 .67804 Mdot
.51551 .59907 Mdot
.58413 .66493 Mdot
.73563 .60346 Mdot
.35559 .5017 Mdot
.68216 .47052 Mdot
.48547 .51771 Mdot
.33742 .48766 Mdot
.35977 .60795 Mdot
.66965 .44143 Mdot
.38028 .33134 Mdot
.51646 .64766 Mdot
.48684 .49714 Mdot
.54889 .5877 Mdot
.71101 .43258 Mdot
.32852 .50491 Mdot
.36602 .33794 Mdot
.48796 .52935 Mdot
.33032 .63608 Mdot
.80333 .57978 Mdot
.3193 .69127 Mdot
.52239 .64254 Mdot
.34096 .45436 Mdot
.69986 .47949 Mdot
.45468 .52175 Mdot
.55731 .33333 Mdot
.33441 .65164 Mdot
.54463 .6564 Mdot
.47546 .3486 Mdot
.68502 .45808 Mdot
.30853 .46242 Mdot
.55076 .34378 Mdot
.31384 .46102 Mdot
.49351 .54599 Mdot
.63987 .43115 Mdot
.51249 .55724 Mdot
.51356 .70653 Mdot
.54527 .33054 Mdot
.66085 .45307 Mdot
.42208 .34548 Mdot
.45048 .49414 Mdot
.37845 .33381 Mdot
.36248 .61469 Mdot
.703 .47582 Mdot
.45904 .33732 Mdot
.34506 .3546 Mdot
.52384 .36286 Mdot
.36427 .64936 Mdot
.53649 .34038 Mdot
.54761 .6671 Mdot
.68835 .44808 Mdot
.55271 .28035 Mdot
.31257 .32909 Mdot
.68458 .74101 Mdot
.45128 .48452 Mdot
.50956 .64153 Mdot
.64884 .2624 Mdot
.7579 .37276 Mdot
.73971 .45567 Mdot
.52387 .30605 Mdot
.53893 .64521 Mdot
.51117 .53518 Mdot
.55041 .67139 Mdot
.56136 .29427 Mdot
.57142 .37174 Mdot
.36911 .37829 Mdot
.51342 .64857 Mdot
.30837 .4812 Mdot
.34724 .31835 Mdot
.33381 .29757 Mdot
.35291 .2994 Mdot
.66513 .49295 Mdot
.48568 .49981 Mdot
.50731 .52684 Mdot
.32764 .74855 Mdot
.52947 .30759 Mdot
.47465 .51063 Mdot
.55637 .63607 Mdot
.26961 .56363 Mdot
.67208 .4475 Mdot
.36211 .33563 Mdot
.5402 .63823 Mdot
.42646 .56258 Mdot
.48609 .51074 Mdot
.36163 .3585 Mdot
.64907 .48306 Mdot
.60612 .49045 Mdot
.52923 .6757 Mdot
.49254 .68321 Mdot
.66793 .47294 Mdot
.78602 .38804 Mdot
.3294 .63127 Mdot
.52704 .641 Mdot
.53286 .30267 Mdot
.7448 .30197 Mdot
.5053 .6158 Mdot
.66254 .50632 Mdot
.47902 .52676 Mdot
.65646 .41166 Mdot
.66671 .68009 Mdot
.48294 .61466 Mdot
.56153 .44639 Mdot
.3858 .52401 Mdot
.58037 .48556 Mdot
.21319 .50944 Mdot
.49078 .43119 Mdot
.27631 .74786 Mdot
.56019 .35124 Mdot
.62665 .63005 Mdot
.8033 .68658 Mdot
.7392 .35496 Mdot
.43648 .43509 Mdot
.59427 .35974 Mdot
.32429 .41383 Mdot
.15206 .45916 Mdot
.35049 .38812 Mdot
.21723 .50446 Mdot
.51246 .70444 Mdot
.77886 .38698 Mdot
.62987 .6446 Mdot
.38282 .41792 Mdot
.55807 .2444 Mdot
.43047 .55497 Mdot
.58391 .80911 Mdot
.4966 .28073 Mdot
.47355 .82731 Mdot
.75974 .53914 Mdot
.29517 .29023 Mdot
.38746 .63354 Mdot
.2606 .61817 Mdot
.63998 .67343 Mdot
.60339 .44078 Mdot
.57457 .33249 Mdot
.64097 .55454 Mdot
.51471 .18705 Mdot
.38044 .34684 Mdot
.71211 .43607 Mdot
.58404 .38862 Mdot
.53351 .81731 Mdot
.49351 .30309 Mdot
.55998 .4469 Mdot
.45272 .49566 Mdot
.63084 .62206 Mdot
.34657 .67755 Mdot
.62525 .5974 Mdot
.42658 .38898 Mdot
.15484 .45887 Mdot
.62615 .49893 Mdot
.30824 .33257 Mdot
.3412 .59208 Mdot
.41506 .4346 Mdot
.65088 .63321 Mdot
.35004 .48016 Mdot
.28644 .49063 Mdot
.64783 .48262 Mdot
.57205 .793 Mdot
.43322 .64564 Mdot
.34322 .69751 Mdot
.35047 .3895 Mdot
.6682 .52195 Mdot
.82987 .46972 Mdot
.74407 .37456 Mdot
.21416 .6673 Mdot
.51008 .8417 Mdot
.20945 .57215 Mdot
.46568 .54656 Mdot
.49017 .3161 Mdot
.28842 .55471 Mdot
.55682 .48665 Mdot
.21723 .607 Mdot
.72314 .51725 Mdot
.63015 .79439 Mdot
.67417 .38334 Mdot
.54849 .83264 Mdot
.62058 .49859 Mdot
.57926 .64538 Mdot
.72387 .4276 Mdot
.61245 .56531 Mdot
.31027 .7023 Mdot
.55883 .81912 Mdot
.37493 .42023 Mdot
.48987 .54765 Mdot
.72763 .35063 Mdot
.67264 .66577 Mdot
.43993 .3688 Mdot
.29022 .47894 Mdot
.75776 .60257 Mdot
.58676 .81717 Mdot
.57279 .44188 Mdot
.51774 .78999 Mdot
.46294 .3085 Mdot
.37714 .25859 Mdot
.3321 .30483 Mdot
.51529 .32349 Mdot
.49089 .83083 Mdot
.68241 .44953 Mdot
.23973 .70726 Mdot
.49744 .44214 Mdot
.49017 .45877 Mdot
.59201 .81571 Mdot
.20402 .62119 Mdot
.65303 .67848 Mdot
.37005 .51074 Mdot
.57511 .22452 Mdot
.59126 .52617 Mdot
.47313 .31332 Mdot
.27557 .46703 Mdot
.63685 .28004 Mdot
.50678 .82767 Mdot
.20072 .58623 Mdot
.70513 .76936 Mdot
.35378 .69758 Mdot
.24695 .47772 Mdot
.62895 .49919 Mdot
.4937 .40012 Mdot
.44739 .36775 Mdot
.5395 .83745 Mdot
.62543 .70898 Mdot
.70181 .26728 Mdot
.21282 .52522 Mdot
.77432 .62178 Mdot
.67375 .29181 Mdot
.56487 .39192 Mdot
.60815 .55496 Mdot
.71396 .38842 Mdot
.52491 .55087 Mdot
.3013 .68363 Mdot
.75878 .58486 Mdot
.36515 .43134 Mdot
.34115 .63394 Mdot
.67237 .36864 Mdot
.23603 .61565 Mdot
.71987 .29215 Mdot
.76345 .59542 Mdot
.64857 .44025 Mdot
.21823 .60617 Mdot
.20781 .54086 Mdot
.68716 .27023 Mdot
.26488 .29958 Mdot
.5144 .79238 Mdot
.46493 .36216 Mdot
.47854 .63452 Mdot
.62536 .63296 Mdot
.64094 .66822 Mdot
.16643 .47583 Mdot
.46771 .6708 Mdot
.28946 .73074 Mdot
.54369 .25227 Mdot
.72306 .62425 Mdot
.27228 .67818 Mdot
.73193 .61338 Mdot
.65365 .70411 Mdot
.75843 .43244 Mdot
.55363 .26039 Mdot
.46639 .62312 Mdot
.59159 .81215 Mdot
.34487 .31013 Mdot
.2153 .60817 Mdot
.49215 .29671 Mdot
.31306 .30454 Mdot
.4578 .44666 Mdot
.42956 .44284 Mdot
.44156 .83496 Mdot
.71327 .34599 Mdot
.30238 .4138 Mdot
.6212 .44693 Mdot
.52883 .46098 Mdot
.72117 .57734 Mdot
.45101 .68415 Mdot
.68847 .5226 Mdot
.31127 .49493 Mdot
.71855 .66322 Mdot
.71835 .40475 Mdot
.25677 .30735 Mdot
.46754 .69072 Mdot
.39068 .63361 Mdot
.46921 .51023 Mdot
.29274 .60784 Mdot
.39909 .79952 Mdot
.47737 .61609 Mdot
.20929 .62914 Mdot
.73111 .35663 Mdot
.29012 .61298 Mdot
.44475 .37252 Mdot
.78592 .54016 Mdot
.5516 .83221 Mdot
.36732 .80911 Mdot
.78495 .40736 Mdot
.66464 .28392 Mdot
.23751 .28457 Mdot
.56773 .25781 Mdot
.25893 .70936 Mdot
.49192 .29735 Mdot
.77919 .26285 Mdot
.33717 .32396 Mdot
.27186 .52864 Mdot
.62186 .52622 Mdot
.39792 .60263 Mdot
.55267 .80891 Mdot
.65825 .6606 Mdot
.32325 .5073 Mdot
.7314 .44427 Mdot
.47161 .66343 Mdot
.57485 .8033 Mdot
.60251 .80059 Mdot
.58152 .79877 Mdot
.52578 .378 Mdot
.65612 .73733 Mdot
.62784 .81247 Mdot
.27478 .55501 Mdot
.45341 .59073 Mdot
.48278 .62898 Mdot
.34753 .72448 Mdot
.24679 .68271 Mdot
.35295 .49377 Mdot
.59308 .52975 Mdot
.62574 .49631 Mdot
.60996 .82034 Mdot
.38424 .79614 Mdot
.62152 .59266 Mdot
.44704 .82976 Mdot
.2878 .41401 Mdot
.28464 .70377 Mdot
.40809 .82469 Mdot
.59088 .43936 Mdot
.49889 .36165 Mdot
.62986 .8207 Mdot
.21593 .55472 Mdot
.59207 .36302 Mdot
.71413 .39427 Mdot
.24509 .68973 Mdot
.66427 .2936 Mdot
.58638 .37521 Mdot
.62275 .5195 Mdot
.81022 .54367 Mdot
.43918 .42349 Mdot
.60287 .44692 Mdot
.45878 .53802 Mdot
.26921 .68136 Mdot
.336 .338 Mdot
.22544 .62887 Mdot
.43525 .40507 Mdot
.4595 .58822 Mdot
.28286 .63848 Mdot
.1955 .55378 Mdot
.6363 .39795 Mdot
.63578 .75121 Mdot
.72317 .35325 Mdot
.73744 .30119 Mdot
.68585 .28561 Mdot
.7675 .5633 Mdot
.53018 .59823 Mdot
.53979 .81705 Mdot
.3103 .78847 Mdot
.41802 .83037 Mdot
.69953 .27742 Mdot
.37455 .27095 Mdot
.54262 .35907 Mdot
.27719 .56874 Mdot
.40617 .58203 Mdot
.57357 .41895 Mdot
.40282 .51776 Mdot
.5265 .28836 Mdot
.83185 .46669 Mdot
.46963 .44813 Mdot
.27633 .55862 Mdot
.65044 .55053 Mdot
.51955 .46574 Mdot
.61642 .75419 Mdot
.64591 .44379 Mdot
.66959 .25419 Mdot
.21881 .61005 Mdot
.34725 .30644 Mdot
.31656 .2728 Mdot
.45923 .63344 Mdot
.5775 .65571 Mdot
.26524 .45891 Mdot
.47208 .5902 Mdot
.74347 .54671 Mdot
.36898 .2711 Mdot
.33081 .77425 Mdot
.24592 .70443 Mdot
.40308 .823 Mdot
.20605 .56582 Mdot
.30933 .31538 Mdot
.29838 .61563 Mdot
.51265 .29055 Mdot
.51239 .26809 Mdot
.3165 .60381 Mdot
.20051 .54907 Mdot
.65259 .6837 Mdot
.73129 .4388 Mdot
.49456 .58754 Mdot
.36552 .78193 Mdot
.25853 .59617 Mdot
.30155 .597 Mdot
.79136 .56559 Mdot
.69173 .50256 Mdot
.24429 .50169 Mdot
.61419 .43683 Mdot
.54761 .73816 Mdot
.66777 .27916 Mdot
.54703 .27846 Mdot
.6417 .45244 Mdot
.19465 .55489 Mdot
.28407 .26244 Mdot
.56436 .47861 Mdot
.42994 .65926 Mdot
.50914 .82069 Mdot
.43789 .57681 Mdot
.65095 .28997 Mdot
.824 .54755 Mdot
.51272 .25184 Mdot
.62475 .50473 Mdot
.46635 .57227 Mdot
.44936 .44795 Mdot
.78042 .43512 Mdot
.68745 .42534 Mdot
.62871 .70069 Mdot
.48988 .8376 Mdot
.43721 .54742 Mdot
.59423 .45618 Mdot
.31444 .66004 Mdot
.47163 .40128 Mdot
.51166 .44935 Mdot
.27884 .64029 Mdot
.57397 .46768 Mdot
.54126 .78391 Mdot
.84058 .44306 Mdot
.59809 .54393 Mdot
.25166 .51857 Mdot
.2795 .56418 Mdot
.76062 .53806 Mdot
.64753 .62901 Mdot
.53043 .25026 Mdot
.51845 .7078 Mdot
.4817 .84523 Mdot
.67632 .37631 Mdot
.28644 .62656 Mdot
.48881 .36807 Mdot
.49207 .6347 Mdot
.58083 .63835 Mdot
.41997 .82873 Mdot
.65891 .4097 Mdot
.84288 .64545 Mdot
.20478 .51356 Mdot
.75798 .48188 Mdot
.66278 .6835 Mdot
.21555 .63866 Mdot
.76792 .44891 Mdot
.51056 .43947 Mdot
.44175 .39845 Mdot
.23471 .66922 Mdot
.67664 .40155 Mdot
.64524 .41327 Mdot
.66206 .26364 Mdot
.63014 .80707 Mdot
.59 .50123 Mdot
.5317 .3711 Mdot
.28332 .41929 Mdot
.52466 .61826 Mdot
.73694 .36363 Mdot
.60777 .24079 Mdot
.49997 .38032 Mdot
.58228 .50228 Mdot
.30742 .78869 Mdot
.48564 .69133 Mdot
.71006 .35163 Mdot
.83621 .65309 Mdot
.86809 .61656 Mdot
.76067 .40779 Mdot
.53109 .84158 Mdot
.6401 .41915 Mdot
.65063 .29334 Mdot
.56494 .27693 Mdot
.40748 .63804 Mdot
.71814 .56535 Mdot
.44808 .8444 Mdot
.29691 .25616 Mdot
.47165 .31549 Mdot
.63517 .54039 Mdot
.44415 .84546 Mdot
.48079 .68149 Mdot
.25453 .513 Mdot
.3798 .25979 Mdot
.17262 .51561 Mdot
.21356 .66161 Mdot
.79924 .56052 Mdot
.16314 .48101 Mdot
.21345 .47922 Mdot
.39198 .42539 Mdot
.24931 .70476 Mdot
.58178 .60396 Mdot
.80052 .53836 Mdot
.21798 .60302 Mdot
.652 .27514 Mdot
.19301 .35635 Mdot
.51961 .45157 Mdot
.4731 .57927 Mdot
.75593 .41767 Mdot
.63431 .28203 Mdot
.63599 .37772 Mdot
.44241 .5907 Mdot
.36125 .62393 Mdot
.64789 .70836 Mdot
.74038 .29526 Mdot
.83193 .55353 Mdot
.48195 .57265 Mdot
.61207 .79036 Mdot
.5077 .26592 Mdot
.32062 .5908 Mdot
.66426 .6478 Mdot
.26706 .59339 Mdot
.28564 .42279 Mdot
.5249 .70032 Mdot
.49599 .8367 Mdot
.28469 .42416 Mdot
.59974 .79479 Mdot
.23976 .71207 Mdot
.45904 .82578 Mdot
.50105 .46746 Mdot
.27251 .45455 Mdot
.24423 .67305 Mdot
.24831 .67687 Mdot
.64474 .78417 Mdot
.22213 .49801 Mdot
.32414 .60299 Mdot
.45557 .56305 Mdot
.43197 .67295 Mdot
.53231 .74923 Mdot
.21725 .64374 Mdot
.77902 .52329 Mdot
.27276 .67396 Mdot
.78394 .41376 Mdot
.19826 .55271 Mdot
.65407 .67152 Mdot
.27082 .60011 Mdot
.47939 .37869 Mdot
.31327 .51211 Mdot
.39129 .35446 Mdot
.6868 .78563 Mdot
.68073 .27194 Mdot
.30531 .73851 Mdot
.6949 .26472 Mdot
.70896 .38756 Mdot
.20889 .49715 Mdot
.71686 .42346 Mdot
.59013 .55939 Mdot
.29152 .29901 Mdot
.24604 .62463 Mdot
.63218 .70727 Mdot
.64199 .2622 Mdot
.7871 .6017 Mdot
.45118 .83843 Mdot
.27422 .68414 Mdot
.73571 .75063 Mdot
.25521 .46344 Mdot
.71997 .65807 Mdot
.56778 .79035 Mdot
.77231 .34344 Mdot
.30148 .59158 Mdot
.5953 .80927 Mdot
.73378 .46629 Mdot
.51514 .84108 Mdot
.55285 .33476 Mdot
.25011 .49056 Mdot
.62549 .25674 Mdot
.28777 .58479 Mdot
.28973 .58364 Mdot
.31364 .75647 Mdot
.72125 .34938 Mdot
.74896 .37396 Mdot
.46417 .36129 Mdot
.3428 .375 Mdot
.41878 .6661 Mdot
.58717 .45526 Mdot
.69646 .77251 Mdot
.53333 .6006 Mdot
.24919 .45671 Mdot
.21248 .61643 Mdot
.51024 .29518 Mdot
.47764 .55554 Mdot
.63619 .26612 Mdot
.81659 .56523 Mdot
.31141 .71881 Mdot
.62162 .81051 Mdot
.47828 .55462 Mdot
.40764 .56296 Mdot
.76697 .64028 Mdot
.60099 .36963 Mdot
.50356 .2645 Mdot
.5679 .45023 Mdot
.42916 .60471 Mdot
.32671 .6333 Mdot
.20946 .56501 Mdot
.29171 .76949 Mdot
.62532 .78787 Mdot
.50605 .26151 Mdot
.29295 .5929 Mdot
.66783 .5079 Mdot
.25272 .62465 Mdot
.7266 .75913 Mdot
.15277 .47829 Mdot
.7141 .39319 Mdot
.19959 .56545 Mdot
.53791 .38668 Mdot
.25557 .51676 Mdot
.30827 .60009 Mdot
.5651 .79156 Mdot
.62056 .53406 Mdot
.65096 .41659 Mdot
.56821 .39438 Mdot
.34161 .65607 Mdot
.47043 .44092 Mdot
.79757 .54688 Mdot
.71674 .34391 Mdot
.7376 .74895 Mdot
.20313 .48 Mdot
.76394 .63084 Mdot
.7833 .70579 Mdot
.65398 .49052 Mdot
.45882 .43915 Mdot
.39016 .24708 Mdot
.28926 .60614 Mdot
.34341 .29559 Mdot
.49077 .58228 Mdot
.34836 .60904 Mdot
.77712 .42359 Mdot
.31678 .40995 Mdot
.32937 .50049 Mdot
.6505 .44081 Mdot
.21592 .48658 Mdot
.64013 .45501 Mdot
.28931 .76441 Mdot
.59103 .43382 Mdot
.64397 .70826 Mdot
.82319 .582 Mdot
.30514 .31343 Mdot
.75032 .3129 Mdot
.46877 .82826 Mdot
.34575 .71635 Mdot
.69342 .42496 Mdot
.65861 .42541 Mdot
.61922 .45832 Mdot
.51077 .30748 Mdot
.51832 .81505 Mdot
.20557 .61849 Mdot
.31385 .27451 Mdot
.72699 .45845 Mdot
.45623 .54823 Mdot
.47406 .59788 Mdot
.34763 .78311 Mdot
.34411 .35019 Mdot
.56754 .82965 Mdot
.78019 .52993 Mdot
.77336 .36084 Mdot
.58342 .41199 Mdot
.38612 .66488 Mdot
.31018 .5804 Mdot
.31524 .35181 Mdot
.47914 .63643 Mdot
.75476 .47799 Mdot
.69183 .49337 Mdot
.46285 .44355 Mdot
.30896 .45379 Mdot
.2579 .30916 Mdot
.52902 .26998 Mdot
.75658 .56225 Mdot
.21345 .64506 Mdot
.64612 .44015 Mdot
.2594 .4704 Mdot
.30303 .33536 Mdot
.47206 .6918 Mdot
.36693 .72909 Mdot
.6679 .79887 Mdot
.4894 .82132 Mdot
.65921 .43653 Mdot
.73353 .30131 Mdot
.42816 .34749 Mdot
.32854 .77145 Mdot
.69694 .40024 Mdot
.21743 .63167 Mdot
.74755 .6119 Mdot
.38935 .81262 Mdot
.66636 .67935 Mdot
.56468 .43562 Mdot
.20867 .59163 Mdot
.4245 .47088 Mdot
.19649 .56843 Mdot
.81277 .58078 Mdot
.41926 .64313 Mdot
.17734 .52301 Mdot
.50521 .37831 Mdot
.62383 .60324 Mdot
.54094 .73379 Mdot
.57289 .42195 Mdot
.23469 .66449 Mdot
.6507 .46841 Mdot
.34572 .43587 Mdot
.66183 .54143 Mdot
.47689 .30479 Mdot
.50302 .8275 Mdot
.69868 .28105 Mdot
.20548 .60628 Mdot
.43349 .67051 Mdot
.24248 .57432 Mdot
.77528 .5247 Mdot
.35123 .70355 Mdot
.51278 .52771 Mdot
.75589 .59443 Mdot
.40906 .48518 Mdot
.3384 .76215 Mdot
.51697 .74233 Mdot
.55502 .81433 Mdot
.38702 .79411 Mdot
.75406 .4104 Mdot
.44048 .48904 Mdot
.72213 .44419 Mdot
.57213 .82284 Mdot
.31793 .72893 Mdot
.63242 .2745 Mdot
.21331 .65929 Mdot
.22851 .48628 Mdot
.7956 .69404 Mdot
.69796 .35193 Mdot
.46351 .60749 Mdot
.2526 .71332 Mdot
.67897 .37968 Mdot
.21619 .47826 Mdot
.62998 .70919 Mdot
.62973 .49186 Mdot
.59615 .81403 Mdot
.58563 .5835 Mdot
.74132 .37917 Mdot
.60135 .76475 Mdot
.62631 .51029 Mdot
.32166 .73156 Mdot
.50373 .56946 Mdot
.38031 .32749 Mdot
.3959 .61608 Mdot
.16336 .46984 Mdot
.6162 .5097 Mdot
.21333 .63165 Mdot
.22039 .63437 Mdot
.2357 .51621 Mdot
.31339 .35762 Mdot
.79721 .69182 Mdot
.67058 .72617 Mdot
.52281 .58307 Mdot
.66962 .43035 Mdot
.33622 .49277 Mdot
.21716 .52707 Mdot
.48974 .64641 Mdot
.37895 .68631 Mdot
.75463 .60561 Mdot
.46652 .84577 Mdot
.48472 .39232 Mdot
.57844 .32805 Mdot
.72957 .46658 Mdot
.6347 .27836 Mdot
.77533 .46302 Mdot
.74748 .35676 Mdot
.23348 .66032 Mdot
.56527 .47905 Mdot
.56219 .44326 Mdot
.73511 .38272 Mdot
.22827 .61056 Mdot
.41465 .41296 Mdot
.56443 .28915 Mdot
.7343 .55304 Mdot
.67544 .77461 Mdot
.71304 .37973 Mdot
.53257 .45607 Mdot
.62292 .41473 Mdot
.42098 .62225 Mdot
.46434 .33168 Mdot
.72426 .35223 Mdot
.63957 .4376 Mdot
.53915 .78877 Mdot
.59573 .48604 Mdot
.26948 .45752 Mdot
.20578 .52938 Mdot
.60713 .42281 Mdot
.22015 .64273 Mdot
.47521 .68001 Mdot
.57363 .79776 Mdot
.28596 .62378 Mdot
.34935 .43773 Mdot
.49709 .59177 Mdot
.68785 .52728 Mdot
.41844 .82861 Mdot
.69537 .39568 Mdot
.57433 .50426 Mdot
.65411 .41999 Mdot
.23393 .69515 Mdot
.28944 .4557 Mdot
.37573 .27468 Mdot
.36043 .51417 Mdot
.38468 .66056 Mdot
.40276 .58665 Mdot
.51053 .30468 Mdot
.47897 .6661 Mdot
.40666 .4296 Mdot
.42535 .6234 Mdot
.73791 .55351 Mdot
.27889 .72064 Mdot
.68473 .78406 Mdot
.67366 .52125 Mdot
.20877 .66061 Mdot
.65565 .5305 Mdot
.64062 .50852 Mdot
.20577 .47871 Mdot
.5745 .51126 Mdot
.4688 .67215 Mdot
.34526 .43242 Mdot
.66096 .49625 Mdot
.68232 .78159 Mdot
.57959 .49744 Mdot
.35368 .46464 Mdot
.44763 .35087 Mdot
.50933 .45099 Mdot
.48954 .18188 Mdot
.529 .25953 Mdot
.24125 .70669 Mdot
.21718 .6077 Mdot
.56046 .26646 Mdot
.64327 .4168 Mdot
.58056 .51313 Mdot
.57073 .8015 Mdot
.41462 .48526 Mdot
.48347 .82689 Mdot
.52328 .37697 Mdot
.74881 .5687 Mdot
.38297 .79046 Mdot
.30319 .69065 Mdot
.34542 .70387 Mdot
.77701 .58212 Mdot
.50006 .78318 Mdot
.46565 .49052 Mdot
.27303 .29307 Mdot
.18108 .38117 Mdot
.70966 .76857 Mdot
.77626 .36401 Mdot
.56687 .60858 Mdot
.25626 .63052 Mdot
.59664 .4761 Mdot
.32642 .59127 Mdot
.4549 .36709 Mdot
.26381 .46315 Mdot
.53794 .38062 Mdot
.72555 .28536 Mdot
.48078 .84431 Mdot
.49069 .60625 Mdot
.39781 .51452 Mdot
.37798 .41708 Mdot
.33574 .31322 Mdot
.63145 .57452 Mdot
.66624 .79781 Mdot
.56158 .28487 Mdot
.39426 .23978 Mdot
.51947 .28679 Mdot
.31782 .75641 Mdot
.33756 .25754 Mdot
.51835 .35576 Mdot
.28693 .76361 Mdot
.77778 .40258 Mdot
.80008 .59376 Mdot
.69967 .26401 Mdot
.35004 .77271 Mdot
.75435 .59155 Mdot
.27462 .47322 Mdot
.52345 .83243 Mdot
.3083 .58337 Mdot
.29888 .41296 Mdot
.51303 .78479 Mdot
.205 .58541 Mdot
.20508 .51912 Mdot
.59394 .32419 Mdot
.63339 .53447 Mdot
.26403 .2708 Mdot
.30646 .29344 Mdot
.84938 .433 Mdot
.48965 .81963 Mdot
.70174 .73234 Mdot
.69843 .39758 Mdot
.47138 .36499 Mdot
.56499 .80279 Mdot
.22738 .64337 Mdot
.60834 .52391 Mdot
.28486 .28065 Mdot
.29424 .67252 Mdot
.2533 .61094 Mdot
.49379 .36212 Mdot
.41895 .82281 Mdot
.31018 .33869 Mdot
.59057 .62413 Mdot
.21001 .60399 Mdot
.67698 .5302 Mdot
.36048 .69996 Mdot
.66872 .77663 Mdot
.35821 .73044 Mdot
.19615 .53447 Mdot
.53063 .38061 Mdot
.40535 .3178 Mdot
.68249 .77625 Mdot
.76626 .47478 Mdot
.74872 .62057 Mdot
.83789 .65034 Mdot
.54751 .83255 Mdot
.5821 .51799 Mdot
.53431 .70548 Mdot
.27104 .74281 Mdot
.39651 .36913 Mdot
.29526 .72965 Mdot
.8283 .47255 Mdot
.20172 .50644 Mdot
.50925 .73929 Mdot
.50994 .7005 Mdot
.27585 .55022 Mdot
.74653 .40935 Mdot
.62598 .52947 Mdot
.31838 .31163 Mdot
.20117 .54788 Mdot
.75908 .55922 Mdot
.84043 .44335 Mdot
.81353 .57337 Mdot
.70038 .43619 Mdot
.50772 .83623 Mdot
.59775 .60719 Mdot
.76677 .53462 Mdot
.56318 .79692 Mdot
.41345 .52209 Mdot
.40852 .42446 Mdot
.77334 .52384 Mdot
.29761 .61234 Mdot
.16273 .46423 Mdot
.77892 .71212 Mdot
.72623 .56768 Mdot
.57424 .82791 Mdot
.37059 .81242 Mdot
.71144 .43943 Mdot
.62263 .54795 Mdot
.30317 .57407 Mdot
.58639 .4887 Mdot
.57826 .37967 Mdot
.31174 .3018 Mdot
.22712 .47988 Mdot
.25313 .32639 Mdot
.52326 .6903 Mdot
.50992 .37462 Mdot
.45638 .83715 Mdot
.25158 .50541 Mdot
.46833 .83714 Mdot
.76664 .5731 Mdot
.51979 .59128 Mdot
.86981 .61279 Mdot
.64844 .29242 Mdot
.45755 .68644 Mdot
.53893 .57913 Mdot
.55703 .59803 Mdot
.53039 .69744 Mdot
.58185 .36815 Mdot
.27189 .57525 Mdot
.19118 .50139 Mdot
.52412 .82925 Mdot
.72432 .47173 Mdot
.30704 .58039 Mdot
.57192 .30458 Mdot
.36294 .65737 Mdot
.54509 .75614 Mdot
.55384 .27436 Mdot
.18335 .48676 Mdot
.48653 .1831 Mdot
.43378 .39275 Mdot
.47481 .4408 Mdot
.35933 .62766 Mdot
.45856 .49983 Mdot
.19632 .4827 Mdot
.50724 .32053 Mdot
.39287 .42164 Mdot
.20452 .60163 Mdot
.77836 .59171 Mdot
.49035 .3578 Mdot
.233 .3032 Mdot
.30401 .59379 Mdot
.51148 .37707 Mdot
.59271 .53833 Mdot
.81588 .54556 Mdot
.53305 .79778 Mdot
.41638 .39563 Mdot
.46186 .48922 Mdot
.76186 .64526 Mdot
.54993 .81067 Mdot
.52027 .32625 Mdot
.30194 .77727 Mdot
.58503 .53469 Mdot
.63521 .57408 Mdot
.66888 .75176 Mdot
.47078 .55929 Mdot
.63437 .70001 Mdot
.54889 .59596 Mdot
.39404 .57961 Mdot
.45961 .1791 Mdot
.48135 .56592 Mdot
.49868 .44914 Mdot
.56442 .47074 Mdot
.24821 .51816 Mdot
.58895 .736 Mdot
.53594 .63044 Mdot
.29232 .47568 Mdot
.29798 .63187 Mdot
.25707 .49179 Mdot
.24978 .48065 Mdot
.49564 .35937 Mdot
.19531 .48442 Mdot
.20552 .51456 Mdot
.61145 .75169 Mdot
.5772 .80773 Mdot
.53825 .73452 Mdot
.48352 .82041 Mdot
.45518 .39751 Mdot
.6422 .37612 Mdot
.36314 .72827 Mdot
.77368 .71664 Mdot
.75082 .47318 Mdot
.58943 .68213 Mdot
.35214 .79799 Mdot
.44487 .83127 Mdot
.4826 .30251 Mdot
.65293 .26912 Mdot
.16837 .40845 Mdot
.29249 .5764 Mdot
.73272 .29024 Mdot
.33106 .27396 Mdot
.34471 .78694 Mdot
.43019 .62903 Mdot
.57962 .51975 Mdot
.78659 .54992 Mdot
.46707 .68266 Mdot
.35283 .35722 Mdot
.82317 .5472 Mdot
.77866 .58202 Mdot
.497 .7827 Mdot
.54509 .59898 Mdot
.53459 .41537 Mdot
.65782 .5052 Mdot
.71551 .76307 Mdot
.357 .28518 Mdot
.40824 .55823 Mdot
.84037 .45944 Mdot
.46856 .1789 Mdot
.21817 .47535 Mdot
.6383 .78466 Mdot
.51941 .26307 Mdot
.42682 .6156 Mdot
.57458 .20566 Mdot
.69929 .50826 Mdot
.67471 .42792 Mdot
.53022 .27073 Mdot
.24681 .57783 Mdot
.71844 .3581 Mdot
.8143 .6778 Mdot
.38422 .81071 Mdot
.47433 .68592 Mdot
.84552 .39522 Mdot
.21122 .60893 Mdot
.40186 .53786 Mdot
.70991 .3475 Mdot
.49311 .83586 Mdot
.54691 .38086 Mdot
.25657 .72214 Mdot
.60057 .43645 Mdot
.61639 .504 Mdot
.25373 .59564 Mdot
.69716 .26819 Mdot
.45983 .55268 Mdot
.84449 .42652 Mdot
.67015 .27696 Mdot
.26071 .61915 Mdot
.67408 .39832 Mdot
.67806 .51579 Mdot
.74782 .49073 Mdot
.5964 .41168 Mdot
.56007 .49108 Mdot
.53506 .45653 Mdot
.56935 .44372 Mdot
.41802 .41108 Mdot
.56832 .41185 Mdot
.64215 .29198 Mdot
.4987 .31027 Mdot
.79571 .56919 Mdot
.16086 .43445 Mdot
.25194 .47197 Mdot
.33754 .34216 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0Z_ooool3o`00
09cooooo000Looooo`03o`000?oooooooooo0:[ooooo1?l0002Kooooo`007?ooool00ol0003ooooo
ooooo`2Booooo`Co00005Oooool3o`0009_ooooo000Looooo`03o`000?oooooooooo08kooooo0_l0
0002ooooo`Co00001?ooool3o`0001;ooooo0_l0002Hooooo`007?ooool00ol0003oooooooooo`2<
ooooo`Co00002_ooool3o`0000Kooooo0_l0000:ooooo`Co0000U_ooool001cooooo00?o0000oooo
ooooool0S?ooool2o`00013ooooo0ol00002ooooo`;o00002oooool3o`0009Kooooo00001_oooooo
k^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`26
ooooo`;o00005_ooool3o`00013ooooo0ol0002Eooooo`0000KoooooogMgMonHV9SooooooiRHV?mg
MgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0
Q_ooool2o`0002[ooooo0_l0002Eooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0]?ooool2o`0009?ooooo0000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3
o`000:gooooo0_l00005ooooo`?o0000T_ooool00003ooooool0003ooooo00;ooooo00?o0000oooo
ooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo08;ooooo0_l0000Yoooo
o`;o00001_ooool4o`00093ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`22ooooo`;o0000;?ooool2o`0000Go
oooo0_l0002@ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001_ooool00ol0003oooooooooo`2`ooooo`;o0000Uoooool00006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0
^Oooool2o`0008kooooo000Looooo`03o`000?oooooooooo0;Cooooo0ol00002ooooo`?o0000SOoo
ool001cooooo00?o0000ooooooooool0]?ooool3o`0000?ooooo0_l0002=ooooo`007?ooool00ol0
003oooooooooo`2gooooo`;o00000oooool2o`0008_ooooo000Looooo`03o`000?oooooooooo0;Oo
oooo0_l00003ooooo`;o0000Roooool001cooooo00?o0000ooooooooool0O?ooool2o`0003oooooo
1?l00028ooooo`007?ooool00ol0003oooooooooo`1looooo`;o0000?oooool4o`0008Sooooo000L
ooooo`03o`000?oooooooooo0;oooooo1?l00026ooooo`007?ooool00ol0003oooooooooo`1loooo
o`;o0000;_ooool2o`000003ooooool0003o0000013ooooo0_l000000ooooooo0000o`000023oooo
o`007?ooool00ol0003oooooooooo`1looooo`;o0000;_ooool2o`000003ooooool0003o000000;o
00001oooool2o`0000Cooooo2?l00021ooooo`007?ooool00ol0003oooooooooo`2[ooooo`?o0000
0oooool4o`0000Gooooo1?l00002ooooo`Go000000?oooooo`000?l00000POooool001cooooo00?o
0000ooooooooool0Noooool2o`0002kooooo0ol000000ooooooo0000o`000005o`0000Kooooo0_l0
0005ooooo`Co0000P_ooool001cooooo0_l0001iooooo`Go00009_ooool2o`0000Cooooo0_l00002
ooooo`Wo00001_ooool2o`0000?ooooo0_l000000ooooooo0000o`000003o`0000gooooo0_l0001a
ooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o00001oooool2o`0000?ooooo0_l00003oooo
o`?o00009oooool3o`0000Cooooo0_l00002ooooo`;o00000oooool5o`0000[ooooo0_l00002oooo
o`Co00003Oooool2o`00077ooooo000Looooo`03o`000?oooooooooo05gooooo0_l00006ooooo`;o
00000oooool2o`0000;ooooo0ol00002ooooo`;o00000_ooool2o`0002Wooooo0_l0000:ooooo`;o
000000?oooooo`000?l000001Ol0000?ooooo`Ko00001_ooool2o`000003ooooool0003o0000077o
oooo000Looooo`03o`000?oooooooooo05gooooo0_l00005ooooo`;o00001?ooool2o`0000?ooooo
0_l00006ooooo`?o00009oooool2o`0000Gooooo0_l00004ooooo`Ko000000?oooooo`000?l00000
0_l0000>ooooo`So00000_ooool4o`0002Cooooo0_l0001>ooooo`007?ooool00ol0003ooooooooo
o`1Iooooo`?o00001oooool3o`0000Cooooo0_l0000;ooooo`?o00009_ooool3o`0000;ooooo0_l0
00001?oooooo0000o`000?l00002ooooo`;o000000?oooooo`000?l000001ol0000Booooo`[o0000
2Oooool3o`0001Sooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`1Iooooo`?o00001ooo
ool2o`0003Wooooo1Ol00002ooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`Co000000Co
ooooo`000?l0003o00004Oooool6o`0000;ooooo0_l00009ooooo`Go00005_ooool2o`0004kooooo
000Looooo`03o`000?oooooooooo05;ooooo0_l0001:ooooo`Wo000000?oooooo`000?l000002?oo
ool3o`0000?ooooo0_l0000Aooooo`;o00000oooool2o`0000Wooooo0_l00002ooooo`Co0000I_oo
ool001cooooo00?o0000ooooooooool0D_ooool2o`0000oooooo0_l00003ooooo`;o00002_ooool4
o`0002Sooooo0_l000000ooooooo0000o`000003ooooo`;o00001oooool2o`000003ooooool0003o
000001[ooooo0_l00007ooooo`Co00000_ooool2o`0006Sooooo000Looooo`03o`000?oooooooooo
06;ooooo1?l000000ooooooo0000o`000002o`0000Wooooo1?l0000fooooo`So00000oooool2o`00
00oooooo0_l00004ooooo`;o00001?ooool2o`000003ooooool0003o000006kooooo000Looooo`03
o`000?oooooooooo05Wooooo0_l00007ooooo`Co000000?oooooo`000?l000000_l00009ooooo`Co
00008oooool4o`0000oooooo2?l00003ooooo`;o00003oooool3o`0000?ooooo0_l00003ooooo`?o
00001oooool2o`0006Sooooo000Looooo`03o`000?oooooooooo05Cooooo0_l00003ooooo`;o0000
2?ooool2o`000003ooooool0003o000000;o000000Coooooo`000?l0003ooooo0_l00002ooooo`Co
00009Oooool5o`0000gooooo1ol00005ooooo`?o00003_ooool3o`0000Sooooo0_l00008ooooo`;o
0000J?ooool001cooooo00?o0000ooooooooool0BOooool2o`0000Wooooo1?l000000ooooooo0000
o`000008ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`000003ooooool0003o000000Co
0000:_ooool2o`0000[ooooo2ol00005ooooo`;o00002oooool2o`000003ooooool0003o000000So
oooo0_l00005ooooo`;o00000_ooool2o`0000Oooooo0_l0001Oooooo`007?ooool00ol0003ooooo
ooooo`19ooooo`;o00002oooool2o`0000kooooo0_l000000ooooooo0000o`00000:o`00033ooooo
1?l000000ooooooo0000o`00000:o`0000Cooooo0ol0000:ooooo`;o00002oooool2o`0000Gooooo
0_l0000;ooooo`;o000000?oooooo`000?l00000G?ooool001cooooo00?o0000ooooooooool0E?oo
ool2o`0000Kooooo0_l00007oooooa3o000000?oooooo`000?l00000:ooooolDo`0000Cooooo0_l0
000;ooooo`;o00000oooool5o`0000Gooooo0_l0000:ooooo`;o000000?oooooo`000?l000000_oo
ool3o`0005cooooo000Looooo`03o`000?oooooooooo05?ooooo1?l00005ooooo`;o00000_ooool2
o`0000?ooooo1Ol000000ooooooo0000o`00000;o`0002[ooooo0ol000000ooooooo0000o`00000?
o`0000Cooooo0_l0000;ooooo`;o00000oooool5o`0000;ooooo0_l000000ooooooo0000o`00000:
ooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000005[ooooo000Loooo
o`03o`000?oooooooooo05?ooooo1?l00009ooooo`;o00000ooooolBo`0002Gooooo0_l00004oooo
oaCo00001Oooool2o`0000gooooo0_l00004ooooo`;o00000_ooool2o`0001Oooooo0_l0000Coooo
o`;o0000AOooool001cooooo0_l0001Booooo`?o00001oooool2o`0000Wooooo5?l0000Rooooo`;o
00001_oooolCo`0001?ooooo0ol0000Looooo`Go00005?ooool2o`0004Gooooo000Looooo`03o`00
0?oooooooooo04Sooooo0ol00006ooooo`?o00001oooool2o`0000Gooooo0_l000000ooooooo0000
o`000002o`0000;ooooo3ol0000Oooooo`;o00000_ooool2o`0000?ooooo0_l000000ooooooo0000
o`00000Ao`0001;ooooo0ol000000ooooooo0000o`000002o`0001Oooooo1ol0001Iooooo`007?oo
ool00ol0003oooooooooo`18ooooo`?o00001Oooool2o`00013ooooo0_l000000ooooooo0000o`00
0003o`000003ooooool0003o000000Ko00000_ooool5o`0001gooooo1?l00002ooooo`;o00000ooo
ool2o`000003ooooool0003o0000017o00005_ooool4o`0001cooooo0_l0000Cooooo`;o0000A?oo
ool001cooooo00?o0000ooooooooool0D?ooool2o`0001Cooooo4ol0000Jooooo`;o00000_ooool2
o`0000Gooooo0_l00002ooooo`;o00000_oooolBo`0000Cooooo0_l00005ooooo`;o0000?_ooool2
o`0004Cooooo000Looooo`03o`000?oooooooooo053ooooo0_l0000=ooooo`;o00000oooool2o`00
00?ooooo5?l0000Fooooo`;o000000?oooooo`000?l000001_ooool2o`0000Cooooo5?l00004oooo
o`;o00001Oooool2o`0002_ooooo0_l0000Booooo`;o0000@oooool001cooooo00?o0000oooooooo
ool0D?ooool2o`0000gooooo1?l000001?oooooo0000o`000?ooool5o`000003ooooool0003o0000
00ko00000oooool2o`0001?ooooo0ol00003ooooo`;o00001ooooolCo`0003Wooooo0_l000000ooo
oooo0000o`00000?ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0@oooool2o`0000[o
oooo0_l0000@ooooo`;o00001?oooolFo`0000?ooooo0_l0000Cooooo`?o00000oooool2o`0000Wo
oooo4?l00007ooooo`;o0000=?ooool2o`0000oooooo0ol00012ooooo`007?ooool00ol0003ooooo
ooooo`13ooooo`;o00002_ooool2o`0001Gooooo5ol00003ooooo`;o00004?ooool2o`0000gooooo
0_l000000ooooooo0000o`00000?o`0000Sooooo0_l0000dooooo`;o00004?ooool2o`0004;ooooo
000Looooo`03o`000?oooooooooo06Kooooo1ol000000ooooooo0000o`00000>o`0001Cooooo0_l0
000=oooooaOo00001Oooool2o`0004Kooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`1?
ooooo`;o00001oooool3o`0000Oooooo0_l00003oooooaSo00000_ooool2o`0000oooooo0_l00003
ooooo`;o00002OoooolHo`0000?ooooo0_l00016ooooo`;o0000@_ooool001cooooo00?o0000oooo
ooooool0@_ooool2o`0000_ooooo0ol00002ooooo`;o00000_ooool3o`0000Oooooo0_l00005oooo
oaKo00000_ooool3o`0000oooooo0_l000001?oooooo0000o`000?l0000;oooooaKo0000Boooool2
o`0004;ooooo000Looooo`03o`000?oooooooooo04;ooooo0_l0000<ooooo`;o00000_ooool2o`00
00Wooooo1Ol00004ooooo`[o000000?oooooo`000?l000002?l00005ooooo`;o00001oooool2o`00
00Kooooo0_l000000ooooooo0000o`00000<oooooaGo0000C?ooool3o`00047ooooo000Looooo`03
o`000?oooooooooo05oooooo1Ol00004oooooaKo00003Oooool2o`0000Cooooo0_l00005ooooo`;o
00002_oooolCo`0004oooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`1Qooooo`Go0000
0ooooolEo`0000Kooooo0_l00009ooooo`Co00001Oooool2o`0000[ooooo5Ol0002@ooooo`007?oo
ool00ol0003oooooooooo`1Qooooo`Go00000ooooolDo`0000Oooooo0_l00009ooooo`?o00002_oo
ool2o`0000Oooooo4Ol000000ooooooo0000o`00000/ooooo`;o00001?ooool2o`0000[ooooo0ol0
001?ooooo`007?ooool00ol0003oooooooooo`1YoooooaSo00001?ooool4o`0000Kooooo0ol00002
ooooo`Co00001?ooool2o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000003?l00007
ooooo`;o00008?ooool2o`0000;ooooo1?l00004ooooo`;o00002_ooool3o`0000gooooo0_l00010
ooooo`007?ooool2o`0006[ooooo6?l00004ooooo`Co00001?ooool4o`0000?ooooo1Ol00005oooo
o`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000co00001oooool2o`00
023ooooo0_l00002ooooo`Go000000?oooooo`000?l000000_ooool2o`0001Sooooo0_l00010oooo
o`007?ooool00ol0003oooooooooo`1Sooooo`;o00001OoooolDo`0000oooooo0ol00006ooooo`?o
00001Oooool3o`0000Kooooo3ol00007ooooo`;o00007?ooool2o`0000;ooooo1_l000000ooooooo
0000o`000003o`0000;ooooo0_l000000ooooooo0000o`00001Gooooo`007?ooool00ol0003ooooo
ooooo`0kooooo`;o00009_ooool2o`0000;ooooo5ol0000>ooooo`;o00004Oooool2o`0000?ooooo
2ol00002ooooo`?o00002Oooool2o`0001cooooo0_l00002ooooo`Ko00000_ooool2o`000003oooo
ool0003o000000;o000000Coooooo`000?l0003o0000Eoooool001cooooo00?o0000ooooooooool0
>oooool2o`0002Gooooo0_l00003oooooaKo00003oooool3o`0000gooooo0ol00005ooooo`Oo0000
00?oooooo`000?l000000_ooool3o`0000[ooooo0_l0000Mooooo`;o00002?ooool2o`0000;ooooo
1?l000001?oooooo0000o`000?l0001Gooooo`007?ooool00ol0003oooooooooo`1Rooooo`;o0000
0oooool2o`0000;ooooo4Ol0000Aooooo`;o00001?ooool2o`0000Oooooo1?l00005ooooo`go0000
2oooool2o`0000;ooooo0_l0000Iooooo`;o00002?ooool2o`0000;ooooo1Ol00003ooooo`;o0000
0oooool2o`0000oooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`1Wooooo`Co00000ooo
ool>o`0001;ooooo0_l00003ooooo`Co00001_ooool3o`0000Gooooo0ol00003ooooo`;o000000?o
ooooo`000?l000002_ooool2o`000004ooooool0003o0000ooooo`?o00009oooool6o`0000;ooooo
0_l00003ooooo`?o00003_ooool2o`0003oooooo000Looooo`03o`000?oooooooooo06Wooooo0_l0
0003ooooo`ko000000?oooooo`000?l000002oooool8o`0000?ooooo0_l00004ooooo`;o00002?oo
ool3o`00017ooooo0ol00004ooooo`;o00005Oooool2o`0001;ooooo1Ol00002ooooo`?o00000ooo
ool2o`0000kooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`1Yooooo`;o00000_oooolB
o`0000_ooooo2?l00009ooooo`;o00002Oooool2o`000003ooooool0003o000000;ooooo0_l00007
ooooo`Go00000_ooool4o`0001;ooooo0_l00002ooooo`;o00006Oooool3o`0005Cooooo000Loooo
o`03o`000?oooooooooo06Wooooo0_l000000ooooooo0000o`00000@o`0000[ooooo0_l00003oooo
o`;o00004oooool2o`0000Gooooo0_l00002ooooo`;o00001oooool4o`000003ooooool0003o0000
00Co00004_ooool2o`0001Wooooo0ol000001?oooooo0000o`000?l0001Dooooo`007?ooool00ol0
003oooooooooo`1/ooooo`ko000000?oooooo`000?l000002oooool2o`000003ooooool0003o0000
00;o00002Oooool2o`0000Kooooo1?l00002ooooo`?o00000oooool2o`0000?ooooo0_l00003oooo
o`?o00000_ooool2o`0000gooooo1Ol00009ooooo`;o00003Oooool2o`0000Gooooo0ol000000ooo
oooo0000o`00000Gooooo`;o0000??ooool001cooooo00?o0000ooooooooool0=oooool2o`0003Go
oooo3_l0000?ooooo`;o00002oooool2o`0000Gooooo1Ol00002ooooo`[o000000?oooooo`000?l0
00001ol0000@ooooo`Go00002Oooool3o`0000Wooooo0_l000001?oooooo0000o`000?l00003oooo
o`?o00006oooool2o`0003cooooo000Looooo`03o`000?oooooooooo03Oooooo0_l0000dooooo`oo
00002oooool4o`0001Cooooo0_l00008ooooo`Co000000Goooooo`000?l0003o0000ooooo`04o`00
00;ooooo0_l0000Mooooo`Co00002Oooool2o`000003ooooool0003o000000Wo00000_ooool2o`00
05?ooooo000Looooo`03o`000?oooooooooo03Kooooo0_l0000eooooo`ko00003?ooool4o`00023o
oooo0_l00002ooooo`;o00009_ooool2o`0000Wooooo0_l000000ooooooo0000o`000006o`0000;o
oooo0ol00002ooooo`;o00000oooool2o`0004kooooo000Looooo`03o`000?oooooooooo03Kooooo
0_l0000booooo`;o00000_ooool7o`0000;ooooo0ol0000=ooooo`;o00008_ooool2o`0000;ooooo
0_l00008ooooo`?o00009_ooool5o`0000;ooooo1?l00007ooooo`?o00000_ooool2o`000003oooo
ool0003o000000gooooo1?l0000jooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o
8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0J_ooool3o`000004
ooooool0003o0000ooooo`Co00003oooool7o`0000oooooo0_l0000Hooooo`;o00000oooool3o`00
02Sooooo0_l000000ooooooo0000o`000005o`0000Kooooo0ol00005ooooo`;o00003Oooool4o`00
03[ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0Joooool2o`0000Cooooo1?l0000=ooooo`Ko000000?ooooo
o`000?l000003oooool2o`0001Sooooo0ol0000Wooooo`;o00001?ooool2o`000003ooooool0003o
000000Go00001_ooool3o`0001Sooooo0_l0000hooooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`09ooooo`Go00001_ooool00ol0003oooooooooo`0dooooo`;o0000>_ooool5o`00
00cooooo1ol000001?oooooo0000o`000?ooool2o`0000;ooooo0_l0000;ooooo`;o00005_ooool2
o`0001Cooooo0_l0000:ooooo`;o00001Oooool3o`0000?ooooo0_l000000ooooooo0000o`000003
o`0002?ooooo0_l0000hooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09oooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0000dooooo`;o0000>_ooool4o`0000;ooooo0_l00009
ooooo`Co00001oooool2o`0000;ooooo0_l00003ooooo`;o00001_ooool2o`0002cooooo0_l0000:
ooooo`?o00001Oooool2o`0000Kooooo0_l000000ooooooo0000o`00000:ooooo`;o000000?ooooo
o`000?l00000C_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?oM
gMgoEEEEooooool00007ooooo`03o`000?oooooooooo03Cooooo0_l0000looooo`Ko00001Oooool3
o`0000;ooooo0ol00005ooooo`;o00002Oooool2o`00047ooooo0_l0000<ooooo`;o00003_ooool2
o`000003ooooool0003o000004kooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo
00[ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0cooooo`;o0000?oooool2o`00
00?ooooo1ol00002ooooo`?o00001Oooool2o`0005Kooooo0_l00002ooooo`;o00001_ooool3o`00
00;ooooo0_l000000ooooooo0000o`000003ooooo`;o0000C?ooool00006oooooomgMgOoV9RHoooo
oonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo03?ooooo0_l0000^
ooooo`;o00003_ooool5o`000003ooooool0003o000000Go00000_ooool4o`0002oooooo0_l00003
ooooo`;o00000_ooool2o`00017ooooo0ol0000>ooooo`;o00002_ooool7o`000003ooooool0003o
000000?ooooo0_l0000Cooooo`;o0000=oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Ooo
ool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo05[ooooo0_l000000ooooooo0000o`00
0003o`000004ooooool0003o0000ooooo`;o00002?ooool2o`000003ooooool0003o000000Co0000
0oooool4o`0000?ooooo0ol0000Tooooo`;o00002Oooool2o`0000?ooooo0_l00002ooooo`;o0000
1oooool2o`0000Gooooo0_l000001?oooooo0000o`000?l0000Kooooo`Co00000oooool2o`0000?o
oooo0ol0000Booooo`;o0000=oooool001cooooo00?o0000ooooooooool0F_ooool2o`000003oooo
ool0003o000000?o00001?ooool2o`0000Sooooo0_l00005ooooo`Co00000_ooool3o`0000?ooooo
0_l0000Uooooo`;o00006oooool2o`0000Cooooo1Ol00004ooooo`;o000000?oooooo`000?l00000
0_l0000Eooooo`;o00000_ooool2o`0000?ooooo0ol0000Booooo`;o0000=oooool001cooooo00?o
0000ooooooooool0F?ooool2o`0000Cooooo0_l00005ooooo`?o00003_ooool5o`000003ooooool0
003o000003Wooooo0_l0000Cooooo`?o000000?oooooo`000?l000003Ol0000@ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0001Sooooo0_l0000gooooo`007?ooool00ol0003oooooooooo`0`
ooooo`;o00009_ooool3o`0000?ooooo0_l00003ooooo`Ko00003Oooool2o`000004ooooool0003o
0000ooooo`;o00000oooool2o`0000Sooooo0_l0000Yooooo`?o00002?ooool2o`0000Wooooo0_l0
0003oooooa7o00000oooool2o`0000Sooooo0ol00007ooooo`;o00005Oooool2o`0003Oooooo000L
ooooo`03o`000?oooooooooo033ooooo0_l0000Wooooo`;o00001oooool7o`0000Wooooo0_l00008
ooooo`;o00000oooool2o`0000Sooooo0_l0000Yooooo`;o00002Oooool2o`0000Gooooo0_l00005
ooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo1_l00003ooooo`Co00001oooool3
o`0000Kooooo0_l0000Cooooo`;o0000>Oooool001cooooo00?o0000ooooooooool0<?ooool2o`00
033ooooo0_l000000ooooooo0000o`000004o`0000Oooooo0_l00008ooooo`;o00000_ooool2o`00
04Kooooo0_l00003ooooo`Oo00000_ooool3o`0000?ooooo0ol000000ooooooo0000o`000004o`00
0003ooooool0003o000000Sooooo0_l0000Kooooo`Co0000=oooool001cooooo00?o0000oooooooo
ool0<?ooool2o`0003;ooooo2_l00004ooooo`?o000000?oooooo`000?l000002?ooool2o`0001[o
oooo0_l0000Nooooo`;o00003Oooool9o`0000;ooooo2_l000000ooooooo0000o`000003o`0000[o
oooo1Ol0000Kooooo`;o0000=oooool001cooooo00?o0000ooooooooool0;oooool4o`00033ooooo
3?l00004ooooo`;o000000?oooooo`000?l000002oooool2o`0000Gooooo0_l0000@ooooo`;o0000
5_ooool2o`0000Kooooo0_l000000ooooooo0000o`000003ooooo`;o00001OoooolLo`0000Wooooo
1Ol00005ooooo`;o00005?ooool2o`0003Oooooo000Looooo`03o`000?oooooooooo02oooooo1?l0
000_ooooo`ko00001Oooool2o`0000cooooo0_l00005ooooo`;o00001Oooool2o`0000oooooo0_l0
000@ooooo`;o00001_ooool2o`000003ooooool0003o000000?ooooo0_l00006oooooaKo000000?o
ooooo`000?l000000ol00002ooooo`;o00003_ooool2o`0004gooooo000Looooo`03o`000?oooooo
oooo06;ooooo2_l00002ooooo`;o00001Oooool2o`00017ooooo0_l00007ooooo`;o00000_ooool3
o`0000Kooooo0_l00002ooooo`;o00003oooool2o`000003ooooool0003o000000Cooooo0_l00002
ooooo`;o00001_ooool2o`0000;ooooo7?l00002ooooo`;o00002?ooool2o`0001Oooooo0_l0000j
ooooo`007?ooool00ol0003oooooooooo`1Looooo`;o00000_ooool<o`0000gooooo0_l0000=oooo
o`;o00002?ooool6o`0000Kooooo0_l0000Cooooo`Go00002?ooool2o`0000Kooooo0_l00004oooo
oa_o000000?oooooo`000?l000000_l00003ooooo`;o000000?oooooo`000?l000005oooool4o`00
03Sooooo000Looooo`03o`000?oooooooooo05Sooooo0_l00002oooooa;o00002oooool2o`0001?o
oooo0_l000000ooooooo0000o`000004o`0000Oooooo0_l00002ooooo`;o00003_ooool5o`0000Wo
oooo0_l00004ooooo`;o00001_oooolKo`000003ooooool0003o000000;o00000oooool2o`0000?o
oooo0_l00002ooooo`;o00004oooool2o`0003Sooooo000Looooo`;o0000FOooool4o`000003oooo
ool0003o000000oo00008?ooool2o`000003ooooool0003o000000;ooooo0_l00007ooooo`;o0000
0_ooool2o`000003ooooool0003o000000_ooooo0_l000000ooooooo0000o`000009ooooo`;o0000
1?ooool3o`000004ooooool0003o0000oooooa_o00001?ooool2o`0000?ooooo0_l00003ooooo`;o
00000_ooool2o`00017ooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`1Eooooo`;o0000
0oooool2o`000004ooooool0003o0000ooooo`oo0000<oooool2o`000003ooooool0003o000000ko
oooo0_l00004ooooo`;o00002_oooolCo`000003ooooool0003o000000go00000_ooool2o`0001oo
oooo0_l0000jooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00001Oooool3o`0000?ooooo
0_l000000ooooooo0000o`00000@o`0002cooooo0_l0000<ooooo`?o00003oooool4o`0000Kooooo
0_l00002ooooo`;o000000?oooooo`000?l000003?l000000ooooooo0000o`00000=o`0000;ooooo
0_l00002ooooo`;o00006oooool2o`0003[ooooo000Looooo`03o`000?oooooooooo02kooooo0ol0
000Looooo`;o00000oooool4o`0000Oooooo4_l0000/ooooo`;o00002oooool4o`00017ooooo0_l0
0006ooooo`;o00000_ooool2o`0000?ooooo7?l00002ooooo`?o000000?oooooo`000?l000006ooo
ool2o`0003[ooooo000Looooo`03o`000?oooooooooo02kooooo1Ol0000Looooo`;o000000?ooooo
o`000?l000001Oooool2o`0000;ooooo5?l0000gooooo`;o00007oooool2o`000003ooooool0003o
000001_o00001?ooool2o`0000Wooooo0_l0000Booooo`?o0000>_ooool001cooooo00?o0000oooo
ooooool0<Oooool2o`0001cooooo0_l000000ooooooo0000o`000002ooooo`Go00000_oooolDo`00
02kooooo0_l00004ooooo`;o00004?ooool2o`0001?ooooo8Ol0000;ooooo`;o00004?ooool4o`00
03_ooooo000Looooo`03o`000?oooooooooo037ooooo0_l0000Nooooo`;o00000oooool4o`0000?o
oooo4ol0000Fooooo`Co00005Oooool2o`0000Cooooo0_l0000=ooooo`;o000000?oooooo`000?l0
00005Oooool7o`000003ooooool0003o0000013o000000?oooooo`000?l000000_l0000Mooooo`?o
0000??ooool001cooooo00?o0000ooooooooool0;_ooool2o`000003ooooool0003o000001Cooooo
0_l00005ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Oooooo4_l0000Fooooo`Co0000
00?oooooo`000?l000009oooool2o`0001Sooooo6ol00005ooooo`Co00005oooool4o`0003cooooo
000Looooo`03o`000?oooooooooo02kooooo0_l00002ooooo`Co00003Oooool2o`0000;ooooo0_l0
0005ooooo`;o00001Oooool4o`0000;ooooo0_l000000ooooooo0000o`00000@o`0001Kooooo3?l0
000/ooooo`;o00000oooool2o`0000Sooooo6Ol000000ooooooo0000o`000005ooooo`Co00000ooo
ool2o`0001;ooooo1?l0000looooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00000_ooool4
o`0000Sooooo0ol000001Ooooooo0000o`000?l0003ooooo00;o00001Oooool2o`0000Sooooo0_l0
0002ooooo`;o000000?oooooo`000?l000004?l0000Eoooooa3o00007oooool2o`0000Sooooo0_l0
0003ooooo`;o00002?oooolIo`0000Oooooo0ol000000ooooooo0000o`000002ooooo`;o00004?oo
ool5o`0003gooooo000Looooo`03o`000?oooooooooo02kooooo0_l000000ooooooo0000o`000009
ooooo`Go000000Goooooo`000?l0003o0000ooooo`02o`0000Gooooo0_l0000<oooooaGo00003Ooo
ool2o`0000;ooooo0ol000001Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`000?l00000
2_l0000Hooooo`Ko00004oooool2o`000003ooooool0003o000001Wo000000Coooooo`000?l0003o
oooo1?l00002ooooo`?o00004oooool3o`0003oooooo000Looooo`03o`000?oooooooooo02kooooo
0_l000000ooooooo0000o`000009ooooo`;o00002Oooool2o`0000Cooooo0_l00007ooooo`;o0000
0ooooolDo`0000kooooo0_l00002ooooo`Co00000_ooool2o`0000?ooooo3Ol0000Gooooo`Co0000
1Oooool2o`0000?ooooo0_l00008ooooo`?o000000?oooooo`000?l000000ol00002oooooa7o0000
00Coooooo`000?l0003ooooo0_l000001?oooooo0000o`000?l00004ooooo`;o00004Oooool4o`00
043ooooo000Looooo`03o`000?oooooooooo03Sooooo0_l00002ooooo`;o00001?ooool2o`0000?o
oooo0_l0000=ooooo`?o00000_oooolCo`0000oooooo3Ol000000ooooooo0000o`00000<o`0001?o
oooo0_l00003ooooo`Co00001?ooool4o`000003ooooool0003o000000Sooooo0ol000000ooooooo
0000o`000004o`000003ooooool0003o000001Oo00006?ooool5o`00043ooooo000Looooo`03o`00
0?oooooooooo03Sooooo0_l00008ooooo`;o00002_ooool4o`0000Gooooo1?l000000ooooooo0000
o`00000@o`0000Oooooo0ol00005ooooo`Co00001?ooool5o`000004ooooool0003o0000ooooo`go
00004Oooool2o`0000?ooooo1?l00006ooooo`;o00001?ooool2o`0000Kooooo0ol00003ooooo`Co
00000_oooolGo`0000?ooooo0_l0000Cooooo`Go0000@?ooool001cooooo00?o0000ooooooooool0
;oooool2o`0001Cooooo0_l00007ooooo`Co00001Oooool5o`000003ooooool0003o000000Ko0000
00?oooooo`000?l000001_l000000ooooooo0000o`000004ooooo`?o00000oooool5o`000003oooo
ool0003o000000cooooo3_l0000Dooooo`Co00003?ooool2o`0000Kooooo0ol00003oooooaco0000
0oooool3o`0001;ooooo1Ol00011ooooo`007?ooool00ol0003oooooooooo`0_ooooo`Co00003Ooo
ool2o`0000;ooooo0ol0000=ooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`_o0000
00Coooooo`000?l0003ooooo0_l00007ooooo`;o000000?oooooo`000?l000000ol000000ooooooo
0000o`00000<ooooo`ko00005?ooool3o`0000Cooooo0_l0000<ooooo`?o000000Goooooo`000?l0
003o0000ooooo`0Jo`0000Cooooo1Ol0000@ooooo`Co0000A?ooool001cooooo0_l0000booooo`;o
000000?oooooo`000?l000001?ooool2o`0000Cooooo0_l00002ooooo`;o00001_ooool2o`0000Ko
oooo0_l0000:ooooo`_o000000?oooooo`000?l000001?l00006ooooo`;o000000?oooooo`000?l0
00000_l0000@ooooo`oo00005?ooool2o`0000Cooooo0_l00002ooooo`;o00001?ooool2o`0000;o
oooo2_l000000ooooooo0000o`000004o`000003ooooool0003o000000Co00000oooool7o`0000Co
oooo0ol0000Aooooo`Go0000A?ooool001cooooo00?o0000ooooooooool0=?ooool2o`0000Cooooo
0_l00007ooooo`;o00001oooool2o`0000Gooooo0ol00009ooooo`[o00001?ooool5o`0000Cooooo
0_l00003ooooo`;o00005?ooool>o`0001?ooooo0_l00003ooooo`Co000000?oooooo`000?l00000
1?ooool4o`000003ooooool0003o000000;o000000?oooooo`000?l000000_l00002ooooo`Go0000
1?ooool4o`0000?ooooo1?l00007ooooo`;o00004Oooool2o`0004Oooooo000Looooo`03o`000?oo
oooooooo03Cooooo1?l00003ooooo`;o000000?oooooo`000?l000000oooool2o`0000Wooooo0_l0
0003ooooo`?o00002Oooool:o`0000gooooo0_l000000ooooooo0000o`00000Iooooo`_o00006?oo
ool4o`0000Wooooo1Ol00005ooooo`;o00000_ooool5o`0000Cooooo1?l0000Qooooo`;o0000Aooo
ool001cooooo00?o0000ooooooooool0=?ooool4o`0000?ooooo0_l000000ooooooo0000o`000002
ooooo`;o00002_ooool2o`0000Cooooo0_l0000;ooooo`;o000000Goooooo`000?l0003o0000oooo
o`03o`0000Oooooo1Ol00002ooooo`;o00006?ooool=o`0001?ooooo0_l0000?ooooo`?o000000?o
ooooo`000?l000000_ooool2o`0000Cooooo1Ol00004ooooo`;o00000_ooool3o`0000Kooooo0_l0
000Cooooo`;o000000?oooooo`000?l00000Aoooool001cooooo00?o0000ooooooooool0=?ooool3
o`0000Kooooo1?l000000ooooooo0000o`00000;ooooo`;o00000oooool2o`0000cooooo0_l00004
ooooo`Ko000000?oooooo`000?l000001_l0000Looooo`go000000?oooooo`000?l000004?ooool2
o`0000;ooooo1?l00009ooooo`?o000000?oooooo`000?l000000_ooool2o`0000gooooo1ol00006
ooooo`;o00004_ooool4o`0004Wooooo000Looooo`03o`000?oooooooooo03Cooooo0_l000000ooo
oooo0000o`000004ooooo`Co00002?ooool2o`0000Cooooo0_l0000Aooooo`;o00001oooool8o`00
00[ooooo0_l0000Eooooo`oo00005?ooool4o`0000Oooooo0_l000000ooooooo0000o`00000Aoooo
o`Oo00002?ooool3o`0001;ooooo1?l00019ooooo`007?ooool00ol0003oooooooooo`0dooooo`Go
00001_ooool2o`0000Sooooo0_l00002ooooo`Co00005oooool2o`0000;ooooo0ol0000;ooooo`;o
000000?oooooo`000?l000000_l0000Cooooo`ko00005oooool2o`0000Oooooo0_l000000ooooooo
0000o`000002o`0000oooooo1?l00009ooooo`Go00004Oooool5o`0004Wooooo000Looooo`03o`00
0?oooooooooo03Cooooo1?l00007ooooo`;o00003?ooool3o`0001Sooooo1?l0000=ooooo`?o0000
0oooool2o`0000;ooooo0_l00008ooooo`Go00000oooool>o`0001Kooooo0_l0000:ooooo`Co0000
3?ooool4o`0000?ooooo0_l00007ooooo`;o00004Oooool6o`0004_ooooo000Looooo`03o`000?oo
oooooooo03Kooooo0_l00009ooooo`;o00009oooool2o`0000gooooo0ol00007ooooo`;o00001ooo
ool6o`0000Gooooo2Ol000000ooooooo0000o`00000Iooooo`;o00001?ooool2o`0000;ooooo0_l0
000=ooooo`Co00000oooool2o`0001Wooooo1_l0001<ooooo`007?ooool00ol0003oooooooooo`0i
ooooo`;o00001?ooool6o`00013ooooo0_l0000Rooooo`?o00004?ooool4o`0000;ooooo0_l00003
ooooo`Wo000000?oooooo`000?l000000_l0000Gooooo`;o00001?ooool2o`000003ooooool0003o
000000?o00004_ooool2o`0001Kooooo0_l000000ooooooo0000o`000004o`0004cooooo000Loooo
o`03o`000?oooooooooo03Wooooo0_l00004ooooo`;o00000_ooool4o`0000kooooo0ol0000boooo
o`Go00000oooool4o`0000;ooooo2?l000000ooooooo0000o`000002o`0001Sooooo0_l00006oooo
o`;o000000?oooooo`000?l000001oooool2o`0000Gooooo0_l00002ooooo`;o00005_ooool2o`00
00;ooooo1Ol0001<ooooo`007?ooool00ol0003oooooooooo`0looooo`;o00001oooool2o`0000oo
oooo0ol0000aooooo`Go00000oooool5o`0000;ooooo3?l0000Eooooo`;o000000?oooooo`000?l0
00001oooool2o`0000;ooooo0_l00004ooooo`?o00001Oooool2o`0001Sooooo0_l000000ooooooo
0000o`000003ooooo`;o0000COooool001cooooo00?o0000ooooooooool0??ooool2o`0000Kooooo
0_l0000@ooooo`?o00009_ooool2o`0000Sooooo1Ol00003ooooo`Ko00000_ooool=o`0001Cooooo
0_l000000ooooooo0000o`000005ooooo`Go000000?oooooo`000?l000000oooool3o`00023ooooo
1Ol00003ooooo`;o00001?ooool2o`0000Oooooo0_l0000nooooo`007?ooool00ol0003ooooooooo
o`0looooo`;o00000_ooool2o`0000;ooooo0_l0000iooooo`;o00002?ooool3o`0000Gooooo0_l0
00001?oooooo0000o`000?ooool2o`000003ooooool0003o000000_o00005_ooool2o`0000Gooooo
0_l000001Ooooooo0000o`000?l0003ooooo00;o00000_ooool2o`0000;ooooo0ol0000Mooooo`;o
00001Oooool3o`0000?ooooo0_l00007ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0
??ooool2o`0000;ooooo0_l00002ooooo`;o00004_ooool2o`0002kooooo1?l0000;ooooo`;o0000
0_ooool<o`0001Oooooo0_l00004ooooo`;o00000_ooool2o`000003ooooool0003o000000Kooooo
0ol0000Hooooo`?o00000_ooool2o`0000Kooooo0_l00006ooooo`;o0000A?ooool001cooooo00?o
0000ooooooooool0?_ooool2o`0000Cooooo0_l0000=ooooo`;o00000oooool2o`0002kooooo1?l0
0008ooooo`;o000000?oooooo`000?l000000_ooool<o`0001Oooooo0_l00004ooooo`Oo00008_oo
ool4o`0000kooooo0_l00002ooooo`Co000000?oooooo`000?l00000?oooool001cooooo0_l0000n
ooooo`?o00001?ooool2o`0000cooooo0ol000000ooooooo0000o`00000`ooooo`Co00001?ooool2
o`0000;ooooo0_l00005ooooo`ko00007Oooool5o`0000Cooooo0_l0000Jooooo`Go00003?ooool2
o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`00000oooooo`007?ooool00ol0
003oooooooooo`0looooo`?o00001Oooool2o`0000cooooo0ol000000ooooooo0000o`00000`oooo
o`;o00001_ooool4o`0000Wooooo3?l0000Looooo`;o000000Coooooo`000?l0003o00000oooool3
o`0001Wooooo1?l0000>ooooo`;o00003?ooool2o`0003gooooo000Looooo`03o`000?oooooooooo
03_ooooo1?l00003ooooo`Co00004?ooool2o`0000;ooooo0_l0000/ooooo`?o00000oooool2o`00
00;ooooo0_l00003ooooo`?o00000oooool:o`0001_ooooo0_l000000ooooooo0000o`000002oooo
o`;o000000?oooooo`000?l000000_l0000Iooooo`Go00007?ooool2o`0003gooooo000Looooo`03
o`000?oooooooooo03_ooooo0ol00004ooooo`Co00003Oooool5o`0000;ooooo1?l0000Sooooo`;o
00001Oooool3o`0000?ooooo0_l00005ooooo`Go00000oooool;o`0001Cooooo0_l00004ooooo`;o
00002?ooool2o`0001Wooooo1?l00008ooooo`;o0000E?ooool001cooooo00?o0000ooooooooool0
Doooool5o`0000Cooooo0_l0000Sooooo`;o00001?ooool2o`0000Oooooo0_l00003ooooo`;o0000
2_ooool8o`0001?ooooo0_l0000<ooooo`;o00006oooool3o`0000Sooooo1Ol00009ooooo`;o0000
Aoooool001cooooo00?o0000ooooooooool0?Oooool5o`00017ooooo1_l0000Xooooo`;o00001?oo
ool2o`0000Cooooo0_l000000ooooooo0000o`000007ooooo`;o00001_ooool8o`0001[ooooo0_l0
0005ooooo`;o00006Oooool2o`0000_ooooo0_l000000ooooooo0000o`000006ooooo`;o000000?o
ooooo`000?l000000oooool2o`0004;ooooo000Looooo`03o`000?oooooooooo03cooooo1_l0000B
ooooo`Ko0000;Oooool3o`0000?ooooo0_l0000:ooooo`;o00001Oooool2o`000003ooooool0003o
000000Co00003oooool2o`0000Wooooo1?l0000Nooooo`;o000000?oooooo`000?l000001Oooool2
o`0000cooooo1?l00004ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0>oooool3o`00
00;ooooo0_l0000Aooooo`Wo0000:_ooool4o`0000[ooooo0_l00003ooooo`;o00001Oooool2o`00
0003ooooool0003o000000Co00003oooool2o`0000_ooooo0_l0000Nooooo`;o000000?oooooo`00
0?l000001Oooool2o`0000kooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`0kooooo`;o
00000oooool2o`0000Wooooo0_l00006ooooo`Co00000_ooool3o`0000?ooooo0_l00002ooooo`;o
00008Oooool3o`0000_ooooo0_l00003ooooo`Co00002?ooool4o`00017ooooo0_l0000=ooooo`Co
00005oooool3o`0000kooooo0_l00005ooooo`;o00001_ooool2o`0004?ooooo000Looooo`03o`00
0?oooooooooo03_ooooo0_l0000>ooooo`?o00001Oooool4o`0000Cooooo0_l00002ooooo`;o0000
0_ooool2o`00027ooooo0_l00002ooooo`;o00003oooool2o`000004ooooool0003o0000o`0000Go
oooo1?l0000@ooooo`?o00003?ooool6o`0001Gooooo1?l0000=ooooo`;o00001Oooool2o`0000?o
oooo0_l000000ooooooo0000o`000013ooooo`007?ooool00ol0003oooooooooo`0kooooo`;o0000
3oooool2o`0000Gooooo0ol00005ooooo`;o00000oooool3o`0001Sooooo0ol00008ooooo`;o0000
0_ooool2o`0000[ooooo0_l00003ooooo`Oo00001?ooool4o`000003ooooool0003o000000kooooo
0_l0000?ooooo`?o00005oooool2o`00017ooooo0_l00006ooooo`;o000000?oooooo`000?l00000
0_ooool2o`0003oooooo000Looooo`03o`000?oooooooooo03_ooooo0_l0000Fooooo`?o00001?oo
ool2o`0000Cooooo0ol00007ooooo`;o00003oooool3o`0000;ooooo0_l00003ooooo`?o00003_oo
ool2o`0000?ooooo2_l000001?oooooo0000o`000?l00002ooooo`Go00002_ooool3o`0002Wooooo
0ol0000:ooooo`;o00001?ooool2o`0000Kooooo0_l000000ooooooo0000o`000002ooooo`;o0000
?oooool001cooooo00?o0000ooooooooool0?_ooool3o`0001;ooooo0ol00004ooooo`;o00001?oo
ool2o`0000Sooooo0_l0000@ooooo`;o000000Coooooo`000?l0003o00000oooool3o`0001;ooooo
3_l00004ooooo`Go00002Oooool3o`0002[ooooo0_l0000:ooooo`;o00001?ooool2o`0004kooooo
000Looooo`03o`000?oooooooooo03kooooo0ol00008ooooo`;o00002Oooool2o`0000kooooo0_l0
0007ooooo`;o00003Oooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`00
0002ooooo`;o00000_ooool4o`0000;ooooo0_l00002ooooo`Oo00000_ooool6o`0000;ooooo1ol0
000>ooooo`;o0000G?ooool2o`0002Wooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo
0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0looooo`;o
00000_ooool2o`0000Oooooo0_l00008ooooo`?o00001Oooool2o`000004ooooool0003o0000o`00
00?ooooo1?l00003ooooo`Co00005Oooool3o`000003ooooool0003o000000;ooooo0_l00002oooo
o`Co00000_ooool2o`0000?ooooo0_l000001?oooooo0000o`000?l00002ooooo`Oo000000Cooooo
o`000?l0003o00000_ooool2o`0000kooooo0_l00004ooooo`;o0000:Oooool2o`0000Kooooo0_l0
0005ooooo`?o00006oooool2o`0002Wooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo
0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0looooo`;o
00000_ooool2o`0000gooooo0ol000000ooooooo0000o`000002o`0000Cooooo0_l000001?oooooo
0000o`000?l00005ooooo`;o00000oooool2o`000003ooooool0003o000001Cooooo0ol0000Goooo
o`go00001?ooool3o`0001Cooooo0ol0000Xooooo`Go00000oooool3o`0000Cooooo0ol00016oooo
o`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooooooo`17ooooo`;o00001_ooool3o`0000;ooooo0ol00007oooo
o`Co00003?ooool2o`0001Cooooo0_l0000@ooooo`;o00000ooooolAo`000003ooooool0003o0000
00Co00005?ooool2o`0002Wooooo1?l00004ooooo`;o000000Coooooo`000?l0003ooooo0ol00016
ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9Sooooo
oiRHV?lQ8B401_ooool3o`0003oooooo0_l00002ooooo`;o00000_ooool2o`0000_ooooo0ol00009
ooooo`;o00001?ooool2o`0001Kooooo0_l00004ooooo`;o00004?ooool2o`0000?ooooo0ol00000
0ooooooo0000o`00000?o`000003ooooool0003o000000;o00002_ooool2o`0000Kooooo0_l0000R
ooooo`;o00001Oooool2o`0000Sooooo0ol000000ooooooo0000o`00000Hooooo`?o0000;?ooool0
0003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oEEEEo`000?l@413o
c<c<00Kooooo00?o0000ooooooooool0?Oooool8o`0001Gooooo0_l00007ooooo`;o000000?ooooo
o`000?l000002oooool2o`000003ooooool0003o000000Cooooo1?l00003ooooo`Co000000?ooooo
o`000?l000004_oooolCo`0000;ooooo1_l00002ooooo`;o00001?ooool2o`0000Kooooo0_l0000R
ooooo`;o00001?ooool3o`0000Sooooo0_l000000ooooooo0000o`00000Iooooo`?o0000;?ooool0
0003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08oooo
o`03o`000?oooooooooo03gooooo2?l0000@ooooo`;o00000oooool3o`0000Kooooo1ol000000ooo
oooo0000o`000002o`0000;ooooo1?l000000ooooooo0000o`000004ooooo`;o00001Oooool4o`00
0003ooooool0003o000000Wooooo0_l00006oooooaGo00000_ooool5o`0000;ooooo1?l000000ooo
oooo0000o`000006ooooo`;o00008oooool2o`0000Cooooo0_l00009ooooo`;o000000?oooooo`00
0?l000006Oooool2o`0002gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00?ogMgM
oa0@4?nHV9P02?ooool00ol0003oooooooooo`11ooooo`Co000000?oooooo`000?l000001Oooool4
o`0000Cooooo0_l00004ooooo`Co00001?ooool7o`000003ooooool0003o000000;o00000_ooool4
o`0000kooooo1?l0000<ooooo`;o00001_oooolAo`000003ooooool0003o000000;o000000?ooooo
o`000?l000001?l00003ooooo`;o000000?oooooo`000?l000001_ooool2o`00027ooooo0_l00004
ooooo`;o00001oooool2o`0000Cooooo0ol0000Fooooo`;o0000<?ooool00006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo04?ooooo
0_l000001?oooooo0000o`000?ooool2o`0000;ooooo1?l00005ooooo`;o00000oooool4o`0000Co
oooo0_l0000=ooooo`?o00003oooool5o`00013ooooo4ol000000ooooooo0000o`000004o`0000;o
oooo0ol00002ooooo`;o000000?oooooo`000?l00000:_ooool3o`0000?ooooo0_l00004ooooo`;o
000000?oooooo`000?l000001?ooool3o`0001Kooooo0_l0000`ooooo`007?ooool00ol0003ooooo
ooooo`0oooooo`Co00001_ooool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000
o`000002o`0000?ooooo1?l0000@ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Gooooo
0_l000000ooooooo0000o`00000>oooooaco000000?oooooo`000?l000000_l000001Ooooooo0000
o`000?l0003ooooo00;o00001_ooool3o`0002;ooooo0_l00008ooooo`Go00001Oooool2o`0001Ko
oooo0_l0000aooooo`007?ooool00ol0003oooooooooo`0oooooo`Co00002Oooool2o`0000?ooooo
0_l000000ooooooo0000o`000002o`0000Oooooo0ol00007ooooo`;o00001?ooool3o`0000Wooooo
1?l00002ooooo`;o00005?oooolKo`0000;ooooo2ol00006ooooo`?o000000Coooooo`000?l0003o
00007?ooool2o`0000Cooooo0ol00003ooooo`Ko00000oooool2o`0001Oooooo0_l0000aooooo`00
7?ooool00ol0003oooooooooo`0oooooo`;o00002oooool4o`000003ooooool0003o000000;ooooo
0ol000000ooooooo0000o`000004ooooo`?o00001?ooool8o`0000;ooooo1?l00007ooooo`;o0000
1?ooool2o`0000;ooooo0ol0000<ooooo`;o00000ooooolJo`000003ooooool0003o000000Co0000
00Coooooo`000?l0003o00002oooool3o`0001_ooooo0ol00004ooooo`?o00000oooool3o`000004
ooooool0003o0000ooooo`Co0000B_ooool001cooooo00?o0000ooooooooool0C?ooool4o`0000Go
oooo0ol000000ooooooo0000o`000003ooooo`;o00001Oooool:o`0000;ooooo0ol00003ooooo`;o
00002?ooool2o`0000;ooooo0ol0000<ooooo`;o00000ooooolJo`0000?ooooo2_l0000>ooooo`;o
00005oooool2o`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l000000oooool3o`0004co
oooo000Looooo`03o`000?oooooooooo043ooooo0_l00004ooooo`;o00001?ooool2o`0000;ooooo
0_l00003ooooo`?o000000?oooooo`000?l000000oooool2o`0000Gooooo1?l000000ooooooo0000
o`000003o`0000;ooooo0ol00003ooooo`;o00002?ooool2o`0000Gooooo0_l0000?ooooo`Oo0000
00?oooooo`000?l000004?l000000ooooooo0000o`000002ooooo`?o00000oooool2o`0000Sooooo
0_l00004ooooo`?o00006oooool2o`0000Cooooo1?l00002ooooo`Co0000COooool001cooooo00?o
0000ooooooooool0@?ooool8o`0000Sooooo0_l00003ooooo`?o00001Oooool2o`0000Cooooo0_l0
00001?oooooo0000o`000?l00002ooooo`Go000000Coooooo`000?l0003o00001_ooool3o`0000Go
oooo0ol00003ooooo`;o00001oooool2o`0000Kooooo7_l000000ooooooo0000o`000004ooooo`;o
00001oooool3o`0000Gooooo0ol0000Mooooo`;o000000?oooooo`000?l000001_l0001?ooooo`00
7?ooool00ol0003oooooooooo`0nooooo`;o00000_ooool4o`0000oooooo0ol00005ooooo`;o0000
1?ooool2o`000003ooooool0003o000000So00002_ooool3o`0000?ooooo1Ol0000<ooooo`;o0000
1Oooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000004_l000000ooooooo0000
o`000005ooooo`;o00002Oooool2o`0000Oooooo0_l0000Looooo`?o000000?oooooo`000?l00000
1_l0001?ooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00000_ooool2o`00013ooooo1_l0
0003ooooo`;o00001?ooool4o`000004ooooool0003o0000o`0000;ooooo0ol00003ooooo`;o0000
1Oooool2o`0000Cooooo1?l0000Doooooaco000000?oooooo`000?l000001?l000000ooooooo0000
o`00000`ooooo`?o00000oooool6o`0004oooooo000Looooo`03o`000?oooooooooo04;ooooo1_l0
000<ooooo`Ko00000oooool2o`0000Kooooo0_l000001?oooooo0000o`000?l00002ooooo`;o0000
1?ooool2o`0000_ooooo0ol000000ooooooo0000o`00000DoooooaWo000000?oooooo`000?l00000
1ol0000:ooooo`;o00009?ooool3o`0000Cooooo1?l0001Aooooo`007?ooool00ol0003ooooooooo
o`12ooooo`Ko00003Oooool2o`0000_ooooo0ol00008ooooo`?o00004?ooool2o`0000;ooooo0_l0
0003ooooo`;o00003_ooool6o`000003ooooool0003o0000017o000000?oooooo`000?l000001ol0
000:ooooo`Co00008_ooool2o`0000Cooooo0ol0000Hooooo`;o0000>Oooool001cooooo00?o0000
ooooooooool0@_ooool3o`00013ooooo0_l0000;ooooo`?o000000?oooooo`000?l000002?l00003
ooooo`;o00002oooool2o`0000Oooooo0_l0000>oooooa[o00001?ooool9o`0000Wooooo0_l00002
ooooo`;o00001Oooool2o`0001gooooo0ol0000Hooooo`;o0000>Oooool001cooooo0_l00010oooo
o`;o00005?ooool2o`0000_ooooo0_l00002ooooo`Wo00001?ooool2o`0000_ooooo0_l0000Goooo
oa[o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000004o`0000gooooo0_l00005
ooooo`;o0000=_ooool3o`0003[ooooo000Looooo`03o`000?oooooooooo03oooooo0_l0000Doooo
o`;o00002oooool3o`000003ooooool0003o000000Ko00004_ooool2o`0001Oooooo6_l000001?oo
oooo0000o`000?ooool6o`000003ooooool0003o000001Gooooo0_l0000Iooooo`;o00006_ooool3
o`0003[ooooo000Looooo`03o`000?oooooooooo05Oooooo0_l00009ooooo`?o00000_ooool7o`00
00Cooooo0_l0000<ooooo`;o00005ooooolJo`000003ooooool0003o000000;ooooo1Ol0000Hoooo
o`;o00003oooool2o`0000Sooooo0_l0000Jooooo`;o0000>oooool001cooooo00?o0000oooooooo
ool0@?ooool4o`0000Cooooo0_l00005ooooo`;o00001_ooool2o`0000Wooooo0ol00002ooooo`Ko
00001?ooool3o`0000Gooooo0_l0000<ooooo`?o00003ooooolJo`000004ooooool0003o0000oooo
o`;o000000?oooooo`000?l000000_ooool2o`0001;ooooo0_l000000ooooooo0000o`00000?oooo
o`;o00002?ooool2o`0001Sooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`10ooooo`Co
00001?ooool3o`000004ooooool0003o0000ooooo`;o00001_ooool2o`0000Sooooo1?l00002oooo
o`?o00001oooool2o`0000Kooooo0ol0000;ooooo`?o00000oooool2o`0000Kooooo0_l00002oooo
oa[o00001?ooool2o`000003ooooool0003o000000;ooooo0_l0000Booooo`Go00003oooool3o`00
023ooooo0ol0000mooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00001Oooool2o`000003
ooooool0003o000001?ooooo1?l00002ooooo`Co00001_ooool2o`0000Gooooo1?l00007ooooo`?o
00001oooool3o`0000Gooooo0_l000000ooooooo0000o`00000Ko`0000Gooooo0_l0000@ooooo`;o
00001Oooool2o`0000;ooooo0_l0000=ooooo`?o00000_ooool2o`0000?ooooo0_l0000Gooooo`;o
0000?_ooool001cooooo00?o0000ooooooooool0@_ooool2o`0000Gooooo0_l0000=ooooo`?o0000
3?ooool4o`0000Gooooo0_l00006ooooo`;o00002Oooool3o`0000?ooooo0_l00003ooooo`Co0000
0_ooool2o`0000;ooooo1?l00002oooooaOo000000Coooooo`000?l0003ooooo0_l00003ooooo`;o
000000?oooooo`000?l000002Oooool3o`0000Sooooo0_l0000Booooo`;o00000oooool2o`0005Oo
oooo000Looooo`03o`000?oooooooooo04Wooooo0_l000000ooooooo0000o`000007ooooo`;o0000
00Goooooo`000?l0003o0000ooooo`02o`0000_ooooo1?l00002ooooo`?o00001oooool2o`0000_o
oooo0_l000000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o
000000?oooooo`000?l000005_l000001?oooooo0000o`000?ooool2o`0000;ooooo0ol000000ooo
oooo0000o`000009ooooo`Oo00006?ooool2o`0005cooooo000Looooo`03o`000?oooooooooo04co
oooo0ol00006ooooo`;o00001Oooool2o`0000cooooo1ol00008ooooo`;o00002oooool2o`000003
ooooool0003o000000Sooooo1?l00003oooooaOo000000Goooooo`000?l0003o0000ooooo`02o`00
00Gooooo0ol0000<ooooo`Wo00005_ooool2o`0005cooooo000Looooo`03o`000?oooooooooo04go
oooo0_l00006ooooo`;o00000oooool2o`0000Sooooo0_l00005ooooo`Co00002?ooool4o`0000_o
oooo0_l000000ooooooo0000o`000008ooooo`Ko000000?oooooo`000?l000005?l000001?oooooo
0000o`000?l00002ooooo`;o00001_ooool2o`0000kooooo1?l000000ooooooo0000o`000002o`00
01Cooooo0_l0000Gooooo`?o0000@_ooool001cooooo00?o0000ooooooooool0C?ooool2o`0000Ko
oooo0ol00003ooooo`?o000000?oooooo`000?l000001?ooool2o`0000Oooooo0_l00008ooooo`Co
00002oooool2o`000003ooooool0003o000000;o00001_oooolMo`000003ooooool0003o000000Wo
oooo0_l0000@ooooo`Co000000?oooooo`000?l000000_l0000]ooooo`?o0000@_ooool001cooooo
00?o0000ooooooooool0C?ooool2o`0000Kooooo0ol00003ooooo`?o000000?oooooo`000?l00000
0oooool3o`00017ooooo1?l0000?ooooo`?o00000_ooool4o`000003ooooool0003o000000Co0000
00?oooooo`000?l000001?l000000ooooooo0000o`00000:o`0000;ooooo0ol00009ooooo`;o0000
4?ooool4o`000004ooooool0003o0000o`0000gooooo0_l0000:ooooo`;o00004?ooool2o`0004Ko
oooo000Looooo`03o`000?oooooooooo04cooooo0_l00004ooooo`;o000000?oooooo`000?l00000
1Oooool2o`0000Gooooo0ol000000ooooooo0000o`00000>ooooo`Co00004oooool5o`0000?ooooo
0_l00004ooooo`;o00000_ooool?o`000003ooooool0003o000000?ooooo1?l0000Gooooo`?o0000
4?ooool3o`0000?ooooo0_l00003ooooo`?o00004?ooool2o`0004Kooooo000Looooo`03o`000?oo
oooooooo04cooooo0_l00004ooooo`;o00001oooool3o`000003ooooool0003o000000?ooooo0_l0
00000ooooooo0000o`000002o`0002?ooooo0_l00004ooooo`Co00000_ooool2o`000004ooooool0
003o0000oooooa;o00000oooool6o`00013ooooo1?l00002ooooo`;o00004Oooool2o`0000;ooooo
0ol00003ooooo`;o00003oooool2o`0004Sooooo000Looooo`03o`000?oooooooooo04Sooooo0_l0
000Aooooo`?o000000?oooooo`000?l000000oooool3o`0000;ooooo1Ol00008ooooo`;o000000?o
ooooo`000?l000006Oooool4o`0000;ooooo0_l000000ooooooo0000o`000002o`000003ooooool0
003o000000ko00001oooool2o`00013ooooo1?l0000Iooooo`?o00005?ooool2o`0004Sooooo000L
ooooo`03o`000?oooooooooo04Sooooo0_l00009ooooo`;o00001oooool2o`0000Oooooo0ol00002
ooooo`Oo000000Goooooo`000?l0003o0000ooooo`05o`0001oooooo0_l00002ooooo`ko000000Co
ooooo`000?l0003o00006_ooool4o`0001[ooooo0ol0000Dooooo`;o0000B?ooool001cooooo0_l0
001Dooooo`;o00004Oooool2o`0000Cooooo3_l0000Tooooo`ko000000?oooooo`000?l000006Ooo
ool5o`0001[ooooo1?l0001Nooooo`007?ooool00ol0003oooooooooo`1<ooooo`?o00002_ooool2
o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`Co00000_ooool;o`0002Oooooo4Ol0000I
ooooo`Co000000?oooooo`000?l000000_ooool2o`0000Sooooo0_l0000:ooooo`?o00004oooool2
o`0004[ooooo000Looooo`03o`000?oooooooooo04[ooooo1Ol0000:ooooo`;o00000oooool2o`00
0003ooooool0003o000000Cooooo0ol00002ooooo`[o0000:_ooool9o`000003ooooool0003o0000
00;o00006Oooool5o`000004ooooool0003o0000ooooo`?o00002?ooool2o`0000_ooooo0_l0000A
ooooo`Co0000B_ooool001cooooo00?o0000ooooooooool0B_ooool5o`000003ooooool0003o0000
00cooooo0_l00007ooooo`;o000000?oooooo`000?l000000oooool7o`0002[ooooo3Ol0000Ioooo
o`co0000:Oooool2o`0004cooooo000Looooo`03o`000?oooooooooo04[ooooo0_l000000ooooooo
0000o`000003o`0000cooooo1?l00008ooooo`;o00000oooool5o`0002cooooo2ol0000Kooooo`Go
000000?oooooo`000?l000000ol0000Xooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0
B_ooool2o`0000;ooooo0_l0000@ooooo`;o00002?ooool2o`000003ooooool0003o000000Go0000
0oooool2o`0002Oooooo2_l0000Jooooo`;o00000oooool2o`000004ooooool0003o0000o`0001Ko
oooo0_l0000Aooooo`?o0000C_ooool001cooooo00?o0000ooooooooool0Eoooool2o`0000Sooooo
0_l00008ooooo`Wo00000oooool2o`0002Sooooo1ol0000Looooo`;o00000oooool2o`000003oooo
ool0003o000000gooooo0_l00008ooooo`?o00004?ooool2o`0004oooooo000Looooo`03o`000?oo
oooooooo04cooooo0_l000001?oooooo0000o`000?l00005ooooo`;o00002?ooool2o`0000Sooooo
0ol00008ooooo`;o00007oooool2o`0000Sooooo0_l000000ooooooo0000o`000002o`0001oooooo
0_l0000Booooo`;o00001Oooool2o`000004ooooool0003o0000o`00067ooooo000Looooo`03o`00
0?oooooooooo04cooooo0_l000001?oooooo0000o`000?l00005ooooo`?o00001oooool3o`0000So
oooo0ol00007ooooo`;o00007oooool2o`0000_ooooo1?l0000Nooooo`?o00003Oooool2o`0000?o
oooo0_l00005ooooo`?o0000I?ooool001cooooo00?o0000ooooooooool0DOooool2o`0000Gooooo
0_l00002ooooo`;o00001?ooool4o`0000Kooooo0ol00003ooooo`?o000000?oooooo`000?l00000
;Oooool4o`0001Gooooo1?l00004ooooo`;o00003_ooool4o`0000Wooooo0_l0000@ooooo`;o0000
D_ooool001cooooo00?o0000ooooooooool0DOooool2o`0000Oooooo1?l00006ooooo`?o00001_oo
ool2o`0000;ooooo1ol0000]ooooo`Go00005?ooool6o`000003ooooool0003o0000017ooooo0_l0
0006ooooo`;o00004oooool2o`0005;ooooo000Looooo`03o`000?oooooooooo05[ooooo0_l00009
ooooo`;o00001_ooool2o`0000;ooooo0_l00002ooooo`;o0000;oooool8o`0000kooooo0_l00004
ooooo`;o000000?oooooo`000?l000003oooool2o`0000Oooooo0ol0001Wooooo`007?ooool00ol0
003oooooooooo`1Oooooo`;o00000oooool2o`0003Wooooo0_l00007ooooo`So00002Oooool2o`00
0003ooooool0003o000000oooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l00007oooo
o`;o0000J?ooool001cooooo00?o0000ooooooooool0Goooool2o`0000?ooooo0ol00009ooooo`;o
0000;Oooool2o`000003ooooool0003o000000Sooooo1?l00006ooooo`;o000000?oooooo`000?l0
00004_ooool2o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`?o0000Joooool001cooooo
00?o0000ooooooooool0E?ooool2o`0000oooooo0ol00008ooooo`;o00000oooool2o`0002_ooooo
1?l0000:ooooo`;o00001?ooool2o`0002?ooooo0ol0000Booooo`;o0000Eoooool001cooooo00?o
0000ooooooooool0E?ooool4o`0000Gooooo0_l00007ooooo`;o00003Oooool2o`0002gooooo0_l0
000:ooooo`;o00006oooool2o`0000Sooooo1?l0000Eooooo`;o0000Eoooool001cooooo0_l0001G
ooooo`;o00001Oooool2o`0000Oooooo1Ol0000kooooo`;o000000?oooooo`000?l000004_ooool2
o`0000[ooooo1_l00006ooooo`Ko00004?ooool3o`0005_ooooo000Looooo`03o`000?oooooooooo
06Oooooo1?l0000kooooo`;o000000?oooooo`000?l000004_ooool2o`0000;ooooo1ol000000ooo
oooo0000o`000002o`0000Gooooo0_l000000ooooooo0000o`00000Dooooo`?o0000Foooool001co
oooo00?o0000ooooooooool0H_ooool4o`0004Oooooo0_l00008ooooo`;o000000Coooooo`000?l0
003ooooo0_l00002ooooo`Oo00001oooool2o`000004ooooool0003o0000ooooo`;o00004oooool2
o`0005gooooo000Looooo`03o`000?oooooooooo06;ooooo1?l00016ooooo`?o00002?ooool2o`00
0004ooooool0003o0000ooooo`;o00002_ooool2o`0000;ooooo1?l0000Gooooo`Co0000GOooool0
01cooooo00?o0000ooooooooool0FOooool2o`0000oooooo0ol0000oooooo`;o000000?oooooo`00
0?l000005_ooool4o`0000;ooooo0_l0000Fooooo`;o000000?oooooo`000?l000000_l0001Moooo
o`007?ooool00ol0003oooooooooo`1Iooooo`?o00003_ooool3o`0004;ooooo0_l00002ooooo`;o
00001?ooool2o`000003ooooool0003o000000;ooooo0ol00004ooooo`?o00006oooool2o`0006;o
oooo000Looooo`03o`000?oooooooooo05[ooooo0ol0000@ooooo`;o0000A?ooool2o`0000Cooooo
0_l000000ooooooo0000o`000002ooooo`?o00007_ooool4o`0006Cooooo000Looooo`03o`000?oo
oooooooo05_ooooo0_l00007ooooo`;o000000?oooooo`000?l000001?ooool3o`0006kooooo0_l0
00000ooooooo0000o`000002o`0006Cooooo000Looooo`03o`000?oooooooooo05cooooo0_l00006
ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`0006Sooooo0_l00004ooooo`;o0000JOoo
ool001cooooo00?o0000ooooooooool0G?ooool4o`0000Sooooo0_l00006ooooo`;o0000Hoooool2
o`000003ooooool0003o000000Co0000Joooool001cooooo00?o0000ooooooooool0G_ooool2o`00
00Oooooo0_l00007ooooo`Go0000:Oooool2o`0003Gooooo0_l00003ooooo`Co00000oooool3o`00
06Gooooo000Looooo`03o`000?oooooooooo06Oooooo0_l00004ooooo`;o00000oooool3o`0002Wo
oooo0ol00002ooooo`;o00001oooool2o`0001kooooo1?l0000:ooooo`?o00000oooool4o`0006Go
oooo000Looooo`03o`000?oooooooooo06cooooo0ol00004ooooo`Co000000?oooooo`000?l00000
8_ooool5o`0000;ooooo0_l00007ooooo`;o00006Oooool2o`0000?ooooo1?l0000;ooooo`;o0000
0oooool2o`0006Oooooo000Looooo`03o`000?oooooooooo063ooooo0ol00009ooooo`;o00001ooo
ool2o`000004ooooool0003o0000o`00027ooooo0_l00006ooooo`;o00001Oooool2o`0000Sooooo
0_l0000<ooooo`;o00000_ooool2o`0001;ooooo0_l0001/ooooo`0000Koooooonk^k_lb<S;o0000
oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000oooo
ooooool0H?ooool3o`0001Kooooo0ol0000Wooooo`?o00001Oooool2o`0000Oooooo1?l0000;oooo
o`;o00001?ooool2o`0007kooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44
ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1iooooo`?o00009ooo
ool2o`0000kooooo1Ol00007ooooo`;o00002?ooool2o`0007kooooo00000ooooooo410@ooooo`02
ooooo`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo06oooooo0_l00008ooooo`;o00000oooool4o`0002Oooooo0_l00008ooooo`;o00000_oo
ool4o`0000Cooooo0ol0000Cooooo`;o0000L_ooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool02Oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0001_ooooo`;o00003Ooo
ool5o`0002Kooooo0_l00009ooooo`Oo00001Oooool2o`0001?ooooo0_l0001booooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_oo
ool00ol0003oooooooooo`21ooooo`;o0000<Oooool5o`0001Oooooo0_l0001gooooo`0000?ooooo
oa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_oo
ool00ol0003oooooooooo`1dooooo`;o0000>_ooool2o`0000Kooooo1?l00002ooooo`;o00002Ooo
ool2o`0000Gooooo0_l0001gooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`00
0?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`1cooooo`Co00000_ooool4o`0003;o
oooo0ol00006ooooo`So00001_ooool5o`0007kooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^
kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo07?ooooo1?l00002
ooooo`Co0000:?ooool2o`0000Sooooo1?l00009ooooo`Co00001_ooool4o`0007oooooo000Loooo
o`03o`000?oooooooooo0:Gooooo0_l00003ooooo`Co00000oooool3o`0000Oooooo1Ol00029oooo
o`007?ooool00ol0003oooooooooo`1]ooooo`;o0000:_ooool4o`0000Gooooo0_l00006ooooo`Co
00001?ooool2o`0000Oooooo0_l00005ooooo`;o00001Oooool2o`0007kooooo000Looooo`03o`00
0?oooooooooo06gooooo0ol0000:ooooo`;o00000oooool4o`000003ooooool0003o000001?ooooo
1?l00005ooooo`;o00004_ooool2o`0000Gooooo0_l00003ooooo`;o00001Oooool2o`0007kooooo
000Looooo`03o`000?oooooooooo06kooooo0_l0000:ooooo`;o00000oooool4o`000003ooooool0
003o000000_ooooo0_l00002ooooo`?o000000?oooooo`000?l000001Oooool3o`0001?ooooo0ol0
0004ooooo`;o0000R_ooool001cooooo00?o0000ooooooooool0Q?ooool3o`0000Kooooo0_l00002
ooooo`;o00000_ooool3o`000004ooooool0003o0000ooooo`;o00000_ooool3o`0000?ooooo0_l0
000=ooooo`Co0000T?ooool001cooooo00?o0000ooooooooool0Ooooool2o`0000?ooooo0ol00006
ooooo`;o00003Oooool2o`0000Sooooo0_l00006ooooo`?o00001?ooool2o`0009;ooooo000Loooo
o`03o`000?oooooooooo07oooooo0_l0000;ooooo`;o00000_ooool2o`0000;ooooo0_l00005oooo
o`Co00000_ooool2o`0000?ooooo0_l00003ooooo`;o000000Coooooo`000?l0003o0000V?ooool0
01cooooo00?o0000ooooooooool0S?ooool2o`000004ooooool0003o0000o`0000;ooooo0_l00005
ooooo`Co00000_ooool2o`0000Sooooo0ol0002Kooooo`007?ooool00ol0003oooooooooo`2?oooo
o`;o00004Oooool4o`0000?ooooo1Ol0002Kooooo`007?ooool00ol0003oooooooooo`2=ooooo`?o
00001?ooool2o`0000;ooooo0ol00007ooooo`Co00000oooool2o`0009kooooo000Looooo`03o`00
0?oooooooooo08gooooo0ol00004ooooo`;o00000_ooool3o`0000Oooooo0_l0002Uooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000B
ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooood[ooooo000Doooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003o
ooooooooo`05ooooo`?o0000oooooom:ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo
000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomB
ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Booooo`03oeEEEOmVIVKo00000?oo
ooooE?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Gooooo00Co410@o`00
0?l0003ooooo0_l000000ol@413oooooooooo`0Eooooo`Go00000oooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<00?ooooo1Ol0002@ooooo`00Y_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l0
0009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OlQ8B7oV9RHoooooonHV9So8B4Q00?o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A02@ooooo`00Y_ooool01Ol0003ooooooooooooooooo0000
01Wooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol0003ooooooooooooooooo000000Cooooo00?oV9RH
ob4Q8Oo^k^h0TOooool00:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00002oooool0
0onHV9So8B4Qonk^kP03ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801Oooool00onHV9So8B4Qonk^
kP2@ooooo`00Y_ooool01Ol0003oQhN7oooooonYZJWo000001_ooooo00?oMgMgofIVI_ooool00_oo
ool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?oMgMgofIVI_ooool0Soooool00:Gooooo00?o
410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Jooooo`09o`000?ooooooooooooooool@413o
^[Zjoooooonj^[[o410@00Oooooo00?o0000ooooooooool0S_ooool00<?ooooo00Go0000okZj^_oo
ooooV9RHoa0@4003ooooo`05o`000?nj^[[ooooookZj^_l000000oooool01Ol0003o^[ZjoooooonH
V9So410@093ooooo0033ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01OnYZJWo410@o`00
0?l@413oZJVY00?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c02@ooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(288) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.72208 .48086 Mdot
.69745 .48809 Mdot
.41147 .28814 Mdot
.52086 .64088 Mdot
.30431 .46888 Mdot
.3745 .34299 Mdot
.56179 .33337 Mdot
.55386 .33258 Mdot
.38735 .28494 Mdot
.57381 .77086 Mdot
.59063 .33056 Mdot
.47311 .70228 Mdot
.56883 .31738 Mdot
.49683 .65542 Mdot
.34761 .60598 Mdot
.5182 .61172 Mdot
.69645 .45686 Mdot
.34509 .40395 Mdot
.51322 .60795 Mdot
.36302 .31691 Mdot
.5781 .60738 Mdot
.49796 .64171 Mdot
.69274 .51883 Mdot
.49461 .65301 Mdot
.45917 .64042 Mdot
.69397 .477 Mdot
.72205 .48329 Mdot
.45757 .68999 Mdot
.51128 .62027 Mdot
.59092 .3055 Mdot
.42678 .52281 Mdot
.29757 .72491 Mdot
.52524 .56367 Mdot
.71002 .6374 Mdot
.58357 .29929 Mdot
.54432 .37731 Mdot
.39788 .3509 Mdot
.56998 .29455 Mdot
.59494 .32901 Mdot
.57245 .35184 Mdot
.57354 .35006 Mdot
.69563 .47508 Mdot
.54605 .31317 Mdot
.43287 .22391 Mdot
.48517 .65557 Mdot
.76598 .56017 Mdot
.36345 .26299 Mdot
.4643 .65838 Mdot
.67171 .5081 Mdot
.37952 .27972 Mdot
.26021 .54506 Mdot
.54743 .33495 Mdot
.50123 .53024 Mdot
.83353 .35931 Mdot
.55973 .32478 Mdot
.48655 .60666 Mdot
.38807 .30487 Mdot
.49605 .68071 Mdot
.48077 .69804 Mdot
.69884 .60816 Mdot
.5078 .6767 Mdot
.33399 .44592 Mdot
.65834 .52459 Mdot
.37346 .27331 Mdot
.39248 .28259 Mdot
.55264 .30616 Mdot
.66427 .45986 Mdot
.58207 .30692 Mdot
.51213 .62513 Mdot
.37104 .29651 Mdot
.4869 .61454 Mdot
.59097 .32938 Mdot
.71872 .48928 Mdot
.49578 .63451 Mdot
.75258 .41708 Mdot
.60811 .37684 Mdot
.34376 .39174 Mdot
.61195 .54137 Mdot
.40327 .39876 Mdot
.36476 .57864 Mdot
.49598 .63647 Mdot
.58322 .19083 Mdot
.30945 .59858 Mdot
.68 .50785 Mdot
.48734 .567 Mdot
.67281 .28646 Mdot
.46256 .64385 Mdot
.43152 .51674 Mdot
.48291 .71083 Mdot
.26512 .4705 Mdot
.38145 .30426 Mdot
.66184 .48939 Mdot
.48629 .64335 Mdot
.50248 .62461 Mdot
.6414 .75689 Mdot
.51728 .6222 Mdot
.4602 .69704 Mdot
.47002 .46555 Mdot
.55384 .35361 Mdot
.51036 .55707 Mdot
.44724 .3847 Mdot
.48868 .52268 Mdot
.47717 .62035 Mdot
.38247 .32347 Mdot
.66036 .52413 Mdot
.51729 .57054 Mdot
.5847 .31229 Mdot
.48989 .64351 Mdot
.60971 .28868 Mdot
.67603 .51156 Mdot
.45351 .69506 Mdot
.32941 .42725 Mdot
.56353 .51004 Mdot
.71585 .50248 Mdot
.75634 .65877 Mdot
.51761 .65562 Mdot
.48026 .68499 Mdot
.70023 .48669 Mdot
.36321 .34447 Mdot
.53156 .1884 Mdot
.71567 .48324 Mdot
.56418 .35813 Mdot
.68329 .45532 Mdot
.50083 .49143 Mdot
.36207 .34453 Mdot
.48043 .48358 Mdot
.4831 .47748 Mdot
.26954 .65247 Mdot
.5248 .64951 Mdot
.56657 .66189 Mdot
.38052 .33418 Mdot
.71291 .49031 Mdot
.56817 .30983 Mdot
.53627 .66694 Mdot
.67644 .48175 Mdot
.55816 .33606 Mdot
.34425 .45127 Mdot
.339 .40342 Mdot
.70021 .51144 Mdot
.77119 .64851 Mdot
.5541 .36701 Mdot
.54136 .34774 Mdot
.26074 .54857 Mdot
.68109 .50804 Mdot
.32034 .44982 Mdot
.57963 .32449 Mdot
.17737 .44641 Mdot
.4564 .64212 Mdot
.25748 .58611 Mdot
.59373 .20155 Mdot
.26057 .54417 Mdot
.57514 .65615 Mdot
.3212 .43395 Mdot
.55787 .33657 Mdot
.4721 .64523 Mdot
.68253 .49968 Mdot
.67948 .47998 Mdot
.4902 .61585 Mdot
.51143 .56704 Mdot
.49764 .66654 Mdot
.51929 .56402 Mdot
.46413 .4696 Mdot
.48651 .64631 Mdot
.8166 .51839 Mdot
.67305 .49577 Mdot
.50423 .57787 Mdot
.39715 .34779 Mdot
.54891 .62394 Mdot
.54698 .31293 Mdot
.51731 .68121 Mdot
.48808 .59178 Mdot
.48263 .70595 Mdot
.55401 .36167 Mdot
.78219 .42473 Mdot
.386 .39689 Mdot
.58116 .34826 Mdot
.53037 .27125 Mdot
.39217 .33654 Mdot
.47033 .69079 Mdot
.31512 .43027 Mdot
.51171 .54914 Mdot
.48895 .63035 Mdot
.26016 .53686 Mdot
.47927 .6968 Mdot
.57344 .67222 Mdot
.53765 .70401 Mdot
.65005 .27282 Mdot
.77993 .45692 Mdot
.51521 .63478 Mdot
.5902 .73121 Mdot
.26238 .57682 Mdot
.55923 .39197 Mdot
.56885 .30797 Mdot
.36769 .34217 Mdot
.36467 .34301 Mdot
.61475 .32357 Mdot
.73609 .65215 Mdot
.55286 .77823 Mdot
.53347 .66438 Mdot
.49273 .52272 Mdot
.69512 .44964 Mdot
.32214 .43526 Mdot
.70618 .50633 Mdot
.568 .17874 Mdot
.38477 .55823 Mdot
.40799 .56552 Mdot
.43657 .32722 Mdot
.38509 .27361 Mdot
.48818 .51543 Mdot
.31499 .4502 Mdot
.48744 .67311 Mdot
.67902 .51169 Mdot
.26232 .5687 Mdot
.50453 .55772 Mdot
.50781 .84257 Mdot
.71567 .47586 Mdot
.33223 .67904 Mdot
.56266 .324 Mdot
.40441 .30874 Mdot
.46293 .64137 Mdot
.50924 .65317 Mdot
.6702 .5123 Mdot
.46796 .66446 Mdot
.38452 .61676 Mdot
.45573 .64695 Mdot
.36238 .30115 Mdot
.37891 .40006 Mdot
.58614 .34652 Mdot
.4351 .33839 Mdot
.7178 .50107 Mdot
.84195 .48857 Mdot
.39448 .32191 Mdot
.5563 .69009 Mdot
.59038 .32772 Mdot
.34441 .44812 Mdot
.38928 .31659 Mdot
.29987 .45505 Mdot
.50846 .68937 Mdot
.40502 .33555 Mdot
.33507 .43614 Mdot
.42835 .55158 Mdot
.51563 .56859 Mdot
.23598 .62847 Mdot
.56667 .3376 Mdot
.66933 .46841 Mdot
.48113 .63404 Mdot
.50108 .53657 Mdot
.50822 .56435 Mdot
.32314 .65244 Mdot
.49128 .48814 Mdot
.48544 .52089 Mdot
.33877 .56384 Mdot
.35048 .41588 Mdot
.73629 .31435 Mdot
.439 .50589 Mdot
.69826 .45747 Mdot
.50017 .62661 Mdot
.58628 .25086 Mdot
.55959 .33987 Mdot
.49189 .67569 Mdot
.64074 .25564 Mdot
.57702 .32634 Mdot
.48477 .68294 Mdot
.59905 .31459 Mdot
.67605 .49139 Mdot
.36813 .61108 Mdot
.71417 .4682 Mdot
.48136 .65119 Mdot
.59746 .31753 Mdot
.36916 .34809 Mdot
.69195 .47717 Mdot
.49304 .64184 Mdot
.52267 .66781 Mdot
.49564 .52251 Mdot
.45649 .64331 Mdot
.62047 .38618 Mdot
.46335 .65585 Mdot
.4211 .3092 Mdot
.51541 .6218 Mdot
.39702 .47284 Mdot
.23644 .43522 Mdot
.69146 .51228 Mdot
.49138 .48892 Mdot
.38891 .31037 Mdot
.39492 .60498 Mdot
.3318 .68821 Mdot
.48799 .65367 Mdot
.48959 .49256 Mdot
.29638 .66717 Mdot
.54203 .33011 Mdot
.48225 .71145 Mdot
.27848 .44053 Mdot
.38039 .30792 Mdot
.48986 .51991 Mdot
.49543 .57402 Mdot
.72073 .45365 Mdot
.51289 .60952 Mdot
.40373 .33209 Mdot
.70001 .46072 Mdot
.50645 .60863 Mdot
.57892 .39177 Mdot
.49766 .54925 Mdot
.54527 .35024 Mdot
.47115 .51465 Mdot
.46795 .68377 Mdot
.37302 .29327 Mdot
.69217 .47242 Mdot
.55648 .32754 Mdot
.71705 .49951 Mdot
.2739 .53704 Mdot
.31375 .6686 Mdot
.76332 .47274 Mdot
.34731 .44928 Mdot
.17045 .48519 Mdot
.57054 .3569 Mdot
.51698 .54121 Mdot
.38409 .25651 Mdot
.64239 .45204 Mdot
.38178 .31913 Mdot
.78121 .63351 Mdot
.38418 .30323 Mdot
.49551 .59893 Mdot
.36939 .32115 Mdot
.63837 .77115 Mdot
.4941 .69071 Mdot
.39797 .28285 Mdot
.45845 .46205 Mdot
.50486 .68555 Mdot
.67598 .48083 Mdot
.33692 .76678 Mdot
.72365 .64621 Mdot
.72778 .65751 Mdot
.39271 .30693 Mdot
.78964 .62204 Mdot
.45284 .68201 Mdot
.53433 .68206 Mdot
.685 .49559 Mdot
.5179 .54794 Mdot
.33452 .41056 Mdot
.3165 .41665 Mdot
.21999 .49865 Mdot
.33847 .72525 Mdot
.74109 .66374 Mdot
.68261 .48078 Mdot
.37273 .3899 Mdot
.75426 .42052 Mdot
.49847 .54809 Mdot
.55372 .333 Mdot
.7796 .40386 Mdot
.48611 .70897 Mdot
.47542 .49879 Mdot
.38359 .62025 Mdot
.67905 .46504 Mdot
.73618 .52268 Mdot
.5555 .32942 Mdot
.72607 .66047 Mdot
.54635 .76982 Mdot
.49627 .6681 Mdot
.55933 .34552 Mdot
.50859 .56477 Mdot
.43308 .51786 Mdot
.26813 .66199 Mdot
.36203 .23313 Mdot
.48177 .65514 Mdot
.75941 .39362 Mdot
.48438 .63257 Mdot
.26516 .63802 Mdot
.48565 .67484 Mdot
.6838 .47224 Mdot
.45941 .70805 Mdot
.44311 .50765 Mdot
.1816 .37689 Mdot
.38309 .55233 Mdot
.30096 .44942 Mdot
.49874 .65276 Mdot
.50513 .66612 Mdot
.33076 .45608 Mdot
.66828 .47388 Mdot
.48865 .62383 Mdot
.75299 .324 Mdot
.48844 .64079 Mdot
.55115 .30987 Mdot
.3236 .62639 Mdot
.2931 .71532 Mdot
.45319 .67151 Mdot
.71878 .45181 Mdot
.54273 .34905 Mdot
.58687 .3291 Mdot
.50427 .51075 Mdot
.56053 .34099 Mdot
.47123 .65288 Mdot
.32213 .62705 Mdot
.65307 .47065 Mdot
.5013 .55087 Mdot
.67837 .46699 Mdot
.27489 .28619 Mdot
.56541 .33583 Mdot
.49764 .51329 Mdot
.74908 .64259 Mdot
.57819 .3173 Mdot
.3784 .42578 Mdot
.45758 .7083 Mdot
.50319 .55578 Mdot
.72755 .47915 Mdot
.37172 .29733 Mdot
.48502 .50221 Mdot
.55882 .32589 Mdot
.48649 .65522 Mdot
.47701 .61387 Mdot
.56077 .34208 Mdot
.62694 .57893 Mdot
.42757 .52046 Mdot
.48187 .64562 Mdot
.67038 .4832 Mdot
.71144 .48614 Mdot
.53901 .6413 Mdot
.48474 .63058 Mdot
.37394 .34664 Mdot
.48946 .49179 Mdot
.48714 .48903 Mdot
.48128 .47701 Mdot
.39842 .30713 Mdot
.16358 .46887 Mdot
.53778 .33952 Mdot
.29662 .72191 Mdot
.6906 .39358 Mdot
.5038 .53676 Mdot
.37873 .35786 Mdot
.51318 .65583 Mdot
.46873 .63573 Mdot
.59801 .30818 Mdot
.19019 .57553 Mdot
.53365 .68178 Mdot
.71313 .46869 Mdot
.55336 .34171 Mdot
.48131 .59663 Mdot
.60794 .26592 Mdot
.33526 .4183 Mdot
.74791 .6622 Mdot
.5508 .33775 Mdot
.65302 .5027 Mdot
.55028 .3374 Mdot
.50332 .66583 Mdot
.49669 .57356 Mdot
.68592 .46276 Mdot
.30389 .46553 Mdot
.49247 .61731 Mdot
.48241 .68006 Mdot
.47542 .34312 Mdot
.74832 .41562 Mdot
.30151 .47088 Mdot
.47263 .63398 Mdot
.51194 .5194 Mdot
.30684 .46612 Mdot
.47433 .65464 Mdot
.50394 .61081 Mdot
.56696 .66471 Mdot
.57346 .29016 Mdot
.33514 .4646 Mdot
.16711 .40554 Mdot
.71685 .47636 Mdot
.61806 .38971 Mdot
.48252 .50864 Mdot
.57045 .35619 Mdot
.38754 .63841 Mdot
.49081 .5057 Mdot
.71375 .37786 Mdot
.81526 .6824 Mdot
.48609 .50153 Mdot
.39076 .36232 Mdot
.66117 .74536 Mdot
.50306 .61177 Mdot
.47986 .64846 Mdot
.33757 .41062 Mdot
.70229 .49476 Mdot
.78015 .45429 Mdot
.5831 .34614 Mdot
.51138 .64248 Mdot
.72258 .49716 Mdot
.65669 .27512 Mdot
.49308 .51534 Mdot
.32257 .42189 Mdot
.32953 .46414 Mdot
.47965 .64041 Mdot
.3083 .68542 Mdot
.68871 .47665 Mdot
.49292 .64202 Mdot
.47648 .68513 Mdot
.37714 .36544 Mdot
.68429 .51165 Mdot
.40109 .33917 Mdot
.49365 .54834 Mdot
.69392 .74439 Mdot
.5415 .26126 Mdot
.57511 .33135 Mdot
.49942 .50519 Mdot
.58715 .34542 Mdot
.37113 .25959 Mdot
.48904 .49097 Mdot
.49434 .64252 Mdot
.64884 .47631 Mdot
.49155 .64197 Mdot
.4875 .64156 Mdot
.48427 .66061 Mdot
.74183 .6645 Mdot
.4058 .39888 Mdot
.31526 .42756 Mdot
.46421 .67766 Mdot
.40592 .3232 Mdot
.607 .26068 Mdot
.5958 .76958 Mdot
.5037 .65167 Mdot
.48064 .68426 Mdot
.71237 .44904 Mdot
.45806 .63752 Mdot
.57516 .32426 Mdot
.67977 .46387 Mdot
.4747 .62162 Mdot
.45257 .36945 Mdot
.48386 .62663 Mdot
.75709 .49642 Mdot
.55697 .3075 Mdot
.44751 .64033 Mdot
.53103 .59618 Mdot
.49024 .49084 Mdot
.48561 .50435 Mdot
.47892 .47598 Mdot
.55166 .30829 Mdot
.38977 .36108 Mdot
.41713 .27773 Mdot
.54208 .62332 Mdot
.47022 .64944 Mdot
.4941 .57173 Mdot
.41093 .35394 Mdot
.44284 .46032 Mdot
.77259 .6342 Mdot
.47279 .60792 Mdot
.39988 .29878 Mdot
.46972 .46673 Mdot
.60588 .5643 Mdot
.67026 .46919 Mdot
.36374 .28488 Mdot
.59194 .3164 Mdot
.3372 .433 Mdot
.22715 .55581 Mdot
.70669 .47389 Mdot
.6813 .4441 Mdot
.38554 .34743 Mdot
.30936 .62892 Mdot
.8317 .34183 Mdot
.37726 .32854 Mdot
.40109 .58035 Mdot
.68238 .49077 Mdot
.5234 .56337 Mdot
.29336 .65651 Mdot
.31817 .62113 Mdot
.39666 .28858 Mdot
.52343 .66648 Mdot
.29782 .25889 Mdot
.37238 .34486 Mdot
.511 .53287 Mdot
.39449 .30808 Mdot
.54133 .34179 Mdot
.38364 .33023 Mdot
.72137 .5094 Mdot
.52296 .6461 Mdot
.8328 .35366 Mdot
.3229 .58075 Mdot
.51804 .64368 Mdot
.5458 .32431 Mdot
.55669 .38788 Mdot
.49602 .67142 Mdot
.32046 .41636 Mdot
.39204 .36107 Mdot
.34038 .2947 Mdot
.50447 .60069 Mdot
.36968 .3151 Mdot
.6972 .44209 Mdot
.35258 .32386 Mdot
.45219 .37831 Mdot
.48467 .49601 Mdot
.67657 .49612 Mdot
.60717 .375 Mdot
.56314 .35835 Mdot
.51558 .57889 Mdot
.4736 .68852 Mdot
.66982 .49534 Mdot
.40826 .58373 Mdot
.52024 .70354 Mdot
.49087 .63979 Mdot
.39638 .3411 Mdot
.37246 .28205 Mdot
.34506 .60636 Mdot
.39643 .32193 Mdot
.51011 .5284 Mdot
.6713 .4886 Mdot
.50993 .60489 Mdot
.71399 .48549 Mdot
.49819 .62589 Mdot
.60929 .27248 Mdot
.66051 .48453 Mdot
.55565 .69074 Mdot
.52252 .67261 Mdot
.80411 .53031 Mdot
.46375 .684 Mdot
.48367 .6434 Mdot
.36407 .30071 Mdot
.32751 .45616 Mdot
.53954 .68342 Mdot
.61568 .28548 Mdot
.3401 .4393 Mdot
.61653 .58732 Mdot
.36292 .34743 Mdot
.34037 .45328 Mdot
.21438 .52036 Mdot
.48975 .48732 Mdot
.31159 .46013 Mdot
.48986 .56679 Mdot
.57407 .33449 Mdot
.64424 .49324 Mdot
.50723 .68494 Mdot
.68518 .74903 Mdot
.42936 .51563 Mdot
.4962 .52004 Mdot
.47606 .65552 Mdot
.51219 .66289 Mdot
.72234 .49696 Mdot
.57133 .18188 Mdot
.39093 .26527 Mdot
.51599 .55968 Mdot
.71163 .47624 Mdot
.58854 .1956 Mdot
.40016 .28625 Mdot
.34686 .41501 Mdot
.59633 .32831 Mdot
.69787 .53291 Mdot
.49932 .52828 Mdot
.56306 .33673 Mdot
.42559 .30653 Mdot
.26184 .53165 Mdot
.51386 .61144 Mdot
.38873 .35565 Mdot
.26054 .54257 Mdot
.46025 .71362 Mdot
.61501 .32601 Mdot
.53994 .3813 Mdot
.66866 .50348 Mdot
.55959 .34252 Mdot
.31204 .42762 Mdot
.6882 .45324 Mdot
.67614 .46744 Mdot
.5799 .32038 Mdot
.81989 .56769 Mdot
.29694 .66632 Mdot
.60249 .3011 Mdot
.33092 .64795 Mdot
.26165 .54002 Mdot
.49745 .52788 Mdot
.31855 .427 Mdot
.38105 .40232 Mdot
.69591 .4756 Mdot
.77681 .40624 Mdot
.2597 .54443 Mdot
.45589 .69461 Mdot
.33583 .43853 Mdot
.65811 .28158 Mdot
.58076 .36893 Mdot
.57045 .33078 Mdot
.47764 .34002 Mdot
.33553 .44831 Mdot
.52331 .67751 Mdot
.19094 .62363 Mdot
.48712 .6918 Mdot
.57981 .32551 Mdot
.38395 .61889 Mdot
.70085 .50579 Mdot
.54317 .32175 Mdot
.38401 .61711 Mdot
.47044 .63656 Mdot
.51862 .65928 Mdot
.41472 .39651 Mdot
.66307 .50388 Mdot
.496 .54595 Mdot
.51628 .6396 Mdot
.48945 .68241 Mdot
.52119 .58125 Mdot
.28653 .70025 Mdot
.57157 .50314 Mdot
.52316 .57281 Mdot
.41005 .31093 Mdot
.50654 .55879 Mdot
.51602 .55816 Mdot
.72837 .46874 Mdot
.43597 .39405 Mdot
.49072 .53702 Mdot
.47907 .65707 Mdot
.48123 .64941 Mdot
.59808 .32314 Mdot
.29593 .66562 Mdot
.31129 .6232 Mdot
.40912 .28066 Mdot
.30665 .4046 Mdot
.53027 .65409 Mdot
.67679 .50178 Mdot
.32424 .47658 Mdot
.50715 .5159 Mdot
.7116 .46849 Mdot
.52108 .6364 Mdot
.37916 .36703 Mdot
.48716 .49694 Mdot
.5099 .50789 Mdot
.33189 .4372 Mdot
.58786 .34724 Mdot
.61576 .57158 Mdot
.37482 .35329 Mdot
.46196 .63516 Mdot
.29326 .4164 Mdot
.3733 .31097 Mdot
.4959 .52685 Mdot
.50912 .56074 Mdot
.67721 .48747 Mdot
.66077 .50987 Mdot
.38969 .47799 Mdot
.40182 .3118 Mdot
.41077 .24597 Mdot
.55302 .34904 Mdot
.4664 .67937 Mdot
.57382 .3609 Mdot
.68241 .51591 Mdot
.26864 .65211 Mdot
.33442 .46072 Mdot
.57504 .32675 Mdot
.49967 .54962 Mdot
.66504 .47372 Mdot
.68119 .51681 Mdot
.48557 .64783 Mdot
.50061 .64501 Mdot
.36042 .28066 Mdot
.26042 .585 Mdot
.59879 .30728 Mdot
.34392 .4184 Mdot
.40646 .279 Mdot
.4938 .60212 Mdot
.68716 .50678 Mdot
.25721 .69721 Mdot
.4669 .68431 Mdot
.40484 .32084 Mdot
.69538 .4868 Mdot
.33671 .41213 Mdot
.31034 .43217 Mdot
.50772 .63215 Mdot
.57337 .66049 Mdot
.57983 .31422 Mdot
.67744 .47799 Mdot
.63361 .50906 Mdot
.46271 .6728 Mdot
.50074 .64965 Mdot
.46101 .71582 Mdot
.60267 .29405 Mdot
.53006 .61434 Mdot
.30272 .46176 Mdot
.70911 .50741 Mdot
.51055 .63673 Mdot
.33283 .45033 Mdot
.47466 .48106 Mdot
.49032 .5016 Mdot
.38385 .2821 Mdot
.31933 .41614 Mdot
.32563 .45074 Mdot
.34216 .43512 Mdot
.77942 .40264 Mdot
.48737 .55971 Mdot
.32741 .49311 Mdot
.5243 .66672 Mdot
.26217 .53888 Mdot
.52261 .61492 Mdot
.54461 .33909 Mdot
.37487 .29108 Mdot
.48896 .66358 Mdot
.52341 .6687 Mdot
.61152 .55873 Mdot
.51215 .6043 Mdot
.53932 .65042 Mdot
.70066 .50733 Mdot
.62928 .49883 Mdot
.36581 .34019 Mdot
.60047 .20812 Mdot
.22434 .69699 Mdot
.53138 .67531 Mdot
.31253 .62847 Mdot
.66484 .47697 Mdot
.59691 .32648 Mdot
.31967 .65027 Mdot
.57381 .36357 Mdot
.708 .48767 Mdot
.49881 .59683 Mdot
.63369 .55444 Mdot
.33831 .44124 Mdot
.50032 .66535 Mdot
.57833 .30589 Mdot
.49903 .66602 Mdot
.54595 .31903 Mdot
.79122 .60744 Mdot
.29599 .61281 Mdot
.48888 .69425 Mdot
.51645 .62149 Mdot
.57478 .59927 Mdot
.50266 .6488 Mdot
.3553 .23944 Mdot
.69121 .48978 Mdot
.54421 .61836 Mdot
.49574 .5964 Mdot
.71856 .65048 Mdot
.47382 .67333 Mdot
.39613 .64838 Mdot
.49647 .68537 Mdot
.18682 .55006 Mdot
.50072 .69204 Mdot
.47675 .69128 Mdot
.55888 .31292 Mdot
.58459 .34139 Mdot
.66281 .43978 Mdot
.49197 .53634 Mdot
.65372 .27595 Mdot
.48122 .68104 Mdot
.39166 .27044 Mdot
.55496 .7084 Mdot
.32741 .45307 Mdot
.7123 .503 Mdot
.87018 .62326 Mdot
.5398 .32223 Mdot
.4088 .33369 Mdot
.42008 .5412 Mdot
.41133 .32272 Mdot
.37141 .27015 Mdot
.65098 .53235 Mdot
.32021 .42577 Mdot
.48524 .62701 Mdot
.71551 .63067 Mdot
.74699 .40754 Mdot
.4628 .6705 Mdot
.41632 .35479 Mdot
.56344 .66945 Mdot
.37445 .50324 Mdot
.34797 .40634 Mdot
.31735 .44023 Mdot
.55993 .32916 Mdot
.39732 .27483 Mdot
.51341 .55809 Mdot
.34008 .45428 Mdot
.36658 .33237 Mdot
.49595 .49572 Mdot
.42499 .39985 Mdot
.68734 .47615 Mdot
.78755 .62522 Mdot
.77308 .55694 Mdot
.5489 .35398 Mdot
.6167 .28649 Mdot
.6456 .48358 Mdot
.70823 .46261 Mdot
.49221 .53176 Mdot
.39661 .29552 Mdot
.64541 .49986 Mdot
.51142 .63516 Mdot
.50511 .55634 Mdot
.48061 .63716 Mdot
.3485 .41136 Mdot
.47495 .66605 Mdot
.3677 .32692 Mdot
.55751 .31213 Mdot
.38266 .30752 Mdot
.55989 .33334 Mdot
.31042 .74256 Mdot
.52529 .67187 Mdot
.49817 .64971 Mdot
.32162 .6266 Mdot
.69166 .51565 Mdot
.70426 .64653 Mdot
.40203 .31518 Mdot
.38787 .30605 Mdot
.4982 .5954 Mdot
.67521 .45614 Mdot
.29142 .44738 Mdot
.33776 .63967 Mdot
.49261 .68653 Mdot
.69208 .49124 Mdot
.50375 .59258 Mdot
.63597 .34089 Mdot
.31792 .59634 Mdot
.70269 .51485 Mdot
.18421 .37136 Mdot
.51892 .67828 Mdot
.51876 .54475 Mdot
.55622 .6728 Mdot
.31424 .70698 Mdot
.52701 .69845 Mdot
.71465 .47384 Mdot
.51377 .56112 Mdot
.683 .50381 Mdot
.37453 .31606 Mdot
.5417 .32343 Mdot
.68642 .50039 Mdot
.50883 .68166 Mdot
.22441 .6958 Mdot
.56537 .30394 Mdot
.49761 .66261 Mdot
.57993 .30319 Mdot
.66302 .52403 Mdot
.70332 .50022 Mdot
.4965 .49655 Mdot
.40216 .57782 Mdot
.57849 .32016 Mdot
.4695 .65431 Mdot
.76981 .41949 Mdot
.51406 .61064 Mdot
.31794 .39976 Mdot
.52822 .63814 Mdot
.52133 .63537 Mdot
.15646 .45376 Mdot
.3987 .60311 Mdot
.5573 .252 Mdot
.57067 .26598 Mdot
.78298 .42803 Mdot
.72938 .47982 Mdot
.34467 .40614 Mdot
.6113 .52464 Mdot
.48556 .48648 Mdot
.40996 .30727 Mdot
.48699 .65904 Mdot
.47379 .47417 Mdot
.59876 .29736 Mdot
.31253 .45799 Mdot
.47914 .69678 Mdot
.41362 .33904 Mdot
.49765 .48981 Mdot
.56615 .33425 Mdot
.69734 .47506 Mdot
.71082 .49829 Mdot
.4012 .40667 Mdot
.51215 .6382 Mdot
.49794 .64354 Mdot
.5793 .29929 Mdot
.54604 .69556 Mdot
.3416 .42666 Mdot
.45772 .46191 Mdot
.58309 .30513 Mdot
.31544 .59649 Mdot
.66349 .50514 Mdot
.51289 .65959 Mdot
.3279 .62454 Mdot
.78214 .44468 Mdot
.61113 .73885 Mdot
.32224 .43909 Mdot
.32443 .68691 Mdot
.71472 .47422 Mdot
.56628 .31101 Mdot
.21701 .50762 Mdot
.45691 .70931 Mdot
.50886 .67067 Mdot
.32737 .69429 Mdot
.3374 .64148 Mdot
.41972 .54404 Mdot
.50014 .55162 Mdot
.29541 .648 Mdot
.50037 .59413 Mdot
.47528 .61681 Mdot
.53044 .65733 Mdot
.5272 .63535 Mdot
.69325 .49784 Mdot
.72041 .66723 Mdot
.38506 .34167 Mdot
.61074 .71943 Mdot
.33651 .39096 Mdot
.45618 .68748 Mdot
.47666 .62333 Mdot
.62472 .65875 Mdot
.35202 .67741 Mdot
.68679 .48457 Mdot
.73122 .48937 Mdot
.55401 .35796 Mdot
.51617 .61122 Mdot
.40369 .31691 Mdot
.55409 .65228 Mdot
.37977 .29019 Mdot
.69425 .49582 Mdot
.37143 .36183 Mdot
.53442 .34562 Mdot
.38959 .35544 Mdot
.4039 .30195 Mdot
.55182 .31798 Mdot
.65822 .49264 Mdot
.46438 .68772 Mdot
.55089 .3188 Mdot
.29491 .46272 Mdot
.34569 .41074 Mdot
.64723 .4569 Mdot
.52366 .56736 Mdot
.48836 .70776 Mdot
.42671 .24638 Mdot
.39861 .35118 Mdot
.3565 .64435 Mdot
.66001 .49174 Mdot
.33807 .46583 Mdot
.68926 .50286 Mdot
.36855 .4868 Mdot
.32569 .44039 Mdot
.48791 .56705 Mdot
.23233 .59404 Mdot
.52746 .36194 Mdot
.47056 .70588 Mdot
.62975 .49887 Mdot
.38054 .2914 Mdot
.54556 .32255 Mdot
.62491 .26383 Mdot
.51666 .56062 Mdot
.68298 .43898 Mdot
.68708 .52889 Mdot
.48671 .48808 Mdot
.56911 .30955 Mdot
.7845 .5451 Mdot
.51635 .64323 Mdot
.56658 .36178 Mdot
.5282 .639 Mdot
.76233 .65516 Mdot
.32893 .37618 Mdot
.47037 .47135 Mdot
.49601 .5981 Mdot
.40097 .28722 Mdot
.49821 .59597 Mdot
.70499 .72289 Mdot
.25637 .62036 Mdot
.53098 .66378 Mdot
.34541 .67747 Mdot
.37254 .25625 Mdot
.68404 .50718 Mdot
.50588 .53086 Mdot
.49681 .52479 Mdot
.47162 .61696 Mdot
.32534 .8089 Mdot
.32509 .45951 Mdot
.44286 .35148 Mdot
.51317 .67893 Mdot
.4967 .63708 Mdot
.61295 .57257 Mdot
.78899 .6081 Mdot
.49359 .48291 Mdot
.50435 .674 Mdot
.34288 .70407 Mdot
.55574 .32049 Mdot
.5104 .61246 Mdot
.48514 .63507 Mdot
.34901 .31637 Mdot
.56113 .31202 Mdot
.37439 .35886 Mdot
.48851 .48665 Mdot
.37086 .28809 Mdot
.30392 .4677 Mdot
.33257 .68084 Mdot
.27681 .67545 Mdot
.32561 .59833 Mdot
.31358 .42147 Mdot
.45317 .66439 Mdot
.47391 .52259 Mdot
.52207 .6598 Mdot
.31488 .44325 Mdot
.59153 .30574 Mdot
.69022 .49324 Mdot
.77688 .64231 Mdot
.49474 .52398 Mdot
.45726 .66317 Mdot
.35461 .41766 Mdot
.682 .49807 Mdot
.82159 .51306 Mdot
.70042 .49563 Mdot
.56765 .32942 Mdot
.61616 .31906 Mdot
.32886 .44417 Mdot
.68922 .50339 Mdot
.36679 .29574 Mdot
.60903 .34622 Mdot
.45057 .69768 Mdot
.53427 .34368 Mdot
.68464 .52396 Mdot
.70933 .51391 Mdot
.65905 .46281 Mdot
.48876 .6028 Mdot
.34998 .66612 Mdot
.50171 .50945 Mdot
.57334 .30011 Mdot
.41572 .32213 Mdot
.25938 .59308 Mdot
.72184 .5786 Mdot
.3077 .60792 Mdot
.49101 .57044 Mdot
.47534 .66406 Mdot
.47892 .64305 Mdot
.52348 .58266 Mdot
.46097 .50846 Mdot
.52712 .66717 Mdot
.59812 .30753 Mdot
.37094 .32911 Mdot
.50088 .68169 Mdot
.49371 .50214 Mdot
.4405 .46819 Mdot
.33132 .46804 Mdot
.74852 .66465 Mdot
.6454 .45741 Mdot
.68377 .49775 Mdot
.40296 .33208 Mdot
.36314 .35465 Mdot
.34465 .44988 Mdot
.55436 .33702 Mdot
.70363 .49385 Mdot
.18692 .54017 Mdot
.33985 .43327 Mdot
.47906 .65985 Mdot
.323 .62623 Mdot
.33791 .71442 Mdot
.4962 .61389 Mdot
.48374 .66221 Mdot
.48997 .53414 Mdot
.4054 .31706 Mdot
.59576 .77927 Mdot
.81343 .52119 Mdot
.33054 .45007 Mdot
.3469 .43123 Mdot
.66699 .45589 Mdot
.46895 .67568 Mdot
.58078 .31202 Mdot
.29811 .67152 Mdot
.57621 .39334 Mdot
.67496 .2909 Mdot
.37948 .25125 Mdot
.48215 .62802 Mdot
.68797 .71159 Mdot
.50651 .69899 Mdot
.65781 .52224 Mdot
.65185 .49749 Mdot
.68428 .48199 Mdot
.55454 .32394 Mdot
.26437 .52815 Mdot
.57612 .34739 Mdot
.46922 .46626 Mdot
.69967 .46777 Mdot
.40841 .57612 Mdot
.3898 .30657 Mdot
.51892 .61142 Mdot
.31748 .43036 Mdot
.26807 .45243 Mdot
.50604 .53708 Mdot
.32709 .68479 Mdot
.37893 .35794 Mdot
.66664 .46856 Mdot
.51616 .6068 Mdot
.60338 .25985 Mdot
.29551 .62509 Mdot
.36319 .24883 Mdot
.47282 .47397 Mdot
.33451 .44565 Mdot
.56833 .7706 Mdot
.33702 .42377 Mdot
.57622 .32595 Mdot
.52368 .67235 Mdot
.47024 .67913 Mdot
.4836 .64228 Mdot
.53559 .66265 Mdot
.55838 .32368 Mdot
.46547 .70295 Mdot
.39636 .47439 Mdot
.48448 .48008 Mdot
.44725 .49882 Mdot
.3059 .44206 Mdot
.55048 .34693 Mdot
.37171 .31757 Mdot
.4846 .51862 Mdot
.34425 .45789 Mdot
.51656 .60186 Mdot
.51618 .6736 Mdot
.48717 .47833 Mdot
.49196 .5675 Mdot
.49441 .70703 Mdot
.3795 .34597 Mdot
.43516 .51179 Mdot
.32696 .46841 Mdot
.32504 .42954 Mdot
.56489 .34218 Mdot
.68841 .50354 Mdot
.33615 .46253 Mdot
.42031 .3106 Mdot
.51057 .61141 Mdot
.52981 .643 Mdot
.69276 .52269 Mdot
.25993 .53964 Mdot
.33097 .4684 Mdot
.53379 .6215 Mdot
.70398 .51257 Mdot
.68719 .52939 Mdot
.5055 .67213 Mdot
.46149 .70044 Mdot
.72721 .46798 Mdot
.34855 .4307 Mdot
.56059 .34581 Mdot
.30494 .58101 Mdot
.53885 .34004 Mdot
.6949 .47294 Mdot
.50681 .55435 Mdot
.65843 .48205 Mdot
.51657 .56145 Mdot
.7307 .2914 Mdot
.52795 .66515 Mdot
.7307 .53805 Mdot
.43441 .46116 Mdot
.39233 .30574 Mdot
.39189 .29817 Mdot
.48828 .49421 Mdot
.7051 .46421 Mdot
.50918 .52701 Mdot
.32729 .41992 Mdot
.78184 .42717 Mdot
.72834 .46807 Mdot
.4024 .30008 Mdot
.4025 .35019 Mdot
.58225 .30376 Mdot
.47423 .66786 Mdot
.51379 .65876 Mdot
.3874 .35704 Mdot
.59906 .39359 Mdot
.6659 .49843 Mdot
.49748 .64386 Mdot
.52236 .57516 Mdot
.38175 .34192 Mdot
.51661 .33585 Mdot
.64523 .49329 Mdot
.48993 .60084 Mdot
.25911 .63024 Mdot
.54594 .31656 Mdot
.46398 .63882 Mdot
.46885 .70637 Mdot
.32206 .45537 Mdot
.32334 .69016 Mdot
.26101 .54766 Mdot
.53783 .32564 Mdot
.49292 .49436 Mdot
.49174 .61569 Mdot
.38916 .30117 Mdot
.53131 .62353 Mdot
.68807 .78958 Mdot
.48762 .48108 Mdot
.51224 .64087 Mdot
.55414 .6614 Mdot
.71426 .48543 Mdot
.49625 .63976 Mdot
.6096 .27416 Mdot
.398 .33407 Mdot
.51417 .64262 Mdot
.57978 .61915 Mdot
.58035 .30402 Mdot
.50562 .53563 Mdot
.33667 .44536 Mdot
.41119 .56235 Mdot
.33418 .76457 Mdot
.41028 .3543 Mdot
.30342 .4471 Mdot
.47538 .67713 Mdot
.40148 .27405 Mdot
.58165 .3458 Mdot
.50194 .51701 Mdot
.46052 .6424 Mdot
.555 .35535 Mdot
.55201 .32232 Mdot
.33152 .44174 Mdot
.85705 .44084 Mdot
.52593 .6794 Mdot
.50323 .65939 Mdot
.84411 .4796 Mdot
.7358 .51165 Mdot
.49709 .66445 Mdot
.47515 .68543 Mdot
.56636 .33788 Mdot
.26166 .51624 Mdot
.32628 .68619 Mdot
.45742 .46885 Mdot
.54331 .3283 Mdot
.41456 .28126 Mdot
.39607 .34596 Mdot
.30329 .45381 Mdot
.6962 .48636 Mdot
.34654 .44871 Mdot
.38619 .33254 Mdot
.48224 .65235 Mdot
.57448 .34095 Mdot
.52296 .77486 Mdot
.55303 .31083 Mdot
.41926 .33155 Mdot
.65973 .52319 Mdot
.64884 .76817 Mdot
.71001 .77826 Mdot
.56829 .49349 Mdot
.61521 .32924 Mdot
.32709 .45352 Mdot
.81469 .51988 Mdot
.49786 .6836 Mdot
.70482 .71719 Mdot
.50167 .66344 Mdot
.47791 .46695 Mdot
.37094 .3012 Mdot
.49613 .49602 Mdot
.51739 .56045 Mdot
.33138 .68549 Mdot
.54993 .32745 Mdot
.59048 .31055 Mdot
.51245 .5629 Mdot
.57166 .32618 Mdot
.51276 .64812 Mdot
.37467 .33725 Mdot
.78265 .34324 Mdot
.4994 .68467 Mdot
.5416 .61321 Mdot
.55037 .36679 Mdot
.76282 .45259 Mdot
.4213 .29542 Mdot
.701 .68834 Mdot
.64539 .26793 Mdot
.57848 .31261 Mdot
.74355 .66601 Mdot
.40343 .32752 Mdot
.48486 .51972 Mdot
.39287 .26759 Mdot
.50756 .65962 Mdot
.48084 .62874 Mdot
.52287 .58619 Mdot
.47746 .68331 Mdot
.66135 .7299 Mdot
.47735 .71131 Mdot
.60228 .64623 Mdot
.52464 .66548 Mdot
.64749 .54215 Mdot
.59123 .33088 Mdot
.51017 .56037 Mdot
.32838 .55876 Mdot
.52322 .6419 Mdot
.72792 .48011 Mdot
.54685 .34685 Mdot
.63137 .24832 Mdot
.55723 .32137 Mdot
.3827 .30552 Mdot
.55298 .3326 Mdot
.46388 .69771 Mdot
.70853 .48225 Mdot
.39015 .32187 Mdot
.5027 .53428 Mdot
.41366 .31051 Mdot
.51781 .64345 Mdot
.50565 .31706 Mdot
.40713 .33592 Mdot
.45881 .71099 Mdot
.7101 .48547 Mdot
.24274 .65701 Mdot
.64318 .48353 Mdot
.4901 .65046 Mdot
.49197 .65785 Mdot
.48883 .47764 Mdot
.55768 .33647 Mdot
.65673 .48678 Mdot
.48031 .33531 Mdot
.33856 .46569 Mdot
.69104 .48289 Mdot
.55513 .68455 Mdot
.30878 .63064 Mdot
.71599 .50223 Mdot
.34132 .70941 Mdot
.57756 .32664 Mdot
.71749 .48154 Mdot
.53526 .71831 Mdot
.60722 .72042 Mdot
.32959 .42566 Mdot
.36588 .29607 Mdot
.3117 .64324 Mdot
.39806 .34257 Mdot
.60671 .26802 Mdot
.36322 .29891 Mdot
.56974 .30445 Mdot
.56277 .67883 Mdot
.38465 .61733 Mdot
.57786 .2942 Mdot
.50747 .30443 Mdot
.39032 .34106 Mdot
.52056 .56827 Mdot
.44194 .50444 Mdot
.51203 .51405 Mdot
.51703 .5364 Mdot
.54135 .3194 Mdot
.71776 .4797 Mdot
.68631 .454 Mdot
.55508 .64774 Mdot
.70598 .50466 Mdot
.3795 .32406 Mdot
.33432 .60093 Mdot
.74887 .64238 Mdot
.59565 .31693 Mdot
.43054 .51865 Mdot
.4778 .62068 Mdot
.36886 .31802 Mdot
.37802 .32087 Mdot
.55215 .32512 Mdot
.63588 .7046 Mdot
.51189 .52329 Mdot
.71092 .53325 Mdot
.70624 .47254 Mdot
.71513 .48552 Mdot
.67565 .51219 Mdot
.26242 .52841 Mdot
.54491 .32602 Mdot
.70671 .46609 Mdot
.5364 .65947 Mdot
.47187 .67394 Mdot
.48499 .50931 Mdot
.34833 .41317 Mdot
.4745 .70972 Mdot
.50923 .52584 Mdot
.50726 .67023 Mdot
.39553 .30897 Mdot
.5593 .70402 Mdot
.482 .48328 Mdot
.40376 .3153 Mdot
.39927 .30905 Mdot
.49048 .49066 Mdot
.55742 .70409 Mdot
.61176 .75838 Mdot
.46339 .62548 Mdot
.66158 .53508 Mdot
.39193 .29474 Mdot
.46573 .36489 Mdot
.72063 .54195 Mdot
.47006 .65792 Mdot
.45096 .46122 Mdot
.37404 .33021 Mdot
.73093 .48189 Mdot
.50565 .65269 Mdot
.49392 .53535 Mdot
.33479 .42799 Mdot
.50303 .52944 Mdot
.49078 .53556 Mdot
.67615 .50584 Mdot
.42186 .25099 Mdot
.72219 .49808 Mdot
.36097 .35547 Mdot
.50534 .54323 Mdot
.83197 .34689 Mdot
.37979 .29408 Mdot
.78112 .4202 Mdot
.38661 .61175 Mdot
.51635 .66742 Mdot
.40144 .33414 Mdot
.70545 .44459 Mdot
.55147 .30651 Mdot
.35639 .66389 Mdot
.69113 .50506 Mdot
.48215 .51154 Mdot
.48719 .50943 Mdot
.38397 .34242 Mdot
.68534 .46946 Mdot
.46692 .70488 Mdot
.71121 .49589 Mdot
.58199 .33601 Mdot
.49396 .5859 Mdot
.65272 .27514 Mdot
.51152 .55642 Mdot
.70735 .50646 Mdot
.41717 .32347 Mdot
.30411 .46539 Mdot
.49218 .69105 Mdot
.63724 .25137 Mdot
.47478 .67695 Mdot
.58658 .3036 Mdot
.42547 .47031 Mdot
.55053 .75067 Mdot
.48348 .67312 Mdot
.47362 .62847 Mdot
.53055 .35115 Mdot
.48619 .67438 Mdot
.51157 .62151 Mdot
.78472 .54794 Mdot
.71279 .50692 Mdot
.49904 .68226 Mdot
.37991 .35351 Mdot
.5896 .62646 Mdot
.49846 .63307 Mdot
.61409 .27694 Mdot
.31201 .69887 Mdot
.41662 .46677 Mdot
.55112 .62923 Mdot
.26761 .64915 Mdot
.49598 .65875 Mdot
.46813 .66451 Mdot
.49444 .58419 Mdot
.69136 .71326 Mdot
.39014 .33433 Mdot
.40129 .28389 Mdot
.30224 .45874 Mdot
.32914 .69561 Mdot
.32857 .43278 Mdot
.58122 .34654 Mdot
.41556 .55018 Mdot
.48129 .4792 Mdot
.68651 .50408 Mdot
.48678 .63923 Mdot
.41552 .30843 Mdot
.51176 .65544 Mdot
.4694 .62179 Mdot
.37977 .3291 Mdot
.37485 .3213 Mdot
.36993 .37796 Mdot
.33747 .4476 Mdot
.68444 .48991 Mdot
.50851 .68697 Mdot
.33976 .44176 Mdot
.52215 .58272 Mdot
.29525 .58894 Mdot
.68453 .48685 Mdot
.70505 .5081 Mdot
.68524 .45903 Mdot
.47787 .69282 Mdot
.4904 .58871 Mdot
.57139 .35123 Mdot
.69288 .52276 Mdot
.58215 .31693 Mdot
.40135 .33605 Mdot
.37121 .34208 Mdot
.50724 .66063 Mdot
.54752 .69066 Mdot
.30958 .43491 Mdot
.40466 .34248 Mdot
.47812 .50203 Mdot
.31443 .4647 Mdot
.48263 .63221 Mdot
.40001 .34027 Mdot
.32713 .41352 Mdot
.62867 .71597 Mdot
.66026 .33003 Mdot
.30553 .46288 Mdot
.51943 .55636 Mdot
.70468 .58748 Mdot
.25694 .61165 Mdot
.32448 .47375 Mdot
.59138 .3299 Mdot
.4681 .68726 Mdot
.46353 .47189 Mdot
.32825 .46637 Mdot
.25641 .56155 Mdot
.38421 .32744 Mdot
.51726 .54011 Mdot
.56521 .51452 Mdot
.74569 .64348 Mdot
.30544 .46686 Mdot
.70858 .50641 Mdot
.67431 .51877 Mdot
.47972 .66421 Mdot
.41165 .55937 Mdot
.59717 .30024 Mdot
.36219 .35294 Mdot
.40629 .28887 Mdot
.65508 .50707 Mdot
.32255 .59706 Mdot
.38384 .35327 Mdot
.46693 .67727 Mdot
.34831 .39776 Mdot
.53871 .64814 Mdot
.37771 .48811 Mdot
.54052 .7526 Mdot
.55848 .65564 Mdot
.30487 .46507 Mdot
.59508 .30057 Mdot
.5596 .31055 Mdot
.55762 .33131 Mdot
.3824 .34936 Mdot
.31699 .64983 Mdot
.40469 .28367 Mdot
.83836 .49479 Mdot
.32525 .46002 Mdot
.17351 .47159 Mdot
.52843 .6855 Mdot
.51818 .66361 Mdot
.51851 .61653 Mdot
.51821 .57295 Mdot
.49636 .65727 Mdot
.55765 .35676 Mdot
.37151 .28972 Mdot
.53665 .38218 Mdot
.66955 .48471 Mdot
.82178 .5156 Mdot
.39113 .30784 Mdot
.4928 .54226 Mdot
.31204 .43386 Mdot
.27662 .68265 Mdot
.31363 .41523 Mdot
.38512 .36304 Mdot
.5054 .62364 Mdot
.66972 .45351 Mdot
.18882 .56093 Mdot
.492 .63895 Mdot
.3998 .35046 Mdot
.41506 .28798 Mdot
.61885 .70991 Mdot
.43036 .6308 Mdot
.56869 .3946 Mdot
.32839 .62047 Mdot
.30303 .43197 Mdot
.52567 .56749 Mdot
.3014 .68021 Mdot
.38618 .33445 Mdot
.3912 .28508 Mdot
.31005 .48093 Mdot
.7618 .44605 Mdot
.69809 .46337 Mdot
.6363 .50057 Mdot
.5579 .35398 Mdot
.51906 .66689 Mdot
.39349 .34278 Mdot
.64436 .5086 Mdot
.3057 .54751 Mdot
.56409 .32525 Mdot
.4085 .33505 Mdot
.47479 .67953 Mdot
.482 .67386 Mdot
.33024 .43396 Mdot
.43597 .4669 Mdot
.51188 .5144 Mdot
.78121 .42549 Mdot
.30941 .61773 Mdot
.38655 .61072 Mdot
.509 .67068 Mdot
.6767 .51119 Mdot
.48973 .49095 Mdot
.31861 .42643 Mdot
.53252 .62673 Mdot
.68495 .74643 Mdot
.72729 .49838 Mdot
.58065 .31725 Mdot
.4988 .53306 Mdot
.33736 .67927 Mdot
.47572 .68055 Mdot
.50214 .66304 Mdot
.48946 .60239 Mdot
.63032 .77411 Mdot
.37503 .29159 Mdot
.68804 .51219 Mdot
.33527 .44753 Mdot
.70337 .49888 Mdot
.35823 .35333 Mdot
.43239 .51246 Mdot
.48854 .69621 Mdot
.72829 .4904 Mdot
.70557 .48955 Mdot
.58737 .30463 Mdot
.55356 .31409 Mdot
.42187 .33829 Mdot
.47647 .68796 Mdot
.48199 .47696 Mdot
.70993 .47025 Mdot
.36208 .31588 Mdot
.32871 .43509 Mdot
.61191 .26856 Mdot
.5221 .67056 Mdot
.38684 .33973 Mdot
.50729 .53316 Mdot
.67278 .49212 Mdot
.40249 .32028 Mdot
.48523 .5215 Mdot
.34779 .4211 Mdot
.48385 .62305 Mdot
.3566 .25237 Mdot
.49441 .53904 Mdot
.49397 .68935 Mdot
.57336 .70331 Mdot
.41293 .55722 Mdot
.47597 .49445 Mdot
.36778 .34386 Mdot
.49096 .52579 Mdot
.66686 .51176 Mdot
.59518 .73073 Mdot
.38869 .28301 Mdot
.63484 .55258 Mdot
.38178 .62519 Mdot
.51465 .5611 Mdot
.6845 .50676 Mdot
.41967 .40214 Mdot
.74807 .42616 Mdot
.25957 .60652 Mdot
.50762 .64065 Mdot
.39768 .34286 Mdot
.33193 .42754 Mdot
.59012 .31122 Mdot
.60778 .29277 Mdot
.39787 .41545 Mdot
.40075 .30261 Mdot
.48709 .63838 Mdot
.71722 .47943 Mdot
.57746 .3203 Mdot
.61575 .5764 Mdot
.40608 .27998 Mdot
.3793 .3551 Mdot
.49735 .60209 Mdot
.3275 .43229 Mdot
.46742 .5147 Mdot
.38109 .28281 Mdot
.37727 .28012 Mdot
.78093 .55035 Mdot
.30485 .42931 Mdot
.4863 .60412 Mdot
.55602 .65163 Mdot
.52054 .6239 Mdot
.82895 .50424 Mdot
.48672 .52 Mdot
.66861 .48523 Mdot
.49137 .66474 Mdot
.38671 .24482 Mdot
.37494 .29977 Mdot
.32841 .62014 Mdot
.525 .35634 Mdot
.54901 .32392 Mdot
.39672 .33135 Mdot
.50669 .64658 Mdot
.61729 .28915 Mdot
.30473 .4549 Mdot
.49208 .59757 Mdot
.51426 .56321 Mdot
.66327 .51612 Mdot
.57342 .34285 Mdot
.58502 .6391 Mdot
.59033 .31879 Mdot
.5617 .34158 Mdot
.73604 .44681 Mdot
.4794 .66325 Mdot
.39444 .31283 Mdot
.40828 .34798 Mdot
.52786 .58635 Mdot
.46579 .34912 Mdot
.6809 .46447 Mdot
.41912 .27069 Mdot
.67219 .75673 Mdot
.53343 .66152 Mdot
.49771 .54805 Mdot
.47258 .46696 Mdot
.61578 .32235 Mdot
.48448 .66937 Mdot
.67975 .50383 Mdot
.37689 .28324 Mdot
.39208 .34752 Mdot
.45833 .70979 Mdot
.55825 .31137 Mdot
.34048 .40961 Mdot
.38017 .3191 Mdot
.31042 .57997 Mdot
.51182 .63967 Mdot
.56653 .36834 Mdot
.38233 .31739 Mdot
.23709 .70282 Mdot
.39728 .24062 Mdot
.71752 .49491 Mdot
.47416 .63068 Mdot
.64694 .48636 Mdot
.30148 .44641 Mdot
.37996 .2686 Mdot
.58774 .30183 Mdot
.50375 .5394 Mdot
.59087 .21523 Mdot
.38656 .34694 Mdot
.69331 .49536 Mdot
.48364 .65587 Mdot
.73656 .6703 Mdot
.49632 .68526 Mdot
.26133 .51388 Mdot
.32737 .46933 Mdot
.59732 .26818 Mdot
.57881 .29949 Mdot
.47116 .63497 Mdot
.34245 .43088 Mdot
.40512 .35474 Mdot
.3803 .33015 Mdot
.6195 .22784 Mdot
.48821 .52957 Mdot
.37428 .26666 Mdot
.48862 .69068 Mdot
.36086 .34475 Mdot
.72306 .57801 Mdot
.55238 .31959 Mdot
.51741 .62169 Mdot
.41052 .32723 Mdot
.75219 .43288 Mdot
.31999 .62484 Mdot
.50901 .63916 Mdot
.55212 .67479 Mdot
.56999 .3053 Mdot
.81571 .52206 Mdot
.36897 .30692 Mdot
.51754 .59903 Mdot
.56544 .35949 Mdot
.562 .6795 Mdot
.55246 .39399 Mdot
.68415 .48954 Mdot
.4057 .34769 Mdot
.56145 .3466 Mdot
.51324 .54978 Mdot
.32988 .41391 Mdot
.42064 .30937 Mdot
.41217 .31587 Mdot
.45464 .65196 Mdot
.51636 .58056 Mdot
.55025 .68784 Mdot
.66229 .48949 Mdot
.57159 .33492 Mdot
.4734 .61676 Mdot
.29128 .58962 Mdot
.50316 .58463 Mdot
.57179 .33738 Mdot
.83878 .38724 Mdot
.50123 .62114 Mdot
.52198 .66901 Mdot
.72871 .6835 Mdot
.66231 .47108 Mdot
.68956 .51837 Mdot
.30156 .61279 Mdot
.45656 .67988 Mdot
.40646 .58171 Mdot
.68614 .49298 Mdot
.69665 .49478 Mdot
.40709 .5799 Mdot
.45697 .64403 Mdot
.64064 .48363 Mdot
.57568 .32228 Mdot
.54938 .32216 Mdot
.71456 .48628 Mdot
.52379 .61926 Mdot
.59551 .32915 Mdot
.64588 .69137 Mdot
.39534 .3572 Mdot
.30792 .6835 Mdot
.70887 .49163 Mdot
.32122 .62903 Mdot
.57577 .32701 Mdot
.30626 .72986 Mdot
.31545 .70844 Mdot
.53015 .67538 Mdot
.48107 .66821 Mdot
.32356 .45264 Mdot
.50455 .53344 Mdot
.48865 .48854 Mdot
.55721 .33197 Mdot
.46058 .50842 Mdot
.68482 .481 Mdot
.45955 .68523 Mdot
.25971 .58908 Mdot
.35079 .77163 Mdot
.46941 .7465 Mdot
.69691 .48795 Mdot
.69508 .47644 Mdot
.37345 .35541 Mdot
.37239 .36444 Mdot
.50332 .69023 Mdot
.56442 .30685 Mdot
.71766 .48671 Mdot
.57643 .33554 Mdot
.38538 .3333 Mdot
.38908 .3085 Mdot
.48202 .48813 Mdot
.51571 .53553 Mdot
.39229 .32811 Mdot
.61498 .27994 Mdot
.29188 .58967 Mdot
.67713 .52414 Mdot
.84351 .48721 Mdot
.29575 .72117 Mdot
.76686 .65219 Mdot
.3336 .42747 Mdot
.55607 .70658 Mdot
.56334 .35883 Mdot
.47039 .63539 Mdot
.50033 .66867 Mdot
.49298 .51453 Mdot
.5607 .36093 Mdot
.31079 .45269 Mdot
.55045 .32207 Mdot
.33441 .41495 Mdot
.40291 .28837 Mdot
.49235 .63606 Mdot
.5151 .63412 Mdot
.58901 .30924 Mdot
.37663 .35993 Mdot
.40716 .33241 Mdot
.32848 .42309 Mdot
.28044 .68653 Mdot
.38415 .34087 Mdot
.70787 .49183 Mdot
.64336 .56558 Mdot
.48814 .51107 Mdot
.50511 .65186 Mdot
.26813 .65293 Mdot
.58809 .7347 Mdot
.52376 .58639 Mdot
.49806 .53157 Mdot
.85651 .43734 Mdot
.50928 .63344 Mdot
.58581 .19448 Mdot
.48046 .48305 Mdot
.65853 .48095 Mdot
.39759 .31914 Mdot
.49363 .54186 Mdot
.56491 .66096 Mdot
.32416 .38002 Mdot
.52514 .59109 Mdot
.6993 .46324 Mdot
.67631 .46131 Mdot
.43344 .513 Mdot
.83076 .5084 Mdot
.33596 .44526 Mdot
.3098 .45762 Mdot
.37964 .28833 Mdot
.60434 .26461 Mdot
.53643 .67546 Mdot
.31586 .45954 Mdot
.65592 .4518 Mdot
.48842 .60619 Mdot
.41715 .54999 Mdot
.44471 .50088 Mdot
.67434 .51519 Mdot
.45412 .63768 Mdot
.37789 .29208 Mdot
.69242 .49364 Mdot
.43851 .50839 Mdot
.5054 .6066 Mdot
.68436 .48452 Mdot
.56213 .33878 Mdot
.40629 .65032 Mdot
.71015 .4986 Mdot
.35793 .659 Mdot
.57957 .30969 Mdot
.42237 .53873 Mdot
.19923 .47992 Mdot
.26897 .7518 Mdot
.5554 .31786 Mdot
.40425 .341 Mdot
.39318 .34164 Mdot
.37873 .34155 Mdot
.66702 .50277 Mdot
.37448 .31195 Mdot
.67531 .47201 Mdot
.6142 .33364 Mdot
.33023 .69054 Mdot
.32716 .44273 Mdot
.43812 .3835 Mdot
.71406 .48868 Mdot
.83517 .49753 Mdot
.82548 .67302 Mdot
.50638 .58278 Mdot
.57638 .29431 Mdot
.32778 .46351 Mdot
.33421 .61443 Mdot
.32169 .45486 Mdot
.40346 .32823 Mdot
.33406 .68248 Mdot
.51369 .65027 Mdot
.65225 .31937 Mdot
.33061 .42795 Mdot
.69777 .4956 Mdot
.4527 .68022 Mdot
.37926 .36933 Mdot
.30238 .44891 Mdot
.32303 .42899 Mdot
.49795 .6564 Mdot
.66573 .4693 Mdot
.40578 .32856 Mdot
.54991 .35604 Mdot
.36429 .39796 Mdot
.51286 .71356 Mdot
.50287 .6309 Mdot
.52908 .65272 Mdot
.31215 .62602 Mdot
.60983 .26445 Mdot
.57558 .3112 Mdot
.2593 .55998 Mdot
.36829 .32509 Mdot
.25626 .60337 Mdot
.7532 .42158 Mdot
.42196 .39469 Mdot
.48705 .51986 Mdot
.48409 .51512 Mdot
.495 .64294 Mdot
.75618 .73783 Mdot
.42314 .63139 Mdot
.59095 .33698 Mdot
.49035 .50731 Mdot
.38112 .36555 Mdot
.71253 .51415 Mdot
.55326 .50261 Mdot
.50548 .70074 Mdot
.55026 .35676 Mdot
.38106 .3358 Mdot
.67952 .79937 Mdot
.33098 .45444 Mdot
.33187 .61206 Mdot
.47778 .6868 Mdot
.49725 .64664 Mdot
.56422 .32028 Mdot
.59327 .30372 Mdot
.78002 .55294 Mdot
.4117 .46566 Mdot
.65608 .2753 Mdot
.54593 .30613 Mdot
.67639 .80348 Mdot
.47459 .46904 Mdot
.68518 .4739 Mdot
.49362 .49422 Mdot
.59114 .29884 Mdot
.49493 .66499 Mdot
.6629 .47123 Mdot
.50149 .51448 Mdot
.6932 .44796 Mdot
.40982 .56456 Mdot
.30508 .58157 Mdot
.47531 .66599 Mdot
.65644 .46912 Mdot
.68918 .49024 Mdot
.68564 .53417 Mdot
.48573 .49629 Mdot
.50568 .67399 Mdot
.51942 .60139 Mdot
.52705 .66043 Mdot
.76205 .56285 Mdot
.49758 .6388 Mdot
.75632 .42354 Mdot
.30403 .60411 Mdot
.31981 .23693 Mdot
.51778 .63971 Mdot
.55587 .33987 Mdot
.48578 .64398 Mdot
.34338 .42945 Mdot
.49232 .61761 Mdot
.40245 .57891 Mdot
.57433 .31952 Mdot
.70252 .72681 Mdot
.33988 .39108 Mdot
.5008 .62918 Mdot
.31537 .41998 Mdot
.77459 .38377 Mdot
.26113 .56268 Mdot
.78105 .54759 Mdot
.71118 .49527 Mdot
.39459 .27062 Mdot
.59671 .29866 Mdot
.3839 .30515 Mdot
.45841 .7022 Mdot
.48751 .48388 Mdot
.16328 .46886 Mdot
.28137 .60847 Mdot
.49284 .66458 Mdot
.5131 .52199 Mdot
.69832 .5109 Mdot
.37672 .29663 Mdot
.79042 .60957 Mdot
.51241 .60998 Mdot
.34872 .43423 Mdot
.33773 .45457 Mdot
.2798 .4403 Mdot
.75839 .49214 Mdot
.74198 .56806 Mdot
.56619 .31895 Mdot
.38435 .34997 Mdot
.32318 .46729 Mdot
.63137 .48878 Mdot
.58342 .29626 Mdot
.61508 .32276 Mdot
.56986 .34574 Mdot
.52174 .65188 Mdot
.48172 .49607 Mdot
.76891 .48792 Mdot
.48996 .53047 Mdot
.52856 .6323 Mdot
.41182 .31611 Mdot
.48689 .5234 Mdot
.3223 .44594 Mdot
.56081 .34449 Mdot
.39326 .30795 Mdot
.49003 .65474 Mdot
.68315 .49584 Mdot
.38082 .49854 Mdot
.36508 .25936 Mdot
.41304 .55629 Mdot
.41313 .5561 Mdot
.70412 .52706 Mdot
.46706 .47868 Mdot
.50122 .32109 Mdot
.61212 .71923 Mdot
.37733 .4003 Mdot
.53738 .6885 Mdot
.46493 .33595 Mdot
.4041 .28217 Mdot
.38804 .32151 Mdot
.51669 .65377 Mdot
.36142 .33055 Mdot
.47027 .69042 Mdot
.36711 .34337 Mdot
.7832 .44084 Mdot
.47456 .70814 Mdot
.38121 .32379 Mdot
.50292 .51091 Mdot
.49442 .69002 Mdot
.68891 .5109 Mdot
.39258 .27318 Mdot
.53035 .67505 Mdot
.23691 .28897 Mdot
.5878 .30525 Mdot
.4854 .49903 Mdot
.35572 .58727 Mdot
.56875 .33182 Mdot
.69128 .4647 Mdot
.46518 .68323 Mdot
.31912 .46221 Mdot
.69331 .47304 Mdot
.30001 .41269 Mdot
.32541 .43113 Mdot
.33281 .59787 Mdot
.70483 .47536 Mdot
.48825 .51497 Mdot
.34773 .43298 Mdot
.52742 .58427 Mdot
.38577 .3234 Mdot
.37351 .25183 Mdot
.49743 .54249 Mdot
.51347 .65424 Mdot
.38151 .36761 Mdot
.5506 .32966 Mdot
.48359 .6354 Mdot
.3936 .34404 Mdot
.49523 .50376 Mdot
.511 .68186 Mdot
.45714 .68577 Mdot
.80914 .52557 Mdot
.43098 .46282 Mdot
.32509 .44408 Mdot
.66045 .52328 Mdot
.53516 .65404 Mdot
.34079 .42731 Mdot
.37464 .2559 Mdot
.49984 .5762 Mdot
.71846 .47596 Mdot
.63848 .69323 Mdot
.36292 .35291 Mdot
.56343 .30507 Mdot
.41858 .33113 Mdot
.3 .44801 Mdot
.85595 .63902 Mdot
.48706 .48761 Mdot
.46363 .62341 Mdot
.51802 .6271 Mdot
.38636 .26689 Mdot
.68858 .48718 Mdot
.66627 .283 Mdot
.48312 .62314 Mdot
.49471 .5715 Mdot
.50191 .6539 Mdot
.34081 .29279 Mdot
.66174 .49587 Mdot
.50392 .65335 Mdot
.54876 .66963 Mdot
.52702 .63744 Mdot
.31199 .42705 Mdot
.17629 .48035 Mdot
.51331 .57205 Mdot
.82778 .32728 Mdot
.49802 .50566 Mdot
.3774 .33143 Mdot
.35854 .65707 Mdot
.35528 .58117 Mdot
.27465 .28639 Mdot
.68604 .46445 Mdot
.65803 .53368 Mdot
.38861 .30947 Mdot
.40618 .40591 Mdot
.46941 .51213 Mdot
.4529 .67661 Mdot
.47297 .68519 Mdot
.40342 .32806 Mdot
.36282 .31129 Mdot
.49438 .49136 Mdot
.52323 .55309 Mdot
.48362 .59213 Mdot
.41627 .32098 Mdot
.4963 .63721 Mdot
.57993 .73723 Mdot
.57543 .29283 Mdot
.7162 .49947 Mdot
.59173 .31294 Mdot
.56048 .29844 Mdot
.77701 .64148 Mdot
.30775 .61986 Mdot
.55834 .35466 Mdot
.57685 .35407 Mdot
.42142 .40385 Mdot
.74635 .64892 Mdot
.31574 .42308 Mdot
.42243 .62923 Mdot
.37172 .33825 Mdot
.50396 .67491 Mdot
.662 .49806 Mdot
.33459 .4925 Mdot
.68493 .2868 Mdot
.45314 .77924 Mdot
.48279 .60932 Mdot
.37032 .3192 Mdot
.4978 .54395 Mdot
.51034 .56109 Mdot
.25679 .60915 Mdot
.50158 .64101 Mdot
.36269 .35529 Mdot
.7482 .6431 Mdot
.58384 .39015 Mdot
.61742 .29423 Mdot
.72684 .5278 Mdot
.48556 .64307 Mdot
.6659 .49603 Mdot
.53947 .33466 Mdot
.33949 .43108 Mdot
.32841 .45217 Mdot
.50036 .6287 Mdot
.38679 .61177 Mdot
.37152 .3945 Mdot
.45529 .68462 Mdot
.45862 .64044 Mdot
.49182 .52517 Mdot
.46375 .6267 Mdot
.52246 .60628 Mdot
.47114 .62302 Mdot
.5217 .58018 Mdot
.5838 .29698 Mdot
.77419 .62887 Mdot
.51316 .56035 Mdot
.4721 .7011 Mdot
.54145 .32629 Mdot
.46154 .70143 Mdot
.55652 .32274 Mdot
.60344 .2557 Mdot
.566 .35318 Mdot
.3296 .44884 Mdot
.36921 .36843 Mdot
.80463 .53308 Mdot
.71704 .48474 Mdot
.54703 .32273 Mdot
.3467 .41432 Mdot
.55393 .3281 Mdot
.37318 .3474 Mdot
.60697 .37882 Mdot
.74072 .50214 Mdot
.31592 .57989 Mdot
.74962 .65945 Mdot
.54174 .37454 Mdot
.36296 .34593 Mdot
.71519 .48433 Mdot
.60911 .27284 Mdot
.46918 .63926 Mdot
.33265 .45322 Mdot
.49452 .64403 Mdot
.56103 .34327 Mdot
.37055 .33248 Mdot
.79532 .53562 Mdot
.32487 .44553 Mdot
.84931 .47499 Mdot
.41619 .31005 Mdot
.50723 .61997 Mdot
.54139 .32407 Mdot
.60601 .28066 Mdot
.58338 .3026 Mdot
.3223 .69297 Mdot
.4699 .47114 Mdot
.36619 .47739 Mdot
.69949 .47584 Mdot
.47908 .47296 Mdot
.35974 .81021 Mdot
.73147 .37727 Mdot
.67644 .49536 Mdot
.36989 .26707 Mdot
.51097 .63736 Mdot
.48304 .60597 Mdot
.51346 .53373 Mdot
.67555 .45534 Mdot
.48959 .60238 Mdot
.48395 .49988 Mdot
.29571 .61572 Mdot
.73461 .52367 Mdot
.4176 .29725 Mdot
.48026 .69035 Mdot
.54083 .32051 Mdot
.5506 .31295 Mdot
.47807 .48458 Mdot
.58686 .32876 Mdot
.46919 .69746 Mdot
.71002 .482 Mdot
.44129 .50472 Mdot
.30121 .45189 Mdot
.76623 .41105 Mdot
.29593 .4284 Mdot
.34402 .40127 Mdot
.53346 .66587 Mdot
.39148 .31021 Mdot
.57918 .20631 Mdot
.47338 .62691 Mdot
.68869 .49398 Mdot
.51267 .62169 Mdot
.4789 .60972 Mdot
.45399 .6927 Mdot
.38427 .34967 Mdot
.31925 .62663 Mdot
.4955 .63736 Mdot
.5425 .34651 Mdot
.40315 .58641 Mdot
.49523 .70446 Mdot
.45728 .45955 Mdot
.40537 .57332 Mdot
.58043 .36205 Mdot
.67159 .52119 Mdot
.39485 .31438 Mdot
.68657 .47846 Mdot
.71477 .45224 Mdot
.69064 .46492 Mdot
.76035 .47991 Mdot
.6057 .72444 Mdot
.58197 .18981 Mdot
.72811 .57571 Mdot
.75141 .66125 Mdot
.72272 .45835 Mdot
.4562 .18678 Mdot
.6766 .49942 Mdot
.68969 .46455 Mdot
.75916 .31374 Mdot
.67136 .46789 Mdot
.50776 .66102 Mdot
.52271 .64024 Mdot
.64544 .7686 Mdot
.37029 .41741 Mdot
.50459 .68315 Mdot
.52294 .58241 Mdot
.33165 .46254 Mdot
.76236 .44687 Mdot
.50141 .53586 Mdot
.33586 .61135 Mdot
.48283 .51976 Mdot
.49725 .65628 Mdot
.4772 .64708 Mdot
.48181 .71127 Mdot
.37835 .78871 Mdot
.38668 .43852 Mdot
.67962 .45929 Mdot
.54635 .66343 Mdot
.52872 .37413 Mdot
.47091 .66086 Mdot
.5036 .6125 Mdot
.44962 .68522 Mdot
.39438 .31272 Mdot
.72084 .50812 Mdot
.5104 .51804 Mdot
.76148 .39628 Mdot
.47678 .67926 Mdot
.29181 .45772 Mdot
.35126 .43947 Mdot
.50736 .64761 Mdot
.679 .46334 Mdot
.48377 .60599 Mdot
.70141 .51688 Mdot
.70051 .47291 Mdot
.49635 .57341 Mdot
.76368 .46831 Mdot
.71544 .51188 Mdot
.45299 .67582 Mdot
.37308 .35828 Mdot
.78145 .42365 Mdot
.51248 .65221 Mdot
.32102 .44089 Mdot
.48315 .66575 Mdot
.31132 .42648 Mdot
.51126 .56986 Mdot
.49074 .52917 Mdot
.53389 .76808 Mdot
.39302 .28454 Mdot
.31664 .41189 Mdot
.36068 .33738 Mdot
.53815 .67493 Mdot
.67549 .44498 Mdot
.59355 .38768 Mdot
.3945 .40109 Mdot
.49105 .52387 Mdot
.26472 .53217 Mdot
.4207 .56378 Mdot
.57469 .34933 Mdot
.68619 .51288 Mdot
.76634 .62472 Mdot
.45518 .46173 Mdot
.42042 .30448 Mdot
.39846 .35534 Mdot
.54147 .39186 Mdot
.78231 .34277 Mdot
.51772 .6405 Mdot
.46409 .46324 Mdot
.59929 .65385 Mdot
.5047 .53214 Mdot
.5008 .4998 Mdot
.41276 .31606 Mdot
.50297 .68425 Mdot
.29131 .63078 Mdot
.39094 .33967 Mdot
.30724 .44433 Mdot
.66788 .48598 Mdot
.33849 .41911 Mdot
.67698 .32983 Mdot
.78405 .55037 Mdot
.39165 .33155 Mdot
.51864 .57702 Mdot
.51229 .67514 Mdot
.65806 .47921 Mdot
.61515 .57539 Mdot
.71162 .50804 Mdot
.31075 .46336 Mdot
.38926 .2812 Mdot
.19021 .36066 Mdot
.48263 .65551 Mdot
.70399 .4899 Mdot
.34356 .39004 Mdot
.48329 .67543 Mdot
.55771 .31118 Mdot
.48982 .60275 Mdot
.70331 .49595 Mdot
.46871 .61703 Mdot
.69935 .47513 Mdot
.38242 .35701 Mdot
.50622 .62926 Mdot
.4818 .63443 Mdot
.26006 .55383 Mdot
.31134 .45242 Mdot
.71308 .51166 Mdot
.30697 .63921 Mdot
.5206 .62395 Mdot
.25972 .62705 Mdot
.49521 .63466 Mdot
.7444 .66114 Mdot
.55534 .66252 Mdot
.4839 .50389 Mdot
.51433 .6227 Mdot
.51196 .64972 Mdot
.61313 .57282 Mdot
.71759 .58077 Mdot
.76384 .56217 Mdot
.55742 .30838 Mdot
.68167 .50887 Mdot
.39499 .33772 Mdot
.38956 .27271 Mdot
.37719 .30878 Mdot
.30884 .47361 Mdot
.52586 .59693 Mdot
.5136 .66434 Mdot
.59335 .33596 Mdot
.32187 .46003 Mdot
.69954 .48483 Mdot
.33116 .4413 Mdot
.3149 .61879 Mdot
.31867 .44268 Mdot
.49025 .48872 Mdot
.42577 .24626 Mdot
.58527 .73422 Mdot
.31411 .43544 Mdot
.7168 .49461 Mdot
.39415 .60661 Mdot
.49277 .56674 Mdot
.82454 .51151 Mdot
.34653 .44373 Mdot
.36917 .2655 Mdot
.51063 .68349 Mdot
.35236 .65868 Mdot
.55826 .32487 Mdot
.33921 .41867 Mdot
.57173 .34503 Mdot
.48115 .60987 Mdot
.65653 .53759 Mdot
.69176 .50074 Mdot
.57388 .29239 Mdot
.50926 .61522 Mdot
.33968 .41929 Mdot
.3896 .32795 Mdot
.74551 .6485 Mdot
.61586 .31265 Mdot
.39097 .47951 Mdot
.25847 .60475 Mdot
.37684 .29172 Mdot
.72484 .66423 Mdot
.57037 .34896 Mdot
.54607 .66521 Mdot
.45914 .71861 Mdot
.53512 .64046 Mdot
.40713 .33022 Mdot
.38843 .32075 Mdot
.49133 .31496 Mdot
.48057 .63437 Mdot
.46955 .61355 Mdot
.67392 .52546 Mdot
.38349 .28254 Mdot
.69155 .46532 Mdot
.65289 .47225 Mdot
.40375 .3411 Mdot
.70489 .51377 Mdot
.32533 .4299 Mdot
.30207 .66058 Mdot
.56854 .35019 Mdot
.57425 .30025 Mdot
.39273 .32959 Mdot
.39756 .29367 Mdot
.39114 .30942 Mdot
.50568 .60189 Mdot
.69963 .47065 Mdot
.46988 .64503 Mdot
.48453 .64702 Mdot
.48822 .56564 Mdot
.6448 .49692 Mdot
.47662 .62846 Mdot
.44745 .50429 Mdot
.34207 .45896 Mdot
.37824 .32471 Mdot
.57772 .33116 Mdot
.37469 .50231 Mdot
.54582 .35244 Mdot
.52691 .63495 Mdot
.78158 .4471 Mdot
.67783 .5071 Mdot
.32243 .45409 Mdot
.40319 .57646 Mdot
.32462 .44895 Mdot
.57419 .29292 Mdot
.68652 .53079 Mdot
.32765 .59709 Mdot
.4843 .62928 Mdot
.3091 .62646 Mdot
.21808 .50458 Mdot
.74152 .41773 Mdot
.56937 .33573 Mdot
.49568 .59264 Mdot
.48113 .50036 Mdot
.61411 .71943 Mdot
.515 .65962 Mdot
.50678 .69823 Mdot
.37497 .59496 Mdot
.52575 .63762 Mdot
.71019 .46432 Mdot
.42398 .54187 Mdot
.52456 .56924 Mdot
.53935 .64764 Mdot
.6223 .23351 Mdot
.51142 .68019 Mdot
.48796 .62897 Mdot
.50343 .67041 Mdot
.48053 .61733 Mdot
.64692 .48829 Mdot
.42777 .52114 Mdot
.54037 .33465 Mdot
.30164 .66065 Mdot
.56237 .3509 Mdot
.3982 .3281 Mdot
.40336 .47164 Mdot
.68038 .52045 Mdot
.32411 .44912 Mdot
.48016 .44119 Mdot
.34236 .68287 Mdot
.37375 .35603 Mdot
.2608 .52665 Mdot
.33968 .41041 Mdot
.50556 .51103 Mdot
.30014 .44456 Mdot
.41149 .32477 Mdot
.55694 .31353 Mdot
.50492 .62308 Mdot
.7063 .46869 Mdot
.70989 .50008 Mdot
.53738 .65856 Mdot
.7778 .40248 Mdot
.56535 .30296 Mdot
.46221 .35466 Mdot
.51997 .65176 Mdot
.5173 .6215 Mdot
.69413 .518 Mdot
.37388 .30427 Mdot
.42083 .56214 Mdot
.31834 .42435 Mdot
.47096 .66793 Mdot
.52233 .57274 Mdot
.31375 .6199 Mdot
.55361 .31135 Mdot
.49014 .49899 Mdot
.50569 .6786 Mdot
.31609 .61136 Mdot
.49719 .59565 Mdot
.53194 .6922 Mdot
.37019 .35973 Mdot
.49583 .57188 Mdot
.4764 .64072 Mdot
.72842 .52711 Mdot
.57382 .34643 Mdot
.68586 .48841 Mdot
.7266 .51838 Mdot
.49056 .52721 Mdot
.58624 .30558 Mdot
.48641 .61325 Mdot
.60242 .29858 Mdot
.48012 .60923 Mdot
.48817 .64954 Mdot
.56638 .33719 Mdot
.68536 .46799 Mdot
.65804 .28117 Mdot
.77431 .62759 Mdot
.46999 .62118 Mdot
.48382 .66974 Mdot
.37021 .41737 Mdot
.32463 .49102 Mdot
.48213 .62782 Mdot
.71695 .48867 Mdot
.48137 .67337 Mdot
.59979 .31289 Mdot
.33649 .44194 Mdot
.68638 .49776 Mdot
.3703 .30731 Mdot
.38434 .35576 Mdot
.38754 .37432 Mdot
.49053 .48839 Mdot
.46089 .63114 Mdot
.6605 .52321 Mdot
.64397 .49108 Mdot
.32815 .65111 Mdot
.37769 .33021 Mdot
.33562 .43128 Mdot
.48225 .69251 Mdot
.50393 .49776 Mdot
.5471 .31451 Mdot
.82384 .31756 Mdot
.32558 .59867 Mdot
.34305 .45995 Mdot
.41194 .4753 Mdot
.49482 .52274 Mdot
.51953 .67019 Mdot
.34171 .42534 Mdot
.40133 .34287 Mdot
.48456 .60403 Mdot
.55284 .65069 Mdot
.366 .26825 Mdot
.39359 .2997 Mdot
.60302 .29794 Mdot
.36635 .33258 Mdot
.32786 .41357 Mdot
.48806 .48843 Mdot
.69578 .50719 Mdot
.5056 .64337 Mdot
.51229 .55613 Mdot
.37476 .33801 Mdot
.4851 .47611 Mdot
.52049 .63954 Mdot
.67555 .50872 Mdot
.37424 .32012 Mdot
.49905 .66019 Mdot
.62036 .706 Mdot
.80425 .53013 Mdot
.36963 .33313 Mdot
.46619 .67958 Mdot
.56626 .51809 Mdot
.39476 .30303 Mdot
.41063 .32355 Mdot
.5059 .58357 Mdot
.34402 .42103 Mdot
.47469 .66345 Mdot
.56413 .30803 Mdot
.31348 .63015 Mdot
.58871 .30812 Mdot
.25572 .60982 Mdot
.51562 .59418 Mdot
.46999 .73241 Mdot
.68879 .44609 Mdot
.3155 .41032 Mdot
.29193 .71413 Mdot
.53399 .6579 Mdot
.65143 .44557 Mdot
.31963 .62947 Mdot
.33083 .58262 Mdot
.61977 .47685 Mdot
.32771 .41712 Mdot
.55711 .33103 Mdot
.49456 .62981 Mdot
.64167 .27404 Mdot
.32587 .41979 Mdot
.25642 .61192 Mdot
.46163 .66712 Mdot
.69619 .49118 Mdot
.51857 .64673 Mdot
.69691 .50502 Mdot
.4912 .67744 Mdot
.80933 .52357 Mdot
.37244 .39553 Mdot
.32295 .69301 Mdot
.50565 .51665 Mdot
.60607 .28084 Mdot
.74994 .65966 Mdot
.3299 .43125 Mdot
.4732 .61164 Mdot
.49576 .51714 Mdot
.55024 .32255 Mdot
.60597 .39403 Mdot
.38778 .30852 Mdot
.54416 .34806 Mdot
.67915 .47527 Mdot
.38874 .3668 Mdot
.48237 .47536 Mdot
.50358 .7512 Mdot
.34145 .42091 Mdot
.5857 .305 Mdot
.50968 .64689 Mdot
.53282 .63642 Mdot
.34146 .28964 Mdot
.17548 .4883 Mdot
.65091 .47205 Mdot
.85528 .4599 Mdot
.68374 .53009 Mdot
.31021 .45574 Mdot
.3753 .36246 Mdot
.4947 .66677 Mdot
.48386 .68707 Mdot
.39237 .29803 Mdot
.65692 .48611 Mdot
.32987 .40561 Mdot
.36304 .47771 Mdot
.59239 .33458 Mdot
.19159 .5085 Mdot
.68641 .50066 Mdot
.19135 .50654 Mdot
.44011 .34825 Mdot
.78533 .48909 Mdot
.28402 .6962 Mdot
.57223 .32732 Mdot
.19112 .50832 Mdot
.69952 .49131 Mdot
.52514 .65535 Mdot
.48985 .51561 Mdot
.48501 .48125 Mdot
.66837 .49644 Mdot
.40271 .32443 Mdot
.33691 .41166 Mdot
.51706 .64633 Mdot
.55172 .70723 Mdot
.61591 .57644 Mdot
.40105 .28671 Mdot
.50775 .5416 Mdot
.5803 .32242 Mdot
.48362 .6737 Mdot
.32634 .46531 Mdot
.57204 .32611 Mdot
.48561 .52373 Mdot
.33295 .68118 Mdot
.46532 .68307 Mdot
.39435 .59436 Mdot
.55993 .32197 Mdot
.31773 .49381 Mdot
.4804 .63721 Mdot
.57045 .34885 Mdot
.50715 .56457 Mdot
.49329 .3426 Mdot
.44239 .52919 Mdot
.73076 .37741 Mdot
.41981 .33537 Mdot
.3676 .34398 Mdot
.23092 .3035 Mdot
.27729 .29692 Mdot
.55292 .34858 Mdot
.49969 .54041 Mdot
.17362 .47793 Mdot
.5798 .33921 Mdot
.48652 .61764 Mdot
.50393 .63252 Mdot
.74852 .64254 Mdot
.50066 .55142 Mdot
.49708 .50297 Mdot
.701 .54589 Mdot
.4597 .69414 Mdot
.50688 .54238 Mdot
.48539 .63525 Mdot
.67562 .46077 Mdot
.57857 .32133 Mdot
.51211 .84252 Mdot
.58773 .2943 Mdot
.4764 .73433 Mdot
.37146 .33747 Mdot
.4133 .34655 Mdot
.50617 .64731 Mdot
.56356 .4947 Mdot
.68239 .80122 Mdot
.5019 .63156 Mdot
.40268 .57758 Mdot
.25667 .60125 Mdot
.5287 .6122 Mdot
.72518 .4906 Mdot
.5081 .56255 Mdot
.64551 .50579 Mdot
.56723 .33058 Mdot
.32773 .41736 Mdot
.3203 .40587 Mdot
.55773 .32975 Mdot
.48877 .68543 Mdot
.2991 .42491 Mdot
.49841 .64885 Mdot
.5194 .66553 Mdot
.3205 .61308 Mdot
.32016 .46636 Mdot
.39778 .31375 Mdot
.32813 .45047 Mdot
.6827 .46461 Mdot
.84492 .40334 Mdot
.33148 .43545 Mdot
.74651 .64851 Mdot
.30917 .63687 Mdot
.1783 .47744 Mdot
.70693 .50399 Mdot
.30095 .4499 Mdot
.55572 .3337 Mdot
.34905 .60342 Mdot
.7138 .69169 Mdot
.54729 .35347 Mdot
.51195 .6703 Mdot
.64707 .48377 Mdot
.69385 .52935 Mdot
.53826 .3452 Mdot
.69365 .50991 Mdot
.5315 .60621 Mdot
.45496 .66193 Mdot
.54004 .33773 Mdot
.33831 .76662 Mdot
.57823 .29914 Mdot
.78438 .62883 Mdot
.4611 .63201 Mdot
.68769 .49556 Mdot
.74387 .66639 Mdot
.71652 .52829 Mdot
.48283 .48709 Mdot
.49332 .61965 Mdot
.33387 .43349 Mdot
.3168 .64979 Mdot
.36946 .31818 Mdot
.75259 .43264 Mdot
.7104 .49304 Mdot
.53665 .34669 Mdot
.69327 .50949 Mdot
.68869 .51413 Mdot
.56853 .29345 Mdot
.67864 .50642 Mdot
.47759 .68053 Mdot
.81492 .52575 Mdot
.70321 .51032 Mdot
.56816 .32021 Mdot
.30992 .46196 Mdot
.71756 .49439 Mdot
.45855 .36771 Mdot
.48513 .69106 Mdot
.40836 .28359 Mdot
.3306 .48244 Mdot
.65316 .47503 Mdot
.33114 .43028 Mdot
.37439 .33329 Mdot
.34951 .42069 Mdot
.56999 .26611 Mdot
.59549 .27401 Mdot
.56701 .65863 Mdot
.48944 .34029 Mdot
.67342 .46698 Mdot
.39014 .36743 Mdot
.47052 .68133 Mdot
.52087 .65632 Mdot
.32234 .47085 Mdot
.72952 .49364 Mdot
.77766 .39471 Mdot
.50268 .53812 Mdot
.76578 .41021 Mdot
.55735 .30802 Mdot
.45075 .36992 Mdot
.32582 .59518 Mdot
.61134 .35351 Mdot
.52502 .56684 Mdot
.49474 .52095 Mdot
.5025 .65432 Mdot
.2606 .56406 Mdot
.32703 .41443 Mdot
.44639 .19914 Mdot
.51965 .61521 Mdot
.3909 .29489 Mdot
.49424 .67474 Mdot
.46311 .50217 Mdot
.53565 .63601 Mdot
.33717 .46511 Mdot
.56413 .36033 Mdot
.71722 .48533 Mdot
.30343 .43864 Mdot
.38596 .35607 Mdot
.34158 .70834 Mdot
.47754 .63126 Mdot
.47694 .69683 Mdot
.40154 .31142 Mdot
.69729 .46485 Mdot
.39441 .3237 Mdot
.568 .35026 Mdot
.32973 .43784 Mdot
.49534 .59979 Mdot
.50325 .55559 Mdot
.38535 .2669 Mdot
.5448 .3271 Mdot
.37836 .36726 Mdot
.5979 .29553 Mdot
.49195 .52083 Mdot
.54278 .65768 Mdot
.3646 .36457 Mdot
.52212 .56489 Mdot
.71453 .63127 Mdot
.33852 .67856 Mdot
.60608 .55699 Mdot
.40444 .32346 Mdot
.28058 .27914 Mdot
.57067 .32422 Mdot
.59593 .309 Mdot
.7888 .62432 Mdot
.74392 .74937 Mdot
.40691 .58085 Mdot
.76204 .37323 Mdot
.56769 .35061 Mdot
.56192 .31627 Mdot
.39562 .32029 Mdot
.67789 .46883 Mdot
.6826 .44885 Mdot
.39156 .36243 Mdot
.27157 .65886 Mdot
.69978 .48507 Mdot
.66213 .76217 Mdot
.40657 .28775 Mdot
.45419 .69589 Mdot
.7996 .53151 Mdot
.3428 .45644 Mdot
.26148 .59624 Mdot
.60422 .3828 Mdot
.50226 .66399 Mdot
.59014 .19699 Mdot
.38632 .30998 Mdot
.4975 .489 Mdot
.51423 .32809 Mdot
.51156 .61209 Mdot
.49952 .67457 Mdot
.47826 .67577 Mdot
.31223 .4807 Mdot
.69662 .59542 Mdot
.49905 .66528 Mdot
.33168 .68628 Mdot
.46458 .70666 Mdot
.3592 .25325 Mdot
.32845 .44991 Mdot
.25943 .51629 Mdot
.35472 .32023 Mdot
.75777 .39029 Mdot
.5217 .68972 Mdot
.59249 .32803 Mdot
.45336 .49833 Mdot
.56561 .33915 Mdot
.57385 .36371 Mdot
.18713 .5449 Mdot
.70797 .46402 Mdot
.51433 .61068 Mdot
.40705 .2962 Mdot
.67906 .44886 Mdot
.45059 .49867 Mdot
.85165 .41529 Mdot
.53555 .35333 Mdot
.86872 .62524 Mdot
.59275 .32063 Mdot
.49378 .48811 Mdot
.67575 .47928 Mdot
.6108 .53489 Mdot
.30881 .62495 Mdot
.69005 .46572 Mdot
.3105 .29045 Mdot
.64231 .50091 Mdot
.22851 .6347 Mdot
.74031 .49355 Mdot
.57337 .31579 Mdot
.53757 .34509 Mdot
.54323 .62327 Mdot
.47418 .66126 Mdot
.29333 .62129 Mdot
.50335 .53847 Mdot
.46322 .68385 Mdot
.39088 .34012 Mdot
.48297 .33115 Mdot
.62961 .26785 Mdot
.67697 .50402 Mdot
.54453 .33226 Mdot
.49723 .67424 Mdot
.47079 .61914 Mdot
.51992 .63399 Mdot
.40558 .40889 Mdot
.6542 .76872 Mdot
.48795 .64513 Mdot
.53876 .67758 Mdot
.37655 .35811 Mdot
.34075 .2906 Mdot
.79653 .37314 Mdot
.18876 .52607 Mdot
.52388 .67491 Mdot
.31475 .45675 Mdot
.3139 .46921 Mdot
.54955 .64582 Mdot
.60346 .52849 Mdot
.26603 .45938 Mdot
.51004 .64748 Mdot
.3448 .69939 Mdot
.40078 .27109 Mdot
.47859 .48753 Mdot
.37526 .33816 Mdot
.70891 .44785 Mdot
.48272 .50918 Mdot
.39711 .34199 Mdot
.30903 .68714 Mdot
.49473 .53769 Mdot
.49409 .33859 Mdot
.30145 .45506 Mdot
.48304 .63611 Mdot
.77534 .6037 Mdot
.38307 .28237 Mdot
.56757 .30836 Mdot
.67844 .48392 Mdot
.55846 .30805 Mdot
.37737 .24978 Mdot
.26326 .63973 Mdot
.48415 .492 Mdot
.59382 .32573 Mdot
.39259 .59934 Mdot
.31911 .45784 Mdot
.58769 .32928 Mdot
.46459 .7218 Mdot
.47677 .70934 Mdot
.66336 .7982 Mdot
.48193 .6948 Mdot
.49231 .31619 Mdot
.58789 .30417 Mdot
.48138 .51021 Mdot
.50432 .64252 Mdot
.41671 .30755 Mdot
.54963 .62391 Mdot
.49717 .64987 Mdot
.37225 .29843 Mdot
.50418 .63391 Mdot
.33978 .44108 Mdot
.67535 .53103 Mdot
.32472 .629 Mdot
.39829 .46611 Mdot
.32072 .41951 Mdot
.34741 .67432 Mdot
.48361 .62563 Mdot
.29293 .29513 Mdot
.6944 .48868 Mdot
.52752 .63655 Mdot
.23385 .58442 Mdot
.66737 .48024 Mdot
.68914 .47703 Mdot
.45133 .6653 Mdot
.59875 .30458 Mdot
.3999 .31366 Mdot
.32318 .45694 Mdot
.61728 .30876 Mdot
.49806 .66202 Mdot
.49434 .59417 Mdot
.31664 .42281 Mdot
.57423 .30638 Mdot
.49354 .60251 Mdot
.65897 .39851 Mdot
.30744 .66479 Mdot
.5725 .29404 Mdot
.49676 .704 Mdot
.69478 .74445 Mdot
.66686 .50927 Mdot
.58828 .19568 Mdot
.37281 .39615 Mdot
.39372 .35607 Mdot
.50844 .54508 Mdot
.83024 .33781 Mdot
.30948 .46268 Mdot
.75065 .41057 Mdot
.52168 .64608 Mdot
.4894 .66704 Mdot
.67522 .46299 Mdot
.47101 .64423 Mdot
.67946 .5083 Mdot
.43633 .3926 Mdot
.76986 .72583 Mdot
.70354 .50487 Mdot
.69946 .50014 Mdot
.41398 .65599 Mdot
.37679 .38664 Mdot
.66889 .48728 Mdot
.47484 .64193 Mdot
.31724 .24952 Mdot
.52393 .71605 Mdot
.33913 .40443 Mdot
.31385 .48319 Mdot
.72349 .49113 Mdot
.71361 .6963 Mdot
.46124 .71643 Mdot
.66202 .74457 Mdot
.26468 .46075 Mdot
.55516 .35038 Mdot
.4991 .58561 Mdot
.49976 .53091 Mdot
.37705 .32062 Mdot
.5007 .57275 Mdot
.48007 .63996 Mdot
.71361 .47162 Mdot
.34917 .44048 Mdot
.57998 .33755 Mdot
.52258 .55945 Mdot
.41296 .27866 Mdot
.31327 .43059 Mdot
.69791 .51516 Mdot
.76357 .65397 Mdot
.29335 .4392 Mdot
.51277 .52097 Mdot
.52415 .66696 Mdot
.50104 .57706 Mdot
.50555 .49873 Mdot
.55925 .32926 Mdot
.40351 .35254 Mdot
.51253 .52441 Mdot
.34864 .61813 Mdot
.29412 .66314 Mdot
.53011 .66513 Mdot
.71742 .49125 Mdot
.54749 .32586 Mdot
.48906 .49159 Mdot
.17404 .47301 Mdot
.50769 .68651 Mdot
.66238 .76269 Mdot
.37794 .48124 Mdot
.49702 .53063 Mdot
.67543 .44926 Mdot
.32425 .45296 Mdot
.46195 .63068 Mdot
.32773 .68835 Mdot
.46207 .68028 Mdot
.54683 .66313 Mdot
.40564 .33746 Mdot
.56802 .34436 Mdot
.56654 .66182 Mdot
.37937 .32131 Mdot
.68741 .47793 Mdot
.6352 .75937 Mdot
.6618 .46405 Mdot
.65329 .47091 Mdot
.76212 .46146 Mdot
.57087 .30254 Mdot
.82963 .33429 Mdot
.323 .49018 Mdot
.5116 .62993 Mdot
.5608 .35827 Mdot
.67162 .49116 Mdot
.47896 .62552 Mdot
.67813 .50742 Mdot
.72368 .50226 Mdot
.4644 .69092 Mdot
.4568 .68324 Mdot
.32877 .69214 Mdot
.69228 .74027 Mdot
.33307 .45189 Mdot
.65802 .4828 Mdot
.70044 .72477 Mdot
.49383 .6654 Mdot
.476 .65011 Mdot
.45428 .49664 Mdot
.30625 .43074 Mdot
.55492 .77003 Mdot
.52201 .65339 Mdot
.25799 .55072 Mdot
.48564 .62005 Mdot
.73225 .47797 Mdot
.6069 .28695 Mdot
.47026 .72917 Mdot
.38255 .3652 Mdot
.65699 .48302 Mdot
.34537 .4532 Mdot
.70158 .44262 Mdot
.59233 .73218 Mdot
.55253 .32777 Mdot
.70313 .49607 Mdot
.40176 .35661 Mdot
.57355 .30866 Mdot
.57892 .29956 Mdot
.44908 .49793 Mdot
.414 .33772 Mdot
.34999 .43863 Mdot
.58361 .32435 Mdot
.62468 .70243 Mdot
.57354 .31364 Mdot
.587 .74698 Mdot
.50329 .69108 Mdot
.32973 .68619 Mdot
.51647 .54407 Mdot
.55522 .66867 Mdot
.58806 .31337 Mdot
.31593 .42538 Mdot
.49604 .60159 Mdot
.69566 .51214 Mdot
.31277 .46098 Mdot
.78296 .54579 Mdot
.4046 .35648 Mdot
.68266 .52752 Mdot
.61519 .32007 Mdot
.66188 .48059 Mdot
.25965 .60166 Mdot
.35048 .44575 Mdot
.451 .46058 Mdot
.32907 .61897 Mdot
.50703 .53475 Mdot
.53973 .65413 Mdot
.50025 .60079 Mdot
.48027 .68233 Mdot
.37125 .33852 Mdot
.3093 .47934 Mdot
.7157 .50416 Mdot
.57508 .66838 Mdot
.57238 .30449 Mdot
.41694 .55482 Mdot
.50519 .50257 Mdot
.47929 .61125 Mdot
.67388 .49265 Mdot
.71893 .50921 Mdot
.71106 .58404 Mdot
.3911 .30152 Mdot
.5463 .69512 Mdot
.53298 .66127 Mdot
.56411 .68917 Mdot
.58816 .31071 Mdot
.71655 .38254 Mdot
.40143 .27407 Mdot
.8727 .62037 Mdot
.37965 .32406 Mdot
.43429 .4688 Mdot
.66832 .50266 Mdot
.32084 .43715 Mdot
.49454 .68542 Mdot
.74948 .509 Mdot
.65564 .46163 Mdot
.32259 .37659 Mdot
.32235 .44794 Mdot
.58989 .25267 Mdot
.56079 .35516 Mdot
.52345 .56002 Mdot
.4859 .61943 Mdot
.4648 .64888 Mdot
.46902 .66381 Mdot
.54748 .3449 Mdot
.45648 .67252 Mdot
.60905 .30121 Mdot
.58917 .73218 Mdot
.23349 .58758 Mdot
.40929 .31224 Mdot
.36083 .23637 Mdot
.64977 .4795 Mdot
.58535 .77045 Mdot
.5715 .75183 Mdot
.33611 .67813 Mdot
.57669 .35804 Mdot
.52363 .59094 Mdot
.39864 .31895 Mdot
.62829 .2732 Mdot
.40925 .30979 Mdot
.56181 .83273 Mdot
.75033 .64143 Mdot
.55143 .26318 Mdot
.46369 .65707 Mdot
.40875 .3366 Mdot
.71399 .70135 Mdot
.5156 .53349 Mdot
.29833 .42662 Mdot
.60251 .72343 Mdot
.76982 .55863 Mdot
.33482 .45052 Mdot
.50334 .68326 Mdot
.64467 .49447 Mdot
.48994 .68661 Mdot
.49656 .68534 Mdot
.52199 .64256 Mdot
.54814 .30859 Mdot
.50828 .68952 Mdot
.47404 .6724 Mdot
.16499 .40907 Mdot
.28468 .42598 Mdot
.36613 .34086 Mdot
.61031 .54446 Mdot
.322 .46006 Mdot
.7104 .4483 Mdot
.32664 .62505 Mdot
.59415 .30498 Mdot
.70735 .58542 Mdot
.4541 .65797 Mdot
.75564 .42518 Mdot
.59444 .29914 Mdot
.34467 .41843 Mdot
.49864 .52567 Mdot
.68899 .28356 Mdot
.3609 .34982 Mdot
.49819 .5096 Mdot
.3734 .30097 Mdot
.52654 .75496 Mdot
.69137 .50673 Mdot
.50691 .53582 Mdot
.58119 .33443 Mdot
.41226 .31336 Mdot
.34007 .6865 Mdot
.47863 .66661 Mdot
.40558 .32603 Mdot
.50911 .55209 Mdot
.31491 .64831 Mdot
.31843 .62892 Mdot
.41235 .33027 Mdot
.59754 .32721 Mdot
.58369 .30832 Mdot
.32458 .46299 Mdot
.67636 .51249 Mdot
.70149 .46546 Mdot
.57907 .31123 Mdot
.60475 .23022 Mdot
.49978 .66135 Mdot
.48541 .65129 Mdot
.33461 .60422 Mdot
.49815 .60912 Mdot
.36894 .41869 Mdot
.50053 .51725 Mdot
.71163 .47335 Mdot
.49817 .60116 Mdot
.49178 .60417 Mdot
.51554 .67868 Mdot
.272 .66452 Mdot
.37214 .33301 Mdot
.45602 .69151 Mdot
.341 .42253 Mdot
.77881 .55188 Mdot
.47181 .67962 Mdot
.51472 .51833 Mdot
.6688 .50468 Mdot
.5506 .39189 Mdot
.56578 .3092 Mdot
.39941 .28816 Mdot
.40476 .29323 Mdot
.21552 .51508 Mdot
.66426 .46488 Mdot
.49909 .51173 Mdot
.36541 .26813 Mdot
.49118 .49088 Mdot
.32015 .4472 Mdot
.43813 .53818 Mdot
.34971 .35015 Mdot
.36617 .33885 Mdot
.56756 .28909 Mdot
.5278 .6316 Mdot
.47139 .67468 Mdot
.76862 .39663 Mdot
.49269 .63453 Mdot
.33562 .43778 Mdot
.57971 .34547 Mdot
.70108 .4959 Mdot
.34002 .44637 Mdot
.59465 .31966 Mdot
.69424 .46522 Mdot
.46519 .70491 Mdot
.48139 .62342 Mdot
.68208 .47932 Mdot
.69304 .51623 Mdot
.5096 .65943 Mdot
.19029 .5743 Mdot
.71704 .47982 Mdot
.6775 .4814 Mdot
.77607 .55386 Mdot
.36225 .34925 Mdot
.54892 .62111 Mdot
.59903 .31356 Mdot
.47484 .67256 Mdot
.40683 .30988 Mdot
.31349 .44345 Mdot
.71268 .48802 Mdot
.50475 .58056 Mdot
.49362 .65913 Mdot
.31619 .4566 Mdot
.29779 .45036 Mdot
.30305 .44621 Mdot
.53842 .34448 Mdot
.45285 .67466 Mdot
.67141 .48306 Mdot
.54821 .35253 Mdot
.32987 .46571 Mdot
.30702 .42624 Mdot
.24572 .66761 Mdot
.50436 .6618 Mdot
.29972 .46268 Mdot
.83956 .38992 Mdot
.3131 .70107 Mdot
.48004 .4813 Mdot
.39854 .37072 Mdot
.28426 .26813 Mdot
.31003 .48936 Mdot
.56384 .34553 Mdot
.41457 .55594 Mdot
.34297 .4085 Mdot
.51751 .55934 Mdot
.48097 .6568 Mdot
.48875 .57294 Mdot
.31063 .45947 Mdot
.26197 .63802 Mdot
.70244 .46082 Mdot
.62141 .60644 Mdot
.32264 .4599 Mdot
.41502 .32509 Mdot
.39251 .26586 Mdot
.38534 .32177 Mdot
.53574 .63419 Mdot
.50786 .76805 Mdot
.61881 .68215 Mdot
.55418 .76562 Mdot
.56418 .35444 Mdot
.72061 .50748 Mdot
.79315 .54146 Mdot
.69129 .47645 Mdot
.37715 .30478 Mdot
.31758 .42422 Mdot
.68103 .46145 Mdot
.57152 .30073 Mdot
.58525 .30974 Mdot
.36302 .35967 Mdot
.37706 .33492 Mdot
.3906 .32992 Mdot
.65789 .49967 Mdot
.67229 .50473 Mdot
.47183 .63493 Mdot
.71212 .50302 Mdot
.39777 .40547 Mdot
.42025 .40196 Mdot
.36285 .30299 Mdot
.56423 .32599 Mdot
.70112 .47371 Mdot
.48496 .63302 Mdot
.38076 .57848 Mdot
.37541 .26392 Mdot
.34316 .45347 Mdot
.81807 .52258 Mdot
.72799 .76502 Mdot
.5082 .59545 Mdot
.54944 .33922 Mdot
.50028 .50653 Mdot
.48432 .68107 Mdot
.39538 .35625 Mdot
.36172 .49062 Mdot
.49434 .54167 Mdot
.47052 .68788 Mdot
.48016 .70395 Mdot
.55101 .32348 Mdot
.33007 .62353 Mdot
.5197 .55948 Mdot
.43786 .50594 Mdot
.57894 .34836 Mdot
.39299 .27107 Mdot
.25545 .27488 Mdot
.71958 .54025 Mdot
.27507 .53868 Mdot
.48359 .51444 Mdot
.50863 .68675 Mdot
.38851 .34324 Mdot
.344 .43619 Mdot
.38594 .33874 Mdot
.72114 .45652 Mdot
.36286 .35289 Mdot
.49651 .63163 Mdot
.6699 .48253 Mdot
.58395 .30506 Mdot
.34987 .58251 Mdot
.57888 .6115 Mdot
.41556 .30262 Mdot
.48653 .47512 Mdot
.45813 .68503 Mdot
.62317 .70976 Mdot
.55536 .6673 Mdot
.47562 .64531 Mdot
.56708 .33732 Mdot
.67555 .50047 Mdot
.55271 .31428 Mdot
.55196 .63169 Mdot
.60844 .50918 Mdot
.56253 .31082 Mdot
.44729 .72029 Mdot
.33521 .41118 Mdot
.26609 .64888 Mdot
.51154 .64324 Mdot
.57733 .3383 Mdot
.47369 .69411 Mdot
.66093 .47511 Mdot
.30325 .67812 Mdot
.31581 .66883 Mdot
.57754 .32444 Mdot
.46761 .47018 Mdot
.31007 .63978 Mdot
.54805 .61795 Mdot
.56434 .35087 Mdot
.32466 .72171 Mdot
.49332 .50505 Mdot
.31351 .43201 Mdot
.30032 .43737 Mdot
.3253 .42441 Mdot
.48394 .64849 Mdot
.72454 .71031 Mdot
.31596 .46532 Mdot
.52576 .3533 Mdot
.33926 .43102 Mdot
.3877 .48402 Mdot
.77945 .401 Mdot
.33 .41336 Mdot
.50453 .6386 Mdot
.48597 .74274 Mdot
.40863 .56679 Mdot
.42051 .326 Mdot
.67615 .28839 Mdot
.1702 .39785 Mdot
.49521 .66723 Mdot
.81081 .5264 Mdot
.70793 .53401 Mdot
.43182 .46171 Mdot
.32345 .67305 Mdot
.38114 .62764 Mdot
.68753 .47317 Mdot
.32922 .62108 Mdot
.6676 .51691 Mdot
.50847 .51808 Mdot
.48828 .6478 Mdot
.65747 .47996 Mdot
.75291 .43391 Mdot
.2943 .7187 Mdot
.76916 .41703 Mdot
.70064 .47063 Mdot
.57422 .3461 Mdot
.55825 .34227 Mdot
.57073 .33503 Mdot
.3785 .34871 Mdot
.70324 .49906 Mdot
.46225 .69669 Mdot
.38687 .35789 Mdot
.51557 .6678 Mdot
.57961 .31747 Mdot
.32593 .67652 Mdot
.69915 .4995 Mdot
.5111 .64797 Mdot
.70587 .71335 Mdot
.37764 .29228 Mdot
.31591 .45815 Mdot
.81585 .52259 Mdot
.39296 .37016 Mdot
.60239 .3021 Mdot
.72425 .46278 Mdot
.29351 .41533 Mdot
.42624 .52221 Mdot
.52966 .66301 Mdot
.50245 .62248 Mdot
.41314 .55554 Mdot
.757 .64046 Mdot
.51709 .57014 Mdot
.38518 .35589 Mdot
.36269 .34208 Mdot
.48951 .69152 Mdot
.70559 .49974 Mdot
.35244 .40838 Mdot
.29593 .46186 Mdot
.5348 .69171 Mdot
.31185 .62718 Mdot
.33179 .68601 Mdot
.48444 .61527 Mdot
.43769 .63664 Mdot
.40343 .35477 Mdot
.48006 .47957 Mdot
.31527 .62027 Mdot
.32652 .42893 Mdot
.52434 .65724 Mdot
.61457 .56204 Mdot
.70946 .49078 Mdot
.40382 .32125 Mdot
.54231 .31825 Mdot
.29502 .43309 Mdot
.36155 .31057 Mdot
.48999 .69135 Mdot
.49254 .60353 Mdot
.58569 .33078 Mdot
.72812 .47099 Mdot
.30677 .44462 Mdot
.38406 .35878 Mdot
.32313 .43402 Mdot
.68534 .50636 Mdot
.71352 .48599 Mdot
.52692 .64312 Mdot
.54972 .69498 Mdot
.41077 .29293 Mdot
.53516 .62818 Mdot
.40158 .33336 Mdot
.34172 .28825 Mdot
.54674 .31523 Mdot
.52656 .63564 Mdot
.69164 .44814 Mdot
.58084 .3146 Mdot
.4967 .6697 Mdot
.41928 .54355 Mdot
.48804 .6056 Mdot
.4096 .33617 Mdot
.34772 .49068 Mdot
.31725 .43114 Mdot
.4457 .65589 Mdot
.75038 .56302 Mdot
.49539 .60789 Mdot
.37779 .2837 Mdot
.61677 .69875 Mdot
.55664 .31938 Mdot
.66338 .49471 Mdot
.40171 .24573 Mdot
.56936 .31785 Mdot
.51011 .63788 Mdot
.33204 .43617 Mdot
.70418 .51491 Mdot
.48226 .50219 Mdot
.28811 .59649 Mdot
.5535 .64573 Mdot
.54214 .69954 Mdot
.51743 .56706 Mdot
.76629 .37768 Mdot
.38929 .33269 Mdot
.67289 .49077 Mdot
.55204 .34242 Mdot
.55348 .32422 Mdot
.37448 .30227 Mdot
.76663 .55602 Mdot
.79672 .45322 Mdot
.83736 .3723 Mdot
.36824 .28641 Mdot
.33237 .42348 Mdot
.30519 .67816 Mdot
.38626 .32005 Mdot
.36847 .32481 Mdot
.36158 .37338 Mdot
.76574 .39233 Mdot
.68899 .46891 Mdot
.4928 .65991 Mdot
.80662 .52775 Mdot
.51926 .63973 Mdot
.27854 .54241 Mdot
.57853 .31771 Mdot
.66311 .49425 Mdot
.44377 .39591 Mdot
.53873 .64405 Mdot
.49631 .6799 Mdot
.46356 .36006 Mdot
.50313 .535 Mdot
.18138 .48664 Mdot
.51165 .62327 Mdot
.3801 .34322 Mdot
.62922 .49411 Mdot
.51165 .52539 Mdot
.70676 .71359 Mdot
.58964 .30856 Mdot
.48442 .48919 Mdot
.51031 .52051 Mdot
.43693 .63268 Mdot
.66208 .51346 Mdot
.69017 .45978 Mdot
.29936 .44658 Mdot
.77995 .45779 Mdot
.59069 .30806 Mdot
.7256 .37165 Mdot
.47609 .64094 Mdot
.58239 .35917 Mdot
.36777 .47706 Mdot
.50176 .66967 Mdot
.44771 .49999 Mdot
.71126 .58361 Mdot
.50343 .58438 Mdot
.566 .74704 Mdot
.57028 .32243 Mdot
.2383 .57919 Mdot
.45949 .66992 Mdot
.40469 .3254 Mdot
.67384 .47045 Mdot
.67876 .52707 Mdot
.34297 .44457 Mdot
.38809 .41234 Mdot
.81224 .68519 Mdot
.66264 .49202 Mdot
.47769 .66549 Mdot
.56048 .31636 Mdot
.48203 .49244 Mdot
.51581 .54738 Mdot
.4658 .4687 Mdot
.70856 .48849 Mdot
.514 .53187 Mdot
.76006 .42721 Mdot
.32881 .62237 Mdot
.60088 .76884 Mdot
.57677 .32951 Mdot
.33477 .42832 Mdot
.51887 .70774 Mdot
.34663 .29495 Mdot
.48489 .61902 Mdot
.27738 .54128 Mdot
.69215 .53403 Mdot
.3359 .43359 Mdot
.48988 .68436 Mdot
.52273 .56967 Mdot
.35412 .67425 Mdot
.34671 .40258 Mdot
.51621 .56705 Mdot
.50936 .60046 Mdot
.67774 .46566 Mdot
.49929 .51036 Mdot
.70181 .49253 Mdot
.49578 .68389 Mdot
.2702 .49536 Mdot
.65872 .48493 Mdot
.66705 .28661 Mdot
.29464 .46347 Mdot
.59695 .30723 Mdot
.48918 .57989 Mdot
.52603 .67339 Mdot
.59729 .77898 Mdot
.48321 .48537 Mdot
.62732 .24005 Mdot
.40832 .32613 Mdot
.16915 .48918 Mdot
.38128 .37578 Mdot
.5024 .3055 Mdot
.59036 .4056 Mdot
.49236 .57251 Mdot
.76282 .55807 Mdot
.54172 .77682 Mdot
.59297 .33651 Mdot
.57077 .77958 Mdot
.47413 .66165 Mdot
.52254 .6684 Mdot
.40291 .3318 Mdot
.56379 .36747 Mdot
.46988 .72956 Mdot
.31433 .62113 Mdot
.34404 .41526 Mdot
.68791 .48651 Mdot
.48112 .64776 Mdot
.74633 .4332 Mdot
.41452 .31402 Mdot
.6063 .57871 Mdot
.50872 .64405 Mdot
.50293 .5343 Mdot
.56582 .36517 Mdot
.58462 .30467 Mdot
.41171 .33726 Mdot
.41594 .33019 Mdot
.52033 .67721 Mdot
.54109 .33772 Mdot
.46871 .63644 Mdot
.31088 .64201 Mdot
.50777 .55161 Mdot
.31745 .44859 Mdot
.48146 .63206 Mdot
.70087 .55133 Mdot
.33936 .79445 Mdot
.53653 .64142 Mdot
.65306 .4731 Mdot
.39442 .32904 Mdot
.37187 .32167 Mdot
.70305 .46707 Mdot
.37208 .31906 Mdot
.62375 .60609 Mdot
.72234 .71419 Mdot
.32056 .44378 Mdot
.60086 .67899 Mdot
.32849 .41752 Mdot
.48535 .48826 Mdot
.50627 .66103 Mdot
.47951 .18107 Mdot
.3692 .28562 Mdot
.37515 .50207 Mdot
.57715 .31296 Mdot
.48548 .48202 Mdot
.45446 .67697 Mdot
.32647 .47975 Mdot
.38192 .31244 Mdot
.49674 .48481 Mdot
.52369 .6464 Mdot
.65719 .49451 Mdot
.49001 .59705 Mdot
.50018 .49784 Mdot
.49715 .50238 Mdot
.52331 .57935 Mdot
.5947 .31957 Mdot
.68312 .5096 Mdot
.58546 .25053 Mdot
.37711 .28995 Mdot
.46424 .68743 Mdot
.47781 .67059 Mdot
.70231 .51774 Mdot
.50785 .62813 Mdot
.54096 .34186 Mdot
.798 .28079 Mdot
.30539 .43755 Mdot
.47896 .48428 Mdot
.67685 .32989 Mdot
.52387 .5806 Mdot
.50531 .59969 Mdot
.39524 .64459 Mdot
.61539 .57585 Mdot
.59751 .30967 Mdot
.54849 .65305 Mdot
.36566 .34666 Mdot
.30814 .44024 Mdot
.5691 .30074 Mdot
.45569 .6604 Mdot
.50076 .63423 Mdot
.33497 .43247 Mdot
.4594 .37455 Mdot
.31714 .41294 Mdot
.55666 .34916 Mdot
.47367 .48417 Mdot
.38268 .57641 Mdot
.50072 .65434 Mdot
.50171 .5244 Mdot
.67862 .49881 Mdot
.556 .35297 Mdot
.69619 .59895 Mdot
.50831 .51606 Mdot
.61615 .31968 Mdot
.58658 .30566 Mdot
.52945 .66121 Mdot
.66171 .46903 Mdot
.73591 .51353 Mdot
.6761 .49598 Mdot
.22127 .56661 Mdot
.58764 .24523 Mdot
.39309 .33253 Mdot
.56492 .32398 Mdot
.40328 .30483 Mdot
.33214 .41087 Mdot
.29391 .65735 Mdot
.41728 .3185 Mdot
.69167 .45332 Mdot
.40589 .30317 Mdot
.47041 .63408 Mdot
.59509 .30296 Mdot
.404 .28354 Mdot
.47329 .64231 Mdot
.48184 .71134 Mdot
.50403 .51946 Mdot
.35387 .42173 Mdot
.31983 .62538 Mdot
.51516 .64377 Mdot
.49811 .51984 Mdot
.50941 .65208 Mdot
.54072 .33984 Mdot
.34103 .57078 Mdot
.46816 .69572 Mdot
.36977 .28421 Mdot
.69913 .27416 Mdot
.36225 .32897 Mdot
.56843 .52551 Mdot
.51321 .66809 Mdot
.50181 .65731 Mdot
.45784 .6857 Mdot
.77396 .56345 Mdot
.60409 .30132 Mdot
.54325 .63911 Mdot
.38085 .36672 Mdot
.69621 .47549 Mdot
.67208 .461 Mdot
.39778 .60356 Mdot
.49932 .51576 Mdot
.53855 .33936 Mdot
.50088 .65914 Mdot
.49782 .49842 Mdot
.31158 .60411 Mdot
.7809 .43 Mdot
.36819 .38391 Mdot
.36893 .30702 Mdot
.67452 .51449 Mdot
.37237 .34879 Mdot
.45526 .6664 Mdot
.51309 .53185 Mdot
.59611 .24875 Mdot
.52821 .34299 Mdot
.30871 .4402 Mdot
.51207 .67267 Mdot
.27613 .67653 Mdot
.37677 .35818 Mdot
.41066 .34321 Mdot
.4676 .63909 Mdot
.66985 .53724 Mdot
.29177 .75082 Mdot
.55951 .35884 Mdot
.63765 .71041 Mdot
.7891 .60927 Mdot
.45903 .7741 Mdot
.55626 .32938 Mdot
.44498 .50234 Mdot
.42165 .32361 Mdot
.2278 .45881 Mdot
.69172 .47445 Mdot
.30743 .44441 Mdot
.47473 .63933 Mdot
.69261 .45399 Mdot
.36527 .29201 Mdot
.716 .50676 Mdot
.50629 .54283 Mdot
.59398 .29963 Mdot
.37527 .32344 Mdot
.53626 .32911 Mdot
.68903 .44568 Mdot
.32397 .42113 Mdot
.26056 .55348 Mdot
.61732 .71162 Mdot
.71653 .58095 Mdot
.45348 .68866 Mdot
.28013 .43511 Mdot
.45524 .69274 Mdot
.69018 .5306 Mdot
.51085 .6424 Mdot
.49071 .70704 Mdot
.41734 .33986 Mdot
.53029 .66413 Mdot
.47813 .63726 Mdot
.7033 .71808 Mdot
.50232 .673 Mdot
.50753 .68232 Mdot
.5313 .65994 Mdot
.67294 .45741 Mdot
.52394 .63998 Mdot
.68078 .51215 Mdot
.75089 .41718 Mdot
.37731 .29042 Mdot
.3274 .41276 Mdot
.32714 .41387 Mdot
.28559 .52991 Mdot
.27502 .67308 Mdot
.80125 .53304 Mdot
.70051 .48234 Mdot
.58769 .31212 Mdot
.46983 .63755 Mdot
.2548 .69454 Mdot
.27199 .50003 Mdot
.4155 .2942 Mdot
.41009 .2971 Mdot
.46869 .67335 Mdot
.70869 .77914 Mdot
.50496 .61865 Mdot
.32668 .59846 Mdot
.48434 .64741 Mdot
.52361 .63056 Mdot
.37765 .37188 Mdot
.25977 .60009 Mdot
.45664 .69205 Mdot
.65641 .50881 Mdot
.30884 .4453 Mdot
.50235 .51993 Mdot
.27569 .50998 Mdot
.77861 .63947 Mdot
.66083 .54502 Mdot
.45842 .69005 Mdot
.38663 .36011 Mdot
.7138 .47902 Mdot
.33389 .60709 Mdot
.54843 .35208 Mdot
.2845 .60142 Mdot
.5814 .75095 Mdot
.56835 .35961 Mdot
.31151 .43392 Mdot
.37912 .26406 Mdot
.52482 .67216 Mdot
.38883 .34653 Mdot
.53348 .62156 Mdot
.30908 .59844 Mdot
.31833 .44522 Mdot
.64256 .50473 Mdot
.57697 .34398 Mdot
.6929 .45553 Mdot
.60587 .556 Mdot
.26991 .49797 Mdot
.15893 .46517 Mdot
.36191 .31317 Mdot
.58513 .6395 Mdot
.66744 .49472 Mdot
.50979 .68563 Mdot
.83537 .37133 Mdot
.6851 .50051 Mdot
.65677 .48866 Mdot
.30766 .58028 Mdot
.2542 .60709 Mdot
.53091 .61976 Mdot
.71934 .48268 Mdot
.37783 .26562 Mdot
.32558 .44808 Mdot
.47065 .65567 Mdot
.50975 .52687 Mdot
.67856 .46196 Mdot
.37931 .30798 Mdot
.26396 .58824 Mdot
.378 .33973 Mdot
.6825 .47033 Mdot
.39278 .28433 Mdot
.5987 .26072 Mdot
.41712 .31579 Mdot
.49375 .62705 Mdot
.50065 .65818 Mdot
.74145 .50039 Mdot
.71355 .48607 Mdot
.50467 .59929 Mdot
.51798 .64087 Mdot
.66993 .4879 Mdot
.36872 .2717 Mdot
.63127 .55956 Mdot
.50891 .60543 Mdot
.49685 .66099 Mdot
.30647 .43269 Mdot
.33886 .63752 Mdot
.34461 .59676 Mdot
.47724 .62814 Mdot
.32868 .42212 Mdot
.66064 .50325 Mdot
.51046 .6562 Mdot
.25806 .59658 Mdot
.40305 .27169 Mdot
.46224 .64538 Mdot
.48328 .5042 Mdot
.45212 .69073 Mdot
.37509 .78632 Mdot
.45784 .68309 Mdot
.67886 .47625 Mdot
.66918 .47681 Mdot
.37842 .25666 Mdot
.68392 .48062 Mdot
.47978 .48417 Mdot
.58194 .30861 Mdot
.62225 .73338 Mdot
.48159 .47972 Mdot
.51733 .57519 Mdot
.32248 .49003 Mdot
.5115 .51911 Mdot
.52234 .53347 Mdot
.372 .38943 Mdot
.48496 .51714 Mdot
.67394 .50224 Mdot
.6538 .4345 Mdot
.53342 .60276 Mdot
.54003 .34393 Mdot
.51152 .52385 Mdot
.4625 .64316 Mdot
.50118 .70319 Mdot
.61292 .5178 Mdot
.55085 .35561 Mdot
.56033 .66425 Mdot
.47066 .65499 Mdot
.61478 .57124 Mdot
.4796 .64911 Mdot
.34913 .43174 Mdot
.69746 .49816 Mdot
.37792 .35183 Mdot
.31971 .45113 Mdot
.51873 .5641 Mdot
.31881 .46091 Mdot
.3926 .34132 Mdot
.58289 .32928 Mdot
.49586 .62815 Mdot
.34259 .40403 Mdot
.33434 .41299 Mdot
.48631 .59466 Mdot
.66664 .47759 Mdot
.55413 .65522 Mdot
.50994 .66106 Mdot
.45755 .68645 Mdot
.70036 .46438 Mdot
.57079 .18101 Mdot
.51811 .67525 Mdot
.44518 .49919 Mdot
.68176 .52997 Mdot
.49554 .49351 Mdot
.38092 .35527 Mdot
.50921 .58607 Mdot
.56046 .30958 Mdot
.57878 .30952 Mdot
.3727 .28252 Mdot
.68783 .4605 Mdot
.37386 .31864 Mdot
.53926 .65248 Mdot
.51247 .52546 Mdot
.4724 .65724 Mdot
.47744 .33756 Mdot
.64865 .2614 Mdot
.70044 .51514 Mdot
.37196 .29438 Mdot
.2965 .62348 Mdot
.599 .30683 Mdot
.36452 .37104 Mdot
.66163 .51509 Mdot
.71663 .47282 Mdot
.70326 .46924 Mdot
.3381 .41737 Mdot
.37797 .32839 Mdot
.70732 .44499 Mdot
.69769 .44207 Mdot
.46958 .62254 Mdot
.46976 .6544 Mdot
.66613 .50852 Mdot
.35047 .30789 Mdot
.31443 .43346 Mdot
.37507 .3616 Mdot
.30243 .76288 Mdot
.55885 .35716 Mdot
.7062 .71536 Mdot
.48108 .62165 Mdot
.88344 .60688 Mdot
.50628 .61959 Mdot
.47787 .65857 Mdot
.70895 .44786 Mdot
.30255 .43058 Mdot
.32797 .44572 Mdot
.66675 .49281 Mdot
.72525 .4984 Mdot
.34521 .44306 Mdot
.36206 .60119 Mdot
.34359 .77123 Mdot
.31982 .60803 Mdot
.71084 .50915 Mdot
.60739 .73502 Mdot
.56759 .33328 Mdot
.68207 .53327 Mdot
.6049 .27438 Mdot
.39158 .28051 Mdot
.41599 .30653 Mdot
.58899 .32288 Mdot
.5149 .67761 Mdot
.37226 .36462 Mdot
.45605 .70592 Mdot
.53923 .27131 Mdot
.46758 .50961 Mdot
.18932 .60583 Mdot
.50325 .62771 Mdot
.56987 .50113 Mdot
.77414 .38723 Mdot
.48845 .60262 Mdot
.7299 .679 Mdot
.30627 .45045 Mdot
.6977 .53018 Mdot
.5547 .3614 Mdot
.81065 .52388 Mdot
.50109 .65573 Mdot
.71753 .49352 Mdot
.57498 .34901 Mdot
.63793 .25453 Mdot
.43816 .50623 Mdot
.4763 .61402 Mdot
.83217 .35185 Mdot
.64904 .47475 Mdot
.37937 .35216 Mdot
.64584 .68513 Mdot
.73032 .49041 Mdot
.43032 .51617 Mdot
.37256 .2739 Mdot
.36004 .65088 Mdot
.72051 .497 Mdot
.31037 .41824 Mdot
.69229 .48781 Mdot
.33452 .45786 Mdot
.71491 .44872 Mdot
.38272 .28934 Mdot
.5048 .67599 Mdot
.37943 .29025 Mdot
.34045 .4585 Mdot
.36352 .30525 Mdot
.55578 .36133 Mdot
.4905 .52673 Mdot
.58026 .31759 Mdot
.29814 .66959 Mdot
.70343 .61122 Mdot
.56938 .34312 Mdot
.40269 .63063 Mdot
.49671 .63246 Mdot
.73311 .47998 Mdot
.37572 .34919 Mdot
.41009 .35481 Mdot
.3173 .62598 Mdot
.68688 .46676 Mdot
.38053 .30163 Mdot
.61166 .72138 Mdot
.60912 .23185 Mdot
.47535 .71095 Mdot
.38314 .23936 Mdot
.67261 .48279 Mdot
.40368 .35964 Mdot
.33134 .60163 Mdot
.72075 .47458 Mdot
.40846 .28939 Mdot
.56777 .34874 Mdot
.56162 .309 Mdot
.4999 .62452 Mdot
.53673 .35782 Mdot
.42064 .31976 Mdot
.60383 .59727 Mdot
.66187 .4972 Mdot
.65503 .2669 Mdot
.31307 .42797 Mdot
.37208 .34285 Mdot
.51478 .55691 Mdot
.69293 .44835 Mdot
.40333 .30222 Mdot
.79535 .70181 Mdot
.3217 .80319 Mdot
.38085 .3036 Mdot
.69807 .49641 Mdot
.71012 .48436 Mdot
.51375 .60183 Mdot
.31365 .62428 Mdot
.38318 .31091 Mdot
.47399 .18136 Mdot
.32945 .68981 Mdot
.49089 .52079 Mdot
.16706 .40434 Mdot
.46099 .695 Mdot
.45362 .68344 Mdot
.55226 .34928 Mdot
.49454 .67925 Mdot
.72321 .50074 Mdot
.50702 .61973 Mdot
.55251 .31248 Mdot
.37455 .28211 Mdot
.50529 .65614 Mdot
.30841 .43828 Mdot
.54714 .32817 Mdot
.5453 .32545 Mdot
.39561 .28708 Mdot
.68909 .46127 Mdot
.82354 .51042 Mdot
.37674 .33762 Mdot
.4526 .67335 Mdot
.49675 .52168 Mdot
.53072 .66128 Mdot
.76203 .47918 Mdot
.68979 .52863 Mdot
.37359 .3503 Mdot
.48584 .56858 Mdot
.56215 .32136 Mdot
.42153 .33065 Mdot
.46145 .69768 Mdot
.40229 .27839 Mdot
.44713 .46296 Mdot
.30648 .25443 Mdot
.67479 .44503 Mdot
.44061 .46025 Mdot
.71618 .47068 Mdot
.48601 .51569 Mdot
.21364 .52537 Mdot
.3139 .4321 Mdot
.36338 .34683 Mdot
.66285 .28297 Mdot
.37489 .29373 Mdot
.50013 .67233 Mdot
.50315 .63334 Mdot
.40313 .33541 Mdot
.32648 .42058 Mdot
.39412 .48114 Mdot
.32463 .40677 Mdot
.70451 .49611 Mdot
.38759 .60985 Mdot
.26155 .73979 Mdot
.42227 .3062 Mdot
.59122 .3143 Mdot
.72982 .53725 Mdot
.51714 .57367 Mdot
.5545 .35958 Mdot
.54412 .32984 Mdot
.3309 .4642 Mdot
.3684 .32134 Mdot
.64785 .50866 Mdot
.58624 .29909 Mdot
.72706 .48016 Mdot
.26022 .58474 Mdot
.50727 .50822 Mdot
.56066 .69763 Mdot
.52306 .5681 Mdot
.32546 .62363 Mdot
.59006 .29844 Mdot
.49719 .63941 Mdot
.53699 .69522 Mdot
.5665 .35153 Mdot
.32642 .46635 Mdot
.4739 .51954 Mdot
.3822 .29963 Mdot
.84547 .41586 Mdot
.49079 .62733 Mdot
.51043 .6669 Mdot
.56414 .3549 Mdot
.75328 .66258 Mdot
.65927 .50984 Mdot
.67363 .46673 Mdot
.38925 .33197 Mdot
.31684 .57989 Mdot
.52227 .63955 Mdot
.49456 .63007 Mdot
.40651 .33362 Mdot
.49572 .50683 Mdot
.15721 .44637 Mdot
.49349 .65752 Mdot
.56694 .32704 Mdot
.45316 .49791 Mdot
.59793 .32608 Mdot
.52908 .68454 Mdot
.49427 .67217 Mdot
.45593 .64348 Mdot
.45934 .69789 Mdot
.57888 .32238 Mdot
.51887 .56814 Mdot
.52633 .59191 Mdot
.67722 .50146 Mdot
.48078 .69482 Mdot
.33127 .68992 Mdot
.49614 .6551 Mdot
.30573 .44575 Mdot
.34285 .59329 Mdot
.4628 .68811 Mdot
.47654 .69511 Mdot
.32633 .68993 Mdot
.4832 .68431 Mdot
.56811 .35456 Mdot
.7074 .47974 Mdot
.56088 .32066 Mdot
.59307 .31699 Mdot
.40306 .29848 Mdot
.31342 .46763 Mdot
.53667 .63335 Mdot
.34573 .43018 Mdot
.52789 .62264 Mdot
.5572 .64886 Mdot
.31393 .64783 Mdot
.32592 .5992 Mdot
.35072 .40991 Mdot
.49203 .63141 Mdot
.39094 .33784 Mdot
.368 .34143 Mdot
.41587 .55333 Mdot
.49674 .56926 Mdot
.54376 .36339 Mdot
.57634 .3394 Mdot
.42177 .4014 Mdot
.29876 .25157 Mdot
.34758 .41305 Mdot
.39921 .47764 Mdot
.46345 .70403 Mdot
.51915 .66751 Mdot
.50836 .5591 Mdot
.40428 .31258 Mdot
.48554 .5195 Mdot
.35752 .34677 Mdot
.57193 .3617 Mdot
.55072 .33099 Mdot
.49899 .62695 Mdot
.67601 .80362 Mdot
.69303 .50816 Mdot
.71038 .48282 Mdot
.55439 .31007 Mdot
.36216 .33161 Mdot
.51028 .54673 Mdot
.85606 .4576 Mdot
.68665 .52678 Mdot
.32274 .41328 Mdot
.47993 .68785 Mdot
.38806 .28133 Mdot
.67961 .50894 Mdot
.34167 .40478 Mdot
.49681 .69393 Mdot
.36932 .27899 Mdot
.49677 .64323 Mdot
.60291 .65264 Mdot
.66945 .50168 Mdot
.32732 .65103 Mdot
.67204 .45431 Mdot
.57715 .3228 Mdot
.59278 .30576 Mdot
.49618 .67022 Mdot
.85671 .44653 Mdot
.63177 .50432 Mdot
.57309 .29318 Mdot
.29963 .44343 Mdot
.49349 .53527 Mdot
.31545 .46581 Mdot
.40134 .33119 Mdot
.31168 .43418 Mdot
.40288 .30064 Mdot
.36958 .26338 Mdot
.6457 .49089 Mdot
.33494 .43325 Mdot
.72387 .66148 Mdot
.51332 .53384 Mdot
.3016 .46855 Mdot
.46501 .67531 Mdot
.51874 .61362 Mdot
.38879 .30773 Mdot
.34492 .42215 Mdot
.50432 .58055 Mdot
.67101 .33079 Mdot
.59609 .31011 Mdot
.55647 .362 Mdot
.5073 .54357 Mdot
.40664 .35301 Mdot
.6464 .48919 Mdot
.29457 .63126 Mdot
.63998 .49605 Mdot
.49182 .63003 Mdot
.53718 .63754 Mdot
.67407 .44916 Mdot
.64987 .47951 Mdot
.49162 .67064 Mdot
.65039 .75259 Mdot
.51597 .55883 Mdot
.56549 .30605 Mdot
.70356 .49838 Mdot
.71355 .49025 Mdot
.41995 .31938 Mdot
.67459 .46404 Mdot
.54247 .70168 Mdot
.56647 .36221 Mdot
.52923 .59564 Mdot
.56561 .32083 Mdot
.30285 .39956 Mdot
.39059 .30075 Mdot
.65119 .2736 Mdot
.66994 .46798 Mdot
.49924 .6005 Mdot
.66368 .47146 Mdot
.30251 .4493 Mdot
.71475 .50137 Mdot
.72161 .53029 Mdot
.47631 .63793 Mdot
.51644 .56594 Mdot
.49117 .49433 Mdot
.32015 .62239 Mdot
.68613 .50477 Mdot
.53753 .64768 Mdot
.5113 .61895 Mdot
.5161 .6379 Mdot
.30875 .63891 Mdot
.67173 .45868 Mdot
.77646 .64228 Mdot
.67436 .43826 Mdot
.67186 .50427 Mdot
.37537 .8201 Mdot
.48821 .48899 Mdot
.49852 .54739 Mdot
.51753 .34005 Mdot
.49392 .66039 Mdot
.37357 .31106 Mdot
.45327 .66266 Mdot
.51072 .5582 Mdot
.46778 .68982 Mdot
.3342 .4514 Mdot
.52775 .67295 Mdot
.49156 .51074 Mdot
.37502 .34046 Mdot
.48671 .60627 Mdot
.50212 .66179 Mdot
.49707 .50635 Mdot
.65836 .47751 Mdot
.70676 .46457 Mdot
.64146 .47883 Mdot
.33822 .45731 Mdot
.56255 .34009 Mdot
.45353 .66456 Mdot
.38993 .33443 Mdot
.3725 .30939 Mdot
.68456 .4527 Mdot
.40302 .34612 Mdot
.54929 .33467 Mdot
.47886 .66229 Mdot
.57836 .32174 Mdot
.33308 .45418 Mdot
.69691 .4993 Mdot
.45579 .67064 Mdot
.4774 .6075 Mdot
.66901 .47702 Mdot
.519 .55766 Mdot
.30062 .45115 Mdot
.4113 .32974 Mdot
.69319 .51691 Mdot
.58037 .30834 Mdot
.41887 .31855 Mdot
.49231 .60231 Mdot
.48157 .84496 Mdot
.494 .67874 Mdot
.51939 .63828 Mdot
.62841 .48679 Mdot
.51682 .6926 Mdot
.37704 .28968 Mdot
.67119 .4624 Mdot
.51519 .6112 Mdot
.31069 .69323 Mdot
.34675 .39177 Mdot
.42468 .30964 Mdot
.47596 .67601 Mdot
.5917 .77925 Mdot
.49875 .60695 Mdot
.6713 .28953 Mdot
.31461 .64775 Mdot
.61599 .28407 Mdot
.56207 .69198 Mdot
.56872 .2947 Mdot
.49696 .51581 Mdot
.39769 .29328 Mdot
.68794 .7117 Mdot
.48818 .67354 Mdot
.70131 .58822 Mdot
.45603 .66316 Mdot
.55502 .32775 Mdot
.74097 .66243 Mdot
.38945 .35941 Mdot
.17209 .48043 Mdot
.49773 .6909 Mdot
.66626 .51635 Mdot
.35224 .35301 Mdot
.4977 .54474 Mdot
.51432 .56857 Mdot
.34907 .42443 Mdot
.42873 .39085 Mdot
.5526 .67191 Mdot
.56382 .31949 Mdot
.52413 .66137 Mdot
.46467 .61899 Mdot
.60627 .21475 Mdot
.67425 .49403 Mdot
.58349 .33664 Mdot
.29267 .26417 Mdot
.49444 .63607 Mdot
.71484 .47099 Mdot
.69198 .47478 Mdot
.34292 .43739 Mdot
.61641 .30947 Mdot
.44512 .37654 Mdot
.66181 .79637 Mdot
.5733 .65182 Mdot
.40609 .31533 Mdot
.47918 .47 Mdot
.45301 .66082 Mdot
.27104 .49772 Mdot
.59165 .3109 Mdot
.50954 .67009 Mdot
.72761 .57565 Mdot
.67682 .48257 Mdot
.49211 .64854 Mdot
.31304 .43744 Mdot
.83482 .50301 Mdot
.59737 .72952 Mdot
.61066 .76717 Mdot
.37766 .26591 Mdot
.53506 .62742 Mdot
.54226 .70082 Mdot
.49595 .49569 Mdot
.53138 .68356 Mdot
.378 .35 Mdot
.45568 .46096 Mdot
.31896 .43462 Mdot
.68316 .51014 Mdot
.49891 .52107 Mdot
.45627 .66296 Mdot
.52923 .61374 Mdot
.30136 .43984 Mdot
.46028 .6342 Mdot
.65111 .69548 Mdot
.47987 .47369 Mdot
.4161 .31575 Mdot
.70396 .51547 Mdot
.53564 .63264 Mdot
.49559 .53931 Mdot
.47417 .65211 Mdot
.69071 .55225 Mdot
.5134 .66946 Mdot
.65259 .31549 Mdot
.67479 .46974 Mdot
.56953 .3095 Mdot
.46188 .69934 Mdot
.49951 .64671 Mdot
.43524 .46127 Mdot
.51158 .54554 Mdot
.48078 .69223 Mdot
.7044 .45985 Mdot
.68777 .50997 Mdot
.66598 .51535 Mdot
.41625 .29975 Mdot
.3159 .61139 Mdot
.57588 .31867 Mdot
.50805 .55911 Mdot
.58599 .29893 Mdot
.49525 .76273 Mdot
.32872 .46112 Mdot
.63925 .26493 Mdot
.48074 .66485 Mdot
.69449 .4671 Mdot
.32901 .75984 Mdot
.67982 .45345 Mdot
.50557 .32433 Mdot
.59079 .30863 Mdot
.68803 .49908 Mdot
.48 .67999 Mdot
.33165 .61778 Mdot
.61257 .77754 Mdot
.59806 .3056 Mdot
.50293 .55609 Mdot
.28361 .40844 Mdot
.38956 .27054 Mdot
.3588 .81004 Mdot
.57851 .29945 Mdot
.77519 .38731 Mdot
.50938 .60582 Mdot
.66117 .47814 Mdot
.57543 .33228 Mdot
.54215 .33449 Mdot
.39195 .3593 Mdot
.47265 .61883 Mdot
.4975 .64715 Mdot
.48346 .50353 Mdot
.58452 .32121 Mdot
.49061 .56713 Mdot
.48103 .6073 Mdot
.49975 .30044 Mdot
.67376 .52365 Mdot
.56645 .17754 Mdot
.41005 .65049 Mdot
.72641 .57662 Mdot
.53214 .18881 Mdot
.68486 .51753 Mdot
.51191 .68046 Mdot
.50887 .55008 Mdot
.41034 .3345 Mdot
.48046 .67408 Mdot
.37072 .29656 Mdot
.55649 .33414 Mdot
.65872 .32964 Mdot
.40352 .64643 Mdot
.52078 .29027 Mdot
.49995 .67649 Mdot
.60311 .72367 Mdot
.32818 .43298 Mdot
.55763 .36337 Mdot
.65016 .49725 Mdot
.53425 .65645 Mdot
.40081 .35321 Mdot
.3958 .27474 Mdot
.67826 .48572 Mdot
.75894 .39196 Mdot
.6559 .27594 Mdot
.51759 .55427 Mdot
.39428 .35046 Mdot
.50103 .54564 Mdot
.58438 .77067 Mdot
.5801 .29465 Mdot
.31995 .43484 Mdot
.40082 .28869 Mdot
.53807 .34395 Mdot
.51829 .6126 Mdot
.68293 .49103 Mdot
.65614 .46104 Mdot
.41984 .54077 Mdot
.37921 .30237 Mdot
.32043 .45635 Mdot
.428 .52993 Mdot
.39491 .59346 Mdot
.31634 .44667 Mdot
.41709 .29857 Mdot
.70806 .50209 Mdot
.68277 .47179 Mdot
.70502 .47809 Mdot
.70715 .71321 Mdot
.69072 .5283 Mdot
.262 .52614 Mdot
.53027 .68448 Mdot
.61328 .72979 Mdot
.52483 .62791 Mdot
.55454 .36109 Mdot
.66589 .49874 Mdot
.31595 .64911 Mdot
.46051 .70241 Mdot
.6168 .77739 Mdot
.51721 .64817 Mdot
.44985 .49775 Mdot
.49489 .66111 Mdot
.61299 .65578 Mdot
.70672 .5278 Mdot
.50243 .69064 Mdot
.58534 .3475 Mdot
.31173 .46035 Mdot
.72458 .46101 Mdot
.5005 .68506 Mdot
.73924 .42278 Mdot
.46445 .67483 Mdot
.65731 .32548 Mdot
.42674 .52386 Mdot
.37539 .43345 Mdot
.52869 .64834 Mdot
.36417 .36384 Mdot
.46284 .72342 Mdot
.60643 .74092 Mdot
.59586 .30379 Mdot
.60743 .723 Mdot
.36602 .35763 Mdot
.74333 .66121 Mdot
.51693 .54962 Mdot
.31953 .43059 Mdot
.4713 .46519 Mdot
.57161 .30337 Mdot
.48362 .66909 Mdot
.51074 .68331 Mdot
.46764 .51541 Mdot
.57437 .77084 Mdot
.50103 .50816 Mdot
.3496 .40794 Mdot
.58963 .74512 Mdot
.48318 .69113 Mdot
.42658 .32201 Mdot
.69549 .45963 Mdot
.7359 .65655 Mdot
.75293 .64647 Mdot
.48663 .60297 Mdot
.68434 .49876 Mdot
.68776 .46061 Mdot
.27186 .72404 Mdot
.33 .42657 Mdot
.51554 .66452 Mdot
.44132 .45685 Mdot
.4539 .66527 Mdot
.5611 .33186 Mdot
.47424 .70581 Mdot
.38902 .30027 Mdot
.33564 .60303 Mdot
.41419 .29377 Mdot
.51501 .63646 Mdot
.69406 .48753 Mdot
.59652 .3199 Mdot
.36859 .26178 Mdot
.61612 .30981 Mdot
.26087 .52741 Mdot
.41718 .39636 Mdot
.34672 .41223 Mdot
.32494 .46469 Mdot
.55719 .36311 Mdot
.47592 .66846 Mdot
.30872 .63281 Mdot
.43102 .68971 Mdot
.48922 .6591 Mdot
.50313 .68096 Mdot
.52612 .32804 Mdot
.58844 .30735 Mdot
.38883 .28403 Mdot
.49012 .67064 Mdot
.53795 .65606 Mdot
.69236 .49256 Mdot
.34271 .41209 Mdot
.41104 .31046 Mdot
.34595 .44606 Mdot
.38269 .34254 Mdot
.37653 .78722 Mdot
.50946 .51559 Mdot
.32221 .46093 Mdot
.57368 .29764 Mdot
.70504 .47278 Mdot
.48481 .48562 Mdot
.39815 .32456 Mdot
.40001 .34936 Mdot
.52162 .61049 Mdot
.67898 .50782 Mdot
.67215 .46734 Mdot
.34549 .44422 Mdot
.57442 .34043 Mdot
.45936 .71299 Mdot
.52213 .57083 Mdot
.36063 .24769 Mdot
.40767 .34557 Mdot
.59767 .74008 Mdot
.64961 .45392 Mdot
.47767 .64614 Mdot
.71069 .46812 Mdot
.50624 .65129 Mdot
.73873 .52186 Mdot
.65112 .4717 Mdot
.50363 .69902 Mdot
.44629 .6357 Mdot
.40376 .30927 Mdot
.22687 .68325 Mdot
.49135 .70936 Mdot
.58518 .26939 Mdot
.45424 .65361 Mdot
.15751 .4664 Mdot
.31903 .75135 Mdot
.47049 .67103 Mdot
.52716 .67203 Mdot
.62451 .82098 Mdot
.49696 .6092 Mdot
.48766 .51225 Mdot
.51664 .5464 Mdot
.7147 .47233 Mdot
.44286 .4595 Mdot
.32173 .62463 Mdot
.33597 .42601 Mdot
.3902 .332 Mdot
.25654 .60462 Mdot
.33418 .4589 Mdot
.6762 .47862 Mdot
.45909 .71347 Mdot
.63256 .48166 Mdot
.38359 .37442 Mdot
.5032 .52706 Mdot
.55617 .33063 Mdot
.31319 .62988 Mdot
.39736 .35581 Mdot
.58276 .30839 Mdot
.50358 .61113 Mdot
.3535 .3091 Mdot
.59192 .33787 Mdot
.23361 .69563 Mdot
.54833 .34843 Mdot
.57986 .30459 Mdot
.31338 .61899 Mdot
.33611 .42591 Mdot
.45925 .46377 Mdot
.54942 .62314 Mdot
.5901 .33319 Mdot
.18507 .49749 Mdot
.39967 .35731 Mdot
.30425 .60214 Mdot
.70547 .52904 Mdot
.51032 .5216 Mdot
.50416 .67839 Mdot
.55435 .35224 Mdot
.48327 .56534 Mdot
.43361 .46134 Mdot
.55174 .32289 Mdot
.45106 .69589 Mdot
.32207 .58098 Mdot
.49534 .53539 Mdot
.48667 .4893 Mdot
.33661 .40564 Mdot
.30727 .29045 Mdot
.68925 .46358 Mdot
.31964 .41595 Mdot
.31086 .66749 Mdot
.51955 .64833 Mdot
.57805 .32457 Mdot
.49971 .52247 Mdot
.57599 .31008 Mdot
.32682 .44033 Mdot
.29942 .44995 Mdot
.67656 .50047 Mdot
.66212 .5114 Mdot
.47257 .47725 Mdot
.32999 .69547 Mdot
.46274 .64661 Mdot
.69384 .6006 Mdot
.65097 .47588 Mdot
.72766 .69205 Mdot
.33821 .42148 Mdot
.34278 .41435 Mdot
.55797 .74827 Mdot
.4715 .63552 Mdot
.45238 .49714 Mdot
.4634 .68909 Mdot
.19467 .47524 Mdot
.4564 .66809 Mdot
.40624 .33797 Mdot
.46945 .6974 Mdot
.78195 .45137 Mdot
.50698 .59384 Mdot
.48767 .6884 Mdot
.38264 .32348 Mdot
.53066 .62276 Mdot
.38848 .30446 Mdot
.51698 .6741 Mdot
.43979 .34829 Mdot
.38955 .33416 Mdot
.28468 .4466 Mdot
.44395 .52874 Mdot
.48694 .50154 Mdot
.33899 .44122 Mdot
.34896 .41509 Mdot
.26456 .58306 Mdot
.70157 .50574 Mdot
.76806 .57085 Mdot
.4813 .68728 Mdot
.40369 .35437 Mdot
.55641 .3385 Mdot
.49195 .59664 Mdot
.51141 .62651 Mdot
.49113 .70925 Mdot
.68129 .50168 Mdot
.41985 .33294 Mdot
.33311 .44238 Mdot
.36749 .31703 Mdot
.43779 .3404 Mdot
.39427 .30289 Mdot
.43674 .63735 Mdot
.52058 .61399 Mdot
.5412 .70154 Mdot
.71671 .62922 Mdot
.33953 .48458 Mdot
.68023 .48894 Mdot
.49593 .5166 Mdot
.32116 .46473 Mdot
.34976 .58303 Mdot
.69921 .46472 Mdot
.4054 .3351 Mdot
.49714 .64291 Mdot
.50805 .50788 Mdot
.54959 .62427 Mdot
.72988 .4829 Mdot
.30792 .4734 Mdot
.39246 .32476 Mdot
.49295 .5244 Mdot
.31677 .60785 Mdot
.79006 .60988 Mdot
.29433 .66254 Mdot
.50279 .64813 Mdot
.34466 .44481 Mdot
.68017 .509 Mdot
.45901 .49712 Mdot
.56175 .3518 Mdot
.31547 .62422 Mdot
.49823 .67817 Mdot
.49603 .34091 Mdot
.69356 .48605 Mdot
.32257 .42208 Mdot
.55303 .35215 Mdot
.32682 .42539 Mdot
.49264 .53875 Mdot
.67015 .43918 Mdot
.51392 .56816 Mdot
.45792 .68392 Mdot
.55813 .33726 Mdot
.68423 .46408 Mdot
.44271 .35152 Mdot
.4645 .47615 Mdot
.40248 .33522 Mdot
.35109 .59039 Mdot
.68492 .50969 Mdot
.48439 .33238 Mdot
.36746 .3145 Mdot
.52867 .3552 Mdot
.34406 .62815 Mdot
.5475 .33338 Mdot
.4933 .68732 Mdot
.70452 .48388 Mdot
.59812 .3048 Mdot
.34291 .28561 Mdot
.65858 .76376 Mdot
.46919 .47106 Mdot
.4986 .63229 Mdot
.6781 .28874 Mdot
.77852 .4067 Mdot
.73829 .50954 Mdot
.57089 .30029 Mdot
.50479 .66724 Mdot
.51856 .5531 Mdot
.49371 .69272 Mdot
.59174 .32745 Mdot
.57487 .38865 Mdot
.37268 .35728 Mdot
.4956 .63967 Mdot
.30835 .43625 Mdot
.38892 .29512 Mdot
.381 .27098 Mdot
.40179 .28833 Mdot
.65098 .4978 Mdot
.50597 .50888 Mdot
.51697 .54373 Mdot
.29873 .72646 Mdot
.57219 .30689 Mdot
.48715 .50195 Mdot
.52341 .67622 Mdot
.26255 .53074 Mdot
.69642 .47016 Mdot
.39156 .31929 Mdot
.51118 .66595 Mdot
.42131 .53534 Mdot
.50076 .51459 Mdot
.37759 .33185 Mdot
.64868 .48181 Mdot
.60839 .49673 Mdot
.48004 .67142 Mdot
.45803 .64405 Mdot
.67028 .48035 Mdot
.80126 .42282 Mdot
.3172 .60306 Mdot
.50514 .65296 Mdot
.57749 .30714 Mdot
.76785 .32711 Mdot
.50698 .61251 Mdot
.64332 .51617 Mdot
.4826 .51205 Mdot
.69285 .43129 Mdot
.64165 .70958 Mdot
.4827 .58721 Mdot
.57293 .45526 Mdot
.37816 .50249 Mdot
.58664 .49631 Mdot
.21363 .47635 Mdot
.50707 .43395 Mdot
.25233 .72355 Mdot
.55732 .36638 Mdot
.60466 .6662 Mdot
.78501 .70906 Mdot
.76435 .38474 Mdot
.45029 .42959 Mdot
.60696 .38467 Mdot
.34442 .38157 Mdot
.15847 .4331 Mdot
.35837 .35376 Mdot
.21832 .47062 Mdot
.45827 .68025 Mdot
.79499 .42243 Mdot
.60576 .67919 Mdot
.38721 .40928 Mdot
.60428 .25919 Mdot
.42618 .52807 Mdot
.5516 .81882 Mdot
.54168 .27206 Mdot
.44339 .82026 Mdot
.7441 .57246 Mdot
.32807 .25735 Mdot
.37047 .60788 Mdot
.24778 .58566 Mdot
.61395 .70327 Mdot
.61834 .44689 Mdot
.58139 .36437 Mdot
.62396 .58049 Mdot
.54724 .18902 Mdot
.3954 .34448 Mdot
.72795 .48773 Mdot
.59394 .40493 Mdot
.50053 .81878 Mdot
.53426 .28906 Mdot
.57143 .45583 Mdot
.46687 .47794 Mdot
.6105 .65752 Mdot
.32137 .65355 Mdot
.60862 .63159 Mdot
.43805 .38899 Mdot
.16144 .43248 Mdot
.62186 .50396 Mdot
.33657 .28917 Mdot
.33304 .56632 Mdot
.42351 .42773 Mdot
.62989 .66596 Mdot
.33731 .46851 Mdot
.28512 .44118 Mdot
.64818 .48093 Mdot
.53732 .80147 Mdot
.41395 .61451 Mdot
.31604 .67264 Mdot
.35826 .35582 Mdot
.6451 .54014 Mdot
.83134 .50169 Mdot
.76628 .40734 Mdot
.1976 .63901 Mdot
.47991 .84034 Mdot
.20254 .54082 Mdot
.46265 .5221 Mdot
.52526 .30059 Mdot
.28004 .52417 Mdot
.56581 .50006 Mdot
.2069 .57585 Mdot
.69735 .55157 Mdot
.6 .80976 Mdot
.7058 .40812 Mdot
.51736 .83668 Mdot
.61802 .50401 Mdot
.54294 .68824 Mdot
.7413 .47715 Mdot
.60034 .59311 Mdot
.28486 .67359 Mdot
.52631 .82455 Mdot
.37985 .41033 Mdot
.48783 .53595 Mdot
.75384 .37878 Mdot
.64962 .69551 Mdot
.4558 .36957 Mdot
.29558 .42809 Mdot
.74111 .62952 Mdot
.55534 .82689 Mdot
.58412 .45055 Mdot
.47901 .78785 Mdot
.49779 .30038 Mdot
.42261 .25401 Mdot
.37698 .2744 Mdot
.55071 .30687 Mdot
.46014 .8263 Mdot
.7004 .47986 Mdot
.21988 .68007 Mdot
.51494 .44719 Mdot
.51151 .46524 Mdot
.56083 .82618 Mdot
.19204 .5907 Mdot
.62729 .70808 Mdot
.35938 .49253 Mdot
.61518 .24013 Mdot
.58809 .54438 Mdot
.50705 .30273 Mdot
.28656 .41714 Mdot
.66407 .30771 Mdot
.47524 .82544 Mdot
.19275 .5553 Mdot
.68107 .78993 Mdot
.32652 .67507 Mdot
.25274 .4357 Mdot
.62368 .50412 Mdot
.50472 .39982 Mdot
.46365 .3677 Mdot
.5088 .84024 Mdot
.59218 .73316 Mdot
.72723 .29185 Mdot
.21099 .49292 Mdot
.75603 .64967 Mdot
.69878 .31875 Mdot
.57028 .4038 Mdot
.59788 .5797 Mdot
.74052 .41982 Mdot
.52873 .57471 Mdot
.27893 .65333 Mdot
.74235 .61327 Mdot
.37173 .42306 Mdot
.32743 .60887 Mdot
.70168 .39311 Mdot
.22412 .58378 Mdot
.74404 .31694 Mdot
.74756 .62316 Mdot
.67983 .44915 Mdot
.20801 .57499 Mdot
.20413 .50911 Mdot
.7132 .29556 Mdot
.29026 .26785 Mdot
.47629 .78962 Mdot
.48163 .3591 Mdot
.47329 .59986 Mdot
.60272 .66924 Mdot
.61565 .69869 Mdot
.17173 .44752 Mdot
.44366 .6291 Mdot
.26434 .70467 Mdot
.59306 .26214 Mdot
.70266 .64895 Mdot
.252 .64754 Mdot
.71239 .63832 Mdot
.62459 .73145 Mdot
.76719 .47723 Mdot
.60266 .27753 Mdot
.4595 .58849 Mdot
.56006 .82275 Mdot
.39013 .28816 Mdot
.20483 .57704 Mdot
.53384 .28435 Mdot
.35014 .26729 Mdot
.47777 .44349 Mdot
.44255 .43533 Mdot
.41366 .82534 Mdot
.7402 .37261 Mdot
.32472 .37411 Mdot
.63944 .44912 Mdot
.54327 .47167 Mdot
.70039 .60471 Mdot
.41961 .64843 Mdot
.66043 .54637 Mdot
.30054 .45112 Mdot
.69721 .6884 Mdot
.74279 .44246 Mdot
.28017 .27546 Mdot
.43238 .6517 Mdot
.37358 .6075 Mdot
.48088 .49719 Mdot
.28143 .5776 Mdot
.37037 .78589 Mdot
.47531 .58599 Mdot
.19623 .5988 Mdot
.75691 .38557 Mdot
.27804 .58243 Mdot
.45994 .37277 Mdot
.77318 .57366 Mdot
.52047 .8367 Mdot
.34007 .7934 Mdot
.79714 .4445 Mdot
.69045 .31103 Mdot
.25989 .25716 Mdot
.61234 .28044 Mdot
.2374 .68196 Mdot
.53344 .28485 Mdot
.79864 .28295 Mdot
.37545 .28923 Mdot
.26537 .49225 Mdot
.61236 .54293 Mdot
.38712 .57425 Mdot
.51883 .81341 Mdot
.63526 .69132 Mdot
.30348 .47296 Mdot
.73719 .49855 Mdot
.45217 .62113 Mdot
.54143 .81181 Mdot
.57076 .81316 Mdot
.54818 .80865 Mdot
.5289 .37655 Mdot
.62638 .75981 Mdot
.59914 .8265 Mdot
.26781 .52246 Mdot
.44619 .56341 Mdot
.4806 .59708 Mdot
.31626 .70183 Mdot
.22802 .65322 Mdot
.3369 .47863 Mdot
.58905 .54866 Mdot
.62257 .50023 Mdot
.58065 .83243 Mdot
.35587 .7813 Mdot
.60582 .62647 Mdot
.41852 .82031 Mdot
.30899 .37219 Mdot
.26113 .67494 Mdot
.38052 .81257 Mdot
.60382 .4472 Mdot
.512 .35191 Mdot
.60223 .83425 Mdot
.21046 .52303 Mdot
.60382 .38688 Mdot
.74045 .42732 Mdot
.22598 .66086 Mdot
.68927 .32106 Mdot
.59601 .39494 Mdot
.61404 .53389 Mdot
.80004 .57603 Mdot
.45199 .42015 Mdot
.61651 .45228 Mdot
.45798 .5125 Mdot
.24888 .65096 Mdot
.36699 .29683 Mdot
.21193 .59803 Mdot
.44665 .40388 Mdot
.45328 .56089 Mdot
.26664 .60679 Mdot
.19042 .52254 Mdot
.66438 .41458 Mdot
.60326 .7711 Mdot
.74963 .38105 Mdot
.76089 .32629 Mdot
.71096 .31167 Mdot
.75184 .59423 Mdot
.53314 .62697 Mdot
.50686 .81948 Mdot
.28475 .76879 Mdot
.39061 .81909 Mdot
.72455 .30257 Mdot
.42211 .2689 Mdot
.5406 .35838 Mdot
.26909 .53744 Mdot
.39837 .55307 Mdot
.58437 .42921 Mdot
.39967 .49632 Mdot
.57896 .28966 Mdot
.83378 .49831 Mdot
.49092 .44818 Mdot
.26905 .52665 Mdot
.63186 .57611 Mdot
.53566 .47737 Mdot
.58154 .77179 Mdot
.67435 .44992 Mdot
.69784 .27922 Mdot
.20805 .57892 Mdot
.39397 .28819 Mdot
.35804 .24597 Mdot
.44828 .59751 Mdot
.53508 .6952 Mdot
.27786 .41189 Mdot
.4683 .56421 Mdot
.72503 .57856 Mdot
.41767 .26726 Mdot
.30285 .7545 Mdot
.22579 .67682 Mdot
.37554 .81046 Mdot
.19966 .5345 Mdot
.34271 .27516 Mdot
.28636 .58527 Mdot
.56279 .28279 Mdot
.56133 .26494 Mdot
.3073 .57563 Mdot
.19598 .51756 Mdot
.62603 .71291 Mdot
.74076 .49237 Mdot
.4954 .576 Mdot
.33688 .76522 Mdot
.24839 .56328 Mdot
.29162 .56791 Mdot
.77812 .59645 Mdot
.66317 .52338 Mdot
.24437 .46337 Mdot
.63278 .4423 Mdot
.49577 .7456 Mdot
.69393 .30591 Mdot
.59627 .29745 Mdot
.66432 .45356 Mdot
.18946 .52369 Mdot
.31524 .23588 Mdot
.57364 .48997 Mdot
.40653 .62802 Mdot
.47686 .81859 Mdot
.43053 .55048 Mdot
.67641 .31777 Mdot
.81453 .57848 Mdot
.55892 .25075 Mdot
.6191 .51262 Mdot
.46106 .54701 Mdot
.46799 .44256 Mdot
.78727 .47572 Mdot
.71967 .46312 Mdot
.59698 .72641 Mdot
.45972 .83325 Mdot
.43391 .52099 Mdot
.60521 .46224 Mdot
.29463 .62791 Mdot
.48473 .40049 Mdot
.52803 .4572 Mdot
.2623 .60841 Mdot
.58352 .47705 Mdot
.50199 .78681 Mdot
.84603 .47214 Mdot
.59126 .56599 Mdot
.24828 .48169 Mdot
.27162 .53317 Mdot
.74519 .57149 Mdot
.62678 .66221 Mdot
.57888 .25456 Mdot
.45985 .69042 Mdot
.45263 .8402 Mdot
.7067 .40124 Mdot
.2723 .59541 Mdot
.50213 .36162 Mdot
.48851 .60975 Mdot
.54919 .68291 Mdot
.39237 .81753 Mdot
.6953 .43046 Mdot
.82856 .66762 Mdot
.20491 .48147 Mdot
.7498 .52699 Mdot
.63699 .71289 Mdot
.20131 .60866 Mdot
.77153 .49362 Mdot
.52603 .44576 Mdot
.45379 .398 Mdot
.2173 .63978 Mdot
.71172 .42843 Mdot
.67868 .4285 Mdot
.6902 .28985 Mdot
.60112 .82161 Mdot
.59176 .51337 Mdot
.53327 .36936 Mdot
.30424 .37677 Mdot
.52068 .63927 Mdot
.76155 .39401 Mdot
.64342 .26392 Mdot
.50934 .3762 Mdot
.58495 .51597 Mdot
.28212 .76894 Mdot
.44777 .65123 Mdot
.73716 .37816 Mdot
.82103 .67537 Mdot
.85668 .63713 Mdot
.77512 .44694 Mdot
.50092 .84317 Mdot
.67173 .4312 Mdot
.67573 .32126 Mdot
.60558 .30836 Mdot
.38878 .61044 Mdot
.69694 .59304 Mdot
.42057 .83575 Mdot
.33076 .23104 Mdot
.50473 .30528 Mdot
.62058 .5623 Mdot
.41694 .83653 Mdot
.4498 .63944 Mdot
.25161 .47488 Mdot
.425 .25599 Mdot
.17193 .48582 Mdot
.19738 .633 Mdot
.78703 .5918 Mdot
.16757 .45285 Mdot
.21945 .44433 Mdot
.39696 .41832 Mdot
.22889 .67711 Mdot
.56959 .64648 Mdot
.78974 .57181 Mdot
.20817 .57181 Mdot
.6793 .30222 Mdot
.20791 .32929 Mdot
.53506 .46035 Mdot
.46878 .55482 Mdot
.76901 .45914 Mdot
.66138 .31004 Mdot
.66162 .39851 Mdot
.43369 .56384 Mdot
.34802 .60052 Mdot
.61766 .73489 Mdot
.76366 .32006 Mdot
.82249 .58312 Mdot
.47803 .55057 Mdot
.57996 .80443 Mdot
.55514 .26197 Mdot
.31218 .56366 Mdot
.64269 .67868 Mdot
.25679 .56091 Mdot
.30702 .38 Mdot
.46571 .68907 Mdot
.46556 .83318 Mdot
.30595 .38114 Mdot
.56725 .80737 Mdot
.21961 .6853 Mdot
.42958 .81705 Mdot
.52123 .47858 Mdot
.2875 .40671 Mdot
.22623 .64321 Mdot
.22983 .64699 Mdot
.61505 .80122 Mdot
.22418 .46301 Mdot
.31569 .57564 Mdot
.44996 .53754 Mdot
.40448 .64142 Mdot
.48075 .74952 Mdot
.20246 .61398 Mdot
.768 .55849 Mdot
.25282 .64309 Mdot
.795 .45172 Mdot
.1933 .52135 Mdot
.62939 .70164 Mdot
.25994 .56815 Mdot
.4922 .37551 Mdot
.29585 .47413 Mdot
.39945 .35851 Mdot
.6611 .80406 Mdot
.70698 .29767 Mdot
.27855 .71345 Mdot
.72083 .28939 Mdot
.73662 .41803 Mdot
.21159 .4638 Mdot
.7386 .4707 Mdot
.58362 .58675 Mdot
.3224 .2645 Mdot
.23252 .59221 Mdot
.60006 .73242 Mdot
.67178 .28849 Mdot
.77129 .63071 Mdot
.42304 .82974 Mdot
.25326 .65384 Mdot
.71373 .77232 Mdot
.26527 .4186 Mdot
.69876 .68316 Mdot
.53228 .79817 Mdot
.79333 .3724 Mdot
.2919 .56284 Mdot
.56379 .8205 Mdot
.7242 .51803 Mdot
.48486 .8404 Mdot
.55837 .34795 Mdot
.25232 .44934 Mdot
.65727 .28244 Mdot
.27799 .55517 Mdot
.2801 .55424 Mdot
.28627 .73401 Mdot
.74787 .37681 Mdot
.77057 .40726 Mdot
.48113 .35827 Mdot
.35706 .33277 Mdot
.39284 .63728 Mdot
.59803 .46233 Mdot
.6716 .79253 Mdot
.53455 .63242 Mdot
.26051 .41353 Mdot
.20091 .5855 Mdot
.55865 .28515 Mdot
.47301 .53359 Mdot
.66573 .29266 Mdot
.8052 .59566 Mdot
.28454 .6918 Mdot
.59221 .82424 Mdot
.47371 .53289 Mdot
.40163 .53493 Mdot
.74563 .66671 Mdot
.6158 .39226 Mdot
.54979 .25989 Mdot
.57906 .45903 Mdot
.4174 .57689 Mdot
.31397 .60432 Mdot
.20309 .53359 Mdot
.26687 .74742 Mdot
.59408 .80334 Mdot
.55258 .25792 Mdot
.28288 .56339 Mdot
.6461 .51972 Mdot
.23905 .59204 Mdot
.70404 .78044 Mdot
.15701 .4514 Mdot
.74047 .42589 Mdot
.1933 .53429 Mdot
.53981 .39033 Mdot
.25207 .47915 Mdot
.2986 .57132 Mdot
.52958 .79881 Mdot
.61023 .55321 Mdot
.68676 .43326 Mdot
.57482 .40675 Mdot
.32054 .63097 Mdot
.48977 .4408 Mdot
.78587 .57946 Mdot
.74354 .37073 Mdot
.71574 .7707 Mdot
.20904 .44663 Mdot
.74399 .65716 Mdot
.76369 .72806 Mdot
.64602 .4924 Mdot
.47724 .43656 Mdot
.43191 .2427 Mdot
.27798 .57577 Mdot
.39326 .27696 Mdot
.49006 .56749 Mdot
.33917 .58405 Mdot
.78647 .46372 Mdot
.33755 .3736 Mdot
.30969 .46935 Mdot
.68182 .4505 Mdot
.22047 .45169 Mdot
.66112 .45493 Mdot
.26454 .74178 Mdot
.60445 .44235 Mdot
.6132 .73454 Mdot
.8107 .61124 Mdot
.33771 .27412 Mdot
.7732 .33866 Mdot
.43895 .82069 Mdot
.3156 .69254 Mdot
.7239 .46623 Mdot
.6954 .44435 Mdot
.63337 .45849 Mdot
.55626 .29354 Mdot
.4849 .8141 Mdot
.19388 .58781 Mdot
.35425 .24657 Mdot
.7211 .5118 Mdot
.45282 .5226 Mdot
.47118 .5711 Mdot
.31948 .76495 Mdot
.36881 .31063 Mdot
.53649 .83641 Mdot
.76814 .56447 Mdot
.79327 .39289 Mdot
.59543 .42383 Mdot
.36211 .64178 Mdot
.30133 .55289 Mdot
.33878 .30561 Mdot
.47345 .60137 Mdot
.74677 .52456 Mdot
.66691 .5135 Mdot
.4826 .44173 Mdot
.3283 .4158 Mdot
.28123 .27696 Mdot
.58202 .27402 Mdot
.73956 .59312 Mdot
.19868 .6155 Mdot
.67688 .44782 Mdot
.26757 .42454 Mdot
.32959 .29249 Mdot
.43583 .65219 Mdot
.33394 .71019 Mdot
.64131 .81561 Mdot
.45787 .81607 Mdot
.69313 .45343 Mdot
.75716 .32638 Mdot
.44906 .35157 Mdot
.30055 .75135 Mdot
.72816 .43228 Mdot
.20385 .60123 Mdot
.72946 .63742 Mdot
.36163 .79874 Mdot
.64136 .70889 Mdot
.576 .44428 Mdot
.20017 .56045 Mdot
.43548 .45663 Mdot
.18999 .53744 Mdot
.79983 .61066 Mdot
.39938 .61445 Mdot
.17559 .49273 Mdot
.5136 .37381 Mdot
.60663 .63841 Mdot
.48551 .73869 Mdot
.58377 .4319 Mdot
.21757 .63487 Mdot
.66218 .46812 Mdot
.35707 .42504 Mdot
.64092 .56547 Mdot
.51396 .29359 Mdot
.47156 .82468 Mdot
.72355 .30635 Mdot
.19535 .57523 Mdot
.40684 .63844 Mdot
.23523 .54033 Mdot
.76351 .55975 Mdot
.32297 .68052 Mdot
.52306 .54975 Mdot
.73927 .62188 Mdot
.41334 .46853 Mdot
.30934 .74234 Mdot
.46108 .73383 Mdot
.52191 .81916 Mdot
.35846 .7794 Mdot
.76896 .4503 Mdot
.45291 .47067 Mdot
.72858 .4982 Mdot
.54048 .83029 Mdot
.29004 .70346 Mdot
.6608 .30194 Mdot
.19731 .63056 Mdot
.23274 .44918 Mdot
.77678 .71646 Mdot
.72547 .37765 Mdot
.4573 .57669 Mdot
.23132 .68638 Mdot
.70977 .40503 Mdot
.22236 .4429 Mdot
.59735 .73383 Mdot
.62768 .49385 Mdot
.56512 .8251 Mdot
.57779 .61907 Mdot
.76327 .41239 Mdot
.56543 .7794 Mdot
.61842 .52074 Mdot
.29332 .7067 Mdot
.50365 .56772 Mdot
.40821 .33242 Mdot
.38274 .58852 Mdot
.16924 .44207 Mdot
.61104 .52071 Mdot
.19988 .60133 Mdot
.20642 .604 Mdot
.23393 .48091 Mdot
.33524 .31164 Mdot
.7785 .71429 Mdot
.64336 .75031 Mdot
.52748 .60435 Mdot
.70475 .45638 Mdot
.31805 .4677 Mdot
.21495 .4946 Mdot
.4813 .61373 Mdot
.35181 .66584 Mdot
.73755 .63213 Mdot
.43822 .83905 Mdot
.49656 .39065 Mdot
.58847 .36205 Mdot
.71834 .51817 Mdot
.66231 .30602 Mdot
.77569 .50562 Mdot
.77148 .38757 Mdot
.2167 .63061 Mdot
.57437 .49041 Mdot
.57358 .45202 Mdot
.7577 .41581 Mdot
.21729 .57917 Mdot
.42276 .40928 Mdot
.59746 .32324 Mdot
.71447 .58329 Mdot
.64838 .79345 Mdot
.73996 .40904 Mdot
.54647 .46601 Mdot
.64695 .42592 Mdot
.40591 .59383 Mdot
.49163 .32459 Mdot
.75067 .3801 Mdot
.66887 .44337 Mdot
.50087 .79113 Mdot
.60031 .49395 Mdot
.28308 .40972 Mdot
.20361 .49755 Mdot
.62493 .43235 Mdot
.20534 .61282 Mdot
.44548 .63809 Mdot
.53962 .80629 Mdot
.27227 .59269 Mdot
.35869 .42912 Mdot
.49887 .58216 Mdot
.66061 .55177 Mdot
.39088 .8173 Mdot
.72654 .42587 Mdot
.57777 .51945 Mdot
.69067 .43749 Mdot
.21516 .66722 Mdot
.30789 .40721 Mdot
.42339 .27414 Mdot
.34626 .4945 Mdot
.36159 .63737 Mdot
.3943 .55764 Mdot
.557 .29155 Mdot
.45851 .62331 Mdot
.41335 .42315 Mdot
.41014 .59475 Mdot
.71855 .5841 Mdot
.25502 .69381 Mdot
.65881 .80249 Mdot
.64897 .5404 Mdot
.19295 .63226 Mdot
.63636 .55055 Mdot
.62853 .5176 Mdot
.21187 .44494 Mdot
.57661 .52795 Mdot
.44403 .63032 Mdot
.3579 .42007 Mdot
.64606 .50096 Mdot
.65612 .80008 Mdot
.58364 .51053 Mdot
.34991 .45864 Mdot
.4686 .35012 Mdot
.52623 .45884 Mdot
.52041 .18164 Mdot
.57975 .26354 Mdot
.22133 .6794 Mdot
.20676 .57655 Mdot
.60675 .29005 Mdot
.67625 .43056 Mdot
.58136 .52946 Mdot
.53687 .80937 Mdot
.42011 .46801 Mdot
.45275 .82108 Mdot
.52713 .37429 Mdot
.73076 .59853 Mdot
.35438 .77536 Mdot
.27977 .66087 Mdot
.3173 .67944 Mdot
.76217 .61133 Mdot
.46012 .77648 Mdot
.4864 .48449 Mdot
.30036 .26156 Mdot
.19426 .35453 Mdot
.68595 .78928 Mdot
.79546 .39639 Mdot
.55467 .65329 Mdot
.24163 .59802 Mdot
.60364 .48223 Mdot
.31823 .56458 Mdot
.47116 .36601 Mdot
.27485 .41617 Mdot
.53854 .3835 Mdot
.74961 .3099 Mdot
.45161 .83912 Mdot
.49224 .58845 Mdot
.39398 .49408 Mdot
.38212 .40735 Mdot
.37848 .28206 Mdot
.61506 .60416 Mdot
.63945 .81457 Mdot
.59898 .31674 Mdot
.43448 .23494 Mdot
.57231 .28335 Mdot
.29002 .73423 Mdot
.38355 .24042 Mdot
.52879 .34276 Mdot
.26235 .74085 Mdot
.79138 .44006 Mdot
.78525 .62331 Mdot
.72535 .28844 Mdot
.3212 .75445 Mdot
.73754 .61918 Mdot
.28261 .42324 Mdot
.49218 .83273 Mdot
.2994 .55563 Mdot
.32089 .37244 Mdot
.473 .78132 Mdot
.19711 .55432 Mdot
.20437 .48717 Mdot
.61087 .35895 Mdot
.61989 .55439 Mdot
.29109 .2433 Mdot
.34283 .25927 Mdot
.85564 .46036 Mdot
.45784 .8143 Mdot
.67737 .75582 Mdot
.72906 .42902 Mdot
.48713 .36106 Mdot
.53092 .80958 Mdot
.21225 .61321 Mdot
.60225 .54021 Mdot
.31579 .25049 Mdot
.27368 .64134 Mdot
.24169 .57834 Mdot
.50774 .3533 Mdot
.39094 .81136 Mdot
.33703 .29413 Mdot
.56836 .66829 Mdot
.20013 .57284 Mdot
.65205 .55296 Mdot
.33258 .67901 Mdot
.64102 .79503 Mdot
.32561 .71029 Mdot
.1933 .50305 Mdot
.53271 .38141 Mdot
.43672 .3286 Mdot
.65621 .7952 Mdot
.76222 .51908 Mdot
.72996 .64551 Mdot
.82296 .67266 Mdot
.51636 .83644 Mdot
.58181 .53525 Mdot
.47137 .70557 Mdot
.2474 .71812 Mdot
.40176 .37154 Mdot
.26958 .70348 Mdot
.82932 .5048 Mdot
.20307 .4744 Mdot
.45351 .7257 Mdot
.45892 .67309 Mdot
.26895 .5174 Mdot
.76298 .44922 Mdot
.61502 .54735 Mdot
.3558 .27297 Mdot
.19678 .51634 Mdot
.7424 .59051 Mdot
.84585 .47246 Mdot
.8013 .60355 Mdot
.72103 .48313 Mdot
.47699 .83439 Mdot
.5823 .64757 Mdot
.75251 .56846 Mdot
.52835 .80354 Mdot
.41229 .49847 Mdot
.41533 .41886 Mdot
.76144 .55898 Mdot
.28598 .58212 Mdot
.1692 .43675 Mdot
.75903 .73419 Mdot
.70568 .59595 Mdot
.54329 .83558 Mdot
.34346 .79713 Mdot
.72461 .49145 Mdot
.60992 .57104 Mdot
.29415 .54618 Mdot
.59136 .49883 Mdot
.5854 .39695 Mdot
.34885 .26526 Mdot
.23278 .44256 Mdot
.2739 .29295 Mdot
.46996 .67686 Mdot
.51762 .36902 Mdot
.42787 .82885 Mdot
.25023 .4664 Mdot
.43918 .83008 Mdot
.75095 .60287 Mdot
.52497 .61054 Mdot
.85878 .63332 Mdot
.67366 .32038 Mdot
.42502 .64916 Mdot
.54308 .61157 Mdot
.5523 .63957 Mdot
.4693 .6926 Mdot
.58939 .38888 Mdot
.26338 .54311 Mdot
.1934 .47014 Mdot
.49251 .82957 Mdot
.70798 .52063 Mdot
.29812 .55268 Mdot
.59233 .34178 Mdot
.34092 .63626 Mdot
.49848 .76091 Mdot
.60108 .29731 Mdot
.18795 .45626 Mdot
.51747 .18258 Mdot
.44569 .39261 Mdot
.49403 .44162 Mdot
.34536 .60458 Mdot
.47266 .48346 Mdot
.20183 .45035 Mdot
.54407 .30261 Mdot
.39787 .41473 Mdot
.19495 .57055 Mdot
.76325 .62044 Mdot
.50638 .34838 Mdot
.25372 .27415 Mdot
.29444 .5651 Mdot
.5185 .37238 Mdot
.58761 .55945 Mdot
.80599 .5773 Mdot
.49663 .79882 Mdot
.42583 .39439 Mdot
.48228 .48082 Mdot
.74003 .67098 Mdot
.51624 .81469 Mdot
.55259 .31167 Mdot
.27646 .75625 Mdot
.58184 .55568 Mdot
.61829 .60357 Mdot
.64083 .77297 Mdot
.46585 .5356 Mdot
.60345 .72641 Mdot
.54734 .63461 Mdot
.38593 .55122 Mdot
.48926 .17654 Mdot
.47681 .54408 Mdot
.51708 .45539 Mdot
.57459 .48111 Mdot
.2452 .4816 Mdot
.54842 .75276 Mdot
.51659 .65799 Mdot
.29997 .42481 Mdot
.28336 .60054 Mdot
.25852 .44911 Mdot
.2547 .43818 Mdot
.51031 .34928 Mdot
.20053 .45225 Mdot
.20547 .48243 Mdot
.57584 .76897 Mdot
.54431 .81644 Mdot
.48228 .73793 Mdot
.45212 .81421 Mdot
.46821 .39692 Mdot
.6691 .39751 Mdot
.33031 .70879 Mdot
.75348 .73866 Mdot
.74341 .52156 Mdot
.54552 .71307 Mdot
.3248 .78076 Mdot
.41657 .82173 Mdot
.52105 .29035 Mdot
.68101 .29585 Mdot
.17926 .38233 Mdot
.28333 .54741 Mdot
.75642 .31485 Mdot
.37841 .25217 Mdot
.31688 .76871 Mdot
.41421 .59959 Mdot
.57946 .53771 Mdot
.77329 .58233 Mdot
.43605 .64221 Mdot
.3725 .3223 Mdot
.81368 .57824 Mdot
.76394 .6113 Mdot
.45714 .77526 Mdot
.5434 .6371 Mdot
.54345 .42134 Mdot
.64075 .51375 Mdot
.69221 .78417 Mdot
.40869 .27868 Mdot
.40261 .53055 Mdot
.84321 .48964 Mdot
.49838 .17702 Mdot
.22488 .43954 Mdot
.60801 .80131 Mdot
.56938 .26296 Mdot
.41309 .58724 Mdot
.61106 .21878 Mdot
.66884 .5341 Mdot
.70965 .45766 Mdot
.58356 .27546 Mdot
.23913 .54373 Mdot
.74515 .38561 Mdot
.79684 .70017 Mdot
.35653 .79636 Mdot
.44105 .64495 Mdot
.85592 .42079 Mdot
.20069 .57785 Mdot
.39661 .5128 Mdot
.73697 .37392 Mdot
.46269 .83189 Mdot
.54729 .38735 Mdot
.23443 .69591 Mdot
.61559 .44366 Mdot
.61288 .51263 Mdot
.2439 .56259 Mdot
.72279 .29299 Mdot
.45567 .52718 Mdot
.85181 .45411 Mdot
.69643 .30349 Mdot
.24775 .58665 Mdot
.70875 .424 Mdot
.65205 .53403 Mdot
.73378 .5352 Mdot
.61145 .42411 Mdot
.56793 .50499 Mdot
.54867 .46656 Mdot
.58061 .45243 Mdot
.42679 .40794 Mdot
.57779 .4223 Mdot
.66753 .32013 Mdot
.53888 .29427 Mdot
.78272 .59979 Mdot
.16969 .4083 Mdot
.25935 .4282 Mdot
.36648 .30049 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`2Kooooo`;o000000?oooooo`000?l000005?ooool2o`0009?o
oooo000Looooo`03o`000?oooooooooo09Kooooo1?l000001?oooooo0000o`000?ooool2o`0001Co
oooo1?l0002Aooooo`007?ooool00ol0003oooooooooo`2Fooooo`Co00002_ooool3o`0000kooooo
0ol0002Aooooo`007?ooool00ol0003oooooooooo`2@ooooo`;o00004_ooool3o`0000oooooo0_l0
002Aooooo`007?ooool00ol0003oooooooooo`2@ooooo`;o00005oooool2o`0000?ooooo0_l00009
ooooo`;o0000S_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol0
0006ooooo`03o`000?oooooooooo0:Wooooo0_l00003ooooo`;o00002Oooool3o`0008gooooo0000
1_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01_ooool00ol0003oooooooooo`2jooooo`?o0000S?ooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo08gooooo
0_l0000/ooooo`?o0000Roooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02ooo
ool00onHV9So8B4Qonk^kP06ooooo`?o0000SOooool2o`0002gooooo0ol0002:ooooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000
ooooooooool0_Oooool2o`0008[ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo
00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2hooooo`;o00001Oooool2o`00
08Sooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@
4006ooooo`03o`000?oooooooooo0;Sooooo0_l00005ooooo`;o0000R?ooool00006ooooooo^k^ko
<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000oooooooo
ool0_?ooool2o`0000?ooooo0_l00026ooooo`007?ooool00ol0003oooooooooo`2looooo`;o0000
0oooool2o`0008Kooooo000Looooo`03o`000?oooooooooo0<?ooooo0_l00024ooooo`007?ooool0
0ol0003oooooooooo`29ooooo`;o0000>?ooool2o`0008Cooooo000Looooo`03o`000?oooooooooo
08Wooooo0_l0002nooooo`007?ooool00ol0003oooooooooo`31ooooo`;o00000_ooool2o`0008;o
oooo000Looooo`03o`000?oooooooooo06Sooooo0_l00008ooooo`;o0000COooool3o`000004oooo
ool0003o0000o`00087ooooo000Looooo`03o`000?oooooooooo06?ooooo0ol00002ooooo`;o0000
1oooool3o`0001Gooooo0_l0000gooooo`;o00000_ooool2o`00087ooooo000Looooo`03o`000?oo
oooooooo06?ooooo0ol0000:ooooo`?o00001_ooool2o`0000kooooo0_l0000mooooo`;o0000Oooo
ool001cooooo00?o0000ooooooooool0L?ooool2o`0000Oooooo0_l00002ooooo`;o00002_ooool2
o`0003Wooooo0_l00002ooooo`;o0000Ooooool001cooooo00?o0000ooooooooool0Foooool2o`00
01Cooooo0_l00006ooooo`?o000000?oooooo`000?l000000_l000000ooooooo0000o`000005oooo
o`;o0000<?ooool2o`0000Oooooo0_l00023ooooo`007?ooool00ol0003oooooooooo`1Kooooo`;o
00004_ooool5o`0000Kooooo0_l00003ooooo`;o000000?oooooo`000?l000000oooool2o`0003;o
oooo0_l000000ooooooo0000o`000009ooooo`;o0000O_ooool001cooooo0_l0001Nooooo`;o0000
1?ooool2o`0000[ooooo1Ol00002ooooo`Co00002oooool4o`0002Sooooo0ol00006ooooo`?o0000
00?oooooo`000?l000002Oooool4o`0007cooooo000Looooo`03o`000?oooooooooo05gooooo0_l0
00001?oooooo0000o`000?ooool2o`0000_ooooo0ol00003ooooo`Co00002oooool3o`0002Wooooo
0ol00004ooooo`Ko00003Oooool2o`0007cooooo000Looooo`03o`000?oooooooooo057ooooo0_l0
000=ooooo`;o00001Oooool2o`0000Sooooo0_l00002ooooo`Ko00002oooool2o`0002Sooooo0_l0
0006ooooo`;o00000_ooool2o`0000;ooooo0_l00009ooooo`?o0000Noooool001cooooo00?o0000
ooooooooool0DOooool2o`0000[ooooo0ol00007ooooo`;o00000oooool2o`0000Gooooo2?l0000;
ooooo`;o00009?ooool2o`000004ooooool0003o0000o`0000gooooo1?l00009ooooo`;o000000?o
ooooo`000?l00000N?ooool001cooooo00?o0000ooooooooool0Foooool5o`0000Gooooo0_l00005
ooooo`;o00001?ooool7o`0003?ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00002
ooooo`;o00000_ooool7o`0000?ooooo0_l00004ooooo`Co0000N?ooool001cooooo00?o0000oooo
ooooool0Foooool2o`0000Sooooo0_l00007ooooo`;o00000_ooool<o`0000Kooooo0_l0000Yoooo
o`Wo000000?oooooo`000?l000000_ooool2o`0000;ooooo0ol00003ooooo`;o00000oooool3o`00
00;ooooo0_l0001fooooo`007?ooool00ol0003oooooooooo`1Iooooo`Co00004Oooool2o`0000?o
oooo2ol00006ooooo`?o0000;?ooool5o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l0
00000_l00004ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`00001fooooo`00
7?ooool00ol0003oooooooooo`1Iooooo`Co00004oooool2o`000003ooooool0003o000000co0000
0oooool3o`0002;ooooo1Ol0000<ooooo`;o00000_ooool2o`000003ooooool0003o000000;o0000
0oooool3o`0000?ooooo1?l0001gooooo`007?ooool00ol0003oooooooooo`1?ooooo`;o00001_oo
ool3o`00013ooooo1?l00002ooooo`;o00000_ooool=o`0000Gooooo0_l0000Qooooo`Go00002ooo
ool3o`0000;ooooo0_l000000ooooooo0000o`000003o`0000;ooooo0_l00003ooooo`Oo00002ooo
ool2o`0006Sooooo000Looooo`03o`000?oooooooooo04oooooo0_l00006ooooo`?o00004?ooool4
o`0000Kooooo0_l000001?oooooo0000o`000?l00002ooooo`co0000<Oooool3o`0000;ooooo2?l0
0007ooooo`;o000000?oooooo`000?l000000_l0000;ooooo`;o0000J?ooool001cooooo00?o0000
ooooooooool0Eoooool2o`0001Sooooo0_l000000ooooooo0000o`00000@o`0002gooooo0_l0000;
ooooo`Ko00003?ooool5o`0000Sooooo0_l0000Nooooo`?o0000Aoooool001cooooo00?o0000oooo
ooooool0E_ooool2o`0001Cooooo0_l00003oooooaCo00009Oooool2o`0000Kooooo0ol000000ooo
oooo0000o`000009ooooo`Go00003?ooool5o`0000Gooooo0_l0000Qooooo`?o0000Aoooool001co
oooo00?o0000ooooooooool0BOooool2o`0000_ooooo0_l0000Booooo`Co00001?oooolCo`0002Go
oooo0_l00006ooooo`;o000000Coooooo`000?l0003o00002Oooool6o`0000kooooo1Ol000001?oo
oooo0000o`000?l0000:ooooo`;o0000Goooool001cooooo00?o0000ooooooooool0BOooool2o`00
00_ooooo0_l00008ooooo`?o00001oooool3o`0000Kooooo4_l0000Pooooo`;o00000oooool2o`00
00Gooooo0_l00002ooooo`Go00001oooool3o`000003ooooool0003o000000kooooo1Ol000001?oo
oooo0000o`000?l00008ooooo`Ko0000GOooool001cooooo00?o0000ooooooooool0EOooool2o`00
00Cooooo0_l00003ooooo`?o00001?ooool2o`000003ooooool0003o000000?o00001?ooool7o`00
0003ooooool0003o000000;o000000?oooooo`000?l000001Ol0000Looooo`Co00001?ooool2o`00
00Cooooo0_l00002ooooo`So000000?oooooo`000?l000001?l000000ooooooo0000o`00000=oooo
o`Go00000oooool2o`0000Sooooo1_l0001Mooooo`007?ooool00ol0003oooooooooo`1Eooooo`?o
00000oooool2o`0000[ooooo0_l000000ooooooo0000o`000003o`0000Cooooo1ol000000ooooooo
0000o`00000:o`0001cooooo0_l00006ooooo`;o00001?ooool3o`000003ooooool0003o000000go
000000?oooooo`000?l000003Oooool2o`0000?ooooo0_l00007ooooo`Co000000?oooooo`000?l0
0000H?ooool001cooooo0_l0001Gooooo`;o00006_ooool8o`000003ooooool0003o000000Wo0000
6?ooool3o`0000Kooooo0_l00009ooooo`;o000000?oooooo`000?l000003Ol0000Eooooo`;o0000
1oooool4o`0006?ooooo000Looooo`03o`000?oooooooooo04Oooooo0_l0000Yoooooa3o000000?o
ooooo`000?l000000_l0000Gooooo`Go00001?ooool2o`0000Cooooo0_l00005oooooa3o00003ooo
ool2o`0000Cooooo0_l00003ooooo`;o00002?ooool2o`0005oooooo000Looooo`03o`000?oooooo
oooo04Oooooo0_l0000Qooooo`;o00001_oooolGo`0001Kooooo1?l0000:oooooaGo00004Oooool3
o`0000?ooooo0_l00003ooooo`;o00001oooool3o`0005oooooo000Looooo`03o`000?oooooooooo
06[ooooo0_l00002ooooo`?o000000?oooooo`000?l000005Ol0000Fooooo`?o00003?oooolEo`00
0004ooooool0003o0000o`0000cooooo0ol00008ooooo`;o00001oooool2o`0000Oooooo0_l0001G
ooooo`007?ooool00ol0003oooooooooo`1Yooooo`;o00000oooool3o`000003ooooool0003o0000
01Co00009_oooolEo`000004ooooool0003o0000o`0000cooooo0_l00007ooooo`;o00001Oooool2
o`0000_ooooo0_l000000ooooooo0000o`00001Dooooo`007?ooool00ol0003oooooooooo`1Yoooo
o`;o00000oooool2o`0000;ooooo2?l000000ooooooo0000o`000009o`0001Kooooo0_l00002oooo
o`;o00003?oooolCo`0000?ooooo0_l0000:ooooo`;o00002_ooool2o`0000Gooooo0_l00006oooo
o`;o000000?oooooo`000?l000000_ooool3o`0005Cooooo000Looooo`03o`000?oooooooooo06ko
oooo0_l00002oooooaGo00005Oooool2o`0000;ooooo0_l0000:ooooo`oo000000?oooooo`000?l0
00000ol00003ooooo`;o00002_ooool2o`0000?ooooo0_l000000ooooooo0000o`000005ooooo`;o
00002_ooool2o`000003ooooool0003o000000;ooooo1?l0000Booooo`;o0000?oooool001cooooo
00?o0000ooooooooool0Koooool2o`0000?ooooo5Ol0000Fooooo`;o00002ooooolDo`0000Cooooo
0_l0000:ooooo`;o00000oooool5o`0000;ooooo0_l000000ooooooo0000o`00000Cooooo`;o0000
4_ooool2o`0003oooooo000Looooo`03o`000?oooooooooo06oooooo0_l00003oooooaGo00004ooo
ool2o`000004ooooool0003o0000o`0000Wooooo5Ol00004ooooo`;o00003?ooool2o`0000?ooooo
0ol00002ooooo`;o00004oooool4o`0005Cooooo000Looooo`03o`000?oooooooooo043ooooo0_l0
000]ooooo`;o000000?oooooo`000?l000004ol00003ooooo`;o00004?ooool2o`0000;ooooo0_l0
00000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000005?l00004ooooo`;o00003?oo
ool2o`0001gooooo1?l000000ooooooo0000o`00000Aooooo`;o0000?_ooool001cooooo00?o0000
ooooooooool0@?ooool2o`00033ooooo5Ol00003ooooo`;o00003Oooool3o`0000Oooooo0_l00002
ooooo`;o000000?oooooo`000?l000005?l00004ooooo`;o00003?ooool3o`000003ooooool0003o
000000;o00006?ooool2o`0000;ooooo0_l0000Aooooo`;o0000?_ooool001cooooo00?o0000oooo
ooooool0L?oooolGo`00017ooooo1?l0000?oooooaCo00001Oooool2o`0000cooooo0ol000000ooo
oooo0000o`000002o`00033ooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`1`oooooaOo
00000oooool2o`0000Oooooo0_l00002ooooo`?o00000oooool2o`0000Gooooo0_l00005oooooaCo
00001Oooool2o`00037ooooo0_l0000Aooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0
LOoooolFo`0000?ooooo0_l00007ooooo`;o00000_ooool2o`0000;ooooo1?l00005ooooo`;o0000
1OoooolDo`0000cooooo0_l0000Zooooo`;o00004Oooool2o`0003gooooo000Looooo`03o`000?oo
oooooooo077ooooo5Ol00004ooooo`;o00002oooool2o`0000;ooooo1?l00005ooooo`;o00000_oo
oolDo`000003ooooool0003o000000cooooo0_l0000]ooooo`;o00003_ooool2o`0003gooooo000L
ooooo`03o`000?oooooooooo073ooooo5Ol0000Booooo`;o00000oooool2o`0000[ooooo5ol00003
ooooo`;o0000=_ooool2o`0000kooooo0_l0000mooooo`007?ooool2o`0006oooooo5ol00006oooo
o`;o00001oooool2o`0000_ooooo0ol00006oooooa?o00001Oooool2o`0004Kooooo0_l0000moooo
o`007?ooool00ol0003oooooooooo`1^ooooo`go000000?oooooo`000?l000001_l00007ooooo`Go
00001?ooool2o`0000_ooooo1?l00002ooooo`Go000000?oooooo`000?l000003?l00008ooooo`;o
0000AOooool3o`0003cooooo000Looooo`03o`000?oooooooooo03_ooooo0_l0000booooo`Go0000
0_ooool?o`0000Oooooo1?l00002ooooo`;o00003Oooool4o`0000;ooooo1Ol00002ooooo`co0000
2Oooool2o`0004Gooooo0ol0000looooo`007?ooool00ol0003oooooooooo`0kooooo`;o0000=?oo
oolDo`0000gooooo0ol00004ooooo`;o00003?ooool3o`000005ooooool0003o0000o`000?ooool0
3?l00008ooooo`;o0000A_ooool2o`0003cooooo000Looooo`03o`000?oooooooooo03[ooooo0_l0
000fooooo`oo00004_ooool2o`0000Cooooo0ol00003ooooo`;o00001oooool2o`000004ooooool0
003o0000o`0000;ooooo3Ol00006ooooo`;o0000A_ooool2o`0003cooooo000Looooo`03o`000?oo
oooooooo03[ooooo0_l0000gooooo`_o00005_ooool3o`0000?ooooo0_l00003ooooo`;o00001ooo
ool2o`0000?ooooo0_l000000ooooooo0000o`00000;o`0008cooooo000Looooo`03o`000?oooooo
oooo07?ooooo2_l0000Booooo`So00003Oooool2o`0000?ooooo0_l00002ooooo`Wo000000?ooooo
o`000?l000000_l0002>ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00009oooool2o`00
00;ooooo0_l0000<ooooo`?o000000Goooooo`000?l0003o0000ooooo`06o`0000kooooo1_l0000?
ooooo`?o00000_ooool2o`0000Cooooo0ol000001?oooooo0000o`000?l00003ooooo`;o0000;Ooo
ool2o`0000Cooooo0_l0000>ooooo`;o00003?ooool2o`0003_ooooo000Looooo`03o`000?oooooo
oooo03Sooooo0_l0000Wooooo`;o00000_ooool3o`0000;ooooo0_l00006ooooo`?o00000_ooool:
o`0000kooooo1Ol00008ooooo`;o00001Oooool7o`0000;ooooo0_l0000Cooooo`;o00009Oooool2
o`0000;ooooo1?l00004ooooo`;o00002?ooool3o`0000_ooooo0_l0000kooooo`007?ooool00ol0
003oooooooooo`0gooooo`;o00009_ooool2o`0000Cooooo1?l000000ooooooo0000o`000006oooo
o`Co00000_ooool4o`00017ooooo1ol00008ooooo`;o00001?ooool3o`0000;ooooo0ol00002oooo
o`?o00004_ooool3o`00023ooooo0_l00002ooooo`Wo00000oooool3o`0000Sooooo0_l00018oooo
o`007?ooool00ol0003oooooooooo`0gooooo`;o00009_ooool3o`0000?ooooo1?l00003ooooo`;o
00001_ooool2o`0000;ooooo0_l0000Cooooo`Co00004Oooool2o`0000Cooooo0ol000001?oooooo
0000o`000?l0000Booooo`?o00008?ooool2o`0000;ooooo1_l000000ooooooo0000o`000002o`00
00;ooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`0gooooo`;o00009oooool2o`0000Co
oooo0_l00004ooooo`;o00001_ooool2o`0001Gooooo0_l000000ooooooo0000o`00000Iooooo`Go
00004_ooool3o`0002;ooooo0_l00009ooooo`?o000000?oooooo`000?l000000_ooool2o`0004oo
oooo000Looooo`03o`000?oooooooooo03Oooooo0_l0000kooooo`;o000000?oooooo`000?l00000
4_ooool2o`000003ooooool0003o000001_ooooo0_l000001?oooooo0000o`000?ooool2o`0000[o
oooo0_l000001?oooooo0000o`000?l00003ooooo`;o00007Oooool2o`0000Oooooo0_l00002oooo
o`Co000000Coooooo`000?l0003o00004oooool2o`0003[ooooo000Looooo`03o`000?oooooooooo
06[ooooo1?l00007ooooo`Co00003oooool2o`000003ooooool0003o0000017ooooo0_l0000<oooo
o`Co000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000?o000000?oooooo`00
0?l000000oooool3o`0002Kooooo0_l00002ooooo`;o00000oooool3o`0001?ooooo0_l0000joooo
o`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooo
oooo00Cooooo00?o0000ooooooooool0J_ooool5o`0000Kooooo0_l0000Aooooo`Oo00003oooool2
o`0000cooooo0_l000000ooooooo0000o`000003o`0000?ooooo1ol000000ooooooo0000o`000002
o`000004ooooool0003o0000o`0001Kooooo0_l000000ooooooo0000o`00000@ooooo`Go00001ooo
ool2o`0000gooooo0_l0000jooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q
1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06_ooooo1?l00006ooooo`;o0000
0oooool2o`0000Oooooo1_l000000ooooooo0000o`000003o`0000Gooooo0_l0000Fooooo`;o0000
00?oooooo`000?l000000ol000000ooooooo0000o`000005o`0000;ooooo1Ol000000ooooooo0000
o`00000Gooooo`;o000000?oooooo`000?l000004Oooool5o`000003ooooool0003o000000?ooooo
0ol00018ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`Go00001_oo
ool00ol0003oooooooooo`0dooooo`;o0000:Oooool2o`0000?ooooo0_l00007ooooo`;o00001?oo
ool6o`000003ooooool0003o000000?ooooo0ol000000ooooooo0000o`000004o`0000?ooooo0_l0
0002ooooo`;o00000_ooool2o`0000[ooooo0_l0000Cooooo`;o00000oooool2o`0000;ooooo0_l0
000Booooo`?o000000?oooooo`000?l000007?ooool4o`000003ooooool0003o000000Cooooo0_l0
0018ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04odA4A?oMgMgo
ooooo`0000Oooooo0ol0000dooooo`;o0000:Oooool2o`0000?ooooo0_l00006ooooo`?o00001?oo
ool2o`0000;ooooo0ol00002ooooo`;o000000Coooooo`000?l0003o00000oooool3o`0000Sooooo
0_l00008ooooo`;o00001?ooool2o`00033ooooo0ol000000ooooooo0000o`00000:ooooo`;o0000
5Oooool2o`0001Cooooo0_l0000hooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooooooo
o`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0<oooool2o`0002_ooooo
0_l00002ooooo`;o000000Coooooo`000?l0003ooooo1Ol00008ooooo`?o00000_ooool3o`000003
ooooool0003o000000?ooooo0_l00006ooooo`;o00002oooool2o`0001Wooooo0_l00005ooooo`?o
00008oooool3o`0001Cooooo0_l0000Dooooo`;o0000>?ooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool02_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo03;ooooo
0ol0000Sooooo`Co00001?ooool2o`0000;ooooo1Ol000000ooooooo0000o`000005o`0000Oooooo
1?l000000ooooooo0000o`000003o`0000?ooooo1?l00004ooooo`;o00009_ooool4o`0000?ooooo
0ol0000Rooooo`Co00002?ooool4o`0000Cooooo0ol000000ooooooo0000o`00001>ooooo`0000Ko
ooooogMgMonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000oooooooo
ool0<_ooool3o`0002;ooooo1Ol00004ooooo`;o000000Coooooo`000?l0003ooooo2ol00007oooo
o`Co00000oooool3o`0000Cooooo0ol0000^ooooo`;o0000:?ooool2o`0000[ooooo1Ol00002oooo
o`Co000000?oooooo`000?l00000C_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool0
0omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo057ooooo0_l00004ooooo`?o00000_ooool4
o`0000;ooooo3_l00008ooooo`Co00000_ooool2o`0005Cooooo0_l0000Iooooo`?o00000_ooool3
o`0001[ooooo0_l0000fooooo`007?ooool00ol0003oooooooooo`1Aooooo`?o00000_ooool2o`00
0004ooooool0003o0000ooooo`Co000000?oooooo`000?l000003_l00003ooooo`?o00001_ooool3
o`0005Cooooo0_l0000Eooooo`Wo00000_ooool2o`0001Oooooo1?l0000fooooo`007?ooool00ol0
003oooooooooo`1Booooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o00000ooooolB
o`000004ooooool0003o0000o`0000Kooooo0_l00004ooooo`;o00002_ooool2o`0001cooooo0_l0
000looooo`Co000000?oooooo`000?l000000_l00002ooooo`;o00000_ooool2o`0001?ooooo0_l0
00000ooooooo0000o`00000eooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00000oooool2
o`0000?ooooo0ol00002oooooa7o00000_ooool2o`0000cooooo0_l0000:ooooo`;o00007?ooool2
o`0000Wooooo0_l00004ooooo`;o00000oooool2o`0001gooooo0_l00008ooooo`?o00000_ooool3
o`0000;ooooo0_l00002ooooo`;o00000_ooool4o`00013ooooo0_l0000eooooo`007?ooool00ol0
003oooooooooo`1Cooooo`;o00000oooool3o`0000;ooooo5Ol00003ooooo`Co00002_ooool2o`00
0003ooooool0003o0000033ooooo0_l00004ooooo`;o00000oooool2o`0000Wooooo0_l0000Boooo
o`;o00001?ooool2o`0000;ooooo1Ol000001?oooooo0000o`000?l00005ooooo`;o00000_ooool4
o`0004Oooooo000Looooo`03o`000?oooooooooo057ooooo0_l00006ooooo`;o000000?oooooo`00
0?l000004Ol000001?oooooo0000o`000?l00004ooooo`;o00003Oooool2o`0000Oooooo0_l0000Y
ooooo`;o00004_ooool2o`0000Sooooo0ol00003ooooo`;o00000oooool2o`0000?ooooo0ol00002
ooooo`Co000000Coooooo`000?l0003o00001Oooool3o`0004cooooo000Looooo`03o`000?oooooo
oooo033ooooo0ol0000Nooooo`;o00002Oooool2o`000003ooooool0003o000000oo000000?ooooo
o`000?l000000oooool2o`0001Oooooo0_l0000@ooooo`;o00005oooool2o`0000_ooooo0_l0000=
ooooo`[o00000oooool2o`0000Cooooo0_l00004ooooo`Co00001oooool3o`0004cooooo000Loooo
o`03o`000?oooooooooo033ooooo1Ol0000Dooooo`;o00000oooool2o`0000Oooooo0_l00003oooo
o`;o000000?oooooo`000?l000003ol00006ooooo`;o00005?ooool2o`0000Wooooo0_l00008oooo
o`;o00005oooool2o`0000_ooooo0_l00008ooooo`;o00000oooool2o`0000?ooooo1?l0000:oooo
o`;o00001?ooool4o`0005Kooooo000Looooo`03o`000?oooooooooo03?ooooo0_l0000@ooooo`;o
00000_ooool2o`0000?ooooo0ol00006ooooo`;o00000ooooolDo`0000[ooooo0_l0000@ooooo`;o
00002Oooool2o`0003Sooooo0_l000000ooooooo0000o`000003o`000004ooooool0003o0000oooo
o`;o00007_ooool2o`0001?ooooo0_l0000eooooo`007?ooool00ol0003oooooooooo`0cooooo`;o
00004?ooool2o`000003ooooool0003o000000Gooooo0_l00006ooooo`Co000000?oooooo`000?l0
00004_l0000:ooooo`;o00006?ooool2o`0000;ooooo1ol0000Rooooo`;o00001oooool2o`0000So
oooo1Ol000001?oooooo0000o`000?ooool5o`0000_ooooo0_l0000<ooooo`Co00004oooool3o`00
03Cooooo000Looooo`03o`000?oooooooooo02oooooo0_l00002ooooo`;o000000?oooooo`000?l0
00002Oooool2o`000005ooooool0003o0000o`000?ooool00_l0000=ooooo`Co00000ooooolBo`00
02Cooooo0_l000000ooooooo0000o`000006o`0000Sooooo0_l0000>ooooo`;o00002?ooool2o`00
0003ooooool0003o000000Cooooo0_l00004ooooo`;o00000oooool?o`0000Wooooo0_l00005oooo
o`;o00001?ooool3o`0000;ooooo0_l0000Booooo`;o0000=?ooool001cooooo00?o0000oooooooo
ool0;oooool2o`0000?ooooo1?l00008ooooo`?o000000?oooooo`000?l000000_ooool2o`0000Co
oooo1?l00007ooooo`Co000000?oooooo`000?l000004?l0000Wooooo`;o00000oooool2o`0000Ko
oooo0_l000000ooooooo0000o`00000>ooooo`;o00001oooool2o`0000;ooooo0ol00005ooooo`;o
00000_ooool2o`0000Gooooo2Ol000000ooooooo0000o`000003o`0000Gooooo0_l00007ooooo`;o
00000_ooool4o`0000?ooooo0_l0000Aooooo`;o0000=Oooool001cooooo0_l0000`ooooo`;o0000
0oooool2o`0000Oooooo1Ol00002ooooo`;o00000_ooool2o`0000Cooooo1?l000000ooooooo0000
o`000004oooooaKo0000;Oooool2o`0000Kooooo0_l0000Aooooo`Go00001?ooool2o`0000;ooooo
0ol00005ooooo`?o00000_ooool2o`0000Cooooo1Ol000001?oooooo0000o`000?l00002ooooo`Ko
00000oooool2o`0000Oooooo2?l00002ooooo`;o00004_ooool2o`0003Gooooo000Looooo`03o`00
0?oooooooooo02oooooo0_l00002ooooo`;o00002?ooool3o`0000Cooooo0_l0000=ooooo`;o0000
2?oooolAo`0003Kooooo0_l0000@ooooo`Ko00002?ooool2o`0000Oooooo4ol00004ooooo`Co0000
3?ooool4o`0000;ooooo0_l00002ooooo`?o00004?ooool2o`0003Kooooo000Looooo`03o`000?oo
oooooooo02oooooo0_l00002ooooo`;o00001?ooool2o`00023ooooo0_l000000ooooooo0000o`00
000@o`0001[ooooo1?l0000Fooooo`;o00000_ooool2o`0000cooooo0_l0000Booooo`;o00000_oo
ool3o`0000;ooooo4_l000001?oooooo0000o`000?l0000Aooooo`;o00000oooool2o`00013ooooo
0ol0000eooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00002oooool2o`0000[ooooo0ol0
0006oooooaGo00006Oooool5o`000003ooooool0003o000000;o00005?ooool5o`0000[ooooo1?l0
000@ooooo`;o00000_ooool2o`000004ooooool0003o0000oooooa7o000000?oooooo`000?l00000
0_l0000:ooooo`Co00000_ooool2o`0001Kooooo0_l0000eooooo`007?ooool00ol0003ooooooooo
o`11ooooo`;o00000_ooool3o`0000Cooooo0_l00004ooooo`?o00001ooooolBo`0001[ooooo3Ol0
000Booooo`;o000000?oooooo`000?l000003?ooool2o`0000Cooooo0_l000000ooooooo0000o`00
000>oooooaCo000000?oooooo`000?l000000_l0000:ooooo`Co00001?ooool2o`0001Cooooo0_l0
000eooooo`007?ooool00ol0003oooooooooo`0_ooooo`?o00003oooool2o`0000;ooooo0_l00005
ooooo`Co00003?ooool@o`0001;ooooo0_l00002ooooo`Go000000?oooooo`000?l000000_l00000
0ooooooo0000o`000002ooooo`So00002Oooool2o`0000[ooooo0_l0000>ooooo`;o000000?ooooo
o`000?l000003ooooolCo`000003ooooool0003o000000;o00004_ooool2o`0004_ooooo000Loooo
o`03o`000?oooooooooo02oooooo1?l00008ooooo`;o00001_ooool2o`0000Wooooo0_l00002oooo
o`;o00002_ooool>o`0001;ooooo0_l00002ooooo`Ko000000?oooooo`000?l000000_l00002oooo
o`_o00002?ooool2o`0000[ooooo0_l0000Poooooa_o000000?oooooo`000?l000001_ooool2o`00
05?ooooo000Looooo`03o`000?oooooooooo037ooooo0_l00002ooooo`;o00001?ooool2o`0000Ko
oooo0_l0000=ooooo`;o00002?ooool8o`000003ooooool0003o000000Go00004Oooool4o`0000;o
oooo0_l000001?oooooo0000o`000?ooool4o`0000;ooooo2ol0000Cooooo`;o00008OoooolGo`00
00;ooooo0_l000000ooooooo0000o`000006ooooo`;o00006Oooool2o`0003Sooooo000Looooo`03
o`000?oooooooooo03Gooooo0_l00005ooooo`Co00000_ooool2o`0000[ooooo0_l0000<ooooo`;o
000000?oooooo`000?l000000_l00003ooooo`;o00003?ooool2o`0000Oooooo1?l000000ooooooo
0000o`00000?ooooo`Wo00004Oooool2o`0000_ooooo0_l0000:ooooo`;o00001oooool3o`000003
ooooool0003o000001?o00001Oooool2o`0000Gooooo0ol00005ooooo`;o00004Oooool3o`0003Oo
oooo000Looooo`03o`000?oooooooooo03Gooooo0ol00004ooooo`Co00000_ooool2o`0000[ooooo
0_l0000Aooooo`;o00000oooool2o`0000;ooooo0_l00006ooooo`Co00001Oooool5o`0000;ooooo
0_l0000?ooooo`[o00002Oooool2o`0000;ooooo0_l0000>ooooo`;o00002_ooool2o`0000Gooooo
7ol000000ooooooo0000o`000004ooooo`Co00001Oooool2o`00013ooooo1?l0000gooooo`007?oo
ool00ol0003oooooooooo`0dooooo`Co00001Oooool4o`0000Oooooo0_l00002ooooo`Co00004Ooo
ool3o`0000;ooooo1_l00006ooooo`?o00000_ooool2o`0000;ooooo1Ol0000Dooooo`_o00001ooo
ool2o`0000;ooooo0_l0000;ooooo`;o00001oooool2o`0000Sooooo0_l000000ooooooo0000o`00
0002o`000003ooooool0003o000000_o000000?oooooo`000?l000002_l00007ooooo`?o00006?oo
ool2o`0003Wooooo000Looooo`03o`000?oooooooooo03Cooooo0_l00009ooooo`;o00001oooool2
o`0000;ooooo0ol0000Booooo`?o00001?ooool2o`000003ooooool0003o000000[ooooo0_l00000
0ooooooo0000o`000002o`0001Sooooo2_l0000Gooooo`;o00001oooool2o`0000Sooooo1ol00000
0ooooooo0000o`00000Ho`0005gooooo000Looooo`03o`000?oooooooooo03?ooooo1_l00006oooo
o`;o00008?ooool2o`0000Sooooo0_l00007ooooo`;o000000Coooooo`000?l0003ooooo0_l0000J
ooooo`[o0000:?ooool3o`000003ooooool0003o000000;o00000_oooolFo`000004ooooool0003o
0000o`0000[ooooo0_l00003ooooo`;o00004Oooool2o`0003Wooooo000Looooo`03o`000?oooooo
oooo03?ooooo1_l00006ooooo`;o00004Oooool2o`0000gooooo0_l00002ooooo`?o000000?ooooo
o`000?l000000_ooool2o`0000;ooooo1Ol000000ooooooo0000o`00000Oooooo`Wo00005_ooool2
o`0000oooooo0ol00002ooooo`?o00000_oooolJo`000003ooooool0003o000000Cooooo0_l00000
0ooooooo0000o`000003ooooo`;o00004Oooool2o`0003Wooooo000Looooo`03o`000?oooooooooo
03Gooooo0_l0000:ooooo`?o00003_ooool4o`0000gooooo2?l00002ooooo`;o00000_ooool3o`00
00Sooooo0_l0000Iooooo`[o00004_ooool6o`0000Kooooo0_l00007ooooo`?o00000_ooool3o`00
00;ooooo6Ol00002ooooo`;o00001?ooool2o`0000;ooooo0_l0000Cooooo`Co0000>Oooool001co
oooo00?o0000ooooooooool0=Oooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo
0000o`000003o`0000kooooo0_l0000=ooooo`;o00000_ooool2o`0000Cooooo0_l00009ooooo`;o
00000_ooool4o`0000;ooooo0_l0000:ooooo`Go00001?ooool;o`00017ooooo1?l00004ooooo`?o
000000Coooooo`000?l0003ooooo0_l00004ooooo`?o000000?oooooo`000?l000007Ol000001?oo
oooo0000o`000?l00003ooooo`;o00000oooool2o`0001;ooooo0ol0000kooooo`007?ooool2o`00
03Wooooo0_l00004ooooo`;o00001?ooool2o`0000kooooo0ol0000Qooooo`;o00001?ooool2o`00
00;ooooo0_l00009ooooo`Ko00001?ooool;o`0001;ooooo0ol00004ooooo`?o00001?ooool2o`00
00;ooooo0_l000000ooooooo0000o`00000Po`000004ooooool0003o0000o`0000?ooooo0_l0000F
ooooo`?o0000??ooool001cooooo00?o0000ooooooooool0>oooool2o`0000Kooooo0_l0000@oooo
o`;o00007oooool3o`0001?ooooo1?l00003ooooo`;o00000oooool:o`0000kooooo0_l00002oooo
o`Co00003OoooolTo`0000Cooooo0_l0000Jooooo`Co0000??ooool001cooooo00?o0000oooooooo
ool0>_ooool3o`0000Kooooo0_l0000aooooo`?o00004Oooool6o`0000?ooooo0_l00003ooooo`co
00003?ooool2o`0000?ooooo0ol0000=ooooo`Ko00000_oooolLo`0000Cooooo0_l00009ooooo`;o
00003oooool4o`0003cooooo000Looooo`03o`000?oooooooooo03[ooooo0ol00002ooooo`;o0000
0_ooool2o`00017ooooo0_l0000booooo`Co00001?ooool4o`0000?ooooo2ol0000?ooooo`;o0000
1Oooool2o`0000Kooooo0_l00006ooooo`;o00000_oooolKo`0000?ooooo0_l00002ooooo`;o0000
1_ooool2o`0000kooooo1?l0000mooooo`007?ooool00ol0003oooooooooo`0jooooo`?o00000_oo
ool2o`00013ooooo0_l00003ooooo`;o00009Oooool2o`0000[ooooo1?l00004ooooo`Ko00000_oo
ool<o`0000kooooo0_l00005ooooo`Co00001?ooool5o`0000?ooooo7ol00002ooooo`?o00000_oo
ool2o`0001Gooooo1Ol0000mooooo`007?ooool00ol0003oooooooooo`0looooo`;o00001?ooool2
o`0000gooooo0_l0000Zooooo`;o00002Oooool4o`0000Gooooo0_l000001?oooooo0000o`000?l0
0002ooooo`co00003oooool2o`0000Cooooo1?l00005ooooo`Co00001Oooool3o`0000Cooooo5Ol0
0003ooooo`;o00006_ooool3o`0003oooooo000Looooo`03o`000?oooooooooo03cooooo0_l00004
ooooo`;o00003Oooool2o`000003ooooool0003o000003;ooooo0ol00009ooooo`Co000000?ooooo
o`000?l000002_l0000?ooooo`;o00000_ooool4o`0000Oooooo0_l00003ooooo`;o00000oooool3
o`0000?ooooo4?l00003ooooo`Co00002_ooool2o`0000oooooo1?l00010ooooo`007?ooool00ol0
003oooooooooo`0jooooo`Co00000oooool3o`0000oooooo0ol0000aooooo`Co00001?ooool2o`00
00;ooooo0_l000001?oooooo0000o`000?ooool<o`0000oooooo0_l00002ooooo`;o00002Oooool4
o`000003ooooool0003o000000Cooooo0_l00002oooooa;o00000_ooool4o`000003ooooool0003o
000000?o00001?ooool2o`0000kooooo1?l00011ooooo`007?ooool00ol0003oooooooooo`0joooo
o`?o00001?ooool3o`0000gooooo1?l00002ooooo`;o0000;_ooool4o`0000Cooooo0_l00002oooo
o`;o000000?oooooo`000?l000000_ooool7o`000004ooooool0003o0000o`00013ooooo0_l0000<
ooooo`Co00002oooool=o`0000?ooooo0_l00007ooooo`Ko00004_ooool5o`00047ooooo000Loooo
o`03o`000?oooooooooo03[ooooo0_l00006ooooo`;o00003Oooool5o`000003ooooool0003o0000
02kooooo0_l00003ooooo`;o00000_ooool2o`0000Sooooo2ol0000@ooooo`;o000000Coooooo`00
0?l0003o00001Oooool2o`000003ooooool0003o000000gooooo1?l000000ooooooo0000o`000007
o`000005ooooool0003o0000o`000?ooool00_l000000ooooooo0000o`000003o`0000;ooooo0ol0
000@ooooo`Go0000@_ooool001cooooo00?o0000ooooooooool0DOooool5o`0000?ooooo0_l0000T
ooooo`;o00001_ooool2o`0000?ooooo0_l00002ooooo`;o00002Oooool:o`0001?ooooo0ol00005
ooooo`;o00003_ooool2o`0000Kooooo3?l000000ooooooo0000o`000004o`0000Gooooo0_l0000>
ooooo`Co0000AOooool001cooooo00?o0000ooooooooool0>oooool5o`00017ooooo0ol000000ooo
oooo0000o`000002ooooo`;o00009?ooool2o`0000Cooooo1?l0000;ooooo`Co00000oooool=o`00
017ooooo0_l00008ooooo`?o00002_ooool7o`000003ooooool0003o000000Oo000000Coooooo`00
0?l0003o00000_ooool2o`0000;ooooo0_l0000Booooo`Go0000AOooool001cooooo00?o0000oooo
ooooool0>_ooool6o`00017ooooo0_l000000ooooooo0000o`000002o`0002Oooooo0_l00004oooo
o`;o00001?ooool2o`000003ooooool0003o000000Cooooo1?l00003ooooo`go00004?ooool3o`00
00Sooooo0ol0000:ooooo`So00000_ooool7o`000004ooooool0003o0000o`0000Cooooo1?l0000B
ooooo`Go0000AOooool001cooooo00?o0000ooooooooool0>Oooool3o`0000;ooooo0_l00009oooo
o`;o00001_ooool2o`000003ooooool0003o000000;o0000;Oooool3o`0000?ooooo0_l000000ooo
oooo0000o`00000;ooooo`So000000?oooooo`000?l000004_ooool2o`0000Kooooo0_l000000ooo
oooo0000o`000009ooooo`Go00000oooool2o`0000kooooo0_l000001?oooooo0000o`000?l0000B
ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0>Oooool2o`0000?ooooo0_l00009oooo
o`?o00001Oooool3o`0000;ooooo0ol0000[ooooo`Co00003oooool2o`0000?ooooo1ol000001?oo
oooo0000o`000?l0000Dooooo`;o00000oooool5o`0000Wooooo0ol00002ooooo`;o00004Oooool2
o`0001Kooooo0_l00019ooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00003oooool2o`00
00Gooooo0ol00003ooooo`?o00000_ooool2o`0000;ooooo0_l0000Rooooo`?o00002oooool2o`00
00?ooooo0_l00003ooooo`_o00005?ooool2o`0000Gooooo1?l00009ooooo`;o00000_ooool2o`00
00_ooooo0_l0000Hooooo`?o0000C?ooool001cooooo0_l0000jooooo`;o00005Oooool3o`0000Go
oooo0_l00002ooooo`;o00000_ooool2o`00027ooooo0ol00002ooooo`;o00002?ooool2o`0000Co
oooo0_l00003ooooo`_o00005?ooool2o`0000Kooooo0_l00005ooooo`;o00001_ooool2o`0000_o
oooo0_l0000Hooooo`?o0000C?ooool001cooooo00?o0000ooooooooool0>Oooool2o`0001Gooooo
0ol00004ooooo`;o00001?ooool3o`0001Wooooo0ol00002ooooo`;o00000oooool3o`000004oooo
ool0003o0000o`0000kooooo0_l00003ooooo`_o00005?ooool2o`0000Cooooo0_l00006ooooo`?o
00000oooool2o`000003ooooool0003o000000Sooooo1Ol0000Fooooo`Go0000C?ooool001cooooo
00?o0000ooooooooool0>oooool3o`0000Sooooo0_l00009ooooo`;o00001?ooool2o`0000Cooooo
0ol0000Iooooo`?o00000_ooool2o`0000;ooooo1?l000000ooooooo0000o`00000<ooooo`;o0000
2?ooool9o`00017ooooo0_l00006ooooo`?o00000_ooool2o`0000;ooooo0_l00004ooooo`;o0000
00?oooooo`000?l000002?ooool5o`0001?ooooo1ol0001=ooooo`007?ooool00ol0003ooooooooo
o`0kooooo`Co00001oooool2o`0000Wooooo0_l00004ooooo`;o00001Oooool2o`0000Oooooo0_l0
000@ooooo`;o000000?oooooo`000?l000001?ooool4o`0000oooooo0_l00004ooooo`;o00000ooo
ool8o`00017ooooo1?l00004ooooo`Co000000Coooooo`000?l0003ooooo0ol0000Xooooo`Go0000
D?ooool001cooooo00?o0000ooooooooool0>_ooool2o`000003ooooool0003o000000gooooo0ol0
00001?oooooo0000o`000?l00005ooooo`;o000000?oooooo`000?l000002_ooool2o`00013ooooo
0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000001_ooool4o`0000[ooooo
0_l00003ooooo`So00004oooool2o`0000Kooooo1Ol000000ooooooo0000o`00000Uooooo`;o0000
0_ooool6o`0004oooooo000Looooo`03o`000?oooooooooo03[ooooo0_l00008ooooo`;o00001_oo
ool3o`000004ooooool0003o0000o`0000Gooooo0_l000001?oooooo0000o`000?l00004ooooo`Co
00000_ooool4o`0001Gooooo0ol000000ooooooo0000o`000002ooooo`;o00000_ooool4o`0000?o
oooo0_l00003ooooo`Co00001?ooool8o`0001?ooooo0_l00003ooooo`;o000000?oooooo`000?l0
00000_l00004ooooo`?o00008Oooool2o`0000;ooooo1_l0001?ooooo`007?ooool00ol0003ooooo
ooooo`14ooooo`;o00002oooool2o`0000Sooooo0ol00004ooooo`Co00000_ooool4o`0001Gooooo
0_l00002ooooo`;o00000_ooool2o`0000Wooooo0_l00003oooooa3o00004oooool2o`0000?ooooo
0_l00009ooooo`?o00007_ooool2o`0000;ooooo0_l00003ooooo`;o00003oooool2o`00043ooooo
000Looooo`03o`000?oooooooooo03cooooo0_l00002ooooo`;o00003oooool2o`0000Sooooo1?l0
000<ooooo`;o00005?ooool2o`0001;ooooo0_l00003ooooo`oo00006Oooool4o`0002Oooooo0ol0
00000ooooooo0000o`000003ooooo`;o00001Oooool2o`0000Sooooo0_l00010ooooo`007?ooool0
0ol0003oooooooooo`0jooooo`Go000000?oooooo`000?l000005Oooool2o`0000Cooooo0_l00000
1?oooooo0000o`000?ooool2o`0000Kooooo0_l0000=ooooo`;o00001?ooool2o`0001?ooooo0_l0
0004ooooo`Ko000000?oooooo`000?l000001_l0000Hooooo`Co00008oooool2o`0000?ooooo0_l0
0006ooooo`?o00001?ooool2o`0004[ooooo000Looooo`03o`000?oooooooooo03[ooooo2?l00009
ooooo`;o00001Oooool2o`0000?ooooo0ol00006ooooo`;o000000?oooooo`000?l000003_ooool2
o`0000?ooooo1?l00003ooooo`Co000000?oooooo`000?l000002oooool2o`0000Sooooo1ol00002
ooooo`Ko00005oooool5o`0000;ooooo0ol0000Looooo`Co00003?ooool2o`0000Oooooo1ol00012
ooooo`007?ooool00ol0003oooooooooo`0mooooo`Go000000?oooooo`000?l000001Oooool3o`00
00Gooooo0_l00004ooooo`;o00001Oooool8o`0000Wooooo0_l000000ooooooo0000o`000003oooo
o`?o00001?ooool4o`000003ooooool0003o000000_ooooo0_l00008ooooo`Oo00000_ooool4o`00
01Kooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000;o00006_ooool5
o`00017ooooo0_l00003ooooo`Oo0000@_ooool001cooooo00?o0000ooooooooool0@oooool4o`00
0003ooooool0003o000000;o00001Oooool3o`0000?ooooo1?l00004ooooo`So000000?oooooo`00
0?l000000_l00002ooooo`Co00003Oooool4o`0001Sooooo2?l000000ooooooo0000o`000004o`00
01Cooooo0_l00007ooooo`;o00006_ooool5o`0000oooooo0_l00002ooooo`;o00002_ooool2o`00
043ooooo000Looooo`03o`000?oooooooooo03_ooooo0_l000000ooooooo0000o`000005ooooo`;o
000000?oooooo`000?l000000oooool2o`000003ooooool0003o000000;o00000oooool4o`0000go
oooo1?l00002ooooo`Co00003Oooool5o`0001?ooooo1?l00002ooooo`Oo00000_ooool4o`00013o
oooo0_l00008ooooo`;o00006oooool7o`0000oooooo0_l0000>ooooo`;o0000@?ooool001cooooo
00?o0000ooooooooool0>oooool2o`000003ooooool0003o000000Sooooo0_l00003ooooo`;o0000
00?oooooo`000?l000000_l00005ooooo`Go00004?ooool4o`0000Oooooo0_l00004ooooo`;o0000
00?oooooo`000?l000003_ooool2o`0000?ooooo1?l000000ooooooo0000o`000002o`0000;ooooo
0_l00002ooooo`Co00004?ooool2o`0000Sooooo0_l0000Jooooo`Co00002Oooool2o`0005[ooooo
00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@
4?o<c<`01_ooool00ol0003oooooooooo`0kooooo`;o00002oooool4o`0000Gooooo0ol000000ooo
oooo0000o`000004ooooo`?o00003_ooool4o`0000Wooooo0_l00002ooooo`;o000000?oooooo`00
0?l000004?ooool2o`0000Gooooo2_l000000ooooooo0000o`000003o`0001Kooooo0_l0000Noooo
o`?o00002_ooool3o`000003ooooool0003o000000[ooooo0_l0001;ooooo`0000KoooooogMgMonH
V9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o
0000ooooooooool0B?ooool4o`0000Cooooo0ol00002ooooo`;o00000oooool2o`0000Oooooo1_l0
0003ooooo`;o00002?ooool2o`0000Cooooo0ol000001?oooooo0000o`000?l0000Eooooo`_o0000
00Coooooo`000?l0003ooooo1?l0000Dooooo`?o00007?ooool5o`0000Wooooo0_l00002ooooo`;o
00001oooool2o`000003ooooool0003o000000Cooooo0_l00015ooooo`0000?ooooooa0@4?ooool0
0_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`0looooo`;o00000oooool2o`0000Sooooo0_l00003ooooo`?o00000_ooool2o`0000?o
oooo0_l00005ooooo`Wo00000_ooool2o`0000Sooooo0_l00004ooooo`;o00000oooool4o`0000Wo
oooo0_l00006oooooa3o000000?oooooo`000?l000000_l0000<ooooo`;o00001oooool2o`0001co
oooo0_l000000ooooooo0000o`000007ooooo`;o00003Oooool3o`0000Kooooo0_l00015ooooo`00
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ
8B401_ooool3o`0003cooooo1ol00008ooooo`;o00000oooool3o`0000Gooooo0ol00004ooooo`Ko
000000?oooooo`000?l000000ol00002ooooo`?o00000_ooool2o`0000Sooooo1?l00003ooooo`;o
00002Oooool2o`0000Kooooo0_l00002ooooo`go00000oooool2o`0000_ooooo0_l0000<ooooo`;o
00005oooool2o`0000[ooooo0_l00004ooooo`;o00002?ooool2o`0000Cooooo0_l00017ooooo`00
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`01_ooool00ol0003oooooooooo`0jooooo`;o000000?oooooo`000?l000000_l0000?ooooo`?o
00001Oooool3o`0000Cooooo1_l00003ooooo`?o000000?oooooo`000?l000000_l00002ooooo`;o
00002?ooool4o`0001Kooooo0_l000000ooooooo0000o`00000Ao`0001Sooooo1Ol0000Eooooo`Co
00003_ooool2o`0000Kooooo0_l00006ooooo`;o0000Aoooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo03[ooooo
0_l00002ooooo`?o00003_ooool6o`0000?ooooo0_l00005ooooo`Oo000000?oooooo`000?l00000
0_l000001?oooooo0000o`000?l00006ooooo`?o00001?ooool3o`0001Oooooo5Ol0000=ooooo`;o
00002_ooool5o`0001Kooooo0ol0000Fooooo`;o00000_ooool3o`0001cooooo0_l0000/ooooo`00
00KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000oooo
ooooool0?_ooool3o`0000kooooo1_l00003ooooo`;o00000_ooool6o`000005ooooool0003o0000
o`000?ooool01?l00009ooooo`Co00000_ooool3o`0001Wooooo5?l00003ooooo`;o00002Oooool2
o`0002Gooooo1?l0000Aooooo`;o00001_ooool3o`000003ooooool0003o000000;ooooo0_l0000E
ooooo`;o0000;?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`00
0?l@4106ooooo`03o`000?oooooooooo03gooooo1_l0000<ooooo`?o00002_ooool4o`0000?ooooo
0ol00002ooooo`?o00002Oooool2o`0000Cooooo0ol000000ooooooo0000o`000003ooooo`;o0000
4?ooool:o`000003ooooool0003o000000So00000_ooool3o`0000Wooooo0_l0000Wooooo`;o0000
2_ooool2o`0000Gooooo0_l00007ooooo`;o000000?oooooo`000?l000000_ooool2o`0004?ooooo
000Looooo`03o`000?oooooooooo03gooooo0ol000000ooooooo0000o`00000Iooooo`;o00000ooo
ool5o`000003ooooool0003o000000;o00000oooool2o`0000Wooooo0_l00003ooooo`;o00000ooo
ool2o`0000oooooo2ol000000ooooooo0000o`000002o`000003ooooool0003o000000?o00000_oo
ool4o`0003gooooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00002_ooool2
o`0000;ooooo1_l000001?oooooo0000o`000?l00004ooooo`;o00002Oooool2o`0001Cooooo0_l0
0002ooooo`_o000000?oooooo`000?l000001ol000001Ooooooo0000o`000?l0003ooooo00Co0000
1oooool3o`00037ooooo0_l00006ooooo`;o00001oooool2o`0001Wooooo0_l0000_ooooo`007?oo
ool00ol0003oooooooooo`0jooooo`;o00005?ooool2o`0000[ooooo0ol000000ooooooo0000o`00
0007o`00013ooooo0_l0000Dooooo`oo000000?oooooo`000?l000004?l00007ooooo`?o0000<Ooo
ool2o`000003ooooool0003o000000?ooooo0ol00004ooooo`Co00006?ooool3o`0002oooooo000L
ooooo`03o`000?oooooooooo03[ooooo0_l0000Eooooo`;o00002Oooool3o`0000;ooooo2?l00003
ooooo`;o00002_ooool2o`0000Kooooo0_l0000?ooooob3o00002oooool2o`0000?ooooo0_l0000/
ooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`?o00006?ooool3o`00033ooooo000L
ooooo`03o`000?oooooooooo03cooooo0_l00005ooooo`;o00001?ooool2o`0000Gooooo0ol00008
ooooo`?o00000oooool7o`0000Cooooo0_l0000:ooooo`;o00001Oooool3o`0000?ooooo0_l00000
0ooooooo0000o`000002ooooo`;o00001?ooool3o`000003ooooool0003o000000co000000?ooooo
o`000?l000001Ol00003ooooo`;o00002oooool2o`0000?ooooo0_l0000Qooooo`?o00001_ooool2
o`0000Sooooo0ol000001?oooooo0000o`000?l0000Hooooo`;o0000<Oooool001cooooo00?o0000
ooooooooool0>oooool3o`0000Gooooo0_l00004ooooo`;o00001Oooool2o`0000Wooooo0ol00003
ooooo`Oo00005oooool2o`0000Cooooo2Ol00004ooooo`;o000000?oooooo`000?l000005_l00002
ooooo`?o00004?ooool2o`00023ooooo0ol00005ooooo`?o00002?ooool6o`0001Kooooo0_l0000d
ooooo`007?ooool00ol0003oooooooooo`0kooooo`?o00001Oooool2o`0000;ooooo0_l0000Hoooo
o`;o00002?ooool2o`0000Gooooo0_l00008ooooo`;o00002?ooool2o`0000;ooooo0_l000000ooo
oooo0000o`000003ooooob3o00004?ooool2o`0001oooooo0_l00004ooooo`;o000000?oooooo`00
0?l000002Oooool2o`000003ooooool0003o000001Kooooo0ol0000dooooo`007?ooool00ol0003o
ooooooooo`0looooo`;o00001Oooool2o`0000;ooooo0_l00008ooooo`?o00003?ooool3o`0000Oo
oooo0ol00005ooooo`;o00001_ooool4o`0000;ooooo0_l00008ooooo`;o000000?oooooo`000?l0
00008ol00008ooooo`;o00001Oooool2o`00023ooooo0ol00003ooooo`;o00001oooool2o`0000Go
oooo0_l0000Gooooo`;o0000=Oooool001cooooo00?o0000ooooooooool0??ooool2o`0000Gooooo
0_l000000ooooooo0000o`000006ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000Wo
oooo1?l00006ooooo`;o00001_ooool2o`0000Kooooo0_l00004ooooo`;o00002?ooool2o`000003
ooooool0003o0000023o000000?oooooo`000?l000002?ooool2o`0000Gooooo0_l0000Qooooo`;o
00002?ooool6o`0000Cooooo0ol0000Gooooo`;o0000=Oooool001cooooo00?o0000ooooooooool0
A_ooool2o`0000Kooooo0_l00005ooooo`;o00002_ooool3o`0000Kooooo0_l00004ooooo`Co0000
2Oooool5o`0000Sooooo1?l00002oooooa[o000000?oooooo`000?l000000_ooool3o`0000?ooooo
0_l00009ooooo`;o00007oooool2o`0000Cooooo1?l00003ooooo`Go00001Oooool3o`0004kooooo
000Looooo`03o`000?oooooooooo04Oooooo0_l00005ooooo`;o00000oooool2o`0000Oooooo0_l0
0004ooooo`?o00000oooool2o`0000Kooooo0_l0000;ooooo`Co00001?ooool3o`0000Cooooo0_l0
0002oooooa[o000000?oooooo`000?l000000_ooool4o`0000;ooooo0_l00002ooooo`;o00001Ooo
ool2o`0001kooooo0ol00004ooooo`Co00000oooool6o`0000?ooooo0_l0001@ooooo`007?ooool2
o`0004Sooooo0_l00004ooooo`?o00000oooool3o`0000Kooooo0_l00004ooooo`So00001oooool2
o`0000[ooooo0_l000001?oooooo0000o`000?l00002ooooo`?o000000Coooooo`000?l0003o0000
0_ooool4o`000003ooooool0003o000001Go000000?oooooo`000?l000000oooool3o`0000?ooooo
0_l000000ooooooo0000o`000005ooooo`;o00007_ooool2o`0000Cooooo0_l00003ooooo`;o0000
00Goooooo`000?l0003o0000ooooo`02o`000003ooooool0003o000000;o0000D?ooool001cooooo
00?o0000ooooooooool0A_ooool2o`0000Gooooo1?l00002ooooo`?o000000?oooooo`000?l00000
2_ooool6o`0000Sooooo0_l0000=ooooo`?o00001_ooool3o`000003ooooool0003o000000?o0000
00?oooooo`000?l000007ol00002ooooo`;o00001oooool3o`000003ooooool0003o0000027ooooo
0_l00003ooooo`;o00001oooool3o`0005;ooooo000Looooo`03o`000?oooooooooo04Kooooo0_l0
0003ooooo`;o00000_ooool2o`0000;ooooo1_l00003ooooo`;o00001oooool2o`0000Sooooo1?l0
000@ooooo`;o00002?ooool2o`000004ooooool0003o0000ooooob?o000000?oooooo`000?l00000
1_ooool2o`0000;ooooo0_l00002ooooo`;o00008?ooool4o`000003ooooool0003o000000;ooooo
1?l0001Cooooo`007?ooool00ol0003oooooooooo`16ooooo`;o00000oooool2o`0000Kooooo1_l0
0003ooooo`Co00003oooool4o`00013ooooo0_l0000:ooooo`?o000000?oooooo`000?l000006_l0
00000ooooooo0000o`000002ooooo`Go00002_ooool2o`0000;ooooo0_l0000Nooooo`Ko000000?o
ooooo`000?l000001?l0001Eooooo`007?ooool00ol0003oooooooooo`16ooooo`;o00002oooool6
o`0000?ooooo1_l0000>ooooo`;o00007Oooool4o`000003ooooool0003o000001Ko00000_ooool:
o`00013ooooo0_l0000Mooooo`?o00000oooool6o`0005Kooooo000Looooo`03o`000?oooooooooo
04;ooooo0_l00008ooooo`;o00001oooool2o`0000Gooooo0ol000001?oooooo0000o`000?l0000;
ooooo`Co00007OoooolMo`0000;ooooo0_l000000ooooooo0000o`000003o`0000_ooooo0_l00005
ooooo`?o00006oooool4o`0000?ooooo1_l0000Fooooo`;o0000?_ooool001cooooo00?o0000oooo
ooooool0@_ooool2o`0000Sooooo0_l0000>ooooo`?o00000_ooool4o`0000Wooooo0ol0000Noooo
oa[o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000Ko00001oooool3o`00
00Kooooo0_l0000Kooooo`;o00000oooool5o`0001Wooooo0_l0000nooooo`007?ooool00ol0003o
ooooooooo`1Fooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo1Ol00006ooooo`Co
00007_oooolKo`0000Cooooo2ol00007ooooo`;o0000:Oooool4o`0001Sooooo0ol0000oooooo`00
7?ooool00ol0003oooooooooo`16ooooo`?o00002?ooool2o`0000?ooooo0_l000000ooooooo0000
o`000002ooooo`;o00001?ooool5o`0000Cooooo1Ol0000Noooooako00000oooool3o`0000?ooooo
0_l0001?ooooo`?o0000?oooool001cooooo00?o0000ooooooooool0A?ooool5o`0000Sooooo0_l0
0003ooooo`;o00001_ooool3o`0000;ooooo2ol000000ooooooo0000o`00000Noooooako00000ooo
ool2o`000003ooooool0003o000000[ooooo1?l0000:ooooo`;o00006_ooool2o`0001cooooo0_l0
0010ooooo`007?ooool00ol0003oooooooooo`14ooooo`Co000000?oooooo`000?l000002oooool2
o`0000Kooooo1?l000000ooooooo0000o`000002o`000003ooooool0003o000000?o00008_oooolN
o`0000;ooooo0_l00002ooooo`;o00002_ooool4o`0000;ooooo0_l00006ooooo`;o00004?ooool2
o`0000Sooooo0_l0000Jooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0A?ooool7o`00
00_ooooo0ol00007ooooo`;o00001?ooool7o`00027ooooo6?l00002ooooo`Go00000_ooool4o`00
01;ooooo0_l00007ooooo`;o00003oooool2o`0000Sooooo0_l0000Iooooo`?o0000@_ooool001co
oooo00?o0000ooooooooool0A?ooool2o`000003ooooool0003o000000kooooo0_l00007ooooo`?o
00000oooool4o`000003ooooool0003o000001_ooooo0_l00004oooooaKo00000_ooool4o`000003
ooooool0003o000000So00006Oooool2o`0000oooooo0ol0000Rooooo`;o0000@oooool001cooooo
00?o0000ooooooooool0FOooool2o`0000Kooooo2Ol0000Nooooo`;o00001OoooolDo`000003oooo
ool0003o000000;o000000?oooooo`000?l000002_l0000Fooooo`;o000000?oooooo`000?l00000
3oooool3o`0000;ooooo0_l00003ooooo`;o0000G_ooool001cooooo00?o0000ooooooooool0AOoo
ool2o`000003ooooool0003o000000Gooooo0_l00008ooooo`;o00001_ooool9o`0002Gooooo4ol0
0002ooooo`;o00000oooool4o`000003ooooool0003o000000Go00005_ooool7o`0001;ooooo0_l0
0003ooooo`;o0000G_ooool001cooooo00?o0000ooooooooool0AOooool2o`000003ooooool0003o
000000Gooooo0ol00007ooooo`;o00001_ooool3o`000003ooooool0003o000000;o00009_ooool>
o`000003ooooool0003o000000?o00001?ooool2o`000005ooooool0003o0000o`000?ooool00ol0
00000ooooooo0000o`00000@ooooo`?o00001Oooool2o`000004ooooool0003o0000o`0001;ooooo
0_l0001Sooooo`007?ooool2o`0004Kooooo0_l00009ooooo`;o00001oooool2o`0000Oooooo0ol0
0007ooooo`;o00008Oooool;o`000003ooooool0003o000000?ooooo0ol00004ooooo`;o00000ooo
ool2o`0000Cooooo0_l0000@ooooo`?o00000_ooool2o`0001Wooooo0_l0000Iooooo`;o0000B?oo
ool001cooooo00?o0000ooooooooool0BOooool2o`0000Oooooo1?l00003ooooo`?o00001_ooool3
o`0000Oooooo0_l0000Sooooo`Wo00000oooool5o`0000?ooooo0_l00004ooooo`?o00000oooool3
o`0000;ooooo0_l0000<ooooo`;o000000?oooooo`000?l000001?l0000Gooooo`;o00006Oooool2
o`0004Sooooo000Looooo`03o`000?oooooooooo04Wooooo0_l00007ooooo`Co00001?ooool4o`00
00Cooooo0_l00008ooooo`;o00008_oooolAo`0000Cooooo0_l00004ooooo`;o00000_ooool5o`00
00;ooooo0_l0000<ooooo`Ko000000?oooooo`000?l00000O?ooool001cooooo00?o0000oooooooo
ool0G?ooool2o`0000Cooooo0ol000000ooooooo0000o`000005o`0002?ooooo3ol00006ooooo`;o
00002?ooool4o`0001;ooooo1Ol000000ooooooo0000o`000002o`0001Wooooo0_l0000Aooooo`;o
0000C?ooool001cooooo00?o0000ooooooooool0Eoooool2o`0000;ooooo0_l00006ooooo`;o0000
00?oooooo`000?l000001Ol0000Tooooo`?o00000_ooool8o`0000Gooooo0_l00008ooooo`;o0000
00?oooooo`000?l000004oooool5o`000003ooooool0003o000000;o00003Oooool3o`0000;ooooo
0ol00003ooooo`?o00003oooool4o`0004cooooo000Looooo`03o`000?oooooooooo05Oooooo0_l0
0002ooooo`;o00003Oooool2o`0002Gooooo0ol00005ooooo`;o00002?ooool2o`000003ooooool0
003o000000Gooooo0_l0000Fooooo`;o000000Coooooo`000?l0003ooooo0_l0000?ooooo`?o0000
0_ooool3o`0000?ooooo0_l0000@ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0COoo
ool2o`0000cooooo0ol0000`ooooo`;o000000Coooooo`000?l0003o00004_ooool2o`0000;ooooo
0_l0000Eooooo`Go00000_ooool2o`0001Oooooo0ol0000Eooooo`;o0000C_ooool001cooooo00?o
0000ooooooooool0COooool3o`0000cooooo0ol00007ooooo`;o00009_ooool2o`000003ooooool0
003o000000;o00005Oooool2o`0001Cooooo1_l0000Kooooo`;o0000I_ooool001cooooo00?o0000
ooooooooool0C_ooool2o`0000Gooooo0_l00005ooooo`?o00001oooool2o`0000;ooooo0_l0000T
ooooo`;o000000?oooooo`000?l00000:Oooool7o`0001_ooooo0ol0000Cooooo`;o0000DOooool0
01cooooo00?o0000ooooooooool0EOooool2o`0000Kooooo0_l000000ooooooo0000o`000008oooo
o`;o00009?ooool2o`0000?ooooo0_l0000Wooooo`Oo00006oooool2o`0001;ooooo1?l0001Aoooo
o`007?ooool00ol0003oooooooooo`1Pooooo`;o0000<oooool2o`0002Gooooo1Ol00002ooooo`;o
00000_ooool2o`0000[ooooo0_l0000;ooooo`;o00004_ooool2o`0005?ooooo000Looooo`03o`00
0?oooooooooo05Wooooo0ol0000fooooo`;o000000?oooooo`000?l000000_l0000Qooooo`Oo0000
00?oooooo`000?l000001Ol0000:ooooo`;o00007_ooool2o`0005Cooooo000Looooo`03o`000?oo
oooooooo05Wooooo0ol0000fooooo`;o00000oooool5o`0001gooooo1ol00002ooooo`Ko0000:Ooo
ool4o`0005Cooooo000Looooo`03o`000?oooooooooo057ooooo0ol00015ooooo`?o00007Oooool2
o`0000?ooooo0_l000000ooooooo0000o`000002o`0001Sooooo0_l0000Booooo`?o0000EOooool0
01cooooo00?o0000ooooooooool0DOooool3o`0000gooooo0_l0000gooooo`;o00008?ooool4o`00
0003ooooool0003o0000013ooooo0_l00008ooooo`?o0000JOooool001cooooo00?o0000oooooooo
ool0Doooool2o`0000cooooo0_l0000booooo`;o00000oooool2o`000003ooooool0003o000001;o
oooo0_l000000ooooooo0000o`000005ooooo`?o00005Oooool2o`0000Kooooo0_l000000ooooooo
0000o`00001Yooooo`007?ooool2o`0005Cooooo0_l00006ooooo`;o000000?oooooo`000?l00000
1?ooool2o`0002oooooo0_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l00000
3Oooool4o`000003ooooool0003o000000?ooooo1?l0000@ooooo`;o00001?ooool2o`0000Kooooo
0_l0000Aooooo`;o0000FOooool001cooooo00?o0000ooooooooool0E?ooool2o`0000Gooooo0_l0
00001?oooooo0000o`000?l00003ooooo`?o0000<Oooool2o`0000Kooooo0_l0000:ooooo`Go0000
1Oooool2o`000003ooooool0003o000001;ooooo1?l0000:ooooo`;o00004Oooool2o`0005Wooooo
000Looooo`03o`000?oooooooooo05Cooooo1?l00007ooooo`;o00001?ooool2o`00043ooooo0_l0
0003ooooo`Co00001_ooool2o`0001Gooooo1?l00006ooooo`?o0000Koooool001cooooo00?o0000
ooooooooool0E_ooool2o`0000oooooo0_l0000nooooo`;o00006_ooool2o`0000?ooooo0_l00000
0ooooooo0000o`000002o`0000Sooooo0ol0001_ooooo`007?ooool00ol0003oooooooooo`1Ooooo
o`;o00001_ooool2o`0003Cooooo0ol0000Sooooo`;o00000oooool2o`000003ooooool0003o0000
00Gooooo0ol0001dooooo`007?ooool00ol0003oooooooooo`1Oooooo`;o00000oooool2o`0000?o
oooo0ol0000aooooo`?o00004?ooool2o`00023ooooo0ol0000Dooooo`;o0000G_ooool001cooooo
00?o0000ooooooooool0F?ooool3o`0000Sooooo0ol00003ooooo`?o0000=Oooool2o`0000Oooooo
0_l00002ooooo`Co00001Oooool2o`0000Gooooo0ol00002ooooo`;o00002Oooool5o`0001Kooooo
0_l0001Nooooo`007?ooool00ol0003oooooooooo`1Hooooo`?o00002?ooool2o`0000Oooooo1?l0
000aooooo`;o00001oooool2o`0000;ooooo1?l00003ooooo`Oo00000_ooool4o`000003ooooool0
003o000000Oooooo1ol0000Aooooo`?o0000H_ooool001cooooo00?o0000ooooooooool0K?ooool5
o`00023ooooo0_l0000Cooooo`;o00002?ooool2o`0000?ooooo1ol00004ooooo`;o00001oooool2
o`000003ooooool0003o000001Kooooo0ol0001Rooooo`007?ooool00ol0003oooooooooo`1_oooo
o`;o00008?ooool3o`0001;ooooo0_l00004ooooo`;o00000_ooool2o`0000cooooo0_l00003oooo
o`Co00000_ooool2o`0001Oooooo0ol0001Tooooo`007?ooool00ol0003oooooooooo`1Vooooo`;o
00002?ooool3o`0001cooooo0_l000000ooooooo0000o`000002ooooo`;o00005?ooool2o`0000;o
oooo0_l00002ooooo`Co00001?ooool4o`0000?ooooo1?l0000Jooooo`Co0000I?ooool001cooooo
00?o0000ooooooooool0I_ooool2o`0000Sooooo0ol0000Looooo`;o00001Oooool2o`0001cooooo
1?l00004ooooo`Co00007Oooool2o`0000;ooooo0_l0001Vooooo`007?ooool00ol0003ooooooooo
o`1eooooo`Co00007oooool2o`0000Gooooo0_l0000looooo`;o0000J_ooool001cooooo00?o0000
ooooooooool0MOooool4o`0001kooooo0ol00005ooooo`;o0000>?ooool5o`0006_ooooo00001_oo
ooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0
1_ooool00ol0003oooooooooo`1[ooooo`;o00002_ooool2o`0001kooooo0_l00006ooooo`;o0000
;_ooool2o`0000Gooooo0_l000000ooooooo0000o`000003o`0006_ooooo00001_ooooooMgMgoiRH
V?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0
003oooooooooo`1[ooooo`?o00000_ooool2o`0005[ooooo0_l000000ooooooo0000o`000004o`00
0003ooooool0003o0000077ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wo
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo06cooooo0_l00002oooo
o`Co0000:_ooool2o`0000Sooooo0ol0000Qooooo`;o00000oooool5o`0000?ooooo0_l0001^oooo
o`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRH
V?lb<S801_ooool3o`0006Gooooo0_l0000;ooooo`;o0000:_ooool2o`0000Sooooo1Ol0000@oooo
o`;o00000oooool4o`0000_ooooo1Ol00002ooooo`Co0000KOooool00003ooooool0003ooooo00;o
oooo00?o0000ooooooooool02Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000oooo
ooooool0IOooool2o`00047ooooo0_l000001?oooooo0000o`000?l0000;ooooo`;o00000_ooool2
o`0000?ooooo1?l0000<ooooo`?o00000oooool4o`0006gooooo00000ooooooo410@ooooo`02oooo
o`03oa0@4?oooooooooo00Wooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooo
oooo06Kooooo0_l00011ooooo`Oo00001?ooool2o`0000?ooooo0_l00004ooooo`;o00004_ooool2
o`0007Cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zj
o`000006ooooo`03o`000?oooooooooo06Kooooo0_l00009ooooo`;o00000oooool4o`000003oooo
ool0003o000002cooooo1ol00004ooooo`;o00002Oooool2o`0008Sooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo
077ooooo0_l00003ooooo`Co000000?oooooo`000?l000004_ooool4o`0000Oooooo0_l00008oooo
o`?o00001Oooool2o`0000Sooooo0_l0000Dooooo`?o0000N_ooool001cooooo00?o0000oooooooo
ool0Noooool3o`0000[ooooo0_l00005ooooo`Co00001?ooool2o`000003ooooool0003o000000?o
oooo0_l00003ooooo`Co00001Oooool4o`0000Gooooo0_l0000Dooooo`?o0000N_ooool001cooooo
00?o0000ooooooooool0M_ooool2o`0000?ooooo0ol00006ooooo`;o00000_ooool2o`000005oooo
ool0003o0000o`000?ooool00_l00006ooooo`;o00001_ooool4o`0000?ooooo0_l00005ooooo`Co
00000_ooool2o`0000[ooooo0_l00006ooooo`;o0000P?ooool001cooooo00?o0000ooooooooool0
M_ooool2o`0000_ooooo0ol00005ooooo`?o000000?oooooo`000?l000001?ooool2o`0000[ooooo
0_l00004ooooo`;o00002Oooool4o`0000Oooooo1?l00006ooooo`;o0000P?ooool001cooooo00?o
0000ooooooooool0Poooool2o`0000gooooo0_l000000ooooooo0000o`000002o`0000kooooo0_l0
0008ooooo`Go00001oooool4o`0008Sooooo000Looooo`03o`000?oooooooooo08Kooooo0ol00002
ooooo`;o00001Oooool2o`0000?ooooo0_l00003ooooo`;o00003_ooool2o`0000?ooooo0ol0000;
ooooo`;o0000R?ooool001cooooo00?o0000ooooooooool0Q_ooool3o`0000;ooooo0_l00005oooo
o`?o00000_ooool2o`0000?ooooo0_l0000>ooooo`;o00001Oooool2o`0000Cooooo0_l00005oooo
o`;o0000Qoooool001cooooo00?o0000ooooooooool0Q?ooool3o`0000_ooooo0ol00002ooooo`;o
00000oooool2o`0000Kooooo0ol00004ooooo`Co00001?ooool2o`0000Cooooo0_l00005ooooo`;o
0000Qoooool001cooooo00?o0000ooooooooool0Q?ooool3o`0000Cooooo0_l00002ooooo`;o0000
1oooool4o`0000Kooooo1Ol00004ooooo`Co0000V_ooool001cooooo00?o0000ooooooooool0Rooo
ool2o`0000;ooooo0_l00007ooooo`Co00000oooool6o`000:Cooooo000Looooo`03o`000?oooooo
oooo09Wooooo0_l00004ooooo`Ko0000Y?ooool001cooooo00?o0000ooooooooool0VOooool2o`00
0:kooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0
003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001;ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo
B_ooool001Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood[ooooo000D
ooooo`03o`000?oooooooooo00Gooooo0ol0003ooooood[ooooo000Dooooo`03o`000?oooooooooo
0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003ooooo
ooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001;ooooo00?oEEEE
ofIVI_l00000oooooomDooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00YOoo
ool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo01Gooooo1Ol00003ooooo`05olc<
c?lQ8B7o0000ob4Q8Oo<c<`00oooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<093ooooo002Vooooo`05
o`000?ooooooooooooooool000002Oooool6o`0000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A003
ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B400oooool01OlQ8B7oV9RHoooooonHV9So8B4Q093ooooo
002Vooooo`05o`000?ooooooooooooooool000006Oooool00onHV9So8B4Qonk^kP04ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000093ooooo002Vooooo`05
o`000?ooooooooooooooool000002Oooool6o`0000_ooooo00?oV9RHob4Q8Oo^k^h00oooool01Olb
<S;oV9RHoooooonHV9So<S8b00?ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P2@ooooo`00Y_ooool0
1Ol0003oQhN7oooooonYZJWo000001_ooooo00?oMgMgofIVI_ooool00_ooool01Oo<c<co0000o`00
0?l0003oc<c<00?ooooo00Goc<c<o`000?l0003o0000olc<c02@ooooo`00YOooool00ol@413o0000
ogMgM`02o`000003oiRHV?oooooooooo01[ooooo00Wo0000oooooooooooooooooa0@4?nj^[[ooooo
okZj^_l@41000oooool01Ol@413o^[Zjoooooonj^[[o410@093ooooo0033ooooo`05o`000?nj^[[o
oooooiRHV?l@41000oooool01Ol0003o^[Zjoooooonj^[[o000000?ooooo00Go0000okZj^_oooooo
^[Zjo`00002@ooooo`00`oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@03ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0T?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(294) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.71577 .53394 Mdot
.69237 .52177 Mdot
.45134 .30056 Mdot
.48771 .66966 Mdot
.29962 .42212 Mdot
.39757 .31108 Mdot
.58396 .33703 Mdot
.58296 .33003 Mdot
.43645 .2805 Mdot
.5375 .78178 Mdot
.59693 .35987 Mdot
.42039 .66879 Mdot
.60199 .33354 Mdot
.46712 .6512 Mdot
.33709 .58148 Mdot
.50691 .6445 Mdot
.71921 .49951 Mdot
.36437 .38706 Mdot
.50546 .63558 Mdot
.4031 .28224 Mdot
.55959 .6421 Mdot
.47884 .64705 Mdot
.66409 .53733 Mdot
.46888 .64769 Mdot
.46043 .60468 Mdot
.70175 .51359 Mdot
.71337 .53565 Mdot
.42364 .64464 Mdot
.49877 .64698 Mdot
.62022 .34133 Mdot
.43015 .4992 Mdot
.27116 .69959 Mdot
.52215 .5907 Mdot
.68632 .65998 Mdot
.62371 .33062 Mdot
.54729 .37534 Mdot
.40287 .34041 Mdot
.62024 .31461 Mdot
.60077 .36184 Mdot
.57219 .3623 Mdot
.57366 .36179 Mdot
.70436 .51366 Mdot
.59367 .31178 Mdot
.47288 .22442 Mdot
.46547 .63853 Mdot
.7482 .5941 Mdot
.4121 .24314 Mdot
.45447 .62112 Mdot
.66173 .5137 Mdot
.43074 .26852 Mdot
.25652 .51229 Mdot
.57767 .32727 Mdot
.50587 .53402 Mdot
.84719 .38288 Mdot
.59301 .32992 Mdot
.49193 .60297 Mdot
.42758 .29741 Mdot
.44406 .66425 Mdot
.42617 .66875 Mdot
.67343 .63205 Mdot
.45061 .67227 Mdot
.32985 .4235 Mdot
.64068 .52879 Mdot
.42534 .25807 Mdot
.44106 .28309 Mdot
.60328 .31165 Mdot
.69477 .47763 Mdot
.61553 .33665 Mdot
.49592 .65192 Mdot
.41821 .2737 Mdot
.48968 .61221 Mdot
.59792 .35928 Mdot
.70489 .53735 Mdot
.4835 .64036 Mdot
.7695 .45207 Mdot
.61528 .40099 Mdot
.36559 .36657 Mdot
.60075 .55759 Mdot
.40811 .39257 Mdot
.36008 .55147 Mdot
.48239 .64193 Mdot
.61501 .20159 Mdot
.30313 .56858 Mdot
.66611 .51872 Mdot
.48968 .5543 Mdot
.69978 .31707 Mdot
.46227 .60894 Mdot
.43599 .49395 Mdot
.42302 .6884 Mdot
.26794 .42833 Mdot
.42367 .28969 Mdot
.673 .49499 Mdot
.47497 .63353 Mdot
.49186 .64187 Mdot
.61269 .77598 Mdot
.50048 .65376 Mdot
.41905 .65384 Mdot
.49158 .46104 Mdot
.56353 .34792 Mdot
.51095 .56847 Mdot
.45785 .385 Mdot
.49596 .51508 Mdot
.48309 .60594 Mdot
.41397 .30425 Mdot
.64229 .52828 Mdot
.51483 .59205 Mdot
.61048 .34282 Mdot
.47595 .63815 Mdot
.64443 .32635 Mdot
.66062 .51888 Mdot
.4168 .6491 Mdot
.34311 .40511 Mdot
.5664 .52786 Mdot
.69162 .54284 Mdot
.7329 .68502 Mdot
.4732 .67284 Mdot
.4367 .6539 Mdot
.69486 .52347 Mdot
.38974 .30479 Mdot
.56303 .19337 Mdot
.70811 .53222 Mdot
.56417 .36008 Mdot
.7123 .48832 Mdot
.51899 .50568 Mdot
.38891 .3042 Mdot
.50253 .48147 Mdot
.50665 .47884 Mdot
.25212 .61992 Mdot
.48313 .67667 Mdot
.52934 .69751 Mdot
.40625 .30978 Mdot
.69941 .53422 Mdot
.60914 .32769 Mdot
.48381 .69264 Mdot
.68973 .50099 Mdot
.58063 .33576 Mdot
.33287 .43623 Mdot
.36154 .38302 Mdot
.67329 .53672 Mdot
.74947 .67623 Mdot
.5558 .36496 Mdot
.56235 .33509 Mdot
.25657 .51593 Mdot
.66642 .51956 Mdot
.32209 .4136 Mdot
.59623 .34712 Mdot
.18636 .41749 Mdot
.45622 .60503 Mdot
.24955 .55338 Mdot
.62702 .21462 Mdot
.25698 .51142 Mdot
.5424 .69217 Mdot
.33526 .40283 Mdot
.58007 .33585 Mdot
.46751 .61917 Mdot
.67543 .51497 Mdot
.69287 .50271 Mdot
.49087 .61813 Mdot
.51126 .5807 Mdot
.45744 .65724 Mdot
.51735 .58737 Mdot
.48327 .46123 Mdot
.47301 .63535 Mdot
.81041 .5526 Mdot
.67464 .50611 Mdot
.50545 .58457 Mdot
.40368 .33699 Mdot
.52611 .66663 Mdot
.5946 .31227 Mdot
.45554 .68502 Mdot
.49367 .58547 Mdot
.42356 .6811 Mdot
.55717 .35758 Mdot
.79341 .46197 Mdot
.39177 .38765 Mdot
.57968 .36685 Mdot
.57625 .27269 Mdot
.40906 .32349 Mdot
.42859 .65228 Mdot
.3357 .39452 Mdot
.51324 .56292 Mdot
.48364 .62886 Mdot
.25764 .50386 Mdot
.42644 .66597 Mdot
.53536 .70476 Mdot
.47982 .71639 Mdot
.68125 .30293 Mdot
.78423 .49779 Mdot
.48996 .66154 Mdot
.55458 .74858 Mdot
.25548 .54451 Mdot
.55996 .39805 Mdot
.6109 .32682 Mdot
.3941 .30548 Mdot
.39163 .30427 Mdot
.62729 .36379 Mdot
.71319 .67559 Mdot
.51559 .78517 Mdot
.48144 .68957 Mdot
.49982 .51934 Mdot
.72228 .49044 Mdot
.33449 .40473 Mdot
.68102 .53809 Mdot
.59815 .18711 Mdot
.38252 .53015 Mdot
.40622 .53849 Mdot
.4559 .33997 Mdot
.43666 .26768 Mdot
.49834 .51 Mdot
.31912 .41034 Mdot
.44984 .65111 Mdot
.66195 .52076 Mdot
.25613 .53643 Mdot
.50506 .56116 Mdot
.47765 .84199 Mdot
.71499 .52788 Mdot
.30742 .65407 Mdot
.5942 .33206 Mdot
.43451 .31532 Mdot
.46375 .60756 Mdot
.47169 .66378 Mdot
.65702 .51624 Mdot
.45219 .6283 Mdot
.37252 .58699 Mdot
.45317 .60834 Mdot
.4075 .27025 Mdot
.3858 .39061 Mdot
.58543 .36876 Mdot
.44922 .34896 Mdot
.69434 .54334 Mdot
.84152 .519 Mdot
.42053 .31625 Mdot
.50735 .71477 Mdot
.59876 .35769 Mdot
.33438 .43405 Mdot
.42128 .30698 Mdot
.30664 .40514 Mdot
.44558 .68351 Mdot
.41634 .33488 Mdot
.33743 .41754 Mdot
.42837 .52725 Mdot
.51409 .58774 Mdot
.22251 .5964 Mdot
.58072 .34446 Mdot
.69512 .48728 Mdot
.47907 .6217 Mdot
.50369 .53801 Mdot
.50867 .57358 Mdot
.30188 .6253 Mdot
.51169 .49467 Mdot
.49346 .51053 Mdot
.33535 .53774 Mdot
.36074 .40665 Mdot
.75766 .34159 Mdot
.44626 .48471 Mdot
.71989 .50135 Mdot
.48974 .64054 Mdot
.63028 .26764 Mdot
.57727 .33944 Mdot
.44805 .657 Mdot
.67535 .28284 Mdot
.59359 .34616 Mdot
.43968 .65603 Mdot
.61606 .35308 Mdot
.6807 .50557 Mdot
.35663 .58365 Mdot
.72116 .5204 Mdot
.46778 .63222 Mdot
.61223 .35444 Mdot
.39129 .3118 Mdot
.70073 .51206 Mdot
.478 .64136 Mdot
.46682 .68257 Mdot
.50278 .5224 Mdot
.45575 .60595 Mdot
.63264 .41031 Mdot
.45554 .61858 Mdot
.44733 .32473 Mdot
.49983 .65188 Mdot
.39865 .45736 Mdot
.24915 .39682 Mdot
.66787 .53039 Mdot
.51155 .4954 Mdot
.42486 .30225 Mdot
.38655 .57551 Mdot
.30503 .66346 Mdot
.46749 .64061 Mdot
.50875 .49656 Mdot
.2753 .63619 Mdot
.57944 .32027 Mdot
.42251 .68882 Mdot
.2933 .39122 Mdot
.42128 .29111 Mdot
.49814 .51448 Mdot
.49794 .56996 Mdot
.73631 .50349 Mdot
.5047 .63707 Mdot
.41809 .33144 Mdot
.71876 .50582 Mdot
.50146 .62982 Mdot
.58059 .40491 Mdot
.49865 .5451 Mdot
.56237 .3397 Mdot
.48036 .49596 Mdot
.43462 .64354 Mdot
.42114 .27312 Mdot
.70509 .50924 Mdot
.58924 .32879 Mdot
.6948 .54199 Mdot
.27056 .5065 Mdot
.29143 .64014 Mdot
.76391 .51915 Mdot
.33682 .43661 Mdot
.17326 .45567 Mdot
.56914 .36512 Mdot
.51986 .56305 Mdot
.4359 .24962 Mdot
.66854 .46242 Mdot
.4162 .30044 Mdot
.76121 .66194 Mdot
.42594 .29198 Mdot
.49828 .60514 Mdot
.40721 .28975 Mdot
.60937 .78861 Mdot
.43617 .67191 Mdot
.4446 .2877 Mdot
.47653 .45371 Mdot
.44443 .67684 Mdot
.69029 .50016 Mdot
.30957 .74672 Mdot
.70071 .66865 Mdot
.70406 .67966 Mdot
.42892 .30375 Mdot
.77102 .65104 Mdot
.42736 .63497 Mdot
.47495 .69921 Mdot
.68046 .5146 Mdot
.51937 .57013 Mdot
.35647 .39039 Mdot
.34392 .38363 Mdot
.22151 .46643 Mdot
.30846 .70287 Mdot
.71677 .68755 Mdot
.69358 .5058 Mdot
.38174 .37433 Mdot
.77017 .45641 Mdot
.49942 .54472 Mdot
.58247 .33022 Mdot
.79488 .43844 Mdot
.4253 .6881 Mdot
.49065 .48708 Mdot
.37056 .5904 Mdot
.70394 .49308 Mdot
.71049 .56434 Mdot
.58696 .32913 Mdot
.70206 .68238 Mdot
.50717 .77612 Mdot
.45581 .65664 Mdot
.57261 .34414 Mdot
.50899 .57455 Mdot
.43743 .4951 Mdot
.24936 .62984 Mdot
.40494 .21755 Mdot
.46496 .6348 Mdot
.77883 .42534 Mdot
.48098 .62466 Mdot
.24978 .60499 Mdot
.44783 .65073 Mdot
.70126 .50218 Mdot
.41102 .66949 Mdot
.45049 .48657 Mdot
.19592 .35061 Mdot
.38087 .52466 Mdot
.31159 .40102 Mdot
.46964 .6522 Mdot
.45944 .66457 Mdot
.32163 .42822 Mdot
.69094 .49008 Mdot
.48724 .62414 Mdot
.77361 .35076 Mdot
.47728 .63483 Mdot
.59986 .31318 Mdot
.30783 .5994 Mdot
.26739 .68849 Mdot
.4361 .62569 Mdot
.73591 .50078 Mdot
.56203 .33712 Mdot
.59579 .35593 Mdot
.51526 .524 Mdot
.57661 .34131 Mdot
.46223 .62288 Mdot
.30628 .59958 Mdot
.67762 .47826 Mdot
.50218 .55062 Mdot
.70221 .49389 Mdot
.2998 .2573 Mdot
.58198 .3419 Mdot
.50826 .51895 Mdot
.72782 .66825 Mdot
.6032 .34149 Mdot
.38046 .42027 Mdot
.40994 .66935 Mdot
.50384 .55764 Mdot
.72309 .53303 Mdot
.41868 .27487 Mdot
.50051 .4985 Mdot
.59161 .32977 Mdot
.46595 .63977 Mdot
.48499 .59889 Mdot
.5758 .3425 Mdot
.6059 .60381 Mdot
.43129 .49704 Mdot
.47186 .62963 Mdot
.6847 .49703 Mdot
.70243 .53099 Mdot
.50406 .68003 Mdot
.48224 .62384 Mdot
.39486 .31379 Mdot
.50886 .49583 Mdot
.50753 .49148 Mdot
.50466 .47696 Mdot
.4319 .30929 Mdot
.1686 .44035 Mdot
.56704 .3257 Mdot
.27033 .69617 Mdot
.71598 .42172 Mdot
.50644 .54159 Mdot
.38983 .32876 Mdot
.47096 .66863 Mdot
.47031 .60967 Mdot
.62116 .34783 Mdot
.1839 .54447 Mdot
.47408 .69858 Mdot
.72002 .52055 Mdot
.57381 .33607 Mdot
.48889 .5842 Mdot
.6488 .29219 Mdot
.35209 .40056 Mdot
.72385 .68709 Mdot
.57649 .33151 Mdot
.65351 .50223 Mdot
.57661 .33091 Mdot
.45923 .6626 Mdot
.49894 .57054 Mdot
.70922 .49704 Mdot
.30153 .41765 Mdot
.49153 .62294 Mdot
.44202 .65166 Mdot
.49742 .34332 Mdot
.76633 .44997 Mdot
.29664 .42425 Mdot
.47385 .61254 Mdot
.51985 .53914 Mdot
.30271 .42029 Mdot
.46241 .6271 Mdot
.49931 .62992 Mdot
.52888 .6995 Mdot
.62384 .31176 Mdot
.32038 .4391 Mdot
.17893 .37947 Mdot
.71529 .52899 Mdot
.62985 .41286 Mdot
.4952 .49989 Mdot
.56927 .36436 Mdot
.36996 .60681 Mdot
.50503 .50686 Mdot
.73701 .40631 Mdot
.79725 .7045 Mdot
.50197 .4992 Mdot
.39439 .34541 Mdot
.63476 .76606 Mdot
.49848 .63019 Mdot
.46912 .6291 Mdot
.35794 .39261 Mdot
.6881 .52874 Mdot
.78509 .49486 Mdot
.58251 .36642 Mdot
.48171 .66182 Mdot
.70204 .54396 Mdot
.68688 .30532 Mdot
.50313 .51511 Mdot
.34486 .39382 Mdot
.316 .43412 Mdot
.47431 .62414 Mdot
.28362 .65602 Mdot
.69984 .509 Mdot
.47784 .6413 Mdot
.43566 .65093 Mdot
.38547 .33724 Mdot
.66464 .52436 Mdot
.41129 .33381 Mdot
.49496 .54053 Mdot
.66902 .76538 Mdot
.58762 .26577 Mdot
.58826 .34791 Mdot
.51312 .51546 Mdot
.58683 .36855 Mdot
.42188 .24479 Mdot
.50873 .49479 Mdot
.47762 .64316 Mdot
.67011 .4803 Mdot
.47749 .63952 Mdot
.47651 .63407 Mdot
.46103 .64019 Mdot
.71744 .6884 Mdot
.41088 .3931 Mdot
.33753 .39251 Mdot
.43897 .63578 Mdot
.42568 .32743 Mdot
.64831 .28514 Mdot
.5615 .78392 Mdot
.47145 .65733 Mdot
.43749 .65358 Mdot
.73306 .49593 Mdot
.46027 .60212 Mdot
.59524 .34326 Mdot
.70514 .49282 Mdot
.48084 .60442 Mdot
.46548 .37168 Mdot
.48414 .62021 Mdot
.74795 .5446 Mdot
.60554 .31606 Mdot
.44629 .60051 Mdot
.52131 .63271 Mdot
.50992 .49587 Mdot
.50028 .50046 Mdot
.50181 .47428 Mdot
.60121 .31245 Mdot
.39422 .34307 Mdot
.45988 .29008 Mdot
.51939 .66605 Mdot
.46396 .61978 Mdot
.49643 .56596 Mdot
.41368 .35299 Mdot
.45639 .44886 Mdot
.75233 .66225 Mdot
.48196 .58859 Mdot
.43798 .3041 Mdot
.49104 .46173 Mdot
.59087 .58655 Mdot
.6954 .48856 Mdot
.41222 .25979 Mdot
.60927 .35067 Mdot
.34053 .41719 Mdot
.22324 .52303 Mdot
.7115 .5204 Mdot
.71402 .47478 Mdot
.39908 .32527 Mdot
.29431 .59731 Mdot
.84659 .3641 Mdot
.40827 .30237 Mdot
.39709 .5522 Mdot
.68424 .5102 Mdot
.5207 .58942 Mdot
.27414 .62466 Mdot
.30478 .59248 Mdot
.44096 .29208 Mdot
.4684 .68271 Mdot
.32723 .23276 Mdot
.3952 .31104 Mdot
.51522 .5482 Mdot
.42914 .30637 Mdot
.56753 .32925 Mdot
.41021 .31028 Mdot
.69348 .55037 Mdot
.48466 .67365 Mdot
.84688 .37681 Mdot
.31938 .55379 Mdot
.48375 .6684 Mdot
.58754 .31846 Mdot
.55697 .39265 Mdot
.4527 .65817 Mdot
.34659 .38637 Mdot
.39553 .34509 Mdot
.3787 .25993 Mdot
.50263 .61795 Mdot
.41 .28577 Mdot
.72596 .48144 Mdot
.38897 .28276 Mdot
.46377 .37946 Mdot
.50249 .49396 Mdot
.67616 .50871 Mdot
.61376 .39933 Mdot
.56337 .35923 Mdot
.51252 .60039 Mdot
.43163 .65218 Mdot
.67325 .50366 Mdot
.40411 .55596 Mdot
.45634 .7058 Mdot
.47866 .63739 Mdot
.40735 .33084 Mdot
.42306 .26428 Mdot
.33448 .58199 Mdot
.42145 .31828 Mdot
.51539 .54363 Mdot
.68039 .50071 Mdot
.5046 .62879 Mdot
.70483 .53231 Mdot
.48938 .63745 Mdot
.64915 .30131 Mdot
.67628 .49122 Mdot
.50632 .71499 Mdot
.46406 .68469 Mdot
.79495 .56528 Mdot
.43261 .64128 Mdot
.47406 .63041 Mdot
.4096 .27108 Mdot
.31998 .42525 Mdot
.48238 .70339 Mdot
.64977 .32165 Mdot
.33698 .42429 Mdot
.59592 .61374 Mdot
.38782 .30745 Mdot
.32884 .43468 Mdot
.21344 .48865 Mdot
.51056 .49262 Mdot
.30922 .41715 Mdot
.49188 .55623 Mdot
.58517 .34923 Mdot
.65237 .49258 Mdot
.44629 .67849 Mdot
.6601 .76973 Mdot
.43389 .49279 Mdot
.50413 .5214 Mdot
.46251 .62932 Mdot
.46462 .67029 Mdot
.70192 .54372 Mdot
.60193 .19071 Mdot
.44299 .26349 Mdot
.51561 .57862 Mdot
.71216 .52538 Mdot
.62097 .20746 Mdot
.44441 .2926 Mdot
.35955 .40353 Mdot
.60254 .362 Mdot
.66368 .55553 Mdot
.5046 .53048 Mdot
.58074 .34037 Mdot
.45363 .32235 Mdot
.25998 .49866 Mdot
.50452 .64015 Mdot
.39572 .33626 Mdot
.25718 .50977 Mdot
.40947 .67887 Mdot
.62644 .36562 Mdot
.54369 .37939 Mdot
.6646 .50837 Mdot
.57514 .34175 Mdot
.33539 .3901 Mdot
.7163 .48983 Mdot
.70055 .49226 Mdot
.60028 .34479 Mdot
.80745 .59899 Mdot
.27595 .63536 Mdot
.63104 .34214 Mdot
.3099 .62209 Mdot
.2586 .5073 Mdot
.50288 .52805 Mdot
.33977 .3948 Mdot
.38761 .3939 Mdot
.704 .51419 Mdot
.79197 .44113 Mdot
.25612 .51159 Mdot
.41871 .64921 Mdot
.33593 .41991 Mdot
.68685 .31233 Mdot
.57725 .38456 Mdot
.58769 .34317 Mdot
.50088 .33952 Mdot
.3289 .42668 Mdot
.4628 .6881 Mdot
.1792 .5946 Mdot
.43279 .66664 Mdot
.59534 .34792 Mdot
.37132 .58906 Mdot
.67797 .53344 Mdot
.58685 .31526 Mdot
.37188 .58738 Mdot
.47112 .61198 Mdot
.47053 .67527 Mdot
.4204 .39226 Mdot
.66103 .50511 Mdot
.4972 .54038 Mdot
.48636 .66517 Mdot
.4412 .65973 Mdot
.51562 .60982 Mdot
.2623 .67126 Mdot
.57533 .51826 Mdot
.51841 .60047 Mdot
.43688 .32114 Mdot
.50707 .56495 Mdot
.51586 .57714 Mdot
.73228 .52244 Mdot
.44484 .39278 Mdot
.49409 .52801 Mdot
.46263 .6331 Mdot
.46898 .63109 Mdot
.60819 .35885 Mdot
.27512 .63456 Mdot
.29794 .59216 Mdot
.45304 .2912 Mdot
.33712 .36657 Mdot
.48444 .68274 Mdot
.67053 .51257 Mdot
.30887 .44366 Mdot
.51624 .53092 Mdot
.71923 .5197 Mdot
.49158 .66755 Mdot
.38612 .341 Mdot
.50481 .49722 Mdot
.52151 .52763 Mdot
.3356 .41534 Mdot
.58711 .37045 Mdot
.59764 .59514 Mdot
.39088 .32089 Mdot
.46542 .6026 Mdot
.32073 .37237 Mdot
.41476 .28602 Mdot
.50169 .52563 Mdot
.50957 .57068 Mdot
.68512 .50436 Mdot
.65336 .5108 Mdot
.38916 .46165 Mdot
.43088 .31575 Mdot
.45751 .24754 Mdot
.56728 .34262 Mdot
.43835 .63858 Mdot
.57111 .37208 Mdot
.66031 .52691 Mdot
.2513 .61956 Mdot
.32112 .43523 Mdot
.59267 .34472 Mdot
.50047 .5473 Mdot
.68856 .48749 Mdot
.65898 .52694 Mdot
.47164 .63503 Mdot
.47653 .65134 Mdot
.40828 .25467 Mdot
.25261 .55246 Mdot
.62248 .34749 Mdot
.35582 .40593 Mdot
.45196 .28826 Mdot
.4967 .60708 Mdot
.67036 .52293 Mdot
.23586 .66866 Mdot
.43369 .64338 Mdot
.42672 .32493 Mdot
.69285 .51945 Mdot
.35673 .39406 Mdot
.33126 .39242 Mdot
.48895 .65286 Mdot
.53874 .69594 Mdot
.6069 .34073 Mdot
.69351 .49993 Mdot
.6306 .51013 Mdot
.44244 .63115 Mdot
.47262 .65324 Mdot
.4094 .68283 Mdot
.6369 .33306 Mdot
.51415 .65385 Mdot
.30344 .41282 Mdot
.68253 .54099 Mdot
.48639 .65835 Mdot
.32637 .42569 Mdot
.49566 .47501 Mdot
.50626 .50383 Mdot
.43422 .27463 Mdot
.34599 .38524 Mdot
.32319 .41926 Mdot
.342 .42188 Mdot
.79494 .43704 Mdot
.48922 .54633 Mdot
.31233 .46396 Mdot
.46907 .68361 Mdot
.25926 .50619 Mdot
.50814 .65112 Mdot
.57204 .32875 Mdot
.4236 .27324 Mdot
.45904 .64669 Mdot
.46706 .68366 Mdot
.59673 .5795 Mdot
.50604 .63027 Mdot
.49767 .68572 Mdot
.67663 .53422 Mdot
.63278 .49881 Mdot
.39407 .30252 Mdot
.63458 .2227 Mdot
.2054 .66999 Mdot
.47324 .69341 Mdot
.2973 .59781 Mdot
.68618 .48944 Mdot
.60445 .36085 Mdot
.2987 .62233 Mdot
.57093 .37483 Mdot
.69857 .52954 Mdot
.50043 .60638 Mdot
.61494 .57317 Mdot
.33484 .42409 Mdot
.45896 .65933 Mdot
.61548 .33297 Mdot
.45813 .65837 Mdot
.5907 .31542 Mdot
.7738 .63724 Mdot
.28554 .57983 Mdot
.43179 .67091 Mdot
.50057 .65248 Mdot
.55827 .63318 Mdot
.47369 .65508 Mdot
.39778 .22115 Mdot
.6884 .51724 Mdot
.5243 .66097 Mdot
.49872 .60169 Mdot
.69502 .67234 Mdot
.44661 .63959 Mdot
.37684 .6144 Mdot
.44056 .66877 Mdot
.18316 .5192 Mdot
.43902 .67926 Mdot
.43011 .65757 Mdot
.60341 .32157 Mdot
.58582 .36365 Mdot
.69551 .46013 Mdot
.4954 .52868 Mdot
.68398 .30633 Mdot
.44079 .65144 Mdot
.44275 .26957 Mdot
.50553 .72668 Mdot
.32213 .42273 Mdot
.68822 .54069 Mdot
.85853 .64363 Mdot
.58336 .31366 Mdot
.41988 .33703 Mdot
.42118 .51635 Mdot
.42977 .33094 Mdot
.423 .25401 Mdot
.63196 .54014 Mdot
.34141 .39522 Mdot
.48441 .62216 Mdot
.69223 .65394 Mdot
.76635 .4402 Mdot
.44429 .62952 Mdot
.41884 .35698 Mdot
.5223 .70263 Mdot
.36926 .48161 Mdot
.36494 .39239 Mdot
.32896 .40406 Mdot
.58822 .33277 Mdot
.44656 .27854 Mdot
.51364 .5736 Mdot
.32816 .43517 Mdot
.39919 .29655 Mdot
.51363 .50539 Mdot
.43225 .39675 Mdot
.69972 .50756 Mdot
.76854 .65406 Mdot
.75685 .59162 Mdot
.56087 .34591 Mdot
.65011 .32321 Mdot
.66165 .48469 Mdot
.72219 .51226 Mdot
.49681 .52546 Mdot
.43756 .29824 Mdot
.64877 .49827 Mdot
.48801 .65828 Mdot
.50576 .56067 Mdot
.47681 .62311 Mdot
.36267 .39996 Mdot
.45395 .63494 Mdot
.40295 .29303 Mdot
.60305 .31983 Mdot
.4229 .29334 Mdot
.58375 .33537 Mdot
.28328 .71985 Mdot
.46735 .68685 Mdot
.47215 .65036 Mdot
.30598 .59897 Mdot
.66553 .53348 Mdot
.68015 .66858 Mdot
.4288 .31854 Mdot
.42684 .29807 Mdot
.5003 .60346 Mdot
.70621 .48277 Mdot
.3041 .39674 Mdot
.318 .61485 Mdot
.43854 .66634 Mdot
.68729 .51862 Mdot
.50387 .60594 Mdot
.65116 .37519 Mdot
.31207 .56818 Mdot
.67254 .54121 Mdot
.19896 .3451 Mdot
.4579 .68453 Mdot
.52078 .56779 Mdot
.51061 .70389 Mdot
.28614 .68072 Mdot
.46365 .7055 Mdot
.71625 .52584 Mdot
.51364 .57728 Mdot
.6715 .51803 Mdot
.4134 .29075 Mdot
.58454 .31545 Mdot
.67624 .51833 Mdot
.44845 .6771 Mdot
.20556 .66869 Mdot
.61245 .32038 Mdot
.46098 .6553 Mdot
.61866 .33185 Mdot
.64407 .52863 Mdot
.68383 .53225 Mdot
.51386 .5066 Mdot
.39858 .54979 Mdot
.60015 .3435 Mdot
.46053 .62197 Mdot
.78331 .45618 Mdot
.50494 .63943 Mdot
.34812 .36617 Mdot
.4957 .67312 Mdot
.49256 .66721 Mdot
.1633 .42644 Mdot
.39084 .57373 Mdot
.60263 .26067 Mdot
.61954 .28008 Mdot
.79354 .46559 Mdot
.72443 .5338 Mdot
.36335 .39031 Mdot
.60454 .53599 Mdot
.50685 .48812 Mdot
.43925 .31801 Mdot
.46278 .64222 Mdot
.49536 .46935 Mdot
.63193 .33643 Mdot
.31137 .41579 Mdot
.42641 .66584 Mdot
.42063 .34439 Mdot
.51679 .50169 Mdot
.58357 .34147 Mdot
.70521 .51488 Mdot
.69061 .53702 Mdot
.40609 .40023 Mdot
.48577 .66062 Mdot
.47731 .64772 Mdot
.62219 .32752 Mdot
.49143 .7145 Mdot
.3483 .41382 Mdot
.47557 .45336 Mdot
.61772 .33576 Mdot
.30953 .56783 Mdot
.66003 .50652 Mdot
.46767 .6697 Mdot
.31235 .59882 Mdot
.78924 .48401 Mdot
.57781 .75851 Mdot
.33142 .40768 Mdot
.29842 .66059 Mdot
.71594 .52616 Mdot
.60765 .32692 Mdot
.21748 .47577 Mdot
.40905 .67079 Mdot
.45653 .67033 Mdot
.29959 .66894 Mdot
.31731 .61657 Mdot
.42044 .51911 Mdot
.50087 .54974 Mdot
.2773 .61561 Mdot
.50172 .60419 Mdot
.48293 .6001 Mdot
.48225 .6843 Mdot
.49706 .67077 Mdot
.68125 .52267 Mdot
.696 .68879 Mdot
.40282 .31997 Mdot
.57899 .74121 Mdot
.36123 .36258 Mdot
.42496 .64149 Mdot
.48164 .60821 Mdot
.59894 .68779 Mdot
.32625 .65375 Mdot
.69174 .51115 Mdot
.71863 .54177 Mdot
.55978 .35302 Mdot
.50595 .64209 Mdot
.42869 .32121 Mdot
.51647 .69036 Mdot
.42851 .27729 Mdot
.6836 .52255 Mdot
.38406 .32865 Mdot
.55876 .33102 Mdot
.39629 .33688 Mdot
.43858 .30954 Mdot
.59593 .31898 Mdot
.66729 .49487 Mdot
.42929 .64538 Mdot
.59478 .3188 Mdot
.29653 .41341 Mdot
.36171 .39768 Mdot
.67517 .46702 Mdot
.52001 .59416 Mdot
.42689 .68807 Mdot
.47021 .25048 Mdot
.40327 .34134 Mdot
.33669 .61873 Mdot
.66966 .49518 Mdot
.3226 .44241 Mdot
.67491 .52206 Mdot
.3618 .4681 Mdot
.3313 .41185 Mdot
.49019 .55484 Mdot
.22311 .56121 Mdot
.54075 .35096 Mdot
.41728 .67217 Mdot
.63324 .49874 Mdot
.42873 .27897 Mdot
.58852 .31724 Mdot
.66163 .29186 Mdot
.51602 .58046 Mdot
.71612 .47 Mdot
.6556 .54487 Mdot
.50743 .49037 Mdot
.60964 .3283 Mdot
.77153 .58096 Mdot
.4833 .6667 Mdot
.56525 .36668 Mdot
.49497 .67367 Mdot
.73953 .68221 Mdot
.35463 .33957 Mdot
.49123 .46532 Mdot
.49869 .60461 Mdot
.44449 .29409 Mdot
.50022 .60434 Mdot
.68031 .74473 Mdot
.24305 .58708 Mdot
.47862 .68754 Mdot
.32004 .65398 Mdot
.42309 .24252 Mdot
.66858 .52095 Mdot
.51034 .54012 Mdot
.50323 .52527 Mdot
.47971 .59673 Mdot
.30077 .79093 Mdot
.31633 .42607 Mdot
.45647 .35742 Mdot
.4528 .6793 Mdot
.48218 .64326 Mdot
.59511 .59636 Mdot
.77139 .63781 Mdot
.51518 .49217 Mdot
.45208 .66757 Mdot
.3129 .68126 Mdot
.59679 .32384 Mdot
.50217 .63802 Mdot
.47973 .62714 Mdot
.38648 .27624 Mdot
.60516 .32296 Mdot
.38717 .32667 Mdot
.50962 .49097 Mdot
.4201 .26751 Mdot
.30011 .42038 Mdot
.30737 .65599 Mdot
.25581 .64406 Mdot
.31914 .57155 Mdot
.33971 .38605 Mdot
.44091 .61988 Mdot
.48083 .50279 Mdot
.47225 .6787 Mdot
.32524 .40437 Mdot
.62023 .34194 Mdot
.68465 .51795 Mdot
.75596 .67036 Mdot
.50143 .52239 Mdot
.44531 .62101 Mdot
.36184 .41091 Mdot
.67684 .5136 Mdot
.81673 .54674 Mdot
.68636 .52762 Mdot
.58878 .33978 Mdot
.63125 .36036 Mdot
.32927 .41751 Mdot
.67438 .52236 Mdot
.41383 .26972 Mdot
.6141 .37863 Mdot
.41279 .65199 Mdot
.56019 .32907 Mdot
.65641 .53749 Mdot
.67857 .5454 Mdot
.68812 .47615 Mdot
.49403 .60135 Mdot
.32648 .64156 Mdot
.51343 .52052 Mdot
.61897 .32363 Mdot
.43392 .33298 Mdot
.25025 .56027 Mdot
.69652 .60662 Mdot
.29943 .57676 Mdot
.49348 .56161 Mdot
.45576 .63385 Mdot
.47224 .62498 Mdot
.51718 .61312 Mdot
.47054 .4891 Mdot
.47194 .68617 Mdot
.62181 .34741 Mdot
.40417 .2971 Mdot
.44459 .66952 Mdot
.50925 .50778 Mdot
.453 .45458 Mdot
.31615 .43929 Mdot
.72422 .68953 Mdot
.67251 .46688 Mdot
.67788 .51472 Mdot
.41764 .33075 Mdot
.38372 .31536 Mdot
.33384 .43549 Mdot
.57861 .33345 Mdot
.6897 .52938 Mdot
.18413 .50929 Mdot
.34178 .41911 Mdot
.4605 .63456 Mdot
.30734 .59906 Mdot
.30758 .69149 Mdot
.49442 .62422 Mdot
.45952 .64055 Mdot
.49409 .52505 Mdot
.42966 .32263 Mdot
.56224 .79276 Mdot
.80656 .55562 Mdot
.32559 .42338 Mdot
.34839 .42079 Mdot
.69882 .47641 Mdot
.44274 .63767 Mdot
.60963 .33981 Mdot
.27623 .64074 Mdot
.57809 .40551 Mdot
.701 .32167 Mdot
.43038 .2416 Mdot
.48278 .61902 Mdot
.66325 .73335 Mdot
.4407 .69106 Mdot
.64159 .52526 Mdot
.65687 .4972 Mdot
.69314 .50781 Mdot
.59279 .32487 Mdot
.26268 .49547 Mdot
.57648 .36193 Mdot
.49044 .46116 Mdot
.71294 .51134 Mdot
.40527 .54877 Mdot
.42765 .30047 Mdot
.50746 .64484 Mdot
.33682 .39658 Mdot
.2767 .40598 Mdot
.50886 .54483 Mdot
.30137 .65896 Mdot
.38987 .32902 Mdot
.69287 .48528 Mdot
.50755 .63707 Mdot
.64553 .28329 Mdot
.28203 .59107 Mdot
.40982 .23141 Mdot
.49411 .46858 Mdot
.33025 .42379 Mdot
.5315 .78067 Mdot
.34849 .40806 Mdot
.59373 .34523 Mdot
.46541 .68563 Mdot
.43984 .64128 Mdot
.47476 .62967 Mdot
.48514 .69012 Mdot
.59396 .32807 Mdot
.4168 .66477 Mdot
.3977 .45865 Mdot
.50795 .48243 Mdot
.45704 .4794 Mdot
.32074 .39759 Mdot
.56805 .33884 Mdot
.41057 .28928 Mdot
.4935 .50826 Mdot
.33069 .44078 Mdot
.5093 .63173 Mdot
.4576 .67904 Mdot
.51082 .48305 Mdot
.49382 .5589 Mdot
.4311 .69165 Mdot
.39783 .31801 Mdot
.4408 .4897 Mdot
.31277 .43646 Mdot
.33998 .40294 Mdot
.57677 .34661 Mdot
.67394 .52181 Mdot
.32186 .43813 Mdot
.44564 .32592 Mdot
.50269 .637 Mdot
.49315 .67691 Mdot
.66186 .54133 Mdot
.25702 .50669 Mdot
.31578 .43938 Mdot
.51304 .66229 Mdot
.67487 .54045 Mdot
.65552 .54555 Mdot
.45412 .66772 Mdot
.41689 .65906 Mdot
.73186 .52151 Mdot
.34994 .42113 Mdot
.57273 .3456 Mdot
.30038 .55178 Mdot
.56742 .32656 Mdot
.70594 .51167 Mdot
.50767 .56109 Mdot
.67682 .48838 Mdot
.51584 .58122 Mdot
.75372 .31829 Mdot
.47412 .68588 Mdot
.70247 .57386 Mdot
.44562 .44836 Mdot
.42946 .3025 Mdot
.43322 .29615 Mdot
.5069 .49644 Mdot
.71906 .51195 Mdot
.51483 .54144 Mdot
.3481 .39599 Mdot
.79263 .4647 Mdot
.73275 .52169 Mdot
.43881 .307 Mdot
.40711 .34375 Mdot
.61883 .33395 Mdot
.45202 .63572 Mdot
.46876 .67029 Mdot
.39443 .33643 Mdot
.60585 .41257 Mdot
.66804 .50286 Mdot
.47696 .64732 Mdot
.51736 .60285 Mdot
.40147 .31688 Mdot
.54607 .32328 Mdot
.65338 .49277 Mdot
.49488 .60033 Mdot
.24466 .59712 Mdot
.59186 .31386 Mdot
.4656 .60697 Mdot
.41629 .67179 Mdot
.31815 .41986 Mdot
.29671 .66377 Mdot
.25693 .51504 Mdot
.57918 .31505 Mdot
.51134 .50135 Mdot
.49168 .62008 Mdot
.43008 .29573 Mdot
.50944 .66331 Mdot
.66416 .80785 Mdot
.51056 .48582 Mdot
.48348 .66198 Mdot
.51216 .69649 Mdot
.70508 .53246 Mdot
.48016 .64429 Mdot
.64914 .30372 Mdot
.4134 .32759 Mdot
.4828 .66448 Mdot
.55853 .65514 Mdot
.61796 .33288 Mdot
.50872 .54317 Mdot
.3313 .42555 Mdot
.40977 .53584 Mdot
.30685 .74427 Mdot
.41292 .35283 Mdot
.31498 .40048 Mdot
.44334 .64369 Mdot
.44985 .28011 Mdot
.58122 .36513 Mdot
.5108 .52588 Mdot
.46096 .60673 Mdot
.5625 .35042 Mdot
.59354 .32178 Mdot
.33201 .41825 Mdot
.86282 .46691 Mdot
.46499 .69145 Mdot
.46478 .6598 Mdot
.84514 .50932 Mdot
.7125 .55724 Mdot
.45926 .65565 Mdot
.43501 .65023 Mdot
.58042 .34438 Mdot
.26114 .48231 Mdot
.30031 .66024 Mdot
.47463 .45836 Mdot
.58227 .3196 Mdot
.45664 .29359 Mdot
.40408 .33435 Mdot
.30968 .4061 Mdot
.69358 .51995 Mdot
.33624 .43577 Mdot
.40969 .31458 Mdot
.46722 .63377 Mdot
.58027 .35481 Mdot
.48269 .77628 Mdot
.6008 .31524 Mdot
.43083 .34158 Mdot
.64239 .52681 Mdot
.62108 .78649 Mdot
.6872 .79745 Mdot
.57467 .50766 Mdot
.62563 .36799 Mdot
.32166 .42277 Mdot
.80813 .55423 Mdot
.44225 .6684 Mdot
.68025 .73915 Mdot
.46094 .65987 Mdot
.50135 .46627 Mdot
.41672 .27689 Mdot
.5137 .50581 Mdot
.51661 .58121 Mdot
.30523 .66057 Mdot
.58703 .32337 Mdot
.61458 .34539 Mdot
.51239 .57752 Mdot
.59269 .34139 Mdot
.47744 .66534 Mdot
.40137 .30667 Mdot
.80135 .36991 Mdot
.44197 .67076 Mdot
.52432 .65532 Mdot
.55365 .36287 Mdot
.76977 .49538 Mdot
.45572 .31089 Mdot
.67692 .71041 Mdot
.67794 .2974 Mdot
.60845 .3385 Mdot
.719 .69013 Mdot
.42113 .32827 Mdot
.49332 .50919 Mdot
.44421 .26732 Mdot
.46571 .66432 Mdot
.48189 .61785 Mdot
.51629 .61735 Mdot
.43769 .65016 Mdot
.635 .75191 Mdot
.41954 .68527 Mdot
.57611 .67838 Mdot
.47023 .68337 Mdot
.62704 .55507 Mdot
.59709 .36055 Mdot
.51055 .57168 Mdot
.32503 .53232 Mdot
.48842 .672 Mdot
.72264 .53394 Mdot
.56628 .33671 Mdot
.66746 .27344 Mdot
.59628 .32569 Mdot
.42389 .29197 Mdot
.58263 .32937 Mdot
.4201 .65668 Mdot
.70435 .52696 Mdot
.41854 .31159 Mdot
.50606 .53851 Mdot
.43987 .32306 Mdot
.48383 .6681 Mdot
.54098 .3096 Mdot
.41731 .33701 Mdot
.40942 .67401 Mdot
.70217 .52976 Mdot
.22608 .62564 Mdot
.65881 .48429 Mdot
.47047 .64147 Mdot
.46444 .64698 Mdot
.51245 .48371 Mdot
.58012 .33563 Mdot
.67098 .49045 Mdot
.50543 .33414 Mdot
.32306 .44266 Mdot
.69498 .51402 Mdot
.50628 .71089 Mdot
.29326 .59892 Mdot
.69192 .54279 Mdot
.31101 .68659 Mdot
.59349 .34681 Mdot
.71098 .53247 Mdot
.47972 .72685 Mdot
.57501 .74166 Mdot
.34446 .4038 Mdot
.41275 .26923 Mdot
.2924 .61302 Mdot
.40716 .33359 Mdot
.64779 .29474 Mdot
.40903 .26921 Mdot
.61416 .32473 Mdot
.51861 .70883 Mdot
.3725 .58751 Mdot
.62479 .32029 Mdot
.54713 .29913 Mdot
.40509 .32475 Mdot
.51735 .59331 Mdot
.44986 .48369 Mdot
.52153 .53489 Mdot
.52084 .55878 Mdot
.5863 .31273 Mdot
.71287 .53161 Mdot
.71476 .48924 Mdot
.52022 .68706 Mdot
.68214 .53694 Mdot
.4122 .30141 Mdot
.32632 .57527 Mdot
.72763 .66802 Mdot
.61129 .35313 Mdot
.43465 .49562 Mdot
.48337 .60699 Mdot
.40816 .28708 Mdot
.41327 .29758 Mdot
.5905 .32367 Mdot
.60792 .72952 Mdot
.51866 .542 Mdot
.67658 .56253 Mdot
.7125 .51917 Mdot
.7056 .53307 Mdot
.65984 .51909 Mdot
.26091 .49541 Mdot
.58545 .31907 Mdot
.71843 .51457 Mdot
.48805 .68912 Mdot
.44541 .63853 Mdot
.49757 .50289 Mdot
.36143 .40217 Mdot
.41819 .68091 Mdot
.51523 .54065 Mdot
.45638 .66855 Mdot
.42913 .30803 Mdot
.51151 .72493 Mdot
.50439 .48262 Mdot
.42979 .32002 Mdot
.43114 .31152 Mdot
.51019 .49595 Mdot
.50878 .72442 Mdot
.57866 .77563 Mdot
.47002 .59685 Mdot
.63776 .54487 Mdot
.43488 .29325 Mdot
.48081 .36656 Mdot
.68953 .57409 Mdot
.45832 .62493 Mdot
.4668 .45099 Mdot
.40545 .30058 Mdot
.72434 .53576 Mdot
.47101 .65988 Mdot
.49742 .52979 Mdot
.34406 .41061 Mdot
.50792 .53565 Mdot
.4945 .52695 Mdot
.66617 .51497 Mdot
.46663 .25585 Mdot
.70089 .54428 Mdot
.38194 .31533 Mdot
.50728 .54918 Mdot
.84653 .36955 Mdot
.42701 .28026 Mdot
.79326 .45699 Mdot
.3761 .58206 Mdot
.46242 .67633 Mdot
.41523 .33077 Mdot
.73054 .48783 Mdot
.60211 .31105 Mdot
.33299 .63873 Mdot
.6737 .5249 Mdot
.49368 .50131 Mdot
.49981 .50526 Mdot
.40191 .31949 Mdot
.70413 .50163 Mdot
.41626 .66847 Mdot
.69305 .53606 Mdot
.58762 .35727 Mdot
.49794 .5838 Mdot
.68324 .30548 Mdot
.51211 .56939 Mdot
.68178 .53907 Mdot
.4344 .33461 Mdot
.30174 .41763 Mdot
.43518 .67047 Mdot
.67243 .27754 Mdot
.44336 .64309 Mdot
.62045 .33682 Mdot
.43388 .4552 Mdot
.50843 .75951 Mdot
.44915 .64755 Mdot
.47713 .60941 Mdot
.55086 .33695 Mdot
.44837 .65088 Mdot
.49809 .64832 Mdot
.7713 .58361 Mdot
.68593 .54334 Mdot
.44355 .66825 Mdot
.39301 .32535 Mdot
.56654 .66089 Mdot
.48533 .6429 Mdot
.65155 .30845 Mdot
.28498 .67127 Mdot
.42304 .45206 Mdot
.52567 .67161 Mdot
.25074 .61651 Mdot
.46417 .65172 Mdot
.45224 .62846 Mdot
.49834 .58181 Mdot
.66668 .73496 Mdot
.40991 .31991 Mdot
.44631 .29109 Mdot
.30534 .40967 Mdot
.30096 .67066 Mdot
.33831 .40889 Mdot
.58049 .36544 Mdot
.41545 .52461 Mdot
.50455 .47886 Mdot
.67268 .52073 Mdot
.47773 .63179 Mdot
.4427 .32237 Mdot
.47068 .6671 Mdot
.47639 .59927 Mdot
.40923 .30532 Mdot
.41109 .29473 Mdot
.37964 .35364 Mdot
.33022 .42792 Mdot
.68581 .51156 Mdot
.44647 .68143 Mdot
.33502 .42577 Mdot
.51615 .61244 Mdot
.28893 .55829 Mdot
.68873 .51026 Mdot
.67893 .5383 Mdot
.71139 .49343 Mdot
.42912 .66016 Mdot
.49534 .58385 Mdot
.57186 .36078 Mdot
.66189 .54149 Mdot
.60451 .34435 Mdot
.41377 .33194 Mdot
.39634 .30783 Mdot
.46475 .66438 Mdot
.49394 .71196 Mdot
.329 .39395 Mdot
.41191 .33945 Mdot
.49265 .49127 Mdot
.30755 .42387 Mdot
.48069 .62232 Mdot
.40978 .33365 Mdot
.35133 .38856 Mdot
.59898 .73979 Mdot
.67985 .36243 Mdot
.30416 .41586 Mdot
.51893 .57975 Mdot
.67861 .61233 Mdot
.24475 .57835 Mdot
.30963 .4406 Mdot
.59782 .35996 Mdot
.43127 .64704 Mdot
.48215 .4626 Mdot
.31435 .43533 Mdot
.25113 .52875 Mdot
.41229 .30895 Mdot
.52035 .56235 Mdot
.56677 .53288 Mdot
.72424 .66866 Mdot
.3015 .42015 Mdot
.68276 .53997 Mdot
.65396 .52528 Mdot
.45701 .63778 Mdot
.41055 .53302 Mdot
.62851 .3394 Mdot
.38417 .3128 Mdot
.44732 .2989 Mdot
.65125 .50718 Mdot
.31657 .56979 Mdot
.39479 .32905 Mdot
.44054 .63735 Mdot
.36777 .37843 Mdot
.49852 .68411 Mdot
.37359 .46954 Mdot
.497 .75905 Mdot
.52089 .69292 Mdot
.30236 .4178 Mdot
.62712 .33884 Mdot
.60529 .32053 Mdot
.58542 .33211 Mdot
.39666 .32391 Mdot
.29625 .62128 Mdot
.44868 .29264 Mdot
.83687 .526 Mdot
.31603 .42665 Mdot
.1787 .44224 Mdot
.46617 .69715 Mdot
.46672 .67656 Mdot
.50472 .6497 Mdot
.51499 .59601 Mdot
.46548 .65147 Mdot
.56238 .3534 Mdot
.42046 .26924 Mdot
.54142 .37989 Mdot
.68277 .49725 Mdot
.81633 .54932 Mdot
.42755 .30277 Mdot
.49472 .53406 Mdot
.33136 .39491 Mdot
.25478 .65186 Mdot
.34215 .38026 Mdot
.39084 .34111 Mdot
.4938 .64435 Mdot
.70211 .47626 Mdot
.18418 .52996 Mdot
.47952 .63832 Mdot
.40454 .34176 Mdot
.45414 .30146 Mdot
.58891 .73346 Mdot
.42541 .59328 Mdot
.57052 .40431 Mdot
.31419 .59495 Mdot
.32541 .3878 Mdot
.52166 .59532 Mdot
.27794 .64982 Mdot
.40834 .31588 Mdot
.43901 .28417 Mdot
.29831 .44153 Mdot
.77055 .48758 Mdot
.71562 .50673 Mdot
.63908 .49896 Mdot
.56494 .3507 Mdot
.46435 .67878 Mdot
.40501 .32922 Mdot
.64092 .50744 Mdot
.30172 .51999 Mdot
.59295 .33408 Mdot
.41875 .33765 Mdot
.44082 .64501 Mdot
.44816 .64675 Mdot
.33777 .41137 Mdot
.44731 .45301 Mdot
.5213 .53505 Mdot
.79236 .46288 Mdot
.29803 .58636 Mdot
.3763 .5811 Mdot
.45657 .67047 Mdot
.66128 .51903 Mdot
.50941 .49547 Mdot
.34018 .39438 Mdot
.50822 .6667 Mdot
.65983 .76723 Mdot
.70666 .54684 Mdot
.60376 .34342 Mdot
.50254 .53299 Mdot
.31218 .65523 Mdot
.44005 .64653 Mdot
.46141 .66019 Mdot
.49448 .60175 Mdot
.60039 .79089 Mdot
.42361 .27376 Mdot
.66612 .52763 Mdot
.3293 .42586 Mdot
.68504 .53161 Mdot
.38134 .31159 Mdot
.43767 .49013 Mdot
.43039 .67293 Mdot
.71411 .54212 Mdot
.6951 .52883 Mdot
.6197 .33828 Mdot
.59931 .31786 Mdot
.43092 .34703 Mdot
.43295 .65371 Mdot
.50545 .47748 Mdot
.7167 .51997 Mdot
.40255 .28084 Mdot
.33643 .41077 Mdot
.65142 .29649 Mdot
.46469 .68329 Mdot
.40482 .32028 Mdot
.51115 .54354 Mdot
.67808 .50376 Mdot
.42571 .32273 Mdot
.49303 .51072 Mdot
.35586 .41143 Mdot
.48556 .61719 Mdot
.40147 .23191 Mdot
.49688 .53298 Mdot
.43699 .67037 Mdot
.532 .72648 Mdot
.41204 .53111 Mdot
.49291 .48478 Mdot
.39314 .30701 Mdot
.49719 .5197 Mdot
.65565 .51436 Mdot
.56036 .74892 Mdot
.43808 .28 Mdot
.61611 .57061 Mdot
.36726 .59533 Mdot
.51436 .57839 Mdot
.6692 .52099 Mdot
.42625 .39819 Mdot
.76402 .46322 Mdot
.2481 .57335 Mdot
.48201 .65726 Mdot
.40678 .33344 Mdot
.34358 .40771 Mdot
.61367 .3457 Mdot
.64097 .33207 Mdot
.40192 .40862 Mdot
.43613 .30786 Mdot
.47833 .63164 Mdot
.71276 .5311 Mdot
.59983 .34274 Mdot
.59678 .60093 Mdot
.4513 .28922 Mdot
.39179 .3264 Mdot
.49844 .61172 Mdot
.33842 .40748 Mdot
.47611 .49536 Mdot
.43163 .27263 Mdot
.42851 .2669 Mdot
.76669 .58589 Mdot
.3286 .38676 Mdot
.49236 .59974 Mdot
.51944 .68996 Mdot
.50099 .65786 Mdot
.82593 .53685 Mdot
.49506 .51128 Mdot
.68162 .49694 Mdot
.45829 .64983 Mdot
.43643 .23826 Mdot
.42075 .27965 Mdot
.31431 .59463 Mdot
.54214 .34412 Mdot
.59033 .3204 Mdot
.41479 .32458 Mdot
.4766 .65862 Mdot
.64947 .32732 Mdot
.30965 .4079 Mdot
.49632 .59851 Mdot
.51382 .58015 Mdot
.64945 .51785 Mdot
.57866 .35543 Mdot
.55889 .67467 Mdot
.60612 .35139 Mdot
.57643 .34298 Mdot
.74974 .49259 Mdot
.45779 .63687 Mdot
.42613 .30982 Mdot
.41317 .34657 Mdot
.52037 .61955 Mdot
.48498 .3517 Mdot
.70535 .49422 Mdot
.46311 .28143 Mdot
.64652 .77686 Mdot
.48301 .68822 Mdot
.49873 .54399 Mdot
.49471 .46334 Mdot
.62922 .36287 Mdot
.45299 .64581 Mdot
.66998 .51587 Mdot
.42755 .26911 Mdot
.40145 .33172 Mdot
.40954 .67187 Mdot
.60397 .31994 Mdot
.35981 .39309 Mdot
.41543 .29863 Mdot
.30628 .5515 Mdot
.48438 .66104 Mdot
.56408 .37433 Mdot
.41746 .29982 Mdot
.2168 .67567 Mdot
.44526 .23744 Mdot
.69899 .53969 Mdot
.4765 .61174 Mdot
.66083 .48721 Mdot
.31422 .39879 Mdot
.43281 .25899 Mdot
.62276 .3359 Mdot
.50585 .54354 Mdot
.62663 .22859 Mdot
.39976 .32583 Mdot
.6837 .52154 Mdot
.46492 .63709 Mdot
.71167 .69347 Mdot
.4406 .66853 Mdot
.26095 .47969 Mdot
.3128 .43773 Mdot
.64121 .29253 Mdot
.62183 .32737 Mdot
.47236 .61166 Mdot
.34545 .41827 Mdot
.40772 .34959 Mdot
.40879 .30663 Mdot
.65545 .24767 Mdot
.49348 .51969 Mdot
.42652 .25314 Mdot
.43414 .66679 Mdot
.38793 .30368 Mdot
.69786 .60627 Mdot
.59551 .32042 Mdot
.50092 .65345 Mdot
.42579 .33378 Mdot
.76571 .47177 Mdot
.3051 .59672 Mdot
.48374 .65806 Mdot
.50383 .70401 Mdot
.61355 .32567 Mdot
.8087 .5563 Mdot
.41267 .27933 Mdot
.51062 .62931 Mdot
.56474 .36289 Mdot
.51734 .70918 Mdot
.55481 .3987 Mdot
.68605 .51115 Mdot
.41094 .34433 Mdot
.57232 .34713 Mdot
.51466 .56552 Mdot
.35253 .39117 Mdot
.44674 .32486 Mdot
.43525 .32635 Mdot
.44938 .61158 Mdot
.51278 .60362 Mdot
.49845 .71125 Mdot
.67324 .49533 Mdot
.58412 .34714 Mdot
.48146 .59814 Mdot
.2844 .55868 Mdot
.50423 .59319 Mdot
.58214 .34923 Mdot
.85026 .41263 Mdot
.49321 .6377 Mdot
.46546 .68247 Mdot
.70366 .70628 Mdot
.68771 .48378 Mdot
.66257 .53457 Mdot
.29164 .58021 Mdot
.43231 .63396 Mdot
.40248 .55392 Mdot
.68343 .51437 Mdot
.68551 .52409 Mdot
.40339 .55226 Mdot
.45596 .60667 Mdot
.6557 .48399 Mdot
.59741 .34248 Mdot
.59179 .31969 Mdot
.70447 .53311 Mdot
.50641 .65591 Mdot
.60115 .36226 Mdot
.6197 .71705 Mdot
.39887 .344 Mdot
.28356 .65397 Mdot
.69517 .53222 Mdot
.30482 .60122 Mdot
.59258 .34552 Mdot
.27901 .70573 Mdot
.2871 .68253 Mdot
.47155 .69256 Mdot
.45354 .64179 Mdot
.32098 .41874 Mdot
.5082 .54026 Mdot
.50914 .49255 Mdot
.58463 .33222 Mdot
.47009 .48897 Mdot
.69428 .50781 Mdot
.42936 .64028 Mdot
.25127 .5564 Mdot
.32299 .75248 Mdot
.42033 .73036 Mdot
.69231 .52125 Mdot
.70279 .51409 Mdot
.38886 .32213 Mdot
.38327 .33283 Mdot
.44154 .6798 Mdot
.61009 .32197 Mdot
.70633 .53534 Mdot
.58504 .35227 Mdot
.40883 .31425 Mdot
.42609 .30113 Mdot
.50253 .48599 Mdot
.5197 .55664 Mdot
.41526 .31803 Mdot
.65134 .31296 Mdot
.28507 .55877 Mdot
.65225 .53383 Mdot
.84329 .51735 Mdot
.26955 .69528 Mdot
.74458 .67963 Mdot
.34413 .40912 Mdot
.507 .72575 Mdot
.56337 .35998 Mdot
.47164 .61116 Mdot
.45599 .66093 Mdot
.50338 .51452 Mdot
.56106 .35996 Mdot
.31478 .40984 Mdot
.59263 .32044 Mdot
.35406 .39594 Mdot
.44524 .29652 Mdot
.48139 .63689 Mdot
.49046 .66101 Mdot
.61538 .34337 Mdot
.38761 .32943 Mdot
.41982 .33476 Mdot
.34617 .40026 Mdot
.25791 .65602 Mdot
.40306 .31843 Mdot
.6943 .53161 Mdot
.6209 .58729 Mdot
.5001 .50727 Mdot
.47159 .65897 Mdot
.25069 .62042 Mdot
.552 .75129 Mdot
.51695 .61806 Mdot
.50229 .53117 Mdot
.86271 .46331 Mdot
.48856 .65522 Mdot
.61811 .20582 Mdot
.50277 .48114 Mdot
.67791 .48776 Mdot
.4238 .31755 Mdot
.49552 .53446 Mdot
.52744 .69688 Mdot
.35102 .34398 Mdot
.51744 .62464 Mdot
.71643 .50749 Mdot
.70455 .48799 Mdot
.43871 .49069 Mdot
.82686 .54092 Mdot
.33109 .42483 Mdot
.31026 .4136 Mdot
.42897 .27574 Mdot
.64625 .28972 Mdot
.48007 .69711 Mdot
.31181 .41951 Mdot
.68723 .46642 Mdot
.49294 .60484 Mdot
.41708 .52463 Mdot
.45372 .4809 Mdot
.65654 .52092 Mdot
.45536 .60089 Mdot
.42617 .27686 Mdot
.68506 .51999 Mdot
.44519 .48688 Mdot
.50155 .62632 Mdot
.69086 .50906 Mdot
.57874 .341 Mdot
.38805 .61383 Mdot
.68984 .53669 Mdot
.3354 .6334 Mdot
.61186 .33706 Mdot
.42376 .51415 Mdot
.20383 .44881 Mdot
.24553 .72838 Mdot
.59839 .32184 Mdot
.41217 .33796 Mdot
.4057 .32805 Mdot
.40053 .31363 Mdot
.6644 .50675 Mdot
.41523 .28784 Mdot
.69691 .4946 Mdot
.62284 .37112 Mdot
.30305 .66558 Mdot
.32983 .41491 Mdot
.44754 .3833 Mdot
.7018 .53407 Mdot
.83327 .52922 Mdot
.80858 .69517 Mdot
.50644 .59456 Mdot
.62395 .31929 Mdot
.31531 .4321 Mdot
.32176 .58957 Mdot
.31842 .41912 Mdot
.42066 .32874 Mdot
.3084 .65797 Mdot
.476 .66705 Mdot
.67315 .35337 Mdot
.34287 .40688 Mdot
.68524 .5254 Mdot
.42878 .63321 Mdot
.38568 .34456 Mdot
.3129 .40141 Mdot
.3398 .40059 Mdot
.46644 .65285 Mdot
.69168 .48509 Mdot
.42172 .33106 Mdot
.55957 .34884 Mdot
.37644 .38432 Mdot
.45066 .71123 Mdot
.48812 .64693 Mdot
.4844 .68125 Mdot
.29776 .5952 Mdot
.65027 .29064 Mdot
.60939 .3351 Mdot
.25398 .5274 Mdot
.40435 .29201 Mdot
.24535 .57013 Mdot
.76909 .45765 Mdot
.42861 .39162 Mdot
.49544 .51154 Mdot
.49433 .50557 Mdot
.47736 .64409 Mdot
.73458 .75839 Mdot
.41521 .59455 Mdot
.59332 .36478 Mdot
.5039 .50733 Mdot
.38772 .34068 Mdot
.68168 .54777 Mdot
.5591 .52113 Mdot
.43976 .69226 Mdot
.55912 .34985 Mdot
.40539 .31152 Mdot
.6552 .81668 Mdot
.32283 .42714 Mdot
.32046 .58677 Mdot
.43438 .6535 Mdot
.47459 .64812 Mdot
.59845 .33123 Mdot
.62304 .34131 Mdot
.76528 .58822 Mdot
.4171 .45122 Mdot
.68628 .30554 Mdot
.59737 .30698 Mdot
.65194 .8203 Mdot
.497 .466 Mdot
.7006 .50438 Mdot
.51202 .50193 Mdot
.62698 .3348 Mdot
.4585 .65368 Mdot
.68816 .48432 Mdot
.51131 .52374 Mdot
.72173 .48713 Mdot
.40816 .53779 Mdot
.30049 .55231 Mdot
.45413 .6352 Mdot
.68235 .47884 Mdot
.6872 .51573 Mdot
.65353 .5508 Mdot
.50355 .49524 Mdot
.45247 .66883 Mdot
.5111 .63393 Mdot
.47622 .68313 Mdot
.74329 .59621 Mdot
.48114 .64536 Mdot
.7712 .46025 Mdot
.29655 .57258 Mdot
.35288 .21484 Mdot
.48702 .6665 Mdot
.57634 .33647 Mdot
.47438 .63325 Mdot
.34714 .41746 Mdot
.49135 .62308 Mdot
.39871 .55088 Mdot
.60022 .33965 Mdot
.67774 .74846 Mdot
.36338 .36408 Mdot
.48854 .64324 Mdot
.34181 .38604 Mdot
.79335 .41555 Mdot
.25547 .53029 Mdot
.76727 .58337 Mdot
.69359 .53571 Mdot
.4451 .27187 Mdot
.62971 .33727 Mdot
.42484 .29304 Mdot
.41415 .66015 Mdot
.50956 .48791 Mdot
.16828 .44036 Mdot
.27045 .57546 Mdot
.45862 .65126 Mdot
.52025 .54251 Mdot
.67262 .53479 Mdot
.42348 .27906 Mdot
.77281 .63923 Mdot
.50427 .63713 Mdot
.34783 .42428 Mdot
.32655 .43331 Mdot
.29498 .39085 Mdot
.75123 .5404 Mdot
.71928 .59963 Mdot
.60004 .33219 Mdot
.397 .32638 Mdot
.31072 .43256 Mdot
.64068 .48873 Mdot
.6263 .32717 Mdot
.62812 .36318 Mdot
.57545 .35453 Mdot
.47895 .67506 Mdot
.49909 .49103 Mdot
.76474 .53334 Mdot
.49498 .52221 Mdot
.50063 .66929 Mdot
.43483 .32633 Mdot
.49398 .51371 Mdot
.32587 .41262 Mdot
.57386 .34465 Mdot
.42857 .30506 Mdot
.46684 .64336 Mdot
.67958 .51315 Mdot
.37713 .4781 Mdot
.41392 .24108 Mdot
.41225 .53023 Mdot
.41236 .53005 Mdot
.67 .55312 Mdot
.4858 .4687 Mdot
.53434 .31417 Mdot
.58052 .7412 Mdot
.38457 .3907 Mdot
.47838 .70514 Mdot
.48815 .33938 Mdot
.44898 .29078 Mdot
.41777 .30903 Mdot
.47437 .67123 Mdot
.39588 .29181 Mdot
.42891 .65182 Mdot
.39301 .30616 Mdot
.79111 .47966 Mdot
.41862 .67853 Mdot
.41319 .30309 Mdot
.51394 .5227 Mdot
.43674 .67148 Mdot
.66762 .52728 Mdot
.44304 .27321 Mdot
.47195 .69253 Mdot
.25762 .26281 Mdot
.61921 .3391 Mdot
.50216 .49678 Mdot
.34979 .561 Mdot
.58638 .34226 Mdot
.71076 .50283 Mdot
.43402 .64133 Mdot
.31156 .4244 Mdot
.70508 .51054 Mdot
.32927 .37116 Mdot
.33878 .40458 Mdot
.32572 .57192 Mdot
.70903 .52011 Mdot
.4986 .50979 Mdot
.34787 .42271 Mdot
.52028 .61679 Mdot
.41555 .30784 Mdot
.42362 .23901 Mdot
.49872 .53845 Mdot
.47244 .66833 Mdot
.38744 .34399 Mdot
.58487 .32549 Mdot
.47908 .62544 Mdot
.40421 .33032 Mdot
.50998 .51038 Mdot
.44998 .67932 Mdot
.42717 .64005 Mdot
.80121 .56025 Mdot
.44124 .44941 Mdot
.32816 .41393 Mdot
.64283 .52704 Mdot
.49008 .68579 Mdot
.3473 .41403 Mdot
.42563 .24343 Mdot
.50198 .57697 Mdot
.71698 .52931 Mdot
.61171 .71897 Mdot
.38464 .31308 Mdot
.61079 .31963 Mdot
.4303 .34103 Mdot
.31201 .39928 Mdot
.84233 .66016 Mdot
.50792 .49034 Mdot
.47069 .59543 Mdot
.49734 .65842 Mdot
.43883 .26202 Mdot
.68994 .51386 Mdot
.69425 .31359 Mdot
.48518 .61628 Mdot
.49693 .56622 Mdot
.4692 .65619 Mdot
.37956 .25857 Mdot
.66749 .49867 Mdot
.47006 .65822 Mdot
.50075 .69999 Mdot
.49519 .67206 Mdot
.33572 .38961 Mdot
.18017 .45052 Mdot
.51205 .58883 Mdot
.84362 .3487 Mdot
.51171 .51443 Mdot
.40654 .30461 Mdot
.33636 .63135 Mdot
.35042 .55475 Mdot
.29951 .25749 Mdot
.70812 .49848 Mdot
.63597 .54237 Mdot
.42526 .30129 Mdot
.41149 .40005 Mdot
.47917 .49368 Mdot
.43185 .63006 Mdot
.43466 .64847 Mdot
.42075 .3286 Mdot
.40495 .2779 Mdot
.51353 .50022 Mdot
.52273 .57818 Mdot
.49045 .58101 Mdot
.43526 .33238 Mdot
.48199 .64281 Mdot
.54233 .7524 Mdot
.62408 .31667 Mdot
.6941 .54139 Mdot
.61276 .34795 Mdot
.61316 .3112 Mdot
.75617 .66957 Mdot
.29578 .58791 Mdot
.56452 .35165 Mdot
.57462 .36825 Mdot
.42822 .39993 Mdot
.72415 .674 Mdot
.34046 .38909 Mdot
.4148 .59301 Mdot
.39905 .30507 Mdot
.45116 .66772 Mdot
.66591 .50007 Mdot
.31968 .46579 Mdot
.71114 .31687 Mdot
.41483 .76582 Mdot
.48938 .60114 Mdot
.4088 .28918 Mdot
.49896 .54017 Mdot
.51068 .57273 Mdot
.24495 .57585 Mdot
.48009 .65092 Mdot
.38307 .31595 Mdot
.72685 .66863 Mdot
.58628 .40505 Mdot
.64708 .33459 Mdot
.69656 .56516 Mdot
.47492 .63249 Mdot
.67024 .50143 Mdot
.57303 .32243 Mdot
.34335 .41694 Mdot
.32321 .42298 Mdot
.48863 .64231 Mdot
.37628 .58206 Mdot
.38098 .38097 Mdot
.42689 .63831 Mdot
.45974 .60452 Mdot
.49822 .52016 Mdot
.46992 .59815 Mdot
.51163 .64169 Mdot
.47739 .60209 Mdot
.5161 .60876 Mdot
.62584 .32825 Mdot
.75443 .65709 Mdot
.51319 .57562 Mdot
.42076 .66639 Mdot
.58243 .31715 Mdot
.41619 .66047 Mdot
.5946 .32587 Mdot
.64531 .27812 Mdot
.56837 .3573 Mdot
.32608 .42157 Mdot
.38049 .33747 Mdot
.79493 .56796 Mdot
.70769 .5339 Mdot
.58965 .31832 Mdot
.35993 .40262 Mdot
.58785 .32701 Mdot
.39396 .3139 Mdot
.61402 .40227 Mdot
.72355 .55176 Mdot
.31213 .55211 Mdot
.72592 .6847 Mdot
.54647 .37014 Mdot
.38873 .30601 Mdot
.70677 .53248 Mdot
.64898 .30179 Mdot
.46903 .61247 Mdot
.32444 .42773 Mdot
.47638 .64395 Mdot
.57491 .34381 Mdot
.40185 .29957 Mdot
.78463 .57121 Mdot
.32694 .41475 Mdot
.8508 .5038 Mdot
.44225 .32403 Mdot
.49686 .64307 Mdot
.58387 .31567 Mdot
.64527 .31291 Mdot
.6204 .33369 Mdot
.29516 .66654 Mdot
.49065 .46492 Mdot
.35885 .46102 Mdot
.70557 .51686 Mdot
.50229 .47193 Mdot
.33293 .7936 Mdot
.7539 .40615 Mdot
.67687 .50817 Mdot
.42096 .25045 Mdot
.48602 .65906 Mdot
.4901 .59774 Mdot
.51769 .55216 Mdot
.70674 .48229 Mdot
.49455 .60191 Mdot
.5002 .49584 Mdot
.28452 .58241 Mdot
.70806 .56462 Mdot
.45155 .31217 Mdot
.43188 .65929 Mdot
.58527 .31313 Mdot
.59769 .31483 Mdot
.49931 .48014 Mdot
.59605 .35568 Mdot
.42252 .65959 Mdot
.70554 .52782 Mdot
.44908 .48388 Mdot
.30992 .40325 Mdot
.78189 .44608 Mdot
.32003 .38215 Mdot
.36468 .38219 Mdot
.48061 .69027 Mdot
.42626 .30487 Mdot
.61357 .21705 Mdot
.47761 .60785 Mdot
.68337 .51699 Mdot
.49853 .64943 Mdot
.48704 .59671 Mdot
.41903 .64648 Mdot
.39716 .32603 Mdot
.30385 .59823 Mdot
.48167 .64187 Mdot
.5641 .33425 Mdot
.39824 .55811 Mdot
.43176 .68894 Mdot
.47497 .45131 Mdot
.40254 .54573 Mdot
.57673 .37828 Mdot
.65092 .52727 Mdot
.42536 .31136 Mdot
.69732 .50808 Mdot
.73309 .50096 Mdot
.71026 .50251 Mdot
.75822 .52785 Mdot
.5729 .74502 Mdot
.61363 .20033 Mdot
.70346 .6049 Mdot
.72754 .6867 Mdot
.73515 .50991 Mdot
.48831 .18616 Mdot
.67282 .51081 Mdot
.71002 .50148 Mdot
.77991 .3399 Mdot
.69699 .48856 Mdot
.46458 .66507 Mdot
.48946 .67085 Mdot
.61728 .78669 Mdot
.37514 .4116 Mdot
.44537 .67442 Mdot
.51679 .61249 Mdot
.3182 .43441 Mdot
.77084 .48851 Mdot
.50425 .53796 Mdot
.32437 .58649 Mdot
.49125 .5071 Mdot
.46644 .65203 Mdot
.46876 .62562 Mdot
.42224 .68823 Mdot
.34954 .77193 Mdot
.388 .4306 Mdot
.70792 .48909 Mdot
.49987 .69573 Mdot
.53737 .36795 Mdot
.4565 .62778 Mdot
.49848 .63157 Mdot
.42193 .63738 Mdot
.42616 .30968 Mdot
.6935 .54932 Mdot
.51874 .53628 Mdot
.78031 .42851 Mdot
.44158 .6464 Mdot
.29717 .40763 Mdot
.34647 .43013 Mdot
.47589 .65975 Mdot
.70502 .49178 Mdot
.49056 .59868 Mdot
.67046 .54192 Mdot
.7089 .51564 Mdot
.49863 .57005 Mdot
.76576 .514 Mdot
.68578 .54817 Mdot
.43255 .62939 Mdot
.38689 .32516 Mdot
.79293 .46082 Mdot
.47378 .66662 Mdot
.32963 .40784 Mdot
.4562 .64211 Mdot
.33552 .38866 Mdot
.51092 .58364 Mdot
.49608 .52203 Mdot
.49303 .77201 Mdot
.44049 .28529 Mdot
.3457 .37886 Mdot
.39189 .29691 Mdot
.48276 .69791 Mdot
.70907 .47202 Mdot
.59797 .40609 Mdot
.39949 .39374 Mdot
.49784 .5184 Mdot
.26253 .49972 Mdot
.41903 .53846 Mdot
.57469 .36224 Mdot
.66462 .52683 Mdot
.74674 .65252 Mdot
.47225 .45246 Mdot
.44962 .32004 Mdot
.40138 .34495 Mdot
.54563 .39321 Mdot
.80103 .36943 Mdot
.4863 .66682 Mdot
.48399 .45671 Mdot
.57146 .68598 Mdot
.50876 .53955 Mdot
.51636 .51287 Mdot
.4356 .32685 Mdot
.44393 .67385 Mdot
.27666 .59643 Mdot
.40631 .32439 Mdot
.31973 .40034 Mdot
.6804 .4969 Mdot
.35278 .40374 Mdot
.69736 .36118 Mdot
.77018 .58588 Mdot
.41252 .31961 Mdot
.5146 .60158 Mdot
.45403 .67591 Mdot
.67894 .48635 Mdot
.59645 .59972 Mdot
.68419 .54321 Mdot
.30658 .41997 Mdot
.43895 .2788 Mdot
.20586 .33438 Mdot
.46492 .63587 Mdot
.69376 .52783 Mdot
.36542 .36375 Mdot
.44684 .64904 Mdot
.60375 .31934 Mdot
.49461 .60269 Mdot
.68759 .53013 Mdot
.47684 .59426 Mdot
.70618 .51631 Mdot
.39204 .33148 Mdot
.49046 .6494 Mdot
.47908 .62271 Mdot
.25534 .52121 Mdot
.31529 .40996 Mdot
.68344 .5465 Mdot
.28921 .60759 Mdot
.50099 .65795 Mdot
.24558 .59382 Mdot
.48321 .6397 Mdot
.72041 .68551 Mdot
.51342 .69731 Mdot
.4986 .49838 Mdot
.49866 .65172 Mdot
.47572 .66518 Mdot
.59522 .59667 Mdot
.69198 .60794 Mdot
.74547 .59572 Mdot
.60529 .31708 Mdot
.66587 .52049 Mdot
.4093 .32713 Mdot
.44058 .27031 Mdot
.41862 .2884 Mdot
.29972 .43072 Mdot
.51692 .63219 Mdot
.46397 .67229 Mdot
.59581 .36569 Mdot
.31439 .42408 Mdot
.69641 .52208 Mdot
.33221 .41761 Mdot
.30266 .58911 Mdot
.32744 .40697 Mdot
.51058 .4942 Mdot
.46944 .25026 Mdot
.54869 .75048 Mdot
.33123 .39778 Mdot
.69866 .53908 Mdot
.3854 .577 Mdot
.49444 .55871 Mdot
.82004 .54483 Mdot
.33887 .43184 Mdot
.41992 .24867 Mdot
.44918 .68032 Mdot
.33006 .63358 Mdot
.59262 .32866 Mdot
.3534 .40368 Mdot
.57656 .35571 Mdot
.48842 .59966 Mdot
.63396 .54837 Mdot
.67785 .52285 Mdot
.62342 .31499 Mdot
.50035 .64 Mdot
.35315 .40473 Mdot
.41428 .31508 Mdot
.72336 .67348 Mdot
.63452 .35504 Mdot
.39062 .46287 Mdot
.2473 .57158 Mdot
.42532 .27556 Mdot
.70056 .68604 Mdot
.57316 .35783 Mdot
.49864 .69662 Mdot
.40775 .68664 Mdot
.50058 .67788 Mdot
.42134 .33333 Mdot
.41842 .30894 Mdot
.52462 .3113 Mdot
.47858 .6213 Mdot
.4781 .59163 Mdot
.6497 .53424 Mdot
.43383 .27468 Mdot
.71045 .50353 Mdot
.67672 .47923 Mdot
.41177 .33758 Mdot
.67468 .54198 Mdot
.33978 .40352 Mdot
.28147 .63002 Mdot
.5716 .35714 Mdot
.6193 .32453 Mdot
.41437 .31944 Mdot
.43908 .29748 Mdot
.42658 .30394 Mdot
.50301 .62073 Mdot
.71043 .51342 Mdot
.46652 .61674 Mdot
.47187 .63341 Mdot
.49033 .55351 Mdot
.65025 .49574 Mdot
.47936 .61273 Mdot
.4561 .48402 Mdot
.32814 .44004 Mdot
.41113 .30058 Mdot
.58931 .3501 Mdot
.36954 .48085 Mdot
.56068 .34262 Mdot
.49712 .67036 Mdot
.78816 .48675 Mdot
.66577 .51689 Mdot
.31937 .41898 Mdot
.39985 .54854 Mdot
.3242 .41697 Mdot
.62336 .31589 Mdot
.65474 .54693 Mdot
.32124 .57053 Mdot
.48285 .62249 Mdot
.29486 .59471 Mdot
.21889 .47265 Mdot
.76054 .45219 Mdot
.58289 .3456 Mdot
.49885 .59592 Mdot
.49679 .4932 Mdot
.58268 .74162 Mdot
.46857 .6718 Mdot
.44105 .69044 Mdot
.36783 .56688 Mdot
.49397 .67145 Mdot
.72201 .51494 Mdot
.42497 .51738 Mdot
.52036 .59684 Mdot
.49964 .68408 Mdot
.65866 .25467 Mdot
.45086 .67839 Mdot
.48413 .62673 Mdot
.45514 .66485 Mdot
.48584 .60687 Mdot
.65918 .48883 Mdot
.43139 .4977 Mdot
.57375 .32284 Mdot
.28107 .63004 Mdot
.56906 .3518 Mdot
.41789 .32389 Mdot
.40654 .45627 Mdot
.65612 .53061 Mdot
.32389 .41662 Mdot
.50031 .44157 Mdot
.31609 .65965 Mdot
.38862 .32305 Mdot
.25963 .49332 Mdot
.35903 .3937 Mdot
.51637 .52556 Mdot
.3147 .39648 Mdot
.42839 .33256 Mdot
.60184 .32031 Mdot
.49388 .64338 Mdot
.71596 .51633 Mdot
.68843 .53729 Mdot
.48986 .68931 Mdot
.79353 .43683 Mdot
.6131 .31951 Mdot
.47928 .35746 Mdot
.47781 .67347 Mdot
.50099 .65321 Mdot
.66543 .53753 Mdot
.41805 .28185 Mdot
.41933 .53691 Mdot
.34131 .39235 Mdot
.45074 .63317 Mdot
.51778 .59985 Mdot
.30125 .58979 Mdot
.6009 .31606 Mdot
.50711 .50193 Mdot
.44848 .67161 Mdot
.3063 .58231 Mdot
.49968 .60253 Mdot
.46984 .70392 Mdot
.38456 .3252 Mdot
.49796 .56771 Mdot
.47244 .62096 Mdot
.69883 .5652 Mdot
.5762 .35894 Mdot
.68776 .51209 Mdot
.69726 .55852 Mdot
.49641 .52035 Mdot
.61832 .33835 Mdot
.48984 .61012 Mdot
.63316 .33902 Mdot
.4879 .59768 Mdot
.471 .63888 Mdot
.581 .34386 Mdot
.70523 .50061 Mdot
.68688 .31189 Mdot
.75466 .65585 Mdot
.47712 .59929 Mdot
.45253 .64544 Mdot
.37508 .41155 Mdot
.30935 .46064 Mdot
.48286 .61885 Mdot
.70404 .5359 Mdot
.44853 .64582 Mdot
.61809 .35222 Mdot
.33364 .42293 Mdot
.67881 .51682 Mdot
.41371 .28076 Mdot
.3936 .33207 Mdot
.39097 .35855 Mdot
.51094 .49419 Mdot
.46596 .59882 Mdot
.6429 .52695 Mdot
.65372 .49073 Mdot
.3069 .62483 Mdot
.40747 .30402 Mdot
.34144 .41435 Mdot
.43073 .66338 Mdot
.51965 .51368 Mdot
.59389 .31337 Mdot
.84014 .33857 Mdot
.31904 .57189 Mdot
.32872 .44143 Mdot
.41674 .45915 Mdot
.50189 .52162 Mdot
.46238 .68067 Mdot
.34945 .41254 Mdot
.40913 .33678 Mdot
.49123 .59738 Mdot
.51564 .68915 Mdot
.41591 .24884 Mdot
.43359 .29912 Mdot
.63412 .33827 Mdot
.3989 .29656 Mdot
.35172 .3892 Mdot
.50861 .49191 Mdot
.67417 .53007 Mdot
.47907 .65618 Mdot
.51287 .57017 Mdot
.40093 .30733 Mdot
.50886 .47918 Mdot
.4886 .66873 Mdot
.66307 .51659 Mdot
.41128 .29333 Mdot
.46333 .65567 Mdot
.59098 .73 Mdot
.79514 .56509 Mdot
.40083 .29942 Mdot
.43807 .63859 Mdot
.56681 .53695 Mdot
.43246 .30288 Mdot
.42865 .33109 Mdot
.50606 .59513 Mdot
.35399 .40916 Mdot
.456 .63288 Mdot
.60918 .32267 Mdot
.2976 .59981 Mdot
.6165 .34219 Mdot
.24379 .57649 Mdot
.51046 .62123 Mdot
.41646 .71203 Mdot
.71914 .48195 Mdot
.34533 .37646 Mdot
.26639 .68708 Mdot
.48602 .68687 Mdot
.68106 .46009 Mdot
.30326 .60114 Mdot
.32673 .55621 Mdot
.63215 .48028 Mdot
.34989 .39323 Mdot
.58561 .33149 Mdot
.48583 .63557 Mdot
.67358 .30466 Mdot
.34758 .39464 Mdot
.24419 .57861 Mdot
.44619 .62626 Mdot
.68888 .52207 Mdot
.4814 .67013 Mdot
.67646 .52959 Mdot
.44626 .65756 Mdot
.80185 .55827 Mdot
.38144 .38277 Mdot
.29574 .66671 Mdot
.51453 .52976 Mdot
.64524 .3132 Mdot
.72622 .68496 Mdot
.33993 .40897 Mdot
.4821 .59278 Mdot
.50488 .51917 Mdot
.59218 .32055 Mdot
.6147 .41431 Mdot
.42542 .29973 Mdot
.56374 .33662 Mdot
.69658 .49988 Mdot
.39214 .3493 Mdot
.50594 .47636 Mdot
.45501 .74765 Mdot
.35279 .40759 Mdot
.61874 .33747 Mdot
.47726 .66188 Mdot
.50138 .67416 Mdot
.38086 .25634 Mdot
.17804 .45834 Mdot
.67435 .4783 Mdot
.85861 .48718 Mdot
.65296 .54471 Mdot
.31197 .41214 Mdot
.38567 .33184 Mdot
.45683 .65435 Mdot
.43569 .65899 Mdot
.43359 .2965 Mdot
.67176 .49011 Mdot
.35593 .38048 Mdot
.35457 .46098 Mdot
.59551 .36408 Mdot
.19194 .47745 Mdot
.67597 .51848 Mdot
.19191 .47551 Mdot
.45365 .35537 Mdot
.78246 .53009 Mdot
.26036 .66672 Mdot
.59154 .3426 Mdot
.19147 .47727 Mdot
.69002 .52494 Mdot
.47853 .67944 Mdot
.4999 .51184 Mdot
.50808 .48376 Mdot
.67135 .50333 Mdot
.42289 .32569 Mdot
.35707 .39356 Mdot
.481 .66858 Mdot
.5007 .72475 Mdot
.59691 .60097 Mdot
.44479 .29365 Mdot
.51013 .55103 Mdot
.59843 .34635 Mdot
.44861 .64808 Mdot
.31351 .43279 Mdot
.5928 .34168 Mdot
.49262 .51262 Mdot
.30765 .65643 Mdot
.43423 .64127 Mdot
.38796 .56545 Mdot
.59617 .32844 Mdot
.30423 .46172 Mdot
.47668 .62292 Mdot
.57327 .35781 Mdot
.50771 .57242 Mdot
.51663 .33758 Mdot
.44507 .50644 Mdot
.75322 .40628 Mdot
.42933 .34451 Mdot
.39295 .307 Mdot
.25086 .27679 Mdot
.30196 .26669 Mdot
.56764 .34209 Mdot
.50107 .53882 Mdot
.17776 .44836 Mdot
.58369 .35823 Mdot
.48854 .61513 Mdot
.48734 .64916 Mdot
.72725 .66812 Mdot
.50144 .55025 Mdot
.51196 .51173 Mdot
.6676 .5708 Mdot
.42126 .65005 Mdot
.50908 .55054 Mdot
.4797 .62757 Mdot
.70444 .48701 Mdot
.599 .34428 Mdot
.48194 .84255 Mdot
.6294 .32703 Mdot
.42228 .71741 Mdot
.39939 .30425 Mdot
.41824 .34926 Mdot
.47582 .65834 Mdot
.57011 .5098 Mdot
.65836 .81853 Mdot
.48737 .64621 Mdot
.39915 .5496 Mdot
.24612 .56808 Mdot
.51405 .65105 Mdot
.71021 .54129 Mdot
.50859 .57138 Mdot
.6441 .50449 Mdot
.58749 .34011 Mdot
.34977 .39352 Mdot
.34993 .37456 Mdot
.58711 .33124 Mdot
.43839 .66177 Mdot
.32511 .38043 Mdot
.47291 .6503 Mdot
.46573 .67855 Mdot
.3098 .58532 Mdot
.30956 .42945 Mdot
.42731 .31372 Mdot
.32434 .42142 Mdot
.70622 .49586 Mdot
.85486 .42909 Mdot
.33689 .41367 Mdot
.72438 .67364 Mdot
.29179 .60559 Mdot
.18277 .44756 Mdot
.68333 .53729 Mdot
.31122 .40143 Mdot
.58241 .33222 Mdot
.33927 .57862 Mdot
.68947 .71405 Mdot
.56052 .34454 Mdot
.45811 .67323 Mdot
.66322 .48507 Mdot
.66077 .54937 Mdot
.56242 .33125 Mdot
.67087 .53027 Mdot
.51874 .64506 Mdot
.44402 .619 Mdot
.57051 .32523 Mdot
.3109 .74663 Mdot
.62193 .32655 Mdot
.76491 .65748 Mdot
.46584 .59964 Mdot
.68145 .51686 Mdot
.71929 .69055 Mdot
.68337 .56107 Mdot
.50385 .48602 Mdot
.49097 .62663 Mdot
.33913 .41449 Mdot
.29607 .62119 Mdot
.40857 .28772 Mdot
.76609 .47147 Mdot
.69499 .53401 Mdot
.55985 .33245 Mdot
.67101 .52966 Mdot
.66501 .52984 Mdot
.61974 .31213 Mdot
.66685 .51693 Mdot
.44051 .64803 Mdot
.8071 .55999 Mdot
.676 .5383 Mdot
.59886 .33469 Mdot
.30709 .41791 Mdot
.69948 .53943 Mdot
.47251 .36978 Mdot
.43273 .66415 Mdot
.45121 .29406 Mdot
.31355 .45362 Mdot
.6759 .48112 Mdot
.34106 .40939 Mdot
.4037 .30334 Mdot
.35705 .41197 Mdot
.61892 .27997 Mdot
.63993 .29997 Mdot
.53115 .69511 Mdot
.51341 .33639 Mdot
.69903 .48965 Mdot
.39296 .35131 Mdot
.43777 .64324 Mdot
.47445 .67616 Mdot
.30888 .43592 Mdot
.713 .54462 Mdot
.7947 .42796 Mdot
.50486 .54108 Mdot
.78168 .44506 Mdot
.60546 .31675 Mdot
.46329 .37213 Mdot
.31995 .5684 Mdot
.61726 .38423 Mdot
.52126 .59423 Mdot
.50236 .5203 Mdot
.46894 .65701 Mdot
.25485 .53163 Mdot
.35086 .38954 Mdot
.48099 .1984 Mdot
.50608 .64941 Mdot
.43413 .29238 Mdot
.44932 .65857 Mdot
.47486 .48458 Mdot
.50451 .67504 Mdot
.322 .44111 Mdot
.5636 .36254 Mdot
.70727 .53433 Mdot
.32161 .39328 Mdot
.39417 .33399 Mdot
.31132 .6855 Mdot
.47859 .61595 Mdot
.42567 .66425 Mdot
.43096 .31524 Mdot
.71402 .50739 Mdot
.4193 .31736 Mdot
.57137 .35668 Mdot
.33448 .41378 Mdot
.49806 .60618 Mdot
.50392 .55754 Mdot
.43799 .26134 Mdot
.58443 .31972 Mdot
.38561 .34074 Mdot
.63302 .33376 Mdot
.49975 .51723 Mdot
.4977 .6912 Mdot
.37933 .32925 Mdot
.5193 .59053 Mdot
.69117 .65445 Mdot
.31341 .65465 Mdot
.59261 .57762 Mdot
.4246 .32643 Mdot
.30662 .25081 Mdot
.59473 .33931 Mdot
.61907 .34738 Mdot
.76993 .65322 Mdot
.722 .76954 Mdot
.40308 .55314 Mdot
.78293 .40347 Mdot
.57099 .35669 Mdot
.60216 .32661 Mdot
.42211 .31635 Mdot
.70067 .49474 Mdot
.71401 .48095 Mdot
.39484 .34624 Mdot
.25312 .62651 Mdot
.69629 .52237 Mdot
.63572 .78167 Mdot
.44805 .29782 Mdot
.41658 .65025 Mdot
.78994 .56686 Mdot
.32974 .43878 Mdot
.25178 .56345 Mdot
.61098 .40485 Mdot
.4606 .66072 Mdot
.62276 .20919 Mdot
.42378 .29912 Mdot
.51687 .50081 Mdot
.54757 .31667 Mdot
.50297 .63871 Mdot
.45038 .66334 Mdot
.44544 .64499 Mdot
.29982 .4423 Mdot
.6707 .61931 Mdot
.4588 .65804 Mdot
.30534 .66145 Mdot
.41422 .66984 Mdot
.4051 .23343 Mdot
.32487 .4213 Mdot
.25907 .48223 Mdot
.39275 .28051 Mdot
.77772 .42159 Mdot
.45716 .69482 Mdot
.59972 .35949 Mdot
.46422 .47956 Mdot
.57924 .34469 Mdot
.57094 .375 Mdot
.18393 .51405 Mdot
.72089 .51358 Mdot
.50508 .63973 Mdot
.44415 .30678 Mdot
.71135 .47845 Mdot
.46091 .47958 Mdot
.86028 .44081 Mdot
.55359 .33977 Mdot
.85685 .64568 Mdot
.60582 .35426 Mdot
.51392 .49689 Mdot
.6915 .4992 Mdot
.60131 .54942 Mdot
.29508 .59313 Mdot
.70935 .50267 Mdot
.34096 .25842 Mdot
.64503 .49878 Mdot
.21476 .60335 Mdot
.72746 .54567 Mdot
.60415 .33651 Mdot
.56198 .33096 Mdot
.52059 .66606 Mdot
.45762 .63089 Mdot
.28069 .58725 Mdot
.50554 .54224 Mdot
.43251 .64085 Mdot
.40596 .32464 Mdot
.50984 .32925 Mdot
.66469 .29717 Mdot
.66838 .51424 Mdot
.57873 .32352 Mdot
.45027 .66101 Mdot
.4785 .59812 Mdot
.49283 .66529 Mdot
.41067 .40282 Mdot
.62702 .78728 Mdot
.47426 .63651 Mdot
.48269 .69968 Mdot
.38866 .32733 Mdot
.37976 .25698 Mdot
.81316 .40232 Mdot
.18724 .49504 Mdot
.46441 .68713 Mdot
.31349 .41614 Mdot
.30473 .42865 Mdot
.51399 .68556 Mdot
.597 .54255 Mdot
.2721 .41449 Mdot
.47688 .66247 Mdot
.31527 .67669 Mdot
.44982 .27615 Mdot
.49876 .48251 Mdot
.4011 .30788 Mdot
.73139 .49341 Mdot
.4952 .50043 Mdot
.40707 .33222 Mdot
.28403 .65796 Mdot
.49752 .53228 Mdot
.51908 .3333 Mdot
.30764 .40601 Mdot
.47845 .62522 Mdot
.75694 .63315 Mdot
.43349 .27413 Mdot
.61019 .32601 Mdot
.68894 .50367 Mdot
.60616 .31772 Mdot
.42786 .23907 Mdot
.24772 .60683 Mdot
.50345 .49068 Mdot
.60241 .35867 Mdot
.38524 .57021 Mdot
.31472 .42008 Mdot
.59608 .35669 Mdot
.41073 .69405 Mdot
.41951 .68191 Mdot
.63762 .81452 Mdot
.42886 .66575 Mdot
.52538 .31216 Mdot
.62037 .33818 Mdot
.49336 .49968 Mdot
.47946 .65448 Mdot
.4443 .32201 Mdot
.52687 .66653 Mdot
.47187 .64927 Mdot
.41885 .27612 Mdot
.4864 .65029 Mdot
.33552 .4253 Mdot
.64741 .54254 Mdot
.30801 .60226 Mdot
.40074 .45185 Mdot
.34534 .38987 Mdot
.32253 .65055 Mdot
.48445 .6191 Mdot
.31989 .26406 Mdot
.69065 .51945 Mdot
.49637 .67172 Mdot
.22623 .55155 Mdot
.68535 .49323 Mdot
.69968 .50957 Mdot
.43856 .61991 Mdot
.62516 .34473 Mdot
.4285 .31565 Mdot
.31738 .42216 Mdot
.63851 .35137 Mdot
.46156 .65547 Mdot
.49791 .59648 Mdot
.3412 .38957 Mdot
.61393 .33013 Mdot
.49646 .6072 Mdot
.68264 .42293 Mdot
.28592 .63523 Mdot
.62193 .31597 Mdot
.4329 .68958 Mdot
.6699 .76545 Mdot
.65803 .5119 Mdot
.62073 .2075 Mdot
.38162 .3838 Mdot
.39838 .34143 Mdot
.51043 .55503 Mdot
.84544 .35987 Mdot
.30638 .41838 Mdot
.76902 .44406 Mdot
.48378 .6726 Mdot
.45592 .64909 Mdot
.70274 .48829 Mdot
.46758 .61743 Mdot
.6654 .5187 Mdot
.44527 .39148 Mdot
.74883 .74688 Mdot
.68033 .53511 Mdot
.68182 .529 Mdot
.39537 .61685 Mdot
.384 .37069 Mdot
.67994 .49833 Mdot
.4709 .62005 Mdot
.35037 .22512 Mdot
.46436 .71947 Mdot
.36126 .38465 Mdot
.30055 .44654 Mdot
.70782 .54095 Mdot
.68932 .71874 Mdot
.40942 .68392 Mdot
.63569 .76534 Mdot
.27037 .41656 Mdot
.56698 .34536 Mdot
.50153 .58941 Mdot
.50419 .53272 Mdot
.41284 .29641 Mdot
.50235 .57378 Mdot
.47481 .6243 Mdot
.71767 .52354 Mdot
.34374 .43012 Mdot
.5851 .35699 Mdot
.52087 .58459 Mdot
.45656 .29017 Mdot
.33431 .39333 Mdot
.66939 .53782 Mdot
.74097 .68116 Mdot
.31157 .38981 Mdot
.52021 .54134 Mdot
.46877 .68357 Mdot
.50307 .57952 Mdot
.52072 .51592 Mdot
.58796 .33224 Mdot
.40708 .34652 Mdot
.51897 .54364 Mdot
.33448 .59412 Mdot
.27383 .63179 Mdot
.47681 .6875 Mdot
.70207 .53762 Mdot
.58754 .3205 Mdot
.50855 .49528 Mdot
.17902 .44357 Mdot
.44605 .6803 Mdot
.63599 .78216 Mdot
.3742 .46415 Mdot
.50159 .5294 Mdot
.70832 .47633 Mdot
.32098 .41964 Mdot
.467 .59946 Mdot
.30119 .66279 Mdot
.43553 .63672 Mdot
.50071 .69571 Mdot
.41532 .3367 Mdot
.57595 .35154 Mdot
.52933 .69746 Mdot
.41374 .29932 Mdot
.69815 .50853 Mdot
.6056 .77794 Mdot
.69043 .47877 Mdot
.67779 .47852 Mdot
.76655 .5063 Mdot
.61602 .32392 Mdot
.84505 .35611 Mdot
.30775 .45908 Mdot
.49222 .65507 Mdot
.56231 .35681 Mdot
.6783 .50241 Mdot
.48225 .61294 Mdot
.66561 .51729 Mdot
.69976 .54742 Mdot
.42626 .6488 Mdot
.4293 .63738 Mdot
.30133 .66696 Mdot
.66726 .76138 Mdot
.32548 .4271 Mdot
.67577 .48861 Mdot
.67565 .74639 Mdot
.45798 .65273 Mdot
.4662 .62618 Mdot
.46572 .47829 Mdot
.32893 .38867 Mdot
.51665 .77786 Mdot
.47784 .67593 Mdot
.25373 .51785 Mdot
.48741 .61666 Mdot
.72889 .53229 Mdot
.64339 .32313 Mdot
.41588 .7076 Mdot
.38869 .34156 Mdot
.67459 .4882 Mdot
.33338 .43826 Mdot
.72865 .48383 Mdot
.55701 .74974 Mdot
.58771 .32566 Mdot
.68738 .53004 Mdot
.4037 .34876 Mdot
.61152 .33146 Mdot
.62181 .32752 Mdot
.45933 .47883 Mdot
.4215 .34374 Mdot
.34589 .42878 Mdot
.59814 .35014 Mdot
.59608 .72701 Mdot
.60648 .33516 Mdot
.55077 .76207 Mdot
.44118 .68058 Mdot
.30353 .66096 Mdot
.5188 .56481 Mdot
.51074 .70112 Mdot
.61053 .34594 Mdot
.33931 .39123 Mdot
.49794 .60939 Mdot
.67029 .5336 Mdot
.30923 .41885 Mdot
.76972 .58166 Mdot
.40652 .35071 Mdot
.65318 .54088 Mdot
.62952 .36116 Mdot
.68093 .48971 Mdot
.249 .56861 Mdot
.34201 .43513 Mdot
.46686 .4505 Mdot
.31534 .5936 Mdot
.51047 .54438 Mdot
.49564 .68805 Mdot
.50031 .61355 Mdot
.4393 .65165 Mdot
.3986 .30493 Mdot
.2981 .43892 Mdot
.69028 .5437 Mdot
.53864 .70176 Mdot
.61504 .32696 Mdot
.4163 .5293 Mdot
.51904 .51864 Mdot
.48707 .59879 Mdot
.67821 .50483 Mdot
.69088 .54878 Mdot
.68515 .60998 Mdot
.43114 .29808 Mdot
.49183 .71432 Mdot
.48261 .6878 Mdot
.51904 .71584 Mdot
.61348 .34396 Mdot
.73981 .41129 Mdot
.4498 .28011 Mdot
.8614 .64057 Mdot
.41227 .30156 Mdot
.44505 .45436 Mdot
.66522 .50754 Mdot
.33262 .40495 Mdot
.43994 .66706 Mdot
.73372 .55604 Mdot
.6848 .47342 Mdot
.34949 .33944 Mdot
.32426 .4141 Mdot
.63374 .27081 Mdot
.56498 .35401 Mdot
.52145 .58566 Mdot
.48772 .61632 Mdot
.46138 .61406 Mdot
.45328 .62854 Mdot
.56831 .33519 Mdot
.43828 .62758 Mdot
.63598 .34326 Mdot
.55334 .74926 Mdot
.22535 .55471 Mdot
.43545 .32174 Mdot
.40418 .21999 Mdot
.6699 .48269 Mdot
.55005 .78322 Mdot
.53345 .76416 Mdot
.31123 .6538 Mdot
.5738 .3717 Mdot
.51627 .62378 Mdot
.42446 .31841 Mdot
.66277 .30385 Mdot
.43706 .31967 Mdot
.5318 .83959 Mdot
.72924 .66728 Mdot
.59912 .27034 Mdot
.45494 .61973 Mdot
.4178 .33888 Mdot
.68967 .72386 Mdot
.52001 .55481 Mdot
.32351 .38152 Mdot
.5694 .74367 Mdot
.75287 .59296 Mdot
.32717 .42767 Mdot
.44468 .67331 Mdot
.6519 .49367 Mdot
.43769 .66391 Mdot
.44061 .66882 Mdot
.48702 .67131 Mdot
.598 .31016 Mdot
.4454 .68349 Mdot
.44758 .63906 Mdot
.17647 .38304 Mdot
.30702 .37873 Mdot
.39388 .30333 Mdot
.59878 .5617 Mdot
.31443 .42421 Mdot
.73213 .49447 Mdot
.31103 .59897 Mdot
.62216 .34294 Mdot
.68128 .61072 Mdot
.44557 .61567 Mdot
.7703 .46223 Mdot
.62814 .33689 Mdot
.35617 .40641 Mdot
.50477 .52798 Mdot
.71538 .31314 Mdot
.38512 .30873 Mdot
.51027 .51719 Mdot
.41901 .27899 Mdot
.48149 .75787 Mdot
.67236 .52618 Mdot
.5101 .54503 Mdot
.58832 .3554 Mdot
.43697 .32447 Mdot
.31315 .66317 Mdot
.45448 .63848 Mdot
.42343 .32913 Mdot
.51025 .5621 Mdot
.2945 .6192 Mdot
.30238 .60021 Mdot
.42487 .33727 Mdot
.6045 .36169 Mdot
.61455 .33891 Mdot
.31383 .42907 Mdot
.6599 .51973 Mdot
.7159 .5107 Mdot
.61008 .33788 Mdot
.64277 .24785 Mdot
.4624 .65698 Mdot
.46899 .63664 Mdot
.32561 .57876 Mdot
.49685 .62132 Mdot
.37341 .41319 Mdot
.50938 .52456 Mdot
.71489 .52342 Mdot
.49911 .61165 Mdot
.49514 .60686 Mdot
.45488 .68153 Mdot
.2527 .63242 Mdot
.40255 .30121 Mdot
.42135 .64577 Mdot
.35131 .4092 Mdot
.76405 .58725 Mdot
.43982 .64286 Mdot
.52274 .54078 Mdot
.6635 .50933 Mdot
.55289 .39572 Mdot
.60902 .32507 Mdot
.44299 .29385 Mdot
.44415 .30253 Mdot
.21516 .48333 Mdot
.69242 .48109 Mdot
.51022 .51949 Mdot
.41511 .24837 Mdot
.51076 .49679 Mdot
.32422 .4115 Mdot
.43941 .51509 Mdot
.37583 .30645 Mdot
.39511 .30162 Mdot
.61996 .30609 Mdot
.50052 .66837 Mdot
.44452 .63875 Mdot
.7865 .42959 Mdot
.48242 .63633 Mdot
.33642 .41918 Mdot
.57951 .36352 Mdot
.68643 .52829 Mdot
.33213 .42935 Mdot
.60806 .3546 Mdot
.712 .50546 Mdot
.41547 .66753 Mdot
.48428 .61423 Mdot
.69465 .50464 Mdot
.66593 .53507 Mdot
.46658 .66633 Mdot
.18415 .54324 Mdot
.71228 .53122 Mdot
.69062 .5017 Mdot
.76066 .58898 Mdot
.38631 .30891 Mdot
.52761 .66363 Mdot
.6169 .35235 Mdot
.44766 .6398 Mdot
.43537 .31796 Mdot
.32432 .40353 Mdot
.70144 .53282 Mdot
.50559 .58914 Mdot
.46355 .64938 Mdot
.31432 .41698 Mdot
.30837 .40044 Mdot
.31543 .39952 Mdot
.56316 .33059 Mdot
.43336 .62832 Mdot
.68553 .4977 Mdot
.56183 .34384 Mdot
.31576 .43592 Mdot
.33205 .38566 Mdot
.22776 .63691 Mdot
.463 .66195 Mdot
.30064 .41307 Mdot
.85081 .41543 Mdot
.28565 .67389 Mdot
.50282 .47954 Mdot
.39917 .3614 Mdot
.31136 .24102 Mdot
.2976 .45339 Mdot
.57384 .34852 Mdot
.41382 .53008 Mdot
.36151 .39289 Mdot
.51687 .58024 Mdot
.46344 .63485 Mdot
.49189 .56259 Mdot
.30925 .41587 Mdot
.24664 .60508 Mdot
.72016 .50741 Mdot
.59868 .63494 Mdot
.31486 .42453 Mdot
.43117 .3348 Mdot
.44421 .26517 Mdot
.41634 .30624 Mdot
.50594 .67381 Mdot
.46475 .76617 Mdot
.59097 .70901 Mdot
.51521 .77372 Mdot
.56672 .35665 Mdot
.69354 .54881 Mdot
.78137 .57699 Mdot
.70111 .51109 Mdot
.42037 .28553 Mdot
.34098 .39159 Mdot
.70744 .49203 Mdot
.61761 .32274 Mdot
.61353 .34114 Mdot
.3808 .32161 Mdot
.40415 .30694 Mdot
.4133 .31745 Mdot
.66096 .49985 Mdot
.66529 .51168 Mdot
.47284 .61234 Mdot
.68806 .54057 Mdot
.40258 .39866 Mdot
.42691 .39809 Mdot
.40761 .27183 Mdot
.59215 .33465 Mdot
.70851 .51658 Mdot
.48088 .62565 Mdot
.37661 .54973 Mdot
.42768 .25151 Mdot
.33105 .437 Mdot
.811 .55663 Mdot
.70586 .78482 Mdot
.50591 .61504 Mdot
.57446 .33168 Mdot
.51335 .5172 Mdot
.44138 .65408 Mdot
.39925 .3431 Mdot
.35308 .47049 Mdot
.49617 .53495 Mdot
.43138 .64937 Mdot
.4227 .67627 Mdot
.59189 .32169 Mdot
.31469 .59834 Mdot
.51852 .58311 Mdot
.44496 .48467 Mdot
.57778 .36527 Mdot
.44373 .27122 Mdot
.27837 .24838 Mdot
.68787 .57228 Mdot
.27154 .50843 Mdot
.49408 .50462 Mdot
.44664 .68134 Mdot
.40292 .3246 Mdot
.34257 .42375 Mdot
.4052 .31866 Mdot
.73509 .50749 Mdot
.38461 .31303 Mdot
.48547 .63934 Mdot
.68499 .49632 Mdot
.61808 .3363 Mdot
.34494 .5565 Mdot
.55943 .64674 Mdot
.44654 .3169 Mdot
.51036 .47934 Mdot
.42855 .63963 Mdot
.59364 .73368 Mdot
.51148 .70033 Mdot
.46917 .62294 Mdot
.58105 .34463 Mdot
.67122 .51081 Mdot
.59861 .31731 Mdot
.52533 .67388 Mdot
.60731 .51706 Mdot
.60662 .32338 Mdot
.40054 .68671 Mdot
.35654 .39173 Mdot
.2493 .61627 Mdot
.4811 .66228 Mdot
.58319 .35533 Mdot
.42675 .65855 Mdot
.68425 .48543 Mdot
.28001 .64793 Mdot
.29339 .64075 Mdot
.59565 .34536 Mdot
.48776 .46313 Mdot
.29176 .6089 Mdot
.52826 .66031 Mdot
.5697 .35368 Mdot
.29516 .69826 Mdot
.50769 .50918 Mdot
.33356 .39461 Mdot
.31986 .39068 Mdot
.34417 .39868 Mdot
.47063 .63353 Mdot
.70023 .73309 Mdot
.30791 .42553 Mdot
.54482 .34006 Mdot
.34326 .41675 Mdot
.38628 .4665 Mdot
.79526 .43516 Mdot
.35289 .3906 Mdot
.48282 .65321 Mdot
.43418 .73188 Mdot
.4067 .53979 Mdot
.43618 .33783 Mdot
.7026 .319 Mdot
.18268 .37182 Mdot
.45647 .6551 Mdot
.80274 .56094 Mdot
.67325 .56173 Mdot
.44234 .44858 Mdot
.30015 .64634 Mdot
.36593 .59775 Mdot
.70233 .50597 Mdot
.31472 .59577 Mdot
.65139 .51977 Mdot
.51683 .53406 Mdot
.4724 .63819 Mdot
.67786 .48651 Mdot
.76604 .47306 Mdot
.26833 .69239 Mdot
.78324 .4533 Mdot
.711 .51408 Mdot
.57657 .35904 Mdot
.57499 .34027 Mdot
.58381 .34639 Mdot
.39555 .31947 Mdot
.6848 .53159 Mdot
.42027 .65449 Mdot
.3938 .33681 Mdot
.46173 .67572 Mdot
.60326 .34275 Mdot
.30193 .65029 Mdot
.68223 .52841 Mdot
.47687 .66369 Mdot
.68139 .73543 Mdot
.42588 .27676 Mdot
.31292 .41823 Mdot
.80872 .55681 Mdot
.39473 .35699 Mdot
.63009 .34317 Mdot
.73336 .51541 Mdot
.32119 .37159 Mdot
.42968 .49858 Mdot
.47754 .68622 Mdot
.49303 .64016 Mdot
.41243 .52951 Mdot
.73606 .66712 Mdot
.51477 .59133 Mdot
.39391 .33304 Mdot
.39077 .30229 Mdot
.43384 .66846 Mdot
.68564 .53382 Mdot
.36639 .39765 Mdot
.29798 .41227 Mdot
.47422 .70551 Mdot
.29711 .59629 Mdot
.3055 .66119 Mdot
.48828 .60974 Mdot
.43421 .59698 Mdot
.40609 .34837 Mdot
.50303 .47816 Mdot
.30248 .59066 Mdot
.34091 .40385 Mdot
.47631 .67956 Mdot
.59852 .58351 Mdot
.69642 .53221 Mdot
.42579 .32445 Mdot
.58774 .31254 Mdot
.31673 .38547 Mdot
.40385 .27651 Mdot
.43412 .66871 Mdot
.49568 .6071 Mdot
.59384 .3562 Mdot
.73037 .52498 Mdot
.31918 .40032 Mdot
.39182 .33498 Mdot
.33576 .40469 Mdot
.66995 .52132 Mdot
.70401 .53228 Mdot
.49039 .67524 Mdot
.49707 .71559 Mdot
.44855 .30537 Mdot
.50966 .66879 Mdot
.41589 .33037 Mdot
.3814 .25537 Mdot
.59321 .31358 Mdot
.49625 .67064 Mdot
.7206 .4863 Mdot
.60673 .34176 Mdot
.4544 .65787 Mdot
.42004 .51857 Mdot
.49294 .60369 Mdot
.41862 .33935 Mdot
.33465 .46816 Mdot
.33611 .39702 Mdot
.43755 .61132 Mdot
.72934 .59572 Mdot
.49581 .61605 Mdot
.42837 .27031 Mdot
.58764 .7233 Mdot
.59798 .32392 Mdot
.6696 .49906 Mdot
.45011 .24499 Mdot
.60154 .3343 Mdot
.48525 .6585 Mdot
.33647 .41472 Mdot
.67348 .54235 Mdot
.4974 .49558 Mdot
.27983 .56475 Mdot
.51922 .68559 Mdot
.48573 .71529 Mdot
.51554 .5883 Mdot
.78656 .40852 Mdot
.41078 .31792 Mdot
.67945 .50304 Mdot
.57267 .33575 Mdot
.59205 .32418 Mdot
.41935 .28101 Mdot
.74947 .59056 Mdot
.80139 .49153 Mdot
.84994 .39662 Mdot
.41747 .26418 Mdot
.34708 .40408 Mdot
.28182 .64822 Mdot
.41781 .30607 Mdot
.40464 .29193 Mdot
.37564 .34202 Mdot
.7846 .42453 Mdot
.70641 .50426 Mdot
.46279 .64885 Mdot
.79813 .56258 Mdot
.48775 .6678 Mdot
.27462 .51289 Mdot
.60281 .34204 Mdot
.66979 .49862 Mdot
.45365 .39508 Mdot
.50168 .68162 Mdot
.44481 .66381 Mdot
.47928 .36219 Mdot
.50627 .53954 Mdot
.18443 .45635 Mdot
.49697 .64994 Mdot
.39997 .31625 Mdot
.63518 .49429 Mdot
.5178 .54329 Mdot
.68228 .7357 Mdot
.61641 .34319 Mdot
.50473 .48898 Mdot
.5179 .53803 Mdot
.43431 .59419 Mdot
.65099 .51483 Mdot
.71372 .49791 Mdot
.31259 .39777 Mdot
.78404 .49874 Mdot
.61741 .34343 Mdot
.74829 .4002 Mdot
.47215 .62077 Mdot
.57886 .37693 Mdot
.36095 .4608 Mdot
.4554 .66285 Mdot
.45734 .48041 Mdot
.68533 .6096 Mdot
.50442 .59317 Mdot
.52643 .75911 Mdot
.59665 .33788 Mdot
.23155 .54604 Mdot
.44259 .6271 Mdot
.42336 .32794 Mdot
.69706 .49235 Mdot
.65134 .53843 Mdot
.33512 .43041 Mdot
.39274 .40561 Mdot
.79393 .70726 Mdot
.67133 .49703 Mdot
.45528 .63686 Mdot
.60176 .32536 Mdot
.50085 .48892 Mdot
.51754 .56683 Mdot
.4856 .46131 Mdot
.69812 .53036 Mdot
.51868 .55138 Mdot
.77353 .46485 Mdot
.31391 .59693 Mdot
.56707 .78391 Mdot
.59045 .34809 Mdot
.34376 .41091 Mdot
.45594 .70901 Mdot
.38728 .26049 Mdot
.48737 .61449 Mdot
.27358 .51154 Mdot
.65871 .5538 Mdot
.33962 .41651 Mdot
.43958 .6618 Mdot
.51872 .59644 Mdot
.32883 .65017 Mdot
.36563 .38568 Mdot
.51473 .58675 Mdot
.5055 .62283 Mdot
.70274 .49242 Mdot
.51095 .51881 Mdot
.68996 .52733 Mdot
.44142 .66676 Mdot
.26865 .4587 Mdot
.67448 .49033 Mdot
.69426 .3174 Mdot
.29582 .41437 Mdot
.62139 .34652 Mdot
.49353 .57141 Mdot
.46743 .68826 Mdot
.56391 .79269 Mdot
.50484 .48516 Mdot
.66367 .26306 Mdot
.42509 .33138 Mdot
.17133 .45973 Mdot
.38631 .35617 Mdot
.54055 .30076 Mdot
.59711 .42084 Mdot
.49503 .56532 Mdot
.74469 .59212 Mdot
.5034 .78177 Mdot
.59527 .36582 Mdot
.53509 .78948 Mdot
.45727 .63113 Mdot
.46635 .68272 Mdot
.41781 .33053 Mdot
.56198 .37104 Mdot
.41567 .70795 Mdot
.30135 .59118 Mdot
.35807 .40222 Mdot
.69033 .51299 Mdot
.47012 .63005 Mdot
.7611 .47234 Mdot
.43831 .32633 Mdot
.58842 .60394 Mdot
.47942 .65973 Mdot
.50629 .53882 Mdot
.56407 .37001 Mdot
.6187 .33642 Mdot
.41963 .34178 Mdot
.42818 .33918 Mdot
.45966 .6852 Mdot
.57119 .3258 Mdot
.46999 .61012 Mdot
.29195 .6115 Mdot
.50894 .55991 Mdot
.32183 .41052 Mdot
.48046 .62083 Mdot
.66863 .57633 Mdot
.3128 .77582 Mdot
.50134 .67904 Mdot
.67658 .47984 Mdot
.41549 .32079 Mdot
.40882 .29229 Mdot
.71546 .51295 Mdot
.41019 .29065 Mdot
.60086 .63436 Mdot
.69804 .73686 Mdot
.32715 .40946 Mdot
.56987 .70723 Mdot
.35001 .39433 Mdot
.50601 .48921 Mdot
.46413 .66356 Mdot
.51012 .18209 Mdot
.41872 .26436 Mdot
.37011 .48068 Mdot
.60781 .33768 Mdot
.50826 .48473 Mdot
.43298 .63076 Mdot
.30998 .44847 Mdot
.41998 .29591 Mdot
.5173 .49633 Mdot
.48493 .67436 Mdot
.6647 .49576 Mdot
.49496 .5951 Mdot
.51655 .51087 Mdot
.51225 .51141 Mdot
.51743 .60872 Mdot
.60818 .35456 Mdot
.66587 .52196 Mdot
.6295 .26703 Mdot
.42612 .2745 Mdot
.42951 .645 Mdot
.45046 .6407 Mdot
.67069 .5433 Mdot
.49191 .65028 Mdot
.56726 .3291 Mdot
.81594 .30125 Mdot
.32399 .39337 Mdot
.5005 .48069 Mdot
.69721 .36124 Mdot
.5177 .61065 Mdot
.50337 .61758 Mdot
.37687 .61101 Mdot
.59657 .60028 Mdot
.61949 .34867 Mdot
.50827 .69017 Mdot
.3901 .3082 Mdot
.32383 .39727 Mdot
.61639 .32072 Mdot
.44562 .61821 Mdot
.48519 .64656 Mdot
.34025 .41479 Mdot
.47231 .376 Mdot
.34571 .38031 Mdot
.56864 .34521 Mdot
.49364 .47639 Mdot
.37879 .54758 Mdot
.4686 .65504 Mdot
.50819 .53065 Mdot
.67447 .51177 Mdot
.56505 .34848 Mdot
.67042 .62282 Mdot
.51732 .53236 Mdot
.63092 .36086 Mdot
.61836 .33864 Mdot
.47842 .68528 Mdot
.68808 .48201 Mdot
.7121 .55844 Mdot
.67607 .50831 Mdot
.21624 .5345 Mdot
.63037 .26145 Mdot
.41237 .32174 Mdot
.59443 .33405 Mdot
.43633 .3114 Mdot
.35514 .3891 Mdot
.27451 .62562 Mdot
.4379 .33102 Mdot
.71838 .49239 Mdot
.43909 .31189 Mdot
.47223 .61026 Mdot
.62475 .34144 Mdot
.44827 .29221 Mdot
.46989 .61864 Mdot
.42225 .68835 Mdot
.51203 .52992 Mdot
.35873 .41569 Mdot
.30478 .59719 Mdot
.48225 .66584 Mdot
.50612 .52352 Mdot
.47264 .66358 Mdot
.56895 .32728 Mdot
.33736 .54488 Mdot
.42353 .65671 Mdot
.41963 .26377 Mdot
.72556 .30197 Mdot
.39734 .29108 Mdot
.56692 .5454 Mdot
.46053 .67349 Mdot
.46625 .65746 Mdot
.42772 .64021 Mdot
.75704 .59734 Mdot
.63206 .34265 Mdot
.5105 .67986 Mdot
.38723 .34206 Mdot
.70425 .51434 Mdot
.70145 .48426 Mdot
.38982 .57416 Mdot
.50879 .5223 Mdot
.5678 .3259 Mdot
.46453 .65721 Mdot
.51434 .50924 Mdot
.30421 .57417 Mdot
.7912 .46792 Mdot
.37886 .36285 Mdot
.4126 .27937 Mdot
.6572 .5203 Mdot
.39264 .31454 Mdot
.44147 .62239 Mdot
.51771 .55016 Mdot
.63849 .2678 Mdot
.55451 .32837 Mdot
.32423 .39761 Mdot
.45603 .67444 Mdot
.25504 .64524 Mdot
.38873 .32757 Mdot
.41683 .34493 Mdot
.46802 .61074 Mdot
.64251 .54978 Mdot
.26623 .72776 Mdot
.56131 .35665 Mdot
.60931 .73498 Mdot
.77143 .63891 Mdot
.41891 .76098 Mdot
.58718 .32975 Mdot
.45373 .48216 Mdot
.43908 .33644 Mdot
.23531 .42295 Mdot
.7031 .51024 Mdot
.31978 .40053 Mdot
.47246 .6183 Mdot
.71863 .49383 Mdot
.41287 .26592 Mdot
.689 .54544 Mdot
.50838 .55013 Mdot
.62747 .33724 Mdot
.41024 .29663 Mdot
.57512 .31672 Mdot
.71941 .48159 Mdot
.34592 .39433 Mdot
.25585 .5209 Mdot
.58704 .73487 Mdot
.69085 .60793 Mdot
.42207 .64191 Mdot
.29764 .38635 Mdot
.41985 .64683 Mdot
.65757 .5487 Mdot
.48159 .66125 Mdot
.42846 .68886 Mdot
.42443 .34684 Mdot
.47758 .68718 Mdot
.47547 .6206 Mdot
.67868 .73996 Mdot
.45247 .66509 Mdot
.44738 .67646 Mdot
.48139 .68605 Mdot
.70385 .48213 Mdot
.4906 .67164 Mdot
.66244 .52229 Mdot
.76812 .45207 Mdot
.42617 .27505 Mdot
.35181 .38786 Mdot
.35118 .38898 Mdot
.2818 .5007 Mdot
.25443 .64154 Mdot
.79138 .5682 Mdot
.69957 .52149 Mdot
.61174 .34473 Mdot
.47025 .61201 Mdot
.23384 .66589 Mdot
.27001 .46443 Mdot
.45149 .30846 Mdot
.44578 .3093 Mdot
.44488 .63566 Mdot
.68582 .79828 Mdot
.4964 .63955 Mdot
.32008 .57181 Mdot
.47153 .63339 Mdot
.49797 .66533 Mdot
.38431 .34747 Mdot
.2494 .56709 Mdot
.42126 .64658 Mdot
.65077 .50922 Mdot
.31992 .40214 Mdot
.51022 .52833 Mdot
.27309 .4766 Mdot
.758 .66766 Mdot
.63548 .55964 Mdot
.42411 .64501 Mdot
.39273 .339 Mdot
.71085 .52863 Mdot
.32403 .58172 Mdot
.56234 .34342 Mdot
.27503 .56912 Mdot
.54461 .76483 Mdot
.56691 .36584 Mdot
.33099 .39456 Mdot
.43185 .25421 Mdot
.46671 .68658 Mdot
.40085 .32769 Mdot
.51273 .66223 Mdot
.30277 .56839 Mdot
.32519 .40853 Mdot
.64231 .50292 Mdot
.57899 .35983 Mdot
.71799 .49573 Mdot
.59265 .57642 Mdot
.26834 .4619 Mdot
.16424 .43714 Mdot
.40335 .27871 Mdot
.5589 .67503 Mdot
.67239 .50169 Mdot
.44786 .68138 Mdot
.84813 .39578 Mdot
.67562 .51738 Mdot
.66936 .49168 Mdot
.30333 .55144 Mdot
.24268 .57372 Mdot
.51173 .6596 Mdot
.71126 .53426 Mdot
.43054 .25476 Mdot
.32521 .41725 Mdot
.46016 .62393 Mdot
.51545 .54204 Mdot
.70558 .49034 Mdot
.42051 .29002 Mdot
.25564 .55584 Mdot
.40145 .3115 Mdot
.70205 .4998 Mdot
.44043 .28489 Mdot
.64197 .2832 Mdot
.4395 .32894 Mdot
.48713 .63263 Mdot
.46531 .65656 Mdot
.72541 .55062 Mdot
.70397 .53234 Mdot
.50311 .61638 Mdot
.4861 .66722 Mdot
.6801 .49939 Mdot
.41951 .25338 Mdot
.61225 .57999 Mdot
.50386 .62842 Mdot
.46233 .6537 Mdot
.32792 .39031 Mdot
.31963 .61289 Mdot
.33671 .57189 Mdot
.47996 .61317 Mdot
.34698 .39945 Mdot
.65983 .50383 Mdot
.46959 .66606 Mdot
.24832 .5636 Mdot
.45138 .27796 Mdot
.46123 .60982 Mdot
.49778 .49792 Mdot
.41934 .64384 Mdot
.34637 .76919 Mdot
.43022 .63756 Mdot
.69564 .5002 Mdot
.68947 .49259 Mdot
.43008 .24641 Mdot
.69427 .50686 Mdot
.50153 .48131 Mdot
.61366 .33797 Mdot
.59057 .75497 Mdot
.50488 .47959 Mdot
.5141 .5977 Mdot
.3073 .45872 Mdot
.51951 .5384 Mdot
.52593 .558 Mdot
.38132 .37333 Mdot
.49444 .50772 Mdot
.66862 .51101 Mdot
.6833 .45236 Mdot
.52146 .64138 Mdot
.56487 .33051 Mdot
.51812 .54197 Mdot
.46255 .60841 Mdot
.43623 .692 Mdot
.60803 .52663 Mdot
.56038 .34876 Mdot
.51983 .69894 Mdot
.4606 .62354 Mdot
.59689 .59473 Mdot
.46854 .6292 Mdot
.34975 .42231 Mdot
.68272 .52635 Mdot
.39325 .32191 Mdot
.32065 .41425 Mdot
.51696 .58676 Mdot
.31231 .42287 Mdot
.40571 .32723 Mdot
.59355 .3529 Mdot
.48725 .63607 Mdot
.36311 .38593 Mdot
.35515 .39344 Mdot
.49242 .58732 Mdot
.68709 .49113 Mdot
.51507 .69238 Mdot
.46532 .66731 Mdot
.42682 .64087 Mdot
.71614 .50914 Mdot
.60126 .18975 Mdot
.45838 .68188 Mdot
.45459 .47952 Mdot
.6517 .54362 Mdot
.51394 .50315 Mdot
.39238 .32817 Mdot
.50788 .60294 Mdot
.60638 .3206 Mdot
.61186 .33631 Mdot
.42324 .26484 Mdot
.71189 .49671 Mdot
.41171 .29195 Mdot
.49615 .68691 Mdot
.51864 .54439 Mdot
.45985 .62661 Mdot
.50152 .33718 Mdot
.68177 .28979 Mdot
.67089 .53975 Mdot
.41973 .27298 Mdot
.28343 .58963 Mdot
.62303 .34716 Mdot
.37752 .33949 Mdot
.64923 .51649 Mdot
.71863 .52592 Mdot
.71372 .51473 Mdot
.35388 .4014 Mdot
.40874 .30298 Mdot
.73156 .48886 Mdot
.7263 .48162 Mdot
.47628 .60013 Mdot
.46059 .62228 Mdot
.65833 .51088 Mdot
.39037 .27029 Mdot
.33297 .39649 Mdot
.38599 .33055 Mdot
.27642 .74102 Mdot
.56252 .3545 Mdot
.68168 .73741 Mdot
.48474 .6121 Mdot
.87362 .62626 Mdot
.49656 .64179 Mdot
.46106 .63274 Mdot
.73142 .49344 Mdot
.3258 .38649 Mdot
.32782 .41779 Mdot
.67355 .50015 Mdot
.70416 .54597 Mdot
.33803 .43063 Mdot
.35293 .57469 Mdot
.31611 .75171 Mdot
.31098 .58009 Mdot
.68277 .54334 Mdot
.57383 .75465 Mdot
.58476 .34215 Mdot
.65112 .54812 Mdot
.64596 .30321 Mdot
.44105 .28029 Mdot
.44436 .32079 Mdot
.60172 .35339 Mdot
.45477 .68017 Mdot
.38314 .333 Mdot
.41039 .66527 Mdot
.58699 .27453 Mdot
.47784 .49136 Mdot
.17947 .57587 Mdot
.49034 .6451 Mdot
.57432 .51619 Mdot
.79258 .41942 Mdot
.49384 .60069 Mdot
.7048 .70171 Mdot
.31412 .40504 Mdot
.66376 .55249 Mdot
.55765 .35756 Mdot
.80313 .55848 Mdot
.46748 .65601 Mdot
.70021 .53893 Mdot
.57501 .36224 Mdot
.67296 .28138 Mdot
.44524 .48495 Mdot
.48441 .59828 Mdot
.84641 .3749 Mdot
.67095 .47937 Mdot
.39365 .32353 Mdot
.62007 .71109 Mdot
.71662 .54254 Mdot
.43482 .49335 Mdot
.42423 .25786 Mdot
.33904 .6248 Mdot
.70001 .5427 Mdot
.33839 .38101 Mdot
.69071 .51728 Mdot
.32277 .43303 Mdot
.7348 .49592 Mdot
.43122 .27954 Mdot
.45041 .66914 Mdot
.42819 .27702 Mdot
.32687 .43848 Mdot
.40775 .27387 Mdot
.55823 .358 Mdot
.49648 .51994 Mdot
.60327 .34334 Mdot
.27656 .6388 Mdot
.67831 .63526 Mdot
.57729 .35177 Mdot
.38943 .59735 Mdot
.48506 .64018 Mdot
.72824 .53425 Mdot
.39401 .3175 Mdot
.41256 .3531 Mdot
.30234 .59693 Mdot
.70692 .50093 Mdot
.42423 .28677 Mdot
.57979 .74308 Mdot
.64695 .25059 Mdot
.41843 .68337 Mdot
.4314 .231 Mdot
.68653 .49847 Mdot
.40427 .35287 Mdot
.32348 .57563 Mdot
.72042 .5283 Mdot
.44861 .30043 Mdot
.57248 .35513 Mdot
.60735 .32121 Mdot
.4908 .63866 Mdot
.55105 .34545 Mdot
.44038 .33338 Mdot
.58375 .6262 Mdot
.6665 .4995 Mdot
.68668 .2961 Mdot
.33589 .39113 Mdot
.39636 .30911 Mdot
.515 .57427 Mdot
.72144 .48745 Mdot
.43804 .30936 Mdot
.77573 .72364 Mdot
.29695 .78463 Mdot
.42357 .28856 Mdot
.68462 .52603 Mdot
.70328 .52918 Mdot
.50766 .6289 Mdot
.29966 .59399 Mdot
.42151 .29626 Mdot
.50476 .18194 Mdot
.30248 .66467 Mdot
.49877 .51611 Mdot
.17895 .37833 Mdot
.42115 .65167 Mdot
.42672 .63661 Mdot
.56673 .3424 Mdot
.44511 .66181 Mdot
.70003 .54634 Mdot
.49688 .64263 Mdot
.59948 .31596 Mdot
.42532 .26611 Mdot
.46797 .66074 Mdot
.32554 .39587 Mdot
.58467 .32205 Mdot
.58625 .31891 Mdot
.44099 .28981 Mdot
.71206 .49833 Mdot
.81928 .54382 Mdot
.40222 .30873 Mdot
.4341 .62714 Mdot
.50416 .52313 Mdot
.47986 .68625 Mdot
.76027 .52657 Mdot
.65767 .54614 Mdot
.39223 .31691 Mdot
.48854 .55483 Mdot
.5971 .33003 Mdot
.43423 .34161 Mdot
.41906 .65532 Mdot
.44939 .28576 Mdot
.46183 .45158 Mdot
.33748 .229 Mdot
.70844 .47162 Mdot
.45353 .44844 Mdot
.72034 .52357 Mdot
.49607 .50792 Mdot
.21219 .49366 Mdot
.33371 .39498 Mdot
.38849 .3071 Mdot
.69102 .31366 Mdot
.42282 .27519 Mdot
.45256 .6626 Mdot
.4865 .64881 Mdot
.41534 .33307 Mdot
.34736 .39598 Mdot
.39438 .4642 Mdot
.35244 .37852 Mdot
.68818 .53116 Mdot
.37764 .5802 Mdot
.23872 .71517 Mdot
.45039 .32193 Mdot
.61103 .3487 Mdot
.70117 .57304 Mdot
.51421 .59557 Mdot
.55863 .35514 Mdot
.5811 .32135 Mdot
.31701 .43529 Mdot
.40626 .28921 Mdot
.6438 .50796 Mdot
.62489 .33222 Mdot
.72169 .53392 Mdot
.25245 .55219 Mdot
.51896 .52521 Mdot
.51336 .7209 Mdot
.51934 .59473 Mdot
.31043 .59728 Mdot
.62693 .33371 Mdot
.4806 .64523 Mdot
.4776 .70936 Mdot
.56987 .35635 Mdot
.31307 .43393 Mdot
.48179 .50029 Mdot
.42626 .2871 Mdot
.85424 .44234 Mdot
.48596 .62913 Mdot
.46048 .67022 Mdot
.56633 .35703 Mdot
.72933 .68821 Mdot
.6522 .51057 Mdot
.69934 .48965 Mdot
.41129 .3174 Mdot
.31311 .55222 Mdot
.48974 .67016 Mdot
.48568 .63575 Mdot
.41859 .33495 Mdot
.50917 .51284 Mdot
.16509 .41927 Mdot
.46491 .64847 Mdot
.59129 .33769 Mdot
.46407 .47919 Mdot
.60581 .36098 Mdot
.46715 .69705 Mdot
.45173 .657 Mdot
.45501 .60586 Mdot
.41789 .65455 Mdot
.59806 .34518 Mdot
.51627 .59131 Mdot
.5183 .62606 Mdot
.67108 .51264 Mdot
.42847 .66483 Mdot
.30415 .66514 Mdot
.4673 .6503 Mdot
.31757 .40068 Mdot
.3359 .56822 Mdot
.42824 .64489 Mdot
.42689 .66186 Mdot
.29954 .66415 Mdot
.43803 .65587 Mdot
.56822 .36056 Mdot
.70624 .52471 Mdot
.59775 .3285 Mdot
.60947 .35175 Mdot
.4402 .3061 Mdot
.30529 .42646 Mdot
.50748 .67352 Mdot
.34823 .41931 Mdot
.50723 .66102 Mdot
.52244 .68789 Mdot
.29366 .61846 Mdot
.31923 .57248 Mdot
.36466 .39909 Mdot
.48403 .63343 Mdot
.40766 .32313 Mdot
.39477 .30503 Mdot
.4154 .52771 Mdot
.49837 .56533 Mdot
.55116 .3549 Mdot
.58197 .35529 Mdot
.42862 .39776 Mdot
.32838 .22651 Mdot
.36116 .4016 Mdot
.40095 .4613 Mdot
.41522 .66523 Mdot
.46387 .67913 Mdot
.50888 .5678 Mdot
.43189 .31833 Mdot
.49409 .50976 Mdot
.38426 .30415 Mdot
.5695 .37134 Mdot
.58344 .32656 Mdot
.48909 .63926 Mdot
.65153 .82041 Mdot
.67196 .52851 Mdot
.70497 .52851 Mdot
.6022 .3158 Mdot
.39603 .29312 Mdot
.51214 .55893 Mdot
.85968 .48466 Mdot
.65602 .54207 Mdot
.34901 .38483 Mdot
.43397 .65632 Mdot
.43792 .27783 Mdot
.66486 .51922 Mdot
.36238 .38659 Mdot
.43593 .67781 Mdot
.41987 .25948 Mdot
.47738 .64626 Mdot
.57573 .68433 Mdot
.66681 .50759 Mdot
.30607 .62461 Mdot
.7041 .47871 Mdot
.5972 .34401 Mdot
.62073 .34276 Mdot
.45383 .65763 Mdot
.86177 .47294 Mdot
.63189 .50468 Mdot
.62263 .31537 Mdot
.31512 .39527 Mdot
.49705 .52932 Mdot
.30735 .42573 Mdot
.41732 .32876 Mdot
.33089 .3949 Mdot
.43876 .30779 Mdot
.42033 .24717 Mdot
.65573 .49083 Mdot
.33962 .41533 Mdot
.69976 .68316 Mdot
.51752 .55206 Mdot
.29806 .42102 Mdot
.44152 .63453 Mdot
.50637 .64702 Mdot
.42642 .30026 Mdot
.35361 .41098 Mdot
.50531 .58855 Mdot
.69106 .36238 Mdot
.61812 .34829 Mdot
.55839 .35925 Mdot
.5094 .55215 Mdot
.40985 .34927 Mdot
.65787 .48951 Mdot
.27971 .59725 Mdot
.64593 .49435 Mdot
.48476 .63223 Mdot
.50493 .67674 Mdot
.70714 .47528 Mdot
.67002 .48273 Mdot
.45281 .65354 Mdot
.6228 .77246 Mdot
.51572 .57774 Mdot
.6111 .32226 Mdot
.68559 .53151 Mdot
.69996 .5346 Mdot
.43989 .33286 Mdot
.70165 .48853 Mdot
.48651 .71702 Mdot
.5651 .36708 Mdot
.51996 .63154 Mdot
.59794 .33279 Mdot
.33283 .36057 Mdot
.43118 .29692 Mdot
.68213 .30379 Mdot
.69585 .48748 Mdot
.49986 .61206 Mdot
.68872 .48502 Mdot
.31269 .40182 Mdot
.69145 .54147 Mdot
.6895 .56502 Mdot
.47413 .6191 Mdot
.51507 .58582 Mdot
.50968 .49952 Mdot
.30609 .59438 Mdot
.67185 .52088 Mdot
.49752 .6833 Mdot
.4996 .64577 Mdot
.48772 .66414 Mdot
.29085 .60767 Mdot
.70224 .4822 Mdot
.75554 .67032 Mdot
.70857 .46456 Mdot
.66552 .51106 Mdot
.34848 .80489 Mdot
.50857 .49247 Mdot
.4995 .54411 Mdot
.54471 .32701 Mdot
.46251 .65029 Mdot
.41494 .28633 Mdot
.44207 .61868 Mdot
.51119 .57009 Mdot
.42864 .64959 Mdot
.32634 .42777 Mdot
.46955 .6895 Mdot
.50363 .5107 Mdot
.39951 .30946 Mdot
.49212 .60274 Mdot
.46249 .65964 Mdot
.51059 .51394 Mdot
.68032 .48542 Mdot
.71974 .51337 Mdot
.65977 .48036 Mdot
.32555 .43578 Mdot
.57778 .34249 Mdot
.44111 .62019 Mdot
.40976 .31976 Mdot
.41477 .28418 Mdot
.71427 .48658 Mdot
.40917 .34086 Mdot
.57886 .32831 Mdot
.45849 .63575 Mdot
.59855 .34437 Mdot
.32405 .42887 Mdot
.68141 .52643 Mdot
.43913 .62577 Mdot
.48611 .59262 Mdot
.68918 .49259 Mdot
.51833 .58052 Mdot
.31009 .40228 Mdot
.42445 .3362 Mdot
.66558 .53582 Mdot
.6135 .33661 Mdot
.43937 .33178 Mdot
.49593 .60538 Mdot
.4519 .84082 Mdot
.4455 .66098 Mdot
.48905 .66715 Mdot
.63833 .48747 Mdot
.45141 .69316 Mdot
.42613 .27424 Mdot
.69998 .48455 Mdot
.50538 .64113 Mdot
.28463 .66482 Mdot
.36731 .36779 Mdot
.45082 .32543 Mdot
.44461 .64333 Mdot
.55776 .79222 Mdot
.49778 .61953 Mdot
.69775 .32035 Mdot
.29429 .61853 Mdot
.65055 .31943 Mdot
.51579 .71742 Mdot
.61942 .31378 Mdot
.50657 .51973 Mdot
.43935 .29725 Mdot
.66322 .73346 Mdot
.44953 .65208 Mdot
.67514 .6126 Mdot
.44421 .62041 Mdot
.58864 .32768 Mdot
.71681 .68624 Mdot
.39465 .34091 Mdot
.17573 .4509 Mdot
.43771 .67542 Mdot
.65109 .51884 Mdot
.37681 .30993 Mdot
.49884 .54083 Mdot
.51321 .58605 Mdot
.3542 .41579 Mdot
.43643 .38898 Mdot
.50557 .70244 Mdot
.59928 .33041 Mdot
.47266 .68117 Mdot
.47254 .59267 Mdot
.64125 .23083 Mdot
.67703 .5059 Mdot
.58813 .35896 Mdot
.32114 .23738 Mdot
.48209 .63964 Mdot
.71907 .52354 Mdot
.70292 .51066 Mdot
.34072 .42432 Mdot
.63712 .35207 Mdot
.45586 .37763 Mdot
.63588 .81272 Mdot
.54161 .68881 Mdot
.43125 .32182 Mdot
.50266 .46955 Mdot
.44289 .61721 Mdot
.26926 .46159 Mdot
.61478 .34638 Mdot
.45732 .67074 Mdot
.70289 .60478 Mdot
.68923 .50169 Mdot
.47232 .64295 Mdot
.32906 .39849 Mdot
.8319 .53492 Mdot
.56297 .74821 Mdot
.57791 .78341 Mdot
.43036 .2549 Mdot
.51009 .66812 Mdot
.48607 .71628 Mdot
.51364 .50537 Mdot
.47046 .69804 Mdot
.39448 .32021 Mdot
.47291 .45199 Mdot
.33404 .40126 Mdot
.66539 .52237 Mdot
.50652 .52526 Mdot
.44456 .62038 Mdot
.51376 .6529 Mdot
.31911 .3932 Mdot
.46428 .60061 Mdot
.62495 .72072 Mdot
.50323 .47309 Mdot
.4386 .32843 Mdot
.673 .54264 Mdot
.50695 .67265 Mdot
.49783 .53424 Mdot
.46404 .62546 Mdot
.6588 .57451 Mdot
.45941 .67428 Mdot
.67424 .34952 Mdot
.69814 .49268 Mdot
.60981 .32864 Mdot
.4179 .65776 Mdot
.47488 .65075 Mdot
.44666 .44852 Mdot
.51365 .55962 Mdot
.43049 .66182 Mdot
.72205 .50757 Mdot
.6678 .52564 Mdot
.65182 .51773 Mdot
.44892 .31441 Mdot
.30611 .58229 Mdot
.60135 .34043 Mdot
.50858 .56738 Mdot
.62493 .33188 Mdot
.45022 .75731 Mdot
.31723 .43061 Mdot
.67304 .29388 Mdot
.45662 .63918 Mdot
.71073 .50718 Mdot
.30171 .73908 Mdot
.71068 .48375 Mdot
.53844 .31579 Mdot
.61683 .34399 Mdot
.6781 .51888 Mdot
.44161 .64955 Mdot
.31816 .59286 Mdot
.58074 .7929 Mdot
.62371 .34546 Mdot
.50355 .55758 Mdot
.30949 .36514 Mdot
.44094 .26805 Mdot
.33203 .79337 Mdot
.62176 .32709 Mdot
.79349 .41954 Mdot
.50401 .62936 Mdot
.68241 .48764 Mdot
.5875 .34888 Mdot
.57498 .32384 Mdot
.39614 .3431 Mdot
.48017 .59956 Mdot
.47421 .6486 Mdot
.49825 .49769 Mdot
.60119 .34887 Mdot
.49258 .55728 Mdot
.48868 .59672 Mdot
.53851 .29688 Mdot
.65072 .53167 Mdot
.59641 .18569 Mdot
.39248 .61304 Mdot
.70157 .60549 Mdot
.56368 .19383 Mdot
.66049 .53031 Mdot
.45118 .67912 Mdot
.51025 .56001 Mdot
.42023 .33892 Mdot
.44766 .64552 Mdot
.41787 .27346 Mdot
.58219 .33312 Mdot
.67827 .36223 Mdot
.38596 .61094 Mdot
.56546 .28723 Mdot
.44869 .6649 Mdot
.57005 .74397 Mdot
.33804 .40867 Mdot
.55874 .36168 Mdot
.65538 .49676 Mdot
.48733 .68635 Mdot
.4043 .34497 Mdot
.44538 .27734 Mdot
.68725 .50437 Mdot
.77859 .4235 Mdot
.68599 .30625 Mdot
.51784 .57547 Mdot
.40082 .33652 Mdot
.50222 .54544 Mdot
.549 .78326 Mdot
.62568 .32259 Mdot
.3342 .40234 Mdot
.44367 .29538 Mdot
.56335 .32996 Mdot
.5066 .64555 Mdot
.68418 .51078 Mdot
.68566 .47329 Mdot
.42099 .5159 Mdot
.42297 .28589 Mdot
.31658 .41959 Mdot
.43041 .50612 Mdot
.38868 .56459 Mdot
.32299 .40814 Mdot
.45036 .31341 Mdot
.68558 .53705 Mdot
.70109 .50098 Mdot
.70649 .52203 Mdot
.68268 .73535 Mdot
.65845 .54629 Mdot
.26078 .49296 Mdot
.46868 .69783 Mdot
.58078 .75082 Mdot
.50093 .66398 Mdot
.55772 .35707 Mdot
.66773 .50304 Mdot
.29536 .62028 Mdot
.41505 .66128 Mdot
.58543 .79308 Mdot
.47949 .66948 Mdot
.46025 .47875 Mdot
.462 .65167 Mdot
.58643 .68611 Mdot
.67243 .5553 Mdot
.44074 .67938 Mdot
.58433 .36903 Mdot
.30913 .41746 Mdot
.73483 .51325 Mdot
.44221 .67218 Mdot
.7579 .45861 Mdot
.44171 .63378 Mdot
.6774 .35843 Mdot
.42996 .50019 Mdot
.37574 .42724 Mdot
.48764 .67892 Mdot
.37942 .32797 Mdot
.40969 .69582 Mdot
.57247 .75969 Mdot
.62432 .34263 Mdot
.57498 .74397 Mdot
.38357 .32037 Mdot
.71932 .68542 Mdot
.51816 .57033 Mdot
.33744 .39862 Mdot
.49328 .4614 Mdot
.61578 .32534 Mdot
.45312 .64481 Mdot
.44933 .68027 Mdot
.47615 .49596 Mdot
.53811 .78185 Mdot
.51335 .51899 Mdot
.36509 .39568 Mdot
.55371 .7608 Mdot
.43208 .66259 Mdot
.44584 .33622 Mdot
.71687 .50167 Mdot
.71243 .67977 Mdot
.73117 .67256 Mdot
.49265 .59875 Mdot
.67708 .51575 Mdot
.71178 .49675 Mdot
.24814 .69765 Mdot
.34384 .40502 Mdot
.46462 .67431 Mdot
.4545 .44591 Mdot
.44098 .62089 Mdot
.58546 .33547 Mdot
.41911 .67476 Mdot
.43042 .29488 Mdot
.32689 .57763 Mdot
.45065 .30768 Mdot
.48846 .66238 Mdot
.69164 .51865 Mdot
.60923 .35578 Mdot
.41886 .24517 Mdot
.63659 .3524 Mdot
.25962 .49413 Mdot
.42317 .39251 Mdot
.36129 .40013 Mdot
.31302 .43107 Mdot
.55855 .36111 Mdot
.45199 .63753 Mdot
.29256 .60119 Mdot
.40101 .64405 Mdot
.46302 .64461 Mdot
.44594 .67106 Mdot
.56325 .31469 Mdot
.61723 .34134 Mdot
.43787 .28106 Mdot
.4526 .65208 Mdot
.49214 .6883 Mdot
.6861 .51945 Mdot
.35955 .39767 Mdot
.43794 .32138 Mdot
.3369 .43344 Mdot
.40138 .31832 Mdot
.34776 .77023 Mdot
.51859 .53333 Mdot
.31393 .42523 Mdot
.62077 .32122 Mdot
.7116 .51853 Mdot
.50638 .4868 Mdot
.42041 .32162 Mdot
.40518 .341 Mdot
.50956 .64597 Mdot
.66564 .51808 Mdot
.69791 .48883 Mdot
.33753 .43173 Mdot
.5806 .3543 Mdot
.40915 .67749 Mdot
.51801 .59744 Mdot
.40624 .22947 Mdot
.41344 .34429 Mdot
.56273 .75757 Mdot
.6787 .46565 Mdot
.46961 .62555 Mdot
.71902 .51885 Mdot
.47236 .65999 Mdot
.71446 .56436 Mdot
.67477 .47816 Mdot
.43836 .68886 Mdot
.44627 .59695 Mdot
.43374 .31529 Mdot
.2089 .65494 Mdot
.42889 .69247 Mdot
.63245 .28982 Mdot
.44813 .61257 Mdot
.16255 .43847 Mdot
.2918 .72969 Mdot
.44779 .63519 Mdot
.46929 .68856 Mdot
.59752 .83383 Mdot
.49623 .61977 Mdot
.49913 .5075 Mdot
.51851 .56707 Mdot
.7177 .52477 Mdot
.45643 .44822 Mdot
.30672 .5971 Mdot
.34619 .40962 Mdot
.41163 .31841 Mdot
.24541 .57137 Mdot
.32193 .43354 Mdot
.6923 .49923 Mdot
.40887 .67819 Mdot
.6468 .48202 Mdot
.388 .35585 Mdot
.50884 .53423 Mdot
.58583 .33044 Mdot
.29743 .59944 Mdot
.40053 .34443 Mdot
.61417 .33834 Mdot
.499 .62995 Mdot
.39419 .27188 Mdot
.5938 .36607 Mdot
.21407 .66805 Mdot
.56563 .33917 Mdot
.61722 .33305 Mdot
.30123 .58881 Mdot
.34633 .40962 Mdot
.47752 .45529 Mdot
.52706 .66574 Mdot
.59481 .36138 Mdot
.1866 .4668 Mdot
.40138 .34783 Mdot
.29718 .57083 Mdot
.67103 .55576 Mdot
.5176 .53884 Mdot
.4481 .67001 Mdot
.56499 .34675 Mdot
.48589 .5489 Mdot
.44461 .44843 Mdot
.59286 .32192 Mdot
.41448 .64972 Mdot
.31853 .55392 Mdot
.49869 .53116 Mdot
.50698 .49123 Mdot
.35955 .3849 Mdot
.33706 .25876 Mdot
.7105 .50036 Mdot
.34626 .38528 Mdot
.28879 .63851 Mdot
.48055 .67168 Mdot
.59566 .34586 Mdot
.50685 .52711 Mdot
.61066 .33456 Mdot
.33166 .41287 Mdot
.3101 .40066 Mdot
.67174 .51149 Mdot
.65291 .51266 Mdot
.49335 .4708 Mdot
.30179 .67067 Mdot
.46103 .61103 Mdot
.66811 .62432 Mdot
.67291 .48075 Mdot
.70286 .71497 Mdot
.35084 .40632 Mdot
.35811 .40044 Mdot
.51691 .75885 Mdot
.47234 .61239 Mdot
.46333 .47849 Mdot
.42756 .64629 Mdot
.19996 .44437 Mdot
.44136 .62417 Mdot
.41531 .33757 Mdot
.42267 .65968 Mdot
.78753 .4914 Mdot
.50551 .61147 Mdot
.43561 .66362 Mdot
.41405 .30446 Mdot
.50943 .66236 Mdot
.42804 .29754 Mdot
.45801 .68012 Mdot
.45321 .35542 Mdot
.40982 .31918 Mdot
.29719 .39643 Mdot
.44682 .50603 Mdot
.5029 .50012 Mdot
.33511 .42469 Mdot
.3605 .40482 Mdot
.25698 .55083 Mdot
.67844 .53401 Mdot
.74948 .60353 Mdot
.43483 .65694 Mdot
.40651 .34822 Mdot
.5778 .33598 Mdot
.49626 .597 Mdot
.49461 .65242 Mdot
.42873 .69215 Mdot
.67286 .51543 Mdot
.43067 .34279 Mdot
.33209 .42016 Mdot
.40737 .28533 Mdot
.45246 .35006 Mdot
.43228 .30233 Mdot
.43263 .59757 Mdot
.50723 .64891 Mdot
.48462 .7163 Mdot
.69353 .65266 Mdot
.32359 .45999 Mdot
.68517 .50753 Mdot
.50528 .51904 Mdot
.31097 .42839 Mdot
.34474 .55705 Mdot
.71522 .50864 Mdot
.41688 .33492 Mdot
.47771 .64656 Mdot
.5198 .52575 Mdot
.52664 .66691 Mdot
.72233 .53652 Mdot
.29928 .4299 Mdot
.41771 .31601 Mdot
.49955 .52078 Mdot
.30812 .57908 Mdot
.77242 .63951 Mdot
.27411 .63118 Mdot
.47428 .65497 Mdot
.33639 .43172 Mdot
.66506 .51961 Mdot
.47133 .47951 Mdot
.56811 .35198 Mdot
.3013 .59456 Mdot
.44677 .66438 Mdot
.52024 .335 Mdot
.69289 .51758 Mdot
.34475 .394 Mdot
.56448 .34589 Mdot
.34387 .401 Mdot
.49539 .53114 Mdot
.70414 .46328 Mdot
.51299 .58508 Mdot
.42946 .63843 Mdot
.57944 .33652 Mdot
.70738 .49671 Mdot
.45627 .35746 Mdot
.48277 .46587 Mdot
.41508 .33238 Mdot
.34459 .56464 Mdot
.66665 .52332 Mdot
.51093 .33005 Mdot
.40835 .28347 Mdot
.54619 .34213 Mdot
.32714 .60426 Mdot
.57929 .32618 Mdot
.43816 .66773 Mdot
.70025 .52512 Mdot
.62456 .34468 Mdot
.38333 .25356 Mdot
.63184 .78298 Mdot
.48972 .46451 Mdot
.48586 .64255 Mdot
.7044 .3193 Mdot
.79341 .44168 Mdot
.71704 .55633 Mdot
.61762 .32177 Mdot
.45835 .66472 Mdot
.51889 .57566 Mdot
.43473 .67366 Mdot
.59972 .35854 Mdot
.57545 .4005 Mdot
.3873 .32375 Mdot
.48011 .64345 Mdot
.32711 .39419 Mdot
.43272 .29054 Mdot
.43344 .26193 Mdot
.4445 .29571 Mdot
.65576 .49734 Mdot
.51751 .52436 Mdot
.51935 .56519 Mdot
.2722 .7014 Mdot
.61284 .32889 Mdot
.50296 .50061 Mdot
.46339 .68744 Mdot
.26074 .49785 Mdot
.70915 .51084 Mdot
.42078 .31134 Mdot
.4616 .67056 Mdot
.42313 .51075 Mdot
.51059 .52307 Mdot
.40638 .30512 Mdot
.66683 .48397 Mdot
.61221 .50215 Mdot
.4502 .6432 Mdot
.45721 .60707 Mdot
.68723 .49543 Mdot
.81147 .45802 Mdot
.30998 .5745 Mdot
.47065 .65942 Mdot
.61401 .33335 Mdot
.7877 .35353 Mdot
.50029 .63484 Mdot
.63458 .51679 Mdot
.49396 .5021 Mdot
.72397 .465 Mdot
.61373 .73426 Mdot
.48922 .57415 Mdot
.58318 .46619 Mdot
.37378 .48118 Mdot
.59109 .50735 Mdot
.21843 .44365 Mdot
.5234 .4392 Mdot
.23037 .69754 Mdot
.55787 .36561 Mdot
.57582 .69611 Mdot
.76471 .73078 Mdot
.7842 .41614 Mdot
.46394 .42497 Mdot
.61482 .40697 Mdot
.36554 .35031 Mdot
.16783 .40654 Mdot
.38121 .31211 Mdot
.22389 .43701 Mdot
.43324 .63493 Mdot
.80566 .45857 Mdot
.57582 .70701 Mdot
.39236 .40233 Mdot
.64619 .28269 Mdot
.42884 .50415 Mdot
.51976 .82474 Mdot
.59006 .27592 Mdot
.41274 .80995 Mdot
.72188 .60367 Mdot
.36426 .23164 Mdot
.35996 .5802 Mdot
.24005 .55237 Mdot
.58409 .72712 Mdot
.63464 .45743 Mdot
.57768 .38094 Mdot
.60315 .60566 Mdot
.57889 .19532 Mdot
.40466 .33248 Mdot
.71603 .54019 Mdot
.60117 .42108 Mdot
.4679 .81661 Mdot
.58334 .2884 Mdot
.58172 .46681 Mdot
.48565 .46811 Mdot
.58348 .68794 Mdot
.30011 .62612 Mdot
.58471 .66319 Mdot
.44733 .38833 Mdot
.171 .40567 Mdot
.62237 .50675 Mdot
.37428 .25582 Mdot
.32973 .54003 Mdot
.43093 .42091 Mdot
.6041 .69402 Mdot
.32142 .44417 Mdot
.30086 .39117 Mdot
.66703 .48317 Mdot
.50286 .80536 Mdot
.40677 .58261 Mdot
.29304 .64455 Mdot
.38003 .31458 Mdot
.6258 .5522 Mdot
.82877 .53395 Mdot
.78262 .44175 Mdot
.18421 .61023 Mdot
.44965 .83583 Mdot
.19973 .50957 Mdot
.46859 .50072 Mdot
.5715 .29554 Mdot
.27689 .49383 Mdot
.57092 .51565 Mdot
.20055 .54426 Mdot
.66513 .57558 Mdot
.56997 .82161 Mdot
.73178 .43888 Mdot
.48645 .83738 Mdot
.6186 .50789 Mdot
.48706 .70823 Mdot
.73895 .53139 Mdot
.58128 .62166 Mdot
.26362 .64215 Mdot
.49423 .8264 Mdot
.38526 .40346 Mdot
.49164 .52436 Mdot
.77506 .40901 Mdot
.62337 .72083 Mdot
.46915 .37164 Mdot
.31975 .38182 Mdot
.72037 .65492 Mdot
.52445 .83312 Mdot
.59464 .4614 Mdot
.44088 .78056 Mdot
.53619 .29713 Mdot
.46739 .25974 Mdot
.42904 .26176 Mdot
.60123 .31077 Mdot
.42922 .81866 Mdot
.7021 .51999 Mdot
.20268 .65184 Mdot
.53196 .45603 Mdot
.53045 .47873 Mdot
.53015 .83318 Mdot
.18383 .55992 Mdot
.5983 .73239 Mdot
.35016 .47168 Mdot
.65343 .26146 Mdot
.57983 .56425 Mdot
.54699 .29779 Mdot
.31203 .37209 Mdot
.6872 .33989 Mdot
.44377 .81996 Mdot
.18869 .52426 Mdot
.65668 .80792 Mdot
.30275 .64895 Mdot
.26622 .39335 Mdot
.62406 .50648 Mdot
.51597 .40003 Mdot
.47805 .36939 Mdot
.47828 .83976 Mdot
.5568 .75056 Mdot
.7504 .319 Mdot
.21345 .46109 Mdot
.73383 .67611 Mdot
.72037 .34905 Mdot
.57429 .41422 Mdot
.5812 .60577 Mdot
.75941 .45479 Mdot
.52277 .6054 Mdot
.26108 .62076 Mdot
.72137 .63999 Mdot
.37437 .41817 Mdot
.31761 .58276 Mdot
.72656 .42205 Mdot
.21651 .55151 Mdot
.76514 .34382 Mdot
.72731 .64954 Mdot
.71188 .47929 Mdot
.20177 .54337 Mdot
.2046 .4777 Mdot
.73675 .32396 Mdot
.31821 .24063 Mdot
.43868 .78191 Mdot
.49855 .35823 Mdot
.48233 .58043 Mdot
.57315 .69895 Mdot
.58638 .7232 Mdot
.18031 .41912 Mdot
.44459 .59169 Mdot
.24194 .67647 Mdot
.63769 .2833 Mdot
.67847 .67094 Mdot
.23589 .61522 Mdot
.68888 .66089 Mdot
.59332 .75348 Mdot
.76629 .52306 Mdot
.64409 .30726 Mdot
.46467 .5627 Mdot
.52902 .82979 Mdot
.43682 .28585 Mdot
.19831 .54552 Mdot
.58237 .28467 Mdot
.39386 .24146 Mdot
.49826 .44326 Mdot
.45526 .42885 Mdot
.38523 .81246 Mdot
.76235 .4017 Mdot
.35109 .33652 Mdot
.66415 .45978 Mdot
.55542 .48621 Mdot
.67488 .62879 Mdot
.40525 .60885 Mdot
.63499 .56162 Mdot
.31005 .40222 Mdot
.6731 .71054 Mdot
.75617 .48527 Mdot
.30634 .24759 Mdot
.42108 .60875 Mdot
.36335 .57945 Mdot
.49768 .4909 Mdot
.27504 .5469 Mdot
.34195 .76851 Mdot
.4822 .56668 Mdot
.18685 .56818 Mdot
.77737 .41646 Mdot
.27102 .5512 Mdot
.47319 .37435 Mdot
.75506 .60623 Mdot
.48955 .83786 Mdot
.31342 .77474 Mdot
.80356 .48219 Mdot
.71282 .34175 Mdot
.28365 .23245 Mdot
.6494 .31349 Mdot
.21879 .65311 Mdot
.58188 .28496 Mdot
.81655 .30354 Mdot
.42468 .27239 Mdot
.26482 .45514 Mdot
.60073 .55953 Mdot
.38361 .54561 Mdot
.48547 .81394 Mdot
.60842 .71715 Mdot
.29685 .4276 Mdot
.72021 .54906 Mdot
.45754 .5879 Mdot
.50835 .81624 Mdot
.53927 .82191 Mdot
.51501 .8143 Mdot
.53684 .37144 Mdot
.59546 .77794 Mdot
.57089 .83733 Mdot
.26616 .48994 Mdot
.4471 .53922 Mdot
.48841 .58396 Mdot
.28829 .67519 Mdot
.21259 .62259 Mdot
.32006 .45315 Mdot
.57974 .56926 Mdot
.62513 .50193 Mdot
.55182 .8413 Mdot
.3281 .76287 Mdot
.58252 .65825 Mdot
.38946 .80749 Mdot
.33654 .33353 Mdot
.24125 .64405 Mdot
.35286 .79729 Mdot
.61656 .45806 Mdot
.5323 .34181 Mdot
.5751 .84488 Mdot
.20927 .49145 Mdot
.61104 .40807 Mdot
.75798 .46465 Mdot
.21001 .63081 Mdot
.71061 .35199 Mdot
.60218 .41297 Mdot
.60414 .54755 Mdot
.78523 .60825 Mdot
.46461 .41709 Mdot
.63207 .46166 Mdot
.46592 .49189 Mdot
.23251 .61892 Mdot
.41379 .27063 Mdot
.20221 .56658 Mdot
.45706 .40243 Mdot
.45486 .53691 Mdot
.25518 .57384 Mdot
.18925 .49146 Mdot
.69228 .43809 Mdot
.5699 .78624 Mdot
.77097 .41111 Mdot
.78111 .3529 Mdot
.73297 .34082 Mdot
.73099 .62345 Mdot
.50863 .6671 Mdot
.47434 .81822 Mdot
.2604 .7471 Mdot
.3629 .80462 Mdot
.74698 .3304 Mdot
.46559 .27932 Mdot
.55309 .34729 Mdot
.26597 .50601 Mdot
.39763 .52555 Mdot
.59388 .44131 Mdot
.40017 .47657 Mdot
.6273 .31499 Mdot
.83177 .5302 Mdot
.51227 .45237 Mdot
.26701 .49469 Mdot
.61044 .60039 Mdot
.54826 .494 Mdot
.546 .78385 Mdot
.70725 .47622 Mdot
.72402 .3077 Mdot
.20124 .54729 Mdot
.43937 .28936 Mdot
.40251 .22722 Mdot
.45209 .56893 Mdot
.47472 .70815 Mdot
.30161 .36786 Mdot
.47092 .5417 Mdot
.70012 .60707 Mdot
.46256 .27657 Mdot
.27655 .73213 Mdot
.20848 .64804 Mdot
.34797 .79479 Mdot
.19739 .50332 Mdot
.38368 .24596 Mdot
.27949 .55441 Mdot
.61558 .29581 Mdot
.61018 .27544 Mdot
.30319 .54703 Mdot
.19541 .48638 Mdot
.59641 .7368 Mdot
.72877 .5448 Mdot
.4982 .57234 Mdot
.30948 .7451 Mdot
.24342 .52986 Mdot
.28678 .53853 Mdot
.7601 .6266 Mdot
.64454 .5277 Mdot
.25039 .42478 Mdot
.65448 .45433 Mdot
.44503 .73899 Mdot
.71692 .33624 Mdot
.63057 .33558 Mdot
.69667 .47265 Mdot
.18817 .49263 Mdot
.34731 .21371 Mdot
.58024 .50288 Mdot
.39472 .59461 Mdot
.44453 .81304 Mdot
.43072 .52637 Mdot
.69791 .34939 Mdot
.80089 .60945 Mdot
.60403 .25982 Mdot
.61551 .51829 Mdot
.46333 .52368 Mdot
.48736 .43969 Mdot
.78731 .51643 Mdot
.72957 .51577 Mdot
.56276 .74547 Mdot
.42936 .82581 Mdot
.43772 .49808 Mdot
.61711 .47062 Mdot
.2805 .59374 Mdot
.49761 .40054 Mdot
.54322 .46912 Mdot
.25053 .5753 Mdot
.59194 .48744 Mdot
.46342 .78404 Mdot
.84808 .50128 Mdot
.57812 .58984 Mdot
.25058 .44476 Mdot
.26876 .50202 Mdot
.72314 .60287 Mdot
.60094 .69081 Mdot
.62443 .26976 Mdot
.42465 .64592 Mdot
.42314 .83218 Mdot
.73185 .43122 Mdot
.26306 .56317 Mdot
.51817 .35606 Mdot
.49192 .60899 Mdot
.49745 .70783 Mdot
.36447 .80308 Mdot
.72579 .46473 Mdot
.81209 .68993 Mdot
.20914 .44986 Mdot
.73033 .56848 Mdot
.60838 .73724 Mdot
.19058 .57823 Mdot
.76601 .53802 Mdot
.5409 .45528 Mdot
.46491 .39764 Mdot
.20327 .60939 Mdot
.73738 .46514 Mdot
.71138 .45611 Mdot
.71563 .31975 Mdot
.57248 .83288 Mdot
.59089 .52618 Mdot
.54225 .36062 Mdot
.33208 .33809 Mdot
.48894 .66875 Mdot
.78068 .42599 Mdot
.67681 .29271 Mdot
.52134 .37191 Mdot
.58402 .53071 Mdot
.25801 .74725 Mdot
.44233 .60815 Mdot
.7593 .40733 Mdot
.80368 .69764 Mdot
.84322 .6583 Mdot
.78213 .48724 Mdot
.47087 .84161 Mdot
.70476 .45616 Mdot
.69684 .35289 Mdot
.62727 .35014 Mdot
.37877 .58068 Mdot
.67092 .61695 Mdot
.39255 .8241 Mdot
.36556 .21065 Mdot
.5435 .30022 Mdot
.60334 .58369 Mdot
.38922 .82466 Mdot
.44941 .60067 Mdot
.25481 .43644 Mdot
.46932 .26238 Mdot
.17472 .45619 Mdot
.18449 .60395 Mdot
.7701 .62267 Mdot
.17522 .42461 Mdot
.22997 .40925 Mdot
.40075 .41148 Mdot
.21135 .64821 Mdot
.53912 .68483 Mdot
.77405 .6049 Mdot
.20238 .5402 Mdot
.70317 .33329 Mdot
.22569 .3031 Mdot
.54895 .47311 Mdot
.47098 .53234 Mdot
.77356 .50216 Mdot
.6841 .34258 Mdot
.68575 .42324 Mdot
.43327 .53924 Mdot
.33906 .57568 Mdot
.58533 .75583 Mdot
.78395 .34634 Mdot
.8092 .61296 Mdot
.48031 .52935 Mdot
.54782 .81451 Mdot
.60284 .27027 Mdot
.30872 .53616 Mdot
.61718 .70512 Mdot
.25154 .52813 Mdot
.33519 .34163 Mdot
.42854 .64759 Mdot
.43498 .82654 Mdot
.33422 .3427 Mdot
.53484 .81587 Mdot
.20199 .65751 Mdot
.39953 .80497 Mdot
.5368 .49674 Mdot
.31454 .36397 Mdot
.21175 .61225 Mdot
.21488 .6159 Mdot
.58535 .81472 Mdot
.23091 .42799 Mdot
.31208 .54799 Mdot
.45211 .51448 Mdot
.38857 .60629 Mdot
.43151 .73791 Mdot
.19112 .58372 Mdot
.75078 .59275 Mdot
.23719 .61058 Mdot
.80001 .49019 Mdot
.19228 .49022 Mdot
.60124 .72652 Mdot
.25388 .53569 Mdot
.50592 .37363 Mdot
.29101 .42897 Mdot
.40072 .34877 Mdot
.63537 .81983 Mdot
.73058 .32667 Mdot
.25444 .68593 Mdot
.74454 .31682 Mdot
.75662 .45236 Mdot
.2185 .43065 Mdot
.74007 .52487 Mdot
.56807 .61629 Mdot
.35702 .23717 Mdot
.2236 .55938 Mdot
.56582 .75118 Mdot
.69841 .31924 Mdot
.75132 .65873 Mdot
.3944 .81786 Mdot
.23631 .62177 Mdot
.69099 .79184 Mdot
.28477 .37467 Mdot
.67463 .70524 Mdot
.49724 .80113 Mdot
.81041 .40178 Mdot
.28737 .53379 Mdot
.53273 .82812 Mdot
.69397 .5573 Mdot
.45455 .83655 Mdot
.57028 .34544 Mdot
.26188 .40759 Mdot
.68587 .31331 Mdot
.27321 .52519 Mdot
.27542 .52463 Mdot
.26101 .70913 Mdot
.76954 .40653 Mdot
.78632 .442 Mdot
.49832 .35748 Mdot
.39076 .29138 Mdot
.37612 .60474 Mdot
.60876 .47163 Mdot
.64647 .80982 Mdot
.50606 .67205 Mdot
.28011 .37125 Mdot
.1932 .55417 Mdot
.61185 .2959 Mdot
.47715 .51227 Mdot
.69173 .32389 Mdot
.78955 .62606 Mdot
.26119 .66182 Mdot
.56325 .83461 Mdot
.47802 .51171 Mdot
.40195 .50886 Mdot
.72105 .69111 Mdot
.62715 .41462 Mdot
.59651 .26663 Mdot
.58911 .4698 Mdot
.4145 .55042 Mdot
.30652 .57493 Mdot
.2009 .5023 Mdot
.24358 .72357 Mdot
.56282 .81497 Mdot
.59904 .26542 Mdot
.27774 .53363 Mdot
.6345 .52114 Mdot
.2302 .55877 Mdot
.6809 .79948 Mdot
.16421 .42411 Mdot
.75826 .46277 Mdot
.19104 .50323 Mdot
.54421 .3908 Mdot
.25448 .44132 Mdot
.29409 .54222 Mdot
.49454 .80124 Mdot
.59685 .57271 Mdot
.71918 .46492 Mdot
.57959 .41825 Mdot
.30362 .60291 Mdot
.50954 .44365 Mdot
.76923 .61163 Mdot
.76558 .3999 Mdot
.69308 .79031 Mdot
.21901 .41326 Mdot
.72054 .68159 Mdot
.74234 .74906 Mdot
.6549 .49214 Mdot
.49632 .43612 Mdot
.47427 .24637 Mdot
.27163 .54486 Mdot
.44297 .27787 Mdot
.49214 .55722 Mdot
.33436 .55833 Mdot
.78911 .50409 Mdot
.36106 .33672 Mdot
.30235 .42599 Mdot
.713 .48217 Mdot
.22955 .41668 Mdot
.69299 .47168 Mdot
.24144 .71734 Mdot
.61738 .45397 Mdot
.58036 .75499 Mdot
.79444 .64025 Mdot
.37692 .24478 Mdot
.79254 .36546 Mdot
.40861 .80987 Mdot
.28917 .66486 Mdot
.73048 .51937 Mdot
.72416 .48372 Mdot
.65487 .46576 Mdot
.61052 .30296 Mdot
.45168 .80951 Mdot
.18599 .55684 Mdot
.39759 .22666 Mdot
.69203 .55164 Mdot
.45762 .50042 Mdot
.47464 .54933 Mdot
.2927 .74388 Mdot
.41109 .28185 Mdot
.50577 .83987 Mdot
.75024 .59796 Mdot
.80854 .42557 Mdot
.60544 .43774 Mdot
.34293 .61524 Mdot
.29745 .52498 Mdot
.37493 .26797 Mdot
.48255 .58219 Mdot
.72617 .56676 Mdot
.65406 .51613 Mdot
.50289 .44278 Mdot
.35083 .39218 Mdot
.30747 .24887 Mdot
.6307 .2947 Mdot
.71719 .62175 Mdot
.18737 .58553 Mdot
.7098 .47588 Mdot
.28597 .37933 Mdot
.36468 .25842 Mdot
.42572 .60888 Mdot
.30382 .68668 Mdot
.61486 .82952 Mdot
.42591 .80745 Mdot
.71922 .49356 Mdot
.77754 .3531 Mdot
.46468 .35684 Mdot
.27432 .72868 Mdot
.74808 .47156 Mdot
.19386 .57034 Mdot
.70752 .66107 Mdot
.33416 .78163 Mdot
.61347 .73363 Mdot
.58605 .4552 Mdot
.19575 .52917 Mdot
.4471 .44493 Mdot
.18744 .50647 Mdot
.78273 .64025 Mdot
.38937 .5838 Mdot
.1775 .46269 Mdot
.5256 .36833 Mdot
.58188 .67031 Mdot
.43217 .72678 Mdot
.59357 .44375 Mdot
.20398 .60434 Mdot
.68895 .48175 Mdot
.35904 .42048 Mdot
.61898 .58723 Mdot
.55659 .28986 Mdot
.44012 .81865 Mdot
.7457 .33436 Mdot
.1891 .54401 Mdot
.39225 .60326 Mdot
.23283 .50638 Mdot
.74533 .5936 Mdot
.29838 .65369 Mdot
.52329 .57462 Mdot
.71832 .64765 Mdot
.41892 .45354 Mdot
.28226 .71955 Mdot
.40998 .71056 Mdot
.48933 .82022 Mdot
.33052 .76103 Mdot
.77583 .4918 Mdot
.46859 .45843 Mdot
.70848 .54718 Mdot
.50926 .83434 Mdot
.26522 .67492 Mdot
.68505 .3341 Mdot
.18463 .6014 Mdot
.24232 .41194 Mdot
.75602 .73793 Mdot
.74818 .40634 Mdot
.46047 .55157 Mdot
.21274 .65815 Mdot
.73488 .43569 Mdot
.23318 .40729 Mdot
.56267 .75197 Mdot
.63363 .49438 Mdot
.53456 .83269 Mdot
.55664 .6555 Mdot
.77919 .44738 Mdot
.52931 .78846 Mdot
.6117 .52912 Mdot
.26797 .67869 Mdot
.5046 .57148 Mdot
.42042 .3357 Mdot
.37721 .5596 Mdot
.17829 .41409 Mdot
.60551 .53092 Mdot
.19003 .57063 Mdot
.19602 .5731 Mdot
.23718 .44587 Mdot
.36937 .27285 Mdot
.75782 .73585 Mdot
.6149 .77024 Mdot
.5161 .64172 Mdot
.72446 .50357 Mdot
.30775 .42961 Mdot
.2171 .46256 Mdot
.48731 .60399 Mdot
.32826 .64118 Mdot
.71649 .657 Mdot
.4094 .82934 Mdot
.5089 .38974 Mdot
.58643 .38268 Mdot
.68678 .55425 Mdot
.68576 .33827 Mdot
.76787 .5476 Mdot
.79022 .41968 Mdot
.20349 .60003 Mdot
.58083 .50326 Mdot
.58384 .46289 Mdot
.77392 .45095 Mdot
.21041 .54722 Mdot
.42971 .40487 Mdot
.60751 .35865 Mdot
.68875 .60982 Mdot
.62107 .80917 Mdot
.76032 .44156 Mdot
.55852 .47929 Mdot
.67258 .44403 Mdot
.40007 .56515 Mdot
.52201 .32018 Mdot
.77201 .41018 Mdot
.70266 .46643 Mdot
.46324 .78825 Mdot
.60491 .50164 Mdot
.30866 .36614 Mdot
.20558 .46618 Mdot
.64342 .44654 Mdot
.19402 .58235 Mdot
.4445 .59833 Mdot
.50581 .81052 Mdot
.26349 .56059 Mdot
.35867 .42456 Mdot
.50159 .58377 Mdot
.63473 .56924 Mdot
.36304 .80277 Mdot
.74792 .4625 Mdot
.57669 .53627 Mdot
.72215 .47216 Mdot
.19923 .63838 Mdot
.33842 .36958 Mdot
.4656 .28627 Mdot
.33363 .47117 Mdot
.34334 .61096 Mdot
.39288 .52982 Mdot
.611 .30144 Mdot
.46546 .59152 Mdot
.41862 .41655 Mdot
.40481 .56607 Mdot
.69319 .61124 Mdot
.23409 .66509 Mdot
.63283 .81821 Mdot
.62839 .55248 Mdot
.18035 .60356 Mdot
.61755 .56776 Mdot
.62123 .52223 Mdot
.22218 .41112 Mdot
.57354 .54663 Mdot
.4448 .59262 Mdot
.36253 .41517 Mdot
.6486 .49936 Mdot
.62981 .81579 Mdot
.58432 .52453 Mdot
.33709 .44432 Mdot
.48775 .35203 Mdot
.54176 .47111 Mdot
.55088 .18571 Mdot
.62714 .28056 Mdot
.20409 .65104 Mdot
.2003 .54497 Mdot
.6419 .32799 Mdot
.70938 .45737 Mdot
.57736 .54746 Mdot
.50333 .81304 Mdot
.42731 .45314 Mdot
.42167 .8121 Mdot
.53612 .36822 Mdot
.70743 .62588 Mdot
.32652 .75656 Mdot
.26071 .62863 Mdot
.29317 .65149 Mdot
.74277 .63951 Mdot
.42044 .76392 Mdot
.50832 .48739 Mdot
.33014 .23503 Mdot
.21042 .32818 Mdot
.66189 .8075 Mdot
.81002 .42936 Mdot
.51675 .6911 Mdot
.23173 .56454 Mdot
.61163 .48885 Mdot
.31502 .53755 Mdot
.48641 .36702 Mdot
.29709 .37149 Mdot
.54285 .38185 Mdot
.77091 .33637 Mdot
.42209 .83093 Mdot
.49666 .58557 Mdot
.39336 .47469 Mdot
.38799 .40016 Mdot
.42933 .26959 Mdot
.59304 .63298 Mdot
.61279 .82844 Mdot
.61421 .35458 Mdot
.47576 .23736 Mdot
.62386 .30215 Mdot
.26439 .70956 Mdot
.43214 .23229 Mdot
.5553 .32808 Mdot
.23945 .71634 Mdot
.79897 .47807 Mdot
.76631 .65216 Mdot
.74886 .31548 Mdot
.29399 .73305 Mdot
.71634 .64501 Mdot
.30529 .37657 Mdot
.46107 .82973 Mdot
.29545 .52748 Mdot
.34777 .33424 Mdot
.43359 .77214 Mdot
.19319 .52317 Mdot
.20777 .45573 Mdot
.61692 .38806 Mdot
.60434 .57367 Mdot
.31936 .21943 Mdot
.38377 .2342 Mdot
.85889 .48762 Mdot
.42566 .80553 Mdot
.65202 .7761 Mdot
.74933 .46689 Mdot
.50357 .3591 Mdot
.49724 .81219 Mdot
.20076 .58233 Mdot
.59309 .55736 Mdot
.3486 .22588 Mdot
.25777 .6082 Mdot
.2351 .54498 Mdot
.52726 .34489 Mdot
.36271 .79658 Mdot
.37426 .25947 Mdot
.52958 .70204 Mdot
.1942 .54147 Mdot
.62852 .57073 Mdot
.30775 .65411 Mdot
.6131 .81022 Mdot
.29596 .68585 Mdot
.19437 .47201 Mdot
.53847 .37861 Mdot
.4554 .3411 Mdot
.62972 .81128 Mdot
.74863 .56153 Mdot
.70751 .66858 Mdot
.80586 .69502 Mdot
.48543 .83699 Mdot
.5764 .55428 Mdot
.41778 .6723 Mdot
.2259 .69182 Mdot
.40257 .36405 Mdot
.24676 .67503 Mdot
.82617 .53738 Mdot
.20844 .44272 Mdot
.40393 .69648 Mdot
.43979 .62909 Mdot
.26733 .48447 Mdot
.77078 .49128 Mdot
.60188 .56494 Mdot
.40178 .24727 Mdot
.19636 .48514 Mdot
.72031 .61963 Mdot
.84786 .50164 Mdot
.78482 .63356 Mdot
.71247 .5352 Mdot
.44626 .82937 Mdot
.55352 .68326 Mdot
.73171 .60061 Mdot
.49387 .80572 Mdot
.41572 .47787 Mdot
.42092 .41277 Mdot
.74293 .59284 Mdot
.27945 .55144 Mdot
.17877 .409 Mdot
.73751 .75491 Mdot
.68003 .62077 Mdot
.51268 .83997 Mdot
.31681 .77888 Mdot
.7088 .54163 Mdot
.59288 .59458 Mdot
.29008 .51801 Mdot
.59486 .50919 Mdot
.5897 .41173 Mdot
.39209 .23971 Mdot
.24381 .40506 Mdot
.29835 .26338 Mdot
.44195 .63933 Mdot
.53015 .36151 Mdot
.39887 .81738 Mdot
.25526 .42695 Mdot
.4096 .81991 Mdot
.73035 .63115 Mdot
.51194 .64778 Mdot
.84569 .65447 Mdot
.69483 .35212 Mdot
.41207 .60814 Mdot
.52635 .65356 Mdot
.52135 .68077 Mdot
.42665 .65369 Mdot
.59297 .40576 Mdot
.25981 .51073 Mdot
.19949 .43928 Mdot
.4611 .82656 Mdot
.67471 .5496 Mdot
.29412 .52456 Mdot
.59299 .36917 Mdot
.32204 .61183 Mdot
.45297 .75628 Mdot
.63332 .33711 Mdot
.19606 .42588 Mdot
.54806 .18643 Mdot
.4559 .39217 Mdot
.51357 .44563 Mdot
.33531 .58011 Mdot
.49247 .47523 Mdot
.21109 .41812 Mdot
.59745 .30334 Mdot
.40198 .40789 Mdot
.18929 .53935 Mdot
.74381 .64816 Mdot
.52812 .33954 Mdot
.27646 .24786 Mdot
.28997 .53611 Mdot
.53001 .36586 Mdot
.57627 .58241 Mdot
.79167 .60909 Mdot
.4607 .79538 Mdot
.43309 .39185 Mdot
.50553 .48112 Mdot
.715 .69457 Mdot
.48305 .81481 Mdot
.6 .31548 Mdot
.25241 .73329 Mdot
.57206 .57883 Mdot
.59598 .63205 Mdot
.61216 .79037 Mdot
.46931 .51326 Mdot
.57017 .74642 Mdot
.5183 .6766 Mdot
.38403 .52366 Mdot
.5191 .17823 Mdot
.47945 .5227 Mdot
.53448 .46618 Mdot
.58253 .49312 Mdot
.24771 .44508 Mdot
.50641 .76091 Mdot
.47066 .67277 Mdot
.32607 .38072 Mdot
.27393 .56831 Mdot
.26823 .40555 Mdot
.2676 .39532 Mdot
.53185 .3392 Mdot
.2095 .42023 Mdot
.20955 .4508 Mdot
.53957 .78038 Mdot
.51189 .82125 Mdot
.42883 .72447 Mdot
.42026 .80461 Mdot
.4807 .39695 Mdot
.69409 .42325 Mdot
.30039 .68479 Mdot
.73174 .75921 Mdot
.72164 .56461 Mdot
.49254 .72682 Mdot
.29838 .76065 Mdot
.38772 .80886 Mdot
.56582 .28731 Mdot
.70593 .32659 Mdot
.19317 .35603 Mdot
.2791 .51853 Mdot
.77724 .34118 Mdot
.42938 .24195 Mdot
.29034 .7477 Mdot
.40905 .57034 Mdot
.5738 .55769 Mdot
.75481 .61384 Mdot
.43002 .60121 Mdot
.40894 .29331 Mdot
.79998 .60931 Mdot
.74466 .63958 Mdot
.4175 .76196 Mdot
.51206 .67841 Mdot
.55242 .42842 Mdot
.63406 .51423 Mdot
.66844 .80284 Mdot
.45357 .28878 Mdot
.40311 .505 Mdot
.84258 .51993 Mdot
.52819 .17942 Mdot
.23638 .40342 Mdot
.57769 .81432 Mdot
.61754 .27619 Mdot
.40897 .55948 Mdot
.64643 .2361 Mdot
.6425 .54492 Mdot
.72673 .5071 Mdot
.63192 .29733 Mdot
.23649 .50934 Mdot
.76649 .41563 Mdot
.77731 .72204 Mdot
.32922 .77881 Mdot
.43608 .60287 Mdot
.86388 .44599 Mdot
.19407 .54646 Mdot
.39609 .48986 Mdot
.75922 .40292 Mdot
.43212 .82481 Mdot
.54961 .3893 Mdot
.21481 .66832 Mdot
.63113 .45497 Mdot
.60993 .52002 Mdot
.23926 .52879 Mdot
.7461 .32052 Mdot
.4598 .50465 Mdot
.85607 .48161 Mdot
.71969 .33356 Mdot
.23986 .55334 Mdot
.73522 .45873 Mdot
.63201 .54274 Mdot
.70658 .57247 Mdot
.62508 .43939 Mdot
.5716 .52107 Mdot
.5604 .47976 Mdot
.59097 .46324 Mdot
.43437 .40413 Mdot
.58564 .43394 Mdot
.68865 .35225 Mdot
.59013 .2939 Mdot
.76509 .62984 Mdot
.18147 .38183 Mdot
.27551 .38445 Mdot
.41237 .27277 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`2Uooooo`;o0000X_ooool001cooooo00?o0000ooooooooool0
YOooool2o`000003ooooool0003o000009oooooo000Looooo`03o`000?oooooooooo0:3ooooo1?l0
0004ooooo`;o0000Woooool001cooooo00?o0000ooooooooool0Voooool2o`0000?ooooo1?l0000:
ooooo`?o00003Oooool3o`0008Sooooo000Looooo`03o`000?oooooooooo09_ooooo0_l0000Aoooo
o`?o00003Oooool4o`0008Oooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44
ooooo`Go00001_ooool00ol0003oooooooooo`2cooooo`;o00002oooool2o`0008Oooooo00001_oo
ooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1_ooool00ol0003oooooooooo`2cooooo`;o00000oooool2o`0008oooooo00000ooooooo410@oooo
o`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003ooooooooo
o`2Hooooo`;o00007_ooool2o`0008oooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0009Sooooo0_l0000Zooooo`;o0000Poooool0
0003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`05oooo
o`03o`000?oooooooooo0<Cooooo0ol00022ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413o
ooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0aOooool4o`00083o
oooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4006
ooooo`03o`000?oooooooooo07?ooooo0_l0001Aooooo`?o0000P?ooool00006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0
KOooool4o`0000;ooooo0_l0001Cooooo`;o0000Ooooool001cooooo00?o0000ooooooooool0KOoo
ool4o`0000oooooo0_l00012ooooo`;o00000_ooool2o`0007oooooo000Looooo`03o`000?oooooo
oooo06Cooooo0_l0000Gooooo`;o000000?oooooo`000?l00000@_ooool2o`0008?ooooo000Loooo
o`03o`000?oooooooooo06Cooooo0_l0000Gooooo`;o000000?oooooo`000?l000005?ooool2o`00
03;ooooo0_l0001mooooo`007?ooool00ol0003oooooooooo`1Wooooo`;o00001Oooool2o`0000go
oooo1?l0000Eooooo`;o0000<_ooool2o`0007gooooo000Looooo`03o`000?oooooooooo06Oooooo
0_l000000ooooooo0000o`000002ooooo`;o00003Oooool5o`0004Kooooo0_l00003ooooo`;o0000
N_ooool001cooooo00?o0000ooooooooool0F?ooool2o`0000gooooo0_l000000ooooooo0000o`00
0007ooooo`;o00002_ooool4o`0000Gooooo0ol0000mooooo`;o00000oooool2o`0007[ooooo000L
ooooo`03o`000?oooooooooo05Sooooo0_l0000=ooooo`?o00002Oooool2o`0000Cooooo0_l00004
ooooo`Co00001Oooool3o`0004?ooooo0_l0001iooooo`007?ooool00ol0003oooooooooo`1Uoooo
o`;o000000?oooooo`000?l000001_ooool2o`0000Oooooo0_l000000ooooooo0000o`000008oooo
o`?o000000Coooooo`000?l0003ooooo0_l00008ooooo`;o0000=Oooool2o`0007Wooooo000Loooo
o`03o`000?oooooooooo067ooooo0_l000001?oooooo0000o`000?l00009ooooo`;o00002_ooool2
o`0000Cooooo0ol000000ooooooo0000o`000004o`000003ooooool0003o000000Sooooo0_l0002`
ooooo`007?ooool00ol0003oooooooooo`1Qooooo`;o000000?oooooo`000?l000004Oooool4o`00
0003ooooool0003o000000Cooooo2?l00004ooooo`;o0000^Oooool001cooooo00?o0000oooooooo
ool0E_ooool3o`0000Oooooo0_l0000Eooooo`Co00001?ooool2o`0000;ooooo1ol00004ooooo`;o
000000?oooooo`000?l000000oooool2o`0003Gooooo0_l00002ooooo`;o0000M_ooool001cooooo
0_l0001Gooooo`?o00001oooool2o`0001gooooo0_l00002ooooo`Wo00001Oooool2o`0000;ooooo
0ol0000eooooo`?o000000?oooooo`000?l00000M_ooool001cooooo00?o0000ooooooooool0H?oo
ool2o`0001Kooooo0ol00006ooooo`;o00000_ooool7o`0000Wooooo0_l0000gooooo`;o00000_oo
ool2o`0007Gooooo000Looooo`03o`000?oooooooooo05kooooo0_l0000;ooooo`;o00001_ooool2
o`000003ooooool0003o000000?o00001_ooool2o`0000;ooooo1_l00009ooooo`;o0000??ooool2
o`0007Gooooo000Looooo`03o`000?oooooooooo05kooooo0_l0000:ooooo`?o00001_ooool2o`00
0003ooooool0003o000000Co00001_ooool2o`000005ooooool0003o0000o`000?ooool01?l00007
ooooo`;o0000:_ooool2o`0000Oooooo0_l00005ooooo`;o0000Moooool001cooooo00?o0000oooo
ooooool0D?ooool2o`0000_ooooo0_l00005ooooo`;o00001?ooool2o`0000[ooooo0ol000000ooo
oooo0000o`000006ooooo`co00001_ooool3o`0002Wooooo0_l00007ooooo`;o00001Oooool2o`00
00;ooooo0_l0001cooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00002oooool3o`0000Co
oooo0_l0000Looooo`go00001_ooool2o`0002Cooooo0_l000001?oooooo0000o`000?l00008oooo
o`;o000000?oooooo`000?l000001_ooool2o`0007?ooooo000Looooo`03o`000?oooooooooo05ko
oooo0_l0000Fooooo`;o00000oooool2o`0000Cooooo3_l0000/ooooo`;o000000?oooooo`000?l0
00000_l00005ooooo`Oo0000Noooool001cooooo00?o0000ooooooooool0M?ooool4o`0000?ooooo
0ol00003ooooo`Wo000000?oooooo`000?l000000_l0000Xooooo`;o00001_ooool3o`0000Gooooo
0_l000000ooooooo0000o`000009ooooo`;o0000L_ooool001cooooo00?o0000ooooooooool0C_oo
ool2o`0002Cooooo0_l00004ooooo`Co000000?oooooo`000?l000002_l000000ooooooo0000o`00
0002o`0000?ooooo0_l0000Rooooo`;o00000_ooool3o`0000Cooooo0_l000000ooooooo0000o`00
000>ooooo`;o0000L_ooool001cooooo00?o0000ooooooooool0C_ooool2o`0002[ooooo0_l00003
oooooa;o00000_ooool2o`0002Kooooo0ol00004ooooo`;o000000?oooooo`000?l000001oooool2
o`0000Oooooo0_l0001`ooooo`007?ooool00ol0003oooooooooo`1kooooo`?o000000?oooooo`00
0?l000004?l00002ooooo`;o0000<?ooool2o`000003ooooool0003o000000?ooooo0ol00007oooo
o`?o0000Koooool001cooooo00?o0000ooooooooool0Noooool3o`000003ooooool0003o000000So
000000?oooooo`000?l000001?l00003ooooo`;o00009?ooool2o`0000gooooo0_l000000ooooooo
0000o`000004o`0000Kooooo0ol0001_ooooo`007?ooool00ol0003oooooooooo`20ooooo`Wo0000
00?oooooo`000?l000001_l000000ooooooo0000o`00000Oooooo`;o00000oooool3o`0000oooooo
0_l000001?oooooo0000o`000?l0001hooooo`007?ooool00ol0003oooooooooo`1kooooo`Co0000
00?oooooo`000?l000004_l0000Mooooo`;o000000?oooooo`000?l000001?ooool2o`0000kooooo
0_l00002ooooo`?o00000_ooool2o`0000Gooooo0_l0001]ooooo`007?ooool00ol0003ooooooooo
o`1koooooaWo00007Oooool2o`0000?ooooo0_l00004ooooo`;o00002oooool8o`0000;ooooo0_l0
0002ooooo`Go0000KOooool001cooooo00?o0000ooooooooool0O?oooolGo`0001Oooooo0ol00000
0ooooooo0000o`000006ooooo`;o00001?ooool2o`0000Gooooo0ol00003ooooo`;o000000Cooooo
o`000?l0003ooooo0ol00002ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0006cooooo
000Looooo`;o0000OOoooolFo`0001Sooooo1_l0000Cooooo`?o00000oooool2o`000004ooooool0
003o0000ooooo`?o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000Xooooo`;o0000
@_ooool001cooooo00?o0000ooooooooool0A_ooool2o`00037ooooo6Ol0000Jooooo`Co00003_oo
ool2o`0000?ooooo0_l00002ooooo`;o00000oooool5o`0000;ooooo0_l00002ooooo`Go00003?oo
ool2o`0001_ooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`16ooooo`;o0000;_ooool2
o`000003ooooool0003o000001Ko0000;Oooool2o`0000?ooooo0_l000001?oooooo0000o`000?l0
0004ooooo`Co00000_ooool2o`0000;ooooo1_l0000:ooooo`?o00006oooool2o`0004;ooooo000L
ooooo`03o`000?oooooooooo07Kooooo7?l0000Jooooo`;o00004?ooool4o`0000Cooooo0_l00005
ooooo`;o000000?oooooo`000?l000002?ooool3o`0000[ooooo0_l0001Pooooo`007?ooool00ol0
003oooooooooo`1goooooa_o00005Oooool2o`0000?ooooo0_l0000<ooooo`So000000?oooooo`00
0?l000001?l00005ooooo`Co00002Oooool5o`0000Gooooo0_l0001Rooooo`007?ooool00ol0003o
ooooooooo`1hoooooaWo00005_ooool2o`000005ooooool0003o0000o`000?ooool00_l00003oooo
o`;o00000_oooolCo`0000Cooooo1?l00009ooooo`Oo000000?oooooo`000?l000000_l00007oooo
o`?o0000F?ooool001cooooo00?o0000ooooooooool0N?ooool3o`000003ooooool0003o000001;o
00005_ooool2o`0000;ooooo0ol000000ooooooo0000o`000003ooooo`;o00000_ooool>o`000003
ooooool0003o000000;o00001_ooool2o`0000cooooo2Ol00007ooooo`Go0000E_ooool001cooooo
00?o0000ooooooooool0N?oooolJo`0001Cooooo0_l0000>oooooa?o00001?ooool5o`0000cooooo
1Ol00002ooooo`;o00002?ooool4o`0005Kooooo000Looooo`03o`000?oooooooooo07Sooooo6_l0
000Looooo`;o00001?oooolEo`0000Cooooo1?l0000<ooooo`Go00002_ooool2o`000003ooooool0
003o000005Sooooo000Looooo`03o`000?oooooooooo047ooooo0_l0000doooooa[o00004Oooool2
o`0000Wooooo7_l00002ooooo`Co00003?ooool2o`0000?ooooo0_l00006ooooo`Co0000Foooool0
01cooooo00?o0000ooooooooool0@Oooool2o`0003Cooooo5_l0000Eooooo`;o00002Oooool2o`00
0003ooooool0003o000001Wo000000?oooooo`000?l000000ol0000Aooooo`;o00001_ooool2o`00
00?ooooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`0oooooo`;o0000:Oooool2o`000003
ooooool0003o000000[ooooo1Ol000000ooooooo0000o`00000<o`0001?ooooo1?l000000ooooooo
0000o`00000;oooooako00002oooool2o`0000Cooooo0_l00003ooooo`;o00001_ooool3o`0005So
oooo000Looooo`03o`000?oooooooooo03oooooo0_l0000Wooooo`Co000000Coooooo`000?l0003o
00000_ooool2o`0000Cooooo0ol000000ooooooo0000o`00000Ao`00013ooooo0ol000000ooooooo
0000o`000002o`0000Sooooo0_l00002oooooa[o000000?oooooo`000?l000002oooool2o`0000Co
oooo0_l00002ooooo`?o00001_ooool2o`0000Oooooo0_l0000Dooooo`;o0000>_ooool001cooooo
00?o0000ooooooooool0J?ooool3o`0000?ooooo0ol000000ooooooo0000o`000003oooooaSo0000
00?oooooo`000?l000002Oooool2o`0000;ooooo0_l00002ooooo`?o00000_ooool3o`0000;ooooo
1Ol000000ooooooo0000o`00000Go`0000oooooo0_l00008ooooo`;o00000oooool2o`0000Kooooo
0_l00003ooooo`Go00004Oooool2o`0003[ooooo000Looooo`03o`000?oooooooooo06Wooooo0_l0
0003ooooo`?o00001Oooool3o`000003ooooool0003o000000oo00001Oooool2o`0000Wooooo0_l0
00001?oooooo0000o`000?l00007ooooo`?o000000?oooooo`000?l000007ol0000=ooooo`?o0000
1oooool2o`0000Cooooo0_l00006ooooo`;o000000?oooooo`000?l000000_ooool3o`0004gooooo
000Looooo`03o`000?oooooooooo03gooooo0_l0000Zooooo`;o00000oooool2o`0000Kooooo0_l0
00000ooooooo0000o`00000?o`0001Cooooo0_l00008ooooo`?o000000?oooooo`000?l000007ol0
000=ooooo`;o00002?ooool2o`0000oooooo0_l00004ooooo`;o0000C?ooool001cooooo0_l0000m
ooooo`?o0000=?ooool2o`0000Cooooo0_l000000ooooooo0000o`00000<o`0000Cooooo0ol0000G
ooooo`;o00000_ooool2o`000003ooooool0003o000001Wo00003Oooool2o`0000Kooooo0_l00005
ooooo`;o00003oooool2o`0000;ooooo0_l0000Aooooo`;o0000>Oooool001cooooo00?o0000oooo
ooooool0??ooool2o`0003Gooooo0_l00003ooooo`;o00000_ooool:o`0000Sooooo0ol00009oooo
o`?o00003oooool2o`0000Cooooo5Ol000001?oooooo0000o`000?ooool3o`0000Wooooo0_l00003
ooooo`Go00000_ooool2o`000003ooooool0003o000000oooooo1ol0000@ooooo`;o0000>Oooool0
01cooooo00?o0000ooooooooool0>oooool2o`0003_ooooo1_l00002ooooo`Ko00002Oooool3o`00
0003ooooool0003o000000Gooooo0ol00008ooooo`;o00002?oooolHo`0000?ooooo1?l00009oooo
o`;o00000oooool5o`0000;ooooo0_l0000Dooooo`Go00004Oooool2o`0003Sooooo000Looooo`03
o`000?oooooooooo03_ooooo0_l0000mooooo`Co00001_ooool2o`0000Wooooo1_l00003ooooo`;o
00001?ooool4o`0000?ooooo0_l00008oooooaOo00001?ooool2o`0000cooooo0_l0000eooooo`;o
0000>?ooool001cooooo00?o0000ooooooooool0J?ooool2o`0000Sooooo0_l00003ooooo`;o0000
0_ooool2o`000003ooooool0003o0000013ooooo0ol00005ooooo`;o00001?ooool4o`0000Kooooo
0_l00002ooooo`;o00000_oooolDo`0000Cooooo0ol0000=ooooo`?o00000_ooool4o`0002kooooo
0_l0000hooooo`007?ooool00ol0003oooooooooo`1Qooooo`?o00001?ooool2o`0000?ooooo0_l0
0003ooooo`?o00000_ooool2o`0000Gooooo0ol0000Gooooo`;o00003_ooool2o`0000;ooooo0_l0
0002oooooa?o00001Oooool3o`0000kooooo0_l00002ooooo`Co00007Oooool2o`0000oooooo0_l0
000hooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o000000Coooooo`000?l0003o00001_oo
ool2o`000003ooooool0003o000000?ooooo1?l00009ooooo`;o00005oooool4o`0000_ooooo1_l0
0004ooooo`;o000000?oooooo`000?l000002_l00007ooooo`?o0000=?ooool4o`0000gooooo0_l0
000hooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00007Oooool2o`0000Cooooo0ol00002
ooooo`Oo000000?oooooo`000?l000001oooool3o`0000?ooooo0_l0000Hooooo`Wo00002_ooool3
o`000005ooooool0003o0000o`000?ooool00_l00003ooooo`co00002?ooool2o`0003Oooooo0_l0
000=ooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0>?ooool2o`0001gooooo1?l00002
ooooo`;o00000oooool7o`000003ooooool0003o000000;ooooo0_l00008ooooo`?o00006?ooool5
o`0000Wooooo0_l00003ooooo`;o00000oooool2o`000003ooooool0003o000000?ooooo1_l00002
ooooo`;o00002_ooool2o`0000Oooooo0_l0000^ooooo`;o00003Oooool2o`0003Sooooo000Loooo
o`03o`000?oooooooooo03Kooooo0_l0000Qooooo`;o00001?ooool2o`0000_ooooo1Ol00003oooo
o`;o00000_ooool2o`0001Kooooo0_l00004ooooo`;o00002Oooool2o`0000Sooooo0_l000000ooo
oooo0000o`000003ooooo`;o000000?oooooo`000?l000000_l0000:ooooo`;o00002_ooool2o`00
03gooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00008Oooool2o`0000Co
oooo0ol00003ooooo`?o00000_ooool8o`0000;ooooo0_l00002ooooo`;o00005_ooool2o`000004
ooooool0003o0000ooooo`;o00004oooool4o`0000Wooooo0_l0000:ooooo`;o0000BOooool2o`00
03Sooooo000Looooo`03o`000?oooooooooo03Kooooo0ol0000Mooooo`;o000000?oooooo`000?l0
00001Oooool2o`0000;ooooo1?l00002ooooo`_o00000_ooool3o`0001Cooooo0_l00003ooooo`;o
00005oooool3o`0000Wooooo0_l000000ooooooo0000o`000008ooooo`;o0000B?ooool2o`0003So
oooo000Looooo`03o`000?oooooooooo03Kooooo0ol0000Mooooo`;o00001Oooool2o`0000Cooooo
1ol000000ooooooo0000o`000008o`0000;ooooo0ol00002ooooo`;o00004?ooool2o`000003oooo
ool0003o000001[ooooo0_l00009ooooo`;o000000?oooooo`000?l000002?ooool2o`0004Sooooo
0_l0000hooooo`007?ooool00ol0003oooooooooo`1Looooo`?o00000_oooolDo`0000Cooooo1Ol0
000<ooooo`;o00000_ooool2o`000003ooooool0003o000000oooooo0_l00009ooooo`Co00005?oo
ool2o`0008;ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o0000
00?o410@ooooooooool01?ooool00ol0003oooooooooo`1Cooooo`;o00001oooool4o`000004oooo
ool0003o0000oooooa7o00001?ooool3o`0000;ooooo0_l000001Ooooooo0000o`000?l0003ooooo
00Oo000000?oooooo`000?l000000ol0000@ooooo`;o00002Oooool6o`0001;ooooo0_l00022oooo
o`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo04gooooo0_l00004ooooo`;o00001oooool5o`0000;ooooo4_l00005
ooooo`;o00000_ooool2o`000005ooooool0003o0000o`000?ooool01_l00002ooooo`;o000000?o
ooooo`000?l000001_ooool2o`0001?ooooo0_l000001?oooooo0000o`000?l0001Mooooo`;o0000
=oooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo00?o
0000ooooooooool0COooool2o`0000Cooooo0_l00008ooooo`Co000000?oooooo`000?l000004Ol0
0005ooooo`;o00000oooool5o`0000?ooooo1?l00005ooooo`;o000000?oooooo`000?l000000ooo
ool2o`0000[ooooo0_l0000:ooooo`Co00004?ooool2o`0002Wooooo0_l00004ooooo`;o00006Ooo
ool2o`0003Oooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CoA4A4
omgMgOoooooo00001oooool3o`00063ooooo5Ol00005ooooo`Co000000?oooooo`000?l000000ol0
0003ooooo`;o00002?ooool4o`0000Wooooo0_l00004ooooo`;o00002_ooool4o`0000?ooooo0_l0
000;ooooo`;o0000:Oooool2o`0000;ooooo1?l0000<ooooo`?o0000@oooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool02Oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oo
oooooooo03Cooooo0_l0000Cooooo`Co00001_ooool2o`000003ooooool0003o000000Sooooo5?l0
0005ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Cooooo0ol00006ooooo`;o00002ooo
ool2o`0001Kooooo2_l00003ooooo`?o00009_ooool2o`000003ooooool0003o000000Go00001Ooo
ool2o`0000Kooooo0ol00013ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:
ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0<oooool5o`0000oooooo1_l00004
ooooo`Co000000?oooooo`000?l000001Oooool2o`000003ooooool0003o000000;o000000?ooooo
o`000?l000003?l00006ooooo`;o000000Coooooo`000?l0003ooooo0_l00007ooooo`?o0000:ooo
ool:o`0000?ooooo0ol0000Vooooo`;o000000?oooooo`000?l000001?l000000ooooooo0000o`00
0002o`000004ooooool0003o0000o`0004_ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`co
oooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0cooooo`;o000000?oooooo`000?l0
00003?ooool2o`000005ooooool0003o0000o`000?ooool00_l00004ooooo`;o00002_oooolGo`00
00;ooooo0_l00006ooooo`?o0000>oooool2o`0000?ooooo1Ol00004ooooo`;o00008Oooool2o`00
00Cooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l0001;ooooo`0000Koooooonk^k_lb
<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0=_ooool2
o`0000_ooooo0ol00005ooooo`;o00002?ooool2o`0000Gooooo6?l00002ooooo`;o00001_ooool2
o`0000Gooooo0_l0000`ooooo`;o00000oooool2o`0000;ooooo0ol000000ooooooo0000o`000002
ooooo`Co00008Oooool2o`0000Kooooo1?l00005ooooo`;o00004?ooool3o`0003Kooooo000Loooo
o`03o`000?oooooooooo03Kooooo0_l000000ooooooo0000o`000006ooooo`Co00000_ooool2o`00
00_ooooo0ol00005oooooaSo00000_ooool2o`0000cooooo0ol0000<ooooo`;o00008_ooool3o`00
00Kooooo0_l00002ooooo`;o00000_ooool3o`0002[ooooo0_l00002ooooo`Co000000?oooooo`00
0?l000004?ooool3o`0003Kooooo000Looooo`03o`000?oooooooooo03;ooooo0_l00003ooooo`Co
00001Oooool3o`0000Cooooo0_l0000;ooooo`;o00001ooooolFo`0000?ooooo1?l0000:ooooo`;o
00000_ooool2o`0000Wooooo0_l0000Sooooo`;o00001?ooool3o`0002Cooooo0_l0000Booooo`Oo
0000BOooool001cooooo00?o0000ooooooooool0<_ooool2o`000003ooooool0003o000000;o0000
1oooool2o`0000Oooooo0_l00003ooooo`;o00003OoooolCo`000003ooooool0003o000000Gooooo
0_l0000>ooooo`;o0000=?ooool3o`0001Wooooo0ol000000ooooooo0000o`000005ooooo`;o0000
00?oooooo`000?l000003oooool7o`0004Wooooo000Looooo`03o`000?oooooooooo037ooooo0ol0
00000ooooooo0000o`000005ooooo`;o00002Oooool4o`0000?ooooo0ol0000<oooooa?o000000?o
ooooo`000?l000000oooool2o`0001_ooooo0_l00015ooooo`?o000000?oooooo`000?l000002?oo
ool2o`0000oooooo1?l000000ooooooo0000o`000003ooooo`;o0000A?ooool001cooooo00?o0000
ooooooooool0<Oooool2o`0000Wooooo0_l00005ooooo`;o00000_ooool2o`0000Kooooo0_l00002
ooooo`;o00001_oooolDo`0000Oooooo0_l00002ooooo`;o00005?ooool2o`000003ooooool0003o
000001_ooooo0_l00017ooooo`Oo00000oooool2o`0000gooooo0_l0000eooooo`007?ooool00ol0
003oooooooooo`13ooooo`;o00003_ooool2o`0000Kooooo5?l0000;ooooo`;o00005?ooool2o`00
01kooooo0_l00008ooooo`;o0000;_ooool2o`0000kooooo1?l00005ooooo`;o00003Oooool2o`00
03Gooooo000Looooo`03o`000?oooooooooo03;ooooo0_l0000Aooooo`;o00002?ooool2o`00013o
oooo3?l0000`ooooo`;o00006oooool2o`0002kooooo0ol0000Aooooo`?o0000B?ooool001cooooo
00?o0000ooooooooool0<Oooool3o`0000Wooooo0_l00006ooooo`;o00002?ooool2o`0000cooooo
0_l00002ooooo`co0000;_ooool4o`0000Oooooo0_l0000Iooooo`;o00001?ooool2o`0001Cooooo
0_l0000;ooooo`?o00002?ooool2o`0000Oooooo0ol00018ooooo`007?ooool00ol0003ooooooooo
o`0aooooo`Co000000?oooooo`000?l000001Oooool2o`000003ooooool0003o000000gooooo0_l0
000<ooooo`?o000000?oooooo`000?l000002?l0000`ooooo`;o000000?oooooo`000?l000000_l0
0004ooooo`;o00005Oooool2o`0000;ooooo0_l00004ooooo`;o00005?ooool2o`0000_ooooo0_l0
0007ooooo`Co00000oooool6o`0001;ooooo1?l0000cooooo`007?ooool00ol0003oooooooooo`0c
ooooo`;o000000?oooooo`000?l000001Oooool2o`000004ooooool0003o0000ooooo`;o00001?oo
ool2o`0000;ooooo1?l0000<ooooo`?o000000?oooooo`000?l000000_ooool7o`00027ooooo0_l0
00000ooooooo0000o`00000<ooooo`Oo00006?ooool2o`0001Sooooo0_l0000Jooooo`;o000000?o
ooooo`000?l000000_ooool6o`0001;ooooo1Ol0000booooo`007?ooool00ol0003oooooooooo`0f
ooooo`Co00000oooool4o`0000;ooooo0_l00004ooooo`;o00000_ooool3o`0000kooooo0_l00000
0ooooooo0000o`000002ooooo`;o00000oooool2o`00023ooooo0ol000001?oooooo0000o`000?l0
000?ooooo`?o00006?ooool2o`0000kooooo0_l00008ooooo`;o00007Oooool2o`000004ooooool0
003o0000o`0001Wooooo0_l0000booooo`007?ooool2o`0003Kooooo1Ol00005ooooo`?o00007?oo
ool2o`000003ooooool0003o000001_ooooo0_l00004ooooo`Co00001?ooool3o`000003ooooool0
003o000000Oo00002_ooool2o`0002Sooooo0_l0000;ooooo`;o00005_ooool9o`0004kooooo000L
ooooo`03o`000?oooooooooo03Gooooo1?l00007ooooo`;o00004?ooool2o`0000Wooooo0_l00003
ooooo`Co00006?ooool2o`0000Cooooo1ol00002ooooo`Co000000?oooooo`000?l000001Ol0000:
ooooo`;o00001oooool2o`0000gooooo0_l00008ooooo`;o00000_ooool2o`0000Kooooo0_l00007
ooooo`;o00005_ooool8o`000003ooooool0003o000004cooooo000Looooo`03o`000?oooooooooo
03Gooooo1Ol00006ooooo`;o00004?ooool4o`0000Oooooo0_l000000ooooooo0000o`000004o`00
01Oooooo1Ol00002ooooo`;o000000?oooooo`000?l000000_l00002ooooo`Co00000oooool7o`00
00kooooo0_l000000ooooooo0000o`00000=ooooo`;o00001oooool3o`0000;ooooo0ol00005oooo
o`;o00003_ooool4o`0000Kooooo0_l00005ooooo`?o000000?oooooo`000?l000000oooool2o`00
0003ooooool0003o000000;ooooo1?l00013ooooo`007?ooool00ol0003oooooooooo`0dooooo`Ko
00001_ooool4o`00013ooooo0_l00009ooooo`Co00000_ooool2o`0000Sooooo1Ol00007ooooo`Oo
00000_ooool2o`0000kooooo1?l000000ooooooo0000o`000003o`0000_ooooo0_l0000Booooo`;o
00001Oooool2o`0000Cooooo0_l00008ooooo`;o00000oooool2o`0000?ooooo0_l000000ooooooo
0000o`000002o`0000Kooooo0_l00005ooooo`;o00000_ooool3o`0000;ooooo0_l000000ooooooo
0000o`000002ooooo`Co0000@oooool001cooooo00?o0000ooooooooool0=?ooool4o`0000[ooooo
0ol0000>ooooo`?o00002Oooool5o`000003ooooool0003o000000Sooooo1Ol00002ooooo`;o0000
0oooool3o`000003ooooool0003o000000?ooooo0_l0000Cooooo`Ko00006oooool5o`0000_ooooo
0_l00008ooooo`?o00000_ooool2o`0000?ooooo0_l000001?oooooo0000o`000?l00002ooooo`Co
00001Oooool2o`000003ooooool0003o000000Go00001Oooool2o`0001Cooooo0_l0000cooooo`00
7?ooool00ol0003oooooooooo`0fooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo
0ol0000=ooooo`?o00003?ooool4o`00013ooooo0_l00002ooooo`Co00006oooool8o`0000Wooooo
0_l0000=ooooo`Go00004oooool2o`0000;ooooo2?l00003ooooo`Co00000_ooool4o`0000;ooooo
0_l000000ooooooo0000o`000008o`0000Cooooo0ol0000Dooooo`;o0000<oooool001cooooo00?o
0000ooooooooool0>Oooool2o`0000Cooooo0_l00003ooooo`;o00007_ooool2o`0000?ooooo0_l0
0004ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l0000Mooooo`Wo00002?oo
ool5o`0000[ooooo1Ol00007ooooo`;o00002_ooool2o`0000Cooooo1_l00003ooooo`;o00000ooo
ool4o`0000?ooooo0_l00002ooooo`;o00002oooool3o`0001Cooooo0_l0000cooooo`007?ooool0
0ol0003oooooooooo`0kooooo`;o00001_ooool2o`0002Cooooo0_l00003ooooo`?o000000?ooooo
o`000?l000000_ooool2o`0002;ooooo2?l0000:ooooo`Go00002oooool2o`0000Cooooo0_l00000
0ooooooo0000o`00000Dooooo`Ko000000?oooooo`000?l000001Ol00006ooooo`;o00000_ooool4
o`0001gooooo0_l0000cooooo`007?ooool00ol0003oooooooooo`0jooooo`?o00001_ooool2o`00
013ooooo0_l0000Booooo`;o00000oooool2o`0000cooooo1?l0000Looooo`Oo00003?ooool2o`00
017ooooo0_l0000Gooooo`_o000000?oooooo`000?l000001_ooool2o`0000;ooooo1?l0000Moooo
o`;o0000<oooool001cooooo00?o0000ooooooooool0>_ooool3o`0000;ooooo0_l00002ooooo`;o
00003?ooool2o`0000;ooooo0_l0000Pooooo`;o00000oooool4o`0000?ooooo0_l0000;ooooo`Oo
00001Oooool8o`0000Gooooo0_l00007ooooo`;o00005_ooool2o`0000Oooooo0_l000000ooooooo
0000o`00000>o`0001Oooooo0_l000000ooooooo0000o`000017ooooo`007?ooool00ol0003ooooo
ooooo`0kooooo`;o00000_ooool2o`000003ooooool0003o000000cooooo0ol0000Qooooo`Go0000
2_ooool2o`0000_ooooo1ol00007ooooo`Ko00001Oooool2o`0000Oooooo0_l0000Fooooo`;o0000
0_ooool2o`0000?ooooo5ol0000Cooooo`;o000000Coooooo`000?l0003o00003oooool2o`0003Go
oooo000Looooo`03o`000?oooooooooo03cooooo0_l00004ooooo`;o00003?ooool5o`0001oooooo
1?l0000Eooooo`Ko00000oooool2o`0000Cooooo2Ol0000<ooooo`;o00006oooool2o`000003oooo
ool0003o000000co000000?oooooo`000?l000002Ol00007ooooo`;o00002Oooool2o`0000;ooooo
0_l0000?ooooo`?o0000=?ooool001cooooo00?o0000ooooooooool0??ooool2o`0000Cooooo0_l0
000?ooooo`;o0000>?ooool5o`0000?ooooo0ol00004ooooo`;o000000?oooooo`000?l000001?l0
000<ooooo`;o00002_ooool2o`0000Cooooo0_l00007ooooo`;o00000ooooolKo`0000Kooooo0_l0
0002ooooo`?o000000?oooooo`000?l000000ol0000Dooooo`;o0000=?ooool001cooooo00?o0000
ooooooooool0>Oooool4o`0000?ooooo1?l0000?ooooo`;o0000:?ooool2o`0000_ooooo1ol00003
ooooo`Go00000oooool:o`0001Oooooo0_l00004ooooo`;o00001oooool2o`0000;ooooo1Ol00000
0ooooooo0000o`00000Do`0000Cooooo0_l00004ooooo`So00000_ooool2o`00017ooooo0_l0000d
ooooo`007?ooool00ol0003oooooooooo`0iooooo`Co00000oooool3o`0000kooooo1?l000000ooo
oooo0000o`00000Uooooo`;o00002_ooool4o`0000Oooooo0_l000001?oooooo0000o`000?l00002
ooooo`[o00002?ooool2o`0000Wooooo0_l0000?ooooo`?o000000?oooooo`000?l000000ol00000
0ooooooo0000o`00000Co`000003ooooool0003o000000Cooooo0_l00004ooooo`Co000000Cooooo
o`000?l0003o00000_ooool2o`0004Oooooo000Looooo`03o`000?oooooooooo03Wooooo0_l00006
ooooo`;o00003_ooool4o`000003ooooool0003o0000033ooooo1?l0000;ooooo`?o00001?ooool8
o`0000Gooooo0_l000000ooooooo0000o`000009ooooo`;o00003oooool3o`000003ooooool0003o
000000go00000_ooool9o`0000;ooooo0ol00009ooooo`;o00000oooool2o`0004cooooo000Loooo
o`;o0000D_ooool3o`0000Cooooo0_l0000^ooooo`Co00001Oooool2o`000004ooooool0003o0000
ooooo`Co00000_ooool9o`0000Gooooo0_l0000Dooooo`;o00001?ooool2o`000003ooooool0003o
000001co00000_ooool3o`0000kooooo0_l0000Cooooo`;o0000=oooool001cooooo00?o0000oooo
ooooool0>_ooool6o`00013ooooo1_l00002ooooo`;o00009Oooool2o`0000Oooooo0_l00007oooo
o`Go00000_ooool3o`0000;ooooo2Ol0000Cooooo`;o00001_ooool4o`0000;ooooo1?l000000ooo
oooo0000o`000004o`000003ooooool0003o000001So00002_ooool2o`0000Cooooo0_l0000Aoooo
o`?o0000=_ooool001cooooo00?o0000ooooooooool0>Oooool7o`0000Sooooo0_l00006ooooo`Ko
0000:Oooool2o`0000Oooooo0_l00003ooooo`;o00000oooool2o`0000Cooooo0_l00002ooooo`_o
00004?ooool4o`000003ooooool0003o000000Gooooo2?l000001Ooooooo0000o`000?l0003ooooo
00;o000000?oooooo`000?l000005Ol000000ooooooo0000o`000008ooooo`Co00001?ooool2o`00
01;ooooo0_l0000fooooo`007?ooool00ol0003oooooooooo`0hooooo`?o00000_ooool2o`0000Wo
oooo0ol00005ooooo`Ko0000:Oooool2o`0000Gooooo1?l00003ooooo`;o00003Oooool;o`0000ko
oooo1?l00003ooooo`?o00001_ooool6o`000005ooooool0003o0000o`000?ooool06_l000000ooo
oooo0000o`000008ooooo`;o00006?ooool2o`0003Sooooo000Looooo`03o`000?oooooooooo03So
oooo0_l00003ooooo`;o00002_ooool2o`0000Cooooo1?l000001?oooooo0000o`000?l0000Xoooo
o`;o00001Oooool2o`0000gooooo1Ol00002ooooo`_o00003_ooool2o`0000Kooooo0_l0000:oooo
o`?o00001?oooolIo`0000;ooooo0_l00008ooooo`;o00006?ooool2o`0003Sooooo000Looooo`03
o`000?oooooooooo03Sooooo0_l0000Eooooo`?o00000oooool2o`0002kooooo0ol00003ooooo`;o
00000_ooool2o`0000Cooooo1Ol00002ooooo`_o00003oooool3o`0000Sooooo0_l00007ooooo`;o
00000ooooolNo`0000Sooooo0_l00005ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0
>?ooool2o`0001Gooooo0ol00005ooooo`;o00000_ooool2o`000003ooooool0003o000002Gooooo
0ol00003ooooo`;o00000_ooool2o`0000cooooo2_l0000?ooooo`?o00002?ooool5o`0000Cooooo
0_l00003oooooa3o000000?oooooo`000?l000002_l00008ooooo`;o00001_ooool2o`00013ooooo
0_l0000iooooo`007?ooool00ol0003oooooooooo`0hooooo`;o000000?oooooo`000?l000002?oo
ool2o`0000Sooooo0_l00006ooooo`;o00000_ooool2o`000003ooooool0003o000002Gooooo0ol0
000@ooooo`;o00000oooool:o`0000_ooooo0_l00002ooooo`?o00002Oooool6o`0000;ooooo0_l0
0003oooooaWo000000Coooooo`000?l0003o00002?ooool3o`0001Oooooo0_l0000iooooo`007?oo
ool00ol0003oooooooooo`0jooooo`?o00002?ooool2o`0000Sooooo0_l00004ooooo`?o00001?oo
ool3o`0001Wooooo0ol00002ooooo`;o00001?ooool3o`0000;ooooo0_l00009ooooo`;o00000ooo
ool2o`0000;ooooo2ol0000;ooooo`;o00000_ooool2o`0000;ooooo1?l00008ooooo`;o00000_oo
ool2o`000003ooooool0003o000000;ooooo5ol000001Ooooooo0000o`000?l0003ooooo00;o0000
1?ooool4o`0001Gooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0jooooo`Co00003?oo
ool2o`0000;ooooo0ol00004ooooo`?o00001?ooool3o`0001Wooooo0ol00002ooooo`;o00000ooo
ool4o`000004ooooool0003o0000o`0000Wooooo0_l00003ooooo`;o00000_ooool<o`0000cooooo
0_l00004ooooo`Co00001?ooool3o`0000Oooooo7?l000000ooooooo0000o`000002ooooo`;o0000
0oooool3o`0001Kooooo0ol0000kooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00000_oo
ool2o`0000cooooo0ol000001?oooooo0000o`000?l0000;ooooo`;o00002?ooool2o`00017ooooo
0_l000000ooooooo0000o`000004ooooo`?o00000_ooool2o`0000cooooo0_l000000ooooooo0000
o`000003ooooo`_o00003?ooool2o`0000Cooooo0_l00005ooooo`Co00001ooooolLo`000004oooo
ool0003o0000ooooo`;o00001?ooool2o`0000Kooooo0_l0000>ooooo`?o0000??ooool001cooooo
00?o0000ooooooooool0>?ooool2o`0000Wooooo0_l00006ooooo`;o00000_ooool2o`0000Kooooo
0_l000000ooooooo0000o`00000:ooooo`;o00004Oooool2o`000003ooooool0003o000000Cooooo
0ol0000@ooooo`;o00001_ooool;o`0000cooooo0_l00004ooooo`;o00001Oooool2o`0000cooooo
7?l000000ooooooo0000o`000007ooooo`;o00000oooool2o`0000gooooo0ol0000mooooo`007?oo
ool00ol0003oooooooooo`13ooooo`;o00002_ooool2o`0000Kooooo1Ol00005ooooo`Co00001?oo
ool2o`0001Gooooo1_l0000:ooooo`;o00002oooool;o`0000cooooo0_l00002ooooo`;o00001ooo
ool2o`0000cooooo7?l0000:ooooo`;o00004Oooool4o`0003gooooo000Looooo`03o`000?oooooo
oooo03[ooooo0ol000000ooooooo0000o`00000?ooooo`;o00002?ooool3o`0000Gooooo1?l00002
ooooo`Co00005Oooool3o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o000000?ooooo
o`000?l000000oooool2o`0000Kooooo2ol0000<ooooo`;o00000_ooool2o`0000Oooooo0_l00006
ooooo`;o00001OoooolIo`0000Oooooo0_l00003ooooo`;o00004Oooool3o`0003kooooo000Loooo
o`03o`000?oooooooooo03Sooooo2?l00009ooooo`;o00001?ooool2o`0000Cooooo0_l00005oooo
o`;o00002Oooool2o`000003ooooool0003o000001Cooooo0_l00007ooooo`;o00000_ooool2o`00
00Kooooo0_l00006ooooo`_o00005_ooool2o`0000Wooooo3?l000001Ooooooo0000o`000?l0003o
oooo00ko000000?oooooo`000?l000001?ooool3o`0001Cooooo1Ol0000nooooo`007?ooool00ol0
003oooooooooo`0hooooo`So000000?oooooo`000?l000001Oooool3o`0000Cooooo0_l00004oooo
o`?o00001?ooool2o`000004ooooool0003o0000ooooo`;o00001_ooool2o`0000_ooooo1?l00004
ooooo`;o00006_ooool2o`000003ooooool0003o000000Oo00003Oooool2o`000004ooooool0003o
0000o`0000Cooooo1?l00008ooooo`[o00000_oooolAo`000004ooooool0003o0000o`0000Cooooo
0_l00005ooooo`;o00003Oooool4o`00043ooooo000Looooo`;o0000??ooool5o`000003ooooool0
003o000000Gooooo0_l00006ooooo`;o00000_ooool4o`0000Oooooo0_l000000ooooooo0000o`00
000Cooooo`Co00000oooool4o`000003ooooool0003o0000017ooooo0_l00002ooooo`?o000000?o
ooooo`000?l000001_l0000>ooooo`;o000000Coooooo`000?l0003o00001_ooool2o`0000Sooooo
0_l000001?oooooo0000o`000?ooool5o`0000;ooooo2?l000000ooooooo0000o`000002o`0000;o
oooo1?l0000<ooooo`;o00003Oooool2o`0004;ooooo000Looooo`03o`000?oooooooooo03_ooooo
0_l00006ooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000?o0000
0_ooool2o`000003ooooool0003o000000Gooooo2?l0000;ooooo`;o00001?ooool2o`0000Cooooo
1Ol000000ooooooo0000o`00000=ooooo`;o00000_ooool2o`0000;ooooo1?l000000ooooooo0000
o`000006o`00013ooooo0_l00007ooooo`;o00001Oooool5o`000004ooooool0003o0000ooooo`Wo
00000_ooool4o`0000Oooooo1?l0000Iooooo`Co0000@_ooool001cooooo00?o0000ooooooooool0
>Oooool4o`0000Kooooo1Ol00002ooooo`;o000000?oooooo`000?l000000_l00006ooooo`;o0000
1Oooool:o`0000Cooooo1?l000000ooooooo0000o`00000:ooooo`Go00004?ooool2o`0000Oooooo
0ol00004ooooo`Go00004?ooool2o`0000Cooooo0_l00008ooooo`?o00002?ooool7o`0000;ooooo
1Ol00004ooooo`Go00000_ooool2o`0001Gooooo1?l00013ooooo`007?ooool00ol0003ooooooooo
o`0hooooo`?o00002_ooool4o`0000Gooooo0ol00006ooooo`Go00002_ooool2o`000004ooooool0
003o0000ooooo`Co00001oooool2o`0000Gooooo1Ol0000Hooooo`Co000000?oooooo`000?l00000
1ol0000>ooooo`;o00001?ooool4o`0000Oooooo0_l000000ooooooo0000o`000007ooooo`Go0000
1Oooool3o`0000?ooooo0ol00004ooooo`;o00004oooool6o`0004?ooooo000Looooo`03o`000?oo
oooooooo03Sooooo0_l0000;ooooo`Co00001Oooool2o`0000;ooooo0_l00005ooooo`?o00003Ooo
ool2o`0000?ooooo0_l00007ooooo`;o00001Oooool2o`000003ooooool0003o0000013ooooo0_l0
0007ooooo`?o000000?oooooo`000?l000001ol0000>ooooo`;o00001_ooool2o`0000Wooooo0ol0
000:ooooo`Go00000oooool2o`0000?ooooo0_l00009ooooo`;o00003_ooool5o`0004Gooooo000L
ooooo`03o`000?oooooooooo03kooooo0_l00005ooooo`;o000000?oooooo`000?l000000oooool3
o`0000;ooooo0_l00003ooooo`;o00004oooool4o`0000[ooooo0ol000000ooooooo0000o`000002
o`00017ooooo0_l00007ooooo`_o00004_ooool2o`0000Cooooo0ol00008ooooo`;o00002oooool:
o`000003ooooool0003o000000;o000000?oooooo`000?l000001_ooool2o`0000gooooo1Ol00016
ooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00000oooool2o`0000Sooooo0_l00002oooo
o`?o00001_ooool4o`0000Kooooo1ol00003ooooo`;o000000?oooooo`000?l000001_ooool2o`00
00Cooooo0ol000000ooooooo0000o`000002o`0000gooooo0_l00008ooooo`;o00000_ooool3o`00
0003ooooool0003o000000Co00004_ooool2o`0000Gooooo0_l00003ooooo`;o00000oooool2o`00
013ooooo1Ol000000ooooooo0000o`000002o`000003ooooool0003o000000;o00004_ooool3o`00
04Wooooo000Looooo`03o`000?oooooooooo03Wooooo1?l0000?ooooo`?o00001_ooool3o`0000Go
oooo2ol000001?oooooo0000o`000?l00008ooooo`;o00000oooool2o`0000Kooooo0_l0000<oooo
o`;o00002?ooool2o`0000;ooooo2_l0000Booooo`;o00000oooool2o`0000Cooooo0ol000000ooo
oooo0000o`000002o`0000Wooooo0_l00005ooooo`;o00001?ooool2o`0000Cooooo0ol0000@oooo
o`Go0000BOooool001cooooo00?o0000ooooooooool0>_ooool4o`0000gooooo1_l00003ooooo`;o
00001oooool;o`0000;ooooo0_l00003ooooo`;o00002?ooool4o`0000Cooooo0_l0000Hooooo`go
00005_ooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000Sooooo1Ol00005oooo
o`;o00000_ooool4o`0001Oooooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`0gooooo`;o
000000?oooooo`000?l000000_l0000=ooooo`Ko00000oooool2o`0000Sooooo1Ol00002ooooo`?o
00000_ooool2o`0000?ooooo0_l00008ooooo`Co00007_ooool2o`0000;ooooo2Ol0000>ooooo`;o
00001Oooool2o`0000;ooooo0_l000000ooooooo0000o`00000<ooooo`Go00001Oooool2o`0000;o
oooo0_l0000Hooooo`;o0000COooool001cooooo00?o0000ooooooooool0=oooool2o`000003oooo
ool0003o000000oooooo0ol0000;ooooo`Co000000?oooooo`000?l000000ol00003ooooo`;o0000
00Coooooo`000?l0003o00001Oooool3o`0000;ooooo1Ol0000Nooooo`;o000000?oooooo`000?l0
00002_l0000>ooooo`;o00001Oooool3o`0000?ooooo0_l0000@ooooo`;o00007oooool3o`000003
ooooool0003o000004gooooo000Looooo`03o`000?oooooooooo03[ooooo0ol000000ooooooo0000
o`00000Iooooo`Co00000oooool5o`000004ooooool0003o0000ooooo`?o00001?ooool4o`0000;o
oooo0ol00002ooooo`;o00000oooool2o`0001Oooooo3_l0000@ooooo`;o00001Oooool4o`000003
ooooool0003o0000033ooooo1?l0001@ooooo`007?ooool00ol0003oooooooooo`0iooooo`Co0000
00?oooooo`000?l000002oooool2o`0000[ooooo1?l000001Ooooooo0000o`000?l0003ooooo00So
00002?ooool2o`0000?ooooo0ol00003ooooo`;o00000oooool2o`0000oooooo0_l00006ooooo`oo
00003oooool2o`0000?ooooo0_l000001?oooooo0000o`000?l00003ooooo`?o0000;?ooool5o`00
053ooooo000Looooo`03o`000?oooooooooo03Wooooo0_l0000@ooooo`;o00002_ooool3o`0000;o
oooo1ol000000ooooooo0000o`000002o`0000gooooo0_l0000Jooooo`;o00001_ooool2o`000003
ooooool0003o000000Co000000?oooooo`000?l000000ol0000@ooooo`;o00000_ooool2o`0000Oo
oooo0ol0000Xooooo`;o000000?oooooo`000?l000000ol0001Aooooo`0000Koooooonk^k_lb<S;o
0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000
ooooooooool0C?ooool2o`0000Wooooo0ol00002ooooo`Go00000_ooool4o`0000;ooooo0_l0000:
ooooo`;o00003?ooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000Cooooo0_l0
00000ooooooo0000o`000004o`0000?ooooo0ol000000ooooooo0000o`000003o`00013ooooo0_l0
000dooooo`Wo0000D_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo
00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo03Oooooo0_l0000<ooooo`;o
00001Oooool2o`0000Sooooo0ol00003ooooo`[o00000oooool2o`0000Wooooo0_l00005ooooo`?o
00001Oooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000Cooooo5Ol0000Eoooo
o`?o0000:Oooool2o`0000?ooooo1_l0001Eooooo`0000?ooooooa0@4?ooool00_ooool00ol@413o
ooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0goooo
o`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00002?ooool3o`0000?ooooo2Ol0000>oooo
o`?o00001Oooool3o`0000Gooooo0_l00004ooooo`;o00000_ooool2o`0000Gooooo3?l000000ooo
oooo0000o`000005o`0001Gooooo0ol00003ooooo`;o00008Oooool2o`000003ooooool0003o0000
00?ooooo1_l0000>ooooo`;o0000AOooool00003ooooool0003ooooo00;ooooo00?o0000oooooooo
ool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0000gooooo`?o00001?ooool2o`00
00;ooooo0_l0000Gooooo`Wo00003oooool2o`0000Oooooo0_l0000:ooooo`Co000000?oooooo`00
0?l000006?l0000Gooooo`;o00000oooool2o`00027ooooo0ol000000ooooooo0000o`000004oooo
o`;o00004?ooool2o`0004Gooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wo
oooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo03Oooooo0ol00005oooo
o`;o000000?oooooo`000?l000002?ooool3o`0000cooooo0_l00002ooooo`?o00001Oooool2o`00
00gooooo0_l00002ooooo`Co00002_ooool4o`000003ooooool0003o000000Ko00000_oooolAo`00
017ooooo1?l000000ooooooo0000o`000003o`0001_ooooo1Ol00004ooooo`;o000000?oooooo`00
0?l000001?ooool3o`0000Gooooo0_l0001?ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413o
ooooooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0>?ooool2o`0000Co
oooo0ol0000;ooooo`?o000000?oooooo`000?l000002?ooool3o`0000[ooooo0_l0000;ooooo`Co
00000_ooool2o`0000Cooooo1?l000000ooooooo0000o`000002o`0000?ooooo0_l000000ooooooo
0000o`00000Ao`000003ooooool0003o000000?o00004Oooool4o`0000?ooooo0ol0000Hooooo`So
00001?ooool2o`0000Sooooo0_l00005ooooo`;o000000?oooooo`000?l000000_l000000ooooooo
0000o`000017ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH
00Sooooo00?o0000ooooooooool0>?ooool2o`0000Cooooo0_l000000ooooooo0000o`000006oooo
o`;o00000_ooool2o`000003ooooool0003o000000Sooooo0ol00008ooooo`;o00001Oooool2o`00
00Kooooo0_l000001?oooooo0000o`000?ooool2o`0000Cooooo1?l000000ooooooo0000o`000002
o`000003ooooool0003o000001Ko00000_ooool2o`0003;ooooo1ol000000ooooooo0000o`00000D
ooooo`;o00000oooool4o`000003ooooool0003o000004Oooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`0hooooo`;o0000
1oooool3o`0000Gooooo0_l0000;ooooo`;o00000oooool2o`0000Oooooo0ol00005ooooo`;o0000
2Oooool2o`000003ooooool0003o000000;o00003?ooool2o`000004ooooool0003o0000o`0000;o
oooo2ol000000ooooooo0000o`000003o`000003ooooool0003o000001Sooooo0_l0000Hooooo`Oo
00004_ooool2o`0000?ooooo0_l0000;ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0
@_ooool2o`0000Cooooo0ol00002ooooo`?o00001_ooool2o`0000?ooooo0ol00005ooooo`?o0000
1?ooool4o`0000Wooooo0_l000000ooooooo0000o`000003o`0000gooooo0ol000000ooooooo0000
o`00000Ao`000004ooooool0003o0000o`0000kooooo0_l00007ooooo`;o00005_ooool2o`0001Wo
oooo0_l0000@ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0B?ooool3o`0000;ooooo
0ol000000ooooooo0000o`000009ooooo`?o00001?ooool2o`0000Gooooo0_l0000Aooooo`;o0000
3?ooool4o`000003ooooool0003o000001Go00003_ooool2o`0000;ooooo0_l0000Kooooo`;o0000
00?oooooo`000?l000002_ooool3o`00067ooooo000Looooo`03o`000?oooooooooo047ooooo0_l0
0006ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo0_l00005ooooo`?o000000Co
ooooo`000?l0003o00001oooool2o`0001oooooo1?l000000ooooooo0000o`00000Eo`0001;ooooo
0_l0000Jooooo`?o000000?oooooo`000?l000002_ooool3o`0000;ooooo0_l0000:ooooo`;o0000
DOooool001cooooo00?o0000ooooooooool0@Oooool2o`0000?ooooo0_l00007ooooo`;o00001?oo
ool2o`0000Kooooo1_l00007ooooo`;o00007Oooool6o`0000;ooooo4Ol00002ooooo`?o00004ooo
ool2o`0001Wooooo0ol0000:ooooo`;o00001_ooool2o`0000Oooooo0_l000000ooooooo0000o`00
0005ooooo`;o00006Oooool2o`0002oooooo000Looooo`03o`000?oooooooooo047ooooo0_l00003
ooooo`;o00001Oooool6o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`;o0000:OoooolK
o`000003ooooool0003o000001?ooooo0_l0000Kooooo`;o00002Oooool2o`0000Gooooo0_l00008
ooooo`Co00001_ooool2o`0001Wooooo0_l0000_ooooo`007?ooool00ol0003oooooooooo`11oooo
o`;o00002_ooool3o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`00000=oooo
o`Go00007?oooolDo`0000;ooooo2_l0000:ooooo`;o00002Oooool4o`0001Kooooo0_l0000@oooo
o`;o00001oooool2o`000003ooooool0003o000000Cooooo0_l0001<ooooo`007?ooool00ol0003o
ooooooooo`16ooooo`;o00001_ooool2o`0000Gooooo0ol000000ooooooo0000o`00000<ooooo`Go
00006OoooolHo`000003ooooool0003o000000So00002_ooool2o`0000Wooooo1?l0000Fooooo`Co
00005oooool2o`0000Cooooo0_l000000ooooooo0000o`00001<ooooo`007?ooool00ol0003ooooo
ooooo`0mooooo`;o00001oooool2o`0000kooooo0_l000000ooooooo0000o`000002o`0000_ooooo
0_l0000Koooooako00007?ooool2o`0001Sooooo0_l0000<ooooo`;o00001?ooool3o`0000Oooooo
1Ol00002ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0?Oooool2o`00013ooooo0_l0
00000ooooooo0000o`000002ooooo`;o00000_ooool4o`0000Sooooo1?l0000Kooooob?o00002_oo
ool2o`0003?ooooo0_l00004ooooo`?o00001oooool2o`000003ooooool0003o000000;ooooo0_l0
000Cooooo`?o0000<oooool001cooooo00?o0000ooooooooool0Boooool2o`0000;ooooo0_l00000
0ooooooo0000o`000002ooooo`;o00000oooool5o`0000Kooooo0ol0000Fooooo`;o00000ooooolT
o`0000[ooooo0_l0000aooooo`;o0000;?ooool3o`0003?ooooo000Looooo`03o`000?oooooooooo
043ooooo0ol00008ooooo`;o00000_ooool2o`0000Kooooo0ol000001?oooooo0000o`000?ooool3
o`0001kooooo0_l00002ooooobCo00002oooool2o`00037ooooo1Ol00004ooooo`;o00008oooool2
o`0003Cooooo000Looooo`;o0000?oooool5o`0000cooooo0_l00006ooooo`?o00000_ooool5o`00
00Cooooo1?l0000Iooooob?o00003Oooool2o`0002Wooooo0_l00007ooooo`Co00001?ooool3o`00
00Cooooo1?l0001@ooooo`007?ooool00ol0003oooooooooo`0nooooo`Co000000?oooooo`000?l0
00002_ooool2o`0000Kooooo0ol00002ooooo`go00006OoooolSo`0000;ooooo0_l00008ooooo`?o
0000:Oooool2o`0000Oooooo0_l00007ooooo`Co00000_ooool4o`0001Kooooo0_l0000hooooo`00
7?ooool00ol0003oooooooooo`0nooooo`Oo00002oooool2o`0000Kooooo0ol00002ooooo`_o0000
7?oooolQo`0000;ooooo0_l00008ooooo`?o00001Oooool2o`0002;ooooo0_l00006ooooo`?o0000
2?ooool3o`0000;ooooo0ol0000Fooooo`?o0000>?ooool001cooooo00?o0000ooooooooool0?_oo
ool2o`000003ooooool0003o000000gooooo0ol00005ooooo`?o00000_ooool5o`000003ooooool0
003o000001kooooo8Ol00003ooooo`?o00002_ooool2o`0000?ooooo0_l0000Pooooo`?o00001?oo
ool2o`000003ooooool0003o000000Wooooo1ol0000Gooooo`;o0000>Oooool001cooooo00?o0000
ooooooooool0B?ooool2o`0000Oooooo0_l00006ooooo`?o000000?oooooo`000?l000001_l0000N
oooooa_o000000?oooooo`000?l000001?l00002ooooo`?o00002_ooool2o`0000Cooooo0_l0000O
ooooo`?o00001?ooool2o`0000gooooo1?l0000Iooooo`;o0000>Oooool001cooooo00?o0000oooo
ooooool0@_ooool2o`0000Cooooo0_l00007ooooo`;o00001_ooool8o`000003ooooool0003o0000
01kooooo:?l0000@ooooo`;o0000;?ooool5o`0000Cooooo0ol0001Eooooo`007?ooool00ol0003o
ooooooooo`0oooooo`;o000000?oooooo`000?l000001?ooool3o`0000Kooooo0_l00006ooooo`;o
000000?oooooo`000?l000000ol0000Pooooob?o000000?oooooo`000?l000000_l0000@ooooo`;o
00007_ooool2o`0000Gooooo1?l00003ooooo`Ko00001Oooool2o`0005Gooooo000Looooo`03o`00
0?oooooooooo03oooooo0_l000000ooooooo0000o`000005ooooo`;o00001_ooool2o`0000Kooooo
0_l00003ooooo`;o00008OoooolSo`0000?ooooo0_l0000@ooooo`;o00007_ooool2o`0000?ooooo
1_l00003ooooo`Go00001_ooool2o`0005Gooooo000Looooo`03o`000?oooooooooo04?ooooo0_l0
0006ooooo`?o00001?ooool2o`0000Gooooo0ol00007ooooo`;o00007?oooolRo`0000;ooooo1?l0
0009ooooo`;o0000:_ooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool3o`0000?ooooo
0_l0001Gooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00001_ooool3o`0000Cooooo0ol0
0005ooooo`;o00001oooool2o`0001cooooo0_l000000ooooooo0000o`000002o`0000;ooooo5?l0
00000ooooooo0000o`000006o`0000_ooooo0_l00003ooooo`;o0000:?ooool2o`000003ooooool0
003o000000Gooooo0_l000000ooooooo0000o`000002o`0005Oooooo000Looooo`03o`000?oooooo
oooo05?ooooo0_l00004ooooo`?o00001_ooool2o`0001gooooo0_l000000ooooooo0000o`000002
o`0000;ooooo4ol000000ooooooo0000o`000005o`000003ooooool0003o000000Sooooo0_l00005
ooooo`;o00009oooool3o`000003ooooool0003o000000;o00001?ooool4o`0005Wooooo000Loooo
o`03o`000?oooooooooo04oooooo0_l00008ooooo`_o00006_ooool2o`000004ooooool0003o0000
ooooo`Co00001Oooool@o`000004ooooool0003o0000o`0000;ooooo1Ol00003ooooo`;o00000ooo
ool2o`0000Cooooo0ol00002ooooo`;o00008oooool2o`0000?ooooo2_l0001Jooooo`007?ooool0
0ol0003oooooooooo`1?ooooo`;o00000_ooool2o`0000Oooooo1ol0000Kooooo`;o000000?ooooo
o`000?l000000_ooool8o`0000?ooooo4Ol00002ooooo`Go00000oooool3o`0000Sooooo0ol00000
1?oooooo0000o`000?l00002ooooo`;o00007Oooool4o`0000?ooooo1ol0001Mooooo`007?ooool0
0ol0003oooooooooo`16ooooo`;o00002oooool2o`0000_ooooo0_l0000Sooooo`Wo00001Oooool=
o`000004ooooool0003o0000ooooo`Co00001?ooool2o`0000cooooo0_l00003ooooo`;o00007Ooo
ool2o`0000Gooooo1_l0000Iooooo`;o0000@oooool001cooooo00?o0000ooooooooool0A_ooool2
o`0000_ooooo0ol0000:ooooo`;o00007oooool3o`0000Cooooo1_l000000ooooooo0000o`00000;
o`0000;ooooo1Ol000001?oooooo0000o`000?l00002ooooo`Go00004Oooool3o`00027ooooo1Ol0
000Jooooo`Co0000@oooool001cooooo00?o0000ooooooooool0Aoooool2o`0000Cooooo0_l00005
ooooo`;o00001_ooool2o`00027ooooo1Ol0000;ooooo`Co000000?oooooo`000?l000001Ol00003
ooooo`?o00000_ooool4o`000003ooooool0003o000000?o00002Oooool3o`0000Oooooo0_l0000Q
ooooo`?o00006oooool4o`0004Cooooo000Looooo`;o0000B?ooool2o`0000Cooooo0_l00005oooo
o`?o00001Oooool2o`00027ooooo0_l0000Cooooo`Oo00000oooool3o`000003ooooool0003o0000
00?o000000Coooooo`000?l0003ooooo0_l00009ooooo`?o0000:?ooool2o`0001kooooo0_l00016
ooooo`007?ooool00ol0003oooooooooo`1Dooooo`?o00002Oooool2o`0003?ooooo1_l00004oooo
o`Go00000_ooool7o`0001Sooooo0_l0000Jooooo`;o00007?ooool2o`0004Sooooo000Looooo`03
o`000?oooooooooo05Oooooo0_l00007ooooo`;o00008Oooool2o`0000_ooooo0_l000000ooooooo
0000o`000007o`0000;ooooo1_l00002ooooo`;o00000_ooool2o`0000Wooooo1?l0000<ooooo`;o
00004?ooool2o`0000Sooooo0_l0000Kooooo`?o0000B?ooool001cooooo00?o0000ooooooooool0
DOooool3o`0000?ooooo0_l0000Xooooo`Co00002_ooool3o`000004ooooool0003o0000ooooo`?o
000000?oooooo`000?l000000_ooool2o`000004ooooool0003o0000ooooo`?o00003_ooool4o`00
00?ooooo0_l00008ooooo`;o00003oooool3o`0000Oooooo0_l0000Kooooo`;o0000BOooool001co
oooo00?o0000ooooooooool0DOooool3o`0002gooooo0_l000000ooooooo0000o`000009ooooo`?o
00001Oooool2o`0000?ooooo1?l000001?oooooo0000o`000?ooool3o`0001Gooooo0_l00008oooo
o`;o00003oooool3o`0000;ooooo0_l0001[ooooo`007?ooool00ol0003oooooooooo`1:ooooo`?o
0000=oooool3o`00017ooooo2?l000001?oooooo0000o`000?ooool3o`0001_ooooo0_l00002oooo
o`;o00005?ooool2o`0000?ooooo0_l0001Vooooo`007?ooool00ol0003oooooooooo`1:ooooo`?o
00002oooool2o`0002_ooooo0_l0000<ooooo`;o00000oooool8o`000004ooooool0003o0000oooo
o`?o00006oooool3o`000003ooooool0003o000001Cooooo0_l00003ooooo`;o0000I_ooool001co
oooo00?o0000ooooooooool0Boooool2o`0000_ooooo0_l0000iooooo`;o00003_ooool2o`0001Ko
oooo0_l00006ooooo`;o00000_ooool2o`0001?ooooo0_l0000Jooooo`?o0000C_ooool001cooooo
00?o0000ooooooooool0Boooool2o`0003_ooooo0ol0000Dooooo`Ko00001?ooool2o`00013ooooo
0_l00003ooooo`;o00001Oooool2o`0001?ooooo0_l0000Jooooo`?o0000C_ooool001cooooo00?o
0000ooooooooool0C?ooool2o`0000Gooooo1?l00004ooooo`;o0000:oooool3o`0000gooooo0_l0
0002ooooo`;o000000?oooooo`000?l000000ol00005ooooo`;o00003oooool2o`0000;ooooo1_l0
000Hooooo`;o0000Joooool001cooooo00?o0000ooooooooool0C?ooool2o`0000Gooooo1Ol00003
ooooo`;o0000:?ooool2o`0000;ooooo0_l0000=ooooo`;o00000_ooool2o`0001cooooo1ol00000
0ooooooo0000o`00000aooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0C_ooool2o`00
00Kooooo0_l00004ooooo`;o00009oooool2o`0000;ooooo0_l0000`ooooo`Ko000000?oooooo`00
0?l000000_l0000>ooooo`?o00000oooool2o`0000Cooooo0_l0000@ooooo`;o000000?oooooo`00
0?l00000D_ooool001cooooo00?o0000ooooooooool0C_ooool2o`0000cooooo1?l0000Xooooo`;o
00000oooool2o`0002cooooo1Ol00002ooooo`Co00003_ooool3o`0000?ooooo0_l00003ooooo`?o
00004?ooool2o`0005Gooooo000Looooo`03o`000?oooooooooo05Kooooo0_l00006ooooo`;o0000
:?ooool2o`0000?ooooo0_l0000Xooooo`Co00000oooool3o`000003ooooool0003o000001Gooooo
0ol00003ooooo`;o00004Oooool2o`0005Gooooo000Looooo`03o`000?oooooooooo05Kooooo0_l0
0003ooooo`;o00000oooool3o`0005;ooooo1_l00004ooooo`;o00006?ooool2o`0006kooooo000L
ooooo`03o`000?oooooooooo053ooooo0ol00008ooooo`;o00000oooool3o`0002gooooo0_l0000Q
ooooo`So00007Oooool3o`0001Cooooo0_l0001Hooooo`007?ooool2o`00057ooooo0ol00008oooo
o`;o00001?ooool2o`0002gooooo0_l0000Looooo`Wo00000_ooool2o`0001gooooo0_l0000Coooo
o`Co0000F?ooool001cooooo00?o0000ooooooooool0Hoooool4o`0004Gooooo2_l00003ooooo`;o
00000_ooool2o`0000_ooooo0_l0000<ooooo`;o00004oooool2o`0005[ooooo000Looooo`03o`00
0?oooooooooo06?ooooo1Ol0000Vooooo`?o00006oooool2o`0000Gooooo0_l00002ooooo`So0000
2oooool2o`00023ooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o00001ooo
ool2o`0002Kooooo0ol00008ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`;o0000
00?oooooo`000?l000002_ooool2o`000003ooooool0003o000000Ko0000;?ooool4o`0005_ooooo
000Looooo`03o`000?oooooooooo05gooooo0_l00008ooooo`?o00006_ooool2o`0001?ooooo0_l0
0003ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000006ooooo`?o0000
1?ooool4o`0001_ooooo0_l0000Cooooo`?o0000G?ooool001cooooo00?o0000ooooooooool0Iooo
ool3o`0001Wooooo1?l0000<ooooo`;o00003?ooool2o`0000Oooooo0_l000000ooooooo0000o`00
0003o`0001Sooooo0ol00008ooooo`?o0000LOooool001cooooo00?o0000ooooooooool0Joooool4
o`0001Cooooo1?l0000<ooooo`;o00005Oooool2o`000003ooooool0003o000001_ooooo0ol00006
ooooo`;o000000?oooooo`000?l000003oooool2o`00063ooooo000Looooo`03o`000?oooooooooo
06_ooooo1Ol0000Iooooo`;o00004Oooool2o`0002Kooooo0_l000000ooooooo0000o`00000:oooo
o`;o00004_ooool2o`00063ooooo000Looooo`03o`000?oooooooooo06;ooooo0_l00009ooooo`?o
00006Oooool2o`00017ooooo0_l00006ooooo`;o00004_ooool2o`0000Wooooo0ol000000ooooooo
0000o`000020ooooo`007?ooool00ol0003oooooooooo`1Rooooo`?o00000_ooool2o`00033ooooo
0_l00006ooooo`;o000000?oooooo`000?l000004_ooool2o`0000Cooooo0_l000000ooooooo0000
o`000002o`0000Wooooo1?l0001gooooo`007?ooool00ol0003oooooooooo`1Sooooo`;o00000_oo
ool4o`00023ooooo0_l0000<ooooo`;o00001Oooool3o`000003ooooool0003o000000?ooooo1Ol0
000@ooooo`;o000000?oooooo`000?l000002?ooool2o`000003ooooool0003o000000;o0000Mooo
ool001cooooo00?o0000ooooooooool0GOooool2o`0000[ooooo0_l0000Pooooo`;o00001_ooool2
o`0000_ooooo0_l00002ooooo`;o00000oooool8o`0000;ooooo0ol00002ooooo`;o00003oooool4
o`0001Cooooo0_l0001Vooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o0000=?ooool2o`00
00oooooo0_l00008ooooo`?o00000_ooool4o`000003ooooool0003o000000_ooooo1_l0000Foooo
o`;o0000I_ooool001cooooo00?o0000ooooooooool0G_ooool2o`0003?ooooo0_l0000Cooooo`Co
00002Oooool2o`0000Sooooo0_l000000ooooooo0000o`000006o`0001?ooooo0_l0001Zooooo`00
00Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0G_ooool2o`0000Sooooo0_l0000nooooo`Co00001Oooool4
o`0000Cooooo0ol00003ooooo`;o000000Coooooo`000?l0003o00006?ooool2o`0006[ooooo0000
1_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ
8B401_ooool00ol0003oooooooooo`1Xooooo`;o00000oooool4o`000003ooooool0003o000001ko
oooo0_l0000Mooooo`Co00001?ooool3o`0001oooooo1?l0001Zooooo`0000?ooooooa0@4?ooool0
0_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`1]ooooo`Co000000?oooooo`000?l000007_ooool2o`0004Gooooo1?l0001/ooooo`00
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb
<S801_ooool3o`0007;ooooo0ol0000Xooooo`?o0000=Oooool2o`0000;ooooo1?l0001/ooooo`00
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<
c<`01_ooool00ol0003oooooooooo`1]ooooo`;o00000oooool3o`0000Wooooo0_l00005ooooo`Co
00005?ooool5o`0003?ooooo0_l0001booooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooo
ooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`1]ooooo`;o
00000oooool2o`0000Kooooo0ol000001?oooooo0000o`000?ooool3o`000003ooooool0003o0000
00;o00001_ooool2o`0000cooooo0_l000000ooooooo0000o`00000Tooooo`;o00001_ooool2o`00
00;ooooo1?l0001cooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooookZj^_l000001_ooool00ol0003oooooooooo`1iooooo`Co00001?ooool3o`000003ooooool0
003o000000;o00001?ooool4o`0000gooooo1Ol0000Pooooo`;o000000Coooooo`000?l0003ooooo
1?l000000ooooooo0000o`000002ooooo`Co0000Loooool00006ooooooo^k^ko<S8bo`000?lb<S;o
k^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0NOooool2o`00
00[ooooo0_l00006ooooo`;o00002_ooool3o`0000;ooooo1Ol000000ooooooo0000o`000004oooo
o`;o00000_ooool2o`0000?ooooo0_l00003ooooo`Co00001oooool2o`0000Cooooo1?l0001loooo
o`007?ooool00ol0003oooooooooo`1looooo`Co00002?ooool2o`000003ooooool0003o000000Oo
oooo1?l000001?oooooo0000o`000?l00005ooooo`;o000000?oooooo`000?l000001?ooool2o`00
00;ooooo0_l00003ooooo`;o00000oooool4o`0000gooooo1?l00004ooooo`?o0000MOooool001co
oooo00?o0000ooooooooool0O?ooool4o`000003ooooool0003o000000Gooooo0_l000001?oooooo
0000o`000?l00006ooooo`Co00000oooool2o`0000Cooooo1?l00006ooooo`;o00002?ooool2o`00
01?ooooo0ol00003ooooo`Co0000MOooool001cooooo00?o0000ooooooooool0Noooool3o`0000?o
oooo0_l00006ooooo`;o000000?oooooo`000?l000003Oooool2o`0000Kooooo1?l00004ooooo`;o
00002?ooool2o`0001Cooooo0_l00003ooooo`;o0000Moooool001cooooo00?o0000ooooooooool0
Noooool3o`0000[ooooo1?l00006ooooo`;o00002Oooool2o`0000Kooooo0_l00002ooooo`;o0000
6?ooool2o`0008Cooooo000Looooo`03o`000?oooooooooo087ooooo0_l00002ooooo`;o000000?o
ooooo`000?l000000_l000000ooooooo0000o`000003ooooo`;o00002Oooool2o`0000Wooooo0ol0
000Hooooo`?o0000Poooool001cooooo00?o0000ooooooooool0POooool2o`0000;ooooo0ol00005
ooooo`;o00000oooool2o`0000kooooo0_l00003ooooo`Go00001oooool2o`000003ooooool0003o
000000Kooooo0_l00004ooooo`;o0000Poooool001cooooo00?o0000ooooooooool0Q_ooool2o`00
00Kooooo1?l00008ooooo`;o00001_ooool2o`0000?ooooo1Ol00007ooooo`;o000000?oooooo`00
0?l000001_ooool2o`0008Wooooo000Looooo`03o`000?oooooooooo08kooooo1?l00006ooooo`Go
00001?ooool4o`0000Cooooo0_l0000;ooooo`;o0000TOooool001cooooo00?o0000ooooooooool0
Soooool2o`0000Cooooo2?l00004ooooo`Co00001?ooool2o`0000Cooooo0_l0002Hooooo`007?oo
ool00ol0003oooooooooo`2?ooooo`;o00001?ooool6o`0001Cooooo0_l00006ooooo`;o0000T?oo
ool001cooooo00?o0000ooooooooool0]oooool2o`00093ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001;ooooo1?l000000ol@413o
ooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo0ol0
003ooooood[ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000oooo
ooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`00
0?oooooooooo0?ooooooD_ooool001;ooooo00?oEEEEofIVI_l00000oooooomDooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00YOooool01?l@413o0000o`000?ooool2o`000003
oa0@4?oooooooooo01Gooooo1Ol00003ooooo`04oa0@4?l0003oA4A4olc<c0Kooooo0_l000000ol@
413oooooooooo`2>ooooo`00Y_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l00009oooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool00onHV9So410@omgMg@06ooooo`03o`000?oooooo
oooo08oooooo002Vooooo`05o`000?ooooooooooooooool000006Oooool00onHV9So8B4Qonk^kP07
ooooo`03ohN7QomEEEGooooo00;ooooo1Ol0002@ooooo`00Y_ooool01Ol0003ooooooooooooooooo
000000Wooooo1_l0000;ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Goc<c<ob4Q8Ol0003oEEEEo`00
0003ooooo`04odA4A?oMgMgoooooo`00097ooooo002Vooooo`05o`000?n7QhOoooooojVYZOl00000
6oooool00omgMgOoIVIVooooo`02ooooo`05ob4Q8On7QhOooooooiRHV?l000000oooool01?oMgMgo
EEEEooooool0002Aooooo`00YOooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo01[o
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?oMgMgolc<
c?l00000TOooool00<?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ob4Q8OnHV9Sooooo
ogMgMomEEED01?ooool00oo^k^koA4A4o`00002Aooooo`00`oooool01OnHV9So410@o`000?lQ8B7o
c<c<00?ooooo00Goc<c<oa0@4?l0003o<S8bonk^kP05ooooo`03ogMgMol0003ooooo093ooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(300) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.68504 .57267 Mdot
.67869 .54773 Mdot
.47397 .31892 Mdot
.433 .66873 Mdot
.3144 .37264 Mdot
.43701 .28651 Mdot
.61619 .34605 Mdot
.62243 .34172 Mdot
.47584 .29392 Mdot
.50148 .7874 Mdot
.59746 .36953 Mdot
.39955 .61606 Mdot
.62568 .35831 Mdot
.44016 .64038 Mdot
.33119 .55539 Mdot
.46486 .67335 Mdot
.71483 .55257 Mdot
.37921 .3788 Mdot
.46869 .66662 Mdot
.45491 .26722 Mdot
.5287 .67265 Mdot
.44623 .65029 Mdot
.64842 .53883 Mdot
.44376 .64092 Mdot
.47339 .5939 Mdot
.69079 .55186 Mdot
.68166 .57199 Mdot
.42574 .60054 Mdot
.45579 .66895 Mdot
.62743 .37505 Mdot
.43819 .48001 Mdot
.24761 .67203 Mdot
.50514 .62512 Mdot
.65896 .67941 Mdot
.64069 .3721 Mdot
.55721 .36968 Mdot
.41642 .31564 Mdot
.65393 .35617 Mdot
.5989 .3739 Mdot
.58162 .35688 Mdot
.58286 .35679 Mdot
.69225 .5538 Mdot
.64198 .33686 Mdot
.51341 .23216 Mdot
.4518 .63297 Mdot
.72406 .62576 Mdot
.46352 .23639 Mdot
.46275 .60725 Mdot
.67084 .5206 Mdot
.47822 .2769 Mdot
.25793 .47994 Mdot
.62144 .33612 Mdot
.50792 .5381 Mdot
.85853 .40593 Mdot
.62688 .34975 Mdot
.48556 .62056 Mdot
.45916 .30298 Mdot
.41996 .62419 Mdot
.4042 .61794 Mdot
.64419 .65211 Mdot
.41437 .63366 Mdot
.32961 .39131 Mdot
.637 .52702 Mdot
.47759 .26077 Mdot
.47697 .29906 Mdot
.64752 .34408 Mdot
.71819 .517 Mdot
.62822 .36978 Mdot
.45036 .66909 Mdot
.46827 .27226 Mdot
.47813 .63108 Mdot
.59837 .3696 Mdot
.67274 .56632 Mdot
.45322 .65176 Mdot
.78001 .48829 Mdot
.61731 .42101 Mdot
.38757 .34509 Mdot
.58666 .57368 Mdot
.41348 .38628 Mdot
.36153 .52437 Mdot
.45159 .65141 Mdot
.6458 .21586 Mdot
.3023 .53892 Mdot
.66931 .52629 Mdot
.49359 .54653 Mdot
.72274 .35121 Mdot
.47333 .60051 Mdot
.44493 .47585 Mdot
.3844 .64043 Mdot
.27871 .38518 Mdot
.4629 .29265 Mdot
.69425 .51776 Mdot
.45753 .63895 Mdot
.4551 .6602 Mdot
.58358 .79089 Mdot
.45289 .67408 Mdot
.41252 .6048 Mdot
.51319 .46206 Mdot
.59235 .34035 Mdot
.50772 .58558 Mdot
.46635 .38497 Mdot
.5072 .50989 Mdot
.48166 .61642 Mdot
.44885 .29647 Mdot
.63909 .52612 Mdot
.50065 .62276 Mdot
.61927 .36865 Mdot
.45347 .6435 Mdot
.6642 .3716 Mdot
.66602 .5223 Mdot
.41361 .60119 Mdot
.35198 .38663 Mdot
.56333 .54699 Mdot
.66044 .55989 Mdot
.70621 .70896 Mdot
.42282 .65468 Mdot
.42736 .61444 Mdot
.67823 .55055 Mdot
.43534 .27573 Mdot
.594 .20261 Mdot
.67873 .56597 Mdot
.5791 .35185 Mdot
.72045 .53849 Mdot
.52578 .52492 Mdot
.43479 .27478 Mdot
.52374 .488 Mdot
.52766 .48832 Mdot
.23947 .58593 Mdot
.42556 .66711 Mdot
.48129 .71638 Mdot
.4419 .29342 Mdot
.67115 .55984 Mdot
.63487 .36115 Mdot
.42138 .6807 Mdot
.69812 .53518 Mdot
.61612 .34287 Mdot
.32336 .40573 Mdot
.37987 .37225 Mdot
.6545 .54214 Mdot
.72419 .70223 Mdot
.56952 .35508 Mdot
.60204 .33158 Mdot
.25749 .48365 Mdot
.6686 .52697 Mdot
.33657 .37741 Mdot
.60808 .35966 Mdot
.19851 .38858 Mdot
.47034 .59104 Mdot
.24682 .52047 Mdot
.65891 .23126 Mdot
.25848 .47911 Mdot
.50021 .71476 Mdot
.35147 .37905 Mdot
.61578 .34249 Mdot
.46837 .61771 Mdot
.67813 .53134 Mdot
.69773 .53883 Mdot
.47361 .63952 Mdot
.50482 .60362 Mdot
.4321 .63301 Mdot
.50439 .61783 Mdot
.50326 .45852 Mdot
.45567 .63845 Mdot
.79941 .58694 Mdot
.68636 .52598 Mdot
.50058 .6047 Mdot
.41921 .31286 Mdot
.48106 .69518 Mdot
.64228 .33816 Mdot
.40553 .64766 Mdot
.495 .59531 Mdot
.3901 .63031 Mdot
.57688 .34748 Mdot
.79871 .49959 Mdot
.39948 .38114 Mdot
.58335 .36583 Mdot
.6222 .28471 Mdot
.43176 .30585 Mdot
.4235 .60777 Mdot
.35889 .37195 Mdot
.50974 .58036 Mdot
.46289 .64371 Mdot
.26015 .47144 Mdot
.4074 .61579 Mdot
.48997 .72293 Mdot
.41972 .70341 Mdot
.70828 .33744 Mdot
.78141 .53889 Mdot
.43983 .66755 Mdot
.51847 .7593 Mdot
.25376 .51222 Mdot
.5638 .40076 Mdot
.63662 .36193 Mdot
.43859 .27939 Mdot
.43736 .27656 Mdot
.62447 .39304 Mdot
.68712 .69651 Mdot
.47877 .7869 Mdot
.41948 .67539 Mdot
.50819 .51734 Mdot
.72577 .54273 Mdot
.34934 .38006 Mdot
.65784 .54804 Mdot
.62749 .19885 Mdot
.38618 .50382 Mdot
.41116 .5144 Mdot
.46433 .34928 Mdot
.48252 .28 Mdot
.51082 .50824 Mdot
.33849 .3727 Mdot
.43619 .62395 Mdot
.66494 .52429 Mdot
.2551 .50424 Mdot
.50424 .56921 Mdot
.44757 .83811 Mdot
.68802 .5688 Mdot
.2863 .62598 Mdot
.625 .35165 Mdot
.44907 .32258 Mdot
.47471 .60018 Mdot
.42936 .6491 Mdot
.66466 .51919 Mdot
.45688 .61207 Mdot
.3694 .5567 Mdot
.46741 .59247 Mdot
.46104 .25959 Mdot
.39356 .38462 Mdot
.58583 .37184 Mdot
.45459 .35361 Mdot
.66182 .56234 Mdot
.8375 .54965 Mdot
.44155 .31139 Mdot
.45142 .71922 Mdot
.59976 .36863 Mdot
.32529 .40473 Mdot
.44933 .30514 Mdot
.33309 .36161 Mdot
.40146 .64025 Mdot
.42595 .3215 Mdot
.33742 .39282 Mdot
.4343 .50706 Mdot
.50271 .61614 Mdot
.21346 .56345 Mdot
.60619 .34752 Mdot
.71243 .52757 Mdot
.46837 .63226 Mdot
.50532 .53927 Mdot
.50554 .59062 Mdot
.28502 .59538 Mdot
.52554 .50869 Mdot
.50696 .50378 Mdot
.33695 .51182 Mdot
.36028 .39892 Mdot
.77573 .37074 Mdot
.45713 .46921 Mdot
.7137 .55435 Mdot
.45525 .65754 Mdot
.67001 .29228 Mdot
.61095 .34233 Mdot
.42936 .62461 Mdot
.70671 .31465 Mdot
.60836 .35731 Mdot
.42675 .6175 Mdot
.61511 .37842 Mdot
.6899 .53047 Mdot
.35199 .55508 Mdot
.69895 .56822 Mdot
.458 .63045 Mdot
.61143 .3765 Mdot
.43239 .28219 Mdot
.69178 .55031 Mdot
.45108 .64702 Mdot
.41281 .65395 Mdot
.50909 .52355 Mdot
.46982 .59172 Mdot
.64084 .43408 Mdot
.46474 .60548 Mdot
.4572 .33605 Mdot
.45348 .67254 Mdot
.40133 .44208 Mdot
.26769 .3587 Mdot
.65786 .53436 Mdot
.52514 .50931 Mdot
.45446 .30459 Mdot
.38739 .54665 Mdot
.28185 .63529 Mdot
.45009 .63654 Mdot
.5229 .50788 Mdot
.25924 .60317 Mdot
.62881 .33323 Mdot
.3838 .64101 Mdot
.32328 .34735 Mdot
.46089 .29176 Mdot
.50895 .51163 Mdot
.4993 .57468 Mdot
.72871 .55701 Mdot
.4671 .66724 Mdot
.42916 .32032 Mdot
.70893 .55714 Mdot
.46941 .65937 Mdot
.58228 .4135 Mdot
.50051 .54146 Mdot
.59886 .33434 Mdot
.49601 .4845 Mdot
.4353 .60793 Mdot
.4704 .27419 Mdot
.69707 .55171 Mdot
.62668 .34616 Mdot
.66287 .56154 Mdot
.27215 .47635 Mdot
.274 .60923 Mdot
.75373 .5649 Mdot
.32586 .40908 Mdot
.17943 .42632 Mdot
.5779 .35936 Mdot
.51377 .58706 Mdot
.48579 .25706 Mdot
.6971 .48652 Mdot
.45237 .29543 Mdot
.73742 .68895 Mdot
.46227 .29671 Mdot
.48538 .62938 Mdot
.45543 .27762 Mdot
.58029 .80216 Mdot
.40747 .62477 Mdot
.47646 .30499 Mdot
.49466 .44952 Mdot
.40691 .6331 Mdot
.69916 .53516 Mdot
.28382 .72372 Mdot
.67444 .68833 Mdot
.67736 .69897 Mdot
.45511 .30911 Mdot
.74844 .67896 Mdot
.43502 .59745 Mdot
.41274 .67884 Mdot
.68105 .53494 Mdot
.51195 .59582 Mdot
.37185 .3802 Mdot
.37032 .36498 Mdot
.22733 .43473 Mdot
.28133 .67701 Mdot
.68949 .70874 Mdot
.69493 .54113 Mdot
.39492 .3617 Mdot
.77954 .4935 Mdot
.50111 .54168 Mdot
.62199 .34142 Mdot
.80474 .47326 Mdot
.38606 .64024 Mdot
.51057 .48355 Mdot
.36634 .55969 Mdot
.71203 .53836 Mdot
.67279 .59237 Mdot
.62541 .34449 Mdot
.67514 .70135 Mdot
.46823 .77631 Mdot
.43224 .63133 Mdot
.60301 .34214 Mdot
.50549 .59236 Mdot
.44633 .47712 Mdot
.2351 .59613 Mdot
.44847 .20895 Mdot
.45531 .62968 Mdot
.79263 .4579 Mdot
.4661 .63709 Mdot
.23934 .57081 Mdot
.43594 .62204 Mdot
.70204 .54438 Mdot
.39003 .61681 Mdot
.46151 .47156 Mdot
.21296 .32439 Mdot
.38427 .4987 Mdot
.34027 .36085 Mdot
.4397 .64315 Mdot
.4253 .63737 Mdot
.32277 .38848 Mdot
.70824 .52744 Mdot
.46772 .64265 Mdot
.79076 .37888 Mdot
.45662 .64245 Mdot
.64483 .34339 Mdot
.29638 .57014 Mdot
.24482 .65936 Mdot
.4484 .59648 Mdot
.73019 .5544 Mdot
.60028 .33267 Mdot
.59915 .36507 Mdot
.51706 .53989 Mdot
.60859 .34289 Mdot
.46467 .61646 Mdot
.29491 .5699 Mdot
.70606 .50699 Mdot
.50279 .55234 Mdot
.71044 .53808 Mdot
.32708 .23243 Mdot
.60983 .34698 Mdot
.51369 .52695 Mdot
.70288 .69188 Mdot
.61713 .36244 Mdot
.37868 .41228 Mdot
.38908 .61674 Mdot
.50346 .5629 Mdot
.69363 .5768 Mdot
.4682 .27391 Mdot
.51684 .50108 Mdot
.62659 .34858 Mdot
.45068 .63437 Mdot
.487 .60831 Mdot
.60673 .343 Mdot
.58044 .62754 Mdot
.43959 .47813 Mdot
.46068 .63229 Mdot
.69953 .52845 Mdot
.67557 .56061 Mdot
.44625 .69109 Mdot
.467 .63755 Mdot
.43357 .28624 Mdot
.52328 .50729 Mdot
.52411 .50175 Mdot
.52661 .48494 Mdot
.45223 .31587 Mdot
.17684 .41186 Mdot
.61379 .32834 Mdot
.24702 .66813 Mdot
.73579 .45357 Mdot
.50688 .54662 Mdot
.41924 .2952 Mdot
.4252 .65036 Mdot
.47565 .60893 Mdot
.62326 .37888 Mdot
.18151 .51308 Mdot
.41208 .67733 Mdot
.69768 .56775 Mdot
.61133 .33826 Mdot
.49323 .58892 Mdot
.68328 .32556 Mdot
.35988 .389 Mdot
.69664 .70951 Mdot
.617 .33762 Mdot
.67212 .50973 Mdot
.61758 .33738 Mdot
.42717 .63641 Mdot
.49993 .57638 Mdot
.71111 .545 Mdot
.31936 .36946 Mdot
.46987 .64526 Mdot
.43254 .61756 Mdot
.51801 .34623 Mdot
.77784 .48577 Mdot
.30996 .37411 Mdot
.4746 .6161 Mdot
.51722 .55961 Mdot
.31837 .37207 Mdot
.46194 .62074 Mdot
.46808 .65786 Mdot
.48057 .71763 Mdot
.65829 .353 Mdot
.31419 .40043 Mdot
.19355 .35313 Mdot
.68757 .56959 Mdot
.63794 .4356 Mdot
.51213 .49701 Mdot
.57842 .35838 Mdot
.36179 .57363 Mdot
.51624 .51295 Mdot
.75495 .43712 Mdot
.7772 .72622 Mdot
.51756 .50319 Mdot
.4094 .31598 Mdot
.60762 .7828 Mdot
.46747 .65742 Mdot
.46086 .62907 Mdot
.37075 .3832 Mdot
.67001 .54752 Mdot
.78303 .53569 Mdot
.58534 .36718 Mdot
.43449 .65893 Mdot
.66727 .56882 Mdot
.71303 .33965 Mdot
.51178 .51769 Mdot
.36342 .37769 Mdot
.31491 .39216 Mdot
.4657 .62975 Mdot
.26357 .62399 Mdot
.69437 .54807 Mdot
.4511 .64684 Mdot
.42946 .61241 Mdot
.41013 .30201 Mdot
.66252 .52831 Mdot
.42434 .31614 Mdot
.49861 .53337 Mdot
.64318 .78321 Mdot
.63212 .2803 Mdot
.60445 .35461 Mdot
.51795 .5296 Mdot
.58683 .37248 Mdot
.4741 .24347 Mdot
.52363 .50614 Mdot
.44945 .64748 Mdot
.69856 .50395 Mdot
.45255 .6457 Mdot
.45721 .64104 Mdot
.44946 .62957 Mdot
.69006 .70969 Mdot
.41611 .3869 Mdot
.36135 .37134 Mdot
.44463 .60638 Mdot
.43631 .32405 Mdot
.68399 .31656 Mdot
.52721 .79325 Mdot
.43516 .64658 Mdot
.42813 .61489 Mdot
.73082 .54941 Mdot
.4737 .59074 Mdot
.6124 .35715 Mdot
.71287 .53882 Mdot
.48237 .61222 Mdot
.47519 .37402 Mdot
.47043 .63569 Mdot
.72596 .58816 Mdot
.64549 .35068 Mdot
.46214 .5801 Mdot
.48579 .66981 Mdot
.52391 .50834 Mdot
.51599 .5025 Mdot
.52444 .48025 Mdot
.646 .34362 Mdot
.41078 .31277 Mdot
.48892 .31069 Mdot
.47146 .69296 Mdot
.46704 .61483 Mdot
.49823 .56749 Mdot
.4166 .33958 Mdot
.47057 .44092 Mdot
.72823 .68873 Mdot
.48902 .58965 Mdot
.45999 .31612 Mdot
.51255 .46241 Mdot
.57054 .60936 Mdot
.71162 .529 Mdot
.46585 .2531 Mdot
.61191 .37182 Mdot
.33884 .3951 Mdot
.22402 .4903 Mdot
.69074 .56243 Mdot
.73129 .52108 Mdot
.42695 .29819 Mdot
.28496 .56435 Mdot
.85927 .38592 Mdot
.44797 .28956 Mdot
.40077 .52603 Mdot
.68687 .53581 Mdot
.50494 .62276 Mdot
.26018 .59109 Mdot
.29639 .56247 Mdot
.47058 .30762 Mdot
.41364 .65559 Mdot
.35791 .21144 Mdot
.4357 .28449 Mdot
.51262 .56424 Mdot
.45318 .31133 Mdot
.61143 .33069 Mdot
.44298 .29745 Mdot
.65801 .56823 Mdot
.42847 .66731 Mdot
.85866 .39946 Mdot
.32035 .52719 Mdot
.43133 .6639 Mdot
.63465 .33846 Mdot
.56153 .39314 Mdot
.42968 .62905 Mdot
.36996 .37018 Mdot
.41015 .3161 Mdot
.42359 .23762 Mdot
.4778 .64864 Mdot
.45894 .27661 Mdot
.7354 .53157 Mdot
.43983 .25841 Mdot
.47291 .3805 Mdot
.51962 .49918 Mdot
.68481 .52862 Mdot
.6152 .41888 Mdot
.5795 .35078 Mdot
.4944 .63279 Mdot
.42563 .60996 Mdot
.68765 .52351 Mdot
.40792 .53076 Mdot
.39905 .67526 Mdot
.45463 .64561 Mdot
.42518 .31012 Mdot
.47468 .26617 Mdot
.32837 .55602 Mdot
.44026 .3137 Mdot
.51334 .55941 Mdot
.69429 .52738 Mdot
.47221 .6606 Mdot
.676 .56332 Mdot
.45766 .65528 Mdot
.68094 .33779 Mdot
.69881 .51734 Mdot
.45013 .71883 Mdot
.41009 .65361 Mdot
.78035 .60011 Mdot
.43561 .60513 Mdot
.46022 .63524 Mdot
.46262 .26213 Mdot
.32483 .38462 Mdot
.41927 .69003 Mdot
.67214 .36511 Mdot
.33197 .39789 Mdot
.56955 .639 Mdot
.43224 .27648 Mdot
.32156 .40086 Mdot
.21677 .45735 Mdot
.52567 .5056 Mdot
.32622 .37188 Mdot
.49513 .55064 Mdot
.60181 .35346 Mdot
.67568 .5029 Mdot
.40622 .63562 Mdot
.63424 .78709 Mdot
.4428 .47449 Mdot
.51026 .52424 Mdot
.46005 .62278 Mdot
.42165 .64477 Mdot
.66727 .56854 Mdot
.63165 .20299 Mdot
.48838 .27796 Mdot
.50766 .60425 Mdot
.68709 .56552 Mdot
.65222 .2228 Mdot
.47297 .30952 Mdot
.3612 .39596 Mdot
.60009 .37525 Mdot
.63543 .56221 Mdot
.50805 .53328 Mdot
.61139 .34526 Mdot
.46571 .33659 Mdot
.26306 .46635 Mdot
.46506 .66927 Mdot
.41649 .30605 Mdot
.2589 .47745 Mdot
.38086 .62803 Mdot
.62339 .39401 Mdot
.55271 .37528 Mdot
.67729 .51988 Mdot
.60736 .34213 Mdot
.36204 .36732 Mdot
.72164 .54148 Mdot
.71105 .53568 Mdot
.61229 .36165 Mdot
.79073 .63012 Mdot
.26 .60238 Mdot
.63788 .38244 Mdot
.29278 .59327 Mdot
.26061 .47508 Mdot
.50758 .52894 Mdot
.36047 .37517 Mdot
.39405 .3881 Mdot
.69153 .55382 Mdot
.80162 .47629 Mdot
.25764 .47919 Mdot
.4161 .60166 Mdot
.33473 .39343 Mdot
.71122 .34714 Mdot
.57626 .38799 Mdot
.61009 .35169 Mdot
.52333 .34178 Mdot
.32664 .39322 Mdot
.40772 .65614 Mdot
.17086 .56538 Mdot
.41109 .61905 Mdot
.60681 .35941 Mdot
.36754 .55852 Mdot
.66015 .54258 Mdot
.6361 .33495 Mdot
.36857 .55706 Mdot
.47423 .61264 Mdot
.41987 .65313 Mdot
.42554 .38664 Mdot
.67711 .51571 Mdot
.50025 .53474 Mdot
.4351 .66533 Mdot
.42356 .62009 Mdot
.49076 .64548 Mdot
.24181 .63995 Mdot
.57484 .53422 Mdot
.49781 .63548 Mdot
.44762 .32827 Mdot
.50552 .57676 Mdot
.50824 .60234 Mdot
.71123 .5729 Mdot
.45204 .39037 Mdot
.50141 .51964 Mdot
.45664 .62601 Mdot
.45911 .63068 Mdot
.60593 .37677 Mdot
.25936 .60147 Mdot
.29014 .56032 Mdot
.48143 .31108 Mdot
.37036 .33823 Mdot
.4238 .6728 Mdot
.6778 .52642 Mdot
.30561 .40142 Mdot
.51606 .54742 Mdot
.69759 .56679 Mdot
.43729 .67187 Mdot
.4079 .30674 Mdot
.52016 .50441 Mdot
.52104 .54837 Mdot
.33887 .3896 Mdot
.58595 .37483 Mdot
.57456 .61854 Mdot
.42595 .28877 Mdot
.47706 .59552 Mdot
.35663 .33946 Mdot
.46168 .28126 Mdot
.50746 .52524 Mdot
.50659 .58732 Mdot
.69288 .53335 Mdot
.66503 .51461 Mdot
.38987 .44485 Mdot
.44636 .32027 Mdot
.50197 .26004 Mdot
.60092 .33832 Mdot
.44233 .60788 Mdot
.57519 .36954 Mdot
.6566 .52845 Mdot
.2387 .58558 Mdot
.31704 .39595 Mdot
.60981 .35596 Mdot
.50174 .54615 Mdot
.70857 .52331 Mdot
.6554 .5282 Mdot
.45583 .63674 Mdot
.44183 .64968 Mdot
.46077 .2454 Mdot
.24996 .51978 Mdot
.62498 .37956 Mdot
.35686 .3961 Mdot
.48225 .30805 Mdot
.48361 .63054 Mdot
.66706 .53171 Mdot
.21773 .63875 Mdot
.43472 .60712 Mdot
.4384 .32319 Mdot
.68113 .54712 Mdot
.36867 .38438 Mdot
.35822 .36665 Mdot
.44487 .66286 Mdot
.49488 .71722 Mdot
.61947 .36496 Mdot
.70073 .53759 Mdot
.63738 .51143 Mdot
.44973 .60577 Mdot
.43928 .64644 Mdot
.37806 .63317 Mdot
.65115 .37782 Mdot
.46837 .68312 Mdot
.32481 .36609 Mdot
.6565 .55169 Mdot
.43944 .66252 Mdot
.32655 .39023 Mdot
.5179 .47691 Mdot
.51825 .51173 Mdot
.47804 .28642 Mdot
.37037 .36832 Mdot
.33143 .38249 Mdot
.33609 .39988 Mdot
.80506 .47168 Mdot
.49345 .53608 Mdot
.30542 .43075 Mdot
.41351 .65697 Mdot
.26139 .47402 Mdot
.4625 .67811 Mdot
.61587 .33306 Mdot
.47193 .27646 Mdot
.4428 .63094 Mdot
.41233 .65515 Mdot
.5775 .6006 Mdot
.47238 .66272 Mdot
.43734 .68909 Mdot
.65863 .54211 Mdot
.64654 .50235 Mdot
.44027 .27701 Mdot
.66721 .24103 Mdot
.18905 .64228 Mdot
.41234 .67089 Mdot
.28752 .56566 Mdot
.70596 .52342 Mdot
.60206 .37564 Mdot
.28257 .59167 Mdot
.57358 .37321 Mdot
.6746 .55658 Mdot
.48504 .63286 Mdot
.59444 .59099 Mdot
.33106 .39595 Mdot
.43038 .63507 Mdot
.63214 .36818 Mdot
.43113 .634 Mdot
.63835 .33826 Mdot
.75219 .66607 Mdot
.28114 .54612 Mdot
.40577 .62207 Mdot
.45379 .67345 Mdot
.52879 .66469 Mdot
.43775 .64812 Mdot
.4411 .21027 Mdot
.68149 .54251 Mdot
.47987 .6911 Mdot
.48794 .62512 Mdot
.66825 .69138 Mdot
.44591 .61548 Mdot
.3687 .57897 Mdot
.41342 .6245 Mdot
.18356 .48831 Mdot
.40153 .63249 Mdot
.41948 .61142 Mdot
.63924 .35348 Mdot
.58895 .36624 Mdot
.72248 .49543 Mdot
.50224 .52141 Mdot
.71 .34094 Mdot
.43217 .61648 Mdot
.48602 .28554 Mdot
.45245 .72919 Mdot
.32786 .38433 Mdot
.65999 .55555 Mdot
.84494 .66466 Mdot
.63453 .33053 Mdot
.42639 .32639 Mdot
.42788 .49531 Mdot
.43689 .33003 Mdot
.47551 .25451 Mdot
.62054 .54279 Mdot
.36077 .37669 Mdot
.46883 .63795 Mdot
.66515 .67414 Mdot
.77958 .47417 Mdot
.45177 .60604 Mdot
.41982 .34725 Mdot
.47109 .71768 Mdot
.36716 .45965 Mdot
.37587 .38477 Mdot
.34817 .37522 Mdot
.62223 .34729 Mdot
.48407 .29674 Mdot
.50813 .59534 Mdot
.32087 .4008 Mdot
.4471 .27624 Mdot
.52193 .52102 Mdot
.43829 .39243 Mdot
.69574 .5472 Mdot
.74563 .68173 Mdot
.73446 .62457 Mdot
.59255 .33762 Mdot
.67161 .36692 Mdot
.68858 .50215 Mdot
.70639 .56323 Mdot
.5042 .5195 Mdot
.46391 .31123 Mdot
.66922 .50524 Mdot
.44053 .66417 Mdot
.50476 .56929 Mdot
.46688 .63132 Mdot
.36752 .39279 Mdot
.45248 .61896 Mdot
.45123 .27655 Mdot
.6409 .3521 Mdot
.46001 .29521 Mdot
.61787 .34508 Mdot
.25858 .69477 Mdot
.41094 .6586 Mdot
.44188 .645 Mdot
.29488 .56922 Mdot
.6532 .53593 Mdot
.6526 .68735 Mdot
.44321 .32062 Mdot
.45838 .30289 Mdot
.48705 .62891 Mdot
.72172 .52927 Mdot
.33504 .35415 Mdot
.30216 .58709 Mdot
.41498 .62167 Mdot
.67967 .5422 Mdot
.48659 .63482 Mdot
.65862 .40836 Mdot
.3108 .54016 Mdot
.6506 .54658 Mdot
.21645 .31897 Mdot
.40706 .64863 Mdot
.51329 .59398 Mdot
.45464 .71243 Mdot
.26172 .65136 Mdot
.40407 .67873 Mdot
.69056 .56853 Mdot
.50709 .60061 Mdot
.67286 .52996 Mdot
.45787 .28418 Mdot
.63462 .33322 Mdot
.67498 .53363 Mdot
.40872 .63574 Mdot
.18931 .64085 Mdot
.64437 .35902 Mdot
.43497 .63569 Mdot
.63551 .36972 Mdot
.6405 .52639 Mdot
.66449 .54611 Mdot
.52151 .52241 Mdot
.40254 .5239 Mdot
.61375 .36098 Mdot
.46473 .61379 Mdot
.79093 .49324 Mdot
.4659 .66902 Mdot
.37761 .34055 Mdot
.43745 .67892 Mdot
.43827 .67273 Mdot
.17313 .39901 Mdot
.39233 .54541 Mdot
.6452 .27827 Mdot
.66252 .30547 Mdot
.79806 .5035 Mdot
.69499 .57782 Mdot
.37631 .38208 Mdot
.59713 .54651 Mdot
.52475 .49787 Mdot
.45149 .32741 Mdot
.44788 .63258 Mdot
.51751 .47149 Mdot
.64304 .37948 Mdot
.32901 .37188 Mdot
.40752 .61567 Mdot
.42272 .33395 Mdot
.52584 .51963 Mdot
.61088 .3479 Mdot
.69162 .55504 Mdot
.66414 .55455 Mdot
.41078 .39397 Mdot
.43761 .66278 Mdot
.44531 .64906 Mdot
.64255 .36943 Mdot
.43176 .70897 Mdot
.34674 .39735 Mdot
.49351 .44896 Mdot
.63071 .37089 Mdot
.30848 .53935 Mdot
.67517 .51579 Mdot
.4232 .64752 Mdot
.30083 .57064 Mdot
.78982 .52365 Mdot
.5439 .77242 Mdot
.34539 .38009 Mdot
.2764 .6311 Mdot
.69005 .56851 Mdot
.63514 .35962 Mdot
.2222 .44451 Mdot
.38696 .61851 Mdot
.41869 .6373 Mdot
.27555 .64012 Mdot
.30112 .58864 Mdot
.42694 .49792 Mdot
.50186 .54968 Mdot
.26474 .58146 Mdot
.48699 .63101 Mdot
.48584 .60819 Mdot
.42155 .67158 Mdot
.43982 .67915 Mdot
.67293 .53939 Mdot
.66876 .70734 Mdot
.43272 .29751 Mdot
.54602 .75678 Mdot
.38579 .33717 Mdot
.42892 .59975 Mdot
.47969 .6182 Mdot
.56923 .71064 Mdot
.30424 .62653 Mdot
.68889 .54243 Mdot
.68473 .57944 Mdot
.5837 .34346 Mdot
.46528 .67132 Mdot
.44162 .32236 Mdot
.46273 .70618 Mdot
.47335 .28506 Mdot
.67415 .54106 Mdot
.41536 .29242 Mdot
.60111 .32766 Mdot
.41628 .30705 Mdot
.45631 .32082 Mdot
.63875 .34586 Mdot
.68994 .51356 Mdot
.42971 .60493 Mdot
.63828 .34472 Mdot
.31736 .36477 Mdot
.36887 .38992 Mdot
.70469 .49418 Mdot
.50207 .62854 Mdot
.38709 .64035 Mdot
.51187 .26384 Mdot
.41602 .31705 Mdot
.3215 .59043 Mdot
.69165 .51547 Mdot
.31387 .40586 Mdot
.67035 .53456 Mdot
.35684 .44696 Mdot
.3411 .38334 Mdot
.49395 .5476 Mdot
.21845 .52771 Mdot
.56567 .34101 Mdot
.39355 .61944 Mdot
.64721 .50232 Mdot
.47258 .28698 Mdot
.63596 .33818 Mdot
.69361 .32544 Mdot
.50711 .60717 Mdot
.7348 .51453 Mdot
.63681 .5465 Mdot
.52441 .50059 Mdot
.63438 .36185 Mdot
.75238 .61581 Mdot
.4322 .66269 Mdot
.57459 .36001 Mdot
.43644 .67842 Mdot
.71336 .70721 Mdot
.38536 .30301 Mdot
.51275 .46563 Mdot
.48586 .62902 Mdot
.47202 .31091 Mdot
.48642 .63002 Mdot
.65405 .76348 Mdot
.2346 .55304 Mdot
.41785 .67059 Mdot
.29816 .62709 Mdot
.47509 .24162 Mdot
.66825 .52934 Mdot
.51002 .54965 Mdot
.50859 .52677 Mdot
.48632 .60002 Mdot
.27676 .77085 Mdot
.3221 .38333 Mdot
.46399 .36117 Mdot
.40874 .6404 Mdot
.4504 .65184 Mdot
.572 .6201 Mdot
.74959 .66647 Mdot
.5289 .50862 Mdot
.41966 .63221 Mdot
.28598 .65446 Mdot
.63438 .34964 Mdot
.46439 .66627 Mdot
.46376 .63816 Mdot
.43628 .25235 Mdot
.63842 .35557 Mdot
.41903 .29188 Mdot
.5257 .5031 Mdot
.47161 .26727 Mdot
.31615 .37123 Mdot
.2858 .62796 Mdot
.23912 .6108 Mdot
.31645 .5449 Mdot
.36685 .36565 Mdot
.45463 .59502 Mdot
.4953 .48969 Mdot
.41829 .65676 Mdot
.34635 .37265 Mdot
.62697 .37535 Mdot
.6793 .53977 Mdot
.73139 .69683 Mdot
.5082 .5219 Mdot
.45737 .59939 Mdot
.35927 .40249 Mdot
.68031 .53169 Mdot
.80714 .58067 Mdot
.67026 .54559 Mdot
.61456 .35081 Mdot
.6301 .39279 Mdot
.33491 .38608 Mdot
.66977 .53433 Mdot
.46642 .2643 Mdot
.60987 .39873 Mdot
.40615 .60212 Mdot
.60425 .32694 Mdot
.64281 .53741 Mdot
.65114 .55419 Mdot
.71447 .51135 Mdot
.48715 .62023 Mdot
.3069 .61366 Mdot
.51674 .53454 Mdot
.64439 .36507 Mdot
.43861 .33478 Mdot
.2464 .52717 Mdot
.66601 .62965 Mdot
.29673 .54595 Mdot
.49608 .55872 Mdot
.45407 .61988 Mdot
.46474 .62845 Mdot
.4903 .64958 Mdot
.48476 .47671 Mdot
.41395 .66217 Mdot
.62432 .37907 Mdot
.4496 .28117 Mdot
.41456 .62754 Mdot
.51833 .51844 Mdot
.46657 .44495 Mdot
.31171 .39877 Mdot
.69677 .71194 Mdot
.70189 .49267 Mdot
.67967 .53305 Mdot
.42939 .31937 Mdot
.4237 .28058 Mdot
.32433 .40574 Mdot
.61684 .34018 Mdot
.67022 .54914 Mdot
.18534 .47844 Mdot
.33798 .3975 Mdot
.45478 .625 Mdot
.29607 .56967 Mdot
.28031 .66492 Mdot
.46992 .64886 Mdot
.44876 .62827 Mdot
.50227 .5167 Mdot
.44144 .32414 Mdot
.52892 .80162 Mdot
.79473 .59015 Mdot
.32832 .38765 Mdot
.34177 .40294 Mdot
.72131 .5178 Mdot
.44562 .6108 Mdot
.6216 .36665 Mdot
.25932 .60793 Mdot
.58013 .41352 Mdot
.72288 .35585 Mdot
.48124 .2443 Mdot
.4712 .63317 Mdot
.63684 .75139 Mdot
.3935 .64735 Mdot
.64102 .5227 Mdot
.67929 .50838 Mdot
.69277 .54187 Mdot
.63186 .34699 Mdot
.26584 .46341 Mdot
.58437 .35819 Mdot
.51187 .46164 Mdot
.70006 .55768 Mdot
.40955 .52414 Mdot
.457 .30553 Mdot
.46525 .67387 Mdot
.35774 .37471 Mdot
.29678 .36029 Mdot
.50837 .55329 Mdot
.27953 .62997 Mdot
.41905 .29547 Mdot
.71245 .52406 Mdot
.46971 .66891 Mdot
.68207 .31396 Mdot
.27485 .55579 Mdot
.45777 .22397 Mdot
.51607 .47007 Mdot
.32949 .39187 Mdot
.49498 .78531 Mdot
.35146 .39286 Mdot
.60953 .35697 Mdot
.41037 .65569 Mdot
.4413 .61068 Mdot
.46095 .6353 Mdot
.42304 .67987 Mdot
.62913 .34964 Mdot
.40013 .61183 Mdot
.40021 .44309 Mdot
.52743 .49297 Mdot
.46986 .46649 Mdot
.34906 .36378 Mdot
.60451 .33648 Mdot
.45763 .28026 Mdot
.50788 .50193 Mdot
.31972 .40891 Mdot
.47429 .66547 Mdot
.41118 .64357 Mdot
.52924 .49568 Mdot
.49639 .55548 Mdot
.38755 .64614 Mdot
.43218 .29172 Mdot
.45062 .4727 Mdot
.31156 .39357 Mdot
.35296 .38261 Mdot
.60195 .34635 Mdot
.67012 .53372 Mdot
.31555 .39994 Mdot
.45473 .33607 Mdot
.46546 .6659 Mdot
.43337 .67827 Mdot
.64368 .54282 Mdot
.25917 .4743 Mdot
.31146 .39871 Mdot
.4636 .68743 Mdot
.65253 .54685 Mdot
.63629 .54746 Mdot
.42031 .63395 Mdot
.40529 .60775 Mdot
.71121 .57221 Mdot
.34286 .40409 Mdot
.60122 .34324 Mdot
.3013 .52284 Mdot
.61346 .32906 Mdot
.69515 .55376 Mdot
.5061 .57199 Mdot
.70078 .51544 Mdot
.50669 .60812 Mdot
.77421 .34713 Mdot
.41546 .66427 Mdot
.66595 .59819 Mdot
.45763 .4386 Mdot
.4563 .30859 Mdot
.4628 .3065 Mdot
.52182 .50593 Mdot
.70392 .56152 Mdot
.51322 .5564 Mdot
.36266 .38189 Mdot
.79742 .50258 Mdot
.71228 .57245 Mdot
.45841 .31895 Mdot
.41629 .32305 Mdot
.63338 .37082 Mdot
.45109 .61774 Mdot
.42308 .64887 Mdot
.41573 .30545 Mdot
.60974 .42908 Mdot
.68459 .51923 Mdot
.4456 .64857 Mdot
.49582 .63796 Mdot
.43466 .29408 Mdot
.58876 .31975 Mdot
.67691 .50347 Mdot
.48806 .61961 Mdot
.23507 .56308 Mdot
.63985 .33761 Mdot
.47594 .60112 Mdot
.393 .61904 Mdot
.32915 .37905 Mdot
.27408 .63408 Mdot
.25795 .48278 Mdot
.63093 .32862 Mdot
.52236 .51498 Mdot
.47221 .64245 Mdot
.46152 .30361 Mdot
.45832 .68575 Mdot
.6402 .82351 Mdot
.52813 .4985 Mdot
.43539 .66091 Mdot
.45613 .70761 Mdot
.67606 .5636 Mdot
.44898 .65038 Mdot
.68001 .3412 Mdot
.42984 .31298 Mdot
.43338 .66121 Mdot
.52531 .68442 Mdot
.6339 .36976 Mdot
.50845 .55121 Mdot
.32844 .39426 Mdot
.4149 .51251 Mdot
.28122 .7211 Mdot
.41611 .33892 Mdot
.34343 .36237 Mdot
.44127 .6149 Mdot
.48565 .2993 Mdot
.58531 .36478 Mdot
.51351 .53637 Mdot
.47329 .59676 Mdot
.58855 .34211 Mdot
.63513 .34577 Mdot
.33499 .38889 Mdot
.86596 .49269 Mdot
.40768 .66171 Mdot
.43137 .64075 Mdot
.8427 .53922 Mdot
.67445 .58703 Mdot
.43422 .63418 Mdot
.42968 .61162 Mdot
.60619 .34726 Mdot
.26546 .44909 Mdot
.27825 .63109 Mdot
.49252 .45291 Mdot
.63097 .33495 Mdot
.48357 .31394 Mdot
.42131 .3106 Mdot
.33525 .36376 Mdot
.68095 .54795 Mdot
.32581 .40783 Mdot
.43933 .30003 Mdot
.45653 .63116 Mdot
.59349 .35424 Mdot
.44259 .77126 Mdot
.644 .34637 Mdot
.43242 .33921 Mdot
.64048 .52439 Mdot
.59319 .80103 Mdot
.66404 .81432 Mdot
.57727 .52289 Mdot
.62228 .3954 Mdot
.32769 .38399 Mdot
.79668 .5887 Mdot
.41466 .62528 Mdot
.65397 .75797 Mdot
.43037 .63709 Mdot
.52382 .47188 Mdot
.46623 .2742 Mdot
.52178 .52149 Mdot
.50705 .6087 Mdot
.28273 .63233 Mdot
.63039 .34129 Mdot
.61956 .373 Mdot
.5064 .59985 Mdot
.61382 .3544 Mdot
.43001 .65581 Mdot
.44206 .2865 Mdot
.81648 .39691 Mdot
.41195 .62683 Mdot
.48153 .68733 Mdot
.56929 .35255 Mdot
.7678 .53943 Mdot
.47288 .32835 Mdot
.65044 .72905 Mdot
.7066 .33153 Mdot
.62244 .36525 Mdot
.69146 .71167 Mdot
.43302 .32065 Mdot
.50736 .50254 Mdot
.48797 .2833 Mdot
.42727 .64328 Mdot
.47205 .63099 Mdot
.48761 .65377 Mdot
.43156 .61356 Mdot
.60757 .76966 Mdot
.38413 .6358 Mdot
.54355 .7028 Mdot
.4143 .65787 Mdot
.60936 .5648 Mdot
.59723 .37032 Mdot
.50694 .5897 Mdot
.32666 .50614 Mdot
.4319 .67053 Mdot
.69267 .57707 Mdot
.60448 .3344 Mdot
.70068 .30329 Mdot
.63237 .35032 Mdot
.4614 .29487 Mdot
.62281 .3411 Mdot
.41116 .60693 Mdot
.68016 .5602 Mdot
.44463 .30616 Mdot
.50693 .54262 Mdot
.44953 .33129 Mdot
.43159 .66387 Mdot
.58338 .30983 Mdot
.42498 .32415 Mdot
.38468 .62212 Mdot
.67645 .55977 Mdot
.21335 .59308 Mdot
.68546 .5002 Mdot
.44964 .64013 Mdot
.44363 .63638 Mdot
.53014 .4975 Mdot
.61601 .34242 Mdot
.69526 .51282 Mdot
.53046 .33592 Mdot
.31402 .40643 Mdot
.68735 .5465 Mdot
.44954 .71546 Mdot
.28347 .56564 Mdot
.66065 .56007 Mdot
.28376 .65989 Mdot
.60754 .35755 Mdot
.68108 .56833 Mdot
.42306 .71585 Mdot
.54161 .75654 Mdot
.3538 .38647 Mdot
.46573 .26288 Mdot
.27892 .58022 Mdot
.42297 .31239 Mdot
.68193 .32886 Mdot
.4626 .25982 Mdot
.64046 .36304 Mdot
.46616 .72047 Mdot
.36926 .55715 Mdot
.65183 .36379 Mdot
.59286 .30305 Mdot
.42945 .30315 Mdot
.50117 .62602 Mdot
.46118 .46894 Mdot
.5194 .55601 Mdot
.51511 .5825 Mdot
.63685 .33198 Mdot
.68341 .5693 Mdot
.72113 .54041 Mdot
.46863 .7061 Mdot
.6594 .54794 Mdot
.45016 .29247 Mdot
.3222 .54935 Mdot
.70271 .69162 Mdot
.61164 .37495 Mdot
.44331 .47722 Mdot
.48093 .61814 Mdot
.45718 .27612 Mdot
.45315 .29014 Mdot
.632 .3444 Mdot
.57806 .74908 Mdot
.51593 .56128 Mdot
.64282 .57501 Mdot
.6926 .5624 Mdot
.67603 .56435 Mdot
.66519 .52199 Mdot
.26426 .46308 Mdot
.6331 .33716 Mdot
.7012 .56294 Mdot
.42605 .68203 Mdot
.44621 .61372 Mdot
.51315 .50165 Mdot
.36426 .39494 Mdot
.38638 .62984 Mdot
.51362 .55598 Mdot
.42032 .63632 Mdot
.45187 .31263 Mdot
.45969 .73032 Mdot
.52473 .49048 Mdot
.44295 .32245 Mdot
.45003 .31705 Mdot
.52405 .50866 Mdot
.45596 .72865 Mdot
.54517 .78792 Mdot
.48101 .59159 Mdot
.62295 .54807 Mdot
.46577 .30511 Mdot
.49371 .36985 Mdot
.65343 .59348 Mdot
.4622 .61468 Mdot
.48301 .44488 Mdot
.44799 .2854 Mdot
.69392 .57901 Mdot
.43261 .64696 Mdot
.50342 .52432 Mdot
.347 .39194 Mdot
.5089 .54206 Mdot
.50204 .51888 Mdot
.67292 .52442 Mdot
.50828 .27067 Mdot
.6662 .5682 Mdot
.4221 .27966 Mdot
.50672 .55652 Mdot
.85884 .39174 Mdot
.47099 .28685 Mdot
.7996 .49415 Mdot
.37454 .55229 Mdot
.41555 .64574 Mdot
.42817 .31717 Mdot
.73445 .53988 Mdot
.64719 .34246 Mdot
.31393 .61016 Mdot
.66673 .53515 Mdot
.51036 .49668 Mdot
.51368 .50596 Mdot
.43281 .29631 Mdot
.70407 .54567 Mdot
.39608 .61539 Mdot
.66625 .55581 Mdot
.59364 .36069 Mdot
.49733 .59652 Mdot
.70951 .34007 Mdot
.50823 .588 Mdot
.6575 .54942 Mdot
.43806 .33633 Mdot
.31956 .36952 Mdot
.40842 .62314 Mdot
.7047 .30834 Mdot
.44181 .6146 Mdot
.63191 .37314 Mdot
.4437 .44261 Mdot
.46608 .76065 Mdot
.43956 .62188 Mdot
.47786 .61541 Mdot
.58748 .32919 Mdot
.43595 .62257 Mdot
.45439 .66913 Mdot
.75187 .61819 Mdot
.65679 .55624 Mdot
.41542 .62602 Mdot
.42388 .29387 Mdot
.53398 .68837 Mdot
.45162 .65469 Mdot
.68009 .34751 Mdot
.26207 .64046 Mdot
.43043 .43921 Mdot
.47928 .69829 Mdot
.23863 .58249 Mdot
.4391 .63768 Mdot
.45681 .61226 Mdot
.49812 .59358 Mdot
.64034 .75307 Mdot
.435 .30405 Mdot
.47559 .30879 Mdot
.32886 .36447 Mdot
.27644 .64218 Mdot
.34623 .38645 Mdot
.58467 .36464 Mdot
.4215 .50256 Mdot
.52607 .48688 Mdot
.67062 .53223 Mdot
.4594 .64031 Mdot
.45303 .33214 Mdot
.42636 .6494 Mdot
.48432 .60072 Mdot
.44633 .29285 Mdot
.45417 .28557 Mdot
.39798 .32417 Mdot
.32638 .39545 Mdot
.68614 .53778 Mdot
.40369 .63853 Mdot
.3301 .39755 Mdot
.48985 .64852 Mdot
.28817 .52762 Mdot
.68858 .5395 Mdot
.65648 .54687 Mdot
.71553 .54311 Mdot
.416 .61256 Mdot
.4962 .5942 Mdot
.58275 .35502 Mdot
.64359 .54304 Mdot
.61474 .36476 Mdot
.4267 .31677 Mdot
.43846 .28303 Mdot
.42696 .64238 Mdot
.43422 .70825 Mdot
.3559 .36647 Mdot
.42091 .322 Mdot
.51173 .48826 Mdot
.31874 .37741 Mdot
.46807 .63452 Mdot
.4239 .31469 Mdot
.37073 .37567 Mdot
.56781 .758 Mdot
.69413 .39697 Mdot
.3231 .36882 Mdot
.50874 .60847 Mdot
.64868 .63244 Mdot
.23761 .54436 Mdot
.30736 .39747 Mdot
.59793 .37019 Mdot
.42995 .60726 Mdot
.50184 .45923 Mdot
.31317 .39288 Mdot
.25101 .4961 Mdot
.44472 .29845 Mdot
.51419 .58661 Mdot
.56221 .55253 Mdot
.6992 .69173 Mdot
.31746 .37153 Mdot
.65736 .55088 Mdot
.65268 .52556 Mdot
.45067 .62392 Mdot
.41588 .50991 Mdot
.63715 .37949 Mdot
.42567 .27873 Mdot
.47126 .31622 Mdot
.66548 .51165 Mdot
.31458 .54261 Mdot
.42179 .29842 Mdot
.44475 .60872 Mdot
.38542 .36645 Mdot
.43857 .68882 Mdot
.37135 .44976 Mdot
.45307 .75721 Mdot
.46911 .71025 Mdot
.31997 .36986 Mdot
.63626 .37831 Mdot
.64108 .35426 Mdot
.62174 .34478 Mdot
.42707 .2951 Mdot
.28058 .59009 Mdot
.47655 .31112 Mdot
.8316 .55742 Mdot
.32135 .3838 Mdot
.18723 .41304 Mdot
.40671 .66944 Mdot
.41724 .64996 Mdot
.45958 .675 Mdot
.4984 .6283 Mdot
.43959 .63887 Mdot
.58505 .34469 Mdot
.47126 .26943 Mdot
.5508 .37593 Mdot
.69843 .52704 Mdot
.80621 .58324 Mdot
.45523 .30722 Mdot
.50019 .52644 Mdot
.35655 .36911 Mdot
.23709 .61914 Mdot
.37127 .35948 Mdot
.41039 .30878 Mdot
.45418 .66328 Mdot
.72333 .51918 Mdot
.18352 .49884 Mdot
.454 .64695 Mdot
.41631 .3186 Mdot
.47631 .32032 Mdot
.55731 .75094 Mdot
.43681 .56557 Mdot
.57347 .41059 Mdot
.30402 .56722 Mdot
.35747 .3581 Mdot
.50248 .63066 Mdot
.25934 .61722 Mdot
.43784 .2997 Mdot
.47481 .29908 Mdot
.29983 .39519 Mdot
.77102 .5305 Mdot
.70601 .55601 Mdot
.65543 .50311 Mdot
.58996 .34332 Mdot
.41441 .64901 Mdot
.4257 .3067 Mdot
.65234 .5093 Mdot
.30296 .4927 Mdot
.62234 .35151 Mdot
.42528 .32593 Mdot
.43858 .61352 Mdot
.44007 .62064 Mdot
.34343 .38816 Mdot
.45975 .44271 Mdot
.51915 .55611 Mdot
.79756 .5006 Mdot
.29238 .55471 Mdot
.37495 .55144 Mdot
.41857 .63741 Mdot
.66632 .52285 Mdot
.52377 .50748 Mdot
.36101 .37508 Mdot
.45543 .68676 Mdot
.63388 .78465 Mdot
.67044 .57468 Mdot
.61534 .36374 Mdot
.50597 .53318 Mdot
.29047 .62781 Mdot
.43669 .61369 Mdot
.43016 .63764 Mdot
.48696 .62122 Mdot
.57046 .80364 Mdot
.47176 .27703 Mdot
.65983 .53131 Mdot
.32744 .39284 Mdot
.66573 .54669 Mdot
.42361 .27631 Mdot
.44718 .47259 Mdot
.40272 .62327 Mdot
.67957 .5766 Mdot
.67346 .55328 Mdot
.62984 .37332 Mdot
.64121 .34765 Mdot
.43233 .34418 Mdot
.42508 .61159 Mdot
.52712 .48604 Mdot
.69521 .56556 Mdot
.45475 .2655 Mdot
.34364 .3866 Mdot
.68419 .33121 Mdot
.41122 .65277 Mdot
.4331 .29959 Mdot
.51023 .55449 Mdot
.69035 .52731 Mdot
.43905 .32078 Mdot
.50652 .50355 Mdot
.35377 .40007 Mdot
.47324 .63363 Mdot
.44792 .2212 Mdot
.50213 .52697 Mdot
.40963 .62388 Mdot
.48753 .73817 Mdot
.41753 .50832 Mdot
.51369 .48341 Mdot
.43691 .27981 Mdot
.50634 .5148 Mdot
.66471 .51758 Mdot
.52506 .76056 Mdot
.47716 .2945 Mdot
.59602 .58761 Mdot
.36125 .56408 Mdot
.5071 .60284 Mdot
.66853 .52981 Mdot
.43188 .39314 Mdot
.77265 .50206 Mdot
.24192 .53959 Mdot
.43773 .65747 Mdot
.42294 .31194 Mdot
.34958 .38917 Mdot
.61875 .37247 Mdot
.65652 .37721 Mdot
.40548 .40162 Mdot
.4559 .31784 Mdot
.4596 .64081 Mdot
.68368 .56894 Mdot
.61452 .36038 Mdot
.57254 .62506 Mdot
.48109 .30874 Mdot
.42232 .29406 Mdot
.48063 .63804 Mdot
.34774 .38534 Mdot
.49069 .48252 Mdot
.47734 .28238 Mdot
.47731 .27329 Mdot
.74641 .62017 Mdot
.36016 .35913 Mdot
.48794 .61641 Mdot
.46719 .70756 Mdot
.45093 .67662 Mdot
.81861 .56973 Mdot
.50795 .50592 Mdot
.69817 .5259 Mdot
.43963 .63139 Mdot
.48596 .24298 Mdot
.46799 .28082 Mdot
.30425 .56694 Mdot
.57208 .33445 Mdot
.63465 .34219 Mdot
.43268 .31202 Mdot
.43493 .65224 Mdot
.66878 .37158 Mdot
.33403 .3651 Mdot
.48963 .61832 Mdot
.50627 .60496 Mdot
.65521 .51827 Mdot
.59212 .35371 Mdot
.52317 .70066 Mdot
.60923 .36976 Mdot
.6064 .3437 Mdot
.74929 .54196 Mdot
.45175 .62404 Mdot
.44908 .3115 Mdot
.41776 .33108 Mdot
.49003 .6572 Mdot
.50103 .35639 Mdot
.71171 .5402 Mdot
.4969 .30139 Mdot
.62037 .79343 Mdot
.4212 .6759 Mdot
.50065 .54011 Mdot
.51673 .46563 Mdot
.62712 .39342 Mdot
.44213 .62469 Mdot
.67427 .52772 Mdot
.4759 .27511 Mdot
.42244 .30591 Mdot
.38656 .61969 Mdot
.64118 .35291 Mdot
.37154 .38433 Mdot
.45329 .29309 Mdot
.30732 .5233 Mdot
.43651 .66148 Mdot
.5697 .37017 Mdot
.45328 .29605 Mdot
.19921 .6476 Mdot
.49277 .24474 Mdot
.66694 .56307 Mdot
.4759 .61781 Mdot
.68715 .50353 Mdot
.34373 .36056 Mdot
.48287 .26707 Mdot
.63488 .37413 Mdot
.50622 .54819 Mdot
.66067 .24635 Mdot
.42675 .29923 Mdot
.67523 .54066 Mdot
.4531 .63135 Mdot
.68399 .71383 Mdot
.4137 .62435 Mdot
.26538 .44619 Mdot
.31079 .3952 Mdot
.67754 .32571 Mdot
.64243 .36918 Mdot
.47482 .61348 Mdot
.34139 .39913 Mdot
.41387 .3311 Mdot
.44521 .29344 Mdot
.68924 .27166 Mdot
.50356 .51139 Mdot
.47837 .25579 Mdot
.41179 .61979 Mdot
.43404 .27379 Mdot
.66734 .62955 Mdot
.63726 .34655 Mdot
.45351 .67425 Mdot
.43252 .32885 Mdot
.77159 .51253 Mdot
.29498 .56675 Mdot
.4381 .65962 Mdot
.44534 .7081 Mdot
.63913 .36317 Mdot
.79686 .59064 Mdot
.46283 .27295 Mdot
.47682 .66374 Mdot
.57688 .35504 Mdot
.46441 .72014 Mdot
.55975 .40086 Mdot
.68664 .53777 Mdot
.41769 .32669 Mdot
.59904 .34413 Mdot
.51032 .58522 Mdot
.36914 .37934 Mdot
.45647 .33586 Mdot
.44332 .331 Mdot
.4636 .59317 Mdot
.49262 .63688 Mdot
.43958 .71075 Mdot
.69418 .51819 Mdot
.60399 .3514 Mdot
.48653 .60386 Mdot
.28309 .52749 Mdot
.49528 .61731 Mdot
.60078 .35155 Mdot
.85932 .43749 Mdot
.45913 .65882 Mdot
.41211 .65264 Mdot
.67607 .72617 Mdot
.7103 .51912 Mdot
.65012 .53595 Mdot
.28758 .54762 Mdot
.44024 .60015 Mdot
.40629 .52854 Mdot
.68241 .5372 Mdot
.67344 .54325 Mdot
.40737 .52712 Mdot
.46986 .59267 Mdot
.68167 .49842 Mdot
.61401 .35841 Mdot
.63604 .3429 Mdot
.67508 .56343 Mdot
.45785 .6797 Mdot
.59898 .37455 Mdot
.59123 .73764 Mdot
.4124 .31661 Mdot
.26391 .62193 Mdot
.67057 .55519 Mdot
.29301 .57111 Mdot
.6088 .35628 Mdot
.25455 .67918 Mdot
.26235 .65352 Mdot
.41135 .66819 Mdot
.44601 .62313 Mdot
.33127 .38034 Mdot
.50836 .54721 Mdot
.52478 .5043 Mdot
.62131 .3442 Mdot
.48423 .47654 Mdot
.69322 .54283 Mdot
.43359 .60215 Mdot
.24805 .52351 Mdot
.29658 .73011 Mdot
.37663 .70236 Mdot
.67916 .54745 Mdot
.6909 .55288 Mdot
.42353 .28877 Mdot
.41194 .29628 Mdot
.40241 .63421 Mdot
.64161 .35854 Mdot
.67518 .56626 Mdot
.59815 .35545 Mdot
.43933 .299 Mdot
.45584 .30474 Mdot
.52221 .49217 Mdot
.51465 .5789 Mdot
.43824 .30774 Mdot
.67796 .35362 Mdot
.28382 .52764 Mdot
.64287 .53314 Mdot
.83956 .54769 Mdot
.24637 .66711 Mdot
.71882 .70524 Mdot
.34843 .39074 Mdot
.45405 .72903 Mdot
.57872 .35151 Mdot
.47498 .61212 Mdot
.42784 .63291 Mdot
.51216 .51749 Mdot
.57733 .35077 Mdot
.33641 .36944 Mdot
.63585 .34414 Mdot
.36535 .3853 Mdot
.47101 .31338 Mdot
.45561 .64777 Mdot
.44049 .66783 Mdot
.62166 .37261 Mdot
.41734 .29467 Mdot
.42792 .32449 Mdot
.35789 .38457 Mdot
.23951 .62348 Mdot
.43405 .29663 Mdot
.67062 .55412 Mdot
.59661 .60761 Mdot
.51305 .50792 Mdot
.43361 .64724 Mdot
.23795 .58647 Mdot
.51561 .76116 Mdot
.48785 .65468 Mdot
.50632 .53117 Mdot
.86628 .48896 Mdot
.44294 .66349 Mdot
.64928 .22069 Mdot
.52402 .48786 Mdot
.70188 .51575 Mdot
.44182 .31534 Mdot
.50069 .52741 Mdot
.47854 .7154 Mdot
.38148 .30875 Mdot
.48529 .6614 Mdot
.70591 .55697 Mdot
.71666 .5338 Mdot
.44824 .47326 Mdot
.81879 .5737 Mdot
.3289 .39345 Mdot
.32999 .3697 Mdot
.47434 .28375 Mdot
.68179 .32222 Mdot
.4173 .68129 Mdot
.32582 .37508 Mdot
.71547 .4995 Mdot
.48443 .62416 Mdot
.42315 .50284 Mdot
.46584 .46719 Mdot
.66003 .52222 Mdot
.47019 .58582 Mdot
.47226 .28261 Mdot
.67738 .541 Mdot
.45572 .47093 Mdot
.4718 .65633 Mdot
.69062 .54064 Mdot
.60984 .3442 Mdot
.38347 .57715 Mdot
.66397 .55368 Mdot
.31741 .60461 Mdot
.62565 .3673 Mdot
.43057 .49354 Mdot
.21215 .41815 Mdot
.22394 .70361 Mdot
.63695 .34977 Mdot
.42199 .32072 Mdot
.42689 .30634 Mdot
.43672 .29092 Mdot
.67847 .51888 Mdot
.46063 .28331 Mdot
.70724 .53557 Mdot
.6186 .39649 Mdot
.27952 .63715 Mdot
.33761 .38453 Mdot
.45459 .38188 Mdot
.67266 .56176 Mdot
.82741 .56115 Mdot
.78962 .71716 Mdot
.49528 .62101 Mdot
.65218 .36252 Mdot
.31615 .38953 Mdot
.31291 .56372 Mdot
.32998 .37868 Mdot
.43242 .32058 Mdot
.2863 .63016 Mdot
.42821 .655 Mdot
.68768 .38964 Mdot
.35011 .38796 Mdot
.67197 .54365 Mdot
.43729 .59722 Mdot
.4054 .31127 Mdot
.34115 .36189 Mdot
.35522 .38045 Mdot
.43847 .64022 Mdot
.71189 .52311 Mdot
.43162 .32326 Mdot
.58832 .33944 Mdot
.38847 .37758 Mdot
.39568 .68103 Mdot
.44914 .65939 Mdot
.42414 .67148 Mdot
.28886 .56324 Mdot
.68468 .32363 Mdot
.62648 .3647 Mdot
.2538 .49501 Mdot
.45262 .27694 Mdot
.23968 .53637 Mdot
.77834 .49503 Mdot
.43425 .38705 Mdot
.50815 .5065 Mdot
.5096 .50055 Mdot
.44857 .64764 Mdot
.71164 .77731 Mdot
.42322 .56429 Mdot
.59295 .37236 Mdot
.51536 .5121 Mdot
.40902 .3069 Mdot
.6512 .55825 Mdot
.55827 .5413 Mdot
.3923 .64873 Mdot
.58674 .34018 Mdot
.44025 .29388 Mdot
.63105 .83136 Mdot
.32412 .38852 Mdot
.31269 .56066 Mdot
.42621 .61257 Mdot
.44442 .64658 Mdot
.62717 .35463 Mdot
.63031 .37685 Mdot
.74457 .62219 Mdot
.42324 .43811 Mdot
.7124 .33993 Mdot
.64623 .33387 Mdot
.62774 .83452 Mdot
.51928 .46929 Mdot
.69946 .54564 Mdot
.52251 .51618 Mdot
.63964 .37623 Mdot
.43597 .63285 Mdot
.7103 .51996 Mdot
.51444 .53499 Mdot
.72804 .5387 Mdot
.41314 .5141 Mdot
.30138 .52335 Mdot
.45228 .61932 Mdot
.70935 .51062 Mdot
.68252 .54087 Mdot
.63142 .55494 Mdot
.52001 .50134 Mdot
.41851 .63309 Mdot
.47485 .668 Mdot
.41793 .6641 Mdot
.71815 .627 Mdot
.44828 .65181 Mdot
.77943 .49811 Mdot
.29456 .54158 Mdot
.38632 .19758 Mdot
.43464 .66661 Mdot
.61284 .34013 Mdot
.45773 .63809 Mdot
.34332 .39948 Mdot
.46971 .64524 Mdot
.40258 .52497 Mdot
.61818 .35929 Mdot
.65151 .76699 Mdot
.38675 .34018 Mdot
.45246 .65797 Mdot
.36786 .36692 Mdot
.80718 .44777 Mdot
.25496 .49805 Mdot
.7473 .61795 Mdot
.66682 .55599 Mdot
.48664 .28902 Mdot
.64007 .37918 Mdot
.46105 .29667 Mdot
.40132 .60783 Mdot
.52673 .4999 Mdot
.17651 .41189 Mdot
.26509 .54198 Mdot
.43836 .63218 Mdot
.51701 .56341 Mdot
.65591 .54014 Mdot
.46979 .28266 Mdot
.75104 .66787 Mdot
.46667 .66703 Mdot
.3391 .40559 Mdot
.32112 .39754 Mdot
.32565 .34719 Mdot
.73134 .5849 Mdot
.69 .62694 Mdot
.62659 .35626 Mdot
.42513 .29747 Mdot
.31327 .38802 Mdot
.66012 .49655 Mdot
.64618 .37054 Mdot
.6256 .39304 Mdot
.59168 .3513 Mdot
.42419 .66179 Mdot
.51785 .49357 Mdot
.7507 .57693 Mdot
.50387 .51483 Mdot
.44463 .68188 Mdot
.44298 .3307 Mdot
.50618 .50689 Mdot
.33873 .37961 Mdot
.60299 .34326 Mdot
.45394 .30984 Mdot
.44741 .63735 Mdot
.68212 .53356 Mdot
.37618 .4575 Mdot
.46517 .23528 Mdot
.4178 .5075 Mdot
.41792 .50735 Mdot
.64063 .5603 Mdot
.50612 .46579 Mdot
.57349 .31322 Mdot
.54769 .75701 Mdot
.39244 .3848 Mdot
.41581 .68892 Mdot
.5079 .34504 Mdot
.47804 .30949 Mdot
.44643 .30354 Mdot
.4245 .65511 Mdot
.44595 .26978 Mdot
.42414 .6078 Mdot
.43736 .27905 Mdot
.79264 .51881 Mdot
.38877 .62681 Mdot
.44938 .2948 Mdot
.51651 .53715 Mdot
.40827 .62468 Mdot
.66102 .53208 Mdot
.48454 .28978 Mdot
.41165 .66858 Mdot
.28027 .23891 Mdot
.62863 .37336 Mdot
.51853 .50128 Mdot
.34966 .53437 Mdot
.61079 .3503 Mdot
.70659 .55047 Mdot
.43668 .60622 Mdot
.32086 .3796 Mdot
.69576 .55251 Mdot
.36419 .34154 Mdot
.35089 .38315 Mdot
.32265 .54586 Mdot
.68923 .56049 Mdot
.51107 .50835 Mdot
.34006 .40427 Mdot
.49108 .65438 Mdot
.44665 .30065 Mdot
.47487 .23799 Mdot
.50186 .53398 Mdot
.42599 .65178 Mdot
.4067 .31114 Mdot
.6275 .34076 Mdot
.46516 .63587 Mdot
.42452 .30691 Mdot
.51765 .52151 Mdot
.40737 .6386 Mdot
.43184 .60046 Mdot
.78805 .59494 Mdot
.45236 .43878 Mdot
.33811 .38243 Mdot
.6407 .52463 Mdot
.42851 .68141 Mdot
.34588 .3969 Mdot
.47733 .244 Mdot
.5013 .58917 Mdot
.68898 .57089 Mdot
.58266 .73929 Mdot
.42592 .27921 Mdot
.64439 .35733 Mdot
.43194 .33832 Mdot
.3416 .35971 Mdot
.82666 .68173 Mdot
.52477 .50101 Mdot
.48169 .59014 Mdot
.4474 .67348 Mdot
.48599 .27434 Mdot
.68547 .54225 Mdot
.71815 .34795 Mdot
.47393 .63219 Mdot
.49856 .56828 Mdot
.43581 .64397 Mdot
.42458 .23677 Mdot
.68766 .51635 Mdot
.43403 .64546 Mdot
.44028 .70221 Mdot
.43731 .67781 Mdot
.36257 .36705 Mdot
.18746 .42095 Mdot
.5012 .6163 Mdot
.85738 .36975 Mdot
.51733 .52702 Mdot
.44572 .28976 Mdot
.31881 .60245 Mdot
.35114 .52819 Mdot
.32676 .2326 Mdot
.70919 .54555 Mdot
.62281 .54495 Mdot
.45537 .30417 Mdot
.41633 .39388 Mdot
.49493 .48235 Mdot
.44211 .59701 Mdot
.43113 .61053 Mdot
.43257 .32055 Mdot
.45731 .26478 Mdot
.52427 .51584 Mdot
.51135 .60886 Mdot
.4948 .58516 Mdot
.43989 .33538 Mdot
.45073 .65144 Mdot
.5045 .76063 Mdot
.6546 .35937 Mdot
.66288 .56055 Mdot
.61639 .37296 Mdot
.65277 .34898 Mdot
.73167 .69607 Mdot
.28957 .55565 Mdot
.58853 .34399 Mdot
.57946 .36562 Mdot
.43405 .39505 Mdot
.6985 .69687 Mdot
.36523 .36972 Mdot
.42253 .56309 Mdot
.44198 .28319 Mdot
.41915 .63151 Mdot
.68533 .51613 Mdot
.31118 .4347 Mdot
.73379 .3502 Mdot
.37767 .74653 Mdot
.48634 .61559 Mdot
.45669 .27856 Mdot
.50152 .53587 Mdot
.50678 .59134 Mdot
.23826 .54192 Mdot
.44297 .65307 Mdot
.42279 .28071 Mdot
.70186 .6921 Mdot
.58789 .41543 Mdot
.6623 .37916 Mdot
.65854 .58636 Mdot
.45846 .63799 Mdot
.6874 .51999 Mdot
.62206 .32997 Mdot
.3409 .39675 Mdot
.32795 .3854 Mdot
.45329 .65755 Mdot
.37475 .55229 Mdot
.39286 .37257 Mdot
.4326 .59922 Mdot
.47297 .59314 Mdot
.50686 .51623 Mdot
.48076 .59333 Mdot
.4714 .67421 Mdot
.48343 .60576 Mdot
.49169 .64444 Mdot
.64477 .37126 Mdot
.73074 .68381 Mdot
.50734 .59782 Mdot
.4023 .61418 Mdot
.63246 .33302 Mdot
.40327 .60856 Mdot
.63157 .34905 Mdot
.68237 .30744 Mdot
.58454 .35047 Mdot
.33011 .38662 Mdot
.40688 .30041 Mdot
.77987 .60262 Mdot
.67725 .56655 Mdot
.63591 .34006 Mdot
.36235 .39516 Mdot
.62781 .3441 Mdot
.43287 .28568 Mdot
.61626 .42181 Mdot
.68901 .58883 Mdot
.3132 .52461 Mdot
.69901 .70755 Mdot
.55895 .36239 Mdot
.43386 .27599 Mdot
.67743 .56501 Mdot
.68063 .33847 Mdot
.47326 .61116 Mdot
.32418 .3904 Mdot
.44851 .64665 Mdot
.60459 .3433 Mdot
.44698 .28116 Mdot
.76814 .60631 Mdot
.33694 .38209 Mdot
.8491 .53273 Mdot
.45174 .33309 Mdot
.45711 .66516 Mdot
.63411 .33287 Mdot
.67292 .35477 Mdot
.63482 .37171 Mdot
.27207 .63676 Mdot
.51207 .46499 Mdot
.35222 .44031 Mdot
.68994 .55631 Mdot
.52479 .47813 Mdot
.30657 .77429 Mdot
.77106 .43678 Mdot
.68569 .52887 Mdot
.47356 .24919 Mdot
.43876 .66242 Mdot
.48882 .61137 Mdot
.51387 .57148 Mdot
.72237 .52897 Mdot
.48687 .62153 Mdot
.51736 .49859 Mdot
.27952 .54815 Mdot
.67009 .59145 Mdot
.46729 .32867 Mdot
.41892 .61342 Mdot
.63604 .33158 Mdot
.64259 .34339 Mdot
.52145 .48438 Mdot
.59947 .36503 Mdot
.41075 .60966 Mdot
.68025 .56163 Mdot
.4603 .46897 Mdot
.33735 .36172 Mdot
.79185 .48155 Mdot
.35521 .34926 Mdot
.38208 .37192 Mdot
.41864 .67519 Mdot
.45305 .30776 Mdot
.64645 .23197 Mdot
.47921 .61381 Mdot
.67977 .53833 Mdot
.45399 .67011 Mdot
.48871 .60694 Mdot
.41879 .5999 Mdot
.42551 .29727 Mdot
.29327 .56788 Mdot
.45146 .6507 Mdot
.60428 .33191 Mdot
.40146 .53184 Mdot
.38953 .6423 Mdot
.49273 .44705 Mdot
.40695 .5207 Mdot
.57533 .37974 Mdot
.64789 .52668 Mdot
.44751 .31204 Mdot
.69418 .54554 Mdot
.72722 .55456 Mdot
.7066 .54993 Mdot
.74396 .57387 Mdot
.53911 .75927 Mdot
.64431 .21438 Mdot
.673 .62927 Mdot
.70047 .70973 Mdot
.72296 .56288 Mdot
.52136 .19008 Mdot
.68089 .52719 Mdot
.70742 .54905 Mdot
.79769 .36732 Mdot
.7124 .53 Mdot
.42627 .64249 Mdot
.43349 .67113 Mdot
.589 .80095 Mdot
.37464 .40495 Mdot
.40982 .63167 Mdot
.4903 .64878 Mdot
.31597 .39356 Mdot
.77101 .53149 Mdot
.50571 .53989 Mdot
.31649 .56099 Mdot
.50631 .49895 Mdot
.43925 .63997 Mdot
.46382 .62559 Mdot
.38399 .64015 Mdot
.32143 .75165 Mdot
.3873 .4201 Mdot
.7175 .53691 Mdot
.43856 .6979 Mdot
.55225 .36033 Mdot
.45944 .61567 Mdot
.46648 .65858 Mdot
.42856 .5954 Mdot
.4492 .31143 Mdot
.65842 .56719 Mdot
.51689 .5555 Mdot
.79351 .46145 Mdot
.43774 .61486 Mdot
.32172 .36025 Mdot
.33551 .40981 Mdot
.43375 .65188 Mdot
.71371 .53778 Mdot
.4883 .61319 Mdot
.64884 .54651 Mdot
.69328 .558 Mdot
.49973 .57539 Mdot
.75756 .55958 Mdot
.65328 .56084 Mdot
.44322 .59698 Mdot
.41994 .29037 Mdot
.79851 .49835 Mdot
.42775 .65247 Mdot
.34468 .3788 Mdot
.44639 .6259 Mdot
.3631 .36589 Mdot
.50339 .60779 Mdot
.50475 .51566 Mdot
.45218 .76919 Mdot
.47498 .30103 Mdot
.37367 .35926 Mdot
.44045 .27115 Mdot
.41962 .68445 Mdot
.72959 .51586 Mdot
.5997 .42004 Mdot
.40505 .38721 Mdot
.50727 .51444 Mdot
.26527 .46789 Mdot
.42407 .51677 Mdot
.5831 .35776 Mdot
.65982 .52991 Mdot
.72308 .67872 Mdot
.48952 .44733 Mdot
.46158 .33397 Mdot
.41304 .31993 Mdot
.55268 .39302 Mdot
.81621 .39644 Mdot
.43396 .66599 Mdot
.50383 .45467 Mdot
.53765 .70926 Mdot
.50888 .54708 Mdot
.521 .53077 Mdot
.44332 .33159 Mdot
.40968 .63036 Mdot
.26798 .56113 Mdot
.43015 .304 Mdot
.34679 .36536 Mdot
.69756 .52489 Mdot
.35718 .39226 Mdot
.71308 .39511 Mdot
.75039 .62023 Mdot
.43606 .30628 Mdot
.49484 .6353 Mdot
.4124 .63872 Mdot
.70336 .51533 Mdot
.57246 .62376 Mdot
.65588 .55494 Mdot
.32165 .37321 Mdot
.47852 .29378 Mdot
.22423 .30841 Mdot
.45428 .63045 Mdot
.6737 .55167 Mdot
.3879 .33992 Mdot
.43734 .62045 Mdot
.64166 .35224 Mdot
.48633 .62268 Mdot
.66844 .54784 Mdot
.48547 .59365 Mdot
.69087 .55647 Mdot
.41834 .29909 Mdot
.44833 .66282 Mdot
.46752 .63325 Mdot
.25569 .48888 Mdot
.33663 .36986 Mdot
.65311 .55788 Mdot
.2774 .5735 Mdot
.45088 .67667 Mdot
.23636 .55972 Mdot
.45369 .65115 Mdot
.69333 .70738 Mdot
.45802 .70904 Mdot
.51539 .49909 Mdot
.45262 .67143 Mdot
.42951 .6539 Mdot
.57202 .62044 Mdot
.66155 .63011 Mdot
.72076 .62683 Mdot
.64444 .35147 Mdot
.66732 .52707 Mdot
.42882 .30883 Mdot
.4842 .28541 Mdot
.46167 .28694 Mdot
.30796 .3813 Mdot
.48149 .66822 Mdot
.41969 .64511 Mdot
.59403 .37484 Mdot
.32294 .38048 Mdot
.68025 .55125 Mdot
.33568 .38856 Mdot
.29582 .55857 Mdot
.34489 .37638 Mdot
.52504 .50724 Mdot
.51127 .2636 Mdot
.51176 .75997 Mdot
.35437 .37163 Mdot
.6671 .56237 Mdot
.38592 .5479 Mdot
.49681 .55568 Mdot
.81096 .57844 Mdot
.32907 .40611 Mdot
.47251 .24658 Mdot
.40606 .63901 Mdot
.3118 .60536 Mdot
.62807 .34886 Mdot
.3575 .39264 Mdot
.59084 .35277 Mdot
.48719 .61263 Mdot
.61793 .55392 Mdot
.67103 .53707 Mdot
.65561 .3572 Mdot
.46164 .66625 Mdot
.35649 .39333 Mdot
.44036 .30469 Mdot
.69776 .69624 Mdot
.63572 .39133 Mdot
.39169 .44599 Mdot
.24141 .53786 Mdot
.47221 .28046 Mdot
.67342 .70482 Mdot
.58665 .35283 Mdot
.43701 .69755 Mdot
.3745 .63878 Mdot
.4421 .6867 Mdot
.42989 .32467 Mdot
.44673 .30407 Mdot
.56129 .31221 Mdot
.46864 .63138 Mdot
.48664 .59081 Mdot
.64048 .533 Mdot
.47778 .28621 Mdot
.70576 .5508 Mdot
.70499 .50735 Mdot
.42206 .32003 Mdot
.65134 .54853 Mdot
.35232 .38297 Mdot
.26608 .59734 Mdot
.58659 .3516 Mdot
.6436 .36596 Mdot
.43678 .30791 Mdot
.46545 .3115 Mdot
.45391 .30731 Mdot
.47625 .6518 Mdot
.6964 .55768 Mdot
.46963 .61382 Mdot
.45733 .63563 Mdot
.49407 .546 Mdot
.67207 .50413 Mdot
.47583 .62212 Mdot
.46818 .47029 Mdot
.31824 .40617 Mdot
.4503 .29076 Mdot
.60215 .35661 Mdot
.36742 .45901 Mdot
.5952 .33538 Mdot
.44007 .679 Mdot
.7881 .52672 Mdot
.67091 .5251 Mdot
.33052 .37926 Mdot
.40397 .52291 Mdot
.33394 .38158 Mdot
.6548 .35829 Mdot
.63482 .54936 Mdot
.3187 .54426 Mdot
.46827 .63679 Mdot
.28633 .56198 Mdot
.22399 .44127 Mdot
.77256 .48843 Mdot
.60549 .34968 Mdot
.4919 .61685 Mdot
.51526 .49327 Mdot
.55 .75774 Mdot
.42178 .64939 Mdot
.39406 .64662 Mdot
.3681 .53866 Mdot
.43664 .6762 Mdot
.70407 .565 Mdot
.43152 .49689 Mdot
.50086 .632 Mdot
.43996 .68985 Mdot
.69261 .28025 Mdot
.40866 .63839 Mdot
.46481 .64225 Mdot
.42353 .63363 Mdot
.48149 .62031 Mdot
.68498 .5037 Mdot
.43963 .47877 Mdot
.62228 .33072 Mdot
.2657 .59732 Mdot
.59134 .34606 Mdot
.43435 .31444 Mdot
.41075 .44169 Mdot
.64906 .53098 Mdot
.33418 .38108 Mdot
.51971 .44494 Mdot
.29315 .63285 Mdot
.4227 .28943 Mdot
.26333 .4607 Mdot
.37047 .38477 Mdot
.51739 .54263 Mdot
.34536 .35894 Mdot
.43502 .33009 Mdot
.63992 .3515 Mdot
.45498 .66283 Mdot
.69777 .56274 Mdot
.6627 .55304 Mdot
.4278 .68396 Mdot
.80384 .47143 Mdot
.64557 .35856 Mdot
.49315 .36186 Mdot
.42468 .65983 Mdot
.45374 .67417 Mdot
.64905 .53944 Mdot
.46557 .2805 Mdot
.42448 .51529 Mdot
.36317 .37387 Mdot
.45258 .6147 Mdot
.49777 .63446 Mdot
.29423 .55886 Mdot
.64348 .34731 Mdot
.51958 .51103 Mdot
.41412 .63155 Mdot
.30168 .55277 Mdot
.48757 .62709 Mdot
.40856 .68063 Mdot
.41816 .28935 Mdot
.49926 .57134 Mdot
.46816 .62487 Mdot
.66063 .58749 Mdot
.58694 .35511 Mdot
.68637 .53962 Mdot
.65914 .57931 Mdot
.50556 .51456 Mdot
.62865 .37243 Mdot
.47981 .62846 Mdot
.64231 .38166 Mdot
.48837 .60922 Mdot
.45211 .63905 Mdot
.60703 .34737 Mdot
.70565 .54555 Mdot
.71136 .34667 Mdot
.73106 .68262 Mdot
.48466 .60145 Mdot
.44237 .62409 Mdot
.37459 .4049 Mdot
.30307 .42559 Mdot
.47136 .63305 Mdot
.67297 .56473 Mdot
.44102 .62057 Mdot
.61714 .37933 Mdot
.33138 .39399 Mdot
.67789 .53478 Mdot
.46312 .27531 Mdot
.41873 .30055 Mdot
.40211 .33605 Mdot
.52527 .50754 Mdot
.47799 .59108 Mdot
.64086 .52452 Mdot
.67779 .50223 Mdot
.28965 .59567 Mdot
.44655 .29015 Mdot
.34208 .39331 Mdot
.41345 .61565 Mdot
.52346 .5335 Mdot
.6413 .33878 Mdot
.8545 .3593 Mdot
.31627 .54523 Mdot
.31809 .40828 Mdot
.42305 .4448 Mdot
.50871 .52174 Mdot
.412 .64859 Mdot
.3484 .39709 Mdot
.42147 .31711 Mdot
.48929 .6119 Mdot
.46157 .70488 Mdot
.46861 .24427 Mdot
.46091 .30918 Mdot
.64398 .38139 Mdot
.44688 .27601 Mdot
.37043 .37667 Mdot
.52468 .50319 Mdot
.66155 .53817 Mdot
.43778 .65397 Mdot
.50849 .58982 Mdot
.44142 .2866 Mdot
.52916 .4902 Mdot
.43424 .66927 Mdot
.66952 .52295 Mdot
.4552 .28451 Mdot
.43512 .63806 Mdot
.55976 .74799 Mdot
.78059 .59992 Mdot
.44657 .2801 Mdot
.44209 .60767 Mdot
.56108 .55709 Mdot
.45756 .31121 Mdot
.43605 .32922 Mdot
.49476 .62158 Mdot
.35364 .39737 Mdot
.45508 .61938 Mdot
.64044 .35833 Mdot
.28709 .56771 Mdot
.62354 .37289 Mdot
.23696 .54253 Mdot
.48108 .6558 Mdot
.37297 .67621 Mdot
.73017 .53198 Mdot
.37435 .35552 Mdot
.24403 .65776 Mdot
.42436 .67805 Mdot
.70997 .4896 Mdot
.29165 .5706 Mdot
.32718 .52991 Mdot
.6495 .48961 Mdot
.36604 .38014 Mdot
.62244 .34462 Mdot
.4579 .6509 Mdot
.70067 .33993 Mdot
.36375 .38022 Mdot
.23701 .54461 Mdot
.45489 .60491 Mdot
.67692 .54499 Mdot
.42886 .66218 Mdot
.66325 .5395 Mdot
.42808 .62331 Mdot
.78913 .59302 Mdot
.39272 .37538 Mdot
.27256 .63705 Mdot
.51506 .54433 Mdot
.67275 .35516 Mdot
.6993 .70784 Mdot
.34675 .38769 Mdot
.48815 .59622 Mdot
.51138 .52309 Mdot
.63552 .34383 Mdot
.61976 .43326 Mdot
.45659 .3031 Mdot
.60222 .33315 Mdot
.70209 .53973 Mdot
.40622 .3208 Mdot
.52772 .48512 Mdot
.40802 .73251 Mdot
.35401 .39539 Mdot
.62985 .37232 Mdot
.43249 .65415 Mdot
.44402 .68523 Mdot
.42607 .23534 Mdot
.18399 .42858 Mdot
.70318 .50492 Mdot
.85909 .5144 Mdot
.63504 .5461 Mdot
.33251 .3695 Mdot
.41421 .29628 Mdot
.43486 .6315 Mdot
.42146 .61574 Mdot
.46274 .30708 Mdot
.69607 .51311 Mdot
.3781 .36634 Mdot
.34689 .43927 Mdot
.59468 .37297 Mdot
.19625 .44675 Mdot
.67468 .5335 Mdot
.19644 .44486 Mdot
.46024 .35924 Mdot
.77231 .57047 Mdot
.24051 .63498 Mdot
.61201 .35415 Mdot
.19577 .44659 Mdot
.67464 .54722 Mdot
.42103 .6636 Mdot
.51111 .51142 Mdot
.52708 .49445 Mdot
.68661 .52191 Mdot
.43568 .32034 Mdot
.36933 .38397 Mdot
.42966 .66104 Mdot
.44589 .72491 Mdot
.57265 .6251 Mdot
.47259 .31061 Mdot
.5086 .56183 Mdot
.60976 .36095 Mdot
.43889 .62162 Mdot
.31462 .38951 Mdot
.61351 .35463 Mdot
.50546 .50476 Mdot
.28596 .62846 Mdot
.4369 .60635 Mdot
.39003 .53762 Mdot
.62946 .35159 Mdot
.29944 .42564 Mdot
.46703 .631 Mdot
.58674 .35286 Mdot
.50526 .588 Mdot
.54287 .3357 Mdot
.45296 .48863 Mdot
.7704 .4369 Mdot
.43081 .3408 Mdot
.43677 .27966 Mdot
.27315 .25207 Mdot
.32959 .24074 Mdot
.60166 .33818 Mdot
.50333 .53693 Mdot
.18528 .41897 Mdot
.59085 .35881 Mdot
.47554 .63384 Mdot
.44684 .65967 Mdot
.70231 .69167 Mdot
.50225 .551 Mdot
.51836 .52495 Mdot
.63534 .5842 Mdot
.41856 .60289 Mdot
.5079 .56012 Mdot
.46338 .63852 Mdot
.71741 .53277 Mdot
.61243 .36045 Mdot
.45188 .83931 Mdot
.6489 .37126 Mdot
.37698 .68443 Mdot
.44272 .2828 Mdot
.41983 .33775 Mdot
.43504 .65135 Mdot
.57221 .52627 Mdot
.63451 .83329 Mdot
.44948 .6583 Mdot
.40315 .52381 Mdot
.24084 .53442 Mdot
.4696 .68132 Mdot
.67566 .57316 Mdot
.50592 .58735 Mdot
.65857 .50798 Mdot
.61378 .35002 Mdot
.36572 .38038 Mdot
.37745 .35453 Mdot
.62334 .34568 Mdot
.41999 .61885 Mdot
.35983 .35036 Mdot
.44208 .64573 Mdot
.41522 .65017 Mdot
.30374 .55659 Mdot
.31511 .384 Mdot
.44641 .31559 Mdot
.32974 .38509 Mdot
.71065 .54215 Mdot
.86226 .45432 Mdot
.34086 .38935 Mdot
.69878 .69656 Mdot
.28018 .57201 Mdot
.19065 .41801 Mdot
.65981 .5491 Mdot
.33969 .36098 Mdot
.62023 .34242 Mdot
.3342 .5525 Mdot
.66281 .73331 Mdot
.59351 .33653 Mdot
.41656 .64012 Mdot
.69021 .50342 Mdot
.63732 .55317 Mdot
.6049 .3293 Mdot
.65961 .53599 Mdot
.47799 .67885 Mdot
.45728 .59651 Mdot
.61744 .33007 Mdot
.28509 .72367 Mdot
.6433 .36866 Mdot
.74159 .68484 Mdot
.47782 .59207 Mdot
.67913 .53676 Mdot
.69171 .71213 Mdot
.64784 .57536 Mdot
.52323 .49331 Mdot
.46683 .64824 Mdot
.34073 .39183 Mdot
.28044 .58997 Mdot
.45719 .27706 Mdot
.77201 .51212 Mdot
.66896 .55608 Mdot
.60139 .32892 Mdot
.66032 .53576 Mdot
.65676 .53258 Mdot
.65556 .35273 Mdot
.67149 .52592 Mdot
.43549 .61474 Mdot
.79444 .59428 Mdot
.6548 .54516 Mdot
.62342 .35631 Mdot
.32391 .37155 Mdot
.66743 .56328 Mdot
.4838 .37296 Mdot
.41388 .61722 Mdot
.47798 .31314 Mdot
.30609 .41736 Mdot
.70353 .50854 Mdot
.3468 .38882 Mdot
.44536 .28606 Mdot
.3544 .40111 Mdot
.66204 .30517 Mdot
.67451 .33631 Mdot
.484 .71521 Mdot
.53937 .33561 Mdot
.71249 .53227 Mdot
.40568 .32433 Mdot
.43799 .6102 Mdot
.42116 .6577 Mdot
.30972 .39108 Mdot
.6776 .57757 Mdot
.80646 .4615 Mdot
.50569 .54404 Mdot
.79186 .48035 Mdot
.64482 .35129 Mdot
.47253 .3742 Mdot
.31811 .54187 Mdot
.61473 .4058 Mdot
.50279 .62918 Mdot
.5094 .52108 Mdot
.43498 .64396 Mdot
.25427 .49933 Mdot
.36974 .37662 Mdot
.51662 .2028 Mdot
.46114 .6758 Mdot
.46595 .30382 Mdot
.42813 .62624 Mdot
.49088 .47419 Mdot
.44784 .68856 Mdot
.31412 .40385 Mdot
.5765 .35428 Mdot
.67662 .56645 Mdot
.35202 .36065 Mdot
.4175 .30281 Mdot
.2841 .65877 Mdot
.47312 .62539 Mdot
.4087 .61413 Mdot
.44683 .31992 Mdot
.70436 .55556 Mdot
.44018 .31104 Mdot
.58698 .35111 Mdot
.34006 .38745 Mdot
.48458 .63054 Mdot
.50352 .56287 Mdot
.48564 .27302 Mdot
.63207 .33679 Mdot
.40778 .30623 Mdot
.6464 .37779 Mdot
.50893 .51557 Mdot
.43654 .69287 Mdot
.41144 .29105 Mdot
.50366 .6234 Mdot
.66402 .67454 Mdot
.29176 .62733 Mdot
.57433 .59883 Mdot
.43625 .32239 Mdot
.33477 .22676 Mdot
.61688 .35498 Mdot
.62142 .37726 Mdot
.74715 .68099 Mdot
.699 .78786 Mdot
.40698 .5279 Mdot
.79881 .43444 Mdot
.58676 .35097 Mdot
.63341 .35539 Mdot
.44211 .31291 Mdot
.70889 .53794 Mdot
.72759 .5298 Mdot
.40916 .31738 Mdot
.23936 .59264 Mdot
.67992 .55128 Mdot
.60901 .79746 Mdot
.47263 .31553 Mdot
.41232 .60192 Mdot
.77464 .60192 Mdot
.31995 .40595 Mdot
.24738 .53032 Mdot
.61357 .42326 Mdot
.42943 .63706 Mdot
.65414 .22488 Mdot
.45631 .30117 Mdot
.5263 .51878 Mdot
.59199 .31539 Mdot
.46457 .6673 Mdot
.42343 .62897 Mdot
.44098 .61741 Mdot
.30066 .39607 Mdot
.64125 .63889 Mdot
.43166 .63451 Mdot
.28262 .63326 Mdot
.39281 .61699 Mdot
.45263 .22396 Mdot
.33001 .38543 Mdot
.26367 .44884 Mdot
.44476 .25846 Mdot
.79214 .45375 Mdot
.40172 .66039 Mdot
.59932 .37093 Mdot
.47843 .46791 Mdot
.60536 .34662 Mdot
.5735 .37345 Mdot
.18476 .48317 Mdot
.70404 .5636 Mdot
.46585 .66931 Mdot
.46289 .3218 Mdot
.72762 .52568 Mdot
.47444 .46733 Mdot
.86634 .46584 Mdot
.58932 .33147 Mdot
.84302 .66676 Mdot
.60694 .37145 Mdot
.52603 .51273 Mdot
.70059 .5355 Mdot
.5896 .56357 Mdot
.28708 .56051 Mdot
.70593 .54953 Mdot
.37489 .23346 Mdot
.66402 .50426 Mdot
.20499 .5713 Mdot
.69525 .58639 Mdot
.62303 .36112 Mdot
.60469 .32891 Mdot
.4732 .69339 Mdot
.45747 .61938 Mdot
.27429 .55224 Mdot
.50611 .54626 Mdot
.43588 .60481 Mdot
.42983 .30386 Mdot
.53745 .33051 Mdot
.69494 .33176 Mdot
.67492 .52569 Mdot
.62548 .33471 Mdot
.42587 .62795 Mdot
.4855 .60098 Mdot
.43967 .67214 Mdot
.41529 .39655 Mdot
.59972 .80216 Mdot
.45471 .64071 Mdot
.41933 .68607 Mdot
.41955 .29326 Mdot
.42467 .23557 Mdot
.82589 .43135 Mdot
.18965 .46419 Mdot
.4091 .65644 Mdot
.3302 .37328 Mdot
.31279 .38112 Mdot
.45952 .70155 Mdot
.58785 .55637 Mdot
.28813 .36925 Mdot
.43193 .65399 Mdot
.28901 .64994 Mdot
.48798 .29494 Mdot
.52016 .48604 Mdot
.44113 .28718 Mdot
.73117 .54658 Mdot
.512 .49742 Mdot
.42399 .31106 Mdot
.26359 .626 Mdot
.50278 .52685 Mdot
.54744 .33135 Mdot
.33347 .36272 Mdot
.46528 .63501 Mdot
.73409 .66115 Mdot
.47785 .28538 Mdot
.6372 .36097 Mdot
.69514 .53609 Mdot
.64423 .35264 Mdot
.47875 .24005 Mdot
.23702 .57276 Mdot
.52137 .49721 Mdot
.60166 .37215 Mdot
.3866 .54173 Mdot
.3271 .3771 Mdot
.59878 .36595 Mdot
.373 .64936 Mdot
.3866 .63104 Mdot
.61209 .82797 Mdot
.4094 .61663 Mdot
.5621 .31275 Mdot
.63052 .37371 Mdot
.51045 .49519 Mdot
.43949 .65377 Mdot
.45496 .33269 Mdot
.48218 .69527 Mdot
.44284 .64435 Mdot
.4679 .27538 Mdot
.44544 .65924 Mdot
.33064 .39755 Mdot
.63236 .54296 Mdot
.29552 .57301 Mdot
.40375 .4376 Mdot
.36691 .37373 Mdot
.30128 .62334 Mdot
.47144 .63478 Mdot
.35002 .23841 Mdot
.68021 .5453 Mdot
.43871 .67892 Mdot
.2234 .51846 Mdot
.70294 .52609 Mdot
.69372 .54824 Mdot
.45263 .59336 Mdot
.62995 .37994 Mdot
.44533 .31816 Mdot
.32654 .38042 Mdot
.64249 .39067 Mdot
.43492 .63631 Mdot
.49132 .6168 Mdot
.36523 .37073 Mdot
.63431 .36585 Mdot
.48347 .63048 Mdot
.70329 .45181 Mdot
.26945 .60332 Mdot
.65381 .35812 Mdot
.38983 .64346 Mdot
.64408 .78331 Mdot
.66909 .51735 Mdot
.652 .22281 Mdot
.39255 .37688 Mdot
.41386 .3132 Mdot
.50846 .56702 Mdot
.85847 .3815 Mdot
.32293 .37171 Mdot
.78119 .47875 Mdot
.42862 .66588 Mdot
.43974 .62886 Mdot
.71548 .53309 Mdot
.46948 .61571 Mdot
.66895 .52575 Mdot
.45246 .38921 Mdot
.72624 .76657 Mdot
.65994 .54529 Mdot
.66662 .54288 Mdot
.39358 .57878 Mdot
.39688 .35603 Mdot
.69618 .52548 Mdot
.46862 .62227 Mdot
.3844 .20622 Mdot
.40699 .69892 Mdot
.37881 .37462 Mdot
.2994 .40262 Mdot
.67348 .57104 Mdot
.66279 .73811 Mdot
.37738 .6347 Mdot
.6086 .78214 Mdot
.28544 .37179 Mdot
.59798 .33994 Mdot
.49655 .60918 Mdot
.50715 .53489 Mdot
.45376 .2887 Mdot
.50205 .58464 Mdot
.46562 .63041 Mdot
.69337 .5682 Mdot
.33314 .40812 Mdot
.59271 .35878 Mdot
.50742 .61645 Mdot
.48547 .31068 Mdot
.35918 .36978 Mdot
.65122 .54125 Mdot
.71493 .70639 Mdot
.34524 .35182 Mdot
.51715 .56215 Mdot
.41336 .65666 Mdot
.50115 .5943 Mdot
.52369 .53613 Mdot
.6227 .34686 Mdot
.41485 .32652 Mdot
.51592 .56336 Mdot
.32469 .56795 Mdot
.25864 .59849 Mdot
.41659 .66864 Mdot
.67045 .56418 Mdot
.63305 .33993 Mdot
.52331 .50645 Mdot
.18736 .4143 Mdot
.40443 .63714 Mdot
.60931 .79794 Mdot
.37165 .44532 Mdot
.50635 .52867 Mdot
.72695 .52172 Mdot
.33041 .38101 Mdot
.47862 .59275 Mdot
.27845 .6339 Mdot
.44125 .6044 Mdot
.43973 .69859 Mdot
.42423 .32217 Mdot
.5955 .34936 Mdot
.48127 .71634 Mdot
.45217 .29213 Mdot
.69407 .54646 Mdot
.57568 .79224 Mdot
.71488 .51569 Mdot
.70609 .50735 Mdot
.76094 .5518 Mdot
.64242 .36375 Mdot
.85833 .37753 Mdot
.30195 .42298 Mdot
.44554 .66702 Mdot
.5813 .34808 Mdot
.69168 .52669 Mdot
.47615 .62519 Mdot
.67044 .52519 Mdot
.66411 .57004 Mdot
.42472 .60448 Mdot
.43533 .60031 Mdot
.27761 .63831 Mdot
.64125 .77919 Mdot
.32507 .39072 Mdot
.69991 .51484 Mdot
.64939 .76483 Mdot
.43677 .63206 Mdot
.46308 .62358 Mdot
.48036 .46711 Mdot
.35924 .36129 Mdot
.47873 .77982 Mdot
.42303 .66103 Mdot
.25458 .4853 Mdot
.47406 .63466 Mdot
.70173 .57841 Mdot
.66513 .36838 Mdot
.37291 .6697 Mdot
.40896 .30837 Mdot
.69921 .51363 Mdot
.32271 .4082 Mdot
.73578 .53485 Mdot
.52126 .76069 Mdot
.62885 .34321 Mdot
.66842 .54763 Mdot
.41218 .32694 Mdot
.6316 .36476 Mdot
.64226 .36928 Mdot
.47263 .46641 Mdot
.42366 .33399 Mdot
.33542 .40831 Mdot
.60534 .36253 Mdot
.56543 .74578 Mdot
.62533 .36245 Mdot
.5145 .77087 Mdot
.40152 .63484 Mdot
.28106 .63244 Mdot
.51283 .58831 Mdot
.45443 .71028 Mdot
.61657 .37019 Mdot
.36316 .37133 Mdot
.48222 .63463 Mdot
.65586 .53805 Mdot
.3247 .37324 Mdot
.75026 .61645 Mdot
.41282 .33179 Mdot
.63782 .54063 Mdot
.62767 .39238 Mdot
.70275 .51973 Mdot
.24366 .53509 Mdot
.33017 .41144 Mdot
.48307 .44449 Mdot
.30558 .56617 Mdot
.50963 .55465 Mdot
.4346 .68876 Mdot
.47982 .6419 Mdot
.43116 .61542 Mdot
.44179 .28269 Mdot
.30102 .39128 Mdot
.65907 .55965 Mdot
.49459 .72134 Mdot
.63846 .36495 Mdot
.42197 .50733 Mdot
.52138 .53836 Mdot
.48751 .61011 Mdot
.68945 .52804 Mdot
.65656 .56475 Mdot
.65489 .63093 Mdot
.4604 .30643 Mdot
.4322 .70907 Mdot
.42086 .67507 Mdot
.46754 .72605 Mdot
.61995 .37145 Mdot
.75754 .44226 Mdot
.48561 .2993 Mdot
.84819 .66147 Mdot
.45008 .29267 Mdot
.45708 .44348 Mdot
.67845 .51987 Mdot
.34854 .3788 Mdot
.41498 .62291 Mdot
.70382 .59498 Mdot
.71291 .50631 Mdot
.38093 .30346 Mdot
.33676 .37948 Mdot
.67305 .29678 Mdot
.58612 .34624 Mdot
.50722 .61818 Mdot
.4744 .63454 Mdot
.4697 .60573 Mdot
.45727 .61329 Mdot
.60754 .33444 Mdot
.44923 .59957 Mdot
.64286 .3851 Mdot
.51706 .75967 Mdot
.22193 .52148 Mdot
.44606 .3278 Mdot
.44828 .2111 Mdot
.69762 .50577 Mdot
.5149 .79079 Mdot
.49535 .77 Mdot
.28992 .62622 Mdot
.57702 .36995 Mdot
.48466 .6602 Mdot
.44138 .31659 Mdot
.69123 .33998 Mdot
.44854 .32735 Mdot
.50232 .84318 Mdot
.7044 .69115 Mdot
.64397 .28836 Mdot
.4638 .60622 Mdot
.42394 .32616 Mdot
.66323 .74335 Mdot
.5151 .57704 Mdot
.35831 .35058 Mdot
.53534 .75745 Mdot
.72968 .62531 Mdot
.3252 .39264 Mdot
.41061 .63038 Mdot
.67478 .50344 Mdot
.41723 .61963 Mdot
.41339 .62457 Mdot
.43141 .66872 Mdot
.64531 .33831 Mdot
.40138 .64014 Mdot
.44669 .61599 Mdot
.19075 .35672 Mdot
.34217 .34081 Mdot
.4397 .27748 Mdot
.58378 .57904 Mdot
.32284 .38061 Mdot
.73103 .5478 Mdot
.29952 .5705 Mdot
.62819 .37708 Mdot
.65118 .63113 Mdot
.4594 .59448 Mdot
.77816 .50053 Mdot
.63892 .37799 Mdot
.35675 .39668 Mdot
.50886 .53114 Mdot
.73852 .34588 Mdot
.42899 .27585 Mdot
.51554 .52777 Mdot
.4671 .27852 Mdot
.4362 .75165 Mdot
.66467 .53485 Mdot
.50927 .55496 Mdot
.59565 .35962 Mdot
.4459 .3307 Mdot
.28957 .63616 Mdot
.44934 .62196 Mdot
.4339 .32333 Mdot
.50782 .57616 Mdot
.27943 .58748 Mdot
.2912 .56942 Mdot
.42966 .33083 Mdot
.60174 .37646 Mdot
.62529 .37003 Mdot
.3179 .38546 Mdot
.66467 .52238 Mdot
.70272 .55889 Mdot
.62386 .36627 Mdot
.67837 .27041 Mdot
.43363 .63758 Mdot
.45402 .63525 Mdot
.32038 .55304 Mdot
.47297 .64805 Mdot
.372 .40594 Mdot
.51291 .53346 Mdot
.6909 .56637 Mdot
.48086 .63853 Mdot
.4834 .62888 Mdot
.40776 .6437 Mdot
.23795 .59872 Mdot
.44624 .28321 Mdot
.42247 .6 Mdot
.35202 .39567 Mdot
.74324 .62129 Mdot
.4399 .61157 Mdot
.51935 .56274 Mdot
.67565 .51963 Mdot
.55828 .39682 Mdot
.63772 .35963 Mdot
.47094 .31012 Mdot
.46592 .31816 Mdot
.21903 .45209 Mdot
.71484 .51945 Mdot
.51485 .52978 Mdot
.46773 .24329 Mdot
.52405 .51001 Mdot
.33932 .37745 Mdot
.44609 .49654 Mdot
.41906 .2707 Mdot
.44152 .27713 Mdot
.65932 .34386 Mdot
.44486 .6813 Mdot
.44566 .61308 Mdot
.79887 .463 Mdot
.45631 .64834 Mdot
.33556 .39326 Mdot
.58522 .36172 Mdot
.66963 .54598 Mdot
.32644 .39837 Mdot
.60831 .37345 Mdot
.70488 .55306 Mdot
.3962 .61442 Mdot
.47546 .62877 Mdot
.69653 .54138 Mdot
.65182 .53745 Mdot
.42573 .64496 Mdot
.18191 .51185 Mdot
.68314 .56866 Mdot
.69778 .53634 Mdot
.73914 .6226 Mdot
.43 .2767 Mdot
.48391 .69351 Mdot
.6162 .37857 Mdot
.44613 .61655 Mdot
.4481 .32506 Mdot
.34666 .37129 Mdot
.67346 .56076 Mdot
.49825 .61208 Mdot
.44119 .63634 Mdot
.3299 .37442 Mdot
.33762 .3588 Mdot
.34436 .36186 Mdot
.60614 .32923 Mdot
.44461 .59672 Mdot
.69931 .52958 Mdot
.59521 .33666 Mdot
.3136 .3943 Mdot
.36295 .36024 Mdot
.21361 .605 Mdot
.42881 .63978 Mdot
.32194 .36543 Mdot
.85961 .4404 Mdot
.26225 .64352 Mdot
.52457 .48635 Mdot
.40616 .34376 Mdot
.34008 .21818 Mdot
.29535 .41323 Mdot
.59815 .34597 Mdot
.4194 .50764 Mdot
.37297 .38449 Mdot
.5076 .60753 Mdot
.45506 .62818 Mdot
.49502 .55887 Mdot
.32733 .3709 Mdot
.23616 .57104 Mdot
.70865 .55895 Mdot
.57016 .66053 Mdot
.32278 .38113 Mdot
.43562 .33399 Mdot
.48869 .28052 Mdot
.44817 .30018 Mdot
.45004 .68912 Mdot
.42235 .75648 Mdot
.56033 .72919 Mdot
.47644 .77564 Mdot
.58427 .34925 Mdot
.65864 .56672 Mdot
.76381 .61186 Mdot
.69295 .55009 Mdot
.4644 .28599 Mdot
.36364 .37285 Mdot
.71473 .53945 Mdot
.64459 .36365 Mdot
.62249 .37022 Mdot
.41739 .28447 Mdot
.44308 .28933 Mdot
.4381 .30546 Mdot
.6815 .51267 Mdot
.67513 .52208 Mdot
.47447 .61481 Mdot
.65998 .55533 Mdot
.40739 .39231 Mdot
.43259 .39312 Mdot
.46076 .26122 Mdot
.62147 .35113 Mdot
.69211 .55827 Mdot
.46523 .63794 Mdot
.37934 .52193 Mdot
.47926 .25459 Mdot
.32177 .40509 Mdot
.79921 .59077 Mdot
.68304 .80253 Mdot
.48149 .64724 Mdot
.61542 .33627 Mdot
.5176 .53143 Mdot
.42966 .61806 Mdot
.41312 .31576 Mdot
.34688 .44741 Mdot
.50105 .52838 Mdot
.42807 .60849 Mdot
.39396 .62433 Mdot
.63439 .34434 Mdot
.30322 .57068 Mdot
.50704 .61277 Mdot
.45571 .46895 Mdot
.58312 .36295 Mdot
.48597 .28788 Mdot
.30289 .22483 Mdot
.65161 .59086 Mdot
.27293 .47847 Mdot
.50975 .49953 Mdot
.40386 .63854 Mdot
.42886 .30111 Mdot
.33528 .40185 Mdot
.43456 .29878 Mdot
.72463 .56066 Mdot
.42593 .27916 Mdot
.45469 .65298 Mdot
.7003 .52819 Mdot
.63047 .37136 Mdot
.34517 .53032 Mdot
.52775 .67685 Mdot
.45955 .33037 Mdot
.53016 .49133 Mdot
.43331 .60118 Mdot
.5624 .7517 Mdot
.45539 .71009 Mdot
.46613 .62352 Mdot
.60608 .34785 Mdot
.67991 .52599 Mdot
.64143 .34668 Mdot
.47827 .69966 Mdot
.6075 .52408 Mdot
.63855 .3569 Mdot
.3687 .64029 Mdot
.3707 .38171 Mdot
.23722 .58228 Mdot
.43387 .65846 Mdot
.59394 .35643 Mdot
.4157 .6105 Mdot
.70723 .51833 Mdot
.26166 .61551 Mdot
.27578 .61015 Mdot
.61 .35842 Mdot
.50867 .46208 Mdot
.2793 .57554 Mdot
.48561 .69134 Mdot
.5895 .34788 Mdot
.26892 .67168 Mdot
.51684 .51789 Mdot
.35782 .37044 Mdot
.35226 .35714 Mdot
.35864 .38172 Mdot
.45711 .63446 Mdot
.67394 .75326 Mdot
.31746 .37924 Mdot
.57784 .33121 Mdot
.34099 .39654 Mdot
.38656 .44863 Mdot
.80569 .46955 Mdot
.36981 .3789 Mdot
.4416 .65676 Mdot
.38726 .70675 Mdot
.41155 .51577 Mdot
.438 .34 Mdot
.72506 .35301 Mdot
.19791 .34559 Mdot
.434 .63143 Mdot
.78958 .59548 Mdot
.64061 .57305 Mdot
.45366 .43826 Mdot
.28122 .61691 Mdot
.35906 .56627 Mdot
.69877 .54783 Mdot
.30422 .56814 Mdot
.65593 .52002 Mdot
.51587 .55111 Mdot
.45292 .64001 Mdot
.7025 .51465 Mdot
.77148 .51408 Mdot
.24544 .6638 Mdot
.79151 .48994 Mdot
.69618 .55844 Mdot
.58701 .35536 Mdot
.60889 .3412 Mdot
.60481 .35076 Mdot
.42993 .29094 Mdot
.66562 .54649 Mdot
.41339 .60553 Mdot
.4151 .30551 Mdot
.41582 .64477 Mdot
.61579 .36305 Mdot
.28204 .62122 Mdot
.66743 .54288 Mdot
.43102 .6545 Mdot
.65512 .75436 Mdot
.47214 .28226 Mdot
.3278 .3746 Mdot
.79679 .59113 Mdot
.40447 .33451 Mdot
.6362 .38235 Mdot
.7169 .56779 Mdot
.35706 .3388 Mdot
.43775 .47938 Mdot
.41754 .66823 Mdot
.45707 .66025 Mdot
.41803 .50683 Mdot
.71129 .69196 Mdot
.50103 .62172 Mdot
.41812 .3017 Mdot
.43745 .27451 Mdot
.40975 .62094 Mdot
.66404 .54846 Mdot
.37287 .39095 Mdot
.3197 .36411 Mdot
.41218 .68602 Mdot
.28788 .56411 Mdot
.28284 .63301 Mdot
.47979 .62653 Mdot
.4488 .57122 Mdot
.41351 .32822 Mdot
.52508 .48508 Mdot
.29503 .56005 Mdot
.35241 .38403 Mdot
.4198 .66142 Mdot
.5781 .60513 Mdot
.67124 .5562 Mdot
.43811 .32204 Mdot
.63786 .33294 Mdot
.35152 .35067 Mdot
.45663 .26255 Mdot
.40966 .62127 Mdot
.48336 .62967 Mdot
.59787 .36402 Mdot
.70736 .57418 Mdot
.34646 .36497 Mdot
.41549 .30254 Mdot
.34978 .381 Mdot
.66857 .53055 Mdot
.67547 .56262 Mdot
.43124 .67415 Mdot
.43878 .71379 Mdot
.46795 .32233 Mdot
.45675 .6889 Mdot
.42875 .31747 Mdot
.42668 .23472 Mdot
.64079 .33843 Mdot
.43902 .67824 Mdot
.72782 .5377 Mdot
.61837 .36529 Mdot
.43054 .63046 Mdot
.4266 .49733 Mdot
.48526 .62253 Mdot
.42403 .32726 Mdot
.32593 .44112 Mdot
.35709 .37459 Mdot
.45284 .58519 Mdot
.70139 .62483 Mdot
.47659 .64129 Mdot
.47601 .2771 Mdot
.5564 .74153 Mdot
.63475 .35067 Mdot
.68892 .51809 Mdot
.49646 .25561 Mdot
.62469 .35825 Mdot
.43867 .66138 Mdot
.33972 .38983 Mdot
.65038 .54836 Mdot
.51516 .49573 Mdot
.27731 .53256 Mdot
.46732 .70464 Mdot
.42566 .70607 Mdot
.50307 .61791 Mdot
.80178 .43999 Mdot
.43691 .30344 Mdot
.69167 .52798 Mdot
.61068 .33737 Mdot
.63224 .346 Mdot
.46666 .28091 Mdot
.72573 .62293 Mdot
.80013 .52992 Mdot
.86017 .42036 Mdot
.47085 .26155 Mdot
.35455 .38855 Mdot
.26335 .61599 Mdot
.4488 .30138 Mdot
.45285 .27712 Mdot
.40085 .30534 Mdot
.79795 .45733 Mdot
.70274 .54898 Mdot
.44154 .63542 Mdot
.78426 .59735 Mdot
.43426 .66795 Mdot
.27563 .48344 Mdot
.61638 .36238 Mdot
.68941 .51795 Mdot
.46206 .39375 Mdot
.44293 .69004 Mdot
.42075 .62459 Mdot
.49251 .36604 Mdot
.50695 .54399 Mdot
.19105 .42647 Mdot
.45248 .66902 Mdot
.43453 .29227 Mdot
.65098 .49942 Mdot
.51513 .56171 Mdot
.656 .75469 Mdot
.6226 .37329 Mdot
.52293 .49686 Mdot
.51598 .5563 Mdot
.44848 .56886 Mdot
.65915 .51658 Mdot
.71271 .54843 Mdot
.34286 .35882 Mdot
.78097 .53992 Mdot
.62322 .37414 Mdot
.76594 .43064 Mdot
.46827 .62437 Mdot
.57715 .37863 Mdot
.35479 .44062 Mdot
.42567 .6331 Mdot
.47009 .4674 Mdot
.65504 .63057 Mdot
.49537 .61742 Mdot
.48673 .76408 Mdot
.6191 .35583 Mdot
.22985 .51302 Mdot
.45227 .6026 Mdot
.43459 .32239 Mdot
.70926 .5336 Mdot
.63827 .53744 Mdot
.32752 .40183 Mdot
.39587 .3995 Mdot
.7736 .7289 Mdot
.69164 .51798 Mdot
.45106 .6216 Mdot
.63458 .35441 Mdot
.51993 .49333 Mdot
.51172 .58975 Mdot
.50611 .4596 Mdot
.67369 .55664 Mdot
.51465 .57164 Mdot
.78017 .5035 Mdot
.30302 .56911 Mdot
.53322 .79406 Mdot
.60497 .35616 Mdot
.34657 .39198 Mdot
.39901 .67991 Mdot
.43531 .24057 Mdot
.47582 .63196 Mdot
.27468 .48192 Mdot
.63303 .55925 Mdot
.33909 .39383 Mdot
.42058 .61973 Mdot
.50018 .63069 Mdot
.30752 .6225 Mdot
.38082 .37742 Mdot
.50352 .61518 Mdot
.47653 .65525 Mdot
.71201 .53705 Mdot
.51553 .53003 Mdot
.67227 .54831 Mdot
.41604 .62362 Mdot
.2727 .42183 Mdot
.69805 .51528 Mdot
.71722 .3519 Mdot
.31592 .36543 Mdot
.62459 .37836 Mdot
.49659 .57325 Mdot
.41037 .66014 Mdot
.53071 .80178 Mdot
.52425 .4933 Mdot
.69731 .29064 Mdot
.43355 .32644 Mdot
.17684 .43042 Mdot
.40048 .33054 Mdot
.58399 .30352 Mdot
.6019 .43481 Mdot
.49727 .5654 Mdot
.71988 .62371 Mdot
.46539 .78108 Mdot
.59362 .37465 Mdot
.49986 .79445 Mdot
.45712 .61924 Mdot
.41247 .65365 Mdot
.42962 .31936 Mdot
.57016 .36483 Mdot
.37272 .67023 Mdot
.29377 .56025 Mdot
.36116 .39421 Mdot
.6865 .54215 Mdot
.46013 .63091 Mdot
.76741 .51378 Mdot
.44617 .33283 Mdot
.56428 .62908 Mdot
.4348 .65562 Mdot
.50706 .54323 Mdot
.57202 .36416 Mdot
.63084 .37182 Mdot
.42306 .33038 Mdot
.43079 .33502 Mdot
.40749 .65048 Mdot
.61758 .33083 Mdot
.47522 .60919 Mdot
.27886 .57844 Mdot
.50705 .57174 Mdot
.33947 .37485 Mdot
.4693 .63282 Mdot
.63629 .59145 Mdot
.28716 .75458 Mdot
.44285 .68809 Mdot
.70466 .50786 Mdot
.43601 .30993 Mdot
.45481 .2813 Mdot
.7004 .56019 Mdot
.45654 .28112 Mdot
.57237 .65974 Mdot
.67188 .75685 Mdot
.34229 .37814 Mdot
.53555 .72662 Mdot
.36505 .38136 Mdot
.52378 .4982 Mdot
.42756 .64147 Mdot
.54132 .18753 Mdot
.47169 .26276 Mdot
.36807 .45892 Mdot
.623 .36445 Mdot
.52688 .49559 Mdot
.44278 .5983 Mdot
.3046 .40877 Mdot
.45697 .29488 Mdot
.52859 .51438 Mdot
.42817 .66794 Mdot
.68731 .51241 Mdot
.49153 .61194 Mdot
.52183 .52891 Mdot
.51866 .525 Mdot
.49261 .6449 Mdot
.60843 .37351 Mdot
.66574 .52789 Mdot
.66931 .2914 Mdot
.47308 .27998 Mdot
.43017 .60488 Mdot
.44622 .61961 Mdot
.64798 .5483 Mdot
.44861 .6646 Mdot
.6113 .33044 Mdot
.83236 .32193 Mdot
.35335 .36241 Mdot
.52235 .48577 Mdot
.71292 .39517 Mdot
.49184 .64712 Mdot
.47845 .64865 Mdot
.36941 .57625 Mdot
.57246 .62437 Mdot
.62081 .37824 Mdot
.45053 .70067 Mdot
.43369 .2786 Mdot
.35098 .36574 Mdot
.64606 .36137 Mdot
.45875 .59697 Mdot
.44838 .65632 Mdot
.341 .39287 Mdot
.483 .37835 Mdot
.37298 .36136 Mdot
.59925 .34072 Mdot
.51556 .47682 Mdot
.38179 .51981 Mdot
.4368 .64303 Mdot
.51043 .53771 Mdot
.68089 .52894 Mdot
.59272 .34152 Mdot
.64101 .64251 Mdot
.51656 .55005 Mdot
.62961 .39295 Mdot
.62839 .37258 Mdot
.41846 .66831 Mdot
.71156 .5176 Mdot
.67393 .58782 Mdot
.68515 .52832 Mdot
.21564 .50217 Mdot
.6695 .28479 Mdot
.43424 .30767 Mdot
.62283 .35263 Mdot
.4532 .32085 Mdot
.37223 .37821 Mdot
.26036 .59214 Mdot
.44302 .33609 Mdot
.72082 .54496 Mdot
.45501 .32294 Mdot
.47581 .61156 Mdot
.63193 .37804 Mdot
.47649 .31058 Mdot
.46932 .61952 Mdot
.38392 .64032 Mdot
.51323 .54155 Mdot
.3538 .40466 Mdot
.29451 .56713 Mdot
.43216 .66119 Mdot
.511 .5286 Mdot
.42979 .65001 Mdot
.61431 .33036 Mdot
.3387 .51898 Mdot
.41467 .60804 Mdot
.47254 .26286 Mdot
.74945 .3324 Mdot
.44755 .27025 Mdot
.55884 .56658 Mdot
.41731 .64248 Mdot
.434 .64146 Mdot
.43221 .60094 Mdot
.73433 .6295 Mdot
.63862 .38333 Mdot
.45522 .69584 Mdot
.40782 .30849 Mdot
.69154 .55407 Mdot
.71802 .52829 Mdot
.39116 .54571 Mdot
.51313 .53067 Mdot
.61436 .32888 Mdot
.43387 .6397 Mdot
.52076 .52542 Mdot
.30207 .54443 Mdot
.79542 .50614 Mdot
.39517 .34073 Mdot
.46277 .27292 Mdot
.66142 .52183 Mdot
.4315 .28522 Mdot
.4541 .59761 Mdot
.51414 .56918 Mdot
.67675 .29383 Mdot
.59764 .32464 Mdot
.35099 .36633 Mdot
.41461 .63911 Mdot
.23821 .61205 Mdot
.41942 .29351 Mdot
.42019 .33171 Mdot
.47414 .60805 Mdot
.62399 .55416 Mdot
.24281 .70287 Mdot
.58082 .34762 Mdot
.57931 .75423 Mdot
.74958 .66751 Mdot
.38031 .74125 Mdot
.62488 .34499 Mdot
.4657 .46828 Mdot
.44141 .3408 Mdot
.24753 .38742 Mdot
.69491 .55104 Mdot
.34668 .36555 Mdot
.47016 .6218 Mdot
.71964 .5467 Mdot
.46668 .25965 Mdot
.6571 .56029 Mdot
.50743 .55887 Mdot
.63799 .37774 Mdot
.45251 .28646 Mdot
.62699 .32718 Mdot
.73062 .53154 Mdot
.36338 .37888 Mdot
.2562 .48862 Mdot
.55519 .75204 Mdot
.66041 .62989 Mdot
.42605 .59805 Mdot
.3299 .34433 Mdot
.41964 .6003 Mdot
.6356 .55199 Mdot
.43479 .65857 Mdot
.38757 .64164 Mdot
.42576 .33957 Mdot
.41721 .66914 Mdot
.46883 .62755 Mdot
.65241 .75866 Mdot
.42236 .63145 Mdot
.40882 .63458 Mdot
.42033 .67212 Mdot
.72086 .52731 Mdot
.43384 .67269 Mdot
.66356 .52552 Mdot
.77886 .48829 Mdot
.47293 .28063 Mdot
.3715 .37507 Mdot
.37034 .37611 Mdot
.2831 .47202 Mdot
.23817 .60816 Mdot
.77599 .60307 Mdot
.68225 .55366 Mdot
.61831 .37051 Mdot
.47395 .61181 Mdot
.21612 .63592 Mdot
.27342 .42866 Mdot
.46917 .32571 Mdot
.46276 .32455 Mdot
.44803 .61129 Mdot
.66261 .81508 Mdot
.45937 .66273 Mdot
.31724 .54536 Mdot
.45731 .63527 Mdot
.44387 .67736 Mdot
.40306 .31517 Mdot
.24433 .53366 Mdot
.42166 .60052 Mdot
.66329 .51272 Mdot
.34558 .36692 Mdot
.51244 .53794 Mdot
.27571 .44332 Mdot
.73371 .69431 Mdot
.61432 .56968 Mdot
.42586 .60105 Mdot
.4129 .30723 Mdot
.68371 .56623 Mdot
.31781 .55612 Mdot
.59602 .33661 Mdot
.27129 .53637 Mdot
.50785 .77245 Mdot
.5761 .35949 Mdot
.35661 .36851 Mdot
.48269 .26051 Mdot
.4107 .65779 Mdot
.42557 .30171 Mdot
.46318 .68722 Mdot
.30199 .53866 Mdot
.34258 .37586 Mdot
.65737 .50651 Mdot
.58731 .3572 Mdot
.71728 .54875 Mdot
.57467 .59742 Mdot
.27219 .4257 Mdot
.17267 .40912 Mdot
.45584 .26419 Mdot
.52315 .70095 Mdot
.6887 .52172 Mdot
.40446 .63928 Mdot
.85853 .41967 Mdot
.67567 .5327 Mdot
.69335 .51262 Mdot
.30432 .52289 Mdot
.23634 .53981 Mdot
.46276 .68516 Mdot
.68029 .56957 Mdot
.48165 .26032 Mdot
.33397 .38259 Mdot
.46345 .61546 Mdot
.5136 .55775 Mdot
.71525 .53675 Mdot
.46133 .2901 Mdot
.25243 .52327 Mdot
.43869 .29021 Mdot
.70481 .54302 Mdot
.47522 .30061 Mdot
.67933 .31352 Mdot
.44597 .33537 Mdot
.46074 .64991 Mdot
.4347 .64025 Mdot
.69173 .58889 Mdot
.67538 .56261 Mdot
.47908 .64718 Mdot
.43357 .66595 Mdot
.69536 .52631 Mdot
.4724 .25144 Mdot
.59066 .59972 Mdot
.47191 .65981 Mdot
.43683 .63649 Mdot
.35765 .36223 Mdot
.30419 .58545 Mdot
.33351 .54586 Mdot
.4756 .6233 Mdot
.35897 .38439 Mdot
.6772 .51419 Mdot
.42688 .64785 Mdot
.24388 .53025 Mdot
.48817 .29732 Mdot
.47237 .60061 Mdot
.51485 .49794 Mdot
.42129 .59819 Mdot
.31846 .7486 Mdot
.43604 .60107 Mdot
.70137 .53934 Mdot
.70548 .52864 Mdot
.48109 .24993 Mdot
.69416 .54229 Mdot
.52299 .4871 Mdot
.62564 .36898 Mdot
.55797 .77099 Mdot
.52612 .48787 Mdot
.4969 .63008 Mdot
.30164 .42234 Mdot
.51709 .5585 Mdot
.51908 .5838 Mdot
.39487 .36001 Mdot
.50884 .50241 Mdot
.67803 .52415 Mdot
.71077 .48202 Mdot
.48274 .6768 Mdot
.60789 .32998 Mdot
.51555 .56065 Mdot
.47371 .60013 Mdot
.39037 .64758 Mdot
.60418 .53454 Mdot
.58907 .3397 Mdot
.46743 .71388 Mdot
.46382 .61551 Mdot
.57398 .61814 Mdot
.46071 .62859 Mdot
.34194 .40496 Mdot
.66981 .54221 Mdot
.42673 .29111 Mdot
.33549 .37678 Mdot
.50453 .61672 Mdot
.32285 .37835 Mdot
.42757 .30568 Mdot
.60039 .3611 Mdot
.45796 .6525 Mdot
.37916 .37695 Mdot
.36835 .38305 Mdot
.49395 .59715 Mdot
.70539 .52562 Mdot
.4605 .70665 Mdot
.42448 .64414 Mdot
.43098 .60069 Mdot
.70427 .55794 Mdot
.63087 .20193 Mdot
.40921 .64647 Mdot
.46699 .46616 Mdot
.63486 .54449 Mdot
.52317 .51909 Mdot
.42125 .29604 Mdot
.49044 .63344 Mdot
.64146 .35508 Mdot
.62645 .367 Mdot
.47461 .26693 Mdot
.71282 .54632 Mdot
.45633 .28368 Mdot
.43537 .68844 Mdot
.51558 .5638 Mdot
.46168 .61779 Mdot
.52482 .33958 Mdot
.71151 .32265 Mdot
.65063 .54409 Mdot
.46953 .27282 Mdot
.27667 .5545 Mdot
.62585 .37976 Mdot
.4036 .30217 Mdot
.65594 .5173 Mdot
.6928 .57009 Mdot
.69752 .56041 Mdot
.35979 .39101 Mdot
.44776 .29051 Mdot
.73455 .54117 Mdot
.73552 .53183 Mdot
.48411 .60189 Mdot
.46456 .61418 Mdot
.67018 .51699 Mdot
.4409 .24934 Mdot
.35614 .37176 Mdot
.41538 .29509 Mdot
.25226 .71712 Mdot
.58392 .34584 Mdot
.65541 .75635 Mdot
.47726 .62644 Mdot
.86201 .64641 Mdot
.45785 .66418 Mdot
.45672 .62416 Mdot
.73116 .54662 Mdot
.35847 .35706 Mdot
.33422 .38511 Mdot
.69081 .52169 Mdot
.66841 .5721 Mdot
.32907 .40433 Mdot
.35007 .54721 Mdot
.29007 .72913 Mdot
.30659 .55167 Mdot
.655 .55426 Mdot
.53966 .76824 Mdot
.6104 .34909 Mdot
.63146 .55102 Mdot
.67782 .34072 Mdot
.47893 .29629 Mdot
.45554 .33189 Mdot
.60466 .36745 Mdot
.40887 .64242 Mdot
.41172 .29643 Mdot
.3931 .6123 Mdot
.63352 .28961 Mdot
.49365 .48018 Mdot
.17325 .54589 Mdot
.45161 .6607 Mdot
.57448 .5322 Mdot
.80596 .45205 Mdot
.48758 .61914 Mdot
.67711 .72148 Mdot
.33958 .36542 Mdot
.63716 .55795 Mdot
.5773 .34753 Mdot
.79048 .59312 Mdot
.43566 .64221 Mdot
.66825 .56351 Mdot
.58329 .35789 Mdot
.70482 .31294 Mdot
.45599 .46925 Mdot
.48723 .60685 Mdot
.85835 .39747 Mdot
.69961 .50368 Mdot
.42567 .29273 Mdot
.59181 .73196 Mdot
.68222 .57861 Mdot
.44375 .47513 Mdot
.47668 .25976 Mdot
.32293 .59577 Mdot
.66616 .56623 Mdot
.36899 .35851 Mdot
.68238 .54443 Mdot
.31932 .39422 Mdot
.73243 .54944 Mdot
.47352 .2895 Mdot
.4174 .63152 Mdot
.47331 .28449 Mdot
.31828 .40346 Mdot
.46038 .26332 Mdot
.57735 .34807 Mdot
.50576 .51429 Mdot
.61519 .36333 Mdot
.25997 .60597 Mdot
.64923 .65557 Mdot
.59584 .3503 Mdot
.388 .5648 Mdot
.45384 .6531 Mdot
.69995 .57944 Mdot
.43038 .28838 Mdot
.41585 .33906 Mdot
.29242 .56617 Mdot
.70622 .54681 Mdot
.46516 .29058 Mdot
.54676 .75865 Mdot
.68228 .27417 Mdot
.38465 .63314 Mdot
.48009 .23229 Mdot
.69908 .53093 Mdot
.41088 .33331 Mdot
.31925 .54976 Mdot
.69307 .57254 Mdot
.47141 .318 Mdot
.5894 .35033 Mdot
.64122 .35611 Mdot
.45728 .65731 Mdot
.58232 .33519 Mdot
.44446 .33909 Mdot
.55623 .65326 Mdot
.68626 .51619 Mdot
.71494 .3296 Mdot
.36156 .36873 Mdot
.43763 .28402 Mdot
.50863 .59753 Mdot
.72754 .53908 Mdot
.45607 .32032 Mdot
.75422 .74466 Mdot
.27292 .76396 Mdot
.46364 .29156 Mdot
.67104 .54348 Mdot
.67761 .56042 Mdot
.4745 .66222 Mdot
.29109 .56256 Mdot
.45736 .29658 Mdot
.53621 .18692 Mdot
.27919 .6361 Mdot
.50874 .5136 Mdot
.19363 .35206 Mdot
.41691 .60396 Mdot
.43345 .59805 Mdot
.60066 .33792 Mdot
.42304 .624 Mdot
.66474 .56931 Mdot
.45743 .66494 Mdot
.64282 .34605 Mdot
.47552 .26999 Mdot
.43115 .64421 Mdot
.35278 .36574 Mdot
.63028 .33849 Mdot
.63365 .33771 Mdot
.47218 .30555 Mdot
.71142 .54779 Mdot
.81038 .57752 Mdot
.44103 .28887 Mdot
.4459 .59632 Mdot
.5098 .52589 Mdot
.41909 .67067 Mdot
.74698 .57229 Mdot
.63739 .5484 Mdot
.42965 .28667 Mdot
.49276 .54637 Mdot
.62808 .35307 Mdot
.43584 .34165 Mdot
.41118 .60578 Mdot
.48163 .30487 Mdot
.47708 .44429 Mdot
.36955 .20867 Mdot
.72934 .51511 Mdot
.46715 .44001 Mdot
.69596 .56975 Mdot
.51003 .50419 Mdot
.21503 .46227 Mdot
.35761 .37091 Mdot
.43302 .27666 Mdot
.71497 .34822 Mdot
.47076 .2779 Mdot
.425 .63052 Mdot
.44683 .65867 Mdot
.42668 .31912 Mdot
.36238 .38141 Mdot
.39628 .44743 Mdot
.37722 .36178 Mdot
.66779 .54888 Mdot
.37665 .5506 Mdot
.21798 .68928 Mdot
.46179 .33554 Mdot
.61467 .37206 Mdot
.66442 .59683 Mdot
.49825 .62733 Mdot
.58049 .34533 Mdot
.6289 .3352 Mdot
.31471 .3941 Mdot
.45508 .27626 Mdot
.65564 .51029 Mdot
.64005 .37364 Mdot
.69155 .57651 Mdot
.24984 .51951 Mdot
.51939 .54505 Mdot
.46096 .72764 Mdot
.50143 .62889 Mdot
.29963 .56867 Mdot
.64052 .37566 Mdot
.44826 .65123 Mdot
.41581 .69359 Mdot
.5865 .35022 Mdot
.31349 .39062 Mdot
.49698 .48834 Mdot
.46582 .29266 Mdot
.86034 .4684 Mdot
.46324 .64608 Mdot
.42026 .64081 Mdot
.58361 .3495 Mdot
.70218 .71147 Mdot
.66389 .51405 Mdot
.71264 .53246 Mdot
.4375 .30354 Mdot
.31418 .52484 Mdot
.43417 .67112 Mdot
.45771 .65088 Mdot
.42706 .32356 Mdot
.51623 .52269 Mdot
.17589 .39205 Mdot
.4423 .63736 Mdot
.61775 .35173 Mdot
.47829 .46757 Mdot
.60305 .37678 Mdot
.40737 .67004 Mdot
.43061 .62778 Mdot
.46927 .59109 Mdot
.41047 .605 Mdot
.61103 .36013 Mdot
.50176 .62261 Mdot
.4854 .66307 Mdot
.67806 .52686 Mdot
.41017 .61575 Mdot
.28064 .63689 Mdot
.44104 .64026 Mdot
.34518 .36416 Mdot
.33368 .54219 Mdot
.42926 .6039 Mdot
.4123 .61286 Mdot
.27658 .63501 Mdot
.42601 .61622 Mdot
.58095 .35361 Mdot
.68333 .56066 Mdot
.6299 .35288 Mdot
.61129 .37265 Mdot
.46007 .31915 Mdot
.31494 .37909 Mdot
.4523 .6901 Mdot
.34274 .40162 Mdot
.45626 .68304 Mdot
.4718 .70765 Mdot
.27886 .5865 Mdot
.31627 .54586 Mdot
.37011 .39219 Mdot
.45916 .64775 Mdot
.43162 .30429 Mdot
.43929 .27957 Mdot
.4212 .5056 Mdot
.49947 .56813 Mdot
.57378 .3443 Mdot
.59355 .35564 Mdot
.43443 .393 Mdot
.35895 .206 Mdot
.36452 .3943 Mdot
.40416 .44554 Mdot
.39813 .6121 Mdot
.41391 .64876 Mdot
.50657 .58257 Mdot
.44529 .3229 Mdot
.50778 .50373 Mdot
.43003 .27203 Mdot
.57462 .36796 Mdot
.62574 .34021 Mdot
.45605 .65618 Mdot
.62731 .83459 Mdot
.66202 .53581 Mdot
.6793 .56149 Mdot
.64425 .34804 Mdot
.44569 .27097 Mdot
.50934 .5739 Mdot
.8605 .51162 Mdot
.63903 .54267 Mdot
.37213 .36945 Mdot
.42329 .61341 Mdot
.47849 .29221 Mdot
.66813 .52561 Mdot
.37829 .37761 Mdot
.40116 .62979 Mdot
.47311 .2584 Mdot
.44665 .64855 Mdot
.54282 .70783 Mdot
.67964 .52102 Mdot
.2889 .59533 Mdot
.72317 .52325 Mdot
.61213 .35895 Mdot
.62685 .37608 Mdot
.43061 .62988 Mdot
.86418 .49912 Mdot
.64204 .50674 Mdot
.65478 .35753 Mdot
.34635 .35818 Mdot
.50328 .52352 Mdot
.31692 .3792 Mdot
.43053 .31755 Mdot
.35632 .36874 Mdot
.45779 .31954 Mdot
.4728 .24518 Mdot
.68032 .50329 Mdot
.34014 .39291 Mdot
.67276 .70193 Mdot
.51377 .57119 Mdot
.31377 .37127 Mdot
.44705 .60752 Mdot
.46281 .67458 Mdot
.45663 .30435 Mdot
.35234 .39844 Mdot
.49847 .61093 Mdot
.70632 .39644 Mdot
.61973 .37707 Mdot
.57626 .34932 Mdot
.50796 .56235 Mdot
.41508 .33219 Mdot
.68323 .50347 Mdot
.27097 .56179 Mdot
.66664 .50161 Mdot
.46033 .64753 Mdot
.44804 .68991 Mdot
.7268 .51984 Mdot
.69772 .50589 Mdot
.43456 .62755 Mdot
.59477 .78825 Mdot
.50799 .60307 Mdot
.64176 .35946 Mdot
.66611 .54706 Mdot
.67116 .56054 Mdot
.44414 .33848 Mdot
.71473 .53271 Mdot
.42695 .70842 Mdot
.57427 .36051 Mdot
.48476 .66855 Mdot
.62529 .35486 Mdot
.3669 .32937 Mdot
.46124 .30551 Mdot
.7089 .33831 Mdot
.71268 .52825 Mdot
.48076 .63969 Mdot
.71022 .52104 Mdot
.34073 .36208 Mdot
.66129 .55861 Mdot
.65226 .58292 Mdot
.46986 .62449 Mdot
.50414 .61409 Mdot
.52218 .51163 Mdot
.29681 .56471 Mdot
.67003 .5317 Mdot
.43749 .6873 Mdot
.45722 .66892 Mdot
.43664 .66633 Mdot
.27881 .57395 Mdot
.71989 .52649 Mdot
.73095 .69677 Mdot
.73151 .5051 Mdot
.6758 .52193 Mdot
.32175 .78682 Mdot
.52444 .5037 Mdot
.50122 .541 Mdot
.5847 .32225 Mdot
.44012 .63562 Mdot
.46155 .2817 Mdot
.45583 .59477 Mdot
.50759 .58809 Mdot
.42587 .60657 Mdot
.32483 .39203 Mdot
.41116 .6632 Mdot
.51382 .51462 Mdot
.43923 .28697 Mdot
.48576 .62042 Mdot
.43099 .63849 Mdot
.51675 .52529 Mdot
.70477 .51547 Mdot
.70323 .56286 Mdot
.68742 .49782 Mdot
.31904 .39938 Mdot
.60756 .34436 Mdot
.45468 .59544 Mdot
.43508 .3038 Mdot
.46263 .2796 Mdot
.72315 .53706 Mdot
.41887 .32133 Mdot
.62141 .33757 Mdot
.45301 .62391 Mdot
.61218 .36014 Mdot
.32307 .39108 Mdot
.66907 .54132 Mdot
.45087 .59871 Mdot
.4899 .59969 Mdot
.70535 .52842 Mdot
.50814 .60907 Mdot
.33816 .36106 Mdot
.43007 .32961 Mdot
.65084 .53799 Mdot
.62702 .36833 Mdot
.44419 .33742 Mdot
.48467 .62759 Mdot
.42218 .83349 Mdot
.4241 .62397 Mdot
.43564 .66904 Mdot
.65691 .49527 Mdot
.39885 .65498 Mdot
.47319 .2797 Mdot
.71698 .52778 Mdot
.4653 .67039 Mdot
.26284 .63322 Mdot
.38829 .34764 Mdot
.46102 .33813 Mdot
.44209 .61581 Mdot
.52407 .80045 Mdot
.4746 .64695 Mdot
.71996 .3547 Mdot
.27939 .58671 Mdot
.67406 .36222 Mdot
.46335 .72584 Mdot
.65417 .35489 Mdot
.51234 .52562 Mdot
.46578 .31146 Mdot
.63681 .7515 Mdot
.43508 .62405 Mdot
.64536 .63234 Mdot
.45694 .59796 Mdot
.62753 .3451 Mdot
.68965 .70746 Mdot
.41247 .3104 Mdot
.18274 .42152 Mdot
.40469 .62845 Mdot
.65628 .51932 Mdot
.41906 .27359 Mdot
.50126 .53645 Mdot
.5032 .61307 Mdot
.35 .40226 Mdot
.44249 .38552 Mdot
.44741 .70798 Mdot
.62833 .35495 Mdot
.41691 .65873 Mdot
.48334 .58767 Mdot
.67456 .25076 Mdot
.68787 .52772 Mdot
.59282 .3627 Mdot
.35107 .21524 Mdot
.45347 .65005 Mdot
.6947 .56906 Mdot
.69439 .55115 Mdot
.33381 .40093 Mdot
.64018 .39091 Mdot
.46371 .37808 Mdot
.61012 .82614 Mdot
.49942 .71228 Mdot
.4429 .32486 Mdot
.52506 .47589 Mdot
.45682 .59401 Mdot
.27299 .42528 Mdot
.61894 .37366 Mdot
.4186 .63822 Mdot
.67239 .62904 Mdot
.69721 .53518 Mdot
.44864 .64243 Mdot
.35283 .37064 Mdot
.82503 .56702 Mdot
.52801 .7604 Mdot
.54503 .79496 Mdot
.48151 .26037 Mdot
.45758 .68881 Mdot
.42628 .70735 Mdot
.52194 .52101 Mdot
.40927 .6736 Mdot
.42874 .29071 Mdot
.4903 .44711 Mdot
.35261 .3768 Mdot
.66505 .52776 Mdot
.51079 .5307 Mdot
.45721 .59821 Mdot
.46834 .68234 Mdot
.35045 .35891 Mdot
.47662 .59208 Mdot
.59668 .74109 Mdot
.52565 .47987 Mdot
.44528 .33453 Mdot
.64989 .5485 Mdot
.45179 .68922 Mdot
.50244 .52906 Mdot
.46346 .62084 Mdot
.6286 .58849 Mdot
.41616 .64186 Mdot
.68955 .38608 Mdot
.70951 .53459 Mdot
.63407 .36215 Mdot
.40763 .60711 Mdot
.44206 .64783 Mdot
.45889 .4389 Mdot
.5103 .5764 Mdot
.41505 .61443 Mdot
.71031 .5597 Mdot
.66284 .5313 Mdot
.65789 .51873 Mdot
.46319 .32968 Mdot
.30152 .55271 Mdot
.61768 .36052 Mdot
.5064 .58169 Mdot
.64043 .37348 Mdot
.40649 .74286 Mdot
.31844 .38872 Mdot
.703 .32772 Mdot
.44925 .62452 Mdot
.70249 .55352 Mdot
.27629 .71555 Mdot
.72339 .53237 Mdot
.57891 .31428 Mdot
.62229 .37399 Mdot
.67533 .53527 Mdot
.43456 .6163 Mdot
.30844 .5661 Mdot
.54901 .80401 Mdot
.62789 .37935 Mdot
.50324 .56248 Mdot
.34485 .32918 Mdot
.48538 .28291 Mdot
.30572 .77401 Mdot
.64264 .36897 Mdot
.80675 .45219 Mdot
.47142 .66072 Mdot
.70489 .51904 Mdot
.603 .35468 Mdot
.62239 .33218 Mdot
.41166 .31382 Mdot
.48559 .6048 Mdot
.4439 .64639 Mdot
.51529 .4982 Mdot
.60836 .36431 Mdot
.49559 .55248 Mdot
.48912 .60849 Mdot
.58139 .30039 Mdot
.64356 .53078 Mdot
.62561 .19721 Mdot
.38998 .57635 Mdot
.67108 .62949 Mdot
.59469 .20312 Mdot
.65302 .53156 Mdot
.40814 .63921 Mdot
.50795 .57329 Mdot
.42532 .32826 Mdot
.44107 .61965 Mdot
.46811 .27171 Mdot
.61934 .34271 Mdot
.6924 .39689 Mdot
.38101 .57516 Mdot
.61387 .29639 Mdot
.42115 .62816 Mdot
.53605 .75783 Mdot
.34636 .38607 Mdot
.57429 .35183 Mdot
.67783 .50727 Mdot
.42571 .67902 Mdot
.41436 .32233 Mdot
.4839 .29514 Mdot
.69376 .5351 Mdot
.79268 .45587 Mdot
.71194 .34071 Mdot
.50973 .6017 Mdot
.41848 .31002 Mdot
.50324 .54601 Mdot
.51379 .79067 Mdot
.65018 .3663 Mdot
.35161 .37784 Mdot
.47045 .31179 Mdot
.60681 .32893 Mdot
.46392 .6738 Mdot
.68627 .53607 Mdot
.71361 .50664 Mdot
.42772 .49485 Mdot
.46524 .28867 Mdot
.32863 .37781 Mdot
.4378 .48668 Mdot
.39089 .5369 Mdot
.3421 .37391 Mdot
.46529 .32936 Mdot
.66128 .55062 Mdot
.70315 .54337 Mdot
.68583 .55955 Mdot
.65641 .75438 Mdot
.63783 .54867 Mdot
.26439 .46048 Mdot
.40816 .67209 Mdot
.54735 .76597 Mdot
.44741 .67954 Mdot
.57784 .34705 Mdot
.68421 .51912 Mdot
.27997 .58884 Mdot
.40133 .60887 Mdot
.55416 .80461 Mdot
.42824 .65982 Mdot
.47374 .46651 Mdot
.4387 .63556 Mdot
.55523 .70925 Mdot
.64135 .56401 Mdot
.40239 .63341 Mdot
.58498 .37144 Mdot
.32589 .37208 Mdot
.72019 .56589 Mdot
.41055 .62802 Mdot
.76882 .49648 Mdot
.44762 .60713 Mdot
.69179 .3936 Mdot
.4379 .48093 Mdot
.37136 .41687 Mdot
.42739 .67338 Mdot
.41233 .28977 Mdot
.37152 .65211 Mdot
.53808 .77259 Mdot
.63063 .37834 Mdot
.54144 .75867 Mdot
.42058 .28461 Mdot
.69224 .70709 Mdot
.51127 .595 Mdot
.35626 .37702 Mdot
.51513 .46318 Mdot
.64068 .36444 Mdot
.4431 .62435 Mdot
.40618 .63904 Mdot
.49064 .48296 Mdot
.50214 .78756 Mdot
.5171 .53305 Mdot
.37342 .38844 Mdot
.51768 .7702 Mdot
.41524 .61578 Mdot
.45076 .34343 Mdot
.7113 .55314 Mdot
.68591 .70038 Mdot
.70578 .69661 Mdot
.48868 .61525 Mdot
.67815 .53297 Mdot
.71273 .54628 Mdot
.22706 .66965 Mdot
.35235 .38706 Mdot
.41818 .64674 Mdot
.46826 .43811 Mdot
.45431 .59596 Mdot
.61838 .34644 Mdot
.39268 .62228 Mdot
.46228 .30315 Mdot
.32203 .55182 Mdot
.46871 .32486 Mdot
.43826 .66635 Mdot
.68141 .54578 Mdot
.60841 .37518 Mdot
.47126 .24214 Mdot
.63927 .39097 Mdot
.26323 .46155 Mdot
.42849 .38724 Mdot
.36607 .39272 Mdot
.31576 .38736 Mdot
.57466 .3512 Mdot
.44953 .61898 Mdot
.28215 .56769 Mdot
.39484 .59606 Mdot
.44565 .63403 Mdot
.41355 .62943 Mdot
.61365 .31863 Mdot
.62487 .37303 Mdot
.47629 .29537 Mdot
.43599 .62683 Mdot
.43044 .68545 Mdot
.67836 .54159 Mdot
.36703 .38946 Mdot
.44847 .32905 Mdot
.32719 .40609 Mdot
.43351 .29501 Mdot
.31975 .74976 Mdot
.51731 .55245 Mdot
.32152 .38145 Mdot
.6481 .36366 Mdot
.69249 .56143 Mdot
.52485 .49618 Mdot
.43712 .31514 Mdot
.41706 .31825 Mdot
.46688 .67577 Mdot
.6697 .52561 Mdot
.71263 .53081 Mdot
.32826 .40495 Mdot
.59421 .35409 Mdot
.38164 .62636 Mdot
.49923 .63161 Mdot
.45305 .22077 Mdot
.41887 .32851 Mdot
.52752 .76884 Mdot
.708 .49447 Mdot
.46397 .62636 Mdot
.69815 .56609 Mdot
.43277 .64836 Mdot
.67773 .5943 Mdot
.70361 .50506 Mdot
.3935 .6436 Mdot
.46202 .57653 Mdot
.44852 .32204 Mdot
.19391 .6258 Mdot
.38575 .647 Mdot
.67162 .32106 Mdot
.46234 .59329 Mdot
.17069 .41051 Mdot
.26674 .70546 Mdot
.4497 .61351 Mdot
.41135 .66197 Mdot
.57106 .84374 Mdot
.47384 .64602 Mdot
.51233 .50706 Mdot
.51221 .59099 Mdot
.69263 .56887 Mdot
.47061 .4404 Mdot
.29629 .56757 Mdot
.34895 .39257 Mdot
.43678 .30459 Mdot
.23952 .53757 Mdot
.31856 .39432 Mdot
.70089 .53615 Mdot
.38087 .62725 Mdot
.6702 .49362 Mdot
.40143 .33044 Mdot
.5099 .54181 Mdot
.62358 .34427 Mdot
.28706 .5673 Mdot
.41294 .31852 Mdot
.6256 .36951 Mdot
.4679 .65763 Mdot
.44619 .25224 Mdot
.59257 .37404 Mdot
.19731 .63955 Mdot
.60213 .33552 Mdot
.63322 .36936 Mdot
.2946 .55789 Mdot
.34902 .39267 Mdot
.49591 .45117 Mdot
.48264 .69479 Mdot
.5955 .36972 Mdot
.19187 .43652 Mdot
.4115 .32382 Mdot
.29564 .54007 Mdot
.64026 .56422 Mdot
.51562 .55678 Mdot
.41561 .63025 Mdot
.5948 .3401 Mdot
.49079 .53685 Mdot
.4564 .4385 Mdot
.63471 .3453 Mdot
.41004 .60106 Mdot
.31948 .52721 Mdot
.5039 .52691 Mdot
.52381 .50101 Mdot
.37765 .37446 Mdot
.37019 .23379 Mdot
.70871 .54851 Mdot
.37047 .36853 Mdot
.2717 .60713 Mdot
.42735 .66196 Mdot
.6094 .35865 Mdot
.51051 .53282 Mdot
.6277 .36543 Mdot
.34017 .38442 Mdot
.33912 .35982 Mdot
.67958 .52674 Mdot
.66305 .51557 Mdot
.51521 .47163 Mdot
.27721 .64232 Mdot
.47152 .60184 Mdot
.63879 .64391 Mdot
.70113 .50616 Mdot
.67564 .73514 Mdot
.35406 .39305 Mdot
.36303 .39229 Mdot
.47567 .76199 Mdot
.47429 .61437 Mdot
.47748 .46685 Mdot
.42766 .60414 Mdot
.20891 .41403 Mdot
.45316 .59908 Mdot
.42364 .32293 Mdot
.4108 .60977 Mdot
.78635 .53171 Mdot
.48358 .64279 Mdot
.41632 .6183 Mdot
.44872 .29671 Mdot
.45866 .68523 Mdot
.45927 .30348 Mdot
.41038 .64465 Mdot
.45965 .35916 Mdot
.43558 .30344 Mdot
.32714 .35165 Mdot
.45488 .48839 Mdot
.51776 .50495 Mdot
.33082 .39669 Mdot
.36116 .39733 Mdot
.25446 .5185 Mdot
.65987 .54325 Mdot
.7253 .63408 Mdot
.42313 .6143 Mdot
.41379 .32833 Mdot
.61422 .34089 Mdot
.49062 .61604 Mdot
.44907 .66809 Mdot
.38582 .64651 Mdot
.67627 .52965 Mdot
.43222 .34019 Mdot
.33324 .39044 Mdot
.45726 .27383 Mdot
.45892 .35533 Mdot
.45788 .31065 Mdot
.44696 .57118 Mdot
.46268 .67624 Mdot
.42475 .70645 Mdot
.66651 .67306 Mdot
.31337 .42872 Mdot
.68986 .53517 Mdot
.51168 .52345 Mdot
.31684 .38347 Mdot
.34489 .53089 Mdot
.70407 .55708 Mdot
.42618 .32203 Mdot
.44645 .64898 Mdot
.51998 .54597 Mdot
.48176 .69547 Mdot
.69109 .5784 Mdot
.30819 .38033 Mdot
.44073 .30858 Mdot
.50748 .51818 Mdot
.30434 .55002 Mdot
.7506 .66812 Mdot
.25902 .5979 Mdot
.43798 .64868 Mdot
.32756 .40405 Mdot
.66784 .52597 Mdot
.48704 .46925 Mdot
.59054 .34578 Mdot
.29239 .56356 Mdot
.42099 .62634 Mdot
.54826 .33245 Mdot
.68299 .54635 Mdot
.36321 .3778 Mdot
.59542 .33922 Mdot
.35632 .3836 Mdot
.50155 .52388 Mdot
.72865 .5022 Mdot
.5036 .61151 Mdot
.43483 .60108 Mdot
.61483 .34236 Mdot
.71046 .5436 Mdot
.46371 .36117 Mdot
.50247 .46216 Mdot
.42703 .31832 Mdot
.34336 .53842 Mdot
.6647 .52921 Mdot
.53852 .33088 Mdot
.45856 .27302 Mdot
.57847 .33266 Mdot
.31391 .57817 Mdot
.62356 .33669 Mdot
.41323 .62243 Mdot
.67939 .5559 Mdot
.62936 .37952 Mdot
.42902 .23381 Mdot
.60485 .79847 Mdot
.51099 .46418 Mdot
.4521 .65504 Mdot
.72676 .3532 Mdot
.80279 .47695 Mdot
.68013 .58885 Mdot
.64562 .36288 Mdot
.42477 .63645 Mdot
.51021 .60286 Mdot
.40474 .62558 Mdot
.59985 .37004 Mdot
.57696 .40734 Mdot
.42125 .28935 Mdot
.44971 .64994 Mdot
.3547 .36533 Mdot
.4665 .30107 Mdot
.48236 .27103 Mdot
.47091 .31241 Mdot
.678 .50787 Mdot
.5185 .54286 Mdot
.51306 .58933 Mdot
.24848 .67411 Mdot
.63518 .36447 Mdot
.51759 .50543 Mdot
.40836 .65592 Mdot
.26385 .46563 Mdot
.69799 .55519 Mdot
.44565 .30798 Mdot
.42032 .642 Mdot
.43019 .49012 Mdot
.51413 .53351 Mdot
.4453 .29 Mdot
.69427 .50482 Mdot
.61832 .5082 Mdot
.44385 .62078 Mdot
.47071 .59406 Mdot
.70211 .52933 Mdot
.81671 .49326 Mdot
.30726 .54595 Mdot
.43298 .64645 Mdot
.63086 .36732 Mdot
.80423 .38088 Mdot
.46508 .66271 Mdot
.63869 .51611 Mdot
.51042 .49752 Mdot
.74163 .50764 Mdot
.58416 .7537 Mdot
.49404 .57381 Mdot
.59223 .47882 Mdot
.37244 .45977 Mdot
.59375 .51869 Mdot
.22742 .41149 Mdot
.53928 .44673 Mdot
.21079 .67035 Mdot
.57061 .35612 Mdot
.54259 .7177 Mdot
.74258 .75147 Mdot
.7988 .44819 Mdot
.47731 .42164 Mdot
.61829 .42652 Mdot
.39065 .31708 Mdot
.17997 .37976 Mdot
.4232 .27668 Mdot
.23373 .40382 Mdot
.44044 .60148 Mdot
.81102 .49463 Mdot
.54271 .7267 Mdot
.39616 .39659 Mdot
.68264 .31326 Mdot
.4364 .48456 Mdot
.48837 .82706 Mdot
.63683 .29209 Mdot
.38211 .79627 Mdot
.6934 .63102 Mdot
.40199 .21287 Mdot
.35658 .5514 Mdot
.23762 .51898 Mdot
.55238 .74455 Mdot
.65217 .4731 Mdot
.57618 .38345 Mdot
.5776 .62973 Mdot
.60977 .20573 Mdot
.42295 .3093 Mdot
.68226 .57662 Mdot
.60629 .43608 Mdot
.43539 .81072 Mdot
.63384 .3037 Mdot
.59077 .47951 Mdot
.50594 .46524 Mdot
.55179 .71084 Mdot
.28336 .59596 Mdot
.55424 .68898 Mdot
.45461 .38656 Mdot
.18343 .37864 Mdot
.62867 .51017 Mdot
.41724 .23347 Mdot
.33144 .51393 Mdot
.43783 .41381 Mdot
.57493 .71622 Mdot
.3125 .40763 Mdot
.33288 .34878 Mdot
.69466 .50431 Mdot
.46876 .80489 Mdot
.41104 .5544 Mdot
.27485 .61394 Mdot
.42064 .27824 Mdot
.6095 .56107 Mdot
.82203 .56646 Mdot
.79333 .47655 Mdot
.17404 .58107 Mdot
.4195 .82813 Mdot
.201 .47845 Mdot
.48041 .48527 Mdot
.62294 .30652 Mdot
.27873 .4638 Mdot
.57133 .53242 Mdot
.19817 .51257 Mdot
.63348 .59009 Mdot
.54038 .82998 Mdot
.75017 .47324 Mdot
.45579 .83469 Mdot
.62342 .51194 Mdot
.42525 .69938 Mdot
.71644 .5795 Mdot
.55441 .64895 Mdot
.24695 .6087 Mdot
.46254 .82472 Mdot
.38818 .39843 Mdot
.50039 .51432 Mdot
.79107 .44025 Mdot
.59499 .74124 Mdot
.47961 .37434 Mdot
.35501 .3488 Mdot
.69588 .6781 Mdot
.49399 .83594 Mdot
.60379 .47389 Mdot
.40351 .76762 Mdot
.5784 .30055 Mdot
.50816 .27543 Mdot
.47946 .26773 Mdot
.64685 .3415 Mdot
.39817 .8076 Mdot
.6849 .55511 Mdot
.18841 .62295 Mdot
.5477 .46864 Mdot
.54413 .49841 Mdot
.4999 .83674 Mdot
.1794 .52889 Mdot
.56752 .75102 Mdot
.34367 .44794 Mdot
.68869 .28797 Mdot
.56608 .58526 Mdot
.59259 .30195 Mdot
.34796 .33627 Mdot
.70516 .37544 Mdot
.41226 .81103 Mdot
.18872 .49318 Mdot
.63227 .82319 Mdot
.2831 .61998 Mdot
.28791 .35186 Mdot
.63095 .50961 Mdot
.52764 .40085 Mdot
.49026 .37255 Mdot
.44796 .83592 Mdot
.52102 .76136 Mdot
.77098 .3482 Mdot
.22003 .4299 Mdot
.70806 .70052 Mdot
.73786 .38205 Mdot
.57849 .42254 Mdot
.55719 .63196 Mdot
.77104 .49164 Mdot
.49828 .64265 Mdot
.24831 .58664 Mdot
.69618 .66419 Mdot
.37135 .40993 Mdot
.31158 .55592 Mdot
.7454 .45412 Mdot
.21337 .51884 Mdot
.78298 .3724 Mdot
.70306 .67385 Mdot
.72742 .52701 Mdot
.19953 .51166 Mdot
.20914 .44674 Mdot
.75724 .35481 Mdot
.3478 .21801 Mdot
.40179 .76876 Mdot
.51489 .35974 Mdot
.49032 .5775 Mdot
.53936 .71999 Mdot
.55501 .74132 Mdot
.19205 .39066 Mdot
.45959 .57062 Mdot
.22266 .64673 Mdot
.67607 .31313 Mdot
.65091 .68962 Mdot
.22424 .58179 Mdot
.66173 .68039 Mdot
.56104 .76992 Mdot
.75531 .56782 Mdot
.67472 .347 Mdot
.47373 .54505 Mdot
.4984 .83329 Mdot
.47228 .29933 Mdot
.19575 .51385 Mdot
.63179 .29922 Mdot
.44059 .22702 Mdot
.51799 .44623 Mdot
.46764 .42364 Mdot
.35672 .79646 Mdot
.77948 .4323 Mdot
.3829 .29994 Mdot
.69162 .48242 Mdot
.56366 .50392 Mdot
.64553 .64893 Mdot
.40904 .57356 Mdot
.61341 .5725 Mdot
.33817 .36099 Mdot
.64662 .72913 Mdot
.75843 .53096 Mdot
.33446 .2239 Mdot
.43255 .57607 Mdot
.36057 .55037 Mdot
.51668 .49221 Mdot
.27388 .51596 Mdot
.31438 .74776 Mdot
.48861 .55723 Mdot
.1813 .53729 Mdot
.79247 .44823 Mdot
.2691 .51974 Mdot
.48417 .37695 Mdot
.7317 .63699 Mdot
.45891 .83564 Mdot
.28771 .75343 Mdot
.80431 .51985 Mdot
.73094 .37537 Mdot
.3084 .21059 Mdot
.67606 .35474 Mdot
.20341 .6232 Mdot
.63138 .29936 Mdot
.83289 .32434 Mdot
.47291 .27643 Mdot
.26984 .41793 Mdot
.5861 .57607 Mdot
.38703 .51833 Mdot
.45245 .81055 Mdot
.57922 .73748 Mdot
.30768 .37754 Mdot
.68487 .58533 Mdot
.47201 .57229 Mdot
.4757 .81682 Mdot
.50819 .82691 Mdot
.48233 .81597 Mdot
.55038 .36507 Mdot
.56421 .79157 Mdot
.54319 .84507 Mdot
.26939 .45797 Mdot
.4541 .51966 Mdot
.49307 .5881 Mdot
.26435 .6453 Mdot
.20072 .59111 Mdot
.31038 .41894 Mdot
.56472 .59107 Mdot
.63463 .50557 Mdot
.52361 .84704 Mdot
.3014 .74125 Mdot
.55214 .68464 Mdot
.36036 .79145 Mdot
.36974 .29838 Mdot
.22538 .61159 Mdot
.32548 .77895 Mdot
.62883 .4718 Mdot
.56072 .33448 Mdot
.54872 .85265 Mdot
.2123 .46019 Mdot
.6144 .42636 Mdot
.76717 .50425 Mdot
.19745 .59998 Mdot
.72753 .38575 Mdot
.60583 .42838 Mdot
.59274 .56064 Mdot
.76583 .63983 Mdot
.47702 .4147 Mdot
.64907 .47595 Mdot
.47871 .47826 Mdot
.22045 .58572 Mdot
.46611 .2652 Mdot
.1964 .53487 Mdot
.46643 .40085 Mdot
.46232 .51747 Mdot
.24905 .54031 Mdot
.19202 .4606 Mdot
.71616 .46879 Mdot
.53653 .79659 Mdot
.78702 .44231 Mdot
.79789 .38063 Mdot
.75134 .37252 Mdot
.70521 .65005 Mdot
.45586 .68726 Mdot
.44199 .8133 Mdot
.23759 .72381 Mdot
.33529 .7871 Mdot
.76631 .36038 Mdot
.50039 .29874 Mdot
.58323 .33682 Mdot
.26781 .47503 Mdot
.40298 .50055 Mdot
.60168 .45453 Mdot
.40354 .45825 Mdot
.6581 .35791 Mdot
.82573 .56232 Mdot
.53229 .46064 Mdot
.26979 .46323 Mdot
.58514 .62352 Mdot
.55529 .51457 Mdot
.51069 .79075 Mdot
.72637 .52118 Mdot
.74737 .33893 Mdot
.19839 .51553 Mdot
.47135 .30429 Mdot
.44812 .21735 Mdot
.46307 .54946 Mdot
.413 .68989 Mdot
.33567 .33019 Mdot
.47837 .52239 Mdot
.66973 .63077 Mdot
.49868 .29614 Mdot
.25236 .70768 Mdot
.19431 .61845 Mdot
.32075 .77609 Mdot
.19912 .47228 Mdot
.42854 .22776 Mdot
.27803 .52318 Mdot
.6602 .32616 Mdot
.65446 .29739 Mdot
.3044 .51873 Mdot
.19884 .45546 Mdot
.5652 .75494 Mdot
.69728 .58624 Mdot
.49951 .57848 Mdot
.28373 .72203 Mdot
.24368 .4965 Mdot
.2871 .50918 Mdot
.73742 .65543 Mdot
.64173 .52558 Mdot
.26236 .38639 Mdot
.67822 .47465 Mdot
.39724 .71878 Mdot
.73586 .36948 Mdot
.64237 .37844 Mdot
.72155 .51194 Mdot
.19081 .46178 Mdot
.37973 .19612 Mdot
.584 .51656 Mdot
.39511 .56277 Mdot
.41229 .80385 Mdot
.43672 .50652 Mdot
.71469 .38387 Mdot
.78301 .64012 Mdot
.6463 .27762 Mdot
.6158 .52259 Mdot
.47153 .5048 Mdot
.50628 .43984 Mdot
.78035 .55689 Mdot
.71192 .56778 Mdot
.52784 .75794 Mdot
.39887 .81514 Mdot
.44622 .47998 Mdot
.62982 .48208 Mdot
.27259 .55839 Mdot
.51031 .40141 Mdot
.55611 .48526 Mdot
.24406 .54153 Mdot
.59907 .49874 Mdot
.42543 .77566 Mdot
.84681 .53057 Mdot
.55797 .61486 Mdot
.25828 .40818 Mdot
.27083 .47139 Mdot
.69477 .63045 Mdot
.57145 .71334 Mdot
.66541 .29377 Mdot
.42562 .6019 Mdot
.39353 .82108 Mdot
.75027 .46437 Mdot
.25881 .53074 Mdot
.53727 .35282 Mdot
.48111 .62882 Mdot
.43766 .70689 Mdot
.33669 .78554 Mdot
.74291 .50729 Mdot
.79352 .71214 Mdot
.21732 .41879 Mdot
.69969 .60319 Mdot
.5782 .75628 Mdot
.1838 .5475 Mdot
.75119 .58052 Mdot
.55484 .46796 Mdot
.4749 .39726 Mdot
.19292 .57851 Mdot
.75099 .50749 Mdot
.73443 .49393 Mdot
.73756 .35279 Mdot
.54433 .84097 Mdot
.58747 .53904 Mdot
.56052 .35097 Mdot
.36526 .30336 Mdot
.43449 .66964 Mdot
.7942 .45871 Mdot
.70659 .32626 Mdot
.53555 .3689 Mdot
.57933 .54595 Mdot
.23541 .72402 Mdot
.45773 .58521 Mdot
.77616 .43807 Mdot
.78424 .71966 Mdot
.8277 .67992 Mdot
.78208 .52798 Mdot
.44087 .83674 Mdot
.72952 .49276 Mdot
.71318 .3873 Mdot
.62852 .38416 Mdot
.37784 .55099 Mdot
.64142 .63646 Mdot
.36418 .80942 Mdot
.40062 .1953 Mdot
.58803 .30335 Mdot
.58225 .60493 Mdot
.36113 .80978 Mdot
.46508 .582 Mdot
.26401 .39817 Mdot
.50916 .27851 Mdot
.18086 .4267 Mdot
.1749 .57449 Mdot
.74856 .65252 Mdot
.18612 .39633 Mdot
.24488 .37439 Mdot
.40395 .40411 Mdot
.19699 .61844 Mdot
.4964 .7093 Mdot
.75345 .63699 Mdot
.20064 .50851 Mdot
.72249 .36752 Mdot
.24605 .27792 Mdot
.56035 .48955 Mdot
.47901 .51277 Mdot
.76944 .54583 Mdot
.70147 .37842 Mdot
.70662 .45254 Mdot
.43929 .51915 Mdot
.3348 .54961 Mdot
.55215 .77115 Mdot
.80111 .37369 Mdot
.79202 .64261 Mdot
.48885 .51194 Mdot
.51618 .82073 Mdot
.64728 .2893 Mdot
.3103 .50888 Mdot
.58888 .72631 Mdot
.25145 .49551 Mdot
.36815 .30701 Mdot
.42744 .60553 Mdot
.40435 .81667 Mdot
.36725 .3082 Mdot
.50297 .82044 Mdot
.18712 .62906 Mdot
.36951 .78947 Mdot
.54378 .52072 Mdot
.35022 .32907 Mdot
.20102 .58063 Mdot
.20368 .58404 Mdot
.55605 .82479 Mdot
.24215 .39337 Mdot
.31345 .52064 Mdot
.45979 .49649 Mdot
.3855 .57159 Mdot
.38632 .71434 Mdot
.18372 .55315 Mdot
.7272 .62491 Mdot
.22615 .57703 Mdot
.79896 .52881 Mdot
.19523 .45932 Mdot
.57104 .74582 Mdot
.25303 .50332 Mdot
.51981 .37359 Mdot
.30102 .37972 Mdot
.41073 .32464 Mdot
.60994 .83279 Mdot
.75087 .35831 Mdot
.23338 .65652 Mdot
.76565 .34647 Mdot
.76928 .48868 Mdot
.22953 .39791 Mdot
.72071 .57485 Mdot
.54227 .64585 Mdot
.39343 .2167 Mdot
.21928 .52593 Mdot
.53107 .76358 Mdot
.72088 .35352 Mdot
.72746 .68518 Mdot
.36553 .80287 Mdot
.22371 .58844 Mdot
.66776 .80905 Mdot
.3142 .33453 Mdot
.64798 .72382 Mdot
.46257 .79956 Mdot
.82348 .43103 Mdot
.2879 .50479 Mdot
.50207 .83213 Mdot
.65663 .57597 Mdot
.42437 .82945 Mdot
.59996 .34179 Mdot
.27912 .3657 Mdot
.71001 .34826 Mdot
.27334 .4952 Mdot
.27568 .49497 Mdot
.23826 .6824 Mdot
.78604 .43748 Mdot
.79651 .47702 Mdot
.51485 .3591 Mdot
.44065 .26615 Mdot
.36978 .57125 Mdot
.6197 .48298 Mdot
.62143 .82428 Mdot
.4507 .68821 Mdot
.30838 .33191 Mdot
.18937 .52265 Mdot
.65786 .32512 Mdot
.48885 .49546 Mdot
.71312 .35876 Mdot
.76978 .65589 Mdot
.24184 .62957 Mdot
.53475 .84176 Mdot
.49003 .49531 Mdot
.40737 .48583 Mdot
.69341 .71297 Mdot
.63497 .43649 Mdot
.64079 .28346 Mdot
.59808 .48214 Mdot
.41911 .52741 Mdot
.30399 .54564 Mdot
.20276 .47118 Mdot
.22222 .69838 Mdot
.532 .8229 Mdot
.64289 .28276 Mdot
.27764 .50374 Mdot
.63618 .51988 Mdot
.22624 .52529 Mdot
.65747 .81611 Mdot
.17441 .39672 Mdot
.76796 .50179 Mdot
.19276 .47229 Mdot
.55171 .38987 Mdot
.26269 .40371 Mdot
.29487 .51331 Mdot
.45987 .79917 Mdot
.57926 .59254 Mdot
.73853 .50737 Mdot
.58403 .42802 Mdot
.29136 .57247 Mdot
.52849 .44962 Mdot
.74774 .64266 Mdot
.78273 .43049 Mdot
.66989 .80764 Mdot
.23286 .38011 Mdot
.6939 .70358 Mdot
.71943 .76856 Mdot
.67894 .50379 Mdot
.51487 .43819 Mdot
.51543 .25863 Mdot
.27039 .51379 Mdot
.48188 .29468 Mdot
.49528 .55209 Mdot
.33429 .53227 Mdot
.78493 .54451 Mdot
.39169 .29894 Mdot
.31333 .37743 Mdot
.72601 .53115 Mdot
.243 .38195 Mdot
.71938 .50878 Mdot
.2204 .69159 Mdot
.62955 .46849 Mdot
.54673 .76968 Mdot
.77449 .66873 Mdot
.41969 .22526 Mdot
.80831 .39296 Mdot
.37827 .79569 Mdot
.26696 .63392 Mdot
.71072 .57053 Mdot
.73254 .53445 Mdot
.68091 .48404 Mdot
.65522 .33546 Mdot
.41875 .80112 Mdot
.18192 .52563 Mdot
.44214 .21524 Mdot
.65636 .56848 Mdot
.46737 .48438 Mdot
.48177 .53094 Mdot
.26767 .72035 Mdot
.461 .27394 Mdot
.4754 .84003 Mdot
.72634 .62931 Mdot
.81922 .45808 Mdot
.61378 .45283 Mdot
.32908 .58639 Mdot
.29874 .4973 Mdot
.41924 .24287 Mdot
.4906 .58029 Mdot
.69353 .60095 Mdot
.66158 .51817 Mdot
.52233 .44694 Mdot
.36741 .37958 Mdot
.33573 .22505 Mdot
.66977 .32767 Mdot
.68984 .64704 Mdot
.17983 .55523 Mdot
.7281 .52155 Mdot
.31541 .33812 Mdot
.40479 .23404 Mdot
.43876 .57782 Mdot
.27678 .65962 Mdot
.58886 .84062 Mdot
.39419 .79528 Mdot
.72038 .54644 Mdot
.79443 .38104 Mdot
.47489 .36144 Mdot
.25028 .70397 Mdot
.75704 .51486 Mdot
.18785 .53918 Mdot
.68201 .68215 Mdot
.30732 .76158 Mdot
.58389 .75311 Mdot
.59515 .46773 Mdot
.19535 .49785 Mdot
.45927 .43599 Mdot
.18889 .47557 Mdot
.76167 .66909 Mdot
.38965 .55408 Mdot
.18279 .4328 Mdot
.54074 .3638 Mdot
.55071 .69554 Mdot
.38492 .69933 Mdot
.60163 .45689 Mdot
.19414 .57332 Mdot
.71227 .5179 Mdot
.35139 .40834 Mdot
.59496 .60775 Mdot
.60376 .29668 Mdot
.40861 .80913 Mdot
.76456 .36457 Mdot
.18676 .51253 Mdot
.39099 .56928 Mdot
.23536 .47285 Mdot
.72063 .625 Mdot
.27796 .62406 Mdot
.51301 .60442 Mdot
.69337 .67101 Mdot
.4255 .44019 Mdot
.25762 .69441 Mdot
.36855 .67411 Mdot
.45709 .81762 Mdot
.30366 .73935 Mdot
.77475 .53411 Mdot
.48528 .45139 Mdot
.67207 .57625 Mdot
.47844 .83501 Mdot
.24408 .64399 Mdot
.7041 .36998 Mdot
.17531 .57183 Mdot
.25717 .37477 Mdot
.73353 .75818 Mdot
.76558 .43697 Mdot
.46863 .5322 Mdot
.19714 .62898 Mdot
.75283 .46946 Mdot
.24859 .3719 Mdot
.52756 .7637 Mdot
.64874 .49934 Mdot
.50442 .83681 Mdot
.52301 .68503 Mdot
.78922 .48297 Mdot
.49368 .79256 Mdot
.60678 .53609 Mdot
.24615 .64823 Mdot
.50362 .5835 Mdot
.42768 .32577 Mdot
.37928 .53134 Mdot
.19041 .38601 Mdot
.59997 .54027 Mdot
.1841 .53968 Mdot
.18965 .54193 Mdot
.24517 .41142 Mdot
.41198 .2456 Mdot
.73537 .75624 Mdot
.58589 .78585 Mdot
.47641 .67568 Mdot
.71619 .55702 Mdot
.3139 .38341 Mdot
.22346 .43117 Mdot
.48389 .61766 Mdot
.30872 .61314 Mdot
.69172 .67955 Mdot
.38028 .81655 Mdot
.52134 .38995 Mdot
.58353 .38928 Mdot
.65162 .56835 Mdot
.704 .37403 Mdot
.75177 .58787 Mdot
.8038 .4523 Mdot
.19412 .569 Mdot
.5845 .51682 Mdot
.59295 .47544 Mdot
.78396 .487 Mdot
.20783 .51501 Mdot
.43579 .39975 Mdot
.60553 .37611 Mdot
.65846 .63141 Mdot
.59396 .82171 Mdot
.77422 .47572 Mdot
.56781 .49541 Mdot
.6974 .47025 Mdot
.40293 .5386 Mdot
.55616 .31977 Mdot
.78809 .44138 Mdot
.72725 .50611 Mdot
.42613 .78014 Mdot
.61018 .50955 Mdot
.34396 .32996 Mdot
.21151 .43536 Mdot
.66203 .46591 Mdot
.18671 .55158 Mdot
.46029 .577 Mdot
.4724 .81063 Mdot
.25965 .52832 Mdot
.34957 .41126 Mdot
.49897 .59995 Mdot
.61111 .58311 Mdot
.33532 .78515 Mdot
.75978 .50239 Mdot
.57067 .55402 Mdot
.7378 .51821 Mdot
.18641 .60897 Mdot
.37116 .34281 Mdot
.49716 .30605 Mdot
.32562 .444 Mdot
.3304 .58242 Mdot
.39766 .50419 Mdot
.65609 .33333 Mdot
.4786 .58113 Mdot
.42353 .40895 Mdot
.40839 .54012 Mdot
.66304 .63363 Mdot
.21643 .63504 Mdot
.60711 .83105 Mdot
.61146 .56086 Mdot
.17098 .57457 Mdot
.59792 .58372 Mdot
.61996 .52502 Mdot
.23648 .37747 Mdot
.56476 .56647 Mdot
.45996 .57162 Mdot
.35779 .40592 Mdot
.66847 .50586 Mdot
.60372 .82852 Mdot
.58161 .53893 Mdot
.32439 .41709 Mdot
.50425 .35624 Mdot
.55465 .48794 Mdot
.58117 .19397 Mdot
.66822 .30774 Mdot
.18982 .62199 Mdot
.19781 .51327 Mdot
.66042 .37349 Mdot
.73289 .49529 Mdot
.56814 .56655 Mdot
.47019 .81274 Mdot
.43565 .4404 Mdot
.39059 .79967 Mdot
.55098 .36096 Mdot
.67941 .64967 Mdot
.29989 .73449 Mdot
.24653 .59475 Mdot
.27354 .62091 Mdot
.71904 .66592 Mdot
.38212 .74498 Mdot
.52603 .49836 Mdot
.36133 .21355 Mdot
.22932 .30227 Mdot
.63778 .82307 Mdot
.82001 .46219 Mdot
.4631 .70683 Mdot
.22677 .53084 Mdot
.62089 .49689 Mdot
.31678 .51079 Mdot
.49996 .36986 Mdot
.33016 .33252 Mdot
.55125 .37849 Mdot
.78924 .36437 Mdot
.3924 .81964 Mdot
.49625 .59826 Mdot
.39534 .45614 Mdot
.39222 .39491 Mdot
.47691 .27702 Mdot
.56469 .65912 Mdot
.58659 .83946 Mdot
.61278 .37802 Mdot
.51695 .24771 Mdot
.66327 .33833 Mdot
.24129 .68295 Mdot
.48106 .23409 Mdot
.59884 .32472 Mdot
.21862 .69054 Mdot
.80049 .51636 Mdot
.74338 .67982 Mdot
.76988 .34461 Mdot
.26886 .70905 Mdot
.69102 .66831 Mdot
.34017 .33846 Mdot
.43012 .82332 Mdot
.29663 .49952 Mdot
.38027 .29783 Mdot
.39518 .75679 Mdot
.19339 .49202 Mdot
.21512 .42483 Mdot
.61548 .4093 Mdot
.58548 .59284 Mdot
.34824 .19937 Mdot
.42692 .21799 Mdot
.8593 .51481 Mdot
.39376 .79317 Mdot
.62611 .79292 Mdot
.75958 .50825 Mdot
.52015 .35948 Mdot
.46395 .8108 Mdot
.19331 .5512 Mdot
.57992 .57481 Mdot
.38238 .20673 Mdot
.24703 .57371 Mdot
.23367 .51186 Mdot
.55298 .3388 Mdot
.33472 .7786 Mdot
.41755 .23631 Mdot
.48161 .71961 Mdot
.19222 .50994 Mdot
.60594 .58598 Mdot
.2866 .62607 Mdot
.58543 .82216 Mdot
.26976 .65808 Mdot
.19945 .4414 Mdot
.54906 .37424 Mdot
.46355 .34998 Mdot
.6034 .8243 Mdot
.72543 .60019 Mdot
.68173 .68907 Mdot
.78666 .71715 Mdot
.45475 .83413 Mdot
.56541 .57456 Mdot
.39388 .61958 Mdot
.20682 .66444 Mdot
.40824 .34969 Mdot
.22722 .64487 Mdot
.81876 .57024 Mdot
.21766 .41156 Mdot
.36722 .65376 Mdot
.4494 .60193 Mdot
.27068 .45205 Mdot
.77008 .53466 Mdot
.58562 .58249 Mdot
.45167 .23508 Mdot
.19996 .45422 Mdot
.69312 .64548 Mdot
.84654 .53097 Mdot
.76426 .66289 Mdot
.68099 .57105 Mdot
.41557 .8211 Mdot
.51561 .7079 Mdot
.70456 .62943 Mdot
.45977 .80361 Mdot
.42232 .46016 Mdot
.42614 .40582 Mdot
.71774 .62409 Mdot
.27825 .52045 Mdot
.19135 .38111 Mdot
.71458 .77404 Mdot
.65037 .64127 Mdot
.48254 .84105 Mdot
.29099 .758 Mdot
.67412 .57228 Mdot
.57039 .61827 Mdot
.29104 .48997 Mdot
.59703 .51968 Mdot
.59281 .42363 Mdot
.43806 .22494 Mdot
.26027 .36765 Mdot
.32548 .23782 Mdot
.4441 .61122 Mdot
.54789 .35466 Mdot
.36966 .80271 Mdot
.26668 .38754 Mdot
.37978 .80649 Mdot
.70515 .657 Mdot
.46861 .67822 Mdot
.83055 .6761 Mdot
.71117 .38667 Mdot
.41955 .57374 Mdot
.48483 .68645 Mdot
.47105 .70273 Mdot
.42069 .60728 Mdot
.59465 .41821 Mdot
.26126 .47873 Mdot
.20918 .40896 Mdot
.42985 .8201 Mdot
.64588 .55747 Mdot
.29525 .49663 Mdot
.59042 .3769 Mdot
.30693 .58472 Mdot
.40866 .7423 Mdot
.64395 .38037 Mdot
.20761 .39588 Mdot
.57849 .19454 Mdot
.46446 .39135 Mdot
.53226 .4529 Mdot
.32978 .5541 Mdot
.51418 .47502 Mdot
.22405 .38615 Mdot
.64741 .32921 Mdot
.40561 .40099 Mdot
.18756 .50792 Mdot
.72016 .67425 Mdot
.55641 .33385 Mdot
.30074 .22444 Mdot
.29062 .50719 Mdot
.54595 .35957 Mdot
.55813 .60686 Mdot
.7729 .64035 Mdot
.42508 .78735 Mdot
.43903 .38783 Mdot
.5261 .48987 Mdot
.6872 .71545 Mdot
.45016 .81106 Mdot
.64342 .34598 Mdot
.23018 .70886 Mdot
.5551 .60368 Mdot
.56768 .6579 Mdot
.58344 .80396 Mdot
.47935 .49543 Mdot
.53605 .76008 Mdot
.46731 .6987 Mdot
.38778 .49797 Mdot
.54939 .18414 Mdot
.48922 .50529 Mdot
.5493 .48201 Mdot
.58867 .506 Mdot
.25545 .40898 Mdot
.4641 .76149 Mdot
.42187 .65204 Mdot
.36057 .3512 Mdot
.27019 .53564 Mdot
.28684 .36208 Mdot
.28913 .35325 Mdot
.56127 .33252 Mdot
.22213 .38849 Mdot
.21759 .41971 Mdot
.5035 .78639 Mdot
.47993 .8224 Mdot
.38212 .69552 Mdot
.38863 .79144 Mdot
.49239 .39764 Mdot
.71513 .45359 Mdot
.27368 .65732 Mdot
.70868 .77807 Mdot
.68705 .59773 Mdot
.43694 .72261 Mdot
.27324 .73808 Mdot
.35882 .79279 Mdot
.6143 .29656 Mdot
.72666 .36054 Mdot
.2098 .32972 Mdot
.27983 .48966 Mdot
.79502 .36884 Mdot
.4804 .24419 Mdot
.26545 .72432 Mdot
.41347 .54443 Mdot
.56209 .57902 Mdot
.73124 .64359 Mdot
.44416 .57329 Mdot
.45418 .28232 Mdot
.78201 .64005 Mdot
.72104 .66614 Mdot
.37929 .74225 Mdot
.45777 .69601 Mdot
.56167 .43617 Mdot
.63946 .5141 Mdot
.6445 .81889 Mdot
.48336 .30903 Mdot
.40853 .48248 Mdot
.8384 .55044 Mdot
.55831 .18605 Mdot
.25269 .36753 Mdot
.54782 .82377 Mdot
.66055 .30015 Mdot
.41311 .53487 Mdot
.67997 .25727 Mdot
.62691 .54705 Mdot
.7156 .5603 Mdot
.6699 .33183 Mdot
.23891 .47541 Mdot
.78236 .44688 Mdot
.75588 .74315 Mdot
.30261 .75836 Mdot
.45162 .57702 Mdot
.8693 .47071 Mdot
.19138 .51486 Mdot
.39932 .46905 Mdot
.77638 .4335 Mdot
.40144 .81447 Mdot
.55594 .38828 Mdot
.19799 .63979 Mdot
.64721 .47069 Mdot
.60903 .5264 Mdot
.2398 .49515 Mdot
.7667 .35023 Mdot
.46931 .48807 Mdot
.8574 .50905 Mdot
.73904 .36652 Mdot
.23724 .51993 Mdot
.75099 .49842 Mdot
.61922 .54645 Mdot
.67004 .59843 Mdot
.63724 .4572 Mdot
.57037 .53821 Mdot
.56948 .49566 Mdot
.60002 .47566 Mdot
.44089 .39956 Mdot
.5926 .44609 Mdot
.7047 .38715 Mdot
.64155 .31324 Mdot
.74297 .65872 Mdot
.19609 .35513 Mdot
.30107 .34283 Mdot
.46439 .26613 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0[oooool2o`0009Sooooo000Looooo`03o`000?oooooo
oooo0:[ooooo1?l000001?oooooo0000o`000?ooool2o`0009Gooooo000Looooo`03o`000?oooooo
oooo0:Kooooo0_l00002ooooo`Co00001?ooool2o`0009Gooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`2Vooooo`;o0000XOoo
ool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A006ooooo`03o`000?oooooooooo07Sooooo0_l00004ooooo`;o0000>?ooool3o`0008ko
oooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h0
1oooool00ol0003oooooooooo`1]ooooo`;o00002Oooool4o`0000;ooooo0_l0000hooooo`?o0000
3?ooool3o`0007oooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o
V9RHob4Q8Oo^k^h01_ooool3o`0006gooooo0_l0000;ooooo`;o0000:?ooool2o`0001Oooooo0_l0
0008ooooo`Co0000O_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool0
0omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo077ooooo0_l0000aooooo`;o00005oooool2
o`0000?ooooo0_l00005ooooo`;o0000O_ooool00003ooooool@413ooooo00;ooooo00?o410@oooo
ooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo0_l000000ooo
oooo0000o`000002ooooo`?o00004oooool2o`0003;ooooo0_l00025ooooo`0000KoooooogMgMonH
V9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003ooooooooo
o`1Pooooo`;o00003oooool2o`000003ooooool0003o000000;ooooo0ol0000Aooooo`Co0000^Ooo
ool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Ko
oooo00?o0000ooooooooool0H?ooool2o`0000cooooo0_l000001?oooooo0000o`000?l0000;oooo
o`;o00002oooool4o`0003kooooo0_l0001iooooo`007?ooool00ol0003oooooooooo`1[ooooo`Go
00000_ooool2o`0000Sooooo0_l000000ooooooo0000o`000006ooooo`;o00000oooool4o`0003ko
oooo0_l0001iooooo`007?ooool00ol0003oooooooooo`1[ooooo`Co00003Oooool2o`0000Wooooo
0_l00005ooooo`?o0000?Oooool3o`0007Sooooo000Looooo`03o`000?oooooooooo05kooooo0_l0
0009ooooo`;o00008oooool5o`0003cooooo0ol0001gooooo`007?ooool00ol0003oooooooooo`1N
ooooo`?o00002?ooool2o`0001[ooooo1?l00002ooooo`;o00000_ooool4o`0003gooooo0ol0001f
ooooo`007?ooool00ol0003oooooooooo`1Oooooo`;o00002?ooool2o`0001[ooooo1?l00002oooo
o`;o0000A?ooool2o`0007Kooooo000Looooo`03o`000?oooooooooo06Kooooo0ol0000<ooooo`?o
00003?ooool2o`0000;ooooo0_l0000>ooooo`;o00002Oooool2o`0002Wooooo0_l00002ooooo`;o
0000MOooool001cooooo00?o0000ooooooooool0I_ooool3o`0000cooooo0ol00008ooooo`;o0000
0_ooool6o`0000Gooooo0_l00002ooooo`;o00000oooool3o`0000Sooooo0_l0000Yooooo`;o0000
0_ooool2o`0007Gooooo000Looooo`03o`000?oooooooooo05Oooooo0_l0000=ooooo`;o00001_oo
ool2o`00013ooooo0_l00002ooooo`Go00001_ooool2o`0000;ooooo0_l000000ooooooo0000o`00
0003o`000:kooooo000Looooo`03o`000?oooooooooo05Oooooo0_l0000=ooooo`?o00001Oooool2
o`0001Cooooo1?l00002ooooo`;o00002Oooool7o`0003Wooooo0_l0001booooo`007?ooool00ol0
003oooooooooo`1Wooooo`;o00006Oooool4o`0000Cooooo0_l00006ooooo`co0000=oooool2o`00
07;ooooo000Looooo`03o`000?oooooooooo08;ooooo0_l0000>ooooo`Wo000000?oooooo`000?l0
00001_ooool2o`0002gooooo0_l0001dooooo`007?ooool2o`0005Kooooo0_l0000cooooo`Go0000
1oooool2o`000003ooooool0003o000000Wooooo0_l0000]ooooo`;o00000_ooool2o`00073ooooo
000Looooo`03o`000?oooooooooo05Gooooo0_l0000cooooo`Go00001Oooool7o`0003cooooo0_l0
001`ooooo`007?ooool00ol0003oooooooooo`2;ooooo`Co00001Oooool8o`0000;ooooo0_l0000i
ooooo`;o0000K_ooool001cooooo00?o0000ooooooooool0Roooool4o`0000?ooooo2_l00002oooo
o`?o00000oooool2o`0003?ooooo0_l0001^ooooo`007?ooool00ol0003oooooooooo`2@ooooo`_o
00001?ooool2o`000003ooooool0003o000000;o0000Xoooool001cooooo00?o0000ooooooooool0
Roooool2o`0000?ooooo2ol00007ooooo`?o0000Y?ooool001cooooo00?o0000ooooooooool0Q?oo
ool2o`0000Gooooo4?l00006ooooo`;o0000=_ooool2o`0006kooooo000Looooo`03o`000?oooooo
oooo08Cooooo0_l00002ooooo`So000000?oooooo`000?l000002Ol00005ooooo`;o0000=_ooool2
o`000003ooooool0003o000006_ooooo000Looooo`03o`000?oooooooooo08Cooooo6?l00005oooo
o`;o0000=oooool4o`0006_ooooo000Looooo`03o`000?oooooooooo04cooooo0_l0000goooooaSo
00001?ooool3o`0002[ooooo0_l0000:ooooo`;o0000KOooool001cooooo00?o0000ooooooooool0
C?ooool2o`0003Oooooo6?l00005ooooo`;o00009_ooool2o`000004ooooool0003o0000o`0000go
oooo0_l0001Zooooo`007?ooool00ol0003oooooooooo`24oooooaGo000000Coooooo`000?l0003o
0000:Oooool2o`0000;ooooo1Ol00007ooooo`;o00001Oooool2o`0006[ooooo000Looooo`03o`00
0?oooooooooo08Cooooo6Ol0000Yooooo`;o00001?ooool4o`0000Kooooo0_l00004ooooo`;o0000
Joooool001cooooo00?o0000ooooooooool0P_oooolJo`0002kooooo1_l00006ooooo`;o00001?oo
ool2o`000003ooooool0003o000006Sooooo000Looooo`03o`000?oooooooooo08;ooooo6ol0000]
ooooo`?o00001oooool6o`0000Gooooo0_l0001Xooooo`007?ooool00ol0003oooooooooo`1doooo
o`;o00000_ooool2o`0000Sooooo5?l000000ooooooo0000o`000004o`000003ooooool0003o0000
023ooooo0_l00002ooooo`;o00002oooool2o`000004ooooool0003o0000ooooo`?o0000Koooool0
01cooooo0_l0001eooooo`;o00000_ooool5o`0000?ooooo7Ol000001?oooooo0000o`000?l0000G
ooooo`?o00001Oooool2o`0000;ooooo0_l00003ooooo`;o00001_ooool4o`0000;ooooo0_l0001`
ooooo`007?ooool00ol0003oooooooooo`17ooooo`;o0000:_ooool2o`0000?ooooo1Ol00002oooo
oa[o000000?oooooo`000?l000000_ooool3o`0001Oooooo1ol0000:ooooo`?o00001oooool2o`00
00_ooooo0_l0001Wooooo`007?ooool00ol0003oooooooooo`17ooooo`;o0000:_ooool3o`0000;o
oooo0ol00003oooooago00000oooool2o`0001[ooooo1Ol00008ooooo`;o000000?oooooo`000?l0
00001oooool4o`0000?ooooo0_l00004ooooo`;o0000Ioooool001cooooo00?o0000ooooooooool0
AOooool2o`0002gooooo0_l00002ooooo`;o00001?ooool2o`000003ooooool0003o000001[o0000
00?oooooo`000?l000006_ooool2o`0000_ooooo0_l0000:ooooo`Co00000oooool2o`0000Gooooo
0_l0001Vooooo`007?ooool00ol0003oooooooooo`15ooooo`;o0000;Oooool2o`0000;ooooo0_l0
0006oooooago00005_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000Aooooo`;o00002Ooo
ool4o`0000Gooooo0_l0001Vooooo`007?ooool00ol0003oooooooooo`1kooooo`;o00000_oooolL
o`0001Sooooo0_l00002ooooo`?o00000oooool2o`0000kooooo0_l00009ooooo`Co00001Oooool3
o`0006Gooooo000Looooo`03o`000?oooooooooo04?ooooo0_l0000fooooo`;o00000_oooolIo`00
01Wooooo0_l00005ooooo`;o000000?oooooo`000?l000000_l00005ooooo`;o00005?ooool2o`00
00Kooooo0_l0001Uooooo`007?ooool00ol0003oooooooooo`13ooooo`;o0000>ooooolIo`0001So
oooo0_l00007ooooo`?o00001oooool2o`00013ooooo0_l00002ooooo`;o00001oooool2o`0002Ko
oooo0_l0000looooo`007?ooool00ol0003oooooooooo`11ooooo`;o0000>ooooolDo`000003oooo
ool0003o000000Co00008Oooool2o`0000;ooooo0ol0000Aooooo`?o000000?oooooo`000?l00000
1Ol000000ooooooo0000o`000002ooooo`?o00009_ooool2o`0003cooooo000Looooo`03o`000?oo
oooooooo047ooooo0_l0000Yooooo`Co00000oooool2o`0000Wooooo4ol00002ooooo`Go00008ooo
ool2o`000003ooooool0003o000000Ko00000_ooool3o`0000Cooooo0_l000001Ooooooo0000o`00
0?l0003ooooo00Oo000000Coooooo`000?l0003ooooo0ol0000Wooooo`;o0000??ooool001cooooo
00?o0000ooooooooool0@?ooool2o`0001kooooo0_l00007ooooo`;o000000?oooooo`000?l00000
0_l00003ooooo`;o00002Oooool3o`000003ooooool0003o000001Co00004oooool2o`000003oooo
ool0003o000000Sooooo0_l000001Ooooooo0000o`000?l0003ooooo00ko00000_ooool2o`0000Go
oooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000?o00002_ooool2o`0005Oo
oooo000Looooo`03o`000?oooooooooo043ooooo0_l0000Nooooo`Co00001?ooool3o`000003oooo
ool0003o0000013ooooo5ol0000Fooooo`;o000000Coooooo`000?l0003ooooo1?l000000ooooooo
0000o`000003o`000003ooooool0003o000000oo000000Coooooo`000?l0003ooooo0_l00003oooo
o`;o00000_ooool2o`0000;ooooo0_l00002ooooo`Co00002_ooool2o`0005Oooooo000Looooo`03
o`000?oooooooooo06;ooooo0ol00003ooooo`;o000000?oooooo`000?l000000_l00006ooooo`;o
00000oooool2o`0000?ooooo1Ol000000ooooooo0000o`00000?o`0001?ooooo1_l00002ooooo`Co
000000?oooooo`000?l000001?l000000ooooooo0000o`00000Ao`000004ooooool0003o0000oooo
o`;o000000?oooooo`000?l000000_l00007ooooo`;o0000IOooool001cooooo00?o0000oooooooo
ool0Hoooool2o`0000Kooooo1?l000001?oooooo0000o`000?ooool6o`000004ooooool0003o0000
ooooo`Co00000_ooool<o`000003ooooool0003o000000Co00004Oooool8o`000003ooooool0003o
000000;ooooo0_l00004oooooaKo00001?ooool2o`000003ooooool0003o000000;o00000_ooool2
o`000003ooooool0003o000000Co00002Oooool2o`0005Sooooo000Looooo`03o`000?oooooooooo
05kooooo0_l00007ooooo`;o00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000004o`00
0004ooooool0003o0000ooooo`;o000000Coooooo`000?l0003ooooo0ol000000ooooooo0000o`00
0008o`0001Gooooo0ol00007ooooo`;o00000_ooool2o`000004ooooool0003o0000oooooaOo0000
00?oooooo`000?l000001?ooool3o`0000;ooooo0_l000001?oooooo0000o`000?ooool3o`0000Wo
oooo0_l00005ooooo`;o0000DOooool001cooooo00?o0000ooooooooool0?Oooool2o`0001oooooo
0_l00005ooooo`Co00003?ooool2o`0000?ooooo0_l00004ooooo`;o00000oooool2o`0000;ooooo
0_l00004ooooo`;o00004?ooool2o`0000;ooooo0ol0000?ooooo`Oo000000?oooooo`000?l00000
4?l000000ooooooo0000o`000003ooooo`Co00002?ooool2o`0000Oooooo0_l00007ooooo`Go0000
Coooool001cooooo0_l0000nooooo`;o00009_ooool5o`0000Cooooo1Ol00007ooooo`;o00001Ooo
ool2o`0000;ooooo0_l0000<ooooo`;o00003?ooool2o`0000;ooooo0_l0000;ooooo`;o00000ooo
oolKo`0000Gooooo1?l00008ooooo`Co00001?ooool3o`0000Oooooo1Ol0001?ooooo`007?ooool0
0ol0003oooooooooo`0kooooo`;o00007Oooool2o`0000_ooooo0ol00002ooooo`Oo00003_ooool2
o`0000gooooo0_l000000ooooooo0000o`00000Fooooo`;o00001Oooool2o`000003ooooool0003o
000001go00001?ooool2o`0000Wooooo1ol000001?oooooo0000o`000?l00007ooooo`Co0000D?oo
ool001cooooo00?o0000ooooooooool0>_ooool4o`0001cooooo0_l0000;ooooo`Co000000Cooooo
o`000?l0003ooooo1?l00003ooooo`?o00001?ooool2o`00017ooooo0ol0000<ooooo`?o00002Ooo
ool2o`000003ooooool0003o000000Gooooo6ol000001?oooooo0000o`000?l00003ooooo`?o0000
2oooool5o`0000;ooooo0_l00004ooooo`;o0000EOooool001cooooo00?o0000ooooooooool0>_oo
ool4o`0001Gooooo0_l0000Dooooo`[o000000?oooooo`000?l000000ol00004ooooo`;o00004_oo
ool3o`0000_ooooo0ol000000ooooooo0000o`000002o`0000Oooooo0_l00005oooooa_o000000Co
ooooo`000?l0003o00000oooool3o`0000[ooooo1Ol00007ooooo`Co00007_ooool2o`0003Gooooo
000Looooo`03o`000?oooooooooo05?ooooo0_l00004ooooo`;o00000_ooool2o`0000Kooooo0_l0
00000ooooooo0000o`00000?o`0000Cooooo0_l0000Cooooo`?o00000_ooool2o`0000?ooooo0_l0
0005ooooo`Co00001oooool6o`0000?ooooo4_l000000ooooooo0000o`000008o`0000?ooooo0_l0
000;ooooo`;o00000_ooool2o`0000Kooooo0_l00003ooooo`;o00006oooool2o`0003Gooooo000L
ooooo`03o`000?oooooooooo05Oooooo1?l00002ooooo`;o00001?oooolFo`0000Cooooo0_l0000D
ooooo`;o00000_ooool2o`0000?ooooo0_l0000>ooooo`;o000000?oooooo`000?l000000ol00000
0ooooooo0000o`00000Ko`0000Gooooo0_l0000?ooooo`;o00002oooool2o`0000Kooooo0_l0001:
ooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o000000?oooooo`000?l000001?ooool2o`00
0003ooooool0003o000000Oooooo6?l0000Qooooo`;o00003?ooool4o`000003ooooool0003o0000
00Cooooo7Ol00002ooooo`Go00003_ooool2o`0000?ooooo0_l00007ooooo`;o00001_ooool4o`00
04Sooooo000Looooo`03o`000?oooooooooo04gooooo0ol000000ooooooo0000o`000006ooooo`?o
00001_ooool:o`000003ooooool0003o000000So000000Coooooo`000?l0003o00008?ooool6o`00
00Wooooo0_l00005ooooo`;o00000_oooolLo`0000?ooooo1?l00009ooooo`;o00001?ooool2o`00
00;ooooo0ol00002ooooo`;o00001_ooool2o`000004ooooool0003o0000ooooo`?o00004_ooool2
o`0003Cooooo000Looooo`03o`000?oooooooooo04cooooo0ol000000ooooooo0000o`000007oooo
o`;o00001_oooolIo`0000;ooooo0_l0000Hooooo`_o00001?ooool2o`0000Sooooo1?l00002oooo
oaco00000_ooool4o`0000[ooooo0_l00007ooooo`?o00000oooool2o`0000Kooooo0_l000000ooo
oooo0000o`000003ooooo`;o00004Oooool2o`0003Cooooo000Looooo`03o`000?oooooooooo03So
oooo0_l0000?ooooo`;o000000?oooooo`000?l000000_ooool2o`0000kooooo7_l0000Eooooo`;o
000000?oooooo`000?l000001?l00009ooooo`;o00002?ooool3o`0000Gooooo0ol000000ooooooo
0000o`00000Ho`0000_ooooo0ol00007ooooo`;o00005?ooool2o`00017ooooo0_l0000dooooo`00
7?ooool00ol0003oooooooooo`0gooooo`Go00003?ooool3o`0001?ooooo8_l0000Cooooo`;o0000
00Coooooo`000?l0003ooooo0ol0000Cooooo`;o00001_ooool3o`0000;ooooo0_l00002oooooaGo
00002oooool2o`0001_ooooo1_l0000@ooooo`;o0000=?ooool001cooooo00?o0000ooooooooool0
=oooool2o`000003ooooool0003o000000cooooo0_l000000ooooooo0000o`00000Aoooooa_o0000
0oooool4o`00013ooooo0_l00004ooooo`;o00007oooool2o`0000cooooo2_l00004ooooo`;o0000
3oooool2o`0000Kooooo0_l0000?ooooo`Ko00004?ooool2o`0003Cooooo000Looooo`03o`000?oo
oooooooo03[ooooo0_l00009ooooo`;o00001?ooool4o`0000?ooooo0ol00002ooooo`;o00002Ooo
oolGo`0000?ooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo2?l00002ooooo`;o0000
0_ooool2o`00027ooooo0_l0000?ooooo`;o000000?oooooo`000?l000000_l0000=ooooo`;o0000
0oooool5o`0000?ooooo0_l000000ooooooo0000o`00000Uooooo`;o0000=?ooool001cooooo00?o
0000ooooooooool0>_ooool5o`0000Gooooo0ol00006ooooo`;o00000oooool3o`0000;ooooo0_l0
0009oooooaKo00001?ooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool8o`000004oooo
ool0003o0000o`0000;ooooo0_l0000@ooooo`;o00001oooool4o`0000Cooooo0_l000000ooooooo
0000o`00000@ooooo`?o00003Oooool2o`0000?ooooo1Ol00003ooooo`;o0000:?ooool2o`0003Co
oooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@oooo
ooooool01?ooool00ol0003oooooooooo`0eooooo`;o00001?ooool4o`0000Gooooo0_l00005oooo
o`;o00004Oooool2o`000003ooooool0003o000001Go00001?ooool2o`0000?ooooo1?l00004oooo
o`Co00000_ooool2o`000004ooooool0003o0000o`00017ooooo0_l00007ooooo`Ko00000_ooool2
o`000003ooooool0003o000000_ooooo2?l0000=ooooo`?o00009?ooool2o`0000kooooo0_l0000d
ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo03Gooooo0_l00002ooooo`;o00001Oooool2o`0000Wooooo0_l0
000Aooooo`;o000000?oooooo`000?l000004ol00006ooooo`?o00000_ooool4o`0000Cooooo1?l0
0005ooooo`?o00006oooool5o`00013ooooo2?l0000@ooooo`?o00000_ooool4o`0001gooooo1?l0
000<ooooo`;o0000=?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool5
o`0000Kooooo00?o0000ooooooooool0=Oooool2o`0000;ooooo0_l00005ooooo`;o00001Oooool2
o`0000Wooooo0_l0000:oooooaOo00001Oooool5o`0000Cooooo0_l00004ooooo`Co00002_ooool2
o`0000?ooooo0_l0000Dooooo`;o00003_ooool2o`000004ooooool0003o0000o`0001Gooooo0ol0
0002ooooo`Co00007oooool2o`0000cooooo0_l0000dooooo`0000?oooooo`000?ooool00_ooool0
0ol0003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0000eooooo`;o00004?oo
ool2o`0000Wooooo0_l0000:oooooaKo00001_ooool2o`000004ooooool0003o0000ooooo`;o0000
2?ooool3o`0000Oooooo0_l000000ooooooo0000o`000003ooooo`;o00001?ooool2o`0000Cooooo
0_l00008ooooo`?o00003Oooool2o`0004oooooo0_l0000dooooo`0000?oooooo`000?ooool00_oo
ool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0
B?ooool2o`0000Sooooo0_l0000:oooooaGo00000_ooool3o`0000Oooooo0ol00005ooooo`;o0000
2oooool2o`0000cooooo0_l00004ooooo`;o00002?ooool3o`0000oooooo0_l0001=ooooo`;o0000
=?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00omgMgOoc<c<o`00
0007ooooo`03o`000?oooooooooo03Cooooo0_l0000:ooooo`;o00001_ooool2o`0000Gooooo1Ol0
000;ooooo`;o000000?oooooo`000?l000003_l00003ooooo`?o00001oooool2o`0000Gooooo0ol0
000_ooooo`;o00002_ooool2o`0000cooooo0_l0000oooooo`;o0000=?ooool00006oooooomgMgOo
V9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo03Cooooo
1?l00008ooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o000000Coooooo`000?l0
003o00003Oooool2o`000003ooooool0003o000000Oo00000oooool2o`0000Gooooo1?l0000=oooo
o`;o0000;oooool3o`0000[ooooo0_l0000<ooooo`;o0000MOooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo03Cooooo1?l00000
0ooooooo0000o`000005ooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o00003_oo
ool2o`0000[ooooo0ol00003ooooo`;o00001Oooool4o`00017ooooo0_l0000;ooooo`;o00007_oo
ool6o`0008cooooo000Looooo`03o`000?oooooooooo03Wooooo0ol00004ooooo`?o00004Oooool2
o`0000Kooooo0_l00002ooooo`;o00001?ooool2o`0000gooooo0_l0000Cooooo`;o00002oooool2
o`00023ooooo1_l0002:ooooo`007?ooool00ol0003oooooooooo`0hooooo`Co00001Oooool4o`00
00oooooo0ol00009ooooo`?o00000oooool2o`0000gooooo0_l00003ooooo`;o00006oooool2o`00
02Cooooo1?l00003ooooo`?o0000C?ooool3o`0003?ooooo000Looooo`03o`000?oooooooooo03So
oooo0ol00007ooooo`?o00004?ooool2o`0000Oooooo0_l000000ooooooo0000o`00000Gooooo`;o
00006?ooool2o`000003ooooool0003o000001oooooo0_l00003ooooo`Co00000oooool3o`0004co
oooo0ol0000cooooo`007?ooool00ol0003oooooooooo`0gooooo`;o000000?oooooo`000?l00000
1_ooool2o`00017ooooo0_l00007ooooo`?o0000<oooool2o`0002;ooooo0_l00003ooooo`;o0000
1Oooool3o`0008;ooooo000Looooo`03o`000?oooooooooo03Kooooo1_l00008ooooo`;o00003ooo
ool2o`0000Oooooo0ol000000ooooooo0000o`00001Fooooo`;o00001Oooool6o`0002kooooo0_l0
0003ooooo`;o00003?ooool2o`0003oooooo000Looooo`03o`000?oooooooooo03Kooooo1?l0000:
ooooo`?o00003_ooool2o`0000Sooooo0_l000000ooooooo0000o`00001Fooooo`;o00001Oooool3
o`0000;ooooo0_l00004ooooo`;o00009oooool2o`000003ooooool0003o000000;o00003?ooool2
o`0003oooooo000Looooo`03o`000?oooooooooo03Sooooo0_l000000ooooooo0000o`000004oooo
o`;o00000_ooool3o`0001Wooooo0_l0000^ooooo`;o00008?ooool2o`0000_ooooo0ol00003oooo
o`;o00000_ooool4o`0002?ooooo0_l00002ooooo`Ko00001Oooool2o`0000Kooooo0_l0000ooooo
o`007?ooool00ol0003oooooooooo`0kooooo`;o00001?ooool2o`0000?ooooo0_l0000Iooooo`;o
00002_ooool4o`0000kooooo0_l00005ooooo`Co00001Oooool4o`000003ooooool0003o000000_o
oooo1?l0000>ooooo`;o00002oooool3o`0000Oooooo0ol0000Tooooo`;o00000_ooool5o`0000;o
oooo0ol000001?oooooo0000o`000?l0000@ooooo`;o0000=?ooool001cooooo00?o0000oooooooo
ool0?Oooool2o`0000Kooooo0_l0000?ooooo`;o00003_ooool2o`0000Gooooo1Ol0000<ooooo`?o
000000?oooooo`000?l000000_ooool8o`000003ooooool0003o000000Ko00002_ooool4o`0004go
oooo0_l00004ooooo`;o00000_ooool3o`0000;ooooo0_l0000@ooooo`;o0000=?ooool001cooooo
00?o0000ooooooooool0??ooool3o`0000Gooooo0ol0000;ooooo`;o00000_ooool2o`0000kooooo
0_l00008ooooo`;o00000oooool2o`0000Cooooo0_l000000ooooooo0000o`000004o`0000;ooooo
0_l00002ooooo`Co00000oooool:o`0000Wooooo0ol0000Fooooo`;o0000<oooool2o`0000Sooooo
0_l0000Eooooo`;o0000=?ooool001cooooo00?o0000ooooooooool0??ooool2o`0000;ooooo0_l0
0002ooooo`;o00003?ooool3o`00017ooooo0_l00004ooooo`?o000000?oooooo`000?l000000ooo
ool2o`0000?ooooo1Ol000000ooooooo0000o`000004ooooo`;o00002Oooool2o`000004ooooool0
003o0000ooooo`So00001Oooool4o`0000?ooooo0_l0000@ooooo`;o0000>oooool2o`0000;ooooo
1_l00015ooooo`007?ooool2o`0003gooooo0_l00002ooooo`;o000000?oooooo`000?l000003Ooo
ool4o`0001Kooooo0ol000000ooooooo0000o`000003ooooo`;o00000oooool2o`000003ooooool0
003o000001_ooooo1Ol00007ooooo`Co000000?oooooo`000?l00000=?ooool3o`0001Kooooo0_l0
0002ooooo`Ko0000AOooool001cooooo00?o0000ooooooooool0?Oooool2o`0000Cooooo0_l0000?
ooooo`;o00007oooool2o`0002?ooooo1Ol000000ooooooo0000o`000006ooooo`?o00005Oooool2
o`0000;ooooo0_l0000Kooooo`Go00001Oooool2o`000003ooooool0003o000000gooooo0_l00002
ooooo`?o00004?ooool2o`0003?ooooo000Looooo`03o`000?oooooooooo03gooooo0_l00004oooo
o`;o00003oooool2o`00023ooooo0_l00005ooooo`Co00006oooool2o`0000;ooooo0_l00007oooo
o`;o00005Oooool2o`0000;ooooo0_l00005ooooo`;o00005oooool2o`0000Gooooo0_l000000ooo
oooo0000o`00000=ooooo`Co00001Oooool2o`0000cooooo0_l0000cooooo`007?ooool00ol0003o
ooooooooo`0jooooo`Co00000oooool4o`0000gooooo1?l0000Nooooo`Co00001Oooool4o`0000Co
oooo0_l0000Hooooo`Ko00001?ooool2o`0001Gooooo0_l00009ooooo`;o0000<Oooool3o`000003
ooooool0003o000000;ooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0jooooo`Co0000
0oooool3o`0000kooooo1?l000000ooooooo0000o`00000Kooooo`?o00003_ooool2o`0001Sooooo
1ol00003ooooo`;o0000AOooool2o`0000cooooo1_l00003ooooo`;o0000@?ooool001cooooo00?o
0000ooooooooool0>_ooool2o`0000Kooooo0_l0000>ooooo`Co000000?oooooo`000?l00000>ooo
ool6o`0000Gooooo1ol0000:ooooo`;o00003?ooool2o`0001?ooooo0_l0000Kooooo`;o00003_oo
ool2o`0000Gooooo0_l0000=ooooo`;o0000<Oooool001cooooo00?o0000ooooooooool0D_ooool2
o`0002[ooooo0_l0000@ooooo`co00001Oooool6o`0000Oooooo1?l0000<ooooo`;o00002Oooool2
o`0000?ooooo0_l00003ooooo`;o00002_ooool2o`0000Cooooo0_l0000:ooooo`;o00003oooool2
o`00013ooooo1Ol0000`ooooo`007?ooool00ol0003oooooooooo`0kooooo`Go00002Oooool2o`00
00Kooooo0_l000000ooooooo0000o`000002ooooo`;o00009?ooool2o`0000kooooo2?l00004oooo
o`Co00001_ooool4o`0000Kooooo0_l0000@ooooo`;o00001_ooool3o`0000?ooooo1?l0000=oooo
o`;o00001?ooool2o`0000Wooooo0ol00006ooooo`;o00001_ooool3o`00013ooooo0_l000000ooo
oooo0000o`00000`ooooo`007?ooool00ol0003oooooooooo`0jooooo`Ko00002Oooool3o`0000Co
oooo1ol000000ooooooo0000o`00000booooo`Go000000?oooooo`000?l000001_ooool4o`0000Go
oooo1_l0000Dooooo`Go00001_ooool2o`0000Gooooo0ol00007ooooo`;o00005Oooool2o`0000Ko
oooo0ol00003ooooo`Ko0000AOooool001cooooo00?o0000ooooooooool0>Oooool3o`0000;ooooo
0_l0000:ooooo`;o00001?ooool7o`0003?ooooo1Ol00009ooooo`Co000000?oooooo`000?l00000
1?ooool3o`000003ooooool0003o000001?ooooo1Ol0000>ooooo`;o00002?ooool2o`0001gooooo
1?l000000ooooooo0000o`000004o`0004Kooooo000Looooo`03o`000?oooooooooo03Sooooo0ol0
0003ooooo`;o00004?ooool3o`0000;ooooo0ol0000Yooooo`;o00001oooool5o`0000Wooooo0_l0
0002ooooo`?o00001?ooool2o`0000;ooooo0_l00006ooooo`;o00002oooool4o`0000Kooooo0_l0
00000ooooooo0000o`00000Booooo`;o00001?ooool2o`0001Gooooo0_l000000ooooooo0000o`00
001:ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00005Oooool3o`0000Cooooo0_l0000Y
ooooo`;o00001oooool2o`0000Sooooo0_l00002ooooo`;o00000_ooool3o`0000?ooooo2?l00005
ooooo`Co00002oooool2o`0000Kooooo0_l000000ooooooo0000o`00000>ooooo`;o00000_ooool4
o`0000;ooooo0_l0000Dooooo`;o00000_ooool2o`0004[ooooo000Looooo`03o`000?oooooooooo
03Sooooo0_l0000Eooooo`?o0000;oooool2o`0000Oooooo0_l00003ooooo`?o00000_ooool3o`00
0003ooooool0003o000000?ooooo0ol00002ooooo`;o000000?oooooo`000?l000000ol00006oooo
o`Co00009Oooool2o`0000Cooooo0_l00002ooooo`;o00004Oooool7o`0001Wooooo0_l0000aoooo
o`007?ooool00ol0003oooooooooo`0hooooo`;o000000?oooooo`000?l000002?ooool2o`0000So
oooo0ol00005ooooo`;o00000_ooool2o`0002_ooooo1?l00003ooooo`?o00000oooool2o`0000Ko
oooo0ol00002ooooo`So00001_ooool4o`0001_ooooo0_l0000?ooooo`;o000000?oooooo`000?l0
00004Oooool9o`0001Kooooo0ol0000aooooo`007?ooool00ol0003oooooooooo`0jooooo`?o0000
2?ooool2o`0000?ooooo0_l00002ooooo`?o00001?ooool4o`0000;ooooo0_l00002ooooo`;o0000
9_ooool3o`0000kooooo0_l000000ooooooo0000o`000002o`0000?ooooo2?l0000;ooooo`;o0000
6?ooool2o`000003ooooool0003o000000;ooooo0_l00008ooooo`Co00000oooool6o`0000[ooooo
1?l00002ooooo`;o000000?oooooo`000?l000000_ooool3o`0000kooooo0_l0000booooo`007?oo
ool00ol0003oooooooooo`0hooooo`Ko00003?ooool3o`000004ooooool0003o0000o`0000Cooooo
0ol00004ooooo`Go00006?ooool3o`0000_ooooo0ol00003ooooo`;o00000oooool2o`0000Cooooo
0_l000000ooooooo0000o`000005ooooo`So00000oooool2o`0000Kooooo0_l00008ooooo`;o0000
1Oooool2o`0000[ooooo0ol000000ooooooo0000o`000002ooooo`?o00001?ooool3o`0000?ooooo
1_l00003ooooo`;o00001?ooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000
o`000002ooooo`?o0000@_ooool001cooooo0_l0000iooooo`;o00000_ooool2o`0000gooooo0_l0
00001?oooooo0000o`000?l0000;ooooo`?o00006_ooool3o`0000?ooooo0_l00006ooooo`?o0000
0oooool2o`0000?ooooo0_l0000=ooooo`Wo00000oooool2o`00013ooooo0_l00005ooooo`;o0000
1oooool3o`000003ooooool0003o000000;o00000oooool3o`0000Sooooo0_l00009ooooo`;o0000
1?ooool2o`000003ooooool0003o000000Cooooo0ol0000Cooooo`;o0000<_ooool001cooooo00?o
0000ooooooooool0@_ooool2o`0000[ooooo0ol00005ooooo`;o00000_ooool2o`000003ooooool0
003o000001_ooooo0_l000000ooooooo0000o`000002o`0000Cooooo0ol0000=ooooo`;o00002Ooo
ool9o`0000[ooooo0_l0000Iooooo`Go000000?oooooo`000?l000003Ol00002ooooo`;o00000_oo
ool2o`0000Sooooo2Ol00003ooooo`?o00004oooool2o`0003;ooooo000Looooo`03o`000?oooooo
oooo03Wooooo0_l00007ooooo`;o00002_ooool3o`0000Gooooo0_l00002ooooo`?o00002Oooool2
o`0001;ooooo0_l000000ooooooo0000o`000005ooooo`Co000000Coooooo`000?l0003o00002Ooo
ool2o`0000Cooooo0_l00003ooooo`Wo00002_ooool2o`0000Kooooo0_l0000=ooooo`;o000000Go
ooooo`000?l0003o0000ooooo`0Eo`0000;ooooo2_l000000ooooooo0000o`000004o`000003oooo
ool0003o000000?ooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`0iooooo`Ko00006ooo
ool3o`0000Cooooo1?l000000ooooooo0000o`00000Kooooo`Co00000_ooool3o`0000oooooo0_l0
0004ooooo`Wo00004Oooool2o`0000Gooooo0_l000001?oooooo0000o`000?ooool4o`000004oooo
ool0003o0000ooooo`Co000000?oooooo`000?l000001?l00004oooooa?o000000?oooooo`000?l0
00002_ooool2o`0001;ooooo0_l0000dooooo`007?ooool00ol0003oooooooooo`0gooooo`So0000
2?ooool3o`0000Gooooo0_l00003ooooo`;o00001?ooool4o`0000?ooooo1?l00003ooooo`Co0000
5_ooool4o`0001;ooooo0_l000000ooooooo0000o`000003ooooo`[o00006?ooool2o`000003oooo
ool0003o000000Oo00000_ooool3o`000004ooooool0003o0000oooooa;o00002_ooool6o`0001[o
oooo0ol0000cooooo`007?ooool00ol0003oooooooooo`0gooooo`So000000?oooooo`000?l00000
1Oooool3o`0000Gooooo0_l00003ooooo`?o00001Oooool2o`0000[ooooo1?l0000Fooooo`?o0000
00?oooooo`000?l000004?ooool2o`000003ooooool0003o000000;ooooo2ol00007ooooo`;o0000
1oooool2o`0000_ooooo0_l00002ooooo`?o00000ooooolBo`000003ooooool0003o000000Oo0000
1Oooool2o`000003ooooool0003o000000;o00001oooool2o`00017ooooo0ol0000cooooo`007?oo
ool00ol0003oooooooooo`0jooooo`;o000000Coooooo`000?l0003ooooo1?l000000ooooooo0000
o`000002ooooo`;o00000_ooool4o`0000?ooooo0ol00008ooooo`;o00002Oooool2o`0000cooooo
1?l00006ooooo`;o00000_ooool2o`0000?ooooo0_l00003ooooo`Co00002oooool;o`0000Oooooo
0_l00007ooooo`;o000000Coooooo`000?l0003o00002oooool3o`0000?ooooo7Ol00004ooooo`;o
00002_ooool5o`00013ooooo0_l0000dooooo`007?ooool00ol0003oooooooooo`0jooooo`;o0000
1_ooool5o`0000;ooooo0_l000000ooooooo0000o`000003o`0000?ooooo0_l000000ooooooo0000
o`000005ooooo`Ko00001_ooool2o`0000_ooooo1Ol00003ooooo`?o00002Oooool2o`0000?ooooo
1?l00004ooooo`;o00001Oooool:o`0000Cooooo0_l00009ooooo`;o00000oooool3o`0000Cooooo
0_l00005ooooo`?o00000ooooolMo`00013ooooo0_l000000ooooooo0000o`000016ooooo`007?oo
ool00ol0003oooooooooo`0gooooo`;o000000?oooooo`000?l000002?ooool4o`0000Cooooo1?l0
0007ooooo`;o00001Oooool6o`0000kooooo0_l00003ooooo`;o00001Oooool5o`0001Gooooo0_l0
0005ooooo`[o00001?ooool2o`0000Oooooo1?l00008ooooo`Ko00001?ooool3o`000004ooooool0
003o0000oooooaWo00004Oooool2o`0004[ooooo000Looooo`03o`000?oooooooooo03Oooooo0_l0
000:ooooo`Go00001?ooool3o`0000;ooooo0_l00005ooooo`Co00001_ooool4o`0000Sooooo0_l0
0002ooooo`;o00002_ooool5o`000003ooooool0003o000001Wooooo2_l0000=ooooo`;o00002_oo
ool2o`0000;ooooo0_l00003ooooob3o00003oooool5o`000003ooooool0003o000004Oooooo000L
ooooo`03o`000?oooooooooo03Oooooo0_l0000:ooooo`;o000000?oooooo`000?l000001?ooool3
o`000004ooooool0003o0000o`0000?ooooo1_l00008ooooo`;o000000?oooooo`000?l000000_l0
00000ooooooo0000o`000002o`0000Oooooo0_l00006ooooo`Co000000?oooooo`000?l000003_oo
ool2o`0000?ooooo0_l00004ooooo`Wo00003_ooool3o`0001;ooooo8_l00006ooooo`;o00000_oo
ool2o`000003ooooool0003o000000;o00000_ooool2o`0000gooooo0ol0000gooooo`007?ooool0
0ol0003oooooooooo`0looooo`;o00002?ooool2o`0000?ooooo1?l000000ooooooo0000o`000002
ooooo`Co00003oooool4o`000003ooooool0003o000000;o00001oooool2o`0000Kooooo1Ol0000@
ooooo`;o00000oooool2o`0000?ooooo2_l0000>ooooo`?o00001oooool2o`0000[ooooo8Ol00006
ooooo`;o000000?oooooo`000?l000000_l000001?oooooo0000o`000?l00002ooooo`;o00003Ooo
ool3o`0003Oooooo000Looooo`03o`000?oooooooooo03Oooooo0_l00003ooooo`;o00003?ooool4
o`0000Kooooo0_l00008ooooo`;o00003?ooool4o`0000Cooooo0_l00005ooooo`;o00000_ooool2
o`000003ooooool0003o000001Sooooo3?l0000>ooooo`?o00001oooool3o`0000Wooooo8Ol00009
ooooo`Oo0000C?ooool001cooooo00?o0000ooooooooool0=oooool5o`0000gooooo1_l00005oooo
o`;o00001_ooool7o`000003ooooool0003o000000Kooooo0_l00006ooooo`;o00001?ooool3o`00
00;ooooo1?l0000Iooooo`co00002_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`00
00;ooooo1?l00008ooooob;o00000oooool2o`0000Cooooo0_l00002ooooo`;o00004_ooool2o`00
03Wooooo000Looooo`03o`000?oooooooooo03Sooooo1?l0000=ooooo`Ko00000oooool2o`0000So
oooo2_l00003ooooo`;o00003oooool2o`0000Gooooo1?l0000Aooooo`;o00001oooool8o`0000_o
oooo0_l00005ooooo`Co00000_ooool2o`0000Gooooo0ol000000ooooooo0000o`00000Qo`0000?o
oooo0_l00004ooooo`;o00000_ooool3o`00017ooooo0_l0000iooooo`007?ooool00ol0003ooooo
ooooo`0eooooo`;o000000?oooooo`000?l000003oooool2o`0000Oooooo0_l00004ooooo`Co0000
00?oooooo`000?l000002?l00002ooooo`;o00000oooool2o`0000[ooooo1?l00005ooooo`;o0000
4Oooool2o`0000Cooooo2ol0000<ooooo`;o00000oooool2o`0000Cooooo0_l00005ooooobOo0000
2_ooool2o`0000?ooooo0_l0000@ooooo`;o0000>_ooool001cooooo0_l0000fooooo`;o000000Co
ooooo`000?l0003ooooo0_l0000Jooooo`Go000000?oooooo`000?l000000ol000000ooooooo0000
o`000002o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000001?ooool2o`000003oooo
ool0003o000000;o00005Oooool2o`0000Oooooo2ol0000<ooooo`;o00000oooool2o`0000Cooooo
0_l00005ooooo`So00000_oooolIo`0000;ooooo0_l0000:ooooo`;o00005?ooool3o`0003[ooooo
000Looooo`03o`000?oooooooooo03Sooooo1Ol0000;ooooo`;o00002oooool4o`0000Gooooo1?l0
0002ooooo`Oo00001Oooool3o`0000?ooooo0ol00002ooooo`;o00005_ooool2o`0000Sooooo2_l0
000<ooooo`;o000000?oooooo`000?l000003Oooool8o`0000;ooooo3Ol000000ooooooo0000o`00
0008o`0000?ooooo0_l00007ooooo`;o00005oooool3o`0003[ooooo000Looooo`03o`000?oooooo
oooo03Oooooo1?l0000=ooooo`;o00002oooool3o`0000;ooooo0ol000000ooooooo0000o`000003
o`000003ooooool0003o000000Go00001?ooool3o`0000;ooooo1?l00003ooooo`;o00001Oooool2
o`0001Oooooo3?l0000;ooooo`?o000000?oooooo`000?l000000oooool2o`0000Sooooo2?l00003
oooooaOo000000Coooooo`000?l0003o00002?ooool2o`0000Gooooo0_l0001=ooooo`007?ooool0
0ol0003oooooooooo`0gooooo`;o00004?ooool2o`0000[ooooo0ol00002ooooo`Co000000?ooooo
o`000?l000000_l000001?oooooo0000o`000?ooool3o`0000Gooooo0_l00002ooooo`?o00003?oo
ool2o`0001Oooooo1Ol000000ooooooo0000o`000004o`0000_ooooo0_l00007ooooo`;o00003?oo
oolNo`000004ooooool0003o0000o`0000Oooooo0_l00006ooooo`;o00003_ooool2o`0003gooooo
000Looooo`03o`000?oooooooooo04;ooooo0_l00005ooooo`;o00002?ooool4o`0000;ooooo1_l0
0003ooooo`?o00003_ooool3o`0000Oooooo0_l00007ooooo`;o00005Oooool2o`000003ooooool0
003o000000Go00005_ooool2o`0000?ooooo0ol00005ooooob3o00002?ooool2o`0001Cooooo1?l0
000mooooo`007?ooool00ol0003oooooooooo`0dooooo`;o00003?ooool2o`0000Gooooo0_l00008
ooooo`?o00000_ooool7o`000003ooooool0003o000000?o00003?ooool3o`0000Kooooo0_l00000
0ooooooo0000o`000007ooooo`;o00000_ooool2o`0001;ooooo2Ol0000;ooooo`Go00001Oooool3
o`0000?ooooo0ol00006ooooo`Co000000?oooooo`000?l000004_l00002ooooo`Co00001oooool2
o`0001Cooooo1?l0000nooooo`007?ooool00ol0003oooooooooo`0dooooo`;o00001Oooool2o`00
01_ooooo3?l00002ooooo`;o00002Oooool3o`0000Kooooo0ol00009ooooo`;o00000_ooool2o`00
00;ooooo0_l0000>ooooo`So00003?ooool5o`0000Gooooo0_l00004ooooo`Co00001_ooool3o`00
0003ooooool0003o000001Ko00002Oooool3o`0001?ooooo0ol0000oooooo`007?ooool00ol0003o
ooooooooo`0eooooo`;o00001?ooool2o`0000;ooooo0_l00008ooooo`?o00002oooool:o`0000Go
oooo0_l0000<ooooo`;o00000oooool4o`00013ooooo0ol00002ooooo`;o00000_ooool2o`0000Ko
oooo1ol0000Nooooo`?o00002_oooolAo`0000;ooooo1?l00008ooooo`;o000000?oooooo`000?l0
00000oooool2o`0000gooooo1?l0000oooooo`007?ooool00ol0003oooooooooo`0dooooo`?o0000
1?ooool2o`0000;ooooo0_l00008ooooo`?o000000?oooooo`000?l000001oooool3o`0000;ooooo
1_l0000Aooooo`Co00000_ooool3o`0000Kooooo0_l00002ooooo`;o00001_ooool3o`0000;ooooo
0_l00002ooooo`;o00001Oooool8o`0000oooooo0_l00003ooooo`Co00001_ooool2o`0000Oooooo
1Ol00003ooooo`co00000_ooool6o`0000Kooooo0ol00006ooooo`;o00003Oooool2o`00047ooooo
000Looooo`03o`000?oooooooooo03Cooooo0ol00004ooooo`;o00002Oooool2o`0000Gooooo0_l0
0007ooooo`?o00000oooool2o`0000Cooooo0_l0000>ooooo`Co00000_ooool6o`0000?ooooo0_l0
0002ooooo`;o00000_ooool8o`000003ooooool0003o000000Sooooo2_l0000>ooooo`;o00000ooo
ool4o`0000oooooo1Ol000000ooooooo0000o`000002ooooo`Ko000000?oooooo`000?l000001_l0
00000ooooooo0000o`000006ooooo`Co00004Oooool5o`00047ooooo000Looooo`03o`000?oooooo
oooo03Gooooo0_l00004ooooo`;o000000?oooooo`000?l000001Oooool3o`0000[ooooo0_l00003
ooooo`;o00002Oooool2o`00013ooooo0_l00003ooooo`Go00002oooool4o`0000;ooooo0_l00000
1?oooooo0000o`000?l00003ooooo`;o00000_ooool:o`0000gooooo0_l00005ooooo`?o00005Ooo
ool2o`0000?ooooo2ol00003ooooo`;o00002Oooool2o`00013ooooo1?l00013ooooo`007?ooool0
0ol0003oooooooooo`0eooooo`;o00001oooool2o`0000Gooooo0_l00002ooooo`?o00001_ooool2
o`0000?ooooo0_l00007ooooo`;o00001_ooool2o`0000[ooooo0_l0000Looooo`?o00000oooool2
o`0000;ooooo0_l000000ooooooo0000o`000006o`0000cooooo0_l00005ooooo`;o00000_ooool2
o`0000?ooooo0_l00006ooooo`;o00000oooool4o`0000Oooooo0_l000000ooooooo0000o`000002
o`0000?ooooo0_l00003ooooo`;o00001?ooool2o`00013ooooo0_l00015ooooo`007?ooool00ol0
003oooooooooo`0nooooo`;o00001?ooool2o`0000?ooooo0ol000000ooooooo0000o`000008oooo
o`;o00001Oooool4o`0000Gooooo0ol0000Uooooo`Co00000_ooool2o`0000;ooooo0_l000000ooo
oooo0000o`000009o`0000gooooo0_l00004ooooo`;o00000_ooool2o`000003ooooool0003o0000
00;o00001_ooool2o`0000?ooooo1Ol00002ooooo`;o00000_ooool2o`000004ooooool0003o0000
o`0000Oooooo1?l00004ooooo`;o00003_ooool4o`0004Gooooo000Looooo`03o`000?oooooooooo
03kooooo0_l00004ooooo`?o00000oooool2o`000003ooooool0003o000000;ooooo0_l00004oooo
o`;o00001Oooool3o`0000Cooooo1?l0000Vooooo`Co00000_ooool@o`0000oooooo0_l00007oooo
o`?o000000?oooooo`000?l000001Oooool4o`0000Cooooo1Ol00002ooooo`[o00001oooool2o`00
00Kooooo0_l0000<ooooo`Co0000Aoooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2
ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo03kooooo0_l0
0002ooooo`;o000000?oooooo`000?l000000oooool2o`0000Gooooo0_l00004ooooo`?o000000Co
ooooo`000?l0003ooooo0_l00005ooooo`;o0000:?oooolFo`0000oooooo0_l00002ooooo`Co0000
00?oooooo`000?l000002Oooool5o`0000?ooooo0_l00004ooooo`Go000000Coooooo`000?l0003o
00007_ooool5o`0004Oooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44oooo
o`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`12ooooo`;o00001Oooool5
o`0000?ooooo1?l00003ooooo`Go00002?ooool2o`0001Kooooo0_l00008ooooo`;o000000?ooooo
o`000?l000006Ol0000Booooo`Go00003oooool2o`0000?ooooo0_l00002ooooo`Ko00001oooool2
o`0001Sooooo1Ol00019ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0looooo`;o00002oooool5
o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`Co00002Oooool2o`0001Kooooo0_l00005
ooooo`oo00000oooool3o`000003ooooool0003o000000Co000000?oooooo`000?l000000_l0000B
ooooo`;o00000oooool2o`0001Kooooo1?l00003ooooo`;o00001?ooool2o`0000Gooooo0_l0000@
ooooo`Go0000B_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0
003oV9RHoooooonHV9So8B4Q00Kooooo0ol0000looooo`;o00003?ooool2o`0000Cooooo0ol00000
0ooooooo0000o`00000>ooooo`;o00006_oooolCo`0000;ooooo2ol000001?oooooo0000o`000?l0
000Cooooo`?o00000_ooool2o`0001Oooooo0ol00003ooooo`Ko00001oooool2o`0000kooooo1?l0
001=ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?mEEEGo
0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`12ooooo`;o00003?ooool3o`000003ooooool0
003o000000cooooo1?l0000Joooooa;o000000?oooooo`000?l000001ol00003ooooo`Ko00003?oo
ool2o`0000Gooooo0ol0000Rooooo`Co00005Oooool6o`0004gooooo00000ooooooo410@ooooo`02
ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`0i
ooooo`;o00001oooool2o`0000Kooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool2
o`0000_ooooo0ol0000Joooooa?o000000?oooooo`000?l000002?l000000ooooooo0000o`000005
o`0000cooooo0ol00002ooooo`Go00000_ooool3o`0003Kooooo0_l0001Aooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0>Ooo
ool2o`0000_ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0ol0
000:ooooo`;o00006?oooolDo`000003ooooool0003o000000;o000000?oooooo`000?l000003?l0
000>ooooo`;o00000_ooool2o`0000Gooooo0ol0000dooooo`;o0000Doooool00006ooooooo^k^ko
<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo04Ko
oooo0_l00002ooooo`;o00001Oooool2o`0000?ooooo0_l00008ooooo`Co00006?oooolWo`0000ko
oooo0_l0000nooooo`;o000000?oooooo`000?l00000Doooool001cooooo00?o0000ooooooooool0
>oooool3o`0001?ooooo0ol00002ooooo`Co00001_ooool3o`0001Oooooo:Ol0000>ooooo`;o0000
0oooool3o`0003Kooooo1?l0001Fooooo`007?ooool00ol0003oooooooooo`0jooooo`Co00002ooo
ool2o`0000Kooooo0ol000001?oooooo0000o`000?ooool2o`00023ooooo:Ol0000Cooooo`?o0000
=Oooool4o`0005Oooooo000Looooo`03o`000?oooooooooo03[ooooo0_l00002ooooo`;o00002Ooo
ool3o`0000Kooooo0_l000000ooooooo0000o`000003o`0000Cooooo1?l0000Gooooo`Go000000?o
ooooo`000?l000008Ol0000Dooooo`;o00000_ooool2o`0002Cooooo0_l00003ooooo`Go000000?o
ooooo`000?l000001Ol0001Gooooo`007?ooool00ol0003oooooooooo`0jooooo`?o000000?ooooo
o`000?l000002_ooool2o`0000Kooooo0_l00003ooooo`_o00005_ooool6o`000003ooooool0003o
000001co000000?oooooo`000?l000000_l0000Dooooo`;o000000Coooooo`000?l0003o00008?oo
ool2o`0000;ooooo0_l00003ooooo`_o0000FOooool001cooooo00?o0000ooooooooool0>Oooool5
o`0000gooooo0_l00005ooooo`;o00000_ooool;o`0001Oooooo1Ol00002oooooako000000?ooooo
o`000?l000000_l0000Booooo`;o00000_ooool3o`0001Gooooo2Ol00003ooooo`Co000000?ooooo
o`000?l000000_ooool8o`00013ooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`0ioooo
o`;o000000?oooooo`000?l000003Oooool2o`0000Gooooo2Ol000000ooooooo0000o`00000Ioooo
o`Ko00000_oooolSo`0000oooooo0_l000000ooooooo0000o`000002ooooo`;o00005?ooool;o`00
00Cooooo0ol000000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l000004?ooool2o`00
04[ooooo000Looooo`03o`000?oooooooooo04;ooooo0ol00005ooooo`;o00001_ooool<o`0001Wo
oooo1?l00004ooooob;o00004?ooool2o`0001[ooooo1?l000000ooooooo0000o`000002o`0001;o
oooo1?l00005ooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0??ooool3o`0000?ooooo
0ol00005ooooo`?o00001?ooool2o`0000;ooooo1ol0000Hooooo`So00000ooooolQo`0001Gooooo
0_l0000Fooooo`;o00006oooool2o`0000Gooooo0_l00002ooooo`Co000000Coooooo`000?l0003o
0000C?ooool001cooooo00?o0000ooooooooool0>_ooool5o`0000Cooooo0_l00006ooooo`;o0000
1?ooool2o`0000?ooooo0_l0000Looooo`Co000000?oooooo`000?l000000ol000000ooooooo0000
o`00000Jo`0000;ooooo0ol0000Eooooo`;o00005Oooool5o`0001Wooooo0_l00003ooooo`;o0000
1?ooool4o`000003ooooool0003o000000?o0000B_ooool001cooooo00?o0000ooooooooool0>_oo
ool2o`0000[ooooo0_l00004ooooo`;o00000oooool3o`0000;ooooo0_l0000Qooooo`Go00000ooo
oolJo`000003ooooool0003o000000;o00003?ooool2o`0001kooooo0_l000000ooooooo0000o`00
000<ooooo`;o00002oooool2o`0000?ooooo0_l0000<ooooo`;o00005Oooool2o`0003?ooooo000L
ooooo`03o`000?oooooooooo03gooooo0_l00006ooooo`?o00001?ooool2o`0000Cooooo0_l0000Q
ooooo`;o00000oooool4o`0000;ooooo7_l0000>ooooo`;o00000_ooool2o`0001[ooooo1?l00009
ooooo`;o000000Coooooo`000?l0003o0000=Oooool2o`0003?ooooo000Looooo`;o0000?_ooool2
o`0000Kooooo0_l00005ooooo`;o00000oooool2o`0000Oooooo0_l0000Iooooo`;o00000oooool4
o`0000;ooooo7_l0000Booooo`;o00006oooool3o`0000Wooooo0_l000000ooooooo0000o`000003
ooooo`;o00003?ooool2o`0005Sooooo000Looooo`03o`000?oooooooooo057ooooo0ol00005oooo
o`?o00006?ooool3o`0000Oooooo0_l000000ooooooo0000o`00000Ao`0000?ooooo1ol0000Coooo
o`;o00006_ooool4o`00013ooooo0_l00009ooooo`;o000000?oooooo`000?l000001Oooool2o`00
057ooooo000Looooo`03o`000?oooooooooo04Sooooo0_l00002ooooo`;o00001?ooool5o`0000;o
oooo0_l0000Iooooo`;o00002?ooool2o`000003ooooool0003o0000013o000000?oooooo`000?l0
00002?l0000Cooooo`;o00000_ooool2o`0001Sooooo0_l0000@ooooo`;o00002Oooool4o`0000Ko
oooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`18ooooo`;o00000_ooool2o`0000Kooooo
1ol0000ToooooaCo000000?oooooo`000?l000000_l00002ooooo`?o00005oooool4o`0002Wooooo
0_l00008ooooo`;o000000?oooooo`000?l000008?ooool2o`0003Oooooo000Looooo`03o`000?oo
oooooooo03oooooo0_l0000;ooooo`;o00002?ooool4o`0002Gooooo6_l000000ooooooo0000o`00
000<ooooo`;o00002_ooool4o`0002Kooooo0_l0000;ooooo`;o00001oooool2o`0001Wooooo0ol0
000gooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00002oooool3o`0000Sooooo0_l0000Y
oooooa[o00003?ooool2o`0003Cooooo0_l00006ooooo`;o00002?ooool3o`000003ooooool0003o
000001Sooooo0ol0000hooooo`007?ooool00ol0003oooooooooo`11ooooo`;o00000oooool2o`00
00Cooooo0ol0000Vooooo`;o00002OoooolHo`000004ooooool0003o0000o`00047ooooo0_l00007
ooooo`;o00002?ooool3o`000003ooooool0003o000000;ooooo0_l0000Dooooo`;o0000>Oooool0
01cooooo00?o0000ooooooooool0@Oooool2o`0000?ooooo0_l00005ooooo`;o00001Oooool2o`00
01kooooo0ol00009ooooo`go000000?oooooo`000?l000001ol00003ooooo`;o00003?ooool2o`00
02[ooooo0ol00006ooooo`;o00000_ooool2o`0000?ooooo0_l0000<ooooo`;o00000_ooool2o`00
04oooooo000Looooo`03o`000?oooooooooo04gooooo0_l00005ooooo`;o00000_ooool2o`0001[o
oooo0ol00007ooooo`;o000000?oooooo`000?l000006?l0000=ooooo`;o0000:_ooool3o`0000[o
oooo0_l00003ooooo`;o00008_ooool2o`0003gooooo000Looooo`03o`000?oooooooooo04oooooo
0_l00007ooooo`;o00006oooool2o`0000Oooooo6?l000000ooooooo0000o`000002o`0000gooooo
0_l0000Xooooo`Co00001oooool3o`0000Oooooo0_l00005ooooo`?o00006?ooool3o`0003gooooo
000Looooo`03o`000?oooooooooo04[ooooo0ol00002ooooo`;o0000;?oooolJo`000003ooooool0
003o000003Sooooo0ol00005ooooo`;o000000Coooooo`000?l0003o00001oooool2o`000003oooo
ool0003o000000;ooooo0ol0000Hooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0B_oo
ool3o`0002[ooooo0_l00004ooooo`;o00000_ooool9o`0000;ooooo0ol000000ooooooo0000o`00
0005o`0000?ooooo0_l0000:ooooo`?o00001oooool2o`0002Sooooo0_l0000<ooooo`Co000000?o
ooooo`000?l000000_l0000Hooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0@oooool2
o`0003;ooooo0_l00009oooooa?o00001?ooool3o`0000[ooooo0ol000000ooooooo0000o`000004
ooooo`;o00007_ooool2o`0000Gooooo0_l000000ooooooo0000o`00000<ooooo`Oo0000F_ooool0
01cooooo00?o0000ooooooooool0@oooool3o`0003cooooo1?l00003ooooo`co00000oooool4o`00
00kooooo0_l00004ooooo`;o00007_ooool2o`0000?ooooo1?l000000ooooooo0000o`000003oooo
o`Ko00001?ooool2o`000003ooooool0003o000005_ooooo000Looooo`03o`000?oooooooooo04?o
oooo0ol0000:ooooo`;o00009_ooool2o`0000Sooooo1?l00004ooooo`So00000oooool7o`0001?o
oooo0_l0000Tooooo`;o00002?ooool6o`0000Kooooo0_l0001Looooo`007?ooool00ol0003ooooo
ooooo`14ooooo`;o00002_ooool2o`0002Kooooo0_l00006ooooo`;o000000?oooooo`000?l00000
1Oooool3o`0000?ooooo0ol000000ooooooo0000o`000005o`0001Cooooo0_l0000Wooooo`;o0000
00?oooooo`000?l000000_ooool4o`0000Oooooo0ol0001Looooo`007?ooool2o`0004Gooooo0_l0
000cooooo`;o00001Oooool2o`0000Cooooo0_l00002ooooo`?o00000_ooool7o`0000;ooooo0_l0
000<ooooo`;o0000;oooool3o`000003ooooool0003o000000;ooooo1Ol00006ooooo`;o0000GOoo
ool001cooooo00?o0000ooooooooool0AOooool2o`0000Cooooo0_l000000ooooooo0000o`00000W
ooooo`Co00002_ooool3o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000000ol00000
0ooooooo0000o`00000<ooooo`;o00001Oooool2o`0002Sooooo0ol000001?oooooo0000o`000?oo
ool2o`0000;ooooo0_l00003ooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0AOooool2
o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`;o00008_ooool2o`000003ooooool0003o
000000Wooooo4ol0000<ooooo`;o00001oooool2o`0002Kooooo1?l00003ooooo`Go00000oooool5
o`00063ooooo000Looooo`03o`000?oooooooooo04Oooooo0_l00005ooooo`;o00000oooool3o`00
02Cooooo0_l0000:oooooa;o00001Oooool2o`0000Gooooo0_l00005ooooo`So00000_ooool2o`00
01kooooo0_l00005ooooo`co0000HOooool001cooooo00?o0000ooooooooool0Aoooool2o`0000_o
oooo0_l0000Tooooo`;o00002oooool6o`0000?ooooo0ol000001?oooooo0000o`000?l00006oooo
o`?o00002oooool2o`0000;ooooo1?l00002ooooo`?o00008_ooool:o`0001[ooooo0_l00019oooo
o`007?ooool00ol0003oooooooooo`1>ooooo`;o00001_ooool2o`0002;ooooo0_l0000:ooooo`;o
00000oooool2o`000003ooooool0003o000000;o00000_ooool2o`0000;ooooo0ol00002ooooo`Co
00005Oooool3o`00027ooooo2?l0000Jooooo`Co0000BOooool001cooooo00?o0000ooooooooool0
C_ooool2o`0000?ooooo0_l000000ooooooo0000o`00000Uooooo`;o00001oooool2o`0000Kooooo
0ol00002ooooo`Co000000Coooooo`000?l0003o00000_ooool4o`0000[ooooo0ol00009ooooo`;o
00008_ooool2o`0001kooooo1?l0001:ooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o0000
0oooool3o`0002;ooooo0_l0000;ooooo`;o00000_ooool3o`0000;ooooo1?l000000ooooooo0000
o`000005o`0000cooooo0ol0000Zooooo`;o00008Oooool2o`0004cooooo000Looooo`03o`000?oo
oooooooo04Wooooo0_l00008ooooo`;o00000oooool3o`0002oooooo0_l000000ooooooo0000o`00
0004ooooo`?o00001Oooool4o`0000_ooooo0_l000000ooooooo0000o`00000=ooooo`;o00004Ooo
ool2o`0000Oooooo0_l0000Oooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0BOooool2
o`0000Sooooo0_l00006ooooo`;o0000<?ooool9o`0001Cooooo0_l000000ooooooo0000o`000003
ooooo`;o00002?ooool2o`00013ooooo0ol00007ooooo`;o00007Oooool4o`0004kooooo000Loooo
o`03o`000?oooooooooo05_ooooo1?l0000Rooooo`;o00003?ooool5o`0001kooooo0_l00008oooo
o`;o00004?ooool3o`0002Kooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`1Mooooo`?o
00008Oooool2o`0000oooooo0_l0000Xooooo`;o00005_ooool2o`0000;ooooo0_l0001_ooooo`00
7?ooool00ol0003oooooooooo`1Eooooo`;o00001oooool2o`0003_ooooo0_l0000Kooooo`;o0000
0_ooool2o`0001Kooooo0_l00002ooooo`;o0000Koooool001cooooo00?o0000ooooooooool0EOoo
ool2o`0000Oooooo0ol0000Gooooo`;o00008Oooool2o`0001Cooooo0_l00005ooooo`?o000000?o
ooooo`000?l000000_l0000Dooooo`;o0000Loooool001cooooo00?o0000ooooooooool0G_ooool3
o`0001Kooooo0ol00006ooooo`?o0000;Oooool3o`0000Kooooo0_l00002ooooo`?o00005?ooool2
o`0001_ooooo0ol0001Eooooo`007?ooool00ol0003oooooooooo`1Rooooo`;o00004oooool3o`00
00Kooooo0ol0000]ooooo`So00007?ooool2o`0001_ooooo0ol0001Eooooo`007?ooool2o`0006?o
oooo1?l0000Aooooo`;o0000>?ooool9o`00017ooooo0_l0001looooo`007?ooool00ol0003ooooo
ooooo`1Jooooo`;o00002?ooool3o`0002?ooooo0_l0000Uooooo`Ko000000?oooooo`000?l00000
0_l0000?ooooo`?o00000oooool2o`0000Cooooo0_l0000Dooooo`;o0000F_ooool001cooooo00?o
0000ooooooooool0F_ooool2o`0000Wooooo0_l0000Fooooo`;o00001_ooool2o`0000?ooooo0_l0
0003ooooo`;o00006Oooool6o`000003ooooool0003o000000?o00000_ooool4o`0000oooooo0ol0
0003ooooo`;o00000oooool3o`0001;ooooo1?l0001Jooooo`007?ooool00ol0003oooooooooo`1J
ooooo`?o00000_ooool2o`0001cooooo0_l00006ooooo`;o00002?ooool2o`0000?ooooo0_l0000:
oooooa7o00000oooool3o`000003ooooool0003o000001Kooooo0ol00003ooooo`;o00004_ooool3
o`0005cooooo000Looooo`03o`000?oooooooooo05_ooooo0_l00002ooooo`?o0000<Oooool3o`00
0003ooooool0003o000000Oooooo4Ol00004ooooo`;o00006Oooool3o`0001Oooooo0_l0001Moooo
o`007?ooool00ol0003oooooooooo`1Eooooo`;o00002Oooool2o`00037ooooo0_l00002ooooo`;o
000000?oooooo`000?l000002?ooool7o`0000?ooooo0_l0000Oooooo`Co00005Oooool2o`0005oo
oooo000Looooo`03o`000?oooooooooo05Gooooo0_l0000Xooooo`;o00003_ooool2o`0000Wooooo
0_l0000<ooooo`;o00000_ooool4o`0000;ooooo0_l0000>ooooo`;o00002oooool3o`0001Cooooo
1?l0001Oooooo`007?ooool00ol0003oooooooooo`1Fooooo`;o00009oooool2o`0000_ooooo0_l0
00000ooooooo0000o`00000<ooooo`;o00000_ooool5o`0000;ooooo0_l000000ooooooo0000o`00
0007o`0000kooooo0_l0000<ooooo`;o00005?ooool2o`00067ooooo000Looooo`03o`000?oooooo
oooo05Kooooo0_l00008ooooo`;o00009?ooool2o`0000Cooooo0_l00009ooooo`;o00001?ooool2
o`0000;ooooo1Ol00005ooooo`Co000000Coooooo`000?l0003o0000<Oooool2o`0006?ooooo000L
ooooo`03o`000?oooooooooo063ooooo0_l00002ooooo`Co000000?oooooo`000?l000006oooool2
o`0000cooooo0_l000000ooooooo0000o`000019ooooo`Co0000Hoooool001cooooo00?o0000oooo
ooooool0I?ooool4o`000003ooooool0003o000001cooooo0_l0000:ooooo`?o00000_ooool2o`00
02Sooooo0_l00009ooooo`;o00004oooool3o`0006Cooooo000Looooo`03o`000?oooooooooo06Wo
oooo0_l0000Looooo`;o00002_ooool2o`0000?ooooo0_l00003ooooo`;o00008oooool2o`0000Ko
oooo0_l000000ooooooo0000o`00001jooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o0000
0_ooool3o`0001[ooooo0_l0000@ooooo`;o00000oooool5o`0000_ooooo0_l0000<ooooo`Co0000
0oooool2o`0000Kooooo0_l000000ooooooo0000o`00000@ooooo`;o0000J?ooool001cooooo00?o
0000ooooooooool0IOooool2o`0000;ooooo0ol00005ooooo`;o000000?oooooo`000?l000001Ooo
ool2o`0000Wooooo0_l0000@ooooo`;o00001Oooool6o`0000Sooooo0_l0000;ooooo`Go00002ooo
ool2o`0001?ooooo0_l0001Xooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q
1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0LOooool2o`000003
ooooool0003o000000Gooooo0ol0000Oooooo`Co000000Coooooo`000?l0003o00000_ooool4o`00
00Wooooo0_l000001?oooooo0000o`000?ooool2o`0000[ooooo1?l0001oooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo
00?o0000ooooooooool0L?ooool3o`0000Cooooo0ol00002ooooo`;o00007oooool4o`0000Kooooo
2?l00005ooooo`;o000000?oooooo`000?l000002Oooool2o`0000;ooooo1?l0001oooooo`0000?o
oooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`1`ooooo`;o00001Oooool3o`000004ooooool0003o0000o`0001Co
oooo0ol0000Aooooo`;o00000oooool4o`0001;ooooo0ol00025ooooo`0000?oooooo`000?ooool0
0_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`0007?o
oooo0ol00005ooooo`;o00001oooool2o`0000cooooo0ol0000Aooooo`Go00002oooool2o`000004
ooooool0003o0000ooooo`So00005_ooool2o`0006gooooo00000ooooooo0000ooooo`02ooooo`03
o`000?oooooooooo00Wooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo
07?ooooo0ol00002ooooo`;o00002?ooool4o`0000cooooo0_l000000ooooooo0000o`00000Aoooo
o`?o00001?ooool3o`0000Cooooo0_l000000ooooooo0000o`000006o`0001Wooooo0_l0001]oooo
o`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj
^_l@41001_ooool00ol0003oooooooooo`1booooo`?o00000oooool2o`0000Cooooo0_l000001?oo
oooo0000o`000?l0000Aooooo`;o00006?ooool3o`0000Sooooo0_l0000Iooooo`?o0000LOooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo
00?o0000ooooooooool0L_ooool3o`0000Wooooo0_l000001?oooooo0000o`000?l00006ooooo`;o
00000_ooool3o`0000;ooooo1Ol0000mooooo`?o0000LOooool00006ooooooo^k^ko<S8bo`000?lb
<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0O_ooool3
o`000003ooooool0003o000000Kooooo1ol00002ooooo`Go000000?oooooo`000?l00000=oooool4
o`0007?ooooo000Looooo`03o`000?oooooooooo07Sooooo0_l00004ooooo`Co00002_ooool2o`00
00?ooooo0_l00004ooooo`Co0000<oooool2o`0000;ooooo1?l0001cooooo`007?ooool00ol0003o
ooooooooo`1hooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o
00001oooool2o`0000Cooooo0_l00007ooooo`;o00000_ooool2o`0001Cooooo0_l000000ooooooo
0000o`00000?ooooo`;o0000NOooool001cooooo00?o0000ooooooooool0O?ooool2o`0000Gooooo
0_l00003ooooo`;o00002?ooool2o`0000Cooooo0_l00006ooooo`;o00000_ooool2o`0000?ooooo
0_l00003ooooo`;o000000?oooooo`000?l000001oooool2o`000004ooooool0003o0000ooooo`;o
00001?ooool2o`0000;ooooo1?l0001kooooo`007?ooool00ol0003oooooooooo`25ooooo`;o0000
00?oooooo`000?l000002?ooool2o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`;o0000
1_ooool2o`0000?ooooo0_l000000ooooooo0000o`00000=ooooo`Go000000?oooooo`000?l00000
0_ooool4o`0007_ooooo000Looooo`03o`000?oooooooooo08Gooooo0ol0000Cooooo`;o00001?oo
ool2o`0000Wooooo0_l0000Booooo`Go00001?ooool2o`0007kooooo000Looooo`03o`000?oooooo
oooo08Gooooo0ol00008ooooo`;o00003?ooool3o`0000_ooooo0_l0000Booooo`Co00001?ooool4
o`0007gooooo000Looooo`03o`000?oooooooooo08Gooooo0_l00004ooooo`;o000000?oooooo`00
0?l000000ol00005ooooo`;o00000oooool5o`00023ooooo0_l00004ooooo`Co0000OOooool001co
oooo00?o0000ooooooooool0Roooool2o`000003ooooool0003o000000?o00001?ooool3o`0000?o
oooo1Ol0000Iooooo`?o0000Roooool001cooooo00?o0000ooooooooool0S_ooool3o`0000Kooooo
1?l00004ooooo`;o00002Oooool2o`000003ooooool0003o000000Oooooo0_l00003ooooo`?o0000
Roooool001cooooo00?o0000ooooooooool0VOooool2o`0000Cooooo0_l00009ooooo`;o000000?o
ooooo`000?l000001oooool2o`00097ooooo000Looooo`03o`000?oooooooooo0:Kooooo0_l00005
ooooo`;o0000V_ooool001cooooo0_l0002Wooooo`;o00001_ooool2o`0009Wooooo000Looooo`03
o`000?oooooooooo0:kooooo0_l0002Iooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Booooo`Co000000?o410@oooooooo
ool00oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`?o0000oooo
oom:ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo
0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003ooooo
ooooo`3ooooooe;ooooo000Booooo`03oeEEEOmVIVKo00000?ooooooE?ooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00:Gooooo00Co410@o`000?l0003ooooo0_l000000ol@413o
ooooooooo`0Eooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP2@ooooo`00Y_ooool01Ol0003ooooooooooooo
oooo000000Wooooo1_l00009ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`2@ooooo`00Y_ooool01Ol0003o
oooooooooooooooo000001cooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo
ooooooooool@41000oooool00ol@413oooooooooo`2>ooooo`00Y_ooool01Ol0003ooooooooooooo
oooo000000Wooooo1_l0000<ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool00000T?ooool00:Kooooo00Go0000ohN7Qooooooo
ZJVYo`00000Jooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool00000T?ooool00:Gooooo00?o410@o`000?mgMgL00_l000000onH
V9Soooooooooo`0Iooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@4100T?ooool00<?ooooo00Go410@oiRHV?oooooo^[Zjo`00
0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg093o
oooo0033ooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP2@ooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(306) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.64824 .58748 Mdot
.66549 .56568 Mdot
.48059 .33107 Mdot
.39065 .62931 Mdot
.34793 .33128 Mdot
.4844 .28081 Mdot
.64861 .37082 Mdot
.65584 .37403 Mdot
.49748 .31336 Mdot
.46654 .78779 Mdot
.61207 .36664 Mdot
.41362 .5755 Mdot
.64016 .38244 Mdot
.4178 .6212 Mdot
.33028 .52873 Mdot
.40684 .66792 Mdot
.6845 .59451 Mdot
.38495 .37334 Mdot
.41193 .66627 Mdot
.50511 .27583 Mdot
.48782 .69274 Mdot
.40961 .63118 Mdot
.65422 .54161 Mdot
.41793 .6248 Mdot
.47472 .60756 Mdot
.667 .57733 Mdot
.64628 .58444 Mdot
.44543 .5863 Mdot
.40077 .65422 Mdot
.62672 .3902 Mdot
.44942 .46527 Mdot
.22743 .64287 Mdot
.46474 .65655 Mdot
.62858 .69507 Mdot
.63713 .40133 Mdot
.5743 .36467 Mdot
.44875 .2875 Mdot
.66235 .40153 Mdot
.60903 .37029 Mdot
.60923 .35235 Mdot
.61057 .3527 Mdot
.66593 .57952 Mdot
.671 .38153 Mdot
.55352 .24739 Mdot
.42763 .62906 Mdot
.69389 .65346 Mdot
.51392 .24253 Mdot
.45848 .61928 Mdot
.68754 .54592 Mdot
.51255 .29972 Mdot
.26448 .44824 Mdot
.66056 .36995 Mdot
.50768 .5418 Mdot
.86745 .42843 Mdot
.64961 .3809 Mdot
.45408 .64485 Mdot
.47889 .31016 Mdot
.42716 .59593 Mdot
.41775 .57983 Mdot
.61195 .66779 Mdot
.41477 .59508 Mdot
.34221 .35275 Mdot
.64714 .5306 Mdot
.52192 .28018 Mdot
.49475 .31773 Mdot
.66801 .38998 Mdot
.71939 .56915 Mdot
.63104 .38844 Mdot
.39766 .64793 Mdot
.50989 .2903 Mdot
.43938 .6481 Mdot
.61275 .36714 Mdot
.64552 .57388 Mdot
.41053 .63933 Mdot
.78446 .52449 Mdot
.61623 .43614 Mdot
.41078 .32613 Mdot
.56887 .58942 Mdot
.41937 .37997 Mdot
.36912 .49855 Mdot
.41022 .6374 Mdot
.67527 .23326 Mdot
.30632 .51012 Mdot
.68178 .54807 Mdot
.49765 .54163 Mdot
.74054 .38799 Mdot
.46931 .61674 Mdot
.45646 .46252 Mdot
.37628 .58631 Mdot
.29791 .3427 Mdot
.48966 .30506 Mdot
.70296 .56056 Mdot
.42261 .63649 Mdot
.40459 .64629 Mdot
.55442 .80153 Mdot
.39706 .65524 Mdot
.43335 .5784 Mdot
.53299 .46779 Mdot
.63614 .34982 Mdot
.49432 .61123 Mdot
.4734 .38406 Mdot
.51958 .51035 Mdot
.45677 .63896 Mdot
.47951 .29775 Mdot
.6505 .53054 Mdot
.46213 .65334 Mdot
.62733 .37955 Mdot
.41746 .63502 Mdot
.66669 .41329 Mdot
.68258 .54321 Mdot
.43561 .57666 Mdot
.35766 .36509 Mdot
.55351 .56573 Mdot
.64341 .56119 Mdot
.67657 .73003 Mdot
.39978 .61032 Mdot
.43806 .59808 Mdot
.66247 .56661 Mdot
.4882 .27011 Mdot
.62446 .21597 Mdot
.64897 .57726 Mdot
.61114 .34852 Mdot
.70084 .58809 Mdot
.52219 .54149 Mdot
.48815 .26881 Mdot
.53934 .50115 Mdot
.54167 .50421 Mdot
.23199 .5511 Mdot
.38923 .62161 Mdot
.42997 .7184 Mdot
.47979 .28989 Mdot
.65022 .56717 Mdot
.64179 .39154 Mdot
.37726 .63394 Mdot
.68751 .57434 Mdot
.65157 .36953 Mdot
.32618 .3633 Mdot
.39109 .36674 Mdot
.657 .54644 Mdot
.6958 .72587 Mdot
.59684 .34945 Mdot
.64987 .35147 Mdot
.26357 .45193 Mdot
.68075 .54787 Mdot
.35991 .34831 Mdot
.63006 .36807 Mdot
.21354 .36007 Mdot
.47482 .60158 Mdot
.24936 .48772 Mdot
.68912 .25113 Mdot
.26513 .44747 Mdot
.45458 .72305 Mdot
.36499 .35995 Mdot
.65174 .3691 Mdot
.45007 .63231 Mdot
.68185 .55774 Mdot
.68353 .57593 Mdot
.42952 .65068 Mdot
.48077 .63491 Mdot
.4231 .61089 Mdot
.46898 .65038 Mdot
.5222 .46065 Mdot
.42273 .6346 Mdot
.78339 .62118 Mdot
.69106 .56073 Mdot
.47736 .63492 Mdot
.45286 .28688 Mdot
.42627 .70047 Mdot
.67 .38306 Mdot
.39502 .59561 Mdot
.48249 .62008 Mdot
.39124 .58022 Mdot
.61259 .34524 Mdot
.79833 .53706 Mdot
.40578 .37659 Mdot
.60293 .35917 Mdot
.66507 .30658 Mdot
.46458 .29088 Mdot
.44025 .59019 Mdot
.37619 .35911 Mdot
.49796 .60404 Mdot
.4209 .64435 Mdot
.26773 .43994 Mdot
.42247 .58108 Mdot
.44273 .7271 Mdot
.36976 .66671 Mdot
.72998 .3752 Mdot
.77168 .57985 Mdot
.39389 .63476 Mdot
.48288 .76331 Mdot
.25711 .48018 Mdot
.57117 .40147 Mdot
.64213 .39329 Mdot
.48922 .27611 Mdot
.48936 .27244 Mdot
.61668 .40398 Mdot
.65836 .71426 Mdot
.44313 .78363 Mdot
.37985 .62641 Mdot
.51659 .51845 Mdot
.70344 .59249 Mdot
.363 .35918 Mdot
.65344 .55199 Mdot
.65603 .21387 Mdot
.39504 .48019 Mdot
.42152 .49441 Mdot
.46651 .35068 Mdot
.51367 .30406 Mdot
.52263 .51185 Mdot
.36526 .34644 Mdot
.4326 .61147 Mdot
.68026 .54347 Mdot
.25917 .4724 Mdot
.49863 .58323 Mdot
.41787 .83117 Mdot
.65236 .58625 Mdot
.26945 .59559 Mdot
.64682 .38001 Mdot
.45749 .3174 Mdot
.47025 .617 Mdot
.40718 .61388 Mdot
.68368 .54032 Mdot
.45141 .62007 Mdot
.37511 .52758 Mdot
.47256 .60254 Mdot
.51248 .2703 Mdot
.39809 .37956 Mdot
.59995 .36565 Mdot
.45625 .3509 Mdot
.64226 .56428 Mdot
.82991 .58053 Mdot
.46332 .30278 Mdot
.39664 .70425 Mdot
.6148 .36728 Mdot
.32795 .36325 Mdot
.47203 .30446 Mdot
.3703 .33342 Mdot
.39778 .58926 Mdot
.44802 .2987 Mdot
.34448 .35872 Mdot
.44417 .49208 Mdot
.46891 .64835 Mdot
.20905 .5302 Mdot
.64105 .36301 Mdot
.70508 .57657 Mdot
.43328 .64208 Mdot
.50611 .54072 Mdot
.49034 .61785 Mdot
.27344 .56351 Mdot
.5302 .524 Mdot
.52274 .504 Mdot
.34342 .48673 Mdot
.35446 .37915 Mdot
.79014 .4013 Mdot
.46962 .45853 Mdot
.68219 .59505 Mdot
.40665 .64484 Mdot
.70466 .32309 Mdot
.64915 .36512 Mdot
.43001 .60503 Mdot
.73375 .35004 Mdot
.63274 .36757 Mdot
.43539 .59913 Mdot
.61614 .38234 Mdot
.68835 .56591 Mdot
.35448 .52647 Mdot
.6609 .59461 Mdot
.43191 .63305 Mdot
.61489 .37856 Mdot
.48362 .27353 Mdot
.66895 .57731 Mdot
.41369 .63452 Mdot
.3948 .60339 Mdot
.5142 .52604 Mdot
.47422 .60247 Mdot
.6454 .4572 Mdot
.46096 .61833 Mdot
.4584 .33523 Mdot
.39796 .65458 Mdot
.40537 .42686 Mdot
.29209 .32178 Mdot
.66764 .54334 Mdot
.52963 .52433 Mdot
.47498 .30795 Mdot
.39666 .52096 Mdot
.2629 .60457 Mdot
.42355 .62898 Mdot
.52916 .52128 Mdot
.24862 .56892 Mdot
.66671 .3721 Mdot
.37511 .5869 Mdot
.36457 .31485 Mdot
.4893 .30309 Mdot
.51973 .51358 Mdot
.49471 .58932 Mdot
.69895 .60257 Mdot
.41033 .6652 Mdot
.45042 .29988 Mdot
.67549 .59406 Mdot
.41419 .66096 Mdot
.58632 .41814 Mdot
.50326 .53884 Mdot
.64585 .3511 Mdot
.51437 .4809 Mdot
.44695 .60112 Mdot
.50963 .29357 Mdot
.6704 .5822 Mdot
.65326 .37922 Mdot
.64368 .56402 Mdot
.27851 .44706 Mdot
.26158 .57673 Mdot
.73237 .60798 Mdot
.32546 .369 Mdot
.1889 .39711 Mdot
.60314 .35302 Mdot
.49724 .61516 Mdot
.52901 .27742 Mdot
.71835 .52413 Mdot
.48192 .29971 Mdot
.71022 .71394 Mdot
.48579 .30773 Mdot
.44531 .65147 Mdot
.49959 .28778 Mdot
.5514 .81167 Mdot
.41645 .58574 Mdot
.49003 .32199 Mdot
.51226 .44948 Mdot
.40944 .58889 Mdot
.68807 .57508 Mdot
.26022 .69823 Mdot
.64534 .70477 Mdot
.64813 .7151 Mdot
.47146 .31173 Mdot
.72224 .70517 Mdot
.45242 .59021 Mdot
.37353 .62817 Mdot
.67953 .56181 Mdot
.49111 .62673 Mdot
.37721 .37194 Mdot
.38956 .35737 Mdot
.23737 .4039 Mdot
.25778 .64855 Mdot
.65968 .72661 Mdot
.67969 .57507 Mdot
.40911 .35457 Mdot
.7827 .53052 Mdot
.50345 .53974 Mdot
.65594 .37357 Mdot
.8094 .5075 Mdot
.37852 .58593 Mdot
.53062 .48823 Mdot
.37101 .52996 Mdot
.69373 .58439 Mdot
.63426 .60459 Mdot
.65441 .37751 Mdot
.64573 .71715 Mdot
.43046 .77106 Mdot
.42469 .61044 Mdot
.64354 .35852 Mdot
.48925 .62032 Mdot
.4578 .464 Mdot
.22583 .56149 Mdot
.49198 .20778 Mdot
.43206 .6305 Mdot
.80097 .49057 Mdot
.4277 .64314 Mdot
.23403 .53598 Mdot
.43429 .61036 Mdot
.68033 .58196 Mdot
.39944 .57199 Mdot
.47419 .46166 Mdot
.23245 .29851 Mdot
.39251 .47531 Mdot
.37566 .3371 Mdot
.41504 .6217 Mdot
.41719 .60591 Mdot
.34156 .34671 Mdot
.70223 .57473 Mdot
.42402 .64799 Mdot
.80429 .40805 Mdot
.41931 .63755 Mdot
.6666 .38868 Mdot
.28996 .53928 Mdot
.22589 .62867 Mdot
.46037 .59839 Mdot
.70219 .60108 Mdot
.64797 .35099 Mdot
.61795 .36472 Mdot
.51178 .55249 Mdot
.64705 .36341 Mdot
.45005 .62905 Mdot
.28871 .53864 Mdot
.71865 .55354 Mdot
.50149 .55619 Mdot
.69274 .58341 Mdot
.35598 .21166 Mdot
.64412 .36585 Mdot
.51461 .53435 Mdot
.67475 .7128 Mdot
.63249 .37616 Mdot
.3737 .39774 Mdot
.398 .57173 Mdot
.49946 .57252 Mdot
.65303 .59783 Mdot
.50867 .29209 Mdot
.52992 .50992 Mdot
.65071 .38018 Mdot
.42591 .62868 Mdot
.46768 .6332 Mdot
.6456 .36192 Mdot
.54996 .649 Mdot
.4509 .46372 Mdot
.43056 .63615 Mdot
.69523 .57168 Mdot
.65188 .57078 Mdot
.38865 .66645 Mdot
.42774 .64416 Mdot
.48243 .27774 Mdot
.52971 .52096 Mdot
.5333 .51597 Mdot
.54209 .49962 Mdot
.46407 .31455 Mdot
.18817 .38346 Mdot
.66029 .35732 Mdot
.22712 .6385 Mdot
.74882 .48778 Mdot
.50503 .55198 Mdot
.4668 .27334 Mdot
.4047 .61059 Mdot
.46228 .62791 Mdot
.62162 .38838 Mdot
.18315 .48167 Mdot
.37416 .62602 Mdot
.66016 .59324 Mdot
.65286 .36357 Mdot
.48598 .60975 Mdot
.71023 .36433 Mdot
.3601 .37203 Mdot
.66676 .72881 Mdot
.65689 .36765 Mdot
.69444 .53827 Mdot
.65741 .36797 Mdot
.41871 .60732 Mdot
.49441 .59256 Mdot
.68674 .58794 Mdot
.35475 .33154 Mdot
.42311 .65149 Mdot
.43727 .60475 Mdot
.53589 .35235 Mdot
.78316 .52157 Mdot
.34201 .33081 Mdot
.45432 .63465 Mdot
.50791 .57756 Mdot
.35227 .33281 Mdot
.4442 .63037 Mdot
.41343 .65855 Mdot
.42926 .71914 Mdot
.6701 .39957 Mdot
.32452 .35365 Mdot
.21066 .32686 Mdot
.65162 .58659 Mdot
.64243 .45791 Mdot
.52933 .50183 Mdot
.60452 .35241 Mdot
.36345 .54086 Mdot
.52266 .52135 Mdot
.76717 .46912 Mdot
.75527 .74727 Mdot
.52905 .51264 Mdot
.44338 .28501 Mdot
.58018 .79554 Mdot
.41304 .6576 Mdot
.43425 .6347 Mdot
.37383 .37358 Mdot
.66186 .55881 Mdot
.77424 .57638 Mdot
.60352 .36084 Mdot
.39931 .62334 Mdot
.64025 .57316 Mdot
.73404 .37708 Mdot
.51813 .52204 Mdot
.37349 .36561 Mdot
.33271 .34592 Mdot
.43505 .63862 Mdot
.24861 .59016 Mdot
.6724 .57818 Mdot
.41385 .63445 Mdot
.4407 .59902 Mdot
.45466 .27346 Mdot
.67556 .54375 Mdot
.45231 .29307 Mdot
.50534 .52748 Mdot
.61661 .7977 Mdot
.67291 .30333 Mdot
.63293 .36377 Mdot
.51509 .54141 Mdot
.60025 .36642 Mdot
.52307 .25575 Mdot
.53055 .52005 Mdot
.41288 .63308 Mdot
.71555 .54726 Mdot
.41525 .63531 Mdot
.42067 .63734 Mdot
.43062 .62573 Mdot
.66018 .72768 Mdot
.42206 .38036 Mdot
.37831 .35983 Mdot
.45187 .60644 Mdot
.44998 .3084 Mdot
.71346 .3532 Mdot
.4935 .7976 Mdot
.4109 .61851 Mdot
.43806 .59906 Mdot
.70581 .59781 Mdot
.47679 .6027 Mdot
.63533 .37077 Mdot
.69393 .58511 Mdot
.46163 .63513 Mdot
.48233 .37572 Mdot
.43103 .64578 Mdot
.69207 .62323 Mdot
.65977 .39412 Mdot
.47487 .58029 Mdot
.42969 .68283 Mdot
.52946 .52249 Mdot
.52866 .51064 Mdot
.54204 .49293 Mdot
.66726 .38922 Mdot
.4472 .28242 Mdot
.50222 .32987 Mdot
.41381 .69171 Mdot
.45275 .6291 Mdot
.49585 .57663 Mdot
.42986 .31692 Mdot
.48539 .43629 Mdot
.70065 .71304 Mdot
.4839 .60876 Mdot
.46853 .32042 Mdot
.53238 .4679 Mdot
.54419 .63136 Mdot
.70305 .57735 Mdot
.51691 .26442 Mdot
.61981 .37603 Mdot
.34288 .36132 Mdot
.22942 .45791 Mdot
.65809 .58351 Mdot
.72756 .57307 Mdot
.46929 .28131 Mdot
.2816 .53032 Mdot
.86982 .40722 Mdot
.48577 .29189 Mdot
.41084 .50362 Mdot
.68134 .56651 Mdot
.46603 .65466 Mdot
.25187 .55636 Mdot
.29281 .53187 Mdot
.48291 .32108 Mdot
.39373 .60492 Mdot
.38922 .1948 Mdot
.48487 .27814 Mdot
.50444 .58103 Mdot
.46853 .31193 Mdot
.65749 .35781 Mdot
.47637 .29377 Mdot
.63471 .56899 Mdot
.39026 .62397 Mdot
.8681 .42159 Mdot
.32598 .50118 Mdot
.394 .6236 Mdot
.66514 .3803 Mdot
.5705 .39202 Mdot
.42609 .60711 Mdot
.38501 .3625 Mdot
.44389 .28532 Mdot
.4717 .22734 Mdot
.42531 .66019 Mdot
.50197 .28927 Mdot
.72355 .58375 Mdot
.49554 .25581 Mdot
.48033 .38109 Mdot
.53244 .51018 Mdot
.68772 .56112 Mdot
.6139 .43301 Mdot
.61263 .348 Mdot
.44948 .65865 Mdot
.44029 .59376 Mdot
.69413 .56025 Mdot
.41804 .51009 Mdot
.3666 .62165 Mdot
.416 .63731 Mdot
.45808 .28904 Mdot
.51745 .2861 Mdot
.32694 .52957 Mdot
.46077 .30342 Mdot
.50572 .57455 Mdot
.69366 .56743 Mdot
.41647 .6645 Mdot
.64985 .57332 Mdot
.40934 .64611 Mdot
.70322 .3796 Mdot
.70604 .56227 Mdot
.39527 .703 Mdot
.39311 .60179 Mdot
.76017 .63413 Mdot
.449 .59893 Mdot
.42713 .63721 Mdot
.51224 .2745 Mdot
.3465 .34511 Mdot
.37188 .64624 Mdot
.68056 .4091 Mdot
.33691 .35984 Mdot
.53706 .66108 Mdot
.48551 .26842 Mdot
.32909 .35664 Mdot
.22418 .42676 Mdot
.53197 .521 Mdot
.35859 .33743 Mdot
.49763 .54853 Mdot
.63205 .36134 Mdot
.69958 .53417 Mdot
.40683 .58931 Mdot
.60781 .80102 Mdot
.45435 .46081 Mdot
.5144 .52796 Mdot
.44122 .63032 Mdot
.40852 .60536 Mdot
.64049 .5729 Mdot
.66044 .21851 Mdot
.52046 .30298 Mdot
.48225 .63632 Mdot
.65376 .58281 Mdot
.68203 .24132 Mdot
.48373 .32376 Mdot
.3568 .37762 Mdot
.60868 .37179 Mdot
.6199 .56132 Mdot
.50958 .5363 Mdot
.64671 .36657 Mdot
.46695 .34019 Mdot
.271 .43518 Mdot
.40808 .66473 Mdot
.45705 .27987 Mdot
.26575 .44586 Mdot
.37979 .5772 Mdot
.61575 .40448 Mdot
.56725 .37199 Mdot
.69205 .55032 Mdot
.64684 .36211 Mdot
.38247 .35682 Mdot
.69958 .59056 Mdot
.69568 .58217 Mdot
.63064 .372 Mdot
.76971 .6606 Mdot
.24953 .56815 Mdot
.63035 .40553 Mdot
.28078 .56212 Mdot
.26769 .44373 Mdot
.51119 .53082 Mdot
.37396 .3623 Mdot
.39773 .38222 Mdot
.66555 .57895 Mdot
.80595 .51101 Mdot
.26431 .44744 Mdot
.43792 .57902 Mdot
.34258 .3575 Mdot
.72994 .38483 Mdot
.58355 .38458 Mdot
.63964 .36747 Mdot
.54381 .34762 Mdot
.33883 .3526 Mdot
.38867 .60262 Mdot
.16604 .53611 Mdot
.42414 .58582 Mdot
.6295 .367 Mdot
.37264 .52902 Mdot
.66184 .54915 Mdot
.66924 .37748 Mdot
.37407 .52784 Mdot
.4579 .63106 Mdot
.40001 .60715 Mdot
.43148 .38038 Mdot
.69519 .54711 Mdot
.50562 .53059 Mdot
.39397 .62827 Mdot
.43199 .59747 Mdot
.43901 .6661 Mdot
.22556 .60706 Mdot
.56947 .54994 Mdot
.45054 .66221 Mdot
.45404 .32145 Mdot
.49698 .59627 Mdot
.48411 .63412 Mdot
.67142 .60636 Mdot
.45832 .38676 Mdot
.512 .51482 Mdot
.43652 .62968 Mdot
.43194 .63408 Mdot
.61116 .37595 Mdot
.24906 .56718 Mdot
.28781 .528 Mdot
.49248 .32807 Mdot
.40246 .31507 Mdot
.38386 .62613 Mdot
.68643 .55472 Mdot
.31708 .35443 Mdot
.50956 .56092 Mdot
.66059 .59243 Mdot
.3902 .63632 Mdot
.4496 .2761 Mdot
.52967 .51586 Mdot
.51208 .56606 Mdot
.34845 .35751 Mdot
.59762 .36878 Mdot
.54587 .64046 Mdot
.47552 .27356 Mdot
.47531 .61173 Mdot
.39331 .31586 Mdot
.49931 .29518 Mdot
.51273 .52643 Mdot
.49279 .6134 Mdot
.68681 .5696 Mdot
.68651 .53732 Mdot
.39216 .42749 Mdot
.4576 .31324 Mdot
.54096 .28222 Mdot
.64525 .35522 Mdot
.4496 .60608 Mdot
.59234 .36217 Mdot
.67025 .53948 Mdot
.23128 .55078 Mdot
.33076 .34984 Mdot
.63506 .36836 Mdot
.50259 .54656 Mdot
.70673 .57157 Mdot
.66916 .53859 Mdot
.42457 .63402 Mdot
.40928 .62638 Mdot
.51258 .25227 Mdot
.25254 .48729 Mdot
.6224 .39075 Mdot
.35319 .3749 Mdot
.49493 .32618 Mdot
.44305 .65127 Mdot
.6758 .54913 Mdot
.20316 .60791 Mdot
.44725 .59998 Mdot
.45157 .30926 Mdot
.66715 .56733 Mdot
.3712 .37334 Mdot
.38083 .35416 Mdot
.39896 .63672 Mdot
.44798 .72373 Mdot
.63108 .37881 Mdot
.68639 .57745 Mdot
.65358 .52058 Mdot
.45445 .60947 Mdot
.41183 .6225 Mdot
.37259 .58169 Mdot
.64696 .41217 Mdot
.4093 .68022 Mdot
.36135 .33226 Mdot
.64837 .55398 Mdot
.39744 .63053 Mdot
.34178 .35021 Mdot
.53809 .48575 Mdot
.52434 .52181 Mdot
.50496 .30846 Mdot
.38686 .36089 Mdot
.35232 .34794 Mdot
.33717 .3641 Mdot
.80998 .50573 Mdot
.50088 .52761 Mdot
.30697 .39574 Mdot
.39226 .60586 Mdot
.26856 .44279 Mdot
.40342 .66942 Mdot
.65937 .36334 Mdot
.50874 .29673 Mdot
.42758 .62052 Mdot
.39324 .60397 Mdot
.55308 .62106 Mdot
.41626 .6664 Mdot
.38267 .65612 Mdot
.66098 .54817 Mdot
.6673 .51729 Mdot
.49125 .27514 Mdot
.69786 .26255 Mdot
.17548 .61422 Mdot
.37905 .61825 Mdot
.2835 .53232 Mdot
.70486 .57059 Mdot
.60966 .37314 Mdot
.27175 .55917 Mdot
.58822 .36642 Mdot
.65503 .56707 Mdot
.44199 .65381 Mdot
.57116 .6078 Mdot
.33836 .3576 Mdot
.42077 .60994 Mdot
.63458 .39164 Mdot
.42194 .6103 Mdot
.66741 .38183 Mdot
.72658 .69332 Mdot
.28315 .51303 Mdot
.4168 .58314 Mdot
.39791 .65574 Mdot
.48793 .68655 Mdot
.40995 .62166 Mdot
.48463 .20698 Mdot
.67197 .56557 Mdot
.42425 .69643 Mdot
.45098 .64972 Mdot
.63872 .70697 Mdot
.44384 .61457 Mdot
.37215 .54511 Mdot
.42206 .59039 Mdot
.18793 .45749 Mdot
.40493 .58481 Mdot
.43559 .58884 Mdot
.65221 .3916 Mdot
.60771 .36095 Mdot
.73536 .53957 Mdot
.51186 .51721 Mdot
.73062 .37866 Mdot
.43811 .60381 Mdot
.5132 .3095 Mdot
.40036 .71647 Mdot
.34854 .34678 Mdot
.64733 .55786 Mdot
.82942 .68623 Mdot
.67184 .37164 Mdot
.44384 .30395 Mdot
.43854 .4787 Mdot
.44592 .31469 Mdot
.52294 .27086 Mdot
.61707 .54432 Mdot
.37262 .36357 Mdot
.42831 .64589 Mdot
.63491 .69056 Mdot
.78699 .5083 Mdot
.45503 .61113 Mdot
.42861 .33027 Mdot
.41759 .71428 Mdot
.36824 .43722 Mdot
.37738 .37724 Mdot
.36736 .35511 Mdot
.65019 .3762 Mdot
.50352 .31859 Mdot
.48893 .62526 Mdot
.3288 .35616 Mdot
.49596 .27988 Mdot
.52138 .53468 Mdot
.44419 .38667 Mdot
.67399 .57878 Mdot
.71915 .7076 Mdot
.70609 .65418 Mdot
.63808 .34848 Mdot
.67916 .41034 Mdot
.70944 .54079 Mdot
.6698 .59643 Mdot
.51361 .51706 Mdot
.47536 .31935 Mdot
.69344 .53222 Mdot
.39646 .63287 Mdot
.4989 .58368 Mdot
.43364 .64041 Mdot
.3651 .37855 Mdot
.44295 .62223 Mdot
.49828 .2835 Mdot
.65484 .39204 Mdot
.48571 .30514 Mdot
.65037 .37183 Mdot
.23682 .66785 Mdot
.38881 .60591 Mdot
.41367 .62448 Mdot
.28893 .53796 Mdot
.6617 .54165 Mdot
.62225 .70235 Mdot
.45589 .31099 Mdot
.47852 .30955 Mdot
.44691 .65204 Mdot
.7108 .58141 Mdot
.37424 .32685 Mdot
.2904 .55706 Mdot
.4256 .59041 Mdot
.67151 .56401 Mdot
.44147 .65613 Mdot
.65954 .43892 Mdot
.31412 .51271 Mdot
.64845 .54798 Mdot
.23636 .29326 Mdot
.39544 .59693 Mdot
.49314 .62458 Mdot
.39827 .69862 Mdot
.24168 .61983 Mdot
.36808 .62656 Mdot
.65431 .588 Mdot
.48461 .63176 Mdot
.68058 .5529 Mdot
.49491 .295 Mdot
.66987 .375 Mdot
.6781 .55643 Mdot
.4087 .5913 Mdot
.17588 .61265 Mdot
.65116 .39738 Mdot
.42125 .6146 Mdot
.63535 .3955 Mdot
.65217 .53119 Mdot
.6607 .5539 Mdot
.52037 .53606 Mdot
.41264 .50193 Mdot
.63215 .37294 Mdot
.45292 .62684 Mdot
.79284 .53022 Mdot
.40886 .66541 Mdot
.4064 .31877 Mdot
.38631 .64369 Mdot
.39007 .63806 Mdot
.18588 .37154 Mdot
.40218 .52066 Mdot
.68369 .30308 Mdot
.69798 .33913 Mdot
.79688 .54123 Mdot
.65382 .59985 Mdot
.37931 .37566 Mdot
.5887 .55615 Mdot
.53578 .5125 Mdot
.45724 .3236 Mdot
.4271 .62557 Mdot
.5378 .47958 Mdot
.63589 .40763 Mdot
.36048 .33926 Mdot
.42267 .58111 Mdot
.4365 .31139 Mdot
.52479 .53556 Mdot
.64387 .36702 Mdot
.6645 .57968 Mdot
.65131 .55911 Mdot
.41534 .38679 Mdot
.39674 .62878 Mdot
.41053 .62965 Mdot
.64105 .40125 Mdot
.37814 .68017 Mdot
.34532 .36875 Mdot
.51097 .44868 Mdot
.63163 .39136 Mdot
.31211 .51154 Mdot
.69382 .54571 Mdot
.40661 .60773 Mdot
.29381 .54098 Mdot
.78424 .56312 Mdot
.50996 .78055 Mdot
.36123 .35643 Mdot
.25895 .59933 Mdot
.65395 .58758 Mdot
.64338 .39117 Mdot
.23109 .41394 Mdot
.39399 .57225 Mdot
.41405 .6001 Mdot
.25589 .60875 Mdot
.28917 .55845 Mdot
.43751 .48118 Mdot
.50172 .55161 Mdot
.25811 .54614 Mdot
.44498 .65356 Mdot
.46729 .63249 Mdot
.38375 .62337 Mdot
.38736 .64602 Mdot
.67139 .55747 Mdot
.63912 .72232 Mdot
.47238 .28545 Mdot
.51274 .7663 Mdot
.41275 .31227 Mdot
.44779 .58812 Mdot
.45397 .63951 Mdot
.53704 .72683 Mdot
.28657 .59672 Mdot
.67534 .57125 Mdot
.64544 .59455 Mdot
.62432 .34598 Mdot
.40774 .66667 Mdot
.45375 .31115 Mdot
.40549 .69769 Mdot
.50251 .3053 Mdot
.67024 .55918 Mdot
.46468 .26901 Mdot
.65057 .34752 Mdot
.45607 .2805 Mdot
.46331 .32155 Mdot
.65976 .38776 Mdot
.70405 .55419 Mdot
.44573 .59372 Mdot
.66069 .38687 Mdot
.35491 .32711 Mdot
.36788 .37725 Mdot
.72318 .53618 Mdot
.4594 .65832 Mdot
.37974 .58595 Mdot
.54909 .28512 Mdot
.44725 .28844 Mdot
.31105 .56042 Mdot
.70351 .55702 Mdot
.32006 .3609 Mdot
.67496 .55319 Mdot
.35487 .4233 Mdot
.35598 .35528 Mdot
.49763 .54341 Mdot
.21868 .49405 Mdot
.60221 .33905 Mdot
.40363 .57443 Mdot
.66821 .51754 Mdot
.50046 .30638 Mdot
.66613 .38068 Mdot
.71951 .36332 Mdot
.47958 .63971 Mdot
.73513 .56502 Mdot
.63392 .54542 Mdot
.53412 .51503 Mdot
.64089 .3914 Mdot
.72704 .6485 Mdot
.39532 .62347 Mdot
.59899 .35319 Mdot
.38612 .64227 Mdot
.68421 .72938 Mdot
.42549 .27096 Mdot
.53286 .47129 Mdot
.44597 .65147 Mdot
.48204 .32429 Mdot
.44542 .65252 Mdot
.62656 .77892 Mdot
.23138 .51855 Mdot
.38261 .62024 Mdot
.28048 .59745 Mdot
.52386 .25373 Mdot
.67855 .54886 Mdot
.50588 .55876 Mdot
.51256 .52927 Mdot
.47526 .62262 Mdot
.25366 .74891 Mdot
.34612 .34261 Mdot
.46761 .36113 Mdot
.40484 .59302 Mdot
.40945 .63636 Mdot
.54296 .6423 Mdot
.72376 .6935 Mdot
.5322 .52628 Mdot
.41962 .59896 Mdot
.26314 .62484 Mdot
.65323 .3866 Mdot
.40827 .66155 Mdot
.42568 .64182 Mdot
.49037 .24741 Mdot
.6496 .39193 Mdot
.46845 .27075 Mdot
.53338 .5185 Mdot
.51495 .28614 Mdot
.35054 .33113 Mdot
.26849 .59755 Mdot
.2273 .57625 Mdot
.3181 .51836 Mdot
.38683 .35696 Mdot
.46447 .60026 Mdot
.5131 .48464 Mdot
.3956 .60822 Mdot
.36907 .35196 Mdot
.62622 .38989 Mdot
.67381 .56266 Mdot
.70359 .72114 Mdot
.51455 .52326 Mdot
.46321 .60792 Mdot
.35196 .38127 Mdot
.68254 .55956 Mdot
.7929 .61458 Mdot
.6639 .55815 Mdot
.64308 .37098 Mdot
.62191 .40838 Mdot
.35032 .35253 Mdot
.67489 .55261 Mdot
.51344 .27948 Mdot
.60603 .40456 Mdot
.42667 .57175 Mdot
.65349 .34916 Mdot
.64853 .53865 Mdot
.64139 .5535 Mdot
.72124 .56152 Mdot
.45526 .6454 Mdot
.29163 .58336 Mdot
.51293 .54589 Mdot
.64631 .40032 Mdot
.44451 .32099 Mdot
.24786 .49411 Mdot
.63243 .64691 Mdot
.2992 .51589 Mdot
.49625 .56101 Mdot
.44259 .62408 Mdot
.43624 .63716 Mdot
.4373 .66895 Mdot
.50061 .47092 Mdot
.38763 .61009 Mdot
.62223 .38967 Mdot
.49426 .28667 Mdot
.4204 .59273 Mdot
.52052 .5291 Mdot
.48106 .43897 Mdot
.32401 .35132 Mdot
.66672 .73123 Mdot
.72149 .53351 Mdot
.68086 .5598 Mdot
.45138 .29926 Mdot
.47716 .26552 Mdot
.32667 .36387 Mdot
.65451 .36897 Mdot
.66036 .55969 Mdot
.19051 .44776 Mdot
.34021 .36291 Mdot
.43711 .62771 Mdot
.28985 .53874 Mdot
.25684 .63573 Mdot
.42029 .65388 Mdot
.43179 .62462 Mdot
.51355 .51278 Mdot
.45232 .31257 Mdot
.49608 .806 Mdot
.7777 .62446 Mdot
.34539 .3493 Mdot
.33784 .37036 Mdot
.72133 .56994 Mdot
.44816 .6107 Mdot
.63031 .38109 Mdot
.24777 .57377 Mdot
.58461 .41782 Mdot
.73947 .39257 Mdot
.52831 .25936 Mdot
.43377 .64471 Mdot
.60904 .76559 Mdot
.38206 .59202 Mdot
.65511 .52911 Mdot
.7004 .54206 Mdot
.67782 .57387 Mdot
.65479 .38354 Mdot
.2738 .4325 Mdot
.61084 .35398 Mdot
.53162 .46685 Mdot
.66749 .58806 Mdot
.41965 .50388 Mdot
.47555 .31049 Mdot
.40704 .66875 Mdot
.37273 .36057 Mdot
.32925 .31913 Mdot
.50413 .56224 Mdot
.26213 .59867 Mdot
.46649 .27342 Mdot
.70866 .5738 Mdot
.41236 .66912 Mdot
.71239 .35007 Mdot
.2738 .52114 Mdot
.50535 .22684 Mdot
.53641 .47741 Mdot
.34158 .35312 Mdot
.45963 .78471 Mdot
.35199 .36886 Mdot
.63384 .36839 Mdot
.39125 .60339 Mdot
.44662 .60757 Mdot
.42726 .63782 Mdot
.37858 .63392 Mdot
.65071 .38265 Mdot
.41582 .57357 Mdot
.40416 .42758 Mdot
.53958 .50925 Mdot
.4838 .45893 Mdot
.37827 .34568 Mdot
.64926 .35701 Mdot
.49834 .29172 Mdot
.52436 .50296 Mdot
.32198 .36572 Mdot
.41759 .67047 Mdot
.40364 .59631 Mdot
.53921 .51351 Mdot
.49719 .55636 Mdot
.37603 .59085 Mdot
.47744 .28067 Mdot
.46249 .46052 Mdot
.3285 .34624 Mdot
.36204 .36328 Mdot
.63886 .35914 Mdot
.67563 .55259 Mdot
.32599 .35329 Mdot
.4564 .3337 Mdot
.40926 .66237 Mdot
.38476 .63964 Mdot
.64554 .54246 Mdot
.26644 .44269 Mdot
.32386 .35122 Mdot
.4044 .67974 Mdot
.64995 .54896 Mdot
.63244 .54641 Mdot
.41829 .60021 Mdot
.42417 .5748 Mdot
.67155 .60586 Mdot
.3377 .37214 Mdot
.64117 .35747 Mdot
.30731 .4948 Mdot
.65975 .3578 Mdot
.66746 .58178 Mdot
.4989 .58884 Mdot
.70893 .56115 Mdot
.47847 .64079 Mdot
.79174 .37728 Mdot
.38665 .61267 Mdot
.62932 .6101 Mdot
.47044 .43134 Mdot
.47256 .31222 Mdot
.47841 .31515 Mdot
.52969 .51853 Mdot
.66828 .59349 Mdot
.5062 .5703 Mdot
.36864 .36843 Mdot
.7965 .54028 Mdot
.67279 .60659 Mdot
.46575 .32156 Mdot
.44206 .29439 Mdot
.63331 .39397 Mdot
.44364 .62024 Mdot
.40527 .60817 Mdot
.45707 .27891 Mdot
.61139 .44302 Mdot
.69653 .55523 Mdot
.41104 .62972 Mdot
.44728 .66307 Mdot
.47632 .28446 Mdot
.63882 .33329 Mdot
.70036 .53553 Mdot
.45641 .64529 Mdot
.2307 .52845 Mdot
.66891 .38175 Mdot
.46991 .6188 Mdot
.40302 .57404 Mdot
.35447 .34423 Mdot
.25605 .60211 Mdot
.26413 .45111 Mdot
.67121 .36798 Mdot
.52487 .52819 Mdot
.42653 .65153 Mdot
.47986 .31222 Mdot
.39898 .6727 Mdot
.61631 .83642 Mdot
.53719 .51564 Mdot
.39775 .62528 Mdot
.39874 .69429 Mdot
.64965 .5736 Mdot
.41023 .63409 Mdot
.70075 .38396 Mdot
.45742 .29464 Mdot
.39695 .62352 Mdot
.48385 .70173 Mdot
.63435 .39397 Mdot
.50468 .55951 Mdot
.33873 .35458 Mdot
.42531 .49336 Mdot
.25782 .69549 Mdot
.42993 .31574 Mdot
.37627 .34064 Mdot
.44264 .61077 Mdot
.50367 .32096 Mdot
.60567 .35864 Mdot
.51085 .54502 Mdot
.47257 .61172 Mdot
.63073 .34806 Mdot
.65773 .3853 Mdot
.34737 .35437 Mdot
.86659 .51817 Mdot
.38347 .60714 Mdot
.41565 .61277 Mdot
.8369 .56932 Mdot
.63627 .59836 Mdot
.42251 .61336 Mdot
.44143 .59878 Mdot
.64128 .36292 Mdot
.2742 .41697 Mdot
.26065 .59963 Mdot
.50998 .45211 Mdot
.6665 .37514 Mdot
.49413 .33063 Mdot
.45589 .28659 Mdot
.37072 .33678 Mdot
.66625 .56756 Mdot
.32614 .36734 Mdot
.47263 .29275 Mdot
.43075 .63218 Mdot
.62382 .35605 Mdot
.40336 .7605 Mdot
.66292 .39077 Mdot
.43888 .32333 Mdot
.65336 .52995 Mdot
.56537 .81166 Mdot
.64068 .82881 Mdot
.57574 .53818 Mdot
.61488 .4056 Mdot
.34878 .34645 Mdot
.78009 .623 Mdot
.42251 .59178 Mdot
.62631 .77342 Mdot
.41889 .61061 Mdot
.54306 .48273 Mdot
.5074 .29138 Mdot
.52104 .53513 Mdot
.47827 .64156 Mdot
.2645 .60162 Mdot
.66009 .37967 Mdot
.62327 .38091 Mdot
.48472 .63066 Mdot
.63897 .37128 Mdot
.40105 .61747 Mdot
.48643 .28493 Mdot
.82802 .42414 Mdot
.4189 .59027 Mdot
.42596 .69432 Mdot
.5985 .34756 Mdot
.75691 .58324 Mdot
.47708 .33735 Mdot
.62195 .74386 Mdot
.73008 .36907 Mdot
.63205 .38147 Mdot
.66143 .72993 Mdot
.45163 .30298 Mdot
.52368 .50312 Mdot
.51661 .30787 Mdot
.41214 .6098 Mdot
.43636 .64387 Mdot
.43332 .67091 Mdot
.44053 .60166 Mdot
.57961 .78311 Mdot
.37922 .58263 Mdot
.50731 .71812 Mdot
.39192 .6069 Mdot
.59345 .57286 Mdot
.61111 .36708 Mdot
.49167 .61696 Mdot
.33324 .48068 Mdot
.38892 .63001 Mdot
.6522 .59745 Mdot
.65043 .35553 Mdot
.72956 .33706 Mdot
.65146 .38542 Mdot
.48682 .3058 Mdot
.65664 .37402 Mdot
.43113 .57878 Mdot
.65447 .57367 Mdot
.46914 .30148 Mdot
.50605 .5467 Mdot
.45423 .32572 Mdot
.39411 .6238 Mdot
.63179 .32207 Mdot
.4452 .30062 Mdot
.38873 .57384 Mdot
.65305 .5707 Mdot
.20485 .55994 Mdot
.70786 .53695 Mdot
.41981 .62993 Mdot
.42237 .62313 Mdot
.53875 .5161 Mdot
.65192 .36925 Mdot
.70774 .55617 Mdot
.5548 .34127 Mdot
.31975 .36171 Mdot
.67052 .57195 Mdot
.39386 .69864 Mdot
.2798 .53111 Mdot
.64339 .56147 Mdot
.26042 .63044 Mdot
.63196 .36701 Mdot
.64818 .58066 Mdot
.37268 .6862 Mdot
.50804 .76525 Mdot
.35873 .36628 Mdot
.51371 .27723 Mdot
.27093 .54609 Mdot
.45507 .28919 Mdot
.70787 .36856 Mdot
.51332 .27151 Mdot
.64424 .39663 Mdot
.41232 .71421 Mdot
.37489 .52794 Mdot
.65449 .40481 Mdot
.64142 .31904 Mdot
.46609 .28704 Mdot
.46034 .65603 Mdot
.47405 .45918 Mdot
.50978 .57435 Mdot
.50026 .60907 Mdot
.67211 .37426 Mdot
.64896 .58313 Mdot
.69992 .58965 Mdot
.41224 .70187 Mdot
.65495 .55251 Mdot
.48387 .29576 Mdot
.32229 .52339 Mdot
.67461 .71252 Mdot
.61652 .37773 Mdot
.45472 .46354 Mdot
.45455 .64016 Mdot
.5015 .28756 Mdot
.48729 .29628 Mdot
.6576 .38237 Mdot
.54718 .76326 Mdot
.50688 .579 Mdot
.61833 .57673 Mdot
.65932 .58502 Mdot
.64898 .5742 Mdot
.68211 .54239 Mdot
.27239 .43192 Mdot
.66554 .37835 Mdot
.6653 .59244 Mdot
.37906 .63866 Mdot
.44564 .61343 Mdot
.52767 .50735 Mdot
.36051 .37848 Mdot
.38641 .57895 Mdot
.5065 .57003 Mdot
.41597 .60111 Mdot
.46673 .31188 Mdot
.40809 .72129 Mdot
.53914 .50456 Mdot
.45433 .31232 Mdot
.46201 .31369 Mdot
.52936 .52291 Mdot
.40368 .71758 Mdot
.51205 .79531 Mdot
.47966 .60771 Mdot
.61639 .54907 Mdot
.48147 .31617 Mdot
.50383 .37412 Mdot
.62014 .60224 Mdot
.45096 .62607 Mdot
.49931 .44263 Mdot
.48971 .28869 Mdot
.65253 .60022 Mdot
.41 .61617 Mdot
.5113 .52144 Mdot
.35022 .36501 Mdot
.50717 .54781 Mdot
.51262 .51465 Mdot
.68557 .54982 Mdot
.54365 .29327 Mdot
.64013 .57202 Mdot
.476 .26365 Mdot
.50254 .56534 Mdot
.86892 .41342 Mdot
.49954 .3054 Mdot
.80034 .53116 Mdot
.38173 .52403 Mdot
.40429 .60076 Mdot
.45295 .2966 Mdot
.71637 .59134 Mdot
.66935 .38846 Mdot
.2996 .5791 Mdot
.67259 .55059 Mdot
.52805 .50009 Mdot
.52546 .51214 Mdot
.47349 .28461 Mdot
.68041 .58403 Mdot
.40903 .57323 Mdot
.6513 .56104 Mdot
.61761 .35906 Mdot
.48256 .62291 Mdot
.7304 .37782 Mdot
.49335 .61495 Mdot
.65164 .55281 Mdot
.44344 .32237 Mdot
.3549 .33169 Mdot
.41859 .58572 Mdot
.73266 .34279 Mdot
.44313 .61093 Mdot
.63084 .39372 Mdot
.45473 .43241 Mdot
.42467 .75495 Mdot
.4355 .61395 Mdot
.45635 .63583 Mdot
.63514 .33942 Mdot
.43381 .61063 Mdot
.3999 .65273 Mdot
.7264 .65056 Mdot
.64406 .55715 Mdot
.42246 .59277 Mdot
.47098 .2757 Mdot
.49495 .70544 Mdot
.40763 .63924 Mdot
.69784 .39111 Mdot
.24375 .60758 Mdot
.43888 .4277 Mdot
.42437 .70202 Mdot
.2317 .5477 Mdot
.42021 .61927 Mdot
.4512 .62017 Mdot
.48497 .61907 Mdot
.61263 .76737 Mdot
.46741 .29216 Mdot
.48679 .32441 Mdot
.36562 .33339 Mdot
.25623 .61109 Mdot
.35512 .36087 Mdot
.6052 .35834 Mdot
.43211 .48474 Mdot
.54117 .50147 Mdot
.67728 .55225 Mdot
.42207 .63907 Mdot
.45658 .32898 Mdot
.406 .61126 Mdot
.47381 .62256 Mdot
.48201 .29302 Mdot
.49203 .29348 Mdot
.4283 .29138 Mdot
.33653 .35441 Mdot
.67889 .56697 Mdot
.40203 .58892 Mdot
.33634 .35848 Mdot
.43712 .66792 Mdot
.29292 .49766 Mdot
.67821 .56962 Mdot
.65351 .55063 Mdot
.69233 .58909 Mdot
.43233 .58636 Mdot
.48376 .61905 Mdot
.61211 .35165 Mdot
.64523 .54258 Mdot
.62886 .37487 Mdot
.45272 .29524 Mdot
.48751 .27928 Mdot
.41291 .60919 Mdot
.37985 .68044 Mdot
.37971 .35268 Mdot
.44543 .29567 Mdot
.5307 .49341 Mdot
.34896 .33662 Mdot
.43095 .64318 Mdot
.45342 .29164 Mdot
.38063 .36774 Mdot
.53597 .77066 Mdot
.70264 .43234 Mdot
.35836 .33326 Mdot
.47986 .64153 Mdot
.61655 .64754 Mdot
.23561 .51005 Mdot
.32144 .3497 Mdot
.61181 .36732 Mdot
.44453 .59592 Mdot
.52066 .46087 Mdot
.33055 .34601 Mdot
.25602 .46389 Mdot
.47608 .29592 Mdot
.49774 .61464 Mdot
.5508 .57177 Mdot
.67105 .71199 Mdot
.35168 .33198 Mdot
.64996 .55375 Mdot
.6679 .53558 Mdot
.43705 .62409 Mdot
.42639 .49095 Mdot
.63054 .40258 Mdot
.47936 .26546 Mdot
.47886 .32758 Mdot
.68812 .53527 Mdot
.31704 .51576 Mdot
.46657 .27748 Mdot
.44976 .60842 Mdot
.39978 .36109 Mdot
.38349 .65665 Mdot
.37141 .4287 Mdot
.40987 .74795 Mdot
.41368 .70617 Mdot
.35508 .33215 Mdot
.63052 .401 Mdot
.65287 .39313 Mdot
.65246 .37481 Mdot
.47199 .27906 Mdot
.27026 .5572 Mdot
.48656 .32651 Mdot
.82263 .58902 Mdot
.34523 .34246 Mdot
.19901 .38426 Mdot
.37643 .61463 Mdot
.40149 .60377 Mdot
.40178 .66366 Mdot
.45615 .65689 Mdot
.41915 .62015 Mdot
.62454 .34729 Mdot
.51342 .28864 Mdot
.56508 .37309 Mdot
.69607 .57019 Mdot
.79146 .61712 Mdot
.47316 .31044 Mdot
.50891 .52074 Mdot
.37762 .35553 Mdot
.2241 .5851 Mdot
.39397 .34988 Mdot
.45011 .27891 Mdot
.40252 .64764 Mdot
.72195 .57139 Mdot
.18686 .4677 Mdot
.41467 .63744 Mdot
.44607 .2899 Mdot
.48277 .33311 Mdot
.52495 .76266 Mdot
.45484 .55179 Mdot
.5792 .41368 Mdot
.29808 .53847 Mdot
.3869 .34341 Mdot
.45847 .66006 Mdot
.24592 .58306 Mdot
.47239 .29128 Mdot
.49281 .31675 Mdot
.31642 .34721 Mdot
.76331 .57361 Mdot
.67351 .59144 Mdot
.67906 .52199 Mdot
.63097 .34944 Mdot
.40071 .60117 Mdot
.46132 .28687 Mdot
.67458 .52498 Mdot
.30913 .46601 Mdot
.64589 .37775 Mdot
.44377 .30277 Mdot
.44297 .60779 Mdot
.43681 .61387 Mdot
.35208 .35991 Mdot
.47327 .43545 Mdot
.50962 .57429 Mdot
.79707 .53818 Mdot
.29187 .52333 Mdot
.38229 .52333 Mdot
.41386 .60004 Mdot
.68242 .54375 Mdot
.52987 .52151 Mdot
.37443 .36248 Mdot
.39639 .6707 Mdot
.60731 .79857 Mdot
.63749 .58036 Mdot
.63024 .37505 Mdot
.50874 .53422 Mdot
.27292 .5979 Mdot
.44215 .6064 Mdot
.41833 .61059 Mdot
.45416 .64614 Mdot
.54081 .81237 Mdot
.50819 .29722 Mdot
.67145 .5432 Mdot
.33961 .35275 Mdot
.66071 .55512 Mdot
.47816 .26195 Mdot
.45895 .45977 Mdot
.41289 .58139 Mdot
.64272 .58786 Mdot
.65767 .56418 Mdot
.62942 .39173 Mdot
.6596 .39011 Mdot
.43695 .33015 Mdot
.43886 .59424 Mdot
.54209 .50122 Mdot
.65939 .58951 Mdot
.50582 .27367 Mdot
.35378 .3591 Mdot
.70902 .37108 Mdot
.3948 .60179 Mdot
.47069 .28733 Mdot
.50488 .56536 Mdot
.69174 .56446 Mdot
.4539 .30777 Mdot
.52255 .5034 Mdot
.34828 .37578 Mdot
.43438 .64645 Mdot
.4945 .22056 Mdot
.50957 .52329 Mdot
.41914 .58703 Mdot
.44296 .73929 Mdot
.42806 .48972 Mdot
.53335 .49008 Mdot
.48789 .27515 Mdot
.51673 .51442 Mdot
.68471 .53927 Mdot
.49009 .76574 Mdot
.49821 .31439 Mdot
.5735 .60359 Mdot
.3641 .53329 Mdot
.48294 .63449 Mdot
.67829 .54933 Mdot
.43761 .38681 Mdot
.77421 .54129 Mdot
.24087 .50553 Mdot
.40139 .62591 Mdot
.45545 .28883 Mdot
.35414 .36501 Mdot
.62328 .38013 Mdot
.65432 .41517 Mdot
.40804 .39315 Mdot
.46426 .31885 Mdot
.42176 .63956 Mdot
.64935 .58299 Mdot
.63317 .37336 Mdot
.54247 .64721 Mdot
.49314 .32633 Mdot
.46978 .27467 Mdot
.43475 .65477 Mdot
.35693 .36127 Mdot
.50777 .47734 Mdot
.50754 .30471 Mdot
.51456 .29555 Mdot
.72005 .65191 Mdot
.3877 .34599 Mdot
.45968 .64227 Mdot
.41082 .70229 Mdot
.39483 .6552 Mdot
.80691 .60278 Mdot
.52221 .50702 Mdot
.69714 .56931 Mdot
.42643 .61771 Mdot
.53183 .25871 Mdot
.50296 .29871 Mdot
.29842 .53825 Mdot
.61341 .33588 Mdot
.66135 .38313 Mdot
.45937 .29611 Mdot
.40552 .62063 Mdot
.6733 .41349 Mdot
.36905 .3372 Mdot
.4586 .64489 Mdot
.48068 .63689 Mdot
.67538 .53298 Mdot
.623 .35507 Mdot
.48208 .71452 Mdot
.62019 .37342 Mdot
.6447 .36189 Mdot
.73429 .59096 Mdot
.43726 .62493 Mdot
.46643 .30888 Mdot
.43616 .30488 Mdot
.4356 .67479 Mdot
.51312 .36227 Mdot
.69159 .58542 Mdot
.51722 .32323 Mdot
.59396 .80644 Mdot
.38035 .62802 Mdot
.50378 .5373 Mdot
.53665 .47295 Mdot
.619 .40641 Mdot
.43359 .61764 Mdot
.68337 .55278 Mdot
.5123 .29698 Mdot
.46057 .28379 Mdot
.39289 .57284 Mdot
.65421 .39259 Mdot
.3737 .37477 Mdot
.48452 .29867 Mdot
.31342 .49596 Mdot
.39756 .62681 Mdot
.5865 .3632 Mdot
.48169 .30088 Mdot
.18455 .61901 Mdot
.53677 .26238 Mdot
.64497 .5676 Mdot
.4529 .63689 Mdot
.70788 .54167 Mdot
.37774 .33893 Mdot
.52238 .28992 Mdot
.63202 .39711 Mdot
.50431 .5535 Mdot
.69257 .26788 Mdot
.46832 .28194 Mdot
.67113 .55985 Mdot
.42967 .62947 Mdot
.65395 .73074 Mdot
.42243 .59055 Mdot
.27423 .41379 Mdot
.32635 .3476 Mdot
.7052 .36518 Mdot
.64112 .40103 Mdot
.45725 .63224 Mdot
.34039 .36631 Mdot
.43398 .30358 Mdot
.48103 .29256 Mdot
.72014 .29916 Mdot
.51653 .50877 Mdot
.5244 .27371 Mdot
.42434 .58681 Mdot
.48795 .26734 Mdot
.63368 .64703 Mdot
.65813 .38714 Mdot
.39746 .65611 Mdot
.44458 .31054 Mdot
.76995 .55385 Mdot
.28992 .53558 Mdot
.39956 .62736 Mdot
.38863 .68696 Mdot
.64298 .39575 Mdot
.77996 .62478 Mdot
.50658 .28809 Mdot
.42034 .67139 Mdot
.60569 .34984 Mdot
.41027 .71288 Mdot
.56787 .4015 Mdot
.67914 .56733 Mdot
.43968 .29922 Mdot
.63854 .35609 Mdot
.49598 .61159 Mdot
.37598 .36984 Mdot
.45788 .3346 Mdot
.44971 .32072 Mdot
.47015 .60186 Mdot
.44492 .66081 Mdot
.38416 .6866 Mdot
.70254 .56092 Mdot
.63573 .36244 Mdot
.47179 .62763 Mdot
.28743 .49693 Mdot
.46296 .6465 Mdot
.63303 .35993 Mdot
.86578 .46171 Mdot
.40717 .64984 Mdot
.39558 .60217 Mdot
.64636 .74277 Mdot
.71197 .56864 Mdot
.65807 .5405 Mdot
.28939 .51561 Mdot
.45422 .59725 Mdot
.41638 .50748 Mdot
.6778 .56393 Mdot
.6677 .5596 Mdot
.41745 .50633 Mdot
.47373 .60402 Mdot
.70556 .53295 Mdot
.63492 .37241 Mdot
.66136 .38441 Mdot
.64929 .57282 Mdot
.3991 .66581 Mdot
.60847 .37079 Mdot
.56135 .75293 Mdot
.44516 .28654 Mdot
.24938 .58813 Mdot
.65435 .56329 Mdot
.28657 .53931 Mdot
.63413 .36763 Mdot
.23337 .65089 Mdot
.24195 .62231 Mdot
.38052 .61495 Mdot
.43645 .62019 Mdot
.35437 .34648 Mdot
.50564 .5541 Mdot
.53222 .51904 Mdot
.65283 .37423 Mdot
.49998 .47066 Mdot
.67704 .57469 Mdot
.44946 .59434 Mdot
.25011 .49073 Mdot
.27212 .70488 Mdot
.34089 .66355 Mdot
.66597 .56592 Mdot
.66612 .57795 Mdot
.47371 .2717 Mdot
.45948 .27006 Mdot
.40454 .5861 Mdot
.64924 .39535 Mdot
.6469 .57525 Mdot
.627 .35932 Mdot
.47359 .29197 Mdot
.47557 .30908 Mdot
.53708 .50465 Mdot
.50147 .60369 Mdot
.46522 .29748 Mdot
.69265 .39805 Mdot
.28821 .49715 Mdot
.6511 .53612 Mdot
.83234 .57827 Mdot
.22661 .63735 Mdot
.69005 .7282 Mdot
.35208 .36523 Mdot
.40188 .71706 Mdot
.61102 .34821 Mdot
.45875 .63094 Mdot
.42208 .60675 Mdot
.5184 .52218 Mdot
.61005 .34736 Mdot
.36702 .34244 Mdot
.65992 .38494 Mdot
.36771 .37226 Mdot
.47984 .32544 Mdot
.41461 .63957 Mdot
.39398 .63572 Mdot
.62483 .38286 Mdot
.46545 .27178 Mdot
.44614 .30295 Mdot
.36256 .36783 Mdot
.22576 .58946 Mdot
.47373 .28586 Mdot
.65547 .56266 Mdot
.56941 .62625 Mdot
.52401 .51353 Mdot
.40995 .61725 Mdot
.23038 .5517 Mdot
.47977 .76461 Mdot
.43338 .67176 Mdot
.50971 .5322 Mdot
.86734 .51428 Mdot
.39782 .63505 Mdot
.67906 .23876 Mdot
.53956 .50118 Mdot
.70938 .56186 Mdot
.45998 .30588 Mdot
.50873 .5224 Mdot
.42632 .71629 Mdot
.41952 .27673 Mdot
.4296 .67575 Mdot
.6728 .59196 Mdot
.70204 .58312 Mdot
.46 .46062 Mdot
.80645 .60657 Mdot
.33974 .35413 Mdot
.3629 .33827 Mdot
.50424 .30472 Mdot
.71002 .36029 Mdot
.37469 .63267 Mdot
.35574 .3394 Mdot
.7291 .54537 Mdot
.44975 .64704 Mdot
.43367 .48539 Mdot
.4793 .45865 Mdot
.67761 .53859 Mdot
.47716 .59276 Mdot
.50384 .3027 Mdot
.67173 .56169 Mdot
.46797 .45985 Mdot
.41715 .66075 Mdot
.67803 .57168 Mdot
.6468 .36494 Mdot
.39256 .54513 Mdot
.65211 .55845 Mdot
.30433 .57336 Mdot
.63169 .38502 Mdot
.44124 .47742 Mdot
.22417 .38833 Mdot
.20459 .67793 Mdot
.65463 .38841 Mdot
.44706 .29524 Mdot
.46215 .28749 Mdot
.48011 .28381 Mdot
.69352 .55047 Mdot
.49695 .2962 Mdot
.69294 .58017 Mdot
.6122 .4053 Mdot
.26026 .60618 Mdot
.3532 .35347 Mdot
.46021 .37903 Mdot
.6494 .56983 Mdot
.81768 .59326 Mdot
.76876 .7387 Mdot
.45967 .64974 Mdot
.65573 .40442 Mdot
.33614 .34421 Mdot
.30822 .53635 Mdot
.35526 .34456 Mdot
.45146 .30246 Mdot
.2684 .59988 Mdot
.40132 .61537 Mdot
.69518 .42622 Mdot
.35552 .36461 Mdot
.66664 .55863 Mdot
.45383 .59157 Mdot
.44367 .27955 Mdot
.3754 .3387 Mdot
.36534 .36332 Mdot
.41762 .6195 Mdot
.70922 .57276 Mdot
.44874 .30426 Mdot
.63274 .34671 Mdot
.39586 .37276 Mdot
.36076 .63005 Mdot
.40303 .63918 Mdot
.38506 .62492 Mdot
.28559 .5304 Mdot
.71209 .36182 Mdot
.63447 .38501 Mdot
.25878 .46302 Mdot
.49876 .285 Mdot
.23921 .5024 Mdot
.78122 .53232 Mdot
.44014 .38115 Mdot
.52201 .50777 Mdot
.52625 .5031 Mdot
.41252 .63226 Mdot
.68757 .7944 Mdot
.44091 .54623 Mdot
.60548 .36722 Mdot
.52275 .51973 Mdot
.45046 .27673 Mdot
.63771 .55656 Mdot
.54968 .56118 Mdot
.37954 .5929 Mdot
.63071 .3461 Mdot
.47873 .2889 Mdot
.60715 .84335 Mdot
.34225 .3475 Mdot
.30908 .53339 Mdot
.43887 .59595 Mdot
.41263 .62763 Mdot
.64454 .38276 Mdot
.62748 .3943 Mdot
.71791 .6535 Mdot
.43043 .42603 Mdot
.73333 .37742 Mdot
.67653 .37875 Mdot
.60387 .8461 Mdot
.5392 .47796 Mdot
.67754 .58077 Mdot
.52432 .5296 Mdot
.63382 .40277 Mdot
.42417 .61461 Mdot
.71119 .56941 Mdot
.51168 .54426 Mdot
.70929 .59003 Mdot
.42352 .49457 Mdot
.30737 .49528 Mdot
.44254 .62236 Mdot
.71834 .55912 Mdot
.67407 .56566 Mdot
.6209 .55426 Mdot
.53139 .51266 Mdot
.41802 .59836 Mdot
.41765 .67311 Mdot
.38832 .61378 Mdot
.68711 .65347 Mdot
.40881 .63409 Mdot
.78131 .53587 Mdot
.29803 .51135 Mdot
.41969 .18512 Mdot
.39283 .62896 Mdot
.65244 .36583 Mdot
.42353 .63625 Mdot
.34118 .3679 Mdot
.42303 .65134 Mdot
.41266 .503 Mdot
.63609 .37616 Mdot
.62412 .7822 Mdot
.41219 .31728 Mdot
.40534 .64199 Mdot
.3864 .35873 Mdot
.81591 .47977 Mdot
.2596 .46618 Mdot
.72111 .65004 Mdot
.65145 .56148 Mdot
.51151 .31265 Mdot
.63302 .40499 Mdot
.48507 .30691 Mdot
.41894 .57212 Mdot
.53571 .51604 Mdot
.18782 .38351 Mdot
.26539 .50863 Mdot
.42537 .61672 Mdot
.50713 .58265 Mdot
.66073 .5456 Mdot
.50238 .30128 Mdot
.7253 .69492 Mdot
.41001 .66457 Mdot
.33477 .37181 Mdot
.33185 .35316 Mdot
.36712 .31557 Mdot
.69931 .62181 Mdot
.65576 .64838 Mdot
.6426 .38271 Mdot
.46904 .27932 Mdot
.33503 .34198 Mdot
.68501 .51918 Mdot
.64399 .40445 Mdot
.61765 .40477 Mdot
.62494 .35375 Mdot
.39352 .61591 Mdot
.53406 .50303 Mdot
.72642 .61711 Mdot
.51526 .51234 Mdot
.3889 .65377 Mdot
.44959 .32014 Mdot
.52047 .5065 Mdot
.35881 .3513 Mdot
.6425 .35891 Mdot
.4702 .31141 Mdot
.42217 .62691 Mdot
.68146 .56187 Mdot
.37794 .43662 Mdot
.51519 .2419 Mdot
.42837 .48894 Mdot
.42849 .48882 Mdot
.62643 .55812 Mdot
.5259 .46864 Mdot
.61938 .32203 Mdot
.51452 .76682 Mdot
.39671 .3796 Mdot
.37029 .64366 Mdot
.52303 .35304 Mdot
.48911 .32587 Mdot
.47212 .30106 Mdot
.40002 .61196 Mdot
.49811 .27213 Mdot
.44065 .59082 Mdot
.48848 .27482 Mdot
.7882 .55777 Mdot
.39188 .57771 Mdot
.48132 .29691 Mdot
.51214 .54872 Mdot
.41726 .58632 Mdot
.67172 .54453 Mdot
.50873 .31296 Mdot
.38041 .61548 Mdot
.30445 .21738 Mdot
.62862 .39051 Mdot
.53067 .51146 Mdot
.35532 .50816 Mdot
.64147 .36766 Mdot
.67821 .58843 Mdot
.44889 .60079 Mdot
.34879 .33933 Mdot
.66895 .5816 Mdot
.39774 .31989 Mdot
.36055 .36216 Mdot
.32391 .51985 Mdot
.6586 .58097 Mdot
.52271 .51218 Mdot
.33602 .37085 Mdot
.4372 .67306 Mdot
.47472 .29914 Mdot
.52372 .24895 Mdot
.50663 .53125 Mdot
.40367 .61182 Mdot
.44499 .27975 Mdot
.65919 .37733 Mdot
.42835 .64164 Mdot
.46062 .28615 Mdot
.51873 .53193 Mdot
.40529 .5913 Mdot
.44925 .59118 Mdot
.76952 .62914 Mdot
.46441 .43047 Mdot
.35561 .35257 Mdot
.6535 .53018 Mdot
.38065 .63951 Mdot
.34522 .3678 Mdot
.52546 .25766 Mdot
.48909 .61409 Mdot
.65194 .58883 Mdot
.5523 .7542 Mdot
.47945 .26605 Mdot
.65277 .3966 Mdot
.43903 .32194 Mdot
.3771 .33673 Mdot
.80896 .70356 Mdot
.53407 .51572 Mdot
.48077 .60575 Mdot
.39398 .64836 Mdot
.52059 .2988 Mdot
.67394 .56855 Mdot
.73676 .38506 Mdot
.43612 .64598 Mdot
.49588 .57815 Mdot
.41352 .61818 Mdot
.47268 .22693 Mdot
.70066 .55537 Mdot
.41174 .61698 Mdot
.38371 .67563 Mdot
.38688 .64242 Mdot
.38302 .35677 Mdot
.19821 .39182 Mdot
.46764 .648 Mdot
.86923 .39033 Mdot
.51602 .53789 Mdot
.48472 .29025 Mdot
.3062 .57126 Mdot
.35763 .50231 Mdot
.35563 .2118 Mdot
.68458 .58719 Mdot
.6183 .54588 Mdot
.47579 .30832 Mdot
.4215 .3866 Mdot
.51312 .47873 Mdot
.45658 .59464 Mdot
.44297 .59943 Mdot
.45155 .30255 Mdot
.50779 .27458 Mdot
.52563 .53043 Mdot
.48174 .64236 Mdot
.48865 .60463 Mdot
.44511 .32252 Mdot
.40989 .6365 Mdot
.46743 .76225 Mdot
.66046 .40404 Mdot
.64452 .56304 Mdot
.62138 .37894 Mdot
.66772 .39547 Mdot
.70391 .72043 Mdot
.28885 .52348 Mdot
.62893 .3488 Mdot
.59956 .35829 Mdot
.43981 .38877 Mdot
.66987 .71686 Mdot
.38229 .36035 Mdot
.43979 .5448 Mdot
.48951 .28235 Mdot
.41997 .59824 Mdot
.69953 .55346 Mdot
.31133 .40131 Mdot
.75192 .38603 Mdot
.34236 .72122 Mdot
.45978 .64066 Mdot
.49941 .28959 Mdot
.50575 .53315 Mdot
.49063 .61927 Mdot
.23668 .5077 Mdot
.40644 .62912 Mdot
.47632 .26495 Mdot
.6737 .71284 Mdot
.59092 .42155 Mdot
.66187 .41823 Mdot
.62557 .5926 Mdot
.42378 .63687 Mdot
.69733 .55783 Mdot
.66514 .36478 Mdot
.34239 .36402 Mdot
.34754 .34753 Mdot
.40596 .64266 Mdot
.38198 .52405 Mdot
.403 .36777 Mdot
.45026 .59043 Mdot
.47501 .60621 Mdot
.51638 .51624 Mdot
.47844 .61027 Mdot
.41282 .67509 Mdot
.46869 .62843 Mdot
.44034 .66582 Mdot
.64194 .40385 Mdot
.70349 .70841 Mdot
.48673 .62829 Mdot
.41767 .57639 Mdot
.6688 .37387 Mdot
.42119 .57387 Mdot
.65245 .3843 Mdot
.71366 .34214 Mdot
.61835 .34992 Mdot
.34741 .34969 Mdot
.45228 .27091 Mdot
.75934 .63641 Mdot
.64773 .57678 Mdot
.66428 .38242 Mdot
.35834 .37769 Mdot
.6559 .37918 Mdot
.4823 .27673 Mdot
.61551 .4367 Mdot
.64741 .60781 Mdot
.31923 .49796 Mdot
.6693 .72737 Mdot
.5799 .35628 Mdot
.48696 .26921 Mdot
.64914 .57564 Mdot
.70262 .38051 Mdot
.45904 .62901 Mdot
.34036 .34903 Mdot
.4134 .63172 Mdot
.64368 .36025 Mdot
.49325 .28468 Mdot
.74568 .64018 Mdot
.35544 .35152 Mdot
.84433 .56175 Mdot
.4552 .32897 Mdot
.40314 .65259 Mdot
.66984 .37439 Mdot
.68644 .40036 Mdot
.6336 .39582 Mdot
.25354 .60466 Mdot
.53211 .47035 Mdot
.34868 .41568 Mdot
.66255 .57906 Mdot
.54289 .49063 Mdot
.28104 .75248 Mdot
.78285 .4682 Mdot
.6879 .56191 Mdot
.52261 .26294 Mdot
.39735 .62976 Mdot
.46541 .63751 Mdot
.50341 .59232 Mdot
.71176 .58127 Mdot
.4538 .64634 Mdot
.53163 .50782 Mdot
.28101 .51454 Mdot
.63231 .60253 Mdot
.47116 .33464 Mdot
.43396 .5895 Mdot
.67193 .37346 Mdot
.66492 .38802 Mdot
.53884 .49584 Mdot
.61823 .36489 Mdot
.42922 .58014 Mdot
.65334 .57482 Mdot
.47308 .45901 Mdot
.37324 .33617 Mdot
.79621 .51702 Mdot
.39004 .32999 Mdot
.39342 .36649 Mdot
.37954 .62575 Mdot
.47154 .30922 Mdot
.67761 .25063 Mdot
.45862 .63502 Mdot
.67549 .56239 Mdot
.39924 .65308 Mdot
.46979 .63241 Mdot
.44089 .57988 Mdot
.46939 .27947 Mdot
.28795 .53619 Mdot
.41074 .63687 Mdot
.65156 .35347 Mdot
.41151 .50956 Mdot
.38127 .58756 Mdot
.51007 .44674 Mdot
.41711 .49978 Mdot
.5855 .37394 Mdot
.66141 .53399 Mdot
.46527 .30802 Mdot
.67484 .57677 Mdot
.69799 .60069 Mdot
.67868 .58813 Mdot
.71743 .61511 Mdot
.50527 .76733 Mdot
.67371 .23154 Mdot
.63909 .64774 Mdot
.67059 .72978 Mdot
.68877 .60489 Mdot
.55516 .1986 Mdot
.68724 .55745 Mdot
.68014 .58813 Mdot
.81236 .39561 Mdot
.70262 .57845 Mdot
.41257 .6086 Mdot
.38908 .63201 Mdot
.56082 .81123 Mdot
.36853 .3904 Mdot
.41298 .59061 Mdot
.43753 .66835 Mdot
.33221 .34744 Mdot
.76295 .57464 Mdot
.50613 .54189 Mdot
.31268 .53427 Mdot
.52417 .4989 Mdot
.41801 .62018 Mdot
.43925 .63475 Mdot
.37597 .58612 Mdot
.29465 .72813 Mdot
.38571 .40595 Mdot
.69972 .58574 Mdot
.38254 .66875 Mdot
.57314 .35607 Mdot
.44885 .62499 Mdot
.41187 .65751 Mdot
.44926 .58322 Mdot
.46655 .30892 Mdot
.63582 .56793 Mdot
.50844 .57185 Mdot
.8012 .49446 Mdot
.44142 .6081 Mdot
.36103 .32572 Mdot
.33082 .37494 Mdot
.4056 .61931 Mdot
.69568 .58481 Mdot
.46327 .63919 Mdot
.64687 .5472 Mdot
.66283 .58272 Mdot
.49467 .59076 Mdot
.73862 .60335 Mdot
.63715 .55943 Mdot
.4572 .59536 Mdot
.47001 .27026 Mdot
.79842 .53574 Mdot
.40355 .61375 Mdot
.36222 .3551 Mdot
.43362 .62173 Mdot
.38434 .35572 Mdot
.47641 .63958 Mdot
.51544 .51388 Mdot
.41232 .76037 Mdot
.49155 .31829 Mdot
.3956 .35004 Mdot
.49383 .26948 Mdot
.3744 .63809 Mdot
.72993 .56702 Mdot
.6012 .42927 Mdot
.41022 .38133 Mdot
.51742 .51486 Mdot
.27288 .43711 Mdot
.43416 .49971 Mdot
.60993 .35335 Mdot
.67234 .54249 Mdot
.69578 .70261 Mdot
.50654 .44628 Mdot
.46335 .3359 Mdot
.44275 .28988 Mdot
.56295 .39243 Mdot
.82778 .42368 Mdot
.39311 .6278 Mdot
.52257 .45701 Mdot
.50055 .72294 Mdot
.50593 .55439 Mdot
.51617 .5454 Mdot
.44944 .32131 Mdot
.414 .58997 Mdot
.26522 .52556 Mdot
.46561 .28822 Mdot
.37578 .34581 Mdot
.69786 .56828 Mdot
.35597 .37242 Mdot
.72347 .43078 Mdot
.72466 .65225 Mdot
.46576 .29464 Mdot
.44804 .66069 Mdot
.40876 .59539 Mdot
.7107 .56197 Mdot
.54266 .64592 Mdot
.64458 .55594 Mdot
.35441 .33548 Mdot
.49992 .31446 Mdot
.24504 .28303 Mdot
.43094 .63005 Mdot
.65939 .56354 Mdot
.41301 .3167 Mdot
.43617 .61102 Mdot
.65526 .39257 Mdot
.45234 .64702 Mdot
.66082 .55774 Mdot
.47997 .61309 Mdot
.66289 .5799 Mdot
.46372 .27567 Mdot
.40026 .64058 Mdot
.4319 .64201 Mdot
.26121 .457 Mdot
.3668 .34294 Mdot
.63958 .55681 Mdot
.27149 .53864 Mdot
.39478 .65517 Mdot
.23234 .52508 Mdot
.41118 .6395 Mdot
.66362 .72605 Mdot
.40092 .69723 Mdot
.53034 .5067 Mdot
.39788 .65262 Mdot
.40268 .61611 Mdot
.54291 .64264 Mdot
.62831 .6467 Mdot
.69012 .65381 Mdot
.65818 .39387 Mdot
.67982 .54689 Mdot
.46074 .29081 Mdot
.51138 .30917 Mdot
.49415 .2998 Mdot
.33514 .33534 Mdot
.42466 .67871 Mdot
.40728 .60383 Mdot
.60412 .36961 Mdot
.34938 .34121 Mdot
.66269 .56854 Mdot
.34803 .35461 Mdot
.29376 .52794 Mdot
.36473 .35365 Mdot
.5307 .52219 Mdot
.54857 .28497 Mdot
.47549 .76278 Mdot
.37401 .35636 Mdot
.64568 .56704 Mdot
.39499 .52184 Mdot
.49738 .5569 Mdot
.79736 .61204 Mdot
.32895 .367 Mdot
.52186 .25913 Mdot
.40394 .59045 Mdot
.29804 .57467 Mdot
.65107 .38147 Mdot
.35594 .37291 Mdot
.62265 .35399 Mdot
.46335 .63805 Mdot
.6073 .55691 Mdot
.67285 .55492 Mdot
.66342 .40262 Mdot
.406 .65859 Mdot
.35479 .37269 Mdot
.46872 .29702 Mdot
.66919 .71609 Mdot
.62736 .41163 Mdot
.39444 .42879 Mdot
.24069 .50386 Mdot
.50565 .30074 Mdot
.64386 .72033 Mdot
.61829 .35204 Mdot
.38151 .6673 Mdot
.36443 .58698 Mdot
.38619 .65706 Mdot
.4468 .30443 Mdot
.4718 .30166 Mdot
.60235 .31952 Mdot
.43432 .64174 Mdot
.48228 .60934 Mdot
.64826 .53517 Mdot
.5049 .30819 Mdot
.67724 .58808 Mdot
.71772 .5536 Mdot
.44772 .29467 Mdot
.64713 .54965 Mdot
.36138 .36306 Mdot
.2564 .56337 Mdot
.61941 .35141 Mdot
.64482 .40019 Mdot
.46454 .29641 Mdot
.47622 .32059 Mdot
.47238 .30953 Mdot
.42259 .66131 Mdot
.66508 .58506 Mdot
.45485 .6297 Mdot
.42608 .63485 Mdot
.4981 .54109 Mdot
.69622 .53303 Mdot
.44789 .64029 Mdot
.48162 .46191 Mdot
.32284 .36173 Mdot
.48555 .29459 Mdot
.62921 .36263 Mdot
.36843 .43665 Mdot
.64181 .34901 Mdot
.38757 .64612 Mdot
.78174 .56654 Mdot
.68377 .54866 Mdot
.35501 .34529 Mdot
.41408 .50127 Mdot
.35452 .34909 Mdot
.66158 .4033 Mdot
.62905 .54842 Mdot
.32039 .5181 Mdot
.42901 .64472 Mdot
.28368 .52849 Mdot
.23327 .41063 Mdot
.77793 .52497 Mdot
.63853 .36311 Mdot
.46133 .64464 Mdot
.53244 .50076 Mdot
.51696 .76789 Mdot
.40426 .60726 Mdot
.38332 .59166 Mdot
.37556 .51178 Mdot
.38744 .64013 Mdot
.66681 .59608 Mdot
.44197 .48108 Mdot
.45586 .66062 Mdot
.38422 .65905 Mdot
.72328 .30955 Mdot
.40644 .59223 Mdot
.42292 .64522 Mdot
.42016 .60294 Mdot
.45233 .6424 Mdot
.70625 .54071 Mdot
.45093 .46434 Mdot
.66492 .36575 Mdot
.25606 .5633 Mdot
.62968 .35141 Mdot
.45782 .29923 Mdot
.4163 .42773 Mdot
.66002 .53707 Mdot
.35516 .34895 Mdot
.53739 .451 Mdot
.27425 .60323 Mdot
.4727 .27159 Mdot
.27173 .42929 Mdot
.37248 .37453 Mdot
.51135 .55612 Mdot
.3797 .33809 Mdot
.4449 .31347 Mdot
.65472 .39117 Mdot
.40312 .64819 Mdot
.66275 .58956 Mdot
.65194 .55741 Mdot
.37898 .64225 Mdot
.80889 .5055 Mdot
.65262 .39798 Mdot
.50327 .36706 Mdot
.39557 .61474 Mdot
.39766 .65631 Mdot
.65446 .54226 Mdot
.50193 .29701 Mdot
.43456 .49832 Mdot
.3771 .36257 Mdot
.44717 .61896 Mdot
.45116 .66141 Mdot
.29216 .52776 Mdot
.6616 .39116 Mdot
.52545 .52213 Mdot
.41643 .59404 Mdot
.30156 .52371 Mdot
.44891 .65098 Mdot
.36989 .62957 Mdot
.46888 .26834 Mdot
.49564 .58365 Mdot
.44168 .63724 Mdot
.6267 .5945 Mdot
.61638 .35332 Mdot
.67706 .56804 Mdot
.6279 .58267 Mdot
.51639 .51352 Mdot
.62927 .39003 Mdot
.44278 .64738 Mdot
.63465 .4087 Mdot
.46739 .63488 Mdot
.42141 .6317 Mdot
.64183 .36366 Mdot
.68164 .58502 Mdot
.73023 .38434 Mdot
.70386 .70726 Mdot
.47328 .62368 Mdot
.43426 .6176 Mdot
.36848 .39034 Mdot
.30569 .38857 Mdot
.43397 .64474 Mdot
.64701 .57263 Mdot
.4372 .61465 Mdot
.61714 .3845 Mdot
.34043 .35606 Mdot
.67827 .55929 Mdot
.50499 .29075 Mdot
.46304 .27699 Mdot
.42369 .30932 Mdot
.53066 .52266 Mdot
.47879 .60533 Mdot
.65377 .53017 Mdot
.70148 .53486 Mdot
.27757 .56433 Mdot
.48465 .2912 Mdot
.34633 .36238 Mdot
.42833 .58593 Mdot
.51704 .55011 Mdot
.66876 .38344 Mdot
.86705 .3796 Mdot
.31782 .51865 Mdot
.32126 .36463 Mdot
.4309 .43184 Mdot
.51486 .52358 Mdot
.39953 .59936 Mdot
.34664 .36975 Mdot
.45015 .29183 Mdot
.46509 .63831 Mdot
.40392 .69544 Mdot
.51882 .25444 Mdot
.47492 .31586 Mdot
.63658 .40974 Mdot
.49592 .27946 Mdot
.37949 .36838 Mdot
.53279 .51784 Mdot
.66722 .54798 Mdot
.40455 .62425 Mdot
.49248 .61764 Mdot
.48609 .28448 Mdot
.54177 .50737 Mdot
.39064 .63092 Mdot
.68467 .5463 Mdot
.49346 .29336 Mdot
.41903 .61553 Mdot
.52763 .76023 Mdot
.76046 .63394 Mdot
.4938 .28339 Mdot
.4497 .60575 Mdot
.5484 .57685 Mdot
.47103 .31507 Mdot
.44599 .31322 Mdot
.45882 .65 Mdot
.35006 .37365 Mdot
.44344 .62447 Mdot
.64844 .3945 Mdot
.28239 .53419 Mdot
.62577 .38496 Mdot
.23525 .50828 Mdot
.42597 .66825 Mdot
.34425 .629 Mdot
.71736 .58454 Mdot
.39818 .34419 Mdot
.22536 .62688 Mdot
.38042 .63253 Mdot
.72768 .53094 Mdot
.28551 .53841 Mdot
.33231 .50413 Mdot
.67033 .50852 Mdot
.37288 .36888 Mdot
.65293 .3753 Mdot
.41294 .64379 Mdot
.72159 .37857 Mdot
.37113 .36775 Mdot
.23495 .5103 Mdot
.45735 .61239 Mdot
.66748 .56307 Mdot
.39485 .62006 Mdot
.66678 .54994 Mdot
.43075 .60321 Mdot
.77103 .62737 Mdot
.4015 .37078 Mdot
.25392 .60503 Mdot
.50976 .55623 Mdot
.68603 .40076 Mdot
.66956 .72771 Mdot
.35411 .36202 Mdot
.4791 .61816 Mdot
.5154 .52771 Mdot
.66007 .38456 Mdot
.62169 .45028 Mdot
.47734 .30842 Mdot
.64933 .35285 Mdot
.68502 .5795 Mdot
.43704 .28889 Mdot
.54277 .50046 Mdot
.36439 .70633 Mdot
.3517 .37245 Mdot
.63011 .39121 Mdot
.40322 .61908 Mdot
.38776 .65711 Mdot
.47408 .22619 Mdot
.1935 .39918 Mdot
.71807 .55002 Mdot
.85685 .54156 Mdot
.63212 .54527 Mdot
.36466 .33983 Mdot
.46171 .27122 Mdot
.42518 .61306 Mdot
.43407 .59324 Mdot
.47791 .31554 Mdot
.70799 .55684 Mdot
.39397 .3605 Mdot
.34287 .41322 Mdot
.60639 .36816 Mdot
.20436 .41637 Mdot
.67808 .55613 Mdot
.20477 .41454 Mdot
.46278 .35817 Mdot
.75484 .60965 Mdot
.22505 .60173 Mdot
.63827 .3697 Mdot
.20389 .41622 Mdot
.66425 .56227 Mdot
.3905 .61512 Mdot
.52104 .51526 Mdot
.5387 .5106 Mdot
.69511 .55847 Mdot
.45295 .30474 Mdot
.37207 .37339 Mdot
.39611 .61994 Mdot
.39276 .70794 Mdot
.54257 .64724 Mdot
.48274 .32437 Mdot
.50258 .5747 Mdot
.6298 .36982 Mdot
.43555 .61314 Mdot
.33487 .34364 Mdot
.63858 .37107 Mdot
.52109 .50376 Mdot
.26851 .59809 Mdot
.44892 .60108 Mdot
.3996 .51294 Mdot
.64876 .38364 Mdot
.30322 .38829 Mdot
.43405 .64032 Mdot
.61835 .35209 Mdot
.49171 .61394 Mdot
.57149 .33822 Mdot
.46367 .47632 Mdot
.78219 .46833 Mdot
.43725 .32481 Mdot
.48785 .2749 Mdot
.29734 .22951 Mdot
.35922 .21922 Mdot
.64594 .35575 Mdot
.50614 .5361 Mdot
.19614 .38997 Mdot
.61673 .35687 Mdot
.43542 .64822 Mdot
.40202 .63681 Mdot
.6742 .71249 Mdot
.50157 .55383 Mdot
.51738 .53653 Mdot
.6088 .59058 Mdot
.43934 .58202 Mdot
.5025 .57156 Mdot
.42522 .6417 Mdot
.70367 .58266 Mdot
.63192 .37171 Mdot
.42219 .83298 Mdot
.64681 .40674 Mdot
.34495 .63875 Mdot
.49014 .28264 Mdot
.43266 .31519 Mdot
.40638 .62035 Mdot
.56917 .5428 Mdot
.61093 .84546 Mdot
.40401 .63894 Mdot
.41325 .50198 Mdot
.24081 .50057 Mdot
.41049 .67972 Mdot
.6417 .58171 Mdot
.49242 .61321 Mdot
.68234 .52762 Mdot
.64345 .37009 Mdot
.37241 .36889 Mdot
.40063 .34297 Mdot
.6523 .37647 Mdot
.43117 .59355 Mdot
.39249 .33303 Mdot
.41302 .62497 Mdot
.40015 .60231 Mdot
.302 .52792 Mdot
.34029 .33959 Mdot
.4617 .30975 Mdot
.34881 .34847 Mdot
.68881 .58604 Mdot
.86708 .47899 Mdot
.34965 .35879 Mdot
.67018 .71661 Mdot
.27457 .5372 Mdot
.202 .38893 Mdot
.65401 .55346 Mdot
.37521 .33687 Mdot
.65411 .37266 Mdot
.3344 .52583 Mdot
.63417 .74907 Mdot
.63958 .34849 Mdot
.41008 .59938 Mdot
.71005 .54307 Mdot
.62871 .55175 Mdot
.65315 .35175 Mdot
.66789 .54541 Mdot
.4205 .6849 Mdot
.4651 .60391 Mdot
.66198 .3616 Mdot
.26144 .69817 Mdot
.64242 .40138 Mdot
.71474 .71029 Mdot
.47812 .60683 Mdot
.67681 .56118 Mdot
.66165 .73044 Mdot
.62198 .57692 Mdot
.53716 .50656 Mdot
.41913 .6508 Mdot
.34711 .36037 Mdot
.27016 .55705 Mdot
.50082 .28851 Mdot
.77048 .55329 Mdot
.65257 .56286 Mdot
.6504 .34882 Mdot
.66854 .54583 Mdot
.66777 .5417 Mdot
.66723 .3991 Mdot
.68345 .54959 Mdot
.44078 .60607 Mdot
.77671 .62826 Mdot
.65387 .54872 Mdot
.64132 .37996 Mdot
.35721 .33574 Mdot
.64509 .56807 Mdot
.49228 .37588 Mdot
.42774 .58718 Mdot
.48726 .3285 Mdot
.30937 .37702 Mdot
.71598 .5545 Mdot
.35306 .36279 Mdot
.4881 .28719 Mdot
.34836 .37708 Mdot
.69763 .33872 Mdot
.698 .37943 Mdot
.43328 .71857 Mdot
.56679 .33896 Mdot
.70036 .58024 Mdot
.43392 .29275 Mdot
.44585 .60486 Mdot
.39622 .61065 Mdot
.32903 .34363 Mdot
.64107 .58788 Mdot
.81306 .49456 Mdot
.50509 .54742 Mdot
.79646 .51566 Mdot
.65865 .39401 Mdot
.47927 .37534 Mdot
.32055 .51563 Mdot
.61067 .41633 Mdot
.45973 .65902 Mdot
.51546 .52348 Mdot
.41336 .61736 Mdot
.25882 .46742 Mdot
.37903 .36799 Mdot
.55284 .21259 Mdot
.40289 .66603 Mdot
.4826 .31533 Mdot
.42817 .60451 Mdot
.50814 .47037 Mdot
.39004 .66478 Mdot
.32174 .35808 Mdot
.60593 .34925 Mdot
.64749 .57629 Mdot
.3822 .34394 Mdot
.46036 .27798 Mdot
.26086 .62928 Mdot
.44297 .64088 Mdot
.42484 .58117 Mdot
.4581 .31333 Mdot
.67237 .59 Mdot
.46306 .30143 Mdot
.62029 .35136 Mdot
.35125 .35702 Mdot
.44365 .65189 Mdot
.4995 .57253 Mdot
.5211 .29734 Mdot
.66536 .37745 Mdot
.44989 .27563 Mdot
.64066 .40894 Mdot
.51778 .51741 Mdot
.38162 .66064 Mdot
.46117 .26602 Mdot
.46439 .65483 Mdot
.63372 .69084 Mdot
.27425 .59753 Mdot
.55051 .61955 Mdot
.45135 .30689 Mdot
.3643 .20694 Mdot
.63993 .374 Mdot
.62128 .38509 Mdot
.7208 .707 Mdot
.67511 .80417 Mdot
.41706 .50702 Mdot
.80998 .46573 Mdot
.6202 .35118 Mdot
.64665 .3882 Mdot
.46223 .30433 Mdot
.69167 .58253 Mdot
.71648 .58251 Mdot
.44202 .28628 Mdot
.23069 .55779 Mdot
.66252 .56829 Mdot
.58219 .80957 Mdot
.48041 .32792 Mdot
.43403 .57619 Mdot
.75349 .63599 Mdot
.32416 .36177 Mdot
.24829 .49713 Mdot
.6135 .4375 Mdot
.41869 .60969 Mdot
.68404 .24375 Mdot
.47876 .30684 Mdot
.52553 .53493 Mdot
.64274 .33101 Mdot
.40817 .6626 Mdot
.42434 .60108 Mdot
.44016 .61244 Mdot
.3166 .34811 Mdot
.60942 .6539 Mdot
.42159 .61099 Mdot
.26416 .60257 Mdot
.40368 .57278 Mdot
.50013 .22504 Mdot
.3486 .34886 Mdot
.27261 .41661 Mdot
.50021 .25888 Mdot
.80118 .4861 Mdot
.37955 .60405 Mdot
.6122 .36851 Mdot
.49352 .46202 Mdot
.64122 .36203 Mdot
.58798 .36671 Mdot
.18957 .45244 Mdot
.66743 .59505 Mdot
.40875 .6656 Mdot
.46899 .32666 Mdot
.72022 .57829 Mdot
.48893 .46066 Mdot
.86992 .49037 Mdot
.63686 .34217 Mdot
.82724 .68836 Mdot
.61698 .37316 Mdot
.52836 .52841 Mdot
.6885 .57626 Mdot
.57485 .5773 Mdot
.28488 .52732 Mdot
.67847 .58745 Mdot
.41074 .21535 Mdot
.68875 .52806 Mdot
.19951 .5388 Mdot
.65322 .60866 Mdot
.63632 .38086 Mdot
.65315 .35126 Mdot
.41601 .69346 Mdot
.44426 .62624 Mdot
.27405 .51795 Mdot
.50474 .5508 Mdot
.44933 .59884 Mdot
.4656 .28787 Mdot
.56556 .33558 Mdot
.71878 .37039 Mdot
.68558 .55211 Mdot
.66383 .37167 Mdot
.42597 .60301 Mdot
.47406 .62348 Mdot
.391 .63888 Mdot
.42002 .38899 Mdot
.57247 .81328 Mdot
.42031 .63475 Mdot
.37344 .64034 Mdot
.46823 .2721 Mdot
.47248 .22585 Mdot
.83488 .45988 Mdot
.1959 .43357 Mdot
.3895 .60342 Mdot
.36004 .34104 Mdot
.34051 .33658 Mdot
.40107 .6902 Mdot
.57551 .56969 Mdot
.31502 .32648 Mdot
.40322 .61847 Mdot
.26665 .6203 Mdot
.50919 .31783 Mdot
.53755 .49687 Mdot
.48544 .28467 Mdot
.70789 .59595 Mdot
.52912 .50211 Mdot
.4567 .28892 Mdot
.24818 .5922 Mdot
.50992 .52378 Mdot
.57891 .33407 Mdot
.37 .33468 Mdot
.4292 .64123 Mdot
.70704 .68695 Mdot
.50559 .30751 Mdot
.64341 .39333 Mdot
.68505 .57265 Mdot
.65694 .39432 Mdot
.52668 .25299 Mdot
.23147 .53803 Mdot
.53438 .5094 Mdot
.6127 .37064 Mdot
.39583 .51634 Mdot
.35488 .34158 Mdot
.61675 .36504 Mdot
.35657 .5975 Mdot
.38585 .57976 Mdot
.58689 .8385 Mdot
.42402 .58311 Mdot
.60352 .31998 Mdot
.62959 .39262 Mdot
.52838 .49882 Mdot
.4051 .62587 Mdot
.45787 .33079 Mdot
.42776 .70118 Mdot
.41447 .62516 Mdot
.50741 .29351 Mdot
.40188 .63502 Mdot
.3366 .35878 Mdot
.63157 .54258 Mdot
.28819 .54186 Mdot
.40775 .42328 Mdot
.37974 .36431 Mdot
.28431 .59361 Mdot
.43236 .64596 Mdot
.38218 .21821 Mdot
.66858 .56579 Mdot
.38691 .64479 Mdot
.22548 .48527 Mdot
.70004 .57152 Mdot
.6719 .57776 Mdot
.46416 .59667 Mdot
.62552 .39612 Mdot
.459 .31081 Mdot
.35165 .34343 Mdot
.63412 .41623 Mdot
.42065 .61476 Mdot
.46103 .64435 Mdot
.38138 .36117 Mdot
.63765 .3928 Mdot
.44303 .65114 Mdot
.71878 .48471 Mdot
.25848 .57005 Mdot
.6606 .40292 Mdot
.38074 .58846 Mdot
.61753 .79786 Mdot
.6884 .54237 Mdot
.68182 .24131 Mdot
.40054 .37234 Mdot
.44911 .28422 Mdot
.50151 .58248 Mdot
.86942 .40264 Mdot
.3564 .33522 Mdot
.78758 .51355 Mdot
.3915 .62272 Mdot
.4289 .61694 Mdot
.70184 .5821 Mdot
.45275 .6313 Mdot
.682 .54748 Mdot
.45867 .38572 Mdot
.70231 .78469 Mdot
.65846 .55089 Mdot
.66495 .55412 Mdot
.40742 .54868 Mdot
.41246 .34478 Mdot
.6965 .56771 Mdot
.44488 .6358 Mdot
.41873 .1927 Mdot
.36232 .6574 Mdot
.38821 .36903 Mdot
.31149 .35575 Mdot
.64199 .57849 Mdot
.63435 .75406 Mdot
.37075 .58301 Mdot
.58119 .79496 Mdot
.31066 .32903 Mdot
.64156 .35375 Mdot
.47136 .63859 Mdot
.50855 .53732 Mdot
.48892 .29562 Mdot
.49191 .6075 Mdot
.43425 .63896 Mdot
.65664 .59005 Mdot
.3301 .37169 Mdot
.6186 .35772 Mdot
.47272 .64988 Mdot
.49779 .32895 Mdot
.37846 .35755 Mdot
.6548 .54443 Mdot
.68591 .7288 Mdot
.38252 .32932 Mdot
.50744 .581 Mdot
.39247 .60555 Mdot
.48574 .62149 Mdot
.51652 .55325 Mdot
.65084 .37642 Mdot
.43822 .29785 Mdot
.50651 .5819 Mdot
.31929 .5411 Mdot
.2489 .56406 Mdot
.3835 .61758 Mdot
.64609 .57059 Mdot
.66284 .38081 Mdot
.53021 .52013 Mdot
.19899 .38547 Mdot
.40407 .58861 Mdot
.58253 .81004 Mdot
.37102 .42467 Mdot
.51076 .52933 Mdot
.72305 .57406 Mdot
.35325 .34632 Mdot
.47802 .60829 Mdot
.26011 .6026 Mdot
.45235 .60255 Mdot
.38331 .67044 Mdot
.44668 .29817 Mdot
.63048 .35536 Mdot
.42993 .71836 Mdot
.48499 .29707 Mdot
.67387 .57715 Mdot
.54576 .80219 Mdot
.71807 .56704 Mdot
.71844 .55399 Mdot
.74506 .59621 Mdot
.64551 .39828 Mdot
.8696 .39845 Mdot
.30538 .38475 Mdot
.39654 .64071 Mdot
.61719 .34726 Mdot
.69302 .56508 Mdot
.44451 .64271 Mdot
.68341 .54834 Mdot
.63731 .57284 Mdot
.44291 .58891 Mdot
.45138 .59375 Mdot
.25821 .60712 Mdot
.6144 .79359 Mdot
.34051 .34977 Mdot
.70888 .56022 Mdot
.62195 .77984 Mdot
.42511 .61512 Mdot
.44132 .63298 Mdot
.49584 .46179 Mdot
.38571 .34848 Mdot
.44205 .77645 Mdot
.39376 .6144 Mdot
.26055 .45328 Mdot
.43388 .64774 Mdot
.65996 .60507 Mdot
.66945 .41108 Mdot
.34668 .62087 Mdot
.44926 .2779 Mdot
.70949 .5587 Mdot
.32418 .36604 Mdot
.72152 .58684 Mdot
.48596 .76515 Mdot
.65733 .37957 Mdot
.66103 .55762 Mdot
.43623 .29754 Mdot
.63704 .38983 Mdot
.64088 .40096 Mdot
.48693 .45947 Mdot
.43692 .31194 Mdot
.33127 .37307 Mdot
.62517 .36724 Mdot
.53376 .75888 Mdot
.63599 .38327 Mdot
.47888 .77376 Mdot
.40293 .586 Mdot
.26291 .60149 Mdot
.49595 .61671 Mdot
.39757 .69605 Mdot
.62435 .37789 Mdot
.37949 .36064 Mdot
.43861 .6533 Mdot
.66283 .54419 Mdot
.35651 .33744 Mdot
.72456 .64893 Mdot
.43287 .30424 Mdot
.64057 .53978 Mdot
.61958 .40572 Mdot
.70641 .56611 Mdot
.24358 .50137 Mdot
.32684 .37433 Mdot
.49938 .44229 Mdot
.30003 .53773 Mdot
.50452 .5651 Mdot
.38101 .65367 Mdot
.43125 .65701 Mdot
.4387 .60225 Mdot
.48977 .28178 Mdot
.3202 .34329 Mdot
.64259 .56038 Mdot
.44839 .72706 Mdot
.6409 .39609 Mdot
.43237 .48969 Mdot
.51441 .55436 Mdot
.46609 .63547 Mdot
.69058 .56422 Mdot
.63643 .56476 Mdot
.62224 .64668 Mdot
.47684 .31351 Mdot
.37847 .68053 Mdot
.3808 .62685 Mdot
.41557 .72069 Mdot
.62492 .38082 Mdot
.76941 .47439 Mdot
.50363 .32095 Mdot
.83307 .68295 Mdot
.48364 .29585 Mdot
.47028 .43555 Mdot
.69272 .55119 Mdot
.36392 .35782 Mdot
.42462 .59099 Mdot
.66381 .62134 Mdot
.72364 .55457 Mdot
.42031 .27192 Mdot
.35801 .34979 Mdot
.707 .32881 Mdot
.62416 .34857 Mdot
.47138 .65134 Mdot
.43418 .6479 Mdot
.46287 .62113 Mdot
.45039 .6214 Mdot
.65265 .35799 Mdot
.4594 .60313 Mdot
.63487 .41186 Mdot
.48133 .76342 Mdot
.22341 .4881 Mdot
.4531 .31978 Mdot
.49233 .20999 Mdot
.71395 .54915 Mdot
.48061 .79322 Mdot
.45826 .76983 Mdot
.27279 .59623 Mdot
.59379 .36266 Mdot
.42902 .67434 Mdot
.45869 .30645 Mdot
.71225 .38001 Mdot
.4551 .3213 Mdot
.47355 .8436 Mdot
.67634 .71234 Mdot
.68354 .31516 Mdot
.45988 .61867 Mdot
.443 .30225 Mdot
.63497 .75951 Mdot
.50238 .60108 Mdot
.3915 .33293 Mdot
.50124 .76486 Mdot
.70048 .65404 Mdot
.33867 .35136 Mdot
.41473 .59071 Mdot
.69867 .53412 Mdot
.42883 .59142 Mdot
.42198 .5904 Mdot
.39015 .62786 Mdot
.67202 .38387 Mdot
.39779 .58917 Mdot
.44365 .61555 Mdot
.20753 .33045 Mdot
.38237 .31429 Mdot
.49067 .27515 Mdot
.56461 .59603 Mdot
.3492 .34124 Mdot
.70702 .59675 Mdot
.29267 .5405 Mdot
.62596 .39229 Mdot
.61885 .64641 Mdot
.4673 .60195 Mdot
.77947 .53879 Mdot
.63255 .40322 Mdot
.35272 .37524 Mdot
.5108 .53459 Mdot
.7575 .38094 Mdot
.48293 .26546 Mdot
.51499 .53705 Mdot
.50445 .29621 Mdot
.39206 .73713 Mdot
.67178 .54882 Mdot
.50426 .56523 Mdot
.62057 .35959 Mdot
.45175 .32244 Mdot
.26998 .60635 Mdot
.43878 .62198 Mdot
.4496 .30595 Mdot
.49845 .59645 Mdot
.26969 .5542 Mdot
.28552 .5371 Mdot
.44186 .31114 Mdot
.60869 .37351 Mdot
.6291 .38558 Mdot
.34128 .34188 Mdot
.68139 .5422 Mdot
.66881 .59085 Mdot
.63173 .38304 Mdot
.71088 .29716 Mdot
.41917 .61392 Mdot
.42575 .63187 Mdot
.31912 .52712 Mdot
.42263 .6559 Mdot
.36517 .39013 Mdot
.51147 .54109 Mdot
.65579 .58655 Mdot
.43452 .65527 Mdot
.4445 .64996 Mdot
.40108 .59392 Mdot
.22819 .56396 Mdot
.49109 .28569 Mdot
.44353 .58315 Mdot
.35014 .37126 Mdot
.71636 .65259 Mdot
.44528 .6073 Mdot
.5086 .58323 Mdot
.69129 .54891 Mdot
.56716 .39662 Mdot
.64506 .39316 Mdot
.4815 .32313 Mdot
.47307 .32573 Mdot
.22703 .42155 Mdot
.71474 .57075 Mdot
.51382 .53869 Mdot
.51809 .25281 Mdot
.52861 .52426 Mdot
.36117 .35034 Mdot
.45643 .48297 Mdot
.47387 .25456 Mdot
.49203 .27626 Mdot
.67884 .39148 Mdot
.38922 .65337 Mdot
.44603 .61253 Mdot
.80582 .49626 Mdot
.41441 .64064 Mdot
.34314 .35789 Mdot
.60839 .35635 Mdot
.66323 .55783 Mdot
.33378 .3571 Mdot
.61589 .3751 Mdot
.67457 .58883 Mdot
.40952 .57275 Mdot
.44033 .64472 Mdot
.68025 .57636 Mdot
.65901 .54208 Mdot
.41002 .60899 Mdot
.18371 .48044 Mdot
.64918 .58236 Mdot
.68614 .57469 Mdot
.71157 .65321 Mdot
.48357 .26694 Mdot
.42979 .70072 Mdot
.61685 .38316 Mdot
.44289 .61556 Mdot
.4557 .31885 Mdot
.37053 .35111 Mdot
.65069 .56945 Mdot
.46952 .6426 Mdot
.42193 .62083 Mdot
.35886 .34163 Mdot
.37484 .33333 Mdot
.37713 .34067 Mdot
.65414 .35262 Mdot
.45809 .59598 Mdot
.69389 .57222 Mdot
.6412 .34986 Mdot
.32958 .34736 Mdot
.38855 .34845 Mdot
.20347 .57227 Mdot
.41595 .61 Mdot
.35924 .33001 Mdot
.86582 .46475 Mdot
.24334 .61101 Mdot
.54034 .49988 Mdot
.42215 .32305 Mdot
.36977 .19952 Mdot
.30324 .37077 Mdot
.63604 .35608 Mdot
.4299 .48945 Mdot
.37487 .37561 Mdot
.47967 .64023 Mdot
.43364 .62959 Mdot
.49563 .56066 Mdot
.36011 .33744 Mdot
.23085 .53634 Mdot
.674 .59504 Mdot
.53614 .68115 Mdot
.34868 .34155 Mdot
.44302 .31826 Mdot
.51912 .30552 Mdot
.47572 .30001 Mdot
.39165 .66751 Mdot
.38111 .73955 Mdot
.5283 .74278 Mdot
.43892 .77198 Mdot
.61925 .34917 Mdot
.63635 .56745 Mdot
.74035 .64523 Mdot
.66975 .57811 Mdot
.49648 .30074 Mdot
.37838 .36202 Mdot
.69482 .58645 Mdot
.64763 .39976 Mdot
.62738 .38289 Mdot
.46995 .26425 Mdot
.48412 .28782 Mdot
.46723 .29572 Mdot
.69985 .54774 Mdot
.68888 .55009 Mdot
.45569 .63337 Mdot
.64755 .55771 Mdot
.41186 .38547 Mdot
.43833 .38683 Mdot
.51158 .27223 Mdot
.64592 .37689 Mdot
.66197 .58194 Mdot
.42653 .64296 Mdot
.38843 .49656 Mdot
.52532 .27244 Mdot
.32584 .36163 Mdot
.78252 .62476 Mdot
.6597 .81805 Mdot
.42909 .66199 Mdot
.657 .36551 Mdot
.51427 .54314 Mdot
.43588 .60222 Mdot
.44643 .28603 Mdot
.3447 .42169 Mdot
.50849 .5239 Mdot
.4427 .59514 Mdot
.40103 .57754 Mdot
.65888 .38408 Mdot
.29605 .54158 Mdot
.47505 .64615 Mdot
.46812 .45799 Mdot
.60522 .3566 Mdot
.51156 .31155 Mdot
.32855 .20433 Mdot
.61945 .59842 Mdot
.27908 .44938 Mdot
.52686 .50222 Mdot
.4022 .58899 Mdot
.46763 .28502 Mdot
.33521 .36568 Mdot
.472 .28789 Mdot
.69174 .60405 Mdot
.47947 .26601 Mdot
.41008 .64162 Mdot
.69599 .57192 Mdot
.63114 .39135 Mdot
.35089 .50458 Mdot
.48669 .69599 Mdot
.46259 .33175 Mdot
.54182 .50932 Mdot
.44977 .5931 Mdot
.53035 .76411 Mdot
.39849 .69652 Mdot
.44249 .635 Mdot
.64066 .36302 Mdot
.6879 .55603 Mdot
.66073 .38977 Mdot
.42327 .70258 Mdot
.60962 .53141 Mdot
.64839 .39259 Mdot
.35628 .58988 Mdot
.37498 .37249 Mdot
.23033 .54755 Mdot
.39959 .6225 Mdot
.62208 .35727 Mdot
.43322 .58481 Mdot
.71064 .56658 Mdot
.24854 .58152 Mdot
.26303 .57791 Mdot
.6326 .36916 Mdot
.52836 .46605 Mdot
.27264 .54099 Mdot
.43178 .69988 Mdot
.62614 .351 Mdot
.24644 .64283 Mdot
.52017 .5271 Mdot
.37705 .35736 Mdot
.38472 .33979 Mdot
.3659 .36624 Mdot
.42729 .63415 Mdot
.64602 .77045 Mdot
.3465 .33713 Mdot
.62228 .33577 Mdot
.34264 .36394 Mdot
.38873 .43028 Mdot
.81094 .50337 Mdot
.37691 .36983 Mdot
.40293 .62954 Mdot
.34825 .66867 Mdot
.42187 .49588 Mdot
.44168 .32665 Mdot
.74244 .38962 Mdot
.21562 .31946 Mdot
.42504 .61219 Mdot
.77115 .62958 Mdot
.61777 .5744 Mdot
.46585 .43026 Mdot
.26675 .58556 Mdot
.36103 .53508 Mdot
.67499 .58145 Mdot
.29793 .53938 Mdot
.67517 .53452 Mdot
.50867 .5654 Mdot
.42058 .63279 Mdot
.71071 .56096 Mdot
.76934 .55563 Mdot
.22601 .63365 Mdot
.79412 .52652 Mdot
.66435 .58534 Mdot
.61621 .35348 Mdot
.64867 .36296 Mdot
.63701 .36289 Mdot
.47692 .27828 Mdot
.66086 .55495 Mdot
.43383 .57962 Mdot
.45662 .27855 Mdot
.40533 .6006 Mdot
.63119 .37522 Mdot
.26663 .59008 Mdot
.66533 .55475 Mdot
.40252 .61784 Mdot
.62734 .76992 Mdot
.50406 .30234 Mdot
.3574 .34036 Mdot
.77979 .62523 Mdot
.42601 .30702 Mdot
.62896 .40395 Mdot
.67976 .60559 Mdot
.39367 .31501 Mdot
.449 .46458 Mdot
.3844 .61763 Mdot
.40537 .64858 Mdot
.42862 .48832 Mdot
.68321 .71422 Mdot
.46325 .65264 Mdot
.4617 .27749 Mdot
.49025 .27054 Mdot
.42159 .58572 Mdot
.65787 .55506 Mdot
.37168 .37985 Mdot
.35758 .32775 Mdot
.36936 .63845 Mdot
.28437 .53095 Mdot
.26442 .60235 Mdot
.44476 .64602 Mdot
.46549 .56287 Mdot
.43601 .29957 Mdot
.54103 .49879 Mdot
.29247 .52913 Mdot
.36039 .36378 Mdot
.39198 .61238 Mdot
.55254 .62592 Mdot
.65368 .56443 Mdot
.45241 .30806 Mdot
.67198 .37583 Mdot
.38722 .33066 Mdot
.50842 .27138 Mdot
.42125 .58581 Mdot
.44373 .6505 Mdot
.61801 .36332 Mdot
.66671 .60511 Mdot
.37593 .34522 Mdot
.45914 .27652 Mdot
.36224 .36007 Mdot
.67766 .54974 Mdot
.65016 .57239 Mdot
.38621 .6333 Mdot
.384 .69021 Mdot
.47377 .33011 Mdot
.39753 .67445 Mdot
.45291 .29726 Mdot
.47464 .22584 Mdot
.66875 .38291 Mdot
.38742 .64437 Mdot
.70981 .58926 Mdot
.63025 .37795 Mdot
.42504 .60847 Mdot
.4372 .4805 Mdot
.45188 .64629 Mdot
.44211 .30358 Mdot
.32395 .41093 Mdot
.37246 .36015 Mdot
.468 .58461 Mdot
.66772 .64837 Mdot
.42984 .65415 Mdot
.51084 .29913 Mdot
.52414 .75367 Mdot
.65237 .3873 Mdot
.69981 .55758 Mdot
.53756 .27678 Mdot
.63983 .38155 Mdot
.3982 .62902 Mdot
.3486 .35827 Mdot
.64642 .54914 Mdot
.5317 .50309 Mdot
.28067 .50081 Mdot
.41038 .69952 Mdot
.37359 .67302 Mdot
.46779 .65007 Mdot
.81208 .47156 Mdot
.46865 .29328 Mdot
.69174 .56585 Mdot
.65308 .36253 Mdot
.65602 .38333 Mdot
.50215 .298 Mdot
.69569 .65127 Mdot
.79331 .5681 Mdot
.86793 .44347 Mdot
.51737 .2782 Mdot
.35727 .36813 Mdot
.2501 .58216 Mdot
.47498 .30135 Mdot
.49874 .28535 Mdot
.44305 .2731 Mdot
.80598 .49006 Mdot
.67636 .58501 Mdot
.4229 .62085 Mdot
.76493 .63148 Mdot
.39165 .62977 Mdot
.28136 .45487 Mdot
.63217 .37552 Mdot
.7002 .55784 Mdot
.46949 .3916 Mdot
.38629 .66206 Mdot
.42722 .59681 Mdot
.50245 .37071 Mdot
.50572 .54854 Mdot
.20134 .39702 Mdot
.39885 .65037 Mdot
.47795 .283 Mdot
.67345 .51705 Mdot
.50634 .57906 Mdot
.62822 .77034 Mdot
.62488 .38414 Mdot
.53536 .51011 Mdot
.50778 .57223 Mdot
.46507 .55946 Mdot
.68027 .53449 Mdot
.68547 .59084 Mdot
.37828 .33649 Mdot
.77094 .58096 Mdot
.6246 .38517 Mdot
.77825 .46216 Mdot
.4423 .63699 Mdot
.58775 .37252 Mdot
.35142 .41662 Mdot
.42134 .60474 Mdot
.48399 .45978 Mdot
.62238 .64631 Mdot
.46291 .64664 Mdot
.44799 .76273 Mdot
.64005 .37611 Mdot
.23316 .47999 Mdot
.4584 .6085 Mdot
.45068 .30564 Mdot
.69654 .57988 Mdot
.64293 .53751 Mdot
.33136 .36127 Mdot
.39688 .39096 Mdot
.7514 .7498 Mdot
.70133 .55929 Mdot
.43972 .62299 Mdot
.64832 .3887 Mdot
.53537 .50434 Mdot
.49451 .61841 Mdot
.52543 .4627 Mdot
.65451 .56646 Mdot
.50381 .59294 Mdot
.78041 .54207 Mdot
.29641 .54006 Mdot
.49986 .79932 Mdot
.63172 .36462 Mdot
.34995 .36472 Mdot
.36382 .62812 Mdot
.48621 .23508 Mdot
.43732 .64714 Mdot
.28053 .45319 Mdot
.61949 .55822 Mdot
.34428 .36057 Mdot
.43088 .59454 Mdot
.45607 .6594 Mdot
.29068 .59232 Mdot
.38787 .37206 Mdot
.47027 .64775 Mdot
.42168 .66423 Mdot
.69503 .58354 Mdot
.51397 .53963 Mdot
.66211 .56091 Mdot
.42492 .59223 Mdot
.28234 .38543 Mdot
.70736 .5599 Mdot
.7347 .38905 Mdot
.35314 .32693 Mdot
.62282 .38942 Mdot
.49394 .58537 Mdot
.3869 .6069 Mdot
.49797 .80642 Mdot
.53773 .50729 Mdot
.72725 .32209 Mdot
.44689 .30868 Mdot
.18563 .40114 Mdot
.42603 .30032 Mdot
.63131 .31658 Mdot
.6053 .44727 Mdot
.49572 .57263 Mdot
.68885 .65087 Mdot
.42851 .77526 Mdot
.60394 .36936 Mdot
.46558 .79456 Mdot
.44429 .62589 Mdot
.39484 .60302 Mdot
.45149 .29942 Mdot
.59059 .35723 Mdot
.3463 .62158 Mdot
.29123 .52896 Mdot
.35764 .37638 Mdot
.6745 .5693 Mdot
.43195 .63504 Mdot
.76566 .55603 Mdot
.45103 .32472 Mdot
.5333 .65197 Mdot
.40241 .62205 Mdot
.50597 .54762 Mdot
.59305 .35654 Mdot
.63106 .39196 Mdot
.43921 .30687 Mdot
.43985 .31705 Mdot
.39398 .59847 Mdot
.66169 .36246 Mdot
.46184 .62796 Mdot
.27138 .54412 Mdot
.4995 .58898 Mdot
.36377 .34871 Mdot
.43315 .64313 Mdot
.60755 .6001 Mdot
.26286 .73101 Mdot
.38652 .65954 Mdot
.71716 .55408 Mdot
.46246 .29725 Mdot
.49623 .29054 Mdot
.66611 .58991 Mdot
.49712 .29162 Mdot
.53854 .68031 Mdot
.64418 .77384 Mdot
.36184 .35295 Mdot
.49987 .73742 Mdot
.37095 .36928 Mdot
.53511 .51213 Mdot
.41398 .60942 Mdot
.57306 .19735 Mdot
.51732 .28027 Mdot
.36914 .43668 Mdot
.63307 .38177 Mdot
.53804 .51168 Mdot
.4564 .59673 Mdot
.31187 .36431 Mdot
.48446 .30275 Mdot
.5292 .53179 Mdot
.38962 .62437 Mdot
.70333 .55146 Mdot
.46614 .63941 Mdot
.51734 .54388 Mdot
.51748 .53686 Mdot
.44116 .6666 Mdot
.61591 .37521 Mdot
.67811 .54607 Mdot
.7041 .32195 Mdot
.50657 .30075 Mdot
.44603 .59409 Mdot
.44001 .61799 Mdot
.64429 .54811 Mdot
.39928 .64226 Mdot
.65752 .3575 Mdot
.84722 .34251 Mdot
.38164 .34675 Mdot
.53904 .49786 Mdot
.7233 .43085 Mdot
.43969 .66787 Mdot
.42583 .66071 Mdot
.37329 .54307 Mdot
.54254 .64653 Mdot
.62029 .38556 Mdot
.39223 .68157 Mdot
.48596 .27146 Mdot
.37768 .3489 Mdot
.65078 .39968 Mdot
.46554 .6053 Mdot
.40518 .63664 Mdot
.3462 .36128 Mdot
.4916 .38053 Mdot
.39386 .35314 Mdot
.64192 .35501 Mdot
.53618 .48441 Mdot
.391 .4948 Mdot
.41462 .61881 Mdot
.50899 .54371 Mdot
.68553 .55845 Mdot
.6354 .35053 Mdot
.60907 .65769 Mdot
.50927 .56462 Mdot
.62144 .40813 Mdot
.629 .38985 Mdot
.38485 .61817 Mdot
.71417 .56764 Mdot
.6357 .59915 Mdot
.68818 .5612 Mdot
.21966 .47003 Mdot
.70419 .31388 Mdot
.46385 .29419 Mdot
.64493 .37849 Mdot
.46096 .31917 Mdot
.37939 .37052 Mdot
.25185 .55746 Mdot
.44717 .32566 Mdot
.69611 .59258 Mdot
.46153 .32233 Mdot
.45966 .63082 Mdot
.62788 .39673 Mdot
.48675 .32609 Mdot
.44837 .63427 Mdot
.37576 .58627 Mdot
.50947 .55113 Mdot
.34652 .37983 Mdot
.28935 .53581 Mdot
.39666 .62233 Mdot
.51278 .53369 Mdot
.40643 .61466 Mdot
.65968 .35962 Mdot
.34508 .49383 Mdot
.4337 .58236 Mdot
.5178 .28079 Mdot
.77016 .36475 Mdot
.49893 .27382 Mdot
.54367 .58746 Mdot
.40835 .60091 Mdot
.41557 .61556 Mdot
.44924 .59196 Mdot
.70602 .65847 Mdot
.63088 .40693 Mdot
.39643 .68043 Mdot
.44814 .27757 Mdot
.66533 .57909 Mdot
.70853 .57942 Mdot
.40088 .52074 Mdot
.51275 .53809 Mdot
.66047 .35828 Mdot
.41721 .61485 Mdot
.51825 .53916 Mdot
.30486 .5154 Mdot
.79383 .54418 Mdot
.41713 .31753 Mdot
.50657 .28803 Mdot
.67905 .53943 Mdot
.48153 .27525 Mdot
.46288 .60372 Mdot
.50419 .5891 Mdot
.71016 .32543 Mdot
.64801 .34258 Mdot
.3772 .34951 Mdot
.40978 .5974 Mdot
.22623 .57761 Mdot
.46796 .27221 Mdot
.4369 .30689 Mdot
.46253 .62612 Mdot
.61363 .55513 Mdot
.22196 .6766 Mdot
.61712 .3468 Mdot
.54843 .76818 Mdot
.72374 .69446 Mdot
.34401 .71481 Mdot
.65368 .37734 Mdot
.47907 .45959 Mdot
.4437 .32953 Mdot
.26425 .35264 Mdot
.66988 .58016 Mdot
.37557 .34593 Mdot
.44603 .63644 Mdot
.69356 .59326 Mdot
.51579 .2735 Mdot
.64054 .56021 Mdot
.50247 .56932 Mdot
.63194 .40222 Mdot
.49051 .29296 Mdot
.66945 .3641 Mdot
.71824 .58408 Mdot
.37223 .36651 Mdot
.26173 .45679 Mdot
.52266 .76336 Mdot
.62725 .6463 Mdot
.44663 .58411 Mdot
.37134 .31423 Mdot
.44138 .58093 Mdot
.62776 .55086 Mdot
.39972 .62345 Mdot
.37935 .58701 Mdot
.43496 .32084 Mdot
.38344 .61842 Mdot
.43877 .63944 Mdot
.62477 .77396 Mdot
.4218 .60103 Mdot
.40974 .59095 Mdot
.38273 .62317 Mdot
.71187 .57961 Mdot
.38825 .63393 Mdot
.67828 .54308 Mdot
.78347 .52448 Mdot
.50593 .30126 Mdot
.38174 .36757 Mdot
.37994 .36789 Mdot
.28921 .4438 Mdot
.22679 .57358 Mdot
.75491 .63697 Mdot
.66129 .57136 Mdot
.62501 .37924 Mdot
.45866 .63006 Mdot
.20199 .60504 Mdot
.28219 .3934 Mdot
.474 .33338 Mdot
.46795 .32878 Mdot
.44864 .61282 Mdot
.63923 .82948 Mdot
.4055 .65319 Mdot
.31868 .51895 Mdot
.42646 .63468 Mdot
.39035 .64835 Mdot
.43863 .28268 Mdot
.24455 .50007 Mdot
.44271 .58286 Mdot
.68574 .53461 Mdot
.37385 .34654 Mdot
.50992 .54591 Mdot
.28346 .41076 Mdot
.70612 .71885 Mdot
.59602 .57731 Mdot
.44525 .58686 Mdot
.45342 .27883 Mdot
.65124 .58082 Mdot
.31563 .52972 Mdot
.64201 .35043 Mdot
.27335 .50392 Mdot
.47191 .77417 Mdot
.60108 .35293 Mdot
.37823 .35503 Mdot
.52542 .2815 Mdot
.38941 .60516 Mdot
.46561 .28297 Mdot
.40394 .67913 Mdot
.30607 .50983 Mdot
.3642 .35164 Mdot
.6812 .52572 Mdot
.61475 .35457 Mdot
.6897 .59336 Mdot
.55118 .61796 Mdot
.28138 .39003 Mdot
.18411 .38112 Mdot
.50714 .27285 Mdot
.48207 .71476 Mdot
.69639 .55991 Mdot
.40213 .58969 Mdot
.8664 .44294 Mdot
.67933 .55653 Mdot
.70672 .55505 Mdot
.3104 .4952 Mdot
.2351 .50566 Mdot
.40333 .6767 Mdot
.64682 .58118 Mdot
.5248 .28096 Mdot
.35352 .34974 Mdot
.45065 .6275 Mdot
.50616 .57243 Mdot
.69799 .58469 Mdot
.49106 .30209 Mdot
.25451 .49082 Mdot
.48158 .28491 Mdot
.68355 .58307 Mdot
.49206 .3181 Mdot
.71018 .34956 Mdot
.44977 .32708 Mdot
.41489 .64611 Mdot
.41686 .61583 Mdot
.64999 .60933 Mdot
.65012 .57233 Mdot
.42706 .66014 Mdot
.39302 .6274 Mdot
.69525 .5676 Mdot
.52156 .26541 Mdot
.56556 .61832 Mdot
.41634 .66359 Mdot
.42089 .61668 Mdot
.38416 .34894 Mdot
.29266 .55572 Mdot
.33537 .51967 Mdot
.44642 .64101 Mdot
.36342 .36832 Mdot
.69613 .54589 Mdot
.40762 .61113 Mdot
.24475 .49683 Mdot
.50792 .3198 Mdot
.4688 .61638 Mdot
.53063 .50507 Mdot
.44339 .58047 Mdot
.29194 .72477 Mdot
.45141 .59511 Mdot
.68495 .57881 Mdot
.69905 .57454 Mdot
.52766 .2668 Mdot
.67809 .5751 Mdot
.5391 .49969 Mdot
.6302 .38557 Mdot
.52508 .78139 Mdot
.54091 .50261 Mdot
.45361 .65766 Mdot
.3053 .3838 Mdot
.50803 .57598 Mdot
.50216 .61206 Mdot
.40971 .3518 Mdot
.52472 .50429 Mdot
.68862 .55353 Mdot
.72867 .52093 Mdot
.42628 .68645 Mdot
.65517 .35461 Mdot
.50677 .57785 Mdot
.46985 .61646 Mdot
.37825 .59189 Mdot
.60161 .54169 Mdot
.63338 .34734 Mdot
.4124 .70857 Mdot
.45074 .62776 Mdot
.54539 .6401 Mdot
.43476 .63431 Mdot
.33669 .3726 Mdot
.6671 .5563 Mdot
.47469 .2759 Mdot
.35997 .34713 Mdot
.46992 .64944 Mdot
.35111 .33972 Mdot
.46303 .28751 Mdot
.62313 .36318 Mdot
.41167 .64479 Mdot
.38655 .37145 Mdot
.37198 .37224 Mdot
.48069 .62221 Mdot
.7022 .57215 Mdot
.40306 .69651 Mdot
.41036 .60757 Mdot
.44862 .59073 Mdot
.67073 .59141 Mdot
.65958 .21733 Mdot
.39953 .59644 Mdot
.48065 .45798 Mdot
.63334 .54373 Mdot
.52322 .53326 Mdot
.46785 .27532 Mdot
.44564 .65718 Mdot
.65241 .39372 Mdot
.63239 .3857 Mdot
.51696 .28702 Mdot
.68726 .58965 Mdot
.49471 .2935 Mdot
.38154 .65381 Mdot
.50623 .5823 Mdot
.44746 .62818 Mdot
.54635 .34545 Mdot
.73678 .35881 Mdot
.65111 .54622 Mdot
.51017 .29162 Mdot
.27612 .52009 Mdot
.62288 .39183 Mdot
.44781 .27114 Mdot
.67663 .53282 Mdot
.65516 .59111 Mdot
.66389 .58771 Mdot
.35854 .37337 Mdot
.48478 .29242 Mdot
.71566 .59237 Mdot
.72348 .58399 Mdot
.47264 .62397 Mdot
.45243 .62708 Mdot
.68945 .54291 Mdot
.4945 .24664 Mdot
.3748 .35752 Mdot
.46341 .271 Mdot
.23036 .69159 Mdot
.62221 .34728 Mdot
.62768 .77194 Mdot
.44363 .64429 Mdot
.8486 .66732 Mdot
.40397 .65265 Mdot
.43863 .62864 Mdot
.70785 .59598 Mdot
.3881 .34239 Mdot
.35101 .35145 Mdot
.69754 .56149 Mdot
.63825 .57686 Mdot
.33019 .36493 Mdot
.35375 .51981 Mdot
.266 .70389 Mdot
.30658 .52342 Mdot
.64454 .55512 Mdot
.5056 .77586 Mdot
.64242 .36698 Mdot
.62388 .55046 Mdot
.69888 .38403 Mdot
.4985 .31652 Mdot
.45863 .33046 Mdot
.61949 .3695 Mdot
.40318 .59395 Mdot
.45918 .27006 Mdot
.40564 .57025 Mdot
.6753 .31483 Mdot
.51154 .4764 Mdot
.17071 .51589 Mdot
.40298 .64271 Mdot
.56973 .54802 Mdot
.81417 .48437 Mdot
.45662 .64464 Mdot
.64726 .73788 Mdot
.37201 .34115 Mdot
.6247 .55638 Mdot
.61305 .34539 Mdot
.77251 .6274 Mdot
.41518 .61742 Mdot
.64538 .56873 Mdot
.61 .35348 Mdot
.73229 .34818 Mdot
.46839 .45832 Mdot
.46923 .63158 Mdot
.86797 .41952 Mdot
.71639 .54733 Mdot
.47295 .27624 Mdot
.56195 .74747 Mdot
.64393 .59197 Mdot
.45529 .4616 Mdot
.52182 .27844 Mdot
.31186 .56498 Mdot
.64176 .57013 Mdot
.39317 .34772 Mdot
.6704 .56711 Mdot
.33396 .34936 Mdot
.70799 .59802 Mdot
.49909 .30884 Mdot
.41879 .59679 Mdot
.50294 .30484 Mdot
.32501 .35822 Mdot
.51035 .27468 Mdot
.61261 .34573 Mdot
.51662 .51343 Mdot
.63058 .37481 Mdot
.24881 .57183 Mdot
.61704 .67154 Mdot
.6299 .35593 Mdot
.39781 .5367 Mdot
.40969 .64076 Mdot
.65792 .60483 Mdot
.47894 .27677 Mdot
.42971 .3159 Mdot
.28779 .53426 Mdot
.68101 .5861 Mdot
.4928 .30489 Mdot
.51348 .76819 Mdot
.71443 .30185 Mdot
.38169 .58061 Mdot
.52742 .2435 Mdot
.69238 .5728 Mdot
.43064 .30602 Mdot
.31914 .52367 Mdot
.65426 .59347 Mdot
.47836 .32895 Mdot
.62358 .35213 Mdot
.65124 .39403 Mdot
.40757 .64691 Mdot
.62721 .34038 Mdot
.44692 .32981 Mdot
.52136 .6754 Mdot
.70001 .5542 Mdot
.73859 .36626 Mdot
.38088 .35786 Mdot
.48642 .2794 Mdot
.48779 .6282 Mdot
.70838 .59025 Mdot
.46328 .32096 Mdot
.73103 .76461 Mdot
.24997 .74143 Mdot
.49104 .30471 Mdot
.66638 .55782 Mdot
.65307 .572 Mdot
.41834 .66799 Mdot
.28789 .5304 Mdot
.48312 .3043 Mdot
.56827 .19632 Mdot
.26023 .60503 Mdot
.51863 .51533 Mdot
.2108 .32586 Mdot
.43757 .58142 Mdot
.45125 .58977 Mdot
.64532 .35479 Mdot
.42854 .59869 Mdot
.63831 .57239 Mdot
.40342 .65278 Mdot
.66238 .39008 Mdot
.51563 .29109 Mdot
.4123 .61375 Mdot
.37866 .35001 Mdot
.66285 .37781 Mdot
.6653 .37912 Mdot
.48581 .32035 Mdot
.68478 .58976 Mdot
.7969 .61122 Mdot
.48378 .28582 Mdot
.45902 .59637 Mdot
.51347 .52942 Mdot
.38323 .62094 Mdot
.72183 .61389 Mdot
.63291 .54717 Mdot
.47942 .2749 Mdot
.49714 .54098 Mdot
.64657 .38304 Mdot
.43979 .32795 Mdot
.43165 .57801 Mdot
.49583 .32376 Mdot
.49276 .44078 Mdot
.40212 .19335 Mdot
.73026 .56609 Mdot
.48143 .43471 Mdot
.65783 .59342 Mdot
.52445 .50713 Mdot
.22194 .43156 Mdot
.37647 .35763 Mdot
.48607 .26918 Mdot
.73343 .38559 Mdot
.50695 .29757 Mdot
.42345 .60317 Mdot
.4028 .63624 Mdot
.45054 .29707 Mdot
.36893 .36792 Mdot
.39997 .43082 Mdot
.39641 .35463 Mdot
.65949 .55772 Mdot
.38434 .52277 Mdot
.19969 .6626 Mdot
.46298 .33735 Mdot
.62126 .37758 Mdot
.62809 .60804 Mdot
.45681 .65604 Mdot
.61898 .34541 Mdot
.66523 .37423 Mdot
.33071 .34747 Mdot
.5004 .28616 Mdot
.67846 .52758 Mdot
.63552 .40162 Mdot
.65153 .59611 Mdot
.25246 .48702 Mdot
.51184 .56074 Mdot
.40862 .719 Mdot
.45854 .65839 Mdot
.29342 .53878 Mdot
.6348 .40318 Mdot
.40931 .63377 Mdot
.36875 .6507 Mdot
.62066 .35069 Mdot
.3329 .34417 Mdot
.51526 .48434 Mdot
.49142 .30689 Mdot
.86377 .49398 Mdot
.41915 .64613 Mdot
.41165 .60269 Mdot
.6183 .34902 Mdot
.67223 .73177 Mdot
.68573 .53606 Mdot
.70029 .58044 Mdot
.46877 .29384 Mdot
.32019 .49831 Mdot
.38937 .63265 Mdot
.41288 .64358 Mdot
.4466 .30143 Mdot
.5176 .53191 Mdot
.18954 .36476 Mdot
.42116 .62222 Mdot
.64371 .37393 Mdot
.49338 .46171 Mdot
.60927 .37443 Mdot
.37647 .61549 Mdot
.4275 .60753 Mdot
.47421 .60117 Mdot
.43112 .57692 Mdot
.63143 .37049 Mdot
.46321 .6536 Mdot
.42959 .67718 Mdot
.68616 .55517 Mdot
.42528 .58325 Mdot
.26137 .60607 Mdot
.41807 .62199 Mdot
.37589 .34359 Mdot
.33645 .51623 Mdot
.44601 .59241 Mdot
.42897 .58336 Mdot
.25811 .60347 Mdot
.43607 .59777 Mdot
.61156 .35016 Mdot
.65558 .57638 Mdot
.64754 .38446 Mdot
.61858 .37619 Mdot
.46715 .32282 Mdot
.34428 .33593 Mdot
.39353 .6711 Mdot
.33927 .36953 Mdot
.39737 .66753 Mdot
.41653 .70546 Mdot
.26939 .55306 Mdot
.31761 .51928 Mdot
.36817 .37939 Mdot
.41598 .64324 Mdot
.46591 .28961 Mdot
.48964 .27685 Mdot
.4317 .48777 Mdot
.49636 .57841 Mdot
.61157 .34242 Mdot
.62249 .35671 Mdot
.44023 .38684 Mdot
.38994 .18997 Mdot
.36112 .37816 Mdot
.40899 .43024 Mdot
.41301 .57247 Mdot
.40064 .60068 Mdot
.49517 .60623 Mdot
.45518 .31462 Mdot
.5233 .50467 Mdot
.4852 .26283 Mdot
.59295 .36041 Mdot
.65891 .37577 Mdot
.40801 .64493 Mdot
.60342 .84613 Mdot
.6695 .5472 Mdot
.65299 .57403 Mdot
.66145 .39197 Mdot
.49741 .27321 Mdot
.5001 .59363 Mdot
.85864 .53847 Mdot
.64037 .54144 Mdot
.38714 .36247 Mdot
.43659 .5936 Mdot
.50102 .31328 Mdot
.68157 .54674 Mdot
.38509 .37202 Mdot
.40668 .5833 Mdot
.52018 .27505 Mdot
.41127 .63076 Mdot
.50668 .72227 Mdot
.69239 .55283 Mdot
.27692 .56389 Mdot
.7181 .57601 Mdot
.63329 .37103 Mdot
.62565 .39017 Mdot
.42559 .60831 Mdot
.86404 .52507 Mdot
.66068 .51879 Mdot
.66218 .40273 Mdot
.38073 .33779 Mdot
.51158 .52038 Mdot
.34608 .33682 Mdot
.45355 .29863 Mdot
.37785 .35509 Mdot
.46498 .32159 Mdot
.52208 .25744 Mdot
.70307 .53757 Mdot
.34573 .36067 Mdot
.64327 .71746 Mdot
.50344 .59183 Mdot
.34797 .33011 Mdot
.45177 .60905 Mdot
.4047 .66678 Mdot
.47632 .30936 Mdot
.34832 .37356 Mdot
.47071 .64143 Mdot
.71608 .43197 Mdot
.62025 .38379 Mdot
.61011 .34616 Mdot
.50211 .57502 Mdot
.43387 .30541 Mdot
.70509 .53947 Mdot
.26822 .52635 Mdot
.69184 .52734 Mdot
.41664 .6443 Mdot
.39008 .66661 Mdot
.7245 .57195 Mdot
.71394 .54932 Mdot
.42881 .6113 Mdot
.56655 .79992 Mdot
.48339 .63496 Mdot
.64847 .39585 Mdot
.66052 .55558 Mdot
.64961 .5678 Mdot
.44694 .32895 Mdot
.70163 .5815 Mdot
.37464 .677 Mdot
.59826 .35354 Mdot
.42845 .68117 Mdot
.64356 .3812 Mdot
.40172 .30244 Mdot
.47815 .3134 Mdot
.73033 .37605 Mdot
.70458 .5772 Mdot
.43349 .65606 Mdot
.7101 .5703 Mdot
.37504 .33862 Mdot
.64519 .56052 Mdot
.6221 .58731 Mdot
.44275 .63814 Mdot
.47161 .64692 Mdot
.52662 .52457 Mdot
.29233 .53415 Mdot
.67747 .55151 Mdot
.38305 .65384 Mdot
.40176 .65585 Mdot
.39365 .63053 Mdot
.27268 .53924 Mdot
.71173 .57876 Mdot
.70313 .72106 Mdot
.73798 .55265 Mdot
.6894 .55051 Mdot
.29553 .76616 Mdot
.53237 .51818 Mdot
.50372 .53893 Mdot
.63341 .33296 Mdot
.42242 .61958 Mdot
.49886 .29545 Mdot
.46524 .60055 Mdot
.49293 .61488 Mdot
.4425 .59162 Mdot
.33908 .35067 Mdot
.38471 .60989 Mdot
.52065 .52082 Mdot
.48489 .28297 Mdot
.45433 .64484 Mdot
.41774 .61166 Mdot
.5166 .53538 Mdot
.7115 .56268 Mdot
.66705 .59393 Mdot
.70998 .53503 Mdot
.32897 .35379 Mdot
.645 .36309 Mdot
.4643 .60091 Mdot
.46766 .29204 Mdot
.50125 .29442 Mdot
.70489 .58794 Mdot
.44503 .29382 Mdot
.65926 .37091 Mdot
.43778 .62577 Mdot
.63209 .3714 Mdot
.33908 .34896 Mdot
.66768 .55532 Mdot
.4607 .6032 Mdot
.47699 .62388 Mdot
.69919 .57431 Mdot
.47889 .64216 Mdot
.37414 .33601 Mdot
.4429 .30989 Mdot
.65752 .54204 Mdot
.63152 .38668 Mdot
.44746 .32788 Mdot
.4465 .64974 Mdot
.39268 .82328 Mdot
.42891 .59969 Mdot
.39129 .632 Mdot
.68088 .51644 Mdot
.38144 .59897 Mdot
.50686 .30053 Mdot
.70825 .5786 Mdot
.408 .66591 Mdot
.24593 .59976 Mdot
.41022 .33074 Mdot
.46124 .3392 Mdot
.44209 .61204 Mdot
.49091 .80413 Mdot
.42442 .65647 Mdot
.73676 .39163 Mdot
.26981 .55334 Mdot
.68415 .40661 Mdot
.41067 .71829 Mdot
.66378 .40059 Mdot
.51466 .53154 Mdot
.47649 .32079 Mdot
.60901 .7657 Mdot
.4322 .6104 Mdot
.61349 .64713 Mdot
.464 .60578 Mdot
.65473 .3794 Mdot
.65995 .72537 Mdot
.45047 .28122 Mdot
.19309 .39246 Mdot
.41113 .58525 Mdot
.67596 .53433 Mdot
.47388 .25686 Mdot
.50542 .53358 Mdot
.47167 .64565 Mdot
.34407 .37512 Mdot
.44832 .38065 Mdot
.39039 .68815 Mdot
.64466 .38384 Mdot
.39283 .6088 Mdot
.4827 .60255 Mdot
.70565 .27406 Mdot
.69011 .56286 Mdot
.61487 .35985 Mdot
.38183 .19769 Mdot
.41196 .63866 Mdot
.65721 .59182 Mdot
.66951 .5798 Mdot
.33521 .36391 Mdot
.63168 .41478 Mdot
.46967 .37709 Mdot
.58471 .8366 Mdot
.45321 .72091 Mdot
.45262 .31444 Mdot
.54355 .48804 Mdot
.46613 .59993 Mdot
.28215 .38945 Mdot
.62227 .38075 Mdot
.41312 .60036 Mdot
.63847 .64739 Mdot
.68704 .57369 Mdot
.41739 .62992 Mdot
.37419 .35462 Mdot
.81419 .59932 Mdot
.49329 .76616 Mdot
.51241 .80191 Mdot
.52468 .28098 Mdot
.39827 .67521 Mdot
.3741 .67516 Mdot
.5214 .53466 Mdot
.37507 .6204 Mdot
.47631 .27717 Mdot
.50739 .44625 Mdot
.36782 .35912 Mdot
.67775 .54545 Mdot
.51179 .53591 Mdot
.46396 .60626 Mdot
.40918 .67946 Mdot
.38254 .34097 Mdot
.47752 .60626 Mdot
.56709 .75634 Mdot
.54301 .49313 Mdot
.44961 .32574 Mdot
.64584 .54904 Mdot
.39311 .66952 Mdot
.50885 .52603 Mdot
.44463 .63147 Mdot
.60205 .59755 Mdot
.40823 .59974 Mdot
.69788 .42329 Mdot
.69568 .58069 Mdot
.64046 .39122 Mdot
.42724 .57615 Mdot
.41103 .62581 Mdot
.47192 .43188 Mdot
.49979 .598 Mdot
.43042 .58661 Mdot
.67528 .59656 Mdot
.67352 .54556 Mdot
.67794 .53505 Mdot
.4666 .33321 Mdot
.30143 .52361 Mdot
.63464 .37605 Mdot
.49551 .60478 Mdot
.63592 .40185 Mdot
.36502 .71981 Mdot
.33866 .34457 Mdot
.72767 .36521 Mdot
.43596 .62333 Mdot
.67236 .58739 Mdot
.25326 .6897 Mdot
.70949 .58437 Mdot
.62676 .32437 Mdot
.62413 .38412 Mdot
.67662 .55748 Mdot
.43905 .60605 Mdot
.30293 .53801 Mdot
.51766 .81092 Mdot
.62448 .39362 Mdot
.49942 .57169 Mdot
.38423 .30139 Mdot
.51433 .30709 Mdot
.28025 .75218 Mdot
.64151 .40107 Mdot
.81486 .48452 Mdot
.41571 .66388 Mdot
.70845 .56631 Mdot
.63183 .36266 Mdot
.66415 .36729 Mdot
.44699 .28372 Mdot
.47052 .62833 Mdot
.41272 .62704 Mdot
.53074 .5057 Mdot
.62533 .37011 Mdot
.49746 .55151 Mdot
.46845 .63442 Mdot
.62767 .3131 Mdot
.65338 .53494 Mdot
.65407 .21202 Mdot
.40187 .54591 Mdot
.63724 .64762 Mdot
.62518 .21654 Mdot
.66437 .53906 Mdot
.40537 .59211 Mdot
.49952 .59194 Mdot
.44187 .30556 Mdot
.4381 .61414 Mdot
.51019 .28958 Mdot
.65339 .37206 Mdot
.70061 .43225 Mdot
.38896 .54314 Mdot
.66021 .31841 Mdot
.42434 .59863 Mdot
.50201 .76536 Mdot
.35557 .36073 Mdot
.60538 .3473 Mdot
.6998 .53996 Mdot
.3805 .63456 Mdot
.4415 .29288 Mdot
.50439 .31729 Mdot
.6854 .57115 Mdot
.80135 .48838 Mdot
.73264 .37825 Mdot
.48564 .63364 Mdot
.45493 .2842 Mdot
.50337 .5478 Mdot
.47946 .79292 Mdot
.65107 .40497 Mdot
.3663 .35921 Mdot
.48014 .324 Mdot
.65479 .35286 Mdot
.40589 .6673 Mdot
.68078 .5662 Mdot
.72389 .55513 Mdot
.43841 .47819 Mdot
.49454 .30343 Mdot
.35522 .34307 Mdot
.44871 .47179 Mdot
.40052 .51238 Mdot
.36588 .34992 Mdot
.46886 .3341 Mdot
.6535 .55514 Mdot
.68208 .58217 Mdot
.65771 .57763 Mdot
.62861 .77007 Mdot
.6332 .54736 Mdot
.27271 .42919 Mdot
.37548 .61823 Mdot
.51386 .77512 Mdot
.39142 .65402 Mdot
.61417 .3453 Mdot
.69643 .55488 Mdot
.26992 .55576 Mdot
.41852 .57272 Mdot
.52327 .81197 Mdot
.39682 .61774 Mdot
.48819 .4598 Mdot
.42218 .61819 Mdot
.52121 .72465 Mdot
.6244 .56262 Mdot
.40517 .58569 Mdot
.59957 .36514 Mdot
.35821 .33736 Mdot
.68435 .60581 Mdot
.41674 .58966 Mdot
.77253 .53498 Mdot
.45236 .60913 Mdot
.69997 .42944 Mdot
.44909 .46611 Mdot
.36495 .39906 Mdot
.38505 .62935 Mdot
.46264 .26547 Mdot
.35351 .60098 Mdot
.50381 .77966 Mdot
.62686 .39566 Mdot
.5078 .76722 Mdot
.47301 .26644 Mdot
.66257 .72554 Mdot
.49115 .62555 Mdot
.36948 .36144 Mdot
.53494 .4697 Mdot
.64328 .39744 Mdot
.43423 .61837 Mdot
.40401 .59055 Mdot
.50768 .47769 Mdot
.46723 .78806 Mdot
.51353 .54451 Mdot
.37328 .37847 Mdot
.48224 .77365 Mdot
.42977 .58755 Mdot
.45131 .33864 Mdot
.68052 .59293 Mdot
.65682 .71774 Mdot
.67724 .71795 Mdot
.46129 .6415 Mdot
.68024 .55863 Mdot
.68721 .58957 Mdot
.20898 .64058 Mdot
.35746 .36563 Mdot
.40492 .60322 Mdot
.48246 .43322 Mdot
.46386 .60146 Mdot
.64929 .37277 Mdot
.40051 .57595 Mdot
.48071 .31241 Mdot
.32127 .52591 Mdot
.47378 .33247 Mdot
.39411 .63209 Mdot
.66862 .56695 Mdot
.61426 .37622 Mdot
.5209 .25289 Mdot
.6308 .41411 Mdot
.27158 .43017 Mdot
.43438 .38106 Mdot
.36358 .3778 Mdot
.33782 .34235 Mdot
.6064 .3469 Mdot
.44185 .62001 Mdot
.27786 .5329 Mdot
.4109 .56109 Mdot
.42513 .62414 Mdot
.41789 .5927 Mdot
.66332 .3465 Mdot
.62648 .3864 Mdot
.4968 .31466 Mdot
.42987 .61245 Mdot
.37977 .64611 Mdot
.67155 .56272 Mdot
.36636 .37602 Mdot
.45435 .32283 Mdot
.32791 .36589 Mdot
.475 .2842 Mdot
.29312 .72604 Mdot
.50923 .56823 Mdot
.34761 .34098 Mdot
.65095 .40221 Mdot
.65987 .58426 Mdot
.53669 .5108 Mdot
.45824 .30195 Mdot
.44683 .28998 Mdot
.40802 .67203 Mdot
.68259 .54799 Mdot
.70197 .57917 Mdot
.3293 .36518 Mdot
.62466 .35637 Mdot
.38192 .57586 Mdot
.45452 .65979 Mdot
.49971 .22186 Mdot
.43874 .30205 Mdot
.49268 .77412 Mdot
.72541 .53729 Mdot
.43841 .63534 Mdot
.66135 .59236 Mdot
.4087 .61688 Mdot
.63816 .60899 Mdot
.71826 .55033 Mdot
.38509 .58948 Mdot
.47476 .57477 Mdot
.45745 .31647 Mdot
.18221 .59622 Mdot
.37324 .5919 Mdot
.70203 .35959 Mdot
.46942 .60145 Mdot
.1818 .3826 Mdot
.2444 .67918 Mdot
.44718 .61583 Mdot
.38595 .6089 Mdot
.54535 .85059 Mdot
.42471 .65523 Mdot
.52412 .51202 Mdot
.49415 .62027 Mdot
.6557 .58998 Mdot
.48538 .43583 Mdot
.29081 .53676 Mdot
.35076 .36687 Mdot
.46755 .294 Mdot
.2388 .50354 Mdot
.33337 .34908 Mdot
.688 .5768 Mdot
.38027 .57663 Mdot
.69559 .52158 Mdot
.4267 .30033 Mdot
.50773 .54842 Mdot
.6538 .37602 Mdot
.28251 .53378 Mdot
.44388 .28853 Mdot
.62972 .3857 Mdot
.41334 .65819 Mdot
.5003 .2527 Mdot
.60361 .36861 Mdot
.18363 .61055 Mdot
.64801 .35448 Mdot
.63428 .39315 Mdot
.29285 .52694 Mdot
.35072 .36698 Mdot
.51368 .45134 Mdot
.42829 .70105 Mdot
.61021 .36594 Mdot
.20096 .40661 Mdot
.43837 .29356 Mdot
.2995 .51011 Mdot
.62326 .56299 Mdot
.50749 .57261 Mdot
.41873 .59474 Mdot
.6386 .35147 Mdot
.49853 .52755 Mdot
.46903 .431 Mdot
.658 .38477 Mdot
.43167 .57384 Mdot
.32511 .50117 Mdot
.51042 .52493 Mdot
.53356 .51501 Mdot
.38727 .36872 Mdot
.40522 .21532 Mdot
.68174 .5886 Mdot
.38675 .36113 Mdot
.25987 .57429 Mdot
.39456 .61856 Mdot
.63197 .36877 Mdot
.51078 .53808 Mdot
.63445 .38639 Mdot
.35444 .35525 Mdot
.37543 .33532 Mdot
.68704 .55624 Mdot
.68435 .53663 Mdot
.53571 .47866 Mdot
.25688 .61134 Mdot
.46728 .61747 Mdot
.60688 .65916 Mdot
.71598 .55088 Mdot
.64642 .75216 Mdot
.35338 .37081 Mdot
.36065 .37599 Mdot
.43548 .75852 Mdot
.45609 .63283 Mdot
.49248 .46091 Mdot
.44492 .59124 Mdot
.22142 .38436 Mdot
.46155 .60519 Mdot
.44573 .29849 Mdot
.4292 .58025 Mdot
.7787 .57185 Mdot
.43332 .6601 Mdot
.42909 .58991 Mdot
.47924 .29782 Mdot
.39929 .67251 Mdot
.47855 .3106 Mdot
.40221 .59609 Mdot
.46206 .35792 Mdot
.46817 .29218 Mdot
.36794 .32052 Mdot
.46568 .47636 Mdot
.52811 .51458 Mdot
.33752 .35811 Mdot
.35607 .37856 Mdot
.25711 .48637 Mdot
.6608 .54945 Mdot
.69574 .66105 Mdot
.43595 .59398 Mdot
.43608 .29979 Mdot
.65244 .36721 Mdot
.46142 .64328 Mdot
.39753 .64561 Mdot
.3737 .59144 Mdot
.68261 .55541 Mdot
.43831 .32455 Mdot
.34488 .35429 Mdot
.50314 .2852 Mdot
.46074 .35414 Mdot
.47172 .31487 Mdot
.46409 .56217 Mdot
.40412 .66804 Mdot
.37299 .67318 Mdot
.63629 .68967 Mdot
.31259 .39392 Mdot
.68343 .56836 Mdot
.51536 .52842 Mdot
.34233 .33989 Mdot
.35051 .50513 Mdot
.67112 .59072 Mdot
.44763 .29935 Mdot
.41083 .63076 Mdot
.51193 .56237 Mdot
.42723 .70111 Mdot
.65055 .59771 Mdot
.33616 .33464 Mdot
.46544 .3001 Mdot
.51586 .51865 Mdot
.30509 .52137 Mdot
.72483 .69511 Mdot
.24939 .56345 Mdot
.40947 .62212 Mdot
.32964 .36377 Mdot
.68107 .5467 Mdot
.50365 .46516 Mdot
.62918 .35078 Mdot
.28872 .53174 Mdot
.42589 .59777 Mdot
.57972 .33469 Mdot
.66873 .56845 Mdot
.37322 .36559 Mdot
.63982 .35149 Mdot
.36267 .36619 Mdot
.51059 .51913 Mdot
.73736 .54879 Mdot
.4733 .64409 Mdot
.45071 .59419 Mdot
.65135 .36829 Mdot
.68733 .58677 Mdot
.46727 .36105 Mdot
.52155 .46381 Mdot
.45142 .29667 Mdot
.34766 .51237 Mdot
.67637 .54594 Mdot
.5669 .33562 Mdot
.50433 .28525 Mdot
.62277 .33693 Mdot
.30493 .54955 Mdot
.66114 .37187 Mdot
.42355 .58926 Mdot
.6579 .57025 Mdot
.62537 .39523 Mdot
.47714 .2259 Mdot
.57782 .81023 Mdot
.53094 .46907 Mdot
.40753 .63995 Mdot
.74412 .38968 Mdot
.80691 .51169 Mdot
.63987 .6033 Mdot
.64921 .40011 Mdot
.41788 .6051 Mdot
.48515 .63513 Mdot
.41326 .584 Mdot
.61347 .36823 Mdot
.582 .40984 Mdot
.47158 .27046 Mdot
.4108 .63462 Mdot
.38004 .35079 Mdot
.48509 .31364 Mdot
.5197 .29445 Mdot
.4802 .32471 Mdot
.69967 .54065 Mdot
.51187 .55735 Mdot
.49556 .61819 Mdot
.22811 .64519 Mdot
.63916 .39308 Mdot
.52775 .51492 Mdot
.38941 .60272 Mdot
.2718 .43455 Mdot
.66797 .58489 Mdot
.46799 .30361 Mdot
.41054 .60319 Mdot
.44103 .47386 Mdot
.512 .54229 Mdot
.48432 .29009 Mdot
.7122 .54661 Mdot
.62746 .51687 Mdot
.43803 .61705 Mdot
.4733 .60655 Mdot
.696 .57354 Mdot
.81716 .52825 Mdot
.3092 .5178 Mdot
.41057 .61633 Mdot
.63452 .39006 Mdot
.81737 .4089 Mdot
.40972 .65935 Mdot
.65484 .52412 Mdot
.52796 .50088 Mdot
.74489 .55458 Mdot
.55368 .768 Mdot
.49263 .58488 Mdot
.59993 .49271 Mdot
.3741 .43815 Mdot
.5953 .52991 Mdot
.24021 .38019 Mdot
.55399 .45634 Mdot
.19389 .64245 Mdot
.59739 .35023 Mdot
.50715 .73065 Mdot
.71884 .77087 Mdot
.80821 .48034 Mdot
.49063 .41985 Mdot
.61851 .44265 Mdot
.42563 .28371 Mdot
.19483 .35289 Mdot
.4777 .26197 Mdot
.24746 .3715 Mdot
.45366 .5989 Mdot
.81139 .53033 Mdot
.50822 .73843 Mdot
.39807 .3888 Mdot
.71301 .34921 Mdot
.44743 .46941 Mdot
.45757 .82576 Mdot
.67821 .31853 Mdot
.35166 .77928 Mdot
.66008 .6529 Mdot
.44023 .20065 Mdot
.36061 .52283 Mdot
.24044 .48569 Mdot
.51974 .75592 Mdot
.66992 .4952 Mdot
.58444 .37842 Mdot
.54672 .65141 Mdot
.63984 .22003 Mdot
.45781 .2868 Mdot
.64463 .58972 Mdot
.60959 .44982 Mdot
.4033 .80127 Mdot
.67713 .33311 Mdot
.59847 .49349 Mdot
.52567 .46804 Mdot
.51736 .72573 Mdot
.2719 .56393 Mdot
.51906 .70694 Mdot
.46065 .38351 Mdot
.19853 .35161 Mdot
.64149 .51838 Mdot
.46292 .22143 Mdot
.33796 .48862 Mdot
.44471 .40632 Mdot
.54358 .73214 Mdot
.31791 .36329 Mdot
.37361 .32005 Mdot
.7127 .54616 Mdot
.43546 .80038 Mdot
.42435 .53335 Mdot
.26144 .5816 Mdot
.4749 .26151 Mdot
.59518 .56822 Mdot
.8111 .59919 Mdot
.79846 .51138 Mdot
.16739 .55183 Mdot
.38946 .81738 Mdot
.20636 .44745 Mdot
.49477 .47714 Mdot
.66953 .33413 Mdot
.28551 .43467 Mdot
.56629 .54906 Mdot
.19984 .48077 Mdot
.60564 .59876 Mdot
.51146 .83487 Mdot
.76079 .50899 Mdot
.42557 .82879 Mdot
.634 .51967 Mdot
.37365 .6629 Mdot
.67784 .61369 Mdot
.51969 .67173 Mdot
.23528 .57384 Mdot
.43121 .81962 Mdot
.38718 .38923 Mdot
.51329 .5089 Mdot
.80209 .472 Mdot
.56531 .75646 Mdot
.4875 .37666 Mdot
.39007 .32925 Mdot
.668 .69829 Mdot
.46414 .83531 Mdot
.61201 .48816 Mdot
.36707 .74934 Mdot
.62401 .31258 Mdot
.54197 .29826 Mdot
.51955 .2899 Mdot
.67005 .38748 Mdot
.36735 .79336 Mdot
.66118 .57427 Mdot
.17733 .59365 Mdot
.56111 .48413 Mdot
.54918 .52077 Mdot
.47025 .83693 Mdot
.17898 .49781 Mdot
.53583 .76409 Mdot
.3415 .42156 Mdot
.72006 .31879 Mdot
.54602 .60607 Mdot
.64086 .31785 Mdot
.38707 .31028 Mdot
.71693 .41302 Mdot
.381 .79876 Mdot
.19269 .46213 Mdot
.60799 .83558 Mdot
.26789 .58897 Mdot
.31843 .31346 Mdot
.64471 .51813 Mdot
.53952 .40254 Mdot
.49978 .37623 Mdot
.41803 .82897 Mdot
.4857 .76576 Mdot
.78849 .37882 Mdot
.23054 .39963 Mdot
.67917 .72216 Mdot
.75041 .41712 Mdot
.58378 .42868 Mdot
.5252 .65581 Mdot
.77579 .52892 Mdot
.44801 .66749 Mdot
.24075 .55162 Mdot
.66727 .68499 Mdot
.36418 .39313 Mdot
.30973 .52852 Mdot
.75757 .48788 Mdot
.21481 .486 Mdot
.79721 .40224 Mdot
.67531 .69528 Mdot
.71884 .57966 Mdot
.20136 .47986 Mdot
.21748 .41648 Mdot
.7741 .38761 Mdot
.37836 .19994 Mdot
.36578 .75043 Mdot
.52943 .36405 Mdot
.48986 .58908 Mdot
.50356 .73222 Mdot
.52263 .75327 Mdot
.20659 .36255 Mdot
.47315 .56514 Mdot
.20689 .61598 Mdot
.70758 .34911 Mdot
.62059 .70448 Mdot
.21741 .54757 Mdot
.63154 .69616 Mdot
.52843 .78082 Mdot
.73395 .60996 Mdot
.69251 .39209 Mdot
.48341 .53166 Mdot
.46838 .8333 Mdot
.49053 .31569 Mdot
.19723 .48207 Mdot
.67512 .32659 Mdot
.48833 .22377 Mdot
.53597 .45206 Mdot
.48011 .41995 Mdot
.32837 .77741 Mdot
.79152 .46362 Mdot
.42336 .26866 Mdot
.71359 .51747 Mdot
.56683 .52357 Mdot
.61324 .6646 Mdot
.42734 .54998 Mdot
.59397 .58109 Mdot
.37418 .33594 Mdot
.61817 .74378 Mdot
.74988 .57736 Mdot
.36382 .20435 Mdot
.45318 .56267 Mdot
.3655 .52185 Mdot
.53369 .5008 Mdot
.27802 .4855 Mdot
.28822 .72384 Mdot
.49234 .55489 Mdot
.17973 .50627 Mdot
.80232 .48033 Mdot
.27254 .48869 Mdot
.49286 .37942 Mdot
.70318 .66465 Mdot
.42872 .8302 Mdot
.26337 .72977 Mdot
.79961 .55736 Mdot
.74387 .4112 Mdot
.33377 .19164 Mdot
.69 .3996 Mdot
.19158 .5927 Mdot
.67482 .32667 Mdot
.84764 .34504 Mdot
.50931 .2972 Mdot
.28028 .38127 Mdot
.56765 .59223 Mdot
.39656 .49389 Mdot
.41993 .80349 Mdot
.54869 .75223 Mdot
.33741 .33254 Mdot
.64401 .60164 Mdot
.48123 .57095 Mdot
.44368 .81366 Mdot
.4777 .82826 Mdot
.4503 .81381 Mdot
.5689 .36127 Mdot
.53304 .80074 Mdot
.51632 .84971 Mdot
.27736 .42706 Mdot
.46482 .50565 Mdot
.48639 .60842 Mdot
.24486 .61316 Mdot
.19267 .55911 Mdot
.3117 .37985 Mdot
.54322 .61268 Mdot
.65022 .51589 Mdot
.49619 .8497 Mdot
.27636 .71674 Mdot
.51652 .70312 Mdot
.33153 .7722 Mdot
.40863 .26878 Mdot
.21391 .57808 Mdot
.29875 .75779 Mdot
.64036 .48878 Mdot
.59681 .33469 Mdot
.52312 .85753 Mdot
.21933 .42955 Mdot
.61496 .44131 Mdot
.76871 .54469 Mdot
.18848 .56864 Mdot
.73932 .42144 Mdot
.60773 .44105 Mdot
.57889 .57305 Mdot
.74184 .66997 Mdot
.48917 .41332 Mdot
.66681 .49684 Mdot
.49313 .4709 Mdot
.21301 .55179 Mdot
.51283 .28046 Mdot
.1949 .503 Mdot
.47507 .39893 Mdot
.47335 .50354 Mdot
.24823 .50652 Mdot
.19861 .42997 Mdot
.73238 .50492 Mdot
.50354 .80226 Mdot
.79788 .47406 Mdot
.81117 .40921 Mdot
.7654 .40626 Mdot
.67521 .67275 Mdot
.39676 .67172 Mdot
.40998 .80478 Mdot
.21668 .69929 Mdot
.30812 .76673 Mdot
.78216 .39205 Mdot
.52323 .321 Mdot
.62796 .34193 Mdot
.2745 .44494 Mdot
.41314 .47914 Mdot
.60814 .46865 Mdot
.40943 .44125 Mdot
.66587 .40348 Mdot
.81573 .59464 Mdot
.54936 .47229 Mdot
.27742 .43287 Mdot
.55535 .64454 Mdot
.5543 .53589 Mdot
.47628 .79251 Mdot
.72298 .57349 Mdot
.76729 .3722 Mdot
.19961 .48364 Mdot
.48612 .31893 Mdot
.49373 .21654 Mdot
.47465 .53669 Mdot
.36832 .64447 Mdot
.37587 .30103 Mdot
.49001 .50807 Mdot
.63607 .64873 Mdot
.52208 .31914 Mdot
.23072 .68161 Mdot
.18349 .58842 Mdot
.29428 .75464 Mdot
.20487 .44141 Mdot
.47499 .21998 Mdot
.28219 .4925 Mdot
.69123 .36841 Mdot
.69211 .32798 Mdot
.3107 .49126 Mdot
.20611 .42486 Mdot
.53324 .76754 Mdot
.65534 .60974 Mdot
.49345 .59588 Mdot
.26019 .69645 Mdot
.24899 .46368 Mdot
.29261 .48046 Mdot
.71045 .68205 Mdot
.65425 .53113 Mdot
.27992 .34854 Mdot
.69988 .50456 Mdot
.35517 .68587 Mdot
.74993 .40498 Mdot
.6355 .40642 Mdot
.72617 .56246 Mdot
.19727 .43117 Mdot
.41206 .18303 Mdot
.58518 .5303 Mdot
.40664 .53654 Mdot
.38041 .79122 Mdot
.44655 .49192 Mdot
.72603 .42025 Mdot
.76092 .66992 Mdot
.68454 .30247 Mdot
.62052 .52817 Mdot
.48346 .49211 Mdot
.52407 .44277 Mdot
.76653 .59672 Mdot
.6737 .60307 Mdot
.49311 .76381 Mdot
.36853 .80138 Mdot
.45753 .46673 Mdot
.64304 .4974 Mdot
.27073 .52333 Mdot
.52264 .40342 Mdot
.56488 .50503 Mdot
.24276 .50746 Mdot
.60548 .51096 Mdot
.38823 .76213 Mdot
.84235 .55994 Mdot
.53003 .639 Mdot
.27095 .37235 Mdot
.2777 .44167 Mdot
.66145 .65258 Mdot
.53963 .72937 Mdot
.70092 .32452 Mdot
.4447 .58742 Mdot
.36391 .80706 Mdot
.76147 .49899 Mdot
.25989 .49828 Mdot
.55801 .35368 Mdot
.44319 .64847 Mdot
.3822 .68037 Mdot
.30937 .76508 Mdot
.74622 .55375 Mdot
.77299 .73398 Mdot
.22927 .38863 Mdot
.66091 .62754 Mdot
.54723 .76999 Mdot
.18089 .51656 Mdot
.7267 .61973 Mdot
.56677 .48345 Mdot
.48411 .39685 Mdot
.18638 .54709 Mdot
.75328 .55189 Mdot
.74454 .53693 Mdot
.75509 .38823 Mdot
.51697 .84585 Mdot
.58132 .55135 Mdot
.58832 .34664 Mdot
.40346 .27365 Mdot
.39046 .6315 Mdot
.80229 .49148 Mdot
.73142 .36326 Mdot
.55121 .36897 Mdot
.57032 .56081 Mdot
.21468 .69963 Mdot
.47069 .58674 Mdot
.78774 .46949 Mdot
.76288 .74113 Mdot
.81013 .7018 Mdot
.7753 .56872 Mdot
.4112 .82888 Mdot
.74119 .53568 Mdot
.7241 .42353 Mdot
.62265 .39848 Mdot
.38568 .52324 Mdot
.60967 .65135 Mdot
.33581 .79183 Mdot
.43547 .18482 Mdot
.63602 .31774 Mdot
.55651 .6252 Mdot
.33303 .79204 Mdot
.47612 .58435 Mdot
.2787 .36036 Mdot
.54201 .30111 Mdot
.19038 .39744 Mdot
.16894 .54497 Mdot
.72266 .68054 Mdot
.19985 .36831 Mdot
.26391 .34029 Mdot
.406 .39509 Mdot
.18605 .58817 Mdot
.44883 .71781 Mdot
.72796 .66706 Mdot
.20301 .47677 Mdot
.73641 .40404 Mdot
.26866 .25401 Mdot
.56771 .50919 Mdot
.49166 .49952 Mdot
.75677 .58889 Mdot
.71255 .416 Mdot
.72206 .48585 Mdot
.44953 .50454 Mdot
.3358 .52312 Mdot
.51881 .78069 Mdot
.81502 .40181 Mdot
.77095 .67167 Mdot
.50306 .50031 Mdot
.48513 .82314 Mdot
.68621 .31685 Mdot
.31695 .48239 Mdot
.55881 .74202 Mdot
.25649 .46333 Mdot
.40602 .27691 Mdot
.44404 .59221 Mdot
.37384 .80363 Mdot
.40498 .27819 Mdot
.47174 .8212 Mdot
.17531 .60025 Mdot
.33979 .77068 Mdot
.53913 .54445 Mdot
.38884 .30188 Mdot
.19427 .54844 Mdot
.19649 .5516 Mdot
.5274 .8313 Mdot
.25761 .35953 Mdot
.31989 .49412 Mdot
.47071 .48433 Mdot
.39503 .5414 Mdot
.34729 .67932 Mdot
.18011 .5223 Mdot
.69754 .65326 Mdot
.22005 .54272 Mdot
.79233 .56717 Mdot
.20202 .42865 Mdot
.53975 .7595 Mdot
.25728 .47132 Mdot
.5331 .37606 Mdot
.32796 .33299 Mdot
.43718 .29424 Mdot
.58489 .84286 Mdot
.76721 .3921 Mdot
.21582 .6259 Mdot
.78358 .37766 Mdot
.77501 .52554 Mdot
.24421 .36596 Mdot
.68385 .61207 Mdot
.50609 .67047 Mdot
.43064 .20279 Mdot
.21985 .4923 Mdot
.49654 .7698 Mdot
.73802 .3904 Mdot
.70003 .70946 Mdot
.33674 .78482 Mdot
.21582 .55428 Mdot
.64422 .82389 Mdot
.35289 .30122 Mdot
.61922 .73843 Mdot
.42864 .79382 Mdot
.83268 .45987 Mdot
.2936 .47644 Mdot
.472 .83265 Mdot
.62787 .578 Mdot
.39434 .81931 Mdot
.64154 .35595 Mdot
.30435 .32543 Mdot
.72835 .38606 Mdot
.27847 .4658 Mdot
.28089 .46591 Mdot
.21846 .65443 Mdot
.79749 .46903 Mdot
.80112 .51199 Mdot
.52948 .36348 Mdot
.49611 .26454 Mdot
.37414 .53928 Mdot
.63036 .4971 Mdot
.59662 .83581 Mdot
.39227 .66714 Mdot
.3453 .29834 Mdot
.18965 .49094 Mdot
.68999 .36701 Mdot
.50482 .48677 Mdot
.72867 .39615 Mdot
.746 .68452 Mdot
.22707 .59574 Mdot
.50705 .84569 Mdot
.50628 .48698 Mdot
.417 .46605 Mdot
.6633 .7316 Mdot
.63932 .45795 Mdot
.68059 .30865 Mdot
.6057 .49572 Mdot
.42928 .50936 Mdot
.30626 .51693 Mdot
.20868 .44027 Mdot
.2032 .67231 Mdot
.50177 .82711 Mdot
.68224 .30813 Mdot
.28263 .47442 Mdot
.6502 .52593 Mdot
.22729 .49169 Mdot
.63391 .83022 Mdot
.18749 .36928 Mdot
.77019 .54157 Mdot
.19843 .44152 Mdot
.56258 .38882 Mdot
.27612 .36662 Mdot
.30089 .48513 Mdot
.42589 .79294 Mdot
.55675 .61189 Mdot
.74225 .55504 Mdot
.58889 .43617 Mdot
.2846 .54021 Mdot
.54551 .4583 Mdot
.72157 .67167 Mdot
.79484 .46176 Mdot
.64635 .82261 Mdot
.25033 .34762 Mdot
.66455 .72245 Mdot
.69521 .78635 Mdot
.70184 .5372 Mdot
.53227 .44262 Mdot
.55355 .2786 Mdot
.27435 .48315 Mdot
.50252 .31643 Mdot
.49737 .55076 Mdot
.33902 .50669 Mdot
.77415 .58458 Mdot
.43435 .26732 Mdot
.34395 .33413 Mdot
.71348 .58369 Mdot
.2606 .3479 Mdot
.72662 .55839 Mdot
.20181 .66499 Mdot
.64061 .48602 Mdot
.51306 .77847 Mdot
.75107 .69611 Mdot
.46405 .21483 Mdot
.82037 .42088 Mdot
.34812 .77825 Mdot
.24956 .60093 Mdot
.67136 .60439 Mdot
.71803 .58673 Mdot
.70446 .51589 Mdot
.68184 .38184 Mdot
.38621 .78914 Mdot
.18193 .49426 Mdot
.48696 .21237 Mdot
.63331 .56901 Mdot
.47958 .47427 Mdot
.49236 .51737 Mdot
.24487 .69476 Mdot
.50495 .28796 Mdot
.44564 .83685 Mdot
.69673 .65699 Mdot
.82542 .49038 Mdot
.61987 .46883 Mdot
.32066 .55619 Mdot
.30508 .47027 Mdot
.4677 .23049 Mdot
.48891 .59399 Mdot
.65356 .62296 Mdot
.68169 .53735 Mdot
.53989 .4538 Mdot
.37445 .36915 Mdot
.36528 .20546 Mdot
.69809 .36901 Mdot
.65842 .66771 Mdot
.176 .52476 Mdot
.72425 .5738 Mdot
.35488 .30456 Mdot
.44745 .21892 Mdot
.45855 .56775 Mdot
.25393 .62994 Mdot
.56347 .8487 Mdot
.36269 .77961 Mdot
.69452 .59342 Mdot
.80771 .40993 Mdot
.48079 .36451 Mdot
.22888 .67771 Mdot
.75557 .55953 Mdot
.18594 .50784 Mdot
.65339 .69998 Mdot
.28158 .73884 Mdot
.55339 .76744 Mdot
.60274 .48153 Mdot
.19895 .46656 Mdot
.47202 .42937 Mdot
.19429 .44485 Mdot
.73684 .69661 Mdot
.39934 .52797 Mdot
.1917 .40325 Mdot
.5584 .36261 Mdot
.51534 .71249 Mdot
.34743 .65831 Mdot
.60837 .47108 Mdot
.18823 .54178 Mdot
.71439 .56823 Mdot
.34344 .38189 Mdot
.56783 .62663 Mdot
.65109 .31587 Mdot
.37736 .79631 Mdot
.77981 .39651 Mdot
.18846 .481 Mdot
.4023 .54075 Mdot
.24266 .43995 Mdot
.68982 .65216 Mdot
.26216 .59232 Mdot
.48631 .63734 Mdot
.66493 .69113 Mdot
.43327 .42806 Mdot
.23593 .66747 Mdot
.34109 .62776 Mdot
.42517 .81152 Mdot
.27849 .7147 Mdot
.76603 .57649 Mdot
.50184 .44901 Mdot
.63784 .58307 Mdot
.44824 .83226 Mdot
.22709 .6114 Mdot
.71676 .40805 Mdot
.16963 .5422 Mdot
.27707 .33847 Mdot
.70954 .77697 Mdot
.7775 .46857 Mdot
.47957 .51741 Mdot
.18486 .59934 Mdot
.76343 .5045 Mdot
.26836 .33728 Mdot
.49278 .76923 Mdot
.67047 .51603 Mdot
.47489 .83758 Mdot
.48091 .70205 Mdot
.79364 .51858 Mdot
.45909 .79179 Mdot
.60411 .54229 Mdot
.2284 .61607 Mdot
.49321 .60642 Mdot
.44492 .3041 Mdot
.38825 .50544 Mdot
.20529 .35819 Mdot
.59436 .54875 Mdot
.18218 .50856 Mdot
.18738 .51055 Mdot
.25762 .37786 Mdot
.45907 .23054 Mdot
.71139 .77519 Mdot
.5567 .79712 Mdot
.4184 .68091 Mdot
.68319 .59802 Mdot
.33972 .33866 Mdot
.23384 .40063 Mdot
.45638 .64135 Mdot
.29356 .58269 Mdot
.66367 .69903 Mdot
.35117 .80088 Mdot
.53358 .39176 Mdot
.58878 .38643 Mdot
.62986 .56821 Mdot
.71591 .41183 Mdot
.72705 .6252 Mdot
.81215 .48465 Mdot
.18874 .53747 Mdot
.58566 .53042 Mdot
.60074 .48932 Mdot
.78819 .52308 Mdot
.20958 .48267 Mdot
.44159 .39341 Mdot
.61153 .3753 Mdot
.62552 .64766 Mdot
.56723 .83107 Mdot
.78204 .51009 Mdot
.57357 .51368 Mdot
.71666 .50427 Mdot
.41317 .51659 Mdot
.59441 .32505 Mdot
.79904 .47311 Mdot
.73425 .55423 Mdot
.3898 .76726 Mdot
.61708 .51872 Mdot
.38349 .30214 Mdot
.22126 .40539 Mdot
.67963 .49131 Mdot
.18331 .52052 Mdot
.47368 .57498 Mdot
.43969 .80683 Mdot
.26109 .49611 Mdot
.34127 .38382 Mdot
.48061 .62826 Mdot
.58842 .59491 Mdot
.30809 .76465 Mdot
.76281 .5434 Mdot
.559 .57137 Mdot
.73534 .5694 Mdot
.17696 .57918 Mdot
.40171 .32252 Mdot
.51566 .32662 Mdot
.32418 .41423 Mdot
.32299 .55261 Mdot
.40759 .48167 Mdot
.68406 .37904 Mdot
.48352 .58864 Mdot
.42849 .40052 Mdot
.41908 .51938 Mdot
.62989 .65066 Mdot
.20241 .60407 Mdot
.58178 .84097 Mdot
.59719 .56727 Mdot
.16511 .54553 Mdot
.57635 .59868 Mdot
.62489 .52952 Mdot
.25451 .34453 Mdot
.54963 .58596 Mdot
.4734 .56674 Mdot
.34973 .38338 Mdot
.69261 .5323 Mdot
.57804 .83829 Mdot
.57508 .55299 Mdot
.32146 .37931 Mdot
.51704 .36199 Mdot
.56282 .50842 Mdot
.6113 .20629 Mdot
.70218 .34222 Mdot
.1788 .59252 Mdot
.19938 .48146 Mdot
.66064 .41442 Mdot
.74294 .53896 Mdot
.55295 .58533 Mdot
.43768 .80862 Mdot
.44508 .42929 Mdot
.3597 .78394 Mdot
.57136 .35695 Mdot
.64765 .66885 Mdot
.27512 .70953 Mdot
.23745 .55975 Mdot
.25877 .58839 Mdot
.69123 .68974 Mdot
.34582 .71958 Mdot
.53618 .51395 Mdot
.39324 .19699 Mdot
.25067 .2771 Mdot
.61376 .83583 Mdot
.8255 .4947 Mdot
.40604 .69864 Mdot
.22685 .49695 Mdot
.63235 .50842 Mdot
.32355 .48482 Mdot
.5111 .37415 Mdot
.37061 .30239 Mdot
.56458 .37578 Mdot
.80444 .3935 Mdot
.36274 .8054 Mdot
.48078 .62483 Mdot
.39971 .43834 Mdot
.3935 .38711 Mdot
.51153 .29937 Mdot
.53029 .68013 Mdot
.56096 .84739 Mdot
.61461 .38051 Mdot
.55629 .26589 Mdot
.68671 .38483 Mdot
.22119 .65502 Mdot
.52833 .246 Mdot
.64926 .34344 Mdot
.20022 .66394 Mdot
.79639 .55441 Mdot
.71681 .70564 Mdot
.7879 .37514 Mdot
.24634 .68295 Mdot
.66219 .6882 Mdot
.38074 .311 Mdot
.39934 .81366 Mdot
.30294 .47226 Mdot
.42063 .26726 Mdot
.35805 .73539 Mdot
.19754 .46091 Mdot
.22627 .39487 Mdot
.6118 .42141 Mdot
.56246 .61132 Mdot
.37734 .18314 Mdot
.47083 .21028 Mdot
.85699 .54194 Mdot
.36213 .77727 Mdot
.59985 .80629 Mdot
.76053 .55074 Mdot
.53564 .36294 Mdot
.43126 .80561 Mdot
.18997 .51971 Mdot
.56214 .59201 Mdot
.41648 .19293 Mdot
.24145 .53854 Mdot
.23738 .47878 Mdot
.58444 .33825 Mdot
.30732 .75761 Mdot
.46397 .22405 Mdot
.43104 .72135 Mdot
.19428 .47834 Mdot
.58296 .5996 Mdot
.26972 .59572 Mdot
.55818 .8308 Mdot
.24787 .62787 Mdot
.20828 .41123 Mdot
.56392 .37163 Mdot
.46566 .351 Mdot
.57745 .8343 Mdot
.69295 .63234 Mdot
.65312 .70638 Mdot
.7655 .73879 Mdot
.42448 .82808 Mdot
.54813 .59454 Mdot
.40403 .57461 Mdot
.19045 .63639 Mdot
.4212 .33352 Mdot
.21138 .6136 Mdot
.80699 .60325 Mdot
.23059 .38123 Mdot
.34806 .6044 Mdot
.45784 .60594 Mdot
.27876 .42058 Mdot
.76095 .57802 Mdot
.56537 .5996 Mdot
.50207 .23633 Mdot
.20739 .42366 Mdot
.66173 .66668 Mdot
.84202 .5604 Mdot
.73982 .69093 Mdot
.64632 .58303 Mdot
.38497 .80961 Mdot
.47326 .71969 Mdot
.67196 .65322 Mdot
.42641 .79752 Mdot
.43142 .44502 Mdot
.4312 .39803 Mdot
.68638 .65081 Mdot
.28258 .49004 Mdot
.20666 .35343 Mdot
.69044 .7914 Mdot
.61802 .65701 Mdot
.45298 .83881 Mdot
.26641 .73474 Mdot
.64132 .57995 Mdot
.5418 .6406 Mdot
.29698 .46255 Mdot
.59861 .53002 Mdot
.59587 .4323 Mdot
.48498 .22075 Mdot
.28197 .33115 Mdot
.35447 .21643 Mdot
.44718 .60995 Mdot
.57041 .35245 Mdot
.34053 .78501 Mdot
.28417 .34866 Mdot
.35005 .79002 Mdot
.67596 .67937 Mdot
.40926 .67595 Mdot
.81336 .69805 Mdot
.72203 .42301 Mdot
.43984 .55428 Mdot
.43011 .69557 Mdot
.41462 .70035 Mdot
.4387 .58722 Mdot
.59679 .42616 Mdot
.26784 .44756 Mdot
.22236 .37928 Mdot
.39878 .81031 Mdot
.63383 .55519 Mdot
.30146 .46935 Mdot
.59949 .37127 Mdot
.29559 .55529 Mdot
.36664 .71945 Mdot
.63671 .40894 Mdot
.22233 .36641 Mdot
.60881 .20675 Mdot
.47193 .38973 Mdot
.54893 .46299 Mdot
.32909 .52762 Mdot
.53499 .48173 Mdot
.24038 .3548 Mdot
.68061 .37268 Mdot
.40829 .39264 Mdot
.18988 .47646 Mdot
.69275 .69791 Mdot
.59071 .33445 Mdot
.32614 .20399 Mdot
.29645 .47896 Mdot
.56598 .35714 Mdot
.53241 .63085 Mdot
.74969 .6704 Mdot
.39017 .77509 Mdot
.44488 .38234 Mdot
.54017 .50486 Mdot
.65703 .73297 Mdot
.41774 .80365 Mdot
.6629 .39028 Mdot
.21015 .68336 Mdot
.53015 .62834 Mdot
.53356 .67887 Mdot
.55492 .81358 Mdot
.49301 .48508 Mdot
.50197 .76748 Mdot
.40931 .69364 Mdot
.39631 .47494 Mdot
.58014 .19421 Mdot
.50462 .4945 Mdot
.56001 .50122 Mdot
.59289 .51936 Mdot
.26806 .37369 Mdot
.42279 .7553 Mdot
.40183 .6084 Mdot
.39258 .33452 Mdot
.27215 .50322 Mdot
.31522 .32122 Mdot
.31987 .31441 Mdot
.59817 .33339 Mdot
.2381 .3574 Mdot
.22942 .38955 Mdot
.46852 .7871 Mdot
.44854 .81995 Mdot
.34607 .65316 Mdot
.35728 .77474 Mdot
.50333 .39908 Mdot
.7301 .48761 Mdot
.25143 .62727 Mdot
.68451 .79503 Mdot
.64656 .6168 Mdot
.38438 .70088 Mdot
.24984 .71341 Mdot
.33017 .77356 Mdot
.66062 .31874 Mdot
.74225 .39694 Mdot
.22887 .3037 Mdot
.28537 .46137 Mdot
.8096 .39745 Mdot
.5277 .25901 Mdot
.24265 .69895 Mdot
.4252 .52467 Mdot
.5437 .60011 Mdot
.70295 .67052 Mdot
.46213 .56403 Mdot
.49505 .2909 Mdot
.75981 .6699 Mdot
.69333 .69019 Mdot
.34328 .71601 Mdot
.3989 .68292 Mdot
.57109 .44439 Mdot
.65628 .52301 Mdot
.62053 .83218 Mdot
.49586 .32718 Mdot
.41798 .46314 Mdot
.83072 .58117 Mdot
.58872 .19679 Mdot
.27362 .33245 Mdot
.51858 .8296 Mdot
.69681 .33212 Mdot
.42356 .51542 Mdot
.71111 .28182 Mdot
.62163 .54722 Mdot
.68082 .59987 Mdot
.69625 .37469 Mdot
.24615 .44232 Mdot
.79278 .47869 Mdot
.73275 .7632 Mdot
.27719 .73527 Mdot
.46789 .57214 Mdot
.87231 .49496 Mdot
.19274 .48317 Mdot
.40568 .45019 Mdot
.78837 .46484 Mdot
.37091 .80098 Mdot
.56665 .38644 Mdot
.18423 .61075 Mdot
.6631 .49175 Mdot
.61061 .53304 Mdot
.2454 .46198 Mdot
.78406 .38152 Mdot
.48147 .47771 Mdot
.85592 .53637 Mdot
.75379 .40173 Mdot
.23988 .48662 Mdot
.75672 .53991 Mdot
.61316 .54859 Mdot
.63251 .61147 Mdot
.64736 .47749 Mdot
.56346 .55511 Mdot
.5752 .51349 Mdot
.60797 .48963 Mdot
.44703 .3939 Mdot
.59847 .45827 Mdot
.71497 .42362 Mdot
.68266 .34807 Mdot
.71664 .68569 Mdot
.21328 .32852 Mdot
.33658 .30652 Mdot
.51138 .28069 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0Moooool2o`0000Wooooo0_l00035ooooo`007?ooool0
0ol0003oooooooooo`1gooooo`;o00002Oooool2o`000003ooooool0003o000000?ooooo0_l0002m
ooooo`007?ooool00ol0003oooooooooo`1kooooo`;o00002?ooool2o`0000?ooooo0_l0002moooo
o`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000
ooooooooool0JOooool2o`00013ooooo0_l00002ooooo`;o00000oooool2o`000<?ooooo00001_oo
ooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1_ooool00ol0003oooooooooo`1Yooooo`;o00004?ooool2o`0000;ooooo0_l00003ooooo`;o0000
;oooool2o`0000;ooooo1?l0002<ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0M?ooool2o`000005ooooool0
003o0000o`000?ooool00ol0000cooooo`;o00000_ooool3o`000003ooooool0003o000000;o0000
S?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^
kP06ooooo`?o0000M?ooool2o`000004ooooool0003o0000o`0000;ooooo0_l0000:ooooo`;o0000
00?oooooo`000?l000009?ooool2o`0000?ooooo0_l0002Aooooo`0000?oooooo`000?ooool00_oo
ool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0I_oo
ool3o`0000Wooooo0ol0000Cooooo`;o000000?oooooo`000?l00000_?ooool00003ooooool@413o
oooo00;ooooo00?o410@ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06Kooooo0ol00009ooooo`?o00009Oooool4o`0002Cooooo0ol00024ooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003ooooo
ooooo`1`ooooo`;o000000?oooooo`000?l000008?ooool2o`0000?ooooo1?l0000Tooooo`?o0000
3?ooool2o`0007Kooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c006ooooo`03o`000?oooooooooo073ooooo0_l0000>ooooo`Co00003oooool4o`00
00?ooooo1?l0000Booooo`;o00007oooool2o`0007Kooooo000Looooo`03o`000?oooooooooo05oo
oooo0_l0000>ooooo`;o00001oooool2o`0000Kooooo1?l0000?ooooo`;o00002?ooool2o`00017o
oooo0_l0000Eooooo`;o00002?ooool4o`0007Cooooo000Looooo`03o`000?oooooooooo05oooooo
0_l0000>ooooo`Co00001Oooool2o`0001Cooooo0_l00003ooooo`;o00000_ooool2o`000004oooo
ool0003o0000ooooo`;o0000:?ooool2o`0000?ooooo0_l00004ooooo`?o0000M?ooool001cooooo
00?o0000ooooooooool0LOooool2o`0001_ooooo0_l00003ooooo`;o00000_ooool2o`000003oooo
ool0003o000000Go0000:oooool2o`0007_ooooo000Looooo`03o`000?oooooooooo09?ooooo1_l0
0002ooooo`;o00000_ooool3o`000:Oooooo000Looooo`03o`000?oooooooooo05gooooo0_l0000b
ooooo`;o000000?oooooo`000?l000000ol00006ooooo`?o0000Yoooool001cooooo00?o0000oooo
ooooool0GOooool2o`0003;ooooo0_l000000ooooooo0000o`000011ooooo`?o0000Koooool001co
oooo00?o0000ooooooooool0V_ooool2o`0000?ooooo0_l0000fooooo`?o0000Koooool001cooooo
00?o0000ooooooooool0V_ooool2o`0000?ooooo0_l0000hooooo`;o0000K_ooool001cooooo00?o
0000ooooooooool0Xoooool3o`0003?ooooo0ol0001]ooooo`007?ooool00ol0003oooooooooo`2S
ooooo`?o00000_ooool2o`00033ooooo0_l0001]ooooo`007?ooool00ol0003oooooooooo`2Loooo
o`?o00001oooool4o`0000Kooooo0_l0000Xooooo`;o0000KOooool001cooooo0_l0002Mooooo`?o
00001?ooool2o`000003ooooool0003o000000Sooooo0_l0000Vooooo`;o00000_ooool2o`0006_o
oooo000Looooo`03o`000?oooooooooo05Cooooo0_l00010ooooo`;o00001oooool2o`0000;ooooo
1_l0000_ooooo`;o00000_ooool2o`0006_ooooo000Looooo`03o`000?oooooooooo05Cooooo0_l0
0010ooooo`;o00001Oooool4o`0000Cooooo1?l0002Pooooo`007?ooool00ol0003oooooooooo`2F
ooooo`?o00001?ooool4o`0000Gooooo1Ol0002Nooooo`007?ooool00ol0003oooooooooo`2Eoooo
o`Oo000000?oooooo`000?l000000_l00003ooooo`Wo0000<_ooool2o`0006Sooooo000Looooo`03
o`000?oooooooooo08Gooooo0_l00002ooooo`;o00001oooool=o`0000Gooooo1_l000000ooooooo
0000o`000004ooooo`;o0000;?ooool2o`0006Sooooo000Looooo`03o`000?oooooooooo087ooooo
0_l00002ooooo`?o000000?oooooo`000?l000001_ooool>o`0000Cooooo0_l000000ooooooo0000
o`000002o`0000Oooooo0_l0000Zooooo`;o0000J_ooool001cooooo00?o0000ooooooooool0Oooo
ool4o`0000;ooooo0ol00004oooooaCo000000?oooooo`000?l000001_l0000dooooo`;o0000J_oo
ool001cooooo00?o0000ooooooooool0Ooooool3o`0000?ooooo0ol00004oooooago00000_ooool2
o`0003Cooooo0_l0001Vooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o0000<?ooool2o`00
00?ooooo0_l00005oooooa?o000000?oooooo`000?l000002?l000000ooooooo0000o`000003oooo
o`;o0000;oooool2o`0006Kooooo000Looooo`03o`000?oooooooooo04cooooo1?l0000`ooooo`;o
00002OoooolDo`0000?ooooo2?l00002ooooo`;o00000_ooool2o`00037ooooo0_l0001Tooooo`00
7?ooool00ol0003oooooooooo`1<ooooo`;o0000>Oooool2o`0000;ooooo7_l00003ooooo`Go0000
<_ooool2o`0006Cooooo000Looooo`03o`000?oooooooooo08Oooooo0_l000000ooooooo0000o`00
000Jo`0000Sooooo0ol0002Hooooo`007?ooool00ol0003oooooooooo`27ooooo`;o000000?ooooo
o`000?l000007?l0002Qooooo`007?ooool00ol0003oooooooooo`19ooooo`;o0000??oooolQo`00
00Gooooo0_l0002Jooooo`007?ooool00ol0003oooooooooo`18ooooo`?o00008Oooool2o`0001_o
oooo7ol00004ooooo`?o0000=?ooool2o`0006Cooooo000Looooo`;o0000BOooool2o`0002;ooooo
0_l000000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l000003?ooool2o`000003oooo
ool0003o000001co00001?ooool2o`0003Gooooo0_l000000ooooooo0000o`00001Qooooo`007?oo
ool00ol0003oooooooooo`17ooooo`;o00009_ooool3o`0000?ooooo0ol000000ooooooo0000o`00
0002o`0000;ooooo0_l00006ooooob3o00001Oooool2o`0002Wooooo0_l000001?oooooo0000o`00
0?l00007ooooo`Co0000HOooool001cooooo00?o0000ooooooooool0Aoooool2o`00027ooooo0_l0
0004ooooo`;o00000oooool2o`0000;ooooo1?l00002ooooo`;o00001_oooolPo`0002gooooo0_l0
00001?oooooo0000o`000?ooool3o`0000Oooooo0_l0001Sooooo`007?ooool00ol0003ooooooooo
o`1Zooooo`;o00003_ooool2o`0000[ooooo8Ol0000]ooooo`;o00000oooool3o`0000_ooooo0_l0
001Pooooo`007?ooool00ol0003oooooooooo`1Tooooo`;o00004_ooool4o`0000Kooooo0_l00002
ooooo`;o00000_oooolBo`0000;ooooo2?l0000Qooooo`?o00003oooool3o`0000Gooooo0_l00004
ooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0I?ooool2o`0000gooooo1?l000000ooo
oooo0000o`000002ooooo`;o000000Coooooo`000?l0003ooooo0_l00004oooooaco00008oooool4
o`0000Gooooo0_l00006ooooo`Go00001?ooool2o`0006Kooooo000Looooo`03o`000?oooooooooo
04;ooooo0_l0000Pooooo`;o000000?oooooo`000?l000002_ooool7o`0000;ooooo2_l00002oooo
oaco00000_ooool2o`0001Sooooo0_l00007ooooo`Ko000000Coooooo`000?l0003ooooo0_l00003
ooooo`Go00002Oooool2o`00067ooooo000Looooo`03o`000?oooooooooo04;ooooo0_l0000Goooo
o`;o00001_ooool2o`0000;ooooo0_l0000;ooooo`Co00001Oooool:o`0000?ooooo3?l000000ooo
oooo0000o`000006o`000003ooooool0003o000000Ko00006?ooool2o`0000?ooooo0_l00002oooo
o`Ko00001?ooool2o`0000Cooooo0_l00006ooooo`;o00000oooool4o`0005oooooo000Looooo`03
o`000?oooooooooo047ooooo0_l0000Hooooo`;o00000_ooool2o`0000;ooooo0_l0000=ooooo`Co
00002Oooool2o`000004ooooool0003o0000ooooo`;o00000ooooolEo`000003ooooool0003o0000
00;ooooo1?l0000Eooooo`;o00001_ooool2o`000004ooooool0003o0000o`0001Gooooo1Ol00003
ooooo`;o0000Goooool001cooooo00?o0000ooooooooool0@Oooool3o`0001_ooooo1_l0000:oooo
o`Go00000_ooool2o`000003ooooool0003o000000;o00001Oooool2o`0000Kooooo2Ol000000ooo
oooo0000o`00000:o`0000Cooooo0_l0000Gooooo`;o00002Oooool2o`0000gooooo0ol00003oooo
o`;o000000?oooooo`000?l000000ol0001Tooooo`007?ooool00ol0003oooooooooo`10ooooo`Co
00004Oooool2o`000003ooooool0003o000000Oooooo1?l00006ooooo`Wo00000_ooool2o`000003
ooooool0003o000000;o00001Oooool2o`0000?ooooo0_l000000ooooooo0000o`00000Eo`0000?o
oooo0_l0000Wooooo`;o00002?ooool3o`0000?ooooo1?l000000ooooooo0000o`00001Uooooo`00
7?ooool00ol0003oooooooooo`10ooooo`;o00004oooool2o`000003ooooool0003o000000gooooo
4Ol00002ooooo`Co00001?ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l00000
0ol00002ooooo`[o00000_ooool4o`0001?ooooo0_l00002ooooo`?o000000?oooooo`000?l00000
0ol00009ooooo`Go00001oooool4o`0000Gooooo0_l0001Xooooo`007?ooool00ol0003ooooooooo
o`1Cooooo`;o000000?oooooo`000?l000003ooooolCo`000004ooooool0003o0000o`0000Oooooo
0_l00008ooooo`co00006Oooool=o`0000;ooooo0_l000001Ooooooo0000o`000?l0003ooooo00Co
00002?ooool4o`0000oooooo0_l0001Nooooo`007?ooool00ol0003oooooooooo`1Booooo`?o0000
00?oooooo`000?l000004oooool@o`0001Cooooo0_l000000ooooooo0000o`000002o`000003oooo
ool0003o000001Oooooo0_l00002ooooo`Co00000_ooool2o`0000Cooooo0_l000001?oooooo0000
o`000?ooool4o`000003ooooool0003o000001;ooooo0_l00008ooooo`;o0000G_ooool001cooooo
00?o0000ooooooooool0Coooool2o`000003ooooool0003o000000Wooooo0_l00005ooooo`;o0000
00?oooooo`000?l000004ol00002ooooo`;o00000_ooool2o`0000kooooo1?l0000Jooooo`;o0000
0_ooool2o`0000[ooooo0_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l00000
0_ooool2o`0000kooooo0ol00002ooooo`;o00001?ooool2o`0002?ooooo0_l0000hooooo`007?oo
ool00ol0003oooooooooo`1>ooooo`Go00002_ooool2o`0000Cooooo4_l000000ooooooo0000o`00
0008o`0000;ooooo0_l0000Yooooo`?o00002oooool2o`0000;ooooo3_l00002ooooo`?o00000_oo
ool2o`0000[ooooo0_l00002ooooo`;o00001?ooool2o`0002?ooooo0ol0000gooooo`007?ooool2
o`0004oooooo0_l000000ooooooo0000o`000004ooooo`Co00002?oooolBo`000003ooooool0003o
000000Oo00004Oooool2o`0000;ooooo0_l0000Gooooo`?o00002oooool2o`000003ooooool0003o
000001;o00000_ooool2o`0000Cooooo0_l00006ooooo`Co00001?ooool3o`0002?ooooo0_l0000g
ooooo`007?ooool00ol0003oooooooooo`0looooo`Go00004Oooool2o`0000?ooooo1?l00008oooo
oaco00000_ooool2o`0000gooooo0_l00002ooooo`;o00004?ooool2o`0000;ooooo0_l00005oooo
o`;o00000oooool2o`0000Kooooo5Ol00007ooooo`;o00001_ooool4o`0000Cooooo0ol0001Loooo
o`007?ooool00ol0003oooooooooo`0looooo`Go00002Oooool2o`0000Kooooo0_l0000=oooooako
00000_ooool2o`0000oooooo1?l0000@ooooo`;o00000_ooool2o`0000Gooooo0_l000000ooooooo
0000o`000002o`000003ooooool0003o000000;ooooo5_l0000Aooooo`;o0000Hoooool001cooooo
00?o0000ooooooooool0?oooool2o`000003ooooool0003o000000Kooooo0_l00004ooooo`;o0000
3ooooolNo`0000;ooooo0_l0000?ooooo`?o00007oooool4o`000004ooooool0003o0000oooooaWo
00002oooool2o`0000[ooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`0oooooo`;o0000
00?oooooo`000?l000001_ooool2o`0000Cooooo0_l00005ooooo`;o00002ooooolLo`0001;ooooo
1?l0000=ooooo`?o00001?ooool2o`0000Kooooo0_l000000ooooooo0000o`000004oooooa[o0000
2oooool2o`000004ooooool0003o0000o`0000Cooooo1?l0001Kooooo`007?ooool00ol0003ooooo
ooooo`0jooooo`;o00000oooool2o`0000_ooooo0_l00009ooooo`;o00002OoooolNo`0001Cooooo
0_l00002ooooo`;o00002Oooool3o`0000;ooooo1?l00006ooooo`;o000000?oooooo`000?l00000
0_l00002ooooo`Wo000000?oooooo`000?l000004Ol00009ooooo`Oo000000?oooooo`000?l00000
0ol00008ooooo`;o0000DOooool001cooooo00?o0000ooooooooool0>Oooool3o`000003ooooool0
003o000000Kooooo0_l00005ooooo`;o00002?ooool2o`0000[ooooo0_l000000ooooooo0000o`00
000Go`000003ooooool0003o000001Oooooo0_l00006ooooo`;o00001_ooool2o`0000Gooooo0_l0
0006ooooo`;o00000_ooool2o`000003ooooool0003o000001So00001?ooool9o`000004ooooool0
003o0000ooooo`;o000000?oooooo`000?l000002?ooool2o`00057ooooo000Looooo`03o`000?oo
oooooooo03Wooooo0_l00002ooooo`;o00001_ooool2o`0000Kooooo0_l00005ooooo`Co00001ooo
ool2o`0000Gooooo6ol0000Nooooo`?o00003Oooool2o`0000;ooooo0ol00005ooooo`;o000000?o
ooooo`000?l000006?l00004ooooo`Go000000Goooooo`000?l0003o0000ooooo`02o`000003oooo
ool0003o000000[ooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`0iooooo`;o00004_oo
ool2o`0000Cooooo0ol00009ooooo`;o00001Oooool=o`000003ooooool0003o000000Ko000000?o
ooooo`000?l000000_l0000Gooooo`;o00001Oooool5o`0000oooooo0ol00004ooooo`?o00000_oo
oolLo`0000?ooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l0000:ooooo`;o0000
1Oooool2o`0004_ooooo000Looooo`03o`000?oooooooooo053ooooo0_l000000ooooooo0000o`00
000<ooooo`;o00000ooooolEo`0000;ooooo0_l000000ooooooo0000o`00000Cooooo`;o000000?o
ooooo`000?l000001?l000000ooooooo0000o`000003o`0000Gooooo0_l00009ooooo`;o00001?oo
ool2o`0000Kooooo6Ol00003ooooo`;o00001oooool6o`0000kooooo1?l0001:ooooo`007?ooool0
0ol0003oooooooooo`0hooooo`;o00002oooool4o`000003ooooool0003o000000Cooooo0_l00005
ooooo`;o00002?ooool3o`000003ooooool0003o000000Kooooo3?l00004ooooo`[o000000?ooooo
o`000?l000000ol000000ooooooo0000o`000002ooooo`;o000000Coooooo`000?l0003ooooo1_l0
00000ooooooo0000o`000008ooooo`;o00002Oooool2o`0000Cooooo0_l00007oooooaWo00000ooo
ool4o`000004ooooool0003o0000ooooo`Ko00001Oooool2o`0000Oooooo1?l0000Gooooo`;o0000
<Oooool001cooooo00?o0000ooooooooool0=oooool4o`0000;ooooo0_l00005ooooo`Go000000?o
ooooo`000?l000002oooool2o`0000Kooooo0_l000001?oooooo0000o`000?ooool2o`0000Cooooo
1_l00003ooooo`?o00001_ooool3o`0000;ooooo1Ol000000ooooooo0000o`000006o`0000;ooooo
0_l00002ooooo`Co00000_ooool2o`0001cooooo0_l00008oooooaWo00000_ooool4o`000003oooo
ool0003o000000?ooooo0_l00007ooooo`;o00001oooool3o`0001Sooooo0_l0000aooooo`007?oo
ool00ol0003oooooooooo`0gooooo`Co00000_ooool2o`0000Gooooo0_l0000Booooo`;o00001Ooo
ool2o`0000[ooooo1Ol0000<ooooo`?o00000oooool5o`0000?ooooo1Ol00002ooooo`?o00000_oo
ool2o`0001cooooo0_l00004ooooo`?o00001ooooolDo`0000;ooooo0ol00002ooooo`?o00001ooo
ool5o`0000;ooooo0_l00006ooooo`;o0000Coooool001cooooo00?o0000ooooooooool0??ooool4
o`0000Gooooo1?l0000?ooooo`;o00001Oooool3o`00017ooooo0ol00004ooooo`Ko00000_ooool5
o`0000?ooooo1Ol00002ooooo`;o00000oooool2o`0001_ooooo0ol00005ooooo`;o00002Oooool7
o`000003ooooool0003o000000So00004Oooool:o`0000Gooooo0_l0000Mooooo`;o0000<?ooool0
0006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413ooooooooo
o`04ooooo`03o`000?oooooooooo03_ooooo1Ol00005ooooo`Co00003oooool2o`0000Gooooo1Ol0
000?ooooo`?o00001?ooool2o`000005ooooool0003o0000o`000?ooool00_l00002ooooo`;o0000
1?ooool4o`0000Kooooo0ol0000Booooo`;o00001oooool2o`000003ooooool0003o000000kooooo
4_l000000ooooooo0000o`000002ooooo`Co00002_ooool5o`000003ooooool0003o000000;ooooo
0_l00003ooooo`;o00001Oooool2o`0001Cooooo0_l0000`ooooo`0000KoooooogMgMonHV9Sooooo
oiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03[o
oooo1_l00006ooooo`;o00004?ooool2o`0000Kooooo1?l0000?ooooo`;o00002oooool3o`0000Wo
oooo0ol00006ooooo`;o00000_ooool2o`0000oooooo0_l00007ooooo`Go00003oooool@o`0000;o
oooo0_l00002ooooo`Co00002?ooool2o`000004ooooool0003o0000o`0000Kooooo0_l00002oooo
o`?o00001Oooool2o`000003ooooool0003o000004?ooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00Wooooo1Ol00006ooooo`03o`000?oooooooooo03[ooooo0ol000000ooooooo
0000o`000006ooooo`?o00005oooool2o`00017ooooo0_l000000ooooooo0000o`000008ooooo`;o
00001_ooool2o`0000gooooo1?l00005ooooo`;o00004_ooool2o`00013ooooo4_l00004ooooo`?o
00002_ooool2o`0000;ooooo0_l0000:ooooo`;o00002?ooool3o`00017ooooo0_l0000`ooooo`00
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oo
oooo0ol0000iooooo`Co00002_ooool3o`0001Oooooo0_l0000@ooooo`;o000000?oooooo`000?l0
00003oooool3o`0000gooooo0_l00007ooooo`;o00002Oooool2o`0000Sooooo0ol0000>ooooo`;o
000000?oooooo`000?l000001ol000000ooooooo0000o`000003o`0000?ooooo1?l0000Booooo`;o
00002_ooool4o`0000;ooooo1?l0000@ooooo`;o0000<?ooool00003ooooool0003ooooo00;ooooo
00?o0000ooooooooool02Oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo03Wo
oooo1?l00007ooooo`;o00000_ooool3o`0001Kooooo0_l0000Gooooo`;o00002oooool2o`0000Co
oooo0_l0000Gooooo`;o00000oooool2o`0000Sooooo0ol00009ooooo`Ko00000_ooool>o`0000Co
oooo0_l0000>ooooo`;o00000oooool3o`0000;ooooo0_l00006ooooo`Co00001?ooool2o`00013o
oooo0_l0000`ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03ogMg
Moo<c<co000000Oooooo00?o0000ooooooooool0?_ooool2o`0000Cooooo0_l00003ooooo`;o0000
;oooool2o`00017ooooo0_l0000Gooooo`;o00006Oooool7o`000003ooooool0003o000000co0000
0_ooool3o`0000Wooooo0_l00004ooooo`;o00000oooool2o`0000?ooooo0_l0000:ooooo`;o0000
00?oooooo`000?l000000_l0000?ooooo`;o0000<?ooool00006oooooomgMgOoV9RHoooooonHV9So
MgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo03kooooo1?l00006ooooo`;o
00003_ooool2o`0000cooooo0_l0001Aooooo`;o00002oooool:o`0000Kooooo0_l000001?oooooo
0000o`000?l00009ooooo`;o00001oooool2o`00017ooooo1ol0000?ooooo`;o0000<?ooool00006
ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooo
oooo03oooooo0ol00005ooooo`?o00002oooool2o`000003ooooool0003o000000cooooo0_l00004
ooooo`;o0000;Oooool2o`0001_ooooo0ol0000=ooooo`Go000000Coooooo`000?l0003ooooo2_l0
000:ooooo`;o00001oooool2o`0001?ooooo0_l0000Aooooo`;o0000<Oooool001cooooo00?o0000
ooooooooool0?oooool2o`0000;ooooo0_l00002ooooo`;o00003?ooool2o`0000oooooo0_l00004
ooooo`Co0000:oooool2o`0001_ooooo1Ol00006ooooo`;o00001?ooool3o`0000Gooooo2?l0000;
ooooo`?o00002Oooool2o`0002Cooooo0_l0000aooooo`007?ooool00ol0003oooooooooo`0ooooo
o`;o00000_ooool2o`000003ooooool0003o000000gooooo1?l0000Booooo`Go0000:?ooool2o`00
00;ooooo0_l0000Looooo`Co00001Oooool2o`0000Gooooo0_l00007ooooo`;o00003oooool2o`00
00;ooooo0_l00002ooooo`;o00000_ooool2o`0001Gooooo0_l0000=ooooo`;o0000<Oooool001co
oooo00?o0000ooooooooool0?oooool3o`0000Cooooo0_l0000?ooooo`;o00004_ooool3o`0000;o
oooo0_l00003ooooo`;o00002_ooool2o`0001Gooooo0_l00002ooooo`;o00007_ooool2o`0000Go
oooo0_l0000Jooooo`;o00000oooool2o`000004ooooool0003o0000o`0000;ooooo0_l0000Ioooo
o`Co00002oooool2o`00037ooooo000Looooo`03o`000?oooooooooo03oooooo0ol00003ooooo`;o
00003oooool2o`0001Sooooo0_l00003ooooo`;o00001Oooool2o`0000;ooooo1Ol00003ooooo`;o
000000?oooooo`000?l00000<Oooool2o`0001kooooo0ol00003ooooo`;o000000?oooooo`000?l0
00008?ooool2o`0003kooooo000Looooo`03o`000?oooooooooo03gooooo0ol00004ooooo`?o0000
3_ooool3o`0001gooooo0_l00004ooooo`[o00000oooool7o`0000Cooooo1Ol0000Rooooo`;o0000
0_ooool4o`0001cooooo1?l00005ooooo`;o0000;Oooool2o`00037ooooo000Looooo`03o`000?oo
oooooooo03cooooo1?l00004ooooo`;o00003oooool3o`0001gooooo0_l00004ooooo`Go000000?o
ooooo`000?l000001Oooool3o`0000;ooooo0_l000001?oooooo0000o`000?ooool5o`000003oooo
ool0003o000001oooooo0_l00002ooooo`Co00000_ooool2o`0001[ooooo0_l00003ooooo`Co0000
;Oooool2o`00037ooooo000Looooo`03o`000?oooooooooo03cooooo0_l00006ooooo`;o00003_oo
ool4o`000003ooooool0003o000001Wooooo0_l000000ooooooo0000o`00000?ooooo`;o00001_oo
ool2o`0000?ooooo0ol000001?oooooo0000o`000?l0000Pooooo`Co00001?ooool2o`0001[ooooo
0_l00003ooooo`;o0000H_ooool001cooooo00?o0000ooooooooool0@?ooool2o`0000Wooooo0_l0
0006ooooo`Co00000_ooool2o`0001Wooooo1Ol00005ooooo`;o00005Oooool3o`000004ooooool0
003o0000o`00023ooooo0_l00006ooooo`;o00003?ooool2o`0007Gooooo000Looooo`03o`000?oo
oooooooo03gooooo1Ol00009ooooo`?o00001Oooool5o`0001kooooo0_l00006ooooo`;o000000?o
ooooo`000?l000005_ooool2o`000003ooooool0003o000000;o00001_ooool2o`000003ooooool0
003o000001Oooooo1Ol0000;ooooo`;o0000@_ooool2o`00037ooooo000Looooo`03o`000?oooooo
oooo03_ooooo1_l0000;ooooo`;o00001Oooool5o`0000;ooooo0_l0000Uooooo`;o00001Oooool2
o`0001;ooooo1?l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000002oooool2
o`0000[ooooo1Ol0001?ooooo`;o0000<Oooool001cooooo00?o0000ooooooooool0>_ooool3o`00
00;ooooo0_l0000Aooooo`Oo000000?oooooo`000?l00000;?ooool2o`0001Gooooo1_l0000Aoooo
o`;o00002Oooool2o`0005?ooooo0_l0000aooooo`007?ooool2o`0003_ooooo0_l00003ooooo`;o
00004Oooool3o`0000;ooooo0_l0000Wooooo`;o00007Oooool2o`000004ooooool0003o0000o`00
00Gooooo0ol0000Dooooo`?o00000_ooool2o`00087ooooo000Looooo`03o`000?oooooooooo03[o
oooo0_l0000Eooooo`?o00000oooool3o`0002Kooooo0_l0000Pooooo`?o00001Oooool4o`0001Co
oooo0_l00002ooooo`;o0000POooool001cooooo00?o0000ooooooooool0>Oooool2o`0000cooooo
0_l00008ooooo`;o00001?ooool3o`0003[ooooo0ol000000ooooooo0000o`00000<ooooo`;o0000
1?ooool3o`000003ooooool0003o000000gooooo0_l0000;ooooo`Co0000NOooool001cooooo00?o
0000ooooooooool0>Oooool2o`000003ooooool0003o000000Wooooo0_l00008ooooo`;o00001_oo
ool2o`0003Gooooo3ol00006ooooo`?o00001Oooool2o`000003ooooool0003o000000gooooo0_l0
000;ooooo`Co0000;_ooool2o`0000_ooooo0_l00008ooooo`;o0000<_ooool001cooooo00?o0000
ooooooooool0>oooool3o`0000kooooo1_l00007ooooo`;o00000_ooool2o`0002Gooooo0_l00008
oooooa7o00001_ooool4o`0000Kooooo0_l00018ooooo`;o000000?oooooo`000?l000000_l0000;
ooooo`;o00002?ooool2o`0003;ooooo000Looooo`03o`000?oooooooooo03Wooooo1_l0000=oooo
o`Oo00001?ooool3o`0000?ooooo0_l00002ooooo`;o00008Oooool2o`0000Sooooo1Ol00006oooo
o`;o00000_ooool2o`000003ooooool0003o000000Cooooo1Ol00004ooooo`;o0000B?ooool2o`00
0004ooooool0003o0000o`0000Cooooo0_l0000@ooooo`;o0000<_ooool001cooooo00?o0000oooo
ooooool0>Oooool2o`0000;ooooo0_l00005ooooo`;o00002_ooool3o`0000Cooooo0ol00004oooo
o`Go00008Oooool2o`0000Sooooo0_l000000ooooooo0000o`000009ooooo`;o000000?oooooo`00
0?l000000_l00004ooooo`Go00005_ooool2o`0000;ooooo0_l0000]ooooo`;o00000_ooool5o`00
0003ooooool0003o000000;ooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o
00002_ooool2o`0000cooooo0ol0000[ooooo`Co00003?ooool2o`000003ooooool0003o000000;o
00001?ooool6o`0000;ooooo0_l0000Aooooo`;o00000_ooool2o`0002gooooo0_l00002ooooo`Go
000000?oooooo`000?l000000_l000000ooooooo0000o`000013ooooo`007?ooool00ol0003ooooo
ooooo`0jooooo`;o00000_ooool2o`00013ooooo0_l00006ooooo`;o00000_ooool2o`000003oooo
ool0003o000001_ooooo0ol0000=ooooo`Co00000oooool3o`0000;ooooo0_l00003ooooo`;o0000
0oooool2o`0000Gooooo1?l00002ooooo`;o0000AOooool2o`0000Oooooo1?l000000ooooooo0000
o`000013ooooo`007?ooool00ol0003oooooooooo`0jooooo`?o000000?oooooo`000?l000002?oo
ool3o`0000Gooooo0_l00006ooooo`;o00000_ooool3o`0001gooooo0ol00003ooooo`;o00001ooo
ool3o`0000Gooooo0ol00002ooooo`?o00000_ooool2o`0000;ooooo1?l00005ooooo`?o00008Ooo
ool2o`0002Kooooo0_l00006ooooo`;o000000?oooooo`000?l000001?l0000?ooooo`;o0000<Ooo
ool001cooooo00?o0000ooooooooool0>?ooool:o`0000Kooooo0ol00005ooooo`;o00000oooool2
o`0000Cooooo1?l00004ooooo`;o00001?ooool2o`0001;ooooo0_l00002ooooo`?o00001_ooool4
o`0000?ooooo0_l00006ooooo`;o00001_ooool4o`0000Gooooo1Ol0000Aooooo`;o00003?ooool2
o`0002kooooo0_l000000ooooooo0000o`000004o`0000oooooo0_l0000aooooo`007?ooool00ol0
003oooooooooo`0hooooo`Oo000000?oooooo`000?l000000_l00002ooooo`;o00000_ooool2o`00
00Cooooo0_l00003ooooo`Co00000_ooool2o`000003ooooool0003o000000?ooooo1?l00002oooo
o`;o00005_ooool2o`0000Kooooo1Ol00003ooooo`;o00000_ooool2o`0000Gooooo0_l00005oooo
o`?o00001?ooool5o`0000?ooooo1?l0000:ooooo`;o00002_ooool2o`0001Sooooo0ol0000Goooo
o`;o00000_ooool3o`0004;ooooo000Looooo`03o`000?oooooooooo03gooooo0_l00003ooooo`;o
000000Coooooo`000?l0003o00000_ooool2o`000003ooooool0003o000000?o00000oooool4o`00
00Gooooo0_l00005ooooo`;o00000oooool4o`0001Wooooo1?l0000:ooooo`;o00001Oooool2o`00
00;ooooo1_l00003ooooo`Ko00000oooool4o`0000Wooooo0_l00002ooooo`;o00001oooool2o`00
01Sooooo1Ol00004ooooo`;o000000?oooooo`000?l000003?ooool2o`0000;ooooo0ol00012oooo
o`007?ooool00ol0003oooooooooo`0jooooo`;o00002?ooool4o`0000;ooooo0_l000000ooooooo
0000o`000002o`0000Cooooo0_l000000ooooooo0000o`000007ooooo`;o00001oooool4o`0001Wo
oooo1?l00002ooooo`;o00002_ooool2o`0000Gooooo0ol00006ooooo`;o00000_ooool2o`00013o
oooo0_l000001?oooooo0000o`000?l00007ooooo`;o00001_ooool2o`0000?ooooo0_l0000>oooo
o`;o00001?ooool2o`000003ooooool0003o000000cooooo1?l00004ooooo`;o00003Oooool2o`00
033ooooo000Looooo`03o`000?oooooooooo03Oooooo0_l000000ooooooo0000o`000007ooooo`Go
00001Oooool4o`0000Oooooo0_l00006ooooo`?o000000?oooooo`000?l000001_ooool2o`0000go
oooo1?l00006ooooo`Ko00000_ooool2o`0000[ooooo0_l00005ooooo`;o00001oooool2o`000004
ooooool0003o0000o`00013ooooo1Ol0000@ooooo`Co000000?oooooo`000?l000009Oooool6o`00
00;ooooo0_l0000;ooooo`Go0000;oooool001cooooo00?o0000ooooooooool0=_ooool3o`0000[o
oooo0_l000000ooooooo0000o`000004ooooo`?o00000_ooool2o`0000Oooooo0ol00003ooooo`Ko
00001_ooool2o`0000Kooooo0_l00004ooooo`Go00001_ooool3o`000003ooooool0003o000001Go
oooo0_l00006ooooo`Oo00004?ooool4o`0000Kooooo0_l00002ooooo`;o00001_ooool3o`0002So
oooo1_l00002ooooo`;o00002oooool2o`000003ooooool0003o000002oooooo000Looooo`;o0000
=oooool2o`0000kooooo0_l00003ooooo`Co00000_ooool2o`0000Cooooo0_l000001?oooooo0000
o`000?l00005ooooo`Ko00003?ooool2o`0000Cooooo0_l00006ooooo`Go00000_ooool2o`00017o
oooo0_l00002ooooo`;o00001Oooool8o`0000?ooooo0_l0000Eooooo`;o00000_ooool2o`0000Ko
oooo0_l0000Mooooo`;o00003?ooool2o`0004Gooooo000Looooo`03o`000?oooooooooo03cooooo
0_l0000<ooooo`Co00001oooool4o`0000gooooo1?l00004ooooo`Co00004?ooool5o`0000;ooooo
0_l00003ooooo`;o00001_ooool2o`0000Cooooo0_l00002ooooo`;o00001?ooool9o`0000?ooooo
0_l0000/ooooo`;o00000oooool2o`0000?ooooo0_l00008ooooo`;o00003_ooool2o`0004?ooooo
000Looooo`03o`000?oooooooooo03Oooooo1?l000000ooooooo0000o`00000;ooooo`Ko00001_oo
ool2o`00017ooooo1?l00002ooooo`Co00002?ooool2o`0000Kooooo1Ol00007ooooo`;o00000ooo
ool2o`000003ooooool0003o000000?ooooo0_l00008ooooo`Wo00001_ooool2o`0002[ooooo0_l0
0003ooooo`;o00000oooool2o`0000Sooooo0_l0000=ooooo`?o0000@oooool001cooooo00?o0000
ooooooooool0=oooool4o`0000kooooo1_l00003ooooo`;o00002_ooool4o`0000Sooooo0_l00002
ooooo`Co00002?ooool2o`0000Kooooo1?l00002ooooo`;o00002Oooool2o`0000Kooooo0_l00006
ooooo`_o00001Oooool4o`0000[ooooo0_l00007ooooo`;o00002_ooool2o`0001_ooooo0_l00005
ooooo`Co00001?ooool3o`0004Cooooo000Looooo`03o`000?oooooooooo03Oooooo1?l0000>oooo
o`;o00001oooool2o`0000Cooooo0_l00003ooooo`Oo00002Oooool2o`000003ooooool0003o0000
00Cooooo0_l00006ooooo`;o00000_ooool4o`0000;ooooo0_l0000Iooooo`_o00001Oooool6o`00
00Sooooo0_l00007ooooo`;o00002_ooool2o`0001_ooooo0_l00005ooooo`Co00000_ooool4o`00
04Gooooo000Looooo`03o`000?oooooooooo03Cooooo0_l000000ooooooo0000o`00000Oooooo`Co
000000?oooooo`000?l000001ol00004ooooo`;o000000?oooooo`000?l000001oooool2o`0000Go
oooo0ol00002ooooo`;o00000_ooool2o`0001_ooooo2_l0000:ooooo`;o00003oooool2o`0000Go
oooo0_l00004ooooo`Ko00001_ooool2o`0001Wooooo0_l000000ooooooo0000o`000003o`0001;o
oooo0_l0000aooooo`007?ooool00ol0003oooooooooo`0dooooo`;o000000Coooooo`000?l0003o
oooo0_l0000;ooooo`;o00003?ooool7o`000003ooooool0003o000000So00000_ooool3o`0000?o
oooo0_l0000<ooooo`;o00000oooool6o`00013ooooo0_l00002ooooo`;o00001?ooool;o`00013o
oooo0_l00006ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000002o`0000;o
oooo2_l00004ooooo`;o000000?oooooo`000?l000006?ooool3o`0001Gooooo0_l0000aooooo`00
7?ooool00ol0003oooooooooo`0gooooo`Go00002oooool2o`0000_ooooo1?l00002ooooo`?o0000
0_ooool8o`0000;ooooo0_l00004ooooo`Ko00000oooool4o`000003ooooool0003o000000;o0000
0oooool2o`0001;ooooo0_l00002ooooo`;o00000oooool:o`0000Cooooo0_l0000<ooooo`;o0000
1_ooool2o`0000?ooooo0_l000001Ooooooo0000o`000?l0003ooooo00Ko00000_ooool4o`000003
ooooool0003o000000Cooooo0_l00003ooooo`;o00004?ooool5o`0001Kooooo0_l0000aooooo`00
7?ooool00ol0003oooooooooo`0eooooo`Go00003_ooool2o`0000Sooooo1Ol00003ooooo`?o0000
00?oooooo`000?l000000_l00002ooooo`?o00000_ooool2o`0000Cooooo1_l00003ooooo`Co0000
00?oooooo`000?l000000_l00005ooooo`;o00006Oooool:o`0000Cooooo0_l00003ooooo`;o0000
6Oooool4o`0000Cooooo1?l00003ooooo`;o00001_ooool2o`000003ooooool0003o000000gooooo
2?l0000Eooooo`;o0000<_ooool001cooooo00?o0000ooooooooool0=Oooool2o`00013ooooo0ol0
0008ooooo`?o00000oooool8o`000004ooooool0003o0000ooooo`Oo00001?ooool2o`0000Cooooo
1Ol00004ooooo`;o00001_ooool2o`0001Kooooo3Ol00009ooooo`;o00004?ooool3o`0000Kooooo
1?l00004ooooo`So00001oooool2o`00013ooooo1Ol000000ooooooo0000o`000006ooooo`;o0000
3Oooool2o`0003;ooooo000Looooo`03o`000?oooooooooo043ooooo0_l00005ooooo`;o00003_oo
ool9o`000003ooooool0003o000000Oo00002oooool3o`0000Kooooo0_l0000Iooooo`;o00000ooo
ool<o`00013ooooo0_l00002ooooo`?o000000?oooooo`000?l000000_ooool3o`0000Gooooo1Ol0
0006ooooo`Ko00002_ooool2o`0000gooooo1?l00002ooooo`Co00000_ooool4o`00047ooooo000L
ooooo`03o`000?oooooooooo043ooooo0_l0000Eooooo`Ko00001?ooool4o`0000gooooo1Ol0000?
ooooo`;o00004Oooool2o`0000Gooooo2_l0000@ooooo`;o00000_ooool3o`000004ooooool0003o
0000o`0000Wooooo2Ol000000ooooooo0000o`00000;o`0000;ooooo1?l00002ooooo`;o00002?oo
ool2o`000003ooooool0003o000000;ooooo1?l00002ooooo`;o0000@oooool001cooooo00?o0000
ooooooooool0<_ooool2o`0000Kooooo0_l000000ooooooo0000o`000008ooooo`?o000000?ooooo
o`000?l000001oooool@o`0000kooooo0ol00008ooooo`;o000000?oooooo`000?l000001?ooool2
o`0000kooooo0_l00008ooooo`Wo00001oooool2o`0000Gooooo0_l0000:ooooo`;o00002?ooool5
o`000003ooooool0003o0000013o00000_ooool3o`0000?ooooo0ol00007ooooo`Go00000oooool3
o`00013ooooo0ol0000dooooo`007?ooool00ol0003oooooooooo`0booooo`;o00001Oooool3o`00
0003ooooool0003o000000Sooooo0ol000000ooooooo0000o`000007ooooo`?o00000_ooool9o`00
00;ooooo0_l0000<ooooo`;o00000_ooool2o`0000Gooooo1Ol0000Dooooo`;o00001_ooool:o`00
00Sooooo0_l00005ooooo`;o00001oooool2o`0000[ooooo4Ol000000ooooooo0000o`000005o`00
00;ooooo0ol000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00002ooooo`Ko00000oooool3
o`00013ooooo0ol0000dooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00001?ooool2o`00
00Wooooo0_l0000>ooooo`?o00000_ooool6o`0000Gooooo0_l0000<ooooo`;o00000_ooool2o`00
00?ooooo1_l0000:ooooo`;o00004Oooool:o`0000?ooooo0_l00008ooooo`;o00002Oooool2o`00
00?ooooo0_l00002ooooo`Oo000000?oooooo`000?l000002ol000000ooooooo0000o`000004o`00
00Kooooo0_l000000ooooooo0000o`000002ooooo`[o00000_ooool3o`0001;ooooo0_l0000doooo
o`007?ooool00ol0003oooooooooo`0booooo`?o00001?ooool2o`0000Sooooo0ol000001?oooooo
0000o`000?l00006ooooo`;o00000_ooool2o`0001oooooo0ol00003ooooo`?o000000?oooooo`00
0?l000002_ooool2o`00017ooooo2?l00005ooooo`;o00002?ooool2o`0000Wooooo0_l00003oooo
o`?o000000Goooooo`000?l0003o0000ooooo`0Eo`000003ooooool0003o000000;o00000_ooool2
o`0000Wooooo1?l00002ooooo`;o00000_ooool2o`0004Wooooo000Looooo`;o0000<oooool2o`00
00Gooooo1?l00006ooooo`;o00000_ooool3o`0000Kooooo0_l00002ooooo`;o00002Oooool2o`00
01Cooooo0_l00005ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o00000_ooool2o`00
017ooooo2?l0000>ooooo`?o00001_ooool2o`0000Cooooo2Ol000000ooooooo0000o`00000Co`00
00;ooooo1?l000001?oooooo0000o`000?ooool2o`0000Gooooo0_l0001Dooooo`007?ooool00ol0
003oooooooooo`0cooooo`;o00001_ooool3o`0000?ooooo0ol00003ooooo`Go00002?ooool2o`00
00Wooooo0_l00004ooooo`;o00006_ooool2o`0000Cooooo0_l00002ooooo`;o00000oooool2o`00
00cooooo2?l0000>ooooo`Oo00000_ooool2o`0000Cooooo2?l00002oooooaKo000000?oooooo`00
0?l000000_l00003ooooo`?o000000?oooooo`000?l000001?l000000ooooooo0000o`00001Aoooo
o`007?ooool00ol0003oooooooooo`0cooooo`;o00001oooool2o`0000?ooooo0ol00003ooooo`;o
000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l00005ooooo`?o00001_ooool3o`0002Co
oooo0_l00003ooooo`;o00002_ooool:o`0000gooooo0_l00002ooooo`Ko00001?ooool2o`000003
ooooool0003o000001ko000000?oooooo`000?l000000_l00002ooooo`So00000_ooool3o`0000Oo
oooo0ol00017ooooo`007?ooool00ol0003oooooooooo`0kooooo`;o00000_ooool2o`0000Kooooo
1?l00003ooooo`;o00001?ooool3o`0000?ooooo1?l00003ooooo`;o000000?oooooo`000?l00000
;Oooool2o`0000Oooooo2Ol0000>ooooo`;o00001_ooool2o`0000Cooooo0_l000000ooooooo0000
o`00000To`0000?ooooo0ol00002ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`000004
ooooool0003o0000o`0000cooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`0kooooo`;o
00000_ooool2o`0000Gooooo1Ol00002ooooo`Go00000oooool4o`000003ooooool0003o000000Go
oooo0_l0000Oooooo`;o00002oooool2o`0000;ooooo0_l00008ooooo`;o000000?oooooo`000?l0
00000ol0000:ooooo`;o00001?ooool2o`0000kooooo1Ol000000ooooooo0000o`00000Ho`000003
ooooool0003o000000;o00002?ooool2o`0000Oooooo0ol0000@ooooo`;o0000>Oooool001cooooo
00?o0000ooooooooool0A_ooool2o`0000Gooooo1Ol00003ooooo`Co00002Oooool2o`0001kooooo
0_l0000;ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000Gooooo2?l0000:ooooo`?o
00000oooool2o`0000oooooo0ol00002oooooa[o000000?oooooo`000?l000001Ol0000=ooooo`?o
00004Oooool2o`0003Wooooo000Looooo`03o`000?oooooooooo03[ooooo0_l0000:ooooo`;o0000
1Oooool2o`0000Kooooo0ol0000:ooooo`;o0000;Oooool3o`0000;ooooo0_l00007ooooo`Ko0000
2oooool2o`0000Gooooo0_l00005ooooo`;o00002OoooolHo`000003ooooool0003o000000Co0000
00?oooooo`000?l000000_l0000;ooooo`Co00000_ooool2o`0000cooooo0_l0000kooooo`007?oo
ool00ol0003oooooooooo`0jooooo`;o00000_ooool2o`0000gooooo0_l000000ooooooo0000o`00
000>ooooo`;o00006_ooool:o`000003ooooool0003o000000Sooooo0_l000000ooooooo0000o`00
0002o`000003ooooool0003o000000;ooooo1ol0000;ooooo`;o000000?oooooo`000?l000000ooo
ool2o`0000Gooooo0_l00009oooooaCo000000?oooooo`000?l000003Ol0000;ooooo`?o00000ooo
ool2o`0000cooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00001_ooool2
o`000003ooooool0003o000000;ooooo0_l000001?oooooo0000o`000?l0000:ooooo`Go00005_oo
ool2o`000003ooooool0003o000000go00002_ooool4o`000003ooooool0003o000000;ooooo1ol0
000;ooooo`;o000000?oooooo`000?l000001?ooool2o`0000?ooooo0_l00006ooooo`;o00001?oo
ool:o`000003ooooool0003o000000ko000000?oooooo`000?l000000_l00009ooooo`;o00000ooo
ool2o`0004kooooo000Looooo`03o`000?oooooooooo04;ooooo0_l00002ooooo`;o000000?ooooo
o`000?l000000_ooool2o`0000;ooooo0ol00009ooooo`Co00005oooool2o`000003ooooool0003o
000000oo00002_ooool2o`0000Gooooo1ol0000:ooooo`;o00001oooool3o`0000?ooooo0ol00005
ooooo`Go000000?oooooo`000?l000007_l00005ooooo`;o000000?oooooo`000?l000000_l00000
0ooooooo0000o`00000Aooooo`;o0000??ooool001cooooo00?o0000ooooooooool0=_ooool2o`00
00[ooooo0_l00002ooooo`;o00001Oooool2o`0000;ooooo0ol0000:ooooo`;o00005Oooool2o`00
0003ooooool0003o000000Oo000000?oooooo`000?l000002_l00008ooooo`;o00001Oooool2o`00
0004ooooool0003o0000o`0000_ooooo0_l00007ooooo`;o00001?ooool3o`0000Gooooo1Ol00000
0ooooooo0000o`00000Ko`0000Sooooo0_l000000ooooooo0000o`000005o`00013ooooo0ol0000l
ooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00003Oooool2o`0000Gooooo1?l000000ooo
oooo0000o`000008ooooo`Go00005Oooool8o`0000?ooooo4?l00004ooooo`Go00000oooool7o`00
01[ooooo0_l00009ooooo`;o000000?oooooo`000?l000007?l00009ooooo`;o00000oooool3o`00
013ooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00002_ooool2o`0000Go
oooo1?l00003ooooo`;o00001_ooool3o`0001Gooooo1ol00005oooooa7o00001?ooool5o`0000?o
oooo1ol0000:ooooo`Go00005?ooool4o`000003ooooool0003o000001co00002Oooool2o`0000Co
oooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`0hooooo`?o00002oooool2o`0000Gooooo
0_l000001?oooooo0000o`000?ooool2o`0001_ooooo0_l000001?oooooo0000o`000?ooool5o`00
00;ooooo5?l00004ooooo`;o00000_ooool9o`0000_ooooo1Ol00003ooooo`;o00002oooool2o`00
00;ooooo0_l00004oooooago00000_ooool2o`0000Gooooo0_l0000Cooooo`;o0000@?ooool00006
ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<
c006ooooo`03o`000?oooooooooo03Kooooo1?l000000ooooooo0000o`000009ooooo`;o00001Ooo
ool2o`000003ooooool0003o000000?o00001?ooool4o`0001?ooooo0_l00004ooooo`Go00000_oo
oolEo`0000Gooooo2ol0000Aooooo`Co00002oooool2o`0000?ooooo0_l00004oooooa[o00001?oo
ool2o`0000Gooooo0_l0000Booooo`?o0000@?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
1Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo03Ko
oooo0ol00002ooooo`;o00002Oooool2o`0000Gooooo0_l00002ooooo`;o000000Coooooo`000?l0
003o00000_ooool4o`0001Wooooo1Ol00002oooooaSo00000_ooool2o`0000;ooooo1ol0000<oooo
o`;o00000oooool4o`0000Cooooo0_l0000:ooooo`?o00000ooooolCo`000005ooooool0003o0000
o`000?ooool00_l00007ooooo`;o00001Oooool2o`0000kooooo0ol00011ooooo`0000?ooooooa0@
4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`0eooooo`Go00003?ooool2o`0000Cooooo0_l00002ooooo`_o00005Oooool2
o`0000Kooooo0_l00002oooooa[o00001oooool4o`0000cooooo0ol00004ooooo`;o000000Cooooo
o`000?l0003ooooo0ol00003ooooo`Co000000Coooooo`000?l0003ooooo0_l000001?oooooo0000
o`000?ooool?o`0000Cooooo0ol0000:ooooo`;o00001Oooool2o`0000gooooo0ol00012ooooo`00
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ
8B401_ooool3o`0003Gooooo0_l000000ooooooo0000o`00000;ooooo`;o00001Oooool=o`0001Ko
oooo0ol00006ooooo`;o000000?oooooo`000?l000007_l00004ooooo`;o00003?ooool2o`0000Go
oooo0_l000001?oooooo0000o`000?ooool2o`0000Cooooo1?l000001?oooooo0000o`000?l00002
ooooo`Go000000Coooooo`000?l0003o00001?ooool5o`0000?ooooo1Ol00008ooooo`;o00005?oo
ool5o`0004;ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000
oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo03kooooo0_l00005ooooo`;o00001_oo
ool:o`0001Kooooo1?l00007ooooo`;o000000?oooooo`000?l000009?l0000=ooooo`;o00001ooo
ool2o`0000gooooo0_l00002ooooo`Go00000oooool@o`0000[ooooo0_l0000Dooooo`;o0000AOoo
ool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08
ooooo`03o`000?oooooooooo03kooooo0_l00006ooooo`;o00000oooool2o`0000;ooooo1ol0000G
ooooo`;o00002OoooolMo`000003ooooool0003o000000Wo00003Oooool2o`0000Kooooo0ol0000?
ooooo`Ko000000?oooooo`000?l000003_l0000;ooooo`;o00001Oooool2o`0000oooooo0_l00015
ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o
0000ooooooooool0=Oooool2o`000003ooooool0003o000000Cooooo0_l00006ooooo`;o00000ooo
ool2o`0000;ooooo0ol0000Woooooaco000000?oooooo`000?l000002Ol0000<ooooo`;o00000_oo
ool4o`000003ooooool0003o0000013ooooo1_l000000ooooooo0000o`000002o`0000Oooooo0_l0
000>ooooo`?o00001?ooool2o`0000cooooo0_l00018ooooo`0000Koooooonk^k_lb<S;o0000oc8b
<_o^k^h<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0=Oooool2o`000003
ooooool0003o000000Oooooo0_l00003ooooo`;o00000oooool3o`0000;ooooo0_l0000Uoooooaco
00000oooool;o`0000cooooo0_l00002ooooo`Co00005?ooool3o`0000cooooo1?l00009ooooo`Co
00000_ooool2o`00017ooooo0ol00018ooooo`007?ooool00ol0003oooooooooo`0eooooo`;o0000
2Oooool3o`0000?ooooo0_l00004ooooo`;o0000:?oooolJo`0000;ooooo1Ol000001?oooooo0000
o`000?ooool5o`0000oooooo0_l00003ooooo`;o00006?ooool2o`0000Sooooo0_l0000;ooooo`Go
00004oooool3o`0004Wooooo000Looooo`03o`000?oooooooooo03Sooooo0_l00006ooooo`;o0000
1?ooool2o`0000?ooooo0_l00006ooooo`;o00006?ooool2o`0000Cooooo0_l000000ooooooo0000
o`00000Oo`000003ooooool0003o000000Go00004?ooool3o`0000;ooooo0_l0000Hooooo`;o0000
1?ooool2o`0000Wooooo0_l00007ooooo`;o00004Oooool4o`0004[ooooo000Looooo`03o`000?oo
oooooooo03Sooooo0_l0000Aooooo`;o00001Oooool3o`0001Sooooo0_l00004ooooo`;o000000Co
ooooo`000?l0003ooooo7?l000000ooooooo0000o`000007o`00013ooooo0ol0000Oooooo`;o0000
00?oooooo`000?l000001oooool4o`0000Oooooo0_l0000?ooooo`Co0000C?ooool001cooooo00?o
0000ooooooooool0@_ooool2o`000003ooooool0003o000000Cooooo1Ol00002ooooo`;o00005ooo
ool2o`0000Gooooo7ol000001?oooooo0000o`000?ooool9o`0001;ooooo0ol00002ooooo`;o0000
6_ooool4o`0000Sooooo0_l00009ooooo`;o00003Oooool5o`0004gooooo000Looooo`03o`000?oo
oooooooo04;ooooo0_l000001?oooooo0000o`000?l00005ooooo`Ko00006?ooool3o`0000?ooooo
9_l000000ooooooo0000o`000004o`0000[ooooo0ol00005ooooo`?o00000_ooool2o`0001cooooo
0_l0000Cooooo`;o00003?ooool5o`0004kooooo000Looooo`03o`000?oooooooooo04Kooooo0_l0
0007ooooo`Co00006Oooool2o`0000?ooooo0_l000000ooooooo0000o`00000Qo`000003ooooool0
003o000000;o00003?ooool3o`0000;ooooo0_l0000^ooooo`;o00005?ooool7o`0004oooooo000L
ooooo`03o`000?oooooooooo03[ooooo0_l0000:ooooo`;o00002?ooool2o`0002Cooooo9_l0000A
ooooo`;o0000;_ooool2o`0001;ooooo1_l0001Booooo`007?ooool00ol0003oooooooooo`0joooo
o`;o00002_ooool2o`0000Sooooo0_l0000Jooooo`;o00001_oooolXo`0000cooooo0_l00003oooo
o`?o0000?_ooool2o`000003ooooool0003o000000;o0000E?ooool001cooooo00?o0000oooooooo
ool0>oooool2o`0000?ooooo0_l00004ooooo`;o00001?ooool2o`0001kooooo0_l00006ooooobOo
00003Oooool2o`0000;ooooo1?l0000nooooo`;o0000FOooool001cooooo00?o0000ooooooooool0
>oooool2o`0000?ooooo0_l00004ooooo`;o00001?ooool2o`0002Kooooo2?l000000ooooooo0000
o`00000Lo`00017ooooo0ol00002ooooo`;o00004_ooool5o`0002?ooooo0_l0001Jooooo`007?oo
ool00ol0003oooooooooo`16ooooo`;o00002?ooool2o`0002;ooooo0ol000000ooooooo0000o`00
000Oo`0001?ooooo1ol0000@ooooo`_o00000oooool2o`0000;ooooo0_l0000Aooooo`;o00000ooo
ool2o`0005[ooooo000Looooo`;o0000BOooool2o`0000Kooooo0_l0000Rooooo`;o00001Oooool8
o`000003ooooool0003o000001;o00004Oooool2o`000003ooooool0003o000000?o00004Oooool4
o`000003ooooool0003o000000Go00000oooool6o`0000Cooooo1Ol00005ooooo`Go0000Goooool0
01cooooo00?o0000ooooooooool0@oooool3o`0000;ooooo0_l0000Sooooo`;o00001Oooool2o`00
00;ooooo2ol000000ooooooo0000o`00000:o`000003ooooool0003o000000Go00003oooool4o`00
00?ooooo0_l0000Booooo`;o00001Oooool2o`0000Sooooo0_l000000ooooooo0000o`000003oooo
o`oo0000Goooool001cooooo00?o0000ooooooooool0@oooool3o`0002Oooooo0_l00003ooooo`;o
00001?oooolNo`00017ooooo0_l0000Iooooo`;o000000?oooooo`000?l000003?ooool2o`000003
ooooool0003o000000?ooooo3?l0001Rooooo`007?ooool00ol0003oooooooooo`1]ooooo`;o0000
0oooool2o`0000Cooooo1?l000001?oooooo0000o`000?ooool;o`000003ooooool0003o000000Oo
00005_ooool2o`0001Cooooo0ol000000ooooooo0000o`00000Gooooo`?o000000?oooooo`000?l0
00004_ooool2o`00057ooooo000Looooo`03o`000?oooooooooo03gooooo0ol0000[ooooo`;o0000
2Oooool7o`0000;ooooo3?l00002ooooo`Ko00006?ooool2o`0001Cooooo1?l0000Iooooo`;o0000
00?oooooo`000?l000004oooool2o`00057ooooo000Looooo`03o`000?oooooooooo03gooooo0ol0
0009ooooo`;o00008?ooool2o`0000Oooooo1_l000000ooooooo0000o`00000<o`000003ooooool0
003o000000Go0000<_ooool2o`0000gooooo0ol0000<ooooo`;o00001_ooool2o`0002Gooooo0_l0
000gooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00008_ooool2o`0000Gooooo0_l00002
ooooo`ko000000?oooooo`000?l000001ol0000Aooooo`;o00008?ooool2o`0000[ooooo0_l00000
1?oooooo0000o`000?l0000<ooooo`;o00001_ooool2o`0000;ooooo0_l000001?oooooo0000o`00
0?ooool2o`0001_ooooo0_l0000gooooo`007?ooool00ol0003oooooooooo`0nooooo`;o0000;Ooo
ool2o`0000Kooooo0ol000001?oooooo0000o`000?ooool;o`000003ooooool0003o000000;o0000
5Oooool2o`0000;ooooo0_l0000Nooooo`;o00002?ooool2o`0000Oooooo0_l00007ooooo`;o0000
1?ooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l0001@ooooo`00
7?ooool00ol0003oooooooooo`0nooooo`;o00001?ooool2o`0002oooooo0ol000000ooooooo0000
o`000002ooooo`[o000000?oooooo`000?l000000_l0000Iooooo`?o00007Oooool2o`00017ooooo
0_l0000=ooooo`;o00003_ooool2o`00053ooooo000Looooo`03o`000?oooooooooo03oooooo0_l0
0003ooooo`;o000000?oooooo`000?l000000oooool2o`0001oooooo0_l00007ooooo`Go00000_oo
ool7o`0000;ooooo1_l0000Jooooo`Oo0000:oooool2o`0000gooooo0_l0001Pooooo`007?ooool0
0ol0003oooooooooo`0oooooo`Co00001?ooool2o`0000?ooooo0_l0000Oooooo`;o00002?ooool3
o`0000;ooooo3_l0000Nooooo`Go0000:oooool2o`0000Wooooo0_l00002ooooo`;o00008_ooool2
o`0003cooooo000Looooo`03o`000?oooooooooo047ooooo0_l00004ooooo`;o00000oooool2o`00
02;ooooo0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o000000;o00001?ooool6o`00
017ooooo0_l0000=ooooo`;o0000:Oooool2o`0000cooooo1?l00008ooooo`;o00006Oooool3o`00
03cooooo000Looooo`03o`000?oooooooooo04oooooo0_l0000Oooooo`;o00000oooool2o`0000;o
oooo1?l00008ooooo`Co00004_ooool2o`0002kooooo0_l00006ooooo`Co00001_ooool2o`0000?o
oooo0_l000000ooooooo0000o`000008ooooo`;o00006?ooool3o`0003gooooo000Looooo`03o`00
0?oooooooooo04Oooooo0_l00006ooooo`;o0000:?ooool4o`0000;ooooo0_l00002ooooo`;o0000
5_ooool2o`0002gooooo0ol00006ooooo`?o00001oooool2o`0000?ooooo0_l00009ooooo`;o0000
6_ooool2o`0003kooooo000Looooo`03o`000?oooooooooo04Oooooo0_l00003ooooo`;o00000_oo
ool2o`0002Oooooo0_l00003ooooo`Oo00000_ooool3o`00013ooooo0ol0000[ooooo`Co00002?oo
ool2o`0000;ooooo0_l00003ooooo`;o00002?ooool3o`0000?ooooo0_l0001Jooooo`007?ooool0
0ol0003oooooooooo`1;ooooo`?o00000_ooool3o`0002Wooooo2Ol000000ooooooo0000o`000002
o`00013ooooo0_l0000/ooooo`?o00002Oooool3o`000003ooooool0003o000000?ooooo0_l00008
ooooo`?o00000_ooool2o`0000;ooooo0_l0000Booooo`;o0000@oooool001cooooo0_l00013oooo
o`?o00001_ooool2o`0000Cooooo0_l0000Vooooo`;o000000?oooooo`000?l000001ol000000ooo
oooo0000o`000003o`0000gooooo0ol0000^ooooo`;o00001Oooool2o`0000;ooooo0ol00006oooo
o`;o00003Oooool2o`0000;ooooo0_l0000Aooooo`?o0000@oooool001cooooo00?o0000oooooooo
ool0@_ooool3o`0000kooooo1?l0000Rooooo`;o00000_ooool2o`0000?ooooo0ol000000ooooooo
0000o`000003o`0000gooooo0ol00009ooooo`;o00008?ooool2o`0000Kooooo1?l0000<ooooo`;o
00001oooool2o`0001[ooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`1Cooooo`Co0000
7?ooool2o`0000Oooooo0ol00003ooooo`Ko00005Oooool2o`0000Gooooo0ol0000Oooooo`;o0000
1?ooool6o`0000cooooo0_l000000ooooooo0000o`000002ooooo`Co00006_ooool2o`0004Cooooo
000Looooo`03o`000?oooooooooo05Kooooo0_l0000Kooooo`;o00001oooool2o`0000Cooooo1?l0
000Gooooo`;o00001_ooool2o`0002Gooooo0_l00002ooooo`;o00003_ooool3o`000003ooooool0
003o000000;o0000HOooool001cooooo00?o0000ooooooooool0COooool2o`0000Oooooo0_l0000Z
ooooo`Co00007_ooool2o`0002cooooo0_l00002ooooo`Ko00001?ooool6o`0006?ooooo000Loooo
o`03o`000?oooooooooo04gooooo0_l00007ooooo`?o00004oooool2o`00013ooooo0ol000000ooo
oooo0000o`000002o`000003ooooool0003o0000013ooooo0_l00009ooooo`;o00009oooool4o`00
0003ooooool0003o000000;ooooo1_l00004ooooo`;o000000?oooooo`000?l00000I?ooool001co
oooo00?o0000ooooooooool0E_ooool3o`0001?ooooo0ol00004ooooo`;o00002Oooool6o`0000?o
oooo1?l00003ooooo`;o00001_ooool2o`000003ooooool0003o000000Kooooo0_l0000Zooooo`Co
000000?oooooo`000?l000000_ooool4o`0000Oooooo0ol0001Uooooo`007?ooool00ol0003ooooo
ooooo`1[ooooo`Co00001?ooool2o`0000[ooooo1_l00003ooooo`?o00000oooool4o`0000Cooooo
0_l00007ooooo`Co0000:Oooool3o`0000?ooooo1?l00002ooooo`?o00001_ooool3o`0006Gooooo
000Looooo`03o`000?oooooooooo05[ooooo0ol0000>ooooo`;o00005?ooool4o`0000?ooooo0_l0
0004ooooo`Co00003Oooool4o`000003ooooool0003o000000;o00009?ooool2o`0000Cooooo1?l0
0003ooooo`;o00000oooool2o`000003ooooool0003o000006Kooooo000Looooo`03o`000?oooooo
oooo05;ooooo0_l00006ooooo`Co0000;_ooool4o`0001Cooooo1?l00003ooooo`?o00009?ooool6
o`0000;ooooo1_l0001Yooooo`007?ooool00ol0003oooooooooo`1Booooo`;o00002?ooool2o`00
02kooooo1?l0000@ooooo`?o00002?ooool4o`0002;ooooo3Ol0001[ooooo`007?ooool00ol0003o
ooooooooo`1Booooo`?o000000?oooooo`000?l000006Oooool2o`0002gooooo0ol0000:ooooo`;o
00008_ooool9o`0001gooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o0000
00?oooooo`000?l000000_l0000Gooooo`;o00002Oooool2o`00027ooooo1?l0000Rooooo`;o0000
1oooool2o`0000;ooooo0_l0000Qooooo`Co0000D?ooool001cooooo00?o0000ooooooooool0COoo
ool2o`0000Wooooo0_l0000Nooooo`;o00000_ooool2o`0000kooooo0_l0000Aooooo`Co00003ooo
ool2o`00017ooooo0_l00007ooooo`;o00009?ooool4o`00057ooooo000Looooo`03o`000?oooooo
oooo04gooooo0_l0000Yooooo`;o00004_ooool2o`0001[ooooo0_l00008ooooo`;o00004Oooool3
o`0000Kooooo0_l0000Tooooo`;o0000Doooool001cooooo00?o0000ooooooooool0POooool2o`00
02Gooooo0_l00009ooooo`;o00004?ooool3o`0000Kooooo0_l0000Rooooo`;o0000EOooool001co
oooo0_l0001@ooooo`;o00008_ooool3o`0000_ooooo0_l0000`ooooo`;o00005Oooool2o`0002Co
oooo1?l0001Eooooo`007?ooool00ol0003oooooooooo`1?ooooo`;o00001_ooool3o`0001Wooooo
0ol0000`ooooo`;o00001_ooool4o`000003ooooool0003o000001Gooooo0_l00002ooooo`;o0000
8?ooool2o`0005Oooooo000Looooo`03o`000?oooooooooo05Oooooo0ol00002ooooo`;o0000:?oo
ool2o`0001gooooo0ol00006ooooo`Co000000Coooooo`000?l0003o00005?ooool2o`0000;ooooo
0_l0001iooooo`007?ooool00ol0003oooooooooo`1Looooo`?o000000?oooooo`000?l000007Ooo
ool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o00006Oooool2o`000003ooooool0
003o000000Co00001_ooool2o`0001Cooooo0_l0001mooooo`007?ooool00ol0003oooooooooo`1M
ooooo`;o000000?oooooo`000?l000006?ooool2o`0000?ooooo0_l000000ooooooo0000o`000006
ooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`000002o`0000_ooooo2_l0000J
ooooo`;o00007_ooool2o`0005gooooo000Looooo`03o`000?oooooooooo05cooooo0_l00002oooo
o`?o00005oooool2o`0001;ooooo0_l00004ooooo`;o000000?oooooo`000?l000001Ol000000ooo
oooo0000o`000004o`000003ooooool0003o000000Co00000_ooool2o`0001;ooooo0_l0000Voooo
o`;o0000GOooool001cooooo00?o0000ooooooooool0G?ooool2o`0000;ooooo0ol0000Hooooo`;o
00005?ooool2o`0000Gooooo3_l00003ooooo`?o00000_ooool4o`00013ooooo0ol00003ooooo`;o
00008?ooool2o`0005gooooo000Looooo`03o`000?oooooooooo06Sooooo0_l000000ooooooo0000
o`00000>ooooo`;o00002oooool2o`000003ooooool0003o000000Cooooo0_l00009ooooo`[o0000
0oooool3o`0000;ooooo1?l0000Aooooo`;o00000oooool2o`0000Cooooo0_l0000Fooooo`;o0000
HOooool001cooooo00?o0000ooooooooool0J?ooool2o`000003ooooool0003o000000?ooooo0_l0
0009ooooo`;o00002_ooool3o`000003ooooool0003o000000Wooooo1Ol000000ooooooo0000o`00
0002ooooo`;o000000?oooooo`000?l000001Oooool2o`0000;ooooo0_l0000Gooooo`?o00000ooo
ool3o`0001?ooooo0_l000000ooooooo0000o`00001Qooooo`007?ooool00ol0003oooooooooo`1W
ooooo`?o00000oooool2o`000003ooooool0003o000000;o00001oooool2o`0000[ooooo0_l00003
ooooo`;o00002?ooool5o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`00000R
ooooo`?o00000oooool2o`0001Cooooo0_l0001Tooooo`007?ooool00ol0003oooooooooo`1Woooo
o`;o00001?ooool4o`000003ooooool0003o000001Sooooo0_l0000Booooo`[o00007?ooool4o`00
01Wooooo0_l0001Tooooo`007?ooool00ol0003oooooooooo`1Zooooo`?o00000_ooool5o`0001So
oooo0_l00004ooooo`;o00003?ooool4o`000003ooooool0003o000000?o00003_ooool2o`0000co
oooo0ol0000Gooooo`;o0000Ioooool001cooooo00?o0000ooooooooool0J_ooool3o`0000Cooooo
0_l0000Iooooo`;o00001?ooool4o`0002;ooooo0_l0000Tooooo`Co0000Ioooool001cooooo00?o
0000ooooooooool0K_ooool2o`0000Sooooo1?l0000Hooooo`;o0000A_ooool4o`0006Wooooo0000
1_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<
c<`01_ooool00ol0003oooooooooo`1Xooooo`?o00000oooool2o`0000Cooooo0_l00002ooooo`Co
00002oooool2o`0000Sooooo1?l00002ooooo`?o0000:_ooool2o`0001Kooooo0_l0001[ooooo`00
00KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q00Kooooo00?o0000ooooooooool0J?ooool3o`0000Wooooo0_l000000ooooooo0000o`00000>
ooooo`;o00002?ooool4o`0000;ooooo0ol00003ooooo`;o00001?ooool2o`0000cooooo0_l00006
ooooo`;o00002Oooool2o`0001Gooooo0ol0001[ooooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`1g
ooooo`?o00003Oooool2o`000003ooooool0003o0000017ooooo1?l00002ooooo`;o00003?ooool2
o`000003ooooool0003o000000?ooooo0_l00006ooooo`;o00000_ooool2o`0001Cooooo0_l0001/
ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9Sooooo
oiRHV?lb<S801_ooool3o`0006kooooo0_l00004ooooo`Ko00001Oooool2o`0000?ooooo0ol00003
ooooo`;o00004oooool3o`000003ooooool0003o000000Cooooo0_l00003ooooo`Co00000_ooool2
o`0000_ooooo0ol000000ooooooo0000o`000022ooooo`0000?oooooo`000?ooool00_ooool00ol0
003oooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`1^
ooooo`;o00000_ooool6o`0000Oooooo1?l000001Ooooooo0000o`000?l0003ooooo00;o000000?o
ooooo`000?l000003oooool6o`000003ooooool0003o000000Cooooo0_l00003ooooo`Co00002ooo
ool4o`000003ooooool0003o000001Cooooo0_l0001_ooooo`0000?ooooooa0@4?ooool00_ooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`1booooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`Go00003oooool4o`0001Wooooo0_l0
0002ooooo`Co00005oooool2o`0006oooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo
00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo07;ooooo0_l00005ooooo`;o
00000oooool2o`0000Kooooo0_l00002ooooo`;o00006?ooool4o`0000Cooooo0_l000001?oooooo
0000o`000?ooool4o`0000;ooooo0ol0002>ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;
ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`1nooooo`;o00001_oo
ool2o`0000Cooooo0_l000000ooooooo0000o`00000Cooooo`Co00001?ooool2o`000003ooooool0
003o000000[o0000S_ooool001cooooo00?o0000ooooooooool0Noooool2o`000003ooooool0003o
000000cooooo0_l000000ooooooo0000o`00000Oooooo`;o00001?ooool2o`0001[ooooo0_l0001e
ooooo`007?ooool00ol0003oooooooooo`1kooooo`?o00002_ooool2o`0000Cooooo0_l00005oooo
o`;o0000>oooool2o`0007Gooooo000Looooo`03o`000?oooooooooo07cooooo0_l0000:ooooo`;o
00001?ooool2o`0000Gooooo0_l00003ooooo`;o0000<Oooool3o`0007Wooooo000Looooo`03o`00
0?oooooooooo07cooooo0_l00008ooooo`;o00002Oooool2o`0000Cooooo0_l000000ooooooo0000
o`000003ooooo`;o0000;?ooool3o`0007Wooooo000Looooo`03o`000?oooooooooo08;ooooo2?l0
0007ooooo`;o00001?ooool2o`0000Kooooo0_l00004ooooo`;o000000?oooooo`000?l000002?oo
ool4o`0001Cooooo1?l0001kooooo`007?ooool00ol0003oooooooooo`22ooooo`So00001?ooool2
o`0000Cooooo1?l0000=ooooo`;o000000?oooooo`000?l000002?ooool4o`0000;ooooo0_l0000<
ooooo`;o00000_ooool4o`0007_ooooo000Looooo`03o`000?oooooooooo08Gooooo0_l00006oooo
o`?o00000oooool6o`0000Wooooo0_l0000Dooooo`Co00000_ooool2o`0000;ooooo1_l00021oooo
o`007?ooool00ol0003oooooooooo`2=ooooo`Co00000_ooool6o`0000Wooooo0_l0000Dooooo`Go
000000?oooooo`000?l000000_ooool4o`0008?ooooo000Looooo`03o`000?oooooooooo08oooooo
0_l00005ooooo`;o00008?ooool5o`0000Cooooo0_l00026ooooo`007?ooool00ol0003ooooooooo
o`2Fooooo`;o00002Oooool2o`000003ooooool0003o000001?ooooo0ol00004ooooo`Go0000Q?oo
ool001cooooo00?o0000ooooooooool0WOooool2o`0000;ooooo0_l000000ooooooo0000o`00000<
ooooo`?o00002oooool2o`000003ooooool0003o000008Cooooo000Looooo`;o0000W_ooool2o`00
00Gooooo0_l00007ooooo`;o00000oooool3o`0009Cooooo000Looooo`03o`000?oooooooooo0:go
oooo0_l0002Jooooo`007?ooool00ol0003oooooooooo`2Vooooo`;o0000XOooool001cooooo00?o
0000ooooooooool0Y_ooool2o`000:7ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o
0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?o
oooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool3o`000?ooooooB_oo
ool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooo
oe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0
oooooomBooooo`004_ooool00omEEEGoIVIVo`00003ooooooeCooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo002Uooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@oooooooo
ool05Oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0T?ooool00:Kooooo00Go0000ooooooooooooooooo`00
0009ooooo`Ko00002Oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40T?ooool00:Kooooo00Go0000oooooooo
ooooooooo`00000Looooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool0S_ooool00:Kooooo00Go0000ooooooooooooooooo`00
0009ooooo`Ko00003?ooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003oV9RHoooooonHV9So8B4Q093ooooo002Vooooo`05o`000?n7QhOoooooojVYZOl0
00006_ooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003oEEEEo`000?l@413oc<c<093ooooo002Uooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHoooo
ooooool06Oooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool0
0omEEEGoQhN7ooooo`2Booooo`00`oooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`03ooooo`03omgMgOl@413oV9RH09;ooooo0033ooooo`05ojVYZOl@413o
0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00Coc<c<odA4A?l0003o
410@T?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(312) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.62511 .58656 Mdot
.65783 .58247 Mdot
.48258 .3286 Mdot
.38713 .57962 Mdot
.39055 .3073 Mdot
.52441 .29548 Mdot
.66631 .40643 Mdot
.66713 .41329 Mdot
.50373 .3239 Mdot
.43271 .78315 Mdot
.6452 .37116 Mdot
.43859 .56651 Mdot
.6518 .40087 Mdot
.40525 .5994 Mdot
.33486 .50242 Mdot
.36188 .62643 Mdot
.64335 .61324 Mdot
.38437 .35992 Mdot
.3651 .62778 Mdot
.54225 .30182 Mdot
.44137 .69924 Mdot
.39377 .59547 Mdot
.67015 .56202 Mdot
.40176 .60079 Mdot
.44905 .6312 Mdot
.64628 .58904 Mdot
.62652 .58272 Mdot
.4491 .59993 Mdot
.36908 .6054 Mdot
.63747 .39275 Mdot
.46288 .45439 Mdot
.21095 .61266 Mdot
.4045 .6603 Mdot
.59598 .70624 Mdot
.63475 .40856 Mdot
.59663 .36545 Mdot
.49769 .27348 Mdot
.65204 .43114 Mdot
.63855 .37112 Mdot
.65144 .36279 Mdot
.65293 .36403 Mdot
.64355 .58958 Mdot
.67426 .42636 Mdot
.59154 .26949 Mdot
.39994 .61173 Mdot
.65866 .67521 Mdot
.56016 .26118 Mdot
.42483 .63282 Mdot
.68988 .58846 Mdot
.52832 .32329 Mdot
.27586 .41779 Mdot
.67468 .41434 Mdot
.50635 .54415 Mdot
.87406 .4505 Mdot
.6573 .41008 Mdot
.40132 .64408 Mdot
.49353 .30938 Mdot
.43208 .59625 Mdot
.44032 .57508 Mdot
.57784 .67875 Mdot
.42901 .58461 Mdot
.37088 .31828 Mdot
.66617 .54932 Mdot
.55276 .30949 Mdot
.49917 .32536 Mdot
.66481 .42845 Mdot
.69541 .61788 Mdot
.64146 .39465 Mdot
.37319 .59701 Mdot
.53368 .31551 Mdot
.3891 .63257 Mdot
.64555 .37179 Mdot
.63614 .57392 Mdot
.38602 .60028 Mdot
.78311 .5602 Mdot
.61502 .44664 Mdot
.43649 .30915 Mdot
.54666 .60356 Mdot
.4253 .37231 Mdot
.38216 .47523 Mdot
.38779 .599 Mdot
.70322 .25347 Mdot
.3147 .48285 Mdot
.68446 .58649 Mdot
.50238 .53701 Mdot
.75225 .42651 Mdot
.43575 .63673 Mdot
.46984 .4531 Mdot
.39533 .54716 Mdot
.32537 .30284 Mdot
.50458 .31333 Mdot
.68568 .60668 Mdot
.39179 .60981 Mdot
.37753 .59999 Mdot
.52539 .80802 Mdot
.36643 .60461 Mdot
.44952 .58535 Mdot
.54991 .47724 Mdot
.67664 .38397 Mdot
.46273 .63833 Mdot
.48003 .38175 Mdot
.53155 .51548 Mdot
.40706 .64292 Mdot
.50479 .30165 Mdot
.66994 .55121 Mdot
.40265 .65592 Mdot
.64787 .38762 Mdot
.39187 .60439 Mdot
.65574 .44308 Mdot
.68923 .58337 Mdot
.45157 .58408 Mdot
.36737 .33512 Mdot
.53657 .58247 Mdot
.64719 .56581 Mdot
.64458 .74757 Mdot
.41061 .57811 Mdot
.43344 .6073 Mdot
.6552 .58072 Mdot
.5352 .28831 Mdot
.65413 .23304 Mdot
.63549 .57754 Mdot
.65531 .36203 Mdot
.66156 .61983 Mdot
.51239 .55347 Mdot
.53592 .28682 Mdot
.54783 .51911 Mdot
.54761 .52353 Mdot
.23 .51594 Mdot
.39323 .57472 Mdot
.38105 .70562 Mdot
.51287 .29748 Mdot
.64627 .57302 Mdot
.64406 .40458 Mdot
.37098 .57732 Mdot
.66016 .60269 Mdot
.66907 .40824 Mdot
.34707 .31805 Mdot
.39427 .35872 Mdot
.66987 .56697 Mdot
.6648 .74623 Mdot
.63496 .35453 Mdot
.68412 .39481 Mdot
.27461 .42137 Mdot
.68401 .58572 Mdot
.38539 .32907 Mdot
.65967 .38758 Mdot
.23134 .33237 Mdot
.45487 .6258 Mdot
.25689 .45554 Mdot
.7173 .27374 Mdot
.27655 .41712 Mdot
.40918 .71837 Mdot
.37669 .33835 Mdot
.6696 .40817 Mdot
.40748 .63383 Mdot
.6745 .59194 Mdot
.65621 .60045 Mdot
.38266 .62536 Mdot
.43213 .65502 Mdot
.41656 .60076 Mdot
.41103 .659 Mdot
.53937 .46642 Mdot
.39353 .6091 Mdot
.76248 .65474 Mdot
.67686 .59947 Mdot
.42861 .6535 Mdot
.50154 .27593 Mdot
.37317 .68403 Mdot
.67195 .42644 Mdot
.41633 .56619 Mdot
.44427 .64414 Mdot
.41678 .55284 Mdot
.65816 .36105 Mdot
.79283 .57357 Mdot
.40939 .36878 Mdot
.63961 .36251 Mdot
.70263 .33654 Mdot
.50461 .28702 Mdot
.44249 .602 Mdot
.38474 .34612 Mdot
.47076 .63118 Mdot
.38423 .61246 Mdot
.27985 .40987 Mdot
.44284 .58091 Mdot
.3971 .71901 Mdot
.34054 .61336 Mdot
.74523 .41492 Mdot
.75538 .6198 Mdot
.38383 .58478 Mdot
.44805 .76153 Mdot
.26555 .44882 Mdot
.58225 .4016 Mdot
.64276 .40559 Mdot
.53148 .2948 Mdot
.53437 .29137 Mdot
.62101 .39928 Mdot
.62747 .72834 Mdot
.40904 .7755 Mdot
.38095 .5718 Mdot
.52623 .52065 Mdot
.66203 .62425 Mdot
.37617 .33646 Mdot
.66299 .56763 Mdot
.68358 .23184 Mdot
.40797 .45986 Mdot
.43559 .47913 Mdot
.46909 .34442 Mdot
.52675 .32647 Mdot
.53238 .51916 Mdot
.3901 .33152 Mdot
.41867 .60932 Mdot
.6876 .58224 Mdot
.26839 .4413 Mdot
.48353 .60356 Mdot
.38858 .82124 Mdot
.62905 .58699 Mdot
.25742 .56355 Mdot
.65689 .40708 Mdot
.47583 .30083 Mdot
.43629 .6373 Mdot
.40988 .58658 Mdot
.69238 .58174 Mdot
.41919 .62864 Mdot
.38899 .50192 Mdot
.45213 .62613 Mdot
.5514 .29755 Mdot
.39877 .36985 Mdot
.63069 .36468 Mdot
.46051 .34164 Mdot
.64325 .56655 Mdot
.81898 .6114 Mdot
.49215 .29312 Mdot
.34931 .67293 Mdot
.64765 .37328 Mdot
.34876 .31835 Mdot
.49474 .30057 Mdot
.4042 .32165 Mdot
.42157 .56471 Mdot
.48792 .28008 Mdot
.36606 .32287 Mdot
.45655 .4819 Mdot
.41222 .65763 Mdot
.2094 .49676 Mdot
.66986 .39665 Mdot
.67313 .61608 Mdot
.39075 .62259 Mdot
.50624 .54144 Mdot
.45376 .64407 Mdot
.26743 .53045 Mdot
.52734 .53733 Mdot
.53654 .51163 Mdot
.35465 .46316 Mdot
.35515 .34477 Mdot
.80064 .43297 Mdot
.48313 .45225 Mdot
.64119 .61212 Mdot
.37961 .60051 Mdot
.7334 .35873 Mdot
.67201 .40424 Mdot
.42436 .60401 Mdot
.75526 .38793 Mdot
.66171 .39024 Mdot
.43161 .60564 Mdot
.63677 .3803 Mdot
.6695 .59979 Mdot
.3641 .4994 Mdot
.62658 .59853 Mdot
.39789 .61734 Mdot
.6385 .37781 Mdot
.5301 .28916 Mdot
.64731 .59043 Mdot
.39147 .60071 Mdot
.412 .57031 Mdot
.51887 .52818 Mdot
.45353 .62647 Mdot
.64696 .4794 Mdot
.42755 .63374 Mdot
.4649 .32147 Mdot
.36744 .6043 Mdot
.41113 .41156 Mdot
.32221 .28748 Mdot
.67984 .57346 Mdot
.52683 .5373 Mdot
.49325 .3051 Mdot
.41227 .50056 Mdot
.24877 .57199 Mdot
.39892 .60771 Mdot
.52889 .5337 Mdot
.24345 .53402 Mdot
.67811 .4189 Mdot
.39351 .54699 Mdot
.40798 .29503 Mdot
.50608 .31184 Mdot
.53009 .51859 Mdot
.47787 .61211 Mdot
.65478 .62912 Mdot
.36496 .62519 Mdot
.48827 .2824 Mdot
.63661 .60662 Mdot
.36919 .62263 Mdot
.59309 .41931 Mdot
.50609 .53699 Mdot
.68195 .39203 Mdot
.53228 .48363 Mdot
.43515 .61453 Mdot
.53061 .31778 Mdot
.64337 .59449 Mdot
.66042 .41328 Mdot
.64459 .56733 Mdot
.28936 .41885 Mdot
.25466 .54336 Mdot
.69988 .64545 Mdot
.34164 .32378 Mdot
.20166 .36837 Mdot
.64271 .35928 Mdot
.46261 .64238 Mdot
.56135 .30648 Mdot
.72552 .56975 Mdot
.50442 .30454 Mdot
.68002 .73616 Mdot
.49986 .31244 Mdot
.39078 .64041 Mdot
.52738 .30917 Mdot
.52278 .8173 Mdot
.43713 .57974 Mdot
.49385 .32595 Mdot
.52883 .45275 Mdot
.43086 .57546 Mdot
.6598 .60347 Mdot
.2392 .67064 Mdot
.61394 .71704 Mdot
.61693 .72722 Mdot
.488 .30531 Mdot
.69275 .72897 Mdot
.44964 .60752 Mdot
.37164 .5722 Mdot
.6689 .59175 Mdot
.44866 .65144 Mdot
.37654 .3545 Mdot
.39856 .35155 Mdot
.25129 .37426 Mdot
.23843 .61809 Mdot
.62787 .74075 Mdot
.65495 .59716 Mdot
.42084 .35018 Mdot
.78 .56697 Mdot
.50573 .53821 Mdot
.66764 .41317 Mdot
.8091 .54095 Mdot
.39871 .54809 Mdot
.54733 .49935 Mdot
.38415 .50336 Mdot
.65711 .61256 Mdot
.60347 .60576 Mdot
.66272 .41364 Mdot
.61441 .7288 Mdot
.39445 .76068 Mdot
.41744 .602 Mdot
.67502 .39634 Mdot
.45082 .64601 Mdot
.47109 .45486 Mdot
.22182 .52623 Mdot
.53508 .21417 Mdot
.40014 .61654 Mdot
.80396 .52279 Mdot
.38764 .61795 Mdot
.2342 .50099 Mdot
.4203 .6102 Mdot
.64873 .60134 Mdot
.4262 .55209 Mdot
.48766 .45629 Mdot
.25399 .27342 Mdot
.40461 .45494 Mdot
.40448 .32821 Mdot
.40426 .5969 Mdot
.42005 .5931 Mdot
.37621 .31461 Mdot
.67178 .61335 Mdot
.38239 .61806 Mdot
.81405 .438 Mdot
.38995 .60723 Mdot
.66399 .42689 Mdot
.28886 .50743 Mdot
.21099 .59697 Mdot
.44667 .61902 Mdot
.65863 .62977 Mdot
.68328 .39316 Mdot
.65281 .3751 Mdot
.50325 .56242 Mdot
.67255 .40174 Mdot
.41034 .63232 Mdot
.28791 .50649 Mdot
.70747 .60528 Mdot
.49682 .56243 Mdot
.65682 .61123 Mdot
.38597 .19497 Mdot
.66884 .40048 Mdot
.51276 .53918 Mdot
.64397 .73026 Mdot
.65407 .39178 Mdot
.36943 .37522 Mdot
.42455 .55079 Mdot
.48907 .58752 Mdot
.61933 .59883 Mdot
.531 .31632 Mdot
.53689 .52298 Mdot
.65842 .411 Mdot
.39981 .60991 Mdot
.42043 .64722 Mdot
.67317 .39989 Mdot
.51446 .66598 Mdot
.46436 .45313 Mdot
.39467 .61721 Mdot
.66839 .60711 Mdot
.64384 .57575 Mdot
.35377 .61484 Mdot
.38683 .61865 Mdot
.52619 .29217 Mdot
.52935 .53376 Mdot
.53426 .53143 Mdot
.5509 .51802 Mdot
.48169 .30254 Mdot
.20256 .35548 Mdot
.68623 .40542 Mdot
.21106 .60783 Mdot
.75495 .52289 Mdot
.50048 .5577 Mdot
.51885 .27638 Mdot
.41212 .58289 Mdot
.41982 .64056 Mdot
.63587 .38802 Mdot
.18876 .45023 Mdot
.374 .57077 Mdot
.62738 .59692 Mdot
.67564 .40617 Mdot
.45652 .63587 Mdot
.72873 .40601 Mdot
.36345 .34122 Mdot
.63465 .74442 Mdot
.67424 .41092 Mdot
.70082 .586 Mdot
.67431 .4114 Mdot
.41906 .5952 Mdot
.47567 .61675 Mdot
.64893 .60983 Mdot
.39558 .31155 Mdot
.37936 .62019 Mdot
.42681 .60994 Mdot
.54979 .36134 Mdot
.78266 .55695 Mdot
.38583 .30337 Mdot
.40812 .63852 Mdot
.49177 .5968 Mdot
.39317 .31145 Mdot
.40575 .62791 Mdot
.3706 .61925 Mdot
.38048 .70611 Mdot
.66247 .43515 Mdot
.35361 .31028 Mdot
.22996 .3011 Mdot
.62825 .587 Mdot
.64406 .4793 Mdot
.54142 .51426 Mdot
.645 .35973 Mdot
.37463 .51158 Mdot
.52628 .52882 Mdot
.77353 .50172 Mdot
.73169 .76731 Mdot
.53482 .52495 Mdot
.49424 .26841 Mdot
.55262 .80422 Mdot
.37114 .61788 Mdot
.39745 .62021 Mdot
.37296 .35311 Mdot
.66304 .57702 Mdot
.75909 .61622 Mdot
.63943 .3637 Mdot
.39801 .5834 Mdot
.63184 .57192 Mdot
.74882 .41642 Mdot
.52403 .52595 Mdot
.37744 .34781 Mdot
.36891 .30856 Mdot
.39434 .62252 Mdot
.23919 .55529 Mdot
.64824 .59343 Mdot
.39158 .60082 Mdot
.43373 .60966 Mdot
.5094 .26734 Mdot
.68452 .57954 Mdot
.49614 .27927 Mdot
.51361 .52417 Mdot
.58936 .8089 Mdot
.7087 .33321 Mdot
.66498 .38946 Mdot
.50945 .54876 Mdot
.6305 .36526 Mdot
.5657 .2799 Mdot
.53034 .53344 Mdot
.39268 .5993 Mdot
.70994 .59866 Mdot
.39108 .60248 Mdot
.39049 .60839 Mdot
.40388 .61344 Mdot
.62826 .7419 Mdot
.42811 .37269 Mdot
.38562 .34781 Mdot
.43254 .62072 Mdot
.47976 .28883 Mdot
.73558 .39341 Mdot
.46039 .79718 Mdot
.40651 .59182 Mdot
.43252 .60783 Mdot
.66342 .62937 Mdot
.45533 .62725 Mdot
.66038 .39365 Mdot
.65686 .61314 Mdot
.41365 .64457 Mdot
.48817 .37533 Mdot
.3869 .62288 Mdot
.64975 .64539 Mdot
.65255 .42448 Mdot
.47184 .59582 Mdot
.37299 .66352 Mdot
.52814 .53518 Mdot
.53591 .52269 Mdot
.55414 .50977 Mdot
.66442 .42759 Mdot
.49905 .2691 Mdot
.50407 .33905 Mdot
.36144 .66494 Mdot
.412 .63453 Mdot
.48532 .59294 Mdot
.45785 .29206 Mdot
.50006 .43451 Mdot
.67008 .73432 Mdot
.45561 .63456 Mdot
.47894 .31046 Mdot
.54937 .47717 Mdot
.51159 .65002 Mdot
.67048 .61519 Mdot
.55791 .29076 Mdot
.64548 .37987 Mdot
.36237 .32346 Mdot
.2395 .42596 Mdot
.63526 .58732 Mdot
.70304 .62162 Mdot
.51627 .28523 Mdot
.28422 .49667 Mdot
.8783 .42805 Mdot
.51421 .30275 Mdot
.42544 .48613 Mdot
.66476 .59487 Mdot
.4063 .65984 Mdot
.249 .52129 Mdot
.29446 .50106 Mdot
.48779 .32043 Mdot
.41005 .57016 Mdot
.42078 .18269 Mdot
.5272 .29397 Mdot
.48798 .60116 Mdot
.48627 .30341 Mdot
.68393 .4049 Mdot
.5072 .29721 Mdot
.62948 .56788 Mdot
.39178 .57668 Mdot
.87529 .4433 Mdot
.33621 .4764 Mdot
.39454 .57942 Mdot
.66924 .42198 Mdot
.58358 .39199 Mdot
.42119 .60167 Mdot
.3898 .3529 Mdot
.49457 .26892 Mdot
.52024 .22881 Mdot
.37452 .63058 Mdot
.52783 .31135 Mdot
.69165 .62843 Mdot
.54589 .27392 Mdot
.48689 .38021 Mdot
.53777 .52522 Mdot
.6743 .59743 Mdot
.61293 .44195 Mdot
.65728 .36285 Mdot
.38949 .64916 Mdot
.43889 .60551 Mdot
.67943 .60116 Mdot
.43227 .49508 Mdot
.36714 .56654 Mdot
.38938 .60412 Mdot
.5034 .2811 Mdot
.54419 .31458 Mdot
.33078 .50323 Mdot
.49031 .29171 Mdot
.49164 .5921 Mdot
.67138 .60417 Mdot
.36806 .6288 Mdot
.63997 .57562 Mdot
.37927 .60367 Mdot
.71501 .42348 Mdot
.68696 .60904 Mdot
.34829 .67072 Mdot
.41146 .56802 Mdot
.73448 .66655 Mdot
.43876 .61393 Mdot
.39248 .61441 Mdot
.54847 .30239 Mdot
.38093 .31729 Mdot
.35582 .58779 Mdot
.67592 .4469 Mdot
.35986 .31906 Mdot
.49905 .6771 Mdot
.53447 .28496 Mdot
.35611 .31358 Mdot
.2357 .39676 Mdot
.53028 .53541 Mdot
.39428 .31974 Mdot
.49871 .54817 Mdot
.66639 .38777 Mdot
.70715 .58206 Mdot
.4288 .57328 Mdot
.58094 .81147 Mdot
.46783 .45098 Mdot
.51739 .53084 Mdot
.40428 .62514 Mdot
.41806 .58431 Mdot
.63234 .57179 Mdot
.68809 .23698 Mdot
.53604 .32761 Mdot
.43304 .65655 Mdot
.63328 .58442 Mdot
.71005 .26258 Mdot
.48773 .32351 Mdot
.35764 .34436 Mdot
.63693 .37164 Mdot
.61706 .56021 Mdot
.5098 .53814 Mdot
.66942 .40298 Mdot
.46943 .33193 Mdot
.28347 .40537 Mdot
.36418 .62295 Mdot
.50877 .27421 Mdot
.27732 .41559 Mdot
.40094 .54301 Mdot
.62007 .40002 Mdot
.58531 .37338 Mdot
.68837 .5942 Mdot
.67365 .40097 Mdot
.3924 .34776 Mdot
.65892 .62056 Mdot
.66019 .61262 Mdot
.65671 .38905 Mdot
.74447 .68984 Mdot
.24449 .53332 Mdot
.62879 .40896 Mdot
.27395 .5296 Mdot
.27938 .41374 Mdot
.51395 .53235 Mdot
.38026 .34636 Mdot
.39763 .37146 Mdot
.64391 .58897 Mdot
.80528 .5449 Mdot
.27578 .41695 Mdot
.45132 .58849 Mdot
.36615 .32098 Mdot
.74202 .42423 Mdot
.59943 .38143 Mdot
.66535 .39712 Mdot
.56092 .3572 Mdot
.36874 .3159 Mdot
.40646 .56479 Mdot
.16486 .50662 Mdot
.44036 .58682 Mdot
.66017 .38676 Mdot
.38609 .50279 Mdot
.67142 .57226 Mdot
.67578 .42324 Mdot
.38777 .50198 Mdot
.4137 .63948 Mdot
.41343 .57695 Mdot
.43822 .37288 Mdot
.69343 .59397 Mdot
.51171 .52831 Mdot
.39002 .58166 Mdot
.43213 .60169 Mdot
.3804 .64872 Mdot
.21393 .57307 Mdot
.55856 .56459 Mdot
.38958 .65369 Mdot
.47032 .30301 Mdot
.47499 .62197 Mdot
.43636 .65546 Mdot
.62888 .6176 Mdot
.46482 .38176 Mdot
.52472 .51439 Mdot
.40271 .6205 Mdot
.39701 .61776 Mdot
.63648 .37481 Mdot
.24421 .53229 Mdot
.29111 .49609 Mdot
.49447 .33272 Mdot
.43588 .2947 Mdot
.38547 .57298 Mdot
.68048 .59342 Mdot
.34453 .30936 Mdot
.49912 .57339 Mdot
.62834 .59639 Mdot
.38039 .58299 Mdot
.50366 .26605 Mdot
.53293 .52858 Mdot
.49885 .58182 Mdot
.36966 .32498 Mdot
.62519 .36605 Mdot
.51149 .65835 Mdot
.52513 .28363 Mdot
.44556 .63493 Mdot
.42833 .29772 Mdot
.52024 .31368 Mdot
.51791 .5277 Mdot
.45967 .64028 Mdot
.66461 .60016 Mdot
.69632 .58055 Mdot
.39646 .40964 Mdot
.47951 .29716 Mdot
.57192 .30976 Mdot
.67868 .39532 Mdot
.43152 .61918 Mdot
.62245 .36103 Mdot
.6846 .57277 Mdot
.22934 .51565 Mdot
.36372 .30996 Mdot
.66233 .39284 Mdot
.50213 .54768 Mdot
.679 .61433 Mdot
.68439 .57125 Mdot
.39456 .61062 Mdot
.39856 .59309 Mdot
.55864 .27374 Mdot
.2601 .45538 Mdot
.63437 .3901 Mdot
.35701 .34 Mdot
.49722 .33248 Mdot
.38944 .63829 Mdot
.68 .58336 Mdot
.1925 .57649 Mdot
.43656 .61392 Mdot
.47989 .29037 Mdot
.65694 .58439 Mdot
.3709 .35092 Mdot
.39335 .34525 Mdot
.38448 .58948 Mdot
.40203 .71723 Mdot
.65083 .39094 Mdot
.6565 .60335 Mdot
.67375 .54418 Mdot
.43115 .62413 Mdot
.40288 .5941 Mdot
.39019 .54273 Mdot
.63576 .4272 Mdot
.35876 .6455 Mdot
.39965 .31608 Mdot
.65698 .56533 Mdot
.3898 .58537 Mdot
.37312 .31663 Mdot
.5532 .49975 Mdot
.52654 .53066 Mdot
.51464 .32497 Mdot
.39286 .35278 Mdot
.38159 .32318 Mdot
.35579 .32221 Mdot
.80993 .53902 Mdot
.51117 .52143 Mdot
.31642 .36036 Mdot
.40809 .56938 Mdot
.28031 .41291 Mdot
.35944 .62631 Mdot
.68018 .41015 Mdot
.52701 .31965 Mdot
.40799 .60867 Mdot
.41019 .56926 Mdot
.52302 .63896 Mdot
.36696 .63111 Mdot
.35745 .59968 Mdot
.67163 .57105 Mdot
.68755 .54842 Mdot
.5335 .29505 Mdot
.72617 .28681 Mdot
.16503 .58608 Mdot
.38629 .56639 Mdot
.28532 .49907 Mdot
.67791 .6128 Mdot
.637 .37277 Mdot
.26676 .52563 Mdot
.61401 .36455 Mdot
.64975 .57608 Mdot
.38734 .63926 Mdot
.5441 .62264 Mdot
.36326 .31842 Mdot
.41694 .59824 Mdot
.64038 .39876 Mdot
.41686 .59947 Mdot
.67024 .42417 Mdot
.69734 .71818 Mdot
.29057 .48155 Mdot
.43851 .57766 Mdot
.36643 .60562 Mdot
.44 .69423 Mdot
.40331 .59203 Mdot
.52793 .21121 Mdot
.66119 .58738 Mdot
.37052 .67789 Mdot
.39597 .64433 Mdot
.60704 .71838 Mdot
.41948 .62024 Mdot
.38619 .5161 Mdot
.43555 .58809 Mdot
.19622 .42681 Mdot
.42924 .56806 Mdot
.44156 .59813 Mdot
.64973 .416 Mdot
.64482 .36611 Mdot
.73353 .58675 Mdot
.52369 .51644 Mdot
.74475 .41827 Mdot
.42798 .61018 Mdot
.52304 .32988 Mdot
.35344 .69068 Mdot
.38056 .31973 Mdot
.6533 .56671 Mdot
.81204 .70817 Mdot
.68341 .42063 Mdot
.48011 .28197 Mdot
.45193 .46646 Mdot
.47148 .29269 Mdot
.55937 .29913 Mdot
.62099 .54877 Mdot
.37838 .34602 Mdot
.38569 .62043 Mdot
.60233 .70246 Mdot
.78853 .54226 Mdot
.42994 .62554 Mdot
.44737 .31138 Mdot
.36783 .69569 Mdot
.37271 .41456 Mdot
.37456 .35819 Mdot
.3828 .33797 Mdot
.66182 .40962 Mdot
.50824 .33102 Mdot
.44713 .64982 Mdot
.35623 .31316 Mdot
.53239 .30153 Mdot
.51495 .54431 Mdot
.4508 .3799 Mdot
.64847 .59491 Mdot
.68945 .73098 Mdot
.67226 .67877 Mdot
.67864 .38423 Mdot
.67388 .44717 Mdot
.71018 .59108 Mdot
.63128 .60525 Mdot
.52495 .5174 Mdot
.48336 .31372 Mdot
.70408 .57819 Mdot
.38701 .58578 Mdot
.48344 .60428 Mdot
.39228 .622 Mdot
.36307 .35011 Mdot
.4121 .62334 Mdot
.53051 .30542 Mdot
.65089 .41885 Mdot
.50202 .31067 Mdot
.6662 .40823 Mdot
.21839 .63955 Mdot
.4046 .56661 Mdot
.4013 .59654 Mdot
.28838 .50589 Mdot
.67675 .56768 Mdot
.58976 .71287 Mdot
.48066 .29424 Mdot
.49385 .3087 Mdot
.39151 .64223 Mdot
.67624 .62184 Mdot
.41084 .31414 Mdot
.28419 .52516 Mdot
.43667 .5912 Mdot
.66263 .58643 Mdot
.38572 .64062 Mdot
.65514 .46463 Mdot
.32166 .48667 Mdot
.66067 .562 Mdot
.25831 .2684 Mdot
.41612 .56735 Mdot
.45226 .65005 Mdot
.35025 .6657 Mdot
.2263 .5869 Mdot
.36604 .57016 Mdot
.62865 .58953 Mdot
.43831 .65381 Mdot
.67897 .58877 Mdot
.51714 .31076 Mdot
.67851 .42238 Mdot
.67394 .5886 Mdot
.42904 .57647 Mdot
.1656 .58434 Mdot
.64502 .41788 Mdot
.41243 .6004 Mdot
.63751 .4016 Mdot
.67166 .5528 Mdot
.66689 .57386 Mdot
.5138 .54536 Mdot
.42715 .4848 Mdot
.65679 .39078 Mdot
.41416 .63341 Mdot
.78931 .56642 Mdot
.36417 .62441 Mdot
.43724 .29893 Mdot
.3704 .58773 Mdot
.37851 .5843 Mdot
.20136 .34436 Mdot
.41779 .50182 Mdot
.71739 .33362 Mdot
.72508 .37861 Mdot
.79055 .57802 Mdot
.61898 .60171 Mdot
.37692 .35841 Mdot
.57924 .56522 Mdot
.53757 .52997 Mdot
.47044 .30676 Mdot
.403 .61001 Mdot
.55373 .49233 Mdot
.63058 .41501 Mdot
.39388 .3226 Mdot
.44295 .58112 Mdot
.46791 .28591 Mdot
.51628 .54751 Mdot
.66767 .40074 Mdot
.64263 .58866 Mdot
.65538 .56995 Mdot
.41974 .37764 Mdot
.3911 .58401 Mdot
.39554 .5956 Mdot
.63676 .41108 Mdot
.34016 .6326 Mdot
.35668 .3303 Mdot
.52748 .45169 Mdot
.63915 .39671 Mdot
.32 .48519 Mdot
.69392 .59219 Mdot
.41529 .58349 Mdot
.29192 .51001 Mdot
.77287 .60197 Mdot
.47654 .78329 Mdot
.37792 .33391 Mdot
.24655 .56604 Mdot
.62882 .58897 Mdot
.64522 .40626 Mdot
.24393 .38433 Mdot
.41967 .54825 Mdot
.42449 .58705 Mdot
.24132 .57546 Mdot
.28266 .52645 Mdot
.45086 .46892 Mdot
.49926 .55504 Mdot
.25725 .51038 Mdot
.3894 .64167 Mdot
.42056 .64654 Mdot
.38754 .5715 Mdot
.36902 .59025 Mdot
.66947 .5838 Mdot
.60768 .73323 Mdot
.51363 .28976 Mdot
.47954 .77016 Mdot
.44608 .28824 Mdot
.44883 .60311 Mdot
.40449 .64081 Mdot
.5037 .7365 Mdot
.27398 .56515 Mdot
.65674 .59221 Mdot
.61713 .59309 Mdot
.66969 .37132 Mdot
.36297 .62534 Mdot
.47936 .29315 Mdot
.35549 .66805 Mdot
.51442 .32163 Mdot
.66712 .5836 Mdot
.51928 .27082 Mdot
.68704 .3906 Mdot
.50769 .27394 Mdot
.47531 .30828 Mdot
.65699 .4218 Mdot
.69326 .60313 Mdot
.44216 .60789 Mdot
.65864 .42209 Mdot
.39767 .30675 Mdot
.36617 .35129 Mdot
.72449 .58513 Mdot
.39822 .65757 Mdot
.40052 .5488 Mdot
.58055 .31058 Mdot
.49576 .2731 Mdot
.30589 .52924 Mdot
.68985 .60482 Mdot
.34329 .3149 Mdot
.67565 .58472 Mdot
.35706 .3977 Mdot
.37619 .32945 Mdot
.50152 .53956 Mdot
.22375 .46065 Mdot
.64734 .35073 Mdot
.4307 .55764 Mdot
.68842 .54916 Mdot
.5116 .32113 Mdot
.66991 .4228 Mdot
.7384 .40374 Mdot
.42821 .65788 Mdot
.71787 .61451 Mdot
.64501 .5524 Mdot
.53522 .53113 Mdot
.64373 .40354 Mdot
.69572 .67763 Mdot
.39548 .5804 Mdot
.63649 .35741 Mdot
.37158 .58638 Mdot
.65256 .74825 Mdot
.47524 .25189 Mdot
.54991 .48109 Mdot
.39121 .64099 Mdot
.48605 .3229 Mdot
.39026 .64128 Mdot
.59808 .79086 Mdot
.23345 .48402 Mdot
.38891 .56921 Mdot
.26766 .56603 Mdot
.56675 .27731 Mdot
.68181 .58505 Mdot
.49792 .56852 Mdot
.51563 .53129 Mdot
.43548 .64356 Mdot
.23178 .72547 Mdot
.3827 .31543 Mdot
.47148 .35698 Mdot
.42542 .57393 Mdot
.3886 .59784 Mdot
.508 .6602 Mdot
.69429 .71808 Mdot
.52661 .54113 Mdot
.42714 .59149 Mdot
.2447 .59309 Mdot
.65423 .41523 Mdot
.36643 .61904 Mdot
.38801 .61527 Mdot
.54212 .26065 Mdot
.648 .41339 Mdot
.52123 .2753 Mdot
.53259 .53393 Mdot
.54177 .31403 Mdot
.39265 .3087 Mdot
.25596 .56548 Mdot
.22073 .54094 Mdot
.32402 .49272 Mdot
.39632 .34993 Mdot
.44795 .62198 Mdot
.53113 .48667 Mdot
.40945 .57342 Mdot
.38686 .33749 Mdot
.63745 .39222 Mdot
.66522 .5877 Mdot
.67298 .74248 Mdot
.52143 .52473 Mdot
.43918 .62752 Mdot
.35234 .34593 Mdot
.67292 .59317 Mdot
.77398 .64809 Mdot
.66478 .5783 Mdot
.66375 .40146 Mdot
.62253 .40686 Mdot
.37586 .324 Mdot
.67617 .5844 Mdot
.54574 .30787 Mdot
.61267 .39998 Mdot
.44816 .57153 Mdot
.68777 .39382 Mdot
.66583 .55638 Mdot
.65023 .56055 Mdot
.70353 .61252 Mdot
.40188 .64545 Mdot
.28175 .55123 Mdot
.50666 .55359 Mdot
.64011 .41472 Mdot
.46494 .29909 Mdot
.25438 .46145 Mdot
.59785 .65821 Mdot
.30622 .48726 Mdot
.49207 .5683 Mdot
.41033 .62382 Mdot
.39613 .6231 Mdot
.37879 .65089 Mdot
.51639 .47019 Mdot
.40062 .56795 Mdot
.63517 .38929 Mdot
.52472 .30544 Mdot
.43293 .58818 Mdot
.5187 .53659 Mdot
.49572 .43607 Mdot
.3548 .30864 Mdot
.63446 .74682 Mdot
.72434 .58193 Mdot
.67171 .59204 Mdot
.48943 .28263 Mdot
.52996 .27647 Mdot
.34701 .31867 Mdot
.67137 .41005 Mdot
.66137 .57626 Mdot
.19958 .41726 Mdot
.35911 .32296 Mdot
.40466 .62029 Mdot
.28896 .50688 Mdot
.23806 .60455 Mdot
.37651 .61993 Mdot
.40525 .61417 Mdot
.52667 .51353 Mdot
.47724 .29363 Mdot
.4638 .80599 Mdot
.75561 .65795 Mdot
.37622 .31877 Mdot
.35047 .32762 Mdot
.69713 .6188 Mdot
.42581 .62108 Mdot
.64817 .39094 Mdot
.24171 .53885 Mdot
.59172 .41902 Mdot
.74985 .43094 Mdot
.56886 .2849 Mdot
.38888 .62475 Mdot
.58022 .77569 Mdot
.40264 .55395 Mdot
.675 .5528 Mdot
.70192 .59153 Mdot
.65526 .59523 Mdot
.65748 .41587 Mdot
.28638 .4029 Mdot
.65265 .36493 Mdot
.54867 .47578 Mdot
.63613 .59649 Mdot
.43366 .48882 Mdot
.49132 .30729 Mdot
.36152 .62771 Mdot
.38099 .34457 Mdot
.37327 .28814 Mdot
.49569 .57304 Mdot
.24968 .56583 Mdot
.51859 .2762 Mdot
.67929 .61651 Mdot
.36381 .63192 Mdot
.73537 .39 Mdot
.27883 .4872 Mdot
.5511 .23977 Mdot
.55283 .48931 Mdot
.3701 .31804 Mdot
.42558 .77898 Mdot
.36057 .33401 Mdot
.66162 .39157 Mdot
.40864 .56727 Mdot
.42819 .61825 Mdot
.392 .61481 Mdot
.37248 .57748 Mdot
.65627 .41159 Mdot
.44078 .56615 Mdot
.40987 .41203 Mdot
.54198 .52888 Mdot
.4981 .45578 Mdot
.39884 .33821 Mdot
.67947 .39935 Mdot
.52271 .31105 Mdot
.53803 .51175 Mdot
.34122 .32004 Mdot
.36621 .63761 Mdot
.42286 .57486 Mdot
.53829 .53339 Mdot
.49449 .56115 Mdot
.39423 .54981 Mdot
.5208 .2907 Mdot
.47593 .45252 Mdot
.36395 .30681 Mdot
.37179 .33761 Mdot
.67206 .39302 Mdot
.67661 .58498 Mdot
.35553 .31047 Mdot
.46407 .31879 Mdot
.36628 .62076 Mdot
.37306 .5835 Mdot
.66046 .55692 Mdot
.27831 .41248 Mdot
.3547 .30853 Mdot
.356 .64174 Mdot
.66175 .56357 Mdot
.64244 .55249 Mdot
.42567 .59107 Mdot
.4457 .57409 Mdot
.62915 .61707 Mdot
.34883 .32924 Mdot
.67464 .39395 Mdot
.318 .46826 Mdot
.68543 .40581 Mdot
.6422 .59218 Mdot
.48068 .61176 Mdot
.69095 .60953 Mdot
.4265 .65806 Mdot
.80608 .40829 Mdot
.39788 .56852 Mdot
.5979 .61348 Mdot
.48356 .42645 Mdot
.48815 .30643 Mdot
.48881 .31262 Mdot
.53108 .53125 Mdot
.63185 .60134 Mdot
.49367 .58608 Mdot
.3721 .34572 Mdot
.7904 .57705 Mdot
.62978 .61852 Mdot
.47659 .30983 Mdot
.48705 .27381 Mdot
.63773 .39928 Mdot
.41416 .62307 Mdot
.41445 .5824 Mdot
.50915 .27346 Mdot
.6122 .45428 Mdot
.6863 .59992 Mdot
.39559 .59609 Mdot
.38697 .65199 Mdot
.51654 .29202 Mdot
.68439 .36715 Mdot
.70686 .58389 Mdot
.40286 .64639 Mdot
.23168 .4937 Mdot
.67187 .42511 Mdot
.43431 .63854 Mdot
.43009 .5568 Mdot
.38637 .3226 Mdot
.24314 .56848 Mdot
.27522 .42064 Mdot
.68594 .41729 Mdot
.52149 .53849 Mdot
.38076 .62335 Mdot
.49229 .3115 Mdot
.35556 .62822 Mdot
.59253 .84671 Mdot
.53606 .53392 Mdot
.3951 .58312 Mdot
.35055 .65978 Mdot
.63957 .57563 Mdot
.39105 .59742 Mdot
.71041 .42812 Mdot
.49737 .2839 Mdot
.39639 .5817 Mdot
.43827 .70599 Mdot
.63824 .39992 Mdot
.49702 .56909 Mdot
.36669 .31687 Mdot
.43912 .47902 Mdot
.23708 .66784 Mdot
.45883 .29061 Mdot
.40202 .33262 Mdot
.42281 .61729 Mdot
.50781 .33285 Mdot
.64373 .36382 Mdot
.50618 .551 Mdot
.44327 .63398 Mdot
.67372 .37826 Mdot
.65757 .41919 Mdot
.37228 .32273 Mdot
.86471 .54334 Mdot
.398 .56342 Mdot
.41306 .5943 Mdot
.8278 .59941 Mdot
.60756 .59715 Mdot
.41394 .60116 Mdot
.43438 .60993 Mdot
.67006 .39682 Mdot
.28777 .38619 Mdot
.24804 .56659 Mdot
.52653 .4549 Mdot
.67521 .42033 Mdot
.49533 .33583 Mdot
.50406 .27801 Mdot
.40169 .32559 Mdot
.65624 .58382 Mdot
.34351 .32195 Mdot
.50643 .29397 Mdot
.39816 .61589 Mdot
.66419 .37764 Mdot
.36597 .74464 Mdot
.6579 .42547 Mdot
.45946 .30084 Mdot
.67308 .55245 Mdot
.53775 .81848 Mdot
.61721 .84095 Mdot
.56976 .55286 Mdot
.6189 .40169 Mdot
.38102 .31972 Mdot
.75851 .65654 Mdot
.43442 .58939 Mdot
.59757 .78523 Mdot
.41588 .59665 Mdot
.55712 .49761 Mdot
.53052 .31527 Mdot
.51456 .54464 Mdot
.42593 .65848 Mdot
.25106 .56917 Mdot
.66477 .41855 Mdot
.64387 .3847 Mdot
.43906 .65302 Mdot
.66166 .39749 Mdot
.40482 .5822 Mdot
.52156 .29925 Mdot
.83603 .45152 Mdot
.43469 .58526 Mdot
.3716 .67632 Mdot
.63828 .3541 Mdot
.73725 .62533 Mdot
.47784 .33336 Mdot
.59188 .75436 Mdot
.7473 .40873 Mdot
.64879 .39267 Mdot
.62933 .74441 Mdot
.48596 .28536 Mdot
.53756 .51142 Mdot
.5283 .32986 Mdot
.41505 .58974 Mdot
.39061 .62665 Mdot
.37582 .65024 Mdot
.43097 .61102 Mdot
.55132 .79224 Mdot
.40006 .54638 Mdot
.46943 .72464 Mdot
.4071 .56964 Mdot
.57812 .57975 Mdot
.64373 .37075 Mdot
.45577 .64344 Mdot
.34435 .45675 Mdot
.38546 .57865 Mdot
.61912 .59816 Mdot
.6814 .39895 Mdot
.75327 .37367 Mdot
.65428 .4131 Mdot
.50213 .31186 Mdot
.66768 .41384 Mdot
.44827 .58454 Mdot
.64274 .57871 Mdot
.49608 .2965 Mdot
.50345 .55026 Mdot
.4671 .30794 Mdot
.39442 .5796 Mdot
.67842 .34922 Mdot
.48415 .28005 Mdot
.41311 .54594 Mdot
.64472 .57646 Mdot
.20077 .52626 Mdot
.71166 .58641 Mdot
.3972 .60441 Mdot
.40422 .60455 Mdot
.53642 .53543 Mdot
.66956 .40837 Mdot
.69469 .60569 Mdot
.57729 .35102 Mdot
.34234 .3157 Mdot
.65365 .58893 Mdot
.34722 .66409 Mdot
.28218 .49695 Mdot
.6469 .56593 Mdot
.24168 .59894 Mdot
.66174 .3893 Mdot
.63165 .57963 Mdot
.33485 .64132 Mdot
.47461 .76829 Mdot
.36706 .33658 Mdot
.54766 .30569 Mdot
.26901 .51128 Mdot
.50145 .27898 Mdot
.72466 .4109 Mdot
.55129 .29915 Mdot
.64136 .40978 Mdot
.36315 .69309 Mdot
.38874 .5022 Mdot
.6441 .42675 Mdot
.68577 .34861 Mdot
.50915 .28601 Mdot
.39962 .65642 Mdot
.48765 .45387 Mdot
.49429 .59274 Mdot
.46945 .63664 Mdot
.68138 .42286 Mdot
.62977 .5824 Mdot
.65975 .62021 Mdot
.36123 .67761 Mdot
.66384 .56893 Mdot
.50924 .30359 Mdot
.3271 .4977 Mdot
.64384 .72995 Mdot
.64086 .37842 Mdot
.4681 .45373 Mdot
.40451 .64169 Mdot
.52908 .30991 Mdot
.51084 .30629 Mdot
.66008 .41802 Mdot
.51592 .77206 Mdot
.49046 .59864 Mdot
.60471 .57498 Mdot
.63454 .58924 Mdot
.63851 .57562 Mdot
.68968 .58249 Mdot
.28512 .40212 Mdot
.67135 .4213 Mdot
.63091 .59871 Mdot
.36884 .58129 Mdot
.4216 .62092 Mdot
.53728 .51866 Mdot
.35951 .34685 Mdot
.41047 .5484 Mdot
.49395 .58578 Mdot
.42417 .58942 Mdot
.48538 .30213 Mdot
.36077 .69987 Mdot
.54532 .52329 Mdot
.4786 .29447 Mdot
.4814 .30045 Mdot
.52778 .53557 Mdot
.35633 .69345 Mdot
.47928 .79793 Mdot
.45302 .63271 Mdot
.6179 .55219 Mdot
.48983 .31541 Mdot
.51136 .37788 Mdot
.59282 .60431 Mdot
.41355 .63158 Mdot
.51523 .44353 Mdot
.5198 .30366 Mdot
.618 .60177 Mdot
.4085 .59013 Mdot
.52145 .52009 Mdot
.36302 .33014 Mdot
.50338 .55268 Mdot
.52523 .51463 Mdot
.68496 .58989 Mdot
.57135 .31886 Mdot
.63284 .57108 Mdot
.52995 .27367 Mdot
.49363 .57724 Mdot
.87684 .43466 Mdot
.51165 .31997 Mdot
.79594 .56726 Mdot
.39638 .50007 Mdot
.42038 .57797 Mdot
.49296 .28196 Mdot
.67893 .63038 Mdot
.66754 .42856 Mdot
.29067 .54648 Mdot
.67679 .58156 Mdot
.54185 .51145 Mdot
.53363 .52161 Mdot
.51499 .29009 Mdot
.64706 .6027 Mdot
.43576 .56052 Mdot
.65336 .57087 Mdot
.6569 .37314 Mdot
.44212 .64635 Mdot
.7448 .41745 Mdot
.45899 .64181 Mdot
.6608 .56687 Mdot
.46311 .30062 Mdot
.39562 .31179 Mdot
.43847 .58185 Mdot
.75531 .37987 Mdot
.42288 .61774 Mdot
.63671 .39758 Mdot
.46678 .42429 Mdot
.38523 .74291 Mdot
.41703 .61303 Mdot
.40884 .64084 Mdot
.6804 .37294 Mdot
.41989 .60993 Mdot
.36998 .60322 Mdot
.69513 .6794 Mdot
.65096 .5642 Mdot
.43351 .58999 Mdot
.52081 .28195 Mdot
.45266 .71151 Mdot
.38524 .59774 Mdot
.70435 .43482 Mdot
.23061 .57307 Mdot
.44849 .41755 Mdot
.37174 .68482 Mdot
.23029 .51261 Mdot
.40758 .60107 Mdot
.41896 .62855 Mdot
.44751 .64397 Mdot
.58388 .77772 Mdot
.50462 .28984 Mdot
.49028 .32608 Mdot
.40147 .31944 Mdot
.24108 .57802 Mdot
.36997 .33124 Mdot
.64323 .36339 Mdot
.44574 .47151 Mdot
.54901 .52005 Mdot
.67786 .58615 Mdot
.38933 .6105 Mdot
.46642 .31276 Mdot
.41195 .58442 Mdot
.43423 .64294 Mdot
.5109 .30077 Mdot
.51661 .30795 Mdot
.47378 .26689 Mdot
.36521 .31546 Mdot
.66306 .5932 Mdot
.42529 .56849 Mdot
.36078 .31792 Mdot
.3788 .64943 Mdot
.30296 .46902 Mdot
.65989 .59372 Mdot
.664 .56691 Mdot
.6529 .61451 Mdot
.44261 .59359 Mdot
.44634 .64365 Mdot
.65528 .36464 Mdot
.66005 .5568 Mdot
.65316 .38784 Mdot
.49418 .28093 Mdot
.5277 .29635 Mdot
.41583 .59024 Mdot
.34118 .63313 Mdot
.39374 .34376 Mdot
.48882 .27654 Mdot
.54655 .50532 Mdot
.3887 .31285 Mdot
.38891 .62104 Mdot
.49821 .27919 Mdot
.38183 .35403 Mdot
.50392 .77794 Mdot
.70504 .46759 Mdot
.39709 .31548 Mdot
.42767 .65925 Mdot
.5833 .65788 Mdot
.23892 .47577 Mdot
.35309 .30674 Mdot
.64434 .37129 Mdot
.43919 .60931 Mdot
.53786 .46621 Mdot
.36653 .30748 Mdot
.26614 .43237 Mdot
.50487 .2982 Mdot
.46346 .64193 Mdot
.53243 .58899 Mdot
.64035 .72873 Mdot
.39312 .31025 Mdot
.65861 .56627 Mdot
.68527 .56781 Mdot
.40773 .61884 Mdot
.4402 .47672 Mdot
.63053 .40546 Mdot
.53153 .27783 Mdot
.48219 .32404 Mdot
.69875 .57942 Mdot
.32369 .49006 Mdot
.51678 .2799 Mdot
.42913 .62073 Mdot
.40661 .35747 Mdot
.35758 .60051 Mdot
.37441 .40653 Mdot
.36916 .73194 Mdot
.36303 .68385 Mdot
.39552 .31239 Mdot
.63137 .40348 Mdot
.64896 .41734 Mdot
.66428 .41107 Mdot
.51939 .28565 Mdot
.26588 .52334 Mdot
.48945 .32786 Mdot
.81004 .62066 Mdot
.38218 .31469 Mdot
.21391 .35608 Mdot
.38499 .56352 Mdot
.41663 .57675 Mdot
.3622 .61749 Mdot
.39558 .65351 Mdot
.40652 .60035 Mdot
.6693 .37252 Mdot
.53836 .31548 Mdot
.58241 .37475 Mdot
.6705 .60703 Mdot
.77205 .65053 Mdot
.49006 .30556 Mdot
.52025 .51804 Mdot
.38936 .34467 Mdot
.21611 .55007 Mdot
.4084 .34601 Mdot
.50319 .26849 Mdot
.37556 .59972 Mdot
.69679 .61997 Mdot
.19416 .43669 Mdot
.38893 .603 Mdot
.49377 .27326 Mdot
.48396 .3319 Mdot
.49244 .7688 Mdot
.46871 .54932 Mdot
.58786 .41453 Mdot
.29694 .50866 Mdot
.40715 .33868 Mdot
.3972 .65836 Mdot
.23812 .54794 Mdot
.50781 .29298 Mdot
.49789 .32337 Mdot
.34821 .30411 Mdot
.74768 .61555 Mdot
.63678 .60294 Mdot
.69741 .55941 Mdot
.6732 .37959 Mdot
.41802 .57475 Mdot
.50718 .28234 Mdot
.69341 .56069 Mdot
.32001 .44047 Mdot
.6586 .40572 Mdot
.48117 .28096 Mdot
.426 .61595 Mdot
.41753 .61409 Mdot
.36922 .32862 Mdot
.48701 .43095 Mdot
.49421 .59262 Mdot
.7914 .5748 Mdot
.29674 .49274 Mdot
.39698 .49954 Mdot
.42449 .58685 Mdot
.68865 .58369 Mdot
.52903 .53444 Mdot
.38042 .34682 Mdot
.35533 .62401 Mdot
.58024 .809 Mdot
.62245 .57659 Mdot
.65381 .38927 Mdot
.51075 .53498 Mdot
.26016 .56614 Mdot
.42701 .61463 Mdot
.41578 .59609 Mdot
.40059 .64493 Mdot
.51151 .81713 Mdot
.52608 .31973 Mdot
.68243 .5763 Mdot
.36917 .31648 Mdot
.66587 .57446 Mdot
.53217 .27314 Mdot
.47242 .45098 Mdot
.43642 .57219 Mdot
.62066 .58524 Mdot
.65461 .5765 Mdot
.63766 .39547 Mdot
.65503 .42261 Mdot
.45338 .31039 Mdot
.43763 .60527 Mdot
.54991 .51997 Mdot
.63033 .59319 Mdot
.5444 .29986 Mdot
.37101 .32946 Mdot
.72483 .41331 Mdot
.41301 .5695 Mdot
.51097 .28956 Mdot
.49487 .57815 Mdot
.67327 .60157 Mdot
.4826 .29044 Mdot
.53677 .5109 Mdot
.3532 .33833 Mdot
.38784 .62656 Mdot
.54023 .22952 Mdot
.51895 .52144 Mdot
.43767 .58333 Mdot
.4004 .73122 Mdot
.44181 .47584 Mdot
.54922 .50282 Mdot
.53145 .29315 Mdot
.52803 .51716 Mdot
.6938 .58139 Mdot
.45569 .76526 Mdot
.50386 .32507 Mdot
.54752 .6177 Mdot
.37556 .50548 Mdot
.43482 .65539 Mdot
.68124 .5852 Mdot
.44428 .37928 Mdot
.76923 .58015 Mdot
.24517 .47163 Mdot
.39642 .58621 Mdot
.50201 .27905 Mdot
.36532 .33264 Mdot
.64464 .38425 Mdot
.64269 .43651 Mdot
.41057 .38195 Mdot
.4781 .30641 Mdot
.3888 .61043 Mdot
.63017 .58245 Mdot
.65696 .39192 Mdot
.50656 .66465 Mdot
.49553 .33159 Mdot
.52041 .28 Mdot
.38246 .63359 Mdot
.37061 .33275 Mdot
.52474 .4779 Mdot
.51967 .32417 Mdot
.53381 .32104 Mdot
.68794 .67962 Mdot
.40587 .34133 Mdot
.40741 .64729 Mdot
.36012 .67732 Mdot
.36535 .60343 Mdot
.79107 .63567 Mdot
.53462 .51422 Mdot
.67219 .60736 Mdot
.41053 .60649 Mdot
.57183 .2842 Mdot
.52019 .31793 Mdot
.29735 .50853 Mdot
.66163 .35483 Mdot
.66283 .42084 Mdot
.49689 .28619 Mdot
.40328 .58751 Mdot
.66522 .44657 Mdot
.40036 .32526 Mdot
.40493 .64796 Mdot
.43097 .65642 Mdot
.69176 .56989 Mdot
.66412 .37634 Mdot
.43873 .71681 Mdot
.64789 .37947 Mdot
.67271 .39918 Mdot
.70493 .63406 Mdot
.4071 .61936 Mdot
.48789 .29961 Mdot
.47339 .27942 Mdot
.37723 .65708 Mdot
.52066 .36855 Mdot
.65458 .61164 Mdot
.52419 .34004 Mdot
.56738 .81581 Mdot
.38008 .57309 Mdot
.50707 .53546 Mdot
.55314 .48417 Mdot
.62155 .40305 Mdot
.41262 .61307 Mdot
.68069 .59038 Mdot
.53032 .32127 Mdot
.50941 .27989 Mdot
.41835 .54796 Mdot
.65013 .41846 Mdot
.37227 .35385 Mdot
.50692 .30575 Mdot
.32417 .47018 Mdot
.39348 .58369 Mdot
.61354 .36213 Mdot
.50325 .30512 Mdot
.17301 .5901 Mdot
.57486 .28862 Mdot
.64206 .56986 Mdot
.40541 .63845 Mdot
.70823 .59187 Mdot
.40436 .33117 Mdot
.54665 .31841 Mdot
.63455 .40046 Mdot
.49941 .55964 Mdot
.72192 .29254 Mdot
.5152 .28489 Mdot
.66692 .58456 Mdot
.4002 .61386 Mdot
.62206 .74377 Mdot
.43552 .58851 Mdot
.28787 .38272 Mdot
.36048 .30689 Mdot
.72335 .40792 Mdot
.63692 .41089 Mdot
.41223 .63965 Mdot
.35586 .32548 Mdot
.4725 .27763 Mdot
.51083 .29983 Mdot
.74754 .32949 Mdot
.53048 .51184 Mdot
.55908 .30247 Mdot
.43953 .58767 Mdot
.53663 .28505 Mdot
.59897 .65847 Mdot
.65634 .42014 Mdot
.3659 .60582 Mdot
.4744 .28816 Mdot
.76129 .59467 Mdot
.29024 .50386 Mdot
.39408 .58544 Mdot
.34482 .64529 Mdot
.64129 .4078 Mdot
.75815 .65813 Mdot
.53276 .31248 Mdot
.36749 .64095 Mdot
.64781 .35892 Mdot
.36115 .69046 Mdot
.57905 .40204 Mdot
.66279 .59352 Mdot
.48133 .27608 Mdot
.6742 .3909 Mdot
.46401 .63881 Mdot
.3766 .35224 Mdot
.46476 .32045 Mdot
.46837 .30049 Mdot
.45088 .62494 Mdot
.38572 .64755 Mdot
.3421 .64347 Mdot
.68493 .60666 Mdot
.66764 .39165 Mdot
.42828 .64573 Mdot
.29712 .46767 Mdot
.40769 .65234 Mdot
.66811 .3882 Mdot
.86973 .48538 Mdot
.37526 .60519 Mdot
.41347 .5704 Mdot
.61503 .75536 Mdot
.68731 .61507 Mdot
.67453 .56413 Mdot
.29644 .48505 Mdot
.44379 .61509 Mdot
.43066 .4918 Mdot
.66579 .59122 Mdot
.66535 .58181 Mdot
.43164 .49087 Mdot
.45163 .62776 Mdot
.71229 .58104 Mdot
.65871 .39355 Mdot
.66165 .42141 Mdot
.64008 .57503 Mdot
.35952 .61873 Mdot
.63749 .37106 Mdot
.53069 .76317 Mdot
.49508 .27051 Mdot
.2404 .55337 Mdot
.65321 .57391 Mdot
.28561 .5066 Mdot
.66244 .3917 Mdot
.21587 .62135 Mdot
.22612 .5897 Mdot
.39019 .5653 Mdot
.4109 .61675 Mdot
.38418 .32393 Mdot
.4997 .56137 Mdot
.53174 .53362 Mdot
.66506 .41115 Mdot
.51566 .4698 Mdot
.65405 .59502 Mdot
.44379 .61022 Mdot
.25718 .45846 Mdot
.25009 .67724 Mdot
.31665 .61657 Mdot
.65784 .58291 Mdot
.64519 .58877 Mdot
.52469 .28038 Mdot
.51485 .26789 Mdot
.42845 .56873 Mdot
.64521 .4146 Mdot
.63587 .57539 Mdot
.66445 .38219 Mdot
.50767 .29422 Mdot
.49258 .30631 Mdot
.54382 .52253 Mdot
.47379 .63096 Mdot
.4983 .29128 Mdot
.69504 .44039 Mdot
.29795 .46797 Mdot
.66946 .55614 Mdot
.82184 .60884 Mdot
.21071 .60658 Mdot
.65873 .74785 Mdot
.3639 .33145 Mdot
.35477 .69207 Mdot
.65526 .36174 Mdot
.41444 .64004 Mdot
.42048 .59801 Mdot
.52401 .52634 Mdot
.65434 .36051 Mdot
.39481 .32941 Mdot
.65963 .42074 Mdot
.36889 .34749 Mdot
.48372 .32256 Mdot
.38689 .60399 Mdot
.38295 .58531 Mdot
.64302 .38704 Mdot
.51859 .27392 Mdot
.48256 .28237 Mdot
.3683 .34048 Mdot
.21704 .55442 Mdot
.51387 .29095 Mdot
.65469 .57435 Mdot
.5385 .64207 Mdot
.53221 .5218 Mdot
.40747 .59047 Mdot
.22825 .51656 Mdot
.44483 .76223 Mdot
.37576 .65139 Mdot
.51242 .5331 Mdot
.8659 .53926 Mdot
.38555 .58781 Mdot
.70713 .25963 Mdot
.54797 .51924 Mdot
.69074 .61013 Mdot
.48755 .29284 Mdot
.51923 .51971 Mdot
.37676 .70187 Mdot
.46657 .25503 Mdot
.37267 .65373 Mdot
.63591 .60285 Mdot
.66558 .61766 Mdot
.47343 .45203 Mdot
.79003 .63926 Mdot
.36787 .31729 Mdot
.39599 .32308 Mdot
.51648 .32228 Mdot
.73003 .40167 Mdot
.36919 .57594 Mdot
.39119 .3198 Mdot
.72432 .59522 Mdot
.39669 .64155 Mdot
.44715 .47259 Mdot
.49324 .45452 Mdot
.68989 .57664 Mdot
.46426 .61556 Mdot
.51773 .32081 Mdot
.66523 .58572 Mdot
.48141 .45314 Mdot
.3705 .62466 Mdot
.65761 .59441 Mdot
.67097 .40225 Mdot
.41175 .5225 Mdot
.6566 .57015 Mdot
.29637 .54093 Mdot
.64509 .39354 Mdot
.45449 .46565 Mdot
.23951 .35949 Mdot
.18775 .65162 Mdot
.65346 .41717 Mdot
.49046 .27723 Mdot
.50693 .28331 Mdot
.5191 .29433 Mdot
.68914 .59522 Mdot
.51754 .31278 Mdot
.65926 .60952 Mdot
.61703 .40118 Mdot
.24591 .57331 Mdot
.37652 .32657 Mdot
.46611 .37429 Mdot
.64306 .57372 Mdot
.8041 .62537 Mdot
.74619 .75947 Mdot
.40273 .65178 Mdot
.64531 .42757 Mdot
.37356 .3095 Mdot
.30821 .50817 Mdot
.3865 .32338 Mdot
.48636 .28487 Mdot
.25523 .56786 Mdot
.40685 .58162 Mdot
.69602 .46171 Mdot
.3665 .33334 Mdot
.66576 .58059 Mdot
.44921 .60959 Mdot
.49692 .26483 Mdot
.40305 .33004 Mdot
.37385 .34022 Mdot
.40687 .59863 Mdot
.68075 .61621 Mdot
.48296 .28478 Mdot
.67577 .37858 Mdot
.39813 .36468 Mdot
.35447 .57368 Mdot
.38373 .59393 Mdot
.38742 .57318 Mdot
.28806 .49778 Mdot
.7315 .40301 Mdot
.64663 .39592 Mdot
.26889 .43183 Mdot
.52944 .30676 Mdot
.24402 .46858 Mdot
.77816 .56906 Mdot
.44698 .37409 Mdot
.53412 .51481 Mdot
.539 .51327 Mdot
.3934 .5986 Mdot
.66262 .80951 Mdot
.45867 .54001 Mdot
.63669 .36791 Mdot
.52761 .52708 Mdot
.50427 .26706 Mdot
.64447 .56016 Mdot
.53323 .5787 Mdot
.39891 .55287 Mdot
.6745 .37646 Mdot
.51332 .29619 Mdot
.58353 .85263 Mdot
.37602 .31554 Mdot
.31014 .50555 Mdot
.43587 .60653 Mdot
.39804 .59669 Mdot
.65338 .40539 Mdot
.63445 .39578 Mdot
.68564 .68064 Mdot
.43891 .4148 Mdot
.74798 .41682 Mdot
.6827 .42698 Mdot
.58032 .85499 Mdot
.55493 .49082 Mdot
.64839 .59863 Mdot
.52 .53986 Mdot
.63223 .408 Mdot
.41309 .6032 Mdot
.68579 .61521 Mdot
.50685 .55046 Mdot
.67008 .62616 Mdot
.43743 .47984 Mdot
.31803 .46873 Mdot
.41178 .62304 Mdot
.70243 .61011 Mdot
.66212 .58903 Mdot
.62174 .55509 Mdot
.53573 .52679 Mdot
.4272 .58967 Mdot
.36551 .64129 Mdot
.39862 .5703 Mdot
.65136 .67363 Mdot
.39067 .59617 Mdot
.77727 .57308 Mdot
.30624 .48268 Mdot
.45292 .17736 Mdot
.38872 .58112 Mdot
.67318 .40708 Mdot
.39227 .61058 Mdot
.35489 .32723 Mdot
.37944 .61999 Mdot
.42717 .48596 Mdot
.6559 .39547 Mdot
.59584 .7939 Mdot
.44281 .29516 Mdot
.38185 .59752 Mdot
.39434 .351 Mdot
.81992 .51165 Mdot
.26937 .43513 Mdot
.689 .67814 Mdot
.65301 .57118 Mdot
.51953 .33113 Mdot
.63053 .41009 Mdot
.50013 .31141 Mdot
.44339 .5669 Mdot
.53519 .53325 Mdot
.20217 .35553 Mdot
.27142 .47589 Mdot
.41126 .60512 Mdot
.489 .60385 Mdot
.67333 .56935 Mdot
.51757 .31912 Mdot
.69597 .71957 Mdot
.36515 .62411 Mdot
.34687 .3281 Mdot
.36199 .31248 Mdot
.40973 .29644 Mdot
.65758 .64681 Mdot
.61931 .66268 Mdot
.65258 .40341 Mdot
.51756 .28355 Mdot
.37392 .30744 Mdot
.70226 .55842 Mdot
.63653 .41664 Mdot
.62135 .4005 Mdot
.6665 .37749 Mdot
.40154 .57527 Mdot
.54317 .51884 Mdot
.69187 .65132 Mdot
.52802 .51426 Mdot
.36328 .59922 Mdot
.46879 .29981 Mdot
.53398 .51246 Mdot
.38181 .3298 Mdot
.67414 .39583 Mdot
.48762 .30419 Mdot
.40057 .60565 Mdot
.66981 .59323 Mdot
.38248 .41558 Mdot
.56113 .26061 Mdot
.44212 .47509 Mdot
.44224 .47498 Mdot
.62775 .55851 Mdot
.54343 .47585 Mdot
.66729 .34404 Mdot
.48139 .77098 Mdot
.39697 .3693 Mdot
.35613 .58519 Mdot
.53265 .36169 Mdot
.49196 .32882 Mdot
.49787 .29838 Mdot
.40931 .57905 Mdot
.54018 .29531 Mdot
.4421 .60283 Mdot
.53206 .29319 Mdot
.77816 .59603 Mdot
.41753 .55133 Mdot
.50663 .30245 Mdot
.50507 .55715 Mdot
.43733 .58104 Mdot
.68155 .5774 Mdot
.51629 .32989 Mdot
.38976 .56551 Mdot
.32977 .19832 Mdot
.63828 .39422 Mdot
.53623 .52507 Mdot
.36669 .4836 Mdot
.666 .39889 Mdot
.64217 .60402 Mdot
.43668 .6153 Mdot
.38707 .31508 Mdot
.64316 .59309 Mdot
.42987 .30292 Mdot
.37185 .33592 Mdot
.32987 .49439 Mdot
.63804 .58553 Mdot
.53225 .51954 Mdot
.34866 .32746 Mdot
.37841 .65605 Mdot
.50099 .29907 Mdot
.56741 .27104 Mdot
.51174 .52982 Mdot
.41071 .58243 Mdot
.49814 .26578 Mdot
.66634 .41693 Mdot
.38914 .61762 Mdot
.5076 .28141 Mdot
.51582 .53899 Mdot
.42667 .57323 Mdot
.44679 .60705 Mdot
.74571 .66222 Mdot
.47698 .42439 Mdot
.37877 .32797 Mdot
.67321 .55274 Mdot
.36962 .58229 Mdot
.35747 .32947 Mdot
.56705 .28259 Mdot
.45564 .64046 Mdot
.62637 .58935 Mdot
.52125 .76382 Mdot
.53134 .27855 Mdot
.6465 .41906 Mdot
.46068 .29899 Mdot
.40568 .32814 Mdot
.78933 .72541 Mdot
.53474 .53175 Mdot
.45569 .63104 Mdot
.37087 .59562 Mdot
.53852 .32498 Mdot
.65893 .59005 Mdot
.74916 .42395 Mdot
.38896 .62789 Mdot
.4846 .59527 Mdot
.40737 .59421 Mdot
.52112 .22876 Mdot
.68906 .60251 Mdot
.40814 .59208 Mdot
.34565 .62678 Mdot
.37198 .5868 Mdot
.39296 .34798 Mdot
.21217 .36326 Mdot
.4111 .65661 Mdot
.87917 .41037 Mdot
.51128 .54469 Mdot
.51524 .30111 Mdot
.29872 .53893 Mdot
.36957 .47836 Mdot
.3856 .19507 Mdot
.64768 .60774 Mdot
.622 .54973 Mdot
.49337 .30593 Mdot
.42686 .37799 Mdot
.5308 .48106 Mdot
.44794 .61392 Mdot
.43461 .61122 Mdot
.48633 .28499 Mdot
.54516 .30138 Mdot
.51995 .54175 Mdot
.42951 .66067 Mdot
.46289 .63105 Mdot
.46402 .3012 Mdot
.38858 .59828 Mdot
.43162 .75782 Mdot
.64969 .43148 Mdot
.6462 .56741 Mdot
.64436 .3822 Mdot
.66109 .43122 Mdot
.67332 .74184 Mdot
.2937 .49215 Mdot
.67202 .37742 Mdot
.63504 .3604 Mdot
.44649 .38135 Mdot
.63882 .73328 Mdot
.38886 .3501 Mdot
.45764 .53797 Mdot
.52594 .29966 Mdot
.42787 .59135 Mdot
.69011 .60077 Mdot
.31935 .36725 Mdot
.76472 .42369 Mdot
.31009 .69039 Mdot
.40843 .64642 Mdot
.52551 .31029 Mdot
.51019 .53163 Mdot
.45302 .64535 Mdot
.2404 .47352 Mdot
.39499 .5918 Mdot
.52962 .2753 Mdot
.64293 .73008 Mdot
.59657 .4235 Mdot
.65057 .44475 Mdot
.60238 .59125 Mdot
.3918 .61109 Mdot
.68415 .60188 Mdot
.68341 .41337 Mdot
.35934 .32503 Mdot
.37923 .3194 Mdot
.38142 .59848 Mdot
.39666 .50013 Mdot
.40838 .36228 Mdot
.44812 .60675 Mdot
.45059 .63007 Mdot
.52704 .51854 Mdot
.44961 .63463 Mdot
.36221 .64065 Mdot
.42486 .64465 Mdot
.38132 .64943 Mdot
.6358 .41451 Mdot
.67311 .73005 Mdot
.44277 .65175 Mdot
.4412 .57093 Mdot
.67849 .42111 Mdot
.44424 .57068 Mdot
.65569 .41377 Mdot
.73829 .38081 Mdot
.6627 .36897 Mdot
.37704 .32045 Mdot
.5084 .26369 Mdot
.73338 .66855 Mdot
.63501 .57673 Mdot
.66651 .4224 Mdot
.35861 .34513 Mdot
.66195 .41544 Mdot
.52694 .29125 Mdot
.61455 .44723 Mdot
.6119 .61093 Mdot
.32983 .47274 Mdot
.63732 .74351 Mdot
.60737 .35786 Mdot
.53493 .28665 Mdot
.6372 .57659 Mdot
.71396 .4245 Mdot
.41636 .63911 Mdot
.37333 .31499 Mdot
.39413 .59916 Mdot
.67363 .39754 Mdot
.52598 .30353 Mdot
.71727 .67168 Mdot
.37974 .32735 Mdot
.83656 .59074 Mdot
.46558 .31226 Mdot
.37137 .6052 Mdot
.67902 .42204 Mdot
.68549 .44179 Mdot
.63635 .4006 Mdot
.24019 .5708 Mdot
.54923 .4798 Mdot
.35016 .38798 Mdot
.64217 .58693 Mdot
.55552 .50718 Mdot
.25673 .72858 Mdot
.78926 .49999 Mdot
.67354 .59788 Mdot
.56293 .28933 Mdot
.39049 .58493 Mdot
.41542 .64851 Mdot
.48173 .61677 Mdot
.67748 .62223 Mdot
.40019 .64473 Mdot
.53893 .52225 Mdot
.28804 .48249 Mdot
.60267 .60302 Mdot
.47433 .32751 Mdot
.44027 .59772 Mdot
.6819 .42218 Mdot
.66241 .42545 Mdot
.55067 .51234 Mdot
.65294 .3754 Mdot
.44666 .58514 Mdot
.64087 .57852 Mdot
.48666 .45349 Mdot
.40373 .32613 Mdot
.79522 .55186 Mdot
.41919 .31991 Mdot
.39716 .3597 Mdot
.38106 .5713 Mdot
.49026 .30354 Mdot
.7067 .27247 Mdot
.4112 .64229 Mdot
.66633 .58889 Mdot
.36936 .60328 Mdot
.42291 .64791 Mdot
.45217 .59081 Mdot
.51768 .28396 Mdot
.28812 .50393 Mdot
.38845 .59919 Mdot
.68372 .39788 Mdot
.42616 .49269 Mdot
.40262 .5508 Mdot
.52649 .44959 Mdot
.43137 .48371 Mdot
.60639 .37128 Mdot
.68024 .56161 Mdot
.48805 .29814 Mdot
.65086 .59443 Mdot
.65376 .6269 Mdot
.64271 .60415 Mdot
.67924 .64752 Mdot
.47169 .76974 Mdot
.70162 .25154 Mdot
.60384 .65981 Mdot
.63846 .74616 Mdot
.6439 .62534 Mdot
.58914 .21173 Mdot
.67803 .59538 Mdot
.64372 .6052 Mdot
.82387 .42455 Mdot
.66917 .61546 Mdot
.41629 .58967 Mdot
.38373 .5798 Mdot
.53286 .81766 Mdot
.3636 .36459 Mdot
.43216 .58013 Mdot
.37903 .6503 Mdot
.36735 .30917 Mdot
.74696 .61656 Mdot
.50572 .54317 Mdot
.3136 .5068 Mdot
.54026 .50738 Mdot
.40628 .59925 Mdot
.3995 .62505 Mdot
.39488 .54689 Mdot
.26964 .70172 Mdot
.38456 .3876 Mdot
.66174 .61764 Mdot
.34865 .61651 Mdot
.59826 .35877 Mdot
.41316 .62945 Mdot
.37075 .61685 Mdot
.45392 .59794 Mdot
.48791 .29972 Mdot
.63184 .56734 Mdot
.4944 .58893 Mdot
.80355 .52691 Mdot
.42496 .61498 Mdot
.40262 .308 Mdot
.34131 .33108 Mdot
.40452 .58711 Mdot
.65861 .61421 Mdot
.41234 .64816 Mdot
.65937 .56054 Mdot
.63877 .58966 Mdot
.47696 .61417 Mdot
.70912 .64268 Mdot
.64222 .56157 Mdot
.44762 .61487 Mdot
.52262 .27606 Mdot
.7932 .57218 Mdot
.40895 .5831 Mdot
.37982 .33409 Mdot
.40851 .6148 Mdot
.39511 .34787 Mdot
.42493 .65621 Mdot
.52746 .51577 Mdot
.37436 .74615 Mdot
.49618 .32377 Mdot
.4098 .34626 Mdot
.53917 .29048 Mdot
.36451 .58015 Mdot
.71014 .6169 Mdot
.60404 .43417 Mdot
.4138 .37269 Mdot
.52824 .51805 Mdot
.28502 .40767 Mdot
.44701 .48814 Mdot
.65186 .36388 Mdot
.68356 .57642 Mdot
.66532 .72335 Mdot
.52282 .44846 Mdot
.46822 .32487 Mdot
.49079 .27122 Mdot
.57573 .39344 Mdot
.83583 .45108 Mdot
.38998 .58076 Mdot
.53958 .46277 Mdot
.46234 .72774 Mdot
.49971 .56198 Mdot
.50823 .55495 Mdot
.46771 .30109 Mdot
.43319 .58066 Mdot
.2684 .49038 Mdot
.50775 .28631 Mdot
.39699 .33721 Mdot
.67375 .6074 Mdot
.36047 .33915 Mdot
.72794 .46727 Mdot
.69325 .68068 Mdot
.50138 .29003 Mdot
.38792 .64998 Mdot
.42652 .57921 Mdot
.692 .61062 Mdot
.50699 .66348 Mdot
.65218 .5639 Mdot
.39317 .31541 Mdot
.50565 .32612 Mdot
.26789 .25866 Mdot
.40012 .6153 Mdot
.65652 .57732 Mdot
.44383 .29414 Mdot
.42022 .61211 Mdot
.65074 .41949 Mdot
.39868 .64383 Mdot
.66354 .57577 Mdot
.4483 .63754 Mdot
.64152 .58769 Mdot
.51556 .27597 Mdot
.38134 .59248 Mdot
.39026 .62124 Mdot
.27183 .42612 Mdot
.39424 .32974 Mdot
.64669 .56117 Mdot
.27156 .50352 Mdot
.36535 .60337 Mdot
.23367 .49037 Mdot
.38604 .60092 Mdot
.63178 .74102 Mdot
.35212 .66493 Mdot
.53898 .52008 Mdot
.36909 .60208 Mdot
.4066 .58318 Mdot
.50788 .66051 Mdot
.59416 .65758 Mdot
.6546 .67464 Mdot
.65149 .42285 Mdot
.68431 .58446 Mdot
.50293 .2841 Mdot
.52101 .32891 Mdot
.51225 .3131 Mdot
.37718 .30298 Mdot
.36901 .65419 Mdot
.41897 .58236 Mdot
.63304 .36861 Mdot
.38613 .31691 Mdot
.65331 .58172 Mdot
.37241 .32333 Mdot
.29691 .49757 Mdot
.38271 .33536 Mdot
.52889 .53575 Mdot
.57998 .31056 Mdot
.44024 .7597 Mdot
.38592 .34312 Mdot
.64312 .57005 Mdot
.41064 .501 Mdot
.49436 .56208 Mdot
.77925 .64533 Mdot
.34622 .32202 Mdot
.5639 .28431 Mdot
.42613 .57137 Mdot
.28956 .54241 Mdot
.65746 .41166 Mdot
.36012 .33956 Mdot
.66446 .37539 Mdot
.41318 .6475 Mdot
.60209 .55993 Mdot
.6728 .58384 Mdot
.65301 .43276 Mdot
.36758 .61385 Mdot
.35954 .33879 Mdot
.50035 .29356 Mdot
.6382 .73238 Mdot
.62398 .41488 Mdot
.39918 .41135 Mdot
.24529 .47005 Mdot
.52082 .32073 Mdot
.61245 .7317 Mdot
.6616 .37021 Mdot
.34885 .61422 Mdot
.37678 .54423 Mdot
.35902 .60177 Mdot
.48157 .2839 Mdot
.49714 .29853 Mdot
.64711 .33556 Mdot
.39144 .62337 Mdot
.45374 .63484 Mdot
.66664 .55364 Mdot
.51474 .32476 Mdot
.64178 .60309 Mdot
.70654 .60518 Mdot
.49145 .27727 Mdot
.65834 .5621 Mdot
.37156 .33699 Mdot
.25209 .52892 Mdot
.66299 .37083 Mdot
.6393 .41303 Mdot
.49905 .29015 Mdot
.48291 .31535 Mdot
.49044 .30436 Mdot
.37258 .62963 Mdot
.63772 .59278 Mdot
.41287 .6364 Mdot
.39425 .6124 Mdot
.50287 .5365 Mdot
.70551 .57999 Mdot
.39952 .6357 Mdot
.49558 .45814 Mdot
.34525 .31599 Mdot
.51139 .3041 Mdot
.66355 .38535 Mdot
.37281 .41402 Mdot
.68089 .38733 Mdot
.36907 .59041 Mdot
.76945 .60574 Mdot
.68508 .58808 Mdot
.38568 .32369 Mdot
.42852 .48449 Mdot
.3817 .32548 Mdot
.65091 .43184 Mdot
.63643 .5531 Mdot
.32652 .49261 Mdot
.38689 .62022 Mdot
.28691 .49548 Mdot
.24648 .38103 Mdot
.77708 .56101 Mdot
.6685 .39451 Mdot
.4074 .64997 Mdot
.54381 .51515 Mdot
.48393 .77245 Mdot
.41493 .58103 Mdot
.4045 .55455 Mdot
.38946 .48787 Mdot
.3746 .58492 Mdot
.62935 .60302 Mdot
.45494 .46976 Mdot
.39455 .65668 Mdot
.35622 .60372 Mdot
.74996 .34182 Mdot
.42699 .57495 Mdot
.3842 .61493 Mdot
.42367 .59431 Mdot
.40149 .64104 Mdot
.70774 .59064 Mdot
.46437 .45375 Mdot
.6823 .41409 Mdot
.25177 .52883 Mdot
.67125 .38003 Mdot
.49301 .28695 Mdot
.42354 .41427 Mdot
.67796 .56311 Mdot
.3822 .32589 Mdot
.55303 .45918 Mdot
.26008 .5716 Mdot
.524 .27945 Mdot
.28477 .39927 Mdot
.37137 .35277 Mdot
.50173 .56736 Mdot
.40626 .33068 Mdot
.47193 .29108 Mdot
.65147 .41837 Mdot
.37528 .60068 Mdot
.63217 .59494 Mdot
.65741 .5695 Mdot
.36563 .58447 Mdot
.80895 .5388 Mdot
.64552 .41973 Mdot
.50978 .37131 Mdot
.40407 .57636 Mdot
.36583 .60615 Mdot
.67004 .56259 Mdot
.52074 .31633 Mdot
.44744 .48673 Mdot
.38217 .34879 Mdot
.4174 .62507 Mdot
.39015 .65335 Mdot
.29542 .49699 Mdot
.65611 .42465 Mdot
.52673 .53186 Mdot
.43049 .58547 Mdot
.30612 .49524 Mdot
.3936 .64331 Mdot
.36626 .57261 Mdot
.52265 .27336 Mdot
.48163 .60377 Mdot
.39849 .62833 Mdot
.6022 .5934 Mdot
.65903 .36923 Mdot
.66102 .59223 Mdot
.61136 .57852 Mdot
.52822 .5161 Mdot
.63906 .39437 Mdot
.39145 .63522 Mdot
.62935 .41554 Mdot
.419 .64811 Mdot
.39589 .60664 Mdot
.66968 .39759 Mdot
.6471 .6042 Mdot
.74249 .42374 Mdot
.67352 .72895 Mdot
.4328 .64357 Mdot
.41288 .61365 Mdot
.36355 .3645 Mdot
.31649 .35124 Mdot
.38894 .62496 Mdot
.63862 .57372 Mdot
.41685 .61483 Mdot
.63579 .38238 Mdot
.36632 .31875 Mdot
.67099 .58986 Mdot
.529 .31375 Mdot
.51445 .27654 Mdot
.45806 .2831 Mdot
.52854 .53622 Mdot
.45449 .63024 Mdot
.67349 .5529 Mdot
.70813 .58311 Mdot
.27086 .53167 Mdot
.51424 .3016 Mdot
.36337 .32616 Mdot
.44162 .59035 Mdot
.50664 .562 Mdot
.6703 .42581 Mdot
.87777 .39935 Mdot
.32364 .49298 Mdot
.34144 .31882 Mdot
.44024 .42019 Mdot
.52129 .52536 Mdot
.41836 .57264 Mdot
.35659 .33184 Mdot
.49569 .2771 Mdot
.4146 .6488 Mdot
.35425 .66403 Mdot
.56283 .27769 Mdot
.4862 .31076 Mdot
.62977 .41788 Mdot
.53275 .30117 Mdot
.38023 .35386 Mdot
.53279 .53286 Mdot
.67585 .57586 Mdot
.39944 .58804 Mdot
.4561 .64413 Mdot
.52181 .29876 Mdot
.54541 .52718 Mdot
.38563 .58043 Mdot
.68779 .58698 Mdot
.51768 .30884 Mdot
.41105 .59858 Mdot
.49532 .76688 Mdot
.73483 .66639 Mdot
.52759 .30295 Mdot
.43192 .61903 Mdot
.5288 .59461 Mdot
.48481 .30754 Mdot
.47283 .29131 Mdot
.40184 .65126 Mdot
.35584 .33722 Mdot
.41045 .62472 Mdot
.64539 .41332 Mdot
.28354 .50058 Mdot
.64163 .38896 Mdot
.23883 .47407 Mdot
.37169 .64097 Mdot
.33353 .57817 Mdot
.6828 .62669 Mdot
.41571 .34015 Mdot
.21072 .59501 Mdot
.37581 .57667 Mdot
.73069 .57726 Mdot
.28494 .50546 Mdot
.34214 .47972 Mdot
.68896 .53982 Mdot
.37483 .34928 Mdot
.66405 .41163 Mdot
.38248 .60506 Mdot
.73524 .41899 Mdot
.37432 .34724 Mdot
.2382 .476 Mdot
.4304 .6277 Mdot
.66161 .58297 Mdot
.39847 .57836 Mdot
.67391 .57657 Mdot
.42636 .60378 Mdot
.74763 .66065 Mdot
.40571 .3644 Mdot
.24044 .57124 Mdot
.50087 .56672 Mdot
.68482 .44204 Mdot
.63756 .74391 Mdot
.36826 .33107 Mdot
.44283 .64148 Mdot
.51798 .53121 Mdot
.66014 .42067 Mdot
.62201 .46531 Mdot
.49415 .3071 Mdot
.68285 .39589 Mdot
.65371 .60334 Mdot
.48558 .2677 Mdot
.5509 .51926 Mdot
.32688 .67024 Mdot
.35772 .33696 Mdot
.63848 .39562 Mdot
.40414 .5848 Mdot
.35992 .60245 Mdot
.52231 .22849 Mdot
.20629 .37025 Mdot
.70989 .60177 Mdot
.85193 .56858 Mdot
.64258 .55173 Mdot
.39572 .3256 Mdot
.51609 .27054 Mdot
.41491 .60353 Mdot
.43675 .6008 Mdot
.48817 .31256 Mdot
.69425 .60626 Mdot
.40038 .35616 Mdot
.34483 .38385 Mdot
.63708 .36878 Mdot
.21603 .3867 Mdot
.67425 .58846 Mdot
.21663 .38496 Mdot
.46667 .35211 Mdot
.73003 .64661 Mdot
.21433 .56735 Mdot
.66275 .39643 Mdot
.21555 .38655 Mdot
.66073 .58021 Mdot
.39958 .57257 Mdot
.52996 .52112 Mdot
.54019 .53013 Mdot
.68197 .60084 Mdot
.48498 .28749 Mdot
.37159 .35163 Mdot
.3994 .5793 Mdot
.34682 .67675 Mdot
.50667 .66467 Mdot
.48665 .32343 Mdot
.48976 .59155 Mdot
.65805 .38772 Mdot
.41788 .61265 Mdot
.37267 .30837 Mdot
.66166 .39704 Mdot
.53579 .51021 Mdot
.25583 .56603 Mdot
.43638 .61552 Mdot
.4147 .49307 Mdot
.6545 .40988 Mdot
.31454 .35118 Mdot
.3925 .62234 Mdot
.66163 .37029 Mdot
.45824 .64064 Mdot
.60175 .34642 Mdot
.47597 .46862 Mdot
.78858 .50013 Mdot
.45724 .30272 Mdot
.53162 .2929 Mdot
.32303 .20928 Mdot
.39023 .20219 Mdot
.67863 .39619 Mdot
.50864 .53555 Mdot
.21022 .36151 Mdot
.65744 .37139 Mdot
.38703 .62887 Mdot
.38569 .59187 Mdot
.64344 .72984 Mdot
.49804 .5586 Mdot
.51245 .54388 Mdot
.58701 .59362 Mdot
.44958 .59269 Mdot
.49108 .58686 Mdot
.38796 .61478 Mdot
.66751 .61846 Mdot
.65773 .3903 Mdot
.39296 .82367 Mdot
.63684 .42114 Mdot
.33022 .58731 Mdot
.52604 .30024 Mdot
.46157 .28987 Mdot
.40374 .5882 Mdot
.56034 .5585 Mdot
.58764 .85497 Mdot
.38433 .5946 Mdot
.42774 .48502 Mdot
.24603 .46698 Mdot
.35961 .6456 Mdot
.62531 .57852 Mdot
.45947 .64005 Mdot
.69879 .56765 Mdot
.6647 .40153 Mdot
.37448 .34893 Mdot
.41852 .33856 Mdot
.66255 .41156 Mdot
.43554 .59834 Mdot
.41887 .32439 Mdot
.40071 .59608 Mdot
.41693 .57478 Mdot
.30496 .49938 Mdot
.38036 .30922 Mdot
.4847 .2969 Mdot
.37906 .32084 Mdot
.65187 .61006 Mdot
.86942 .50312 Mdot
.36901 .32641 Mdot
.63915 .7331 Mdot
.27493 .50238 Mdot
.21648 .36053 Mdot
.66234 .56881 Mdot
.40439 .32778 Mdot
.6674 .41145 Mdot
.3402 .49986 Mdot
.60393 .76087 Mdot
.67965 .38529 Mdot
.42382 .58284 Mdot
.70884 .59364 Mdot
.63423 .55509 Mdot
.68591 .39677 Mdot
.67834 .57489 Mdot
.36602 .65998 Mdot
.44472 .62513 Mdot
.68376 .40996 Mdot
.24036 .67052 Mdot
.63739 .4122 Mdot
.6848 .7331 Mdot
.45255 .63148 Mdot
.66826 .58946 Mdot
.62952 .74497 Mdot
.60883 .57409 Mdot
.54243 .52482 Mdot
.37839 .61606 Mdot
.3659 .32548 Mdot
.26582 .52317 Mdot
.52763 .31028 Mdot
.76198 .594 Mdot
.65238 .57255 Mdot
.68615 .39204 Mdot
.67844 .57567 Mdot
.68128 .57258 Mdot
.65869 .43307 Mdot
.68397 .58847 Mdot
.4267 .61345 Mdot
.75402 .66134 Mdot
.66561 .56606 Mdot
.65464 .4015 Mdot
.39475 .31731 Mdot
.64169 .57015 Mdot
.49886 .37764 Mdot
.44032 .59092 Mdot
.48952 .33012 Mdot
.3232 .33514 Mdot
.7041 .60572 Mdot
.36689 .33075 Mdot
.5203 .3017 Mdot
.35232 .33964 Mdot
.72487 .37814 Mdot
.70923 .42467 Mdot
.38459 .70711 Mdot
.59484 .34755 Mdot
.66562 .61487 Mdot
.47978 .26929 Mdot
.43057 .6162 Mdot
.40797 .57506 Mdot
.3663 .30533 Mdot
.61933 .58484 Mdot
.81467 .52706 Mdot
.50271 .55072 Mdot
.7957 .55035 Mdot
.65173 .42337 Mdot
.48484 .37429 Mdot
.32738 .49019 Mdot
.6116 .41726 Mdot
.39854 .65848 Mdot
.52165 .52567 Mdot
.40814 .59376 Mdot
.2685 .43627 Mdot
.37999 .35335 Mdot
.5888 .22782 Mdot
.36112 .6213 Mdot
.4913 .31556 Mdot
.42435 .60221 Mdot
.525 .47166 Mdot
.35562 .61309 Mdot
.34722 .31267 Mdot
.64835 .35874 Mdot
.6353 .57631 Mdot
.40324 .33824 Mdot
.51207 .27522 Mdot
.24218 .59772 Mdot
.39615 .63127 Mdot
.44407 .58309 Mdot
.47969 .29756 Mdot
.63707 .60104 Mdot
.49335 .29208 Mdot
.66383 .3716 Mdot
.37177 .32673 Mdot
.38948 .63928 Mdot
.48909 .58754 Mdot
.54007 .32411 Mdot
.67197 .42076 Mdot
.5041 .26587 Mdot
.63222 .41923 Mdot
.52734 .52059 Mdot
.35332 .60523 Mdot
.51803 .26558 Mdot
.40438 .65871 Mdot
.60111 .70262 Mdot
.26156 .56581 Mdot
.52077 .63777 Mdot
.48202 .28827 Mdot
.39467 .19141 Mdot
.6596 .399 Mdot
.63853 .3857 Mdot
.69121 .73056 Mdot
.65054 .81839 Mdot
.43129 .49149 Mdot
.81616 .49688 Mdot
.66383 .3714 Mdot
.64945 .40889 Mdot
.49012 .29335 Mdot
.65651 .60994 Mdot
.68264 .6251 Mdot
.49221 .26845 Mdot
.22746 .52255 Mdot
.65347 .58149 Mdot
.55545 .81799 Mdot
.48344 .32537 Mdot
.45098 .58251 Mdot
.72654 .66815 Mdot
.34649 .31629 Mdot
.25432 .46433 Mdot
.61313 .44785 Mdot
.41673 .59611 Mdot
.71208 .26535 Mdot
.49638 .30701 Mdot
.51704 .54715 Mdot
.68731 .36562 Mdot
.36567 .6203 Mdot
.42657 .597 Mdot
.42006 .61621 Mdot
.34795 .30474 Mdot
.57605 .66437 Mdot
.41609 .59941 Mdot
.25048 .57009 Mdot
.43075 .5561 Mdot
.54623 .2364 Mdot
.37855 .32088 Mdot
.28632 .38576 Mdot
.54841 .27981 Mdot
.80488 .51814 Mdot
.39497 .55912 Mdot
.64378 .37202 Mdot
.50858 .46075 Mdot
.6708 .39639 Mdot
.61352 .36482 Mdot
.19829 .42186 Mdot
.63032 .60233 Mdot
.36401 .62459 Mdot
.47537 .31725 Mdot
.68991 .62409 Mdot
.50359 .45853 Mdot
.87104 .51442 Mdot
.68056 .37696 Mdot
.8096 .7103 Mdot
.64509 .37686 Mdot
.52303 .54107 Mdot
.65906 .60434 Mdot
.55628 .58962 Mdot
.28851 .49469 Mdot
.64308 .60354 Mdot
.44765 .2037 Mdot
.70295 .5712 Mdot
.19841 .50594 Mdot
.61558 .61347 Mdot
.65158 .39665 Mdot
.68622 .39619 Mdot
.36328 .66878 Mdot
.40935 .6262 Mdot
.27982 .48446 Mdot
.50093 .55569 Mdot
.43906 .61403 Mdot
.50811 .28611 Mdot
.59386 .34535 Mdot
.7352 .41115 Mdot
.68266 .59133 Mdot
.67592 .41699 Mdot
.42522 .59957 Mdot
.43367 .64373 Mdot
.37826 .58543 Mdot
.4252 .37996 Mdot
.54538 .82069 Mdot
.39279 .60687 Mdot
.36181 .58184 Mdot
.52045 .27638 Mdot
.52057 .22748 Mdot
.84008 .48797 Mdot
.20599 .40321 Mdot
.40684 .56587 Mdot
.39214 .32392 Mdot
.38207 .30711 Mdot
.35219 .65504 Mdot
.55934 .58176 Mdot
.35325 .29031 Mdot
.40467 .58458 Mdot
.24872 .58846 Mdot
.51508 .33333 Mdot
.54927 .51313 Mdot
.52125 .29842 Mdot
.66639 .6292 Mdot
.54113 .51439 Mdot
.50276 .28002 Mdot
.2383 .55729 Mdot
.51873 .52232 Mdot
.6134 .3431 Mdot
.40299 .32293 Mdot
.38983 .61823 Mdot
.67624 .70955 Mdot
.51587 .32474 Mdot
.64342 .40708 Mdot
.66042 .60013 Mdot
.65047 .42189 Mdot
.56907 .2765 Mdot
.23139 .50309 Mdot
.53908 .52597 Mdot
.64256 .37322 Mdot
.4111 .49562 Mdot
.38889 .32093 Mdot
.6514 .37418 Mdot
.36252 .55047 Mdot
.40976 .54861 Mdot
.56191 .84602 Mdot
.44259 .58452 Mdot
.64867 .33628 Mdot
.63698 .39612 Mdot
.54279 .51023 Mdot
.39795 .58921 Mdot
.46625 .31553 Mdot
.37473 .68573 Mdot
.40078 .59755 Mdot
.52861 .31681 Mdot
.38741 .59088 Mdot
.36069 .31824 Mdot
.64317 .54998 Mdot
.28622 .50952 Mdot
.4133 .40868 Mdot
.38313 .3514 Mdot
.2723 .56216 Mdot
.38732 .62425 Mdot
.41559 .20341 Mdot
.65928 .58486 Mdot
.36981 .58896 Mdot
.23255 .45247 Mdot
.67242 .61036 Mdot
.64839 .59283 Mdot
.45136 .61858 Mdot
.6319 .39566 Mdot
.48242 .296 Mdot
.38551 .32002 Mdot
.62647 .42488 Mdot
.41215 .59988 Mdot
.40732 .64957 Mdot
.38722 .3502 Mdot
.64083 .40135 Mdot
.38949 .63816 Mdot
.72752 .52067 Mdot
.25289 .5361 Mdot
.64998 .43071 Mdot
.40168 .55102 Mdot
.59029 .80914 Mdot
.69361 .5863 Mdot
.70986 .26256 Mdot
.40409 .36547 Mdot
.4999 .27159 Mdot
.48552 .60287 Mdot
.87834 .42329 Mdot
.39456 .31632 Mdot
.78823 .54804 Mdot
.39373 .57704 Mdot
.41197 .60851 Mdot
.66598 .61694 Mdot
.41003 .63561 Mdot
.68511 .58619 Mdot
.46508 .38081 Mdot
.67729 .80103 Mdot
.66785 .57058 Mdot
.66919 .57727 Mdot
.42954 .53245 Mdot
.42774 .33859 Mdot
.6732 .60624 Mdot
.40142 .63074 Mdot
.45304 .18423 Mdot
.33926 .60241 Mdot
.38999 .35874 Mdot
.33699 .31091 Mdot
.62846 .57613 Mdot
.6044 .76621 Mdot
.38725 .54292 Mdot
.55365 .80372 Mdot
.34654 .29165 Mdot
.67761 .39141 Mdot
.4204 .65283 Mdot
.50885 .5387 Mdot
.51251 .30704 Mdot
.46337 .6344 Mdot
.39372 .62189 Mdot
.6282 .59244 Mdot
.34328 .32713 Mdot
.65872 .37347 Mdot
.41581 .66092 Mdot
.4992 .33633 Mdot
.38808 .3464 Mdot
.6692 .56418 Mdot
.65435 .74794 Mdot
.41471 .3189 Mdot
.48994 .60156 Mdot
.40847 .5694 Mdot
.44636 .64612 Mdot
.50534 .56596 Mdot
.6619 .41027 Mdot
.48097 .27451 Mdot
.48893 .60271 Mdot
.31873 .51346 Mdot
.24463 .5291 Mdot
.39153 .56859 Mdot
.63996 .57201 Mdot
.66648 .42072 Mdot
.53015 .53327 Mdot
.21374 .35723 Mdot
.42702 .57016 Mdot
.55583 .81847 Mdot
.37323 .4024 Mdot
.51484 .53014 Mdot
.69634 .62203 Mdot
.3837 .32299 Mdot
.4511 .63275 Mdot
.24673 .56958 Mdot
.437 .61828 Mdot
.34816 .61911 Mdot
.4875 .27896 Mdot
.6696 .38342 Mdot
.381 .70556 Mdot
.50868 .30513 Mdot
.65 .59392 Mdot
.51602 .80798 Mdot
.69555 .6161 Mdot
.70688 .60566 Mdot
.71905 .63733 Mdot
.64099 .41237 Mdot
.87887 .41887 Mdot
.31714 .3463 Mdot
.37949 .58991 Mdot
.66261 .36618 Mdot
.67346 .60271 Mdot
.39573 .63388 Mdot
.68519 .58767 Mdot
.62885 .57119 Mdot
.44526 .60174 Mdot
.44557 .61057 Mdot
.24381 .57403 Mdot
.58685 .80459 Mdot
.37276 .31548 Mdot
.69179 .60892 Mdot
.59359 .79126 Mdot
.41281 .60427 Mdot
.40204 .6263 Mdot
.51115 .46104 Mdot
.40238 .3431 Mdot
.40695 .76807 Mdot
.40299 .57472 Mdot
.2716 .42224 Mdot
.38668 .62704 Mdot
.6213 .61084 Mdot
.65971 .44287 Mdot
.33998 .57009 Mdot
.50273 .26719 Mdot
.69383 .60807 Mdot
.34289 .32049 Mdot
.68778 .62968 Mdot
.45134 .7639 Mdot
.66252 .41665 Mdot
.66376 .57588 Mdot
.47925 .27353 Mdot
.64327 .39955 Mdot
.63684 .41065 Mdot
.50145 .45697 Mdot
.46776 .28661 Mdot
.3431 .32881 Mdot
.65686 .38247 Mdot
.50178 .7664 Mdot
.64911 .3969 Mdot
.44425 .77101 Mdot
.42723 .56721 Mdot
.24961 .56882 Mdot
.46026 .64368 Mdot
.34974 .66178 Mdot
.64745 .3844 Mdot
.38588 .34894 Mdot
.38546 .6358 Mdot
.6758 .57017 Mdot
.39314 .31852 Mdot
.69289 .6777 Mdot
.47086 .278 Mdot
.6562 .5524 Mdot
.62231 .40208 Mdot
.68368 .61125 Mdot
.24875 .46793 Mdot
.33876 .3302 Mdot
.5153 .44321 Mdot
.29909 .50844 Mdot
.49478 .5776 Mdot
.35821 .59643 Mdot
.37935 .63253 Mdot
.42968 .60992 Mdot
.52664 .29942 Mdot
.35536 .30223 Mdot
.64737 .56489 Mdot
.4033 .7206 Mdot
.63993 .40604 Mdot
.44576 .47692 Mdot
.5039 .56643 Mdot
.41739 .64769 Mdot
.67276 .60067 Mdot
.63584 .56517 Mdot
.58864 .65714 Mdot
.48936 .31035 Mdot
.34025 .63317 Mdot
.38165 .57232 Mdot
.36734 .7022 Mdot
.64508 .38602 Mdot
.77538 .50686 Mdot
.50777 .33282 Mdot
.81612 .70485 Mdot
.50903 .30348 Mdot
.48384 .43039 Mdot
.68794 .59517 Mdot
.37806 .33658 Mdot
.43582 .59072 Mdot
.62227 .63302 Mdot
.71181 .60647 Mdot
.46797 .2516 Mdot
.38291 .32846 Mdot
.73468 .36557 Mdot
.66843 .37318 Mdot
.41366 .6611 Mdot
.3867 .62745 Mdot
.42643 .63666 Mdot
.41733 .62864 Mdot
.68067 .40247 Mdot
.44107 .62223 Mdot
.62778 .41945 Mdot
.44643 .76136 Mdot
.22985 .45513 Mdot
.4712 .30085 Mdot
.5359 .21678 Mdot
.70693 .60031 Mdot
.44715 .79073 Mdot
.42269 .76391 Mdot
.26047 .56441 Mdot
.62419 .36143 Mdot
.37245 .65138 Mdot
.48635 .29236 Mdot
.7248 .4216 Mdot
.47105 .30333 Mdot
.44535 .84078 Mdot
.64558 .73011 Mdot
.71701 .34875 Mdot
.4264 .63335 Mdot
.48113 .28012 Mdot
.60529 .77198 Mdot
.47605 .628 Mdot
.41823 .32428 Mdot
.46745 .76661 Mdot
.66598 .67733 Mdot
.36984 .31512 Mdot
.43287 .58181 Mdot
.70653 .58184 Mdot
.43677 .59477 Mdot
.43552 .58802 Mdot
.38818 .57851 Mdot
.67374 .42809 Mdot
.42162 .56465 Mdot
.41843 .62061 Mdot
.22651 .30464 Mdot
.42097 .29622 Mdot
.53314 .29475 Mdot
.54063 .61131 Mdot
.38597 .3168 Mdot
.66511 .62929 Mdot
.29099 .50927 Mdot
.63525 .39352 Mdot
.58552 .65674 Mdot
.44848 .62422 Mdot
.77477 .57659 Mdot
.63128 .40765 Mdot
.35648 .34008 Mdot
.51129 .53685 Mdot
.7716 .41773 Mdot
.53401 .28005 Mdot
.51128 .54286 Mdot
.52358 .31721 Mdot
.35082 .71509 Mdot
.67791 .57997 Mdot
.49459 .5777 Mdot
.65921 .37603 Mdot
.46813 .3032 Mdot
.25501 .57456 Mdot
.41026 .61958 Mdot
.48187 .28659 Mdot
.47588 .62224 Mdot
.26605 .52 Mdot
.28544 .50419 Mdot
.47209 .28748 Mdot
.63557 .37248 Mdot
.64305 .3917 Mdot
.37971 .31146 Mdot
.68941 .58194 Mdot
.63422 .59939 Mdot
.64706 .39287 Mdot
.73976 .3272 Mdot
.41268 .59814 Mdot
.39682 .61089 Mdot
.32243 .50113 Mdot
.37607 .62397 Mdot
.3603 .36222 Mdot
.50814 .54583 Mdot
.63093 .58885 Mdot
.38204 .63383 Mdot
.3911 .63861 Mdot
.42227 .5709 Mdot
.22378 .52865 Mdot
.52366 .30283 Mdot
.45081 .59549 Mdot
.35752 .33501 Mdot
.68378 .67951 Mdot
.42772 .61725 Mdot
.48976 .60477 Mdot
.68928 .59279 Mdot
.57919 .39706 Mdot
.64449 .4089 Mdot
.48594 .32142 Mdot
.47851 .31869 Mdot
.23908 .39174 Mdot
.68867 .61746 Mdot
.51007 .54419 Mdot
.56262 .27542 Mdot
.52642 .53652 Mdot
.38407 .33111 Mdot
.46817 .47459 Mdot
.52984 .26165 Mdot
.53304 .29649 Mdot
.67803 .43574 Mdot
.36381 .59893 Mdot
.42274 .62069 Mdot
.80759 .52885 Mdot
.38584 .6044 Mdot
.3661 .32156 Mdot
.64859 .36426 Mdot
.66475 .57765 Mdot
.36005 .3158 Mdot
.64234 .37697 Mdot
.63945 .60176 Mdot
.43629 .56041 Mdot
.39185 .63106 Mdot
.65399 .59821 Mdot
.67445 .56586 Mdot
.41521 .58734 Mdot
.18946 .44901 Mdot
.63068 .58176 Mdot
.65898 .60183 Mdot
.67836 .67908 Mdot
.53384 .28213 Mdot
.37657 .68628 Mdot
.63672 .38129 Mdot
.418 .62006 Mdot
.47354 .30119 Mdot
.38858 .33792 Mdot
.64433 .57437 Mdot
.4163 .65428 Mdot
.40638 .60331 Mdot
.39099 .32365 Mdot
.40697 .32316 Mdot
.40256 .33303 Mdot
.6859 .39811 Mdot
.44756 .61587 Mdot
.66683 .60641 Mdot
.68008 .3878 Mdot
.36452 .30792 Mdot
.40475 .34379 Mdot
.19766 .53897 Mdot
.41581 .59354 Mdot
.3995 .31242 Mdot
.8695 .48854 Mdot
.22951 .5769 Mdot
.54941 .51789 Mdot
.44717 .30146 Mdot
.4 .18509 Mdot
.32026 .32875 Mdot
.67277 .38879 Mdot
.44351 .47603 Mdot
.37282 .35527 Mdot
.42805 .65828 Mdot
.40159 .61772 Mdot
.49189 .56755 Mdot
.39512 .32066 Mdot
.23095 .50145 Mdot
.63497 .60644 Mdot
.49801 .6948 Mdot
.38538 .31662 Mdot
.4664 .29543 Mdot
.53299 .32891 Mdot
.50063 .3003 Mdot
.35471 .6176 Mdot
.34239 .71612 Mdot
.49557 .75046 Mdot
.40312 .76306 Mdot
.6639 .36927 Mdot
.63296 .56711 Mdot
.71112 .67592 Mdot
.64694 .59148 Mdot
.51315 .31521 Mdot
.38366 .34923 Mdot
.65686 .6146 Mdot
.64127 .41571 Mdot
.64462 .38907 Mdot
.52532 .2702 Mdot
.51736 .29933 Mdot
.50097 .29173 Mdot
.69602 .59696 Mdot
.68665 .59208 Mdot
.41014 .639 Mdot
.6536 .56677 Mdot
.41538 .3761 Mdot
.44501 .37937 Mdot
.54954 .29965 Mdot
.65942 .4056 Mdot
.63904 .58851 Mdot
.38737 .61676 Mdot
.40254 .47477 Mdot
.56059 .30099 Mdot
.34825 .31649 Mdot
.76106 .658 Mdot
.636 .83135 Mdot
.37557 .6357 Mdot
.67644 .40992 Mdot
.50839 .55061 Mdot
.42884 .60758 Mdot
.4965 .27101 Mdot
.34772 .39419 Mdot
.51788 .52155 Mdot
.43891 .60779 Mdot
.42806 .55846 Mdot
.65951 .41966 Mdot
.29387 .51111 Mdot
.4201 .65991 Mdot
.48165 .45137 Mdot
.64416 .36247 Mdot
.52009 .33048 Mdot
.35499 .18688 Mdot
.59351 .59957 Mdot
.28972 .42128 Mdot
.53985 .51282 Mdot
.4254 .56871 Mdot
.51185 .28605 Mdot
.3527 .3226 Mdot
.51101 .29082 Mdot
.64699 .62623 Mdot
.53137 .27852 Mdot
.3837 .60128 Mdot
.66876 .60775 Mdot
.63891 .39638 Mdot
.36204 .48034 Mdot
.44064 .70167 Mdot
.46907 .31935 Mdot
.54397 .52938 Mdot
.44522 .6092 Mdot
.49809 .77097 Mdot
.35039 .66283 Mdot
.40088 .62819 Mdot
.66966 .39632 Mdot
.67996 .59502 Mdot
.65626 .42338 Mdot
.37084 .68486 Mdot
.61485 .54046 Mdot
.64682 .41238 Mdot
.36359 .54546 Mdot
.37444 .35322 Mdot
.22891 .51249 Mdot
.39904 .58323 Mdot
.662 .37652 Mdot
.44436 .59263 Mdot
.68767 .61336 Mdot
.24099 .54671 Mdot
.25581 .54474 Mdot
.66027 .39045 Mdot
.54565 .47392 Mdot
.27197 .50605 Mdot
.37831 .68636 Mdot
.66885 .3767 Mdot
.22815 .61237 Mdot
.52034 .53376 Mdot
.38714 .34552 Mdot
.40845 .33375 Mdot
.37183 .34224 Mdot
.39525 .61326 Mdot
.61676 .78451 Mdot
.38664 .31169 Mdot
.67069 .36057 Mdot
.35958 .32511 Mdot
.39316 .41158 Mdot
.81122 .53645 Mdot
.37732 .35292 Mdot
.39336 .58912 Mdot
.32159 .62066 Mdot
.43587 .48081 Mdot
.45875 .30605 Mdot
.75382 .42793 Mdot
.23547 .29389 Mdot
.41576 .60305 Mdot
.74752 .66258 Mdot
.60545 .57297 Mdot
.47851 .42448 Mdot
.25759 .55301 Mdot
.37165 .50666 Mdot
.64648 .59722 Mdot
.29645 .50949 Mdot
.69086 .57134 Mdot
.49698 .57964 Mdot
.39468 .60629 Mdot
.69297 .60996 Mdot
.76012 .59662 Mdot
.21055 .60249 Mdot
.79132 .56234 Mdot
.63704 .5925 Mdot
.65877 .36917 Mdot
.67381 .40283 Mdot
.66792 .393 Mdot
.52267 .28872 Mdot
.6661 .5745 Mdot
.44904 .58729 Mdot
.50893 .27283 Mdot
.42106 .57889 Mdot
.6542 .39028 Mdot
.25628 .55763 Mdot
.66881 .57786 Mdot
.40503 .58368 Mdot
.59843 .78179 Mdot
.51822 .32072 Mdot
.3913 .32168 Mdot
.75791 .65855 Mdot
.46192 .28042 Mdot
.62888 .40603 Mdot
.63533 .62103 Mdot
.42896 .29644 Mdot
.46249 .45361 Mdot
.39232 .56926 Mdot
.37573 .60266 Mdot
.44238 .47448 Mdot
.6523 .73324 Mdot
.40413 .65632 Mdot
.51325 .27589 Mdot
.53619 .28983 Mdot
.43963 .58456 Mdot
.66406 .5723 Mdot
.36811 .35609 Mdot
.39938 .30888 Mdot
.35906 .57987 Mdot
.28668 .49798 Mdot
.25078 .5699 Mdot
.39366 .63622 Mdot
.47389 .56594 Mdot
.47758 .27493 Mdot
.55058 .51671 Mdot
.2952 .49837 Mdot
.37026 .33654 Mdot
.40303 .57237 Mdot
.52142 .64384 Mdot
.65154 .574 Mdot
.48152 .28981 Mdot
.67986 .42403 Mdot
.41687 .32086 Mdot
.54783 .29786 Mdot
.43945 .58434 Mdot
.39031 .63832 Mdot
.65397 .37477 Mdot
.62593 .61382 Mdot
.39766 .3368 Mdot
.51172 .27306 Mdot
.37484 .33627 Mdot
.68051 .58507 Mdot
.64108 .57539 Mdot
.38047 .57897 Mdot
.34131 .64877 Mdot
.47765 .32385 Mdot
.35397 .62999 Mdot
.49228 .28236 Mdot
.52277 .22834 Mdot
.67074 .42556 Mdot
.37054 .58878 Mdot
.67103 .62599 Mdot
.65116 .38992 Mdot
.41953 .6014 Mdot
.45062 .46812 Mdot
.39877 .64298 Mdot
.47925 .2808 Mdot
.32929 .37932 Mdot
.3812 .34416 Mdot
.46446 .60322 Mdot
.63079 .6645 Mdot
.38045 .62866 Mdot
.52706 .32219 Mdot
.49163 .76011 Mdot
.65319 .41458 Mdot
.68613 .6033 Mdot
.57029 .30505 Mdot
.6525 .40035 Mdot
.39169 .58521 Mdot
.36896 .32543 Mdot
.65784 .56135 Mdot
.54187 .51733 Mdot
.28971 .47037 Mdot
.35943 .67342 Mdot
.34024 .62192 Mdot
.40992 .65805 Mdot
.81748 .50302 Mdot
.50406 .29138 Mdot
.67177 .60216 Mdot
.67677 .40575 Mdot
.65826 .417 Mdot
.52009 .31704 Mdot
.66032 .67358 Mdot
.78141 .60551 Mdot
.87328 .46605 Mdot
.55 .30717 Mdot
.36455 .33663 Mdot
.24238 .54753 Mdot
.49906 .30064 Mdot
.52908 .30701 Mdot
.4984 .25983 Mdot
.80876 .52229 Mdot
.64389 .60047 Mdot
.40655 .60427 Mdot
.74019 .66426 Mdot
.38728 .58062 Mdot
.29165 .42703 Mdot
.65449 .39133 Mdot
.68616 .60367 Mdot
.47686 .38836 Mdot
.35535 .6081 Mdot
.43128 .59688 Mdot
.50934 .37455 Mdot
.50244 .55284 Mdot
.21484 .36823 Mdot
.37156 .60018 Mdot
.51877 .29237 Mdot
.6931 .55104 Mdot
.49009 .59864 Mdot
.59931 .78233 Mdot
.64183 .38782 Mdot
.539 .52739 Mdot
.49385 .58929 Mdot
.4747 .56006 Mdot
.69429 .57427 Mdot
.64608 .61099 Mdot
.40662 .32817 Mdot
.75431 .62089 Mdot
.64069 .38823 Mdot
.78516 .4941 Mdot
.39904 .62881 Mdot
.60996 .36966 Mdot
.35271 .38963 Mdot
.42227 .59633 Mdot
.49826 .45663 Mdot
.58878 .65675 Mdot
.40755 .65239 Mdot
.41099 .7553 Mdot
.65771 .39951 Mdot
.24167 .44723 Mdot
.4349 .62568 Mdot
.48283 .2869 Mdot
.66252 .61195 Mdot
.65983 .55226 Mdot
.35377 .3177 Mdot
.39625 .37785 Mdot
.72758 .76962 Mdot
.68559 .60512 Mdot
.40981 .62086 Mdot
.64991 .41084 Mdot
.543 .52121 Mdot
.45766 .64503 Mdot
.54271 .46947 Mdot
.65002 .57547 Mdot
.48169 .61759 Mdot
.7747 .58017 Mdot
.29473 .50976 Mdot
.46687 .79994 Mdot
.66353 .38844 Mdot
.36314 .3298 Mdot
.35975 .57117 Mdot
.53621 .24334 Mdot
.38867 .62988 Mdot
.2909 .42527 Mdot
.61799 .55804 Mdot
.36401 .32377 Mdot
.43453 .59873 Mdot
.39485 .65565 Mdot
.27917 .56028 Mdot
.38847 .36052 Mdot
.41405 .65805 Mdot
.37057 .63249 Mdot
.65879 .61297 Mdot
.50972 .54556 Mdot
.66103 .57807 Mdot
.43478 .59181 Mdot
.2969 .35049 Mdot
.69056 .60819 Mdot
.74577 .4279 Mdot
.39643 .30567 Mdot
.63576 .38955 Mdot
.47972 .60612 Mdot
.40193 .56573 Mdot
.46576 .8067 Mdot
.54221 .52595 Mdot
.75263 .35646 Mdot
.47763 .28748 Mdot
.19775 .37235 Mdot
.46655 .27351 Mdot
.67721 .34238 Mdot
.60778 .45837 Mdot
.4871 .58677 Mdot
.65279 .67153 Mdot
.39321 .76467 Mdot
.63302 .36841 Mdot
.43232 .78999 Mdot
.40968 .62607 Mdot
.41227 .57016 Mdot
.48933 .28281 Mdot
.62221 .35784 Mdot
.3392 .57083 Mdot
.29406 .49788 Mdot
.35897 .34356 Mdot
.65841 .59078 Mdot
.39619 .61813 Mdot
.75634 .59765 Mdot
.4659 .30568 Mdot
.49563 .6692 Mdot
.40092 .58527 Mdot
.50298 .5516 Mdot
.62611 .3575 Mdot
.63833 .39668 Mdot
.47411 .28232 Mdot
.46546 .29291 Mdot
.41402 .56695 Mdot
.68276 .41055 Mdot
.41943 .64031 Mdot
.26994 .50921 Mdot
.48096 .61202 Mdot
.38707 .33202 Mdot
.38986 .6231 Mdot
.58183 .60508 Mdot
.24025 .70549 Mdot
.35733 .6049 Mdot
.70559 .60554 Mdot
.49724 .28912 Mdot
.52231 .30902 Mdot
.63366 .59707 Mdot
.52192 .31021 Mdot
.50062 .69415 Mdot
.61523 .78776 Mdot
.38179 .33285 Mdot
.46392 .74055 Mdot
.37314 .34803 Mdot
.53755 .52912 Mdot
.41589 .59138 Mdot
.60499 .21145 Mdot
.54845 .30927 Mdot
.37353 .41416 Mdot
.64907 .3937 Mdot
.53903 .53087 Mdot
.44572 .61569 Mdot
.33225 .31911 Mdot
.50333 .30826 Mdot
.52124 .54544 Mdot
.39101 .57638 Mdot
.6954 .60084 Mdot
.41486 .65018 Mdot
.50936 .55361 Mdot
.51231 .54437 Mdot
.38181 .65105 Mdot
.64227 .37702 Mdot
.68403 .58282 Mdot
.73306 .35736 Mdot
.52161 .32125 Mdot
.44196 .60838 Mdot
.41428 .619 Mdot
.65607 .55943 Mdot
.37929 .59284 Mdot
.6842 .4046 Mdot
.86051 .36275 Mdot
.40047 .34035 Mdot
.54971 .51493 Mdot
.72776 .46732 Mdot
.38056 .65142 Mdot
.37445 .63158 Mdot
.38747 .51467 Mdot
.50675 .66403 Mdot
.63745 .38521 Mdot
.3484 .63852 Mdot
.53294 .28847 Mdot
.39557 .34026 Mdot
.64327 .41893 Mdot
.44368 .62639 Mdot
.38704 .59433 Mdot
.36442 .3254 Mdot
.49883 .38193 Mdot
.40598 .34922 Mdot
.67695 .39273 Mdot
.55193 .49746 Mdot
.4051 .47335 Mdot
.40698 .59548 Mdot
.50601 .54786 Mdot
.6759 .59476 Mdot
.67577 .384 Mdot
.57547 .66829 Mdot
.4976 .57869 Mdot
.62238 .40617 Mdot
.63908 .39409 Mdot
.39237 .56985 Mdot
.69062 .61531 Mdot
.60658 .59817 Mdot
.67449 .59777 Mdot
.22817 .43827 Mdot
.73386 .34755 Mdot
.50096 .28835 Mdot
.65751 .40489 Mdot
.47613 .30456 Mdot
.37902 .35518 Mdot
.24877 .52245 Mdot
.46283 .30584 Mdot
.65453 .61953 Mdot
.47377 .30794 Mdot
.41526 .64064 Mdot
.63271 .39756 Mdot
.48975 .32759 Mdot
.4047 .63325 Mdot
.39455 .54689 Mdot
.50281 .55909 Mdot
.34939 .34164 Mdot
.28961 .50393 Mdot
.3974 .58091 Mdot
.51258 .53708 Mdot
.40896 .58617 Mdot
.68381 .4076 Mdot
.35631 .47013 Mdot
.44676 .59035 Mdot
.54847 .30984 Mdot
.787 .39825 Mdot
.5395 .29745 Mdot
.52147 .60648 Mdot
.42191 .58199 Mdot
.41033 .59524 Mdot
.44602 .60783 Mdot
.67267 .68269 Mdot
.62832 .41105 Mdot
.35116 .63851 Mdot
.50177 .26623 Mdot
.64365 .58889 Mdot
.6748 .61957 Mdot
.4165 .50152 Mdot
.50993 .54263 Mdot
.68554 .40648 Mdot
.41136 .59657 Mdot
.51161 .54787 Mdot
.31187 .48773 Mdot
.78697 .58131 Mdot
.44681 .2943 Mdot
.53281 .31243 Mdot
.69017 .57824 Mdot
.52766 .28948 Mdot
.4431 .6242 Mdot
.48394 .61244 Mdot
.73775 .3614 Mdot
.6878 .38323 Mdot
.39466 .34046 Mdot
.42536 .58139 Mdot
.21942 .54232 Mdot
.52021 .27627 Mdot
.4722 .28158 Mdot
.4216 .63962 Mdot
.61143 .55712 Mdot
.204 .64931 Mdot
.66273 .36582 Mdot
.51726 .77683 Mdot
.69427 .71899 Mdot
.31149 .68216 Mdot
.66247 .41299 Mdot
.49294 .45538 Mdot
.45808 .31051 Mdot
.285 .31932 Mdot
.64501 .59277 Mdot
.39675 .33719 Mdot
.40146 .63206 Mdot
.65178 .61827 Mdot
.55192 .30178 Mdot
.64582 .56348 Mdot
.492 .58346 Mdot
.63151 .40602 Mdot
.51609 .30662 Mdot
.68781 .41352 Mdot
.68416 .62679 Mdot
.37595 .34736 Mdot
.27235 .42599 Mdot
.49002 .76911 Mdot
.59321 .65705 Mdot
.4517 .59789 Mdot
.41306 .29543 Mdot
.45155 .59219 Mdot
.6333 .55435 Mdot
.39813 .58377 Mdot
.39985 .54926 Mdot
.45868 .29711 Mdot
.39093 .56894 Mdot
.39522 .62645 Mdot
.5961 .78558 Mdot
.42589 .59468 Mdot
.42994 .57723 Mdot
.38676 .57076 Mdot
.67863 .62133 Mdot
.38139 .58032 Mdot
.68677 .58076 Mdot
.78222 .5602 Mdot
.52066 .32121 Mdot
.38318 .35448 Mdot
.38097 .35378 Mdot
.30006 .41688 Mdot
.22066 .53827 Mdot
.72817 .66902 Mdot
.64953 .58203 Mdot
.64666 .38543 Mdot
.41511 .63948 Mdot
.19178 .57359 Mdot
.29582 .35959 Mdot
.4768 .32755 Mdot
.47389 .31903 Mdot
.42402 .62263 Mdot
.61577 .84153 Mdot
.37177 .60742 Mdot
.32445 .49336 Mdot
.39453 .6127 Mdot
.36879 .5939 Mdot
.49032 .2642 Mdot
.24999 .46679 Mdot
.45062 .59487 Mdot
.69768 .57737 Mdot
.39508 .33674 Mdot
.5054 .55167 Mdot
.29592 .37941 Mdot
.67566 .74051 Mdot
.5792 .5833 Mdot
.4485 .6005 Mdot
.50618 .27069 Mdot
.63364 .58124 Mdot
.31806 .50306 Mdot
.68015 .38883 Mdot
.28134 .47233 Mdot
.43713 .77028 Mdot
.63972 .35816 Mdot
.39034 .34464 Mdot
.55547 .31066 Mdot
.40567 .56671 Mdot
.51299 .28341 Mdot
.35591 .64057 Mdot
.31452 .48253 Mdot
.3844 .33394 Mdot
.69832 .56482 Mdot
.65675 .36847 Mdot
.64834 .61583 Mdot
.5218 .6361 Mdot
.29543 .35581 Mdot
.19844 .35344 Mdot
.54594 .29931 Mdot
.43878 .71701 Mdot
.68133 .60242 Mdot
.42505 .56913 Mdot
.87185 .46571 Mdot
.67443 .58959 Mdot
.69485 .60457 Mdot
.32114 .46906 Mdot
.23912 .47156 Mdot
.35629 .63665 Mdot
.6301 .5796 Mdot
.55516 .31018 Mdot
.3805 .32505 Mdot
.41206 .63211 Mdot
.49279 .58916 Mdot
.66075 .6158 Mdot
.50813 .31242 Mdot
.26157 .45889 Mdot
.51882 .29595 Mdot
.64988 .60435 Mdot
.49669 .32393 Mdot
.73345 .38966 Mdot
.46343 .30829 Mdot
.38096 .60844 Mdot
.41033 .59657 Mdot
.61315 .6136 Mdot
.64112 .57533 Mdot
.37538 .63198 Mdot
.39031 .5805 Mdot
.67234 .60534 Mdot
.56098 .2924 Mdot
.53614 .63456 Mdot
.36848 .62753 Mdot
.41029 .60079 Mdot
.40074 .34288 Mdot
.28675 .52407 Mdot
.34247 .49447 Mdot
.39809 .63472 Mdot
.36853 .34149 Mdot
.6952 .59373 Mdot
.41256 .58592 Mdot
.25076 .46377 Mdot
.51305 .33408 Mdot
.43565 .63625 Mdot
.54009 .51864 Mdot
.45299 .59231 Mdot
.26729 .69807 Mdot
.44421 .61185 Mdot
.65426 .60294 Mdot
.66896 .6111 Mdot
.56534 .29424 Mdot
.65414 .59599 Mdot
.54864 .51723 Mdot
.6437 .39255 Mdot
.49242 .78667 Mdot
.54804 .52139 Mdot
.39314 .65191 Mdot
.31734 .34507 Mdot
.49251 .59461 Mdot
.46946 .63965 Mdot
.42267 .3471 Mdot
.53747 .51336 Mdot
.68304 .59411 Mdot
.73458 .56391 Mdot
.37068 .66612 Mdot
.68503 .40065 Mdot
.49089 .59699 Mdot
.43647 .63672 Mdot
.39726 .55154 Mdot
.60063 .54915 Mdot
.67594 .37962 Mdot
.36231 .68617 Mdot
.41188 .6323 Mdot
.51104 .65805 Mdot
.39801 .62056 Mdot
.34768 .32937 Mdot
.66832 .57996 Mdot
.52313 .28511 Mdot
.38656 .3284 Mdot
.41262 .65895 Mdot
.38833 .31697 Mdot
.5073 .28399 Mdot
.65842 .37946 Mdot
.38119 .60467 Mdot
.38707 .35947 Mdot
.37216 .35077 Mdot
.44083 .64521 Mdot
.6738 .61207 Mdot
.35366 .66505 Mdot
.4166 .58707 Mdot
.44685 .60629 Mdot
.63487 .60099 Mdot
.68719 .23569 Mdot
.41988 .57093 Mdot
.49473 .45418 Mdot
.64507 .55122 Mdot
.51668 .54373 Mdot
.51869 .27902 Mdot
.38783 .64497 Mdot
.64826 .41714 Mdot
.64482 .39437 Mdot
.54304 .31529 Mdot
.64826 .61137 Mdot
.5184 .30976 Mdot
.35849 .5967 Mdot
.48857 .60324 Mdot
.40954 .62975 Mdot
.56473 .35533 Mdot
.75647 .3972 Mdot
.66447 .56272 Mdot
.53277 .31662 Mdot
.2817 .48648 Mdot
.63379 .39113 Mdot
.50388 .26117 Mdot
.6927 .57045 Mdot
.62633 .59287 Mdot
.63452 .59406 Mdot
.36143 .34123 Mdot
.51308 .30237 Mdot
.67755 .63067 Mdot
.69149 .62856 Mdot
.43197 .64353 Mdot
.41362 .6332 Mdot
.6938 .58739 Mdot
.54525 .2613 Mdot
.38534 .34429 Mdot
.51746 .27166 Mdot
.21106 .6648 Mdot
.66744 .37062 Mdot
.59885 .7839 Mdot
.39409 .63402 Mdot
.83346 .68886 Mdot
.37164 .60581 Mdot
.40451 .62208 Mdot
.66634 .6292 Mdot
.40884 .33773 Mdot
.37736 .324 Mdot
.68048 .60393 Mdot
.62623 .57421 Mdot
.34919 .3204 Mdot
.36382 .49385 Mdot
.24435 .6764 Mdot
.31113 .4958 Mdot
.65265 .56343 Mdot
.47197 .77796 Mdot
.66704 .39947 Mdot
.62788 .55336 Mdot
.70823 .42862 Mdot
.50319 .3268 Mdot
.4669 .31545 Mdot
.65041 .37778 Mdot
.4238 .57296 Mdot
.51461 .26768 Mdot
.43267 .55503 Mdot
.71059 .34796 Mdot
.52897 .47829 Mdot
.17201 .48577 Mdot
.3803 .59608 Mdot
.55945 .56283 Mdot
.81747 .51643 Mdot
.40344 .64617 Mdot
.61567 .75017 Mdot
.3989 .33102 Mdot
.62614 .55711 Mdot
.65865 .36151 Mdot
.74932 .66065 Mdot
.40844 .59553 Mdot
.64126 .57064 Mdot
.65188 .36401 Mdot
.75423 .38602 Mdot
.48191 .45176 Mdot
.42299 .64706 Mdot
.87536 .44116 Mdot
.71062 .59883 Mdot
.52183 .28403 Mdot
.53116 .75787 Mdot
.61812 .58996 Mdot
.46873 .45195 Mdot
.5538 .30772 Mdot
.3063 .53308 Mdot
.63651 .57013 Mdot
.40919 .34376 Mdot
.65876 .58677 Mdot
.36742 .3112 Mdot
.66614 .63071 Mdot
.50836 .32186 Mdot
.42879 .58936 Mdot
.5152 .32159 Mdot
.35048 .31349 Mdot
.54695 .30212 Mdot
.65802 .36139 Mdot
.5284 .51619 Mdot
.65421 .38957 Mdot
.2431 .53699 Mdot
.58275 .68274 Mdot
.66882 .38323 Mdot
.41566 .51641 Mdot
.3844 .6004 Mdot
.62003 .60985 Mdot
.52501 .28899 Mdot
.45852 .29082 Mdot
.28871 .50205 Mdot
.64586 .60446 Mdot
.50686 .31535 Mdot
.48028 .7721 Mdot
.74271 .33285 Mdot
.40392 .54652 Mdot
.57069 .26431 Mdot
.6651 .60559 Mdot
.46724 .27927 Mdot
.32351 .49792 Mdot
.62369 .59487 Mdot
.48136 .32512 Mdot
.6663 .37522 Mdot
.64735 .41607 Mdot
.37799 .60278 Mdot
.67402 .36868 Mdot
.45991 .3115 Mdot
.48087 .6891 Mdot
.68971 .60149 Mdot
.75649 .40494 Mdot
.38991 .34776 Mdot
.52696 .29582 Mdot
.44402 .6519 Mdot
.66886 .62578 Mdot
.47579 .30769 Mdot
.70643 .78317 Mdot
.22838 .7174 Mdot
.5058 .31405 Mdot
.66644 .58006 Mdot
.64344 .57706 Mdot
.36739 .6348 Mdot
.29029 .49838 Mdot
.50119 .30834 Mdot
.60058 .21 Mdot
.24619 .57211 Mdot
.52871 .51936 Mdot
.23013 .30015 Mdot
.44926 .59125 Mdot
.44934 .6065 Mdot
.67908 .39506 Mdot
.42997 .59932 Mdot
.63041 .57103 Mdot
.37132 .60558 Mdot
.65777 .42474 Mdot
.53851 .31808 Mdot
.41135 .59144 Mdot
.39532 .34146 Mdot
.66923 .41935 Mdot
.67044 .42153 Mdot
.49051 .32173 Mdot
.64619 .6097 Mdot
.77885 .64462 Mdot
.51916 .29796 Mdot
.44777 .61668 Mdot
.51587 .5321 Mdot
.38892 .56998 Mdot
.68521 .64784 Mdot
.64272 .55309 Mdot
.52667 .28776 Mdot
.50235 .53595 Mdot
.65401 .4075 Mdot
.45669 .30745 Mdot
.44889 .5838 Mdot
.49865 .33095 Mdot
.50841 .44046 Mdot
.43479 .18276 Mdot
.71114 .61615 Mdot
.49565 .43208 Mdot
.62588 .59609 Mdot
.53576 .51599 Mdot
.23299 .40138 Mdot
.38643 .34537 Mdot
.53438 .28611 Mdot
.74548 .42469 Mdot
.52464 .31937 Mdot
.42436 .59738 Mdot
.38656 .59219 Mdot
.49104 .28066 Mdot
.37266 .34563 Mdot
.40564 .4143 Mdot
.40741 .35097 Mdot
.66278 .57476 Mdot
.39923 .49943 Mdot
.18412 .63549 Mdot
.46747 .32647 Mdot
.64544 .38155 Mdot
.59759 .61081 Mdot
.39651 .65344 Mdot
.66516 .36641 Mdot
.67486 .41908 Mdot
.36573 .30846 Mdot
.52953 .30841 Mdot
.69593 .56566 Mdot
.63375 .40779 Mdot
.6198 .59657 Mdot
.26006 .45512 Mdot
.50049 .57412 Mdot
.36078 .69728 Mdot
.39732 .65688 Mdot
.29236 .50781 Mdot
.63252 .40915 Mdot
.39112 .59644 Mdot
.34958 .59326 Mdot
.66447 .37152 Mdot
.37023 .30761 Mdot
.53339 .48735 Mdot
.50415 .31569 Mdot
.86459 .51911 Mdot
.38215 .61221 Mdot
.42145 .58612 Mdot
.66303 .36833 Mdot
.64005 .74844 Mdot
.69668 .57884 Mdot
.66544 .61494 Mdot
.50355 .29178 Mdot
.33075 .47315 Mdot
.38332 .58032 Mdot
.38266 .60487 Mdot
.48431 .28142 Mdot
.51548 .53818 Mdot
.20595 .33779 Mdot
.40487 .60303 Mdot
.66127 .40279 Mdot
.50844 .46044 Mdot
.63551 .37318 Mdot
.38455 .56403 Mdot
.42116 .60306 Mdot
.4548 .62528 Mdot
.44908 .58185 Mdot
.65849 .38953 Mdot
.40353 .65691 Mdot
.37266 .65566 Mdot
.67983 .5935 Mdot
.44297 .58571 Mdot
.24695 .57334 Mdot
.40452 .59995 Mdot
.39915 .33541 Mdot
.34431 .4913 Mdot
.44364 .60677 Mdot
.4441 .58845 Mdot
.24467 .5702 Mdot
.4331 .60544 Mdot
.65525 .36334 Mdot
.64081 .58065 Mdot
.65321 .40886 Mdot
.64416 .37911 Mdot
.47643 .31198 Mdot
.38553 .30915 Mdot
.35359 .62347 Mdot
.35221 .32753 Mdot
.35763 .62013 Mdot
.36535 .68456 Mdot
.26603 .51872 Mdot
.32325 .49358 Mdot
.3652 .35315 Mdot
.38385 .60738 Mdot
.5065 .28731 Mdot
.5311 .29567 Mdot
.44523 .47467 Mdot
.48473 .59577 Mdot
.65788 .35849 Mdot
.66269 .37666 Mdot
.4469 .37959 Mdot
.42106 .17827 Mdot
.36012 .34683 Mdot
.41569 .41532 Mdot
.43905 .56274 Mdot
.41829 .57444 Mdot
.46702 .63338 Mdot
.47697 .29698 Mdot
.53648 .51271 Mdot
.53663 .27819 Mdot
.62427 .35986 Mdot
.6677 .41606 Mdot
.37995 .6017 Mdot
.57985 .85498 Mdot
.67797 .57726 Mdot
.6414 .57794 Mdot
.6554 .4249 Mdot
.53894 .29616 Mdot
.47868 .61848 Mdot
.85413 .56519 Mdot
.65511 .55326 Mdot
.39202 .35397 Mdot
.43725 .60328 Mdot
.50753 .3259 Mdot
.6855 .5854 Mdot
.38506 .35913 Mdot
.43112 .56835 Mdot
.55448 .30407 Mdot
.39459 .59677 Mdot
.46933 .72825 Mdot
.68609 .596 Mdot
.27037 .53115 Mdot
.68871 .62191 Mdot
.65907 .39158 Mdot
.63686 .392 Mdot
.41984 .6018 Mdot
.86132 .55075 Mdot
.6812 .54643 Mdot
.6516 .43188 Mdot
.40718 .33051 Mdot
.52231 .51908 Mdot
.38647 .31114 Mdot
.4913 .28366 Mdot
.38998 .34449 Mdot
.47617 .30938 Mdot
.56454 .28206 Mdot
.7076 .58664 Mdot
.36477 .32474 Mdot
.61189 .7288 Mdot
.482 .61611 Mdot
.39113 .3062 Mdot
.42975 .62232 Mdot
.36151 .62345 Mdot
.49275 .30704 Mdot
.35475 .3362 Mdot
.41813 .65425 Mdot
.72 .46824 Mdot
.63902 .38405 Mdot
.65484 .35983 Mdot
.48937 .59191 Mdot
.47082 .27934 Mdot
.70782 .58915 Mdot
.27147 .49135 Mdot
.70534 .57134 Mdot
.38308 .60866 Mdot
.35443 .61568 Mdot
.69971 .62064 Mdot
.70678 .60047 Mdot
.41771 .606 Mdot
.53843 .80745 Mdot
.43504 .65588 Mdot
.64442 .41406 Mdot
.66537 .57455 Mdot
.64521 .57292 Mdot
.46045 .31031 Mdot
.66613 .61646 Mdot
.33915 .6277 Mdot
.63524 .35731 Mdot
.37191 .66031 Mdot
.6544 .40405 Mdot
.44027 .2791 Mdot
.49021 .31117 Mdot
.74531 .41572 Mdot
.67212 .61609 Mdot
.38104 .63364 Mdot
.68379 .61528 Mdot
.40288 .3298 Mdot
.64926 .56664 Mdot
.60233 .58553 Mdot
.39826 .6297 Mdot
.416 .65831 Mdot
.52529 .53546 Mdot
.29311 .50311 Mdot
.6787 .58595 Mdot
.3595 .59716 Mdot
.36811 .60789 Mdot
.38769 .58254 Mdot
.27251 .50426 Mdot
.67907 .62078 Mdot
.6725 .74236 Mdot
.72863 .60144 Mdot
.68656 .59267 Mdot
.27025 .74328 Mdot
.53239 .53289 Mdot
.50622 .53741 Mdot
.68025 .36398 Mdot
.40771 .60334 Mdot
.51965 .31355 Mdot
.44826 .62244 Mdot
.45864 .64169 Mdot
.44238 .60438 Mdot
.37083 .31501 Mdot
.3977 .56573 Mdot
.52599 .5266 Mdot
.5226 .29707 Mdot
.40151 .64429 Mdot
.4146 .59592 Mdot
.51276 .54186 Mdot
.69217 .61133 Mdot
.63074 .601 Mdot
.71441 .5842 Mdot
.35841 .31176 Mdot
.67181 .40002 Mdot
.44714 .62248 Mdot
.50485 .28996 Mdot
.52246 .3144 Mdot
.66587 .62234 Mdot
.49001 .27512 Mdot
.67271 .41405 Mdot
.40661 .62017 Mdot
.65808 .3904 Mdot
.37236 .31409 Mdot
.66956 .57995 Mdot
.44191 .62291 Mdot
.43602 .6452 Mdot
.66927 .61109 Mdot
.42632 .65919 Mdot
.40442 .32638 Mdot
.4739 .28681 Mdot
.67314 .56468 Mdot
.64337 .39407 Mdot
.46147 .30893 Mdot
.39261 .64031 Mdot
.36353 .81017 Mdot
.42918 .60033 Mdot
.38501 .58147 Mdot
.69926 .55337 Mdot
.39965 .55759 Mdot
.52206 .32127 Mdot
.67506 .61896 Mdot
.3635 .62449 Mdot
.23439 .56477 Mdot
.4334 .31697 Mdot
.46556 .32789 Mdot
.42125 .61755 Mdot
.45837 .80333 Mdot
.37643 .62606 Mdot
.74723 .43022 Mdot
.26633 .51907 Mdot
.68108 .44573 Mdot
.36247 .69732 Mdot
.65385 .43159 Mdot
.51475 .53565 Mdot
.48296 .31572 Mdot
.5802 .77579 Mdot
.41962 .60845 Mdot
.58044 .65743 Mdot
.44194 .62622 Mdot
.66101 .41461 Mdot
.62822 .73957 Mdot
.50259 .27042 Mdot
.20668 .36389 Mdot
.43372 .57414 Mdot
.6915 .57162 Mdot
.53015 .26449 Mdot
.50979 .53194 Mdot
.41682 .65752 Mdot
.35084 .3354 Mdot
.45478 .37447 Mdot
.3457 .64771 Mdot
.65243 .40575 Mdot
.40666 .57134 Mdot
.45996 .62812 Mdot
.73404 .30001 Mdot
.67393 .59978 Mdot
.65379 .37101 Mdot
.41298 .18462 Mdot
.38707 .60117 Mdot
.62694 .59433 Mdot
.64515 .59228 Mdot
.35444 .32123 Mdot
.62501 .42151 Mdot
.47536 .3741 Mdot
.55947 .84398 Mdot
.4071 .71593 Mdot
.47571 .29549 Mdot
.55667 .50419 Mdot
.44961 .62216 Mdot
.29618 .35506 Mdot
.64331 .38382 Mdot
.42398 .58631 Mdot
.60327 .65935 Mdot
.66054 .60206 Mdot
.39672 .60212 Mdot
.38771 .3422 Mdot
.79949 .63151 Mdot
.45907 .76629 Mdot
.48021 .80435 Mdot
.55502 .31021 Mdot
.35403 .63146 Mdot
.33958 .62501 Mdot
.51497 .54431 Mdot
.37937 .56694 Mdot
.52318 .28741 Mdot
.52371 .4486 Mdot
.37926 .34015 Mdot
.68435 .58215 Mdot
.5108 .53918 Mdot
.44143 .62657 Mdot
.35889 .64434 Mdot
.40596 .335 Mdot
.45259 .6308 Mdot
.53676 .76665 Mdot
.55473 .51032 Mdot
.46426 .30653 Mdot
.65727 .56092 Mdot
.35425 .62102 Mdot
.51641 .52459 Mdot
.40503 .62874 Mdot
.57736 .60368 Mdot
.42289 .58127 Mdot
.69935 .45963 Mdot
.66119 .61178 Mdot
.64368 .40302 Mdot
.44708 .57811 Mdot
.39953 .59447 Mdot
.48519 .42728 Mdot
.47582 .62435 Mdot
.4417 .5925 Mdot
.63514 .6088 Mdot
.68183 .57942 Mdot
.69246 .57352 Mdot
.47148 .32341 Mdot
.30603 .49513 Mdot
.65529 .39396 Mdot
.4683 .63186 Mdot
.63384 .40834 Mdot
.32759 .6888 Mdot
.37557 .31135 Mdot
.74605 .40495 Mdot
.40791 .61755 Mdot
.63946 .59928 Mdot
.23308 .66195 Mdot
.67287 .62291 Mdot
.67436 .34991 Mdot
.64136 .38725 Mdot
.6721 .58787 Mdot
.4261 .61205 Mdot
.30197 .50915 Mdot
.48682 .81366 Mdot
.63329 .39337 Mdot
.48941 .58624 Mdot
.42493 .28021 Mdot
.52579 .32868 Mdot
.25599 .72826 Mdot
.6371 .4112 Mdot
.81811 .51659 Mdot
.36805 .62742 Mdot
.68558 .61232 Mdot
.66519 .38802 Mdot
.6802 .4148 Mdot
.49829 .26985 Mdot
.42658 .64555 Mdot
.39864 .59654 Mdot
.53976 .51938 Mdot
.65472 .38331 Mdot
.49703 .55314 Mdot
.42029 .64845 Mdot
.67318 .33723 Mdot
.67217 .55669 Mdot
.68159 .22979 Mdot
.42263 .52717 Mdot
.60218 .65949 Mdot
.65484 .23367 Mdot
.6806 .56805 Mdot
.42629 .57384 Mdot
.47929 .61615 Mdot
.47722 .2824 Mdot
.41767 .61532 Mdot
.53458 .31507 Mdot
.66758 .41066 Mdot
.70278 .46737 Mdot
.40702 .51934 Mdot
.6994 .35144 Mdot
.42878 .59547 Mdot
.46825 .76723 Mdot
.37037 .3315 Mdot
.64839 .35728 Mdot
.70332 .58924 Mdot
.37395 .57831 Mdot
.48768 .27247 Mdot
.50964 .33053 Mdot
.66217 .59975 Mdot
.80466 .52051 Mdot
.74699 .41769 Mdot
.43837 .65554 Mdot
.50485 .27571 Mdot
.50184 .55013 Mdot
.44598 .79026 Mdot
.64097 .42356 Mdot
.37822 .33902 Mdot
.48445 .32134 Mdot
.68612 .39864 Mdot
.36178 .62494 Mdot
.66481 .59433 Mdot
.71164 .607 Mdot
.45184 .46588 Mdot
.5094 .31559 Mdot
.38778 .32227 Mdot
.46179 .46111 Mdot
.41559 .49272 Mdot
.38704 .33417 Mdot
.47283 .32569 Mdot
.6606 .56936 Mdot
.64963 .60273 Mdot
.64082 .58274 Mdot
.59968 .7821 Mdot
.64302 .55329 Mdot
.28569 .39926 Mdot
.38146 .56553 Mdot
.48055 .77879 Mdot
.3645 .6006 Mdot
.65995 .36234 Mdot
.6866 .59966 Mdot
.26591 .52173 Mdot
.44291 .56729 Mdot
.49288 .81527 Mdot
.402 .57882 Mdot
.50281 .45756 Mdot
.40906 .6026 Mdot
.48606 .73272 Mdot
.62216 .56101 Mdot
.42911 .56899 Mdot
.63056 .36427 Mdot
.39413 .31945 Mdot
.63951 .62382 Mdot
.43451 .58295 Mdot
.76954 .57312 Mdot
.43007 .62271 Mdot
.70195 .46489 Mdot
.46253 .45517 Mdot
.36081 .37272 Mdot
.38356 .57555 Mdot
.51937 .26612 Mdot
.35713 .55348 Mdot
.47012 .78126 Mdot
.63301 .39623 Mdot
.47434 .77012 Mdot
.5266 .27461 Mdot
.63079 .74029 Mdot
.44938 .65053 Mdot
.37817 .34252 Mdot
.55164 .47995 Mdot
.64024 .40923 Mdot
.41207 .61396 Mdot
.42614 .5715 Mdot
.52465 .47819 Mdot
.43342 .78353 Mdot
.5075 .55203 Mdot
.37021 .3562 Mdot
.4477 .77147 Mdot
.44063 .59286 Mdot
.45894 .3248 Mdot
.64098 .60915 Mdot
.62568 .73141 Mdot
.64608 .73584 Mdot
.40921 .64808 Mdot
.67265 .59112 Mdot
.64826 .61128 Mdot
.19424 .61089 Mdot
.36678 .33528 Mdot
.41863 .57977 Mdot
.4966 .43089 Mdot
.44621 .62277 Mdot
.66475 .4077 Mdot
.42757 .55658 Mdot
.49267 .31221 Mdot
.32522 .50002 Mdot
.47693 .32644 Mdot
.38648 .58367 Mdot
.65806 .58534 Mdot
.63971 .37648 Mdot
.56469 .2759 Mdot
.62459 .42009 Mdot
.28455 .40018 Mdot
.44127 .3736 Mdot
.36222 .34828 Mdot
.3763 .30943 Mdot
.64988 .35771 Mdot
.41341 .62146 Mdot
.27957 .49846 Mdot
.43666 .54842 Mdot
.40386 .6076 Mdot
.43217 .58594 Mdot
.6957 .39227 Mdot
.64072 .39032 Mdot
.50233 .32439 Mdot
.41685 .60746 Mdot
.36321 .58811 Mdot
.66404 .58598 Mdot
.36556 .34913 Mdot
.46935 .30465 Mdot
.3463 .3208 Mdot
.51613 .29094 Mdot
.26832 .69945 Mdot
.49627 .584 Mdot
.38506 .31545 Mdot
.64193 .42107 Mdot
.6356 .58892 Mdot
.53906 .52907 Mdot
.49052 .28899 Mdot
.49436 .27381 Mdot
.36047 .63292 Mdot
.68503 .58693 Mdot
.66795 .61539 Mdot
.34818 .32039 Mdot
.66465 .37861 Mdot
.40401 .54326 Mdot
.39335 .65464 Mdot
.5452 .23258 Mdot
.47807 .27795 Mdot
.45852 .77382 Mdot
.72586 .58609 Mdot
.39864 .62448 Mdot
.62884 .59668 Mdot
.40754 .58915 Mdot
.60493 .61168 Mdot
.70982 .60212 Mdot
.40741 .55448 Mdot
.47497 .58641 Mdot
.47661 .29997 Mdot
.17393 .56628 Mdot
.38983 .54925 Mdot
.72251 .40235 Mdot
.45069 .6244 Mdot
.19579 .35492 Mdot
.22515 .65128 Mdot
.42027 .62334 Mdot
.39968 .56611 Mdot
.52018 .85447 Mdot
.37741 .62512 Mdot
.53303 .52046 Mdot
.45603 .6466 Mdot
.62769 .59198 Mdot
.5 .43406 Mdot
.29064 .50521 Mdot
.36161 .33182 Mdot
.50283 .29099 Mdot
.24338 .46963 Mdot
.36709 .31072 Mdot
.65822 .60423 Mdot
.40161 .54287 Mdot
.70975 .56461 Mdot
.46728 .27351 Mdot
.50333 .55396 Mdot
.66383 .4126 Mdot
.28381 .50021 Mdot
.49272 .27103 Mdot
.64328 .39221 Mdot
.37082 .61879 Mdot
.5497 .27137 Mdot
.63319 .36787 Mdot
.17321 .58119 Mdot
.68085 .39655 Mdot
.63891 .39941 Mdot
.29642 .49639 Mdot
.36148 .33188 Mdot
.53036 .4549 Mdot
.37521 .68587 Mdot
.64363 .36975 Mdot
.21339 .37733 Mdot
.48414 .27149 Mdot
.30801 .48174 Mdot
.62034 .56107 Mdot
.49352 .58976 Mdot
.43059 .58799 Mdot
.67747 .38743 Mdot
.50982 .51991 Mdot
.482 .42583 Mdot
.65816 .41927 Mdot
.45041 .5776 Mdot
.33535 .47632 Mdot
.51804 .52417 Mdot
.53501 .53071 Mdot
.38897 .35808 Mdot
.44132 .20305 Mdot
.6446 .6067 Mdot
.39257 .35288 Mdot
.25347 .54064 Mdot
.3997 .57741 Mdot
.66025 .38971 Mdot
.5092 .54121 Mdot
.64527 .39631 Mdot
.37537 .32829 Mdot
.40577 .32587 Mdot
.67922 .59461 Mdot
.69543 .5786 Mdot
.5522 .49053 Mdot
.24161 .57836 Mdot
.43334 .63646 Mdot
.57326 .6698 Mdot
.70728 .60232 Mdot
.61557 .76556 Mdot
.35994 .33638 Mdot
.36117 .34462 Mdot
.39709 .74886 Mdot
.41087 .63907 Mdot
.50747 .45953 Mdot
.44416 .6051 Mdot
.23713 .35572 Mdot
.44058 .62477 Mdot
.48653 .2787 Mdot
.44659 .58526 Mdot
.76499 .61132 Mdot
.37886 .63723 Mdot
.43825 .594 Mdot
.50457 .3015 Mdot
.3558 .62813 Mdot
.49294 .30946 Mdot
.42203 .57335 Mdot
.46598 .35158 Mdot
.50494 .29041 Mdot
.40911 .30341 Mdot
.47799 .46895 Mdot
.5332 .52611 Mdot
.36211 .31827 Mdot
.35658 .34493 Mdot
.26483 .45488 Mdot
.67053 .57161 Mdot
.66166 .68283 Mdot
.43664 .60303 Mdot
.4775 .27511 Mdot
.67187 .40779 Mdot
.4083 .64923 Mdot
.37528 .5947 Mdot
.39061 .54915 Mdot
.67748 .59141 Mdot
.45815 .30244 Mdot
.3709 .32093 Mdot
.53256 .30893 Mdot
.46441 .34656 Mdot
.48535 .30783 Mdot
.47326 .56475 Mdot
.36053 .62482 Mdot
.33974 .62218 Mdot
.60372 .70172 Mdot
.32116 .35753 Mdot
.66393 .59715 Mdot
.51739 .5321 Mdot
.38186 .31087 Mdot
.36158 .48083 Mdot
.63568 .60073 Mdot
.48702 .28036 Mdot
.39448 .59637 Mdot
.50002 .57647 Mdot
.3742 .68534 Mdot
.6179 .59796 Mdot
.37851 .30303 Mdot
.49576 .29298 Mdot
.52573 .5203 Mdot
.31036 .49356 Mdot
.69545 .71971 Mdot
.24522 .52852 Mdot
.40278 .59173 Mdot
.34979 .31926 Mdot
.68523 .58507 Mdot
.51986 .46582 Mdot
.6712 .37912 Mdot
.29057 .49987 Mdot
.43001 .5963 Mdot
.6145 .34351 Mdot
.65652 .58605 Mdot
.37727 .34759 Mdot
.67817 .38832 Mdot
.36974 .33966 Mdot
.52208 .5174 Mdot
.73027 .59724 Mdot
.41937 .6575 Mdot
.44471 .61066 Mdot
.67018 .40754 Mdot
.65019 .60948 Mdot
.47116 .35679 Mdot
.53887 .46942 Mdot
.49196 .28099 Mdot
.35765 .48746 Mdot
.68313 .58162 Mdot
.59576 .3452 Mdot
.53348 .30943 Mdot
.67103 .36212 Mdot
.30068 .51978 Mdot
.67336 .41562 Mdot
.43704 .58864 Mdot
.64845 .57937 Mdot
.63251 .39499 Mdot
.5253 .2294 Mdot
.55089 .81825 Mdot
.54815 .47802 Mdot
.38453 .59803 Mdot
.75558 .42789 Mdot
.80608 .5456 Mdot
.60813 .60368 Mdot
.64202 .41762 Mdot
.421 .59337 Mdot
.43696 .65653 Mdot
.43577 .57507 Mdot
.64544 .37269 Mdot
.59096 .40963 Mdot
.5237 .27749 Mdot
.39067 .59819 Mdot
.3957 .34262 Mdot
.49435 .31602 Mdot
.54036 .32172 Mdot
.48428 .32208 Mdot
.70262 .58996 Mdot
.5016 .56933 Mdot
.45891 .64495 Mdot
.21138 .61521 Mdot
.64134 .40254 Mdot
.53284 .52614 Mdot
.40719 .56543 Mdot
.28429 .40481 Mdot
.63948 .59464 Mdot
.49349 .29703 Mdot
.42063 .58526 Mdot
.45451 .46175 Mdot
.50783 .54788 Mdot
.51518 .30075 Mdot
.7076 .59758 Mdot
.64028 .531 Mdot
.41464 .61675 Mdot
.44886 .62991 Mdot
.66727 .60846 Mdot
.8131 .56234 Mdot
.31544 .49081 Mdot
.40848 .59073 Mdot
.64178 .39785 Mdot
.82705 .4374 Mdot
.36856 .61734 Mdot
.67504 .54808 Mdot
.54127 .51223 Mdot
.73497 .60169 Mdot
.52286 .77701 Mdot
.47925 .60521 Mdot
.60648 .50795 Mdot
.37881 .41645 Mdot
.59633 .5411 Mdot
.2566 .35015 Mdot
.56677 .46761 Mdot
.17995 .6142 Mdot
.63542 .35516 Mdot
.47108 .73583 Mdot
.69378 .78868 Mdot
.8125 .5122 Mdot
.50377 .41979 Mdot
.61784 .45523 Mdot
.47348 .26085 Mdot
.21224 .32641 Mdot
.53185 .27288 Mdot
.26483 .34049 Mdot
.44173 .61616 Mdot
.80703 .56517 Mdot
.47331 .74306 Mdot
.3977 .37652 Mdot
.73617 .38897 Mdot
.46078 .45827 Mdot
.4274 .82091 Mdot
.71255 .35292 Mdot
.32199 .75934 Mdot
.62402 .66796 Mdot
.47854 .19479 Mdot
.37175 .49657 Mdot
.24838 .45293 Mdot
.48705 .76152 Mdot
.68516 .52488 Mdot
.60294 .37539 Mdot
.51062 .6683 Mdot
.66888 .23778 Mdot
.5053 .27961 Mdot
.62054 .5877 Mdot
.6116 .46236 Mdot
.37206 .78842 Mdot
.70969 .37268 Mdot
.60494 .50867 Mdot
.54318 .47515 Mdot
.48189 .73311 Mdot
.26604 .53077 Mdot
.48137 .71646 Mdot
.46691 .379 Mdot
.21618 .32503 Mdot
.65878 .53654 Mdot
.50908 .21921 Mdot
.34906 .46487 Mdot
.45203 .39853 Mdot
.5113 .74199 Mdot
.3393 .31729 Mdot
.41314 .30399 Mdot
.70843 .59719 Mdot
.40329 .79194 Mdot
.44177 .5217 Mdot
.25353 .54836 Mdot
.5301 .27067 Mdot
.58201 .5746 Mdot
.79616 .63178 Mdot
.79826 .54559 Mdot
.16428 .52243 Mdot
.35994 .80372 Mdot
.21579 .41685 Mdot
.50954 .47426 Mdot
.70416 .3743 Mdot
.29694 .40656 Mdot
.55505 .56451 Mdot
.20568 .44891 Mdot
.58042 .60403 Mdot
.48316 .83625 Mdot
.76416 .54493 Mdot
.39578 .81976 Mdot
.64912 .53469 Mdot
.34575 .60808 Mdot
.63336 .62897 Mdot
.47876 .68594 Mdot
.2292 .53849 Mdot
.40054 .81112 Mdot
.38336 .37275 Mdot
.52814 .50983 Mdot
.8079 .5036 Mdot
.53491 .76673 Mdot
.49387 .37737 Mdot
.41969 .31877 Mdot
.63739 .7147 Mdot
.43492 .83129 Mdot
.61891 .50415 Mdot
.33242 .72623 Mdot
.6697 .33556 Mdot
.56747 .32328 Mdot
.5435 .31817 Mdot
.66905 .42853 Mdot
.33717 .77619 Mdot
.64637 .58333 Mdot
.16955 .56416 Mdot
.57087 .50213 Mdot
.5436 .54206 Mdot
.44122 .83369 Mdot
.18259 .46664 Mdot
.50388 .77165 Mdot
.34489 .39347 Mdot
.74672 .35306 Mdot
.51933 .62493 Mdot
.68522 .34687 Mdot
.42547 .29069 Mdot
.72217 .45119 Mdot
.35037 .78345 Mdot
.20073 .43117 Mdot
.58382 .84522 Mdot
.25776 .55662 Mdot
.35792 .28124 Mdot
.66297 .53773 Mdot
.55143 .4056 Mdot
.50713 .37931 Mdot
.38848 .81896 Mdot
.45109 .76444 Mdot
.80268 .41036 Mdot
.24474 .3704 Mdot
.64772 .74039 Mdot
.75732 .45357 Mdot
.59033 .43287 Mdot
.48579 .67278 Mdot
.77414 .56577 Mdot
.38731 .65761 Mdot
.23888 .51629 Mdot
.63543 .70137 Mdot
.35943 .36526 Mdot
.31248 .50112 Mdot
.7631 .5223 Mdot
.22088 .45341 Mdot
.80768 .43298 Mdot
.64454 .71298 Mdot
.68723 .62445 Mdot
.20743 .44801 Mdot
.22967 .38702 Mdot
.78679 .42164 Mdot
.4094 .18636 Mdot
.33149 .7274 Mdot
.54088 .37096 Mdot
.47509 .61131 Mdot
.46726 .73658 Mdot
.49001 .7595 Mdot
.22393 .33509 Mdot
.47784 .56949 Mdot
.19492 .58466 Mdot
.73117 .38945 Mdot
.58816 .71488 Mdot
.21567 .51303 Mdot
.59916 .70753 Mdot
.49597 .78659 Mdot
.70209 .64703 Mdot
.69698 .43611 Mdot
.49455 .52245 Mdot
.43898 .82982 Mdot
.49646 .32106 Mdot
.20276 .45023 Mdot
.70933 .36369 Mdot
.53534 .23117 Mdot
.55187 .46018 Mdot
.49258 .4177 Mdot
.3007 .75573 Mdot
.79851 .49527 Mdot
.47226 .24976 Mdot
.72332 .56082 Mdot
.56367 .54286 Mdot
.57922 .67551 Mdot
.44855 .54193 Mdot
.57541 .58811 Mdot
.4045 .32631 Mdot
.58812 .75413 Mdot
.7304 .62189 Mdot
.39393 .18897 Mdot
.46632 .56578 Mdot
.37765 .49605 Mdot
.54448 .51598 Mdot
.28732 .4561 Mdot
.26394 .69717 Mdot
.49248 .55716 Mdot
.18225 .47517 Mdot
.80689 .51217 Mdot
.28128 .4585 Mdot
.50004 .38114 Mdot
.67012 .68782 Mdot
.39904 .82164 Mdot
.24074 .70412 Mdot
.78997 .59412 Mdot
.75087 .44839 Mdot
.3595 .17556 Mdot
.69077 .4414 Mdot
.18354 .56165 Mdot
.7091 .36381 Mdot
.8608 .36539 Mdot
.52717 .32021 Mdot
.29571 .34615 Mdot
.54467 .60675 Mdot
.41083 .47318 Mdot
.38845 .79285 Mdot
.51744 .76166 Mdot
.38067 .30214 Mdot
.61169 .60168 Mdot
.48038 .58008 Mdot
.41242 .80682 Mdot
.4478 .82595 Mdot
.41901 .80786 Mdot
.59095 .36358 Mdot
.50214 .80558 Mdot
.4901 .85126 Mdot
.29013 .39742 Mdot
.47737 .49713 Mdot
.45799 .63463 Mdot
.23044 .57939 Mdot
.18868 .52675 Mdot
.32397 .33855 Mdot
.51491 .63205 Mdot
.66931 .53821 Mdot
.46938 .84924 Mdot
.25337 .68979 Mdot
.47797 .71275 Mdot
.30346 .75023 Mdot
.45292 .24841 Mdot
.20718 .54389 Mdot
.27314 .73423 Mdot
.6505 .50959 Mdot
.64016 .34571 Mdot
.49813 .85954 Mdot
.23039 .39957 Mdot
.6148 .45289 Mdot
.76311 .58479 Mdot
.18343 .53693 Mdot
.74509 .45843 Mdot
.60909 .45111 Mdot
.56195 .58424 Mdot
.71353 .69796 Mdot
.50105 .41306 Mdot
.68246 .52564 Mdot
.50787 .46844 Mdot
.21043 .51752 Mdot
.54448 .30868 Mdot
.19754 .47104 Mdot
.48366 .39643 Mdot
.48621 .49534 Mdot
.25275 .473 Mdot
.20901 .3997 Mdot
.73941 .54364 Mdot
.47098 .80342 Mdot
.8036 .50575 Mdot
.82081 .43843 Mdot
.77459 .44154 Mdot
.64181 .69039 Mdot
.35496 .62564 Mdot
.37888 .79286 Mdot
.19796 .67388 Mdot
.28185 .7439 Mdot
.79404 .42492 Mdot
.53364 .33951 Mdot
.67402 .37064 Mdot
.28569 .41608 Mdot
.42712 .46162 Mdot
.61299 .48368 Mdot
.41774 .42556 Mdot
.65583 .43516 Mdot
.8018 .62692 Mdot
.56289 .48652 Mdot
.28968 .40373 Mdot
.5209 .66151 Mdot
.54375 .55513 Mdot
.44278 .78938 Mdot
.69665 .62162 Mdot
.78307 .40673 Mdot
.205 .45168 Mdot
.49123 .32068 Mdot
.53863 .22467 Mdot
.48555 .52794 Mdot
.35351 .58627 Mdot
.41785 .27989 Mdot
.50488 .50029 Mdot
.60113 .6606 Mdot
.53222 .33818 Mdot
.21196 .65428 Mdot
.17633 .55802 Mdot
.26899 .73083 Mdot
.21463 .41098 Mdot
.52135 .22201 Mdot
.29164 .46299 Mdot
.70745 .41538 Mdot
.72235 .36512 Mdot
.32171 .46531 Mdot
.2171 .3949 Mdot
.50107 .77461 Mdot
.6166 .61559 Mdot
.47283 .62125 Mdot
.23928 .66876 Mdot
.25923 .43167 Mdot
.3031 .45293 Mdot
.67955 .70541 Mdot
.67388 .55405 Mdot
.30273 .31246 Mdot
.71341 .54283 Mdot
.32237 .64221 Mdot
.75842 .44208 Mdot
.63105 .41337 Mdot
.70863 .61344 Mdot
.20755 .40086 Mdot
.44427 .17438 Mdot
.58387 .54369 Mdot
.42508 .51945 Mdot
.34929 .77548 Mdot
.45877 .48216 Mdot
.73111 .4576 Mdot
.73475 .69823 Mdot
.71807 .3329 Mdot
.6302 .53815 Mdot
.497 .48571 Mdot
.54024 .44795 Mdot
.74607 .63507 Mdot
.63161 .61491 Mdot
.45886 .76399 Mdot
.33871 .78479 Mdot
.47065 .45757 Mdot
.65602 .51845 Mdot
.27491 .48887 Mdot
.5344 .4066 Mdot
.56836 .52638 Mdot
.24682 .47354 Mdot
.61223 .52467 Mdot
.35268 .74407 Mdot
.83476 .58928 Mdot
.49401 .65839 Mdot
.28825 .33811 Mdot
.28908 .41318 Mdot
.62532 .66782 Mdot
.50678 .73908 Mdot
.73007 .36058 Mdot
.44768 .60088 Mdot
.33472 .79033 Mdot
.76588 .53393 Mdot
.26632 .46629 Mdot
.57884 .35967 Mdot
.3911 .63637 Mdot
.34269 .63348 Mdot
.28298 .74214 Mdot
.73686 .60038 Mdot
.75068 .75511 Mdot
.2447 .35953 Mdot
.62075 .63992 Mdot
.51598 .77845 Mdot
.18211 .48546 Mdot
.6925 .65339 Mdot
.57586 .50068 Mdot
.49294 .39606 Mdot
.1838 .5154 Mdot
.74521 .59636 Mdot
.74308 .58115 Mdot
.76743 .42549 Mdot
.49027 .84756 Mdot
.5721 .56301 Mdot
.6234 .35125 Mdot
.44662 .25227 Mdot
.385 .58059 Mdot
.80506 .52376 Mdot
.75028 .40254 Mdot
.56693 .37334 Mdot
.5563 .57447 Mdot
.1961 .6744 Mdot
.46463 .60651 Mdot
.79406 .50122 Mdot
.7398 .76172 Mdot
.79062 .72373 Mdot
.76219 .60883 Mdot
.38188 .81801 Mdot
.7404 .58048 Mdot
.72891 .46062 Mdot
.6285 .39539 Mdot
.40074 .50015 Mdot
.57648 .66173 Mdot
.30792 .77177 Mdot
.47006 .17932 Mdot
.6814 .34526 Mdot
.52559 .64269 Mdot
.3054 .77187 Mdot
.46992 .60271 Mdot
.29862 .32419 Mdot
.56668 .3254 Mdot
.20319 .36865 Mdot
.16661 .51526 Mdot
.69272 .70579 Mdot
.21647 .34082 Mdot
.28672 .30761 Mdot
.40811 .38327 Mdot
.17884 .55749 Mdot
.40138 .71173 Mdot
.69791 .69423 Mdot
.20962 .44503 Mdot
.74398 .44204 Mdot
.29306 .23166 Mdot
.56994 .52978 Mdot
.5069 .49313 Mdot
.73572 .63001 Mdot
.71677 .45388 Mdot
.73055 .5219 Mdot
.46181 .4954 Mdot
.3423 .49753 Mdot
.48578 .78501 Mdot
.82566 .43054 Mdot
.74611 .69959 Mdot
.52079 .49702 Mdot
.45467 .82175 Mdot
.719 .35097 Mdot
.32836 .45734 Mdot
.52774 .7524 Mdot
.26665 .43186 Mdot
.44953 .25489 Mdot
.44268 .60567 Mdot
.34389 .78775 Mdot
.44823 .25594 Mdot
.44112 .81813 Mdot
.16668 .57126 Mdot
.31091 .74892 Mdot
.52471 .56282 Mdot
.42881 .28043 Mdot
.19171 .51591 Mdot
.19355 .51883 Mdot
.49935 .83431 Mdot
.27685 .32708 Mdot
.3308 .46905 Mdot
.48266 .47735 Mdot
.41366 .51994 Mdot
.31767 .63475 Mdot
.18058 .49127 Mdot
.66263 .6759 Mdot
.21916 .50806 Mdot
.78053 .60475 Mdot
.21259 .39849 Mdot
.50808 .76775 Mdot
.26663 .43999 Mdot
.54483 .38104 Mdot
.36986 .298 Mdot
.4824 .27154 Mdot
.56018 .85007 Mdot
.77893 .42738 Mdot
.20199 .59454 Mdot
.79805 .40987 Mdot
.77426 .56199 Mdot
.2623 .33524 Mdot
.63902 .63009 Mdot
.46154 .68423 Mdot
.4681 .19524 Mdot
.2253 .45903 Mdot
.46252 .77042 Mdot
.74891 .42897 Mdot
.66953 .7307 Mdot
.30855 .76418 Mdot
.21289 .51974 Mdot
.62048 .83631 Mdot
.39697 .27746 Mdot
.58881 .74865 Mdot
.39591 .784 Mdot
.83803 .48824 Mdot
.30418 .44922 Mdot
.44255 .82963 Mdot
.61457 .57399 Mdot
.3648 .80619 Mdot
.67603 .39316 Mdot
.3382 .28927 Mdot
.73994 .42555 Mdot
.28811 .4374 Mdot
.29068 .4378 Mdot
.20199 .62563 Mdot
.80386 .50064 Mdot
.80058 .5462 Mdot
.54095 .37048 Mdot
.54345 .28569 Mdot
.38821 .51171 Mdot
.64094 .51498 Mdot
.57196 .84441 Mdot
.35527 .61731 Mdot
.38848 .27335 Mdot
.19398 .4592 Mdot
.70695 .41421 Mdot
.52183 .48549 Mdot
.73748 .43508 Mdot
.71851 .7113 Mdot
.21724 .56086 Mdot
.47999 .84639 Mdot
.52359 .48615 Mdot
.42987 .44966 Mdot
.63107 .74649 Mdot
.64082 .47845 Mdot
.71489 .34042 Mdot
.61271 .51103 Mdot
.44257 .49731 Mdot
.31282 .48946 Mdot
.21858 .40992 Mdot
.1868 .64567 Mdot
.47211 .82762 Mdot
.71621 .33985 Mdot
.29243 .44612 Mdot
.66994 .54706 Mdot
.23342 .45841 Mdot
.6103 .84193 Mdot
.20334 .34215 Mdot
.76545 .58102 Mdot
.20808 .41102 Mdot
.576 .38992 Mdot
.29454 .33116 Mdot
.31175 .45827 Mdot
.39313 .78266 Mdot
.52876 .62919 Mdot
.73181 .60297 Mdot
.59408 .44264 Mdot
.28338 .50699 Mdot
.55997 .46893 Mdot
.69103 .69756 Mdot
.80207 .4933 Mdot
.62259 .83516 Mdot
.27107 .31637 Mdot
.63303 .73767 Mdot
.66993 .80223 Mdot
.70691 .5861 Mdot
.54796 .44897 Mdot
.58724 .30367 Mdot
.28343 .45351 Mdot
.5078 .32892 Mdot
.49737 .55187 Mdot
.34878 .48236 Mdot
.75718 .62363 Mdot
.48773 .2516 Mdot
.38602 .3074 Mdot
.67819 .62446 Mdot
.28195 .31525 Mdot
.71222 .60985 Mdot
.18595 .63789 Mdot
.65005 .50704 Mdot
.47971 .78185 Mdot
.72441 .72187 Mdot
.50869 .21309 Mdot
.82867 .44914 Mdot
.31873 .75787 Mdot
.23747 .56634 Mdot
.62954 .61525 Mdot
.68297 .62828 Mdot
.71685 .55795 Mdot
.68754 .42911 Mdot
.35456 .77393 Mdot
.18595 .46288 Mdot
.53135 .21783 Mdot
.62781 .56759 Mdot
.49265 .46904 Mdot
.50652 .50848 Mdot
.22468 .66754 Mdot
.53151 .31173 Mdot
.41654 .83054 Mdot
.66223 .67921 Mdot
.82726 .52178 Mdot
.62405 .4855 Mdot
.31795 .52564 Mdot
.31603 .44436 Mdot
.51707 .23062 Mdot
.47114 .61834 Mdot
.61439 .63244 Mdot
.69327 .57781 Mdot
.55529 .4628 Mdot
.37586 .35066 Mdot
.39562 .19014 Mdot
.71432 .41402 Mdot
.62418 .68268 Mdot
.17619 .49416 Mdot
.69813 .62195 Mdot
.39936 .28129 Mdot
.4911 .2127 Mdot
.46785 .57528 Mdot
.23578 .59837 Mdot
.53853 .85387 Mdot
.33206 .76082 Mdot
.65256 .619 Mdot
.81724 .43952 Mdot
.48468 .36382 Mdot
.21043 .65024 Mdot
.74427 .60391 Mdot
.18818 .4764 Mdot
.62232 .7138 Mdot
.25736 .71382 Mdot
.52255 .77646 Mdot
.60902 .49679 Mdot
.20671 .43534 Mdot
.48503 .42492 Mdot
.20366 .41431 Mdot
.70861 .72205 Mdot
.41576 .50837 Mdot
.20392 .37413 Mdot
.57716 .36676 Mdot
.47785 .72089 Mdot
.32463 .60812 Mdot
.61352 .48635 Mdot
.18639 .50994 Mdot
.69037 .61575 Mdot
.34628 .34261 Mdot
.53681 .64269 Mdot
.69268 .34655 Mdot
.34676 .78046 Mdot
.7909 .42976 Mdot
.19414 .44942 Mdot
.42156 .52214 Mdot
.25454 .40829 Mdot
.65404 .67299 Mdot
.25148 .55937 Mdot
.43725 .65847 Mdot
.63379 .70711 Mdot
.44232 .41709 Mdot
.21756 .63918 Mdot
.33017 .57818 Mdot
.39412 .80191 Mdot
.25548 .68753 Mdot
.74991 .61765 Mdot
.51784 .45018 Mdot
.62058 .57904 Mdot
.41868 .82625 Mdot
.21465 .57773 Mdot
.72265 .44673 Mdot
.16763 .51237 Mdot
.30163 .30387 Mdot
.68433 .79402 Mdot
.78383 .50044 Mdot
.49264 .508 Mdot
.17603 .56926 Mdot
.76716 .53974 Mdot
.29207 .30422 Mdot
.45857 .76914 Mdot
.69042 .54851 Mdot
.44597 .83492 Mdot
.43468 .7056 Mdot
.79262 .55359 Mdot
.42567 .78626 Mdot
.60386 .54923 Mdot
.21509 .58286 Mdot
.46526 .63341 Mdot
.48069 .28264 Mdot
.40285 .48337 Mdot
.22287 .33097 Mdot
.58889 .55693 Mdot
.18438 .47733 Mdot
.1893 .47903 Mdot
.2741 .34576 Mdot
.50786 .22723 Mdot
.68615 .79242 Mdot
.52762 .80406 Mdot
.36444 .6528 Mdot
.64073 .61548 Mdot
.38035 .30816 Mdot
.248 .37124 Mdot
.40526 .64399 Mdot
.28389 .55038 Mdot
.63303 .71466 Mdot
.32247 .78262 Mdot
.54522 .39543 Mdot
.60439 .38209 Mdot
.62441 .56628 Mdot
.7212 .45016 Mdot
.6936 .65781 Mdot
.81551 .51671 Mdot
.18746 .50563 Mdot
.58441 .54369 Mdot
.6073 .50464 Mdot
.78679 .5586 Mdot
.21578 .45047 Mdot
.44828 .38594 Mdot
.6374 .37469 Mdot
.59158 .65841 Mdot
.54082 .83703 Mdot
.78387 .54425 Mdot
.57507 .53231 Mdot
.72655 .54362 Mdot
.4282 .50067 Mdot
.63654 .33796 Mdot
.80485 .50478 Mdot
.72367 .60408 Mdot
.35497 .75016 Mdot
.62634 .53079 Mdot
.4242 .28109 Mdot
.23467 .37628 Mdot
.69346 .52319 Mdot
.18407 .48927 Mdot
.47421 .58687 Mdot
.40798 .79926 Mdot
.26796 .46438 Mdot
.3439 .34402 Mdot
.43628 .64989 Mdot
.56467 .60474 Mdot
.2818 .74166 Mdot
.75805 .58419 Mdot
.5412 .58701 Mdot
.7156 .61826 Mdot
.17101 .54922 Mdot
.43155 .30603 Mdot
.52126 .34195 Mdot
.32968 .38334 Mdot
.32133 .52268 Mdot
.42148 .46314 Mdot
.6923 .42673 Mdot
.4716 .61 Mdot
.43424 .391 Mdot
.43405 .50528 Mdot
.59546 .66208 Mdot
.19233 .57252 Mdot
.55675 .84793 Mdot
.58476 .57298 Mdot
.16275 .51627 Mdot
.55161 .61184 Mdot
.63644 .53988 Mdot
.27594 .31286 Mdot
.52795 .60371 Mdot
.4774 .57233 Mdot
.34988 .34739 Mdot
.70348 .57803 Mdot
.5526 .84495 Mdot
.56421 .56599 Mdot
.33189 .33672 Mdot
.52545 .36873 Mdot
.56475 .53045 Mdot
.64101 .22242 Mdot
.72803 .38194 Mdot
.17115 .56281 Mdot
.20508 .44959 Mdot
.64893 .44037 Mdot
.74074 .5841 Mdot
.53151 .6024 Mdot
.40614 .8008 Mdot
.45562 .41991 Mdot
.32958 .76525 Mdot
.59561 .35972 Mdot
.61344 .68245 Mdot
.25263 .68209 Mdot
.23401 .5244 Mdot
.24934 .55492 Mdot
.66006 .70998 Mdot
.31284 .68822 Mdot
.53675 .53163 Mdot
.42544 .18514 Mdot
.27403 .25306 Mdot
.58983 .84593 Mdot
.82663 .52631 Mdot
.35597 .66965 Mdot
.232 .4633 Mdot
.64541 .52513 Mdot
.33483 .46021 Mdot
.51949 .37884 Mdot
.41326 .28116 Mdot
.58105 .37718 Mdot
.81622 .42335 Mdot
.33351 .78846 Mdot
.43894 .64726 Mdot
.40645 .42126 Mdot
.39165 .37345 Mdot
.52756 .32263 Mdot
.4914 .69365 Mdot
.53581 .85238 Mdot
.63664 .37853 Mdot
.59235 .29018 Mdot
.69243 .43097 Mdot
.20446 .62617 Mdot
.57124 .2676 Mdot
.6882 .38483 Mdot
.18453 .63689 Mdot
.78725 .5916 Mdot
.687 .72885 Mdot
.80266 .40659 Mdot
.22683 .65516 Mdot
.63063 .70376 Mdot
.42058 .29187 Mdot
.36921 .80082 Mdot
.31388 .44612 Mdot
.46845 .24819 Mdot
.32328 .70841 Mdot
.20584 .42991 Mdot
.24092 .36586 Mdot
.6116 .42477 Mdot
.5346 .62777 Mdot
.40653 .17062 Mdot
.51478 .21058 Mdot
.85203 .56894 Mdot
.33137 .75816 Mdot
.57338 .81609 Mdot
.75315 .59304 Mdot
.54866 .36983 Mdot
.39966 .79674 Mdot
.19093 .48802 Mdot
.53919 .60756 Mdot
.45059 .18414 Mdot
.24144 .50327 Mdot
.24624 .44607 Mdot
.62093 .34593 Mdot
.28102 .73403 Mdot
.51104 .22228 Mdot
.38292 .7091 Mdot
.20031 .4467 Mdot
.55794 .61136 Mdot
.25764 .56371 Mdot
.53133 .836 Mdot
.23056 .59601 Mdot
.22064 .38187 Mdot
.58146 .37366 Mdot
.46838 .3445 Mdot
.5517 .84107 Mdot
.65331 .6547 Mdot
.62216 .71982 Mdot
.7426 .75957 Mdot
.39464 .81887 Mdot
.52433 .61276 Mdot
.4311 .55814 Mdot
.1771 .60804 Mdot
.44016 .31829 Mdot
.19954 .58168 Mdot
.79108 .63609 Mdot
.24689 .35204 Mdot
.34805 .5571 Mdot
.43709 .62353 Mdot
.29172 .39039 Mdot
.74358 .62003 Mdot
.54045 .61494 Mdot
.54994 .25039 Mdot
.21852 .39377 Mdot
.6274 .68209 Mdot
.83436 .58979 Mdot
.71178 .71699 Mdot
.6279 .58129 Mdot
.35496 .79518 Mdot
.42952 .7196 Mdot
.63581 .67016 Mdot
.39414 .78755 Mdot
.44267 .4323 Mdot
.43726 .38905 Mdot
.65016 .67089 Mdot
.29214 .46078 Mdot
.22457 .32638 Mdot
.66536 .80679 Mdot
.58409 .6679 Mdot
.42408 .83339 Mdot
.24346 .7095 Mdot
.62652 .577 Mdot
.50704 .65875 Mdot
.30773 .43628 Mdot
.60031 .54045 Mdot
.59985 .43778 Mdot
.53144 .22657 Mdot
.3086 .29665 Mdot
.38475 .19923 Mdot
.42602 .62001 Mdot
.59572 .35666 Mdot
.31202 .7646 Mdot
.30746 .31149 Mdot
.32092 .77083 Mdot
.64345 .69718 Mdot
.35992 .63935 Mdot
.79419 .72012 Mdot
.72674 .46015 Mdot
.45853 .55115 Mdot
.3756 .68026 Mdot
.36297 .67704 Mdot
.44456 .5981 Mdot
.60105 .42952 Mdot
.2791 .41766 Mdot
.23867 .35062 Mdot
.36842 .79729 Mdot
.6398 .55823 Mdot
.31234 .44318 Mdot
.62589 .36805 Mdot
.28979 .52399 Mdot
.32878 .68839 Mdot
.63028 .41701 Mdot
.23999 .33792 Mdot
.63872 .22286 Mdot
.47919 .38697 Mdot
.56272 .47515 Mdot
.33374 .50147 Mdot
.55131 .49387 Mdot
.25974 .32466 Mdot
.69249 .42165 Mdot
.41086 .38156 Mdot
.19614 .44501 Mdot
.66214 .71828 Mdot
.63109 .34406 Mdot
.35231 .1865 Mdot
.3072 .45192 Mdot
.58846 .36085 Mdot
.49854 .65116 Mdot
.72227 .69857 Mdot
.35651 .75901 Mdot
.45148 .3758 Mdot
.54587 .52395 Mdot
.62495 .74665 Mdot
.38633 .79272 Mdot
.65823 .42521 Mdot
.19261 .65708 Mdot
.49655 .64932 Mdot
.495 .69269 Mdot
.52667 .81938 Mdot
.50752 .48082 Mdot
.46821 .76925 Mdot
.35814 .66467 Mdot
.40863 .45505 Mdot
.61109 .20836 Mdot
.52221 .49235 Mdot
.56465 .52369 Mdot
.59593 .5329 Mdot
.28514 .33999 Mdot
.38342 .74286 Mdot
.41306 .57921 Mdot
.41792 .32664 Mdot
.28001 .47164 Mdot
.35385 .2866 Mdot
.35999 .28218 Mdot
.64227 .34518 Mdot
.25712 .32748 Mdot
.24474 .36044 Mdot
.43462 .78272 Mdot
.41779 .8139 Mdot
.32539 .60257 Mdot
.32682 .75486 Mdot
.51356 .40098 Mdot
.73781 .52375 Mdot
.23377 .59544 Mdot
.65947 .80995 Mdot
.60877 .62325 Mdot
.34073 .66441 Mdot
.22855 .68701 Mdot
.30226 .75165 Mdot
.69969 .35192 Mdot
.75174 .43492 Mdot
.25005 .2784 Mdot
.29556 .43393 Mdot
.82085 .42677 Mdot
.56847 .28442 Mdot
.22231 .672 Mdot
.44061 .51248 Mdot
.51841 .61931 Mdot
.6704 .69328 Mdot
.47136 .56826 Mdot
.52112 .30848 Mdot
.73352 .69822 Mdot
.66225 .71073 Mdot
.31089 .68373 Mdot
.35191 .64332 Mdot
.58004 .45264 Mdot
.67659 .54789 Mdot
.59657 .8429 Mdot
.49783 .33383 Mdot
.43052 .44706 Mdot
.81974 .61189 Mdot
.6192 .21158 Mdot
.29871 .29912 Mdot
.48997 .83185 Mdot
.7255 .37007 Mdot
.43788 .50222 Mdot
.73933 .30906 Mdot
.62618 .55096 Mdot
.638 .6157 Mdot
.70959 .42048 Mdot
.25812 .41044 Mdot
.79792 .51049 Mdot
.70819 .78188 Mdot
.25341 .70996 Mdot
.47201 .58246 Mdot
.87292 .51875 Mdot
.1981 .45142 Mdot
.41491 .43322 Mdot
.79519 .49655 Mdot
.34094 .78463 Mdot
.58078 .38696 Mdot
.17376 .58134 Mdot
.67694 .51907 Mdot
.61593 .54161 Mdot
.25577 .42981 Mdot
.79786 .41381 Mdot
.49457 .47249 Mdot
.85167 .56354 Mdot
.76314 .43871 Mdot
.24768 .45377 Mdot
.7535 .58153 Mdot
.61367 .55242 Mdot
.59989 .61523 Mdot
.65522 .50051 Mdot
.55008 .57051 Mdot
.57698 .53166 Mdot
.61484 .50535 Mdot
.45383 .38711 Mdot
.6031 .47053 Mdot
.71905 .46065 Mdot
.70946 .39305 Mdot
.68644 .70978 Mdot
.23269 .30247 Mdot
.38028 .27915 Mdot
.54313 .30842 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo083ooooo0_l00037ooooo`007?ooool00ol0003oooooooooo`20oooo
o`;o00002oooool2o`000;[ooooo000Looooo`03o`000?oooooooooo077ooooo0_l0000Booooo`;o
00001_ooool4o`000;Sooooo000Looooo`03o`000?oooooooooo077ooooo0_l0000Booooo`;o0000
2?ooool2o`0000Cooooo0_l0002booooo`007?ooool00ol0003oooooooooo`22ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0000Cooooo0_l00004ooooo`;o0000/_ooool001cooooo00?o0000
ooooooooool0Koooool3o`0000cooooo0_l000001Ooooooo0000o`000?l0003ooooo00?o000000?o
ooooo`000?l000001?ooool2o`000;Sooooo000Looooo`03o`000?oooooooooo06oooooo0ol0000:
ooooo`Co000000?oooooo`000?l000000oooool2o`000<7ooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`1looooo`?o0000b_oo
ool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A006ooooo`03o`000?oooooooooo07[ooooo1?l0000Fooooo`;o00000_ooool2o`000:oo
oooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h0
1oooool00ol0003oooooooooo`1Wooooo`;o00004?ooool3o`0001Sooooo0_l00002ooooo`;o0000
[oooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^
kP06ooooo`?o0000Ioooool2o`00013ooooo1?l0000?ooooo`;o0000^oooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooo
oooo07_ooooo0_l00006ooooo`;o00001oooool4o`000;Wooooo00000ooooooo410@ooooo`02oooo
o`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Uoooo
o`;o00007?ooool2o`0000Wooooo0_l0000cooooo`;o0000Q?ooool00006oooooomgMgOoV9RHoooo
oonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0IOoo
ool2o`0003cooooo0_l00003ooooo`;o00004_ooool2o`000003ooooool0003o000000Ko0000P_oo
ool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Ko
oooo00?o0000ooooooooool0W?ooool2o`0000?ooooo1?l00003ooooo`Co00004?ooool2o`000003
ooooool0003o000000;o00000_ooool2o`0008;ooooo000Looooo`03o`000?oooooooooo09cooooo
0_l00003ooooo`;o00001_ooool3o`0009gooooo000Looooo`03o`000?oooooooooo0:;ooooo0_l0
0005ooooo`?o0000WOooool001cooooo00?o0000ooooooooool0X_ooool2o`0000;ooooo0_l00003
ooooo`;o00007oooool2o`0007_ooooo000Looooo`03o`000?oooooooooo0:7ooooo0ol000001Ooo
oooo0000o`000?l0003ooooo00Co00007oooool2o`0007_ooooo000Looooo`03o`000?oooooooooo
0:7ooooo0_l000000ooooooo0000o`000005o`000003ooooool0003o000000gooooo0_l0000Moooo
o`;o0000KOooool001cooooo00?o0000ooooooooool0Foooool2o`0004Oooooo1Ol000000ooooooo
0000o`000003o`0000cooooo0_l0000Dooooo`;o00001oooool2o`0006gooooo000Looooo`03o`00
0?oooooooooo05_ooooo0_l0001=ooooo`;o000000Coooooo`000?l0003o00008Oooool2o`0000Oo
oooo1?l0001[ooooo`007?ooool00ol0003oooooooooo`2^ooooo`?o00009?ooool2o`0000Cooooo
0ol0001[ooooo`007?ooool00ol0003oooooooooo`2_ooooo`;o00009?ooool2o`0007;ooooo000L
ooooo`03o`000?oooooooooo0:[ooooo0_l0002Mooooo`007?ooool00ol0003oooooooooo`2?oooo
o`;o00000oooool2o`0001Cooooo0_l0002Mooooo`007?ooool2o`0008kooooo1?l00003ooooo`Go
00000_ooool2o`0001;ooooo0_l0000_ooooo`;o0000Ioooool001cooooo00?o0000ooooooooool0
EOooool2o`0003Kooooo0ol00004ooooo`Go00000_ooool2o`0001;ooooo0_l0000_ooooo`?o0000
I_ooool001cooooo00?o0000ooooooooool0EOooool2o`0003Oooooo0_l00004ooooo`;o0000Booo
ool2o`0006Kooooo000Looooo`03o`000?oooooooooo05?ooooo0_l0000iooooo`;o00001_ooool2
o`0000Kooooo1?l00006ooooo`;o00000_ooool3o`0000?ooooo0ol0000]ooooo`;o0000IOooool0
01cooooo00?o0000ooooooooool0Doooool2o`00047ooooo0_l00004ooooo`Oo00001Oooool2o`00
00;ooooo0ol00003ooooo`?o000000?oooooo`000?l00000:_ooool3o`0006Cooooo000Looooo`03
o`000?oooooooooo09Kooooo0_l00002ooooo`go000000?oooooo`000?l000003?ooool2o`0002_o
oooo0ol0001Sooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o0000A?oooolDo`0000cooooo
0_l00004ooooo`;o00009_ooool2o`0006?ooooo000Looooo`03o`000?oooooooooo04oooooo0ol0
000Xooooo`;o00006?ooool2o`0000;ooooo4ol00003ooooo`?o000000Coooooo`000?l0003ooooo
0_l00005ooooo`;o00009?ooool2o`000003ooooool0003o000006;ooooo000Looooo`03o`000?oo
oooooooo04oooooo0_l0000Yooooo`;o00006?ooool2o`000003ooooool0003o000001;o00000ooo
ool3o`000003ooooool0003o000000?o0000:oooool2o`000003ooooool0003o000006;ooooo000L
ooooo`03o`000?oooooooooo04kooooo0_l0000Xooooo`;o00000oooool2o`0000Gooooo0_l00005
ooooo`;o00001ooooolIo`000003ooooool0003o000000?ooooo1?l0002Booooo`007?ooool00ol0
003oooooooooo`1>ooooo`;o00008Oooool2o`0000Gooooo0_l00003ooooo`?o00000_ooool8o`00
0003ooooool0003o000000Cooooo7?l000000ooooooo0000o`000003ooooo`?o0000Toooool001co
oooo00?o0000ooooooooool0LOooool2o`0000_ooooo0_l00002ooooo`;o00000_ooool4o`0000Oo
oooo6?l000000ooooooo0000o`000003o`0000Cooooo1Ol0002Aooooo`007?ooool00ol0003ooooo
ooooo`1Uooooo`;o00000oooool2o`0000?ooooo0_l00005ooooo`;o00005Oooool2o`0000Gooooo
6ol00004ooooo`Ko0000;oooool2o`0005oooooo000Looooo`03o`000?oooooooooo06Gooooo0_l0
0003ooooo`;o000000?oooooo`000?l000000_l00005ooooo`;o00003Oooool3o`0000Gooooo0_l0
0002oooooaco00001?ooool4o`0000;ooooo0_l00004ooooo`;o0000:Oooool2o`0005oooooo000L
ooooo`03o`000?oooooooooo04Wooooo0_l0000Rooooo`Co00004?ooool3o`000004ooooool0003o
0000o`0000;ooooo1Ol00002oooooago00000oooool5o`0000Oooooo0_l0000Xooooo`;o0000H?oo
ool001cooooo00?o0000ooooooooool0BOooool2o`0001Kooooo0_l0000Aooooo`;o00002oooool3
o`000003ooooool0003o000000So00000_oooolPo`0000?ooooo0_l0000aooooo`;o0000H?ooool0
01cooooo0_l00018ooooo`;o00005?ooool2o`0000;ooooo0_l0000Aooooo`;o00002oooool2o`00
00;ooooo1ol00002ooooo`;o000000?oooooo`000?l000007_l000000ooooooo0000o`00000goooo
o`;o0000G?ooool001cooooo00?o0000ooooooooool0A_ooool4o`00017ooooo1Ol00006ooooo`;o
00001Oooool2o`000003ooooool0003o000000Gooooo1Ol00005ooooo`?o00001?ooool4o`0000;o
oooo0_l000000ooooooo0000o`00000Ho`000003ooooool0003o000000Ko00001oooool2o`0002ko
oooo0_l0001Looooo`007?ooool00ol0003oooooooooo`16ooooo`Co00003oooool4o`000003oooo
ool0003o000000Kooooo0_l00005oooooa;o00000_ooool3o`0000Cooooo0_l00007ooooo`ko0000
00?oooooo`000?l000002Ol000000ooooooo0000o`000009o`0000Cooooo0_l0002<ooooo`007?oo
ool00ol0003oooooooooo`1Iooooo`;o00003oooool4o`000003ooooool0003o0000013o00001ooo
ool4o`0000Cooooo7?l000000ooooooo0000o`000009o`000003ooooool0003o0000037ooooo0_l0
001Kooooo`007?ooool00ol0003oooooooooo`1Fooooo`;o00001oooool3o`0000Sooooo5ol00009
ooooo`;o00000_oooolNo`000003ooooool0003o000000Co00000oooool2o`000003ooooool0003o
0000037ooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`1Dooooo`Ko00001Oooool3o`00
00Wooooo5Ol00002ooooo`;o00001Oooool2o`0000?ooooo0_l00002ooooo`Co000000?oooooo`00
0?l000005_l0002Jooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o00000_ooool3o`0000go
oooo6Ol000000ooooooo0000o`000003o`0000;ooooo1?l00006ooooo`co000000?oooooo`000?l0
00003_l00006ooooo`;o0000TOooool001cooooo00?o0000ooooooooool0FOooool2o`0000gooooo
6_l000000ooooooo0000o`000002o`0000Cooooo0_l00006ooooo`go000000?oooooo`000?l00000
3Ol00006ooooo`;o0000TOooool001cooooo00?o0000ooooooooool0@oooool2o`0000cooooo0_l0
000:ooooo`;o00003?oooolGo`0000;ooooo0_l0000;oooooago00001_ooool3o`0009;ooooo000L
ooooo`03o`000?oooooooooo047ooooo1_l00009ooooo`?o00000oooool2o`0000Gooooo0_l00005
ooooo`;o00001OoooolGo`0000;ooooo0_l0000;oooooago00001_ooool3o`0003Gooooo0_l0001K
ooooo`007?ooool00ol0003oooooooooo`11ooooo`;o00000_ooool4o`0000Oooooo0_l00004oooo
o`;o00001?ooool2o`0000Kooooo0_l00004oooooaWo000000?oooooo`000?l000003OoooolIo`00
043ooooo0_l000000ooooooo0000o`00001Hooooo`007?ooool00ol0003oooooooooo`15ooooo`Co
00002?ooool2o`0000Wooooo0_l00007ooooo`;o00000oooool3o`000003ooooool0003o000001?o
00004_ooool;o`000003ooooool0003o000000Oo00009?ooool2o`0000Kooooo0_l0000:ooooo`;o
000000?oooooo`000?l000001_ooool4o`0005Sooooo000Looooo`03o`000?oooooooooo03oooooo
0_l00004ooooo`;o00000oooool2o`0000Gooooo0_l00007ooooo`;o00002Oooool5o`0000Cooooo
3_l000000ooooooo0000o`000004o`000004ooooool0003o0000ooooo`;o00003_ooool2o`0000Co
oooo0ol000000ooooooo0000o`000003o`0000?ooooo0_l0000Pooooo`;o000000Coooooo`000?l0
003o00001Oooool3o`0000Oooooo1?l000000ooooooo0000o`000006ooooo`;o0000F_ooool001co
oooo00?o0000ooooooooool0?oooool2o`0000;ooooo0_l00005ooooo`;o00001_ooool2o`0000Go
oooo0ol0000:ooooo`Co00001?oooolHo`000003ooooool0003o000000Wooooo0_l00009ooooo`Go
00001Oooool5o`0001oooooo0_l00002ooooo`;o00001_ooool2o`0000Oooooo0_l00002ooooo`?o
0000H_ooool001cooooo00?o0000ooooooooool0?_ooool2o`0000?ooooo0_l0000=ooooo`;o0000
1Oooool2o`00017ooooo6Ol0000=ooooo`Go00002Oooool2o`0000Cooooo0ol000000ooooooo0000
o`00000Gooooo`?o00000oooool2o`0000[ooooo0_l000000ooooooo0000o`00000:ooooo`?o0000
2Oooool2o`0005Oooooo000Looooo`03o`000?oooooooooo03kooooo0_l0000Eooooo`;o00001Ooo
ool2o`0000Gooooo0_l00007oooooaOo00000oooool2o`0000_ooooo1?l0000?ooooo`;o00005Ooo
ool5o`000003ooooool0003o000000?o000000Coooooo`000?l0003ooooo0ol00006ooooo`;o0000
00?oooooo`000?l000001Ol0000<ooooo`;o00000oooool2o`0005Oooooo000Looooo`;o0000Booo
ool2o`0000Cooooo0_l00003ooooo`;o00001Oooool3o`0000Cooooo0_l00009oooooa7o000000Co
ooooo`000?l0003o00000_ooool3o`0000_ooooo0_l0000Xooooo`Go00001?ooool2o`0000Cooooo
1?l00007ooooo`So00001?ooool5o`0000?ooooo0_l0001Looooo`007?ooool00ol0003ooooooooo
o`0mooooo`;o00002oooool4o`0000;ooooo0_l0000;ooooo`;o00000oooool3o`0000gooooo4Ol0
0002ooooo`;o00003Oooool2o`0002;ooooo0_l0000=ooooo`;o00001Oooool2o`0000Oooooo1_l0
0002ooooo`;o00000_ooool5o`0000Oooooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`0l
ooooo`Co00000_ooool2o`0000Gooooo0_l000000ooooooo0000o`00000>ooooo`;o00001?ooool3
o`0000kooooo3Ol0000Dooooo`?o00007Oooool2o`0000;ooooo0_l00004ooooo`;o00001oooool2
o`000003ooooool0003o000000;o00001Oooool2o`0000[ooooo0_l00003ooooo`;o00002Oooool4
o`0005Kooooo000Looooo`03o`000?oooooooooo03cooooo1?l00002ooooo`;o00001Oooool5o`00
00kooooo0_l00007ooooo`;o00003Oooool>o`0001?ooooo0_l0000Kooooo`Co00000_ooool2o`00
00Cooooo0ol000000ooooooo0000o`000002ooooo`oo00005Oooool2o`0000Gooooo0_l0001Foooo
o`007?ooool00ol0003oooooooooo`11ooooo`Co00001Oooool4o`0000kooooo0_l00005ooooo`Co
00002_ooool2o`0000?ooooo2Ol000001?oooooo0000o`000?l0000Vooooo`;o00001?ooool2o`00
0003ooooool0003o000000Cooooo0_l000001?oooooo0000o`000?ooool3o`000003ooooool0003o
0000017o000000?oooooo`000?l000004Oooool5o`0002Kooooo0_l0000cooooo`007?ooool00ol0
003oooooooooo`0oooooo`Ko00001_ooool3o`0001Gooooo0_l0000<ooooo`?o00001_ooool2o`00
00;ooooo1Ol0000Gooooo`;o00003Oooool2o`0000Cooooo0_l0000:ooooo`Go00001?oooolAo`00
0004ooooool0003o0000ooooo`Co00001_ooool2o`0000;ooooo1ol0000Vooooo`;o0000<oooool0
01cooooo00?o0000ooooooooool0?_ooool3o`000003ooooool0003o000000Oooooo0_l0000Goooo
o`;o00002oooool3o`0000Wooooo1_l0000Gooooo`;o00002Oooool4o`0000oooooo0_l00002oooo
o`Co00001?ooool2o`000003ooooool0003o000000go000000?oooooo`000?l000001?l00006oooo
o`;o00000_ooool2o`0000;ooooo0_l0000Wooooo`;o0000<oooool001cooooo00?o0000oooooooo
ool0?Oooool4o`000003ooooool0003o000000Sooooo0ol0000Eooooo`;o00005oooool3o`000003
ooooool0003o000000?ooooo0_l0000Jooooo`;o000000?oooooo`000?l000000_l00003ooooo`Co
00002?ooool2o`0000Oooooo0ol00004ooooo`So000000?oooooo`000?l000001_l00002ooooo`;o
00002oooool2o`0005oooooo000Looooo`03o`000?oooooooooo03gooooo1?l0000;ooooo`Co0000
8Oooool2o`000003ooooool0003o000000?ooooo1ol00003ooooo`;o000000Coooooo`000?l0003o
00000_ooool4o`000003ooooool0003o000000;ooooo0_l000001?oooooo0000o`000?ooool3o`00
00Gooooo0_l00008ooooo`Co00001?ooool2o`0000?ooooo0ol00004ooooo`Co00001oooool@o`00
00Kooooo1?l00003ooooo`;o00001oooool2o`0005Kooooo000Looooo`03o`000?oooooooooo03oo
oooo0_l000000ooooooo0000o`000005ooooo`;o00000oooool2o`00027ooooo0_l000000ooooooo
0000o`000003ooooo`Ko00001?ooool6o`0000;ooooo1ol00002ooooo`;o000000Coooooo`000?l0
003ooooo1_l00002ooooo`;o00004?ooool2o`0000?ooooo0ol00004ooooo`;o00002Oooool@o`00
00Kooooo1?l00003ooooo`;o00001oooool2o`0005Kooooo000Looooo`03o`000?oooooooooo04;o
oooo0_l00005ooooo`;o000000?oooooo`000?l000003_ooool2o`0000Wooooo0_l0000Dooooo`;o
00000oooool7o`0000Cooooo1?l00002ooooo`?o00000_ooool4o`000003ooooool0003o000000Go
000000?oooooo`000?l000001_ooool2o`0000[ooooo0_l00004ooooo`;o00002_ooool6o`000003
ooooool0003o000000Oo00003Oooool2o`0000;ooooo0_l00004ooooo`;o0000EOooool001cooooo
00?o0000ooooooooool0A?ooool2o`0000Kooooo0_l0000<ooooo`Co00002Oooool2o`0000?ooooo
0_l0000Cooooo`?o00000_ooool2o`0000Gooooo1?l00002ooooo`?o00000_ooool4o`0000;ooooo
1Ol00002ooooo`;o00001_ooool2o`00013ooooo1?l00008oooooa3o000000?oooooo`000?l00000
2oooool2o`000003ooooool0003o000000Cooooo0_l0001Eooooo`007?ooool00ol0003ooooooooo
o`12ooooo`Co000000?oooooo`000?l000000oooool2o`0000_ooooo0ol0000;ooooo`;o00000ooo
ool2o`0000_ooooo0_l00006ooooo`?o00002_ooool4o`0000Kooooo0_l00004ooooo`;o00006Ooo
ool2o`0000Kooooo0_l00008oooooa3o000000?oooooo`000?l000002oooool2o`0000Kooooo0ol0
001Eooooo`007?ooool00ol0003oooooooooo`12ooooo`?o00000_ooool2o`00013ooooo1?l0000A
ooooo`?o00002?ooool2o`0000kooooo0ol00002ooooo`Co00001Oooool3o`0001gooooo1?l0000?
oooooa?o00003Oooool3o`0000Cooooo0ol0001Eooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^
k^h5ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0@ooo
ool2o`0000Gooooo0_l0000?ooooo`;o00003oooool5o`0001Sooooo0ol0000;ooooo`;o00007_oo
ool2o`000003ooooool0003o000000kooooo5_l00003ooooo`;o00001Oooool3o`0005cooooo0000
1_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0@oooool2o`0000Cooooo0ol0000Pooooo`?o0000:_ooool2o`000003oooo
ool0003o000000oooooo0_l00008ooooo`Go00003?oooolHo`0000?ooooo0_l00006ooooo`;o0000
G?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo00?o
0000ooooooooool0@?ooool5o`0000;ooooo1?l0000>ooooo`Co00004?ooool2o`000003ooooool0
003o000001gooooo0_l00008ooooo`;o000000?oooooo`000?l000003oooool2o`0000Wooooo0_l0
0009ooooo`;o000000?oooooo`000?l000005Ol0000Eooooo`;o00002?ooool2o`0001_ooooo0_l0
000^ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04odA4A?oMgMgo
ooooo`0000Oooooo0ol0000oooooo`Co00001?ooool3o`0000oooooo1?l0000Cooooo`;o00001?oo
ool2o`0001Oooooo0_l0000Booooo`;o00004oooool3o`0000Sooooo1Ol00002ooooo`Go000000?o
ooooo`000?l000002ol0000:ooooo`Go00001?ooool4o`0000Sooooo0_l0000Kooooo`;o0000;_oo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?oMgMgoEEEEooooool0
0007ooooo`03o`000?oooooooooo03oooooo0ol00006ooooo`;o00003_ooool4o`0001[ooooo0_l0
000[ooooo`;o00002_ooool2o`0000Oooooo0ol0000:oooooaSo00002_ooool7o`000003ooooool0
003o000000?o0000EOooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool0
0omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo04oooooo0_l00007ooooo`Co000000?ooooo
o`000?l000005oooool2o`0000_ooooo0_l0000Uooooo`;o00000oooool2o`0001Gooooo5ol0000:
ooooo`Co000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000007ooooo`;o00001?oo
ool3o`0004Gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l00000
1oooool00ol0003oooooooooo`10ooooo`Go00002_ooool3o`0000Gooooo1?l00002ooooo`;o0000
5oooool2o`0000Cooooo1?l000000ooooooo0000o`000002o`0002Gooooo0_l0000@ooooo`;o0000
2?oooolGo`0000[ooooo0ol000000ooooooo0000o`000002ooooo`;o00002_ooool2o`0000;ooooo
1Ol0000Fooooo`;o0000;Oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo
0000ooooo`06ooooo`03o`000?oooooooooo03kooooo1ol0000;ooooo`;o00001?ooool3o`000003
ooooool0003o000001Wooooo0ol000001?oooooo0000o`000?ooool9o`000003ooooool0003o0000
00?ooooo0_l0000Booooo`;o00006_ooool3o`0000Wooooo5ol00004ooooo`Co00000_ooool2o`00
0004ooooool0003o0000ooooo`;o00003oooool4o`0001Oooooo0_l0000]ooooo`007?ooool00ol0
003oooooooooo`0mooooo`?o00000_ooool2o`0001;ooooo1_l00002ooooo`;o00005Oooool6o`00
00Gooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo1Ol0000<ooooo`;o000000?ooooo
o`000?l000006_ooool2o`0000Kooooo0_l00002oooooaOo00001?ooool4o`0000;ooooo0_l00004
ooooo`?o00001_ooool2o`0000Kooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`0moooo
o`;o00000oooool2o`00017ooooo1ol00002ooooo`;o00005oooool2o`0000Oooooo0_l00009oooo
o`Oo00002_ooool2o`0000;ooooo0_l0000Jooooo`?o00001?ooool2o`0000;ooooo6?l00004oooo
o`;o00000oooool2o`000004ooooool0003o0000ooooo`?o00001_ooool2o`0000?ooooo0_l0000L
ooooo`;o0000;Oooool001cooooo00?o0000ooooooooool0?Oooool2o`0001Kooooo0ol00002oooo
o`;o00009?ooool2o`0000Wooooo0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o0000
00?o00001?ooool2o`0001[ooooo1?l00003ooooo`;o00000_oooolEo`000003ooooool0003o0000
00Cooooo0ol00002ooooo`;o000000?oooooo`000?l000001Ol00003ooooo`;o00001Oooool4o`00
00Gooooo0_l000000ooooooo0000o`00000?ooooo`?o0000;Oooool001cooooo00?o0000oooooooo
ool0??ooool3o`0000_ooooo0_l00009ooooo`;o00001?ooool2o`0002Oooooo0_l0000>ooooo`;o
000000?oooooo`000?l000000ol0000Rooooo`;o00000oooool2o`0000?ooooo0_l000000ooooooo
0000o`00000?o`000003ooooool0003o000000Cooooo0ol00007ooooo`Oo000000?oooooo`000?l0
00000_ooool2o`0000?ooooo0_l00005ooooo`Go00003oooool2o`0002kooooo000Looooo`03o`00
0?oooooooooo03cooooo0_l000000ooooooo0000o`000009ooooo`;o00000oooool2o`0000Cooooo
0_l00004ooooo`;o00009oooool2o`0001?ooooo0ol00002ooooo`;o00007oooool2o`0000[ooooo
1_l000000ooooooo0000o`000005o`000003ooooool0003o000000?o00000oooool3o`0000Sooooo
1ol000000ooooooo0000o`000002ooooo`;o00000_ooool2o`0000Sooooo0ol0000?ooooo`;o0000
;_ooool001cooooo00?o0000ooooooooool0?_ooool3o`0000kooooo0ol000001?oooooo0000o`00
0?l00006ooooo`;o00009Oooool2o`0000Oooooo0_l0000;ooooo`?o000000?oooooo`000?l00000
0_l0000Kooooo`;o000000?oooooo`000?l000003_ooool:o`0000?ooooo0ol00003ooooo`?o0000
2_ooool3o`0000_ooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l0000?ooooo`;o
0000;_ooool001cooooo00?o0000ooooooooool0>oooool2o`000004ooooool0003o0000o`0000oo
oooo0_l000001?oooooo0000o`000?l00006ooooo`;o00000_ooool2o`00027ooooo0_l00007oooo
o`;o00003oooool4o`0001_ooooo0_l00002ooooo`;o00002oooool8o`0000?ooooo0_l00005oooo
o`Co00002Oooool2o`0000;ooooo0_l0000>ooooo`;o000000?oooooo`000?l000005?ooool2o`00
02kooooo000Looooo`03o`000?oooooooooo03_ooooo0_l00002ooooo`;o00001Oooool2o`0000_o
oooo0ol00004ooooo`?o00000oooool2o`0003_ooooo1?l0000Nooooo`?o00002oooool2o`0000;o
oooo1?l00003ooooo`;o00001Oooool4o`0000Wooooo0_l00002ooooo`;o00000_ooool2o`0000oo
oooo1_l0000>ooooo`;o0000;_ooool001cooooo00?o0000ooooooooool0A_ooool2o`0000_ooooo
0_l00005ooooo`?o00001Oooool4o`0003_ooooo0_l000000ooooooo0000o`00000Gooooo`Co0000
0_ooool2o`0000[ooooo1_l00006ooooo`Go00003_ooool2o`0000?ooooo0ol00002ooooo`;o0000
2oooool6o`0000gooooo0ol0000^ooooo`007?ooool00ol0003oooooooooo`0looooo`;o00000_oo
ool2o`0000[ooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo1?l0000kooooo`;o000000?o
ooooo`000?l000005oooool2o`0000Cooooo0_l0000:ooooo`Ko00001?ooool7o`0000kooooo0_l0
0003ooooo`;o00000oooool2o`0001kooooo0ol0000^ooooo`007?ooool00ol0003oooooooooo`0j
ooooo`So00002Oooool3o`0000Gooooo0_l00006ooooo`;o00000_ooool2o`000004ooooool0003o
0000o`0002?ooooo0_l0000Jooooo`Co00001?ooool4o`0001?ooooo0ol0000:ooooo`;o00000_oo
ool2o`000003ooooool0003o000000;o00003?ooool2o`0000Oooooo0_l0000Gooooo`;o0000?_oo
ool001cooooo0_l0000kooooo`[o00001?ooool2o`000003ooooool0003o000000Kooooo0_l0000:
ooooo`?o00009_ooool2o`0000[ooooo1ol00009ooooo`Ko00000_ooool4o`0000Wooooo0_l00007
ooooo`Co00003_ooool2o`000004ooooool0003o0000o`0000cooooo0ol00007ooooo`;o00005ooo
ool2o`000003ooooool0003o000000[ooooo0_l0000_ooooo`007?ooool00ol0003oooooooooo`0j
ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000002o`000004ooooool0003o
0000o`0000?ooooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l00005ooooo`?o00007_oo
ool3o`0000Gooooo0_l00008ooooo`go00001Oooool2o`000003ooooool0003o000000;o00003_oo
ool2o`0000Oooooo1Ol0000Nooooo`Co00002Oooool2o`0001Sooooo0_l0000:ooooo`;o0000;ooo
ool001cooooo00?o0000ooooooooool0A?ooool2o`000004ooooool0003o0000o`0000?ooooo0_l0
00000ooooooo0000o`000002o`0000Cooooo1?l00003ooooo`;o000000?oooooo`000?l000000ooo
ool2o`0000?ooooo0_l0000Booooo`?o00003oooool5o`0000;ooooo2Ol00005ooooo`Co00005ooo
ool5o`0001kooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo0_l0001Eooooo`007?ooool0
0ol0003oooooooooo`0kooooo`;o00002?ooool2o`000003ooooool0003o000000Gooooo1?l00005
ooooo`Go00001Oooool2o`0000?ooooo1?l000000ooooooo0000o`00000Cooooo`;o00001?ooool2
o`0000Oooooo1?l000000ooooooo0000o`000004ooooo`Wo00002oooool3o`00013ooooo0_l0000J
ooooo`?o00001Oooool6o`0000;ooooo0_l0001Iooooo`007?ooool00ol0003oooooooooo`0ioooo
o`Co00002?ooool2o`000003ooooool0003o000000Cooooo1ol00006ooooo`;o00003?ooool2o`00
00?ooooo0ol0000@ooooo`;o00000_ooool4o`0000Oooooo1?l0000=ooooo`?o00002?ooool2o`00
0003ooooool0003o000000;o00004?ooool2o`0000cooooo0_l0000;ooooo`Co00001?ooool5o`00
05kooooo000Looooo`03o`000?oooooooooo03Sooooo0ol0000=ooooo`;o00000_ooool5o`0000;o
oooo0_l00006ooooo`Co00001_ooool2o`0000Oooooo0ol0000Dooooo`;o00002?ooool3o`0001?o
oooo0_l00004ooooo`?o00000oooool2o`000003ooooool0003o000000gooooo0_l000000ooooooo
0000o`000009ooooo`;o00003Oooool3o`0000Kooooo0_l0000/ooooo`?o0000;oooool001cooooo
00?o0000ooooooooool0>?ooool2o`0000;ooooo0_l0000=ooooo`Co00001?ooool2o`0000Gooooo
0_l000000ooooooo0000o`000002o`0000?ooooo1_l00006ooooo`;o00007Oooool3o`0000Gooooo
0ol00002ooooo`;o00000oooool2o`000004ooooool0003o0000o`0000Cooooo1?l00003ooooo`Co
00002_ooool2o`0000Cooooo0_l0000Hooooo`?o00000oooool2o`000003ooooool0003o000002co
oooo0ol0000_ooooo`007?ooool00ol0003oooooooooo`0looooo`;o00003?ooool6o`0000Oooooo
1Ol00003ooooo`;o00000oooool6o`0000Kooooo0_l0000>ooooo`Co00002Oooool5o`0000Gooooo
0ol00002ooooo`?o00000_ooool2o`000004ooooool0003o0000ooooo`;o00000_ooool4o`0000?o
oooo0_l0000<ooooo`;o00009?ooool2o`00067ooooo000Looooo`03o`000?oooooooooo03Sooooo
0ol0000?ooooo`Ko00001?ooool2o`000004ooooool0003o0000o`0000gooooo1?l0000=ooooo`;o
00001Oooool5o`0000Oooooo1?l00005ooooo`;o00001oooool2o`0000?ooooo0_l00003ooooo`;o
00001?ooool4o`0000;ooooo0_l0002Dooooo`007?ooool00ol0003oooooooooo`0hooooo`Co0000
3_ooool2o`0000Sooooo0_l0000Cooooo`Co00001Oooool4o`0000;ooooo0_l00005ooooo`;o0000
2Oooool5o`0000Gooooo0_l00003ooooo`;o00001oooool2o`0000?ooooo0ol00003ooooo`Co0000
0_ooool2o`0001Oooooo1?l0001iooooo`007?ooool00ol0003oooooooooo`0hooooo`Co00007_oo
ool3o`0000?ooooo1Ol00006ooooo`;o000000?oooooo`000?l000000_ooool4o`0000Wooooo0_l0
0009ooooo`?o00001?ooool2o`0000Kooooo0_l00006ooooo`;o00001?ooool4o`0000?ooooo0ol0
000Kooooo`Co0000NOooool001cooooo00?o0000ooooooooool0=?ooool2o`000003ooooool0003o
000000oooooo0_l0000=ooooo`So000000?oooooo`000?l000001?l00008ooooo`;o00000_ooool3
o`0000[ooooo0_l00005ooooo`Ko00001Oooool2o`0000_ooooo0_l000000ooooooo0000o`000003
ooooo`;o000000?oooooo`000?l000001?ooool3o`000003ooooool0003o000000kooooo0ol00000
0ooooooo0000o`00001>ooooo`;o0000<?ooool001cooooo00?o0000ooooooooool0=?ooool2o`00
0003ooooool0003o000000?o00003?ooool2o`0000cooooo1?l00003ooooo`;o000000?oooooo`00
0?l000001Ol00009ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Wooooo1Ol00002oooo
o`?o00003_ooool2o`0000Kooooo0_l000000ooooooo0000o`000005ooooo`;o000000?oooooo`00
0?l000003_ooool3o`000003ooooool0003o000004?ooooo0ol00008ooooo`;o0000<?ooool001co
oooo00?o0000ooooooooool0=oooool5o`0000cooooo0_l00009ooooo`Ko00000oooool2o`0000;o
oooo2Ol00003ooooo`;o00000_ooool2o`0000Wooooo0_l0000:ooooo`Co00000_ooool3o`0001Ko
oooo0_l000000ooooooo0000o`000005ooooo`;o0000F_ooool3o`0000Sooooo0_l0000`ooooo`00
7?ooool00ol0003oooooooooo`0fooooo`?o00003oooool2o`0000Wooooo0ol00003ooooo`Ko0000
00?oooooo`000?l000001ol00003ooooo`;o00001?ooool2o`0000kooooo0ol00002ooooo`Co0000
1oooool2o`0000Kooooo0_l00005ooooo`;o00000oooool2o`0000Oooooo0ol00019ooooo`;o0000
0oooool3o`0004Kooooo000Looooo`03o`000?oooooooooo03Kooooo0_l00008ooooo`;o00001_oo
ool2o`0000gooooo2?l000001?oooooo0000o`000?l00002ooooo`Co00000_ooool3o`0000Cooooo
0_l000000ooooooo0000o`000002o`0000Wooooo0ol00004ooooo`;o000000?oooooo`000?l00000
1?ooool2o`0000?ooooo0_l000000ooooooo0000o`000005ooooo`;o00000_ooool2o`0000Sooooo
1?l0000?ooooo`;o0000=oooool2o`000003ooooool0003o000000?o00000_ooool2o`0004;ooooo
000Looooo`;o0000@Oooool2o`0000Gooooo0ol0000=ooooo`go000000?oooooo`000?l000001_l0
0006ooooo`Ko00000_ooool5o`0000;ooooo1?l000000ooooooo0000o`000003ooooo`;o00002Ooo
ool2o`0000Oooooo0_l00003ooooo`;o00001oooool5o`0000Cooooo0_l00009ooooo`;o00003Ooo
ool2o`0002Cooooo0_l00002ooooo`Go000000?oooooo`000?l000000_ooool2o`0004;ooooo000L
ooooo`03o`000?oooooooooo04Oooooo0ol000000ooooooo0000o`000007ooooo`[o000000Cooooo
o`000?l0003ooooo2ol00006ooooo`;o00001?ooool7o`0000;ooooo1?l000001?oooooo0000o`00
0?ooool2o`0001Cooooo0_l0000<ooooo`Go00000oooool3o`0000Sooooo0_l00002ooooo`;o0000
2_ooool2o`0002Cooooo0_l00002ooooo`Go000000?oooooo`000?l000000_l000000ooooooo0000
o`00000?ooooo`;o0000<?ooool001cooooo00?o0000ooooooooool0<_ooool2o`0000Gooooo0_l0
0002ooooo`;o00001?ooool2o`0000;ooooo0_l00002ooooo`;o00001oooool9o`0000Cooooo1Ol0
0002ooooo`?o00002_ooool3o`000003ooooool0003o000000;o00003?ooool3o`00013ooooo0_l0
000>ooooo`Oo00000oooool2o`0000Wooooo0_l000001?oooooo0000o`000?l00008ooooo`;o0000
9oooool2o`0000Oooooo1?l000000ooooooo0000o`00000?ooooo`;o0000<?ooool001cooooo00?o
0000ooooooooool0<_ooool2o`0000Gooooo0_l00002ooooo`;o00001?ooool2o`0000_ooooo0_l0
0002ooooo`?o000000?oooooo`000?l000002_l0000Aooooo`?o00002oooool2o`0000Cooooo0_l0
000Aooooo`;o00000oooool2o`0000Gooooo2ol0000>ooooo`Go00002Oooool3o`0002Kooooo0_l0
0005ooooo`Co0000A_ooool001cooooo00?o0000ooooooooool0<oooool2o`0000Cooooo0_l00007
ooooo`;o00000oooool2o`0000Oooooo0_l00002ooooo`;o00000oooool9o`0000;ooooo0_l0000@
ooooo`;o00000_ooool2o`0000Oooooo0_l00006ooooo`;o00005?ooool2o`0000Cooooo2ol0000?
ooooo`Co00002oooool2o`0002gooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o
0000043ooooo000Looooo`03o`000?oooooooooo037ooooo1?l00003ooooo`;o000000?oooooo`00
0?l000001Oooool2o`0000;ooooo0ol000000ooooooo0000o`000008ooooo`;o00003_ooool2o`00
013ooooo0_l00002ooooo`;o00001oooool2o`0000Kooooo0_l0000Iooooo`_o00006oooool2o`00
03Cooooo1ol0000>ooooo`;o0000<?ooool001cooooo00?o0000ooooooooool0<Oooool3o`0000Co
oooo0_l000000ooooooo0000o`000004ooooo`;o00000oooool3o`000003ooooool0003o000000Oo
oooo0_l00009ooooo`;o00006_ooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`00
01[ooooo0_l000000ooooooo0000o`00000:o`0001_ooooo0_l00003ooooo`;o00001Oooool2o`00
02Sooooo0_l000001?oooooo0000o`000?l0000=ooooo`Go0000;oooool001cooooo00?o0000oooo
ooooool0<_ooool2o`0000Oooooo0_l00004ooooo`;o00000oooool2o`0000Gooooo0_l00004oooo
o`;o00002Oooool2o`0000Gooooo0_l0000Iooooo`So00001?ooool2o`0000oooooo0_l00003oooo
o`oo00008?ooool2o`0000Gooooo0_l00003ooooo`;o00002_ooool2o`0000Kooooo0_l000000ooo
oooo0000o`00000;ooooo`Co00001?ooool2o`0000[ooooo0_l000000ooooooo0000o`00000_oooo
o`007?ooool00ol0003oooooooooo`0booooo`;o00002_ooool2o`0000Cooooo1_l00003ooooo`;o
00001?ooool2o`0000?ooooo1?l00008ooooo`?o00006oooool2o`000003ooooool0003o000000Go
oooo0_l0000?ooooo`;o00000oooool>o`0000Cooooo0ol0000<ooooo`;o00002Oooool2o`0000[o
oooo1Ol0000:ooooo`;o000000?oooooo`000?l000000oooool2o`000003ooooool0003o000000_o
oooo1?l00004ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0>_ooool2o`0000;ooooo
0_l00004ooooo`?o000000?oooooo`000?l000000_ooool4o`0000?ooooo1?l000000ooooooo0000
o`000002o`0000Cooooo0_l00002ooooo`;o00008?ooool2o`0001;ooooo0_l00006ooooo`ko0000
1?ooool3o`0000cooooo0_l00009ooooo`;o00002_ooool3o`0000oooooo0_l0000Cooooo`Ko0000
0_ooool2o`0003kooooo000Looooo`03o`000?oooooooooo03[ooooo0_l00009ooooo`;o00001Ooo
ool4o`0000?ooooo1?l00009ooooo`;o00009?ooool4o`00013ooooo0_l00006ooooo`go00001Ooo
ool6o`0000kooooo0_l00002ooooo`;o0000<oooool6o`0004;ooooo000Looooo`03o`000?oooooo
oooo04_ooooo0ol00005ooooo`?o00002_ooool2o`0002Kooooo0_l0000Gooooo`go00001_ooool6
o`0000Cooooo0_l00008ooooo`;o00000_ooool2o`000003ooooool0003o000002Cooooo0_l0001B
ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00002_ooool2o`000003ooooool0003o0000
00;ooooo1Ol0000@ooooo`;o0000;oooool2o`0000cooooo3_l0000Aooooo`;o00002Oooool2o`00
00Cooooo0_l000000ooooooo0000o`000004o`0001gooooo0_l0000<ooooo`?o0000@oooool001co
oooo00?o0000ooooooooool0>?ooool2o`0000?ooooo0_l00005ooooo`;o000000?oooooo`000?l0
00000_ooool2o`000004ooooool0003o0000o`0000cooooo0_l0000_ooooo`;o000000?oooooo`00
0?l000003?ooool;o`0001Cooooo0ol00003ooooo`;o00000oooool4o`0000Gooooo1_l00004oooo
o`;o00005oooool2o`0000cooooo0ol0000?ooooo`;o0000<_ooool001cooooo00?o0000oooooooo
ool0?Oooool2o`000003ooooool0003o000000;ooooo0_l00009ooooo`;o00002Oooool2o`000003
ooooool0003o000001Sooooo0_l000001Ooooooo0000o`000?l0003ooooo00?o00003Oooool2o`00
0003ooooool0003o000000cooooo2_l00004ooooo`;o00001?ooool2o`0000Gooooo0_l00002oooo
o`?o00000oooool2o`0000Gooooo0_l0000:ooooo`;o00000oooool2o`0000Kooooo0_l00002oooo
o`;o00000_ooool2o`0000Kooooo0ol00004ooooo`?o00001?ooool3o`00013ooooo0_l0000boooo
o`007?ooool00ol0003oooooooooo`10ooooo`;o00000_ooool2o`0000Cooooo0ol00002ooooo`;o
00002Oooool3o`0001Gooooo0_l00003ooooo`;o000000?oooooo`000?l000001Ol000000ooooooo
0000o`000002o`0001Wooooo2Ol00005ooooo`;o00001?ooool2o`0000Gooooo0_l0000Jooooo`Go
00002Oooool2o`0000;ooooo0_l00002ooooo`;o00001_ooool2o`0000Gooooo0ol000000ooooooo
0000o`000003o`00017ooooo0_l0000booooo`007?ooool2o`0003Gooooo0_l0000<ooooo`;o0000
1_ooool3o`0000;ooooo0_l00007ooooo`;o000000?oooooo`000?l000005Oooool2o`0000Oooooo
3Ol00002ooooo`;o00001Oooool2o`000003ooooool0003o000000Sooooo2_l0000Gooooo`?o0000
1?ooool4o`0000?ooooo0_l00006ooooo`Ko000000Coooooo`000?l0003o00007Oooool2o`000003
ooooool0003o000000?o00004?ooool2o`0003?ooooo000Looooo`03o`000?oooooooooo03Cooooo
0_l0000<ooooo`;o00001_ooool2o`0000?ooooo0ol00006ooooo`;o00005_ooool4o`0000Oooooo
3_l000000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l000002?ooool7o`00013ooooo
0_l00008ooooo`?o00000_ooool6o`000003ooooool0003o000000?o000000?oooooo`000?l00000
1_l00003ooooo`Go00007Oooool3o`0001?ooooo0_l0000cooooo`007?ooool00ol0003ooooooooo
o`13ooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`;o00001_ooool2o`0001?ooooo
0_l000000ooooooo0000o`00000;ooooo`Ko000000Coooooo`000?l0003ooooo1?l0000Aooooo`Wo
00002?ooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool=o`000003ooooool0003o000000Ko
00001_ooool2o`0001Wooooo0_l00002ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0
=_ooool2o`0000_ooooo0_l00005ooooo`;o000000?oooooo`000?l000000ol00005ooooo`;o0000
5?ooool2o`0000kooooo1_l00004ooooo`Go00002_ooool2o`0000Cooooo1ol0000:ooooo`;o0000
0oooool2o`0000Sooooo0_l00002ooooo`;o000000?oooooo`000?l000002ol000000ooooooo0000
o`000006o`0000Kooooo0ol00003ooooo`;o00004oooool4o`0004_ooooo000Looooo`03o`000?oo
oooooooo03Cooooo1_l00009ooooo`;o00002Oooool4o`0000?ooooo1?l0000Pooooo`;o00000_oo
ool3o`0000Oooooo1_l00009ooooo`;o00001Oooool6o`0000Cooooo0_l00009ooooo`;o00000_oo
ool2o`0000Sooooo0_l00003ooooo`Go00000_ooool?o`0000;ooooo1Ol00003ooooo`Co00003ooo
ool7o`0000Gooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`0cooooo`Co000000?ooooo
o`000?l000002Oooool2o`0000?ooooo0ol000000ooooooo0000o`000009o`0001gooooo0_l00002
ooooo`oo00000oooool3o`0000Oooooo1?l00005ooooo`Ko00001?ooool2o`0000Sooooo2Ol0000<
ooooo`?o00000_ooool@o`0000;ooooo1?l00002ooooo`;o00000_ooool2o`0000;ooooo0_l0000;
ooooo`?o00000_ooool2o`0000?ooooo1?l0000;ooooo`?o0000=Oooool001cooooo00?o0000oooo
ooooool0<oooool4o`0000_ooooo0_l00004ooooo`oo00007Oooool2o`000003ooooool0003o0000
017o000000Coooooo`000?l0003o00001_ooool5o`0000?ooooo1_l0000?ooooo`Go00000_ooool2
o`0000gooooo5_l000001?oooooo0000o`000?l00002ooooo`;o00001_ooool2o`0000_ooooo1?l0
00000ooooooo0000o`000002o`000003ooooool0003o000000gooooo0ol0000eooooo`007?ooool0
0ol0003oooooooooo`0booooo`;o000000?oooooo`000?l000001?ooool2o`0000Gooooo0_l00006
ooooo`Wo00005oooool3o`0000Cooooo7ol00005ooooo`Co00000oooool5o`0000kooooo0_l0000G
oooooa_o00001Oooool2o`0000oooooo0ol00002ooooo`?o00004?ooool2o`0003Kooooo000Loooo
o`03o`000?oooooooooo03;ooooo0_l00007ooooo`;o00001Oooool2o`0000?ooooo0_l000000ooo
oooo0000o`000007o`0001Oooooo0ol00002ooooob7o00001?ooool2o`000003ooooool0003o0000
00Cooooo1?l0000>ooooo`Co00001_ooool3o`0000Gooooo1Ol00002oooooaSo000000?oooooo`00
0?l000001Oooool2o`0000cooooo0_l000000ooooooo0000o`000002ooooo`?o0000BOooool001co
oooo00?o0000ooooooooool0>oooool2o`0000Gooooo0_l00003ooooo`;o00000_ooool6o`0001Oo
oooo0ol00004ooooo`;o00000ooooolMo`0000?ooooo0_l00007ooooo`Co00002?ooool2o`0000Ko
oooo0_l00006ooooo`?o00001OoooolRo`0000Oooooo0_l0000:ooooo`Go00000_ooool3o`0004Wo
oooo000Looooo`03o`000?oooooooooo03Gooooo0_l00004ooooo`Co00000oooool2o`0000?ooooo
0_l00002ooooo`;o00006oooool3o`0000Kooooo8?l00007ooooo`;o00000oooool4o`0000Sooooo
0_l00007ooooo`;o00001?ooool2o`0000Wooooo0_l000000ooooooo0000o`00000No`000004oooo
ool0003o0000ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000;ooooo1Ol00002oooo
o`?o0000B_ooool001cooooo00?o0000ooooooooool0<_ooool2o`000003ooooool0003o000000Go
oooo0ol00003ooooo`;o00000oooool2o`0002Sooooo8?l00005ooooo`Co00000_ooool4o`0000_o
oooo0_l00005ooooo`?o00000oooool2o`0000_ooooo8Ol000000ooooooo0000o`000004ooooo`?o
000000?oooooo`000?l000001ol00002ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0
<_ooool2o`0000Sooooo0_l00004ooooo`;o00000_ooool2o`00023ooooo0_l00005ooooob;o0000
1Oooool3o`000003ooooool0003o000000?o00003?ooool3o`0000Gooooo0_l00002ooooo`?o0000
1_ooool2o`0000?ooooo8Ol00002ooooo`Co000000?oooooo`000?l000000oooool4o`0005?ooooo
000Looooo`03o`000?oooooooooo03;ooooo0_l000000ooooooo0000o`00000?ooooo`;o00001Ooo
ool2o`0001Wooooo0_l00005ooooob;o00001Oooool3o`000003ooooool0003o000000?o00002_oo
ool2o`000003ooooool0003o000000?ooooo0_l00004ooooo`;o00001oooool2o`0000?ooooo2ol0
00000ooooooo0000o`00000Bo`0000?ooooo1?l0000Oooooo`?o0000>oooool00006ooooooo^k^ko
<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03
o`000?oooooooooo03Gooooo0_l0000?ooooo`;o00001?ooool3o`0001oooooo0_l00004oooooago
00002Oooool5o`0000[ooooo0_l00006ooooo`;o00002?ooool2o`0000?ooooo0_l00003ooooo`;o
000000?oooooo`000?l000006ol0000<ooooo`;o000000?oooooo`000?l000001_ooool3o`0000co
oooo0ol0000kooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmE
EEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0?_ooool2o`000003ooooool0003o
000000Cooooo0ol00002ooooo`;o00008?ooool2o`000004ooooool0003o0000oooooago00001Ooo
ool2o`0000;ooooo1Ol00009ooooo`;o00004Oooool2o`0000?ooooo1?l000000ooooooo0000o`00
000Mo`0000?ooooo1?l00003ooooo`;o000000?oooooo`000?l000000ol00003ooooo`;o000000Co
ooooo`000?l0003o0000B_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0?_ooool2o`000003oooo
ool0003o000000Cooooo1_l0000Sooooo`Co000000?oooooo`000?l000006ol00004ooooo`;o0000
0_ooool4o`0000[ooooo0_l0000Cooooo`;o00000_ooool3o`000003ooooool0003o000001Wo0000
0_ooool3o`0000;ooooo1?l000000ooooooo0000o`000002o`0000;ooooo0ol00004ooooo`;o0000
3_ooool2o`0003kooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go
0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000@Oooool2o`0000Kooooo1?l0000Iooooo`;o0000
0_ooool2o`0000Cooooo8_l000000ooooooo0000o`000002o`0000;ooooo1Ol0000;ooooo`;o0000
0oooool2o`0000gooooo0_l000000ooooooo0000o`000005o`000003ooooool0003o000001Ko0000
0_ooool3o`0000Cooooo1Ol00004ooooo`;o00000oooool2o`00013ooooo0_l0000nooooo`0000?o
ooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
1_ooool00ol0003oooooooooo`11ooooo`;o00001oooool2o`0001[ooooo0_l00002ooooo`;o0000
0ooooolQo`0000?ooooo1?l000000ooooooo0000o`000003o`0000Wooooo1Ol00003ooooo`;o0000
1?ooool2o`0000;ooooo0ol00002ooooo`;o000000?oooooo`000?l000001Ol00002oooooaOo0000
00?oooooo`000?l000000_l00002ooooo`Ko000000?oooooo`000?l000001_ooool3o`000003oooo
ool0003o000004gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00?o
EEEEohN7Qoooool02?ooool00ol0003oooooooooo`0fooooo`;o00002Oooool2o`0000Oooooo0_l0
000Jooooo`;o00001Oooool5o`000003ooooool0003o000001_o00000oooool2o`0000?ooooo1Ol0
0009ooooo`Co000000?oooooo`000?l000000_l00005ooooo`;o00000_ooool3o`0000;ooooo0_l0
00000ooooooo0000o`000002o`0000Gooooo2?l000000ooooooo0000o`00000<o`000003ooooool0
003o000000;o00000_ooool2o`0000Gooooo0_l00004ooooo`Co00000_ooool2o`0000_ooooo0_l0
0010ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo
00?o0000ooooooooool0=_ooool2o`0000?ooooo0_l00004ooooo`;o00000oooool2o`0001kooooo
0_l00005ooooo`;o000000?oooooo`000?l000000_ooool3o`000003ooooool0003o000001Ko0000
1Oooool6o`0000cooooo0_l00002ooooo`So00002oooool2o`000003ooooool0003o000000;o0000
00?oooooo`000?l000000ooooolKo`0000kooooo0ol0000?ooooo`?o0000@?ooool00006ooooooo^
k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo
03Oooooo0_l00002ooooo`;o00001?ooool2o`0000?ooooo0_l0000Sooooo`;o000000?oooooo`00
0?l000000_l00002ooooo`;o00000_oooolHo`0000?ooooo2?l0000<ooooo`;o00000oooool2o`00
0003ooooool0003o000000;o00002ooooolQo`000003ooooool0003o000000Go00002?ooool2o`00
00Cooooo0_l0000?ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0=oooool2o`0000So
oooo0_l00007ooooo`;o00005oooool2o`0000Kooooo0_l000000ooooooo0000o`00000Qo`0000;o
oooo2?l0000Aooooo`Co00003_ooool3o`0000;ooooo1?l000000ooooooo0000o`00000Go`000003
ooooool0003o000000?o00002?ooool3o`000003ooooool0003o000005Cooooo000Looooo`03o`00
0?oooooooooo04;ooooo0_l00006ooooo`;o00005oooool4o`0000Cooooo9_l00004ooooo`Ko0000
2_ooool2o`0000Oooooo0_l0000Hooooo`Go00000oooool;o`000003ooooool0003o000000Wo0000
0_ooool2o`0000?ooooo1ol0000>ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0@_oo
ool2o`00027ooooo0_l00004ooooobKo00001Oooool3o`0000cooooo0_l00006ooooo`;o00004ooo
ool2o`0000Oooooo0ol00002oooooa?o00001_ooool2o`0000?ooooo0_l000001?oooooo0000o`00
0?l0000?ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0?_ooool3o`0002Wooooo:_l0
0003ooooo`;o00003?ooool2o`0000?ooooo0_l000000ooooooo0000o`00000Cooooo`;o00002?oo
ool4o`000003ooooool0003o000000_o00003_ooool2o`0000Cooooo0_l0000=ooooo`;o0000A_oo
ool001cooooo00?o0000ooooooooool0?_ooool3o`0002Wooooo0_l000000ooooooo0000o`00000G
o`0000;ooooo4Ol0000?ooooo`Co00007_ooool6o`000003ooooool0003o000000co00003?ooool3
o`0001?ooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`1[ooooo`?o000000?oooooo`00
0?l000006?l00003ooooo`Ko000000?oooooo`000?l000000ol0000;ooooo`;o00000oooool2o`00
01[ooooo1?l00002ooooo`Co00000oooool6o`000003ooooool0003o000000Go00000_ooool2o`00
00Sooooo0_l0000Booooo`?o0000Aoooool001cooooo00?o0000ooooooooool0>?ooool2o`0002Wo
oooo0_l00006ooooo`?o000000?oooooo`000?l000005?l000000ooooooo0000o`00000?o`0000co
oooo0_l000000ooooooo0000o`000002ooooo`;o00006?ooool4o`0001Wooooo0_l00003ooooo`;o
00001oooool2o`0000cooooo1Ol00017ooooo`007?ooool00ol0003oooooooooo`0hooooo`?o0000
2?ooool2o`0001kooooo0_l00008oooooaoo000000?oooooo`000?l000002?l0000>ooooo`?o0000
0_ooool2o`0001[ooooo0_l0000Nooooo`;o00001oooool2o`0000cooooo0_l0001:ooooo`007?oo
ool00ol0003oooooooooo`0iooooo`;o00002?ooool2o`00023ooooo0_l00002ooooo`ko00000ooo
ool=o`0000;ooooo3_l0000>ooooo`Co00000_ooool2o`0001Wooooo0_l0000Kooooo`;o00006?oo
ool2o`0004[ooooo000Looooo`03o`000?oooooooooo03Wooooo0_l0000Zooooo`;o00000_ooool5
o`000003ooooool0003o000000Ko00000ooooolKo`00017ooooo0ol00002ooooo`;o00008_ooool2
o`0000oooooo0_l000000ooooooo0000o`000004ooooo`;o00003_ooool2o`0004kooooo000Loooo
o`03o`000?oooooooooo03Wooooo0_l00004ooooo`;o0000:_ooool4o`0000;ooooo0_l00004oooo
oago00002_ooool2o`0000Kooooo0_l0000Wooooo`;o000000?oooooo`000?l000001Oooool4o`00
00?ooooo0_l00007ooooo`;o00003Oooool3o`0004kooooo000Looooo`;o0000>_ooool2o`0000Co
oooo1?l00002ooooo`;o00009?ooool4o`0000Cooooo2ol000000ooooooo0000o`000007o`0000;o
oooo1ol0000=ooooo`;o00000_ooool2o`0002kooooo0_l00005ooooo`Ko000000?oooooo`000?l0
00005Oooool3o`0004oooooo000Looooo`03o`000?oooooooooo03Wooooo0_l00006ooooo`;o0000
0_ooool3o`0002Oooooo0_l00002oooooako00003Oooool2o`0000;ooooo0_l0000/ooooo`;o0000
2oooool2o`0001Gooooo0_l000000ooooooo0000o`00001@ooooo`007?ooool00ol0003ooooooooo
o`0kooooo`;o00001?ooool2o`0000?ooooo0_l0000Wooooo`;o00000oooool5o`000003ooooool0
003o0000017o00004?ooool2o`0000;ooooo0ol0000Eooooo`So00003oooool2o`0000_ooooo0ol0
000Booooo`Co0000Doooool001cooooo00?o0000ooooooooool0>oooool2o`0000_ooooo0_l0000T
ooooo`;o00000oooool6o`000003ooooool0003o0000013o00004Oooool2o`0000;ooooo0ol00000
0ooooooo0000o`00000@ooooo`_o00007?ooool2o`0000oooooo1_l0001Dooooo`007?ooool00ol0
003oooooooooo`11ooooo`;o00001Oooool2o`00027ooooo3?l00009ooooo`;o000000?oooooo`00
0?l000001Ol0000Gooooo`;o00000_ooool2o`00013ooooo0_l00005ooooo`Co00000oooool2o`00
00;ooooo0_l0000Rooooo`Ko0000E_ooool001cooooo00?o0000ooooooooool0@Oooool2o`0000;o
oooo0_l00002ooooo`;o00008?ooool9o`000003ooooool0003o000002[ooooo1?l0000Booooo`;o
000000?oooooo`000?l000002Oooool6o`0001gooooo0_l000000ooooooo0000o`000004o`0005So
oooo000Looooo`03o`000?oooooooooo04Gooooo0_l00002ooooo`?o00006_ooool2o`0000Gooooo
1ol000000ooooooo0000o`00000Vooooo`;o00000oooool3o`00017ooooo0ol000000ooooooo0000
o`00000;ooooo`;o00000_ooool2o`0000;ooooo0_l0000Gooooo`Go0000G?ooool001cooooo00?o
0000ooooooooool0??ooool3o`0000Kooooo0_l00003ooooo`;o00006_ooool2o`0000Gooooo1ol0
000Vooooo`;o000000?oooooo`000?l000000oooool2o`0001;ooooo0ol0000Booooo`;o00000_oo
ool6o`00013ooooo0_l00002ooooo`?o0000GOooool001cooooo00?o0000ooooooooool0??ooool3
o`0000Kooooo0_l00005ooooo`Co00007Oooool3o`000005ooooool0003o0000o`000?ooool00_l0
000Sooooo`;o00000_ooool2o`0001Sooooo0_l0000Fooooo`Oo00003?ooool4o`0006;ooooo000L
ooooo`03o`000?oooooooooo04cooooo1?l0000Mooooo`;o00000_ooool3o`000004ooooool0003o
0000o`0002Kooooo0_l0000Hooooo`;o00005oooool?o`0000?ooooo0_l0001Tooooo`007?ooool0
0ol0003oooooooooo`1>ooooo`;o00004Oooool2o`0000oooooo0_l000001?oooooo0000o`000?l0
0010ooooo`Co00001oooool2o`0000;ooooo0ol00009ooooo`;o00000_ooool9o`0006Wooooo000L
ooooo`03o`000?oooooooooo04kooooo0_l0000Aooooo`;o00003oooool7o`0001Wooooo0_l00004
ooooo`;o00008?ooool2o`0000Oooooo0_l00002ooooo`?o00002Oooool2o`0000;ooooo0_l00002
ooooo`Co0000J_ooool001cooooo00?o0000ooooooooool0Aoooool2o`0000Kooooo0_l0000@oooo
o`?o00000oooool2o`0000Wooooo1ol0000Iooooo`;o00001?ooool2o`0003cooooo0_l0000coooo
o`;o0000??ooool001cooooo00?o0000ooooooooool0Aoooool2o`0000Kooooo0_l0000@ooooo`?o
00000oooool2o`0000Kooooo1Ol0000Tooooo`;o00000oooool2o`0002kooooo0_l00007ooooo`;o
00005_ooool2o`0001_ooooo0_l0000looooo`007?ooool00ol0003oooooooooo`1Qooooo`;o0000
3?ooool7o`0001Gooooo0_l0000?ooooo`Go0000;?ooool2o`0000Oooooo0_l00007ooooo`;o0000
3Oooool2o`0005Wooooo000Looooo`03o`000?oooooooooo05;ooooo0ol0000Kooooo`Ko00005Ooo
ool2o`0000oooooo1Ol0000/ooooo`;o00001oooool2o`0000Gooooo1?l00003ooooo`;o000000Co
ooooo`000?l0003ooooo0ol0001Looooo`007?ooool2o`0005?ooooo1?l0000Kooooo`?o00000ooo
ool2o`0001;ooooo0ol0000booooo`;o00002Oooool4o`0000kooooo0_l00005ooooo`;o000000Co
ooooo`000?l0003ooooo0ol00002ooooo`;o0000F?ooool001cooooo00?o0000ooooooooool0B_oo
ool2o`0000Oooooo0ol0000Kooooo`;o000000Coooooo`000?l0003ooooo0_l0000Booooo`?o0000
<Oooool3o`0000Oooooo1?l0000Rooooo`;o00005?ooool2o`0004;ooooo000Looooo`03o`000?oo
oooooooo04[ooooo0_l0000Xooooo`;o00000_ooool3o`0000kooooo1?l0000aooooo`Co00001ooo
ool3o`0000gooooo0_l00002ooooo`;o00009Oooool3o`0004;ooooo000Looooo`03o`000?oooooo
oooo04[ooooo0ol00002ooooo`;o00005?ooool2o`00017ooooo0ol0000>ooooo`Co0000<Oooool3
o`0000Wooooo0_l00007ooooo`;o00000oooool7o`0000Oooooo0_l0000Kooooo`?o0000@oooool0
01cooooo00?o0000ooooooooool0Boooool2o`0000;ooooo0ol0000Cooooo`;o00004_ooool2o`00
00Cooooo0_l0000>ooooo`;o00001oooool2o`0002;ooooo0_l00008ooooo`;o00001_ooool2o`00
00?ooooo0_l00003ooooo`;o000000?oooooo`000?l000002Oooool2o`0001_ooooo0_l00014oooo
o`007?ooool00ol0003oooooooooo`16ooooo`;o00002?ooool2o`0001Wooooo0_l000000ooooooo
0000o`00000?ooooo`?o00002Oooool2o`0000;ooooo0_l00007ooooo`?o00008?ooool3o`0000Ko
oooo1?l00002ooooo`?o000000?oooooo`000?l000004oooool2o`0006Cooooo000Looooo`03o`00
0?oooooooooo04Kooooo0_l0000Sooooo`;o000000?oooooo`000?l000003Oooool6o`0000Gooooo
0_l000000ooooooo0000o`00000<ooooo`;o00008?ooool2o`0000Cooooo0_l000000ooooooo0000
o`000002o`0000;ooooo0ol00006ooooo`;o00002Oooool3o`0000;ooooo0_l0000Iooooo`;o0000
BOooool001cooooo00?o0000ooooooooool0OOooool6o`0000Gooooo0_l0000=ooooo`;o0000:?oo
ool2o`0000?ooooo0_l0000;ooooo`?o00002?ooool3o`000003ooooool0003o000000Cooooo0_l0
000Dooooo`;o0000BOooool001cooooo00?o0000ooooooooool0B?ooool2o`0001kooooo0_l0000[
ooooo`Co0000>oooool2o`0000cooooo0_l00004ooooo`;o00004oooool2o`0004[ooooo000Loooo
o`03o`000?oooooooooo04Sooooo0_l00005ooooo`?o00005_ooool2o`0002Sooooo0_l000000ooo
oooo0000o`00000/ooooo`Co000000?oooooo`000?l000000_ooool3o`0000Sooooo0_l00002oooo
o`Co00007_ooool2o`0004[ooooo000Looooo`03o`000?oooooooooo04oooooo0ol00002ooooo`;o
00004_ooool2o`0000[ooooo0_l00008ooooo`;o00004_ooool2o`000003ooooool0003o000000?o
oooo0_l0000Wooooo`Oo00000_ooool4o`0000Kooooo0ol00002ooooo`Co0000J_ooool001cooooo
00?o0000ooooooooool0E?ooool3o`000003ooooool0003o000001[ooooo0_l00008ooooo`;o0000
5Oooool2o`0000;ooooo0ol0000Vooooo`?o00000_ooool2o`0000?ooooo1_l00004ooooo`?o0000
0_ooool4o`0006[ooooo000Looooo`03o`000?oooooooooo05Gooooo0_l000000ooooooo0000o`00
000jooooo`?o00000_ooool2o`0000Gooooo0ol0000Oooooo`;o00001_ooool8o`0000Cooooo0_l0
00000ooooooo0000o`000002o`0006cooooo000Looooo`03o`000?oooooooooo05Sooooo0_l0000i
ooooo`?o00002_ooool4o`0002Cooooo1?l00003ooooo`;o00001_ooool4o`0006kooooo000Loooo
o`03o`000?oooooooooo05Cooooo0_l00002ooooo`;o00005Oooool2o`0000;ooooo0_l00004oooo
o`;o00006?ooool2o`000003ooooool0003o000000[ooooo0_l0000Rooooo`Oo00000_ooool2o`00
00Kooooo0ol0001_ooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o00000_ooool2o`0001Go
oooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Kooooo`;o0000;_ooool@o`00
0003ooooool0003o0000073ooooo000Looooo`;o0000H?ooool4o`0000gooooo0_l00004ooooo`;o
00001Oooool2o`0001kooooo0_l0000Looooo`;o00001oooool2o`000003ooooool0003o000000go
0000Loooool001cooooo00?o0000ooooooooool0G_ooool5o`0000gooooo0_l0000;ooooo`;o0000
7_ooool2o`0000Wooooo0_l0000Aooooo`?o00001_ooool2o`0000Kooooo0_l0001kooooo`007?oo
ool00ol0003oooooooooo`1Nooooo`;o00001_ooool2o`0001[ooooo0_l0000Tooooo`;o00004Ooo
ool3o`0000Kooooo0_l0000Zooooo`;o0000Eoooool001cooooo00?o0000ooooooooool0G_ooool2
o`0000Cooooo1_l00006ooooo`;o00002_ooool2o`0000Cooooo0_l00004ooooo`;o000000?ooooo
o`000?l000003_ooool3o`0000_ooooo0_l0000Iooooo`;o00009oooool5o`0005Oooooo000Loooo
o`03o`000?oooooooooo06Cooooo0ol000000ooooooo0000o`000006ooooo`;o00002_ooool2o`00
0003ooooool0003o000000Oooooo0_l000000ooooooo0000o`000003o`0000[ooooo1?l00006oooo
o`;o00000oooool2o`0001Gooooo0_l0000[ooooo`Co0000F?ooool001cooooo00?o0000oooooooo
ool0HOooool3o`0000?ooooo0ol0000Booooo`;o000000?oooooo`000?l000001Oooool2o`0000Go
oooo1_l000000ooooooo0000o`000004ooooo`;o00000oooool2o`0000?ooooo1?l000000ooooooo
0000o`000002o`0001?ooooo0ol000000ooooooo0000o`00000Wooooo`;o0000F_ooool001cooooo
00?o0000ooooooooool0HOooool3o`0000?ooooo0_l0000Cooooo`;o00000_ooool2o`0000Cooooo
0_l00007ooooo`Co000000?oooooo`000?l000000_l00003ooooo`So00000oooool2o`0000;ooooo
0ol0000Dooooo`;o000000?oooooo`000?l000008oooool3o`0005gooooo000Looooo`03o`000?oo
oooooooo05oooooo0ol00003ooooo`;o00006Oooool2o`0000Sooooo0_l000001Ooooooo0000o`00
0?l0003ooooo01;o000000?oooooo`000?l000006oooool2o`0002Kooooo0ol0001Mooooo`007?oo
ool00ol0003oooooooooo`1Oooooo`?o00000oooool2o`0000Oooooo0ol0000@ooooo`;o00001ooo
ool2o`000005ooooool0003o0000o`000?ooool00ol00002ooooo`Go00000oooool4o`0000;ooooo
0_l0000Cooooo`;o00001_ooool2o`0008Kooooo000Looooo`03o`000?oooooooooo06[ooooo0_l0
0002ooooo`?o00004?ooool2o`0000?ooooo0_l00009ooooo`;o00000oooool4o`0000Gooooo0ol0
0002ooooo`Co00004Oooool3o`0008gooooo000Looooo`03o`000?oooooooooo06[ooooo0_l00000
0ooooooo0000o`00000Gooooo`;o00003Oooool5o`0000Kooooo0_l00002ooooo`Co00004_ooool2
o`0000?ooooo0_l0000Qooooo`;o0000IOooool001cooooo00?o0000ooooooooool0IOooool2o`00
00?ooooo1_l0000<ooooo`?o00002_ooool2o`0000[ooooo1ol0000Rooooo`?o00001?ooool2o`00
01_ooooo0_l0001Uooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o00000oooool6o`0000co
oooo0ol00008ooooo`Co00003?ooool2o`000003ooooool0003o000000?o00007oooool3o`0000?o
oooo0ol0000Kooooo`;o0000IOooool001cooooo00?o0000ooooooooool0JOooool2o`000003oooo
ool0003o000000Oooooo0_l00005ooooo`;o00002Oooool4o`000004ooooool0003o0000o`0000go
oooo0ol0000Nooooo`?o00001?ooool2o`0001Sooooo0_l0001Yooooo`0000Koooooonk^k_lb<S;o
0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000
ooooooooool0JOooool2o`0000[ooooo1?l000000ooooooo0000o`000003ooooo`;o00002?ooool2
o`000004ooooool0003o0000o`00023ooooo0_l0000<ooooo`?o00006_ooool3o`000003ooooool0
003o000006Wooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q
8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1`ooooo`;o00000_ooool2o`000004
ooooool0003o0000ooooo`;o00000_ooool3o`00017ooooo0_l0000Kooooo`;o00003Oooool2o`00
01[ooooo0ol0001/ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`1`ooooo`;o00000_ooool2o`00
00Sooooo0_l000000ooooooo0000o`00000?ooooo`Co00000_ooool2o`000:oooooo00000ooooooo
0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06oooo
o`?o0000LOooool2o`000003ooooool0003o000000Kooooo0_l00002ooooo`?o00003_ooool2o`00
0005ooooool0003o0000o`000?ooool00_l0000Fooooo`;o00009?ooool4o`0006oooooo00000ooo
oooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Goc<c<o`000?l0003o0000olc<c006
ooooo`03o`000?oooooooooo077ooooo1Ol00006ooooo`;o00000_ooool4o`0000gooooo1_l00000
0ooooooo0000o`000005ooooo`;o00001oooool2o`0000Kooooo0_l00009ooooo`;o00005oooool6
o`0006oooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go410@okZj
^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo07?ooooo0_l0000=ooooo`Co00003Oooool3
o`0000;ooooo0_l00005ooooo`;o00000oooool2o`000005ooooool0003o0000o`000?ooool00_l0
0003ooooo`;o00001oooool5o`0001Cooooo1?l0001cooooo`0000KoooooogMgMonHV9SooooooiRH
V?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`1booooo`;o
00002_ooool2o`0000Cooooo0_l0000Nooooo`;o000000?oooooo`000?l000000_ooool2o`0000co
oooo0_l000000ooooooo0000o`00000Dooooo`?o0000M?ooool00006ooooooo^k^ko<S8bo`000?lb
<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0L_ooool2
o`0000[ooooo0_l00004ooooo`;o00005?ooool4o`0001Oooooo0ol000000ooooooo0000o`00002>
ooooo`007?ooool00ol0003oooooooooo`1hooooo`Ko00001_ooool2o`0000Kooooo0_l0000<oooo
o`Co00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000;ooooo1?l00002oooo
o`?o00006?ooool2o`0007Oooooo000Looooo`03o`000?oooooooooo07Sooooo2?l00007ooooo`;o
00000oooool2o`0000;ooooo0_l0000@ooooo`;o00000_ooool=o`0001gooooo0_l0001gooooo`00
7?ooool00ol0003oooooooooo`1jooooo`Ko00001oooool2o`0000Oooooo0_l0000Eooooo`;o0000
1?ooool2o`0009[ooooo000Looooo`03o`000?oooooooooo07cooooo0_l00006ooooo`;o00002?oo
ool2o`0000Kooooo0_l0002aooooo`007?ooool00ol0003oooooooooo`24ooooo`;o00001?ooool6
o`0000Kooooo0_l0000cooooo`;o0000O?ooool001cooooo00?o0000ooooooooool0Q?ooool4o`00
00;ooooo1?l0000=ooooo`;o000000?oooooo`000?l00000:oooool2o`0007cooooo000Looooo`03
o`000?oooooooooo08Kooooo0_l00004ooooo`?o00002_ooool4o`000003ooooool0003o000000Wo
oooo0_l000000ooooooo0000o`00000Hooooo`;o0000POooool001cooooo00?o0000ooooooooool0
SOooool2o`0000[ooooo0_l0000>ooooo`;o000000?oooooo`000?l000006?ooool2o`00087ooooo
000Looooo`03o`000?oooooooooo08gooooo0_l0000Pooooo`;o00003Oooool2o`0000;ooooo1Ol0
0022ooooo`007?ooool00ol0003oooooooooo`2=ooooo`;o00002Oooool2o`0001Gooooo1_l00000
0ooooooo0000o`000002ooooo`Ko00000_ooool5o`0008;ooooo000Looooo`03o`000?oooooooooo
09Gooooo0_l000001?oooooo0000o`000?ooool2o`0001?ooooo1Ol000000ooooooo0000o`000002
ooooo`Go0000R_ooool001cooooo0_l0002Fooooo`;o00001?ooool2o`0000gooooo0_l00005oooo
o`?o00001_ooool2o`0008gooooo000Looooo`03o`000?oooooooooo09_ooooo0_l00008ooooo`;o
00000oooool3o`0000Gooooo0_l00005ooooo`Co0000S?ooool001cooooo00?o0000ooooooooool0
YOooool2o`0000Cooooo0_l0000<ooooo`Co0000S?ooool001cooooo00?o0000ooooooooool0W_oo
ool2o`000:Wooooo000Looooo`03o`000?oooooooooo09kooooo0_l0002Yooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Booooo`Co000000?o410@ooooooooool00oooool00ol0003o
ooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`?o0000oooooom:ooooo`005?ooool0
0ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Co
oooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo
000Booooo`03oeEEEOmVIVKo00000?ooooooE?ooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00:Gooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0Eooooo`05
oiRHV?l@413o0000oc8b<_o<c<`01?ooool4o`000003oa0@4?oooooooooo00Go0000T?ooool00:Ko
oooo00Go0000ooooooooooooooooo`000009ooooo`Ko00002Oooool01Ol@413o^[ZjoooooomgMgOo
<S8b00Kooooo00?o0000ooooooooool00_ooool01OnHV9So8B4Qonk^k_ooooooA4A4093ooooo002V
ooooo`05o`000?ooooooooooooooool000007?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?oV9RHob4Q8Oo^k^h0TOooool00:Kooooo00Go0000ooooooooooooooooo`00
0009ooooo`Ko00003?ooool00onYZJWo410@ooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o
V9RHob4Q8Oo^k^h0T?ooool00:Kooooo00Go0000ohN7QoooooooZJVYo`00000Jooooo`03oa0@4?l0
003o^[Zj00Kooooo00?o0000ooooooooool01Oooool00omgMgOoIVIVooooo`2?ooooo`00YOooool0
0ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo01Wooooo00?o^[Zjob4Q8Oooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo08kooooo0033ooooo`05oa0@4?nHV9Sooooo
okZj^_l000001_ooool00ol0003oooooooooo`02ooooo`05o`000?nj^[[ooooooiRHV?l@4100T?oo
ool00<?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@04ooooo`03oeEEEOmVIVKo000000Cooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c02@ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(318) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.62075 .58498 Mdot
.65133 .60601 Mdot
.49233 .31465 Mdot
.41077 .55675 Mdot
.42977 .30027 Mdot
.54805 .31685 Mdot
.66771 .43525 Mdot
.66256 .43865 Mdot
.50998 .31889 Mdot
.39989 .77394 Mdot
.68534 .39736 Mdot
.44478 .58312 Mdot
.66643 .41892 Mdot
.39926 .58213 Mdot
.34514 .47784 Mdot
.35113 .56927 Mdot
.61144 .61179 Mdot
.38427 .33383 Mdot
.35261 .57118 Mdot
.55967 .33001 Mdot
.39366 .69202 Mdot
.4002 .57037 Mdot
.67664 .60338 Mdot
.3971 .5795 Mdot
.39707 .63603 Mdot
.63686 .5989 Mdot
.62584 .58385 Mdot
.41964 .61797 Mdot
.37709 .55627 Mdot
.66668 .4017 Mdot
.47754 .44756 Mdot
.19847 .58175 Mdot
.3504 .62763 Mdot
.56187 .71221 Mdot
.65087 .40807 Mdot
.62221 .37406 Mdot
.54954 .28468 Mdot
.64304 .43925 Mdot
.68039 .39065 Mdot
.69302 .39561 Mdot
.69345 .39803 Mdot
.63428 .59729 Mdot
.66143 .45392 Mdot
.62616 .29706 Mdot
.38568 .58275 Mdot
.62005 .68932 Mdot
.59988 .29011 Mdot
.37703 .6178 Mdot
.66756 .63153 Mdot
.53172 .33503 Mdot
.29167 .3888 Mdot
.66688 .44699 Mdot
.50502 .5443 Mdot
.87837 .47232 Mdot
.66029 .42723 Mdot
.35736 .6068 Mdot
.51527 .30179 Mdot
.41133 .60481 Mdot
.43788 .59494 Mdot
.54225 .68456 Mdot
.42216 .59613 Mdot
.40822 .29786 Mdot
.67944 .58717 Mdot
.56847 .33749 Mdot
.50571 .31723 Mdot
.65221 .44671 Mdot
.65194 .65006 Mdot
.66772 .4065 Mdot
.38816 .55355 Mdot
.54021 .33367 Mdot
.36206 .58751 Mdot
.68525 .39821 Mdot
.6426 .58526 Mdot
.39302 .56542 Mdot
.77641 .59484 Mdot
.61627 .45208 Mdot
.46612 .29483 Mdot
.52 .61502 Mdot
.43096 .3626 Mdot
.39925 .45571 Mdot
.39484 .56646 Mdot
.72923 .27596 Mdot
.32753 .45797 Mdot
.66478 .62744 Mdot
.5076 .5337 Mdot
.7572 .46593 Mdot
.38227 .62925 Mdot
.48408 .44764 Mdot
.42507 .53305 Mdot
.36068 .2685 Mdot
.51871 .31155 Mdot
.64786 .63671 Mdot
.38562 .57467 Mdot
.38906 .55815 Mdot
.49657 .81047 Mdot
.37552 .55433 Mdot
.43407 .60679 Mdot
.5629 .4893 Mdot
.69331 .43227 Mdot
.41068 .64925 Mdot
.48716 .37766 Mdot
.54116 .52679 Mdot
.36072 .61051 Mdot
.52933 .30505 Mdot
.68163 .59162 Mdot
.35119 .62104 Mdot
.67604 .41004 Mdot
.39097 .57233 Mdot
.64372 .4577 Mdot
.67204 .62887 Mdot
.43718 .60567 Mdot
.39045 .30297 Mdot
.51381 .59584 Mdot
.65741 .58951 Mdot
.61062 .76091 Mdot
.42138 .57858 Mdot
.40204 .61089 Mdot
.65134 .60334 Mdot
.56361 .31852 Mdot
.68253 .2535 Mdot
.63943 .58678 Mdot
.69581 .39778 Mdot
.62032 .62682 Mdot
.50084 .56106 Mdot
.56556 .31756 Mdot
.54841 .53828 Mdot
.54463 .54255 Mdot
.23358 .48077 Mdot
.41716 .55938 Mdot
.33738 .68125 Mdot
.5383 .30943 Mdot
.65178 .59279 Mdot
.65989 .4133 Mdot
.39696 .54096 Mdot
.63279 .6147 Mdot
.66763 .43874 Mdot
.38557 .28163 Mdot
.39432 .34026 Mdot
.67294 .60705 Mdot
.63161 .76277 Mdot
.6801 .37552 Mdot
.69076 .44302 Mdot
.29007 .39223 Mdot
.66517 .62687 Mdot
.40621 .31446 Mdot
.68071 .42228 Mdot
.25164 .30589 Mdot
.40656 .63686 Mdot
.26943 .42432 Mdot
.74306 .2985 Mdot
.29242 .38824 Mdot
.36613 .70306 Mdot
.3928 .31165 Mdot
.66798 .43927 Mdot
.36792 .60331 Mdot
.65224 .62194 Mdot
.63222 .61079 Mdot
.36606 .5776 Mdot
.37331 .64197 Mdot
.40059 .59292 Mdot
.35497 .63045 Mdot
.55396 .47481 Mdot
.38675 .57589 Mdot
.7369 .68691 Mdot
.64655 .62638 Mdot
.37034 .63793 Mdot
.55065 .28972 Mdot
.32891 .65061 Mdot
.65911 .45172 Mdot
.43329 .5718 Mdot
.38743 .64157 Mdot
.43966 .55512 Mdot
.69804 .39892 Mdot
.7826 .60868 Mdot
.41085 .35593 Mdot
.68422 .38516 Mdot
.73388 .37257 Mdot
.54298 .29818 Mdot
.41229 .61576 Mdot
.39173 .32291 Mdot
.42388 .64711 Mdot
.38049 .5697 Mdot
.29639 .38136 Mdot
.43337 .60137 Mdot
.35487 .70084 Mdot
.33849 .55658 Mdot
.75297 .45546 Mdot
.73288 .65775 Mdot
.40532 .55641 Mdot
.41428 .75437 Mdot
.27898 .41868 Mdot
.59591 .40373 Mdot
.65837 .41263 Mdot
.55441 .32076 Mdot
.56011 .32021 Mdot
.64514 .3961 Mdot
.59476 .73784 Mdot
.37643 .76298 Mdot
.40917 .54514 Mdot
.53454 .52818 Mdot
.61901 .63177 Mdot
.3943 .31042 Mdot
.6677 .60258 Mdot
.7098 .25243 Mdot
.4238 .4434 Mdot
.4517 .46865 Mdot
.47665 .3341 Mdot
.52881 .33626 Mdot
.53855 .53103 Mdot
.40699 .31926 Mdot
.39294 .59839 Mdot
.67172 .6275 Mdot
.28233 .41152 Mdot
.45319 .62428 Mdot
.35992 .80838 Mdot
.62404 .58755 Mdot
.25065 .53036 Mdot
.66275 .42568 Mdot
.51132 .28593 Mdot
.38231 .63005 Mdot
.41362 .58228 Mdot
.6765 .62936 Mdot
.37671 .60988 Mdot
.40818 .48217 Mdot
.4034 .63528 Mdot
.57381 .32901 Mdot
.39777 .35269 Mdot
.67344 .38005 Mdot
.47082 .33072 Mdot
.65355 .58671 Mdot
.80479 .64192 Mdot
.52963 .29132 Mdot
.31437 .62897 Mdot
.68584 .40158 Mdot
.38761 .28239 Mdot
.52401 .29699 Mdot
.42669 .31913 Mdot
.43697 .57346 Mdot
.5387 .2815 Mdot
.40112 .29643 Mdot
.46971 .47664 Mdot
.35629 .62984 Mdot
.21463 .46319 Mdot
.67755 .43572 Mdot
.63137 .63196 Mdot
.37228 .5813 Mdot
.50704 .54019 Mdot
.39815 .64796 Mdot
.26728 .49683 Mdot
.52 .54551 Mdot
.54637 .52562 Mdot
.36996 .44221 Mdot
.37289 .30297 Mdot
.80692 .46544 Mdot
.49704 .44955 Mdot
.61085 .6101 Mdot
.39004 .55994 Mdot
.7556 .39807 Mdot
.67245 .4404 Mdot
.40022 .60138 Mdot
.77032 .42746 Mdot
.67934 .42539 Mdot
.40251 .60858 Mdot
.67443 .39501 Mdot
.64136 .62055 Mdot
.38004 .47621 Mdot
.61061 .59418 Mdot
.37964 .58379 Mdot
.67728 .39518 Mdot
.55847 .31651 Mdot
.63618 .60019 Mdot
.39443 .57043 Mdot
.42811 .57279 Mdot
.52418 .53061 Mdot
.40466 .63643 Mdot
.64572 .50069 Mdot
.37825 .62071 Mdot
.484 .30371 Mdot
.37666 .55467 Mdot
.41901 .3964 Mdot
.35755 .25754 Mdot
.67409 .61844 Mdot
.51973 .54517 Mdot
.51893 .29879 Mdot
.43093 .48665 Mdot
.23996 .53784 Mdot
.38945 .57997 Mdot
.52377 .54262 Mdot
.24413 .49898 Mdot
.66758 .45268 Mdot
.42326 .53151 Mdot
.44798 .28468 Mdot
.52094 .31161 Mdot
.53808 .52888 Mdot
.44186 .63268 Mdot
.61164 .63348 Mdot
.35499 .56881 Mdot
.53758 .28326 Mdot
.61215 .60383 Mdot
.36088 .56784 Mdot
.60359 .41911 Mdot
.50971 .53512 Mdot
.6909 .44034 Mdot
.54793 .49124 Mdot
.39643 .6156 Mdot
.53617 .33289 Mdot
.62909 .59936 Mdot
.65903 .43163 Mdot
.65425 .58827 Mdot
.30447 .39228 Mdot
.25297 .50953 Mdot
.65759 .67362 Mdot
.37498 .28352 Mdot
.21753 .34019 Mdot
.68793 .38517 Mdot
.40967 .65186 Mdot
.58197 .33587 Mdot
.71812 .61668 Mdot
.52646 .30627 Mdot
.64727 .75494 Mdot
.51656 .30782 Mdot
.35584 .59536 Mdot
.53844 .32572 Mdot
.49447 .81902 Mdot
.43078 .59848 Mdot
.50155 .31539 Mdot
.54392 .45878 Mdot
.43241 .59083 Mdot
.63185 .61482 Mdot
.22112 .64143 Mdot
.58105 .7246 Mdot
.58416 .73481 Mdot
.51541 .29571 Mdot
.66051 .74957 Mdot
.41347 .6231 Mdot
.3992 .53796 Mdot
.64891 .61745 Mdot
.3905 .6503 Mdot
.38092 .32331 Mdot
.40035 .338 Mdot
.26894 .34609 Mdot
.22359 .58606 Mdot
.59462 .75034 Mdot
.63453 .60834 Mdot
.42809 .34475 Mdot
.77181 .60238 Mdot
.50878 .53627 Mdot
.66295 .43915 Mdot
.80401 .57348 Mdot
.42812 .53652 Mdot
.55856 .51518 Mdot
.40311 .48251 Mdot
.62157 .61814 Mdot
.58098 .60248 Mdot
.65986 .43403 Mdot
.58161 .73596 Mdot
.36043 .74558 Mdot
.39954 .59417 Mdot
.68061 .44017 Mdot
.39424 .64748 Mdot
.48515 .44974 Mdot
.22332 .49068 Mdot
.57721 .22801 Mdot
.38102 .58535 Mdot
.80188 .55443 Mdot
.376 .57574 Mdot
.23994 .46621 Mdot
.39279 .60031 Mdot
.62624 .60627 Mdot
.44572 .55839 Mdot
.50128 .45451 Mdot
.27715 .24964 Mdot
.4196 .43807 Mdot
.42196 .32449 Mdot
.40163 .58039 Mdot
.40953 .59358 Mdot
.41449 .29929 Mdot
.63197 .62903 Mdot
.3735 .57219 Mdot
.81991 .46862 Mdot
.38763 .57189 Mdot
.6522 .44459 Mdot
.29358 .47539 Mdot
.20039 .56471 Mdot
.40233 .62748 Mdot
.61423 .63587 Mdot
.69128 .44158 Mdot
.68757 .4081 Mdot
.49122 .5717 Mdot
.67471 .44013 Mdot
.37024 .60465 Mdot
.29298 .47425 Mdot
.67369 .64899 Mdot
.48748 .57101 Mdot
.6226 .61718 Mdot
.41672 .1824 Mdot
.67384 .43597 Mdot
.51165 .54023 Mdot
.61096 .74358 Mdot
.6751 .41826 Mdot
.37166 .34561 Mdot
.44494 .55586 Mdot
.46853 .60623 Mdot
.60281 .59352 Mdot
.53723 .33226 Mdot
.53704 .53763 Mdot
.66 .42868 Mdot
.38746 .58176 Mdot
.36588 .6258 Mdot
.67649 .44015 Mdot
.47496 .67599 Mdot
.47897 .44655 Mdot
.37892 .58093 Mdot
.63406 .62273 Mdot
.6479 .5921 Mdot
.35311 .55822 Mdot
.3749 .57563 Mdot
.55255 .3161 Mdot
.52396 .54297 Mdot
.52841 .54373 Mdot
.55165 .53823 Mdot
.51392 .29019 Mdot
.21974 .32813 Mdot
.68494 .45066 Mdot
.19905 .57649 Mdot
.75439 .55797 Mdot
.49194 .56414 Mdot
.56124 .30178 Mdot
.41793 .5832 Mdot
.36889 .61942 Mdot
.66848 .39805 Mdot
.19819 .41896 Mdot
.4024 .53859 Mdot
.61288 .59314 Mdot
.67295 .44474 Mdot
.40339 .64406 Mdot
.73787 .44875 Mdot
.38207 .30397 Mdot
.60102 .75568 Mdot
.66872 .44512 Mdot
.68054 .63503 Mdot
.66845 .44537 Mdot
.40708 .59335 Mdot
.43676 .63674 Mdot
.61843 .61175 Mdot
.42931 .30626 Mdot
.36962 .57174 Mdot
.39603 .60612 Mdot
.55856 .37178 Mdot
.77673 .59134 Mdot
.42887 .29409 Mdot
.3645 .60764 Mdot
.46533 .61664 Mdot
.42778 .3055 Mdot
.37214 .59729 Mdot
.36506 .56614 Mdot
.33698 .68167 Mdot
.64878 .45169 Mdot
.39775 .28063 Mdot
.25121 .27635 Mdot
.62329 .58707 Mdot
.64304 .4998 Mdot
.54754 .53078 Mdot
.68966 .3874 Mdot
.39331 .48806 Mdot
.52697 .53615 Mdot
.77407 .53427 Mdot
.70673 .78601 Mdot
.53436 .53808 Mdot
.54875 .27738 Mdot
.52498 .80887 Mdot
.36674 .56554 Mdot
.37672 .58503 Mdot
.37944 .32008 Mdot
.66009 .60816 Mdot
.73795 .65426 Mdot
.6837 .38592 Mdot
.4126 .56921 Mdot
.63876 .58143 Mdot
.7564 .45671 Mdot
.52864 .53182 Mdot
.3855 .31786 Mdot
.41336 .28992 Mdot
.37355 .58406 Mdot
.23551 .51997 Mdot
.6338 .60205 Mdot
.39436 .57057 Mdot
.40005 .61219 Mdot
.56055 .28723 Mdot
.67189 .62444 Mdot
.54497 .28786 Mdot
.52482 .52361 Mdot
.56177 .81667 Mdot
.73893 .36814 Mdot
.68142 .4282 Mdot
.50295 .55269 Mdot
.67308 .3803 Mdot
.59935 .31179 Mdot
.52474 .54327 Mdot
.39616 .57093 Mdot
.68133 .64528 Mdot
.3926 .57083 Mdot
.38664 .57289 Mdot
.38491 .58705 Mdot
.59495 .75164 Mdot
.43434 .36321 Mdot
.39132 .32489 Mdot
.38981 .61648 Mdot
.52596 .2802 Mdot
.74944 .43553 Mdot
.42804 .79228 Mdot
.40743 .58083 Mdot
.40103 .61033 Mdot
.61797 .63785 Mdot
.40616 .63803 Mdot
.67588 .42534 Mdot
.62086 .61836 Mdot
.36309 .61767 Mdot
.49429 .37235 Mdot
.37048 .57867 Mdot
.6069 .65248 Mdot
.64762 .43335 Mdot
.44663 .6177 Mdot
.33202 .61833 Mdot
.52213 .54368 Mdot
.53687 .53671 Mdot
.55893 .53088 Mdot
.65223 .44558 Mdot
.55235 .28167 Mdot
.50411 .33467 Mdot
.32462 .61818 Mdot
.36918 .60782 Mdot
.46188 .61295 Mdot
.50122 .27371 Mdot
.51433 .43548 Mdot
.637 .75193 Mdot
.4027 .64264 Mdot
.50468 .29486 Mdot
.56245 .4891 Mdot
.47303 .66205 Mdot
.62981 .6293 Mdot
.58577 .32356 Mdot
.6805 .40368 Mdot
.39786 .29382 Mdot
.25398 .395 Mdot
.62944 .59138 Mdot
.66118 .65691 Mdot
.55189 .30593 Mdot
.29271 .46425 Mdot
.88489 .44843 Mdot
.53436 .31289 Mdot
.44242 .47384 Mdot
.6432 .61512 Mdot
.35161 .62817 Mdot
.25179 .48627 Mdot
.30137 .47091 Mdot
.50161 .30755 Mdot
.4274 .57113 Mdot
.45248 .17509 Mdot
.55165 .31775 Mdot
.45911 .62149 Mdot
.51607 .29344 Mdot
.68238 .44948 Mdot
.53497 .30484 Mdot
.63784 .57778 Mdot
.41519 .5593 Mdot
.88031 .46472 Mdot
.35067 .45407 Mdot
.41443 .56366 Mdot
.65817 .44553 Mdot
.59924 .39536 Mdot
.40095 .5975 Mdot
.39198 .33229 Mdot
.54883 .2781 Mdot
.56694 .24139 Mdot
.35653 .57723 Mdot
.53729 .32716 Mdot
.64573 .6553 Mdot
.58371 .30665 Mdot
.49365 .37736 Mdot
.53544 .54027 Mdot
.64669 .62358 Mdot
.61509 .44546 Mdot
.69668 .40018 Mdot
.34849 .60435 Mdot
.40683 .61469 Mdot
.64694 .62919 Mdot
.44829 .48587 Mdot
.39418 .53143 Mdot
.39049 .57003 Mdot
.54765 .29447 Mdot
.554 .33806 Mdot
.34023 .47832 Mdot
.52987 .28928 Mdot
.46795 .61145 Mdot
.63872 .62386 Mdot
.35384 .57308 Mdot
.64517 .58891 Mdot
.38684 .56123 Mdot
.71605 .4655 Mdot
.6474 .6389 Mdot
.31422 .62563 Mdot
.42966 .57021 Mdot
.70354 .69629 Mdot
.39908 .61851 Mdot
.38119 .57754 Mdot
.567 .33211 Mdot
.41479 .30421 Mdot
.37305 .53972 Mdot
.66298 .47395 Mdot
.39916 .2898 Mdot
.45719 .68431 Mdot
.56585 .31562 Mdot
.39863 .28416 Mdot
.25103 .3679 Mdot
.52313 .54522 Mdot
.42075 .31401 Mdot
.49793 .54778 Mdot
.68351 .4285 Mdot
.69119 .63314 Mdot
.43355 .58741 Mdot
.55368 .81847 Mdot
.48231 .445 Mdot
.52079 .53267 Mdot
.374 .59405 Mdot
.41812 .5888 Mdot
.63946 .58166 Mdot
.71429 .25802 Mdot
.53794 .34289 Mdot
.37385 .64404 Mdot
.63058 .5888 Mdot
.73595 .28606 Mdot
.49908 .31065 Mdot
.3753 .3034 Mdot
.67869 .38955 Mdot
.62501 .56727 Mdot
.51094 .53783 Mdot
.6721 .43735 Mdot
.48104 .31709 Mdot
.30026 .37724 Mdot
.35653 .56659 Mdot
.55625 .29352 Mdot
.29333 .3868 Mdot
.42934 .53191 Mdot
.64362 .3964 Mdot
.60507 .38053 Mdot
.66067 .63308 Mdot
.6759 .44099 Mdot
.39644 .33054 Mdot
.61794 .62596 Mdot
.62356 .61994 Mdot
.67835 .41988 Mdot
.71543 .71717 Mdot
.24523 .49835 Mdot
.64531 .40581 Mdot
.27333 .49625 Mdot
.29551 .38526 Mdot
.51747 .53308 Mdot
.38842 .31918 Mdot
.39673 .35364 Mdot
.6352 .59726 Mdot
.7997 .57791 Mdot
.2917 .38794 Mdot
.43251 .60995 Mdot
.40275 .29564 Mdot
.74667 .46409 Mdot
.62227 .38505 Mdot
.67506 .43136 Mdot
.57354 .36928 Mdot
.40851 .29484 Mdot
.42995 .56346 Mdot
.16731 .47694 Mdot
.42507 .6052 Mdot
.68159 .42242 Mdot
.40517 .48238 Mdot
.66958 .6116 Mdot
.6638 .45313 Mdot
.40691 .48196 Mdot
.36626 .61326 Mdot
.4234 .58003 Mdot
.4461 .36426 Mdot
.66576 .63613 Mdot
.51959 .52758 Mdot
.41085 .56061 Mdot
.40637 .60728 Mdot
.34413 .59917 Mdot
.20718 .53848 Mdot
.54114 .57667 Mdot
.34558 .61025 Mdot
.50473 .28556 Mdot
.43325 .64098 Mdot
.37725 .64545 Mdot
.59696 .61328 Mdot
.47246 .37539 Mdot
.53775 .52095 Mdot
.37783 .5897 Mdot
.379 .58323 Mdot
.67705 .39131 Mdot
.24515 .49728 Mdot
.29986 .46549 Mdot
.49919 .32357 Mdot
.47416 .27819 Mdot
.41243 .55036 Mdot
.65476 .62715 Mdot
.38676 .27559 Mdot
.48347 .58761 Mdot
.6143 .593 Mdot
.40402 .55222 Mdot
.55696 .28203 Mdot
.53023 .54025 Mdot
.47927 .59862 Mdot
.40154 .3003 Mdot
.66563 .37784 Mdot
.47204 .66925 Mdot
.55955 .31029 Mdot
.39131 .63566 Mdot
.46471 .28349 Mdot
.52886 .32265 Mdot
.52412 .52955 Mdot
.40621 .6489 Mdot
.63794 .61684 Mdot
.68119 .62983 Mdot
.40308 .39152 Mdot
.51757 .28537 Mdot
.59516 .33746 Mdot
.68471 .44137 Mdot
.39023 .61464 Mdot
.66236 .37354 Mdot
.67848 .61979 Mdot
.23293 .48049 Mdot
.40825 .28737 Mdot
.67741 .42694 Mdot
.50032 .54777 Mdot
.63699 .63551 Mdot
.67962 .61837 Mdot
.38548 .57751 Mdot
.40402 .57382 Mdot
.59504 .30587 Mdot
.27277 .42448 Mdot
.66573 .39786 Mdot
.3784 .29951 Mdot
.50128 .32411 Mdot
.35711 .59236 Mdot
.66455 .62316 Mdot
.18581 .54465 Mdot
.39779 .61658 Mdot
.52454 .28121 Mdot
.64879 .60585 Mdot
.37934 .31672 Mdot
.39849 .32958 Mdot
.40191 .55932 Mdot
.35908 .70006 Mdot
.67459 .41456 Mdot
.62977 .61256 Mdot
.68577 .58411 Mdot
.38674 .61737 Mdot
.4042 .5782 Mdot
.419 .52446 Mdot
.63621 .42637 Mdot
.33253 .58968 Mdot
.42807 .31233 Mdot
.66524 .59687 Mdot
.4078 .56231 Mdot
.41091 .2985 Mdot
.56243 .51791 Mdot
.52539 .53813 Mdot
.5183 .32696 Mdot
.39469 .33463 Mdot
.40977 .30857 Mdot
.39294 .28847 Mdot
.80511 .57141 Mdot
.5254 .5196 Mdot
.33265 .32593 Mdot
.42717 .56889 Mdot
.29648 .38456 Mdot
.34904 .56872 Mdot
.67392 .45046 Mdot
.53181 .33151 Mdot
.39048 .58836 Mdot
.42816 .5704 Mdot
.48738 .65185 Mdot
.35077 .57509 Mdot
.36952 .54731 Mdot
.67075 .61101 Mdot
.69479 .59305 Mdot
.55597 .32202 Mdot
.75174 .31306 Mdot
.15764 .55787 Mdot
.41543 .54573 Mdot
.29302 .46669 Mdot
.63714 .63372 Mdot
.67831 .39039 Mdot
.2676 .49169 Mdot
.64864 .37346 Mdot
.65184 .59711 Mdot
.35529 .59185 Mdot
.51309 .63423 Mdot
.40246 .29206 Mdot
.40335 .59243 Mdot
.66388 .40725 Mdot
.40202 .59276 Mdot
.65818 .4482 Mdot
.66501 .73985 Mdot
.30371 .45214 Mdot
.43379 .59745 Mdot
.37465 .55497 Mdot
.3903 .68653 Mdot
.40641 .57792 Mdot
.57042 .22278 Mdot
.6485 .61008 Mdot
.32747 .64049 Mdot
.35487 .6029 Mdot
.57391 .72495 Mdot
.38353 .60451 Mdot
.40715 .49521 Mdot
.4213 .60278 Mdot
.20849 .39624 Mdot
.43828 .58214 Mdot
.4151 .61298 Mdot
.65205 .42353 Mdot
.68727 .39281 Mdot
.71878 .63259 Mdot
.53633 .52226 Mdot
.7514 .45858 Mdot
.39641 .60729 Mdot
.52358 .33634 Mdot
.31478 .65477 Mdot
.4124 .30572 Mdot
.66173 .59514 Mdot
.79298 .73021 Mdot
.67256 .45815 Mdot
.53086 .27631 Mdot
.46715 .45813 Mdot
.51528 .27812 Mdot
.58284 .33064 Mdot
.63203 .56123 Mdot
.3874 .31733 Mdot
.37252 .57603 Mdot
.56818 .70896 Mdot
.7847 .57546 Mdot
.38501 .6172 Mdot
.47557 .29403 Mdot
.32538 .66492 Mdot
.3807 .39213 Mdot
.37789 .32624 Mdot
.39671 .3166 Mdot
.66276 .43156 Mdot
.51067 .32879 Mdot
.38921 .64805 Mdot
.39901 .28401 Mdot
.54911 .3251 Mdot
.50888 .54854 Mdot
.45869 .37183 Mdot
.63241 .60283 Mdot
.65705 .75112 Mdot
.63416 .69658 Mdot
.69464 .43335 Mdot
.66064 .47303 Mdot
.68747 .6401 Mdot
.60895 .60103 Mdot
.53656 .52408 Mdot
.5047 .29966 Mdot
.69094 .62977 Mdot
.40626 .55989 Mdot
.45265 .62499 Mdot
.37339 .58208 Mdot
.37485 .31159 Mdot
.37819 .59981 Mdot
.54405 .32602 Mdot
.65052 .42668 Mdot
.51948 .30818 Mdot
.66614 .43573 Mdot
.20357 .61023 Mdot
.42785 .56364 Mdot
.40131 .57754 Mdot
.29365 .4738 Mdot
.67696 .61256 Mdot
.55587 .71831 Mdot
.52122 .28414 Mdot
.51608 .30152 Mdot
.35467 .59778 Mdot
.63095 .63883 Mdot
.43899 .31035 Mdot
.2837 .49233 Mdot
.41872 .60544 Mdot
.65039 .61095 Mdot
.35331 .59224 Mdot
.64829 .48546 Mdot
.33376 .46253 Mdot
.66995 .59681 Mdot
.28182 .2449 Mdot
.43228 .57287 Mdot
.39508 .65141 Mdot
.31699 .61836 Mdot
.21598 .55286 Mdot
.39218 .53327 Mdot
.62122 .5886 Mdot
.37944 .6454 Mdot
.65835 .62431 Mdot
.52898 .31888 Mdot
.66675 .45515 Mdot
.65527 .62043 Mdot
.4306 .59051 Mdot
.1584 .55595 Mdot
.64828 .42021 Mdot
.39993 .58904 Mdot
.65961 .40616 Mdot
.68239 .59446 Mdot
.66531 .60927 Mdot
.50757 .54954 Mdot
.44398 .47279 Mdot
.67694 .42068 Mdot
.37093 .60891 Mdot
.78077 .60132 Mdot
.35508 .56791 Mdot
.47319 .28237 Mdot
.39149 .54681 Mdot
.40165 .55123 Mdot
.21949 .31777 Mdot
.43592 .48963 Mdot
.74587 .36844 Mdot
.74312 .42185 Mdot
.7794 .61342 Mdot
.60014 .59576 Mdot
.37926 .32757 Mdot
.56814 .5738 Mdot
.53131 .54438 Mdot
.50141 .28896 Mdot
.38808 .58459 Mdot
.56473 .5082 Mdot
.64127 .41153 Mdot
.41772 .31601 Mdot
.43321 .60159 Mdot
.51621 .27196 Mdot
.50716 .55371 Mdot
.67307 .43486 Mdot
.63453 .5963 Mdot
.66093 .59881 Mdot
.42448 .36642 Mdot
.40942 .56285 Mdot
.40062 .57201 Mdot
.64993 .41069 Mdot
.32535 .57547 Mdot
.38714 .29295 Mdot
.54255 .45747 Mdot
.66494 .40511 Mdot
.33238 .46094 Mdot
.66784 .63561 Mdot
.41814 .58627 Mdot
.29568 .47859 Mdot
.75636 .63937 Mdot
.44374 .78107 Mdot
.39764 .31076 Mdot
.23955 .53148 Mdot
.62191 .58842 Mdot
.65881 .41508 Mdot
.26051 .35599 Mdot
.44242 .55018 Mdot
.41769 .59458 Mdot
.232 .54087 Mdot
.2819 .49349 Mdot
.46598 .46068 Mdot
.49292 .55967 Mdot
.26221 .47483 Mdot
.3542 .59571 Mdot
.36627 .62528 Mdot
.41465 .55124 Mdot
.38847 .54732 Mdot
.65737 .61545 Mdot
.57489 .7393 Mdot
.546 .30648 Mdot
.44685 .76898 Mdot
.489 .27037 Mdot
.41657 .61987 Mdot
.36119 .6064 Mdot
.47033 .74004 Mdot
.26724 .53192 Mdot
.64069 .60799 Mdot
.6049 .58907 Mdot
.6989 .41706 Mdot
.35312 .56851 Mdot
.52137 .28266 Mdot
.31977 .6223 Mdot
.51955 .32389 Mdot
.6561 .61361 Mdot
.56533 .2968 Mdot
.69712 .44111 Mdot
.55577 .29257 Mdot
.50398 .29167 Mdot
.65147 .43463 Mdot
.65788 .64036 Mdot
.40682 .61844 Mdot
.65205 .43621 Mdot
.43489 .301 Mdot
.37605 .31445 Mdot
.70905 .63352 Mdot
.34806 .62023 Mdot
.42966 .53868 Mdot
.60669 .33706 Mdot
.54824 .28279 Mdot
.30629 .49787 Mdot
.65306 .63893 Mdot
.38228 .27847 Mdot
.66032 .62035 Mdot
.36424 .37094 Mdot
.40096 .30749 Mdot
.50579 .536 Mdot
.23358 .42774 Mdot
.69267 .37981 Mdot
.44658 .56817 Mdot
.69522 .59421 Mdot
.51751 .32161 Mdot
.65844 .44685 Mdot
.74925 .44533 Mdot
.36909 .64181 Mdot
.68459 .65649 Mdot
.66081 .57757 Mdot
.52916 .54403 Mdot
.66073 .41254 Mdot
.65925 .7015 Mdot
.41406 .56515 Mdot
.68173 .37892 Mdot
.39355 .54684 Mdot
.61882 .76294 Mdot
.52978 .24927 Mdot
.56271 .49379 Mdot
.35555 .59627 Mdot
.49846 .30942 Mdot
.3549 .59591 Mdot
.56874 .79916 Mdot
.24084 .44978 Mdot
.41655 .55068 Mdot
.26027 .53337 Mdot
.60132 .30884 Mdot
.66413 .6251 Mdot
.48511 .58046 Mdot
.51936 .5325 Mdot
.37905 .6344 Mdot
.21141 .70097 Mdot
.41754 .30391 Mdot
.47819 .34929 Mdot
.43141 .58578 Mdot
.39617 .5667 Mdot
.46792 .67067 Mdot
.66176 .73933 Mdot
.51691 .54962 Mdot
.41396 .59875 Mdot
.23146 .55972 Mdot
.65476 .42725 Mdot
.36243 .56373 Mdot
.37903 .57425 Mdot
.58564 .28945 Mdot
.65349 .42064 Mdot
.56369 .30216 Mdot
.52555 .5451 Mdot
.55105 .33678 Mdot
.42987 .30241 Mdot
.24873 .5321 Mdot
.2196 .50495 Mdot
.33478 .46852 Mdot
.39876 .33522 Mdot
.40174 .63004 Mdot
.54721 .4942 Mdot
.4246 .57356 Mdot
.3998 .31981 Mdot
.667 .40144 Mdot
.65072 .61333 Mdot
.64011 .76014 Mdot
.52863 .52885 Mdot
.39053 .62625 Mdot
.36959 .30344 Mdot
.65 .62108 Mdot
.75077 .68052 Mdot
.65994 .60995 Mdot
.67066 .43108 Mdot
.64121 .40255 Mdot
.40596 .3048 Mdot
.66099 .62062 Mdot
.55997 .33481 Mdot
.63379 .39626 Mdot
.44701 .59028 Mdot
.69538 .44377 Mdot
.67677 .59504 Mdot
.6632 .58852 Mdot
.66451 .65153 Mdot
.35664 .60866 Mdot
.2776 .51798 Mdot
.49791 .5591 Mdot
.64881 .41463 Mdot
.50327 .28096 Mdot
.26595 .42973 Mdot
.56334 .66397 Mdot
.31793 .46064 Mdot
.48173 .57973 Mdot
.37717 .59854 Mdot
.37352 .58586 Mdot
.34173 .60138 Mdot
.53111 .47327 Mdot
.42526 .56145 Mdot
.66702 .39806 Mdot
.53921 .32198 Mdot
.42001 .60102 Mdot
.51635 .53985 Mdot
.51002 .43619 Mdot
.39987 .28038 Mdot
.6007 .75809 Mdot
.71074 .63047 Mdot
.65039 .61978 Mdot
.53808 .28429 Mdot
.5692 .30677 Mdot
.38516 .28198 Mdot
.66754 .44183 Mdot
.6598 .60667 Mdot
.21252 .38702 Mdot
.3956 .29113 Mdot
.37855 .59132 Mdot
.29387 .47488 Mdot
.22415 .57191 Mdot
.36812 .56998 Mdot
.38454 .58863 Mdot
.53942 .52138 Mdot
.51927 .28177 Mdot
.43209 .80179 Mdot
.72865 .68968 Mdot
.41085 .30209 Mdot
.38299 .28856 Mdot
.65387 .65177 Mdot
.38564 .61065 Mdot
.67357 .41179 Mdot
.24165 .50373 Mdot
.60229 .41908 Mdot
.75344 .47003 Mdot
.60048 .31649 Mdot
.36939 .58146 Mdot
.55053 .78142 Mdot
.43021 .5467 Mdot
.68478 .59586 Mdot
.67685 .63898 Mdot
.63665 .6078 Mdot
.65575 .43055 Mdot
.30321 .37502 Mdot
.6929 .39873 Mdot
.56191 .48732 Mdot
.6211 .59632 Mdot
.44956 .47908 Mdot
.51574 .29904 Mdot
.34966 .57033 Mdot
.39021 .31863 Mdot
.42228 .27155 Mdot
.4815 .58701 Mdot
.24261 .53166 Mdot
.56119 .30147 Mdot
.63602 .63719 Mdot
.34757 .57509 Mdot
.75017 .43209 Mdot
.2899 .45473 Mdot
.59331 .26223 Mdot
.56449 .50423 Mdot
.40789 .29714 Mdot
.39277 .76867 Mdot
.38694 .2975 Mdot
.67817 .42581 Mdot
.42902 .56738 Mdot
.38921 .6112 Mdot
.38067 .57731 Mdot
.39866 .54213 Mdot
.65859 .42708 Mdot
.44645 .58264 Mdot
.41774 .3966 Mdot
.53482 .54583 Mdot
.51201 .45603 Mdot
.40812 .32878 Mdot
.68172 .44443 Mdot
.53304 .32317 Mdot
.54715 .52653 Mdot
.37683 .28094 Mdot
.34411 .58147 Mdot
.42938 .58495 Mdot
.52923 .54778 Mdot
.48676 .56881 Mdot
.42433 .53524 Mdot
.54988 .31199 Mdot
.48993 .4483 Mdot
.41002 .28518 Mdot
.39074 .30745 Mdot
.68181 .43611 Mdot
.66068 .62116 Mdot
.39976 .28197 Mdot
.48547 .30049 Mdot
.36052 .56517 Mdot
.39675 .5463 Mdot
.67267 .59215 Mdot
.29464 .38379 Mdot
.39982 .28025 Mdot
.33306 .58498 Mdot
.66965 .59874 Mdot
.65817 .57588 Mdot
.41381 .59744 Mdot
.44289 .59364 Mdot
.59756 .61274 Mdot
.37974 .28911 Mdot
.68266 .43837 Mdot
.33304 .44413 Mdot
.68365 .45059 Mdot
.63053 .59762 Mdot
.44522 .63225 Mdot
.65087 .64212 Mdot
.36755 .64079 Mdot
.81688 .43972 Mdot
.42329 .55931 Mdot
.57121 .61282 Mdot
.49703 .42366 Mdot
.51448 .29658 Mdot
.5093 .30144 Mdot
.52696 .54161 Mdot
.61291 .59761 Mdot
.47308 .60418 Mdot
.38363 .31259 Mdot
.77945 .61244 Mdot
.59699 .61437 Mdot
.50356 .29345 Mdot
.54031 .276 Mdot
.66196 .40518 Mdot
.37918 .60148 Mdot
.41903 .58512 Mdot
.557 .29313 Mdot
.61347 .46283 Mdot
.6535 .63404 Mdot
.40016 .57224 Mdot
.34532 .60658 Mdot
.54576 .30972 Mdot
.71131 .41592 Mdot
.68932 .63457 Mdot
.35642 .61042 Mdot
.23805 .45921 Mdot
.65941 .4506 Mdot
.3801 .62936 Mdot
.44664 .56674 Mdot
.41302 .31141 Mdot
.23562 .53361 Mdot
.29074 .39159 Mdot
.6772 .45771 Mdot
.51607 .54358 Mdot
.36715 .57487 Mdot
.51256 .30251 Mdot
.3437 .56989 Mdot
.56881 .8543 Mdot
.52755 .54706 Mdot
.41173 .56622 Mdot
.3192 .60961 Mdot
.64481 .5886 Mdot
.39743 .56872 Mdot
.70885 .46944 Mdot
.54158 .29108 Mdot
.41337 .56672 Mdot
.39235 .69787 Mdot
.66169 .40594 Mdot
.48429 .58129 Mdot
.4063 .29392 Mdot
.45479 .46941 Mdot
.21933 .63864 Mdot
.50333 .27258 Mdot
.41608 .32646 Mdot
.38753 .60594 Mdot
.50958 .33034 Mdot
.6873 .38987 Mdot
.49967 .55478 Mdot
.38992 .63336 Mdot
.69608 .42616 Mdot
.65344 .43296 Mdot
.40512 .30136 Mdot
.86022 .56828 Mdot
.42516 .55424 Mdot
.40647 .58762 Mdot
.81562 .62919 Mdot
.59073 .59287 Mdot
.39951 .59068 Mdot
.40018 .61288 Mdot
.6775 .43597 Mdot
.30547 .35709 Mdot
.24082 .53223 Mdot
.54166 .46063 Mdot
.66425 .45065 Mdot
.49868 .32755 Mdot
.55065 .29314 Mdot
.42138 .32168 Mdot
.64892 .60513 Mdot
.3786 .28282 Mdot
.53758 .30277 Mdot
.38113 .58329 Mdot
.69105 .41963 Mdot
.33138 .72416 Mdot
.64957 .43853 Mdot
.49642 .28147 Mdot
.68351 .59465 Mdot
.51031 .82153 Mdot
.59372 .85061 Mdot
.55875 .5661 Mdot
.64121 .39743 Mdot
.41267 .30602 Mdot
.73213 .6885 Mdot
.41941 .60279 Mdot
.56791 .79327 Mdot
.40474 .59095 Mdot
.5661 .51577 Mdot
.53736 .3313 Mdot
.50845 .54884 Mdot
.36696 .6408 Mdot
.24299 .53521 Mdot
.65728 .43882 Mdot
.67631 .4044 Mdot
.38031 .64524 Mdot
.67314 .4278 Mdot
.41597 .57538 Mdot
.54244 .31683 Mdot
.84063 .47925 Mdot
.42389 .6004 Mdot
.32831 .63836 Mdot
.68397 .3773 Mdot
.70931 .66376 Mdot
.48681 .31929 Mdot
.56061 .7602 Mdot
.75713 .44948 Mdot
.6724 .41312 Mdot
.59586 .7545 Mdot
.53337 .28288 Mdot
.54709 .52592 Mdot
.52891 .33973 Mdot
.4117 .58798 Mdot
.3682 .5841 Mdot
.34049 .59946 Mdot
.39726 .61034 Mdot
.52289 .79705 Mdot
.42912 .53546 Mdot
.43152 .72302 Mdot
.42658 .5683 Mdot
.56213 .58569 Mdot
.68456 .3955 Mdot
.40065 .64881 Mdot
.35954 .43511 Mdot
.41009 .55447 Mdot
.60311 .59301 Mdot
.68421 .44489 Mdot
.77098 .41241 Mdot
.65649 .42609 Mdot
.5185 .30899 Mdot
.66243 .43947 Mdot
.43385 .6058 Mdot
.6447 .5925 Mdot
.52878 .29586 Mdot
.49892 .55248 Mdot
.49746 .28932 Mdot
.41425 .56365 Mdot
.71465 .39004 Mdot
.53543 .27824 Mdot
.43868 .54322 Mdot
.64799 .59316 Mdot
.20137 .49227 Mdot
.69301 .63659 Mdot
.39237 .577 Mdot
.3938 .58319 Mdot
.52674 .54865 Mdot
.6678 .4393 Mdot
.65743 .64254 Mdot
.59716 .36473 Mdot
.38057 .27861 Mdot
.64201 .60458 Mdot
.31541 .6158 Mdot
.29055 .46399 Mdot
.65709 .58935 Mdot
.228 .56589 Mdot
.68015 .42506 Mdot
.63391 .58547 Mdot
.315 .587 Mdot
.44175 .76626 Mdot
.38884 .3034 Mdot
.56377 .33412 Mdot
.27324 .47624 Mdot
.54838 .29185 Mdot
.73152 .45382 Mdot
.5726 .33022 Mdot
.65385 .41336 Mdot
.32178 .66018 Mdot
.40794 .48239 Mdot
.64177 .42821 Mdot
.71971 .3894 Mdot
.54667 .30121 Mdot
.3493 .61958 Mdot
.50142 .4521 Mdot
.46989 .612 Mdot
.42032 .65045 Mdot
.6696 .45801 Mdot
.6293 .58568 Mdot
.61872 .62607 Mdot
.32141 .63762 Mdot
.66736 .60411 Mdot
.53039 .30944 Mdot
.33703 .47332 Mdot
.61085 .74324 Mdot
.67871 .39789 Mdot
.48241 .44794 Mdot
.36053 .60723 Mdot
.53935 .32733 Mdot
.52895 .31198 Mdot
.65537 .43428 Mdot
.48465 .77586 Mdot
.46303 .61869 Mdot
.60025 .57532 Mdot
.62683 .59189 Mdot
.64385 .5878 Mdot
.67334 .62862 Mdot
.30209 .37404 Mdot
.66036 .44733 Mdot
.61449 .59537 Mdot
.39292 .54203 Mdot
.38384 .60682 Mdot
.54118 .53378 Mdot
.37476 .30637 Mdot
.43648 .54503 Mdot
.47346 .6038 Mdot
.41499 .59556 Mdot
.5167 .29207 Mdot
.32016 .66866 Mdot
.54279 .54163 Mdot
.51949 .28309 Mdot
.5157 .28862 Mdot
.52163 .54386 Mdot
.31683 .65911 Mdot
.44703 .79611 Mdot
.40032 .63973 Mdot
.62765 .56241 Mdot
.50745 .30411 Mdot
.51728 .38007 Mdot
.56986 .60407 Mdot
.37208 .60695 Mdot
.53015 .44725 Mdot
.53726 .31755 Mdot
.59903 .59577 Mdot
.40965 .58212 Mdot
.53306 .52425 Mdot
.39235 .29735 Mdot
.49699 .55649 Mdot
.53806 .52152 Mdot
.66182 .62908 Mdot
.59194 .34389 Mdot
.64044 .58158 Mdot
.57104 .30385 Mdot
.47798 .59272 Mdot
.88275 .45552 Mdot
.51799 .32058 Mdot
.78692 .60196 Mdot
.41563 .48198 Mdot
.42541 .58613 Mdot
.54082 .28674 Mdot
.63142 .64837 Mdot
.65439 .44923 Mdot
.288 .51294 Mdot
.66426 .62007 Mdot
.54976 .5278 Mdot
.53685 .53418 Mdot
.54657 .30763 Mdot
.62375 .60607 Mdot
.44759 .57361 Mdot
.65873 .59763 Mdot
.69081 .41014 Mdot
.38479 .64181 Mdot
.75171 .45783 Mdot
.40506 .64956 Mdot
.66679 .60057 Mdot
.50021 .28187 Mdot
.42912 .30654 Mdot
.42914 .60077 Mdot
.77184 .41884 Mdot
.38717 .60623 Mdot
.66263 .40348 Mdot
.47979 .4179 Mdot
.3486 .72517 Mdot
.38904 .59862 Mdot
.36304 .61019 Mdot
.70471 .42319 Mdot
.39287 .5998 Mdot
.37983 .55536 Mdot
.65887 .70302 Mdot
.66163 .59165 Mdot
.41835 .60252 Mdot
.5579 .30689 Mdot
.40976 .70699 Mdot
.39496 .56366 Mdot
.69987 .47462 Mdot
.22284 .53764 Mdot
.45944 .40833 Mdot
.32791 .65131 Mdot
.2344 .47753 Mdot
.39806 .58484 Mdot
.37669 .60961 Mdot
.39082 .64373 Mdot
.55424 .7838 Mdot
.54035 .29946 Mdot
.49907 .31434 Mdot
.4264 .31638 Mdot
.23109 .5436 Mdot
.39578 .30324 Mdot
.68706 .38907 Mdot
.4612 .46248 Mdot
.54865 .53962 Mdot
.6603 .62252 Mdot
.38425 .57284 Mdot
.49262 .29397 Mdot
.41634 .58351 Mdot
.37819 .63289 Mdot
.53402 .3094 Mdot
.53119 .31715 Mdot
.5301 .26182 Mdot
.40603 .29194 Mdot
.64379 .61324 Mdot
.4359 .57994 Mdot
.40074 .28989 Mdot
.34274 .59948 Mdot
.31772 .44265 Mdot
.64122 .61091 Mdot
.6689 .60276 Mdot
.61693 .61699 Mdot
.4201 .61078 Mdot
.38964 .64266 Mdot
.69464 .40048 Mdot
.67244 .59179 Mdot
.678 .41572 Mdot
.54249 .28725 Mdot
.54979 .31942 Mdot
.41138 .58885 Mdot
.32604 .5759 Mdot
.39961 .32891 Mdot
.54078 .27958 Mdot
.55594 .52248 Mdot
.42366 .30508 Mdot
.3732 .57879 Mdot
.54631 .28949 Mdot
.38494 .32654 Mdot
.47203 .78026 Mdot
.70164 .50188 Mdot
.42679 .31092 Mdot
.36834 .64275 Mdot
.54961 .66323 Mdot
.24764 .44189 Mdot
.39891 .27818 Mdot
.6847 .39654 Mdot
.40356 .61672 Mdot
.55259 .47428 Mdot
.41189 .28743 Mdot
.28085 .40223 Mdot
.53257 .30344 Mdot
.41088 .65195 Mdot
.50835 .60317 Mdot
.60747 .74122 Mdot
.42881 .30421 Mdot
.66577 .5987 Mdot
.68312 .61536 Mdot
.38077 .59327 Mdot
.45591 .46709 Mdot
.65037 .40396 Mdot
.56932 .30859 Mdot
.49504 .30928 Mdot
.68442 .62979 Mdot
.33508 .46597 Mdot
.55699 .30318 Mdot
.38772 .61343 Mdot
.4086 .34596 Mdot
.36912 .54788 Mdot
.38097 .38371 Mdot
.33207 .70991 Mdot
.32191 .64731 Mdot
.42851 .30716 Mdot
.65311 .40309 Mdot
.65066 .42368 Mdot
.66278 .43471 Mdot
.55357 .30827 Mdot
.26731 .48918 Mdot
.4975 .3161 Mdot
.79411 .65184 Mdot
.41792 .30306 Mdot
.23179 .3288 Mdot
.41506 .54192 Mdot
.42495 .58242 Mdot
.36011 .56135 Mdot
.34865 .61348 Mdot
.39856 .58362 Mdot
.69782 .41808 Mdot
.54565 .33624 Mdot
.60104 .38173 Mdot
.63567 .62441 Mdot
.74832 .68281 Mdot
.5165 .29712 Mdot
.53359 .5214 Mdot
.39594 .32588 Mdot
.21341 .51445 Mdot
.4137 .33857 Mdot
.55583 .28429 Mdot
.38783 .55657 Mdot
.65304 .65231 Mdot
.20535 .40569 Mdot
.3914 .56915 Mdot
.54648 .28121 Mdot
.49182 .31922 Mdot
.4602 .76983 Mdot
.47518 .55201 Mdot
.5994 .41532 Mdot
.30103 .4785 Mdot
.4163 .33284 Mdot
.34716 .62067 Mdot
.23625 .51263 Mdot
.53936 .30343 Mdot
.50599 .31453 Mdot
.39357 .27394 Mdot
.72468 .65505 Mdot
.61563 .60067 Mdot
.69807 .60929 Mdot
.69466 .42707 Mdot
.42725 .58155 Mdot
.54876 .29785 Mdot
.69435 .6099 Mdot
.33518 .41682 Mdot
.66465 .42703 Mdot
.5323 .27648 Mdot
.39019 .60813 Mdot
.38828 .59961 Mdot
.39781 .30151 Mdot
.50082 .42903 Mdot
.4699 .61186 Mdot
.78093 .61004 Mdot
.30672 .46379 Mdot
.4162 .48158 Mdot
.41791 .59446 Mdot
.67119 .62875 Mdot
.52321 .54346 Mdot
.38821 .31962 Mdot
.34698 .56618 Mdot
.5528 .81584 Mdot
.62506 .57833 Mdot
.67707 .41698 Mdot
.51361 .53478 Mdot
.25258 .5333 Mdot
.39189 .60842 Mdot
.40529 .59067 Mdot
.35644 .60704 Mdot
.48265 .81797 Mdot
.53088 .33088 Mdot
.67339 .62145 Mdot
.4084 .29551 Mdot
.66415 .60888 Mdot
.57299 .30392 Mdot
.48666 .44597 Mdot
.43831 .59076 Mdot
.61686 .58304 Mdot
.65492 .60133 Mdot
.66491 .40319 Mdot
.65004 .43372 Mdot
.48245 .29134 Mdot
.40634 .6135 Mdot
.54946 .53983 Mdot
.61924 .59146 Mdot
.56361 .32959 Mdot
.3981 .30331 Mdot
.73087 .45592 Mdot
.42919 .57278 Mdot
.54453 .30436 Mdot
.47834 .59393 Mdot
.64225 .62431 Mdot
.52623 .28311 Mdot
.54696 .5249 Mdot
.37644 .2969 Mdot
.36717 .58202 Mdot
.58357 .24783 Mdot
.53069 .52381 Mdot
.42724 .60121 Mdot
.36064 .71519 Mdot
.45737 .46647 Mdot
.55859 .52042 Mdot
.55593 .31974 Mdot
.53825 .52601 Mdot
.67813 .62958 Mdot
.42224 .7596 Mdot
.50959 .32015 Mdot
.51769 .62888 Mdot
.39372 .48277 Mdot
.37579 .64429 Mdot
.66355 .62475 Mdot
.45203 .3706 Mdot
.7583 .61756 Mdot
.25478 .43839 Mdot
.40965 .56901 Mdot
.54865 .29231 Mdot
.39153 .30027 Mdot
.67706 .40502 Mdot
.63509 .44022 Mdot
.41365 .36767 Mdot
.5078 .29119 Mdot
.38416 .57234 Mdot
.62964 .58595 Mdot
.67604 .42127 Mdot
.46608 .6744 Mdot
.50039 .32254 Mdot
.55938 .30548 Mdot
.35818 .58383 Mdot
.39471 .30439 Mdot
.53968 .48272 Mdot
.52281 .32951 Mdot
.5379 .33717 Mdot
.65093 .70164 Mdot
.41288 .3341 Mdot
.3581 .615 Mdot
.32072 .63694 Mdot
.37556 .55299 Mdot
.77136 .66783 Mdot
.54359 .52742 Mdot
.63665 .62598 Mdot
.39322 .58967 Mdot
.60386 .31536 Mdot
.5261 .32516 Mdot
.30149 .47847 Mdot
.7026 .39319 Mdot
.65475 .43864 Mdot
.53915 .29172 Mdot
.4108 .57629 Mdot
.65126 .46736 Mdot
.42041 .32096 Mdot
.35642 .61371 Mdot
.37191 .6424 Mdot
.68653 .61915 Mdot
.69206 .41845 Mdot
.39563 .70874 Mdot
.68222 .40605 Mdot
.67682 .43944 Mdot
.66275 .66634 Mdot
.3801 .59298 Mdot
.5207 .29202 Mdot
.52511 .27033 Mdot
.33715 .60942 Mdot
.52471 .37269 Mdot
.6207 .61614 Mdot
.52286 .34577 Mdot
.54059 .82164 Mdot
.40806 .54533 Mdot
.51122 .53387 Mdot
.56513 .49821 Mdot
.64353 .39884 Mdot
.3875 .59465 Mdot
.65794 .6262 Mdot
.5344 .33497 Mdot
.55228 .29821 Mdot
.44163 .54902 Mdot
.65041 .42565 Mdot
.3786 .32049 Mdot
.52694 .30876 Mdot
.33908 .44673 Mdot
.41064 .56495 Mdot
.64839 .3719 Mdot
.5252 .30572 Mdot
.16483 .56115 Mdot
.60558 .31931 Mdot
.65059 .58764 Mdot
.36343 .60522 Mdot
.68435 .64049 Mdot
.41954 .32645 Mdot
.55556 .34133 Mdot
.65875 .40333 Mdot
.49032 .56703 Mdot
.74826 .3195 Mdot
.55151 .30502 Mdot
.65498 .61375 Mdot
.38363 .58402 Mdot
.58893 .75234 Mdot
.42085 .60302 Mdot
.30566 .35333 Mdot
.40683 .28293 Mdot
.73112 .45138 Mdot
.65023 .41067 Mdot
.36548 .61212 Mdot
.3905 .2901 Mdot
.5247 .26862 Mdot
.53482 .30889 Mdot
.77104 .36189 Mdot
.5427 .52215 Mdot
.58078 .33303 Mdot
.42371 .60526 Mdot
.56768 .31637 Mdot
.56435 .66429 Mdot
.65222 .43262 Mdot
.37402 .55481 Mdot
.52165 .27662 Mdot
.74617 .63393 Mdot
.2962 .47238 Mdot
.40946 .56642 Mdot
.32182 .59003 Mdot
.65565 .41237 Mdot
.7316 .68987 Mdot
.54105 .3313 Mdot
.34215 .58554 Mdot
.69191 .38884 Mdot
.32029 .65608 Mdot
.59221 .40468 Mdot
.64329 .61313 Mdot
.53426 .27319 Mdot
.6852 .43605 Mdot
.41229 .65011 Mdot
.38219 .3211 Mdot
.48468 .30246 Mdot
.50527 .28292 Mdot
.40285 .63375 Mdot
.34776 .60028 Mdot
.32053 .58812 Mdot
.6472 .63613 Mdot
.68072 .4317 Mdot
.37224 .63061 Mdot
.31184 .44044 Mdot
.35564 .62053 Mdot
.68399 .43012 Mdot
.87109 .50867 Mdot
.38231 .55957 Mdot
.42868 .57398 Mdot
.58231 .76362 Mdot
.64383 .64253 Mdot
.6783 .60832 Mdot
.30897 .45655 Mdot
.40234 .62323 Mdot
.44693 .48169 Mdot
.64751 .6148 Mdot
.65684 .61171 Mdot
.44779 .48089 Mdot
.40183 .6359 Mdot
.69785 .63189 Mdot
.67532 .42361 Mdot
.65382 .43811 Mdot
.64565 .58871 Mdot
.35623 .56196 Mdot
.67943 .38965 Mdot
.49986 .76825 Mdot
.54866 .27994 Mdot
.23722 .51814 Mdot
.65618 .59904 Mdot
.2907 .47376 Mdot
.67842 .42664 Mdot
.20228 .59094 Mdot
.21534 .55599 Mdot
.41889 .54847 Mdot
.3836 .59499 Mdot
.41049 .31075 Mdot
.48967 .56965 Mdot
.52532 .5443 Mdot
.66314 .43559 Mdot
.53035 .47274 Mdot
.63606 .60682 Mdot
.40599 .62084 Mdot
.26932 .42715 Mdot
.23091 .64767 Mdot
.30667 .56611 Mdot
.65087 .60614 Mdot
.63635 .59804 Mdot
.56213 .30801 Mdot
.56399 .29124 Mdot
.43733 .58237 Mdot
.65123 .41885 Mdot
.64138 .58586 Mdot
.68742 .42332 Mdot
.5381 .30388 Mdot
.51742 .29915 Mdot
.5422 .54038 Mdot
.42793 .64754 Mdot
.53516 .29511 Mdot
.68658 .47655 Mdot
.31268 .44084 Mdot
.67945 .59716 Mdot
.80814 .63908 Mdot
.19886 .57514 Mdot
.62529 .7635 Mdot
.39173 .29863 Mdot
.31571 .65691 Mdot
.69591 .39745 Mdot
.36625 .61436 Mdot
.4045 .59556 Mdot
.52826 .53219 Mdot
.69589 .3955 Mdot
.41234 .32094 Mdot
.65333 .43589 Mdot
.38034 .31229 Mdot
.49719 .30824 Mdot
.38978 .56779 Mdot
.40441 .55587 Mdot
.6742 .40462 Mdot
.56287 .29946 Mdot
.53292 .27849 Mdot
.38586 .30642 Mdot
.21359 .51871 Mdot
.54504 .30725 Mdot
.65685 .60047 Mdot
.50375 .65335 Mdot
.53605 .53339 Mdot
.40905 .58128 Mdot
.23166 .48137 Mdot
.41105 .75445 Mdot
.33969 .60094 Mdot
.51598 .53333 Mdot
.86187 .56402 Mdot
.40393 .55952 Mdot
.73312 .28274 Mdot
.54842 .53845 Mdot
.65027 .64228 Mdot
.52705 .28783 Mdot
.53227 .52229 Mdot
.33304 .6755 Mdot
.51939 .24849 Mdot
.33645 .60322 Mdot
.61501 .60027 Mdot
.62459 .62764 Mdot
.48756 .44727 Mdot
.76981 .67118 Mdot
.40692 .29506 Mdot
.41875 .31747 Mdot
.52092 .32574 Mdot
.74089 .44443 Mdot
.39528 .53888 Mdot
.41868 .31232 Mdot
.70288 .64252 Mdot
.35742 .60071 Mdot
.46234 .46404 Mdot
.50704 .45385 Mdot
.6792 .62466 Mdot
.42395 .63452 Mdot
.52253 .3254 Mdot
.65275 .61278 Mdot
.49528 .45008 Mdot
.35982 .57009 Mdot
.63902 .60934 Mdot
.67348 .4387 Mdot
.43407 .51153 Mdot
.66161 .59985 Mdot
.29461 .50779 Mdot
.67023 .40972 Mdot
.46949 .45778 Mdot
.25806 .33209 Mdot
.17358 .62493 Mdot
.65293 .42779 Mdot
.54197 .28151 Mdot
.54774 .29818 Mdot
.54528 .3127 Mdot
.66046 .63402 Mdot
.52741 .32014 Mdot
.62582 .61766 Mdot
.63909 .39695 Mdot
.23684 .53895 Mdot
.40387 .30652 Mdot
.47361 .3678 Mdot
.64884 .5905 Mdot
.78706 .65697 Mdot
.72216 .77915 Mdot
.35319 .61615 Mdot
.64187 .43017 Mdot
.4165 .29377 Mdot
.31335 .48018 Mdot
.41233 .31201 Mdot
.53408 .28296 Mdot
.24739 .53438 Mdot
.41719 .57713 Mdot
.69059 .49477 Mdot
.39162 .3015 Mdot
.65834 .61161 Mdot
.41138 .62418 Mdot
.55211 .2759 Mdot
.41917 .32514 Mdot
.38944 .31025 Mdot
.40044 .58337 Mdot
.6374 .63816 Mdot
.53181 .28026 Mdot
.69722 .42743 Mdot
.39708 .34763 Mdot
.37469 .53084 Mdot
.39773 .56068 Mdot
.41385 .55241 Mdot
.29621 .46624 Mdot
.74205 .44544 Mdot
.66888 .41218 Mdot
.28357 .40198 Mdot
.542 .32601 Mdot
.25405 .43549 Mdot
.76956 .6048 Mdot
.45503 .3659 Mdot
.54291 .52774 Mdot
.54669 .52872 Mdot
.39705 .57128 Mdot
.63699 .82248 Mdot
.4707 .54065 Mdot
.67967 .3867 Mdot
.52918 .53533 Mdot
.55711 .28355 Mdot
.65812 .5837 Mdot
.51103 .59252 Mdot
.42797 .5424 Mdot
.69804 .42488 Mdot
.53979 .30921 Mdot
.56004 .85927 Mdot
.41354 .29979 Mdot
.31618 .47829 Mdot
.40417 .6126 Mdot
.40029 .57466 Mdot
.66291 .42185 Mdot
.66196 .40087 Mdot
.64859 .70205 Mdot
.44897 .40428 Mdot
.75536 .45711 Mdot
.67013 .46162 Mdot
.55693 .86125 Mdot
.56589 .50658 Mdot
.62855 .60446 Mdot
.51438 .54466 Mdot
.64934 .40648 Mdot
.39716 .59064 Mdot
.64236 .64147 Mdot
.50041 .55422 Mdot
.62443 .63855 Mdot
.45326 .4699 Mdot
.33302 .44459 Mdot
.37834 .59933 Mdot
.6643 .64961 Mdot
.64741 .61128 Mdot
.63274 .56611 Mdot
.53311 .54039 Mdot
.41597 .59794 Mdot
.34047 .58545 Mdot
.42285 .56157 Mdot
.61287 .68586 Mdot
.39845 .56787 Mdot
.76773 .60922 Mdot
.31921 .45627 Mdot
.48592 .17407 Mdot
.41071 .5591 Mdot
.67085 .44256 Mdot
.38496 .57546 Mdot
.38807 .29036 Mdot
.36986 .57164 Mdot
.44397 .4741 Mdot
.67263 .42142 Mdot
.56677 .80202 Mdot
.48166 .27725 Mdot
.39374 .56054 Mdot
.39664 .33445 Mdot
.81928 .54316 Mdot
.28376 .4054 Mdot
.65183 .70048 Mdot
.65823 .59749 Mdot
.51953 .33505 Mdot
.6458 .4073 Mdot
.51765 .30734 Mdot
.44763 .58366 Mdot
.52752 .54595 Mdot
.21931 .32818 Mdot
.28319 .44411 Mdot
.39476 .58974 Mdot
.45853 .62409 Mdot
.6733 .61118 Mdot
.52315 .32397 Mdot
.66362 .741 Mdot
.3562 .5679 Mdot
.37843 .2877 Mdot
.40514 .28767 Mdot
.44882 .28638 Mdot
.61349 .65661 Mdot
.58273 .66955 Mdot
.66443 .42045 Mdot
.55425 .30582 Mdot
.418 .29227 Mdot
.70255 .60739 Mdot
.64448 .41423 Mdot
.64488 .39696 Mdot
.69241 .421 Mdot
.42012 .56767 Mdot
.54503 .53636 Mdot
.64904 .67574 Mdot
.53999 .52305 Mdot
.3766 .54943 Mdot
.5063 .28241 Mdot
.54442 .52507 Mdot
.40357 .31211 Mdot
.6805 .43927 Mdot
.51621 .29473 Mdot
.39191 .58048 Mdot
.64799 .61863 Mdot
.39024 .39488 Mdot
.6008 .28932 Mdot
.4577 .46569 Mdot
.45782 .4656 Mdot
.64017 .57144 Mdot
.55735 .48592 Mdot
.7079 .38035 Mdot
.44875 .7701 Mdot
.39592 .35126 Mdot
.37445 .53825 Mdot
.53683 .36914 Mdot
.4988 .31807 Mdot
.52806 .29811 Mdot
.42019 .57809 Mdot
.56226 .32546 Mdot
.4113 .61586 Mdot
.55643 .3201 Mdot
.76313 .63298 Mdot
.44044 .5534 Mdot
.52977 .30688 Mdot
.49475 .56426 Mdot
.42949 .59948 Mdot
.67163 .62163 Mdot
.51752 .33226 Mdot
.41848 .54824 Mdot
.35589 .18173 Mdot
.66627 .40313 Mdot
.53487 .53912 Mdot
.38303 .46238 Mdot
.67386 .43259 Mdot
.61885 .60403 Mdot
.39659 .61732 Mdot
.42052 .30605 Mdot
.63037 .5986 Mdot
.46352 .28921 Mdot
.39241 .30675 Mdot
.34083 .47052 Mdot
.63383 .59218 Mdot
.53816 .5313 Mdot
.38102 .28787 Mdot
.33839 .60839 Mdot
.52931 .30079 Mdot
.60385 .30158 Mdot
.51828 .52934 Mdot
.41794 .58161 Mdot
.55275 .27772 Mdot
.65931 .4395 Mdot
.37687 .57667 Mdot
.54983 .29766 Mdot
.51317 .54148 Mdot
.43262 .58592 Mdot
.41121 .62128 Mdot
.71686 .69309 Mdot
.49028 .42004 Mdot
.40371 .30892 Mdot
.68351 .59508 Mdot
.39341 .54314 Mdot
.38858 .29307 Mdot
.59958 .31437 Mdot
.40102 .6466 Mdot
.61924 .58734 Mdot
.49017 .76833 Mdot
.56863 .30919 Mdot
.64817 .42259 Mdot
.49924 .27997 Mdot
.42314 .32478 Mdot
.76796 .74699 Mdot
.52842 .54431 Mdot
.40433 .64052 Mdot
.38684 .55136 Mdot
.5418 .34241 Mdot
.64432 .60907 Mdot
.75455 .46365 Mdot
.36635 .58382 Mdot
.45969 .61562 Mdot
.40516 .58238 Mdot
.56766 .24161 Mdot
.65406 .63725 Mdot
.40755 .5824 Mdot
.33522 .56821 Mdot
.39376 .54736 Mdot
.39678 .33116 Mdot
.22926 .33555 Mdot
.35589 .62784 Mdot
.88743 .42982 Mdot
.50689 .54742 Mdot
.5365 .31293 Mdot
.29725 .50601 Mdot
.38608 .4577 Mdot
.41633 .18245 Mdot
.61947 .60966 Mdot
.63348 .5624 Mdot
.51826 .2994 Mdot
.43284 .36758 Mdot
.54621 .4879 Mdot
.40703 .62563 Mdot
.39914 .61365 Mdot
.53395 .28299 Mdot
.56351 .33074 Mdot
.51304 .54722 Mdot
.36977 .64541 Mdot
.41351 .64455 Mdot
.50057 .28257 Mdot
.39577 .56687 Mdot
.39696 .74795 Mdot
.64164 .43782 Mdot
.6556 .58967 Mdot
.67827 .40367 Mdot
.64866 .44637 Mdot
.64044 .75956 Mdot
.30387 .46253 Mdot
.69572 .42441 Mdot
.67959 .38016 Mdot
.45421 .37278 Mdot
.60575 .74541 Mdot
.39251 .32934 Mdot
.47012 .5384 Mdot
.54531 .32004 Mdot
.41442 .59924 Mdot
.65645 .63712 Mdot
.33405 .3337 Mdot
.77138 .46217 Mdot
.28226 .65492 Mdot
.35914 .61499 Mdot
.53601 .32489 Mdot
.51582 .53083 Mdot
.39699 .64841 Mdot
.24953 .43985 Mdot
.40409 .57001 Mdot
.56977 .30549 Mdot
.60995 .74317 Mdot
.60599 .42331 Mdot
.64012 .45702 Mdot
.58811 .58887 Mdot
.38433 .57528 Mdot
.65008 .63327 Mdot
.67591 .45416 Mdot
.39411 .29223 Mdot
.41196 .30459 Mdot
.39273 .56057 Mdot
.41592 .48212 Mdot
.4097 .35025 Mdot
.41263 .62191 Mdot
.39932 .63648 Mdot
.53676 .52668 Mdot
.39562 .63847 Mdot
.33861 .58397 Mdot
.37015 .62698 Mdot
.34412 .6005 Mdot
.64594 .41241 Mdot
.64008 .74811 Mdot
.38435 .64671 Mdot
.44263 .58947 Mdot
.66705 .4543 Mdot
.44501 .58905 Mdot
.65656 .4277 Mdot
.7554 .42215 Mdot
.69656 .41045 Mdot
.40982 .30373 Mdot
.56116 .28244 Mdot
.70226 .69795 Mdot
.6395 .58604 Mdot
.65594 .44315 Mdot
.37545 .30444 Mdot
.65807 .43421 Mdot
.554 .316 Mdot
.61585 .45292 Mdot
.58651 .60675 Mdot
.34457 .44989 Mdot
.60367 .75535 Mdot
.63983 .36877 Mdot
.56481 .31712 Mdot
.64188 .58737 Mdot
.71435 .46638 Mdot
.36789 .61531 Mdot
.41239 .29763 Mdot
.39674 .57216 Mdot
.67862 .43979 Mdot
.54181 .32201 Mdot
.68338 .69947 Mdot
.40481 .30939 Mdot
.82583 .61951 Mdot
.49232 .29336 Mdot
.37918 .5574 Mdot
.66735 .4554 Mdot
.67326 .47431 Mdot
.65984 .40477 Mdot
.23224 .5358 Mdot
.56221 .4921 Mdot
.35779 .35867 Mdot
.63599 .59524 Mdot
.56112 .52835 Mdot
.23409 .70311 Mdot
.79045 .53178 Mdot
.64574 .62312 Mdot
.59213 .3217 Mdot
.40844 .56274 Mdot
.36208 .62291 Mdot
.44377 .63664 Mdot
.63174 .64002 Mdot
.35641 .6065 Mdot
.53859 .53833 Mdot
.30082 .45249 Mdot
.58166 .59949 Mdot
.4871 .31136 Mdot
.41459 .61189 Mdot
.67037 .458 Mdot
.65181 .44204 Mdot
.5551 .53231 Mdot
.68743 .40847 Mdot
.43184 .606 Mdot
.64358 .59093 Mdot
.50045 .45152 Mdot
.42286 .3227 Mdot
.78923 .58569 Mdot
.44198 .31701 Mdot
.39688 .34293 Mdot
.40943 .54486 Mdot
.51847 .29593 Mdot
.73336 .2968 Mdot
.36311 .61348 Mdot
.65022 .61456 Mdot
.37924 .55505 Mdot
.36738 .6284 Mdot
.43103 .61213 Mdot
.55396 .30614 Mdot
.2941 .47189 Mdot
.39489 .56713 Mdot
.68776 .44497 Mdot
.44302 .4815 Mdot
.43086 .54267 Mdot
.5415 .45512 Mdot
.44776 .47268 Mdot
.6354 .37757 Mdot
.68411 .60795 Mdot
.52223 .29126 Mdot
.63454 .60428 Mdot
.61167 .63049 Mdot
.61914 .60443 Mdot
.63366 .66651 Mdot
.43871 .7671 Mdot
.72767 .27384 Mdot
.56876 .66591 Mdot
.60462 .75827 Mdot
.60479 .6251 Mdot
.6226 .22971 Mdot
.65119 .62588 Mdot
.61892 .6057 Mdot
.83204 .45379 Mdot
.62863 .62848 Mdot
.41208 .58909 Mdot
.40831 .55357 Mdot
.50513 .82027 Mdot
.36841 .32902 Mdot
.4282 .5954 Mdot
.34226 .6007 Mdot
.41171 .28931 Mdot
.72356 .65597 Mdot
.50548 .54251 Mdot
.31963 .47997 Mdot
.55094 .52241 Mdot
.39965 .58303 Mdot
.37269 .58991 Mdot
.42461 .53241 Mdot
.24694 .67308 Mdot
.38647 .36515 Mdot
.62151 .62487 Mdot
.34606 .55897 Mdot
.62609 .36932 Mdot
.37359 .60497 Mdot
.36749 .56465 Mdot
.42597 .61832 Mdot
.5206 .29211 Mdot
.6411 .57887 Mdot
.47208 .6076 Mdot
.80083 .55875 Mdot
.39056 .60674 Mdot
.43742 .30278 Mdot
.36969 .28874 Mdot
.41157 .57736 Mdot
.62111 .62 Mdot
.36045 .62003 Mdot
.67002 .59481 Mdot
.63021 .5945 Mdot
.43969 .63452 Mdot
.66936 .67424 Mdot
.65517 .58283 Mdot
.40606 .62591 Mdot
.56414 .30358 Mdot
.78325 .60721 Mdot
.41672 .58011 Mdot
.39847 .31238 Mdot
.38476 .59184 Mdot
.39855 .33281 Mdot
.36654 .63786 Mdot
.53885 .52421 Mdot
.33918 .72707 Mdot
.50454 .31406 Mdot
.41533 .33937 Mdot
.56543 .32151 Mdot
.38796 .53878 Mdot
.67232 .65681 Mdot
.6097 .4356 Mdot
.4168 .36081 Mdot
.53769 .52704 Mdot
.30147 .37988 Mdot
.46108 .48157 Mdot
.69283 .39702 Mdot
.67417 .62209 Mdot
.63206 .74033 Mdot
.53777 .45337 Mdot
.48414 .3079 Mdot
.54468 .27699 Mdot
.58968 .39753 Mdot
.84048 .47884 Mdot
.41155 .5601 Mdot
.55423 .471 Mdot
.42436 .72447 Mdot
.48938 .57057 Mdot
.49771 .56182 Mdot
.5041 .2833 Mdot
.42808 .59642 Mdot
.2775 .45632 Mdot
.54555 .30032 Mdot
.40736 .32713 Mdot
.63779 .6273 Mdot
.38192 .30063 Mdot
.72623 .5037 Mdot
.65696 .70382 Mdot
.53821 .29697 Mdot
.34715 .60449 Mdot
.42678 .59107 Mdot
.65117 .64344 Mdot
.46663 .67342 Mdot
.66274 .59239 Mdot
.42417 .30955 Mdot
.51062 .32239 Mdot
.29224 .23579 Mdot
.38222 .58469 Mdot
.65552 .60324 Mdot
.48339 .27608 Mdot
.39104 .60111 Mdot
.65 .42706 Mdot
.35641 .60439 Mdot
.66155 .60793 Mdot
.39306 .63942 Mdot
.63465 .59519 Mdot
.55934 .29948 Mdot
.3978 .55786 Mdot
.37348 .57997 Mdot
.28692 .39659 Mdot
.41162 .32082 Mdot
.65976 .58615 Mdot
.27781 .46841 Mdot
.3756 .55296 Mdot
.24041 .45594 Mdot
.39241 .56572 Mdot
.59841 .75154 Mdot
.31849 .61733 Mdot
.54075 .53618 Mdot
.38011 .55413 Mdot
.41581 .57773 Mdot
.46777 .67092 Mdot
.55995 .66317 Mdot
.6161 .68773 Mdot
.64819 .43093 Mdot
.66669 .62656 Mdot
.54467 .29552 Mdot
.52197 .3342 Mdot
.52367 .31646 Mdot
.42267 .28983 Mdot
.33402 .60303 Mdot
.4205 .58827 Mdot
.67571 .38418 Mdot
.41822 .30695 Mdot
.64902 .60209 Mdot
.40465 .30175 Mdot
.30512 .46832 Mdot
.39897 .31531 Mdot
.52209 .54474 Mdot
.60593 .33712 Mdot
.40608 .75115 Mdot
.39463 .32198 Mdot
.65138 .58863 Mdot
.42947 .48667 Mdot
.48622 .57023 Mdot
.75706 .67766 Mdot
.38197 .28372 Mdot
.59555 .31657 Mdot
.43401 .58368 Mdot
.28716 .50922 Mdot
.65904 .42816 Mdot
.3813 .30069 Mdot
.69298 .41784 Mdot
.36128 .62008 Mdot
.60224 .56552 Mdot
.6594 .61791 Mdot
.64284 .44173 Mdot
.36805 .56094 Mdot
.38157 .29987 Mdot
.53423 .29774 Mdot
.60519 .74437 Mdot
.63585 .41044 Mdot
.40624 .3938 Mdot
.25513 .43694 Mdot
.52539 .32766 Mdot
.57965 .73845 Mdot
.69515 .41103 Mdot
.34797 .5572 Mdot
.40386 .51819 Mdot
.37011 .54908 Mdot
.53117 .27866 Mdot
.52746 .29764 Mdot
.69121 .36286 Mdot
.37173 .58239 Mdot
.4003 .64153 Mdot
.67843 .59253 Mdot
.51847 .32684 Mdot
.61943 .60318 Mdot
.67244 .64867 Mdot
.54284 .28241 Mdot
.66828 .59535 Mdot
.39121 .30699 Mdot
.25328 .49434 Mdot
.69547 .41251 Mdot
.64985 .41326 Mdot
.53669 .29519 Mdot
.50294 .30099 Mdot
.51783 .29657 Mdot
.35619 .57555 Mdot
.62613 .59539 Mdot
.36818 .61008 Mdot
.38362 .57811 Mdot
.50817 .53336 Mdot
.69105 .63138 Mdot
.36339 .59798 Mdot
.50925 .45784 Mdot
.3843 .27982 Mdot
.53129 .31135 Mdot
.68423 .42468 Mdot
.38071 .39156 Mdot
.69382 .43656 Mdot
.38842 .54744 Mdot
.75186 .6434 Mdot
.66371 .62845 Mdot
.41156 .31166 Mdot
.4452 .4728 Mdot
.40763 .30992 Mdot
.64203 .4391 Mdot
.65187 .57245 Mdot
.33753 .46862 Mdot
.37323 .57674 Mdot
.29582 .46388 Mdot
.26341 .3528 Mdot
.77049 .59614 Mdot
.6787 .43365 Mdot
.35667 .61779 Mdot
.54848 .5327 Mdot
.45135 .77195 Mdot
.42054 .5847 Mdot
.43129 .54894 Mdot
.40779 .46867 Mdot
.39757 .54827 Mdot
.60924 .59838 Mdot
.46949 .46254 Mdot
.34656 .61697 Mdot
.36506 .54973 Mdot
.77224 .37633 Mdot
.43117 .58778 Mdot
.37779 .57128 Mdot
.40951 .59713 Mdot
.35976 .6041 Mdot
.68475 .63955 Mdot
.47895 .4472 Mdot
.67417 .45383 Mdot
.25299 .49422 Mdot
.69307 .42632 Mdot
.53613 .28902 Mdot
.43262 .40125 Mdot
.68143 .60892 Mdot
.40751 .3105 Mdot
.56632 .46903 Mdot
.25112 .53856 Mdot
.56243 .30699 Mdot
.302 .37096 Mdot
.37863 .3189 Mdot
.48796 .57893 Mdot
.42175 .32694 Mdot
.51707 .2772 Mdot
.65114 .42685 Mdot
.38668 .55691 Mdot
.61919 .59336 Mdot
.66263 .60003 Mdot
.3876 .54198 Mdot
.8042 .57121 Mdot
.64719 .42218 Mdot
.51432 .37287 Mdot
.42023 .57089 Mdot
.37369 .55498 Mdot
.67616 .60375 Mdot
.52756 .32456 Mdot
.46145 .48014 Mdot
.3882 .32261 Mdot
.37873 .60574 Mdot
.34606 .61013 Mdot
.30385 .46741 Mdot
.64926 .43643 Mdot
.52436 .53943 Mdot
.42186 .59766 Mdot
.31527 .46817 Mdot
.35469 .6003 Mdot
.39216 .53498 Mdot
.56606 .30109 Mdot
.45108 .62463 Mdot
.36937 .59141 Mdot
.5866 .59081 Mdot
.69447 .40831 Mdot
.64346 .61135 Mdot
.60851 .5779 Mdot
.53906 .52507 Mdot
.66665 .40395 Mdot
.36064 .59135 Mdot
.6398 .41185 Mdot
.36451 .62546 Mdot
.3898 .57684 Mdot
.67667 .43586 Mdot
.62236 .60704 Mdot
.74732 .46363 Mdot
.64048 .74708 Mdot
.37678 .63229 Mdot
.38704 .59516 Mdot
.3684 .32888 Mdot
.33481 .3151 Mdot
.3692 .58166 Mdot
.64526 .58692 Mdot
.38739 .59936 Mdot
.67222 .39517 Mdot
.40464 .29466 Mdot
.65213 .61853 Mdot
.53679 .32932 Mdot
.55818 .29922 Mdot
.50595 .26672 Mdot
.52152 .54502 Mdot
.4033 .63928 Mdot
.68367 .5954 Mdot
.69145 .63402 Mdot
.27018 .49824 Mdot
.53542 .31238 Mdot
.39636 .2958 Mdot
.42248 .60815 Mdot
.49342 .57167 Mdot
.65767 .44952 Mdot
.88688 .41847 Mdot
.3343 .46873 Mdot
.37775 .28026 Mdot
.4512 .40968 Mdot
.52797 .52938 Mdot
.42913 .57972 Mdot
.38573 .29371 Mdot
.54612 .28596 Mdot
.36145 .62252 Mdot
.32021 .61609 Mdot
.5974 .30978 Mdot
.50928 .29865 Mdot
.63817 .41411 Mdot
.54977 .3251 Mdot
.38373 .32497 Mdot
.5265 .54419 Mdot
.66917 .61682 Mdot
.40911 .57276 Mdot
.40092 .6495 Mdot
.54307 .31676 Mdot
.53935 .5455 Mdot
.40933 .5558 Mdot
.66715 .62969 Mdot
.5311 .31838 Mdot
.4015 .58718 Mdot
.46322 .76841 Mdot
.70396 .69617 Mdot
.54356 .32285 Mdot
.39058 .61492 Mdot
.50335 .60946 Mdot
.51132 .29551 Mdot
.51775 .2778 Mdot
.353 .61489 Mdot
.37992 .29705 Mdot
.37643 .59923 Mdot
.65244 .41842 Mdot
.29075 .46759 Mdot
.67211 .40404 Mdot
.24781 .44027 Mdot
.34491 .58681 Mdot
.34157 .53227 Mdot
.63587 .64779 Mdot
.42448 .33694 Mdot
.20043 .5626 Mdot
.40264 .54415 Mdot
.72015 .62363 Mdot
.29044 .47249 Mdot
.35654 .45763 Mdot
.69718 .58166 Mdot
.3828 .31729 Mdot
.66221 .43469 Mdot
.38723 .56439 Mdot
.74077 .45967 Mdot
.38389 .31526 Mdot
.24685 .44208 Mdot
.384 .61898 Mdot
.65327 .60918 Mdot
.41672 .56676 Mdot
.66726 .61574 Mdot
.40139 .60312 Mdot
.71916 .69181 Mdot
.40611 .35085 Mdot
.23234 .53629 Mdot
.48775 .57789 Mdot
.67244 .47422 Mdot
.60388 .75581 Mdot
.39493 .30181 Mdot
.38645 .63835 Mdot
.52078 .53335 Mdot
.65359 .43625 Mdot
.62171 .47806 Mdot
.51771 .30066 Mdot
.68848 .44333 Mdot
.62788 .6107 Mdot
.54142 .2701 Mdot
.55079 .53945 Mdot
.29858 .62619 Mdot
.38183 .29769 Mdot
.66537 .40398 Mdot
.41353 .57599 Mdot
.37077 .54978 Mdot
.56861 .24166 Mdot
.22231 .342 Mdot
.67908 .64728 Mdot
.8443 .59537 Mdot
.65841 .57528 Mdot
.41624 .31905 Mdot
.56339 .29477 Mdot
.39729 .59244 Mdot
.40977 .61069 Mdot
.50894 .30106 Mdot
.65658 .64256 Mdot
.40118 .34229 Mdot
.35347 .35319 Mdot
.6798 .38766 Mdot
.23112 .35777 Mdot
.65561 .62063 Mdot
.23189 .35613 Mdot
.47423 .3433 Mdot
.69802 .67984 Mdot
.20863 .53229 Mdot
.67453 .42854 Mdot
.23063 .3576 Mdot
.65554 .60768 Mdot
.42149 .56401 Mdot
.53571 .53121 Mdot
.53262 .54601 Mdot
.64917 .6311 Mdot
.53067 .28321 Mdot
.37939 .31784 Mdot
.41636 .56829 Mdot
.31181 .63425 Mdot
.4662 .67442 Mdot
.49844 .31019 Mdot
.46665 .61096 Mdot
.67997 .42068 Mdot
.38967 .59922 Mdot
.4165 .29228 Mdot
.67352 .42767 Mdot
.54673 .52357 Mdot
.24847 .53263 Mdot
.39622 .61716 Mdot
.4328 .47885 Mdot
.65931 .42469 Mdot
.333 .31548 Mdot
.37313 .58249 Mdot
.69511 .41113 Mdot
.40429 .64831 Mdot
.63285 .36094 Mdot
.48894 .46495 Mdot
.78973 .53194 Mdot
.49254 .28306 Mdot
.55632 .31968 Mdot
.34977 .1915 Mdot
.42212 .18973 Mdot
.68384 .44194 Mdot
.51204 .53458 Mdot
.22735 .33385 Mdot
.69225 .40901 Mdot
.36465 .58316 Mdot
.40037 .56153 Mdot
.61046 .74304 Mdot
.49006 .56528 Mdot
.50804 .54677 Mdot
.56767 .59544 Mdot
.42682 .61298 Mdot
.47056 .60528 Mdot
.37956 .57388 Mdot
.62571 .62966 Mdot
.6777 .42144 Mdot
.3643 .81141 Mdot
.64082 .41836 Mdot
.33472 .53903 Mdot
.54485 .32041 Mdot
.5069 .27251 Mdot
.41029 .57701 Mdot
.54462 .5715 Mdot
.56449 .86197 Mdot
.3974 .5615 Mdot
.44449 .47319 Mdot
.25638 .43416 Mdot
.3331 .58981 Mdot
.6277 .58098 Mdot
.40599 .64863 Mdot
.69384 .6189 Mdot
.67103 .43207 Mdot
.38282 .31676 Mdot
.42903 .33549 Mdot
.66148 .43302 Mdot
.41129 .60856 Mdot
.43868 .32194 Mdot
.40163 .57683 Mdot
.42672 .58079 Mdot
.31266 .47178 Mdot
.42165 .29782 Mdot
.52128 .28841 Mdot
.41056 .30541 Mdot
.6203 .61354 Mdot
.86918 .52687 Mdot
.39977 .30039 Mdot
.60608 .74531 Mdot
.28152 .46747 Mdot
.23406 .33306 Mdot
.66642 .60297 Mdot
.4222 .32414 Mdot
.66418 .43821 Mdot
.35177 .47588 Mdot
.57248 .76817 Mdot
.69451 .43459 Mdot
.4219 .59163 Mdot
.68371 .64178 Mdot
.64908 .57269 Mdot
.69108 .44508 Mdot
.67171 .61819 Mdot
.3292 .61107 Mdot
.39677 .62932 Mdot
.67841 .45245 Mdot
.22225 .64124 Mdot
.64932 .41168 Mdot
.65219 .75259 Mdot
.40041 .63869 Mdot
.65084 .61625 Mdot
.59601 .75512 Mdot
.60665 .57498 Mdot
.53868 .54241 Mdot
.37327 .56847 Mdot
.3987 .2975 Mdot
.2673 .48899 Mdot
.53784 .32645 Mdot
.74709 .63315 Mdot
.65667 .59767 Mdot
.69511 .44185 Mdot
.67105 .61865 Mdot
.67603 .61849 Mdot
.64655 .44652 Mdot
.6624 .62785 Mdot
.39279 .60759 Mdot
.72661 .69258 Mdot
.6706 .60327 Mdot
.66689 .4219 Mdot
.42341 .31204 Mdot
.6501 .5875 Mdot
.50485 .37701 Mdot
.42102 .60778 Mdot
.49654 .31883 Mdot
.34691 .29537 Mdot
.66886 .64798 Mdot
.39437 .3006 Mdot
.53936 .31702 Mdot
.37446 .29763 Mdot
.74305 .42137 Mdot
.70797 .46688 Mdot
.3408 .68398 Mdot
.62278 .36174 Mdot
.62619 .6254 Mdot
.53544 .26721 Mdot
.39228 .61232 Mdot
.42272 .57366 Mdot
.41275 .28556 Mdot
.61544 .58267 Mdot
.81153 .55885 Mdot
.4982 .55296 Mdot
.78993 .58406 Mdot
.64796 .43163 Mdot
.49104 .37058 Mdot
.33902 .46643 Mdot
.62246 .41286 Mdot
.3478 .62157 Mdot
.52784 .52993 Mdot
.40581 .58294 Mdot
.28283 .40644 Mdot
.38381 .32431 Mdot
.62347 .24858 Mdot
.35532 .56449 Mdot
.50828 .30496 Mdot
.40184 .60065 Mdot
.53994 .47671 Mdot
.35676 .55699 Mdot
.38875 .27861 Mdot
.69237 .38909 Mdot
.64011 .586 Mdot
.4126 .33075 Mdot
.55765 .29664 Mdot
.22859 .5646 Mdot
.3659 .59176 Mdot
.43185 .60364 Mdot
.51731 .28573 Mdot
.61762 .59926 Mdot
.53139 .29169 Mdot
.6954 .41381 Mdot
.4011 .30275 Mdot
.35624 .59332 Mdot
.46854 .60625 Mdot
.54426 .34245 Mdot
.66114 .44761 Mdot
.55734 .28212 Mdot
.63893 .41571 Mdot
.53507 .52889 Mdot
.36021 .55055 Mdot
.56728 .29035 Mdot
.35092 .62557 Mdot
.56694 .70903 Mdot
.25403 .53313 Mdot
.48508 .65092 Mdot
.52802 .28142 Mdot
.42563 .18 Mdot
.67095 .42623 Mdot
.67218 .39937 Mdot
.65892 .75092 Mdot
.62549 .83035 Mdot
.44748 .48151 Mdot
.81784 .528 Mdot
.69554 .41362 Mdot
.65815 .41989 Mdot
.52816 .28995 Mdot
.62359 .61624 Mdot
.63597 .64633 Mdot
.54702 .27582 Mdot
.22983 .48716 Mdot
.64936 .60215 Mdot
.52864 .82271 Mdot
.49494 .3112 Mdot
.43826 .60396 Mdot
.69417 .6972 Mdot
.38579 .28041 Mdot
.26545 .4324 Mdot
.6147 .45381 Mdot
.40552 .59154 Mdot
.73792 .28915 Mdot
.51919 .30204 Mdot
.50779 .55352 Mdot
.71435 .41374 Mdot
.36048 .56458 Mdot
.40779 .60059 Mdot
.38734 .60295 Mdot
.39306 .27423 Mdot
.54168 .67003 Mdot
.40189 .59204 Mdot
.24217 .53608 Mdot
.44733 .56586 Mdot
.58911 .2574 Mdot
.41023 .30509 Mdot
.30416 .35659 Mdot
.58269 .31301 Mdot
.8035 .54962 Mdot
.42408 .5466 Mdot
.68395 .39651 Mdot
.52297 .46289 Mdot
.67821 .43657 Mdot
.64784 .37356 Mdot
.21097 .39146 Mdot
.61069 .59804 Mdot
.35477 .56804 Mdot
.49599 .30017 Mdot
.64409 .65073 Mdot
.51771 .45981 Mdot
.86966 .53813 Mdot
.70192 .42783 Mdot
.79028 .73229 Mdot
.68218 .40138 Mdot
.515 .54775 Mdot
.63054 .61477 Mdot
.53333 .59944 Mdot
.2977 .46357 Mdot
.62 .60423 Mdot
.48473 .19831 Mdot
.69526 .62285 Mdot
.20184 .47284 Mdot
.58839 .60915 Mdot
.67008 .41739 Mdot
.69188 .44481 Mdot
.32456 .62452 Mdot
.3748 .59924 Mdot
.29154 .45259 Mdot
.49342 .56095 Mdot
.39921 .61881 Mdot
.54594 .30048 Mdot
.62162 .36027 Mdot
.74331 .45255 Mdot
.65852 .62801 Mdot
.66651 .44955 Mdot
.40464 .60037 Mdot
.37746 .63312 Mdot
.40078 .55163 Mdot
.43089 .36902 Mdot
.5184 .8244 Mdot
.38879 .57421 Mdot
.38369 .53846 Mdot
.56235 .30271 Mdot
.56697 .23992 Mdot
.84154 .5158 Mdot
.21965 .37342 Mdot
.42933 .56475 Mdot
.41528 .31592 Mdot
.42426 .29674 Mdot
.32248 .60285 Mdot
.53855 .59152 Mdot
.40078 .26565 Mdot
.4139 .57642 Mdot
.23585 .55491 Mdot
.51513 .33473 Mdot
.55365 .53264 Mdot
.54298 .31621 Mdot
.62029 .63933 Mdot
.54725 .53083 Mdot
.54825 .29345 Mdot
.23412 .52189 Mdot
.52974 .52455 Mdot
.6498 .35923 Mdot
.42459 .32004 Mdot
.37646 .5776 Mdot
.64236 .72816 Mdot
.51937 .3275 Mdot
.65727 .41388 Mdot
.63527 .61363 Mdot
.64829 .42908 Mdot
.60382 .30766 Mdot
.23683 .46829 Mdot
.53536 .5418 Mdot
.68255 .39613 Mdot
.42959 .48079 Mdot
.41612 .31186 Mdot
.68743 .40598 Mdot
.38603 .51768 Mdot
.43597 .54483 Mdot
.53713 .85064 Mdot
.42917 .60437 Mdot
.69283 .3642 Mdot
.66394 .40294 Mdot
.5511 .52679 Mdot
.40753 .57179 Mdot
.4901 .29684 Mdot
.33 .65359 Mdot
.40016 .57741 Mdot
.53471 .33083 Mdot
.40201 .56264 Mdot
.40044 .28998 Mdot
.6592 .57406 Mdot
.29029 .47676 Mdot
.42086 .39401 Mdot
.38731 .32544 Mdot
.26607 .52917 Mdot
.36926 .57998 Mdot
.44954 .19399 Mdot
.64985 .60787 Mdot
.39017 .54709 Mdot
.24449 .4201 Mdot
.6345 .62768 Mdot
.63451 .6019 Mdot
.40731 .6305 Mdot
.65954 .39912 Mdot
.52069 .28636 Mdot
.41497 .30906 Mdot
.63111 .42168 Mdot
.4004 .58861 Mdot
.35685 .61731 Mdot
.39116 .32803 Mdot
.66158 .40892 Mdot
.35724 .59229 Mdot
.72887 .5579 Mdot
.2527 .50186 Mdot
.64228 .43727 Mdot
.4302 .54225 Mdot
.56271 .81702 Mdot
.67321 .63248 Mdot
.73577 .28602 Mdot
.40399 .35109 Mdot
.55205 .28474 Mdot
.4556 .62344 Mdot
.88543 .44346 Mdot
.42424 .31106 Mdot
.78352 .58167 Mdot
.41584 .56137 Mdot
.39161 .59188 Mdot
.62527 .62728 Mdot
.36752 .60694 Mdot
.66563 .62774 Mdot
.4727 .37445 Mdot
.65146 .81536 Mdot
.66876 .60804 Mdot
.66364 .61264 Mdot
.4496 .53071 Mdot
.44019 .33453 Mdot
.63835 .62632 Mdot
.36827 .59566 Mdot
.48726 .18076 Mdot
.34275 .54803 Mdot
.39007 .33719 Mdot
.37518 .27437 Mdot
.6326 .58163 Mdot
.57324 .77404 Mdot
.41585 .52283 Mdot
.52601 .80844 Mdot
.39202 .26413 Mdot
.68741 .43818 Mdot
.36366 .63111 Mdot
.5101 .53804 Mdot
.52933 .31361 Mdot
.4128 .64694 Mdot
.37398 .58313 Mdot
.61798 .59013 Mdot
.37482 .28619 Mdot
.69146 .41198 Mdot
.35799 .63617 Mdot
.50131 .32923 Mdot
.39396 .32597 Mdot
.67442 .60438 Mdot
.6207 .76292 Mdot
.43849 .31631 Mdot
.46079 .62173 Mdot
.42732 .56923 Mdot
.38917 .64461 Mdot
.49084 .57724 Mdot
.66223 .43184 Mdot
.53454 .27181 Mdot
.45908 .62298 Mdot
.32403 .48609 Mdot
.24611 .49406 Mdot
.41878 .55277 Mdot
.64754 .58709 Mdot
.65672 .44186 Mdot
.52478 .54298 Mdot
.2315 .32988 Mdot
.43545 .58299 Mdot
.52905 .82322 Mdot
.3792 .37903 Mdot
.51994 .53086 Mdot
.65209 .65347 Mdot
.41113 .30988 Mdot
.39816 .6384 Mdot
.23868 .53513 Mdot
.3946 .61907 Mdot
.34371 .56091 Mdot
.53874 .28029 Mdot
.68906 .42794 Mdot
.33733 .68116 Mdot
.52863 .30978 Mdot
.63448 .60347 Mdot
.48659 .8097 Mdot
.65272 .64901 Mdot
.67267 .64907 Mdot
.68293 .67209 Mdot
.65133 .41426 Mdot
.88638 .43876 Mdot
.33679 .30927 Mdot
.39871 .55503 Mdot
.69816 .40739 Mdot
.64139 .62493 Mdot
.36349 .59352 Mdot
.66422 .62835 Mdot
.63543 .57924 Mdot
.4147 .61725 Mdot
.40729 .62226 Mdot
.23468 .53952 Mdot
.55892 .81194 Mdot
.4116 .29751 Mdot
.65211 .64239 Mdot
.56443 .79899 Mdot
.396 .59081 Mdot
.37229 .59289 Mdot
.5257 .46368 Mdot
.40806 .33373 Mdot
.37367 .75495 Mdot
.42108 .56871 Mdot
.28709 .39263 Mdot
.36623 .58155 Mdot
.59554 .60541 Mdot
.64638 .45967 Mdot
.3523 .52685 Mdot
.55589 .28256 Mdot
.65495 .64326 Mdot
.37879 .28169 Mdot
.64108 .65385 Mdot
.41778 .75736 Mdot
.65748 .43551 Mdot
.66159 .60813 Mdot
.53324 .2699 Mdot
.66437 .4103 Mdot
.6504 .41048 Mdot
.5155 .45785 Mdot
.51569 .27237 Mdot
.37342 .28734 Mdot
.68378 .41698 Mdot
.46991 .76885 Mdot
.66897 .41499 Mdot
.41079 .76317 Mdot
.4379 .57979 Mdot
.24169 .53469 Mdot
.40638 .65154 Mdot
.3179 .61249 Mdot
.67827 .40806 Mdot
.39083 .32594 Mdot
.35756 .58757 Mdot
.67423 .61353 Mdot
.42116 .31228 Mdot
.65606 .70096 Mdot
.52275 .26806 Mdot
.67103 .58481 Mdot
.64507 .39822 Mdot
.64298 .63754 Mdot
.25906 .43526 Mdot
.36729 .28771 Mdot
.53023 .44695 Mdot
.30329 .47877 Mdot
.47856 .59322 Mdot
.37231 .54559 Mdot
.35761 .58112 Mdot
.39755 .60871 Mdot
.54607 .32039 Mdot
.40314 .27641 Mdot
.65811 .58908 Mdot
.36107 .7041 Mdot
.65669 .41032 Mdot
.46071 .46865 Mdot
.48973 .57775 Mdot
.36366 .62372 Mdot
.64267 .62352 Mdot
.64694 .58022 Mdot
.55485 .66252 Mdot
.51171 .30006 Mdot
.32507 .57611 Mdot
.40964 .54623 Mdot
.32542 .67332 Mdot
.67596 .40633 Mdot
.77555 .53923 Mdot
.50956 .33029 Mdot
.79751 .7269 Mdot
.53035 .30922 Mdot
.4976 .4277 Mdot
.65936 .63321 Mdot
.39522 .31202 Mdot
.41876 .60456 Mdot
.58644 .63314 Mdot
.67927 .65052 Mdot
.52048 .2461 Mdot
.40543 .31227 Mdot
.75537 .40583 Mdot
.69684 .41828 Mdot
.35627 .63482 Mdot
.36586 .58187 Mdot
.37564 .62185 Mdot
.37591 .60819 Mdot
.68018 .44688 Mdot
.39531 .62478 Mdot
.6354 .41532 Mdot
.41261 .75389 Mdot
.24112 .42255 Mdot
.50748 .28399 Mdot
.5783 .23133 Mdot
.67599 .64582 Mdot
.41447 .78371 Mdot
.38877 .75272 Mdot
.25333 .53162 Mdot
.66497 .3745 Mdot
.33773 .59997 Mdot
.52675 .28677 Mdot
.72822 .46304 Mdot
.50507 .28604 Mdot
.41751 .83485 Mdot
.61254 .74378 Mdot
.74349 .38761 Mdot
.37773 .61948 Mdot
.53265 .2759 Mdot
.57443 .78044 Mdot
.43191 .64571 Mdot
.43811 .3219 Mdot
.43431 .76327 Mdot
.62755 .69341 Mdot
.40984 .29515 Mdot
.42673 .59694 Mdot
.69066 .63294 Mdot
.41529 .60766 Mdot
.42135 .60272 Mdot
.41202 .55703 Mdot
.66035 .45469 Mdot
.43703 .57342 Mdot
.3828 .60379 Mdot
.24749 .27979 Mdot
.45846 .28387 Mdot
.55593 .32164 Mdot
.51183 .62373 Mdot
.41823 .30678 Mdot
.61929 .63872 Mdot
.29504 .47767 Mdot
.66421 .4003 Mdot
.55191 .66204 Mdot
.40089 .63166 Mdot
.76449 .61322 Mdot
.64887 .40579 Mdot
.37786 .29936 Mdot
.51256 .53705 Mdot
.78009 .45539 Mdot
.56961 .31145 Mdot
.50825 .54476 Mdot
.52972 .32731 Mdot
.31405 .68669 Mdot
.66659 .62032 Mdot
.47838 .59334 Mdot
.68987 .41463 Mdot
.50257 .28525 Mdot
.24541 .54097 Mdot
.38085 .59592 Mdot
.52957 .28041 Mdot
.43418 .64123 Mdot
.26823 .48556 Mdot
.29138 .47143 Mdot
.51976 .27495 Mdot
.6771 .3889 Mdot
.67078 .40684 Mdot
.41942 .29931 Mdot
.67364 .6282 Mdot
.61674 .59699 Mdot
.67156 .41144 Mdot
.76454 .35973 Mdot
.40237 .58851 Mdot
.38575 .57964 Mdot
.33091 .4761 Mdot
.36392 .57256 Mdot
.36698 .32429 Mdot
.50457 .54768 Mdot
.62396 .58959 Mdot
.35775 .58379 Mdot
.35752 .59391 Mdot
.43245 .58056 Mdot
.22492 .49304 Mdot
.54076 .31998 Mdot
.4253 .61548 Mdot
.38352 .29628 Mdot
.6464 .70048 Mdot
.38988 .61029 Mdot
.45879 .62494 Mdot
.6628 .63309 Mdot
.59317 .40013 Mdot
.65605 .41564 Mdot
.49956 .30786 Mdot
.49701 .30246 Mdot
.25493 .3631 Mdot
.64429 .64506 Mdot
.5067 .54612 Mdot
.5981 .30731 Mdot
.52012 .54404 Mdot
.40356 .31445 Mdot
.48112 .47014 Mdot
.57665 .2889 Mdot
.55423 .32263 Mdot
.66351 .46457 Mdot
.37735 .54952 Mdot
.38453 .60768 Mdot
.80443 .56076 Mdot
.38903 .56704 Mdot
.40224 .29587 Mdot
.6905 .39451 Mdot
.66053 .60963 Mdot
.40146 .28818 Mdot
.68044 .39851 Mdot
.61888 .60094 Mdot
.44798 .57351 Mdot
.36454 .58838 Mdot
.63285 .60813 Mdot
.67687 .60954 Mdot
.41419 .58738 Mdot
.19906 .41773 Mdot
.63084 .58592 Mdot
.6328 .61343 Mdot
.64058 .69861 Mdot
.56772 .3131 Mdot
.33135 .65496 Mdot
.67372 .39547 Mdot
.38313 .60308 Mdot
.50912 .28522 Mdot
.40058 .32145 Mdot
.64931 .59186 Mdot
.36027 .6294 Mdot
.3955 .5846 Mdot
.41478 .31509 Mdot
.42802 .32086 Mdot
.41627 .32695 Mdot
.68998 .446 Mdot
.40531 .62641 Mdot
.6336 .62121 Mdot
.69266 .43663 Mdot
.40997 .28641 Mdot
.41034 .33532 Mdot
.19642 .50527 Mdot
.40796 .58988 Mdot
.4313 .30802 Mdot
.8706 .51195 Mdot
.22095 .54176 Mdot
.55056 .53759 Mdot
.48244 .2828 Mdot
.4306 .17468 Mdot
.34618 .28982 Mdot
.68614 .43375 Mdot
.45884 .46709 Mdot
.37819 .32227 Mdot
.36887 .64208 Mdot
.38021 .58722 Mdot
.48201 .57854 Mdot
.42045 .31522 Mdot
.23656 .46671 Mdot
.61098 .60318 Mdot
.45768 .70005 Mdot
.41804 .3063 Mdot
.50803 .27813 Mdot
.53422 .34195 Mdot
.52792 .30112 Mdot
.35188 .56055 Mdot
.30757 .68711 Mdot
.46296 .75257 Mdot
.36925 .74925 Mdot
.69701 .41148 Mdot
.64261 .57942 Mdot
.6766 .70257 Mdot
.63485 .60036 Mdot
.52235 .31822 Mdot
.38902 .32425 Mdot
.61953 .61925 Mdot
.64848 .41606 Mdot
.67347 .40728 Mdot
.56978 .29846 Mdot
.53952 .31373 Mdot
.53636 .2974 Mdot
.6657 .63904 Mdot
.66108 .63107 Mdot
.36503 .60977 Mdot
.66191 .59543 Mdot
.41904 .36417 Mdot
.45277 .37075 Mdot
.57011 .33037 Mdot
.66511 .42783 Mdot
.63164 .59412 Mdot
.37719 .57474 Mdot
.42007 .45752 Mdot
.58351 .33199 Mdot
.38797 .28115 Mdot
.73501 .68977 Mdot
.61205 .84241 Mdot
.3522 .58253 Mdot
.67105 .44691 Mdot
.50104 .55508 Mdot
.39923 .60694 Mdot
.54962 .2815 Mdot
.35623 .36608 Mdot
.53005 .52321 Mdot
.40478 .61577 Mdot
.44467 .56861 Mdot
.65399 .43493 Mdot
.29723 .48006 Mdot
.36154 .63803 Mdot
.49562 .44835 Mdot
.68807 .38907 Mdot
.52031 .33483 Mdot
.38198 .17246 Mdot
.57279 .59877 Mdot
.30463 .39484 Mdot
.54755 .52859 Mdot
.43578 .58026 Mdot
.54832 .30327 Mdot
.3893 .2868 Mdot
.54338 .30498 Mdot
.60683 .62707 Mdot
.56868 .30917 Mdot
.39122 .5638 Mdot
.6338 .62335 Mdot
.66506 .40474 Mdot
.37789 .45916 Mdot
.39369 .69423 Mdot
.48913 .30137 Mdot
.53615 .54703 Mdot
.40806 .62132 Mdot
.46603 .77274 Mdot
.31798 .61407 Mdot
.37024 .59326 Mdot
.67772 .4354 Mdot
.65286 .62731 Mdot
.65014 .43543 Mdot
.32729 .65106 Mdot
.62374 .55328 Mdot
.6539 .41919 Mdot
.38665 .51424 Mdot
.3803 .32095 Mdot
.233 .47743 Mdot
.41311 .57014 Mdot
.69082 .41716 Mdot
.42241 .61098 Mdot
.64516 .64176 Mdot
.23946 .51156 Mdot
.25375 .51106 Mdot
.67856 .42407 Mdot
.55934 .48437 Mdot
.27752 .47094 Mdot
.33261 .65563 Mdot
.69435 .4219 Mdot
.21436 .5807 Mdot
.51961 .5373 Mdot
.39381 .32456 Mdot
.42153 .32999 Mdot
.38645 .30996 Mdot
.383 .57944 Mdot
.58647 .79497 Mdot
.42342 .30307 Mdot
.70584 .40483 Mdot
.39425 .29244 Mdot
.40012 .39282 Mdot
.80673 .56866 Mdot
.38224 .32216 Mdot
.40596 .56737 Mdot
.31092 .56821 Mdot
.45184 .47059 Mdot
.49136 .28635 Mdot
.75853 .4672 Mdot
.25715 .26942 Mdot
.39801 .59303 Mdot
.71897 .69347 Mdot
.60213 .57408 Mdot
.49182 .42048 Mdot
.2535 .51971 Mdot
.38935 .48321 Mdot
.62861 .60254 Mdot
.30027 .47914 Mdot
.68465 .62029 Mdot
.47903 .59587 Mdot
.38987 .57561 Mdot
.65266 .64374 Mdot
.74434 .63605 Mdot
.19922 .57071 Mdot
.78358 .59692 Mdot
.62581 .59489 Mdot
.69438 .40804 Mdot
.67453 .44176 Mdot
.67969 .43253 Mdot
.55308 .31207 Mdot
.66426 .60906 Mdot
.43167 .60841 Mdot
.55726 .29242 Mdot
.42481 .58732 Mdot
.67639 .41779 Mdot
.25112 .52425 Mdot
.66284 .61263 Mdot
.41481 .57637 Mdot
.56853 .78983 Mdot
.52298 .32568 Mdot
.41692 .31387 Mdot
.73129 .69023 Mdot
.5116 .26583 Mdot
.6483 .40359 Mdot
.59964 .61776 Mdot
.46595 .28183 Mdot
.47721 .44667 Mdot
.41914 .55419 Mdot
.38513 .55833 Mdot
.45798 .46506 Mdot
.61906 .7482 Mdot
.35182 .62253 Mdot
.5579 .29793 Mdot
.56317 .32005 Mdot
.4269 .60334 Mdot
.66492 .60642 Mdot
.37476 .32075 Mdot
.43428 .30379 Mdot
.38061 .53608 Mdot
.29475 .46606 Mdot
.24252 .53592 Mdot
.36067 .59382 Mdot
.47073 .57738 Mdot
.53102 .26977 Mdot
.55228 .53685 Mdot
.30312 .46863 Mdot
.39086 .3058 Mdot
.42292 .56707 Mdot
.48489 .65636 Mdot
.6549 .59769 Mdot
.52615 .28199 Mdot
.66768 .45746 Mdot
.43897 .31858 Mdot
.56926 .32881 Mdot
.42702 .60308 Mdot
.35745 .59305 Mdot
.68832 .40896 Mdot
.59739 .60887 Mdot
.40829 .32726 Mdot
.55889 .29451 Mdot
.39376 .30926 Mdot
.66317 .62416 Mdot
.64618 .5897 Mdot
.40627 .54989 Mdot
.31719 .59503 Mdot
.49209 .3076 Mdot
.34076 .57138 Mdot
.54006 .28638 Mdot
.56897 .24161 Mdot
.65815 .44976 Mdot
.39108 .54749 Mdot
.62524 .63899 Mdot
.67555 .4145 Mdot
.40069 .59586 Mdot
.46584 .45971 Mdot
.3571 .60367 Mdot
.53056 .27494 Mdot
.34133 .34756 Mdot
.39065 .31854 Mdot
.43256 .62491 Mdot
.59309 .67232 Mdot
.3618 .57862 Mdot
.53089 .33336 Mdot
.45952 .76139 Mdot
.65479 .4259 Mdot
.65079 .63545 Mdot
.59448 .3341 Mdot
.66716 .41945 Mdot
.40871 .56402 Mdot
.40067 .29993 Mdot
.66843 .59445 Mdot
.54538 .53431 Mdot
.30393 .44181 Mdot
.32095 .63094 Mdot
.33259 .56428 Mdot
.35457 .62854 Mdot
.81829 .53432 Mdot
.53857 .29971 Mdot
.64071 .62332 Mdot
.67398 .44572 Mdot
.65528 .432 Mdot
.52651 .3245 Mdot
.62138 .68805 Mdot
.76477 .64162 Mdot
.87618 .48838 Mdot
.56602 .33555 Mdot
.38711 .3017 Mdot
.24062 .5125 Mdot
.52661 .3001 Mdot
.5415 .32589 Mdot
.5549 .27185 Mdot
.8066 .55393 Mdot
.6235 .60268 Mdot
.39457 .58515 Mdot
.71032 .69461 Mdot
.41022 .55746 Mdot
.30631 .40085 Mdot
.67563 .41851 Mdot
.65054 .63565 Mdot
.48481 .38384 Mdot
.3608 .55287 Mdot
.4103 .60448 Mdot
.51456 .37615 Mdot
.49639 .55646 Mdot
.2316 .3403 Mdot
.38409 .55423 Mdot
.5469 .3115 Mdot
.69803 .59769 Mdot
.46268 .61872 Mdot
.56941 .79051 Mdot
.67298 .40372 Mdot
.53412 .543 Mdot
.47143 .60805 Mdot
.47498 .56703 Mdot
.68501 .62402 Mdot
.61535 .61101 Mdot
.42401 .32505 Mdot
.7314 .65877 Mdot
.67202 .40271 Mdot
.78675 .52617 Mdot
.3691 .59218 Mdot
.64129 .37644 Mdot
.35992 .36085 Mdot
.40685 .59661 Mdot
.51214 .4569 Mdot
.55503 .66212 Mdot
.35554 .62049 Mdot
.37576 .74245 Mdot
.66976 .42448 Mdot
.25492 .41545 Mdot
.38847 .62155 Mdot
.52989 .28129 Mdot
.62582 .62114 Mdot
.67398 .58686 Mdot
.39387 .28488 Mdot
.39623 .35921 Mdot
.70242 .78803 Mdot
.64894 .63591 Mdot
.37956 .59625 Mdot
.65657 .42113 Mdot
.54276 .53877 Mdot
.4027 .65104 Mdot
.55684 .47876 Mdot
.65255 .59707 Mdot
.44334 .63734 Mdot
.76351 .61706 Mdot
.29851 .479 Mdot
.43459 .7961 Mdot
.68163 .42644 Mdot
.39276 .29729 Mdot
.38299 .53098 Mdot
.582 .26469 Mdot
.36437 .58513 Mdot
.30561 .39901 Mdot
.62703 .56633 Mdot
.39887 .29523 Mdot
.41036 .60795 Mdot
.3472 .61576 Mdot
.27359 .52688 Mdot
.38808 .33758 Mdot
.3574 .63169 Mdot
.35207 .57758 Mdot
.62232 .61933 Mdot
.50551 .548 Mdot
.65786 .60717 Mdot
.41713 .60449 Mdot
.3163 .31765 Mdot
.65139 .64114 Mdot
.74974 .46733 Mdot
.43494 .29955 Mdot
.66738 .39868 Mdot
.44756 .62705 Mdot
.42699 .56051 Mdot
.43411 .8028 Mdot
.53745 .54339 Mdot
.77294 .39314 Mdot
.52521 .27803 Mdot
.213 .34392 Mdot
.51913 .26297 Mdot
.71481 .37984 Mdot
.61007 .46802 Mdot
.46742 .60544 Mdot
.61388 .68395 Mdot
.35984 .74958 Mdot
.67572 .38403 Mdot
.39999 .78105 Mdot
.37501 .59945 Mdot
.42834 .57287 Mdot
.53786 .28429 Mdot
.66246 .37141 Mdot
.35097 .52728 Mdot
.30216 .46789 Mdot
.377 .30331 Mdot
.64323 .60887 Mdot
.37841 .58275 Mdot
.73996 .63774 Mdot
.49838 .28699 Mdot
.4531 .67726 Mdot
.41203 .573 Mdot
.49763 .55454 Mdot
.66843 .37278 Mdot
.66445 .40439 Mdot
.5247 .27267 Mdot
.5091 .27595 Mdot
.43163 .57099 Mdot
.67672 .45227 Mdot
.36882 .61888 Mdot
.27468 .47407 Mdot
.44539 .63247 Mdot
.40447 .31728 Mdot
.37145 .58098 Mdot
.55741 .60821 Mdot
.2197 .67853 Mdot
.36568 .55075 Mdot
.67097 .64849 Mdot
.53658 .29331 Mdot
.53432 .32189 Mdot
.61845 .59532 Mdot
.53302 .32217 Mdot
.4605 .6998 Mdot
.58532 .7981 Mdot
.4007 .31343 Mdot
.42858 .73707 Mdot
.38257 .31515 Mdot
.53198 .54363 Mdot
.41022 .58926 Mdot
.63648 .22983 Mdot
.56265 .33659 Mdot
.3814 .39181 Mdot
.67166 .4138 Mdot
.53144 .54598 Mdot
.40364 .62505 Mdot
.36503 .27928 Mdot
.52243 .30758 Mdot
.51101 .55287 Mdot
.41492 .55835 Mdot
.66186 .64058 Mdot
.36101 .62411 Mdot
.49923 .56013 Mdot
.50761 .54743 Mdot
.34328 .60285 Mdot
.68037 .39847 Mdot
.66814 .62569 Mdot
.75555 .3965 Mdot
.52596 .32868 Mdot
.40624 .61854 Mdot
.3828 .59919 Mdot
.6683 .59169 Mdot
.39643 .5562 Mdot
.68294 .44941 Mdot
.87223 .38244 Mdot
.40781 .33099 Mdot
.55282 .53469 Mdot
.72604 .50375 Mdot
.34237 .6028 Mdot
.35552 .57814 Mdot
.40826 .49419 Mdot
.46633 .67388 Mdot
.67164 .39812 Mdot
.32903 .58128 Mdot
.56148 .31758 Mdot
.40343 .32817 Mdot
.64658 .41925 Mdot
.39503 .62922 Mdot
.39874 .56383 Mdot
.39781 .29629 Mdot
.50554 .38151 Mdot
.40996 .33976 Mdot
.68561 .43881 Mdot
.56225 .51444 Mdot
.42252 .45644 Mdot
.40375 .58243 Mdot
.50201 .54981 Mdot
.65029 .62395 Mdot
.69262 .43191 Mdot
.54069 .67403 Mdot
.47994 .59465 Mdot
.64167 .40187 Mdot
.66687 .40383 Mdot
.41892 .55473 Mdot
.64733 .64512 Mdot
.58897 .59396 Mdot
.64651 .62386 Mdot
.24121 .40704 Mdot
.75786 .38477 Mdot
.53954 .29588 Mdot
.66494 .42569 Mdot
.50806 .28885 Mdot
.3822 .3253 Mdot
.25134 .48746 Mdot
.49541 .28667 Mdot
.61481 .62217 Mdot
.50308 .29091 Mdot
.3663 .61557 Mdot
.65914 .4006 Mdot
.49784 .31589 Mdot
.36734 .60043 Mdot
.42428 .53217 Mdot
.49251 .56669 Mdot
.37009 .29878 Mdot
.29555 .47228 Mdot
.41438 .56728 Mdot
.51305 .53783 Mdot
.41382 .58131 Mdot
.68028 .45103 Mdot
.37178 .44917 Mdot
.42662 .61026 Mdot
.56234 .33695 Mdot
.79961 .43246 Mdot
.55986 .32639 Mdot
.49257 .62226 Mdot
.42202 .58991 Mdot
.40482 .58543 Mdot
.4099 .62116 Mdot
.63521 .70062 Mdot
.64291 .40748 Mdot
.33141 .5811 Mdot
.55546 .28086 Mdot
.63508 .59706 Mdot
.63083 .63587 Mdot
.43478 .48892 Mdot
.50781 .54377 Mdot
.68332 .45102 Mdot
.40369 .5868 Mdot
.50466 .55228 Mdot
.32339 .46225 Mdot
.7751 .61712 Mdot
.48675 .27574 Mdot
.54112 .33131 Mdot
.67793 .62603 Mdot
.55621 .31537 Mdot
.3959 .62753 Mdot
.44849 .63269 Mdot
.75895 .40068 Mdot
.7034 .43505 Mdot
.4026 .32762 Mdot
.42404 .59174 Mdot
.21803 .50643 Mdot
.56226 .30248 Mdot
.523 .27111 Mdot
.3706 .6201 Mdot
.61749 .56448 Mdot
.1891 .6213 Mdot
.69841 .40706 Mdot
.48608 .78063 Mdot
.66179 .7402 Mdot
.28432 .64432 Mdot
.66026 .43349 Mdot
.50668 .45464 Mdot
.48704 .2909 Mdot
.30927 .28837 Mdot
.6321 .59963 Mdot
.40716 .32698 Mdot
.36718 .59672 Mdot
.61317 .61946 Mdot
.5718 .33213 Mdot
.65759 .58691 Mdot
.47331 .60089 Mdot
.65067 .40483 Mdot
.53205 .31613 Mdot
.68188 .45613 Mdot
.63737 .6489 Mdot
.38485 .31647 Mdot
.28743 .39654 Mdot
.4577 .76976 Mdot
.55912 .66257 Mdot
.42391 .61753 Mdot
.45191 .28459 Mdot
.42909 .61317 Mdot
.64814 .57158 Mdot
.41235 .56952 Mdot
.42915 .53875 Mdot
.49867 .27807 Mdot
.41821 .55248 Mdot
.37003 .5875 Mdot
.56651 .79344 Mdot
.40997 .59912 Mdot
.43024 .59177 Mdot
.41436 .54989 Mdot
.63304 .64014 Mdot
.40631 .55166 Mdot
.67252 .62629 Mdot
.77557 .59487 Mdot
.52504 .32791 Mdot
.38579 .32809 Mdot
.38437 .32557 Mdot
.31502 .3915 Mdot
.21999 .50232 Mdot
.69613 .69804 Mdot
.64608 .59911 Mdot
.67714 .40772 Mdot
.36699 .61451 Mdot
.1856 .5417 Mdot
.31403 .32758 Mdot
.48891 .31172 Mdot
.49324 .30169 Mdot
.38359 .61006 Mdot
.59228 .85107 Mdot
.37738 .55907 Mdot
.3351 .46914 Mdot
.38339 .57851 Mdot
.3859 .54917 Mdot
.54702 .27073 Mdot
.26052 .4343 Mdot
.42571 .61495 Mdot
.68523 .62781 Mdot
.4062 .32568 Mdot
.49877 .55552 Mdot
.31293 .34956 Mdot
.64284 .75858 Mdot
.56213 .58855 Mdot
.41861 .61806 Mdot
.55676 .28856 Mdot
.63423 .58748 Mdot
.32545 .47747 Mdot
.69187 .43742 Mdot
.29461 .44233 Mdot
.40369 .76128 Mdot
.6852 .38188 Mdot
.39665 .32667 Mdot
.57167 .33851 Mdot
.42821 .56458 Mdot
.55139 .30271 Mdot
.33382 .58353 Mdot
.32743 .45763 Mdot
.4012 .31608 Mdot
.69549 .61577 Mdot
.69359 .4056 Mdot
.61267 .61587 Mdot
.48649 .64933 Mdot
.31414 .32355 Mdot
.2155 .32625 Mdot
.5659 .32954 Mdot
.39574 .70895 Mdot
.64737 .63127 Mdot
.43526 .58049 Mdot
.87481 .48824 Mdot
.65459 .62114 Mdot
.65845 .64209 Mdot
.33613 .44528 Mdot
.24849 .43791 Mdot
.33719 .5788 Mdot
.63236 .58449 Mdot
.57145 .33818 Mdot
.4074 .30881 Mdot
.3711 .60601 Mdot
.47061 .60796 Mdot
.62174 .62262 Mdot
.52169 .3133 Mdot
.2739 .428 Mdot
.54358 .31329 Mdot
.62423 .60882 Mdot
.50479 .31447 Mdot
.74831 .43201 Mdot
.49383 .28914 Mdot
.38306 .56496 Mdot
.40342 .58586 Mdot
.58602 .60972 Mdot
.64624 .5897 Mdot
.35572 .57889 Mdot
.41189 .56027 Mdot
.63846 .62519 Mdot
.58833 .32487 Mdot
.50226 .64663 Mdot
.35546 .57196 Mdot
.39899 .58722 Mdot
.40639 .33286 Mdot
.2865 .49152 Mdot
.3551 .47119 Mdot
.36368 .59607 Mdot
.38508 .30722 Mdot
.66775 .63706 Mdot
.41497 .58453 Mdot
.26181 .43157 Mdot
.51323 .33437 Mdot
.38249 .62885 Mdot
.54289 .53507 Mdot
.43033 .6136 Mdot
.24506 .66915 Mdot
.40505 .62197 Mdot
.62864 .61082 Mdot
.63134 .62541 Mdot
.59254 .32599 Mdot
.63515 .60726 Mdot
.55045 .53667 Mdot
.67039 .40788 Mdot
.46027 .78703 Mdot
.54679 .54059 Mdot
.34836 .60993 Mdot
.33736 .30783 Mdot
.46727 .61421 Mdot
.4196 .65243 Mdot
.43096 .34225 Mdot
.54575 .52807 Mdot
.65607 .62933 Mdot
.72919 .60725 Mdot
.3298 .62195 Mdot
.6869 .44735 Mdot
.46439 .61692 Mdot
.3828 .62981 Mdot
.42703 .53948 Mdot
.60255 .55816 Mdot
.6965 .42848 Mdot
.32126 .65042 Mdot
.37087 .60601 Mdot
.47155 .66897 Mdot
.37654 .58571 Mdot
.37833 .28882 Mdot
.66052 .6132 Mdot
.55674 .31012 Mdot
.40752 .31495 Mdot
.35609 .6316 Mdot
.4195 .30833 Mdot
.54737 .2988 Mdot
.68684 .41659 Mdot
.38704 .56313 Mdot
.38695 .33558 Mdot
.38023 .31725 Mdot
.3837 .63993 Mdot
.63437 .62981 Mdot
.3195 .61759 Mdot
.41483 .58856 Mdot
.41188 .62093 Mdot
.61583 .59836 Mdot
.71338 .25662 Mdot
.43124 .57906 Mdot
.50859 .45381 Mdot
.66103 .57651 Mdot
.51011 .54849 Mdot
.55901 .30374 Mdot
.3508 .59828 Mdot
.65046 .42287 Mdot
.66944 .40976 Mdot
.55203 .33802 Mdot
.61653 .61239 Mdot
.53075 .31934 Mdot
.37255 .54584 Mdot
.45843 .62352 Mdot
.37196 .60199 Mdot
.5789 .36798 Mdot
.76959 .43694 Mdot
.67212 .59993 Mdot
.53878 .33368 Mdot
.29315 .45471 Mdot
.66444 .39799 Mdot
.55855 .27672 Mdot
.68684 .61996 Mdot
.61571 .58989 Mdot
.62207 .59424 Mdot
.38071 .30281 Mdot
.53397 .31184 Mdot
.63007 .64777 Mdot
.64552 .65529 Mdot
.3761 .6316 Mdot
.37086 .60825 Mdot
.67231 .63313 Mdot
.58786 .29048 Mdot
.39342 .32223 Mdot
.56358 .29662 Mdot
.19453 .63705 Mdot
.69804 .41508 Mdot
.56906 .79207 Mdot
.36275 .59233 Mdot
.81674 .71076 Mdot
.37884 .55794 Mdot
.37682 .59224 Mdot
.62026 .6393 Mdot
.41882 .33295 Mdot
.40674 .30592 Mdot
.64552 .63126 Mdot
.63076 .5793 Mdot
.38694 .28374 Mdot
.37972 .47136 Mdot
.22553 .64717 Mdot
.32018 .46976 Mdot
.66338 .5924 Mdot
.43898 .77502 Mdot
.67385 .43383 Mdot
.64143 .56786 Mdot
.70588 .46993 Mdot
.50833 .32143 Mdot
.49071 .29683 Mdot
.68462 .4077 Mdot
.43151 .58371 Mdot
.56394 .29088 Mdot
.44891 .5647 Mdot
.73846 .38717 Mdot
.54407 .48434 Mdot
.17716 .45546 Mdot
.39433 .55855 Mdot
.5426 .57514 Mdot
.81605 .54802 Mdot
.35683 .61068 Mdot
.58283 .75812 Mdot
.41445 .32407 Mdot
.63841 .56967 Mdot
.69814 .39975 Mdot
.72115 .69187 Mdot
.40405 .58379 Mdot
.64944 .58742 Mdot
.69279 .39717 Mdot
.76969 .42559 Mdot
.49586 .44879 Mdot
.3678 .62768 Mdot
.8806 .46249 Mdot
.68212 .6455 Mdot
.55677 .30874 Mdot
.5002 .76307 Mdot
.6089 .58666 Mdot
.4831 .4462 Mdot
.57089 .33638 Mdot
.30662 .5011 Mdot
.64528 .58346 Mdot
.41534 .33734 Mdot
.64757 .60801 Mdot
.41055 .29081 Mdot
.61958 .64072 Mdot
.51461 .32012 Mdot
.41697 .59886 Mdot
.52017 .32434 Mdot
.3923 .28074 Mdot
.56525 .33162 Mdot
.6978 .39919 Mdot
.5391 .52529 Mdot
.67698 .41752 Mdot
.24328 .50197 Mdot
.54724 .68854 Mdot
.68879 .42726 Mdot
.43618 .5058 Mdot
.39229 .56404 Mdot
.59511 .60429 Mdot
.55461 .31355 Mdot
.50283 .27273 Mdot
.29535 .4703 Mdot
.62121 .60644 Mdot
.51833 .3143 Mdot
.44759 .77096 Mdot
.76681 .36632 Mdot
.43217 .53821 Mdot
.60817 .29319 Mdot
.63326 .61959 Mdot
.51825 .2672 Mdot
.33292 .47328 Mdot
.61104 .59088 Mdot
.49372 .31018 Mdot
.6941 .41887 Mdot
.65088 .42136 Mdot
.38674 .55991 Mdot
.70324 .41641 Mdot
.48799 .29198 Mdot
.43763 .69234 Mdot
.65549 .6372 Mdot
.76776 .44484 Mdot
.39452 .32848 Mdot
.5497 .31866 Mdot
.3856 .64767 Mdot
.62365 .63745 Mdot
.5049 .29129 Mdot
.68073 .80006 Mdot
.20848 .69231 Mdot
.51882 .3128 Mdot
.65928 .6119 Mdot
.64659 .59238 Mdot
.34755 .57894 Mdot
.29822 .46736 Mdot
.52103 .30615 Mdot
.63247 .22807 Mdot
.23744 .53771 Mdot
.53681 .52866 Mdot
.25141 .27546 Mdot
.42793 .61176 Mdot
.41404 .62231 Mdot
.68532 .44137 Mdot
.40732 .60444 Mdot
.63745 .58008 Mdot
.37878 .55761 Mdot
.64999 .43782 Mdot
.54454 .33795 Mdot
.40901 .58514 Mdot
.40229 .32872 Mdot
.65954 .44384 Mdot
.65944 .44651 Mdot
.50228 .30977 Mdot
.61658 .61009 Mdot
.75667 .67706 Mdot
.54195 .31447 Mdot
.40494 .627 Mdot
.51877 .53355 Mdot
.41629 .55137 Mdot
.64034 .6696 Mdot
.65836 .5766 Mdot
.55702 .31375 Mdot
.50817 .53259 Mdot
.66123 .42321 Mdot
.48815 .28772 Mdot
.43513 .60525 Mdot
.50296 .32296 Mdot
.5233 .44309 Mdot
.46749 .17689 Mdot
.67405 .65657 Mdot
.50963 .43213 Mdot
.61217 .5922 Mdot
.5428 .53004 Mdot
.24787 .37228 Mdot
.39342 .32386 Mdot
.5648 .31652 Mdot
.75031 .46442 Mdot
.52968 .32957 Mdot
.40647 .5988 Mdot
.40047 .56247 Mdot
.54075 .28453 Mdot
.38404 .31289 Mdot
.41362 .39801 Mdot
.41126 .34164 Mdot
.662 .60688 Mdot
.41842 .482 Mdot
.17151 .60805 Mdot
.4825 .31 Mdot
.67932 .40452 Mdot
.57212 .6099 Mdot
.34915 .61395 Mdot
.69947 .4092 Mdot
.66452 .44958 Mdot
.41076 .28766 Mdot
.54083 .32691 Mdot
.69302 .61603 Mdot
.6508 .40709 Mdot
.60522 .5918 Mdot
.27276 .42422 Mdot
.484 .58863 Mdot
.32011 .66519 Mdot
.34791 .61882 Mdot
.29687 .47662 Mdot
.64845 .40738 Mdot
.39837 .56839 Mdot
.36153 .54205 Mdot
.6958 .41413 Mdot
.41495 .29006 Mdot
.54933 .49576 Mdot
.51636 .31277 Mdot
.86276 .54391 Mdot
.37968 .56817 Mdot
.41747 .59203 Mdot
.69716 .40999 Mdot
.60604 .76089 Mdot
.68306 .62866 Mdot
.62601 .62532 Mdot
.53788 .29948 Mdot
.34546 .4504 Mdot
.40772 .55349 Mdot
.38747 .56446 Mdot
.53494 .27928 Mdot
.51362 .54026 Mdot
.22485 .31153 Mdot
.39546 .58314 Mdot
.66838 .42894 Mdot
.52283 .46258 Mdot
.67679 .38933 Mdot
.41455 .542 Mdot
.39962 .59804 Mdot
.40681 .63651 Mdot
.43738 .60313 Mdot
.67863 .4219 Mdot
.35124 .62285 Mdot
.33535 .60602 Mdot
.65421 .62668 Mdot
.42821 .60543 Mdot
.23782 .53907 Mdot
.39853 .58165 Mdot
.4109 .32708 Mdot
.35757 .46842 Mdot
.40889 .619 Mdot
.42629 .60793 Mdot
.23656 .53556 Mdot
.40354 .60977 Mdot
.69518 .39909 Mdot
.64155 .59168 Mdot
.65969 .4231 Mdot
.68024 .4018 Mdot
.50147 .29537 Mdot
.42508 .30042 Mdot
.34572 .56545 Mdot
.385 .28919 Mdot
.35286 .56297 Mdot
.32347 .64897 Mdot
.26853 .48417 Mdot
.33373 .46924 Mdot
.37443 .31596 Mdot
.38558 .5666 Mdot
.54385 .29981 Mdot
.55325 .32108 Mdot
.46046 .46596 Mdot
.45948 .61614 Mdot
.69895 .39572 Mdot
.69105 .4178 Mdot
.4547 .37114 Mdot
.45216 .17088 Mdot
.37521 .30666 Mdot
.42445 .40091 Mdot
.44791 .57732 Mdot
.42764 .58144 Mdot
.41811 .64758 Mdot
.51585 .28383 Mdot
.54563 .52681 Mdot
.57316 .31016 Mdot
.66541 .37354 Mdot
.66077 .44053 Mdot
.38916 .56076 Mdot
.55645 .86119 Mdot
.66923 .61907 Mdot
.64444 .59111 Mdot
.64874 .43608 Mdot
.5603 .3254 Mdot
.43936 .6382 Mdot
.84695 .59169 Mdot
.66996 .58506 Mdot
.3935 .3349 Mdot
.40789 .61225 Mdot
.51223 .3234 Mdot
.66675 .62768 Mdot
.38525 .33369 Mdot
.43904 .58379 Mdot
.5738 .33393 Mdot
.39919 .57162 Mdot
.43208 .72644 Mdot
.65693 .63227 Mdot
.26982 .49769 Mdot
.64307 .64822 Mdot
.67713 .42328 Mdot
.66669 .4008 Mdot
.40038 .5963 Mdot
.85594 .57623 Mdot
.69086 .58914 Mdot
.64236 .43965 Mdot
.42278 .32706 Mdot
.53417 .52389 Mdot
.42383 .30254 Mdot
.53824 .28621 Mdot
.39649 .32628 Mdot
.50365 .29291 Mdot
.59724 .31417 Mdot
.68789 .63666 Mdot
.39863 .29626 Mdot
.57906 .73559 Mdot
.44441 .63607 Mdot
.43099 .29923 Mdot
.38701 .61499 Mdot
.3536 .56652 Mdot
.51688 .29974 Mdot
.37987 .29587 Mdot
.36153 .63077 Mdot
.71781 .50429 Mdot
.67363 .39905 Mdot
.6965 .39513 Mdot
.46609 .6114 Mdot
.52231 .26894 Mdot
.68608 .6385 Mdot
.28073 .45733 Mdot
.69754 .62278 Mdot
.38403 .56658 Mdot
.35316 .55897 Mdot
.65669 .65456 Mdot
.67567 .64588 Mdot
.39565 .59603 Mdot
.51041 .81099 Mdot
.3759 .64488 Mdot
.65135 .41794 Mdot
.66377 .60857 Mdot
.65107 .59188 Mdot
.48947 .29074 Mdot
.62563 .62698 Mdot
.3275 .5702 Mdot
.68027 .37797 Mdot
.33255 .61288 Mdot
.66452 .42239 Mdot
.48487 .26317 Mdot
.51152 .30112 Mdot
.75281 .4562 Mdot
.63057 .63121 Mdot
.35745 .58303 Mdot
.64057 .63996 Mdot
.41919 .32492 Mdot
.6586 .59175 Mdot
.59164 .58386 Mdot
.36804 .5922 Mdot
.35865 .6334 Mdot
.52041 .54216 Mdot
.29928 .47245 Mdot
.66105 .62308 Mdot
.37362 .54646 Mdot
.37407 .55734 Mdot
.40914 .55888 Mdot
.27855 .46918 Mdot
.63362 .64004 Mdot
.6396 .75997 Mdot
.70524 .64683 Mdot
.66041 .63125 Mdot
.24638 .71865 Mdot
.52626 .54398 Mdot
.50953 .53561 Mdot
.71013 .41169 Mdot
.39576 .58581 Mdot
.52846 .32213 Mdot
.40176 .63052 Mdot
.40464 .64928 Mdot
.41013 .61684 Mdot
.41063 .2958 Mdot
.42423 .5564 Mdot
.5289 .53378 Mdot
.5452 .31648 Mdot
.3573 .60718 Mdot
.40518 .58954 Mdot
.50968 .54402 Mdot
.65089 .64394 Mdot
.61223 .59703 Mdot
.69793 .63448 Mdot
.40218 .28468 Mdot
.67567 .43883 Mdot
.40065 .62971 Mdot
.54038 .2997 Mdot
.5304 .32475 Mdot
.62275 .63225 Mdot
.54241 .27947 Mdot
.6655 .44486 Mdot
.37919 .59299 Mdot
.67775 .42185 Mdot
.41243 .29636 Mdot
.66129 .61409 Mdot
.39564 .62585 Mdot
.37903 .63623 Mdot
.63158 .62565 Mdot
.36716 .64176 Mdot
.4233 .32304 Mdot
.52204 .27547 Mdot
.67689 .60769 Mdot
.66906 .40819 Mdot
.49156 .28943 Mdot
.35672 .59653 Mdot
.33516 .79438 Mdot
.40598 .6042 Mdot
.40827 .55579 Mdot
.70196 .60116 Mdot
.42758 .54884 Mdot
.52638 .32902 Mdot
.63135 .6356 Mdot
.3544 .56785 Mdot
.2284 .52914 Mdot
.458 .30713 Mdot
.48014 .312 Mdot
.38665 .60469 Mdot
.42648 .79825 Mdot
.36208 .5743 Mdot
.75076 .46942 Mdot
.26872 .48457 Mdot
.66875 .47574 Mdot
.32138 .66567 Mdot
.64382 .44109 Mdot
.51521 .53713 Mdot
.50265 .30136 Mdot
.55051 .78153 Mdot
.39408 .59889 Mdot
.54685 .66279 Mdot
.3936 .62775 Mdot
.65827 .4329 Mdot
.59503 .7492 Mdot
.55446 .28571 Mdot
.22334 .33602 Mdot
.43497 .59156 Mdot
.68494 .62075 Mdot
.57581 .29275 Mdot
.51533 .53103 Mdot
.35949 .63317 Mdot
.37677 .29391 Mdot
.46295 .36678 Mdot
.32125 .59312 Mdot
.66222 .42109 Mdot
.4251 .5694 Mdot
.41109 .64143 Mdot
.75934 .32793 Mdot
.64425 .62412 Mdot
.6906 .40564 Mdot
.44438 .17596 Mdot
.39253 .56673 Mdot
.6149 .59112 Mdot
.63271 .5995 Mdot
.39227 .28712 Mdot
.63189 .41705 Mdot
.48223 .3687 Mdot
.53443 .84842 Mdot
.36356 .69988 Mdot
.51631 .28212 Mdot
.56338 .52477 Mdot
.40328 .63131 Mdot
.31496 .32266 Mdot
.67657 .40336 Mdot
.41827 .59381 Mdot
.56826 .66541 Mdot
.6336 .61466 Mdot
.39454 .57563 Mdot
.39653 .32295 Mdot
.78123 .66316 Mdot
.42569 .76129 Mdot
.44852 .8026 Mdot
.57125 .33818 Mdot
.33957 .57296 Mdot
.32973 .56746 Mdot
.50889 .54854 Mdot
.40928 .53995 Mdot
.55469 .31156 Mdot
.53867 .45365 Mdot
.39257 .31461 Mdot
.66909 .62562 Mdot
.51074 .53936 Mdot
.39295 .62754 Mdot
.33345 .58823 Mdot
.41806 .32977 Mdot
.40089 .63832 Mdot
.5062 .7719 Mdot
.55905 .53169 Mdot
.49612 .28756 Mdot
.66833 .59376 Mdot
.3485 .56337 Mdot
.52625 .52548 Mdot
.3712 .59727 Mdot
.55291 .60802 Mdot
.42316 .59009 Mdot
.69421 .49362 Mdot
.62499 .62012 Mdot
.6612 .41226 Mdot
.43986 .5987 Mdot
.40293 .5752 Mdot
.49873 .42488 Mdot
.43315 .64287 Mdot
.42047 .60958 Mdot
.60906 .6054 Mdot
.66987 .62283 Mdot
.68413 .62277 Mdot
.48776 .30623 Mdot
.31521 .46804 Mdot
.6737 .42028 Mdot
.42037 .64694 Mdot
.65033 .40749 Mdot
.2962 .65109 Mdot
.41673 .29654 Mdot
.75694 .44591 Mdot
.38204 .59276 Mdot
.62121 .59937 Mdot
.21602 .63274 Mdot
.62795 .63745 Mdot
.71185 .39049 Mdot
.67307 .40296 Mdot
.65486 .61877 Mdot
.39375 .6064 Mdot
.30619 .47994 Mdot
.45649 .81248 Mdot
.66244 .39881 Mdot
.46961 .60461 Mdot
.4677 .26551 Mdot
.52688 .33725 Mdot
.23342 .70279 Mdot
.65006 .41095 Mdot
.81665 .54818 Mdot
.35524 .57172 Mdot
.64391 .63962 Mdot
.68274 .42765 Mdot
.67144 .45259 Mdot
.55147 .2818 Mdot
.37102 .62911 Mdot
.4006 .57513 Mdot
.54197 .53574 Mdot
.68222 .41528 Mdot
.49295 .55628 Mdot
.36526 .62684 Mdot
.71216 .37211 Mdot
.68108 .59936 Mdot
.70784 .25019 Mdot
.44376 .52145 Mdot
.56724 .66549 Mdot
.68322 .25417 Mdot
.67939 .61444 Mdot
.43189 .58628 Mdot
.44124 .6362 Mdot
.52785 .27459 Mdot
.38725 .60035 Mdot
.5414 .33399 Mdot
.66491 .4381 Mdot
.69916 .50141 Mdot
.42917 .50607 Mdot
.72874 .39289 Mdot
.41041 .60181 Mdot
.43515 .76403 Mdot
.39576 .30367 Mdot
.69284 .38763 Mdot
.68053 .63779 Mdot
.40005 .54376 Mdot
.5414 .27548 Mdot
.51199 .32913 Mdot
.63675 .61478 Mdot
.80292 .55206 Mdot
.75402 .45797 Mdot
.37915 .64694 Mdot
.55281 .29201 Mdot
.49823 .55168 Mdot
.41328 .78306 Mdot
.64206 .42232 Mdot
.39303 .31322 Mdot
.49865 .30725 Mdot
.6898 .44645 Mdot
.35243 .56792 Mdot
.64376 .61499 Mdot
.67876 .65082 Mdot
.46711 .45746 Mdot
.51969 .31606 Mdot
.41418 .31211 Mdot
.47631 .45437 Mdot
.43359 .47869 Mdot
.40266 .31835 Mdot
.48717 .30904 Mdot
.66486 .60215 Mdot
.62559 .60768 Mdot
.63935 .59254 Mdot
.56974 .79032 Mdot
.65865 .577 Mdot
.30286 .37106 Mdot
.41153 .54057 Mdot
.44777 .7774 Mdot
.37685 .55086 Mdot
.69857 .40156 Mdot
.65401 .63415 Mdot
.2677 .48743 Mdot
.44699 .58424 Mdot
.46301 .81462 Mdot
.41764 .57053 Mdot
.51691 .4587 Mdot
.39682 .58674 Mdot
.45092 .73399 Mdot
.63163 .57001 Mdot
.43748 .58312 Mdot
.67334 .3797 Mdot
.42093 .31366 Mdot
.60191 .62196 Mdot
.42625 .5988 Mdot
.76044 .60992 Mdot
.38695 .61552 Mdot
.69793 .49899 Mdot
.47719 .44831 Mdot
.36545 .33928 Mdot
.41 .55046 Mdot
.5679 .29157 Mdot
.37852 .51828 Mdot
.43711 .77787 Mdot
.66031 .40009 Mdot
.44146 .76796 Mdot
.56801 .30372 Mdot
.59748 .75055 Mdot
.39154 .65003 Mdot
.38988 .31495 Mdot
.56419 .49289 Mdot
.65385 .41213 Mdot
.38652 .5946 Mdot
.43389 .58382 Mdot
.53961 .48298 Mdot
.4006 .77442 Mdot
.49952 .55693 Mdot
.37605 .32194 Mdot
.41424 .76423 Mdot
.41938 .60918 Mdot
.47687 .30845 Mdot
.6133 .60744 Mdot
.59291 .74043 Mdot
.61274 .74961 Mdot
.35868 .61732 Mdot
.6519 .62024 Mdot
.61661 .61234 Mdot
.18303 .58089 Mdot
.38992 .3026 Mdot
.42303 .58644 Mdot
.51049 .43113 Mdot
.39958 .62918 Mdot
.66585 .43404 Mdot
.4453 .56565 Mdot
.51217 .30323 Mdot
.33436 .47529 Mdot
.48973 .31043 Mdot
.4077 .55833 Mdot
.64856 .60704 Mdot
.67899 .39548 Mdot
.59988 .30757 Mdot
.6325 .4155 Mdot
.30172 .37191 Mdot
.44921 .3651 Mdot
.37558 .30935 Mdot
.41861 .2955 Mdot
.69382 .38923 Mdot
.38029 .59981 Mdot
.28744 .46466 Mdot
.45312 .55498 Mdot
.39065 .5842 Mdot
.42208 .5991 Mdot
.70507 .44375 Mdot
.67064 .40372 Mdot
.50863 .31841 Mdot
.39401 .59587 Mdot
.38279 .54289 Mdot
.65174 .61192 Mdot
.3771 .31201 Mdot
.50236 .28682 Mdot
.38297 .283 Mdot
.54651 .30888 Mdot
.24589 .67062 Mdot
.47625 .60143 Mdot
.41895 .30522 Mdot
.64439 .41996 Mdot
.62811 .59235 Mdot
.5328 .54447 Mdot
.53264 .2881 Mdot
.54677 .28218 Mdot
.34394 .57539 Mdot
.66482 .62796 Mdot
.6277 .62747 Mdot
.38566 .28338 Mdot
.69051 .42077 Mdot
.43187 .53418 Mdot
.34695 .61363 Mdot
.58792 .25251 Mdot
.53043 .27219 Mdot
.4252 .76855 Mdot
.71013 .63408 Mdot
.37296 .58881 Mdot
.61449 .59334 Mdot
.41042 .58093 Mdot
.57924 .60899 Mdot
.67877 .64748 Mdot
.43322 .55106 Mdot
.45715 .60685 Mdot
.51273 .28568 Mdot
.16927 .53614 Mdot
.41992 .5313 Mdot
.73222 .44655 Mdot
.403 .63332 Mdot
.21248 .32767 Mdot
.20925 .62211 Mdot
.38126 .60716 Mdot
.42543 .55871 Mdot
.49539 .85536 Mdot
.36355 .57416 Mdot
.53766 .53271 Mdot
.40027 .65121 Mdot
.61794 .58963 Mdot
.51423 .43502 Mdot
.2961 .47375 Mdot
.38978 .29711 Mdot
.53819 .29856 Mdot
.25322 .43642 Mdot
.41057 .29024 Mdot
.63009 .61417 Mdot
.42986 .53215 Mdot
.70587 .61391 Mdot
.52 .26332 Mdot
.49598 .55861 Mdot
.66131 .43483 Mdot
.29114 .46732 Mdot
.54645 .27843 Mdot
.67048 .40731 Mdot
.36565 .56596 Mdot
.5881 .30351 Mdot
.67602 .3838 Mdot
.16621 .55174 Mdot
.68575 .44308 Mdot
.66252 .40626 Mdot
.30507 .4671 Mdot
.38963 .29705 Mdot
.54551 .4613 Mdot
.33034 .65394 Mdot
.68491 .39462 Mdot
.22917 .34881 Mdot
.53868 .27195 Mdot
.32116 .45572 Mdot
.62917 .56912 Mdot
.47089 .60862 Mdot
.41921 .59928 Mdot
.69083 .43521 Mdot
.52451 .51776 Mdot
.49543 .42266 Mdot
.65365 .43352 Mdot
.44297 .59819 Mdot
.34979 .45392 Mdot
.52759 .52599 Mdot
.52939 .54352 Mdot
.38927 .33587 Mdot
.47763 .1968 Mdot
.61818 .60719 Mdot
.3944 .33449 Mdot
.25238 .50662 Mdot
.41788 .56733 Mdot
.67918 .42377 Mdot
.50855 .54134 Mdot
.66802 .41098 Mdot
.40163 .30634 Mdot
.42493 .32299 Mdot
.65274 .62657 Mdot
.68214 .62807 Mdot
.56387 .50556 Mdot
.23149 .544 Mdot
.3807 .62718 Mdot
.53834 .67561 Mdot
.67509 .64714 Mdot
.5835 .77484 Mdot
.38418 .29848 Mdot
.37766 .30543 Mdot
.36101 .73362 Mdot
.36531 .61046 Mdot
.52181 .46154 Mdot
.41081 .61848 Mdot
.25594 .32846 Mdot
.39334 .62581 Mdot
.53799 .27926 Mdot
.43165 .60609 Mdot
.74568 .64916 Mdot
.35279 .58537 Mdot
.41688 .60824 Mdot
.52933 .30481 Mdot
.34401 .56985 Mdot
.51482 .30149 Mdot
.43034 .58295 Mdot
.47369 .34266 Mdot
.54002 .29998 Mdot
.44542 .29612 Mdot
.49092 .46558 Mdot
.53259 .53809 Mdot
.40163 .29109 Mdot
.37398 .3035 Mdot
.27772 .42448 Mdot
.66957 .61056 Mdot
.62409 .69797 Mdot
.40775 .61166 Mdot
.53087 .26985 Mdot
.66956 .44148 Mdot
.35756 .61773 Mdot
.39174 .55387 Mdot
.42072 .53177 Mdot
.65468 .6241 Mdot
.49373 .28282 Mdot
.40596 .29938 Mdot
.54328 .32921 Mdot
.47269 .33677 Mdot
.5114 .29602 Mdot
.47096 .57556 Mdot
.35142 .56757 Mdot
.3318 .56465 Mdot
.56956 .70836 Mdot
.33746 .32165 Mdot
.64042 .61522 Mdot
.51961 .53415 Mdot
.42127 .29995 Mdot
.37738 .45959 Mdot
.61673 .59847 Mdot
.5378 .2809 Mdot
.39954 .57136 Mdot
.48259 .59177 Mdot
.32963 .65286 Mdot
.60186 .59282 Mdot
.42369 .29058 Mdot
.53199 .29393 Mdot
.53466 .52749 Mdot
.32011 .46751 Mdot
.66307 .74106 Mdot
.24678 .4935 Mdot
.40657 .57733 Mdot
.38834 .28344 Mdot
.66684 .62738 Mdot
.53475 .46993 Mdot
.6938 .42548 Mdot
.29798 .46879 Mdot
.4102 .60318 Mdot
.65136 .35965 Mdot
.64684 .60601 Mdot
.38555 .31759 Mdot
.69062 .43618 Mdot
.38753 .3069 Mdot
.53493 .5221 Mdot
.70953 .64307 Mdot
.36144 .63501 Mdot
.40644 .62172 Mdot
.66879 .43964 Mdot
.61964 .61223 Mdot
.47792 .34905 Mdot
.55344 .47786 Mdot
.54113 .2855 Mdot
.37282 .46543 Mdot
.66866 .62462 Mdot
.62438 .3601 Mdot
.54391 .33004 Mdot
.70528 .40703 Mdot
.30138 .48923 Mdot
.66509 .44627 Mdot
.42147 .60414 Mdot
.64798 .59735 Mdot
.66061 .39913 Mdot
.57126 .24366 Mdot
.52397 .82256 Mdot
.56138 .48973 Mdot
.39442 .56315 Mdot
.76047 .46713 Mdot
.80036 .5786 Mdot
.58728 .59888 Mdot
.64715 .41759 Mdot
.40955 .5945 Mdot
.3776 .64683 Mdot
.43499 .59376 Mdot
.68472 .39878 Mdot
.60381 .41004 Mdot
.56384 .30535 Mdot
.39657 .56869 Mdot
.40176 .32976 Mdot
.50984 .30688 Mdot
.54546 .34101 Mdot
.49793 .30794 Mdot
.67906 .63812 Mdot
.48692 .58192 Mdot
.40433 .65167 Mdot
.19863 .5845 Mdot
.66064 .40997 Mdot
.53239 .53789 Mdot
.4298 .5646 Mdot
.30108 .37677 Mdot
.6258 .5972 Mdot
.52667 .29423 Mdot
.41806 .59102 Mdot
.46969 .45355 Mdot
.50286 .55066 Mdot
.53679 .31272 Mdot
.67902 .6442 Mdot
.65384 .55392 Mdot
.3849 .59832 Mdot
.39769 .63515 Mdot
.63213 .62259 Mdot
.80481 .5954 Mdot
.32611 .46581 Mdot
.40903 .58229 Mdot
.66527 .40819 Mdot
.83327 .46636 Mdot
.36556 .5637 Mdot
.68617 .58974 Mdot
.54889 .52848 Mdot
.71347 .64582 Mdot
.49198 .78129 Mdot
.44762 .62622 Mdot
.61195 .52482 Mdot
.38676 .39511 Mdot
.59817 .55282 Mdot
.27627 .32185 Mdot
.57715 .47985 Mdot
.16923 .58578 Mdot
.68064 .37636 Mdot
.43535 .73405 Mdot
.6677 .80463 Mdot
.81192 .54368 Mdot
.51672 .42121 Mdot
.61783 .46444 Mdot
.52999 .25676 Mdot
.23194 .3007 Mdot
.57291 .30353 Mdot
.28543 .31132 Mdot
.39981 .62208 Mdot
.79811 .59908 Mdot
.43879 .74147 Mdot
.39749 .35852 Mdot
.75126 .43093 Mdot
.47547 .4512 Mdot
.39778 .81251 Mdot
.73894 .39332 Mdot
.29381 .73689 Mdot
.58718 .67544 Mdot
.5167 .19491 Mdot
.38885 .47432 Mdot
.26107 .42114 Mdot
.45476 .76205 Mdot
.69365 .5615 Mdot
.62917 .38054 Mdot
.47049 .6778 Mdot
.69645 .25865 Mdot
.55007 .29505 Mdot
.61421 .58497 Mdot
.61326 .47334 Mdot
.34203 .7724 Mdot
.73025 .4187 Mdot
.61038 .52545 Mdot
.55713 .48506 Mdot
.4465 .73361 Mdot
.26596 .4971 Mdot
.44305 .71768 Mdot
.47443 .37281 Mdot
.23613 .2993 Mdot
.67375 .56798 Mdot
.55468 .22652 Mdot
.36437 .44359 Mdot
.46064 .3903 Mdot
.47872 .74612 Mdot
.37559 .27877 Mdot
.44821 .29623 Mdot
.68042 .64408 Mdot
.37221 .77958 Mdot
.45836 .51825 Mdot
.25085 .51452 Mdot
.57289 .30045 Mdot
.569 .58049 Mdot
.77749 .66377 Mdot
.79301 .5789 Mdot
.16477 .49283 Mdot
.33128 .78731 Mdot
.22901 .38684 Mdot
.52379 .47559 Mdot
.72443 .42215 Mdot
.31259 .38019 Mdot
.53666 .57695 Mdot
.2158 .41728 Mdot
.55619 .60752 Mdot
.45535 .83426 Mdot
.76092 .58013 Mdot
.36669 .80766 Mdot
.66424 .56178 Mdot
.34863 .55214 Mdot
.59594 .628 Mdot
.43453 .68919 Mdot
.22882 .50283 Mdot
.37071 .79929 Mdot
.38233 .34742 Mdot
.54162 .51856 Mdot
.80877 .53501 Mdot
.50429 .77191 Mdot
.5 .37565 Mdot
.44335 .31541 Mdot
.60471 .72646 Mdot
.40623 .82401 Mdot
.62433 .52193 Mdot
.30056 .69911 Mdot
.70956 .3692 Mdot
.58543 .34695 Mdot
.55131 .33996 Mdot
.65568 .45056 Mdot
.30824 .75642 Mdot
.64263 .59699 Mdot
.1653 .53442 Mdot
.57701 .52139 Mdot
.52861 .5576 Mdot
.4127 .82721 Mdot
.19011 .43554 Mdot
.47205 .77418 Mdot
.35387 .36504 Mdot
.76818 .38997 Mdot
.48586 .63951 Mdot
.71974 .38688 Mdot
.46535 .27605 Mdot
.72036 .48878 Mdot
.32097 .76533 Mdot
.2127 .40041 Mdot
.5597 .85205 Mdot
.25277 .52341 Mdot
.40504 .25932 Mdot
.67736 .57121 Mdot
.56266 .41034 Mdot
.51335 .38062 Mdot
.35965 .80599 Mdot
.41754 .75784 Mdot
.81316 .44238 Mdot
.26246 .34258 Mdot
.61414 .75444 Mdot
.7579 .49069 Mdot
.59841 .43565 Mdot
.44124 .67899 Mdot
.76655 .60155 Mdot
.34233 .61444 Mdot
.24269 .48107 Mdot
.60133 .71226 Mdot
.36544 .32819 Mdot
.31994 .47492 Mdot
.7623 .5565 Mdot
.23143 .42121 Mdot
.81416 .46451 Mdot
.61153 .72609 Mdot
.64099 .64915 Mdot
.21774 .41643 Mdot
.24539 .35861 Mdot
.79486 .45654 Mdot
.44077 .17715 Mdot
.29992 .70047 Mdot
.54843 .37874 Mdot
.43923 .63206 Mdot
.4314 .73398 Mdot
.45785 .76056 Mdot
.24377 .30873 Mdot
.47171 .58224 Mdot
.18687 .55295 Mdot
.74604 .43214 Mdot
.55435 .72018 Mdot
.21913 .47828 Mdot
.56521 .71367 Mdot
.46398 .78745 Mdot
.66085 .6757 Mdot
.68952 .47403 Mdot
.50866 .5166 Mdot
.4101 .82303 Mdot
.50675 .31172 Mdot
.21258 .41854 Mdot
.73315 .40771 Mdot
.57978 .2487 Mdot
.56529 .47007 Mdot
.50515 .41686 Mdot
.27439 .73184 Mdot
.80063 .5269 Mdot
.52553 .24607 Mdot
.7196 .60664 Mdot
.55342 .5597 Mdot
.5437 .68131 Mdot
.46253 .54492 Mdot
.55571 .59379 Mdot
.42343 .32301 Mdot
.55696 .75973 Mdot
.70063 .66168 Mdot
.42455 .1776 Mdot
.46476 .57948 Mdot
.39547 .47459 Mdot
.54831 .53384 Mdot
.3016 .42823 Mdot
.24208 .66839 Mdot
.48765 .56238 Mdot
.18882 .44405 Mdot
.80643 .5436 Mdot
.29507 .42979 Mdot
.50661 .38096 Mdot
.63334 .70511 Mdot
.36995 .80998 Mdot
.22021 .67701 Mdot
.77569 .62967 Mdot
.75141 .48609 Mdot
.38543 .1623 Mdot
.68049 .476 Mdot
.17941 .5303 Mdot
.73291 .40791 Mdot
.87237 .3852 Mdot
.53172 .33201 Mdot
.31583 .31322 Mdot
.51715 .61856 Mdot
.42825 .45709 Mdot
.358 .77872 Mdot
.48621 .7659 Mdot
.42568 .29065 Mdot
.59238 .59619 Mdot
.46662 .59739 Mdot
.38198 .79636 Mdot
.41842 .8202 Mdot
.38847 .79823 Mdot
.61462 .37305 Mdot
.47165 .80627 Mdot
.46436 .8498 Mdot
.30703 .36949 Mdot
.49036 .49354 Mdot
.40571 .64419 Mdot
.22122 .54456 Mdot
.18894 .49413 Mdot
.34629 .29877 Mdot
.4794 .64634 Mdot
.68262 .57461 Mdot
.44303 .84579 Mdot
.2329 .66091 Mdot
.43864 .71352 Mdot
.27691 .72598 Mdot
.5007 .23934 Mdot
.20535 .50919 Mdot
.24916 .70878 Mdot
.6581 .5349 Mdot
.68579 .37043 Mdot
.47361 .85871 Mdot
.24522 .37056 Mdot
.61552 .46101 Mdot
.75102 .62339 Mdot
.18245 .50496 Mdot
.74456 .49565 Mdot
.6113 .45833 Mdot
.54095 .59333 Mdot
.68134 .72264 Mdot
.51283 .41375 Mdot
.69164 .56197 Mdot
.52209 .46988 Mdot
.21286 .48301 Mdot
.55784 .33473 Mdot
.20452 .43909 Mdot
.49256 .3933 Mdot
.49973 .49223 Mdot
.26247 .44013 Mdot
.22291 .37004 Mdot
.73761 .5827 Mdot
.43901 .80027 Mdot
.80421 .53719 Mdot
.82676 .46818 Mdot
.77839 .478 Mdot
.60603 .70175 Mdot
.34524 .56757 Mdot
.34883 .77767 Mdot
.18162 .6479 Mdot
.25706 .71911 Mdot
.80165 .45844 Mdot
.53423 .35038 Mdot
.70197 .41866 Mdot
.30123 .38878 Mdot
.44366 .44816 Mdot
.61622 .49928 Mdot
.42825 .41116 Mdot
.64422 .44691 Mdot
.78434 .65868 Mdot
.57285 .50222 Mdot
.30617 .37633 Mdot
.4824 .6722 Mdot
.52457 .56921 Mdot
.41007 .78172 Mdot
.65253 .65336 Mdot
.79415 .44202 Mdot
.21472 .4199 Mdot
.50361 .30905 Mdot
.58167 .24154 Mdot
.49728 .52258 Mdot
.37025 .53822 Mdot
.46074 .2659 Mdot
.52148 .49967 Mdot
.5662 .6666 Mdot
.53239 .34854 Mdot
.19628 .62601 Mdot
.17283 .52738 Mdot
.24539 .70519 Mdot
.22808 .38113 Mdot
.5666 .23363 Mdot
.30628 .43528 Mdot
.70849 .46024 Mdot
.74428 .40697 Mdot
.33699 .44167 Mdot
.23161 .36566 Mdot
.46908 .77667 Mdot
.58797 .61149 Mdot
.431 .64033 Mdot
.22137 .63946 Mdot
.27418 .4008 Mdot
.31823 .42728 Mdot
.64534 .72467 Mdot
.68353 .59701 Mdot
.33012 .2795 Mdot
.71552 .58572 Mdot
.3028 .5915 Mdot
.76049 .48005 Mdot
.64315 .41006 Mdot
.67136 .65417 Mdot
.22137 .37115 Mdot
.47624 .17 Mdot
.58084 .55672 Mdot
.44441 .51241 Mdot
.31953 .7568 Mdot
.47174 .47724 Mdot
.72964 .49483 Mdot
.7049 .72424 Mdot
.74647 .36752 Mdot
.64392 .55666 Mdot
.51055 .48419 Mdot
.55465 .45506 Mdot
.71921 .67082 Mdot
.60117 .61076 Mdot
.42545 .759 Mdot
.31 .76568 Mdot
.48457 .45248 Mdot
.66638 .54623 Mdot
.28514 .45551 Mdot
.5453 .41118 Mdot
.56579 .54663 Mdot
.25621 .44027 Mdot
.61948 .54037 Mdot
.31969 .72198 Mdot
.82412 .61839 Mdot
.45103 .66833 Mdot
.30964 .30616 Mdot
.30473 .38632 Mdot
.58836 .67539 Mdot
.47383 .74287 Mdot
.75229 .40061 Mdot
.41754 .61793 Mdot
.30654 .77126 Mdot
.764 .5684 Mdot
.27831 .43534 Mdot
.59847 .37078 Mdot
.35948 .59203 Mdot
.32731 .57606 Mdot
.25812 .71719 Mdot
.71643 .64433 Mdot
.72685 .77522 Mdot
.26339 .33196 Mdot
.58403 .6422 Mdot
.48476 .78205 Mdot
.18752 .45423 Mdot
.65034 .67793 Mdot
.58184 .51942 Mdot
.50181 .39469 Mdot
.1854 .48346 Mdot
.7281 .6387 Mdot
.73173 .62399 Mdot
.77382 .46356 Mdot
.46405 .84615 Mdot
.55918 .57355 Mdot
.66448 .36729 Mdot
.4934 .24151 Mdot
.40879 .55527 Mdot
.80278 .55544 Mdot
.76207 .44318 Mdot
.58112 .38146 Mdot
.53666 .58532 Mdot
.17986 .64865 Mdot
.43036 .62755 Mdot
.79526 .53287 Mdot
.71526 .7811 Mdot
.76936 .74541 Mdot
.74315 .64727 Mdot
.35329 .80428 Mdot
.72914 .62407 Mdot
.72723 .49756 Mdot
.65612 .39698 Mdot
.41996 .48312 Mdot
.54239 .66732 Mdot
.28111 .74959 Mdot
.50436 .17854 Mdot
.71733 .38448 Mdot
.48964 .65508 Mdot
.27883 .74961 Mdot
.43909 .62443 Mdot
.3232 .29088 Mdot
.58388 .34831 Mdot
.21914 .34047 Mdot
.16799 .48534 Mdot
.6593 .72733 Mdot
.23574 .31429 Mdot
.31275 .2774 Mdot
.41089 .36816 Mdot
.17538 .52655 Mdot
.35717 .69377 Mdot
.6638 .71729 Mdot
.2204 .41365 Mdot
.74483 .48036 Mdot
.31873 .21117 Mdot
.56649 .54906 Mdot
.52277 .49316 Mdot
.70651 .66731 Mdot
.7141 .49077 Mdot
.73158 .55908 Mdot
.47484 .49115 Mdot
.35454 .47387 Mdot
.45329 .78441 Mdot
.8329 .45963 Mdot
.71779 .72578 Mdot
.53845 .50144 Mdot
.42472 .81679 Mdot
.74469 .39018 Mdot
.3439 .4345 Mdot
.49642 .75752 Mdot
.2814 .40176 Mdot
.49731 .24405 Mdot
.40919 .61772 Mdot
.315 .76925 Mdot
.49581 .24472 Mdot
.41108 .81133 Mdot
.1614 .54209 Mdot
.28361 .72479 Mdot
.5055 .57593 Mdot
.47178 .26532 Mdot
.19351 .48314 Mdot
.195 .48578 Mdot
.47178 .8339 Mdot
.29948 .29679 Mdot
.34589 .44636 Mdot
.49524 .47466 Mdot
.43515 .50923 Mdot
.30089 .58455 Mdot
.18523 .46004 Mdot
.62402 .69107 Mdot
.2236 .47331 Mdot
.76395 .64103 Mdot
.22668 .36895 Mdot
.47646 .7709 Mdot
.28072 .41003 Mdot
.55422 .38768 Mdot
.41835 .28063 Mdot
.53709 .27068 Mdot
.5357 .85439 Mdot
.78557 .46378 Mdot
.19232 .56272 Mdot
.80862 .44256 Mdot
.76758 .59743 Mdot
.28342 .30638 Mdot
.59979 .63018 Mdot
.41251 .68396 Mdot
.50556 .19359 Mdot
.23552 .42621 Mdot
.42925 .76599 Mdot
.75291 .46824 Mdot
.63643 .7483 Mdot
.28159 .74132 Mdot
.2151 .48495 Mdot
.59663 .8463 Mdot
.4419 .26377 Mdot
.55723 .75411 Mdot
.36454 .7703 Mdot
.83953 .51638 Mdot
.31932 .42385 Mdot
.41361 .82327 Mdot
.61516 .57522 Mdot
.33608 .79028 Mdot
.68446 .43863 Mdot
.38004 .26007 Mdot
.74401 .46532 Mdot
.30242 .41043 Mdot
.30507 .41118 Mdot
.18903 .59627 Mdot
.80524 .5321 Mdot
.79503 .57952 Mdot
.54844 .37834 Mdot
.57369 .31818 Mdot
.40856 .49152 Mdot
.64996 .53779 Mdot
.54738 .85009 Mdot
.35273 .56039 Mdot
.43401 .25849 Mdot
.20233 .42749 Mdot
.70825 .45944 Mdot
.53773 .48975 Mdot
.73899 .47407 Mdot
.68766 .73536 Mdot
.21265 .52517 Mdot
.45339 .84398 Mdot
.53966 .49103 Mdot
.445 .43678 Mdot
.59742 .75702 Mdot
.63987 .49792 Mdot
.74312 .37715 Mdot
.61878 .52814 Mdot
.45719 .49066 Mdot
.32384 .46408 Mdot
.23223 .38018 Mdot
.17317 .61867 Mdot
.44294 .8246 Mdot
.74426 .37636 Mdot
.30694 .41938 Mdot
.68262 .58638 Mdot
.24453 .42551 Mdot
.58668 .85106 Mdot
.2218 .31567 Mdot
.75442 .61897 Mdot
.22139 .38104 Mdot
.59051 .39456 Mdot
.31746 .29831 Mdot
.32718 .4336 Mdot
.36175 .76856 Mdot
.49534 .64233 Mdot
.70878 .64747 Mdot
.60033 .44743 Mdot
.28839 .47357 Mdot
.57163 .48113 Mdot
.65664 .71922 Mdot
.80435 .52483 Mdot
.59868 .84532 Mdot
.2946 .28722 Mdot
.59981 .74841 Mdot
.64386 .81596 Mdot
.68751 .63623 Mdot
.56175 .45686 Mdot
.61659 .33075 Mdot
.2974 .4253 Mdot
.51119 .32648 Mdot
.49409 .55414 Mdot
.36337 .46043 Mdot
.73436 .66076 Mdot
.5438 .2555 Mdot
.4268 .29898 Mdot
.63164 .64244 Mdot
.30651 .28497 Mdot
.67811 .65272 Mdot
.17304 .61045 Mdot
.65685 .53202 Mdot
.44694 .78023 Mdot
.69486 .7453 Mdot
.55276 .21974 Mdot
.8334 .47779 Mdot
.29081 .73504 Mdot
.23091 .53096 Mdot
.59924 .61086 Mdot
.63588 .64932 Mdot
.71481 .60449 Mdot
.67599 .46578 Mdot
.32434 .75563 Mdot
.19387 .43161 Mdot
.57456 .23149 Mdot
.63586 .57667 Mdot
.50582 .46775 Mdot
.52253 .50707 Mdot
.20738 .63905 Mdot
.54035 .33004 Mdot
.388 .82112 Mdot
.62414 .69438 Mdot
.82486 .55264 Mdot
.62638 .50281 Mdot
.32146 .49568 Mdot
.3314 .42043 Mdot
.56462 .2425 Mdot
.43054 .63791 Mdot
.5803 .63292 Mdot
.68098 .6267 Mdot
.56807 .47347 Mdot
.38265 .31921 Mdot
.4265 .17892 Mdot
.71826 .45807 Mdot
.58837 .69098 Mdot
.18036 .46327 Mdot
.65447 .65452 Mdot
.44402 .26799 Mdot
.53489 .21497 Mdot
.4594 .59377 Mdot
.22273 .56539 Mdot
.51389 .85615 Mdot
.30298 .73934 Mdot
.61349 .62064 Mdot
.82295 .46971 Mdot
.48984 .35928 Mdot
.19514 .62189 Mdot
.72414 .64575 Mdot
.19461 .44495 Mdot
.5896 .72272 Mdot
.23512 .68705 Mdot
.49164 .78074 Mdot
.61383 .51354 Mdot
.21842 .40446 Mdot
.4984 .42247 Mdot
.21677 .3842 Mdot
.67739 .74466 Mdot
.43475 .49648 Mdot
.21942 .34563 Mdot
.59521 .37613 Mdot
.44001 .72118 Mdot
.31979 .55602 Mdot
.61701 .50239 Mdot
.18879 .47784 Mdot
.64688 .64522 Mdot
.36645 .29945 Mdot
.50185 .6541 Mdot
.72493 .38646 Mdot
.3174 .76184 Mdot
.79746 .46386 Mdot
.20378 .41789 Mdot
.44204 .51458 Mdot
.27079 .37791 Mdot
.61531 .68584 Mdot
.24613 .52539 Mdot
.37748 .64875 Mdot
.60043 .71794 Mdot
.4529 .40698 Mdot
.2028 .60988 Mdot
.33662 .53275 Mdot
.36399 .78891 Mdot
.23506 .65834 Mdot
.72687 .65653 Mdot
.53277 .45431 Mdot
.62166 .57867 Mdot
.38963 .81695 Mdot
.20698 .54348 Mdot
.72121 .48483 Mdot
.16938 .48234 Mdot
.33027 .27229 Mdot
.65819 .80913 Mdot
.78477 .53236 Mdot
.50716 .50411 Mdot
.17084 .53899 Mdot
.76458 .57436 Mdot
.31919 .27378 Mdot
.4252 .76398 Mdot
.69679 .59377 Mdot
.41752 .82902 Mdot
.38842 .69641 Mdot
.78656 .58757 Mdot
.39333 .77631 Mdot
.60728 .55847 Mdot
.20644 .54907 Mdot
.41571 .64698 Mdot
.53109 .2772 Mdot
.42098 .46619 Mdot
.24287 .3048 Mdot
.58422 .56552 Mdot
.19071 .44608 Mdot
.19546 .4475 Mdot
.2942 .31561 Mdot
.55574 .23543 Mdot
.65996 .80771 Mdot
.49867 .8069 Mdot
.332 .60019 Mdot
.60765 .61302 Mdot
.42237 .29686 Mdot
.26576 .34329 Mdot
.35917 .61 Mdot
.28 .51702 Mdot
.60041 .72555 Mdot
.29474 .76206 Mdot
.55557 .40049 Mdot
.62931 .38493 Mdot
.63212 .57406 Mdot
.71939 .48785 Mdot
.65281 .68244 Mdot
.8141 .54828 Mdot
.19049 .47353 Mdot
.58158 .55663 Mdot
.61262 .52154 Mdot
.7802 .59302 Mdot
.22624 .41865 Mdot
.45606 .3774 Mdot
.6779 .39208 Mdot
.55747 .66394 Mdot
.51453 .83974 Mdot
.78014 .57768 Mdot
.57234 .54992 Mdot
.72641 .58487 Mdot
.44475 .49121 Mdot
.68063 .36144 Mdot
.80559 .53622 Mdot
.69727 .64953 Mdot
.32245 .72928 Mdot
.63758 .54881 Mdot
.46679 .26642 Mdot
.25152 .34842 Mdot
.70002 .56083 Mdot
.18905 .45785 Mdot
.45611 .60755 Mdot
.37719 .78789 Mdot
.28028 .43376 Mdot
.36333 .30093 Mdot
.37831 .6405 Mdot
.53878 .61251 Mdot
.25703 .71668 Mdot
.74608 .62376 Mdot
.51783 .59962 Mdot
.67994 .65865 Mdot
.16867 .51903 Mdot
.4633 .29262 Mdot
.51976 .34608 Mdot
.34144 .35251 Mdot
.32604 .49348 Mdot
.43808 .44873 Mdot
.68353 .46594 Mdot
.43604 .63094 Mdot
.44161 .38044 Mdot
.44992 .49796 Mdot
.56079 .66789 Mdot
.18631 .54052 Mdot
.53197 .85198 Mdot
.57317 .57856 Mdot
.16398 .48684 Mdot
.52326 .62239 Mdot
.65157 .5609 Mdot
.30023 .28343 Mdot
.50026 .61844 Mdot
.4695 .58691 Mdot
.36646 .30465 Mdot
.69042 .62961 Mdot
.52741 .84868 Mdot
.54809 .57719 Mdot
.35564 .29463 Mdot
.53014 .37398 Mdot
.55942 .5507 Mdot
.66981 .24213 Mdot
.74506 .42488 Mdot
.16706 .53287 Mdot
.21509 .41792 Mdot
.63893 .44915 Mdot
.72804 .6278 Mdot
.50435 .61654 Mdot
.37552 .78928 Mdot
.46734 .41169 Mdot
.30087 .74397 Mdot
.62205 .37006 Mdot
.57789 .6898 Mdot
.23286 .65266 Mdot
.23631 .48902 Mdot
.24529 .52066 Mdot
.62613 .72578 Mdot
.28469 .65184 Mdot
.5296 .54537 Mdot
.45779 .178 Mdot
.29885 .23059 Mdot
.56596 .85329 Mdot
.8235 .55732 Mdot
.31964 .62477 Mdot
.24222 .42998 Mdot
.65759 .54983 Mdot
.3503 .43796 Mdot
.52578 .38266 Mdot
.45623 .26752 Mdot
.59889 .38367 Mdot
.82461 .4537 Mdot
.3053 .76916 Mdot
.38137 .64023 Mdot
.41564 .405 Mdot
.39084 .35269 Mdot
.53121 .33403 Mdot
.45026 .69807 Mdot
.51097 .85445 Mdot
.6754 .39387 Mdot
.62459 .31818 Mdot
.68312 .46886 Mdot
.19128 .59672 Mdot
.60804 .29708 Mdot
.70254 .43667 Mdot
.17178 .60951 Mdot
.77329 .62752 Mdot
.65439 .74877 Mdot
.81374 .43846 Mdot
.21055 .62605 Mdot
.59693 .7139 Mdot
.46015 .27855 Mdot
.34 .78505 Mdot
.32928 .42197 Mdot
.52034 .24334 Mdot
.29211 .67672 Mdot
.21804 .39929 Mdot
.25893 .33827 Mdot
.61912 .42167 Mdot
.50189 .64037 Mdot
.43571 .16179 Mdot
.55806 .21865 Mdot
.84437 .59571 Mdot
.30224 .73633 Mdot
.54658 .8225 Mdot
.73808 .63386 Mdot
.55789 .37849 Mdot
.36901 .78418 Mdot
.19617 .45622 Mdot
.5112 .62028 Mdot
.48462 .18033 Mdot
.24713 .46821 Mdot
.25984 .41448 Mdot
.66068 .36265 Mdot
.25644 .7084 Mdot
.55735 .23068 Mdot
.33972 .68588 Mdot
.21051 .41518 Mdot
.53003 .62072 Mdot
.25082 .53054 Mdot
.50469 .83791 Mdot
.21834 .56291 Mdot
.23639 .35336 Mdot
.59998 .38098 Mdot
.47609 .33421 Mdot
.52613 .8448 Mdot
.61131 .66522 Mdot
.58958 .72857 Mdot
.71822 .77919 Mdot
.36554 .8066 Mdot
.49418 .62766 Mdot
.44653 .56902 Mdot
.16696 .57959 Mdot
.46369 .30591 Mdot
.19191 .5493 Mdot
.77134 .66821 Mdot
.26631 .3244 Mdot
.36528 .51896 Mdot
.3914 .62212 Mdot
.30885 .36182 Mdot
.71851 .65916 Mdot
.51083 .62729 Mdot
.59269 .27589 Mdot
.23318 .36463 Mdot
.59141 .69073 Mdot
.82364 .61894 Mdot
.6806 .74018 Mdot
.62861 .58397 Mdot
.326 .77799 Mdot
.38667 .70936 Mdot
.59806 .67914 Mdot
.36312 .77384 Mdot
.45568 .42176 Mdot
.44476 .37899 Mdot
.61132 .68266 Mdot
.30681 .43327 Mdot
.24483 .30037 Mdot
.63956 .82004 Mdot
.54929 .67354 Mdot
.39575 .82485 Mdot
.22249 .68279 Mdot
.62984 .58092 Mdot
.46691 .66937 Mdot
.3228 .41164 Mdot
.60364 .5521 Mdot
.60549 .44062 Mdot
.57593 .24201 Mdot
.33948 .26547 Mdot
.41591 .1863 Mdot
.38654 .61016 Mdot
.62279 .36794 Mdot
.28476 .74197 Mdot
.33589 .27778 Mdot
.29298 .74928 Mdot
.60852 .70926 Mdot
.33794 .5821 Mdot
.77326 .74199 Mdot
.72492 .49706 Mdot
.46653 .55801 Mdot
.33062 .6458 Mdot
.32264 .63718 Mdot
.41742 .61467 Mdot
.60847 .43003 Mdot
.29479 .38922 Mdot
.258 .32338 Mdot
.33905 .78131 Mdot
.65433 .57877 Mdot
.32765 .41891 Mdot
.66631 .37939 Mdot
.28956 .49179 Mdot
.29713 .65048 Mdot
.63929 .41337 Mdot
.2604 .31085 Mdot
.66773 .24262 Mdot
.48694 .38284 Mdot
.57353 .48872 Mdot
.34393 .47701 Mdot
.56266 .50955 Mdot
.28185 .29627 Mdot
.68515 .4628 Mdot
.41395 .36741 Mdot
.20642 .41359 Mdot
.62875 .73466 Mdot
.67478 .36466 Mdot
.37901 .17196 Mdot
.32249 .42687 Mdot
.61169 .3712 Mdot
.4572 .66275 Mdot
.69102 .72388 Mdot
.32481 .73947 Mdot
.45956 .36786 Mdot
.54267 .54249 Mdot
.59157 .75593 Mdot
.35596 .77833 Mdot
.64989 .43857 Mdot
.17771 .63032 Mdot
.45481 .6613 Mdot
.45415 .69775 Mdot
.49871 .82135 Mdot
.52163 .48133 Mdot
.43511 .76596 Mdot
.32258 .61737 Mdot
.42375 .43873 Mdot
.64168 .22652 Mdot
.53919 .4971 Mdot
.56229 .54514 Mdot
.59899 .54677 Mdot
.30614 .30844 Mdot
.34692 .72481 Mdot
.42148 .58175 Mdot
.43634 .32422 Mdot
.29321 .44152 Mdot
.40106 .26271 Mdot
.40768 .26091 Mdot
.68792 .37101 Mdot
.27885 .29928 Mdot
.26335 .33285 Mdot
.40171 .77373 Mdot
.38774 .80425 Mdot
.32305 .55132 Mdot
.298 .73226 Mdot
.52316 .40339 Mdot
.73804 .5606 Mdot
.22131 .56226 Mdot
.63377 .82268 Mdot
.57755 .62192 Mdot
.31058 .61647 Mdot
.20964 .65933 Mdot
.27582 .72748 Mdot
.72884 .39352 Mdot
.75458 .47364 Mdot
.27289 .25436 Mdot
.31019 .40809 Mdot
.82867 .45649 Mdot
.60027 .31606 Mdot
.20473 .64388 Mdot
.45644 .50754 Mdot
.48603 .63462 Mdot
.63436 .71068 Mdot
.46724 .58214 Mdot
.53386 .32076 Mdot
.70351 .72417 Mdot
.62835 .72693 Mdot
.28363 .6464 Mdot
.32874 .58709 Mdot
.58831 .46101 Mdot
.68731 .58998 Mdot
.57263 .8509 Mdot
.50123 .32588 Mdot
.4453 .43432 Mdot
.80555 .64227 Mdot
.64918 .23028 Mdot
.32737 .26865 Mdot
.46186 .83058 Mdot
.74588 .41219 Mdot
.45306 .49528 Mdot
.76422 .33825 Mdot
.63927 .56523 Mdot
.60545 .61259 Mdot
.70961 .46379 Mdot
.27449 .37994 Mdot
.79787 .54193 Mdot
.6825 .79891 Mdot
.23164 .68295 Mdot
.4575 .60248 Mdot
.8711 .54223 Mdot
.20757 .41973 Mdot
.42654 .41816 Mdot
.79701 .52826 Mdot
.31209 .7657 Mdot
.59677 .3916 Mdot
.16672 .55184 Mdot
.68582 .55298 Mdot
.62512 .5543 Mdot
.27088 .39866 Mdot
.80772 .44664 Mdot
.50773 .47133 Mdot
.84461 .59044 Mdot
.76627 .47649 Mdot
.26021 .4219 Mdot
.74233 .62191 Mdot
.62155 .56151 Mdot
.57244 .61425 Mdot
.66004 .52632 Mdot
.53009 .58263 Mdot
.57505 .549 Mdot
.62037 .52269 Mdot
.46184 .37925 Mdot
.60666 .48316 Mdot
.71664 .49714 Mdot
.72125 .44098 Mdot
.65293 .73015 Mdot
.2541 .27751 Mdot
.42749 .26363 Mdot
.55627 .33403 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo07Wooooo0_l0000?ooooo`;o
0000_Oooool001cooooo00?o0000ooooooooool0NOooool2o`0000oooooo0_l0002mooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo07Oooooo0_l0000F
ooooo`;o00001_ooool2o`000;3ooooo000Looooo`03o`000?oooooooooo07Oooooo0ol0000>oooo
o`;o00001Oooool2o`0000Kooooo0_l000000ooooooo0000o`00002]ooooo`007?ooool00ol0003o
ooooooooo`1hooooo`;o00003?ooool4o`000003ooooool0003o000000Ko000000?oooooo`000?l0
00001?ooool2o`000:gooooo000Looooo`03o`000?oooooooooo08Kooooo0ol00002ooooo`Co0000
0_ooool2o`000003ooooool0003o000000Cooooo0ol00003ooooo`;o0000Yoooool001cooooo00?o
0000ooooooooool0L?ooool2o`00017ooooo0ol000000ooooooo0000o`00000Aooooo`?o00000ooo
ool2o`000:Oooooo000Looooo`03o`000?oooooooooo073ooooo0_l0000Aooooo`?o0000`oooool0
01cooooo00?o0000ooooooooool0Poooool4o`000<;ooooo00001_ooooook^k^oc8b<_l0003o<S8b
onk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`1^ooooo`;o00005Oooool2
o`0001Wooooo0_l0002Wooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0K_ooool2o`0001kooooo
0_l00007ooooo`;o00001oooool2o`0000;ooooo0_l0002Sooooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0S_oo
ool2o`0000Oooooo0_l000000ooooooo0000o`000008ooooo`;o0000Xoooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06ooooo`?o0000V_ooool2
o`000:gooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIV
I_ooool01Oooool00ol0003oooooooooo`3ooooood[ooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood[o
oooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4006
ooooo`03o`000?oooooooooo06Cooooo0_l0003Sooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Tooooo`;o0000
A?ooool2o`0009gooooo000Looooo`03o`000?oooooooooo0:[ooooo0_l0002Mooooo`007?ooool0
0ol0003oooooooooo`2`ooooo`Co0000UOooool001cooooo00?o0000ooooooooool0/?ooool4o`00
00;ooooo0_l0002Aooooo`007?ooool00ol0003oooooooooo`2`ooooo`;o00001?ooool2o`0001Go
oooo0_l0001jooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o0000DOooool3o`0000Gooooo
0_l0000<ooooo`;o00000_ooool7o`0007Sooooo000Looooo`03o`000?oooooooooo05gooooo0_l0
001Booooo`;o000000Coooooo`000?l0003ooooo0ol0000<ooooo`;o00000_ooool3o`0000;ooooo
0_l0001hooooo`007?ooool00ol0003oooooooooo`1Kooooo`;o0000E?ooool2o`000004ooooool0
003o0000ooooo`?o0000Soooool001cooooo00?o0000ooooooooool0Foooool2o`0004;ooooo0_l0
000@ooooo`;o000000?oooooo`000?l00000Toooool001cooooo00?o0000ooooooooool0WOooool4
o`0001?ooooo1ol0000Jooooo`?o0000LOooool001cooooo00?o0000ooooooooool0F?ooool2o`00
04?ooooo0ol00005ooooo`Co00002oooool7o`0001[ooooo0ol0001aooooo`007?ooool00ol0003o
ooooooooo`1Hooooo`;o0000@oooool3o`0000Gooooo1Ol0000<ooooo`;o000000Coooooo`000?l0
003o00002oooool2o`00083ooooo000Looooo`;o0000Eoooool2o`0004gooooo0_l000000ooooooo
0000o`00000?ooooo`?o00002oooool2o`0001Wooooo0_l0001Uooooo`007?ooool00ol0003ooooo
ooooo`1Eooooo`?o0000Hoooool2o`0001gooooo0_l00006ooooo`?o0000I?ooool001cooooo00?o
0000ooooooooool0EOooool2o`0001Wooooo0_l0000Gooooo`;o00007Oooool2o`0000?ooooo0_l0
000<ooooo`?o00007?ooool2o`0000Oooooo0ol0001Sooooo`007?ooool00ol0003oooooooooo`1`
ooooo`;o00001_ooool2o`0000Kooooo0ol00006ooooo`;o00007Oooool2o`0000?ooooo0_l0000=
ooooo`;o00008?ooool2o`0000Cooooo0_l0001Sooooo`007?ooool00ol0003oooooooooo`1hoooo
o`;o00000_ooool2o`000003ooooool0003o000000;o00001?ooool2o`0000?ooooo0_l0000<oooo
o`;o00002Oooool2o`000003ooooool0003o000000oooooo0_l00002ooooo`;o00007oooool2o`00
06Wooooo000Looooo`03o`000?oooooooooo06_ooooo0_l0000?ooooo`Go00001_ooool2o`0000?o
oooo0_l00002ooooo`Oo00000oooool2o`0000Gooooo0ol000001?oooooo0000o`000?ooool4o`00
00gooooo0_l00002ooooo`;o0000R_ooool001cooooo00?o0000ooooooooool0D?ooool2o`0001Go
oooo0_l00002ooooo`;o00001?ooool2o`0000_ooooo0_l0000<ooooo`;o00000_ooool7o`0000Co
oooo0_l00004ooooo`?o000000?oooooo`000?l000002Ol0002Iooooo`007?ooool00ol0003ooooo
ooooo`1@ooooo`;o00004_ooool2o`000004ooooool0003o0000o`0000Oooooo0_l00009ooooo`;o
00001oooool2o`0000Gooooo0_l0000=ooooo`;o00000_ooool4o`000003ooooool0003o000000co
0000=oooool2o`0005kooooo000Looooo`03o`000?oooooooooo04kooooo0_l0000Dooooo`;o0000
0_ooool2o`0000cooooo0_l00002ooooo`Co000000?oooooo`000?l000001?ooool2o`0000cooooo
0_l00004ooooo`?o00000ooooolEo`0000Wooooo0_l0000Zooooo`;o0000G_ooool001cooooo00?o
0000ooooooooool0COooool4o`00017ooooo0_l00004ooooo`?o00002?ooool2o`000003ooooool0
003o000000Wo00004Oooool3o`000004ooooool0003o0000ooooo`?o00000_ooool2o`000003oooo
ool0003o0000017o00002Oooool2o`0002[ooooo0_l0001Nooooo`007?ooool00ol0003ooooooooo
o`1=ooooo`Co00004Oooool2o`0000Cooooo0ol00008ooooo`;o000000?oooooo`000?l000002_l0
0002ooooo`;o00003?ooool6o`000004ooooool0003o0000ooooo`Oo000000?oooooo`000?l00000
3ol0000eooooo`;o0000GOooool001cooooo00?o0000ooooooooool0G_ooool4o`0001Cooooo4?l0
0008ooooo`[o000000Coooooo`000?l0003ooooo6Ol0000eooooo`?o0000G?ooool001cooooo00?o
0000ooooooooool0G?ooool7o`00017ooooo4?l0000:ooooo`Oo00001_oooolIo`0000Cooooo0_l0
0005ooooo`;o0000:_ooool3o`0005_ooooo000Looooo`03o`000?oooooooooo05cooooo0_l00003
ooooo`;o00000_ooool2o`0000Kooooo0_l00005oooooaGo00001Oooool2o`0000?ooooo0_l00004
oooooako000000?oooooo`000?l000000ol00002ooooo`;o0000:oooool2o`0005_ooooo000Loooo
o`03o`000?oooooooooo06Gooooo0_l00006ooooo`;o000000?oooooo`000?l000001Oooool2o`00
0003ooooool0003o000000ko00002Oooool3o`000003ooooool0003o000000Go000000?oooooo`00
0?l000006?l000001?oooooo0000o`000?l00002ooooo`;o000000?oooooo`000?l00000QOooool0
01cooooo00?o0000ooooooooool0F?ooool2o`0000Cooooo0_l00003ooooo`;o00002?ooool2o`00
0003ooooool0003o000000Cooooo5?l00003ooooo`?o00000oooool3o`000003ooooool0003o0000
00;ooooo0ol000000ooooooo0000o`00000Ho`0000Wooooo0_l00004ooooo`;o00008?ooool2o`00
00;ooooo0_l0001Iooooo`007?ooool2o`0004Wooooo0ol000000ooooooo0000o`000009ooooo`?o
00001?ooool2o`0000?ooooo0_l00008ooooo`;o00000ooooolJo`000004ooooool0003o0000o`00
00[ooooo1Ol000000ooooooo0000o`00000Fo`0000Sooooo1?l00004ooooo`;o00008?ooool2o`00
00;ooooo0_l0001Iooooo`007?ooool00ol0003oooooooooo`18ooooo`?o000000?oooooo`000?l0
00002Oooool2o`0001Cooooo0_l00003oooooa[o00003OoooolOo`0000?ooooo0_l00003ooooo`;o
0000Qoooool001cooooo00?o0000ooooooooool0Boooool2o`000003ooooool0003o000000Sooooo
0_l00007ooooo`;o00001oooool2o`0000Oooooo6Ol00005ooooo`Co00001?oooolOo`0000;ooooo
0ol000000ooooooo0000o`000002o`0008Oooooo000Looooo`03o`000?oooooooooo04_ooooo0_l0
00001?oooooo0000o`000?ooool2o`0000Gooooo0_l00006ooooo`?o00001oooool2o`0000[ooooo
5?l000000ooooooo0000o`000004ooooo`Co00000_oooolQo`0000;ooooo0_l00002ooooo`Co0000
Qoooool001cooooo00?o0000ooooooooool0AOooool2o`0000Cooooo0_l00004ooooo`;o00001_oo
ool2o`0000Gooooo0_l000000ooooooo0000o`000005ooooo`;o00002_oooolDo`000003ooooool0
003o000000[ooooo3?l000000ooooooo0000o`00000Bo`000003ooooool0003o000000?ooooo1?l0
000^ooooo`;o0000Eoooool001cooooo00?o0000ooooooooool0A?ooool3o`0000;ooooo0_l0000>
ooooo`;o000000?oooooo`000?l000001Oooool2o`0000?ooooo0ol0000;oooooa?o00000_ooool3
o`0000[ooooo2ol000000ooooooo0000o`00000Ao`0000;ooooo0_l00003ooooo`Co0000;_ooool2
o`0005Oooooo000Looooo`03o`000?oooooooooo04Cooooo0_l00003ooooo`;o00004Oooool2o`00
00Gooooo0_l00003ooooo`?o00002ooooolCo`0000;ooooo0ol0000;ooooob3o00001Oooool5o`00
00Cooooo0_l0000Vooooo`;o0000F?ooool001cooooo00?o0000ooooooooool0A?ooool2o`00013o
oooo0_l0000;ooooo`;o00001Oooool2o`0000[ooooo4ol00002ooooo`;o00003OoooolLo`000003
ooooool0003o000000Cooooo0_l00002ooooo`;o00001?ooool2o`0002Kooooo0_l0001Hooooo`00
7?ooool00ol0003oooooooooo`12ooooo`;o00003?ooool2o`000004ooooool0003o0000ooooo`;o
00002_ooool3o`0000?ooooo1?l00007ooooo`;o000000?oooooo`000?l000004Ol000001?oooooo
0000o`000?l0000AoooooaSo00001?ooool5o`0008[ooooo000Looooo`03o`000?oooooooooo047o
oooo1Ol00002ooooo`;o00001Oooool3o`000003ooooool0003o000000gooooo0_l00004ooooo`;o
00002Oooool3o`000003ooooool0003o000000oo00000_ooool2o`0001;ooooo0ol000000ooooooo
0000o`00000=o`000003ooooool0003o000000Go000000?oooooo`000?l000000ol0000dooooo`;o
0000E?ooool001cooooo00?o0000ooooooooool0@Oooool2o`000004ooooool0003o0000ooooo`?o
00001Oooool5o`0000kooooo0_l0000?ooooo`?o000000?oooooo`000?l000003ol0000=ooooo`;o
00001oooool3o`000003ooooool0003o000000_o00000oooool7o`000003ooooool0003o000000Wo
oooo0_l0000/ooooo`;o0000E?ooool001cooooo00?o0000ooooooooool0A_ooool4o`0000Kooooo
1?l0000Eooooo`;o00003_ooool>o`000004ooooool0003o0000ooooo`;o00002?ooool4o`0000Oo
oooo3ol00002ooooo`_o000000?oooooo`000?l000001_ooool2o`0008;ooooo000Looooo`03o`00
0?oooooooooo04Gooooo1Ol00006ooooo`Co00005Oooool2o`0000kooooo4Ol000000ooooooo0000
o`000009ooooo`?o00001oooool2o`000003ooooool0003o000001Ko00000_ooool3o`000003oooo
ool0003o0000037ooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`13ooooo`Co000000?o
ooooo`000?l000001_ooool2o`00027ooooo0_l00005ooooo`Ko000000?oooooo`000?l000000_l0
00000ooooooo0000o`00000>ooooo`;o00003_ooool4o`000003ooooool0003o000000_o000000?o
ooooo`000?l000000oooool2o`000003ooooool0003o0000037ooooo0_l0001Cooooo`007?ooool0
0ol0003oooooooooo`11ooooo`Ko000000?oooooo`000?l000002?ooool3o`0001kooooo0_l00007
ooooo`Wo00000_ooool3o`0000cooooo0_l0000@ooooo`_o00002_ooool2o`0008[ooooo000Loooo
o`03o`000?oooooooooo047ooooo0_l000001?oooooo0000o`000?l0000;ooooo`Co00005Oooool2
o`0000Sooooo0_l000000ooooooo0000o`000003ooooo`Ko00001?ooool3o`0000cooooo0_l0000=
ooooo`?o00000_ooool5o`0000_ooooo0_l000000ooooooo0000o`00002:ooooo`007?ooool2o`00
04Gooooo0_l000000ooooooo0000o`000005ooooo`;o00001?ooool2o`0000cooooo0_l00007oooo
o`;o00002?ooool2o`000003ooooool0003o000000?ooooo0_l000001?oooooo0000o`000?l0000D
ooooo`?o00002oooool3o`000004ooooool0003o0000o`0000kooooo0_l0002=ooooo`007?ooool0
0ol0003oooooooooo`17ooooo`Co00000oooool2o`0000;ooooo0_l0000<ooooo`Co00001oooool2
o`0000;ooooo0_l0000:ooooo`So00005?ooool3o`0000oooooo0ol0000>ooooo`;o0000SOooool0
01cooooo00?o0000ooooooooool0B?ooool3o`0000Kooooo0ol0000;ooooo`?o00002Oooool2o`00
00;ooooo0_l0000:ooooo`Ko000000?oooooo`000?l00000aOooool001cooooo00?o0000oooooooo
ool0Aoooool3o`0000;ooooo0_l00003ooooo`;o00003?ooool3o`0000kooooo0_l0000;ooooo`;o
00000oooool2o`0001Oooooo0_l0000Zooooo`;o00001_ooool3o`0002?ooooo0_l0001Booooo`00
7?ooool00ol0003oooooooooo`17ooooo`;o00000oooool2o`000003ooooool0003o0000013ooooo
0_l0000=ooooo`?o00002_ooool2o`0000Gooooo0_l00002ooooo`?o00004?ooool2o`0002Wooooo
0ol000000ooooooo0000o`000003ooooo`?o000000?oooooo`000?l000001?ooool2o`0000;ooooo
0_l0000Fooooo`Co0000D?ooool001cooooo00?o0000ooooooooool0B?ooool2o`0000Gooooo0_l0
000@ooooo`;o00003?ooool4o`0000Oooooo0_l00008ooooo`;o00000_ooool3o`0000;ooooo1Ol0
000/ooooo`;o00001_ooool3o`000003ooooool0003o000000Oooooo0_l00002ooooo`Co00000_oo
ool2o`0001Kooooo1?l0001@ooooo`007?ooool00ol0003oooooooooo`16ooooo`Co00001?ooool2
o`0001oooooo0ol00008ooooo`;o00001_ooool9o`0000;ooooo2?l000001?oooooo0000o`000?oo
ool2o`00013ooooo0_l0000:ooooo`?o00001?ooool2o`0000Oooooo0ol00002ooooo`;o00001_oo
ool2o`000003ooooool0003o000000Cooooo0_l00004ooooo`;o00001oooool5o`0000Cooooo0_l0
001Booooo`007?ooool00ol0003oooooooooo`14ooooo`Co00001?ooool4o`0000kooooo1?l0000A
ooooo`;o00003Oooool3o`000003ooooool0003o000000?o00001?ooool6o`000004ooooool0003o
0000ooooo`;o000000Coooooo`000?l0003o00003?ooool2o`0000Gooooo0_l00003ooooo`?o0000
1Oooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l000000ooooooo0000
o`000002ooooo`?o00001Oooool3o`0000Gooooo0ol00006ooooo`Go0000F?ooool001cooooo00?o
0000ooooooooool0A?ooool3o`0000Gooooo0ol0000?ooooo`Co00004Oooool2o`0001[ooooo1?l0
0003ooooo`;o00001?ooool3o`0000Cooooo0_l00002ooooo`?o00002?ooool2o`0000_ooooo0_l0
0002ooooo`Go00001oooool2o`0000;ooooo1?l00002ooooo`Go00001_ooool2o`0000Gooooo0_l0
001Looooo`007?ooool00ol0003oooooooooo`14ooooo`;o00003_ooool2o`0000Sooooo1?l0000^
ooooo`;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o
000000;ooooo0ol00004ooooo`;o000000?oooooo`000?l000002oooool2o`0000Cooooo1?l00003
ooooo`Ko00000_ooool4o`0000;ooooo0ol0000?ooooo`;o000000?oooooo`000?l000001oooool2
o`00053ooooo000Looooo`03o`000?oooooooooo04Cooooo1_l0000:ooooo`?o00001_ooool7o`00
01?ooooo0_l0000Cooooo`?o000000?oooooo`000?l000000_l00006ooooo`;o000000?oooooo`00
0?l000001ol00008ooooo`;o000000?oooooo`000?l000001_ooool2o`0000?ooooo1Ol00006oooo
o`Ko00001Oooool8o`000003ooooool0003o000000?ooooo1?l00008ooooo`;o00001oooool2o`00
053ooooo000Looooo`03o`000?oooooooooo04?ooooo1ol0000;ooooo`;o00001Oooool4o`0000;o
oooo0_l0000Cooooo`?o00004_ooool3o`0000?ooooo0_l00006ooooo`;o00001?ooool6o`000003
ooooool0003o000000Gooooo0_l00009ooooo`;o00001?ooool4o`0000Kooooo0_l0000:ooooo`[o
00000oooool5o`0000_ooooo0_l0000Sooooo`;o0000<?ooool001cooooo00?o0000ooooooooool0
@Oooool4o`0000;ooooo0_l0000Booooo`Ko00005oooool2o`00023ooooo0_l0000;ooooo`;o0000
1oooool2o`0000gooooo0_l00005ooooo`;o000000?oooooo`000?l000003Oooool7o`0000Kooooo
1Ol00002ooooo`Co00000_ooool2o`0002?ooooo0ol0000_ooooo`007?ooool00ol0003ooooooooo
o`11ooooo`;o00001?ooool2o`0001;ooooo1_l0000aooooo`;o00007?ooool2o`0001Cooooo0_l0
00000ooooooo0000o`00000=ooooo`So00000oooool7o`0000;ooooo1?l00006ooooo`;o00008?oo
ool2o`0002oooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o0000
00?o410@ooooooooool01?ooool00ol0003oooooooooo`11ooooo`;o00005oooool7o`0000;ooooo
0_l0000Cooooo`;o00001?ooool4o`0000?ooooo0_l0000;ooooo`;o00002?ooool2o`00023ooooo
0_l0000Hooooo`[o000000?oooooo`000?l000000ol000001?oooooo0000o`000?ooool4o`0000Ko
oooo0ol0001@ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo043ooooo0ol0000<ooooo`;o00002?ooool4o`00
00;ooooo0_l00002ooooo`;o00004oooool5o`000003ooooool0003o000000;o00000_ooool3o`00
01Gooooo0_l000000ooooooo0000o`00000Kooooo`Go00002Oooool6o`000003ooooool0003o0000
00Cooooo2ol00007ooooo`;o000000?oooooo`000?l000001?ooool2o`0000?ooooo0_l0001@oooo
o`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`Go00001_ooool00ol0003o
ooooooooo`10ooooo`;o000000?oooooo`000?l000002_ooool2o`0000?ooooo0_l00003ooooo`?o
00000oooool3o`0001Sooooo0ol00006ooooo`?o00006Oooool2o`0001_ooooo1Ol00009ooooo`Ko
000000?oooooo`000?l000003_l0000Aooooo`;o0000EOooool00003ooooool0003ooooo00;ooooo
00?o0000ooooooooool02Oooool01?m4A4CogMgMooooool00007ooooo`?o0000@Oooool4o`0000oo
oooo0ol000000ooooooo0000o`000006ooooo`;o00008Oooool2o`000004ooooool0003o0000oooo
o`;o00009_ooool2o`0000Wooooo0ol0000=oooooaGo00004?ooool4o`0005Cooooo00000ooooooo
0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0
003oooooooooo`0oooooo`Ko00004?ooool2o`000003ooooool0003o000000Kooooo0_l0000Qoooo
o`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00005_ooool2o`0000Wooooo0_l0000:
ooooo`?o00003?oooolGo`0000kooooo1?l0001Dooooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0?oooool2o`00
00;ooooo0_l00006ooooo`;o00002oooool2o`0000Oooooo0_l0000Pooooo`;o00002Oooool5o`00
01?ooooo0_l0000Eooooo`?o00003OoooolFo`0000Oooooo0_l00002ooooo`;o00000_ooool2o`00
05Gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l000001oooool0
0ol0003oooooooooo`1;ooooo`;o00002_ooool3o`0000Gooooo1?l00002ooooo`;o00008?ooool2
o`0000Kooooo1?l000000ooooooo0000o`00000Gooooo`;o00001?ooool2o`0000_ooooo0_l00009
oooooa[o00001Oooool2o`0000;ooooo0_l00007ooooo`;o0000D?ooool00006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo03oooooo1?l0
00000ooooooo0000o`000009ooooo`Co00001?ooool3o`0000Gooooo0_l00004ooooo`;o00008?oo
ool2o`0000Kooooo0_l00003ooooo`;o00003Oooool2o`0000Sooooo0_l00004ooooo`;o00002_oo
ool3o`0000Cooooo0_l00002oooooaOo00000_ooool3o`0000Sooooo0_l00007ooooo`;o0000D?oo
ool001cooooo00?o0000ooooooooool0?Oooool;o`0000Oooooo1?l00004ooooo`;o00004?ooool2
o`0001cooooo0_l0000?ooooo`;o00001_ooool2o`000003ooooool0003o000001[ooooo0_l00005
ooooo`;o000000?oooooo`000?l000002_l000000ooooooo0000o`00000>o`0000?ooooo0_l0000a
ooooo`;o0000:oooool001cooooo00?o0000ooooooooool0?Oooool8o`000004ooooool0003o0000
o`0000?ooooo0_l00003ooooo`;o00001?ooool2o`0000Oooooo0_l00005ooooo`Co00007?ooool2
o`0000Oooooo0_l00006ooooo`;o00000_ooool2o`0000;ooooo0_l00002ooooo`;o00006_ooool2
o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000005ol00004ooooo`;o00000oooool2
o`0000Oooooo0_l0000Sooooo`;o0000:oooool001cooooo00?o0000ooooooooool0?Oooool2o`00
0003ooooool0003o000000;o00000oooool2o`0000;ooooo0ol00003ooooo`;o000000?oooooo`00
0?l000000_l00008ooooo`;o00000_ooool2o`000004ooooool0003o0000o`0002Kooooo0_l0000:
ooooo`Co00001?ooool2o`0001[ooooo0ol00002ooooo`;o00000_ooool2o`0000;ooooo5_l00005
ooooo`;o00001?ooool2o`0000;ooooo0_l00003ooooo`;o0000D?ooool001cooooo00?o0000oooo
ooooool0?_ooool2o`0000Sooooo1_l00003ooooo`;o000000?oooooo`000?l000000_l00005oooo
o`;o00001Oooool5o`0003Cooooo0ol0000Qooooo`;o00002?oooolHo`0000Gooooo0_l00004oooo
o`;o00000_ooool2o`0000;ooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`0nooooo`;o
00002?ooool6o`0000Gooooo1?l00005ooooo`Co00001?ooool3o`0003Oooooo0ol0000Qooooo`;o
00001ooooolGo`0000kooooo0_l00004ooooo`;o00009?ooool2o`0002_ooooo000Looooo`03o`00
0?oooooooooo03_ooooo0_l0000>ooooo`;o00000oooool5o`0000;ooooo0_l00003ooooo`Ko0000
1Oooool2o`0003Kooooo0_l000000ooooooo0000o`00000Nooooo`;o00002OoooolCo`0000oooooo
0ol0000>ooooo`;o00006_ooool2o`0002_ooooo000Looooo`03o`000?oooooooooo03[ooooo0ol0
000Booooo`Ko00000_ooool2o`0000Oooooo0_l00005ooooo`;o00000oooool2o`0000?ooooo0_l0
000Jooooo`;o00004oooool3o`0001[ooooo0_l000000ooooooo0000o`00000;oooooaCo00003?oo
ool3o`0000Cooooo0_l00008ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0>_ooool2
o`0000?ooooo0_l0000<ooooo`Oo00000oooool2o`0000Oooooo0_l0000:ooooo`Co000000?ooooo
o`000?l000004_ooool3o`0000Gooooo0_l0000Cooooo`?o00006_ooool2o`000003ooooool0003o
000000Oooooo6?l0000=ooooo`;o00001?ooool2o`0000gooooo0ol0000Dooooo`;o0000:oooool0
01cooooo00?o0000ooooooooool0?oooool2o`0000_ooooo2?l00008ooooo`;o000000Coooooo`00
0?l0003ooooo0ol00005ooooo`;o00000_ooool2o`0000Cooooo0_l0000?ooooo`?o00007_ooool2
o`0001Wooooo0_l00008oooooaKo00001Oooool2o`0000cooooo0_l00008ooooo`;o00000oooool5
o`0001Cooooo0_l0000[ooooo`007?ooool00ol0003oooooooooo`0jooooo`Co00003_ooool3o`00
00Wooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0ol00003ooooo`Co000000?ooooo
o`000?l000001?ooool3o`00013ooooo0_l0000Aooooo`?o00002_ooool2o`0001Wooooo0_l00000
0ooooooo0000o`000007oooooaKo00000oooool2o`0000Gooooo0_l000000ooooooo0000o`000006
o`0000Kooooo0_l00003ooooo`?o00005_ooool2o`0002_ooooo000Looooo`03o`000?oooooooooo
03[ooooo1?l0000Jooooo`;o00003_ooool4o`000003ooooool0003o000000Cooooo1?l0000Doooo
o`?o00002Oooool9o`0000Sooooo0_l0000Eooooo`;o00000oooool2o`0000Kooooo5?l000000ooo
oooo0000o`000007ooooo`Go000000?oooooo`000?l000000_l00002ooooo`;o00002oooool2o`00
01Oooooo0_l0000[ooooo`007?ooool2o`0003gooooo0_l0000=ooooo`;o00003_ooool2o`000004
ooooool0003o0000o`0000Wooooo1?l00007ooooo`;o00005?ooool3o`0000Wooooo2_l00007oooo
o`;o00005Oooool2o`0000?ooooo0_l00006oooooa7o00003Oooool6o`0000;ooooo0_l0000?oooo
o`;o00005oooool2o`0002_ooooo000Looooo`03o`000?oooooooooo03Kooooo0_l000000ooooooo
0000o`00000@ooooo`;o00003?ooool8o`0000Cooooo0_l00005ooooo`Co00003_ooool2o`0001Go
oooo1?l000001?oooooo0000o`000?ooool6o`0000Kooooo1Ol00002ooooo`;o00004_ooool2o`00
00Wooooo3_l0000=ooooo`;o00000_ooool2o`000003ooooool0003o000000Oooooo0_l0000<oooo
o`Co00003oooool2o`0002cooooo000Looooo`03o`000?oooooooooo03Kooooo0_l000000ooooooo
0000o`000003o`0000cooooo0_l0000:ooooo`So00000oooool2o`000003ooooool0003o000000?o
00001Oooool4o`0000Sooooo0_l00002ooooo`;o00001Oooool4o`0000_ooooo1Ol00006ooooo`Oo
00000oooool6o`000004ooooool0003o0000ooooo`;o00003_ooool3o`0000Kooooo0ol00004oooo
o`Wo00002_ooool2o`0000;ooooo0_l00004ooooo`Co00001_ooool2o`0000;ooooo0_l000000ooo
oooo0000o`000005ooooo`Co00003oooool2o`0002cooooo000Looooo`03o`000?oooooooooo03So
oooo1_l0000<ooooo`;o00002_ooool3o`0000Sooooo0_l000001?oooooo0000o`000?ooool3o`00
00Kooooo1?l00003ooooo`;o000000?oooooo`000?l000002Oooool4o`0000_ooooo0ol0000;oooo
o`Ko00001?ooool3o`0000Cooooo0_l00006ooooo`;o00001_ooool3o`0000Kooooo1?l00005oooo
o`Oo00001_ooool2o`0000;ooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo1?l0000:
ooooo`;o000000?oooooo`000?l000001_ooool4o`0003cooooo000Looooo`03o`000?oooooooooo
03Oooooo0ol00008ooooo`;o00001_ooool2o`0000kooooo2?l00002ooooo`?o000000Coooooo`00
0?l0003o00001oooool2o`0000?ooooo1?l0000Gooooo`Go00001?ooool2o`0000Oooooo1Ol00003
ooooo`?o00003?ooool2o`0000Kooooo1?l00007ooooo`;o00001?ooool4o`0000?ooooo0_l00005
ooooo`?o00001?ooool2o`0000;ooooo1_l00004ooooo`?o000000?oooooo`000?l000000_ooool2
o`0000Cooooo0_l00004ooooo`;o00003Oooool2o`0002gooooo000Looooo`03o`000?oooooooooo
03Oooooo0_l00009ooooo`;o00001Oooool3o`0000cooooo2_l000000ooooooo0000o`000003o`00
0004ooooool0003o0000o`0000Wooooo0_l00002ooooo`;o00002_ooool2o`0000Wooooo1?l00000
0ooooooo0000o`000004ooooo`?o00000oooool2o`0000?ooooo0ol0000Iooooo`Go00002Oooool2
o`0000;ooooo0_l00002ooooo`Go00001Oooool5o`0000;ooooo0_l00003ooooo`Oo00000_ooool3
o`000003ooooool0003o000000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000Cooooo0_l0
000=ooooo`;o0000;Oooool001cooooo00?o0000ooooooooool0BOooool3o`000003ooooool0003o
000000Oooooo1?l000000ooooooo0000o`000004o`0000;ooooo1Ol000000ooooooo0000o`000002
o`0000?ooooo0_l00003ooooo`;o00002_ooool2o`0000;ooooo0_l00008ooooo`Go00001Oooool2
o`000003ooooool0003o000000?ooooo0_l00003ooooo`;o00000_ooool2o`0000Cooooo0_l00002
ooooo`;o00003?ooool2o`0000cooooo0_l00006ooooo`Co00001Oooool6o`0000Oooooo1ol0000=
ooooo`;o00000oooool6o`0003cooooo000Looooo`03o`000?oooooooooo03[ooooo0_l00002oooo
o`;o00001Oooool2o`0000;ooooo0_l00002ooooo`;o00001oooool3o`000003ooooool0003o0000
00Go000000?oooooo`000?l000000_l00002ooooo`Go00000_ooool3o`0000Kooooo0_l00007oooo
o`;o00002Oooool8o`0000Gooooo0_l00006ooooo`;o00000oooool2o`000004ooooool0003o0000
o`0000Cooooo0_l00002ooooo`?o00003?ooool2o`0000kooooo0ol00004ooooo`Co00000oooool3
o`0000Sooooo0_l00002ooooo`?o00005?ooool4o`0000kooooo0_l0000^ooooo`007?ooool00ol0
003oooooooooo`0cooooo`;o00001Oooool2o`0000;ooooo0_l00005ooooo`;o00002_ooool2o`00
00;ooooo0ol00002ooooo`Go00000oooool4o`0000;ooooo1_l000001?oooooo0000o`000?l00006
ooooo`;o000000?oooooo`000?l000000_l0000=ooooo`Co00001Oooool2o`0000Kooooo0_l00002
ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000?ooooo0_l0
000<ooooo`;o00003_ooool;o`0000;ooooo0_l0000:ooooo`;o00000oooool2o`0000;ooooo0_l0
000Rooooo`;o0000;_ooool001cooooo00?o0000ooooooooool0<oooool2o`0000Gooooo0_l00007
ooooo`;o00000oooool2o`0000Oooooo0_l00002ooooo`;o00001?oooolCo`000003ooooool0003o
000000Oooooo0_l000000ooooooo0000o`000002o`0000[ooooo0_l00003ooooo`;o00000_ooool2
o`000003ooooool0003o000000Kooooo0_l00007ooooo`;o00001?ooool2o`0000;ooooo0ol00005
ooooo`;o00003?ooool2o`0000gooooo2?l00003ooooo`;o00003?ooool2o`0000?ooooo1?l00002
ooooo`;o00004?ooool4o`0003[ooooo000Looooo`03o`000?oooooooooo03?ooooo0_l00005oooo
o`?o00001?ooool4o`0000?ooooo0_l000000ooooooo0000o`00000?ooooo`co00000oooool3o`00
00gooooo0ol000000ooooooo0000o`000006o`000005ooooool0003o0000o`000?ooool01?l00002
ooooo`;o00004_ooool2o`0000Cooooo0_l00002ooooo`?o00000oooool4o`0000Oooooo0_l00003
ooooo`;o00009_ooool2o`0000?ooooo0_l00004ooooo`;o00004?ooool4o`0003[ooooo000Loooo
o`03o`000?oooooooooo03?ooooo0_l00004ooooo`Go00000oooool3o`0000Cooooo0_l000001?oo
oooo0000o`000?ooool2o`0000?ooooo0ol0000@ooooo`;o00004oooool3o`000003ooooool0003o
000000Ko000000?oooooo`000?l000000_ooool4o`0000;ooooo0_l0000>ooooo`;o00000_ooool2
o`0000Cooooo0ol00002ooooo`?o00000_ooool2o`0000Wooooo0_l0000<ooooo`;o00005Oooool2
o`0000Sooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`0booooo`?o00001?ooool2o`00
0003ooooool0003o000000Cooooo0_l00003ooooo`Co00000oooool2o`0000?ooooo0ol00008oooo
o`;o00001_ooool2o`0001Cooooo0_l0000:ooooo`?o00000oooool2o`0001;ooooo0_l00009oooo
o`?o000000?oooooo`000?l000000_l00002ooooo`;o00005_ooool2o`0001Gooooo0_l00008oooo
o`;o00009_ooool3o`0002kooooo000Looooo`03o`000?oooooooooo03;ooooo0_l0000:ooooo`;o
00001Oooool6o`0000?ooooo0_l00003ooooo`;o00000oooool4o`0000;ooooo0_l0000Looooo`;o
00000oooool2o`0000Gooooo1?l000000ooooooo0000o`000002ooooo`;o00000oooool2o`0000Oo
oooo0_l0000:ooooo`Go00000oooool2o`0000;ooooo0_l0000[ooooo`Co00002_ooool2o`0002Co
oooo0ol0000^ooooo`007?ooool00ol0003oooooooooo`0booooo`;o00001_ooool2o`0000;ooooo
0_l00005ooooo`;o00001Oooool5o`0000;ooooo0_l00003ooooo`Co00002Oooool3o`0001Wooooo
0_l00007ooooo`;o000000?oooooo`000?l000001?l00003ooooo`;o00001?ooool2o`000003oooo
ool0003o000000Gooooo0_l00003ooooo`Ko00000_ooool2o`0002Sooooo0ol00004ooooo`;o0000
0oooool2o`0000?ooooo0_l00002ooooo`;o0000EOooool001cooooo00?o0000ooooooooool0<_oo
ool2o`0000Kooooo0_l00009ooooo`;o00001Oooool5o`0000;ooooo1?l000000ooooooo0000o`00
0006ooooo`;o00000oooool3o`0001Wooooo0_l00006ooooo`;o00000oooool3o`0000_ooooo0_l0
0008ooooo`;o00000oooool2o`000004ooooool0003o0000o`0000;ooooo0ol0000Fooooo`;o0000
3oooool3o`0000Gooooo0_l000001?oooooo0000o`000?l00003ooooo`;o0000FOooool001cooooo
0_l0001=ooooo`Co00000oooool4o`0000Wooooo0_l0000Wooooo`;o00000oooool2o`0001Kooooo
0_l00003ooooo`;o00001oooool2o`0000kooooo0_l00006ooooo`Co00003oooool3o`0000?ooooo
0_l000000ooooooo0000o`00001Oooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00002_oo
ool2o`000003ooooool0003o000000;ooooo1Ol0000@ooooo`;o0000?oooool2o`0000?ooooo0_l0
0003ooooo`;o00001oooool4o`0000cooooo0ol000000ooooooo0000o`000003ooooo`?o00003ooo
ool3o`0000?ooooo0_l000000ooooooo0000o`00001Oooooo`007?ooool00ol0003oooooooooo`0h
ooooo`;o00000_ooool2o`0000Gooooo0ol000000ooooooo0000o`000002ooooo`;o000000?ooooo
o`000?l000003?ooool3o`0002Wooooo1?l00005ooooo`;o00003_ooool2o`0000?ooooo0_l0000;
ooooo`Go00003Oooool2o`000003ooooool0003o000001_ooooo0_l000000ooooooo0000o`00001O
ooooo`007?ooool00ol0003oooooooooo`0looooo`;o000000?oooooo`000?l000000_ooool2o`00
00Wooooo0ol00009ooooo`Go0000:Oooool4o`0000Gooooo0_l0000Cooooo`;o00002oooool3o`00
067ooooo0_l0000`ooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00002?ooool3o`0000;o
oooo0ol00009ooooo`;o00007_ooool2o`0000gooooo0ol000000ooooooo0000o`00000Tooooo`?o
00003_ooool2o`00057ooooo0_l0000`ooooo`007?ooool00ol0003oooooooooo`12ooooo`;o0000
1Oooool3o`0000;ooooo0_l00007ooooo`;o000000?oooooo`000?l000007_ooool2o`0000gooooo
0_l000001?oooooo0000o`000?l0000Booooo`;o00003oooool4o`0000kooooo0_l00017ooooo`?o
00001oooool2o`00033ooooo000Looooo`03o`000?oooooooooo03?ooooo0_l0000=ooooo`;o0000
1Oooool2o`0000?ooooo0ol00005ooooo`?o00006_ooool2o`0000;ooooo0_l000000ooooooo0000
o`000003ooooo`;o00002oooool2o`0000?ooooo0_l0000>ooooo`;o00001?ooool2o`0000?ooooo
0_l00004ooooo`Co00000oooool2o`0005;ooooo0ol0000iooooo`007?ooool00ol0003ooooooooo
o`0cooooo`;o00003Oooool2o`0000Cooooo0ol000000ooooooo0000o`000003o`0000Gooooo0_l0
000Kooooo`;o00000_ooool2o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o00001ooo
ool2o`0000?ooooo0_l0000;ooooo`;o00001oooool>o`0000?ooooo0ol00008ooooo`;o000000Co
ooooo`000?l0003o0000P?ooool001cooooo00?o0000ooooooooool0=Oooool2o`0000[ooooo0_l0
0005ooooo`;o00000_ooool4o`0003?ooooo0ol00006ooooo`;o00004?ooool2o`0000Oooooo3_l0
0003ooooo`;o00002?ooool3o`000004ooooool0003o0000o`0000[ooooo0_l0000Wooooo`;o0000
0oooool2o`0004Kooooo000Looooo`03o`000?oooooooooo03Cooooo0ol0000:ooooo`;o00000ooo
ool2o`0000Cooooo1?l00003ooooo`Co00005oooool3o`0001?ooooo0_l0000Oooooo`co000000Co
ooooo`000?l0003o00003Oooool5o`0000cooooo0_l0000Wooooo`;o000000?oooooo`000?l00000
0_l00003ooooo`;o00003oooool2o`00033ooooo000Looooo`03o`000?oooooooooo03Cooooo0_l0
00000ooooooo0000o`000007ooooo`;o00001?ooool3o`000003ooooool0003o000000Go00000_oo
ool4o`0001Cooooo0_l000001?oooooo0000o`000?l00005ooooo`;o000000Coooooo`000?l0003o
oooo0_l00007ooooo`Go00001?ooool2o`00017ooooo0_l000000ooooooo0000o`00000>o`00017o
oooo0_l0000;ooooo`;o00009oooool9o`0000;ooooo0_l0000?ooooo`;o0000<?ooool001cooooo
00?o0000ooooooooool0<_ooool3o`0000;ooooo0_l00007ooooo`;o00001Oooool>o`0001Gooooo
0ol00009ooooo`;o000000Coooooo`000?l0003ooooo0_l00007ooooo`Ko00000oooool2o`00017o
oooo4ol0000Nooooo`;o00009?ooool2o`000003ooooool0003o000000Co000000Goooooo`000?l0
003o0000ooooo`02o`00047ooooo000Looooo`03o`000?oooooooooo03;ooooo0ol0000;ooooo`;o
00000oooool2o`000003ooooool0003o000000Wo00005oooool2o`0000Wooooo3?l00005ooooo`Go
00002_ooool2o`0000[ooooo4Ol0000Mooooo`;o000000?oooooo`000?l000009?ooool2o`0000Go
oooo1_l000000ooooooo0000o`00000?ooooo`;o0000<?ooool001cooooo00?o0000ooooooooool0
<oooool3o`0000?ooooo0_l00005ooooo`;o00000_ooool3o`000003ooooool0003o000000Ko0000
6Oooool2o`0000[ooooo1ol000000ooooooo0000o`000006o`0000;ooooo1?l0000:ooooo`;o0000
2_oooolAo`0001?ooooo0_l00008ooooo`;o00009oooool2o`0000Gooooo1Ol0000Cooooo`;o0000
<?ooool001cooooo00?o0000ooooooooool0<Oooool2o`000003ooooool0003o000000?ooooo0_l0
0005ooooo`;o00000_ooool2o`000003ooooool0003o000000Go00006oooool2o`0000Oooooo0_l0
00000ooooooo0000o`000002ooooo`co00000_ooool6o`0000Gooooo0_l000000ooooooo0000o`00
0009oooooa7o00005?ooool2o`00037ooooo0_l00005ooooo`;o000000?oooooo`000?l000001?l0
000<ooooo`;o000000?oooooo`000?l00000<?ooool001cooooo00?o0000ooooooooool0<Oooool2
o`0000Kooooo0_l00005ooooo`;o00000_ooool2o`000003ooooool0003o000002?ooooo0_l00004
ooooo`Ko000000?oooooo`000?l000002_l000000ooooooo0000o`000005o`0000Gooooo0_l0000:
oooooa7o00001?ooool3o`0000Wooooo0_l0000Dooooo`;o0000:oooool6o`0000cooooo0_l00000
0ooooooo0000o`00000`ooooo`007?ooool2o`0003cooooo0_l00002ooooo`;o0000:oooool2o`00
00?ooooo2?l000000ooooooo0000o`000003o`000003ooooool0003o000000Wo000000?oooooo`00
0?l000004?ooool?o`0000Gooooo1ol00006ooooo`;o00002_ooool2o`0000Gooooo0_l000000ooo
oooo0000o`00000Zooooo`;o00000_ooool2o`0004;ooooo000Looooo`03o`000?oooooooooo03;o
oooo0_l00005ooooo`Co00000_ooool2o`000003ooooool0003o0000027ooooo0_l00007ooooo`;o
000000?oooooo`000?l000006ol00009ooooo`;o00001?ooool9o`000003ooooool0003o000000Wo
oooo1ol00006ooooo`?o00001Oooool2o`0000;ooooo0_l00004ooooo`?o00001oooool2o`0002Co
oooo0ol000001?oooooo0000o`000?ooool2o`0003oooooo000Looooo`03o`000?oooooooooo033o
oooo1?l00005ooooo`;o00001oooool2o`0000Gooooo0_l0000Iooooo`?o00000oooool2o`000003
ooooool0003o000000Co00000ooooolBo`0000?ooooo1_l00006ooooo`;o00000oooool8o`0001Go
oooo0_l00004ooooo`?o00001Oooool2o`0000Cooooo0_l00002ooooo`;o00002?ooool2o`0001Oo
oooo0_l0000;ooooo`?o00001?ooool2o`0003oooooo000Looooo`03o`000?oooooooooo033ooooo
0_l0000@ooooo`;o00000oooool4o`0001Wooooo0_l00004ooooo`;o000000?oooooo`000?l00000
0ol00004oooooa;o00000oooool6o`0000?ooooo0_l00006ooooo`Go00001oooool2o`0000Kooooo
0_l00007ooooo`;o00001Oooool3o`0000Cooooo0_l00004ooooo`;o00006_ooool3o`0000Gooooo
0_l000000ooooooo0000o`00000:ooooo`?o000000?oooooo`000?l000000_ooool2o`0003oooooo
000Looooo`03o`000?oooooooooo033ooooo1?l00007ooooo`Co00001?ooool3o`000003ooooool0
003o000002?ooooo1ol000001?oooooo0000o`000?oooolCo`0000?ooooo0_l00005ooooo`;o0000
1Oooool6o`0000Oooooo0_l00006ooooo`;o00003_ooool3o`0000?ooooo1_l00004ooooo`;o0000
0_ooool2o`0000Oooooo1Ol00007ooooo`Go00000oooool2o`0000gooooo0ol000000ooooooo0000
o`000013ooooo`007?ooool00ol0003oooooooooo`0booooo`;o00001oooool4o`0000Cooooo1_l0
000Gooooo`;o00001_ooool2o`0000;ooooo2_l00003oooooa7o00000oooool3o`0000_ooooo1_l0
000Aooooo`;o00001_ooool2o`0000Cooooo0_l00003ooooo`Wo00000_ooool2o`0000;ooooo0_l0
0007ooooo`Go00002_ooool2o`0001?ooooo0_l0000Aooooo`;o0000<oooool001cooooo00?o0000
ooooooooool0?Oooool2o`0000Kooooo1?l0000Gooooo`?o00001?ooool4o`000003ooooool0003o
000001co00000oooool3o`0000Oooooo0_l000000ooooooo0000o`000003o`0000Sooooo0_l00009
ooooo`;o00001_ooool2o`0000Cooooo0_l00003ooooo`[o00002?ooool2o`0001_ooooo0_l0000<
ooooo`;o00004?ooool2o`0003?ooooo000Looooo`03o`000?oooooooooo03gooooo0_l00006oooo
o`;o00006_ooool2o`0000Cooooo9?l00002ooooo`;o00002?ooool2o`000003ooooool0003o0000
00?o00002?ooool2o`0000Cooooo0_l0000Hooooo`Co000000?oooooo`000?l000001?l00005oooo
o`?o00006_ooool2o`0000_ooooo0ol0000@ooooo`;o0000<oooool001cooooo00?o0000oooooooo
ool0?Oooool2o`0000Kooooo0_l0000Oooooo`?o00000_oooolQo`0000;ooooo0_l00005ooooo`;o
00000oooool5o`0000gooooo0ol00003ooooo`;o000000?oooooo`000?l000002?ooool4o`000003
ooooool0003o000000?ooooo1Ol000000ooooooo0000o`000003o`0000Cooooo1?l0000Iooooo`;o
00001?ooool2o`0000Cooooo0ol00015ooooo`007?ooool00ol0003oooooooooo`0mooooo`;o0000
9oooool3o`000003ooooool0003o0000023o00000_ooool2o`0000Gooooo0_l00002ooooo`Go0000
0_ooool2o`0000Wooooo1Ol00002ooooo`;o000000Coooooo`000?l0003o00001oooool:o`000003
ooooool0003o000000;o00000oooool4o`0000Gooooo0_l0000Iooooo`;o00000oooool3o`000003
ooooool0003o000000?o00003oooool2o`0003Gooooo000Looooo`03o`000?oooooooooo03?ooooo
0_l00003ooooo`;o00000oooool2o`0000?ooooo0_l0000RooooobKo00000_ooool2o`0000?ooooo
1?l00002ooooo`Go00000_ooool2o`0000Wooooo1Ol00005ooooo`?o00002_ooool2o`0000;ooooo
2_l000000ooooooo0000o`000002o`0000[ooooo0_l0000Booooo`;o00001Oooool3o`000003oooo
ool0003o000000;o00004?ooool2o`0003Gooooo000Looooo`03o`000?oooooooooo03?ooooo0_l0
0003ooooo`;o00000oooool2o`0000?ooooo0_l0000Jooooo`;o00001oooool7o`000003ooooool0
003o000001oo00000oooool4o`0000;ooooo0ol0000<ooooo`;o00002oooool2o`0000Gooooo0_l0
0006ooooo`co000000Coooooo`000?l0003o00000_ooool2o`0000?ooooo0_l00002ooooo`;o0000
1oooool2o`0000;ooooo0_l00005ooooo`;o00001_ooool5o`0004Wooooo000Looooo`03o`000?oo
oooooooo03?ooooo0_l00008ooooo`;o00001_ooool2o`0001Oooooo0_l00003ooooo`?o000000?o
ooooo`000?l000001Ol000000ooooooo0000o`00000Oo`0000Cooooo0ol00002ooooo`;o00003Ooo
ool2o`000003ooooool0003o000000Kooooo0_l00007ooooo`;o00001?oooolCo`000003ooooool0
003o000000Go00002?ooool2o`000003ooooool0003o000000;ooooo0_l0000>ooooo`?o0000B_oo
ool001cooooo00?o0000ooooooooool0<oooool2o`0000Wooooo0_l00005ooooo`;o00007?ooool;
o`000003ooooool0003o000001ko00001_ooool2o`0000;ooooo0_l0000@ooooo`;o00001_ooool2
o`0000Kooooo0_l00004oooooaGo000000?oooooo`000?l000001_l00006ooooo`;o00005Oooool3
o`00013ooooo0_l0000hooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?oo
ool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0?_ooool2o`0001oooooo
0_l00004ooooo`;o000000Coooooo`000?l0003o00001?oooolPo`0000;ooooo0_l00005ooooo`?o
00001oooool2o`0000Oooooo0ol00003ooooo`Co00001_ooool3o`0000;ooooo8Ol0000Gooooo`Co
00004oooool2o`0003Sooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44oooo
o`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0jooooo`;o00008oooool2
o`0000;ooooo1?l00008oooooaoo00000oooool2o`000003ooooool0003o000000;ooooo0ol00007
ooooo`?o00001_ooool3o`0000?ooooo0_l00002ooooo`;o00001OoooolQo`000004ooooool0003o
0000o`0001Gooooo1ol00005ooooo`;o00002_ooool3o`0003Sooooo00000ooooooo410@ooooo`02
ooooo`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo03[ooooo0_l0000Wooooo`;o00000ooooolVo`0000Kooooo0_l00002ooooo`;o00002Ooo
ool3o`0000?ooooo0_l0000:ooooo`?o000000?oooooo`000?l000001_l000000ooooooo0000o`00
000Io`0000;ooooo0_l0000Eooooo`Co000000?oooooo`000?l000000_ooool2o`000003ooooool0
003o000000[ooooo0_l0000iooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09
ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0006Gooooo0_l000000ooooooo0000o`00
000To`0000?ooooo0_l00003ooooo`Co00001oooool2o`000003ooooool0003o000000?ooooo0_l0
000;ooooo`;o000000?oooooo`000?l000000_l00005ooooo`_o000000?oooooo`000?l000002ol0
0004ooooo`?o00004oooool4o`000003ooooool0003o000000;o000000?oooooo`000?l00000B?oo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oEEEEo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0IOooool2o`0000;ooooo1_l000000ooooooo0000o`00
000Ko`0000Cooooo0_l000000ooooooo0000o`000003o`0000Sooooo0_l0000Booooo`;o00000_oo
ool2o`0000?ooooo0_l00002ooooo`[o000000?oooooo`000?l000001?l000000ooooooo0000o`00
0004o`0000Kooooo0_l00002ooooo`Co00003Oooool4o`000003ooooool0003o000000;o0000Booo
ool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08
ooooo`03o`000?oooooooooo03Cooooo0_l0000^ooooo`;o00000oooool6o`000003ooooool0003o
000001_o00000oooool3o`000003ooooool0003o000000;o00002?ooool2o`0000kooooo0ol00002
ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000002oooooa[o00000ooo
ool3o`0000;ooooo1?l000000ooooooo0000o`00000;ooooo`;o00000_ooool3o`0004cooooo0000
1_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003ooooo
ooooo`0dooooo`?o00001oooool2o`0002Cooooo0_l000001?oooooo0000o`000?ooool2o`000004
ooooool0003o0000oooooa_o00001Oooool3o`000003ooooool0003o000000;o00002?ooool2o`00
00Wooooo0_l00003ooooo`?o00000oooool4o`000004ooooool0003o0000oooooako00000_ooool4
o`0000Oooooo0_l00008ooooo`;o000000Coooooo`000?l0003ooooo1?l0001<ooooo`0000Kooooo
onk^k_lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000oooooooo
ool0=Oooool2o`0000Oooooo0_l0000Sooooo`?o000000Goooooo`000?l0003o0000ooooo`0;o`00
0003ooooool0003o000001;o00001oooool5o`0000kooooo0_l00004ooooo`;o00002Oooool2o`00
00?ooooo0_l000000ooooooo0000o`00000Lo`0000;ooooo0_l000000ooooooo0000o`00000@oooo
o`Co00000_ooool3o`0004gooooo000Looooo`03o`000?oooooooooo03Gooooo0_l0000Zooooo`Wo
000000?oooooo`000?l000002Ol000000ooooooo0000o`00000Ao`0000?ooooo0_l00003ooooo`Co
00002Oooool3o`0000;ooooo0ol0000?ooooo`;o00001_ooool3o`000003ooooool0003o000001So
000000Goooooo`000?l0003o0000ooooo`02o`0000;ooooo0_l0000:ooooo`Ko000000Coooooo`00
0?l0003o00003Oooool2o`0003oooooo000Looooo`03o`000?oooooooooo03Gooooo0_l00003oooo
o`Co00008oooool9o`0000?ooooo7?l00004ooooo`;o00000_ooool4o`0000[ooooo1ol00002oooo
o`;o00003_ooool2o`0000Gooooo0ol000000ooooooo0000o`00000Ko`0000Gooooo0_l00006oooo
o`;o00000_ooool5o`0000;ooooo0_l0000>ooooo`;o0000?oooool001cooooo00?o0000oooooooo
ool0=Oooool2o`0000?ooooo1?l00002ooooo`;o00008_ooool5o`0000Cooooo3?l000000ooooooo
0000o`00000:o`0000?ooooo1?l00002ooooo`Go00002?ooool2o`0000Cooooo0_l00002ooooo`Co
00003_ooool2o`0000Kooooo7Ol000001?oooooo0000o`000?l00005ooooo`;o000000Goooooo`00
0?l0003o0000ooooo`05o`0001Kooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0eoooo
o`;o00001Oooool2o`0000;ooooo0ol0000Jooooo`;o00000oooool6o`0000Kooooo2Ol000001?oo
oooo0000o`000?ooool:o`0000?ooooo1Ol000000ooooooo0000o`000003o`0000Wooooo0ol00003
ooooo`;o00000_ooool2o`0001Kooooo0_l000001?oooooo0000o`000?oooolIo`000004ooooool0
003o0000o`0000Gooooo0_l000001?oooooo0000o`000?l00003ooooo`?o00001Oooool2o`00053o
oooo000Looooo`03o`000?oooooooooo03Kooooo0_l00004ooooo`;o00000oooool2o`0001[ooooo
0_l00003ooooo`;o000000?oooooo`000?l000001oooool9o`000003ooooool0003o000000Wo0000
1Oooool4o`0000;ooooo0_l0000=ooooo`;o00000oooool4o`0001Sooooo8Ol00004ooooo`;o0000
1?ooool2o`0000cooooo0ol0000;ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0=_oo
ool2o`0000[ooooo0_l0000Nooooo`;o000000?oooooo`000?l000002?oooolDo`0000Oooooo1_l0
000Cooooo`?o00004oooool4o`0000;ooooo0_l00002ooooo`[o000000?oooooo`000?l000004Ol0
0002ooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000?ooooo0_l0
0002ooooo`;o00002oooool2o`0004;ooooo000Looooo`03o`000?oooooooooo03_ooooo0_l00005
ooooo`;o00007_ooool5o`0000Wooooo1?l00002ooooo`?o00000_ooool7o`0000Cooooo0_l00002
ooooo`Ko00002_ooool2o`0000Oooooo0_l0000Dooooo`Co00001_ooool:o`000003ooooool0003o
000000_o000000?oooooo`000?l000000ol00002ooooo`;o000000?oooooo`000?l000001?ooool5
o`0000?ooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`0kooooo`;o00000oooool2o`00
00;ooooo0_l0000Nooooo`Go00001ooooolBo`0000Cooooo2Ol0000;ooooo`;o00000oooool2o`00
02?ooooo4ol000000ooooooo0000o`000007o`0000Sooooo0_l00002ooooo`?o00000_ooool2o`00
00oooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00000_ooool2o`0001oo
oooo1?l00009oooooa;o00001?ooool5o`0000gooooo0_l000000ooooooo0000o`000002o`0001Wo
oooo0_l00009oooooa7o00000_ooool6o`0000?ooooo1?l00004ooooo`;o00000_ooool2o`000003
ooooool0003o000000Go00002oooool3o`0004Cooooo000Looooo`03o`000?oooooooooo03oooooo
0_l00003ooooo`;o00004_ooool3o`0000gooooo0_l00009ooooo`[o000000?oooooo`000?l00000
1Ol00004ooooo`;o00003Oooool2o`0000?ooooo1?l0000Iooooo`;o00002Oooool2o`0000;ooooo
3?l00003ooooo`Co00001Oooool8o`0000Oooooo0_l00002ooooo`?o00002oooool2o`0004Gooooo
000Looooo`03o`000?oooooooooo03Oooooo0_l00006ooooo`;o00001Oooool3o`0000oooooo0ol0
000:ooooo`;o000000?oooooo`000?l000002_oooolGo`0000gooooo1?l00003ooooo`;o0000:?oo
ool9o`0000;ooooo2?l00003ooooo`[o00001Oooool2o`0005Wooooo000Looooo`;o0000>?ooool2
o`0000gooooo1?l0000?ooooo`;o000000Coooooo`000?l0003o00001_ooool4o`0000kooooo0_l0
00000ooooooo0000o`00000=o`00017ooooo0ol0000Tooooo`;o00001_ooool6o`000005ooooool0
003o0000o`000?ooool01ol00004ooooo`Go00002_ooool2o`0000kooooo0_l00019ooooo`007?oo
ool00ol0003oooooooooo`18ooooo`;o00003_ooool3o`000004ooooool0003o0000o`0000Cooooo
1ol0000Aooooo`Wo000000?oooooo`000?l000004oooool3o`0000;ooooo0ol0000Oooooo`;o0000
2Oooool?o`0000gooooo0_l00002ooooo`;o00004?ooool2o`0004Wooooo000Looooo`03o`000?oo
oooooooo04Wooooo0_l0000=ooooo`;o00002Oooool3o`000004ooooool0003o0000o`00033ooooo
0ol00002ooooo`?o00008Oooool2o`0000Oooooo2Ol000000ooooooo0000o`000005o`0000[ooooo
1ol0000=ooooo`?o0000Boooool001cooooo00?o0000ooooooooool0@?ooool2o`0000Kooooo0ol0
000Hooooo`Co0000:Oooool2o`0000Cooooo0_l00002ooooo`;o00005?ooool2o`00017ooooo0_l0
000>ooooo`;o00000_ooool6o`0000?ooooo0_l00004ooooo`Oo00003_ooool3o`0004_ooooo000L
ooooo`03o`000?oooooooooo043ooooo0_l00006ooooo`;o00006Oooool5o`0002Sooooo0ol00003
ooooo`;o00005_ooool8o`0002[ooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l0
000<ooooo`?o0000COooool001cooooo00?o0000ooooooooool0I?ooool4o`0002Wooooo0_l0000I
ooooo`_o00003?ooool2o`0000Gooooo0_l00007ooooo`;o00003Oooool3o`0001;ooooo1Ol0001=
ooooo`007?ooool00ol0003oooooooooo`1;ooooo`?o00005_ooool3o`0002Sooooo0_l00003oooo
o`Co00005?ooool2o`0000Cooooo1Ol00003ooooo`;o00001oooool2o`0000Gooooo1?l00005oooo
o`;o00003Oooool2o`0000;ooooo0_l0000>ooooo`?o0000D?ooool001cooooo00?o0000oooooooo
ool0Boooool4o`0001Gooooo1?l0000Wooooo`;o00000oooool4o`000003ooooool0003o0000017o
oooo0_l000000ooooooo0000o`000009ooooo`;o000000?oooooo`000?l000003Oooool2o`0000Co
oooo0_l00002ooooo`;o00000_ooool2o`0000[ooooo0_l0000>ooooo`;o0000DOooool001cooooo
00?o0000ooooooooool0A?ooool2o`0000Oooooo0_l0000<ooooo`;o00002Oooool4o`0002Gooooo
0_l00003ooooo`;o000000?oooooo`000?l000000_l0000@ooooo`?o000000?oooooo`000?l00000
2_ooool4o`00013ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00000_ooool2o`0001Ko
oooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00005Oooool2o`0000_ooooo
0_l0000Rooooo`;o000000?oooooo`000?l000001?ooool4o`0001;ooooo0_l0000>ooooo`;o0000
00?oooooo`000?l000003oooool2o`0000;ooooo0_l0000:ooooo`;o00003oooool4o`0005Gooooo
000Looooo`03o`000?oooooooooo04Cooooo0ol000000ooooooo0000o`00000Pooooo`;o00008?oo
ool2o`0000Oooooo0_l0000Fooooo`;o00003oooool2o`0000?ooooo0_l0000:ooooo`?o00003Ooo
ool2o`0000kooooo1Ol0001Eooooo`007?ooool00ol0003oooooooooo`15ooooo`;o000000?ooooo
o`000?l000006?ooool2o`0000Kooooo0ol0000>ooooo`;o00001Oooool2o`0000gooooo0_l0000I
ooooo`?o00005?ooool3o`0000[ooooo0_l0000Mooooo`;o0000F?ooool001cooooo00?o0000oooo
ooooool0BOooool2o`0001Gooooo1?l00007ooooo`;o00003_ooool2o`0000Gooooo0_l00005oooo
o`;o00001_ooool2o`0001Wooooo1?l00008ooooo`;o00002Oooool5o`00027ooooo1Ol0001Koooo
o`007?ooool00ol0003oooooooooo`10ooooo`;o00001oooool2o`0001Gooooo0_l0000Jooooo`;o
00002oooool3o`0002;ooooo0_l00008ooooo`;o000000Coooooo`000?l0003o00001_ooool5o`00
01gooooo2?l0001Kooooo`007?ooool00ol0003oooooooooo`10ooooo`;o0000;_ooool2o`0000[o
oooo0_l0000<ooooo`;o0000;oooool3o`0000Wooooo0ol0000Iooooo`Wo0000GOooool001cooooo
00?o0000ooooooooool0L?ooool2o`0000Sooooo1?l0000Aooooo`?o0000=Oooool7o`00013ooooo
2_l0001Qooooo`007?ooool2o`0004;ooooo0_l0000Kooooo`;o00004?ooool4o`0000Kooooo1?l0
000Aooooo`Go0000;Oooool2o`0000Cooooo0_l000000ooooooo0000o`000008o`0000Kooooo0_l0
0002ooooo`Go0000I_ooool001cooooo00?o0000ooooooooool0@Oooool2o`0000Gooooo0_l00002
ooooo`;o00004?ooool2o`00013ooooo1Ol0000Looooo`?o0000;Oooool2o`0000Oooooo0ol00000
0ooooooo0000o`000004o`0000Cooooo1?l0001]ooooo`007?ooool00ol0003oooooooooo`18oooo
o`;o00000_ooool2o`0002Cooooo0ol0000<ooooo`;o0000Aoooool2o`0000Kooooo0_l00004oooo
o`;o0000Koooool001cooooo00?o0000ooooooooool0COooool2o`000003ooooool0003o000001Ko
oooo0_l0000@ooooo`;o000000?oooooo`000?l000000_ooool2o`00037ooooo0ol0000;ooooo`;o
00001_ooool2o`0003Wooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o0000
00?oooooo`000?l000005_ooool2o`00013ooooo0_l000000ooooooo0000o`00000<ooooo`;o0000
9_ooool4o`0000Oooooo1_l00006ooooo`;o0000>Oooool2o`0004;ooooo000Looooo`03o`000?oo
oooooooo053ooooo0_l0000Oooooo`;o00006?ooool2o`0002Kooooo0ol00008ooooo`Co00004_oo
ool2o`0000oooooo0_l0001Rooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00000_ooool2
o`0001oooooo0_l0000Iooooo`;o00008_ooool3o`0000cooooo0_l0000Aooooo`Co00003oooool2
o`0006;ooooo000Looooo`03o`000?oooooooooo04cooooo0_l00002ooooo`;o00004_ooool2o`00
02;ooooo0_l000001?oooooo0000o`000?l0000Rooooo`?o00002Oooool2o`000003ooooool0003o
0000017ooooo0_l00006ooooo`;o0000KOooool001cooooo00?o0000ooooooooool0E_ooool4o`00
00[ooooo0_l00002ooooo`;o00000oooool3o`0001Kooooo1ol0000Zooooo`Co000000Coooooo`00
0?l0003ooooo1_l00003ooooo`;o00001?ooool2o`0000[ooooo0_l000000ooooooo0000o`000002
ooooo`;o00000_ooool2o`0006;ooooo000Looooo`03o`000?oooooooooo05Kooooo1?l0000;oooo
o`;o000000?oooooo`000?l000000_l000001?oooooo0000o`000?l0000Fooooo`;o000000?ooooo
o`000?l00000;?ooool4o`000004ooooool0003o0000ooooo`Ko00000oooool2o`0000?ooooo0ol0
0002ooooo`;o00002Oooool2o`0000;ooooo0_l00002ooooo`;o00006?ooool2o`0004Sooooo000L
ooooo`03o`000?oooooooooo05Gooooo0ol00005ooooo`;o00001_ooool2o`0000?ooooo0_l0001@
ooooo`;o00002_ooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`0002Wooooo1?l00018
ooooo`007?ooool00ol0003oooooooooo`1Eooooo`;o00001?ooool4o`0001?ooooo0_l0000Doooo
o`Co000000?oooooo`000?l000000_l0000Wooooo`Co00003?ooool2o`0000Kooooo0_l0000:oooo
o`;o00007oooool3o`0004Wooooo000Looooo`03o`000?oooooooooo05_ooooo1Ol0000Booooo`;o
00004oooool5o`000003ooooool0003o000000;o00009oooool4o`000003ooooool0003o000000Wo
oooo0_l0000Booooo`;o0000Joooool001cooooo00?o0000ooooooooool0F?ooool3o`000003oooo
ool0003o000000?o00001Oooool2o`0001oooooo0_l00002ooooo`;o00002?ooool2o`00023ooooo
1?l00002ooooo`;o00000oooool2o`0000Kooooo0_l00007ooooo`?o00000oooool2o`0001cooooo
0_l0001@ooooo`007?ooool00ol0003oooooooooo`1Hooooo`?o00000oooool3o`0000Gooooo0_l0
000>ooooo`;o00004oooool2o`0000Sooooo0ol0000Oooooo`;o00001?ooool2o`0000;ooooo1?l0
0005ooooo`;o00001oooool3o`0000;ooooo0ol0000Looooo`;o0000D?ooool001cooooo00?o0000
ooooooooool0G_ooool2o`00017ooooo0_l00003ooooo`;o00001Oooool2o`0001Oooooo1?l0000W
ooooo`Ko00001?ooool3o`0000[ooooo0_l00004ooooo`;o00005_ooool2o`00057ooooo000Loooo
o`;o0000F?ooool3o`000003ooooool0003o000001Cooooo0_l000000ooooooo0000o`000007oooo
o`;o000000?oooooo`000?l000005_ooool2o`0002?ooooo2_l00004ooooo`?o00000oooool4o`00
00Wooooo0_l0000Fooooo`;o0000DOooool001cooooo00?o0000ooooooooool0Eoooool3o`000003
ooooool0003o000001Cooooo0_l000000ooooooo0000o`000005ooooo`;o00000oooool5o`0000ko
oooo0_l0000Looooo`;o00002Oooool5o`0000;ooooo0ol00005ooooo`;o00000oooool5o`0007Co
oooo000Looooo`03o`000?oooooooooo063ooooo0_l00002ooooo`Co00003_ooool2o`0000?ooooo
0_l00005ooooo`Co00003Oooool2o`0000Sooooo0_l0000Booooo`;o00002Oooool6o`0000;ooooo
0_l00005ooooo`;o000000?oooooo`000?l000000_l0001gooooo`007?ooool00ol0003ooooooooo
o`1Pooooo`;o00000_ooool4o`0000kooooo0_l0000<ooooo`Co00002Oooool2o`0000[ooooo0_l0
000Booooo`?o00001_ooool9o`0000Wooooo1?l0001iooooo`007?ooool00ol0003oooooooooo`1L
ooooo`;o00001Oooool2o`0001;ooooo0_l00006ooooo`;o000000?oooooo`000?l000001ol00005
ooooo`Co00002oooool2o`00013ooooo0ol00005ooooo`?o00000oooool<o`000004ooooool0003o
0000o`0007[ooooo000Looooo`03o`000?oooooooooo05cooooo0_l00003ooooo`Ko00004?ooool2
o`0000Kooooo0_l000001Ooooooo0000o`000?l0003ooooo00So00000_ooool4o`0000Kooooo0_l0
0003ooooo`;o00006?ooool2o`0000Kooooo2_l0001nooooo`007?ooool00ol0003oooooooooo`1O
ooooo`So00002oooool2o`0000Sooooo0_l00005ooooo`;o000000?oooooo`000?l000001ol00002
ooooo`Ko00000oooool3o`0000;ooooo0_l0000Eooooo`;o0000TOooool001cooooo00?o0000oooo
ooooool0Goooool3o`000003ooooool0003o000000Kooooo0_l00005ooooo`?o00001oooool2o`00
00Sooooo0_l00003ooooo`ko00000_ooool2o`0000;ooooo1?l0000Cooooo`;o0000TOooool001co
oooo00?o0000ooooooooool0H?ooool2o`0000Wooooo0_l00005ooooo`?o00002Oooool3o`0000[o
oooo0_l000001?oooooo0000o`000?l00003ooooo`Go000000?oooooo`000?l000001?ooool3o`00
01?ooooo0_l00002ooooo`;o0000;?ooool2o`0005oooooo000Looooo`03o`000?oooooooooo06Ko
oooo0_l00006ooooo`Ko00002?ooool5o`0000Wooooo0ol000000ooooooo0000o`000005ooooo`?o
00000_ooool2o`0001[ooooo0_l00002ooooo`;o0000:oooool3o`0005oooooo000Looooo`03o`00
0?oooooooooo06Kooooo0_l00002ooooo`;o00000_ooool5o`0000;ooooo0_l00005ooooo`Co0000
00?oooooo`000?l000001oooool6o`0000Gooooo0ol00002ooooo`Co00004Oooool2o`0000Kooooo
0_l0000/ooooo`Co0000H?ooool001cooooo00?o0000ooooooooool0J_ooool3o`0000Oooooo0ol0
0007ooooo`;o000000?oooooo`000?l000000_l00007ooooo`Go00001Oooool2o`0000;ooooo1?l0
000Aooooo`?o00001Oooool2o`0002cooooo0_l0001Rooooo`007?ooool00ol0003oooooooooo`1X
ooooo`;o000000?oooooo`000?l000001oooool2o`000003ooooool0003o000000[ooooo0_l0000:
ooooo`;o000000Coooooo`000?l0003o00006oooool2o`0002kooooo1?l0001Uooooo`007?ooool0
0ol0003oooooooooo`1Xooooo`?o00002?ooool2o`000004ooooool0003o0000o`0001Wooooo0ol0
000Pooooo`;o0000:Oooool4o`0006Gooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Yooooo`;o
00002?ooool2o`000003ooooool0003o000000oooooo0_l0000[ooooo`?o0000T_ooool00006oooo
oomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06
ooooo`03o`000?oooooooooo06Wooooo0_l0000=ooooo`;o00003Oooool4o`0000;ooooo0_l0000G
ooooo`;o00003?ooool3o`0000Cooooo0_l0002<ooooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`1e
ooooo`;o000000?oooooo`000?l000000_l0000;ooooo`So00005oooool2o`0000cooooo0ol00003
ooooo`?o00007?ooool3o`0006gooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000MOooool2o`0000?ooooo0_l0000;
ooooo`Ko000000?oooooo`000?l000009?ooool3o`0000?ooooo0_l0000Mooooo`?o0000KOooool0
0003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Oo<c<co0000o`000?l0003o
c<c<00Kooooo00?o0000ooooooooool0Koooool6o`0000Gooooo0_l0000=ooooo`;o00000oooool2
o`0000Gooooo0_l0000Mooooo`;o00007oooool2o`0007;ooooo00000ooooooo410@ooooo`02oooo
o`03oa0@4?oooooooooo00Wooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooo
oooo06oooooo1_l00005ooooo`;o00006Oooool2o`0000?ooooo0_l00002ooooo`;o00001oooool2
o`0002Wooooo1Ol0001booooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj
^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`1aooooo`Go00001oooool2o`0000?ooooo
0_l0000=ooooo`;o00001oooool2o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0000Wooooo
0_l0000Nooooo`?o0000M?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo
410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0Loooool3o`0000Oooooo0_l00003oooo
o`;o00003Oooool4o`0000Wooooo0_l00002ooooo`;o00003?ooool4o`0001Wooooo0_l000000ooo
oooo0000o`00001gooooo`007?ooool00ol0003oooooooooo`1kooooo`;o00002Oooool2o`0000_o
oooo0_l00004ooooo`;o00000_ooool2o`00017ooooo0_l000000ooooooo0000o`00000Hooooo`;o
000000?oooooo`000?l00000Moooool001cooooo00?o0000ooooooooool0N_ooool3o`0000Oooooo
1?l0000Aooooo`;o00000_ooool7o`0000Sooooo0_l00002ooooo`;o000000?oooooo`000?l00000
5oooool2o`0007_ooooo000Looooo`03o`000?oooooooooo07[ooooo0_l000001?oooooo0000o`00
0?ooool6o`0000Kooooo0_l0000@ooooo`Ko000000?oooooo`000?l000000ol00002ooooo`Co0000
6_ooool4o`0007_ooooo000Looooo`03o`000?oooooooooo07gooooo0_l000000ooooooo0000o`00
0003o`0000Oooooo0_l0000Gooooo`Go00001?ooool2o`0001[ooooo0ol0001looooo`007?ooool0
0ol0003oooooooooo`22ooooo`Co00003?ooool2o`0003?ooooo0_l00020ooooo`007?ooool00ol0
003oooooooooo`24ooooo`;o00002_ooool4o`000003ooooool0003o0000033ooooo0_l00020oooo
o`007?ooool00ol0003oooooooooo`24ooooo`;o00002_ooool2o`0000?ooooo0_l0002booooo`00
7?ooool00ol0003oooooooooo`24ooooo`;o00006_ooool2o`000003ooooool0003o00000:Cooooo
000Looooo`03o`000?oooooooooo0:3ooooo0_l000000ooooooo0000o`00000Nooooo`;o0000Q?oo
ool001cooooo00?o0000ooooooooool0S?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000B
ooooo`;o00005Oooool3o`0000;ooooo0_l00024ooooo`007?ooool00ol0003oooooooooo`2<oooo
o`;o00000_ooool2o`000003ooooool0003o000001;ooooo1Ol0000Booooo`?o0000R?ooool001co
oooo0_l0002Dooooo`;o00004oooool5o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o
00000oooool4o`0008[ooooo000Looooo`03o`000?oooooooooo09gooooo0_l00003ooooo`?o0000
1?ooool4o`000003ooooool0003o000000;ooooo1_l00003ooooo`Co0000R_ooool001cooooo00?o
0000ooooooooool0U_ooool2o`0000Gooooo0_l00003ooooo`?o00001Oooool2o`0000Sooooo0ol0
002Booooo`007?ooool00ol0003oooooooooo`2Fooooo`;o00006Oooool5o`0009?ooooo000Loooo
o`03o`000?oooooooooo0;7ooooo1Ol0002Cooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooo
oom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Booooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooood[ooooo
000Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool0
0ol0003oooooooooo`05ooooo`?o0000oooooom:ooooo`005?ooool00ol0003oooooooooo`3ooooo
oe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0
oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Booooo`03oeEEEOmVIVKo
00000?ooooooE?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Gooooo00Co
410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0Eooooo`05oiRHV?l@413o0000oc8b<_o<
c<`01?ooool4o`000008oa0@4?ooooooooooolc<c?lQ8B7o0000ob4Q8Oo<c<b@ooooo`00Y_ooool0
1Ol0003ooooooooooooooooo000000Wooooo1_l00009ooooo`05oa0@4?nj^[[oooooogMgMolb<S80
1_ooool00ol0003oooooooooo`02ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40T?ooool00:Kooooo
00Go0000ooooooooooooooooo`00000Looooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo0000093ooooo002Vooooo`05o`000?oooooooooooooo
ool000002Oooool6o`0000cooooo00?oZJVYoa0@4?ooool01Oooool00ol0003oooooooooo`02oooo
o`05oc8b<_nHV9SooooooiRHV?lb<S80T?ooool00:Kooooo00Go0000ohN7QoooooooZJVYo`00000J
ooooo`03oa0@4?l0003o^[Zj00Kooooo00?o0000ooooooooool00_ooool01Oo<c<co0000o`000?l0
003oc<c<093ooooo002Uooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool06Oooool0
0onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo00;ooooo00Go410@okZj^_oooooo^[Zjoa0@
402@ooooo`00`oooool01Ol@413oV9RHoooooonj^[[o000000Kooooo00?o0000ooooooooool00_oo
ool01Ol0003o^[Zjoooooonj^[[o0000093ooooo0033ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0
1?ooool00omEEEGoIVIVo`000004ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0T?ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(324) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.62836 .59875 Mdot
.63709 .63443 Mdot
.51734 .29926 Mdot
.42109 .56716 Mdot
.45634 .30216 Mdot
.55881 .33103 Mdot
.66831 .45061 Mdot
.66402 .44695 Mdot
.52998 .30642 Mdot
.36847 .76049 Mdot
.7094 .44322 Mdot
.41758 .60253 Mdot
.68318 .44252 Mdot
.39231 .57101 Mdot
.36127 .45618 Mdot
.37435 .52714 Mdot
.59869 .60689 Mdot
.39711 .29872 Mdot
.37504 .52904 Mdot
.56133 .34695 Mdot
.34894 .67267 Mdot
.40504 .5669 Mdot
.65823 .65067 Mdot
.39464 .5681 Mdot
.34648 .60561 Mdot
.63339 .61964 Mdot
.63391 .60224 Mdot
.36837 .60868 Mdot
.40687 .53815 Mdot
.69844 .43256 Mdot
.49294 .444 Mdot
.19004 .55038 Mdot
.32384 .57228 Mdot
.52699 .71239 Mdot
.68433 .42243 Mdot
.6502 .38971 Mdot
.58742 .31573 Mdot
.65196 .43649 Mdot
.71257 .43295 Mdot
.71505 .44521 Mdot
.71313 .44806 Mdot
.63275 .61678 Mdot
.65088 .46116 Mdot
.65682 .32845 Mdot
.38847 .55916 Mdot
.58027 .69431 Mdot
.63162 .32506 Mdot
.34879 .57333 Mdot
.62646 .65727 Mdot
.53478 .33141 Mdot
.31157 .36185 Mdot
.65841 .45762 Mdot
.50537 .54229 Mdot
.88063 .49408 Mdot
.67372 .44001 Mdot
.34829 .55363 Mdot
.55051 .29894 Mdot
.37345 .59161 Mdot
.39976 .60742 Mdot
.50628 .68468 Mdot
.38471 .59716 Mdot
.44095 .2908 Mdot
.67271 .6371 Mdot
.57164 .35679 Mdot
.52782 .30379 Mdot
.65174 .44901 Mdot
.60428 .65763 Mdot
.69485 .43673 Mdot
.41493 .54493 Mdot
.54134 .33479 Mdot
.37096 .54334 Mdot
.70858 .4441 Mdot
.64722 .61662 Mdot
.40826 .55829 Mdot
.76461 .62819 Mdot
.62124 .45375 Mdot
.50052 .28501 Mdot
.48947 .62279 Mdot
.43698 .35036 Mdot
.4189 .44081 Mdot
.40801 .56051 Mdot
.75293 .30025 Mdot
.34461 .43598 Mdot
.62707 .65315 Mdot
.51468 .5327 Mdot
.75466 .50534 Mdot
.34246 .5872 Mdot
.49882 .44546 Mdot
.4448 .54033 Mdot
.40242 .24195 Mdot
.54389 .30627 Mdot
.60782 .64252 Mdot
.39662 .55602 Mdot
.4121 .54954 Mdot
.46797 .80891 Mdot
.40638 .53534 Mdot
.38822 .61208 Mdot
.5722 .50292 Mdot
.68433 .47252 Mdot
.3533 .63025 Mdot
.49564 .37186 Mdot
.5442 .54287 Mdot
.34677 .5582 Mdot
.5571 .31077 Mdot
.67175 .64207 Mdot
.32995 .56475 Mdot
.69402 .44637 Mdot
.40096 .55983 Mdot
.63943 .45847 Mdot
.63244 .65996 Mdot
.39225 .61325 Mdot
.42591 .2792 Mdot
.48699 .60552 Mdot
.65505 .63126 Mdot
.57538 .76953 Mdot
.40185 .58888 Mdot
.36564 .58722 Mdot
.6395 .63345 Mdot
.57241 .34307 Mdot
.70907 .27698 Mdot
.64408 .61544 Mdot
.71488 .4487 Mdot
.59496 .61982 Mdot
.48818 .56616 Mdot
.57543 .34384 Mdot
.54094 .55509 Mdot
.53388 .55697 Mdot
.24275 .446 Mdot
.42052 .57366 Mdot
.30103 .64811 Mdot
.55837 .31972 Mdot
.64874 .62878 Mdot
.68667 .43345 Mdot
.42684 .53869 Mdot
.61617 .6208 Mdot
.66538 .45246 Mdot
.43467 .26295 Mdot
.40055 .31037 Mdot
.65162 .65122 Mdot
.59685 .77487 Mdot
.71917 .41365 Mdot
.67645 .4775 Mdot
.30969 .36508 Mdot
.62783 .65329 Mdot
.42477 .29766 Mdot
.6838 .45706 Mdot
.27426 .28106 Mdot
.35181 .61436 Mdot
.28674 .39472 Mdot
.76597 .32472 Mdot
.31234 .3614 Mdot
.32728 .67921 Mdot
.41972 .28529 Mdot
.66505 .45314 Mdot
.35835 .55637 Mdot
.62283 .63991 Mdot
.61928 .61909 Mdot
.38289 .54142 Mdot
.32942 .59669 Mdot
.38176 .57616 Mdot
.32492 .57673 Mdot
.56569 .48521 Mdot
.39583 .55749 Mdot
.70725 .71672 Mdot
.61525 .63642 Mdot
.32962 .59025 Mdot
.5841 .3202 Mdot
.29776 .60501 Mdot
.65134 .45766 Mdot
.41731 .59067 Mdot
.33822 .60416 Mdot
.43842 .57515 Mdot
.71551 .45048 Mdot
.76786 .64223 Mdot
.41376 .33749 Mdot
.71807 .42827 Mdot
.758 .41289 Mdot
.57149 .31884 Mdot
.36611 .60025 Mdot
.40921 .29128 Mdot
.36714 .63678 Mdot
.39891 .54932 Mdot
.31682 .35497 Mdot
.39072 .60853 Mdot
.31742 .67464 Mdot
.36175 .51355 Mdot
.75266 .49597 Mdot
.70486 .69253 Mdot
.41979 .56237 Mdot
.38175 .74253 Mdot
.29698 .39037 Mdot
.6102 .4104 Mdot
.68657 .43163 Mdot
.56095 .33806 Mdot
.56699 .34175 Mdot
.68364 .41148 Mdot
.56116 .74238 Mdot
.34558 .7465 Mdot
.43034 .55155 Mdot
.53842 .5409 Mdot
.58992 .62385 Mdot
.42169 .28586 Mdot
.65133 .64592 Mdot
.73428 .27527 Mdot
.44149 .43094 Mdot
.46849 .46226 Mdot
.49101 .32329 Mdot
.53205 .33095 Mdot
.53845 .54583 Mdot
.42129 .30085 Mdot
.37437 .57176 Mdot
.63314 .65912 Mdot
.30078 .38359 Mdot
.40622 .63162 Mdot
.33198 .79279 Mdot
.63045 .60292 Mdot
.24955 .49616 Mdot
.6758 .44176 Mdot
.55968 .28778 Mdot
.34191 .58804 Mdot
.3955 .58398 Mdot
.63672 .66361 Mdot
.35609 .56678 Mdot
.42917 .46897 Mdot
.3505 .61014 Mdot
.58145 .35451 Mdot
.40139 .32734 Mdot
.71351 .4159 Mdot
.48632 .32119 Mdot
.65433 .62609 Mdot
.78758 .67161 Mdot
.56947 .3046 Mdot
.29488 .57647 Mdot
.70569 .44766 Mdot
.43632 .26515 Mdot
.56116 .30297 Mdot
.43725 .31422 Mdot
.41874 .59317 Mdot
.58287 .30624 Mdot
.43784 .28468 Mdot
.48282 .47509 Mdot
.32622 .57625 Mdot
.22475 .42978 Mdot
.6708 .46102 Mdot
.59986 .62908 Mdot
.38373 .5477 Mdot
.51046 .53802 Mdot
.34312 .61977 Mdot
.2732 .46306 Mdot
.51415 .54818 Mdot
.54917 .5435 Mdot
.38865 .42492 Mdot
.41013 .26758 Mdot
.8088 .4986 Mdot
.51066 .45008 Mdot
.59954 .60565 Mdot
.41129 .55186 Mdot
.77064 .44001 Mdot
.66552 .4585 Mdot
.37351 .57949 Mdot
.77834 .46787 Mdot
.68017 .45769 Mdot
.36772 .586 Mdot
.70686 .43355 Mdot
.61707 .62991 Mdot
.40062 .45852 Mdot
.61088 .59753 Mdot
.38545 .55437 Mdot
.70789 .43592 Mdot
.56789 .33882 Mdot
.63176 .61947 Mdot
.40382 .56204 Mdot
.41221 .5895 Mdot
.52976 .5366 Mdot
.35076 .61235 Mdot
.64204 .5211 Mdot
.34687 .5766 Mdot
.51657 .28957 Mdot
.40717 .53653 Mdot
.42918 .38164 Mdot
.39718 .23365 Mdot
.64261 .65731 Mdot
.51432 .54769 Mdot
.55594 .29997 Mdot
.44939 .47875 Mdot
.23662 .50278 Mdot
.39235 .56146 Mdot
.51938 .54635 Mdot
.25037 .46419 Mdot
.65493 .46375 Mdot
.44408 .53747 Mdot
.48587 .28034 Mdot
.54542 .30771 Mdot
.54006 .54378 Mdot
.38931 .63384 Mdot
.58198 .62452 Mdot
.37929 .52926 Mdot
.5808 .30649 Mdot
.60665 .60328 Mdot
.38622 .53283 Mdot
.61754 .42175 Mdot
.51557 .53441 Mdot
.67759 .47577 Mdot
.55959 .50216 Mdot
.35975 .5859 Mdot
.53912 .33196 Mdot
.62711 .61303 Mdot
.66925 .44043 Mdot
.65385 .62788 Mdot
.32346 .36771 Mdot
.2568 .47555 Mdot
.61007 .68776 Mdot
.42232 .25711 Mdot
.23626 .31284 Mdot
.72001 .43009 Mdot
.35244 .63236 Mdot
.59216 .36065 Mdot
.69853 .66026 Mdot
.55417 .30912 Mdot
.6125 .76953 Mdot
.5459 .30286 Mdot
.35827 .54472 Mdot
.54562 .32824 Mdot
.46641 .817 Mdot
.38992 .60526 Mdot
.52577 .30105 Mdot
.55709 .46694 Mdot
.39729 .60227 Mdot
.61532 .62013 Mdot
.20624 .61108 Mdot
.54702 .72651 Mdot
.55054 .7371 Mdot
.55549 .29583 Mdot
.626 .76635 Mdot
.3621 .6074 Mdot
.42863 .53611 Mdot
.62487 .63557 Mdot
.33753 .6173 Mdot
.40175 .28593 Mdot
.40568 .31099 Mdot
.28995 .31973 Mdot
.21334 .55302 Mdot
.56032 .75504 Mdot
.62325 .6204 Mdot
.43167 .33384 Mdot
.7586 .63613 Mdot
.5141 .53516 Mdot
.6637 .44767 Mdot
.79424 .6052 Mdot
.44525 .54638 Mdot
.56418 .53492 Mdot
.42446 .46837 Mdot
.60342 .61505 Mdot
.56419 .59987 Mdot
.6674 .44201 Mdot
.54802 .73784 Mdot
.32867 .72641 Mdot
.38029 .57569 Mdot
.66914 .46663 Mdot
.3405 .61643 Mdot
.49957 .44795 Mdot
.2304 .45544 Mdot
.61733 .24915 Mdot
.38449 .55605 Mdot
.79495 .58543 Mdot
.39115 .5482 Mdot
.25115 .43208 Mdot
.37238 .57259 Mdot
.61887 .61275 Mdot
.44147 .57751 Mdot
.51442 .45593 Mdot
.30149 .2277 Mdot
.43652 .42484 Mdot
.42898 .31505 Mdot
.39462 .57251 Mdot
.38337 .58462 Mdot
.44382 .29621 Mdot
.60278 .62758 Mdot
.39271 .54459 Mdot
.82177 .49972 Mdot
.40018 .55668 Mdot
.65347 .44663 Mdot
.30402 .44421 Mdot
.19414 .532 Mdot
.35392 .60137 Mdot
.58276 .62718 Mdot
.67754 .4769 Mdot
.70013 .45407 Mdot
.47453 .58192 Mdot
.66645 .46062 Mdot
.35813 .55879 Mdot
.30384 .44302 Mdot
.62527 .67291 Mdot
.47197 .58146 Mdot
.60525 .61517 Mdot
.44807 .17387 Mdot
.66946 .45736 Mdot
.5139 .53927 Mdot
.57634 .75196 Mdot
.6857 .45027 Mdot
.38366 .31134 Mdot
.44293 .57437 Mdot
.43316 .62051 Mdot
.60053 .5932 Mdot
.54023 .332 Mdot
.53183 .54995 Mdot
.6723 .44025 Mdot
.38997 .56036 Mdot
.33544 .57462 Mdot
.66706 .46243 Mdot
.4329 .6772 Mdot
.49434 .44318 Mdot
.38796 .5527 Mdot
.60984 .62534 Mdot
.64663 .6253 Mdot
.38175 .52174 Mdot
.39059 .54726 Mdot
.56267 .33427 Mdot
.51915 .54682 Mdot
.52118 .55012 Mdot
.54446 .55589 Mdot
.55857 .29185 Mdot
.23963 .3017 Mdot
.66825 .4785 Mdot
.19122 .54472 Mdot
.74766 .59223 Mdot
.4799 .57121 Mdot
.58259 .33364 Mdot
.39601 .58804 Mdot
.34276 .56998 Mdot
.70202 .43138 Mdot
.2116 .3878 Mdot
.4306 .53887 Mdot
.61449 .5982 Mdot
.66253 .462 Mdot
.34759 .61926 Mdot
.73723 .4903 Mdot
.41884 .27342 Mdot
.56604 .76198 Mdot
.6606 .45799 Mdot
.6382 .66927 Mdot
.66029 .45788 Mdot
.38295 .58228 Mdot
.38206 .63452 Mdot
.60618 .61047 Mdot
.45102 .30662 Mdot
.39042 .54131 Mdot
.36783 .57877 Mdot
.56222 .38092 Mdot
.7656 .62455 Mdot
.46061 .29572 Mdot
.35196 .55779 Mdot
.42438 .62819 Mdot
.45009 .30572 Mdot
.36686 .55553 Mdot
.39108 .53498 Mdot
.30073 .64862 Mdot
.64609 .45314 Mdot
.44608 .27141 Mdot
.27415 .2531 Mdot
.62991 .602 Mdot
.6397 .51939 Mdot
.54607 .54883 Mdot
.71952 .43373 Mdot
.41562 .47215 Mdot
.52724 .54275 Mdot
.76896 .56641 Mdot
.68071 .80309 Mdot
.52983 .54878 Mdot
.59218 .30915 Mdot
.49717 .80946 Mdot
.39294 .53592 Mdot
.38257 .55264 Mdot
.40324 .28225 Mdot
.64047 .64262 Mdot
.71145 .68942 Mdot
.71735 .42896 Mdot
.40866 .57687 Mdot
.64663 .61106 Mdot
.75618 .49714 Mdot
.53173 .54032 Mdot
.4095 .28382 Mdot
.45137 .28812 Mdot
.38173 .54988 Mdot
.23756 .48446 Mdot
.62828 .61792 Mdot
.40366 .56204 Mdot
.36393 .5864 Mdot
.59378 .32318 Mdot
.63573 .65804 Mdot
.58185 .31496 Mdot
.53554 .53098 Mdot
.53344 .8211 Mdot
.76287 .40657 Mdot
.67858 .4609 Mdot
.49599 .5537 Mdot
.71319 .41601 Mdot
.62428 .34516 Mdot
.51932 .54757 Mdot
.40367 .56374 Mdot
.63553 .6758 Mdot
.40297 .56063 Mdot
.39878 .5562 Mdot
.3838 .56007 Mdot
.56056 .75644 Mdot
.44093 .35174 Mdot
.40735 .29254 Mdot
.35633 .58117 Mdot
.57509 .29535 Mdot
.75428 .47836 Mdot
.39655 .78322 Mdot
.39525 .57791 Mdot
.36579 .58593 Mdot
.5847 .62941 Mdot
.35117 .61516 Mdot
.67913 .45446 Mdot
.60256 .61477 Mdot
.34105 .56541 Mdot
.50215 .36684 Mdot
.38506 .54518 Mdot
.57027 .64695 Mdot
.66031 .4344 Mdot
.39865 .62491 Mdot
.31651 .55966 Mdot
.51736 .54671 Mdot
.53251 .54916 Mdot
.5566 .55226 Mdot
.65267 .44775 Mdot
.59165 .31496 Mdot
.51422 .32124 Mdot
.30995 .56052 Mdot
.35432 .56056 Mdot
.42122 .62499 Mdot
.55401 .2728 Mdot
.52816 .43915 Mdot
.6019 .76509 Mdot
.34736 .61718 Mdot
.54642 .28876 Mdot
.57184 .50261 Mdot
.43013 .6644 Mdot
.60087 .62647 Mdot
.60181 .35382 Mdot
.70149 .44585 Mdot
.43811 .28076 Mdot
.27266 .36544 Mdot
.63312 .60975 Mdot
.6111 .67075 Mdot
.57055 .32921 Mdot
.3071 .43389 Mdot
.88971 .46844 Mdot
.55286 .31798 Mdot
.4599 .46637 Mdot
.62333 .62983 Mdot
.32427 .57321 Mdot
.2603 .45183 Mdot
.31367 .4422 Mdot
.53296 .29527 Mdot
.41344 .58801 Mdot
.48424 .17186 Mdot
.56083 .33438 Mdot
.41481 .63092 Mdot
.55781 .29511 Mdot
.66646 .47525 Mdot
.56066 .31511 Mdot
.64769 .60738 Mdot
.41983 .57261 Mdot
.88341 .48597 Mdot
.36916 .43523 Mdot
.41483 .57548 Mdot
.65594 .45062 Mdot
.61552 .40381 Mdot
.37744 .57833 Mdot
.40294 .30016 Mdot
.59178 .30988 Mdot
.61004 .26435 Mdot
.37544 .53455 Mdot
.54376 .3283 Mdot
.59762 .65929 Mdot
.60661 .34213 Mdot
.50171 .37227 Mdot
.52868 .55105 Mdot
.61789 .63562 Mdot
.62239 .4456 Mdot
.71339 .45135 Mdot
.34413 .54772 Mdot
.36428 .59436 Mdot
.61305 .6379 Mdot
.4637 .48175 Mdot
.42567 .52437 Mdot
.40313 .55842 Mdot
.57787 .32069 Mdot
.55305 .34867 Mdot
.35538 .45586 Mdot
.57125 .30372 Mdot
.42978 .62447 Mdot
.6123 .62928 Mdot
.37522 .53078 Mdot
.64682 .62109 Mdot
.40884 .55 Mdot
.70676 .5035 Mdot
.60625 .64396 Mdot
.29626 .57212 Mdot
.4161 .58819 Mdot
.66784 .72193 Mdot
.35848 .59043 Mdot
.39212 .55331 Mdot
.57081 .35259 Mdot
.43948 .29921 Mdot
.40725 .52024 Mdot
.64914 .49008 Mdot
.44241 .27966 Mdot
.4141 .68121 Mdot
.57705 .34306 Mdot
.44545 .27527 Mdot
.26992 .34041 Mdot
.5164 .54892 Mdot
.43591 .30799 Mdot
.49664 .54642 Mdot
.67953 .46278 Mdot
.65397 .67391 Mdot
.40154 .60108 Mdot
.52582 .82201 Mdot
.49749 .44222 Mdot
.52601 .53625 Mdot
.37134 .55514 Mdot
.39056 .59049 Mdot
.64702 .61173 Mdot
.73857 .28123 Mdot
.53646 .34247 Mdot
.32883 .59968 Mdot
.63572 .60938 Mdot
.7593 .31119 Mdot
.52776 .29659 Mdot
.41267 .2689 Mdot
.71255 .43055 Mdot
.63708 .58821 Mdot
.51485 .53704 Mdot
.66784 .45634 Mdot
.50367 .3029 Mdot
.32084 .35124 Mdot
.38225 .52904 Mdot
.58505 .32614 Mdot
.31336 .36008 Mdot
.44764 .53946 Mdot
.68161 .41072 Mdot
.62463 .39313 Mdot
.61969 .65175 Mdot
.66627 .4624 Mdot
.40688 .30086 Mdot
.5934 .6184 Mdot
.60362 .61694 Mdot
.68512 .45388 Mdot
.68296 .74169 Mdot
.25156 .46363 Mdot
.67937 .41725 Mdot
.27915 .46255 Mdot
.31558 .35886 Mdot
.52336 .53483 Mdot
.41027 .28651 Mdot
.40067 .32823 Mdot
.63349 .61758 Mdot
.78956 .60993 Mdot
.31169 .36097 Mdot
.38458 .61304 Mdot
.43954 .28545 Mdot
.74338 .50332 Mdot
.64943 .39682 Mdot
.67363 .45632 Mdot
.58045 .38206 Mdot
.44387 .28916 Mdot
.42352 .58194 Mdot
.17339 .44703 Mdot
.38084 .60474 Mdot
.68414 .45781 Mdot
.42638 .46862 Mdot
.64445 .65133 Mdot
.65256 .46157 Mdot
.42798 .46851 Mdot
.3473 .56331 Mdot
.40152 .59103 Mdot
.45458 .35439 Mdot
.62185 .65789 Mdot
.52899 .53151 Mdot
.41721 .57075 Mdot
.36997 .58859 Mdot
.34524 .54203 Mdot
.20546 .50354 Mdot
.51818 .58417 Mdot
.33611 .55207 Mdot
.55404 .28336 Mdot
.3776 .63616 Mdot
.3303 .60294 Mdot
.57919 .60648 Mdot
.48177 .36798 Mdot
.54636 .53498 Mdot
.37808 .55568 Mdot
.38569 .55365 Mdot
.71057 .43146 Mdot
.25166 .46255 Mdot
.31401 .43699 Mdot
.51666 .30805 Mdot
.51865 .26927 Mdot
.42746 .56038 Mdot
.6199 .64385 Mdot
.43752 .25877 Mdot
.45922 .60183 Mdot
.61649 .5989 Mdot
.4227 .55678 Mdot
.59478 .31717 Mdot
.52548 .54811 Mdot
.44931 .61349 Mdot
.43485 .28704 Mdot
.70785 .4088 Mdot
.42932 .67066 Mdot
.57387 .33655 Mdot
.34357 .60062 Mdot
.50518 .27449 Mdot
.54079 .31927 Mdot
.53052 .5357 Mdot
.34935 .62672 Mdot
.61801 .62572 Mdot
.64206 .66719 Mdot
.41281 .37362 Mdot
.5653 .29185 Mdot
.61194 .36349 Mdot
.67154 .47135 Mdot
.35803 .5801 Mdot
.70461 .40242 Mdot
.64596 .66092 Mdot
.24212 .44573 Mdot
.45019 .28351 Mdot
.6781 .45666 Mdot
.49878 .5459 Mdot
.60107 .63452 Mdot
.64831 .66098 Mdot
.39377 .55701 Mdot
.4021 .57176 Mdot
.62115 .34058 Mdot
.29017 .39527 Mdot
.70089 .42878 Mdot
.41847 .26858 Mdot
.51805 .30892 Mdot
.36217 .5433 Mdot
.6302 .65142 Mdot
.18321 .51256 Mdot
.35948 .58779 Mdot
.57341 .29483 Mdot
.63563 .63221 Mdot
.40603 .27947 Mdot
.40878 .30144 Mdot
.41634 .56202 Mdot
.32083 .67439 Mdot
.68926 .44778 Mdot
.61578 .61774 Mdot
.68012 .63327 Mdot
.35416 .57955 Mdot
.39746 .57394 Mdot
.443 .52537 Mdot
.65596 .42457 Mdot
.33873 .53355 Mdot
.44446 .31076 Mdot
.65467 .64096 Mdot
.41484 .56914 Mdot
.44215 .29312 Mdot
.56667 .53832 Mdot
.52462 .54332 Mdot
.53003 .31603 Mdot
.40342 .30403 Mdot
.43213 .29766 Mdot
.43834 .27375 Mdot
.79559 .603 Mdot
.53908 .52755 Mdot
.35473 .29349 Mdot
.41567 .58625 Mdot
.31658 .35831 Mdot
.37205 .52566 Mdot
.66003 .46763 Mdot
.53706 .32844 Mdot
.38387 .56545 Mdot
.41477 .58783 Mdot
.44694 .6572 Mdot
.37041 .53004 Mdot
.40257 .52477 Mdot
.64604 .65184 Mdot
.68351 .64248 Mdot
.56149 .3399 Mdot
.77418 .3406 Mdot
.15343 .52972 Mdot
.43252 .55571 Mdot
.30662 .43614 Mdot
.60266 .63353 Mdot
.71179 .43126 Mdot
.27459 .45768 Mdot
.68899 .39614 Mdot
.6453 .63121 Mdot
.36108 .54215 Mdot
.47828 .64105 Mdot
.44251 .28324 Mdot
.38293 .57849 Mdot
.69291 .43366 Mdot
.38228 .5774 Mdot
.6537 .45348 Mdot
.63013 .75754 Mdot
.32124 .42587 Mdot
.39364 .60657 Mdot
.4054 .53519 Mdot
.34426 .66513 Mdot
.39817 .57576 Mdot
.61119 .24159 Mdot
.63151 .6332 Mdot
.30016 .59018 Mdot
.35024 .5496 Mdot
.53982 .72604 Mdot
.3645 .56788 Mdot
.42958 .48339 Mdot
.37966 .6 Mdot
.22435 .36615 Mdot
.41129 .60017 Mdot
.36931 .60088 Mdot
.67326 .43141 Mdot
.71428 .43922 Mdot
.69347 .67364 Mdot
.54436 .53585 Mdot
.75004 .49868 Mdot
.36689 .57988 Mdot
.52834 .32811 Mdot
.28634 .61147 Mdot
.43647 .29824 Mdot
.65356 .63795 Mdot
.77254 .75198 Mdot
.65657 .47452 Mdot
.58084 .29621 Mdot
.48277 .45369 Mdot
.56821 .28569 Mdot
.59489 .35761 Mdot
.64436 .58648 Mdot
.41124 .28468 Mdot
.38873 .54556 Mdot
.53323 .70953 Mdot
.77599 .60758 Mdot
.35345 .57815 Mdot
.51288 .28195 Mdot
.29227 .62542 Mdot
.39244 .37075 Mdot
.39732 .28755 Mdot
.41757 .29094 Mdot
.67036 .44394 Mdot
.52254 .31511 Mdot
.33694 .61343 Mdot
.44585 .27545 Mdot
.5542 .33644 Mdot
.50382 .54907 Mdot
.46825 .36308 Mdot
.62654 .61695 Mdot
.62246 .76732 Mdot
.59371 .70617 Mdot
.68505 .47414 Mdot
.64739 .48795 Mdot
.64545 .67614 Mdot
.60523 .60009 Mdot
.54306 .53795 Mdot
.54254 .29169 Mdot
.65539 .67184 Mdot
.41694 .56641 Mdot
.40533 .63198 Mdot
.38364 .54887 Mdot
.40629 .27381 Mdot
.36704 .56121 Mdot
.54969 .33299 Mdot
.66903 .43184 Mdot
.5477 .30499 Mdot
.66747 .4492 Mdot
.19246 .58011 Mdot
.42196 .58143 Mdot
.39764 .57112 Mdot
.30468 .44277 Mdot
.65047 .65644 Mdot
.52122 .71816 Mdot
.56898 .29392 Mdot
.55142 .29935 Mdot
.35503 .54583 Mdot
.59405 .63369 Mdot
.45871 .31075 Mdot
.28992 .45922 Mdot
.37628 .59926 Mdot
.63187 .63511 Mdot
.35897 .54153 Mdot
.64098 .50171 Mdot
.35034 .44112 Mdot
.65836 .64293 Mdot
.30647 .22328 Mdot
.41538 .59129 Mdot
.34058 .62189 Mdot
.30248 .56256 Mdot
.21088 .51833 Mdot
.42398 .52554 Mdot
.62718 .60113 Mdot
.3317 .60385 Mdot
.62474 .64617 Mdot
.54389 .31675 Mdot
.6535 .46611 Mdot
.62604 .64212 Mdot
.3959 .60103 Mdot
.15445 .52759 Mdot
.67397 .42688 Mdot
.38542 .5741 Mdot
.69204 .42898 Mdot
.67048 .64502 Mdot
.64315 .64726 Mdot
.50199 .55006 Mdot
.46135 .46548 Mdot
.68386 .45314 Mdot
.35413 .56246 Mdot
.76751 .63479 Mdot
.37988 .52883 Mdot
.51624 .27248 Mdot
.4216 .54148 Mdot
.42264 .55386 Mdot
.24005 .29209 Mdot
.45359 .48348 Mdot
.76855 .40615 Mdot
.75104 .4668 Mdot
.76379 .64716 Mdot
.59544 .59429 Mdot
.39746 .28945 Mdot
.55459 .58162 Mdot
.52249 .55226 Mdot
.54808 .28341 Mdot
.38718 .56194 Mdot
.57148 .5261 Mdot
.67163 .41762 Mdot
.43141 .30727 Mdot
.39043 .60855 Mdot
.57054 .28094 Mdot
.49782 .55576 Mdot
.67013 .45599 Mdot
.63372 .61659 Mdot
.64975 .63959 Mdot
.43017 .35229 Mdot
.41462 .57078 Mdot
.4034 .56803 Mdot
.68195 .4231 Mdot
.3361 .52318 Mdot
.43061 .27158 Mdot
.5558 .46543 Mdot
.695 .43328 Mdot
.34918 .43946 Mdot
.62395 .6594 Mdot
.39306 .5895 Mdot
.30497 .44766 Mdot
.73521 .67455 Mdot
.41165 .77425 Mdot
.42326 .28869 Mdot
.23818 .49631 Mdot
.62794 .6016 Mdot
.68474 .43339 Mdot
.28053 .32927 Mdot
.44522 .56723 Mdot
.38468 .59245 Mdot
.22845 .50532 Mdot
.28798 .46019 Mdot
.48156 .45627 Mdot
.48329 .5649 Mdot
.27271 .44028 Mdot
.35659 .54421 Mdot
.33611 .57422 Mdot
.42768 .56281 Mdot
.4192 .53957 Mdot
.63192 .6426 Mdot
.54137 .7403 Mdot
.56581 .32482 Mdot
.41507 .76313 Mdot
.5397 .26576 Mdot
.36539 .60737 Mdot
.35124 .55513 Mdot
.43766 .73785 Mdot
.26665 .49784 Mdot
.62822 .62569 Mdot
.60552 .59196 Mdot
.69926 .4672 Mdot
.37722 .52792 Mdot
.57017 .2932 Mdot
.30299 .56666 Mdot
.53327 .31423 Mdot
.63287 .64093 Mdot
.59097 .332 Mdot
.68411 .48066 Mdot
.58547 .32523 Mdot
.54837 .28643 Mdot
.6619 .43706 Mdot
.6131 .65356 Mdot
.36174 .59731 Mdot
.66078 .43844 Mdot
.46107 .30323 Mdot
.40509 .27645 Mdot
.68 .67569 Mdot
.32835 .56313 Mdot
.44484 .55005 Mdot
.62855 .36353 Mdot
.58803 .31351 Mdot
.31314 .46707 Mdot
.61043 .6486 Mdot
.4324 .25811 Mdot
.62938 .64668 Mdot
.37667 .34457 Mdot
.42805 .28992 Mdot
.5118 .53421 Mdot
.24807 .3956 Mdot
.72558 .42462 Mdot
.43341 .58917 Mdot
.68329 .64372 Mdot
.53364 .31146 Mdot
.65496 .45214 Mdot
.7513 .48707 Mdot
.32681 .59486 Mdot
.6381 .68523 Mdot
.66465 .62092 Mdot
.52138 .55081 Mdot
.68759 .43383 Mdot
.61886 .71843 Mdot
.41321 .57597 Mdot
.71923 .41884 Mdot
.42268 .54313 Mdot
.58376 .77309 Mdot
.58311 .26367 Mdot
.57166 .50817 Mdot
.35715 .54521 Mdot
.5282 .29549 Mdot
.35697 .54467 Mdot
.53876 .80357 Mdot
.25345 .41628 Mdot
.42898 .56308 Mdot
.25856 .49974 Mdot
.62765 .34249 Mdot
.62836 .65172 Mdot
.46459 .59362 Mdot
.52519 .53529 Mdot
.33714 .59042 Mdot
.19289 .67586 Mdot
.44191 .3008 Mdot
.48873 .34021 Mdot
.40134 .59898 Mdot
.40808 .56177 Mdot
.4247 .67117 Mdot
.6267 .75652 Mdot
.50801 .55257 Mdot
.37954 .59072 Mdot
.22396 .52515 Mdot
.67122 .43522 Mdot
.38992 .53163 Mdot
.39415 .55009 Mdot
.6172 .32687 Mdot
.67711 .43127 Mdot
.58486 .33493 Mdot
.518 .5499 Mdot
.55007 .34549 Mdot
.45475 .30382 Mdot
.24714 .49769 Mdot
.22422 .469 Mdot
.35039 .44665 Mdot
.40587 .307 Mdot
.35218 .60338 Mdot
.55894 .50539 Mdot
.4089 .58825 Mdot
.41648 .29514 Mdot
.69878 .43268 Mdot
.62983 .63606 Mdot
.60541 .77352 Mdot
.53403 .53779 Mdot
.34892 .59023 Mdot
.40585 .26667 Mdot
.62222 .63764 Mdot
.72378 .71103 Mdot
.6387 .64314 Mdot
.6727 .45171 Mdot
.67595 .41288 Mdot
.43336 .29279 Mdot
.62963 .64737 Mdot
.5601 .35024 Mdot
.66717 .40582 Mdot
.41444 .60799 Mdot
.68126 .48123 Mdot
.66518 .64392 Mdot
.65985 .63313 Mdot
.61474 .6679 Mdot
.34592 .55478 Mdot
.27998 .48409 Mdot
.48716 .56371 Mdot
.67853 .42432 Mdot
.55507 .27948 Mdot
.28248 .39937 Mdot
.5295 .66417 Mdot
.3339 .43703 Mdot
.46191 .59341 Mdot
.36794 .5598 Mdot
.37987 .55071 Mdot
.34069 .54334 Mdot
.54392 .47928 Mdot
.42277 .57837 Mdot
.70134 .43011 Mdot
.54882 .32653 Mdot
.3799 .59777 Mdot
.5176 .5402 Mdot
.52398 .4391 Mdot
.44799 .27271 Mdot
.56568 .76441 Mdot
.68349 .67321 Mdot
.62364 .63757 Mdot
.58033 .30753 Mdot
.58761 .33975 Mdot
.43415 .26289 Mdot
.66285 .45444 Mdot
.64168 .64181 Mdot
.22906 .35733 Mdot
.4388 .27756 Mdot
.37663 .557 Mdot
.30449 .44381 Mdot
.21534 .53831 Mdot
.39078 .5393 Mdot
.38206 .56032 Mdot
.54714 .53612 Mdot
.56932 .29111 Mdot
.40121 .79365 Mdot
.69742 .71881 Mdot
.43887 .29524 Mdot
.42922 .26567 Mdot
.60495 .66046 Mdot
.35952 .57354 Mdot
.69167 .44529 Mdot
.24715 .46876 Mdot
.61598 .42192 Mdot
.74959 .50882 Mdot
.62426 .34879 Mdot
.38171 .54566 Mdot
.52013 .78271 Mdot
.4391 .56267 Mdot
.67184 .64654 Mdot
.63165 .66864 Mdot
.62536 .62211 Mdot
.66861 .43739 Mdot
.32376 .34925 Mdot
.71215 .44857 Mdot
.57154 .50049 Mdot
.62317 .60496 Mdot
.46528 .4741 Mdot
.55313 .2978 Mdot
.3719 .52689 Mdot
.4119 .28732 Mdot
.46732 .26926 Mdot
.45763 .60151 Mdot
.24109 .49676 Mdot
.58279 .33345 Mdot
.599 .63502 Mdot
.36663 .52839 Mdot
.75603 .47517 Mdot
.30652 .42488 Mdot
.62996 .29328 Mdot
.57191 .52114 Mdot
.44139 .29013 Mdot
.36151 .75413 Mdot
.42756 .27379 Mdot
.6793 .45692 Mdot
.41866 .58543 Mdot
.3606 .57678 Mdot
.39213 .55277 Mdot
.42782 .54139 Mdot
.6733 .43838 Mdot
.42017 .60225 Mdot
.42793 .38163 Mdot
.52365 .55524 Mdot
.52509 .45927 Mdot
.41561 .30855 Mdot
.66791 .47073 Mdot
.54349 .32251 Mdot
.54909 .54468 Mdot
.42547 .25645 Mdot
.35855 .53062 Mdot
.4006 .59733 Mdot
.51782 .5544 Mdot
.47288 .57844 Mdot
.44375 .54356 Mdot
.56383 .33028 Mdot
.50405 .44737 Mdot
.45314 .28262 Mdot
.42221 .28157 Mdot
.67242 .46547 Mdot
.62896 .64727 Mdot
.44736 .27424 Mdot
.52071 .28688 Mdot
.38731 .53104 Mdot
.42451 .5449 Mdot
.66417 .63976 Mdot
.31492 .3572 Mdot
.44799 .27255 Mdot
.34239 .53002 Mdot
.65646 .64445 Mdot
.66352 .61817 Mdot
.38077 .59006 Mdot
.40656 .60898 Mdot
.58039 .60605 Mdot
.42563 .26357 Mdot
.67152 .46756 Mdot
.35218 .42317 Mdot
.66718 .47732 Mdot
.62961 .61363 Mdot
.39385 .63484 Mdot
.6073 .6496 Mdot
.32628 .59298 Mdot
.82399 .47141 Mdot
.42396 .57561 Mdot
.54712 .61104 Mdot
.51083 .42269 Mdot
.55405 .29562 Mdot
.54547 .29508 Mdot
.52229 .54735 Mdot
.61224 .60059 Mdot
.43964 .61873 Mdot
.41287 .27935 Mdot
.76403 .64617 Mdot
.57845 .60729 Mdot
.54649 .2873 Mdot
.58756 .30303 Mdot
.69384 .43055 Mdot
.36575 .56289 Mdot
.39447 .58982 Mdot
.58601 .32626 Mdot
.61625 .46833 Mdot
.61367 .64558 Mdot
.40307 .56775 Mdot
.33939 .54855 Mdot
.56282 .32595 Mdot
.71505 .46774 Mdot
.65061 .674 Mdot
.34402 .55614 Mdot
.24984 .42534 Mdot
.65237 .45657 Mdot
.34118 .58589 Mdot
.43472 .58766 Mdot
.43188 .3016 Mdot
.23383 .49813 Mdot
.31039 .36454 Mdot
.66014 .47819 Mdot
.51353 .5447 Mdot
.38609 .54094 Mdot
.54752 .29759 Mdot
.36451 .52361 Mdot
.54508 .85929 Mdot
.51738 .55291 Mdot
.4116 .57455 Mdot
.30991 .5521 Mdot
.64676 .6206 Mdot
.40624 .56379 Mdot
.69734 .50573 Mdot
.57696 .3142 Mdot
.41142 .57623 Mdot
.34929 .67904 Mdot
.69318 .43078 Mdot
.46342 .59468 Mdot
.44327 .28705 Mdot
.47102 .46385 Mdot
.20485 .6083 Mdot
.55664 .27306 Mdot
.42228 .31286 Mdot
.36479 .57184 Mdot
.52068 .31669 Mdot
.71652 .43574 Mdot
.49174 .55706 Mdot
.34407 .59703 Mdot
.69055 .47107 Mdot
.66483 .43706 Mdot
.43602 .29039 Mdot
.85309 .5932 Mdot
.4301 .57058 Mdot
.38835 .57954 Mdot
.80041 .65833 Mdot
.58235 .59239 Mdot
.3837 .57434 Mdot
.3634 .587 Mdot
.67059 .46111 Mdot
.3269 .32999 Mdot
.23915 .49717 Mdot
.55483 .46854 Mdot
.65447 .45914 Mdot
.51345 .31214 Mdot
.58114 .32221 Mdot
.42991 .31274 Mdot
.63638 .63208 Mdot
.42703 .2588 Mdot
.56408 .31637 Mdot
.38655 .55541 Mdot
.69165 .46369 Mdot
.30011 .69979 Mdot
.65707 .43892 Mdot
.54681 .27617 Mdot
.67144 .64531 Mdot
.48294 .82081 Mdot
.57017 .85792 Mdot
.54225 .57643 Mdot
.6781 .40994 Mdot
.43637 .29858 Mdot
.70157 .71795 Mdot
.3784 .59828 Mdot
.53754 .79719 Mdot
.3847 .5792 Mdot
.5708 .53553 Mdot
.54095 .3313 Mdot
.50325 .54936 Mdot
.3259 .59282 Mdot
.24036 .50035 Mdot
.66146 .4431 Mdot
.69941 .44286 Mdot
.33229 .6041 Mdot
.67625 .45279 Mdot
.40298 .58294 Mdot
.55481 .32636 Mdot
.84174 .50739 Mdot
.38294 .6009 Mdot
.3017 .58704 Mdot
.72107 .41766 Mdot
.67389 .69673 Mdot
.50794 .30422 Mdot
.52847 .76072 Mdot
.75905 .49061 Mdot
.6901 .44504 Mdot
.56124 .75954 Mdot
.57828 .30286 Mdot
.54951 .54403 Mdot
.53008 .33419 Mdot
.3894 .58445 Mdot
.37828 .54606 Mdot
.34109 .54153 Mdot
.36449 .58268 Mdot
.49437 .79752 Mdot
.44633 .54494 Mdot
.39475 .71399 Mdot
.4159 .58552 Mdot
.54316 .59056 Mdot
.71068 .44078 Mdot
.34483 .62258 Mdot
.3782 .4168 Mdot
.42303 .56407 Mdot
.60118 .59308 Mdot
.66972 .47341 Mdot
.78222 .45254 Mdot
.67329 .43615 Mdot
.54619 .30474 Mdot
.66329 .4473 Mdot
.3886 .61135 Mdot
.64409 .62305 Mdot
.56522 .30621 Mdot
.49315 .55364 Mdot
.54356 .28182 Mdot
.4148 .57532 Mdot
.73551 .43985 Mdot
.58288 .30135 Mdot
.44733 .55751 Mdot
.64594 .626 Mdot
.20676 .45823 Mdot
.65514 .67636 Mdot
.39622 .5629 Mdot
.39001 .56651 Mdot
.5153 .55432 Mdot
.66497 .45297 Mdot
.61175 .65498 Mdot
.61389 .38165 Mdot
.43049 .25707 Mdot
.63229 .62591 Mdot
.3023 .56006 Mdot
.30493 .4331 Mdot
.65496 .63088 Mdot
.21976 .53177 Mdot
.68087 .45816 Mdot
.64061 .6104 Mdot
.31671 .53254 Mdot
.40992 .75956 Mdot
.42449 .27813 Mdot
.56571 .35201 Mdot
.28363 .44145 Mdot
.58071 .31982 Mdot
.72788 .49481 Mdot
.57927 .35462 Mdot
.68349 .42787 Mdot
.29039 .61881 Mdot
.42896 .46916 Mdot
.6602 .42803 Mdot
.74028 .43802 Mdot
.57103 .32317 Mdot
.32989 .56267 Mdot
.51475 .45351 Mdot
.43199 .62504 Mdot
.36363 .63797 Mdot
.65457 .47191 Mdot
.63634 .60638 Mdot
.59408 .61865 Mdot
.29691 .58688 Mdot
.6496 .64647 Mdot
.55365 .31347 Mdot
.35219 .45114 Mdot
.57625 .75159 Mdot
.70611 .43957 Mdot
.49728 .44545 Mdot
.34999 .55546 Mdot
.54516 .32998 Mdot
.55036 .31351 Mdot
.66478 .43893 Mdot
.45372 .77484 Mdot
.42072 .62941 Mdot
.60417 .58238 Mdot
.63064 .60774 Mdot
.64659 .61935 Mdot
.63396 .66085 Mdot
.32283 .34806 Mdot
.65551 .4535 Mdot
.61551 .6003 Mdot
.42385 .53721 Mdot
.36236 .56961 Mdot
.53779 .54934 Mdot
.41006 .27042 Mdot
.44434 .56069 Mdot
.44028 .6184 Mdot
.38292 .59038 Mdot
.55939 .29483 Mdot
.288 .63023 Mdot
.53283 .55563 Mdot
.56852 .29202 Mdot
.56127 .29227 Mdot
.51687 .54672 Mdot
.28695 .61735 Mdot
.41557 .78999 Mdot
.34655 .61215 Mdot
.63982 .58512 Mdot
.54146 .29577 Mdot
.52298 .37979 Mdot
.54852 .60356 Mdot
.35668 .56162 Mdot
.54377 .45342 Mdot
.55055 .3223 Mdot
.59374 .5943 Mdot
.39451 .58039 Mdot
.54061 .53628 Mdot
.43173 .2781 Mdot
.48831 .55997 Mdot
.5461 .53575 Mdot
.62349 .65107 Mdot
.60661 .36742 Mdot
.64781 .61236 Mdot
.59207 .33842 Mdot
.45091 .60804 Mdot
.88685 .4761 Mdot
.53492 .31105 Mdot
.77341 .63523 Mdot
.43599 .47019 Mdot
.39657 .59533 Mdot
.58012 .31114 Mdot
.59005 .64483 Mdot
.65091 .45288 Mdot
.29184 .47922 Mdot
.63253 .65015 Mdot
.55028 .54681 Mdot
.53467 .54726 Mdot
.56516 .32575 Mdot
.61699 .61092 Mdot
.4298 .59447 Mdot
.6493 .6372 Mdot
.69972 .45785 Mdot
.33653 .60267 Mdot
.75059 .49803 Mdot
.34838 .62665 Mdot
.65253 .64425 Mdot
.55129 .27831 Mdot
.45059 .30679 Mdot
.38705 .60528 Mdot
.78173 .45898 Mdot
.36435 .57174 Mdot
.69536 .43006 Mdot
.49347 .41308 Mdot
.31515 .70263 Mdot
.37287 .56869 Mdot
.34849 .55913 Mdot
.70207 .47257 Mdot
.37292 .57238 Mdot
.40936 .53966 Mdot
.61879 .71987 Mdot
.65641 .6354 Mdot
.37798 .59708 Mdot
.57506 .33388 Mdot
.36865 .69308 Mdot
.41046 .55895 Mdot
.68667 .50771 Mdot
.22081 .50122 Mdot
.4715 .40022 Mdot
.29688 .60607 Mdot
.24408 .44292 Mdot
.38924 .57091 Mdot
.35634 .56655 Mdot
.33932 .60929 Mdot
.52389 .78552 Mdot
.56873 .31727 Mdot
.52442 .29955 Mdot
.43932 .31248 Mdot
.22692 .50813 Mdot
.42894 .28369 Mdot
.71697 .43459 Mdot
.47736 .45723 Mdot
.54016 .55614 Mdot
.62755 .64736 Mdot
.39784 .55407 Mdot
.53429 .28309 Mdot
.39516 .58684 Mdot
.33763 .58832 Mdot
.55589 .31627 Mdot
.54694 .31744 Mdot
.58451 .27999 Mdot
.44486 .28571 Mdot
.62549 .62985 Mdot
.41129 .59776 Mdot
.44334 .28082 Mdot
.34358 .54185 Mdot
.3367 .4194 Mdot
.6259 .62696 Mdot
.65213 .6467 Mdot
.5999 .61219 Mdot
.3735 .60403 Mdot
.33907 .60709 Mdot
.71164 .45101 Mdot
.66425 .63933 Mdot
.68908 .45128 Mdot
.58076 .31269 Mdot
.55832 .33375 Mdot
.38847 .5845 Mdot
.33695 .52348 Mdot
.40991 .30173 Mdot
.5857 .30655 Mdot
.5587 .54354 Mdot
.44635 .30425 Mdot
.38675 .54729 Mdot
.58134 .3169 Mdot
.402 .29085 Mdot
.44062 .77773 Mdot
.69294 .53433 Mdot
.44438 .30933 Mdot
.32593 .59594 Mdot
.51579 .66363 Mdot
.26132 .40902 Mdot
.44773 .26969 Mdot
.70982 .442 Mdot
.36156 .59295 Mdot
.56448 .48441 Mdot
.45249 .28535 Mdot
.29995 .37389 Mdot
.56054 .31262 Mdot
.35369 .63329 Mdot
.47947 .61344 Mdot
.57318 .74878 Mdot
.45222 .30496 Mdot
.65346 .64252 Mdot
.65467 .66119 Mdot
.3755 .5596 Mdot
.4723 .46137 Mdot
.68609 .41979 Mdot
.58635 .34097 Mdot
.52474 .2946 Mdot
.64629 .66915 Mdot
.35116 .44443 Mdot
.57736 .33159 Mdot
.358 .57721 Mdot
.41106 .32542 Mdot
.40201 .52497 Mdot
.39167 .36121 Mdot
.29932 .68291 Mdot
.29374 .60064 Mdot
.44942 .30714 Mdot
.68918 .42145 Mdot
.67216 .43042 Mdot
.6675 .4452 Mdot
.56992 .33148 Mdot
.27485 .45503 Mdot
.52136 .30089 Mdot
.77506 .68205 Mdot
.44293 .30061 Mdot
.25237 .30275 Mdot
.43538 .55025 Mdot
.40009 .59318 Mdot
.38885 .52847 Mdot
.33539 .55607 Mdot
.39061 .57092 Mdot
.69719 .46774 Mdot
.54443 .3408 Mdot
.61894 .39386 Mdot
.60956 .62738 Mdot
.72084 .71312 Mdot
.55527 .29734 Mdot
.54322 .53362 Mdot
.40955 .2964 Mdot
.21617 .47858 Mdot
.41675 .32132 Mdot
.59225 .31868 Mdot
.41261 .54719 Mdot
.60413 .66043 Mdot
.22031 .37514 Mdot
.40429 .55882 Mdot
.58811 .31131 Mdot
.51305 .30366 Mdot
.42864 .76616 Mdot
.47392 .55783 Mdot
.61304 .41934 Mdot
.31063 .44888 Mdot
.42026 .31817 Mdot
.3273 .56344 Mdot
.24006 .47724 Mdot
.56451 .31811 Mdot
.53058 .30189 Mdot
.44425 .26176 Mdot
.69525 .69063 Mdot
.6137 .60376 Mdot
.67747 .65799 Mdot
.68883 .47054 Mdot
.40254 .59424 Mdot
.57553 .32329 Mdot
.6726 .65878 Mdot
.35409 .39576 Mdot
.67501 .44408 Mdot
.58175 .29746 Mdot
.36379 .57537 Mdot
.37157 .56859 Mdot
.43161 .2846 Mdot
.51465 .42934 Mdot
.43206 .62494 Mdot
.76595 .64368 Mdot
.32149 .43742 Mdot
.43649 .46986 Mdot
.38486 .5926 Mdot
.6317 .65923 Mdot
.51822 .54696 Mdot
.40974 .28665 Mdot
.37061 .52308 Mdot
.52476 .81914 Mdot
.63557 .598 Mdot
.68752 .45124 Mdot
.51901 .53508 Mdot
.25074 .49912 Mdot
.36421 .57693 Mdot
.3851 .57961 Mdot
.3474 .5534 Mdot
.45412 .81509 Mdot
.53681 .32738 Mdot
.63951 .65803 Mdot
.44319 .28949 Mdot
.64261 .64622 Mdot
.59445 .33892 Mdot
.5013 .4442 Mdot
.40339 .60531 Mdot
.62506 .5948 Mdot
.64357 .63567 Mdot
.69655 .43196 Mdot
.66175 .43576 Mdot
.52372 .2795 Mdot
.36503 .59302 Mdot
.54089 .5565 Mdot
.6238 .60105 Mdot
.56701 .34911 Mdot
.43022 .28567 Mdot
.72664 .49651 Mdot
.41304 .58998 Mdot
.56676 .32276 Mdot
.45065 .60919 Mdot
.61432 .63221 Mdot
.5732 .29728 Mdot
.55014 .54292 Mdot
.41784 .26594 Mdot
.37967 .54433 Mdot
.62284 .27497 Mdot
.53938 .53446 Mdot
.3851 .60411 Mdot
.3244 .69264 Mdot
.47362 .46097 Mdot
.56194 .54174 Mdot
.56295 .33865 Mdot
.54265 .54086 Mdot
.63841 .66495 Mdot
.38987 .7492 Mdot
.52847 .30712 Mdot
.48444 .63574 Mdot
.4154 .46686 Mdot
.32992 .6008 Mdot
.62817 .65107 Mdot
.46129 .36115 Mdot
.74198 .65303 Mdot
.26936 .40622 Mdot
.40827 .57422 Mdot
.58048 .32027 Mdot
.42887 .27883 Mdot
.69906 .44389 Mdot
.64418 .43536 Mdot
.41872 .35061 Mdot
.55233 .28845 Mdot
.39826 .55378 Mdot
.63649 .60684 Mdot
.68301 .45268 Mdot
.42286 .6741 Mdot
.51849 .3072 Mdot
.57764 .33421 Mdot
.37127 .53893 Mdot
.42733 .28332 Mdot
.55241 .49078 Mdot
.53183 .32123 Mdot
.53753 .33636 Mdot
.61047 .71628 Mdot
.417 .31681 Mdot
.3406 .56067 Mdot
.29667 .58602 Mdot
.40681 .53425 Mdot
.74833 .69857 Mdot
.54556 .54435 Mdot
.60891 .62889 Mdot
.38319 .56836 Mdot
.62882 .34769 Mdot
.53705 .31952 Mdot
.31113 .44897 Mdot
.72357 .4449 Mdot
.66018 .44157 Mdot
.57492 .31263 Mdot
.40076 .57885 Mdot
.6419 .47637 Mdot
.42943 .31174 Mdot
.34077 .55885 Mdot
.32834 .59669 Mdot
.65603 .66452 Mdot
.6932 .46378 Mdot
.35501 .69188 Mdot
.69992 .44871 Mdot
.66768 .46234 Mdot
.61351 .68217 Mdot
.37553 .55896 Mdot
.56263 .29775 Mdot
.57893 .286 Mdot
.32871 .55035 Mdot
.52832 .37292 Mdot
.60443 .61366 Mdot
.52411 .33828 Mdot
.51343 .82376 Mdot
.42974 .55114 Mdot
.51765 .5337 Mdot
.57322 .51378 Mdot
.68075 .41221 Mdot
.37658 .56546 Mdot
.62289 .64643 Mdot
.53662 .33277 Mdot
.5778 .32607 Mdot
.44541 .56582 Mdot
.66998 .43124 Mdot
.40224 .28233 Mdot
.55212 .31059 Mdot
.35805 .42657 Mdot
.41269 .57294 Mdot
.68841 .39472 Mdot
.55387 .30795 Mdot
.15999 .5321 Mdot
.63001 .35067 Mdot
.65155 .62439 Mdot
.35385 .55534 Mdot
.64092 .6746 Mdot
.4255 .3152 Mdot
.55454 .35247 Mdot
.6935 .42641 Mdot
.47687 .57542 Mdot
.7712 .34791 Mdot
.57105 .32854 Mdot
.63205 .63998 Mdot
.3866 .55783 Mdot
.55484 .75577 Mdot
.3792 .59974 Mdot
.32714 .32595 Mdot
.45248 .27907 Mdot
.72794 .49289 Mdot
.68228 .42332 Mdot
.348 .56193 Mdot
.43526 .27275 Mdot
.57905 .28394 Mdot
.55683 .31669 Mdot
.79041 .39539 Mdot
.54885 .53817 Mdot
.59106 .35869 Mdot
.3798 .60362 Mdot
.5788 .34458 Mdot
.53045 .66447 Mdot
.66435 .43614 Mdot
.40488 .53456 Mdot
.57404 .28924 Mdot
.72533 .67065 Mdot
.30778 .44212 Mdot
.41093 .57272 Mdot
.32429 .53361 Mdot
.68542 .42894 Mdot
.70091 .7191 Mdot
.54368 .3339 Mdot
.3537 .53232 Mdot
.71977 .43661 Mdot
.29014 .61306 Mdot
.60553 .41129 Mdot
.62525 .62937 Mdot
.58477 .29582 Mdot
.67486 .46847 Mdot
.35499 .63231 Mdot
.4044 .28446 Mdot
.5183 .28846 Mdot
.55657 .28217 Mdot
.35086 .60811 Mdot
.34723 .54442 Mdot
.32359 .53222 Mdot
.60769 .64157 Mdot
.67511 .46213 Mdot
.33562 .58273 Mdot
.33096 .41625 Mdot
.33354 .56533 Mdot
.67835 .46412 Mdot
.86988 .53195 Mdot
.40786 .54496 Mdot
.41139 .59059 Mdot
.54877 .7667 Mdot
.60189 .64491 Mdot
.65539 .65472 Mdot
.32559 .43131 Mdot
.35651 .59733 Mdot
.46281 .47659 Mdot
.62645 .63359 Mdot
.63512 .64104 Mdot
.4636 .47583 Mdot
.34927 .60945 Mdot
.66444 .67445 Mdot
.68057 .45316 Mdot
.66015 .4406 Mdot
.64729 .62131 Mdot
.38429 .52612 Mdot
.71283 .43117 Mdot
.46914 .76837 Mdot
.59046 .31152 Mdot
.23974 .48278 Mdot
.64641 .63574 Mdot
.30175 .44205 Mdot
.67862 .45753 Mdot
.19277 .55988 Mdot
.20965 .52178 Mdot
.43192 .56105 Mdot
.37479 .5626 Mdot
.43071 .29931 Mdot
.47464 .57922 Mdot
.51865 .54894 Mdot
.66681 .44594 Mdot
.54318 .47863 Mdot
.62578 .62131 Mdot
.35973 .5985 Mdot
.28632 .39736 Mdot
.21495 .61676 Mdot
.31194 .5184 Mdot
.63668 .6341 Mdot
.63373 .61889 Mdot
.57849 .33708 Mdot
.59395 .32744 Mdot
.41016 .5999 Mdot
.67741 .42852 Mdot
.64599 .61618 Mdot
.68646 .46294 Mdot
.56336 .31725 Mdot
.55443 .29906 Mdot
.5332 .55453 Mdot
.37198 .63939 Mdot
.56963 .31107 Mdot
.67112 .50448 Mdot
.33177 .4168 Mdot
.66574 .64683 Mdot
.79146 .66856 Mdot
.19121 .54329 Mdot
.5904 .77468 Mdot
.43032 .27821 Mdot
.28658 .61436 Mdot
.71525 .44836 Mdot
.34618 .56421 Mdot
.38019 .58079 Mdot
.53121 .5404 Mdot
.71693 .44621 Mdot
.4232 .30611 Mdot
.66193 .4388 Mdot
.41072 .27702 Mdot
.5279 .29423 Mdot
.4049 .5567 Mdot
.4199 .56099 Mdot
.69853 .44123 Mdot
.58623 .33298 Mdot
.58099 .2996 Mdot
.41986 .2774 Mdot
.21563 .4827 Mdot
.5645 .32435 Mdot
.64558 .63697 Mdot
.46561 .65853 Mdot
.53489 .5462 Mdot
.39516 .57954 Mdot
.24065 .44658 Mdot
.37856 .74203 Mdot
.33883 .54278 Mdot
.52199 .53447 Mdot
.8552 .58873 Mdot
.41671 .56402 Mdot
.75665 .30757 Mdot
.54082 .55522 Mdot
.60679 .64928 Mdot
.57035 .30061 Mdot
.54165 .53388 Mdot
.29746 .64012 Mdot
.57308 .25823 Mdot
.33301 .54481 Mdot
.61335 .6032 Mdot
.598 .62234 Mdot
.50198 .44578 Mdot
.7463 .70166 Mdot
.44264 .28818 Mdot
.431 .30872 Mdot
.53284 .3166 Mdot
.74206 .48656 Mdot
.42589 .53483 Mdot
.43555 .30585 Mdot
.66801 .68177 Mdot
.3543 .54914 Mdot
.47814 .45925 Mdot
.52022 .45627 Mdot
.64302 .66354 Mdot
.36759 .62569 Mdot
.53425 .31737 Mdot
.63159 .63772 Mdot
.50891 .45029 Mdot
.38366 .53322 Mdot
.62575 .6246 Mdot
.66719 .45854 Mdot
.45299 .51057 Mdot
.64932 .64063 Mdot
.29908 .47476 Mdot
.69273 .44104 Mdot
.48481 .45379 Mdot
.27952 .30636 Mdot
.1622 .59806 Mdot
.66957 .43409 Mdot
.58497 .3087 Mdot
.57456 .32263 Mdot
.56002 .32683 Mdot
.61887 .652 Mdot
.5417 .31647 Mdot
.60771 .61722 Mdot
.67519 .40851 Mdot
.23343 .50368 Mdot
.43058 .29187 Mdot
.48297 .36037 Mdot
.64844 .62504 Mdot
.76685 .68745 Mdot
.69699 .79747 Mdot
.33609 .56004 Mdot
.6585 .42951 Mdot
.45029 .29266 Mdot
.32373 .45328 Mdot
.43088 .30137 Mdot
.57871 .3035 Mdot
.24513 .49981 Mdot
.40163 .58479 Mdot
.68038 .5246 Mdot
.42789 .27947 Mdot
.63613 .64231 Mdot
.36044 .60645 Mdot
.5953 .30925 Mdot
.42572 .31397 Mdot
.4189 .28204 Mdot
.39126 .57251 Mdot
.59919 .63637 Mdot
.57905 .29998 Mdot
.69074 .47259 Mdot
.40097 .32067 Mdot
.40802 .51219 Mdot
.41384 .55933 Mdot
.42631 .56389 Mdot
.31003 .43662 Mdot
.74308 .48738 Mdot
.69014 .44131 Mdot
.30259 .37403 Mdot
.54814 .33133 Mdot
.26904 .40348 Mdot
.75589 .63873 Mdot
.46455 .35697 Mdot
.54474 .54444 Mdot
.54701 .54667 Mdot
.40349 .56467 Mdot
.61086 .83315 Mdot
.47656 .54379 Mdot
.71482 .42784 Mdot
.52921 .54351 Mdot
.59379 .31859 Mdot
.6596 .62688 Mdot
.48482 .6027 Mdot
.44119 .55551 Mdot
.69293 .47178 Mdot
.55945 .32085 Mdot
.53662 .86326 Mdot
.44273 .29588 Mdot
.32741 .45223 Mdot
.36497 .59037 Mdot
.40054 .56898 Mdot
.67949 .44043 Mdot
.69701 .42771 Mdot
.60823 .71606 Mdot
.46048 .39453 Mdot
.7549 .49748 Mdot
.65424 .47709 Mdot
.53366 .86488 Mdot
.57274 .52415 Mdot
.6222 .61412 Mdot
.51131 .54556 Mdot
.68359 .42041 Mdot
.38317 .57224 Mdot
.60121 .6427 Mdot
.49278 .55612 Mdot
.58941 .63129 Mdot
.46965 .46409 Mdot
.35211 .42363 Mdot
.36764 .56104 Mdot
.61487 .66607 Mdot
.62969 .63255 Mdot
.64506 .59203 Mdot
.52712 .54987 Mdot
.38086 .59222 Mdot
.35189 .53159 Mdot
.42117 .57772 Mdot
.57395 .68907 Mdot
.40733 .56424 Mdot
.75314 .64344 Mdot
.33616 .43306 Mdot
.51864 .17519 Mdot
.41871 .5696 Mdot
.66335 .45836 Mdot
.39561 .55576 Mdot
.43294 .27087 Mdot
.39066 .54145 Mdot
.4612 .46701 Mdot
.68206 .4496 Mdot
.53712 .80627 Mdot
.52864 .26892 Mdot
.41242 .5556 Mdot
.40482 .30487 Mdot
.81419 .57426 Mdot
.30253 .37755 Mdot
.61114 .71533 Mdot
.64909 .63671 Mdot
.52611 .32449 Mdot
.67917 .41836 Mdot
.54716 .30335 Mdot
.42081 .60307 Mdot
.51843 .55174 Mdot
.23917 .30174 Mdot
.30055 .41444 Mdot
.38349 .56976 Mdot
.41347 .63274 Mdot
.64816 .6536 Mdot
.53574 .3166 Mdot
.62874 .75846 Mdot
.38118 .52956 Mdot
.42482 .26183 Mdot
.44799 .2823 Mdot
.48572 .28202 Mdot
.57448 .65239 Mdot
.54747 .66932 Mdot
.68122 .44129 Mdot
.57261 .33088 Mdot
.45277 .29181 Mdot
.68385 .65563 Mdot
.67415 .42106 Mdot
.68307 .41189 Mdot
.6913 .46554 Mdot
.41233 .5822 Mdot
.53899 .55271 Mdot
.60268 .68664 Mdot
.54625 .53823 Mdot
.40888 .53201 Mdot
.5579 .28252 Mdot
.54804 .54215 Mdot
.42529 .29424 Mdot
.6696 .46597 Mdot
.5569 .29588 Mdot
.39242 .56383 Mdot
.6232 .6351 Mdot
.40131 .37509 Mdot
.63272 .32405 Mdot
.47402 .46014 Mdot
.47412 .46006 Mdot
.6511 .60239 Mdot
.56782 .49829 Mdot
.7355 .42684 Mdot
.41698 .76453 Mdot
.40004 .32497 Mdot
.40867 .51964 Mdot
.53828 .37204 Mdot
.52087 .30285 Mdot
.5628 .30673 Mdot
.40175 .58774 Mdot
.56704 .34589 Mdot
.36556 .5994 Mdot
.56316 .3392 Mdot
.74363 .66785 Mdot
.44068 .57253 Mdot
.55565 .3119 Mdot
.48192 .57113 Mdot
.38815 .60483 Mdot
.63767 .65675 Mdot
.5261 .32077 Mdot
.43191 .56054 Mdot
.38239 .16758 Mdot
.69709 .43316 Mdot
.52927 .54986 Mdot
.40289 .44586 Mdot
.67227 .45569 Mdot
.61405 .60714 Mdot
.35843 .58735 Mdot
.44255 .30368 Mdot
.62871 .61387 Mdot
.50081 .28029 Mdot
.42384 .28257 Mdot
.35686 .44928 Mdot
.63623 .61408 Mdot
.53798 .54582 Mdot
.42759 .26374 Mdot
.33084 .54947 Mdot
.56108 .3089 Mdot
.63276 .33573 Mdot
.52674 .53227 Mdot
.39756 .58735 Mdot
.59465 .31138 Mdot
.66195 .44481 Mdot
.39086 .54931 Mdot
.57646 .32401 Mdot
.51375 .5412 Mdot
.40222 .59973 Mdot
.36196 .60364 Mdot
.68346 .72076 Mdot
.50412 .41733 Mdot
.42826 .29286 Mdot
.67114 .64572 Mdot
.42407 .53897 Mdot
.43176 .27282 Mdot
.62374 .34721 Mdot
.3454 .62031 Mdot
.62576 .59885 Mdot
.45932 .76786 Mdot
.58502 .34109 Mdot
.67141 .42806 Mdot
.55063 .27644 Mdot
.43011 .31595 Mdot
.74517 .76794 Mdot
.52064 .55066 Mdot
.34908 .61621 Mdot
.4159 .54202 Mdot
.53977 .34395 Mdot
.62974 .6292 Mdot
.75228 .50324 Mdot
.37735 .54461 Mdot
.41727 .62668 Mdot
.39321 .57644 Mdot
.6106 .26477 Mdot
.61208 .64816 Mdot
.39369 .57862 Mdot
.35345 .51954 Mdot
.42238 .54379 Mdot
.40673 .30167 Mdot
.24918 .309 Mdot
.32741 .57371 Mdot
.89398 .44869 Mdot
.50359 .54701 Mdot
.5541 .3197 Mdot
.3019 .47328 Mdot
.40577 .44157 Mdot
.44768 .17386 Mdot
.60926 .61004 Mdot
.64576 .5885 Mdot
.55491 .2998 Mdot
.43978 .35536 Mdot
.55821 .49803 Mdot
.35733 .60384 Mdot
.36238 .58669 Mdot
.5786 .3034 Mdot
.56643 .34973 Mdot
.50785 .54846 Mdot
.32569 .60011 Mdot
.35604 .62741 Mdot
.55148 .27901 Mdot
.40782 .56151 Mdot
.36414 .7333 Mdot
.652 .43487 Mdot
.6537 .62989 Mdot
.70074 .44401 Mdot
.65 .44684 Mdot
.60572 .77301 Mdot
.31899 .4355 Mdot
.69131 .46986 Mdot
.71754 .4195 Mdot
.46362 .36353 Mdot
.57125 .75266 Mdot
.40501 .29736 Mdot
.4772 .54105 Mdot
.5546 .33046 Mdot
.37919 .59134 Mdot
.61389 .65013 Mdot
.35463 .30182 Mdot
.77133 .5012 Mdot
.26019 .61587 Mdot
.34128 .56112 Mdot
.54444 .32585 Mdot
.5237 .53239 Mdot
.34227 .61951 Mdot
.26359 .40721 Mdot
.40613 .56999 Mdot
.58929 .33909 Mdot
.5754 .75132 Mdot
.61934 .42518 Mdot
.6375 .45727 Mdot
.58007 .58987 Mdot
.39552 .55514 Mdot
.61175 .64227 Mdot
.66011 .47323 Mdot
.43688 .27694 Mdot
.43722 .29735 Mdot
.41198 .55472 Mdot
.43625 .47039 Mdot
.41211 .33079 Mdot
.36231 .60552 Mdot
.3475 .60794 Mdot
.54108 .54086 Mdot
.34447 .60703 Mdot
.35044 .53015 Mdot
.33706 .57783 Mdot
.34405 .54301 Mdot
.67674 .42108 Mdot
.60491 .76173 Mdot
.33427 .60853 Mdot
.40937 .60642 Mdot
.65397 .46528 Mdot
.41272 .60688 Mdot
.6718 .43684 Mdot
.76428 .46498 Mdot
.70335 .46079 Mdot
.43665 .29534 Mdot
.5978 .31898 Mdot
.66648 .7232 Mdot
.64456 .61497 Mdot
.65681 .44696 Mdot
.41217 .26959 Mdot
.6664 .44066 Mdot
.56394 .33536 Mdot
.62059 .45488 Mdot
.56944 .60246 Mdot
.36331 .43041 Mdot
.56859 .76228 Mdot
.67637 .38943 Mdot
.57481 .34314 Mdot
.64548 .61765 Mdot
.70448 .50398 Mdot
.34615 .56593 Mdot
.4439 .29363 Mdot
.40251 .56481 Mdot
.66833 .46436 Mdot
.55075 .32873 Mdot
.64471 .72176 Mdot
.42845 .29399 Mdot
.81223 .64783 Mdot
.53441 .2826 Mdot
.40767 .54069 Mdot
.6538 .46685 Mdot
.65758 .49536 Mdot
.69313 .42832 Mdot
.23004 .50009 Mdot
.57139 .50609 Mdot
.3717 .32912 Mdot
.6357 .61745 Mdot
.56033 .55031 Mdot
.21359 .67663 Mdot
.78646 .56329 Mdot
.6177 .63464 Mdot
.61151 .35286 Mdot
.41452 .5699 Mdot
.33555 .56993 Mdot
.39108 .63749 Mdot
.59376 .63501 Mdot
.34792 .55296 Mdot
.53224 .55129 Mdot
.3183 .4255 Mdot
.56639 .59754 Mdot
.51434 .29627 Mdot
.36978 .59961 Mdot
.6551 .47251 Mdot
.65543 .44358 Mdot
.552 .55234 Mdot
.69973 .45419 Mdot
.38642 .61022 Mdot
.64438 .62123 Mdot
.51383 .45274 Mdot
.43082 .31427 Mdot
.77861 .61827 Mdot
.4574 .31599 Mdot
.40133 .31459 Mdot
.43067 .55134 Mdot
.55781 .29815 Mdot
.75711 .32295 Mdot
.34523 .56185 Mdot
.62837 .63594 Mdot
.40908 .53895 Mdot
.33434 .57807 Mdot
.38166 .61346 Mdot
.57209 .33081 Mdot
.30583 .44113 Mdot
.40737 .56089 Mdot
.67283 .47651 Mdot
.45963 .47546 Mdot
.44256 .55655 Mdot
.55485 .46288 Mdot
.4646 .46615 Mdot
.67078 .39455 Mdot
.66179 .65637 Mdot
.56433 .29856 Mdot
.62687 .61923 Mdot
.58398 .62155 Mdot
.61399 .60748 Mdot
.58888 .66902 Mdot
.40679 .7598 Mdot
.75143 .29798 Mdot
.53456 .66603 Mdot
.56944 .76552 Mdot
.58043 .61572 Mdot
.65477 .25257 Mdot
.61865 .64023 Mdot
.61248 .60794 Mdot
.83689 .48336 Mdot
.60062 .62524 Mdot
.38843 .58522 Mdot
.42319 .56167 Mdot
.47753 .81908 Mdot
.38772 .28954 Mdot
.38975 .6018 Mdot
.34193 .54277 Mdot
.45079 .2868 Mdot
.69367 .69136 Mdot
.50747 .54006 Mdot
.33097 .45423 Mdot
.55482 .54155 Mdot
.39146 .57168 Mdot
.37505 .55211 Mdot
.44467 .53921 Mdot
.22715 .64289 Mdot
.39388 .3401 Mdot
.5976 .61873 Mdot
.37215 .51832 Mdot
.65618 .38703 Mdot
.35946 .56117 Mdot
.39414 .53598 Mdot
.3729 .61419 Mdot
.56249 .29772 Mdot
.64962 .61051 Mdot
.43668 .62155 Mdot
.79328 .58987 Mdot
.36526 .57472 Mdot
.46257 .30466 Mdot
.41325 .25776 Mdot
.39977 .58005 Mdot
.6013 .61565 Mdot
.33719 .56633 Mdot
.66006 .64122 Mdot
.63169 .612 Mdot
.3862 .63424 Mdot
.62242 .69381 Mdot
.65798 .62433 Mdot
.35668 .60322 Mdot
.58416 .33595 Mdot
.7688 .6407 Mdot
.39859 .58571 Mdot
.42226 .29018 Mdot
.37871 .5619 Mdot
.40692 .30444 Mdot
.32732 .5889 Mdot
.54454 .5391 Mdot
.3071 .70383 Mdot
.52971 .30104 Mdot
.41799 .32307 Mdot
.57309 .34575 Mdot
.4203 .52957 Mdot
.62283 .67833 Mdot
.62004 .43594 Mdot
.42042 .34473 Mdot
.5414 .54173 Mdot
.32172 .35421 Mdot
.4747 .47927 Mdot
.71368 .4467 Mdot
.63978 .65888 Mdot
.59679 .75265 Mdot
.55126 .46067 Mdot
.51363 .29326 Mdot
.58988 .30662 Mdot
.60302 .40544 Mdot
.84163 .50701 Mdot
.41787 .57105 Mdot
.56618 .48111 Mdot
.38774 .71389 Mdot
.4738 .58057 Mdot
.4855 .56749 Mdot
.55516 .28164 Mdot
.38894 .60219 Mdot
.29224 .42381 Mdot
.57113 .32187 Mdot
.41605 .30661 Mdot
.60859 .63036 Mdot
.42121 .27154 Mdot
.7183 .53923 Mdot
.617 .72017 Mdot
.56974 .31443 Mdot
.34299 .54721 Mdot
.39225 .5988 Mdot
.60693 .65106 Mdot
.42342 .67335 Mdot
.65663 .63649 Mdot
.443 .30732 Mdot
.52735 .30918 Mdot
.31756 .21493 Mdot
.38553 .55684 Mdot
.6422 .6369 Mdot
.53118 .26844 Mdot
.37098 .57164 Mdot
.66829 .43166 Mdot
.34999 .55136 Mdot
.64165 .64378 Mdot
.34251 .60605 Mdot
.6347 .61624 Mdot
.58262 .33145 Mdot
.41597 .55693 Mdot
.38581 .54802 Mdot
.30625 .36903 Mdot
.42284 .30547 Mdot
.65914 .62989 Mdot
.29028 .43426 Mdot
.40686 .53425 Mdot
.25251 .42219 Mdot
.40776 .55791 Mdot
.56383 .75714 Mdot
.30455 .56096 Mdot
.53539 .55089 Mdot
.41015 .53891 Mdot
.40061 .58389 Mdot
.42455 .67136 Mdot
.52625 .66342 Mdot
.57679 .69176 Mdot
.66307 .43292 Mdot
.62939 .65452 Mdot
.57498 .3189 Mdot
.52841 .32511 Mdot
.54266 .31211 Mdot
.45864 .29052 Mdot
.33044 .54453 Mdot
.39187 .59241 Mdot
.71352 .42218 Mdot
.43985 .30276 Mdot
.63919 .6311 Mdot
.43539 .29024 Mdot
.31843 .44096 Mdot
.41995 .29208 Mdot
.51625 .54794 Mdot
.62746 .36356 Mdot
.37349 .73786 Mdot
.41173 .29255 Mdot
.65151 .62577 Mdot
.44815 .47844 Mdot
.47148 .58054 Mdot
.73125 .70821 Mdot
.43036 .26174 Mdot
.61778 .34912 Mdot
.40573 .59918 Mdot
.29115 .47587 Mdot
.67245 .43919 Mdot
.42059 .27113 Mdot
.69422 .46414 Mdot
.33764 .56674 Mdot
.60755 .57649 Mdot
.63096 .64514 Mdot
.64999 .43839 Mdot
.39679 .53419 Mdot
.4214 .27088 Mdot
.56675 .31151 Mdot
.5708 .75146 Mdot
.6647 .41445 Mdot
.41622 .37666 Mdot
.26996 .40491 Mdot
.5349 .32123 Mdot
.54613 .74002 Mdot
.70163 .46081 Mdot
.37525 .5182 Mdot
.43164 .5113 Mdot
.40275 .52671 Mdot
.57969 .29836 Mdot
.56284 .30604 Mdot
.72742 .40039 Mdot
.38229 .54779 Mdot
.34585 .61406 Mdot
.66836 .64219 Mdot
.53024 .31601 Mdot
.61556 .60707 Mdot
.62392 .67171 Mdot
.58483 .30993 Mdot
.65829 .64106 Mdot
.4229 .28173 Mdot
.26019 .46008 Mdot
.70039 .46225 Mdot
.68033 .42442 Mdot
.57045 .31237 Mdot
.53978 .29161 Mdot
.55679 .29802 Mdot
.3762 .53349 Mdot
.62784 .60886 Mdot
.3515 .5618 Mdot
.39253 .55563 Mdot
.51539 .53254 Mdot
.65465 .67283 Mdot
.36137 .54998 Mdot
.52217 .4606 Mdot
.43411 .26063 Mdot
.55243 .31498 Mdot
.68347 .46116 Mdot
.39238 .37011 Mdot
.68257 .47549 Mdot
.41912 .53966 Mdot
.72949 .67866 Mdot
.62545 .65256 Mdot
.43064 .3006 Mdot
.46241 .46574 Mdot
.42959 .2966 Mdot
.65134 .43594 Mdot
.66014 .61119 Mdot
.35342 .44715 Mdot
.38856 .54643 Mdot
.31043 .43442 Mdot
.28377 .32621 Mdot
.75863 .6297 Mdot
.67277 .46109 Mdot
.33688 .56277 Mdot
.5454 .55074 Mdot
.41957 .76675 Mdot
.39545 .59092 Mdot
.43792 .5661 Mdot
.42835 .45497 Mdot
.42335 .54761 Mdot
.60695 .59894 Mdot
.48435 .45911 Mdot
.33024 .55927 Mdot
.39737 .52361 Mdot
.7899 .41225 Mdot
.39901 .59998 Mdot
.39614 .54772 Mdot
.37992 .586 Mdot
.35269 .55265 Mdot
.64184 .67433 Mdot
.49424 .4439 Mdot
.65893 .47116 Mdot
.25992 .45995 Mdot
.68802 .46895 Mdot
.57537 .30872 Mdot
.44369 .38888 Mdot
.65803 .65632 Mdot
.429 .29678 Mdot
.57679 .47982 Mdot
.24784 .50409 Mdot
.57962 .33678 Mdot
.323 .34475 Mdot
.40357 .28096 Mdot
.46789 .59143 Mdot
.42775 .3168 Mdot
.57008 .28625 Mdot
.66929 .43236 Mdot
.41183 .54653 Mdot
.62281 .60201 Mdot
.64989 .64142 Mdot
.41968 .53308 Mdot
.79473 .60282 Mdot
.67105 .42714 Mdot
.51931 .37071 Mdot
.40891 .5842 Mdot
.40451 .53442 Mdot
.65748 .65075 Mdot
.53853 .31999 Mdot
.47519 .47769 Mdot
.40721 .2889 Mdot
.3611 .56518 Mdot
.33666 .55205 Mdot
.31742 .43981 Mdot
.65869 .43731 Mdot
.52285 .54376 Mdot
.38332 .59763 Mdot
.32909 .44335 Mdot
.35261 .54761 Mdot
.42381 .5277 Mdot
.58837 .33514 Mdot
.40327 .63129 Mdot
.3716 .5505 Mdot
.57693 .59113 Mdot
.70383 .45809 Mdot
.62705 .62906 Mdot
.61592 .58743 Mdot
.544 .54016 Mdot
.69656 .43405 Mdot
.36622 .54442 Mdot
.66959 .41695 Mdot
.33488 .57367 Mdot
.39574 .56055 Mdot
.67041 .46021 Mdot
.61475 .61048 Mdot
.74421 .50295 Mdot
.60529 .76075 Mdot
.33719 .58684 Mdot
.37587 .56536 Mdot
.38779 .28937 Mdot
.3595 .28194 Mdot
.38139 .54562 Mdot
.64814 .61977 Mdot
.3715 .56777 Mdot
.70579 .43197 Mdot
.44158 .28627 Mdot
.62586 .63876 Mdot
.5419 .32948 Mdot
.58179 .3306 Mdot
.56056 .26988 Mdot
.51562 .54806 Mdot
.34872 .61413 Mdot
.67106 .64604 Mdot
.65397 .67449 Mdot
.27571 .46458 Mdot
.55396 .31861 Mdot
.43548 .28057 Mdot
.37697 .60439 Mdot
.47631 .58161 Mdot
.65237 .4547 Mdot
.89434 .43694 Mdot
.34983 .44677 Mdot
.42682 .25654 Mdot
.46349 .40038 Mdot
.53319 .53785 Mdot
.40583 .59434 Mdot
.4289 .27086 Mdot
.58416 .3146 Mdot
.33552 .56927 Mdot
.307 .55913 Mdot
.62256 .34366 Mdot
.54774 .29345 Mdot
.66638 .41728 Mdot
.55472 .33695 Mdot
.40237 .28875 Mdot
.5195 .54948 Mdot
.6395 .65304 Mdot
.4042 .57564 Mdot
.34499 .62359 Mdot
.55531 .32686 Mdot
.52721 .557 Mdot
.42158 .56504 Mdot
.62739 .65612 Mdot
.54573 .31793 Mdot
.38762 .57484 Mdot
.43175 .76523 Mdot
.66833 .72188 Mdot
.5515 .33071 Mdot
.35795 .5806 Mdot
.47236 .62012 Mdot
.55207 .29302 Mdot
.57039 .28724 Mdot
.33723 .55873 Mdot
.42157 .26821 Mdot
.36684 .55965 Mdot
.67864 .42931 Mdot
.30397 .43635 Mdot
.69838 .439 Mdot
.26172 .40752 Mdot
.35568 .53429 Mdot
.36583 .49832 Mdot
.59353 .64579 Mdot
.4285 .326 Mdot
.19453 .52975 Mdot
.42851 .54637 Mdot
.69839 .66588 Mdot
.30194 .44081 Mdot
.37501 .43922 Mdot
.6909 .62862 Mdot
.40809 .28189 Mdot
.66738 .4446 Mdot
.40663 .55248 Mdot
.73779 .49933 Mdot
.41068 .28117 Mdot
.26048 .40917 Mdot
.35139 .57894 Mdot
.63532 .63713 Mdot
.41209 .57917 Mdot
.63877 .65118 Mdot
.37221 .58149 Mdot
.68618 .71991 Mdot
.40878 .3295 Mdot
.23 .50061 Mdot
.46824 .59026 Mdot
.65684 .49482 Mdot
.56877 .7628 Mdot
.42967 .28233 Mdot
.33934 .5998 Mdot
.52551 .53676 Mdot
.66177 .43917 Mdot
.62095 .48872 Mdot
.55347 .30003 Mdot
.6741 .47593 Mdot
.61601 .61563 Mdot
.59092 .29709 Mdot
.54265 .55655 Mdot
.2817 .57687 Mdot
.42297 .26992 Mdot
.69607 .43291 Mdot
.40167 .58112 Mdot
.40324 .52782 Mdot
.61132 .26502 Mdot
.24123 .31471 Mdot
.6321 .67564 Mdot
.8339 .62195 Mdot
.66394 .61753 Mdot
.42748 .30797 Mdot
.59059 .33002 Mdot
.38143 .57303 Mdot
.36842 .59417 Mdot
.54545 .29466 Mdot
.61115 .65436 Mdot
.40485 .31627 Mdot
.36878 .32235 Mdot
.71433 .42908 Mdot
.24941 .32994 Mdot
.62607 .64248 Mdot
.25034 .32845 Mdot
.48604 .33408 Mdot
.65931 .70732 Mdot
.20808 .49689 Mdot
.67594 .4545 Mdot
.2489 .32975 Mdot
.6381 .63854 Mdot
.41751 .57976 Mdot
.5366 .54427 Mdot
.52191 .55436 Mdot
.61278 .64042 Mdot
.57618 .30089 Mdot
.4051 .28037 Mdot
.41042 .57968 Mdot
.2905 .58399 Mdot
.42301 .67415 Mdot
.52751 .29605 Mdot
.42835 .624 Mdot
.68495 .45563 Mdot
.37246 .56949 Mdot
.45163 .2913 Mdot
.67647 .45312 Mdot
.55086 .5413 Mdot
.24672 .49818 Mdot
.35841 .5869 Mdot
.45124 .47015 Mdot
.67579 .43814 Mdot
.3575 .28271 Mdot
.38306 .54885 Mdot
.7015 .46088 Mdot
.3478 .62469 Mdot
.6658 .38203 Mdot
.50168 .4648 Mdot
.78568 .56345 Mdot
.54137 .27578 Mdot
.56335 .3389 Mdot
.37707 .17623 Mdot
.45487 .18185 Mdot
.67057 .47095 Mdot
.51786 .53452 Mdot
.2473 .30732 Mdot
.70164 .45772 Mdot
.37686 .54306 Mdot
.41405 .56244 Mdot
.5759 .7513 Mdot
.47779 .57297 Mdot
.50498 .54647 Mdot
.54828 .59704 Mdot
.37712 .61107 Mdot
.43611 .61971 Mdot
.39474 .55039 Mdot
.59728 .62432 Mdot
.68334 .4542 Mdot
.33634 .79643 Mdot
.6679 .42088 Mdot
.35644 .50118 Mdot
.55402 .33029 Mdot
.56057 .27517 Mdot
.39989 .57876 Mdot
.52284 .57987 Mdot
.5415 .86641 Mdot
.41308 .55966 Mdot
.46175 .46605 Mdot
.27173 .40246 Mdot
.33939 .53366 Mdot
.63709 .602 Mdot
.34918 .62626 Mdot
.66593 .66558 Mdot
.67191 .45253 Mdot
.40856 .28155 Mdot
.43434 .32699 Mdot
.66873 .44322 Mdot
.37057 .59412 Mdot
.44977 .32003 Mdot
.39846 .57111 Mdot
.40293 .59353 Mdot
.32529 .44593 Mdot
.45078 .29813 Mdot
.56581 .29629 Mdot
.43552 .29674 Mdot
.60644 .61226 Mdot
.86633 .55054 Mdot
.43373 .28566 Mdot
.57158 .75263 Mdot
.29441 .43417 Mdot
.25444 .30687 Mdot
.64996 .64529 Mdot
.42941 .31493 Mdot
.66483 .44845 Mdot
.3691 .45536 Mdot
.54005 .77054 Mdot
.68429 .47479 Mdot
.3891 .59502 Mdot
.63971 .67501 Mdot
.65791 .60956 Mdot
.67602 .47916 Mdot
.64058 .65549 Mdot
.31931 .55175 Mdot
.35005 .5984 Mdot
.66252 .47404 Mdot
.20737 .61078 Mdot
.68077 .42316 Mdot
.61748 .76799 Mdot
.34712 .61115 Mdot
.62716 .63696 Mdot
.56135 .76021 Mdot
.61373 .58468 Mdot
.52921 .5543 Mdot
.39563 .54257 Mdot
.4355 .28331 Mdot
.27487 .45483 Mdot
.54466 .32824 Mdot
.72654 .6698 Mdot
.64793 .63548 Mdot
.68162 .47978 Mdot
.63957 .65516 Mdot
.64451 .65864 Mdot
.64865 .44593 Mdot
.62489 .65115 Mdot
.3653 .57711 Mdot
.69498 .72119 Mdot
.65307 .6479 Mdot
.68041 .44423 Mdot
.44016 .30836 Mdot
.65127 .6239 Mdot
.51157 .37375 Mdot
.37614 .60288 Mdot
.51804 .30332 Mdot
.37906 .26123 Mdot
.62009 .66843 Mdot
.43038 .28132 Mdot
.55243 .32382 Mdot
.41526 .26513 Mdot
.75111 .46637 Mdot
.69606 .50355 Mdot
.30393 .65199 Mdot
.6512 .38133 Mdot
.60123 .62175 Mdot
.5879 .29005 Mdot
.36091 .58003 Mdot
.40754 .58726 Mdot
.45465 .28395 Mdot
.62351 .59371 Mdot
.80386 .58987 Mdot
.49216 .55448 Mdot
.77954 .61653 Mdot
.66221 .43332 Mdot
.49913 .36461 Mdot
.35539 .44541 Mdot
.64369 .4145 Mdot
.32699 .56462 Mdot
.53267 .53824 Mdot
.39278 .57723 Mdot
.30157 .37848 Mdot
.40293 .28815 Mdot
.6558 .27473 Mdot
.38191 .52702 Mdot
.54149 .29671 Mdot
.37463 .58055 Mdot
.55249 .48441 Mdot
.38662 .5232 Mdot
.4386 .26283 Mdot
.71985 .43715 Mdot
.64501 .61538 Mdot
.41791 .3137 Mdot
.58357 .32884 Mdot
.2205 .53038 Mdot
.36922 .54821 Mdot
.38787 .60886 Mdot
.56482 .29186 Mdot
.6172 .60422 Mdot
.57029 .30626 Mdot
.69901 .46338 Mdot
.43244 .28787 Mdot
.36052 .54355 Mdot
.43316 .62053 Mdot
.54244 .34585 Mdot
.65564 .45421 Mdot
.595 .31741 Mdot
.66668 .41848 Mdot
.53819 .5419 Mdot
.39203 .52086 Mdot
.59781 .32752 Mdot
.32581 .56986 Mdot
.53197 .70951 Mdot
.25226 .49907 Mdot
.4443 .6563 Mdot
.57561 .29772 Mdot
.45703 .17286 Mdot
.67716 .44996 Mdot
.70253 .43572 Mdot
.62441 .76741 Mdot
.60004 .84003 Mdot
.46328 .47649 Mdot
.81492 .55895 Mdot
.69932 .46325 Mdot
.68004 .43513 Mdot
.56957 .30266 Mdot
.60705 .61528 Mdot
.59418 .64412 Mdot
.59206 .3067 Mdot
.23781 .45211 Mdot
.63935 .6314 Mdot
.50162 .82369 Mdot
.52301 .29625 Mdot
.3945 .61282 Mdot
.65685 .72143 Mdot
.43533 .2622 Mdot
.28162 .40177 Mdot
.6193 .45619 Mdot
.38431 .58015 Mdot
.76115 .31456 Mdot
.55342 .30179 Mdot
.49839 .55559 Mdot
.71998 .46627 Mdot
.38757 .53066 Mdot
.37618 .58587 Mdot
.3677 .56982 Mdot
.44371 .2617 Mdot
.50671 .67055 Mdot
.38293 .577 Mdot
.23926 .50117 Mdot
.43626 .58656 Mdot
.62687 .28731 Mdot
.43562 .29633 Mdot
.32571 .32944 Mdot
.60187 .34671 Mdot
.79737 .58064 Mdot
.43603 .56023 Mdot
.7095 .44154 Mdot
.53604 .46783 Mdot
.67036 .46215 Mdot
.68802 .39591 Mdot
.22722 .36159 Mdot
.60905 .59957 Mdot
.37946 .52869 Mdot
.53328 .28819 Mdot
.59836 .65353 Mdot
.53074 .46394 Mdot
.86574 .56174 Mdot
.69555 .4754 Mdot
.76957 .75399 Mdot
.70432 .44521 Mdot
.50861 .54968 Mdot
.61433 .61913 Mdot
.50677 .60575 Mdot
.31244 .43468 Mdot
.61515 .60785 Mdot
.52171 .19895 Mdot
.66546 .66837 Mdot
.20989 .43972 Mdot
.57054 .60415 Mdot
.68547 .44525 Mdot
.67695 .47956 Mdot
.306 .56844 Mdot
.36604 .55851 Mdot
.30872 .42339 Mdot
.4829 .56664 Mdot
.35829 .59078 Mdot
.57123 .32226 Mdot
.64952 .38017 Mdot
.74253 .49335 Mdot
.62181 .64759 Mdot
.65622 .45965 Mdot
.37559 .58289 Mdot
.33705 .58812 Mdot
.42201 .55363 Mdot
.43779 .35627 Mdot
.49137 .82442 Mdot
.39826 .55862 Mdot
.41681 .52615 Mdot
.58296 .33465 Mdot
.60995 .2624 Mdot
.83939 .54348 Mdot
.23678 .34438 Mdot
.42169 .58305 Mdot
.42956 .30558 Mdot
.45411 .29772 Mdot
.31762 .54455 Mdot
.51348 .59763 Mdot
.45181 .25671 Mdot
.40133 .58165 Mdot
.22892 .52007 Mdot
.52282 .32272 Mdot
.55037 .5522 Mdot
.55566 .32651 Mdot
.58562 .63109 Mdot
.54577 .54878 Mdot
.57919 .3206 Mdot
.23566 .48625 Mdot
.53814 .53459 Mdot
.68778 .3843 Mdot
.43437 .31353 Mdot
.38978 .54937 Mdot
.60609 .74185 Mdot
.53048 .31711 Mdot
.68511 .43129 Mdot
.61901 .62253 Mdot
.66496 .43176 Mdot
.63095 .34119 Mdot
.24777 .43408 Mdot
.52744 .55219 Mdot
.70923 .44027 Mdot
.44835 .47168 Mdot
.43382 .304 Mdot
.7021 .4524 Mdot
.41601 .50327 Mdot
.44414 .56038 Mdot
.51233 .85228 Mdot
.3849 .60739 Mdot
.72862 .40254 Mdot
.69633 .4309 Mdot
.55212 .54627 Mdot
.40492 .5738 Mdot
.52903 .28444 Mdot
.29769 .60938 Mdot
.39757 .57006 Mdot
.53947 .32949 Mdot
.41337 .56456 Mdot
.44306 .28067 Mdot
.66498 .61629 Mdot
.30031 .4448 Mdot
.4307 .37951 Mdot
.40435 .2908 Mdot
.26585 .49544 Mdot
.38308 .54486 Mdot
.48409 .18994 Mdot
.63444 .63375 Mdot
.42054 .54071 Mdot
.26098 .38887 Mdot
.60584 .62841 Mdot
.62896 .6185 Mdot
.35498 .60877 Mdot
.6967 .42432 Mdot
.56695 .29473 Mdot
.43541 .30176 Mdot
.65294 .42016 Mdot
.38595 .57437 Mdot
.33747 .56233 Mdot
.40499 .29534 Mdot
.69078 .43251 Mdot
.36236 .54331 Mdot
.72288 .59511 Mdot
.25811 .46772 Mdot
.65291 .43477 Mdot
.44251 .55576 Mdot
.53438 .82157 Mdot
.631 .66242 Mdot
.75914 .31115 Mdot
.40681 .32858 Mdot
.5891 .31733 Mdot
.40966 .63163 Mdot
.89075 .46318 Mdot
.44178 .30828 Mdot
.77391 .61416 Mdot
.41772 .57496 Mdot
.38056 .56776 Mdot
.59888 .62246 Mdot
.35434 .55892 Mdot
.62752 .65401 Mdot
.48201 .36705 Mdot
.62505 .82749 Mdot
.64708 .64916 Mdot
.63874 .64716 Mdot
.46149 .53763 Mdot
.44876 .32939 Mdot
.60985 .63024 Mdot
.36658 .55187 Mdot
.52121 .18211 Mdot
.36912 .50986 Mdot
.39918 .30509 Mdot
.42371 .25083 Mdot
.64157 .60671 Mdot
.54108 .77723 Mdot
.44134 .5218 Mdot
.49817 .80909 Mdot
.4432 .25111 Mdot
.67551 .47163 Mdot
.33001 .57981 Mdot
.51406 .537 Mdot
.54907 .31452 Mdot
.35537 .62936 Mdot
.38294 .54977 Mdot
.62295 .59945 Mdot
.42112 .25872 Mdot
.69842 .4595 Mdot
.32296 .58453 Mdot
.51463 .31435 Mdot
.40821 .29512 Mdot
.65537 .65053 Mdot
.58568 .77338 Mdot
.45327 .31558 Mdot
.41702 .63137 Mdot
.4154 .58659 Mdot
.33801 .60911 Mdot
.4712 .58905 Mdot
.66998 .44353 Mdot
.58561 .29463 Mdot
.41448 .63201 Mdot
.33549 .45986 Mdot
.25319 .45939 Mdot
.42811 .56672 Mdot
.64967 .62161 Mdot
.6584 .44598 Mdot
.51963 .54731 Mdot
.25199 .30376 Mdot
.40775 .59946 Mdot
.50206 .82424 Mdot
.3896 .3555 Mdot
.52679 .53434 Mdot
.60315 .66107 Mdot
.43189 .29937 Mdot
.34595 .60901 Mdot
.23625 .49994 Mdot
.35623 .58702 Mdot
.36825 .51835 Mdot
.58384 .30552 Mdot
.68379 .46683 Mdot
.30098 .64799 Mdot
.55223 .31229 Mdot
.62755 .61895 Mdot
.45747 .80743 Mdot
.60532 .65718 Mdot
.62409 .67218 Mdot
.63805 .69729 Mdot
.68101 .42616 Mdot
.89214 .45815 Mdot
.36317 .27575 Mdot
.4185 .55513 Mdot
.70775 .45843 Mdot
.6132 .63181 Mdot
.366 .54739 Mdot
.62591 .65298 Mdot
.64518 .60701 Mdot
.36624 .60364 Mdot
.35942 .60094 Mdot
.23128 .50411 Mdot
.53034 .81574 Mdot
.44349 .29299 Mdot
.60809 .65082 Mdot
.53465 .80272 Mdot
.38272 .57127 Mdot
.37168 .55333 Mdot
.53882 .46907 Mdot
.41334 .31287 Mdot
.34228 .73777 Mdot
.41179 .58333 Mdot
.30679 .365 Mdot
.37947 .54343 Mdot
.58305 .60055 Mdot
.64038 .4624 Mdot
.37987 .49782 Mdot
.59358 .31719 Mdot
.60967 .65372 Mdot
.42768 .25815 Mdot
.59489 .65533 Mdot
.38533 .74615 Mdot
.66485 .44085 Mdot
.64148 .64388 Mdot
.58538 .29162 Mdot
.69054 .436 Mdot
.68256 .42335 Mdot
.52855 .46166 Mdot
.56997 .28094 Mdot
.41886 .25861 Mdot
.69036 .45642 Mdot
.43859 .76648 Mdot
.68751 .44296 Mdot
.37872 .75075 Mdot
.41326 .59854 Mdot
.23922 .49973 Mdot
.34944 .62978 Mdot
.30674 .55572 Mdot
.69661 .44697 Mdot
.40625 .29319 Mdot
.36723 .54058 Mdot
.64701 .65527 Mdot
.43782 .30728 Mdot
.6155 .71701 Mdot
.57737 .2819 Mdot
.66801 .63189 Mdot
.6829 .41283 Mdot
.60362 .63942 Mdot
.27441 .40372 Mdot
.41036 .25616 Mdot
.54385 .45313 Mdot
.313 .44968 Mdot
.45125 .60846 Mdot
.40578 .52533 Mdot
.37317 .53719 Mdot
.36604 .58179 Mdot
.55494 .33128 Mdot
.45148 .26994 Mdot
.65586 .63154 Mdot
.32313 .67957 Mdot
.68749 .42874 Mdot
.47614 .46423 Mdot
.47001 .58981 Mdot
.33579 .57145 Mdot
.6153 .6322 Mdot
.65331 .61582 Mdot
.52118 .66285 Mdot
.54878 .29574 Mdot
.33545 .5236 Mdot
.42967 .55324 Mdot
.29164 .63665 Mdot
.69749 .44387 Mdot
.77017 .5711 Mdot
.5207 .31663 Mdot
.77752 .74874 Mdot
.55383 .31335 Mdot
.51152 .42717 Mdot
.6186 .65062 Mdot
.42079 .28738 Mdot
.37688 .59874 Mdot
.55721 .62743 Mdot
.63164 .67802 Mdot
.57343 .256 Mdot
.4262 .29591 Mdot
.76842 .44845 Mdot
.69615 .46737 Mdot
.3227 .58247 Mdot
.37891 .54331 Mdot
.34447 .57606 Mdot
.35733 .56498 Mdot
.66586 .47109 Mdot
.35218 .59263 Mdot
.66182 .41715 Mdot
.38008 .74174 Mdot
.25699 .39104 Mdot
.55779 .28422 Mdot
.61842 .25347 Mdot
.62871 .67241 Mdot
.38271 .77257 Mdot
.35657 .73716 Mdot
.25192 .4976 Mdot
.70734 .40481 Mdot
.33739 .54189 Mdot
.5709 .29977 Mdot
.72223 .50229 Mdot
.55397 .28385 Mdot
.39014 .82602 Mdot
.57784 .75251 Mdot
.76232 .43022 Mdot
.34763 .57519 Mdot
.58232 .29724 Mdot
.54259 .78446 Mdot
.37661 .6396 Mdot
.449 .32 Mdot
.40228 .7552 Mdot
.58728 .70085 Mdot
.44447 .29026 Mdot
.38745 .60141 Mdot
.65327 .67367 Mdot
.37294 .59735 Mdot
.37974 .60001 Mdot
.42121 .56831 Mdot
.64991 .46156 Mdot
.41883 .59316 Mdot
.36493 .5669 Mdot
.27024 .25637 Mdot
.49767 .27638 Mdot
.56171 .33966 Mdot
.47882 .6318 Mdot
.44002 .30268 Mdot
.58523 .63035 Mdot
.30465 .44666 Mdot
.69845 .42933 Mdot
.51828 .66242 Mdot
.35085 .6043 Mdot
.74909 .64786 Mdot
.68345 .4197 Mdot
.418 .26816 Mdot
.51663 .53678 Mdot
.78232 .49381 Mdot
.58461 .34283 Mdot
.50711 .54388 Mdot
.5383 .32367 Mdot
.28289 .65347 Mdot
.63421 .65224 Mdot
.451 .6086 Mdot
.69534 .45984 Mdot
.55221 .28192 Mdot
.24113 .50623 Mdot
.37256 .56104 Mdot
.57737 .2983 Mdot
.3788 .63684 Mdot
.27653 .45121 Mdot
.30326 .44003 Mdot
.57314 .28629 Mdot
.71225 .42877 Mdot
.69549 .43972 Mdot
.44747 .29878 Mdot
.63459 .66091 Mdot
.61761 .60248 Mdot
.69149 .44332 Mdot
.78501 .39355 Mdot
.38649 .57611 Mdot
.39173 .55806 Mdot
.34478 .45259 Mdot
.38551 .53741 Mdot
.38909 .2843 Mdot
.50179 .5467 Mdot
.62942 .604 Mdot
.37091 .53864 Mdot
.36107 .5445 Mdot
.40757 .59662 Mdot
.23171 .45772 Mdot
.55129 .3266 Mdot
.37414 .61162 Mdot
.42534 .27049 Mdot
.60581 .71381 Mdot
.3617 .57666 Mdot
.41362 .63341 Mdot
.62141 .65372 Mdot
.60717 .40755 Mdot
.68307 .43109 Mdot
.53069 .29469 Mdot
.53253 .29008 Mdot
.27425 .33598 Mdot
.60107 .64781 Mdot
.50472 .54522 Mdot
.62432 .34149 Mdot
.51574 .54641 Mdot
.42323 .29542 Mdot
.49399 .46935 Mdot
.60807 .32738 Mdot
.55968 .33893 Mdot
.64952 .47711 Mdot
.40953 .53269 Mdot
.36183 .5707 Mdot
.79647 .59192 Mdot
.40525 .55564 Mdot
.43902 .2852 Mdot
.71456 .44279 Mdot
.63938 .64352 Mdot
.44529 .28035 Mdot
.70623 .44141 Mdot
.61719 .60575 Mdot
.43034 .59436 Mdot
.37177 .54552 Mdot
.62215 .61888 Mdot
.65297 .65477 Mdot
.39071 .58647 Mdot
.2126 .38661 Mdot
.63759 .60788 Mdot
.61733 .6204 Mdot
.59994 .71017 Mdot
.58101 .34298 Mdot
.29828 .61139 Mdot
.70623 .43347 Mdot
.36581 .56672 Mdot
.55829 .28596 Mdot
.41567 .29684 Mdot
.64781 .62627 Mdot
.32915 .57662 Mdot
.38892 .56854 Mdot
.42993 .30479 Mdot
.43718 .31601 Mdot
.42219 .31338 Mdot
.67457 .47897 Mdot
.35602 .60302 Mdot
.61084 .6242 Mdot
.68138 .4747 Mdot
.45209 .28359 Mdot
.41452 .31605 Mdot
.19976 .47128 Mdot
.38654 .58176 Mdot
.45164 .30837 Mdot
.86911 .53532 Mdot
.21805 .50568 Mdot
.54373 .55515 Mdot
.52832 .27298 Mdot
.46149 .16841 Mdot
.3796 .25707 Mdot
.67713 .46792 Mdot
.47478 .46202 Mdot
.40052 .28385 Mdot
.32655 .59515 Mdot
.3821 .55617 Mdot
.46283 .59198 Mdot
.43456 .30849 Mdot
.24765 .43257 Mdot
.60591 .60229 Mdot
.41705 .69655 Mdot
.44026 .30232 Mdot
.56082 .2805 Mdot
.53342 .33945 Mdot
.55991 .30798 Mdot
.37941 .52251 Mdot
.27786 .65386 Mdot
.4311 .74958 Mdot
.33748 .73127 Mdot
.70267 .46189 Mdot
.6505 .61206 Mdot
.63769 .72342 Mdot
.63059 .61834 Mdot
.54014 .3123 Mdot
.40641 .29072 Mdot
.6005 .61449 Mdot
.67737 .42481 Mdot
.69587 .44235 Mdot
.59459 .33443 Mdot
.55524 .32248 Mdot
.56828 .31311 Mdot
.62008 .65946 Mdot
.62142 .6512 Mdot
.3501 .5598 Mdot
.65345 .63823 Mdot
.4235 .34874 Mdot
.4621 .3614 Mdot
.57575 .35333 Mdot
.67436 .44483 Mdot
.63309 .61307 Mdot
.39272 .54875 Mdot
.43934 .44501 Mdot
.59556 .35857 Mdot
.43711 .26445 Mdot
.70493 .71913 Mdot
.58792 .85106 Mdot
.36664 .53484 Mdot
.6601 .4616 Mdot
.49249 .5574 Mdot
.36813 .58204 Mdot
.58994 .31334 Mdot
.37011 .33842 Mdot
.53942 .53352 Mdot
.36273 .59333 Mdot
.4309 .58985 Mdot
.66329 .43846 Mdot
.306 .44937 Mdot
.32406 .58768 Mdot
.5094 .44856 Mdot
.71748 .43516 Mdot
.52683 .32471 Mdot
.40934 .16098 Mdot
.55425 .59856 Mdot
.32344 .37037 Mdot
.54783 .54682 Mdot
.41087 .59791 Mdot
.57029 .32532 Mdot
.43599 .26967 Mdot
.56548 .32207 Mdot
.58133 .61769 Mdot
.58511 .3411 Mdot
.40886 .55566 Mdot
.60909 .62551 Mdot
.69535 .43314 Mdot
.39738 .44231 Mdot
.34958 .67524 Mdot
.52444 .28765 Mdot
.52359 .55686 Mdot
.36037 .60081 Mdot
.43453 .76977 Mdot
.30589 .55746 Mdot
.37016 .55206 Mdot
.67109 .46102 Mdot
.61847 .64218 Mdot
.66021 .43702 Mdot
.29651 .60573 Mdot
.63391 .57416 Mdot
.67876 .43096 Mdot
.41555 .49942 Mdot
.40319 .28342 Mdot
.24262 .44282 Mdot
.40778 .57781 Mdot
.69358 .46206 Mdot
.37497 .60619 Mdot
.60323 .64507 Mdot
.24353 .4764 Mdot
.25721 .47718 Mdot
.68109 .45633 Mdot
.56963 .49681 Mdot
.28934 .43659 Mdot
.299 .61238 Mdot
.6919 .46751 Mdot
.20513 .54815 Mdot
.52186 .53902 Mdot
.40914 .29384 Mdot
.42663 .31905 Mdot
.41718 .27969 Mdot
.39101 .55561 Mdot
.55532 .80183 Mdot
.44785 .30279 Mdot
.71737 .45744 Mdot
.43683 .27717 Mdot
.41014 .37445 Mdot
.79758 .60008 Mdot
.40357 .28547 Mdot
.40924 .57025 Mdot
.31746 .51916 Mdot
.46835 .46459 Mdot
.53838 .27763 Mdot
.75582 .50653 Mdot
.28039 .24652 Mdot
.38103 .5739 Mdot
.68597 .7213 Mdot
.60711 .5823 Mdot
.50568 .41812 Mdot
.25502 .48591 Mdot
.41105 .46653 Mdot
.62395 .6136 Mdot
.30956 .44926 Mdot
.65275 .66467 Mdot
.45039 .61097 Mdot
.39707 .56013 Mdot
.60787 .65246 Mdot
.72279 .67283 Mdot
.19213 .53852 Mdot
.77111 .63018 Mdot
.6279 .60833 Mdot
.70403 .45781 Mdot
.66519 .46152 Mdot
.674 .46154 Mdot
.56627 .33282 Mdot
.64253 .64638 Mdot
.38473 .61154 Mdot
.58682 .32593 Mdot
.395 .59547 Mdot
.68653 .45111 Mdot
.2516 .49021 Mdot
.63815 .64652 Mdot
.40164 .58241 Mdot
.53787 .79361 Mdot
.53437 .3179 Mdot
.43266 .30561 Mdot
.70053 .71939 Mdot
.56684 .27233 Mdot
.68403 .41808 Mdot
.57951 .60976 Mdot
.50729 .27275 Mdot
.49275 .44294 Mdot
.42693 .5686 Mdot
.41008 .54636 Mdot
.47434 .45947 Mdot
.58396 .75842 Mdot
.32908 .56659 Mdot
.58266 .32976 Mdot
.57091 .34356 Mdot
.38349 .6051 Mdot
.64548 .64584 Mdot
.39873 .2815 Mdot
.45832 .30537 Mdot
.41431 .52131 Mdot
.30861 .43605 Mdot
.23965 .50103 Mdot
.36379 .54588 Mdot
.45272 .5933 Mdot
.58378 .28987 Mdot
.54607 .55507 Mdot
.31626 .44067 Mdot
.42373 .28088 Mdot
.41481 .58302 Mdot
.44381 .6608 Mdot
.64678 .63402 Mdot
.57394 .29657 Mdot
.65342 .46972 Mdot
.45198 .31743 Mdot
.57513 .35198 Mdot
.38375 .60505 Mdot
.36181 .5439 Mdot
.69964 .4552 Mdot
.58307 .60313 Mdot
.41658 .30745 Mdot
.58647 .32817 Mdot
.42242 .28485 Mdot
.62834 .65051 Mdot
.64703 .6224 Mdot
.42539 .55572 Mdot
.31557 .5388 Mdot
.52292 .29292 Mdot
.35985 .52329 Mdot
.57994 .31036 Mdot
.61159 .26503 Mdot
.65242 .45516 Mdot
.42096 .54183 Mdot
.58972 .63187 Mdot
.68957 .44857 Mdot
.37895 .57742 Mdot
.48152 .45516 Mdot
.35119 .55114 Mdot
.5813 .29472 Mdot
.35906 .31677 Mdot
.41226 .28755 Mdot
.37896 .62342 Mdot
.55665 .67213 Mdot
.37884 .53886 Mdot
.53525 .32951 Mdot
.42812 .75795 Mdot
.67256 .43467 Mdot
.6108 .6442 Mdot
.61156 .36126 Mdot
.68284 .44346 Mdot
.41326 .57081 Mdot
.43466 .28616 Mdot
.65915 .64034 Mdot
.54112 .55117 Mdot
.32294 .41615 Mdot
.29959 .57771 Mdot
.35089 .51655 Mdot
.32602 .57427 Mdot
.8146 .56542 Mdot
.56746 .31592 Mdot
.61417 .63057 Mdot
.66248 .46377 Mdot
.66692 .43774 Mdot
.5378 .31924 Mdot
.58128 .69312 Mdot
.74395 .67575 Mdot
.87679 .51076 Mdot
.56851 .35421 Mdot
.42464 .27601 Mdot
.24442 .47744 Mdot
.56006 .30652 Mdot
.54783 .33084 Mdot
.59915 .30546 Mdot
.79971 .58493 Mdot
.62008 .60935 Mdot
.38815 .5679 Mdot
.67576 .72133 Mdot
.42024 .56754 Mdot
.32478 .37675 Mdot
.6856 .45085 Mdot
.61049 .64412 Mdot
.4936 .37814 Mdot
.39217 .52303 Mdot
.37342 .59044 Mdot
.51998 .37461 Mdot
.48789 .55999 Mdot
.25128 .31357 Mdot
.41235 .54223 Mdot
.5621 .32764 Mdot
.68421 .64705 Mdot
.42025 .62939 Mdot
.53874 .79447 Mdot
.69896 .43956 Mdot
.52563 .55251 Mdot
.43569 .62193 Mdot
.46364 .57912 Mdot
.65055 .66668 Mdot
.60358 .60854 Mdot
.43095 .31666 Mdot
.70292 .6934 Mdot
.69953 .43799 Mdot
.78298 .5581 Mdot
.37064 .55071 Mdot
.67938 .39569 Mdot
.37322 .33191 Mdot
.37977 .58336 Mdot
.52516 .46015 Mdot
.52142 .66245 Mdot
.33351 .56526 Mdot
.34276 .72487 Mdot
.67855 .44808 Mdot
.27273 .38486 Mdot
.35148 .5843 Mdot
.57698 .2991 Mdot
.60457 .61885 Mdot
.6688 .63494 Mdot
.44101 .27202 Mdot
.40063 .33503 Mdot
.67622 .80475 Mdot
.60915 .64291 Mdot
.37161 .56028 Mdot
.67817 .43421 Mdot
.53492 .55363 Mdot
.34639 .62669 Mdot
.56794 .49005 Mdot
.6458 .63179 Mdot
.39045 .63785 Mdot
.74729 .65193 Mdot
.30772 .44871 Mdot
.40325 .78813 Mdot
.68038 .46006 Mdot
.43204 .27841 Mdot
.41633 .51717 Mdot
.62046 .29738 Mdot
.37476 .54382 Mdot
.32415 .37479 Mdot
.63927 .58862 Mdot
.43752 .28228 Mdot
.37072 .59281 Mdot
.33191 .55815 Mdot
.27452 .49266 Mdot
.39769 .30477 Mdot
.32562 .57877 Mdot
.37033 .53207 Mdot
.60303 .61599 Mdot
.50211 .5474 Mdot
.64 .64031 Mdot
.37604 .59711 Mdot
.33985 .28761 Mdot
.60813 .64912 Mdot
.74603 .50626 Mdot
.46219 .30204 Mdot
.70106 .43094 Mdot
.39804 .63192 Mdot
.42485 .57803 Mdot
.40324 .79498 Mdot
.52759 .55447 Mdot
.78785 .43143 Mdot
.57594 .29324 Mdot
.23113 .31624 Mdot
.57467 .27421 Mdot
.74076 .42564 Mdot
.61274 .47578 Mdot
.43221 .61987 Mdot
.57467 .68707 Mdot
.32859 .73062 Mdot
.7136 .422 Mdot
.36877 .7681 Mdot
.36593 .55878 Mdot
.4123 .58966 Mdot
.58018 .30736 Mdot
.7044 .40028 Mdot
.37815 .49769 Mdot
.31553 .43976 Mdot
.41458 .26974 Mdot
.62919 .62819 Mdot
.38588 .553 Mdot
.71746 .67491 Mdot
.54652 .28072 Mdot
.40836 .67365 Mdot
.40453 .57832 Mdot
.49037 .55698 Mdot
.71029 .40466 Mdot
.69543 .43236 Mdot
.57794 .28807 Mdot
.56236 .27943 Mdot
.4168 .58948 Mdot
.66134 .4722 Mdot
.34323 .56948 Mdot
.28561 .43938 Mdot
.39403 .63506 Mdot
.42142 .29771 Mdot
.38354 .54693 Mdot
.53206 .6098 Mdot
.20158 .65071 Mdot
.39777 .52487 Mdot
.62231 .67047 Mdot
.57203 .31135 Mdot
.54533 .32256 Mdot
.62084 .60257 Mdot
.54418 .32178 Mdot
.41994 .69688 Mdot
.55461 .80495 Mdot
.42254 .29253 Mdot
.39426 .72778 Mdot
.40982 .28034 Mdot
.52363 .55194 Mdot
.38774 .58359 Mdot
.66678 .25246 Mdot
.56349 .353 Mdot
.39302 .37049 Mdot
.68927 .44476 Mdot
.5211 .55376 Mdot
.35599 .60021 Mdot
.40884 .25007 Mdot
.5503 .30676 Mdot
.50107 .55545 Mdot
.42078 .57147 Mdot
.61606 .65713 Mdot
.33382 .57081 Mdot
.48751 .56503 Mdot
.50405 .54723 Mdot
.34094 .54483 Mdot
.70624 .44133 Mdot
.6313 .65547 Mdot
.77099 .43826 Mdot
.53468 .32249 Mdot
.36141 .59685 Mdot
.3698 .5642 Mdot
.66123 .6378 Mdot
.41667 .55421 Mdot
.66696 .4757 Mdot
.88245 .40144 Mdot
.41435 .31022 Mdot
.54814 .55356 Mdot
.7181 .53926 Mdot
.34003 .54469 Mdot
.37369 .53436 Mdot
.43042 .48245 Mdot
.42311 .67369 Mdot
.70335 .43424 Mdot
.33881 .52725 Mdot
.57053 .34128 Mdot
.41289 .30427 Mdot
.67345 .42512 Mdot
.34923 .59686 Mdot
.41154 .5625 Mdot
.43596 .28197 Mdot
.51259 .37901 Mdot
.41312 .31986 Mdot
.67361 .4705 Mdot
.56775 .53393 Mdot
.44159 .4442 Mdot
.39288 .57517 Mdot
.49804 .54916 Mdot
.61984 .63885 Mdot
.6839 .4718 Mdot
.50525 .67445 Mdot
.45196 .60967 Mdot
.6769 .41278 Mdot
.69673 .43417 Mdot
.4263 .56917 Mdot
.6033 .64992 Mdot
.57917 .59302 Mdot
.61752 .63555 Mdot
.25848 .37687 Mdot
.77581 .42442 Mdot
.5715 .315 Mdot
.67635 .44385 Mdot
.55445 .28731 Mdot
.40108 .28841 Mdot
.25962 .45301 Mdot
.54321 .2793 Mdot
.59328 .61467 Mdot
.54812 .28548 Mdot
.345 .56525 Mdot
.69555 .425 Mdot
.52187 .30076 Mdot
.3611 .55392 Mdot
.44453 .53875 Mdot
.47876 .57472 Mdot
.40918 .26388 Mdot
.30716 .44186 Mdot
.41105 .57741 Mdot
.5165 .53757 Mdot
.3965 .58374 Mdot
.66433 .47459 Mdot
.39078 .43211 Mdot
.37877 .60914 Mdot
.563 .35308 Mdot
.80766 .46709 Mdot
.56329 .34495 Mdot
.45686 .63268 Mdot
.39088 .5944 Mdot
.39009 .57722 Mdot
.36138 .60235 Mdot
.59528 .71089 Mdot
.6756 .41658 Mdot
.34231 .52715 Mdot
.5945 .31551 Mdot
.63355 .61739 Mdot
.59626 .6314 Mdot
.45265 .48238 Mdot
.5078 .54245 Mdot
.66676 .47739 Mdot
.38847 .57668 Mdot
.49752 .55324 Mdot
.33932 .43934 Mdot
.75882 .65111 Mdot
.53564 .26897 Mdot
.54374 .33397 Mdot
.64063 .66321 Mdot
.56644 .33668 Mdot
.3507 .59584 Mdot
.39816 .63628 Mdot
.77318 .44228 Mdot
.69389 .48047 Mdot
.41266 .30312 Mdot
.38999 .59689 Mdot
.22234 .47044 Mdot
.58306 .33449 Mdot
.57702 .2852 Mdot
.34309 .57154 Mdot
.62852 .58128 Mdot
.17745 .59272 Mdot
.70829 .4582 Mdot
.45523 .77963 Mdot
.62678 .75738 Mdot
.26404 .60251 Mdot
.668 .4422 Mdot
.51981 .45699 Mdot
.5299 .27961 Mdot
.33652 .26065 Mdot
.62913 .61571 Mdot
.41601 .30633 Mdot
.36488 .55166 Mdot
.59387 .61237 Mdot
.57757 .35527 Mdot
.65711 .62954 Mdot
.44156 .616 Mdot
.68591 .42051 Mdot
.54843 .31761 Mdot
.6641 .48071 Mdot
.59421 .64784 Mdot
.4103 .28251 Mdot
.30674 .36906 Mdot
.42609 .76569 Mdot
.52549 .66283 Mdot
.37161 .61197 Mdot
.49012 .27901 Mdot
.37912 .61281 Mdot
.65752 .60767 Mdot
.40827 .57682 Mdot
.44452 .55005 Mdot
.55022 .27475 Mdot
.42812 .56611 Mdot
.3761 .54899 Mdot
.53624 .79715 Mdot
.37812 .58723 Mdot
.39445 .60144 Mdot
.42867 .56083 Mdot
.59462 .6356 Mdot
.42399 .55788 Mdot
.63489 .65925 Mdot
.76379 .62826 Mdot
.53449 .32123 Mdot
.40146 .29282 Mdot
.40233 .28961 Mdot
.33372 .36827 Mdot
.22504 .4665 Mdot
.65928 .72245 Mdot
.63991 .62755 Mdot
.69657 .44579 Mdot
.34645 .56475 Mdot
.18352 .50954 Mdot
.33628 .29797 Mdot
.51605 .29653 Mdot
.52896 .2885 Mdot
.35915 .5716 Mdot
.56875 .85827 Mdot
.40552 .54047 Mdot
.35064 .44724 Mdot
.39206 .55559 Mdot
.41656 .53931 Mdot
.5943 .30067 Mdot
.27611 .40299 Mdot
.37485 .61156 Mdot
.64861 .66859 Mdot
.41616 .30451 Mdot
.49042 .55832 Mdot
.3338 .32164 Mdot
.60813 .7724 Mdot
.54251 .5927 Mdot
.36773 .60782 Mdot
.58964 .32269 Mdot
.63963 .61187 Mdot
.33825 .45295 Mdot
.68016 .4746 Mdot
.31342 .41485 Mdot
.37172 .74774 Mdot
.72019 .42441 Mdot
.40947 .29756 Mdot
.57599 .35905 Mdot
.42115 .5825 Mdot
.57303 .32744 Mdot
.34428 .529 Mdot
.34457 .43564 Mdot
.42053 .29433 Mdot
.67016 .66343 Mdot
.70589 .45535 Mdot
.59646 .60986 Mdot
.44606 .65507 Mdot
.33684 .29379 Mdot
.23517 .29989 Mdot
.57021 .35045 Mdot
.35516 .69213 Mdot
.61152 .63911 Mdot
.41016 .59783 Mdot
.87543 .51084 Mdot
.62499 .64172 Mdot
.61268 .65541 Mdot
.35519 .42474 Mdot
.26278 .40535 Mdot
.35164 .52648 Mdot
.63976 .60836 Mdot
.57574 .35873 Mdot
.43044 .29587 Mdot
.35715 .56032 Mdot
.43476 .62187 Mdot
.59965 .61741 Mdot
.54432 .3091 Mdot
.29105 .3987 Mdot
.55838 .32568 Mdot
.61471 .61241 Mdot
.52955 .30143 Mdot
.75396 .4753 Mdot
.53958 .28029 Mdot
.40419 .54915 Mdot
.38935 .5761 Mdot
.56709 .60507 Mdot
.64708 .62245 Mdot
.37333 .53486 Mdot
.41777 .57144 Mdot
.61092 .62975 Mdot
.60516 .35487 Mdot
.46456 .65273 Mdot
.37779 .53121 Mdot
.38702 .5726 Mdot
.41245 .31077 Mdot
.29275 .45874 Mdot
.37291 .45164 Mdot
.36354 .54891 Mdot
.41862 .27725 Mdot
.62299 .6601 Mdot
.39374 .58603 Mdot
.27787 .40062 Mdot
.52151 .32197 Mdot
.34287 .58696 Mdot
.53811 .55101 Mdot
.38003 .61393 Mdot
.22576 .63868 Mdot
.35856 .59863 Mdot
.6165 .61625 Mdot
.60539 .625 Mdot
.61085 .35576 Mdot
.62469 .62063 Mdot
.54425 .55445 Mdot
.69444 .44004 Mdot
.42867 .78283 Mdot
.53743 .55634 Mdot
.3388 .55237 Mdot
.36418 .27424 Mdot
.42775 .62652 Mdot
.36316 .63948 Mdot
.4353 .33285 Mdot
.54675 .54574 Mdot
.61904 .64586 Mdot
.71427 .64836 Mdot
.31207 .56439 Mdot
.67112 .47752 Mdot
.42305 .62828 Mdot
.34235 .58811 Mdot
.44288 .55078 Mdot
.60816 .57148 Mdot
.68947 .47265 Mdot
.29235 .60508 Mdot
.35705 .56018 Mdot
.42874 .67032 Mdot
.38175 .55281 Mdot
.42418 .26244 Mdot
.63601 .64475 Mdot
.57119 .3346 Mdot
.42518 .29902 Mdot
.32483 .57839 Mdot
.43972 .30426 Mdot
.57374 .32262 Mdot
.69213 .45862 Mdot
.4075 .55147 Mdot
.39794 .3019 Mdot
.40627 .28031 Mdot
.33681 .59968 Mdot
.60392 .62958 Mdot
.30541 .56099 Mdot
.38973 .58751 Mdot
.3625 .60394 Mdot
.61561 .60268 Mdot
.7377 .27973 Mdot
.40812 .59512 Mdot
.52177 .4565 Mdot
.66523 .61968 Mdot
.50468 .54933 Mdot
.57875 .33319 Mdot
.35147 .54441 Mdot
.67286 .42986 Mdot
.69247 .44035 Mdot
.55093 .34723 Mdot
.60358 .60982 Mdot
.5446 .31817 Mdot
.40596 .52572 Mdot
.41346 .6323 Mdot
.36177 .5581 Mdot
.58768 .38194 Mdot
.77549 .47727 Mdot
.65739 .64638 Mdot
.54032 .33394 Mdot
.31002 .42564 Mdot
.70021 .42774 Mdot
.59934 .31244 Mdot
.65582 .66512 Mdot
.62008 .59795 Mdot
.62517 .60478 Mdot
.41856 .27186 Mdot
.5536 .31723 Mdot
.58925 .64354 Mdot
.59744 .65916 Mdot
.33726 .58572 Mdot
.35474 .5619 Mdot
.62968 .66199 Mdot
.61913 .32754 Mdot
.4108 .29186 Mdot
.58927 .33137 Mdot
.18096 .60867 Mdot
.7002 .4653 Mdot
.53853 .79608 Mdot
.36676 .54626 Mdot
.79867 .73268 Mdot
.40711 .54082 Mdot
.37474 .55624 Mdot
.58561 .63106 Mdot
.42273 .31996 Mdot
.43276 .29395 Mdot
.61038 .63771 Mdot
.64095 .60348 Mdot
.43519 .26564 Mdot
.39989 .45399 Mdot
.20983 .61673 Mdot
.33401 .44559 Mdot
.65709 .6368 Mdot
.40695 .76757 Mdot
.67122 .45627 Mdot
.65244 .59906 Mdot
.69361 .50552 Mdot
.52622 .30775 Mdot
.52976 .28458 Mdot
.69935 .45153 Mdot
.4036 .59784 Mdot
.59417 .32715 Mdot
.43896 .58468 Mdot
.75796 .4307 Mdot
.55637 .49359 Mdot
.18619 .42482 Mdot
.41412 .55446 Mdot
.52001 .58287 Mdot
.81016 .57907 Mdot
.34405 .55654 Mdot
.54902 .76059 Mdot
.42238 .30982 Mdot
.64983 .59932 Mdot
.71486 .45135 Mdot
.68853 .72016 Mdot
.39156 .57593 Mdot
.65084 .62332 Mdot
.71352 .44684 Mdot
.7781 .46612 Mdot
.50958 .44907 Mdot
.33513 .57746 Mdot
.88395 .48362 Mdot
.63657 .67641 Mdot
.5724 .33398 Mdot
.46935 .76322 Mdot
.61231 .59263 Mdot
.49808 .4437 Mdot
.57523 .35732 Mdot
.31335 .46988 Mdot
.65018 .61717 Mdot
.41848 .32133 Mdot
.63287 .63179 Mdot
.44875 .2874 Mdot
.58413 .63235 Mdot
.53268 .3091 Mdot
.38022 .59354 Mdot
.53336 .31497 Mdot
.44126 .26738 Mdot
.56852 .35129 Mdot
.7151 .45069 Mdot
.54385 .54042 Mdot
.68696 .45146 Mdot
.24902 .46712 Mdot
.51134 .68859 Mdot
.68406 .46625 Mdot
.45415 .50334 Mdot
.4091 .55677 Mdot
.58329 .5997 Mdot
.56641 .33466 Mdot
.55605 .27289 Mdot
.30769 .44001 Mdot
.61419 .60955 Mdot
.54101 .30761 Mdot
.41577 .76516 Mdot
.78635 .40117 Mdot
.44661 .54962 Mdot
.63926 .32697 Mdot
.61202 .62309 Mdot
.57322 .27783 Mdot
.34753 .45049 Mdot
.61314 .596 Mdot
.52257 .29527 Mdot
.69403 .46561 Mdot
.67468 .42946 Mdot
.40979 .54898 Mdot
.70506 .4671 Mdot
.53024 .28057 Mdot
.39431 .68439 Mdot
.61312 .64931 Mdot
.77166 .48514 Mdot
.40688 .29772 Mdot
.55878 .33329 Mdot
.33471 .61058 Mdot
.5896 .63012 Mdot
.54954 .28676 Mdot
.6542 .815 Mdot
.19057 .66663 Mdot
.54279 .30705 Mdot
.63644 .64323 Mdot
.6455 .62443 Mdot
.36427 .53051 Mdot
.31168 .43818 Mdot
.55074 .30506 Mdot
.66323 .2505 Mdot
.23434 .50246 Mdot
.53948 .54281 Mdot
.27435 .25227 Mdot
.37897 .61107 Mdot
.36281 .6072 Mdot
.67202 .4719 Mdot
.37261 .58763 Mdot
.64635 .60911 Mdot
.4073 .54053 Mdot
.65796 .43861 Mdot
.54284 .34137 Mdot
.39142 .58095 Mdot
.41181 .3038 Mdot
.65815 .44944 Mdot
.65576 .45221 Mdot
.53162 .29709 Mdot
.60574 .60876 Mdot
.73083 .70771 Mdot
.55629 .32484 Mdot
.3555 .60325 Mdot
.524 .53579 Mdot
.42825 .56386 Mdot
.59432 .67542 Mdot
.66336 .61909 Mdot
.56852 .33649 Mdot
.51588 .53188 Mdot
.67775 .43938 Mdot
.53348 .27768 Mdot
.39029 .6118 Mdot
.52036 .30805 Mdot
.53703 .44822 Mdot
.50007 .17554 Mdot
.62479 .67928 Mdot
.52332 .43467 Mdot
.61401 .59731 Mdot
.54264 .54663 Mdot
.26639 .34444 Mdot
.40947 .29307 Mdot
.5752 .34283 Mdot
.74737 .50375 Mdot
.5368 .32555 Mdot
.37757 .58391 Mdot
.41323 .56318 Mdot
.58185 .30974 Mdot
.41289 .27981 Mdot
.42403 .38237 Mdot
.41392 .32256 Mdot
.64294 .64375 Mdot
.43849 .47075 Mdot
.16187 .58057 Mdot
.51024 .29531 Mdot
.70027 .44545 Mdot
.54925 .60825 Mdot
.33529 .5567 Mdot
.70725 .46037 Mdot
.65543 .45827 Mdot
.45156 .28499 Mdot
.5466 .33093 Mdot
.66675 .66347 Mdot
.68479 .42186 Mdot
.60465 .59351 Mdot
.29018 .39502 Mdot
.45919 .60286 Mdot
.28835 .6256 Mdot
.32954 .56152 Mdot
.3069 .44613 Mdot
.68211 .42027 Mdot
.40677 .56442 Mdot
.39453 .51497 Mdot
.69901 .46381 Mdot
.45242 .28875 Mdot
.56058 .50785 Mdot
.54098 .3056 Mdot
.85817 .56856 Mdot
.39978 .54783 Mdot
.38713 .59122 Mdot
.70433 .46055 Mdot
.57085 .76855 Mdot
.64518 .66784 Mdot
.60115 .62158 Mdot
.56727 .31525 Mdot
.36416 .43102 Mdot
.42303 .56113 Mdot
.40668 .55273 Mdot
.58187 .3018 Mdot
.51532 .53984 Mdot
.24606 .28631 Mdot
.39044 .56797 Mdot
.67407 .44851 Mdot
.5359 .46751 Mdot
.71183 .42905 Mdot
.4351 .5501 Mdot
.37658 .57735 Mdot
.3521 .61422 Mdot
.39401 .61185 Mdot
.68322 .45521 Mdot
.32838 .56681 Mdot
.32949 .54727 Mdot
.61992 .64318 Mdot
.38332 .60734 Mdot
.2343 .50388 Mdot
.39266 .57018 Mdot
.41838 .30935 Mdot
.3757 .4494 Mdot
.3623 .59964 Mdot
.38003 .60741 Mdot
.23414 .5002 Mdot
.36705 .58775 Mdot
.71327 .44985 Mdot
.64246 .6202 Mdot
.67744 .43788 Mdot
.70318 .44422 Mdot
.54289 .2874 Mdot
.45164 .30137 Mdot
.36928 .52202 Mdot
.43086 .26767 Mdot
.37968 .52457 Mdot
.29437 .60289 Mdot
.27714 .44974 Mdot
.34911 .44713 Mdot
.40221 .27732 Mdot
.40404 .55229 Mdot
.57054 .32027 Mdot
.55986 .33735 Mdot
.47631 .46106 Mdot
.4168 .62705 Mdot
.71884 .44739 Mdot
.69319 .46261 Mdot
.46415 .362 Mdot
.48332 .16766 Mdot
.41034 .27079 Mdot
.43537 .38718 Mdot
.42691 .59781 Mdot
.40291 .59443 Mdot
.36075 .63377 Mdot
.56512 .28976 Mdot
.54766 .54444 Mdot
.59025 .34309 Mdot
.70765 .40402 Mdot
.66174 .44665 Mdot
.41028 .55169 Mdot
.53316 .86476 Mdot
.63755 .65392 Mdot
.64487 .62201 Mdot
.65865 .43683 Mdot
.56437 .34465 Mdot
.38525 .63682 Mdot
.83705 .618 Mdot
.66708 .63182 Mdot
.40251 .30375 Mdot
.36655 .5935 Mdot
.52785 .31052 Mdot
.62854 .65497 Mdot
.39783 .29896 Mdot
.41034 .60153 Mdot
.5799 .35735 Mdot
.40355 .56664 Mdot
.39598 .71763 Mdot
.61745 .64791 Mdot
.27548 .464 Mdot
.59872 .65028 Mdot
.68134 .45468 Mdot
.69914 .43194 Mdot
.37845 .57731 Mdot
.84792 .60165 Mdot
.68189 .63857 Mdot
.65117 .43647 Mdot
.42884 .31748 Mdot
.54163 .53654 Mdot
.44869 .30253 Mdot
.57893 .30885 Mdot
.40964 .29713 Mdot
.54702 .28702 Mdot
.62079 .34721 Mdot
.64759 .67445 Mdot
.43648 .28261 Mdot
.54543 .73712 Mdot
.39203 .63731 Mdot
.4584 .30138 Mdot
.35632 .57783 Mdot
.37881 .52708 Mdot
.55352 .29896 Mdot
.4222 .26752 Mdot
.32894 .57868 Mdot
.7097 .53901 Mdot
.70333 .43673 Mdot
.71766 .44596 Mdot
.42743 .62429 Mdot
.57686 .28248 Mdot
.64414 .67458 Mdot
.29574 .42522 Mdot
.66869 .66856 Mdot
.40333 .5509 Mdot
.38159 .52225 Mdot
.60699 .66524 Mdot
.62831 .67221 Mdot
.37748 .57299 Mdot
.48242 .81049 Mdot
.32971 .60164 Mdot
.6783 .42815 Mdot
.64261 .64581 Mdot
.64898 .62767 Mdot
.53303 .28009 Mdot
.59944 .62245 Mdot
.34127 .51971 Mdot
.71861 .41695 Mdot
.32114 .5537 Mdot
.67938 .44217 Mdot
.53581 .25953 Mdot
.54775 .29619 Mdot
.75227 .49663 Mdot
.59987 .62814 Mdot
.37131 .53806 Mdot
.60044 .63983 Mdot
.42585 .31382 Mdot
.65415 .63376 Mdot
.58782 .58691 Mdot
.37001 .54996 Mdot
.32522 .58112 Mdot
.51788 .54424 Mdot
.31094 .443 Mdot
.62764 .64823 Mdot
.40683 .52703 Mdot
.4039 .53651 Mdot
.41856 .56806 Mdot
.29086 .4351 Mdot
.59511 .63575 Mdot
.60488 .77329 Mdot
.67039 .68469 Mdot
.62075 .65065 Mdot
.22445 .69281 Mdot
.51956 .54914 Mdot
.51511 .53479 Mdot
.71661 .46409 Mdot
.38773 .56921 Mdot
.54085 .31859 Mdot
.35193 .60388 Mdot
.34805 .62603 Mdot
.36435 .59907 Mdot
.4444 .29122 Mdot
.42751 .57278 Mdot
.53036 .54209 Mdot
.55704 .32852 Mdot
.34786 .5539 Mdot
.38616 .57907 Mdot
.50881 .54334 Mdot
.6065 .65131 Mdot
.61162 .59991 Mdot
.66346 .67608 Mdot
.44813 .27827 Mdot
.66778 .46084 Mdot
.35177 .6021 Mdot
.56853 .3174 Mdot
.54049 .32198 Mdot
.59278 .62527 Mdot
.5868 .30759 Mdot
.65972 .45455 Mdot
.37508 .55831 Mdot
.68296 .45445 Mdot
.44509 .29276 Mdot
.63571 .6457 Mdot
.35164 .59396 Mdot
.33606 .59242 Mdot
.60537 .6253 Mdot
.3256 .59422 Mdot
.4311 .31478 Mdot
.5748 .28854 Mdot
.65462 .65373 Mdot
.69377 .43902 Mdot
.53665 .2797 Mdot
.35785 .54592 Mdot
.30783 .77611 Mdot
.37247 .58625 Mdot
.42126 .56423 Mdot
.68654 .6499 Mdot
.43607 .56465 Mdot
.53477 .32306 Mdot
.59687 .63149 Mdot
.37912 .52835 Mdot
.22819 .49296 Mdot
.48356 .30158 Mdot
.50622 .29758 Mdot
.36563 .57034 Mdot
.3955 .78919 Mdot
.38266 .53695 Mdot
.74674 .50816 Mdot
.27723 .45015 Mdot
.65398 .49495 Mdot
.28922 .62629 Mdot
.65114 .43827 Mdot
.51863 .53753 Mdot
.53919 .29171 Mdot
.52013 .78281 Mdot
.3742 .57295 Mdot
.51299 .66328 Mdot
.34939 .59415 Mdot
.66773 .44028 Mdot
.56077 .75398 Mdot
.59012 .31931 Mdot
.24284 .30918 Mdot
.39924 .60406 Mdot
.65278 .66504 Mdot
.60508 .33098 Mdot
.52315 .53237 Mdot
.32592 .58099 Mdot
.41973 .26448 Mdot
.47252 .35849 Mdot
.32176 .53616 Mdot
.68003 .43947 Mdot
.41367 .58573 Mdot
.35415 .62239 Mdot
.7812 .35698 Mdot
.6158 .63369 Mdot
.70403 .45397 Mdot
.47597 .17164 Mdot
.40692 .55859 Mdot
.61831 .5982 Mdot
.62971 .61621 Mdot
.43854 .27234 Mdot
.65596 .41748 Mdot
.49101 .3619 Mdot
.50938 .84984 Mdot
.32458 .67496 Mdot
.56678 .28916 Mdot
.56463 .54639 Mdot
.35235 .60601 Mdot
.33777 .29279 Mdot
.70048 .4424 Mdot
.38561 .59267 Mdot
.53414 .66553 Mdot
.61682 .62145 Mdot
.39824 .56432 Mdot
.41205 .29456 Mdot
.75984 .69358 Mdot
.3934 .75154 Mdot
.41746 .79677 Mdot
.57545 .35864 Mdot
.35753 .52375 Mdot
.34562 .51804 Mdot
.50383 .54907 Mdot
.43417 .54469 Mdot
.56809 .33379 Mdot
.55213 .46105 Mdot
.41696 .28668 Mdot
.63218 .65626 Mdot
.51376 .53829 Mdot
.34919 .5934 Mdot
.34095 .53245 Mdot
.42268 .3169 Mdot
.34758 .61117 Mdot
.47566 .77229 Mdot
.55627 .55295 Mdot
.54348 .28015 Mdot
.65964 .63969 Mdot
.37385 .52227 Mdot
.53506 .53343 Mdot
.36642 .55484 Mdot
.5269 .61048 Mdot
.39119 .59546 Mdot
.68391 .52426 Mdot
.60474 .6178 Mdot
.68797 .43413 Mdot
.39946 .61058 Mdot
.40044 .57148 Mdot
.51249 .4244 Mdot
.37774 .63774 Mdot
.37457 .60356 Mdot
.60169 .60232 Mdot
.63504 .65586 Mdot
.65027 .66565 Mdot
.51907 .29165 Mdot
.32907 .44322 Mdot
.68339 .45007 Mdot
.36314 .6346 Mdot
.68411 .42171 Mdot
.27266 .60842 Mdot
.44798 .29513 Mdot
.75988 .48735 Mdot
.37664 .56027 Mdot
.62126 .60641 Mdot
.20233 .60243 Mdot
.59292 .63141 Mdot
.73287 .44085 Mdot
.69967 .43911 Mdot
.62731 .64127 Mdot
.36676 .57711 Mdot
.3158 .45142 Mdot
.42671 .80751 Mdot
.69872 .42663 Mdot
.43534 .61921 Mdot
.51394 .25942 Mdot
.53013 .33081 Mdot
.21299 .67632 Mdot
.68195 .42334 Mdot
.81073 .57924 Mdot
.37771 .53095 Mdot
.60322 .64199 Mdot
.67985 .46165 Mdot
.6574 .46712 Mdot
.59094 .31467 Mdot
.33597 .58053 Mdot
.40009 .56946 Mdot
.53672 .55114 Mdot
.69123 .45427 Mdot
.48552 .56005 Mdot
.33422 .57547 Mdot
.74118 .41474 Mdot
.66555 .64922 Mdot
.7324 .27287 Mdot
.45978 .52469 Mdot
.53313 .66564 Mdot
.70972 .27768 Mdot
.65132 .65884 Mdot
.40122 .59954 Mdot
.3879 .63613 Mdot
.57951 .2923 Mdot
.37038 .5682 Mdot
.54206 .33594 Mdot
.66513 .44917 Mdot
.69041 .53337 Mdot
.44879 .5022 Mdot
.74702 .44003 Mdot
.37573 .58893 Mdot
.40315 .75611 Mdot
.42857 .28387 Mdot
.72111 .43546 Mdot
.6369 .67074 Mdot
.42781 .54431 Mdot
.58854 .30316 Mdot
.5234 .31574 Mdot
.61903 .62413 Mdot
.79637 .58306 Mdot
.75315 .49821 Mdot
.33099 .60584 Mdot
.58366 .32316 Mdot
.49331 .55249 Mdot
.38153 .77174 Mdot
.66633 .42392 Mdot
.41847 .28627 Mdot
.53027 .29397 Mdot
.67423 .47916 Mdot
.37667 .52716 Mdot
.62384 .63029 Mdot
.63095 .6779 Mdot
.48279 .45293 Mdot
.54035 .30942 Mdot
.43213 .30278 Mdot
.49112 .45133 Mdot
.45194 .47013 Mdot
.41943 .29675 Mdot
.51622 .2941 Mdot
.64953 .64389 Mdot
.617 .61283 Mdot
.64035 .61909 Mdot
.53904 .79432 Mdot
.66339 .61965 Mdot
.32379 .34494 Mdot
.43488 .54666 Mdot
.4158 .77138 Mdot
.40867 .53348 Mdot
.71357 .4532 Mdot
.61398 .64612 Mdot
.27561 .45319 Mdot
.41946 .60351 Mdot
.43365 .81024 Mdot
.40836 .58199 Mdot
.52997 .46273 Mdot
.38702 .57049 Mdot
.4166 .72917 Mdot
.64383 .59544 Mdot
.40952 .60043 Mdot
.71354 .41542 Mdot
.43639 .3079 Mdot
.57923 .61301 Mdot
.38578 .60199 Mdot
.74582 .64485 Mdot
.35583 .57819 Mdot
.68877 .53058 Mdot
.49255 .44476 Mdot
.38081 .30303 Mdot
.4264 .55896 Mdot
.59756 .32869 Mdot
.40887 .50067 Mdot
.40502 .77002 Mdot
.69673 .4257 Mdot
.40959 .76116 Mdot
.58852 .33744 Mdot
.56301 .75591 Mdot
.33829 .6177 Mdot
.41501 .28492 Mdot
.57298 .5073 Mdot
.68437 .42719 Mdot
.3763 .56466 Mdot
.40549 .5992 Mdot
.55235 .49105 Mdot
.36915 .76108 Mdot
.48981 .56036 Mdot
.39896 .28297 Mdot
.38213 .75241 Mdot
.37416 .60229 Mdot
.50489 .2947 Mdot
.60461 .60568 Mdot
.55924 .74458 Mdot
.57772 .75852 Mdot
.33868 .563 Mdot
.62415 .63905 Mdot
.60372 .60984 Mdot
.17546 .55067 Mdot
.42589 .2786 Mdot
.39487 .59372 Mdot
.52408 .43377 Mdot
.35153 .60063 Mdot
.66886 .44808 Mdot
.43424 .58669 Mdot
.54657 .29773 Mdot
.34886 .45242 Mdot
.51799 .29535 Mdot
.41874 .5663 Mdot
.6344 .63239 Mdot
.7083 .43738 Mdot
.62635 .34152 Mdot
.65748 .41666 Mdot
.32266 .34574 Mdot
.45811 .35554 Mdot
.4087 .27263 Mdot
.45035 .29501 Mdot
.72056 .43797 Mdot
.36803 .56269 Mdot
.30145 .43294 Mdot
.4513 .57065 Mdot
.38822 .56408 Mdot
.38252 .59857 Mdot
.69327 .48649 Mdot
.69816 .43748 Mdot
.52929 .30559 Mdot
.3772 .57149 Mdot
.41561 .5304 Mdot
.63178 .63658 Mdot
.40814 .27507 Mdot
.55073 .2827 Mdot
.43163 .26198 Mdot
.56405 .32623 Mdot
.22639 .64024 Mdot
.44462 .61624 Mdot
.44193 .30233 Mdot
.67095 .42393 Mdot
.63141 .60909 Mdot
.52343 .55309 Mdot
.57394 .30535 Mdot
.58756 .31223 Mdot
.36202 .52694 Mdot
.62668 .65337 Mdot
.60072 .62404 Mdot
.43411 .26433 Mdot
.69039 .46392 Mdot
.44853 .54336 Mdot
.33383 .55588 Mdot
.62613 .28109 Mdot
.58242 .29195 Mdot
.39304 .75868 Mdot
.68129 .67598 Mdot
.37639 .55175 Mdot
.61657 .5992 Mdot
.39588 .58062 Mdot
.55861 .60586 Mdot
.63165 .67556 Mdot
.43725 .56947 Mdot
.41782 .62008 Mdot
.56112 .28859 Mdot
.16825 .50572 Mdot
.44219 .53628 Mdot
.73058 .48903 Mdot
.35115 .6078 Mdot
.23175 .3012 Mdot
.19693 .59202 Mdot
.36088 .56794 Mdot
.42583 .57568 Mdot
.47078 .85327 Mdot
.38394 .53794 Mdot
.53643 .54662 Mdot
.34438 .62515 Mdot
.62315 .59915 Mdot
.52803 .43864 Mdot
.30718 .44333 Mdot
.43003 .27588 Mdot
.56829 .31511 Mdot
.26801 .40427 Mdot
.44925 .28695 Mdot
.61454 .61857 Mdot
.4479 .53992 Mdot
.68457 .66076 Mdot
.57547 .27511 Mdot
.4861 .56316 Mdot
.66704 .44373 Mdot
.30446 .43621 Mdot
.59003 .30888 Mdot
.69498 .43976 Mdot
.39171 .53533 Mdot
.61371 .33936 Mdot
.71388 .42191 Mdot
.16273 .52212 Mdot
.6717 .47347 Mdot
.69323 .43176 Mdot
.31877 .43987 Mdot
.42996 .27572 Mdot
.55849 .46971 Mdot
.29784 .6099 Mdot
.71162 .44 Mdot
.24801 .32142 Mdot
.58838 .29759 Mdot
.33833 .43283 Mdot
.64145 .59286 Mdot
.43477 .6224 Mdot
.38074 .59597 Mdot
.6804 .47246 Mdot
.53944 .52519 Mdot
.50929 .42125 Mdot
.66442 .4375 Mdot
.40359 .61167 Mdot
.36827 .43499 Mdot
.53556 .53466 Mdot
.52201 .55047 Mdot
.3993 .30319 Mdot
.51397 .1964 Mdot
.61022 .60824 Mdot
.4033 .30373 Mdot
.25685 .47254 Mdot
.41175 .5805 Mdot
.68165 .45667 Mdot
.51075 .53955 Mdot
.691 .43981 Mdot
.42948 .28996 Mdot
.43285 .31569 Mdot
.61903 .64182 Mdot
.64436 .667 Mdot
.57123 .52274 Mdot
.22719 .50858 Mdot
.34308 .58412 Mdot
.50264 .67605 Mdot
.62735 .67266 Mdot
.55034 .77963 Mdot
.42455 .27216 Mdot
.41374 .27132 Mdot
.32755 .71357 Mdot
.34956 .56051 Mdot
.5349 .46633 Mdot
.36356 .60097 Mdot
.27758 .30285 Mdot
.35053 .59203 Mdot
.584 .30413 Mdot
.38618 .61014 Mdot
.72138 .68441 Mdot
.36478 .53679 Mdot
.3734 .59928 Mdot
.55732 .31066 Mdot
.36495 .52371 Mdot
.55037 .29849 Mdot
.40344 .59677 Mdot
.48566 .33348 Mdot
.56806 .31722 Mdot
.47603 .29491 Mdot
.50353 .46571 Mdot
.52876 .54776 Mdot
.44285 .28211 Mdot
.41108 .26837 Mdot
.29531 .3959 Mdot
.64543 .65085 Mdot
.5848 .70518 Mdot
.36695 .59293 Mdot
.58364 .28985 Mdot
.66377 .45627 Mdot
.33754 .563 Mdot
.41643 .54815 Mdot
.44255 .53725 Mdot
.62246 .64276 Mdot
.54298 .27606 Mdot
.43827 .28996 Mdot
.5469 .33434 Mdot
.48639 .32727 Mdot
.55173 .29335 Mdot
.45415 .59114 Mdot
.3756 .52635 Mdot
.34959 .51662 Mdot
.53458 .70901 Mdot
.36055 .28796 Mdot
.62131 .62742 Mdot
.52415 .53668 Mdot
.44848 .29999 Mdot
.39686 .44269 Mdot
.61667 .60328 Mdot
.58275 .30517 Mdot
.40389 .56682 Mdot
.45618 .60639 Mdot
.29764 .60832 Mdot
.59945 .59264 Mdot
.45889 .2914 Mdot
.56879 .30789 Mdot
.53905 .54034 Mdot
.33449 .44361 Mdot
.62817 .75843 Mdot
.25396 .45887 Mdot
.39884 .57562 Mdot
.43662 .26652 Mdot
.62887 .65495 Mdot
.5477 .47669 Mdot
.68913 .46904 Mdot
.31093 .43938 Mdot
.37446 .58951 Mdot
.68969 .38507 Mdot
.63424 .63057 Mdot
.40978 .28365 Mdot
.67965 .47291 Mdot
.42056 .27891 Mdot
.54356 .53502 Mdot
.67757 .68232 Mdot
.3259 .58378 Mdot
.35936 .59968 Mdot
.66498 .45422 Mdot
.60701 .61131 Mdot
.48851 .33996 Mdot
.565 .48849 Mdot
.58133 .31063 Mdot
.39223 .44786 Mdot
.63256 .65553 Mdot
.65353 .38035 Mdot
.54682 .33535 Mdot
.71512 .45923 Mdot
.30822 .45866 Mdot
.65839 .45547 Mdot
.3789 .60099 Mdot
.64259 .62823 Mdot
.69746 .42527 Mdot
.61336 .2682 Mdot
.49692 .82311 Mdot
.57089 .50322 Mdot
.41067 .55812 Mdot
.75799 .50652 Mdot
.79009 .61064 Mdot
.57463 .59631 Mdot
.67517 .42462 Mdot
.38248 .585 Mdot
.33007 .605 Mdot
.39748 .60529 Mdot
.70784 .44436 Mdot
.61931 .41473 Mdot
.58243 .33677 Mdot
.4061 .56305 Mdot
.41086 .30426 Mdot
.54123 .29865 Mdot
.54369 .34521 Mdot
.52893 .29424 Mdot
.63483 .66987 Mdot
.4655 .59494 Mdot
.34771 .62854 Mdot
.1899 .5533 Mdot
.68964 .43226 Mdot
.52882 .54749 Mdot
.42218 .58305 Mdot
.32164 .35085 Mdot
.62632 .60938 Mdot
.56523 .30368 Mdot
.3883 .59135 Mdot
.48538 .44909 Mdot
.49783 .55055 Mdot
.55447 .31984 Mdot
.63275 .67354 Mdot
.66214 .58796 Mdot
.37164 .56532 Mdot
.34728 .6052 Mdot
.60847 .62392 Mdot
.79228 .62753 Mdot
.34146 .44298 Mdot
.39418 .5799 Mdot
.69264 .43558 Mdot
.83605 .49573 Mdot
.39298 .53397 Mdot
.67721 .63996 Mdot
.54905 .54715 Mdot
.68231 .68405 Mdot
.46138 .78074 Mdot
.39829 .63134 Mdot
.6158 .54345 Mdot
.39823 .3749 Mdot
.60228 .56659 Mdot
.29884 .29567 Mdot
.58503 .49325 Mdot
.16166 .55736 Mdot
.71932 .41497 Mdot
.40063 .72614 Mdot
.64085 .81851 Mdot
.80678 .57478 Mdot
.52928 .42431 Mdot
.61955 .47003 Mdot
.58461 .27361 Mdot
.25378 .27615 Mdot
.59462 .33864 Mdot
.30889 .28453 Mdot
.35608 .59398 Mdot
.78508 .63167 Mdot
.40544 .7344 Mdot
.40155 .33453 Mdot
.75756 .47396 Mdot
.49071 .44762 Mdot
.36884 .80084 Mdot
.75638 .43799 Mdot
.26771 .7123 Mdot
.55112 .67563 Mdot
.55433 .20078 Mdot
.40973 .45788 Mdot
.2785 .39079 Mdot
.42327 .75781 Mdot
.69228 .60285 Mdot
.6609 .39498 Mdot
.42802 .67799 Mdot
.72203 .28218 Mdot
.57902 .32284 Mdot
.62066 .59433 Mdot
.61456 .48273 Mdot
.3135 .75343 Mdot
.73729 .46674 Mdot
.61427 .54397 Mdot
.5677 .49727 Mdot
.41197 .728 Mdot
.27187 .46332 Mdot
.40544 .7112 Mdot
.4837 .36554 Mdot
.25819 .27484 Mdot
.67651 .61155 Mdot
.59851 .24284 Mdot
.38322 .42594 Mdot
.47061 .38176 Mdot
.44662 .7448 Mdot
.42413 .25426 Mdot
.47901 .29386 Mdot
.6346 .67443 Mdot
.3425 .76372 Mdot
.47172 .52043 Mdot
.25367 .48042 Mdot
.59677 .33656 Mdot
.55428 .58615 Mdot
.75558 .69445 Mdot
.78323 .61106 Mdot
.16893 .46302 Mdot
.30379 .76838 Mdot
.24591 .35774 Mdot
.53639 .48022 Mdot
.72846 .47126 Mdot
.33193 .35597 Mdot
.51328 .58446 Mdot
.22981 .3861 Mdot
.5308 .6094 Mdot
.42799 .82899 Mdot
.75191 .61396 Mdot
.33836 .79271 Mdot
.67041 .60105 Mdot
.37714 .51523 Mdot
.56908 .61959 Mdot
.39014 .68051 Mdot
.23421 .46727 Mdot
.34181 .78437 Mdot
.39069 .31551 Mdot
.55064 .53364 Mdot
.80505 .56623 Mdot
.47374 .77224 Mdot
.50727 .3713 Mdot
.46051 .31458 Mdot
.57021 .73267 Mdot
.378 .81357 Mdot
.62742 .54211 Mdot
.27253 .66873 Mdot
.73987 .41072 Mdot
.59643 .36834 Mdot
.54998 .34841 Mdot
.65053 .45496 Mdot
.28105 .73435 Mdot
.63938 .62392 Mdot
.16457 .50443 Mdot
.57966 .5414 Mdot
.50957 .56498 Mdot
.3846 .81767 Mdot
.20161 .40454 Mdot
.44071 .77186 Mdot
.36819 .33721 Mdot
.78405 .42871 Mdot
.44588 .64685 Mdot
.74153 .43466 Mdot
.50818 .26801 Mdot
.71178 .52437 Mdot
.29318 .74472 Mdot
.22844 .37018 Mdot
.53552 .85611 Mdot
.25342 .48954 Mdot
.45453 .25089 Mdot
.67839 .61683 Mdot
.57257 .4167 Mdot
.51953 .37959 Mdot
.33158 .79023 Mdot
.38512 .74659 Mdot
.81972 .47472 Mdot
.28335 .31648 Mdot
.5789 .76373 Mdot
.75182 .5276 Mdot
.60836 .43832 Mdot
.39506 .67228 Mdot
.75366 .63551 Mdot
.32906 .55597 Mdot
.25202 .44644 Mdot
.56587 .71679 Mdot
.38554 .28867 Mdot
.3325 .44998 Mdot
.75569 .58988 Mdot
.24642 .38975 Mdot
.81649 .49656 Mdot
.57655 .73368 Mdot
.59678 .65009 Mdot
.23198 .38531 Mdot
.26443 .33152 Mdot
.79782 .49192 Mdot
.47238 .17231 Mdot
.27204 .6704 Mdot
.55289 .38512 Mdot
.38604 .63223 Mdot
.3966 .72521 Mdot
.4264 .75686 Mdot
.26592 .28383 Mdot
.45062 .5983 Mdot
.18284 .52107 Mdot
.75137 .47568 Mdot
.5198 .71996 Mdot
.22785 .44372 Mdot
.53045 .71405 Mdot
.43252 .78375 Mdot
.61383 .69156 Mdot
.67377 .50316 Mdot
.52473 .51779 Mdot
.38168 .81303 Mdot
.53389 .30029 Mdot
.2263 .38726 Mdot
.74515 .45533 Mdot
.61983 .27591 Mdot
.57584 .48095 Mdot
.51777 .41722 Mdot
.25006 .7063 Mdot
.79788 .55847 Mdot
.57826 .25801 Mdot
.70392 .65045 Mdot
.5356 .5714 Mdot
.50775 .68147 Mdot
.46606 .55347 Mdot
.53313 .59752 Mdot
.43125 .31483 Mdot
.52493 .7601 Mdot
.66162 .69409 Mdot
.45559 .17037 Mdot
.44505 .59697 Mdot
.41654 .45909 Mdot
.5443 .55165 Mdot
.32046 .40279 Mdot
.22309 .63809 Mdot
.47784 .56911 Mdot
.1994 .41299 Mdot
.80133 .5747 Mdot
.31374 .40326 Mdot
.51349 .37861 Mdot
.59418 .7153 Mdot
.34164 .79551 Mdot
.20214 .64902 Mdot
.75737 .66339 Mdot
.7451 .52337 Mdot
.41147 .15175 Mdot
.66479 .50117 Mdot
.17931 .49864 Mdot
.74481 .4556 Mdot
.88241 .40433 Mdot
.53667 .32881 Mdot
.34007 .28331 Mdot
.48567 .62645 Mdot
.44713 .44561 Mdot
.32893 .76142 Mdot
.45529 .7652 Mdot
.46054 .2917 Mdot
.5834 .59445 Mdot
.4357 .61356 Mdot
.3525 .78254 Mdot
.38952 .81111 Mdot
.35881 .78518 Mdot
.63883 .38838 Mdot
.44164 .8029 Mdot
.43893 .84543 Mdot
.32769 .34359 Mdot
.50312 .49385 Mdot
.34935 .62117 Mdot
.21763 .50875 Mdot
.19354 .46129 Mdot
.37735 .26401 Mdot
.43769 .65216 Mdot
.68149 .62118 Mdot
.41698 .83936 Mdot
.21526 .63068 Mdot
.40008 .70597 Mdot
.25252 .69998 Mdot
.5499 .24204 Mdot
.20856 .47423 Mdot
.22739 .68205 Mdot
.66157 .56497 Mdot
.72358 .40905 Mdot
.44939 .8551 Mdot
.26363 .34278 Mdot
.61821 .46556 Mdot
.73321 .65981 Mdot
.1856 .47267 Mdot
.73728 .53234 Mdot
.61517 .46249 Mdot
.51585 .59898 Mdot
.64584 .74323 Mdot
.5245 .4155 Mdot
.6907 .60355 Mdot
.53487 .47441 Mdot
.22047 .44847 Mdot
.55771 .34881 Mdot
.21593 .40733 Mdot
.50213 .38941 Mdot
.51288 .49328 Mdot
.27739 .40852 Mdot
.24023 .34125 Mdot
.72825 .62052 Mdot
.40781 .79306 Mdot
.80018 .56841 Mdot
.82897 .49839 Mdot
.77628 .51515 Mdot
.56911 .70587 Mdot
.36766 .52301 Mdot
.32016 .75947 Mdot
.16773 .62161 Mdot
.23432 .6929 Mdot
.80459 .49256 Mdot
.53346 .3496 Mdot
.70168 .46883 Mdot
.32065 .36351 Mdot
.46162 .43863 Mdot
.61757 .51532 Mdot
.44077 .39826 Mdot
.64696 .44518 Mdot
.76368 .68926 Mdot
.57912 .5194 Mdot
.32635 .35101 Mdot
.44115 .67473 Mdot
.50293 .5769 Mdot
.37838 .76995 Mdot
.60353 .66121 Mdot
.80018 .47764 Mdot
.22837 .38854 Mdot
.53351 .29718 Mdot
.62142 .2668 Mdot
.51111 .52116 Mdot
.40431 .51696 Mdot
.50559 .25978 Mdot
.53651 .50448 Mdot
.53199 .66679 Mdot
.53197 .34656 Mdot
.18389 .59707 Mdot
.17317 .49644 Mdot
.22401 .67834 Mdot
.24513 .35221 Mdot
.6092 .25425 Mdot
.32539 .4103 Mdot
.6964 .49854 Mdot
.75699 .45192 Mdot
.35627 .42124 Mdot
.24942 .33747 Mdot
.43761 .77392 Mdot
.56863 .60621 Mdot
.37472 .63447 Mdot
.20674 .60899 Mdot
.29353 .37163 Mdot
.33749 .40438 Mdot
.60857 .7388 Mdot
.66973 .64758 Mdot
.36134 .25097 Mdot
.7064 .62922 Mdot
.29913 .53946 Mdot
.75557 .518 Mdot
.6746 .4181 Mdot
.62191 .67537 Mdot
.2386 .34226 Mdot
.50801 .16983 Mdot
.57734 .56939 Mdot
.4606 .51302 Mdot
.29156 .73557 Mdot
.48456 .47607 Mdot
.72165 .53087 Mdot
.67175 .74721 Mdot
.76915 .40494 Mdot
.65436 .58702 Mdot
.52343 .48657 Mdot
.56733 .46391 Mdot
.68658 .7027 Mdot
.58685 .60451 Mdot
.39305 .74922 Mdot
.28287 .74434 Mdot
.49876 .4508 Mdot
.67063 .58091 Mdot
.30106 .42455 Mdot
.55513 .41679 Mdot
.55782 .56385 Mdot
.27059 .40806 Mdot
.62631 .55999 Mdot
.28995 .69645 Mdot
.81052 .64699 Mdot
.40429 .66524 Mdot
.33464 .27716 Mdot
.32418 .36152 Mdot
.55221 .67558 Mdot
.44144 .74104 Mdot
.76683 .44342 Mdot
.36722 .60677 Mdot
.2798 .7501 Mdot
.75639 .60173 Mdot
.29539 .40596 Mdot
.61576 .3859 Mdot
.36459 .5442 Mdot
.33876 .5236 Mdot
.23537 .69079 Mdot
.68676 .68285 Mdot
.70183 .794 Mdot
.28505 .30614 Mdot
.55222 .63778 Mdot
.45393 .78086 Mdot
.19699 .42294 Mdot
.6044 .68973 Mdot
.58497 .5388 Mdot
.51098 .39259 Mdot
.19125 .45128 Mdot
.70324 .67728 Mdot
.712 .66374 Mdot
.77372 .50229 Mdot
.43815 .84174 Mdot
.54155 .58174 Mdot
.70578 .39692 Mdot
.54213 .24221 Mdot
.42189 .56403 Mdot
.79568 .58647 Mdot
.76609 .48423 Mdot
.59195 .39248 Mdot
.51223 .59214 Mdot
.16604 .62264 Mdot
.3759 .62417 Mdot
.79147 .56429 Mdot
.68958 .79896 Mdot
.74666 .76648 Mdot
.71889 .68299 Mdot
.32548 .78784 Mdot
.70899 .66432 Mdot
.71916 .53335 Mdot
.69496 .41983 Mdot
.43988 .47229 Mdot
.50777 .66788 Mdot
.25595 .72566 Mdot
.5383 .18234 Mdot
.74071 .43183 Mdot
.44933 .66002 Mdot
.25388 .72566 Mdot
.38721 .62663 Mdot
.35174 .26147 Mdot
.59395 .36892 Mdot
.23797 .31315 Mdot
.17308 .45518 Mdot
.62316 .74426 Mdot
.25735 .28906 Mdot
.34138 .25057 Mdot
.41611 .35028 Mdot
.17587 .4953 Mdot
.3183 .66642 Mdot
.6265 .7352 Mdot
.23516 .38277 Mdot
.73841 .51792 Mdot
.34508 .19287 Mdot
.55793 .56542 Mdot
.53702 .49796 Mdot
.67002 .69904 Mdot
.70488 .52528 Mdot
.72538 .59604 Mdot
.48725 .491 Mdot
.37226 .45394 Mdot
.42138 .77912 Mdot
.83679 .48912 Mdot
.68646 .7495 Mdot
.55191 .5116 Mdot
.39535 .80831 Mdot
.76266 .43306 Mdot
.36318 .4148 Mdot
.46533 .75747 Mdot
.30051 .37349 Mdot
.54729 .24552 Mdot
.36332 .5989 Mdot
.28767 .74846 Mdot
.5457 .24574 Mdot
.38169 .80101 Mdot
.15952 .51265 Mdot
.25864 .6987 Mdot
.48399 .58581 Mdot
.51892 .25943 Mdot
.19971 .45018 Mdot
.20091 .45258 Mdot
.44462 .8301 Mdot
.32493 .26931 Mdot
.36488 .42703 Mdot
.50734 .47545 Mdot
.45362 .50769 Mdot
.29908 .53395 Mdot
.19401 .42869 Mdot
.58388 .69724 Mdot
.23323 .439 Mdot
.74315 .67529 Mdot
.24414 .34037 Mdot
.44529 .76917 Mdot
.29929 .38184 Mdot
.56053 .39473 Mdot
.46221 .28035 Mdot
.58787 .29518 Mdot
.51122 .85581 Mdot
.78646 .50082 Mdot
.18661 .5307 Mdot
.81501 .47567 Mdot
.75554 .63115 Mdot
.30722 .27985 Mdot
.57216 .62115 Mdot
.3648 .66928 Mdot
.54262 .19762 Mdot
.25039 .39423 Mdot
.39712 .75689 Mdot
.74936 .50721 Mdot
.60124 .76139 Mdot
.25647 .71661 Mdot
.2226 .45015 Mdot
.57268 .85383 Mdot
.4862 .25888 Mdot
.5248 .75431 Mdot
.33474 .75312 Mdot
.83733 .54434 Mdot
.33855 .40114 Mdot
.38511 .81371 Mdot
.62578 .58874 Mdot
.30849 .77179 Mdot
.67277 .46938 Mdot
.42889 .24151 Mdot
.74014 .50428 Mdot
.32083 .38559 Mdot
.32356 .38673 Mdot
.17975 .56649 Mdot
.80191 .56342 Mdot
.78501 .61168 Mdot
.55281 .38474 Mdot
.58596 .34818 Mdot
.4303 .47935 Mdot
.65521 .56614 Mdot
.52272 .85284 Mdot
.38058 .52291 Mdot
.47893 .25359 Mdot
.21489 .396 Mdot
.69609 .4979 Mdot
.55098 .49793 Mdot
.73286 .51191 Mdot
.65397 .75601 Mdot
.21349 .48916 Mdot
.42713 .83852 Mdot
.5527 .49981 Mdot
.46154 .42712 Mdot
.56259 .76251 Mdot
.63678 .51643 Mdot
.76468 .41739 Mdot
.62319 .54757 Mdot
.47112 .4888 Mdot
.33939 .44109 Mdot
.24946 .35147 Mdot
.16243 .59152 Mdot
.41423 .81825 Mdot
.76582 .41623 Mdot
.32569 .39501 Mdot
.67601 .63637 Mdot
.26036 .3938 Mdot
.56302 .8578 Mdot
.24263 .29015 Mdot
.73776 .65494 Mdot
.23832 .35183 Mdot
.60421 .40312 Mdot
.34419 .26891 Mdot
.34662 .41191 Mdot
.33199 .75101 Mdot
.45697 .64923 Mdot
.67536 .68526 Mdot
.60802 .45109 Mdot
.29953 .44139 Mdot
.5803 .49445 Mdot
.61935 .73563 Mdot
.80183 .55631 Mdot
.57466 .853 Mdot
.32053 .26076 Mdot
.56538 .75429 Mdot
.61719 .82736 Mdot
.64724 .67404 Mdot
.57357 .46591 Mdot
.6429 .35887 Mdot
.316 .39935 Mdot
.52457 .31293 Mdot
.488 .5568 Mdot
.38213 .44244 Mdot
.70622 .69493 Mdot
.59495 .27827 Mdot
.45449 .30041 Mdot
.59241 .6376 Mdot
.33383 .25777 Mdot
.62988 .67886 Mdot
.16311 .58292 Mdot
.65974 .56114 Mdot
.41489 .77397 Mdot
.66292 .7657 Mdot
.59545 .23445 Mdot
.83443 .50694 Mdot
.265 .71013 Mdot
.23011 .49502 Mdot
.58414 .60457 Mdot
.59295 .64762 Mdot
.69943 .64977 Mdot
.65868 .4867 Mdot
.29599 .73464 Mdot
.2059 .40039 Mdot
.61543 .25308 Mdot
.64649 .60502 Mdot
.51832 .46983 Mdot
.53795 .51271 Mdot
.19311 .60965 Mdot
.54402 .33252 Mdot
.35999 .80872 Mdot
.58438 .70113 Mdot
.81829 .58336 Mdot
.62642 .52052 Mdot
.33204 .46724 Mdot
.35059 .39916 Mdot
.60834 .26542 Mdot
.37429 .63226 Mdot
.55109 .6286 Mdot
.64372 .66564 Mdot
.57797 .48508 Mdot
.40631 .28314 Mdot
.45779 .17194 Mdot
.71025 .49802 Mdot
.55222 .69227 Mdot
.18861 .43214 Mdot
.60504 .66371 Mdot
.4872 .26318 Mdot
.57775 .22516 Mdot
.42883 .61097 Mdot
.21484 .53155 Mdot
.48935 .85549 Mdot
.27607 .71553 Mdot
.59318 .61324 Mdot
.82474 .50039 Mdot
.49813 .35179 Mdot
.18323 .59289 Mdot
.69656 .68338 Mdot
.20525 .41353 Mdot
.55545 .72591 Mdot
.21532 .65916 Mdot
.461 .78019 Mdot
.61657 .53163 Mdot
.23403 .37418 Mdot
.51208 .42173 Mdot
.23353 .35471 Mdot
.64372 .76376 Mdot
.45271 .49142 Mdot
.23788 .31799 Mdot
.61113 .38951 Mdot
.40305 .71409 Mdot
.333 .51025 Mdot
.61851 .51896 Mdot
.1955 .44553 Mdot
.60292 .64971 Mdot
.40405 .26344 Mdot
.46336 .65926 Mdot
.7463 .43285 Mdot
.28973 .74079 Mdot
.79919 .49858 Mdot
.21739 .38671 Mdot
.45895 .51557 Mdot
.29103 .34932 Mdot
.57599 .68946 Mdot
.24644 .49084 Mdot
.32937 .60765 Mdot
.56559 .72287 Mdot
.46478 .39789 Mdot
.19175 .57981 Mdot
.35843 .49729 Mdot
.33503 .77273 Mdot
.21759 .62774 Mdot
.69771 .69173 Mdot
.54633 .46102 Mdot
.63205 .59565 Mdot
.36125 .80461 Mdot
.20429 .50886 Mdot
.71273 .52085 Mdot
.17487 .45204 Mdot
.36208 .24504 Mdot
.63134 .82208 Mdot
.78035 .56389 Mdot
.52217 .50569 Mdot
.16935 .50845 Mdot
.75636 .6077 Mdot
.34895 .24701 Mdot
.39298 .75412 Mdot
.68506 .64298 Mdot
.3895 .82009 Mdot
.34533 .67635 Mdot
.77575 .62032 Mdot
.36233 .76235 Mdot
.61459 .57296 Mdot
.20269 .51488 Mdot
.35823 .63148 Mdot
.5805 .29713 Mdot
.44079 .4541 Mdot
.26511 .28007 Mdot
.58084 .57504 Mdot
.20114 .41485 Mdot
.20586 .41597 Mdot
.31753 .28796 Mdot
.60081 .25404 Mdot
.63302 .82087 Mdot
.46993 .80563 Mdot
.33043 .5419 Mdot
.59323 .60675 Mdot
.45229 .29744 Mdot
.28675 .31711 Mdot
.34629 .55704 Mdot
.28262 .48311 Mdot
.56606 .73085 Mdot
.26859 .73964 Mdot
.56397 .40696 Mdot
.66079 .39777 Mdot
.64373 .59986 Mdot
.71067 .52336 Mdot
.60787 .69595 Mdot
.80817 .57933 Mdot
.1978 .44125 Mdot
.57846 .56928 Mdot
.61615 .54009 Mdot
.76863 .6262 Mdot
.24096 .38742 Mdot
.46551 .36823 Mdot
.71042 .43292 Mdot
.52366 .66423 Mdot
.48831 .8392 Mdot
.77131 .61009 Mdot
.5662 .56552 Mdot
.71696 .62546 Mdot
.46073 .48722 Mdot
.71941 .39599 Mdot
.8017 .56745 Mdot
.65767 .68521 Mdot
.29282 .70513 Mdot
.64728 .57506 Mdot
.51261 .26014 Mdot
.27157 .32204 Mdot
.69723 .60177 Mdot
.19818 .42632 Mdot
.41595 .62039 Mdot
.34758 .77306 Mdot
.29768 .40479 Mdot
.39904 .26406 Mdot
.33324 .59694 Mdot
.5103 .61731 Mdot
.23438 .69028 Mdot
.72792 .66091 Mdot
.49044 .60846 Mdot
.63172 .68457 Mdot
.17009 .48856 Mdot
.49844 .28375 Mdot
.52167 .33714 Mdot
.35866 .32274 Mdot
.33779 .46608 Mdot
.45618 .4384 Mdot
.66579 .49197 Mdot
.38216 .62986 Mdot
.45046 .36921 Mdot
.46477 .496 Mdot
.52647 .66817 Mdot
.18444 .50823 Mdot
.50721 .85308 Mdot
.56118 .58439 Mdot
.16879 .45719 Mdot
.49177 .62911 Mdot
.6609 .59623 Mdot
.32699 .25684 Mdot
.46669 .62861 Mdot
.44527 .60356 Mdot
.40111 .26711 Mdot
.65472 .67163 Mdot
.50227 .84939 Mdot
.52633 .58459 Mdot
.3909 .25943 Mdot
.53347 .37577 Mdot
.54711 .56592 Mdot
.69714 .26516 Mdot
.75229 .46926 Mdot
.16655 .50266 Mdot
.22899 .38669 Mdot
.64171 .44616 Mdot
.70649 .66787 Mdot
.47179 .6264 Mdot
.34604 .77435 Mdot
.47998 .40478 Mdot
.27417 .72047 Mdot
.65004 .387 Mdot
.54216 .69058 Mdot
.2162 .62188 Mdot
.24429 .45396 Mdot
.2469 .48604 Mdot
.59006 .73627 Mdot
.26281 .61157 Mdot
.5204 .55228 Mdot
.49017 .17539 Mdot
.3246 .2102 Mdot
.54205 .85799 Mdot
.81617 .58811 Mdot
.30155 .56974 Mdot
.25722 .39781 Mdot
.66446 .58374 Mdot
.36939 .41898 Mdot
.53125 .38436 Mdot
.50014 .2615 Mdot
.61585 .39521 Mdot
.8293 .48436 Mdot
.27858 .74777 Mdot
.33526 .59844 Mdot
.42711 .38993 Mdot
.39638 .32532 Mdot
.53505 .33027 Mdot
.40898 .69301 Mdot
.48624 .85354 Mdot
.70805 .4331 Mdot
.65352 .34845 Mdot
.66583 .49476 Mdot
.18185 .5668 Mdot
.63834 .3309 Mdot
.6921 .48117 Mdot
.16199 .58206 Mdot
.7552 .66152 Mdot
.61958 .76461 Mdot
.82103 .47066 Mdot
.19779 .59599 Mdot
.5619 .7179 Mdot
.50133 .27098 Mdot
.31201 .7665 Mdot
.34854 .4005 Mdot
.57243 .25286 Mdot
.26578 .6416 Mdot
.23404 .36926 Mdot
.27997 .31235 Mdot
.63655 .4211 Mdot
.46474 .6473 Mdot
.46503 .15651 Mdot
.59993 .23428 Mdot
.83393 .62227 Mdot
.27535 .71211 Mdot
.51934 .82527 Mdot
.71632 .67168 Mdot
.56299 .38685 Mdot
.33965 .76827 Mdot
.20572 .42433 Mdot
.47876 .6288 Mdot
.51841 .1813 Mdot
.25823 .43401 Mdot
.27794 .38421 Mdot
.70084 .39065 Mdot
.23414 .68135 Mdot
.60143 .24851 Mdot
.30321 .65428 Mdot
.22455 .38409 Mdot
.49947 .62654 Mdot
.24966 .49635 Mdot
.4782 .83646 Mdot
.21116 .52911 Mdot
.2553 .3261 Mdot
.61753 .39328 Mdot
.49046 .32355 Mdot
.5006 .84543 Mdot
.57202 .66358 Mdot
.55569 .73182 Mdot
.69266 .79735 Mdot
.3372 .79147 Mdot
.45772 .63695 Mdot
.4326 .59008 Mdot
.16002 .55113 Mdot
.49093 .29749 Mdot
.18845 .51667 Mdot
.74827 .69891 Mdot
.28858 .29865 Mdot
.39416 .49588 Mdot
.35239 .58713 Mdot
.3298 .33519 Mdot
.68661 .69375 Mdot
.47703 .6351 Mdot
.62787 .3103 Mdot
.25113 .33657 Mdot
.55506 .69219 Mdot
.80995 .64758 Mdot
.64679 .75988 Mdot
.63663 .60474 Mdot
.29837 .75828 Mdot
.34667 .69067 Mdot
.56073 .68009 Mdot
.33358 .75675 Mdot
.46986 .41329 Mdot
.4537 .36826 Mdot
.57242 .68524 Mdot
.32591 .40846 Mdot
.26728 .27584 Mdot
.61322 .83096 Mdot
.51414 .67383 Mdot
.36787 .81329 Mdot
.20391 .65518 Mdot
.63928 .60382 Mdot
.42345 .66982 Mdot
.3417 .38935 Mdot
.60926 .5671 Mdot
.61446 .44183 Mdot
.61694 .26672 Mdot
.37377 .23914 Mdot
.44782 .17754 Mdot
.36037 .57388 Mdot
.65117 .38564 Mdot
.25937 .71744 Mdot
.36845 .24904 Mdot
.26686 .72577 Mdot
.57216 .71468 Mdot
.35072 .52877 Mdot
.75088 .7633 Mdot
.71674 .53271 Mdot
.46192 .56986 Mdot
.30043 .59779 Mdot
.29803 .58608 Mdot
.36939 .60427 Mdot
.62028 .43099 Mdot
.31449 .36282 Mdot
.28008 .29787 Mdot
.31098 .76252 Mdot
.65958 .6199 Mdot
.34683 .39722 Mdot
.70821 .4109 Mdot
.29565 .45938 Mdot
.27358 .60749 Mdot
.6682 .41747 Mdot
.28326 .28563 Mdot
.69523 .26576 Mdot
.49556 .37736 Mdot
.58117 .50365 Mdot
.35988 .45529 Mdot
.56944 .52771 Mdot
.30628 .27025 Mdot
.66697 .48972 Mdot
.41896 .35044 Mdot
.22055 .3826 Mdot
.5934 .74626 Mdot
.71494 .39794 Mdot
.40605 .16026 Mdot
.34182 .40457 Mdot
.63462 .38694 Mdot
.41101 .66185 Mdot
.65643 .74555 Mdot
.29557 .71695 Mdot
.46918 .35926 Mdot
.53213 .55618 Mdot
.55715 .75999 Mdot
.32697 .76082 Mdot
.65725 .43909 Mdot
.1656 .60331 Mdot
.40777 .65998 Mdot
.41298 .69358 Mdot
.47097 .81959 Mdot
.53445 .48554 Mdot
.40312 .75799 Mdot
.30852 .56004 Mdot
.44072 .42609 Mdot
.67127 .24863 Mdot
.55255 .50656 Mdot
.55343 .56276 Mdot
.6032 .56191 Mdot
.33064 .27976 Mdot
.31362 .70202 Mdot
.39878 .59037 Mdot
.44606 .32159 Mdot
.31195 .41385 Mdot
.45172 .25351 Mdot
.45702 .25342 Mdot
.72488 .41053 Mdot
.30297 .27334 Mdot
.28494 .30702 Mdot
.3702 .76049 Mdot
.35846 .79144 Mdot
.33845 .50741 Mdot
.27149 .70735 Mdot
.53243 .4059 Mdot
.73136 .59684 Mdot
.21402 .52826 Mdot
.60756 .83307 Mdot
.55122 .61772 Mdot
.2972 .56204 Mdot
.19334 .63081 Mdot
.25148 .7016 Mdot
.74684 .44078 Mdot
.7501 .51208 Mdot
.29699 .23213 Mdot
.32877 .38441 Mdot
.83298 .48658 Mdot
.62412 .34847 Mdot
.19 .61489 Mdot
.47019 .508 Mdot
.44658 .64283 Mdot
.59596 .72162 Mdot
.44595 .59913 Mdot
.54577 .32143 Mdot
.6702 .74702 Mdot
.5923 .73793 Mdot
.26299 .60517 Mdot
.33528 .5315 Mdot
.59584 .46909 Mdot
.67814 .64007 Mdot
.54863 .85631 Mdot
.51673 .31072 Mdot
.46146 .42464 Mdot
.78838 .67185 Mdot
.67807 .25276 Mdot
.35886 .24219 Mdot
.43421 .82593 Mdot
.75698 .45694 Mdot
.46746 .49342 Mdot
.78551 .36841 Mdot
.65081 .5948 Mdot
.5909 .60614 Mdot
.69808 .50145 Mdot
.29497 .35124 Mdot
.79295 .57306 Mdot
.65596 .81402 Mdot
.21233 .65485 Mdot
.42086 .61717 Mdot
.8668 .56562 Mdot
.22103 .38842 Mdot
.44018 .4052 Mdot
.79385 .55985 Mdot
.28484 .74451 Mdot
.61252 .40102 Mdot
.16322 .52216 Mdot
.68639 .59199 Mdot
.63567 .5758 Mdot
.29034 .36922 Mdot
.81328 .47989 Mdot
.52013 .47358 Mdot
.83474 .61713 Mdot
.76269 .51457 Mdot
.27753 .39142 Mdot
.7244 .65974 Mdot
.63285 .58087 Mdot
.54808 .61204 Mdot
.66102 .55498 Mdot
.50571 .59019 Mdot
.57039 .56465 Mdot
.62384 .54213 Mdot
.47124 .3707 Mdot
.60906 .49574 Mdot
.708 .53177 Mdot
.71773 .48603 Mdot
.61694 .74586 Mdot
.27722 .25413 Mdot
.47337 .25924 Mdot
.5562 .34722 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`0008?ooooo0_l00035ooooo`007?ooool00ol0003oooooooooo`22ooooo`;o00003oooool2
o`000;Cooooo000Looooo`03o`000?oooooooooo09?ooooo0_l0002dooooo`007?ooool00ol0003o
ooooooooo`20ooooo`?o0000a_ooool001cooooo00?o0000ooooooooool0P?ooool3o`000<Kooooo
000Looooo`03o`000?oooooooooo07Sooooo0_l0000Hooooo`;o00001Oooool2o`000:kooooo000L
ooooo`03o`000?oooooooooo07Sooooo0_l0000Fooooo`Co00000_ooool6o`0000Gooooo0_l0002V
ooooo`007?ooool00ol0003oooooooooo`2>ooooo`Go00000oooool3o`000004ooooool0003o0000
o`0000Cooooo0_l00002ooooo`;o0000X_ooool001cooooo00?o0000ooooooooool0Moooool2o`00
01Gooooo0_l000000ooooooo0000o`000008ooooo`;o00000_ooool2o`0000Cooooo0_l0002Roooo
o`007?ooool00ol0003oooooooooo`1gooooo`;o00005Oooool2o`0000oooooo0_l00004ooooo`;o
0000X_ooool001cooooo00?o0000ooooooooool0T?ooool2o`0001?ooooo0ol00003ooooo`;o0000
W?ooool001cooooo00?o0000ooooooooool0T?ooool2o`0001Cooooo0_l00003ooooo`;o0000W?oo
ool001cooooo00?o0000ooooooooool0VOooool2o`000:kooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`1/ooooo`;o0000:ooo
ool2o`000:kooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1/ooooo`;o0000=Oooool2o`000:Co
oooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h0
1oooool00ol0003oooooooooo`2Sooooo`;o000000?oooooo`000?l000001?ooool2o`0009_ooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_oo
ool3o`000:Kooooo0_l00004ooooo`;o00000_ooool2o`0009Oooooo00000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`2`
ooooo`;o0000Uoooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool03Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB_ooool00006oooooomgMgOoV9RHoooo
oonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0I_oo
ool2o`000>7ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c006ooooo`03o`000?oooooooooo06?ooooo0_l000000ooooooo0000o`00003Qooooo`00
7?ooool00ol0003oooooooooo`1Sooooo`;o0000i?ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o0000ioooool001cooooo00?o0000oooo
ooooool0G_ooool4o`0005Kooooo0_l0002?ooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o
0000F?ooool2o`0008oooooo000Looooo`03o`000?oooooooooo05gooooo0_l0000Nooooo`;o0000
b_ooool001cooooo00?o0000ooooooooool0GOooool2o`0001kooooo0_l0000oooooo`?o0000R?oo
ool001cooooo00?o0000ooooooooool0M_ooool2o`0004Kooooo0ol00028ooooo`007?ooool00ol0
003oooooooooo`1aooooo`;o00000oooool2o`0000Oooooo0_l00007ooooo`;o00008_ooool2o`00
0003ooooool0003o000000kooooo0_l00002ooooo`;o0000Q?ooool001cooooo00?o0000oooooooo
ool0LOooool3o`0000_ooooo0_l00007ooooo`;o00008_ooool5o`0000kooooo0_l00002ooooo`;o
0000Q?ooool001cooooo00?o0000ooooooooool0Eoooool2o`0001Gooooo0_l00002ooooo`Co0000
=oooool3o`00013ooooo0_l00003ooooo`;o00003oooool2o`00077ooooo000Looooo`;o0000E_oo
ool4o`0001;ooooo0_l000000ooooooo0000o`000002ooooo`Co00002oooool2o`0000?ooooo0_l0
0004ooooo`;o00000_ooool2o`0002kooooo0_l00003ooooo`;o00003Oooool4o`00077ooooo000L
ooooo`03o`000?oooooooooo05Gooooo0ol0000Cooooo`;o00001Oooool2o`0000gooooo0_l00003
ooooo`;o00001?ooool2o`000003ooooool0003o000000;o00001Oooool2o`0001cooooo0_l00007
ooooo`;o000000?oooooo`000?l000000ol0000:ooooo`;o000000Goooooo`000?l0003o0000oooo
o`02o`0006oooooo000Looooo`03o`000?oooooooooo05Cooooo1?l0000>ooooo`;o000000?ooooo
o`000?l000003Oooool2o`0000Sooooo0_l000000ooooooo0000o`000004o`0000Cooooo1?l00005
ooooo`;o00007?ooool4o`0000Gooooo0_l000000ooooooo0000o`000003o`0000[ooooo0_l00002
ooooo`;o000000?oooooo`000?l00000Koooool001cooooo00?o0000ooooooooool0E?ooool2o`00
00kooooo1?l000001?oooooo0000o`000?l00003ooooo`;o00001_ooool3o`000003ooooool0003o
000000Gooooo2_l00003ooooo`;o00001Oooool2o`0000;ooooo0_l00003ooooo`?o000000?ooooo
o`000?l000000_l00003ooooo`;o00002_ooool4o`0008oooooo000Looooo`03o`000?oooooooooo
06Cooooo0_l00004ooooo`;o00000oooool2o`0000Kooooo0_l00002ooooo`;o000000?oooooo`00
0?l000000ol000000ooooooo0000o`000009o`0000Oooooo0_l00002ooooo`?o00000_ooool3o`00
0003ooooool0003o000000;o00000oooool2o`0000kooooo0_l00006ooooo`;o0000QOooool001co
oooo00?o0000ooooooooool0Moooool2o`0000Gooooo4Ol0000<ooooo`;o00003oooool2o`0000co
oooo0_l00006ooooo`Ko00005_ooool3o`0006Sooooo000Looooo`03o`000?oooooooooo063ooooo
0_l00004ooooo`;o00001?ooool2o`00017ooooo4_l00003ooooo`;o00002oooool2o`0000;ooooo
0_l000000ooooooo0000o`000004o`0000Cooooo0_l0000>ooooo`Ko00005_ooool3o`0006Sooooo
000Looooo`03o`000?oooooooooo05oooooo0ol00004ooooo`;o00001?ooool2o`0001;ooooo4Ol0
0003ooooo`;o00002Oooool4o`000005ooooool0003o0000o`000?ooool01?l00004ooooo`Ko0000
1?ooool2o`0000Oooooo0_l0000Uooooo`;o0000GOooool001cooooo00?o0000ooooooooool0Cooo
ool3o`000003ooooool0003o000000[ooooo0_l0000Aooooo`?o00002oooool@o`0000kooooo1Ol0
00000ooooooo0000o`000002ooooo`;o00000_ooool:o`000004ooooool0003o0000ooooo`;o0000
2_ooool3o`0000Sooooo0_l0000@ooooo`;o00001Oooool3o`0005cooooo000Looooo`03o`000?oo
oooooooo04oooooo1_l0000;ooooo`;o00001_ooool3o`0000Oooooo0ol0000:oooooa;o00002_oo
ool2o`000003ooooool0003o000000;o00001?ooool?o`000005ooooool0003o0000o`000?ooool0
0_l000000ooooooo0000o`000007ooooo`?o00002?ooool2o`00013ooooo0_l00006ooooo`?o0000
Foooool001cooooo00?o0000ooooooooool0D_ooool2o`000003ooooool0003o000000Wooooo0_l0
0006ooooo`?o00001Oooool3o`0000_ooooo4ol000000ooooooo0000o`000006ooooo`?o00000_oo
ool2o`0000;ooooo0_l000000ooooooo0000o`00000Do`000003ooooool0003o000000Wooooo0_l0
000Iooooo`;o00000_ooool2o`0000?ooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`1C
ooooo`Co000000?oooooo`000?l000001oooool2o`0000Sooooo0_l00003ooooo`?o00002?ooool2
o`000003ooooool0003o000001Co00001_ooool2o`0000;ooooo0ol00002ooooo`;o00000oooool<
o`000003ooooool0003o000000?o00003_ooool2o`0001gooooo0_l00003ooooo`;o0000Foooool0
01cooooo00?o0000ooooooooool0C?ooool2o`0000;ooooo0_l000000ooooooo0000o`000003oooo
o`;o00001oooool4o`0000Kooooo0_l00004ooooo`;o00001_oooolIo`0000cooooo0ol00004oooo
o`Ko00000_ooool=o`0000kooooo0_l0001oooooo`007?ooool00ol0003oooooooooo`1:ooooo`Co
00000_ooool2o`00017ooooo0_l00006ooooo`;o00001?ooool2o`0000Kooooo0ol000000ooooooo
0000o`00000Eo`00013ooooo6Ol0000;ooooo`;o0000Ooooool001cooooo00?o0000ooooooooool0
B_ooool3o`0001gooooo0_l00003ooooo`;o00002Oooool2o`000003ooooool0003o000001Go0000
0oooool3o`0000Kooooo7Ol0000<ooooo`;o0000O_ooool001cooooo00?o0000ooooooooool0Eooo
ool2o`0000Cooooo0_l0000;ooooo`;o00000oooool2o`0000kooooo5Ol00003ooooo`?o00000_oo
ool2o`0000;ooooo7_l00008ooooo`;o000000?oooooo`000?l000009Oooool2o`0005Oooooo000L
ooooo`;o0000BOooool4o`0000_ooooo0_l000001?oooooo0000o`000?ooool2o`0000_ooooo0_l0
000AoooooaOo00001Oooool2o`000003ooooool0003o000000?ooooo7_l00007ooooo`;o0000:?oo
ool3o`0005Kooooo000Looooo`03o`000?oooooooooo04Sooooo1?l00002ooooo`;o00001_ooool2
o`0000;ooooo0_l0000Cooooo`;o00001oooool2o`0000?ooooo6?l00004ooooo`;o00001OoooolO
o`0003;ooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o000000?oooooo`00
0?l000000_l00005ooooo`Go00005?ooool2o`0000Oooooo0_l00003oooooaSo00002oooool;o`00
0003ooooool0003o000001?o0000<Oooool2o`0005Gooooo000Looooo`03o`000?oooooooooo04_o
oooo1_l00006ooooo`Co00008ooooolEo`00017ooooo1ol000000ooooooo0000o`00000Co`0000Oo
oooo0_l0000Xooooo`;o0000EOooool001cooooo00?o0000ooooooooool0BOooool7o`0000Oooooo
0_l0000Pooooo`;o00000ooooolEo`00013ooooo7_l00007ooooo`;o0000:Oooool2o`0005Cooooo
000Looooo`03o`000?oooooooooo04Oooooo1_l000000ooooooo0000o`000007ooooo`?o00005ooo
ool2o`0000Kooooo1?l00002ooooo`?o000000?oooooo`000?l000002?l00002ooooo`Go00003ooo
oolNo`0003;ooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`17ooooo`;o000000Cooooo
o`000?l0003o00002oooool4o`0001Gooooo0_l00008ooooo`;o00000_ooool=o`0000;ooooo1_l0
000?oooooago0000<oooool2o`0005Cooooo000Looooo`03o`000?oooooooooo04[ooooo0_l00000
0ooooooo0000o`000006ooooo`;o00000_ooool3o`0000gooooo0_l00006ooooo`;o000000?ooooo
o`000?l000002Oooool2o`000003ooooool0003o000000Ko00000oooool4o`0000Wooooo0_l00007
ooooo`;o000000?oooooo`000?l000006?l0000booooo`;o0000EOooool001cooooo00?o0000oooo
ooooool0COooool4o`0000Cooooo0_l000000ooooooo0000o`00000=ooooo`Co00001_ooool2o`00
0003ooooool0003o000000Oooooo1?l000000ooooooo0000o`000002o`000003ooooool0003o0000
00Cooooo0_l0000;ooooo`Co00001Oooool2o`000003ooooool0003o000001Oo00002_ooool3o`00
02Kooooo0_l000000ooooooo0000o`00001Booooo`007?ooool00ol0003oooooooooo`1>ooooo`?o
00001_ooool3o`0000gooooo0_l0000<ooooo`;o00001_ooool7o`0000?ooooo1?l00003ooooo`;o
00002_ooool4o`0000Wooooo0ol000000ooooooo0000o`00000Co`0000;ooooo0_l000000ooooooo
0000o`000002ooooo`Go00001?ooool2o`00027ooooo0_l0001Booooo`007?ooool00ol0003ooooo
ooooo`1=ooooo`?o00000_ooool2o`0000?ooooo0_l0000=ooooo`;o00003Oooool2o`0000Oooooo
1_l00005ooooo`;o00000oooool2o`0000[ooooo0_l0000<oooooaSo000000Goooooo`000?l0003o
0000ooooo`02o`0000Gooooo0_l00004ooooo`;o0000MOooool001cooooo00?o0000ooooooooool0
COooool2o`0000?ooooo0_l0000Booooo`?o00003?ooool2o`0000Oooooo1_l00004ooooo`Co0000
3_ooool2o`0000cooooo5ol00002ooooo`;o00002Oooool2o`0007_ooooo000Looooo`03o`000?oo
oooooooo04gooooo0ol00005ooooo`;o00004?ooool2o`0000_ooooo0_l00008ooooo`?o00000_oo
ool2o`0000?ooooo1?l0000>ooooo`;o00002_ooool4o`000003ooooool0003o000001?o00002_oo
ool2o`0007gooooo000Looooo`03o`000?oooooooooo04[ooooo1_l00004ooooo`?o00007Oooool2
o`0000Kooooo0_l00005ooooo`;o00005_ooool2o`0000Wooooo0_l00002ooooo`Go000000?ooooo
o`000?l000003_l00004ooooo`So0000;?ooool2o`0004oooooo000Looooo`03o`000?oooooooooo
04Wooooo1Ol00004ooooo`Co00003oooool4o`0000kooooo0_l00003ooooo`;o00001oooool2o`00
01Cooooo0_l0000=ooooo`Go00000oooool=o`0000;ooooo0_l000000ooooooo0000o`000005o`00
02gooooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`19ooooo`?o00001_ooool3o`00013o
oooo1?l0000>ooooo`;o00003?ooool2o`0002;ooooo5Ol00002ooooo`?o00000oooool4o`0002go
oooo0_l0001@ooooo`007?ooool2o`0005cooooo0_l00008ooooo`;o00007?ooool5o`0000;ooooo
0_l0000Mooooo`oo00000oooool2o`0000?ooooo0_l00003ooooo`Ko00001Oooool2o`0002Gooooo
0_l0001@ooooo`007?ooool00ol0003oooooooooo`1:ooooo`Go00003?ooool3o`0000Kooooo1?l0
000Kooooo`[o00004Oooool2o`0000[ooooo0_l00003ooooo`[o00000_ooool2o`0000?ooooo0_l0
00000ooooooo0000o`000006o`0000Gooooo0_l0001gooooo`007?ooool00ol0003oooooooooo`18
ooooo`Oo00003Oooool2o`0000Gooooo1ol0000Aooooo`;o00002oooool5o`0000?ooooo1Ol00009
ooooo`;o00004?ooool2o`000003ooooool0003o000000Ko00001Oooool5o`0003Gooooo0_l0001=
ooooo`007?ooool00ol0003oooooooooo`17ooooo`?o00000_ooool2o`0001Cooooo1Ol000000ooo
oooo0000o`00000Aooooo`;o00003Oooool3o`0000?ooooo2?l0000Mooooo`Ko000000?oooooo`00
0?l000000_l000000ooooooo0000o`000002o`0000Sooooo0_l0000[ooooo`;o0000COooool001co
oooo00?o0000ooooooooool0A_ooool3o`0000?ooooo0_l0000Cooooo`Co000000?oooooo`000?l0
00004oooool2o`0001Gooooo1_l000001?oooooo0000o`000?ooool2o`0001Wooooo1?l000000ooo
oooo0000o`000002o`0000?ooooo0_l00008ooooo`;o0000N_ooool001cooooo00?o0000oooooooo
ool0AOooool3o`0000gooooo0_l00009ooooo`So00004oooool2o`0001Gooooo1?l00003ooooo`;o
000000?oooooo`000?l000000_l0000Mooooo`;o00001?ooool2o`0000?ooooo0_l0001oooooo`00
7?ooool00ol0003oooooooooo`15ooooo`;o000000?oooooo`000?l000002oooool2o`0000Cooooo
0_l00003ooooo`?o000000Coooooo`000?l0003o00000_ooool2o`0002Cooooo0ol000000ooooooo
0000o`000004ooooo`;o00000oooool3o`0001cooooo0ol000000ooooooo0000o`000002o`0000?o
oooo0_l0000aooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0A_ooool4o`00017ooooo
0ol00002ooooo`;o00000oooool2o`0000;ooooo0_l0000Aooooo`;o00004Oooool3o`000003oooo
ool0003o000000;o00000_ooool2o`0000;ooooo1_l00002ooooo`;o00001?ooool2o`00013ooooo
0ol000000ooooooo0000o`00000hooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0A?oo
ool6o`0001;ooooo1Ol00004ooooo`?o00005?ooool8o`00017ooooo0_l00006ooooo`Oo000000Co
ooooo`000?l0003ooooo0_l000000ooooooo0000o`00002Looooo`007?ooool00ol0003ooooooooo
o`14ooooo`;o00000_ooool2o`0000Kooooo0_l0000<ooooo`?o00001Oooool2o`0001Kooooo1ol0
000Hooooo`;o00000oooool5o`000003ooooool0003o000000;o0000WOooool001cooooo00?o0000
ooooooooool0D?ooool2o`0000cooooo0ol00005ooooo`;o00006oooool2o`0000;ooooo0ol0000;
ooooo`;o00001_ooool2o`0000Cooooo1Ol00002ooooo`;o00001oooool2o`0000oooooo0_l00009
ooooo`?o0000Moooool001cooooo00?o0000ooooooooool0A?ooool3o`0000;ooooo0_l0000:oooo
o`Co00001?ooool3o`0000Oooooo0_l0000Mooooo`Co00002oooool2o`0000cooooo1Ol000000ooo
oooo0000o`000005ooooo`;o000000?oooooo`000?l000001?ooool4o`0000Oooooo0_l00009oooo
o`?o00000_ooool2o`0000Kooooo0_l0001[ooooo`007?ooool00ol0003oooooooooo`11ooooo`co
00002?ooool4o`0000Cooooo0ol00004ooooo`Go00007Oooool2o`0000;ooooo0_l0000Mooooo`;o
00001Oooool2o`000003ooooool0003o000000Cooooo1?l00007ooooo`;o00001?ooool2o`0000?o
oooo1?l000000ooooooo0000o`000006ooooo`;o0000Joooool001cooooo00?o0000ooooooooool0
@Oooool9o`000004ooooool0003o0000o`0000?ooooo0_l00004ooooo`;o00001?ooool2o`0000Go
oooo0ol00004ooooo`;o00006_ooool2o`000003ooooool0003o000000;o00004Oooool2o`0000oo
oooo0_l000000ooooooo0000o`00000>ooooo`?o00001?ooool4o`000003ooooool0003o000000;o
00001Oooool2o`0000;ooooo0_l00002ooooo`;o0000Ioooool00006ooooooo^k^ko<S8bo`000?lb
<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo
04Cooooo1?l00004ooooo`;o00000_ooool3o`0000?ooooo0ol00004ooooo`;o00003?ooool2o`00
01[ooooo0_l00003ooooo`;o00004Oooool2o`000003ooooool0003o000001Wooooo0_l00004oooo
o`Ko00000oooool2o`000003ooooool0003o000000Oooooo0_l00006ooooo`;o00006Oooool2o`00
04cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0@_ooool2o`0000Wooooo1_l00003ooooo`;o000000?ooooo
o`000?l000000ol00008ooooo`;o00001oooool2o`00027ooooo0_l0000>ooooo`;o00003_ooool2
o`0000Wooooo0_l00005ooooo`Go00001_ooool2o`0000;ooooo0_l000001?oooooo0000o`000?oo
ool2o`000003ooooool0003o000000?ooooo0_l00003ooooo`;o00004oooool4o`0004[ooooo0000
0ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006ooooo`03o`000?oooooo
oooo04;ooooo0_l00009ooooo`Go00001_ooool6o`0000Gooooo0_l000000ooooooo0000o`000005
ooooo`Co00006_ooool2o`0000Gooooo1Ol0000Kooooo`;o00004?ooool2o`0000Wooooo0_l00002
ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000003ooooo`;o000000?o
ooooo`000?l000000_l0000Eooooo`;o0000B_ooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool02Oooool01?m4A4CogMgMooooool00007ooooo`?o0000?oooool2o`0000oooooo0_l0
0003ooooo`So00001Oooool4o`0000Cooooo0_l000001?oooooo0000o`000?l0000Kooooo`;o0000
1_ooool4o`0002Wooooo0_l000000ooooooo0000o`00000>ooooo`;o00003?ooool2o`000003oooo
ool0003o000000;ooooo0ol0000Aooooo`;o00007Oooool2o`0002cooooo00000ooooooo0000oooo
o`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003ooooo
ooooo`0nooooo`?o00004Oooool8o`0000;ooooo0ol00003ooooo`Co00001?ooool5o`0001cooooo
0_l00006ooooo`;o00000oooool2o`0000oooooo0_l0000Eooooo`;o000000Coooooo`000?l0003o
00003oooool2o`0000[ooooo1?l00003ooooo`?o00002oooool2o`0000Cooooo0_l0000Mooooo`;o
0000;?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00omgMgOoc<c<
o`000007ooooo`03o`000?oooooooooo03kooooo0_l00002ooooo`;o00003Oooool7o`0000Cooooo
0ol00007ooooo`;o00000_ooool3o`0001kooooo0_l0000;ooooo`;o00003oooool2o`0000Sooooo
0_l0000;ooooo`?o000000?oooooo`000?l000003oooool2o`000003ooooool0003o000000Sooooo
0ol00002ooooo`;o00002oooool4o`0002?ooooo0_l0000/ooooo`0000KoooooogMgMonHV9Sooooo
oiRHV?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0@_ooool2o`0000go
oooo1ol0000>ooooo`;o00001Oooool2o`0004Cooooo0_l0000<ooooo`?o00005?ooool4o`0000Ko
oooo0_l00003ooooo`?o00000oooool2o`0000Gooooo0_l00007ooooo`;o0000B_ooool00006oooo
ooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo
03gooooo1?l0000Mooooo`;o00000_ooool2o`0000;ooooo0_l00005ooooo`;o00000oooool2o`00
027ooooo0_l00006ooooo`;o00002?ooool2o`0001Sooooo0ol000000ooooooo0000o`000006oooo
o`;o00001Oooool2o`0000;ooooo1?l00006ooooo`So00000oooool2o`0000?ooooo0_l00009oooo
o`;o0000B_ooool001cooooo00?o0000ooooooooool0?Oooool4o`0000kooooo0_l0000=ooooo`;o
00000_ooool2o`000004ooooool0003o0000ooooo`;o00002?ooool2o`0000?ooooo0_l0000Loooo
o`;o00001_ooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000008oooo
o`;o00000oooool2o`0000gooooo0_l00006ooooo`;o00000_ooool;o`0000Sooooo1?l00005oooo
o`;o00000oooool2o`000003ooooool0003o000005;ooooo000Looooo`03o`000?oooooooooo03oo
oooo0_l0000>ooooo`;o00005?ooool2o`000003ooooool0003o000000;o00001?ooool2o`0000;o
oooo0_l000000ooooooo0000o`00000Wooooo`Ko00002oooool2o`0000?ooooo0_l0000;ooooo`Co
00001?ooool2o`0000?ooooo4?l00004ooooo`Co00003Oooool2o`0005;ooooo000Looooo`03o`00
0?oooooooooo03Wooooo0_l000001?oooooo0000o`000?ooool2o`0000gooooo0_l0000;ooooo`;o
000000?oooooo`000?l000000ol00007ooooo`;o00000oooool3o`0000;ooooo0_l00005ooooo`;o
00003Oooool2o`0000Kooooo0_l0000>ooooo`?o00000oooool2o`0001Wooooo1?l00004ooooo`;o
00000oooool3o`0000;ooooo3?l00003ooooo`Ko00003_ooool2o`0004oooooo000Looooo`03o`00
0?oooooooooo03Wooooo0_l000000ooooooo0000o`000003o`0000cooooo0ol0000;ooooo`So0000
00Coooooo`000?l0003o00002?ooool6o`0000Cooooo1?l0000=ooooo`?o00001Oooool2o`0000ko
oooo0ol00003ooooo`;o00006_ooool3o`0000[ooooo0_l00002ooooo`go00000_ooool6o`000003
ooooool0003o000000;o00002Oooool2o`0004oooooo000Looooo`03o`000?oooooooooo03_ooooo
1?l00006ooooo`;o00001_ooool2o`0000gooooo0_l00003ooooo`;o000000Coooooo`000?l0003o
00002_ooool4o`0000Cooooo0_l0000@ooooo`?o00001?ooool2o`0000kooooo0ol0000Pooooo`?o
00002_ooool3o`000003ooooool0003o000000[o000000?oooooo`000?l000000ol00003ooooo`Co
00000oooool4o`0000Gooooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`0jooooo`?o0000
2?ooool2o`0000Kooooo1Ol0000<ooooo`Co00001?ooool2o`000004ooooool0003o0000o`0000Ko
oooo0ol00006ooooo`;o00003oooool2o`0001Gooooo0_l000000ooooooo0000o`00000Nooooo`;o
00002_oooolFo`0000Gooooo1?l000000ooooooo0000o`000002o`0000Gooooo0ol0001;ooooo`00
7?ooool00ol0003oooooooooo`0jooooo`;o00004Oooool5o`0000Sooooo3_l000000ooooooo0000
o`000003o`0000Kooooo0_l00005ooooo`;o0000:Oooool2o`0001kooooo0_l00005ooooo`;o0000
00?oooooo`000?l000005_l00005ooooo`Co00000oooool2o`0000Kooooo0_l0000Qooooo`;o0000
:?ooool001cooooo00?o0000ooooooooool0@?ooool2o`0000Kooooo0_l0000;ooooo`;o00000_oo
ool5o`000003ooooool0003o000000Ko00000_ooool7o`0000Cooooo1?l0000Hooooo`Co00004_oo
ool4o`0001Sooooo0_l00002ooooo`;o00001Oooool>o`0000;ooooo2ol00003ooooo`Ko000000?o
ooooo`000?l000000oooool2o`0002Kooooo0_l0000Xooooo`007?ooool00ol0003oooooooooo`0m
ooooo`;o000000?oooooo`000?l000001_ooool2o`000004ooooool0003o0000o`0000Oooooo0_l0
00001?oooooo0000o`000?l00003ooooo`_o000000Goooooo`000?l0003o0000ooooo`02o`0000Ko
oooo1?l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`0000[ooooo1?l00008ooooo`Co
00001_ooool4o`0001Sooooo1?l00009oooooaWo00000_ooool7o`000003ooooool0003o000000?o
oooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`0looooo`?o00001oooool2o`0000?ooooo
1Ol00008ooooo`;o00001?ooool?o`000003ooooool0003o000000;o00001_ooool2o`0000?ooooo
1Ol00002ooooo`;o00001Oooool4o`0000gooooo1Ol0000Sooooo`Co00001OoooolLo`000003oooo
ool0003o000000?ooooo0_l00004ooooo`Co0000D?ooool001cooooo00?o0000ooooooooool0=Ooo
ool2o`0000Gooooo0_l00006ooooo`Co00000_ooool3o`000003ooooool0003o000000kooooo1Ol0
0003ooooo`;o000000?oooooo`000?l000000oooool4o`0000Cooooo0_l00004ooooo`;o000000?o
ooooo`000?l000002_ooool4o`0000_ooooo2_l00007ooooo`;o00006Oooool2o`0000Gooooo7?l0
000<ooooo`?o00009oooool2o`0002Sooooo000Looooo`;o0000=_ooool2o`0000?ooooo0_l00000
1?oooooo0000o`000?l00004ooooo`?o00000oooool2o`0000Gooooo0_l00003ooooo`;o00001ooo
ool6o`0000;ooooo0ol00002ooooo`Ko00000oooool3o`0000Cooooo0_l0000Looooo`[o00001ooo
ool2o`0001Gooooo0_l0000;oooooaWo00002_ooool2o`0000;ooooo0_l00002ooooo`;o00008ooo
ool2o`0002Sooooo000Looooo`03o`000?oooooooooo03Gooooo0_l00003ooooo`;o000000Cooooo
o`000?l0003o00001Oooool4o`000003ooooool0003o000000;o00000oooool2o`0000?ooooo0_l0
000:oooooa7o000000Coooooo`000?l0003o00001oooool2o`0000Oooooo0_l00002ooooo`;o0000
3?ooool7o`0000;ooooo0ol00008ooooo`;o00004oooool2o`0000;ooooo0_l00006oooooaWo0000
1oooool2o`0000;ooooo0_l00006ooooo`;o0000COooool001cooooo00?o0000ooooooooool0<ooo
ool4o`0000Sooooo0_l00006ooooo`?o00000_ooool2o`0000?ooooo0_l00002ooooo`?o00000ooo
ool2o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l00004ooooo`Oo00001ooo
ool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o00002_ooool5o`0000Oooooo1Ol0
0005ooooo`;o00005_ooool3o`0000?ooooo7?l00007ooooo`;o00000_ooool2o`0002[ooooo0_l0
000Yooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00001_ooool2o`0000;ooooo0_l00007
ooooo`;o00001Oooool4o`0000;ooooo0_l00003ooooo`Co00000_ooool2o`0000Oooooo0_l00005
ooooo`Co00002_ooool2o`000004ooooool0003o0000ooooo`;o00004?ooool6o`0000Oooooo1ol0
0004ooooo`Co00004oooool2o`0000Cooooo0ol000000ooooooo0000o`00000Fo`0000_ooooo0_l0
0006ooooo`;o00008_ooool2o`0002Wooooo000Looooo`03o`000?oooooooooo03?ooooo0_l00006
ooooo`;o00004Oooool5o`0000;ooooo1?l000000ooooooo0000o`000002o`0000_ooooo0_l0000I
ooooo`;o00003_ooool8o`0000?ooooo0_l00005ooooo`Go00000oooool4o`0000?ooooo0_l0000=
ooooo`;o00001_ooool2o`000003ooooool0003o000001Ko00004oooool2o`0002;ooooo0_l0000Y
ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00004?ooool2o`000003ooooool0003o0000
00?ooooo1Ol00003ooooo`Co00002Oooool2o`0000Cooooo1?l0000Fooooo`?o00003Oooool7o`00
00Kooooo0ol00006ooooo`Co00001?ooool3o`0000;ooooo1?l0000;ooooo`?o00001Oooool2o`00
00;ooooo4ol000000ooooooo0000o`000002o`0000Cooooo0_l00002ooooo`;o00000_ooool2o`00
00?ooooo0_l00008ooooo`;o00006Oooool2o`0002Wooooo000Looooo`03o`000?oooooooooo04Go
oooo0_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000004?ooool2o`0000Co
oooo1?l0000Fooooo`?o000000?oooooo`000?l000001Ol00002ooooo`;o000000Coooooo`000?l0
003o00002?ooool2o`000003ooooool0003o000000?ooooo0_l00003ooooo`?o00000oooool4o`00
00?ooooo0_l00005ooooo`;o00001?ooool3o`0000Wooooo4ol000000ooooooo0000o`000002o`00
00Cooooo0_l00002ooooo`?o000000?oooooo`000?l000000oooool2o`0000Sooooo0_l00002oooo
o`;o00005?ooool2o`0002[ooooo000Looooo`03o`000?oooooooooo03Wooooo0_l00002ooooo`;o
00001_ooool2o`0000Kooooo0_l000000ooooooo0000o`00000<ooooo`;o00000_ooool2o`0001oo
oooo0_l000000ooooooo0000o`000005o`000004ooooool0003o0000o`0000;ooooo0_l00008oooo
o`;o00001_ooool2o`0000Cooooo0_l00003ooooo`Co00002_ooool2o`0000Cooooo0ol00009oooo
o`oo000000?oooooo`000?l000001oooool2o`0000Kooooo0ol0000Cooooo`?o00004oooool2o`00
02[ooooo000Looooo`03o`000?oooooooooo03Wooooo0_l00002ooooo`;o000000?oooooo`000?l0
00002?ooool3o`0000?ooooo0_l00009ooooo`Go00008oooool2o`0000Kooooo0_l000000ooooooo
0000o`000002ooooo`?o00001?ooool3o`0000Gooooo0_l00002ooooo`;o00000oooool2o`0000;o
oooo0_l0000Cooooo`;o00002?oooolEo`0000Oooooo0_l00005ooooo`Co00001?ooool2o`0000_o
oooo1Ol0000Booooo`;o0000:oooool001cooooo00?o0000ooooooooool0@?ooool2o`000003oooo
ool0003o000000Gooooo1?l00002ooooo`;o00002Oooool4o`0002Wooooo0_l00004ooooo`;o0000
0_ooool3o`000003ooooool0003o000000Co00001Oooool2o`0000Oooooo0_l000001?oooooo0000
o`000?l00008ooooo`;o00002Oooool2o`0000Sooooo3ol00002ooooo`;o00004?ooool4o`0000Co
oooo0_l00006ooooo`;o00000_ooool4o`0001Cooooo0_l0000[ooooo`007?ooool00ol0003ooooo
ooooo`12ooooo`?o00001Oooool4o`000003ooooool0003o000000Oooooo0_l000000ooooooo0000
o`00000[ooooo`;o00001?ooool3o`0000;ooooo0_l000001?oooooo0000o`000?l0000Aooooo`;o
000000?oooooo`000?l000001Oooool2o`000004ooooool0003o0000o`0000[ooooo0_l0000=oooo
o`Wo000000Coooooo`000?l0003o00004Oooool2o`0000gooooo0_l00002ooooo`;o00001_ooool2
o`0003_ooooo000Looooo`03o`000?oooooooooo04;ooooo0_l00005ooooo`Go000000?oooooo`00
0?l000001_ooool3o`0002kooooo0_l00005ooooo`?o000000?oooooo`000?l000005Oooool2o`00
00Cooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00002_ooool2o`0000kooooo0_l00003
ooooo`?o000000Coooooo`000?l0003o00001Oooool2o`0000kooooo1?l0000Aooooo`Co00003Ooo
ool2o`0002cooooo000Looooo`03o`000?oooooooooo03Cooooo0_l0000<ooooo`;o00001Oooool2
o`000004ooooool0003o0000ooooo`;o00001_ooool2o`0003Oooooo1?l000000ooooooo0000o`00
000?ooooo`;o00000_ooool2o`0000Cooooo0_l00002ooooo`;o00000_ooool2o`0000cooooo0_l0
0007ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Kooooo0_l00003ooooo`;o000000?o
ooooo`000?l000000ol000000ooooooo0000o`000004o`00017ooooo1?l0000=ooooo`;o0000;?oo
ool001cooooo00?o0000ooooooooool0=?ooool2o`0000cooooo0_l00008ooooo`Go00001?ooool2
o`0003Sooooo0_l000001?oooooo0000o`000?ooool2o`0000Cooooo0_l00009ooooo`;o00002?oo
ool2o`0000;ooooo0ol0000?ooooo`;o00001oooool2o`000003ooooool0003o000000?o00004ooo
ool8o`000003ooooool0003o000000[ooooo0_l000000ooooooo0000o`000007ooooo`?o0000>ooo
ool001cooooo00?o0000ooooooooool0=Oooool2o`0000oooooo0ol00003ooooo`Co00000oooool4
o`0003Sooooo0_l00003ooooo`;o00001Oooool2o`0000?ooooo0_l000000ooooooo0000o`00000;
ooooo`?o00000_ooool2o`0000;ooooo0ol00006ooooo`;o00002oooool8o`0001;ooooo0_l00000
1?oooooo0000o`000?l00004ooooo`;o00001Oooool2o`0000?ooooo0_l000000ooooooo0000o`00
0008ooooo`;o00003?ooool2o`0002gooooo000Looooo`03o`000?oooooooooo03Gooooo1?l00007
ooooo`;o00001?ooool:o`0000?ooooo0_l0000Looooo`Co00000_ooool3o`0000;ooooo0_l0000E
ooooo`?o00002_ooool2o`000003ooooool0003o000000Kooooo0_l00002ooooo`Go000000?ooooo
o`000?l000000_ooool3o`0000Kooooo0_l0000=ooooo`Go00002?ooool2o`0000?ooooo0_l00003
ooooo`?o00000_ooool2o`000003ooooool0003o000000;o00001_ooool2o`0000Cooooo0_l00000
0ooooooo0000o`000002o`0000;ooooo0_l000000ooooooo0000o`00000<ooooo`;o0000;Oooool0
01cooooo0_l0000fooooo`Co00001oooool2o`0000;ooooo0_l000000ooooooo0000o`000009o`00
0003ooooool0003o000001_ooooo1Ol00002ooooo`?o00000_ooool2o`0000?ooooo1?l0000>oooo
o`;o00005_ooool2o`0000;ooooo1Ol000001?oooooo0000o`000?l0000Dooooo`;o00001_ooool2
o`0000Sooooo0ol00002ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`Co00000oooool2
o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000001_l0000nooooo`007?ooool00ol0
003oooooooooo`0booooo`;o00002oooool2o`0000?ooooo0_l000000ooooooo0000o`000009o`00
01kooooo0_l0000?ooooo`Co00002Oooool4o`0001Wooooo0_l00003ooooo`Co00000_ooool2o`00
0003ooooool0003o0000017ooooo0_l00006ooooo`Go00001Oooool6o`0000?ooooo0_l00003oooo
o`Oo00001?ooool3o`0000;ooooo0_l00009ooooo`?o0000?oooool001cooooo00?o0000oooooooo
ool0<_ooool3o`0000[ooooo0_l00002ooooo`;o00000_ooool8o`0001_ooooo0_l0000Gooooo`;o
00002Oooool4o`0000?ooooo0_l0000?ooooo`;o00000oooool2o`0000?ooooo1?l00002ooooo`;o
000000?oooooo`000?l000006oooool3o`0000;ooooo0_l000000ooooooo0000o`000004o`0000?o
oooo0_l00004ooooo`Oo00001?ooool2o`00017ooooo0_l000000ooooooo0000o`00000iooooo`00
7?ooool00ol0003oooooooooo`0cooooo`;o00000oooool2o`0000Gooooo0_l00002ooooo`;o0000
00Coooooo`000?l0003o00000_ooool2o`0001_ooooo1?l00008ooooo`;o00006Oooool3o`0000?o
oooo0_l0000?ooooo`;o00002?ooool4o`0000;ooooo0_l0000Sooooo`;o000000Coooooo`000?l0
003o00003_ooool5o`0001Oooooo0_l000000ooooooo0000o`000009ooooo`;o0000;_ooool001co
oooo00?o0000ooooooooool0<?ooool2o`000003ooooool0003o000000?ooooo0_l00005ooooo`;o
00000_ooool2o`000003ooooool0003o0000023ooooo0_l00008ooooo`Co00002oooool2o`0000Go
oooo0_l00005ooooo`;o000000?oooooo`000?l000005oooool2o`0000?ooooo0_l00004ooooo`;o
0000<_ooool2o`0000?ooooo0ol0000Wooooo`;o0000;_ooool001cooooo00?o0000ooooooooool0
<?ooool2o`0000Kooooo1?l00002ooooo`;o0000;_ooool2o`0000;ooooo0_l00003ooooo`;o0000
0oooool2o`0000;ooooo1Ol00003ooooo`;o00001oooool3o`0001Oooooo0_l00003ooooo`;o0000
1?ooool2o`0000gooooo0_l00004ooooo`;o00007Oooool2o`0000Cooooo0_l00002ooooo`;o0000
0_ooool2o`0004oooooo000Looooo`03o`000?oooooooooo03[ooooo0_l00002ooooo`;o000000?o
ooooo`000?l000001?ooool2o`0001Wooooo0ol00006ooooo`Ko00000oooool5o`0000?ooooo0_l0
0002ooooo`Go00003?ooool2o`0001Cooooo0_l0000?ooooo`;o00002oooool2o`0000Cooooo0ol0
000Nooooo`;o00001?ooool4o`0000;ooooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`0a
ooooo`;o00001Oooool2o`0000Kooooo0ol00004ooooo`;o00006Oooool3o`0000Cooooo2_l00000
0ooooooo0000o`000008o`0000?ooooo1?l00007ooooo`;o00001oooool2o`0000_ooooo0_l00003
ooooo`;o00003Oooool4o`0000_ooooo0_l000000ooooooo0000o`000002ooooo`?o00005?ooool3
o`0000Kooooo1?l00002ooooo`;o0000EOooool001cooooo00?o0000ooooooooool0<Oooool2o`00
00Gooooo0_l00006ooooo`;o00000oooool2o`0002;ooooo0ol00002oooooaCo000000?oooooo`00
0?l000001?l00003ooooo`;o00001?ooool2o`000003ooooool0003o000000_ooooo0_l00007oooo
o`;o00002Oooool2o`00013ooooo0_l00003ooooo`;o00002_ooool3o`0000Gooooo1Ol00008oooo
o`;o0000FOooool001cooooo00?o0000ooooooooool0;_ooool2o`00017ooooo0ol000000ooooooo
0000o`00000RoooooaWo00000_ooool5o`0000?ooooo0_l00004ooooo`;o00005oooool2o`0000So
oooo0ol0000Qooooo`?o00001Oooool4o`0000_ooooo0_l0001Gooooo`007?ooool00ol0003ooooo
ooooo`0^ooooo`Co00001oooool4o`0000Cooooo1Ol0000Mooooo`Co00000_oooolDo`0000;ooooo
2Ol0000Kooooo`[o00002?ooool2o`0000gooooo0_l0000Fooooo`;o00001?ooool2o`000003oooo
ool0003o000000;o00000oooool2o`0000;ooooo0_l0000Uooooo`;o0000<?ooool001cooooo00?o
0000ooooooooool0;_ooool4o`0000Oooooo1?l00005ooooo`Co00005oooool2o`0000Cooooo1Ol0
00000ooooooo0000o`000002o`000003ooooool0003o000000oo000000?oooooo`000?l000001ol0
000Iooooo`oo00000_ooool5o`0000cooooo0_l0000Fooooo`?o00000oooool2o`000003ooooool0
003o000000;o00000oooool2o`0002Sooooo0ol0000`ooooo`007?ooool00ol0003oooooooooo`0k
ooooo`;o00001Oooool2o`0001Wooooo0_l00004ooooo`Go00000_ooool3o`0000?ooooo0_l00000
0ooooooo0000o`00000>o`0000;ooooo1Ol00002ooooo`?o00000oooool2o`0000kooooo3ol00002
ooooo`Go00000_ooool2o`00023ooooo0ol00007ooooo`;o0000;_ooool2o`00037ooooo000Loooo
o`03o`000?oooooooooo03_ooooo0_l00005ooooo`;o00006Oooool2o`0000Cooooo1?l000000ooo
oooo0000o`000004o`0000?ooooo3Ol000000ooooooo0000o`000002o`000003ooooool0003o0000
00Co00000_ooool4o`0000;ooooo0_l00003ooooo`;o00002?oooolAo`000004ooooool0003o0000
o`0000?ooooo0ol00008ooooo`;o00007Oooool5o`00067ooooo000Looooo`03o`000?oooooooooo
03[ooooo0_l0000Qooooo`;o00001?ooool2o`0000?ooooo5ol000000ooooooo0000o`000009o`00
0003ooooool0003o000000;o00001oooool2o`0000Oooooo5Ol00004ooooo`;o00002Oooool2o`00
0004ooooool0003o0000o`0001Wooooo1Ol0000Tooooo`?o0000>_ooool001cooooo00?o0000oooo
ooooool0>_ooool2o`0002Oooooo0_l00002oooooaWo000000?oooooo`000?l000003Ol00007oooo
o`;o00001OoooolHo`0000kooooo0_l000001?oooooo0000o`000?l00012ooooo`?o0000>_ooool0
01cooooo0_l0000aooooo`;o00000oooool2o`0000?ooooo0_l00003ooooo`;o00009_ooool3o`00
0003ooooool0003o000002;o00003ooooolHo`00017ooooo0_l0001=ooooo`;o0000<Oooool001co
oooo00?o0000ooooooooool0<?ooool2o`0000?ooooo0_l00003ooooo`;o00000oooool2o`000003
ooooool0003o000001gooooo0_l000000ooooooo0000o`00000;o`000003ooooool0003o000001_o
00001Oooool2o`0000Kooooo6?l0001Rooooo`;o0000<Oooool001cooooo00?o0000ooooooooool0
<Oooool2o`0000Oooooo0_l00006ooooo`;o00007?ooool3o`000003ooooool0003o000002Go0000
00?oooooo`000?l000001_ooool2o`0000Gooooo2?l000000ooooooo0000o`00000=o`00023ooooo
0_l0000/ooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0<Oooool2o`0000Sooooo0_l0
000Qooooo`Co000000?oooooo`000?l000000_oooolYo`0000Kooooo0_l00002ooooo`Oo00000ooo
ool<o`0001Sooooo0_l00009ooooo`;o00009_ooool2o`000003ooooool0003o000000?o00000_oo
ool2o`0004;ooooo000Looooo`03o`000?oooooooooo03_ooooo0_l0000Pooooo`So00000_oooolY
o`0000Kooooo0_l00002ooooo`Co00004_ooool2o`0000kooooo0_l00006ooooo`;o00002Oooool2
o`0002Kooooo2?l00002ooooo`;o00003_ooool2o`0003;ooooo000Looooo`03o`000?oooooooooo
03Oooooo0_l0000Tooooo`Oo00000_oooolYo`0000[ooooo1?l00005ooooo`;o00002_ooool5o`00
0003ooooool0003o000000;o00002?ooool2o`0000oooooo1?l0000Qooooo`;o00000_ooool5o`00
00;ooooo0ol000000ooooooo0000o`00000>ooooo`?o0000<Oooool001cooooo00?o0000oooooooo
ool0=oooool2o`0002Kooooo1Ol00002ooooo`Wo000000?oooooo`000?l000005ol000000ooooooo
0000o`000003o`0000Sooooo1_l00005ooooo`;o00002_ooool2o`000004ooooool0003o0000oooo
o`Ko00001_ooool4o`0000gooooo1?l0000Qooooo`;o00000_ooool2o`000004ooooool0003o0000
ooooo`Co000000?oooooo`000?l000003?ooool2o`000003ooooool0003o0000037ooooo000Loooo
o`03o`000?oooooooooo03Oooooo0_l0000Tooooo`Go00000oooool9o`0000;ooooo8Ol000000ooo
oooo0000o`000003ooooo`Go00003_ooool2o`0000cooooo0_l00008ooooo`;o0000<_ooool2o`00
00Sooooo0ol0000@ooooo`;o0000=?ooool001cooooo00?o0000ooooooooool0GOooool3o`0000Go
oooo1_l000000ooooooo0000o`000002o`000003ooooool0003o000001Oo000000Goooooo`000?l0
003o0000ooooo`02o`000003ooooool0003o000000?ooooo1?l0000?ooooo`;o00003Oooool2o`00
00Oooooo1?l00004ooooo`?o000000?oooooo`000?l000009_ooool2o`0000Kooooo1_l000000ooo
oooo0000o`000012ooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o00000_ooool4o`0000Ko
oooo8ol00002ooooo`?o00002?ooool4o`0000Kooooo0_l0000:ooooo`;o00002oooool2o`0000Oo
oooo1?l00004ooooo`?o000000?oooooo`000?l00000;_ooool6o`000003ooooool0003o000004;o
oooo000Looooo`03o`000?oooooooooo037ooooo0_l00008ooooo`;o00006oooool2o`0000;ooooo
1?l00006ooooob;o00001?ooool2o`0000Gooooo1_l00007ooooo`;o00001?ooool2o`0000Cooooo
0_l00002ooooo`;o00004?ooool2o`0000Cooooo1?l0000:ooooo`;o00009oooool2o`0000;ooooo
0ol00013ooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00002?ooool2o`0001kooooo0_l0
0008ooooo`Ko000000?oooooo`000?l000006_l00003ooooo`;o00001_ooool6o`0000[ooooo1_l0
0003ooooo`;o00000_ooool2o`000003ooooool0003o000000_ooooo0ol000000ooooooo0000o`00
0002ooooo`Co00002?ooool4o`0002Oooooo0ol000000ooooooo0000o`000003o`00047ooooo000L
ooooo`03o`000?oooooooooo037ooooo0_l0000Xooooo`Go00001Oooool3o`000003ooooool0003o
000001co00000_ooool4o`0000cooooo0_l00008ooooo`Ko00001oooool2o`000003ooooool0003o
000000Kooooo0_l00003ooooo`?o000000?oooooo`000?l000001_ooool4o`000003ooooool0003o
000000?o0000:?ooool4o`0000?ooooo0ol00011ooooo`007?ooool00ol0003oooooooooo`1Moooo
o`?o00001_ooool3o`000003ooooool0003o000001[o00000_ooool4o`0000Cooooo0_l00002oooo
o`?o00000_ooool2o`0000Kooooo0_l0000:ooooo`;o000000?oooooo`000?l000001_ooool5o`00
00Oooooo0_l000000ooooooo0000o`000002ooooo`Go000000?oooooo`000?l000000_l0000Moooo
o`;o00002_ooool5o`0000;ooooo0_l0000;ooooo`;o0000=Oooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oo
oooooooo037ooooo0_l00003ooooo`Co00000_ooool2o`00023ooooo0_l00006ooooo`Ko00000_oo
oolHo`0000;ooooo0ol00004ooooo`So00002_ooool4o`0000Oooooo0ol00009ooooo`?o00000_oo
ool8o`000004ooooool0003o0000o`0000;ooooo1Ol0000;ooooo`;o00004_ooool2o`000003oooo
ool0003o000000[ooooo1Ol0000>ooooo`?o0000=Oooool00006oooooomgMgOoV9RHoooooonHV9So
MgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo
037ooooo0_l00003ooooo`Co00000_ooool3o`0002Oooooo1Ol000000ooooooo0000o`00000Ho`00
00;ooooo0_l00003ooooo`Co000000?oooooo`000?l000000_l0000=ooooo`;o00001oooool4o`00
00Oooooo1Ol000000ooooooo0000o`00000:o`000004ooooool0003o0000ooooo`Go000000?ooooo
o`000?l000001_ooool2o`0000[ooooo1Ol00003ooooo`;o00003_ooool2o`00013ooooo0_l0000f
ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`0aooooo`;o00001Oooool2o`0000?ooooo0_l0000O
ooooo`;o00001_oooolNo`0000?ooooo0ol00003ooooo`Co00000_ooool2o`0000kooooo0ol00003
ooooo`;o00000oooool4o`000005ooooool0003o0000o`000?ooool00_l000000ooooooo0000o`00
0005oooooa7o000000?oooooo`000?l000004_ooool5o`0001?ooooo0_l00018ooooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_oo
ool3o`00037ooooo0ol0000:ooooo`;o00004_ooool2o`0000Sooooo1?l00006ooooob?o00001?oo
ool6o`0000Oooooo0_l00007ooooo`?o00000oooool2o`0000?ooooo1?l000000ooooooo0000o`00
0002o`0000?ooooo0_l00004oooooa;o00001?ooool2o`0000Gooooo1?l0000Aooooo`;o00002_oo
ool3o`0000oooooo0_l0000gooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09
ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0booooo`;o00002_oo
ool2o`0001;ooooo0_l00007ooooo`Co00002?oooolPo`0000Kooooo0_l000001?oooooo0000o`00
0?l00007ooooo`;o00001Oooool2o`0000_ooooo0_l00002ooooo`co000000?oooooo`000?l00000
4Ol00004ooooo`;o00001Oooool4o`00017ooooo0_l0000:ooooo`?o00003oooool2o`0003Oooooo
00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qoooool02?oo
ool00ol0003oooooooooo`0gooooo`;o00000_ooool2o`0000;ooooo0_l0000Aooooo`;o000000?o
ooooo`000?l000001?ooool4o`0000Sooooo7_l0000:ooooo`?o00002?ooool4o`0000?ooooo0_l0
0006ooooo`;o00001?ooool2o`000003ooooool0003o000001go000000?oooooo`000?l000007_oo
ool2o`0000Cooooo0_l00004ooooo`;o0000BOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo03Oooooo0_l00002ooooo`;o0000
0_ooool3o`00013ooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool2o`0000Sooooo
7_l00003ooooo`;o00001Oooool2o`0000_ooooo0_l00009ooooo`Co00000oooool3o`0000Oooooo
0_l00003oooooaSo00000oooool2o`0001Sooooo0_l00003ooooo`?o000000?oooooo`000?l00000
0_l0001:ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co0000oa0@
40Kooooo00?o0000ooooooooool0>_ooool2o`0000?ooooo0ol0000?ooooo`?o00001Oooool6o`00
00[ooooo0ol000000ooooooo0000o`000002o`0000Cooooo3?l00007ooooo`Co00000_ooool3o`00
00Oooooo0_l0000=ooooo`Co00000oooool2o`0000Sooooo0ol00002oooooaGo000000?oooooo`00
0?l000000oooool2o`0001Kooooo0_l00005ooooo`?o000000?oooooo`000?l000000_l0001:oooo
o`007?ooool00ol0003oooooooooo`0jooooo`;o00001?ooool4o`0000gooooo0_l00006ooooo`Co
00003Oooool7o`0000Cooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00001oooool2o`00
00?ooooo1_l00008ooooo`;o00002?ooool2o`0000_ooooo0_l00007ooooo`?o00000_oooolEo`00
00;ooooo0_l00003ooooo`;o00005Oooool2o`0000Kooooo0ol0000@ooooo`?o0000>oooool001co
oooo00?o0000ooooooooool0<oooool2o`0000_ooooo1Ol0000Dooooo`Co00003Oooool6o`0001?o
oooo1?l00002ooooo`Ko00001oooool2o`0000[ooooo0_l0000;ooooo`;o00001?ooool3o`000005
ooooool0003o0000o`000?ooool05?l000000ooooooo0000o`000002o`0000?ooooo0ol0000=oooo
o`;o00003Oooool3o`00013ooooo0ol0000kooooo`007?ooool00ol0003oooooooooo`0booooo`?o
00003_ooool2o`0002Kooooo1_l00005ooooo`?o00001Oooool2o`0000?ooooo2Ol0000:ooooo`;o
00000oooool2o`0001Sooooo0ol000000ooooooo0000o`00000Ko`0000Cooooo0_l0000=ooooo`;o
00002_ooool2o`000003ooooool0003o0000017ooooo0_l0000looooo`007?ooool00ol0003ooooo
ooooo`0booooo`;o00003oooool2o`0001Gooooo0ol0000?ooooo`Ko00000_ooool5o`000003oooo
ool0003o000000;ooooo0_l00004ooooo`Oo00002_ooool2o`0000?ooooo0ol000000ooooooo0000
o`00000Aooooo`;o00001_oooolKo`00017ooooo0_l0000>ooooo`?o00001_ooool2o`0000_ooooo
0_l0000looooo`007?ooool00ol0003oooooooooo`0kooooo`;o00001Oooool3o`0001Gooooo0ol0
000?ooooo`Ko00000_ooool2o`0000;ooooo1?l00003ooooo`;o00000_ooool6o`0000_ooooo0ol0
00000ooooooo0000o`000006o`0000oooooo1?l00007oooooa[o00002Oooool2o`0000?ooooo0_l0
00000ooooooo0000o`00000;ooooo`Oo00001Oooool2o`0004Wooooo000Looooo`03o`000?oooooo
oooo03_ooooo0_l00005ooooo`;o00005_ooool2o`00017ooooo1_l00003ooooo`Oo000000?ooooo
o`000?l000002?l00009ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l0000A
ooooo`;o00002OoooolMo`0000;ooooo0_l00002ooooo`;o00000oooool2o`0000kooooo1?l00000
0ooooooo0000o`000002ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0Foooool2o`00
01;ooooo5ol0000;ooooo`;o00001?ooool5o`0001kooooo2?l000000ooooooo0000o`00000Fo`00
01Kooooo2?l00002ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0AOooool3o`0001?o
oooo1?l0000Cooooo`ko00004Oooool2o`0000Cooooo0_l000000ooooooo0000o`00000Dooooo`;o
00002ooooolOo`0001Gooooo2?l0001@ooooo`007?ooool00ol0003oooooooooo`15ooooo`?o0000
2oooool2o`0000Sooooo0_l0000Cooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o0000
4?ooool2o`0000Wooooo0_l0000Fooooo`;o00002_oooolQo`0001Cooooo0ol00002ooooo`;o0000
DOooool001cooooo00?o0000ooooooooool0A_ooool2o`0000_ooooo0_l0000hooooo`;o00002Ooo
ool2o`0002;ooooo0ol000000ooooooo0000o`00000Fo`0000;ooooo0ol0000Aooooo`;o000000Co
ooooo`000?l0003ooooo1?l0001Aooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00007_oo
ool2o`0002gooooo0_l00002ooooo`Co00008?ooool2o`0000Gooooo7?l00002ooooo`;o00000ooo
ool2o`0000?ooooo0_l00008ooooo`Co00000_ooool3o`0000cooooo0ol00013ooooo`007?ooool2
o`0003oooooo0_l0000Nooooo`?o0000:Oooool2o`000003ooooool0003o000000;ooooo1?l0000P
ooooo`Co00001?oooolKo`0000;ooooo0ol00002ooooo`Co000000?oooooo`000?l000002Oooool3
o`000004ooooool0003o0000o`0000gooooo0ol00013ooooo`007?ooool00ol0003oooooooooo`0n
ooooo`Go00005?ooool3o`0000Gooooo0_l0000Yooooo`;o000000?oooooo`000?l000001?ooool2
o`0002;ooooo0_l00004oooooaOo00001_ooool3o`0000Cooooo0_l00009ooooo`Go00000_ooool2
o`0005Cooooo000Looooo`03o`000?oooooooooo03oooooo1?l0000Dooooo`?o00001Oooool2o`00
02cooooo0_l00004ooooo`;o0000:?oooolHo`0000;ooooo1Ol0000@ooooo`?o00004Oooool2o`00
04Oooooo000Looooo`03o`000?oooooooooo04;ooooo0_l0000mooooo`?o00002?ooool4o`0000?o
oooo0_l0000Yooooo`Go000000?oooooo`000?l000003ol00002ooooo`?o000000?oooooo`000?l0
00000_ooool2o`0000Oooooo1?l00006ooooo`;o00003?ooool2o`0004Oooooo000Looooo`03o`00
0?oooooooooo04;ooooo0_l0000Xooooo`;o00004oooool3o`0000Cooooo0_l00002ooooo`Co0000
0oooool2o`0000kooooo2?l0000;ooooo`;o00001_ooool5o`0000?ooooo3Ol00002ooooo`?o0000
0oooool2o`0000;ooooo0_l00002ooooo`;o00000oooool4o`0000Kooooo0_l0001Eooooo`007?oo
ool00ol0003oooooooooo`0jooooo`;o0000:?ooool2o`0000Kooooo0_l0000Booooo`;o00001_oo
ool2o`0001Oooooo2ol0000:ooooo`;o00002Oooool2o`000003ooooool0003o000000?ooooo2_l0
0002ooooo`?o00001oooool2o`000004ooooool0003o0000o`0000Wooooo0_l00002ooooo`;o0000
EOooool001cooooo00?o0000ooooooooool0>_ooool2o`0001Wooooo0_l0000=ooooo`;o00003Ooo
ool2o`0000_ooooo0_l00004ooooo`Co00005oooool2o`0000Cooooo1Ol00002ooooo`;o00003?oo
ool2o`0000?ooooo1ol000000ooooooo0000o`000007o`0000;ooooo0ol00008ooooo`;o000000?o
ooooo`000?l000001?ooool2o`0000Cooooo0_l0000=ooooo`;o0000B_ooool001cooooo00?o0000
ooooooooool0EOooool2o`0000gooooo0_l00008ooooo`;o00000oooool2o`0000Sooooo0_l00002
ooooo`;o00000oooool4o`0001Oooooo1?l00009ooooo`;o000000?oooooo`000?l000002Oooool2
o`0000Gooooo0_l000000ooooooo0000o`00000;o`000004ooooool0003o0000o`0000?ooooo0_l0
00000ooooooo0000o`000006ooooo`Go00004_ooool3o`0004[ooooo000Looooo`03o`000?oooooo
oooo03_ooooo0_l00004ooooo`?o00007oooool5o`0000Cooooo1?l0000=ooooo`;o00000_ooool2
o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0001;ooooo0_l000000ooooooo0000o`00
000:ooooo`Co00002_ooool2o`0000Oooooo3Ol000000ooooooo0000o`000003ooooo`?o000000?o
ooooo`000?l000000_ooool2o`0000;ooooo1?l00002ooooo`;o000000?oooooo`000?l000003?oo
ool2o`0004_ooooo000Looooo`03o`000?oooooooooo03_ooooo0_l00004ooooo`?o000000?ooooo
o`000?l000007?ooool6o`0000?ooooo1?l0000;ooooo`;o00002_ooool4o`000003ooooool0003o
000001;ooooo0_l0000=ooooo`Go00002Oooool2o`0000Oooooo3Ol000000ooooooo0000o`000003
ooooo`?o00001Oooool2o`0000;ooooo0_l00002ooooo`Co000000?oooooo`000?l00000FOooool0
01cooooo00?o0000ooooooooool0AOooool5o`0001Cooooo0_l00005ooooo`Co00001Oooool2o`00
00_ooooo0_l00006ooooo`;o00000_ooool2o`0001Sooooo0_l0000?ooooo`;o00004?ooool2o`00
0003ooooool0003o000000;o00002_ooool2o`000004ooooool0003o0000ooooo`;o000000?ooooo
o`000?l000001_ooool2o`000003ooooool0003o000000gooooo0_l0001?ooooo`007?ooool00ol0
003oooooooooo`16ooooo`Co00005?ooool2o`0001cooooo0_l00005ooooo`;o00007?ooool2o`00
01?ooooo0_l00008ooooo`;o00000_ooool2o`0000?ooooo1?l00005ooooo`;o000000?oooooo`00
0?l000001_l000000ooooooo0000o`000006ooooo`?o00003oooool2o`0004oooooo000Looooo`03
o`000?oooooooooo07cooooo0_l0000Sooooo`?o00004_ooool3o`0000Oooooo1?l00005ooooo`Co
00001Oooool2o`0000;ooooo1_l00007ooooo`;o00000_ooool2o`0000_ooooo0ol0001Booooo`00
7?ooool00ol0003oooooooooo`15ooooo`;o000000Coooooo`000?l0003o00006oooool2o`0000Go
oooo0_l000000ooooooo0000o`00000`ooooo`;o00002?ooool2o`0000;ooooo0ol00004ooooo`?o
00001oooool5o`0001Sooooo1ol0000?ooooo`?o0000D_ooool001cooooo00?o0000ooooooooool0
AOooool2o`000004ooooool0003o0000o`0001_ooooo0_l00005ooooo`;o000000?oooooo`000?l0
00000_ooool2o`0000_ooooo0ol0000Xooooo`;o00000_ooool3o`0000Gooooo0ol00007ooooo`Ko
00002oooool2o`0000Kooooo0_l000000ooooooo0000o`000004o`0000kooooo0ol0001Dooooo`00
7?ooool00ol0003oooooooooo`1@ooooo`;o00002?ooool2o`0001Sooooo0_l0000;ooooo`Ko0000
<_ooool3o`0000Kooooo0_l00002ooooo`;o00000oooool2o`0000Kooooo0_l000001?oooooo0000
o`000?l00002ooooo`;o00001?ooool3o`0000_ooooo0_l000001?oooooo0000o`000?l0001Doooo
o`007?ooool2o`0004oooooo1?l00008ooooo`;o00000_ooool2o`0000;ooooo0_l0000Pooooo`?o
0000<oooool3o`0000kooooo0_l00009ooooo`?o00005_ooool2o`0005Sooooo000Looooo`03o`00
0?oooooooooo04kooooo0_l0000;ooooo`;o000000?oooooo`000?l000001Ol0001Eooooo`?o0000
7_ooool2o`0001;ooooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o00001?oo
ool2o`0000Gooooo0_l00003ooooo`;o000000?oooooo`000?l000006Oooool2o`0003Gooooo0_l0
0003ooooo`;o000000?oooooo`000?l000004oooool2o`0000Oooooo0_l0000=ooooo`;o0000GOoo
ool001cooooo00?o0000ooooooooool0C_ooool2o`0000;ooooo1?l0000Xooooo`Co00009oooool3
o`0000Wooooo0_l00006ooooo`Co00004Oooool2o`0001?ooooo0_l000000ooooooo0000o`00001M
ooooo`007?ooool00ol0003oooooooooo`1Booooo`?o000000?oooooo`000?l000003oooool2o`00
017ooooo1?l000001?oooooo0000o`000?l0000Uooooo`Go00004_ooool5o`0002?ooooo0ol0001P
ooooo`007?ooool00ol0003oooooooooo`1@ooooo`Go000000?oooooo`000?l000001?ooool2o`00
00Wooooo0_l0000Aooooo`Co000000?oooooo`000?l000009_ooool4o`0000Wooooo1?l00005oooo
o`;o00000_ooool5o`0001cooooo0_l00002ooooo`;o0000HOooool001cooooo00?o0000oooooooo
ool0D?ooool3o`0000;ooooo0ol00004ooooo`;o00007oooool2o`0002Kooooo0ol0000;ooooo`Go
00001Oooool2o`0000?ooooo1Ol0000Dooooo`?o000000?oooooo`000?l000000ol0001Uooooo`00
7?ooool00ol0003oooooooooo`1Eooooo`;o00009_ooool2o`0002Kooooo0ol0000;ooooo`?o0000
2?ooool2o`0000Gooooo0_l00004ooooo`;o000000?oooooo`000?l000000_ooool2o`000004oooo
ool0003o0000ooooo`_o0000I_ooool001cooooo00?o0000ooooooooool0Coooool2o`0000;ooooo
0_l0000Booooo`;o00000oooool2o`0000oooooo0ol0000/ooooo`Co000000Coooooo`000?l0003o
oooo0_l00008ooooo`;o00002oooool2o`000003ooooool0003o000000;ooooo0_l000001?oooooo
0000o`000?ooool5o`000003ooooool0003o000006Wooooo000Looooo`03o`000?oooooooooo04oo
oooo0_l00002ooooo`;o00004_ooool2o`0000?ooooo0_l0000>ooooo`Co00000_ooool4o`0002Ko
oooo1?l000000ooooooo0000o`00002Fooooo`007?ooool00ol0003oooooooooo`1Wooooo`;o0000
00?oooooo`000?l000004?ooool2o`0000Cooooo1?l0000[ooooo`;o000000Coooooo`000?l0003o
0000BOooool2o`0004Oooooo000Looooo`03o`000?oooooooooo05Sooooo0_l000001?oooooo0000
o`000?l00009ooooo`;o000000?oooooo`000?l000001oooool2o`0000_ooooo0_l0000_ooooo`;o
000000Goooooo`000?l0003o0000ooooo`02o`0000_ooooo0_l000000ooooooo0000o`00000foooo
o`;o0000Aoooool001cooooo00?o0000ooooooooool0F?ooool2o`000004ooooool0003o0000o`00
00gooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l00008ooooo`;o00002?ooool2
o`00027ooooo1?l00007ooooo`;o00000_ooool3o`0000?ooooo0_l000001?oooooo0000o`000?oo
ool2o`0007oooooo000Looooo`03o`000?oooooooooo05Cooooo0_l00004ooooo`;o00003oooool2
o`0000?ooooo0_l00004ooooo`Co00004?ooool4o`0001kooooo1Ol0000;ooooo`?o00000_ooool3
o`0001Kooooo0_l0001]ooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o00000_ooool6o`00
01Wooooo0ol0000Booooo`?o00007Oooool4o`0000;ooooo0ol0000<ooooo`;o00001?ooool2o`00
00Gooooo0_l0000:ooooo`;o0000KOooool001cooooo00?o0000ooooooooool0Eoooool4o`000003
ooooool0003o000000oooooo0_l00006ooooo`;o000000Coooooo`000?l0003o00004_ooool2o`00
02?ooooo0ol00008ooooo`;o00001_ooool4o`0000Gooooo0_l000000ooooooo0000o`000003oooo
o`;o0000LOooool001cooooo0_l0001Hooooo`;o000000?oooooo`000?l000003?ooool2o`0000?o
oooo0_l00006ooooo`Wo00002_ooool2o`0002cooooo0ol00004ooooo`;o00001_ooool2o`0000[o
oooo0_l00003ooooo`;o00000oooool2o`0001cooooo0_l0001>ooooo`007?ooool00ol0003ooooo
ooooo`1Gooooo`;o000000?oooooo`000?l000001_ooool2o`0000Cooooo0ol00007ooooo`;o0000
0oooool3o`000004ooooool0003o0000o`0000[ooooo0_l0000Mooooo`;o00002Oooool8o`0000Co
oooo0_l0000Kooooo`;o00006Oooool5o`0004kooooo000Looooo`03o`000?oooooooooo06;ooooo
0_l00005ooooo`;o00001oooool2o`0000Cooooo0_l00002ooooo`Go00001_ooool2o`0000[ooooo
0_l0000Booooo`;o00001oooool:o`0000Cooooo0_l00008ooooo`?o00001_ooool2o`0002?ooooo
0ol0001@ooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o00001Oooool2o`0000?ooooo0_l0
0009ooooo`?o00001Oooool7o`0000?ooooo0ol0000:ooooo`;o00004_ooool2o`0000Kooooo1_l0
0003ooooo`Co00003?ooool3o`0000?ooooo0_l000000ooooooo0000o`00001fooooo`007?ooool0
0ol0003oooooooooo`1Mooooo`;o00000_ooool2o`000003ooooool0003o000000?o00000oooool2
o`0000Cooooo1Ol00005ooooo`;o000000?oooooo`000?l000001?l000001?oooooo0000o`000?l0
000<ooooo`;o00004?ooool3o`0000Gooooo2?l000000ooooooo0000o`000002o`0000Cooooo0ol0
0005ooooo`;o00000oooool3o`00023ooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`1Q
ooooo`?o00000_ooool3o`0000?ooooo0_l00004ooooo`Co00002oooool9o`000003ooooool0003o
000000?ooooo0_l00003ooooo`;o00004Oooool2o`0000Cooooo0_l00003ooooo`Co000000?ooooo
o`000?l000001_ooool3o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o00001Oooool2
o`0001Wooooo0ol0001Gooooo`007?ooool00ol0003oooooooooo`1Oooooo`;o000000?oooooo`00
0?l000001oooool2o`0000Oooooo0_l0000:ooooo`;o000000?oooooo`000?l000002_l000001?oo
oooo0000o`000?l00002ooooo`;o00005oooool2o`0000Cooooo1Ol00007ooooo`;o000000?ooooo
o`000?l000001Ol0000:ooooo`;o00006?ooool3o`0005Sooooo000Looooo`03o`000?oooooooooo
05oooooo0ol00007ooooo`Co00001oooool2o`000003ooooool0003o000000;o00001Oooool2o`00
0003ooooool0003o000000Cooooo1_l00002ooooo`;o00000_ooool4o`0001?ooooo0_l00008oooo
o`?o00002Oooool7o`0002Gooooo0_l0001Iooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o
00001oooool2o`0000;ooooo0_l00008ooooo`Co00001Oooool5o`0000Gooooo0ol00003ooooo`;o
00001?ooool3o`0001?ooooo0_l0000<ooooo`Ko000000Coooooo`000?l0003o0000QOooool001co
oooo00?o0000ooooooooool0H?ooool2o`0000_ooooo0_l0000Cooooo`Go00000oooool3o`0000?o
oooo0_l0000Jooooo`;o00003?ooool6o`000003ooooool0003o000008Kooooo000Looooo`03o`00
0?oooooooooo063ooooo0_l0000Sooooo`;o00001?ooool2o`0000?ooooo1?l0000Hooooo`;o0000
00?oooooo`000?l00000V?ooool001cooooo00?o0000ooooooooool0Joooool2o`0000;ooooo1?l0
000:ooooo`;o00002?ooool4o`0000Gooooo1?l0000Aooooo`;o00001Oooool2o`000003ooooool0
003o000009Sooooo000Looooo`03o`000?oooooooooo06Kooooo0_l00003ooooo`;o00000_ooool4
o`0000[ooooo1?l00006ooooo`Co00006_ooool3o`0000Cooooo0_l0002Kooooo`007?ooool00ol0
003oooooooooo`1Vooooo`Ko00001Oooool2o`0000[ooooo1?l00002ooooo`;o00008Oooool2o`00
0:7ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Xooooo`Co00001Oooool2o`0000[ooooo2?l0
000Vooooo`;o0000<oooool2o`0006Oooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo
0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1Xooooo`Go
00004_ooool4o`000003ooooool0003o000001Oooooo0_l0000;ooooo`?o0000<?ooool5o`0006Oo
oooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo06[ooooo0ol0000Booooo`;o00000oooool2o`0001Oo
oooo0_l0000;ooooo`?o0000;oooool5o`0006Sooooo00000ooooooo0000ooooo`02ooooo`03o`00
0?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000M?ooool2o`0000;o
oooo0_l0000Booooo`;o00007?ooool3o`0000Cooooo0_l0000Vooooo`;o000000?oooooo`000?l0
0000Joooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Oo<c<co0000
o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0L_ooool4o`0000;ooooo0_l0000Booooo`;o
00001oooool2o`0001?ooooo0ol00003ooooo`?o00009Oooool3o`0006kooooo00000ooooooo410@
ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03
o`000?oooooooooo077ooooo0ol00009ooooo`;o00002?ooool2o`0000Sooooo0_l000001?oooooo
0000o`000?l00007ooooo`;o00002oooool2o`0000?ooooo0_l0000Vooooo`;o0000Koooool00006
oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o
0000ooooooooool0LOooool2o`0000Gooooo0_l000000ooooooo0000o`000002o`0000Sooooo1?l0
0006ooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo0_l0002Yooooo`0000Kooooo
onk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003o
ooooooooo`1dooooo`;o000000?oooooo`000?l000001?l0000<ooooo`;o00001Oooool2o`0000Oo
oooo0_l0000>ooooo`;o00009_ooool2o`0007Kooooo000Looooo`03o`000?oooooooooo07Cooooo
0_l000000ooooooo0000o`000002o`0000Sooooo0_l0000;ooooo`;o00000_ooool2o`000003oooo
ool0003o000000kooooo1?l0000Qooooo`;o00000oooool2o`0007Kooooo000Looooo`03o`000?oo
oooooooo07Wooooo1?l00006ooooo`;o00003oooool7o`0000cooooo0_l000000ooooooo0000o`00
000Mooooo`Go0000Noooool001cooooo00?o0000ooooooooool0Noooool2o`0001Sooooo0_l00002
ooooo`;o000000?oooooo`000?l000000ol00002ooooo`Ko000000?oooooo`000?l000007Oooool3
o`0007gooooo000Looooo`03o`000?oooooooooo07_ooooo0_l0000<ooooo`;o00004Oooool5o`00
00;ooooo1?l0000Nooooo`Co0000P?ooool001cooooo00?o0000ooooooooool0Noooool2o`0000[o
oooo1?l00002ooooo`;o0000=?ooool6o`00083ooooo000Looooo`03o`000?oooooooooo08Oooooo
0_l00004ooooo`;o0000<oooool3o`0008Cooooo000Looooo`03o`000?oooooooooo09Sooooo0_l0
000Xooooo`?o0000Q?ooool001cooooo00?o0000ooooooooool0Q?ooool2o`000003ooooool0003o
000000oooooo0_l000000ooooooo0000o`00000Rooooo`;o0000R?ooool001cooooo00?o0000oooo
ooooool0Q?ooool2o`000003ooooool0003o000000;ooooo0_l0000>ooooo`;o00008_ooool2o`00
08Sooooo000Looooo`03o`000?oooooooooo08_ooooo0_l0000Booooo`;o0000Z?ooool001cooooo
00?o0000ooooooooool0Roooool2o`0001;ooooo0_l000000ooooooo0000o`00002Uooooo`007?oo
ool2o`000:3ooooo1_l000000ooooooo0000o`00000?ooooo`;o00000_ooool2o`0008cooooo000L
ooooo`03o`000?oooooooooo08kooooo0_l00005ooooo`;o00000oooool3o`0000Cooooo1?l00000
0ooooooo0000o`000002ooooo`;o00002_ooool3o`0000;ooooo0_l0002<ooooo`007?ooool00ol0
003oooooooooo`2>ooooo`;o00001Oooool2o`0000?ooooo0ol00005ooooo`;o00001_ooool6o`00
00?ooooo1Ol0002Aooooo`007?ooool00ol0003oooooooooo`2/ooooo`Co00000oooool4o`0009;o
oooo000Looooo`03o`000?oooooooooo0:Wooooo1_l0002Jooooo`007?ooool00ol0003ooooooooo
o`2Yooooo`Go0000Voooool001cooooo00?o0000ooooooooool0[?ooool2o`0009_ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo
00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000D
ooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBoooo
o`004_ooool00omEEEGoIVIVo`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo002Uooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05Oooool0
1OnHV9So410@o`000?lb<S;oc<c<00?ooooo1Ol00005ooooo`;o000000?o410@ooooooooool0S_oo
ool00:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00002Oooool01Ol@413o^[Zjoooo
oomgMgOo<S8b00?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo08oo
oooo002Vooooo`05o`000?ooooooooooooooool000007?ooool00ol0003oooooooooo`02ooooo`03
oiRHV?lQ8B7ok^k^00Cooooo1Ol0002@ooooo`00Y_ooool01Ol0003ooooooooooooooooo000000Wo
oooo1_l0000<ooooo`03ojVYZOl@413ooooo00Cooooo00?oV9RHob4Q8Oo^k^h00oooool01?m4A4Co
gMgMooooool0002Aooooo`00Y_ooool01Ol0003oQhN7oooooonYZJWo000001[ooooo00?o410@o`00
0?nj^[X01_ooool00omgMgOoIVIVooooo`02ooooo`04omgMgOmEEEGoooooo`00097ooooo002Uoooo
o`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool06Oooool00onj^[[o8B4Qooooo`06oooo
o`03o`000?oooooooooo00;ooooo00?oMgMgolc<c?l00000TOooool00<?ooooo00Go410@oiRHV?oo
oooo^[Zjo`000003ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00oo^k^koA4A4o`00002A
ooooo`00`oooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c005ooooo`03ogMgMol0003ooooo093ooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(330) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.63155 .63239 Mdot
.61014 .65969 Mdot
.55664 .29215 Mdot
.39495 .57911 Mdot
.47021 .30345 Mdot
.57006 .33304 Mdot
.68049 .46295 Mdot
.68173 .45811 Mdot
.5679 .30154 Mdot
.33865 .74342 Mdot
.70752 .49055 Mdot
.36696 .59659 Mdot
.69435 .47197 Mdot
.37901 .55916 Mdot
.38244 .43922 Mdot
.40845 .51848 Mdot
.6011 .61372 Mdot
.42667 .26315 Mdot
.40831 .52082 Mdot
.56227 .34617 Mdot
.31079 .6437 Mdot
.38714 .56819 Mdot
.61578 .68429 Mdot
.3828 .56012 Mdot
.32314 .54956 Mdot
.62064 .65081 Mdot
.63344 .63985 Mdot
.33132 .56389 Mdot
.4197 .55073 Mdot
.71128 .47831 Mdot
.50839 .44343 Mdot
.18575 .51874 Mdot
.33177 .5157 Mdot
.49214 .70646 Mdot
.71347 .46154 Mdot
.68041 .41263 Mdot
.60394 .34991 Mdot
.68064 .44443 Mdot
.72022 .48592 Mdot
.71091 .49459 Mdot
.70671 .49518 Mdot
.62257 .6488 Mdot
.65913 .45985 Mdot
.68352 .36216 Mdot
.39043 .55141 Mdot
.54199 .68954 Mdot
.65599 .36125 Mdot
.35569 .52687 Mdot
.58547 .65846 Mdot
.55112 .31893 Mdot
.33498 .33746 Mdot
.66884 .45946 Mdot
.5094 .54093 Mdot
.88096 .51593 Mdot
.69365 .46302 Mdot
.37158 .51622 Mdot
.59175 .31263 Mdot
.35098 .55384 Mdot
.34918 .5861 Mdot
.47022 .67904 Mdot
.34877 .56581 Mdot
.46412 .28813 Mdot
.6434 .68244 Mdot
.56835 .3631 Mdot
.56765 .29901 Mdot
.67007 .45161 Mdot
.56957 .64585 Mdot
.70461 .47868 Mdot
.41667 .56092 Mdot
.55413 .32481 Mdot
.39644 .52846 Mdot
.70598 .4906 Mdot
.63253 .65967 Mdot
.39864 .56634 Mdot
.74834 .65976 Mdot
.63069 .45523 Mdot
.54028 .28147 Mdot
.45558 .62556 Mdot
.44459 .3361 Mdot
.43974 .43086 Mdot
.3959 .5675 Mdot
.77394 .32591 Mdot
.36563 .41766 Mdot
.58903 .65685 Mdot
.52437 .53609 Mdot
.74422 .54371 Mdot
.33835 .53233 Mdot
.51333 .44627 Mdot
.44621 .55562 Mdot
.4497 .2258 Mdot
.58054 .3109 Mdot
.58386 .63644 Mdot
.39617 .55727 Mdot
.4102 .56279 Mdot
.43955 .80341 Mdot
.42186 .54739 Mdot
.33955 .58122 Mdot
.57813 .51786 Mdot
.66779 .49153 Mdot
.31093 .5852 Mdot
.50613 .36517 Mdot
.54074 .55893 Mdot
.36671 .51754 Mdot
.58654 .32327 Mdot
.63896 .68554 Mdot
.34423 .51202 Mdot
.69363 .48237 Mdot
.39374 .56251 Mdot
.6496 .45605 Mdot
.58821 .66622 Mdot
.34174 .5855 Mdot
.46486 .27042 Mdot
.45591 .61098 Mdot
.62664 .67254 Mdot
.53922 .77288 Mdot
.36294 .57527 Mdot
.35277 .54551 Mdot
.61238 .6617 Mdot
.57347 .35222 Mdot
.73324 .30313 Mdot
.63109 .65713 Mdot
.70802 .49642 Mdot
.58878 .61792 Mdot
.47334 .57073 Mdot
.57569 .35516 Mdot
.52712 .56507 Mdot
.51868 .56245 Mdot
.25732 .41211 Mdot
.38756 .58205 Mdot
.27302 .60894 Mdot
.57942 .32788 Mdot
.62309 .6673 Mdot
.70489 .47108 Mdot
.43237 .55536 Mdot
.60859 .63547 Mdot
.67734 .46168 Mdot
.48235 .26479 Mdot
.42193 .27545 Mdot
.60856 .67952 Mdot
.56064 .78186 Mdot
.74156 .46349 Mdot
.66088 .4907 Mdot
.3329 .34047 Mdot
.58937 .65757 Mdot
.44838 .27775 Mdot
.67901 .47871 Mdot
.29891 .25826 Mdot
.31833 .56191 Mdot
.30845 .36728 Mdot
.78572 .3519 Mdot
.33575 .33713 Mdot
.29414 .64899 Mdot
.45626 .26795 Mdot
.67656 .46176 Mdot
.37803 .52511 Mdot
.5973 .6476 Mdot
.61222 .6379 Mdot
.4047 .53753 Mdot
.31809 .53669 Mdot
.37065 .55243 Mdot
.3297 .51924 Mdot
.57443 .49681 Mdot
.39443 .5572 Mdot
.67421 .74332 Mdot
.5951 .63954 Mdot
.324 .53095 Mdot
.5976 .34947 Mdot
.28237 .5519 Mdot
.66234 .45704 Mdot
.37305 .58885 Mdot
.31881 .54548 Mdot
.40712 .59005 Mdot
.70727 .49777 Mdot
.74919 .67379 Mdot
.4224 .31393 Mdot
.72957 .48179 Mdot
.77434 .45554 Mdot
.58883 .3385 Mdot
.33857 .55465 Mdot
.44352 .26322 Mdot
.31957 .59958 Mdot
.40425 .55464 Mdot
.34061 .33123 Mdot
.34286 .57972 Mdot
.28593 .64259 Mdot
.39796 .49555 Mdot
.74371 .53547 Mdot
.67232 .72303 Mdot
.39979 .57551 Mdot
.351 .72646 Mdot
.31918 .36443 Mdot
.62353 .42134 Mdot
.70667 .46992 Mdot
.56563 .33786 Mdot
.56931 .34655 Mdot
.71919 .44965 Mdot
.52689 .74122 Mdot
.31684 .72654 Mdot
.42149 .57006 Mdot
.53728 .55542 Mdot
.57946 .61678 Mdot
.45699 .26995 Mdot
.61184 .67688 Mdot
.75663 .30003 Mdot
.46005 .42237 Mdot
.48487 .45959 Mdot
.50931 .31584 Mdot
.54893 .31763 Mdot
.53286 .55827 Mdot
.4436 .27666 Mdot
.37258 .5446 Mdot
.58915 .66626 Mdot
.32316 .35812 Mdot
.35254 .6136 Mdot
.30509 .77474 Mdot
.63061 .63751 Mdot
.25432 .46167 Mdot
.69275 .46545 Mdot
.60578 .31238 Mdot
.33709 .5328 Mdot
.36539 .56718 Mdot
.58935 .67322 Mdot
.36741 .52816 Mdot
.44969 .46178 Mdot
.32125 .55637 Mdot
.57835 .3674 Mdot
.41488 .29741 Mdot
.73632 .46637 Mdot
.5042 .31547 Mdot
.63038 .66936 Mdot
.76763 .70005 Mdot
.59989 .33096 Mdot
.29319 .5216 Mdot
.69991 .49103 Mdot
.48183 .26759 Mdot
.59595 .32323 Mdot
.44467 .29908 Mdot
.37256 .59138 Mdot
.60778 .34159 Mdot
.46743 .28308 Mdot
.49492 .47653 Mdot
.33144 .51926 Mdot
.23963 .39704 Mdot
.67103 .4712 Mdot
.58769 .62515 Mdot
.4 .54223 Mdot
.51741 .53901 Mdot
.30921 .56677 Mdot
.28503 .43025 Mdot
.51119 .54865 Mdot
.5452 .56084 Mdot
.40985 .41212 Mdot
.45962 .25019 Mdot
.80592 .53232 Mdot
.52352 .45352 Mdot
.60284 .61364 Mdot
.40726 .56396 Mdot
.77812 .48349 Mdot
.6716 .46505 Mdot
.36417 .54725 Mdot
.77892 .50893 Mdot
.67724 .4762 Mdot
.35504 .54615 Mdot
.71565 .48339 Mdot
.60177 .63916 Mdot
.42316 .44723 Mdot
.61802 .61794 Mdot
.39407 .54669 Mdot
.71382 .4855 Mdot
.57125 .34494 Mdot
.61979 .64931 Mdot
.39231 .56539 Mdot
.36961 .58429 Mdot
.53466 .54761 Mdot
.31944 .55903 Mdot
.63615 .54073 Mdot
.3513 .5275 Mdot
.56074 .286 Mdot
.42132 .54908 Mdot
.44185 .36788 Mdot
.44016 .21735 Mdot
.59697 .67438 Mdot
.51184 .54826 Mdot
.59483 .31747 Mdot
.46596 .47575 Mdot
.2393 .46704 Mdot
.3894 .55579 Mdot
.51765 .54836 Mdot
.26214 .43004 Mdot
.66002 .4637 Mdot
.44789 .55214 Mdot
.52268 .28108 Mdot
.58045 .3127 Mdot
.53602 .55799 Mdot
.33664 .60658 Mdot
.56742 .61553 Mdot
.41066 .52411 Mdot
.60591 .34059 Mdot
.61115 .61802 Mdot
.41213 .53232 Mdot
.63272 .43026 Mdot
.52443 .53781 Mdot
.66227 .48955 Mdot
.56746 .51517 Mdot
.3511 .54091 Mdot
.55455 .32134 Mdot
.62187 .64192 Mdot
.69106 .45939 Mdot
.62838 .67007 Mdot
.34572 .34573 Mdot
.26622 .44198 Mdot
.56467 .68534 Mdot
.47398 .25031 Mdot
.25759 .28667 Mdot
.72967 .48386 Mdot
.30992 .58805 Mdot
.59323 .37889 Mdot
.66957 .69807 Mdot
.58589 .32015 Mdot
.57621 .77926 Mdot
.58504 .31094 Mdot
.38692 .51879 Mdot
.56264 .32253 Mdot
.43848 .81126 Mdot
.34415 .57606 Mdot
.56681 .29651 Mdot
.56802 .47666 Mdot
.3501 .57969 Mdot
.60854 .63446 Mdot
.19482 .58005 Mdot
.51264 .72218 Mdot
.51649 .73362 Mdot
.59763 .31479 Mdot
.58978 .77847 Mdot
.32964 .55894 Mdot
.43603 .55245 Mdot
.60217 .6482 Mdot
.30738 .56233 Mdot
.44103 .25577 Mdot
.42536 .27743 Mdot
.31387 .29557 Mdot
.20814 .51904 Mdot
.52543 .75416 Mdot
.61385 .64214 Mdot
.43664 .31649 Mdot
.74095 .66791 Mdot
.5226 .53785 Mdot
.68085 .45824 Mdot
.78048 .63578 Mdot
.4412 .56338 Mdot
.56501 .556 Mdot
.44557 .4605 Mdot
.6025 .62117 Mdot
.54934 .59962 Mdot
.68848 .45851 Mdot
.51403 .73395 Mdot
.29963 .70383 Mdot
.37069 .55105 Mdot
.66511 .47436 Mdot
.31 .56131 Mdot
.51363 .44918 Mdot
.24307 .42069 Mdot
.65422 .27715 Mdot
.39209 .5466 Mdot
.78348 .6158 Mdot
.40225 .54856 Mdot
.26747 .39919 Mdot
.37089 .54335 Mdot
.61671 .6348 Mdot
.40962 .59211 Mdot
.5265 .46025 Mdot
.32664 .208 Mdot
.45467 .4153 Mdot
.43832 .29419 Mdot
.37785 .56168 Mdot
.36174 .55754 Mdot
.46152 .29266 Mdot
.59224 .62631 Mdot
.40656 .54738 Mdot
.81946 .5314 Mdot
.39684 .56038 Mdot
.67406 .45105 Mdot
.32037 .41486 Mdot
.19226 .49923 Mdot
.33155 .54891 Mdot
.56704 .61734 Mdot
.66174 .49083 Mdot
.68937 .49081 Mdot
.44995 .59161 Mdot
.66987 .46739 Mdot
.37593 .5261 Mdot
.32053 .41375 Mdot
.57727 .67253 Mdot
.44725 .59169 Mdot
.60421 .62289 Mdot
.48002 .16944 Mdot
.67412 .46751 Mdot
.52032 .54107 Mdot
.54052 .75489 Mdot
.68677 .47704 Mdot
.40656 .27686 Mdot
.41362 .59027 Mdot
.38429 .61802 Mdot
.60799 .60674 Mdot
.55542 .32202 Mdot
.52354 .55695 Mdot
.69274 .4619 Mdot
.38975 .55324 Mdot
.3425 .52072 Mdot
.66837 .46937 Mdot
.39067 .66873 Mdot
.50972 .44279 Mdot
.39659 .54813 Mdot
.60039 .63097 Mdot
.62443 .6642 Mdot
.41533 .51808 Mdot
.40299 .54756 Mdot
.56998 .3376 Mdot
.51695 .54869 Mdot
.51512 .55193 Mdot
.53051 .5673 Mdot
.60251 .31461 Mdot
.26191 .27652 Mdot
.6557 .48588 Mdot
.18755 .51274 Mdot
.73527 .62507 Mdot
.46153 .5792 Mdot
.58737 .35439 Mdot
.36145 .56973 Mdot
.35353 .52126 Mdot
.71475 .47939 Mdot
.22865 .35722 Mdot
.43498 .55595 Mdot
.62143 .62164 Mdot
.66707 .46532 Mdot
.31222 .56705 Mdot
.72612 .52926 Mdot
.46493 .26091 Mdot
.53047 .76289 Mdot
.67009 .46088 Mdot
.5875 .67897 Mdot
.67 .46062 Mdot
.36424 .55609 Mdot
.33066 .6036 Mdot
.60734 .62146 Mdot
.46162 .30379 Mdot
.40883 .54349 Mdot
.36271 .54231 Mdot
.56305 .38573 Mdot
.74996 .65603 Mdot
.4797 .30059 Mdot
.37166 .52097 Mdot
.37338 .62027 Mdot
.46093 .30264 Mdot
.38451 .53163 Mdot
.41349 .53788 Mdot
.27275 .60961 Mdot
.66031 .45289 Mdot
.48424 .27796 Mdot
.29847 .23172 Mdot
.6308 .63636 Mdot
.63413 .53828 Mdot
.53755 .56378 Mdot
.7257 .48761 Mdot
.43796 .46379 Mdot
.52718 .55004 Mdot
.75824 .59794 Mdot
.65394 .81829 Mdot
.52312 .55512 Mdot
.61395 .34823 Mdot
.4691 .80589 Mdot
.41395 .5401 Mdot
.39473 .54347 Mdot
.44497 .25438 Mdot
.60551 .66567 Mdot
.68053 .72058 Mdot
.72826 .48253 Mdot
.37686 .57486 Mdot
.63652 .65513 Mdot
.74749 .53676 Mdot
.53278 .5512 Mdot
.4499 .25913 Mdot
.47562 .29248 Mdot
.39712 .54152 Mdot
.24565 .44901 Mdot
.61895 .6456 Mdot
.39225 .56528 Mdot
.35285 .54383 Mdot
.60577 .35749 Mdot
.59149 .66798 Mdot
.59961 .34558 Mdot
.54305 .54604 Mdot
.5046 .82197 Mdot
.78003 .44682 Mdot
.67368 .47717 Mdot
.48947 .55347 Mdot
.73603 .46647 Mdot
.6431 .37688 Mdot
.5163 .54935 Mdot
.39026 .56597 Mdot
.58365 .68279 Mdot
.3936 .56424 Mdot
.39676 .55912 Mdot
.38804 .54775 Mdot
.52558 .75566 Mdot
.44902 .33851 Mdot
.44088 .26303 Mdot
.35379 .53593 Mdot
.61117 .32955 Mdot
.7494 .52069 Mdot
.3661 .77028 Mdot
.37194 .56428 Mdot
.35423 .5448 Mdot
.56836 .6191 Mdot
.3173 .56266 Mdot
.68021 .47338 Mdot
.60179 .62029 Mdot
.35572 .51765 Mdot
.51226 .36003 Mdot
.40298 .54205 Mdot
.54192 .63503 Mdot
.69047 .44896 Mdot
.34439 .60189 Mdot
.33037 .50539 Mdot
.51552 .54816 Mdot
.52487 .55687 Mdot
.54823 .56915 Mdot
.67222 .45126 Mdot
.60892 .35176 Mdot
.53744 .3076 Mdot
.32067 .50592 Mdot
.37144 .52402 Mdot
.36908 .61578 Mdot
.60683 .29404 Mdot
.54104 .44508 Mdot
.56542 .77306 Mdot
.31364 .56403 Mdot
.59458 .30283 Mdot
.57787 .51745 Mdot
.38591 .65529 Mdot
.59118 .62458 Mdot
.60755 .37829 Mdot
.698 .48768 Mdot
.47105 .28134 Mdot
.29511 .33778 Mdot
.6281 .6449 Mdot
.56835 .66281 Mdot
.57958 .34181 Mdot
.32653 .40663 Mdot
.89282 .4881 Mdot
.57711 .32273 Mdot
.47677 .46283 Mdot
.60607 .64507 Mdot
.33156 .5165 Mdot
.27436 .41841 Mdot
.33094 .41595 Mdot
.5781 .29727 Mdot
.37166 .58439 Mdot
.51621 .17301 Mdot
.56864 .33614 Mdot
.36211 .6177 Mdot
.59981 .31623 Mdot
.65631 .48039 Mdot
.58506 .32793 Mdot
.63986 .65187 Mdot
.3879 .5811 Mdot
.88468 .50717 Mdot
.39091 .42083 Mdot
.38162 .57891 Mdot
.67279 .45451 Mdot
.6306 .41705 Mdot
.36683 .54991 Mdot
.43092 .26628 Mdot
.61298 .34854 Mdot
.64747 .2967 Mdot
.40499 .52574 Mdot
.56116 .32148 Mdot
.56307 .64614 Mdot
.61715 .3726 Mdot
.51165 .36594 Mdot
.51988 .55583 Mdot
.59769 .64158 Mdot
.63475 .44785 Mdot
.70428 .49724 Mdot
.37111 .51014 Mdot
.34427 .54936 Mdot
.59214 .63823 Mdot
.47735 .48153 Mdot
.44162 .53651 Mdot
.3962 .56329 Mdot
.59178 .34464 Mdot
.55524 .34389 Mdot
.37578 .43759 Mdot
.60179 .33201 Mdot
.38007 .61971 Mdot
.59893 .63448 Mdot
.40734 .52244 Mdot
.62837 .66225 Mdot
.40813 .56113 Mdot
.68924 .53503 Mdot
.58133 .63615 Mdot
.29673 .51727 Mdot
.37376 .5865 Mdot
.62814 .74214 Mdot
.34557 .5431 Mdot
.39742 .55205 Mdot
.56835 .35872 Mdot
.45559 .29057 Mdot
.43204 .52842 Mdot
.64061 .49787 Mdot
.47509 .2832 Mdot
.37207 .6677 Mdot
.57731 .35579 Mdot
.48094 .28119 Mdot
.292 .31475 Mdot
.51236 .54984 Mdot
.44663 .29298 Mdot
.4966 .54428 Mdot
.67224 .47931 Mdot
.60322 .69566 Mdot
.3534 .58236 Mdot
.49741 .82191 Mdot
.51263 .44239 Mdot
.53222 .54513 Mdot
.38747 .53515 Mdot
.35738 .56646 Mdot
.63633 .65589 Mdot
.76059 .30626 Mdot
.54483 .3296 Mdot
.31495 .53963 Mdot
.6301 .6469 Mdot
.77972 .33747 Mdot
.57146 .29494 Mdot
.46191 .253 Mdot
.72272 .48354 Mdot
.64152 .6263 Mdot
.52245 .53962 Mdot
.67459 .46558 Mdot
.53553 .29419 Mdot
.34473 .32785 Mdot
.41242 .52598 Mdot
.59457 .35281 Mdot
.33684 .33595 Mdot
.44968 .55357 Mdot
.71818 .44754 Mdot
.64309 .41059 Mdot
.58549 .65034 Mdot
.66811 .46871 Mdot
.43363 .26845 Mdot
.5873 .61635 Mdot
.60184 .62219 Mdot
.68276 .47819 Mdot
.64775 .76262 Mdot
.26342 .42956 Mdot
.71399 .45316 Mdot
.29109 .42996 Mdot
.33905 .33509 Mdot
.53116 .54241 Mdot
.44839 .26108 Mdot
.4142 .29848 Mdot
.62237 .64984 Mdot
.77535 .64076 Mdot
.33517 .33657 Mdot
.33678 .57949 Mdot
.46786 .28465 Mdot
.73172 .54082 Mdot
.68054 .41773 Mdot
.67658 .47019 Mdot
.58179 .3925 Mdot
.46791 .28917 Mdot
.38464 .58824 Mdot
.18319 .41674 Mdot
.34005 .56861 Mdot
.67839 .47945 Mdot
.44725 .46104 Mdot
.60222 .67309 Mdot
.66022 .46066 Mdot
.44867 .4611 Mdot
.36305 .52054 Mdot
.36108 .57619 Mdot
.46397 .34409 Mdot
.58208 .65526 Mdot
.53763 .54289 Mdot
.3883 .57844 Mdot
.35303 .54941 Mdot
.37519 .5075 Mdot
.20877 .4683 Mdot
.49366 .58651 Mdot
.3595 .50747 Mdot
.60368 .30447 Mdot
.32728 .60349 Mdot
.3134 .54339 Mdot
.57147 .60504 Mdot
.49283 .36026 Mdot
.54871 .55305 Mdot
.39019 .54096 Mdot
.39485 .54659 Mdot
.72034 .48388 Mdot
.26373 .4285 Mdot
.3328 .4115 Mdot
.55021 .29745 Mdot
.56852 .27221 Mdot
.40875 .57739 Mdot
.59214 .64661 Mdot
.48629 .26197 Mdot
.4229 .60995 Mdot
.62296 .62379 Mdot
.40854 .57336 Mdot
.61108 .35441 Mdot
.52047 .55226 Mdot
.40686 .618 Mdot
.46344 .28193 Mdot
.73597 .45562 Mdot
.386 .6613 Mdot
.57745 .34864 Mdot
.32602 .54387 Mdot
.54988 .27354 Mdot
.56659 .31423 Mdot
.53593 .54738 Mdot
.30952 .57868 Mdot
.60585 .63877 Mdot
.59131 .68057 Mdot
.42574 .35671 Mdot
.60715 .31989 Mdot
.62355 .38746 Mdot
.66165 .47996 Mdot
.35603 .53631 Mdot
.73575 .44608 Mdot
.59768 .67977 Mdot
.2567 .41183 Mdot
.4785 .28906 Mdot
.67763 .47391 Mdot
.49946 .54303 Mdot
.58424 .6284 Mdot
.59975 .68192 Mdot
.39425 .55515 Mdot
.38051 .5677 Mdot
.63953 .37354 Mdot
.31198 .3683 Mdot
.71673 .47701 Mdot
.46785 .25767 Mdot
.55139 .29832 Mdot
.39073 .5211 Mdot
.59224 .65884 Mdot
.1848 .48032 Mdot
.34895 .54194 Mdot
.61044 .32812 Mdot
.6112 .65759 Mdot
.44968 .25443 Mdot
.43469 .26969 Mdot
.39829 .57328 Mdot
.28867 .64246 Mdot
.69059 .47901 Mdot
.61076 .63402 Mdot
.65536 .67986 Mdot
.35399 .5336 Mdot
.37689 .5646 Mdot
.454 .5361 Mdot
.68978 .43997 Mdot
.37024 .4976 Mdot
.45327 .30182 Mdot
.61865 .67697 Mdot
.38896 .57608 Mdot
.46295 .29007 Mdot
.56643 .5593 Mdot
.52473 .54888 Mdot
.55924 .30688 Mdot
.42842 .26978 Mdot
.45248 .28393 Mdot
.47675 .27608 Mdot
.78203 .63351 Mdot
.54754 .54337 Mdot
.38171 .26485 Mdot
.37476 .58507 Mdot
.34004 .33469 Mdot
.4069 .51522 Mdot
.66009 .46914 Mdot
.55553 .31759 Mdot
.38277 .54988 Mdot
.3729 .58528 Mdot
.40367 .65278 Mdot
.40423 .51803 Mdot
.42658 .53299 Mdot
.60315 .67487 Mdot
.65526 .68671 Mdot
.56501 .33966 Mdot
.79316 .36877 Mdot
.15241 .50153 Mdot
.41901 .57432 Mdot
.32538 .40846 Mdot
.58673 .62893 Mdot
.7214 .4841 Mdot
.28753 .4248 Mdot
.72481 .43347 Mdot
.61824 .66584 Mdot
.39079 .51948 Mdot
.44019 .64133 Mdot
.47209 .28524 Mdot
.36844 .55437 Mdot
.70722 .47568 Mdot
.36943 .55338 Mdot
.66816 .45506 Mdot
.59331 .77045 Mdot
.34294 .40346 Mdot
.34563 .58025 Mdot
.42144 .54678 Mdot
.30606 .6333 Mdot
.37498 .56589 Mdot
.64921 .2672 Mdot
.60802 .65394 Mdot
.29239 .53379 Mdot
.37625 .51546 Mdot
.50548 .72098 Mdot
.37193 .535 Mdot
.44948 .4787 Mdot
.344 .5639 Mdot
.2437 .33689 Mdot
.36136 .58988 Mdot
.33922 .55736 Mdot
.70085 .45859 Mdot
.71549 .49091 Mdot
.65967 .70804 Mdot
.54644 .55335 Mdot
.74018 .53756 Mdot
.36121 .54204 Mdot
.54749 .31429 Mdot
.26945 .56321 Mdot
.45448 .28774 Mdot
.61987 .67481 Mdot
.75106 .77305 Mdot
.65146 .47668 Mdot
.61445 .33353 Mdot
.49816 .45254 Mdot
.6127 .31632 Mdot
.59682 .37811 Mdot
.6466 .62574 Mdot
.45067 .26086 Mdot
.404 .54511 Mdot
.49832 .70382 Mdot
.76248 .63859 Mdot
.35482 .53238 Mdot
.55953 .28025 Mdot
.26981 .58004 Mdot
.40778 .35103 Mdot
.43489 .25491 Mdot
.45005 .26876 Mdot
.68808 .46167 Mdot
.55174 .30363 Mdot
.30997 .55684 Mdot
.48112 .28156 Mdot
.56217 .3326 Mdot
.50128 .54691 Mdot
.47921 .3541 Mdot
.61864 .64367 Mdot
.58621 .77883 Mdot
.55312 .70605 Mdot
.66749 .49373 Mdot
.6402 .49418 Mdot
.59301 .69099 Mdot
.61124 .61506 Mdot
.54374 .55487 Mdot
.58968 .30187 Mdot
.60523 .69519 Mdot
.39337 .57617 Mdot
.35165 .61347 Mdot
.39881 .54269 Mdot
.45277 .25136 Mdot
.37963 .53428 Mdot
.56176 .32803 Mdot
.69811 .45505 Mdot
.5846 .31324 Mdot
.68145 .46167 Mdot
.18522 .54942 Mdot
.3834 .58695 Mdot
.38011 .56373 Mdot
.32146 .41375 Mdot
.60423 .68119 Mdot
.48653 .71205 Mdot
.60818 .3242 Mdot
.5921 .31355 Mdot
.38339 .51692 Mdot
.57708 .62427 Mdot
.4699 .30947 Mdot
.3025 .42698 Mdot
.34359 .56101 Mdot
.60662 .65486 Mdot
.38948 .51737 Mdot
.63415 .51414 Mdot
.37104 .42342 Mdot
.62114 .68039 Mdot
.33183 .20396 Mdot
.37097 .58773 Mdot
.30636 .56932 Mdot
.30919 .50809 Mdot
.21094 .4835 Mdot
.43986 .53806 Mdot
.62947 .63354 Mdot
.3138 .54451 Mdot
.59328 .65187 Mdot
.57132 .31536 Mdot
.65658 .46622 Mdot
.59743 .65148 Mdot
.35012 .57752 Mdot
.1537 .49917 Mdot
.70456 .45657 Mdot
.37394 .55454 Mdot
.7117 .47197 Mdot
.63542 .68713 Mdot
.60404 .67004 Mdot
.49873 .54764 Mdot
.47816 .46204 Mdot
.68313 .47677 Mdot
.36964 .52478 Mdot
.75005 .66641 Mdot
.41128 .52414 Mdot
.56516 .27399 Mdot
.4254 .5582 Mdot
.4119 .57114 Mdot
.26278 .26764 Mdot
.4689 .48208 Mdot
.78499 .44523 Mdot
.74816 .51139 Mdot
.74428 .67875 Mdot
.60145 .60457 Mdot
.43374 .25626 Mdot
.53614 .58709 Mdot
.51391 .5541 Mdot
.59836 .30006 Mdot
.38731 .55143 Mdot
.5743 .54563 Mdot
.7084 .44757 Mdot
.44426 .28884 Mdot
.34267 .57951 Mdot
.61671 .31277 Mdot
.48952 .55557 Mdot
.67575 .46719 Mdot
.62332 .64954 Mdot
.615 .67282 Mdot
.43852 .33638 Mdot
.38686 .57669 Mdot
.38522 .56737 Mdot
.71163 .46029 Mdot
.36754 .48879 Mdot
.47349 .26914 Mdot
.56689 .47501 Mdot
.70864 .47676 Mdot
.36999 .42168 Mdot
.58243 .65794 Mdot
.35914 .56801 Mdot
.32039 .41829 Mdot
.71011 .70677 Mdot
.38084 .7633 Mdot
.45547 .27258 Mdot
.24279 .46071 Mdot
.6297 .63449 Mdot
.70424 .46957 Mdot
.30359 .30455 Mdot
.42211 .58455 Mdot
.3536 .56282 Mdot
.23081 .46911 Mdot
.30036 .42791 Mdot
.49676 .45527 Mdot
.46939 .57051 Mdot
.2889 .40727 Mdot
.38585 .51715 Mdot
.34353 .52063 Mdot
.40615 .57911 Mdot
.42578 .55576 Mdot
.60046 .6573 Mdot
.50753 .73559 Mdot
.58008 .3361 Mdot
.3845 .75282 Mdot
.59308 .27828 Mdot
.33112 .56076 Mdot
.37317 .51913 Mdot
.40607 .73046 Mdot
.27259 .46355 Mdot
.61246 .64849 Mdot
.61357 .60915 Mdot
.68105 .49885 Mdot
.41033 .52145 Mdot
.60946 .3245 Mdot
.30802 .51123 Mdot
.5642 .30737 Mdot
.60235 .65765 Mdot
.59732 .36032 Mdot
.66434 .50019 Mdot
.59555 .35275 Mdot
.59735 .30261 Mdot
.68987 .45176 Mdot
.57931 .64691 Mdot
.33986 .54975 Mdot
.68812 .45159 Mdot
.47638 .3053 Mdot
.45018 .25209 Mdot
.6402 .70818 Mdot
.34338 .5105 Mdot
.43735 .56804 Mdot
.64736 .3902 Mdot
.60628 .34902 Mdot
.32577 .43771 Mdot
.58112 .64199 Mdot
.48233 .25819 Mdot
.59562 .65626 Mdot
.39385 .31938 Mdot
.45705 .27726 Mdot
.52067 .53634 Mdot
.26686 .3648 Mdot
.73971 .4774 Mdot
.39211 .59719 Mdot
.65443 .68764 Mdot
.56707 .30611 Mdot
.67054 .45483 Mdot
.74402 .52785 Mdot
.31721 .53477 Mdot
.58622 .69553 Mdot
.64481 .66947 Mdot
.51456 .55256 Mdot
.70484 .47199 Mdot
.57632 .72702 Mdot
.38003 .57797 Mdot
.73855 .47058 Mdot
.42439 .56018 Mdot
.54742 .77795 Mdot
.62863 .2933 Mdot
.57708 .52391 Mdot
.38574 .5182 Mdot
.57252 .29455 Mdot
.38593 .51773 Mdot
.50805 .80398 Mdot
.27097 .38409 Mdot
.40718 .57969 Mdot
.26285 .46576 Mdot
.64803 .37515 Mdot
.59094 .65737 Mdot
.43253 .60327 Mdot
.53228 .54389 Mdot
.33061 .53334 Mdot
.17655 .65059 Mdot
.45605 .29322 Mdot
.50255 .33235 Mdot
.35472 .58076 Mdot
.39447 .56813 Mdot
.3812 .66047 Mdot
.58974 .76884 Mdot
.50159 .55136 Mdot
.35394 .55777 Mdot
.22211 .48982 Mdot
.69678 .45876 Mdot
.41501 .53376 Mdot
.40145 .55197 Mdot
.6375 .36392 Mdot
.70297 .46202 Mdot
.58906 .35695 Mdot
.51271 .55105 Mdot
.55381 .33877 Mdot
.46738 .30391 Mdot
.25146 .46292 Mdot
.23459 .43363 Mdot
.37051 .42841 Mdot
.42819 .27335 Mdot
.32859 .5499 Mdot
.56666 .51893 Mdot
.36803 .58091 Mdot
.44569 .26993 Mdot
.71135 .47858 Mdot
.60466 .65316 Mdot
.56923 .78197 Mdot
.53674 .55096 Mdot
.34005 .53742 Mdot
.45498 .24658 Mdot
.5988 .64628 Mdot
.69379 .73888 Mdot
.60399 .6641 Mdot
.68107 .46685 Mdot
.71331 .44615 Mdot
.45749 .28294 Mdot
.59519 .65673 Mdot
.56007 .34856 Mdot
.70543 .43326 Mdot
.36258 .59822 Mdot
.66235 .49888 Mdot
.62868 .68472 Mdot
.63004 .67627 Mdot
.57192 .66071 Mdot
.36847 .51518 Mdot
.28906 .45076 Mdot
.47398 .56793 Mdot
.70886 .45859 Mdot
.60612 .30184 Mdot
.30355 .37118 Mdot
.49661 .65926 Mdot
.35394 .41678 Mdot
.42919 .60323 Mdot
.38148 .53441 Mdot
.39565 .54032 Mdot
.36948 .50523 Mdot
.5545 .48755 Mdot
.38611 .58585 Mdot
.71564 .47816 Mdot
.56658 .32362 Mdot
.3465 .56257 Mdot
.52286 .54311 Mdot
.53709 .44437 Mdot
.48487 .27993 Mdot
.53008 .76541 Mdot
.64563 .70706 Mdot
.59975 .64762 Mdot
.60467 .34087 Mdot
.58979 .36182 Mdot
.48207 .26443 Mdot
.67426 .46082 Mdot
.60696 .66656 Mdot
.24891 .32861 Mdot
.47408 .27945 Mdot
.38838 .54032 Mdot
.32096 .41463 Mdot
.21185 .50393 Mdot
.41055 .54197 Mdot
.38722 .54635 Mdot
.54861 .55432 Mdot
.61028 .32213 Mdot
.37112 .78185 Mdot
.66261 .74416 Mdot
.45873 .28842 Mdot
.47706 .26363 Mdot
.56824 .6487 Mdot
.36365 .53361 Mdot
.69402 .48004 Mdot
.25814 .43433 Mdot
.6306 .43035 Mdot
.73786 .54627 Mdot
.64248 .37941 Mdot
.40094 .53945 Mdot
.48917 .77909 Mdot
.41863 .58094 Mdot
.63665 .68829 Mdot
.5835 .67314 Mdot
.61376 .64466 Mdot
.69356 .45752 Mdot
.34757 .32604 Mdot
.7053 .49497 Mdot
.57785 .51493 Mdot
.62454 .63336 Mdot
.47989 .47284 Mdot
.59454 .31406 Mdot
.40649 .51632 Mdot
.44901 .26269 Mdot
.50544 .27599 Mdot
.42089 .60969 Mdot
.24557 .46143 Mdot
.58771 .35447 Mdot
.58162 .62743 Mdot
.40138 .51345 Mdot
.75221 .51798 Mdot
.32821 .39844 Mdot
.65951 .33064 Mdot
.57555 .53955 Mdot
.46506 .2881 Mdot
.33207 .73594 Mdot
.46998 .26827 Mdot
.67774 .47502 Mdot
.3778 .58689 Mdot
.3611 .53599 Mdot
.39797 .55181 Mdot
.43031 .55862 Mdot
.69501 .46199 Mdot
.37002 .59828 Mdot
.44068 .3677 Mdot
.51176 .55697 Mdot
.53691 .46517 Mdot
.43406 .27896 Mdot
.66087 .47673 Mdot
.56588 .31765 Mdot
.54422 .56174 Mdot
.47676 .25177 Mdot
.39313 .5089 Mdot
.35557 .5791 Mdot
.50798 .55505 Mdot
.44969 .58871 Mdot
.4422 .56023 Mdot
.57414 .33682 Mdot
.51779 .44941 Mdot
.48207 .28967 Mdot
.4608 .26836 Mdot
.66739 .47598 Mdot
.59489 .65605 Mdot
.48326 .2811 Mdot
.56778 .28563 Mdot
.41391 .53136 Mdot
.42386 .5624 Mdot
.63018 .68205 Mdot
.33859 .33324 Mdot
.48499 .27977 Mdot
.37536 .49739 Mdot
.61803 .67988 Mdot
.64553 .66698 Mdot
.35502 .55834 Mdot
.35419 .59295 Mdot
.57367 .60496 Mdot
.47593 .25943 Mdot
.66511 .47693 Mdot
.3747 .40632 Mdot
.65559 .48359 Mdot
.62303 .64436 Mdot
.34086 .61028 Mdot
.57777 .64048 Mdot
.31834 .53291 Mdot
.82727 .50336 Mdot
.38927 .58514 Mdot
.52294 .60844 Mdot
.52454 .42349 Mdot
.59672 .31349 Mdot
.5905 .30641 Mdot
.51889 .55008 Mdot
.61811 .62134 Mdot
.39307 .61938 Mdot
.45615 .25926 Mdot
.74469 .67776 Mdot
.56988 .60541 Mdot
.59529 .30182 Mdot
.6144 .34178 Mdot
.71097 .4742 Mdot
.37729 .53394 Mdot
.35925 .56938 Mdot
.59545 .35365 Mdot
.6211 .4722 Mdot
.58611 .6426 Mdot
.38542 .56701 Mdot
.36542 .50742 Mdot
.57712 .33416 Mdot
.69802 .50861 Mdot
.59919 .69324 Mdot
.36568 .51461 Mdot
.26663 .39271 Mdot
.66425 .45649 Mdot
.33846 .53086 Mdot
.3948 .59665 Mdot
.44887 .28551 Mdot
.23798 .46221 Mdot
.33361 .34003 Mdot
.65107 .48186 Mdot
.5143 .54545 Mdot
.4068 .53978 Mdot
.59049 .30955 Mdot
.4004 .50738 Mdot
.52123 .86159 Mdot
.50911 .5536 Mdot
.38089 .57615 Mdot
.32398 .50006 Mdot
.62876 .66195 Mdot
.39126 .56781 Mdot
.67952 .53439 Mdot
.59653 .34131 Mdot
.37882 .5767 Mdot
.312 .65168 Mdot
.71041 .47394 Mdot
.4306 .60419 Mdot
.46933 .28769 Mdot
.48669 .46191 Mdot
.19387 .57731 Mdot
.60894 .29588 Mdot
.43534 .28746 Mdot
.36825 .53688 Mdot
.54833 .3042 Mdot
.72075 .48926 Mdot
.48269 .55856 Mdot
.32994 .54091 Mdot
.67266 .49514 Mdot
.69166 .45421 Mdot
.4612 .28418 Mdot
.84338 .61821 Mdot
.40042 .58498 Mdot
.36861 .55925 Mdot
.78237 .68653 Mdot
.58085 .59758 Mdot
.37322 .55322 Mdot
.35192 .54388 Mdot
.67087 .47111 Mdot
.3515 .30531 Mdot
.24348 .46165 Mdot
.56579 .47814 Mdot
.66414 .45879 Mdot
.54288 .30023 Mdot
.59345 .34793 Mdot
.44007 .29255 Mdot
.61174 .65825 Mdot
.47788 .25542 Mdot
.58615 .33126 Mdot
.39342 .54811 Mdot
.67736 .48981 Mdot
.27259 .67236 Mdot
.68492 .44897 Mdot
.59981 .29296 Mdot
.63668 .68747 Mdot
.45549 .81625 Mdot
.5465 .86288 Mdot
.51958 .58122 Mdot
.71552 .44441 Mdot
.45412 .28781 Mdot
.6675 .74388 Mdot
.34542 .56184 Mdot
.5064 .79687 Mdot
.36812 .55611 Mdot
.57157 .55619 Mdot
.55653 .32195 Mdot
.5005 .54705 Mdot
.31809 .53275 Mdot
.24371 .46489 Mdot
.68405 .45435 Mdot
.69978 .48491 Mdot
.31408 .54482 Mdot
.68109 .47018 Mdot
.3686 .57304 Mdot
.5712 .32789 Mdot
.83947 .53609 Mdot
.34439 .56705 Mdot
.2957 .52997 Mdot
.74077 .46902 Mdot
.63196 .72196 Mdot
.54069 .29457 Mdot
.49582 .7557 Mdot
.75218 .53131 Mdot
.69378 .47865 Mdot
.52605 .75904 Mdot
.60721 .33681 Mdot
.54514 .56136 Mdot
.54487 .32032 Mdot
.36341 .56236 Mdot
.39876 .53658 Mdot
.37074 .50439 Mdot
.35709 .54195 Mdot
.46563 .79356 Mdot
.44366 .5611 Mdot
.35996 .69848 Mdot
.37545 .58485 Mdot
.52005 .59237 Mdot
.71099 .4899 Mdot
.3085 .57129 Mdot
.39955 .40259 Mdot
.40026 .57818 Mdot
.60871 .60708 Mdot
.6592 .48037 Mdot
.7868 .49348 Mdot
.69702 .46101 Mdot
.58364 .31199 Mdot
.68096 .45776 Mdot
.34011 .58077 Mdot
.62451 .66134 Mdot
.5958 .32812 Mdot
.48672 .55409 Mdot
.59501 .29561 Mdot
.38174 .57882 Mdot
.73954 .49253 Mdot
.61192 .33846 Mdot
.43351 .5753 Mdot
.62326 .66403 Mdot
.21704 .42438 Mdot
.60447 .69837 Mdot
.38896 .55972 Mdot
.38341 .55558 Mdot
.50599 .5545 Mdot
.67666 .46163 Mdot
.5772 .64703 Mdot
.62724 .40061 Mdot
.48086 .25573 Mdot
.61465 .65235 Mdot
.31009 .50617 Mdot
.32447 .40528 Mdot
.62687 .67228 Mdot
.217 .49694 Mdot
.67699 .47705 Mdot
.63253 .65158 Mdot
.33859 .4881 Mdot
.37929 .74844 Mdot
.46483 .26851 Mdot
.56427 .3545 Mdot
.30006 .40862 Mdot
.5948 .34661 Mdot
.7137 .53157 Mdot
.57596 .36611 Mdot
.70873 .46509 Mdot
.27017 .57171 Mdot
.4495 .46197 Mdot
.69358 .44512 Mdot
.74602 .48964 Mdot
.58492 .33976 Mdot
.34554 .51068 Mdot
.52707 .45778 Mdot
.38299 .6212 Mdot
.31704 .59978 Mdot
.65228 .47325 Mdot
.63249 .64516 Mdot
.58812 .61686 Mdot
.29064 .53125 Mdot
.60993 .67563 Mdot
.58169 .32156 Mdot
.37221 .43273 Mdot
.54045 .75447 Mdot
.70856 .48674 Mdot
.51196 .44594 Mdot
.37179 .51839 Mdot
.56085 .32347 Mdot
.5792 .31894 Mdot
.69006 .45508 Mdot
.42337 .76911 Mdot
.36897 .6195 Mdot
.61207 .60007 Mdot
.62775 .64132 Mdot
.62973 .66113 Mdot
.58882 .66842 Mdot
.34683 .32464 Mdot
.66987 .45584 Mdot
.62153 .62416 Mdot
.43157 .55331 Mdot
.36911 .53402 Mdot
.52902 .55995 Mdot
.45842 .25198 Mdot
.42684 .57893 Mdot
.39397 .61935 Mdot
.35529 .56021 Mdot
.60112 .31733 Mdot
.26522 .58691 Mdot
.51868 .56093 Mdot
.60917 .32234 Mdot
.60414 .31705 Mdot
.51509 .54804 Mdot
.26781 .57052 Mdot
.38487 .77988 Mdot
.31728 .55702 Mdot
.64372 .62283 Mdot
.58666 .30371 Mdot
.52996 .37663 Mdot
.52603 .60244 Mdot
.37242 .52627 Mdot
.55576 .46162 Mdot
.57159 .32278 Mdot
.59876 .60376 Mdot
.36901 .56469 Mdot
.543 .55282 Mdot
.4691 .27459 Mdot
.47751 .56292 Mdot
.54797 .55371 Mdot
.5885 .65302 Mdot
.6155 .38879 Mdot
.63645 .65671 Mdot
.59569 .36444 Mdot
.4103 .61426 Mdot
.88919 .49647 Mdot
.5687 .30669 Mdot
.75587 .66677 Mdot
.45555 .46399 Mdot
.35497 .57435 Mdot
.60142 .34261 Mdot
.56451 .63126 Mdot
.66582 .45368 Mdot
.30259 .44629 Mdot
.59461 .66041 Mdot
.54391 .56367 Mdot
.52847 .55696 Mdot
.57885 .33597 Mdot
.61652 .63203 Mdot
.38436 .59878 Mdot
.61653 .67143 Mdot
.68642 .49263 Mdot
.31884 .54365 Mdot
.74093 .53706 Mdot
.30896 .57829 Mdot
.61422 .67698 Mdot
.60331 .29814 Mdot
.46107 .30363 Mdot
.34253 .57378 Mdot
.78472 .49982 Mdot
.36813 .53649 Mdot
.71224 .47483 Mdot
.50744 .40972 Mdot
.28551 .67641 Mdot
.37513 .5421 Mdot
.36753 .51919 Mdot
.68149 .50522 Mdot
.37132 .5437 Mdot
.4195 .55344 Mdot
.57654 .72859 Mdot
.62474 .67539 Mdot
.34657 .56074 Mdot
.57994 .34806 Mdot
.3312 .67102 Mdot
.39892 .56806 Mdot
.66931 .5331 Mdot
.22454 .46445 Mdot
.4847 .39319 Mdot
.28106 .55354 Mdot
.25909 .40926 Mdot
.37839 .55649 Mdot
.3678 .52823 Mdot
.31513 .55144 Mdot
.49292 .7824 Mdot
.58836 .33555 Mdot
.56589 .295 Mdot
.44726 .29926 Mdot
.22864 .47194 Mdot
.46301 .27552 Mdot
.72227 .4883 Mdot
.49306 .45559 Mdot
.5256 .56532 Mdot
.59399 .65484 Mdot
.39868 .55718 Mdot
.58531 .29042 Mdot
.36241 .56837 Mdot
.33303 .53175 Mdot
.58079 .32448 Mdot
.5731 .31791 Mdot
.62639 .31713 Mdot
.47182 .28786 Mdot
.60737 .64715 Mdot
.36283 .58833 Mdot
.47485 .28432 Mdot
.37344 .50627 Mdot
.35931 .40018 Mdot
.61004 .64669 Mdot
.61204 .67785 Mdot
.59992 .61713 Mdot
.33765 .56275 Mdot
.31684 .54868 Mdot
.7027 .49615 Mdot
.63061 .68184 Mdot
.68684 .48036 Mdot
.6006 .34378 Mdot
.56741 .33386 Mdot
.36314 .56162 Mdot
.3687 .48946 Mdot
.43533 .27042 Mdot
.60986 .34333 Mdot
.5553 .56375 Mdot
.45765 .29892 Mdot
.40153 .54457 Mdot
.59765 .34596 Mdot
.43742 .25922 Mdot
.40997 .77073 Mdot
.68019 .56436 Mdot
.45374 .30076 Mdot
.31537 .53587 Mdot
.48211 .65889 Mdot
.27989 .37766 Mdot
.48679 .27667 Mdot
.7091 .4901 Mdot
.3445 .54668 Mdot
.57343 .49579 Mdot
.47918 .29115 Mdot
.32292 .34791 Mdot
.58721 .32686 Mdot
.31055 .58978 Mdot
.44516 .61847 Mdot
.5377 .75071 Mdot
.46369 .30345 Mdot
.61637 .67684 Mdot
.60665 .68742 Mdot
.38548 .5405 Mdot
.48823 .4593 Mdot
.71642 .46038 Mdot
.58787 .36161 Mdot
.56884 .29215 Mdot
.59501 .68587 Mdot
.37154 .42658 Mdot
.58334 .34891 Mdot
.35893 .53463 Mdot
.42196 .29687 Mdot
.42613 .53306 Mdot
.4065 .3398 Mdot
.27145 .65208 Mdot
.28073 .54778 Mdot
.45974 .30302 Mdot
.71704 .46409 Mdot
.701 .45706 Mdot
.68536 .45991 Mdot
.57738 .34235 Mdot
.28836 .42207 Mdot
.5612 .29445 Mdot
.75332 .71071 Mdot
.45701 .29393 Mdot
.27534 .27829 Mdot
.42734 .56915 Mdot
.35853 .57618 Mdot
.41642 .5299 Mdot
.35629 .5093 Mdot
.37871 .55767 Mdot
.67923 .49759 Mdot
.55195 .33116 Mdot
.63514 .41027 Mdot
.59851 .63139 Mdot
.69031 .74068 Mdot
.59638 .3155 Mdot
.54707 .55097 Mdot
.43948 .26664 Mdot
.22453 .44268 Mdot
.42715 .29334 Mdot
.60693 .35422 Mdot
.41302 .56134 Mdot
.56763 .64847 Mdot
.23878 .34528 Mdot
.39625 .56426 Mdot
.60816 .3477 Mdot
.54814 .29397 Mdot
.39809 .75803 Mdot
.46423 .56556 Mdot
.62699 .42831 Mdot
.32586 .42086 Mdot
.43103 .2916 Mdot
.34188 .51043 Mdot
.24969 .44214 Mdot
.58491 .3323 Mdot
.57206 .29966 Mdot
.48945 .26757 Mdot
.66034 .72088 Mdot
.61803 .6247 Mdot
.64013 .69639 Mdot
.67169 .49324 Mdot
.35922 .57894 Mdot
.58796 .34369 Mdot
.63232 .69592 Mdot
.37607 .37797 Mdot
.69 .4656 Mdot
.61417 .33492 Mdot
.36429 .53758 Mdot
.37465 .541 Mdot
.46375 .27825 Mdot
.52816 .43181 Mdot
.38307 .62114 Mdot
.74702 .67527 Mdot
.34054 .41416 Mdot
.45601 .46367 Mdot
.35349 .56305 Mdot
.5881 .66495 Mdot
.51599 .54858 Mdot
.44785 .26077 Mdot
.40618 .51152 Mdot
.49612 .81879 Mdot
.63696 .63733 Mdot
.68636 .47902 Mdot
.52736 .53999 Mdot
.2548 .4646 Mdot
.36294 .5386 Mdot
.36777 .55661 Mdot
.37087 .51547 Mdot
.42591 .80854 Mdot
.55617 .3167 Mdot
.59415 .67174 Mdot
.46704 .28896 Mdot
.60438 .66908 Mdot
.59851 .36639 Mdot
.51573 .4454 Mdot
.35272 .5873 Mdot
.63089 .62605 Mdot
.61317 .66622 Mdot
.71086 .47684 Mdot
.69068 .45094 Mdot
.57465 .28222 Mdot
.34608 .54891 Mdot
.52616 .56593 Mdot
.6272 .6309 Mdot
.56648 .35292 Mdot
.46202 .27747 Mdot
.71216 .5328 Mdot
.36993 .5852 Mdot
.58246 .33601 Mdot
.40966 .61506 Mdot
.59796 .63727 Mdot
.60842 .32979 Mdot
.54661 .56069 Mdot
.46835 .25522 Mdot
.40086 .53678 Mdot
.65614 .30997 Mdot
.54343 .55086 Mdot
.34241 .57125 Mdot
.29267 .6651 Mdot
.48941 .4591 Mdot
.55984 .56289 Mdot
.56689 .34009 Mdot
.54099 .55704 Mdot
.58983 .67578 Mdot
.35908 .73481 Mdot
.56558 .30118 Mdot
.448 .63679 Mdot
.43748 .45764 Mdot
.31493 .54095 Mdot
.59135 .65693 Mdot
.47182 .35137 Mdot
.72113 .68586 Mdot
.28873 .3758 Mdot
.37986 .57348 Mdot
.59426 .34661 Mdot
.46688 .27275 Mdot
.69827 .48527 Mdot
.66999 .44045 Mdot
.42775 .33139 Mdot
.59976 .30716 Mdot
.39917 .55726 Mdot
.6323 .64566 Mdot
.68334 .47582 Mdot
.37975 .66292 Mdot
.55329 .29728 Mdot
.58193 .3505 Mdot
.39964 .5257 Mdot
.46238 .27389 Mdot
.56197 .50095 Mdot
.55656 .31054 Mdot
.54988 .32417 Mdot
.5684 .72231 Mdot
.42967 .28819 Mdot
.35903 .5148 Mdot
.29079 .53044 Mdot
.423 .54628 Mdot
.7225 .72713 Mdot
.54083 .56044 Mdot
.59669 .63141 Mdot
.37957 .55036 Mdot
.64885 .37896 Mdot
.56316 .31206 Mdot
.32636 .42108 Mdot
.72103 .4967 Mdot
.68487 .45261 Mdot
.59647 .33899 Mdot
.37206 .56926 Mdot
.6408 .47612 Mdot
.44032 .29128 Mdot
.36053 .51394 Mdot
.31707 .53663 Mdot
.60746 .69063 Mdot
.67832 .4912 Mdot
.31878 .66771 Mdot
.69389 .48808 Mdot
.66868 .4698 Mdot
.56691 .67843 Mdot
.3861 .54025 Mdot
.60118 .3218 Mdot
.61973 .3225 Mdot
.35105 .5029 Mdot
.5341 .36875 Mdot
.60414 .62143 Mdot
.53731 .32461 Mdot
.48573 .82222 Mdot
.42139 .5696 Mdot
.52675 .53818 Mdot
.57772 .53071 Mdot
.71706 .44871 Mdot
.38014 .54377 Mdot
.59191 .65036 Mdot
.55176 .32078 Mdot
.58767 .34678 Mdot
.42357 .58331 Mdot
.69914 .45557 Mdot
.44385 .25386 Mdot
.58307 .31912 Mdot
.38034 .41063 Mdot
.38334 .57626 Mdot
.72428 .43149 Mdot
.58667 .3194 Mdot
.1586 .50293 Mdot
.65008 .38121 Mdot
.62931 .66695 Mdot
.37524 .52115 Mdot
.5886 .68595 Mdot
.436 .29201 Mdot
.55527 .34887 Mdot
.715 .47103 Mdot
.45566 .58478 Mdot
.79041 .37706 Mdot
.58048 .34193 Mdot
.60267 .65654 Mdot
.39109 .5492 Mdot
.52031 .7537 Mdot
.34412 .5634 Mdot
.35181 .301 Mdot
.48424 .28712 Mdot
.71382 .53007 Mdot
.71165 .46072 Mdot
.36482 .52027 Mdot
.4755 .27319 Mdot
.62091 .32022 Mdot
.58105 .32541 Mdot
.80553 .42903 Mdot
.54871 .55657 Mdot
.59159 .37682 Mdot
.34056 .56686 Mdot
.57813 .35817 Mdot
.49757 .65952 Mdot
.69205 .45334 Mdot
.42165 .54584 Mdot
.61459 .32338 Mdot
.69973 .70398 Mdot
.32483 .41406 Mdot
.38275 .57489 Mdot
.35002 .49081 Mdot
.70881 .46741 Mdot
.66674 .74479 Mdot
.5566 .32545 Mdot
.38771 .50664 Mdot
.72331 .4902 Mdot
.27214 .56438 Mdot
.61761 .42158 Mdot
.60763 .64679 Mdot
.61769 .33483 Mdot
.66546 .48015 Mdot
.31152 .58873 Mdot
.44473 .25634 Mdot
.56374 .28579 Mdot
.6063 .3053 Mdot
.32327 .55422 Mdot
.37617 .51032 Mdot
.34907 .48968 Mdot
.58453 .63584 Mdot
.67144 .47545 Mdot
.33584 .52687 Mdot
.35372 .396 Mdot
.34792 .51376 Mdot
.67067 .47943 Mdot
.86617 .55557 Mdot
.41312 .55675 Mdot
.36821 .58424 Mdot
.51474 .76434 Mdot
.57656 .63415 Mdot
.61025 .68433 Mdot
.34628 .40973 Mdot
.33716 .54678 Mdot
.47739 .47535 Mdot
.60478 .64916 Mdot
.60354 .65987 Mdot
.47818 .47459 Mdot
.32118 .55503 Mdot
.61713 .70229 Mdot
.68204 .47391 Mdot
.68582 .45216 Mdot
.62855 .66265 Mdot
.4154 .52458 Mdot
.72229 .48425 Mdot
.43883 .76364 Mdot
.61033 .34903 Mdot
.2482 .44757 Mdot
.61528 .66859 Mdot
.31867 .41229 Mdot
.67693 .47489 Mdot
.18738 .52839 Mdot
.20907 .48726 Mdot
.41255 .57892 Mdot
.38224 .54114 Mdot
.4502 .28344 Mdot
.45129 .58909 Mdot
.51427 .55036 Mdot
.68426 .45967 Mdot
.55379 .48676 Mdot
.61468 .64479 Mdot
.33763 .5494 Mdot
.3078 .36979 Mdot
.20242 .58497 Mdot
.33145 .47796 Mdot
.6102 .65919 Mdot
.62146 .65073 Mdot
.58107 .35285 Mdot
.6033 .35993 Mdot
.36049 .58878 Mdot
.70525 .4606 Mdot
.63194 .65872 Mdot
.67485 .48487 Mdot
.58491 .33101 Mdot
.5945 .31578 Mdot
.52001 .56043 Mdot
.32321 .60512 Mdot
.59437 .3339 Mdot
.6552 .52406 Mdot
.35451 .3967 Mdot
.62778 .68651 Mdot
.77205 .69687 Mdot
.18773 .51125 Mdot
.55409 .78059 Mdot
.46819 .27349 Mdot
.26857 .56681 Mdot
.70866 .49642 Mdot
.36132 .5203 Mdot
.36511 .55319 Mdot
.53233 .55094 Mdot
.712 .49608 Mdot
.44048 .28201 Mdot
.68852 .45271 Mdot
.45571 .25636 Mdot
.57279 .29364 Mdot
.39891 .56332 Mdot
.40144 .57479 Mdot
.70122 .48351 Mdot
.59165 .35706 Mdot
.61191 .33624 Mdot
.46255 .264 Mdot
.22327 .44654 Mdot
.57961 .33484 Mdot
.61361 .66843 Mdot
.42505 .65615 Mdot
.52965 .55646 Mdot
.3701 .56487 Mdot
.25506 .41257 Mdot
.34794 .72541 Mdot
.36756 .50368 Mdot
.53023 .54129 Mdot
.84594 .61358 Mdot
.39612 .57467 Mdot
.77732 .33366 Mdot
.52691 .56509 Mdot
.5776 .63991 Mdot
.60392 .3298 Mdot
.54565 .55084 Mdot
.27103 .59874 Mdot
.62153 .28308 Mdot
.35935 .50163 Mdot
.61794 .62401 Mdot
.59149 .6209 Mdot
.51613 .44728 Mdot
.72006 .72994 Mdot
.46779 .28793 Mdot
.44305 .28967 Mdot
.56167 .30842 Mdot
.73314 .52686 Mdot
.43512 .5506 Mdot
.44773 .29111 Mdot
.62239 .70894 Mdot
.3804 .51823 Mdot
.49345 .45803 Mdot
.53222 .46147 Mdot
.59394 .67885 Mdot
.32102 .58468 Mdot
.56239 .30953 Mdot
.60428 .65539 Mdot
.52186 .45344 Mdot
.41046 .53083 Mdot
.61191 .64582 Mdot
.67216 .46644 Mdot
.46603 .51542 Mdot
.61379 .67295 Mdot
.31057 .44272 Mdot
.69883 .47936 Mdot
.49987 .45303 Mdot
.30354 .28272 Mdot
.15354 .57105 Mdot
.69675 .45673 Mdot
.60742 .34437 Mdot
.58773 .34259 Mdot
.57447 .33222 Mdot
.58472 .64989 Mdot
.56983 .31366 Mdot
.60511 .62615 Mdot
.71319 .44098 Mdot
.236 .46774 Mdot
.45671 .28022 Mdot
.49432 .35264 Mdot
.62609 .66535 Mdot
.74397 .71623 Mdot
.67106 .81413 Mdot
.35464 .51185 Mdot
.6912 .44467 Mdot
.47036 .29483 Mdot
.33953 .4281 Mdot
.44851 .28459 Mdot
.60696 .33748 Mdot
.24881 .46477 Mdot
.3664 .57286 Mdot
.66744 .5511 Mdot
.46583 .27236 Mdot
.60309 .66128 Mdot
.32978 .55701 Mdot
.6172 .34954 Mdot
.43678 .29092 Mdot
.45834 .26567 Mdot
.37709 .55882 Mdot
.58071 .62816 Mdot
.6102 .33542 Mdot
.6721 .49669 Mdot
.41674 .28828 Mdot
.43431 .51669 Mdot
.40014 .57028 Mdot
.4035 .5794 Mdot
.32878 .40993 Mdot
.73427 .52762 Mdot
.69776 .47734 Mdot
.32543 .34849 Mdot
.56198 .32606 Mdot
.28871 .37325 Mdot
.73779 .67059 Mdot
.47516 .34784 Mdot
.53993 .56027 Mdot
.54037 .56262 Mdot
.38912 .56619 Mdot
.58437 .84142 Mdot
.47688 .54719 Mdot
.72722 .48104 Mdot
.52788 .55162 Mdot
.60886 .35485 Mdot
.63478 .67248 Mdot
.45401 .60886 Mdot
.42783 .57456 Mdot
.67407 .49765 Mdot
.57919 .32923 Mdot
.51309 .86461 Mdot
.46098 .29169 Mdot
.344 .42815 Mdot
.34897 .54711 Mdot
.38324 .56542 Mdot
.69542 .46813 Mdot
.71557 .47406 Mdot
.56638 .72145 Mdot
.47342 .3858 Mdot
.74595 .53694 Mdot
.64808 .47924 Mdot
.51027 .8659 Mdot
.57576 .54329 Mdot
.61806 .63858 Mdot
.51141 .5456 Mdot
.71455 .45922 Mdot
.37537 .5519 Mdot
.57763 .63235 Mdot
.4844 .55718 Mdot
.57328 .62127 Mdot
.48549 .46193 Mdot
.37461 .40677 Mdot
.38012 .53468 Mdot
.57269 .65851 Mdot
.60753 .65199 Mdot
.64571 .63339 Mdot
.51989 .55425 Mdot
.3527 .55969 Mdot
.38594 .50479 Mdot
.38498 .5845 Mdot
.53693 .68304 Mdot
.3912 .56876 Mdot
.7342 .67543 Mdot
.35708 .41353 Mdot
.55118 .18078 Mdot
.39054 .57888 Mdot
.67094 .46318 Mdot
.39611 .55624 Mdot
.47546 .2702 Mdot
.40883 .54379 Mdot
.47776 .46382 Mdot
.68637 .47366 Mdot
.50675 .80663 Mdot
.5807 .27593 Mdot
.40368 .56713 Mdot
.42891 .27099 Mdot
.80481 .60484 Mdot
.32514 .35216 Mdot
.56882 .72139 Mdot
.61675 .67106 Mdot
.54798 .3109 Mdot
.71329 .4541 Mdot
.58562 .31211 Mdot
.37067 .59927 Mdot
.51117 .55276 Mdot
.2614 .27654 Mdot
.32274 .38763 Mdot
.37819 .55114 Mdot
.36087 .61872 Mdot
.60381 .67767 Mdot
.56452 .30987 Mdot
.59197 .77112 Mdot
.4115 .52571 Mdot
.47568 .25711 Mdot
.47749 .28737 Mdot
.52167 .28254 Mdot
.54457 .63992 Mdot
.51441 .66326 Mdot
.69507 .4699 Mdot
.57991 .34436 Mdot
.47371 .29543 Mdot
.65054 .69561 Mdot
.70843 .45251 Mdot
.71867 .44977 Mdot
.67611 .491 Mdot
.37484 .58035 Mdot
.527 .56259 Mdot
.55934 .68196 Mdot
.54632 .55593 Mdot
.42591 .54429 Mdot
.60718 .30658 Mdot
.54508 .5595 Mdot
.45169 .27666 Mdot
.6659 .47419 Mdot
.59861 .31597 Mdot
.38695 .55673 Mdot
.60155 .64646 Mdot
.41579 .35693 Mdot
.65743 .36029 Mdot
.48985 .45824 Mdot
.48995 .45817 Mdot
.64539 .64767 Mdot
.57489 .51179 Mdot
.74744 .47859 Mdot
.38641 .75454 Mdot
.4145 .29377 Mdot
.43319 .52792 Mdot
.54185 .36871 Mdot
.5594 .29545 Mdot
.59381 .32631 Mdot
.36389 .57456 Mdot
.56774 .35014 Mdot
.33926 .55367 Mdot
.56685 .34075 Mdot
.72041 .69997 Mdot
.41192 .58876 Mdot
.58457 .32255 Mdot
.4637 .57851 Mdot
.34342 .57425 Mdot
.59358 .66906 Mdot
.55096 .30826 Mdot
.41311 .57854 Mdot
.40886 .15589 Mdot
.70986 .47793 Mdot
.52158 .55546 Mdot
.4246 .43477 Mdot
.67677 .46872 Mdot
.61641 .62705 Mdot
.34877 .54103 Mdot
.45456 .29543 Mdot
.62228 .64374 Mdot
.54263 .27794 Mdot
.46098 .27034 Mdot
.37738 .43209 Mdot
.62687 .65031 Mdot
.53249 .55799 Mdot
.47741 .26101 Mdot
.35431 .50332 Mdot
.59083 .32579 Mdot
.65556 .37003 Mdot
.53538 .54224 Mdot
.36258 .57069 Mdot
.61496 .35073 Mdot
.6826 .45559 Mdot
.40101 .54901 Mdot
.58811 .34477 Mdot
.5183 .54257 Mdot
.3547 .58199 Mdot
.33327 .55515 Mdot
.64626 .74391 Mdot
.51795 .41616 Mdot
.45455 .27862 Mdot
.63603 .68767 Mdot
.43003 .55542 Mdot
.47323 .2709 Mdot
.64201 .37826 Mdot
.31019 .56805 Mdot
.62967 .63049 Mdot
.42903 .76265 Mdot
.58632 .36065 Mdot
.70215 .45496 Mdot
.60323 .29582 Mdot
.4386 .29579 Mdot
.72139 .78786 Mdot
.51412 .55225 Mdot
.31533 .56327 Mdot
.42069 .55806 Mdot
.54662 .33194 Mdot
.61039 .65103 Mdot
.74188 .54168 Mdot
.39933 .53486 Mdot
.36444 .6151 Mdot
.37314 .562 Mdot
.64785 .29728 Mdot
.58278 .64286 Mdot
.37081 .56329 Mdot
.38939 .49605 Mdot
.42341 .56094 Mdot
.43288 .26902 Mdot
.27163 .28394 Mdot
.33462 .51775 Mdot
.899 .46697 Mdot
.50304 .54484 Mdot
.57645 .32441 Mdot
.31367 .44173 Mdot
.42717 .43061 Mdot
.47961 .16937 Mdot
.61055 .62408 Mdot
.64719 .62885 Mdot
.59425 .31655 Mdot
.44842 .3419 Mdot
.56658 .51001 Mdot
.33085 .55281 Mdot
.35171 .54304 Mdot
.60696 .33735 Mdot
.56574 .35301 Mdot
.50542 .54735 Mdot
.31164 .54012 Mdot
.31331 .5819 Mdot
.60322 .2989 Mdot
.39465 .56784 Mdot
.33355 .71427 Mdot
.68136 .44349 Mdot
.62655 .671 Mdot
.69933 .48627 Mdot
.67009 .44958 Mdot
.56951 .78152 Mdot
.33839 .41171 Mdot
.67376 .49463 Mdot
.73681 .47137 Mdot
.47438 .35396 Mdot
.53575 .75437 Mdot
.43491 .2651 Mdot
.47954 .54352 Mdot
.56753 .32964 Mdot
.35315 .55789 Mdot
.58258 .64538 Mdot
.38009 .27294 Mdot
.764 .54025 Mdot
.24467 .57439 Mdot
.35931 .51549 Mdot
.56374 .32022 Mdot
.53266 .54049 Mdot
.30888 .56621 Mdot
.28248 .37614 Mdot
.38398 .57019 Mdot
.59203 .36275 Mdot
.53966 .75397 Mdot
.63477 .43273 Mdot
.64803 .4551 Mdot
.57738 .59552 Mdot
.39671 .55588 Mdot
.58739 .6392 Mdot
.65481 .47572 Mdot
.47328 .2776 Mdot
.45575 .28798 Mdot
.40445 .5663 Mdot
.45576 .46426 Mdot
.42173 .30457 Mdot
.33153 .55716 Mdot
.32155 .55249 Mdot
.53955 .55662 Mdot
.32052 .55026 Mdot
.38466 .50268 Mdot
.34154 .52354 Mdot
.37337 .50728 Mdot
.71009 .45468 Mdot
.5683 .77022 Mdot
.31191 .55003 Mdot
.3576 .59314 Mdot
.65773 .46533 Mdot
.36086 .59607 Mdot
.6957 .46002 Mdot
.76416 .5083 Mdot
.68741 .49734 Mdot
.45718 .28669 Mdot
.61374 .35663 Mdot
.62678 .74304 Mdot
.63185 .6571 Mdot
.67692 .45311 Mdot
.46108 .25305 Mdot
.6893 .45715 Mdot
.56994 .33911 Mdot
.62963 .45639 Mdot
.55694 .60147 Mdot
.38534 .41527 Mdot
.53285 .76385 Mdot
.71291 .42126 Mdot
.57544 .35416 Mdot
.63031 .65937 Mdot
.68682 .53488 Mdot
.35985 .5212 Mdot
.46388 .29149 Mdot
.3886 .56551 Mdot
.66697 .47192 Mdot
.56614 .32611 Mdot
.60245 .73706 Mdot
.45366 .27925 Mdot
.79582 .67546 Mdot
.58568 .29016 Mdot
.41756 .55337 Mdot
.65612 .46716 Mdot
.64487 .50773 Mdot
.71292 .47219 Mdot
.23374 .46391 Mdot
.57709 .52145 Mdot
.39136 .30053 Mdot
.62385 .6517 Mdot
.55399 .56897 Mdot
.19564 .64963 Mdot
.77737 .59433 Mdot
.59837 .64112 Mdot
.62335 .38041 Mdot
.38786 .57624 Mdot
.34652 .51754 Mdot
.33869 .61186 Mdot
.57571 .62499 Mdot
.37167 .5156 Mdot
.52252 .55798 Mdot
.34007 .40231 Mdot
.55315 .59828 Mdot
.55407 .2895 Mdot
.34074 .5567 Mdot
.65213 .47405 Mdot
.67893 .45048 Mdot
.54219 .5679 Mdot
.68903 .49056 Mdot
.33934 .57796 Mdot
.62637 .6607 Mdot
.52625 .45684 Mdot
.43989 .29463 Mdot
.76365 .6495 Mdot
.46584 .31252 Mdot
.42012 .28077 Mdot
.42201 .56987 Mdot
.59759 .31805 Mdot
.77756 .35032 Mdot
.36238 .51843 Mdot
.60392 .65171 Mdot
.42009 .55256 Mdot
.33855 .52292 Mdot
.3347 .57779 Mdot
.57956 .34388 Mdot
.32312 .4126 Mdot
.39518 .56726 Mdot
.65918 .4865 Mdot
.47495 .47351 Mdot
.42847 .57539 Mdot
.56613 .47232 Mdot
.48081 .46341 Mdot
.70823 .42427 Mdot
.61755 .68963 Mdot
.60168 .32369 Mdot
.61706 .64502 Mdot
.572 .61396 Mdot
.61616 .62718 Mdot
.55212 .65733 Mdot
.37612 .74814 Mdot
.77255 .32355 Mdot
.50162 .66086 Mdot
.53358 .76746 Mdot
.56922 .6103 Mdot
.68485 .28001 Mdot
.59431 .64392 Mdot
.61458 .62599 Mdot
.83845 .51329 Mdot
.59203 .62386 Mdot
.36233 .56194 Mdot
.40324 .57676 Mdot
.44992 .81411 Mdot
.42167 .25496 Mdot
.34633 .57297 Mdot
.37115 .50572 Mdot
.47622 .2914 Mdot
.65825 .72129 Mdot
.51336 .53969 Mdot
.34791 .43062 Mdot
.55228 .56103 Mdot
.37805 .55867 Mdot
.39208 .53687 Mdot
.44703 .5542 Mdot
.21061 .61182 Mdot
.40772 .31389 Mdot
.59304 .61901 Mdot
.40803 .50746 Mdot
.68831 .41216 Mdot
.37488 .52822 Mdot
.41461 .54101 Mdot
.32936 .57282 Mdot
.60111 .32166 Mdot
.63915 .65556 Mdot
.3891 .62042 Mdot
.78126 .6202 Mdot
.36561 .5385 Mdot
.47793 .30642 Mdot
.46503 .24468 Mdot
.37045 .56891 Mdot
.59991 .61973 Mdot
.35113 .51601 Mdot
.62418 .68065 Mdot
.62556 .64513 Mdot
.33403 .60539 Mdot
.574 .69827 Mdot
.63533 .67013 Mdot
.33114 .55188 Mdot
.58777 .35694 Mdot
.75036 .67228 Mdot
.36448 .57072 Mdot
.4536 .27234 Mdot
.38456 .54411 Mdot
.43088 .27137 Mdot
.32295 .52919 Mdot
.54413 .55619 Mdot
.27868 .67738 Mdot
.57155 .29867 Mdot
.42733 .29611 Mdot
.57296 .35484 Mdot
.43508 .54345 Mdot
.57355 .677 Mdot
.63438 .44041 Mdot
.42832 .32487 Mdot
.53908 .55733 Mdot
.34524 .33115 Mdot
.4868 .48032 Mdot
.70833 .4947 Mdot
.59385 .67254 Mdot
.55996 .75978 Mdot
.56282 .46979 Mdot
.5547 .28748 Mdot
.61353 .34553 Mdot
.61411 .4167 Mdot
.83941 .53574 Mdot
.3883 .57903 Mdot
.57531 .49234 Mdot
.35328 .6969 Mdot
.44972 .59051 Mdot
.46982 .57309 Mdot
.60531 .3038 Mdot
.34561 .57262 Mdot
.3125 .39415 Mdot
.58606 .33935 Mdot
.43579 .27753 Mdot
.59513 .63172 Mdot
.46799 .26182 Mdot
.70461 .57277 Mdot
.57495 .72844 Mdot
.5915 .33533 Mdot
.37009 .50907 Mdot
.35007 .5729 Mdot
.57636 .64123 Mdot
.38021 .66232 Mdot
.62411 .67606 Mdot
.45308 .29828 Mdot
.56241 .30187 Mdot
.34343 .19644 Mdot
.39168 .54784 Mdot
.61124 .66537 Mdot
.58371 .27664 Mdot
.37128 .54181 Mdot
.69778 .4543 Mdot
.3748 .51622 Mdot
.60548 .66724 Mdot
.32013 .54856 Mdot
.6242 .6502 Mdot
.58869 .35329 Mdot
.40397 .57008 Mdot
.40046 .54415 Mdot
.32929 .34393 Mdot
.44076 .28124 Mdot
.63184 .67404 Mdot
.30839 .40281 Mdot
.42302 .5463 Mdot
.26958 .38975 Mdot
.39885 .56581 Mdot
.52858 .75719 Mdot
.31283 .50669 Mdot
.52552 .55951 Mdot
.42071 .55294 Mdot
.36686 .5715 Mdot
.38107 .66063 Mdot
.49331 .65862 Mdot
.53919 .68629 Mdot
.69334 .45048 Mdot
.58932 .65947 Mdot
.59111 .34151 Mdot
.54986 .31193 Mdot
.57443 .3125 Mdot
.4816 .29657 Mdot
.35606 .50019 Mdot
.35585 .56859 Mdot
.7316 .47445 Mdot
.45293 .2927 Mdot
.61422 .66062 Mdot
.46093 .28361 Mdot
.33634 .41635 Mdot
.4506 .27117 Mdot
.51326 .54894 Mdot
.64582 .39009 Mdot
.34283 .72028 Mdot
.44448 .26545 Mdot
.62809 .66763 Mdot
.46497 .4752 Mdot
.44711 .59096 Mdot
.70255 .73626 Mdot
.48027 .26106 Mdot
.63328 .37894 Mdot
.35748 .58465 Mdot
.30197 .44319 Mdot
.69384 .46159 Mdot
.46793 .26106 Mdot
.67887 .49236 Mdot
.35129 .51648 Mdot
.61541 .59647 Mdot
.59781 .65723 Mdot
.6773 .44453 Mdot
.41732 .5409 Mdot
.46861 .26155 Mdot
.59215 .33164 Mdot
.53538 .75299 Mdot
.70239 .4394 Mdot
.42917 .36054 Mdot
.28952 .37467 Mdot
.5596 .31189 Mdot
.51224 .73591 Mdot
.68592 .49605 Mdot
.41063 .50941 Mdot
.45016 .51758 Mdot
.42551 .53548 Mdot
.61194 .3346 Mdot
.59444 .32604 Mdot
.75248 .44436 Mdot
.39938 .54105 Mdot
.31522 .55929 Mdot
.63413 .68496 Mdot
.55948 .30697 Mdot
.61778 .62849 Mdot
.57687 .67042 Mdot
.60627 .34504 Mdot
.62238 .67941 Mdot
.46109 .26906 Mdot
.27269 .42657 Mdot
.68426 .49609 Mdot
.70981 .46008 Mdot
.59376 .33513 Mdot
.58706 .29973 Mdot
.59696 .31713 Mdot
.40612 .52545 Mdot
.62518 .63981 Mdot
.368 .52259 Mdot
.39523 .55344 Mdot
.52514 .53623 Mdot
.6042 .69536 Mdot
.38529 .52432 Mdot
.53389 .46605 Mdot
.48337 .26232 Mdot
.57946 .32118 Mdot
.67497 .48112 Mdot
.40768 .35028 Mdot
.66527 .49318 Mdot
.42563 .55585 Mdot
.70304 .71077 Mdot
.58852 .65527 Mdot
.44904 .28399 Mdot
.47902 .46254 Mdot
.45199 .28133 Mdot
.68004 .44379 Mdot
.64693 .65968 Mdot
.37375 .42947 Mdot
.40306 .54551 Mdot
.32982 .40812 Mdot
.30714 .30168 Mdot
.7421 .66145 Mdot
.67163 .47282 Mdot
.35356 .51379 Mdot
.53525 .56467 Mdot
.38896 .75718 Mdot
.35855 .57084 Mdot
.41395 .58381 Mdot
.44912 .44656 Mdot
.41983 .56532 Mdot
.61347 .6157 Mdot
.49869 .45902 Mdot
.34823 .50873 Mdot
.42427 .52956 Mdot
.80279 .44861 Mdot
.35252 .57937 Mdot
.40474 .55177 Mdot
.35927 .55544 Mdot
.37629 .5189 Mdot
.58951 .68643 Mdot
.50953 .44358 Mdot
.65589 .47314 Mdot
.27245 .42643 Mdot
.67202 .49116 Mdot
.60018 .3377 Mdot
.45653 .37769 Mdot
.6126 .68719 Mdot
.45151 .28092 Mdot
.585 .49158 Mdot
.25054 .46904 Mdot
.58235 .35364 Mdot
.34728 .32107 Mdot
.44617 .25379 Mdot
.43756 .60111 Mdot
.43667 .29513 Mdot
.61367 .31806 Mdot
.69788 .45556 Mdot
.41336 .56036 Mdot
.62598 .6309 Mdot
.61368 .67374 Mdot
.43212 .54793 Mdot
.78121 .63335 Mdot
.70253 .45407 Mdot
.52706 .36517 Mdot
.37093 .57872 Mdot
.42155 .54551 Mdot
.61487 .68378 Mdot
.56405 .31313 Mdot
.48753 .47856 Mdot
.44376 .26065 Mdot
.37247 .53121 Mdot
.36017 .50777 Mdot
.33558 .41504 Mdot
.68734 .44933 Mdot
.52303 .54814 Mdot
.34783 .56508 Mdot
.34749 .42123 Mdot
.37997 .51612 Mdot
.43859 .54107 Mdot
.5928 .35986 Mdot
.34947 .6116 Mdot
.39144 .53316 Mdot
.57187 .59582 Mdot
.6894 .49594 Mdot
.60895 .64841 Mdot
.62492 .61216 Mdot
.5428 .55689 Mdot
.70855 .47818 Mdot
.39266 .52515 Mdot
.70695 .44542 Mdot
.34268 .51987 Mdot
.39135 .55845 Mdot
.67166 .47025 Mdot
.615 .62959 Mdot
.73274 .5406 Mdot
.56864 .76932 Mdot
.33391 .53047 Mdot
.37993 .54315 Mdot
.42185 .25481 Mdot
.38924 .25337 Mdot
.40081 .53913 Mdot
.6306 .66232 Mdot
.37546 .5406 Mdot
.71663 .48174 Mdot
.46867 .28631 Mdot
.60009 .65015 Mdot
.55874 .3212 Mdot
.58836 .35219 Mdot
.61239 .29409 Mdot
.51258 .5489 Mdot
.31681 .5603 Mdot
.63576 .68784 Mdot
.60314 .69609 Mdot
.28724 .43189 Mdot
.57732 .32386 Mdot
.46948 .27936 Mdot
.33872 .56548 Mdot
.45207 .59097 Mdot
.6658 .4553 Mdot
.90036 .45472 Mdot
.36989 .4284 Mdot
.47786 .25272 Mdot
.47706 .39237 Mdot
.53608 .5505 Mdot
.36129 .58184 Mdot
.473 .26729 Mdot
.60188 .34718 Mdot
.34703 .51709 Mdot
.31715 .50512 Mdot
.64093 .37572 Mdot
.59327 .30714 Mdot
.70369 .44313 Mdot
.56211 .33319 Mdot
.43941 .25797 Mdot
.51442 .551 Mdot
.59727 .66894 Mdot
.3767 .57084 Mdot
.30814 .57287 Mdot
.57113 .3285 Mdot
.51271 .55951 Mdot
.39788 .57808 Mdot
.58688 .65851 Mdot
.57172 .31721 Mdot
.37367 .55667 Mdot
.40123 .75753 Mdot
.6287 .74219 Mdot
.56501 .32769 Mdot
.35547 .53656 Mdot
.43515 .62439 Mdot
.59694 .31023 Mdot
.61332 .31924 Mdot
.3568 .51173 Mdot
.47062 .25991 Mdot
.38094 .53346 Mdot
.70525 .46214 Mdot
.32256 .40786 Mdot
.7038 .48217 Mdot
.28046 .37627 Mdot
.38919 .50957 Mdot
.39873 .4817 Mdot
.56757 .63263 Mdot
.43448 .30581 Mdot
.19301 .49685 Mdot
.42552 .56442 Mdot
.66803 .70224 Mdot
.31922 .41121 Mdot
.39666 .4255 Mdot
.67042 .67347 Mdot
.4502 .25709 Mdot
.68589 .45956 Mdot
.40436 .56156 Mdot
.72565 .53667 Mdot
.45294 .25861 Mdot
.27898 .37773 Mdot
.35259 .53157 Mdot
.60689 .65882 Mdot
.37668 .57859 Mdot
.59801 .66729 Mdot
.36158 .54711 Mdot
.64938 .7436 Mdot
.41959 .30205 Mdot
.23357 .46442 Mdot
.43857 .60007 Mdot
.64441 .50678 Mdot
.53301 .76444 Mdot
.46458 .27552 Mdot
.32377 .54164 Mdot
.53146 .54521 Mdot
.68811 .45277 Mdot
.62059 .4972 Mdot
.59305 .31551 Mdot
.66019 .48689 Mdot
.6125 .63337 Mdot
.62169 .33832 Mdot
.52805 .56685 Mdot
.27809 .52584 Mdot
.47024 .26213 Mdot
.70957 .47719 Mdot
.36987 .571 Mdot
.42512 .53703 Mdot
.64836 .29763 Mdot
.26282 .28869 Mdot
.58088 .68007 Mdot
.82065 .64831 Mdot
.64641 .66644 Mdot
.44154 .28658 Mdot
.59793 .35905 Mdot
.37396 .55081 Mdot
.34627 .55198 Mdot
.59072 .30612 Mdot
.57721 .64623 Mdot
.42165 .28354 Mdot
.38993 .29274 Mdot
.7256 .48233 Mdot
.27059 .30358 Mdot
.59715 .65164 Mdot
.27166 .30224 Mdot
.50075 .327 Mdot
.61523 .72695 Mdot
.21269 .46119 Mdot
.67918 .47091 Mdot
.27006 .30336 Mdot
.60728 .66199 Mdot
.38048 .58292 Mdot
.53281 .5563 Mdot
.51132 .55575 Mdot
.58977 .63906 Mdot
.60747 .33419 Mdot
.4482 .2543 Mdot
.37507 .57755 Mdot
.2851 .53025 Mdot
.37991 .66301 Mdot
.57144 .29449 Mdot
.37817 .61864 Mdot
.68086 .47891 Mdot
.37413 .5421 Mdot
.47296 .29464 Mdot
.6808 .47053 Mdot
.54846 .55968 Mdot
.2509 .46335 Mdot
.34922 .54074 Mdot
.46872 .46589 Mdot
.69637 .46406 Mdot
.38681 .25439 Mdot
.39861 .54219 Mdot
.68579 .496 Mdot
.30939 .57517 Mdot
.69931 .41075 Mdot
.51353 .4677 Mdot
.77652 .59448 Mdot
.59483 .28905 Mdot
.56715 .34069 Mdot
.40445 .16352 Mdot
.48817 .17853 Mdot
.66166 .47892 Mdot
.52656 .53894 Mdot
.26974 .28224 Mdot
.68785 .4941 Mdot
.40017 .53343 Mdot
.39658 .57218 Mdot
.54013 .75407 Mdot
.45809 .58187 Mdot
.50482 .54471 Mdot
.52647 .59748 Mdot
.33341 .57197 Mdot
.38826 .61872 Mdot
.40137 .55259 Mdot
.5888 .62141 Mdot
.68183 .47681 Mdot
.30937 .77896 Mdot
.70383 .4471 Mdot
.38908 .48025 Mdot
.56725 .32916 Mdot
.61165 .30064 Mdot
.37195 .5685 Mdot
.49861 .58233 Mdot
.51839 .86831 Mdot
.39936 .57003 Mdot
.4784 .46279 Mdot
.29171 .37262 Mdot
.37104 .49808 Mdot
.63585 .64238 Mdot
.30958 .57794 Mdot
.62077 .69735 Mdot
.67993 .46667 Mdot
.45086 .25725 Mdot
.43881 .30996 Mdot
.68797 .46006 Mdot
.34717 .55344 Mdot
.45533 .31167 Mdot
.38032 .56442 Mdot
.36003 .57887 Mdot
.34273 .42245 Mdot
.46548 .29849 Mdot
.60443 .32359 Mdot
.45525 .28634 Mdot
.60678 .62259 Mdot
.86087 .57443 Mdot
.46401 .28047 Mdot
.53605 .75442 Mdot
.31292 .40348 Mdot
.27727 .2823 Mdot
.61106 .67545 Mdot
.43865 .29435 Mdot
.68075 .45941 Mdot
.39097 .44 Mdot
.507 .7675 Mdot
.66669 .4938 Mdot
.3524 .56791 Mdot
.58741 .68535 Mdot
.64613 .65728 Mdot
.65996 .49242 Mdot
.59645 .6713 Mdot
.33761 .50086 Mdot
.33244 .54451 Mdot
.65546 .47732 Mdot
.19597 .57962 Mdot
.71093 .45942 Mdot
.58118 .77862 Mdot
.31849 .55603 Mdot
.60236 .65085 Mdot
.52613 .75979 Mdot
.62302 .60797 Mdot
.51695 .55821 Mdot
.40988 .54791 Mdot
.46716 .28077 Mdot
.28843 .42187 Mdot
.5619 .32197 Mdot
.70126 .70313 Mdot
.6167 .66968 Mdot
.66303 .49735 Mdot
.59592 .6701 Mdot
.59773 .677 Mdot
.66933 .44847 Mdot
.58932 .65415 Mdot
.36326 .53955 Mdot
.65984 .7459 Mdot
.61214 .67913 Mdot
.69165 .47024 Mdot
.4498 .29677 Mdot
.6295 .66654 Mdot
.52048 .36824 Mdot
.3398 .56363 Mdot
.55529 .2948 Mdot
.41782 .23526 Mdot
.57555 .66429 Mdot
.46583 .2756 Mdot
.57167 .32493 Mdot
.46597 .25242 Mdot
.74833 .51104 Mdot
.67762 .53164 Mdot
.27504 .61387 Mdot
.68042 .40646 Mdot
.59603 .62266 Mdot
.62379 .33024 Mdot
.35797 .53802 Mdot
.36778 .57925 Mdot
.48249 .29108 Mdot
.62996 .62375 Mdot
.79171 .62031 Mdot
.48508 .55535 Mdot
.7648 .64772 Mdot
.69249 .44996 Mdot
.50966 .35755 Mdot
.37599 .42831 Mdot
.67336 .42825 Mdot
.34075 .51114 Mdot
.53537 .55046 Mdot
.37216 .56196 Mdot
.32417 .35296 Mdot
.44044 .25784 Mdot
.68477 .30581 Mdot
.41354 .52388 Mdot
.58616 .30432 Mdot
.36348 .54864 Mdot
.56249 .4943 Mdot
.41842 .52313 Mdot
.48492 .26667 Mdot
.7229 .49067 Mdot
.63187 .65763 Mdot
.43207 .28534 Mdot
.59135 .35283 Mdot
.21791 .49546 Mdot
.39179 .52991 Mdot
.34094 .57777 Mdot
.60684 .31957 Mdot
.62085 .62829 Mdot
.59899 .33239 Mdot
.68271 .49576 Mdot
.46132 .28022 Mdot
.38941 .51988 Mdot
.38429 .61803 Mdot
.54777 .3354 Mdot
.66938 .45629 Mdot
.61118 .35465 Mdot
.70364 .44431 Mdot
.5362 .55584 Mdot
.42268 .52367 Mdot
.60864 .36154 Mdot
.3358 .51448 Mdot
.49706 .70376 Mdot
.25639 .46468 Mdot
.40058 .65143 Mdot
.60968 .33167 Mdot
.48897 .16986 Mdot
.68446 .46961 Mdot
.71033 .48244 Mdot
.58822 .77926 Mdot
.57432 .84723 Mdot
.47779 .47531 Mdot
.80762 .58972 Mdot
.68299 .49593 Mdot
.701 .46657 Mdot
.60164 .33015 Mdot
.60572 .62463 Mdot
.56937 .63136 Mdot
.61559 .34654 Mdot
.25135 .41767 Mdot
.61405 .66087 Mdot
.47427 .82087 Mdot
.56578 .29237 Mdot
.3434 .58679 Mdot
.61555 .73943 Mdot
.48329 .26447 Mdot
.30239 .3733 Mdot
.62783 .45788 Mdot
.36698 .55621 Mdot
.78138 .34105 Mdot
.59154 .31627 Mdot
.49022 .55522 Mdot
.70498 .50952 Mdot
.4143 .53117 Mdot
.35823 .55244 Mdot
.37162 .53838 Mdot
.4891 .26741 Mdot
.4716 .66557 Mdot
.37006 .55374 Mdot
.24234 .46561 Mdot
.39752 .59645 Mdot
.65759 .3244 Mdot
.45567 .28626 Mdot
.35041 .30474 Mdot
.60854 .37392 Mdot
.78656 .6111 Mdot
.41776 .5787 Mdot
.70928 .48968 Mdot
.54734 .47502 Mdot
.66981 .47176 Mdot
.72402 .43281 Mdot
.2469 .33263 Mdot
.61535 .61786 Mdot
.41112 .52372 Mdot
.58181 .2931 Mdot
.56725 .64044 Mdot
.54229 .47051 Mdot
.8592 .58554 Mdot
.67463 .50293 Mdot
.74783 .77496 Mdot
.70115 .48889 Mdot
.50489 .54869 Mdot
.60864 .63317 Mdot
.47811 .60824 Mdot
.33183 .40897 Mdot
.61697 .62855 Mdot
.55828 .20544 Mdot
.61954 .69885 Mdot
.22257 .40686 Mdot
.55808 .60258 Mdot
.69211 .47485 Mdot
.66035 .49362 Mdot
.31118 .51239 Mdot
.38143 .53231 Mdot
.33078 .3977 Mdot
.4678 .57278 Mdot
.3451 .54322 Mdot
.58581 .33959 Mdot
.6779 .40524 Mdot
.73242 .53234 Mdot
.59027 .64997 Mdot
.6653 .45967 Mdot
.36127 .55052 Mdot
.33267 .53144 Mdot
.41164 .57076 Mdot
.44653 .34239 Mdot
.46414 .82064 Mdot
.39404 .55989 Mdot
.43472 .53826 Mdot
.58717 .35524 Mdot
.64766 .29406 Mdot
.83361 .57127 Mdot
.257 .31644 Mdot
.38219 .58764 Mdot
.44439 .28617 Mdot
.46952 .29986 Mdot
.33787 .49596 Mdot
.48666 .5998 Mdot
.49723 .2631 Mdot
.36923 .57097 Mdot
.22784 .48438 Mdot
.54588 .30888 Mdot
.54019 .56733 Mdot
.57169 .32861 Mdot
.56842 .62046 Mdot
.53726 .56364 Mdot
.59292 .3457 Mdot
.2433 .4506 Mdot
.5424 .55061 Mdot
.72234 .41905 Mdot
.44258 .29631 Mdot
.40057 .54817 Mdot
.56795 .74975 Mdot
.55878 .30768 Mdot
.70645 .46864 Mdot
.60919 .63874 Mdot
.69543 .45144 Mdot
.65249 .37426 Mdot
.26381 .401 Mdot
.51773 .55591 Mdot
.71028 .48885 Mdot
.46603 .46727 Mdot
.44801 .28846 Mdot
.69209 .49139 Mdot
.44035 .50449 Mdot
.42686 .57869 Mdot
.48723 .85099 Mdot
.34 .57402 Mdot
.75289 .44726 Mdot
.71188 .476 Mdot
.54636 .56382 Mdot
.3791 .57071 Mdot
.57885 .28827 Mdot
.28026 .55765 Mdot
.38129 .56329 Mdot
.55679 .31968 Mdot
.39369 .57292 Mdot
.47476 .28411 Mdot
.6483 .66541 Mdot
.31642 .41438 Mdot
.44303 .36579 Mdot
.43968 .26031 Mdot
.27204 .4614 Mdot
.40231 .5402 Mdot
.51899 .19135 Mdot
.60922 .65693 Mdot
.42547 .55725 Mdot
.28177 .3593 Mdot
.59448 .62881 Mdot
.61889 .64645 Mdot
.32489 .55683 Mdot
.7188 .47122 Mdot
.6063 .32335 Mdot
.45073 .28846 Mdot
.6872 .43552 Mdot
.37378 .55509 Mdot
.35454 .51385 Mdot
.43653 .26371 Mdot
.70749 .47349 Mdot
.39085 .52126 Mdot
.71013 .63096 Mdot
.26912 .43411 Mdot
.68253 .44396 Mdot
.42918 .57462 Mdot
.50557 .82258 Mdot
.58605 .66701 Mdot
.77957 .33744 Mdot
.41837 .30035 Mdot
.60442 .35179 Mdot
.35634 .61556 Mdot
.8944 .4825 Mdot
.45144 .29798 Mdot
.75971 .64532 Mdot
.38424 .58071 Mdot
.37941 .54792 Mdot
.59252 .62149 Mdot
.37278 .52326 Mdot
.58862 .65762 Mdot
.49307 .35932 Mdot
.59819 .83733 Mdot
.6058 .67457 Mdot
.60093 .6656 Mdot
.46437 .54654 Mdot
.45378 .31936 Mdot
.59626 .6327 Mdot
.38729 .52963 Mdot
.55489 .18821 Mdot
.40539 .49627 Mdot
.4242 .26946 Mdot
.47584 .24458 Mdot
.63595 .64918 Mdot
.50822 .77528 Mdot
.4543 .53151 Mdot
.47007 .80557 Mdot
.49144 .25425 Mdot
.66333 .48341 Mdot
.33272 .52294 Mdot
.52168 .53929 Mdot
.57732 .31835 Mdot
.31241 .58453 Mdot
.39767 .5425 Mdot
.62744 .62895 Mdot
.47282 .25115 Mdot
.6844 .49254 Mdot
.32175 .52492 Mdot
.54277 .30194 Mdot
.43946 .26513 Mdot
.61277 .68212 Mdot
.54935 .77857 Mdot
.46073 .31067 Mdot
.36479 .61935 Mdot
.37431 .58506 Mdot
.31429 .55108 Mdot
.44271 .59863 Mdot
.68829 .4612 Mdot
.61918 .33416 Mdot
.3619 .61857 Mdot
.35269 .43634 Mdot
.26583 .42549 Mdot
.40204 .58192 Mdot
.63021 .66428 Mdot
.67916 .45363 Mdot
.51685 .5492 Mdot
.27489 .27921 Mdot
.35869 .58652 Mdot
.47475 .82147 Mdot
.4045 .33284 Mdot
.53416 .54408 Mdot
.56647 .64887 Mdot
.45081 .28444 Mdot
.31967 .55306 Mdot
.23979 .46417 Mdot
.34775 .53952 Mdot
.40458 .50484 Mdot
.60917 .34166 Mdot
.67078 .48582 Mdot
.27299 .60879 Mdot
.58168 .31993 Mdot
.6177 .64549 Mdot
.42867 .80122 Mdot
.57071 .64571 Mdot
.57678 .67102 Mdot
.58824 .70908 Mdot
.70888 .46192 Mdot
.89628 .47707 Mdot
.39473 .24749 Mdot
.4073 .57042 Mdot
.69304 .49871 Mdot
.59748 .63614 Mdot
.39036 .52673 Mdot
.58847 .65583 Mdot
.63832 .65078 Mdot
.33512 .55771 Mdot
.3349 .55121 Mdot
.23383 .46804 Mdot
.50114 .81587 Mdot
.46413 .2909 Mdot
.57748 .64185 Mdot
.50416 .80244 Mdot
.37631 .55112 Mdot
.3892 .53462 Mdot
.55001 .4766 Mdot
.4296 .2822 Mdot
.31325 .71701 Mdot
.37363 .58056 Mdot
.33015 .33985 Mdot
.40142 .53603 Mdot
.58077 .60264 Mdot
.64838 .4594 Mdot
.41266 .48723 Mdot
.60961 .35392 Mdot
.57654 .64487 Mdot
.47844 .2551 Mdot
.56299 .64186 Mdot
.35457 .73083 Mdot
.68824 .45598 Mdot
.60529 .66712 Mdot
.62097 .33108 Mdot
.70362 .47536 Mdot
.71179 .46097 Mdot
.54025 .468 Mdot
.61632 .31246 Mdot
.47073 .24941 Mdot
.68216 .48396 Mdot
.4081 .75959 Mdot
.6952 .47574 Mdot
.34832 .7345 Mdot
.3639 .59035 Mdot
.24275 .46418 Mdot
.30865 .58331 Mdot
.31811 .50274 Mdot
.6939 .4847 Mdot
.43939 .26287 Mdot
.39599 .52352 Mdot
.60176 .67748 Mdot
.44842 .29403 Mdot
.573 .72449 Mdot
.62077 .31709 Mdot
.64076 .67814 Mdot
.7182 .45075 Mdot
.58264 .63218 Mdot
.29443 .37412 Mdot
.46184 .24143 Mdot
.55584 .46132 Mdot
.32815 .42221 Mdot
.41065 .61462 Mdot
.42816 .53472 Mdot
.40191 .52596 Mdot
.3588 .54248 Mdot
.56707 .33028 Mdot
.48966 .27785 Mdot
.6272 .67317 Mdot
.2908 .64906 Mdot
.70991 .46877 Mdot
.49094 .4633 Mdot
.44092 .59945 Mdot
.3455 .51865 Mdot
.59866 .63818 Mdot
.6381 .66165 Mdot
.48802 .65812 Mdot
.5927 .30942 Mdot
.36668 .48877 Mdot
.41902 .57171 Mdot
.26694 .59476 Mdot
.69742 .48422 Mdot
.75935 .60229 Mdot
.5484 .30416 Mdot
.7565 .76996 Mdot
.58194 .32165 Mdot
.52527 .42869 Mdot
.58564 .64894 Mdot
.45517 .26984 Mdot
.34437 .56108 Mdot
.53222 .62029 Mdot
.58038 .68248 Mdot
.6215 .28015 Mdot
.45072 .27816 Mdot
.7733 .49235 Mdot
.67861 .49646 Mdot
.3231 .52309 Mdot
.40119 .53544 Mdot
.34989 .52572 Mdot
.36997 .52825 Mdot
.65975 .47557 Mdot
.33962 .54093 Mdot
.69889 .43936 Mdot
.34936 .72535 Mdot
.27716 .36106 Mdot
.60624 .30797 Mdot
.655 .28268 Mdot
.57977 .67443 Mdot
.35228 .75755 Mdot
.32667 .71759 Mdot
.25638 .46326 Mdot
.73702 .44991 Mdot
.36618 .50223 Mdot
.60498 .32977 Mdot
.70705 .53703 Mdot
.60343 .30482 Mdot
.36314 .8144 Mdot
.54191 .75585 Mdot
.77297 .47492 Mdot
.35312 .52718 Mdot
.61477 .33498 Mdot
.51002 .78359 Mdot
.32672 .60741 Mdot
.45452 .31124 Mdot
.37151 .74292 Mdot
.54748 .69853 Mdot
.46741 .29011 Mdot
.34572 .57088 Mdot
.60238 .69496 Mdot
.34445 .55731 Mdot
.34402 .56397 Mdot
.39361 .57988 Mdot
.65787 .46014 Mdot
.37266 .59144 Mdot
.3731 .53494 Mdot
.29443 .23476 Mdot
.53924 .27515 Mdot
.56531 .33969 Mdot
.44174 .63369 Mdot
.45311 .29278 Mdot
.56842 .61986 Mdot
.32033 .41729 Mdot
.71472 .47609 Mdot
.48496 .65773 Mdot
.32693 .55017 Mdot
.72933 .6801 Mdot
.71496 .45846 Mdot
.46759 .25697 Mdot
.52434 .54014 Mdot
.77784 .53241 Mdot
.58517 .36145 Mdot
.50937 .5429 Mdot
.56062 .31507 Mdot
.25818 .61671 Mdot
.59414 .66298 Mdot
.41028 .61468 Mdot
.6822 .4902 Mdot
.60267 .30188 Mdot
.24277 .47071 Mdot
.38278 .53866 Mdot
.61042 .33317 Mdot
.32823 .60491 Mdot
.29089 .41813 Mdot
.3208 .41089 Mdot
.61568 .31986 Mdot
.7243 .4816 Mdot
.70137 .48081 Mdot
.46198 .29668 Mdot
.58921 .66904 Mdot
.62213 .62737 Mdot
.69605 .47916 Mdot
.80099 .42768 Mdot
.37199 .55627 Mdot
.39255 .5538 Mdot
.36389 .43233 Mdot
.40875 .53611 Mdot
.42608 .25086 Mdot
.50171 .54403 Mdot
.62925 .63751 Mdot
.3996 .52519 Mdot
.38914 .52092 Mdot
.36077 .58465 Mdot
.24416 .42283 Mdot
.5684 .3254 Mdot
.33153 .57065 Mdot
.4712 .26433 Mdot
.56393 .7181 Mdot
.36189 .53662 Mdot
.36116 .61946 Mdot
.58505 .65272 Mdot
.61955 .41884 Mdot
.70586 .46702 Mdot
.57583 .29551 Mdot
.58011 .29381 Mdot
.29674 .31072 Mdot
.57366 .636 Mdot
.50582 .54344 Mdot
.64374 .37432 Mdot
.51442 .5475 Mdot
.44951 .27543 Mdot
.50583 .47165 Mdot
.62428 .36419 Mdot
.56403 .33723 Mdot
.6452 .47839 Mdot
.42582 .54533 Mdot
.36781 .53405 Mdot
.78414 .6223 Mdot
.40025 .56285 Mdot
.46774 .28417 Mdot
.71249 .49303 Mdot
.60411 .66491 Mdot
.47686 .28494 Mdot
.70669 .48785 Mdot
.61999 .62931 Mdot
.38514 .59896 Mdot
.39537 .53053 Mdot
.61437 .64057 Mdot
.60759 .68241 Mdot
.36157 .56445 Mdot
.2298 .35606 Mdot
.63238 .64746 Mdot
.60975 .63646 Mdot
.55855 .71221 Mdot
.58101 .35872 Mdot
.27988 .56015 Mdot
.71531 .48299 Mdot
.37377 .53556 Mdot
.60575 .30983 Mdot
.44364 .27041 Mdot
.62448 .66552 Mdot
.33427 .52037 Mdot
.38093 .55536 Mdot
.44521 .2859 Mdot
.44393 .30056 Mdot
.43498 .28792 Mdot
.65917 .49104 Mdot
.33099 .55138 Mdot
.60202 .63154 Mdot
.66494 .4914 Mdot
.48026 .28987 Mdot
.42849 .28618 Mdot
.20782 .43731 Mdot
.36571 .55876 Mdot
.46164 .30525 Mdot
.86508 .55901 Mdot
.22076 .4691 Mdot
.53012 .56651 Mdot
.58038 .27922 Mdot
.49281 .16612 Mdot
.41876 .23234 Mdot
.66681 .48142 Mdot
.4902 .46052 Mdot
.44098 .25392 Mdot
.31668 .53507 Mdot
.39114 .54461 Mdot
.431 .60202 Mdot
.44543 .29224 Mdot
.26382 .39956 Mdot
.61087 .61685 Mdot
.37799 .68478 Mdot
.45357 .29276 Mdot
.61029 .30668 Mdot
.54426 .32609 Mdot
.59088 .32442 Mdot
.41346 .51733 Mdot
.25406 .61762 Mdot
.40048 .74172 Mdot
.30825 .70972 Mdot
.6863 .49761 Mdot
.63871 .65731 Mdot
.5956 .73713 Mdot
.62 .64775 Mdot
.57229 .31071 Mdot
.44158 .26136 Mdot
.59946 .61865 Mdot
.70787 .45798 Mdot
.69846 .48238 Mdot
.60018 .36414 Mdot
.57486 .32653 Mdot
.59171 .33357 Mdot
.57975 .65501 Mdot
.58707 .65144 Mdot
.36844 .52063 Mdot
.61953 .67486 Mdot
.43175 .33058 Mdot
.47268 .3517 Mdot
.57263 .36273 Mdot
.68896 .46532 Mdot
.62567 .647 Mdot
.40229 .55007 Mdot
.45931 .43717 Mdot
.59776 .37912 Mdot
.48283 .26737 Mdot
.6715 .74518 Mdot
.56356 .85745 Mdot
.399 .51882 Mdot
.66642 .46307 Mdot
.48313 .55881 Mdot
.35943 .54414 Mdot
.60836 .34991 Mdot
.3888 .31221 Mdot
.54415 .54996 Mdot
.34465 .54767 Mdot
.38847 .59657 Mdot
.6896 .45365 Mdot
.32097 .42013 Mdot
.32048 .52781 Mdot
.52251 .4517 Mdot
.7222 .48888 Mdot
.54856 .31121 Mdot
.43676 .15231 Mdot
.53453 .5986 Mdot
.34556 .34849 Mdot
.54116 .56296 Mdot
.36238 .58808 Mdot
.58262 .33996 Mdot
.4783 .27119 Mdot
.58219 .33468 Mdot
.56972 .6115 Mdot
.58641 .36072 Mdot
.4019 .56504 Mdot
.59972 .63033 Mdot
.70897 .47689 Mdot
.419 .43067 Mdot
.31168 .64701 Mdot
.57196 .28783 Mdot
.51009 .55837 Mdot
.33549 .55161 Mdot
.40394 .7623 Mdot
.31625 .50402 Mdot
.38934 .53272 Mdot
.67112 .47145 Mdot
.59255 .64466 Mdot
.68876 .45036 Mdot
.28089 .55322 Mdot
.6395 .60551 Mdot
.70402 .46331 Mdot
.44008 .49881 Mdot
.44415 .25504 Mdot
.25759 .40911 Mdot
.37542 .57455 Mdot
.67964 .49027 Mdot
.33631 .56569 Mdot
.57768 .63493 Mdot
.25318 .44164 Mdot
.26629 .44366 Mdot
.67886 .47604 Mdot
.57663 .51037 Mdot
.30695 .40469 Mdot
.28005 .56126 Mdot
.67544 .49311 Mdot
.2006 .51503 Mdot
.52706 .54464 Mdot
.4413 .26481 Mdot
.43494 .29674 Mdot
.45901 .26301 Mdot
.39475 .55209 Mdot
.52349 .8046 Mdot
.4597 .2992 Mdot
.70486 .50285 Mdot
.47306 .27774 Mdot
.42346 .35728 Mdot
.78427 .63052 Mdot
.4432 .25648 Mdot
.38494 .57263 Mdot
.33969 .47935 Mdot
.48429 .46227 Mdot
.59151 .28885 Mdot
.74533 .54484 Mdot
.30488 .22558 Mdot
.37288 .55086 Mdot
.64925 .74479 Mdot
.61549 .60162 Mdot
.51951 .41733 Mdot
.26218 .45234 Mdot
.43347 .45673 Mdot
.61951 .63971 Mdot
.32464 .42092 Mdot
.60346 .68811 Mdot
.40889 .61633 Mdot
.39218 .55948 Mdot
.57606 .64282 Mdot
.6964 .7061 Mdot
.18929 .5062 Mdot
.75441 .66171 Mdot
.62556 .63949 Mdot
.68979 .49591 Mdot
.66855 .46711 Mdot
.67161 .47413 Mdot
.57363 .33989 Mdot
.6042 .66907 Mdot
.3376 .57802 Mdot
.59647 .35416 Mdot
.35416 .57305 Mdot
.68617 .47812 Mdot
.25784 .45617 Mdot
.60103 .66477 Mdot
.36861 .57163 Mdot
.50644 .79299 Mdot
.56204 .30988 Mdot
.44618 .28861 Mdot
.66631 .74501 Mdot
.61669 .30025 Mdot
.71632 .45723 Mdot
.57046 .60689 Mdot
.55306 .27251 Mdot
.50838 .44219 Mdot
.39876 .58264 Mdot
.41269 .55916 Mdot
.49021 .45755 Mdot
.54767 .76354 Mdot
.34187 .51307 Mdot
.58983 .3525 Mdot
.57201 .3514 Mdot
.34089 .57087 Mdot
.60683 .6717 Mdot
.44026 .25171 Mdot
.47161 .306 Mdot
.43582 .53123 Mdot
.32747 .40899 Mdot
.24278 .4655 Mdot
.39005 .52404 Mdot
.41693 .6033 Mdot
.62094 .3287 Mdot
.5329 .56753 Mdot
.33411 .41543 Mdot
.46226 .26938 Mdot
.37626 .58267 Mdot
.40049 .65535 Mdot
.617 .66817 Mdot
.60947 .32979 Mdot
.6533 .47046 Mdot
.45869 .31114 Mdot
.57228 .36118 Mdot
.34105 .57101 Mdot
.39008 .52118 Mdot
.68826 .49105 Mdot
.57954 .6039 Mdot
.4355 .27858 Mdot
.59473 .35491 Mdot
.45827 .27015 Mdot
.59189 .65684 Mdot
.62735 .66307 Mdot
.41221 .57334 Mdot
.3363 .49194 Mdot
.56743 .29028 Mdot
.39589 .50358 Mdot
.60194 .34213 Mdot
.64856 .29763 Mdot
.66546 .45562 Mdot
.42451 .55858 Mdot
.57323 .62174 Mdot
.68984 .47958 Mdot
.36835 .55072 Mdot
.49688 .454 Mdot
.37609 .51698 Mdot
.61592 .33244 Mdot
.38197 .28807 Mdot
.4491 .26307 Mdot
.32893 .58788 Mdot
.52305 .66509 Mdot
.40419 .53206 Mdot
.55302 .31756 Mdot
.39762 .74979 Mdot
.69793 .45967 Mdot
.58501 .6395 Mdot
.62291 .38586 Mdot
.69323 .47201 Mdot
.38617 .57574 Mdot
.4641 .28143 Mdot
.62379 .67962 Mdot
.5303 .56286 Mdot
.34576 .39431 Mdot
.29807 .52138 Mdot
.38594 .4918 Mdot
.33269 .51776 Mdot
.80648 .59614 Mdot
.58873 .33395 Mdot
.59919 .63662 Mdot
.66532 .46673 Mdot
.69233 .45627 Mdot
.56406 .31234 Mdot
.54287 .68817 Mdot
.71962 .70726 Mdot
.87522 .53347 Mdot
.56583 .35851 Mdot
.46657 .26738 Mdot
.25384 .44276 Mdot
.59224 .32392 Mdot
.56215 .32556 Mdot
.62385 .34796 Mdot
.78828 .6154 Mdot
.61993 .63406 Mdot
.38142 .55446 Mdot
.63727 .74307 Mdot
.39387 .57886 Mdot
.34665 .35525 Mdot
.68613 .47721 Mdot
.58483 .63922 Mdot
.50399 .37165 Mdot
.42169 .52627 Mdot
.35229 .55305 Mdot
.52755 .36994 Mdot
.47711 .56305 Mdot
.27355 .28836 Mdot
.41828 .55726 Mdot
.5752 .33428 Mdot
.65437 .68988 Mdot
.3684 .61924 Mdot
.5073 .79406 Mdot
.7035 .48283 Mdot
.51603 .55537 Mdot
.38779 .62031 Mdot
.43859 .59125 Mdot
.60044 .6877 Mdot
.60565 .61824 Mdot
.43898 .29706 Mdot
.66985 .72361 Mdot
.70568 .48224 Mdot
.77404 .58959 Mdot
.39072 .53245 Mdot
.71692 .42913 Mdot
.39227 .30381 Mdot
.36215 .55403 Mdot
.53693 .46604 Mdot
.48832 .65774 Mdot
.34795 .5137 Mdot
.31251 .70327 Mdot
.68692 .47006 Mdot
.29483 .35625 Mdot
.34753 .53491 Mdot
.6095 .33352 Mdot
.60161 .62392 Mdot
.63963 .68036 Mdot
.47995 .27612 Mdot
.41313 .30789 Mdot
.64929 .81955 Mdot
.58468 .63757 Mdot
.38309 .53756 Mdot
.70099 .46445 Mdot
.52242 .56086 Mdot
.30773 .57789 Mdot
.57592 .50243 Mdot
.61814 .66647 Mdot
.33816 .61195 Mdot
.72677 .68431 Mdot
.32289 .41994 Mdot
.37272 .77628 Mdot
.67499 .47793 Mdot
.46905 .27506 Mdot
.43898 .52565 Mdot
.6495 .33721 Mdot
.39839 .53207 Mdot
.34607 .35316 Mdot
.64299 .62759 Mdot
.46932 .28175 Mdot
.34869 .55264 Mdot
.35093 .50878 Mdot
.28217 .45856 Mdot
.4231 .26892 Mdot
.32899 .52091 Mdot
.40331 .51968 Mdot
.60169 .62125 Mdot
.50133 .54481 Mdot
.60699 .66443 Mdot
.34584 .55937 Mdot
.36676 .26113 Mdot
.57883 .64073 Mdot
.73427 .54368 Mdot
.47847 .30478 Mdot
.71459 .47861 Mdot
.34433 .60931 Mdot
.38849 .58689 Mdot
.37317 .7835 Mdot
.51554 .55765 Mdot
.79734 .47043 Mdot
.61327 .32822 Mdot
.25189 .28964 Mdot
.62189 .30627 Mdot
.75343 .47573 Mdot
.61607 .4817 Mdot
.383 .61707 Mdot
.53765 .68069 Mdot
.29992 .70839 Mdot
.73181 .47424 Mdot
.33899 .75154 Mdot
.38112 .53233 Mdot
.36956 .58445 Mdot
.6047 .34068 Mdot
.73597 .44303 Mdot
.41107 .48642 Mdot
.3336 .41441 Mdot
.4635 .25512 Mdot
.61093 .65019 Mdot
.39556 .54646 Mdot
.68977 .70826 Mdot
.59812 .29684 Mdot
.36472 .65804 Mdot
.3737 .57214 Mdot
.48147 .55878 Mdot
.73909 .45013 Mdot
.70985 .47642 Mdot
.61793 .32434 Mdot
.61184 .30655 Mdot
.37345 .58778 Mdot
.65648 .47483 Mdot
.35435 .52128 Mdot
.30249 .40678 Mdot
.34106 .61063 Mdot
.44643 .27503 Mdot
.40069 .54172 Mdot
.50539 .60874 Mdot
.18615 .62252 Mdot
.42374 .53122 Mdot
.57629 .66804 Mdot
.59568 .33604 Mdot
.56731 .31899 Mdot
.62433 .62985 Mdot
.56707 .31777 Mdot
.38089 .68582 Mdot
.52322 .80776 Mdot
.45169 .27357 Mdot
.36177 .71325 Mdot
.45286 .25753 Mdot
.51511 .5542 Mdot
.36396 .56059 Mdot
.69528 .27909 Mdot
.56199 .35373 Mdot
.40826 .35077 Mdot
.69382 .47786 Mdot
.51129 .55505 Mdot
.33387 .54884 Mdot
.45997 .23555 Mdot
.58505 .31604 Mdot
.49294 .5544 Mdot
.38982 .58117 Mdot
.57874 .65107 Mdot
.34393 .51747 Mdot
.47345 .56949 Mdot
.50325 .54517 Mdot
.369 .50628 Mdot
.70679 .48781 Mdot
.59 .66191 Mdot
.779 .48158 Mdot
.55831 .31251 Mdot
.3402 .54923 Mdot
.37828 .53773 Mdot
.628 .67952 Mdot
.40737 .56874 Mdot
.6563 .48125 Mdot
.89124 .41959 Mdot
.43202 .27993 Mdot
.53646 .56747 Mdot
.70441 .57279 Mdot
.36806 .50558 Mdot
.40406 .5242 Mdot
.45017 .47764 Mdot
.37994 .66258 Mdot
.71256 .48193 Mdot
.37125 .49327 Mdot
.57253 .34921 Mdot
.43542 .27385 Mdot
.70539 .45489 Mdot
.33354 .54285 Mdot
.39522 .57073 Mdot
.46861 .28049 Mdot
.52122 .37438 Mdot
.42538 .29009 Mdot
.66322 .48084 Mdot
.56893 .55471 Mdot
.46139 .43654 Mdot
.37448 .56122 Mdot
.49558 .54731 Mdot
.59629 .64439 Mdot
.66787 .49046 Mdot
.4697 .6693 Mdot
.4113 .61562 Mdot
.7141 .4467 Mdot
.70851 .47835 Mdot
.39749 .58275 Mdot
.57412 .63866 Mdot
.57544 .5973 Mdot
.5975 .64121 Mdot
.27969 .34829 Mdot
.78748 .46526 Mdot
.59214 .33705 Mdot
.69072 .46665 Mdot
.60204 .30794 Mdot
.43841 .25711 Mdot
.27345 .41955 Mdot
.59577 .29346 Mdot
.58903 .61452 Mdot
.59753 .3017 Mdot
.35943 .5201 Mdot
.71747 .47115 Mdot
.56195 .29457 Mdot
.38197 .52614 Mdot
.44728 .55366 Mdot
.45805 .58353 Mdot
.45963 .24692 Mdot
.32427 .41365 Mdot
.37742 .57693 Mdot
.52382 .54071 Mdot
.36587 .56792 Mdot
.65588 .47862 Mdot
.41218 .41975 Mdot
.33546 .57111 Mdot
.56153 .35343 Mdot
.81097 .50212 Mdot
.5648 .34607 Mdot
.4148 .63355 Mdot
.35363 .56898 Mdot
.37158 .55972 Mdot
.33433 .55358 Mdot
.55477 .71206 Mdot
.71175 .44972 Mdot
.37573 .49528 Mdot
.61187 .35329 Mdot
.62257 .64981 Mdot
.58149 .6242 Mdot
.4682 .48058 Mdot
.51149 .54183 Mdot
.65532 .48346 Mdot
.37181 .55815 Mdot
.49138 .55252 Mdot
.35943 .41983 Mdot
.73859 .68285 Mdot
.5889 .27933 Mdot
.5566 .32553 Mdot
.59222 .67641 Mdot
.57106 .34209 Mdot
.33545 .54271 Mdot
.34508 .61422 Mdot
.78006 .48524 Mdot
.67225 .50661 Mdot
.4362 .27287 Mdot
.35099 .56984 Mdot
.23236 .43501 Mdot
.58738 .35523 Mdot
.61889 .32076 Mdot
.35251 .52235 Mdot
.63547 .61216 Mdot
.16901 .56388 Mdot
.69373 .49889 Mdot
.42491 .77393 Mdot
.5899 .76971 Mdot
.25175 .55794 Mdot
.6886 .45907 Mdot
.53175 .46213 Mdot
.58196 .28556 Mdot
.36608 .23671 Mdot
.62121 .64519 Mdot
.43597 .27726 Mdot
.38636 .52812 Mdot
.59106 .61375 Mdot
.57426 .3656 Mdot
.6301 .67275 Mdot
.39602 .61801 Mdot
.71581 .46092 Mdot
.57413 .3191 Mdot
.65245 .48703 Mdot
.56693 .6345 Mdot
.45157 .25902 Mdot
.32976 .34405 Mdot
.39554 .75721 Mdot
.4926 .65807 Mdot
.33013 .56946 Mdot
.52857 .2786 Mdot
.33355 .57527 Mdot
.64697 .65521 Mdot
.37676 .57454 Mdot
.43697 .56816 Mdot
.60318 .29377 Mdot
.4027 .58155 Mdot
.39523 .53624 Mdot
.5052 .79663 Mdot
.35737 .55468 Mdot
.34909 .57662 Mdot
.40942 .57806 Mdot
.57624 .62566 Mdot
.40841 .57455 Mdot
.59025 .66802 Mdot
.74751 .65984 Mdot
.55921 .31169 Mdot
.43537 .26033 Mdot
.43869 .25854 Mdot
.35558 .34768 Mdot
.23582 .43126 Mdot
.61848 .74091 Mdot
.61773 .65985 Mdot
.69508 .4842 Mdot
.36112 .52076 Mdot
.18567 .47719 Mdot
.3619 .27151 Mdot
.5563 .29012 Mdot
.57685 .29075 Mdot
.36521 .53247 Mdot
.54511 .8631 Mdot
.41672 .55198 Mdot
.37073 .42898 Mdot
.39512 .553 Mdot
.42423 .55508 Mdot
.62222 .34278 Mdot
.29634 .37367 Mdot
.33189 .57103 Mdot
.59775 .68746 Mdot
.43746 .27578 Mdot
.48053 .56038 Mdot
.35806 .29609 Mdot
.57192 .78134 Mdot
.51919 .59402 Mdot
.33175 .56257 Mdot
.6012 .35495 Mdot
.63074 .65189 Mdot
.35644 .43121 Mdot
.66426 .49032 Mdot
.33634 .39088 Mdot
.34162 .73038 Mdot
.73498 .47751 Mdot
.43842 .26734 Mdot
.57282 .36816 Mdot
.38199 .58699 Mdot
.58279 .34315 Mdot
.37783 .49784 Mdot
.36563 .41734 Mdot
.44895 .2727 Mdot
.62747 .6978 Mdot
.69335 .49566 Mdot
.59618 .61398 Mdot
.40247 .6507 Mdot
.36289 .26737 Mdot
.25712 .27468 Mdot
.56868 .3565 Mdot
.31895 .66802 Mdot
.58987 .63751 Mdot
.36188 .58747 Mdot
.87385 .53378 Mdot
.59713 .65033 Mdot
.57759 .64788 Mdot
.3776 .40835 Mdot
.28182 .37434 Mdot
.38685 .5007 Mdot
.63346 .64962 Mdot
.57253 .36769 Mdot
.45311 .28175 Mdot
.37394 .52605 Mdot
.38654 .61986 Mdot
.59668 .61958 Mdot
.5784 .31245 Mdot
.3127 .37177 Mdot
.57432 .3304 Mdot
.61372 .63057 Mdot
.57115 .29878 Mdot
.74971 .51816 Mdot
.59196 .2918 Mdot
.40685 .55765 Mdot
.37266 .55864 Mdot
.55222 .60302 Mdot
.62734 .66313 Mdot
.40349 .52428 Mdot
.38777 .57916 Mdot
.59752 .63342 Mdot
.61288 .37993 Mdot
.42384 .65104 Mdot
.40854 .52474 Mdot
.376 .55526 Mdot
.43036 .27963 Mdot
.30541 .42674 Mdot
.3947 .43717 Mdot
.38758 .52553 Mdot
.46181 .26286 Mdot
.58137 .65771 Mdot
.36281 .56675 Mdot
.2985 .37171 Mdot
.54505 .30803 Mdot
.33892 .53227 Mdot
.5277 .56111 Mdot
.33345 .57713 Mdot
.20978 .60735 Mdot
.33689 .54886 Mdot
.61241 .63411 Mdot
.5972 .62704 Mdot
.62197 .38209 Mdot
.61457 .64356 Mdot
.5312 .56634 Mdot
.70053 .48026 Mdot
.39769 .77433 Mdot
.52272 .56399 Mdot
.36249 .50921 Mdot
.39622 .2461 Mdot
.37759 .62049 Mdot
.31671 .60166 Mdot
.43961 .31692 Mdot
.54088 .56185 Mdot
.58984 .64689 Mdot
.69192 .68572 Mdot
.3216 .50871 Mdot
.65775 .48649 Mdot
.37168 .61967 Mdot
.33739 .53301 Mdot
.43437 .56944 Mdot
.6151 .59176 Mdot
.67115 .49575 Mdot
.27743 .55365 Mdot
.37397 .52591 Mdot
.38533 .6608 Mdot
.39427 .54284 Mdot
.47502 .25723 Mdot
.60106 .66199 Mdot
.57631 .34512 Mdot
.4474 .27875 Mdot
.32844 .52041 Mdot
.45179 .29353 Mdot
.58717 .34188 Mdot
.68118 .48671 Mdot
.40588 .56137 Mdot
.42524 .26616 Mdot
.44943 .25505 Mdot
.32181 .54083 Mdot
.59156 .62797 Mdot
.31402 .50665 Mdot
.36022 .56418 Mdot
.33321 .55575 Mdot
.62041 .62586 Mdot
.75979 .3047 Mdot
.36235 .5842 Mdot
.53377 .46193 Mdot
.64632 .66853 Mdot
.50179 .54739 Mdot
.5836 .35094 Mdot
.38072 .51338 Mdot
.70183 .45739 Mdot
.69949 .47892 Mdot
.554 .34125 Mdot
.60506 .61886 Mdot
.57063 .31647 Mdot
.42803 .53529 Mdot
.36079 .6183 Mdot
.37904 .5287 Mdot
.59101 .39456 Mdot
.77368 .518 Mdot
.61762 .68149 Mdot
.55399 .32356 Mdot
.33165 .40011 Mdot
.71736 .47588 Mdot
.61977 .35308 Mdot
.60707 .69088 Mdot
.62619 .6256 Mdot
.62595 .63475 Mdot
.46596 .25979 Mdot
.5783 .32303 Mdot
.56443 .63011 Mdot
.563 .64599 Mdot
.33492 .52963 Mdot
.37065 .52496 Mdot
.58533 .66544 Mdot
.63992 .36432 Mdot
.44435 .26446 Mdot
.59581 .35868 Mdot
.17039 .57997 Mdot
.68263 .49817 Mdot
.50723 .7958 Mdot
.3917 .52671 Mdot
.77947 .75421 Mdot
.41715 .55315 Mdot
.3883 .53844 Mdot
.56843 .62043 Mdot
.43173 .29519 Mdot
.4561 .28291 Mdot
.59013 .63608 Mdot
.63762 .64595 Mdot
.48075 .26735 Mdot
.42216 .44263 Mdot
.19748 .58556 Mdot
.35258 .42418 Mdot
.62433 .6765 Mdot
.37624 .75577 Mdot
.67582 .46824 Mdot
.64799 .64415 Mdot
.67555 .53293 Mdot
.56242 .30057 Mdot
.57961 .28876 Mdot
.69099 .48889 Mdot
.35707 .58202 Mdot
.60377 .35987 Mdot
.40226 .596 Mdot
.76852 .47649 Mdot
.56531 .50465 Mdot
.19904 .39424 Mdot
.4058 .56739 Mdot
.49557 .58515 Mdot
.7999 .60965 Mdot
.36546 .51483 Mdot
.51483 .75745 Mdot
.43735 .28465 Mdot
.64607 .64378 Mdot
.70587 .49796 Mdot
.65218 .74417 Mdot
.37334 .56042 Mdot
.62965 .66595 Mdot
.70806 .4947 Mdot
.77905 .50733 Mdot
.52263 .45227 Mdot
.33986 .52271 Mdot
.88548 .50467 Mdot
.58448 .68425 Mdot
.57769 .34582 Mdot
.43892 .75849 Mdot
.62081 .61491 Mdot
.51293 .44416 Mdot
.57193 .36598 Mdot
.3262 .44023 Mdot
.63446 .66155 Mdot
.42828 .29418 Mdot
.60998 .65482 Mdot
.47375 .29082 Mdot
.56555 .62118 Mdot
.56823 .30443 Mdot
.35106 .56005 Mdot
.56364 .30781 Mdot
.48353 .27208 Mdot
.56693 .35597 Mdot
.70666 .49769 Mdot
.54245 .55705 Mdot
.68595 .47865 Mdot
.26028 .43285 Mdot
.4755 .68285 Mdot
.67133 .48556 Mdot
.46781 .50636 Mdot
.40077 .5659 Mdot
.58142 .60231 Mdot
.57232 .34089 Mdot
.6085 .29535 Mdot
.32538 .41217 Mdot
.61514 .62857 Mdot
.5771 .30933 Mdot
.38518 .75495 Mdot
.80126 .43637 Mdot
.43975 .56688 Mdot
.66448 .36224 Mdot
.60376 .63229 Mdot
.61977 .31035 Mdot
.36709 .43114 Mdot
.62084 .61864 Mdot
.56572 .29157 Mdot
.67796 .49334 Mdot
.70314 .45881 Mdot
.4097 .56096 Mdot
.68627 .50301 Mdot
.58206 .28644 Mdot
.35331 .66593 Mdot
.58266 .64434 Mdot
.76766 .52562 Mdot
.4362 .26616 Mdot
.56812 .334 Mdot
.3106 .55287 Mdot
.57445 .62049 Mdot
.59827 .30375 Mdot
.62712 .82778 Mdot
.17492 .64081 Mdot
.57902 .3104 Mdot
.60251 .66189 Mdot
.62434 .66299 Mdot
.39857 .51336 Mdot
.33004 .41182 Mdot
.58682 .31564 Mdot
.6922 .27704 Mdot
.23721 .46656 Mdot
.53641 .5571 Mdot
.29866 .23095 Mdot
.33444 .57328 Mdot
.33014 .55913 Mdot
.66141 .4808 Mdot
.35509 .55074 Mdot
.63771 .65316 Mdot
.41755 .55304 Mdot
.68587 .44947 Mdot
.55041 .33088 Mdot
.36771 .56238 Mdot
.43504 .27296 Mdot
.67574 .4552 Mdot
.67121 .45528 Mdot
.57573 .2975 Mdot
.6077 .62019 Mdot
.70208 .73583 Mdot
.57357 .32838 Mdot
.33049 .55135 Mdot
.53105 .54357 Mdot
.40551 .58002 Mdot
.5549 .66586 Mdot
.64472 .6678 Mdot
.57297 .3439 Mdot
.52592 .5359 Mdot
.69595 .46626 Mdot
.58634 .28596 Mdot
.34106 .58255 Mdot
.55508 .29841 Mdot
.54926 .45555 Mdot
.53263 .17874 Mdot
.57492 .6794 Mdot
.53639 .4394 Mdot
.6213 .62051 Mdot
.53582 .56099 Mdot
.28816 .31838 Mdot
.44222 .26449 Mdot
.57588 .35422 Mdot
.73621 .54166 Mdot
.55767 .31546 Mdot
.36083 .55256 Mdot
.39526 .57213 Mdot
.60396 .34311 Mdot
.45585 .25953 Mdot
.43712 .36794 Mdot
.42475 .29382 Mdot
.60642 .66847 Mdot
.45767 .46493 Mdot
.15531 .55288 Mdot
.54876 .28831 Mdot
.69736 .48677 Mdot
.52611 .60606 Mdot
.35581 .50959 Mdot
.6914 .49965 Mdot
.66575 .45855 Mdot
.47857 .29055 Mdot
.56117 .32493 Mdot
.62239 .69646 Mdot
.71417 .46136 Mdot
.61244 .60982 Mdot
.31201 .36805 Mdot
.42259 .61075 Mdot
.26658 .5809 Mdot
.34589 .50984 Mdot
.32276 .41738 Mdot
.71381 .45807 Mdot
.39075 .56844 Mdot
.42505 .51659 Mdot
.6825 .49608 Mdot
.47614 .29331 Mdot
.56785 .52209 Mdot
.57885 .30842 Mdot
.85078 .59337 Mdot
.40621 .55415 Mdot
.35561 .56403 Mdot
.68843 .49786 Mdot
.53485 .77096 Mdot
.59416 .68388 Mdot
.5961 .62253 Mdot
.58918 .33353 Mdot
.38615 .416 Mdot
.40374 .57636 Mdot
.40411 .56177 Mdot
.61076 .33823 Mdot
.52123 .54195 Mdot
.26934 .26246 Mdot
.38192 .55646 Mdot
.68498 .46647 Mdot
.54722 .47468 Mdot
.72371 .4818 Mdot
.42726 .56897 Mdot
.36754 .5488 Mdot
.3186 .56186 Mdot
.34348 .58549 Mdot
.6807 .47719 Mdot
.34092 .51303 Mdot
.35357 .50142 Mdot
.59271 .64633 Mdot
.33911 .57276 Mdot
.23677 .46799 Mdot
.38001 .55917 Mdot
.43525 .28138 Mdot
.39747 .43545 Mdot
.3376 .55179 Mdot
.33743 .5704 Mdot
.23767 .46429 Mdot
.3528 .54681 Mdot
.7054 .49628 Mdot
.62587 .65884 Mdot
.69734 .46541 Mdot
.70119 .4877 Mdot
.59194 .29916 Mdot
.46443 .30092 Mdot
.40516 .50945 Mdot
.47658 .26629 Mdot
.41326 .51985 Mdot
.28027 .55032 Mdot
.29181 .41662 Mdot
.36907 .42856 Mdot
.44651 .25085 Mdot
.40337 .5598 Mdot
.58698 .33823 Mdot
.56547 .33665 Mdot
.49165 .45973 Mdot
.36392 .61516 Mdot
.71312 .49765 Mdot
.67903 .49032 Mdot
.47488 .35254 Mdot
.51466 .16865 Mdot
.45856 .25243 Mdot
.44838 .37474 Mdot
.37942 .59944 Mdot
.35931 .57938 Mdot
.31508 .5928 Mdot
.60833 .318 Mdot
.54292 .56113 Mdot
.59211 .3658 Mdot
.73748 .44885 Mdot
.68067 .45635 Mdot
.40697 .56322 Mdot
.50975 .86573 Mdot
.5953 .66736 Mdot
.62604 .66141 Mdot
.68762 .44903 Mdot
.56588 .34677 Mdot
.33344 .60802 Mdot
.82431 .64418 Mdot
.63963 .67794 Mdot
.42788 .26922 Mdot
.34621 .55024 Mdot
.56177 .30285 Mdot
.58846 .65892 Mdot
.4272 .26355 Mdot
.36007 .59015 Mdot
.57657 .36888 Mdot
.38688 .56697 Mdot
.36177 .70268 Mdot
.58702 .64666 Mdot
.28712 .43129 Mdot
.56973 .63744 Mdot
.68065 .47531 Mdot
.71235 .47829 Mdot
.36828 .55027 Mdot
.83726 .6271 Mdot
.65495 .68392 Mdot
.6796 .44402 Mdot
.43716 .29654 Mdot
.54364 .5533 Mdot
.46065 .2997 Mdot
.60253 .34063 Mdot
.43892 .26715 Mdot
.5959 .30202 Mdot
.63788 .37799 Mdot
.59558 .69126 Mdot
.46837 .28116 Mdot
.51144 .73284 Mdot
.33954 .61216 Mdot
.47338 .30356 Mdot
.35716 .53394 Mdot
.41178 .5218 Mdot
.59394 .31501 Mdot
.47147 .25992 Mdot
.33251 .5218 Mdot
.69618 .57174 Mdot
.70976 .48348 Mdot
.71291 .49631 Mdot
.37699 .61844 Mdot
.62014 .31756 Mdot
.59177 .68853 Mdot
.31633 .39604 Mdot
.62421 .70039 Mdot
.40455 .55838 Mdot
.41514 .5186 Mdot
.5673 .65437 Mdot
.57959 .67395 Mdot
.37255 .54764 Mdot
.45444 .80596 Mdot
.31402 .54188 Mdot
.70598 .4611 Mdot
.60467 .66892 Mdot
.62423 .66697 Mdot
.58537 .28766 Mdot
.59325 .62183 Mdot
.37424 .48894 Mdot
.73933 .46808 Mdot
.33929 .50253 Mdot
.69354 .46863 Mdot
.58856 .27062 Mdot
.5916 .30889 Mdot
.74313 .536 Mdot
.58854 .62472 Mdot
.40021 .52507 Mdot
.57918 .63044 Mdot
.43695 .29086 Mdot
.6238 .6732 Mdot
.58976 .59623 Mdot
.39094 .53154 Mdot
.32682 .52257 Mdot
.51866 .54624 Mdot
.32784 .41579 Mdot
.59333 .65528 Mdot
.42778 .53723 Mdot
.41956 .54747 Mdot
.3923 .57803 Mdot
.30887 .40363 Mdot
.57668 .62593 Mdot
.56867 .78165 Mdot
.62605 .71189 Mdot
.58707 .65062 Mdot
.20491 .66629 Mdot
.51483 .55072 Mdot
.5238 .53793 Mdot
.70083 .50678 Mdot
.37989 .55457 Mdot
.56725 .31399 Mdot
.32796 .55025 Mdot
.309 .57726 Mdot
.3391 .55265 Mdot
.46646 .2906 Mdot
.39544 .58536 Mdot
.5301 .55144 Mdot
.57095 .33056 Mdot
.37098 .51606 Mdot
.36863 .55725 Mdot
.51148 .54292 Mdot
.57582 .64119 Mdot
.61783 .62034 Mdot
.6156 .70295 Mdot
.48093 .28481 Mdot
.67014 .46865 Mdot
.32964 .54856 Mdot
.58812 .33543 Mdot
.56394 .31535 Mdot
.58234 .6191 Mdot
.60996 .34461 Mdot
.67238 .4587 Mdot
.38652 .5396 Mdot
.68143 .4766 Mdot
.4656 .29187 Mdot
.60012 .66202 Mdot
.33796 .54165 Mdot
.32776 .53468 Mdot
.5969 .62715 Mdot
.31654 .53415 Mdot
.43981 .29529 Mdot
.61551 .3231 Mdot
.60986 .68317 Mdot
.70144 .47925 Mdot
.58927 .28955 Mdot
.38579 .51918 Mdot
.28185 .75566 Mdot
.35656 .5498 Mdot
.39861 .57742 Mdot
.65644 .69167 Mdot
.41318 .58245 Mdot
.5579 .31289 Mdot
.58213 .62458 Mdot
.41115 .52316 Mdot
.2339 .45673 Mdot
.50893 .3004 Mdot
.54188 .28999 Mdot
.37012 .53693 Mdot
.36541 .77644 Mdot
.40747 .53346 Mdot
.73475 .5454 Mdot
.29182 .41705 Mdot
.64266 .50638 Mdot
.2671 .58166 Mdot
.67881 .44504 Mdot
.52578 .54171 Mdot
.5864 .29936 Mdot
.48917 .7792 Mdot
.37126 .54498 Mdot
.47912 .65856 Mdot
.33637 .54076 Mdot
.6904 .45808 Mdot
.5259 .75317 Mdot
.60405 .35348 Mdot
.26489 .28366 Mdot
.35032 .58281 Mdot
.60339 .68838 Mdot
.61812 .36568 Mdot
.53219 .54015 Mdot
.32763 .52267 Mdot
.47055 .25551 Mdot
.48377 .3502 Mdot
.34606 .4916 Mdot
.6966 .46824 Mdot
.37346 .58329 Mdot
.31412 .57383 Mdot
.79932 .38638 Mdot
.5978 .6391 Mdot
.69263 .49363 Mdot
.50787 .17168 Mdot
.39769 .56572 Mdot
.62473 .62454 Mdot
.62119 .64594 Mdot
.47796 .27505 Mdot
.69178 .43556 Mdot
.50219 .35456 Mdot
.48403 .84825 Mdot
.29171 .64345 Mdot
.60978 .3186 Mdot
.56115 .56656 Mdot
.32609 .5526 Mdot
.36396 .26632 Mdot
.7011 .48525 Mdot
.35365 .56369 Mdot
.50126 .66039 Mdot
.60851 .6363 Mdot
.3879 .5619 Mdot
.44303 .26685 Mdot
.73579 .72217 Mdot
.36261 .7378 Mdot
.38725 .78709 Mdot
.57224 .36742 Mdot
.39347 .50237 Mdot
.37959 .49003 Mdot
.50128 .54692 Mdot
.43192 .56309 Mdot
.57428 .34192 Mdot
.56364 .47026 Mdot
.45329 .26625 Mdot
.59012 .66328 Mdot
.52073 .54024 Mdot
.33699 .54008 Mdot
.37315 .49819 Mdot
.43332 .29189 Mdot
.31873 .55626 Mdot
.44541 .76777 Mdot
.54744 .5695 Mdot
.59566 .29431 Mdot
.62477 .67963 Mdot
.40907 .51306 Mdot
.54105 .54824 Mdot
.38479 .53094 Mdot
.4995 .60987 Mdot
.35277 .5699 Mdot
.67041 .55135 Mdot
.60235 .62362 Mdot
.70469 .47246 Mdot
.34775 .58864 Mdot
.38037 .56622 Mdot
.52606 .42576 Mdot
.32746 .60554 Mdot
.33853 .56308 Mdot
.6066 .61354 Mdot
.59229 .66582 Mdot
.6004 .68675 Mdot
.56308 .28799 Mdot
.34749 .42112 Mdot
.68626 .47499 Mdot
.31673 .59496 Mdot
.71389 .46074 Mdot
.25814 .5626 Mdot
.46583 .29502 Mdot
.75388 .5285 Mdot
.38531 .54173 Mdot
.62244 .63296 Mdot
.19225 .57148 Mdot
.57757 .62242 Mdot
.73574 .49341 Mdot
.70446 .48298 Mdot
.59887 .6524 Mdot
.3639 .54073 Mdot
.3308 .42447 Mdot
.39747 .79887 Mdot
.71762 .4742 Mdot
.38723 .618 Mdot
.56304 .26357 Mdot
.54724 .31701 Mdot
.19509 .64934 Mdot
.71146 .46048 Mdot
.80046 .60979 Mdot
.40866 .52446 Mdot
.58012 .63317 Mdot
.67336 .4787 Mdot
.65861 .46815 Mdot
.60835 .35124 Mdot
.33808 .52526 Mdot
.38257 .56522 Mdot
.52638 .5604 Mdot
.68447 .48353 Mdot
.47484 .56377 Mdot
.34051 .52099 Mdot
.75894 .46182 Mdot
.62621 .68773 Mdot
.75491 .29752 Mdot
.46833 .53156 Mdot
.5002 .66054 Mdot
.73383 .30385 Mdot
.60381 .68323 Mdot
.3542 .581 Mdot
.33563 .60855 Mdot
.61633 .32939 Mdot
.3745 .53987 Mdot
.55381 .32609 Mdot
.68023 .45997 Mdot
.67772 .56288 Mdot
.46366 .50482 Mdot
.75283 .4896 Mdot
.35473 .55384 Mdot
.3724 .74395 Mdot
.46264 .27527 Mdot
.72588 .48915 Mdot
.58589 .67907 Mdot
.42717 .56203 Mdot
.61513 .34237 Mdot
.5522 .30433 Mdot
.6079 .63925 Mdot
.78522 .61347 Mdot
.74382 .53742 Mdot
.31152 .54673 Mdot
.5952 .35036 Mdot
.48781 .55265 Mdot
.35112 .75656 Mdot
.70082 .44778 Mdot
.45462 .26733 Mdot
.57569 .29483 Mdot
.65889 .491 Mdot
.41024 .52031 Mdot
.60599 .64569 Mdot
.57981 .68183 Mdot
.49829 .45169 Mdot
.57498 .30963 Mdot
.44803 .28637 Mdot
.50565 .45139 Mdot
.46933 .46597 Mdot
.44613 .27298 Mdot
.55783 .2887 Mdot
.61165 .6745 Mdot
.61523 .63301 Mdot
.62536 .6566 Mdot
.50757 .79394 Mdot
.64436 .66828 Mdot
.34797 .32135 Mdot
.43054 .56531 Mdot
.38505 .76112 Mdot
.42469 .54606 Mdot
.70315 .49845 Mdot
.58591 .64313 Mdot
.28952 .42017 Mdot
.36901 .59864 Mdot
.40479 .80218 Mdot
.37208 .57709 Mdot
.5416 .46923 Mdot
.37832 .55442 Mdot
.3838 .71897 Mdot
.64366 .63746 Mdot
.35971 .58865 Mdot
.73662 .46568 Mdot
.44701 .29331 Mdot
.56853 .60867 Mdot
.34452 .57006 Mdot
.72655 .67733 Mdot
.35646 .53385 Mdot
.67581 .55945 Mdot
.50793 .4442 Mdot
.40715 .26807 Mdot
.40938 .57606 Mdot
.60765 .36213 Mdot
.43558 .49942 Mdot
.37427 .75791 Mdot
.71745 .47239 Mdot
.37896 .74994 Mdot
.5919 .36124 Mdot
.52788 .75571 Mdot
.30763 .56295 Mdot
.45342 .26381 Mdot
.57828 .52306 Mdot
.7097 .46529 Mdot
.38086 .54321 Mdot
.3573 .58446 Mdot
.5619 .50122 Mdot
.33929 .74411 Mdot
.47863 .56306 Mdot
.43967 .25271 Mdot
.35158 .73672 Mdot
.33967 .5618 Mdot
.54151 .28807 Mdot
.60799 .61763 Mdot
.52495 .74309 Mdot
.54165 .76223 Mdot
.35528 .5149 Mdot
.59883 .64859 Mdot
.60519 .61899 Mdot
.17157 .52044 Mdot
.46531 .27004 Mdot
.35575 .57193 Mdot
.53706 .43851 Mdot
.33098 .54713 Mdot
.68325 .46214 Mdot
.39475 .59592 Mdot
.58967 .3089 Mdot
.36847 .4331 Mdot
.5596 .28997 Mdot
.39451 .57721 Mdot
.61035 .65648 Mdot
.71256 .48663 Mdot
.64646 .37441 Mdot
.6938 .43595 Mdot
.34689 .32212 Mdot
.46801 .34573 Mdot
.45599 .25237 Mdot
.46815 .29632 Mdot
.72301 .49134 Mdot
.37879 .53567 Mdot
.32082 .40416 Mdot
.42764 .5865 Mdot
.38547 .55314 Mdot
.34654 .56508 Mdot
.67193 .51251 Mdot
.70545 .48115 Mdot
.56793 .30073 Mdot
.37402 .54678 Mdot
.43135 .54391 Mdot
.60533 .65522 Mdot
.45411 .2534 Mdot
.60105 .30144 Mdot
.48111 .26218 Mdot
.57771 .33527 Mdot
.21018 .60899 Mdot
.40005 .61897 Mdot
.45492 .2941 Mdot
.7045 .45191 Mdot
.62738 .64294 Mdot
.51377 .55507 Mdot
.60212 .33503 Mdot
.60687 .34799 Mdot
.39741 .50848 Mdot
.58863 .65661 Mdot
.59327 .62337 Mdot
.48102 .26562 Mdot
.67646 .48894 Mdot
.44732 .55825 Mdot
.35456 .50839 Mdot
.65799 .31706 Mdot
.61862 .33024 Mdot
.36226 .74479 Mdot
.64207 .70858 Mdot
.39308 .53783 Mdot
.62292 .6241 Mdot
.36904 .56592 Mdot
.53928 .60372 Mdot
.58053 .67966 Mdot
.4101 .58604 Mdot
.3647 .60943 Mdot
.60635 .31415 Mdot
.17096 .47502 Mdot
.44702 .55118 Mdot
.71741 .52745 Mdot
.32371 .554 Mdot
.25329 .27578 Mdot
.1883 .56126 Mdot
.36982 .53218 Mdot
.39123 .5862 Mdot
.44612 .84821 Mdot
.40755 .53537 Mdot
.53049 .55759 Mdot
.30714 .57511 Mdot
.62772 .62884 Mdot
.54092 .44452 Mdot
.32384 .41495 Mdot
.46982 .27166 Mdot
.58996 .33435 Mdot
.28752 .37385 Mdot
.4746 .29081 Mdot
.60923 .63316 Mdot
.44958 .55406 Mdot
.64994 .69901 Mdot
.62218 .30776 Mdot
.47333 .56751 Mdot
.68656 .45893 Mdot
.32311 .40788 Mdot
.61192 .34715 Mdot
.70109 .48048 Mdot
.41362 .53866 Mdot
.62906 .37228 Mdot
.73209 .47417 Mdot
.16274 .49232 Mdot
.66018 .48207 Mdot
.7094 .47464 Mdot
.33699 .41552 Mdot
.4699 .2715 Mdot
.56918 .47961 Mdot
.28016 .55829 Mdot
.71252 .48997 Mdot
.26959 .29545 Mdot
.61924 .3378 Mdot
.35942 .41368 Mdot
.64308 .63366 Mdot
.38657 .62029 Mdot
.34868 .56203 Mdot
.66544 .48825 Mdot
.54866 .54045 Mdot
.52313 .42154 Mdot
.69106 .4541 Mdot
.3508 .59284 Mdot
.39003 .42047 Mdot
.54048 .54956 Mdot
.51541 .55246 Mdot
.42561 .26759 Mdot
.54999 .20175 Mdot
.61241 .62401 Mdot
.42854 .26947 Mdot
.2669 .43892 Mdot
.37551 .57901 Mdot
.6787 .4767 Mdot
.51699 .54031 Mdot
.69962 .47752 Mdot
.45779 .27851 Mdot
.44068 .2973 Mdot
.59324 .64497 Mdot
.59358 .68251 Mdot
.57467 .54154 Mdot
.22878 .47242 Mdot
.34171 .53012 Mdot
.46679 .67086 Mdot
.57876 .67373 Mdot
.51641 .77938 Mdot
.46948 .26484 Mdot
.46188 .25543 Mdot
.29734 .68964 Mdot
.36738 .52062 Mdot
.5463 .4734 Mdot
.33672 .55367 Mdot
.3017 .27931 Mdot
.33924 .53963 Mdot
.61048 .34088 Mdot
.33924 .5777 Mdot
.6929 .71616 Mdot
.39662 .5188 Mdot
.34252 .55897 Mdot
.58679 .32341 Mdot
.40081 .50781 Mdot
.59199 .31228 Mdot
.35781 .58123 Mdot
.50042 .3265 Mdot
.58797 .33496 Mdot
.50208 .29763 Mdot
.51524 .46883 Mdot
.52332 .55391 Mdot
.47332 .28483 Mdot
.46042 .25144 Mdot
.3173 .36966 Mdot
.6033 .67381 Mdot
.54565 .70329 Mdot
.347 .55013 Mdot
.62086 .32863 Mdot
.67308 .46237 Mdot
.35409 .51427 Mdot
.41387 .56437 Mdot
.44662 .55233 Mdot
.59469 .64842 Mdot
.59635 .29037 Mdot
.46302 .2858 Mdot
.55865 .32751 Mdot
.50257 .3207 Mdot
.59648 .31018 Mdot
.41981 .60169 Mdot
.40967 .51868 Mdot
.38436 .49108 Mdot
.49966 .70336 Mdot
.3892 .25856 Mdot
.60678 .64242 Mdot
.53053 .54434 Mdot
.46168 .29803 Mdot
.41851 .43101 Mdot
.62096 .62719 Mdot
.60859 .34084 Mdot
.3868 .56729 Mdot
.41768 .61341 Mdot
.28069 .55626 Mdot
.60683 .6056 Mdot
.48117 .29724 Mdot
.59661 .33187 Mdot
.53825 .55548 Mdot
.35344 .42262 Mdot
.5914 .771 Mdot
.26669 .42502 Mdot
.37527 .5664 Mdot
.48103 .26896 Mdot
.58867 .6592 Mdot
.55833 .48551 Mdot
.6727 .49214 Mdot
.3289 .41263 Mdot
.35368 .55325 Mdot
.72414 .42041 Mdot
.6118 .65575 Mdot
.45026 .25925 Mdot
.6648 .4881 Mdot
.46187 .26546 Mdot
.54637 .5524 Mdot
.63632 .71223 Mdot
.32544 .52482 Mdot
.3362 .5501 Mdot
.67553 .46225 Mdot
.60778 .62264 Mdot
.50236 .33213 Mdot
.57347 .50031 Mdot
.6028 .34324 Mdot
.41417 .43577 Mdot
.59083 .66319 Mdot
.68348 .40621 Mdot
.5578 .3282 Mdot
.70109 .50298 Mdot
.32104 .42924 Mdot
.67064 .45834 Mdot
.34273 .56411 Mdot
.61887 .66243 Mdot
.71829 .47244 Mdot
.64946 .30186 Mdot
.46958 .81982 Mdot
.57699 .51803 Mdot
.39997 .56768 Mdot
.7478 .54502 Mdot
.77578 .64148 Mdot
.56724 .59859 Mdot
.70673 .45597 Mdot
.36108 .55701 Mdot
.31146 .54572 Mdot
.34859 .58235 Mdot
.70508 .49034 Mdot
.63578 .42533 Mdot
.58545 .35597 Mdot
.39206 .56741 Mdot
.43399 .27283 Mdot
.58477 .3053 Mdot
.549 .3353 Mdot
.57399 .29423 Mdot
.58498 .67672 Mdot
.43313 .60432 Mdot
.30794 .58099 Mdot
.1853 .5218 Mdot
.70727 .47252 Mdot
.52364 .55378 Mdot
.38267 .58796 Mdot
.3455 .32753 Mdot
.62386 .63894 Mdot
.59797 .32697 Mdot
.35582 .56506 Mdot
.50108 .44777 Mdot
.49409 .5491 Mdot
.57659 .32477 Mdot
.58191 .67842 Mdot
.6583 .63118 Mdot
.37804 .5397 Mdot
.32399 .54951 Mdot
.60057 .62926 Mdot
.7761 .6583 Mdot
.3612 .42343 Mdot
.36949 .56421 Mdot
.70493 .47658 Mdot
.83527 .52565 Mdot
.41524 .53816 Mdot
.64785 .68485 Mdot
.54227 .56354 Mdot
.64315 .71441 Mdot
.43119 .77553 Mdot
.34451 .60881 Mdot
.61715 .56429 Mdot
.41308 .35634 Mdot
.6076 .58495 Mdot
.32392 .27209 Mdot
.59026 .50701 Mdot
.15747 .52882 Mdot
.74098 .46536 Mdot
.36764 .71283 Mdot
.61351 .83007 Mdot
.79709 .60558 Mdot
.54118 .42875 Mdot
.62365 .47344 Mdot
.6285 .30817 Mdot
.27749 .25314 Mdot
.59882 .36637 Mdot
.33471 .26049 Mdot
.34048 .54405 Mdot
.76818 .66286 Mdot
.37336 .72248 Mdot
.41384 .30741 Mdot
.75432 .5169 Mdot
.50589 .4471 Mdot
.34068 .7861 Mdot
.76419 .48471 Mdot
.24423 .6861 Mdot
.51714 .66927 Mdot
.59123 .21219 Mdot
.4318 .44759 Mdot
.30027 .36242 Mdot
.39277 .74896 Mdot
.67998 .64549 Mdot
.69628 .42037 Mdot
.38569 .6683 Mdot
.74518 .308 Mdot
.59109 .34646 Mdot
.62765 .62246 Mdot
.61634 .49036 Mdot
.28685 .73196 Mdot
.73031 .512 Mdot
.61576 .56468 Mdot
.5749 .5106 Mdot
.37901 .71697 Mdot
.28365 .43046 Mdot
.36965 .69783 Mdot
.49477 .35788 Mdot
.28209 .252 Mdot
.6623 .65919 Mdot
.63913 .26742 Mdot
.40472 .41281 Mdot
.4819 .37342 Mdot
.41564 .73837 Mdot
.47584 .2485 Mdot
.50677 .29558 Mdot
.58302 .68064 Mdot
.31442 .74467 Mdot
.48141 .52425 Mdot
.26211 .44669 Mdot
.60265 .36634 Mdot
.53537 .59011 Mdot
.73093 .72316 Mdot
.76906 .64206 Mdot
.17671 .43292 Mdot
.27785 .74728 Mdot
.26622 .32994 Mdot
.54712 .4873 Mdot
.71604 .51466 Mdot
.35444 .33429 Mdot
.48888 .58724 Mdot
.24769 .35585 Mdot
.50401 .60852 Mdot
.40102 .82049 Mdot
.73773 .64607 Mdot
.31106 .77514 Mdot
.6612 .64773 Mdot
.41231 .50703 Mdot
.55025 .61234 Mdot
.34842 .66077 Mdot
.24549 .43198 Mdot
.31405 .76658 Mdot
.41116 .28119 Mdot
.55312 .55284 Mdot
.79667 .59736 Mdot
.44349 .76766 Mdot
.51669 .36519 Mdot
.47085 .31225 Mdot
.53495 .73256 Mdot
.35042 .80025 Mdot
.62716 .56459 Mdot
.24895 .63606 Mdot
.75923 .45685 Mdot
.59993 .38655 Mdot
.55293 .34219 Mdot
.66372 .45489 Mdot
.25609 .71046 Mdot
.62058 .65786 Mdot
.16746 .47413 Mdot
.57992 .56125 Mdot
.49364 .56543 Mdot
.35705 .80519 Mdot
.21698 .3739 Mdot
.41016 .76505 Mdot
.38731 .31089 Mdot
.79428 .46829 Mdot
.4015 .64335 Mdot
.74927 .48582 Mdot
.55492 .26908 Mdot
.69712 .55672 Mdot
.26747 .72204 Mdot
.24763 .34086 Mdot
.51115 .85734 Mdot
.25978 .45572 Mdot
.50014 .2559 Mdot
.66179 .66469 Mdot
.58069 .42446 Mdot
.52713 .3759 Mdot
.3046 .77196 Mdot
.35438 .73125 Mdot
.8223 .50734 Mdot
.30704 .29245 Mdot
.54272 .76774 Mdot
.73883 .56336 Mdot
.61973 .44339 Mdot
.35106 .65281 Mdot
.73614 .66743 Mdot
.34865 .50633 Mdot
.26685 .41288 Mdot
.52994 .71415 Mdot
.4193 .25438 Mdot
.35021 .42748 Mdot
.74362 .62197 Mdot
.26552 .35961 Mdot
.81442 .52916 Mdot
.54066 .73496 Mdot
.56801 .63686 Mdot
.25006 .3552 Mdot
.28646 .30615 Mdot
.79536 .52775 Mdot
.50436 .17182 Mdot
.24852 .63808 Mdot
.5557 .38815 Mdot
.33374 .60286 Mdot
.36364 .71098 Mdot
.39589 .74848 Mdot
.29012 .26077 Mdot
.41238 .60703 Mdot
.18287 .48909 Mdot
.74653 .51853 Mdot
.48519 .71381 Mdot
.24177 .4098 Mdot
.49568 .70826 Mdot
.40166 .77569 Mdot
.56754 .69196 Mdot
.65706 .52323 Mdot
.53952 .52641 Mdot
.3539 .80005 Mdot
.57675 .30088 Mdot
.24389 .35683 Mdot
.74424 .50316 Mdot
.65342 .31148 Mdot
.58403 .4929 Mdot
.53029 .41867 Mdot
.22823 .67956 Mdot
.79018 .58992 Mdot
.62528 .28408 Mdot
.6791 .68957 Mdot
.51417 .57544 Mdot
.47179 .67595 Mdot
.45867 .56374 Mdot
.50804 .59802 Mdot
.43988 .29544 Mdot
.49245 .75495 Mdot
.61511 .71607 Mdot
.48714 .16713 Mdot
.40511 .60531 Mdot
.43824 .44956 Mdot
.5333 .56472 Mdot
.34327 .38058 Mdot
.20736 .607 Mdot
.46075 .57742 Mdot
.21402 .38212 Mdot
.79151 .60545 Mdot
.33654 .37982 Mdot
.52203 .37402 Mdot
.55421 .71712 Mdot
.31428 .77838 Mdot
.18679 .62064 Mdot
.73549 .69479 Mdot
.73152 .55912 Mdot
.43743 .1437 Mdot
.64995 .51763 Mdot
.18327 .46667 Mdot
.74373 .50343 Mdot
.89101 .42262 Mdot
.55488 .31767 Mdot
.36754 .25703 Mdot
.45062 .62895 Mdot
.46664 .43861 Mdot
.30155 .74127 Mdot
.42497 .75976 Mdot
.48299 .29784 Mdot
.58228 .59925 Mdot
.38855 .61421 Mdot
.32413 .76563 Mdot
.36126 .79889 Mdot
.33019 .76901 Mdot
.66351 .40922 Mdot
.41217 .79554 Mdot
.41364 .83812 Mdot
.35158 .32017 Mdot
.51504 .49747 Mdot
.31189 .57035 Mdot
.21961 .47249 Mdot
.20242 .42842 Mdot
.41509 .2372 Mdot
.39243 .64616 Mdot
.663 .66867 Mdot
.39123 .83012 Mdot
.20083 .59974 Mdot
.36352 .69094 Mdot
.23082 .67272 Mdot
.59806 .2563 Mdot
.21695 .43926 Mdot
.20827 .65459 Mdot
.65869 .59934 Mdot
.74694 .45671 Mdot
.42526 .84872 Mdot
.28522 .31673 Mdot
.62378 .46845 Mdot
.71059 .69334 Mdot
.19294 .44022 Mdot
.72338 .56719 Mdot
.62174 .46553 Mdot
.489 .60076 Mdot
.60768 .75875 Mdot
.53602 .41789 Mdot
.67833 .64669 Mdot
.5457 .48123 Mdot
.23317 .41445 Mdot
.55874 .34605 Mdot
.23143 .37614 Mdot
.51235 .38489 Mdot
.52509 .49763 Mdot
.29713 .37885 Mdot
.2606 .31364 Mdot
.71225 .65594 Mdot
.37746 .78206 Mdot
.79128 .59942 Mdot
.82733 .52917 Mdot
.76777 .55219 Mdot
.5323 .70209 Mdot
.40351 .50921 Mdot
.29322 .73863 Mdot
.15631 .59534 Mdot
.21413 .66581 Mdot
.80253 .52721 Mdot
.53978 .33822 Mdot
.68243 .50202 Mdot
.34336 .34088 Mdot
.48004 .43277 Mdot
.61653 .53176 Mdot
.45498 .38724 Mdot
.66793 .4474 Mdot
.74033 .71807 Mdot
.58201 .5377 Mdot
.34975 .32825 Mdot
.39915 .66813 Mdot
.48079 .58097 Mdot
.34806 .75437 Mdot
.56669 .64912 Mdot
.80094 .51367 Mdot
.24594 .35808 Mdot
.5778 .29878 Mdot
.65612 .29975 Mdot
.52616 .52538 Mdot
.43137 .52308 Mdot
.55272 .26256 Mdot
.5486 .51367 Mdot
.49885 .66171 Mdot
.53953 .33427 Mdot
.17473 .5677 Mdot
.17735 .46522 Mdot
.20532 .6508 Mdot
.26547 .32457 Mdot
.64775 .28321 Mdot
.34833 .38897 Mdot
.67677 .52647 Mdot
.75991 .49785 Mdot
.3788 .40493 Mdot
.27027 .31072 Mdot
.40697 .76669 Mdot
.55423 .60376 Mdot
.32504 .59995 Mdot
.19562 .57783 Mdot
.31675 .34478 Mdot
.36031 .38504 Mdot
.57002 .74699 Mdot
.63303 .68851 Mdot
.39528 .22765 Mdot
.68757 .66978 Mdot
.3118 .49192 Mdot
.74355 .55487 Mdot
.71032 .45036 Mdot
.57403 .67315 Mdot
.25891 .31451 Mdot
.53967 .17391 Mdot
.57475 .58239 Mdot
.47233 .51778 Mdot
.26588 .71224 Mdot
.49636 .47782 Mdot
.70751 .56458 Mdot
.63598 .76628 Mdot
.78571 .44366 Mdot
.65317 .62875 Mdot
.53475 .49204 Mdot
.57768 .47375 Mdot
.64901 .72929 Mdot
.58465 .60629 Mdot
.36223 .73542 Mdot
.25774 .72118 Mdot
.51248 .45219 Mdot
.66581 .62097 Mdot
.32245 .3967 Mdot
.56372 .42327 Mdot
.54558 .57653 Mdot
.28984 .37764 Mdot
.62993 .58509 Mdot
.2639 .66826 Mdot
.79404 .67487 Mdot
.35842 .64787 Mdot
.36241 .25178 Mdot
.34684 .33934 Mdot
.51821 .66912 Mdot
.41022 .73408 Mdot
.77316 .48781 Mdot
.33248 .5612 Mdot
.2549 .72723 Mdot
.74354 .63369 Mdot
.31715 .37916 Mdot
.63018 .404 Mdot
.39173 .52366 Mdot
.37115 .49052 Mdot
.21524 .66352 Mdot
.64943 .71424 Mdot
.676 .8112 Mdot
.30931 .28252 Mdot
.52432 .63051 Mdot
.42358 .77503 Mdot
.21062 .39173 Mdot
.56063 .68671 Mdot
.58588 .55857 Mdot
.5208 .38965 Mdot
.20127 .41907 Mdot
.67208 .71082 Mdot
.68564 .69931 Mdot
.76657 .54101 Mdot
.41245 .83429 Mdot
.51828 .58524 Mdot
.73723 .43869 Mdot
.59052 .25427 Mdot
.39936 .57761 Mdot
.78407 .61684 Mdot
.76163 .52538 Mdot
.59856 .40443 Mdot
.4864 .59471 Mdot
.15463 .59668 Mdot
.32676 .58712 Mdot
.78262 .59533 Mdot
.66313 .81503 Mdot
.72295 .78654 Mdot
.69017 .71505 Mdot
.29879 .76896 Mdot
.68187 .70012 Mdot
.70513 .56682 Mdot
.7218 .46619 Mdot
.45871 .4669 Mdot
.47299 .66301 Mdot
.23293 .70051 Mdot
.57183 .1907 Mdot
.74993 .48297 Mdot
.40658 .6557 Mdot
.23104 .70054 Mdot
.33456 .59672 Mdot
.38327 .23672 Mdot
.59667 .386 Mdot
.25941 .28705 Mdot
.18192 .42468 Mdot
.58486 .75563 Mdot
.28109 .26551 Mdot
.37194 .22768 Mdot
.42547 .33035 Mdot
.18026 .46377 Mdot
.28629 .63241 Mdot
.58695 .74692 Mdot
.25368 .35297 Mdot
.72464 .55337 Mdot
.37162 .17704 Mdot
.54525 .5775 Mdot
.54829 .50601 Mdot
.62713 .72276 Mdot
.69032 .5566 Mdot
.71249 .63155 Mdot
.49869 .49372 Mdot
.39421 .4392 Mdot
.39039 .7697 Mdot
.83728 .51903 Mdot
.65273 .77006 Mdot
.56068 .52531 Mdot
.36661 .79662 Mdot
.77233 .47796 Mdot
.38546 .39909 Mdot
.43472 .75246 Mdot
.32349 .34757 Mdot
.59662 .25946 Mdot
.33885 .55186 Mdot
.26227 .72576 Mdot
.59514 .25921 Mdot
.35308 .78744 Mdot
.16106 .48301 Mdot
.23653 .67119 Mdot
.45867 .5934 Mdot
.56916 .26467 Mdot
.21037 .41734 Mdot
.21138 .41952 Mdot
.41776 .82296 Mdot
.35264 .24511 Mdot
.38704 .41204 Mdot
.51823 .47909 Mdot
.46688 .51178 Mdot
.31236 .48815 Mdot
.20689 .39733 Mdot
.54479 .69355 Mdot
.24808 .40534 Mdot
.7188 .7069 Mdot
.26465 .31308 Mdot
.41484 .76289 Mdot
.32177 .3561 Mdot
.56489 .40039 Mdot
.49362 .28836 Mdot
.62053 .33545 Mdot
.48648 .85436 Mdot
.78123 .53819 Mdot
.18504 .49861 Mdot
.81715 .50909 Mdot
.73876 .66301 Mdot
.33322 .25605 Mdot
.55413 .6131 Mdot
.32299 .64238 Mdot
.57902 .20718 Mdot
.26955 .36365 Mdot
.36633 .74369 Mdot
.73786 .54485 Mdot
.56466 .76932 Mdot
.23369 .69066 Mdot
.23528 .41596 Mdot
.54855 .85897 Mdot
.52964 .26182 Mdot
.49201 .74895 Mdot
.30687 .73285 Mdot
.83144 .5724 Mdot
.36127 .38189 Mdot
.35724 .80112 Mdot
.63262 .61964 Mdot
.28235 .75107 Mdot
.66388 .47931 Mdot
.48015 .23689 Mdot
.72785 .54123 Mdot
.3428 .36357 Mdot
.3456 .36512 Mdot
.17413 .53652 Mdot
.79385 .59468 Mdot
.77071 .64267 Mdot
.55556 .3877 Mdot
.58538 .36596 Mdot
.45019 .47395 Mdot
.65413 .59981 Mdot
.49775 .85267 Mdot
.4143 .51866 Mdot
.52205 .25744 Mdot
.2313 .36513 Mdot
.67628 .52569 Mdot
.56036 .50859 Mdot
.71896 .54707 Mdot
.61799 .7724 Mdot
.21981 .45287 Mdot
.40117 .83009 Mdot
.56175 .51113 Mdot
.47867 .42066 Mdot
.52725 .76261 Mdot
.63157 .5342 Mdot
.7791 .45951 Mdot
.62454 .5701 Mdot
.48328 .49038 Mdot
.35923 .42139 Mdot
.26999 .32414 Mdot
.15456 .56418 Mdot
.38607 .80858 Mdot
.78042 .45788 Mdot
.34815 .3737 Mdot
.64829 .68221 Mdot
.28055 .36369 Mdot
.53926 .86209 Mdot
.2656 .26594 Mdot
.71639 .68816 Mdot
.25847 .32376 Mdot
.61552 .41502 Mdot
.37389 .24363 Mdot
.36944 .39409 Mdot
.30421 .73042 Mdot
.41485 .64732 Mdot
.63322 .71382 Mdot
.61714 .45529 Mdot
.31657 .41106 Mdot
.58611 .50862 Mdot
.57998 .74585 Mdot
.79467 .58785 Mdot
.55045 .85829 Mdot
.34833 .23744 Mdot
.53018 .75461 Mdot
.59007 .83635 Mdot
.59524 .69063 Mdot
.58332 .476 Mdot
.66705 .38828 Mdot
.33864 .37641 Mdot
.55591 .30299 Mdot
.47938 .55911 Mdot
.40384 .42948 Mdot
.67374 .72503 Mdot
.63394 .31599 Mdot
.46847 .30169 Mdot
.57217 .62631 Mdot
.36318 .23425 Mdot
.57893 .68223 Mdot
.15625 .55517 Mdot
.65692 .59398 Mdot
.38407 .76355 Mdot
.629 .7825 Mdot
.63563 .25656 Mdot
.83181 .53665 Mdot
.24184 .68366 Mdot
.23523 .45888 Mdot
.58052 .60502 Mdot
.56579 .63411 Mdot
.6737 .68984 Mdot
.64723 .49469 Mdot
.26998 .71142 Mdot
.22172 .36968 Mdot
.65264 .28208 Mdot
.64055 .64915 Mdot
.52943 .47453 Mdot
.55051 .52392 Mdot
.18213 .57979 Mdot
.55794 .32463 Mdot
.33269 .79355 Mdot
.54509 .69844 Mdot
.80778 .61345 Mdot
.62389 .53853 Mdot
.34906 .44182 Mdot
.37294 .38128 Mdot
.64603 .29813 Mdot
.32471 .59687 Mdot
.5247 .62249 Mdot
.59348 .68096 Mdot
.58534 .49768 Mdot
.4476 .2566 Mdot
.4896 .16906 Mdot
.69225 .53078 Mdot
.51695 .68645 Mdot
.20081 .40101 Mdot
.56652 .65217 Mdot
.52971 .26547 Mdot
.61878 .24283 Mdot
.37984 .60928 Mdot
.21233 .49706 Mdot
.46467 .85189 Mdot
.25176 .68988 Mdot
.58961 .61378 Mdot
.82251 .53165 Mdot
.51028 .34328 Mdot
.17463 .56349 Mdot
.66262 .71543 Mdot
.22001 .38244 Mdot
.52073 .72269 Mdot
.19836 .63069 Mdot
.4308 .77496 Mdot
.61653 .55112 Mdot
.25313 .34489 Mdot
.52563 .42265 Mdot
.25354 .32627 Mdot
.6081 .77856 Mdot
.46763 .49165 Mdot
.25904 .29153 Mdot
.62399 .4058 Mdot
.36789 .7004 Mdot
.36114 .47759 Mdot
.61748 .53613 Mdot
.20645 .41324 Mdot
.57394 .63832 Mdot
.45363 .2432 Mdot
.42248 .65664 Mdot
.75553 .48229 Mdot
.26419 .71773 Mdot
.79566 .53384 Mdot
.23473 .35614 Mdot
.47056 .52104 Mdot
.31482 .32308 Mdot
.53863 .68353 Mdot
.25261 .45622 Mdot
.30871 .54878 Mdot
.53002 .7209 Mdot
.47798 .38988 Mdot
.18454 .54918 Mdot
.39014 .47722 Mdot
.30748 .75367 Mdot
.20341 .59635 Mdot
.66344 .72193 Mdot
.55795 .46959 Mdot
.63558 .63213 Mdot
.3336 .78939 Mdot
.20657 .47402 Mdot
.69784 .55324 Mdot
.18416 .4214 Mdot
.39628 .22282 Mdot
.60403 .83262 Mdot
.77071 .595 Mdot
.5359 .51205 Mdot
.17161 .47767 Mdot
.74294 .63958 Mdot
.3807 .22448 Mdot
.3622 .74027 Mdot
.65712 .68689 Mdot
.36196 .80819 Mdot
.30837 .64773 Mdot
.76059 .6516 Mdot
.33292 .7448 Mdot
.62259 .59605 Mdot
.20381 .48053 Mdot
.3137 .58855 Mdot
.61349 .33411 Mdot
.46055 .44689 Mdot
.28933 .25715 Mdot
.5802 .58651 Mdot
.21566 .38384 Mdot
.22046 .38477 Mdot
.34345 .26324 Mdot
.64136 .2822 Mdot
.60563 .8316 Mdot
.44135 .8003 Mdot
.35702 .4986 Mdot
.59309 .61063 Mdot
.46774 .29884 Mdot
.31059 .29306 Mdot
.36718 .51662 Mdot
.29213 .44984 Mdot
.53103 .72975 Mdot
.24442 .71569 Mdot
.57064 .41384 Mdot
.69672 .42267 Mdot
.64163 .64283 Mdot
.69592 .55552 Mdot
.56333 .69642 Mdot
.79778 .60997 Mdot
.20943 .40901 Mdot
.57653 .58242 Mdot
.61703 .56065 Mdot
.75266 .65767 Mdot
.25964 .3574 Mdot
.47649 .3589 Mdot
.71874 .48495 Mdot
.49047 .65942 Mdot
.46198 .83528 Mdot
.75769 .6412 Mdot
.55802 .57909 Mdot
.69968 .66336 Mdot
.47457 .48748 Mdot
.74724 .43875 Mdot
.79301 .59853 Mdot
.60834 .70704 Mdot
.26651 .67847 Mdot
.64925 .61029 Mdot
.56142 .26391 Mdot
.29441 .2975 Mdot
.68482 .64307 Mdot
.21154 .39489 Mdot
.3625 .60853 Mdot
.31932 .75504 Mdot
.31967 .37848 Mdot
.44699 .24098 Mdot
.32127 .53753 Mdot
.48013 .61828 Mdot
.21435 .66302 Mdot
.70461 .69494 Mdot
.45925 .61306 Mdot
.58083 .69083 Mdot
.17526 .45781 Mdot
.53798 .28084 Mdot
.53585 .32332 Mdot
.38069 .29482 Mdot
.35592 .44219 Mdot
.47478 .43195 Mdot
.65007 .50482 Mdot
.33057 .59785 Mdot
.46122 .35781 Mdot
.47752 .49799 Mdot
.4929 .66318 Mdot
.18684 .47573 Mdot
.48218 .85124 Mdot
.54652 .58973 Mdot
.17719 .42727 Mdot
.45755 .63074 Mdot
.65508 .64249 Mdot
.35559 .23366 Mdot
.42733 .63111 Mdot
.4038 .61008 Mdot
.44905 .24393 Mdot
.60444 .69454 Mdot
.47688 .84703 Mdot
.50159 .58666 Mdot
.43555 .23536 Mdot
.53834 .37299 Mdot
.52954 .57493 Mdot
.72241 .29118 Mdot
.74909 .51327 Mdot
.16973 .47215 Mdot
.24677 .35637 Mdot
.66028 .44702 Mdot
.67799 .7032 Mdot
.43382 .62945 Mdot
.3179 .75628 Mdot
.49332 .39913 Mdot
.24991 .69528 Mdot
.67971 .41053 Mdot
.50712 .68477 Mdot
.20287 .59024 Mdot
.25772 .41974 Mdot
.2543 .45157 Mdot
.55287 .74065 Mdot
.24814 .56869 Mdot
.51225 .5536 Mdot
.52267 .17734 Mdot
.35084 .19226 Mdot
.51802 .85995 Mdot
.8049 .6181 Mdot
.30448 .51387 Mdot
.27671 .3671 Mdot
.6608 .62513 Mdot
.3914 .40415 Mdot
.53732 .38319 Mdot
.54568 .26341 Mdot
.6309 .41078 Mdot
.83035 .51539 Mdot
.25375 .7247 Mdot
.32166 .53932 Mdot
.44092 .37656 Mdot
.41181 .29381 Mdot
.55224 .31808 Mdot
.3694 .67898 Mdot
.46139 .84964 Mdot
.71693 .48376 Mdot
.68007 .3803 Mdot
.65011 .5089 Mdot
.17613 .53665 Mdot
.66292 .36581 Mdot
.6706 .50619 Mdot
.15526 .55442 Mdot
.73344 .69316 Mdot
.58309 .77563 Mdot
.82438 .5031 Mdot
.18863 .56526 Mdot
.52638 .71488 Mdot
.54532 .27072 Mdot
.28558 .74561 Mdot
.37103 .38248 Mdot
.62027 .27572 Mdot
.24511 .60425 Mdot
.2535 .34025 Mdot
.3037 .28848 Mdot
.66101 .43063 Mdot
.42404 .64632 Mdot
.49444 .1547 Mdot
.63932 .25696 Mdot
.82066 .64861 Mdot
.25117 .68606 Mdot
.49154 .82447 Mdot
.68904 .70558 Mdot
.56532 .39245 Mdot
.31181 .74931 Mdot
.21963 .39273 Mdot
.44202 .63122 Mdot
.55196 .18702 Mdot
.27455 .40122 Mdot
.30035 .35599 Mdot
.73378 .42962 Mdot
.21464 .65346 Mdot
.64174 .27504 Mdot
.2744 .61681 Mdot
.24237 .3538 Mdot
.46689 .6278 Mdot
.25439 .46186 Mdot
.45173 .83163 Mdot
.2092 .49481 Mdot
.27705 .30041 Mdot
.63313 .40964 Mdot
.50854 .31624 Mdot
.47481 .84288 Mdot
.53893 .65307 Mdot
.52126 .72897 Mdot
.66632 .81374 Mdot
.30991 .77373 Mdot
.4156 .63689 Mdot
.3905 .59743 Mdot
.15644 .5226 Mdot
.52091 .29357 Mdot
.18929 .48394 Mdot
.72241 .72744 Mdot
.31331 .27523 Mdot
.42396 .48963 Mdot
.3453 .53727 Mdot
.35393 .31098 Mdot
.64894 .72225 Mdot
.43921 .63641 Mdot
.65447 .34871 Mdot
.2721 .31001 Mdot
.51964 .68636 Mdot
.79339 .67548 Mdot
.61088 .77523 Mdot
.63373 .64411 Mdot
.27251 .73643 Mdot
.31134 .66518 Mdot
.5258 .67323 Mdot
.30586 .73663 Mdot
.48485 .40694 Mdot
.4644 .35733 Mdot
.53585 .67857 Mdot
.34883 .38722 Mdot
.29159 .25316 Mdot
.58649 .8395 Mdot
.4792 .66865 Mdot
.34065 .79898 Mdot
.18802 .62719 Mdot
.63621 .64558 Mdot
.37966 .65872 Mdot
.36391 .37012 Mdot
.6153 .58773 Mdot
.62604 .44588 Mdot
.65251 .29981 Mdot
.41055 .21848 Mdot
.48037 .17305 Mdot
.36394 .53432 Mdot
.68109 .40977 Mdot
.23633 .69155 Mdot
.40411 .22608 Mdot
.24299 .70075 Mdot
.53538 .71258 Mdot
.3853 .50183 Mdot
.72747 .78365 Mdot
.70269 .56589 Mdot
.44203 .58305 Mdot
.2886 .54224 Mdot
.29223 .53009 Mdot
.33578 .56025 Mdot
.63533 .43683 Mdot
.33763 .33903 Mdot
.30456 .27452 Mdot
.28456 .74137 Mdot
.64035 .66749 Mdot
.36923 .37885 Mdot
.73533 .45863 Mdot
.30814 .42774 Mdot
.25927 .56128 Mdot
.7055 .44477 Mdot
.30826 .26263 Mdot
.72065 .29197 Mdot
.50585 .37098 Mdot
.58571 .51934 Mdot
.38081 .43811 Mdot
.57214 .54758 Mdot
.33261 .24699 Mdot
.65108 .50198 Mdot
.42793 .33125 Mdot
.23837 .3523 Mdot
.55638 .75226 Mdot
.74374 .44127 Mdot
.43312 .15128 Mdot
.36462 .38587 Mdot
.65712 .40758 Mdot
.36458 .64656 Mdot
.61916 .76263 Mdot
.26916 .69203 Mdot
.48018 .35057 Mdot
.51754 .56089 Mdot
.52227 .75854 Mdot
.29969 .74049 Mdot
.68496 .4492 Mdot
.15619 .5761 Mdot
.36064 .64356 Mdot
.3734 .68061 Mdot
.44328 .81413 Mdot
.54539 .4925 Mdot
.37237 .74577 Mdot
.31889 .50566 Mdot
.45881 .4171 Mdot
.69924 .27446 Mdot
.5614 .51924 Mdot
.53941 .57479 Mdot
.6077 .58084 Mdot
.35786 .25445 Mdot
.28416 .67562 Mdot
.36027 .57342 Mdot
.4509 .31089 Mdot
.33488 .38959 Mdot
.49765 .25901 Mdot
.50185 .25933 Mdot
.74732 .45863 Mdot
.32902 .25011 Mdot
.30916 .28337 Mdot
.34026 .74359 Mdot
.33014 .77556 Mdot
.36812 .47753 Mdot
.24781 .68068 Mdot
.54152 .40819 Mdot
.71839 .63154 Mdot
.21206 .49374 Mdot
.581 .84099 Mdot
.52685 .61326 Mdot
.30222 .50837 Mdot
.17992 .60199 Mdot
.22978 .67448 Mdot
.75229 .49035 Mdot
.73797 .5492 Mdot
.32199 .21211 Mdot
.35079 .36354 Mdot
.83376 .51705 Mdot
.64234 .37917 Mdot
.1784 .58553 Mdot
.48144 .5113 Mdot
.40198 .63993 Mdot
.5564 .72494 Mdot
.40577 .607 Mdot
.56866 .31873 Mdot
.63424 .76591 Mdot
.55498 .74296 Mdot
.25 .56125 Mdot
.36606 .49423 Mdot
.60262 .47713 Mdot
.64905 .685 Mdot
.5245 .85902 Mdot
.54824 .29925 Mdot
.47831 .41803 Mdot
.76848 .7002 Mdot
.70522 .27878 Mdot
.39236 .22043 Mdot
.40695 .8179 Mdot
.75822 .50235 Mdot
.47995 .49523 Mdot
.80289 .3988 Mdot
.64858 .63834 Mdot
.58993 .60911 Mdot
.67929 .53015 Mdot
.31903 .32498 Mdot
.78309 .60364 Mdot
.62886 .82696 Mdot
.19588 .6262 Mdot
.36873 .60915 Mdot
.85995 .58919 Mdot
.23833 .35783 Mdot
.45537 .39455 Mdot
.78569 .5912 Mdot
.25959 .72145 Mdot
.62647 .41457 Mdot
.16321 .49231 Mdot
.67689 .63377 Mdot
.64106 .60852 Mdot
.31365 .34204 Mdot
.81443 .51353 Mdot
.53101 .47845 Mdot
.82192 .64364 Mdot
.75201 .55232 Mdot
.29918 .36292 Mdot
.70094 .69429 Mdot
.63892 .61406 Mdot
.52395 .60915 Mdot
.65708 .58606 Mdot
.48007 .59375 Mdot
.56453 .57882 Mdot
.62412 .564 Mdot
.48237 .36214 Mdot
.61001 .50814 Mdot
.69397 .56387 Mdot
.70042 .52271 Mdot
.57891 .75608 Mdot
.30176 .2327 Mdot
.51578 .2642 Mdot
.55809 .34365 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2:ooooo`;o0000_Oooool001co
oooo00?o0000ooooooooool0R_ooool2o`000;gooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo0_l0002:ooooo`?o0000_Oooool001cooooo00?o0000ooooooooool0POooool2
o`0000Kooooo0ol0000Aooooo`;o0000Z_ooool001cooooo00?o0000ooooooooool0POooool2o`00
01[ooooo0_l0002Zooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo083ooooo0_l0000Jooooo`;o0000Zoooool001cooooo00?o0000ooooooooool0P?oo
ool2o`0001Sooooo1?l00005ooooo`;o0000Y?ooool001cooooo00?o0000ooooooooool0V?ooool5
o`0000?ooooo1Ol0002Tooooo`007?ooool00ol0003oooooooooo`2Hooooo`;o000000?oooooo`00
0?l000000oooool3o`000003ooooool0003o000000Kooooo0_l0002Kooooo`007?ooool00ol0003o
ooooooooo`1eooooo`;o00008Oooool2o`0000[ooooo1?l00004ooooo`;o0000Voooool001cooooo
00?o0000ooooooooool0MOooool2o`0002Cooooo0_l00009ooooo`;o000000?oooooo`000?l00000
1?ooool2o`0009Sooooo000Looooo`03o`000?oooooooooo09_ooooo0_l0000<ooooo`;o00001?oo
ool2o`0009Sooooo000Looooo`03o`000?oooooooooo0;3ooooo0_l0002Gooooo`007?ooool00ol0
003oooooooooo`2`ooooo`;o00001?ooool2o`00097ooooo00001_ooooook^k^oc8b<_l0003o<S8b
onk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`1^ooooo`;o0000=Oooool2
o`0000Wooooo0_l00004ooooo`;o0000TOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Ooo
ool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo06cooooo
1?l0000eooooo`;o0000X_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_oo
ool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo06cooooo0_l0003Kooooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0002_
ooooo`;o0000V?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00omg
MgOoIVIVooooo`05ooooo`03o`000?oooooooooo06Sooooo0_l00015ooooo`;o000000?oooooo`00
0?l00000UOooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool03Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo06Kooooo1?l00018ooooo`;o00001?ooool2o`0008oo
oooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4006
ooooo`03o`000?oooooooooo06Gooooo0ol0001@ooooo`;o00000_ooool2o`0008_ooooo00001_oo
ooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`00
0?oooooooooo06Gooooo0_l0001Eooooo`;o0000Roooool001cooooo00?o0000ooooooooool0P_oo
ool2o`0000Oooooo0_l0002looooo`007?ooool00ol0003oooooooooo`1looooo`;o00001?ooool2
o`0000Oooooo0_l0002looooo`007?ooool00ol0003oooooooooo`1hooooo`;o00000_ooool3o`00
0<[ooooo000Looooo`03o`000?oooooooooo05oooooo0_l0000Dooooo`;o000000?oooooo`000?l0
00000oooool2o`000003ooooool0003o000000cooooo0_l0002iooooo`007?ooool00ol0003ooooo
ooooo`1Oooooo`;o00005?ooool2o`0000Kooooo0_l000000ooooooo0000o`00000<ooooo`;o0000
^Oooool001cooooo00?o0000ooooooooool0GOooool3o`00013ooooo0_l0000Booooo`;o0000`ooo
ool001cooooo00?o0000ooooooooool0G?ooool4o`00013ooooo1Ol00004ooooo`;o00002Oooool2
o`0000Cooooo0_l00006ooooo`;o00001?ooool2o`000:oooooo000Looooo`03o`000?oooooooooo
05cooooo0_l0000?ooooo`;o00000oooool3o`0000Cooooo0_l00008ooooo`?o00001?ooool2o`00
00Kooooo0_l00004ooooo`;o0000[oooool001cooooo00?o0000ooooooooool0KOooool2o`0001Co
oooo0_l00008ooooo`;o00000oooool2o`00037ooooo0_l00022ooooo`007?ooool00ol0003ooooo
ooooo`1_ooooo`;o00001Oooool2o`0000Gooooo0_l0000>ooooo`So00000_ooool2o`0002cooooo
0_l00022ooooo`007?ooool00ol0003oooooooooo`1Xooooo`;o00001Oooool2o`0000Gooooo0_l0
0004ooooo`?o00003oooool7o`0000;ooooo0_l0002`ooooo`007?ooool2o`0005Wooooo0_l0000=
ooooo`?o00002?ooool2o`0000Sooooo0_l00009ooooo`;o00000_ooool9o`000003ooooool0003o
000000;o0000/?ooool001cooooo00?o0000ooooooooool0E_ooool4o`000003ooooool0003o0000
00[ooooo0_l00008ooooo`?o00001_ooool3o`0000Oooooo1Ol000000ooooooo0000o`00000>o`00
00;ooooo0_l0000Nooooo`;o0000Roooool001cooooo00?o0000ooooooooool0E_ooool2o`0000;o
oooo1Ol0000:ooooo`;o00001_ooool2o`000003ooooool0003o000000Cooooo0ol00007ooooo`?o
00000_oooolBo`000004ooooool0003o0000ooooo`;o00001Oooool2o`0001Cooooo1?l0000;oooo
o`?o0000Noooool001cooooo00?o0000ooooooooool0F_ooool5o`0000[ooooo0_l00008ooooo`?o
00001Oooool2o`0000cooooo2Ol000000ooooooo0000o`000006o`0000?ooooo0ol00005ooooo`;o
00005_ooool2o`0000_ooooo0ol0001kooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o0000
1Oooool2o`0000?ooooo0_l00007ooooo`;o000000?oooooo`000?l000001Oooool2o`0001;ooooo
0_l000000ooooooo0000o`00000@o`0000;ooooo0ol00003ooooo`;o00000_ooool2o`0000?ooooo
0_l000001?oooooo0000o`000?ooool4o`0000Oooooo0_l00029ooooo`007?ooool00ol0003ooooo
ooooo`1Booooo`Co00000_ooool2o`0000Kooooo0_l0000:ooooo`;o00001?ooool2o`0000Cooooo
0_l0000<oooooaOo000000?oooooo`000?l000001?ooool2o`0000;ooooo0_l00003ooooo`;o0000
00Coooooo`000?l0003ooooo1?l0000Eooooo`;o000000?oooooo`000?l00000N?ooool001cooooo
00?o0000ooooooooool0D_ooool3o`0000?ooooo0_l0000Hooooo`;o00001?ooool2o`0000Oooooo
0_l00003oooooaOo00002oooool2o`0000?ooooo0_l000000ooooooo0000o`000009ooooo`;o0000
3oooool2o`000003ooooool0003o000007Sooooo000Looooo`03o`000?oooooooooo06Gooooo0_l0
000;ooooo`;o00001?ooool2o`0000Oooooo0_l00003oooooaGo00004_ooool5o`0000?ooooo0_l0
0004ooooo`;o0000S?ooool001cooooo00?o0000ooooooooool0Coooool4o`0000cooooo0_l00000
1?oooooo0000o`000?ooool2o`0000_ooooo0_l00004ooooo`;o00001_ooool2o`0000?ooooo5ol0
0004ooooo`;o00002Oooool2o`0000;ooooo0ol00002ooooo`?o00000_ooool3o`0000[ooooo0_l0
0005ooooo`;o00003_ooool4o`0006Sooooo000Looooo`03o`000?oooooooooo04oooooo1?l00003
ooooo`;o00001_ooool3o`000003ooooool0003o000001cooooo0_l00003oooooaSo00000oooool2
o`0000Kooooo0_l000001?oooooo0000o`000?l00006ooooo`;o00000oooool6o`0000Oooooo0_l0
0005ooooo`;o00000_ooool2o`0000Sooooo2?l0001Vooooo`007?ooool00ol0003oooooooooo`1D
ooooo`Co00001_ooool5o`0001oooooo0_l000000ooooooo0000o`000006o`000003ooooool0003o
000000go00002Oooool4o`000004ooooool0003o0000o`0000Cooooo0_l00003ooooo`Co000000Co
ooooo`000?l0003o00001oooool2o`0000Gooooo1_l00008ooooo`;o000000Coooooo`000?l0003o
oooo0_l0001Vooooo`007?ooool00ol0003oooooooooo`1Booooo`Ko00001oooool4o`0001oooooo
0_l000000ooooooo0000o`00000Do`0000_ooooo0_l00003ooooo`?o00001?ooool;o`0000Wooooo
0ol00004ooooo`Ko0000M_ooool001cooooo00?o0000ooooooooool0D?ooool4o`000003ooooool0
003o000000Sooooo1?l0000Eooooo`;o00002_oooolHo`000003ooooool0003o000000gooooo4ol0
0008ooooo`;o0000P?ooool001cooooo00?o0000ooooooooool0C_ooool6o`000003ooooool0003o
000000Sooooo0ol0000Fooooo`;o00002_oooolHo`000003ooooool0003o000000gooooo5?l0000V
ooooo`?o0000H?ooool001cooooo00?o0000ooooooooool0C_ooool4o`0000;ooooo0_l0000:oooo
o`?o00005Oooool2o`000003ooooool0003o000000Gooooo0ol000000ooooooo0000o`00000Co`00
00[ooooo0_l00003oooooa_o00000oooool2o`0000Gooooo0_l0000Eooooo`?o0000H?ooool001co
oooo00?o0000ooooooooool0E?ooool2o`0000Kooooo0_l00003ooooo`?o00003Oooool2o`0000Go
oooo0_l000000ooooooo0000o`000005oooooaWo00001?ooool4o`0000;ooooo0_l00003oooooa7o
00000_ooool8o`0000?ooooo0_l00004ooooo`?o00008?ooool2o`0005Kooooo000Looooo`;o0000
Eoooool2o`0000Cooooo0_l00002ooooo`Co00002oooool4o`0000Sooooo0_l00006ooooo`Ko0000
00?oooooo`000?l000002ol000001?oooooo0000o`000?l00004ooooo`Go00002Oooool=o`000003
ooooool0003o000000[o00001oooool5o`0001kooooo0ol0001Eooooo`007?ooool00ol0003ooooo
ooooo`1Dooooo`Co00001oooool3o`0000cooooo0ol0000:ooooo`?o00001_ooool3o`0000Gooooo
3_l00008ooooo`;o00002Oooool=o`000003ooooool0003o000000[o00002?ooool4o`0001Oooooo
0ol00005ooooo`?o0000E?ooool001cooooo00?o0000ooooooooool0E?ooool3o`0000;ooooo0_l0
0004ooooo`;o00003Oooool2o`0000cooooo0_l00005ooooo`Co00000_ooool2o`0000Cooooo0_l0
00000ooooooo0000o`000006o`00017ooooo3?l00003ooooo`_o000000?oooooo`000?l000001ooo
ool2o`0000[ooooo0_l0000=ooooo`?o00001_ooool2o`0005Cooooo000Looooo`03o`000?oooooo
oooo05Cooooo0ol00002ooooo`;o00000_ooool2o`0000oooooo0_l0000:ooooo`;o00001_ooool3
o`0000Cooooo1?l00002ooooo`;o000000Coooooo`000?l0003ooooo1?l0000Boooooa[o000000?o
ooooo`000?l000000_l00007ooooo`;o00002?ooool2o`00017ooooo0_l00003ooooo`;o0000E?oo
ool001cooooo00?o0000ooooooooool0DOooool6o`0000Kooooo0_l0000@ooooo`;o00002Oooool3
o`0000Cooooo0ol000000ooooooo0000o`000004ooooo`;o00000_ooool8o`0001Kooooo5_l00000
0ooooooo0000o`000004o`0000Kooooo0ol0000Kooooo`;o0000FOooool001cooooo00?o0000oooo
ooooool0D?ooool4o`0000Gooooo1?l0000Booooo`;o00002_ooool2o`0000Cooooo0_l00002oooo
o`;o00000oooool3o`0000?ooooo0ol000001?oooooo0000o`000?l00009ooooo`Co00002_oooolJ
o`0000;ooooo0_l00004ooooo`Co0000MOooool001cooooo00?o0000ooooooooool0D?ooool2o`00
00Oooooo1?l0000Aooooo`;o00003?ooool2o`0000cooooo0ol00003ooooo`;o00003_ooool4o`00
00[ooooo7_l00006ooooo`;o0000MOooool001cooooo00?o0000ooooooooool0F_ooool2o`0000Oo
oooo0_l00008ooooo`?o00003?ooool2o`0001;ooooo0_l0000=ooooo`;o00003?oooolMo`0007oo
oooo000Looooo`03o`000?oooooooooo04oooooo0ol000001?oooooo0000o`000?l0000=ooooo`?o
00001oooool2o`0001Sooooo0_l0000Fooooo`;o00002OoooolNo`0000[ooooo0_l0000Sooooo`?o
0000Coooool001cooooo00?o0000ooooooooool0COooool5o`000004ooooool0003o0000o`0000ko
oooo0_l00006ooooo`Co00005oooool2o`0001Kooooo0_l00009oooooako00002_ooool2o`0002?o
oooo0ol0001?ooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00001?ooool2o`0001Kooooo
1Ol0000Fooooo`Co00005Oooool2o`0000cooooo7?l00009ooooo`;o0000MOooool001cooooo00?o
0000ooooooooool0C?ooool2o`0000Gooooo0_l0000Eooooo`Co000000?oooooo`000?l000003ooo
ool2o`0000Cooooo1?l0000Eooooo`;o00002_ooool7o`000003ooooool0003o000001Co00002Ooo
ool2o`0002Gooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`1;ooooo`?o00003_ooool2
o`0000_ooooo1?l00002ooooo`;o00003oooool2o`0000Wooooo1Ol0000Kooooo`Ko00000_oooolE
o`0000Oooooo0_l0000Xooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0Boooool6o`00
00_ooooo0_l0000:ooooo`Oo00004Oooool2o`0000Wooooo1Ol0000Looooo`;o00000_ooool2o`00
0003ooooool0003o000001?o00001oooool2o`0002Sooooo0ol0001=ooooo`007?ooool00ol0003o
ooooooooo`1=ooooo`Co00004Oooool3o`0000;ooooo2?l0000Aooooo`;o00002oooool3o`0000?o
oooo0_l0000=ooooo`;o00003?oooolHo`0003;ooooo0_l0001=ooooo`007?ooool00ol0003ooooo
ooooo`1:ooooo`;o00000oooool2o`00017ooooo1ol00004ooooo`;o000000?oooooo`000?l00000
6oooool3o`0000?ooooo0ol000000ooooooo0000o`000009ooooo`;o00003?oooolHo`00087ooooo
000Looooo`;o0000Boooool2o`0000?ooooo0_l00006ooooo`;o00003?ooool3o`0000Gooooo0_l0
00000ooooooo0000o`00000?ooooo`;o00004Oooool2o`000003ooooool0003o000000;o00005_oo
oolHo`0000Sooooo0_l0000Vooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0B_ooool3
o`0000;ooooo0_l00006ooooo`;o00003Oooool2o`0000Gooooo0_l0000Booooo`;o00004oooool5
o`0000;ooooo0_l0000BoooooaSo00002?ooool2o`0002Kooooo1?l0001<ooooo`007?ooool00ol0
003oooooooooo`17ooooo`[o00002oooool4o`0000Gooooo0ol00005ooooo`;o00004_ooool4o`00
00;ooooo0_l0000=ooooo`Co00000oooool4o`0001;ooooo5Ol0000cooooo`;o0000C?ooool001co
oooo00?o0000ooooooooool0Aoooool9o`000003ooooool0003o000000;o00000oooool2o`0000;o
oooo1?l00005ooooo`;o00001_ooool2o`0001?ooooo0ol000001?oooooo0000o`000?l00009oooo
o`?o00000_ooool3o`0000;ooooo1Ol000001?oooooo0000o`000?l0000?oooooa;o0000Poooool0
01cooooo00?o0000ooooooooool0Aoooool2o`000003ooooool0003o000000;o00000oooool4o`00
0003ooooool0003o000000;o00000oooool3o`0000Gooooo0_l0000Oooooo`Co00002?ooool3o`00
00;ooooo1?l000001?oooooo0000o`000?l00003ooooo`?o00003oooool@o`0000gooooo1Ol00004
ooooo`;o0000KOooool001cooooo00?o0000ooooooooool0Aoooool2o`0000[ooooo1_l00004oooo
o`?o00001?ooool2o`0000Kooooo1?l0000Hooooo`;o00000_ooool2o`0000_ooooo0_l000000ooo
oooo0000o`000003ooooo`Go000000?oooooo`000?l000003?ooool4o`000003ooooool0003o0000
00So000000?oooooo`000?l000000_l00002ooooo`?o00000oooool5o`0000Cooooo0_l0001]oooo
o`007?ooool00ol0003oooooooooo`17ooooo`;o00002_ooool6o`0000Oooooo1_l00006ooooo`Co
00006_ooool4o`0001?ooooo2?l000000ooooooo0000o`000002o`0000Sooooo1_l000000ooooooo
0000o`000003o`0000?ooooo1?l00002ooooo`?o00001_ooool2o`0002Sooooo0_l00019ooooo`00
7?ooool00ol0003oooooooooo`14ooooo`;o00004?ooool2o`0000Gooooo2?l0000=ooooo`;o0000
5_ooool4o`0001;ooooo0ol00002ooooo`;o000000?oooooo`000?l000001?l00008ooooo`Co0000
3oooool2o`0000Kooooo0_l0000[ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0@ooo
ool3o`0001;ooooo3Ol00008ooooo`;o00000oooool2o`0001[ooooo0_l00009ooooo`;o00001Ooo
ool3o`0000?ooooo1?l000000ooooooo0000o`00000Eooooo`;o000000?oooooo`000?l000000_oo
ool2o`000003ooooool0003o000000Go0000M_ooool001cooooo00?o0000ooooooooool0@oooool2
o`0000;ooooo0_l0000>ooooo`[o00000oooool2o`0000Cooooo0_l000000ooooooo0000o`000007
ooooo`;o00004oooool2o`000004ooooool0003o0000ooooo`;o00001_ooool2o`0000_ooooo1?l0
00000ooooooo0000o`00000?ooooo`Co00000_ooool2o`000003ooooool0003o000000Cooooo1ol0
000[ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0Aoooool2o`0000kooooo1Ol00000
0ooooooo0000o`000004ooooo`?o00001?ooool4o`0000Kooooo1?l0000Cooooo`;o00001?ooool2
o`0001Cooooo0ol0000Booooo`Co00000_ooool3o`0000;ooooo0_l000000ooooooo0000o`000005
o`0000Sooooo0_l0000Rooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0@_ooool4o`00
00kooooo0_l00007ooooo`;o00001?ooool2o`0000Gooooo1?l00004ooooo`Go0000=?ooool2o`00
013ooooo0ol00003ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`000003ooooool0003o
000000;o00002?ooool2o`0006kooooo000Looooo`03o`000?oooooooooo04;ooooo1?l0000>oooo
o`;o00003oooool2o`0000Oooooo0_l000000ooooooo0000o`000004o`0001Wooooo0_l00004oooo
o`;o00002oooool2o`0000Kooooo0_l00004ooooo`Co00002Oooool3o`0000Gooooo0ol0000goooo
o`;o0000Aoooool001cooooo00?o0000ooooooooool0E?ooool2o`0000oooooo0_l00002ooooo`?o
000000Goooooo`000?l0003o0000ooooo`04o`0001_ooooo0_l00004ooooo`Co00002Oooool4o`00
00[ooooo1?l00009ooooo`?o00000oooool2o`000003ooooool0003o000000Gooooo0_l00005oooo
o`;o0000:Oooool2o`0004Oooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46
ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`11ooooo`;o000000?ooooo
o`000?l000003Oooool3o`0001?ooooo0ol000000ooooooo0000o`000005ooooo`;o00008Oooool5
o`0000Wooooo0_l0000:ooooo`;o000000?oooooo`000?l000000oooool2o`0000Wooooo0_l00008
ooooo`;o00001Oooool2o`0007;ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ
8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0?Oooool2o`0000;ooooo0_l0
00000ooooooo0000o`000004ooooo`;o00001oooool2o`0000gooooo1Ol00006ooooo`Co00000ooo
ool2o`0001[ooooo0_l00005ooooo`;o000000?oooooo`000?l000006?ooool2o`0000?ooooo0_l0
00000ooooooo0000o`00002;ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09
ooooo`Go00001_ooool00ol0003oooooooooo`0mooooo`;o000000Coooooo`000?l0003o00001ooo
ool2o`0000Kooooo0ol0000=ooooo`So00000oooool6o`0000Kooooo0_l0000Eooooo`;o00002_oo
ool2o`0001kooooo0_l00013ooooo`;o0000A_ooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool02Oooool01?m4A4CogMgMooooool00007ooooo`?o0000?_ooool4o`00013ooooo1Ol0
0009ooooo`;o00001Oooool3o`000003ooooool0003o000000Cooooo0_l00006ooooo`;o00000ooo
ool2o`0001cooooo0_l0000Fooooo`;o00004_ooool2o`0003Oooooo0_l00016ooooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o
0000ooooooooool0?_ooool2o`0000gooooo0_l00003ooooo`;o000000?oooooo`000?l000002Ooo
ool8o`0000?ooooo0ol00008ooooo`?o00000_ooool2o`000003ooooool0003o000003Cooooo0_l0
0009ooooo`;o00001_ooool4o`0000gooooo1?l0001]ooooo`0000?ooooooa0@4?ooool00_ooool0
0ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0@?ooool2
o`0000?ooooo0_l00006ooooo`;o000000?oooooo`000?l000002?ooool2o`0000;ooooo3?l00002
ooooo`;o00002?ooool3o`0000;ooooo0_l0000Mooooo`;o00004?ooool2o`00017ooooo0_l00006
ooooo`Co00001oooool4o`0000;ooooo1?l0001]ooooo`0000KoooooogMgMonHV9SooooooiRHV?mg
MgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0@?ooool2o`0000?ooooo0_l0
0004ooooo`;o00000_ooool3o`0000Sooooo0_l00002ooooo`?o00000_ooool9o`000003ooooool0
003o000000Oooooo1_l00005ooooo`;o00005oooool2o`0000Gooooo0_l00009ooooo`;o00006ooo
ool6o`0000?ooooo1?l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l0001Xooooo`0000Ko
ooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000oooooooo
ool0?oooool2o`0000Oooooo0_l000000ooooooo0000o`000002ooooo`?o000000?oooooo`000?l0
00003_ooool<o`000004ooooool0003o0000o`0000Gooooo1?l00004ooooo`?o00003Oooool2o`00
00oooooo0_l0000Cooooo`;o00003?ooool2o`0000;ooooo1ol0000:ooooo`;o000000Coooooo`00
0?l0003ooooo0_l0001Xooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00001Oooool4o`00
00Gooooo0ol00003ooooo`;o00000oooool4o`0000Cooooo0_l00006ooooo`[o00000_ooool6o`00
00Cooooo0ol00004ooooo`;o00003_ooool3o`0000Gooooo0_l0000:ooooo`?o000000?oooooo`00
0?l000000_l0000:ooooo`;o00003?ooool2o`0000;ooooo0ol0000>ooooo`;o0000K_ooool001co
oooo00?o0000ooooooooool0>?ooool2o`0000Cooooo0_l000000ooooooo0000o`000006ooooo`Co
000000?oooooo`000?l000000_l00003ooooo`;o00000oooool3o`0000Oooooo2?l000000ooooooo
0000o`000007o`0000Cooooo0ol00005ooooo`;o00003Oooool2o`0000Gooooo0_l0000:ooooo`So
00006?ooool7o`0000kooooo0_l00003ooooo`;o00001?ooool2o`000003ooooool0003o000003Go
oooo0_l0000Yooooo`007?ooool00ol0003oooooooooo`0gooooo`?o00001?ooool2o`000003oooo
ool0003o000000;o00001_ooool3o`0000;ooooo0_l00003ooooo`;o00000oooool2o`0000Wooooo
1Ol00002ooooo`_o00001?ooool2o`0000Gooooo0_l0000>ooooo`;o00001?ooool2o`0000cooooo
0ol0000:ooooo`;o00001?ooool2o`0000[ooooo1?l0000Eooooo`?o000000?oooooo`000?l00000
0_l000000ooooooo0000o`00000eooooo`;o0000:Oooool001cooooo00?o0000ooooooooool0=_oo
ool3o`0000[ooooo0_l00007ooooo`;o00001Oooool4o`0000?ooooo0_l00002ooooo`Co00001Ooo
ool3o`0000;ooooo1Ol000001?oooooo0000o`000?ooool2o`0000Kooooo0_l0000Cooooo`;o0000
4oooool2o`0000[ooooo0_l00004ooooo`;o00004?ooool2o`0001;ooooo0_l000000ooooooo0000
o`00000Looooo`;o00007?ooool2o`0002Wooooo000Looooo`03o`000?oooooooooo03Kooooo0_l0
0006ooooo`;o00004Oooool6o`000003ooooool0003o000000?o000000?oooooo`000?l000000_l0
0003ooooo`;o00001?ooool5o`0000Cooooo1?l00005ooooo`Co00000oooool2o`000003ooooool0
003o000000;ooooo0_l0000Jooooo`;o00000oooool2o`0001[ooooo1Ol00006ooooo`;o00000_oo
ool2o`0000cooooo0_l00004ooooo`;o00004oooool4o`0004Gooooo000Looooo`03o`000?oooooo
oooo03Kooooo0_l00006ooooo`;o00002?ooool3o`000003ooooool0003o000000?ooooo1Ol00002
ooooo`Go00002?ooool2o`0000Cooooo1?l000000ooooooo0000o`000007o`0000Kooooo0_l00003
ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Wooooo1?l0000=ooooo`?o00000_ooool2
o`0001[ooooo1?l00007ooooo`;o00000_ooool2o`0000Sooooo0_l00002ooooo`Go000000?ooooo
o`000?l000005Oooool2o`0004Gooooo000Looooo`03o`000?oooooooooo03Kooooo0_l0000@oooo
o`?o000000?oooooo`000?l000000_ooool3o`000003ooooool0003o000000Cooooo0_l0000Coooo
o`[o00000oooool3o`0000Cooooo0_l000000ooooooo0000o`000009ooooo`?o00000_ooool4o`00
00kooooo0_l0000Pooooo`?o00003_ooool5o`000003ooooool0003o000000Cooooo0ol0000Foooo
o`;o0000Aoooool001cooooo00?o0000ooooooooool0>oooool2o`0000?ooooo0_l000000ooooooo
0000o`000003ooooo`;o00001_ooool2o`000003ooooool0003o0000017ooooo0_l00007ooooo`;o
00001Oooool4o`000003ooooool0003o000000;o00001?ooool2o`000003ooooool0003o000000Wo
oooo1Ol0000Dooooo`?o00007_ooool2o`0000kooooo1ol0000:ooooo`;o000000?oooooo`000?l0
00003oooool2o`0004Oooooo000Looooo`03o`000?oooooooooo03_ooooo0_l00003ooooo`;o0000
00?oooooo`000?l000000_l00006ooooo`Co00000_ooool2o`0000Wooooo0_l000001?oooooo0000
o`000?l00002ooooo`;o00001_ooool4o`0000Cooooo1?l000001?oooooo0000o`000?l00007oooo
o`;o00003Oooool2o`0000_ooooo1?l00005ooooo`?o00006Oooool2o`0000;ooooo0_l0000:oooo
o`;o00001?ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000001Oooool6o`00
05Sooooo000Looooo`03o`000?oooooooooo04Gooooo0_l00006ooooo`Co00000_ooool2o`0000Wo
oooo1_l0000:ooooo`Co00004oooool2o`0001[ooooo1Ol00005ooooo`?o00006?ooool6o`0000[o
oooo1_l000000ooooooo0000o`000002ooooo`Ko00001?ooool2o`000004ooooool0003o0000oooo
o`;o00002?ooool2o`0004cooooo000Looooo`03o`000?oooooooooo04Gooooo0_l00005ooooo`?o
00000_ooool4o`0000[ooooo0_l0000Uooooo`;o000000?oooooo`000?l000000_l000000ooooooo
0000o`000002ooooo`;o00002oooool7o`0000Gooooo0ol0000Jooooo`Co00001oooool<o`000003
ooooool0003o000000Go00001?ooool3o`0000?ooooo0_l00007ooooo`?o00001?ooool2o`0004Ko
oooo000Looooo`;o0000A_ooool2o`0000Cooooo2?l00007ooooo`?o0000:Oooool2o`000003oooo
ool0003o000000;o000000?oooooo`000?l000000_ooool2o`0000[ooooo2_l0000Rooooo`;o0000
1ooooolEo`0000Cooooo0_l00003ooooo`;o00001oooool2o`0000Gooooo0_l00016ooooo`007?oo
ool00ol0003oooooooooo`14ooooo`;o00001Oooool2o`0000;ooooo1?l00007ooooo`?o0000?ooo
ool6o`000004ooooool0003o0000ooooo`;o00001oooool2o`0001Cooooo0_l00002ooooo`;o0000
1?ooool2o`0000;ooooo5Ol00003ooooo`?o00002_ooool2o`0002Oooooo0_l0000Vooooo`007?oo
ool00ol0003oooooooooo`0eooooo`;o00003Oooool2o`0000;ooooo0_l00004ooooo`Go00001Ooo
ool2o`0002oooooo0ol0000?ooooo`Ko00001Oooool3o`0000Kooooo0_l0000Dooooo`;o000000Co
ooooo`000?l0003o00001?ooool2o`0000;ooooo5?l00004ooooo`;o00000_ooool2o`0000;ooooo
0_l00003ooooo`Co00009Oooool2o`0002Kooooo000Looooo`03o`000?oooooooooo03Gooooo0_l0
000:ooooo`;o00001Oooool:o`0000?ooooo0_l000000ooooooo0000o`00000_ooooo`?o000000Co
ooooo`000?l0003o00002_ooool6o`0000Oooooo1?l00006ooooo`;o00005Oooool3o`0000Cooooo
0_l000000ooooooo0000o`00000Co`0000Cooooo0_l00002ooooo`;o00000_ooool2o`0000Cooooo
0ol0001=ooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00002?ooool2o`0000;ooooo0_l0
00000ooooooo0000o`000008o`0000?ooooo0_l0000dooooo`So00001?ooool9o`0000Oooooo1Ol0
0005ooooo`;o00007?ooool2o`000003ooooool0003o000001?o00001_ooool2o`0000Cooooo0_l0
0004ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0=_ooool4o`0000_ooooo0_l00000
0ooooooo0000o`00000:o`000003ooooool0003o000003Cooooo0_l000000ooooooo0000o`000003
o`000003ooooool0003o000000So00001Oooool2o`0000Cooooo1Ol0000Hooooo`;o00002OoooolH
o`0000;ooooo1?l0000=ooooo`;o00008_ooool2o`0002Oooooo000Looooo`03o`000?oooooooooo
03Kooooo1?l00006ooooo`;o00000_ooool2o`000003ooooool0003o000000Co000000?oooooo`00
0?l000000_ooool2o`0003gooooo0_l000001?oooooo0000o`000?l0000<ooooo`?o00001?ooool4
o`0000?ooooo1?l0000Aooooo`?o00001ooooolFo`000003ooooool0003o000000;ooooo1?l0000=
ooooo`Go00007oooool2o`0002Oooooo000Looooo`03o`000?oooooooooo03?ooooo0_l0000:oooo
o`?o00000_ooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`00000noooo
o`;o00001oooool3o`0000Oooooo0_l000000ooooooo0000o`000006ooooo`Co000000?oooooo`00
0?l000000ol00002ooooo`;o00003?ooool3o`0000Oooooo4?l000000ooooooo0000o`000005o`00
00;ooooo1Ol0000?ooooo`?o0000B?ooool001cooooo00?o0000ooooooooool0<oooool3o`0000?o
oooo0_l00004ooooo`;o00000oooool2o`000003ooooool0003o000003;ooooo0_l0000Aooooo`;o
00000oooool3o`000004ooooool0003o0000o`0000?ooooo0_l00002ooooo`;o00001Oooool2o`00
00Cooooo0ol00003ooooo`?o000000?oooooo`000?l000000_l00004ooooo`;o00001?ooool3o`00
00?ooooo0_l00002oooooa3o000000?oooooo`000?l000001Ol00002ooooo`Co00000oooool2o`00
00?ooooo0ol0000Vooooo`;o0000:?ooool001cooooo00?o0000ooooooooool0=?ooool2o`0000;o
oooo0ol0000]ooooo`;o000000?oooooo`000?l000001Oooool4o`0000Gooooo0_l0000Aooooo`;o
00000oooool3o`000003ooooool0003o000000Ko00001_ooool2o`000004ooooool0003o0000o`00
00?ooooo0ol00003ooooo`?o00000oooool2o`0000Cooooo0_l0000:oooooa_o00000oooool4o`00
0003ooooool0003o000000;o00000oooool3o`0002Kooooo0_l0000Xooooo`007?ooool00ol0003o
ooooooooo`0aooooo`;o000000?oooooo`000?l000000_ooool2o`0000Gooooo0_l0000Wooooo`;o
000000?oooooo`000?l000001Oooool4o`0000Gooooo0_l000000ooooooo0000o`00000>ooooo`;o
00001?ooool5o`000003ooooool0003o000000?o00001_ooool2o`0000;ooooo0_l00002ooooo`;o
00001Oooool3o`0000gooooo0_l00008ooooob3o000000?oooooo`000?l000000ol00003ooooo`Co
00009?ooool2o`0002Sooooo000Looooo`03o`000?oooooooooo037ooooo0_l00007ooooo`;o0000
0oooool4o`0000?ooooo0_l0000fooooo`;o00000_ooool2o`00013ooooo1Ol0000Dooooo`;o0000
0oooool2o`00013ooooo0_l0000:ooooo`Wo000000Goooooo`000?l0003o0000ooooo`0=o`0000Go
oooo1_l00003ooooo`?o00008oooool2o`0002Sooooo000Looooo`03o`000?oooooooooo03Sooooo
1?l00004ooooo`?o00000oooool2o`0001[ooooo0_l00006ooooo`;o00001oooool5o`0000[ooooo
0_l0000Booooo`;o00005_ooool6o`0001cooooo6ol00005ooooo`?o000000Coooooo`000?l0003o
oooo1Ol0000Rooooo`;o0000:Oooool001cooooo00?o0000ooooooooool0<Oooool2o`0000Gooooo
0_l00006ooooo`;o00000_ooool2o`0001cooooo0_l00006ooooo`;o000000Coooooo`000?l0003o
00000oooool9o`0000Kooooo0_l00002ooooo`;o00003?ooool4o`000003ooooool0003o000000oo
oooo0_l000000ooooooo0000o`000003o`0000Gooooo0_l000000ooooooo0000o`000008ooooo`;o
00002_oooolJo`0000;ooooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l0000Uooooo`;o
0000:Oooool001cooooo00?o0000ooooooooool0<Oooool2o`0000gooooo1_l0000Looooo`;o0000
1_ooool2o`000004ooooool0003o0000o`0000?ooooo2Ol00002ooooo`;o00001_ooool2o`0000co
oooo0_l00002ooooo`?o00000oooool2o`0000[ooooo0_l000000ooooooo0000o`000004ooooo`;o
00000_ooool2o`000003ooooool0003o000000Sooooo0_l00006ooooo`Co00000_ooool=o`000003
ooooool0003o000000Oo00000_ooool3o`000003ooooool0003o000000;o00001?ooool2o`0000?o
oooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o000000?oooooo`000?l00000
0oooool5o`0002Gooooo0_l00004ooooo`;o000000?oooooo`000?l000001?l00002ooooo`;o0000
00?oooooo`000?l000000_l00009ooooo`;o00002_ooool3o`0000Cooooo0_l00004ooooo`;o0000
00?oooooo`000?l000002_ooool2o`000005ooooool0003o0000o`000?ooool00_l0000:ooooo`;o
00001?ooool4o`0000?ooooo3?l000000ooooooo0000o`000006o`0000?ooooo0_l00006ooooo`;o
00001oooool2o`0001oooooo0_l0000Zooooo`007?ooool2o`0002oooooo0_l00008ooooo`;o0000
00?oooooo`000?l000001?ooool4o`00027ooooo0_l00002ooooo`;o00000oooool4o`0000;ooooo
2?l00003ooooo`;o00002?ooool3o`0000[ooooo0_l0000;ooooo`;o000000?oooooo`000?l00000
2_ooool2o`000005ooooool0003o0000o`000?ooool00_l0000:ooooo`;o00001?ooool2o`0000Go
oooo0ol000000ooooooo0000o`00000?o`0000_ooooo0_l00006ooooo`;o00008?ooool2o`0002[o
oooo000Looooo`03o`000?oooooooooo02kooooo1?l00009ooooo`;o00001?ooool2o`00023ooooo
1Ol00002ooooo`;o00000_ooool9o`0000;ooooo1_l000000ooooooo0000o`000008ooooo`?o0000
1_ooool2o`0001kooooo0ol000000ooooooo0000o`00000Fooooo`?o000000Goooooo`000?l0003o
0000ooooo`02o`000003ooooool0003o000000Oo00002oooool2o`0000;ooooo0_l00007ooooo`;o
00001oooool2o`0000;ooooo0ol0000Aooooo`;o0000:oooool001cooooo00?o0000ooooooooool0
<?ooool2o`0000Sooooo0_l00005ooooo`;o00007_ooool5o`0000;ooooo1?l00002ooooo`[o0000
00?oooooo`000?l000002Ol00007ooooo`;o00001_ooool3o`0001Sooooo0_l00004ooooo`;o0000
00?oooooo`000?l000000oooool2o`0000oooooo1Ol00004ooooo`?o000000Coooooo`000?l0003o
00000oooool3o`0000_ooooo0_l00002ooooo`;o00001Oooool2o`0000Wooooo0_l000000ooooooo
0000o`000002o`00017ooooo0_l0000[ooooo`007?ooool00ol0003oooooooooo`0jooooo`;o0000
8_ooool2o`000003ooooool0003o000000Co000000Coooooo`000?l0003ooooo3Ol00002ooooo`[o
00004?ooool2o`0001Sooooo0_l00002ooooo`Co000000Goooooo`000?l0003o0000ooooo`03o`00
00Cooooo0_l00009ooooo`Co00001Oooool3o`000003ooooool0003o000000?ooooo1?l0000<oooo
o`;o00000oooool2o`0000?ooooo0_l0000;ooooo`?o00004oooool2o`0002_ooooo000Looooo`03
o`000?oooooooooo03Wooooo0_l0000Sooooo`Go00000_ooool2o`0000Cooooo3ol000000ooooooo
0000o`000007o`00013ooooo0_l00003ooooo`;o00003oooool2o`0000;ooooo0_l00002ooooo`Co
000000Goooooo`000?l0003o0000ooooo`02o`0000Gooooo0_l00006ooooo`;o00000oooool2o`00
00Gooooo0_l00007ooooo`Co00001_ooool2o`0000Cooooo0ol00002ooooo`;o00000oooool2o`00
00Gooooo0_l00003ooooo`?o00001Oooool2o`0003[ooooo000Looooo`03o`000?oooooooooo03Wo
oooo0_l00002ooooo`;o00007_ooool6o`0000Gooooo5?l00002ooooo`Oo000000Coooooo`000?l0
003ooooo0_l00009ooooo`;o00000oooool2o`0000oooooo0_l00002ooooo`;o00001Oooool5o`00
013ooooo0_l0000:ooooo`;o00003Oooool2o`0000;ooooo0_l00004ooooo`Co00003Oooool2o`00
00?ooooo0_l00003ooooo`Go00002oooool2o`0002gooooo000Looooo`03o`000?oooooooooo03Wo
oooo0_l00002ooooo`;o000000?oooooo`000?l000006oooool2o`0000Sooooo1?l000000ooooooo
0000o`00000Go`000004ooooool0003o0000ooooo`;o00000oooool2o`0000Cooooo1?l0000Koooo
o`Co000000?oooooo`000?l000000_l0000Cooooo`;o00005?ooool2o`0000Sooooo1?l00005oooo
o`;o00004?ooool4o`0000cooooo0_l0000]ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o
00000oooool2o`0000;ooooo0ol00005ooooo`;o00006_ooool3o`0000Kooooo8Ol00002ooooo`;o
00001?ooool2o`0000Gooooo0ol0000Kooooo`Co000000?oooooo`000?l000000_l0000Cooooo`;o
000000?oooooo`000?l000003?ooool2o`0000gooooo1?l00005ooooo`;o00004_ooool2o`0003_o
oooo000Looooo`03o`000?oooooooooo02oooooo0_l00003ooooo`;o00000_ooool2o`0001gooooo
0_l00003ooooo`?o00001_oooolUo`000003ooooool0003o000000Sooooo0_l00002ooooo`;o0000
3?ooool2o`0000;ooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo
0000o`00000Gooooo`?o00001?ooool2o`0000Kooooo0_l0000>ooooo`;o00000_ooool4o`0001?o
oooo0_l0000looooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00002?ooool2o`0001cooooo
0_l0000;ooooo`Co000000?oooooo`000?l000000_l000000ooooooo0000o`000002o`0000;ooooo
5?l000000ooooooo0000o`000002o`0000cooooo0_l0000<ooooo`;o00000_ooool2o`0000;ooooo
0_l000000ooooooo0000o`000004ooooo`;o00005oooool2o`0000Gooooo0_l0000;ooooo`;o0000
00?oooooo`000?l000000ol000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000;o
00001oooool4o`0000;ooooo0_l00002ooooo`Co0000??ooool001cooooo00?o0000ooooooooool0
;oooool2o`0000Sooooo0_l0000Nooooo`Go00001_ooool9o`000003ooooool0003o000000;o0000
00?oooooo`000?l000004ol000001?oooooo0000o`000?l00004ooooo`;o00000_ooool2o`0002;o
oooo0_l0000:ooooo`;o00004_ooool3o`0000;ooooo0_l00005ooooo`?o000000?oooooo`000?l0
00000ol000001?oooooo0000o`000?ooool2o`0000Kooooo0_l00004ooooo`Go000000?oooooo`00
0?l000001?l0000nooooo`007?ooool00ol0003oooooooooo`1Iooooo`Go00001OoooolVo`000003
ooooool0003o000000Cooooo0_l00002ooooo`;o00008_ooool2o`0000[ooooo0_l00003ooooo`;o
00002oooool9o`0000Gooooo0_l00004ooooo`;o00000_ooool2o`000003ooooool0003o000000Ko
oooo0_l00004ooooo`;o000000?oooooo`000?l000000_ooool3o`0000Cooooo0_l00009ooooo`;o
0000;oooool001cooooo00?o0000ooooooooool0=Oooool3o`0002?ooooo0_l00006ooooob;o0000
00?oooooo`000?l000001_l00002ooooo`;o00004oooool4o`00013ooooo0_l0000:ooooo`Oo0000
2_ooool8o`0000Cooooo1?l00002ooooo`;o00000oooool4o`0000Wooooo0_l00003ooooo`;o0000
2Oooool2o`000003ooooool0003o000000Wooooo0_l0000_ooooo`007?ooool00ol0003ooooooooo
o`0eooooo`?o0000:_ooool7o`000003ooooool0003o000002;o00000_ooool2o`00013ooooo2Ol0
0003ooooo`;o00001oooool4o`0000[ooooo1?l000001?oooooo0000o`000?l0000Eooooo`;o0000
1?ooool9o`0000?ooooo0ol00003ooooo`;o00003_ooool2o`000003ooooool0003o000003[ooooo
000Looooo`03o`000?oooooooooo05[ooooo0_l00006oooooa;o000000?oooooo`000?l000003ol0
00000ooooooo0000o`000004o`0000_ooooo0_l00004ooooo`oo000000?oooooo`000?l000001ooo
ool2o`0001;ooooo0_l0000Looooo`So00000oooool3o`0005;ooooo000Looooo`03o`000?oooooo
oooo05Oooooo0_l000000ooooooo0000o`000005ooooob;o00000_ooool7o`0000Oooooo0_l00002
ooooo`?o00000ooooolCo`0000Kooooo0ol0000]ooooo`;o00000oooool6o`0005Sooooo000Loooo
o`;o0000>Oooool2o`0001gooooo0_l00008ooooob;o00000_ooool7o`000003ooooool0003o0000
00Cooooo0_l00002ooooo`;o00001?oooolCo`0000Kooooo0ol0000;ooooo`;o00003oooool2o`00
00oooooo0_l00003ooooo`?o0000Foooool001cooooo00?o0000ooooooooool0;oooool2o`0000Oo
oooo0_l0000Looooo`Co00001ooooolQo`0000;ooooo0ol000000ooooooo0000o`000002o`000004
ooooool0003o0000o`0000[ooooo6?l0000Booooo`;o00003oooool3o`0000Oooooo0_l00007oooo
o`;o00000_ooool2o`0000;ooooo0_l00004ooooo`;o0000DOooool001cooooo00?o0000oooooooo
ool0;oooool2o`0002Gooooo1?l00007ooooob_o000000Coooooo`000?l0003o00002_ooool4o`00
0003ooooool0003o0000017o00000_ooool4o`0001kooooo0_l00004ooooo`Go00001oooool2o`00
00Cooooo1?l00004ooooo`;o00007_ooool2o`00037ooooo000Looooo`03o`000?oooooooooo02oo
oooo0_l0000Mooooo`;o00001oooool2o`0000Sooooo;ol00008ooooo`Ko00000oooool?o`0000Co
oooo1?l00003ooooo`;o00006oooool2o`0000;ooooo1Ol00009ooooo`;o00000_ooool2o`0002Go
oooo0ol0000aooooo`007?ooool00ol0003oooooooooo`0eooooo`;o00000_ooool2o`0001;ooooo
1_l000001?oooooo0000o`000?ooool2o`0000Oooooo1_l000000ooooooo0000o`00000Ro`000003
ooooool0003o000000;o00001oooool4o`0000Oooooo5?l00003ooooo`Co00002?ooool2o`00017o
oooo0_l0000@ooooo`Co00009oooool2o`0003;ooooo000Looooo`03o`000?oooooooooo02oooooo
0_l00002ooooo`Co00000_ooool3o`00017ooooo0_l000001Ooooooo0000o`000?l0003ooooo00Go
00001oooool6o`0000;ooooo8ol000000ooooooo0000o`000003ooooo`Co000000?oooooo`000?l0
00000_l00003ooooo`;o00001OoooolAo`0000Cooooo0_l00009ooooo`Ko00003_ooool3o`0000?o
oooo1_l00008ooooo`;o0000Foooool001cooooo00?o0000ooooooooool0;oooool2o`0000;ooooo
1?l00003ooooo`;o00004Oooool2o`0000Gooooo0ol00009ooooo`Co00001?oooolUo`0000Cooooo
1?l000000ooooooo0000o`000005ooooo`;o00001oooool?o`0000oooooo1_l0000?ooooo`;o0000
0oooool6o`0000?ooooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00001Ooo
ool2o`0000Cooooo0_l0000@ooooo`;o00001?ooool3o`0000[ooooo1?l00004ooooobGo00001ooo
ool4o`00013ooooo2_l0000Eooooo`;o00005Oooool2o`000003ooooool0003o000000Cooooo0_l0
000Qooooo`?o0000??ooool001cooooo00?o0000ooooooooool0;_ooool2o`0000_ooooo0_l0000?
ooooo`;o00001Oooool3o`0000[ooooo1?l00003ooooobCo00002Oooool4o`0000_ooooo0_l00003
ooooo`;o000000?oooooo`000?l000006_ooool2o`0001Gooooo0_l000000ooooooo0000o`00000W
ooooo`?o00001oooool2o`0003?ooooo000Looooo`03o`000?oooooooooo02oooooo0_l0000:oooo
o`?o00003_ooool2o`0001;ooooo1?l00003oooooaoo000000?oooooo`000?l000000_l00007oooo
o`Go00003?ooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`0000Gooooo0_l0000[oooo
o`;o0000<Oooool2o`0003?ooooo000Looooo`03o`000?oooooooooo02oooooo0_l00003ooooo`;o
000000?oooooo`000?l000000_ooool3o`0001Gooooo0ol0000:ooooo`Co00001OoooolMo`000003
ooooool0003o000000Sooooo1?l00003ooooo`;o00002oooool2o`0000Kooooo0_l00002ooooo`;o
000000?oooooo`000?l000003?ooool2o`0008Gooooo000Looooo`03o`000?oooooooooo03Cooooo
0_l000000ooooooo0000o`000003ooooo`Co00004oooool3o`0000[ooooo1?l000000ooooooo0000
o`000003oooooako00001?ooool2o`0000;ooooo1?l00004ooooo`;o00001?ooool2o`0000Gooooo
0_l0000:ooooo`;o00001?ooool2o`0000Wooooo0_l00005ooooo`;o0000O_ooool001cooooo00?o
0000ooooooooool0=_ooool2o`0000Cooooo1?l0000Booooo`;o00003Oooool3o`000003ooooool0
003o000000;o00000_oooolEo`000003ooooool0003o000000Ko00000oooool2o`0000;ooooo0ol0
0008ooooo`Ko00001?ooool2o`0000?ooooo0_l0000;ooooo`Co00001oooool4o`0000?ooooo0_l0
0007ooooo`;o0000:_ooool2o`0001?ooooo0_l0000dooooo`007?ooool00ol0003oooooooooo`0f
ooooo`;o00001?ooool4o`0001;ooooo0_l0000=ooooo`?o00000_ooool3o`0000;ooooo5?l00002
ooooo`Co00000_ooool2o`0000;ooooo1_l0000:ooooo`Ko00001?ooool2o`0000?ooooo0_l00002
ooooo`;o00002Oooool2o`0000Wooooo0_l0000<ooooo`;o00009?ooool2o`000003ooooool0003o
000000?o00000oooool2o`0000kooooo0ol0000cooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^
k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0
?_ooool2o`00027ooooo1?l00008ooooo`Oo000000?oooooo`000?l000000_ooool2o`0000Kooooo
1?l00006ooooo`So00001Oooool2o`0000_ooooo0_l00003ooooo`;o00000_ooool2o`0001Cooooo
0_l0000<ooooo`;o00009?ooool7o`0000Cooooo0_l0000<ooooo`;o000000?oooooo`000?l00000
<oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMgMooo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo02oooooo0_l0000=ooooo`;o00004oooool2o`00
00kooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo2Ol00003ooooo`Wo00002oooool2
o`000003ooooool0003o000000Gooooo1?l00009ooooo`;o00003oooool4o`0000;ooooo0_l00006
ooooo`Co00002_ooool2o`0002?ooooo1Ol00002ooooo`?o000000?oooooo`000?l000003Oooool2
o`0003Kooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo02oooooo0_l0000=ooooo`;o00004oooool3
o`0000gooooo2?l00006ooooo`Ko000000?oooooo`000?l000001ol0000:ooooo`?o00003?ooool2
o`0000Gooooo0_l00004ooooo`;o000000?oooooo`000?l000000oooool3o`0000;ooooo1ol00000
0ooooooo0000o`000005ooooo`Go00002Oooool3o`0001kooooo0_l00003ooooo`Go000000?ooooo
o`000?l000000_l000000ooooooo0000o`000015ooooo`0000?oooooo`000?ooool00_ooool00ol0
003oooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0003Oooooo0_l00005
ooooo`;o00005?ooool2o`0000gooooo2?l000000ooooooo0000o`000004ooooo`Go000000?ooooo
o`000?l000000ol00007ooooo`?o000000?oooooo`000?l000001?l0000<ooooo`?o00001?ooool2
o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`Oo00000oooool2o`0000Sooooo0ol0000;
ooooo`?o00007_ooool3o`0000Sooooo0ol00019ooooo`0000?oooooo`000?ooool00_ooool00ol0
003oooooooooo`09ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0g
ooooo`;o00004oooool2o`0001Gooooo2ol0000Booooo`;o00000_ooool3o`000003ooooool0003o
000000;o00003oooool2o`0000[ooooo0_l00002ooooo`;o00000oooool4o`000003ooooool0003o
000000Go00000oooool4o`000003ooooool0003o000000Kooooo0_l0000Uooooo`;o00001_ooool6
o`000003ooooool0003o000004Gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo
00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`10ooooo`?o00002Oooool2o`00
00Oooooo0_l0000>ooooo`Wo00001?ooool4o`0000;ooooo0_l00006ooooo`Co000000Coooooo`00
0?l0003ooooo0ol00005ooooo`;o00001_ooool2o`0000Kooooo0_l00004ooooo`?o00000_ooool2
o`0000?ooooo0_l00003ooooo`Wo000000?oooooo`000?l000001Ol000000ooooooo0000o`000003
ooooo`;o0000;Oooool9o`0004Gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00?o
gMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`10ooooo`?o00004_ooool2o`0000oooooo0_l0
00000ooooooo0000o`000005o`0000;ooooo1?l00002ooooo`;o00001Oooool5o`000004ooooool0
003o0000o`0000Sooooo0_l00006ooooo`;o00001?ooool4o`0000Cooooo0_l00007ooooo`;o0000
1?ooool3o`0000Cooooo0ol00003ooooo`Co000000?oooooo`000?l000000_ooool3o`000003oooo
ool0003o000002_ooooo0_l000001?oooooo0000o`000?l00017ooooo`0000Koooooonk^k_lb<S;o
0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0@Oooool2
o`0001?ooooo0_l0000Booooo`co00001?ooool2o`0000?ooooo2Ol00008ooooo`?o00002oooool2
o`0000Oooooo0_l00006ooooo`?o00000oooool3o`0000Cooooo2Ol000001?oooooo0000o`000?l0
0002ooooo`?o000000?oooooo`000?l00000:_ooool3o`000005ooooool0003o0000o`000?ooool0
0_l0000:ooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0Coooool3o`0000?ooooo0ol0
000Dooooo`[o000000?oooooo`000?l000000ol000000ooooooo0000o`000007o`0000Oooooo0_l0
0002ooooo`;o00001Oooool2o`0000gooooo0_l00007ooooo`;o00000_ooool6o`000003ooooool0
003o000000_o00001?ooool2o`0002gooooo0ol00004ooooo`?o00002Oooool3o`0003Sooooo000L
ooooo`03o`000?oooooooooo03Wooooo0_l0000Dooooo`?o00000oooool2o`0001[ooooo4_l0000:
ooooo`;o00002Oooool2o`0000oooooo0_l00009oooooaCo00000_ooool2o`0000Sooooo0_l0000H
ooooo`;o00002_ooool5o`0000?ooooo0_l0000:ooooo`;o0000>Oooool001cooooo00?o0000oooo
ooooool0>Oooool2o`0003Oooooo3?l0000<ooooo`;o00006oooool4o`0000Wooooo6?l000000ooo
oooo0000o`000004ooooo`?o00005Oooool2o`000003ooooool0003o000000[ooooo1Ol0001:oooo
o`007?ooool00ol0003oooooooooo`0iooooo`;o000000?oooooo`000?l00000C?ooool2o`0000Co
oooo0_l00002ooooo`;o00004Oooool2o`0000gooooo5Ol00002ooooo`?o00000oooool2o`0001Ko
oooo0_l0000>ooooo`;o00003oooool2o`0003_ooooo000Looooo`03o`000?oooooooooo03Wooooo
0_l000001?oooooo0000o`000?l00018ooooo`Co000000Coooooo`000?l0003ooooo1?l000000ooo
oooo0000o`00000Aooooo`;o00002oooool?o`000003ooooool0003o000000Go00000_ooool7o`00
00oooooo0_l0000Fooooo`;o00003oooool2o`0003_ooooo000Looooo`03o`000?oooooooooo03go
oooo0_l0000Jooooo`;o00001Oooool2o`00027ooooo0_l00002ooooo`Co000000Coooooo`000?l0
003ooooo1?l0000Dooooo`;o00002oooool3o`000003ooooool0003o000001[o00001?ooool2o`00
00Wooooo1Ol00006ooooo`;o00002_ooool3o`0004cooooo000Looooo`03o`000?oooooooooo04go
oooo0_l0000:ooooo`;o00001Oooool2o`00027ooooo0_l00006ooooo`Go00007?ooool2o`0000Ko
oooo7?l00008ooooo`;o00002_ooool4o`0000Kooooo0_l0000:ooooo`;o0000COooool001cooooo
00?o0000ooooooooool0COooool2o`00033ooooo0_l00002ooooo`;o00001_ooool2o`000003oooo
ool0003o000001cooooo0ol00005oooooago00007Oooool2o`0000Cooooo0_l00004ooooo`;o0000
COooool001cooooo00?o0000ooooooooool0=Oooool2o`0001Kooooo0_l0000:ooooo`Co00002?oo
ool2o`0000[ooooo0_l0000<ooooo`;o00002_ooool2o`00023ooooo0_l00004ooooo`?o000000?o
ooooo`000?l000006_l00008ooooo`;o00004Oooool2o`0000;ooooo2?l0001?ooooo`007?ooool0
0ol0003oooooooooo`0eooooo`;o00008_ooool4o`0000Cooooo0_l00002ooooo`;o00002_ooool4
o`0000Oooooo0_l000000ooooooo0000o`000005ooooo`;o00000oooool2o`0002Kooooo8?l00006
ooooo`Co00003oooool2o`0000Cooooo0ol000000ooooooo0000o`000002o`0000gooooo0ol0000o
ooooo`007?ooool00ol0003oooooooooo`0looooo`;o00007Oooool3o`0000;ooooo1?l0000=oooo
o`Co00001oooool2o`0000Gooooo0_l000000ooooooo0000o`00000[oooooako00000_ooool2o`00
00Cooooo0_l0000Aooooo`;o00001Oooool4o`00013ooooo0ol0000oooooo`007?ooool2o`0003Oo
oooo0_l00004ooooo`;o000000?oooooo`000?l000004oooool2o`0000Gooooo0ol00002ooooo`Co
00002_ooool2o`000003ooooool0003o000000_ooooo0ol00002ooooo`;o000000?oooooo`000?l0
0000;?ooool3o`000003ooooool0003o000001Ko00000oooool2o`0001kooooo1?l0000@ooooo`;o
0000@?ooool001cooooo00?o0000ooooooooool0=_ooool2o`0000Oooooo1Ol0000@ooooo`;o0000
3?ooool2o`0000[ooooo0_l0000:ooooo`;o00000_ooool4o`0000Cooooo0_l0000Sooooo`;o0000
1oooool3o`000003ooooool0003o000001Ko00005?ooool2o`0000gooooo0_l0001Dooooo`007?oo
ool00ol0003oooooooooo`10ooooo`Co0000;oooool2o`0000?ooooo1?l00002ooooo`Co00000ooo
ool3o`00013ooooo1_l0000=ooooo`;o00000oooool2o`0000?ooooo0ol000000ooooooo0000o`00
000:o`000003ooooool0003o000000So00005?ooool2o`0000[ooooo0ol00005ooooo`;o0000Cooo
ool001cooooo00?o0000ooooooooool0KOooool2o`0000Cooooo0_l00003ooooo`Co00002Oooool3
o`00013ooooo2Ol0000?ooooo`;o00001?ooool2o`000003ooooool0003o000001Go00000oooool2
o`0001Sooooo1_l00005ooooo`;o0000Coooool001cooooo00?o0000ooooooooool0@_ooool2o`00
01Oooooo0_l00004ooooo`;o00002_ooool2o`0000Wooooo1?l0000Jooooo`;o00001?ooool5o`00
00;ooooo0_l000000ooooooo0000o`00000=ooooo`Co00000_oooolBo`000003ooooool0003o0000
00?ooooo0_l0000:ooooo`;o00002oooool7o`0000?ooooo0_l0001Aooooo`007?ooool00ol0003o
ooooooooo`0oooooo`;o000000?oooooo`000?l000003_ooool2o`0000Oooooo0_l00004ooooo`;o
000000?oooooo`000?l000002Oooool2o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`;o
00005Oooool3o`0000Cooooo0_l00005ooooo`;o000000?oooooo`000?l000002?ooool2o`0000?o
oooo1?l000000ooooooo0000o`00000?o`000003ooooool0003o000000?o00000_ooool2o`0000[o
oooo0_l0000:ooooo`Co000000?oooooo`000?l000000_l00002ooooo`;o0000DOooool001cooooo
00?o0000ooooooooool0?oooool2o`000003ooooool0003o000000Gooooo0_l00007ooooo`;o0000
4?ooool2o`0000;ooooo0_l00005ooooo`;o00001?ooool2o`0000?ooooo0ol000000ooooooo0000
o`00000Dooooo`?o000000?oooooo`000?l000002_ooool3o`0000Wooooo0_l00005oooooa[o0000
0oooool2o`0000Kooooo0_l0000=ooooo`Co000000?oooooo`000?l000000_l0001Eooooo`007?oo
ool00ol0003oooooooooo`17ooooo`Co00002_ooool2o`00017ooooo0_l0000@ooooo`?o00005ooo
ool3o`000003ooooool0003o000000[ooooo1Ol0000>ooooo`co000000?oooooo`000?l000001ol0
00000ooooooo0000o`000004ooooo`Co00001?ooool2o`0000kooooo0_l00002ooooo`;o0000Eooo
ool001cooooo00?o0000ooooooooool0Aoooool2o`0000cooooo1_l0000jooooo`;o00004?ooool2
o`0000kooooo5Ol0000:ooooo`;o00004?ooool2o`000003ooooool0003o000000;ooooo0ol0000<
ooooo`?o0000B?ooool001cooooo00?o0000ooooooooool0A_ooool3o`0000[ooooo0_l00002oooo
o`Co00006Oooool2o`0001oooooo0_l0000Cooooo`;o00002?ooool2o`000003ooooool0003o0000
01;o000000?oooooo`000?l000000oooool2o`0001Gooooo1Ol000001?oooooo0000o`000?l0000=
ooooo`?o0000B?ooool001cooooo00?o0000ooooooooool0A_ooool2o`0000?ooooo1?l00004oooo
o`;o00007oooool4o`0001gooooo1?l0000Aooooo`?o00001Oooool4o`000003ooooool0003o0000
01;o000000?oooooo`000?l000001Ol0000Fooooo`;o000000?oooooo`000?l000000_l0001Ioooo
o`007?ooool00ol0003oooooooooo`1;ooooo`Go00009_ooool4o`0001gooooo0_l00008ooooo`;o
000000Coooooo`000?l0003o00001?ooool2o`0000Gooooo1?l00002oooooa_o00002_ooool2o`00
00Oooooo1?l00002ooooo`;o00003?ooool2o`0004gooooo000Looooo`03o`000?oooooooooo04co
oooo1?l0000=ooooo`;o00006?ooool3o`0002Oooooo0_l000001?oooooo0000o`000?l00004oooo
o`Co00000oooool4o`0000Cooooo3Ol000000ooooooo0000o`000004o`000003ooooool0003o0000
00?o00001Oooool2o`0000;ooooo0_l00006ooooo`Go00004?ooool2o`0004gooooo000Looooo`03
o`000?oooooooooo04Sooooo0ol00003ooooo`;o00001?ooool2o`0000Oooooo0_l0000Cooooo`;o
0000>?ooool3o`0000Kooooo0_l00002ooooo`;o000000?oooooo`000?l000002Ol000000ooooooo
0000o`000003o`0000Cooooo0ol00003ooooo`Co00002_ooool2o`0006;ooooo000Looooo`03o`00
0?oooooooooo04Sooooo0ol00002ooooo`?o00001?ooool2o`0001cooooo0_l0000iooooo`;o0000
1_ooool2o`0000;ooooo2ol00006ooooo`;o00001?ooool3o`0000Cooooo0_l00007ooooo`Go0000
1Oooool3o`0005cooooo000Looooo`03o`000?oooooooooo04gooooo0_l0000Pooooo`Co000000?o
ooooo`000?l00000=oooool3o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo1?l0
0002ooooo`Wo000000Coooooo`000?l0003o00001?ooool2o`0000Sooooo1Ol00005ooooo`?o0000
2_ooool2o`00053ooooo000Looooo`;o0000B?ooool3o`000003ooooool0003o000002;ooooo1?l0
00000ooooooo0000o`00000cooooo`;o00000_ooool3o`0000?ooooo0_l00002ooooo`;o00001ooo
ool3o`0000;ooooo1Ol00002ooooo`;o000000?oooooo`000?l000001Oooool2o`0000;ooooo0ol0
0009ooooo`;o00003_ooool3o`00053ooooo000Looooo`03o`000?oooooooooo04Oooooo0ol00000
0ooooooo0000o`00000Aooooo`;o00000_ooool2o`0000kooooo1?l0000Xooooo`?o00002?ooool2
o`0000;ooooo0_l0000Eooooo`Go00003?ooool2o`000003ooooool0003o000000?o00000_ooool3
o`0000Cooooo0_l0000>ooooo`;o0000DOooool001cooooo00?o0000ooooooooool0G_ooool2o`00
00;ooooo0_l0000>ooooo`;o0000:?ooool5o`0000cooooo0_l000000ooooooo0000o`00000@oooo
o`Go00001Oooool4o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo1_l00000
1?oooooo0000o`000?ooool2o`00067ooooo000Looooo`03o`000?oooooooooo04oooooo0_l0000=
ooooo`Co00004?ooool2o`0002Sooooo0ol0000Aooooo`;o00002Oooool2o`0000Gooooo0_l00002
ooooo`;o00001?ooool4o`0000;ooooo0_l00003ooooo`;o00000oooool4o`000003ooooool0003o
000000;o000000?oooooo`000?l000002Oooool2o`0005Kooooo000Looooo`03o`000?oooooooooo
04oooooo0_l00002ooooo`?o00002?ooool4o`0000Oooooo0_l00007ooooo`Co00009?ooool2o`00
00cooooo1?l00004ooooo`Co00001oooool2o`0000Wooooo2ol00006ooooo`;o00002?ooool2o`00
00kooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00001Oooool3o`0000co
oooo0_l00005ooooo`;o00001oooool4o`000003ooooool0003o0000027ooooo0_l0000;ooooo`Go
00001?ooool4o`00013ooooo0_l00002ooooo`Wo00000_ooool2o`0000Oooooo0ol0000?ooooo`;o
0000FOooool001cooooo00?o0000ooooooooool0C?ooool2o`0000Cooooo0_l0000>ooooo`;o0000
0_ooool2o`0000Cooooo0_l00009ooooo`Co0000;?ooool2o`0000Oooooo0_l000000ooooooo0000
o`00000?ooooo`;o00003Oooool2o`0000Cooooo0_l000001?oooooo0000o`000?l0000>ooooo`?o
0000FOooool001cooooo00?o0000ooooooooool0D?ooool5o`00017ooooo0_l00004ooooo`;o0000
2?ooool2o`000003ooooool0003o000002Gooooo0_l000000ooooooo0000o`000002o`000003oooo
ool0003o000000Wooooo1?l0000Aooooo`?o00001?ooool2o`000003ooooool0003o000000Oo0000
3oooool5o`0005[ooooo000Looooo`03o`000?oooooooooo04oooooo1_l0000>ooooo`;o00002?oo
ool3o`0000Kooooo0_l0000Xooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`00
0007ooooo`;o000000?oooooo`000?l000000_l0000@ooooo`?o00001?ooool2o`000003ooooool0
003o000000Go00004Oooool3o`0005cooooo000Looooo`03o`000?oooooooooo04oooooo1?l0000@
ooooo`;o00002?ooool3o`0003Kooooo0_l000000ooooooo0000o`000006ooooo`;o00000oooool4
o`0000[ooooo0_l00009ooooo`;o00001_ooool2o`0000kooooo0_l0001Pooooo`007?ooool00ol0
003oooooooooo`1?ooooo`;o00002?ooool2o`0000Cooooo0ol00009ooooo`;o00000_ooool2o`00
00oooooo0_l0000Pooooo`;o00000_ooool2o`000004ooooool0003o0000o`0000_ooooo0ol0000:
ooooo`;o00002Oooool2o`0001Gooooo0ol0001Pooooo`007?ooool00ol0003oooooooooo`1Ioooo
o`;o00001?ooool3o`0000Kooooo0_l000000ooooooo0000o`000007o`0000cooooo1?l0000Moooo
o`Go00001?ooool4o`0003;ooooo0_l00004ooooo`;o0000HOooool001cooooo00?o0000oooooooo
ool0EOooool2o`0000Gooooo0_l00002ooooo`;o00001_ooool2o`0000?ooooo0ol000001?oooooo
0000o`000?l0000>ooooo`?o00007?ooool5o`0000Kooooo0_l0000@ooooo`Co00007?ooool4o`00
06Oooooo000Looooo`03o`000?oooooooooo05Gooooo0_l00002ooooo`;o000000?oooooo`000?l0
00001?l0000<ooooo`;o00000_ooool2o`0000[ooooo0_l00003ooooo`;o00008_ooool2o`0000Oo
oooo0_l0000<ooooo`Co00000_ooool3o`000003ooooool0003o000001;ooooo1_l0001Wooooo`00
7?ooool00ol0003oooooooooo`1Iooooo`;o00000oooool2o`0000;ooooo0_l00004ooooo`Go0000
1Oooool5o`0000Oooooo0_l0000Wooooo`;o00001oooool3o`00017ooooo0ol000001?oooooo0000
o`000?ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000001?l00003ooooo`;o
0000Joooool001cooooo00?o0000ooooooooool0Eoooool4o`0000Oooooo0_l00004ooooo`Go0000
1Oooool6o`0002oooooo0_l00008ooooo`;o00000_ooool2o`0000;ooooo1?l0000;ooooo`;o0000
00Coooooo`000?l0003ooooo1?l000000ooooooo0000o`000004o`00073ooooo000Looooo`;o0000
F?ooool4o`0000Oooooo0_l0000Aooooo`Co00000oooool3o`0001gooooo0_l0000=ooooo`;o0000
2?ooool2o`0000;ooooo1?l0000Fooooo`;o0000M?ooool001cooooo00?o0000ooooooooool0F?oo
ool2o`0000Kooooo1?l00006ooooo`;o000000?oooooo`000?l000002?ooool4o`000004ooooool0
003o0000o`0000[ooooo0_l0000Aooooo`;o00001oooool4o`000003ooooool0003o000000;o0000
0oooool2o`0000;ooooo0_l00012ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0F?oo
ool2o`0000Kooooo0_l00002ooooo`;o00001?ooool2o`000003ooooool0003o000000;o00001Ooo
ool2o`000003ooooool0003o000000Ko00002?ooool2o`00017ooooo0ol00004ooooo`_o00000ooo
ool2o`0000Gooooo1?l0000mooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0F?ooool2
o`0000[ooooo0_l00008ooooo`?o00001Oooool2o`000003ooooool0003o000000So00000oooool2
o`0000?ooooo0_l0000?ooooo`?o00001?ooool2o`000003ooooool0003o000000;o00000_ooool2
o`0000Cooooo0_l00004ooooo`Co00001_ooool2o`0008Gooooo000Looooo`03o`000?oooooooooo
07Kooooo1Ol00003ooooo`Oo000000?oooooo`000?l000000_l000000ooooooo0000o`00000Ioooo
o`Go000000?oooooo`000?l000000_l00002ooooo`;o00003_ooool2o`000003ooooool0003o0000
00Sooooo0_l0001hooooo`007?ooool00ol0003oooooooooo`1Rooooo`;o00000_ooool2o`00013o
oooo0ol00004ooooo`Ko00000oooool2o`000003ooooool0003o000001Kooooo0_l00003ooooo`?o
000000?oooooo`000?l000000_l0000Eooooo`;o00000oooool3o`0000;ooooo0_l0001hooooo`00
7?ooool00ol0003oooooooooo`1Mooooo`;o00000oooool2o`0000;ooooo1?l0000Aooooo`;o0000
0oooool3o`0000?ooooo0_l00004ooooo`?o00004_ooool4o`0000?ooooo1?l000000ooooooo0000
o`000005ooooo`?o00001Oooool2o`0000cooooo0ol0001looooo`007?ooool00ol0003ooooooooo
o`1Mooooo`Co00001oooool2o`0000Wooooo0_l00006ooooo`;o00001?ooool2o`0000?ooooo0_l0
0004ooooo`?o00004_ooool2o`0000Oooooo1Ol00005ooooo`?o00001Oooool3o`0000Kooooo0_l0
0009ooooo`;o00008?ooool2o`0005Gooooo000Looooo`03o`000?oooooooooo05oooooo1?l00005
ooooo`;o00002Oooool2o`0000Sooooo1_l00003ooooo`Co00005oooool2o`0000Oooooo0ol00007
ooooo`?o00000oooool5o`0000Cooooo1?l00009ooooo`;o00007Oooool5o`0005Gooooo000Loooo
o`03o`000?oooooooooo05oooooo1Ol00004ooooo`;o00002Oooool4o`0000Kooooo1?l00005oooo
o`Co00004Oooool2o`0000Cooooo0_l0000;ooooo`?o00000oooool2o`0000?ooooo1Ol00004oooo
o`?o0000:_ooool3o`0005Oooooo000Looooo`03o`000?oooooooooo067ooooo0ol0000?ooooo`So
00008?ooool2o`0000Oooooo0_l00008ooooo`Ko000000?oooooo`000?l000001ol00004ooooo`;o
0000QOooool001cooooo00?o0000ooooooooool0MOooool6o`00023ooooo0ol00004ooooo`Co0000
2_ooool4o`000003ooooool0003o000000;o00000_ooool2o`0000cooooo0_l0000Mooooo`;o0000
Goooool001cooooo00?o0000ooooooooool0Joooool2o`0000;ooooo0_l00004ooooo`;o00000ooo
ool2o`00023ooooo0_l00004ooooo`;o00009Oooool2o`0001cooooo0ol0001Oooooo`007?ooool0
0ol0003oooooooooo`1Yooooo`Co00000_ooool2o`0000Wooooo0_l0001[ooooo`;o0000H?ooool0
0006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Q
olc<c006ooooo`03o`000?oooooooooo06Sooooo0ol0000Xooooo`;o00003?ooool2o`000:Kooooo
00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRH
V?lQ8B401_ooool00ol0003oooooooooo`1Xooooo`;o00002Oooool2o`0000gooooo0_l0000?oooo
o`;o00002oooool3o`000:Kooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wo
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo06_ooooo0_l000001Ooo
oooo0000o`000?l0003ooooo00?o00002?ooool2o`0000?ooooo0_l00008ooooo`;o00004_ooool3
o`000:Kooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRH
V?ooooooV9RHoc8b<P06ooooo`?o0000Joooool2o`000003ooooool0003o000000Co00002Oooool2
o`000003ooooool0003o000000Gooooo0_l00002ooooo`?o00004_ooool2o`000:Oooooo00000ooo
oooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Goc<c<o`000?l0003o0000olc<c006
ooooo`03o`000?oooooooooo073ooooo0_l0000>ooooo`;o00001Oooool2o`0000;ooooo0_l00003
ooooo`;o00000oooool2o`0000Wooooo0ol00003ooooo`;o0000XOooool00003ooooool@413ooooo
00;ooooo00?o410@ooooooooool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000
ooooooooool0L?ooool4o`0000Kooooo0_l0000;ooooo`;o00001oooool2o`0000?ooooo0_l0000:
ooooo`;o00000oooool2o`000:7ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go
0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo07;ooooo0_l00006ooooo`;o0000
2oooool2o`0000;ooooo0_l0000Iooooo`;o0000<?ooool2o`0006oooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo
07;ooooo0_l0000Gooooo`Go00003oooool2o`0003?ooooo1_l0001_ooooo`007?ooool00ol0003o
ooooooooo`1booooo`;o00003?ooool2o`0000[ooooo1_l0000;ooooo`Co0000<?ooool2o`000003
ooooool0003o000000;o0000LOooool001cooooo00?o0000ooooooooool0Ooooool3o`0000kooooo
0_l000000ooooooo0000o`000003o`0000;ooooo0_l000000ooooooo0000o`000003o`0002gooooo
1?l0001fooooo`007?ooool00ol0003oooooooooo`1oooooo`;o00000oooool2o`0000gooooo1Ol0
0002ooooo`So0000;Oooool2o`0007Sooooo000Looooo`03o`000?oooooooooo08Cooooo0_l0000F
ooooo`;o00000_ooool2o`0002Kooooo0_l0001oooooo`007?ooool00ol0003oooooooooo`1koooo
o`;o00000_ooool2o`0004?ooooo0_l00002ooooo`;o0000Ooooool001cooooo00?o0000oooooooo
ool0Noooool2o`0000;ooooo0_l000000ooooooo0000o`00000;ooooo`;o0000;oooool3o`000003
ooooool0003o000008?ooooo000Looooo`03o`000?oooooooooo08;ooooo0_l0000;ooooo`;o0000
00?oooooo`000?l00000:?ooool2o`000003ooooool0003o000000;o0000Q_ooool001cooooo00?o
0000ooooooooool0Poooool2o`0000gooooo0_l0000Wooooo`?o000000?oooooo`000?l00000R?oo
ool001cooooo00?o0000ooooooooool0Poooool2o`00017ooooo0_l0000Qooooo`Co0000S?ooool0
01cooooo00?o0000ooooooooool0U_ooool2o`00027ooooo0ol0002=ooooo`007?ooool00ol0003o
ooooooooo`26ooooo`;o00001Oooool2o`0000?ooooo0_l00003ooooo`Co00007?ooool2o`00093o
oooo000Looooo`;o0000Qoooool2o`0000Gooooo0_l00003ooooo`?o00000_ooool6o`000003oooo
ool0003o000001Oooooo0_l0002@ooooo`007?ooool00ol0003oooooooooo`2Cooooo`;o00001?oo
ool4o`000003ooooool0003o00000:Wooooo000Looooo`03o`000?oooooooooo09[ooooo0_l00006
ooooo`;o00000oooool2o`0000Gooooo0ol00002ooooo`;o0000U?ooool001cooooo00?o0000oooo
ooooool0X_ooool2o`000003ooooool0003o000000;o00000_ooool2o`000004ooooool0003o0000
o`0000;ooooo0_l0002Dooooo`007?ooool00ol0003oooooooooo`2Sooooo`Go00000oooool5o`00
09Wooooo000Looooo`03o`000?oooooooooo0:;ooooo1Ol00006ooooo`?o0000VOooool001cooooo
00?o0000ooooooooool0X_ooool2o`000003ooooool0003o00000:;ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0
oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB_oo
ool001Cooooo00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o0000oooo
ooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`00
0?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`004_ooool0
0omEEEGoIVIVo`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
002Uooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05Oooool01OnHV9So410@
o`000?lb<S;oc<c<00?ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h0T?ooool00:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00002Oooool0
1Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0T?ooool00:Kooooo00Go0000ooooooooooooooooo`00000Looooo`03
o`000?oooooooooo00Gooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo
08kooooo002Vooooo`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo00?oZJVYoa0@
4?ooool01Oooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool00000T?ooool0
0:Kooooo00Go0000ohN7QoooooooZJVYo`00000Jooooo`03oa0@4?l0003o^[Zj00Gooooo00?o410@
o`000?nj^[X00oooool01Ol0003ooooooooooooooooo0000093ooooo002Uooooo`03oa0@4?l0003o
MgMg00;o000000?oV9RHooooooooool06Oooool00onj^[[o8B4Qooooo`05ooooo`03okZj^_lQ8B7o
oooo00;ooooo00Go410@oooooooooooooooooa0@402@ooooo`00`oooool01Ol@413oV9RHoooooonj
^[[o000000?ooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0T?ooool00<?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05ojVYZOl@413o0000oa0@
4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^093ooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(336) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.61326 .67579 Mdot
.57628 .67222 Mdot
.60564 .30112 Mdot
.35169 .55987 Mdot
.47738 .29559 Mdot
.59251 .33247 Mdot
.70019 .48858 Mdot
.70548 .48784 Mdot
.61323 .31626 Mdot
.31076 .72312 Mdot
.68785 .52136 Mdot
.3247 .55419 Mdot
.69676 .50303 Mdot
.36337 .53935 Mdot
.40653 .42842 Mdot
.42167 .53461 Mdot
.6041 .64007 Mdot
.47107 .23995 Mdot
.41935 .53696 Mdot
.57625 .33607 Mdot
.28092 .60788 Mdot
.35678 .54857 Mdot
.56498 .69214 Mdot
.36367 .54267 Mdot
.33713 .49544 Mdot
.5897 .67917 Mdot
.60892 .68236 Mdot
.33063 .50712 Mdot
.39717 .56369 Mdot
.70057 .51846 Mdot
.52323 .44571 Mdot
.18559 .4868 Mdot
.36597 .48067 Mdot
.45815 .69447 Mdot
.71868 .51328 Mdot
.71077 .44449 Mdot
.60589 .37047 Mdot
.71248 .47691 Mdot
.70297 .5287 Mdot
.68831 .52646 Mdot
.68419 .52354 Mdot
.59266 .68007 Mdot
.68493 .47062 Mdot
.7063 .3978 Mdot
.37665 .54614 Mdot
.50762 .67557 Mdot
.675 .39687 Mdot
.38271 .50631 Mdot
.56219 .64921 Mdot
.58479 .31268 Mdot
.36135 .3162 Mdot
.6947 .47729 Mdot
.51688 .54367 Mdot
.87944 .53793 Mdot
.706 .49979 Mdot
.39979 .51139 Mdot
.62483 .34273 Mdot
.35627 .5159 Mdot
.32103 .53222 Mdot
.43492 .6677 Mdot
.34183 .51743 Mdot
.48206 .28084 Mdot
.59728 .71233 Mdot
.57159 .35596 Mdot
.61448 .31455 Mdot
.70035 .47373 Mdot
.55416 .63269 Mdot
.69538 .51339 Mdot
.38528 .56767 Mdot
.5844 .31735 Mdot
.40411 .53793 Mdot
.68665 .52014 Mdot
.59311 .69288 Mdot
.3648 .55773 Mdot
.72816 .68919 Mdot
.64378 .46139 Mdot
.58549 .28653 Mdot
.41788 .62151 Mdot
.45594 .32036 Mdot
.46056 .42553 Mdot
.36197 .55584 Mdot
.792 .35261 Mdot
.38961 .40373 Mdot
.56616 .65132 Mdot
.53405 .5467 Mdot
.7257 .57979 Mdot
.3658 .49636 Mdot
.527 .44983 Mdot
.42757 .56928 Mdot
.49925 .22215 Mdot
.61789 .33236 Mdot
.57751 .63817 Mdot
.37235 .55248 Mdot
.37733 .5648 Mdot
.41138 .79393 Mdot
.40278 .56233 Mdot
.31926 .52312 Mdot
.58066 .53387 Mdot
.66311 .49492 Mdot
.29406 .52683 Mdot
.51869 .35843 Mdot
.53163 .57122 Mdot
.39587 .50865 Mdot
.61278 .34327 Mdot
.59035 .71176 Mdot
.38011 .48654 Mdot
.68578 .50571 Mdot
.36551 .55227 Mdot
.67298 .46425 Mdot
.55826 .65551 Mdot
.31691 .52846 Mdot
.49764 .27272 Mdot
.41927 .61003 Mdot
.57961 .6941 Mdot
.50258 .77046 Mdot
.33882 .53157 Mdot
.36591 .51444 Mdot
.57592 .67525 Mdot
.58102 .347 Mdot
.75457 .33155 Mdot
.59336 .69062 Mdot
.6848 .52547 Mdot
.59134 .63313 Mdot
.45405 .57491 Mdot
.58068 .35052 Mdot
.51381 .56626 Mdot
.50745 .56082 Mdot
.27701 .3799 Mdot
.34482 .55518 Mdot
.25407 .5663 Mdot
.60397 .33856 Mdot
.57924 .68812 Mdot
.70335 .51085 Mdot
.40869 .56958 Mdot
.59577 .66177 Mdot
.69965 .48535 Mdot
.51593 .2784 Mdot
.45879 .24652 Mdot
.56091 .68126 Mdot
.52365 .7833 Mdot
.74522 .51719 Mdot
.65949 .49128 Mdot
.35911 .31896 Mdot
.56583 .6519 Mdot
.48158 .26256 Mdot
.68297 .49216 Mdot
.32514 .23791 Mdot
.32016 .50121 Mdot
.33394 .34277 Mdot
.80206 .37961 Mdot
.36211 .31599 Mdot
.26764 .61429 Mdot
.49511 .26482 Mdot
.699 .48466 Mdot
.39801 .52328 Mdot
.5791 .65533 Mdot
.59584 .66617 Mdot
.3998 .54868 Mdot
.34074 .48602 Mdot
.3676 .5309 Mdot
.36262 .48189 Mdot
.58058 .50941 Mdot
.37166 .55113 Mdot
.63879 .76571 Mdot
.58439 .65041 Mdot
.35111 .48595 Mdot
.59996 .36423 Mdot
.28397 .49763 Mdot
.68991 .47124 Mdot
.33209 .54903 Mdot
.33556 .49108 Mdot
.35789 .57805 Mdot
.68351 .52585 Mdot
.72706 .70303 Mdot
.43933 .28786 Mdot
.71734 .53113 Mdot
.78265 .49895 Mdot
.60196 .35118 Mdot
.34695 .50681 Mdot
.48958 .25156 Mdot
.29306 .54564 Mdot
.3795 .55737 Mdot
.36724 .31056 Mdot
.32286 .52317 Mdot
.26125 .60651 Mdot
.42708 .50276 Mdot
.72594 .57251 Mdot
.63613 .74839 Mdot
.35793 .56243 Mdot
.32243 .7068 Mdot
.34494 .34166 Mdot
.63464 .43562 Mdot
.7057 .51173 Mdot
.58495 .33163 Mdot
.58158 .33995 Mdot
.73423 .50288 Mdot
.49261 .73366 Mdot
.29054 .70365 Mdot
.38341 .57484 Mdot
.53045 .56717 Mdot
.58187 .6248 Mdot
.49366 .26631 Mdot
.56457 .68224 Mdot
.77658 .32637 Mdot
.47883 .41749 Mdot
.50014 .46018 Mdot
.52926 .31387 Mdot
.58284 .31122 Mdot
.52395 .56559 Mdot
.47963 .25828 Mdot
.37668 .52975 Mdot
.55887 .65629 Mdot
.34885 .33585 Mdot
.31109 .57096 Mdot
.27952 .75453 Mdot
.60842 .67921 Mdot
.26502 .4277 Mdot
.70305 .4999 Mdot
.63482 .35163 Mdot
.36432 .49572 Mdot
.34891 .53068 Mdot
.55363 .66177 Mdot
.38933 .5168 Mdot
.46852 .45893 Mdot
.32869 .49773 Mdot
.57768 .36506 Mdot
.43921 .26662 Mdot
.7374 .52087 Mdot
.52223 .31431 Mdot
.58518 .69575 Mdot
.74523 .72681 Mdot
.61564 .35825 Mdot
.31014 .47186 Mdot
.68213 .51535 Mdot
.51297 .28066 Mdot
.61929 .35159 Mdot
.4613 .27435 Mdot
.33037 .55144 Mdot
.61436 .36982 Mdot
.48792 .28101 Mdot
.505 .48056 Mdot
.36468 .48299 Mdot
.25906 .36542 Mdot
.68611 .48355 Mdot
.58683 .63626 Mdot
.39114 .54904 Mdot
.52671 .5457 Mdot
.30615 .50594 Mdot
.30277 .39909 Mdot
.51168 .54922 Mdot
.53565 .57453 Mdot
.43225 .40411 Mdot
.50835 .25431 Mdot
.79818 .56647 Mdot
.53528 .45968 Mdot
.60537 .64111 Mdot
.37362 .56345 Mdot
.77767 .52709 Mdot
.69209 .48165 Mdot
.37014 .524 Mdot
.77179 .54983 Mdot
.68481 .48991 Mdot
.36676 .51649 Mdot
.69994 .52409 Mdot
.58886 .65695 Mdot
.44537 .44212 Mdot
.61374 .65646 Mdot
.38354 .54677 Mdot
.69662 .52372 Mdot
.58418 .33965 Mdot
.59039 .67779 Mdot
.36197 .55204 Mdot
.33357 .54217 Mdot
.53415 .56099 Mdot
.32414 .49889 Mdot
.62811 .55947 Mdot
.37914 .50318 Mdot
.61133 .29917 Mdot
.40046 .56326 Mdot
.45695 .35575 Mdot
.48574 .20985 Mdot
.5573 .66803 Mdot
.51272 .54919 Mdot
.62326 .34802 Mdot
.48011 .47645 Mdot
.24815 .431 Mdot
.37119 .54679 Mdot
.5187 .55126 Mdot
.27938 .39733 Mdot
.6826 .47314 Mdot
.43254 .56599 Mdot
.55965 .28634 Mdot
.61655 .33324 Mdot
.52733 .56763 Mdot
.30204 .55703 Mdot
.56283 .61551 Mdot
.41773 .54092 Mdot
.61319 .36765 Mdot
.60925 .65123 Mdot
.41059 .54826 Mdot
.64769 .44426 Mdot
.5331 .54823 Mdot
.66174 .49031 Mdot
.572 .52947 Mdot
.3689 .51099 Mdot
.58728 .31558 Mdot
.59805 .67624 Mdot
.70857 .49626 Mdot
.58269 .69438 Mdot
.37068 .32685 Mdot
.28145 .40953 Mdot
.52818 .66851 Mdot
.51901 .26197 Mdot
.28117 .26201 Mdot
.71626 .53242 Mdot
.29139 .53068 Mdot
.58921 .38709 Mdot
.63401 .72881 Mdot
.61479 .34147 Mdot
.53877 .7835 Mdot
.62115 .33611 Mdot
.40817 .5247 Mdot
.59483 .32214 Mdot
.41073 .80179 Mdot
.32748 .52088 Mdot
.61485 .31207 Mdot
.57672 .48749 Mdot
.32741 .52661 Mdot
.59655 .66119 Mdot
.18696 .54865 Mdot
.47871 .71129 Mdot
.4826 .72377 Mdot
.62725 .34854 Mdot
.55226 .78536 Mdot
.33441 .50355 Mdot
.41598 .56777 Mdot
.58151 .66032 Mdot
.30779 .50176 Mdot
.49043 .24451 Mdot
.46152 .2488 Mdot
.3403 .27408 Mdot
.2079 .48446 Mdot
.49062 .74724 Mdot
.59314 .66948 Mdot
.4491 .2929 Mdot
.71949 .69724 Mdot
.53163 .54734 Mdot
.70496 .48714 Mdot
.76268 .66521 Mdot
.41512 .57557 Mdot
.56229 .57636 Mdot
.46498 .45734 Mdot
.60193 .64758 Mdot
.53282 .60014 Mdot
.70831 .49379 Mdot
.48022 .72382 Mdot
.27384 .6785 Mdot
.36912 .53052 Mdot
.67856 .4814 Mdot
.31151 .50077 Mdot
.52678 .45318 Mdot
.26104 .38719 Mdot
.68653 .31115 Mdot
.3828 .54532 Mdot
.76761 .64521 Mdot
.38534 .55335 Mdot
.28867 .36831 Mdot
.37716 .52784 Mdot
.60092 .6681 Mdot
.36046 .58139 Mdot
.53733 .46707 Mdot
.35224 .19081 Mdot
.47324 .40933 Mdot
.46073 .26661 Mdot
.36013 .53906 Mdot
.35823 .52537 Mdot
.47718 .2813 Mdot
.59054 .64116 Mdot
.38969 .55539 Mdot
.81299 .56369 Mdot
.36911 .55405 Mdot
.70443 .47675 Mdot
.34194 .38876 Mdot
.19482 .46628 Mdot
.34623 .50003 Mdot
.56206 .6163 Mdot
.66004 .49153 Mdot
.67576 .50642 Mdot
.4147 .59534 Mdot
.68856 .48124 Mdot
.39603 .52229 Mdot
.34239 .3878 Mdot
.54528 .65547 Mdot
.41095 .59523 Mdot
.60197 .65008 Mdot
.51249 .1691 Mdot
.69188 .48453 Mdot
.52743 .54836 Mdot
.50429 .75164 Mdot
.68818 .49808 Mdot
.43917 .24743 Mdot
.36552 .58266 Mdot
.33553 .59139 Mdot
.61084 .63684 Mdot
.58782 .31644 Mdot
.51634 .55868 Mdot
.70677 .49865 Mdot
.37426 .54625 Mdot
.37569 .4918 Mdot
.68554 .48099 Mdot
.35096 .65089 Mdot
.52449 .44523 Mdot
.38302 .54917 Mdot
.5943 .652 Mdot
.58239 .68803 Mdot
.42692 .53531 Mdot
.38698 .55335 Mdot
.58875 .33438 Mdot
.51765 .55122 Mdot
.51279 .55262 Mdot
.51565 .56964 Mdot
.63079 .3516 Mdot
.28619 .25295 Mdot
.65958 .48572 Mdot
.18814 .48049 Mdot
.71782 .65586 Mdot
.43442 .58514 Mdot
.5893 .35847 Mdot
.34416 .52842 Mdot
.38488 .50078 Mdot
.70246 .52159 Mdot
.24915 .3277 Mdot
.41175 .57024 Mdot
.61368 .66211 Mdot
.68793 .47841 Mdot
.30899 .50614 Mdot
.70514 .56283 Mdot
.50639 .26779 Mdot
.49467 .75785 Mdot
.69453 .47887 Mdot
.54831 .66588 Mdot
.69471 .47871 Mdot
.36103 .52696 Mdot
.29904 .5519 Mdot
.60483 .65131 Mdot
.4703 .28939 Mdot
.39597 .55443 Mdot
.37433 .52075 Mdot
.56541 .38476 Mdot
.73031 .68549 Mdot
.48809 .2995 Mdot
.39708 .5153 Mdot
.32648 .58829 Mdot
.47031 .28779 Mdot
.39482 .53191 Mdot
.4058 .55281 Mdot
.25373 .56718 Mdot
.68916 .4674 Mdot
.50753 .28872 Mdot
.32387 .21254 Mdot
.6095 .6785 Mdot
.62653 .55631 Mdot
.52535 .57177 Mdot
.70882 .53281 Mdot
.45806 .46089 Mdot
.52556 .55736 Mdot
.7422 .62829 Mdot
.62679 .83139 Mdot
.51763 .55742 Mdot
.61713 .37844 Mdot
.44074 .79821 Mdot
.40376 .55448 Mdot
.3874 .54587 Mdot
.49456 .24661 Mdot
.56897 .67033 Mdot
.64614 .74705 Mdot
.71504 .53121 Mdot
.34584 .54252 Mdot
.60053 .69305 Mdot
.73015 .57432 Mdot
.52951 .56186 Mdot
.49686 .25434 Mdot
.48844 .29222 Mdot
.39056 .54674 Mdot
.25945 .41449 Mdot
.59309 .6755 Mdot
.36205 .55195 Mdot
.3675 .51376 Mdot
.60447 .3768 Mdot
.55905 .65935 Mdot
.60426 .3642 Mdot
.54306 .5639 Mdot
.47509 .81917 Mdot
.79027 .48765 Mdot
.6817 .488 Mdot
.48344 .55208 Mdot
.737 .52091 Mdot
.65753 .40698 Mdot
.51636 .55141 Mdot
.36042 .55051 Mdot
.54331 .66837 Mdot
.36372 .55274 Mdot
.37044 .55356 Mdot
.37984 .54293 Mdot
.49066 .74887 Mdot
.46007 .32403 Mdot
.48727 .24919 Mdot
.37471 .51035 Mdot
.62561 .36663 Mdot
.7345 .56109 Mdot
.33709 .75377 Mdot
.355 .53499 Mdot
.36749 .51526 Mdot
.56405 .6182 Mdot
.31828 .50194 Mdot
.68937 .49141 Mdot
.60202 .64643 Mdot
.38856 .49991 Mdot
.52534 .35323 Mdot
.39334 .55063 Mdot
.51952 .62359 Mdot
.71714 .48885 Mdot
.30854 .55182 Mdot
.36576 .47233 Mdot
.51668 .5504 Mdot
.51757 .55932 Mdot
.53494 .5803 Mdot
.70261 .47531 Mdot
.61024 .37605 Mdot
.57281 .30234 Mdot
.35269 .46766 Mdot
.39494 .51734 Mdot
.32289 .58058 Mdot
.64677 .33352 Mdot
.55237 .4529 Mdot
.52788 .77516 Mdot
.31306 .50328 Mdot
.63336 .33721 Mdot
.58049 .53338 Mdot
.34437 .63455 Mdot
.59042 .6392 Mdot
.60516 .39447 Mdot
.68361 .51188 Mdot
.49196 .28305 Mdot
.32093 .31267 Mdot
.60017 .6822 Mdot
.5427 .64473 Mdot
.59306 .34432 Mdot
.35035 .38345 Mdot
.89435 .50745 Mdot
.6064 .33466 Mdot
.49245 .46264 Mdot
.58633 .66319 Mdot
.36553 .48111 Mdot
.29359 .38701 Mdot
.3526 .39322 Mdot
.6243 .32147 Mdot
.33452 .54377 Mdot
.54841 .17866 Mdot
.58883 .33275 Mdot
.31767 .57986 Mdot
.62762 .35102 Mdot
.66593 .48021 Mdot
.60797 .34368 Mdot
.60629 .69323 Mdot
.34568 .55484 Mdot
.8842 .52835 Mdot
.41442 .41173 Mdot
.34418 .54829 Mdot
.70148 .47787 Mdot
.64376 .43399 Mdot
.36863 .52708 Mdot
.47477 .24408 Mdot
.61596 .37779 Mdot
.67724 .33645 Mdot
.41236 .53967 Mdot
.59428 .32039 Mdot
.54525 .6312 Mdot
.61742 .39571 Mdot
.52408 .35932 Mdot
.51401 .55657 Mdot
.58431 .6537 Mdot
.6501 .45659 Mdot
.68117 .52309 Mdot
.40309 .50606 Mdot
.35639 .50926 Mdot
.58351 .64693 Mdot
.48889 .48411 Mdot
.43723 .55333 Mdot
.36602 .55454 Mdot
.59934 .35685 Mdot
.57154 .33135 Mdot
.39976 .4252 Mdot
.61621 .36031 Mdot
.33196 .59102 Mdot
.59074 .65216 Mdot
.41716 .53793 Mdot
.5873 .69069 Mdot
.37669 .56275 Mdot
.66862 .55857 Mdot
.57464 .63599 Mdot
.31624 .46901 Mdot
.33407 .54727 Mdot
.58536 .75567 Mdot
.36309 .50773 Mdot
.37894 .55142 Mdot
.57362 .35115 Mdot
.47456 .27492 Mdot
.43318 .54649 Mdot
.63821 .49921 Mdot
.49431 .28687 Mdot
.3338 .64459 Mdot
.58136 .35168 Mdot
.50161 .28936 Mdot
.3169 .29136 Mdot
.51183 .55037 Mdot
.46713 .27008 Mdot
.49907 .54231 Mdot
.67851 .48841 Mdot
.55138 .69373 Mdot
.32669 .53053 Mdot
.46834 .81812 Mdot
.52705 .4453 Mdot
.53394 .5577 Mdot
.39279 .53622 Mdot
.34575 .52426 Mdot
.59982 .69336 Mdot
.78005 .33273 Mdot
.57024 .31799 Mdot
.33482 .48638 Mdot
.60014 .68462 Mdot
.79698 .36454 Mdot
.61958 .31443 Mdot
.50891 .25856 Mdot
.70722 .52917 Mdot
.62542 .67269 Mdot
.53027 .54857 Mdot
.69405 .48425 Mdot
.57495 .29378 Mdot
.37131 .3075 Mdot
.4171 .54339 Mdot
.59572 .36371 Mdot
.36325 .31495 Mdot
.43396 .56674 Mdot
.73504 .50019 Mdot
.66038 .43228 Mdot
.56871 .64561 Mdot
.68589 .48054 Mdot
.47666 .2469 Mdot
.59033 .63072 Mdot
.60089 .64785 Mdot
.68525 .49501 Mdot
.61053 .77915 Mdot
.28074 .39697 Mdot
.72741 .50583 Mdot
.30914 .39901 Mdot
.36541 .31442 Mdot
.53515 .55521 Mdot
.49476 .25448 Mdot
.43808 .26793 Mdot
.59166 .68033 Mdot
.75723 .67023 Mdot
.36162 .3153 Mdot
.31886 .52054 Mdot
.48718 .28218 Mdot
.71185 .57456 Mdot
.71217 .44963 Mdot
.69087 .48741 Mdot
.58135 .39775 Mdot
.48414 .28464 Mdot
.3396 .55784 Mdot
.19656 .38649 Mdot
.33284 .51404 Mdot
.6818 .49211 Mdot
.46642 .45799 Mdot
.56127 .67138 Mdot
.68548 .4717 Mdot
.46768 .45813 Mdot
.39175 .50804 Mdot
.33693 .53065 Mdot
.47521 .3333 Mdot
.56174 .64524 Mdot
.5404 .55964 Mdot
.34796 .5537 Mdot
.36226 .51613 Mdot
.40722 .50653 Mdot
.21715 .43284 Mdot
.47022 .58551 Mdot
.39569 .49465 Mdot
.6387 .34362 Mdot
.29682 .55133 Mdot
.32995 .48799 Mdot
.57014 .61172 Mdot
.50558 .35319 Mdot
.54435 .57077 Mdot
.38823 .54159 Mdot
.384 .54728 Mdot
.70422 .52779 Mdot
.28122 .39595 Mdot
.35561 .39 Mdot
.59625 .3006 Mdot
.61982 .29075 Mdot
.36389 .57037 Mdot
.57675 .64997 Mdot
.52206 .27665 Mdot
.37628 .60287 Mdot
.6132 .66471 Mdot
.36708 .5684 Mdot
.61146 .37941 Mdot
.51787 .55459 Mdot
.35828 .60334 Mdot
.48604 .27694 Mdot
.7445 .51011 Mdot
.34548 .64132 Mdot
.58641 .34649 Mdot
.34522 .4942 Mdot
.59912 .28379 Mdot
.60426 .32186 Mdot
.53548 .56174 Mdot
.29724 .51879 Mdot
.59151 .66078 Mdot
.54953 .6695 Mdot
.44189 .34152 Mdot
.63008 .35802 Mdot
.62966 .40909 Mdot
.6713 .48229 Mdot
.3759 .51236 Mdot
.75004 .49802 Mdot
.55361 .67229 Mdot
.27641 .3796 Mdot
.49392 .29207 Mdot
.68754 .48942 Mdot
.50375 .54137 Mdot
.58196 .63481 Mdot
.55368 .67593 Mdot
.37397 .5503 Mdot
.35457 .54286 Mdot
.65266 .40389 Mdot
.33757 .34434 Mdot
.7062 .52207 Mdot
.51071 .26671 Mdot
.59769 .30188 Mdot
.40838 .52899 Mdot
.5668 .65486 Mdot
.19054 .44791 Mdot
.36653 .50983 Mdot
.62602 .36533 Mdot
.5786 .67251 Mdot
.49854 .25042 Mdot
.47705 .2483 Mdot
.35875 .5602 Mdot
.26349 .60627 Mdot
.68771 .50191 Mdot
.59814 .66275 Mdot
.61598 .71506 Mdot
.37659 .50911 Mdot
.35655 .53904 Mdot
.4522 .54795 Mdot
.72124 .47946 Mdot
.40637 .49225 Mdot
.46531 .28168 Mdot
.56999 .68904 Mdot
.35034 .55321 Mdot
.47996 .28095 Mdot
.56331 .57894 Mdot
.52448 .5552 Mdot
.6019 .31204 Mdot
.46987 .24479 Mdot
.47832 .26866 Mdot
.50075 .28435 Mdot
.76441 .66292 Mdot
.54877 .5622 Mdot
.41238 .2411 Mdot
.33559 .54669 Mdot
.36636 .31416 Mdot
.42338 .53041 Mdot
.67812 .47599 Mdot
.59085 .31443 Mdot
.37532 .53986 Mdot
.33451 .54551 Mdot
.36112 .63724 Mdot
.41934 .53265 Mdot
.42341 .55129 Mdot
.56038 .67321 Mdot
.61481 .71936 Mdot
.58302 .33235 Mdot
.80851 .39715 Mdot
.15455 .47325 Mdot
.37702 .57571 Mdot
.34874 .38469 Mdot
.58405 .63728 Mdot
.70533 .52862 Mdot
.30623 .39383 Mdot
.74713 .48127 Mdot
.57619 .68271 Mdot
.40992 .52766 Mdot
.39953 .63339 Mdot
.49021 .28584 Mdot
.36459 .52971 Mdot
.70019 .51432 Mdot
.36607 .53021 Mdot
.69684 .47438 Mdot
.55499 .77781 Mdot
.36768 .38578 Mdot
.32414 .52488 Mdot
.40293 .56182 Mdot
.27758 .59413 Mdot
.3544 .53786 Mdot
.6831 .29887 Mdot
.5799 .66805 Mdot
.30515 .48027 Mdot
.40331 .51438 Mdot
.47168 .70952 Mdot
.38557 .52436 Mdot
.46568 .47927 Mdot
.34106 .51362 Mdot
.26604 .30892 Mdot
.3252 .54267 Mdot
.34469 .50818 Mdot
.71409 .50304 Mdot
.69484 .52781 Mdot
.61997 .73493 Mdot
.54167 .57042 Mdot
.72165 .57359 Mdot
.37388 .51945 Mdot
.58307 .3088 Mdot
.26478 .51264 Mdot
.47616 .27232 Mdot
.57196 .68879 Mdot
.72892 .79303 Mdot
.66275 .47699 Mdot
.62589 .37096 Mdot
.51281 .45436 Mdot
.63731 .35835 Mdot
.59253 .38815 Mdot
.63035 .67225 Mdot
.49677 .25631 Mdot
.39052 .55276 Mdot
.46441 .69195 Mdot
.74482 .66801 Mdot
.37808 .50905 Mdot
.61082 .29386 Mdot
.25857 .53166 Mdot
.42639 .33365 Mdot
.48431 .23961 Mdot
.49094 .26005 Mdot
.70501 .4948 Mdot
.59557 .30512 Mdot
.31502 .49708 Mdot
.5016 .28963 Mdot
.58617 .32659 Mdot
.50253 .54462 Mdot
.49157 .34596 Mdot
.59457 .67443 Mdot
.54871 .78505 Mdot
.51456 .69573 Mdot
.6608 .49654 Mdot
.63968 .49488 Mdot
.54604 .68273 Mdot
.61084 .64842 Mdot
.53766 .57067 Mdot
.63052 .33332 Mdot
.55298 .69443 Mdot
.353 .5571 Mdot
.31051 .57049 Mdot
.39003 .54844 Mdot
.50243 .25033 Mdot
.38997 .52982 Mdot
.58953 .32395 Mdot
.71608 .49898 Mdot
.61917 .33703 Mdot
.70197 .48905 Mdot
.18176 .51827 Mdot
.33937 .55556 Mdot
.35869 .54141 Mdot
.34334 .38809 Mdot
.55707 .67895 Mdot
.45262 .69996 Mdot
.62739 .36142 Mdot
.6244 .34358 Mdot
.40712 .52062 Mdot
.57538 .6272 Mdot
.47664 .30087 Mdot
.32135 .39671 Mdot
.34411 .51219 Mdot
.57837 .66693 Mdot
.41075 .52489 Mdot
.62794 .52415 Mdot
.39466 .41042 Mdot
.57072 .69373 Mdot
.35751 .18718 Mdot
.33183 .54649 Mdot
.30139 .50845 Mdot
.33604 .46495 Mdot
.21628 .44855 Mdot
.43371 .55528 Mdot
.61069 .67582 Mdot
.32967 .48875 Mdot
.57311 .653 Mdot
.60759 .32657 Mdot
.67651 .4727 Mdot
.57601 .65674 Mdot
.32967 .52498 Mdot
.15617 .47064 Mdot
.71821 .50429 Mdot
.36664 .5341 Mdot
.70704 .51627 Mdot
.58532 .7103 Mdot
.56469 .67128 Mdot
.49892 .54494 Mdot
.49384 .46193 Mdot
.68694 .49487 Mdot
.39324 .51639 Mdot
.72894 .69578 Mdot
.41811 .54124 Mdot
.61674 .291 Mdot
.39733 .56998 Mdot
.3721 .56979 Mdot
.28733 .24481 Mdot
.48152 .48404 Mdot
.79515 .48471 Mdot
.73431 .55362 Mdot
.7214 .70784 Mdot
.60623 .63071 Mdot
.48246 .23973 Mdot
.5144 .58713 Mdot
.50962 .5536 Mdot
.63776 .33694 Mdot
.37535 .54381 Mdot
.57366 .56611 Mdot
.7284 .49777 Mdot
.46902 .26555 Mdot
.32295 .5229 Mdot
.64318 .35707 Mdot
.48204 .55406 Mdot
.69327 .48576 Mdot
.59255 .68105 Mdot
.56915 .68281 Mdot
.45094 .31937 Mdot
.34873 .55167 Mdot
.35675 .54666 Mdot
.71873 .51146 Mdot
.40511 .47985 Mdot
.50433 .27834 Mdot
.57577 .48572 Mdot
.70014 .51583 Mdot
.39372 .40851 Mdot
.56001 .64678 Mdot
.34493 .52609 Mdot
.34107 .39185 Mdot
.68199 .73526 Mdot
.35138 .74839 Mdot
.49039 .2662 Mdot
.25347 .42536 Mdot
.61012 .67661 Mdot
.70456 .50982 Mdot
.32928 .28228 Mdot
.37749 .58377 Mdot
.34782 .52037 Mdot
.23903 .43266 Mdot
.31904 .39744 Mdot
.51109 .45723 Mdot
.44929 .57577 Mdot
.3102 .377 Mdot
.40862 .52248 Mdot
.37669 .49253 Mdot
.36017 .56923 Mdot
.39979 .56862 Mdot
.57307 .6616 Mdot
.47394 .72477 Mdot
.59783 .34209 Mdot
.35547 .73859 Mdot
.64095 .30892 Mdot
.33381 .50531 Mdot
.39918 .51506 Mdot
.37617 .71831 Mdot
.28531 .43015 Mdot
.58693 .67058 Mdot
.61451 .64335 Mdot
.66527 .50883 Mdot
.42007 .53829 Mdot
.62819 .3624 Mdot
.33408 .46675 Mdot
.60639 .31636 Mdot
.57379 .66363 Mdot
.59514 .37185 Mdot
.65395 .50314 Mdot
.59655 .36453 Mdot
.63545 .33868 Mdot
.71465 .49055 Mdot
.56565 .63922 Mdot
.35284 .50603 Mdot
.71388 .48905 Mdot
.48353 .30134 Mdot
.49995 .24893 Mdot
.59255 .72889 Mdot
.37964 .48469 Mdot
.4064 .57827 Mdot
.66383 .41786 Mdot
.60879 .37217 Mdot
.34434 .4113 Mdot
.57118 .63844 Mdot
.52118 .27268 Mdot
.57102 .65678 Mdot
.41534 .29632 Mdot
.48688 .26948 Mdot
.53096 .54511 Mdot
.28954 .336 Mdot
.73408 .52982 Mdot
.34214 .57283 Mdot
.6134 .71979 Mdot
.60979 .31812 Mdot
.69928 .47615 Mdot
.72714 .56611 Mdot
.34052 .48453 Mdot
.54018 .68584 Mdot
.60328 .70562 Mdot
.51165 .55283 Mdot
.70233 .51115 Mdot
.53366 .7258 Mdot
.34425 .54645 Mdot
.73694 .52457 Mdot
.39451 .57087 Mdot
.51035 .77706 Mdot
.66279 .33433 Mdot
.57889 .54092 Mdot
.40784 .5234 Mdot
.62065 .31492 Mdot
.40827 .52307 Mdot
.47678 .80011 Mdot
.29295 .35398 Mdot
.36077 .57037 Mdot
.27374 .43187 Mdot
.66428 .40672 Mdot
.56709 .65313 Mdot
.38852 .60058 Mdot
.53497 .55691 Mdot
.35737 .49154 Mdot
.16255 .62554 Mdot
.47286 .27697 Mdot
.51785 .32756 Mdot
.32893 .52987 Mdot
.36058 .55485 Mdot
.34092 .63893 Mdot
.55134 .77544 Mdot
.4992 .54787 Mdot
.35365 .51929 Mdot
.22615 .45415 Mdot
.7118 .50024 Mdot
.41121 .55058 Mdot
.38092 .5543 Mdot
.65015 .39716 Mdot
.71177 .50607 Mdot
.58916 .36176 Mdot
.51111 .55126 Mdot
.57362 .32696 Mdot
.47489 .29392 Mdot
.26174 .42856 Mdot
.25064 .39907 Mdot
.39392 .41497 Mdot
.46738 .2468 Mdot
.34235 .49871 Mdot
.57084 .53399 Mdot
.33576 .53848 Mdot
.48692 .25693 Mdot
.70038 .51863 Mdot
.57875 .66439 Mdot
.53214 .78493 Mdot
.53338 .56446 Mdot
.36354 .50062 Mdot
.50621 .24772 Mdot
.58112 .65637 Mdot
.66154 .76311 Mdot
.56942 .66814 Mdot
.69658 .49032 Mdot
.73268 .49758 Mdot
.48191 .27233 Mdot
.57037 .65658 Mdot
.57303 .33717 Mdot
.73401 .47804 Mdot
.32125 .55382 Mdot
.65325 .50082 Mdot
.57705 .70337 Mdot
.58137 .69913 Mdot
.54774 .64386 Mdot
.39836 .50814 Mdot
.30497 .41877 Mdot
.45653 .57196 Mdot
.7187 .50861 Mdot
.64213 .34224 Mdot
.32859 .34572 Mdot
.46502 .64965 Mdot
.3774 .40046 Mdot
.38403 .59952 Mdot
.39069 .53127 Mdot
.39123 .54517 Mdot
.4046 .50064 Mdot
.56268 .49744 Mdot
.34173 .55695 Mdot
.70429 .52174 Mdot
.59732 .32586 Mdot
.34416 .51478 Mdot
.52776 .55088 Mdot
.54874 .45172 Mdot
.50709 .29007 Mdot
.49425 .76051 Mdot
.60006 .73021 Mdot
.58059 .65774 Mdot
.61192 .36665 Mdot
.58844 .36715 Mdot
.51596 .27804 Mdot
.69808 .48231 Mdot
.56905 .67213 Mdot
.27165 .30128 Mdot
.49584 .2843 Mdot
.38814 .53998 Mdot
.3426 .38873 Mdot
.21369 .4691 Mdot
.39904 .55418 Mdot
.38108 .54176 Mdot
.5435 .57165 Mdot
.63077 .36139 Mdot
.34226 .76664 Mdot
.6252 .76491 Mdot
.47813 .27631 Mdot
.51223 .2758 Mdot
.55089 .63409 Mdot
.38267 .51706 Mdot
.68823 .5051 Mdot
.27469 .40125 Mdot
.64475 .4439 Mdot
.71837 .58088 Mdot
.6567 .40868 Mdot
.39497 .54816 Mdot
.45793 .77035 Mdot
.37345 .57942 Mdot
.58687 .71194 Mdot
.54973 .65838 Mdot
.59091 .67041 Mdot
.71148 .49716 Mdot
.37404 .30587 Mdot
.68317 .52225 Mdot
.58086 .53043 Mdot
.60708 .67306 Mdot
.49276 .47453 Mdot
.62572 .34579 Mdot
.42223 .53161 Mdot
.49449 .25609 Mdot
.53719 .28704 Mdot
.37369 .6019 Mdot
.25611 .42641 Mdot
.58947 .3588 Mdot
.57988 .63213 Mdot
.42114 .52677 Mdot
.7383 .55913 Mdot
.35375 .37648 Mdot
.68144 .37058 Mdot
.57562 .55926 Mdot
.48275 .28163 Mdot
.30478 .71466 Mdot
.5028 .27538 Mdot
.68638 .48987 Mdot
.33583 .55068 Mdot
.37923 .5163 Mdot
.37946 .55171 Mdot
.4034 .57135 Mdot
.70769 .50044 Mdot
.32603 .55824 Mdot
.45588 .35542 Mdot
.50499 .55474 Mdot
.54701 .47304 Mdot
.46972 .253 Mdot
.67309 .4802 Mdot
.60133 .32281 Mdot
.53398 .57454 Mdot
.52047 .26473 Mdot
.41819 .51783 Mdot
.33106 .52907 Mdot
.5028 .55227 Mdot
.41522 .59328 Mdot
.41861 .5733 Mdot
.59273 .33721 Mdot
.53048 .45416 Mdot
.49778 .29428 Mdot
.49722 .26868 Mdot
.67894 .48356 Mdot
.57072 .65605 Mdot
.50441 .29027 Mdot
.61858 .30357 Mdot
.41282 .54832 Mdot
.39219 .57191 Mdot
.57942 .70277 Mdot
.36517 .31238 Mdot
.50733 .29 Mdot
.41037 .49527 Mdot
.56825 .6905 Mdot
.60532 .70455 Mdot
.35363 .5203 Mdot
.31917 .54274 Mdot
.57364 .61297 Mdot
.51497 .27198 Mdot
.67642 .48271 Mdot
.39957 .39433 Mdot
.66184 .48312 Mdot
.59677 .67834 Mdot
.30386 .56305 Mdot
.56778 .6353 Mdot
.34301 .48394 Mdot
.82676 .53557 Mdot
.34424 .55909 Mdot
.4984 .6034 Mdot
.53772 .42571 Mdot
.62762 .347 Mdot
.62821 .33741 Mdot
.51834 .55274 Mdot
.61168 .65963 Mdot
.34402 .59777 Mdot
.50186 .2599 Mdot
.72193 .70688 Mdot
.56758 .61104 Mdot
.63449 .33675 Mdot
.62062 .37562 Mdot
.70436 .5166 Mdot
.38917 .52786 Mdot
.34345 .52662 Mdot
.596 .36505 Mdot
.6283 .47645 Mdot
.57597 .64286 Mdot
.35721 .54672 Mdot
.40062 .49947 Mdot
.59721 .33875 Mdot
.67326 .52987 Mdot
.5494 .68865 Mdot
.39688 .50551 Mdot
.28808 .36202 Mdot
.69215 .47231 Mdot
.36675 .49553 Mdot
.34446 .57434 Mdot
.47482 .26668 Mdot
.24816 .42621 Mdot
.35982 .31864 Mdot
.65876 .48105 Mdot
.51793 .54829 Mdot
.39875 .55114 Mdot
.62608 .33967 Mdot
.42393 .51904 Mdot
.4971 .86121 Mdot
.50517 .5517 Mdot
.34632 .54633 Mdot
.35707 .46507 Mdot
.58787 .6909 Mdot
.35913 .55198 Mdot
.66055 .55552 Mdot
.60501 .35948 Mdot
.3449 .54489 Mdot
.2819 .618 Mdot
.70421 .51607 Mdot
.38596 .60073 Mdot
.48625 .28499 Mdot
.50118 .46307 Mdot
.18645 .54592 Mdot
.64735 .33629 Mdot
.4638 .25947 Mdot
.38207 .52252 Mdot
.59078 .30347 Mdot
.70169 .53073 Mdot
.47241 .55893 Mdot
.35173 .49525 Mdot
.66238 .50026 Mdot
.71363 .49374 Mdot
.48289 .27612 Mdot
.83102 .64343 Mdot
.35244 .5686 Mdot
.35939 .53115 Mdot
.76178 .71344 Mdot
.58435 .61187 Mdot
.36781 .53316 Mdot
.36687 .51307 Mdot
.68608 .4834 Mdot
.37879 .28355 Mdot
.25392 .42635 Mdot
.57442 .48886 Mdot
.69075 .47348 Mdot
.58485 .29888 Mdot
.59798 .35994 Mdot
.46322 .26589 Mdot
.57836 .67329 Mdot
.51931 .26895 Mdot
.60599 .3459 Mdot
.38168 .5469 Mdot
.67019 .49856 Mdot
.24928 .64277 Mdot
.71346 .48434 Mdot
.64239 .3299 Mdot
.58701 .71143 Mdot
.42788 .80791 Mdot
.52263 .8653 Mdot
.4971 .57853 Mdot
.73546 .49591 Mdot
.47589 .27206 Mdot
.63092 .76541 Mdot
.34434 .51375 Mdot
.47473 .79194 Mdot
.36258 .52995 Mdot
.56958 .57647 Mdot
.5891 .31715 Mdot
.50155 .54444 Mdot
.34275 .48373 Mdot
.25328 .42946 Mdot
.70967 .48767 Mdot
.68688 .51201 Mdot
.32983 .48901 Mdot
.69315 .4913 Mdot
.34398 .53518 Mdot
.59762 .33141 Mdot
.83377 .56543 Mdot
.33771 .51541 Mdot
.31125 .47746 Mdot
.74071 .52272 Mdot
.58499 .73747 Mdot
.58284 .29475 Mdot
.46321 .74514 Mdot
.73631 .5703 Mdot
.68951 .50445 Mdot
.49088 .75259 Mdot
.6169 .36715 Mdot
.53531 .57478 Mdot
.57597 .31164 Mdot
.35353 .52786 Mdot
.39681 .54528 Mdot
.40581 .50068 Mdot
.37182 .51617 Mdot
.43673 .78513 Mdot
.42015 .57377 Mdot
.32796 .67752 Mdot
.33612 .54705 Mdot
.49654 .58896 Mdot
.69106 .52376 Mdot
.30201 .51039 Mdot
.4227 .39313 Mdot
.35606 .56399 Mdot
.61131 .63767 Mdot
.669 .48118 Mdot
.78454 .5345 Mdot
.70965 .50154 Mdot
.61937 .33552 Mdot
.70543 .48701 Mdot
.32005 .52288 Mdot
.58431 .68691 Mdot
.61512 .3535 Mdot
.47988 .55324 Mdot
.63783 .33063 Mdot
.34433 .54834 Mdot
.72673 .53955 Mdot
.62007 .37203 Mdot
.39611 .58219 Mdot
.58149 .68684 Mdot
.23215 .39093 Mdot
.55152 .69751 Mdot
.36649 .54756 Mdot
.36906 .54197 Mdot
.50122 .55127 Mdot
.6992 .48471 Mdot
.56308 .6378 Mdot
.63707 .42038 Mdot
.52153 .27003 Mdot
.58488 .67404 Mdot
.33738 .46392 Mdot
.34858 .38153 Mdot
.57996 .69418 Mdot
.21991 .46167 Mdot
.68372 .49007 Mdot
.59882 .6887 Mdot
.37387 .46229 Mdot
.35038 .7335 Mdot
.49941 .27174 Mdot
.57304 .34526 Mdot
.32183 .37882 Mdot
.59983 .36036 Mdot
.69105 .56143 Mdot
.57625 .36258 Mdot
.71205 .51142 Mdot
.26207 .52192 Mdot
.46833 .45913 Mdot
.72136 .48755 Mdot
.73703 .53812 Mdot
.59835 .34824 Mdot
.38176 .48645 Mdot
.53817 .46471 Mdot
.33474 .59438 Mdot
.29107 .54617 Mdot
.666 .47502 Mdot
.6037 .68513 Mdot
.59103 .63181 Mdot
.30359 .47868 Mdot
.56374 .67953 Mdot
.61068 .33831 Mdot
.39578 .41954 Mdot
.50424 .75116 Mdot
.69142 .52015 Mdot
.52587 .44921 Mdot
.39869 .51335 Mdot
.59251 .32101 Mdot
.61096 .33511 Mdot
.71212 .4931 Mdot
.39381 .75897 Mdot
.32291 .5852 Mdot
.61491 .63098 Mdot
.60293 .68 Mdot
.58933 .69136 Mdot
.55697 .65745 Mdot
.3735 .30426 Mdot
.69811 .47622 Mdot
.61194 .66431 Mdot
.40932 .56811 Mdot
.38514 .52162 Mdot
.51896 .56377 Mdot
.50667 .25518 Mdot
.38514 .58236 Mdot
.3449 .59822 Mdot
.35171 .521 Mdot
.62768 .35258 Mdot
.25231 .54104 Mdot
.50844 .55951 Mdot
.6297 .36084 Mdot
.63006 .35427 Mdot
.51633 .55018 Mdot
.26022 .5213 Mdot
.35525 .76612 Mdot
.32343 .49729 Mdot
.62936 .66912 Mdot
.62721 .33266 Mdot
.53969 .37105 Mdot
.50228 .5986 Mdot
.39391 .51965 Mdot
.56598 .47156 Mdot
.6021 .32983 Mdot
.60424 .62847 Mdot
.35333 .53279 Mdot
.5383 .56915 Mdot
.4962 .27816 Mdot
.46367 .56562 Mdot
.54313 .57106 Mdot
.56888 .64923 Mdot
.61809 .40728 Mdot
.59941 .69389 Mdot
.59286 .37441 Mdot
.36154 .60134 Mdot
.88987 .51664 Mdot
.61087 .31981 Mdot
.73483 .69617 Mdot
.47337 .46187 Mdot
.33577 .52567 Mdot
.60792 .36449 Mdot
.5536 .62262 Mdot
.69513 .47177 Mdot
.31996 .41556 Mdot
.56709 .65753 Mdot
.53253 .57537 Mdot
.52068 .56176 Mdot
.59704 .34092 Mdot
.60299 .6662 Mdot
.33569 .56869 Mdot
.57115 .68358 Mdot
.67259 .50573 Mdot
.33698 .49014 Mdot
.72257 .57331 Mdot
.29701 .51843 Mdot
.56639 .68469 Mdot
.64228 .33714 Mdot
.46992 .28878 Mdot
.32889 .51864 Mdot
.7806 .54071 Mdot
.38238 .52222 Mdot
.70469 .5178 Mdot
.5214 .40768 Mdot
.26025 .64741 Mdot
.38038 .5308 Mdot
.39546 .51062 Mdot
.66251 .51697 Mdot
.37702 .52836 Mdot
.39442 .56525 Mdot
.53405 .72776 Mdot
.57627 .69386 Mdot
.34621 .51433 Mdot
.5887 .3482 Mdot
.29878 .64243 Mdot
.36356 .55863 Mdot
.65254 .55179 Mdot
.23393 .42793 Mdot
.4988 .3875 Mdot
.28155 .49955 Mdot
.27918 .37734 Mdot
.36615 .53817 Mdot
.38952 .51717 Mdot
.32601 .49323 Mdot
.46154 .7743 Mdot
.604 .34954 Mdot
.61459 .31019 Mdot
.46282 .27575 Mdot
.2362 .43553 Mdot
.49176 .2737 Mdot
.70407 .53124 Mdot
.50788 .45697 Mdot
.51219 .56576 Mdot
.57114 .65478 Mdot
.37354 .55438 Mdot
.63255 .31973 Mdot
.34616 .52873 Mdot
.36085 .49223 Mdot
.6077 .33859 Mdot
.60718 .3293 Mdot
.64946 .36248 Mdot
.48818 .28702 Mdot
.58528 .66516 Mdot
.32706 .54178 Mdot
.49334 .2873 Mdot
.40681 .50432 Mdot
.3846 .3858 Mdot
.58712 .66763 Mdot
.56431 .68318 Mdot
.60214 .64249 Mdot
.33735 .50978 Mdot
.3306 .49203 Mdot
.68059 .52103 Mdot
.57997 .70298 Mdot
.68468 .49923 Mdot
.60639 .36428 Mdot
.58965 .33084 Mdot
.35425 .52747 Mdot
.40603 .48133 Mdot
.4772 .24913 Mdot
.61535 .37249 Mdot
.54761 .57955 Mdot
.47016 .28226 Mdot
.38947 .55104 Mdot
.60235 .36255 Mdot
.48552 .24416 Mdot
.38029 .75948 Mdot
.66406 .592 Mdot
.46625 .28099 Mdot
.33744 .48439 Mdot
.44894 .64929 Mdot
.30276 .34864 Mdot
.51152 .28848 Mdot
.68938 .52237 Mdot
.35907 .50843 Mdot
.57979 .50817 Mdot
.49327 .29359 Mdot
.34914 .32496 Mdot
.61034 .34525 Mdot
.291 .53297 Mdot
.40483 .61492 Mdot
.50194 .74635 Mdot
.47209 .29071 Mdot
.56816 .68671 Mdot
.55673 .68735 Mdot
.38665 .53786 Mdot
.50308 .46037 Mdot
.72222 .51335 Mdot
.58681 .36521 Mdot
.61812 .3101 Mdot
.549 .67742 Mdot
.39502 .41352 Mdot
.59048 .35181 Mdot
.37904 .51373 Mdot
.44571 .26579 Mdot
.42285 .55137 Mdot
.42519 .32035 Mdot
.24886 .61865 Mdot
.284 .4942 Mdot
.46916 .28719 Mdot
.71876 .51649 Mdot
.71568 .50221 Mdot
.70559 .49187 Mdot
.59098 .34258 Mdot
.30754 .39117 Mdot
.6103 .30612 Mdot
.72929 .73731 Mdot
.47306 .27826 Mdot
.30035 .25582 Mdot
.39154 .57688 Mdot
.33569 .52896 Mdot
.4161 .54827 Mdot
.39238 .49368 Mdot
.36493 .53873 Mdot
.66482 .50638 Mdot
.57724 .32082 Mdot
.6492 .43003 Mdot
.59264 .65025 Mdot
.65754 .76458 Mdot
.62586 .34806 Mdot
.54383 .56885 Mdot
.48387 .2501 Mdot
.23845 .40747 Mdot
.45237 .2627 Mdot
.607 .37572 Mdot
.3812 .56586 Mdot
.55023 .63375 Mdot
.26051 .31662 Mdot
.36516 .55494 Mdot
.61141 .37317 Mdot
.59402 .29729 Mdot
.3687 .74562 Mdot
.44578 .57265 Mdot
.63979 .4417 Mdot
.3461 .39584 Mdot
.45694 .26178 Mdot
.37813 .48353 Mdot
.26497 .40819 Mdot
.60428 .34512 Mdot
.61797 .31846 Mdot
.52125 .282 Mdot
.62105 .74486 Mdot
.60926 .66216 Mdot
.59121 .71979 Mdot
.66366 .49828 Mdot
.33315 .53106 Mdot
.5975 .35306 Mdot
.58073 .71447 Mdot
.40039 .36407 Mdot
.7018 .49772 Mdot
.62467 .37161 Mdot
.37952 .51971 Mdot
.38123 .52985 Mdot
.48959 .27554 Mdot
.54104 .43615 Mdot
.3348 .59435 Mdot
.72463 .70447 Mdot
.36323 .39492 Mdot
.47384 .46151 Mdot
.3475 .52035 Mdot
.55915 .65463 Mdot
.51676 .55083 Mdot
.49445 .25379 Mdot
.42552 .52573 Mdot
.4669 .81457 Mdot
.61403 .68205 Mdot
.68589 .49836 Mdot
.53392 .55143 Mdot
.26486 .43046 Mdot
.37795 .51916 Mdot
.3619 .52982 Mdot
.39976 .51023 Mdot
.39805 .79829 Mdot
.59214 .31444 Mdot
.55772 .66403 Mdot
.48363 .28379 Mdot
.56563 .67106 Mdot
.59469 .37812 Mdot
.52926 .44929 Mdot
.32221 .53531 Mdot
.6174 .66977 Mdot
.57272 .67787 Mdot
.70169 .51755 Mdot
.71572 .49055 Mdot
.62559 .30479 Mdot
.35807 .5105 Mdot
.51233 .5665 Mdot
.61099 .67264 Mdot
.57555 .34465 Mdot
.48935 .27376 Mdot
.68966 .56221 Mdot
.33306 .54326 Mdot
.59957 .34428 Mdot
.36094 .6018 Mdot
.58799 .65239 Mdot
.62299 .36493 Mdot
.53748 .57504 Mdot
.51254 .26464 Mdot
.39795 .54646 Mdot
.68175 .35041 Mdot
.54013 .56792 Mdot
.33161 .51693 Mdot
.26615 .63398 Mdot
.50412 .46034 Mdot
.55427 .58053 Mdot
.58422 .33357 Mdot
.53311 .57043 Mdot
.55203 .66431 Mdot
.33019 .71682 Mdot
.61145 .31417 Mdot
.40865 .63031 Mdot
.45802 .454 Mdot
.33385 .4871 Mdot
.56772 .6533 Mdot
.48381 .3422 Mdot
.69662 .71537 Mdot
.31235 .34791 Mdot
.34846 .54439 Mdot
.59948 .35991 Mdot
.49664 .27545 Mdot
.68574 .5109 Mdot
.70379 .46572 Mdot
.44214 .31148 Mdot
.63417 .34412 Mdot
.37365 .5548 Mdot
.6031 .68532 Mdot
.68806 .49479 Mdot
.33999 .64128 Mdot
.60042 .30242 Mdot
.58835 .35147 Mdot
.40891 .53728 Mdot
.49294 .27246 Mdot
.56862 .51249 Mdot
.59658 .31181 Mdot
.57983 .31539 Mdot
.52676 .71854 Mdot
.45829 .25831 Mdot
.39244 .50041 Mdot
.30409 .47809 Mdot
.40521 .5619 Mdot
.69466 .75291 Mdot
.53081 .57203 Mdot
.59132 .64838 Mdot
.37353 .53746 Mdot
.66538 .40973 Mdot
.60238 .31778 Mdot
.34658 .39619 Mdot
.69871 .53521 Mdot
.7114 .48721 Mdot
.60676 .35844 Mdot
.34953 .53655 Mdot
.64999 .47631 Mdot
.4644 .26492 Mdot
.39394 .50094 Mdot
.33941 .48554 Mdot
.5562 .69121 Mdot
.6693 .50002 Mdot
.28801 .6378 Mdot
.68074 .50852 Mdot
.68544 .48138 Mdot
.53312 .66014 Mdot
.38718 .53819 Mdot
.62412 .35523 Mdot
.63923 .36623 Mdot
.38898 .48384 Mdot
.54439 .36138 Mdot
.6028 .64893 Mdot
.5638 .31374 Mdot
.45749 .81685 Mdot
.38365 .57456 Mdot
.53474 .54974 Mdot
.57855 .54895 Mdot
.73333 .50142 Mdot
.381 .53551 Mdot
.57347 .65117 Mdot
.58435 .31398 Mdot
.59501 .35445 Mdot
.37974 .58366 Mdot
.7161 .50002 Mdot
.49382 .24535 Mdot
.6136 .33857 Mdot
.40483 .39962 Mdot
.34741 .54848 Mdot
.74729 .47849 Mdot
.61594 .34183 Mdot
.16062 .47366 Mdot
.66706 .41165 Mdot
.58546 .69367 Mdot
.39931 .51833 Mdot
.5449 .67413 Mdot
.46068 .2637 Mdot
.56873 .33607 Mdot
.71037 .51832 Mdot
.42461 .59013 Mdot
.80569 .40641 Mdot
.59363 .34524 Mdot
.57487 .66351 Mdot
.37946 .54569 Mdot
.48596 .7457 Mdot
.34172 .51345 Mdot
.37917 .27899 Mdot
.50202 .29403 Mdot
.69088 .56002 Mdot
.71832 .51166 Mdot
.39306 .5093 Mdot
.50205 .28207 Mdot
.64201 .36493 Mdot
.60714 .33915 Mdot
.81633 .46219 Mdot
.54232 .57319 Mdot
.58729 .38391 Mdot
.33519 .51331 Mdot
.5804 .35409 Mdot
.46605 .64987 Mdot
.71453 .49339 Mdot
.40416 .56126 Mdot
.63358 .36455 Mdot
.67052 .73316 Mdot
.34673 .38948 Mdot
.34834 .54734 Mdot
.38787 .47141 Mdot
.70968 .51232 Mdot
.63009 .7661 Mdot
.58672 .3189 Mdot
.41575 .51267 Mdot
.70433 .53284 Mdot
.26705 .51309 Mdot
.62678 .43446 Mdot
.58572 .6653 Mdot
.62883 .37334 Mdot
.67352 .48484 Mdot
.29236 .53135 Mdot
.49354 .24785 Mdot
.61453 .30097 Mdot
.64003 .34568 Mdot
.33278 .49775 Mdot
.40624 .50972 Mdot
.38666 .46974 Mdot
.57857 .63848 Mdot
.68219 .48572 Mdot
.36651 .49114 Mdot
.37918 .38051 Mdot
.38319 .49068 Mdot
.67745 .48755 Mdot
.86005 .57981 Mdot
.38509 .56373 Mdot
.33295 .54115 Mdot
.48061 .75612 Mdot
.56939 .63154 Mdot
.56064 .68739 Mdot
.37015 .39257 Mdot
.35332 .50294 Mdot
.49001 .4771 Mdot
.58218 .66324 Mdot
.57262 .66573 Mdot
.49087 .47632 Mdot
.3299 .497 Mdot
.56398 .71039 Mdot
.68958 .49314 Mdot
.71226 .48766 Mdot
.58721 .69103 Mdot
.42073 .54278 Mdot
.70631 .52926 Mdot
.4091 .75428 Mdot
.61296 .37578 Mdot
.26234 .41337 Mdot
.57209 .68093 Mdot
.34083 .38593 Mdot
.68608 .48922 Mdot
.18609 .49647 Mdot
.21372 .45259 Mdot
.36667 .57392 Mdot
.38457 .53574 Mdot
.47745 .26663 Mdot
.41729 .59351 Mdot
.51333 .55135 Mdot
.70526 .4908 Mdot
.56206 .49655 Mdot
.59133 .67129 Mdot
.3513 .50431 Mdot
.33316 .34509 Mdot
.1937 .55297 Mdot
.36209 .44991 Mdot
.57672 .67209 Mdot
.59031 .67987 Mdot
.58606 .35211 Mdot
.60082 .37628 Mdot
.32547 .5409 Mdot
.71457 .50708 Mdot
.59314 .69199 Mdot
.67396 .49376 Mdot
.60534 .34465 Mdot
.62439 .34686 Mdot
.51008 .55948 Mdot
.29346 .55355 Mdot
.60941 .35449 Mdot
.642 .53782 Mdot
.37993 .38137 Mdot
.57564 .70392 Mdot
.75017 .72364 Mdot
.18851 .47896 Mdot
.51702 .78085 Mdot
.49671 .27687 Mdot
.26242 .51687 Mdot
.68539 .52597 Mdot
.39077 .50646 Mdot
.36446 .52678 Mdot
.52932 .56139 Mdot
.6887 .52829 Mdot
.47265 .25857 Mdot
.71321 .49016 Mdot
.50269 .25699 Mdot
.62122 .31436 Mdot
.36747 .55684 Mdot
.35982 .56349 Mdot
.68886 .51255 Mdot
.59135 .36425 Mdot
.62145 .37091 Mdot
.50224 .26778 Mdot
.23643 .41104 Mdot
.59851 .3412 Mdot
.57122 .67926 Mdot
.38399 .64494 Mdot
.52221 .56236 Mdot
.35359 .53369 Mdot
.27461 .38019 Mdot
.31954 .7052 Mdot
.40341 .4975 Mdot
.53524 .5539 Mdot
.83406 .63864 Mdot
.35613 .55889 Mdot
.79488 .36063 Mdot
.51359 .56617 Mdot
.56785 .63492 Mdot
.61958 .3612 Mdot
.54242 .56841 Mdot
.25444 .55399 Mdot
.66032 .32045 Mdot
.39683 .48882 Mdot
.6097 .66157 Mdot
.59262 .63746 Mdot
.52931 .45147 Mdot
.69185 .75541 Mdot
.48489 .28387 Mdot
.46753 .26539 Mdot
.60331 .31475 Mdot
.7137 .56273 Mdot
.41633 .56635 Mdot
.46933 .26939 Mdot
.57053 .72043 Mdot
.40442 .51984 Mdot
.50776 .4598 Mdot
.54278 .46894 Mdot
.55221 .66937 Mdot
.30285 .52515 Mdot
.60327 .3159 Mdot
.57668 .66473 Mdot
.53371 .45933 Mdot
.41093 .54636 Mdot
.5889 .66909 Mdot
.69133 .48259 Mdot
.47428 .52221 Mdot
.56817 .68169 Mdot
.32845 .41312 Mdot
.69126 .50886 Mdot
.51419 .45521 Mdot
.32972 .26155 Mdot
.14769 .54416 Mdot
.71376 .49904 Mdot
.61244 .37082 Mdot
.59817 .35228 Mdot
.59672 .33577 Mdot
.56845 .64478 Mdot
.60753 .32444 Mdot
.60048 .65309 Mdot
.73614 .49086 Mdot
.24458 .43141 Mdot
.48395 .27043 Mdot
.50747 .34602 Mdot
.58316 .69009 Mdot
.71887 .74274 Mdot
.6448 .82893 Mdot
.39006 .49447 Mdot
.71995 .48531 Mdot
.48218 .28978 Mdot
.36006 .40636 Mdot
.47543 .26592 Mdot
.61622 .36723 Mdot
.25857 .42996 Mdot
.34312 .53334 Mdot
.65267 .57448 Mdot
.49639 .27442 Mdot
.57123 .66594 Mdot
.33647 .50272 Mdot
.62027 .38164 Mdot
.46214 .26298 Mdot
.49835 .26547 Mdot
.36304 .53773 Mdot
.57829 .63177 Mdot
.62042 .36919 Mdot
.66085 .5015 Mdot
.44578 .25639 Mdot
.44364 .53257 Mdot
.36256 .56053 Mdot
.35767 .56723 Mdot
.35184 .38718 Mdot
.71512 .56364 Mdot
.69272 .50735 Mdot
.35147 .32604 Mdot
.59136 .32314 Mdot
.31258 .34554 Mdot
.71588 .6999 Mdot
.48707 .33922 Mdot
.52992 .57139 Mdot
.52908 .57288 Mdot
.35966 .54962 Mdot
.55758 .84709 Mdot
.47277 .54961 Mdot
.71461 .53004 Mdot
.52481 .55867 Mdot
.60883 .37778 Mdot
.58847 .70094 Mdot
.41702 .60833 Mdot
.3883 .58005 Mdot
.66152 .50372 Mdot
.60271 .33884 Mdot
.48925 .86332 Mdot
.47742 .28023 Mdot
.36518 .40767 Mdot
.36187 .51213 Mdot
.35802 .54444 Mdot
.70131 .5029 Mdot
.70793 .51998 Mdot
.52509 .71708 Mdot
.48754 .37852 Mdot
.72836 .57421 Mdot
.65722 .4787 Mdot
.48658 .86431 Mdot
.57532 .56349 Mdot
.59857 .67134 Mdot
.51471 .54736 Mdot
.7219 .51182 Mdot
.37014 .53452 Mdot
.57178 .63149 Mdot
.47524 .55695 Mdot
.5715 .62296 Mdot
.50015 .46291 Mdot
.39947 .39479 Mdot
.38981 .53043 Mdot
.54999 .64247 Mdot
.58127 .66692 Mdot
.62508 .68014 Mdot
.51546 .5556 Mdot
.35083 .51883 Mdot
.41557 .50979 Mdot
.34172 .55481 Mdot
.50411 .66894 Mdot
.3582 .55226 Mdot
.71152 .70471 Mdot
.38113 .39827 Mdot
.58343 .19087 Mdot
.34907 .55592 Mdot
.6932 .48044 Mdot
.37351 .55209 Mdot
.50485 .28012 Mdot
.39562 .55462 Mdot
.49307 .4639 Mdot
.69164 .49678 Mdot
.47581 .8028 Mdot
.63122 .30096 Mdot
.36795 .56212 Mdot
.46969 .24576 Mdot
.79133 .6353 Mdot
.35098 .32989 Mdot
.52703 .71747 Mdot
.57153 .68359 Mdot
.58595 .30694 Mdot
.72603 .50664 Mdot
.62073 .33726 Mdot
.32609 .55991 Mdot
.50801 .55184 Mdot
.28564 .25292 Mdot
.34896 .36473 Mdot
.3721 .53657 Mdot
.31675 .58065 Mdot
.55858 .67546 Mdot
.60508 .31789 Mdot
.55373 .77825 Mdot
.41674 .54272 Mdot
.51654 .26981 Mdot
.49395 .29057 Mdot
.55773 .28752 Mdot
.52218 .62688 Mdot
.48407 .65235 Mdot
.69928 .50311 Mdot
.59141 .34605 Mdot
.48451 .2926 Mdot
.60669 .7237 Mdot
.72428 .50321 Mdot
.73374 .50294 Mdot
.66831 .4988 Mdot
.33954 .54339 Mdot
.51532 .56435 Mdot
.52506 .6647 Mdot
.53992 .57212 Mdot
.41077 .56102 Mdot
.63987 .34734 Mdot
.53625 .57378 Mdot
.48453 .26476 Mdot
.67937 .48176 Mdot
.627 .34999 Mdot
.36912 .54512 Mdot
.58261 .65915 Mdot
.43338 .34092 Mdot
.67678 .39614 Mdot
.50465 .45944 Mdot
.50475 .45937 Mdot
.61561 .69229 Mdot
.5788 .52645 Mdot
.7434 .52961 Mdot
.35728 .74055 Mdot
.44063 .26256 Mdot
.43473 .54594 Mdot
.55065 .36079 Mdot
.6082 .30553 Mdot
.61528 .35099 Mdot
.34007 .53203 Mdot
.57814 .34255 Mdot
.34855 .50694 Mdot
.58367 .33397 Mdot
.69412 .72879 Mdot
.36371 .58042 Mdot
.61193 .34121 Mdot
.43751 .58418 Mdot
.32899 .51936 Mdot
.55948 .66179 Mdot
.59148 .30706 Mdot
.36744 .57409 Mdot
.43495 .14669 Mdot
.69985 .51722 Mdot
.51595 .55694 Mdot
.44653 .42898 Mdot
.69242 .48712 Mdot
.60662 .66261 Mdot
.3672 .50925 Mdot
.47035 .27734 Mdot
.59678 .67746 Mdot
.58948 .28479 Mdot
.49547 .26973 Mdot
.40106 .42029 Mdot
.5946 .68422 Mdot
.52379 .56518 Mdot
.51476 .27381 Mdot
.39202 .48664 Mdot
.61369 .34813 Mdot
.67417 .40386 Mdot
.53892 .55776 Mdot
.34363 .52958 Mdot
.61722 .3806 Mdot
.70801 .48724 Mdot
.3841 .55271 Mdot
.5968 .35377 Mdot
.52455 .54821 Mdot
.32776 .5309 Mdot
.34162 .50381 Mdot
.60609 .76155 Mdot
.53158 .41614 Mdot
.48429 .26795 Mdot
.58609 .7111 Mdot
.40556 .56926 Mdot
.50251 .2792 Mdot
.65605 .40775 Mdot
.30614 .50713 Mdot
.6132 .67339 Mdot
.39946 .75286 Mdot
.58562 .36271 Mdot
.71835 .50164 Mdot
.64347 .33458 Mdot
.45976 .26827 Mdot
.69705 .80637 Mdot
.51148 .5525 Mdot
.31556 .50255 Mdot
.39179 .56827 Mdot
.57075 .32018 Mdot
.58363 .66944 Mdot
.72322 .57755 Mdot
.39906 .54436 Mdot
.31939 .57749 Mdot
.35805 .53537 Mdot
.67741 .3371 Mdot
.57262 .64012 Mdot
.35567 .53385 Mdot
.42089 .50056 Mdot
.39271 .57098 Mdot
.47551 .24675 Mdot
.29623 .26079 Mdot
.36865 .48399 Mdot
.90261 .48464 Mdot
.50625 .54387 Mdot
.60456 .33469 Mdot
.33166 .41266 Mdot
.44886 .42472 Mdot
.51207 .16896 Mdot
.60508 .6557 Mdot
.62917 .67555 Mdot
.6236 .34708 Mdot
.46014 .32774 Mdot
.57186 .52328 Mdot
.34164 .50136 Mdot
.36748 .51253 Mdot
.61632 .36717 Mdot
.57495 .34442 Mdot
.50668 .54637 Mdot
.32993 .48558 Mdot
.29835 .52225 Mdot
.6418 .33792 Mdot
.36095 .5549 Mdot
.30563 .69157 Mdot
.71338 .47666 Mdot
.58032 .69322 Mdot
.68555 .51232 Mdot
.70115 .47238 Mdot
.53237 .78452 Mdot
.36144 .39207 Mdot
.66347 .5004 Mdot
.73424 .52497 Mdot
.48656 .34519 Mdot
.49997 .74991 Mdot
.47998 .24593 Mdot
.47839 .54469 Mdot
.59318 .32911 Mdot
.35306 .51871 Mdot
.57034 .64106 Mdot
.40948 .24854 Mdot
.7492 .57861 Mdot
.23627 .53172 Mdot
.39223 .50116 Mdot
.59762 .32207 Mdot
.53794 .55485 Mdot
.30626 .50541 Mdot
.30565 .34751 Mdot
.35344 .54658 Mdot
.59017 .36996 Mdot
.50355 .75041 Mdot
.65077 .44644 Mdot
.67067 .46325 Mdot
.57967 .6085 Mdot
.37419 .55243 Mdot
.57955 .64262 Mdot
.66739 .47714 Mdot
.49649 .28282 Mdot
.4767 .27352 Mdot
.36925 .56238 Mdot
.47351 .46219 Mdot
.44163 .27507 Mdot
.33797 .50377 Mdot
.3327 .49595 Mdot
.53189 .56929 Mdot
.33378 .49428 Mdot
.41587 .50694 Mdot
.37354 .49302 Mdot
.40619 .50518 Mdot
.7233 .50607 Mdot
.5306 .77281 Mdot
.32321 .4918 Mdot
.32099 .54466 Mdot
.67863 .47277 Mdot
.32119 .55005 Mdot
.71003 .50015 Mdot
.7547 .55128 Mdot
.6701 .51082 Mdot
.47857 .274 Mdot
.61371 .38291 Mdot
.58408 .75622 Mdot
.59419 .69111 Mdot
.70569 .48058 Mdot
.50827 .25809 Mdot
.70992 .4937 Mdot
.58751 .33502 Mdot
.64224 .46221 Mdot
.54604 .60342 Mdot
.40931 .4051 Mdot
.49684 .75948 Mdot
.74054 .4635 Mdot
.58114 .34953 Mdot
.59103 .69108 Mdot
.66654 .5578 Mdot
.38926 .50589 Mdot
.47968 .28261 Mdot
.36012 .54896 Mdot
.68215 .48127 Mdot
.5949 .32652 Mdot
.55839 .74377 Mdot
.48322 .26748 Mdot
.77679 .70215 Mdot
.6329 .31966 Mdot
.39254 .56433 Mdot
.67521 .47298 Mdot
.63789 .51344 Mdot
.70771 .51726 Mdot
.24336 .42752 Mdot
.57925 .53801 Mdot
.41618 .27416 Mdot
.59112 .68241 Mdot
.54352 .5823 Mdot
.18052 .62253 Mdot
.76346 .62483 Mdot
.58512 .65422 Mdot
.62804 .40371 Mdot
.34964 .55233 Mdot
.38066 .49253 Mdot
.30208 .5649 Mdot
.57304 .62654 Mdot
.40021 .51096 Mdot
.5145 .55883 Mdot
.36494 .38393 Mdot
.53931 .60034 Mdot
.60281 .29761 Mdot
.34665 .50891 Mdot
.66528 .47548 Mdot
.70856 .48046 Mdot
.52793 .57671 Mdot
.67575 .50598 Mdot
.32219 .52008 Mdot
.5864 .6883 Mdot
.5375 .46364 Mdot
.46151 .26772 Mdot
.74474 .67906 Mdot
.4726 .30126 Mdot
.45374 .25004 Mdot
.38417 .57502 Mdot
.62468 .35048 Mdot
.79446 .37848 Mdot
.39255 .50589 Mdot
.57957 .66318 Mdot
.39583 .56496 Mdot
.37095 .49037 Mdot
.31896 .51835 Mdot
.5915 .34545 Mdot
.34535 .38761 Mdot
.36177 .55514 Mdot
.66234 .48657 Mdot
.48835 .47468 Mdot
.38878 .58079 Mdot
.57524 .4829 Mdot
.49579 .46389 Mdot
.73708 .46656 Mdot
.56444 .69806 Mdot
.62293 .35659 Mdot
.5925 .67352 Mdot
.57032 .61759 Mdot
.60637 .66251 Mdot
.52691 .64035 Mdot
.34717 .73272 Mdot
.79077 .3502 Mdot
.47037 .65101 Mdot
.49745 .76356 Mdot
.56614 .61359 Mdot
.71197 .31146 Mdot
.5803 .65114 Mdot
.60624 .66033 Mdot
.83669 .54356 Mdot
.59161 .63963 Mdot
.35348 .52692 Mdot
.35965 .56582 Mdot
.42226 .80537 Mdot
.46639 .23281 Mdot
.33232 .52 Mdot
.40567 .50233 Mdot
.48982 .29199 Mdot
.61836 .74477 Mdot
.52241 .54439 Mdot
.36952 .41083 Mdot
.54459 .57698 Mdot
.36356 .53846 Mdot
.39324 .54076 Mdot
.42978 .56795 Mdot
.19764 .58042 Mdot
.42786 .28826 Mdot
.5951 .63778 Mdot
.42902 .52071 Mdot
.71872 .44661 Mdot
.39348 .52272 Mdot
.40328 .55533 Mdot
.31983 .5123 Mdot
.62418 .35511 Mdot
.60321 .6949 Mdot
.34034 .59678 Mdot
.7649 .6495 Mdot
.37931 .52123 Mdot
.48558 .30309 Mdot
.51443 .25149 Mdot
.34922 .53514 Mdot
.60106 .64469 Mdot
.38548 .49498 Mdot
.57348 .69667 Mdot
.59797 .68058 Mdot
.30071 .55489 Mdot
.53127 .68679 Mdot
.59031 .70016 Mdot
.34286 .50109 Mdot
.58804 .36051 Mdot
.72847 .70155 Mdot
.34452 .53103 Mdot
.48961 .26453 Mdot
.38252 .53894 Mdot
.47169 .24702 Mdot
.35072 .48429 Mdot
.53721 .57159 Mdot
.25441 .64859 Mdot
.61806 .31738 Mdot
.4507 .26556 Mdot
.57902 .34919 Mdot
.42299 .5603 Mdot
.53939 .65936 Mdot
.65018 .45161 Mdot
.44251 .30307 Mdot
.53092 .56934 Mdot
.37146 .31114 Mdot
.49735 .48379 Mdot
.68587 .52451 Mdot
.55691 .66434 Mdot
.52241 .76103 Mdot
.5722 .48013 Mdot
.60396 .29656 Mdot
.618 .37675 Mdot
.62178 .42971 Mdot
.83376 .56511 Mdot
.3475 .554 Mdot
.58199 .50458 Mdot
.32171 .6746 Mdot
.41471 .59456 Mdot
.44825 .57806 Mdot
.6403 .34377 Mdot
.33226 .51941 Mdot
.33731 .36817 Mdot
.59944 .34908 Mdot
.47253 .25317 Mdot
.58998 .64693 Mdot
.50743 .27002 Mdot
.68583 .60375 Mdot
.53273 .72725 Mdot
.60631 .35237 Mdot
.40306 .50443 Mdot
.33466 .52194 Mdot
.56554 .63463 Mdot
.34031 .64073 Mdot
.57535 .69368 Mdot
.46745 .27847 Mdot
.60822 .31202 Mdot
.36946 .18055 Mdot
.38124 .54554 Mdot
.57234 .67568 Mdot
.63373 .30317 Mdot
.37885 .52747 Mdot
.71662 .4983 Mdot
.4019 .51391 Mdot
.56769 .67108 Mdot
.33477 .49324 Mdot
.59264 .68209 Mdot
.59097 .35894 Mdot
.36574 .56357 Mdot
.38926 .5502 Mdot
.35543 .32193 Mdot
.47354 .25836 Mdot
.58434 .69938 Mdot
.33179 .37488 Mdot
.40523 .56192 Mdot
.29125 .35934 Mdot
.36538 .55771 Mdot
.49329 .75121 Mdot
.34145 .46508 Mdot
.51592 .56123 Mdot
.39616 .56541 Mdot
.34478 .53317 Mdot
.34083 .63907 Mdot
.46144 .6491 Mdot
.50565 .67217 Mdot
.7175 .49216 Mdot
.5643 .6527 Mdot
.60121 .35467 Mdot
.58774 .30826 Mdot
.6121 .32793 Mdot
.49263 .29784 Mdot
.39414 .48491 Mdot
.34252 .52375 Mdot
.72537 .52648 Mdot
.4713 .27418 Mdot
.57784 .67663 Mdot
.48319 .27559 Mdot
.35827 .3954 Mdot
.48901 .26152 Mdot
.51358 .55011 Mdot
.66175 .41743 Mdot
.31463 .69898 Mdot
.48912 .25366 Mdot
.58378 .69294 Mdot
.47938 .47574 Mdot
.41096 .59471 Mdot
.67171 .76096 Mdot
.51705 .27482 Mdot
.64359 .40609 Mdot
.32705 .53498 Mdot
.31928 .41258 Mdot
.70757 .4994 Mdot
.50806 .26946 Mdot
.66846 .50113 Mdot
.38544 .49547 Mdot
.61759 .62783 Mdot
.57159 .6591 Mdot
.70974 .47441 Mdot
.40554 .55642 Mdot
.50806 .27017 Mdot
.60977 .35158 Mdot
.49972 .74831 Mdot
.73013 .48554 Mdot
.4451 .3462 Mdot
.31331 .34696 Mdot
.59898 .31474 Mdot
.47852 .72566 Mdot
.66992 .50857 Mdot
.42983 .52382 Mdot
.45795 .52853 Mdot
.41975 .5537 Mdot
.62258 .37005 Mdot
.61592 .35144 Mdot
.76573 .49168 Mdot
.39212 .5481 Mdot
.31904 .49905 Mdot
.58387 .70785 Mdot
.60211 .31226 Mdot
.60643 .66484 Mdot
.54631 .65333 Mdot
.61095 .37011 Mdot
.57224 .69417 Mdot
.49672 .26923 Mdot
.29059 .39476 Mdot
.66887 .50758 Mdot
.71781 .51009 Mdot
.608 .35439 Mdot
.62995 .32984 Mdot
.62497 .34946 Mdot
.4134 .53995 Mdot
.6022 .67751 Mdot
.39366 .51353 Mdot
.37637 .55041 Mdot
.5346 .54721 Mdot
.55216 .69396 Mdot
.40233 .52801 Mdot
.54392 .47353 Mdot
.51898 .27644 Mdot
.60938 .33622 Mdot
.67809 .49123 Mdot
.42629 .33277 Mdot
.66005 .495 Mdot
.39952 .56864 Mdot
.67352 .73896 Mdot
.56705 .65022 Mdot
.47627 .26602 Mdot
.49446 .46263 Mdot
.48039 .26702 Mdot
.71227 .47589 Mdot
.61082 .70079 Mdot
.39724 .41682 Mdot
.38939 .55243 Mdot
.35337 .38594 Mdot
.33307 .2797 Mdot
.72163 .69085 Mdot
.68497 .48465 Mdot
.38843 .49518 Mdot
.52233 .57085 Mdot
.35968 .74352 Mdot
.34145 .52656 Mdot
.36704 .57826 Mdot
.46937 .44286 Mdot
.38519 .57159 Mdot
.61201 .65072 Mdot
.51204 .46182 Mdot
.38498 .48685 Mdot
.42427 .54797 Mdot
.81098 .4847 Mdot
.32913 .52762 Mdot
.38322 .55642 Mdot
.35926 .52287 Mdot
.40135 .51734 Mdot
.54529 .67519 Mdot
.52418 .44609 Mdot
.67046 .47607 Mdot
.29037 .3946 Mdot
.66588 .49684 Mdot
.61045 .36127 Mdot
.47119 .36805 Mdot
.56144 .692 Mdot
.48051 .26644 Mdot
.59065 .50343 Mdot
.25938 .43406 Mdot
.58639 .35372 Mdot
.3742 .30041 Mdot
.49585 .24714 Mdot
.39543 .60022 Mdot
.45885 .26685 Mdot
.63682 .36022 Mdot
.71547 .49913 Mdot
.38232 .56558 Mdot
.61009 .67202 Mdot
.56763 .68204 Mdot
.41482 .56431 Mdot
.76361 .66275 Mdot
.71942 .5013 Mdot
.53858 .35763 Mdot
.33928 .53948 Mdot
.40441 .561 Mdot
.56443 .6909 Mdot
.60253 .31907 Mdot
.49812 .48198 Mdot
.49102 .25013 Mdot
.38945 .52262 Mdot
.3962 .49549 Mdot
.35773 .39403 Mdot
.71493 .48663 Mdot
.5237 .55378 Mdot
.34214 .51649 Mdot
.36977 .40276 Mdot
.40534 .51759 Mdot
.42953 .55804 Mdot
.59143 .36774 Mdot
.30934 .56718 Mdot
.39664 .53806 Mdot
.57107 .60594 Mdot
.67215 .51071 Mdot
.58507 .66714 Mdot
.62124 .65221 Mdot
.53522 .57135 Mdot
.69863 .51631 Mdot
.40537 .53324 Mdot
.72915 .49471 Mdot
.37623 .49134 Mdot
.36892 .5491 Mdot
.68749 .48362 Mdot
.60395 .66332 Mdot
.71298 .57459 Mdot
.5309 .77196 Mdot
.36251 .49206 Mdot
.38153 .53504 Mdot
.46667 .23278 Mdot
.42251 .23077 Mdot
.39525 .54792 Mdot
.58944 .69262 Mdot
.38199 .53028 Mdot
.70212 .52407 Mdot
.48668 .28372 Mdot
.57871 .65888 Mdot
.592 .31834 Mdot
.59153 .35803 Mdot
.6506 .33496 Mdot
.51291 .54985 Mdot
.31996 .49985 Mdot
.58569 .71102 Mdot
.55118 .69418 Mdot
.30483 .40077 Mdot
.60565 .33526 Mdot
.49205 .28083 Mdot
.33528 .51168 Mdot
.41777 .59485 Mdot
.69436 .47273 Mdot
.905 .47173 Mdot
.39328 .41479 Mdot
.52084 .26611 Mdot
.49161 .38599 Mdot
.53313 .56374 Mdot
.33153 .53464 Mdot
.50573 .27675 Mdot
.60541 .36708 Mdot
.3813 .49259 Mdot
.34773 .46554 Mdot
.65456 .40569 Mdot
.62966 .33997 Mdot
.72879 .49076 Mdot
.58565 .32686 Mdot
.48808 .24479 Mdot
.51291 .5518 Mdot
.56176 .66479 Mdot
.34979 .54081 Mdot
.30042 .51218 Mdot
.59707 .33158 Mdot
.50378 .55668 Mdot
.35448 .56192 Mdot
.56323 .65036 Mdot
.6066 .32777 Mdot
.36416 .53445 Mdot
.37185 .74553 Mdot
.58597 .75586 Mdot
.59264 .3263 Mdot
.37534 .51205 Mdot
.39243 .61808 Mdot
.63014 .34481 Mdot
.63563 .36096 Mdot
.392 .49617 Mdot
.51076 .27014 Mdot
.39137 .53032 Mdot
.71296 .50775 Mdot
.34599 .3832 Mdot
.69165 .51412 Mdot
.30349 .34741 Mdot
.41516 .5166 Mdot
.42844 .48266 Mdot
.55765 .62453 Mdot
.45072 .27805 Mdot
.19598 .46378 Mdot
.39278 .57363 Mdot
.63159 .73178 Mdot
.34168 .38513 Mdot
.41991 .41731 Mdot
.63896 .71096 Mdot
.49786 .25295 Mdot
.70615 .49216 Mdot
.37305 .5604 Mdot
.70506 .56929 Mdot
.49955 .25652 Mdot
.30179 .34862 Mdot
.37717 .50679 Mdot
.57523 .6686 Mdot
.34211 .54404 Mdot
.56352 .66441 Mdot
.3691 .52191 Mdot
.60967 .76191 Mdot
.44109 .27184 Mdot
.24304 .42802 Mdot
.39685 .59965 Mdot
.63789 .51201 Mdot
.49698 .76016 Mdot
.49264 .27499 Mdot
.34447 .49177 Mdot
.53322 .55725 Mdot
.71296 .48988 Mdot
.62089 .50394 Mdot
.62361 .34552 Mdot
.66291 .48711 Mdot
.59963 .66376 Mdot
.63197 .37709 Mdot
.51355 .56808 Mdot
.28811 .47671 Mdot
.50857 .2715 Mdot
.70038 .51671 Mdot
.34672 .5354 Mdot
.41772 .55517 Mdot
.67776 .33745 Mdot
.28668 .26433 Mdot
.54311 .66431 Mdot
.80465 .6744 Mdot
.60683 .70455 Mdot
.46921 .26222 Mdot
.59602 .37127 Mdot
.37074 .53306 Mdot
.3551 .51163 Mdot
.62855 .33735 Mdot
.56362 .63745 Mdot
.45369 .2526 Mdot
.41645 .26599 Mdot
.71162 .53006 Mdot
.29426 .27908 Mdot
.57571 .65653 Mdot
.29543 .27792 Mdot
.51599 .32305 Mdot
.56793 .73633 Mdot
.22247 .42518 Mdot
.69151 .48983 Mdot
.29371 .27881 Mdot
.5729 .67036 Mdot
.34014 .54972 Mdot
.52538 .56454 Mdot
.50558 .55381 Mdot
.58135 .64493 Mdot
.61893 .36626 Mdot
.49734 .24916 Mdot
.34243 .5423 Mdot
.2964 .47889 Mdot
.34015 .64143 Mdot
.61973 .31404 Mdot
.33026 .58875 Mdot
.68368 .49361 Mdot
.37991 .52997 Mdot
.48442 .29161 Mdot
.69266 .49114 Mdot
.54032 .57504 Mdot
.26107 .42889 Mdot
.36778 .50946 Mdot
.48468 .46516 Mdot
.70606 .5022 Mdot
.41955 .23177 Mdot
.3905 .54809 Mdot
.66987 .50843 Mdot
.29982 .51468 Mdot
.72873 .44813 Mdot
.52393 .47293 Mdot
.7625 .62494 Mdot
.64017 .32309 Mdot
.58396 .33408 Mdot
.4315 .15352 Mdot
.522 .17994 Mdot
.67217 .48172 Mdot
.53405 .55023 Mdot
.29431 .25901 Mdot
.67241 .508 Mdot
.40116 .54371 Mdot
.35852 .55827 Mdot
.50396 .75064 Mdot
.4289 .58769 Mdot
.50833 .54442 Mdot
.50304 .59426 Mdot
.32393 .51324 Mdot
.33924 .59444 Mdot
.38017 .5545 Mdot
.58977 .63527 Mdot
.68635 .49377 Mdot
.28363 .7593 Mdot
.72598 .49543 Mdot
.4212 .47819 Mdot
.59333 .32868 Mdot
.6468 .34285 Mdot
.3503 .5362 Mdot
.4765 .58082 Mdot
.49502 .86768 Mdot
.36222 .55979 Mdot
.49387 .46282 Mdot
.31584 .34533 Mdot
.40696 .49337 Mdot
.60907 .68521 Mdot
.29787 .51789 Mdot
.56703 .70763 Mdot
.69626 .48926 Mdot
.49835 .25363 Mdot
.45221 .28469 Mdot
.7066 .49411 Mdot
.35425 .51279 Mdot
.46301 .29366 Mdot
.35801 .54176 Mdot
.33365 .53151 Mdot
.36429 .40252 Mdot
.47627 .2883 Mdot
.62501 .35853 Mdot
.47776 .27219 Mdot
.60377 .65175 Mdot
.85276 .59883 Mdot
.48763 .27675 Mdot
.50024 .75004 Mdot
.33671 .37649 Mdot
.30222 .25978 Mdot
.56467 .68048 Mdot
.46085 .26691 Mdot
.70387 .48762 Mdot
.41495 .43091 Mdot
.4738 .7585 Mdot
.66028 .49619 Mdot
.34144 .52087 Mdot
.54442 .67289 Mdot
.61098 .69905 Mdot
.6571 .49314 Mdot
.55941 .66561 Mdot
.37471 .47302 Mdot
.35106 .49866 Mdot
.66705 .47823 Mdot
.18817 .54809 Mdot
.71915 .51051 Mdot
.54365 .78385 Mdot
.3258 .49683 Mdot
.57943 .66135 Mdot
.49091 .75341 Mdot
.62152 .64628 Mdot
.50901 .55717 Mdot
.3916 .5575 Mdot
.48926 .27961 Mdot
.30765 .39097 Mdot
.59465 .32126 Mdot
.67239 .73237 Mdot
.57235 .68283 Mdot
.65481 .49901 Mdot
.56005 .66442 Mdot
.55572 .67037 Mdot
.70076 .47103 Mdot
.56854 .65041 Mdot
.37722 .5199 Mdot
.6221 .76597 Mdot
.56387 .6843 Mdot
.69751 .50035 Mdot
.46629 .27505 Mdot
.5859 .69364 Mdot
.5322 .36155 Mdot
.33824 .51127 Mdot
.60346 .30209 Mdot
.46088 .21839 Mdot
.5491 .64761 Mdot
.49329 .27603 Mdot
.60041 .33069 Mdot
.51214 .26036 Mdot
.73458 .55338 Mdot
.65873 .5516 Mdot
.25493 .57212 Mdot
.70927 .43857 Mdot
.59604 .64293 Mdot
.63908 .37284 Mdot
.37574 .51487 Mdot
.33716 .53717 Mdot
.49743 .29524 Mdot
.61828 .66717 Mdot
.77546 .64985 Mdot
.4772 .55489 Mdot
.74609 .67726 Mdot
.71745 .49112 Mdot
.52305 .35083 Mdot
.39952 .41629 Mdot
.70674 .45677 Mdot
.37679 .48327 Mdot
.5325 .56323 Mdot
.35771 .53459 Mdot
.35002 .33057 Mdot
.48914 .24549 Mdot
.70946 .34101 Mdot
.41998 .5417 Mdot
.62648 .33279 Mdot
.36844 .52398 Mdot
.5697 .50527 Mdot
.42471 .54131 Mdot
.51703 .28046 Mdot
.70356 .53284 Mdot
.59383 .69138 Mdot
.46278 .25647 Mdot
.59314 .3609 Mdot
.22107 .46011 Mdot
.40005 .53628 Mdot
.32351 .52065 Mdot
.6301 .3576 Mdot
.60849 .66719 Mdot
.61383 .35803 Mdot
.66813 .50633 Mdot
.48639 .27435 Mdot
.40881 .52723 Mdot
.33553 .5914 Mdot
.56969 .32319 Mdot
.69738 .47608 Mdot
.61147 .37964 Mdot
.72793 .49214 Mdot
.52906 .56666 Mdot
.42815 .54173 Mdot
.60651 .38203 Mdot
.37081 .48239 Mdot
.46313 .69187 Mdot
.26656 .43066 Mdot
.3578 .63493 Mdot
.62267 .36686 Mdot
.52137 .17111 Mdot
.6952 .49407 Mdot
.69623 .51957 Mdot
.55078 .78585 Mdot
.54827 .85197 Mdot
.49036 .47711 Mdot
.79606 .62057 Mdot
.66818 .50666 Mdot
.70573 .50645 Mdot
.6176 .3594 Mdot
.60182 .65246 Mdot
.56085 .62499 Mdot
.61967 .37896 Mdot
.27015 .38472 Mdot
.57755 .67656 Mdot
.44645 .81416 Mdot
.6153 .30799 Mdot
.31692 .53051 Mdot
.57155 .74967 Mdot
.51716 .27828 Mdot
.32722 .34753 Mdot
.63981 .46338 Mdot
.36202 .52909 Mdot
.7984 .36827 Mdot
.62191 .3446 Mdot
.48309 .55357 Mdot
.67922 .5353 Mdot
.41329 .54836 Mdot
.36201 .52122 Mdot
.38228 .52603 Mdot
.52098 .28181 Mdot
.43678 .655 Mdot
.36594 .53081 Mdot
.25168 .42998 Mdot
.34696 .57625 Mdot
.68027 .36501 Mdot
.47807 .2725 Mdot
.37779 .28295 Mdot
.6059 .39136 Mdot
.77136 .6408 Mdot
.37279 .57738 Mdot
.68984 .52229 Mdot
.55651 .48387 Mdot
.68467 .48294 Mdot
.74677 .48035 Mdot
.26949 .30503 Mdot
.61208 .6543 Mdot
.41842 .54079 Mdot
.629 .32039 Mdot
.55363 .6287 Mdot
.55184 .47882 Mdot
.85007 .60978 Mdot
.65935 .51089 Mdot
.72544 .7948 Mdot
.6845 .51513 Mdot
.50494 .54706 Mdot
.59761 .66053 Mdot
.44743 .60671 Mdot
.35521 .38741 Mdot
.60589 .6642 Mdot
.59419 .21762 Mdot
.56586 .70827 Mdot
.23981 .37467 Mdot
.54801 .60441 Mdot
.69273 .50193 Mdot
.65628 .49453 Mdot
.3387 .4684 Mdot
.39271 .53001 Mdot
.35641 .37658 Mdot
.44586 .57827 Mdot
.36263 .50742 Mdot
.59909 .34896 Mdot
.70614 .43672 Mdot
.71285 .56716 Mdot
.57269 .64952 Mdot
.69124 .47475 Mdot
.36555 .52295 Mdot
.36065 .49179 Mdot
.37214 .56945 Mdot
.45858 .32795 Mdot
.43659 .81301 Mdot
.36839 .55166 Mdot
.42756 .55577 Mdot
.58857 .3588 Mdot
.6781 .33318 Mdot
.82427 .59942 Mdot
.27997 .29009 Mdot
.33824 .55519 Mdot
.47145 .26388 Mdot
.47835 .29222 Mdot
.37447 .46893 Mdot
.45871 .59848 Mdot
.53296 .27762 Mdot
.34646 .53488 Mdot
.23271 .44833 Mdot
.58435 .3051 Mdot
.52597 .5753 Mdot
.59744 .33208 Mdot
.56405 .61902 Mdot
.52514 .57151 Mdot
.59929 .35835 Mdot
.25668 .41576 Mdot
.53925 .56748 Mdot
.74761 .46153 Mdot
.462 .27068 Mdot
.3848 .55204 Mdot
.52907 .75107 Mdot
.60086 .31208 Mdot
.70692 .51108 Mdot
.59343 .66388 Mdot
.71784 .4945 Mdot
.67016 .40678 Mdot
.2848 .36983 Mdot
.51181 .55597 Mdot
.69126 .52265 Mdot
.482 .46652 Mdot
.47172 .26785 Mdot
.67692 .50891 Mdot
.45401 .51457 Mdot
.38523 .58222 Mdot
.4616 .84678 Mdot
.32687 .51759 Mdot
.76496 .49515 Mdot
.70328 .518 Mdot
.5355 .57661 Mdot
.35086 .54267 Mdot
.62805 .31367 Mdot
.2787 .50371 Mdot
.3596 .54226 Mdot
.59088 .31626 Mdot
.35593 .55601 Mdot
.4934 .28712 Mdot
.61 .70462 Mdot
.33798 .38718 Mdot
.45786 .35355 Mdot
.48745 .24656 Mdot
.28487 .42828 Mdot
.39505 .54927 Mdot
.55391 .19832 Mdot
.57805 .67027 Mdot
.39817 .56944 Mdot
.30631 .33201 Mdot
.59122 .64475 Mdot
.59233 .67579 Mdot
.3319 .49991 Mdot
.71303 .52119 Mdot
.62662 .35964 Mdot
.47336 .2698 Mdot
.72053 .47266 Mdot
.36595 .53412 Mdot
.38926 .49601 Mdot
.48248 .24627 Mdot
.70256 .5137 Mdot
.40829 .52918 Mdot
.69146 .66441 Mdot
.2857 .40195 Mdot
.71409 .47801 Mdot
.39017 .5806 Mdot
.47611 .81993 Mdot
.55613 .6544 Mdot
.79684 .36452 Mdot
.44085 .26975 Mdot
.60539 .37197 Mdot
.31359 .57477 Mdot
.8965 .50142 Mdot
.46653 .2771 Mdot
.74134 .67482 Mdot
.34388 .55146 Mdot
.37621 .5366 Mdot
.5933 .63877 Mdot
.39634 .51789 Mdot
.56524 .65133 Mdot
.50587 .35231 Mdot
.57109 .84467 Mdot
.56208 .67531 Mdot
.56654 .66607 Mdot
.45801 .55416 Mdot
.46152 .30242 Mdot
.59013 .64856 Mdot
.39812 .53281 Mdot
.5881 .19906 Mdot
.43191 .50487 Mdot
.46481 .24301 Mdot
.52239 .25577 Mdot
.60406 .68935 Mdot
.4751 .76769 Mdot
.45521 .54294 Mdot
.44165 .79793 Mdot
.53161 .26944 Mdot
.66868 .48599 Mdot
.36486 .48636 Mdot
.52991 .54796 Mdot
.61004 .33322 Mdot
.29578 .52575 Mdot
.38974 .54755 Mdot
.61268 .67117 Mdot
.51781 .26249 Mdot
.67146 .50435 Mdot
.351 .48094 Mdot
.58413 .2999 Mdot
.48475 .24926 Mdot
.56333 .68754 Mdot
.51222 .77798 Mdot
.4676 .29589 Mdot
.31968 .5831 Mdot
.33536 .54632 Mdot
.32529 .49282 Mdot
.40277 .59936 Mdot
.70558 .4948 Mdot
.63106 .37359 Mdot
.31751 .58088 Mdot
.37503 .41728 Mdot
.28381 .39317 Mdot
.35513 .56768 Mdot
.58794 .69319 Mdot
.70709 .48292 Mdot
.51707 .5515 Mdot
.29984 .25666 Mdot
.32619 .5375 Mdot
.44694 .81484 Mdot
.42358 .31198 Mdot
.53646 .55826 Mdot
.54851 .63377 Mdot
.4769 .26762 Mdot
.33009 .49536 Mdot
.24945 .42829 Mdot
.36776 .50771 Mdot
.42794 .51657 Mdot
.61563 .37109 Mdot
.67063 .49218 Mdot
.25407 .56611 Mdot
.61197 .33768 Mdot
.59247 .67429 Mdot
.40031 .7911 Mdot
.55575 .63307 Mdot
.54585 .65387 Mdot
.54057 .7051 Mdot
.71539 .51022 Mdot
.89892 .49551 Mdot
.42977 .22578 Mdot
.36838 .56622 Mdot
.67287 .51592 Mdot
.58854 .65142 Mdot
.40253 .53305 Mdot
.56656 .65043 Mdot
.60535 .69167 Mdot
.34067 .50601 Mdot
.34708 .50313 Mdot
.24231 .43161 Mdot
.47133 .81207 Mdot
.48025 .28246 Mdot
.56667 .6357 Mdot
.4731 .79783 Mdot
.37138 .53505 Mdot
.39413 .53722 Mdot
.55908 .4858 Mdot
.4628 .25336 Mdot
.28697 .69328 Mdot
.33879 .54256 Mdot
.35657 .31779 Mdot
.39917 .54617 Mdot
.5842 .61563 Mdot
.67017 .46583 Mdot
.43771 .49226 Mdot
.61005 .37789 Mdot
.56369 .63638 Mdot
.51995 .26879 Mdot
.54694 .62842 Mdot
.32586 .71199 Mdot
.71044 .49216 Mdot
.56769 .67085 Mdot
.63511 .37239 Mdot
.698 .51144 Mdot
.71815 .51187 Mdot
.55004 .47614 Mdot
.64305 .35667 Mdot
.51684 .2595 Mdot
.67885 .49714 Mdot
.37861 .74827 Mdot
.69313 .50474 Mdot
.31995 .71484 Mdot
.32629 .54472 Mdot
.25249 .42867 Mdot
.29328 .5248 Mdot
.34903 .46428 Mdot
.68378 .50697 Mdot
.48589 .2479 Mdot
.40892 .53374 Mdot
.55761 .67375 Mdot
.46743 .27196 Mdot
.53066 .72207 Mdot
.64393 .36206 Mdot
.59422 .70835 Mdot
.73263 .50402 Mdot
.57844 .63519 Mdot
.31861 .3471 Mdot
.51339 .24649 Mdot
.56608 .47127 Mdot
.34828 .39777 Mdot
.362 .60183 Mdot
.42347 .55286 Mdot
.41011 .5385 Mdot
.37231 .51775 Mdot
.59228 .32903 Mdot
.51445 .28978 Mdot
.57983 .69494 Mdot
.26493 .61438 Mdot
.70899 .51366 Mdot
.50449 .46527 Mdot
.40019 .59966 Mdot
.3793 .49257 Mdot
.58773 .65347 Mdot
.59823 .69763 Mdot
.45561 .64869 Mdot
.62772 .34124 Mdot
.40431 .4793 Mdot
.3792 .57437 Mdot
.25183 .55003 Mdot
.68616 .5097 Mdot
.74334 .63232 Mdot
.59089 .30349 Mdot
.73478 .79013 Mdot
.61078 .33855 Mdot
.53845 .43194 Mdot
.57002 .64513 Mdot
.49279 .26478 Mdot
.34458 .51274 Mdot
.50873 .6129 Mdot
.54129 .66686 Mdot
.66083 .3163 Mdot
.48259 .2646 Mdot
.76949 .53621 Mdot
.66514 .50482 Mdot
.35332 .48054 Mdot
.39966 .54564 Mdot
.37933 .50092 Mdot
.39085 .51893 Mdot
.67292 .47903 Mdot
.36043 .50215 Mdot
.72786 .48408 Mdot
.32087 .70535 Mdot
.30116 .33326 Mdot
.63829 .34816 Mdot
.68644 .31804 Mdot
.54609 .658 Mdot
.32354 .73927 Mdot
.29943 .69463 Mdot
.26686 .42937 Mdot
.74898 .50277 Mdot
.4025 .49478 Mdot
.62039 .36211 Mdot
.68526 .56524 Mdot
.63829 .34382 Mdot
.3367 .80016 Mdot
.50551 .75304 Mdot
.77479 .51999 Mdot
.38068 .50443 Mdot
.62531 .37197 Mdot
.47693 .77756 Mdot
.29519 .55697 Mdot
.46248 .29275 Mdot
.34254 .72688 Mdot
.51091 .6862 Mdot
.48313 .28474 Mdot
.33424 .51837 Mdot
.55102 .69248 Mdot
.34856 .5118 Mdot
.341 .51366 Mdot
.35026 .55909 Mdot
.68319 .47009 Mdot
.3304 .55158 Mdot
.38619 .52523 Mdot
.31976 .21528 Mdot
.58471 .28196 Mdot
.58325 .33251 Mdot
.40101 .62707 Mdot
.47135 .27438 Mdot
.5641 .61868 Mdot
.34127 .39093 Mdot
.70534 .52017 Mdot
.45223 .64832 Mdot
.34041 .49789 Mdot
.7059 .7094 Mdot
.72301 .51124 Mdot
.511 .26591 Mdot
.53135 .54989 Mdot
.7664 .57068 Mdot
.58445 .36254 Mdot
.51499 .54491 Mdot
.59793 .31705 Mdot
.24025 .57804 Mdot
.56472 .65851 Mdot
.36158 .60173 Mdot
.67231 .50125 Mdot
.63967 .34073 Mdot
.25082 .43487 Mdot
.38719 .53474 Mdot
.62221 .36819 Mdot
.29698 .55351 Mdot
.31079 .3874 Mdot
.34341 .38532 Mdot
.63727 .36255 Mdot
.71042 .52911 Mdot
.6913 .51153 Mdot
.47488 .28428 Mdot
.55674 .65823 Mdot
.61004 .66732 Mdot
.69008 .5065 Mdot
.81234 .46145 Mdot
.36395 .53302 Mdot
.3748 .54855 Mdot
.38703 .41681 Mdot
.40423 .5495 Mdot
.47343 .23201 Mdot
.50546 .54285 Mdot
.6073 .67848 Mdot
.40941 .53685 Mdot
.4077 .52791 Mdot
.32885 .53681 Mdot
.26198 .38921 Mdot
.59736 .3281 Mdot
.32382 .51132 Mdot
.50723 .27361 Mdot
.52305 .71231 Mdot
.37913 .51729 Mdot
.31696 .58172 Mdot
.56639 .6463 Mdot
.62908 .43269 Mdot
.70825 .51004 Mdot
.62313 .31829 Mdot
.62744 .32001 Mdot
.32195 .28781 Mdot
.56454 .63024 Mdot
.51057 .54397 Mdot
.65841 .40526 Mdot
.51614 .54961 Mdot
.48444 .26244 Mdot
.51619 .47622 Mdot
.62858 .39333 Mdot
.5841 .33033 Mdot
.65426 .47804 Mdot
.40953 .56177 Mdot
.38449 .52062 Mdot
.76756 .65167 Mdot
.36879 .55774 Mdot
.48742 .28183 Mdot
.69055 .52667 Mdot
.56883 .66865 Mdot
.4949 .28891 Mdot
.6892 .51922 Mdot
.60714 .66724 Mdot
.33623 .56946 Mdot
.40134 .53894 Mdot
.59479 .6693 Mdot
.55922 .68318 Mdot
.35022 .52696 Mdot
.25042 .32659 Mdot
.60177 .68639 Mdot
.59564 .66331 Mdot
.51877 .70393 Mdot
.58192 .35574 Mdot
.27708 .50634 Mdot
.69997 .52365 Mdot
.38592 .5261 Mdot
.63664 .34948 Mdot
.48491 .25544 Mdot
.58158 .68864 Mdot
.36756 .48564 Mdot
.36838 .53991 Mdot
.4722 .2643 Mdot
.45983 .27549 Mdot
.46312 .25973 Mdot
.65773 .4916 Mdot
.34322 .50078 Mdot
.59495 .65389 Mdot
.66156 .49329 Mdot
.49539 .29349 Mdot
.45876 .2562 Mdot
.22068 .40341 Mdot
.35872 .52878 Mdot
.46974 .29082 Mdot
.8586 .5833 Mdot
.22909 .43261 Mdot
.51579 .56887 Mdot
.63095 .30474 Mdot
.52455 .16791 Mdot
.46186 .2164 Mdot
.67298 .48663 Mdot
.50449 .46206 Mdot
.49116 .24319 Mdot
.33964 .48447 Mdot
.38463 .54381 Mdot
.38643 .59912 Mdot
.46694 .26877 Mdot
.28489 .36845 Mdot
.60969 .64991 Mdot
.34183 .66569 Mdot
.47165 .27471 Mdot
.64211 .3488 Mdot
.57174 .31531 Mdot
.61485 .34764 Mdot
.42616 .5342 Mdot
.2366 .57973 Mdot
.37144 .72965 Mdot
.28203 .68519 Mdot
.66925 .51044 Mdot
.60159 .69561 Mdot
.55214 .74218 Mdot
.59186 .67735 Mdot
.61154 .32511 Mdot
.48874 .24874 Mdot
.60119 .64347 Mdot
.71873 .50753 Mdot
.68835 .50976 Mdot
.59666 .37731 Mdot
.60163 .33406 Mdot
.60789 .35191 Mdot
.55978 .64341 Mdot
.56908 .64738 Mdot
.39519 .51246 Mdot
.57167 .6885 Mdot
.4452 .31095 Mdot
.48471 .34268 Mdot
.57462 .35702 Mdot
.70167 .49676 Mdot
.59645 .68162 Mdot
.38363 .55404 Mdot
.47897 .43347 Mdot
.59362 .38968 Mdot
.5142 .28071 Mdot
.63572 .76706 Mdot
.53894 .86151 Mdot
.41534 .5312 Mdot
.6893 .47701 Mdot
.47275 .55903 Mdot
.37102 .51899 Mdot
.61046 .37451 Mdot
.41184 .28833 Mdot
.54149 .56738 Mdot
.35829 .50896 Mdot
.33941 .56943 Mdot
.71302 .4917 Mdot
.34123 .39369 Mdot
.34824 .48201 Mdot
.53456 .4575 Mdot
.70365 .53148 Mdot
.58653 .30729 Mdot
.46409 .14635 Mdot
.51234 .59623 Mdot
.37038 .32973 Mdot
.52975 .57352 Mdot
.327 .54122 Mdot
.5966 .34618 Mdot
.5063 .28225 Mdot
.60045 .34352 Mdot
.56685 .61461 Mdot
.58568 .36288 Mdot
.36826 .5599 Mdot
.59426 .65099 Mdot
.70024 .51612 Mdot
.44123 .42439 Mdot
.28161 .61214 Mdot
.62213 .3085 Mdot
.50215 .55512 Mdot
.34723 .50367 Mdot
.37435 .75054 Mdot
.34643 .46439 Mdot
.39606 .5362 Mdot
.68594 .48371 Mdot
.57862 .64966 Mdot
.71517 .48864 Mdot
.2815 .49929 Mdot
.63299 .64611 Mdot
.71102 .50734 Mdot
.45555 .50686 Mdot
.49358 .24645 Mdot
.27764 .37711 Mdot
.34551 .54123 Mdot
.67094 .49999 Mdot
.33302 .51064 Mdot
.57049 .63273 Mdot
.26854 .40804 Mdot
.28124 .4112 Mdot
.68585 .49106 Mdot
.58051 .52503 Mdot
.32992 .37626 Mdot
.27673 .50745 Mdot
.66584 .50004 Mdot
.20074 .4815 Mdot
.52994 .55418 Mdot
.48669 .25058 Mdot
.45638 .26784 Mdot
.50115 .26471 Mdot
.37771 .54951 Mdot
.4911 .80315 Mdot
.47144 .28408 Mdot
.67991 .52846 Mdot
.4962 .28273 Mdot
.43997 .34196 Mdot
.76689 .65992 Mdot
.49213 .24671 Mdot
.35146 .54826 Mdot
.37284 .45468 Mdot
.49904 .46312 Mdot
.63773 .32129 Mdot
.72686 .58097 Mdot
.33028 .20691 Mdot
.37024 .53221 Mdot
.60968 .76295 Mdot
.61732 .63485 Mdot
.53306 .41772 Mdot
.27547 .41934 Mdot
.45453 .45287 Mdot
.59846 .67319 Mdot
.34483 .39551 Mdot
.55411 .68562 Mdot
.36027 .60266 Mdot
.36808 .55006 Mdot
.56429 .63513 Mdot
.66636 .73508 Mdot
.19075 .47366 Mdot
.73399 .69118 Mdot
.60276 .67756 Mdot
.67241 .51094 Mdot
.68767 .48017 Mdot
.68365 .4852 Mdot
.58985 .33798 Mdot
.56554 .6709 Mdot
.32084 .51943 Mdot
.59661 .36628 Mdot
.33674 .52446 Mdot
.68677 .49791 Mdot
.27004 .42278 Mdot
.56728 .66573 Mdot
.34548 .53463 Mdot
.47449 .7876 Mdot
.60272 .31577 Mdot
.47045 .26665 Mdot
.6296 .76623 Mdot
.65074 .34333 Mdot
.72529 .51048 Mdot
.56839 .61228 Mdot
.60306 .28409 Mdot
.52345 .4443 Mdot
.35212 .56539 Mdot
.38262 .56463 Mdot
.50508 .45872 Mdot
.51073 .76257 Mdot
.37748 .48559 Mdot
.59229 .35943 Mdot
.5805 .34564 Mdot
.33095 .51594 Mdot
.56488 .67461 Mdot
.49141 .24114 Mdot
.47831 .29885 Mdot
.4348 .54916 Mdot
.35074 .38589 Mdot
.25216 .42993 Mdot
.40508 .53083 Mdot
.36803 .59455 Mdot
.63658 .37081 Mdot
.51792 .57111 Mdot
.35608 .39386 Mdot
.4971 .27026 Mdot
.33824 .54607 Mdot
.35835 .63912 Mdot
.57363 .68245 Mdot
.62387 .36568 Mdot
.66923 .4737 Mdot
.46569 .29498 Mdot
.57497 .35508 Mdot
.33091 .51611 Mdot
.40796 .52866 Mdot
.67491 .50576 Mdot
.58273 .61583 Mdot
.47142 .25356 Mdot
.59483 .36532 Mdot
.49417 .26745 Mdot
.56815 .65373 Mdot
.58578 .69019 Mdot
.37059 .57099 Mdot
.37186 .46453 Mdot
.61735 .30746 Mdot
.42283 .51288 Mdot
.60871 .36475 Mdot
.67794 .33743 Mdot
.69385 .47267 Mdot
.39592 .56995 Mdot
.57118 .62315 Mdot
.68679 .50146 Mdot
.36845 .52854 Mdot
.51144 .4558 Mdot
.4023 .51555 Mdot
.62828 .37106 Mdot
.40921 .26266 Mdot
.49435 .25639 Mdot
.30643 .52939 Mdot
.4932 .65312 Mdot
.40536 .54444 Mdot
.58795 .31288 Mdot
.36861 .73748 Mdot
.71148 .50159 Mdot
.57712 .64055 Mdot
.6284 .40766 Mdot
.69625 .50212 Mdot
.34924 .55066 Mdot
.48683 .27728 Mdot
.5735 .69561 Mdot
.51834 .5665 Mdot
.37148 .3772 Mdot
.31746 .47182 Mdot
.41866 .49304 Mdot
.3665 .48274 Mdot
.79423 .62691 Mdot
.60555 .34927 Mdot
.5893 .65337 Mdot
.6851 .47785 Mdot
.71212 .49555 Mdot
.60306 .31871 Mdot
.5087 .67392 Mdot
.69255 .73538 Mdot
.87162 .55669 Mdot
.572 .34999 Mdot
.50147 .27245 Mdot
.26898 .40922 Mdot
.61618 .34863 Mdot
.59192 .32304 Mdot
.63099 .38351 Mdot
.77254 .64499 Mdot
.60338 .67032 Mdot
.36958 .54006 Mdot
.59568 .75877 Mdot
.35122 .55882 Mdot
.37131 .33695 Mdot
.68772 .49758 Mdot
.57707 .64027 Mdot
.51625 .36529 Mdot
.42478 .54471 Mdot
.35789 .51669 Mdot
.53839 .36318 Mdot
.46312 .5659 Mdot
.29805 .26512 Mdot
.38987 .56667 Mdot
.59562 .33714 Mdot
.61302 .72121 Mdot
.32245 .58459 Mdot
.47533 .78893 Mdot
.6909 .51417 Mdot
.51061 .55509 Mdot
.33906 .59595 Mdot
.39887 .59369 Mdot
.55206 .68291 Mdot
.60559 .6474 Mdot
.45907 .26962 Mdot
.6331 .74861 Mdot
.69291 .51571 Mdot
.75995 .62053 Mdot
.39699 .53709 Mdot
.7426 .47485 Mdot
.41638 .27779 Mdot
.3623 .52474 Mdot
.54694 .47387 Mdot
.45599 .64835 Mdot
.38323 .49065 Mdot
.28554 .67835 Mdot
.69574 .49629 Mdot
.32044 .33025 Mdot
.37105 .50487 Mdot
.62114 .3677 Mdot
.59975 .64895 Mdot
.592 .70896 Mdot
.5038 .28621 Mdot
.43371 .27989 Mdot
.62197 .83218 Mdot
.5778 .6394 Mdot
.38837 .53432 Mdot
.70801 .50566 Mdot
.5121 .56075 Mdot
.29616 .51818 Mdot
.5811 .51591 Mdot
.57566 .68287 Mdot
.30171 .56494 Mdot
.70273 .71359 Mdot
.34324 .39408 Mdot
.34359 .76089 Mdot
.68159 .4892 Mdot
.49573 .27836 Mdot
.4422 .54246 Mdot
.66934 .37796 Mdot
.4015 .54179 Mdot
.37074 .33469 Mdot
.62592 .67419 Mdot
.49028 .2819 Mdot
.35606 .51372 Mdot
.38756 .48895 Mdot
.29691 .42573 Mdot
.46368 .24231 Mdot
.36127 .48259 Mdot
.41725 .5338 Mdot
.60138 .64707 Mdot
.50436 .54324 Mdot
.57078 .67119 Mdot
.34728 .51341 Mdot
.39621 .23891 Mdot
.56902 .63617 Mdot
.71456 .57777 Mdot
.48632 .30208 Mdot
.70302 .52113 Mdot
.30636 .56256 Mdot
.34285 .55994 Mdot
.34424 .76863 Mdot
.50813 .55637 Mdot
.8013 .50952 Mdot
.6286 .36704 Mdot
.27492 .26445 Mdot
.6515 .35088 Mdot
.75224 .52574 Mdot
.62075 .48728 Mdot
.33427 .58953 Mdot
.50531 .6664 Mdot
.27433 .68347 Mdot
.7258 .52636 Mdot
.31096 .73184 Mdot
.39255 .5298 Mdot
.33341 .54226 Mdot
.61207 .36659 Mdot
.75187 .49386 Mdot
.43668 .49098 Mdot
.35577 .3928 Mdot
.50924 .26177 Mdot
.58464 .66969 Mdot
.38444 .54773 Mdot
.65828 .73705 Mdot
.63939 .3335 Mdot
.32555 .63154 Mdot
.34719 .53889 Mdot
.47085 .5596 Mdot
.75078 .50255 Mdot
.70135 .51662 Mdot
.63608 .36678 Mdot
.64335 .34938 Mdot
.33303 .54827 Mdot
.66994 .4772 Mdot
.38547 .50146 Mdot
.3247 .37742 Mdot
.30392 .56359 Mdot
.48292 .25982 Mdot
.39217 .54919 Mdot
.47891 .60425 Mdot
.1737 .59437 Mdot
.4221 .54968 Mdot
.54734 .651 Mdot
.60855 .35651 Mdot
.60164 .32466 Mdot
.60968 .67038 Mdot
.60232 .32392 Mdot
.34467 .66751 Mdot
.49128 .80648 Mdot
.4874 .26345 Mdot
.33156 .69433 Mdot
.49989 .25555 Mdot
.51073 .55405 Mdot
.35582 .52785 Mdot
.72115 .30921 Mdot
.57175 .34344 Mdot
.42678 .33337 Mdot
.69032 .50424 Mdot
.50614 .55335 Mdot
.3485 .50151 Mdot
.51163 .2385 Mdot
.61739 .33885 Mdot
.48677 .55223 Mdot
.34688 .55653 Mdot
.56174 .64079 Mdot
.37824 .4905 Mdot
.45493 .57367 Mdot
.50618 .54417 Mdot
.4039 .5013 Mdot
.6893 .51927 Mdot
.56286 .65439 Mdot
.77926 .52503 Mdot
.59718 .31405 Mdot
.35359 .5061 Mdot
.38602 .53079 Mdot
.57775 .69931 Mdot
.36983 .56555 Mdot
.66516 .48088 Mdot
.89861 .43675 Mdot
.46698 .25248 Mdot
.52182 .57322 Mdot
.68565 .60375 Mdot
.40336 .49988 Mdot
.41329 .53795 Mdot
.4664 .47798 Mdot
.34011 .64094 Mdot
.69849 .52106 Mdot
.40758 .48746 Mdot
.58227 .34389 Mdot
.47496 .25098 Mdot
.72028 .50376 Mdot
.35352 .49863 Mdot
.35882 .55648 Mdot
.49056 .28069 Mdot
.53218 .36846 Mdot
.45297 .25916 Mdot
.67137 .48396 Mdot
.56686 .57522 Mdot
.48086 .43292 Mdot
.35941 .53625 Mdot
.49531 .5452 Mdot
.58111 .65326 Mdot
.66421 .49411 Mdot
.43458 .65842 Mdot
.3629 .60305 Mdot
.73279 .49845 Mdot
.69843 .51634 Mdot
.35115 .56439 Mdot
.56387 .6318 Mdot
.57676 .60883 Mdot
.58449 .65338 Mdot
.30436 .32187 Mdot
.79272 .50642 Mdot
.60535 .35363 Mdot
.70098 .49862 Mdot
.63529 .34603 Mdot
.48735 .24348 Mdot
.2925 .38803 Mdot
.63934 .32867 Mdot
.59261 .63084 Mdot
.63615 .33797 Mdot
.38967 .50478 Mdot
.71209 .52019 Mdot
.61101 .30679 Mdot
.39894 .52679 Mdot
.43054 .56743 Mdot
.4283 .58897 Mdot
.50965 .25102 Mdot
.34626 .38893 Mdot
.34407 .54389 Mdot
.53046 .54996 Mdot
.3483 .53127 Mdot
.66665 .47908 Mdot
.43458 .41251 Mdot
.32649 .5136 Mdot
.57156 .34292 Mdot
.80956 .53744 Mdot
.57834 .33724 Mdot
.36969 .62115 Mdot
.3409 .52217 Mdot
.35999 .53358 Mdot
.3442 .5037 Mdot
.51577 .70339 Mdot
.72879 .50135 Mdot
.41083 .49272 Mdot
.6128 .37945 Mdot
.59182 .68048 Mdot
.58136 .63048 Mdot
.4811 .48225 Mdot
.51834 .54501 Mdot
.66169 .48297 Mdot
.36181 .53337 Mdot
.48633 .55079 Mdot
.38295 .40439 Mdot
.71509 .71184 Mdot
.63764 .30864 Mdot
.58665 .31893 Mdot
.55301 .66633 Mdot
.58608 .33743 Mdot
.35538 .49992 Mdot
.30594 .56963 Mdot
.77932 .52829 Mdot
.65614 .51503 Mdot
.47642 .25102 Mdot
.33855 .52074 Mdot
.24807 .40031 Mdot
.58871 .35897 Mdot
.63964 .36457 Mdot
.38343 .5007 Mdot
.62828 .65449 Mdot
.16389 .53476 Mdot
.67321 .51655 Mdot
.39538 .76385 Mdot
.55156 .77639 Mdot
.24799 .51214 Mdot
.70782 .49416 Mdot
.54225 .46952 Mdot
.63118 .31259 Mdot
.39701 .21702 Mdot
.59484 .6773 Mdot
.47291 .25314 Mdot
.39915 .53121 Mdot
.59493 .63199 Mdot
.57514 .36132 Mdot
.5831 .69726 Mdot
.34671 .59793 Mdot
.72114 .51363 Mdot
.60706 .33069 Mdot
.65533 .48693 Mdot
.55583 .62528 Mdot
.49829 .25569 Mdot
.35585 .32214 Mdot
.36621 .74447 Mdot
.4607 .64862 Mdot
.32387 .5097 Mdot
.56886 .28388 Mdot
.3206 .51575 Mdot
.61326 .69801 Mdot
.3461 .5423 Mdot
.40578 .57828 Mdot
.64438 .33215 Mdot
.35586 .56797 Mdot
.39531 .54276 Mdot
.47363 .79149 Mdot
.35901 .52116 Mdot
.32999 .52378 Mdot
.36397 .57118 Mdot
.57342 .62725 Mdot
.36596 .56884 Mdot
.55822 .65836 Mdot
.72732 .68926 Mdot
.59869 .31435 Mdot
.48281 .24342 Mdot
.48712 .24464 Mdot
.37999 .3302 Mdot
.25223 .39687 Mdot
.57487 .75198 Mdot
.58044 .67982 Mdot
.68489 .50775 Mdot
.39036 .50661 Mdot
.19199 .44468 Mdot
.3902 .24888 Mdot
.60556 .29944 Mdot
.62569 .31475 Mdot
.38453 .51766 Mdot
.52126 .86539 Mdot
.39302 .5632 Mdot
.39414 .41556 Mdot
.37682 .55016 Mdot
.39844 .56779 Mdot
.63064 .37988 Mdot
.3207 .34694 Mdot
.32372 .5118 Mdot
.55031 .68095 Mdot
.4754 .25335 Mdot
.46877 .56168 Mdot
.38519 .27359 Mdot
.53474 .78478 Mdot
.49552 .59048 Mdot
.33242 .50663 Mdot
.60045 .37085 Mdot
.59686 .68769 Mdot
.37901 .41368 Mdot
.6622 .49203 Mdot
.36256 .37147 Mdot
.3137 .70961 Mdot
.7276 .52916 Mdot
.48237 .24968 Mdot
.57366 .36419 Mdot
.33841 .55438 Mdot
.59435 .3481 Mdot
.4122 .49728 Mdot
.38964 .40343 Mdot
.48668 .26079 Mdot
.57472 .71278 Mdot
.6748 .51324 Mdot
.60012 .63689 Mdot
.35958 .6347 Mdot
.39155 .24491 Mdot
.28102 .25094 Mdot
.57509 .34908 Mdot
.28818 .63818 Mdot
.58241 .64434 Mdot
.32719 .54028 Mdot
.8702 .55725 Mdot
.57677 .65606 Mdot
.56293 .63845 Mdot
.40231 .39687 Mdot
.30511 .34577 Mdot
.41826 .50577 Mdot
.60121 .68822 Mdot
.57354 .36347 Mdot
.48062 .26813 Mdot
.39503 .52073 Mdot
.3378 .59477 Mdot
.59836 .64175 Mdot
.61518 .33133 Mdot
.33826 .34781 Mdot
.59807 .33499 Mdot
.60248 .66294 Mdot
.61764 .31714 Mdot
.73523 .55908 Mdot
.63722 .32493 Mdot
.37843 .5604 Mdot
.3616 .53416 Mdot
.53747 .60292 Mdot
.58573 .69021 Mdot
.41284 .53778 Mdot
.34707 .5536 Mdot
.59055 .65022 Mdot
.61264 .39887 Mdot
.38206 .63992 Mdot
.41571 .54047 Mdot
.36663 .53593 Mdot
.46554 .25165 Mdot
.32435 .39674 Mdot
.41845 .42872 Mdot
.40231 .53038 Mdot
.50285 .26667 Mdot
.55926 .6459 Mdot
.34819 .52856 Mdot
.32317 .34542 Mdot
.58373 .30435 Mdot
.36632 .49674 Mdot
.51696 .56368 Mdot
.31869 .51746 Mdot
.19736 .57569 Mdot
.35118 .50359 Mdot
.59901 .66415 Mdot
.59451 .64661 Mdot
.62619 .40449 Mdot
.59232 .67069 Mdot
.51697 .56935 Mdot
.69132 .51061 Mdot
.36794 .76185 Mdot
.51032 .56346 Mdot
.39767 .49871 Mdot
.43175 .22465 Mdot
.32994 .59067 Mdot
.29005 .54885 Mdot
.45111 .29434 Mdot
.53008 .57278 Mdot
.575 .64794 Mdot
.66392 .71803 Mdot
.35394 .47011 Mdot
.66096 .48646 Mdot
.32508 .58672 Mdot
.36449 .49607 Mdot
.40113 .57869 Mdot
.61695 .62135 Mdot
.66096 .50002 Mdot
.2774 .50064 Mdot
.39517 .52066 Mdot
.34479 .64056 Mdot
.38789 .54528 Mdot
.51598 .26967 Mdot
.56956 .66432 Mdot
.58808 .34335 Mdot
.48007 .26223 Mdot
.36078 .48192 Mdot
.46996 .27391 Mdot
.59832 .35141 Mdot
.67542 .49836 Mdot
.37451 .56137 Mdot
.46784 .24112 Mdot
.49807 .25071 Mdot
.34277 .49026 Mdot
.58905 .64137 Mdot
.3432 .46545 Mdot
.34985 .52584 Mdot
.34096 .50405 Mdot
.60993 .66499 Mdot
.77935 .33113 Mdot
.33005 .5374 Mdot
.54425 .46957 Mdot
.60586 .70572 Mdot
.50268 .54512 Mdot
.5892 .35322 Mdot
.40743 .51553 Mdot
.71583 .50296 Mdot
.69202 .50926 Mdot
.57208 .32888 Mdot
.60487 .64753 Mdot
.60627 .32648 Mdot
.42278 .5534 Mdot
.31669 .58006 Mdot
.39506 .52613 Mdot
.59069 .40346 Mdot
.76388 .55851 Mdot
.56739 .69144 Mdot
.58513 .31653 Mdot
.35692 .37918 Mdot
.70769 .52207 Mdot
.62259 .3849 Mdot
.55583 .69117 Mdot
.61424 .66776 Mdot
.60699 .67482 Mdot
.50797 .26753 Mdot
.60704 .33584 Mdot
.554 .62194 Mdot
.54523 .63109 Mdot
.36406 .49226 Mdot
.39376 .51734 Mdot
.55676 .65281 Mdot
.65362 .39775 Mdot
.48959 .25299 Mdot
.59436 .36924 Mdot
.16288 .55116 Mdot
.66663 .50891 Mdot
.47539 .79087 Mdot
.40326 .53385 Mdot
.75941 .77495 Mdot
.39233 .56401 Mdot
.38993 .53879 Mdot
.56406 .61901 Mdot
.45496 .26543 Mdot
.4812 .27114 Mdot
.58347 .64394 Mdot
.6081 .68835 Mdot
.51211 .28017 Mdot
.44436 .43709 Mdot
.18871 .55409 Mdot
.37511 .40653 Mdot
.57538 .69415 Mdot
.34709 .74028 Mdot
.69229 .48617 Mdot
.62088 .68983 Mdot
.65731 .55278 Mdot
.60902 .31132 Mdot
.62855 .31464 Mdot
.67824 .50641 Mdot
.32905 .5322 Mdot
.60138 .37666 Mdot
.35162 .57931 Mdot
.76931 .5227 Mdot
.5713 .51707 Mdot
.21555 .36381 Mdot
.36953 .56383 Mdot
.47263 .58395 Mdot
.78546 .63984 Mdot
.3966 .50552 Mdot
.48081 .74874 Mdot
.46786 .25826 Mdot
.61884 .68944 Mdot
.68223 .52492 Mdot
.61298 .76299 Mdot
.35988 .53514 Mdot
.58641 .69349 Mdot
.68562 .52429 Mdot
.77229 .5484 Mdot
.53459 .45815 Mdot
.37235 .49117 Mdot
.88528 .52567 Mdot
.54307 .67041 Mdot
.58865 .3449 Mdot
.40911 .74894 Mdot
.61734 .65483 Mdot
.52701 .44737 Mdot
.57342 .36099 Mdot
.34488 .41376 Mdot
.59408 .69513 Mdot
.45279 .26372 Mdot
.58022 .67031 Mdot
.48782 .29003 Mdot
.55929 .61747 Mdot
.61181 .31817 Mdot
.34952 .51764 Mdot
.60558 .31611 Mdot
.51098 .28458 Mdot
.57415 .34786 Mdot
.68303 .52533 Mdot
.53472 .57125 Mdot
.68611 .49789 Mdot
.27706 .39996 Mdot
.44041 .67139 Mdot
.67122 .4923 Mdot
.47755 .5119 Mdot
.36668 .55934 Mdot
.58496 .61576 Mdot
.58801 .33756 Mdot
.64732 .33553 Mdot
.34778 .38799 Mdot
.60477 .66268 Mdot
.61631 .32852 Mdot
.35604 .74078 Mdot
.81151 .47124 Mdot
.41065 .57782 Mdot
.6851 .398 Mdot
.59544 .65587 Mdot
.64726 .35528 Mdot
.39037 .4166 Mdot
.61518 .65889 Mdot
.61545 .30729 Mdot
.66705 .50147 Mdot
.71518 .50469 Mdot
.37831 .56365 Mdot
.66653 .5166 Mdot
.63105 .31361 Mdot
.31695 .63863 Mdot
.57133 .64066 Mdot
.75552 .56586 Mdot
.48073 .24743 Mdot
.59013 .33144 Mdot
.31907 .49395 Mdot
.57358 .6234 Mdot
.63538 .34025 Mdot
.59968 .83829 Mdot
.1617 .61524 Mdot
.61707 .33075 Mdot
.57043 .66567 Mdot
.5831 .68744 Mdot
.41935 .52545 Mdot
.35268 .38931 Mdot
.61897 .34019 Mdot
.71859 .30719 Mdot
.24614 .43035 Mdot
.52836 .56744 Mdot
.32403 .21182 Mdot
.32336 .51466 Mdot
.33467 .50392 Mdot
.67024 .48277 Mdot
.36206 .51819 Mdot
.60311 .69267 Mdot
.39283 .56414 Mdot
.71385 .48554 Mdot
.57576 .32014 Mdot
.35543 .53122 Mdot
.47522 .25025 Mdot
.70362 .48088 Mdot
.69969 .47698 Mdot
.62219 .31983 Mdot
.60583 .65059 Mdot
.67116 .76059 Mdot
.59912 .3336 Mdot
.34275 .50048 Mdot
.53416 .55592 Mdot
.35908 .56923 Mdot
.52691 .64779 Mdot
.6038 .70464 Mdot
.58631 .34 Mdot
.53542 .5473 Mdot
.70351 .50267 Mdot
.6345 .31537 Mdot
.31905 .52504 Mdot
.6023 .30444 Mdot
.56003 .46495 Mdot
.56516 .18667 Mdot
.53905 .66224 Mdot
.54835 .44627 Mdot
.61436 .66101 Mdot
.52523 .56911 Mdot
.3128 .29456 Mdot
.48773 .25118 Mdot
.5814 .34975 Mdot
.71681 .57633 Mdot
.5946 .31493 Mdot
.36326 .52327 Mdot
.35768 .55708 Mdot
.6099 .36705 Mdot
.50152 .25986 Mdot
.45268 .35532 Mdot
.44997 .2628 Mdot
.56722 .67254 Mdot
.47507 .46312 Mdot
.15176 .5252 Mdot
.59604 .29395 Mdot
.68398 .51089 Mdot
.50216 .60155 Mdot
.39186 .49355 Mdot
.67131 .51575 Mdot
.6925 .47451 Mdot
.49298 .29291 Mdot
.59157 .32196 Mdot
.56871 .7079 Mdot
.71938 .51344 Mdot
.61351 .64338 Mdot
.3376 .3441 Mdot
.37596 .60344 Mdot
.25531 .53358 Mdot
.38232 .48603 Mdot
.34373 .39174 Mdot
.7225 .51057 Mdot
.35825 .55176 Mdot
.43601 .5333 Mdot
.66779 .50655 Mdot
.48838 .29301 Mdot
.57141 .53809 Mdot
.61829 .3295 Mdot
.84067 .61845 Mdot
.38141 .55846 Mdot
.34753 .52226 Mdot
.67045 .51205 Mdot
.49857 .76758 Mdot
.54934 .67464 Mdot
.59617 .64292 Mdot
.6062 .34954 Mdot
.41005 .40598 Mdot
.36039 .56604 Mdot
.37267 .56029 Mdot
.61913 .37092 Mdot
.5274 .54935 Mdot
.29437 .24038 Mdot
.3675 .541 Mdot
.69871 .49364 Mdot
.55642 .48352 Mdot
.70954 .52889 Mdot
.39156 .57674 Mdot
.3701 .52727 Mdot
.32052 .50115 Mdot
.31797 .52898 Mdot
.68546 .49291 Mdot
.37654 .48486 Mdot
.39167 .48428 Mdot
.57734 .65041 Mdot
.32756 .51636 Mdot
.2453 .43171 Mdot
.36373 .54016 Mdot
.46891 .25502 Mdot
.42105 .42741 Mdot
.34894 .50516 Mdot
.32881 .514 Mdot
.24725 .42818 Mdot
.36471 .51501 Mdot
.68257 .52328 Mdot
.58721 .68708 Mdot
.70505 .5034 Mdot
.68549 .51457 Mdot
.63378 .33251 Mdot
.47391 .28914 Mdot
.42609 .52284 Mdot
.50941 .27778 Mdot
.42373 .53716 Mdot
.28218 .49671 Mdot
.31198 .38597 Mdot
.39244 .41474 Mdot
.49739 .24518 Mdot
.37363 .559 Mdot
.60093 .34939 Mdot
.58577 .3309 Mdot
.5059 .46141 Mdot
.31901 .57735 Mdot
.68932 .53026 Mdot
.67056 .49974 Mdot
.48701 .34384 Mdot
.54626 .17392 Mdot
.5066 .2557 Mdot
.46345 .36399 Mdot
.33182 .56585 Mdot
.33276 .5314 Mdot
.29308 .53652 Mdot
.63249 .35736 Mdot
.53277 .57357 Mdot
.58949 .37304 Mdot
.74999 .50129 Mdot
.70636 .48599 Mdot
.37396 .56293 Mdot
.48603 .86408 Mdot
.56187 .66217 Mdot
.58562 .68833 Mdot
.71527 .4866 Mdot
.57876 .33841 Mdot
.29955 .55863 Mdot
.80886 .67018 Mdot
.59262 .70753 Mdot
.46954 .24417 Mdot
.35681 .51103 Mdot
.607 .31203 Mdot
.5641 .65178 Mdot
.47157 .24047 Mdot
.32431 .54226 Mdot
.57616 .36638 Mdot
.35789 .54795 Mdot
.33022 .68258 Mdot
.57312 .64533 Mdot
.30479 .40018 Mdot
.55853 .62814 Mdot
.68749 .49233 Mdot
.70146 .51928 Mdot
.36888 .52834 Mdot
.82392 .65268 Mdot
.61473 .71754 Mdot
.71183 .47575 Mdot
.45818 .26839 Mdot
.53865 .56968 Mdot
.47181 .28519 Mdot
.61022 .36459 Mdot
.48301 .24994 Mdot
.6348 .33729 Mdot
.65033 .40663 Mdot
.54764 .68437 Mdot
.48993 .28084 Mdot
.47769 .72232 Mdot
.30258 .56545 Mdot
.48012 .29794 Mdot
.37845 .51188 Mdot
.42074 .53904 Mdot
.62461 .34597 Mdot
.51129 .27064 Mdot
.36509 .48544 Mdot
.67817 .60197 Mdot
.69494 .51958 Mdot
.68957 .52916 Mdot
.32926 .58789 Mdot
.643 .36241 Mdot
.546 .67896 Mdot
.34147 .37076 Mdot
.57112 .71294 Mdot
.37583 .55919 Mdot
.42631 .5359 Mdot
.54655 .6379 Mdot
.54628 .65744 Mdot
.37354 .53089 Mdot
.42641 .79744 Mdot
.33192 .48731 Mdot
.71446 .50783 Mdot
.56592 .67123 Mdot
.58049 .68907 Mdot
.63337 .31678 Mdot
.59382 .63967 Mdot
.41036 .48372 Mdot
.73963 .5222 Mdot
.37667 .47542 Mdot
.7 .50152 Mdot
.6372 .2973 Mdot
.62731 .34003 Mdot
.7252 .57285 Mdot
.58785 .63681 Mdot
.4099 .53704 Mdot
.57495 .63171 Mdot
.46232 .26299 Mdot
.57649 .69176 Mdot
.5945 .61547 Mdot
.398 .53671 Mdot
.35811 .48235 Mdot
.5217 .55039 Mdot
.34939 .39202 Mdot
.57037 .65434 Mdot
.42055 .55522 Mdot
.4003 .56161 Mdot
.35087 .55706 Mdot
.33221 .37569 Mdot
.5739 .62771 Mdot
.53156 .7845 Mdot
.5754 .7252 Mdot
.56978 .64704 Mdot
.18805 .63945 Mdot
.51358 .55177 Mdot
.53252 .548 Mdot
.67576 .52958 Mdot
.36889 .53887 Mdot
.60505 .32233 Mdot
.34136 .49852 Mdot
.29783 .5172 Mdot
.34943 .50649 Mdot
.4821 .28423 Mdot
.34842 .56462 Mdot
.5269 .56009 Mdot
.59525 .33222 Mdot
.39949 .51079 Mdot
.36157 .53065 Mdot
.51728 .54569 Mdot
.56487 .63422 Mdot
.61216 .65858 Mdot
.5626 .71016 Mdot
.49942 .29118 Mdot
.68768 .48191 Mdot
.34474 .49866 Mdot
.60393 .34926 Mdot
.601 .32002 Mdot
.5845 .62851 Mdot
.6148 .37321 Mdot
.69839 .47981 Mdot
.388 .53813 Mdot
.68641 .49337 Mdot
.48067 .28427 Mdot
.56903 .66344 Mdot
.35846 .50124 Mdot
.35347 .49046 Mdot
.5942 .64637 Mdot
.3399 .48388 Mdot
.46097 .26832 Mdot
.63466 .36481 Mdot
.56074 .68596 Mdot
.69279 .51101 Mdot
.63582 .32092 Mdot
.40723 .52436 Mdot
.25752 .73336 Mdot
.36387 .51903 Mdot
.35553 .56225 Mdot
.61594 .72277 Mdot
.36634 .57674 Mdot
.5965 .31392 Mdot
.58178 .63118 Mdot
.41897 .54033 Mdot
.24549 .42065 Mdot
.53275 .30314 Mdot
.58581 .29224 Mdot
.38291 .52403 Mdot
.33667 .76025 Mdot
.40614 .54701 Mdot
.71499 .57947 Mdot
.31192 .38638 Mdot
.63676 .51149 Mdot
.25556 .53434 Mdot
.71079 .47601 Mdot
.53123 .55163 Mdot
.62968 .3291 Mdot
.45794 .77048 Mdot
.37569 .52882 Mdot
.44559 .64897 Mdot
.35783 .49965 Mdot
.70954 .49506 Mdot
.49111 .74628 Mdot
.60422 .37265 Mdot
.2891 .25985 Mdot
.3245 .52942 Mdot
.55397 .68585 Mdot
.61844 .3917 Mdot
.53781 .55433 Mdot
.35905 .48291 Mdot
.51389 .26611 Mdot
.49631 .34269 Mdot
.38346 .46981 Mdot
.70168 .50386 Mdot
.33628 .54421 Mdot
.30524 .51299 Mdot
.81355 .41568 Mdot
.58643 .65295 Mdot
.6757 .51104 Mdot
.5401 .17609 Mdot
.36467 .55669 Mdot
.61393 .66619 Mdot
.59418 .67765 Mdot
.50267 .28458 Mdot
.72416 .47554 Mdot
.51562 .34795 Mdot
.45812 .84367 Mdot
.26589 .60746 Mdot
.63315 .35866 Mdot
.55521 .5833 Mdot
.33716 .49857 Mdot
.39277 .24386 Mdot
.68741 .51331 Mdot
.34686 .52065 Mdot
.47002 .6506 Mdot
.59507 .66213 Mdot
.36363 .54731 Mdot
.48701 .25317 Mdot
.70969 .7483 Mdot
.3336 .7204 Mdot
.35786 .77389 Mdot
.57338 .363 Mdot
.42182 .51052 Mdot
.41422 .48779 Mdot
.50253 .54463 Mdot
.40235 .57435 Mdot
.58881 .33965 Mdot
.57296 .48065 Mdot
.49509 .26166 Mdot
.56186 .65525 Mdot
.52844 .54809 Mdot
.35894 .49977 Mdot
.40861 .49492 Mdot
.45865 .26266 Mdot
.32588 .49701 Mdot
.41565 .75864 Mdot
.53366 .58014 Mdot
.63889 .32956 Mdot
.57445 .69651 Mdot
.42642 .52827 Mdot
.53964 .56536 Mdot
.39563 .53171 Mdot
.47219 .60574 Mdot
.33943 .52191 Mdot
.65507 .5751 Mdot
.60038 .64927 Mdot
.70173 .5112 Mdot
.31828 .53445 Mdot
.35607 .54229 Mdot
.53907 .42865 Mdot
.29627 .55433 Mdot
.33775 .51038 Mdot
.60814 .64352 Mdot
.5613 .65856 Mdot
.55234 .68179 Mdot
.61356 .30236 Mdot
.36979 .40267 Mdot
.69016 .49706 Mdot
.29318 .53934 Mdot
.71983 .51286 Mdot
.25328 .51527 Mdot
.47878 .28637 Mdot
.73873 .56802 Mdot
.38535 .53838 Mdot
.6059 .67147 Mdot
.18577 .54009 Mdot
.57712 .62666 Mdot
.7207 .53937 Mdot
.69146 .51504 Mdot
.57613 .65842 Mdot
.37641 .52097 Mdot
.35073 .40058 Mdot
.36897 .78671 Mdot
.70939 .52156 Mdot
.3382 .59304 Mdot
.61282 .27931 Mdot
.58103 .31033 Mdot
.18002 .62227 Mdot
.71844 .51142 Mdot
.78602 .63998 Mdot
.41606 .54029 Mdot
.57474 .63367 Mdot
.67982 .4887 Mdot
.67735 .4747 Mdot
.60985 .37525 Mdot
.36945 .49164 Mdot
.35798 .54382 Mdot
.51615 .56239 Mdot
.68033 .49857 Mdot
.46001 .56747 Mdot
.37371 .49047 Mdot
.76492 .51034 Mdot
.57355 .70351 Mdot
.77507 .3238 Mdot
.47096 .53746 Mdot
.46884 .65077 Mdot
.75509 .33227 Mdot
.55608 .68074 Mdot
.32842 .52979 Mdot
.30084 .55971 Mdot
.63093 .36934 Mdot
.38225 .52914 Mdot
.58312 .31801 Mdot
.70311 .4874 Mdot
.66196 .59001 Mdot
.47398 .5107 Mdot
.74576 .53725 Mdot
.35844 .51884 Mdot
.34343 .72803 Mdot
.49178 .27329 Mdot
.70831 .5337 Mdot
.54718 .66532 Mdot
.39671 .57271 Mdot
.62119 .3764 Mdot
.59568 .30575 Mdot
.59226 .66289 Mdot
.76967 .64302 Mdot
.72585 .57423 Mdot
.32505 .48955 Mdot
.59759 .36273 Mdot
.48209 .55164 Mdot
.32241 .73814 Mdot
.72375 .49479 Mdot
.49481 .26322 Mdot
.6233 .31761 Mdot
.65751 .49157 Mdot
.42114 .53707 Mdot
.58576 .66333 Mdot
.54126 .66594 Mdot
.51308 .4534 Mdot
.61444 .32686 Mdot
.47354 .26657 Mdot
.51945 .45433 Mdot
.4852 .46533 Mdot
.48466 .25865 Mdot
.60764 .29938 Mdot
.56565 .68045 Mdot
.60149 .66578 Mdot
.58845 .68572 Mdot
.47556 .78883 Mdot
.60311 .70472 Mdot
.3748 .30076 Mdot
.39883 .5754 Mdot
.35562 .74682 Mdot
.40742 .56211 Mdot
.6797 .52313 Mdot
.57533 .6429 Mdot
.30906 .38934 Mdot
.32523 .55807 Mdot
.37658 .79052 Mdot
.3415 .53966 Mdot
.55127 .4775 Mdot
.36846 .53757 Mdot
.35324 .70413 Mdot
.62034 .68381 Mdot
.32515 .54035 Mdot
.73823 .52035 Mdot
.46711 .27056 Mdot
.56517 .61221 Mdot
.33439 .51722 Mdot
.70341 .70681 Mdot
.37806 .51126 Mdot
.66015 .58562 Mdot
.5227 .44652 Mdot
.44272 .24033 Mdot
.36562 .57023 Mdot
.60525 .38166 Mdot
.45191 .50842 Mdot
.34507 .74212 Mdot
.71093 .52069 Mdot
.35001 .73492 Mdot
.59037 .36834 Mdot
.49275 .74946 Mdot
.30755 .50233 Mdot
.49733 .26063 Mdot
.58001 .54 Mdot
.71246 .51219 Mdot
.38187 .53577 Mdot
.3271 .53469 Mdot
.56854 .51279 Mdot
.31134 .72391 Mdot
.46492 .56533 Mdot
.49042 .24141 Mdot
.32302 .71763 Mdot
.34015 .51032 Mdot
.58572 .29095 Mdot
.60741 .64853 Mdot
.49077 .7353 Mdot
.50506 .75992 Mdot
.38949 .49745 Mdot
.57923 .65714 Mdot
.60489 .64773 Mdot
.17135 .49003 Mdot
.49826 .27287 Mdot
.33878 .52489 Mdot
.54897 .44537 Mdot
.34736 .49889 Mdot
.70238 .49085 Mdot
.34455 .5736 Mdot
.62596 .33861 Mdot
.3919 .41885 Mdot
.60954 .30153 Mdot
.35292 .55858 Mdot
.57903 .67125 Mdot
.69473 .52331 Mdot
.66218 .40589 Mdot
.72549 .4771 Mdot
.37376 .30151 Mdot
.47952 .33579 Mdot
.5046 .25368 Mdot
.47962 .28899 Mdot
.70336 .53327 Mdot
.38822 .52999 Mdot
.34509 .37932 Mdot
.38461 .58752 Mdot
.37264 .54293 Mdot
.34138 .51563 Mdot
.65373 .52352 Mdot
.69364 .51502 Mdot
.61374 .31582 Mdot
.37509 .53179 Mdot
.41787 .56093 Mdot
.57738 .66574 Mdot
.50266 .25311 Mdot
.63879 .33956 Mdot
.51691 .27593 Mdot
.59676 .33966 Mdot
.19755 .57741 Mdot
.35102 .60107 Mdot
.47149 .27665 Mdot
.72247 .50069 Mdot
.60127 .68066 Mdot
.50862 .55417 Mdot
.61404 .36185 Mdot
.60994 .37216 Mdot
.42136 .5193 Mdot
.56605 .6509 Mdot
.59304 .64056 Mdot
.51389 .27883 Mdot
.67059 .49748 Mdot
.42729 .57114 Mdot
.39107 .49147 Mdot
.68207 .35757 Mdot
.63291 .37089 Mdot
.33323 .72735 Mdot
.59521 .73 Mdot
.39272 .54207 Mdot
.61295 .66496 Mdot
.35196 .53315 Mdot
.5182 .60091 Mdot
.54314 .66376 Mdot
.362 .57714 Mdot
.31983 .5702 Mdot
.63395 .35339 Mdot
.17726 .44415 Mdot
.43209 .56537 Mdot
.69439 .55864 Mdot
.33344 .49789 Mdot
.27676 .25179 Mdot
.18337 .53005 Mdot
.38723 .52113 Mdot
.3451 .56166 Mdot
.42115 .84012 Mdot
.40417 .54844 Mdot
.52212 .56354 Mdot
.2977 .515 Mdot
.61297 .67118 Mdot
.55227 .45229 Mdot
.34548 .38994 Mdot
.49949 .27715 Mdot
.60606 .35057 Mdot
.31124 .34596 Mdot
.48861 .29062 Mdot
.59794 .661 Mdot
.43346 .5672 Mdot
.60574 .72585 Mdot
.6509 .35253 Mdot
.456 .57175 Mdot
.70703 .49239 Mdot
.34655 .38341 Mdot
.61557 .37619 Mdot
.69143 .51116 Mdot
.40507 .55338 Mdot
.6366 .40024 Mdot
.72622 .52635 Mdot
.16628 .46241 Mdot
.66806 .48297 Mdot
.70279 .51559 Mdot
.35914 .39491 Mdot
.4997 .27712 Mdot
.57755 .49064 Mdot
.27828 .50438 Mdot
.69242 .52501 Mdot
.29354 .27133 Mdot
.62897 .37581 Mdot
.3836 .39886 Mdot
.62227 .68023 Mdot
.33791 .59527 Mdot
.34599 .51632 Mdot
.66498 .49102 Mdot
.55135 .55938 Mdot
.53646 .42319 Mdot
.71341 .4932 Mdot
.31727 .5411 Mdot
.41358 .41123 Mdot
.53806 .56609 Mdot
.51259 .55305 Mdot
.46756 .2422 Mdot
.58548 .21273 Mdot
.60627 .65711 Mdot
.47019 .24467 Mdot
.28265 .40655 Mdot
.34116 .54328 Mdot
.68504 .49115 Mdot
.52532 .54632 Mdot
.69341 .50893 Mdot
.48611 .27063 Mdot
.46002 .27064 Mdot
.57879 .65045 Mdot
.54969 .67279 Mdot
.57454 .56157 Mdot
.23622 .43601 Mdot
.37003 .4975 Mdot
.43135 .65988 Mdot
.54575 .65698 Mdot
.48221 .77368 Mdot
.50564 .27298 Mdot
.50791 .261 Mdot
.271 .66274 Mdot
.3945 .5116 Mdot
.5556 .48214 Mdot
.34631 .50527 Mdot
.32788 .25823 Mdot
.36118 .5012 Mdot
.6173 .37187 Mdot
.32238 .51984 Mdot
.66113 .74368 Mdot
.41392 .53005 Mdot
.34557 .51082 Mdot
.61284 .34354 Mdot
.42399 .5197 Mdot
.62524 .34268 Mdot
.33018 .53191 Mdot
.51562 .32263 Mdot
.60421 .34894 Mdot
.52312 .30265 Mdot
.5254 .47425 Mdot
.5189 .55685 Mdot
.49157 .28652 Mdot
.50844 .25606 Mdot
.34306 .34654 Mdot
.5613 .67274 Mdot
.50868 .692 Mdot
.35746 .51161 Mdot
.63653 .37073 Mdot
.69574 .48186 Mdot
.38871 .49598 Mdot
.37968 .56778 Mdot
.43062 .56646 Mdot
.57684 .65306 Mdot
.64096 .32538 Mdot
.48283 .27856 Mdot
.58709 .32141 Mdot
.51894 .31781 Mdot
.62985 .34448 Mdot
.37154 .5946 Mdot
.42229 .53515 Mdot
.41758 .49135 Mdot
.46577 .69151 Mdot
.42191 .23499 Mdot
.58895 .66299 Mdot
.5331 .5561 Mdot
.47376 .28492 Mdot
.44078 .42471 Mdot
.60936 .66644 Mdot
.61555 .37018 Mdot
.35754 .54799 Mdot
.37014 .60382 Mdot
.27985 .50223 Mdot
.61012 .6348 Mdot
.49158 .29801 Mdot
.61259 .35572 Mdot
.53138 .56786 Mdot
.37619 .40541 Mdot
.55315 .77802 Mdot
.28476 .39279 Mdot
.35395 .53824 Mdot
.51092 .28156 Mdot
.56404 .65207 Mdot
.56654 .49579 Mdot
.66529 .49794 Mdot
.3513 .38962 Mdot
.35849 .51785 Mdot
.7489 .46333 Mdot
.58045 .67244 Mdot
.49711 .25474 Mdot
.66474 .49054 Mdot
.50051 .26803 Mdot
.5422 .56972 Mdot
.58813 .73047 Mdot
.35559 .48301 Mdot
.34934 .50357 Mdot
.69776 .48392 Mdot
.60434 .65252 Mdot
.51763 .32738 Mdot
.5792 .51322 Mdot
.60873 .36603 Mdot
.43679 .42936 Mdot
.56243 .65576 Mdot
.71242 .43915 Mdot
.58571 .3212 Mdot
.67657 .52569 Mdot
.33986 .40222 Mdot
.6972 .4782 Mdot
.33993 .51302 Mdot
.57911 .68196 Mdot
.71153 .52133 Mdot
.67758 .3424 Mdot
.44185 .81264 Mdot
.57967 .53397 Mdot
.3646 .55937 Mdot
.72966 .58151 Mdot
.75759 .67094 Mdot
.56392 .60555 Mdot
.72003 .50547 Mdot
.3585 .52473 Mdot
.32568 .48892 Mdot
.32394 .52818 Mdot
.68618 .51926 Mdot
.6517 .44136 Mdot
.58689 .3578 Mdot
.35994 .55252 Mdot
.47421 .24953 Mdot
.62483 .3324 Mdot
.57108 .32331 Mdot
.62204 .31578 Mdot
.5482 .66259 Mdot
.38935 .60159 Mdot
.29416 .52196 Mdot
.18478 .48997 Mdot
.70336 .51316 Mdot
.51929 .55697 Mdot
.33841 .55591 Mdot
.37203 .30724 Mdot
.60197 .67608 Mdot
.61758 .3549 Mdot
.34648 .5227 Mdot
.5162 .4494 Mdot
.49209 .5471 Mdot
.60438 .33494 Mdot
.54494 .66301 Mdot
.63903 .67648 Mdot
.38408 .53176 Mdot
.33806 .4959 Mdot
.59561 .6513 Mdot
.75644 .68758 Mdot
.38449 .40802 Mdot
.35408 .53304 Mdot
.69768 .51291 Mdot
.83105 .55603 Mdot
.40684 .55375 Mdot
.60377 .71596 Mdot
.53067 .57445 Mdot
.59756 .73509 Mdot
.4017 .76579 Mdot
.3066 .56189 Mdot
.61452 .58742 Mdot
.43105 .34008 Mdot
.60974 .61016 Mdot
.35104 .25139 Mdot
.59284 .52114 Mdot
.15648 .50026 Mdot
.74335 .51918 Mdot
.33698 .69492 Mdot
.58582 .83923 Mdot
.78313 .63591 Mdot
.55222 .43447 Mdot
.63087 .47695 Mdot
.65626 .35285 Mdot
.30275 .23201 Mdot
.59495 .3783 Mdot
.36232 .23967 Mdot
.35845 .50424 Mdot
.74787 .69224 Mdot
.34355 .70633 Mdot
.43443 .27918 Mdot
.74103 .55834 Mdot
.52043 .44947 Mdot
.31359 .76854 Mdot
.76149 .5313 Mdot
.22374 .65881 Mdot
.48621 .65767 Mdot
.62692 .22884 Mdot
.45332 .44299 Mdot
.32578 .33683 Mdot
.36383 .73599 Mdot
.65745 .68526 Mdot
.7276 .45858 Mdot
.34625 .64907 Mdot
.76548 .33574 Mdot
.59753 .35721 Mdot
.61749 .66516 Mdot
.61881 .49699 Mdot
.26248 .7084 Mdot
.70954 .55014 Mdot
.61336 .5877 Mdot
.57899 .52507 Mdot
.34831 .70131 Mdot
.3013 .39922 Mdot
.33659 .67866 Mdot
.50769 .35103 Mdot
.30751 .23115 Mdot
.63205 .70125 Mdot
.67506 .29931 Mdot
.42755 .40459 Mdot
.49487 .36591 Mdot
.38594 .72726 Mdot
.52107 .26055 Mdot
.53119 .3003 Mdot
.54421 .66575 Mdot
.28829 .72293 Mdot
.48832 .52774 Mdot
.27647 .41385 Mdot
.59846 .38084 Mdot
.51344 .58939 Mdot
.70423 .74927 Mdot
.75092 .67155 Mdot
.18816 .40262 Mdot
.25375 .72433 Mdot
.2895 .30395 Mdot
.55561 .49628 Mdot
.69065 .54634 Mdot
.37957 .31572 Mdot
.46476 .58697 Mdot
.26906 .32699 Mdot
.4774 .60416 Mdot
.37438 .80885 Mdot
.71899 .676 Mdot
.28509 .75531 Mdot
.635 .69202 Mdot
.43217 .52068 Mdot
.53378 .60818 Mdot
.31202 .6318 Mdot
.26227 .39797 Mdot
.28777 .74633 Mdot
.44307 .25033 Mdot
.54942 .57174 Mdot
.78384 .62811 Mdot
.41376 .75848 Mdot
.52902 .35836 Mdot
.47765 .30399 Mdot
.49957 .72541 Mdot
.32357 .78418 Mdot
.62266 .58887 Mdot
.23037 .60195 Mdot
.76728 .50475 Mdot
.59737 .39835 Mdot
.57041 .32946 Mdot
.69235 .47101 Mdot
.23373 .68523 Mdot
.58381 .68184 Mdot
.17381 .44368 Mdot
.57902 .58092 Mdot
.48027 .5633 Mdot
.33014 .78999 Mdot
.23608 .3439 Mdot
.38053 .75385 Mdot
.41069 .28697 Mdot
.79872 .508 Mdot
.35725 .62657 Mdot
.74263 .5349 Mdot
.60485 .28167 Mdot
.67822 .58502 Mdot
.24419 .69773 Mdot
.26997 .31295 Mdot
.48641 .85577 Mdot
.2722 .42248 Mdot
.53948 .27037 Mdot
.62951 .70534 Mdot
.58683 .43292 Mdot
.53727 .37017 Mdot
.27899 .75151 Mdot
.32568 .71239 Mdot
.82084 .54026 Mdot
.33312 .27094 Mdot
.50598 .76583 Mdot
.71908 .59689 Mdot
.63053 .45235 Mdot
.31304 .6226 Mdot
.71465 .69684 Mdot
.38602 .48516 Mdot
.28668 .38126 Mdot
.49488 .70391 Mdot
.46296 .23178 Mdot
.37224 .40874 Mdot
.72662 .65227 Mdot
.28828 .33131 Mdot
.80794 .5623 Mdot
.50466 .72916 Mdot
.55634 .62701 Mdot
.27161 .32652 Mdot
.31105 .28295 Mdot
.78713 .56392 Mdot
.5367 .1757 Mdot
.22985 .60434 Mdot
.5601 .38659 Mdot
.30136 .55117 Mdot
.33303 .69218 Mdot
.36694 .73594 Mdot
.31599 .23996 Mdot
.36283 .59559 Mdot
.18703 .45693 Mdot
.73129 .55897 Mdot
.45133 .70172 Mdot
.26068 .37711 Mdot
.46177 .69634 Mdot
.37191 .76366 Mdot
.5282 .67719 Mdot
.6433 .53679 Mdot
.54904 .54098 Mdot
.32687 .78428 Mdot
.62126 .32306 Mdot
.26501 .32773 Mdot
.73051 .54719 Mdot
.67875 .3526 Mdot
.58962 .50496 Mdot
.54248 .42101 Mdot
.20925 .65207 Mdot
.77781 .62105 Mdot
.66278 .32183 Mdot
.6476 .72226 Mdot
.49515 .57221 Mdot
.43668 .66478 Mdot
.43951 .57273 Mdot
.48324 .5945 Mdot
.46091 .26849 Mdot
.46002 .7443 Mdot
.56467 .72438 Mdot
.51912 .16797 Mdot
.35425 .58991 Mdot
.45916 .44544 Mdot
.52023 .56964 Mdot
.36923 .36244 Mdot
.1951 .57561 Mdot
.43411 .58381 Mdot
.23246 .35181 Mdot
.77732 .63564 Mdot
.36271 .36032 Mdot
.53295 .36804 Mdot
.51532 .70972 Mdot
.28819 .75896 Mdot
.17445 .59227 Mdot
.71063 .72337 Mdot
.71125 .59203 Mdot
.46317 .13811 Mdot
.6388 .52838 Mdot
.19131 .43446 Mdot
.72976 .54731 Mdot
.89818 .43995 Mdot
.59005 .31405 Mdot
.39741 .23516 Mdot
.41169 .62402 Mdot
.48589 .4355 Mdot
.27621 .71873 Mdot
.39546 .74972 Mdot
.49365 .29922 Mdot
.58604 .61396 Mdot
.33893 .58946 Mdot
.29721 .746 Mdot
.33378 .78374 Mdot
.30294 .75003 Mdot
.68904 .43615 Mdot
.3834 .78439 Mdot
.38844 .82785 Mdot
.37812 .29974 Mdot
.52539 .50356 Mdot
.30602 .5093 Mdot
.22722 .43612 Mdot
.21582 .39566 Mdot
.4572 .21929 Mdot
.3488 .62647 Mdot
.63007 .70809 Mdot
.36573 .8181 Mdot
.18983 .5686 Mdot
.32992 .66959 Mdot
.21221 .6447 Mdot
.64263 .28129 Mdot
.23046 .40455 Mdot
.19214 .62682 Mdot
.64802 .63654 Mdot
.755 .50827 Mdot
.40098 .83949 Mdot
.30963 .29285 Mdot
.63224 .47257 Mdot
.68417 .72317 Mdot
.20445 .40765 Mdot
.70342 .59929 Mdot
.63057 .47039 Mdot
.46123 .599 Mdot
.5677 .76825 Mdot
.54724 .42097 Mdot
.65531 .68684 Mdot
.55451 .48991 Mdot
.25088 .38136 Mdot
.57338 .33424 Mdot
.25096 .34596 Mdot
.52357 .37997 Mdot
.53492 .50464 Mdot
.32112 .35189 Mdot
.28366 .28769 Mdot
.69086 .6882 Mdot
.34823 .76757 Mdot
.77796 .62994 Mdot
.82188 .56048 Mdot
.75283 .58862 Mdot
.4972 .69036 Mdot
.4251 .52218 Mdot
.26839 .71559 Mdot
.14754 .56939 Mdot
.19684 .6383 Mdot
.79535 .56223 Mdot
.55952 .32584 Mdot
.66459 .51341 Mdot
.36883 .32132 Mdot
.49807 .43025 Mdot
.61277 .54849 Mdot
.4706 .37836 Mdot
.69952 .46923 Mdot
.7148 .74453 Mdot
.5817 .55691 Mdot
.37581 .30853 Mdot
.35901 .65236 Mdot
.45744 .58293 Mdot
.31946 .73557 Mdot
.54866 .63399 Mdot
.7962 .54999 Mdot
.26706 .32898 Mdot
.6233 .32241 Mdot
.68412 .33878 Mdot
.53804 .53583 Mdot
.43669 .54066 Mdot
.60104 .27496 Mdot
.55667 .52528 Mdot
.46721 .65183 Mdot
.56135 .32209 Mdot
.16897 .53811 Mdot
.18542 .43373 Mdot
.18964 .62302 Mdot
.28867 .29871 Mdot
.68043 .31931 Mdot
.37422 .37213 Mdot
.65743 .54462 Mdot
.75213 .54299 Mdot
.40359 .39351 Mdot
.29375 .28585 Mdot
.37728 .75518 Mdot
.54102 .60395 Mdot
.29679 .54615 Mdot
.18811 .54627 Mdot
.34335 .32074 Mdot
.38582 .37004 Mdot
.53067 .74828 Mdot
.58198 .70944 Mdot
.43084 .20991 Mdot
.66121 .70518 Mdot
.33883 .45437 Mdot
.72418 .5896 Mdot
.72732 .50159 Mdot
.54211 .65538 Mdot
.28192 .28838 Mdot
.57126 .1824 Mdot
.57392 .59712 Mdot
.48004 .5233 Mdot
.24287 .68729 Mdot
.50613 .4821 Mdot
.68812 .59502 Mdot
.59824 .7807 Mdot
.79612 .48272 Mdot
.63507 .67485 Mdot
.54371 .49969 Mdot
.58618 .48472 Mdot
.60734 .74927 Mdot
.58867 .62086 Mdot
.33324 .71795 Mdot
.235 .69665 Mdot
.52524 .45642 Mdot
.64981 .66316 Mdot
.34804 .37306 Mdot
.57126 .43031 Mdot
.52768 .58321 Mdot
.31338 .34976 Mdot
.62717 .61556 Mdot
.24199 .63821 Mdot
.77487 .70176 Mdot
.31826 .61801 Mdot
.39219 .23059 Mdot
.37219 .32022 Mdot
.48738 .65744 Mdot
.3804 .72241 Mdot
.77073 .53215 Mdot
.33454 .50628 Mdot
.23222 .70306 Mdot
.72609 .66366 Mdot
.34307 .35562 Mdot
.64163 .42388 Mdot
.40637 .53154 Mdot
.40781 .48399 Mdot
.19807 .63582 Mdot
.60603 .73703 Mdot
.64983 .82656 Mdot
.33575 .26151 Mdot
.49842 .62177 Mdot
.39404 .76484 Mdot
.22816 .36092 Mdot
.52445 .67038 Mdot
.58496 .57878 Mdot
.53146 .3859 Mdot
.21557 .38699 Mdot
.6363 .7386 Mdot
.65442 .72971 Mdot
.75219 .57921 Mdot
.38689 .82384 Mdot
.49547 .58224 Mdot
.75488 .48771 Mdot
.63603 .27711 Mdot
.35589 .56298 Mdot
.76809 .64626 Mdot
.74841 .56579 Mdot
.60045 .41537 Mdot
.45986 .59403 Mdot
.14581 .57108 Mdot
.30545 .52828 Mdot
.76919 .62586 Mdot
.63628 .82913 Mdot
.69868 .80519 Mdot
.65801 .74275 Mdot
.27352 .74801 Mdot
.64966 .73044 Mdot
.68604 .59725 Mdot
.72144 .51882 Mdot
.47561 .46552 Mdot
.43842 .65273 Mdot
.21239 .67456 Mdot
.60476 .20359 Mdot
.74458 .53263 Mdot
.36449 .64105 Mdot
.21065 .67464 Mdot
.30486 .5424 Mdot
.41661 .21713 Mdot
.59412 .39646 Mdot
.28312 .26249 Mdot
.19443 .39414 Mdot
.54557 .7607 Mdot
.30663 .24403 Mdot
.40359 .20911 Mdot
.44034 .30992 Mdot
.18862 .43197 Mdot
.26214 .59394 Mdot
.54606 .75132 Mdot
.2756 .32467 Mdot
.70418 .5853 Mdot
.39792 .1638 Mdot
.52695 .58366 Mdot
.55642 .5165 Mdot
.57955 .7364 Mdot
.67214 .58394 Mdot
.69383 .66464 Mdot
.50852 .49876 Mdot
.41806 .43068 Mdot
.36064 .7562 Mdot
.83441 .54936 Mdot
.61726 .78676 Mdot
.56498 .54176 Mdot
.33872 .78184 Mdot
.77302 .52317 Mdot
.40975 .38801 Mdot
.40496 .74256 Mdot
.34969 .32472 Mdot
.6421 .28501 Mdot
.34997 .50604 Mdot
.23917 .70156 Mdot
.64087 .28435 Mdot
.3255 .77088 Mdot
.16599 .45321 Mdot
.21762 .64281 Mdot
.42589 .59645 Mdot
.61925 .28278 Mdot
.22553 .38476 Mdot
.22641 .38673 Mdot
.39105 .81253 Mdot
.38188 .22471 Mdot
.41108 .402 Mdot
.52736 .48483 Mdot
.47579 .51804 Mdot
.33907 .45171 Mdot
.22372 .36629 Mdot
.50945 .68016 Mdot
.2679 .37313 Mdot
.69168 .73509 Mdot
.28786 .28754 Mdot
.38529 .75212 Mdot
.34761 .33347 Mdot
.56881 .40369 Mdot
.51434 .29679 Mdot
.63204 .37493 Mdot
.46125 .85007 Mdot
.76968 .57541 Mdot
.18767 .46636 Mdot
.81493 .54286 Mdot
.71799 .69243 Mdot
.36087 .23546 Mdot
.54026 .60946 Mdot
.29015 .60653 Mdot
.61449 .22199 Mdot
.29259 .33511 Mdot
.3373 .72686 Mdot
.71847 .57959 Mdot
.52707 .77129 Mdot
.21365 .66386 Mdot
.25307 .38271 Mdot
.52419 .8616 Mdot
.57242 .27095 Mdot
.45939 .73797 Mdot
.28126 .70999 Mdot
.82191 .60081 Mdot
.38665 .3668 Mdot
.33008 .78571 Mdot
.62276 .66326 Mdot
.25799 .72843 Mdot
.67341 .48328 Mdot
.5276 .24729 Mdot
.70756 .57406 Mdot
.36779 .34494 Mdot
.37063 .34695 Mdot
.17219 .50625 Mdot
.78123 .62553 Mdot
.75248 .67217 Mdot
.55995 .38601 Mdot
.58363 .3678 Mdot
.467 .47354 Mdot
.64459 .63741 Mdot
.47228 .84962 Mdot
.42563 .53587 Mdot
.56369 .26788 Mdot
.25141 .33529 Mdot
.65699 .54343 Mdot
.56654 .52084 Mdot
.69825 .57798 Mdot
.58022 .78393 Mdot
.23149 .4169 Mdot
.37542 .81872 Mdot
.56755 .52393 Mdot
.49589 .41716 Mdot
.49177 .75676 Mdot
.62458 .55105 Mdot
.78612 .50218 Mdot
.62126 .59545 Mdot
.49367 .49435 Mdot
.38258 .40574 Mdot
.29341 .29872 Mdot
.1496 .53688 Mdot
.35848 .7958 Mdot
.78783 .50006 Mdot
.37364 .35617 Mdot
.60476 .71451 Mdot
.3047 .33588 Mdot
.51527 .86379 Mdot
.29037 .2434 Mdot
.69121 .71792 Mdot
.28145 .29729 Mdot
.62331 .42862 Mdot
.40549 .2231 Mdot
.39463 .38084 Mdot
.27879 .70729 Mdot
.37181 .6345 Mdot
.58455 .73044 Mdot
.62698 .46202 Mdot
.33894 .38422 Mdot
.58899 .52309 Mdot
.53953 .74877 Mdot
.78268 .61909 Mdot
.526 .8611 Mdot
.37732 .21774 Mdot
.49491 .74882 Mdot
.56267 .84266 Mdot
.54762 .68341 Mdot
.59113 .4866 Mdot
.68965 .41989 Mdot
.36456 .35729 Mdot
.60081 .30764 Mdot
.46817 .56078 Mdot
.4269 .42209 Mdot
.63783 .75018 Mdot
.65773 .361 Mdot
.47658 .29281 Mdot
.56727 .6246 Mdot
.3938 .21483 Mdot
.54039 .66623 Mdot
.15241 .5274 Mdot
.64706 .62942 Mdot
.35455 .7491 Mdot
.5936 .79515 Mdot
.67217 .28545 Mdot
.82545 .56698 Mdot
.2217 .65617 Mdot
.24629 .42277 Mdot
.58386 .61722 Mdot
.5543 .62466 Mdot
.6405 .72273 Mdot
.64507 .49544 Mdot
.2467 .68647 Mdot
.24126 .33974 Mdot
.68459 .31747 Mdot
.60894 .69178 Mdot
.5386 .48123 Mdot
.55729 .5389 Mdot
.1744 .54969 Mdot
.58872 .31943 Mdot
.30634 .77591 Mdot
.5089 .6861 Mdot
.79334 .6433 Mdot
.61877 .55653 Mdot
.3715 .42134 Mdot
.39765 .36748 Mdot
.67559 .33843 Mdot
.29808 .54169 Mdot
.49948 .615 Mdot
.55052 .67108 Mdot
.59005 .51035 Mdot
.49588 .25044 Mdot
.52186 .1704 Mdot
.6704 .55434 Mdot
.48371 .674 Mdot
.21691 .37004 Mdot
.54684 .63612 Mdot
.57216 .2738 Mdot
.65704 .26735 Mdot
.33107 .57829 Mdot
.21526 .4622 Mdot
.43957 .84535 Mdot
.23045 .66297 Mdot
.59341 .63076 Mdot
.81625 .5635 Mdot
.52566 .33664 Mdot
.16949 .53383 Mdot
.62389 .74097 Mdot
.23873 .35205 Mdot
.48651 .71258 Mdot
.18452 .60209 Mdot
.40129 .76521 Mdot
.61288 .57181 Mdot
.27548 .31717 Mdot
.53863 .42492 Mdot
.27642 .29934 Mdot
.57098 .78851 Mdot
.47936 .49527 Mdot
.28254 .26664 Mdot
.63333 .4235 Mdot
.33541 .6812 Mdot
.3962 .46316 Mdot
.61348 .55378 Mdot
.22173 .38117 Mdot
.56379 .63152 Mdot
.50653 .24377 Mdot
.38127 .64505 Mdot
.75194 .53099 Mdot
.24117 .6931 Mdot
.78652 .56946 Mdot
.25553 .32675 Mdot
.47719 .52671 Mdot
.34166 .29966 Mdot
.50566 .66925 Mdot
.2646 .4223 Mdot
.32 .49078 Mdot
.49498 .71156 Mdot
.49221 .38334 Mdot
.18112 .5181 Mdot
.42142 .4745 Mdot
.28165 .73214 Mdot
.19284 .56477 Mdot
.62507 .74627 Mdot
.56753 .47969 Mdot
.61673 .67698 Mdot
.30697 .77159 Mdot
.21381 .43909 Mdot
.67856 .58119 Mdot
.19713 .39078 Mdot
.43179 .20597 Mdot
.5764 .8407 Mdot
.75601 .62531 Mdot
.5466 .52183 Mdot
.1775 .4467 Mdot
.72506 .66941 Mdot
.41353 .20657 Mdot
.33321 .72283 Mdot
.61762 .71981 Mdot
.335 .79357 Mdot
.27902 .61295 Mdot
.74145 .68116 Mdot
.30546 .72417 Mdot
.62277 .62934 Mdot
.20979 .44617 Mdot
.29427 .53078 Mdot
.62448 .37074 Mdot
.47987 .44391 Mdot
.31514 .23644 Mdot
.58229 .60233 Mdot
.23408 .35342 Mdot
.23905 .35425 Mdot
.37135 .24197 Mdot
.67542 .31852 Mdot
.5779 .83988 Mdot
.41303 .79094 Mdot
.39516 .48392 Mdot
.59774 .6311 Mdot
.4777 .29026 Mdot
.33685 .27162 Mdot
.3967 .50828 Mdot
.30842 .41803 Mdot
.49606 .72162 Mdot
.22263 .69068 Mdot
.576 .42036 Mdot
.72826 .46149 Mdot
.61445 .68804 Mdot
.67703 .58348 Mdot
.52402 .68336 Mdot
.7832 .64007 Mdot
.22535 .37708 Mdot
.57652 .59772 Mdot
.61399 .5831 Mdot
.73278 .68715 Mdot
.28185 .32903 Mdot
.48894 .35035 Mdot
.7019 .52713 Mdot
.4582 .64983 Mdot
.43539 .82791 Mdot
.73981 .67067 Mdot
.54792 .58985 Mdot
.67619 .69726 Mdot
.48588 .49057 Mdot
.76315 .48572 Mdot
.77988 .62914 Mdot
.55641 .71072 Mdot
.24394 .65004 Mdot
.63898 .65243 Mdot
.61118 .27907 Mdot
.31968 .27526 Mdot
.66334 .68167 Mdot
.22888 .36385 Mdot
.31849 .56793 Mdot
.29278 .73427 Mdot
.34574 .35546 Mdot
.50002 .23699 Mdot
.34429 .48815 Mdot
.44869 .61497 Mdot
.19726 .63535 Mdot
.67729 .72499 Mdot
.42337 .61172 Mdot
.53787 .67755 Mdot
.18419 .42678 Mdot
.58224 .28576 Mdot
.56252 .31297 Mdot
.4069 .26989 Mdot
.37919 .42375 Mdot
.4931 .42895 Mdot
.64242 .50923 Mdot
.30161 .5436 Mdot
.47396 .34715 Mdot
.48758 .50245 Mdot
.46048 .65319 Mdot
.19344 .4431 Mdot
.45665 .84648 Mdot
.52852 .59263 Mdot
.18919 .39716 Mdot
.42037 .62584 Mdot
.63016 .68821 Mdot
.38532 .21428 Mdot
.38372 .6223 Mdot
.35343 .594 Mdot
.50236 .24138 Mdot
.55262 .69323 Mdot
.45096 .84164 Mdot
.47864 .58443 Mdot
.48538 .22467 Mdot
.54732 .36641 Mdot
.50984 .57504 Mdot
.7451 .31977 Mdot
.73518 .55516 Mdot
.17645 .44147 Mdot
.26805 .32743 Mdot
.69031 .46369 Mdot
.64443 .73288 Mdot
.39121 .62221 Mdot
.29143 .73552 Mdot
.50732 .39474 Mdot
.2285 .66885 Mdot
.70948 .44224 Mdot
.47369 .67286 Mdot
.19328 .55843 Mdot
.27647 .38707 Mdot
.26748 .41796 Mdot
.51531 .73815 Mdot
.24116 .52454 Mdot
.50838 .55273 Mdot
.55532 .184 Mdot
.37712 .17696 Mdot
.49367 .85917 Mdot
.78966 .64779 Mdot
.32851 .46766 Mdot
.30024 .33866 Mdot
.64381 .6693 Mdot
.41532 .39415 Mdot
.5453 .37913 Mdot
.59266 .27385 Mdot
.64346 .42929 Mdot
.82775 .54684 Mdot
.23119 .70036 Mdot
.34369 .48937 Mdot
.45682 .36533 Mdot
.43798 .26295 Mdot
.5867 .31268 Mdot
.33317 .65702 Mdot
.43611 .84271 Mdot
.70077 .52522 Mdot
.70413 .41454 Mdot
.64098 .51538 Mdot
.17416 .50618 Mdot
.68327 .40099 Mdot
.65531 .51387 Mdot
.15152 .52678 Mdot
.70865 .72189 Mdot
.54529 .78119 Mdot
.82381 .53581 Mdot
.18314 .53413 Mdot
.49169 .70449 Mdot
.59287 .27986 Mdot
.26108 .72269 Mdot
.39593 .36861 Mdot
.66051 .31014 Mdot
.23068 .5657 Mdot
.27607 .31282 Mdot
.32972 .26706 Mdot
.69103 .45258 Mdot
.3817 .63546 Mdot
.52419 .15637 Mdot
.67515 .28604 Mdot
.80464 .67468 Mdot
.2301 .65876 Mdot
.46311 .82001 Mdot
.65773 .73482 Mdot
.56799 .39384 Mdot
.28579 .72773 Mdot
.23765 .36169 Mdot
.40124 .62502 Mdot
.5851 .19748 Mdot
.29582 .37069 Mdot
.32623 .33053 Mdot
.75481 .47563 Mdot
.19828 .62513 Mdot
.67673 .30907 Mdot
.25397 .57588 Mdot
.26364 .32481 Mdot
.43208 .62352 Mdot
.26505 .42789 Mdot
.42508 .82336 Mdot
.21253 .46022 Mdot
.30119 .27674 Mdot
.64637 .42902 Mdot
.52809 .31428 Mdot
.44848 .83716 Mdot
.51275 .63895 Mdot
.48709 .71941 Mdot
.63959 .82819 Mdot
.28398 .75373 Mdot
.37106 .62457 Mdot
.34081 .57187 Mdot
.15608 .49405 Mdot
.55305 .29525 Mdot
.19448 .4511 Mdot
.69455 .75318 Mdot
.3401 .25453 Mdot
.44524 .49569 Mdot
.36765 .50453 Mdot
.3808 .28967 Mdot
.60633 .74331 Mdot
.39811 .62906 Mdot
.67394 .38672 Mdot
.29569 .28536 Mdot
.48647 .67375 Mdot
.77415 .70239 Mdot
.57332 .78568 Mdot
.60571 .6852 Mdot
.24875 .71283 Mdot
.28164 .63449 Mdot
.49478 .66054 Mdot
.2803 .71398 Mdot
.50027 .40261 Mdot
.47698 .34713 Mdot
.50399 .66445 Mdot
.37472 .37039 Mdot
.31742 .23272 Mdot
.55947 .84539 Mdot
.445 .65799 Mdot
.31424 .78207 Mdot
.17507 .59921 Mdot
.60693 .68744 Mdot
.33921 .63648 Mdot
.3887 .35447 Mdot
.61654 .6161 Mdot
.63846 .45461 Mdot
.68087 .33945 Mdot
.44883 .20383 Mdot
.51348 .17288 Mdot
.38223 .51769 Mdot
.71076 .44193 Mdot
.21605 .66479 Mdot
.44172 .20935 Mdot
.22175 .67472 Mdot
.49959 .70248 Mdot
.41673 .50633 Mdot
.70346 .80263 Mdot
.68375 .596 Mdot
.40608 .58882 Mdot
.29675 .48739 Mdot
.30623 .4777 Mdot
.33848 .50756 Mdot
.65174 .44938 Mdot
.36369 .31835 Mdot
.33099 .25369 Mdot
.26016 .71817 Mdot
.59794 .70215 Mdot
.39407 .36444 Mdot
.74186 .51356 Mdot
.32698 .39809 Mdot
.25493 .51354 Mdot
.72871 .49343 Mdot
.33499 .24225 Mdot
.74343 .3208 Mdot
.51808 .36463 Mdot
.58709 .53564 Mdot
.40488 .42699 Mdot
.57127 .5683 Mdot
.36035 .22687 Mdot
.64417 .505 Mdot
.44228 .31131 Mdot
.25959 .32323 Mdot
.51873 .75197 Mdot
.75934 .48976 Mdot
.46003 .14492 Mdot
.38995 .37151 Mdot
.67975 .43325 Mdot
.32319 .61793 Mdot
.57983 .77426 Mdot
.24605 .66536 Mdot
.4925 .34262 Mdot
.50736 .55915 Mdot
.4875 .75123 Mdot
.27446 .71783 Mdot
.71337 .48457 Mdot
.1496 .54903 Mdot
.31929 .61321 Mdot
.337 .65985 Mdot
.41566 .80497 Mdot
.55375 .50139 Mdot
.3434 .72982 Mdot
.35018 .46667 Mdot
.47721 .41159 Mdot
.72491 .30355 Mdot
.56636 .53383 Mdot
.5203 .57918 Mdot
.60904 .60526 Mdot
.38704 .23318 Mdot
.2591 .64648 Mdot
.33949 .52876 Mdot
.46011 .29087 Mdot
.36119 .36978 Mdot
.53557 .27371 Mdot
.54003 .2733 Mdot
.75437 .51031 Mdot
.35656 .22993 Mdot
.33557 .26232 Mdot
.31225 .72344 Mdot
.30307 .75695 Mdot
.40298 .4665 Mdot
.22734 .65283 Mdot
.5507 .40991 Mdot
.69993 .66383 Mdot
.21555 .45889 Mdot
.55413 .84625 Mdot
.50259 .6074 Mdot
.32559 .46357 Mdot
.16952 .57315 Mdot
.2111 .64662 Mdot
.7448 .5379 Mdot
.7183 .58357 Mdot
.34754 .19456 Mdot
.37567 .34608 Mdot
.83105 .54794 Mdot
.6565 .40848 Mdot
.16993 .55603 Mdot
.49076 .51597 Mdot
.35708 .62317 Mdot
.51726 .71973 Mdot
.35517 .592 Mdot
.60298 .32573 Mdot
.5963 .78005 Mdot
.51716 .74114 Mdot
.24518 .51607 Mdot
.40328 .48532 Mdot
.60887 .4852 Mdot
.60559 .71649 Mdot
.50009 .859 Mdot
.59308 .30066 Mdot
.49531 .41424 Mdot
.74618 .7269 Mdot
.73006 .30789 Mdot
.42693 .20367 Mdot
.38001 .80662 Mdot
.74871 .54665 Mdot
.49013 .49949 Mdot
.81625 .42886 Mdot
.62508 .68487 Mdot
.59456 .62712 Mdot
.65977 .55008 Mdot
.34618 .30163 Mdot
.76874 .63361 Mdot
.60138 .83764 Mdot
.18252 .59747 Mdot
.32262 .57189 Mdot
.85054 .61321 Mdot
.25913 .32845 Mdot
.47177 .38647 Mdot
.77288 .62216 Mdot
.23673 .69696 Mdot
.63792 .43106 Mdot
.16676 .46235 Mdot
.65724 .67444 Mdot
.63326 .65055 Mdot
.34033 .31765 Mdot
.81104 .54755 Mdot
.53995 .48528 Mdot
.8063 .66993 Mdot
.73399 .5883 Mdot
.32461 .33717 Mdot
.67321 .72465 Mdot
.62983 .65774 Mdot
.49949 .60401 Mdot
.64714 .61887 Mdot
.45272 .59416 Mdot
.55894 .59187 Mdot
.62023 .58785 Mdot
.49498 .35412 Mdot
.60962 .5202 Mdot
.67581 .59278 Mdot
.6758 .54774 Mdot
.54004 .76013 Mdot
.32738 .21356 Mdot
.55476 .27448 Mdot
.5743 .33195 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo09?ooooo0_l0002dooooo`007?ooool0
0ol0003oooooooooo`2Cooooo`;o0000]?ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`2:ooooo`;o00001_ooool3o`000;Cooooo000Looooo`03o`00
0?oooooooooo08[ooooo0_l00006ooooo`?o0000]?ooool001cooooo0_l00029ooooo`;o0000_ooo
ool001cooooo00?o0000ooooooooool0R?ooool2o`0001gooooo0_l0002Pooooo`007?ooool00ol0
003oooooooooo`2Wooooo`;o0000X?ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`1nooooo`;o0000bOooool001cooooo00?o0000ooooooooool0O_oo
ool2o`0002?ooooo1_l0002Pooooo`007?ooool00ol0003oooooooooo`2Sooooo`Ko0000X?ooool0
01cooooo00?o0000ooooooooool0Xoooool2o`000003ooooool0003o000000Kooooo0_l0002Ioooo
o`007?ooool00ol0003oooooooooo`1gooooo`;o0000:_ooool2o`0000Kooooo1Ol0002Iooooo`00
7?ooool00ol0003oooooooooo`1dooooo`;o000000?oooooo`000?l00000;Oooool2o`0000?ooooo
1Ol0002Iooooo`007?ooool00ol0003oooooooooo`1dooooo`;o0000<?ooool2o`0000Kooooo0_l0
00000ooooooo0000o`000003ooooo`;o0000TOooool001cooooo00?o0000ooooooooool0L?ooool2
o`0003oooooo0_l000000ooooooo0000o`000002o`00097ooooo000Looooo`03o`000?oooooooooo
073ooooo0_l00012ooooo`;o0000Toooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2
ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo06oooooo0_l00019ooooo`;o0000SOooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A006ooooo`03o`000?oooooooooo06gooooo1?l00019ooooo`;o0000SOooool00003ooooool@
413ooooo00;ooooo00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oo
oooooooo06gooooo0_l00011ooooo`;o00002?ooool3o`0008cooooo00000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;3ooooo0_l00008
ooooo`?o0000S?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00omg
MgOoIVIVooooo`05ooooo`03o`000?oooooooooo08Oooooo1?l00003ooooo`;o0000<Oooool2o`00
08Kooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`1Xooooo`;o00005Oooool2o`0000;ooooo0_l00002ooooo`Co
00000oooool2o`00037ooooo0_l00026ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;oooo
o`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`1Vooooo`Co00005Oooool2
o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000cooooo0_l0002]ooooo`0000Koooooonk^
k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`1Tooooo`Go00004?ooool2o`000003ooooool0003o000000[ooooo0_l00002ooooo`;o0000
3?ooool2o`0001kooooo0_l0002=ooooo`007?ooool00ol0003oooooooooo`1Tooooo`Go00003_oo
ool4o`000004ooooool0003o0000o`0000Gooooo0_l0000<ooooo`;o00009_ooool2o`000003oooo
ool0003o000008[ooooo000Looooo`03o`000?oooooooooo07Oooooo0_l00004ooooo`;o00001Ooo
ool2o`0000_ooooo0ol0000Yooooo`;o0000R_ooool001cooooo00?o0000ooooooooool0P?ooool2
o`0000Kooooo0_l00007ooooo`;o00001oooool2o`0000;ooooo0_l0000Tooooo`;o0000Poooool0
01cooooo00?o0000ooooooooool0LOooool2o`0000Gooooo0_l00006ooooo`;o00001_ooool2o`00
013ooooo0_l00002ooooo`;o00009?ooool2o`0008?ooooo000Looooo`03o`000?oooooooooo073o
oooo0ol00005ooooo`;o00000_ooool2o`0000Sooooo1?l0000nooooo`;o0000Ooooool001cooooo
00?o0000ooooooooool0Goooool3o`000003ooooool0003o000000_ooooo0_l00008ooooo`Co0000
1oooool3o`0000_ooooo1Ol0000`ooooo`;o0000Ooooool001cooooo00?o0000ooooooooool0Gooo
ool3o`000003ooooool0003o000000cooooo0_l00007ooooo`;o000000?oooooo`000?l000001_oo
ool2o`0000cooooo1Ol00007ooooo`;o0000Z?ooool001cooooo00?o0000ooooooooool0Hoooool2
o`000003ooooool0003o000000Wooooo0ol00009ooooo`;o00001_ooool2o`0000kooooo0_l00002
ooooo`?o00000oooool2o`000003ooooool0003o00000:Gooooo000Looooo`03o`000?oooooooooo
05cooooo0_l00005ooooo`;o000000Coooooo`000?l0003ooooo0_l00007ooooo`;o000000?ooooo
o`000?l000001_ooool2o`0000?ooooo0_l00008ooooo`;o00001Oooool4o`0000;ooooo1Ol00000
1?oooooo0000o`000?ooool2o`000:Gooooo000Looooo`03o`000?oooooooooo05[ooooo1?l00002
ooooo`;o00001oooool2o`0000[ooooo0_l00004ooooo`?o00001?ooool2o`0000Sooooo0_l00005
oooooa3o0000Y_ooool001cooooo00?o0000ooooooooool0F_ooool3o`0000?ooooo0_l0000Ioooo
o`?o00000oooool2o`0000Sooooo0_l00004oooooaCo00000oooool2o`0009oooooo000Looooo`;o
0000Eoooool4o`0001Cooooo0_l0000;ooooo`;o00001?ooool2o`0000Sooooo0ol00002oooooaGo
00000oooool2o`0009oooooo000Looooo`03o`000?oooooooooo05Kooooo1Ol0000=ooooo`;o0000
00Coooooo`000?l0003ooooo0_l0000Looooo`;o00000_ooool2o`000003ooooool0003o0000013o
0000Y?ooool001cooooo00?o0000ooooooooool0FOooool2o`0000?ooooo0_l00007ooooo`?o0000
00?oooooo`000?l000008?ooool2o`000003ooooool0003o000001;o00000_ooool2o`000:7ooooo
000Looooo`03o`000?oooooooooo05[ooooo1_l00007ooooo`Co00008_oooolKo`000:7ooooo000L
ooooo`03o`000?oooooooooo05Kooooo2_l00007ooooo`Co00005_ooool2o`0000Sooooo0_l00000
0ooooooo0000o`00000Go`000:;ooooo000Looooo`03o`000?oooooooooo05Kooooo1Ol00002oooo
o`;o00002?ooool4o`0001Kooooo0_l000000ooooooo0000o`000005oooooaco0000:oooool2o`00
07Gooooo000Looooo`03o`000?oooooooooo05Sooooo0_l00003ooooo`;o00002?ooool2o`0001Oo
oooo0_l00002ooooo`;o00001OoooolMo`000003ooooool0003o000000;o00001_ooool2o`0001go
oooo0_l0001eooooo`007?ooool00ol0003oooooooooo`1Looooo`;o00002_ooool4o`0000gooooo
0_l00005ooooo`;o00002Oooool3o`0000;ooooo6?l000000ooooooo0000o`000003o`0000Gooooo
0_l000000ooooooo0000o`000005ooooo`;o0000R_ooool001cooooo00?o0000ooooooooool0G?oo
ool4o`0000Cooooo0_l00002ooooo`Go00003?ooool2o`0000Sooooo0_l00007ooooo`;o00001?oo
oolFo`0000;ooooo1?l00002ooooo`;o00001?ooool2o`0000Gooooo1?l00028ooooo`007?ooool0
0ol0003oooooooooo`1Looooo`Co00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000:
ooooo`;o00002_ooool3o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0
003o000001Co000000?oooooo`000?l000001Oooool2o`0000_ooooo1?l00002ooooo`;o00001_oo
ool2o`0007cooooo000Looooo`03o`000?oooooooooo05cooooo0_l00003ooooo`;o00001?ooool3
o`0000gooooo0_l0000;ooooo`;o00000oooool2o`0000Cooooo0_l00002oooooaGo000000?ooooo
o`000?l000003oooool2o`000003ooooool0003o000000;ooooo1_l00004ooooo`Co0000N_ooool0
01cooooo00?o0000ooooooooool0G?ooool2o`0000?ooooo0_l00004ooooo`;o00003_ooool2o`00
01Kooooo0_l00002oooooaGo00003Oooool2o`0000;ooooo1Ol000000ooooooo0000o`000002o`00
00;ooooo0_l00005ooooo`?o00002?ooool3o`0006oooooo000Looooo`03o`000?oooooooooo05So
oooo1_l00007ooooo`;o00004?ooool2o`0000Wooooo0_l00003ooooo`;o00000_ooool2o`0000;o
oooo0_l00004ooooo`oo00001oooool2o`0000Cooooo0ol000000ooooooo0000o`000002ooooo`Go
000000Coooooo`000?l0003o00002_ooool3o`0000Sooooo0ol0001_ooooo`007?ooool00ol0003o
ooooooooo`1Gooooo`Go00001oooool4o`00017ooooo0_l00008ooooo`;o00000oooool2o`0000;o
oooo0_l00005ooooo`;o000000?oooooo`000?l000003_l00006ooooo`;o00001?ooool3o`0000Ko
oooo0ol00008ooooo`?o0000POooool001cooooo00?o0000ooooooooool0Eoooool2o`0000Sooooo
1?l0000Cooooo`;o00005?ooool3o`000003ooooool0003o0000017o00002oooool2o`0000Gooooo
0_l000001Ooooooo0000o`000?l0003ooooo00;o00000oooool5o`00087ooooo000Looooo`03o`00
0?oooooooooo05Sooooo0_l00007ooooo`?o00007oooool2o`0000Wooooo0ol000000ooooooo0000
o`000002o`000003ooooool0003o000000So00000_ooool2o`0000_ooooo0_l00005ooooo`;o0000
00Coooooo`000?l0003ooooo1Ol000000ooooooo0000o`000006ooooo`;o0000O?ooool001cooooo
0_l0001Fooooo`Wo00003Oooool4o`0000Oooooo0ol0000:ooooo`;o00003oooool;o`0000Cooooo
0_l00004ooooo`;o00003oooool2o`000003ooooool0003o000000Oo00000oooool4o`0000[ooooo
0_l000000ooooooo0000o`00001]ooooo`007?ooool00ol0003oooooooooo`1Eooooo`?o00000_oo
ool4o`0000gooooo1?l00007ooooo`?o00004oooool2o`0000Cooooo0_l00002ooooo`Wo00001ooo
ool2o`000003ooooool0003o000000_ooooo0_l00002ooooo`go00000_ooool3o`0000_ooooo0_l0
00000ooooooo0000o`00000<ooooo`;o0000Goooool001cooooo00?o0000ooooooooool0E?ooool2
o`0000Cooooo0_l0000Iooooo`?o00005?ooool2o`0000Cooooo0_l00003ooooo`;o000000?ooooo
o`000?l000002_ooool2o`000003ooooool0003o000000_ooooo0_l00002oooooa;o00006_ooool4
o`0005oooooo000Looooo`03o`000?oooooooooo05?ooooo0ol0000Nooooo`Co00004oooool2o`00
02cooooo2?l000000ooooooo0000o`000005o`0000;ooooo0ol00005ooooo`;o00000oooool2o`00
00cooooo0_l000000ooooooo0000o`00001Nooooo`007?ooool00ol0003oooooooooo`1Cooooo`Go
00003Oooool2o`0000cooooo1Ol0000>ooooo`;o00000oooool4o`0001Wooooo0_l00009ooooo`;o
00000_ooool6o`000003ooooool0003o000000ko00001Oooool2o`0000?ooooo0_l000000ooooooo
0000o`000006ooooo`;o000000Coooooo`000?l0003ooooo0_l0001Nooooo`007?ooool00ol0003o
ooooooooo`1Aooooo`;o000000?oooooo`000?l000000_l0000=ooooo`;o00002oooool5o`000003
ooooool0003o000000cooooo0_l00004ooooo`?o00005oooool4o`0000Wooooo0_l000000ooooooo
0000o`00000Do`0000Oooooo0_l00006ooooo`;o00001_ooool2o`0006Cooooo000Looooo`03o`00
0?oooooooooo057ooooo0_l00003ooooo`;o00004oooool2o`0000?ooooo1Ol00003ooooo`;o0000
5Oooool2o`0001Cooooo1Ol0000;oooooaOo00001oooool2o`0000?ooooo1Ol0000Aooooo`;o0000
FOooool001cooooo00?o0000ooooooooool0DOooool2o`0000?ooooo0_l00007ooooo`;o00002_oo
ool3o`0000;ooooo1ol0000?ooooo`;o00001oooool3o`0001;ooooo0ol0000<oooooa_o00001Ooo
ool2o`0000?ooooo1Ol0000Aooooo`;o0000FOooool001cooooo00?o0000ooooooooool0DOooool3
o`0000;ooooo0_l00007ooooo`;o00002oooool6o`0000;ooooo0ol0000?ooooo`;o00002?ooool4
o`00013ooooo0_l0000<oooooa?o000000?oooooo`000?l000001_l00005ooooo`;o00006Oooool2
o`0000Sooooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`1=ooooo`go00005?ooool2o`00
00Gooooo0_l0000Jooooo`?o00004?ooool2o`0000cooooo0_l00002ooooo`?o000000?oooooo`00
0?l000002_l00003ooooo`Go0000:_ooool2o`0004oooooo000Looooo`03o`000?oooooooooo04go
oooo2_l000000ooooooo0000o`000002o`0000Cooooo0_l00002ooooo`Co00001_ooool2o`0000Go
oooo0_l000000ooooooo0000o`00000Gooooo`?o00004?ooool2o`00013ooooo0ol000000ooooooo
0000o`00000Do`00027ooooo0_l00005ooooo`?o0000C_ooool001cooooo00?o0000ooooooooool0
C_ooool2o`0000[ooooo0ol000000ooooooo0000o`000002o`0000;ooooo1?l00005ooooo`?o0000
1Oooool2o`000003ooooool0003o000000gooooo0_l0000>ooooo`;o00007Oooool3o`000003oooo
ool0003o000001Ko00000_ooool2o`0000;ooooo0_l0000Gooooo`;o00001_ooool3o`0004gooooo
000Looooo`03o`000?oooooooooo04kooooo0_l0000:ooooo`?o000000Coooooo`000?l0003o0000
1Oooool2o`0000Gooooo0ol00005ooooo`;o00004?ooool2o`0000kooooo0ol0000=ooooo`;o0000
3?oooolMo`0000;ooooo0_l00002ooooo`;o00006oooool2o`0000?ooooo0_l0001=ooooo`007?oo
ool00ol0003oooooooooo`1;ooooo`;o00003Oooool2o`0000;ooooo0ol00005ooooo`;o00001?oo
ool4o`0000Gooooo0_l0000Aooooo`?o000000?oooooo`000?l000002_ooool4o`0000_ooooo0_l0
000<oooooa_o00002?ooool4o`0000Oooooo0_l0000@ooooo`;o0000D_ooool001cooooo00?o0000
ooooooooool0BOooool4o`0001cooooo1Ol0000Jooooo`Ko00002oooool6o`0001Oooooo7?l00006
ooooo`Co00001oooool2o`0006Cooooo000Looooo`03o`000?oooooooooo04Wooooo0_l00003oooo
o`;o00003oooool?o`0000Kooooo1?l0000Cooooo`Co00001oooool9o`0000;ooooo0_l0000Coooo
oaco00001_ooool2o`0006oooooo000Looooo`;o0000Coooool2o`0000kooooo4?l00006ooooo`Co
00005Oooool2o`0000Oooooo0ol000000ooooooo0000o`000002o`0000?ooooo0_l000000ooooooo
0000o`000002o`0000kooooo4?l000001Ooooooo0000o`000?l0003ooooo00Co000000?oooooo`00
0?l000002?ooool2o`00027ooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`18ooooo`Co
00003oooool2o`000005ooooool0003o0000o`000?ooool00_l000000ooooooo0000o`00000Zoooo
o`;o00002?ooool2o`0000?ooooo0ol000000ooooooo0000o`000003o`0000gooooo6Ol000001?oo
oooo0000o`000?l00006ooooo`?o00008Oooool2o`0004[ooooo000Looooo`03o`000?oooooooooo
04Sooooo1?l0000?ooooo`;o00002?ooool2o`0000Gooooo0ol00007ooooo`;o00000oooool2o`00
01;ooooo1?l0000:ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`0000gooooo5_l00000
0ooooooo0000o`000004o`0000Kooooo0_l0000Rooooo`;o0000B_ooool001cooooo00?o0000oooo
ooooool0B_ooool2o`0000oooooo0_l0000?ooooo`?o00001?ooool2o`000003ooooool0003o0000
00?ooooo0_l0000Booooo`Co00002_ooool2o`0000Kooooo1Ol000000ooooooo0000o`000009oooo
oa[o00002_ooool2o`0006gooooo000Looooo`03o`000?oooooooooo04Kooooo0_l000000ooooooo
0000o`00000?ooooo`?o00005Oooool4o`0002oooooo3?l00005ooooo`?o000000?oooooo`000?l0
00005Ol000000ooooooo0000o`000006ooooo`;o00008_ooool2o`0004Wooooo000Looooo`03o`00
0?oooooooooo04;ooooo0_l000000ooooooo0000o`000004o`0000Gooooo0_l00008ooooo`;o0000
4_ooool2o`0000;ooooo1?l00006ooooo`Co00004Oooool4o`0000Sooooo0_l00005ooooo`?o0000
0_ooool8o`0000Gooooo6ol000000ooooooo0000o`000005ooooo`;o00008oooool3o`0004Sooooo
000Looooo`03o`000?oooooooooo04;ooooo0_l000000ooooooo0000o`000002o`0000Oooooo0_l0
0007ooooo`?o00003_ooool2o`0000;ooooo0_l0000:ooooo`Ko00004Oooool6o`0000Kooooo0_l0
0005ooooo`?o00000_ooool2o`0000?ooooo0_l00007oooooaSo00002_ooool2o`0002Cooooo0ol0
0017ooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00005?ooool5o`0000cooooo0ol00005
ooooo`;o00000_ooool2o`0000;ooooo1Ol0000Fooooo`;o00004_ooool7o`0000[ooooo4ol0000=
ooooo`;o00009?ooool2o`0004Oooooo000Looooo`03o`000?oooooooooo04?ooooo0_l00005oooo
o`;o00001oooool2o`0000Cooooo0_l000000ooooooo0000o`00000:ooooo`;o000000?oooooo`00
0?l000000_l00003ooooo`;o00000_ooool2o`0000;ooooo0ol0000^ooooo`?o00003_oooolBo`00
00cooooo0_l0001]ooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00000oooool2o`0000Go
oooo1?l000001?oooooo0000o`000?l00008ooooo`;o00000oooool6o`000003ooooool0003o0000
00?o00000oooool2o`0001kooooo0_l00004ooooo`;o00007ooooolBo`0000Sooooo0_l0000Voooo
o`;o0000BOooool001cooooo00?o0000ooooooooool0A?ooool3o`0000Oooooo0_l000000ooooooo
0000o`000002ooooo`Ko00001_ooool2o`0000;ooooo3Ol00003ooooo`Go00000_ooool2o`0001Oo
oooo0_l00004ooooo`;o00002Oooool2o`0000Gooooo0_l0000>ooooo`_o000000?oooooo`000?l0
00002oooool2o`0002Kooooo0_l000000ooooooo0000o`000016ooooo`007?ooool00ol0003ooooo
ooooo`14ooooo`Co00001_ooool2o`0000Cooooo1?l000000ooooooo0000o`00000:ooooo`;o0000
0oooool8o`000003ooooool0003o000000;ooooo0ol00002ooooo`;o00007_ooool2o`0000Sooooo
0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00002ooooo`Wo000000?oooooo`000?l00000
=_ooool2o`0004Kooooo000Looooo`03o`000?oooooooooo03cooooo0_l00004ooooo`;o00000_oo
ool2o`0000Kooooo0_l000001?oooooo0000o`000?ooool4o`0000Cooooo0_l00003ooooo`?o0000
1_ooool8o`000004ooooool0003o0000o`0000?ooooo0_l0000Jooooo`;o00001Oooool4o`0000Wo
oooo0_l00007ooooo`Co00001Oooool3o`0000?ooooo0_l000000ooooooo0000o`000002o`000003
ooooool0003o000000cooooo0_l0001`ooooo`007?ooool00ol0003oooooooooo`0looooo`;o0000
1?ooool2o`0000;ooooo1?l00007ooooo`;o00000oooool2o`0000?ooooo0ol00002ooooo`Co0000
1_ooool8o`0000;ooooo0_l00003ooooo`;o00001_ooool2o`0001;ooooo0_l00005ooooo`Co0000
2Oooool2o`0000Oooooo0_l00008ooooo`?o00001oooool2o`0000oooooo0_l0001`ooooo`0000Ko
ooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Co
oooo00?o0000ooooooooool0??ooool2o`0000[ooooo0_l00007ooooo`;o00001Oooool5o`0000?o
oooo0ol00008ooooo`Wo000000?oooooo`000?l000002?ooool4o`0000?ooooo0_l0000]ooooo`;o
00001_ooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l00000Ooooool00006oooo
oomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0jooooo`?o00001Oooool2o`0000[ooooo0_l00007ooooo`Ko00000oooool2o`00
00?ooooo0ol00003ooooo`Wo000000?oooooo`000?l000001oooool3o`0000;ooooo0_l000000ooo
oooo0000o`00000Iooooo`;o00004_ooool2o`0000Kooooo0_l00002ooooo`;o00000_ooool2o`00
0003ooooool0003o000000Gooooo0_l00006ooooo`?o0000:Oooool2o`0004Cooooo00000ooooooo
410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006ooooo`03o`000?oooooooooo03[o
oooo0ol00005ooooo`;o00002_ooool2o`000003ooooool0003o000000?ooooo1?l000001?oooooo
0000o`000?ooool5o`000003ooooool0003o000000;o00001?ooool3o`0000;ooooo0ol00004oooo
o`?o00000oooool4o`000003ooooool0003o000001cooooo0_l0000Fooooo`;o00000_ooool3o`00
0003ooooool0003o000000Co00001?ooool2o`0000;ooooo1?l00004ooooo`?o000000?oooooo`00
0?l000001Oooool2o`0001oooooo0_l00014ooooo`0000?oooooo`000?ooool00_ooool00ol0003o
ooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0000iooooo`;o00004_ooool3o`00
0003ooooool0003o000000?ooooo1Ol00003ooooo`Go000000?oooooo`000?l000000_l00003oooo
o`Go00000oooool3o`000003ooooool0003o000000;o00001Oooool4o`0001_ooooo0_l0000Hoooo
o`;o00000oooool2o`0000?ooooo0_l00006ooooo`;o00001?ooool2o`0000Oooooo0ol00005oooo
o`;o0000IOooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?oMgMgo
EEEEooooool00007ooooo`03o`000?oooooooooo03Wooooo0_l00009ooooo`;o000000?oooooo`00
0?l000001?ooool2o`0000Oooooo0_l000000ooooooo0000o`000004ooooo`;o00002_ooool2o`00
0004ooooool0003o0000ooooo`co00001?ooool3o`0000?ooooo1?l0000Dooooo`;o00005?ooool2
o`0000Gooooo0_l0000:ooooo`;o00000oooool2o`000003ooooool0003o000000?o00000_ooool2
o`000003ooooool0003o000002Kooooo0_l00015ooooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0?oooool2o`00
00?ooooo0_l000001?oooooo0000o`000?ooool2o`0000Kooooo1?l00002ooooo`;o00005oooool7
o`000003ooooool0003o000000?o00000oooool2o`0000Cooooo1?l0000;ooooo`;o00003_ooool2
o`0000gooooo0_l00005ooooo`;o00001oooool2o`000004ooooool0003o0000o`0000;ooooo3?l0
000Yooooo`;o0000AOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4
o`000007ooooo`03o`000?oooooooooo03oooooo0_l00008ooooo`?o00001_ooool4o`0000;ooooo
0_l0000:ooooo`;o00001_ooool2o`0000Gooooo1Ol000001?oooooo0000o`000?ooool2o`0000Go
oooo0_l00004ooooo`;o00002oooool3o`0000gooooo0_l00007ooooo`;o00005?ooool2o`000004
ooooool0003o0000o`0000Cooooo2Ol0001aooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h=
ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0BOooool2o`0000Kooooo0ol00002
ooooo`Co00002_ooool2o`000004ooooool0003o0000o`0000;ooooo0_l00006ooooo`;o000000?o
ooooo`000?l000000oooool3o`0000Cooooo0_l00004ooooo`;o00003?ooool2o`0000Cooooo0_l0
000@ooooo`;o00003_ooool2o`0001?ooooo0ol0000:ooooo`;o0000I_ooool001cooooo00?o0000
ooooooooool0Aoooool2o`0000Oooooo1Ol000000ooooooo0000o`000008ooooo`;o00000_ooool2
o`000004ooooool0003o0000o`0000;ooooo0_l00008ooooo`?o000000?oooooo`000?l000001?l0
0005ooooo`;o00004Oooool2o`0000?ooooo0_l0000:ooooo`;o00005?ooool2o`0001;ooooo0ol0
000;ooooo`;o00008Oooool2o`0004?ooooo000Looooo`03o`000?oooooooooo04Oooooo0_l00003
ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o00001oooool3o`0001?ooooo0ol0
0002ooooo`Oo00001?ooool2o`00017ooooo0_l00003ooooo`;o00002_ooool2o`000003ooooool0
003o000000;o00001oooool2o`0001;ooooo0_l00006ooooo`?o00001_ooool2o`0002Kooooo0_l0
0013ooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00001?ooool6o`0000Oooooo0_l0000D
ooooo`Co00000oooool5o`0000Kooooo0_l00002ooooo`Go00006_ooool6o`0000Oooooo0_l0000A
ooooo`Go00003Oooool2o`0006_ooooo000Looooo`03o`000?oooooooooo03Sooooo0_l0000;oooo
o`;o000000Coooooo`000?l0003ooooo1_l000000ooooooo0000o`000003o`0000Kooooo0_l0000H
ooooo`;o00001Oooool4o`0000?ooooo1?l00002ooooo`Go00000_ooool2o`0001Kooooo0ol0000M
ooooo`;o000000?oooooo`000?l00000N_ooool001cooooo00?o0000ooooooooool0>?ooool2o`00
00_ooooo0_l000001?oooooo0000o`000?ooool:o`0000Cooooo0_l00002ooooo`;o00007oooool4
o`000003ooooool0003o000000;o00000oooool2o`000003ooooool0003o000000?ooooo0_l00008
ooooo`Co00002oooool2o`0000Wooooo0_l0000>ooooo`?o00000_ooool6o`0003Cooooo0_l00012
ooooo`007?ooool00ol0003oooooooooo`0iooooo`?o00001oooool2o`0000;ooooo0_l000000ooo
oooo0000o`00000;o`0000;ooooo0_l0000Uooooo`;o000000Coooooo`000?l0003o00001?ooool2
o`000003ooooool0003o000000Wooooo0_l00002ooooo`Co00002oooool2o`0000Wooooo0_l00003
ooooo`;o00002Oooool;o`0000;ooooo0_l00004ooooo`;o0000:_ooool2o`0004;ooooo000Loooo
o`03o`000?oooooooooo03Wooooo0ol00007ooooo`;o000000?oooooo`000?l000002?l000000ooo
oooo0000o`000002ooooo`;o0000=_ooool2o`0000Wooooo1?l0000?ooooo`?o00000_ooool2o`00
00Wooooo0_l0000;ooooo`Co000000?oooooo`000?l000001?ooool2o`0000Cooooo0_l000000ooo
oooo0000o`000004ooooo`;o0000??ooool2o`0002Oooooo000Looooo`03o`000?oooooooooo03[o
oooo0_l00006ooooo`;o00000_ooool2o`000003ooooool0003o000000?ooooo0_l0000mooooo`;o
00002oooool2o`00013ooooo0_l00002ooooo`;o00005_ooool4o`00013ooooo0_l00004ooooo`Co
0000>_ooool2o`0002Oooooo000Looooo`03o`000?oooooooooo03Kooooo0_l00003ooooo`;o0000
1Oooool2o`0004Wooooo0_l000000ooooooo0000o`000003ooooo`;o0000=Oooool2o`0000;ooooo
0_l0000Aooooo`?o0000>_ooool2o`0002Oooooo000Looooo`03o`000?oooooooooo03Gooooo0ol0
0003ooooo`;o00000oooool2o`0004_ooooo0_l000001?oooooo0000o`000?l00002ooooo`;o0000
00?oooooo`000?l000003?ooool3o`0000Gooooo0ol0000Kooooo`Ko00004Oooool2o`0006Cooooo
000Looooo`03o`000?oooooooooo03Gooooo0ol00002ooooo`?o00000oooool2o`000003ooooool0
003o000000?ooooo0_l00017ooooo`;o00001Oooool2o`0000[ooooo1_l00004ooooo`?o00007Ooo
ool4o`00017ooooo0_l000001?oooooo0000o`000?ooool2o`0005kooooo000Looooo`;o0000=ooo
ool2o`0000;ooooo0ol00005ooooo`?o00000oooool2o`00023ooooo0_l00006ooooo`;o0000<?oo
ool6o`0000Cooooo1?l0000Gooooo`;o00001?ooool3o`0000_ooooo0_l00005ooooo`Co000000?o
ooooo`000?l00000G_ooool001cooooo00?o0000ooooooooool0<_ooool2o`0000Oooooo0_l00005
ooooo`;o00000_ooool2o`0002;ooooo0_l00006ooooo`;o000000?oooooo`000?l000006Oooool3
o`00013ooooo2?l00003ooooo`Co00005oooool2o`000004ooooool0003o0000ooooo`;o00003?oo
ool2o`0000Gooooo0_l0001Sooooo`007?ooool00ol0003oooooooooo`0booooo`;o00001Oooool2
o`0000_ooooo0_l0000Rooooo`;o00002Oooool2o`0001Wooooo1_l0000:ooooo`co00001?ooool2
o`0001[ooooo0_l000000ooooooo0000o`00000Aooooo`;o00001Oooool2o`0005kooooo000Loooo
o`03o`000?oooooooooo03Wooooo0_l00006ooooo`Go0000Boooool7o`0000Oooooo1_l00002oooo
o`;o000000?oooooo`000?l000008Oooool4o`00017ooooo0_l00005ooooo`;o00001?ooool2o`00
01?ooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`0booooo`;o00002?ooool2o`0000?o
oooo1Ol0000Pooooo`;o000000Goooooo`000?l0003o0000ooooo`03o`0000Gooooo0ol00005oooo
o`;o00004_ooool2o`000003ooooool0003o000000?o00000oooool9o`0000Gooooo0ol00005oooo
o`;o00005?ooool2o`0000;ooooo0ol00007ooooo`?o00000oooool2o`0000_ooooo0_l00002oooo
o`Co00004oooool3o`0004;ooooo000Looooo`03o`000?oooooooooo03;ooooo0_l00005ooooo`;o
000000?oooooo`000?l000001?ooool2o`0002;ooooo3?l00003ooooo`?o00001Oooool4o`0001Go
oooo3?l00009ooooo`;o00001Oooool2o`0001Cooooo0_l00002ooooo`?o00001oooool3o`0000?o
oooo0_l00003ooooo`;o00002Oooool5o`0001Cooooo0_l00012ooooo`007?ooool00ol0003ooooo
ooooo`0_ooooo`;o00002?ooool2o`000003ooooool0003o000000Cooooo0_l0000Oooooo`;o0000
0_ooool;o`0000Cooooo0_l000001?oooooo0000o`000?l00003ooooo`;o00005_ooool5o`0000Co
oooo0_l00009ooooo`Co00006_ooool2o`0000_ooooo0_l00002ooooo`Wo00002Oooool2o`0005_o
oooo000Looooo`03o`000?oooooooooo02oooooo0ol00008ooooo`;o00001_ooool2o`0001gooooo
1?l00005ooooo`;o00000oooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool3o`0001So
oooo0_l0000@ooooo`;o00001?ooool4o`0000Cooooo0_l0000Cooooo`?o00002_ooool<o`0000Co
oooo0_l0000Looooo`;o00007?ooool2o`0002Gooooo000Looooo`03o`000?oooooooooo02oooooo
0ol00008ooooo`;o00007_ooool2o`0000Gooooo1?l0000>ooooo`;o000000Goooooo`000?l0003o
0000ooooo`02o`0000Wooooo0_l0000=ooooo`;o00000_ooool2o`000004ooooool0003o0000o`00
00Kooooo1Ol00004ooooo`Co00000oooool2o`0001;ooooo1?l00003ooooo`;o00000_oooolGo`00
00?ooooo0_l00002ooooo`;o00004Oooool2o`0001cooooo0_l0000Uooooo`007?ooool00ol0003o
ooooooooo`0jooooo`;o00007_ooool2o`000003ooooool0003o000000Co00005?ooool2o`0000Oo
oooo0_l00003ooooo`;o00003Oooool2o`0000;ooooo0_l000001?oooooo0000o`000?l00006oooo
o`;o000000?oooooo`000?l000001_ooool2o`0000Cooooo0ol0000@ooooo`?o00001?ooool;o`00
0003ooooool0003o000000go000000?oooooo`000?l000001_l0001Fooooo`007?ooool00ol0003o
ooooooooo`0iooooo`?o00000_ooool2o`0001gooooo1_l0000:ooooo`co00001oooool2o`0000?o
oooo1?l0000;ooooo`;o00000oooool2o`0000?ooooo1Ol00008ooooo`;o00000_ooool4o`0000;o
oooo1?l0000HoooooaOo00000oooool2o`0000;ooooo0_l0000>ooooo`;o0000B?ooool001cooooo
00?o0000ooooooooool0>Oooool2o`0000?ooooo1?l0000Uoooooago00000oooool2o`00013ooooo
1?l000000ooooooo0000o`000003o`0000Gooooo0_l000001?oooooo0000o`000?l00003ooooo`?o
00000_ooool3o`0000;ooooo0_l00005ooooo`;o00003_oooolFo`000003ooooool0003o000000Co
oooo0_l00003ooooo`;o00002?ooool3o`0000?ooooo0_l0000Kooooo`;o00009_ooool001cooooo
00?o0000ooooooooool0>Oooool2o`0000Gooooo0_l0000Kooooo`;o00001oooool:o`0000?ooooo
0ol000000ooooooo0000o`00000<o`0001Cooooo1?l000000ooooooo0000o`000008ooooo`;o0000
0_ooool2o`0000?ooooo0ol00003ooooo`?o000000Coooooo`000?l0003o00001?ooool2o`0000;o
oooo0_l00009oooooa[o00001_ooool2o`000003ooooool0003o000000Oooooo0ol00004ooooo`;o
00006oooool2o`0002Kooooo000Looooo`03o`000?oooooooooo03Cooooo0_l00002ooooo`?o0000
8_ooool2o`0000Gooooo2_l000000ooooooo0000o`00000>o`000003ooooool0003o000000Co0000
1?ooool2o`0000kooooo0_l0000Dooooo`;o00001Oooool3o`0000;ooooo0_l00008ooooo`;o0000
2OoooolLo`0000Cooooo1_l00006ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0;ooo
ool2o`0000?ooooo0_l00002ooooo`;o00007oooool2o`0000Wooooo2_l000000ooooooo0000o`00
000Eo`0000Cooooo0_l000000ooooooo0000o`000009ooooo`Co000000?oooooo`000?l000004Ooo
ool2o`0000Kooooo0_l0000Booooo`Co000000?oooooo`000?l000006_l00003ooooo`;o000000?o
ooooo`000?l000000_l0000Yooooo`;o00009oooool001cooooo00?o0000ooooooooool0;oooool2
o`0000Sooooo0_l0000Mooooo`?o00002?ooool>o`0000;ooooo1Ol000000ooooooo0000o`00000;
o`0000Oooooo0_l00009ooooo`;o00000oooool2o`0000;ooooo0_l0000>ooooo`Go00003oooool2
o`0000Gooooo1?l000000ooooooo0000o`00000Jo`0000?ooooo0_l00003ooooo`;o0000:Oooool2
o`0002Oooooo000Looooo`;o0000<?ooool2o`0000Sooooo0_l0000Kooooo`Go00001OoooolFo`00
0003ooooool0003o000000_o000000?oooooo`000?l000005?ooool2o`0000Cooooo0_l0000:oooo
o`;o000000?oooooo`000?l000001?l0000?ooooo`;o00001Oooool2o`0000;ooooo7Ol00003oooo
o`;o00002?ooool4o`00027ooooo0_l0000Xooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o
00009Oooool4o`0000Kooooo8_l00003ooooo`Ko00004?ooool2o`0000[ooooo0_l000001?oooooo
0000o`000?ooool2o`000003ooooool0003o000000Oooooo0_l000000ooooooo0000o`000008oooo
o`;o00001?ooool3o`000003ooooool0003o000000Oo00000_oooolBo`0000;ooooo0ol00003oooo
o`;o00000oooool4o`00027ooooo0_l0000Xooooo`007?ooool00ol0003oooooooooo`0dooooo`?o
00007oooool3o`0000Oooooo1_l00002oooooako000000?oooooo`000?l000000_l00005ooooo`;o
00002Oooool2o`0000[ooooo0_l000000ooooooo0000o`000009ooooo`;o00000_ooool2o`000003
ooooool0003o000000Sooooo0_l00005ooooo`;o00000_oooolLo`0000;ooooo0ol00003ooooo`;o
00001Oooool6o`0001gooooo0_l0000Xooooo`007?ooool00ol0003oooooooooo`0dooooo`?o0000
7oooool2o`0000Kooooo1Ol00002ooooo`;o000000?oooooo`000?l000007Ol00008ooooo`?o0000
1?ooool2o`0001gooooo0_l00002ooooo`;o000000?oooooo`000?l000003oooool2o`0000?ooooo
3Ol000000ooooooo0000o`000008o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o0000
1oooool4o`0001gooooo0_l0000Xooooo`007?ooool00ol0003oooooooooo`1=ooooo`Co000000Co
ooooo`000?l0003o00002Oooool4o`0000;ooooo5Ol00003ooooo`Ko000000?oooooo`000?l00000
0ol00007ooooo`;o00001Oooool3o`0001cooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o
00003Oooool4o`0000;ooooo6Ol00003ooooo`?o000000?oooooo`000?l000000_ooool2o`0000Wo
oooo0_l00017ooooo`007?ooool00ol0003oooooooooo`1<ooooo`Go000000Coooooo`000?l0003o
00002?ooool4o`0000?ooooo8Ol000001?oooooo0000o`000?l00007ooooo`;o00001Oooool2o`00
00?ooooo0_l0000Cooooo`;o00000_ooool6o`00013ooooo0ol00003ooooo`So000000?oooooo`00
0?l000003Ol00004ooooo`?o0000;Oooool2o`0002[ooooo000Looooo`03o`000?oooooooooo03Oo
oooo0_l0000Cooooo`;o000000Coooooo`000?l0003ooooo0_l00008ooooo`Co00001?oooolUo`00
00Oooooo0_l00005ooooo`;o00000oooool2o`0001?ooooo0_l00003ooooo`;o000000?oooooo`00
0?l000001oooool2o`0000Sooooo0_l00003ooooo`So000000?oooooo`000?l000003Ol00003oooo
o`Co00002?ooool2o`0002?ooooo0_l0000Zooooo`007?ooool00ol0003oooooooooo`0gooooo`;o
00006?ooool2o`0000Wooooo0ol00005oooooaoo000000?oooooo`000?l000001Ol0000;ooooo`Co
00005?ooool2o`0000Cooooo1?l00004ooooo`?o00000oooool2o`0001Gooooo3Ol000000ooooooo
0000o`000003ooooo`Co00001_ooool4o`0004oooooo000Looooo`03o`000?oooooooooo02kooooo
0_l0000Kooooo`;o00001?ooool2o`0000Wooooo1Ol00003oooooaco000000?oooooo`000?l00000
2?l0000;ooooo`Co00005?ooool2o`000004ooooool0003o0000ooooo`Oo000000Coooooo`000?l0
003o00002Oooool2o`0000Oooooo0_l00005ooooo`ko00000_ooool2o`000003ooooool0003o0000
00;o00000_ooool2o`0000?ooooo1Ol0000Qooooo`;o0000:oooool001cooooo00?o0000oooooooo
ool0;_ooool2o`0001_ooooo0_l0000?ooooo`;o000000Goooooo`000?l0003o0000ooooo`0Wo`00
00Oooooo0_l00004ooooo`;o00000_ooool2o`0001Cooooo0_l00002ooooo`Ko00003Oooool2o`00
00;ooooo0_l00003ooooo`;o00001Oooool=o`0000?ooooo2?l000000ooooooo0000o`000006oooo
o`;o00008?ooool3o`0002_ooooo000Looooo`03o`000?oooooooooo02kooooo0_l00008ooooo`;o
00003oooool2o`0000Gooooo0_l00009ooooo`?o000000Goooooo`000?l0003o0000ooooo`0Vo`00
00?ooooo0_l00003ooooo`;o00001?ooool2o`0000;ooooo0_l0000Iooooo`;o000000?oooooo`00
0?l000004Oooool2o`0000Wooooo1?l000000ooooooo0000o`000009o`0000;ooooo1?l000000ooo
oooo0000o`000002o`0000;ooooo0_l000000ooooooo0000o`000002o`00023ooooo0_l0000/oooo
o`007?ooool00ol0003oooooooooo`0booooo`?o00000oooool2o`0000oooooo0_l00004ooooo`?o
00002Oooool3o`0000Gooooo9_l000000ooooooo0000o`000002o`0002Kooooo1?l000000ooooooo
0000o`000002o`0001[ooooo1?l000001?oooooo0000o`000?ooool8o`0000Cooooo1ol00002oooo
o`;o000000?oooooo`000?l000000_ooool2o`0000_ooooo0ol0000nooooo`007?ooool00ol0003o
ooooooooo`0]ooooo`;o00000oooool3o`0000?ooooo0_l0000Eooooo`;o00002_ooool2o`0000Oo
oooo9Ol000000ooooooo0000o`000009ooooo`;o00005?ooool2o`0000Oooooo2Ol0000@ooooo`;o
00002_ooool2o`0000Cooooo1Ol00008ooooo`Co00001_ooool2o`0000?ooooo0_l00006ooooo`;o
00000oooool3o`0000oooooo0_l0000]ooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o0000
1?ooool2o`0000Cooooo0_l0000Cooooo`;o00002oooool4o`0000Cooooo0_l000000ooooooo0000
o`00000Qo`000003ooooool0003o000000Wooooo0_l00009ooooo`;o00002Oooool2o`0000;ooooo
1?l000000ooooooo0000o`000005o`0001;ooooo0_l0000Gooooo`Co00000_ooool4o`0000Kooooo
0_l00002ooooo`;o00001oooool2o`0000;ooooo0_l0000Aooooo`;o0000;Oooool001cooooo00?o
0000ooooooooool0;?ooool2o`0000_ooooo0_l0000Cooooo`;o00003?ooool5o`0000;ooooo9_l0
00000ooooooo0000o`000002o`0000;ooooo0_l00006ooooo`;o00001?ooool:o`0000Oooooo1?l0
00000ooooooo0000o`000002ooooo`?o00005oooool2o`0001;ooooo1?l00007ooooo`;o00001ooo
ool2o`0000Wooooo1?l00003ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0;?ooool2
o`0000_ooooo0_l0000Pooooo`Ko00000ooooolTo`000004ooooool0003o0000ooooo`;o000000Co
ooooo`000?l0003o00001_ooool2o`0000;ooooo4?l0000Vooooo`;o00001?ooool2o`0000?ooooo
0_l0000:ooooo`;o00001?ooool4o`00017ooooo0ol00002ooooo`Go0000>oooool001cooooo0_l0
000^ooooo`;o00000_ooool2o`0000;ooooo0_l00002ooooo`;o00004oooool2o`0000[ooooo1_l0
0005ooooo`;o000000?oooooo`000?l000007_l000000ooooooo0000o`000004ooooo`;o00001Ooo
ool2o`0000;ooooo4_l0000<ooooo`;o00002Oooool2o`0000;ooooo0_l0000:ooooo`;o00000ooo
ool2o`0000?ooooo0_l00004ooooo`;o00001?ooool2o`0000Cooooo0_l00006ooooo`;o00001_oo
ool2o`0000?ooooo0_l00003ooooo`Co0000??ooool001cooooo00?o0000ooooooooool0;Oooool2
o`0000;ooooo0_l00002ooooo`;o00000_ooool4o`00017ooooo0ol00009ooooo`Ko000000?ooooo
o`000?l000000_oooolSo`000004ooooool0003o0000o`0000Gooooo0_l00003ooooo`Ko00000ooo
ool=o`0000cooooo0_l00009ooooo`;o00000_ooool2o`0000Oooooo1Ol0000>ooooo`;o00001_oo
ool2o`0000Cooooo0_l00004ooooo`;o00001_ooool2o`0000[ooooo0_l0000looooo`007?ooool0
0ol0003oooooooooo`0dooooo`;o00001?ooool3o`0001;ooooo0_l0000;ooooo`Co000000?ooooo
o`000?l000000_oooolMo`0000;ooooo2?l00005ooooo`;o00001?ooool5o`0000?ooooo3_l0000<
ooooo`;o00002?ooool4o`000003ooooool0003o000000Kooooo1Ol000000ooooooo0000o`00000C
ooooo`;o00001?ooool2o`0001Oooooo0_l0000;ooooo`;o0000<?ooool001cooooo00?o0000oooo
ooooool0=?ooool2o`0000Gooooo0_l0000Oooooo`Co00001_ooool2o`0000;ooooo6?l00002oooo
o`Oo00002_ooool4o`0000Kooooo3ol000000ooooooo0000o`000006ooooo`Co00002_ooool2o`00
0003ooooool0003o000000Wooooo1Ol00005ooooo`?o00002_ooool5o`0000Gooooo0_l0000Doooo
o`;o00002oooool2o`00033ooooo000Looooo`03o`000?oooooooooo03_ooooo0_l0000Qooooo`Co
00001?ooool2o`0000?ooooo3ol000000ooooooo0000o`00000=o`0000[ooooo1_l00007oooooa3o
00001_ooool2o`0000oooooo0_l0000;ooooo`;o00001Oooool4o`000004ooooool0003o0000oooo
o`;o00001?ooool5o`0000Gooooo0_l00009ooooo`;o00000_ooool6o`00043ooooo000Looooo`03
o`000?oooooooooo03_ooooo0_l0000:ooooo`;o00001_ooool2o`0000gooooo1?l00006ooooo`;o
00000_ooool?o`000003ooooool0003o000000So00000_ooool3o`0000Sooooo1?l000000ooooooo
0000o`000007ooooo`oo00001oooool2o`0002;ooooo1?l00002ooooo`;o000000?oooooo`000?l0
00000_ooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000008ooooo`;o
000000?oooooo`000?l000000_ooool6o`0000;ooooo0_l0000looooo`007?ooool00ol0003ooooo
ooooo`0/ooooo`;o00003?ooool3o`0000[ooooo0_l00006ooooo`;o00003Oooool5o`000003oooo
ool0003o000000;ooooo7Ol00002ooooo`Co00001oooool3o`0000kooooo3?l00007ooooo`?o0000
8_ooool2o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool2o`000004oooo
ool0003o0000ooooo`;o00002?ooool2o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o
000000?oooooo`000?l00000??ooool001cooooo00?o0000ooooooooool0;?ooool2o`0000cooooo
0_l0000Cooooo`;o00003oooool3o`000004ooooool0003o0000o`0000;ooooo1?l00002ooooo`So
000000?oooooo`000?l000002ol00002ooooo`So000000?oooooo`000?l000000_l00009ooooo`;o
00001?ooool>o`0000Gooooo0_l0000;ooooo`;o00007?ooool2o`000003ooooool0003o000000;o
oooo0_l000001?oooooo0000o`000?l00007ooooo`;o00001Oooool2o`0000[ooooo0_l0000ooooo
o`007?ooool00ol0003oooooooooo`0/ooooo`;o00001Oooool2o`0000Oooooo0_l0000Aooooo`;o
00004?ooool6o`0000Cooooo0ol00003ooooo`[o000000?oooooo`000?l000000ol000000ooooooo
0000o`000005o`0000;ooooo2?l0000:ooooo`;o00000oooool?o`0000?ooooo0_l0000=ooooo`;o
00002oooool3o`0000oooooo1?l000000ooooooo0000o`000004o`0000Sooooo0ol0001Aooooo`00
7?ooool00ol0003oooooooooo`0cooooo`;o00001oooool2o`0000cooooo0_l00003ooooo`;o0000
4Oooool4o`0000;ooooo0_l000000ooooooo0000o`000002o`0000;ooooo5_l00006ooooo`Go0000
3?ooool2o`0000;ooooo0_l00002ooooo`Wo00001?ooool4o`0000?ooooo0_l0000Dooooo`?o0000
3?ooool2o`000003ooooool0003o000000Oo00001Oooool2o`0000Cooooo0_l0001Aooooo`007?oo
ool00ol0003oooooooooo`0looooo`?o00002_ooool3o`0000?ooooo0_l0000Booooo`Co000000?o
ooooo`000?l000000oooool3o`000003ooooool0003o000000Go00000_ooool3o`0000;ooooo1Ol0
0009ooooo`?o00001oooool2o`0000Gooooo0_l00005ooooo`;o000000?oooooo`000?l000000_l0
00000ooooooo0000o`000003o`000003ooooool0003o000000;o000000?oooooo`000?l000000_l0
000Mooooo`;o00001?ooool2o`0000?ooooo1ol00005ooooo`?o00008Oooool2o`0003?ooooo000L
ooooo`03o`000?oooooooooo03gooooo0_l0000:ooooo`;o00006?ooool4o`0000Oooooo0_l00000
0ooooooo0000o`000002o`000003ooooool0003o000000Oo00002_ooool3o`0000Gooooo0_l00003
ooooo`Co00000oooool2o`0000Kooooo1ol000000ooooooo0000o`000004o`0000Gooooo0_l0000:
ooooo`;o00004Oooool4o`0000Wooooo1ol00006ooooo`;o00008?ooool3o`0003?ooooo000Loooo
o`03o`000?oooooooooo06Cooooo1Ol0000:ooooo`;o00000_ooool4o`0000;ooooo0_l00009oooo
o`Co00001Oooool9o`0000?ooooo0_l00004ooooo`;o00000_ooool3o`0000?ooooo0_l00002oooo
o`;o00004?ooool5o`0000_ooooo0_l00002ooooo`Co00001_ooool2o`0000?ooooo0_l0000[oooo
o`;o0000=?ooool001cooooo00?o0000ooooooooool0IOooool7o`0000?ooooo0_l00008ooooo`;o
00001Oooool2o`0000Cooooo1Ol00008ooooo`Co00001_ooool3o`0000?ooooo0_l00009ooooo`;o
00004oooool5o`0000_ooooo0_l0000<ooooo`;o00001?ooool2o`0000;ooooo0_l00004ooooo`;o
0000E_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^oc8b
<_l0003o410@olc<c006ooooo`03o`000?oooooooooo03Gooooo0_l0000Jooooo`;o00000oooool2
o`0000kooooo1_l00003ooooo`?o00003?ooool4o`000003ooooool0003o000000Co00001_ooool2
o`000003ooooool0003o000000Wooooo1Ol000000ooooooo0000o`000003ooooo`;o00001?ooool2
o`0000;ooooo0_l0000Booooo`;o00002oooool3o`0000;ooooo0_l00009ooooo`;o00000_ooool2
o`0000;ooooo0_l00004ooooo`;o0000E_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Ooo
ool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo03Gooooo
0_l0000Jooooo`;o00000oooool2o`00017ooooo1?l00002ooooo`So00001oooool2o`0000;ooooo
1?l000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Gooooo
0_l000000ooooooo0000o`000003ooooo`;o00002?ooool2o`0000?ooooo0_l0000=ooooo`;o0000
3?ooool2o`0000;ooooo1_l00005ooooo`;o000000?oooooo`000?l00000HOooool00003ooooool@
413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0=Oooool2o`000003ooooool0003o000002oooooo1_l00003ooooo`Go0000
0_ooool3o`000003ooooool0003o000000;o000000?oooooo`000?l000000_l000000ooooooo0000
o`000008ooooo`?o00001Oooool2o`0000Cooooo0_l00002ooooo`;o00001?ooool4o`0000[ooooo
0_l0000=ooooo`;o00004_ooool4o`0000?ooooo0_l00003ooooo`;o00008?ooool2o`0000Oooooo
0_l0000fooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?nH
V9SooooooiRHV?lQ8B401_ooool3o`0003Gooooo0_l000000ooooooo0000o`00000=ooooo`;o0000
8oooool4o`000004ooooool0003o0000o`0000;ooooo0_l000000ooooooo0000o`000006o`00013o
oooo0ol0000:ooooo`?o00001?ooool2o`0000;ooooo1?l000000ooooooo0000o`000007ooooo`Co
00007Oooool2o`0000Oooooo0_l0000Tooooo`?o00001oooool2o`0003Kooooo00000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03
o`000?oooooooooo03Sooooo0_l0000=ooooo`;o00002?ooool3o`0000Oooooo0_l0000Aooooo`;o
000000?oooooo`000?l000001Ol00002ooooo`?o00006Oooool4o`0000Cooooo0ol00004ooooo`;o
00001?ooool5o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0000Oooooo0_l0000Doooo
o`;o000000?oooooo`000?l00000:_ooool2o`00043ooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`17ooooo`;o
00002?ooool4o`0000?ooooo0_l000000ooooooo0000o`00000Gooooo`;o00003_ooool2o`0000So
oooo0_l00006ooooo`Co00001?ooool3o`0000Wooooo1_l00003ooooo`;o000000?oooooo`000?l0
00000ol00007ooooo`;o00005oooool2o`0006cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMg
M`_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`1Cooooo`;o00000oooool2o`00
02[ooooo1?l00006ooooo`;o00003oooool2o`0000Wooooo1?l00006ooooo`?o000000?oooooo`00
0?l000000_l00006ooooo`;o0000C?ooool2o`0003Oooooo00001_ooooook^k^oc8b<_l0003o<S8b
onk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`0aooooo`;o00007ooo
ool3o`0000;ooooo0ol0000:ooooo`;o00006_ooool2o`0000;ooooo1?l00006ooooo`;o00003_oo
ool2o`000003ooooool0003o0000013ooooo1_l000000ooooooo0000o`000003o`0000?ooooo0_l0
0004ooooo`;o0000A_ooool2o`0003Oooooo000Looooo`03o`000?oooooooooo037ooooo0_l0000J
ooooo`;o00000oooool3o`0000;ooooo0ol0000:ooooo`?o00005Oooool2o`0000;ooooo0_l0000<
ooooo`;o00003_ooool2o`000003ooooool0003o000000oooooo1ol000000ooooooo0000o`000003
o`0000Gooooo0_l00002ooooo`;o00001?ooool2o`0003gooooo0_l000000ooooooo0000o`00000g
ooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00002Oooool2o`0000[ooooo0ol0000=oooo
o`;o00001_ooool2o`0000Kooooo0_l0000Hooooo`;o00004?ooool7o`0000?ooooo0ol00007oooo
o`?o00001oooool2o`0002?ooooo0_l00004ooooo`?o00000oooool2o`0000cooooo0_l0000joooo
o`007?ooool00ol0003oooooooooo`0gooooo`;o000000Coooooo`000?l0003ooooo0_l0000Soooo
o`;o00003?ooool2o`0000;ooooo0ol00002ooooo`Co00000_ooool2o`000003ooooool0003o0000
00;o00000oooool2o`0001?ooooo0_l00005ooooo`;o00002Oooool=o`0000Sooooo0_l0000/oooo
o`?o000000?oooooo`000?l000000ol00003ooooo`;o0000B?ooool001cooooo00?o0000oooooooo
ool0<Oooool2o`0000Cooooo0_l000000ooooooo0000o`000003o`0002?ooooo0_l0000:ooooo`Co
00000oooool2o`0000;ooooo1?l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l00002oooo
o`;o00006_ooool3o`0000Sooooo2ol00002ooooo`;o00001_ooool2o`0002_ooooo1ol000001Ooo
oooo0000o`000?l0003ooooo00;o0000BOooool001cooooo00?o0000ooooooooool0<Oooool2o`00
00Sooooo0_l0000aooooo`Co00003?ooool5o`0000;ooooo0_l0000Oooooo`;o00001OoooolFo`00
0003ooooool0003o000000?o00001Oooool2o`0001gooooo0_l00003ooooo`;o00000_ooool2o`00
0003ooooool0003o000000;o000000?oooooo`000?l00000BOooool001cooooo00?o0000oooooooo
ool0Doooool2o`0000gooooo0_l00002ooooo`;o00005_ooool2o`000003ooooool0003o000002[o
oooo5_l000001?oooooo0000o`000?ooool2o`0000Gooooo0_l0000Mooooo`?o00001_ooool2o`00
0004ooooool0003o0000o`0004gooooo000Looooo`03o`000?oooooooooo03cooooo0ol0000Doooo
o`;o00000oooool2o`0000Sooooo0_l00002ooooo`;o00000_ooool4o`0000;ooooo1?l000001?oo
oooo0000o`000?ooool2o`0000Cooooo0_l0000^oooooa?o000000?oooooo`000?l000000ol00007
ooooo`?o00007Oooool2o`0000Kooooo0_l000000ooooooo0000o`000004o`0004[ooooo000Loooo
o`03o`000?oooooooooo03Wooooo0_l000001?oooooo0000o`000?l0000<ooooo`;o00002oooool4
o`0000Oooooo0_l00005ooooo`Co00000_ooool4o`000004ooooool0003o0000ooooo`;o0000:Ooo
ool2o`0000;ooooo0_l00005ooooo`;o00000ooooolDo`0000Oooooo0ol0000Xooooo`Ko00003?oo
ool2o`0003cooooo000Looooo`03o`000?oooooooooo03Wooooo0_l000000ooooooo0000o`000005
ooooo`;o00001_ooool4o`0000_ooooo0_l000000ooooooo0000o`000004ooooo`;o00001_ooool3
o`0000?ooooo1?l00003ooooo`;o0000:Oooool2o`0000;ooooo0_l00005ooooo`?o000000?ooooo
o`000?l000001_l00002ooooo`[o0000<?ooool3o`0000;ooooo1Ol0000:ooooo`?o0000??ooool0
01cooooo00?o0000ooooooooool0@Oooool4o`0000Sooooo0_l000000ooooooo0000o`00000;oooo
o`;o00002_ooool5o`0000Gooooo0_l00003ooooo`?o0000<_ooool4o`000003ooooool0003o0000
01Co00000_ooool2o`0002[ooooo0ol00005ooooo`;o00002_ooool2o`0003gooooo000Looooo`03
o`000?oooooooooo047ooooo0_l0000<ooooo`Co00005_ooool2o`0000;ooooo0_l00009ooooo`?o
00004_ooool8o`0001;ooooo0_l00004ooooo`Co000000?oooooo`000?l000004Ol000000ooooooo
0000o`000002ooooo`;o0000:Oooool4o`0000Cooooo0_l0001:ooooo`007?ooool2o`00047ooooo
0_l00004ooooo`;o00001?ooool2o`000003ooooool0003o000000;o00006_ooool3o`000003oooo
ool0003o000001Sooooo3?l00002ooooo`;o00003?ooool2o`0000Gooooo5ol000000ooooooo0000
o`000002ooooo`Co00006_ooool2o`0000_ooooo1Ol00003ooooo`;o00002Oooool2o`0003oooooo
000Looooo`03o`000?oooooooooo043ooooo0_l00004ooooo`;o00001?ooool2o`00023ooooo0_l0
00000ooooooo0000o`00000Gooooo`?o00001?ooool6o`0000;ooooo0_l000000ooooooo0000o`00
000>ooooo`Co000000?oooooo`000?l000006ol0000Gooooo`;o000000?oooooo`000?l000003?oo
ool4o`0000kooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`14ooooo`Go00007oooool2
o`0001oooooo0ol000000ooooooo0000o`000003ooooo`;o00001_ooool4o`0000kooooo6ol00000
1?oooooo0000o`000?l0000Jooooo`;o0000H_ooool001cooooo00?o0000ooooooooool0A?ooool5
o`0001oooooo1?l0000Looooo`?o00000_ooool2o`0000_ooooo1Ol0000:ooooo`Co000000?ooooo
o`000?l000002ol000000ooooooo0000o`000002o`000003ooooool0003o000000?o00000oooool2
o`0002[ooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`12ooooo`;o00000oooool2o`00
00_ooooo0_l0000Dooooo`;o00007?ooool4o`00017ooooo0_l000000ooooooo0000o`000005oooo
ob;o00001_ooool2o`0000cooooo1Ol00006ooooo`;o00002_ooool3o`0005;ooooo000Looooo`03
o`000?oooooooooo04;ooooo0_l00003ooooo`;o00000oooool2o`0000Kooooo0_l0000Eooooo`?o
00007?ooool2o`0001Cooooo0_l00005ooooo`;o00000_oooolNo`0000Kooooo0_l0000<ooooo`Go
00001_ooool2o`0000Cooooo0_l00004ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0
Aoooool2o`0000?ooooo0_l0000Iooooo`;o00000_ooool3o`0001cooooo0_l0000Dooooo`;o0000
1Oooool3o`0000;ooooo6ol00002ooooo`;o00000_ooool2o`0001Wooooo0_l00003ooooo`?o0000
0_ooool4o`0000cooooo0ol00014ooooo`007?ooool00ol0003oooooooooo`17ooooo`;o00007_oo
ool2o`0002;ooooo0_l00009ooooo`;o000000Coooooo`000?l0003o00001?ooool3o`0000Cooooo
0ol00003oooooako00000_ooool2o`0001Wooooo0_l00003ooooo`;o000000?oooooo`000?l00000
0_l0000>ooooo`?o0000A?ooool001cooooo00?o0000ooooooooool0@Oooool2o`000003ooooool0
003o000001oooooo0_l0000Tooooo`;o00002Oooool2o`000004ooooool0003o0000o`0000Cooooo
0ol00005ooooo`;o00000ooooolQo`0000Cooooo0_l0000Booooo`;o00001Oooool6o`0000oooooo
0_l00015ooooo`007?ooool00ol0003oooooooooo`11ooooo`;o000000?oooooo`000?l000003ooo
ool2o`0000;ooooo0_l0000:ooooo`Co000000?oooooo`000?l00000=Oooool3o`0000Cooooo0_l0
00000ooooooo0000o`00000>o`000003ooooool0003o0000013o00001?ooool2o`0001;ooooo0_l0
0005ooooo`Co00004Oooool2o`0004Gooooo000Looooo`03o`000?oooooooooo05Gooooo0_l00002
ooooo`;o00003?ooool5o`0003Kooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o
000001Wo00002oooool2o`0001Oooooo0ol0001Iooooo`007?ooool00ol0003oooooooooo`18oooo
o`;o00000_ooool2o`0000Oooooo0_l000000ooooooo0000o`00000>ooooo`?o0000=oooool2o`00
00;ooooo0_l00004oooooago00002Oooool4o`0001?ooooo0_l00002ooooo`;o0000F_ooool001co
oooo00?o0000ooooooooool0B?ooool2o`000004ooooool0003o0000o`0000[ooooo0_l00018oooo
o`;o00001Oooool2o`000003ooooool0003o000001go00001_ooool3o`0000Wooooo0_l00009oooo
o`Co00001_ooool2o`0005Gooooo000Looooo`03o`000?oooooooooo04Gooooo0_l00004ooooo`;o
00004oooool2o`0000Kooooo0_l0000Yooooo`?o00002?ooool2o`000003ooooool0003o000000Ko
oooo0_l00004oooooaWo000000Coooooo`000?l0003o00001Oooool2o`0000[ooooo0_l00006oooo
o`So00000_ooool2o`000003ooooool0003o000005Gooooo000Looooo`03o`000?oooooooooo04Go
oooo0_l00004ooooo`;o00003?ooool2o`0000?ooooo1?l00006ooooo`Co00009Oooool5o`0000So
oooo0_l000000ooooooo0000o`000002o`0000[ooooo5ol00004ooooo`;o00006Oooool8o`0000;o
oooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`19ooooo`Go00002oooool2o`0000?ooooo
0_l00002ooooo`;o00001?ooool4o`0002Gooooo0ol0000?ooooo`;o00002_ooool3o`0000;ooooo
4Ol0000Cooooo`;o00002_ooool4o`000003ooooool0003o000000;o0000G?ooool001cooooo0_l0
0018ooooo`Oo00005?ooool2o`0000Wooooo0_l0000Pooooo`;o000000?oooooo`000?l000006ooo
ool2o`0000?ooooo0_l000000ooooooo0000o`000008o`0000;ooooo0_l00005ooooo`;o00003?oo
ool2o`0000[ooooo1?l000000ooooooo0000o`000002o`0000_ooooo0ol0001>ooooo`007?ooool0
0ol0003oooooooooo`17ooooo`Go00003oooool2o`0000Oooooo0_l00007ooooo`Co00007_ooool2
o`0000_ooooo1Ol00003ooooo`?o00001Oooool2o`0000Wooooo3_l00005ooooo`;o00001oooool2
o`0000kooooo1?l000001?oooooo0000o`000?l0000=ooooo`?o0000C_ooool001cooooo00?o0000
ooooooooool0B?ooool2o`0000gooooo0_l00002ooooo`;o00001oooool3o`0000Gooooo0_l00000
0ooooooo0000o`00000[ooooo`Go00000oooool3o`0000Gooooo0_l00006ooooo`So000000Cooooo
o`000?l0003ooooo1?l00005ooooo`;o00002?ooool2o`0000cooooo1?l00002ooooo`?o00003_oo
ool2o`0004oooooo000Looooo`03o`000?oooooooooo05;ooooo0_l00003ooooo`?o00002?ooool2
o`000003ooooool0003o000000Gooooo0_l0000Wooooo`;o000000?oooooo`000?l000002_ooool2
o`0000_ooooo1_l00002ooooo`Ko000000Coooooo`000?l0003o00001_ooool2o`000003ooooool0
003o000001?ooooo0_l00004ooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0COooool2
o`0000?ooooo0_l00003ooooo`?o00002?ooool2o`0000;ooooo0_l0000]ooooo`;o000000?ooooo
o`000?l000000_l000000ooooooo0000o`000005ooooo`Co00002Oooool4o`000003ooooool0003o
000000So00003?ooool2o`0001;ooooo0ol000000ooooooo0000o`00000>ooooo`;o0000Doooool0
01cooooo00?o0000ooooooooool0COooool2o`0000Cooooo0_l00002ooooo`;o00001_ooool2o`00
00?ooooo1_l0000`ooooo`;o000000?oooooo`000?l000001oooool3o`0000gooooo3Ol000000ooo
oooo0000o`00000Hooooo`Co00000_ooool2o`0000kooooo0_l0001Cooooo`007?ooool00ol0003o
ooooooooo`1Aooooo`Oo00001oooool2o`0000?ooooo0ol000001?oooooo0000o`000?l0000;oooo
o`;o00008_ooool2o`0000Sooooo0_l000000ooooooo0000o`00000=ooooo`;o00001?ooool2o`00
00;ooooo1ol0000=ooooo`;o00001oooool3o`0006Wooooo000Looooo`03o`000?oooooooooo057o
oooo0_l00002ooooo`?o00000_ooool2o`0000Gooooo0ol000000ooooooo0000o`000002ooooo`;o
00002oooool4o`0001gooooo0_l000001?oooooo0000o`000?ooool2o`0000Gooooo0_l000000ooo
oooo0000o`000002o`0000_ooooo0_l00004ooooo`;o00000oooool6o`0000Gooooo0_l000000ooo
oooo0000o`000003ooooo`;o00001?ooool2o`000003ooooool0003o000000?ooooo0ol0000;oooo
o`;o0000Eoooool001cooooo00?o0000ooooooooool0Coooool4o`0000Oooooo0_l00004ooooo`Co
00001Oooool2o`0000gooooo0_l0000Looooo`Go00000_ooool4o`0000Sooooo0ol00008ooooo`;o
000000?oooooo`000?l000002?ooool5o`0000Kooooo0_l000000ooooooo0000o`000006ooooo`Go
00001_ooool3o`0000_ooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`1?ooooo`?o0000
1oooool2o`0000Gooooo0ol00006ooooo`Go00001oooool2o`0000?ooooo0_l0000Jooooo`Go0000
1?ooool3o`0000Oooooo0ol00008ooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo
0_l00007ooooo`;o00001Oooool2o`0000Cooooo0ol00004ooooo`;o00003_ooool3o`0005Sooooo
000Looooo`03o`000?oooooooooo053ooooo0_l00006ooooo`?o00001_ooool2o`0000Kooooo1_l0
0006ooooo`;o00000oooool2o`0002Cooooo0_l00007ooooo`?o00003_ooool7o`0000Sooooo0ol0
0002ooooo`Go00001?ooool2o`0000Gooooo0_l0000>ooooo`?o0000F?ooool001cooooo00?o0000
ooooooooool0D?ooool2o`0000Kooooo0_l000000ooooooo0000o`000004ooooo`;o000000?ooooo
o`000?l000001oooool3o`0000;ooooo0ol0000Wooooo`;o00007?ooool3o`000004ooooool0003o
0000o`0000Gooooo0_l000000ooooooo0000o`000003ooooo`?o000000Coooooo`000?l0003ooooo
1?l000001?oooooo0000o`000?ooool2o`0006[ooooo000Looooo`03o`000?oooooooooo053ooooo
0_l00009ooooo`;o00001oooool3o`0000Oooooo2?l0000Kooooo`;o00002Oooool2o`0000Kooooo
0_l0000?ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o000000?oooooo`000?l00000
0oooool2o`0000?ooooo0_l00005ooooo`;o000000?oooooo`000?l000000_l000001?oooooo0000
o`000?ooool2o`0000[ooooo0_l0001Nooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o0000
1Oooool3o`000003ooooool0003o000000;ooooo0_l0000Kooooo`;o00004Oooool2o`0000[ooooo
0_l00003ooooo`;o000000?oooooo`000?l000000_l00005ooooo`;o00001?ooool2o`0000;ooooo
0_l00005ooooo`;o00000oooool2o`00013ooooo0_l0001Nooooo`007?ooool00ol0003ooooooooo
o`1Uooooo`;o00001Oooool3o`000003ooooool0003o000000?o00002oooool2o`00013ooooo0ol0
000?ooooo`;o00002_ooool4o`0000gooooo0_l00002ooooo`Co00002Oooool3o`0000oooooo1?l0
001Qooooo`007?ooool00ol0003oooooooooo`1Eooooo`;o00000oooool2o`000003ooooool0003o
0000017ooooo2Ol00007ooooo`;o00004?ooool3o`0000Gooooo1?l000000ooooooo0000o`000008
ooooo`;o00001oooool2o`0000gooooo0_l00002ooooo`Co00001Oooool2o`0000;ooooo0ol0000>
ooooo`Go0000HOooool001cooooo0_l0001Fooooo`;o00000oooool2o`000003ooooool0003o0000
00;o00003Oooool4o`0000;ooooo1Ol00004ooooo`;o00000_ooool2o`0001Gooooo2_l00006oooo
o`Go000000?oooooo`000?l000001_ooool2o`0000[ooooo0_l00003ooooo`;o000000Goooooo`00
0?l0003o0000ooooo`02o`00017ooooo1?l0001Tooooo`007?ooool00ol0003oooooooooo`1Goooo
o`Co00001?ooool2o`0000Wooooo0_l00002ooooo`?o00001Oooool5o`0000;ooooo0ol000000ooo
oooo0000o`00000Eooooo`;o000000?oooooo`000?l000001Ol00003ooooo`;o000000Coooooo`00
0?l0003ooooo0_l000000ooooooo0000o`000006ooooo`?o00002Oooool2o`0000Kooooo0ol0000A
ooooo`;o000000?oooooo`000?l00000I_ooool001cooooo00?o0000ooooooooool0Eoooool4o`00
00Cooooo0_l00009ooooo`;o00001Oooool2o`0000Cooooo1?l00003ooooo`;o000000?oooooo`00
0?l000005Oooool2o`0000;ooooo0_l00002ooooo`;o00000oooool2o`00013ooooo0_l000001?oo
oooo0000o`000?l0000Pooooo`?o0000JOooool001cooooo00?o0000ooooooooool0Eoooool5o`00
00?ooooo0_l00009ooooo`;o00001Oooool2o`0000Cooooo0ol00002ooooo`;o00001Oooool2o`00
017ooooo1?l00002ooooo`Ko00002_ooool2o`0000cooooo0ol000000ooooooo0000o`00000Foooo
o`;o00001Oooool2o`0006[ooooo000Looooo`03o`000?oooooooooo05Sooooo1?l0000>ooooo`Co
00001_ooool3o`000003ooooool0003o000000;ooooo0_l00005ooooo`;o00004Oooool2o`0000Go
oooo1ol00002ooooo`;o00001?ooool3o`0000oooooo0_l000000ooooooo0000o`000002o`0000ko
oooo0_l000000ooooooo0000o`00001aooooo`007?ooool00ol0003oooooooooo`1[ooooo`?o0000
0_ooool2o`0000;ooooo0ol00005ooooo`Go00007Oooool2o`000004ooooool0003o0000o`0000;o
oooo0_l00005ooooo`;o00004_ooool4o`000003ooooool0003o000000?o000000?oooooo`000?l0
00001?ooool3o`000003ooooool0003o0000077ooooo000Looooo`03o`000?oooooooooo06;ooooo
0_l00007ooooo`Co000000?oooooo`000?l000002_ooool5o`0001Kooooo0_l00005ooooo`;o0000
00?oooooo`000?l000004_ooool2o`0000oooooo2?l00004ooooo`;o0000MOooool001cooooo00?o
0000ooooooooool0H?ooool4o`0000;ooooo0_l00004ooooo`?o00008_ooool2o`0000Cooooo0_l0
0005ooooo`?o00001_ooool4o`0000[ooooo0_l0000Dooooo`;o0000O?ooool001cooooo00?o0000
ooooooooool0H?ooool2o`0000Cooooo0_l00009ooooo`;o00007_ooool3o`0000Gooooo0_l00004
ooooo`;o00001_ooool4o`0000Cooooo0_l00008ooooo`;o0000>?ooool2o`0005Cooooo000Loooo
o`03o`000?oooooooooo063ooooo0_l0000?ooooo`;o00007oooool2o`0000?ooooo1?l00007oooo
o`?o00000oooool2o`0000Gooooo1?l00006ooooo`;o00002?ooool2o`0002kooooo0_l0001Doooo
o`007?ooool00ol0003oooooooooo`1Rooooo`;o00001_ooool2o`0002_ooooo0_l00009ooooo`Co
00001oooool6o`0000_ooooo0ol00002ooooo`;o0000Q?ooool001cooooo00?o0000ooooooooool0
H_ooool2o`000005ooooool0003o0000o`000?ooool00ol0000=ooooo`;o00003oooool2o`0001So
oooo1?l000000ooooooo0000o`000005o`0000Wooooo0_l00003ooooo`?o0000R?ooool001cooooo
00?o0000ooooooooool0IOooool6o`0000Wooooo0_l00003ooooo`;o00003oooool2o`0000[ooooo
0_l0000>ooooo`;o000000?oooooo`000?l000001ol00004ooooo`;o000000?oooooo`000?l00000
2_ooool2o`0008;ooooo000Looooo`03o`000?oooooooooo06Oooooo0ol0000:ooooo`;o000000?o
ooooo`000?l000001Oooool2o`0000;ooooo0_l0000Booooo`?o00005_ooool3o`0000Cooooo0_l0
000=ooooo`;o00009?ooool2o`0005cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Xooooo`?o
00003?ooool2o`0000Gooooo0_l00002ooooo`;o00004_ooool3o`0001gooooo0_l0000aooooo`Co
0000G?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRH
V?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo06Wooooo0_l00006ooooo`;o00003oooool2
o`0000?ooooo0_l0000=ooooo`;o00009Oooool2o`0002Wooooo0ol0001Nooooo`0000?ooooooa0@
4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`1Zooooo`;o00001Oooool2o`0000_ooooo0_l00007ooooo`;o00000_ooool3
o`0000Sooooo0ol0000Tooooo`;o0000:Oooool2o`0005oooooo00000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000J_ooool2
o`0001;ooooo0_l00002ooooo`;o00001oooool3o`0000Sooooo0ol00003ooooo`;o0000@oooool2
o`0006Kooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Goc<c<o`00
0?l0003o0000olc<c006ooooo`03o`000?oooooooooo07Sooooo0_l00008ooooo`Go00004?ooool2
o`0000?ooooo0_l00011ooooo`Co0000I_ooool00003ooooool@413ooooo00;ooooo00?o410@oooo
ooooool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0M_ooool4
o`0000Wooooo1_l0000Cooooo`;o0000@Oooool2o`0006Sooooo00001_ooooooMgMgoiRHV?oooooo
V9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo07Kooooo
0_l00003ooooo`;o00002_ooool2o`000003ooooool0003o000000;o00001oooool2o`000;;ooooo
00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06oooo
o`03o`000?oooooooooo07_ooooo0_l0000=ooooo`Go00001Oooool3o`000;;ooooo000Looooo`03
o`000?oooooooooo07?ooooo0_l000000ooooooo0000o`00000Eooooo`;o00000_ooool2o`000004
ooooool0003o0000ooooo`;o0000/?ooool001cooooo00?o0000ooooooooool0Loooool2o`000003
ooooool0003o000001Wooooo1Ol000000ooooooo0000o`00002`ooooo`007?ooool00ol0003ooooo
ooooo`1jooooo`;o00002_ooool2o`0000_ooooo0_l00002ooooo`;o0000/?ooool001cooooo00?o
0000ooooooooool0N_ooool2o`0000[ooooo0_l00002ooooo`;o0000@?ooool2o`000003ooooool0
003o000007Sooooo000Looooo`03o`000?oooooooooo07[ooooo0_l0000>ooooo`;o0000??ooool2
o`000003ooooool0003o000000Co0000N?ooool001cooooo00?o0000ooooooooool0a_ooool4o`00
0004ooooool0003o0000ooooo`;o0000NOooool001cooooo00?o0000ooooooooool0S_ooool2o`00
033ooooo0_l00004ooooo`;o0000POooool001cooooo00?o0000ooooooooool0Ooooool2o`0000Co
oooo0_l00007ooooo`;o00009oooool3o`000003ooooool0003o000000;ooooo0ol00027ooooo`00
7?ooool00ol0003oooooooooo`1oooooo`;o00001?ooool2o`0000?ooooo0_l00003ooooo`Co0000
8?ooool2o`0000;ooooo0ol000000ooooooo0000o`000002ooooo`;o0000R?ooool001cooooo00?o
0000ooooooooool0R_ooool3o`0000;ooooo1Ol0000Looooo`Go000000?oooooo`000?l00000TOoo
ool001cooooo00?o0000ooooooooool0Roooool2o`0000Cooooo0ol00002ooooo`;o00006?ooool4
o`0000;ooooo0_l0002Aooooo`007?ooool2o`0009?ooooo0_l00002ooooo`;o00005_ooool2o`00
0003ooooool0003o000009Kooooo000Looooo`03o`000?oooooooooo09;ooooo0_l00006ooooo`;o
00004_ooool2o`0009Wooooo000Looooo`03o`000?oooooooooo09[ooooo0_l000000ooooooo0000
o`000002o`000:Sooooo000Looooo`03o`000?oooooooooo09gooooo1?l00006ooooo`;o00000_oo
ool2o`0009cooooo000Looooo`03o`000?oooooooooo09[ooooo0ol000000ooooooo0000o`000004
ooooo`Go00000_ooool2o`0009cooooo000Looooo`03o`000?oooooooooo09[ooooo1Ol00005oooo
o`Co0000XOooool001cooooo00?o0000ooooooooool0WOooool2o`000:[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooooooo
ool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
B_ooool001Cooooo00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o0000
ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03
o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`004_oo
ool00omEEEGoIVIVo`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo002Uooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05Oooool01OnHV9So
410@o`000?lb<S;oc<c<00?ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o
0000oa0@4?o<c<`0T?ooool00:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00002Ooo
ool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05
oeEEEOmgMgOooooooiRHV?lQ8B40T?ooool00:Kooooo00Go0000ooooooooooooooooo`00000Loooo
o`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
oooo08kooooo002Vooooo`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo00?oZJVY
oa0@4?ooool01Oooool00onYZJWo410@ooooo`02ooooo`05o`000?nHV9SooooooiRHV?lQ8B40T?oo
ool00:Kooooo00Go0000ohN7QoooooooZJVYo`00000Jooooo`03oa0@4?l0003o^[Zj00Gooooo00?o
410@o`000?nj^[X00oooool01Ol0003oEEEEo`000?l@413oc<c<093ooooo002Uooooo`03oa0@4?l0
003oMgMg00;o000000?oV9RHooooooooool06Oooool00onj^[[o8B4Qooooo`05ooooo`03okZj^_lQ
8B7ooooo00;ooooo00?oEEEEohN7Qoooool0T_ooool00<?ooooo00Go410@oiRHV?oooooo^[Zjo`00
0003ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool00ooMgMgo410@oiRHV02Booooo`00`ooo
ool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@04ooooo`04
olc<c?m4A4Co0000oa0@493ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000
\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(342) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.5708 .70849 Mdot
.5459 .67301 Mdot
.65237 .33111 Mdot
.32943 .50842 Mdot
.4912 .2767 Mdot
.62611 .34177 Mdot
.70971 .52909 Mdot
.71318 .53274 Mdot
.65059 .35125 Mdot
.2853 .70031 Mdot
.67282 .53148 Mdot
.31665 .49256 Mdot
.69373 .53096 Mdot
.35412 .51035 Mdot
.43081 .42464 Mdot
.40375 .54933 Mdot
.58931 .68004 Mdot
.52292 .23641 Mdot
.39891 .54987 Mdot
.60873 .3316 Mdot
.25992 .56752 Mdot
.34252 .50621 Mdot
.5242 .6765 Mdot
.35099 .51123 Mdot
.375 .46938 Mdot
.54885 .68907 Mdot
.56262 .70887 Mdot
.36311 .46988 Mdot
.35476 .5489 Mdot
.68118 .53992 Mdot
.53699 .45054 Mdot
.18949 .45462 Mdot
.40301 .47897 Mdot
.42599 .67696 Mdot
.69802 .55353 Mdot
.73462 .48583 Mdot
.60811 .37478 Mdot
.72719 .52927 Mdot
.67642 .54957 Mdot
.66914 .53671 Mdot
.66903 .53146 Mdot
.55019 .69248 Mdot
.71255 .50514 Mdot
.72465 .43544 Mdot
.35359 .52373 Mdot
.47918 .65601 Mdot
.69002 .43239 Mdot
.39775 .51248 Mdot
.55377 .64972 Mdot
.63053 .32361 Mdot
.39012 .29842 Mdot
.71597 .51848 Mdot
.52468 .55121 Mdot
.87616 .56012 Mdot
.70146 .53796 Mdot
.40437 .52566 Mdot
.64052 .37698 Mdot
.37357 .49814 Mdot
.3336 .47443 Mdot
.40086 .65081 Mdot
.36414 .48463 Mdot
.50429 .26739 Mdot
.5428 .72111 Mdot
.59052 .34522 Mdot
.65247 .35055 Mdot
.72191 .51984 Mdot
.55084 .63269 Mdot
.6832 .53276 Mdot
.34276 .54181 Mdot
.62855 .32641 Mdot
.38123 .54246 Mdot
.67312 .52945 Mdot
.54259 .7002 Mdot
.33723 .51687 Mdot
.70468 .71602 Mdot
.65814 .47456 Mdot
.63411 .30351 Mdot
.37738 .60818 Mdot
.47206 .30418 Mdot
.4806 .42448 Mdot
.33771 .51351 Mdot
.80698 .38004 Mdot
.41522 .39509 Mdot
.55553 .65461 Mdot
.53777 .56316 Mdot
.70011 .61168 Mdot
.3945 .49388 Mdot
.53959 .45593 Mdot
.39049 .57066 Mdot
.54721 .23252 Mdot
.64291 .36581 Mdot
.57189 .65956 Mdot
.34556 .5218 Mdot
.33824 .53251 Mdot
.38349 .78058 Mdot
.36086 .55248 Mdot
.33937 .4688 Mdot
.57988 .55057 Mdot
.67599 .50184 Mdot
.30336 .46895 Mdot
.53299 .35333 Mdot
.51908 .57632 Mdot
.40408 .52174 Mdot
.63146 .36669 Mdot
.53639 .71517 Mdot
.41017 .49273 Mdot
.68595 .52164 Mdot
.34257 .51545 Mdot
.70116 .49049 Mdot
.54599 .64936 Mdot
.33208 .47083 Mdot
.52065 .27705 Mdot
.37769 .59855 Mdot
.53276 .6885 Mdot
.46603 .76187 Mdot
.35024 .48543 Mdot
.38013 .50571 Mdot
.54322 .67384 Mdot
.60666 .3409 Mdot
.77264 .36177 Mdot
.54396 .69902 Mdot
.66791 .53378 Mdot
.58444 .66579 Mdot
.42836 .57593 Mdot
.60356 .34332 Mdot
.50524 .56313 Mdot
.50224 .55595 Mdot
.30139 .35021 Mdot
.33035 .50085 Mdot
.24445 .52187 Mdot
.62925 .35587 Mdot
.53626 .68411 Mdot
.68915 .53924 Mdot
.36533 .5616 Mdot
.56622 .68793 Mdot
.71235 .52715 Mdot
.53585 .29172 Mdot
.50704 .23269 Mdot
.5289 .66485 Mdot
.48622 .77871 Mdot
.73092 .56644 Mdot
.67351 .49802 Mdot
.38777 .30097 Mdot
.55489 .65455 Mdot
.52065 .26001 Mdot
.69689 .51556 Mdot
.3526 .22028 Mdot
.35448 .45826 Mdot
.36251 .32185 Mdot
.81486 .40757 Mdot
.39084 .29834 Mdot
.24817 .57657 Mdot
.5264 .27203 Mdot
.71259 .52629 Mdot
.39095 .53232 Mdot
.56125 .6698 Mdot
.56268 .68965 Mdot
.36827 .54391 Mdot
.38142 .46546 Mdot
.36482 .51247 Mdot
.40017 .47822 Mdot
.58404 .52249 Mdot
.34645 .52071 Mdot
.6019 .78336 Mdot
.56819 .67296 Mdot
.39004 .47421 Mdot
.60812 .36508 Mdot
.30235 .44833 Mdot
.71628 .50957 Mdot
.3275 .49016 Mdot
.3751 .46479 Mdot
.32008 .53244 Mdot
.66684 .53349 Mdot
.7021 .72948 Mdot
.46484 .26228 Mdot
.68843 .56348 Mdot
.78315 .5422 Mdot
.61861 .35991 Mdot
.37548 .48556 Mdot
.53321 .25999 Mdot
.29103 .48702 Mdot
.34518 .53032 Mdot
.39607 .2934 Mdot
.34345 .47073 Mdot
.24367 .56786 Mdot
.43521 .52058 Mdot
.70046 .60488 Mdot
.59754 .76788 Mdot
.33016 .51475 Mdot
.29659 .68418 Mdot
.37337 .32266 Mdot
.64274 .45179 Mdot
.68952 .5417 Mdot
.62027 .33504 Mdot
.61211 .33698 Mdot
.72442 .55554 Mdot
.45927 .71926 Mdot
.2671 .67848 Mdot
.33838 .54637 Mdot
.52089 .57348 Mdot
.5807 .6516 Mdot
.5241 .27155 Mdot
.53067 .66785 Mdot
.79389 .35391 Mdot
.49723 .41601 Mdot
.51397 .46332 Mdot
.54773 .31667 Mdot
.62867 .32106 Mdot
.51581 .56835 Mdot
.52186 .25584 Mdot
.37076 .51997 Mdot
.54608 .65025 Mdot
.3771 .31727 Mdot
.29329 .51361 Mdot
.25555 .73251 Mdot
.56351 .70675 Mdot
.28184 .39476 Mdot
.69982 .53561 Mdot
.64251 .38966 Mdot
.39393 .49236 Mdot
.35643 .49495 Mdot
.53794 .64854 Mdot
.39191 .5237 Mdot
.48528 .45954 Mdot
.36594 .46319 Mdot
.59064 .35427 Mdot
.47318 .24141 Mdot
.71776 .56742 Mdot
.53772 .31608 Mdot
.53533 .6945 Mdot
.72087 .75151 Mdot
.62244 .3764 Mdot
.34288 .43416 Mdot
.67452 .52287 Mdot
.53079 .29153 Mdot
.62989 .37659 Mdot
.4941 .25092 Mdot
.32388 .49111 Mdot
.61412 .38187 Mdot
.50728 .27211 Mdot
.51362 .48619 Mdot
.40158 .48088 Mdot
.28273 .33566 Mdot
.70591 .51507 Mdot
.57978 .66608 Mdot
.3606 .53722 Mdot
.53177 .55765 Mdot
.332 .45495 Mdot
.32577 .37085 Mdot
.51509 .55201 Mdot
.52112 .58085 Mdot
.45494 .40122 Mdot
.54587 .27357 Mdot
.78538 .60088 Mdot
.54546 .46805 Mdot
.58955 .68142 Mdot
.33695 .52811 Mdot
.76899 .56986 Mdot
.71115 .51921 Mdot
.37332 .51296 Mdot
.75677 .58985 Mdot
.69998 .5165 Mdot
.37865 .50723 Mdot
.67669 .54289 Mdot
.56578 .67985 Mdot
.46568 .44204 Mdot
.58525 .69685 Mdot
.35692 .53 Mdot
.6753 .53997 Mdot
.61464 .33876 Mdot
.55024 .68911 Mdot
.34121 .51203 Mdot
.33535 .48677 Mdot
.52888 .57297 Mdot
.36031 .46008 Mdot
.61798 .57696 Mdot
.39843 .50815 Mdot
.65709 .33257 Mdot
.35807 .5513 Mdot
.47422 .34584 Mdot
.53187 .21232 Mdot
.53701 .65443 Mdot
.51631 .55255 Mdot
.63547 .37825 Mdot
.49168 .47961 Mdot
.26303 .39561 Mdot
.35024 .51899 Mdot
.52155 .55714 Mdot
.3017 .36702 Mdot
.70977 .5054 Mdot
.39915 .56984 Mdot
.59831 .29694 Mdot
.64134 .36511 Mdot
.51746 .57157 Mdot
.29349 .49755 Mdot
.56401 .62681 Mdot
.39369 .55136 Mdot
.61467 .37953 Mdot
.58513 .69127 Mdot
.37942 .55097 Mdot
.66167 .4631 Mdot
.53606 .56388 Mdot
.67702 .49879 Mdot
.57329 .54502 Mdot
.38501 .50638 Mdot
.63197 .32774 Mdot
.5565 .69601 Mdot
.7065 .53872 Mdot
.53458 .69141 Mdot
.3977 .31155 Mdot
.30214 .37914 Mdot
.50446 .64655 Mdot
.55071 .28259 Mdot
.30656 .23923 Mdot
.68694 .56365 Mdot
.29779 .4729 Mdot
.58991 .38381 Mdot
.59387 .75168 Mdot
.63417 .36771 Mdot
.50065 .7817 Mdot
.64258 .37055 Mdot
.39851 .53817 Mdot
.63448 .33856 Mdot
.38316 .78857 Mdot
.35025 .47274 Mdot
.65411 .34849 Mdot
.58315 .49951 Mdot
.3452 .47508 Mdot
.56721 .68842 Mdot
.18279 .51726 Mdot
.44671 .69402 Mdot
.45029 .70741 Mdot
.63814 .38202 Mdot
.5138 .78628 Mdot
.36878 .47169 Mdot
.37505 .56475 Mdot
.55863 .674 Mdot
.33638 .45287 Mdot
.53775 .25469 Mdot
.51004 .23588 Mdot
.36867 .25573 Mdot
.21255 .44956 Mdot
.45666 .73386 Mdot
.55824 .68834 Mdot
.47169 .26714 Mdot
.69492 .72363 Mdot
.53523 .56213 Mdot
.71357 .53202 Mdot
.74136 .69306 Mdot
.37168 .5693 Mdot
.55823 .59481 Mdot
.48219 .45793 Mdot
.58203 .68502 Mdot
.51371 .59823 Mdot
.70887 .53758 Mdot
.44799 .70728 Mdot
.25159 .65114 Mdot
.366 .5137 Mdot
.70205 .50725 Mdot
.34249 .45343 Mdot
.53885 .45977 Mdot
.28399 .3556 Mdot
.71268 .34998 Mdot
.35781 .5289 Mdot
.74776 .67344 Mdot
.35234 .53389 Mdot
.31406 .3403 Mdot
.37305 .51995 Mdot
.56465 .69515 Mdot
.32039 .53824 Mdot
.54618 .47544 Mdot
.37796 .17629 Mdot
.49176 .4068 Mdot
.49912 .24587 Mdot
.35311 .50729 Mdot
.36568 .50293 Mdot
.50108 .26414 Mdot
.57908 .6725 Mdot
.35414 .5385 Mdot
.80231 .5964 Mdot
.34258 .51938 Mdot
.72228 .52515 Mdot
.36785 .36695 Mdot
.20169 .43313 Mdot
.37985 .48123 Mdot
.56325 .62695 Mdot
.67409 .49844 Mdot
.67814 .51496 Mdot
.37052 .58458 Mdot
.7093 .51605 Mdot
.39063 .5306 Mdot
.3685 .36623 Mdot
.53246 .64003 Mdot
.36585 .5829 Mdot
.5801 .68677 Mdot
.54541 .173 Mdot
.70868 .52049 Mdot
.53092 .56029 Mdot
.46849 .7416 Mdot
.69449 .52192 Mdot
.47867 .22739 Mdot
.32317 .54273 Mdot
.30225 .54366 Mdot
.59641 .67827 Mdot
.63212 .3288 Mdot
.51356 .56004 Mdot
.70306 .53817 Mdot
.35226 .52162 Mdot
.40413 .49593 Mdot
.7076 .51338 Mdot
.31612 .62486 Mdot
.53815 .45019 Mdot
.35438 .53033 Mdot
.57335 .68232 Mdot
.53839 .68699 Mdot
.41013 .55079 Mdot
.35359 .53532 Mdot
.62184 .33954 Mdot
.52049 .55651 Mdot
.51392 .55457 Mdot
.50471 .56636 Mdot
.63886 .38668 Mdot
.31206 .23141 Mdot
.67699 .49526 Mdot
.19284 .44802 Mdot
.69608 .68405 Mdot
.39688 .58247 Mdot
.60431 .35365 Mdot
.35613 .4898 Mdot
.40416 .50961 Mdot
.67985 .54348 Mdot
.27272 .29968 Mdot
.36893 .56394 Mdot
.58085 .70067 Mdot
.71099 .51384 Mdot
.33616 .45578 Mdot
.67811 .58849 Mdot
.53245 .28092 Mdot
.45941 .74642 Mdot
.71474 .51949 Mdot
.52985 .64795 Mdot
.71496 .51951 Mdot
.36553 .5058 Mdot
.29375 .49225 Mdot
.58135 .68925 Mdot
.49004 .26673 Mdot
.36026 .54326 Mdot
.37886 .51564 Mdot
.57254 .37831 Mdot
.70727 .71244 Mdot
.49745 .28796 Mdot
.39848 .52764 Mdot
.29708 .53759 Mdot
.49114 .26521 Mdot
.37982 .53377 Mdot
.37054 .54995 Mdot
.24392 .52298 Mdot
.71686 .50513 Mdot
.52057 .29286 Mdot
.35002 .19579 Mdot
.56511 .70719 Mdot
.617 .57308 Mdot
.51247 .5726 Mdot
.67972 .55836 Mdot
.47525 .46202 Mdot
.52342 .5652 Mdot
.72115 .65705 Mdot
.59959 .84229 Mdot
.5159 .56013 Mdot
.61304 .39118 Mdot
.41209 .78622 Mdot
.36714 .54923 Mdot
.36044 .53298 Mdot
.53973 .25938 Mdot
.54323 .66544 Mdot
.60951 .76814 Mdot
.68614 .56185 Mdot
.344 .49416 Mdot
.54939 .70792 Mdot
.70501 .60769 Mdot
.52381 .57018 Mdot
.53669 .26749 Mdot
.50076 .28118 Mdot
.36205 .53588 Mdot
.27872 .3815 Mdot
.55361 .69073 Mdot
.34133 .51208 Mdot
.38165 .50674 Mdot
.60317 .3777 Mdot
.54439 .65185 Mdot
.61108 .36927 Mdot
.53666 .58032 Mdot
.44525 .81243 Mdot
.79388 .52822 Mdot
.69949 .51292 Mdot
.47791 .54925 Mdot
.71714 .56736 Mdot
.66891 .43642 Mdot
.51888 .55588 Mdot
.34206 .51011 Mdot
.52261 .64775 Mdot
.34134 .51394 Mdot
.34366 .52042 Mdot
.3584 .52566 Mdot
.45657 .73566 Mdot
.47537 .30945 Mdot
.53284 .25624 Mdot
.38899 .51001 Mdot
.62563 .39017 Mdot
.70996 .5968 Mdot
.30984 .73417 Mdot
.35495 .50167 Mdot
.38023 .50738 Mdot
.56528 .63011 Mdot
.35165 .45741 Mdot
.70142 .52122 Mdot
.58296 .68418 Mdot
.40722 .51065 Mdot
.54059 .34858 Mdot
.36116 .53964 Mdot
.49998 .61304 Mdot
.719 .54168 Mdot
.30339 .49049 Mdot
.40378 .46841 Mdot
.51998 .55546 Mdot
.5144 .56115 Mdot
.51803 .58385 Mdot
.72218 .52264 Mdot
.60797 .38263 Mdot
.61703 .30979 Mdot
.39326 .45522 Mdot
.39493 .52764 Mdot
.29747 .52637 Mdot
.66703 .38053 Mdot
.56234 .46291 Mdot
.48994 .77086 Mdot
.34362 .45542 Mdot
.65161 .37908 Mdot
.57982 .55 Mdot
.30931 .60362 Mdot
.58033 .67085 Mdot
.60025 .3997 Mdot
.67895 .52166 Mdot
.50801 .2767 Mdot
.34947 .29078 Mdot
.554 .70104 Mdot
.5332 .63221 Mdot
.61798 .34833 Mdot
.37744 .36521 Mdot
.89436 .52651 Mdot
.63357 .35635 Mdot
.50653 .46512 Mdot
.55905 .67962 Mdot
.40259 .47921 Mdot
.31765 .35859 Mdot
.37775 .37497 Mdot
.65527 .36223 Mdot
.33453 .48823 Mdot
.58081 .18908 Mdot
.62294 .33874 Mdot
.29395 .52532 Mdot
.63665 .38361 Mdot
.68878 .49638 Mdot
.62801 .36224 Mdot
.55558 .71329 Mdot
.33119 .50111 Mdot
.88203 .54954 Mdot
.43829 .40811 Mdot
.337 .49594 Mdot
.71969 .52411 Mdot
.65458 .45355 Mdot
.36936 .51245 Mdot
.52643 .24295 Mdot
.61224 .38957 Mdot
.69775 .38026 Mdot
.38851 .54812 Mdot
.63521 .3371 Mdot
.53803 .62481 Mdot
.61175 .40844 Mdot
.53859 .35412 Mdot
.51248 .55748 Mdot
.56561 .67429 Mdot
.66735 .47317 Mdot
.66741 .5295 Mdot
.41182 .52218 Mdot
.37941 .49564 Mdot
.5702 .67048 Mdot
.49851 .48869 Mdot
.41222 .56276 Mdot
.34071 .51672 Mdot
.61266 .36005 Mdot
.60553 .32683 Mdot
.42426 .41955 Mdot
.62137 .37796 Mdot
.29996 .54243 Mdot
.57088 .67948 Mdot
.39551 .54958 Mdot
.5399 .69331 Mdot
.33922 .53048 Mdot
.64862 .57531 Mdot
.57089 .65494 Mdot
.35122 .43421 Mdot
.33075 .49009 Mdot
.5407 .76128 Mdot
.38479 .5005 Mdot
.34993 .52746 Mdot
.59603 .34136 Mdot
.50506 .25888 Mdot
.41069 .55827 Mdot
.64297 .50066 Mdot
.5079 .28151 Mdot
.30133 .61379 Mdot
.60322 .3446 Mdot
.51388 .28906 Mdot
.34416 .27077 Mdot
.51443 .55276 Mdot
.50296 .25162 Mdot
.50482 .54218 Mdot
.69689 .51012 Mdot
.51326 .6726 Mdot
.34074 .47674 Mdot
.43887 .81039 Mdot
.54035 .45069 Mdot
.53084 .57111 Mdot
.37378 .534 Mdot
.36061 .49048 Mdot
.54857 .70744 Mdot
.79676 .36035 Mdot
.60998 .31821 Mdot
.37591 .46061 Mdot
.55264 .70233 Mdot
.81095 .39215 Mdot
.65614 .35376 Mdot
.54314 .27701 Mdot
.67961 .55379 Mdot
.58811 .71187 Mdot
.53334 .56232 Mdot
.71014 .52213 Mdot
.62089 .30482 Mdot
.40007 .2907 Mdot
.39095 .55221 Mdot
.6054 .36141 Mdot
.39199 .29742 Mdot
.40108 .57053 Mdot
.72747 .55391 Mdot
.67675 .45804 Mdot
.56101 .65441 Mdot
.70817 .51344 Mdot
.52629 .24627 Mdot
.58475 .66262 Mdot
.58106 .68454 Mdot
.69573 .51848 Mdot
.57189 .7906 Mdot
.30312 .36682 Mdot
.71329 .55563 Mdot
.33251 .37115 Mdot
.39401 .29724 Mdot
.53362 .57046 Mdot
.53512 .26616 Mdot
.4713 .24258 Mdot
.54938 .69163 Mdot
.73561 .69799 Mdot
.39047 .2975 Mdot
.34102 .46725 Mdot
.50588 .27217 Mdot
.68593 .60274 Mdot
.73595 .49272 Mdot
.70568 .52093 Mdot
.5833 .39663 Mdot
.50227 .27144 Mdot
.32448 .50009 Mdot
.21342 .35636 Mdot
.36044 .47464 Mdot
.69621 .51448 Mdot
.48345 .45858 Mdot
.53749 .659 Mdot
.71274 .50657 Mdot
.48461 .45872 Mdot
.40188 .51921 Mdot
.34963 .48366 Mdot
.48867 .32269 Mdot
.55613 .64734 Mdot
.53612 .57669 Mdot
.33359 .50178 Mdot
.37653 .50328 Mdot
.41462 .52411 Mdot
.23054 .39784 Mdot
.44638 .58208 Mdot
.41593 .50837 Mdot
.65201 .38626 Mdot
.29175 .49219 Mdot
.37051 .45772 Mdot
.57137 .62861 Mdot
.51961 .34781 Mdot
.53462 .58488 Mdot
.36503 .53225 Mdot
.35674 .53056 Mdot
.67781 .54993 Mdot
.30375 .36588 Mdot
.38145 .37325 Mdot
.64513 .32377 Mdot
.66479 .32568 Mdot
.32733 .52683 Mdot
.56371 .66502 Mdot
.54539 .29288 Mdot
.33108 .5743 Mdot
.57837 .702 Mdot
.33019 .52699 Mdot
.60808 .38707 Mdot
.51823 .55865 Mdot
.31688 .56732 Mdot
.51002 .26896 Mdot
.73363 .56165 Mdot
.31073 .61217 Mdot
.61145 .34428 Mdot
.38222 .47616 Mdot
.6482 .30768 Mdot
.64114 .3474 Mdot
.52974 .57428 Mdot
.3124 .46241 Mdot
.56425 .68374 Mdot
.52861 .65093 Mdot
.46085 .32862 Mdot
.63426 .38931 Mdot
.63044 .42752 Mdot
.69385 .50132 Mdot
.3878 .51203 Mdot
.74726 .55075 Mdot
.53043 .65487 Mdot
.30078 .34987 Mdot
.50506 .28507 Mdot
.70207 .51885 Mdot
.51119 .54362 Mdot
.57699 .6615 Mdot
.52756 .65743 Mdot
.34831 .52253 Mdot
.3472 .50271 Mdot
.66181 .43242 Mdot
.36618 .32406 Mdot
.68215 .54736 Mdot
.53773 .28281 Mdot
.6461 .32605 Mdot
.3942 .54088 Mdot
.55364 .6569 Mdot
.20045 .41544 Mdot
.38476 .50405 Mdot
.62667 .38977 Mdot
.54698 .6753 Mdot
.54062 .26548 Mdot
.52577 .24748 Mdot
.33236 .51344 Mdot
.24563 .56732 Mdot
.69059 .52244 Mdot
.56699 .69049 Mdot
.56731 .73578 Mdot
.39129 .51047 Mdot
.3517 .50385 Mdot
.43847 .5561 Mdot
.73151 .53382 Mdot
.4249 .50858 Mdot
.49193 .25776 Mdot
.52954 .67708 Mdot
.33528 .50304 Mdot
.50304 .26589 Mdot
.55954 .59698 Mdot
.52405 .56323 Mdot
.64526 .33843 Mdot
.52115 .23951 Mdot
.5133 .25929 Mdot
.5153 .28526 Mdot
.74321 .69081 Mdot
.54392 .58049 Mdot
.44538 .22304 Mdot
.33252 .4905 Mdot
.39491 .29714 Mdot
.40949 .54715 Mdot
.70466 .50377 Mdot
.63568 .33011 Mdot
.35926 .52104 Mdot
.3328 .48926 Mdot
.32338 .61116 Mdot
.40259 .54742 Mdot
.3923 .55901 Mdot
.53533 .65937 Mdot
.56629 .73855 Mdot
.61803 .33394 Mdot
.82017 .42545 Mdot
.15985 .4448 Mdot
.33315 .54216 Mdot
.37556 .36574 Mdot
.57726 .66515 Mdot
.67832 .55166 Mdot
.33006 .36602 Mdot
.7536 .53346 Mdot
.53769 .67769 Mdot
.39713 .54079 Mdot
.35882 .61549 Mdot
.50507 .27711 Mdot
.36453 .50958 Mdot
.68451 .5376 Mdot
.36477 .51099 Mdot
.71931 .51784 Mdot
.51558 .77897 Mdot
.39445 .37338 Mdot
.34344 .4723 Mdot
.36126 .55227 Mdot
.2593 .55043 Mdot
.35198 .50157 Mdot
.71161 .33566 Mdot
.55134 .67498 Mdot
.3361 .43866 Mdot
.40446 .52926 Mdot
.43971 .692 Mdot
.38177 .52476 Mdot
.47828 .48329 Mdot
.36672 .48254 Mdot
.29103 .28277 Mdot
.32776 .48254 Mdot
.37305 .48396 Mdot
.70285 .54575 Mdot
.67158 .54216 Mdot
.57587 .7531 Mdot
.53118 .5831 Mdot
.69588 .60463 Mdot
.37986 .51468 Mdot
.62945 .31963 Mdot
.27251 .46332 Mdot
.50853 .25892 Mdot
.53104 .67848 Mdot
.70646 .81155 Mdot
.68613 .49253 Mdot
.62388 .39313 Mdot
.52626 .45868 Mdot
.64116 .3953 Mdot
.5921 .38632 Mdot
.59511 .71223 Mdot
.53513 .26882 Mdot
.35698 .53816 Mdot
.43246 .67454 Mdot
.7234 .69549 Mdot
.39227 .51138 Mdot
.65791 .32577 Mdot
.25883 .48292 Mdot
.44777 .31907 Mdot
.53587 .24629 Mdot
.52825 .26689 Mdot
.7061 .53534 Mdot
.64322 .3271 Mdot
.34892 .45274 Mdot
.51375 .28924 Mdot
.6246 .33328 Mdot
.50748 .54493 Mdot
.50546 .33904 Mdot
.55543 .69173 Mdot
.51034 .78528 Mdot
.48137 .6763 Mdot
.67212 .50136 Mdot
.64606 .49731 Mdot
.51547 .65978 Mdot
.58863 .68964 Mdot
.52612 .58037 Mdot
.65198 .37477 Mdot
.5141 .67368 Mdot
.33269 .50741 Mdot
.29305 .51304 Mdot
.36017 .53607 Mdot
.54369 .26758 Mdot
.37878 .52975 Mdot
.62921 .33468 Mdot
.70811 .54583 Mdot
.64047 .36939 Mdot
.71018 .5306 Mdot
.1822 .4869 Mdot
.32653 .49835 Mdot
.35025 .50634 Mdot
.36941 .36684 Mdot
.52788 .66114 Mdot
.4204 .68234 Mdot
.62995 .38876 Mdot
.63957 .37702 Mdot
.4017 .53513 Mdot
.57476 .6484 Mdot
.48855 .28261 Mdot
.34553 .36977 Mdot
.36963 .48509 Mdot
.5514 .67312 Mdot
.40081 .53931 Mdot
.62366 .53226 Mdot
.4199 .40304 Mdot
.5273 .68167 Mdot
.38323 .17309 Mdot
.32968 .48846 Mdot
.32375 .45571 Mdot
.37588 .44139 Mdot
.22695 .41388 Mdot
.40544 .56362 Mdot
.56796 .70671 Mdot
.36999 .45802 Mdot
.55931 .66265 Mdot
.64006 .35322 Mdot
.70404 .49997 Mdot
.55836 .66726 Mdot
.34875 .47601 Mdot
.16185 .44194 Mdot
.7048 .54944 Mdot
.36094 .51236 Mdot
.68652 .54482 Mdot
.53216 .70957 Mdot
.53981 .66193 Mdot
.50286 .54359 Mdot
.50796 .46449 Mdot
.69681 .51997 Mdot
.39479 .52602 Mdot
.70474 .72253 Mdot
.39389 .55169 Mdot
.66253 .32479 Mdot
.35234 .55353 Mdot
.33217 .53227 Mdot
.3133 .22395 Mdot
.49174 .48819 Mdot
.7993 .5237 Mdot
.70971 .59018 Mdot
.69581 .73394 Mdot
.59615 .67026 Mdot
.53444 .24511 Mdot
.49455 .57999 Mdot
.50961 .55338 Mdot
.65586 .38096 Mdot
.3552 .52198 Mdot
.56994 .58658 Mdot
.72156 .55087 Mdot
.50821 .25048 Mdot
.34377 .47064 Mdot
.64939 .39684 Mdot
.47511 .55123 Mdot
.70842 .52221 Mdot
.54952 .69291 Mdot
.53319 .67162 Mdot
.46823 .30244 Mdot
.33603 .50098 Mdot
.34437 .50564 Mdot
.69931 .55271 Mdot
.4304 .492 Mdot
.52183 .28467 Mdot
.58242 .49769 Mdot
.68318 .53822 Mdot
.41907 .40088 Mdot
.55344 .64655 Mdot
.35859 .49008 Mdot
.36634 .36947 Mdot
.65169 .75961 Mdot
.32379 .73008 Mdot
.52232 .26882 Mdot
.27 .39098 Mdot
.56688 .70668 Mdot
.6907 .53999 Mdot
.35708 .26297 Mdot
.33128 .55135 Mdot
.3651 .49162 Mdot
.25311 .39658 Mdot
.34306 .37022 Mdot
.52418 .46161 Mdot
.4211 .57693 Mdot
.33587 .35041 Mdot
.40119 .53689 Mdot
.40437 .4972 Mdot
.32616 .523 Mdot
.35529 .55451 Mdot
.55282 .6661 Mdot
.44183 .70787 Mdot
.6228 .35156 Mdot
.32834 .72083 Mdot
.67489 .35371 Mdot
.36725 .47199 Mdot
.40033 .52831 Mdot
.34841 .70187 Mdot
.30477 .39852 Mdot
.5533 .68267 Mdot
.5953 .6861 Mdot
.66619 .51119 Mdot
.39866 .55088 Mdot
.63022 .39003 Mdot
.37412 .44196 Mdot
.64607 .3459 Mdot
.55155 .66752 Mdot
.59993 .36819 Mdot
.659 .504 Mdot
.60548 .36259 Mdot
.65241 .38125 Mdot
.71561 .54123 Mdot
.56277 .64792 Mdot
.37972 .49079 Mdot
.71663 .5399 Mdot
.49339 .28719 Mdot
.54262 .26503 Mdot
.54119 .73528 Mdot
.4109 .49053 Mdot
.36026 .56618 Mdot
.67843 .44717 Mdot
.60891 .37845 Mdot
.36787 .38911 Mdot
.56711 .65302 Mdot
.54636 .29034 Mdot
.55536 .66216 Mdot
.44082 .27613 Mdot
.51734 .26698 Mdot
.53578 .55962 Mdot
.31556 .30984 Mdot
.71053 .572 Mdot
.31437 .51817 Mdot
.56439 .73816 Mdot
.64717 .34993 Mdot
.71956 .52108 Mdot
.7017 .59925 Mdot
.38156 .46392 Mdot
.50827 .66239 Mdot
.54979 .72011 Mdot
.51247 .55406 Mdot
.68838 .53841 Mdot
.49344 .71397 Mdot
.33897 .49491 Mdot
.7159 .56967 Mdot
.34943 .55198 Mdot
.47338 .77017 Mdot
.68348 .38079 Mdot
.57724 .55883 Mdot
.39953 .53719 Mdot
.65663 .35474 Mdot
.40026 .53715 Mdot
.44503 .79175 Mdot
.31888 .32676 Mdot
.32574 .52468 Mdot
.29105 .39923 Mdot
.67759 .43814 Mdot
.555 .6564 Mdot
.34188 .57746 Mdot
.53234 .57136 Mdot
.39218 .48409 Mdot
.15104 .60076 Mdot
.50199 .25888 Mdot
.53243 .32586 Mdot
.34353 .47768 Mdot
.33801 .5118 Mdot
.30682 .60824 Mdot
.51192 .77561 Mdot
.50124 .54532 Mdot
.36914 .49696 Mdot
.23609 .4186 Mdot
.70428 .54285 Mdot
.37815 .55239 Mdot
.34863 .53034 Mdot
.65701 .42632 Mdot
.69837 .54498 Mdot
.60177 .35612 Mdot
.51296 .55288 Mdot
.61088 .32496 Mdot
.49041 .27352 Mdot
.27813 .39506 Mdot
.27197 .36614 Mdot
.41902 .40745 Mdot
.51775 .23897 Mdot
.37799 .47672 Mdot
.57157 .55044 Mdot
.34096 .4859 Mdot
.52808 .26171 Mdot
.68094 .53982 Mdot
.5537 .67264 Mdot
.49446 .78194 Mdot
.5258 .57418 Mdot
.39036 .49604 Mdot
.5482 .26669 Mdot
.56161 .67221 Mdot
.628 .78323 Mdot
.54533 .66495 Mdot
.70628 .52696 Mdot
.72674 .55153 Mdot
.51199 .26374 Mdot
.55508 .6614 Mdot
.60416 .33105 Mdot
.74294 .53299 Mdot
.31391 .49209 Mdot
.66005 .50181 Mdot
.52665 .69519 Mdot
.53092 .6938 Mdot
.54066 .6345 Mdot
.40635 .52234 Mdot
.32716 .3897 Mdot
.43316 .57346 Mdot
.7016 .55149 Mdot
.65663 .38662 Mdot
.35686 .32383 Mdot
.43482 .63583 Mdot
.40306 .38904 Mdot
.33746 .57408 Mdot
.3777 .53079 Mdot
.36395 .53587 Mdot
.41754 .51754 Mdot
.56834 .50831 Mdot
.3267 .5005 Mdot
.68091 .54528 Mdot
.63388 .34295 Mdot
.3676 .48608 Mdot
.52975 .56251 Mdot
.55903 .46117 Mdot
.5195 .29335 Mdot
.45881 .74927 Mdot
.5496 .74064 Mdot
.56022 .6722 Mdot
.61451 .37781 Mdot
.59789 .36092 Mdot
.53607 .29154 Mdot
.71412 .52439 Mdot
.54178 .66625 Mdot
.29691 .27585 Mdot
.51051 .28108 Mdot
.36659 .5317 Mdot
.36853 .36716 Mdot
.22073 .43421 Mdot
.36308 .54557 Mdot
.3603 .52641 Mdot
.53306 .58487 Mdot
.63317 .39174 Mdot
.31478 .74832 Mdot
.5861 .78034 Mdot
.50612 .26222 Mdot
.53249 .28854 Mdot
.54605 .63092 Mdot
.38745 .51942 Mdot
.68781 .52366 Mdot
.29643 .37031 Mdot
.65752 .46183 Mdot
.69251 .61094 Mdot
.668 .43751 Mdot
.36459 .53997 Mdot
.42679 .75631 Mdot
.32941 .54362 Mdot
.53323 .71255 Mdot
.53599 .64405 Mdot
.55601 .68654 Mdot
.70716 .54141 Mdot
.40269 .28926 Mdot
.66938 .52957 Mdot
.58067 .54654 Mdot
.56601 .7026 Mdot
.50355 .47848 Mdot
.63896 .37927 Mdot
.40703 .54767 Mdot
.53375 .26714 Mdot
.56457 .29974 Mdot
.32883 .57194 Mdot
.27254 .39231 Mdot
.60419 .35396 Mdot
.57666 .65759 Mdot
.40983 .54433 Mdot
.71442 .5961 Mdot
.38201 .35971 Mdot
.69669 .41057 Mdot
.5722 .57966 Mdot
.50396 .26836 Mdot
.28007 .69088 Mdot
.52224 .28216 Mdot
.70099 .51794 Mdot
.32874 .49331 Mdot
.38604 .51667 Mdot
.34994 .52802 Mdot
.3586 .55919 Mdot
.7017 .53957 Mdot
.31416 .49709 Mdot
.47327 .34539 Mdot
.50354 .55154 Mdot
.555 .48242 Mdot
.51662 .24437 Mdot
.69724 .50185 Mdot
.63863 .34517 Mdot
.51914 .57964 Mdot
.55053 .28485 Mdot
.41469 .53734 Mdot
.34626 .47867 Mdot
.50266 .54916 Mdot
.37103 .58308 Mdot
.3769 .56961 Mdot
.62307 .34443 Mdot
.54199 .46156 Mdot
.50745 .28967 Mdot
.52415 .27522 Mdot
.70077 .50853 Mdot
.55566 .66153 Mdot
.51651 .29164 Mdot
.6606 .34161 Mdot
.38184 .55231 Mdot
.347 .55093 Mdot
.52847 .69622 Mdot
.394 .29501 Mdot
.5198 .29348 Mdot
.42583 .51288 Mdot
.52747 .67702 Mdot
.55221 .72085 Mdot
.36823 .49728 Mdot
.32164 .48115 Mdot
.57503 .6327 Mdot
.53852 .28783 Mdot
.6992 .50587 Mdot
.42537 .38763 Mdot
.68166 .49523 Mdot
.55415 .69573 Mdot
.2915 .50449 Mdot
.56588 .64723 Mdot
.3838 .46553 Mdot
.82259 .56797 Mdot
.32618 .50354 Mdot
.47568 .59503 Mdot
.55027 .42902 Mdot
.63953 .38157 Mdot
.64709 .37626 Mdot
.52013 .55783 Mdot
.58075 .69818 Mdot
.30681 .5548 Mdot
.53584 .27418 Mdot
.69645 .73303 Mdot
.56866 .62606 Mdot
.65295 .37933 Mdot
.61668 .39168 Mdot
.68459 .54248 Mdot
.38036 .52846 Mdot
.35733 .4887 Mdot
.60475 .36261 Mdot
.6371 .48387 Mdot
.56783 .66055 Mdot
.34449 .50609 Mdot
.41561 .51515 Mdot
.62492 .34933 Mdot
.65743 .53428 Mdot
.51452 .66656 Mdot
.40768 .51935 Mdot
.31369 .33414 Mdot
.71728 .51224 Mdot
.39567 .49379 Mdot
.31475 .5211 Mdot
.5124 .25558 Mdot
.26419 .39113 Mdot
.38846 .30076 Mdot
.67874 .49243 Mdot
.52275 .55483 Mdot
.36535 .54409 Mdot
.64373 .37629 Mdot
.42023 .53799 Mdot
.47251 .8581 Mdot
.5058 .55004 Mdot
.34028 .49618 Mdot
.39676 .45464 Mdot
.54014 .69397 Mdot
.34012 .50937 Mdot
.64282 .5707 Mdot
.61463 .36704 Mdot
.34101 .49446 Mdot
.25957 .58005 Mdot
.68495 .54209 Mdot
.33947 .5764 Mdot
.50315 .27324 Mdot
.51411 .46665 Mdot
.18275 .51453 Mdot
.66592 .3832 Mdot
.50706 .24365 Mdot
.38157 .52184 Mdot
.63906 .32178 Mdot
.6746 .55039 Mdot
.46031 .55842 Mdot
.38628 .48276 Mdot
.67129 .50422 Mdot
.71186 .54179 Mdot
.50906 .26602 Mdot
.81612 .66877 Mdot
.32276 .51769 Mdot
.36047 .50533 Mdot
.73893 .73871 Mdot
.58446 .63785 Mdot
.36252 .51317 Mdot
.38195 .50592 Mdot
.70601 .51498 Mdot
.40834 .26528 Mdot
.27024 .39196 Mdot
.58078 .50078 Mdot
.71574 .51225 Mdot
.63365 .31392 Mdot
.60948 .36042 Mdot
.50222 .24693 Mdot
.5462 .67536 Mdot
.54621 .2876 Mdot
.62511 .36134 Mdot
.35562 .52842 Mdot
.681 .50772 Mdot
.23046 .61178 Mdot
.72111 .53667 Mdot
.66493 .37665 Mdot
.53342 .7121 Mdot
.40011 .79574 Mdot
.4984 .86516 Mdot
.48027 .57135 Mdot
.73129 .5508 Mdot
.5086 .25859 Mdot
.59274 .78187 Mdot
.36852 .4859 Mdot
.44264 .78223 Mdot
.36326 .50789 Mdot
.56595 .59583 Mdot
.63292 .3304 Mdot
.50642 .54439 Mdot
.38363 .46511 Mdot
.26882 .39474 Mdot
.7156 .53595 Mdot
.68056 .52418 Mdot
.37006 .45833 Mdot
.70356 .52448 Mdot
.34995 .4909 Mdot
.63037 .34613 Mdot
.82484 .59528 Mdot
.36323 .47978 Mdot
.34513 .4385 Mdot
.72212 .56938 Mdot
.53573 .74117 Mdot
.63155 .30927 Mdot
.43144 .72866 Mdot
.71193 .60556 Mdot
.68905 .52468 Mdot
.45647 .73981 Mdot
.61747 .38247 Mdot
.52053 .58072 Mdot
.61954 .317 Mdot
.3611 .49903 Mdot
.36854 .54027 Mdot
.41839 .518 Mdot
.38179 .51132 Mdot
.40784 .77214 Mdot
.3788 .57061 Mdot
.29963 .65229 Mdot
.33259 .49096 Mdot
.47634 .58148 Mdot
.67266 .53594 Mdot
.32364 .457 Mdot
.44637 .38854 Mdot
.32801 .515 Mdot
.5963 .6793 Mdot
.69187 .49903 Mdot
.77533 .57503 Mdot
.70172 .54157 Mdot
.6417 .36879 Mdot
.71394 .53232 Mdot
.34053 .46906 Mdot
.54037 .68817 Mdot
.62554 .37365 Mdot
.47277 .55118 Mdot
.66025 .37603 Mdot
.33702 .49607 Mdot
.6995 .57565 Mdot
.61752 .38849 Mdot
.34829 .5626 Mdot
.53856 .6854 Mdot
.25193 .35847 Mdot
.51155 .6771 Mdot
.3474 .51491 Mdot
.35396 .51601 Mdot
.50148 .54788 Mdot
.71266 .52648 Mdot
.56132 .64434 Mdot
.64309 .43983 Mdot
.54848 .28868 Mdot
.54934 .68189 Mdot
.37709 .44114 Mdot
.37602 .36274 Mdot
.53293 .68882 Mdot
.22844 .42646 Mdot
.69918 .51556 Mdot
.54945 .70339 Mdot
.41055 .45931 Mdot
.32351 .71514 Mdot
.52274 .27812 Mdot
.59948 .3365 Mdot
.34811 .35315 Mdot
.61053 .36242 Mdot
.66559 .583 Mdot
.5908 .35165 Mdot
.69385 .54725 Mdot
.26619 .47249 Mdot
.48507 .45975 Mdot
.7241 .54142 Mdot
.71344 .57874 Mdot
.61851 .35502 Mdot
.41132 .49336 Mdot
.54738 .47327 Mdot
.30103 .54773 Mdot
.28855 .48806 Mdot
.69087 .49347 Mdot
.55589 .70596 Mdot
.5848 .66421 Mdot
.33374 .43719 Mdot
.53231 .66549 Mdot
.63371 .36231 Mdot
.42056 .41255 Mdot
.46849 .74105 Mdot
.67558 .53294 Mdot
.53869 .45502 Mdot
.40164 .52681 Mdot
.63349 .3358 Mdot
.6362 .36098 Mdot
.71166 .54034 Mdot
.36532 .7446 Mdot
.29557 .53288 Mdot
.60224 .67136 Mdot
.5577 .70241 Mdot
.54082 .69564 Mdot
.54358 .64924 Mdot
.40234 .28743 Mdot
.71879 .52024 Mdot
.5774 .7011 Mdot
.36652 .56102 Mdot
.38439 .52339 Mdot
.51236 .56449 Mdot
.5438 .2736 Mdot
.33787 .55504 Mdot
.30738 .5557 Mdot
.36658 .49563 Mdot
.63559 .38445 Mdot
.24941 .49416 Mdot
.50424 .55584 Mdot
.63242 .39049 Mdot
.63651 .38737 Mdot
.51975 .55512 Mdot
.26423 .47241 Mdot
.32704 .74897 Mdot
.36007 .4586 Mdot
.59529 .70992 Mdot
.64975 .37231 Mdot
.55285 .36517 Mdot
.48062 .5905 Mdot
.39193 .52812 Mdot
.57407 .48273 Mdot
.6343 .3497 Mdot
.59576 .6672 Mdot
.35636 .49968 Mdot
.52788 .58005 Mdot
.51456 .27785 Mdot
.44578 .56684 Mdot
.53282 .58435 Mdot
.55883 .6564 Mdot
.61528 .42078 Mdot
.54801 .7074 Mdot
.59689 .36988 Mdot
.31918 .56596 Mdot
.88895 .53665 Mdot
.64683 .35209 Mdot
.71072 .72313 Mdot
.48919 .46283 Mdot
.35329 .48115 Mdot
.61332 .3729 Mdot
.55127 .62536 Mdot
.7196 .51403 Mdot
.34349 .38811 Mdot
.5521 .65843 Mdot
.51688 .57902 Mdot
.51567 .56432 Mdot
.62317 .35024 Mdot
.56777 .69611 Mdot
.31299 .51089 Mdot
.5339 .67377 Mdot
.67598 .513 Mdot
.3767 .46536 Mdot
.69685 .60464 Mdot
.31226 .46218 Mdot
.53006 .67087 Mdot
.66017 .38287 Mdot
.49018 .26599 Mdot
.3534 .47298 Mdot
.76918 .58101 Mdot
.38208 .52191 Mdot
.68386 .54337 Mdot
.5353 .40674 Mdot
.23967 .61657 Mdot
.37162 .52329 Mdot
.40194 .52323 Mdot
.65701 .51672 Mdot
.37243 .51995 Mdot
.35156 .54769 Mdot
.49371 .71655 Mdot
.53082 .68577 Mdot
.36915 .48797 Mdot
.61185 .34696 Mdot
.27236 .60908 Mdot
.33591 .51632 Mdot
.63732 .56559 Mdot
.2488 .39185 Mdot
.51373 .3835 Mdot
.29842 .44992 Mdot
.30381 .34801 Mdot
.35646 .51271 Mdot
.39166 .52404 Mdot
.36443 .45808 Mdot
.43018 .76086 Mdot
.62114 .36111 Mdot
.65494 .34653 Mdot
.49448 .2526 Mdot
.24953 .39935 Mdot
.51613 .27257 Mdot
.6762 .55287 Mdot
.52144 .46084 Mdot
.50393 .56188 Mdot
.55679 .66139 Mdot
.34452 .52362 Mdot
.66294 .36462 Mdot
.35685 .49185 Mdot
.39394 .48707 Mdot
.63158 .35956 Mdot
.63788 .35432 Mdot
.65602 .4028 Mdot
.50298 .27634 Mdot
.55678 .67926 Mdot
.33023 .48299 Mdot
.50686 .28097 Mdot
.41614 .52189 Mdot
.4114 .37681 Mdot
.55582 .68186 Mdot
.52975 .6684 Mdot
.58605 .6812 Mdot
.36728 .47733 Mdot
.36988 .46108 Mdot
.66855 .52698 Mdot
.5288 .69687 Mdot
.69147 .51908 Mdot
.61245 .37134 Mdot
.62489 .3384 Mdot
.36179 .49967 Mdot
.43033 .49406 Mdot
.5254 .24813 Mdot
.61357 .38463 Mdot
.53682 .59171 Mdot
.49531 .26055 Mdot
.35752 .5366 Mdot
.61086 .36638 Mdot
.53443 .25097 Mdot
.35183 .74428 Mdot
.64485 .61726 Mdot
.49326 .25769 Mdot
.37878 .46115 Mdot
.4164 .63463 Mdot
.32938 .32268 Mdot
.52537 .29514 Mdot
.67286 .53349 Mdot
.38175 .49765 Mdot
.58349 .52118 Mdot
.5038 .28579 Mdot
.37793 .30565 Mdot
.62839 .36528 Mdot
.29594 .47512 Mdot
.36153 .59869 Mdot
.46684 .73526 Mdot
.49043 .26878 Mdot
.52984 .67374 Mdot
.5212 .66788 Mdot
.36791 .52998 Mdot
.51647 .46394 Mdot
.70154 .55628 Mdot
.59779 .35825 Mdot
.65745 .34864 Mdot
.52215 .65642 Mdot
.42012 .40628 Mdot
.61036 .35033 Mdot
.3884 .51496 Mdot
.48152 .24089 Mdot
.39149 .55881 Mdot
.44724 .30342 Mdot
.23177 .58353 Mdot
.30314 .44592 Mdot
.49072 .26413 Mdot
.69595 .5552 Mdot
.70469 .54672 Mdot
.70933 .53464 Mdot
.61786 .3457 Mdot
.33176 .36355 Mdot
.65371 .33949 Mdot
.70348 .76141 Mdot
.50096 .2597 Mdot
.32701 .23572 Mdot
.34484 .55455 Mdot
.35023 .48212 Mdot
.3857 .55404 Mdot
.41437 .50598 Mdot
.35537 .51169 Mdot
.66799 .50939 Mdot
.61914 .32334 Mdot
.66122 .45224 Mdot
.57367 .68005 Mdot
.6235 .78426 Mdot
.63742 .38055 Mdot
.53485 .58355 Mdot
.52989 .25425 Mdot
.25763 .37337 Mdot
.49157 .23986 Mdot
.6055 .37919 Mdot
.34044 .5368 Mdot
.54514 .63017 Mdot
.28501 .28966 Mdot
.33996 .51607 Mdot
.61014 .38145 Mdot
.64359 .31901 Mdot
.34096 .72944 Mdot
.41715 .57506 Mdot
.65033 .45838 Mdot
.37067 .37492 Mdot
.4978 .24113 Mdot
.41055 .48861 Mdot
.28561 .37602 Mdot
.6246 .35928 Mdot
.65252 .35616 Mdot
.54184 .29563 Mdot
.57871 .76169 Mdot
.57647 .69845 Mdot
.5375 .72428 Mdot
.67432 .50386 Mdot
.34613 .48095 Mdot
.61431 .35657 Mdot
.52794 .71126 Mdot
.42613 .35463 Mdot
.70147 .53384 Mdot
.62231 .39244 Mdot
.38292 .51893 Mdot
.37315 .52374 Mdot
.51323 .2714 Mdot
.55318 .44195 Mdot
.30108 .54771 Mdot
.69946 .73078 Mdot
.38864 .38022 Mdot
.48972 .46244 Mdot
.36494 .49129 Mdot
.5474 .64968 Mdot
.51977 .55576 Mdot
.5354 .26544 Mdot
.41621 .54391 Mdot
.43724 .80634 Mdot
.56868 .71239 Mdot
.69297 .51994 Mdot
.53489 .567 Mdot
.28121 .39713 Mdot
.38249 .51752 Mdot
.36306 .50727 Mdot
.40545 .52469 Mdot
.37058 .78447 Mdot
.63678 .33128 Mdot
.54022 .65287 Mdot
.50263 .27043 Mdot
.54059 .66266 Mdot
.59606 .37414 Mdot
.54166 .45569 Mdot
.33183 .47675 Mdot
.57944 .70712 Mdot
.53925 .67196 Mdot
.68247 .54049 Mdot
.71623 .54208 Mdot
.66516 .34604 Mdot
.3794 .49766 Mdot
.50355 .56245 Mdot
.57017 .70535 Mdot
.60281 .33674 Mdot
.51475 .27057 Mdot
.66456 .58361 Mdot
.33384 .48715 Mdot
.62227 .35425 Mdot
.31876 .56633 Mdot
.56893 .67718 Mdot
.624 .38675 Mdot
.52324 .58246 Mdot
.54146 .28253 Mdot
.36853 .54161 Mdot
.69916 .39301 Mdot
.53075 .58077 Mdot
.35731 .47462 Mdot
.24529 .60033 Mdot
.51738 .46404 Mdot
.54667 .59492 Mdot
.61839 .33553 Mdot
.52125 .57698 Mdot
.53475 .64894 Mdot
.30384 .69583 Mdot
.65063 .34811 Mdot
.3681 .61433 Mdot
.47615 .4546 Mdot
.3748 .46036 Mdot
.55534 .65712 Mdot
.49775 .33388 Mdot
.66928 .74118 Mdot
.33956 .32327 Mdot
.34327 .49715 Mdot
.61056 .36178 Mdot
.51741 .27723 Mdot
.68106 .52284 Mdot
.72788 .51205 Mdot
.46182 .29195 Mdot
.64719 .38439 Mdot
.34421 .52388 Mdot
.55519 .70554 Mdot
.69752 .52097 Mdot
.30622 .61091 Mdot
.64813 .32871 Mdot
.60904 .3486 Mdot
.38676 .54511 Mdot
.51798 .27311 Mdot
.57272 .52497 Mdot
.64149 .33343 Mdot
.62401 .32157 Mdot
.48853 .7041 Mdot
.50148 .23973 Mdot
.40926 .51284 Mdot
.33446 .43691 Mdot
.36358 .55405 Mdot
.66543 .77534 Mdot
.51758 .57614 Mdot
.57425 .67792 Mdot
.36089 .51899 Mdot
.67932 .44093 Mdot
.64252 .34315 Mdot
.37109 .37541 Mdot
.67102 .55305 Mdot
.717 .53711 Mdot
.6165 .36816 Mdot
.3512 .49659 Mdot
.66733 .48598 Mdot
.5041 .24714 Mdot
.40977 .51396 Mdot
.38036 .46386 Mdot
.51836 .67133 Mdot
.67864 .50801 Mdot
.26344 .60387 Mdot
.68031 .51841 Mdot
.70722 .51348 Mdot
.51414 .63988 Mdot
.3679 .53047 Mdot
.63093 .38258 Mdot
.64027 .40125 Mdot
.4176 .49333 Mdot
.55963 .35416 Mdot
.58164 .68647 Mdot
.6008 .31445 Mdot
.4287 .80765 Mdot
.33868 .54631 Mdot
.53666 .56624 Mdot
.57585 .56817 Mdot
.72437 .55442 Mdot
.36692 .52486 Mdot
.56075 .66214 Mdot
.62966 .32413 Mdot
.61155 .35518 Mdot
.333 .55268 Mdot
.70709 .54626 Mdot
.53982 .25773 Mdot
.63548 .3652 Mdot
.43004 .39401 Mdot
.33861 .49814 Mdot
.75514 .53008 Mdot
.63468 .36894 Mdot
.166 .44433 Mdot
.68172 .44303 Mdot
.53681 .69341 Mdot
.39709 .53067 Mdot
.52052 .65242 Mdot
.50103 .24412 Mdot
.59906 .32948 Mdot
.68749 .54892 Mdot
.3832 .58394 Mdot
.81702 .43565 Mdot
.61766 .3493 Mdot
.55224 .66854 Mdot
.35546 .5261 Mdot
.45253 .7313 Mdot
.36724 .48316 Mdot
.40876 .26054 Mdot
.51213 .29243 Mdot
.6653 .58124 Mdot
.69877 .55247 Mdot
.40156 .52095 Mdot
.51775 .2849 Mdot
.64468 .40145 Mdot
.63081 .35928 Mdot
.8228 .49456 Mdot
.53072 .58496 Mdot
.58894 .37873 Mdot
.36298 .47656 Mdot
.60055 .34601 Mdot
.43598 .63604 Mdot
.71272 .54237 Mdot
.36275 .55284 Mdot
.63465 .396 Mdot
.63873 .75766 Mdot
.37254 .36935 Mdot
.34025 .49814 Mdot
.42034 .47671 Mdot
.69137 .54551 Mdot
.59186 .78233 Mdot
.63003 .32942 Mdot
.41669 .53253 Mdot
.67584 .55466 Mdot
.27512 .46317 Mdot
.63288 .44885 Mdot
.55694 .67973 Mdot
.62621 .39738 Mdot
.69482 .50427 Mdot
.29859 .47329 Mdot
.53828 .25979 Mdot
.65871 .3364 Mdot
.65206 .38822 Mdot
.37008 .46687 Mdot
.41111 .52656 Mdot
.41956 .47392 Mdot
.5725 .66092 Mdot
.70166 .51251 Mdot
.39829 .48972 Mdot
.40637 .37055 Mdot
.40989 .49857 Mdot
.69666 .50881 Mdot
.85153 .60479 Mdot
.34457 .53874 Mdot
.33586 .48583 Mdot
.4471 .74192 Mdot
.56837 .6459 Mdot
.52415 .66958 Mdot
.39621 .38018 Mdot
.38227 .48951 Mdot
.50042 .48112 Mdot
.55658 .67561 Mdot
.54916 .66711 Mdot
.50138 .48032 Mdot
.36755 .46378 Mdot
.51606 .69695 Mdot
.69991 .5219 Mdot
.71705 .53798 Mdot
.53963 .69343 Mdot
.39583 .55351 Mdot
.67883 .55306 Mdot
.38042 .74032 Mdot
.61035 .38503 Mdot
.28192 .38078 Mdot
.53641 .67283 Mdot
.36729 .36398 Mdot
.70138 .51744 Mdot
.18886 .46427 Mdot
.2236 .41812 Mdot
.327 .53273 Mdot
.36886 .5278 Mdot
.51443 .25783 Mdot
.3737 .5841 Mdot
.51545 .55414 Mdot
.7102 .53391 Mdot
.5678 .50732 Mdot
.5556 .68728 Mdot
.38004 .48844 Mdot
.36165 .32402 Mdot
.18878 .5208 Mdot
.39709 .4379 Mdot
.54625 .67338 Mdot
.54878 .69004 Mdot
.60673 .34755 Mdot
.60108 .37427 Mdot
.32969 .48155 Mdot
.69957 .54764 Mdot
.543 .69962 Mdot
.68888 .50823 Mdot
.62562 .36011 Mdot
.63718 .37864 Mdot
.50607 .55676 Mdot
.28691 .49559 Mdot
.621 .36865 Mdot
.63181 .54705 Mdot
.40707 .37159 Mdot
.52553 .69488 Mdot
.72626 .74847 Mdot
.19342 .44645 Mdot
.47977 .7751 Mdot
.5161 .2778 Mdot
.26832 .46769 Mdot
.66787 .53461 Mdot
.40271 .51738 Mdot
.36749 .50873 Mdot
.52396 .56982 Mdot
.66797 .53872 Mdot
.51599 .24984 Mdot
.71517 .5399 Mdot
.53906 .27281 Mdot
.65738 .35449 Mdot
.33935 .51902 Mdot
.33019 .51704 Mdot
.68097 .52623 Mdot
.60179 .3594 Mdot
.61928 .38892 Mdot
.52876 .27835 Mdot
.25481 .37652 Mdot
.6239 .35176 Mdot
.53721 .67125 Mdot
.3452 .62454 Mdot
.51668 .56556 Mdot
.35561 .50008 Mdot
.29886 .35025 Mdot
.29391 .68211 Mdot
.41918 .51403 Mdot
.53455 .56966 Mdot
.81961 .6639 Mdot
.33236 .51063 Mdot
.80921 .3882 Mdot
.50508 .56295 Mdot
.56607 .64702 Mdot
.62318 .38156 Mdot
.53325 .58254 Mdot
.24794 .50769 Mdot
.68674 .36609 Mdot
.42035 .5021 Mdot
.57736 .69833 Mdot
.58289 .67073 Mdot
.54137 .45823 Mdot
.66231 .77751 Mdot
.50325 .27141 Mdot
.50693 .24932 Mdot
.64484 .34185 Mdot
.68689 .59133 Mdot
.37593 .56406 Mdot
.50558 .25256 Mdot
.52 .71383 Mdot
.40004 .5336 Mdot
.52067 .46395 Mdot
.55129 .47791 Mdot
.53135 .6522 Mdot
.31616 .46707 Mdot
.64419 .34266 Mdot
.55225 .67073 Mdot
.54405 .46749 Mdot
.38137 .55031 Mdot
.55575 .68409 Mdot
.70991 .51905 Mdot
.47828 .52707 Mdot
.53343 .67008 Mdot
.35214 .38717 Mdot
.68557 .52739 Mdot
.5273 .45986 Mdot
.35762 .24325 Mdot
.1446 .51732 Mdot
.70664 .54399 Mdot
.61215 .38079 Mdot
.61534 .35679 Mdot
.62675 .34742 Mdot
.56135 .65372 Mdot
.64148 .35198 Mdot
.57661 .68774 Mdot
.73583 .54686 Mdot
.2592 .39575 Mdot
.51487 .26481 Mdot
.52165 .34124 Mdot
.53758 .68902 Mdot
.69214 .76646 Mdot
.61862 .84171 Mdot
.41229 .50586 Mdot
.72504 .53934 Mdot
.49762 .27425 Mdot
.3841 .38924 Mdot
.51347 .25578 Mdot
.61695 .38192 Mdot
.2744 .39588 Mdot
.35117 .48974 Mdot
.6362 .59531 Mdot
.51822 .27666 Mdot
.54819 .66586 Mdot
.37107 .47326 Mdot
.61493 .39665 Mdot
.50307 .24459 Mdot
.52794 .27467 Mdot
.35557 .50979 Mdot
.57555 .65554 Mdot
.61913 .38685 Mdot
.66848 .5041 Mdot
.4856 .23421 Mdot
.43508 .54676 Mdot
.33384 .51668 Mdot
.32631 .51929 Mdot
.37818 .36923 Mdot
.6885 .59275 Mdot
.6877 .52835 Mdot
.38005 .30719 Mdot
.63118 .3359 Mdot
.33995 .32106 Mdot
.69092 .72616 Mdot
.50042 .33129 Mdot
.51717 .57522 Mdot
.51523 .57545 Mdot
.34263 .50917 Mdot
.53044 .85018 Mdot
.46545 .55042 Mdot
.68612 .56063 Mdot
.5218 .56539 Mdot
.60622 .38284 Mdot
.53622 .70232 Mdot
.37472 .59643 Mdot
.34111 .55502 Mdot
.66713 .50591 Mdot
.62826 .35476 Mdot
.46494 .85932 Mdot
.50215 .26367 Mdot
.38966 .39199 Mdot
.38008 .50148 Mdot
.34704 .5063 Mdot
.69583 .53502 Mdot
.68453 .54755 Mdot
.48732 .70216 Mdot
.5029 .37314 Mdot
.70306 .60713 Mdot
.67775 .49035 Mdot
.46241 .86003 Mdot
.57166 .58397 Mdot
.56046 .69435 Mdot
.51996 .55251 Mdot
.70218 .55532 Mdot
.36226 .51547 Mdot
.5704 .64833 Mdot
.46493 .55582 Mdot
.57204 .64064 Mdot
.51325 .46634 Mdot
.42525 .38809 Mdot
.37802 .52988 Mdot
.544 .63558 Mdot
.55304 .67594 Mdot
.58437 .71652 Mdot
.5148 .55779 Mdot
.36806 .49412 Mdot
.41889 .52978 Mdot
.3288 .499 Mdot
.47684 .65032 Mdot
.33948 .50861 Mdot
.68593 .73075 Mdot
.40707 .38794 Mdot
.61516 .20545 Mdot
.33193 .50394 Mdot
.71277 .51945 Mdot
.3465 .52273 Mdot
.52147 .28601 Mdot
.3598 .54305 Mdot
.50674 .4666 Mdot
.6976 .52474 Mdot
.44435 .79464 Mdot
.67054 .34245 Mdot
.33499 .52227 Mdot
.52069 .24006 Mdot
.77395 .66517 Mdot
.37934 .31125 Mdot
.48882 .7027 Mdot
.53413 .67409 Mdot
.63312 .32056 Mdot
.71097 .55542 Mdot
.64144 .37083 Mdot
.31279 .49896 Mdot
.50899 .55157 Mdot
.31147 .23132 Mdot
.3782 .3466 Mdot
.36109 .51759 Mdot
.2929 .52645 Mdot
.53204 .65963 Mdot
.64428 .34579 Mdot
.51442 .77921 Mdot
.39107 .55172 Mdot
.54209 .2873 Mdot
.5058 .28394 Mdot
.59538 .29778 Mdot
.50357 .61584 Mdot
.45647 .63787 Mdot
.69473 .53327 Mdot
.61548 .34787 Mdot
.49773 .27871 Mdot
.55626 .73807 Mdot
.7117 .55295 Mdot
.72374 .55548 Mdot
.67885 .50679 Mdot
.33897 .49051 Mdot
.5082 .56278 Mdot
.50215 .64359 Mdot
.52796 .58275 Mdot
.37022 .55739 Mdot
.65083 .38923 Mdot
.52234 .58091 Mdot
.52039 .26336 Mdot
.70246 .50815 Mdot
.63691 .38254 Mdot
.35091 .51672 Mdot
.56022 .67467 Mdot
.45362 .32762 Mdot
.69208 .43202 Mdot
.51807 .46313 Mdot
.51818 .46307 Mdot
.56737 .71959 Mdot
.57959 .5419 Mdot
.72408 .57439 Mdot
.33002 .72302 Mdot
.47658 .23817 Mdot
.41346 .558 Mdot
.56637 .35242 Mdot
.65246 .33738 Mdot
.62749 .37263 Mdot
.35072 .48656 Mdot
.60703 .33633 Mdot
.37637 .48715 Mdot
.61763 .33534 Mdot
.66558 .75372 Mdot
.32268 .53873 Mdot
.63242 .36493 Mdot
.40152 .58223 Mdot
.35295 .47332 Mdot
.54326 .65333 Mdot
.63892 .32517 Mdot
.32739 .53343 Mdot
.46045 .13994 Mdot
.68188 .53864 Mdot
.51439 .55884 Mdot
.46738 .42808 Mdot
.70679 .52211 Mdot
.57368 .6972 Mdot
.38567 .50422 Mdot
.49973 .25752 Mdot
.55477 .69532 Mdot
.63841 .30386 Mdot
.52203 .27422 Mdot
.42539 .41458 Mdot
.5489 .6967 Mdot
.51597 .56803 Mdot
.537 .28871 Mdot
.41817 .49773 Mdot
.62851 .3698 Mdot
.68966 .43818 Mdot
.53572 .57462 Mdot
.35482 .48951 Mdot
.61262 .39327 Mdot
.71511 .53444 Mdot
.35206 .53256 Mdot
.6133 .3563 Mdot
.52849 .55842 Mdot
.34138 .47755 Mdot
.37437 .47886 Mdot
.56381 .77279 Mdot
.54483 .41706 Mdot
.51734 .26423 Mdot
.5327 .71105 Mdot
.36168 .55927 Mdot
.5195 .28364 Mdot
.66702 .43657 Mdot
.33144 .45565 Mdot
.57213 .70716 Mdot
.37107 .73873 Mdot
.59844 .35537 Mdot
.7072 .54859 Mdot
.66306 .38104 Mdot
.49693 .24635 Mdot
.67258 .8231 Mdot
.51251 .55378 Mdot
.34766 .45607 Mdot
.34798 .54773 Mdot
.61031 .31967 Mdot
.5523 .67908 Mdot
.69751 .60892 Mdot
.37122 .5416 Mdot
.2964 .52194 Mdot
.35585 .5047 Mdot
.69773 .38091 Mdot
.56718 .65555 Mdot
.35633 .50214 Mdot
.43089 .51903 Mdot
.34779 .55059 Mdot
.52544 .24524 Mdot
.32259 .23996 Mdot
.4041 .48446 Mdot
.90481 .5017 Mdot
.51247 .5462 Mdot
.6324 .35457 Mdot
.35534 .38735 Mdot
.46974 .42358 Mdot
.54498 .17278 Mdot
.57802 .69224 Mdot
.59217 .71443 Mdot
.63642 .37807 Mdot
.47563 .31403 Mdot
.57413 .5377 Mdot
.37596 .47761 Mdot
.38279 .50614 Mdot
.61705 .38197 Mdot
.60226 .33641 Mdot
.51123 .54784 Mdot
.37089 .4559 Mdot
.31192 .46488 Mdot
.65917 .3833 Mdot
.33811 .51215 Mdot
.28084 .66599 Mdot
.72799 .52926 Mdot
.53376 .68849 Mdot
.67961 .5232 Mdot
.72317 .51881 Mdot
.49464 .78154 Mdot
.38711 .3772 Mdot
.6723 .50493 Mdot
.71186 .56901 Mdot
.50062 .33747 Mdot
.46481 .73879 Mdot
.52947 .24821 Mdot
.47522 .54446 Mdot
.62877 .3407 Mdot
.36935 .49621 Mdot
.56498 .65369 Mdot
.44152 .22947 Mdot
.727 .61444 Mdot
.23539 .48885 Mdot
.40846 .51343 Mdot
.63651 .34118 Mdot
.53655 .57216 Mdot
.33241 .45466 Mdot
.3325 .32199 Mdot
.34313 .50246 Mdot
.59753 .36447 Mdot
.46794 .7401 Mdot
.66646 .46586 Mdot
.69823 .48812 Mdot
.58084 .63208 Mdot
.34655 .52348 Mdot
.57059 .66434 Mdot
.692 .49573 Mdot
.51183 .28069 Mdot
.50778 .25987 Mdot
.3354 .52352 Mdot
.48924 .4632 Mdot
.47236 .24872 Mdot
.37172 .47529 Mdot
.37068 .46562 Mdot
.5208 .57555 Mdot
.37236 .46549 Mdot
.42146 .52675 Mdot
.40191 .49585 Mdot
.41496 .52247 Mdot
.70816 .5537 Mdot
.49244 .76887 Mdot
.36133 .45494 Mdot
.3218 .48292 Mdot
.7062 .50178 Mdot
.31716 .48804 Mdot
.70333 .54138 Mdot
.73532 .59181 Mdot
.66882 .51479 Mdot
.5085 .2616 Mdot
.60939 .39283 Mdot
.53957 .76152 Mdot
.5443 .70015 Mdot
.72011 .52928 Mdot
.54295 .27639 Mdot
.70984 .53882 Mdot
.62038 .33886 Mdot
.65586 .47473 Mdot
.53508 .60662 Mdot
.43397 .4005 Mdot
.46118 .74867 Mdot
.75493 .51214 Mdot
.60475 .34278 Mdot
.54213 .69707 Mdot
.64711 .57409 Mdot
.40227 .51611 Mdot
.50145 .2667 Mdot
.34345 .5094 Mdot
.70497 .51048 Mdot
.63172 .34097 Mdot
.51409 .74052 Mdot
.51719 .26314 Mdot
.75538 .72761 Mdot
.66326 .36472 Mdot
.35034 .54549 Mdot
.70251 .49908 Mdot
.63625 .51635 Mdot
.68626 .54592 Mdot
.25883 .39196 Mdot
.57799 .55541 Mdot
.44537 .25204 Mdot
.54773 .69225 Mdot
.53057 .59124 Mdot
.16838 .5956 Mdot
.74486 .65428 Mdot
.56568 .67528 Mdot
.62659 .42201 Mdot
.33582 .502 Mdot
.40709 .49932 Mdot
.2888 .5071 Mdot
.57287 .64536 Mdot
.40511 .52547 Mdot
.51143 .55901 Mdot
.39193 .37075 Mdot
.52329 .60124 Mdot
.65137 .32555 Mdot
.37369 .48623 Mdot
.68984 .49327 Mdot
.7218 .53102 Mdot
.5113 .57689 Mdot
.67859 .51471 Mdot
.34531 .46878 Mdot
.54084 .69103 Mdot
.5469 .47215 Mdot
.49918 .24696 Mdot
.72247 .70651 Mdot
.48568 .28151 Mdot
.49892 .23252 Mdot
.33898 .54717 Mdot
.63478 .38071 Mdot
.80765 .4071 Mdot
.40439 .51777 Mdot
.55515 .67305 Mdot
.35292 .54865 Mdot
.40176 .49177 Mdot
.34276 .46615 Mdot
.61601 .34763 Mdot
.37153 .36715 Mdot
.33825 .51301 Mdot
.68013 .49726 Mdot
.49956 .47828 Mdot
.34145 .55609 Mdot
.58219 .49483 Mdot
.50916 .46689 Mdot
.751 .51702 Mdot
.52062 .68206 Mdot
.62905 .3822 Mdot
.55467 .68931 Mdot
.5716 .63469 Mdot
.57354 .69699 Mdot
.51002 .62564 Mdot
.32033 .71396 Mdot
.80595 .37763 Mdot
.44085 .63704 Mdot
.46142 .7533 Mdot
.56734 .62746 Mdot
.73509 .34613 Mdot
.56512 .66924 Mdot
.57519 .6957 Mdot
.83161 .57406 Mdot
.58087 .67201 Mdot
.36196 .49881 Mdot
.32828 .51901 Mdot
.39458 .79279 Mdot
.51665 .22666 Mdot
.35545 .4763 Mdot
.41692 .51954 Mdot
.50184 .28192 Mdot
.57532 .76088 Mdot
.52889 .55433 Mdot
.39443 .39626 Mdot
.53274 .5885 Mdot
.35506 .51039 Mdot
.36942 .53584 Mdot
.39418 .57051 Mdot
.18849 .54892 Mdot
.4539 .26489 Mdot
.58439 .67268 Mdot
.42483 .53878 Mdot
.74078 .48988 Mdot
.38853 .52914 Mdot
.36598 .54925 Mdot
.3479 .46362 Mdot
.63106 .38258 Mdot
.55158 .71168 Mdot
.30436 .55232 Mdot
.74462 .6775 Mdot
.38128 .51962 Mdot
.49442 .29043 Mdot
.55297 .27272 Mdot
.3524 .49605 Mdot
.58356 .68228 Mdot
.40887 .50427 Mdot
.52741 .68618 Mdot
.55346 .69802 Mdot
.29355 .49533 Mdot
.49945 .664 Mdot
.538 .70336 Mdot
.37701 .47866 Mdot
.60181 .35455 Mdot
.70368 .72811 Mdot
.35394 .49067 Mdot
.52341 .26759 Mdot
.36411 .52693 Mdot
.52199 .24238 Mdot
.39017 .47226 Mdot
.52497 .58051 Mdot
.23457 .61825 Mdot
.65326 .35532 Mdot
.48783 .24121 Mdot
.6031 .34148 Mdot
.38669 .5637 Mdot
.52285 .64049 Mdot
.66665 .46959 Mdot
.46335 .2809 Mdot
.51975 .57489 Mdot
.39985 .29469 Mdot
.50632 .48893 Mdot
.66927 .5334 Mdot
.53931 .65236 Mdot
.48457 .75528 Mdot
.57949 .49182 Mdot
.65241 .32509 Mdot
.61418 .3904 Mdot
.62573 .44325 Mdot
.82487 .59498 Mdot
.33303 .50168 Mdot
.58597 .51726 Mdot
.29389 .64806 Mdot
.37048 .58393 Mdot
.41862 .57852 Mdot
.65358 .38705 Mdot
.35588 .47604 Mdot
.3659 .34669 Mdot
.61858 .35644 Mdot
.51906 .24667 Mdot
.57448 .67604 Mdot
.53141 .28274 Mdot
.66288 .63183 Mdot
.49269 .71579 Mdot
.62053 .36468 Mdot
.41319 .52064 Mdot
.35562 .47901 Mdot
.56425 .64444 Mdot
.30645 .6103 Mdot
.53035 .68498 Mdot
.49638 .25652 Mdot
.64958 .34364 Mdot
.39532 .16745 Mdot
.35662 .52761 Mdot
.54081 .67071 Mdot
.67161 .34579 Mdot
.37435 .52128 Mdot
.70913 .546 Mdot
.40371 .52842 Mdot
.54183 .66458 Mdot
.37372 .46568 Mdot
.54894 .69357 Mdot
.6052 .35494 Mdot
.33283 .52153 Mdot
.35804 .5361 Mdot
.38408 .30346 Mdot
.51686 .25048 Mdot
.53291 .6966 Mdot
.35929 .35148 Mdot
.36359 .55407 Mdot
.31701 .33182 Mdot
.33752 .51738 Mdot
.45873 .73879 Mdot
.38174 .44498 Mdot
.51118 .56124 Mdot
.35302 .54923 Mdot
.35214 .49133 Mdot
.30676 .60839 Mdot
.43074 .63521 Mdot
.47783 .65308 Mdot
.71575 .54413 Mdot
.55316 .65342 Mdot
.61551 .36083 Mdot
.63479 .32298 Mdot
.64206 .35816 Mdot
.50141 .28904 Mdot
.42054 .49649 Mdot
.35927 .48708 Mdot
.69915 .56569 Mdot
.50326 .25632 Mdot
.54319 .67611 Mdot
.5097 .26605 Mdot
.3833 .379 Mdot
.52582 .26605 Mdot
.51663 .55356 Mdot
.67566 .44615 Mdot
.28932 .67488 Mdot
.53165 .26121 Mdot
.53618 .69143 Mdot
.4912 .47876 Mdot
.36583 .58246 Mdot
.63956 .78182 Mdot
.5394 .29025 Mdot
.64904 .43072 Mdot
.33671 .47926 Mdot
.34264 .38512 Mdot
.70269 .53909 Mdot
.53255 .28282 Mdot
.67667 .5082 Mdot
.40853 .50477 Mdot
.60538 .66746 Mdot
.55404 .66374 Mdot
.72717 .52532 Mdot
.36727 .55134 Mdot
.53192 .28319 Mdot
.62336 .36762 Mdot
.46472 .73696 Mdot
.73418 .54088 Mdot
.46366 .33419 Mdot
.34064 .32251 Mdot
.64186 .33785 Mdot
.44631 .70909 Mdot
.67076 .51333 Mdot
.42323 .54155 Mdot
.45627 .53708 Mdot
.38546 .55858 Mdot
.62086 .38945 Mdot
.6276 .37344 Mdot
.76776 .53951 Mdot
.36221 .53767 Mdot
.35399 .4563 Mdot
.53129 .70568 Mdot
.6453 .3388 Mdot
.57175 .69817 Mdot
.53499 .63913 Mdot
.61164 .37905 Mdot
.52805 .68318 Mdot
.5233 .27505 Mdot
.31353 .36568 Mdot
.67072 .51221 Mdot
.69958 .5514 Mdot
.62016 .36726 Mdot
.65397 .37179 Mdot
.63573 .38046 Mdot
.38943 .5488 Mdot
.55876 .70054 Mdot
.39789 .5246 Mdot
.34948 .52477 Mdot
.53798 .56397 Mdot
.51373 .67301 Mdot
.38949 .53708 Mdot
.5518 .4825 Mdot
.54109 .29191 Mdot
.63438 .36001 Mdot
.69437 .51076 Mdot
.4477 .31805 Mdot
.67206 .50017 Mdot
.35501 .55431 Mdot
.6418 .76272 Mdot
.5569 .65499 Mdot
.51404 .25656 Mdot
.50832 .46533 Mdot
.51604 .26053 Mdot
.72782 .52805 Mdot
.55937 .72194 Mdot
.42206 .41018 Mdot
.35631 .53706 Mdot
.37997 .36868 Mdot
.36106 .26073 Mdot
.69783 .71747 Mdot
.70433 .51456 Mdot
.41072 .50586 Mdot
.5103 .5704 Mdot
.33222 .72628 Mdot
.35627 .48667 Mdot
.32556 .53809 Mdot
.48837 .44305 Mdot
.34109 .545 Mdot
.58794 .69192 Mdot
.5239 .46673 Mdot
.41325 .49515 Mdot
.39634 .55746 Mdot
.81452 .52015 Mdot
.34591 .47668 Mdot
.34832 .53323 Mdot
.36863 .50313 Mdot
.39986 .53077 Mdot
.52018 .65333 Mdot
.53775 .45114 Mdot
.6961 .49738 Mdot
.31333 .3655 Mdot
.67792 .50439 Mdot
.61706 .37328 Mdot
.48736 .36067 Mdot
.52179 .67434 Mdot
.51665 .26043 Mdot
.59404 .51568 Mdot
.27449 .3996 Mdot
.60574 .3488 Mdot
.40329 .28328 Mdot
.54044 .26077 Mdot
.3487 .58036 Mdot
.49684 .24506 Mdot
.63953 .39622 Mdot
.70758 .5454 Mdot
.34145 .53759 Mdot
.56963 .70438 Mdot
.53282 .66988 Mdot
.37455 .56192 Mdot
.74242 .69063 Mdot
.7083 .54929 Mdot
.55437 .35161 Mdot
.34284 .48826 Mdot
.36311 .55287 Mdot
.52457 .67504 Mdot
.64184 .34413 Mdot
.50715 .48708 Mdot
.53511 .25995 Mdot
.38604 .52651 Mdot
.41568 .50946 Mdot
.38292 .37762 Mdot
.71972 .53911 Mdot
.52436 .56184 Mdot
.36507 .48464 Mdot
.39479 .38897 Mdot
.40311 .53241 Mdot
.39736 .56453 Mdot
.59974 .36279 Mdot
.29388 .50883 Mdot
.3745 .53738 Mdot
.57178 .62334 Mdot
.67074 .51568 Mdot
.55501 .67971 Mdot
.59556 .69578 Mdot
.52289 .57895 Mdot
.68211 .53707 Mdot
.3868 .54127 Mdot
.72507 .54878 Mdot
.40477 .49576 Mdot
.34703 .51758 Mdot
.70671 .51627 Mdot
.57083 .69563 Mdot
.68706 .60309 Mdot
.49271 .76803 Mdot
.39511 .48803 Mdot
.36773 .52521 Mdot
.517 .22681 Mdot
.45797 .21459 Mdot
.36503 .54009 Mdot
.54009 .6965 Mdot
.37316 .52443 Mdot
.67817 .54496 Mdot
.50436 .27272 Mdot
.55822 .67076 Mdot
.63473 .33378 Mdot
.60632 .3547 Mdot
.67009 .38217 Mdot
.51605 .55304 Mdot
.35488 .45739 Mdot
.53237 .71066 Mdot
.51288 .67308 Mdot
.32778 .3726 Mdot
.63267 .35591 Mdot
.5097 .27545 Mdot
.36424 .47604 Mdot
.3744 .58537 Mdot
.71859 .51437 Mdot
.90823 .48803 Mdot
.41842 .40711 Mdot
.55009 .28589 Mdot
.50708 .38154 Mdot
.52604 .57364 Mdot
.34115 .4816 Mdot
.52426 .28495 Mdot
.60997 .37216 Mdot
.40749 .49969 Mdot
.38813 .44961 Mdot
.66473 .43447 Mdot
.64638 .37893 Mdot
.72833 .54543 Mdot
.62395 .33302 Mdot
.53588 .25329 Mdot
.51465 .55417 Mdot
.54307 .65661 Mdot
.34728 .49763 Mdot
.32038 .45806 Mdot
.62989 .34567 Mdot
.50088 .55189 Mdot
.32891 .51198 Mdot
.55387 .65127 Mdot
.63859 .35293 Mdot
.35933 .51028 Mdot
.34406 .72966 Mdot
.54135 .76165 Mdot
.63015 .33874 Mdot
.38776 .51146 Mdot
.349 .59783 Mdot
.64313 .38233 Mdot
.63806 .39566 Mdot
.4124 .50846 Mdot
.53487 .28472 Mdot
.37918 .53086 Mdot
.69773 .54661 Mdot
.37308 .36334 Mdot
.68083 .52947 Mdot
.33022 .32162 Mdot
.41285 .53541 Mdot
.44617 .49482 Mdot
.557 .62991 Mdot
.48061 .25107 Mdot
.2033 .43055 Mdot
.34695 .55279 Mdot
.59086 .75351 Mdot
.36832 .36355 Mdot
.44304 .41462 Mdot
.60027 .73905 Mdot
.53841 .26713 Mdot
.70935 .5352 Mdot
.33901 .5257 Mdot
.67883 .59532 Mdot
.53694 .27083 Mdot
.32837 .32255 Mdot
.39384 .50933 Mdot
.54827 .6707 Mdot
.34016 .49229 Mdot
.54471 .65801 Mdot
.37482 .51138 Mdot
.5679 .77403 Mdot
.47321 .24582 Mdot
.25837 .39241 Mdot
.3501 .58047 Mdot
.63686 .51474 Mdot
.46124 .74945 Mdot
.51543 .27376 Mdot
.3826 .47356 Mdot
.53045 .57035 Mdot
.7153 .53956 Mdot
.62263 .51067 Mdot
.63755 .3773 Mdot
.68054 .49785 Mdot
.56716 .69226 Mdot
.6287 .40264 Mdot
.50369 .5642 Mdot
.3112 .43377 Mdot
.53135 .28419 Mdot
.68256 .53887 Mdot
.35108 .49363 Mdot
.38184 .5582 Mdot
.69799 .3812 Mdot
.3124 .24206 Mdot
.52487 .64489 Mdot
.78603 .70006 Mdot
.5541 .72196 Mdot
.51064 .24904 Mdot
.60088 .36796 Mdot
.36413 .51567 Mdot
.37665 .49548 Mdot
.64742 .37642 Mdot
.56187 .64464 Mdot
.49799 .2341 Mdot
.44713 .2441 Mdot
.68326 .5583 Mdot
.31998 .25689 Mdot
.55834 .66688 Mdot
.32122 .25595 Mdot
.5298 .32163 Mdot
.52052 .73361 Mdot
.23728 .38983 Mdot
.70398 .5225 Mdot
.31941 .25657 Mdot
.54549 .66914 Mdot
.3329 .49463 Mdot
.51796 .56871 Mdot
.50484 .55136 Mdot
.57022 .66739 Mdot
.61943 .38369 Mdot
.54052 .26366 Mdot
.34225 .49151 Mdot
.32305 .43593 Mdot
.30636 .61112 Mdot
.65646 .35346 Mdot
.29948 .53891 Mdot
.69608 .51667 Mdot
.37224 .52272 Mdot
.49808 .27765 Mdot
.70344 .52401 Mdot
.52716 .58458 Mdot
.27733 .39526 Mdot
.3858 .50474 Mdot
.49878 .46726 Mdot
.699 .53887 Mdot
.45434 .21534 Mdot
.36085 .53632 Mdot
.67084 .51323 Mdot
.3182 .45966 Mdot
.74826 .49253 Mdot
.53228 .47985 Mdot
.74378 .65433 Mdot
.6672 .36976 Mdot
.61783 .33562 Mdot
.458 .14617 Mdot
.55632 .1864 Mdot
.6952 .50176 Mdot
.53574 .56617 Mdot
.32062 .23804 Mdot
.67358 .51421 Mdot
.3736 .54289 Mdot
.334 .51202 Mdot
.46829 .74043 Mdot
.38898 .58326 Mdot
.51456 .5475 Mdot
.48216 .58622 Mdot
.35209 .46697 Mdot
.30404 .54876 Mdot
.34798 .52974 Mdot
.58228 .66695 Mdot
.6975 .51913 Mdot
.25939 .73779 Mdot
.7209 .54874 Mdot
.4423 .48964 Mdot
.62915 .34061 Mdot
.6614 .38871 Mdot
.35186 .49729 Mdot
.45533 .5772 Mdot
.47123 .86449 Mdot
.3343 .51585 Mdot
.50774 .46548 Mdot
.34342 .32133 Mdot
.42462 .51008 Mdot
.56165 .7106 Mdot
.31375 .46178 Mdot
.51867 .69457 Mdot
.7071 .52628 Mdot
.53827 .26799 Mdot
.47827 .25748 Mdot
.70764 .53635 Mdot
.37516 .49515 Mdot
.4823 .26916 Mdot
.34964 .50576 Mdot
.34612 .48148 Mdot
.38888 .38712 Mdot
.4949 .26877 Mdot
.62949 .38506 Mdot
.50967 .26019 Mdot
.58016 .68893 Mdot
.84211 .62389 Mdot
.51105 .27021 Mdot
.46504 .73899 Mdot
.36454 .3541 Mdot
.32887 .23966 Mdot
.53214 .66671 Mdot
.49904 .24612 Mdot
.71254 .5314 Mdot
.43854 .42874 Mdot
.44095 .74385 Mdot
.67165 .5009 Mdot
.36113 .48527 Mdot
.52086 .65136 Mdot
.55984 .72083 Mdot
.66921 .49786 Mdot
.54059 .65494 Mdot
.41054 .47385 Mdot
.38374 .48472 Mdot
.69119 .49614 Mdot
.1841 .51652 Mdot
.70044 .55263 Mdot
.50534 .78303 Mdot
.36301 .46021 Mdot
.55658 .6723 Mdot
.45643 .74072 Mdot
.59944 .68996 Mdot
.50647 .55495 Mdot
.35399 .54098 Mdot
.50928 .27263 Mdot
.3319 .36337 Mdot
.63491 .33791 Mdot
.64093 .75699 Mdot
.53518 .67421 Mdot
.66309 .50051 Mdot
.54198 .65495 Mdot
.53384 .65478 Mdot
.72367 .5171 Mdot
.55784 .65662 Mdot
.38136 .51745 Mdot
.58268 .78064 Mdot
.5286 .669 Mdot
.69674 .53098 Mdot
.49823 .2539 Mdot
.53713 .69381 Mdot
.54685 .35598 Mdot
.36671 .47878 Mdot
.65048 .33061 Mdot
.50716 .21147 Mdot
.54121 .63765 Mdot
.51483 .27466 Mdot
.63266 .34848 Mdot
.54469 .2797 Mdot
.71004 .59006 Mdot
.64177 .56528 Mdot
.24391 .52846 Mdot
.73264 .47836 Mdot
.58145 .67751 Mdot
.63813 .40539 Mdot
.38531 .51343 Mdot
.34349 .48602 Mdot
.50663 .29013 Mdot
.58213 .7059 Mdot
.75541 .67834 Mdot
.46848 .55345 Mdot
.72397 .70476 Mdot
.71684 .5435 Mdot
.53834 .3464 Mdot
.42421 .41019 Mdot
.73183 .50098 Mdot
.40982 .48774 Mdot
.52576 .57294 Mdot
.35646 .50424 Mdot
.37841 .31181 Mdot
.53627 .25462 Mdot
.72896 .37928 Mdot
.39574 .55268 Mdot
.64907 .37197 Mdot
.37242 .51144 Mdot
.57443 .51734 Mdot
.40232 .55391 Mdot
.53639 .29327 Mdot
.67524 .55404 Mdot
.54387 .69995 Mdot
.50768 .24124 Mdot
.60533 .35756 Mdot
.2299 .42485 Mdot
.37893 .53906 Mdot
.34632 .4698 Mdot
.63452 .3891 Mdot
.57168 .7008 Mdot
.62138 .37459 Mdot
.67122 .51108 Mdot
.51259 .26829 Mdot
.3965 .54006 Mdot
.30224 .54366 Mdot
.60776 .32098 Mdot
.71845 .51958 Mdot
.60804 .38731 Mdot
.72616 .54647 Mdot
.51988 .57226 Mdot
.40684 .55483 Mdot
.60346 .38544 Mdot
.40632 .48392 Mdot
.43113 .67446 Mdot
.28306 .39751 Mdot
.32033 .6075 Mdot
.6226 .38756 Mdot
.55422 .17674 Mdot
.70198 .52723 Mdot
.67827 .53656 Mdot
.51243 .78651 Mdot
.52187 .85417 Mdot
.50073 .48116 Mdot
.78041 .65096 Mdot
.67096 .51131 Mdot
.69453 .53995 Mdot
.62297 .37881 Mdot
.57809 .68823 Mdot
.56123 .63288 Mdot
.61498 .39372 Mdot
.29379 .35407 Mdot
.54308 .67583 Mdot
.41817 .8036 Mdot
.65641 .34464 Mdot
.33039 .47204 Mdot
.52636 .75071 Mdot
.53761 .29216 Mdot
.35535 .32534 Mdot
.6522 .47492 Mdot
.36386 .50719 Mdot
.81205 .39595 Mdot
.63696 .37544 Mdot
.47668 .55056 Mdot
.65839 .54279 Mdot
.38235 .55258 Mdot
.37165 .50497 Mdot
.37794 .52335 Mdot
.54151 .29545 Mdot
.4026 .63904 Mdot
.36407 .51101 Mdot
.267 .39503 Mdot
.31508 .52472 Mdot
.69559 .4059 Mdot
.50958 .26057 Mdot
.40742 .26467 Mdot
.60136 .39634 Mdot
.75209 .66941 Mdot
.32972 .54093 Mdot
.67316 .53371 Mdot
.56355 .49414 Mdot
.70545 .51353 Mdot
.75373 .53247 Mdot
.29467 .27931 Mdot
.58533 .69466 Mdot
.39461 .5516 Mdot
.65966 .36362 Mdot
.55057 .62954 Mdot
.55934 .48864 Mdot
.83843 .63461 Mdot
.6587 .51106 Mdot
.70276 .81315 Mdot
.67626 .5241 Mdot
.50869 .5474 Mdot
.56846 .68913 Mdot
.41364 .59969 Mdot
.38155 .37074 Mdot
.57179 .69748 Mdot
.62877 .23508 Mdot
.51772 .69485 Mdot
.2613 .34374 Mdot
.53874 .60836 Mdot
.69304 .527 Mdot
.66733 .49829 Mdot
.37951 .44663 Mdot
.38041 .53162 Mdot
.38461 .36072 Mdot
.41499 .57874 Mdot
.38478 .49999 Mdot
.61844 .35605 Mdot
.72966 .4756 Mdot
.68641 .59552 Mdot
.56127 .6605 Mdot
.71544 .51379 Mdot
.37189 .50861 Mdot
.39409 .48657 Mdot
.33234 .53195 Mdot
.47437 .31407 Mdot
.40872 .80161 Mdot
.34444 .5179 Mdot
.39541 .56275 Mdot
.6035 .35347 Mdot
.69957 .3767 Mdot
.81135 .62791 Mdot
.30524 .26573 Mdot
.32608 .4976 Mdot
.51154 .25161 Mdot
.49368 .27375 Mdot
.41077 .46833 Mdot
.42889 .59325 Mdot
.56113 .29416 Mdot
.35144 .49328 Mdot
.24356 .4124 Mdot
.63174 .31803 Mdot
.51046 .57499 Mdot
.62979 .34628 Mdot
.56524 .63083 Mdot
.51246 .57232 Mdot
.61151 .36073 Mdot
.2756 .38237 Mdot
.53005 .5799 Mdot
.76133 .50818 Mdot
.49752 .24901 Mdot
.35309 .53294 Mdot
.4903 .74491 Mdot
.64451 .33753 Mdot
.69075 .54257 Mdot
.56293 .6866 Mdot
.71358 .54547 Mdot
.68508 .43979 Mdot
.31004 .3414 Mdot
.51045 .55589 Mdot
.67359 .53507 Mdot
.49597 .46858 Mdot
.50886 .2536 Mdot
.67666 .51688 Mdot
.45766 .52537 Mdot
.33797 .55495 Mdot
.43534 .8397 Mdot
.35219 .47097 Mdot
.76552 .54344 Mdot
.68286 .54215 Mdot
.51978 .58184 Mdot
.34591 .49909 Mdot
.66289 .35679 Mdot
.2931 .45334 Mdot
.34978 .50736 Mdot
.63488 .33141 Mdot
.33503 .50878 Mdot
.50699 .28089 Mdot
.55824 .72422 Mdot
.36413 .36418 Mdot
.47495 .34339 Mdot
.53446 .25432 Mdot
.30425 .39694 Mdot
.36374 .54046 Mdot
.58847 .211 Mdot
.54849 .67398 Mdot
.35338 .55381 Mdot
.33399 .30776 Mdot
.57692 .67557 Mdot
.55288 .69011 Mdot
.36842 .46743 Mdot
.68802 .55296 Mdot
.63018 .38707 Mdot
.50866 .25569 Mdot
.73566 .52589 Mdot
.36057 .51177 Mdot
.41069 .50711 Mdot
.53108 .25034 Mdot
.68617 .53954 Mdot
.3939 .54094 Mdot
.66787 .69439 Mdot
.30751 .37212 Mdot
.72735 .53089 Mdot
.34279 .55689 Mdot
.44628 .81339 Mdot
.54462 .64704 Mdot
.81082 .39213 Mdot
.47385 .24399 Mdot
.60682 .3753 Mdot
.29328 .51854 Mdot
.89711 .51997 Mdot
.49673 .25525 Mdot
.71942 .70219 Mdot
.33355 .49788 Mdot
.36321 .52107 Mdot
.58255 .67236 Mdot
.39527 .52884 Mdot
.55482 .65369 Mdot
.51991 .347 Mdot
.54369 .84939 Mdot
.53472 .66185 Mdot
.54533 .66146 Mdot
.44335 .55907 Mdot
.47781 .28049 Mdot
.57331 .67708 Mdot
.38118 .53635 Mdot
.62058 .21464 Mdot
.43854 .52231 Mdot
.51535 .23423 Mdot
.55845 .27758 Mdot
.55441 .70883 Mdot
.44195 .75438 Mdot
.44537 .55098 Mdot
.41293 .78596 Mdot
.56258 .2886 Mdot
.68854 .50096 Mdot
.40019 .4844 Mdot
.53334 .56155 Mdot
.63695 .35913 Mdot
.30626 .46782 Mdot
.3607 .5355 Mdot
.57302 .70559 Mdot
.54896 .2828 Mdot
.67631 .51164 Mdot
.39108 .46898 Mdot
.63266 .31419 Mdot
.531 .25433 Mdot
.52596 .67138 Mdot
.47516 .77141 Mdot
.48444 .27295 Mdot
.29406 .52972 Mdot
.33269 .49018 Mdot
.3637 .45724 Mdot
.35658 .58296 Mdot
.7064 .53579 Mdot
.6286 .39947 Mdot
.29338 .52674 Mdot
.40074 .40441 Mdot
.30678 .36349 Mdot
.32475 .5182 Mdot
.53873 .69542 Mdot
.71873 .53159 Mdot
.51961 .55634 Mdot
.32647 .23647 Mdot
.33352 .48009 Mdot
.41867 .80437 Mdot
.4464 .29355 Mdot
.53293 .57317 Mdot
.54268 .62881 Mdot
.51322 .25771 Mdot
.36835 .4629 Mdot
.26504 .3932 Mdot
.3874 .50377 Mdot
.42682 .53501 Mdot
.61442 .38388 Mdot
.68675 .50508 Mdot
.2445 .52166 Mdot
.63502 .36324 Mdot
.55408 .68961 Mdot
.37241 .77725 Mdot
.55302 .63429 Mdot
.53411 .63924 Mdot
.50079 .68604 Mdot
.69747 .54955 Mdot
.90011 .5135 Mdot
.46697 .21094 Mdot
.3323 .52598 Mdot
.66662 .51918 Mdot
.57005 .6772 Mdot
.38429 .53941 Mdot
.5564 .65459 Mdot
.55501 .71146 Mdot
.37225 .47904 Mdot
.37821 .48376 Mdot
.25678 .39579 Mdot
.4411 .8042 Mdot
.5019 .26702 Mdot
.56487 .64641 Mdot
.44158 .78868 Mdot
.36233 .51666 Mdot
.37363 .53529 Mdot
.56591 .49629 Mdot
.50957 .23948 Mdot
.2638 .66723 Mdot
.33923 .48968 Mdot
.38553 .29926 Mdot
.36982 .54241 Mdot
.58423 .64237 Mdot
.69753 .48983 Mdot
.45037 .50581 Mdot
.60724 .38416 Mdot
.56221 .6439 Mdot
.54713 .28766 Mdot
.54074 .62418 Mdot
.29977 .69016 Mdot
.71166 .53861 Mdot
.54202 .66448 Mdot
.63356 .40204 Mdot
.68615 .53449 Mdot
.69846 .55244 Mdot
.55776 .48581 Mdot
.64942 .39653 Mdot
.55018 .28028 Mdot
.68997 .51336 Mdot
.35061 .733 Mdot
.69044 .52806 Mdot
.29414 .69241 Mdot
.32675 .48445 Mdot
.26816 .39391 Mdot
.30346 .46744 Mdot
.38912 .44896 Mdot
.68369 .52019 Mdot
.53259 .25417 Mdot
.39 .54352 Mdot
.53272 .65795 Mdot
.50173 .25283 Mdot
.49127 .70892 Mdot
.64835 .40037 Mdot
.54042 .71502 Mdot
.72147 .55596 Mdot
.57415 .65846 Mdot
.34624 .32343 Mdot
.55461 .26738 Mdot
.57418 .48244 Mdot
.37253 .37744 Mdot
.31956 .56679 Mdot
.39111 .55982 Mdot
.38702 .54634 Mdot
.38057 .51253 Mdot
.62812 .33982 Mdot
.52864 .2973 Mdot
.5324 .68931 Mdot
.24588 .5769 Mdot
.68978 .54541 Mdot
.51643 .4695 Mdot
.35369 .58205 Mdot
.40613 .49868 Mdot
.5679 .67741 Mdot
.54586 .70908 Mdot
.42407 .63453 Mdot
.64384 .37842 Mdot
.43011 .49118 Mdot
.33525 .54256 Mdot
.24647 .50402 Mdot
.68239 .52291 Mdot
.72252 .66071 Mdot
.63917 .32189 Mdot
.7127 .80891 Mdot
.6336 .36253 Mdot
.55098 .43657 Mdot
.56221 .6555 Mdot
.525 .27028 Mdot
.36947 .48576 Mdot
.48666 .6035 Mdot
.52117 .64606 Mdot
.6887 .36101 Mdot
.51949 .26163 Mdot
.75669 .57894 Mdot
.66976 .50859 Mdot
.39306 .4703 Mdot
.37067 .54256 Mdot
.40064 .50671 Mdot
.39072 .52582 Mdot
.69769 .50109 Mdot
.38732 .49498 Mdot
.73333 .53921 Mdot
.29513 .68243 Mdot
.32836 .30837 Mdot
.64855 .3891 Mdot
.71128 .35813 Mdot
.53205 .64196 Mdot
.29677 .71811 Mdot
.27526 .66899 Mdot
.28358 .39644 Mdot
.74334 .5553 Mdot
.42052 .51083 Mdot
.62326 .38278 Mdot
.66135 .58632 Mdot
.65144 .38621 Mdot
.31099 .78347 Mdot
.46947 .74338 Mdot
.76758 .56431 Mdot
.39823 .50995 Mdot
.62286 .39328 Mdot
.4438 .76602 Mdot
.28668 .49911 Mdot
.48238 .26793 Mdot
.31584 .70763 Mdot
.47995 .66623 Mdot
.50164 .27077 Mdot
.35828 .47746 Mdot
.51364 .67109 Mdot
.37258 .48934 Mdot
.36665 .4825 Mdot
.32946 .50699 Mdot
.71107 .5032 Mdot
.32376 .49123 Mdot
.38124 .52551 Mdot
.34591 .19819 Mdot
.63245 .29908 Mdot
.61815 .33421 Mdot
.35934 .60949 Mdot
.50313 .25645 Mdot
.56531 .63058 Mdot
.36673 .36869 Mdot
.68257 .54523 Mdot
.42021 .634 Mdot
.37683 .47424 Mdot
.67965 .73528 Mdot
.70385 .55579 Mdot
.53873 .28249 Mdot
.53352 .5641 Mdot
.74801 .60776 Mdot
.59766 .35468 Mdot
.52202 .55112 Mdot
.63985 .33849 Mdot
.22929 .53844 Mdot
.54966 .65657 Mdot
.31924 .56649 Mdot
.68032 .51037 Mdot
.65506 .38463 Mdot
.26499 .39947 Mdot
.37164 .5295 Mdot
.62141 .38792 Mdot
.29057 .49467 Mdot
.33561 .36014 Mdot
.37004 .36434 Mdot
.63919 .39792 Mdot
.68248 .55651 Mdot
.68306 .52822 Mdot
.49706 .26467 Mdot
.54291 .64941 Mdot
.57305 .7019 Mdot
.68733 .5257 Mdot
.81918 .49448 Mdot
.36074 .50979 Mdot
.35037 .52276 Mdot
.41243 .40744 Mdot
.37171 .54745 Mdot
.52477 .23038 Mdot
.51223 .54524 Mdot
.56279 .70549 Mdot
.38769 .5452 Mdot
.39468 .53995 Mdot
.3366 .4812 Mdot
.28481 .35758 Mdot
.63245 .34416 Mdot
.3532 .46603 Mdot
.52817 .28446 Mdot
.48607 .696 Mdot
.38502 .5172 Mdot
.2926 .52792 Mdot
.559 .65243 Mdot
.63539 .4479 Mdot
.69246 .5434 Mdot
.65642 .35893 Mdot
.65868 .36261 Mdot
.34944 .26776 Mdot
.56412 .64009 Mdot
.51756 .54831 Mdot
.66987 .43532 Mdot
.51995 .55467 Mdot
.52247 .26251 Mdot
.52427 .48262 Mdot
.62466 .41298 Mdot
.62032 .33366 Mdot
.67353 .48859 Mdot
.36853 .55702 Mdot
.38504 .52257 Mdot
.74714 .67975 Mdot
.33919 .52063 Mdot
.50631 .27216 Mdot
.67016 .53827 Mdot
.54454 .66462 Mdot
.50742 .28349 Mdot
.67526 .53048 Mdot
.57045 .69982 Mdot
.31285 .51206 Mdot
.37774 .54103 Mdot
.55949 .68987 Mdot
.52614 .66532 Mdot
.36047 .49557 Mdot
.27408 .29866 Mdot
.55334 .70491 Mdot
.56488 .68839 Mdot
.48364 .68581 Mdot
.60056 .34807 Mdot
.29001 .45556 Mdot
.677 .5426 Mdot
.38015 .52568 Mdot
.64586 .38923 Mdot
.5275 .25893 Mdot
.53747 .68663 Mdot
.40238 .48537 Mdot
.3557 .51503 Mdot
.51192 .25241 Mdot
.49185 .25093 Mdot
.50618 .24336 Mdot
.67093 .49732 Mdot
.37746 .47884 Mdot
.57223 .68383 Mdot
.67499 .50018 Mdot
.50564 .28729 Mdot
.50324 .23871 Mdot
.23813 .37015 Mdot
.36254 .50422 Mdot
.4887 .26789 Mdot
.84964 .60833 Mdot
.24281 .39657 Mdot
.50538 .56592 Mdot
.66906 .3473 Mdot
.55672 .17389 Mdot
.50774 .20999 Mdot
.69311 .50459 Mdot
.51726 .46597 Mdot
.53898 .25403 Mdot
.38081 .46312 Mdot
.36044 .52999 Mdot
.33967 .57485 Mdot
.50379 .25081 Mdot
.31019 .34008 Mdot
.58652 .6904 Mdot
.30997 .64062 Mdot
.50308 .25683 Mdot
.65255 .39101 Mdot
.61274 .31721 Mdot
.62966 .37066 Mdot
.40999 .54999 Mdot
.2256 .54111 Mdot
.34432 .71352 Mdot
.25919 .6584 Mdot
.66841 .51415 Mdot
.54969 .7107 Mdot
.50881 .73749 Mdot
.55149 .69036 Mdot
.64366 .35604 Mdot
.53418 .25707 Mdot
.58459 .68144 Mdot
.70253 .55109 Mdot
.68337 .52493 Mdot
.5978 .37394 Mdot
.63104 .35137 Mdot
.62189 .36597 Mdot
.55553 .64465 Mdot
.56015 .65569 Mdot
.39996 .52461 Mdot
.53102 .67801 Mdot
.46429 .29125 Mdot
.49866 .33453 Mdot
.59294 .34656 Mdot
.70238 .5334 Mdot
.55174 .69708 Mdot
.35061 .53265 Mdot
.49771 .43336 Mdot
.59266 .38877 Mdot
.53243 .29214 Mdot
.59848 .78409 Mdot
.51403 .86302 Mdot
.39939 .54506 Mdot
.71278 .51397 Mdot
.46071 .55839 Mdot
.37868 .51197 Mdot
.60876 .38156 Mdot
.43868 .26768 Mdot
.53269 .58142 Mdot
.38083 .49719 Mdot
.3149 .51264 Mdot
.71355 .54046 Mdot
.36614 .37122 Mdot
.3886 .46798 Mdot
.54515 .46577 Mdot
.67578 .55274 Mdot
.63367 .32129 Mdot
.49114 .14313 Mdot
.49143 .58874 Mdot
.3973 .31457 Mdot
.51541 .57622 Mdot
.33071 .4826 Mdot
.61892 .3524 Mdot
.52212 .28832 Mdot
.6234 .35474 Mdot
.56813 .62898 Mdot
.59839 .35555 Mdot
.33695 .52104 Mdot
.57416 .68176 Mdot
.68298 .53846 Mdot
.46263 .42318 Mdot
.25993 .57281 Mdot
.66113 .3489 Mdot
.50004 .55029 Mdot
.37793 .4842 Mdot
.34627 .73489 Mdot
.38665 .44753 Mdot
.37607 .53629 Mdot
.70567 .515 Mdot
.56514 .66685 Mdot
.71779 .54067 Mdot
.29842 .44974 Mdot
.61082 .68877 Mdot
.69666 .54486 Mdot
.46216 .5167 Mdot
.53907 .25857 Mdot
.30222 .34764 Mdot
.3451 .49353 Mdot
.6803 .5089 Mdot
.36302 .47351 Mdot
.56893 .64801 Mdot
.28922 .37629 Mdot
.30169 .38076 Mdot
.69962 .51784 Mdot
.58135 .54025 Mdot
.35713 .35233 Mdot
.28914 .45649 Mdot
.67512 .50607 Mdot
.20545 .44764 Mdot
.52952 .56625 Mdot
.53163 .25684 Mdot
.49336 .24452 Mdot
.53078 .27616 Mdot
.35098 .5257 Mdot
.45831 .79705 Mdot
.49478 .26259 Mdot
.66271 .53475 Mdot
.5116 .28037 Mdot
.45921 .32904 Mdot
.74586 .68788 Mdot
.53783 .25783 Mdot
.34071 .50107 Mdot
.40767 .44868 Mdot
.51223 .46643 Mdot
.66623 .36751 Mdot
.70134 .61308 Mdot
.35628 .19075 Mdot
.36478 .51505 Mdot
.56809 .77502 Mdot
.6023 .67647 Mdot
.54619 .41903 Mdot
.29442 .38819 Mdot
.47306 .4535 Mdot
.55899 .69505 Mdot
.36943 .37416 Mdot
.52031 .66521 Mdot
.31831 .56718 Mdot
.34577 .5171 Mdot
.56305 .64357 Mdot
.63377 .75925 Mdot
.19643 .44092 Mdot
.71039 .7182 Mdot
.55918 .70106 Mdot
.67076 .51594 Mdot
.70961 .51476 Mdot
.70307 .51365 Mdot
.62044 .34232 Mdot
.54068 .66252 Mdot
.34426 .46771 Mdot
.6044 .36395 Mdot
.35507 .48165 Mdot
.69389 .52062 Mdot
.28809 .39086 Mdot
.54606 .66201 Mdot
.35118 .49228 Mdot
.44214 .77729 Mdot
.64388 .34204 Mdot
.50868 .25209 Mdot
.59131 .78235 Mdot
.66561 .38972 Mdot
.70712 .55686 Mdot
.5696 .62786 Mdot
.65166 .30985 Mdot
.53742 .44895 Mdot
.32494 .5139 Mdot
.34217 .53715 Mdot
.51862 .4624 Mdot
.47361 .75487 Mdot
.40896 .49051 Mdot
.6058 .35604 Mdot
.60732 .33962 Mdot
.35739 .47368 Mdot
.53717 .66358 Mdot
.54023 .25234 Mdot
.49053 .28102 Mdot
.41121 .56003 Mdot
.37733 .36761 Mdot
.26752 .39504 Mdot
.38898 .54002 Mdot
.32381 .55987 Mdot
.63571 .40224 Mdot
.5059 .56845 Mdot
.38123 .37686 Mdot
.52259 .27572 Mdot
.33523 .4914 Mdot
.32124 .6127 Mdot
.53625 .67511 Mdot
.62443 .388 Mdot
.69523 .49489 Mdot
.48352 .27129 Mdot
.59464 .34497 Mdot
.35723 .4737 Mdot
.39413 .54049 Mdot
.67807 .51417 Mdot
.58311 .642 Mdot
.51782 .24601 Mdot
.60371 .36215 Mdot
.52335 .27236 Mdot
.55537 .65777 Mdot
.53923 .69157 Mdot
.33068 .53233 Mdot
.40926 .46141 Mdot
.65811 .34536 Mdot
.42397 .53213 Mdot
.61367 .37378 Mdot
.69818 .38115 Mdot
.71827 .5139 Mdot
.35106 .5524 Mdot
.57169 .6405 Mdot
.69052 .52151 Mdot
.36774 .51265 Mdot
.52478 .46008 Mdot
.40247 .52981 Mdot
.62643 .39538 Mdot
.43975 .24196 Mdot
.53341 .26725 Mdot
.31798 .47025 Mdot
.46694 .63781 Mdot
.37706 .54603 Mdot
.63362 .32647 Mdot
.3413 .72125 Mdot
.70274 .54309 Mdot
.57015 .66057 Mdot
.6283 .42571 Mdot
.69442 .53027 Mdot
.33729 .50073 Mdot
.51013 .26975 Mdot
.52803 .68529 Mdot
.50967 .56578 Mdot
.39901 .36543 Mdot
.35339 .43689 Mdot
.43375 .51017 Mdot
.40307 .48182 Mdot
.77792 .65713 Mdot
.62233 .36249 Mdot
.56897 .67876 Mdot
.70934 .51104 Mdot
.70917 .5413 Mdot
.64242 .3444 Mdot
.48073 .65427 Mdot
.66344 .75973 Mdot
.86611 .58041 Mdot
.59507 .34006 Mdot
.52364 .27996 Mdot
.28946 .37751 Mdot
.62986 .37236 Mdot
.63169 .33636 Mdot
.62706 .40665 Mdot
.75288 .6735 Mdot
.56486 .69829 Mdot
.35612 .51613 Mdot
.55189 .76732 Mdot
.33021 .50737 Mdot
.39824 .32233 Mdot
.69471 .52139 Mdot
.57031 .66037 Mdot
.53009 .35993 Mdot
.39973 .55579 Mdot
.37371 .49985 Mdot
.55304 .35691 Mdot
.44491 .56722 Mdot
.32437 .24425 Mdot
.34698 .54491 Mdot
.62509 .34703 Mdot
.56413 .73915 Mdot
.29545 .53198 Mdot
.44297 .7789 Mdot
.68043 .52877 Mdot
.5097 .55473 Mdot
.30361 .55086 Mdot
.35137 .57565 Mdot
.52055 .66207 Mdot
.58502 .68681 Mdot
.49522 .24684 Mdot
.5939 .76758 Mdot
.67999 .53136 Mdot
.74104 .65031 Mdot
.37578 .53727 Mdot
.75248 .52685 Mdot
.44489 .25566 Mdot
.36839 .5063 Mdot
.55483 .48322 Mdot
.42452 .63427 Mdot
.40993 .49857 Mdot
.2622 .65088 Mdot
.70002 .5284 Mdot
.34912 .30754 Mdot
.39193 .50425 Mdot
.62063 .3866 Mdot
.57939 .68451 Mdot
.53832 .71375 Mdot
.51772 .28871 Mdot
.46207 .25449 Mdot
.59456 .84256 Mdot
.57138 .66065 Mdot
.37286 .53024 Mdot
.69654 .5417 Mdot
.50743 .55862 Mdot
.31119 .46205 Mdot
.5835 .5297 Mdot
.53725 .6773 Mdot
.28844 .50723 Mdot
.67596 .73932 Mdot
.36809 .37228 Mdot
.31599 .74227 Mdot
.69847 .51328 Mdot
.51408 .27752 Mdot
.42693 .55474 Mdot
.68222 .41643 Mdot
.3755 .54232 Mdot
.39763 .31987 Mdot
.58815 .71293 Mdot
.50784 .27455 Mdot
.37541 .49716 Mdot
.41385 .49862 Mdot
.31822 .39544 Mdot
.51398 .23285 Mdot
.39899 .47815 Mdot
.39919 .5473 Mdot
.582 .68428 Mdot
.51063 .54497 Mdot
.54359 .66745 Mdot
.37051 .48867 Mdot
.42723 .2214 Mdot
.56655 .64918 Mdot
.68872 .6068 Mdot
.49524 .2897 Mdot
.68048 .54369 Mdot
.29407 .50348 Mdot
.32457 .50353 Mdot
.31666 .75063 Mdot
.50602 .55405 Mdot
.7999 .54816 Mdot
.6285 .39314 Mdot
.29978 .24102 Mdot
.66291 .3957 Mdot
.73735 .57237 Mdot
.62634 .49412 Mdot
.30192 .54075 Mdot
.47871 .64787 Mdot
.25211 .65658 Mdot
.69974 .56587 Mdot
.28515 .70956 Mdot
.38052 .53143 Mdot
.33512 .48674 Mdot
.61464 .37791 Mdot
.75165 .54611 Mdot
.44994 .50448 Mdot
.3811 .37581 Mdot
.54066 .27912 Mdot
.55267 .68014 Mdot
.35662 .53108 Mdot
.62412 .7606 Mdot
.65978 .37898 Mdot
.29393 .59656 Mdot
.34802 .49471 Mdot
.45801 .55949 Mdot
.74566 .55466 Mdot
.68309 .53973 Mdot
.63645 .39939 Mdot
.65369 .39183 Mdot
.32896 .49017 Mdot
.69506 .49767 Mdot
.40391 .51046 Mdot
.35134 .35238 Mdot
.29124 .50514 Mdot
.52343 .25987 Mdot
.36135 .53812 Mdot
.45311 .59663 Mdot
.16435 .56655 Mdot
.3919 .55764 Mdot
.53751 .63823 Mdot
.61902 .36885 Mdot
.63757 .3465 Mdot
.57043 .70327 Mdot
.63851 .34671 Mdot
.31269 .64325 Mdot
.4589 .80069 Mdot
.52316 .26539 Mdot
.30446 .67187 Mdot
.53797 .27033 Mdot
.51057 .55423 Mdot
.36211 .50126 Mdot
.7436 .34214 Mdot
.59901 .33494 Mdot
.44811 .31874 Mdot
.68965 .52538 Mdot
.5058 .55141 Mdot
.38024 .48419 Mdot
.55615 .25755 Mdot
.6379 .36876 Mdot
.48211 .54904 Mdot
.33015 .50302 Mdot
.55924 .64508 Mdot
.40663 .49598 Mdot
.43015 .57494 Mdot
.51218 .54634 Mdot
.41646 .51794 Mdot
.67527 .5306 Mdot
.55087 .65285 Mdot
.77146 .56778 Mdot
.64087 .33566 Mdot
.38014 .49153 Mdot
.37515 .52746 Mdot
.52858 .69123 Mdot
.33349 .52657 Mdot
.68737 .49617 Mdot
.90449 .45295 Mdot
.51428 .24203 Mdot
.50808 .57159 Mdot
.66272 .63183 Mdot
.41727 .51642 Mdot
.39103 .54779 Mdot
.47914 .48169 Mdot
.30629 .61052 Mdot
.67811 .53952 Mdot
.42852 .5026 Mdot
.61018 .33976 Mdot
.52242 .24739 Mdot
.70692 .55082 Mdot
.3853 .48684 Mdot
.33576 .51117 Mdot
.50899 .27414 Mdot
.54584 .36309 Mdot
.49434 .23781 Mdot
.69292 .50212 Mdot
.56308 .59444 Mdot
.49947 .43284 Mdot
.35555 .50615 Mdot
.49778 .54353 Mdot
.56402 .67096 Mdot
.67788 .50206 Mdot
.40021 .64209 Mdot
.32034 .56875 Mdot
.72615 .5522 Mdot
.68199 .5369 Mdot
.32522 .51227 Mdot
.56323 .64065 Mdot
.57807 .63058 Mdot
.56596 .67433 Mdot
.33198 .29834 Mdot
.79158 .5472 Mdot
.61898 .36435 Mdot
.70012 .5335 Mdot
.6468 .38629 Mdot
.53609 .25169 Mdot
.31639 .35945 Mdot
.6629 .37493 Mdot
.58635 .66416 Mdot
.65359 .38105 Mdot
.40355 .5154 Mdot
.68774 .5515 Mdot
.65391 .34066 Mdot
.38802 .53442 Mdot
.39553 .57034 Mdot
.38815 .58408 Mdot
.54911 .27102 Mdot
.37218 .36868 Mdot
.34159 .49339 Mdot
.5327 .56357 Mdot
.3556 .49446 Mdot
.69029 .49631 Mdot
.45679 .41028 Mdot
.35458 .4691 Mdot
.59907 .33454 Mdot
.80337 .5728 Mdot
.61037 .33345 Mdot
.32849 .59403 Mdot
.35972 .48506 Mdot
.35838 .50631 Mdot
.37602 .48133 Mdot
.48109 .68534 Mdot
.71879 .55347 Mdot
.42785 .50976 Mdot
.6092 .38834 Mdot
.54939 .69188 Mdot
.57844 .65717 Mdot
.49157 .48618 Mdot
.52517 .55283 Mdot
.68155 .49506 Mdot
.35934 .50798 Mdot
.48234 .54798 Mdot
.40851 .39405 Mdot
.68894 .73769 Mdot
.67247 .35311 Mdot
.62995 .32938 Mdot
.53432 .65074 Mdot
.61769 .33897 Mdot
.38564 .48934 Mdot
.28962 .51246 Mdot
.77067 .57059 Mdot
.65255 .51544 Mdot
.52364 .24865 Mdot
.35946 .48228 Mdot
.2691 .36718 Mdot
.60348 .35366 Mdot
.64146 .40036 Mdot
.40335 .50882 Mdot
.60176 .69782 Mdot
.16203 .50548 Mdot
.66634 .51972 Mdot
.36676 .74958 Mdot
.51221 .7767 Mdot
.25296 .46682 Mdot
.70824 .53733 Mdot
.55067 .47841 Mdot
.66582 .3567 Mdot
.42856 .2018 Mdot
.55354 .6933 Mdot
.51941 .24696 Mdot
.38359 .5364 Mdot
.58752 .66687 Mdot
.59055 .35031 Mdot
.53306 .69372 Mdot
.30866 .55581 Mdot
.70021 .55563 Mdot
.63682 .35493 Mdot
.67029 .49387 Mdot
.55422 .62895 Mdot
.53668 .26943 Mdot
.38446 .30378 Mdot
.33857 .72802 Mdot
.42993 .63477 Mdot
.35428 .46539 Mdot
.61169 .29599 Mdot
.34664 .46572 Mdot
.56295 .72169 Mdot
.34432 .49436 Mdot
.35954 .5658 Mdot
.66549 .37898 Mdot
.3249 .51899 Mdot
.36934 .53817 Mdot
.44164 .78159 Mdot
.37015 .50239 Mdot
.35014 .47576 Mdot
.32689 .52777 Mdot
.57302 .64639 Mdot
.32935 .52666 Mdot
.54421 .6507 Mdot
.70382 .71607 Mdot
.64184 .33729 Mdot
.53293 .24846 Mdot
.53529 .25252 Mdot
.40633 .31625 Mdot
.27386 .36418 Mdot
.52982 .75424 Mdot
.54235 .68 Mdot
.68357 .52132 Mdot
.4023 .5173 Mdot
.2025 .41216 Mdot
.42031 .23061 Mdot
.65286 .32927 Mdot
.66047 .35692 Mdot
.38804 .52104 Mdot
.49705 .86511 Mdot
.35132 .54515 Mdot
.41921 .40811 Mdot
.34994 .5251 Mdot
.35427 .55282 Mdot
.62659 .40355 Mdot
.34846 .32363 Mdot
.35279 .46617 Mdot
.52052 .65974 Mdot
.52137 .24918 Mdot
.45433 .56201 Mdot
.41455 .25473 Mdot
.49692 .78228 Mdot
.47495 .58302 Mdot
.36518 .47129 Mdot
.60422 .36997 Mdot
.54828 .70082 Mdot
.40455 .40199 Mdot
.67658 .49991 Mdot
.39108 .3572 Mdot
.28846 .68622 Mdot
.70168 .56868 Mdot
.52904 .25274 Mdot
.58745 .35291 Mdot
.32699 .49711 Mdot
.61596 .35136 Mdot
.42581 .51551 Mdot
.41527 .39481 Mdot
.52518 .26389 Mdot
.52366 .70559 Mdot
.67067 .51839 Mdot
.58838 .6752 Mdot
.32177 .60769 Mdot
.4219 .22692 Mdot
.30647 .22904 Mdot
.59918 .33999 Mdot
.26357 .60433 Mdot
.57133 .66814 Mdot
.33181 .48211 Mdot
.86459 .58122 Mdot
.55932 .66775 Mdot
.56101 .64466 Mdot
.4278 .3907 Mdot
.33203 .32028 Mdot
.42462 .52533 Mdot
.55189 .70544 Mdot
.58774 .35218 Mdot
.51515 .26112 Mdot
.39156 .52929 Mdot
.30301 .54892 Mdot
.5839 .67823 Mdot
.64175 .36287 Mdot
.36688 .32762 Mdot
.62816 .34835 Mdot
.56997 .69427 Mdot
.65312 .35486 Mdot
.71081 .59523 Mdot
.6635 .37091 Mdot
.34203 .5307 Mdot
.35847 .5079 Mdot
.5211 .60228 Mdot
.53919 .69154 Mdot
.39066 .54748 Mdot
.33321 .50117 Mdot
.57229 .67834 Mdot
.6078 .40928 Mdot
.34261 .61883 Mdot
.39168 .55017 Mdot
.35898 .51276 Mdot
.51341 .24046 Mdot
.34859 .3702 Mdot
.4416 .42673 Mdot
.38696 .53812 Mdot
.53034 .2782 Mdot
.55326 .64546 Mdot
.35801 .49384 Mdot
.35116 .3226 Mdot
.63118 .31706 Mdot
.39461 .49457 Mdot
.51038 .56331 Mdot
.34307 .46556 Mdot
.18885 .54395 Mdot
.38047 .48791 Mdot
.56642 .69183 Mdot
.57769 .67911 Mdot
.6243 .4218 Mdot
.55675 .68802 Mdot
.50621 .56685 Mdot
.68393 .52794 Mdot
.33942 .74569 Mdot
.50357 .5592 Mdot
.4142 .51334 Mdot
.46945 .21021 Mdot
.2987 .54157 Mdot
.286 .49111 Mdot
.47284 .26882 Mdot
.5163 .57605 Mdot
.56391 .66216 Mdot
.63203 .74481 Mdot
.3947 .45882 Mdot
.67838 .49642 Mdot
.2966 .53521 Mdot
.39382 .49277 Mdot
.35411 .56305 Mdot
.60667 .65844 Mdot
.66999 .50323 Mdot
.29232 .45114 Mdot
.39172 .52935 Mdot
.31011 .61108 Mdot
.36133 .53319 Mdot
.54148 .28698 Mdot
.54858 .66364 Mdot
.6152 .34372 Mdot
.51979 .25843 Mdot
.39873 .47705 Mdot
.50237 .25537 Mdot
.61609 .35651 Mdot
.68613 .51102 Mdot
.33907 .52765 Mdot
.51909 .23501 Mdot
.54008 .26545 Mdot
.38178 .47078 Mdot
.57797 .6717 Mdot
.38359 .44653 Mdot
.3613 .49498 Mdot
.3738 .47835 Mdot
.57484 .70046 Mdot
.7962 .35872 Mdot
.33712 .48217 Mdot
.55267 .4787 Mdot
.55282 .72216 Mdot
.50733 .54528 Mdot
.60832 .35022 Mdot
.4069 .53168 Mdot
.70412 .54711 Mdot
.68553 .5282 Mdot
.6077 .32542 Mdot
.58435 .68658 Mdot
.63927 .35189 Mdot
.38978 .55979 Mdot
.2931 .52565 Mdot
.38606 .53159 Mdot
.59029 .40657 Mdot
.74594 .59764 Mdot
.52632 .67732 Mdot
.62958 .3265 Mdot
.38472 .36351 Mdot
.68325 .54875 Mdot
.61646 .40134 Mdot
.5181 .67113 Mdot
.57714 .70436 Mdot
.56468 .7034 Mdot
.53419 .28174 Mdot
.63314 .35755 Mdot
.55195 .62519 Mdot
.53799 .62472 Mdot
.39598 .48916 Mdot
.39417 .52688 Mdot
.54621 .6468 Mdot
.66231 .42805 Mdot
.53239 .2611 Mdot
.60093 .36542 Mdot
.15853 .52237 Mdot
.66741 .51192 Mdot
.44315 .78111 Mdot
.38415 .54022 Mdot
.73872 .79458 Mdot
.35033 .54511 Mdot
.36907 .53272 Mdot
.56526 .63084 Mdot
.49322 .24243 Mdot
.5127 .26269 Mdot
.57232 .66892 Mdot
.55932 .71168 Mdot
.5299 .2908 Mdot
.46501 .43665 Mdot
.1836 .52261 Mdot
.40033 .39389 Mdot
.53008 .68539 Mdot
.31994 .7214 Mdot
.70753 .52158 Mdot
.57533 .72097 Mdot
.64065 .56695 Mdot
.65048 .34365 Mdot
.66273 .35796 Mdot
.68037 .51615 Mdot
.3413 .47896 Mdot
.60121 .3749 Mdot
.31604 .53104 Mdot
.76013 .56779 Mdot
.57457 .53039 Mdot
.23564 .33397 Mdot
.33448 .52484 Mdot
.44971 .58046 Mdot
.76709 .66932 Mdot
.40748 .51925 Mdot
.44764 .73379 Mdot
.51176 .24591 Mdot
.57254 .71977 Mdot
.66672 .53193 Mdot
.57181 .77585 Mdot
.35682 .50644 Mdot
.53755 .69419 Mdot
.66929 .53304 Mdot
.7576 .5886 Mdot
.54507 .46643 Mdot
.40223 .49337 Mdot
.88342 .54662 Mdot
.52103 .64913 Mdot
.6144 .34503 Mdot
.38047 .73482 Mdot
.58997 .69693 Mdot
.53999 .45308 Mdot
.5891 .34984 Mdot
.36866 .39173 Mdot
.54261 .70284 Mdot
.49152 .24064 Mdot
.54967 .67605 Mdot
.50123 .2787 Mdot
.56024 .62593 Mdot
.64847 .35161 Mdot
.36834 .49242 Mdot
.64566 .34501 Mdot
.5265 .29264 Mdot
.59907 .33871 Mdot
.66693 .53272 Mdot
.5224 .57854 Mdot
.69354 .52002 Mdot
.29899 .36931 Mdot
.40678 .65455 Mdot
.68731 .50556 Mdot
.48435 .51735 Mdot
.33669 .51935 Mdot
.58481 .64286 Mdot
.61922 .34058 Mdot
.66635 .38248 Mdot
.37391 .3684 Mdot
.57203 .69596 Mdot
.64452 .36215 Mdot
.32879 .72307 Mdot
.81713 .50539 Mdot
.36547 .56835 Mdot
.70187 .43465 Mdot
.57092 .68521 Mdot
.6556 .39728 Mdot
.41561 .40816 Mdot
.58481 .69917 Mdot
.65682 .34397 Mdot
.67492 .50761 Mdot
.70209 .54722 Mdot
.33959 .53258 Mdot
.66066 .51688 Mdot
.66522 .35781 Mdot
.28719 .60457 Mdot
.56592 .65449 Mdot
.73509 .60392 Mdot
.52916 .24985 Mdot
.62489 .33913 Mdot
.3553 .45328 Mdot
.57401 .64306 Mdot
.65121 .38235 Mdot
.57209 .84633 Mdot
.15108 .58997 Mdot
.64348 .36417 Mdot
.54796 .66498 Mdot
.53923 .6873 Mdot
.4089 .54306 Mdot
.37859 .37148 Mdot
.63805 .37082 Mdot
.74149 .34023 Mdot
.26107 .39484 Mdot
.5186 .57217 Mdot
.35013 .19511 Mdot
.35049 .46719 Mdot
.36881 .47212 Mdot
.69235 .5007 Mdot
.37452 .50391 Mdot
.5522 .71009 Mdot
.35068 .5456 Mdot
.72013 .53781 Mdot
.61749 .32201 Mdot
.35876 .50148 Mdot
.52309 .24717 Mdot
.7186 .52784 Mdot
.71922 .52206 Mdot
.65473 .35985 Mdot
.58274 .68922 Mdot
.6389 .78148 Mdot
.6298 .34869 Mdot
.37731 .47822 Mdot
.53222 .57021 Mdot
.3256 .52234 Mdot
.50925 .63083 Mdot
.55049 .71973 Mdot
.61631 .34049 Mdot
.53865 .56458 Mdot
.69714 .53687 Mdot
.66693 .36056 Mdot
.33754 .46973 Mdot
.64882 .33203 Mdot
.56873 .47574 Mdot
.59749 .19936 Mdot
.52092 .64229 Mdot
.55892 .45475 Mdot
.58239 .70025 Mdot
.51434 .57104 Mdot
.33986 .27349 Mdot
.53204 .25814 Mdot
.60479 .3431 Mdot
.69095 .60594 Mdot
.63847 .33387 Mdot
.37035 .5067 Mdot
.33472 .51068 Mdot
.61294 .37626 Mdot
.53559 .27397 Mdot
.47047 .34509 Mdot
.48842 .23919 Mdot
.54033 .66475 Mdot
.49046 .4643 Mdot
.15124 .49745 Mdot
.64576 .31704 Mdot
.68015 .52141 Mdot
.48 .59337 Mdot
.41411 .50562 Mdot
.66546 .5184 Mdot
.71641 .51457 Mdot
.50388 .28503 Mdot
.63212 .33546 Mdot
.51978 .69576 Mdot
.69857 .55418 Mdot
.59445 .68589 Mdot
.36622 .32383 Mdot
.33089 .57484 Mdot
.25475 .48569 Mdot
.41194 .49316 Mdot
.36905 .37032 Mdot
.70379 .55515 Mdot
.33999 .5085 Mdot
.42409 .54884 Mdot
.67069 .51104 Mdot
.50038 .28188 Mdot
.57135 .55549 Mdot
.64522 .36433 Mdot
.82782 .64394 Mdot
.34548 .5325 Mdot
.3633 .49184 Mdot
.66801 .51571 Mdot
.46231 .75798 Mdot
.52459 .6545 Mdot
.58155 .6776 Mdot
.62255 .36324 Mdot
.43459 .40151 Mdot
.32847 .51976 Mdot
.33888 .52529 Mdot
.61727 .3869 Mdot
.53033 .56108 Mdot
.32077 .22041 Mdot
.3542 .51442 Mdot
.70409 .52996 Mdot
.5635 .49379 Mdot
.68175 .55557 Mdot
.3449 .55446 Mdot
.36994 .51379 Mdot
.35495 .45851 Mdot
.33301 .47145 Mdot
.69777 .51808 Mdot
.40875 .48931 Mdot
.41918 .49482 Mdot
.56379 .66586 Mdot
.35373 .47105 Mdot
.25988 .39608 Mdot
.35347 .51083 Mdot
.5146 .2449 Mdot
.44392 .42556 Mdot
.37795 .48667 Mdot
.35666 .47113 Mdot
.26275 .39287 Mdot
.37892 .50491 Mdot
.6682 .53036 Mdot
.54215 .69108 Mdot
.69722 .53843 Mdot
.67737 .52441 Mdot
.65537 .37578 Mdot
.49273 .26818 Mdot
.41944 .54122 Mdot
.52779 .28798 Mdot
.40431 .55135 Mdot
.30003 .44782 Mdot
.33702 .35885 Mdot
.41762 .40683 Mdot
.54263 .25985 Mdot
.34053 .52557 Mdot
.6193 .35803 Mdot
.62146 .33531 Mdot
.51865 .46546 Mdot
.29617 .52176 Mdot
.66693 .54105 Mdot
.68018 .50855 Mdot
.50094 .33613 Mdot
.57814 .18369 Mdot
.54334 .27394 Mdot
.48025 .35565 Mdot
.31242 .50679 Mdot
.34547 .4808 Mdot
.2964 .47791 Mdot
.63689 .39106 Mdot
.51852 .57829 Mdot
.59531 .3673 Mdot
.74538 .55376 Mdot
.71544 .53259 Mdot
.33753 .52806 Mdot
.46183 .85972 Mdot
.545 .65559 Mdot
.54032 .6903 Mdot
.71998 .53923 Mdot
.61013 .33436 Mdot
.29002 .49996 Mdot
.79083 .69587 Mdot
.5391 .71289 Mdot
.52088 .23879 Mdot
.37819 .49678 Mdot
.64876 .34269 Mdot
.55362 .65278 Mdot
.52353 .23728 Mdot
.32737 .48179 Mdot
.58856 .35535 Mdot
.34356 .50707 Mdot
.30217 .65846 Mdot
.56425 .65882 Mdot
.32779 .37203 Mdot
.55768 .63322 Mdot
.69949 .51976 Mdot
.68092 .54113 Mdot
.36818 .51299 Mdot
.80802 .67827 Mdot
.56589 .73707 Mdot
.72763 .52776 Mdot
.49507 .24567 Mdot
.52792 .58058 Mdot
.49418 .26368 Mdot
.61476 .37506 Mdot
.52936 .25344 Mdot
.65283 .37989 Mdot
.6589 .4337 Mdot
.51577 .66175 Mdot
.50851 .27369 Mdot
.44554 .70552 Mdot
.28895 .50769 Mdot
.49226 .28114 Mdot
.38981 .51342 Mdot
.39887 .55152 Mdot
.63799 .37838 Mdot
.53511 .28526 Mdot
.40089 .48371 Mdot
.65625 .62957 Mdot
.67766 .5354 Mdot
.66779 .54007 Mdot
.29906 .5375 Mdot
.64694 .40023 Mdot
.51816 .65642 Mdot
.37023 .35025 Mdot
.52106 .70398 Mdot
.3416 .52775 Mdot
.40883 .55108 Mdot
.53965 .62992 Mdot
.53259 .64169 Mdot
.3679 .51758 Mdot
.39836 .78479 Mdot
.37275 .45888 Mdot
.69884 .54785 Mdot
.54063 .663 Mdot
.53648 .68588 Mdot
.66528 .36186 Mdot
.5823 .67347 Mdot
.43223 .4977 Mdot
.72068 .5688 Mdot
.41176 .4779 Mdot
.69664 .53353 Mdot
.6757 .33807 Mdot
.64443 .37737 Mdot
.69968 .60499 Mdot
.58011 .66716 Mdot
.38806 .54556 Mdot
.5729 .65187 Mdot
.50325 .24471 Mdot
.53221 .68428 Mdot
.59204 .64672 Mdot
.37692 .53781 Mdot
.39652 .47568 Mdot
.52473 .55831 Mdot
.37472 .37266 Mdot
.55654 .66037 Mdot
.38548 .55975 Mdot
.35869 .55011 Mdot
.33173 .50591 Mdot
.3597 .3523 Mdot
.57331 .64729 Mdot
.49386 .78136 Mdot
.5243 .72202 Mdot
.56084 .65622 Mdot
.17402 .61259 Mdot
.51544 .55452 Mdot
.53567 .56331 Mdot
.65924 .53469 Mdot
.35701 .51531 Mdot
.64132 .3484 Mdot
.3773 .47561 Mdot
.31406 .46132 Mdot
.37725 .48779 Mdot
.50147 .26962 Mdot
.32357 .51085 Mdot
.52263 .56753 Mdot
.62825 .34422 Mdot
.40471 .52506 Mdot
.36203 .50718 Mdot
.52379 .55278 Mdot
.56378 .64345 Mdot
.58204 .69771 Mdot
.51509 .69608 Mdot
.51063 .28868 Mdot
.7082 .51562 Mdot
.37973 .47895 Mdot
.6213 .36091 Mdot
.64023 .3433 Mdot
.58139 .65689 Mdot
.61283 .38466 Mdot
.7164 .52324 Mdot
.36849 .53109 Mdot
.69791 .51908 Mdot
.50064 .26858 Mdot
.54901 .6628 Mdot
.38668 .49275 Mdot
.39036 .48042 Mdot
.57767 .67873 Mdot
.38119 .46282 Mdot
.4982 .24702 Mdot
.63567 .39707 Mdot
.52523 .66841 Mdot
.68422 .52946 Mdot
.66487 .3667 Mdot
.39797 .53758 Mdot
.23515 .7096 Mdot
.37472 .50577 Mdot
.32915 .513 Mdot
.56848 .74183 Mdot
.32566 .53585 Mdot
.64041 .33492 Mdot
.57846 .6581 Mdot
.39566 .55155 Mdot
.26271 .38571 Mdot
.55383 .30974 Mdot
.63497 .30884 Mdot
.38047 .52296 Mdot
.30949 .74102 Mdot
.3757 .54766 Mdot
.68917 .60865 Mdot
.33692 .35923 Mdot
.63595 .51448 Mdot
.25477 .48639 Mdot
.72679 .52762 Mdot
.53234 .56535 Mdot
.65427 .37107 Mdot
.42679 .75645 Mdot
.37123 .51894 Mdot
.41258 .63414 Mdot
.38735 .49107 Mdot
.70825 .53904 Mdot
.45718 .73291 Mdot
.60562 .37468 Mdot
.31508 .23818 Mdot
.33971 .47491 Mdot
.52004 .66536 Mdot
.61223 .405 Mdot
.53674 .57174 Mdot
.39718 .47701 Mdot
.5417 .28406 Mdot
.50999 .33649 Mdot
.41725 .47294 Mdot
.69506 .53561 Mdot
.33552 .4894 Mdot
.32689 .459 Mdot
.82391 .4446 Mdot
.5675 .67599 Mdot
.67351 .51752 Mdot
.57266 .18524 Mdot
.33811 .51628 Mdot
.57796 .70327 Mdot
.55284 .6928 Mdot
.51726 .28687 Mdot
.7367 .52971 Mdot
.53034 .34368 Mdot
.4316 .83611 Mdot
.24752 .56849 Mdot
.63682 .39232 Mdot
.54824 .59723 Mdot
.37383 .47159 Mdot
.42325 .22593 Mdot
.6796 .52514 Mdot
.36434 .49074 Mdot
.44048 .63668 Mdot
.56545 .68743 Mdot
.34644 .51221 Mdot
.53037 .25905 Mdot
.68213 .77143 Mdot
.30711 .69998 Mdot
.32971 .75738 Mdot
.58785 .35173 Mdot
.42466 .52992 Mdot
.43316 .50349 Mdot
.50748 .54493 Mdot
.35659 .56063 Mdot
.61855 .34233 Mdot
.58019 .4924 Mdot
.52931 .27066 Mdot
.54944 .65236 Mdot
.53196 .5607 Mdot
.38797 .49207 Mdot
.42476 .51226 Mdot
.49932 .24247 Mdot
.36303 .46038 Mdot
.38672 .7448 Mdot
.51623 .58278 Mdot
.6619 .37557 Mdot
.52812 .68671 Mdot
.41522 .54587 Mdot
.53184 .57908 Mdot
.3806 .53424 Mdot
.44483 .59831 Mdot
.35906 .48349 Mdot
.63805 .59611 Mdot
.57959 .68517 Mdot
.68805 .53787 Mdot
.32828 .47488 Mdot
.34835 .50403 Mdot
.55144 .4327 Mdot
.28933 .49581 Mdot
.36708 .47796 Mdot
.58996 .68451 Mdot
.54684 .65343 Mdot
.52164 .66123 Mdot
.65748 .33742 Mdot
.39481 .38889 Mdot
.69655 .52347 Mdot
.29488 .48051 Mdot
.69938 .55426 Mdot
.25818 .46845 Mdot
.4979 .26881 Mdot
.71474 .60409 Mdot
.36649 .5291 Mdot
.56613 .70091 Mdot
.18305 .50866 Mdot
.57644 .64977 Mdot
.6917 .5723 Mdot
.67991 .52968 Mdot
.55713 .66805 Mdot
.37984 .51743 Mdot
.37468 .38087 Mdot
.34127 .77127 Mdot
.68485 .54997 Mdot
.30363 .54657 Mdot
.65913 .30788 Mdot
.62664 .31918 Mdot
.16793 .59537 Mdot
.69907 .55246 Mdot
.76768 .66946 Mdot
.39225 .55026 Mdot
.57196 .65325 Mdot
.69765 .51142 Mdot
.70436 .50219 Mdot
.60796 .38157 Mdot
.39995 .49202 Mdot
.34762 .50614 Mdot
.51053 .56207 Mdot
.68961 .51506 Mdot
.44 .56926 Mdot
.40359 .49356 Mdot
.7593 .55804 Mdot
.52423 .69308 Mdot
.79264 .35131 Mdot
.46912 .54076 Mdot
.43911 .63682 Mdot
.77307 .36247 Mdot
.52556 .66203 Mdot
.34313 .47734 Mdot
.29062 .50098 Mdot
.62991 .39659 Mdot
.37456 .5243 Mdot
.62699 .32579 Mdot
.71235 .53073 Mdot
.64322 .61479 Mdot
.48067 .51661 Mdot
.72568 .58013 Mdot
.37202 .50111 Mdot
.31671 .70888 Mdot
.51653 .27244 Mdot
.67897 .55877 Mdot
.52895 .64712 Mdot
.35088 .55514 Mdot
.61694 .39278 Mdot
.6431 .32773 Mdot
.56299 .68516 Mdot
.7501 .67144 Mdot
.70036 .60646 Mdot
.36419 .45491 Mdot
.60741 .36204 Mdot
.47641 .54919 Mdot
.29569 .71685 Mdot
.71911 .54782 Mdot
.52769 .27112 Mdot
.65695 .3584 Mdot
.67066 .49721 Mdot
.40099 .55058 Mdot
.5586 .67911 Mdot
.52166 .64543 Mdot
.52669 .45765 Mdot
.64438 .35962 Mdot
.51141 .25449 Mdot
.53212 .45977 Mdot
.49921 .46749 Mdot
.52538 .26081 Mdot
.65436 .3306 Mdot
.5328 .6674 Mdot
.56692 .69469 Mdot
.54385 .69149 Mdot
.44316 .77882 Mdot
.54975 .71925 Mdot
.40381 .28373 Mdot
.35241 .55887 Mdot
.32803 .72904 Mdot
.36597 .55578 Mdot
.66636 .52886 Mdot
.56735 .65989 Mdot
.33357 .36189 Mdot
.31366 .49686 Mdot
.34904 .77551 Mdot
.3443 .48975 Mdot
.55888 .48728 Mdot
.35816 .51468 Mdot
.32553 .6853 Mdot
.5764 .71705 Mdot
.32993 .48103 Mdot
.71918 .56729 Mdot
.50258 .25187 Mdot
.56622 .62548 Mdot
.35934 .4772 Mdot
.6773 .7328 Mdot
.39016 .51277 Mdot
.64186 .60934 Mdot
.53639 .45139 Mdot
.4845 .22292 Mdot
.3283 .52785 Mdot
.60242 .38374 Mdot
.45778 .51965 Mdot
.31785 .72298 Mdot
.68652 .55078 Mdot
.32309 .71648 Mdot
.59861 .36294 Mdot
.4584 .73675 Mdot
.33578 .45316 Mdot
.53177 .27168 Mdot
.57833 .55773 Mdot
.6935 .5479 Mdot
.36715 .52565 Mdot
.33704 .47914 Mdot
.5726 .52529 Mdot
.2858 .7012 Mdot
.44759 .56627 Mdot
.53937 .25192 Mdot
.29694 .69571 Mdot
.36868 .48032 Mdot
.63482 .30763 Mdot
.58564 .68846 Mdot
.45753 .72081 Mdot
.46852 .75086 Mdot
.40979 .50867 Mdot
.5599 .67063 Mdot
.58421 .68673 Mdot
.17483 .45949 Mdot
.52092 .27761 Mdot
.3561 .48364 Mdot
.5595 .45377 Mdot
.38127 .48152 Mdot
.70865 .53167 Mdot
.31525 .52008 Mdot
.64442 .37551 Mdot
.41698 .41083 Mdot
.65498 .33411 Mdot
.33123 .50835 Mdot
.54824 .67526 Mdot
.67476 .53818 Mdot
.6748 .43687 Mdot
.73666 .53159 Mdot
.4028 .28445 Mdot
.49284 .32623 Mdot
.54314 .27142 Mdot
.49654 .27161 Mdot
.67495 .55432 Mdot
.37745 .52868 Mdot
.3729 .35942 Mdot
.33721 .56051 Mdot
.35471 .51939 Mdot
.36532 .48358 Mdot
.64581 .52579 Mdot
.68094 .53177 Mdot
.65122 .3512 Mdot
.36776 .51908 Mdot
.37949 .56156 Mdot
.55182 .67176 Mdot
.542 .26999 Mdot
.65501 .38339 Mdot
.53856 .29079 Mdot
.62395 .34936 Mdot
.1888 .54574 Mdot
.31162 .56161 Mdot
.50126 .2578 Mdot
.71194 .55089 Mdot
.55583 .70126 Mdot
.50808 .55315 Mdot
.61898 .37688 Mdot
.60966 .37945 Mdot
.41695 .53866 Mdot
.55572 .65429 Mdot
.58116 .67367 Mdot
.53291 .29098 Mdot
.68243 .50739 Mdot
.38949 .57168 Mdot
.41489 .50298 Mdot
.69836 .39941 Mdot
.63157 .39928 Mdot
.30656 .70695 Mdot
.54424 .73789 Mdot
.36787 .53591 Mdot
.57791 .70202 Mdot
.35544 .4984 Mdot
.49697 .59433 Mdot
.52525 .64453 Mdot
.32284 .53358 Mdot
.30075 .51191 Mdot
.64045 .39022 Mdot
.18723 .41299 Mdot
.39867 .56938 Mdot
.66796 .58051 Mdot
.37066 .46757 Mdot
.30177 .22952 Mdot
.18225 .49871 Mdot
.38619 .5245 Mdot
.32433 .50625 Mdot
.39579 .82893 Mdot
.37253 .54697 Mdot
.51566 .56613 Mdot
.31499 .45984 Mdot
.57336 .70575 Mdot
.56228 .46222 Mdot
.37118 .36932 Mdot
.51777 .28018 Mdot
.62169 .36359 Mdot
.33851 .32127 Mdot
.50155 .27983 Mdot
.5683 .68962 Mdot
.40013 .57072 Mdot
.55551 .73949 Mdot
.66143 .39681 Mdot
.43249 .57339 Mdot
.70958 .536 Mdot
.37362 .36374 Mdot
.61236 .38778 Mdot
.68346 .52823 Mdot
.36933 .54969 Mdot
.63731 .42324 Mdot
.70031 .56611 Mdot
.17321 .43241 Mdot
.68965 .49917 Mdot
.68464 .54056 Mdot
.38429 .3789 Mdot
.51797 .28034 Mdot
.58362 .50272 Mdot
.2923 .4539 Mdot
.67237 .53801 Mdot
.31944 .2495 Mdot
.62556 .39921 Mdot
.40951 .38903 Mdot
.58032 .71556 Mdot
.30297 .54966 Mdot
.36744 .48847 Mdot
.68079 .50096 Mdot
.54787 .57878 Mdot
.54919 .42586 Mdot
.71228 .5414 Mdot
.32101 .47972 Mdot
.43754 .40748 Mdot
.52965 .57833 Mdot
.51339 .55471 Mdot
.51876 .2357 Mdot
.61982 .22913 Mdot
.57786 .69378 Mdot
.52153 .23968 Mdot
.30375 .37633 Mdot
.3403 .49133 Mdot
.69904 .51712 Mdot
.53024 .55738 Mdot
.68648 .52941 Mdot
.51586 .26672 Mdot
.49554 .24791 Mdot
.56468 .66738 Mdot
.52634 .65329 Mdot
.57102 .58206 Mdot
.24945 .39984 Mdot
.39666 .49772 Mdot
.39672 .64326 Mdot
.53219 .64118 Mdot
.44821 .76218 Mdot
.52703 .28308 Mdot
.5401 .27801 Mdot
.2488 .63376 Mdot
.40033 .52359 Mdot
.56282 .49234 Mdot
.37623 .48419 Mdot
.35573 .23997 Mdot
.38844 .4948 Mdot
.61539 .38595 Mdot
.34573 .46876 Mdot
.62728 .76639 Mdot
.39892 .54383 Mdot
.37156 .48597 Mdot
.6313 .36688 Mdot
.41973 .53862 Mdot
.64087 .37732 Mdot
.34264 .47945 Mdot
.52928 .32119 Mdot
.62172 .36102 Mdot
.53877 .30821 Mdot
.5334 .48132 Mdot
.51771 .56058 Mdot
.50575 .27884 Mdot
.54468 .27503 Mdot
.37161 .32727 Mdot
.53636 .65979 Mdot
.4766 .67276 Mdot
.37808 .49758 Mdot
.63567 .40215 Mdot
.71319 .52236 Mdot
.41034 .50681 Mdot
.33837 .53703 Mdot
.396 .56977 Mdot
.56158 .66654 Mdot
.66648 .37212 Mdot
.50679 .267 Mdot
.62885 .33116 Mdot
.53336 .318 Mdot
.64314 .38192 Mdot
.32656 .56165 Mdot
.4041 .54982 Mdot
.43383 .50809 Mdot
.43387 .67411 Mdot
.45709 .21796 Mdot
.5608 .68207 Mdot
.53111 .5696 Mdot
.49577 .26451 Mdot
.46219 .42352 Mdot
.57308 .70101 Mdot
.61482 .38318 Mdot
.34338 .50675 Mdot
.32613 .57277 Mdot
.29521 .45208 Mdot
.597 .67577 Mdot
.50059 .28859 Mdot
.6222 .37226 Mdot
.52133 .57448 Mdot
.40149 .39317 Mdot
.51385 .77883 Mdot
.3078 .36322 Mdot
.35143 .5012 Mdot
.52782 .29091 Mdot
.55337 .65287 Mdot
.57227 .50701 Mdot
.6764 .50462 Mdot
.37713 .37123 Mdot
.37296 .50079 Mdot
.76193 .51028 Mdot
.54807 .67703 Mdot
.53659 .26797 Mdot
.68078 .50059 Mdot
.52707 .27735 Mdot
.53226 .58308 Mdot
.53702 .73463 Mdot
.39439 .4746 Mdot
.37932 .48618 Mdot
.71253 .52495 Mdot
.58 .68979 Mdot
.53215 .32568 Mdot
.58225 .52671 Mdot
.61285 .37458 Mdot
.45831 .42838 Mdot
.5496 .65312 Mdot
.73535 .47962 Mdot
.62776 .32989 Mdot
.66229 .53056 Mdot
.36347 .37882 Mdot
.71683 .52108 Mdot
.3665 .48115 Mdot
.54012 .68004 Mdot
.68668 .55174 Mdot
.69643 .38615 Mdot
.41374 .8016 Mdot
.579 .5507 Mdot
.33573 .51764 Mdot
.70439 .6142 Mdot
.73593 .69871 Mdot
.56384 .61874 Mdot
.70531 .55129 Mdot
.36646 .50301 Mdot
.36515 .45498 Mdot
.34027 .47393 Mdot
.67358 .52837 Mdot
.66675 .46224 Mdot
.60298 .35194 Mdot
.33993 .5103 Mdot
.52266 .2459 Mdot
.64805 .37067 Mdot
.60963 .32164 Mdot
.65713 .35615 Mdot
.53183 .6458 Mdot
.34285 .57894 Mdot
.30627 .46505 Mdot
.1883 .45789 Mdot
.68704 .54008 Mdot
.51805 .56089 Mdot
.3255 .4982 Mdot
.40074 .29052 Mdot
.55956 .69964 Mdot
.62621 .37663 Mdot
.36236 .49086 Mdot
.5302 .45363 Mdot
.49218 .54497 Mdot
.63211 .35451 Mdot
.52784 .64467 Mdot
.6054 .71479 Mdot
.37286 .52637 Mdot
.37564 .47058 Mdot
.57479 .68302 Mdot
.73379 .71492 Mdot
.40993 .3979 Mdot
.35644 .50046 Mdot
.68468 .53474 Mdot
.82333 .58687 Mdot
.37081 .55106 Mdot
.5508 .72917 Mdot
.51565 .57731 Mdot
.54805 .74421 Mdot
.37302 .75185 Mdot
.2947 .50261 Mdot
.6066 .6123 Mdot
.45165 .3266 Mdot
.60323 .64258 Mdot
.37967 .23404 Mdot
.59297 .53543 Mdot
.15875 .47159 Mdot
.7273 .56757 Mdot
.30944 .67332 Mdot
.55791 .84576 Mdot
.76507 .66556 Mdot
.56248 .44129 Mdot
.64006 .48409 Mdot
.66821 .39753 Mdot
.32921 .21308 Mdot
.59613 .3744 Mdot
.39119 .22249 Mdot
.3846 .4948 Mdot
.72455 .7195 Mdot
.31648 .68666 Mdot
.46306 .25362 Mdot
.71774 .59602 Mdot
.53389 .45439 Mdot
.28789 .74857 Mdot
.74787 .57586 Mdot
.20643 .63092 Mdot
.45829 .64223 Mdot
.66091 .25022 Mdot
.47306 .44297 Mdot
.35433 .31463 Mdot
.33672 .71928 Mdot
.62722 .71891 Mdot
.74618 .50653 Mdot
.31196 .62168 Mdot
.78264 .36499 Mdot
.61118 .35862 Mdot
.5826 .70427 Mdot
.62235 .50371 Mdot
.24069 .68327 Mdot
.68037 .57662 Mdot
.60571 .61262 Mdot
.57999 .54032 Mdot
.32058 .68177 Mdot
.3242 .37089 Mdot
.30729 .65493 Mdot
.52178 .34597 Mdot
.33407 .21262 Mdot
.59047 .73152 Mdot
.70483 .33732 Mdot
.45067 .40161 Mdot
.50912 .3598 Mdot
.35814 .71182 Mdot
.5541 .28173 Mdot
.55155 .30784 Mdot
.5253 .64623 Mdot
.26448 .69901 Mdot
.49432 .53055 Mdot
.29633 .38291 Mdot
.59729 .3782 Mdot
.49335 .58205 Mdot
.6761 .77225 Mdot
.72924 .69917 Mdot
.20308 .37234 Mdot
.23178 .69999 Mdot
.31526 .28033 Mdot
.56152 .50637 Mdot
.6638 .56361 Mdot
.40678 .30066 Mdot
.43918 .58394 Mdot
.29349 .3002 Mdot
.45131 .59666 Mdot
.34818 .79416 Mdot
.6966 .70309 Mdot
.26073 .73355 Mdot
.59582 .72557 Mdot
.42859 .53826 Mdot
.51661 .60452 Mdot
.28311 .59616 Mdot
.28429 .36588 Mdot
.2633 .72402 Mdot
.48355 .22977 Mdot
.54099 .5874 Mdot
.76672 .65833 Mdot
.38489 .74464 Mdot
.54393 .3532 Mdot
.48832 .28706 Mdot
.46582 .71082 Mdot
.29777 .76566 Mdot
.61286 .6144 Mdot
.21689 .56703 Mdot
.76423 .55229 Mdot
.59437 .40165 Mdot
.60509 .3253 Mdot
.71806 .51116 Mdot
.21422 .65909 Mdot
.5433 .68466 Mdot
.18369 .41291 Mdot
.57634 .60144 Mdot
.46819 .55976 Mdot
.30414 .77232 Mdot
.25856 .31509 Mdot
.35228 .73871 Mdot
.43778 .26637 Mdot
.7975 .54728 Mdot
.31893 .59706 Mdot
.72183 .57792 Mdot
.6529 .30777 Mdot
.6565 .60925 Mdot
.22361 .67224 Mdot
.29495 .28699 Mdot
.4612 .85141 Mdot
.29046 .39082 Mdot
.5728 .28836 Mdot
.58667 .73377 Mdot
.59164 .4416 Mdot
.55064 .3645 Mdot
.25506 .72924 Mdot
.29959 .69056 Mdot
.81539 .57345 Mdot
.3611 .25242 Mdot
.46909 .75747 Mdot
.69334 .62713 Mdot
.63967 .4647 Mdot
.2839 .58472 Mdot
.68997 .72318 Mdot
.41489 .49367 Mdot
.3112 .35247 Mdot
.46236 .68653 Mdot
.51237 .22382 Mdot
.39728 .39511 Mdot
.70528 .68025 Mdot
.31423 .30559 Mdot
.79696 .59577 Mdot
.47009 .7157 Mdot
.55471 .63058 Mdot
.29618 .29997 Mdot
.3378 .26239 Mdot
.77303 .60008 Mdot
.5694 .18432 Mdot
.21618 .56978 Mdot
.56831 .38105 Mdot
.2967 .4908 Mdot
.30561 .66969 Mdot
.33975 .71954 Mdot
.34307 .22177 Mdot
.31999 .55886 Mdot
.19528 .42463 Mdot
.70625 .59397 Mdot
.41913 .68408 Mdot
.28417 .34632 Mdot
.42972 .67882 Mdot
.34334 .74786 Mdot
.50072 .65441 Mdot
.63304 .54542 Mdot
.55238 .55893 Mdot
.30085 .766 Mdot
.65186 .36184 Mdot
.28923 .30056 Mdot
.70492 .58354 Mdot
.69542 .39541 Mdot
.59285 .51738 Mdot
.55408 .42385 Mdot
.19336 .62425 Mdot
.76093 .65153 Mdot
.68851 .36723 Mdot
.61154 .74806 Mdot
.48139 .56537 Mdot
.40265 .64811 Mdot
.40749 .57492 Mdot
.46019 .58794 Mdot
.49802 .24709 Mdot
.42845 .72778 Mdot
.51598 .71693 Mdot
.55156 .17299 Mdot
.31463 .54734 Mdot
.4783 .44558 Mdot
.50919 .56861 Mdot
.39743 .34899 Mdot
.18667 .54415 Mdot
.39649 .58145 Mdot
.25444 .32255 Mdot
.75893 .66495 Mdot
.39131 .34546 Mdot
.54667 .3626 Mdot
.47991 .69296 Mdot
.26364 .73759 Mdot
.16525 .56425 Mdot
.68353 .74862 Mdot
.68559 .62107 Mdot
.48854 .13491 Mdot
.63183 .53499 Mdot
.2033 .4023 Mdot
.70399 .58335 Mdot
.90383 .45632 Mdot
.63514 .32914 Mdot
.42874 .21804 Mdot
.37055 .60909 Mdot
.50424 .43581 Mdot
.25326 .69426 Mdot
.36722 .73538 Mdot
.50157 .29086 Mdot
.5857 .6411 Mdot
.30497 .54161 Mdot
.27212 .72413 Mdot
.3073 .76594 Mdot
.27745 .72871 Mdot
.71326 .47058 Mdot
.35537 .76963 Mdot
.36324 .8147 Mdot
.40689 .2828 Mdot
.53383 .5117 Mdot
.33017 .45692 Mdot
.24021 .40033 Mdot
.23347 .36336 Mdot
.50258 .21103 Mdot
.31215 .59467 Mdot
.58751 .73579 Mdot
.34059 .80338 Mdot
.18243 .53745 Mdot
.30036 .64328 Mdot
.19689 .61631 Mdot
.68112 .31598 Mdot
.24896 .37074 Mdot
.17917 .59905 Mdot
.62807 .67421 Mdot
.74803 .55845 Mdot
.37649 .82739 Mdot
.3364 .27164 Mdot
.64192 .48068 Mdot
.65507 .74872 Mdot
.22008 .37533 Mdot
.67849 .62794 Mdot
.63997 .479 Mdot
.43205 .59356 Mdot
.52626 .7709 Mdot
.55795 .4243 Mdot
.62427 .7205 Mdot
.56096 .49984 Mdot
.27328 .3499 Mdot
.60629 .32921 Mdot
.27402 .31734 Mdot
.53625 .37551 Mdot
.54255 .51363 Mdot
.34866 .32839 Mdot
.30899 .26383 Mdot
.66533 .71652 Mdot
.32039 .74985 Mdot
.76024 .65973 Mdot
.81256 .5923 Mdot
.73153 .62295 Mdot
.4658 .67197 Mdot
.41884 .54076 Mdot
.24599 .69081 Mdot
.14142 .5438 Mdot
.18263 .61068 Mdot
.78269 .59747 Mdot
.59065 .32171 Mdot
.6616 .51386 Mdot
.39644 .30529 Mdot
.5154 .43068 Mdot
.60632 .565 Mdot
.48747 .37206 Mdot
.72374 .51432 Mdot
.68771 .76807 Mdot
.57802 .57683 Mdot
.40404 .29243 Mdot
.32326 .6283 Mdot
.43038 .58154 Mdot
.29295 .71399 Mdot
.54287 .62907 Mdot
.78568 .58643 Mdot
.29132 .3019 Mdot
.65386 .36246 Mdot
.70418 .38142 Mdot
.54549 .55184 Mdot
.41997 .55428 Mdot
.64836 .29859 Mdot
.56082 .53897 Mdot
.43715 .63774 Mdot
.59506 .31926 Mdot
.16659 .50839 Mdot
.19722 .40218 Mdot
.17712 .59529 Mdot
.31429 .27517 Mdot
.7056 .36072 Mdot
.40194 .36052 Mdot
.64191 .55522 Mdot
.73314 .5851 Mdot
.4291 .38729 Mdot
.31939 .26331 Mdot
.34899 .73977 Mdot
.52686 .60455 Mdot
.29487 .48659 Mdot
.18435 .51467 Mdot
.37261 .30032 Mdot
.4129 .35995 Mdot
.49155 .74191 Mdot
.52957 .70615 Mdot
.46718 .19794 Mdot
.62964 .73446 Mdot
.37561 .43185 Mdot
.69844 .62075 Mdot
.71676 .55334 Mdot
.52843 .63879 Mdot
.30722 .2643 Mdot
.60267 .19534 Mdot
.57336 .616 Mdot
.48488 .52716 Mdot
.22279 .66121 Mdot
.51462 .48791 Mdot
.66482 .62188 Mdot
.55905 .78976 Mdot
.80066 .52124 Mdot
.60059 .71387 Mdot
.55029 .50891 Mdot
.59235 .49628 Mdot
.56281 .76155 Mdot
.58672 .65063 Mdot
.30679 .69742 Mdot
.21489 .67115 Mdot
.5369 .46313 Mdot
.62287 .70172 Mdot
.37681 .35448 Mdot
.578 .43745 Mdot
.50859 .58157 Mdot
.34054 .32517 Mdot
.61504 .65027 Mdot
.22443 .60699 Mdot
.75328 .72736 Mdot
.28782 .57885 Mdot
.42316 .21389 Mdot
.39961 .30467 Mdot
.45966 .64195 Mdot
.35268 .70645 Mdot
.7592 .5754 Mdot
.36736 .47316 Mdot
.21201 .67798 Mdot
.70457 .69119 Mdot
.37195 .33621 Mdot
.64999 .44441 Mdot
.38951 .54108 Mdot
.43032 .49785 Mdot
.18407 .60799 Mdot
.55844 .74975 Mdot
.62373 .83988 Mdot
.36396 .2435 Mdot
.47461 .61081 Mdot
.36542 .7505 Mdot
.24945 .33106 Mdot
.49936 .64848 Mdot
.58164 .60003 Mdot
.54341 .38197 Mdot
.23394 .35541 Mdot
.59726 .75975 Mdot
.61976 .75433 Mdot
.73061 .61507 Mdot
.36141 .81043 Mdot
.47683 .57519 Mdot
.75809 .53846 Mdot
.67624 .30982 Mdot
.32874 .51392 Mdot
.74816 .67448 Mdot
.72641 .60349 Mdot
.60011 .42336 Mdot
.43133 .58983 Mdot
.13957 .54584 Mdot
.31747 .46942 Mdot
.75115 .65549 Mdot
.60945 .84111 Mdot
.67425 .82207 Mdot
.62362 .76542 Mdot
.24999 .72535 Mdot
.6139 .7547 Mdot
.66302 .62436 Mdot
.69733 .5585 Mdot
.49036 .46704 Mdot
.40442 .63704 Mdot
.19462 .64817 Mdot
.63676 .22083 Mdot
.72499 .57668 Mdot
.32676 .61646 Mdot
.19298 .64834 Mdot
.30636 .48123 Mdot
.45075 .20283 Mdot
.59212 .39827 Mdot
.30864 .2399 Mdot
.2105 .36371 Mdot
.50566 .75842 Mdot
.33352 .22498 Mdot
.43572 .19505 Mdot
.46056 .28996 Mdot
.20083 .40016 Mdot
.24628 .55277 Mdot
.50496 .74741 Mdot
.30044 .29862 Mdot
.67887 .61253 Mdot
.42371 .15328 Mdot
.5077 .58155 Mdot
.56135 .52831 Mdot
.53035 .73768 Mdot
.65154 .60758 Mdot
.67037 .6943 Mdot
.51691 .50547 Mdot
.4413 .42883 Mdot
.33244 .73921 Mdot
.82815 .58002 Mdot
.58071 .79908 Mdot
.5652 .56019 Mdot
.31186 .76431 Mdot
.76446 .56744 Mdot
.43488 .38197 Mdot
.37654 .72817 Mdot
.37847 .30547 Mdot
.68065 .32112 Mdot
.37793 .4881 Mdot
.21864 .67629 Mdot
.67979 .32019 Mdot
.29924 .7516 Mdot
.17418 .42332 Mdot
.20215 .61395 Mdot
.38499 .58916 Mdot
.6643 .31455 Mdot
.245 .35301 Mdot
.24583 .35478 Mdot
.36463 .79882 Mdot
.41198 .20837 Mdot
.43576 .3975 Mdot
.53478 .49228 Mdot
.48128 .52334 Mdot
.37488 .42918 Mdot
.24437 .33604 Mdot
.47993 .66023 Mdot
.2921 .34312 Mdot
.6625 .75947 Mdot
.31329 .2642 Mdot
.35709 .73731 Mdot
.37602 .31451 Mdot
.57407 .40364 Mdot
.52545 .30134 Mdot
.62929 .40118 Mdot
.4354 .84298 Mdot
.75167 .6116 Mdot
.19438 .43394 Mdot
.80829 .57689 Mdot
.69391 .71896 Mdot
.38965 .21845 Mdot
.52699 .60806 Mdot
.26738 .56484 Mdot
.64851 .24161 Mdot
.31893 .30928 Mdot
.31061 .70696 Mdot
.69262 .60966 Mdot
.4891 .76671 Mdot
.19649 .63661 Mdot
.27562 .35117 Mdot
.49946 .86159 Mdot
.61544 .28655 Mdot
.4278 .72117 Mdot
.25831 .68508 Mdot
.80873 .62948 Mdot
.41369 .35647 Mdot
.30391 .76777 Mdot
.59003 .70492 Mdot
.23569 .70431 Mdot
.69565 .50348 Mdot
.56705 .26881 Mdot
.68168 .60104 Mdot
.39516 .3302 Mdot
.39796 .33277 Mdot
.17392 .4758 Mdot
.7642 .65582 Mdot
.73074 .69982 Mdot
.56824 .38031 Mdot
.59389 .35945 Mdot
.48062 .47639 Mdot
.62473 .67604 Mdot
.44629 .84374 Mdot
.40791 .55098 Mdot
.6043 .28339 Mdot
.27479 .30706 Mdot
.64182 .55352 Mdot
.56983 .53437 Mdot
.67332 .60321 Mdot
.54112 .78975 Mdot
.24831 .38172 Mdot
.34996 .8045 Mdot
.57029 .53814 Mdot
.51276 .4163 Mdot
.45693 .7446 Mdot
.61597 .56662 Mdot
.7858 .5446 Mdot
.61179 .62301 Mdot
.50201 .49991 Mdot
.40807 .39521 Mdot
.31922 .27572 Mdot
.14748 .50959 Mdot
.33166 .78005 Mdot
.78817 .54202 Mdot
.40127 .34307 Mdot
.55188 .72858 Mdot
.33209 .3111 Mdot
.4909 .86286 Mdot
.31657 .22291 Mdot
.66321 .74374 Mdot
.30686 .27293 Mdot
.62741 .4427 Mdot
.43817 .20752 Mdot
.42114 .37282 Mdot
.25607 .68217 Mdot
.33236 .61052 Mdot
.5335 .73273 Mdot
.63581 .47223 Mdot
.3657 .36178 Mdot
.58921 .53779 Mdot
.49914 .7435 Mdot
.76638 .64988 Mdot
.50119 .86127 Mdot
.40686 .20188 Mdot
.46038 .7365 Mdot
.5349 .84625 Mdot
.51638 .66081 Mdot
.59682 .49793 Mdot
.71004 .45509 Mdot
.39285 .34263 Mdot
.64649 .3338 Mdot
.45397 .56138 Mdot
.44931 .4202 Mdot
.59967 .76969 Mdot
.6679 .40356 Mdot
.49216 .27324 Mdot
.56762 .6381 Mdot
.42496 .1997 Mdot
.52046 .64535 Mdot
.1516 .49957 Mdot
.62863 .66589 Mdot
.32685 .7312 Mdot
.55709 .8032 Mdot
.70374 .32034 Mdot
.81549 .59785 Mdot
.20476 .62812 Mdot
.26305 .38774 Mdot
.58387 .64414 Mdot
.55205 .6273 Mdot
.60232 .74787 Mdot
.65263 .49784 Mdot
.22643 .66029 Mdot
.26413 .31111 Mdot
.70975 .35779 Mdot
.55916 .71449 Mdot
.54575 .48946 Mdot
.55936 .55648 Mdot
.17013 .51969 Mdot
.63141 .33151 Mdot
.28122 .75607 Mdot
.47798 .6664 Mdot
.77531 .67251 Mdot
.61064 .57405 Mdot
.39754 .40743 Mdot
.42377 .35832 Mdot
.69545 .38263 Mdot
.29915 .4816 Mdot
.47614 .60501 Mdot
.52843 .6525 Mdot
.59238 .52322 Mdot
.53864 .26375 Mdot
.55457 .17607 Mdot
.64993 .56981 Mdot
.45362 .65675 Mdot
.23672 .33967 Mdot
.54014 .62901 Mdot
.61545 .28889 Mdot
.6916 .298 Mdot
.3042 .52401 Mdot
.22348 .42742 Mdot
.41388 .83575 Mdot
.21234 .63533 Mdot
.58696 .66457 Mdot
.80591 .59581 Mdot
.54227 .33403 Mdot
.16777 .50401 Mdot
.58178 .75915 Mdot
.26106 .32283 Mdot
.45426 .69567 Mdot
.17406 .57363 Mdot
.37262 .75125 Mdot
.60509 .59305 Mdot
.30051 .29158 Mdot
.55101 .42817 Mdot
.30176 .2744 Mdot
.53268 .79281 Mdot
.48822 .50067 Mdot
.30796 .24371 Mdot
.63887 .44122 Mdot
.30657 .65766 Mdot
.42675 .46708 Mdot
.60641 .57125 Mdot
.24112 .34982 Mdot
.5632 .64036 Mdot
.55035 .26249 Mdot
.34263 .62421 Mdot
.73544 .57617 Mdot
.22093 .66737 Mdot
.77171 .60501 Mdot
.2794 .299 Mdot
.48034 .53002 Mdot
.37093 .27968 Mdot
.4785 .65038 Mdot
.28242 .38972 Mdot
.35714 .45193 Mdot
.46205 .69488 Mdot
.50747 .37865 Mdot
.18159 .48683 Mdot
.4435 .48446 Mdot
.25794 .7086 Mdot
.18594 .53307 Mdot
.58389 .76388 Mdot
.57491 .49098 Mdot
.57446 .71112 Mdot
.28167 .75154 Mdot
.22609 .40453 Mdot
.6568 .60464 Mdot
.21368 .3603 Mdot
.46788 .19468 Mdot
.54851 .84606 Mdot
.73647 .65444 Mdot
.55315 .53427 Mdot
.18709 .41545 Mdot
.70326 .69671 Mdot
.44676 .19341 Mdot
.30666 .70239 Mdot
.57029 .74024 Mdot
.30891 .77644 Mdot
.25775 .57403 Mdot
.71896 .7085 Mdot
.28036 .70106 Mdot
.6086 .66963 Mdot
.22072 .41207 Mdot
.30136 .47229 Mdot
.62248 .39167 Mdot
.4981 .44448 Mdot
.34209 .21831 Mdot
.58246 .62558 Mdot
.25609 .32407 Mdot
.26132 .32492 Mdot
.40062 .22453 Mdot
.70125 .36075 Mdot
.54991 .84542 Mdot
.385 .77759 Mdot
.42175 .4956 Mdot
.58991 .66768 Mdot
.49449 .27143 Mdot
.36502 .25326 Mdot
.405 .52179 Mdot
.33099 .38928 Mdot
.46278 .70621 Mdot
.20347 .66502 Mdot
.58089 .42576 Mdot
.74591 .51064 Mdot
.56712 .7162 Mdot
.65555 .6073 Mdot
.49382 .66114 Mdot
.76464 .66945 Mdot
.24536 .34596 Mdot
.57632 .61794 Mdot
.60609 .60683 Mdot
.70959 .71417 Mdot
.30715 .30308 Mdot
.50303 .3432 Mdot
.67635 .54719 Mdot
.42697 .63568 Mdot
.40838 .81714 Mdot
.7182 .69803 Mdot
.53692 .59854 Mdot
.6481 .72638 Mdot
.495 .4956 Mdot
.76746 .53374 Mdot
.76237 .65911 Mdot
.51075 .69508 Mdot
.22536 .62046 Mdot
.61441 .69419 Mdot
.6578 .30701 Mdot
.34698 .25576 Mdot
.63492 .71498 Mdot
.25006 .33377 Mdot
.301 .50896 Mdot
.26828 .71127 Mdot
.37463 .33665 Mdot
.54816 .25254 Mdot
.38373 .4704 Mdot
.41558 .60636 Mdot
.18332 .60756 Mdot
.64711 .7505 Mdot
.38296 .60095 Mdot
.51087 .65415 Mdot
.19682 .39565 Mdot
.63004 .30132 Mdot
.59891 .31385 Mdot
.43639 .24911 Mdot
.40523 .41226 Mdot
.51074 .42903 Mdot
.64266 .51073 Mdot
.30195 .48268 Mdot
.48897 .33774 Mdot
.49584 .50803 Mdot
.42935 .63876 Mdot
.20427 .4105 Mdot
.43048 .83882 Mdot
.5089 .59014 Mdot
.20461 .36711 Mdot
.38092 .61246 Mdot
.58955 .7226 Mdot
.41557 .19893 Mdot
.3413 .59972 Mdot
.31355 .55276 Mdot
.54818 .25846 Mdot
.51446 .67225 Mdot
.42447 .83312 Mdot
.45696 .5799 Mdot
.53583 .22951 Mdot
.5614 .35888 Mdot
.49542 .56785 Mdot
.76477 .35045 Mdot
.71075 .59178 Mdot
.18677 .41048 Mdot
.29242 .30052 Mdot
.71859 .50198 Mdot
.60736 .75622 Mdot
.34851 .6018 Mdot
.26698 .71256 Mdot
.52187 .39182 Mdot
.21015 .6417 Mdot
.73331 .48279 Mdot
.44275 .65616 Mdot
.18742 .52646 Mdot
.3001 .35691 Mdot
.28628 .38594 Mdot
.4786 .72788 Mdot
.24227 .48029 Mdot
.5088 .55225 Mdot
.58796 .19559 Mdot
.40313 .16445 Mdot
.46886 .85563 Mdot
.77081 .67671 Mdot
.36766 .4394 Mdot
.32718 .31311 Mdot
.61387 .70851 Mdot
.43978 .38925 Mdot
.55653 .37346 Mdot
.6397 .29438 Mdot
.65339 .44958 Mdot
.82151 .57861 Mdot
.21113 .67512 Mdot
.38284 .47089 Mdot
.47444 .35677 Mdot
.47306 .23849 Mdot
.63245 .32525 Mdot
.30171 .62879 Mdot
.4103 .83269 Mdot
.67661 .54458 Mdot
.72424 .45186 Mdot
.63841 .51766 Mdot
.1759 .47552 Mdot
.70003 .43707 Mdot
.65255 .51437 Mdot
.15079 .49908 Mdot
.68153 .74722 Mdot
.50665 .78057 Mdot
.81945 .56871 Mdot
.18138 .50292 Mdot
.4594 .68716 Mdot
.64127 .30062 Mdot
.23878 .69818 Mdot
.42223 .35944 Mdot
.69034 .35348 Mdot
.22264 .52678 Mdot
.30125 .28746 Mdot
.35757 .24852 Mdot
.71947 .48933 Mdot
.34158 .6139 Mdot
.55445 .16155 Mdot
.70612 .32082 Mdot
.78601 .70031 Mdot
.21233 .63074 Mdot
.43418 .81176 Mdot
.62356 .75871 Mdot
.57376 .39041 Mdot
.26198 .70404 Mdot
.25954 .33187 Mdot
.35924 .60749 Mdot
.61755 .2127 Mdot
.32125 .34328 Mdot
.35511 .30842 Mdot
.76324 .52442 Mdot
.18527 .59677 Mdot
.70457 .34914 Mdot
.24222 .53306 Mdot
.28792 .2977 Mdot
.39501 .61211 Mdot
.28184 .39493 Mdot
.39813 .81164 Mdot
.22099 .42571 Mdot
.32733 .25552 Mdot
.65725 .4504 Mdot
.54601 .31688 Mdot
.42171 .82812 Mdot
.49136 .6245 Mdot
.45467 .70308 Mdot
.61288 .84055 Mdot
.2597 .73181 Mdot
.33022 .59856 Mdot
.31419 .51643 Mdot
.15899 .4654 Mdot
.58721 .3031 Mdot
.204 .41821 Mdot
.66532 .77558 Mdot
.36852 .23691 Mdot
.4561 .50765 Mdot
.39026 .50184 Mdot
.40999 .27175 Mdot
.56027 .75574 Mdot
.35665 .6108 Mdot
.68819 .42377 Mdot
.32142 .26308 Mdot
.45665 .65636 Mdot
.75249 .72797 Mdot
.53453 .79036 Mdot
.55792 .70779 Mdot
.22736 .68795 Mdot
.25823 .60014 Mdot
.46773 .64395 Mdot
.25728 .6893 Mdot
.51591 .4003 Mdot
.49173 .33813 Mdot
.4776 .64635 Mdot
.4025 .35873 Mdot
.34434 .21487 Mdot
.53208 .84865 Mdot
.41174 .64224 Mdot
.28893 .7629 Mdot
.16527 .57154 Mdot
.55834 .71019 Mdot
.30525 .60487 Mdot
.41528 .34296 Mdot
.60738 .65113 Mdot
.65003 .46816 Mdot
.70068 .38267 Mdot
.48791 .19557 Mdot
.54704 .17717 Mdot
.38656 .51951 Mdot
.73432 .48268 Mdot
.1987 .63754 Mdot
.48027 .19902 Mdot
.20342 .64806 Mdot
.46681 .68493 Mdot
.42273 .52608 Mdot
.67927 .81987 Mdot
.66106 .62275 Mdot
.35927 .57494 Mdot
.32284 .44166 Mdot
.33763 .43717 Mdot
.36972 .47758 Mdot
.66849 .46847 Mdot
.39204 .30116 Mdot
.35903 .23575 Mdot
.23809 .69342 Mdot
.5448 .71263 Mdot
.42047 .35459 Mdot
.72798 .56378 Mdot
.35108 .37193 Mdot
.26053 .46648 Mdot
.72579 .54767 Mdot
.36311 .22487 Mdot
.76309 .35177 Mdot
.53197 .35924 Mdot
.58533 .55243 Mdot
.42917 .4227 Mdot
.56753 .58862 Mdot
.38897 .21026 Mdot
.64681 .50619 Mdot
.46195 .29174 Mdot
.28378 .29586 Mdot
.48123 .74453 Mdot
.76179 .53935 Mdot
.4866 .14121 Mdot
.41673 .36203 Mdot
.70208 .4651 Mdot
.2915 .579 Mdot
.53892 .77985 Mdot
.22643 .63758 Mdot
.50615 .33578 Mdot
.50327 .55506 Mdot
.45355 .73761 Mdot
.25164 .69327 Mdot
.72082 .53682 Mdot
.14582 .52211 Mdot
.2885 .5724 Mdot
.30515 .63284 Mdot
.38811 .79206 Mdot
.55958 .51162 Mdot
.31664 .71064 Mdot
.3907 .45244 Mdot
.49547 .40941 Mdot
.74756 .33527 Mdot
.56782 .55009 Mdot
.50249 .57478 Mdot
.60283 .63579 Mdot
.41748 .21621 Mdot
.23871 .61555 Mdot
.35324 .48528 Mdot
.48166 .26512 Mdot
.38992 .3551 Mdot
.56635 .29143 Mdot
.57267 .29046 Mdot
.74626 .56029 Mdot
.38507 .21319 Mdot
.36376 .24428 Mdot
.28666 .70076 Mdot
.27763 .73609 Mdot
.43133 .47285 Mdot
.2103 .62431 Mdot
.56031 .41077 Mdot
.67689 .69282 Mdot
.22435 .42416 Mdot
.52688 .8489 Mdot
.47991 .59861 Mdot
.36276 .43416 Mdot
.16226 .54463 Mdot
.19565 .6184 Mdot
.72425 .58044 Mdot
.69243 .61363 Mdot
.37333 .17966 Mdot
.4027 .33258 Mdot
.82482 .57917 Mdot
.66771 .43729 Mdot
.16475 .52669 Mdot
.49938 .52119 Mdot
.31837 .59274 Mdot
.4808 .70532 Mdot
.31486 .55066 Mdot
.6377 .34836 Mdot
.55689 .78875 Mdot
.48007 .73184 Mdot
.24883 .47109 Mdot
.42656 .49917 Mdot
.61435 .49414 Mdot
.55323 .73086 Mdot
.47522 .85622 Mdot
.64204 .32131 Mdot
.51206 .41303 Mdot
.72191 .75156 Mdot
.75184 .33946 Mdot
.46193 .19211 Mdot
.35352 .79214 Mdot
.72825 .58764 Mdot
.49841 .50516 Mdot
.82561 .4584 Mdot
.58294 .71938 Mdot
.58911 .66109 Mdot
.64266 .56308 Mdot
.3758 .2818 Mdot
.75003 .66251 Mdot
.57376 .84586 Mdot
.17253 .56892 Mdot
.30191 .51427 Mdot
.83869 .63779 Mdot
.28308 .30082 Mdot
.48905 .38116 Mdot
.75547 .65234 Mdot
.21652 .67146 Mdot
.64628 .44906 Mdot
.1737 .43228 Mdot
.62886 .71004 Mdot
.60911 .69337 Mdot
.36975 .29674 Mdot
.80302 .58183 Mdot
.54696 .49369 Mdot
.78801 .69585 Mdot
.70925 .62113 Mdot
.35309 .31481 Mdot
.64243 .75026 Mdot
.60177 .70069 Mdot
.47681 .59556 Mdot
.63018 .65254 Mdot
.42174 .59018 Mdot
.55475 .60514 Mdot
.611 .61303 Mdot
.50897 .34776 Mdot
.60817 .5319 Mdot
.65444 .61849 Mdot
.6539 .56114 Mdot
.50067 .75691 Mdot
.35375 .19696 Mdot
.59252 .28896 Mdot
.60878 .32824 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`2Kooooo`;o0000[?ooool001cooooo00?o0000ooooooooool0Voooool2o`000:cooooo000L
ooooo`03o`000?oooooooooo09;ooooo0_l00006ooooo`;o0000[Oooool001cooooo00?o0000oooo
ooooool0T_ooool2o`0000Kooooo1?l0002[ooooo`007?ooool00ol0003oooooooooo`2Aooooo`;o
00002Oooool2o`000:_ooooo000Looooo`03o`000?oooooooooo097ooooo0_l0002fooooo`007?oo
ool2o`0008Oooooo0_l00031ooooo`007?ooool00ol0003oooooooooo`26ooooo`;o0000`Oooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2`ooooo`;o
0000Uoooool001cooooo00?o0000ooooooooool0Ooooool2o`0002oooooo0_l0002Gooooo`007?oo
ool00ol0003oooooooooo`1mooooo`Co0000b?ooool001cooooo00?o0000ooooooooool0OOooool2
o`000<[ooooo000Looooo`03o`000?oooooooooo07Wooooo0_l0000booooo`Ko0000U_ooool001co
oooo00?o0000ooooooooool0Moooool4o`0003;ooooo1_l0002Fooooo`007?ooool00ol0003ooooo
ooooo`1fooooo`?o0000=Oooool4o`0009Oooooo000Looooo`03o`000?oooooooooo07Kooooo0_l0
000mooooo`;o000000?oooooo`000?l00000Soooool001cooooo00?o0000ooooooooool0/Oooool2
o`0000;ooooo1Ol0002?ooooo`007?ooool00ol0003oooooooooo`1`ooooo`;o0000?oooool2o`00
00?ooooo0_l000000ooooooo0000o`00002>ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5
ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0L?ooool2o`0001_ooooo0_l00003
ooooo`;o00009Oooool2o`0008kooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ
8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1^ooooo`?o0000
6Oooool2o`000003ooooool0003o000000?ooooo1?l00005ooooo`;o00007_ooool2o`0000?ooooo
0_l00027ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ
8B7ok^k^00Oooooo00?o0000ooooooooool0KOooool4o`0001;ooooo0_l000000ooooooo0000o`00
0002ooooo`;o00002?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000Nooooo`;o000000?o
ooooo`000?l000000_l00027ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0;
ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0001]ooooo`;o00004Oooool2o`000004ooooool0003o
0000ooooo`?o00001_ooool2o`0000?ooooo0_l00002ooooo`;o00009?ooool2o`0008Wooooo0000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool0
0ol0003oooooooooo`20ooooo`;o00001Oooool2o`0000Kooooo0_l0000cooooo`;o0000Poooool0
0003ooooool@413ooooo00;ooooo00?o410@ooooooooool03Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo08;ooooo0_l00007ooooo`;o0000=oooool2o`0008?ooooo00001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oo
oooooooo07_ooooo0_l00005ooooo`;o00001oooool2o`0000Oooooo0ol00008ooooo`Co00001_oo
ool2o`00013ooooo0_l0002<ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Wooooo`Co000000?oooooo`000?l0
00002oooool4o`0000Wooooo0_l00008ooooo`?o000000Coooooo`000?l0003o00002?ooool4o`00
00Kooooo0_l0000@ooooo`;o00002?ooool3o`00087ooooo000Looooo`03o`000?oooooooooo06Oo
oooo1ol0000;ooooo`Co00001oooool6o`0000Kooooo0ol0000booooo`?o0000POooool001cooooo
00?o0000ooooooooool0I?ooool2o`0000Gooooo0_l00002ooooo`;o00002_ooool2o`0000Oooooo
0_l000001?oooooo0000o`000?l00007ooooo`;o0000>?ooool2o`0007cooooo000Looooo`03o`00
0?oooooooooo06;ooooo1?l00006ooooo`;o000000?oooooo`000?l000002_ooool2o`000003oooo
ool0003o000000Oooooo0_l00004ooooo`;o00002oooool2o`0000Oooooo0_l0000Vooooo`;o0000
O?ooool001cooooo00?o0000ooooooooool0H_ooool3o`0000Cooooo0_l000000ooooooo0000o`00
0004ooooo`;o00001oooool2o`000003ooooool0003o000000Gooooo0ol00005ooooo`;o00002Ooo
ool4o`0000Oooooo0ol0002Sooooo`007?ooool00ol0003oooooooooo`1Nooooo`Co00001oooool2
o`0000Oooooo0_l0000Aooooo`?o00001?ooool2o`0000[ooooo0ol00009ooooo`;o000000Cooooo
o`000?l0003ooooo0_l0000Jooooo`;o0000POooool001cooooo00?o0000ooooooooool0G_ooool6
o`00027ooooo0_l00005ooooo`;o00002oooool2o`0000?ooooo0_l000000ooooooo0000o`000002
o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00005_ooool2o`00087ooooo000Loooo
o`03o`000?oooooooooo067ooooo0ol00002ooooo`;o00002Oooool2o`000003ooooool0003o0000
00;ooooo0_l0000Pooooo`;o00000_ooool2o`000003ooooool0003o000000Go00001_ooool2o`00
01Sooooo0_l0001oooooo`007?ooool00ol0003oooooooooo`1Pooooo`Wo00001oooool3o`000003
ooooool0003o000000;ooooo0_l0000Looooo`?o000000?oooooo`000?l000003?l0000Pooooo`;o
0000Ooooool001cooooo00?o0000ooooooooool0G_ooool;o`0000Oooooo0_l0000Iooooo`;o0000
2?oooolDo`0002Kooooo0_l0001hooooo`007?ooool00ol0003oooooooooo`1Nooooo`Ko00000_oo
ool2o`0000Sooooo1?l0000Gooooo`Co00001_ooool3o`000003ooooool0003o000000ko000000?o
ooooo`000?l000008oooool2o`0007Sooooo000Looooo`03o`000?oooooooooo063ooooo0_l00004
ooooo`;o00002?ooool4o`0001Kooooo0_l000000ooooooo0000o`000007ooooo`;o00001Oooool?
o`0009gooooo000Looooo`;o0000IOooool2o`0000[ooooo0_l0000Hooooo`;o000000?oooooo`00
0?l000001oooool4o`0000;ooooo4_l0000Uooooo`;o0000M?ooool001cooooo00?o0000oooooooo
ool0I?ooool2o`0000cooooo0ol0000>ooooo`;o00002?ooool2o`0000?ooooo0ol00003ooooo`;o
00000_ooool:o`0000;ooooo2?l0000Sooooo`;o0000M?ooool001cooooo00?o0000ooooooooool0
I?ooool5o`0000Cooooo0_l00003ooooo`Co00003Oooool2o`0000Sooooo0_l00003ooooo`?o0000
0oooool2o`0000;ooooo5?l000000ooooooo0000o`00002Fooooo`007?ooool00ol0003ooooooooo
o`1Tooooo`Go00001?ooool2o`0000?ooooo1?l0000;ooooo`;o00002_ooool2o`0000Wooooo0_l0
0002oooooaCo000000?oooooo`000?l00000U_ooool001cooooo00?o0000ooooooooool0H?ooool7
o`0000?ooooo0_l00004ooooo`Co00003Oooool2o`00013ooooo0_l00007oooooa;o000000?ooooo
o`000?l00000V?ooool001cooooo00?o0000ooooooooool0Goooool8o`0000?ooooo0_l00002oooo
o`Co00003oooool2o`0000Oooooo0ol00003ooooo`;o000000?oooooo`000?l000000_l00002oooo
oaWo0000Uoooool001cooooo00?o0000ooooooooool0Goooool2o`0000_ooooo1?l0000Aooooo`;o
00001oooool3o`0000?ooooo0_l00003ooooo`?o000000?oooooo`000?l000005ol00002ooooo`;o
0000Toooool001cooooo00?o0000ooooooooool0H?ooool2o`0000Sooooo1?l0000Cooooo`;o0000
4oooool2o`000003ooooool0003o000001Oo00000_ooool2o`0009?ooooo000Looooo`03o`000?oo
oooooooo05gooooo2Ol00004ooooo`?o00005?ooool2o`0000Sooooo0_l0000<oooooaWo0000Uooo
ool001cooooo00?o0000ooooooooool0G?ooool4o`0000;ooooo1?l0000?ooooo`;o00005?ooool2
o`0000oooooo4ol00003ooooo`;o0000UOooool001cooooo00?o0000ooooooooool0Foooool3o`00
00Gooooo0_l0000@ooooo`?o00002?ooool2o`00017ooooo0_l00002ooooo`;o000000?oooooo`00
0?l000006?l0002Eooooo`007?ooool00ol0003oooooooooo`1Kooooo`;o00001_ooool2o`00017o
oooo0_l00007ooooo`?o00004Oooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`000003
ooooool0003o000000go000000Coooooo`000?l0003o00003oooool2o`0008Kooooo000Looooo`03
o`000?oooooooooo05cooooo1?l0000Oooooo`;o00006_oooolFo`0000;ooooo0_l000000ooooooo
0000o`000005ooooo`;o00000_ooool2o`000003ooooool0003o000008?ooooo000Looooo`03o`00
0?oooooooooo05Wooooo0_l000000ooooooo0000o`000002o`0000kooooo0_l0000>ooooo`Co0000
4?ooool3o`0000Kooooo5Ol00003ooooo`Go00001Oooool2o`0000Gooooo0_l00023ooooo`007?oo
ool00ol0003oooooooooo`1Iooooo`;o00000oooool2o`0000kooooo0_l0000<ooooo`Ko00002ooo
ool2o`0000?ooooo0ol00008oooooa?o00000oooool5o`0001Cooooo0_l0001kooooo`007?ooool0
0ol0003oooooooooo`1Hooooo`Co00000_ooool2o`0000Sooooo0_l0000:ooooo`;o00001Oooool5
o`0000gooooo0_l0000Fooooo`[o00001?ooool2o`0000Wooooo0ol00002ooooo`;o00001oooool2
o`000003ooooool0003o000000cooooo0_l0001Zooooo`007?ooool2o`0005Kooooo2ol00008oooo
o`;o00002_ooool3o`0000;ooooo1_l000000ooooooo0000o`00000Uooooo`?o00000_ooool2o`00
00Kooooo0_l00008ooooo`?o00000_ooool2o`0000Cooooo0ol000000ooooooo0000o`000002o`00
00cooooo0_l0001Zooooo`007?ooool00ol0003oooooooooo`1Eooooo`Wo00000_ooool2o`0001?o
oooo0_l00002ooooo`Wo00003?ooool2o`0000Cooooo1?l0000?ooooo`;o00002oooool2o`0000Go
oooo0_l0000<ooooo`Ko0000N_ooool001cooooo00?o0000ooooooooool0E_ooool2o`0000?ooooo
0_l00003ooooo`Co00001Oooool2o`0000?ooooo0_l00007ooooo`Co00000_ooool3o`0000kooooo
0_l00004ooooo`Co00005oooool2o`0000[ooooo0_l00009ooooo`;o00000_ooool4o`000003oooo
ool0003o000000?o0000MOooool001cooooo00?o0000ooooooooool0E_ooool2o`0000[ooooo1?l0
00000ooooooo0000o`000002o`0000?ooooo1?l00005ooooo`?o00000oooool2o`0001Sooooo0_l0
000Booooo`;o00000_ooool3o`0001?ooooo0ol000001?oooooo0000o`000?l00003ooooo`Go0000
1?ooool2o`0006oooooo000Looooo`03o`000?oooooooooo05;ooooo0_l0000?ooooo`?o000000Co
ooooo`000?l0003o00001_ooool2o`0000Gooooo0_l00004ooooo`;o00006?ooool2o`0001;ooooo
0_l00003ooooo`;o00003Oooool2o`0000Cooooo0_l00002ooooo`?o00001?ooool4o`0000Cooooo
0_l0001_ooooo`007?ooool00ol0003oooooooooo`1@ooooo`Co00004oooool3o`0000Gooooo0_l0
0005ooooo`?o00001?ooool2o`000003ooooool0003o000001Cooooo0ol0000Booooo`;o000000?o
ooooo`000?l000003oooool2o`0000Cooooo0_l00002ooooo`?o00000_ooool2o`0000Cooooo0_l0
0003ooooo`;o0000K_ooool001cooooo00?o0000ooooooooool0D?ooool2o`0000?ooooo0_l0000H
ooooo`;o00001Oooool3o`0000Cooooo0_l000000ooooooo0000o`00000<ooooo`;o00001_ooool3
o`00013ooooo1?l000000ooooooo0000o`00000>ooooo`?o000000?oooooo`000?l000000ol00000
0ooooooo0000o`000002o`000004ooooool0003o0000o`0000Cooooo0_l00003ooooo`;o0000K_oo
ool001cooooo00?o0000ooooooooool0Coooool4o`0000;ooooo0_l0000@ooooo`Wo00000_ooool2
o`0000;ooooo0ol00004ooooo`?o00003_ooool2o`0000_ooooo0_l0000;ooooo`?o00004Oooool4
o`0000;ooooo3Ol0000:ooooo`;o00001_ooool3o`0006Gooooo000Looooo`03o`000?oooooooooo
04oooooo1?l0000Dooooo`ko000000?oooooo`000?l000001_ooool2o`0001_ooooo0ol0000:oooo
o`?o00004Oooool2o`0000?ooooo5Ol00003ooooo`;o00001_ooool3o`0006Gooooo000Looooo`03
o`000?oooooooooo04oooooo1?l0000Aooooo`;o00001Oooool<o`0001Sooooo1Ol00008ooooo`;o
00002oooool2o`0001Kooooo1_l000000ooooooo0000o`00000<o`0007?ooooo000Looooo`03o`00
0?oooooooooo04gooooo0_l00002ooooo`;o00004?ooool3o`0000Sooooo0_l00003ooooo`Co0000
1_ooool2o`00013ooooo1Ol0000;ooooo`;o00007_ooool5o`0000Cooooo2ol0001fooooo`007?oo
ool00ol0003oooooooooo`19ooooo`;o00000_ooool3o`000003ooooool0003o000000oooooo0ol0
000Hooooo`Co00004_ooool2o`0000Wooooo0ol0000;ooooo`;o00004Oooool5o`000003ooooool0
003o000000go00006oooool2o`0005Sooooo000Looooo`03o`000?oooooooooo04Wooooo0_l00000
0ooooooo0000o`000002o`0000Sooooo0_l00008ooooo`;o00004Oooool3o`0000Kooooo0ol0000B
ooooo`;o00001_ooool9o`0000Sooooo0_l0000AoooooaGo00001?ooool2o`0000Oooooo1?l0000:
ooooo`;o0000F?ooool001cooooo00?o0000ooooooooool0BOooool2o`000003ooooool0003o0000
00[ooooo0_l00007ooooo`?o00004Oooool3o`0002?ooooo0ol000000ooooooo0000o`000003o`00
00;ooooo0_l0000FoooooaOo00000oooool2o`0000Oooooo1?l00008ooooo`;o000000?oooooo`00
0?l00000Eoooool001cooooo00?o0000ooooooooool0BOooool2o`0000Kooooo0_l00008ooooo`;o
00001?ooool3o`000003ooooool0003o000001Gooooo0_l000000ooooooo0000o`000002ooooo`;o
00004_ooool2o`0000Oooooo0_l00004ooooo`;o000000?oooooo`000?l000004ooooolGo`000003
ooooool0003o000001Gooooo1Ol0001Gooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o0000
0oooool2o`0000Kooooo1?l000000ooooooo0000o`000005ooooo`;o00003?ooool2o`0000;ooooo
0_l00002ooooo`?o000000?oooooo`000?l000000_ooool2o`00013ooooo1?l00007ooooo`Co0000
00Goooooo`000?l0003o0000ooooo`04o`0000oooooo7?l0000Cooooo`;o000000?oooooo`000?l0
0000FOooool001cooooo0_l0001<ooooo`?o00001oooool2o`0000;ooooo0_l00002ooooo`Co0000
2?ooool2o`0000Sooooo1_l00002ooooo`Co00005_ooool3o`0000[ooooo0_l000001?oooooo0000
o`000?l00003ooooo`?o00003_oooolLo`0000Wooooo0_l000000ooooooo0000o`000005ooooo`;o
00002?ooool2o`0005;ooooo000Looooo`03o`000?oooooooooo04_ooooo0ol00007ooooo`?o0000
1?ooool7o`0000Kooooo0_l00002ooooo`Ko00000_ooool2o`0000Kooooo0_l0000Zooooo`;o0000
00Goooooo`000?l0003o0000ooooo`02o`0000;ooooo0_l00005ooooo`?o000000?oooooo`000?l0
00005?l00002ooooo`;o00000oooool2o`0000?ooooo0_l000000ooooooo0000o`00000>ooooo`?o
00001oooool2o`0004Wooooo000Looooo`03o`000?oooooooooo04;ooooo0_l00004ooooo`;o0000
0_ooool2o`0000Sooooo0_l000001?oooooo0000o`000?ooool4o`000003ooooool0003o000000[o
oooo2?l00002ooooo`;o00000_ooool2o`0000Kooooo1_l0000=ooooo`Co00003oooool=o`0000Go
oooo6ol000000ooooooo0000o`000003ooooo`;o00005_ooool2o`0000Sooooo0_l00019ooooo`00
7?ooool00ol0003oooooooooo`12ooooo`;o00001?ooool2o`0000;ooooo1?l00009ooooo`;o0000
0oooool2o`0000?ooooo0_l00004ooooo`?o00001oooool7o`000003ooooool0003o000000;ooooo
0_l000000ooooooo0000o`000005o`0000gooooo1?l00008ooooo`;o00001?ooool5o`000003oooo
ool0003o000000Go00001_oooolKo`0000gooooo0_l0000Jooooo`;o0000B?ooool001cooooo00?o
0000ooooooooool0@_ooool2o`0000[ooooo0_l00009ooooo`;o00001Oooool2o`000003ooooool0
003o000000Cooooo0ol00007ooooo`[o00000_ooool2o`000003ooooool0003o000000Co00004ooo
ool2o`0000Gooooo0_l00004ooooo`?o00000oooool2o`0000?ooooo0_l00008oooooa[o00001Ooo
ool2o`0000;ooooo1Ol0000Booooo`;o00001_ooool2o`0004Sooooo000Looooo`03o`000?oooooo
oooo047ooooo0ol00004ooooo`;o00002oooool2o`0000;ooooo0_l00004ooooo`Go00000oooool4
o`0000Sooooo2?l00003ooooo`?o00000oooool2o`0001Gooooo0_l0000Aooooo`Co00003?oooolI
o`0000Cooooo0ol00002ooooo`?o00005?ooool2o`000003ooooool0003o000000?ooooo0_l00018
ooooo`007?ooool00ol0003oooooooooo`0oooooo`Co00001Oooool2o`0000[ooooo0ol00002oooo
o`;o00000_ooool7o`0000?ooooo0ol00009ooooo`So00000oooool2o`0002oooooo0ol0000<oooo
oa;o00000_ooool5o`0000Cooooo0ol0000Looooo`;o0000COooool001cooooo00?o0000oooooooo
ool0?_ooool3o`0000Wooooo0_l000000ooooooo0000o`000005ooooo`;o00001oooool5o`0000Co
oooo1?l00002ooooo`Co00000oooool7o`0000;ooooo0_l00002ooooo`;o00006Oooool2o`00027o
oooo5Ol000001?oooooo0000o`000?l00005ooooo`;o0000Joooool001cooooo00?o0000oooooooo
ool0?_ooool2o`0000Cooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l0000;oooo
o`;o000000?oooooo`000?l000001?ooool4o`0000;ooooo1?l00003ooooo`Oo00000_ooool2o`00
00;ooooo0_l00003ooooo`;o00005?ooool2o`0000?ooooo0_l00008ooooo`;o00001Oooool2o`00
00_ooooo6Ol0001booooo`007?ooool00ol0003oooooooooo`14ooooo`;o00002Oooool3o`0000Oo
oooo0ol00003ooooo`;o00001_ooool2o`0000_ooooo2_l00004ooooo`;o000000?oooooo`000?l0
00006Oooool3o`0000Oooooo0_l00005ooooo`;o00000oooool2o`0000Kooooo6?l00009ooooo`;o
00008Oooool2o`0004Gooooo000Looooo`03o`000?oooooooooo04gooooo1?l00006ooooo`Go0000
0_ooool3o`00017ooooo0_l000000ooooooo0000o`000008o`0000?ooooo0_l0000Gooooo`;o0000
1?ooool2o`0001;ooooo0ol00004oooooa_o00000oooool2o`0000?ooooo1?l00006ooooo`;o0000
5oooool2o`0004Gooooo000Looooo`03o`000?oooooooooo04gooooo0_l00007ooooo`Co00000ooo
ool3o`0001;ooooo0_l00002ooooo`;o000000?oooooo`000?l000001?l0000;ooooo`;o00003ooo
ool2o`0000Cooooo1?l00008ooooo`;o00001_ooool2o`0000Gooooo0_l00002oooooaSo00000_oo
ool2o`0000;ooooo1Ol00006ooooo`;o00005oooool2o`0004Gooooo000Looooo`03o`000?oooooo
oooo05;ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000gooooo0_l00000
1?oooooo0000o`000?l00009ooooo`;o00000oooool2o`0000Cooooo1_l0000Gooooo`;o00002?oo
ool2o`0000gooooo0ol000000ooooooo0000o`00000Fo`0000Kooooo1?l0001Wooooo`007?ooool0
0ol0003oooooooooo`19ooooo`;o00001oooool4o`0000;ooooo1_l00009ooooo`?o00000_ooool2
o`000004ooooool0003o0000o`0000;ooooo0_l00003ooooo`[o00000oooool4o`000003ooooool0
003o000000;o0000:?ooool2o`0000Cooooo0_l000000ooooooo0000o`00000Do`0000Sooooo0_l0
000Sooooo`;o0000A?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo
0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo04Wooooo0_l00002ooooo`;o0000
00?oooooo`000?l000001Ol000000ooooooo0000o`000004o`0000Wooooo0ol00002ooooo`;o0000
1_ooool2o`0000?ooooo2_l00003ooooo`Co000000?oooooo`000?l000000_l0000Gooooo`;o0000
3oooool2o`0000Cooooo0_l00003oooooaCo00002Oooool2o`0002;ooooo0ol00013ooooo`0000Ko
ooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo03cooooo0_l0000=ooooo`oo00001Oooool2o`0000?ooooo0_l0000>ooooo`;o
00001Oooool:o`0000?ooooo0_l0000Looooo`;o00004_ooool2o`0000Cooooo3_l000000ooooooo
0000o`000005o`0000Sooooo0ol0000Sooooo`;o0000@oooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool02Oooool5o`0000Kooooo00?o0000ooooooooool0??ooool4o`0000Oooooo
0_l00002ooooo`oo000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l0000Fooooo`?o0000
0_ooool4o`0000Gooooo0_l0000^ooooo`;o000000?oooooo`000?l000000ol00002ooooo`;o0000
00?oooooo`000?l000003_l00007ooooo`?o00008oooool2o`0004?ooooo00000ooooooo0000oooo
o`02ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`0003cooooo
1?l00007ooooo`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o000000Coooooo`000?l0
003ooooo0_l000000ooooooo0000o`000002ooooo`;o00007oooool3o`000004ooooool0003o0000
o`0000;ooooo0ol00003ooooo`?o00004_ooool2o`0001Oooooo1?l00003ooooo`;o000000?ooooo
o`000?l000002_l00002ooooo`;o00002?ooool2o`0006Sooooo00000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`0l
ooooo`Co00001_ooool2o`0000;ooooo0_l0000booooo`Co00000_ooool3o`0000;ooooo0_l00004
ooooo`?o00004_ooool2o`00017ooooo0_l00004ooooo`;o00001?ooool3o`0000;ooooo2ol00002
ooooo`;o00001oooool2o`0006Wooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo
00[ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`16ooooo`;o0000=Oooool3o`00
00;ooooo1Ol00003ooooo`?o00003oooool3o`0000_ooooo0_l0000;ooooo`;o00000oooool2o`00
00Cooooo0ol00003ooooo`;o000000?oooooo`000?l000002?ooool2o`0000Oooooo0_l0000Soooo
o`Co0000@_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007
ooooo`03o`000?oooooooooo03Wooooo0_l00003ooooo`?o00000oooool2o`0000Gooooo0_l0000`
ooooo`;o000000?oooooo`000?l000001_l00002ooooo`?o00001?ooool2o`0000Wooooo0ol0000;
ooooo`;o00001_ooool2o`0000Sooooo0_l00004ooooo`?o00000oooool2o`0001Gooooo0_l0000R
ooooo`Co0000@_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000oooo
o`06ooooo`03o`000?oooooooooo03Sooooo0ol00002ooooo`Co00000oooool4o`0000?ooooo0_l0
000cooooo`;o00000_ooool4o`0000Cooooo0_l00003ooooo`;o00004?ooool2o`0000gooooo0_l0
000Cooooo`;o00005_ooool2o`0006Sooooo000Looooo`03o`000?oooooooooo03Sooooo0ol00002
ooooo`Co00001?ooool3o`000003ooooool0003o000003_ooooo0_l00004ooooo`;o00004?ooool2
o`0000?ooooo0_l00008ooooo`;o00006?ooool2o`00017ooooo0_l0001]ooooo`007?ooool00ol0
003oooooooooo`0oooooo`;o00001?ooool2o`0000;ooooo0_l0000kooooo`;o00001_ooool2o`00
00kooooo0_l00003ooooo`;o00002?ooool3o`0001Cooooo0_l000000ooooooo0000o`00000Aoooo
o`;o0000KOooool001cooooo00?o0000ooooooooool0=Oooool2o`0000Gooooo0_l00007ooooo`Co
0000?Oooool4o`0000Cooooo0_l00002ooooo`Go000000?oooooo`000?l000005?ooool5o`0000co
oooo0_l00003ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000oooooo0_l0001[oooo
o`007?ooool00ol0003oooooooooo`0eooooo`;o00001Oooool2o`0000Kooooo1Ol0000oooooo`;o
00000_ooool2o`0000Cooooo1Ol000000ooooooo0000o`00000Eooooo`Co00001_ooool2o`0000Co
oooo0_l00007ooooo`Go00001Oooool2o`0000Sooooo0_l0000Yooooo`;o0000@?ooool001cooooo
00?o0000ooooooooool0?_ooool2o`0000Cooooo1?l0000^ooooo`;o00004oooool3o`0000?ooooo
0_l000000ooooooo0000o`00000<ooooo`Co00002Oooool2o`0000Sooooo0_l0000=ooooo`?o0000
1?ooool2o`000004ooooool0003o0000o`0003;ooooo0_l00010ooooo`007?ooool00ol0003ooooo
ooooo`0eooooo`;o00001?ooool2o`000003ooooool0003o0000027ooooo0_l00009ooooo`;o0000
1?ooool2o`0000;ooooo0_l0000Cooooo`?o00000oooool2o`000003ooooool0003o000000Sooooo
0_l00002ooooo`Co00002Oooool2o`0001kooooo0_l000001?oooooo0000o`000?l00007ooooo`?o
0000J_ooool001cooooo00?o0000ooooooooool0=Oooool2o`0000Cooooo0_l000000ooooooo0000
o`000004ooooo`;o00006oooool2o`0000;ooooo0_l00002ooooo`So000000?oooooo`000?l00000
0_ooool2o`0001_ooooo0_l00009ooooo`Co00003Oooool2o`00027ooooo1ol00003ooooo`?o0000
00?oooooo`000?l000001_ooool2o`0001cooooo0_l00011ooooo`007?ooool00ol0003ooooooooo
o`14ooooo`;o00007oooool2o`0000;ooooo2?l00003ooooo`;o00001oooool2o`0001Cooooo0_l0
000;ooooo`;o00003Oooool2o`0000Oooooo0_l0000Cooooo`;o00001Oooool6o`000004ooooool0
003o0000o`0000;ooooo0_l00006ooooo`;o00007?ooool2o`00047ooooo000Looooo`03o`000?oo
oooooooo037ooooo0_l00009ooooo`;o00009oooool2o`0000;ooooo0_l000000ooooooo0000o`00
0006ooooo`Go00001?ooool2o`0001Gooooo1?l00003ooooo`;o00004oooool2o`000003ooooool0
003o000000?ooooo0_l00002ooooo`;o00002Oooool3o`0000;ooooo0ol00006ooooo`;o000000?o
ooooo`000?l000001?l0001[ooooo`007?ooool00ol0003oooooooooo`0`ooooo`Co00001oooool3
o`00027ooooo0_l00004ooooo`;o00003oooool4o`0001[ooooo1_l000001?oooooo0000o`000?oo
ool2o`00013ooooo0_l000000ooooooo0000o`000007ooooo`;o00002Oooool3o`0000;ooooo0_l0
00000ooooooo0000o`000007ooooo`Co0000;?ooool2o`0003oooooo000Looooo`03o`000?oooooo
oooo033ooooo1?l00007ooooo`;o00000_ooool4o`0001_ooooo0ol0000Gooooo`Go00001?ooool2
o`0001Gooooo0_l00004ooooo`;o00002oooool2o`0001gooooo0ol000001?oooooo0000o`000?l0
0007ooooo`?o0000;Oooool2o`0003oooooo000Looooo`;o0000??ooool2o`0000;ooooo1?l0000H
ooooo`Go00004?ooool2o`0000Kooooo1Ol00004ooooo`;o00009oooool4o`0001cooooo2ol00004
ooooo`;o00003?ooool2o`00063ooooo000Looooo`03o`000?oooooooooo03[ooooo0_l0000Noooo
o`Go00001_ooool2o`000003ooooool0003o000000_o00001Oooool5o`0001Oooooo0ol0000?oooo
o`Ko00001?ooool2o`0001Wooooo0_l000000ooooooo0000o`000003o`0000kooooo0_l00002oooo
o`;o0000>Oooool2o`0002Gooooo000Looooo`03o`000?oooooooooo03Wooooo0ol0000Nooooo`?o
00001oooool3o`000003ooooool0003o000000go00001Oooool3o`0001Oooooo1_l0000;ooooo`Oo
00001?ooool2o`0001_ooooo1?l00005ooooo`;o00002Oooool2o`0002?ooooo0_l0000Hooooo`;o
00009Oooool001cooooo00?o0000ooooooooool0=Oooool2o`0000;ooooo0_l0000Oooooo`;o0000
1_ooool9o`0000;ooooo3?l00003ooooo`;o00000oooool3o`0001Gooooo0ol0000:ooooo`So0000
1?ooool2o`0001_ooooo0_l000000ooooooo0000o`000004ooooo`;o0000;_ooool2o`0001Sooooo
0_l0000Uooooo`007?ooool00ol0003oooooooooo`0eooooo`;o00000oooool2o`0001Wooooo0ol0
0009ooooo`Oo00001Oooool2o`0000;ooooo2Ol00002ooooo`;o00000oooool3o`0001?ooooo0_l0
00000ooooooo0000o`000002o`0000?ooooo3Ol00004ooooo`?o00005oooool2o`0000Cooooo1Ol0
001booooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00002?ooool2o`0001;ooooo0_l00000
0ooooooo0000o`000005o`0000Oooooo1_l00006ooooo`Ko00000_ooool9o`0000_ooooo0_l0000>
ooooo`;o00000_ooool5o`000003ooooool0003o000000Go00000oooool4o`0000Cooooo0_l0000G
ooooo`;o00001Oooool4o`0000Wooooo0_l0001Wooooo`007?ooool00ol0003oooooooooo`0`oooo
o`;o00006oooool8o`0000[ooooo0ol000001?oooooo0000o`000?l00002ooooo`Wo000000?ooooo
o`000?l000002_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l0000Cooooo`Co000000?o
ooooo`000?l000001Ol00005ooooo`;o00008?ooool2o`0000Cooooo0_l00009ooooo`;o00000_oo
ool2o`0006?ooooo000Looooo`03o`000?oooooooooo033ooooo0_l0000Kooooo`;o000000?ooooo
o`000?l000000ol00008ooooo`Co00000_ooool3o`0000;ooooo5_l000001?oooooo0000o`000?oo
ool5o`000003ooooool0003o000001?ooooo0_l00005ooooo`;o00001oooool3o`0001_ooooo0_l0
0002ooooo`;o00001?ooool2o`0000gooooo0_l0001Sooooo`007?ooool00ol0003oooooooooo`0`
ooooo`;o00000oooool2o`0001_ooooo0ol00007ooooo`Co00001ooooolIo`0000;ooooo1Ol00000
0ooooooo0000o`00000>ooooo`;o00005?ooool2o`0000Gooooo0_l0000Dooooo`;o00000oooool4
o`000003ooooool0003o000001;ooooo0_l0001Nooooo`007?ooool00ol0003oooooooooo`0eoooo
o`;o00005?ooool2o`0000oooooo0ol00006oooooaGo000000?oooooo`000?l000001?l000001?oo
oooo0000o`000?ooool2o`00017ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00001ooo
ool2o`0000?ooooo1?l00003ooooo`;o00005Oooool2o`0000;ooooo1?l0000Eooooo`Co0000G?oo
ool001cooooo00?o0000ooooooooool0Boooool2o`0000?ooooo0_l0000:ooooo`Ko00000ooooolH
o`000005ooooool0003o0000o`000?ooool00_l0000Dooooo`;o00000_ooool2o`000004ooooool0
003o0000o`0000Gooooo1?l00004ooooo`Co00001?ooool2o`0001?ooooo0ol0000Kooooo`?o0000
G?ooool001cooooo00?o0000ooooooooool0Coooool3o`0000[ooooo1_l00003oooooago00002_oo
ool2o`0000[ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo1?l0
0004ooooo`Co00001?ooool2o`0001;ooooo1?l00006ooooo`;o00004oooool3o`0005cooooo000L
ooooo`03o`000?oooooooooo03Oooooo0_l0000@ooooo`;o00001?ooool2o`0000Wooooo1?l00005
ooooo`;o000000?oooooo`000?l000007?l00008ooooo`;o00003_ooool4o`000003ooooool0003o
000000;o00002Oooool2o`000004ooooool0003o0000o`0001Oooooo0ol00007ooooo`Co00001_oo
ool2o`0000Gooooo0_l00003ooooo`;o0000=_ooool2o`0002Cooooo000Looooo`03o`000?oooooo
oooo03Oooooo0_l0000@ooooo`;o00003_ooool8o`000003ooooool0003o0000023o00001?ooool2
o`0000;ooooo0_l0000>ooooo`Co000000?oooooo`000?l000000_l00005ooooo`;o00000_ooool2
o`0000;ooooo0ol00002ooooo`Co00007?ooool6o`0000;ooooo0ol00004ooooo`;o00001Oooool4
o`0003;ooooo0_l0000Tooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00002_ooool8o`00
0003ooooool0003o000002?o000000?oooooo`000?l000000_ooool3o`0000kooooo0_l0000;oooo
o`;o00000_ooool2o`0000?ooooo0_l00002ooooo`Co00002Oooool2o`0000;ooooo0_l0000<oooo
o`co00002Oooool6o`0001Gooooo0ol00010ooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o
00002Oooool2o`0001?ooooo0_l0000:ooooo`Go00001?ooool2o`0000;ooooo8Ol000001?oooooo
0000o`000?l00002ooooo`;o00003_ooool2o`0000oooooo0_l00003ooooo`?o00000oooool2o`00
00;ooooo0ol00004ooooo`;o00000_ooool2o`0000Cooooo1?l00003ooooo`_o00002oooool2o`00
01Wooooo0ol00010ooooo`007?ooool2o`0002kooooo0ol00008ooooo`;o00007oooool5o`0000Co
oooo0_l00002ooooobGo00004?ooool2o`0000;ooooo0_l0000Aooooo`Co00000oooool3o`000004
ooooool0003o0000o`0000gooooo1Ol000000ooooooo0000o`00000?o`0000Kooooo0_l0000foooo
o`;o00009Oooool001cooooo00?o0000ooooooooool0;Oooool3o`0000?ooooo0_l00002ooooo`;o
00004oooool2o`0000_ooooo1Ol00004ooooo`;o00000_oooolHo`0000;ooooo2ol00003ooooo`;o
00002oooool2o`0000;ooooo0_l0000Aooooo`;o00001Oooool3o`0000[ooooo0_l00005ooooo`;o
00000oooool9o`000003ooooool0003o000000Oo000000?oooooo`000?l000000_ooool2o`0003Ko
oooo0_l0000Uooooo`007?ooool00ol0003oooooooooo`0aooooo`Co00000_ooool2o`0001?ooooo
0ol0000;ooooo`Co00001?ooool2o`0000;ooooo1Ol000000ooooooo0000o`00000Bo`000003oooo
ool0003o000000So00000oooool4o`0000_ooooo0ol00004ooooo`;o00003Oooool5o`0000;ooooo
0_l0000:ooooo`;o00001_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000Ao`0000Oooooo
0_l0000Eooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0;?ooool2o`0000?ooooo0ol0
0004ooooo`;o00004oooool2o`0000_ooooo1_l00002ooooo`;o000000?oooooo`000?l000009?l0
0004ooooo`?o00002oooool3o`0000Cooooo0_l00009ooooo`;o00000_ooool5o`0000kooooo0_l0
0005ooooo`?o00000_ooool2o`000003ooooool0003o0000013o00001oooool3o`0000;ooooo0ol0
000@ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0;?ooool2o`0000Cooooo0_l00004
ooooo`;o00008?ooool6o`0000;ooooo:Ol0000Oooooo`Co000000Coooooo`000?l0003ooooo0_l0
00000ooooooo0000o`00000?ooooo`;o00001Oooool2o`0000?ooooo5_l000000ooooooo0000o`00
0003ooooo`;o000000?oooooo`000?l000000ol0000[ooooo`;o00009_ooool001cooooo00?o0000
ooooooooool0:oooool2o`0000_ooooo0_l0000Pooooo`Ko00000_ooool3o`000003ooooool0003o
0000027o00002Oooool2o`0000Cooooo0_l0000@ooooo`Co00001?ooool2o`0000Oooooo1?l0000<
ooooo`;o00000oooool;o`000003ooooool0003o000000go00001Oooool3o`0002kooooo0_l0000V
ooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o00001oooool2o`0000;ooooo0_l0000Roooo
o`Co00000_oooolJo`0000?ooooo1ol000001?oooooo0000o`000?l00007ooooo`?o00001?ooool4
o`0001_ooooo0_l00002ooooo`Co00003?ooool3o`0000;ooooo6Ol00007ooooo`;o00004oooool2
o`0001Wooooo0_l0000Wooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00000_ooool2o`00
00;ooooo0_l00002ooooo`Co00004?ooool2o`0000kooooo0ol00003oooooa[o00000oooool7o`00
00;ooooo1Ol00004ooooo`;o00001_ooool3o`0000;ooooo0_l0000Gooooo`;o000000Coooooo`00
0?l0003ooooo0_l0000=ooooo`;o00001_oooolEo`0001Oooooo0_l00003ooooo`;o00006Oooool2
o`0002Oooooo000Looooo`03o`000?oooooooooo02cooooo0_l00002ooooo`;o00001_ooool4o`00
013ooooo0_l0000=ooooo`Ko00000_ooool2o`000003ooooool0003o000001go000000?oooooo`00
0?l000000_ooool3o`0000Cooooo0_l00006ooooo`;o00000oooool2o`0001Kooooo0_l00002oooo
o`;o000000?oooooo`000?l000003oooool2o`0000Oooooo4ol000000ooooooo0000o`000007oooo
o`;o00002_ooool2o`0001gooooo0_l0000Xooooo`007?ooool00ol0003oooooooooo`0booooo`;o
00001Oooool2o`0000[ooooo0_l00005ooooo`;o00003Oooool6o`0000;ooooo0_l000000ooooooo
0000o`00000Po`0000Wooooo0_l00005ooooo`Co00005oooool2o`000004ooooool0003o0000oooo
o`;o00004oooool2o`0000Gooooo6?l00004ooooo`;o000000?oooooo`000?l000002?ooool4o`00
01gooooo0_l0000Xooooo`007?ooool00ol0003oooooooooo`0booooo`;o00004Oooool2o`0000Go
oooo0_l0000=ooooo`?o00001OoooolOo`0000;ooooo1?l0000@ooooo`Co000000?oooooo`000?l0
00005?ooool2o`0000;ooooo1Ol00006ooooo`;o00000oooool2o`0000[ooooo6_l00004ooooo`;o
00002oooool2o`0004Wooooo000Looooo`03o`000?oooooooooo03Wooooo0_l0000@ooooo`;o0000
3oooool3o`0000Cooooo9_l0000?ooooo`;o00000oooool2o`00017ooooo0_l00003ooooo`Co0000
00Coooooo`000?l0003ooooo0_l00003ooooo`;o00000oooool4o`0000Oooooo2ol000000ooooooo
0000o`00000=o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0005;ooooo000Looooo`03
o`000?oooooooooo03Sooooo0ol0000<ooooo`;o00000_ooool2o`0000oooooo0ol00005ooooo`Go
000000?oooooo`000?l000004Ol000001Ooooooo0000o`000?l0003ooooo00Oo00001oooool2o`00
01kooooo0_l00003ooooo`Co00000oooool3o`0000[ooooo0_l00007oooooaKo00000_ooool2o`00
00;ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00009_ooool2o`0002[ooooo000Loooo
o`03o`000?oooooooooo03Sooooo0_l0000<ooooo`?o00005?ooool4o`0000?ooooo1Ol000000ooo
oooo0000o`000002o`000003ooooool0003o0000013o00000_ooool6o`0000Oooooo0_l00003oooo
o`;o00006oooool2o`000003ooooool0003o000000Co000000?oooooo`000?l000005ooooolHo`00
00Gooooo1_l0000Uooooo`;o0000:_ooool001cooooo00?o0000ooooooooool0:_ooool2o`0000Go
oooo0_l00006ooooo`?o00002_ooool2o`0001Gooooo1?l00004oooooa_o000000?oooooo`000?l0
00001Ol0000=ooooo`Co00000oooool8o`0000kooooo0_l00002ooooo`Go00005oooool2o`000003
ooooool0003o000001Ko00001oooool4o`0000?ooooo0ol0001;ooooo`007?ooool00ol0003ooooo
ooooo`0Zooooo`;o00001Oooool2o`0000Kooooo0ol0000Rooooo`?o000000Coooooo`000?l0003o
oooo2ol000000ooooooo0000o`00000:o`000003ooooool0003o000000Go00001Oooool2o`0000_o
oooo1?l000000ooooooo0000o`000007o`00017ooooo0_l000000ooooooo0000o`00000>ooooo`?o
00001_ooool2o`0000;ooooo5ol00003ooooo`;o00000oooool2o`0000Cooooo1_l0000Jooooo`;o
0000;?ooool001cooooo0_l0000[ooooo`;o00003_ooool2o`0001Gooooo0_l0000;ooooo`?o0000
00Coooooo`000?l0003o00001Oooool2o`000003ooooool0003o000001Ko000000?oooooo`000?l0
00000_ooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000003o`0000Co
oooo2_l0000<ooooo`Ko00003_ooool3o`0000_ooooo5_l00002ooooo`?o00002oooool5o`0001Wo
oooo0_l0000/ooooo`007?ooool00ol0003oooooooooo`0jooooo`;o00004?ooool2o`0000?ooooo
0_l0000<ooooo`;o000000Coooooo`000?l0003o00000oooool2o`0000?ooooo5_l00002ooooo`?o
00001Oooool2o`0000Cooooo2?l00004ooooo`[o00001?ooool2o`0000Kooooo1ol0000Aooooo`;o
00001oooool8o`000003ooooool0003o000000_o00000_ooool3o`0000?ooooo0_l0000:ooooo`;o
00006Oooool2o`0002cooooo000Looooo`03o`000?oooooooooo04cooooo0_l0000Aooooo`Go0000
1?ooool>o`000003ooooool0003o000000Wo00000oooool4o`0000;ooooo0_l00006ooooo`?o0000
00?oooooo`000?l000001_ooool;o`0000?ooooo0_l00003ooooo`;o00000_ooool6o`00017ooooo
0_l00007oooooaCo00001?ooool2o`0000Cooooo0_l0001Cooooo`007?ooool00ol0003ooooooooo
o`1Pooooo`?o000000Coooooo`000?l0003o00000oooool=o`000003ooooool0003o000000_o0000
0_ooool2o`0000;ooooo0ol00003ooooo`Go00002Oooool=o`0000Cooooo2_l0000Cooooo`;o0000
2?ooool5o`0000;ooooo2?l000001?oooooo0000o`000?l00004ooooo`?o00000_ooool2o`0002Co
oooo0_l0000^ooooo`007?ooool00ol0003oooooooooo`1Rooooo`Ko00000_ooool2o`000003oooo
ool0003o0000013o00000oooool3o`0000Oooooo0_l00002ooooo`Ko00002_ooool=o`0000?ooooo
0_l00002ooooo`;o00000_ooool2o`0001?ooooo0_l00002ooooo`;o00001_ooool5o`000003oooo
ool0003o000000Wooooo0_l00003ooooo`;o00000_ooool2o`0002Cooooo0_l0000^ooooo`007?oo
ool00ol0003oooooooooo`0booooo`;o00007oooool2o`0000gooooo1_l00002ooooo`;o000000?o
ooooo`000?l000003Ol000001?oooooo0000o`000?ooool4o`0000[ooooo1?l00007ooooo`;o0000
1Oooool=o`0001Cooooo0_l000000ooooooo0000o`000005ooooo`Co00000_ooool2o`000003oooo
ool0003o000000Gooooo0ol000001?oooooo0000o`000?l00007ooooo`?o00002_ooool2o`00057o
oooo000Looooo`03o`000?oooooooooo03;ooooo1?l0000=ooooo`;o00001_ooool4o`0000;ooooo
1?l0000>ooooo`?o00002oooool8o`000004ooooool0003o0000ooooo`Go00002Oooool5o`0000Wo
oooo0_l00002ooooo`;o000000?oooooo`000?l000002ol0000:ooooo`;o00002?ooool2o`000003
ooooool0003o000000Gooooo1?l00005ooooo`;o00001Oooool2o`0000;ooooo0ol000000ooooooo
0000o`000007o`0000Oooooo1_l0000=ooooo`?o0000@?ooool001cooooo00?o0000ooooooooool0
<_ooool4o`0000gooooo0_l00006ooooo`Co00000_ooool2o`0000Oooooo0_l00007ooooo`Ko0000
2_ooool6o`0000;ooooo1_l0000:ooooo`Co00002Oooool2o`0000?ooooo0_l00002ooooo`Oo0000
00?oooooo`000?l000000_l0000:ooooo`;o00002?ooool2o`0000Wooooo1Ol0000<ooooo`;o0000
00Coooooo`000?l0003ooooo1ol00002ooooo`;o00001Oooool6o`0000gooooo0ol00010ooooo`00
7?ooool00ol0003oooooooooo`0booooo`;o000000?oooooo`000?l000003?ooool2o`0000_ooooo
0ol00007ooooo`;o00002_ooool7o`000004ooooool0003o0000ooooo`;o00001?ooool2o`0000;o
oooo2?l000000ooooooo0000o`000002ooooo`?o00003?ooool3o`0000Gooooo3_l0000Dooooo`Ko
00001_ooool4o`0000cooooo1?l00002ooooo`;o00000_ooool2o`0000?ooooo0_l000000ooooooo
0000o`000002ooooo`;o000000?oooooo`000?l000000_l00007ooooo`;o00000_ooool2o`0000?o
oooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0eooooo`;o00005Oooool3o`000004oooo
ool0003o0000o`0000Oooooo0_l0000<ooooo`So000000?oooooo`000?l000003_ooool:o`0000Go
oooo0_l00005ooooo`;o00001_ooool2o`000003ooooool0003o000000So00000_ooool2o`0000So
oooo0_l00009ooooo`Co00001oooool3o`0000Sooooo0_l00004ooooo`;o00000oooool2o`000005
ooooool0003o0000o`000?ooool00_l00002ooooo`;o000000Coooooo`000?l0003o00000oooool2
o`0000Oooooo2?l000000ooooooo0000o`00000mooooo`007?ooool00ol0003oooooooooo`1<oooo
o`?o00000_ooool2o`0000Oooooo0ol0000>ooooo`Go00003Oooool2o`0000Cooooo1ol00004oooo
o`Go00001?ooool2o`0000Cooooo0_l00002ooooo`oo00001_ooool4o`0000_ooooo0_l0000=oooo
o`?o00000_ooool2o`0000Wooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00001Oooool2
o`0000;ooooo0_l00009ooooo`Co00000_ooool4o`0000[ooooo0ol0000aooooo`007?ooool00ol0
003oooooooooo`18ooooo`;o00001oooool2o`0000Kooooo1?l0000Aooooo`Co000000?oooooo`00
0?l000000ol000000ooooooo0000o`000006o`0000Oooooo0_l000000ooooooo0000o`000003o`00
0003ooooool0003o000000Cooooo0_l00003ooooo`?o00000_ooool2o`000003ooooool0003o0000
00Wo00001oooool2o`0001cooooo0ol0000:ooooo`;o00001?ooool5o`0000[ooooo0_l00009oooo
o`;o00001Oooool3o`0000[ooooo0ol0000aooooo`007?ooool00ol0003oooooooooo`18ooooo`;o
00003oooool2o`0001Cooooo0ol000000ooooooo0000o`000003o`000003ooooool0003o000000Ko
00002_ooool4o`0000?ooooo0_l00003ooooo`Co000000?oooooo`000?l000001_ooool:o`0000Oo
oooo0ol0000Kooooo`?o00002oooool2o`0000Kooooo0ol0000?ooooo`;o00002oooool2o`0003oo
oooo000Looooo`03o`000?oooooooooo02gooooo0_l00017ooooo`;o000000?oooooo`000?l00000
2_ooool2o`000003ooooool0003o000000Sooooo0_l00004ooooo`?o000000?oooooo`000?l00000
1?ooool2o`0000Gooooo0_l000000ooooooo0000o`000007ooooo`;o00007?ooool2o`0000?ooooo
0_l00009ooooo`;o00001?ooool2o`0000Oooooo0_l00007ooooo`;o00002oooool2o`0003oooooo
00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@
4?o<c<`01_ooool00ol0003oooooooooo`0]ooooo`;o0000=Oooool2o`000003ooooool0003o0000
013ooooo0_l0000:ooooo`;o000000Coooooo`000?l0003o00003Oooool2o`0000;ooooo1?l00002
ooooo`;o00001Oooool4o`0000Sooooo0_l0000:ooooo`;o00005Oooool2o`000004ooooool0003o
0000o`0000Cooooo0ol00006ooooo`;o00001Oooool2o`00013ooooo0_l00013ooooo`0000Kooooo
ogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Ko
oooo00?o0000ooooooooool0<oooool2o`000003ooooool0003o000000;o00007_ooool2o`0000;o
oooo0_l00004ooooo`Co000000?oooooo`000?l000003Oooool2o`00013ooooo0ol00004ooooo`;o
00001_ooool3o`0000Cooooo0_l0000;ooooo`;o000000?oooooo`000?l000000_ooool4o`0000_o
oooo0_l00008ooooo`;o00003?ooool5o`0000Cooooo1Ol00004ooooo`;o00004_ooool7o`0000;o
oooo0_l0000oooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`0cooooo`;o000000?oooooo`000?l0
00000_l0000Booooo`;o00000_ooool2o`0000Kooooo0_l00002ooooo`;o00001?ooool4o`0000;o
oooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00002ooooo`?o00002_ooool2o`00
00Sooooo1?l00006ooooo`?o00002Oooool2o`0000Kooooo0_l000000ooooooo0000o`000002oooo
o`Co00000oooool2o`00013ooooo0_l0000<ooooo`Co00000oooool2o`000003ooooool0003o0000
00;o00001oooool2o`0000Oooooo0_l000000ooooooo0000o`000003ooooo`Go000000Coooooo`00
0?l0003ooooo0_l0000oooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09oooo
o`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0002gooooo0_l00008ooooo`;o00004oooool2
o`0000;ooooo0_l0000Fooooo`;o000000?oooooo`000?l000000ol00002ooooo`;o00000oooool4
o`0000Sooooo0_l00008ooooo`;o00002Oooool4o`0000Oooooo0_l000000ooooooo0000o`000003
ooooo`;o00002_ooool4o`0001cooooo0_l000001?oooooo0000o`000?l00003ooooo`;o00001_oo
ool2o`0000Cooooo0_l00007ooooo`;o000000Coooooo`000?l0003o00002?ooool2o`0004;ooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oeEEEOl0003o410@
olc<c006ooooo`03o`000?oooooooooo02gooooo0_l0000Sooooo`;o00001_ooool2o`0000?ooooo
1?l0000:ooooo`;o00002_ooool2o`0000Sooooo0_l0000Booooo`;o000000?oooooo`000?l00000
2?ooool5o`000003ooooool0003o000000Cooooo0_l00005ooooo`;o00006Oooool2o`0000?ooooo
0_l000000ooooooo0000o`000006o`000004ooooool0003o0000o`0000;ooooo0_l000000ooooooo
0000o`00000:ooooo`;o00000_ooool2o`0001Cooooo0_l0000fooooo`0000?ooooooa0@4?ooool0
0_ooool00ol@413oooooooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0
>?ooool2o`0000_ooooo0_l0000;ooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo
1?l000001?oooooo0000o`000?l0000:ooooo`;o00000_ooool4o`0000[ooooo0_l0000Booooo`;o
00002oooool2o`000004ooooool0003o0000ooooo`?o00000oooool2o`0000oooooo0_l0000:oooo
o`;o000000?oooooo`000?l000000_l00008ooooo`[o00001Oooool2o`0000;ooooo0_l00006oooo
o`;o00005oooool3o`0003Kooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00?ogMgM
oa0@4?nHV9P02?ooool00ol0003oooooooooo`0eooooo`;o000000?oooooo`000?l000002oooool4
o`0000cooooo0_l00009ooooo`?o000000Goooooo`000?l0003o0000ooooo`02o`0000Kooooo0ol0
0002ooooo`Go00000oooool2o`0001Oooooo0_l0000?ooooo`;o00000_ooool2o`0001Cooooo0_l0
000:ooooo`;o000000Coooooo`000?l0003o00001_ooool2o`000003ooooool0003o000000Go0000
3?ooool3o`0001kooooo0_l0000gooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`04
olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0=Oooool2o`000003ooooool0003o0000
00Cooooo0_l00007ooooo`;o000000?oooooo`000?l000004_ooool5o`0000;ooooo0_l000001?oo
oooo0000o`000?ooool2o`0000?ooooo0ol000000ooooooo0000o`000002ooooo`;o00000oooool2
o`0001Oooooo0_l00007ooooo`?o00007oooool4o`0000Sooooo0_l0000:ooooo`;o00000_ooool2
o`000004ooooool0003o0000o`0000Gooooo1?l00004ooooo`;o0000Eoooool001cooooo00?o0000
ooooooooool0??ooool4o`0000Sooooo1?l0000Booooo`;o00001_ooool2o`0000?ooooo0ol00003
ooooo`;o000000?oooooo`000?l00000:Oooool3o`00017ooooo0_l000001?oooooo0000o`000?l0
000:ooooo`;o00002?ooool3o`000003ooooool0003o000000[ooooo0_l000001?oooooo0000o`00
0?l00005ooooo`Co0000GOooool001cooooo00?o0000ooooooooool0??ooool2o`0000Oooooo0_l0
00000ooooooo0000o`000002o`0001Kooooo0_l00002ooooo`;o00001?ooool2o`0004Gooooo0_l0
00001?oooooo0000o`000?l0000Eooooo`;o000000Coooooo`000?l0003ooooo0_l00005ooooo`;o
00000_ooool2o`0000;ooooo0_l0001Tooooo`007?ooool00ol0003oooooooooo`0kooooo`;o0000
1?ooool2o`0000;ooooo0_l0000Kooooo`?o00001oooool2o`0002kooooo0_l0000=ooooo`?o0000
2?ooool2o`0000_ooooo0_l0000>ooooo`?o00001Oooool2o`0000;ooooo0_l00002ooooo`;o0000
1Oooool2o`0002;ooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`0kooooo`;o00000_oo
ool4o`00023ooooo0_l00007ooooo`;o0000;_ooool2o`0000Cooooo0_l00007ooooo`?o000000?o
ooooo`000?l000001ol000000ooooooo0000o`000008ooooo`;o00003_ooool3o`0000?ooooo0_l0
0002ooooo`;o00002oooool2o`0001Sooooo0_l00008ooooo`;o0000>Oooool001cooooo00?o0000
ooooooooool0?oooool4o`0001_ooooo0_l00005ooooo`;o0000>oooool2o`0000Sooooo3ol0000F
ooooo`;o00001_ooool2o`0000;ooooo0_l0000Tooooo`?o0000@oooool001cooooo00?o0000oooo
ooooool0?oooool4o`0000[ooooo0_l0000?ooooo`?o00001?ooool2o`0001_ooooo0_l000001?oo
oooo0000o`000?l0000Jooooo`;o00001Oooool2o`000003ooooool0003o000000go00005_ooool5
o`0002gooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0looooo`;o00000oooool2o`00
00[ooooo0_l0000@ooooo`;o00007oooool=o`0001cooooo0_l000000ooooooo0000o`000007o`00
0003ooooool0003o000000?o00001Oooool2o`00017ooooo0ol0000gooooo`;o0000>_ooool001co
oooo00?o0000ooooooooool0??ooool3o`0000;ooooo0_l00003ooooo`;o0000=oooool3o`0000;o
oooo2Ol00004ooooo`;o000000?oooooo`000?l000003Oooool2o`000003ooooool0003o000000Oo
00001?ooool5o`0000;ooooo0_l00004ooooo`;o0000Boooool2o`0003[ooooo000Looooo`03o`00
0?oooooooooo03gooooo0_l00002ooooo`;o00000oooool2o`0001Kooooo0_l000001?oooooo0000
o`000?l0000Iooooo`Co000000?oooooo`000?l000001?ooool4o`0000Gooooo1Ol00009ooooo`;o
00000_ooool;o`0000Gooooo1_l000000ooooooo0000o`000004ooooo`;o0000Boooool2o`0003[o
oooo000Looooo`03o`000?oooooooooo047ooooo0_l0000Kooooo`;o000000Coooooo`000?l0003o
00006Oooool3o`0000;ooooo0_l0000=ooooo`Go000000?oooooo`000?l000001_ooool3o`0000?o
oooo1ol00004ooooo`Wo000000?oooooo`000?l000001?ooool2o`0004Oooooo0_l0000nooooo`00
7?ooool00ol0003oooooooooo`0kooooo`Go00007?ooool2o`00027ooooo0_l0000Cooooo`;o0000
00Coooooo`000?l0003o00001?ooool4o`0000?ooooo5?l000001?oooooo0000o`000?ooool2o`00
04[ooooo0_l0000nooooo`007?ooool2o`0003cooooo1Ol0000>ooooo`;o000000?oooooo`000?l0
00002Oooool4o`0001kooooo0ol0000Fooooo`?o00001?ooool2o`0000Gooooo6_l00003ooooo`Co
00000oooool2o`0002;ooooo0_l00003ooooo`Go00000oooool2o`0004gooooo000Looooo`03o`00
0?oooooooooo04kooooo0_l000000ooooooo0000o`00000;ooooo`Co00007?ooool4o`0001Gooooo
0ol00005ooooo`;o000000Coooooo`000?l0003ooooo6?l00005ooooo`Co00000oooool2o`00023o
oooo3?l00003ooooo`;o0000COooool001cooooo00?o0000ooooooooool0C_ooool4o`0000cooooo
1?l0000Nooooo`;o00002_ooool2o`0000;ooooo0ol00004ooooo`?o00001Oooool2o`000004oooo
ool0003o0000oooooaKo00001_ooool2o`0002?ooooo0_l00003ooooo`;o000000?oooooo`000?l0
00000_l00002ooooo`?o00000_ooool2o`0004kooooo000Looooo`03o`000?oooooooooo04;ooooo
0_l000001?oooooo0000o`000?l00006ooooo`Co00003?ooool4o`0002[ooooo0_l00002ooooo`?o
00001Oooool2o`0000?ooooo0_l00005oooooaOo000000?oooooo`000?l000000oooool2o`0002?o
oooo0ol0000:ooooo`Co00000_ooool2o`0004kooooo000Looooo`03o`000?oooooooooo03kooooo
0_l00002ooooo`;o000000Coooooo`000?l0003o0000D?ooool2o`0000?ooooo0ol000001?oooooo
0000o`000?oooolJo`0002Wooooo0_l00007ooooo`;o000000Coooooo`000?l0003o00000_ooool2
o`0000cooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00001?ooool2o`00
00cooooo0_l00004ooooo`;o0000?_ooool2o`0000Cooooo0_l000000ooooooo0000o`00000Mo`00
0003ooooool0003o000000Gooooo0_l0000Vooooo`;o000000?oooooo`000?l000000_l000000ooo
oooo0000o`00000<ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0@_ooool4o`0000co
oooo0_l00002ooooo`Co00001_ooool2o`0003Kooooo0_l00009oooooaGo000000?oooooo`000?l0
00001Ol000001?oooooo0000o`000?l00004ooooo`;o00009_ooool2o`0000?ooooo0ol0000=oooo
o`;o0000@_ooool001cooooo00?o0000ooooooooool0@_ooool5o`0000oooooo0_l00007ooooo`Co
00009_ooool2o`0000Wooooo0_l000000ooooooo0000o`00000:oooooaWo00000_ooool6o`0000Co
oooo0_l0000Uooooo`Co00000_ooool5o`0000_ooooo0_l00012ooooo`007?ooool00ol0003ooooo
ooooo`11ooooo`Ko00004oooool2o`0000?ooooo1?l0000Tooooo`Co00002Oooool2o`000003oooo
ool0003o000000;o00001oooool3o`000003ooooool0003o000001Go000000?oooooo`000?l00000
0_l00005ooooo`?o00009?ooool5o`0000Cooooo0ol0001?ooooo`007?ooool00ol0003ooooooooo
o`11ooooo`Co00003_ooool2o`0000Gooooo0_l0000[ooooo`Co00003_ooool2o`0000Oooooo0_l0
0003oooooa_o00001Oooool2o`0001Sooooo0_l0000;ooooo`?o000000?oooooo`000?l000000ooo
ool2o`0000[ooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`11ooooo`;o00001oooool2
o`0000?ooooo0_l00002ooooo`;o00001oooool2o`0000Kooooo0_l0000Oooooo`;o000000?ooooo
o`000?l000006oooool2o`000003ooooool0003o000000Co000000?oooooo`000?l000003ol0000Q
ooooo`;o00003?ooool2o`000003ooooool0003o000000oooooo0_l00014ooooo`007?ooool00ol0
003oooooooooo`1:ooooo`;o00000oooool3o`0000Sooooo1Ol00004ooooo`Go00007?ooool3o`00
00_ooooo1?l00003ooooo`;o00001?ooool2o`0000Cooooo0_l000000ooooooo0000o`00000Fo`00
01kooooo0_l0001Yooooo`007?ooool00ol0003oooooooooo`16ooooo`;o00002?ooool2o`0000So
oooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000007?ooool2o`0000_o
oooo1Ol00003ooooo`;o00001?ooool2o`0000Oooooo6?l00003ooooo`;o00006Oooool2o`0000ko
oooo0_l0001Iooooo`007?ooool00ol0003oooooooooo`16ooooo`;o00001?ooool2o`0000;ooooo
0_l00005ooooo`;o00000oooool4o`0002_ooooo0_l00004ooooo`;o00005Oooool?o`000003oooo
ool0003o000000?o00000_ooool2o`0000;ooooo0_l0000Cooooo`;o00001oooool2o`0000[ooooo
0ol0001Iooooo`007?ooool00ol0003oooooooooo`1:ooooo`Oo00001_ooool2o`0000?ooooo1Ol0
000Zooooo`Co000000?oooooo`000?l000000_l00004ooooo`;o00002?oooolKo`000005ooooool0
003o0000o`000?ooool01?l0000?ooooo`Go00001oooool2o`0000Cooooo0_l00004ooooo`?o0000
3?ooool3o`0004[ooooo000Looooo`03o`000?oooooooooo04[ooooo0_l00002ooooo`?o000000?o
ooooo`000?l000002Oooool5o`0002_ooooo0_l000000ooooooo0000o`000002o`0000Cooooo1?l0
0006ooooobCo00003oooool3o`0000Wooooo0_l00002ooooo`Co00000_ooool4o`0000gooooo0ol0
001:ooooo`007?ooool2o`0004Wooooo1?l00006ooooo`;o00000oooool4o`0000Gooooo0_l0000;
ooooo`;o0000:oooool2o`0000Sooooo0_l00002ooooo`?o000000?oooooo`000?l000004?l00002
ooooo`;o00001Oooool2o`0001Sooooo0_l00002ooooo`;o00000_ooool4o`0000oooooo0_l0001;
ooooo`007?ooool00ol0003oooooooooo`18ooooo`?o00001_ooool2o`0000Cooooo1?l00005oooo
o`;o00002oooool2o`00027ooooo0_l00009ooooo`;o00002?ooool2o`0000?ooooo5?l00002oooo
o`;o00001Oooool2o`0001Gooooo0_l00006ooooo`Ko00004?ooool2o`0004_ooooo000Looooo`03
o`000?oooooooooo04Wooooo0_l00006ooooo`;o00003Oooool5o`0000[ooooo0_l0000Kooooo`Ko
000000?oooooo`000?l000000oooool2o`000003ooooool0003o000000Sooooo5_l000000ooooooo
0000o`00000Pooooo`;o00001_ooool3o`00063ooooo000Looooo`03o`000?oooooooooo04Wooooo
0_l00005ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Gooooo1Ol0000:ooooo`;o0000
6oooool5o`0000;ooooo0ol00002ooooo`;o00000_ooool2o`0000Sooooo1Ol00003ooooo`go0000
0oooool2o`0000Cooooo0_l00002ooooo`;o00007?ooool3o`00063ooooo000Looooo`03o`000?oo
oooooooo04Wooooo0_l00005ooooo`;o000000?oooooo`000?l000001?ooool4o`0000Kooooo0ol0
0006ooooo`;o00000oooool2o`0001[ooooo0_l00005ooooo`;o00001_ooool3o`0000Kooooo0_l0
00000ooooooo0000o`00000?o`0000;ooooo1_l00003ooooo`;o00000_ooool2o`0001Sooooo0ol0
00000ooooooo0000o`00001Qooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00001_ooool3
o`0000Kooooo0ol00005ooooo`;o00000oooool2o`0002;ooooo0_l00005ooooo`?o00001Oooool3
o`0000;ooooo6_l00007ooooo`;o00002?ooool2o`0000Wooooo1_l00006ooooo`;o0000G?ooool0
01cooooo00?o0000ooooooooool0G?ooool3o`0000Kooooo0_l00003ooooo`?o00009?ooool2o`00
00;ooooo0_l00005ooooo`?o00001Oooool2o`0000Cooooo1?l000001?oooooo0000o`000?ooool:
o`0000Gooooo0_l00004ooooo`Go00002?ooool2o`0000Sooooo1ol00003ooooo`;o000000?ooooo
o`000?l00000G?ooool001cooooo00?o0000ooooooooool0GOooool2o`0000Gooooo0_l000001?oo
oooo0000o`000?ooool3o`0001[ooooo0_l00008ooooo`;o00005?ooool2o`0000Cooooo3?l00000
0ooooooo0000o`000002o`0000Wooooo0ol0000Booooo`Co000000?oooooo`000?l000000_l00003
ooooo`;o0000Goooool001cooooo00?o0000ooooooooool0COooool2o`0000?ooooo0_l000000ooo
oooo0000o`00000=ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0001[ooooo0_l00008
ooooo`;o00005?ooool2o`0000;ooooo1?l000000ooooooo0000o`000003o`0000;ooooo0_l00003
ooooo`Co00003oooool2o`0000_ooooo1?l000000ooooooo0000o`000002o`0006Cooooo000Loooo
o`03o`000?oooooooooo04gooooo1?l000001?oooooo0000o`000?ooool3o`0000oooooo1ol00009
ooooo`;o00003_ooool3o`0000kooooo0_l0000Aooooo`;o00000_ooool2o`000003ooooool0003o
000000[ooooo0_l0000?ooooo`;o00003?ooool2o`000004ooooool0003o0000o`0000kooooo0ol0
001Eooooo`007?ooool00ol0003oooooooooo`1?ooooo`Co00000oooool2o`0000gooooo1?l00000
0ooooooo0000o`000002o`0000Wooooo0_l0000>ooooo`?o00001Oooool4o`0000Gooooo0_l0000@
ooooo`;o00000oooool3o`0000[ooooo0_l0000Jooooo`;o000000?oooooo`000?l000000_ooool4
o`0000kooooo0ol0001Eooooo`007?ooool00ol0003oooooooooo`1?ooooo`Co00003_ooool2o`00
00;ooooo0ol00005ooooo`?o00001?ooool2o`0000;ooooo0_l0000Dooooo`Go000000?oooooo`00
0?l000000_ooool2o`0000_ooooo0_l00003ooooo`Co00000_ooool2o`0000?ooooo0_l00004oooo
o`?o00002oooool2o`0000gooooo1Ol000001?oooooo0000o`000?l0001Xooooo`007?ooool00ol0
003oooooooooo`1Aooooo`?o00000_ooool2o`0000Wooooo0_l0000:ooooo`Go00000_ooool3o`00
0003ooooool0003o000001Cooooo2?l0000<ooooo`;o000000?oooooo`000?l000000_ooool6o`00
00;ooooo0_l000001?oooooo0000o`000?l00004ooooo`;o00000_ooool2o`0000Sooooo0_l0000>
ooooo`;o000000?oooooo`000?l000000_l0000<ooooo`;o0000Foooool001cooooo00?o0000oooo
ooooool0DOooool3o`0000;ooooo0_l00009ooooo`;o00001Oooool2o`0000Cooooo1?l00003oooo
o`;o000000?oooooo`000?l000004oooool2o`000003ooooool0003o000000Co00001_ooool2o`00
00Cooooo0ol00004ooooo`?o000000?oooooo`000?l000002?l00008ooooo`;o00005Oooool4o`00
00;ooooo0_l0000>ooooo`;o0000Foooool001cooooo00?o0000ooooooooool0HOooool4o`0000?o
oooo0_l00004ooooo`?o00000_ooool2o`0000?ooooo1?l0000?ooooo`Co00000_ooool2o`000004
ooooool0003o0000o`0000;ooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l00005oooo
o`;o00000_ooool9o`0001?ooooo0_l00008ooooo`Ko0000Koooool001cooooo00?o0000oooooooo
ool0Hoooool2o`0000Kooooo0ol000000ooooooo0000o`000002ooooo`;o00001?ooool3o`0000oo
oooo0_l00004ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000004o`0000co
oooo0_l0000@ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Sooooo0_l00004ooooo`;o
0000KOooool001cooooo0_l0001Kooooo`;o00001oooool3o`000003ooooool0003o000000;ooooo
0ol00005ooooo`Co00006_ooool5o`0000[ooooo0_l00005ooooo`;o00002Oooool2o`0000cooooo
0_l000000ooooooo0000o`000008ooooo`?o000000?oooooo`000?l000001oooool2o`0000cooooo
0_l0001Oooooo`007?ooool00ol0003oooooooooo`1Hooooo`Co000000?oooooo`000?l000001?oo
ool3o`000003ooooool0003o000000[ooooo1?l0000Eooooo`;o00000oooool5o`00017ooooo0ol0
0008ooooo`;o00000oooool2o`0000?ooooo0ol00007ooooo`;o00001Oooool3o`000004ooooool0
003o0000ooooo`;o00001?ooool2o`0000[ooooo1?l0001Oooooo`007?ooool00ol0003ooooooooo
o`1Hooooo`;o00000oooool2o`0000Sooooo0_l0000<ooooo`;o00004?ooool2o`0000?ooooo0_l0
0004ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0000?ooooo0_l00007ooooo`;o0000
2?ooool2o`0000?ooooo0_l00003ooooo`?o00000oooool6o`0000Cooooo0_l00006ooooo`;o0000
4?ooool3o`00063ooooo000Looooo`03o`000?oooooooooo05Sooooo0_l0000=ooooo`;o00007_oo
ool2o`0000Wooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00000oooool3o`00013ooooo
0_l00005ooooo`;o00000oooool2o`0000;ooooo1?l000001?oooooo0000o`000?ooool4o`0000;o
oooo0_l000001?oooooo0000o`000?l0001cooooo`007?ooool00ol0003oooooooooo`1Jooooo`;o
0000;?ooool2o`0000Cooooo0_l00002ooooo`Co00002_ooool2o`0000[ooooo0_l00005ooooo`;o
00000_ooool4o`0000?ooooo0_l00007ooooo`;o000000?oooooo`000?l000000ol000001?oooooo
0000o`000?ooool3o`0000_ooooo0_l0001Vooooo`007?ooool00ol0003oooooooooo`1Jooooo`;o
000000?oooooo`000?l000001Ol0000Tooooo`;o00000_ooool4o`0000Cooooo0_l00005ooooo`;o
00003oooool2o`0000Gooooo0_l00002ooooo`Go00002oooool3o`0000?ooooo0_l0000>ooooo`;o
00000_ooool2o`0006Kooooo000Looooo`03o`000?oooooooooo05gooooo1ol0000<ooooo`;o0000
6_ooool2o`0000gooooo0ol0000Booooo`;o00002?ooool2o`000003ooooool0003o000000;o0000
00?oooooo`000?l000000oooool3o`0001;ooooo0ol0001Zooooo`007?ooool00ol0003ooooooooo
o`1Oooooo`;o00002_ooool2o`0000?ooooo0_l0000?ooooo`;o00004oooool3o`0000;ooooo0ol0
0009ooooo`;o00001oooool2o`000003ooooool0003o000000Sooooo1?l000000ooooooo0000o`00
000Dooooo`Ko0000Joooool001cooooo00?o0000ooooooooool0Goooool2o`0000[ooooo0_l00000
0ooooooo0000o`00000Aooooo`;o00004oooool4o`000003ooooool0003o000000Kooooo0_l00002
ooooo`;o00002_ooool5o`0001cooooo0_l00002ooooo`Co0000KOooool001cooooo00?o0000oooo
ooooool0HOooool2o`0000_ooooo0_l00005ooooo`;o00000_ooool2o`00017ooooo0_l0000:oooo
o`Co00001oooool3o`0000oooooo0ol0000Kooooo`?o0000Loooool001cooooo00?o0000oooooooo
ool0HOooool2o`0000Gooooo0_l0000;ooooo`;o00000_ooool2o`00017ooooo0_l0000<ooooo`;o
000000?oooooo`000?l000001ol00005ooooo`;o00003?ooool6o`0000gooooo0_l00005ooooo`;o
0000M?ooool001cooooo00?o0000ooooooooool0HOooool2o`0000Gooooo0_l0000;ooooo`;o0000
0_ooool2o`0000?ooooo0_l0000<ooooo`;o00003oooool8o`0000Kooooo0_l0000<ooooo`Wo0000
1Oooool3o`0000;ooooo0_l0001kooooo`007?ooool00ol0003oooooooooo`1Qooooo`;o00004_oo
ool2o`0000Oooooo0_l00002ooooo`;o00006_ooool7o`0001Oooooo0_l000001?oooooo0000o`00
0?l00005ooooo`?o0000Ooooool001cooooo00?o0000ooooooooool0NOooool2o`0000Oooooo0_l0
0008ooooo`;o00005Oooool2o`0000Gooooo1?l00003ooooo`?o00000_ooool2o`00097ooooo0000
1_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<
c<`01_ooool00ol0003oooooooooo`1]ooooo`Co00002?ooool5o`0000kooooo0ol0000Jooooo`Go
00000oooool3o`0000;ooooo0_l0002Aooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5oooo
o`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0KOooool4
o`0000Wooooo1_l0000=ooooo`;o00000_ooool2o`0001Kooooo0_l00011ooooo`;o0000Foooool0
0003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool0Loooool2o`0000Wooooo0_l0000=ooooo`;o00000_ooool2
o`0002Kooooo0_l0000aooooo`;o0000Foooool00003ooooool0003ooooo00;ooooo00?o0000oooo
ooooool02Oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0001[ooooo`;o00001_ooool2
o`0000cooooo1Ol0000;ooooo`;o00007_ooool2o`0000Kooooo0_l0002>ooooo`0000?oooooo`00
0?ooool00_ooool00ol0003oooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool0
0ol0003oooooooooo`1[ooooo`;o000000?oooooo`000?l000004Oooool5o`0000Cooooo1?l0000S
ooooo`;o0000U_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol@
413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0K_ooool2o`0001Cooooo0_l00002
ooooo`Ko0000E_ooool2o`0006?ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go
0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo07;ooooo0_l0000:ooooo`;o0000
2?ooool7o`0005?ooooo1?l0001Sooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05
ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`1booooo`;o00002_ooool2o`00
00Wooooo1_l0001Aooooo`Co0000IOooool001cooooo00?o0000ooooooooool0L_ooool2o`0000go
oooo0_l0000:ooooo`;o0000DOooool2o`0006Oooooo000Looooo`03o`000?oooooooooo087ooooo
0_l0001Dooooo`Co0000K_ooool001cooooo00?o0000ooooooooool0eoooool4o`0006kooooo000L
ooooo`03o`000?oooooooooo07Oooooo0_l0000<ooooo`;o0000D?ooool2o`00073ooooo000Loooo
o`03o`000?oooooooooo07Oooooo0_l00004ooooo`;o00001_ooool2o`000<;ooooo000Looooo`03
o`000?oooooooooo07gooooo0_l00003ooooo`;o00000_ooool2o`000<7ooooo000Looooo`03o`00
0?oooooooooo08;ooooo0ol000000ooooooo0000o`000002o`000;oooooo000Looooo`03o`000?oo
oooooooo08?ooooo0_l00003ooooo`Co0000=oooool2o`0000;ooooo0_l00020ooooo`007?ooool0
0ol0003oooooooooo`28ooooo`Co000000?oooooo`000?l00000;_ooool4o`000003ooooool0003o
000000Go0000P?ooool001cooooo00?o0000ooooooooool0R_ooool2o`000003ooooool0003o0000
01_ooooo0_l00002ooooo`Go00000oooool3o`0000Cooooo1?l000001?oooooo0000o`000?ooool2
o`0008;ooooo000Looooo`03o`000?oooooooooo0:Oooooo1Ol000000ooooooo0000o`000004o`00
00?ooooo0ol0002@ooooo`007?ooool2o`0009?ooooo0_l0000Cooooo`Co00000_ooool2o`0009[o
oooo000Looooo`03o`000?oooooooooo09;ooooo0_l000000ooooooo0000o`00000?ooooo`;o0000
00?oooooo`000?l00000W_ooool001cooooo00?o0000ooooooooool0UOooool4o`0000gooooo0_l0
002Qooooo`007?ooool00ol0003oooooooooo`2Booooo`?o000000Coooooo`000?l0003o00001Ooo
ool3o`000:Sooooo000Looooo`03o`000?oooooooooo09;ooooo1Ol00005ooooo`Go00000_ooool2
o`000:Cooooo000Looooo`03o`000?oooooooooo09Gooooo0_l00005ooooo`Co00000oooool2o`00
0:Cooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000
oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Booooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooood[o
oooo000Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`005?oo
ool00ol0003oooooooooo`05ooooo`?o0000oooooom:ooooo`005?ooool00ol0003oooooooooo`3o
oooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000oooooooo
ool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Booooo`03oeEEEOmV
IVKo00000?ooooooE?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Gooooo
00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0Eooooo`05oiRHV?l@413o0000oc8b
<_o<c<`01Oooool2o`000004oa0@4?ooooooooooooooo`Go0000T?ooool00:Kooooo00Go0000oooo
ooooooooooooo`000009ooooo`Ko00002Oooool01Ol@413o^[ZjoooooomgMgOo<S8b00Kooooo00?o
0000ooooooooool00_ooool01OnHV9So8B4Qonk^k_ooooooA4A4093ooooo002Vooooo`05o`000?oo
ooooooooooooool000007?ooool01?l0003oooooooooooooool5o`0000Cooooo00?oV9RHob4Q8Oo^
k^h0TOooool00:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00003?ooool00onYZJWo
410@ooooo`02ooooo`04odA4A?oMgMgoooooo`0000Kooooo00?oV9RHob4Q8Oo^k^h0T?ooool00:Ko
oooo00Go0000ohN7QoooooooZJVYo`00000Jooooo`03oa0@4?l0003o^[Zj00?ooooo00CogMgMoeEE
EOoooooo00001oooool00omgMgOoIVIVooooo`2?ooooo`00YOooool00ol@413o0000ogMgM`02o`00
0003oiRHV?oooooooooo01Wooooo00?o^[Zjob4Q8Oooool00oooool00omgMgOoc<c<o`000008oooo
o`03o`000?oooooooooo08kooooo0033ooooo`05oa0@4?nHV9SooooookZj^_l000001?ooool00oo^
k^koA4A4o`000004ooooo`05o`000?nj^[[ooooooiRHV?l@4100T?ooool00<?ooooo00GoZJVYoa0@
4?l0003o410@ojVYZ@05ooooo`03ogMgMol0003ooooo00?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c02@ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(348) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.51774 .71567 Mdot
.52366 .67084 Mdot
.68313 .37813 Mdot
.34885 .45696 Mdot
.5195 .25595 Mdot
.66035 .3683 Mdot
.69833 .57089 Mdot
.69726 .57503 Mdot
.66761 .39416 Mdot
.26269 .67551 Mdot
.67469 .53911 Mdot
.34616 .44179 Mdot
.68796 .55681 Mdot
.35919 .47932 Mdot
.4528 .42774 Mdot
.36511 .5417 Mdot
.55036 .71393 Mdot
.57094 .2541 Mdot
.3593 .53817 Mdot
.65278 .34614 Mdot
.24786 .52465 Mdot
.35926 .46684 Mdot
.5042 .65426 Mdot
.35739 .47647 Mdot
.40401 .47785 Mdot
.51337 .68094 Mdot
.51092 .70822 Mdot
.39788 .4689 Mdot
.32644 .50119 Mdot
.67356 .54864 Mdot
.54936 .45775 Mdot
.19734 .42242 Mdot
.41743 .49845 Mdot
.39637 .65475 Mdot
.67133 .57083 Mdot
.74611 .53419 Mdot
.62404 .37209 Mdot
.71335 .58232 Mdot
.66171 .55359 Mdot
.66751 .53949 Mdot
.67128 .53675 Mdot
.51172 .68417 Mdot
.72197 .55846 Mdot
.73764 .47511 Mdot
.3466 .48265 Mdot
.45653 .63479 Mdot
.70162 .46877 Mdot
.38326 .51852 Mdot
.5445 .66698 Mdot
.67341 .35672 Mdot
.42062 .28478 Mdot
.71262 .57119 Mdot
.5289 .56423 Mdot
.87115 .58244 Mdot
.68487 .56598 Mdot
.37955 .52949 Mdot
.64243 .40169 Mdot
.37764 .49431 Mdot
.37552 .44418 Mdot
.36879 .62852 Mdot
.38663 .48045 Mdot
.53772 .25795 Mdot
.49304 .70638 Mdot
.62494 .34416 Mdot
.66966 .39474 Mdot
.7164 .57492 Mdot
.5492 .64894 Mdot
.6815 .5466 Mdot
.32516 .48702 Mdot
.67091 .35803 Mdot
.34671 .51782 Mdot
.67663 .5383 Mdot
.50187 .68288 Mdot
.3461 .46583 Mdot
.67852 .73972 Mdot
.67195 .49424 Mdot
.67919 .33477 Mdot
.33823 .58344 Mdot
.49301 .28874 Mdot
.49929 .42716 Mdot
.34992 .46482 Mdot
.81874 .40804 Mdot
.44111 .39221 Mdot
.54245 .67224 Mdot
.53345 .58105 Mdot
.66944 .638 Mdot
.39678 .50733 Mdot
.55074 .46436 Mdot
.34572 .5483 Mdot
.58927 .2565 Mdot
.65187 .39722 Mdot
.54863 .69012 Mdot
.34561 .47402 Mdot
.33086 .47687 Mdot
.35618 .76342 Mdot
.32754 .50883 Mdot
.38285 .44567 Mdot
.57573 .56765 Mdot
.69735 .52733 Mdot
.33434 .42393 Mdot
.54785 .35118 Mdot
.50695 .57549 Mdot
.38215 .52728 Mdot
.64389 .38757 Mdot
.49037 .69556 Mdot
.41335 .51157 Mdot
.69283 .54696 Mdot
.35058 .46934 Mdot
.72141 .53637 Mdot
.53959 .65914 Mdot
.37495 .44043 Mdot
.54043 .27534 Mdot
.33676 .5729 Mdot
.50314 .66757 Mdot
.43024 .74667 Mdot
.38052 .46717 Mdot
.37451 .50284 Mdot
.52142 .66844 Mdot
.64697 .35082 Mdot
.7871 .39338 Mdot
.50352 .68312 Mdot
.66852 .53725 Mdot
.55427 .70219 Mdot
.39537 .56935 Mdot
.64227 .35001 Mdot
.50331 .55789 Mdot
.50346 .5521 Mdot
.32965 .32395 Mdot
.35674 .45432 Mdot
.24411 .47696 Mdot
.65105 .37944 Mdot
.50894 .66708 Mdot
.6781 .55436 Mdot
.3263 .52168 Mdot
.52406 .69818 Mdot
.70198 .57215 Mdot
.5476 .29699 Mdot
.55795 .23822 Mdot
.51642 .65084 Mdot
.44904 .7678 Mdot
.70074 .60593 Mdot
.6958 .52253 Mdot
.41819 .28708 Mdot
.54215 .67155 Mdot
.55516 .26974 Mdot
.70396 .55553 Mdot
.38098 .20577 Mdot
.39768 .44967 Mdot
.39322 .30502 Mdot
.82412 .43571 Mdot
.42129 .28482 Mdot
.23573 .53713 Mdot
.549 .2786 Mdot
.70297 .57201 Mdot
.36185 .5221 Mdot
.53436 .68577 Mdot
.52074 .69525 Mdot
.33698 .5067 Mdot
.41042 .47737 Mdot
.36101 .49033 Mdot
.41537 .49723 Mdot
.58495 .53568 Mdot
.34694 .47454 Mdot
.56439 .79585 Mdot
.53624 .69389 Mdot
.41007 .49046 Mdot
.63193 .36575 Mdot
.33446 .40965 Mdot
.72088 .56439 Mdot
.36137 .44752 Mdot
.40734 .47326 Mdot
.31737 .47051 Mdot
.66776 .53646 Mdot
.67488 .75267 Mdot
.49794 .2422 Mdot
.66086 .57509 Mdot
.77624 .5844 Mdot
.64274 .37163 Mdot
.39075 .4899 Mdot
.5649 .27988 Mdot
.31172 .43462 Mdot
.33695 .47888 Mdot
.42669 .28029 Mdot
.38565 .45126 Mdot
.23324 .52783 Mdot
.42307 .53421 Mdot
.66983 .63082 Mdot
.55746 .7811 Mdot
.34294 .46066 Mdot
.27406 .65936 Mdot
.40376 .3078 Mdot
.64742 .46898 Mdot
.67605 .55595 Mdot
.6613 .35841 Mdot
.65405 .35266 Mdot
.69408 .59515 Mdot
.42874 .69814 Mdot
.24689 .6517 Mdot
.31896 .48961 Mdot
.51052 .57535 Mdot
.56034 .68863 Mdot
.54768 .27638 Mdot
.51638 .65383 Mdot
.80839 .38237 Mdot
.5149 .41765 Mdot
.52603 .46852 Mdot
.56247 .32237 Mdot
.67327 .35274 Mdot
.50988 .56909 Mdot
.55934 .26888 Mdot
.3572 .49826 Mdot
.53927 .65985 Mdot
.4074 .3027 Mdot
.30136 .45475 Mdot
.23355 .70912 Mdot
.51241 .70724 Mdot
.30442 .36381 Mdot
.68613 .56375 Mdot
.63789 .41154 Mdot
.39762 .50612 Mdot
.37441 .47708 Mdot
.53301 .65073 Mdot
.369 .51936 Mdot
.49983 .46288 Mdot
.40408 .46563 Mdot
.62022 .35017 Mdot
.51373 .2264 Mdot
.6845 .59944 Mdot
.5495 .31831 Mdot
.5009 .67364 Mdot
.69495 .77373 Mdot
.63183 .38418 Mdot
.384 .41427 Mdot
.68366 .53618 Mdot
.54244 .29307 Mdot
.63599 .39157 Mdot
.53972 .24164 Mdot
.3565 .44536 Mdot
.62285 .381 Mdot
.53575 .26248 Mdot
.52088 .49298 Mdot
.41456 .4998 Mdot
.30992 .30853 Mdot
.70954 .56169 Mdot
.54987 .69972 Mdot
.33788 .49547 Mdot
.53112 .57342 Mdot
.37622 .42819 Mdot
.35315 .34664 Mdot
.52034 .55942 Mdot
.50599 .57956 Mdot
.4768 .40319 Mdot
.56846 .29404 Mdot
.76743 .63504 Mdot
.55369 .47772 Mdot
.54984 .71484 Mdot
.33427 .47277 Mdot
.7521 .611 Mdot
.70885 .56799 Mdot
.36469 .49867 Mdot
.73372 .62748 Mdot
.70478 .55828 Mdot
.37239 .50198 Mdot
.66779 .54838 Mdot
.52963 .6944 Mdot
.4832 .44599 Mdot
.53647 .72076 Mdot
.34227 .48841 Mdot
.66954 .54526 Mdot
.65513 .35601 Mdot
.51412 .6823 Mdot
.35336 .46719 Mdot
.37143 .45276 Mdot
.51799 .581 Mdot
.40159 .45706 Mdot
.60542 .59301 Mdot
.38769 .5169 Mdot
.68568 .38129 Mdot
.3267 .50579 Mdot
.49331 .33852 Mdot
.57663 .22554 Mdot
.52926 .65323 Mdot
.52144 .5608 Mdot
.63824 .39787 Mdot
.50117 .48411 Mdot
.28362 .36185 Mdot
.34984 .47781 Mdot
.52325 .56736 Mdot
.32848 .3401 Mdot
.71995 .5575 Mdot
.35471 .55325 Mdot
.63933 .31465 Mdot
.65116 .39551 Mdot
.50898 .57195 Mdot
.31043 .44202 Mdot
.56037 .65159 Mdot
.35311 .53455 Mdot
.62481 .37934 Mdot
.53912 .71754 Mdot
.34084 .52199 Mdot
.67392 .48614 Mdot
.53135 .58038 Mdot
.69962 .52643 Mdot
.57121 .56143 Mdot
.37784 .50685 Mdot
.67243 .36205 Mdot
.51269 .69194 Mdot
.68731 .57114 Mdot
.50247 .67087 Mdot
.42634 .30024 Mdot
.32763 .35209 Mdot
.49023 .62757 Mdot
.57074 .30117 Mdot
.33331 .21883 Mdot
.65986 .57448 Mdot
.32532 .42534 Mdot
.60246 .37412 Mdot
.55082 .76616 Mdot
.64461 .39068 Mdot
.46223 .77332 Mdot
.64838 .39969 Mdot
.36438 .53106 Mdot
.66703 .37356 Mdot
.35601 .7717 Mdot
.38978 .45964 Mdot
.67253 .39403 Mdot
.58734 .51206 Mdot
.38513 .45626 Mdot
.52433 .6994 Mdot
.18246 .48592 Mdot
.41787 .6713 Mdot
.42081 .68495 Mdot
.6376 .40265 Mdot
.47473 .78083 Mdot
.39909 .47505 Mdot
.33237 .53121 Mdot
.52975 .68469 Mdot
.38117 .42945 Mdot
.57281 .27878 Mdot
.56091 .24414 Mdot
.39861 .24092 Mdot
.22214 .41484 Mdot
.42482 .71393 Mdot
.51913 .69011 Mdot
.50417 .24542 Mdot
.66793 .74659 Mdot
.53158 .57865 Mdot
.69819 .57504 Mdot
.71684 .71893 Mdot
.3292 .53456 Mdot
.55184 .61234 Mdot
.49707 .46131 Mdot
.53927 .71187 Mdot
.49634 .5906 Mdot
.68992 .57301 Mdot
.41855 .68474 Mdot
.23313 .62247 Mdot
.36039 .4918 Mdot
.71356 .55371 Mdot
.38809 .43471 Mdot
.54926 .46837 Mdot
.31122 .32702 Mdot
.7314 .39219 Mdot
.34358 .48879 Mdot
.72425 .69993 Mdot
.33699 .48645 Mdot
.34304 .31602 Mdot
.35851 .50049 Mdot
.51814 .69975 Mdot
.31237 .47725 Mdot
.55303 .48527 Mdot
.40356 .16461 Mdot
.50986 .40759 Mdot
.54807 .24281 Mdot
.36176 .47752 Mdot
.37012 .48842 Mdot
.53771 .25372 Mdot
.54468 .7031 Mdot
.33382 .49108 Mdot
.78736 .62918 Mdot
.34679 .47044 Mdot
.71164 .57822 Mdot
.39677 .35034 Mdot
.21294 .40024 Mdot
.39726 .49071 Mdot
.55985 .65148 Mdot
.69639 .52335 Mdot
.69284 .53659 Mdot
.32848 .55322 Mdot
.71069 .56484 Mdot
.36282 .52112 Mdot
.39755 .34991 Mdot
.53045 .64002 Mdot
.3246 .54912 Mdot
.53614 .71127 Mdot
.57875 .18126 Mdot
.70614 .56671 Mdot
.52879 .57475 Mdot
.43426 .72438 Mdot
.69695 .55581 Mdot
.52225 .2181 Mdot
.3111 .48271 Mdot
.29267 .48483 Mdot
.55996 .71486 Mdot
.672 .36324 Mdot
.51407 .56322 Mdot
.68556 .5676 Mdot
.34807 .48063 Mdot
.40441 .51209 Mdot
.71206 .56191 Mdot
.28761 .59263 Mdot
.55042 .45749 Mdot
.34096 .48608 Mdot
.53302 .70298 Mdot
.50837 .67048 Mdot
.37254 .54688 Mdot
.3363 .48845 Mdot
.65958 .36297 Mdot
.52284 .56637 Mdot
.5177 .56021 Mdot
.50066 .55918 Mdot
.6359 .40633 Mdot
.33917 .21223 Mdot
.70018 .52364 Mdot
.20156 .41561 Mdot
.67064 .70893 Mdot
.35293 .56341 Mdot
.63655 .35642 Mdot
.37905 .47498 Mdot
.39189 .52082 Mdot
.6694 .55044 Mdot
.2989 .27369 Mdot
.32804 .52645 Mdot
.52974 .71958 Mdot
.71371 .56477 Mdot
.38133 .43202 Mdot
.65116 .60552 Mdot
.54871 .28801 Mdot
.42566 .72828 Mdot
.71089 .57081 Mdot
.5251 .64274 Mdot
.71101 .57099 Mdot
.3674 .48913 Mdot
.31319 .43828 Mdot
.53595 .71356 Mdot
.52533 .24792 Mdot
.3332 .49959 Mdot
.36564 .50477 Mdot
.58751 .37115 Mdot
.68145 .73636 Mdot
.51687 .2688 Mdot
.37214 .52633 Mdot
.29128 .47858 Mdot
.52748 .24744 Mdot
.35165 .51238 Mdot
.33477 .51353 Mdot
.24329 .4783 Mdot
.72496 .55956 Mdot
.53248 .28657 Mdot
.37658 .18171 Mdot
.51349 .70918 Mdot
.6052 .58844 Mdot
.50381 .56879 Mdot
.65728 .56352 Mdot
.48924 .46592 Mdot
.51898 .57316 Mdot
.69566 .68329 Mdot
.57263 .85079 Mdot
.51625 .5652 Mdot
.6162 .38965 Mdot
.38354 .76999 Mdot
.33297 .51015 Mdot
.34123 .49316 Mdot
.57125 .28316 Mdot
.52806 .66513 Mdot
.57154 .78346 Mdot
.65998 .57156 Mdot
.37061 .46439 Mdot
.50183 .69548 Mdot
.67403 .63509 Mdot
.5155 .57589 Mdot
.56199 .28565 Mdot
.52368 .26344 Mdot
.33969 .49617 Mdot
.30311 .35113 Mdot
.51485 .68643 Mdot
.35336 .46732 Mdot
.37483 .50444 Mdot
.61807 .37193 Mdot
.53729 .65927 Mdot
.63061 .37051 Mdot
.52508 .59153 Mdot
.41491 .80168 Mdot
.79133 .56794 Mdot
.70765 .55594 Mdot
.47314 .54597 Mdot
.68384 .59894 Mdot
.67734 .46559 Mdot
.522 .56505 Mdot
.35548 .46749 Mdot
.51669 .63662 Mdot
.35158 .46779 Mdot
.34626 .4717 Mdot
.34664 .48804 Mdot
.42452 .71589 Mdot
.49507 .29545 Mdot
.5675 .27739 Mdot
.37796 .51129 Mdot
.62469 .39673 Mdot
.67855 .62534 Mdot
.28476 .71191 Mdot
.36763 .47778 Mdot
.37322 .50348 Mdot
.56058 .65634 Mdot
.39571 .44628 Mdot
.70122 .56159 Mdot
.54075 .71215 Mdot
.39423 .52277 Mdot
.55634 .34755 Mdot
.33631 .4975 Mdot
.48254 .60083 Mdot
.69463 .58352 Mdot
.32757 .43757 Mdot
.42486 .48721 Mdot
.52311 .56535 Mdot
.51401 .56445 Mdot
.50245 .57989 Mdot
.71387 .57686 Mdot
.61808 .37843 Mdot
.66417 .3331 Mdot
.42321 .46859 Mdot
.36885 .52351 Mdot
.29852 .46602 Mdot
.66959 .42187 Mdot
.57037 .47413 Mdot
.45225 .75975 Mdot
.38933 .43758 Mdot
.65158 .41235 Mdot
.57579 .567 Mdot
.28315 .56535 Mdot
.54691 .70313 Mdot
.60341 .39353 Mdot
.68844 .53973 Mdot
.53231 .26527 Mdot
.38016 .27263 Mdot
.50806 .69293 Mdot
.53006 .63355 Mdot
.65113 .36455 Mdot
.40652 .35233 Mdot
.89284 .54532 Mdot
.65276 .38373 Mdot
.51866 .46976 Mdot
.52585 .68725 Mdot
.41685 .49858 Mdot
.34557 .3341 Mdot
.40511 .36166 Mdot
.66416 .40479 Mdot
.36982 .45268 Mdot
.61318 .20443 Mdot
.66076 .36345 Mdot
.29528 .46572 Mdot
.63576 .40234 Mdot
.71049 .53515 Mdot
.64552 .38184 Mdot
.50424 .70624 Mdot
.35722 .45506 Mdot
.8782 .57072 Mdot
.46094 .41008 Mdot
.36598 .45809 Mdot
.70997 .57651 Mdot
.66251 .47478 Mdot
.36307 .4947 Mdot
.5708 .26265 Mdot
.61666 .38765 Mdot
.70927 .42425 Mdot
.34977 .52794 Mdot
.66846 .37302 Mdot
.53528 .63073 Mdot
.60943 .41007 Mdot
.55392 .35227 Mdot
.51461 .56085 Mdot
.5336 .69201 Mdot
.68522 .49783 Mdot
.67125 .53475 Mdot
.39041 .53153 Mdot
.38325 .49792 Mdot
.53946 .69452 Mdot
.50641 .49406 Mdot
.37177 .55542 Mdot
.34853 .46805 Mdot
.63923 .36637 Mdot
.6501 .34041 Mdot
.44731 .42077 Mdot
.63012 .38403 Mdot
.29128 .48372 Mdot
.53323 .69941 Mdot
.35574 .535 Mdot
.50493 .67574 Mdot
.33343 .47569 Mdot
.63049 .58695 Mdot
.55124 .68621 Mdot
.3926 .41872 Mdot
.36499 .45009 Mdot
.49533 .75799 Mdot
.38287 .504 Mdot
.34183 .48043 Mdot
.63489 .3441 Mdot
.54452 .25477 Mdot
.37058 .55158 Mdot
.65211 .50912 Mdot
.52817 .26785 Mdot
.27617 .57736 Mdot
.64112 .3505 Mdot
.52776 .27798 Mdot
.37325 .25346 Mdot
.5192 .5594 Mdot
.54756 .24912 Mdot
.51302 .54581 Mdot
.70827 .55222 Mdot
.4939 .6472 Mdot
.38112 .45268 Mdot
.40884 .79869 Mdot
.55225 .45837 Mdot
.52135 .58134 Mdot
.34758 .50659 Mdot
.38002 .4796 Mdot
.5015 .69427 Mdot
.81055 .38882 Mdot
.65659 .3368 Mdot
.41058 .46919 Mdot
.50657 .69281 Mdot
.82158 .42013 Mdot
.67075 .39902 Mdot
.56294 .29442 Mdot
.66016 .55848 Mdot
.53691 .7323 Mdot
.5297 .57754 Mdot
.70543 .56851 Mdot
.66762 .33001 Mdot
.43062 .27781 Mdot
.35023 .53285 Mdot
.63291 .36142 Mdot
.42245 .28403 Mdot
.35694 .55507 Mdot
.69871 .59591 Mdot
.69211 .48838 Mdot
.54545 .67768 Mdot
.71235 .56238 Mdot
.56903 .26566 Mdot
.55676 .6998 Mdot
.53852 .71087 Mdot
.70076 .55605 Mdot
.53245 .79656 Mdot
.32996 .34009 Mdot
.68189 .58619 Mdot
.3602 .34753 Mdot
.42434 .28418 Mdot
.52483 .58293 Mdot
.56149 .28392 Mdot
.51102 .22702 Mdot
.51186 .68292 Mdot
.71091 .72358 Mdot
.42104 .28385 Mdot
.38481 .44609 Mdot
.53474 .26144 Mdot
.6573 .62439 Mdot
.74538 .54334 Mdot
.70394 .56461 Mdot
.5915 .39056 Mdot
.53287 .25822 Mdot
.35137 .44995 Mdot
.23349 .32691 Mdot
.39305 .4703 Mdot
.70455 .55445 Mdot
.49821 .46195 Mdot
.52761 .6563 Mdot
.72091 .56004 Mdot
.49933 .46206 Mdot
.38176 .52466 Mdot
.38165 .46567 Mdot
.50575 .31275 Mdot
.54723 .6675 Mdot
.52514 .58866 Mdot
.35842 .4573 Mdot
.37435 .49883 Mdot
.39234 .53382 Mdot
.24866 .36382 Mdot
.42014 .57497 Mdot
.40576 .52428 Mdot
.64942 .41722 Mdot
.31048 .43827 Mdot
.40865 .46202 Mdot
.56489 .65689 Mdot
.53432 .34462 Mdot
.52181 .59334 Mdot
.34408 .49727 Mdot
.3417 .48847 Mdot
.66228 .55451 Mdot
.3307 .33926 Mdot
.40906 .36145 Mdot
.68259 .36624 Mdot
.69531 .37354 Mdot
.32882 .46714 Mdot
.53931 .68601 Mdot
.55927 .30417 Mdot
.30097 .52685 Mdot
.52687 .71822 Mdot
.33074 .46865 Mdot
.6154 .38306 Mdot
.51962 .56638 Mdot
.29302 .51543 Mdot
.5403 .26342 Mdot
.70521 .60362 Mdot
.28368 .57627 Mdot
.64893 .35656 Mdot
.40306 .48879 Mdot
.68948 .34565 Mdot
.6638 .38494 Mdot
.51809 .58234 Mdot
.3489 .42253 Mdot
.5259 .69441 Mdot
.52249 .64326 Mdot
.48226 .31852 Mdot
.63112 .40404 Mdot
.62709 .44138 Mdot
.71206 .5435 Mdot
.37518 .5113 Mdot
.72863 .59867 Mdot
.52257 .64705 Mdot
.32904 .32354 Mdot
.52372 .26913 Mdot
.70387 .56096 Mdot
.5199 .55048 Mdot
.55098 .69487 Mdot
.51859 .64578 Mdot
.34585 .47699 Mdot
.3642 .47041 Mdot
.66705 .4593 Mdot
.39679 .30793 Mdot
.66719 .55463 Mdot
.55378 .29344 Mdot
.68201 .36944 Mdot
.35866 .52862 Mdot
.53996 .67183 Mdot
.21437 .38328 Mdot
.37971 .5056 Mdot
.62561 .39741 Mdot
.5225 .67284 Mdot
.56758 .28715 Mdot
.56796 .26641 Mdot
.34607 .46117 Mdot
.23512 .52689 Mdot
.69455 .55194 Mdot
.52272 .70005 Mdot
.51418 .74012 Mdot
.3795 .5131 Mdot
.36457 .47519 Mdot
.41395 .55711 Mdot
.71492 .58641 Mdot
.41653 .52616 Mdot
.53304 .24382 Mdot
.50892 .658 Mdot
.35846 .45918 Mdot
.53797 .25621 Mdot
.55372 .61499 Mdot
.52095 .57241 Mdot
.67332 .38106 Mdot
.56853 .25637 Mdot
.55068 .26289 Mdot
.53067 .27565 Mdot
.71879 .71676 Mdot
.53482 .59649 Mdot
.47961 .21096 Mdot
.36647 .45178 Mdot
.42518 .28422 Mdot
.37303 .5444 Mdot
.71779 .55261 Mdot
.67347 .36721 Mdot
.35105 .48729 Mdot
.36761 .45151 Mdot
.29356 .57665 Mdot
.36446 .53967 Mdot
.3492 .53891 Mdot
.52536 .65428 Mdot
.51378 .74244 Mdot
.66022 .35558 Mdot
.82808 .45363 Mdot
.16821 .41621 Mdot
.31899 .48348 Mdot
.4046 .35211 Mdot
.54855 .69732 Mdot
.66114 .55617 Mdot
.358 .34249 Mdot
.74458 .58427 Mdot
.51481 .6648 Mdot
.36143 .53115 Mdot
.32248 .58755 Mdot
.53 .2634 Mdot
.36353 .48925 Mdot
.67758 .54958 Mdot
.36235 .48986 Mdot
.71574 .57281 Mdot
.47566 .77312 Mdot
.42207 .36599 Mdot
.38496 .45239 Mdot
.32789 .50889 Mdot
.25128 .50443 Mdot
.3668 .47482 Mdot
.73342 .37642 Mdot
.52515 .67729 Mdot
.37792 .41546 Mdot
.37692 .5314 Mdot
.41073 .66931 Mdot
.35993 .51067 Mdot
.48768 .48856 Mdot
.3895 .48162 Mdot
.31818 .25895 Mdot
.36588 .44386 Mdot
.39102 .48729 Mdot
.67953 .57042 Mdot
.66493 .54473 Mdot
.52902 .76149 Mdot
.51738 .58946 Mdot
.6658 .62926 Mdot
.36703 .50543 Mdot
.67432 .35176 Mdot
.2922 .41799 Mdot
.54727 .25802 Mdot
.5091 .65992 Mdot
.68398 .82833 Mdot
.70929 .52914 Mdot
.62165 .39726 Mdot
.53832 .46528 Mdot
.6348 .41475 Mdot
.60325 .37672 Mdot
.54721 .73625 Mdot
.55935 .28498 Mdot
.33544 .49306 Mdot
.40322 .65257 Mdot
.69879 .72045 Mdot
.37953 .5142 Mdot
.69007 .37329 Mdot
.27032 .43578 Mdot
.47151 .30768 Mdot
.57632 .27058 Mdot
.55495 .2785 Mdot
.68996 .56975 Mdot
.67967 .36899 Mdot
.39424 .43894 Mdot
.52759 .27807 Mdot
.66508 .36097 Mdot
.51486 .5491 Mdot
.52067 .33353 Mdot
.51514 .68876 Mdot
.4714 .77909 Mdot
.4553 .65237 Mdot
.69323 .52336 Mdot
.65693 .50712 Mdot
.5025 .63978 Mdot
.54418 .71897 Mdot
.51152 .58319 Mdot
.6539 .41013 Mdot
.49437 .64818 Mdot
.35247 .4588 Mdot
.3014 .45429 Mdot
.3386 .49444 Mdot
.56965 .28967 Mdot
.35398 .50968 Mdot
.66701 .36612 Mdot
.68321 .57571 Mdot
.64751 .39724 Mdot
.69713 .57184 Mdot
.1865 .45529 Mdot
.35487 .45053 Mdot
.36177 .47444 Mdot
.39834 .35081 Mdot
.51728 .64805 Mdot
.39069 .65987 Mdot
.62832 .3997 Mdot
.64165 .4009 Mdot
.36968 .53229 Mdot
.55812 .6824 Mdot
.5131 .26095 Mdot
.37381 .34752 Mdot
.38839 .4852 Mdot
.5266 .67665 Mdot
.36582 .53354 Mdot
.62144 .53952 Mdot
.44486 .40164 Mdot
.50351 .65934 Mdot
.40873 .16183 Mdot
.36488 .44846 Mdot
.36542 .42352 Mdot
.41476 .44115 Mdot
.24267 .37981 Mdot
.36267 .55214 Mdot
.516 .7116 Mdot
.40827 .46206 Mdot
.53863 .68051 Mdot
.65876 .38763 Mdot
.72001 .54891 Mdot
.53473 .6817 Mdot
.387 .46049 Mdot
.1706 .41314 Mdot
.67828 .57429 Mdot
.35953 .48655 Mdot
.67186 .55555 Mdot
.4898 .68707 Mdot
.52841 .6602 Mdot
.51002 .54566 Mdot
.52017 .4692 Mdot
.69996 .55763 Mdot
.3699 .52271 Mdot
.67809 .74609 Mdot
.35319 .53495 Mdot
.69396 .37247 Mdot
.32225 .50485 Mdot
.32712 .47383 Mdot
.34034 .20539 Mdot
.49997 .49335 Mdot
.79787 .56182 Mdot
.67773 .61812 Mdot
.66812 .75663 Mdot
.5639 .70854 Mdot
.57582 .26885 Mdot
.48108 .56899 Mdot
.51327 .55595 Mdot
.65522 .41695 Mdot
.34878 .48365 Mdot
.56284 .60653 Mdot
.69236 .59023 Mdot
.55235 .25323 Mdot
.38594 .45153 Mdot
.64341 .42257 Mdot
.46858 .54797 Mdot
.70429 .56725 Mdot
.51104 .68379 Mdot
.51606 .65786 Mdot
.49016 .28672 Mdot
.36088 .45909 Mdot
.36047 .46848 Mdot
.67259 .57127 Mdot
.43539 .51079 Mdot
.53673 .28096 Mdot
.58686 .51025 Mdot
.67632 .54893 Mdot
.44426 .39907 Mdot
.54602 .66417 Mdot
.37968 .47751 Mdot
.39486 .35215 Mdot
.6201 .77938 Mdot
.29837 .70876 Mdot
.54875 .27395 Mdot
.29209 .35858 Mdot
.51513 .71052 Mdot
.67806 .55609 Mdot
.3865 .24706 Mdot
.31096 .49446 Mdot
.38055 .48411 Mdot
.2727 .36194 Mdot
.37123 .34766 Mdot
.53568 .46807 Mdot
.38477 .56846 Mdot
.36495 .32843 Mdot
.36785 .53271 Mdot
.40354 .51306 Mdot
.33157 .46386 Mdot
.32333 .50769 Mdot
.53276 .67541 Mdot
.41242 .68519 Mdot
.65135 .37091 Mdot
.30355 .69997 Mdot
.69066 .40333 Mdot
.39812 .47405 Mdot
.37339 .52812 Mdot
.32338 .68173 Mdot
.33036 .37027 Mdot
.52049 .68248 Mdot
.55457 .7199 Mdot
.68251 .52399 Mdot
.35866 .5386 Mdot
.62769 .40083 Mdot
.41362 .44122 Mdot
.66814 .3874 Mdot
.53101 .67463 Mdot
.62276 .36269 Mdot
.67419 .51518 Mdot
.632 .36223 Mdot
.65147 .41434 Mdot
.69214 .58043 Mdot
.55077 .67446 Mdot
.3883 .49561 Mdot
.6939 .58071 Mdot
.51431 .26685 Mdot
.57016 .28773 Mdot
.49159 .72501 Mdot
.41593 .5101 Mdot
.32149 .52456 Mdot
.69129 .47891 Mdot
.62173 .37534 Mdot
.39452 .37223 Mdot
.55008 .68192 Mdot
.56132 .30339 Mdot
.53702 .67631 Mdot
.46969 .25985 Mdot
.54685 .26901 Mdot
.53355 .57732 Mdot
.34433 .28703 Mdot
.67684 .59877 Mdot
.32391 .45721 Mdot
.51168 .74097 Mdot
.66597 .39099 Mdot
.71277 .57501 Mdot
.67094 .62511 Mdot
.41152 .47571 Mdot
.49184 .63898 Mdot
.49804 .70943 Mdot
.51627 .55865 Mdot
.67854 .55331 Mdot
.45863 .69156 Mdot
.36786 .45963 Mdot
.6824 .60017 Mdot
.32157 .50144 Mdot
.43696 .75691 Mdot
.69152 .42508 Mdot
.57184 .5772 Mdot
.36603 .53149 Mdot
.67056 .39996 Mdot
.36675 .53209 Mdot
.4133 .7786 Mdot
.34803 .30312 Mdot
.32964 .46484 Mdot
.31442 .36914 Mdot
.68847 .47038 Mdot
.54098 .67287 Mdot
.30753 .53354 Mdot
.52285 .58255 Mdot
.4035 .49949 Mdot
.14202 .57644 Mdot
.54205 .25196 Mdot
.54487 .32555 Mdot
.38267 .4562 Mdot
.35184 .46445 Mdot
.28088 .57094 Mdot
.47217 .76858 Mdot
.50728 .54583 Mdot
.37704 .4897 Mdot
.25168 .38372 Mdot
.68255 .57051 Mdot
.33924 .52206 Mdot
.33858 .48119 Mdot
.65886 .45217 Mdot
.67734 .5655 Mdot
.63265 .35601 Mdot
.51743 .55827 Mdot
.65662 .34271 Mdot
.52099 .25312 Mdot
.30026 .36351 Mdot
.29798 .33576 Mdot
.44374 .40641 Mdot
.56626 .25352 Mdot
.40002 .48654 Mdot
.56857 .56797 Mdot
.37602 .45793 Mdot
.55924 .2765 Mdot
.6735 .54843 Mdot
.52819 .67891 Mdot
.45661 .77254 Mdot
.51423 .5793 Mdot
.39148 .50565 Mdot
.57563 .29089 Mdot
.53276 .68709 Mdot
.59402 .79886 Mdot
.52968 .66712 Mdot
.69824 .56747 Mdot
.69858 .59405 Mdot
.54612 .26326 Mdot
.53744 .67566 Mdot
.64781 .34243 Mdot
.73102 .58637 Mdot
.34236 .44064 Mdot
.67639 .51453 Mdot
.49394 .66939 Mdot
.49812 .6704 Mdot
.54028 .64261 Mdot
.38415 .52888 Mdot
.35459 .36484 Mdot
.40269 .56829 Mdot
.67478 .57247 Mdot
.65438 .4211 Mdot
.3875 .30602 Mdot
.40587 .6179 Mdot
.42971 .38322 Mdot
.30516 .52764 Mdot
.35246 .50904 Mdot
.34065 .49797 Mdot
.40052 .53077 Mdot
.57178 .52013 Mdot
.35341 .45155 Mdot
.66836 .55238 Mdot
.66337 .37608 Mdot
.38663 .48404 Mdot
.52633 .57539 Mdot
.56752 .47221 Mdot
.53128 .28616 Mdot
.42482 .73139 Mdot
.49876 .73623 Mdot
.53197 .68565 Mdot
.62605 .37813 Mdot
.62586 .35644 Mdot
.54793 .29704 Mdot
.70583 .57244 Mdot
.52647 .66397 Mdot
.32417 .25277 Mdot
.53023 .26929 Mdot
.34532 .49854 Mdot
.39741 .35079 Mdot
.23308 .39955 Mdot
.33301 .5037 Mdot
.34673 .49018 Mdot
.51968 .59219 Mdot
.62919 .40487 Mdot
.28912 .7273 Mdot
.54607 .78991 Mdot
.54315 .25737 Mdot
.54542 .2925 Mdot
.54515 .64313 Mdot
.36849 .5139 Mdot
.69199 .54934 Mdot
.32275 .34263 Mdot
.668 .48316 Mdot
.66267 .63539 Mdot
.6764 .46618 Mdot
.33779 .50072 Mdot
.39649 .73688 Mdot
.31519 .48442 Mdot
.48926 .69115 Mdot
.5332 .64613 Mdot
.51919 .68702 Mdot
.68556 .57273 Mdot
.43311 .27644 Mdot
.67307 .53601 Mdot
.57727 .56298 Mdot
.51602 .70643 Mdot
.51241 .48377 Mdot
.6397 .40168 Mdot
.36974 .54305 Mdot
.5594 .28321 Mdot
.58868 .31452 Mdot
.30001 .52304 Mdot
.29461 .36017 Mdot
.63624 .35651 Mdot
.55348 .69194 Mdot
.37452 .54295 Mdot
.68294 .62617 Mdot
.41174 .34853 Mdot
.70659 .44997 Mdot
.56493 .59972 Mdot
.53667 .25813 Mdot
.25841 .66523 Mdot
.5381 .27943 Mdot
.70407 .55972 Mdot
.36074 .44991 Mdot
.36976 .51169 Mdot
.34131 .48069 Mdot
.32284 .51494 Mdot
.68356 .56665 Mdot
.33995 .44358 Mdot
.49249 .33797 Mdot
.50706 .55064 Mdot
.56108 .49305 Mdot
.56252 .25684 Mdot
.71412 .5463 Mdot
.66411 .38147 Mdot
.50465 .57723 Mdot
.5695 .30236 Mdot
.38356 .54146 Mdot
.38392 .45967 Mdot
.50715 .54878 Mdot
.32879 .55154 Mdot
.33342 .53801 Mdot
.65681 .36707 Mdot
.55174 .47061 Mdot
.52274 .27496 Mdot
.54449 .27762 Mdot
.7118 .55382 Mdot
.53763 .67631 Mdot
.52916 .28234 Mdot
.68289 .39135 Mdot
.34221 .52513 Mdot
.3209 .49886 Mdot
.49469 .67115 Mdot
.4246 .28175 Mdot
.53151 .28649 Mdot
.41454 .52935 Mdot
.50707 .65659 Mdot
.4996 .71207 Mdot
.3764 .48895 Mdot
.35867 .43866 Mdot
.56616 .66396 Mdot
.55245 .29675 Mdot
.71278 .55082 Mdot
.45099 .38623 Mdot
.70496 .52805 Mdot
.51164 .68965 Mdot
.30419 .4474 Mdot
.55311 .67617 Mdot
.41187 .47845 Mdot
.81486 .60041 Mdot
.35033 .45257 Mdot
.45606 .58388 Mdot
.56218 .4332 Mdot
.63881 .4036 Mdot
.64859 .4069 Mdot
.52174 .56709 Mdot
.53068 .71802 Mdot
.29057 .49854 Mdot
.55613 .28771 Mdot
.66883 .75579 Mdot
.5636 .6524 Mdot
.65282 .41361 Mdot
.61819 .39175 Mdot
.67305 .55268 Mdot
.35601 .51071 Mdot
.38047 .47574 Mdot
.63142 .3617 Mdot
.64463 .49527 Mdot
.54518 .68752 Mdot
.3601 .46872 Mdot
.40003 .52862 Mdot
.65407 .37166 Mdot
.65749 .53402 Mdot
.49834 .64331 Mdot
.3878 .52799 Mdot
.34267 .30983 Mdot
.71934 .56757 Mdot
.39791 .50791 Mdot
.32188 .45961 Mdot
.55248 .26007 Mdot
.28577 .35789 Mdot
.41884 .28698 Mdot
.70237 .52285 Mdot
.52555 .56629 Mdot
.33521 .50433 Mdot
.64553 .40406 Mdot
.39088 .5442 Mdot
.44731 .85223 Mdot
.51042 .55124 Mdot
.36742 .4614 Mdot
.42568 .46833 Mdot
.50462 .67637 Mdot
.35544 .46543 Mdot
.62705 .58126 Mdot
.63478 .37201 Mdot
.36918 .46152 Mdot
.24515 .53958 Mdot
.67359 .55265 Mdot
.30601 .53139 Mdot
.53194 .25988 Mdot
.5252 .47214 Mdot
.18291 .48317 Mdot
.66738 .42328 Mdot
.55565 .24825 Mdot
.36213 .5094 Mdot
.67975 .36052 Mdot
.65985 .55342 Mdot
.4456 .5563 Mdot
.40023 .49569 Mdot
.69137 .52424 Mdot
.68878 .57735 Mdot
.54222 .26149 Mdot
.79878 .69403 Mdot
.33378 .45875 Mdot
.36593 .48418 Mdot
.71423 .76194 Mdot
.5704 .67402 Mdot
.35941 .4883 Mdot
.37575 .50437 Mdot
.70968 .5617 Mdot
.43956 .25094 Mdot
.29217 .3595 Mdot
.58487 .51338 Mdot
.71816 .56718 Mdot
.67878 .34761 Mdot
.63677 .36395 Mdot
.54995 .24596 Mdot
.52202 .67206 Mdot
.5621 .30181 Mdot
.64483 .37857 Mdot
.34314 .48646 Mdot
.69911 .53599 Mdot
.21615 .57999 Mdot
.70042 .5828 Mdot
.66814 .4185 Mdot
.48956 .69063 Mdot
.37242 .77972 Mdot
.47364 .86241 Mdot
.46805 .56256 Mdot
.70518 .59592 Mdot
.54752 .25793 Mdot
.55377 .79281 Mdot
.38717 .4847 Mdot
.4108 .76748 Mdot
.36459 .48757 Mdot
.55991 .61553 Mdot
.67167 .36547 Mdot
.51386 .54813 Mdot
.41203 .47789 Mdot
.29011 .36182 Mdot
.69626 .57825 Mdot
.68743 .54201 Mdot
.40827 .46257 Mdot
.69913 .56447 Mdot
.37577 .46916 Mdot
.65917 .37483 Mdot
.81253 .6256 Mdot
.39028 .4766 Mdot
.38789 .42045 Mdot
.68921 .60395 Mdot
.48796 .73132 Mdot
.67738 .34069 Mdot
.40164 .7067 Mdot
.68092 .63485 Mdot
.69169 .55083 Mdot
.4239 .72044 Mdot
.62471 .38373 Mdot
.50541 .57899 Mdot
.66696 .34206 Mdot
.37214 .48284 Mdot
.33973 .50464 Mdot
.40121 .53132 Mdot
.3711 .50614 Mdot
.37939 .75468 Mdot
.33501 .54047 Mdot
.27569 .62394 Mdot
.36619 .45204 Mdot
.45941 .57209 Mdot
.67108 .5412 Mdot
.3654 .42446 Mdot
.46969 .38882 Mdot
.34087 .45974 Mdot
.55927 .71562 Mdot
.71169 .53999 Mdot
.75893 .61442 Mdot
.68195 .56742 Mdot
.64888 .39793 Mdot
.6982 .57545 Mdot
.38378 .44699 Mdot
.50887 .67278 Mdot
.63555 .38568 Mdot
.46539 .54843 Mdot
.66226 .41651 Mdot
.36589 .45817 Mdot
.66708 .59638 Mdot
.62072 .389 Mdot
.31524 .51422 Mdot
.50964 .66964 Mdot
.27604 .32777 Mdot
.48962 .65043 Mdot
.35277 .47389 Mdot
.35388 .48068 Mdot
.50637 .54739 Mdot
.70284 .57213 Mdot
.55209 .67019 Mdot
.6449 .45817 Mdot
.56496 .30362 Mdot
.51883 .67789 Mdot
.41555 .44131 Mdot
.4056 .3494 Mdot
.50304 .66792 Mdot
.24245 .39169 Mdot
.70518 .5572 Mdot
.50405 .69101 Mdot
.43395 .47484 Mdot
.29915 .69378 Mdot
.541 .2775 Mdot
.64082 .34302 Mdot
.37772 .33261 Mdot
.63584 .36599 Mdot
.64209 .59686 Mdot
.62182 .34847 Mdot
.67315 .56261 Mdot
.28216 .42582 Mdot
.49957 .46311 Mdot
.70014 .58707 Mdot
.68013 .60756 Mdot
.64654 .36879 Mdot
.41401 .5124 Mdot
.55459 .48327 Mdot
.28931 .49001 Mdot
.3079 .43538 Mdot
.71294 .5337 Mdot
.50708 .69927 Mdot
.55572 .70107 Mdot
.3747 .41273 Mdot
.51935 .6542 Mdot
.64833 .38725 Mdot
.44472 .41243 Mdot
.43433 .72377 Mdot
.67591 .54152 Mdot
.55013 .4632 Mdot
.37583 .52833 Mdot
.6685 .37062 Mdot
.6507 .38874 Mdot
.68962 .57651 Mdot
.3383 .7264 Mdot
.29258 .47349 Mdot
.57033 .71011 Mdot
.50972 .69767 Mdot
.5039 .67814 Mdot
.5379 .65678 Mdot
.43298 .27441 Mdot
.71294 .57417 Mdot
.52628 .71672 Mdot
.32729 .5217 Mdot
.36295 .51264 Mdot
.50952 .56444 Mdot
.56579 .29305 Mdot
.31288 .5005 Mdot
.29056 .49967 Mdot
.37734 .48684 Mdot
.63458 .40194 Mdot
.25646 .44797 Mdot
.50584 .55342 Mdot
.62913 .40321 Mdot
.63377 .40471 Mdot
.52312 .56497 Mdot
.27969 .42607 Mdot
.30053 .72879 Mdot
.40167 .45494 Mdot
.54761 .73479 Mdot
.65316 .40685 Mdot
.56892 .36208 Mdot
.46262 .57936 Mdot
.36579 .52123 Mdot
.58018 .49517 Mdot
.65832 .3805 Mdot
.56511 .70596 Mdot
.36995 .47856 Mdot
.5136 .58441 Mdot
.53565 .27068 Mdot
.42256 .56409 Mdot
.51943 .59163 Mdot
.54291 .67675 Mdot
.61172 .4276 Mdot
.50114 .69379 Mdot
.61845 .36284 Mdot
.2951 .51339 Mdot
.88648 .55652 Mdot
.66412 .39226 Mdot
.6842 .74706 Mdot
.50288 .4663 Mdot
.38518 .46807 Mdot
.6292 .37433 Mdot
.54967 .64108 Mdot
.7196 .56972 Mdot
.37139 .36548 Mdot
.53817 .67122 Mdot
.50323 .57542 Mdot
.51278 .567 Mdot
.65252 .37052 Mdot
.52011 .70374 Mdot
.32865 .45178 Mdot
.51498 .65959 Mdot
.69221 .53353 Mdot
.40779 .4748 Mdot
.66665 .62954 Mdot
.3487 .42231 Mdot
.5138 .65491 Mdot
.65962 .4211 Mdot
.52596 .24748 Mdot
.39128 .46282 Mdot
.75025 .6199 Mdot
.36243 .50991 Mdot
.67184 .55279 Mdot
.54934 .40698 Mdot
.22381 .58467 Mdot
.35485 .50017 Mdot
.37882 .52671 Mdot
.66789 .52155 Mdot
.35815 .49989 Mdot
.32558 .49791 Mdot
.4584 .69478 Mdot
.50355 .66435 Mdot
.38549 .48617 Mdot
.64752 .35839 Mdot
.25249 .57249 Mdot
.34576 .46473 Mdot
.624 .57541 Mdot
.26889 .35735 Mdot
.52939 .38168 Mdot
.3289 .40979 Mdot
.33225 .32217 Mdot
.35776 .48225 Mdot
.36853 .51929 Mdot
.40469 .45799 Mdot
.39948 .74209 Mdot
.64308 .37465 Mdot
.67461 .39298 Mdot
.53902 .24279 Mdot
.2684 .36445 Mdot
.54122 .26987 Mdot
.65882 .55633 Mdot
.53345 .46684 Mdot
.50256 .55623 Mdot
.53829 .67737 Mdot
.34339 .47383 Mdot
.67124 .40949 Mdot
.37744 .47644 Mdot
.40233 .50245 Mdot
.64929 .38374 Mdot
.65666 .38639 Mdot
.65208 .4321 Mdot
.52922 .26156 Mdot
.52487 .68471 Mdot
.36855 .44613 Mdot
.52793 .26686 Mdot
.39575 .53307 Mdot
.43847 .3728 Mdot
.52247 .6848 Mdot
.51515 .65336 Mdot
.54591 .71275 Mdot
.39394 .47829 Mdot
.40719 .46605 Mdot
.67433 .53418 Mdot
.49453 .67191 Mdot
.69811 .55207 Mdot
.62987 .37276 Mdot
.66214 .36502 Mdot
.37178 .48369 Mdot
.43401 .5128 Mdot
.5673 .26675 Mdot
.62065 .38337 Mdot
.52393 .59983 Mdot
.53491 .24746 Mdot
.33695 .49245 Mdot
.63285 .36857 Mdot
.57246 .27424 Mdot
.32493 .72551 Mdot
.62248 .64028 Mdot
.53457 .24457 Mdot
.41175 .47127 Mdot
.38471 .61493 Mdot
.35899 .30055 Mdot
.53613 .29202 Mdot
.67314 .54012 Mdot
.38296 .50058 Mdot
.58464 .53428 Mdot
.52245 .26929 Mdot
.40873 .29027 Mdot
.64337 .38387 Mdot
.32222 .42665 Mdot
.32277 .568 Mdot
.4337 .71695 Mdot
.52432 .24951 Mdot
.51159 .65633 Mdot
.50604 .64745 Mdot
.34737 .49906 Mdot
.52812 .46947 Mdot
.67212 .57622 Mdot
.6272 .35488 Mdot
.67541 .39568 Mdot
.51265 .6414 Mdot
.44481 .40532 Mdot
.64413 .35903 Mdot
.3731 .51296 Mdot
.52586 .22812 Mdot
.34847 .53813 Mdot
.4722 .28961 Mdot
.22009 .54748 Mdot
.33549 .40811 Mdot
.52776 .24658 Mdot
.66913 .57056 Mdot
.68014 .57279 Mdot
.69279 .57248 Mdot
.65283 .36296 Mdot
.35996 .34033 Mdot
.67852 .38685 Mdot
.67637 .78261 Mdot
.5407 .25146 Mdot
.35485 .2183 Mdot
.31738 .50214 Mdot
.38311 .46551 Mdot
.34475 .52974 Mdot
.40607 .52218 Mdot
.35835 .48091 Mdot
.68553 .52434 Mdot
.66526 .34766 Mdot
.67079 .4764 Mdot
.53487 .70221 Mdot
.58904 .79937 Mdot
.63799 .40106 Mdot
.52231 .59254 Mdot
.56665 .27415 Mdot
.28147 .34125 Mdot
.54029 .23293 Mdot
.61871 .37423 Mdot
.32815 .48128 Mdot
.54415 .64163 Mdot
.31185 .26502 Mdot
.34879 .46727 Mdot
.62037 .37845 Mdot
.68377 .35956 Mdot
.31522 .70995 Mdot
.37904 .56602 Mdot
.65814 .47749 Mdot
.39822 .35894 Mdot
.54839 .23862 Mdot
.41714 .50846 Mdot
.311 .34681 Mdot
.64619 .37695 Mdot
.66577 .39889 Mdot
.5537 .30347 Mdot
.53429 .77052 Mdot
.52651 .71416 Mdot
.48896 .70832 Mdot
.69483 .52687 Mdot
.38218 .46079 Mdot
.64292 .36583 Mdot
.48626 .68774 Mdot
.4524 .34979 Mdot
.68861 .56497 Mdot
.62112 .39529 Mdot
.36551 .50969 Mdot
.35535 .50183 Mdot
.54032 .26704 Mdot
.56405 .44924 Mdot
.28936 .48998 Mdot
.67208 .75378 Mdot
.41531 .37049 Mdot
.5035 .46589 Mdot
.3808 .48385 Mdot
.54043 .66069 Mdot
.52277 .56546 Mdot
.56234 .28385 Mdot
.38337 .54583 Mdot
.40705 .79407 Mdot
.51433 .7167 Mdot
.69811 .55386 Mdot
.52827 .58166 Mdot
.30339 .36584 Mdot
.3664 .50882 Mdot
.36509 .4872 Mdot
.38142 .52963 Mdot
.34378 .76712 Mdot
.67331 .36909 Mdot
.53319 .65557 Mdot
.53397 .25802 Mdot
.52857 .66133 Mdot
.61449 .36607 Mdot
.55262 .46437 Mdot
.37278 .44404 Mdot
.52629 .72256 Mdot
.52029 .66373 Mdot
.67378 .54985 Mdot
.69207 .58134 Mdot
.68451 .39591 Mdot
.38117 .49896 Mdot
.50181 .55622 Mdot
.51844 .71274 Mdot
.64484 .34539 Mdot
.54202 .268 Mdot
.64128 .59759 Mdot
.3698 .45151 Mdot
.64903 .37192 Mdot
.29469 .51394 Mdot
.53361 .6965 Mdot
.62593 .39276 Mdot
.50805 .58257 Mdot
.55837 .296 Mdot
.33876 .50546 Mdot
.70926 .43498 Mdot
.5171 .58735 Mdot
.3917 .46746 Mdot
.23011 .5651 Mdot
.52891 .4697 Mdot
.53801 .60817 Mdot
.65972 .3571 Mdot
.50828 .57733 Mdot
.5296 .64785 Mdot
.28047 .67243 Mdot
.66992 .39188 Mdot
.33057 .58805 Mdot
.49157 .45815 Mdot
.41013 .46832 Mdot
.54065 .67366 Mdot
.51359 .3267 Mdot
.64008 .76277 Mdot
.36957 .30261 Mdot
.36774 .46474 Mdot
.63639 .36564 Mdot
.53808 .27273 Mdot
.68886 .54219 Mdot
.72887 .56795 Mdot
.48661 .27401 Mdot
.64489 .41198 Mdot
.34297 .47373 Mdot
.50673 .6982 Mdot
.69936 .55861 Mdot
.28021 .57421 Mdot
.68175 .37334 Mdot
.6441 .35704 Mdot
.34969 .52445 Mdot
.54198 .27163 Mdot
.57416 .53826 Mdot
.67457 .37442 Mdot
.66974 .34979 Mdot
.45635 .6803 Mdot
.5526 .24058 Mdot
.39462 .52496 Mdot
.37544 .41282 Mdot
.32833 .51236 Mdot
.63546 .79405 Mdot
.50582 .57438 Mdot
.5369 .70172 Mdot
.3535 .48826 Mdot
.69101 .47347 Mdot
.66797 .38297 Mdot
.39856 .35957 Mdot
.65547 .55493 Mdot
.69642 .57983 Mdot
.63499 .37424 Mdot
.37115 .47246 Mdot
.68792 .50834 Mdot
.5513 .24769 Mdot
.39428 .52584 Mdot
.41085 .4751 Mdot
.50074 .64805 Mdot
.69704 .53363 Mdot
.24537 .56724 Mdot
.69203 .54018 Mdot
.71174 .5617 Mdot
.50458 .62659 Mdot
.34697 .49926 Mdot
.63284 .39642 Mdot
.63291 .41936 Mdot
.42055 .51351 Mdot
.57856 .35206 Mdot
.53798 .71231 Mdot
.64511 .32882 Mdot
.3994 .79449 Mdot
.31919 .48963 Mdot
.53054 .58241 Mdot
.56914 .5876 Mdot
.69439 .59441 Mdot
.35102 .49607 Mdot
.53977 .68174 Mdot
.67261 .3566 Mdot
.64202 .36264 Mdot
.31127 .49654 Mdot
.68216 .57493 Mdot
.57255 .28205 Mdot
.64721 .39047 Mdot
.45476 .39377 Mdot
.36493 .46046 Mdot
.74807 .58071 Mdot
.64403 .39184 Mdot
.1746 .41494 Mdot
.69415 .47615 Mdot
.5027 .67379 Mdot
.3686 .52659 Mdot
.51225 .63813 Mdot
.55076 .24341 Mdot
.64128 .33828 Mdot
.66863 .55895 Mdot
.33947 .55835 Mdot
.82438 .46469 Mdot
.65023 .36479 Mdot
.53058 .67577 Mdot
.34512 .48532 Mdot
.42131 .71061 Mdot
.38918 .4824 Mdot
.43992 .24615 Mdot
.52527 .28034 Mdot
.64201 .59453 Mdot
.67238 .57058 Mdot
.38014 .52533 Mdot
.5328 .27739 Mdot
.6372 .42274 Mdot
.64914 .38286 Mdot
.82522 .52609 Mdot
.51654 .5905 Mdot
.60427 .36924 Mdot
.39264 .47397 Mdot
.63744 .34949 Mdot
.40722 .61817 Mdot
.68905 .57839 Mdot
.32841 .51052 Mdot
.62904 .40984 Mdot
.60542 .77711 Mdot
.40096 .35436 Mdot
.36573 .46206 Mdot
.43462 .49579 Mdot
.67349 .55963 Mdot
.55286 .79306 Mdot
.67038 .3621 Mdot
.38879 .53968 Mdot
.65719 .55796 Mdot
.29572 .4177 Mdot
.63534 .46341 Mdot
.52461 .68507 Mdot
.62136 .40317 Mdot
.71095 .54647 Mdot
.3264 .42573 Mdot
.56958 .28271 Mdot
.68455 .38586 Mdot
.64877 .41853 Mdot
.40336 .47196 Mdot
.3864 .53367 Mdot
.43536 .49265 Mdot
.54809 .69137 Mdot
.70926 .55714 Mdot
.40398 .50593 Mdot
.43394 .3657 Mdot
.40801 .51572 Mdot
.70912 .55119 Mdot
.84084 .63053 Mdot
.32879 .48514 Mdot
.3724 .45279 Mdot
.41533 .72136 Mdot
.5555 .67646 Mdot
.50849 .65012 Mdot
.42314 .37292 Mdot
.39132 .49665 Mdot
.50918 .48622 Mdot
.52744 .68312 Mdot
.53007 .67197 Mdot
.51016 .48548 Mdot
.40441 .46733 Mdot
.48386 .66917 Mdot
.69969 .5608 Mdot
.69576 .58026 Mdot
.50466 .67564 Mdot
.35463 .53789 Mdot
.66028 .55755 Mdot
.3532 .72219 Mdot
.61821 .38212 Mdot
.30655 .35091 Mdot
.51757 .66136 Mdot
.39672 .34737 Mdot
.70474 .55974 Mdot
.19558 .43198 Mdot
.23847 .38417 Mdot
.32317 .47163 Mdot
.34963 .49909 Mdot
.55254 .26326 Mdot
.33109 .554 Mdot
.5197 .56125 Mdot
.69406 .57298 Mdot
.57135 .51907 Mdot
.51844 .68693 Mdot
.39075 .49461 Mdot
.39232 .30706 Mdot
.18787 .48864 Mdot
.42821 .44261 Mdot
.52358 .67135 Mdot
.51265 .68143 Mdot
.64262 .35475 Mdot
.61896 .36821 Mdot
.36863 .44489 Mdot
.67601 .56805 Mdot
.50252 .68278 Mdot
.70457 .54437 Mdot
.64603 .37838 Mdot
.63902 .39968 Mdot
.50753 .55524 Mdot
.30247 .44103 Mdot
.63704 .37863 Mdot
.62492 .55341 Mdot
.43454 .36684 Mdot
.49321 .66875 Mdot
.70074 .77096 Mdot
.20236 .41401 Mdot
.44305 .76309 Mdot
.53672 .27189 Mdot
.2859 .42175 Mdot
.66789 .53766 Mdot
.38401 .52423 Mdot
.36554 .49184 Mdot
.51591 .57582 Mdot
.66512 .53984 Mdot
.55886 .26003 Mdot
.6927 .57945 Mdot
.56063 .28965 Mdot
.67147 .40009 Mdot
.34529 .46806 Mdot
.34064 .46202 Mdot
.68601 .54291 Mdot
.63079 .35787 Mdot
.62155 .39024 Mdot
.54609 .28313 Mdot
.27794 .34387 Mdot
.65172 .37207 Mdot
.51937 .66146 Mdot
.31175 .596 Mdot
.51276 .56839 Mdot
.36934 .47796 Mdot
.32704 .32366 Mdot
.27164 .65689 Mdot
.40502 .52903 Mdot
.52633 .5831 Mdot
.8027 .68915 Mdot
.34899 .45992 Mdot
.82022 .41623 Mdot
.50325 .55767 Mdot
.55337 .67612 Mdot
.62882 .38828 Mdot
.52027 .59061 Mdot
.25142 .46136 Mdot
.69994 .41314 Mdot
.41613 .52107 Mdot
.52739 .71496 Mdot
.54935 .70473 Mdot
.55187 .46711 Mdot
.6321 .79585 Mdot
.53358 .25902 Mdot
.55207 .25142 Mdot
.67045 .38359 Mdot
.65808 .61103 Mdot
.33318 .53099 Mdot
.54903 .25196 Mdot
.47972 .68969 Mdot
.36918 .53031 Mdot
.5319 .47004 Mdot
.55786 .48831 Mdot
.52468 .64647 Mdot
.35403 .42717 Mdot
.6694 .38377 Mdot
.5289 .67664 Mdot
.55245 .47696 Mdot
.34271 .5232 Mdot
.52082 .68568 Mdot
.70826 .56694 Mdot
.48029 .52953 Mdot
.51736 .65733 Mdot
.37985 .366 Mdot
.68751 .54787 Mdot
.53894 .46669 Mdot
.38683 .22823 Mdot
.14424 .49054 Mdot
.68337 .57339 Mdot
.62222 .37889 Mdot
.64341 .36687 Mdot
.65641 .37225 Mdot
.54612 .67757 Mdot
.66059 .38807 Mdot
.53227 .70856 Mdot
.71332 .59523 Mdot
.27943 .3616 Mdot
.54709 .26614 Mdot
.5362 .33844 Mdot
.50634 .67119 Mdot
.66432 .78701 Mdot
.59285 .85221 Mdot
.40394 .52142 Mdot
.70258 .58665 Mdot
.52694 .25657 Mdot
.41021 .37763 Mdot
.55322 .26125 Mdot
.62473 .38291 Mdot
.29599 .36368 Mdot
.37727 .46995 Mdot
.61797 .61364 Mdot
.53911 .27318 Mdot
.53053 .67046 Mdot
.39901 .47824 Mdot
.61415 .39603 Mdot
.55207 .24537 Mdot
.54788 .28084 Mdot
.36016 .48061 Mdot
.55408 .68967 Mdot
.62285 .38839 Mdot
.68785 .52176 Mdot
.53191 .22534 Mdot
.41133 .55145 Mdot
.34388 .46365 Mdot
.33531 .46141 Mdot
.4065 .35645 Mdot
.65945 .61324 Mdot
.68766 .55022 Mdot
.41058 .29231 Mdot
.66726 .36877 Mdot
.37008 .30054 Mdot
.66363 .74883 Mdot
.5158 .32416 Mdot
.50612 .57361 Mdot
.50428 .57234 Mdot
.35657 .46778 Mdot
.50293 .8506 Mdot
.45564 .54942 Mdot
.6604 .56989 Mdot
.51746 .57218 Mdot
.6167 .37773 Mdot
.49633 .68057 Mdot
.3337 .56936 Mdot
.3149 .50131 Mdot
.68553 .5217 Mdot
.65145 .37788 Mdot
.44002 .85262 Mdot
.53895 .25441 Mdot
.41627 .38231 Mdot
.37806 .50126 Mdot
.36077 .47127 Mdot
.68496 .55973 Mdot
.66834 .55615 Mdot
.45567 .67825 Mdot
.51919 .37021 Mdot
.67222 .63397 Mdot
.70124 .51999 Mdot
.43761 .85305 Mdot
.56436 .60399 Mdot
.51607 .69504 Mdot
.52467 .56302 Mdot
.67301 .57592 Mdot
.35722 .48865 Mdot
.55529 .68004 Mdot
.45298 .55356 Mdot
.56087 .67251 Mdot
.52451 .47171 Mdot
.45085 .3867 Mdot
.35339 .50899 Mdot
.54318 .64633 Mdot
.52532 .67946 Mdot
.53148 .73333 Mdot
.51686 .56303 Mdot
.3793 .48772 Mdot
.39355 .53893 Mdot
.35671 .45244 Mdot
.45458 .63021 Mdot
.35582 .46464 Mdot
.65817 .75305 Mdot
.4337 .38309 Mdot
.646 .22458 Mdot
.35515 .45681 Mdot
.70966 .56932 Mdot
.34504 .47526 Mdot
.53588 .28169 Mdot
.33312 .49907 Mdot
.51844 .47138 Mdot
.69568 .55946 Mdot
.41284 .7818 Mdot
.69184 .39282 Mdot
.33879 .46781 Mdot
.56795 .25663 Mdot
.753 .694 Mdot
.40966 .2966 Mdot
.45692 .67863 Mdot
.51491 .65996 Mdot
.67646 .35525 Mdot
.67974 .58397 Mdot
.64729 .39888 Mdot
.33694 .44431 Mdot
.51343 .55436 Mdot
.33854 .21207 Mdot
.40953 .33377 Mdot
.35485 .48807 Mdot
.29349 .46711 Mdot
.52209 .65114 Mdot
.66703 .38608 Mdot
.47463 .77316 Mdot
.35054 .53261 Mdot
.55709 .29893 Mdot
.52497 .26851 Mdot
.63545 .3147 Mdot
.48707 .60391 Mdot
.4313 .62028 Mdot
.68618 .55828 Mdot
.64974 .36203 Mdot
.52343 .25994 Mdot
.50401 .73642 Mdot
.68148 .58295 Mdot
.69328 .59466 Mdot
.69783 .53318 Mdot
.3714 .45789 Mdot
.50669 .56013 Mdot
.4873 .6252 Mdot
.51341 .58661 Mdot
.33133 .52034 Mdot
.64709 .41822 Mdot
.50727 .58056 Mdot
.55209 .27055 Mdot
.71314 .55464 Mdot
.63651 .40187 Mdot
.3522 .47786 Mdot
.53012 .6866 Mdot
.47609 .31741 Mdot
.70387 .46892 Mdot
.5298 .4688 Mdot
.52991 .46875 Mdot
.5121 .72224 Mdot
.57733 .55762 Mdot
.69147 .60921 Mdot
.30505 .70234 Mdot
.5188 .22493 Mdot
.3745 .55284 Mdot
.58743 .34977 Mdot
.67906 .38429 Mdot
.63737 .38701 Mdot
.37976 .46814 Mdot
.64955 .34817 Mdot
.38974 .49135 Mdot
.65922 .35627 Mdot
.63564 .77444 Mdot
.31391 .47787 Mdot
.6457 .38751 Mdot
.35833 .56533 Mdot
.39081 .46262 Mdot
.53568 .65901 Mdot
.67799 .36429 Mdot
.32279 .47245 Mdot
.48524 .13568 Mdot
.6752 .54828 Mdot
.51575 .56328 Mdot
.48635 .43138 Mdot
.70342 .56596 Mdot
.5246 .71059 Mdot
.38032 .50631 Mdot
.54098 .24934 Mdot
.51225 .68997 Mdot
.68261 .33707 Mdot
.54379 .27543 Mdot
.44874 .41543 Mdot
.50805 .68547 Mdot
.51026 .56906 Mdot
.55026 .29613 Mdot
.41748 .51747 Mdot
.64001 .38644 Mdot
.70219 .4741 Mdot
.52532 .58703 Mdot
.37882 .47353 Mdot
.61469 .39162 Mdot
.69723 .57723 Mdot
.33803 .48532 Mdot
.64246 .36479 Mdot
.5279 .57205 Mdot
.38124 .45387 Mdot
.3962 .48545 Mdot
.52028 .77682 Mdot
.55769 .41873 Mdot
.54923 .26815 Mdot
.48953 .68909 Mdot
.32475 .51677 Mdot
.5349 .27798 Mdot
.67493 .46495 Mdot
.37563 .42842 Mdot
.51941 .71594 Mdot
.34422 .72054 Mdot
.62952 .35359 Mdot
.68063 .5762 Mdot
.66408 .42084 Mdot
.54568 .24133 Mdot
.64831 .83778 Mdot
.51646 .5585 Mdot
.39278 .44152 Mdot
.32359 .49585 Mdot
.65681 .3382 Mdot
.52253 .67985 Mdot
.66715 .63439 Mdot
.3404 .50798 Mdot
.30007 .46174 Mdot
.36503 .47952 Mdot
.70914 .4248 Mdot
.54837 .68391 Mdot
.3676 .47926 Mdot
.41761 .53363 Mdot
.32156 .49893 Mdot
.56899 .2643 Mdot
.35026 .22175 Mdot
.41411 .50335 Mdot
.90555 .51827 Mdot
.52014 .5532 Mdot
.65357 .38163 Mdot
.38291 .36684 Mdot
.48902 .4266 Mdot
.57831 .18094 Mdot
.53096 .71221 Mdot
.54266 .73629 Mdot
.63892 .39864 Mdot
.49512 .30116 Mdot
.57348 .5527 Mdot
.39813 .48571 Mdot
.37625 .5051 Mdot
.62477 .38302 Mdot
.64428 .34478 Mdot
.51787 .55351 Mdot
.40922 .45967 Mdot
.34789 .42389 Mdot
.65818 .42094 Mdot
.35157 .46464 Mdot
.25971 .63841 Mdot
.71432 .58255 Mdot
.5039 .66826 Mdot
.68763 .54079 Mdot
.71868 .57418 Mdot
.45676 .77213 Mdot
.41417 .36715 Mdot
.69227 .52558 Mdot
.67824 .59667 Mdot
.51625 .33113 Mdot
.43142 .72063 Mdot
.57029 .26922 Mdot
.47123 .54306 Mdot
.66255 .37009 Mdot
.37782 .48964 Mdot
.54828 .68076 Mdot
.47503 .21639 Mdot
.69808 .64611 Mdot
.24211 .44636 Mdot
.39327 .52496 Mdot
.66609 .37706 Mdot
.52739 .58609 Mdot
.37668 .42823 Mdot
.36226 .30032 Mdot
.36298 .46634 Mdot
.6233 .3587 Mdot
.43398 .7226 Mdot
.68146 .49086 Mdot
.71968 .53188 Mdot
.57012 .66573 Mdot
.34435 .47556 Mdot
.54422 .69178 Mdot
.71314 .53688 Mdot
.53141 .26992 Mdot
.5461 .25779 Mdot
.33781 .46886 Mdot
.50283 .46669 Mdot
.51137 .23144 Mdot
.39775 .48048 Mdot
.40456 .47122 Mdot
.50894 .5763 Mdot
.40546 .47224 Mdot
.39911 .53774 Mdot
.40221 .51139 Mdot
.39391 .533 Mdot
.67821 .58017 Mdot
.4545 .75793 Mdot
.40313 .45123 Mdot
.35808 .43973 Mdot
.72022 .55188 Mdot
.34934 .43964 Mdot
.68308 .56897 Mdot
.70659 .62763 Mdot
.68403 .52801 Mdot
.54548 .25929 Mdot
.61289 .38974 Mdot
.49438 .75797 Mdot
.50296 .68418 Mdot
.70567 .57886 Mdot
.56304 .29399 Mdot
.68951 .57429 Mdot
.65913 .36121 Mdot
.66871 .49333 Mdot
.52517 .61137 Mdot
.45784 .40145 Mdot
.42693 .73111 Mdot
.75579 .56232 Mdot
.64379 .35057 Mdot
.50373 .68025 Mdot
.62957 .58542 Mdot
.38455 .52331 Mdot
.53608 .25526 Mdot
.35664 .46864 Mdot
.71289 .55804 Mdot
.66385 .37294 Mdot
.47205 .72626 Mdot
.55007 .26769 Mdot
.7319 .75146 Mdot
.67158 .40966 Mdot
.32648 .49489 Mdot
.71938 .54707 Mdot
.63996 .52098 Mdot
.67071 .55611 Mdot
.27977 .35805 Mdot
.57313 .57329 Mdot
.47783 .23563 Mdot
.51049 .6817 Mdot
.51546 .59513 Mdot
.15922 .56885 Mdot
.72198 .68197 Mdot
.53292 .69247 Mdot
.62165 .43314 Mdot
.35981 .45925 Mdot
.40443 .51536 Mdot
.29946 .44991 Mdot
.55869 .67818 Mdot
.38047 .52985 Mdot
.51261 .56086 Mdot
.41984 .36277 Mdot
.50589 .59851 Mdot
.68569 .37125 Mdot
.38921 .4889 Mdot
.71215 .5327 Mdot
.70571 .58074 Mdot
.49985 .57031 Mdot
.69333 .53694 Mdot
.38782 .45159 Mdot
.50714 .675 Mdot
.55431 .48209 Mdot
.5474 .24345 Mdot
.69726 .73137 Mdot
.51128 .25939 Mdot
.54947 .23193 Mdot
.31877 .49075 Mdot
.63629 .39875 Mdot
.81718 .43604 Mdot
.38545 .52539 Mdot
.52864 .68062 Mdot
.32566 .49976 Mdot
.40563 .50844 Mdot
.38666 .44694 Mdot
.65027 .36237 Mdot
.40038 .35189 Mdot
.3508 .46504 Mdot
.70311 .52843 Mdot
.50879 .48311 Mdot
.31447 .50286 Mdot
.58698 .5074 Mdot
.52059 .47191 Mdot
.74953 .5693 Mdot
.49696 .65589 Mdot
.63194 .3944 Mdot
.51646 .68688 Mdot
.56333 .66504 Mdot
.52458 .71032 Mdot
.4972 .61417 Mdot
.29604 .69229 Mdot
.81794 .40566 Mdot
.41288 .61934 Mdot
.42669 .73635 Mdot
.56248 .65373 Mdot
.75327 .38323 Mdot
.53704 .68931 Mdot
.52657 .71126 Mdot
.82346 .60472 Mdot
.54656 .7042 Mdot
.37267 .48357 Mdot
.33719 .46221 Mdot
.36708 .77644 Mdot
.56662 .23824 Mdot
.38968 .46697 Mdot
.39834 .53184 Mdot
.52384 .26467 Mdot
.53021 .76864 Mdot
.53061 .56915 Mdot
.42127 .38803 Mdot
.51872 .59465 Mdot
.35945 .48027 Mdot
.34364 .50325 Mdot
.34935 .55059 Mdot
.18308 .51754 Mdot
.48503 .24625 Mdot
.54956 .70683 Mdot
.39747 .54585 Mdot
.75022 .53869 Mdot
.36203 .51867 Mdot
.3323 .50926 Mdot
.39145 .4495 Mdot
.63292 .39654 Mdot
.50204 .7014 Mdot
.28985 .49554 Mdot
.72078 .7036 Mdot
.36379 .50837 Mdot
.51343 .27088 Mdot
.57847 .29627 Mdot
.37205 .47347 Mdot
.54254 .71165 Mdot
.40175 .51923 Mdot
.50043 .66249 Mdot
.50968 .69038 Mdot
.31152 .44044 Mdot
.47967 .6397 Mdot
.4969 .68268 Mdot
.39784 .48722 Mdot
.63358 .35518 Mdot
.67661 .75144 Mdot
.37747 .4731 Mdot
.55063 .27451 Mdot
.34792 .49408 Mdot
.56775 .2595 Mdot
.41163 .48854 Mdot
.51019 .58235 Mdot
.21917 .58708 Mdot
.66702 .3987 Mdot
.53502 .23156 Mdot
.64302 .3486 Mdot
.34271 .53865 Mdot
.51751 .63187 Mdot
.68302 .49428 Mdot
.4907 .26075 Mdot
.50854 .57523 Mdot
.42994 .28218 Mdot
.51374 .49511 Mdot
.67004 .53788 Mdot
.53254 .65435 Mdot
.4475 .74189 Mdot
.58469 .50446 Mdot
.68661 .37108 Mdot
.6174 .38938 Mdot
.62628 .45608 Mdot
.8126 .62533 Mdot
.3581 .4568 Mdot
.58759 .52998 Mdot
.27052 .61863 Mdot
.32839 .55238 Mdot
.38116 .56886 Mdot
.65087 .41898 Mdot
.39005 .4672 Mdot
.39709 .33048 Mdot
.64548 .36965 Mdot
.56316 .2606 Mdot
.53846 .70103 Mdot
.54685 .28815 Mdot
.63628 .65684 Mdot
.45769 .69394 Mdot
.63994 .37603 Mdot
.39312 .53122 Mdot
.38775 .46898 Mdot
.5538 .67243 Mdot
.28042 .57348 Mdot
.50373 .66351 Mdot
.5384 .24625 Mdot
.67236 .38796 Mdot
.4208 .15718 Mdot
.34425 .4871 Mdot
.52232 .66478 Mdot
.69113 .39605 Mdot
.35813 .50218 Mdot
.68385 .57676 Mdot
.37676 .53049 Mdot
.52785 .66337 Mdot
.406 .47333 Mdot
.51025 .68362 Mdot
.63663 .35773 Mdot
.338 .46621 Mdot
.33759 .4926 Mdot
.41457 .28906 Mdot
.55919 .26128 Mdot
.49775 .67382 Mdot
.38983 .33326 Mdot
.32833 .5124 Mdot
.34608 .3079 Mdot
.34576 .46623 Mdot
.42605 .71968 Mdot
.41799 .44904 Mdot
.5108 .56183 Mdot
.32531 .50044 Mdot
.37622 .47153 Mdot
.28081 .57112 Mdot
.40113 .61704 Mdot
.45539 .63244 Mdot
.69026 .58189 Mdot
.54198 .66905 Mdot
.64029 .36933 Mdot
.67645 .35902 Mdot
.65653 .39214 Mdot
.51902 .27166 Mdot
.42125 .51618 Mdot
.38262 .47704 Mdot
.66717 .58436 Mdot
.5447 .25182 Mdot
.51964 .6693 Mdot
.54262 .26204 Mdot
.41001 .36746 Mdot
.55381 .2761 Mdot
.52132 .56183 Mdot
.68783 .47699 Mdot
.26746 .64863 Mdot
.56258 .27918 Mdot
.50363 .67194 Mdot
.50085 .48321 Mdot
.32456 .54854 Mdot
.60694 .79847 Mdot
.55241 .2987 Mdot
.6498 .45243 Mdot
.37662 .4502 Mdot
.37034 .36226 Mdot
.68452 .56749 Mdot
.54802 .2892 Mdot
.69526 .5317 Mdot
.40094 .51945 Mdot
.57566 .70642 Mdot
.53518 .67567 Mdot
.71693 .57979 Mdot
.33192 .51222 Mdot
.54718 .28886 Mdot
.63903 .38032 Mdot
.4316 .71856 Mdot
.71389 .59135 Mdot
.48449 .32495 Mdot
.37072 .30205 Mdot
.67159 .37846 Mdot
.41682 .68657 Mdot
.68693 .52884 Mdot
.39412 .54718 Mdot
.44716 .54161 Mdot
.34281 .53311 Mdot
.62221 .39171 Mdot
.63686 .38757 Mdot
.75937 .58579 Mdot
.33833 .49722 Mdot
.39763 .44691 Mdot
.49108 .68212 Mdot
.67307 .3814 Mdot
.5225 .7092 Mdot
.53361 .64161 Mdot
.62315 .37715 Mdot
.50308 .66081 Mdot
.54401 .27682 Mdot
.34073 .34032 Mdot
.68746 .52822 Mdot
.67351 .57052 Mdot
.63771 .37708 Mdot
.65731 .41005 Mdot
.63702 .39947 Mdot
.35027 .52919 Mdot
.51119 .69703 Mdot
.37383 .5245 Mdot
.34416 .47896 Mdot
.53321 .58176 Mdot
.49427 .6476 Mdot
.35709 .52279 Mdot
.55786 .49279 Mdot
.55378 .30075 Mdot
.65041 .38656 Mdot
.70633 .55074 Mdot
.47151 .3065 Mdot
.69358 .52263 Mdot
.32329 .50731 Mdot
.6089 .78171 Mdot
.5429 .6739 Mdot
.55314 .26223 Mdot
.52026 .47015 Mdot
.55156 .26587 Mdot
.71522 .58175 Mdot
.50494 .71856 Mdot
.44621 .41003 Mdot
.33601 .49177 Mdot
.40834 .35664 Mdot
.39065 .2452 Mdot
.6714 .74076 Mdot
.70905 .56024 Mdot
.40226 .52089 Mdot
.50333 .56594 Mdot
.30693 .70586 Mdot
.38186 .47384 Mdot
.31687 .47733 Mdot
.5055 .44635 Mdot
.32163 .4893 Mdot
.54212 .71986 Mdot
.53401 .47347 Mdot
.41447 .51432 Mdot
.35375 .54101 Mdot
.81359 .55481 Mdot
.38483 .45807 Mdot
.33576 .48304 Mdot
.37107 .49129 Mdot
.37112 .52887 Mdot
.51146 .63847 Mdot
.54993 .45855 Mdot
.71547 .54133 Mdot
.34053 .34013 Mdot
.69814 .53083 Mdot
.63125 .37749 Mdot
.50477 .35598 Mdot
.50297 .65163 Mdot
.55205 .26637 Mdot
.59552 .52807 Mdot
.29548 .36703 Mdot
.64089 .35473 Mdot
.43416 .26997 Mdot
.57093 .28435 Mdot
.31201 .53954 Mdot
.54634 .24055 Mdot
.63317 .41421 Mdot
.68311 .57499 Mdot
.32802 .4825 Mdot
.51837 .7115 Mdot
.517 .65669 Mdot
.33274 .52783 Mdot
.718 .71654 Mdot
.68103 .57768 Mdot
.57239 .35043 Mdot
.37499 .4609 Mdot
.3286 .5108 Mdot
.50557 .65357 Mdot
.66677 .38321 Mdot
.51473 .49325 Mdot
.56658 .281 Mdot
.36185 .51539 Mdot
.40459 .52492 Mdot
.40985 .36604 Mdot
.69716 .58286 Mdot
.5222 .57179 Mdot
.38699 .48128 Mdot
.42138 .38088 Mdot
.3731 .53213 Mdot
.35303 .54728 Mdot
.62678 .35852 Mdot
.30496 .45055 Mdot
.34553 .50889 Mdot
.56616 .64999 Mdot
.68564 .53004 Mdot
.52356 .68301 Mdot
.5507 .72619 Mdot
.50824 .57947 Mdot
.67686 .54754 Mdot
.35189 .52225 Mdot
.69767 .5915 Mdot
.40523 .51216 Mdot
.35012 .47423 Mdot
.70893 .56299 Mdot
.52289 .70671 Mdot
.65825 .6251 Mdot
.45473 .75705 Mdot
.40252 .50359 Mdot
.35116 .497 Mdot
.56694 .23865 Mdot
.49418 .20457 Mdot
.33793 .5012 Mdot
.50283 .67826 Mdot
.35478 .50208 Mdot
.6669 .55072 Mdot
.53323 .26055 Mdot
.532 .68298 Mdot
.67053 .36989 Mdot
.63783 .35838 Mdot
.67336 .42404 Mdot
.52094 .56098 Mdot
.39812 .44896 Mdot
.48948 .6885 Mdot
.49321 .64747 Mdot
.35513 .3485 Mdot
.65265 .38266 Mdot
.53449 .26589 Mdot
.39359 .47465 Mdot
.33184 .55585 Mdot
.71841 .56992 Mdot
.91002 .50372 Mdot
.44325 .40588 Mdot
.56843 .30277 Mdot
.52326 .37948 Mdot
.51485 .57922 Mdot
.37896 .45602 Mdot
.53895 .28336 Mdot
.6275 .37151 Mdot
.40452 .51574 Mdot
.42117 .4585 Mdot
.67144 .46221 Mdot
.64648 .40786 Mdot
.70351 .59153 Mdot
.66478 .36015 Mdot
.57216 .27684 Mdot
.51875 .56056 Mdot
.53392 .66075 Mdot
.36887 .46891 Mdot
.36075 .42335 Mdot
.65928 .37413 Mdot
.50377 .54917 Mdot
.34477 .45839 Mdot
.54365 .66822 Mdot
.6581 .38619 Mdot
.36091 .48443 Mdot
.31824 .71042 Mdot
.49597 .7586 Mdot
.66472 .37004 Mdot
.37564 .51104 Mdot
.31285 .56368 Mdot
.64174 .40719 Mdot
.63204 .41249 Mdot
.40178 .52319 Mdot
.54966 .29224 Mdot
.35338 .51053 Mdot
.67575 .56575 Mdot
.4026 .34887 Mdot
.68321 .5435 Mdot
.35989 .29965 Mdot
.38207 .53955 Mdot
.45149 .50961 Mdot
.5547 .65108 Mdot
.52224 .23449 Mdot
.21502 .3976 Mdot
.31967 .50098 Mdot
.54736 .76685 Mdot
.39782 .34733 Mdot
.46457 .41732 Mdot
.55713 .7576 Mdot
.56402 .28671 Mdot
.69231 .57267 Mdot
.33807 .472 Mdot
.65172 .61405 Mdot
.55972 .28719 Mdot
.35793 .30028 Mdot
.38269 .51432 Mdot
.52679 .67241 Mdot
.37057 .45978 Mdot
.53445 .66336 Mdot
.36685 .49963 Mdot
.5249 .77915 Mdot
.51313 .22946 Mdot
.27919 .35842 Mdot
.31299 .54013 Mdot
.64095 .51957 Mdot
.4269 .73198 Mdot
.53974 .26975 Mdot
.40537 .48659 Mdot
.52152 .58062 Mdot
.69307 .57943 Mdot
.62568 .51865 Mdot
.64008 .39924 Mdot
.70327 .52929 Mdot
.5217 .70101 Mdot
.6228 .41163 Mdot
.50095 .55722 Mdot
.34483 .40085 Mdot
.54615 .28895 Mdot
.67537 .54886 Mdot
.37377 .4713 Mdot
.33986 .52988 Mdot
.70939 .42502 Mdot
.33956 .22228 Mdot
.52033 .63656 Mdot
.76496 .72498 Mdot
.50083 .71476 Mdot
.55515 .25463 Mdot
.62377 .36302 Mdot
.35779 .49052 Mdot
.3817 .4958 Mdot
.6488 .40727 Mdot
.55224 .67088 Mdot
.54844 .23267 Mdot
.48066 .22855 Mdot
.65956 .56526 Mdot
.34731 .23747 Mdot
.53502 .68152 Mdot
.34862 .23674 Mdot
.54147 .32063 Mdot
.47674 .71736 Mdot
.25681 .35567 Mdot
.70138 .56399 Mdot
.34672 .23708 Mdot
.52645 .66892 Mdot
.36385 .45386 Mdot
.51154 .5709 Mdot
.50866 .55138 Mdot
.54175 .69302 Mdot
.62516 .38616 Mdot
.56885 .28603 Mdot
.37206 .4616 Mdot
.36092 .40673 Mdot
.2803 .57449 Mdot
.67127 .39893 Mdot
.29285 .47955 Mdot
.70255 .55548 Mdot
.35568 .50058 Mdot
.52456 .25927 Mdot
.69955 .5642 Mdot
.5122 .58739 Mdot
.29934 .36357 Mdot
.37996 .50664 Mdot
.5109 .47137 Mdot
.68278 .56379 Mdot
.48985 .20487 Mdot
.33873 .49522 Mdot
.68707 .52886 Mdot
.35764 .42339 Mdot
.75605 .5405 Mdot
.53879 .48808 Mdot
.72077 .68193 Mdot
.67388 .41454 Mdot
.65924 .35666 Mdot
.48381 .14148 Mdot
.59092 .19837 Mdot
.71274 .54483 Mdot
.52965 .58171 Mdot
.34824 .21967 Mdot
.68932 .53182 Mdot
.34099 .51097 Mdot
.34881 .46161 Mdot
.43424 .72303 Mdot
.34488 .56042 Mdot
.52189 .55563 Mdot
.46528 .57531 Mdot
.39368 .45669 Mdot
.29135 .49087 Mdot
.33886 .4803 Mdot
.55145 .70191 Mdot
.70107 .55778 Mdot
.237 .71482 Mdot
.69271 .58861 Mdot
.44951 .50546 Mdot
.66281 .37039 Mdot
.65979 .42542 Mdot
.37074 .47335 Mdot
.43338 .57107 Mdot
.4468 .85863 Mdot
.34511 .46348 Mdot
.51968 .47026 Mdot
.37368 .30135 Mdot
.41498 .52726 Mdot
.50955 .70891 Mdot
.35096 .42268 Mdot
.48752 .66682 Mdot
.69943 .56784 Mdot
.56324 .28704 Mdot
.5165 .23835 Mdot
.69013 .57149 Mdot
.38123 .49446 Mdot
.51537 .2477 Mdot
.36212 .47368 Mdot
.38176 .46104 Mdot
.41512 .37713 Mdot
.52875 .25164 Mdot
.6304 .39676 Mdot
.54736 .25979 Mdot
.53489 .71243 Mdot
.829 .64957 Mdot
.53991 .26475 Mdot
.4316 .72089 Mdot
.39524 .33721 Mdot
.35675 .22228 Mdot
.51846 .65458 Mdot
.54783 .24288 Mdot
.69802 .57399 Mdot
.45931 .43286 Mdot
.40968 .72296 Mdot
.69283 .52268 Mdot
.3849 .47797 Mdot
.5131 .63771 Mdot
.50522 .71755 Mdot
.69057 .51869 Mdot
.53253 .65715 Mdot
.42754 .49354 Mdot
.39675 .49508 Mdot
.71239 .53673 Mdot
.18391 .48499 Mdot
.67335 .57225 Mdot
.4666 .77568 Mdot
.40338 .45958 Mdot
.52996 .68186 Mdot
.42375 .72144 Mdot
.55837 .72364 Mdot
.50885 .55454 Mdot
.33174 .493 Mdot
.53664 .26433 Mdot
.36012 .34017 Mdot
.66773 .37341 Mdot
.60797 .77663 Mdot
.5156 .66093 Mdot
.68141 .51577 Mdot
.5338 .65861 Mdot
.52598 .65027 Mdot
.72074 .57263 Mdot
.54225 .67587 Mdot
.36568 .50774 Mdot
.54233 .78938 Mdot
.51361 .65281 Mdot
.68926 .55979 Mdot
.54192 .24632 Mdot
.50265 .6743 Mdot
.56307 .35418 Mdot
.39256 .47894 Mdot
.68216 .37663 Mdot
.55446 .21536 Mdot
.54066 .64613 Mdot
.53857 .26962 Mdot
.65846 .3783 Mdot
.56356 .29668 Mdot
.67803 .61813 Mdot
.62783 .57405 Mdot
.2419 .48417 Mdot
.74585 .52433 Mdot
.54342 .70761 Mdot
.63066 .4219 Mdot
.37197 .50988 Mdot
.37708 .4606 Mdot
.52199 .27513 Mdot
.52971 .72402 Mdot
.73183 .70524 Mdot
.45873 .55105 Mdot
.69889 .72971 Mdot
.69161 .58251 Mdot
.55382 .34546 Mdot
.4481 .41041 Mdot
.73893 .55485 Mdot
.41711 .50756 Mdot
.51513 .57866 Mdot
.36565 .48 Mdot
.40878 .29704 Mdot
.57157 .27804 Mdot
.74257 .41951 Mdot
.35484 .53725 Mdot
.65274 .40609 Mdot
.36547 .49736 Mdot
.57666 .53001 Mdot
.36174 .5434 Mdot
.54752 .29828 Mdot
.65732 .55716 Mdot
.50282 .68369 Mdot
.55751 .24723 Mdot
.63519 .35926 Mdot
.24424 .39008 Mdot
.34719 .51391 Mdot
.38826 .45347 Mdot
.63141 .40413 Mdot
.52138 .71088 Mdot
.63259 .38215 Mdot
.68856 .52806 Mdot
.54257 .26535 Mdot
.36121 .5302 Mdot
.29266 .48484 Mdot
.6536 .33763 Mdot
.71329 .57361 Mdot
.61522 .38329 Mdot
.70014 .59095 Mdot
.51057 .57403 Mdot
.36683 .54716 Mdot
.61312 .37888 Mdot
.41672 .50346 Mdot
.4018 .65246 Mdot
.30543 .36646 Mdot
.29133 .57158 Mdot
.62453 .392 Mdot
.5875 .18706 Mdot
.69541 .56408 Mdot
.67479 .54497 Mdot
.47348 .78081 Mdot
.49507 .85371 Mdot
.50946 .48629 Mdot
.76087 .68071 Mdot
.68817 .52795 Mdot
.67975 .55975 Mdot
.63047 .38616 Mdot
.53335 .71019 Mdot
.55727 .65803 Mdot
.6159 .39307 Mdot
.32155 .32665 Mdot
.51979 .66907 Mdot
.38955 .78904 Mdot
.67721 .39219 Mdot
.3727 .43979 Mdot
.48189 .74138 Mdot
.54941 .29852 Mdot
.38591 .30724 Mdot
.66371 .49202 Mdot
.36547 .48794 Mdot
.82231 .42396 Mdot
.6409 .39759 Mdot
.47097 .54716 Mdot
.65311 .54172 Mdot
.34252 .52577 Mdot
.37065 .49471 Mdot
.35856 .50638 Mdot
.55326 .30313 Mdot
.3698 .6173 Mdot
.36204 .4892 Mdot
.28806 .36182 Mdot
.31897 .46305 Mdot
.70507 .44579 Mdot
.54703 .25987 Mdot
.43868 .25033 Mdot
.60577 .39005 Mdot
.72905 .6965 Mdot
.31758 .48126 Mdot
.67322 .54041 Mdot
.56837 .50524 Mdot
.71064 .56044 Mdot
.74522 .58335 Mdot
.32194 .25594 Mdot
.53756 .71956 Mdot
.35401 .53553 Mdot
.66793 .40774 Mdot
.54922 .64521 Mdot
.56471 .49945 Mdot
.8243 .65995 Mdot
.67179 .51906 Mdot
.6801 .82972 Mdot
.68415 .53801 Mdot
.51509 .55149 Mdot
.52468 .70097 Mdot
.37694 .58424 Mdot
.40955 .35917 Mdot
.52284 .70881 Mdot
.66136 .25732 Mdot
.4865 .66703 Mdot
.28663 .31485 Mdot
.53138 .61555 Mdot
.69143 .55534 Mdot
.68801 .51747 Mdot
.41635 .45072 Mdot
.35368 .51205 Mdot
.41403 .35046 Mdot
.37593 .56786 Mdot
.38332 .50377 Mdot
.6457 .3693 Mdot
.74372 .52081 Mdot
.65781 .61595 Mdot
.54126 .68149 Mdot
.71652 .56822 Mdot
.36762 .49602 Mdot
.40292 .50213 Mdot
.32754 .47365 Mdot
.49412 .3012 Mdot
.38065 .78629 Mdot
.34893 .47177 Mdot
.35127 .5443 Mdot
.63587 .35577 Mdot
.712 .42099 Mdot
.79499 .65661 Mdot
.33232 .2439 Mdot
.3549 .44988 Mdot
.55428 .257 Mdot
.5239 .25438 Mdot
.43056 .48686 Mdot
.39626 .58199 Mdot
.58383 .31091 Mdot
.37421 .47153 Mdot
.26034 .3773 Mdot
.67642 .35146 Mdot
.50036 .56861 Mdot
.65876 .3744 Mdot
.56038 .65724 Mdot
.50399 .56863 Mdot
.6379 .36581 Mdot
.29967 .35149 Mdot
.5163 .58611 Mdot
.76355 .55578 Mdot
.54448 .2432 Mdot
.33813 .4864 Mdot
.45292 .73068 Mdot
.6735 .37982 Mdot
.67581 .55746 Mdot
.52307 .69422 Mdot
.68763 .58059 Mdot
.69729 .4742 Mdot
.33891 .31659 Mdot
.51303 .55815 Mdot
.67253 .54134 Mdot
.50791 .47257 Mdot
.5509 .25555 Mdot
.69039 .53593 Mdot
.45352 .53246 Mdot
.31299 .50041 Mdot
.40854 .82951 Mdot
.39205 .46027 Mdot
.75538 .5898 Mdot
.67246 .55127 Mdot
.50447 .57937 Mdot
.36708 .46803 Mdot
.67572 .40384 Mdot
.32139 .41127 Mdot
.36066 .47425 Mdot
.6722 .36784 Mdot
.35285 .46107 Mdot
.52808 .26689 Mdot
.5042 .7205 Mdot
.39349 .34647 Mdot
.49398 .33571 Mdot
.57024 .27699 Mdot
.3297 .36879 Mdot
.33698 .5003 Mdot
.62211 .22964 Mdot
.52437 .6739 Mdot
.32267 .50575 Mdot
.36427 .28723 Mdot
.5407 .7029 Mdot
.51489 .6854 Mdot
.40214 .47116 Mdot
.66558 .56236 Mdot
.62954 .39877 Mdot
.54942 .25648 Mdot
.72646 .58073 Mdot
.35994 .48604 Mdot
.40109 .52172 Mdot
.5702 .27198 Mdot
.67652 .55193 Mdot
.35835 .52838 Mdot
.6404 .72 Mdot
.3339 .34582 Mdot
.71203 .5834 Mdot
.3148 .50443 Mdot
.41597 .80283 Mdot
.53965 .65624 Mdot
.82145 .42013 Mdot
.51435 .22827 Mdot
.62266 .37185 Mdot
.2985 .45915 Mdot
.89621 .5382 Mdot
.53956 .24587 Mdot
.69446 .7269 Mdot
.36196 .45575 Mdot
.35258 .49116 Mdot
.54795 .70549 Mdot
.36829 .52431 Mdot
.54267 .6709 Mdot
.53461 .34387 Mdot
.51599 .85151 Mdot
.52361 .65494 Mdot
.53244 .66574 Mdot
.42075 .55873 Mdot
.50474 .25765 Mdot
.53683 .70048 Mdot
.35075 .5148 Mdot
.65178 .23481 Mdot
.42712 .53499 Mdot
.56567 .24662 Mdot
.58421 .30066 Mdot
.50499 .70074 Mdot
.40995 .73505 Mdot
.42636 .55338 Mdot
.38431 .76973 Mdot
.5873 .30764 Mdot
.70829 .53898 Mdot
.41033 .50241 Mdot
.53018 .57705 Mdot
.65251 .38834 Mdot
.33888 .42394 Mdot
.33933 .49468 Mdot
.52077 .71565 Mdot
.5681 .30058 Mdot
.69321 .53317 Mdot
.41458 .4853 Mdot
.67804 .34738 Mdot
.56746 .27493 Mdot
.50935 .65232 Mdot
.43866 .7585 Mdot
.51538 .25125 Mdot
.29289 .47021 Mdot
.36687 .45179 Mdot
.40432 .45622 Mdot
.31758 .54571 Mdot
.68977 .57017 Mdot
.62305 .40781 Mdot
.29385 .4673 Mdot
.42739 .39806 Mdot
.33403 .33734 Mdot
.33502 .46002 Mdot
.50265 .67653 Mdot
.70252 .57881 Mdot
.52229 .56579 Mdot
.35429 .21895 Mdot
.37329 .44761 Mdot
.39005 .7899 Mdot
.47255 .2782 Mdot
.52251 .58405 Mdot
.54151 .6384 Mdot
.55174 .26203 Mdot
.40538 .46702 Mdot
.28628 .35991 Mdot
.38217 .5073 Mdot
.40206 .5439 Mdot
.62172 .38307 Mdot
.70486 .54035 Mdot
.24421 .47672 Mdot
.64838 .38896 Mdot
.51592 .68639 Mdot
.34531 .75976 Mdot
.55067 .65258 Mdot
.53248 .64087 Mdot
.4736 .65849 Mdot
.67347 .56728 Mdot
.89981 .5311 Mdot
.50495 .20267 Mdot
.3332 .46898 Mdot
.67879 .5289 Mdot
.53435 .69758 Mdot
.35108 .51906 Mdot
.54291 .67312 Mdot
.50448 .70391 Mdot
.395 .48391 Mdot
.39402 .49089 Mdot
.27681 .36142 Mdot
.4104 .79217 Mdot
.53619 .25578 Mdot
.55299 .67469 Mdot
.41012 .77476 Mdot
.35617 .48903 Mdot
.34651 .50704 Mdot
.57053 .50764 Mdot
.55976 .24744 Mdot
.24413 .63959 Mdot
.37223 .45781 Mdot
.41629 .28484 Mdot
.33898 .50719 Mdot
.56813 .67956 Mdot
.71883 .5336 Mdot
.45155 .51862 Mdot
.61659 .37959 Mdot
.55289 .6705 Mdot
.56337 .30235 Mdot
.53876 .63235 Mdot
.27681 .66604 Mdot
.69099 .57587 Mdot
.52806 .66352 Mdot
.62708 .41502 Mdot
.68125 .54996 Mdot
.67221 .57027 Mdot
.56346 .49659 Mdot
.64352 .42236 Mdot
.57087 .29969 Mdot
.70194 .5484 Mdot
.32443 .71416 Mdot
.68923 .55294 Mdot
.27143 .66787 Mdot
.36376 .4441 Mdot
.28954 .36097 Mdot
.33476 .42297 Mdot
.42189 .4578 Mdot
.6928 .54426 Mdot
.56881 .27583 Mdot
.35333 .52637 Mdot
.52345 .6509 Mdot
.54573 .24867 Mdot
.45778 .68564 Mdot
.64176 .42457 Mdot
.49312 .69717 Mdot
.69047 .59328 Mdot
.55103 .69094 Mdot
.37652 .30385 Mdot
.58328 .29335 Mdot
.58033 .49489 Mdot
.39966 .36205 Mdot
.29512 .51461 Mdot
.34777 .53858 Mdot
.34929 .52544 Mdot
.36925 .50542 Mdot
.66288 .36895 Mdot
.53828 .29581 Mdot
.50231 .66788 Mdot
.23364 .53785 Mdot
.67286 .5583 Mdot
.52647 .47549 Mdot
.3155 .54345 Mdot
.40402 .51462 Mdot
.53277 .69558 Mdot
.499 .69391 Mdot
.3934 .61579 Mdot
.64444 .4054 Mdot
.43558 .51002 Mdot
.32004 .4845 Mdot
.2508 .45814 Mdot
.68964 .54358 Mdot
.69742 .6867 Mdot
.67978 .36071 Mdot
.69054 .82601 Mdot
.64811 .38726 Mdot
.56262 .44241 Mdot
.54537 .67956 Mdot
.54949 .27678 Mdot
.3877 .48539 Mdot
.46761 .59115 Mdot
.51491 .63465 Mdot
.70397 .4085 Mdot
.55295 .26923 Mdot
.7347 .61889 Mdot
.68796 .52537 Mdot
.41518 .48744 Mdot
.33939 .50807 Mdot
.39098 .51754 Mdot
.36639 .51925 Mdot
.71488 .54597 Mdot
.38994 .50303 Mdot
.71369 .59014 Mdot
.27276 .65734 Mdot
.3582 .28713 Mdot
.64457 .41626 Mdot
.72829 .40123 Mdot
.52996 .64119 Mdot
.27253 .69461 Mdot
.25463 .64154 Mdot
.30615 .36558 Mdot
.72122 .60167 Mdot
.40904 .52731 Mdot
.62809 .38923 Mdot
.63866 .60103 Mdot
.64881 .41673 Mdot
.28627 .76457 Mdot
.43489 .72655 Mdot
.75154 .60673 Mdot
.38592 .51763 Mdot
.62091 .39643 Mdot
.41133 .74879 Mdot
.30066 .44373 Mdot
.51617 .24672 Mdot
.29187 .68562 Mdot
.45566 .64336 Mdot
.53295 .25737 Mdot
.38999 .47039 Mdot
.49508 .64617 Mdot
.38568 .48958 Mdot
.38952 .48153 Mdot
.35026 .45632 Mdot
.72242 .55579 Mdot
.35629 .44534 Mdot
.35898 .51043 Mdot
.37254 .18372 Mdot
.67744 .32868 Mdot
.66018 .35588 Mdot
.32221 .58063 Mdot
.54451 .25177 Mdot
.56049 .65695 Mdot
.39537 .35157 Mdot
.66939 .5533 Mdot
.38898 .61485 Mdot
.40135 .48375 Mdot
.65135 .75724 Mdot
.67389 .57776 Mdot
.55509 .29402 Mdot
.52877 .57883 Mdot
.72288 .64212 Mdot
.62901 .35277 Mdot
.52689 .56283 Mdot
.66992 .37762 Mdot
.22522 .49844 Mdot
.53822 .66768 Mdot
.29498 .51417 Mdot
.69722 .5367 Mdot
.65326 .41862 Mdot
.28501 .36563 Mdot
.34978 .50253 Mdot
.62356 .39112 Mdot
.30777 .44007 Mdot
.36422 .33751 Mdot
.39941 .34869 Mdot
.63254 .41545 Mdot
.65996 .56263 Mdot
.68547 .54548 Mdot
.53378 .25081 Mdot
.53728 .65623 Mdot
.52213 .71303 Mdot
.68992 .54929 Mdot
.82172 .52667 Mdot
.36184 .48568 Mdot
.34636 .47914 Mdot
.43797 .40484 Mdot
.33684 .51246 Mdot
.5733 .24748 Mdot
.52034 .55235 Mdot
.51233 .70545 Mdot
.35045 .52533 Mdot
.35962 .52854 Mdot
.37556 .45118 Mdot
.312 .32894 Mdot
.66171 .37553 Mdot
.39483 .45687 Mdot
.54281 .28631 Mdot
.45589 .67157 Mdot
.36853 .51099 Mdot
.29235 .46868 Mdot
.54569 .67428 Mdot
.63786 .46309 Mdot
.67582 .55936 Mdot
.66751 .40299 Mdot
.66743 .40664 Mdot
.37865 .25102 Mdot
.55629 .66803 Mdot
.52442 .55809 Mdot
.67836 .465 Mdot
.52353 .56474 Mdot
.55432 .27208 Mdot
.53112 .49019 Mdot
.61802 .42104 Mdot
.66204 .35738 Mdot
.69627 .51493 Mdot
.33028 .51874 Mdot
.36408 .51295 Mdot
.72324 .70598 Mdot
.34349 .46874 Mdot
.53504 .26176 Mdot
.66727 .54089 Mdot
.52948 .66617 Mdot
.52637 .26908 Mdot
.67767 .54014 Mdot
.5207 .70894 Mdot
.32741 .45262 Mdot
.34496 .51375 Mdot
.51872 .69204 Mdot
.5132 .64899 Mdot
.37518 .4811 Mdot
.30033 .27278 Mdot
.50574 .69585 Mdot
.52294 .697 Mdot
.45568 .66128 Mdot
.63618 .35068 Mdot
.31705 .41249 Mdot
.66827 .54831 Mdot
.35807 .50943 Mdot
.64159 .41409 Mdot
.56115 .27498 Mdot
.50798 .66955 Mdot
.41166 .50369 Mdot
.35537 .48213 Mdot
.55408 .25782 Mdot
.53728 .24005 Mdot
.55517 .24731 Mdot
.69281 .51977 Mdot
.39795 .48767 Mdot
.53107 .70259 Mdot
.69703 .52539 Mdot
.52274 .27164 Mdot
.55442 .24114 Mdot
.25978 .33806 Mdot
.36774 .48582 Mdot
.5231 .24836 Mdot
.8385 .63412 Mdot
.26174 .36188 Mdot
.50164 .5595 Mdot
.6877 .39739 Mdot
.58934 .18432 Mdot
.55448 .21396 Mdot
.70956 .54542 Mdot
.52824 .47177 Mdot
.57433 .27884 Mdot
.4116 .47448 Mdot
.34369 .49175 Mdot
.30644 .52917 Mdot
.54873 .24941 Mdot
.33909 .31531 Mdot
.5412 .71808 Mdot
.28351 .61114 Mdot
.54423 .25192 Mdot
.64854 .42083 Mdot
.65977 .33763 Mdot
.63999 .38801 Mdot
.37266 .54634 Mdot
.2211 .50213 Mdot
.31955 .69399 Mdot
.24003 .63011 Mdot
.68391 .52734 Mdot
.50102 .69875 Mdot
.46811 .72185 Mdot
.51393 .68419 Mdot
.65912 .39222 Mdot
.568 .27873 Mdot
.54412 .712 Mdot
.67562 .57303 Mdot
.68852 .54507 Mdot
.61633 .36646 Mdot
.6554 .37852 Mdot
.6396 .37803 Mdot
.54835 .66471 Mdot
.54409 .67765 Mdot
.3758 .52607 Mdot
.50944 .65964 Mdot
.48891 .27277 Mdot
.5144 .32756 Mdot
.62763 .34577 Mdot
.68955 .56576 Mdot
.50939 .68829 Mdot
.33732 .48427 Mdot
.5152 .43638 Mdot
.60257 .37964 Mdot
.5438 .29467 Mdot
.56061 .79593 Mdot
.48868 .86199 Mdot
.3617 .53563 Mdot
.71469 .56624 Mdot
.44617 .55621 Mdot
.36856 .50346 Mdot
.61934 .37783 Mdot
.46868 .25136 Mdot
.51963 .58935 Mdot
.38269 .49972 Mdot
.32954 .45328 Mdot
.69099 .5783 Mdot
.39438 .35374 Mdot
.41347 .48332 Mdot
.55385 .47535 Mdot
.65867 .55604 Mdot
.67649 .3564 Mdot
.51787 .14259 Mdot
.47511 .57693 Mdot
.42588 .30341 Mdot
.5039 .57289 Mdot
.36922 .44636 Mdot
.64872 .36771 Mdot
.53564 .28409 Mdot
.64919 .37327 Mdot
.5627 .65604 Mdot
.62936 .35366 Mdot
.34146 .46797 Mdot
.53407 .70344 Mdot
.67599 .54893 Mdot
.48223 .42645 Mdot
.24681 .53093 Mdot
.67875 .39731 Mdot
.50353 .54785 Mdot
.39344 .49092 Mdot
.31999 .71578 Mdot
.42057 .45471 Mdot
.34733 .50988 Mdot
.70946 .56147 Mdot
.53883 .68821 Mdot
.69432 .58203 Mdot
.3289 .40966 Mdot
.57455 .7235 Mdot
.67653 .56381 Mdot
.46253 .52468 Mdot
.57124 .28226 Mdot
.33065 .32161 Mdot
.37158 .46525 Mdot
.69798 .5359 Mdot
.39504 .47168 Mdot
.55455 .67881 Mdot
.31465 .34757 Mdot
.32702 .35363 Mdot
.70338 .55871 Mdot
.57925 .55564 Mdot
.38744 .33353 Mdot
.3158 .41306 Mdot
.69473 .52895 Mdot
.21483 .41386 Mdot
.52358 .57756 Mdot
.56609 .27699 Mdot
.54208 .23748 Mdot
.54951 .28408 Mdot
.34384 .48078 Mdot
.42546 .78605 Mdot
.53304 .24813 Mdot
.66304 .53464 Mdot
.53152 .26959 Mdot
.48084 .319 Mdot
.72159 .71396 Mdot
.57065 .28114 Mdot
.3633 .46355 Mdot
.43427 .45989 Mdot
.52355 .4717 Mdot
.67376 .41263 Mdot
.67059 .63977 Mdot
.38262 .17726 Mdot
.35863 .49098 Mdot
.52533 .78017 Mdot
.56809 .71433 Mdot
.55884 .42106 Mdot
.3188 .35973 Mdot
.48868 .45722 Mdot
.51474 .69389 Mdot
.39712 .35775 Mdot
.50633 .64538 Mdot
.2941 .51519 Mdot
.35015 .47285 Mdot
.55359 .6708 Mdot
.59967 .77819 Mdot
.20624 .40831 Mdot
.68417 .74223 Mdot
.51126 .69793 Mdot
.68549 .53019 Mdot
.71204 .56428 Mdot
.70912 .55881 Mdot
.65682 .36338 Mdot
.52874 .66136 Mdot
.38736 .44968 Mdot
.63001 .36236 Mdot
.3855 .47009 Mdot
.69791 .55494 Mdot
.31173 .36128 Mdot
.53241 .66672 Mdot
.37501 .4709 Mdot
.41019 .76172 Mdot
.66968 .38311 Mdot
.55171 .25456 Mdot
.55224 .79296 Mdot
.66567 .42759 Mdot
.67576 .5815 Mdot
.56392 .65517 Mdot
.69148 .34983 Mdot
.54996 .45593 Mdot
.3393 .45757 Mdot
.32883 .4825 Mdot
.53049 .46809 Mdot
.4375 .73997 Mdot
.41399 .50952 Mdot
.63654 .35874 Mdot
.64841 .35055 Mdot
.39247 .46686 Mdot
.52494 .65824 Mdot
.57653 .27799 Mdot
.51581 .25969 Mdot
.37067 .55294 Mdot
.40597 .35459 Mdot
.28863 .36191 Mdot
.35452 .52356 Mdot
.30085 .50504 Mdot
.62892 .41693 Mdot
.50044 .56136 Mdot
.40827 .36472 Mdot
.5429 .27644 Mdot
.36812 .45461 Mdot
.29186 .57826 Mdot
.51572 .6623 Mdot
.62537 .39406 Mdot
.71585 .53821 Mdot
.51544 .24968 Mdot
.63088 .34555 Mdot
.39238 .46674 Mdot
.3588 .52834 Mdot
.69325 .53615 Mdot
.56747 .67892 Mdot
.56254 .25905 Mdot
.63097 .36066 Mdot
.5464 .27598 Mdot
.54022 .67408 Mdot
.50569 .67406 Mdot
.32608 .47311 Mdot
.43219 .47776 Mdot
.67823 .39345 Mdot
.39914 .5417 Mdot
.62872 .37512 Mdot
.70961 .42496 Mdot
.71857 .56945 Mdot
.32222 .50284 Mdot
.56073 .6722 Mdot
.6954 .55168 Mdot
.36213 .4932 Mdot
.53664 .46654 Mdot
.37439 .53041 Mdot
.62217 .40142 Mdot
.47241 .22712 Mdot
.55899 .28298 Mdot
.35628 .43012 Mdot
.44379 .62017 Mdot
.34152 .51627 Mdot
.67408 .36194 Mdot
.31623 .70176 Mdot
.6814 .56908 Mdot
.54671 .6894 Mdot
.62439 .43835 Mdot
.68893 .55736 Mdot
.3619 .46015 Mdot
.5397 .26382 Mdot
.50157 .66226 Mdot
.50599 .56294 Mdot
.42727 .35957 Mdot
.39545 .4232 Mdot
.42719 .52656 Mdot
.41522 .50089 Mdot
.7579 .68659 Mdot
.64257 .37654 Mdot
.53249 .69722 Mdot
.7151 .56159 Mdot
.68706 .57462 Mdot
.66693 .38379 Mdot
.45867 .63329 Mdot
.63315 .77988 Mdot
.85877 .60448 Mdot
.63412 .3428 Mdot
.54028 .27913 Mdot
.31474 .3488 Mdot
.63889 .38914 Mdot
.66719 .36955 Mdot
.62083 .415 Mdot
.72956 .70044 Mdot
.51677 .70193 Mdot
.35448 .48282 Mdot
.50693 .76783 Mdot
.35057 .45698 Mdot
.42656 .31182 Mdot
.69757 .55594 Mdot
.54696 .68941 Mdot
.54483 .35703 Mdot
.35801 .54262 Mdot
.3761 .49506 Mdot
.57022 .35484 Mdot
.42121 .5644 Mdot
.35205 .22605 Mdot
.32505 .49228 Mdot
.6559 .37048 Mdot
.51167 .7419 Mdot
.29299 .47249 Mdot
.41096 .76366 Mdot
.68358 .54294 Mdot
.51272 .55685 Mdot
.28995 .4937 Mdot
.3141 .53378 Mdot
.50814 .6437 Mdot
.54145 .71506 Mdot
.54356 .2403 Mdot
.55313 .78007 Mdot
.68091 .54347 Mdot
.71758 .67819 Mdot
.34642 .51005 Mdot
.74643 .57856 Mdot
.47681 .239 Mdot
.3681 .492 Mdot
.56082 .4938 Mdot
.3939 .6156 Mdot
.40806 .51573 Mdot
.24281 .62172 Mdot
.69321 .56253 Mdot
.38019 .28875 Mdot
.38557 .51061 Mdot
.62396 .38939 Mdot
.53685 .70953 Mdot
.49212 .69454 Mdot
.53128 .28063 Mdot
.49677 .23612 Mdot
.56736 .85053 Mdot
.5475 .69037 Mdot
.3499 .50403 Mdot
.67909 .56232 Mdot
.50821 .5573 Mdot
.34712 .42177 Mdot
.58333 .54354 Mdot
.51479 .66422 Mdot
.29895 .45007 Mdot
.64724 .76109 Mdot
.39612 .35546 Mdot
.29033 .72087 Mdot
.70679 .55542 Mdot
.53562 .27016 Mdot
.39588 .55548 Mdot
.69024 .4525 Mdot
.3426 .51241 Mdot
.42603 .30911 Mdot
.53691 .73307 Mdot
.53402 .26406 Mdot
.37933 .49565 Mdot
.4121 .517 Mdot
.3455 .36912 Mdot
.56465 .24397 Mdot
.41437 .49687 Mdot
.36058 .53681 Mdot
.53967 .71147 Mdot
.51858 .55109 Mdot
.52668 .6663 Mdot
.3854 .4876 Mdot
.4591 .20889 Mdot
.55228 .67834 Mdot
.65951 .62979 Mdot
.51436 .27015 Mdot
.66959 .55095 Mdot
.30811 .44638 Mdot
.34864 .45156 Mdot
.29082 .7299 Mdot
.50875 .5537 Mdot
.79342 .58611 Mdot
.62479 .40154 Mdot
.32604 .21971 Mdot
.66113 .43076 Mdot
.70918 .61242 Mdot
.63236 .5038 Mdot
.29405 .48131 Mdot
.45711 .62817 Mdot
.23353 .62838 Mdot
.66759 .58494 Mdot
.26199 .68523 Mdot
.3539 .51208 Mdot
.37123 .45253 Mdot
.62605 .37829 Mdot
.7366 .59497 Mdot
.45162 .51752 Mdot
.4083 .36369 Mdot
.55883 .29371 Mdot
.52197 .68068 Mdot
.34119 .48858 Mdot
.58843 .77866 Mdot
.66034 .41835 Mdot
.2717 .55597 Mdot
.37168 .4686 Mdot
.44197 .55743 Mdot
.72486 .60135 Mdot
.67484 .54976 Mdot
.62989 .4146 Mdot
.64963 .42228 Mdot
.36298 .44868 Mdot
.7146 .54094 Mdot
.3909 .52116 Mdot
.3812 .33242 Mdot
.30351 .44794 Mdot
.5573 .272 Mdot
.33755 .49669 Mdot
.42786 .58612 Mdot
.15813 .539 Mdot
.34924 .53757 Mdot
.53664 .64323 Mdot
.63585 .37687 Mdot
.66251 .38147 Mdot
.51945 .71146 Mdot
.66284 .38241 Mdot
.28602 .61459 Mdot
.4263 .79028 Mdot
.55236 .2736 Mdot
.28108 .64667 Mdot
.56118 .28777 Mdot
.51398 .55723 Mdot
.37039 .48451 Mdot
.76187 .37727 Mdot
.64043 .34177 Mdot
.47182 .30728 Mdot
.69134 .55158 Mdot
.50977 .55205 Mdot
.39484 .49252 Mdot
.58964 .28575 Mdot
.64615 .39466 Mdot
.47899 .5451 Mdot
.35453 .45509 Mdot
.5504 .66882 Mdot
.40694 .51289 Mdot
.39811 .56894 Mdot
.51974 .55311 Mdot
.39895 .53068 Mdot
.67758 .5402 Mdot
.54107 .66637 Mdot
.75563 .60903 Mdot
.67261 .37599 Mdot
.38785 .49629 Mdot
.35348 .50517 Mdot
.49798 .66694 Mdot
.33347 .46997 Mdot
.70943 .53385 Mdot
.90884 .46838 Mdot
.56203 .25322 Mdot
.50043 .56488 Mdot
.63614 .65684 Mdot
.40101 .52997 Mdot
.35216 .52991 Mdot
.48878 .48678 Mdot
.28029 .57374 Mdot
.67192 .54661 Mdot
.42585 .52073 Mdot
.65083 .35292 Mdot
.56551 .26402 Mdot
.67904 .57724 Mdot
.39594 .49727 Mdot
.35094 .46255 Mdot
.53514 .26475 Mdot
.56144 .36036 Mdot
.54386 .23318 Mdot
.71093 .54343 Mdot
.55713 .61362 Mdot
.51687 .43583 Mdot
.36357 .47962 Mdot
.50387 .54324 Mdot
.53508 .68905 Mdot
.69907 .52938 Mdot
.3675 .61996 Mdot
.2951 .51751 Mdot
.69752 .59409 Mdot
.67695 .54738 Mdot
.34119 .45673 Mdot
.55542 .6681 Mdot
.56876 .66245 Mdot
.53379 .69238 Mdot
.36198 .27832 Mdot
.78435 .58712 Mdot
.63939 .37441 Mdot
.68827 .56358 Mdot
.64379 .41292 Mdot
.57337 .27558 Mdot
.3442 .33476 Mdot
.6662 .4166 Mdot
.55725 .70154 Mdot
.65276 .41517 Mdot
.38643 .52366 Mdot
.66652 .56096 Mdot
.67784 .38795 Mdot
.35774 .52036 Mdot
.35074 .55132 Mdot
.34419 .5609 Mdot
.57421 .29393 Mdot
.40074 .35359 Mdot
.37028 .46168 Mdot
.52832 .57794 Mdot
.37459 .4761 Mdot
.71164 .53621 Mdot
.47777 .41286 Mdot
.3946 .46103 Mdot
.64058 .34154 Mdot
.79258 .60777 Mdot
.65388 .34876 Mdot
.29774 .55468 Mdot
.38453 .47651 Mdot
.3643 .48245 Mdot
.39497 .48812 Mdot
.45317 .66114 Mdot
.68818 .58949 Mdot
.41957 .52685 Mdot
.61539 .38494 Mdot
.51169 .68306 Mdot
.55509 .69265 Mdot
.50011 .49119 Mdot
.52848 .5659 Mdot
.70491 .5278 Mdot
.36303 .48385 Mdot
.47972 .54438 Mdot
.43482 .38953 Mdot
.66085 .7599 Mdot
.68824 .40285 Mdot
.67035 .362 Mdot
.52833 .64847 Mdot
.6572 .35884 Mdot
.3939 .49885 Mdot
.29758 .45441 Mdot
.75404 .6114 Mdot
.66199 .51968 Mdot
.56567 .26591 Mdot
.38674 .47472 Mdot
.29477 .33651 Mdot
.63573 .35586 Mdot
.63406 .41939 Mdot
.39178 .51999 Mdot
.55919 .72921 Mdot
.16353 .47608 Mdot
.67808 .529 Mdot
.33952 .73147 Mdot
.47249 .76987 Mdot
.26676 .42325 Mdot
.68968 .57234 Mdot
.55717 .48871 Mdot
.67895 .40478 Mdot
.46027 .19117 Mdot
.51299 .68772 Mdot
.56328 .26112 Mdot
.35264 .51711 Mdot
.55655 .7041 Mdot
.62218 .34753 Mdot
.49979 .67158 Mdot
.29152 .49969 Mdot
.67153 .57445 Mdot
.65557 .38582 Mdot
.6923 .51668 Mdot
.55249 .64756 Mdot
.56051 .28642 Mdot
.41488 .28947 Mdot
.313 .7083 Mdot
.40018 .61658 Mdot
.39582 .45727 Mdot
.65582 .31757 Mdot
.38988 .45029 Mdot
.50819 .72112 Mdot
.37056 .46478 Mdot
.32111 .52371 Mdot
.668 .42029 Mdot
.33443 .46055 Mdot
.34182 .50433 Mdot
.40991 .76665 Mdot
.37234 .4925 Mdot
.38777 .46161 Mdot
.32763 .46759 Mdot
.55818 .67937 Mdot
.33044 .46801 Mdot
.5377 .65836 Mdot
.67764 .73971 Mdot
.672 .37798 Mdot
.57279 .2714 Mdot
.57217 .27594 Mdot
.43427 .30605 Mdot
.30013 .33408 Mdot
.4851 .74656 Mdot
.51615 .67001 Mdot
.69175 .54441 Mdot
.38365 .52394 Mdot
.21703 .38 Mdot
.4515 .21714 Mdot
.68456 .37629 Mdot
.67301 .40315 Mdot
.36765 .51504 Mdot
.47231 .86221 Mdot
.32726 .49513 Mdot
.44386 .40719 Mdot
.34402 .47954 Mdot
.32372 .50514 Mdot
.62083 .41087 Mdot
.37883 .3044 Mdot
.39448 .4566 Mdot
.50919 .64235 Mdot
.56358 .26442 Mdot
.43606 .55981 Mdot
.44552 .24024 Mdot
.45887 .77333 Mdot
.45727 .5736 Mdot
.39771 .47173 Mdot
.62492 .36637 Mdot
.5049 .68779 Mdot
.43081 .39645 Mdot
.69881 .52679 Mdot
.4204 .34872 Mdot
.26645 .66082 Mdot
.66888 .58937 Mdot
.56705 .27252 Mdot
.61645 .34872 Mdot
.35621 .45031 Mdot
.64772 .36437 Mdot
.41265 .5312 Mdot
.44117 .39193 Mdot
.55517 .27482 Mdot
.48569 .67977 Mdot
.68377 .53131 Mdot
.55217 .71053 Mdot
.29242 .57205 Mdot
.45324 .21377 Mdot
.33302 .20937 Mdot
.63952 .34508 Mdot
.24543 .56777 Mdot
.54197 .69436 Mdot
.37058 .44712 Mdot
.85712 .60556 Mdot
.53486 .68293 Mdot
.55171 .67019 Mdot
.45298 .38986 Mdot
.36182 .29861 Mdot
.40452 .53745 Mdot
.50457 .6951 Mdot
.61721 .34828 Mdot
.55048 .26526 Mdot
.36459 .5214 Mdot
.29039 .49125 Mdot
.54542 .70977 Mdot
.65301 .39458 Mdot
.39749 .3117 Mdot
.65639 .37411 Mdot
.52287 .70505 Mdot
.66722 .39829 Mdot
.6793 .62401 Mdot
.66871 .41404 Mdot
.33487 .47733 Mdot
.36283 .48298 Mdot
.50369 .59828 Mdot
.50569 .67401 Mdot
.35198 .52941 Mdot
.3587 .45675 Mdot
.53513 .70016 Mdot
.60663 .40978 Mdot
.3091 .58888 Mdot
.35174 .53208 Mdot
.35853 .48474 Mdot
.56224 .25139 Mdot
.37692 .34834 Mdot
.46217 .43058 Mdot
.35417 .52093 Mdot
.54779 .28458 Mdot
.54642 .66311 Mdot
.37598 .47824 Mdot
.38167 .30384 Mdot
.6763 .34995 Mdot
.39629 .50776 Mdot
.50848 .56223 Mdot
.3871 .44673 Mdot
.18408 .51231 Mdot
.39155 .49462 Mdot
.52143 .70003 Mdot
.53887 .70537 Mdot
.61927 .43162 Mdot
.51854 .68843 Mdot
.50184 .56071 Mdot
.68617 .54631 Mdot
.31257 .72623 Mdot
.50348 .55465 Mdot
.3998 .52699 Mdot
.50795 .20246 Mdot
.29057 .48295 Mdot
.30314 .43776 Mdot
.50481 .24676 Mdot
.50478 .57343 Mdot
.54154 .68483 Mdot
.59771 .76577 Mdot
.42279 .47389 Mdot
.7016 .52598 Mdot
.29221 .47595 Mdot
.39717 .50629 Mdot
.31865 .51749 Mdot
.5809 .69704 Mdot
.69003 .52254 Mdot
.32033 .4096 Mdot
.36469 .52156 Mdot
.28325 .57484 Mdot
.3415 .49414 Mdot
.55646 .29835 Mdot
.53247 .66999 Mdot
.65228 .35945 Mdot
.55585 .26839 Mdot
.415 .49579 Mdot
.5446 .25054 Mdot
.64409 .36738 Mdot
.70101 .54328 Mdot
.33611 .47342 Mdot
.5685 .2502 Mdot
.56702 .28686 Mdot
.40695 .48344 Mdot
.54437 .70169 Mdot
.41886 .45207 Mdot
.37604 .48168 Mdot
.39633 .48462 Mdot
.52419 .71381 Mdot
.81016 .38718 Mdot
.37546 .45219 Mdot
.55916 .48923 Mdot
.49989 .71413 Mdot
.51451 .54924 Mdot
.64239 .35742 Mdot
.37773 .5342 Mdot
.67944 .5724 Mdot
.68676 .548 Mdot
.65286 .34088 Mdot
.54085 .71444 Mdot
.65926 .38618 Mdot
.34647 .53749 Mdot
.29417 .46625 Mdot
.35813 .51742 Mdot
.59442 .40332 Mdot
.72004 .6336 Mdot
.50576 .65602 Mdot
.67156 .35894 Mdot
.41377 .35338 Mdot
.66657 .55627 Mdot
.61354 .40221 Mdot
.50052 .64781 Mdot
.52487 .71868 Mdot
.51466 .70569 Mdot
.55024 .29 Mdot
.65161 .38404 Mdot
.55033 .64142 Mdot
.53522 .63062 Mdot
.4023 .50475 Mdot
.36872 .52257 Mdot
.54087 .65749 Mdot
.66656 .45578 Mdot
.56329 .27974 Mdot
.62594 .36104 Mdot
.15732 .49361 Mdot
.68377 .52529 Mdot
.4112 .76623 Mdot
.3504 .51929 Mdot
.71765 .81282 Mdot
.32675 .4945 Mdot
.34581 .50139 Mdot
.56039 .65726 Mdot
.54233 .23598 Mdot
.5475 .26355 Mdot
.5421 .69561 Mdot
.50745 .70784 Mdot
.54187 .29191 Mdot
.48324 .44044 Mdot
.18231 .49122 Mdot
.42696 .38731 Mdot
.50321 .66362 Mdot
.2952 .69961 Mdot
.70438 .5663 Mdot
.52087 .73045 Mdot
.62641 .57654 Mdot
.67304 .38846 Mdot
.67484 .40465 Mdot
.69367 .53939 Mdot
.38049 .45467 Mdot
.61859 .36878 Mdot
.3145 .46919 Mdot
.7412 .61017 Mdot
.57515 .54432 Mdot
.25889 .30527 Mdot
.33585 .46929 Mdot
.42494 .57373 Mdot
.74509 .6976 Mdot
.38765 .52783 Mdot
.41657 .71266 Mdot
.55789 .25367 Mdot
.51766 .72693 Mdot
.66878 .53558 Mdot
.52953 .78196 Mdot
.3637 .48095 Mdot
.50268 .67485 Mdot
.67033 .53772 Mdot
.73484 .62647 Mdot
.55364 .47601 Mdot
.40472 .50973 Mdot
.87991 .56753 Mdot
.51403 .63648 Mdot
.65083 .35949 Mdot
.35347 .71646 Mdot
.54248 .72398 Mdot
.5516 .46116 Mdot
.62033 .34696 Mdot
.39548 .37528 Mdot
.50018 .68521 Mdot
.54019 .23347 Mdot
.52342 .67592 Mdot
.526 .26182 Mdot
.55794 .64895 Mdot
.66567 .39309 Mdot
.38098 .48739 Mdot
.66855 .38647 Mdot
.53809 .29088 Mdot
.63974 .34422 Mdot
.66839 .53612 Mdot
.5081 .57891 Mdot
.69831 .55447 Mdot
.32547 .34198 Mdot
.37515 .63259 Mdot
.705 .54118 Mdot
.48978 .52227 Mdot
.34307 .46675 Mdot
.56832 .68022 Mdot
.65721 .36124 Mdot
.66816 .42295 Mdot
.40248 .35399 Mdot
.52373 .70814 Mdot
.65551 .3965 Mdot
.30382 .70225 Mdot
.81827 .53868 Mdot
.32462 .53003 Mdot
.71472 .47298 Mdot
.52917 .70184 Mdot
.65124 .42757 Mdot
.44073 .40645 Mdot
.53485 .72178 Mdot
.67802 .39184 Mdot
.69391 .52963 Mdot
.67797 .57038 Mdot
.33165 .47753 Mdot
.67286 .52362 Mdot
.67766 .40539 Mdot
.26532 .56597 Mdot
.54831 .68213 Mdot
.70695 .63791 Mdot
.56904 .27037 Mdot
.66167 .36552 Mdot
.39916 .44442 Mdot
.56074 .67618 Mdot
.64982 .41404 Mdot
.54447 .85186 Mdot
.14307 .56516 Mdot
.6534 .39676 Mdot
.53109 .66987 Mdot
.50873 .67132 Mdot
.37377 .54167 Mdot
.4065 .35873 Mdot
.64478 .39597 Mdot
.76018 .37556 Mdot
.28165 .36094 Mdot
.50955 .57308 Mdot
.37664 .18105 Mdot
.39238 .45533 Mdot
.39877 .47543 Mdot
.71128 .54186 Mdot
.37284 .49712 Mdot
.50301 .7002 Mdot
.32657 .4952 Mdot
.69858 .5826 Mdot
.66415 .3452 Mdot
.36899 .48141 Mdot
.56618 .26441 Mdot
.7058 .57717 Mdot
.71152 .57532 Mdot
.66525 .4028 Mdot
.53752 .71461 Mdot
.60617 .79811 Mdot
.65691 .37583 Mdot
.39839 .48714 Mdot
.52342 .58178 Mdot
.33179 .46312 Mdot
.49674 .61785 Mdot
.49864 .7095 Mdot
.65522 .35855 Mdot
.53356 .58267 Mdot
.6838 .56147 Mdot
.67801 .40804 Mdot
.38078 .4446 Mdot
.68015 .37722 Mdot
.57551 .48779 Mdot
.62925 .21704 Mdot
.51479 .63195 Mdot
.56802 .4653 Mdot
.53155 .72059 Mdot
.5066 .56936 Mdot
.36886 .25569 Mdot
.56541 .27804 Mdot
.64362 .35078 Mdot
.66147 .62938 Mdot
.67252 .37273 Mdot
.36857 .49398 Mdot
.3507 .46159 Mdot
.62626 .3761 Mdot
.55601 .28742 Mdot
.49007 .33756 Mdot
.53594 .23045 Mdot
.52671 .6619 Mdot
.50374 .46786 Mdot
.15371 .46952 Mdot
.68584 .35795 Mdot
.68948 .54089 Mdot
.46145 .58203 Mdot
.40609 .52185 Mdot
.678 .52769 Mdot
.71646 .56937 Mdot
.52298 .26855 Mdot
.66803 .3692 Mdot
.48788 .66815 Mdot
.67129 .57183 Mdot
.55357 .71953 Mdot
.39682 .3077 Mdot
.30074 .5276 Mdot
.26465 .43907 Mdot
.41481 .51243 Mdot
.39737 .35394 Mdot
.67416 .57717 Mdot
.3562 .46506 Mdot
.39322 .55156 Mdot
.68799 .52756 Mdot
.5229 .26385 Mdot
.56733 .57387 Mdot
.65459 .39836 Mdot
.81234 .66972 Mdot
.33501 .4807 Mdot
.37971 .48251 Mdot
.68263 .5279 Mdot
.42719 .74177 Mdot
.51658 .64186 Mdot
.54346 .70773 Mdot
.64208 .37716 Mdot
.4583 .40263 Mdot
.33658 .46277 Mdot
.33841 .47165 Mdot
.62159 .38737 Mdot
.52778 .57488 Mdot
.34815 .20285 Mdot
.35544 .48049 Mdot
.6939 .56657 Mdot
.56835 .50489 Mdot
.66006 .56117 Mdot
.31747 .50204 Mdot
.36216 .49566 Mdot
.39798 .45037 Mdot
.37576 .44165 Mdot
.70216 .55747 Mdot
.41476 .50851 Mdot
.42107 .51477 Mdot
.53873 .68648 Mdot
.39288 .46177 Mdot
.2801 .36196 Mdot
.35854 .47881 Mdot
.56065 .25547 Mdot
.46436 .42926 Mdot
.39115 .49222 Mdot
.3941 .46437 Mdot
.28386 .35931 Mdot
.37438 .50153 Mdot
.67133 .53568 Mdot
.50793 .67613 Mdot
.68237 .56194 Mdot
.68484 .53904 Mdot
.65682 .41349 Mdot
.52705 .25006 Mdot
.38868 .54573 Mdot
.54105 .28841 Mdot
.36502 .54333 Mdot
.33121 .40867 Mdot
.36577 .33645 Mdot
.44257 .40539 Mdot
.57387 .28468 Mdot
.33916 .47266 Mdot
.64461 .37121 Mdot
.66191 .35966 Mdot
.52965 .47139 Mdot
.29993 .4616 Mdot
.66254 .54078 Mdot
.69806 .53557 Mdot
.51647 .32967 Mdot
.61014 .19824 Mdot
.565 .29297 Mdot
.49853 .35005 Mdot
.33085 .44907 Mdot
.38198 .46005 Mdot
.32219 .42856 Mdot
.63251 .40774 Mdot
.50509 .57613 Mdot
.61876 .36021 Mdot
.72478 .60074 Mdot
.69911 .57672 Mdot
.3347 .47301 Mdot
.43701 .85268 Mdot
.53599 .66224 Mdot
.50732 .67408 Mdot
.69729 .58313 Mdot
.65331 .34922 Mdot
.30465 .44398 Mdot
.77038 .72096 Mdot
.49295 .69381 Mdot
.56866 .25551 Mdot
.38128 .49762 Mdot
.67248 .3867 Mdot
.54261 .66906 Mdot
.57109 .25536 Mdot
.36575 .44315 Mdot
.61684 .35052 Mdot
.35885 .46809 Mdot
.27831 .63133 Mdot
.54419 .68347 Mdot
.35519 .34796 Mdot
.55456 .65559 Mdot
.70156 .55958 Mdot
.67226 .54936 Mdot
.36204 .49371 Mdot
.78972 .70362 Mdot
.51297 .74065 Mdot
.71527 .58152 Mdot
.54391 .23951 Mdot
.51362 .58487 Mdot
.53169 .24835 Mdot
.62841 .37667 Mdot
.5668 .27323 Mdot
.65244 .41384 Mdot
.66354 .45924 Mdot
.50207 .6411 Mdot
.53522 .26417 Mdot
.4162 .68286 Mdot
.29935 .45037 Mdot
.51719 .26023 Mdot
.37561 .51341 Mdot
.35865 .53918 Mdot
.63966 .40027 Mdot
.54969 .29273 Mdot
.41159 .50199 Mdot
.63075 .65448 Mdot
.6754 .54403 Mdot
.66404 .54049 Mdot
.2933 .47802 Mdot
.63994 .42336 Mdot
.50737 .63923 Mdot
.40153 .33518 Mdot
.4845 .67726 Mdot
.33753 .47482 Mdot
.37078 .54622 Mdot
.53829 .63712 Mdot
.53065 .6415 Mdot
.35777 .49475 Mdot
.37063 .76814 Mdot
.40965 .46525 Mdot
.67544 .56749 Mdot
.52832 .66151 Mdot
.5078 .66835 Mdot
.67545 .40836 Mdot
.54696 .70599 Mdot
.43378 .51599 Mdot
.68758 .60261 Mdot
.42616 .49809 Mdot
.68675 .56021 Mdot
.69897 .38787 Mdot
.64556 .40529 Mdot
.66912 .63072 Mdot
.54937 .70066 Mdot
.35058 .52588 Mdot
.55469 .68493 Mdot
.55215 .2456 Mdot
.50572 .66432 Mdot
.57237 .6854 Mdot
.34677 .51141 Mdot
.41414 .49393 Mdot
.52495 .56987 Mdot
.4025 .35833 Mdot
.53892 .67664 Mdot
.34243 .53407 Mdot
.32777 .50492 Mdot
.35314 .45748 Mdot
.39023 .33413 Mdot
.55783 .68049 Mdot
.45605 .7718 Mdot
.48056 .70171 Mdot
.5441 .67869 Mdot
.16297 .58596 Mdot
.5195 .5615 Mdot
.53131 .57973 Mdot
.65935 .53411 Mdot
.35555 .48348 Mdot
.66312 .38576 Mdot
.40053 .48519 Mdot
.35144 .4225 Mdot
.38965 .49231 Mdot
.53377 .25667 Mdot
.3411 .45507 Mdot
.51652 .57377 Mdot
.6596 .37176 Mdot
.38035 .52939 Mdot
.36477 .48619 Mdot
.52744 .56516 Mdot
.55411 .67119 Mdot
.53232 .7188 Mdot
.48343 .66825 Mdot
.52547 .27559 Mdot
.71041 .56374 Mdot
.39918 .48934 Mdot
.64332 .37469 Mdot
.66643 .38151 Mdot
.55757 .69385 Mdot
.62014 .38302 Mdot
.70844 .57371 Mdot
.34679 .5001 Mdot
.70133 .55807 Mdot
.53397 .25548 Mdot
.53334 .67009 Mdot
.39148 .50143 Mdot
.40527 .49597 Mdot
.53912 .70516 Mdot
.41201 .4743 Mdot
.54644 .24269 Mdot
.62968 .41173 Mdot
.51038 .65015 Mdot
.68498 .54694 Mdot
.67251 .41159 Mdot
.36432 .53033 Mdot
.21503 .68484 Mdot
.37139 .49787 Mdot
.3439 .45912 Mdot
.51715 .7471 Mdot
.31907 .47479 Mdot
.67288 .37508 Mdot
.55447 .69346 Mdot
.35516 .53643 Mdot
.28523 .35276 Mdot
.5713 .31917 Mdot
.68007 .34191 Mdot
.36048 .50874 Mdot
.2843 .71915 Mdot
.33968 .51625 Mdot
.65983 .63201 Mdot
.36564 .3368 Mdot
.63998 .51953 Mdot
.26449 .43968 Mdot
.7144 .58119 Mdot
.52684 .57885 Mdot
.65797 .40989 Mdot
.3965 .73703 Mdot
.35836 .49842 Mdot
.38041 .61399 Mdot
.39354 .50098 Mdot
.68821 .57291 Mdot
.42541 .71296 Mdot
.62223 .37076 Mdot
.34242 .21901 Mdot
.38098 .45037 Mdot
.50593 .64532 Mdot
.61019 .4055 Mdot
.52782 .58597 Mdot
.41369 .49534 Mdot
.55803 .29697 Mdot
.52455 .33135 Mdot
.43382 .4918 Mdot
.68407 .55911 Mdot
.3698 .45408 Mdot
.37014 .42808 Mdot
.83045 .47312 Mdot
.53355 .6946 Mdot
.68717 .53328 Mdot
.60537 .19937 Mdot
.34735 .46611 Mdot
.52604 .71869 Mdot
.51296 .68681 Mdot
.53152 .27863 Mdot
.72489 .58376 Mdot
.54504 .34207 Mdot
.40453 .82535 Mdot
.23661 .52792 Mdot
.63198 .40863 Mdot
.54035 .61072 Mdot
.40172 .47911 Mdot
.45472 .21289 Mdot
.68601 .54126 Mdot
.3811 .48311 Mdot
.41246 .61903 Mdot
.52396 .69719 Mdot
.35499 .47227 Mdot
.56334 .27727 Mdot
.65365 .79125 Mdot
.2835 .67708 Mdot
.30307 .7379 Mdot
.6176 .348 Mdot
.40148 .54044 Mdot
.43094 .52102 Mdot
.51485 .5491 Mdot
.32103 .51562 Mdot
.65554 .36165 Mdot
.58531 .50504 Mdot
.55249 .28073 Mdot
.5405 .6646 Mdot
.52945 .57565 Mdot
.3931 .50195 Mdot
.41354 .52886 Mdot
.55003 .24095 Mdot
.40335 .45982 Mdot
.35913 .72667 Mdot
.50089 .57764 Mdot
.66462 .41671 Mdot
.50067 .66331 Mdot
.38131 .54655 Mdot
.5188 .58698 Mdot
.35186 .51333 Mdot
.4172 .58739 Mdot
.38561 .47504 Mdot
.61937 .61447 Mdot
.53661 .71002 Mdot
.67889 .55278 Mdot
.36957 .43985 Mdot
.36335 .47192 Mdot
.56308 .43773 Mdot
.30561 .44097 Mdot
.39337 .47861 Mdot
.54865 .7168 Mdot
.5384 .6628 Mdot
.50992 .64385 Mdot
.68292 .38656 Mdot
.42139 .38081 Mdot
.69647 .5582 Mdot
.31931 .43022 Mdot
.67173 .57255 Mdot
.27287 .42381 Mdot
.53147 .25359 Mdot
.68372 .63419 Mdot
.34734 .4973 Mdot
.51672 .70523 Mdot
.18425 .47719 Mdot
.55843 .6847 Mdot
.66098 .58837 Mdot
.68239 .54277 Mdot
.5335 .68072 Mdot
.36471 .50628 Mdot
.4012 .36611 Mdot
.3147 .7528 Mdot
.66636 .55811 Mdot
.29223 .48817 Mdot
.69685 .34845 Mdot
.67241 .34924 Mdot
.15879 .56865 Mdot
.67258 .57086 Mdot
.74572 .69776 Mdot
.35222 .53261 Mdot
.55313 .68551 Mdot
.70773 .55362 Mdot
.71871 .55106 Mdot
.61876 .37743 Mdot
.40358 .50815 Mdot
.36112 .4718 Mdot
.50955 .56171 Mdot
.70046 .54881 Mdot
.41354 .56596 Mdot
.40595 .51023 Mdot
.74254 .60282 Mdot
.49324 .66662 Mdot
.80742 .37975 Mdot
.46417 .5415 Mdot
.41085 .61907 Mdot
.78743 .39405 Mdot
.51429 .64677 Mdot
.38256 .45556 Mdot
.30491 .44472 Mdot
.62481 .40603 Mdot
.3557 .50341 Mdot
.67014 .35616 Mdot
.69851 .57357 Mdot
.62145 .63734 Mdot
.48549 .52158 Mdot
.69365 .61498 Mdot
.37426 .49388 Mdot
.29268 .68693 Mdot
.54159 .27016 Mdot
.65665 .56388 Mdot
.52454 .64147 Mdot
.32051 .50598 Mdot
.61767 .39295 Mdot
.67924 .3696 Mdot
.52415 .69369 Mdot
.72682 .69824 Mdot
.66972 .6325 Mdot
.40508 .45352 Mdot
.63392 .36332 Mdot
.47111 .54623 Mdot
.27155 .69328 Mdot
.69125 .58665 Mdot
.55079 .27946 Mdot
.66841 .40283 Mdot
.69248 .51946 Mdot
.36142 .54032 Mdot
.52597 .68658 Mdot
.51575 .63453 Mdot
.53896 .46424 Mdot
.65715 .39492 Mdot
.55237 .25849 Mdot
.54324 .46734 Mdot
.51124 .47165 Mdot
.55795 .27392 Mdot
.68483 .37831 Mdot
.51864 .65552 Mdot
.52015 .70199 Mdot
.50869 .67782 Mdot
.41112 .76358 Mdot
.49828 .7084 Mdot
.43459 .27049 Mdot
.31928 .51125 Mdot
.30259 .70817 Mdot
.32905 .51573 Mdot
.67072 .53377 Mdot
.54535 .68675 Mdot
.36197 .33894 Mdot
.33935 .44332 Mdot
.3225 .75735 Mdot
.37438 .46298 Mdot
.56441 .49811 Mdot
.3565 .48443 Mdot
.30116 .66324 Mdot
.52169 .72763 Mdot
.36911 .44482 Mdot
.68605 .60033 Mdot
.54708 .24891 Mdot
.56207 .65071 Mdot
.39063 .47118 Mdot
.649 .75485 Mdot
.37647 .51339 Mdot
.621 .63064 Mdot
.54871 .45865 Mdot
.53027 .21674 Mdot
.32858 .46832 Mdot
.61338 .37664 Mdot
.45574 .52809 Mdot
.29303 .701 Mdot
.6665 .5597 Mdot
.29864 .69507 Mdot
.62549 .35805 Mdot
.42602 .71737 Mdot
.3805 .42928 Mdot
.55381 .28325 Mdot
.57299 .57588 Mdot
.67244 .56271 Mdot
.35048 .49658 Mdot
.37695 .45046 Mdot
.57402 .5386 Mdot
.2631 .67647 Mdot
.42533 .56358 Mdot
.57602 .27729 Mdot
.27388 .67161 Mdot
.39224 .4819 Mdot
.67993 .34028 Mdot
.54118 .7164 Mdot
.42697 .69972 Mdot
.43317 .73476 Mdot
.39874 .52246 Mdot
.53298 .6847 Mdot
.5406 .71441 Mdot
.18194 .42886 Mdot
.54015 .27579 Mdot
.38433 .47224 Mdot
.5686 .46419 Mdot
.39793 .49179 Mdot
.69509 .57093 Mdot
.32332 .45872 Mdot
.64658 .4042 Mdot
.44178 .4098 Mdot
.68312 .38238 Mdot
.35044 .45811 Mdot
.52324 .67414 Mdot
.67079 .54372 Mdot
.68492 .4683 Mdot
.72343 .58521 Mdot
.43364 .2712 Mdot
.50927 .31743 Mdot
.56637 .29157 Mdot
.5281 .25429 Mdot
.65693 .55737 Mdot
.35396 .50793 Mdot
.40304 .345 Mdot
.30939 .50785 Mdot
.35098 .48234 Mdot
.38802 .48096 Mdot
.6483 .52801 Mdot
.68119 .54428 Mdot
.66815 .39452 Mdot
.35635 .49505 Mdot
.33671 .53106 Mdot
.52788 .67657 Mdot
.56595 .29022 Mdot
.65358 .41779 Mdot
.55117 .29842 Mdot
.65358 .37075 Mdot
.18378 .51418 Mdot
.29116 .50747 Mdot
.54212 .25078 Mdot
.68295 .582 Mdot
.50904 .69481 Mdot
.5116 .55467 Mdot
.62954 .38106 Mdot
.62148 .37648 Mdot
.3861 .54321 Mdot
.54275 .67222 Mdot
.54571 .70537 Mdot
.54479 .29432 Mdot
.70038 .53737 Mdot
.34472 .54869 Mdot
.40928 .52031 Mdot
.70807 .4404 Mdot
.62569 .41033 Mdot
.28261 .68404 Mdot
.49415 .72998 Mdot
.34274 .50181 Mdot
.52644 .71781 Mdot
.37087 .47726 Mdot
.47996 .58271 Mdot
.52087 .63667 Mdot
.31884 .47191 Mdot
.31194 .45245 Mdot
.63576 .41021 Mdot
.20076 .38203 Mdot
.35417 .55252 Mdot
.64398 .59376 Mdot
.40313 .47302 Mdot
.32787 .20936 Mdot
.18501 .46722 Mdot
.36349 .51474 Mdot
.34617 .4527 Mdot
.37002 .81479 Mdot
.3377 .51283 Mdot
.5114 .56788 Mdot
.35291 .42192 Mdot
.52099 .71609 Mdot
.57037 .4734 Mdot
.39964 .3538 Mdot
.53579 .2742 Mdot
.64138 .37654 Mdot
.36856 .30053 Mdot
.52528 .26275 Mdot
.52424 .70102 Mdot
.35582 .55465 Mdot
.50356 .73776 Mdot
.65896 .43101 Mdot
.40171 .56817 Mdot
.69178 .57314 Mdot
.40306 .34945 Mdot
.61784 .3859 Mdot
.68567 .54589 Mdot
.33408 .51234 Mdot
.63299 .43985 Mdot
.668 .58558 Mdot
.18353 .40225 Mdot
.70997 .53837 Mdot
.67485 .55139 Mdot
.41104 .36772 Mdot
.5358 .27445 Mdot
.58737 .51527 Mdot
.32026 .41156 Mdot
.66919 .54212 Mdot
.34683 .23034 Mdot
.62041 .40457 Mdot
.43602 .38475 Mdot
.52631 .72958 Mdot
.29 .49222 Mdot
.38434 .48495 Mdot
.70228 .53179 Mdot
.53972 .59643 Mdot
.56133 .42934 Mdot
.68937 .57756 Mdot
.35843 .43745 Mdot
.46033 .40934 Mdot
.51616 .58468 Mdot
.51702 .55984 Mdot
.56809 .25078 Mdot
.65236 .2505 Mdot
.53 .71286 Mdot
.56874 .25677 Mdot
.3296 .34951 Mdot
.37141 .45954 Mdot
.70371 .55792 Mdot
.52998 .57232 Mdot
.68611 .54921 Mdot
.54608 .26762 Mdot
.54319 .24112 Mdot
.53815 .68802 Mdot
.51915 .64251 Mdot
.5638 .60207 Mdot
.26823 .36492 Mdot
.39533 .51072 Mdot
.36392 .62077 Mdot
.53019 .64073 Mdot
.41508 .74474 Mdot
.54227 .2844 Mdot
.55871 .29278 Mdot
.23097 .60346 Mdot
.37694 .52581 Mdot
.56781 .50339 Mdot
.39246 .48974 Mdot
.38482 .22496 Mdot
.39101 .5037 Mdot
.621 .38555 Mdot
.38816 .45199 Mdot
.59223 .78394 Mdot
.36177 .53449 Mdot
.38841 .48716 Mdot
.64367 .38752 Mdot
.38994 .54436 Mdot
.64249 .40219 Mdot
.38119 .4564 Mdot
.54091 .32005 Mdot
.64343 .37515 Mdot
.55003 .31193 Mdot
.53975 .48966 Mdot
.5176 .56688 Mdot
.52898 .26483 Mdot
.56605 .29425 Mdot
.40213 .31227 Mdot
.52617 .65557 Mdot
.45076 .64952 Mdot
.38037 .49795 Mdot
.62889 .41681 Mdot
.70717 .57091 Mdot
.40099 .52141 Mdot
.32667 .48054 Mdot
.35123 .5511 Mdot
.53698 .68464 Mdot
.67194 .41593 Mdot
.53984 .25994 Mdot
.66877 .36275 Mdot
.54466 .31833 Mdot
.64193 .40693 Mdot
.30191 .50777 Mdot
.36533 .54226 Mdot
.42865 .52488 Mdot
.40474 .65218 Mdot
.49329 .20729 Mdot
.52509 .69011 Mdot
.52273 .58063 Mdot
.53267 .24983 Mdot
.48178 .42682 Mdot
.52247 .71243 Mdot
.62244 .38261 Mdot
.35909 .46783 Mdot
.29804 .52385 Mdot
.32435 .41068 Mdot
.56198 .71307 Mdot
.51868 .27074 Mdot
.63481 .3817 Mdot
.51017 .57615 Mdot
.4281 .38691 Mdot
.47409 .77262 Mdot
.33509 .33722 Mdot
.36699 .47417 Mdot
.53995 .29053 Mdot
.54242 .66887 Mdot
.57576 .51916 Mdot
.6966 .52939 Mdot
.4051 .35792 Mdot
.37493 .49467 Mdot
.76349 .55795 Mdot
.52178 .67463 Mdot
.5615 .28576 Mdot
.70244 .53155 Mdot
.54504 .28102 Mdot
.51884 .59027 Mdot
.48848 .7226 Mdot
.41316 .4923 Mdot
.39244 .49292 Mdot
.70424 .57145 Mdot
.53421 .71272 Mdot
.54453 .3253 Mdot
.58264 .54034 Mdot
.62753 .37502 Mdot
.47758 .43207 Mdot
.54019 .66529 Mdot
.74786 .52584 Mdot
.66874 .36067 Mdot
.66544 .53214 Mdot
.39082 .36023 Mdot
.71078 .57313 Mdot
.39058 .48051 Mdot
.51473 .66799 Mdot
.66575 .56049 Mdot
.7069 .42925 Mdot
.38535 .78658 Mdot
.57494 .56784 Mdot
.34426 .4652 Mdot
.67349 .64164 Mdot
.7112 .72432 Mdot
.56072 .64123 Mdot
.67751 .57593 Mdot
.37034 .48918 Mdot
.40572 .45439 Mdot
.38183 .45027 Mdot
.67795 .53807 Mdot
.68066 .48777 Mdot
.63628 .35454 Mdot
.35446 .46552 Mdot
.56651 .26304 Mdot
.65261 .40449 Mdot
.65571 .33931 Mdot
.67009 .40123 Mdot
.5281 .64332 Mdot
.30805 .53593 Mdot
.33931 .42216 Mdot
.19575 .42577 Mdot
.67642 .55292 Mdot
.51766 .56729 Mdot
.35388 .44973 Mdot
.43125 .27767 Mdot
.51211 .69707 Mdot
.63384 .38803 Mdot
.38028 .48132 Mdot
.54291 .46033 Mdot
.49519 .54329 Mdot
.65347 .38133 Mdot
.52417 .63908 Mdot
.56243 .74087 Mdot
.35302 .5025 Mdot
.40348 .47947 Mdot
.53373 .70459 Mdot
.70849 .73996 Mdot
.43598 .39375 Mdot
.36924 .47888 Mdot
.68036 .54853 Mdot
.81227 .61802 Mdot
.33444 .51475 Mdot
.49861 .72192 Mdot
.50336 .57364 Mdot
.4981 .73989 Mdot
.34561 .73391 Mdot
.30942 .44569 Mdot
.59253 .63833 Mdot
.47444 .31627 Mdot
.58347 .67942 Mdot
.40941 .2204 Mdot
.59092 .54933 Mdot
.16425 .44275 Mdot
.69571 .60526 Mdot
.28566 .64879 Mdot
.5298 .84966 Mdot
.74327 .69402 Mdot
.5717 .44893 Mdot
.64843 .49602 Mdot
.66892 .43394 Mdot
.35647 .19669 Mdot
.61438 .3663 Mdot
.42085 .20918 Mdot
.38795 .50106 Mdot
.69867 .74423 Mdot
.29273 .66407 Mdot
.49818 .23533 Mdot
.68633 .62723 Mdot
.54603 .46176 Mdot
.26394 .72651 Mdot
.72346 .61646 Mdot
.19247 .60284 Mdot
.43325 .62389 Mdot
.69256 .27561 Mdot
.49035 .44656 Mdot
.3853 .29641 Mdot
.3119 .69932 Mdot
.59203 .74487 Mdot
.74929 .55866 Mdot
.28427 .5882 Mdot
.79641 .3954 Mdot
.63936 .3643 Mdot
.53058 .72334 Mdot
.62654 .51245 Mdot
.22176 .65705 Mdot
.65275 .59014 Mdot
.59181 .63884 Mdot
.57802 .55578 Mdot
.29638 .65915 Mdot
.35148 .34652 Mdot
.28246 .62772 Mdot
.53645 .34309 Mdot
.36143 .19672 Mdot
.54215 .74845 Mdot
.72684 .37989 Mdot
.47289 .40366 Mdot
.52452 .35589 Mdot
.33262 .69256 Mdot
.57613 .3019 Mdot
.56776 .3173 Mdot
.52068 .63777 Mdot
.24336 .67344 Mdot
.50129 .53297 Mdot
.32119 .35506 Mdot
.61287 .36976 Mdot
.47895 .57074 Mdot
.64708 .79173 Mdot
.70448 .72442 Mdot
.22133 .34251 Mdot
.2122 .67468 Mdot
.34291 .25963 Mdot
.56527 .51752 Mdot
.64505 .56878 Mdot
.43552 .28933 Mdot
.41013 .57607 Mdot
.32037 .27603 Mdot
.42556 .58615 Mdot
.32262 .77657 Mdot
.67108 .72688 Mdot
.23833 .71028 Mdot
.54893 .74598 Mdot
.40353 .54605 Mdot
.49941 .59816 Mdot
.26284 .55605 Mdot
.3109 .33673 Mdot
.24099 .7001 Mdot
.52915 .22135 Mdot
.53027 .59962 Mdot
.74572 .68745 Mdot
.35738 .72658 Mdot
.55995 .35171 Mdot
.51041 .26589 Mdot
.43534 .68909 Mdot
.27332 .74502 Mdot
.59714 .6404 Mdot
.20841 .53166 Mdot
.75077 .59753 Mdot
.59823 .39614 Mdot
.64979 .33904 Mdot
.72093 .56655 Mdot
.19771 .63246 Mdot
.51326 .67325 Mdot
.19701 .3823 Mdot
.56941 .62335 Mdot
.45608 .55584 Mdot
.27936 .75245 Mdot
.28401 .28799 Mdot
.3257 .71994 Mdot
.46793 .25015 Mdot
.79093 .58584 Mdot
.29076 .55765 Mdot
.68905 .61126 Mdot
.6927 .34721 Mdot
.63296 .62972 Mdot
.20593 .64602 Mdot
.32215 .26348 Mdot
.43548 .84421 Mdot
.31431 .36159 Mdot
.60288 .30727 Mdot
.53735 .7487 Mdot
.59554 .44994 Mdot
.56655 .36159 Mdot
.23316 .70559 Mdot
.27663 .66645 Mdot
.80592 .6066 Mdot
.39054 .23728 Mdot
.43323 .74219 Mdot
.66341 .65313 Mdot
.64587 .47949 Mdot
.26502 .54193 Mdot
.66287 .74591 Mdot
.41741 .51371 Mdot
.33947 .32743 Mdot
.43421 .66367 Mdot
.56252 .23212 Mdot
.424 .38769 Mdot
.68024 .70524 Mdot
.34277 .28312 Mdot
.78134 .62927 Mdot
.43865 .69463 Mdot
.5527 .64986 Mdot
.32317 .27612 Mdot
.36625 .24497 Mdot
.75285 .63536 Mdot
.60233 .19793 Mdot
.20738 .53477 Mdot
.58215 .37459 Mdot
.31792 .43733 Mdot
.28201 .64436 Mdot
.31485 .69989 Mdot
.37111 .20651 Mdot
.29865 .50335 Mdot
.20752 .39251 Mdot
.67478 .62088 Mdot
.38943 .66157 Mdot
.31166 .31845 Mdot
.40036 .65658 Mdot
.31634 .7287 Mdot
.4838 .6328 Mdot
.62666 .55107 Mdot
.54953 .57907 Mdot
.2762 .74552 Mdot
.6613 .40246 Mdot
.31596 .2759 Mdot
.67241 .60847 Mdot
.70489 .43697 Mdot
.5941 .52988 Mdot
.5654 .42707 Mdot
.18056 .5964 Mdot
.73983 .68083 Mdot
.70178 .41396 Mdot
.5727 .76679 Mdot
.47182 .55706 Mdot
.37048 .62601 Mdot
.36542 .56211 Mdot
.43772 .57896 Mdot
.54622 .24259 Mdot
.39883 .70584 Mdot
.47588 .69374 Mdot
.58444 .1824 Mdot
.30088 .48826 Mdot
.49515 .44901 Mdot
.50353 .56409 Mdot
.42675 .34104 Mdot
.18187 .51284 Mdot
.35235 .56224 Mdot
.27955 .29496 Mdot
.73672 .69299 Mdot
.42139 .33582 Mdot
.5624 .35989 Mdot
.45056 .66911 Mdot
.24097 .71466 Mdot
.1592 .5365 Mdot
.65485 .77015 Mdot
.6562 .64551 Mdot
.51354 .13406 Mdot
.62909 .5396 Mdot
.21924 .37054 Mdot
.67157 .60784 Mdot
.90795 .47194 Mdot
.67366 .36582 Mdot
.46076 .20592 Mdot
.332 .58273 Mdot
.52139 .43908 Mdot
.23304 .66841 Mdot
.34065 .7171 Mdot
.51822 .27382 Mdot
.56988 .67825 Mdot
.29632 .48189 Mdot
.24922 .70044 Mdot
.28219 .74581 Mdot
.2541 .70547 Mdot
.731 .51327 Mdot
.3284 .75152 Mdot
.33818 .79871 Mdot
.43741 .26963 Mdot
.53996 .52144 Mdot
.37416 .42863 Mdot
.25848 .36557 Mdot
.25509 .33215 Mdot
.54948 .21298 Mdot
.28592 .55389 Mdot
.53898 .75075 Mdot
.3159 .78604 Mdot
.17862 .50654 Mdot
.2757 .6134 Mdot
.18484 .58787 Mdot
.71113 .35899 Mdot
.27196 .33857 Mdot
.16945 .57145 Mdot
.59896 .70795 Mdot
.72703 .60395 Mdot
.35177 .81249 Mdot
.36509 .25364 Mdot
.6508 .4938 Mdot
.62421 .76968 Mdot
.23956 .34375 Mdot
.64998 .65263 Mdot
.64812 .49193 Mdot
.4005 .58263 Mdot
.48431 .76589 Mdot
.56851 .42769 Mdot
.58821 .74613 Mdot
.56521 .51069 Mdot
.29982 .32097 Mdot
.65065 .34263 Mdot
.30015 .29093 Mdot
.55049 .37292 Mdot
.54772 .52413 Mdot
.37886 .30907 Mdot
.33606 .24256 Mdot
.6368 .74022 Mdot
.29427 .72929 Mdot
.73861 .68827 Mdot
.79942 .62426 Mdot
.70428 .65391 Mdot
.43921 .6495 Mdot
.38797 .54523 Mdot
.22635 .66484 Mdot
.13789 .5185 Mdot
.17156 .58315 Mdot
.76459 .63233 Mdot
.62986 .32998 Mdot
.67523 .52249 Mdot
.4256 .29333 Mdot
.53178 .43368 Mdot
.59735 .58088 Mdot
.50521 .36877 Mdot
.72324 .57006 Mdot
.65957 .78837 Mdot
.57032 .59674 Mdot
.43397 .28003 Mdot
.2936 .5977 Mdot
.39789 .57336 Mdot
.26908 .69022 Mdot
.54174 .6388 Mdot
.76962 .62259 Mdot
.31812 .2774 Mdot
.66266 .40417 Mdot
.71617 .42481 Mdot
.5458 .57171 Mdot
.38529 .55341 Mdot
.68969 .33316 Mdot
.56165 .55412 Mdot
.40856 .61971 Mdot
.6369 .32994 Mdot
.16767 .47859 Mdot
.2128 .37091 Mdot
.16783 .56772 Mdot
.34174 .25444 Mdot
.72204 .40505 Mdot
.43035 .35483 Mdot
.63126 .56023 Mdot
.70353 .62158 Mdot
.45441 .38634 Mdot
.34672 .24357 Mdot
.32236 .72083 Mdot
.51184 .60378 Mdot
.31715 .4344 Mdot
.1845 .48307 Mdot
.40397 .28387 Mdot
.44052 .35535 Mdot
.45414 .72718 Mdot
.48968 .68195 Mdot
.50353 .19154 Mdot
.59486 .75719 Mdot
.41252 .42726 Mdot
.66792 .64721 Mdot
.68622 .58765 Mdot
.5248 .63517 Mdot
.33428 .24276 Mdot
.63363 .21289 Mdot
.56774 .6407 Mdot
.48896 .52981 Mdot
.20581 .63448 Mdot
.52166 .49488 Mdot
.63858 .64509 Mdot
.51895 .79294 Mdot
.79972 .55892 Mdot
.55537 .73931 Mdot
.55466 .51942 Mdot
.5967 .50868 Mdot
.51655 .76509 Mdot
.56584 .68926 Mdot
.28328 .6744 Mdot
.19759 .64509 Mdot
.5467 .47152 Mdot
.58786 .73201 Mdot
.40755 .34141 Mdot
.58433 .44477 Mdot
.49453 .57218 Mdot
.3705 .30461 Mdot
.59183 .68608 Mdot
.21126 .57514 Mdot
.7296 .75128 Mdot
.26906 .53394 Mdot
.45464 .20189 Mdot
.42855 .29308 Mdot
.4349 .62365 Mdot
.32746 .68672 Mdot
.7385 .61608 Mdot
.39726 .47508 Mdot
.19441 .65237 Mdot
.67966 .71565 Mdot
.40292 .32146 Mdot
.65482 .46505 Mdot
.35429 .52457 Mdot
.43148 .51633 Mdot
.17327 .58025 Mdot
.5089 .75083 Mdot
.59806 .85094 Mdot
.39342 .2289 Mdot
.45338 .59744 Mdot
.33818 .73236 Mdot
.27404 .30271 Mdot
.48302 .62846 Mdot
.57374 .62267 Mdot
.55703 .379 Mdot
.25608 .32491 Mdot
.55616 .77391 Mdot
.58308 .7729 Mdot
.7024 .64704 Mdot
.33614 .79415 Mdot
.46217 .56666 Mdot
.74799 .58736 Mdot
.70859 .35122 Mdot
.34259 .45947 Mdot
.72459 .70096 Mdot
.69647 .63635 Mdot
.60071 .42699 Mdot
.39938 .57965 Mdot
.13587 .52094 Mdot
.3557 .42935 Mdot
.72896 .68359 Mdot
.58296 .8507 Mdot
.65001 .8369 Mdot
.58796 .78277 Mdot
.22851 .70138 Mdot
.57598 .77255 Mdot
.63687 .64803 Mdot
.66839 .575 Mdot
.50293 .47075 Mdot
.37162 .61563 Mdot
.17973 .62172 Mdot
.6673 .24222 Mdot
.69266 .61165 Mdot
.29615 .58371 Mdot
.17816 .62198 Mdot
.33582 .43235 Mdot
.48509 .19384 Mdot
.59784 .39195 Mdot
.33555 .21972 Mdot
.22988 .33388 Mdot
.46593 .74777 Mdot
.36139 .20875 Mdot
.46756 .1855 Mdot
.48592 .27179 Mdot
.21686 .3687 Mdot
.23867 .5103 Mdot
.46496 .73445 Mdot
.32768 .27533 Mdot
.65091 .6347 Mdot
.44882 .14549 Mdot
.49373 .57186 Mdot
.56355 .54145 Mdot
.48386 .72502 Mdot
.62909 .62783 Mdot
.64312 .7197 Mdot
.52434 .51343 Mdot
.46174 .43294 Mdot
.30612 .71899 Mdot
.81876 .61096 Mdot
.54356 .80668 Mdot
.561 .57974 Mdot
.28641 .74432 Mdot
.74688 .60953 Mdot
.45996 .38101 Mdot
.34993 .70957 Mdot
.40924 .29018 Mdot
.7095 .36601 Mdot
.38977 .49294 Mdot
.20087 .65037 Mdot
.70905 .36492 Mdot
.27469 .73002 Mdot
.18571 .39326 Mdot
.19021 .585 Mdot
.34198 .56507 Mdot
.69895 .35822 Mdot
.26847 .32267 Mdot
.26931 .32429 Mdot
.33861 .78199 Mdot
.44248 .19628 Mdot
.4597 .39839 Mdot
.54026 .50076 Mdot
.48499 .52679 Mdot
.41136 .42315 Mdot
.2684 .30718 Mdot
.45674 .63821 Mdot
.32024 .31616 Mdot
.63211 .77962 Mdot
.34045 .24355 Mdot
.33057 .71878 Mdot
.40648 .29953 Mdot
.58248 .40033 Mdot
.53427 .29736 Mdot
.62345 .41041 Mdot
.40898 .83293 Mdot
.72742 .64546 Mdot
.20516 .40167 Mdot
.79739 .6107 Mdot
.66724 .74201 Mdot
.41912 .20527 Mdot
.51362 .60715 Mdot
.25502 .51995 Mdot
.68037 .26542 Mdot
.34798 .28688 Mdot
.28665 .68445 Mdot
.66281 .63399 Mdot
.45142 .7551 Mdot
.1824 .60935 Mdot
.30237 .32226 Mdot
.47421 .85886 Mdot
.65773 .30961 Mdot
.39836 .69896 Mdot
.23836 .65873 Mdot
.79206 .6583 Mdot
.44132 .35143 Mdot
.27906 .74758 Mdot
.54056 .72881 Mdot
.21573 .67916 Mdot
.71201 .54651 Mdot
.59875 .29394 Mdot
.65386 .62145 Mdot
.42399 .31989 Mdot
.42674 .3231 Mdot
.17932 .44522 Mdot
.7432 .68498 Mdot
.70596 .72516 Mdot
.58228 .3739 Mdot
.6218 .35426 Mdot
.49117 .48102 Mdot
.5949 .7104 Mdot
.41974 .83487 Mdot
.36965 .54557 Mdot
.64451 .30447 Mdot
.30099 .28092 Mdot
.63186 .55816 Mdot
.57034 .54872 Mdot
.64701 .62297 Mdot
.50112 .78937 Mdot
.26996 .34818 Mdot
.32489 .7875 Mdot
.57005 .55318 Mdot
.52908 .41787 Mdot
.42371 .72583 Mdot
.60552 .58089 Mdot
.77857 .58602 Mdot
.59505 .65207 Mdot
.50889 .50612 Mdot
.43435 .39058 Mdot
.34687 .25563 Mdot
.14823 .48224 Mdot
.30586 .76158 Mdot
.78185 .58304 Mdot
.4303 .3349 Mdot
.49942 .72182 Mdot
.36217 .29007 Mdot
.46597 .85923 Mdot
.34383 .20477 Mdot
.63344 .76512 Mdot
.33414 .2512 Mdot
.62795 .456 Mdot
.47115 .19701 Mdot
.44775 .36989 Mdot
.23642 .65568 Mdot
.30056 .57721 Mdot
.48589 .71892 Mdot
.64234 .48523 Mdot
.39544 .34476 Mdot
.58699 .55224 Mdot
.46032 .72933 Mdot
.74583 .67963 Mdot
.47586 .85872 Mdot
.43667 .19002 Mdot
.42783 .71739 Mdot
.50677 .84711 Mdot
.50328 .64086 Mdot
.60085 .51024 Mdot
.72598 .49488 Mdot
.42269 .33303 Mdot
.67744 .37769 Mdot
.43572 .55938 Mdot
.46984 .42347 Mdot
.56016 .78314 Mdot
.66901 .43824 Mdot
.52288 .25343 Mdot
.55943 .66747 Mdot
.45619 .18901 Mdot
.51397 .63377 Mdot
.15381 .47158 Mdot
.6013 .69956 Mdot
.30127 .71023 Mdot
.51991 .80629 Mdot
.72917 .3602 Mdot
.80186 .629 Mdot
.19117 .59992 Mdot
.2852 .35465 Mdot
.56692 .68154 Mdot
.55063 .64389 Mdot
.56104 .76503 Mdot
.66615 .50865 Mdot
.20934 .63342 Mdot
.28988 .28438 Mdot
.72686 .40119 Mdot
.50631 .71039 Mdot
.55116 .49891 Mdot
.55659 .57594 Mdot
.16932 .48965 Mdot
.67014 .36523 Mdot
.25765 .73433 Mdot
.45339 .64365 Mdot
.75391 .70069 Mdot
.59961 .59065 Mdot
.42482 .40083 Mdot
.45031 .35404 Mdot
.70625 .42636 Mdot
.32496 .43129 Mdot
.45536 .59252 Mdot
.52162 .64394 Mdot
.59264 .53611 Mdot
.56685 .28509 Mdot
.58771 .18636 Mdot
.63287 .57914 Mdot
.42691 .63621 Mdot
.25993 .31047 Mdot
.53879 .63665 Mdot
.65831 .31191 Mdot
.72159 .33384 Mdot
.30756 .46271 Mdot
.23698 .39299 Mdot
.38768 .82323 Mdot
.19761 .60736 Mdot
.55756 .70208 Mdot
.79149 .62822 Mdot
.55777 .33523 Mdot
.16958 .47408 Mdot
.53738 .76911 Mdot
.28658 .2955 Mdot
.42537 .67296 Mdot
.16684 .54536 Mdot
.34524 .7333 Mdot
.59296 .61408 Mdot
.3278 .26862 Mdot
.56281 .43221 Mdot
.32905 .25194 Mdot
.49352 .79108 Mdot
.49508 .5065 Mdot
.33484 .2232 Mdot
.63994 .45774 Mdot
.28207 .63083 Mdot
.44421 .4827 Mdot
.59639 .58804 Mdot
.26431 .31972 Mdot
.55557 .66778 Mdot
.58067 .28883 Mdot
.30952 .59528 Mdot
.70642 .61482 Mdot
.20365 .641 Mdot
.75111 .63963 Mdot
.30586 .27342 Mdot
.48233 .53168 Mdot
.40218 .26354 Mdot
.45655 .63021 Mdot
.30574 .35937 Mdot
.40078 .44426 Mdot
.43314 .67209 Mdot
.52353 .37631 Mdot
.1859 .4553 Mdot
.45304 .49909 Mdot
.23667 .68354 Mdot
.18287 .50154 Mdot
.54078 .77412 Mdot
.58023 .50341 Mdot
.52004 .72097 Mdot
.25803 .72955 Mdot
.24313 .37075 Mdot
.63364 .62401 Mdot
.23356 .33049 Mdot
.5038 .18868 Mdot
.52033 .84875 Mdot
.71254 .68154 Mdot
.55616 .54857 Mdot
.20028 .38439 Mdot
.67827 .72088 Mdot
.47963 .18496 Mdot
.28294 .67947 Mdot
.51874 .74639 Mdot
.28396 .75704 Mdot
.24462 .53272 Mdot
.69358 .73317 Mdot
.25805 .67601 Mdot
.57844 .7079 Mdot
.23635 .37856 Mdot
.33065 .42561 Mdot
.62173 .39488 Mdot
.51466 .44794 Mdot
.36994 .20304 Mdot
.57291 .65697 Mdot
.2813 .29645 Mdot
.28684 .29748 Mdot
.43071 .21121 Mdot
.71755 .4059 Mdot
.52164 .84829 Mdot
.3576 .76036 Mdot
.42334 .5152 Mdot
.55852 .70533 Mdot
.52637 .25298 Mdot
.39469 .23834 Mdot
.3831 .52784 Mdot
.35861 .36488 Mdot
.43288 .684 Mdot
.18706 .63904 Mdot
.58641 .42978 Mdot
.74714 .5638 Mdot
.51175 .7185 Mdot
.63238 .62733 Mdot
.47327 .63779 Mdot
.74241 .69757 Mdot
.26915 .31629 Mdot
.56992 .64427 Mdot
.59271 .63122 Mdot
.68367 .73821 Mdot
.33499 .28016 Mdot
.51868 .33782 Mdot
.66371 .55159 Mdot
.39677 .6171 Mdot
.381 .80289 Mdot
.69345 .72271 Mdot
.52447 .60513 Mdot
.6171 .75013 Mdot
.5021 .50124 Mdot
.7611 .5805 Mdot
.74097 .68787 Mdot
.47988 .66712 Mdot
.21079 .59036 Mdot
.57788 .72717 Mdot
.69608 .34698 Mdot
.37579 .2394 Mdot
.60178 .74141 Mdot
.27462 .30525 Mdot
.31418 .45017 Mdot
.24624 .68654 Mdot
.40564 .32254 Mdot
.58383 .2802 Mdot
.40848 .48397 Mdot
.38058 .59025 Mdot
.17259 .57988 Mdot
.6152 .77115 Mdot
.34221 .57723 Mdot
.49797 .63411 Mdot
.21303 .3648 Mdot
.6756 .33036 Mdot
.64243 .32757 Mdot
.46821 .23372 Mdot
.43187 .40884 Mdot
.52743 .43181 Mdot
.64946 .51635 Mdot
.32869 .43243 Mdot
.50614 .33015 Mdot
.5031 .51355 Mdot
.39953 .62 Mdot
.21916 .37827 Mdot
.40376 .82807 Mdot
.49245 .58044 Mdot
.22326 .33753 Mdot
.34248 .5888 Mdot
.53934 .74101 Mdot
.44588 .18772 Mdot
.30711 .56465 Mdot
.29697 .49529 Mdot
.58062 .28538 Mdot
.49554 .64719 Mdot
.39743 .82143 Mdot
.43483 .57297 Mdot
.58132 .25056 Mdot
.58 .35559 Mdot
.48853 .55866 Mdot
.78087 .38267 Mdot
.67891 .62028 Mdot
.20061 .37967 Mdot
.31926 .27622 Mdot
.72852 .55593 Mdot
.56813 .77288 Mdot
.31274 .56882 Mdot
.24496 .68789 Mdot
.53698 .39075 Mdot
.19499 .61425 Mdot
.74574 .53016 Mdot
.41455 .63581 Mdot
.18549 .49458 Mdot
.32783 .33015 Mdot
.31034 .35649 Mdot
.44452 .70946 Mdot
.25157 .43688 Mdot
.51287 .55465 Mdot
.62029 .21224 Mdot
.42868 .15484 Mdot
.44345 .84931 Mdot
.74856 .70447 Mdot
.40823 .43444 Mdot
.35689 .2913 Mdot
.57499 .73736 Mdot
.46385 .38952 Mdot
.57146 .3695 Mdot
.6828 .32537 Mdot
.66021 .47086 Mdot
.81176 .61058 Mdot
.19375 .64939 Mdot
.40755 .48405 Mdot
.49347 .35124 Mdot
.51377 .2244 Mdot
.67398 .35987 Mdot
.27604 .59591 Mdot
.384 .81969 Mdot
.6662 .54965 Mdot
.7385 .49246 Mdot
.64219 .52167 Mdot
.18136 .44472 Mdot
.71317 .4751 Mdot
.66224 .51896 Mdot
.15305 .4712 Mdot
.65279 .76876 Mdot
.46766 .7732 Mdot
.81129 .6016 Mdot
.18351 .47163 Mdot
.43118 .66439 Mdot
.68466 .33391 Mdot
.21898 .67261 Mdot
.44895 .35531 Mdot
.70822 .40096 Mdot
.22106 .48763 Mdot
.32861 .26473 Mdot
.3868 .2333 Mdot
.73443 .53914 Mdot
.30796 .58274 Mdot
.58521 .17039 Mdot
.73117 .3603 Mdot
.76494 .72521 Mdot
.19802 .60241 Mdot
.40467 .79962 Mdot
.58772 .77698 Mdot
.58518 .38408 Mdot
.24072 .67874 Mdot
.28487 .30387 Mdot
.32189 .57825 Mdot
.64881 .23258 Mdot
.35022 .31986 Mdot
.38633 .29027 Mdot
.75988 .57265 Mdot
.17566 .56851 Mdot
.7238 .39311 Mdot
.23912 .48963 Mdot
.31467 .27302 Mdot
.35736 .5914 Mdot
.3044 .36396 Mdot
.37099 .79642 Mdot
.23455 .39159 Mdot
.35506 .23717 Mdot
.66527 .47309 Mdot
.56022 .32197 Mdot
.39433 .81586 Mdot
.47345 .6096 Mdot
.4253 .68054 Mdot
.58654 .85053 Mdot
.2374 .70839 Mdot
.29894 .56122 Mdot
.32521 .45592 Mdot
.16507 .4366 Mdot
.62407 .31714 Mdot
.21768 .38567 Mdot
.63535 .79426 Mdot
.39804 .22277 Mdot
.45806 .51834 Mdot
.38627 .50835 Mdot
.44092 .25773 Mdot
.51238 .75811 Mdot
.32012 .58164 Mdot
.69826 .46034 Mdot
.34884 .24364 Mdot
.43039 .63581 Mdot
.72874 .75186 Mdot
.49488 .78884 Mdot
.50786 .70289 Mdot
.2086 .66221 Mdot
.24127 .56342 Mdot
.44437 .6252 Mdot
.23715 .66319 Mdot
.53169 .40013 Mdot
.50851 .33085 Mdot
.45596 .62695 Mdot
.43094 .35286 Mdot
.3721 .19986 Mdot
.50434 .84923 Mdot
.3799 .6213 Mdot
.26501 .74174 Mdot
.15855 .54412 Mdot
.50728 .70556 Mdot
.27992 .56657 Mdot
.44301 .33604 Mdot
.58431 .68885 Mdot
.65959 .48577 Mdot
.71212 .4261 Mdot
.52734 .19335 Mdot
.58102 .18618 Mdot
.36772 .51316 Mdot
.74655 .52996 Mdot
.18442 .61024 Mdot
.51923 .19493 Mdot
.1881 .62119 Mdot
.43884 .66187 Mdot
.40134 .53758 Mdot
.65522 .83508 Mdot
.63535 .64611 Mdot
.31957 .53584 Mdot
.36214 .4117 Mdot
.3792 .41474 Mdot
.39489 .48066 Mdot
.6852 .49421 Mdot
.42206 .28807 Mdot
.38822 .22111 Mdot
.21861 .66764 Mdot
.49691 .69718 Mdot
.44746 .34965 Mdot
.69703 .60275 Mdot
.37931 .35034 Mdot
.2762 .42186 Mdot
.6991 .59135 Mdot
.39217 .21079 Mdot
.7791 .38433 Mdot
.54677 .3565 Mdot
.58027 .5693 Mdot
.45144 .42523 Mdot
.56075 .6084 Mdot
.41812 .19737 Mdot
.6562 .51327 Mdot
.48676 .27373 Mdot
.31044 .27083 Mdot
.44509 .72948 Mdot
.7523 .58716 Mdot
.51276 .1401 Mdot
.44399 .35803 Mdot
.72079 .50443 Mdot
.27194 .53368 Mdot
.49717 .77865 Mdot
.21047 .60919 Mdot
.52107 .33 Mdot
.50508 .55234 Mdot
.42156 .71759 Mdot
.23157 .66738 Mdot
.70003 .58266 Mdot
.1448 .49526 Mdot
.2708 .52526 Mdot
.27903 .60117 Mdot
.36085 .77548 Mdot
.56299 .52281 Mdot
.29252 .68867 Mdot
.42236 .46374 Mdot
.51324 .41038 Mdot
.76652 .36908 Mdot
.56541 .56776 Mdot
.49275 .56494 Mdot
.58525 .6708 Mdot
.44846 .20378 Mdot
.22305 .58356 Mdot
.38184 .47014 Mdot
.5169 .24443 Mdot
.41951 .3461 Mdot
.59259 .30944 Mdot
.60242 .30865 Mdot
.72395 .60518 Mdot
.41417 .20013 Mdot
.39322 .22963 Mdot
.26394 .67607 Mdot
.25418 .71331 Mdot
.44616 .48893 Mdot
.19677 .59556 Mdot
.57085 .41078 Mdot
.65019 .71783 Mdot
.23837 .38986 Mdot
.49924 .8488 Mdot
.46052 .58679 Mdot
.40289 .42466 Mdot
.15824 .51626 Mdot
.1834 .59014 Mdot
.69202 .61467 Mdot
.6625 .63838 Mdot
.39911 .16761 Mdot
.43111 .32342 Mdot
.81529 .61065 Mdot
.67598 .46587 Mdot
.16286 .49731 Mdot
.50752 .52632 Mdot
.29055 .55173 Mdot
.44921 .68255 Mdot
.29915 .49246 Mdot
.66114 .38271 Mdot
.51656 .79146 Mdot
.44531 .71435 Mdot
.26098 .42757 Mdot
.42615 .51791 Mdot
.61909 .50455 Mdot
.50074 .7256 Mdot
.44976 .85061 Mdot
.68186 .36163 Mdot
.52839 .41426 Mdot
.69609 .77378 Mdot
.76998 .37297 Mdot
.49655 .1855 Mdot
.32767 .77461 Mdot
.69748 .62259 Mdot
.50563 .51093 Mdot
.8311 .48734 Mdot
.52977 .73466 Mdot
.56196 .69965 Mdot
.62926 .57082 Mdot
.40744 .26585 Mdot
.72738 .68989 Mdot
.54612 .85157 Mdot
.16576 .54058 Mdot
.31174 .45434 Mdot
.8244 .66286 Mdot
.30962 .27551 Mdot
.50694 .37894 Mdot
.73379 .68114 Mdot
.19914 .64538 Mdot
.65123 .46781 Mdot
.18407 .40207 Mdot
.59468 .73792 Mdot
.57088 .72691 Mdot
.40123 .27994 Mdot
.79053 .61596 Mdot
.55198 .50319 Mdot
.76724 .72109 Mdot
.67884 .64945 Mdot
.38402 .29641 Mdot
.60985 .77081 Mdot
.55858 .73107 Mdot
.45733 .58427 Mdot
.60546 .68511 Mdot
.38635 .5783 Mdot
.55004 .62107 Mdot
.59586 .63883 Mdot
.52419 .34331 Mdot
.60607 .54312 Mdot
.63026 .64121 Mdot
.63868 .5661 Mdot
.46165 .7454 Mdot
.38055 .18313 Mdot
.63058 .30761 Mdot
.65369 .3437 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`2Sooooo`;o0000Y?ooool001cooooo00?o0000ooooooooool0V_ooool2o`0000Oooooo0_l0
002Tooooo`007?ooool00ol0003oooooooooo`2Iooooo`?o00001oooool2o`000:Cooooo000Loooo
o`03o`000?oooooooooo09Wooooo0_l00008ooooo`?o0000Xoooool001cooooo00?o0000oooooooo
ool0S_ooool2o`0001Cooooo0_l0002Sooooo`007?ooool00ol0003oooooooooo`2>ooooo`;o0000
^Oooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo08Sooooo0_l0002o
ooooo`007?ooool00ol0003oooooooooo`25ooooo`;o000000?oooooo`000?l00000_oooool001co
oooo00?o0000ooooooooool0POooool2o`0000;ooooo0_l00032ooooo`007?ooool00ol0003ooooo
ooooo`1oooooo`Co0000a_ooool001cooooo00?o0000ooooooooool0O_ooool3o`000<Sooooo000L
ooooo`03o`000?oooooooooo07kooooo0_l0000jooooo`;o0000SOooool001cooooo00?o0000oooo
ooooool0^_ooool2o`0008gooooo000Looooo`03o`000?oooooooooo07Wooooo0_l0003>ooooo`00
7?ooool00ol0003oooooooooo`1gooooo`Co0000?Oooool2o`0008oooooo000Looooo`03o`000?oo
oooooooo07Gooooo1Ol0000nooooo`Ko0000Roooool001cooooo00?o0000ooooooooool0MOooool5
o`0001?ooooo0_l00005ooooo`;o00000_ooool2o`0000Cooooo0_l0000Iooooo`Go0000Roooool0
01cooooo00?o0000ooooooooool0R_ooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2
o`0000;ooooo0_l00004ooooo`Co00005oooool4o`0008cooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`2:ooooo`;o00001?oo
ool4o`0000Kooooo0_l00004ooooo`;o00001_ooool2o`0009oooooo00001_ooooooMgMgoiRHV?oo
ooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`1`ooooo`Co00006?ooool2o`0000Cooooo0_l00006ooooo`;o00001?ooool2o`0000?o
oooo0_l000000ooooooo0000o`00002Oooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooo
ooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0L?ooool4o`000003oooo
ool0003o000000gooooo0_l00006ooooo`;o00001oooool2o`0000kooooo0_l0000Eooooo`;o0000
0_ooool4o`0008Gooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o
V9RHob4Q8Oo^k^h01_ooool3o`0006gooooo0_l00005ooooo`?o00003?ooool3o`0000[ooooo0_l0
0003ooooo`;o00002Oooool3o`0001Wooooo0_l00002ooooo`Co0000QOooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooo
oooo06_ooooo1?l00005ooooo`;o00000_ooool2o`0000Wooooo0ol00008ooooo`Ko00001oooool4
o`000004ooooool0003o0000o`00023ooooo0_l00024ooooo`0000?ooooooa0@4?ooool00_ooool0
0ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Joooool3
o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0000[ooooo0ol00007ooooo`;o000000Co
ooooo`000?l0003o00001oooool4o`0002Cooooo0_l00024ooooo`0000KoooooogMgMonHV9Sooooo
oiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`1Woooo
o`Go00001_ooool2o`000003ooooool0003o000000Gooooo0_l00007ooooo`;o000000?oooooo`00
0?l000001oooool2o`0000Gooooo0_l00002ooooo`;o0000:?ooool2o`00087ooooo00001_oooooo
k^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oo
oooooooo06Oooooo1Ol0000@ooooo`;o00002_ooool2o`0000Gooooo0ol00006ooooo`;o00005Ooo
ool3o`0001Cooooo0_l00002ooooo`;o0000OOooool001cooooo00?o0000ooooooooool0L?ooool2
o`0001gooooo0ol00005ooooo`;o00003Oooool4o`0000Gooooo0ol0000Gooooo`?o0000OOooool0
01cooooo00?o0000ooooooooool0I_ooool2o`000004ooooool0003o0000ooooo`Ko00002?ooool2
o`0000Gooooo0_l0000<ooooo`;o00001_ooool2o`0000gooooo1?l0000Oooooo`;o0000O_ooool0
01cooooo00?o0000ooooooooool0I_ooool2o`000003ooooool0003o000000Oo00002?ooool2o`00
00;ooooo0_l000000ooooooo0000o`00000Pooooo`;o00000oooool2o`0002Cooooo0_l0001ioooo
o`007?ooool00ol0003oooooooooo`1Yooooo`Co000000?oooooo`000?l000000_l00007ooooo`;o
00000oooool2o`0001Kooooo0_l0000:ooooo`Go00000_ooool2o`0000gooooo0_l0000Dooooo`;o
0000NOooool001cooooo00?o0000ooooooooool0KOooool4o`0000Sooooo1Ol0000Hooooo`Co0000
2?ooool:o`0000cooooo0_l0000<ooooo`;o0000POooool001cooooo00?o0000ooooooooool0KOoo
ool2o`0000_ooooo1?l0000Fooooo`;o00000_ooool2o`0000Sooooo0ol00002ooooo`;o000000?o
ooooo`000?l000001Ol00002ooooo`;o00004Oooool2o`0000Oooooo0_l0001hooooo`007?ooool0
0ol0003oooooooooo`1^ooooo`;o00002_ooool2o`0001Sooooo0_l000000ooooooo0000o`000005
ooooo`;o00000_ooool2o`0000;ooooo0_l00002ooooo`Oo00000_ooool2o`0001[ooooo0ol0001g
ooooo`007?ooool00ol0003oooooooooo`1]ooooo`Go00001?ooool2o`0000?ooooo0ol0000Ioooo
o`;o00001Oooool2o`0000Cooooo1?l00003ooooo`Go000000Coooooo`000?l0003ooooo0_l0000J
ooooo`;o0000Moooool001cooooo00?o0000ooooooooool0JOooool2o`0000;ooooo0_l000000ooo
oooo0000o`000004ooooo`;o00000oooool5o`0000gooooo0_l00008ooooo`;o00001Oooool2o`00
00Cooooo0_l00005ooooo`So000000?oooooo`000?l000007oooool2o`0007;ooooo000Looooo`03
o`000?oooooooooo06Sooooo2?l00003ooooo`;o00001_ooool2o`000003ooooool0003o000000_o
oooo1?l0000;ooooo`;o00000_ooool4o`0000;ooooo0_l00003ooooo`go00007oooool2o`0007;o
oooo000Looooo`03o`000?oooooooooo06Sooooo0_l000000ooooooo0000o`000003o`0000?ooooo
0_l00005ooooo`?o00003_ooool2o`0000gooooo0_l00004ooooo`;o00000_oooolDo`00097ooooo
000Looooo`;o0000J?ooool4o`0000cooooo0_l000000ooooooo0000o`00000?ooooo`;o00001ooo
ool2o`0000[ooooo0_l00002oooooaCo000000?oooooo`000?l000005Oooool2o`0007Oooooo000L
ooooo`03o`000?oooooooooo06Kooooo1ol00006ooooo`;o000000Coooooo`000?l0003o00004_oo
ool2o`0000Oooooo0_l0000>oooooaCo000000?oooooo`000?l000005Oooool2o`0007Oooooo000L
ooooo`03o`000?oooooooooo06Gooooo0ol00003ooooo`Co00001?ooool5o`0001?ooooo0_l0000C
ooooo`;o00000ooooolCo`0000Cooooo0_l0000Eooooo`;o0000M?ooool001cooooo00?o0000oooo
ooooool0I?ooool3o`0000Gooooo0ol00005ooooo`;o00005Oooool2o`0000Sooooo0_l00005oooo
o`;o00000_oooolGo`0000Gooooo0_l0000Eooooo`;o0000M?ooool001cooooo00?o0000oooooooo
ool0I?ooool5o`0000?ooooo0_l0000Aooooo`;o00005?ooool2o`0000Gooooo0_l00004oooooaKo
0000TOooool001cooooo00?o0000ooooooooool0H_ooool2o`000003ooooool0003o000000;o0000
5_ooool4o`0001oooooo0ol000000ooooooo0000o`00000:o`000003ooooool0003o000000?o0000
8Oooool2o`0006kooooo000Looooo`03o`000?oooooooooo067ooooo0ol00003ooooo`;o00006?oo
ool2o`0000Kooooo0ol0000FoooooaOo00008?ooool2o`0006kooooo000Looooo`03o`000?oooooo
oooo05gooooo1ol00003ooooo`;o00003oooool2o`0000oooooo0ol0000>ooooo`?o00001_oooolF
o`00093ooooo000Looooo`03o`000?oooooooooo05gooooo3?l0000?ooooo`;o00003oooool2o`00
00oooooo0ol00008oooooa?o00009Oooool2o`0006[ooooo000Looooo`03o`000?oooooooooo067o
oooo2?l00009ooooo`;o00002oooool2o`0000Oooooo0ol0000;ooooo`;o00000_ooool2o`0000[o
oooo4ol0000Tooooo`;o0000J_ooool001cooooo00?o0000ooooooooool0G_ooool2o`0000Cooooo
0_l00003ooooo`;o000000?oooooo`000?l000001?ooool2o`0000_ooooo0_l00005ooooo`Go0000
2oooool2o`0000oooooo4_l000000ooooooo0000o`00002=ooooo`007?ooool00ol0003ooooooooo
o`1Jooooo`;o00000_ooool2o`0000Wooooo0_l000000ooooooo0000o`00000Aooooo`;o00000_oo
ool7o`0001gooooo5ol0002;ooooo`007?ooool00ol0003oooooooooo`1Iooooo`?o00004?ooool3
o`0000;ooooo1?l00003ooooo`;o00001Oooool2o`0000;ooooo1Ol00002ooooo`;o00003oooool3
o`0000_ooooo4_l000000ooooooo0000o`00002;ooooo`007?ooool00ol0003oooooooooo`1Ioooo
o`;o00000oooool2o`0000cooooo0ol000000ooooooo0000o`000003o`0000?ooooo1?l00005oooo
o`Ko00000oooool2o`0000[ooooo0_l00003ooooo`?o00002ooooolBo`0008kooooo000Looooo`03
o`000?oooooooooo05Oooooo1?l00003ooooo`;o00004?ooool4o`0000Kooooo0_l00005ooooo`Co
00000_ooool2o`0000gooooo0_l00005ooooo`;o00002oooool?o`000003ooooool0003o000000?o
oooo0_l00028ooooo`007?ooool00ol0003oooooooooo`1Gooooo`Co00005oooool2o`0000Gooooo
0_l00006ooooo`;o00001?ooool2o`0001Cooooo0_l0000;oooooa;o00000oooool2o`0008Sooooo
000Looooo`;o0000FOooool3o`0001Kooooo1ol000000ooooooo0000o`000005ooooo`?o00001?oo
ool2o`0001Cooooo0_l0000;ooooo`?o000000?oooooo`000?l000003?l0002=ooooo`007?ooool0
0ol0003oooooooooo`1Eooooo`;o00000_ooool2o`0001;ooooo0_l00002ooooo`Wo00001_ooool3
o`0000Cooooo0_l0000Dooooo`;o00004Oooool9o`000003ooooool0003o000001;ooooo0_l0001i
ooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o000000?oooooo`000?l000000_l00002oooo
o`;o00004_ooool2o`0000Gooooo3ol00004ooooo`Co00002_ooool3o`0001Sooooo2Ol00002oooo
o`;o00000oooool2o`0000Oooooo0_l00003ooooo`;o0000NOooool001cooooo00?o0000oooooooo
ool0D?ooool7o`0000[ooooo0_l00009ooooo`?o00002?ooool2o`000003ooooool0003o000000Go
00001_ooool4o`0000[ooooo0ol0000Rooooo`Go000000?oooooo`000?l000001oooool2o`0000Oo
oooo0_l0001eooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o00003_ooool2o`0000Wooooo
0ol00008ooooo`;o00001?ooool4o`0000Kooooo0_l0000Hooooo`;o00003?ooool2o`0000Wooooo
0_l000001?oooooo0000o`000?ooool2o`00013ooooo0_l0001eooooo`007?ooool00ol0003ooooo
ooooo`1Dooooo`;o00000oooool2o`0000Wooooo0_l00004ooooo`Co00003oooool4o`0000Kooooo
0_l0000=ooooo`;o00002Oooool2o`0000cooooo0_l0000:ooooo`;o00003_ooool3o`0000Cooooo
0_l0001eooooo`007?ooool00ol0003oooooooooo`1Booooo`Co00000oooool2o`0000Oooooo1?l0
0004ooooo`Ko00005_ooool2o`0000kooooo1Ol00007ooooo`;o00002?ooool5o`0000Cooooo0ol0
0003ooooo`;o00002_ooool2o`0000;ooooo0ol00003ooooo`;o0000M_ooool001cooooo00?o0000
ooooooooool0D_ooool3o`0000Wooooo0_l00002ooooo`;o00001?ooool2o`0000Cooooo0_l0000?
ooooo`?o00001?ooool3o`0000kooooo1?l00007ooooo`;o00002?ooool5o`000003ooooool0003o
000000Co00003oooool2o`0000Sooooo0_l0001fooooo`007?ooool00ol0003oooooooooo`1?oooo
o`;o00000_ooool3o`0000Sooooo0_l00007ooooo`?o00005Oooool3o`0000Gooooo0ol0000@oooo
o`;o00002?ooool2o`0000Kooooo0ol00003ooooo`?o00009Oooool2o`0006gooooo000Looooo`03
o`000?oooooooooo04Sooooo0_l00005ooooo`;o00000oooool4o`0000Wooooo0ol000000ooooooo
0000o`000002o`0000;ooooo0_l00006ooooo`;o00004oooool2o`00013ooooo0_l00007ooooo`?o
00001oooool2o`0001kooooo0ol00008ooooo`Co0000KOooool001cooooo00?o0000ooooooooool0
B?ooool2o`0000Gooooo0_l00005ooooo`;o00002Oooool3o`000003ooooool0003o000000;o0000
0_ooool2o`0000Kooooo0_l00003ooooo`;o00000oooool2o`0002;ooooo2?l0000Pooooo`Oo0000
1Oooool2o`000003ooooool0003o000006oooooo000Looooo`03o`000?oooooooooo04Oooooo0ol0
0005ooooo`;o00003Oooool2o`0000Oooooo0_l00003ooooo`?o00002?ooool<o`0000?ooooo1?l0
000Gooooo`;o000000?oooooo`000?l000000ol00008ooooo`;o00005_ooool4o`0000Oooooo0ol0
00000ooooooo0000o`000004o`0000Wooooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`15
ooooo`Co00002?ooool2o`0000;ooooo0_l00005ooooo`Co000000?oooooo`000?l000001_ooool2
o`000004ooooool0003o0000o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l000001ol0
0002ooooo`Go00000_ooool2o`0000gooooo1?l00006ooooo`;o00000oooool2o`0000Gooooo0_l0
000Jooooo`;o00000_ooool5o`0000?ooooo1Ol00009ooooo`;o0000H?ooool001cooooo00?o0000
ooooooooool0AOooool2o`0000[ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool3
o`0000;ooooo0_l00004ooooo`Ko00001?ooool4o`0000Sooooo0_l00002ooooo`;o00000_ooool4
o`0000?ooooo0_l0000=ooooo`Co00001_ooool2o`0000?ooooo0_l0000Pooooo`Wo00000oooool4
o`0006gooooo000Looooo`03o`000?oooooooooo04Cooooo0_l00004ooooo`;o00002oooool3o`00
00_ooooo1Ol000000ooooooo0000o`000004ooooo`?o00002Oooool2o`0000;ooooo0_l00004oooo
o`;o00007_ooool2o`000004ooooool0003o0000ooooo`;o00006?ooool2o`000003ooooool0003o
000000Oo00000_ooool2o`000004ooooool0003o0000o`0006kooooo000Looooo`03o`000?oooooo
oooo04Cooooo0_l00004ooooo`;o00002oooool2o`0000Sooooo0ol000001Ooooooo0000o`000?l0
003ooooo00;o00000oooool5o`0000;ooooo0ol00004ooooo`Go00001?ooool2o`00023ooooo0_l0
00001?oooooo0000o`000?ooool2o`000004ooooool0003o0000o`0001?ooooo3Ol000001Ooooooo
0000o`000?l0003ooooo00?o000000?oooooo`000?l000000_l0001Yooooo`007?ooool2o`0005Go
oooo0_l0000:ooooo`Go00000_ooool4o`0000?ooooo1Ol00002ooooo`Co00000oooool;o`0000Oo
oooo0ol0000=ooooo`;o00004?ooool3o`0000?ooooo0_l00003ooooo`;o00001oooool?o`000003
ooooool0003o000000Go000000?oooooo`000?l000000ol0001Xooooo`007?ooool00ol0003ooooo
ooooo`1Dooooo`;o00000oooool2o`0000?ooooo1?l000000ooooooo0000o`000002ooooo`;o0000
1oooool2o`0000Gooooo0_l00003ooooo`_o000000?oooooo`000?l000000_ooool5o`0000cooooo
0ol0000>ooooo`Ko00000_ooool4o`000003ooooool0003o000000Oooooo1?l000000ooooooo0000
o`000008o`0000?ooooo1?l00003ooooo`Co000000?oooooo`000?l00000IOooool001cooooo00?o
0000ooooooooool0D?ooool2o`0000Oooooo0_l00003ooooo`Go00000_ooool4o`0001?ooooo2Ol0
0003ooooo`;o000000?oooooo`000?l000001?l0000<ooooo`;o000000?oooooo`000?l000001Ooo
ool2o`0000Cooooo2_l000001?oooooo0000o`000?l0000;ooooo`oo000000?oooooo`000?l00000
0_l00008ooooo`;o0000IOooool001cooooo00?o0000ooooooooool0D?ooool2o`0000;ooooo0_l0
00000ooooooo0000o`000005o`0000;ooooo0ol000001?oooooo0000o`000?l0000Dooooo`So0000
1?ooool3o`000003ooooool0003o000000?o00004?ooool2o`0000Gooooo0_l00004ooooo`?o0000
0oooool4o`0000;ooooo0_l0000:oooooaSo00000_ooool2o`0000;ooooo0_l00004ooooo`;o0000
G_ooool001cooooo00?o0000ooooooooool0DOooool2o`000003ooooool0003o000000So00000_oo
ool6o`0000oooooo0_l00004ooooo`So00000_ooool4o`0000?ooooo0_l0000Uooooo`Co00003_oo
oolHo`0000;ooooo0_l00002ooooo`;o00001?ooool3o`0005gooooo000Looooo`03o`000?oooooo
oooo047ooooo0_l0000:ooooo`;o000000?oooooo`000?l000004_l0000;ooooo`Co00000_ooool2
o`000003ooooool0003o000000Cooooo1Ol00002ooooo`;o00000_ooool2o`0002Sooooo1?l0000=
oooooaSo00001oooool2o`0000Gooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`11oooo
o`Co00002?ooool2o`000004ooooool0003o0000ooooo`;o00001?ooool2o`000003ooooool0003o
000000Ko00000oooool2o`0000Cooooo1_l00002ooooo`;o000000Coooooo`000?l0003o00001?oo
ool8o`0000;ooooo0_l0000Eooooo`;o00007oooool2o`000003ooooool0003o000001Ko00001ooo
ool2o`00013ooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`11ooooo`Go00001Oooool2
o`0000oooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0ol00003ooooo`;o00002_oo
ool2o`000003ooooool0003o000000?ooooo1?l00004ooooo`;o00000oooool2o`00013ooooo0_l0
0003ooooo`;o00003oooool2o`0000?ooooo0_l00004oooooaco000000?oooooo`000?l000005Ooo
ool2o`0005;ooooo000Looooo`03o`000?oooooooooo047ooooo0_l000000ooooooo0000o`000005
ooooo`;o00006oooool2o`0001;ooooo0ol00004ooooo`;o000000?oooooo`000?l000000oooool2
o`000003ooooool0003o000001Gooooo0_l00008ooooo`;o00001Oooool2o`000003ooooool0003o
000000;o00000oooool2o`000003ooooool0003o000001_o00004oooool2o`000003ooooool0003o
0000057ooooo000Looooo`03o`000?oooooooooo04?ooooo0_l00004ooooo`;o00001_ooool2o`00
02[ooooo0_l00003ooooo`?o000000?oooooo`000?l000000oooool2o`0001Wooooo0_l00007oooo
o`;o00002?ooool2o`0000Gooooo0_l000000ooooooo0000o`00000Ko`0000[ooooo0_l00007oooo
o`Go0000DOooool001cooooo00?o0000ooooooooool0?Oooool2o`0000Cooooo0_l00004ooooo`Co
00001?ooool2o`0002oooooo1Ol0000;ooooo`;o00003Oooool2o`0000?ooooo1?l00007ooooo`;o
00003Oooool2o`000003ooooool0003o000001So00002oooool4o`0000Sooooo0_l0000<ooooo`;o
0000AOooool001cooooo00?o0000ooooooooool0??ooool4o`0000;ooooo0ol00005ooooo`?o0000
00?oooooo`000?l00000<oooool4o`000003ooooool0003o000000;o00001_ooool2o`0000gooooo
0_l00003ooooo`Co00001oooool2o`0000Oooooo0_l00004ooooo`;o000000?oooooo`000?l00000
6?l0000;ooooo`;o00001oooool2o`0000Kooooo0ol00006ooooo`?o0000A?ooool001cooooo00?o
0000ooooooooool0??ooool4o`0000;ooooo0ol00005ooooo`;o00000_ooool2o`0003?ooooo0_l0
00000ooooooo0000o`000004o`0000?ooooo0ol0000Xooooo`;o00002?oooolIo`0000;ooooo0_l0
000@ooooo`;o00001_ooool3o`0000Oooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`13
ooooo`;o00001Oooool4o`0003Oooooo1_l00004ooooo`?o000000?oooooo`000?l000000_l0000D
ooooo`;o00003oooool2o`0000?ooooo7?l00002ooooo`;o00008_ooool2o`0004Cooooo00001_oo
ooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?oo
ool00ol0003oooooooooo`0iooooo`;o00001Oooool2o`0000Kooooo1_l0000gooooo`;o00000_oo
ool5o`000005ooooool0003o0000o`000?ooool01?l0000Dooooo`;o00003ooooolPo`000003oooo
ool0003o000000Sooooo0_l000000ooooooo0000o`00000@ooooo`;o00001Oooool2o`0004Cooooo
00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0>Oooool2o`0000Gooooo0_l00006ooooo`Go0000>oooool6o`0000;o
oooo0_l0000/ooooo`Co00000_oooolKo`0000Sooooo0_l000000ooooooo0000o`00000@ooooo`;o
000000?oooooo`000?l00000B?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool0
2Oooool5o`0000Kooooo00?o0000ooooooooool0@Oooool3o`0000Cooooo0_l0000mooooo`?o0000
0oooool2o`0000?ooooo0_l0000Eooooo`;o00005?ooool2o`0000?ooooo6ol0000Pooooo`;o0000
B?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?m4A4CogMgMoooo
ool00007ooooo`?o0000>?ooool2o`0000Gooooo1Ol00004ooooo`;o00008_ooool2o`0001Sooooo
0ol00004ooooo`;o00000_ooool3o`0000?ooooo0_l0000@ooooo`;o00003_ooool2o`0000;ooooo
0_l00005oooooaOo000000Coooooo`000?l0003o00000oooool2o`0000Cooooo0ol0001Nooooo`00
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oo
oooo00?o0000ooooooooool0>?ooool2o`0000Gooooo0_l0000[ooooo`;o00006?ooool2o`0000?o
oooo1?l00002ooooo`;o00000oooool3o`00023ooooo0_l00002ooooo`;o00000oooool@o`000003
ooooool0003o000000Ko000000Coooooo`000?l0003o00000oooool2o`000003ooooool0003o0000
00Co00006oooool2o`00047ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[o
oooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0oooooo`;o00009oooool3o`0000Oo
oooo0_l0000Eooooo`Ko00000oooool2o`0000;ooooo0_l0000:ooooo`;o00002oooool2o`00017o
oooo0_l00002ooooo`co000000?oooooo`000?l000001_l00006ooooo`;o00000_ooool4o`0001go
oooo0_l00011ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co0000
00Oooooo00?o0000ooooooooool0?oooool2o`0002;ooooo2?l00007ooooo`;o00005Oooool7o`00
00;ooooo0_l0000>ooooo`?o00002_ooool2o`0000Gooooo0_l00009ooooo`?o00000_ooool>o`00
0003ooooool0003o000000?o00001oooool2o`0002?ooooo0_l00011ooooo`0000Koooooonk^k_lb
<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0=?ooool3
o`0000Oooooo0_l00002ooooo`Co00007Oooool8o`0000Oooooo0_l00002ooooo`Go00004Oooool4
o`0000;ooooo0_l00003ooooo`;o00002_ooool2o`0000?ooooo0_l0000<ooooo`;o00002Oooool3
o`0000;ooooo3_l000000ooooooo0000o`000002o`0000Oooooo0_l0001Wooooo`007?ooool00ol0
003oooooooooo`0cooooo`Co00001oooool2o`0000;ooooo1?l0000Eooooo`?o00001Oooool2o`00
017ooooo1Ol000000ooooooo0000o`00000@ooooo`;o00000oooool2o`0000;ooooo0_l0000:oooo
o`;o00000oooool2o`0000Oooooo0_l0000Cooooo`Ko000000?oooooo`000?l000002_l00007oooo
o`;o00009Oooool2o`00043ooooo000Looooo`03o`000?oooooooooo03?ooooo0_l0000Tooooo`Go
00003oooool2o`0000_ooooo1?l0000@ooooo`;o00000oooool2o`0000kooooo0_l00003ooooo`;o
00001oooool3o`00017ooooo0_l000000ooooooo0000o`000002o`0000;ooooo2_l0000;ooooo`;o
00002?ooool2o`0001Sooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0looooo`;o0000
5Oooool5o`000003ooooool0003o000000kooooo0ol000000ooooooo0000o`000006o`0000Gooooo
0_l000000ooooooo0000o`000002o`000003ooooool0003o000000[ooooo0_l00005ooooo`;o0000
6oooool2o`00017ooooo0_l00002oooooa3o00002_ooool4o`0000Kooooo0_l0000Hooooo`;o0000
@?ooool001cooooo00?o0000ooooooooool0??ooool2o`0001?ooooo2Ol0000;ooooo`Oo000000?o
ooooo`000?l000001_l00008ooooo`Co000000?oooooo`000?l000002oooool2o`0000Cooooo0_l0
0002ooooo`Co000000?oooooo`000?l000005?ooool3o`0000Sooooo0_l00002ooooo`;o00001?oo
ool9o`000003ooooool0003o000000Co00001?ooool2o`0000?ooooo1Ol0000Pooooo`;o0000@?oo
ool001cooooo00?o0000ooooooooool0=oooool2o`0000?ooooo0_l0000Cooooo`;o00001?ooool3
o`0000[ooooo1_l00005ooooo`?o00000_ooool6o`0000Sooooo0_l0000;ooooo`;o000000Cooooo
o`000?l0003o00001?ooool4o`000003ooooool0003o000001?ooooo1?l00004ooooo`;o00000_oo
ool2o`0000;ooooo0_l0000;ooooo`Ko00001oooool2o`0000?ooooo1?l0001Sooooo`007?ooool0
0ol0003oooooooooo`0gooooo`;o00000oooool2o`0002Kooooo1ol00005ooooo`;o00000_ooool6
o`0001Oooooo1?l00002ooooo`;o000000?oooooo`000?l000003?ooool3o`0000Sooooo0_l00006
ooooo`;o00002?ooool3o`0000Sooooo1ol0000;ooooo`;o0000IOooool001cooooo00?o0000oooo
ooooool0<_ooool2o`0000Sooooo0_l0000@ooooo`;o00001?ooool2o`0000[ooooo1Ol000000ooo
oooo0000o`000003o`0000gooooo1?l00005ooooo`;o00003_ooool3o`0000?ooooo0_l000000ooo
oooo0000o`000008ooooo`;o00000_ooool3o`0000Sooooo0_l0000@ooooo`?o00002?ooool2o`00
00?ooooo0_l0000:ooooo`Co00008Oooool4o`0003oooooo000Looooo`03o`000?oooooooooo03;o
oooo0_l0000Jooooo`;o00000_ooool4o`0000Wooooo1ol000000ooooooo0000o`000005ooooo`;o
000000Coooooo`000?l0003ooooo0ol00003ooooo`Co00000oooool2o`00027ooooo1?l0000;oooo
o`;o00004_ooool2o`000003ooooool0003o000000[ooooo0_l00009ooooo`Co00008Oooool4o`00
03oooooo000Looooo`03o`000?oooooooooo03;ooooo0_l0000Nooooo`;o00002oooool7o`000003
ooooool0003o000000;ooooo1Ol000000ooooooo0000o`000005o`0000?ooooo0ol00005ooooo`;o
00000_ooool2o`00013ooooo0_l0000;ooooo`;o00002oooool2o`0001;ooooo1Ol0000:ooooo`;o
00002_ooool2o`0006Gooooo000Looooo`03o`000?oooooooooo03;ooooo0_l00003ooooo`;o0000
4_ooool2o`00017ooooo1Ol00007ooooo`Go000000?oooooo`000?l000002Ol000000ooooooo0000
o`000002o`0000?ooooo0_l00002ooooo`;o00004?ooool2o`0000Gooooo0_l0000Aooooo`;o0000
1Oooool2o`0000cooooo0_l0000Gooooo`?o0000IOooool001cooooo00?o0000ooooooooool0=ooo
ool2o`0001;ooooo0_l00003ooooo`;o00003?ooool5o`0000Gooooo1Ol00003oooooa3o00001?oo
ool2o`0001?ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`000?l00000
3_ooool2o`000003ooooool0003o000000;ooooo0_l0000Uooooo`;o0000I_ooool001cooooo0_l0
001Aooooo`;o00002oooool4o`000003ooooool0003o000000?ooooo0ol00004oooooa?o00000ooo
ool2o`0001Kooooo0ol00004ooooo`;o00003_ooool2o`000003ooooool0003o000000Kooooo0_l0
000?ooooo`;o000000?oooooo`000?l000002?ooool2o`0000Cooooo0_l0001Uooooo`007?ooool0
0ol0003oooooooooo`0iooooo`;o00008_ooool4o`000003ooooool0003o000000?ooooo0_l00002
oooooaOo00000_ooool3o`0003Oooooo0_l0000?ooooo`;o000000?oooooo`000?l000002?ooool2
o`0000Cooooo0_l0000Uooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0>Oooool2o`00
01?ooooo0_l0000=ooooo`?o00000_ooool2o`000003ooooool0003o000001_o00000oooool2o`00
01Cooooo0ol0000@ooooo`Co00005_ooool2o`0000;ooooo1?l00005ooooo`;o0000<_ooool2o`00
03kooooo000Looooo`03o`000?oooooooooo04kooooo0_l0000=ooooo`?o00001Oooool3o`000003
ooooool0003o000001So00000_ooool2o`0000;ooooo0_l0000@ooooo`Go00003Oooool5o`0001Ko
oooo0_l00002ooooo`Co00001?ooool3o`0000Sooooo0_l0001Xooooo`007?ooool00ol0003ooooo
ooooo`1>ooooo`;o00003Oooool5o`0000;ooooo6_l000000ooooooo0000o`000002o`0000;ooooo
0_l00002ooooo`;o00004oooool3o`0000[ooooo1ol00003ooooo`;o00005?ooool2o`0000Oooooo
1Ol00006ooooo`;o00009oooool2o`0003oooooo000Looooo`03o`000?oooooooooo03Sooooo0_l0
000Rooooo`?o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000001Go00000_oo
ool3o`0000;ooooo0_l0000Dooooo`;o000000?oooooo`000?l000000_l00008ooooo`So00000ooo
ool2o`0001Cooooo0_l00003ooooo`?o00000oooool5o`0002gooooo0_l0000oooooo`007?ooool0
0ol0003oooooooooo`0^ooooo`;o00002?ooool2o`00027ooooo1?l00003ooooo`?o00000_oooolM
o`0000;ooooo0ol0000Booooo`;o00000oooool2o`0000?ooooo3?l00004ooooo`;o00006?ooool6
o`0000?ooooo1_l00002ooooo`?o0000@?ooool2o`0002Cooooo000Looooo`03o`000?oooooooooo
02kooooo0_l00003ooooo`;o00000oooool2o`00027ooooo0_l00005ooooob;o00000_ooool3o`00
01Oooooo1?l000000ooooooo0000o`000005o`0000;ooooo0ol00004ooooo`?o00005oooool2o`00
00;ooooo0ol00005ooooo`So000000?oooooo`000?l000009?ooool2o`0001Oooooo0_l0000Toooo
o`007?ooool00ol0003oooooooooo`0^ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o
00004_ooool2o`0000gooooo0_l00005ooooob;o00000_ooool2o`000003ooooool0003o000001Ko
oooo0ol000000ooooooo0000o`000005o`0000;ooooo1?l00003ooooo`?o00006oooool5o`0000Co
oooo1_l00002ooooo`;o00001_ooool2o`0001cooooo0_l0000Gooooo`;o00009?ooool001cooooo
00?o0000ooooooooool0<Oooool4o`0000?ooooo0_l0000Aooooo`?o00003Oooool3o`0000Cooooo
1?l00002oooooaco00001Oooool2o`0001cooooo0_l00007ooooo`;o00007?ooool2o`0000;ooooo
0ol000000ooooooo0000o`000004ooooo`Co00001?ooool2o`0000Kooooo0_l0001Kooooo`007?oo
ool00ol0003oooooooooo`0/ooooo`;o00001Oooool2o`0000?ooooo0_l0000Aooooo`;o00003_oo
ool4o`0000;ooooo1?l000000ooooooo0000o`00000Mo`0000Cooooo0_l00002ooooo`;o00003Ooo
ool2o`000004ooooool0003o0000ooooo`;o00003?ooool2o`0001cooooo0_l00002ooooo`;o0000
00?oooooo`000?l000001_ooool2o`0006[ooooo000Looooo`03o`000?oooooooooo02cooooo0_l0
000:ooooo`;o00004Oooool2o`0000kooooo1?l00002ooooobCo00002?ooool2o`0000gooooo0_l0
00001?oooooo0000o`000?ooool3o`0000_ooooo0_l0000Kooooo`;o00000oooool2o`000003oooo
ool0003o000000;o0000L?ooool001cooooo00?o0000ooooooooool0>?ooool3o`0000Wooooo0_l0
0005ooooo`;o00003_ooool2o`000003ooooool0003o000000?ooooo1_l000000ooooooo0000o`00
000Io`000003ooooool0003o000000;o00000oooool2o`0000cooooo0_l00002ooooo`;o000000Co
ooooo`000?l0003o00001_ooool2o`0000?ooooo1?l00003ooooo`;o00005?ooool2o`0000?ooooo
0_l00003ooooo`Co00000_ooool2o`0002_ooooo0_l0000mooooo`007?ooool00ol0003ooooooooo
o`0[ooooo`;o00001_ooool2o`0000?ooooo0ol00009ooooo`;o00001?ooool2o`0000kooooo1_l0
0004ooooo`Co000000?oooooo`000?l000006_l000000ooooooo0000o`000004o`000003ooooool0
003o000000cooooo0_l00002ooooo`;o00002?ooool5o`0000?ooooo0ol00003ooooo`;o00005_oo
ool2o`0000?ooooo0_l00003ooooo`?o000000?oooooo`000?l000003Oooool2o`0001cooooo0_l0
000mooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o00000_ooool2o`0000;ooooo0_l00003
ooooo`?o00003oooool2o`0000kooooo1Ol00002ooooo`;o000000?oooooo`000?l000006_l00000
0ooooooo0000o`000002o`0000;ooooo1Ol0000Cooooo`Wo000000Coooooo`000?l0003ooooo0_l0
0003ooooo`?o00001Oooool2o`0001?ooooo1?l00002ooooo`Co00000_ooool3o`0000_ooooo0_l0
0002ooooo`;o0000Foooool001cooooo00?o0000ooooooooool0:oooool2o`0000;ooooo1?l00006
ooooo`;o00002_ooool2o`0001?ooooo1Ol00002ooooo`;o00000_oooolMo`000005ooooool0003o
0000o`000?ooool01?l0000Dooooo`Wo00002Oooool5o`0000?ooooo0_l0000Cooooo`Co00000ooo
ool3o`0000;ooooo0ol0000;ooooo`;o0000Goooool001cooooo0_l0000booooo`;o00001Oooool2
o`0000_ooooo0_l0000Dooooo`;o00001?oooolQo`000005ooooool0003o0000o`000?ooool01?l0
0004ooooo`;o00003_ooool2o`0000_ooooo0_l000000ooooooo0000o`000002ooooo`?o00006Ooo
ool2o`0000[ooooo0_l0001/ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00002_ooool2
o`0000Sooooo0_l0000;ooooo`Co00000ooooolLo`000004ooooool0003o0000ooooo`Co00002Ooo
ool2o`0000kooooo0_l0000;ooooo`;o000000Coooooo`000?l0003o00000_ooool3o`0000;ooooo
0ol00009ooooo`;o00000oooool2o`0001[ooooo0_l0000looooo`;o00008oooool001cooooo00?o
0000ooooooooool0=_ooool2o`0000cooooo0_l00008ooooo`;o00002oooool5o`000003ooooool0
003o000001ko000000?oooooo`000?l000000_l00008ooooo`;o00003Oooool2o`0000?ooooo0_l0
000<ooooo`;o00000oooool3o`000003ooooool0003o000000;o00002?ooool2o`0000?ooooo0_l0
0006ooooo`;o00004_ooool2o`0003cooooo0_l0000Sooooo`007?ooool00ol0003oooooooooo`0f
ooooo`;o00004_ooool2o`0000oooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0
003o000001co000000Coooooo`000?l0003o00001?ooool2o`0000;ooooo0ol0000<ooooo`;o0000
00?oooooo`000?l000000_l0000@ooooo`Co00000_ooool3o`000004ooooool0003o0000o`0000oo
oooo1?l000000ooooooo0000o`000005ooooo`;o0000Joooool001cooooo00?o0000ooooooooool0
=oooool3o`00013ooooo0_l0000@ooooo`;o00001Oooool3o`000003ooooool0003o000001?o0000
00?oooooo`000?l000000ol000000ooooooo0000o`000002o`0000;ooooo0ol00003ooooo`;o0000
3oooool2o`0000Gooooo0_l0000;ooooo`;o00001?ooool3o`000004ooooool0003o0000o`0000Oo
oooo0_l00006ooooo`?o00000_ooool2o`0000Gooooo0_l0000<ooooo`;o0000GOooool001cooooo
00?o0000ooooooooool0<?ooool2o`0000Gooooo0ol0000Qooooo`?o00001Oooool>o`000003oooo
ool0003o000000So00000oooool<o`0001Gooooo0_l00005ooooo`;o00004Oooool3o`0000_ooooo
0_l00005ooooo`Co00001?ooool5o`000004ooooool0003o0000o`0000[ooooo0_l0001Mooooo`00
7?ooool00ol0003oooooooooo`0Yooooo`;o00001Oooool2o`0000Kooooo0_l0000Eooooo`;o0000
2_ooool3o`0000Kooooo4_l00003oooooa;o00001?ooool4o`0001gooooo0_l00002ooooo`Go0000
0_ooool2o`0000[ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`000003oooo
ool0003o000000[o0000@?ooool2o`0002Gooooo000Looooo`03o`000?oooooooooo02Sooooo0ol0
000=ooooo`;o00005Oooool2o`0000_ooooo1?l00004oooooa;o00000oooool=o`000004ooooool0
003o0000o`0000Gooooo1?l00007ooooo`?o00003oooool2o`0000;ooooo0_l000000ooooooo0000
o`000004o`0000kooooo0_l00003ooooo`?o00001?ooool7o`000003ooooool0003o000000Go0000
3?ooool2o`0003;ooooo0_l0000Uooooo`007?ooool00ol0003oooooooooo`0Xooooo`;o00008ooo
ool2o`0000Gooooo0_l00007ooooo`?o00001Oooool4o`000003ooooool0003o000001Ko000000Go
ooooo`000?l0003o0000ooooo`03o`0000Sooooo0_l00006ooooo`?o00001?ooool2o`0000Wooooo
1?l00003ooooo`;o00005oooool3o`0000Kooooo3Ol0000<ooooo`?o00005oooool2o`0003oooooo
000Looooo`03o`000?oooooooooo04Sooooo0ol00002ooooo`;o00001Oooool2o`0000Oooooo1Ol0
0003ooooo`Go000000?oooooo`000?l000001_l000000ooooooo0000o`00000Co`0000Oooooo1?l0
0004ooooo`Co00001Oooool2o`0000_ooooo0_l0000>ooooo`;o00003oooool2o`0000Kooooo3_l0
0009ooooo`?o00005_ooool3o`0003oooooo000Looooo`03o`000?oooooooooo043ooooo0_l00006
ooooo`?o000000?oooooo`000?l000004?ooool4o`0000Cooooo8Ol00009ooooo`;o00001_ooool5
o`0001_ooooo0_l000000ooooooo0000o`000003o`0000oooooo0_l00003ooooo`;o00000_ooool@
o`0000Kooooo0ol0000Fooooo`;o00005oooool2o`0002Oooooo000Looooo`03o`000?oooooooooo
043ooooo0_l0000:ooooo`;o00001_ooool3o`0000Wooooo1?l00002oooooa_o000000?oooooo`00
0?l000001Ol00007ooooo`;o00001oooool4o`0000;ooooo0_l0000Gooooo`Oo00004oooool7o`00
0003ooooool0003o000000Ko000000?oooooo`000?l000000ol00006ooooo`?o0000;oooool2o`00
02Oooooo000Looooo`03o`000?oooooooooo033ooooo0_l0000>ooooo`;o00001_ooool3o`0000Wo
oooo0ol00009ooooo`Ko000000?oooooo`000?l000000_l000000ooooooo0000o`000007o`0000;o
oooo0_l000000ooooooo0000o`000006o`0000;ooooo1Ol0000Fooooo`;o00005_ooool2o`000004
ooooool0003o0000ooooo`;o00004oooool@o`000003ooooool0003o000000Co00001_ooool3o`00
01Cooooo0_l0000Gooooo`;o0000:?ooool001cooooo00?o0000ooooooooool0<?ooool4o`0001Co
oooo0ol000000ooooooo0000o`000004ooooo`;o00003?ooool6o`0000?ooooo0_l000000ooooooo
0000o`000007o`000003ooooool0003o000000[o00003?ooool2o`0000?ooooo0_l0000Nooooo`;o
00000_ooool4o`0000;ooooo0_l00007ooooo`;o000000?oooooo`000?l000001Oooool2o`000003
ooooool0003o000001Co00000_ooool2o`0000?ooooo1?l0000Booooo`;o00005oooool2o`0002So
oooo000Looooo`03o`000?oooooooooo033ooooo1?l0000Hooooo`;o00001?ooool2o`0000kooooo
0ol00004ooooo`;o00000ooooolCo`0000gooooo0_l00003ooooo`Co000000?oooooo`000?l00000
0oooool2o`000003ooooool0003o0000017ooooo0_l00002ooooo`Go00001Oooool2o`0000?ooooo
0_l000000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l000004_l00004ooooo`;o0000
00?oooooo`000?l000000_ooool2o`0005Gooooo000Looooo`03o`000?oooooooooo033ooooo0_l0
00000ooooooo0000o`00000?ooooo`;o00007Oooool2o`0000Wooooo4ol0000Cooooo`Ko00000ooo
ool2o`000003ooooool0003o000000?o00004_ooool2o`000003ooooool0003o000000Gooooo0_l0
000Aooooo`_o000000?oooooo`000?l000001_l00006ooooo`;o0000;_ooool2o`0002Wooooo000L
ooooo`;o0000=?ooool2o`0000oooooo0_l0000Mooooo`;o000000?oooooo`000?l000001?ooool5
o`0000;ooooo1?l000000ooooooo0000o`000007o`0000oooooo2_l00006ooooo`Oo00002_ooool2
o`0000;ooooo0_l00005ooooo`;o00002_ooool2o`0000_ooooo2_l000000ooooooo0000o`000006
o`0003Kooooo0_l0000Yooooo`007?ooool00ol0003oooooooooo`1Iooooo`Co00002Oooool4o`00
00;ooooo1Ol000001?oooooo0000o`000?ooool3o`000004ooooool0003o0000ooooo`;o00001?oo
ool2o`0000?ooooo0_l00006ooooo`Ko00002oooool7o`0000[ooooo2?l00002ooooo`?o00002Ooo
ool3o`0000Wooooo5Ol0001Qooooo`007?ooool00ol0003oooooooooo`1Booooo`;o000000?ooooo
o`000?l000000_ooool6o`0000Sooooo0ol00004ooooo`Ko000000Goooooo`000?l0003o0000oooo
o`02o`000004ooooool0003o0000o`0000?ooooo0ol00002ooooo`;o00001?ooool5o`0000Cooooo
0_l00007ooooo`Wo00002oooool7o`000003ooooool0003o000000[ooooo0_l00008ooooo`[o0000
00?oooooo`000?l000003Ol000000ooooooo0000o`000006ooooo`;o00003_ooool2o`0001Kooooo
0_l0000[ooooo`007?ooool00ol0003oooooooooo`1Booooo`;o000000?oooooo`000?l000001?oo
ool4o`0000Wooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00000oooool2o`0000Kooooo
0_l00004ooooo`Co00000oooool5o`000003ooooool0003o000000Cooooo0_l00003ooooo`;o0000
0_ooool:o`0000oooooo0_l0000?ooooo`;o00001_oooolJo`000003ooooool0003o000000;ooooo
0_l00002ooooo`;o00002_ooool2o`0000;ooooo0_l0000Fooooo`;o0000:oooool001cooooo00?o
0000ooooooooool0Boooool2o`0000kooooo1?l0000<ooooo`?o000000?oooooo`000?l000000_oo
ool2o`00013ooooo0_l00003ooooo`Co00001_ooool2o`0000Gooooo0_l00002ooooo`[o00003Ooo
ool4o`0000oooooo0_l00007oooooaSo00001_ooool6o`0000Wooooo0ol00017ooooo`007?ooool0
0ol0003oooooooooo`0[ooooo`;o00006_ooool2o`0000;ooooo0_l00005ooooo`;o00000oooool3
o`0000?ooooo0_l000000ooooooo0000o`000002o`0000Oooooo0ol000000ooooooo0000o`000004
o`0000;ooooo0_l0000:ooooo`Go00003?ooool2o`0000Kooooo0_l000000ooooooo0000o`000009
o`0000cooooo1?l0000Booooo`;o00001?oooolFo`0000Oooooo0_l000000ooooooo0000o`00000;
ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0:oooool2o`0000?ooooo0_l000000ooo
oooo0000o`000002o`00013ooooo0_l00003ooooo`;o00001?ooool2o`0000?ooooo0ol00006oooo
o`Co000000?oooooo`000?l000000_ooool4o`0000Cooooo0_l00003ooooo`Go00000_ooool4o`00
00;ooooo1Ol0000:ooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`co00002Oooool7
o`00017ooooo1?l00002ooooo`;o00000ooooolAo`000003ooooool0003o000000Cooooo0ol0000;
ooooo`;o00006oooool2o`0002gooooo000Looooo`03o`000?oooooooooo033ooooo0_l000000ooo
oooo0000o`000002o`0001Gooooo1?l00008ooooo`;o000000?oooooo`000?l000001Oooool2o`00
0003ooooool0003o000000;ooooo0_l0000;ooooo`Go00000_ooool4o`0000Sooooo0_l00006oooo
o`?o00001?ooool3o`0000;ooooo3_l00003ooooo`;o00001?ooool7o`0000kooooo0_l00003oooo
o`;o00000oooool2o`000003ooooool0003o000001?o00001Oooool2o`000003ooooool0003o0000
00Sooooo0_l0000Jooooo`?o0000;Oooool001cooooo00?o0000ooooooooool0<oooool2o`0000co
oooo0_l0000;ooooo`;o00001oooool3o`000003ooooool0003o000000gooooo0_l0000Booooo`;o
00001Oooool3o`000003ooooool0003o000000Kooooo1?l00003ooooo`;o00000oooool>o`0000?o
oooo0_l00005ooooo`?o00003oooool4o`0000Sooooo5_l0000:ooooo`;o00009?ooool2o`0002ko
oooo000Looooo`03o`000?oooooooooo02[ooooo0_l0000Eooooo`;o00004oooool4o`000003oooo
ool0003o000000?o00001Oooool2o`0000?ooooo0ol0000=ooooo`;o00000_ooool2o`000003oooo
ool0003o000000;ooooo0ol000000ooooooo0000o`000006ooooo`Co00000_ooool2o`0000Kooooo
3Ol00005ooooo`;o00000_ooool3o`0000oooooo0ol00009oooooaGo00001oooool2o`0005Sooooo
000Looooo`03o`000?oooooooooo02[ooooo0_l00008ooooo`?o00003?ooool2o`00017ooooo1?l0
00000ooooooo0000o`000003o`0000Cooooo0ol00004ooooo`;o00003Oooool2o`000005ooooool0
003o0000o`000?ooool00_l00007ooooo`;o00001oooool2o`0000;ooooo0_l00003ooooo`;o0000
00?oooooo`000?l000002ol00003ooooo`Go00000_ooool2o`0000Kooooo0_l000000ooooooo0000
o`000005ooooo`Co00002oooool@o`000003ooooool0003o000000Gooooo0_l00002ooooo`;o0000
E?ooool001cooooo00?o0000ooooooooool0=?ooool3o`0000?ooooo0_l00007ooooo`Co00005Ooo
ool2o`0000;ooooo0_l00002ooooo`?o000000?oooooo`000?l000000_l0000;ooooo`;o00001?oo
ool3o`0000[ooooo0_l00004ooooo`Go00000oooool2o`0000;ooooo0_l000000ooooooo0000o`00
000;o`0000?ooooo0_l000000ooooooo0000o`00000:ooooo`;o000000?oooooo`000?l000001Ooo
ool4o`0000Wooooo0_l000000ooooooo0000o`00000=o`000003ooooool0003o000000Cooooo0ol0
0002ooooo`;o00000oooool4o`0001_ooooo0_l0000`ooooo`007?ooool00ol0003oooooooooo`0a
ooooo`;o000000?oooooo`000?l000000_ooool4o`0000Oooooo1?l0000Eooooo`;o00000_ooool2
o`0000?ooooo0_l000000ooooooo0000o`000002o`0000_ooooo0_l00005ooooo`;o00001?ooool5
o`0000Oooooo1?l00004ooooo`;o00001oooool;o`0000Wooooo0_l00007ooooo`;o00002Oooool2
o`0000[ooooo0_l00002ooooo`Wo000000Goooooo`000?l0003o0000ooooo`05o`0000;ooooo1ol0
0003ooooo`So00005oooool2o`00033ooooo000Looooo`03o`000?oooooooooo037ooooo0_l00005
ooooo`;o00001oooool4o`0001Cooooo0_l00006ooooo`;o00000_ooool2o`000003ooooool0003o
000000;ooooo0_l0000:ooooo`;o00002_ooool5o`0000Wooooo1?l00007ooooo`;o00001?ooool7
o`0000_ooooo0_l00007ooooo`Go00001_ooool2o`0000Gooooo0_l000000ooooooo0000o`000002
o`0000?ooooo1Ol000000ooooooo0000o`000002ooooo`;o000000Coooooo`000?l0003ooooo0_l0
0003ooooo`Ko00001?ooool7o`0004Wooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo
0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0hooooo`;o
00001oooool2o`0001Kooooo0ol00005ooooo`;o00002Oooool2o`0000;ooooo0_l00006ooooo`;o
00005_ooool2o`0000;ooooo0_l00007ooooo`;o00001Oooool5o`0001Kooooo1?l0000:ooooo`;o
000000Coooooo`000?l0003ooooo1?l00005ooooo`Oo000000?oooooo`000?l000003?ooool2o`00
05Gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOo
oooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0gooooo`;o00000oooool2o`0001Sooooo0_l0
0002ooooo`;o00001Oooool3o`0000cooooo0_l0000Nooooo`;o00004_ooool5o`000003ooooool0
003o000000;o00001oooool2o`0000[ooooo0_l0000:ooooo`;o00001_ooool2o`0000;ooooo0_l0
00000ooooooo0000o`000005o`000003ooooool0003o000000Gooooo0_l0001Looooo`0000?ooooo
oa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`0gooooo`;o000000?oooooo`000?l000000_l0000Hooooo`;o00001?oo
ool2o`0000?ooooo0ol0000/ooooo`;o00003?ooool5o`000003ooooool0003o000000So00001_oo
ool3o`0001Kooooo0_l00006ooooo`;o000000?oooooo`000?l000002Ol000000ooooooo0000o`00
0003ooooo`Co00000oooool2o`0001?ooooo0_l00012ooooo`0000?oooooo`000?ooool00_ooool0
0ol0003oooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0003[ooooo1Ol0
0008ooooo`;o00003_ooool2o`0000?ooooo0_l0000booooo`;o00001oooool2o`0000?ooooo1Ol0
0003ooooo`Co00002Oooool3o`0001Kooooo0ol00009ooooo`Ko000000?oooooo`000?l000001Ooo
ool5o`0000;ooooo0_l000000ooooooo0000o`00000Booooo`?o0000@_ooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o
0000ooooooooool0>oooool4o`0000Sooooo0_l0000>ooooo`;o0000@?ooool3o`0000Kooooo0_l0
0003ooooo`;o00002_ooool3o`0001Kooooo0_l00002ooooo`;o00002_ooool7o`0000?ooooo1?l0
0003ooooo`;o00004oooool4o`0000;ooooo0_l00009ooooo`;o0000=?ooool00003ooooool@413o
oooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooo
oooo03Sooooo0_l00002ooooo`;o00000oooool2o`0005?ooooo0_l00002ooooo`;o00001_ooool3
o`0000;ooooo0_l00002ooooo`;o00001Oooool4o`0001[ooooo0_l00004ooooo`Go000000?ooooo
o`000?l000001Ol00004ooooo`?o00001Oooool5o`0000[ooooo0_l00002ooooo`;o00001?ooool2
o`0000Wooooo0_l0000dooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@
413oV9RH00Sooooo00?o0000ooooooooool0>?ooool2o`0000;ooooo0_l00003ooooo`;o00005Ooo
ool2o`0003cooooo0_l0000;ooooo`;o00000_ooool2o`0000;ooooo0ol000001?oooooo0000o`00
0?ooool2o`0001kooooo0_l00002ooooo`Go000000Coooooo`000?l0003o00001?ooool2o`0000So
oooo1ol0000:ooooo`?o00000oooool4o`00047ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^
kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`0hooooo`;o00000_ooool2
o`0001Sooooo1Ol0000Jooooo`;o000000?oooooo`000?l000001?l0000Pooooo`;o00001oooool4
o`000004ooooool0003o0000ooooo`Go00002Oooool2o`0000Kooooo0_l00009ooooo`Co00002?oo
ool4o`0000;ooooo0ol00008ooooo`;o000000?oooooo`000?l000000ol0000:ooooo`;o00000ooo
ool4o`00047ooooo000Looooo`03o`000?oooooooooo03cooooo0_l0000Fooooo`Co000000?ooooo
o`000?l000006Oooool3o`000003ooooool0003o000000Wo00006oooool2o`0000Wooooo0_l00005
ooooo`Co00002Oooool2o`0000Kooooo0_l00009ooooo`Co00001?ooool2o`0000?ooooo0ol00002
ooooo`;o00000oooool2o`0000;ooooo0ol00005ooooo`;o00002?ooool2o`0000Gooooo0_l00013
ooooo`007?ooool00ol0003oooooooooo`0fooooo`Go00004?ooool2o`0000Oooooo0_l0000Loooo
o`Co00000_ooool2o`0000?ooooo1ol00004ooooo`;o00000_ooool2o`00013ooooo0_l0000?oooo
o`;o00008?ooool3o`0000?ooooo1?l00006ooooo`;o00001?ooool2o`0000;ooooo0ol00002oooo
o`;o00002oooool2o`0000Gooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`0fooooo`Go
00003Oooool2o`000003ooooool0003o000000Wooooo0_l0000Jooooo`Co00000_ooool2o`0000Co
oooo0_l000001?oooooo0000o`000?l00004ooooo`Ko00008Oooool2o`0000Cooooo1?l0000Aoooo
o`;o00000_ooool2o`000004ooooool0003o0000o`0000;ooooo1Ol00004ooooo`Co00003Oooool2
o`0000Cooooo0_l00008ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0B?ooool2o`00
00cooooo1?l0000Kooooo`;o00004_ooool3o`000004ooooool0003o0000ooooo`?o00002?ooool2
o`0000?ooooo0_l0000Cooooo`Co00004?ooool3o`0000;ooooo0_l00002ooooo`;o00000_ooool2
o`000003ooooool0003o000000;o00000_ooool2o`000003ooooool0003o000000Oooooo0_l00009
ooooo`;o00001Oooool2o`000003ooooool0003o000000;ooooo0_l00013ooooo`007?ooool00ol0
003oooooooooo`18ooooo`Co00003?ooool2o`0001[ooooo0ol0000Fooooo`;o000000Coooooo`00
0?l0003o00001_ooool4o`0000?ooooo0_l00008ooooo`;o00004Oooool2o`0000Oooooo0_l00000
1?oooooo0000o`000?l00006ooooo`Ko000000?oooooo`000?l000000_l00005ooooo`;o00001ooo
ool2o`0000gooooo1Ol00002ooooo`;o000000?oooooo`000?l000001oooool2o`0003[ooooo000L
ooooo`03o`000?oooooooooo03gooooo0_l000000ooooooo0000o`000006ooooo`Co00002oooool3
o`0001[ooooo1?l0000Hooooo`?o00001_ooool2o`0000?ooooo0_l00003ooooo`?o00000_ooool5
o`00013ooooo0_l00007ooooo`;o00000_ooool2o`0000Kooooo1ol000000ooooooo0000o`00000:
ooooo`;o00003Oooool2o`0000?ooooo1?l00003ooooo`;o00002_ooool2o`0003[ooooo000Loooo
o`03o`000?oooooooooo03gooooo1Ol0000Eooooo`;o00007Oooool2o`0000_ooooo0_l00002oooo
o`?o00001_ooool3o`0000Kooooo0_l00003ooooo`;o00000oooool7o`000003ooooool0003o0000
01Wooooo0_l00008ooooo`;o000000?oooooo`000?l000001ol00002ooooo`;o00001_ooool2o`00
00Wooooo0_l00002ooooo`;o00005_ooool2o`0003[ooooo000Looooo`03o`000?oooooooooo03Wo
oooo0_l00004ooooo`;o00002oooool2o`0000?ooooo0_l0000`ooooo`;o00000_ooool3o`0000Oo
oooo0_l00003ooooo`Co00000_ooool2o`000003ooooool0003o000000go00003_ooool4o`0000Ko
oooo0_l00008ooooo`;o000000?oooooo`000?l000001_l00003ooooo`;o00000_ooool2o`0000co
oooo0ol00002ooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0>Oooool2o`0000?ooooo
0_l0000<ooooo`;o000000?oooooo`000?l000000_l0000mooooo`?o00000oooool4o`0000;ooooo
5Ol000001?oooooo0000o`000?ooool2o`0000Gooooo1?l00006ooooo`;o000000?oooooo`000?l0
00002?ooool2o`000004ooooool0003o0000o`0000Wooooo0_l00003ooooo`;o00001oooool2o`00
05Oooooo000Looooo`03o`000?oooooooooo03cooooo1Ol0000>ooooo`;o00001oooool2o`0003Ko
oooo0_l0000;oooooaCo000000Coooooo`000?l0003ooooo0_l0000Booooo`Go00000oooool2o`00
00Cooooo0_l00006ooooo`;o00001_ooool3o`0005oooooo000Looooo`03o`000?oooooooooo03_o
oooo1_l0000Booooo`;o00000oooool3o`00033ooooo0_l00002ooooo`?o00002_ooool?o`000003
ooooool0003o000000Go00000_ooool2o`0001Cooooo0ol00003ooooo`;o00000_ooool2o`0000;o
oooo0_l00004ooooo`?o00001_ooool2o`0001oooooo0_l0000nooooo`007?ooool2o`0003cooooo
0_l000000ooooooo0000o`00000<ooooo`;o00001Oooool2o`0000Cooooo0_l0000Tooooo`?o0000
2Oooool2o`0000;ooooo0ol00009oooooa3o00001?ooool7o`0000Sooooo0_l0000;ooooo`;o0000
0_ooool2o`0000Cooooo0_l00002ooooo`;o00001Oooool2o`0002Oooooo0_l0000nooooo`007?oo
ool00ol0003oooooooooo`0kooooo`;o000000?oooooo`000?l000002Oooool2o`000003ooooool0
003o000002oooooo1Ol0000>ooooo`;o00002Oooool2o`000003ooooool0003o000000_o00001?oo
ool7o`0000Sooooo0_l00009ooooo`;o00001?ooool2o`0000?ooooo0_l0000;ooooo`;o0000I_oo
ool001cooooo00?o0000ooooooooool0A?ooool2o`0000?ooooo0ol00009ooooo`;o00009_ooool3
o`0001Kooooo0_l00006oooooa3o00000_ooool8o`00017ooooo1?l00007ooooo`;o00002oooool2
o`0001[ooooo0ol00019ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00001?ooool2o`00
00Oooooo1?l00006ooooo`;o00007?ooool2o`000003ooooool0003o000000_ooooo0_l00002oooo
o`?o00001?ooool2o`0000Sooooo3_l00003ooooo`Oo00004oooool2o`00033ooooo0ol00008oooo
o`;o0000?oooool001cooooo00?o0000ooooooooool0@?ooool2o`0000Cooooo0_l000000ooooooo
0000o`000008ooooo`Co00001?ooool5o`0001_ooooo0_l0000;ooooo`Go00000_ooool3o`0000go
oooo4Ol00003ooooo`Co0000DOooool2o`0003oooooo000Looooo`03o`000?oooooooooo043ooooo
0_l000001?oooooo0000o`000?ooool5o`0000Gooooo0_l00002ooooo`Co00000oooool2o`000003
ooooool0003o000002Sooooo0ol0000=oooooaSo000000?oooooo`000?l000001?l0001Aooooo`;o
0000?oooool001cooooo00?o0000ooooooooool0@oooool2o`0000?ooooo0_l00006ooooo`;o0000
0_ooool4o`0002[ooooo1?l00009ooooo`;o00001ooooolLo`000003ooooool0003o000000?ooooo
0_l00018ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0@oooool2o`0000?ooooo0_l0
00000ooooooo0000o`000008ooooo`Go0000:?ooool6o`000003ooooool0003o000000Cooooo0ol0
0007ooooo`;o000000?oooooo`000?l000005_l00002ooooo`;o00000_ooool2o`0004Sooooo0_l0
0013ooooo`007?ooool00ol0003oooooooooo`11ooooo`Co00001_ooool2o`0000?ooooo1?l00000
0ooooooo0000o`000003o`0002cooooo0_l000000ooooooo0000o`000005ooooo`;o00002?ooool2
o`000003ooooool0003o000000Ko000000?oooooo`000?l000003?l00002ooooo`;o0000TOooool0
01cooooo00?o0000ooooooooool0@Oooool3o`0000Kooooo0_l00004ooooo`Co00001?ooool2o`00
02cooooo0_l00008ooooo`?o00001oooool2o`000004ooooool0003o0000ooooo`?o00000_ooool?
o`000003ooooool0003o000000?ooooo0_l0000Yooooo`;o00001oooool2o`0005Wooooo000Loooo
o`03o`000?oooooooooo04;ooooo0_l00005ooooo`?o00003?ooool2o`0000_ooooo0_l0000Loooo
o`;o000000?oooooo`000?l000001_ooool5o`0000Oooooo7Ol00003ooooo`;o00008_ooool2o`00
00Cooooo3?l00003ooooo`;o0000E?ooool001cooooo00?o0000ooooooooool0@_ooool2o`0000Go
oooo0_l000000ooooooo0000o`000003ooooo`;o00001Oooool5o`0000Sooooo1?l0000Iooooo`Go
00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000008oooooago00001?ooool2o`0000?o
oooo0_l0000Kooooo`?o00000oooool<o`0000;ooooo0ol0001Dooooo`007?ooool00ol0003ooooo
ooooo`12ooooo`;o00002?ooool2o`0000?ooooo0_l00005ooooo`Go00002_ooool2o`0001Wooooo
1Ol00002ooooo`?o00001Oooool2o`0000Gooooo1Ol00002oooooaWo00000_ooool4o`0000?ooooo
0_l0000Looooo`;o00002oooool4o`0000;ooooo0_l0000=ooooo`;o0000A_ooool001cooooo00?o
0000ooooooooool0C?ooool2o`0000Kooooo0_l00005ooooo`?o00002_ooool2o`00023ooooo0_l0
0005ooooo`;o00001Oooool5o`0000?ooooo5_l00004ooooo`;o0000;?ooool2o`0000;ooooo1?l0
000Aooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0E?ooool3o`0000Gooooo0ol00005
ooooo`;o00000_ooool2o`00027ooooo0_l00004ooooo`;o00001?ooool2o`0000;ooooo6?l0000e
ooooo`;o00000_ooool4o`000003ooooool0003o000000gooooo0_l00017ooooo`007?ooool00ol0
003oooooooooo`1Dooooo`?o00001_ooool2o`0000Gooooo0_l0000Hooooo`;o00002?ooool2o`00
0003ooooool0003o000000Cooooo0_l00004ooooo`;o00000ooooolGo`0000Kooooo0_l0000]oooo
o`?o000000?oooooo`000?l000000_l000000ooooooo0000o`00000=ooooo`;o0000Aoooool001co
oooo0_l00018ooooo`;o00000_ooool4o`0000cooooo0ol000001?oooooo0000o`000?ooool3o`00
01Wooooo0_l00007ooooo`?o00003_ooool2o`0000;ooooo6Ol00004ooooo`;o00001Oooool2o`00
02Gooooo1?l00002ooooo`?o000000?oooooo`000?l00000E_ooool001cooooo00?o0000oooooooo
ool0Aoooool2o`0000;ooooo1?l0000<ooooo`?o000000Coooooo`000?l0003ooooo0ol0000Roooo
o`;o00003oooool2o`0000Gooooo1?l000000ooooooo0000o`00000?o`0000_ooooo0_l0000Toooo
o`Go00001?ooool4o`0000[ooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`18ooooo`;o
00001Oooool2o`0000kooooo1Ol0000Jooooo`?o00006oooool2o`0000;ooooo2?l000000ooooooo
0000o`00000;o`000004ooooool0003o0000o`0000Gooooo0_l0000Hooooo`;o00002oooool3o`00
0003ooooool0003o000000?ooooo0_l0000<ooooo`;o0000B_ooool001cooooo00?o0000oooooooo
ool0B?ooool4o`0000?ooooo0_l0000<ooooo`Wo00002?ooool2o`0000kooooo0ol00004ooooo`;o
00001_ooool2o`0000cooooo7ol00003ooooo`Co00005Oooool2o`000003ooooool0003o000000co
oooo0_l000000ooooooo0000o`00001Mooooo`007?ooool00ol0003oooooooooo`18ooooo`Co0000
0oooool2o`0000Sooooo0_l00002ooooo`?o00000oooool5o`0000Kooooo0_l0000Dooooo`Co0000
1Oooool2o`0000cooooo0_l000000ooooooo0000o`00000Bo`000003ooooool0003o000000;o0000
1_ooool2o`0001Oooooo0_l0000?ooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0BOoo
ool4o`0000;ooooo0_l00008ooooo`;o00002Oooool4o`0000?ooooo0_l00002ooooo`;o00004ooo
ool7o`0000;ooooo0_l00008ooooo`;o00001_ooool3o`000003ooooool0003o000000co000000?o
ooooo`000?l000000ol0000Rooooo`;o00002_ooool4o`00063ooooo000Looooo`03o`000?oooooo
oooo04Wooooo1?l0000<ooooo`;o00001Oooool2o`0000;ooooo1_l000001Ooooooo0000o`000?l0
003ooooo00;o00005?ooool6o`0000cooooo0_l000000ooooooo0000o`000003oooooaGo00006?oo
ool5o`0000Sooooo0_l00004ooooo`;o00001?ooool3o`00067ooooo000Looooo`03o`000?oooooo
oooo05Wooooo1?l00003ooooo`;o00000oooool5o`0000;ooooo0_l000000ooooooo0000o`00000@
ooooo`[o00002Oooool2o`0000Cooooo0ol000000ooooooo0000o`00000?o`000003ooooool0003o
000000;o00000oooool2o`0001?ooooo1Ol00008ooooo`;o00000_ooool4o`0000;ooooo1?l0000>
ooooo`?o0000DOooool001cooooo00?o0000ooooooooool0D_ooool2o`0000Oooooo0_l00005oooo
o`;o000000Coooooo`000?l0003o00000_ooool2o`0000?ooooo1?l0000>ooooo`Co000000?ooooo
o`000?l000001?l00008ooooo`Co000000?oooooo`000?l000004ol000001?oooooo0000o`000?oo
ool2o`0000?ooooo0_l0000Pooooo`;o00000_ooool2o`0000;ooooo1?l0000@ooooo`?o0000DOoo
ool001cooooo00?o0000ooooooooool0D?ooool4o`0000Kooooo1_l00002ooooo`?o000000?ooooo
o`000?l000000_ooool2o`0000Cooooo0ol0000Cooooo`Ko000000Coooooo`000?l0003ooooo1?l0
0002ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000003ooooo`Ko0000
0_ooool2o`000004ooooool0003o0000ooooo`;o00000_ooool4o`0001cooooo0_l00006ooooo`Oo
00004?ooool2o`0005;ooooo000Looooo`03o`000?oooooooooo053ooooo0_l00004ooooo`;o0000
0_ooool6o`0000?ooooo0_l00005ooooo`?o00006Oooool3o`0000Cooooo1ol00007ooooo`Co0000
1Oooool5o`0000;ooooo0ol00004ooooo`;o00000_ooool4o`000003ooooool0003o000001Wooooo
0_l00006ooooo`?o0000J?ooool001cooooo00?o0000ooooooooool0D?ooool2o`0000Cooooo0_l0
0003ooooo`;o00003Oooool5o`0001;ooooo0_l00003ooooo`Go00001?ooool2o`0000;ooooo0_l0
0006ooooo`Co00001_ooool2o`000003ooooool0003o000000?o000000?oooooo`000?l000000_oo
ool2o`0000Oooooo0_l0000Pooooo`Co0000J?ooool001cooooo00?o0000ooooooooool0D?ooool2
o`0000gooooo0_l0000;ooooo`?o00003_ooool2o`0000;ooooo0_l00004ooooo`Co00002?ooool2
o`0000Wooooo1?l00006ooooo`So00001oooool2o`0000Cooooo0_l0000Kooooo`;o000000?ooooo
o`000?l00000J_ooool001cooooo00?o0000ooooooooool0D_ooool2o`0000_ooooo0_l0000Loooo
o`?o00001oooool5o`0000;ooooo0_l00009ooooo`;o00000oooool7o`0000Kooooo1Ol000000ooo
oooo0000o`000002o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l000002Oooool2o`00
00Sooooo1ol00006ooooo`;o0000IOooool001cooooo00?o0000ooooooooool0D_ooool2o`000003
ooooool0003o000000;ooooo0_l0000Sooooo`;o00000oooool2o`0000;ooooo1Ol00002ooooo`;o
00002Oooool2o`0000?ooooo0_l00002ooooo`?o00001_ooool2o`0000Cooooo1?l00008ooooo`;o
000000?oooooo`000?l000002Oooool2o`0000Sooooo1ol00003ooooo`;o000000?oooooo`000?l0
0000IOooool001cooooo00?o0000ooooooooool0EOooool6o`0002Sooooo0_l00003ooooo`;o0000
2?ooool4o`0000Cooooo0_l00007ooooo`Co00002?ooool2o`0000[ooooo1?l0000Eooooo`?o0000
00?oooooo`000?l000000_l00003ooooo`;o0000J?ooool001cooooo0_l0001Gooooo`Co0000:?oo
ool2o`0000Cooooo0_l00008ooooo`Co00001?ooool2o`0000Kooooo1Ol00004ooooo`?o000000?o
ooooo`000?l000002_ooool2o`0000Sooooo0_l0000=ooooo`?o000000?oooooo`000?l000000_l0
000=ooooo`;o0000G_ooool001cooooo00?o0000ooooooooool0Eoooool2o`0000[ooooo0_l00002
ooooo`;o00006Oooool2o`0001kooooo0_l00007ooooo`?o00005oooool2o`0000_ooooo1?l00000
1?oooooo0000o`000?l0000?ooooo`?o0000GOooool001cooooo00?o0000ooooooooool0Eoooool4
o`0000Sooooo1_l0000?ooooo`;o00004?ooool2o`0000?ooooo0ol0000Oooooo`;o00002_ooool2
o`00013ooooo1Ol000000ooooooo0000o`000002o`00013ooooo0ol0001Mooooo`007?ooool00ol0
003oooooooooo`1Iooooo`;o00002_ooool2o`0000Gooooo0_l00002ooooo`;o00001_ooool2o`00
013ooooo0ol00002ooooo`?o00002oooool2o`0000Cooooo0_l0000<ooooo`;o00002_ooool2o`00
013ooooo0ol000000ooooooo0000o`000002o`0007;ooooo000Looooo`03o`000?oooooooooo063o
oooo0_l0000:ooooo`;o00000_ooool2o`00013ooooo0_l00007ooooo`?o000000Coooooo`000?l0
003o00002oooool2o`0000Cooooo0_l00003ooooo`;o00008_ooool4o`0000?ooooo0_l0000?oooo
o`;o0000Hoooool001cooooo00?o0000ooooooooool0FOooool2o`0000Gooooo0_l0000>ooooo`;o
00003oooool3o`0000Sooooo0_l0000<ooooo`;o00002?ooool2o`0000;ooooo0_l00005ooooo`;o
000000?oooooo`000?l000000_ooool2o`0000Kooooo0_l0000:ooooo`Ko00005?ooool2o`0006?o
oooo000Looooo`03o`000?oooooooooo05Wooooo0_l0000Aooooo`;o00001oooool2o`0000;ooooo
0_l00006ooooo`?o00002_ooool2o`0000Kooooo0_l00002ooooo`;o00001Oooool2o`000003oooo
ool0003o000000;ooooo0_l000001?oooooo0000o`000?ooool3o`000003ooooool0003o000000;o
oooo0_l00006ooooo`;o00001oooool2o`000003ooooool0003o000000Cooooo0_l0001gooooo`00
7?ooool00ol0003oooooooooo`1/ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o0000
1oooool2o`0000[ooooo1Ol00003ooooo`;o00002Oooool2o`0000Gooooo1Ol000000ooooooo0000
o`000005ooooo`Co000000?oooooo`000?l000001_ooool4o`000003ooooool0003o000000Oooooo
0ol0000=ooooo`;o0000Ioooool001cooooo00?o0000ooooooooool0Ioooool2o`0000Oooooo0ol0
0006ooooo`;o00001_ooool2o`0000gooooo2Ol0000Aooooo`Co00000oooool2o`0000;ooooo1?l0
00000ooooooo0000o`000006ooooo`Co00001Oooool2o`0000Cooooo0_l0000;ooooo`Co0000Iooo
ool001cooooo00?o0000ooooooooool0IOooool4o`0000Sooooo0_l000000ooooooo0000o`00000;
ooooo`Co00003?ooool8o`0000Gooooo0_l00005ooooo`Co00000oooool2o`0000?ooooo0_l00008
ooooo`;o00000_ooool5o`0000Oooooo0_l0000Aooooo`;o0000JOooool001cooooo00?o0000oooo
ooooool0IOooool2o`0000?ooooo0_l00008ooooo`?o00002oooool3o`00013ooooo0ol00006oooo
o`;o00001Oooool5o`0000Kooooo0ol00008ooooo`;o00000_ooool5o`0000;ooooo0_l00002oooo
o`;o0000OOooool001cooooo00?o0000ooooooooool0J_ooool2o`0000Wooooo0_l0000;ooooo`;o
00004_ooool2o`0000oooooo0ol00006ooooo`Co00000_ooool2o`0000?ooooo1?l00003ooooo`;o
00000_ooool2o`0000;ooooo0_l0000<ooooo`;o0000Koooool001cooooo00?o0000ooooooooool0
Hoooool2o`000003ooooool0003o0000013ooooo0ol0000;ooooo`;o0000:_ooool2o`0000;ooooo
0_l00003ooooo`Co00004oooool4o`0000;ooooo0_l0001_ooooo`007?ooool00ol0003ooooooooo
o`1Sooooo`;o000000?oooooo`000?l000004?ooool5o`0000Wooooo0ol0000Dooooo`Co00000ooo
ool2o`0000Kooooo1?l0000Qooooo`Go0000Loooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^
1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo06Wo
oooo0_l0000@ooooo`;o000000?oooooo`000?l000001?l00003ooooo`;o00005?ooool4o`0000?o
oooo0ol00005ooooo`Ko00006Oooool2o`000004ooooool0003o0000ooooo`;o0000M_ooool00006
oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q
8@06ooooo`03o`000?oooooooooo06Wooooo0_l0000:ooooo`;o00001oooool6o`00027ooooo0_l0
0002ooooo`;o00001Oooool6o`0001Cooooo0ol000000ooooooo0000o`00001iooooo`0000?ooooo
oa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`1Zooooo`;o00002Oooool2o`0000Wooooo0ol0000Vooooo`;o00001ooo
ool4o`0000Kooooo0ol00002ooooo`;o00001oooool2o`0007gooooo00000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000J_oo
ool2o`0000cooooo0_l00006ooooo`Go0000=oooool3o`0000;ooooo0_l00026ooooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_oo
ool00ol0003oooooooooo`1hooooo`;o00002Oooool2o`00023ooooo0_l00006ooooo`;o0000V_oo
ool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol@413o^[Zjoooooonj
^[[o410@00Kooooo00?o0000ooooooooool0YOooool2o`0000Kooooo0_l0002Jooooo`0000Kooooo
ogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003o
ooooooooo`1_ooooo`;o0000M?ooool2o`0006;ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^
kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo06oooooo0_l00003
ooooo`;o00001_ooool2o`0006Oooooo0_l0001Rooooo`007?ooool00ol0003oooooooooo`1doooo
o`;o00001_ooool2o`000<_ooooo000Looooo`03o`000?oooooooooo07Wooooo0_l00002ooooo`;o
0000b_ooool001cooooo00?o0000ooooooooool0NOooool3o`000004ooooool0003o0000ooooo`;o
0000aoooool001cooooo00?o0000ooooooooool0N_ooool2o`0000?ooooo0ol0001Hooooo`;o0000
00?oooooo`000?l00000J_ooool001cooooo00?o0000ooooooooool0Ooooool4o`0005Kooooo0ol0
00000ooooooo0000o`00001Zooooo`007?ooool00ol0003oooooooooo`21ooooo`;o0000E_ooool2
o`0006kooooo000Looooo`03o`000?oooooooooo087ooooo0_l00002ooooo`;o0000B?ooool4o`00
07Kooooo000Looooo`03o`000?oooooooooo08Gooooo0_l00018ooooo`Co0000M_ooool001cooooo
00?o0000ooooooooool0coooool2o`0007Sooooo000Looooo`03o`000?oooooooooo08[ooooo0_l0
002mooooo`007?ooool00ol0003oooooooooo`2:ooooo`Co00004?ooool5o`0000;ooooo1Ol0002O
ooooo`007?ooool2o`0008_ooooo1_l0000>ooooo`Go000000?oooooo`000?l000001?l00003oooo
o`?o00001Oooool3o`0000;ooooo1_l00029ooooo`007?ooool00ol0003oooooooooo`2:ooooo`?o
000000?oooooo`000?l000003Oooool2o`000003ooooool0003o000000;ooooo0_l00007ooooo`?o
00001Oooool3o`0000;ooooo1_l00029ooooo`007?ooool00ol0003oooooooooo`2=ooooo`;o0000
1Oooool5o`0000Cooooo0_l0002Zooooo`007?ooool00ol0003oooooooooo`2=ooooo`;o00001Ooo
ool5o`0000;ooooo0_l0002/ooooo`007?ooool00ol0003oooooooooo`2Fooooo`;o00000oooool2
o`000:cooooo000Looooo`03o`000?oooooooooo09Kooooo0_l0002aooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`004_ooool4o`000003
oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Ooo
ool3o`000?ooooooB_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0
003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo
00?o0000ooooooooool0oooooomBooooo`004_ooool00omEEEGoIVIVo`00003ooooooeCooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo002Uooooo`04oa0@4?l0003o0000ooooo`;o
000000?o410@ooooooooool05Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_l000002Ol@
413oooooooooooooooooc<c<ob4Q8Ol0003o8B4Qolc<c02@ooooo`00Y_ooool01Ol0003ooooooooo
oooooooo000000Wooooo1_l00009ooooo`05oa0@4?nj^[[oooooogMgMolb<S801_ooool00ol0003o
ooooooooo`02ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40T?ooool00:Kooooo00Go0000oooooooo
ooooooooo`00000Looooo`04o`000?ooooooooooooooo`Go00000oooool01Ol0003ooooooooooooo
oooo0000093ooooo002Vooooo`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo00?o
ZJVYoa0@4?ooool00_ooool01?m4A4CogMgMooooool00004ooooo`05oc8b<_nHV9SooooooiRHV?lb
<S80T?ooool00:Kooooo00Go0000ohN7QoooooooZJVYo`00000Jooooo`03oa0@4?l0003o^[Zj00?o
oooo00CogMgMoeEEEOoooooo00001?ooool01Oo<c<co0000o`000?l0003oc<c<093ooooo002Uoooo
o`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool06Oooool00onj^[[o8B4Qooooo`03oooo
o`03ogMgMoo<c<co000000Cooooo00Go410@okZj^_oooooo^[Zjoa0@402@ooooo`00`oooool01Ol@
413oV9RHoooooonj^[[o000000Cooooo00?ok^k^odA4A?l000001?ooool01Ol0003o^[Zjoooooonj
^[[o0000093ooooo0033ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01Oooool00omgMgOo0000oooo
o`03ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0T?ooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(354) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.47105 .69673 Mdot
.50411 .67376 Mdot
.69105 .42731 Mdot
.39083 .43913 Mdot
.56049 .24549 Mdot
.68142 .40725 Mdot
.67336 .59811 Mdot
.66979 .59895 Mdot
.66686 .42807 Mdot
.24333 .64922 Mdot
.68775 .56163 Mdot
.39352 .42433 Mdot
.68072 .58271 Mdot
.37602 .45782 Mdot
.47071 .43656 Mdot
.32913 .50316 Mdot
.4965 .72566 Mdot
.60534 .28528 Mdot
.32728 .49525 Mdot
.69223 .38329 Mdot
.24477 .48069 Mdot
.3879 .45425 Mdot
.49872 .64312 Mdot
.37825 .45537 Mdot
.40102 .49467 Mdot
.49133 .66761 Mdot
.47104 .68454 Mdot
.40353 .48632 Mdot
.33622 .44409 Mdot
.68027 .56524 Mdot
.56044 .4669 Mdot
.20918 .3904 Mdot
.40151 .51249 Mdot
.3699 .62855 Mdot
.65982 .57445 Mdot
.74415 .5851 Mdot
.65579 .37915 Mdot
.67833 .61866 Mdot
.66622 .55774 Mdot
.6809 .55539 Mdot
.68607 .55698 Mdot
.48807 .66776 Mdot
.70268 .61129 Mdot
.74444 .51666 Mdot
.36801 .44744 Mdot
.43869 .6134 Mdot
.70958 .50654 Mdot
.3536 .49825 Mdot
.51862 .69177 Mdot
.69894 .40578 Mdot
.45246 .27537 Mdot
.68355 .61202 Mdot
.52533 .57961 Mdot
.86444 .6048 Mdot
.67156 .58291 Mdot
.34483 .50315 Mdot
.64507 .41135 Mdot
.36823 .48027 Mdot
.41252 .45177 Mdot
.33997 .60092 Mdot
.38532 .48313 Mdot
.57816 .26131 Mdot
.45963 .67494 Mdot
.66779 .361 Mdot
.66828 .43008 Mdot
.68537 .61679 Mdot
.53384 .67819 Mdot
.68661 .57221 Mdot
.34828 .43433 Mdot
.69634 .40584 Mdot
.33477 .4669 Mdot
.68969 .56313 Mdot
.48191 .65867 Mdot
.38286 .44093 Mdot
.65028 .75984 Mdot
.68426 .5205 Mdot
.71367 .37888 Mdot
.30651 .54835 Mdot
.51914 .27523 Mdot
.51633 .43304 Mdot
.38567 .44424 Mdot
.82728 .43652 Mdot
.46568 .39506 Mdot
.51328 .69365 Mdot
.52232 .59507 Mdot
.63627 .65841 Mdot
.37194 .50344 Mdot
.56027 .47439 Mdot
.31498 .50055 Mdot
.62172 .28919 Mdot
.65371 .4167 Mdot
.50466 .70862 Mdot
.37557 .44353 Mdot
.36241 .4323 Mdot
.32989 .74264 Mdot
.33002 .44998 Mdot
.41525 .45784 Mdot
.56809 .58449 Mdot
.70771 .57414 Mdot
.37844 .39925 Mdot
.5624 .35189 Mdot
.50069 .56958 Mdot
.34791 .50351 Mdot
.65627 .40359 Mdot
.46346 .66369 Mdot
.38776 .51766 Mdot
.69083 .58425 Mdot
.38213 .44664 Mdot
.71899 .59268 Mdot
.52141 .68237 Mdot
.41465 .4473 Mdot
.56701 .27073 Mdot
.30515 .53428 Mdot
.4922 .65094 Mdot
.39656 .72474 Mdot
.3953 .47311 Mdot
.3594 .4811 Mdot
.50448 .67025 Mdot
.68626 .3839 Mdot
.79759 .42612 Mdot
.48306 .66008 Mdot
.68318 .55486 Mdot
.50396 .72094 Mdot
.35788 .54893 Mdot
.68309 .37916 Mdot
.50739 .55665 Mdot
.50921 .55297 Mdot
.36106 .30209 Mdot
.39654 .44481 Mdot
.25278 .43252 Mdot
.66672 .40543 Mdot
.49755 .65622 Mdot
.67858 .57215 Mdot
.31767 .46149 Mdot
.48497 .68788 Mdot
.67416 .60232 Mdot
.56061 .29257 Mdot
.60267 .26289 Mdot
.51004 .65363 Mdot
.41279 .75025 Mdot
.6621 .63135 Mdot
.70946 .56799 Mdot
.44998 .27744 Mdot
.51364 .69299 Mdot
.58161 .28343 Mdot
.68902 .59842 Mdot
.40987 .19468 Mdot
.42118 .4698 Mdot
.4254 .29275 Mdot
.82981 .46403 Mdot
.45306 .27552 Mdot
.23026 .49689 Mdot
.57043 .28006 Mdot
.67479 .60324 Mdot
.3387 .48195 Mdot
.49891 .69221 Mdot
.4854 .68277 Mdot
.33914 .45294 Mdot
.40795 .49705 Mdot
.36557 .46297 Mdot
.39948 .51096 Mdot
.58371 .54881 Mdot
.37575 .44494 Mdot
.52677 .80303 Mdot
.49383 .69819 Mdot
.39729 .50483 Mdot
.66651 .38171 Mdot
.37542 .38576 Mdot
.69715 .61437 Mdot
.4038 .44424 Mdot
.40823 .49309 Mdot
.34946 .42151 Mdot
.68279 .55371 Mdot
.64599 .7722 Mdot
.53592 .23105 Mdot
.64828 .57493 Mdot
.7624 .62477 Mdot
.66902 .39426 Mdot
.37997 .49038 Mdot
.58388 .29722 Mdot
.34957 .39665 Mdot
.36639 .43755 Mdot
.45843 .27149 Mdot
.41273 .46564 Mdot
.2298 .48724 Mdot
.39463 .53475 Mdot
.63733 .6501 Mdot
.51701 .7879 Mdot
.38444 .43543 Mdot
.25529 .63292 Mdot
.43517 .29757 Mdot
.64835 .48639 Mdot
.6759 .57109 Mdot
.69013 .40081 Mdot
.68986 .39087 Mdot
.65806 .61396 Mdot
.40247 .67128 Mdot
.2302 .62386 Mdot
.33953 .43344 Mdot
.50353 .57266 Mdot
.51685 .71626 Mdot
.57122 .27801 Mdot
.50895 .65591 Mdot
.82001 .41145 Mdot
.53166 .42218 Mdot
.53633 .47556 Mdot
.57368 .3281 Mdot
.70162 .40146 Mdot
.50704 .56878 Mdot
.58562 .28711 Mdot
.35657 .46319 Mdot
.52073 .68265 Mdot
.43858 .29275 Mdot
.33213 .40702 Mdot
.21377 .68471 Mdot
.47252 .68459 Mdot
.33194 .33644 Mdot
.67404 .58324 Mdot
.63599 .4167 Mdot
.37344 .50353 Mdot
.38269 .47122 Mdot
.52235 .66943 Mdot
.34421 .48629 Mdot
.51198 .46836 Mdot
.41188 .4864 Mdot
.66148 .36237 Mdot
.55777 .22278 Mdot
.65075 .61334 Mdot
.56 .3183 Mdot
.48669 .65269 Mdot
.66787 .79309 Mdot
.65251 .3918 Mdot
.42244 .41334 Mdot
.69507 .56935 Mdot
.55841 .28572 Mdot
.64871 .39908 Mdot
.58845 .25293 Mdot
.40145 .43749 Mdot
.64918 .38332 Mdot
.57381 .26135 Mdot
.52628 .50028 Mdot
.39676 .51212 Mdot
.34 .28486 Mdot
.6878 .60558 Mdot
.50073 .7155 Mdot
.35116 .44631 Mdot
.52231 .58793 Mdot
.41769 .43042 Mdot
.38376 .32764 Mdot
.52178 .5721 Mdot
.49743 .57129 Mdot
.49693 .40944 Mdot
.58108 .30824 Mdot
.74442 .66813 Mdot
.56021 .48898 Mdot
.49575 .7259 Mdot
.36879 .43285 Mdot
.72719 .64916 Mdot
.68241 .60741 Mdot
.35877 .46981 Mdot
.70316 .66087 Mdot
.68717 .60017 Mdot
.35906 .47864 Mdot
.67525 .56016 Mdot
.49037 .69149 Mdot
.4976 .45286 Mdot
.48128 .71842 Mdot
.36047 .44621 Mdot
.67899 .56007 Mdot
.68837 .39468 Mdot
.49087 .66905 Mdot
.38524 .4486 Mdot
.40428 .457 Mdot
.5066 .58304 Mdot
.41777 .47874 Mdot
.59062 .60722 Mdot
.35813 .50102 Mdot
.69202 .43048 Mdot
.3321 .44747 Mdot
.51373 .33402 Mdot
.61726 .25049 Mdot
.5188 .66877 Mdot
.52165 .5736 Mdot
.64503 .4047 Mdot
.5089 .48931 Mdot
.30925 .33078 Mdot
.3741 .44869 Mdot
.51854 .57933 Mdot
.35883 .3176 Mdot
.70107 .60985 Mdot
.31887 .51167 Mdot
.68042 .34116 Mdot
.65441 .4149 Mdot
.5045 .5695 Mdot
.34736 .4014 Mdot
.54034 .68458 Mdot
.32599 .48742 Mdot
.652 .38375 Mdot
.4839 .71789 Mdot
.32767 .46731 Mdot
.68403 .51343 Mdot
.52007 .59336 Mdot
.70962 .57438 Mdot
.56556 .57804 Mdot
.35796 .48637 Mdot
.69422 .41025 Mdot
.48322 .67321 Mdot
.66825 .58723 Mdot
.48978 .65233 Mdot
.45582 .29293 Mdot
.3572 .32933 Mdot
.48098 .61302 Mdot
.5826 .315 Mdot
.36104 .20103 Mdot
.64788 .57425 Mdot
.36736 .39576 Mdot
.62844 .3713 Mdot
.50629 .77226 Mdot
.65417 .40596 Mdot
.42436 .75809 Mdot
.64996 .41527 Mdot
.33399 .49188 Mdot
.68105 .41555 Mdot
.32967 .75131 Mdot
.40751 .47565 Mdot
.67118 .4319 Mdot
.58961 .52514 Mdot
.40821 .47018 Mdot
.48423 .68887 Mdot
.18598 .4545 Mdot
.39316 .64462 Mdot
.39562 .65776 Mdot
.64143 .40817 Mdot
.43555 .76849 Mdot
.39869 .49094 Mdot
.31545 .47397 Mdot
.49748 .68674 Mdot
.42069 .43494 Mdot
.59304 .30287 Mdot
.60231 .27107 Mdot
.42957 .23013 Mdot
.23662 .38058 Mdot
.39662 .68784 Mdot
.48825 .67815 Mdot
.5439 .23399 Mdot
.63915 .76563 Mdot
.52082 .59216 Mdot
.6702 .59986 Mdot
.68957 .74222 Mdot
.31119 .4776 Mdot
.54185 .63167 Mdot
.50949 .46682 Mdot
.48651 .71366 Mdot
.48434 .57786 Mdot
.66797 .59068 Mdot
.39331 .65752 Mdot
.21858 .59315 Mdot
.36392 .46291 Mdot
.69814 .60411 Mdot
.42406 .44621 Mdot
.55802 .47855 Mdot
.34199 .30229 Mdot
.7419 .43625 Mdot
.36071 .44746 Mdot
.69753 .72395 Mdot
.35935 .44117 Mdot
.37471 .29619 Mdot
.35492 .4654 Mdot
.48076 .68313 Mdot
.3391 .42389 Mdot
.55823 .49614 Mdot
.42902 .15583 Mdot
.52723 .41155 Mdot
.5938 .26078 Mdot
.37854 .45974 Mdot
.37033 .4709 Mdot
.58044 .25896 Mdot
.49477 .71289 Mdot
.35238 .44147 Mdot
.7683 .66155 Mdot
.37928 .44336 Mdot
.67835 .6147 Mdot
.42755 .33954 Mdot
.22828 .36784 Mdot
.38402 .49634 Mdot
.54001 .68432 Mdot
.70944 .56931 Mdot
.69904 .57947 Mdot
.3026 .504 Mdot
.68633 .60777 Mdot
.33988 .48207 Mdot
.42837 .3394 Mdot
.52439 .6565 Mdot
.30133 .49747 Mdot
.48472 .71003 Mdot
.61247 .19417 Mdot
.68108 .60444 Mdot
.51923 .58766 Mdot
.40325 .7 Mdot
.68511 .59165 Mdot
.56807 .21931 Mdot
.3341 .42708 Mdot
.30826 .42749 Mdot
.50871 .73354 Mdot
.69296 .41103 Mdot
.51431 .56942 Mdot
.67044 .58417 Mdot
.37063 .44801 Mdot
.37655 .51189 Mdot
.6898 .6077 Mdot
.26632 .55623 Mdot
.56144 .46675 Mdot
.36207 .4441 Mdot
.48686 .70051 Mdot
.49513 .65738 Mdot
.33279 .51398 Mdot
.35691 .44167 Mdot
.68547 .40324 Mdot
.51891 .57841 Mdot
.51934 .57119 Mdot
.50418 .55532 Mdot
.638 .41064 Mdot
.36713 .19564 Mdot
.71159 .57157 Mdot
.2144 .38342 Mdot
.64221 .72988 Mdot
.31664 .52503 Mdot
.67582 .3796 Mdot
.38665 .47461 Mdot
.35937 .50676 Mdot
.67548 .56248 Mdot
.32717 .25028 Mdot
.31543 .46729 Mdot
.47664 .71059 Mdot
.68922 .61013 Mdot
.42047 .43896 Mdot
.62729 .61511 Mdot
.56542 .28603 Mdot
.3948 .7035 Mdot
.68212 .61036 Mdot
.51974 .65536 Mdot
.6821 .61054 Mdot
.36876 .46859 Mdot
.35146 .39995 Mdot
.48348 .71158 Mdot
.57164 .24473 Mdot
.34336 .44605 Mdot
.35373 .4739 Mdot
.60835 .36984 Mdot
.65343 .75677 Mdot
.55049 .25236 Mdot
.34139 .49435 Mdot
.3097 .42275 Mdot
.57415 .24618 Mdot
.34195 .46635 Mdot
.33097 .45732 Mdot
.25156 .43402 Mdot
.70562 .61285 Mdot
.55325 .27322 Mdot
.40344 .17049 Mdot
.47199 .68721 Mdot
.59144 .60207 Mdot
.50231 .56326 Mdot
.65436 .56365 Mdot
.50027 .47168 Mdot
.5112 .57908 Mdot
.66638 .70623 Mdot
.54614 .85678 Mdot
.51463 .57246 Mdot
.6361 .38562 Mdot
.35564 .74953 Mdot
.33285 .4537 Mdot
.35543 .44757 Mdot
.58897 .30422 Mdot
.5105 .67572 Mdot
.53329 .79296 Mdot
.65032 .57143 Mdot
.39418 .46388 Mdot
.47346 .66743 Mdot
.64039 .65609 Mdot
.50688 .57736 Mdot
.57818 .29753 Mdot
.56132 .25219 Mdot
.3517 .44781 Mdot
.33192 .32435 Mdot
.48842 .67194 Mdot
.38513 .44865 Mdot
.35825 .48221 Mdot
.65008 .37496 Mdot
.51996 .68045 Mdot
.66246 .38333 Mdot
.51075 .59781 Mdot
.38452 .7868 Mdot
.78319 .60646 Mdot
.69129 .60161 Mdot
.46906 .54261 Mdot
.65044 .61229 Mdot
.68258 .49513 Mdot
.51917 .57704 Mdot
.38587 .45078 Mdot
.5138 .64123 Mdot
.38392 .44705 Mdot
.37793 .4433 Mdot
.36276 .44961 Mdot
.39601 .68989 Mdot
.51982 .28299 Mdot
.58795 .29816 Mdot
.3548 .48912 Mdot
.63712 .39532 Mdot
.64454 .64584 Mdot
.26221 .68742 Mdot
.37996 .46525 Mdot
.35823 .48019 Mdot
.53777 .69017 Mdot
.42241 .46508 Mdot
.68223 .59786 Mdot
.48744 .71535 Mdot
.36057 .50994 Mdot
.57105 .34988 Mdot
.34795 .44644 Mdot
.46937 .5858 Mdot
.66299 .60237 Mdot
.37162 .40708 Mdot
.41846 .50698 Mdot
.51984 .57778 Mdot
.51341 .57002 Mdot
.49407 .56983 Mdot
.68142 .61588 Mdot
.64653 .37862 Mdot
.70376 .37289 Mdot
.42868 .49154 Mdot
.34125 .48923 Mdot
.32473 .41401 Mdot
.66154 .45076 Mdot
.57667 .48685 Mdot
.41578 .74134 Mdot
.42372 .45088 Mdot
.6454 .42809 Mdot
.56831 .58376 Mdot
.26702 .52239 Mdot
.49662 .71508 Mdot
.61984 .3867 Mdot
.69479 .57656 Mdot
.56885 .25928 Mdot
.41243 .25881 Mdot
.47958 .66986 Mdot
.5252 .64861 Mdot
.67936 .39744 Mdot
.43631 .34507 Mdot
.88976 .564 Mdot
.66417 .40923 Mdot
.52908 .47606 Mdot
.49372 .68373 Mdot
.40064 .51233 Mdot
.37653 .31452 Mdot
.4332 .35372 Mdot
.65897 .43278 Mdot
.4036 .45555 Mdot
.64506 .22508 Mdot
.68574 .40441 Mdot
.32044 .41354 Mdot
.64046 .40678 Mdot
.7111 .58818 Mdot
.66186 .40194 Mdot
.46802 .67856 Mdot
.39622 .44575 Mdot
.87267 .59193 Mdot
.48111 .41693 Mdot
.39764 .456 Mdot
.67769 .61232 Mdot
.66703 .49742 Mdot
.36196 .46658 Mdot
.60038 .29165 Mdot
.6382 .3843 Mdot
.7129 .4661 Mdot
.32847 .47826 Mdot
.6824 .41629 Mdot
.52936 .6487 Mdot
.61679 .40449 Mdot
.56871 .35375 Mdot
.5164 .56864 Mdot
.49396 .69443 Mdot
.70037 .5315 Mdot
.68692 .55564 Mdot
.35339 .51324 Mdot
.36805 .48693 Mdot
.49523 .70201 Mdot
.51238 .50005 Mdot
.33151 .5233 Mdot
.38224 .44417 Mdot
.67119 .38834 Mdot
.69225 .37521 Mdot
.46702 .42841 Mdot
.65156 .39041 Mdot
.30707 .42673 Mdot
.48872 .69812 Mdot
.3271 .48961 Mdot
.48907 .65708 Mdot
.36593 .43345 Mdot
.61519 .59462 Mdot
.50923 .70862 Mdot
.42885 .4225 Mdot
.40341 .4493 Mdot
.45104 .74471 Mdot
.36293 .4895 Mdot
.36787 .44244 Mdot
.67858 .36791 Mdot
.58509 .26678 Mdot
.33069 .51814 Mdot
.66207 .52451 Mdot
.56307 .25753 Mdot
.25884 .53753 Mdot
.68202 .37864 Mdot
.55501 .26405 Mdot
.4038 .23985 Mdot
.52099 .5716 Mdot
.59041 .26574 Mdot
.52145 .55499 Mdot
.69514 .60015 Mdot
.48748 .63057 Mdot
.40915 .46439 Mdot
.37884 .78289 Mdot
.56287 .46797 Mdot
.5096 .58653 Mdot
.34538 .45949 Mdot
.38222 .47698 Mdot
.47402 .66626 Mdot
.82138 .4179 Mdot
.69787 .37447 Mdot
.41467 .49157 Mdot
.47868 .66851 Mdot
.82878 .44847 Mdot
.66736 .43379 Mdot
.57489 .30334 Mdot
.66189 .55935 Mdot
.48167 .73112 Mdot
.51905 .59025 Mdot
.67919 .60439 Mdot
.70646 .36976 Mdot
.46226 .26935 Mdot
.32544 .48371 Mdot
.67005 .37991 Mdot
.4542 .27486 Mdot
.32012 .51524 Mdot
.66108 .61842 Mdot
.70468 .52438 Mdot
.51091 .69925 Mdot
.6897 .60811 Mdot
.59678 .29255 Mdot
.50757 .7213 Mdot
.48649 .71217 Mdot
.68662 .59562 Mdot
.49265 .79665 Mdot
.36031 .31782 Mdot
.65468 .59497 Mdot
.39097 .32931 Mdot
.45589 .27533 Mdot
.51256 .59084 Mdot
.57862 .29615 Mdot
.5541 .22233 Mdot
.48903 .6672 Mdot
.6836 .74639 Mdot
.45295 .27444 Mdot
.41604 .45939 Mdot
.57368 .25991 Mdot
.6285 .63993 Mdot
.73969 .59535 Mdot
.68134 .60155 Mdot
.60778 .38493 Mdot
.57371 .25654 Mdot
.39589 .43655 Mdot
.25653 .29867 Mdot
.39856 .48473 Mdot
.69037 .59848 Mdot
.51052 .46743 Mdot
.51616 .67002 Mdot
.70022 .6119 Mdot
.51166 .46756 Mdot
.34894 .50119 Mdot
.39734 .47346 Mdot
.5265 .30329 Mdot
.52001 .69402 Mdot
.51148 .59558 Mdot
.39513 .44836 Mdot
.36277 .47907 Mdot
.35461 .51645 Mdot
.27123 .33144 Mdot
.39072 .5617 Mdot
.37238 .51979 Mdot
.64211 .43067 Mdot
.34774 .39878 Mdot
.41889 .48542 Mdot
.54099 .69135 Mdot
.54921 .34348 Mdot
.50729 .59675 Mdot
.3527 .45176 Mdot
.36014 .44578 Mdot
.66628 .55861 Mdot
.3611 .31713 Mdot
.437 .35503 Mdot
.69895 .41789 Mdot
.70691 .42633 Mdot
.36626 .42622 Mdot
.50112 .69757 Mdot
.56938 .30837 Mdot
.29298 .4689 Mdot
.47547 .70675 Mdot
.36782 .42827 Mdot
.64086 .38027 Mdot
.51635 .57616 Mdot
.29143 .45705 Mdot
.57621 .2662 Mdot
.66605 .63128 Mdot
.26518 .53598 Mdot
.68432 .39039 Mdot
.39065 .50007 Mdot
.71707 .39453 Mdot
.67016 .41932 Mdot
.5064 .58429 Mdot
.39486 .40651 Mdot
.48858 .68754 Mdot
.51771 .65389 Mdot
.50575 .31116 Mdot
.63637 .40561 Mdot
.62335 .44915 Mdot
.70577 .59593 Mdot
.35328 .48659 Mdot
.6954 .63778 Mdot
.51649 .65735 Mdot
.36046 .30159 Mdot
.55768 .2557 Mdot
.6843 .60028 Mdot
.52603 .56356 Mdot
.50411 .71344 Mdot
.51366 .65202 Mdot
.37298 .44477 Mdot
.38625 .46009 Mdot
.66837 .4847 Mdot
.42875 .29642 Mdot
.67079 .56263 Mdot
.56685 .29416 Mdot
.69613 .42026 Mdot
.33261 .48512 Mdot
.51218 .69112 Mdot
.23218 .35173 Mdot
.35989 .48743 Mdot
.6372 .39633 Mdot
.50211 .67339 Mdot
.58275 .30352 Mdot
.59526 .29225 Mdot
.3865 .43883 Mdot
.23183 .48586 Mdot
.6874 .58789 Mdot
.48297 .68763 Mdot
.46343 .72657 Mdot
.35446 .49164 Mdot
.38164 .46173 Mdot
.3803 .54644 Mdot
.67857 .62258 Mdot
.38683 .52739 Mdot
.58159 .2486 Mdot
.50134 .65061 Mdot
.39377 .44964 Mdot
.57932 .26063 Mdot
.5435 .63524 Mdot
.51313 .5805 Mdot
.67933 .42491 Mdot
.60198 .28607 Mdot
.58344 .27647 Mdot
.55924 .264 Mdot
.69154 .74019 Mdot
.52189 .60852 Mdot
.51397 .20465 Mdot
.40275 .45188 Mdot
.45664 .27549 Mdot
.33368 .51159 Mdot
.70281 .60556 Mdot
.69071 .41495 Mdot
.36524 .453 Mdot
.40347 .45268 Mdot
.27298 .53652 Mdot
.32965 .50051 Mdot
.3212 .48987 Mdot
.51582 .66638 Mdot
.46321 .72967 Mdot
.69159 .39765 Mdot
.83239 .48176 Mdot
.17953 .38761 Mdot
.3441 .42957 Mdot
.43456 .34415 Mdot
.50069 .71279 Mdot
.66426 .55849 Mdot
.3889 .32429 Mdot
.7222 .62979 Mdot
.503 .66147 Mdot
.33238 .48963 Mdot
.29432 .55174 Mdot
.56797 .25643 Mdot
.36741 .46498 Mdot
.68242 .56946 Mdot
.36644 .46407 Mdot
.68586 .61524 Mdot
.43598 .75982 Mdot
.44934 .36385 Mdot
.41145 .46641 Mdot
.33023 .45017 Mdot
.25347 .4579 Mdot
.38265 .46368 Mdot
.74747 .41987 Mdot
.50056 .67824 Mdot
.41838 .41284 Mdot
.34203 .50257 Mdot
.38554 .64262 Mdot
.3466 .47237 Mdot
.49451 .49442 Mdot
.38621 .48608 Mdot
.34696 .23792 Mdot
.40826 .4447 Mdot
.38242 .48958 Mdot
.66499 .58044 Mdot
.67472 .55604 Mdot
.48114 .75956 Mdot
.50423 .58979 Mdot
.63435 .64726 Mdot
.35381 .47556 Mdot
.70293 .40081 Mdot
.32251 .37948 Mdot
.5847 .27128 Mdot
.50086 .65217 Mdot
.66169 .84317 Mdot
.71421 .58161 Mdot
.63458 .39398 Mdot
.54869 .47358 Mdot
.63222 .41823 Mdot
.62852 .37307 Mdot
.49285 .74206 Mdot
.57608 .29463 Mdot
.35172 .44352 Mdot
.37711 .6268 Mdot
.67151 .74234 Mdot
.35373 .49235 Mdot
.70139 .42604 Mdot
.29233 .3924 Mdot
.49725 .29965 Mdot
.60172 .29995 Mdot
.57561 .28656 Mdot
.67055 .58916 Mdot
.69428 .41912 Mdot
.42589 .45449 Mdot
.5548 .26404 Mdot
.69039 .40527 Mdot
.52235 .55945 Mdot
.53729 .32927 Mdot
.48694 .67356 Mdot
.43254 .76599 Mdot
.43583 .62758 Mdot
.7074 .56724 Mdot
.66802 .52464 Mdot
.49874 .63052 Mdot
.48896 .72419 Mdot
.50008 .57847 Mdot
.64819 .4283 Mdot
.48804 .63159 Mdot
.39146 .4437 Mdot
.33231 .40673 Mdot
.35269 .44626 Mdot
.584 .30666 Mdot
.34516 .46672 Mdot
.68728 .41044 Mdot
.6626 .58615 Mdot
.65105 .41276 Mdot
.6721 .59728 Mdot
.19454 .42356 Mdot
.39834 .44055 Mdot
.38159 .45895 Mdot
.42895 .34057 Mdot
.51175 .65239 Mdot
.36424 .63326 Mdot
.63721 .39954 Mdot
.64509 .41001 Mdot
.33657 .49731 Mdot
.51805 .71089 Mdot
.55003 .24595 Mdot
.40481 .33079 Mdot
.38242 .48647 Mdot
.50178 .67955 Mdot
.33353 .49538 Mdot
.62144 .54762 Mdot
.46795 .40602 Mdot
.49622 .64602 Mdot
.434 .15349 Mdot
.40461 .44799 Mdot
.41039 .41768 Mdot
.438 .4596 Mdot
.26322 .34716 Mdot
.32446 .51428 Mdot
.47208 .69128 Mdot
.41853 .4853 Mdot
.50489 .6942 Mdot
.66469 .41671 Mdot
.70781 .60399 Mdot
.50209 .69069 Mdot
.40513 .47462 Mdot
.18236 .38433 Mdot
.66098 .58138 Mdot
.36888 .46027 Mdot
.67357 .56721 Mdot
.46792 .6559 Mdot
.51416 .67345 Mdot
.51822 .55268 Mdot
.53065 .47565 Mdot
.6849 .59532 Mdot
.34238 .48955 Mdot
.64952 .76608 Mdot
.32579 .4879 Mdot
.70602 .42541 Mdot
.32931 .44482 Mdot
.36031 .42843 Mdot
.36807 .18937 Mdot
.50633 .4987 Mdot
.79126 .59898 Mdot
.64443 .63648 Mdot
.63895 .77546 Mdot
.51495 .73121 Mdot
.60208 .29855 Mdot
.47389 .5575 Mdot
.51833 .5642 Mdot
.6473 .43553 Mdot
.36797 .44969 Mdot
.55112 .62676 Mdot
.65842 .6069 Mdot
.5912 .27313 Mdot
.41268 .46608 Mdot
.63618 .43181 Mdot
.46215 .54428 Mdot
.67945 .6028 Mdot
.4879 .66691 Mdot
.50725 .65859 Mdot
.51693 .27338 Mdot
.39484 .45191 Mdot
.38688 .456 Mdot
.6602 .57565 Mdot
.42188 .52263 Mdot
.56001 .27092 Mdot
.58935 .52338 Mdot
.68214 .56795 Mdot
.46781 .40298 Mdot
.52172 .6908 Mdot
.38428 .476 Mdot
.42538 .34063 Mdot
.58803 .79441 Mdot
.27553 .68493 Mdot
.57383 .27824 Mdot
.31904 .32931 Mdot
.47218 .68963 Mdot
.67699 .5729 Mdot
.41716 .23499 Mdot
.32544 .43514 Mdot
.37827 .47909 Mdot
.29726 .3296 Mdot
.40218 .33061 Mdot
.54549 .47617 Mdot
.34565 .54368 Mdot
.39642 .31171 Mdot
.33519 .49621 Mdot
.37495 .51174 Mdot
.37128 .42665 Mdot
.32766 .44729 Mdot
.50579 .68564 Mdot
.38693 .65786 Mdot
.67418 .4012 Mdot
.28153 .67651 Mdot
.68992 .4475 Mdot
.39876 .48986 Mdot
.34125 .49687 Mdot
.30153 .65849 Mdot
.36107 .34698 Mdot
.49448 .67554 Mdot
.50134 .73353 Mdot
.69963 .55819 Mdot
.3267 .49529 Mdot
.63607 .40025 Mdot
.43718 .45972 Mdot
.67138 .42435 Mdot
.50547 .68341 Mdot
.66037 .37268 Mdot
.69303 .54249 Mdot
.66879 .37964 Mdot
.64469 .42979 Mdot
.66368 .59762 Mdot
.51714 .70117 Mdot
.37324 .49051 Mdot
.66433 .59941 Mdot
.54861 .25021 Mdot
.58546 .30596 Mdot
.45049 .6984 Mdot
.39217 .51835 Mdot
.31166 .46453 Mdot
.70122 .51389 Mdot
.65186 .37925 Mdot
.42295 .36132 Mdot
.51103 .70539 Mdot
.57177 .30939 Mdot
.50724 .69048 Mdot
.50113 .24852 Mdot
.57629 .27469 Mdot
.52343 .59224 Mdot
.37527 .26821 Mdot
.64617 .60914 Mdot
.36404 .41782 Mdot
.46169 .72676 Mdot
.66738 .42476 Mdot
.68138 .61401 Mdot
.63881 .64341 Mdot
.41039 .49644 Mdot
.48439 .62305 Mdot
.46181 .67959 Mdot
.5193 .56895 Mdot
.67981 .57206 Mdot
.4322 .66214 Mdot
.39727 .45894 Mdot
.6493 .61334 Mdot
.33185 .44209 Mdot
.40227 .73694 Mdot
.69061 .46353 Mdot
.56237 .59518 Mdot
.33472 .49361 Mdot
.66676 .43428 Mdot
.33484 .49475 Mdot
.38204 .76057 Mdot
.37963 .28387 Mdot
.36853 .42561 Mdot
.34312 .34309 Mdot
.6961 .50399 Mdot
.51196 .69264 Mdot
.29528 .47651 Mdot
.51073 .58886 Mdot
.3834 .50516 Mdot
.13541 .55244 Mdot
.58499 .26244 Mdot
.55699 .3249 Mdot
.40698 .46865 Mdot
.38684 .44595 Mdot
.26393 .52947 Mdot
.43287 .75402 Mdot
.51517 .55097 Mdot
.37183 .47791 Mdot
.27262 .35044 Mdot
.6665 .58286 Mdot
.32659 .46662 Mdot
.36536 .43993 Mdot
.656 .47415 Mdot
.66803 .57658 Mdot
.67294 .37602 Mdot
.52046 .56969 Mdot
.6962 .38173 Mdot
.56381 .24469 Mdot
.32738 .33535 Mdot
.32792 .30901 Mdot
.46621 .41137 Mdot
.60164 .28257 Mdot
.38959 .49699 Mdot
.56146 .5856 Mdot
.40231 .46528 Mdot
.58056 .29021 Mdot
.68039 .56508 Mdot
.50101 .68232 Mdot
.41942 .7565 Mdot
.50377 .57799 Mdot
.36823 .49811 Mdot
.59157 .31151 Mdot
.49716 .69114 Mdot
.56014 .80981 Mdot
.51004 .67835 Mdot
.67595 .59666 Mdot
.66144 .61624 Mdot
.58011 .27203 Mdot
.50794 .69061 Mdot
.68984 .37584 Mdot
.70124 .63027 Mdot
.39026 .4201 Mdot
.6954 .54355 Mdot
.48146 .64518 Mdot
.48553 .64878 Mdot
.53055 .6669 Mdot
.3488 .50636 Mdot
.38565 .34558 Mdot
.36663 .55094 Mdot
.66047 .57795 Mdot
.6458 .43891 Mdot
.41968 .2928 Mdot
.37841 .59569 Mdot
.45577 .38308 Mdot
.29617 .46906 Mdot
.34512 .46503 Mdot
.3505 .44936 Mdot
.36438 .52034 Mdot
.57308 .5326 Mdot
.39681 .43989 Mdot
.6733 .56254 Mdot
.67673 .41394 Mdot
.38225 .48447 Mdot
.51638 .58655 Mdot
.57421 .4846 Mdot
.55253 .27228 Mdot
.39351 .70691 Mdot
.45298 .71527 Mdot
.49784 .6896 Mdot
.65379 .384 Mdot
.6666 .37091 Mdot
.56081 .29282 Mdot
.6766 .60631 Mdot
.5104 .67355 Mdot
.35285 .23264 Mdot
.5639 .25966 Mdot
.352 .45336 Mdot
.42807 .34021 Mdot
.25041 .36579 Mdot
.33909 .4489 Mdot
.36066 .45068 Mdot
.50565 .59407 Mdot
.63458 .40524 Mdot
.26562 .70396 Mdot
.50576 .79345 Mdot
.58247 .26676 Mdot
.56088 .28723 Mdot
.53369 .67004 Mdot
.34796 .48218 Mdot
.68855 .58433 Mdot
.35289 .31916 Mdot
.67587 .50781 Mdot
.63099 .65415 Mdot
.68162 .4953 Mdot
.34576 .44918 Mdot
.36808 .71227 Mdot
.33847 .42907 Mdot
.46493 .65941 Mdot
.52445 .66501 Mdot
.49052 .6765 Mdot
.66613 .58649 Mdot
.46468 .26812 Mdot
.68802 .55817 Mdot
.57066 .57917 Mdot
.47511 .68634 Mdot
.51996 .48978 Mdot
.64341 .40885 Mdot
.33175 .50789 Mdot
.57707 .29373 Mdot
.60995 .33119 Mdot
.29407 .46435 Mdot
.32156 .33123 Mdot
.67554 .37941 Mdot
.50799 .71374 Mdot
.33526 .51116 Mdot
.648 .6481 Mdot
.44186 .34318 Mdot
.71173 .48884 Mdot
.55315 .61932 Mdot
.57715 .26029 Mdot
.24019 .63833 Mdot
.56217 .27093 Mdot
.68546 .60005 Mdot
.40172 .44543 Mdot
.35021 .4819 Mdot
.36737 .44209 Mdot
.32059 .45368 Mdot
.67037 .58204 Mdot
.38733 .42059 Mdot
.51306 .3334 Mdot
.51353 .55455 Mdot
.56499 .50461 Mdot
.5965 .28303 Mdot
.70501 .59903 Mdot
.67291 .41755 Mdot
.49777 .56892 Mdot
.58105 .31505 Mdot
.34371 .51642 Mdot
.40435 .4722 Mdot
.51417 .5532 Mdot
.3033 .5015 Mdot
.31209 .48285 Mdot
.68044 .40363 Mdot
.55984 .4814 Mdot
.55266 .25945 Mdot
.56805 .27543 Mdot
.69654 .60326 Mdot
.50755 .69113 Mdot
.55307 .26802 Mdot
.68335 .43644 Mdot
.32602 .47098 Mdot
.33349 .4401 Mdot
.48147 .64678 Mdot
.4564 .27276 Mdot
.55253 .27269 Mdot
.38301 .52822 Mdot
.50031 .64764 Mdot
.46154 .68302 Mdot
.37217 .47702 Mdot
.40441 .43198 Mdot
.53777 .69894 Mdot
.56421 .2954 Mdot
.70004 .60166 Mdot
.47523 .39001 Mdot
.71206 .57844 Mdot
.48419 .67083 Mdot
.33773 .40297 Mdot
.51763 .70383 Mdot
.40861 .49833 Mdot
.80361 .63252 Mdot
.394 .4376 Mdot
.43843 .5713 Mdot
.57349 .43809 Mdot
.64157 .40979 Mdot
.64557 .42092 Mdot
.5175 .57821 Mdot
.47801 .71016 Mdot
.29813 .43958 Mdot
.57177 .29291 Mdot
.6397 .7747 Mdot
.54243 .68604 Mdot
.64608 .43034 Mdot
.63624 .38805 Mdot
.67673 .56684 Mdot
.34507 .46907 Mdot
.3865 .47609 Mdot
.66865 .37884 Mdot
.65048 .51066 Mdot
.50355 .70409 Mdot
.38653 .45573 Mdot
.36441 .51851 Mdot
.675 .40389 Mdot
.6707 .54445 Mdot
.49364 .63059 Mdot
.35235 .50856 Mdot
.37432 .28986 Mdot
.6932 .61525 Mdot
.37262 .50465 Mdot
.36041 .41792 Mdot
.58668 .27711 Mdot
.3122 .32759 Mdot
.45059 .27745 Mdot
.71339 .57157 Mdot
.52119 .57965 Mdot
.34019 .45037 Mdot
.64549 .41602 Mdot
.35068 .52389 Mdot
.42144 .84361 Mdot
.51702 .55771 Mdot
.39567 .4596 Mdot
.43171 .4909 Mdot
.48843 .65717 Mdot
.3876 .44993 Mdot
.61393 .58863 Mdot
.66425 .38768 Mdot
.39632 .46141 Mdot
.23865 .49785 Mdot
.67713 .56731 Mdot
.29508 .47386 Mdot
.57192 .25655 Mdot
.53458 .47916 Mdot
.18692 .45169 Mdot
.65899 .45057 Mdot
.59645 .2716 Mdot
.34854 .47354 Mdot
.70071 .41207 Mdot
.66438 .5564 Mdot
.42755 .55115 Mdot
.38249 .50088 Mdot
.70578 .56679 Mdot
.66421 .59226 Mdot
.57892 .26749 Mdot
.77914 .71889 Mdot
.37618 .42572 Mdot
.37313 .46553 Mdot
.68805 .78274 Mdot
.5362 .70871 Mdot
.36709 .46074 Mdot
.35878 .48305 Mdot
.6879 .6057 Mdot
.47197 .24122 Mdot
.31898 .33016 Mdot
.58697 .5264 Mdot
.69215 .61424 Mdot
.70834 .39669 Mdot
.67138 .3848 Mdot
.59373 .2653 Mdot
.50236 .67253 Mdot
.57275 .30858 Mdot
.66428 .39965 Mdot
.36273 .44605 Mdot
.70281 .58344 Mdot
.20621 .54792 Mdot
.66682 .60721 Mdot
.65969 .44685 Mdot
.46553 .659 Mdot
.34513 .75991 Mdot
.44822 .85703 Mdot
.4579 .55448 Mdot
.66609 .6233 Mdot
.58494 .27149 Mdot
.51462 .79804 Mdot
.38203 .48521 Mdot
.37978 .7476 Mdot
.36938 .46538 Mdot
.5485 .63711 Mdot
.69089 .41268 Mdot
.52165 .55779 Mdot
.40921 .49805 Mdot
.3164 .33187 Mdot
.66711 .5999 Mdot
.69258 .5765 Mdot
.4181 .48568 Mdot
.67885 .59662 Mdot
.39128 .46986 Mdot
.67517 .40987 Mdot
.79726 .65587 Mdot
.39101 .4849 Mdot
.42586 .42373 Mdot
.65309 .62227 Mdot
.4464 .70694 Mdot
.71083 .38703 Mdot
.37508 .67955 Mdot
.64624 .65741 Mdot
.68719 .58456 Mdot
.39467 .69469 Mdot
.64813 .38631 Mdot
.49732 .57056 Mdot
.70338 .38594 Mdot
.3763 .47088 Mdot
.34328 .45265 Mdot
.36502 .52121 Mdot
.35508 .47971 Mdot
.35204 .73285 Mdot
.31184 .48636 Mdot
.25666 .59366 Mdot
.40243 .45182 Mdot
.44442 .56224 Mdot
.68326 .55932 Mdot
.41052 .41886 Mdot
.49173 .39371 Mdot
.38322 .43284 Mdot
.50774 .73363 Mdot
.70837 .59301 Mdot
.73554 .65174 Mdot
.66891 .58102 Mdot
.65143 .41449 Mdot
.66992 .60011 Mdot
.41484 .45986 Mdot
.49401 .65906 Mdot
.65344 .39556 Mdot
.45757 .54484 Mdot
.65366 .4409 Mdot
.39754 .45597 Mdot
.64063 .60305 Mdot
.64057 .38741 Mdot
.31391 .4529 Mdot
.49657 .65824 Mdot
.30384 .29963 Mdot
.48139 .63002 Mdot
.37895 .45024 Mdot
.37292 .45329 Mdot
.51372 .55158 Mdot
.67462 .60315 Mdot
.52143 .69902 Mdot
.64277 .47439 Mdot
.57589 .31263 Mdot
.49663 .6717 Mdot
.4385 .45977 Mdot
.43601 .34185 Mdot
.49192 .65105 Mdot
.26178 .35812 Mdot
.68836 .60014 Mdot
.47813 .6654 Mdot
.43773 .49562 Mdot
.27769 .66999 Mdot
.56572 .27219 Mdot
.68425 .37145 Mdot
.40941 .31756 Mdot
.66932 .38519 Mdot
.62201 .60461 Mdot
.6636 .36218 Mdot
.66811 .57177 Mdot
.30898 .38457 Mdot
.51166 .46857 Mdot
.66489 .61069 Mdot
.64671 .62301 Mdot
.67335 .39597 Mdot
.38809 .51848 Mdot
.5601 .49444 Mdot
.30137 .43217 Mdot
.34433 .39581 Mdot
.71384 .58805 Mdot
.47455 .67355 Mdot
.50593 .72136 Mdot
.41542 .40771 Mdot
.51133 .65967 Mdot
.65893 .4073 Mdot
.46611 .41847 Mdot
.40343 .69933 Mdot
.68718 .56404 Mdot
.55996 .47303 Mdot
.3428 .49911 Mdot
.68442 .41464 Mdot
.65908 .41026 Mdot
.66521 .59243 Mdot
.31325 .70479 Mdot
.31361 .41898 Mdot
.52404 .73439 Mdot
.47734 .67441 Mdot
.48672 .65752 Mdot
.52197 .67898 Mdot
.46479 .26588 Mdot
.68203 .61373 Mdot
.47582 .70488 Mdot
.31844 .46165 Mdot
.34638 .47637 Mdot
.50982 .56597 Mdot
.57844 .3052 Mdot
.3229 .43985 Mdot
.29752 .44061 Mdot
.37439 .47712 Mdot
.63997 .40568 Mdot
.27296 .40402 Mdot
.5114 .55566 Mdot
.63556 .40355 Mdot
.63766 .40785 Mdot
.52011 .57749 Mdot
.3056 .38468 Mdot
.27611 .70604 Mdot
.41965 .47677 Mdot
.49308 .74099 Mdot
.64898 .42498 Mdot
.58602 .3637 Mdot
.44741 .56774 Mdot
.34122 .48477 Mdot
.58435 .50869 Mdot
.66996 .41223 Mdot
.51708 .72992 Mdot
.37985 .4676 Mdot
.5018 .58172 Mdot
.5672 .2645 Mdot
.3932 .55399 Mdot
.50555 .59339 Mdot
.51008 .69649 Mdot
.61287 .42779 Mdot
.47407 .66566 Mdot
.65583 .36985 Mdot
.29462 .4541 Mdot
.88239 .57631 Mdot
.66514 .42403 Mdot
.65575 .76757 Mdot
.51428 .47177 Mdot
.39665 .47725 Mdot
.65876 .38434 Mdot
.53767 .66897 Mdot
.69212 .61646 Mdot
.40207 .34834 Mdot
.51169 .68899 Mdot
.49763 .56691 Mdot
.51071 .57027 Mdot
.67515 .40197 Mdot
.47912 .68778 Mdot
.37187 .41766 Mdot
.50578 .65864 Mdot
.70099 .57662 Mdot
.40739 .49429 Mdot
.63498 .64781 Mdot
.3946 .40616 Mdot
.50642 .65378 Mdot
.6505 .44305 Mdot
.57254 .24498 Mdot
.40516 .47872 Mdot
.72402 .65604 Mdot
.34826 .47413 Mdot
.67578 .56582 Mdot
.56364 .40882 Mdot
.21259 .55229 Mdot
.35393 .46215 Mdot
.34571 .50033 Mdot
.68582 .54312 Mdot
.35535 .46479 Mdot
.33857 .44149 Mdot
.43121 .66549 Mdot
.49416 .64932 Mdot
.37963 .48428 Mdot
.68214 .39055 Mdot
.23932 .53395 Mdot
.38354 .44012 Mdot
.61303 .58259 Mdot
.29368 .32524 Mdot
.5454 .38255 Mdot
.36889 .38349 Mdot
.36377 .30075 Mdot
.37266 .45731 Mdot
.34401 .48583 Mdot
.4193 .48059 Mdot
.37049 .71804 Mdot
.66671 .39614 Mdot
.67351 .43285 Mdot
.58731 .25319 Mdot
.2923 .33167 Mdot
.57184 .26934 Mdot
.66149 .55781 Mdot
.54375 .4746 Mdot
.50705 .555 Mdot
.50707 .69234 Mdot
.3746 .44141 Mdot
.66459 .44186 Mdot
.38444 .4737 Mdot
.38033 .50563 Mdot
.66227 .40619 Mdot
.66432 .41417 Mdot
.64353 .44891 Mdot
.56832 .25492 Mdot
.49509 .68136 Mdot
.40788 .4488 Mdot
.56353 .25681 Mdot
.35849 .51845 Mdot
.46476 .37407 Mdot
.49385 .67879 Mdot
.5081 .65414 Mdot
.49152 .72081 Mdot
.39193 .4887 Mdot
.41421 .48791 Mdot
.68991 .55816 Mdot
.48095 .64712 Mdot
.68875 .5916 Mdot
.66034 .384 Mdot
.68523 .40645 Mdot
.37536 .47082 Mdot
.41884 .52407 Mdot
.59441 .292 Mdot
.64549 .38321 Mdot
.50928 .60428 Mdot
.58133 .2525 Mdot
.35347 .44416 Mdot
.66543 .38413 Mdot
.59525 .29996 Mdot
.30003 .70359 Mdot
.59669 .6607 Mdot
.58256 .25041 Mdot
.41412 .4935 Mdot
.3548 .58942 Mdot
.39082 .28291 Mdot
.55383 .28052 Mdot
.68586 .56069 Mdot
.3656 .48782 Mdot
.58365 .54737 Mdot
.55627 .25513 Mdot
.44092 .27933 Mdot
.65908 .40117 Mdot
.36339 .39526 Mdot
.29591 .52561 Mdot
.40416 .69174 Mdot
.56966 .24486 Mdot
.50409 .65235 Mdot
.50263 .64019 Mdot
.35228 .45533 Mdot
.53803 .47676 Mdot
.65574 .57884 Mdot
.66847 .37076 Mdot
.67312 .4352 Mdot
.51015 .64219 Mdot
.46731 .41025 Mdot
.67963 .38807 Mdot
.35098 .48576 Mdot
.57396 .2298 Mdot
.32126 .48857 Mdot
.49992 .2795 Mdot
.21376 .51103 Mdot
.37622 .38472 Mdot
.57492 .24591 Mdot
.65867 .57288 Mdot
.66331 .58199 Mdot
.66968 .59322 Mdot
.68165 .39794 Mdot
.39099 .32249 Mdot
.68041 .43173 Mdot
.64843 .8006 Mdot
.58418 .26069 Mdot
.38347 .20404 Mdot
.32667 .44165 Mdot
.39821 .47457 Mdot
.32437 .47715 Mdot
.37333 .51869 Mdot
.37419 .45747 Mdot
.70183 .56172 Mdot
.69964 .39198 Mdot
.67744 .50257 Mdot
.48837 .70199 Mdot
.55469 .80974 Mdot
.64271 .40704 Mdot
.50792 .59648 Mdot
.58905 .29573 Mdot
.3097 .31214 Mdot
.59087 .24461 Mdot
.64948 .37666 Mdot
.35621 .43279 Mdot
.5336 .66788 Mdot
.34048 .24316 Mdot
.38306 .44413 Mdot
.64883 .38008 Mdot
.70464 .41189 Mdot
.2919 .6875 Mdot
.33913 .53868 Mdot
.66246 .49812 Mdot
.42726 .34845 Mdot
.59578 .25693 Mdot
.39486 .51811 Mdot
.3406 .32143 Mdot
.66635 .39998 Mdot
.66287 .42974 Mdot
.56381 .30295 Mdot
.48884 .77084 Mdot
.47721 .70282 Mdot
.45534 .6764 Mdot
.70654 .57212 Mdot
.4024 .47178 Mdot
.67374 .39122 Mdot
.46376 .65575 Mdot
.47838 .34952 Mdot
.67395 .58605 Mdot
.63572 .39226 Mdot
.34979 .47677 Mdot
.35259 .46346 Mdot
.57343 .26745 Mdot
.57379 .4577 Mdot
.30146 .43213 Mdot
.64308 .77303 Mdot
.44244 .36641 Mdot
.51501 .47139 Mdot
.37865 .47921 Mdot
.52083 .68427 Mdot
.51949 .5777 Mdot
.57945 .29691 Mdot
.34284 .52043 Mdot
.37697 .77758 Mdot
.46851 .69568 Mdot
.68724 .59222 Mdot
.51638 .59249 Mdot
.33072 .33803 Mdot
.35085 .47703 Mdot
.3699 .46572 Mdot
.34626 .50479 Mdot
.31797 .7465 Mdot
.68905 .41634 Mdot
.51992 .67403 Mdot
.57486 .25747 Mdot
.51344 .67423 Mdot
.64924 .36952 Mdot
.56199 .47466 Mdot
.41131 .44989 Mdot
.47337 .71077 Mdot
.50701 .66688 Mdot
.67951 .56606 Mdot
.66305 .59832 Mdot
.68351 .44026 Mdot
.36598 .48546 Mdot
.50625 .55443 Mdot
.47289 .69421 Mdot
.68675 .37688 Mdot
.57382 .2695 Mdot
.62115 .60569 Mdot
.40449 .45458 Mdot
.67209 .39976 Mdot
.2939 .45485 Mdot
.49073 .69678 Mdot
.64119 .39314 Mdot
.49746 .57488 Mdot
.5694 .29989 Mdot
.34171 .45282 Mdot
.71313 .47536 Mdot
.50442 .58769 Mdot
.4006 .48211 Mdot
.22057 .52888 Mdot
.53871 .47708 Mdot
.52867 .62225 Mdot
.69017 .39868 Mdot
.50059 .57172 Mdot
.5214 .66392 Mdot
.26056 .64716 Mdot
.67006 .42849 Mdot
.3007 .55316 Mdot
.50438 .46394 Mdot
.41496 .49076 Mdot
.51117 .69275 Mdot
.53175 .32064 Mdot
.60971 .77974 Mdot
.40161 .28656 Mdot
.3929 .46152 Mdot
.66992 .38546 Mdot
.56736 .26755 Mdot
.69305 .57811 Mdot
.70583 .61878 Mdot
.51626 .26 Mdot
.64002 .42157 Mdot
.37445 .44099 Mdot
.47508 .67248 Mdot
.68382 .59499 Mdot
.26272 .53352 Mdot
.69301 .42326 Mdot
.68103 .38667 Mdot
.33097 .47472 Mdot
.57099 .27073 Mdot
.57307 .55188 Mdot
.68562 .42103 Mdot
.70121 .39649 Mdot
.43243 .65147 Mdot
.59801 .26209 Mdot
.36 .51174 Mdot
.416 .40812 Mdot
.32736 .45323 Mdot
.60522 .80876 Mdot
.50049 .56801 Mdot
.48986 .70383 Mdot
.36517 .45548 Mdot
.69959 .50812 Mdot
.6744 .42163 Mdot
.42745 .34918 Mdot
.65802 .55665 Mdot
.66607 .60103 Mdot
.66267 .38905 Mdot
.38632 .46692 Mdot
.70592 .54538 Mdot
.59374 .26793 Mdot
.35933 .5121 Mdot
.4102 .49575 Mdot
.49674 .63584 Mdot
.70339 .5802 Mdot
.23383 .52893 Mdot
.69599 .58065 Mdot
.68968 .60736 Mdot
.49847 .61999 Mdot
.35193 .45509 Mdot
.64268 .39971 Mdot
.62919 .42237 Mdot
.39702 .52233 Mdot
.59836 .35636 Mdot
.48541 .71268 Mdot
.68882 .35887 Mdot
.3701 .77734 Mdot
.3398 .43352 Mdot
.5187 .59451 Mdot
.55812 .60624 Mdot
.65849 .61336 Mdot
.35652 .45696 Mdot
.50453 .69597 Mdot
.69851 .40526 Mdot
.67564 .38855 Mdot
.32414 .4367 Mdot
.66264 .5848 Mdot
.59108 .30454 Mdot
.65578 .40816 Mdot
.47788 .39872 Mdot
.3954 .45663 Mdot
.72805 .62688 Mdot
.65293 .40612 Mdot
.18641 .38554 Mdot
.70356 .5121 Mdot
.48831 .65418 Mdot
.33909 .49151 Mdot
.50917 .63825 Mdot
.5955 .26356 Mdot
.68572 .36707 Mdot
.66856 .56604 Mdot
.30826 .51357 Mdot
.82791 .49359 Mdot
.67865 .39683 Mdot
.50444 .68347 Mdot
.36475 .44716 Mdot
.39384 .6841 Mdot
.38534 .4861 Mdot
.47231 .23633 Mdot
.55113 .26482 Mdot
.62266 .60151 Mdot
.66066 .57514 Mdot
.34736 .50036 Mdot
.55969 .2663 Mdot
.63174 .42889 Mdot
.6629 .40559 Mdot
.8237 .55683 Mdot
.50326 .58997 Mdot
.63308 .36851 Mdot
.39487 .48593 Mdot
.67943 .37471 Mdot
.37998 .5961 Mdot
.6636 .59327 Mdot
.32913 .45175 Mdot
.63151 .41019 Mdot
.5716 .79136 Mdot
.43072 .34499 Mdot
.39442 .45833 Mdot
.42775 .51227 Mdot
.67101 .57056 Mdot
.51365 .79807 Mdot
.69279 .40927 Mdot
.34933 .51856 Mdot
.65851 .55889 Mdot
.32727 .3797 Mdot
.63444 .47708 Mdot
.49471 .68126 Mdot
.63022 .39855 Mdot
.70235 .59754 Mdot
.36881 .39664 Mdot
.58716 .30276 Mdot
.68825 .43321 Mdot
.64126 .43143 Mdot
.40557 .49058 Mdot
.34883 .51193 Mdot
.43033 .50986 Mdot
.50343 .70885 Mdot
.69148 .6034 Mdot
.37997 .50855 Mdot
.46085 .36603 Mdot
.37837 .51629 Mdot
.69673 .60001 Mdot
.8281 .65667 Mdot
.35355 .43521 Mdot
.40471 .45785 Mdot
.38665 .695 Mdot
.51947 .70543 Mdot
.50372 .64456 Mdot
.44995 .37097 Mdot
.37444 .49361 Mdot
.51637 .49211 Mdot
.49753 .68346 Mdot
.50687 .68116 Mdot
.51745 .49141 Mdot
.41066 .48774 Mdot
.46925 .64083 Mdot
.6821 .59602 Mdot
.66549 .6007 Mdot
.48891 .6568 Mdot
.32483 .49201 Mdot
.66255 .55886 Mdot
.32806 .70024 Mdot
.64453 .38091 Mdot
.33554 .32473 Mdot
.50696 .66286 Mdot
.42801 .33664 Mdot
.68591 .60067 Mdot
.20629 .39984 Mdot
.25818 .35146 Mdot
.35658 .42509 Mdot
.35307 .45724 Mdot
.58444 .27847 Mdot
.30406 .5055 Mdot
.52007 .57322 Mdot
.66987 .59475 Mdot
.57277 .53147 Mdot
.49016 .6757 Mdot
.37582 .49227 Mdot
.42446 .29471 Mdot
.191 .45647 Mdot
.4475 .45974 Mdot
.50372 .6739 Mdot
.49056 .66714 Mdot
.6812 .38354 Mdot
.65322 .37332 Mdot
.4088 .44772 Mdot
.665 .57673 Mdot
.4825 .65911 Mdot
.69948 .5928 Mdot
.66505 .40057 Mdot
.64427 .40669 Mdot
.51271 .55837 Mdot
.33635 .39814 Mdot
.66025 .39307 Mdot
.62179 .5592 Mdot
.46136 .3673 Mdot
.48095 .64425 Mdot
.67399 .79073 Mdot
.21543 .38182 Mdot
.40756 .7444 Mdot
.56702 .26598 Mdot
.31415 .38177 Mdot
.68234 .55458 Mdot
.3509 .50272 Mdot
.36555 .46783 Mdot
.50721 .57769 Mdot
.67814 .55367 Mdot
.59138 .28253 Mdot
.6646 .59739 Mdot
.57479 .2984 Mdot
.66756 .43508 Mdot
.38056 .44104 Mdot
.38172 .43378 Mdot
.69127 .57537 Mdot
.67043 .37584 Mdot
.64013 .38882 Mdot
.5656 .28002 Mdot
.30551 .31408 Mdot
.67338 .40213 Mdot
.508 .66484 Mdot
.28578 .56147 Mdot
.50976 .57099 Mdot
.38027 .46687 Mdot
.35841 .30138 Mdot
.25312 .6301 Mdot
.37016 .52232 Mdot
.51402 .59218 Mdot
.78346 .71411 Mdot
.38902 .44101 Mdot
.82784 .44466 Mdot
.50738 .55646 Mdot
.51788 .70395 Mdot
.64703 .39195 Mdot
.50651 .59322 Mdot
.2644 .41651 Mdot
.70196 .4567 Mdot
.38759 .5243 Mdot
.47739 .70436 Mdot
.49813 .7184 Mdot
.56072 .47758 Mdot
.60169 .81021 Mdot
.57398 .2576 Mdot
.59214 .27161 Mdot
.67563 .42402 Mdot
.63146 .62259 Mdot
.31615 .47389 Mdot
.58977 .2692 Mdot
.45563 .65683 Mdot
.33731 .49516 Mdot
.54141 .47776 Mdot
.56244 .49967 Mdot
.51829 .65872 Mdot
.40099 .41488 Mdot
.67479 .42326 Mdot
.50298 .68206 Mdot
.55916 .48804 Mdot
.32784 .46939 Mdot
.49236 .67746 Mdot
.68266 .60648 Mdot
.48209 .5306 Mdot
.50853 .65974 Mdot
.40997 .35036 Mdot
.68799 .57904 Mdot
.54888 .47516 Mdot
.41698 .21685 Mdot
.14652 .46379 Mdot
.66451 .58491 Mdot
.65029 .3816 Mdot
.67318 .39223 Mdot
.67578 .40619 Mdot
.51142 .69976 Mdot
.66558 .41851 Mdot
.48363 .70396 Mdot
.6747 .62816 Mdot
.30467 .3299 Mdot
.57861 .27398 Mdot
.55065 .33717 Mdot
.49307 .65583 Mdot
.63578 .80412 Mdot
.56769 .86031 Mdot
.37097 .51666 Mdot
.66689 .61253 Mdot
.56869 .25057 Mdot
.43733 .37211 Mdot
.58634 .27828 Mdot
.64887 .38581 Mdot
.32267 .33465 Mdot
.39108 .47138 Mdot
.59791 .62911 Mdot
.56776 .26865 Mdot
.50818 .68091 Mdot
.39571 .49268 Mdot
.62919 .38994 Mdot
.59548 .26645 Mdot
.56825 .28018 Mdot
.37502 .45908 Mdot
.50982 .71283 Mdot
.64268 .38822 Mdot
.70436 .56121 Mdot
.5809 .23092 Mdot
.37599 .54137 Mdot
.38321 .4378 Mdot
.37681 .42852 Mdot
.43551 .34912 Mdot
.63211 .62567 Mdot
.68614 .58014 Mdot
.44244 .28188 Mdot
.68521 .41248 Mdot
.40221 .28462 Mdot
.63465 .76744 Mdot
.5337 .31778 Mdot
.50119 .56786 Mdot
.5005 .56558 Mdot
.38605 .45195 Mdot
.47502 .84826 Mdot
.44331 .54611 Mdot
.65212 .56984 Mdot
.51076 .5772 Mdot
.64543 .37747 Mdot
.4784 .65339 Mdot
.30322 .52888 Mdot
.32457 .44064 Mdot
.70267 .55905 Mdot
.66825 .40495 Mdot
.41444 .84324 Mdot
.58116 .26065 Mdot
.44281 .37864 Mdot
.36248 .48361 Mdot
.38438 .45715 Mdot
.67711 .58057 Mdot
.67063 .5644 Mdot
.43213 .64969 Mdot
.53591 .37013 Mdot
.63896 .65437 Mdot
.71407 .56776 Mdot
.41216 .84345 Mdot
.55251 .62399 Mdot
.48298 .67824 Mdot
.52265 .57669 Mdot
.65654 .57901 Mdot
.36603 .45889 Mdot
.51684 .70766 Mdot
.43871 .54912 Mdot
.52692 .70542 Mdot
.53405 .47865 Mdot
.47505 .39051 Mdot
.34552 .46579 Mdot
.53097 .67272 Mdot
.49918 .67938 Mdot
.47691 .72819 Mdot
.51663 .57187 Mdot
.37454 .47927 Mdot
.35447 .52124 Mdot
.39796 .44357 Mdot
.43651 .60958 Mdot
.38841 .44998 Mdot
.62884 .77119 Mdot
.45959 .38386 Mdot
.67531 .24814 Mdot
.39407 .44498 Mdot
.68214 .60866 Mdot
.37416 .44343 Mdot
.55883 .27089 Mdot
.34384 .44565 Mdot
.52845 .47764 Mdot
.68149 .59147 Mdot
.38169 .76422 Mdot
.69454 .44058 Mdot
.37653 .43474 Mdot
.60132 .28596 Mdot
.72877 .72129 Mdot
.44117 .28644 Mdot
.43342 .64988 Mdot
.5056 .65883 Mdot
.70207 .40551 Mdot
.65501 .59118 Mdot
.64983 .41371 Mdot
.38383 .41876 Mdot
.51921 .56306 Mdot
.36644 .1954 Mdot
.44102 .32674 Mdot
.36582 .45658 Mdot
.3175 .41442 Mdot
.5147 .66037 Mdot
.67152 .42266 Mdot
.43511 .7597 Mdot
.32577 .48364 Mdot
.56725 .30089 Mdot
.55939 .25598 Mdot
.67615 .33993 Mdot
.47422 .58929 Mdot
.40838 .60007 Mdot
.67881 .58132 Mdot
.68064 .39478 Mdot
.56304 .25006 Mdot
.45652 .71712 Mdot
.65662 .59112 Mdot
.65764 .61275 Mdot
.70418 .58025 Mdot
.40021 .46098 Mdot
.51032 .56108 Mdot
.47708 .60962 Mdot
.50118 .58356 Mdot
.3225 .46141 Mdot
.63983 .42958 Mdot
.49785 .57277 Mdot
.57875 .28054 Mdot
.69696 .60452 Mdot
.64124 .40679 Mdot
.37499 .4509 Mdot
.49625 .68806 Mdot
.50043 .31029 Mdot
.71181 .50718 Mdot
.53979 .47624 Mdot
.5399 .47621 Mdot
.46479 .70094 Mdot
.57204 .57327 Mdot
.65461 .6303 Mdot
.28275 .67903 Mdot
.56458 .22359 Mdot
.3339 .52188 Mdot
.61081 .35501 Mdot
.68255 .43019 Mdot
.65333 .39776 Mdot
.39397 .47284 Mdot
.68914 .38312 Mdot
.37797 .49006 Mdot
.6905 .39763 Mdot
.6049 .79065 Mdot
.34096 .42463 Mdot
.65728 .40512 Mdot
.32056 .52954 Mdot
.40509 .4783 Mdot
.51919 .67888 Mdot
.69652 .41465 Mdot
.35564 .42529 Mdot
.50936 .13395 Mdot
.68182 .56656 Mdot
.51558 .57099 Mdot
.50309 .43816 Mdot
.6799 .60148 Mdot
.47776 .69782 Mdot
.35973 .48839 Mdot
.58551 .25959 Mdot
.48434 .67161 Mdot
.71544 .38242 Mdot
.56928 .2739 Mdot
.46912 .42218 Mdot
.48474 .66521 Mdot
.50736 .5691 Mdot
.56285 .29342 Mdot
.39067 .52303 Mdot
.65521 .39967 Mdot
.71106 .51216 Mdot
.51205 .59444 Mdot
.38805 .47393 Mdot
.63305 .38658 Mdot
.66825 .60021 Mdot
.36116 .44141 Mdot
.67429 .39023 Mdot
.51968 .58518 Mdot
.40823 .46561 Mdot
.38765 .49335 Mdot
.47625 .77306 Mdot
.57061 .42125 Mdot
.57855 .27683 Mdot
.46642 .65762 Mdot
.32055 .45586 Mdot
.56089 .268 Mdot
.67953 .49351 Mdot
.41728 .43041 Mdot
.47193 .69823 Mdot
.31949 .69883 Mdot
.67104 .37162 Mdot
.66083 .58431 Mdot
.65502 .44606 Mdot
.59278 .25746 Mdot
.62447 .85017 Mdot
.51956 .56903 Mdot
.42356 .45767 Mdot
.33862 .43931 Mdot
.69768 .37635 Mdot
.4974 .67653 Mdot
.63476 .65373 Mdot
.34029 .45549 Mdot
.32838 .41136 Mdot
.37749 .46333 Mdot
.71273 .46653 Mdot
.50839 .70498 Mdot
.37849 .46564 Mdot
.38635 .53223 Mdot
.33402 .44043 Mdot
.59757 .29165 Mdot
.37879 .20661 Mdot
.39394 .51383 Mdot
.90481 .53455 Mdot
.52509 .56645 Mdot
.66629 .40877 Mdot
.41271 .35204 Mdot
.5063 .4331 Mdot
.61203 .19373 Mdot
.48102 .70557 Mdot
.48746 .73921 Mdot
.64492 .40584 Mdot
.51892 .28999 Mdot
.56974 .56811 Mdot
.38883 .49509 Mdot
.35847 .48391 Mdot
.6488 .38591 Mdot
.68651 .37585 Mdot
.52335 .56573 Mdot
.4214 .48335 Mdot
.39411 .40737 Mdot
.64919 .44178 Mdot
.38657 .44578 Mdot
.24261 .60958 Mdot
.6793 .61958 Mdot
.49254 .652 Mdot
.69362 .57619 Mdot
.68833 .61812 Mdot
.41955 .75604 Mdot
.44149 .36265 Mdot
.70578 .56893 Mdot
.64748 .60661 Mdot
.5337 .32603 Mdot
.40142 .69559 Mdot
.5959 .29555 Mdot
.4671 .54078 Mdot
.68123 .40997 Mdot
.37225 .47861 Mdot
.51048 .70329 Mdot
.50894 .20909 Mdot
.66412 .67204 Mdot
.25626 .40518 Mdot
.35871 .51068 Mdot
.67766 .41672 Mdot
.51437 .59528 Mdot
.41799 .43074 Mdot
.39419 .2832 Mdot
.3897 .45764 Mdot
.66317 .37058 Mdot
.40334 .698 Mdot
.69401 .52188 Mdot
.7203 .58796 Mdot
.54061 .70079 Mdot
.37355 .4429 Mdot
.50022 .70539 Mdot
.71174 .591 Mdot
.56438 .26088 Mdot
.5841 .27 Mdot
.37496 .43426 Mdot
.51414 .47215 Mdot
.5546 .22564 Mdot
.39276 .49278 Mdot
.40735 .49054 Mdot
.50173 .57176 Mdot
.40731 .49161 Mdot
.36083 .52427 Mdot
.37458 .50988 Mdot
.35654 .51701 Mdot
.65659 .58601 Mdot
.41781 .73945 Mdot
.42367 .47297 Mdot
.40384 .43278 Mdot
.70562 .60628 Mdot
.39672 .42497 Mdot
.66812 .58259 Mdot
.67069 .6561 Mdot
.69934 .56341 Mdot
.58263 .27002 Mdot
.6327 .3845 Mdot
.4503 .7445 Mdot
.48191 .66027 Mdot
.67252 .6095 Mdot
.57516 .30317 Mdot
.66681 .591 Mdot
.68669 .4017 Mdot
.67985 .51799 Mdot
.51555 .61846 Mdot
.47965 .40745 Mdot
.39543 .70679 Mdot
.74415 .61037 Mdot
.684 .38096 Mdot
.48517 .65857 Mdot
.61487 .59298 Mdot
.35179 .50248 Mdot
.57818 .25814 Mdot
.38534 .45235 Mdot
.69378 .60643 Mdot
.6796 .4126 Mdot
.4355 .70071 Mdot
.57947 .27752 Mdot
.70669 .77331 Mdot
.6649 .44224 Mdot
.34219 .43991 Mdot
.70876 .60228 Mdot
.64629 .53095 Mdot
.67233 .56647 Mdot
.30557 .32679 Mdot
.56438 .59088 Mdot
.51193 .22584 Mdot
.48899 .66526 Mdot
.50137 .59327 Mdot
.153 .54245 Mdot
.69524 .70713 Mdot
.49329 .69395 Mdot
.61919 .43611 Mdot
.39429 .45099 Mdot
.37447 .51356 Mdot
.33057 .40335 Mdot
.52117 .70838 Mdot
.3454 .5042 Mdot
.51479 .56683 Mdot
.44736 .36009 Mdot
.49224 .58981 Mdot
.69837 .42297 Mdot
.37976 .48863 Mdot
.71395 .58668 Mdot
.67158 .61075 Mdot
.4974 .5619 Mdot
.69899 .5802 Mdot
.41368 .46726 Mdot
.49129 .65859 Mdot
.56004 .49327 Mdot
.59305 .26079 Mdot
.66966 .75314 Mdot
.54842 .24451 Mdot
.59793 .24966 Mdot
.33836 .43412 Mdot
.64315 .40389 Mdot
.82285 .46526 Mdot
.35148 .50475 Mdot
.49997 .68361 Mdot
.33695 .44272 Mdot
.38022 .51099 Mdot
.41649 .46142 Mdot
.68067 .39542 Mdot
.43067 .34237 Mdot
.38592 .44521 Mdot
.71065 .578 Mdot
.51653 .48882 Mdot
.32269 .44197 Mdot
.58978 .5206 Mdot
.53034 .4784 Mdot
.73398 .61786 Mdot
.48994 .63871 Mdot
.64382 .39785 Mdot
.48906 .67375 Mdot
.53436 .69978 Mdot
.47788 .69755 Mdot
.48596 .60301 Mdot
.2747 .66828 Mdot
.82675 .4342 Mdot
.38655 .59782 Mdot
.39438 .71269 Mdot
.54081 .68752 Mdot
.76581 .42219 Mdot
.49757 .69678 Mdot
.47868 .70038 Mdot
.81232 .63529 Mdot
.49585 .71547 Mdot
.37574 .4716 Mdot
.37826 .43061 Mdot
.34013 .75637 Mdot
.60879 .26655 Mdot
.39998 .48047 Mdot
.36165 .5195 Mdot
.56075 .253 Mdot
.48414 .76751 Mdot
.52393 .5844 Mdot
.44772 .38645 Mdot
.5043 .59544 Mdot
.37516 .45832 Mdot
.34692 .45438 Mdot
.31637 .5054 Mdot
.18132 .4863 Mdot
.51962 .2345 Mdot
.49736 .72002 Mdot
.35783 .5296 Mdot
.7467 .58886 Mdot
.34136 .4796 Mdot
.33319 .45264 Mdot
.41745 .46684 Mdot
.64263 .39985 Mdot
.46959 .67267 Mdot
.29894 .43702 Mdot
.69383 .72719 Mdot
.35006 .47439 Mdot
.54544 .25321 Mdot
.59433 .31627 Mdot
.38559 .46802 Mdot
.48903 .71675 Mdot
.36943 .51359 Mdot
.49171 .64558 Mdot
.48242 .66958 Mdot
.34904 .40079 Mdot
.46804 .61923 Mdot
.47773 .65511 Mdot
.38738 .49544 Mdot
.67408 .37615 Mdot
.6478 .77116 Mdot
.38793 .47262 Mdot
.57471 .28035 Mdot
.35733 .45342 Mdot
.59942 .28794 Mdot
.40061 .50433 Mdot
.49926 .57645 Mdot
.20816 .55557 Mdot
.66409 .43062 Mdot
.58539 .23924 Mdot
.68424 .37852 Mdot
.31764 .48619 Mdot
.51355 .63651 Mdot
.6968 .52631 Mdot
.52347 .24622 Mdot
.50209 .57084 Mdot
.46117 .27402 Mdot
.51924 .50186 Mdot
.68437 .55658 Mdot
.52021 .67241 Mdot
.41251 .72058 Mdot
.58781 .51772 Mdot
.69938 .42317 Mdot
.63745 .38593 Mdot
.62481 .46721 Mdot
.79737 .65562 Mdot
.39535 .44773 Mdot
.58726 .54288 Mdot
.25215 .58736 Mdot
.30278 .50272 Mdot
.3419 .54258 Mdot
.64304 .43377 Mdot
.39994 .48086 Mdot
.42959 .31983 Mdot
.67207 .39554 Mdot
.5946 .28586 Mdot
.49117 .70501 Mdot
.56385 .28454 Mdot
.6062 .6787 Mdot
.4307 .66472 Mdot
.66397 .39417 Mdot
.35619 .51509 Mdot
.39698 .4798 Mdot
.52102 .70163 Mdot
.26303 .53262 Mdot
.49475 .64896 Mdot
.58499 .255 Mdot
.67433 .42808 Mdot
.44587 .14986 Mdot
.36263 .44723 Mdot
.50748 .66956 Mdot
.69247 .44258 Mdot
.35325 .46597 Mdot
.66216 .5874 Mdot
.34233 .50167 Mdot
.51161 .6746 Mdot
.40687 .49258 Mdot
.48751 .66608 Mdot
.67521 .38065 Mdot
.37686 .43329 Mdot
.35379 .44467 Mdot
.44646 .27896 Mdot
.59075 .28341 Mdot
.48341 .65053 Mdot
.42212 .32079 Mdot
.32733 .45325 Mdot
.37772 .28838 Mdot
.38236 .44078 Mdot
.39675 .69406 Mdot
.43647 .47045 Mdot
.51264 .56571 Mdot
.336 .44304 Mdot
.38903 .47103 Mdot
.26384 .5297 Mdot
.37297 .59423 Mdot
.4374 .61143 Mdot
.66182 .59716 Mdot
.51547 .69126 Mdot
.66955 .39094 Mdot
.69937 .40938 Mdot
.65998 .41752 Mdot
.55116 .25517 Mdot
.39696 .52405 Mdot
.38619 .47838 Mdot
.6469 .58668 Mdot
.58703 .26515 Mdot
.50287 .66873 Mdot
.57876 .26809 Mdot
.43738 .3615 Mdot
.5761 .28426 Mdot
.52085 .5743 Mdot
.69695 .51037 Mdot
.24952 .62096 Mdot
.58207 .29475 Mdot
.49025 .65387 Mdot
.50873 .48835 Mdot
.30148 .49661 Mdot
.57436 .81076 Mdot
.56328 .29686 Mdot
.64632 .47045 Mdot
.40871 .45871 Mdot
.40096 .34484 Mdot
.67007 .58323 Mdot
.56431 .28635 Mdot
.70377 .57725 Mdot
.36848 .51309 Mdot
.53221 .73297 Mdot
.50681 .68827 Mdot
.68336 .61981 Mdot
.33014 .45488 Mdot
.56378 .28537 Mdot
.65987 .39564 Mdot
.40196 .69335 Mdot
.67602 .62547 Mdot
.5071 .31843 Mdot
.40281 .28619 Mdot
.68006 .42202 Mdot
.39143 .65932 Mdot
.70103 .56737 Mdot
.35399 .52858 Mdot
.43215 .5412 Mdot
.32101 .47981 Mdot
.6394 .39027 Mdot
.65258 .39763 Mdot
.7414 .62904 Mdot
.3497 .44751 Mdot
.42314 .46642 Mdot
.47204 .6523 Mdot
.67893 .42491 Mdot
.47721 .69461 Mdot
.52616 .66055 Mdot
.6521 .3813 Mdot
.49522 .64664 Mdot
.56834 .27467 Mdot
.37119 .31976 Mdot
.70164 .56738 Mdot
.66138 .57599 Mdot
.6619 .39283 Mdot
.65106 .43124 Mdot
.64313 .405 Mdot
.32788 .47986 Mdot
.47871 .67522 Mdot
.34358 .49436 Mdot
.3704 .44393 Mdot
.52189 .59549 Mdot
.48795 .63111 Mdot
.33597 .47858 Mdot
.56172 .50396 Mdot
.56396 .29988 Mdot
.66061 .40874 Mdot
.69499 .59799 Mdot
.49736 .29832 Mdot
.70794 .56668 Mdot
.32797 .447 Mdot
.57564 .79575 Mdot
.51227 .69496 Mdot
.58559 .27861 Mdot
.53048 .47661 Mdot
.58185 .2784 Mdot
.68057 .61977 Mdot
.46187 .69288 Mdot
.46779 .41582 Mdot
.35345 .44319 Mdot
.43722 .35 Mdot
.42139 .2336 Mdot
.64298 .76024 Mdot
.68865 .60459 Mdot
.36931 .51503 Mdot
.5037 .56129 Mdot
.28423 .68273 Mdot
.38914 .47661 Mdot
.34536 .42513 Mdot
.52057 .45233 Mdot
.34271 .43422 Mdot
.48679 .72305 Mdot
.54245 .4816 Mdot
.38762 .51973 Mdot
.32276 .49506 Mdot
.80845 .58861 Mdot
.40636 .47159 Mdot
.36161 .43863 Mdot
.36801 .47287 Mdot
.33933 .49557 Mdot
.50836 .6378 Mdot
.56079 .46788 Mdot
.71018 .59598 Mdot
.371 .31954 Mdot
.70598 .57813 Mdot
.65782 .3877 Mdot
.52303 .35422 Mdot
.49854 .64018 Mdot
.58183 .27907 Mdot
.59544 .54076 Mdot
.32183 .33752 Mdot
.67997 .38204 Mdot
.46637 .26107 Mdot
.58801 .30465 Mdot
.29598 .48413 Mdot
.59358 .25729 Mdot
.63155 .41686 Mdot
.6631 .58561 Mdot
.3551 .43334 Mdot
.47351 .69292 Mdot
.50845 .65882 Mdot
.31782 .46986 Mdot
.69075 .73991 Mdot
.65994 .58572 Mdot
.59017 .35464 Mdot
.39921 .4663 Mdot
.32902 .45207 Mdot
.50014 .64401 Mdot
.67342 .42078 Mdot
.52048 .49999 Mdot
.58493 .29934 Mdot
.34377 .47719 Mdot
.37077 .51938 Mdot
.43726 .35996 Mdot
.66475 .6041 Mdot
.51453 .58123 Mdot
.38484 .48375 Mdot
.44772 .37846 Mdot
.33894 .5 Mdot
.31966 .50269 Mdot
.66662 .37308 Mdot
.33814 .40528 Mdot
.34247 .45918 Mdot
.54571 .6831 Mdot
.69966 .56697 Mdot
.4957 .67908 Mdot
.49671 .73575 Mdot
.49926 .57281 Mdot
.68355 .56781 Mdot
.33381 .47418 Mdot
.66158 .61281 Mdot
.37742 .51252 Mdot
.37748 .44783 Mdot
.68619 .6056 Mdot
.47884 .69283 Mdot
.62912 .64091 Mdot
.41804 .73845 Mdot
.37982 .50631 Mdot
.35566 .45752 Mdot
.60888 .26712 Mdot
.53039 .20066 Mdot
.34539 .44955 Mdot
.48574 .65676 Mdot
.35216 .46311 Mdot
.67293 .56055 Mdot
.57279 .25805 Mdot
.49983 .68836 Mdot
.6864 .41539 Mdot
.67575 .38214 Mdot
.66645 .45507 Mdot
.52116 .57352 Mdot
.42199 .46915 Mdot
.46672 .65708 Mdot
.48652 .63032 Mdot
.38575 .32966 Mdot
.66495 .40853 Mdot
.57014 .26149 Mdot
.39488 .487 Mdot
.30403 .50845 Mdot
.69066 .61573 Mdot
.91032 .51907 Mdot
.46586 .41071 Mdot
.57984 .31459 Mdot
.53977 .38025 Mdot
.50427 .57849 Mdot
.40528 .46602 Mdot
.56003 .27419 Mdot
.6592 .38141 Mdot
.37432 .51381 Mdot
.43341 .48152 Mdot
.67457 .4894 Mdot
.64359 .41977 Mdot
.66594 .61776 Mdot
.69089 .40444 Mdot
.59338 .30132 Mdot
.51987 .57224 Mdot
.51697 .67868 Mdot
.38914 .46382 Mdot
.40651 .41476 Mdot
.67583 .40958 Mdot
.51038 .55116 Mdot
.3871 .43599 Mdot
.51713 .692 Mdot
.66537 .41531 Mdot
.37141 .46088 Mdot
.29482 .68818 Mdot
.45161 .74564 Mdot
.68258 .41155 Mdot
.35372 .48685 Mdot
.28966 .51913 Mdot
.64102 .41496 Mdot
.63185 .41454 Mdot
.36796 .51617 Mdot
.56418 .28998 Mdot
.34421 .46671 Mdot
.66687 .57542 Mdot
.43333 .34024 Mdot
.68965 .57266 Mdot
.39177 .28217 Mdot
.34275 .51361 Mdot
.44682 .51949 Mdot
.53659 .68248 Mdot
.5699 .23285 Mdot
.23088 .36519 Mdot
.33039 .44113 Mdot
.5024 .77176 Mdot
.42909 .33699 Mdot
.48339 .42472 Mdot
.51189 .76652 Mdot
.5795 .30001 Mdot
.66931 .59283 Mdot
.37283 .43574 Mdot
.62596 .62642 Mdot
.57524 .29618 Mdot
.38974 .28249 Mdot
.35574 .49523 Mdot
.50477 .67786 Mdot
.39837 .46163 Mdot
.51543 .68086 Mdot
.35867 .47225 Mdot
.48142 .77687 Mdot
.557 .22479 Mdot
.30486 .32704 Mdot
.29646 .48484 Mdot
.64783 .53013 Mdot
.39526 .70777 Mdot
.57092 .26783 Mdot
.39496 .5004 Mdot
.50989 .58609 Mdot
.66479 .59771 Mdot
.6295 .52915 Mdot
.64524 .40729 Mdot
.7102 .57893 Mdot
.48178 .68723 Mdot
.62642 .40847 Mdot
.50504 .55438 Mdot
.38458 .38121 Mdot
.56293 .28462 Mdot
.68151 .56701 Mdot
.38837 .46884 Mdot
.32129 .47476 Mdot
.71302 .46675 Mdot
.36772 .20523 Mdot
.5175 .64516 Mdot
.7418 .74879 Mdot
.46102 .68664 Mdot
.59226 .27629 Mdot
.66109 .37364 Mdot
.36432 .46008 Mdot
.36898 .48463 Mdot
.64549 .42139 Mdot
.52101 .6996 Mdot
.59711 .24992 Mdot
.51548 .21985 Mdot
.65537 .56533 Mdot
.37585 .22124 Mdot
.50235 .69091 Mdot
.3772 .22076 Mdot
.55369 .31826 Mdot
.44165 .68843 Mdot
.28066 .32354 Mdot
.68036 .59879 Mdot
.37524 .22076 Mdot
.50698 .67588 Mdot
.39999 .45099 Mdot
.50716 .57122 Mdot
.51507 .55638 Mdot
.49768 .70358 Mdot
.64632 .38814 Mdot
.5847 .30397 Mdot
.39743 .46411 Mdot
.40234 .39422 Mdot
.26274 .53386 Mdot
.66789 .43414 Mdot
.31132 .42341 Mdot
.68814 .59714 Mdot
.35385 .46307 Mdot
.56464 .25044 Mdot
.67926 .59696 Mdot
.4999 .58311 Mdot
.32637 .33522 Mdot
.35928 .48825 Mdot
.52115 .47701 Mdot
.67257 .58019 Mdot
.52539 .20036 Mdot
.352 .44673 Mdot
.70112 .56755 Mdot
.40369 .41285 Mdot
.75211 .58892 Mdot
.54384 .49699 Mdot
.69389 .70697 Mdot
.66664 .44761 Mdot
.69023 .39798 Mdot
.5089 .13952 Mdot
.62544 .21612 Mdot
.70515 .59727 Mdot
.51785 .59347 Mdot
.37668 .20425 Mdot
.70063 .57237 Mdot
.33775 .45816 Mdot
.38765 .44166 Mdot
.40349 .6985 Mdot
.31143 .51809 Mdot
.52511 .56942 Mdot
.45156 .56452 Mdot
.41271 .47516 Mdot
.30336 .43252 Mdot
.36638 .43974 Mdot
.50127 .71837 Mdot
.68531 .59649 Mdot
.21677 .69076 Mdot
.6593 .60546 Mdot
.44537 .51678 Mdot
.68114 .41034 Mdot
.65082 .44744 Mdot
.38528 .46682 Mdot
.40881 .56081 Mdot
.42165 .85017 Mdot
.38417 .43893 Mdot
.52992 .47666 Mdot
.40587 .28596 Mdot
.38424 .52723 Mdot
.46982 .68428 Mdot
.39702 .40791 Mdot
.47486 .63998 Mdot
.67619 .59803 Mdot
.57861 .29945 Mdot
.56208 .23278 Mdot
.66924 .59012 Mdot
.36985 .48365 Mdot
.55921 .23875 Mdot
.38244 .45908 Mdot
.40197 .47162 Mdot
.44194 .37303 Mdot
.57319 .2495 Mdot
.64087 .39858 Mdot
.58348 .27211 Mdot
.48336 .70963 Mdot
.81361 .67568 Mdot
.57492 .26625 Mdot
.40152 .6959 Mdot
.42744 .32611 Mdot
.38549 .20817 Mdot
.51044 .65893 Mdot
.5936 .26064 Mdot
.67087 .59913 Mdot
.47586 .44184 Mdot
.38124 .6964 Mdot
.70742 .56617 Mdot
.38642 .48071 Mdot
.51002 .63867 Mdot
.46253 .6918 Mdot
.70722 .55989 Mdot
.51857 .67481 Mdot
.41863 .5114 Mdot
.37988 .49768 Mdot
.7113 .5905 Mdot
.18762 .45337 Mdot
.65982 .57674 Mdot
.42824 .76138 Mdot
.41686 .48152 Mdot
.49968 .68564 Mdot
.39435 .69576 Mdot
.50662 .73883 Mdot
.51434 .55898 Mdot
.34875 .44131 Mdot
.57299 .26289 Mdot
.39116 .32236 Mdot
.68161 .41598 Mdot
.57446 .79114 Mdot
.5058 .66032 Mdot
.70052 .54903 Mdot
.51837 .67701 Mdot
.51803 .66342 Mdot
.69172 .61865 Mdot
.51037 .69541 Mdot
.35137 .47571 Mdot
.50164 .79197 Mdot
.50701 .652 Mdot
.67864 .58498 Mdot
.5878 .25841 Mdot
.48798 .65443 Mdot
.5791 .35661 Mdot
.39047 .48776 Mdot
.69107 .42587 Mdot
.6001 .23055 Mdot
.52937 .671 Mdot
.57018 .26673 Mdot
.67184 .41114 Mdot
.57494 .30551 Mdot
.64464 .63658 Mdot
.61728 .57993 Mdot
.24867 .44012 Mdot
.74724 .57344 Mdot
.49162 .71475 Mdot
.62726 .42455 Mdot
.35266 .48277 Mdot
.40036 .46787 Mdot
.55185 .25918 Mdot
.47552 .71558 Mdot
.70523 .72996 Mdot
.44744 .54707 Mdot
.67136 .75161 Mdot
.66207 .59889 Mdot
.5682 .34754 Mdot
.46938 .41643 Mdot
.72646 .60835 Mdot
.39541 .51758 Mdot
.50483 .57846 Mdot
.37719 .46403 Mdot
.44032 .28679 Mdot
.59201 .30162 Mdot
.74969 .46076 Mdot
.32529 .49144 Mdot
.64901 .424 Mdot
.36027 .46993 Mdot
.5766 .54308 Mdot
.32633 .50285 Mdot
.56002 .29368 Mdot
.65912 .55833 Mdot
.48213 .65988 Mdot
.59831 .27205 Mdot
.67324 .38048 Mdot
.26391 .35657 Mdot
.33861 .46403 Mdot
.41237 .46938 Mdot
.6365 .40587 Mdot
.47562 .69504 Mdot
.65471 .3913 Mdot
.70243 .56832 Mdot
.57622 .26915 Mdot
.33286 .48853 Mdot
.30824 .4275 Mdot
.69553 .37392 Mdot
.68273 .61374 Mdot
.64051 .38036 Mdot
.66349 .61435 Mdot
.5044 .57201 Mdot
.32837 .51057 Mdot
.64055 .37678 Mdot
.39743 .51505 Mdot
.37555 .62664 Mdot
.33298 .33897 Mdot
.27218 .53007 Mdot
.64084 .39179 Mdot
.62108 .20224 Mdot
.67747 .59261 Mdot
.68405 .56455 Mdot
.43444 .76827 Mdot
.46782 .8505 Mdot
.51663 .49221 Mdot
.7378 .70918 Mdot
.70222 .56782 Mdot
.67467 .57585 Mdot
.64994 .3919 Mdot
.4835 .70634 Mdot
.53424 .6911 Mdot
.63309 .38812 Mdot
.3527 .30341 Mdot
.50311 .66878 Mdot
.36101 .77058 Mdot
.6762 .43435 Mdot
.41369 .44503 Mdot
.44069 .72059 Mdot
.56123 .29493 Mdot
.41804 .29377 Mdot
.67303 .51434 Mdot
.36929 .46635 Mdot
.82913 .45228 Mdot
.64685 .40688 Mdot
.46571 .54355 Mdot
.66234 .54727 Mdot
.32575 .4718 Mdot
.36474 .47384 Mdot
.34971 .46868 Mdot
.56343 .30223 Mdot
.33994 .58953 Mdot
.36699 .46354 Mdot
.31415 .3315 Mdot
.35495 .41817 Mdot
.70957 .48458 Mdot
.58321 .27181 Mdot
.47113 .24058 Mdot
.62461 .38338 Mdot
.7027 .72131 Mdot
.3439 .42772 Mdot
.68573 .56091 Mdot
.5712 .51736 Mdot
.68974 .60598 Mdot
.72335 .62909 Mdot
.3507 .23545 Mdot
.48226 .71822 Mdot
.32587 .48905 Mdot
.66166 .438 Mdot
.5356 .6739 Mdot
.56802 .51127 Mdot
.80783 .68561 Mdot
.69069 .54415 Mdot
.65766 .84431 Mdot
.69407 .57096 Mdot
.52193 .56198 Mdot
.48332 .69023 Mdot
.34117 .55721 Mdot
.43788 .35296 Mdot
.47763 .69458 Mdot
.69126 .28363 Mdot
.47346 .63982 Mdot
.31527 .28876 Mdot
.52357 .62683 Mdot
.68329 .58584 Mdot
.70567 .55648 Mdot
.43412 .47279 Mdot
.34303 .46788 Mdot
.44366 .34591 Mdot
.33637 .53931 Mdot
.36339 .48979 Mdot
.67248 .39554 Mdot
.74632 .56968 Mdot
.6304 .62916 Mdot
.50552 .69734 Mdot
.68967 .61364 Mdot
.36236 .47147 Mdot
.38116 .50592 Mdot
.36091 .42862 Mdot
.51804 .29014 Mdot
.3528 .76714 Mdot
.3792 .4459 Mdot
.31987 .49784 Mdot
.67562 .37854 Mdot
.71626 .46371 Mdot
.77534 .68506 Mdot
.3607 .22503 Mdot
.39864 .44004 Mdot
.59006 .27716 Mdot
.56652 .24725 Mdot
.42656 .50601 Mdot
.36177 .56087 Mdot
.60196 .32767 Mdot
.38829 .4693 Mdot
.28249 .34401 Mdot
.70452 .40102 Mdot
.49917 .56076 Mdot
.6753 .4093 Mdot
.53704 .69115 Mdot
.50256 .56333 Mdot
.67076 .38686 Mdot
.32826 .32411 Mdot
.50395 .58585 Mdot
.75537 .60192 Mdot
.59111 .25812 Mdot
.36018 .442 Mdot
.41871 .70769 Mdot
.68038 .42425 Mdot
.67438 .57156 Mdot
.48731 .68456 Mdot
.66137 .59379 Mdot
.70634 .51108 Mdot
.3706 .29617 Mdot
.51694 .5656 Mdot
.6845 .5607 Mdot
.51785 .47804 Mdot
.58874 .2733 Mdot
.69846 .57648 Mdot
.44382 .53481 Mdot
.32311 .43978 Mdot
.38121 .81631 Mdot
.40824 .47728 Mdot
.73533 .63281 Mdot
.6774 .5656 Mdot
.49626 .57033 Mdot
.38945 .46198 Mdot
.67066 .44099 Mdot
.35991 .38169 Mdot
.38145 .45786 Mdot
.68926 .4148 Mdot
.38994 .44531 Mdot
.56367 .25692 Mdot
.46051 .69492 Mdot
.42497 .33468 Mdot
.51452 .33074 Mdot
.59114 .30004 Mdot
.36012 .34551 Mdot
.34557 .44849 Mdot
.65381 .25423 Mdot
.50243 .6759 Mdot
.32885 .44563 Mdot
.3965 .271 Mdot
.49182 .7087 Mdot
.48917 .67142 Mdot
.40512 .48959 Mdot
.66354 .56522 Mdot
.6387 .39953 Mdot
.58715 .27249 Mdot
.69565 .6257 Mdot
.36952 .46049 Mdot
.36774 .51468 Mdot
.5941 .29716 Mdot
.67974 .5696 Mdot
.33261 .48466 Mdot
.61001 .74052 Mdot
.36391 .32408 Mdot
.67649 .61833 Mdot
.32169 .44339 Mdot
.38557 .78819 Mdot
.52336 .68004 Mdot
.82865 .44848 Mdot
.55866 .22438 Mdot
.65469 .37799 Mdot
.32703 .40931 Mdot
.89375 .55627 Mdot
.58617 .25585 Mdot
.66698 .74845 Mdot
.39774 .4506 Mdot
.36192 .45593 Mdot
.49644 .71767 Mdot
.34043 .48937 Mdot
.51445 .69303 Mdot
.54945 .34274 Mdot
.48805 .85099 Mdot
.51433 .66516 Mdot
.51258 .68036 Mdot
.39029 .54981 Mdot
.54089 .24282 Mdot
.49039 .70284 Mdot
.33952 .46723 Mdot
.68107 .25931 Mdot
.40108 .5361 Mdot
.60472 .27595 Mdot
.60275 .32135 Mdot
.47212 .67353 Mdot
.38013 .71001 Mdot
.39864 .54759 Mdot
.35635 .74926 Mdot
.60757 .32647 Mdot
.70668 .59046 Mdot
.38963 .5112 Mdot
.51977 .59015 Mdot
.66041 .41163 Mdot
.384 .40188 Mdot
.35295 .44685 Mdot
.47289 .69897 Mdot
.57954 .31254 Mdot
.7017 .57714 Mdot
.40645 .50361 Mdot
.70795 .39626 Mdot
.58939 .29681 Mdot
.50366 .64704 Mdot
.40375 .73886 Mdot
.55755 .24088 Mdot
.31545 .41663 Mdot
.40291 .45225 Mdot
.42054 .47879 Mdot
.2976 .49234 Mdot
.67013 .58917 Mdot
.62872 .40452 Mdot
.31792 .41457 Mdot
.45311 .39889 Mdot
.36457 .31581 Mdot
.37714 .42754 Mdot
.48662 .65567 Mdot
.6702 .60628 Mdot
.51887 .57772 Mdot
.38291 .20457 Mdot
.40899 .45381 Mdot
.36147 .77156 Mdot
.5017 .26707 Mdot
.51005 .58976 Mdot
.53284 .66284 Mdot
.58478 .27722 Mdot
.41179 .48789 Mdot
.31245 .32947 Mdot
.36015 .49068 Mdot
.36328 .53085 Mdot
.64653 .3838 Mdot
.70317 .58992 Mdot
.25294 .43227 Mdot
.65761 .40832 Mdot
.48909 .67295 Mdot
.31937 .73887 Mdot
.5329 .68282 Mdot
.52558 .6589 Mdot
.45822 .63213 Mdot
.66415 .57433 Mdot
.89798 .5485 Mdot
.54304 .2009 Mdot
.37033 .4304 Mdot
.69535 .55863 Mdot
.49037 .69818 Mdot
.33596 .47077 Mdot
.51287 .69456 Mdot
.46966 .67625 Mdot
.38806 .49171 Mdot
.38146 .49361 Mdot
.30182 .32947 Mdot
.37986 .77577 Mdot
.57799 .25854 Mdot
.51864 .70275 Mdot
.37925 .75595 Mdot
.36529 .4581 Mdot
.34456 .45884 Mdot
.57316 .51993 Mdot
.59984 .27372 Mdot
.22819 .61103 Mdot
.40066 .46172 Mdot
.44849 .2747 Mdot
.3401 .45422 Mdot
.53076 .71287 Mdot
.7184 .59005 Mdot
.44418 .526 Mdot
.6443 .37855 Mdot
.52179 .6997 Mdot
.57417 .3102 Mdot
.53188 .6533 Mdot
.25749 .6402 Mdot
.66632 .59333 Mdot
.51162 .67489 Mdot
.62733 .41448 Mdot
.68394 .57336 Mdot
.66082 .57485 Mdot
.56702 .50832 Mdot
.63629 .43163 Mdot
.58284 .31398 Mdot
.69393 .59369 Mdot
.30053 .69219 Mdot
.68447 .58274 Mdot
.25225 .64174 Mdot
.40704 .44324 Mdot
.31589 .33101 Mdot
.37877 .39861 Mdot
.43461 .48058 Mdot
.69301 .58314 Mdot
.59026 .29832 Mdot
.33147 .47908 Mdot
.51587 .6616 Mdot
.58947 .26378 Mdot
.43275 .65633 Mdot
.63465 .43328 Mdot
.46497 .66589 Mdot
.65611 .6089 Mdot
.50627 .71112 Mdot
.40865 .28884 Mdot
.60242 .31667 Mdot
.58452 .50841 Mdot
.42801 .35203 Mdot
.29395 .45552 Mdot
.3206 .48867 Mdot
.33 .47544 Mdot
.35481 .47759 Mdot
.68239 .40954 Mdot
.55416 .28559 Mdot
.49121 .65044 Mdot
.22813 .49806 Mdot
.67182 .56939 Mdot
.5349 .48273 Mdot
.29694 .48924 Mdot
.37449 .51288 Mdot
.491 .69542 Mdot
.47224 .66477 Mdot
.3643 .59178 Mdot
.64391 .41605 Mdot
.42252 .52209 Mdot
.34466 .43056 Mdot
.26434 .41382 Mdot
.6923 .57956 Mdot
.66859 .70949 Mdot
.70059 .41226 Mdot
.66851 .84124 Mdot
.6588 .40711 Mdot
.57318 .44927 Mdot
.50941 .70018 Mdot
.57218 .27992 Mdot
.38179 .48593 Mdot
.4523 .57715 Mdot
.51133 .63709 Mdot
.70741 .45332 Mdot
.58035 .28098 Mdot
.70398 .65398 Mdot
.70307 .56503 Mdot
.40567 .50512 Mdot
.3395 .45508 Mdot
.36054 .50411 Mdot
.34299 .48389 Mdot
.70591 .59917 Mdot
.36861 .49541 Mdot
.67602 .62444 Mdot
.25415 .63065 Mdot
.3901 .27007 Mdot
.6382 .42539 Mdot
.73687 .44542 Mdot
.52365 .65733 Mdot
.25123 .6693 Mdot
.23788 .61296 Mdot
.33379 .33835 Mdot
.68486 .6375 Mdot
.37581 .52385 Mdot
.6457 .39205 Mdot
.61814 .61054 Mdot
.64167 .4296 Mdot
.26283 .7437 Mdot
.4034 .70247 Mdot
.727 .64589 Mdot
.35622 .49995 Mdot
.63469 .39296 Mdot
.38043 .72597 Mdot
.33344 .39946 Mdot
.5607 .23851 Mdot
.271 .66138 Mdot
.43712 .62023 Mdot
.57426 .25617 Mdot
.39669 .48229 Mdot
.48916 .63061 Mdot
.37676 .48577 Mdot
.38629 .48606 Mdot
.39211 .4401 Mdot
.70516 .6097 Mdot
.40129 .43726 Mdot
.34643 .47142 Mdot
.39952 .17205 Mdot
.71346 .36999 Mdot
.69134 .3979 Mdot
.29437 .5429 Mdot
.58693 .26493 Mdot
.53731 .69085 Mdot
.42598 .34024 Mdot
.67349 .56389 Mdot
.35938 .59012 Mdot
.39325 .49662 Mdot
.62164 .77487 Mdot
.65563 .58105 Mdot
.56764 .29572 Mdot
.51761 .59068 Mdot
.69161 .67207 Mdot
.67079 .37058 Mdot
.52454 .57754 Mdot
.67962 .42019 Mdot
.22794 .45856 Mdot
.51439 .68705 Mdot
.29406 .45504 Mdot
.70113 .58301 Mdot
.64523 .43547 Mdot
.31028 .33441 Mdot
.34991 .45914 Mdot
.64088 .39061 Mdot
.34385 .39913 Mdot
.39542 .32032 Mdot
.43039 .33888 Mdot
.63045 .41778 Mdot
.65835 .56278 Mdot
.68907 .57592 Mdot
.57853 .25342 Mdot
.52194 .67796 Mdot
.47501 .69774 Mdot
.68777 .58214 Mdot
.82016 .55807 Mdot
.37044 .46217 Mdot
.3713 .44597 Mdot
.46148 .4088 Mdot
.33347 .45742 Mdot
.61027 .27912 Mdot
.5256 .56566 Mdot
.47356 .6828 Mdot
.33073 .47607 Mdot
.33314 .48576 Mdot
.40745 .45891 Mdot
.34277 .30421 Mdot
.67613 .4123 Mdot
.41326 .47586 Mdot
.56147 .2798 Mdot
.43368 .64372 Mdot
.35017 .48034 Mdot
.31537 .41551 Mdot
.51371 .69753 Mdot
.63673 .47721 Mdot
.67267 .57243 Mdot
.6628 .43409 Mdot
.66156 .43679 Mdot
.40924 .23804 Mdot
.52631 .69956 Mdot
.52556 .57264 Mdot
.68361 .49497 Mdot
.5206 .5775 Mdot
.57928 .28336 Mdot
.53627 .49833 Mdot
.6184 .41834 Mdot
.69133 .40035 Mdot
.71211 .55875 Mdot
.32305 .45941 Mdot
.34664 .47757 Mdot
.69628 .7298 Mdot
.37901 .43958 Mdot
.57375 .26035 Mdot
.67967 .55595 Mdot
.51059 .67767 Mdot
.5604 .25717 Mdot
.68939 .56523 Mdot
.47631 .69266 Mdot
.37007 .41732 Mdot
.33753 .46252 Mdot
.48663 .67887 Mdot
.50801 .64866 Mdot
.37888 .47314 Mdot
.32863 .24951 Mdot
.47603 .67002 Mdot
.48526 .68605 Mdot
.43521 .63491 Mdot
.67796 .37469 Mdot
.35465 .38108 Mdot
.67575 .56052 Mdot
.34694 .47005 Mdot
.63673 .42111 Mdot
.5832 .29146 Mdot
.49538 .65651 Mdot
.39052 .51265 Mdot
.37199 .45509 Mdot
.58936 .27744 Mdot
.58726 .24969 Mdot
.59661 .27044 Mdot
.70854 .56282 Mdot
.38708 .49571 Mdot
.48584 .69806 Mdot
.70866 .5719 Mdot
.55498 .25692 Mdot
.59909 .26394 Mdot
.28524 .30793 Mdot
.37206 .46775 Mdot
.56892 .24333 Mdot
.8252 .66033 Mdot
.2854 .3291 Mdot
.50515 .55629 Mdot
.68733 .44238 Mdot
.62229 .1994 Mdot
.5998 .22871 Mdot
.7022 .59608 Mdot
.53753 .47914 Mdot
.59484 .30389 Mdot
.41145 .49564 Mdot
.35787 .44893 Mdot
.29645 .47083 Mdot
.59104 .26704 Mdot
.37079 .29491 Mdot
.48591 .72052 Mdot
.26293 .57876 Mdot
.58664 .26473 Mdot
.64066 .43369 Mdot
.69991 .37714 Mdot
.65388 .40047 Mdot
.33297 .51346 Mdot
.22294 .46325 Mdot
.29759 .67152 Mdot
.22471 .60097 Mdot
.69951 .56269 Mdot
.47062 .66977 Mdot
.43327 .69546 Mdot
.48945 .66984 Mdot
.66153 .41984 Mdot
.58769 .2993 Mdot
.49006 .71854 Mdot
.66049 .57886 Mdot
.69064 .57897 Mdot
.65125 .37073 Mdot
.66989 .40868 Mdot
.66211 .39492 Mdot
.5229 .69264 Mdot
.51007 .69806 Mdot
.34396 .49725 Mdot
.50123 .65234 Mdot
.51888 .25815 Mdot
.53237 .3217 Mdot
.67084 .36404 Mdot
.67366 .58726 Mdot
.48368 .66805 Mdot
.36163 .44039 Mdot
.53108 .44216 Mdot
.62649 .37481 Mdot
.55879 .28814 Mdot
.52259 .80239 Mdot
.46277 .85839 Mdot
.33004 .49436 Mdot
.68915 .61149 Mdot
.42839 .55109 Mdot
.35606 .47584 Mdot
.64815 .37907 Mdot
.50092 .24048 Mdot
.50622 .59161 Mdot
.36616 .48718 Mdot
.37263 .41921 Mdot
.6646 .595 Mdot
.42464 .34203 Mdot
.40659 .50196 Mdot
.56083 .48666 Mdot
.66146 .55761 Mdot
.70128 .40676 Mdot
.54429 .14465 Mdot
.46384 .56483 Mdot
.45513 .2963 Mdot
.49986 .56556 Mdot
.40801 .44952 Mdot
.67543 .39722 Mdot
.5571 .27263 Mdot
.67102 .40061 Mdot
.53964 .6902 Mdot
.67087 .37155 Mdot
.37852 .43732 Mdot
.48728 .70201 Mdot
.6819 .56763 Mdot
.49949 .43341 Mdot
.24221 .4879 Mdot
.67559 .43876 Mdot
.5105 .55008 Mdot
.38101 .49313 Mdot
.29596 .69363 Mdot
.43531 .47722 Mdot
.3424 .46116 Mdot
.68792 .60543 Mdot
.49923 .69815 Mdot
.66369 .60085 Mdot
.36886 .38337 Mdot
.52971 .74453 Mdot
.66906 .57515 Mdot
.45894 .52851 Mdot
.58938 .30372 Mdot
.36216 .29994 Mdot
.39366 .46497 Mdot
.70219 .58275 Mdot
.39859 .48677 Mdot
.51702 .70641 Mdot
.34428 .32278 Mdot
.35654 .33074 Mdot
.68586 .59906 Mdot
.57423 .57094 Mdot
.4196 .32049 Mdot
.35316 .38109 Mdot
.70521 .57417 Mdot
.22865 .38047 Mdot
.51274 .58574 Mdot
.58674 .29675 Mdot
.59173 .251 Mdot
.56802 .28404 Mdot
.36857 .44433 Mdot
.39287 .77001 Mdot
.5793 .2512 Mdot
.67783 .54881 Mdot
.56474 .26077 Mdot
.50446 .31179 Mdot
.6944 .73761 Mdot
.58923 .30267 Mdot
.39224 .45678 Mdot
.44557 .48029 Mdot
.53315 .47853 Mdot
.66667 .44606 Mdot
.63709 .66067 Mdot
.40909 .16665 Mdot
.36414 .46102 Mdot
.48211 .77806 Mdot
.52045 .7366 Mdot
.57147 .42389 Mdot
.3477 .33544 Mdot
.50149 .46326 Mdot
.48304 .67629 Mdot
.42648 .3469 Mdot
.50333 .63897 Mdot
.29262 .45648 Mdot
.37877 .44743 Mdot
.52212 .70029 Mdot
.56509 .79179 Mdot
.22016 .37603 Mdot
.65591 .76284 Mdot
.47811 .67589 Mdot
.69951 .56693 Mdot
.68798 .60862 Mdot
.68994 .60404 Mdot
.68359 .40145 Mdot
.51352 .67441 Mdot
.41493 .46495 Mdot
.66709 .37808 Mdot
.39476 .47831 Mdot
.68626 .59235 Mdot
.34004 .33559 Mdot
.51187 .6809 Mdot
.38923 .46978 Mdot
.37924 .74091 Mdot
.67545 .42311 Mdot
.58992 .27342 Mdot
.51296 .79784 Mdot
.65742 .45342 Mdot
.65429 .5863 Mdot
.54118 .6893 Mdot
.7166 .40004 Mdot
.56131 .46491 Mdot
.38259 .42999 Mdot
.35595 .43379 Mdot
.54064 .47557 Mdot
.40362 .71774 Mdot
.38989 .51698 Mdot
.67455 .38128 Mdot
.68738 .3847 Mdot
.40169 .48218 Mdot
.51339 .66895 Mdot
.59806 .30471 Mdot
.55404 .24596 Mdot
.33064 .51978 Mdot
.43536 .34709 Mdot
.31476 .33168 Mdot
.33416 .47731 Mdot
.30583 .44374 Mdot
.62742 .41745 Mdot
.50329 .55637 Mdot
.43579 .35801 Mdot
.56787 .27351 Mdot
.40127 .45546 Mdot
.27137 .53852 Mdot
.50522 .66129 Mdot
.63972 .39377 Mdot
.71278 .5935 Mdot
.55843 .23998 Mdot
.67436 .36619 Mdot
.40176 .48204 Mdot
.33287 .48496 Mdot
.69955 .5796 Mdot
.5303 .71223 Mdot
.59507 .28454 Mdot
.66894 .37783 Mdot
.57065 .27664 Mdot
.51059 .69257 Mdot
.49075 .65683 Mdot
.35942 .42748 Mdot
.43394 .49842 Mdot
.67664 .43592 Mdot
.35996 .52727 Mdot
.65787 .38439 Mdot
.71328 .46672 Mdot
.69115 .61561 Mdot
.33112 .44338 Mdot
.52699 .70513 Mdot
.68796 .58867 Mdot
.36309 .46509 Mdot
.5468 .47468 Mdot
.34074 .49962 Mdot
.63189 .39742 Mdot
.5061 .21841 Mdot
.57683 .2932 Mdot
.40349 .41976 Mdot
.42355 .60066 Mdot
.33304 .46263 Mdot
.69543 .41098 Mdot
.29378 .67935 Mdot
.66716 .5813 Mdot
.50349 .70651 Mdot
.62092 .44434 Mdot
.68061 .58389 Mdot
.39444 .45357 Mdot
.57549 .26573 Mdot
.49304 .64632 Mdot
.50788 .562 Mdot
.45487 .35853 Mdot
.43031 .43028 Mdot
.40353 .53138 Mdot
.39697 .513 Mdot
.73445 .71462 Mdot
.66487 .39668 Mdot
.4897 .69599 Mdot
.69298 .60965 Mdot
.66539 .58889 Mdot
.67311 .42124 Mdot
.44135 .61232 Mdot
.60225 .79558 Mdot
.84964 .62874 Mdot
.67812 .36619 Mdot
.56397 .27235 Mdot
.34425 .32402 Mdot
.65236 .40013 Mdot
.68451 .41298 Mdot
.62332 .41105 Mdot
.70306 .72509 Mdot
.47846 .68341 Mdot
.37098 .45449 Mdot
.46199 .75961 Mdot
.39182 .44079 Mdot
.45588 .30551 Mdot
.68528 .59232 Mdot
.50369 .70675 Mdot
.55974 .35717 Mdot
.32448 .49961 Mdot
.36685 .47914 Mdot
.58764 .35792 Mdot
.3913 .55389 Mdot
.38067 .21103 Mdot
.34335 .43758 Mdot
.67702 .4048 Mdot
.46171 .72807 Mdot
.31459 .41827 Mdot
.3799 .74319 Mdot
.69023 .5728 Mdot
.51739 .56438 Mdot
.30007 .43534 Mdot
.30029 .47621 Mdot
.50537 .63947 Mdot
.48663 .71819 Mdot
.59179 .25491 Mdot
.51195 .78585 Mdot
.68868 .5702 Mdot
.69013 .70328 Mdot
.34182 .46059 Mdot
.7265 .62553 Mdot
.51065 .22875 Mdot
.36628 .47033 Mdot
.56462 .50529 Mdot
.36484 .5917 Mdot
.37843 .51633 Mdot
.22758 .59166 Mdot
.67785 .58987 Mdot
.41304 .27444 Mdot
.36029 .49565 Mdot
.64264 .38958 Mdot
.48603 .70945 Mdot
.46568 .66322 Mdot
.55597 .26765 Mdot
.53465 .2264 Mdot
.54056 .85596 Mdot
.50355 .70777 Mdot
.34858 .46006 Mdot
.67194 .5765 Mdot
.51285 .56049 Mdot
.39278 .40463 Mdot
.5806 .55734 Mdot
.50338 .66118 Mdot
.32982 .40334 Mdot
.61728 .77839 Mdot
.42597 .34431 Mdot
.26699 .69709 Mdot
.69112 .60068 Mdot
.56758 .26425 Mdot
.35633 .53688 Mdot
.69423 .48721 Mdot
.3374 .46013 Mdot
.4553 .30251 Mdot
.48167 .73194 Mdot
.57125 .26032 Mdot
.3679 .48238 Mdot
.38307 .5197 Mdot
.37698 .34846 Mdot
.60513 .27271 Mdot
.39838 .51035 Mdot
.32875 .49475 Mdot
.48699 .71378 Mdot
.52487 .56366 Mdot
.50891 .67488 Mdot
.37831 .48475 Mdot
.49111 .20137 Mdot
.5154 .7047 Mdot
.62931 .64688 Mdot
.54688 .25271 Mdot
.67533 .56289 Mdot
.34343 .40354 Mdot
.393 .43509 Mdot
.2671 .70683 Mdot
.51449 .55826 Mdot
.78207 .62293 Mdot
.63363 .3991 Mdot
.35323 .201 Mdot
.65267 .45356 Mdot
.67121 .64214 Mdot
.63704 .5161 Mdot
.31195 .4247 Mdot
.43963 .60807 Mdot
.21872 .5995 Mdot
.64685 .58755 Mdot
.24185 .65934 Mdot
.34309 .46809 Mdot
.40437 .45664 Mdot
.65368 .38409 Mdot
.708 .63677 Mdot
.44458 .52524 Mdot
.43593 .35698 Mdot
.57101 .29899 Mdot
.49653 .67628 Mdot
.3598 .44542 Mdot
.5522 .791 Mdot
.65153 .44106 Mdot
.25944 .51198 Mdot
.39035 .46618 Mdot
.42204 .55186 Mdot
.68987 .63861 Mdot
.6804 .56698 Mdot
.62932 .41554 Mdot
.64145 .43627 Mdot
.40361 .44648 Mdot
.70981 .59522 Mdot
.35829 .50619 Mdot
.41307 .31805 Mdot
.33668 .40314 Mdot
.58177 .2864 Mdot
.34967 .44676 Mdot
.40174 .57152 Mdot
.15499 .51178 Mdot
.32202 .48839 Mdot
.52787 .66469 Mdot
.66106 .39115 Mdot
.67187 .41622 Mdot
.47417 .6938 Mdot
.67138 .41703 Mdot
.26513 .58296 Mdot
.39386 .77494 Mdot
.57667 .28183 Mdot
.26192 .61957 Mdot
.57629 .2979 Mdot
.51828 .56583 Mdot
.37414 .46979 Mdot
.77535 .4141 Mdot
.68423 .36995 Mdot
.49757 .29917 Mdot
.68642 .58445 Mdot
.51607 .55782 Mdot
.38066 .49498 Mdot
.61383 .31316 Mdot
.65205 .40979 Mdot
.47752 .54168 Mdot
.39502 .4433 Mdot
.52124 .69695 Mdot
.37891 .51413 Mdot
.36106 .54969 Mdot
.52485 .5662 Mdot
.36264 .51913 Mdot
.68929 .56515 Mdot
.51697 .6887 Mdot
.732 .6476 Mdot
.6828 .42105 Mdot
.37236 .49039 Mdot
.34887 .46367 Mdot
.48702 .64661 Mdot
.36997 .43105 Mdot
.71129 .58644 Mdot
.91168 .48332 Mdot
.59835 .27999 Mdot
.50173 .55823 Mdot
.60607 .67871 Mdot
.36516 .52014 Mdot
.32839 .48184 Mdot
.49593 .49251 Mdot
.26287 .53294 Mdot
.68035 .56275 Mdot
.40289 .52788 Mdot
.68777 .38874 Mdot
.59445 .2892 Mdot
.65913 .58381 Mdot
.37744 .4979 Mdot
.38791 .44416 Mdot
.57155 .26163 Mdot
.57752 .36172 Mdot
.59372 .24747 Mdot
.70498 .59531 Mdot
.54625 .63418 Mdot
.53271 .44156 Mdot
.37697 .462 Mdot
.51219 .54694 Mdot
.49684 .69456 Mdot
.7075 .57719 Mdot
.33796 .59194 Mdot
.29232 .45892 Mdot
.66071 .61547 Mdot
.68374 .56782 Mdot
.38471 .43129 Mdot
.52559 .69915 Mdot
.54122 .69747 Mdot
.49378 .69482 Mdot
.39375 .26234 Mdot
.77146 .62551 Mdot
.66501 .39287 Mdot
.67502 .58524 Mdot
.63877 .42149 Mdot
.59549 .30135 Mdot
.37509 .31494 Mdot
.65761 .44387 Mdot
.50755 .72281 Mdot
.64557 .43171 Mdot
.35316 .50427 Mdot
.66541 .56528 Mdot
.67898 .43219 Mdot
.33809 .47705 Mdot
.31698 .50711 Mdot
.31094 .51859 Mdot
.58854 .31249 Mdot
.43066 .34415 Mdot
.39665 .46253 Mdot
.51741 .58971 Mdot
.38376 .47109 Mdot
.71114 .58969 Mdot
.49678 .41967 Mdot
.40904 .47913 Mdot
.68441 .36985 Mdot
.77725 .64212 Mdot
.69197 .38687 Mdot
.28075 .50719 Mdot
.38767 .47987 Mdot
.37437 .46348 Mdot
.38452 .49333 Mdot
.43231 .63491 Mdot
.65602 .60262 Mdot
.39119 .52928 Mdot
.63925 .38169 Mdot
.48882 .66712 Mdot
.50923 .71542 Mdot
.50678 .4965 Mdot
.52393 .58076 Mdot
.71219 .57816 Mdot
.3726 .4627 Mdot
.47875 .54118 Mdot
.46018 .39103 Mdot
.6314 .77807 Mdot
.68653 .44642 Mdot
.69284 .40918 Mdot
.5203 .66353 Mdot
.68743 .39844 Mdot
.37456 .49682 Mdot
.32695 .40596 Mdot
.72965 .64946 Mdot
.67757 .53775 Mdot
.59339 .2904 Mdot
.39064 .48115 Mdot
.32448 .30934 Mdot
.67547 .37849 Mdot
.62999 .42301 Mdot
.35973 .50615 Mdot
.50804 .74337 Mdot
.16826 .44665 Mdot
.69479 .55799 Mdot
.31412 .70993 Mdot
.43317 .75557 Mdot
.289 .38287 Mdot
.66837 .59009 Mdot
.56167 .49997 Mdot
.67369 .44399 Mdot
.4916 .18504 Mdot
.48638 .67097 Mdot
.59435 .28622 Mdot
.33836 .47039 Mdot
.50599 .72396 Mdot
.6641 .36175 Mdot
.48674 .65065 Mdot
.29858 .4404 Mdot
.65685 .57716 Mdot
.6641 .41288 Mdot
.70894 .55861 Mdot
.5368 .67764 Mdot
.57637 .29653 Mdot
.4467 .27947 Mdot
.28991 .68568 Mdot
.37186 .59367 Mdot
.41355 .47664 Mdot
.69656 .34987 Mdot
.41592 .46692 Mdot
.46282 .69749 Mdot
.39377 .46396 Mdot
.31194 .4635 Mdot
.65946 .44827 Mdot
.37626 .42728 Mdot
.34493 .45369 Mdot
.37901 .74659 Mdot
.36741 .47456 Mdot
.40443 .47582 Mdot
.36452 .42568 Mdot
.51996 .7089 Mdot
.36782 .42774 Mdot
.52082 .68007 Mdot
.64939 .75975 Mdot
.68072 .42201 Mdot
.59728 .29843 Mdot
.5939 .30079 Mdot
.46282 .29991 Mdot
.33025 .30768 Mdot
.44282 .7279 Mdot
.50029 .66533 Mdot
.69246 .58209 Mdot
.35077 .50221 Mdot
.23546 .34853 Mdot
.48314 .20858 Mdot
.69383 .42644 Mdot
.66815 .43847 Mdot
.34673 .48218 Mdot
.4469 .85668 Mdot
.34268 .4404 Mdot
.46619 .4123 Mdot
.36981 .44402 Mdot
.33027 .44567 Mdot
.62551 .40649 Mdot
.41098 .28975 Mdot
.41327 .47548 Mdot
.50651 .63939 Mdot
.59241 .28822 Mdot
.41301 .55311 Mdot
.47765 .23049 Mdot
.42142 .75766 Mdot
.44134 .56344 Mdot
.40064 .48816 Mdot
.66004 .37651 Mdot
.48094 .66397 Mdot
.45615 .39774 Mdot
.70892 .57433 Mdot
.44975 .34586 Mdot
.24808 .634 Mdot
.64516 .59376 Mdot
.59046 .29518 Mdot
.65627 .35939 Mdot
.39933 .44171 Mdot
.67757 .39446 Mdot
.37979 .52832 Mdot
.46576 .39477 Mdot
.57809 .28524 Mdot
.46713 .64911 Mdot
.69786 .56594 Mdot
.49927 .72476 Mdot
.27294 .53066 Mdot
.4849 .20552 Mdot
.36035 .19217 Mdot
.68259 .3724 Mdot
.23381 .52953 Mdot
.49705 .70456 Mdot
.40809 .45125 Mdot
.84781 .63009 Mdot
.50125 .69139 Mdot
.52114 .69879 Mdot
.47666 .39423 Mdot
.39379 .28148 Mdot
.3672 .52758 Mdot
.47571 .66874 Mdot
.65734 .35949 Mdot
.58155 .27709 Mdot
.34051 .48384 Mdot
.30197 .43305 Mdot
.49218 .71823 Mdot
.65617 .41594 Mdot
.42951 .30047 Mdot
.67418 .40717 Mdot
.47982 .69145 Mdot
.66447 .4305 Mdot
.64518 .64443 Mdot
.66072 .44356 Mdot
.36615 .43524 Mdot
.37342 .46226 Mdot
.49028 .58849 Mdot
.49078 .6568 Mdot
.32864 .4812 Mdot
.39565 .44827 Mdot
.48948 .70075 Mdot
.6146 .40416 Mdot
.28374 .55253 Mdot
.32677 .48382 Mdot
.3704 .45874 Mdot
.59958 .27858 Mdot
.40795 .3321 Mdot
.47896 .43904 Mdot
.33597 .47468 Mdot
.56631 .28269 Mdot
.5228 .69025 Mdot
.38204 .47299 Mdot
.41388 .28964 Mdot
.70535 .39911 Mdot
.37122 .50324 Mdot
.51045 .56384 Mdot
.41688 .46143 Mdot
.18307 .48081 Mdot
.37638 .49297 Mdot
.48233 .68632 Mdot
.4894 .70855 Mdot
.6177 .4337 Mdot
.48913 .67663 Mdot
.50501 .55716 Mdot
.68873 .57704 Mdot
.28779 .70387 Mdot
.5085 .55469 Mdot
.36461 .51722 Mdot
.54661 .2013 Mdot
.30655 .42618 Mdot
.33761 .39604 Mdot
.5445 .23502 Mdot
.50025 .5666 Mdot
.5032 .69922 Mdot
.56231 .78076 Mdot
.42458 .49647 Mdot
.71114 .57476 Mdot
.31206 .42079 Mdot
.37292 .50323 Mdot
.31448 .45637 Mdot
.54102 .7265 Mdot
.70563 .56387 Mdot
.35826 .37983 Mdot
.34044 .48405 Mdot
.26509 .53422 Mdot
.3546 .44824 Mdot
.56671 .29975 Mdot
.50958 .68265 Mdot
.68423 .39529 Mdot
.58312 .28363 Mdot
.39991 .50998 Mdot
.58769 .26415 Mdot
.67315 .39309 Mdot
.69792 .59024 Mdot
.37009 .43461 Mdot
.60525 .28059 Mdot
.58227 .30287 Mdot
.39936 .49928 Mdot
.49516 .71162 Mdot
.43541 .47422 Mdot
.37859 .47411 Mdot
.38842 .49313 Mdot
.47593 .70037 Mdot
.82119 .41623 Mdot
.40664 .45977 Mdot
.56359 .50071 Mdot
.46069 .68555 Mdot
.52198 .55934 Mdot
.67963 .38545 Mdot
.34133 .50561 Mdot
.66325 .58129 Mdot
.6876 .57831 Mdot
.69412 .3774 Mdot
.48642 .71713 Mdot
.66614 .41629 Mdot
.3205 .48667 Mdot
.31873 .41383 Mdot
.34054 .47525 Mdot
.60616 .39698 Mdot
.68708 .66419 Mdot
.49944 .64587 Mdot
.69607 .40705 Mdot
.44293 .34873 Mdot
.66919 .56292 Mdot
.62436 .39516 Mdot
.49648 .63551 Mdot
.47401 .70548 Mdot
.47479 .68457 Mdot
.56569 .28877 Mdot
.66328 .40838 Mdot
.53799 .66953 Mdot
.52932 .64851 Mdot
.37887 .50671 Mdot
.34184 .4884 Mdot
.5233 .68211 Mdot
.66661 .4811 Mdot
.58241 .29569 Mdot
.66433 .3741 Mdot
.15918 .46489 Mdot
.70021 .56074 Mdot
.38012 .74618 Mdot
.33542 .47049 Mdot
.6964 .82949 Mdot
.34281 .43977 Mdot
.34947 .45521 Mdot
.53704 .69118 Mdot
.59223 .24956 Mdot
.5808 .27352 Mdot
.49643 .70542 Mdot
.46916 .6818 Mdot
.55843 .28423 Mdot
.49859 .44743 Mdot
.18485 .45981 Mdot
.45301 .38694 Mdot
.49419 .64858 Mdot
.27326 .67545 Mdot
.68025 .60256 Mdot
.46827 .71674 Mdot
.61496 .58317 Mdot
.67461 .42891 Mdot
.66956 .44093 Mdot
.6973 .582 Mdot
.40718 .46587 Mdot
.6525 .37341 Mdot
.34605 .41965 Mdot
.71294 .64811 Mdot
.57289 .55863 Mdot
.28498 .27827 Mdot
.37288 .43271 Mdot
.39713 .56168 Mdot
.71981 .72413 Mdot
.35229 .50832 Mdot
.38902 .68597 Mdot
.59488 .27768 Mdot
.46675 .70997 Mdot
.68416 .554 Mdot
.48674 .78108 Mdot
.37569 .46248 Mdot
.48768 .65476 Mdot
.68473 .55673 Mdot
.70452 .66017 Mdot
.5605 .48729 Mdot
.37839 .51094 Mdot
.87471 .58845 Mdot
.51078 .63826 Mdot
.68335 .39411 Mdot
.32869 .69426 Mdot
.48726 .72738 Mdot
.56174 .47098 Mdot
.66174 .3602 Mdot
.42397 .36509 Mdot
.47905 .65877 Mdot
.59077 .24515 Mdot
.50054 .67577 Mdot
.5648 .25278 Mdot
.53996 .68063 Mdot
.66585 .42581 Mdot
.37572 .48068 Mdot
.67228 .42413 Mdot
.5558 .28047 Mdot
.68304 .37177 Mdot
.68357 .55403 Mdot
.4995 .5724 Mdot
.68683 .59262 Mdot
.35568 .31897 Mdot
.34656 .60565 Mdot
.70257 .59062 Mdot
.49485 .52577 Mdot
.3805 .43838 Mdot
.53065 .7134 Mdot
.68557 .40027 Mdot
.65991 .45079 Mdot
.43222 .3452 Mdot
.47852 .69485 Mdot
.6564 .41945 Mdot
.28156 .67883 Mdot
.81529 .57113 Mdot
.31049 .47129 Mdot
.72286 .51376 Mdot
.48516 .69546 Mdot
.64232 .44331 Mdot
.46357 .41107 Mdot
.4799 .71802 Mdot
.6771 .43476 Mdot
.70434 .57425 Mdot
.66413 .57929 Mdot
.36281 .43312 Mdot
.69132 .54869 Mdot
.67222 .4435 Mdot
.25175 .52458 Mdot
.50957 .70401 Mdot
.67263 .66584 Mdot
.59388 .29537 Mdot
.68453 .40644 Mdot
.42571 .46358 Mdot
.52444 .70805 Mdot
.64335 .428 Mdot
.51698 .85484 Mdot
.13761 .54058 Mdot
.65494 .41775 Mdot
.5089 .68118 Mdot
.49487 .65817 Mdot
.33516 .50931 Mdot
.43507 .35136 Mdot
.65031 .4094 Mdot
.77401 .41265 Mdot
.3072 .32964 Mdot
.50422 .5706 Mdot
.40343 .16984 Mdot
.41317 .47328 Mdot
.39805 .49103 Mdot
.70655 .59428 Mdot
.36354 .47692 Mdot
.47108 .67202 Mdot
.34198 .44016 Mdot
.66572 .60524 Mdot
.70023 .38857 Mdot
.37676 .46754 Mdot
.59482 .28984 Mdot
.67356 .60865 Mdot
.67994 .61307 Mdot
.66072 .43215 Mdot
.48397 .71394 Mdot
.57347 .81036 Mdot
.67302 .40852 Mdot
.38785 .49587 Mdot
.51146 .58875 Mdot
.37193 .42645 Mdot
.48654 .6067 Mdot
.46221 .67981 Mdot
.68653 .39677 Mdot
.5221 .59639 Mdot
.6751 .58013 Mdot
.67212 .44567 Mdot
.41488 .45553 Mdot
.6885 .42564 Mdot
.5804 .50116 Mdot
.65986 .23979 Mdot
.51056 .63394 Mdot
.57547 .47686 Mdot
.47756 .71344 Mdot
.50424 .56602 Mdot
.39935 .24155 Mdot
.58543 .29675 Mdot
.68378 .38101 Mdot
.63093 .64666 Mdot
.68544 .41868 Mdot
.3646 .47155 Mdot
.38853 .44347 Mdot
.65534 .38301 Mdot
.57182 .29262 Mdot
.511 .33299 Mdot
.58622 .23876 Mdot
.51197 .67274 Mdot
.51478 .4733 Mdot
.15911 .44139 Mdot
.70741 .41024 Mdot
.69433 .57822 Mdot
.44549 .56982 Mdot
.37345 .5185 Mdot
.69512 .55684 Mdot
.68882 .61414 Mdot
.55732 .25491 Mdot
.68533 .41331 Mdot
.47482 .64103 Mdot
.65894 .57507 Mdot
.50008 .73248 Mdot
.42879 .29619 Mdot
.2924 .46989 Mdot
.2846 .3955 Mdot
.38914 .51897 Mdot
.42743 .34328 Mdot
.65623 .58059 Mdot
.38822 .45053 Mdot
.35296 .53193 Mdot
.70225 .56725 Mdot
.56023 .25191 Mdot
.55893 .59215 Mdot
.65464 .41991 Mdot
.79433 .69557 Mdot
.36321 .43696 Mdot
.37921 .47774 Mdot
.69841 .56181 Mdot
.39419 .7189 Mdot
.51332 .64662 Mdot
.49159 .71487 Mdot
.6641 .39658 Mdot
.47988 .40875 Mdot
.37735 .43033 Mdot
.37338 .4359 Mdot
.64262 .38674 Mdot
.51809 .5872 Mdot
.37612 .18805 Mdot
.37366 .45467 Mdot
.6748 .59191 Mdot
.57122 .51701 Mdot
.65993 .56137 Mdot
.32687 .44158 Mdot
.36074 .46613 Mdot
.42083 .47069 Mdot
.41439 .44924 Mdot
.68619 .59746 Mdot
.39159 .51688 Mdot
.39725 .5232 Mdot
.50048 .6972 Mdot
.40722 .47878 Mdot
.30536 .33032 Mdot
.37632 .45708 Mdot
.59584 .28099 Mdot
.48126 .43744 Mdot
.37821 .49165 Mdot
.40533 .48131 Mdot
.30988 .32853 Mdot
.36042 .48031 Mdot
.68663 .55635 Mdot
.49106 .65993 Mdot
.67404 .57904 Mdot
.6937 .57231 Mdot
.64958 .43376 Mdot
.57229 .24727 Mdot
.34823 .52385 Mdot
.55916 .28029 Mdot
.32842 .50494 Mdot
.37137 .38342 Mdot
.39704 .31951 Mdot
.46534 .41004 Mdot
.59159 .30684 Mdot
.37319 .43697 Mdot
.67034 .39563 Mdot
.68955 .40228 Mdot
.53894 .4789 Mdot
.32824 .41123 Mdot
.67473 .55215 Mdot
.70249 .58251 Mdot
.53396 .32434 Mdot
.64197 .21776 Mdot
.57764 .30442 Mdot
.51773 .34741 Mdot
.37544 .41755 Mdot
.40303 .47125 Mdot
.3635 .3968 Mdot
.63498 .41007 Mdot
.49883 .56845 Mdot
.65777 .36845 Mdot
.68973 .63812 Mdot
.66944 .6017 Mdot
.36904 .4333 Mdot
.41154 .843 Mdot
.51709 .68145 Mdot
.49205 .65828 Mdot
.66468 .60444 Mdot
.6914 .38702 Mdot
.33897 .4008 Mdot
.74782 .74506 Mdot
.46688 .66282 Mdot
.60259 .28547 Mdot
.36719 .48499 Mdot
.67513 .42744 Mdot
.51583 .69177 Mdot
.60484 .28653 Mdot
.40852 .4438 Mdot
.65678 .36079 Mdot
.38665 .45431 Mdot
.25912 .6022 Mdot
.5057 .70114 Mdot
.38583 .32915 Mdot
.53387 .68756 Mdot
.68404 .59757 Mdot
.67869 .56444 Mdot
.36256 .4652 Mdot
.76921 .72835 Mdot
.46258 .72682 Mdot
.68071 .61966 Mdot
.59237 .25446 Mdot
.50172 .58215 Mdot
.57791 .25014 Mdot
.65657 .38499 Mdot
.58977 .29537 Mdot
.64568 .4302 Mdot
.664 .4831 Mdot
.49843 .63132 Mdot
.57207 .26148 Mdot
.39095 .65562 Mdot
.33031 .40363 Mdot
.5555 .24689 Mdot
.352 .4883 Mdot
.32641 .49594 Mdot
.64429 .40769 Mdot
.56397 .29037 Mdot
.39149 .51174 Mdot
.60154 .67651 Mdot
.68516 .5647 Mdot
.67654 .55316 Mdot
.31261 .42227 Mdot
.63354 .4309 Mdot
.50402 .63454 Mdot
.4336 .32589 Mdot
.46682 .64698 Mdot
.37027 .43638 Mdot
.3315 .51209 Mdot
.53079 .65904 Mdot
.52405 .65817 Mdot
.36015 .46198 Mdot
.34362 .74756 Mdot
.41704 .48829 Mdot
.66515 .57601 Mdot
.51318 .67408 Mdot
.49593 .6557 Mdot
.66927 .44408 Mdot
.49534 .71709 Mdot
.41726 .52611 Mdot
.6522 .6195 Mdot
.41414 .51453 Mdot
.67735 .58254 Mdot
.70546 .43799 Mdot
.64469 .41698 Mdot
.63678 .64981 Mdot
.49987 .71567 Mdot
.33039 .47668 Mdot
.51319 .71034 Mdot
.59541 .26672 Mdot
.49622 .65132 Mdot
.53341 .71772 Mdot
.34071 .46184 Mdot
.4 .50854 Mdot
.51818 .58205 Mdot
.43138 .34944 Mdot
.50793 .69265 Mdot
.32017 .48068 Mdot
.33377 .44735 Mdot
.39272 .44355 Mdot
.42248 .32173 Mdot
.51893 .70946 Mdot
.41893 .75558 Mdot
.45104 .66888 Mdot
.50928 .6986 Mdot
.15473 .55955 Mdot
.51974 .57331 Mdot
.52018 .59283 Mdot
.67322 .5457 Mdot
.3707 .45565 Mdot
.6691 .41924 Mdot
.39121 .49677 Mdot
.39746 .408 Mdot
.37706 .49037 Mdot
.57541 .25658 Mdot
.38521 .43011 Mdot
.50901 .57718 Mdot
.67803 .40855 Mdot
.34551 .50373 Mdot
.37079 .46509 Mdot
.52353 .57966 Mdot
.52223 .70086 Mdot
.47867 .71238 Mdot
.469 .64008 Mdot
.55472 .26124 Mdot
.6869 .6071 Mdot
.38661 .49742 Mdot
.66679 .39636 Mdot
.67442 .41951 Mdot
.51113 .7181 Mdot
.64543 .38261 Mdot
.67787 .60945 Mdot
.35105 .45535 Mdot
.6852 .59685 Mdot
.57621 .25615 Mdot
.50997 .6836 Mdot
.37088 .49595 Mdot
.38768 .50484 Mdot
.48967 .70866 Mdot
.412 .49569 Mdot
.5927 .25929 Mdot
.63081 .41248 Mdot
.50527 .64654 Mdot
.68776 .57605 Mdot
.66539 .4444 Mdot
.33438 .49115 Mdot
.19738 .65943 Mdot
.3622 .47585 Mdot
.38603 .43554 Mdot
.46623 .73731 Mdot
.3496 .42461 Mdot
.68377 .42056 Mdot
.50819 .71544 Mdot
.32592 .49074 Mdot
.31239 .32291 Mdot
.58363 .32907 Mdot
.71214 .38916 Mdot
.34843 .4717 Mdot
.26146 .69505 Mdot
.33188 .46166 Mdot
.62921 .64963 Mdot
.39689 .31982 Mdot
.64646 .52989 Mdot
.28431 .396 Mdot
.67989 .61877 Mdot
.51557 .58931 Mdot
.65167 .43169 Mdot
.36807 .71245 Mdot
.35683 .46424 Mdot
.35022 .58778 Mdot
.37286 .49754 Mdot
.66726 .58894 Mdot
.39732 .68684 Mdot
.65493 .37706 Mdot
.37066 .20261 Mdot
.41085 .46197 Mdot
.50292 .63852 Mdot
.61961 .39867 Mdot
.51484 .59551 Mdot
.39848 .50918 Mdot
.56866 .30019 Mdot
.54057 .32717 Mdot
.42855 .5094 Mdot
.67731 .57946 Mdot
.40248 .4566 Mdot
.4137 .42669 Mdot
.83329 .50135 Mdot
.49206 .69572 Mdot
.69862 .5711 Mdot
.63792 .2187 Mdot
.38331 .44228 Mdot
.47473 .70648 Mdot
.487 .67042 Mdot
.55768 .26642 Mdot
.69223 .62695 Mdot
.55925 .34275 Mdot
.37697 .81151 Mdot
.23306 .48668 Mdot
.63411 .41064 Mdot
.53161 .6264 Mdot
.39757 .49452 Mdot
.48645 .20478 Mdot
.69256 .57467 Mdot
.37949 .47921 Mdot
.38605 .5975 Mdot
.48563 .68719 Mdot
.38135 .45189 Mdot
.58387 .2945 Mdot
.62466 .8074 Mdot
.2632 .65217 Mdot
.27829 .71587 Mdot
.65789 .35949 Mdot
.36285 .52778 Mdot
.41111 .52889 Mdot
.52234 .55945 Mdot
.31832 .45434 Mdot
.68429 .39931 Mdot
.58836 .51829 Mdot
.57228 .28506 Mdot
.51796 .68703 Mdot
.51953 .58869 Mdot
.37189 .49763 Mdot
.38169 .52741 Mdot
.59599 .26053 Mdot
.41662 .48172 Mdot
.3335 .7046 Mdot
.49391 .56769 Mdot
.65592 .44283 Mdot
.49163 .64629 Mdot
.34073 .51973 Mdot
.50601 .58888 Mdot
.34123 .4671 Mdot
.3883 .57092 Mdot
.38972 .48028 Mdot
.59899 .62987 Mdot
.48563 .70958 Mdot
.68051 .57212 Mdot
.41187 .44289 Mdot
.38452 .45973 Mdot
.57392 .4435 Mdot
.34073 .39904 Mdot
.39128 .48833 Mdot
.49404 .72641 Mdot
.51808 .68392 Mdot
.50706 .64137 Mdot
.68588 .43309 Mdot
.44774 .37839 Mdot
.6829 .59189 Mdot
.35971 .39667 Mdot
.6586 .57583 Mdot
.29674 .38307 Mdot
.57489 .25285 Mdot
.64872 .65735 Mdot
.35397 .45446 Mdot
.47627 .68597 Mdot
.18927 .44555 Mdot
.51699 .71259 Mdot
.64033 .59114 Mdot
.68987 .57148 Mdot
.50222 .68891 Mdot
.35213 .47396 Mdot
.42891 .35676 Mdot
.28963 .7316 Mdot
.66773 .56364 Mdot
.30595 .43018 Mdot
.72156 .39787 Mdot
.70324 .39706 Mdot
.15261 .5423 Mdot
.66054 .57544 Mdot
.72051 .72432 Mdot
.32668 .48471 Mdot
.51134 .70969 Mdot
.69346 .60051 Mdot
.70491 .60493 Mdot
.64777 .37849 Mdot
.37813 .50932 Mdot
.38398 .45763 Mdot
.51168 .56452 Mdot
.6926 .59272 Mdot
.38068 .55282 Mdot
.37946 .51209 Mdot
.71551 .64287 Mdot
.48182 .64297 Mdot
.81937 .40883 Mdot
.45748 .54007 Mdot
.38419 .59734 Mdot
.79783 .42675 Mdot
.50969 .64811 Mdot
.40748 .468 Mdot
.3392 .40137 Mdot
.63094 .40373 Mdot
.35128 .46459 Mdot
.69722 .40358 Mdot
.6714 .59944 Mdot
.5964 .65726 Mdot
.48952 .52497 Mdot
.65665 .63848 Mdot
.367 .47693 Mdot
.27172 .66274 Mdot
.57186 .26981 Mdot
.65332 .56398 Mdot
.51974 .65371 Mdot
.32659 .44515 Mdot
.63481 .38873 Mdot
.69345 .41944 Mdot
.48823 .68535 Mdot
.70027 .72266 Mdot
.63706 .65208 Mdot
.42332 .4759 Mdot
.66964 .38192 Mdot
.46614 .54291 Mdot
.25037 .66792 Mdot
.65933 .60221 Mdot
.57146 .28244 Mdot
.66373 .43468 Mdot
.70839 .5622 Mdot
.32751 .49909 Mdot
.49427 .68352 Mdot
.51223 .63781 Mdot
.54954 .47256 Mdot
.65842 .41983 Mdot
.58771 .27626 Mdot
.55268 .4765 Mdot
.52142 .4773 Mdot
.58106 .28781 Mdot
.69277 .42807 Mdot
.51025 .65986 Mdot
.48029 .68648 Mdot
.49043 .66154 Mdot
.38004 .74311 Mdot
.46254 .67847 Mdot
.4667 .26167 Mdot
.32058 .44959 Mdot
.27972 .68468 Mdot
.32482 .45634 Mdot
.68676 .55448 Mdot
.50416 .70388 Mdot
.39309 .32141 Mdot
.38672 .41989 Mdot
.29731 .7363 Mdot
.39692 .46655 Mdot
.56785 .50992 Mdot
.37007 .4568 Mdot
.28056 .63868 Mdot
.4692 .71358 Mdot
.40906 .44801 Mdot
.65156 .6154 Mdot
.59021 .26515 Mdot
.54208 .68379 Mdot
.39629 .48314 Mdot
.61923 .77244 Mdot
.35249 .48907 Mdot
.59738 .64913 Mdot
.55968 .46784 Mdot
.57738 .22165 Mdot
.36533 .42667 Mdot
.642 .37551 Mdot
.44817 .53168 Mdot
.27099 .67668 Mdot
.66652 .56456 Mdot
.27708 .67122 Mdot
.66559 .37179 Mdot
.39713 .69158 Mdot
.4203 .43437 Mdot
.5721 .28795 Mdot
.5637 .59365 Mdot
.66758 .57123 Mdot
.35583 .45675 Mdot
.40869 .4592 Mdot
.57289 .55226 Mdot
.24363 .65023 Mdot
.39718 .55419 Mdot
.59775 .30402 Mdot
.25427 .6458 Mdot
.3878 .48857 Mdot
.71269 .38685 Mdot
.48607 .71903 Mdot
.40064 .67289 Mdot
.40042 .71148 Mdot
.36504 .51332 Mdot
.49903 .69023 Mdot
.48624 .71686 Mdot
.19256 .39825 Mdot
.56646 .27066 Mdot
.392 .47812 Mdot
.5761 .47562 Mdot
.38361 .49734 Mdot
.67187 .59479 Mdot
.36274 .41828 Mdot
.64606 .41707 Mdot
.46399 .41515 Mdot
.68844 .43029 Mdot
.39096 .44133 Mdot
.50165 .67478 Mdot
.68125 .56033 Mdot
.69172 .50057 Mdot
.68985 .62715 Mdot
.46575 .2624 Mdot
.52896 .30904 Mdot
.57962 .30487 Mdot
.57108 .25036 Mdot
.65851 .55845 Mdot
.34665 .46565 Mdot
.43441 .33658 Mdot
.31305 .44643 Mdot
.37015 .45119 Mdot
.38578 .48454 Mdot
.65773 .53743 Mdot
.68824 .57089 Mdot
.66712 .42873 Mdot
.35939 .46094 Mdot
.31849 .4749 Mdot
.50251 .68092 Mdot
.57968 .30371 Mdot
.64568 .43493 Mdot
.56249 .29582 Mdot
.67552 .40299 Mdot
.1825 .48276 Mdot
.29385 .44849 Mdot
.58566 .26173 Mdot
.65802 .59124 Mdot
.47891 .67191 Mdot
.51728 .5616 Mdot
.65377 .38828 Mdot
.65097 .37973 Mdot
.34586 .51981 Mdot
.51347 .69393 Mdot
.49457 .71545 Mdot
.55967 .28846 Mdot
.70254 .58532 Mdot
.31424 .50075 Mdot
.3781 .51973 Mdot
.71217 .48005 Mdot
.62905 .40877 Mdot
.26181 .65915 Mdot
.45096 .70564 Mdot
.34791 .45286 Mdot
.4754 .70601 Mdot
.38141 .46808 Mdot
.46851 .56892 Mdot
.51797 .64583 Mdot
.35076 .42295 Mdot
.34771 .40882 Mdot
.63551 .41429 Mdot
.21775 .3514 Mdot
.31871 .51041 Mdot
.62461 .60012 Mdot
.40439 .49121 Mdot
.35465 .19162 Mdot
.1916 .43551 Mdot
.345 .47823 Mdot
.39052 .43348 Mdot
.34407 .79766 Mdot
.33372 .45808 Mdot
.50903 .56949 Mdot
.3988 .40822 Mdot
.47282 .6996 Mdot
.57675 .48608 Mdot
.42959 .34395 Mdot
.5645 .26636 Mdot
.66427 .39566 Mdot
.40066 .28437 Mdot
.56347 .25285 Mdot
.48307 .68981 Mdot
.31943 .51414 Mdot
.45616 .71895 Mdot
.65047 .4524 Mdot
.36538 .55046 Mdot
.66872 .59256 Mdot
.43365 .34097 Mdot
.64082 .38352 Mdot
.68885 .57632 Mdot
.3316 .45603 Mdot
.62778 .44913 Mdot
.64676 .5885 Mdot
.19712 .37232 Mdot
.70834 .59076 Mdot
.67906 .56782 Mdot
.43839 .36213 Mdot
.56431 .26651 Mdot
.58923 .52828 Mdot
.35855 .38149 Mdot
.68078 .55816 Mdot
.3753 .21425 Mdot
.62873 .39937 Mdot
.46166 .38613 Mdot
.47247 .71947 Mdot
.30095 .434 Mdot
.37996 .48279 Mdot
.70792 .58101 Mdot
.52815 .61135 Mdot
.57304 .43353 Mdot
.66435 .59294 Mdot
.40434 .43027 Mdot
.48066 .41611 Mdot
.50412 .58446 Mdot
.51906 .57036 Mdot
.60463 .281 Mdot
.6824 .27625 Mdot
.48009 .70515 Mdot
.60194 .28647 Mdot
.35935 .32707 Mdot
.39893 .46226 Mdot
.68675 .59907 Mdot
.52164 .58649 Mdot
.68637 .57812 Mdot
.57683 .27346 Mdot
.59116 .25532 Mdot
.49904 .69735 Mdot
.51528 .64992 Mdot
.55208 .62184 Mdot
.29207 .3321 Mdot
.36855 .50397 Mdot
.33454 .59238 Mdot
.52397 .65703 Mdot
.38374 .72148 Mdot
.5619 .27767 Mdot
.57139 .29833 Mdot
.21747 .57264 Mdot
.34485 .49801 Mdot
.57083 .5155 Mdot
.38133 .4918 Mdot
.41479 .21351 Mdot
.36901 .49671 Mdot
.64379 .38503 Mdot
.41354 .46786 Mdot
.5569 .79614 Mdot
.33068 .49324 Mdot
.38073 .48725 Mdot
.65619 .40336 Mdot
.34968 .52343 Mdot
.64479 .41179 Mdot
.40604 .46786 Mdot
.55324 .3173 Mdot
.66646 .3967 Mdot
.56055 .3108 Mdot
.54447 .49869 Mdot
.51449 .57457 Mdot
.56603 .25632 Mdot
.57837 .30621 Mdot
.43386 .30197 Mdot
.51568 .66817 Mdot
.43071 .62521 Mdot
.36643 .48429 Mdot
.62747 .41731 Mdot
.67879 .60701 Mdot
.36774 .51439 Mdot
.35518 .43157 Mdot
.31735 .50703 Mdot
.50098 .69448 Mdot
.6643 .44738 Mdot
.57854 .26455 Mdot
.69122 .40887 Mdot
.55621 .3165 Mdot
.64131 .41494 Mdot
.30518 .44628 Mdot
.32902 .50392 Mdot
.40638 .53071 Mdot
.37875 .62652 Mdot
.52954 .20282 Mdot
.49128 .68439 Mdot
.51102 .5872 Mdot
.57806 .25184 Mdot
.49898 .43382 Mdot
.47552 .69749 Mdot
.64745 .38404 Mdot
.38697 .45445 Mdot
.29183 .4659 Mdot
.36349 .3824 Mdot
.51166 .73344 Mdot
.55134 .25437 Mdot
.6564 .39285 Mdot
.50275 .57276 Mdot
.4541 .38675 Mdot
.43462 .75899 Mdot
.36565 .31586 Mdot
.38334 .46367 Mdot
.55743 .28141 Mdot
.51587 .6915 Mdot
.5771 .53188 Mdot
.70601 .5758 Mdot
.4339 .35003 Mdot
.36663 .47788 Mdot
.75463 .60403 Mdot
.5005 .67342 Mdot
.57766 .29713 Mdot
.70819 .58084 Mdot
.56588 .2775 Mdot
.50534 .59173 Mdot
.44902 .69471 Mdot
.39985 .50719 Mdot
.37853 .49306 Mdot
.67609 .60432 Mdot
.48279 .7092 Mdot
.55666 .32452 Mdot
.58057 .55392 Mdot
.65706 .38337 Mdot
.49396 .43947 Mdot
.51727 .68725 Mdot
.74866 .57473 Mdot
.69288 .40716 Mdot
.68143 .54895 Mdot
.42027 .3473 Mdot
.6805 .61131 Mdot
.38784 .48661 Mdot
.50081 .66287 Mdot
.66532 .56436 Mdot
.7102 .47002 Mdot
.35715 .76766 Mdot
.56732 .58478 Mdot
.38233 .43887 Mdot
.63953 .66333 Mdot
.68388 .74714 Mdot
.54531 .6714 Mdot
.65921 .58176 Mdot
.3697 .4714 Mdot
.42311 .47699 Mdot
.4114 .46242 Mdot
.69078 .56436 Mdot
.69219 .51828 Mdot
.67651 .37794 Mdot
.38713 .44902 Mdot
.59602 .28928 Mdot
.64976 .42267 Mdot
.69662 .37712 Mdot
.66585 .43482 Mdot
.5217 .65815 Mdot
.29456 .47963 Mdot
.38411 .4004 Mdot
.20715 .39381 Mdot
.67883 .57 Mdot
.51425 .57485 Mdot
.39794 .43887 Mdot
.46285 .26926 Mdot
.47924 .67602 Mdot
.65044 .39548 Mdot
.38062 .47781 Mdot
.55411 .46891 Mdot
.50202 .54306 Mdot
.66647 .40852 Mdot
.52018 .65102 Mdot
.51465 .75407 Mdot
.35114 .46186 Mdot
.39906 .49545 Mdot
.4865 .70249 Mdot
.68103 .76225 Mdot
.46092 .3958 Mdot
.37933 .46704 Mdot
.68468 .57182 Mdot
.79796 .64906 Mdot
.32959 .45814 Mdot
.45631 .69499 Mdot
.4989 .56571 Mdot
.45233 .72053 Mdot
.31997 .7124 Mdot
.34539 .4035 Mdot
.57138 .66403 Mdot
.49907 .30912 Mdot
.54941 .71254 Mdot
.43981 .21077 Mdot
.58691 .56265 Mdot
.17292 .41389 Mdot
.65794 .62772 Mdot
.26607 .62216 Mdot
.50161 .85091 Mdot
.71802 .72071 Mdot
.58006 .4575 Mdot
.65516 .51235 Mdot
.66251 .46125 Mdot
.38425 .1831 Mdot
.64895 .3696 Mdot
.45096 .2 Mdot
.36845 .4926 Mdot
.67081 .76586 Mdot
.27268 .63925 Mdot
.53651 .22592 Mdot
.65087 .65033 Mdot
.55657 .47088 Mdot
.24205 .70274 Mdot
.68908 .65009 Mdot
.18169 .57488 Mdot
.41083 .60315 Mdot
.72106 .30424 Mdot
.50504 .45285 Mdot
.4179 .28268 Mdot
.2898 .67658 Mdot
.55432 .76282 Mdot
.73774 .60904 Mdot
.26395 .55071 Mdot
.80656 .42668 Mdot
.67279 .38723 Mdot
.47632 .71565 Mdot
.63076 .5238 Mdot
.2059 .63022 Mdot
.63326 .59399 Mdot
.57065 .66484 Mdot
.5731 .57119 Mdot
.27605 .63411 Mdot
.38204 .3273 Mdot
.26261 .59823 Mdot
.55111 .34223 Mdot
.3893 .18373 Mdot
.49077 .75151 Mdot
.73984 .42519 Mdot
.49322 .41012 Mdot
.54057 .35457 Mdot
.30998 .66998 Mdot
.59014 .31874 Mdot
.57887 .32589 Mdot
.51778 .64695 Mdot
.22531 .64677 Mdot
.50988 .53703 Mdot
.35044 .33127 Mdot
.64506 .37103 Mdot
.47052 .55921 Mdot
.61763 .8074 Mdot
.67714 .74675 Mdot
.24274 .3136 Mdot
.19524 .64883 Mdot
.37204 .24231 Mdot
.56689 .52938 Mdot
.63738 .5687 Mdot
.46543 .28231 Mdot
.37766 .55999 Mdot
.34922 .25501 Mdot
.39876 .57128 Mdot
.29794 .75628 Mdot
.64314 .74683 Mdot
.21819 .6859 Mdot
.49825 .75253 Mdot
.36506 .53341 Mdot
.48637 .58675 Mdot
.25157 .5133 Mdot
.34132 .31155 Mdot
.22116 .67501 Mdot
.57716 .22567 Mdot
.51676 .60886 Mdot
.72108 .71487 Mdot
.33182 .70459 Mdot
.57535 .35411 Mdot
.54446 .24895 Mdot
.40967 .6619 Mdot
.25053 .72258 Mdot
.57481 .66563 Mdot
.20481 .49634 Mdot
.72752 .63903 Mdot
.61304 .38931 Mdot
.69238 .37343 Mdot
.69578 .61559 Mdot
.18432 .60572 Mdot
.49643 .66374 Mdot
.21369 .35192 Mdot
.55543 .64764 Mdot
.4427 .55054 Mdot
.2561 .73067 Mdot
.31193 .26324 Mdot
.30123 .698 Mdot
.50025 .23937 Mdot
.77931 .62313 Mdot
.27485 .51187 Mdot
.65279 .6318 Mdot
.7188 .39653 Mdot
.60773 .64643 Mdot
.1913 .61948 Mdot
.35099 .24298 Mdot
.40909 .83403 Mdot
.34282 .33637 Mdot
.63176 .32819 Mdot
.48554 .74927 Mdot
.59936 .45767 Mdot
.58325 .36316 Mdot
.21355 .68092 Mdot
.25729 .64062 Mdot
.79273 .63941 Mdot
.42105 .22594 Mdot
.39956 .71989 Mdot
.63027 .67457 Mdot
.64895 .49611 Mdot
.25666 .49666 Mdot
.634 .76454 Mdot
.39216 .52102 Mdot
.37076 .30706 Mdot
.41101 .63755 Mdot
.60712 .25701 Mdot
.45025 .38667 Mdot
.65211 .7266 Mdot
.37335 .26446 Mdot
.76132 .66223 Mdot
.41222 .66758 Mdot
.53582 .68051 Mdot
.35212 .25548 Mdot
.39591 .23102 Mdot
.72686 .66862 Mdot
.63515 .21679 Mdot
.20335 .49984 Mdot
.60066 .37298 Mdot
.35803 .40148 Mdot
.26273 .61706 Mdot
.29262 .67738 Mdot
.3997 .19452 Mdot
.30442 .44244 Mdot
.22361 .36085 Mdot
.64211 .63916 Mdot
.36303 .63489 Mdot
.34239 .29426 Mdot
.37419 .63043 Mdot
.29136 .70657 Mdot
.47319 .61483 Mdot
.62442 .5566 Mdot
.54055 .59892 Mdot
.2532 .72319 Mdot
.65729 .42871 Mdot
.34468 .25429 Mdot
.64169 .6218 Mdot
.70835 .47644 Mdot
.59374 .54257 Mdot
.5766 .43061 Mdot
.17094 .56885 Mdot
.71495 .70826 Mdot
.70418 .45738 Mdot
.53262 .77841 Mdot
.46444 .55019 Mdot
.34144 .59849 Mdot
.32603 .52822 Mdot
.41462 .56702 Mdot
.5926 .25902 Mdot
.37239 .67881 Mdot
.44967 .6613 Mdot
.61771 .19641 Mdot
.31701 .42995 Mdot
.50967 .45501 Mdot
.50505 .56045 Mdot
.45625 .33868 Mdot
.18073 .4817 Mdot
.31631 .52318 Mdot
.30736 .26963 Mdot
.71101 .71905 Mdot
.45157 .33187 Mdot
.57863 .36138 Mdot
.42817 .64199 Mdot
.22049 .69054 Mdot
.15629 .50905 Mdot
.6251 .78763 Mdot
.6244 .66546 Mdot
.53818 .13553 Mdot
.6306 .54612 Mdot
.23889 .33961 Mdot
.64126 .62062 Mdot
.91054 .48708 Mdot
.69201 .41395 Mdot
.49287 .19877 Mdot
.3017 .54666 Mdot
.53681 .44493 Mdot
.21587 .64168 Mdot
.31629 .6954 Mdot
.54896 .2567 Mdot
.53348 .71222 Mdot
.31462 .42512 Mdot
.22888 .67539 Mdot
.25876 .72365 Mdot
.23324 .68075 Mdot
.73733 .56228 Mdot
.30287 .73033 Mdot
.31344 .78 Mdot
.46936 .26083 Mdot
.5438 .53282 Mdot
.4163 .42987 Mdot
.28155 .33262 Mdot
.28025 .30267 Mdot
.59541 .22565 Mdot
.27193 .50744 Mdot
.48802 .75232 Mdot
.29193 .76629 Mdot
.17838 .47571 Mdot
.25648 .58128 Mdot
.1762 .55968 Mdot
.73028 .40768 Mdot
.29904 .30894 Mdot
.16282 .54406 Mdot
.56292 .73363 Mdot
.69303 .64121 Mdot
.32701 .79485 Mdot
.3952 .23921 Mdot
.65756 .51097 Mdot
.59251 .78575 Mdot
.26262 .31363 Mdot
.61857 .67339 Mdot
.65402 .50854 Mdot
.36693 .56277 Mdot
.44284 .75275 Mdot
.57915 .43121 Mdot
.54961 .76346 Mdot
.56744 .52238 Mdot
.32983 .29544 Mdot
.69192 .37801 Mdot
.3288 .26728 Mdot
.56539 .37321 Mdot
.55058 .53607 Mdot
.41085 .29437 Mdot
.36441 .22429 Mdot
.60619 .75884 Mdot
.27029 .70632 Mdot
.7133 .71494 Mdot
.78263 .65598 Mdot
.67199 .68011 Mdot
.41733 .62497 Mdot
.34752 .52292 Mdot
.20972 .63811 Mdot
.13694 .49352 Mdot
.16358 .55588 Mdot
.74113 .66598 Mdot
.6731 .352 Mdot
.69388 .54986 Mdot
.45596 .28538 Mdot
.54685 .439 Mdot
.58571 .59529 Mdot
.52335 .36869 Mdot
.69655 .61848 Mdot
.63079 .80511 Mdot
.55812 .61599 Mdot
.46505 .27217 Mdot
.27102 .56273 Mdot
.36176 .55361 Mdot
.2482 .66471 Mdot
.53291 .66345 Mdot
.748 .65764 Mdot
.34691 .25604 Mdot
.65778 .4311 Mdot
.72103 .46739 Mdot
.53865 .59255 Mdot
.34444 .52908 Mdot
.72128 .37702 Mdot
.55881 .57059 Mdot
.38161 .59763 Mdot
.68097 .35566 Mdot
.17211 .44873 Mdot
.23192 .34031 Mdot
.16163 .54038 Mdot
.37057 .23702 Mdot
.72954 .4497 Mdot
.45825 .35405 Mdot
.62672 .56358 Mdot
.66654 .64939 Mdot
.4783 .39049 Mdot
.37533 .22708 Mdot
.29782 .69877 Mdot
.49779 .59938 Mdot
.35695 .39889 Mdot
.18855 .45138 Mdot
.43686 .27186 Mdot
.46758 .35574 Mdot
.42035 .70352 Mdot
.47061 .65173 Mdot
.53941 .1904 Mdot
.55849 .77317 Mdot
.4406 .43852 Mdot
.63437 .66851 Mdot
.65593 .59917 Mdot
.52109 .64693 Mdot
.36263 .22421 Mdot
.66359 .23515 Mdot
.55075 .67088 Mdot
.49381 .53172 Mdot
.19206 .60752 Mdot
.52671 .50234 Mdot
.60966 .66469 Mdot
.47841 .78987 Mdot
.79369 .59566 Mdot
.50456 .74958 Mdot
.55672 .5308 Mdot
.59938 .52195 Mdot
.47003 .75915 Mdot
.52329 .71907 Mdot
.26316 .6494 Mdot
.18325 .61884 Mdot
.55489 .48155 Mdot
.54822 .75244 Mdot
.43896 .33446 Mdot
.59054 .45177 Mdot
.48972 .56209 Mdot
.40249 .28865 Mdot
.55759 .71668 Mdot
.20233 .5431 Mdot
.70416 .77314 Mdot
.2623 .48627 Mdot
.4861 .1946 Mdot
.45866 .28551 Mdot
.4128 .60303 Mdot
.30526 .66381 Mdot
.70901 .65228 Mdot
.39707 .49003 Mdot
.17962 .62656 Mdot
.65199 .73649 Mdot
.43501 .31181 Mdot
.65552 .48518 Mdot
.3333 .47805 Mdot
.41343 .52626 Mdot
.16563 .55276 Mdot
.46055 .73902 Mdot
.57301 .8596 Mdot
.42384 .21807 Mdot
.4348 .58228 Mdot
.31275 .71082 Mdot
.30154 .27659 Mdot
.47188 .61119 Mdot
.55897 .64649 Mdot
.57186 .37892 Mdot
.28159 .29617 Mdot
.51435 .78094 Mdot
.54558 .78527 Mdot
.66892 .67354 Mdot
.3113 .7751 Mdot
.44904 .55798 Mdot
.72613 .63172 Mdot
.73072 .39889 Mdot
.38478 .4344 Mdot
.69785 .725 Mdot
.66123 .66245 Mdot
.60503 .42685 Mdot
.36494 .55976 Mdot
.13469 .49638 Mdot
.4029 .41847 Mdot
.70294 .70944 Mdot
.557 .85782 Mdot
.62617 .84945 Mdot
.55197 .79462 Mdot
.20938 .67649 Mdot
.53724 .78391 Mdot
.60776 .66837 Mdot
.6543 .57632 Mdot
.51328 .47607 Mdot
.34156 .58811 Mdot
.16775 .59548 Mdot
.69574 .26732 Mdot
.65563 .63395 Mdot
.27398 .54544 Mdot
.16624 .5959 Mdot
.38176 .40779 Mdot
.51892 .18991 Mdot
.61463 .38529 Mdot
.36346 .20217 Mdot
.25234 .30522 Mdot
.428 .72815 Mdot
.38994 .19564 Mdot
.49907 .18045 Mdot
.51604 .25773 Mdot
.23652 .33803 Mdot
.23921 .46756 Mdot
.42835 .71163 Mdot
.35678 .25536 Mdot
.6216 .6521 Mdot
.47326 .14047 Mdot
.48892 .56165 Mdot
.56288 .55567 Mdot
.44492 .69811 Mdot
.60483 .64458 Mdot
.61299 .74013 Mdot
.52995 .52212 Mdot
.47816 .44168 Mdot
.28203 .69599 Mdot
.80623 .64179 Mdot
.50644 .80944 Mdot
.55178 .59883 Mdot
.26269 .7222 Mdot
.72055 .64795 Mdot
.48379 .38496 Mdot
.32574 .68722 Mdot
.44142 .27931 Mdot
.72602 .41589 Mdot
.37658 .49073 Mdot
.18602 .62416 Mdot
.72599 .41485 Mdot
.25215 .70651 Mdot
.20037 .36346 Mdot
.18167 .55623 Mdot
.30907 .52418 Mdot
.71886 .40989 Mdot
.29541 .29458 Mdot
.29634 .29609 Mdot
.31324 .76215 Mdot
.47282 .18851 Mdot
.48182 .40431 Mdot
.5439 .51009 Mdot
.4886 .52897 Mdot
.44037 .43204 Mdot
.29543 .28039 Mdot
.43878 .61616 Mdot
.35137 .29311 Mdot
.60114 .79528 Mdot
.36888 .226 Mdot
.30618 .69697 Mdot
.43799 .28914 Mdot
.59531 .39641 Mdot
.55063 .2855 Mdot
.62752 .40754 Mdot
.38202 .81994 Mdot
.69746 .67553 Mdot
.21987 .36978 Mdot
.78228 .64412 Mdot
.63867 .76112 Mdot
.44898 .1961 Mdot
.50114 .60481 Mdot
.25297 .47367 Mdot
.70942 .29275 Mdot
.37919 .26852 Mdot
.26583 .65984 Mdot
.6313 .65249 Mdot
.4152 .73595 Mdot
.17135 .58225 Mdot
.3326 .29688 Mdot
.44831 .85339 Mdot
.69661 .34094 Mdot
.37223 .67186 Mdot
.2217 .63149 Mdot
.77203 .68679 Mdot
.46854 .35137 Mdot
.25584 .72546 Mdot
.48525 .73046 Mdot
.19835 .65338 Mdot
.70315 .59811 Mdot
.62589 .31909 Mdot
.62632 .63593 Mdot
.45385 .31399 Mdot
.45641 .31784 Mdot
.18824 .41454 Mdot
.71844 .71239 Mdot
.67861 .7476 Mdot
.60095 .37245 Mdot
.66292 .36634 Mdot
.49929 .48638 Mdot
.55765 .73593 Mdot
.39262 .82289 Mdot
.33088 .51061 Mdot
.68301 .33214 Mdot
.32942 .25749 Mdot
.62827 .56127 Mdot
.56778 .56382 Mdot
.62054 .6375 Mdot
.46068 .78238 Mdot
.29599 .31723 Mdot
.30044 .76789 Mdot
.56656 .56889 Mdot
.54472 .42176 Mdot
.39351 .7006 Mdot
.59362 .5936 Mdot
.76482 .6257 Mdot
.56999 .68083 Mdot
.51484 .51265 Mdot
.45967 .39207 Mdot
.376 .23894 Mdot
.15168 .45477 Mdot
.28137 .74066 Mdot
.76939 .62241 Mdot
.45947 .33196 Mdot
.45689 .69506 Mdot
.3943 .27339 Mdot
.44035 .85288 Mdot
.37171 .18927 Mdot
.60256 .78182 Mdot
.36275 .23258 Mdot
.62627 .46751 Mdot
.50378 .19143 Mdot
.47338 .37192 Mdot
.22006 .62835 Mdot
.27833 .53739 Mdot
.44842 .6897 Mdot
.64602 .50055 Mdot
.42711 .33367 Mdot
.5824 .56628 Mdot
.4253 .70566 Mdot
.72151 .70766 Mdot
.44989 .85343 Mdot
.46629 .18222 Mdot
.39877 .69176 Mdot
.47828 .84514 Mdot
.49982 .63219 Mdot
.60345 .52331 Mdot
.73474 .53886 Mdot
.45276 .32882 Mdot
.68549 .42485 Mdot
.41254 .55281 Mdot
.48752 .43106 Mdot
.52034 .79044 Mdot
.66369 .46532 Mdot
.56586 .24606 Mdot
.52922 .70062 Mdot
.48711 .18268 Mdot
.51008 .63517 Mdot
.15892 .44339 Mdot
.56649 .72653 Mdot
.27821 .68666 Mdot
.48232 .80419 Mdot
.74727 .40367 Mdot
.78481 .65998 Mdot
.18077 .57187 Mdot
.31208 .3246 Mdot
.5283 .71399 Mdot
.53714 .67268 Mdot
.5183 .77431 Mdot
.68131 .53099 Mdot
.19555 .60625 Mdot
.31799 .26007 Mdot
.73533 .44558 Mdot
.46693 .68403 Mdot
.55451 .50925 Mdot
.5482 .59544 Mdot
.17193 .45962 Mdot
.69006 .41165 Mdot
.23594 .71106 Mdot
.43436 .6204 Mdot
.72951 .72736 Mdot
.5857 .60566 Mdot
.45088 .40163 Mdot
.47635 .35444 Mdot
.70934 .46747 Mdot
.3675 .40047 Mdot
.43723 .57825 Mdot
.51682 .65371 Mdot
.59121 .54882 Mdot
.58299 .30177 Mdot
.62116 .20148 Mdot
.62017 .58427 Mdot
.40343 .61321 Mdot
.2861 .28304 Mdot
.53125 .65884 Mdot
.69762 .34377 Mdot
.74583 .37379 Mdot
.33864 .41377 Mdot
.25554 .35959 Mdot
.36105 .80769 Mdot
.18616 .57942 Mdot
.50776 .72338 Mdot
.77315 .66029 Mdot
.57125 .33893 Mdot
.17478 .4441 Mdot
.49173 .77048 Mdot
.31477 .27064 Mdot
.40102 .64624 Mdot
.16288 .51733 Mdot
.31963 .71178 Mdot
.57609 .63395 Mdot
.35674 .24892 Mdot
.57407 .43689 Mdot
.35769 .23253 Mdot
.45394 .78292 Mdot
.501 .5115 Mdot
.36279 .20536 Mdot
.63748 .47204 Mdot
.26238 .60177 Mdot
.44662 .49974 Mdot
.58319 .60333 Mdot
.29083 .29169 Mdot
.52594 .69897 Mdot
.59968 .31295 Mdot
.28398 .56047 Mdot
.66854 .6435 Mdot
.18948 .61438 Mdot
.7249 .67217 Mdot
.33433 .25068 Mdot
.48462 .53242 Mdot
.43492 .25181 Mdot
.4389 .6097 Mdot
.33372 .33266 Mdot
.42687 .46363 Mdot
.40917 .64538 Mdot
.53997 .3768 Mdot
.19392 .42365 Mdot
.45227 .5111 Mdot
.21815 .65743 Mdot
.18351 .4701 Mdot
.49679 .77657 Mdot
.5835 .51669 Mdot
.47005 .70403 Mdot
.23636 .706 Mdot
.26467 .33844 Mdot
.60937 .63944 Mdot
.25651 .30192 Mdot
.53921 .18779 Mdot
.49192 .84875 Mdot
.68469 .70582 Mdot
.55523 .565 Mdot
.21697 .35364 Mdot
.65064 .74143 Mdot
.51203 .18116 Mdot
.26248 .65458 Mdot
.46735 .73709 Mdot
.26043 .73567 Mdot
.23971 .49034 Mdot
.66587 .75463 Mdot
.23893 .64959 Mdot
.536 .73423 Mdot
.25652 .34629 Mdot
.37417 .39876 Mdot
.63649 .3923 Mdot
.52944 .45395 Mdot
.39831 .19098 Mdot
.54815 .69125 Mdot
.30922 .27116 Mdot
.31508 .27257 Mdot
.46124 .20224 Mdot
.72456 .45095 Mdot
.49316 .84846 Mdot
.33128 .73943 Mdot
.40071 .52415 Mdot
.50819 .72618 Mdot
.57001 .24828 Mdot
.42538 .22734 Mdot
.34841 .5047 Mdot
.38965 .34614 Mdot
.40779 .65681 Mdot
.17349 .61301 Mdot
.59346 .4322 Mdot
.73301 .61402 Mdot
.46614 .69619 Mdot
.6077 .64359 Mdot
.4596 .617 Mdot
.71687 .72391 Mdot
.2962 .28881 Mdot
.55113 .6755 Mdot
.57307 .65492 Mdot
.65559 .7588 Mdot
.36473 .26083 Mdot
.53544 .3341 Mdot
.66932 .55839 Mdot
.36813 .59357 Mdot
.35353 .78515 Mdot
.66607 .7442 Mdot
.51219 .61087 Mdot
.58439 .76807 Mdot
.50794 .5069 Mdot
.74495 .62446 Mdot
.71587 .71485 Mdot
.46468 .63884 Mdot
.20023 .56014 Mdot
.53456 .74776 Mdot
.72155 .39601 Mdot
.40577 .22662 Mdot
.56613 .76054 Mdot
.30219 .27897 Mdot
.35141 .40844 Mdot
.22701 .66054 Mdot
.43754 .31356 Mdot
.607 .30887 Mdot
.40058 .50025 Mdot
.34633 .56436 Mdot
.16498 .55244 Mdot
.58248 .78667 Mdot
.30922 .54098 Mdot
.49168 .62259 Mdot
.23275 .33465 Mdot
.71198 .3721 Mdot
.68622 .35611 Mdot
.50126 .22424 Mdot
.45603 .41303 Mdot
.54284 .43703 Mdot
.65961 .52953 Mdot
.37256 .4035 Mdot
.52533 .32436 Mdot
.50941 .51932 Mdot
.37144 .59667 Mdot
.23795 .34683 Mdot
.37652 .81433 Mdot
.48331 .56786 Mdot
.24498 .30895 Mdot
.31038 .55545 Mdot
.48503 .74202 Mdot
.47599 .18067 Mdot
.28537 .5206 Mdot
.30754 .43555 Mdot
.60075 .31096 Mdot
.48971 .63166 Mdot
.36996 .80661 Mdot
.41081 .56236 Mdot
.61599 .28334 Mdot
.60041 .35903 Mdot
.48751 .55136 Mdot
.79307 .41612 Mdot
.64513 .63965 Mdot
.21785 .3492 Mdot
.34807 .25504 Mdot
.71272 .61071 Mdot
.5281 .78279 Mdot
.28869 .52646 Mdot
.2257 .66197 Mdot
.55242 .39206 Mdot
.18307 .5868 Mdot
.74521 .58047 Mdot
.38915 .61224 Mdot
.18748 .46273 Mdot
.35889 .30782 Mdot
.33892 .33077 Mdot
.41528 .6836 Mdot
.26874 .39548 Mdot
.51855 .56277 Mdot
.6517 .23426 Mdot
.45372 .14814 Mdot
.4174 .84017 Mdot
.72337 .73056 Mdot
.43638 .44951 Mdot
.38875 .27378 Mdot
.53129 .75477 Mdot
.48645 .39454 Mdot
.58826 .36989 Mdot
.71745 .36585 Mdot
.66324 .49271 Mdot
.79856 .64232 Mdot
.17919 .62348 Mdot
.39949 .49991 Mdot
.51332 .3489 Mdot
.55778 .22132 Mdot
.69697 .40916 Mdot
.25683 .56021 Mdot
.35735 .80358 Mdot
.67291 .55946 Mdot
.74527 .53586 Mdot
.64938 .5319 Mdot
.19037 .41382 Mdot
.72165 .51578 Mdot
.67789 .53738 Mdot
.15819 .44314 Mdot
.62296 .78616 Mdot
.42909 .75869 Mdot
.79952 .63415 Mdot
.18941 .4401 Mdot
.40771 .63823 Mdot
.71762 .37795 Mdot
.20194 .64638 Mdot
.47508 .3559 Mdot
.71385 .44742 Mdot
.22578 .44871 Mdot
.3575 .24522 Mdot
.41707 .22174 Mdot
.7302 .59352 Mdot
.28333 .54475 Mdot
.61639 .18288 Mdot
.74914 .40323 Mdot
.74178 .74899 Mdot
.18702 .57416 Mdot
.37513 .78351 Mdot
.55128 .78944 Mdot
.60247 .37993 Mdot
.22237 .65234 Mdot
.31312 .27847 Mdot
.29428 .53973 Mdot
.67823 .25689 Mdot
.38179 .30115 Mdot
.41924 .27654 Mdot
.74575 .61817 Mdot
.16931 .54043 Mdot
.73355 .43862 Mdot
.24441 .44633 Mdot
.34336 .25131 Mdot
.32384 .56062 Mdot
.3319 .33657 Mdot
.34398 .7778 Mdot
.253 .35846 Mdot
.38389 .22223 Mdot
.66994 .49702 Mdot
.57088 .32668 Mdot
.36664 .8003 Mdot
.45885 .59349 Mdot
.40046 .65345 Mdot
.56076 .85803 Mdot
.2174 .68388 Mdot
.28014 .51613 Mdot
.36626 .4179 Mdot
.17432 .40781 Mdot
.663 .33867 Mdot
.23541 .3538 Mdot
.6051 .80894 Mdot
.4284 .21244 Mdot
.45394 .52473 Mdot
.36229 .49501 Mdot
.47318 .24821 Mdot
.46483 .7495 Mdot
.29274 .54403 Mdot
.70473 .49739 Mdot
.37753 .22749 Mdot
.4075 .61297 Mdot
.70326 .77367 Mdot
.45479 .7807 Mdot
.47256 .67721 Mdot
.1926 .63596 Mdot
.23075 .52521 Mdot
.42427 .60484 Mdot
.22022 .63617 Mdot
.54745 .40233 Mdot
.52727 .32526 Mdot
.43827 .60701 Mdot
.45898 .35201 Mdot
.40032 .18805 Mdot
.47619 .84701 Mdot
.35047 .59485 Mdot
.2428 .71893 Mdot
.15493 .51702 Mdot
.47048 .67936 Mdot
.26407 .52412 Mdot
.47071 .33381 Mdot
.5476 .72006 Mdot
.66621 .50651 Mdot
.71625 .46803 Mdot
.56674 .19716 Mdot
.61531 .20019 Mdot
.34813 .48099 Mdot
.74606 .58 Mdot
.17323 .58306 Mdot
.55813 .19681 Mdot
.17584 .59438 Mdot
.41615 .63588 Mdot
.36342 .52564 Mdot
.63153 .84803 Mdot
.60673 .66623 Mdot
.30341 .47869 Mdot
.40484 .40082 Mdot
.41919 .41235 Mdot
.39063 .4904 Mdot
.69916 .52743 Mdot
.45338 .27916 Mdot
.41819 .21007 Mdot
.20196 .64123 Mdot
.46831 .66686 Mdot
.47406 .34941 Mdot
.65891 .62541 Mdot
.41024 .33444 Mdot
.30116 .38152 Mdot
.66261 .61384 Mdot
.42185 .2003 Mdot
.79106 .41814 Mdot
.56161 .35683 Mdot
.57184 .58579 Mdot
.46992 .43367 Mdot
.5493 .62867 Mdot
.44741 .18841 Mdot
.66841 .52945 Mdot
.51648 .25966 Mdot
.33903 .24866 Mdot
.41203 .70643 Mdot
.73198 .63115 Mdot
.53853 .14152 Mdot
.47052 .35887 Mdot
.73065 .55111 Mdot
.26495 .48516 Mdot
.45521 .76978 Mdot
.19817 .58066 Mdot
.53772 .32518 Mdot
.5109 .55432 Mdot
.39299 .69145 Mdot
.21454 .64064 Mdot
.66661 .6067 Mdot
.14646 .46852 Mdot
.2664 .47532 Mdot
.25913 .56663 Mdot
.33424 .75531 Mdot
.56426 .53489 Mdot
.27143 .66445 Mdot
.43101 .48691 Mdot
.53029 .41437 Mdot
.78126 .40447 Mdot
.55863 .58571 Mdot
.49124 .5563 Mdot
.55445 .70435 Mdot
.47956 .19596 Mdot
.21204 .55112 Mdot
.39293 .47527 Mdot
.56243 .23736 Mdot
.44929 .34295 Mdot
.61608 .32856 Mdot
.63115 .32909 Mdot
.68882 .64125 Mdot
.44357 .19092 Mdot
.42365 .21877 Mdot
.24445 .64985 Mdot
.23305 .68902 Mdot
.44658 .50461 Mdot
.1866 .56693 Mdot
.58289 .41085 Mdot
.62066 .73822 Mdot
.25744 .35669 Mdot
.47117 .84587 Mdot
.44385 .57359 Mdot
.43479 .43384 Mdot
.15733 .48814 Mdot
.17451 .56215 Mdot
.65521 .63738 Mdot
.63046 .65767 Mdot
.42479 .15844 Mdot
.4603 .31866 Mdot
.80244 .64195 Mdot
.68104 .49483 Mdot
.16415 .46799 Mdot
.51586 .53274 Mdot
.2761 .50402 Mdot
.42444 .65448 Mdot
.3121 .43312 Mdot
.67 .41581 Mdot
.47579 .78778 Mdot
.41507 .6892 Mdot
.28141 .38673 Mdot
.40422 .52637 Mdot
.62251 .51647 Mdot
.45652 .70064 Mdot
.42363 .84221 Mdot
.70163 .41373 Mdot
.54416 .41785 Mdot
.66913 .79318 Mdot
.78398 .40793 Mdot
.53064 .18372 Mdot
.3027 .75425 Mdot
.6607 .64859 Mdot
.51185 .51707 Mdot
.83284 .51585 Mdot
.47538 .72844 Mdot
.51398 .7245 Mdot
.61997 .57594 Mdot
.44065 .2544 Mdot
.70112 .71497 Mdot
.51863 .85474 Mdot
.16227 .51248 Mdot
.34702 .40989 Mdot
.80782 .68826 Mdot
.33819 .25314 Mdot
.52493 .38003 Mdot
.7083 .70782 Mdot
.18474 .61908 Mdot
.65228 .48658 Mdot
.1977 .37208 Mdot
.55717 .75744 Mdot
.52461 .74606 Mdot
.43426 .2676 Mdot
.77357 .64957 Mdot
.55507 .51368 Mdot
.74429 .74526 Mdot
.64466 .67242 Mdot
.41662 .28252 Mdot
.57647 .78608 Mdot
.50737 .74445 Mdot
.44001 .5716 Mdot
.5733 .71312 Mdot
.3496 .5541 Mdot
.54081 .64235 Mdot
.57409 .66393 Mdot
.54013 .34093 Mdot
.60358 .55413 Mdot
.60321 .66081 Mdot
.63211 .5675 Mdot
.42454 .72513 Mdot
.40763 .17229 Mdot
.66878 .33199 Mdot
.69378 .38113 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`2Rooooo`;o0000YOooool001cooooo00?o0000ooooooooool0X_ooool2o`0000Oooooo0_l0
002Looooo`007?ooool00ol0003oooooooooo`2Fooooo`;o00002_ooool2o`0000Oooooo0_l0002L
ooooo`007?ooool00ol0003oooooooooo`2Fooooo`;o00002_ooool2o`0000Oooooo0_l0002Loooo
o`007?ooool00ol0003oooooooooo`2]ooooo`;o0000V_ooool001cooooo00?o0000ooooooooool0
SOooool2o`000003ooooool0003o000001_ooooo0_l0002Jooooo`007?ooool2o`0008[ooooo0_l0
0002ooooo`;o000000?oooooo`000?l00000]oooool001cooooo00?o0000ooooooooool0R?ooool3
o`000;kooooo000Looooo`03o`000?oooooooooo08Kooooo1?l0002oooooo`007?ooool00ol0003o
ooooooooo`26ooooo`;o0000`Oooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`21ooooo`;o0000a_ooool001cooooo00?o0000ooooooooool0O_ooool5
o`000<Kooooo000Looooo`03o`000?oooooooooo07kooooo1Ol00036ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo09Oooooo0_l00005ooooo`;o0000
0oooool2o`000:Cooooo000Looooo`03o`000?oooooooooo07Wooooo1?l0000Gooooo`;o000000Co
ooooo`000?l0003ooooo0_l00002ooooo`;o00000oooool2o`0000Cooooo0_l0000Iooooo`;o0000
Poooool001cooooo00?o0000ooooooooool0NOooool4o`0001Oooooo0_l00004ooooo`Co00002ooo
ool2o`0001Wooooo0_l00023ooooo`007?ooool00ol0003oooooooooo`1dooooo`Co00001_ooool2
o`0000kooooo0_l00006ooooo`;o00001?ooool2o`0000Oooooo0_l00004ooooo`;o0000W?ooool0
0006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oo
oooooooo06oooooo1?l000000ooooooo0000o`000002o`0000Kooooo0_l0000<ooooo`Co00001_oo
ool2o`0000Sooooo0_l00003ooooo`;o00001?ooool2o`0001Kooooo0_l00024ooooo`0000Kooooo
ogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Ko
oooo00?o0000ooooooooool0Koooool7o`0000Gooooo0_l000001?oooooo0000o`000?ooool2o`00
00Wooooo1?l00008ooooo`Co00001?ooool2o`00013ooooo0_l0000?ooooo`Co0000P_ooool00003
ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03
o`000?oooooooooo07?ooooo0ol00005ooooo`;o000000Coooooo`000?l0003ooooo0_l0000;oooo
o`?o00001oooool6o`0001Cooooo1?l0000=ooooo`Go0000POooool00003ooooool0003ooooo00;o
oooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06ooooo`?o0000Koooool2o`000004
ooooool0003o0000ooooo`;o00003_ooool2o`0000Sooooo0_l000000ooooooo0000o`000008oooo
o`;o00002Oooool4o`0000;ooooo0ol00004ooooo`;o00003_ooool4o`00087ooooo00000ooooooo
0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003o
ooooooooo`1_ooooo`;o000000?oooooo`000?l000001ol0000:ooooo`;o00002oooool2o`0000Ko
oooo1?l00005ooooo`;o00000_ooool4o`0000;ooooo0ol0000Dooooo`Co0000POooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo07;ooooo1?l000000ooooooo0000o`000002o`0001kooooo0ol00006ooooo`?o0000
Y?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So410@
00Kooooo00?o0000ooooooooool0Moooool4o`0000Wooooo0_l00005ooooo`;o00003?ooool2o`00
00Oooooo0_l0002Uooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1fooooo`Co00002Oooool3o`000003ooooool0
003o000000;ooooo0_l0002looooo`007?ooool00ol0003oooooooooo`1fooooo`;o00002oooool6
o`0001Sooooo0_l0000Tooooo`;o00000_ooool4o`0007[ooooo000Looooo`03o`000?oooooooooo
07Kooooo0ol0000;ooooo`Co00006Oooool2o`000003ooooool0003o000000_ooooo0_l00002oooo
o`;o00004?ooool2o`0000;ooooo1?l0001jooooo`007?ooool00ol0003oooooooooo`1booooo`?o
000000?oooooo`000?l000000ol00009ooooo`Co00005oooool2o`0000?ooooo0_l0000:ooooo`Oo
000000?oooooo`000?l000004Oooool2o`0007cooooo000Looooo`03o`000?oooooooooo077ooooo
2_l00005ooooo`;o00000_ooool4o`0001Oooooo0_l00002ooooo`;o00001Oooool3o`0000?ooooo
1_l00002ooooo`;o00001?ooool2o`0000kooooo0_l0001iooooo`007?ooool00ol0003ooooooooo
o`1aooooo`;o000000?oooooo`000?l000000ol00007ooooo`;o00000oooool5o`0000gooooo0_l0
0009ooooo`?o00001Oooool3o`0000?ooooo0ol00004ooooo`?o00001?ooool3o`0000gooooo0_l0
001iooooo`007?ooool00ol0003oooooooooo`1_ooooo`Go00002Oooool2o`0000Kooooo0_l00000
0ooooooo0000o`00000=ooooo`;o00002Oooool2o`0000Kooooo0_l00007ooooo`So00001?ooool2
o`0008Sooooo000Looooo`03o`000?oooooooooo06kooooo1_l00009ooooo`;o00001Oooool3o`00
00oooooo0_l0000=ooooo`;o00000oooool2o`000003ooooool0003o000000Cooooo1?l00002oooo
o`;o00005Oooool2o`0000;ooooo0_l0001cooooo`007?ooool00ol0003oooooooooo`1]ooooo`?o
00001Oooool3o`0000Gooooo1_l000000ooooooo0000o`00000@ooooo`;o00001oooool2o`0000Co
oooo0_l00006ooooo`;o00000oooool3o`0000Gooooo0ol0000Cooooo`;o000000Coooooo`000?l0
003o0000Loooool001cooooo00?o0000ooooooooool0Joooool5o`0000Gooooo0ol00005ooooo`Ko
00004_ooool3o`0000Oooooo0_l0000;ooooo`;o00000oooool4o`0000Gooooo0ol0000Fooooo`;o
0000M?ooool001cooooo00?o0000ooooooooool0Joooool2o`000003ooooool0003o000000;o0000
0oooool2o`0000Oooooo0_l0000Eooooo`?o00001oooool2o`0000Gooooo0_l00004ooooo`go0000
0oooool2o`0008_ooooo000Looooo`03o`000?oooooooooo06[ooooo0_l00004ooooo`;o00009?oo
ool2o`0000Oooooo0_l00005ooooo`;o00001Oooool>o`000004ooooool0003o0000o`0001Wooooo
0_l0001_ooooo`007?ooool2o`0006Sooooo1ol00002ooooo`;o00006?ooool2o`0000[ooooo0_l0
0007ooooo`;o00003?oooolCo`0000Gooooo0_l0000Aooooo`;o0000Koooool001cooooo00?o0000
ooooooooool0Ioooool;o`0001Sooooo0ol0000Poooooa?o00001Oooool2o`0000[ooooo0_l0001f
ooooo`007?ooool00ol0003oooooooooo`1Wooooo`;o000000?oooooo`000?l000001_l0000Ioooo
o`;o00005oooool3o`0000Kooooo4ol000000ooooooo0000o`00000>ooooo`;o00001_ooool2o`00
06kooooo000Looooo`03o`000?oooooooooo06Cooooo0_l000000ooooooo0000o`000004ooooo`;o
00001?ooool2o`0000gooooo0_l0000@ooooo`?o00003Oooool3o`0000Sooooo4Ol000000ooooooo
0000o`00000Fooooo`;o0000K_ooool001cooooo00?o0000ooooooooool0H_ooool4o`0000gooooo
0_l000000ooooooo0000o`000004ooooo`;o00001?ooool2o`00013ooooo0ol0000=ooooo`;o0000
2OoooolCo`0001Oooooo0_l0001^ooooo`007?ooool00ol0003oooooooooo`1Rooooo`;o00000ooo
ool2o`0000gooooo0_l00004ooooo`;o00002oooool2o`0000Sooooo0ol00009ooooo`;o00003_oo
oolEo`0001[ooooo0_l0001Yooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o000000?ooooo
o`000?l000000_ooool2o`0000gooooo0ol00002ooooo`;o00003?ooool2o`0000Oooooo0ol0000:
ooooo`;o00003_oooolAo`0000;ooooo0_l0000Jooooo`;o0000JOooool001cooooo00?o0000oooo
ooooool0H?ooool5o`00017ooooo0ol00002ooooo`Co00002oooool2o`0000Gooooo1?l0000?oooo
o`;o00002_oooolCo`0008Kooooo000Looooo`03o`000?oooooooooo05kooooo0_l000000ooooooo
0000o`000002o`0001Kooooo1?l00003ooooo`Co00001?ooool2o`0000;ooooo1ol0000?ooooo`?o
00002OoooolCo`0001Oooooo0_l0001]ooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o0000
0oooool2o`0000;ooooo0_l0000Nooooo`Co00001Oooool9o`0000_ooooo0_l00004ooooo`;o0000
2ooooolBo`0001Kooooo0_l0001]ooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o000000?o
ooooo`000?l000000_l00002ooooo`;o00005oooool3o`0000Kooooo0_l00005ooooo`Oo000000?o
ooooo`000?l000002_ooool2o`0000Cooooo0_l00009oooooaCo0000QOooool001cooooo00?o0000
ooooooooool0FOooool2o`000003ooooool0003o000000gooooo0_l0000;ooooo`;o000000?ooooo
o`000?l000001Ol00002ooooo`;o00001_ooool2o`0000;ooooo1Ol0000@ooooo`;o00002?oooolD
o`000003ooooool0003o000001Oooooo0_l0001Zooooo`007?ooool00ol0003oooooooooo`1Loooo
o`;o00001Oooool2o`0000Kooooo0_l0000:ooooo`?o00001?ooool5o`0000Sooooo0ol00002oooo
o`?o00007?oooolDo`000003ooooool0003o000000;o00005Oooool2o`0006[ooooo000Looooo`03
o`000?oooooooooo05_ooooo0ol00005ooooo`;o00004Oooool3o`0000Kooooo1_l00006ooooo`?o
00005oooool2o`0000_ooooo2_l000000ooooooo0000o`000004o`0000?ooooo0_l00021ooooo`00
7?ooool00ol0003oooooooooo`1Kooooo`?o00002Oooool2o`0000;ooooo0_l000000ooooooo0000
o`000005ooooo`?o00002_ooool6o`0000?ooooo0_l00003ooooo`;o00004oooool2o`0000_ooooo
3ol0000Rooooo`;o0000I?ooool001cooooo00?o0000ooooooooool0F?ooool2o`0000;ooooo0ol0
0008ooooo`?o000000Coooooo`000?l0003ooooo0_l00005ooooo`?o00002_ooool;o`0000?ooooo
0_l0000<ooooo`;o00004_ooool@o`00027ooooo0_l0001Tooooo`007?ooool2o`00057ooooo0_l0
0006ooooo`;o00000oooool4o`0000Oooooo0_l00007ooooo`?o000000?oooooo`000?l000000ol0
000>ooooo`Co00001?ooool2o`000003ooooool0003o000000Wooooo0_l0000Cooooo`oo0000Qooo
ool001cooooo00?o0000ooooooooool0D?ooool2o`0000Gooooo0_l00006ooooo`;o00002_ooool3
o`000003ooooool0003o000000?o00001?ooool2o`0000kooooo0ol00005ooooo`;o000000?ooooo
o`000?l000002Oooool2o`0000Oooooo0_l0000:ooooo`oo00009?ooool2o`00067ooooo000Loooo
o`03o`000?oooooooooo04kooooo1?l00005ooooo`;o00003oooool2o`000005ooooool0003o0000
o`000?ooool01Ol000000ooooooo0000o`00000Booooo`;o00001Oooool2o`0001Gooooo0_l0000:
ooooo`;o00000_ooool9o`0002Kooooo0_l0001Qooooo`007?ooool00ol0003oooooooooo`1<oooo
o`Co00002Oooool2o`0000;ooooo0_l00007ooooo`Co00001oooool2o`0000;ooooo0_l0000Ioooo
o`;o00003?ooool3o`0000Oooooo0_l00008ooooo`;o000000?oooooo`000?l000001ol00003oooo
o`;o0000Q_ooool001cooooo00?o0000ooooooooool0Boooool3o`0000Cooooo0_l00005ooooo`;o
00000_ooool2o`0000;ooooo0_l00003ooooo`?o00000_ooool2o`00013ooooo0_l0000;ooooo`;o
00001?ooool2o`0000cooooo1Ol00005ooooo`;o00002?ooool2o`000003ooooool0003o000000Oo
000000?oooooo`000?l000000_l000000ooooooo0000o`000023ooooo`007?ooool00ol0003ooooo
ooooo`1;ooooo`;o00001Oooool2o`0000cooooo0ol00008ooooo`;o00001_ooool2o`000004oooo
ool0003o0000o`0000Cooooo0_l0000;ooooo`;o00001?ooool2o`0000kooooo0ol0000>ooooo`;o
00001?ooool;o`0000;ooooo0_l00023ooooo`007?ooool00ol0003oooooooooo`1Looooo`;o0000
0_ooool2o`0000gooooo2_l00004ooooo`;o00000_ooool3o`0000Cooooo0_l00007ooooo`?o0000
3Oooool2o`0000Oooooo0_l00004ooooo`Co00001Oooool2o`000005ooooool0003o0000o`000?oo
ool00_l00006ooooo`;o0000Ooooool001cooooo00?o0000ooooooooool0G?ooool2o`0000Cooooo
0_l00007ooooo`?o000000?oooooo`000?l000000ol000000ooooooo0000o`000004ooooo`Co0000
0_ooool3o`000004ooooool0003o0000ooooo`;o00001oooool3o`0000gooooo0_l00006ooooo`?o
00001?ooool4o`0000Sooooo0_l00002ooooo`;o00001_ooool2o`0007oooooo000Looooo`03o`00
0?oooooooooo05Oooooo0_l00003ooooo`;o00001?ooool2o`0000?ooooo1ol00004ooooo`;o0000
1oooool4o`0000Kooooo1_l0000Looooo`Ko00001?ooool2o`0000Gooooo0_l00006ooooo`;o0000
Qoooool001cooooo00?o0000ooooooooool0Eoooool4o`000004ooooool0003o0000ooooo`Oo0000
00?oooooo`000?l000000_l000000ooooooo0000o`000002ooooo`Co00001?ooool5o`0000[ooooo
1?l000001?oooooo0000o`000?ooool2o`0001Kooooo1ol00003ooooo`;o00000oooool6o`0000Co
oooo1_l00003ooooo`;o0000O_ooool001cooooo00?o0000ooooooooool0E?ooool2o`0000?ooooo
3_l00003ooooo`;o00000_ooool5o`0000Gooooo1Ol00002ooooo`Co00002Oooool2o`000003oooo
ool0003o000000;o00004?ooool2o`0000Kooooo0ol00008ooooo`?o000000?oooooo`000?l00000
1?ooool6o`0000?ooooo0_l0000:ooooo`;o00000oooool2o`0006gooooo000Looooo`03o`000?oo
oooooooo04Sooooo0_l0000:ooooo`;o00000_ooool2o`000003ooooool0003o000000oo000000?o
ooooo`000?l000000ol00008ooooo`;o00000oooool5o`0000;ooooo0ol00002ooooo`;o00000_oo
ool4o`0000;ooooo0_l0000;ooooo`?o00001Oooool2o`0001Kooooo0_l0000Aooooo`;o00000ooo
ool2o`0006gooooo000Looooo`03o`000?oooooooooo04Sooooo0ol00007ooooo`;o00001?ooool2
o`0000Oooooo0_l00002ooooo`[o00004oooool2o`0000;ooooo1ol00008ooooo`;o00002oooool3
o`0000Gooooo0_l00003ooooo`;o0000V?ooool001cooooo00?o0000ooooooooool0B?ooool4o`00
00Kooooo0_l0000Aooooo`;o000000?oooooo`000?l000001?l0000Hooooo`Go00001Oooool2o`00
01[ooooo0_l000000ooooooo0000o`000005ooooo`;o00007?ooool2o`0000;ooooo0ol00003oooo
o`;o0000JOooool001cooooo00?o0000ooooooooool0B?ooool4o`0000cooooo0_l0000>ooooo`;o
00000_ooool2o`0001Sooooo3?l0000Jooooo`;o000000Coooooo`000?l0003ooooo0_l00002oooo
o`;o00007?ooool2o`0000;ooooo0ol00003ooooo`?o0000J?ooool001cooooo00?o0000oooooooo
ool0B_ooool2o`0000Cooooo1?l00004ooooo`;o00004_ooool2o`0000?ooooo0ol00006ooooo`?o
00000_ooool2o`0000Cooooo2ol0000Dooooo`;o00002Oooool2o`000004ooooool0003o0000oooo
o`;o0000:?ooool2o`0006Sooooo000Looooo`;o0000A?ooool2o`0000Cooooo0ol00004ooooo`Co
000000?oooooo`000?l000006_ooool3o`0000?ooooo0_l000001?oooooo0000o`000?l00002oooo
o`Co00000_ooool;o`0000Kooooo1?l00009ooooo`?o00003oooool3o`0002Kooooo0_l0001Yoooo
o`007?ooool00ol0003oooooooooo`12ooooo`?o00000oooool3o`0000Gooooo0_l00003ooooo`;o
00008?ooool2o`0000Kooooo1Ol00003ooooo`Oo00000oooool2o`000003ooooool0003o000000Co
00002Oooool2o`0000kooooo1Ol0000Oooooo`;o00001Oooool2o`0006Wooooo000Looooo`03o`00
0?oooooooooo04;ooooo0ol00003ooooo`?o00001Oooool4o`0002kooooo0_l00003ooooo`Go0000
1Oooool2o`000004ooooool0003o0000ooooo`;o00003Oooool2o`0000Cooooo0_l00005ooooo`Oo
00000_ooool2o`000003ooooool0003o000000;ooooo0_l0000Booooo`Ko0000K?ooool001cooooo
00?o0000ooooooooool0C_ooool6o`0003Cooooo1?l00002ooooo`Co00000_ooool5o`0000gooooo
0_l00004ooooo`;o00001?ooool3o`0000;ooooo0ol000001Ooooooo0000o`000?l0003ooooo00;o
00000_ooool2o`0000cooooo1?l00004ooooo`Go0000Joooool001cooooo00?o0000ooooooooool0
AOooool2o`0000Oooooo1Ol0000cooooo`;o00000_ooool8o`0000?ooooo0_l0000Kooooo`;o0000
1?ooool5o`0000;ooooo0_l0000@ooooo`Ko00001Oooool2o`0006_ooooo000Looooo`03o`000?oo
oooooooo03gooooo0_l00006ooooo`Co00001Oooool2o`0003Kooooo0_l00002ooooo`Ko00000_oo
ool2o`0002Cooooo1Ol0000Eooooo`So00002oooool2o`0006;ooooo000Looooo`03o`000?oooooo
oooo03gooooo0_l00007ooooo`?o00001Oooool2o`0003Kooooo0_l00004ooooo`Co00000_ooool2
o`0001;ooooo0_l0000Cooooo`;o00003Oooool2o`0000Kooooo2ol00008ooooo`;o0000H_ooool0
01cooooo00?o0000ooooooooool0??ooool3o`0000Gooooo1?l00012ooooo`Ko00000_ooool2o`00
00;ooooo0_l0000>ooooo`;o00000_ooool2o`0000oooooo0_l00002ooooo`;o000000?oooooo`00
0?l000001?ooool4o`0000;ooooo2_l000000ooooooo0000o`000002o`0000Gooooo1?l0001Soooo
o`007?ooool00ol0003oooooooooo`0looooo`?o00001Oooool2o`0004Cooooo1_l00003ooooo`;o
000000?oooooo`000?l000004_ooool2o`0000Sooooo0_l00005ooooo`;o00000_ooool2o`000003
ooooool0003o000000Cooooo0_l00003oooooaWo00002?ooool2o`0005Wooooo000Looooo`03o`00
0?oooooooooo04Cooooo0_l00016ooooo`Co00000oooool2o`0001Oooooo0_l00006ooooo`;o0000
2Oooool2o`0000Oooooo0_l00002oooooaOo00000_ooool3o`0000Kooooo0_l0001Iooooo`007?oo
ool00ol0003oooooooooo`14ooooo`;o000000?oooooo`000?l000000_l0000Cooooo`;o00000_oo
ool2o`000003ooooool0003o000000;o00001_ooool4o`0000Kooooo0_l0000Aooooo`Co00005ooo
ool2o`0000?ooooo0_l00008ooooo`;o00002?ooool2o`0000[ooooo5_l00002ooooo`Co0000HOoo
ool001cooooo00?o0000ooooooooool0>?ooool2o`0000Sooooo0_l00003ooooo`Co00003oooool2
o`000003ooooool0003o000000Go000000?oooooo`000?l000000_l00006ooooo`Wo000000?ooooo
o`000?l000005Oooool4o`0001?ooooo0_l00003ooooo`?o00001oooool2o`0000Sooooo0_l00005
ooooo`;o000000?oooooo`000?l000005?l00004ooooo`?o0000H_ooool001cooooo00?o0000oooo
ooooool0=oooool4o`0000Oooooo0_l0000Dooooo`Co000000Coooooo`000?l0003ooooo0ol0000?
ooooo`Ko00005_ooool6o`0000Gooooo0_l0000Booooo`;o00004oooool7o`000003ooooool0003o
000001?o00000_ooool6o`0006;ooooo000Looooo`03o`000?oooooooooo03Oooooo1?l00005oooo
o`;o00005_ooool2o`0001cooooo0_l0000Fooooo`Ko00000oooool4o`0002Oooooo1_l000000ooo
oooo0000o`00000Do`000003ooooool0003o000000Co0000Hoooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooo
oooo043ooooo0_l0000Iooooo`;o0000=Oooool2o`0000?ooooo0ol00002ooooo`;o00004_ooool2
o`00017ooooo0_l00004oooooaGo000000Coooooo`000?l0003o00000_ooool2o`0006?ooooo0000
1_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0@?ooool2o`0001;ooooo0_l00003ooooo`Co00003Oooool6o`000003oooo
ool0003o000000?o00002Oooool2o`00017ooooo1?l000001?oooooo0000o`000?ooool4o`0001;o
oooo0_l0000<ooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000001;o
000000?oooooo`000?l000000ol000000ooooooo0000o`000002o`00063ooooo00000ooooooo410@
ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006ooooo`03o`000?oooooooooo03_ooooo
0_l00002ooooo`;o00004oooool2o`0000?ooooo0_l0000>oooooa3o00001_ooool2o`0000kooooo
1ol000001?oooooo0000o`000?ooool2o`0002;ooooo0_l000000ooooooo0000o`000002oooooa[o
000000?oooooo`000?l000000_l000000ooooooo0000o`000002o`000003ooooool0003o000005go
oooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo
00001oooool3o`0003_ooooo0_l00002ooooo`;o00009_ooool<o`000003ooooool0003o000000Go
00001Oooool2o`0000gooooo0ol00002ooooo`;o000000?oooooo`000?l000005Oooool2o`0001Go
oooo0_l000000ooooooo0000o`00000Eo`000004ooooool0003o0000o`0000;ooooo1?l000000ooo
oooo0000o`000004ooooo`;o0000Eoooool00003ooooool0003ooooo00;ooooo00?o0000oooooooo
ool02Oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo053ooooo0_l00003oooo
o`;o00003oooool:o`000004ooooool0003o0000ooooo`?o00000_ooool2o`000003ooooool0003o
000000;ooooo0_l0000=ooooo`;o00000oooool2o`0000?ooooo0_l0000Cooooo`;o00005?ooool3
o`000003ooooool0003o000001Wo00003?ooool3o`0000Sooooo0_l0001=ooooo`0000?ooooooa0@
4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0=Oooool2o`0001Wooooo0_l00003ooooo`;o00003oooool:o`0000Gooooo0_l000000ooo
oooo0000o`000002ooooo`Co00000oooool2o`0000gooooo1?l00002ooooo`?o00000oooool2o`00
01?ooooo0_l0000?oooooako00001oooool2o`0000Cooooo0_l00009ooooo`?o00002Oooool2o`00
047ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l000001oooool0
0ol0003oooooooooo`0eooooo`;o0000<?ooool3o`0000?ooooo0ol00005ooooo`;o000000?ooooo
o`000?l000000_ooool4o`0000?ooooo0ol0000<ooooo`Co00000_ooool2o`0000;ooooo1?l00007
ooooo`;o00002_ooool2o`0000Gooooo0_l0000;oooooago00000_ooool2o`000003ooooool0003o
0000013ooooo0_l00009ooooo`?o0000@?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Ooo
ool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo03Cooooo0_l00003ooooo`?o00005_oo
ool2o`0000oooooo1_l000001?oooooo0000o`000?ooool2o`00013ooooo0ol00002ooooo`?o0000
2Oooool2o`000004ooooool0003o0000o`0000Kooooo0_l00009ooooo`?o00004?ooool2o`0000_o
oooo7Ol00002ooooo`Co00003_ooool2o`0000gooooo0_l00010ooooo`007?ooool00ol0003ooooo
ooooo`0dooooo`;o00000oooool3o`0001Kooooo0_l0000>ooooo`Ko00000_ooool2o`0000Cooooo
2?l00007ooooo`So00002Oooool2o`000003ooooool0003o000000;o000000Coooooo`000?l0003o
00003Oooool2o`0000?ooooo0_l0000Fooooo`;o000000?oooooo`000?l000006?l00006ooooo`;o
00003_ooool2o`0000?ooooo0ol00007ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0
D_ooool2o`0000kooooo0ol00008ooooo`_o000000?oooooo`000?l000000_l00002ooooo`;o0000
00?oooooo`000?l000004?ooool3o`000004ooooool0003o0000o`0000?ooooo0_l0000=ooooo`;o
00001oooool2o`0000gooooo0_l000000ooooooo0000o`000006o`000003ooooool0003o000000ko
00001oooool2o`0000Gooooo0_l0000<ooooo`?o00001oooool2o`00043ooooo000Looooo`03o`00
0?oooooooooo03_ooooo0_l0000Tooooo`?o00001_ooool6o`0000Gooooo0_l00002ooooo`Go0000
00Coooooo`000?l0003ooooo0_l00003ooooo`?o00002oooool2o`0000;ooooo0_l00003ooooo`;o
00002Oooool2o`0000;ooooo0_l00007ooooo`;o00004?oooolIo`0000kooooo0_l00004ooooo`;o
0000D_ooool001cooooo00?o0000ooooooooool0>oooool2o`0002?ooooo1?l00005oooooa3o0000
0oooool3o`0000Cooooo0_l00002ooooo`?o00002oooool2o`0000;ooooo0_l0000>ooooo`;o0000
2oooool2o`0000Wooooo1?l00003ooooo`?o000000?oooooo`000?l000000ol00003oooooa3o0000
2Oooool2o`0000Kooooo0_l00008ooooo`;o000000?oooooo`000?l00000AOooool001cooooo00?o
0000ooooooooool0H?ooool5o`0000Cooooo1Ol00002ooooo`_o00000_ooool2o`000004ooooool0
003o0000ooooo`?o00000_ooool2o`0000[ooooo0_l00005ooooo`;o00006oooool2o`0000Oooooo
1?l00004ooooo`So000000?oooooo`000?l000004?l00009ooooo`;o00004?ooool2o`000003oooo
ool0003o000004Gooooo000Looooo`03o`000?oooooooooo04kooooo0_l0000>ooooo`Oo00001Ooo
ool4o`0000;ooooo3Ol00002ooooo`?o000000Coooooo`000?l0003o00000_ooool5o`0000Oooooo
0ol00004ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00000@ooooo`Co
00000oooool2o`0000Kooooo0_l00002oooooaKo0000J_ooool001cooooo00?o0000ooooooooool0
>oooool2o`00017ooooo0_l0000=ooooo`Oo00000_ooool2o`0000;ooooo6?l00003ooooo`;o0000
0_ooool4o`0000Sooooo0_l00007ooooo`;o000000Coooooo`000?l0003ooooo0_l00007ooooo`;o
00001oooool4o`0000?ooooo0_l00006ooooo`;o00000ooooolDo`0000oooooo0_l0000Jooooo`;o
0000?_ooool001cooooo00?o0000ooooooooool0>_ooool3o`00013ooooo0_l0000>ooooo`Go0000
0oooool3o`000003ooooool0003o000000Ko000000?oooooo`000?l000003Ol00004ooooo`;o0000
1?ooool2o`0000Sooooo0_l000001?oooooo0000o`000?l00002ooooo`;o000000?oooooo`000?l0
00002oooool3o`0000Oooooo0_l0000<ooooo`;o00001_ooool3o`0000?ooooo2Ol00005ooooo`;o
00001oooool2o`000003ooooool0003o000001[ooooo0_l0000nooooo`007?ooool00ol0003ooooo
ooooo`0`ooooo`;o00002?ooool2o`00017ooooo0_l0000>ooooo`Co00001?oooolOo`000003oooo
ool0003o000000Cooooo0_l0000:ooooo`Co00000_ooool2o`000003ooooool0003o000000Oooooo
0_l00003ooooo`;o00001oooool2o`0001Cooooo4ol000000ooooooo0000o`000007ooooo`;o0000
GOooool001cooooo00?o0000ooooooooool0<?ooool2o`0000?ooooo0_l00003ooooo`;o00004?oo
ool2o`0000oooooo1ol000000ooooooo0000o`00000No`000003ooooool0003o000000oooooo0ol0
000?ooooo`Co00002_ooool2o`0000gooooo0_l00005ooooo`co00000_ooool5o`0000_ooooo0ol0
000Kooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0<oooool4o`0000?ooooo0_l0000:
ooooo`;o00001?ooool2o`0000kooooo0_l000000ooooooo0000o`000003o`0000;ooooo7ol00000
0ooooooo0000o`000002ooooo`;o00004_ooool2o`0000_ooooo0_l00009ooooo`?o00003Oooool4
o`0000?ooooo0_l000000ooooooo0000o`000007o`0000;ooooo0ol00006ooooo`;o00001Oooool3
o`0001_ooooo0_l0000nooooo`007?ooool2o`0003Cooooo0ol00003ooooo`?o00002_ooool2o`00
01Cooooo0_l00006ooooo`;o000000?oooooo`000?l000007?l000000ooooooo0000o`000002oooo
o`;o00004_ooool2o`0000Gooooo0_l0000?ooooo`;o00001?ooool2o`0000Wooooo0ol00003oooo
o`;o000000?oooooo`000?l000001Ol00005ooooo`;o00001_ooool2o`0000;ooooo0ol0000Noooo
o`?o0000?Oooool001cooooo00?o0000ooooooooool0;_ooool2o`0000Wooooo0ol0000Pooooo`;o
00001?ooool4o`000003ooooool0003o000001co000000Coooooo`000?l0003o00005Oooool6o`00
0004ooooool0003o0000ooooo`;o00004_ooool2o`0001;ooooo1ol0000;ooooo`;o00001?ooool3
o`0001oooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00002Oooool3o`00
00[ooooo0_l00007ooooo`;o00002_ooool3o`0000Cooooo8ol000001?oooooo0000o`000?l0000E
ooooo`Ko00001?ooool2o`0000gooooo1?l00004ooooo`;o00003oooool4o`000003ooooool0003o
000000Wooooo1?l0001Uooooo`007?ooool00ol0003oooooooooo`0dooooo`;o00000_ooool4o`00
00[ooooo0_l00007ooooo`;o00002_ooool2o`0000Gooooo9_l00002ooooo`?o000000?oooooo`00
0?l000009oooool4o`0000Cooooo0_l0000Booooo`;o00002oooool3o`0000gooooo0_l0001Goooo
o`007?ooool00ol0003oooooooooo`0/ooooo`;o00000_ooool2o`0000;ooooo0_l00002ooooo`?o
00002_ooool2o`0001Cooooo0ol00004ooooo`Go000000?oooooo`000?l000007?l000001?oooooo
0000o`000?ooool3o`000003ooooool0003o000000oooooo0ol0000Aooooo`;o00007_ooool2o`00
00Sooooo0_l00006ooooo`;o00002Oooool2o`0001Sooooo0_l0000mooooo`007?ooool00ol0003o
ooooooooo`0/ooooo`;o00000_ooool4o`0000Gooooo0_l0000:ooooo`;o00000oooool2o`0000oo
oooo0ol00004ooooo`?o000000?oooooo`000?l000008Ol0000Fooooo`Go00003_ooool3o`0001;o
oooo0ol0000:ooooo`;o00001oooool2o`0000Cooooo1Ol0000Oooooo`;o000000?oooooo`000?l0
0000?Oooool001cooooo00?o0000ooooooooool0;?ooool2o`0000Cooooo0_l00004ooooo`;o0000
4?ooool2o`0000oooooo1?l00004ooooobGo00000_ooool2o`0001Kooooo0ol0000;ooooo`Go0000
4_ooool3o`0000Cooooo0_l00004ooooo`;o00003Oooool5o`0001oooooo0_l00010ooooo`007?oo
ool00ol0003oooooooooo`0/ooooo`;o00002_ooool2o`0001Cooooo0_l0000;ooooo`Co00000_oo
oolSo`000005ooooool0003o0000o`000?ooool00ol0000Cooooo`;o000000?oooooo`000?l00000
0_l00008ooooo`Oo00005_ooool2o`000004ooooool0003o0000ooooo`;o00004?ooool2o`0006Co
oooo000Looooo`03o`000?oooooooooo03Kooooo0_l0000Fooooo`;o00000oooool2o`0000Oooooo
1?l000000ooooooo0000o`00000Uo`000004ooooool0003o0000o`0001?ooooo0_l00002oooooa;o
00000_ooool2o`00017ooooo1Ol00002ooooo`;o00003oooool4o`0006?ooooo000Looooo`03o`00
0?oooooooooo03Kooooo0_l0000Kooooo`;o00001oooool7o`000003ooooool0003o000002;o0000
0_ooool2o`000003ooooool0003o000001Cooooo4_l00002ooooo`;o00004Oooool5o`0001?ooooo
1?l0001Sooooo`007?ooool00ol0003oooooooooo`0gooooo`?o00004_ooool2o`0000kooooo0_l0
00000ooooooo0000o`00000Ro`000004ooooool0003o0000o`0000;ooooo0_l00002ooooo`;o0000
5Oooool:o`0000;ooooo1?l0000Pooooo`?o00003Oooool2o`0002Gooooo0_l0000Gooooo`;o0000
8oooool001cooooo00?o0000ooooooooool0=oooool3o`0000kooooo0_l00002ooooo`;o00000ooo
ool3o`0000Sooooo0ol00003ooooobGo00000_ooool2o`0001?ooooo0_l0000:ooooo`Co00000_oo
ool4o`0000?ooooo0ol0000Eooooo`Co000000Coooooo`000?l0003o00003?ooool2o`0002Kooooo
0_l0000Gooooo`;o00008oooool001cooooo00?o0000ooooooooool0;oooool2o`0000Kooooo0_l0
000>ooooo`?o000000?oooooo`000?l000001?ooool3o`0000Sooooo0ol00003ooooo`So000000?o
ooooo`000?l000002Ol000000ooooooo0000o`00000=o`0000;ooooo0_l0000Dooooo`;o000000?o
ooooo`000?l000000ol0000<ooooo`;o00000oooool3o`0001Gooooo1?l00002ooooo`Co00001Ooo
ool2o`0000?ooooo0_l0000oooooo`;o00008oooool001cooooo00?o0000ooooooooool0;oooool2
o`0001Kooooo1_l0000@ooooo`;o00001Oooool9o`0000;ooooo5ol00002ooooo`;o00004oooool2
o`0000;ooooo1_l0000;ooooo`;o00001?ooool2o`0001Kooooo0_l00005ooooo`;o00001Oooool2
o`0000?ooooo0_l0000oooooo`;o00008oooool001cooooo00?o0000ooooooooool0:Oooool2o`00
01oooooo0_l0000Aooooo`;o00001_ooool9o`000003ooooool0003o000001Co00000oooool4o`00
017ooooo0_l00005ooooo`?o00002oooool2o`00023ooooo0_l00003ooooo`?o0000;Oooool2o`00
03kooooo000Looooo`03o`000?oooooooooo02Sooooo0ol0000Dooooo`;o00001Oooool3o`000003
ooooool0003o000000Cooooo0_l0000<ooooo`;o00001?ooool:o`000003ooooool0003o000001Co
000000Coooooo`000?l0003ooooo0ol0000Aooooo`;o00000_ooool2o`0000Oooooo0_l000000ooo
oooo0000o`000003ooooo`;o00006oooool2o`0000;ooooo1Ol000001?oooooo0000o`000?l00005
ooooo`;o00009_ooool2o`0003kooooo000Looooo`;o0000:Oooool2o`0001Cooooo0ol00005oooo
o`?o000000?oooooo`000?l000001?ooool2o`0000cooooo0ol000000ooooooo0000o`00000?o`00
0003ooooool0003o000000[o000000Coooooo`000?l0003o00000_ooool2o`000003ooooool0003o
000000;ooooo0_l0000Booooo`So000000Coooooo`000?l0003ooooo0_l00003ooooo`?o00001?oo
ool2o`0001?ooooo0ol00002ooooo`Go00001Oooool2o`0000;ooooo0_l0000Xooooo`;o0000??oo
ool001cooooo00?o0000ooooooooool0?_ooool2o`0001Kooooo0_l00007ooooo`;o000000?ooooo
o`000?l000001Ol000000ooooooo0000o`000007o`000003ooooool0003o000000;o000000?ooooo
o`000?l000001ol0000;ooooo`;o00005?ooool6o`0000[ooooo0ol00003ooooo`;o00004oooool2
o`0000Sooooo0_l00003ooooo`?o0000:oooool2o`0003cooooo000Looooo`03o`000?oooooooooo
05Gooooo1?l00006ooooo`;o00000_ooool7o`000003ooooool0003o000000Ko000000?oooooo`00
0?l000001_l000000ooooooo0000o`000003o`0000;ooooo0_l000000ooooooo0000o`000004oooo
o`;o00004_ooool2o`0000Cooooo0_l0000:ooooo`?o00007oooool2o`000003ooooool0003o0000
00Cooooo0_l00003ooooo`;o0000I?ooool001cooooo00?o0000ooooooooool0;oooool2o`00017o
oooo0_l0000Aooooo`Co00001_ooool2o`0000;ooooo0ol000000ooooooo0000o`000004o`000003
ooooool0003o000000?o00000oooool5o`0000?ooooo1?l00002ooooo`;o000000Coooooo`000?l0
003o00001Oooool2o`00013ooooo0_l0000:ooooo`;o000000?oooooo`000?l000000_ooool3o`00
00?ooooo0_l0000Dooooo`Co000000Coooooo`000?l0003ooooo0_l00005ooooo`;o000000Cooooo
o`000?l0003o0000I?ooool001cooooo00?o0000ooooooooool0;oooool4o`0000oooooo0_l0000:
ooooo`;o000000?oooooo`000?l000000oooool2o`0000Oooooo0ol00002ooooo`;o000000?ooooo
o`000?l000000_l000000ooooooo0000o`00000<o`000003ooooool0003o000000Co00000oooool2
o`000004ooooool0003o0000o`0000Gooooo0_l0000>ooooo`;o00000_ooool2o`0000Sooooo0_l0
00001Ooooooo0000o`000?l0003ooooo00?o00000oooool2o`0001Cooooo1?l00006ooooo`;o0000
0oooool6o`0000;ooooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`0_ooooo`Co00006ooo
ool2o`000003ooooool0003o000000?ooooo0ol00007ooooo`;o00000_ooool7o`000003ooooool0
003o000000co000000?oooooo`000?l000001?l00002ooooo`?o000000?oooooo`000?l000001?oo
ool2o`00013ooooo0_l00002ooooo`;o00003?ooool2o`0000;ooooo0ol00002ooooo`;o00002_oo
ool2o`0000?ooooo0_l00004ooooo`;o00001?ooool2o`000003ooooool0003o000000Cooooo1Ol0
0002ooooo`;o00001Oooool2o`0001_ooooo0_l0000looooo`007?ooool00ol0003oooooooooo`0_
ooooo`Co00009?ooool2o`000003ooooool0003o000000Gooooo0_l000000ooooooo0000o`000004
o`000003ooooool0003o000001;o00001?ooool2o`0000Sooooo0_l0000Cooooo`?o00004Oooool2
o`0000;ooooo0ol00009ooooo`;o00000oooool2o`0000[ooooo1?l00002ooooo`;o00002?ooool2
o`0000Gooooo0_l0000Kooooo`;o00005oooool2o`0002?ooooo000Looooo`03o`000?oooooooooo
05?ooooo0_l00004ooooo`?o00001Oooool4o`0000?ooooo5ol00006ooooo`?o00001Oooool2o`00
01?ooooo0_l00004ooooo`;o00002oooool3o`0000?ooooo0ol000001?oooooo0000o`000?l0000G
ooooo`?o000000Coooooo`000?l0003o0000A?ooool2o`0002?ooooo000Looooo`03o`000?oooooo
oooo04Oooooo0_l00005ooooo`;o00000_ooool3o`0000Cooooo1Ol00003ooooo`Co00000oooool3
o`000003ooooool0003o000000[o00000_ooool8o`000003ooooool0003o000000?o00001Oooool2
o`000003ooooool0003o000000Wooooo1?l00009ooooo`;o00002oooool2o`0000Cooooo0ol00000
1?oooooo0000o`000?l00007ooooo`;o00002?ooool4o`0000?ooooo0_l00002ooooo`Go0000I_oo
ool001cooooo00?o0000ooooooooool0A?ooool2o`000004ooooool0003o0000o`0000Cooooo0_l0
0002ooooo`;o00001_ooool4o`000003ooooool0003o000000Oo00001?oooolJo`0000Oooooo0_l0
00001?oooooo0000o`000?l00008ooooo`Co00005Oooool2o`0000Gooooo0ol0000;ooooo`;o0000
1oooool5o`0000Sooooo1?l0001Vooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00000_oo
ool2o`0000Sooooo0_l000000ooooooo0000o`000008ooooo`;o00000oooool4o`0000Cooooo0_l0
00000ooooooo0000o`000005o`0000;ooooo1Ol00002ooooo`Go00002_ooool2o`000003ooooool0
003o000000Kooooo1_l0000Booooo`;o000000?oooooo`000?l000001?l00002ooooo`;o00002ooo
ool2o`0000?ooooo0ol000001?oooooo0000o`000?ooool2o`0000?ooooo0_l00003ooooo`?o0000
Ioooool001cooooo00?o0000ooooooooool0B_ooool2o`0000Kooooo0_l000000ooooooo0000o`00
0008ooooo`;o00003_ooool2o`000004ooooool0003o0000o`0000Gooooo1?l000001?oooooo0000
o`000?l0000:ooooo`Co00002Oooool3o`000003ooooool0003o000000Gooooo0_l00007ooooo`;o
00000_ooool2o`000003ooooool0003o000000Co00005?ooool3o`0000Wooooo0_l00004ooooo`;o
0000@?ooool2o`0002Gooooo000Looooo`03o`000?oooooooooo04[ooooo0_l00004ooooo`Wo0000
1_ooool2o`0000Wooooo0_l00004ooooo`;o000000?oooooo`000?l000001oooool2o`000003oooo
ool0003o000000_ooooo0_l0000Dooooo`Co00001oooool4o`0000?ooooo0_l0000Looooo`;o0000
1?ooool2o`00017ooooo0_l000000ooooooo0000o`00000booooo`;o00009Oooool001cooooo00?o
0000ooooooooool0:Oooool2o`0000Kooooo1?l0000Kooooo`Wo00000oooool2o`0000?ooooo0_l0
0007ooooo`;o00001?ooool2o`0000Cooooo0_l00007ooooo`;o00002?ooool2o`0000Kooooo0_l0
00001?oooooo0000o`000?ooool3o`0000Sooooo0_l0000;ooooo`;o00003Oooool2o`0001;ooooo
0_l00004ooooo`;o00004Oooool2o`000003ooooool0003o000005Wooooo000Looooo`03o`000?oo
oooooooo02Wooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l00009ooooo`;o00006?oo
ool2o`000004ooooool0003o0000o`0000?ooooo0_l00007ooooo`Go00001oooool2o`00017ooooo
0_l00006ooooo`Wo00001Oooool2o`0001Oooooo0_l000000ooooooo0000o`000003o`0001Kooooo
0_l00003ooooo`Go0000JOooool001cooooo00?o0000ooooooooool0;_ooool2o`000003ooooool0
003o000000_ooooo0ol0000Dooooo`;o000000Coooooo`000?l0003ooooo1Ol0000;ooooo`Co0000
2Oooool2o`0000Cooooo0_l0000<ooooo`Co000000?oooooo`000?l000001?l00008ooooo`;o0000
0_ooool2o`0001?ooooo1ol00007ooooo`;o000000?oooooo`000?l000002?ooool2o`000004oooo
ool0003o0000o`0000;ooooo1Ol00002ooooo`;o0000IOooool001cooooo0_l00010ooooo`Co0000
3oooool2o`000003ooooool0003o000000Oooooo1?l0000?ooooo`Co00000oooool2o`000004oooo
ool0003o0000ooooo`;o00001oooool2o`0000;ooooo1Ol00003ooooo`;o00003Oooool4o`0001Co
oooo1?l00008ooooo`;o000000?oooooo`000?l000002?ooool2o`0000;ooooo1Ol000000ooooooo
0000o`000005o`0000Kooooo0_l0000dooooo`;o00009oooool001cooooo00?o0000ooooooooool0
:?ooool2o`0000Sooooo0_l0000=ooooo`;o00003oooool2o`0000Cooooo0_l00002ooooo`Ko0000
3?ooool2o`000003ooooool0003o000000;o00000oooool2o`000003ooooool0003o000000;o0000
0oooool2o`000003ooooool0003o000000;o00000_ooool3o`0000Gooooo0_l00006ooooo`;o0000
1Oooool5o`0000oooooo0_l000000ooooooo0000o`000003o`0000;ooooo0_l0000Eooooo`Go0000
00?oooooo`000?l000000ol00008ooooo`;o0000=?ooool2o`0002Oooooo000Looooo`03o`000?oo
oooooooo02Sooooo0_l00007ooooo`?o00000oooool2o`0000Oooooo0ol0000@ooooo`;o00000ooo
ool2o`0000;ooooo1?l000000ooooooo0000o`000008ooooo`;o000000?oooooo`000?l000000_oo
ool2o`0000Cooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l000000ooooooo0000o`00
000:ooooo`;o00002?ooool3o`0000;ooooo2?l0000;ooooo`;o000000Coooooo`000?l0003ooooo
0_l00005ooooo`;o00001Oooool2o`0000Wooooo1?l000000ooooooo0000o`000004o`000004oooo
ool0003o0000ooooo`;o00009Oooool2o`0001Cooooo0_l0000Yooooo`007?ooool00ol0003ooooo
ooooo`0_ooooo`Co00000oooool3o`0000Cooooo0_l000000ooooooo0000o`00000>ooooo`;o0000
00?oooooo`000?l000003?ooool2o`0000Sooooo0_l00006ooooo`;o00000_ooool2o`0001Gooooo
0_l000000ooooooo0000o`000002ooooo`?o00001?ooool2o`000003ooooool0003o000000Oo0000
2oooool2o`000004ooooool0003o0000ooooo`;o00002oooool3o`0000Wooooo5?l0000Qooooo`?o
00005?ooool2o`0002Wooooo000Looooo`03o`000?oooooooooo02oooooo0_l00004ooooo`?o0000
1Oooool2o`00017ooooo0_l00002ooooo`;o00000oooool2o`0000[ooooo0_l0000;ooooo`?o0000
0_ooool2o`0000;ooooo1?l00002ooooo`?o00002?ooool4o`0000Gooooo0ol00003ooooo`;o0000
00?oooooo`000?l000002?l0000>ooooo`;o00000oooool2o`0000Wooooo1?l00008oooooaCo0000
1_ooool2o`0001Wooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0eooooo`;o00007Ooo
ool2o`0000?ooooo0_l0000:ooooo`;o00001_ooool2o`0000?ooooo0ol00006ooooo`Co00000_oo
ool3o`0000Sooooo1Ol00002ooooo`;o00001_ooool2o`000003ooooool0003o000000Wo00002?oo
ool2o`0000;ooooo0_l00002ooooo`Co00002oooool2o`0000Kooooo5?l00008ooooo`;o0000;ooo
ool2o`0002[ooooo000Looooo`03o`000?oooooooooo03Cooooo0_l00003ooooo`;o00005Oooool2
o`0001_ooooo0_l0000Dooooo`;o00002Oooool3o`0000;ooooo0ol00003ooooo`;o00000_ooool<
o`0000Sooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00003Oooool5o`0000?ooooo0ol0
00000ooooooo0000o`00000@o`0000Wooooo0_l0000/ooooo`;o0000:_ooool001cooooo00?o0000
ooooooooool0=?ooool2o`000003ooooool0003o000000;o00002?ooool2o`0000_ooooo0_l0000X
ooooo`;o00000_ooool3o`0000;ooooo0_l00006ooooo`Go00001?ooool2o`0000?ooooo0_l00002
ooooo`co00002Oooool7o`00017ooooo0ol00002ooooo`?o00000ooooolAo`0000Wooooo0_l0000D
ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0=oooool4o`0000Sooooo0_l0000eoooo
o`;o00000_ooool3o`0000[ooooo1?l0000>ooooo`co00002Oooool2o`0000;ooooo0ol0000Foooo
oaOo00002Oooool2o`0001Cooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`0gooooo`Co
00005oooool2o`0003Kooooo1?l000000ooooooo0000o`000009ooooo`;o00000_ooool;o`0000_o
oooo1?l0000>ooooo`;o00001ooooolGo`0000Wooooo0_l0000Zooooo`;o0000;?ooool001cooooo
00?o0000ooooooooool0>Oooool2o`0000;ooooo0_l0000Aooooo`Co0000=_ooool2o`0000?ooooo
0_l00009ooooo`;o00000_ooool;o`0000_ooooo1?l0000=ooooo`?o00002OoooolEo`0000Sooooo
0ol0000Zooooo`;o0000;?ooool001cooooo00?o0000ooooooooool0=?ooool3o`0000;ooooo0_l0
0002ooooo`;o00004Oooool4o`0003Gooooo0_l0000Dooooo`[o00003?ooool3o`0000_ooooo1Ol0
0009oooooaGo00002?ooool3o`0005Sooooo000Looooo`03o`000?oooooooooo03Cooooo0ol00000
0ooooooo0000o`00000Dooooo`;o00000_ooool2o`0001Oooooo0_l000000ooooooo0000o`00000I
ooooo`;o00002_ooool2o`0000?ooooo0_l00003ooooo`Wo00002_ooool6o`0000_ooooo1Ol00006
ooooo`;o000000?oooooo`000?l000003?l000001?oooooo0000o`000?ooool5o`0000Kooooo0_l0
001Iooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00005?ooool2o`0001_ooooo0_l00000
0ooooooo0000o`000003o`0002;ooooo0ol00002ooooo`Co00000_ooool8o`0000[ooooo1_l0000<
ooooo`;o00001_ooool4o`000003ooooool0003o000000_o000000?oooooo`000?l000001ol00007
ooooo`?o00004Oooool2o`0001?ooooo0_l0000_ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^
k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0
@oooool2o`000003ooooool0003o000000Sooooo0_l0000Gooooo`Co00000oooool7o`0001[ooooo
0_l00003ooooo`;o00001?ooool2o`000003ooooool0003o000000Oo00000oooool2o`0000Gooooo
1?l00007ooooo`;o00001Oooool2o`0000Cooooo1_l000000ooooooo0000o`00000Eo`000003oooo
ool0003o000000Cooooo0ol0000Aooooo`;o00004oooool2o`0002oooooo00001_ooooooMgMgoiRH
V?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0
003oooooooooo`0booooo`Go00003?ooool2o`000003ooooool0003o000000Sooooo0_l0000Goooo
o`?o00000_ooool2o`0000?ooooo2?l0000Fooooo`;o00003?ooool9o`0000?ooooo0_l000000ooo
oooo0000o`000002ooooo`?o00001Oooool2o`000003ooooool0003o000000Gooooo0_l00004oooo
o`;o00000_ooool2o`000003ooooool0003o000001Go000000Coooooo`000?l0003ooooo0_l0000@
ooooo`;o00006?ooool2o`0002oooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo
00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo03;ooooo1Ol0000<
ooooo`;o00003Oooool2o`0001Oooooo0_l000000ooooooo0000o`000005ooooo`Oo00001Oooool2
o`0001_ooooo2_l00004ooooo`Go00000_ooool2o`0000Gooooo0_l00008ooooo`;o000000?ooooo
o`000?l000002?oooolDo`0000Oooooo0_l0000?ooooo`?o0000BOooool00003ooooool0003ooooo
00;ooooo00?o0000ooooooooool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol00013
ooooo`Co00002Oooool4o`0001Oooooo0_l0000;ooooo`Co00001Oooool3o`0000;ooooo0_l0000B
ooooo`;o00000_ooool2o`0000;ooooo0_l00008ooooo`;o000000?oooooo`000?l000002Oooool4
o`0000Sooooo0ol00003ooooo`;o00000ooooolCo`0000kooooo0_l00009ooooo`;o0000B_ooool0
0003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oEEEEo`000?l@413o
c<c<00Kooooo00?o0000ooooooooool0>?ooool2o`0000;ooooo0_l00007ooooo`;o00002Oooool4
o`0001Oooooo1?l0000Cooooo`;o00000_ooool2o`0001;ooooo0_l00003ooooo`;o000000?ooooo
o`000?l000003_ooool2o`0000Kooooo1?l00008ooooo`;o00001?ooool2o`000003ooooool0003o
000001?o00003Oooool3o`0000Oooooo0_l0000Hooooo`;o0000<_ooool00003ooooool@413ooooo
00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo
03Sooooo0_l000001?oooooo0000o`000?l0000=ooooo`;o00008?ooool2o`0001Oooooo0_l00002
ooooo`?o00002_ooool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000004
o`0000[ooooo0_l00006ooooo`Co00002?ooool2o`0000Kooooo5_l00004ooooo`;o00000_ooool2
o`0000?ooooo0_l00008ooooo`;o00006?ooool2o`0003;ooooo00001_ooooooMgMgoiRHV?oooooo
V9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0kooooo`;o00002Ooo
ool2o`0000?ooooo0_l0000^ooooo`;o00003Oooool4o`0000Sooooo0ol000000ooooooo0000o`00
0007ooooo`Oo00004_ooool2o`0000Oooooo0_l00007oooooa7o000000Goooooo`000?l0003o0000
ooooo`02o`0000;ooooo0_l00002ooooo`Co0000FOooool00006ooooooo^k^ko<S8bo`000?lb<S;o
k^k^3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo03Gooooo0_l00003oooo
o`;o00002_ooool2o`0000;ooooo0_l0000_ooooo`;o00000_ooool4o`0000Oooooo1?l00008oooo
o`Co00002Oooool2o`0000?ooooo0_l0000Kooooo`;o000000?oooooo`000?l000001OoooolDo`00
0003ooooool0003o000000Cooooo0_l00002ooooo`;o0000FOooool001cooooo00?o0000oooooooo
ool0=Oooool2o`000003ooooool0003o000000;o00003_ooool2o`0000Kooooo0_l0000[ooooo`Co
00002?ooool2o`0000Gooooo0_l00002ooooo`Co00002_ooool2o`0000cooooo0_l0000Dooooo`;o
00001Oooool8o`000003ooooool0003o000000Wo00001oooool3o`000003ooooool0003o000005Wo
oooo000Looooo`03o`000?oooooooooo03Sooooo1?l0000Aooooo`;o00000_ooool3o`0003Gooooo
1?l00005ooooo`Co00002?ooool2o`0000Cooooo0_l0000:ooooo`Co00006Oooool2o`000004oooo
ool0003o0000ooooo`Co000000?oooooo`000?l000001_l000000ooooooo0000o`000008ooooo`;o
000000?oooooo`000?l00000FOooool001cooooo00?o0000ooooooooool0=oooool5o`0000_ooooo
0_l00004ooooo`;o00000_ooool4o`0002oooooo0_l00003ooooo`?o00002?ooool2o`0000Cooooo
1_l00008ooooo`;o00001_ooool2o`0001Oooooo0_l00002ooooo`Go00000oooool2o`000003oooo
ool0003o000000;o00004_ooool2o`0000Cooooo1?l000001?oooooo0000o`000?l0001=ooooo`00
7?ooool00ol0003oooooooooo`0gooooo`Co00003?ooool2o`0000[ooooo0_l0000Qooooo`?o0000
2oooool2o`0000;ooooo1?l0000>ooooo`Co00002?ooool5o`0000Cooooo0ol0000Fooooo`Co0000
0_ooool6o`000003ooooool0003o000000Co000000?oooooo`000?l000000_l00008ooooo`?o0000
0oooool2o`0000Cooooo2?l0001=ooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00001_oo
ool2o`0000?ooooo0_l00009ooooo`;o00008oooool5o`0000oooooo1?l0000=ooooo`Oo00001_oo
ool2o`000003ooooool0003o000000Cooooo0_l0000=ooooo`?o00001oooool4o`0000Gooooo0ol0
00000ooooooo0000o`000003o`0000;ooooo1_l00005ooooo`Go000000?oooooo`000?l000001_oo
ool4o`0001Oooooo0_l0000gooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00000oooool2
o`0000Oooooo1?l00005ooooo`;o00006oooool5o`0001Wooooo0_l00006ooooo`So000000?ooooo
o`000?l000002?ooool5o`0000Kooooo0_l00005ooooo`?o00002?ooool2o`0000Gooooo1ol00009
ooooo`;o00001Oooool8o`00017ooooo0ol0000=ooooo`;o0000=oooool001cooooo00?o0000oooo
ooooool0>oooool2o`0000Oooooo0_l00007ooooo`Co00001Oooool2o`0001[ooooo0ol0000>oooo
o`;o00001?ooool3o`0000Gooooo0_l00008ooooo`;o000000?oooooo`000?l000001Ol00007oooo
o`Co00001oooool2o`0000oooooo0_l00004ooooo`Oo00003Oooool2o`0000Cooooo0_l000000ooo
oooo0000o`00000Cooooo`?o000000?oooooo`000?l00000@oooool001cooooo00?o0000oooooooo
ool0>oooool2o`0000?ooooo0_l00002ooooo`;o00001?ooool2o`0000Cooooo0_l00003ooooo`Co
00006Oooool2o`0000gooooo1?l00004ooooo`?o00001oooool5o`0000?ooooo0_l000000ooooooo
0000o`000005o`0000Sooooo0ol0000Booooo`;o00000_ooool4o`0000?ooooo0ol000001?oooooo
0000o`000?l00007ooooo`Go00000_ooool2o`0000Gooooo0_l0000Cooooo`;o00001?ooool2o`00
04?ooooo000Looooo`03o`000?oooooooooo03kooooo1_l00006ooooo`;o00000_ooool4o`0000?o
oooo1?l0000Pooooo`;o00001_ooool3o`0000?ooooo0_l0000:ooooo`Go000000?oooooo`000?l0
00000_l000000ooooooo0000o`000005o`0000Oooooo0_l0000Dooooo`;o00000_ooool5o`000003
ooooool0003o000000;o00000_ooool2o`000004ooooool0003o0000o`0000?ooooo1Ol00005oooo
o`;o00000_ooool2o`0000kooooo0_l00003ooooo`Ko0000AOooool001cooooo00?o0000oooooooo
ool0?_ooool2o`0000;ooooo0_l0000:ooooo`Co00009oooool2o`000004ooooool0003o0000oooo
o`Co00001?ooool4o`0000[ooooo4Ol00006ooooo`;o00001?ooool2o`0000gooooo0ol00005oooo
o`;o000000?oooooo`000?l000000_l00005ooooo`?o00001?ooool3o`0000Kooooo0_l000000ooo
oooo0000o`00000?ooooo`?o00001?ooool4o`0004Gooooo000Looooo`03o`000?oooooooooo03co
oooo1?l00005ooooo`;o00000oooool3o`0000;ooooo1Ol0000Xooooo`;o000000?oooooo`000?l0
00000_l00006ooooo`;o00002Oooool2o`0000;ooooo4_l00007ooooo`?o00002_ooool2o`000004
ooooool0003o0000o`0000Gooooo0ol00002ooooo`?o00000_ooool4o`0000gooooo2?l0000;oooo
o`;o000000?oooooo`000?l000000oooool2o`0004Sooooo000Looooo`;o0000?Oooool2o`0000Oo
oooo0_l00003ooooo`Co00000oooool3o`0003Gooooo0_l00009oooooaKo00001oooool2o`0000_o
oooo0_l00006ooooo`;o000000?oooooo`000?l000000_l00002ooooo`?o000000?oooooo`000?l0
00000_l00005ooooo`;o00001Oooool:o`0000[ooooo0_l00006ooooo`;o0000B?ooool001cooooo
00?o0000ooooooooool0?Oooool2o`0000Kooooo0_l00004ooooo`?o00001?ooool2o`0002Oooooo
0_l000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l000002?oooolDo`0000;ooooo
0_l0000;ooooo`;o00003_ooool2o`000003ooooool0003o000000?o00000_ooool2o`0000[ooooo
0_l00003ooooo`Co00001_ooool2o`0001;ooooo0_l00018ooooo`007?ooool00ol0003ooooooooo
o`0mooooo`;o00001?ooool2o`0000gooooo0_l0000:ooooo`;o00006_ooool6o`000003ooooool0
003o000000?ooooo0_l000000ooooooo0000o`000005ooooo`;o000000Goooooo`000?l0003o0000
ooooo`0Do`0000_ooooo0_l00006ooooo`;o00002Oooool8o`0000Gooooo0_l00009ooooo`;o0000
1?ooool2o`0000Kooooo0_l00009ooooo`;o00000oooool2o`0000Sooooo0_l0000nooooo`007?oo
ool00ol0003oooooooooo`0looooo`;o00001Oooool2o`000003ooooool0003o000000?ooooo0_l0
0004ooooo`Go00002?ooool2o`0001[ooooo1Ol00002ooooo`;o00001_ooool2o`0000?ooooo1?l0
00001?oooooo0000o`000?l00002oooooa?o00004oooool4o`0000Oooooo2?l00005ooooo`;o0000
2Oooool2o`0000Cooooo0_l00006ooooo`;o00001Oooool3o`000004ooooool0003o0000o`0000_o
oooo0ol0000nooooo`007?ooool00ol0003oooooooooo`0looooo`;o00002?ooool2o`0000?ooooo
1?l00002ooooo`Ko00002?ooool2o`0001[ooooo0_l00004ooooo`;o00001Oooool3o`0000?ooooo
0_l00003ooooo`So000000?oooooo`000?l000003Ol0000;ooooo`?o00001Oooool6o`0000Oooooo
0ol00005ooooo`;o00001_ooool2o`0000Cooooo0_l0000@ooooo`;o000000Coooooo`000?l0003o
00000_ooool2o`0000_ooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`1=ooooo`?o0000
1?ooool3o`0000Sooooo0_l0000Qooooo`;o00001?ooool3o`0000Sooooo6Ol0000:ooooo`?o0000
2?ooool3o`0000?ooooo0_l00003ooooo`;o00001Oooool2o`0000;ooooo0_l00002ooooo`;o0000
4?ooool3o`0000?ooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o00001_oo
ool2o`0000Wooooo0_l0000Looooo`;o000000?oooooo`000?l000001?ooool2o`0000Gooooo0_l0
0002ooooo`_o000000?oooooo`000?l000003?l00002ooooo`;o00001_ooool2o`0000Sooooo0ol0
0003ooooo`;o000000?oooooo`000?l000002oooool2o`0000oooooo0_l00003ooooo`?o0000FOoo
ool001cooooo00?o0000ooooooooool0C_ooool2o`0000Kooooo0_l00005ooooo`;o00000_ooool2
o`0001;ooooo0_l00007ooooo`?o00003_ooool2o`0000Cooooo7?l0000Aooooo`;o000000?ooooo
o`000?l000000oooool2o`0000;ooooo0_l00004ooooo`?o00001_ooool2o`0000Wooooo0_l0001O
ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00000_ooool2o`000003ooooool0003o0000
00_ooooo0ol000000ooooooo0000o`000005o`0001Kooooo0_l00007ooooo`;o00004?ooool4o`00
0003ooooool0003o0000013o00000_ooool8o`0000oooooo0_l00003ooooo`;o00000_ooool2o`00
00?ooooo0_l00004ooooo`?o00001_ooool4o`0000Oooooo0_l0000Jooooo`;o0000@oooool001co
oooo00?o0000ooooooooool0@?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000;ooooo`?o
000000?oooooo`000?l000001?l0000Gooooo`?o00006?oooolHo`0000;ooooo0ol00002ooooo`;o
00003oooool3o`0000Kooooo0_l0000;ooooo`;o00001oooool2o`0002?ooooo0_l00013ooooo`00
7?ooool00ol0003oooooooooo`12ooooo`;o00001?ooool2o`0000kooooo0ol000000ooooooo0000
o`00000Gooooo`?o00002oooool2o`0000gooooo5_l000000ooooooo0000o`000004o`0000Kooooo
0_l0000:ooooo`;o00004oooool2o`00077ooooo000Looooo`03o`000?oooooooooo04;ooooo0ol0
0003ooooo`;o00003?ooool6o`0001oooooo0ol00005ooooo`;o00003OoooolFo`000003ooooool0
003o000000Co00001_ooool2o`00047ooooo0_l00009ooooo`;o0000A?ooool001cooooo00?o0000
ooooooooool0@_ooool3o`0000?ooooo0_l00007ooooo`;o00000oooool3o`000003ooooool0003o
000000;o00002?ooool2o`0001?ooooo1?l00004ooooo`;o00001oooool4o`0000;ooooo5Ol00003
ooooo`Co0000BOooool3o`0000Wooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`13oooo
o`?o00000_ooool2o`0000Oooooo0_l00008ooooo`Go00001_ooool2o`0001Cooooo1_l000000ooo
oooo0000o`000007ooooo`Co00000_ooool2o`0000;ooooo4_l00002ooooo`Ko0000Aoooool2o`00
00[ooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`13ooooo`?o00002oooool2o`0000Go
oooo0_l00002ooooo`Co00000oooool2o`0000;ooooo0_l0000Aooooo`So00001oooool2o`0000?o
oooo6_l00002ooooo`Ko0000C_ooool2o`0004Wooooo000Looooo`03o`000?oooooooooo057ooooo
1?l00003ooooo`;o00000_ooool6o`000005ooooool0003o0000o`000?ooool00_l0000?ooooo`Wo
00002?ooool2o`0000;ooooo7?l00002ooooo`?o0000D?ooool2o`0004Wooooo000Looooo`;o0000
E?ooool2o`0000Sooooo1Ol00002ooooo`;o000000?oooooo`000?l000003oooool2o`0000;ooooo
0_l000000ooooooo0000o`000009ooooo`;o000000?oooooo`000?l000007ol0002Kooooo`007?oo
ool00ol0003oooooooooo`1;ooooo`;o00001_ooool2o`0000Gooooo0_l00002ooooo`;o00000_oo
ool2o`0000?ooooo1?l0000Aooooo`Go00001?ooool2o`0000?ooooo0_l00005oooooago00000_oo
ool2o`0002[ooooo0_l0001[ooooo`007?ooool00ol0003oooooooooo`19ooooo`Co000000?ooooo
o`000?l000000oooool5o`0000;ooooo0ol000000ooooooo0000o`000002ooooo`;o00001?ooool3
o`00017ooooo1Ol000000ooooooo0000o`000004o`0000Gooooo1?l00004oooooaCo00001oooool2
o`0002?ooooo0_l00004ooooo`Go00000_ooool4o`000003ooooool0003o0000063ooooo000Loooo
o`03o`000?oooooooooo04Wooooo0_l00003ooooo`;o00000oooool5o`0000?ooooo0_l00005oooo
o`;o00005?ooool2o`0000;ooooo0ol00003ooooo`Ko00001Oooool4o`0000?ooooo5Ol000000ooo
oooo0000o`00000Yooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`Go000000?ooooo
o`000?l000000oooool2o`0005_ooooo000Looooo`03o`000?oooooooooo04Wooooo0_l0000Goooo
o`Co00003_ooool2o`0000;ooooo0_l00002ooooo`Co00001oooool2o`0000_ooooo6?l00003oooo
o`;o00001Oooool2o`0001gooooo0_l0000:ooooo`;o00000oooool2o`0000Cooooo0_l0000=oooo
o`;o0000C?ooool001cooooo00?o0000ooooooooool0Eoooool2o`0000_ooooo0_l0000>ooooo`;o
00001_ooool4o`0000Oooooo0_l00006ooooo`Co000000?oooooo`000?l000004?l00002ooooo`Co
00000oooool4o`0000?ooooo0_l0000Xooooo`;o00000_ooool4o`0000?ooooo0_l0000>ooooo`;o
0000C?ooool001cooooo00?o0000ooooooooool0Boooool2o`0000[ooooo0_l0000Looooo`;o0000
1Oooool5o`000003ooooool0003o000000Oooooo0_l00002ooooo`Co000000?oooooo`000?l00000
4_l00002ooooo`;o00000_ooool2o`000003ooooool0003o000002gooooo0_l000000ooooooo0000
o`000003o`0000?ooooo0_l0000<ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0Booo
ool2o`000003ooooool0003o000000Co00008Oooool2o`0000;ooooo0_l000000ooooooo0000o`00
0003o`000003ooooool0003o000000Oooooo0_l00002ooooo`?o00001?ooool>o`0000;ooooo0_l0
0002ooooo`;o00000_ooool2o`00033ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l0
000>ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0C_ooool6o`0002Cooooo0ol00002
ooooo`;o00001oooool2o`0000[ooooo0ol00005ooooo`_o00001oooool2o`0000Kooooo0_l0000J
ooooo`;o00003Oooool4o`0000;ooooo0ol000000ooooooo0000o`00001Nooooo`007?ooool00ol0
003oooooooooo`1?ooooo`;o00009oooool2o`0000?ooooo0_l00007ooooo`?o00000oooool2o`00
00Cooooo0ol00002ooooo`;o00000_ooool5o`000003ooooool0003o000000;o00001oooool2o`00
00Kooooo0_l0000Gooooo`;o000000?oooooo`000?l000003?ooool5o`0000;ooooo0ol000000ooo
oooo0000o`00000;ooooo`;o0000DOooool001cooooo00?o0000ooooooooool0Coooool2o`0000Wo
oooo0_l00003ooooo`;o00003_ooool2o`0001Kooooo0_l00003ooooo`;o00001?ooool3o`0000;o
oooo1_l00002ooooo`;o00000oooool2o`0002Oooooo0_l0000?ooooo`;o000000?oooooo`000?l0
00001?ooool4o`0000_ooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`1?ooooo`Co0000
1oooool2o`0000?ooooo0_l0000>ooooo`;o00004_ooool2o`0001Cooooo0ol00002ooooo`[o0000
00Coooooo`000?l0003o00001Oooool4o`0002cooooo0_l00004ooooo`;o0000H?ooool001cooooo
00?o0000ooooooooool0DOooool2o`0000[ooooo0_l00005ooooo`;o00006Oooool2o`0000;ooooo
0ol0000<ooooo`Co00002?ooool6o`000005ooooool0003o0000o`000?ooool00ol00005ooooo`Co
00004Oooool2o`0000Sooooo0_l0000<ooooo`;o0000JOooool001cooooo00?o0000ooooooooool0
F?ooool2o`0000?ooooo0_l00005ooooo`;o00000_ooool2o`0000gooooo0_l00006ooooo`;o0000
0_ooool3o`0000cooooo1?l00004ooooo`Co00000oooool2o`0000;ooooo0_l0000Kooooo`?o0000
00?oooooo`000?l000002?ooool2o`0000_ooooo0ol0001Yooooo`007?ooool00ol0003ooooooooo
o`1Booooo`;o00001?ooool2o`0000gooooo0ol0000=ooooo`?o00001oooool5o`0000Wooooo0_l0
0009ooooo`Co00000oooool2o`0000Gooooo0_l0000Hooooo`?o00002oooool2o`0000?ooooo0ol0
0004ooooo`?o00003oooool3o`0005Sooooo000Looooo`03o`000?oooooooooo05;ooooo0_l0000@
ooooo`;o000000?oooooo`000?l000000oooool2o`0000Wooooo0ol00007ooooo`;o00003?ooool2
o`00013ooooo0_l00004ooooo`Go00008Oooool2o`0000Kooooo2Ol0000@ooooo`?o0000F?ooool0
01cooooo0_l0001Uooooo`;o000000?oooooo`000?l000000oooool2o`0000;ooooo0_l00005oooo
o`?o00002?ooool2o`0000_ooooo0_l00002ooooo`;o00001Oooool2o`0000Cooooo0_l00005oooo
o`;o000000?oooooo`000?l000008Oooool2o`0000Kooooo0_l000000ooooooo0000o`000002o`00
017ooooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`1Oooooo`;o00001_ooool2o`0000Oo
oooo0_l0000@ooooo`;o00001Oooool2o`000003ooooool0003o000000Gooooo0_l00005ooooo`So
000000?oooooo`000?l000002Oooool2o`0002Gooooo0ol0000Eooooo`;o0000F_ooool001cooooo
00?o0000ooooooooool0GOooool4o`0000Sooooo1?l0000:ooooo`;o00002oooool3o`0000;ooooo
0_l000000ooooooo0000o`00000=ooooo`Go00000oooool2o`0000Cooooo0_l00003ooooo`;o0000
00?oooooo`000?l000007Oooool2o`0000?ooooo0ol0001aooooo`007?ooool00ol0003ooooooooo
o`1Mooooo`;o00002_ooool5o`0000Wooooo0ol0000:ooooo`So00001_ooool2o`000003ooooool0
003o000000;ooooo0_l0000>ooooo`;o00001_ooool2o`000003ooooool0003o000000_ooooo0_l0
000:ooooo`Ko00000_ooool2o`0007;ooooo000Looooo`03o`000?oooooooooo06;ooooo0_l00008
ooooo`;o00002_ooool2o`0000_ooooo1ol00006ooooo`;o000000?oooooo`000?l000000_ooool2
o`0001Cooooo0ol00002ooooo`;o00002oooool2o`0000Wooooo1ol00006ooooo`;o0000K_ooool0
01cooooo00?o0000ooooooooool0Foooool2o`0000Gooooo0_l0000Dooooo`;o00003Oooool4o`00
01Sooooo0_l0000:ooooo`?o00006?ooool4o`000003ooooool0003o000000;o00000oooool2o`00
0003ooooool0003o000006kooooo000Looooo`03o`000?oooooooooo05_ooooo0_l000000ooooooo
0000o`00000?ooooo`?o00001_ooool2o`0000oooooo0ol00004ooooo`;o00002?ooool2o`0000Oo
oooo0_l0000Eooooo`;o00003_ooool4o`000003ooooool0003o000000;o00000oooool2o`00077o
oooo000Looooo`03o`000?oooooooooo05kooooo0_l0000?ooooo`Go00002?ooool2o`0000_ooooo
0ol00004ooooo`;o00002?ooool4o`000003ooooool0003o000000;o00005oooool2o`0000Wooooo
0_l000000ooooooo0000o`000002o`0000;ooooo1Ol0001fooooo`007?ooool00ol0003ooooooooo
o`1Qooooo`;o00003oooool2o`0000Cooooo0_l00002ooooo`;o00006Oooool2o`0000;ooooo0ol0
00000ooooooo0000o`000002o`0000;ooooo0_l0000;ooooo`;o00004Oooool5o`0000;ooooo1Ol0
000@ooooo`?o0000IOooool001cooooo00?o0000ooooooooool0HOooool2o`0000Wooooo0_l00006
ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0001Wooooo1?l00003ooooo`;o00001Ooo
ool2o`0000;ooooo0_l00007ooooo`;o00004Oooool3o`000004ooooool0003o0000ooooo`?o0000
4_ooool3o`0006Gooooo000Looooo`03o`000?oooooooooo06;ooooo0_l00008ooooo`;o00001_oo
ool2o`000003ooooool0003o000001Oooooo0_l00007ooooo`?o00000_ooool2o`0000?ooooo0_l0
0004ooooo`;o00002?ooool2o`0000_ooooo1?l000000ooooooo0000o`000002ooooo`;o0000O_oo
ool001cooooo00?o0000ooooooooool0H_ooool2o`0000_ooooo0_l00005ooooo`?o00005oooool4
o`0000Kooooo0_l00007ooooo`;o00000oooool2o`000003ooooool0003o000000;o00001?ooool2
o`0000_ooooo1?l0000Hooooo`;o0000Joooool001cooooo00?o0000ooooooooool0Koooool2o`00
00Gooooo1_l0000Dooooo`Co00000oooool2o`0000[ooooo0ol00002ooooo`;o000000?oooooo`00
0?l000000_l00008ooooo`Co00000_ooool2o`0000Sooooo0_l0000Cooooo`;o0000Joooool001co
oooo00?o0000ooooooooool0NOooool3o`0001_ooooo0ol00009ooooo`Co00002?ooool3o`0000Co
oooo1Ol00002ooooo`;o00000_ooool2o`0000Cooooo0_l0000>ooooo`;o0000L?ooool00006oooo
ooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006
ooooo`03o`000?oooooooooo09Sooooo0_l00005ooooo`Co00000_ooool2o`0000;ooooo0_l00004
ooooo`?o00000_ooool5o`0000;ooooo0_l00004ooooo`;o00004_ooool4o`00073ooooo00001_oo
ooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40
1_ooool00ol0003oooooooooo`1Vooooo`;o0000=?ooool2o`000003ooooool0003o000000;o0000
1_ooool2o`0000Gooooo0ol000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00002ooooo`?o
00004oooool3o`00077ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo06Kooooo0_l00004ooooo`;o
00001Oooool2o`0002Oooooo0_l00005ooooo`;o00002oooool3o`0000Cooooo0_l00006ooooo`?o
00003Oooool2o`0007Sooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo
00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000K?ooool2o`0000;ooooo0_l000000ooooooo
0000o`00000^ooooo`;o000000Coooooo`000?l0003o00009_ooool2o`0007Sooooo00000ooooooo
0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Goc<c<o`000?l0003o0000olc<c006oooo
o`03o`000?oooooooooo073ooooo0_l00002ooooo`;o00008oooool2o`0000_ooooo0ol0000Poooo
o`Co0000O?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol@413o
^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0L_ooool4o`0002?ooooo0_l00006oooo
o`;o00003Oooool4o`0000gooooo0_l00002ooooo`So0000O?ooool00006oooooomgMgOoV9RHoooo
oonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0L_oo
ool2o`0000?ooooo0_l0000Xooooo`;o00003Oooool4o`0000?ooooo0_l00007ooooo`?o00000_oo
ool4o`00083ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@06ooooo`03o`000?oooooooooo07Oooooo0_l0000nooooo`;o00001oooool2o`0008Oo
oooo000Looooo`03o`000?oooooooooo07Oooooo0ol0003?ooooo`007?ooool00ol0003ooooooooo
o`1hooooo`;o0000coooool001cooooo00?o0000ooooooooool0N?ooool2o`0000;ooooo0_l0003;
ooooo`007?ooool00ol0003oooooooooo`1looooo`;o0000boooool001cooooo00?o0000oooooooo
ool0g_ooool2o`0006Wooooo000Looooo`03o`000?oooooooooo087ooooo0_l0001Kooooo`;o0000
JOooool001cooooo00?o0000ooooooooool0POooool2o`000<Kooooo000Looooo`03o`000?oooooo
oooo08Cooooo0_l00033ooooo`007?ooool00ol0003oooooooooo`22ooooo`Ko0000Boooool4o`00
07;ooooo000Looooo`03o`000?oooooooooo08;ooooo1_l0000=ooooo`;o000000?oooooo`000?l0
0000>?ooool5o`0007;ooooo000Looooo`03o`000?oooooooooo09Gooooo1Ol00002ooooo`;o0000
:_ooool3o`0000Oooooo0_l0001eooooo`007?ooool2o`0008Kooooo0_l00004ooooo`;o00001ooo
ool2o`000003ooooool0003o000000;ooooo0ol000000ooooooo0000o`00000Vooooo`Co0000O_oo
ool001cooooo00?o0000ooooooooool0QOooool2o`0000Cooooo0_l000000ooooooo0000o`000004
ooooo`;o00001Oooool2o`0000;ooooo0_l00003ooooo`?o00001Oooool2o`0001Wooooo0_l00020
ooooo`007?ooool00ol0003oooooooooo`2=ooooo`?o00000oooool2o`0000oooooo0ol00005oooo
o`Co000000Coooooo`000?l0003o0000UOooool001cooooo00?o0000ooooooooool0SOooool3o`00
00?ooooo0_l0000Iooooo`;o000000Goooooo`000?l0003o0000ooooo`03o`00097ooooo000Loooo
o`03o`000?oooooooooo0;Gooooo0ol0002Aooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooo
oom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Booooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooood[ooooo
000Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool0
0ol0003oooooooooo`05ooooo`?o0000oooooom:ooooo`005?ooool00ol0003oooooooooo`3ooooo
oe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0
oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Booooo`03oeEEEOmVIVKo
00000?ooooooE?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Gooooo00Co
410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0Eooooo`05oiRHV?l@413o0000oc8b<_o<
c<`01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo0_l000000ol@413oooooooooo`2>oooo
o`00Y_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l00009ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S801oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo08oooooo002Voooo
o`05o`000?ooooooooooooooool000007?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Go0000T?ooool00:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00003?ooool0
0onYZJWo410@ooooo`06ooooo`08ogMgMolb<S;ooooooooooom4A4CogMgMooooool0002Aooooo`00
Y_ooool01Ol0003oQhN7oooooonYZJWo000001[ooooo00?o410@o`000?nj^[X01?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00;ooooo00CogMgMoeEEEOoooooo0000TOooool00:Gooooo00?o410@o`00
0?mgMgL00_l000000onHV9Soooooooooo`0Iooooo`03okZj^_lQ8B7ooooo00?ooooo00?o0000oooo
ooooool01Oooool00omgMgOoc<c<o`00002Aooooo`00`oooool01Ol@413oV9RHoooooonj^[[o0000
00Cooooo00?o0000ooooooooool01Oooool00oo^k^koA4A4o`00002Aooooo`00`oooool01OnYZJWo
410@o`000?l@413oZJVY00Cooooo1?l00005ooooo`03ogMgMol0003ooooo093ooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(360) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.445 .66432 Mdot
.47832 .68023 Mdot
.68114 .46499 Mdot
.41516 .45488 Mdot
.60789 .2513 Mdot
.68516 .44449 Mdot
.65388 .61043 Mdot
.65188 .60791 Mdot
.6619 .44498 Mdot
.22753 .62188 Mdot
.69059 .60469 Mdot
.4273 .43973 Mdot
.66972 .61011 Mdot
.39124 .45037 Mdot
.48294 .44877 Mdot
.32176 .44489 Mdot
.44282 .71103 Mdot
.62414 .31679 Mdot
.32741 .43641 Mdot
.71221 .43443 Mdot
.25053 .43678 Mdot
.3987 .46052 Mdot
.4926 .64975 Mdot
.39439 .45182 Mdot
.37243 .48804 Mdot
.47706 .66252 Mdot
.45356 .65436 Mdot
.37994 .48586 Mdot
.37684 .40926 Mdot
.68427 .60069 Mdot
.56977 .47786 Mdot
.22488 .35888 Mdot
.36676 .50076 Mdot
.34713 .59884 Mdot
.66738 .58569 Mdot
.72922 .6338 Mdot
.69199 .40708 Mdot
.64078 .63295 Mdot
.67964 .58188 Mdot
.69106 .5933 Mdot
.69286 .59923 Mdot
.47555 .65904 Mdot
.66247 .64632 Mdot
.74438 .55913 Mdot
.39843 .44033 Mdot
.42483 .59211 Mdot
.71257 .54623 Mdot
.34168 .45125 Mdot
.47338 .70449 Mdot
.70047 .45614 Mdot
.48504 .27088 Mdot
.6471 .63039 Mdot
.51407 .59388 Mdot
.85598 .62718 Mdot
.66663 .6011 Mdot
.33211 .45103 Mdot
.65984 .41689 Mdot
.3659 .45026 Mdot
.41741 .47602 Mdot
.31589 .56838 Mdot
.37068 .46673 Mdot
.61647 .27972 Mdot
.44667 .64227 Mdot
.70726 .39798 Mdot
.66174 .44796 Mdot
.64573 .6365 Mdot
.49657 .70518 Mdot
.68122 .61048 Mdot
.39303 .41407 Mdot
.69776 .45521 Mdot
.35934 .41908 Mdot
.69038 .60745 Mdot
.47594 .64602 Mdot
.41005 .45054 Mdot
.62051 .77592 Mdot
.69238 .55324 Mdot
.73278 .43136 Mdot
.2863 .50633 Mdot
.55018 .26638 Mdot
.53145 .44171 Mdot
.40791 .45431 Mdot
.83253 .46547 Mdot
.48781 .40314 Mdot
.46831 .70047 Mdot
.50625 .6044 Mdot
.602 .67332 Mdot
.34826 .46814 Mdot
.5681 .48642 Mdot
.31261 .44057 Mdot
.64493 .3229 Mdot
.66147 .42609 Mdot
.45497 .70169 Mdot
.40504 .44598 Mdot
.40538 .42553 Mdot
.30513 .71852 Mdot
.36675 .40741 Mdot
.4141 .48098 Mdot
.55668 .60028 Mdot
.69169 .62669 Mdot
.42197 .39744 Mdot
.57633 .35486 Mdot
.50211 .56544 Mdot
.33379 .45281 Mdot
.6737 .42098 Mdot
.45592 .63509 Mdot
.35181 .49346 Mdot
.67166 .62036 Mdot
.40426 .4527 Mdot
.69125 .64246 Mdot
.48193 .70129 Mdot
.42351 .47256 Mdot
.60283 .27332 Mdot
.2881 .48749 Mdot
.48548 .65021 Mdot
.36651 .69642 Mdot
.38413 .47256 Mdot
.36092 .44345 Mdot
.48089 .67831 Mdot
.70754 .43254 Mdot
.80396 .4597 Mdot
.47625 .64829 Mdot
.69259 .59477 Mdot
.4489 .71189 Mdot
.32536 .51194 Mdot
.70907 .42668 Mdot
.5138 .56218 Mdot
.51617 .56024 Mdot
.39478 .28533 Mdot
.41252 .46237 Mdot
.26999 .39004 Mdot
.67822 .43111 Mdot
.48654 .66107 Mdot
.67808 .60348 Mdot
.34529 .40716 Mdot
.46017 .66797 Mdot
.65041 .61443 Mdot
.58488 .28325 Mdot
.63266 .29862 Mdot
.49458 .67078 Mdot
.37874 .72597 Mdot
.62617 .64211 Mdot
.69903 .62204 Mdot
.48247 .27273 Mdot
.46896 .70048 Mdot
.60402 .29509 Mdot
.65888 .62574 Mdot
.43914 .18716 Mdot
.41074 .4897 Mdot
.45836 .28525 Mdot
.83203 .49265 Mdot
.48557 .27112 Mdot
.23157 .45651 Mdot
.59942 .28134 Mdot
.64982 .61573 Mdot
.34826 .4302 Mdot
.46275 .68484 Mdot
.46396 .66533 Mdot
.37451 .41579 Mdot
.37737 .49525 Mdot
.38212 .44218 Mdot
.3648 .49796 Mdot
.58055 .56205 Mdot
.40377 .44667 Mdot
.4898 .80504 Mdot
.45636 .68291 Mdot
.36426 .49133 Mdot
.69707 .41757 Mdot
.41754 .37894 Mdot
.65563 .64424 Mdot
.41785 .46621 Mdot
.38022 .49329 Mdot
.39707 .4044 Mdot
.69283 .59316 Mdot
.61584 .78774 Mdot
.57528 .22883 Mdot
.65304 .57975 Mdot
.7422 .66266 Mdot
.68878 .42746 Mdot
.36234 .46576 Mdot
.5977 .30624 Mdot
.3956 .37898 Mdot
.40452 .43319 Mdot
.49107 .26741 Mdot
.40448 .48309 Mdot
.23323 .44674 Mdot
.35828 .5146 Mdot
.6045 .66347 Mdot
.47676 .78838 Mdot
.41539 .44714 Mdot
.24051 .60534 Mdot
.46732 .29187 Mdot
.64579 .50293 Mdot
.67783 .6002 Mdot
.69639 .44775 Mdot
.70432 .44045 Mdot
.63297 .61588 Mdot
.38178 .64063 Mdot
.21734 .59549 Mdot
.38444 .40564 Mdot
.50236 .56967 Mdot
.46067 .71927 Mdot
.60124 .28097 Mdot
.49262 .67214 Mdot
.82859 .44095 Mdot
.5471 .42932 Mdot
.54515 .48404 Mdot
.58406 .33121 Mdot
.70647 .45326 Mdot
.50695 .57036 Mdot
.6041 .30151 Mdot
.37767 .43431 Mdot
.48121 .70092 Mdot
.4707 .28727 Mdot
.37758 .37869 Mdot
.19645 .65957 Mdot
.45476 .65533 Mdot
.36358 .31344 Mdot
.66731 .60366 Mdot
.64879 .4151 Mdot
.34902 .46935 Mdot
.3807 .45998 Mdot
.4918 .69312 Mdot
.34748 .43645 Mdot
.52222 .47494 Mdot
.38845 .49255 Mdot
.70202 .39554 Mdot
.60306 .22941 Mdot
.62862 .6141 Mdot
.57432 .31438 Mdot
.48149 .64596 Mdot
.63998 .80935 Mdot
.68086 .41182 Mdot
.45 .42727 Mdot
.68741 .61584 Mdot
.587 .27572 Mdot
.67258 .41244 Mdot
.62788 .28208 Mdot
.42254 .45969 Mdot
.68419 .40419 Mdot
.61368 .27534 Mdot
.52999 .5079 Mdot
.36175 .4965 Mdot
.37232 .26536 Mdot
.65337 .62914 Mdot
.44917 .70374 Mdot
.38891 .42358 Mdot
.50829 .59832 Mdot
.439 .45298 Mdot
.4165 .31444 Mdot
.51479 .58599 Mdot
.49765 .5649 Mdot
.51467 .4194 Mdot
.59196 .31353 Mdot
.71672 .6992 Mdot
.56458 .50098 Mdot
.44229 .71078 Mdot
.40868 .43156 Mdot
.69489 .68257 Mdot
.64933 .62545 Mdot
.37211 .43831 Mdot
.66641 .6877 Mdot
.65664 .62491 Mdot
.36319 .44193 Mdot
.68531 .5926 Mdot
.45997 .67555 Mdot
.50892 .4614 Mdot
.43669 .69102 Mdot
.39515 .43227 Mdot
.68736 .59584 Mdot
.70012 .44266 Mdot
.47589 .66289 Mdot
.40342 .45607 Mdot
.40557 .47375 Mdot
.49885 .57911 Mdot
.40026 .49238 Mdot
.57377 .6195 Mdot
.34211 .45642 Mdot
.68139 .46797 Mdot
.37051 .4077 Mdot
.53502 .33227 Mdot
.65032 .28643 Mdot
.48977 .69004 Mdot
.51386 .58694 Mdot
.66533 .41271 Mdot
.51485 .49501 Mdot
.33919 .30357 Mdot
.39953 .44629 Mdot
.50887 .58811 Mdot
.39183 .30049 Mdot
.66115 .64418 Mdot
.30793 .45445 Mdot
.71631 .37716 Mdot
.66332 .42539 Mdot
.5048 .5686 Mdot
.39402 .38274 Mdot
.50041 .71176 Mdot
.33356 .42901 Mdot
.68621 .40684 Mdot
.43845 .69215 Mdot
.35238 .41523 Mdot
.69012 .54508 Mdot
.50455 .60111 Mdot
.69335 .62753 Mdot
.55609 .59417 Mdot
.35501 .44571 Mdot
.69317 .45612 Mdot
.46935 .6573 Mdot
.66182 .59959 Mdot
.48347 .64887 Mdot
.48609 .29006 Mdot
.38975 .31186 Mdot
.47448 .59898 Mdot
.59124 .32151 Mdot
.38939 .18611 Mdot
.65272 .57918 Mdot
.41226 .38784 Mdot
.66385 .38252 Mdot
.46162 .76983 Mdot
.67042 .42039 Mdot
.38808 .73574 Mdot
.66004 .42259 Mdot
.33524 .43618 Mdot
.67843 .44891 Mdot
.30461 .72767 Mdot
.39054 .48414 Mdot
.66282 .45223 Mdot
.5901 .53885 Mdot
.39563 .48241 Mdot
.4591 .66787 Mdot
.19314 .423 Mdot
.37299 .61518 Mdot
.37548 .6275 Mdot
.65983 .41247 Mdot
.39728 .7492 Mdot
.37306 .4838 Mdot
.33435 .41551 Mdot
.46626 .68042 Mdot
.43852 .4589 Mdot
.60354 .31961 Mdot
.62748 .30537 Mdot
.46136 .22365 Mdot
.25578 .34754 Mdot
.37359 .65683 Mdot
.46848 .66552 Mdot
.58631 .23295 Mdot
.60905 .78047 Mdot
.50552 .60066 Mdot
.65119 .60899 Mdot
.66009 .76231 Mdot
.32667 .41779 Mdot
.52461 .65409 Mdot
.51979 .47359 Mdot
.44235 .68948 Mdot
.48005 .56394 Mdot
.65892 .6008 Mdot
.37303 .62718 Mdot
.20808 .56368 Mdot
.38147 .44072 Mdot
.66128 .6378 Mdot
.43367 .47141 Mdot
.56507 .49055 Mdot
.37548 .28233 Mdot
.74376 .48058 Mdot
.39431 .43303 Mdot
.66808 .74498 Mdot
.39802 .42861 Mdot
.40824 .2815 Mdot
.37451 .43361 Mdot
.46124 .66105 Mdot
.38611 .3982 Mdot
.56112 .50763 Mdot
.45432 .15006 Mdot
.54351 .41845 Mdot
.62688 .29288 Mdot
.39022 .45318 Mdot
.37605 .44882 Mdot
.61943 .2806 Mdot
.447 .6957 Mdot
.39312 .42229 Mdot
.74523 .6927 Mdot
.40644 .449 Mdot
.6428 .62854 Mdot
.4587 .33472 Mdot
.24769 .33645 Mdot
.35989 .4731 Mdot
.50014 .71151 Mdot
.69783 .62326 Mdot
.67997 .62474 Mdot
.29973 .44524 Mdot
.6512 .6294 Mdot
.34903 .43089 Mdot
.45949 .33487 Mdot
.50184 .68255 Mdot
.30253 .43742 Mdot
.44379 .6845 Mdot
.64617 .2117 Mdot
.65088 .62201 Mdot
.50614 .59559 Mdot
.37719 .66946 Mdot
.66305 .61842 Mdot
.61359 .23069 Mdot
.37988 .39691 Mdot
.34492 .38296 Mdot
.45349 .72968 Mdot
.69156 .45562 Mdot
.51138 .57733 Mdot
.66516 .60052 Mdot
.39895 .44294 Mdot
.346 .47921 Mdot
.65333 .63256 Mdot
.25245 .5177 Mdot
.57064 .47772 Mdot
.39768 .4329 Mdot
.45179 .67788 Mdot
.48461 .65929 Mdot
.31625 .45881 Mdot
.39606 .42655 Mdot
.69124 .44547 Mdot
.50951 .58778 Mdot
.51353 .58326 Mdot
.51096 .5584 Mdot
.6552 .4119 Mdot
.39553 .18205 Mdot
.69784 .62574 Mdot
.23111 .35188 Mdot
.61156 .74628 Mdot
.29923 .47314 Mdot
.70427 .42311 Mdot
.37906 .46477 Mdot
.3385 .46207 Mdot
.68382 .59446 Mdot
.357 .22996 Mdot
.33897 .41061 Mdot
.43894 .6799 Mdot
.65158 .63393 Mdot
.43557 .46398 Mdot
.60772 .61858 Mdot
.59223 .28112 Mdot
.36846 .67283 Mdot
.6473 .62766 Mdot
.49926 .67902 Mdot
.64718 .6278 Mdot
.37772 .44669 Mdot
.39802 .38374 Mdot
.44213 .68508 Mdot
.61899 .26038 Mdot
.38293 .41648 Mdot
.36515 .43596 Mdot
.63177 .37694 Mdot
.62376 .7732 Mdot
.59361 .24902 Mdot
.33786 .44134 Mdot
.34777 .38013 Mdot
.62094 .26399 Mdot
.36531 .42378 Mdot
.3633 .41171 Mdot
.26833 .39156 Mdot
.6654 .6494 Mdot
.58891 .26408 Mdot
.4304 .16225 Mdot
.4525 .65707 Mdot
.57593 .61399 Mdot
.50684 .56289 Mdot
.66536 .57539 Mdot
.50879 .47797 Mdot
.50374 .58045 Mdot
.63401 .72487 Mdot
.52019 .86011 Mdot
.50974 .57958 Mdot
.67006 .3955 Mdot
.32907 .72507 Mdot
.36767 .41117 Mdot
.39088 .42801 Mdot
.59962 .31713 Mdot
.48011 .68767 Mdot
.49531 .79664 Mdot
.65704 .57836 Mdot
.39212 .46894 Mdot
.46461 .64479 Mdot
.60578 .671 Mdot
.50194 .5754 Mdot
.59321 .30034 Mdot
.60705 .25667 Mdot
.38813 .42468 Mdot
.36424 .30217 Mdot
.47285 .66195 Mdot
.40333 .456 Mdot
.35921 .44337 Mdot
.68915 .39914 Mdot
.48226 .69896 Mdot
.69342 .41534 Mdot
.49639 .59788 Mdot
.35439 .76782 Mdot
.77009 .64342 Mdot
.65796 .62982 Mdot
.46578 .53919 Mdot
.62916 .6128 Mdot
.68408 .52508 Mdot
.51032 .58704 Mdot
.40147 .45752 Mdot
.50244 .65888 Mdot
.40448 .45431 Mdot
.40604 .44787 Mdot
.39372 .43587 Mdot
.37258 .65886 Mdot
.54936 .27385 Mdot
.60053 .31117 Mdot
.35069 .44549 Mdot
.66615 .40146 Mdot
.61117 .65885 Mdot
.2425 .66113 Mdot
.38536 .45581 Mdot
.36118 .44217 Mdot
.49463 .71522 Mdot
.4161 .48734 Mdot
.6567 .61873 Mdot
.44184 .69198 Mdot
.33713 .46584 Mdot
.58422 .3543 Mdot
.38649 .42076 Mdot
.46074 .57059 Mdot
.64555 .60613 Mdot
.41713 .40413 Mdot
.39009 .50841 Mdot
.51044 .58824 Mdot
.51044 .57688 Mdot
.49458 .56234 Mdot
.64382 .63226 Mdot
.68443 .3991 Mdot
.72761 .42462 Mdot
.40947 .50372 Mdot
.34277 .43681 Mdot
.36882 .38047 Mdot
.65054 .46559 Mdot
.58108 .50077 Mdot
.3821 .7156 Mdot
.42975 .47598 Mdot
.64811 .43034 Mdot
.55711 .59953 Mdot
.26104 .47712 Mdot
.44697 .69954 Mdot
.64732 .38916 Mdot
.68065 .6197 Mdot
.61158 .26916 Mdot
.4459 .24979 Mdot
.46869 .65179 Mdot
.50671 .67406 Mdot
.69202 .43759 Mdot
.46576 .3436 Mdot
.88507 .5827 Mdot
.6737 .43071 Mdot
.5379 .48353 Mdot
.46697 .67474 Mdot
.36582 .49995 Mdot
.40954 .30051 Mdot
.46117 .35141 Mdot
.65406 .44306 Mdot
.4065 .47259 Mdot
.67559 .25119 Mdot
.69046 .44633 Mdot
.3631 .37782 Mdot
.66029 .41089 Mdot
.6839 .63689 Mdot
.67838 .42506 Mdot
.45432 .64815 Mdot
.41137 .46276 Mdot
.86545 .61319 Mdot
.4978 .42773 Mdot
.4015 .46916 Mdot
.64383 .62559 Mdot
.66793 .52104 Mdot
.37687 .4401 Mdot
.61564 .3178 Mdot
.67311 .39616 Mdot
.71033 .50538 Mdot
.34372 .42277 Mdot
.67899 .45049 Mdot
.50979 .67519 Mdot
.63679 .40058 Mdot
.58242 .35776 Mdot
.51321 .57878 Mdot
.4592 .68092 Mdot
.70822 .57445 Mdot
.69414 .59871 Mdot
.33046 .46541 Mdot
.35964 .45318 Mdot
.45408 .68664 Mdot
.51689 .50618 Mdot
.31014 .47093 Mdot
.40671 .45166 Mdot
.69481 .42577 Mdot
.7178 .42585 Mdot
.48137 .44052 Mdot
.68123 .41025 Mdot
.34336 .38213 Mdot
.45437 .67795 Mdot
.33252 .43121 Mdot
.48115 .65221 Mdot
.40673 .42959 Mdot
.60343 .59971 Mdot
.45808 .70635 Mdot
.45129 .44003 Mdot
.41264 .46911 Mdot
.41011 .72078 Mdot
.35481 .45107 Mdot
.40224 .43793 Mdot
.71272 .41218 Mdot
.61722 .28945 Mdot
.31224 .46386 Mdot
.66996 .54663 Mdot
.60759 .262 Mdot
.24944 .49597 Mdot
.70874 .42565 Mdot
.5961 .25906 Mdot
.43539 .23038 Mdot
.51446 .58504 Mdot
.62135 .29371 Mdot
.52503 .56999 Mdot
.66129 .6325 Mdot
.48375 .62397 Mdot
.40223 .48029 Mdot
.34918 .76302 Mdot
.57165 .47923 Mdot
.49971 .58564 Mdot
.37392 .42364 Mdot
.37504 .46141 Mdot
.46563 .64451 Mdot
.82911 .44746 Mdot
.72227 .42646 Mdot
.38848 .49715 Mdot
.46864 .65013 Mdot
.83262 .47722 Mdot
.65931 .4504 Mdot
.58878 .30294 Mdot
.67497 .57895 Mdot
.43218 .70811 Mdot
.50502 .59762 Mdot
.65027 .62033 Mdot
.73111 .42023 Mdot
.49487 .26541 Mdot
.33632 .42588 Mdot
.70054 .41913 Mdot
.48671 .27056 Mdot
.30658 .45922 Mdot
.63164 .6222 Mdot
.71075 .56603 Mdot
.4636 .70134 Mdot
.65303 .63278 Mdot
.61106 .31566 Mdot
.45152 .71546 Mdot
.4433 .68797 Mdot
.66007 .6219 Mdot
.45308 .79099 Mdot
.39328 .30098 Mdot
.64567 .59637 Mdot
.4237 .31712 Mdot
.48818 .27127 Mdot
.50021 .59256 Mdot
.59431 .29988 Mdot
.5984 .22741 Mdot
.47639 .65975 Mdot
.65416 .76593 Mdot
.48562 .26995 Mdot
.41335 .48227 Mdot
.61454 .27445 Mdot
.60039 .65015 Mdot
.71982 .64333 Mdot
.65331 .62023 Mdot
.62982 .38698 Mdot
.6165 .27229 Mdot
.42014 .45596 Mdot
.28213 .27228 Mdot
.37694 .48039 Mdot
.65952 .62707 Mdot
.52081 .47412 Mdot
.48728 .68881 Mdot
.65948 .64493 Mdot
.52203 .47423 Mdot
.33632 .4511 Mdot
.3847 .47457 Mdot
.55159 .29483 Mdot
.47322 .70705 Mdot
.49766 .5962 Mdot
.40804 .46356 Mdot
.36464 .445 Mdot
.32933 .46944 Mdot
.29771 .3017 Mdot
.35987 .53842 Mdot
.33959 .48363 Mdot
.64424 .43061 Mdot
.39404 .38019 Mdot
.39773 .49645 Mdot
.49815 .71691 Mdot
.56433 .34393 Mdot
.49446 .5941 Mdot
.38573 .42716 Mdot
.39529 .43176 Mdot
.6794 .58259 Mdot
.39411 .30043 Mdot
.46423 .35397 Mdot
.69339 .46416 Mdot
.70103 .47252 Mdot
.41127 .42379 Mdot
.45963 .69003 Mdot
.58337 .30513 Mdot
.30936 .41159 Mdot
.44089 .67543 Mdot
.41091 .42684 Mdot
.67819 .39574 Mdot
.50878 .58364 Mdot
.31261 .40222 Mdot
.61208 .2803 Mdot
.62865 .6432 Mdot
.25541 .4935 Mdot
.70102 .43686 Mdot
.36156 .48167 Mdot
.72716 .44834 Mdot
.66939 .44169 Mdot
.49823 .58019 Mdot
.43326 .41389 Mdot
.46206 .67144 Mdot
.49891 .67612 Mdot
.53111 .30667 Mdot
.65788 .4076 Mdot
.62376 .45116 Mdot
.67256 .63888 Mdot
.35222 .44278 Mdot
.65259 .66414 Mdot
.49604 .67894 Mdot
.39419 .28473 Mdot
.60183 .25593 Mdot
.65525 .62215 Mdot
.52358 .58009 Mdot
.45226 .70505 Mdot
.49757 .67159 Mdot
.40298 .44421 Mdot
.39243 .46053 Mdot
.66577 .50834 Mdot
.4614 .28961 Mdot
.68097 .58998 Mdot
.58824 .28881 Mdot
.68938 .46365 Mdot
.34066 .42981 Mdot
.46951 .69803 Mdot
.25364 .32139 Mdot
.3551 .44766 Mdot
.66572 .40206 Mdot
.47767 .67786 Mdot
.59481 .31065 Mdot
.60955 .31417 Mdot
.41345 .45168 Mdot
.23566 .44492 Mdot
.66713 .61884 Mdot
.45932 .66592 Mdot
.42199 .69564 Mdot
.34817 .44701 Mdot
.38931 .45656 Mdot
.34483 .51831 Mdot
.6392 .63791 Mdot
.34962 .50203 Mdot
.62554 .27289 Mdot
.49116 .6601 Mdot
.40598 .46328 Mdot
.61766 .28058 Mdot
.52514 .65868 Mdot
.50457 .58368 Mdot
.67178 .45385 Mdot
.61982 .31536 Mdot
.60965 .29313 Mdot
.60081 .26238 Mdot
.66205 .76047 Mdot
.50763 .61943 Mdot
.54798 .20385 Mdot
.40954 .47018 Mdot
.48884 .27153 Mdot
.31849 .45604 Mdot
.66467 .64264 Mdot
.68714 .45627 Mdot
.39194 .43928 Mdot
.40931 .47102 Mdot
.26187 .49356 Mdot
.32434 .44235 Mdot
.32777 .42914 Mdot
.48953 .68589 Mdot
.42096 .70013 Mdot
.69988 .44693 Mdot
.83313 .50999 Mdot
.19378 .35913 Mdot
.39018 .40674 Mdot
.46439 .34204 Mdot
.45045 .70121 Mdot
.67753 .58055 Mdot
.42172 .31194 Mdot
.68813 .66706 Mdot
.48606 .67107 Mdot
.33625 .43348 Mdot
.27619 .51119 Mdot
.61227 .26635 Mdot
.38084 .4444 Mdot
.68193 .60532 Mdot
.38136 .44327 Mdot
.64672 .63533 Mdot
.39769 .73888 Mdot
.47488 .36674 Mdot
.40247 .48267 Mdot
.36689 .40765 Mdot
.26563 .41256 Mdot
.38779 .45798 Mdot
.75285 .46465 Mdot
.47367 .6792 Mdot
.44735 .42677 Mdot
.33078 .44929 Mdot
.36458 .61294 Mdot
.36252 .43015 Mdot
.49945 .49959 Mdot
.36869 .4691 Mdot
.3768 .22019 Mdot
.42064 .46873 Mdot
.36414 .46754 Mdot
.66606 .5937 Mdot
.68713 .58851 Mdot
.43413 .74661 Mdot
.49463 .58422 Mdot
.6029 .65965 Mdot
.36347 .43677 Mdot
.70838 .45292 Mdot
.36076 .35071 Mdot
.61393 .29164 Mdot
.49023 .66111 Mdot
.63967 .85595 Mdot
.69235 .63395 Mdot
.66396 .39929 Mdot
.55756 .48403 Mdot
.6443 .41504 Mdot
.66399 .38371 Mdot
.44019 .72952 Mdot
.59373 .29646 Mdot
.39123 .42272 Mdot
.35461 .59771 Mdot
.64203 .76062 Mdot
.3471 .44702 Mdot
.69365 .47074 Mdot
.32365 .35512 Mdot
.52481 .2951 Mdot
.61468 .32409 Mdot
.59849 .29076 Mdot
.66114 .60259 Mdot
.6881 .46159 Mdot
.42934 .4792 Mdot
.59585 .25889 Mdot
.69337 .4504 Mdot
.52329 .57501 Mdot
.55569 .32594 Mdot
.47105 .66134 Mdot
.39472 .74592 Mdot
.42169 .60352 Mdot
.69789 .621 Mdot
.67695 .54977 Mdot
.49323 .63374 Mdot
.43849 .70334 Mdot
.49624 .57116 Mdot
.64985 .43234 Mdot
.48433 .62559 Mdot
.41097 .45822 Mdot
.37777 .37854 Mdot
.39002 .42494 Mdot
.59485 .31477 Mdot
.3671 .42638 Mdot
.68719 .45089 Mdot
.66023 .59392 Mdot
.66277 .42166 Mdot
.65424 .60865 Mdot
.2064 .39194 Mdot
.41778 .46065 Mdot
.392 .45582 Mdot
.45987 .33626 Mdot
.49625 .67082 Mdot
.34161 .60312 Mdot
.66372 .40403 Mdot
.66094 .41605 Mdot
.33183 .44209 Mdot
.46374 .71631 Mdot
.59462 .24467 Mdot
.43749 .32064 Mdot
.36661 .46579 Mdot
.47327 .68128 Mdot
.33159 .43911 Mdot
.6229 .5579 Mdot
.48763 .41555 Mdot
.48989 .64992 Mdot
.45905 .14814 Mdot
.41484 .469 Mdot
.44054 .43354 Mdot
.4403 .48311 Mdot
.28827 .31661 Mdot
.31031 .45805 Mdot
.44965 .66046 Mdot
.39733 .4962 Mdot
.4637 .69219 Mdot
.66825 .43523 Mdot
.67072 .64509 Mdot
.46516 .68739 Mdot
.38896 .48184 Mdot
.19707 .3557 Mdot
.66357 .59021 Mdot
.38623 .44444 Mdot
.6796 .5957 Mdot
.46282 .63229 Mdot
.48373 .68947 Mdot
.52379 .56649 Mdot
.53956 .48334 Mdot
.65974 .62003 Mdot
.34319 .43763 Mdot
.61955 .78209 Mdot
.333 .42931 Mdot
.69996 .47173 Mdot
.36858 .40424 Mdot
.4062 .4207 Mdot
.39619 .1762 Mdot
.51102 .50422 Mdot
.78004 .63489 Mdot
.61348 .64634 Mdot
.60866 .79016 Mdot
.45993 .73191 Mdot
.61551 .32341 Mdot
.47036 .5491 Mdot
.51727 .5776 Mdot
.64467 .43845 Mdot
.3963 .44094 Mdot
.53308 .64743 Mdot
.63884 .60819 Mdot
.61698 .29899 Mdot
.40401 .48327 Mdot
.63912 .43016 Mdot
.45576 .53997 Mdot
.65168 .61934 Mdot
.47597 .65833 Mdot
.49004 .67298 Mdot
.54821 .26499 Mdot
.40415 .46521 Mdot
.39663 .46004 Mdot
.66706 .58669 Mdot
.39432 .51969 Mdot
.59706 .26706 Mdot
.59003 .53714 Mdot
.68298 .60408 Mdot
.48818 .41215 Mdot
.47666 .70651 Mdot
.3768 .46296 Mdot
.45651 .33503 Mdot
.55593 .80457 Mdot
.25561 .65902 Mdot
.60272 .28377 Mdot
.35008 .30409 Mdot
.45093 .65916 Mdot
.67687 .60221 Mdot
.44878 .22711 Mdot
.36732 .39618 Mdot
.3714 .45869 Mdot
.32603 .30071 Mdot
.43486 .32002 Mdot
.55379 .48616 Mdot
.31583 .50157 Mdot
.42939 .30057 Mdot
.33194 .44053 Mdot
.34508 .47786 Mdot
.41384 .42807 Mdot
.36528 .40449 Mdot
.47048 .68864 Mdot
.36621 .62726 Mdot
.6858 .4355 Mdot
.26256 .65097 Mdot
.67836 .4807 Mdot
.3738 .48329 Mdot
.33535 .44355 Mdot
.28329 .63272 Mdot
.39515 .32991 Mdot
.47296 .67082 Mdot
.44659 .72434 Mdot
.69962 .61079 Mdot
.32697 .4362 Mdot
.66215 .4038 Mdot
.43925 .48344 Mdot
.66696 .44631 Mdot
.47199 .68715 Mdot
.69847 .40542 Mdot
.70289 .58749 Mdot
.69995 .41795 Mdot
.64655 .43145 Mdot
.65042 .60224 Mdot
.46738 .70882 Mdot
.35907 .45982 Mdot
.64905 .60411 Mdot
.59162 .24671 Mdot
.59625 .31547 Mdot
.42496 .66146 Mdot
.35585 .49765 Mdot
.33574 .408 Mdot
.70631 .55247 Mdot
.68882 .40385 Mdot
.45126 .35654 Mdot
.46092 .70577 Mdot
.58468 .30766 Mdot
.46753 .69268 Mdot
.53431 .2432 Mdot
.60656 .28454 Mdot
.5077 .60264 Mdot
.40785 .25387 Mdot
.62817 .6087 Mdot
.41074 .41245 Mdot
.42077 .69563 Mdot
.66425 .44299 Mdot
.6448 .63037 Mdot
.60748 .65503 Mdot
.38053 .49675 Mdot
.48018 .61308 Mdot
.44714 .64636 Mdot
.51486 .58177 Mdot
.67865 .60462 Mdot
.41494 .63125 Mdot
.39812 .47029 Mdot
.6276 .61396 Mdot
.37281 .40472 Mdot
.37051 .71043 Mdot
.68347 .49575 Mdot
.54818 .61182 Mdot
.33409 .43802 Mdot
.65868 .45033 Mdot
.33309 .43909 Mdot
.35201 .73761 Mdot
.41303 .26956 Mdot
.41291 .42505 Mdot
.37579 .32222 Mdot
.69981 .5399 Mdot
.46826 .69862 Mdot
.30815 .41773 Mdot
.49965 .58899 Mdot
.35385 .47888 Mdot
.13115 .52891 Mdot
.62003 .28682 Mdot
.5713 .32224 Mdot
.39583 .48093 Mdot
.40667 .45609 Mdot
.25618 .48593 Mdot
.39545 .73149 Mdot
.52208 .56297 Mdot
.36978 .45258 Mdot
.29849 .31951 Mdot
.66467 .59616 Mdot
.35185 .41424 Mdot
.40248 .43386 Mdot
.64987 .49193 Mdot
.67036 .59494 Mdot
.70488 .41797 Mdot
.51519 .58331 Mdot
.71637 .43408 Mdot
.61152 .25347 Mdot
.35869 .31139 Mdot
.36088 .28677 Mdot
.48484 .42149 Mdot
.62094 .31301 Mdot
.36289 .47875 Mdot
.54971 .60235 Mdot
.39538 .4762 Mdot
.59913 .2981 Mdot
.68444 .60069 Mdot
.47091 .68189 Mdot
.384 .73354 Mdot
.49957 .57302 Mdot
.35035 .46113 Mdot
.60027 .32519 Mdot
.46287 .68243 Mdot
.52687 .81617 Mdot
.47796 .68885 Mdot
.65594 .61189 Mdot
.63315 .61935 Mdot
.61062 .28735 Mdot
.46777 .69346 Mdot
.71574 .42581 Mdot
.65898 .66021 Mdot
.42773 .43226 Mdot
.70424 .59017 Mdot
.47993 .63434 Mdot
.48234 .64146 Mdot
.50051 .69443 Mdot
.33218 .45607 Mdot
.41874 .33253 Mdot
.33305 .51739 Mdot
.66593 .58815 Mdot
.64199 .44108 Mdot
.45283 .28448 Mdot
.35323 .56846 Mdot
.47984 .38879 Mdot
.31334 .41127 Mdot
.36865 .42564 Mdot
.38607 .42422 Mdot
.33392 .47888 Mdot
.57249 .54556 Mdot
.41755 .45927 Mdot
.68261 .59247 Mdot
.67682 .44426 Mdot
.3682 .46458 Mdot
.50457 .59211 Mdot
.57902 .4982 Mdot
.58867 .26306 Mdot
.36658 .67647 Mdot
.41896 .68034 Mdot
.46428 .68231 Mdot
.68733 .40848 Mdot
.70368 .40858 Mdot
.58489 .28362 Mdot
.64778 .6196 Mdot
.48158 .6862 Mdot
.38256 .21572 Mdot
.60761 .2643 Mdot
.38384 .42709 Mdot
.4591 .33558 Mdot
.27253 .33363 Mdot
.37719 .41405 Mdot
.39165 .43419 Mdot
.49421 .58997 Mdot
.65655 .40635 Mdot
.2446 .67871 Mdot
.46579 .79097 Mdot
.61561 .287 Mdot
.5882 .27855 Mdot
.50152 .69817 Mdot
.35361 .43643 Mdot
.67074 .6183 Mdot
.38584 .30097 Mdot
.6804 .53563 Mdot
.59848 .6678 Mdot
.68313 .5249 Mdot
.38262 .41996 Mdot
.34275 .68305 Mdot
.38434 .40164 Mdot
.45891 .63262 Mdot
.49641 .69055 Mdot
.47061 .66699 Mdot
.66157 .59726 Mdot
.49724 .26424 Mdot
.69315 .60207 Mdot
.56081 .59458 Mdot
.45542 .6585 Mdot
.52569 .49629 Mdot
.66071 .4142 Mdot
.31971 .45098 Mdot
.59487 .29679 Mdot
.62883 .34972 Mdot
.31283 .40771 Mdot
.35265 .30635 Mdot
.70422 .42276 Mdot
.4547 .70908 Mdot
.31983 .45594 Mdot
.61323 .66238 Mdot
.47113 .34348 Mdot
.71211 .5277 Mdot
.53585 .6383 Mdot
.6165 .27815 Mdot
.2257 .61056 Mdot
.59891 .26894 Mdot
.65593 .62315 Mdot
.41521 .46586 Mdot
.35513 .43779 Mdot
.40219 .4372 Mdot
.3531 .40382 Mdot
.66689 .59959 Mdot
.4259 .43157 Mdot
.53452 .33158 Mdot
.51959 .56554 Mdot
.56711 .51676 Mdot
.61533 .3095 Mdot
.67003 .64018 Mdot
.67214 .44303 Mdot
.49951 .56333 Mdot
.58981 .32032 Mdot
.32206 .46481 Mdot
.3902 .4803 Mdot
.52063 .56473 Mdot
.30188 .44187 Mdot
.32387 .42222 Mdot
.68752 .44181 Mdot
.56607 .49354 Mdot
.59469 .25464 Mdot
.60062 .27675 Mdot
.66054 .6358 Mdot
.46719 .69333 Mdot
.59175 .2604 Mdot
.6705 .46664 Mdot
.34772 .41676 Mdot
.37562 .40488 Mdot
.47982 .6358 Mdot
.48902 .26855 Mdot
.58843 .26335 Mdot
.34606 .50018 Mdot
.49175 .65602 Mdot
.44509 .6489 Mdot
.3708 .45256 Mdot
.42884 .45376 Mdot
.49098 .72126 Mdot
.58574 .28826 Mdot
.66401 .6379 Mdot
.49707 .3986 Mdot
.69249 .63113 Mdot
.47144 .65682 Mdot
.38377 .37827 Mdot
.46666 .71108 Mdot
.37763 .49656 Mdot
.78921 .66402 Mdot
.41815 .45577 Mdot
.42192 .55727 Mdot
.58436 .44367 Mdot
.65861 .41362 Mdot
.65295 .42395 Mdot
.5086 .58624 Mdot
.44006 .68021 Mdot
.32786 .389 Mdot
.59216 .29151 Mdot
.60943 .7895 Mdot
.50232 .71316 Mdot
.64713 .43285 Mdot
.66892 .39695 Mdot
.68143 .59863 Mdot
.36481 .42736 Mdot
.37759 .46508 Mdot
.70041 .4172 Mdot
.65326 .52873 Mdot
.45647 .69698 Mdot
.39679 .45964 Mdot
.33477 .47692 Mdot
.684 .43759 Mdot
.68525 .573 Mdot
.48888 .62917 Mdot
.3329 .46004 Mdot
.40788 .27484 Mdot
.65174 .6416 Mdot
.3478 .46969 Mdot
.40771 .40972 Mdot
.61123 .29689 Mdot
.34273 .30122 Mdot
.48303 .27283 Mdot
.69961 .62605 Mdot
.51065 .59088 Mdot
.37722 .4156 Mdot
.65643 .42017 Mdot
.32313 .4765 Mdot
.39491 .83223 Mdot
.52058 .57143 Mdot
.39657 .46922 Mdot
.41479 .50407 Mdot
.48073 .65159 Mdot
.40294 .45863 Mdot
.60413 .59435 Mdot
.6913 .41957 Mdot
.39522 .47027 Mdot
.23982 .45575 Mdot
.68125 .59929 Mdot
.30935 .41548 Mdot
.61525 .27051 Mdot
.54244 .48735 Mdot
.19459 .42014 Mdot
.64864 .46393 Mdot
.62191 .30251 Mdot
.36252 .43208 Mdot
.69843 .46123 Mdot
.67813 .57901 Mdot
.40583 .54056 Mdot
.35585 .47469 Mdot
.69691 .62031 Mdot
.6555 .59899 Mdot
.61294 .28378 Mdot
.75742 .74298 Mdot
.41709 .43077 Mdot
.38261 .4496 Mdot
.66072 .80077 Mdot
.48653 .72691 Mdot
.38502 .44294 Mdot
.35868 .44421 Mdot
.65336 .62932 Mdot
.50529 .23635 Mdot
.34995 .30484 Mdot
.58723 .54001 Mdot
.65144 .63985 Mdot
.7168 .45045 Mdot
.69764 .42354 Mdot
.62389 .29632 Mdot
.47837 .67758 Mdot
.58561 .30728 Mdot
.68166 .42608 Mdot
.3966 .43446 Mdot
.67898 .62968 Mdot
.20049 .51603 Mdot
.64314 .61306 Mdot
.64977 .45974 Mdot
.45972 .63265 Mdot
.31886 .73653 Mdot
.42217 .84913 Mdot
.44851 .5468 Mdot
.63213 .63146 Mdot
.61394 .29198 Mdot
.47591 .7976 Mdot
.36749 .46477 Mdot
.35059 .7226 Mdot
.38124 .44625 Mdot
.52877 .66064 Mdot
.68869 .45502 Mdot
.52376 .57311 Mdot
.37846 .49684 Mdot
.34698 .30584 Mdot
.6499 .60654 Mdot
.67972 .61788 Mdot
.39651 .49617 Mdot
.65679 .61463 Mdot
.38544 .46785 Mdot
.67916 .44077 Mdot
.77896 .68567 Mdot
.37198 .47308 Mdot
.44852 .44234 Mdot
.62486 .6265 Mdot
.4169 .67099 Mdot
.7254 .44105 Mdot
.35298 .64822 Mdot
.61045 .67328 Mdot
.67004 .61712 Mdot
.37025 .66367 Mdot
.68144 .40505 Mdot
.49796 .56432 Mdot
.71936 .43961 Mdot
.37851 .454 Mdot
.37799 .41921 Mdot
.334 .48024 Mdot
.35996 .4398 Mdot
.32655 .70699 Mdot
.32084 .42554 Mdot
.2428 .56224 Mdot
.40935 .46997 Mdot
.42962 .55117 Mdot
.68994 .59889 Mdot
.44015 .43535 Mdot
.51175 .40286 Mdot
.41669 .44364 Mdot
.4525 .72905 Mdot
.67732 .63857 Mdot
.70554 .6854 Mdot
.66717 .59775 Mdot
.66164 .42304 Mdot
.65085 .60896 Mdot
.41182 .48176 Mdot
.48327 .6595 Mdot
.67853 .41456 Mdot
.44914 .53997 Mdot
.64722 .44879 Mdot
.40146 .46908 Mdot
.62736 .60163 Mdot
.67387 .39962 Mdot
.34463 .40073 Mdot
.48509 .66176 Mdot
.33467 .2749 Mdot
.47863 .61878 Mdot
.39967 .45113 Mdot
.3946 .44639 Mdot
.52072 .56261 Mdot
.64984 .61551 Mdot
.47201 .71129 Mdot
.63815 .48729 Mdot
.58653 .31386 Mdot
.47648 .67087 Mdot
.44081 .48312 Mdot
.46619 .34022 Mdot
.48526 .65001 Mdot
.286 .32653 Mdot
.65723 .62605 Mdot
.46967 .64757 Mdot
.42366 .50744 Mdot
.25946 .64425 Mdot
.60091 .27292 Mdot
.71457 .41865 Mdot
.44244 .3084 Mdot
.69613 .42218 Mdot
.60689 .60822 Mdot
.70376 .39676 Mdot
.67376 .59258 Mdot
.34473 .35151 Mdot
.52183 .47512 Mdot
.6393 .61506 Mdot
.6203 .62691 Mdot
.68975 .43204 Mdot
.35192 .49446 Mdot
.56331 .50625 Mdot
.33416 .38445 Mdot
.39 .37503 Mdot
.68735 .63788 Mdot
.46261 .6497 Mdot
.45024 .71407 Mdot
.4464 .41907 Mdot
.49151 .6772 Mdot
.67226 .42509 Mdot
.48306 .42943 Mdot
.37753 .66877 Mdot
.6884 .60584 Mdot
.56813 .48491 Mdot
.33429 .44631 Mdot
.68183 .4511 Mdot
.66996 .42668 Mdot
.65597 .59973 Mdot
.29062 .68019 Mdot
.35364 .37895 Mdot
.47087 .74046 Mdot
.46436 .65269 Mdot
.4796 .65006 Mdot
.4848 .69964 Mdot
.49765 .26183 Mdot
.64532 .63068 Mdot
.44245 .67385 Mdot
.34614 .4075 Mdot
.35848 .43203 Mdot
.5105 .57101 Mdot
.59079 .30796 Mdot
.36242 .39741 Mdot
.32671 .38964 Mdot
.37163 .45453 Mdot
.66085 .40982 Mdot
.29818 .36398 Mdot
.51745 .56474 Mdot
.65886 .40575 Mdot
.65718 .40984 Mdot
.51076 .5883 Mdot
.34035 .35098 Mdot
.25419 .6811 Mdot
.40388 .49247 Mdot
.44026 .72824 Mdot
.65257 .42988 Mdot
.60184 .3699 Mdot
.4335 .55564 Mdot
.34724 .43347 Mdot
.58648 .5227 Mdot
.67454 .43742 Mdot
.46209 .73221 Mdot
.38308 .45628 Mdot
.4959 .57438 Mdot
.60711 .2702 Mdot
.36073 .53203 Mdot
.49438 .58917 Mdot
.46445 .6988 Mdot
.62167 .42413 Mdot
.46594 .64416 Mdot
.69563 .39912 Mdot
.31797 .39965 Mdot
.87662 .59614 Mdot
.66343 .44048 Mdot
.62587 .78428 Mdot
.52397 .47802 Mdot
.38086 .47507 Mdot
.69044 .41292 Mdot
.5061 .69795 Mdot
.65047 .64178 Mdot
.43405 .33742 Mdot
.47085 .6964 Mdot
.50067 .56181 Mdot
.50852 .57456 Mdot
.68568 .43672 Mdot
.45709 .66252 Mdot
.41691 .41812 Mdot
.48926 .67174 Mdot
.6837 .62465 Mdot
.37853 .49329 Mdot
.60325 .66038 Mdot
.43312 .41329 Mdot
.49247 .66806 Mdot
.64444 .44954 Mdot
.61975 .2614 Mdot
.38613 .48358 Mdot
.69111 .68761 Mdot
.36178 .43218 Mdot
.68168 .59703 Mdot
.57809 .41272 Mdot
.20579 .51999 Mdot
.37712 .43172 Mdot
.33504 .44874 Mdot
.69753 .583 Mdot
.37538 .43377 Mdot
.38064 .40991 Mdot
.41328 .6341 Mdot
.48731 .65084 Mdot
.36723 .46215 Mdot
.69951 .43544 Mdot
.23271 .49441 Mdot
.41109 .45055 Mdot
.60523 .58886 Mdot
.32238 .29642 Mdot
.56119 .38641 Mdot
.41144 .3735 Mdot
.39746 .28444 Mdot
.39056 .44716 Mdot
.34782 .43601 Mdot
.40106 .49417 Mdot
.3444 .68927 Mdot
.68595 .42647 Mdot
.66405 .45518 Mdot
.62704 .28162 Mdot
.32049 .30223 Mdot
.60718 .2773 Mdot
.67499 .57745 Mdot
.55255 .48427 Mdot
.5138 .56039 Mdot
.46603 .69349 Mdot
.40652 .44406 Mdot
.65453 .4569 Mdot
.37903 .46237 Mdot
.35165 .47662 Mdot
.67509 .42751 Mdot
.66994 .43345 Mdot
.63807 .45323 Mdot
.61319 .26563 Mdot
.46921 .67495 Mdot
.41653 .47144 Mdot
.60828 .26198 Mdot
.33082 .47348 Mdot
.48892 .38027 Mdot
.47046 .67205 Mdot
.49319 .66981 Mdot
.44133 .70128 Mdot
.36981 .47609 Mdot
.39024 .49494 Mdot
.69418 .60378 Mdot
.47927 .63563 Mdot
.66434 .62193 Mdot
.69166 .41401 Mdot
.68855 .44704 Mdot
.37819 .45316 Mdot
.38971 .51944 Mdot
.60875 .31326 Mdot
.68083 .40111 Mdot
.49579 .60505 Mdot
.62358 .27632 Mdot
.39206 .42464 Mdot
.69464 .4183 Mdot
.6066 .31935 Mdot
.27754 .67896 Mdot
.56711 .6778 Mdot
.6254 .27545 Mdot
.38663 .49779 Mdot
.32885 .55783 Mdot
.42422 .27034 Mdot
.58548 .26957 Mdot
.69037 .60233 Mdot
.3577 .45186 Mdot
.58072 .56062 Mdot
.60025 .25451 Mdot
.47391 .27332 Mdot
.67738 .42222 Mdot
.40869 .38526 Mdot
.28384 .47663 Mdot
.38009 .66101 Mdot
.61711 .25872 Mdot
.49197 .66462 Mdot
.49614 .6504 Mdot
.38232 .42801 Mdot
.54647 .48548 Mdot
.66079 .58541 Mdot
.70498 .40975 Mdot
.66277 .45696 Mdot
.49984 .65777 Mdot
.4861 .42025 Mdot
.69995 .43205 Mdot
.35177 .44072 Mdot
.62188 .24587 Mdot
.3289 .4281 Mdot
.53012 .27367 Mdot
.21247 .47456 Mdot
.41802 .37791 Mdot
.62167 .26445 Mdot
.6671 .58379 Mdot
.66407 .59271 Mdot
.6573 .60377 Mdot
.69306 .43956 Mdot
.42385 .31049 Mdot
.66938 .46024 Mdot
.61987 .81513 Mdot
.62071 .28509 Mdot
.41271 .19312 Mdot
.36662 .40076 Mdot
.38406 .47571 Mdot
.34102 .42045 Mdot
.34077 .48328 Mdot
.39095 .4486 Mdot
.69834 .61479 Mdot
.71142 .4448 Mdot
.68068 .53083 Mdot
.45133 .68033 Mdot
.52099 .81543 Mdot
.6617 .41257 Mdot
.49496 .59429 Mdot
.60228 .31049 Mdot
.3411 .28693 Mdot
.63293 .27405 Mdot
.68797 .40001 Mdot
.40092 .42031 Mdot
.50278 .69612 Mdot
.37042 .22445 Mdot
.40704 .45227 Mdot
.68581 .40194 Mdot
.70347 .46177 Mdot
.27141 .66259 Mdot
.31136 .49355 Mdot
.66313 .51983 Mdot
.45695 .34386 Mdot
.63061 .29047 Mdot
.35868 .49966 Mdot
.37337 .30095 Mdot
.68254 .42809 Mdot
.65836 .4428 Mdot
.58145 .29568 Mdot
.44359 .76241 Mdot
.44483 .67282 Mdot
.44077 .64236 Mdot
.69252 .62479 Mdot
.389 .47858 Mdot
.69392 .42956 Mdot
.45793 .62949 Mdot
.50315 .35388 Mdot
.66483 .60473 Mdot
.66621 .39889 Mdot
.36003 .43463 Mdot
.37501 .43103 Mdot
.60948 .27802 Mdot
.58245 .46709 Mdot
.33428 .38445 Mdot
.61287 .78823 Mdot
.46803 .36775 Mdot
.52482 .47772 Mdot
.37144 .45907 Mdot
.48011 .70198 Mdot
.51023 .58784 Mdot
.59442 .30122 Mdot
.31914 .46921 Mdot
.34739 .7569 Mdot
.44372 .66219 Mdot
.66324 .62079 Mdot
.5023 .59735 Mdot
.36222 .31462 Mdot
.36035 .4355 Mdot
.38111 .4468 Mdot
.33173 .45332 Mdot
.29359 .72286 Mdot
.68477 .45586 Mdot
.48681 .69477 Mdot
.61675 .27408 Mdot
.48276 .68939 Mdot
.68981 .39388 Mdot
.56955 .48684 Mdot
.41819 .47414 Mdot
.4368 .67841 Mdot
.48438 .67858 Mdot
.6833 .60058 Mdot
.64938 .60243 Mdot
.67026 .47013 Mdot
.36002 .45067 Mdot
.51309 .55923 Mdot
.44815 .66337 Mdot
.71301 .42577 Mdot
.60841 .27943 Mdot
.60556 .60967 Mdot
.4082 .47263 Mdot
.68586 .433 Mdot
.31671 .40029 Mdot
.45618 .67901 Mdot
.67134 .40322 Mdot
.49559 .5675 Mdot
.5865 .29533 Mdot
.37668 .41794 Mdot
.71167 .5143 Mdot
.4955 .58208 Mdot
.3801 .48108 Mdot
.21623 .49238 Mdot
.54704 .48591 Mdot
.51491 .63996 Mdot
.69809 .44652 Mdot
.50084 .56665 Mdot
.49477 .68809 Mdot
.24444 .62052 Mdot
.66377 .44829 Mdot
.2811 .51265 Mdot
.51468 .47112 Mdot
.38935 .49692 Mdot
.46777 .69788 Mdot
.55247 .31543 Mdot
.57871 .79189 Mdot
.435 .27559 Mdot
.39373 .46713 Mdot
.69627 .42285 Mdot
.6052 .27196 Mdot
.67838 .61916 Mdot
.66478 .65363 Mdot
.54966 .2524 Mdot
.64858 .42064 Mdot
.40677 .44363 Mdot
.46359 .6495 Mdot
.65966 .61879 Mdot
.25393 .49083 Mdot
.6849 .46346 Mdot
.70196 .43208 Mdot
.34895 .42154 Mdot
.60571 .27711 Mdot
.56977 .56576 Mdot
.67871 .45627 Mdot
.70951 .44909 Mdot
.41643 .62265 Mdot
.6292 .29618 Mdot
.33561 .46723 Mdot
.44673 .41971 Mdot
.3617 .40739 Mdot
.57506 .81935 Mdot
.50285 .56433 Mdot
.4506 .68314 Mdot
.38948 .43985 Mdot
.7039 .54554 Mdot
.67038 .447 Mdot
.45699 .34471 Mdot
.67161 .57351 Mdot
.64836 .60686 Mdot
.68932 .41906 Mdot
.38617 .46233 Mdot
.71055 .5951 Mdot
.62221 .29802 Mdot
.33497 .46721 Mdot
.38063 .49621 Mdot
.49239 .63894 Mdot
.68224 .62828 Mdot
.22856 .48984 Mdot
.67734 .62297 Mdot
.65345 .63221 Mdot
.49117 .61934 Mdot
.38229 .42762 Mdot
.66787 .4081 Mdot
.63893 .41836 Mdot
.36031 .50493 Mdot
.61703 .36616 Mdot
.44242 .68767 Mdot
.72246 .40353 Mdot
.34129 .75619 Mdot
.38471 .40592 Mdot
.5032 .60104 Mdot
.54214 .62347 Mdot
.63372 .61523 Mdot
.38364 .43233 Mdot
.46224 .69276 Mdot
.70034 .45565 Mdot
.6972 .4294 Mdot
.36514 .39635 Mdot
.6615 .59321 Mdot
.60123 .31921 Mdot
.66964 .4228 Mdot
.49833 .40829 Mdot
.39944 .46789 Mdot
.69666 .66588 Mdot
.6695 .41947 Mdot
.20129 .3564 Mdot
.70805 .55102 Mdot
.48186 .64892 Mdot
.33911 .43789 Mdot
.50067 .65224 Mdot
.62635 .296 Mdot
.71765 .41374 Mdot
.67755 .58977 Mdot
.29882 .45738 Mdot
.82769 .52248 Mdot
.6921 .4367 Mdot
.47149 .68612 Mdot
.39687 .43697 Mdot
.37153 .65296 Mdot
.36826 .46828 Mdot
.50534 .23153 Mdot
.59098 .25726 Mdot
.60889 .60457 Mdot
.6676 .58688 Mdot
.33605 .44953 Mdot
.59973 .26409 Mdot
.63733 .42624 Mdot
.67595 .42778 Mdot
.8185 .5869 Mdot
.49383 .58371 Mdot
.6707 .38268 Mdot
.37357 .47743 Mdot
.70962 .42035 Mdot
.35493 .56914 Mdot
.65421 .59927 Mdot
.36465 .40775 Mdot
.64955 .40856 Mdot
.53783 .80036 Mdot
.46073 .34147 Mdot
.39723 .46773 Mdot
.40436 .51514 Mdot
.67604 .59491 Mdot
.47489 .79741 Mdot
.69254 .45447 Mdot
.32457 .46944 Mdot
.67181 .57558 Mdot
.36679 .35235 Mdot
.63161 .48914 Mdot
.46913 .67446 Mdot
.65659 .39983 Mdot
.66831 .63729 Mdot
.41366 .38965 Mdot
.59858 .31425 Mdot
.67616 .46749 Mdot
.64319 .43078 Mdot
.37913 .48981 Mdot
.32832 .46189 Mdot
.40894 .51445 Mdot
.45408 .7006 Mdot
.65694 .63115 Mdot
.34988 .47889 Mdot
.48583 .37134 Mdot
.34521 .48474 Mdot
.66243 .63386 Mdot
.81345 .68294 Mdot
.39761 .41954 Mdot
.40507 .47442 Mdot
.36251 .66363 Mdot
.46749 .71382 Mdot
.49505 .65606 Mdot
.47511 .37455 Mdot
.35715 .46284 Mdot
.52173 .49833 Mdot
.46871 .67876 Mdot
.47431 .6874 Mdot
.52293 .4977 Mdot
.38625 .49235 Mdot
.46546 .62163 Mdot
.65825 .6176 Mdot
.6484 .60613 Mdot
.48116 .6518 Mdot
.32865 .43243 Mdot
.67577 .57921 Mdot
.3056 .67496 Mdot
.68127 .39895 Mdot
.36798 .30322 Mdot
.48705 .67577 Mdot
.45953 .33196 Mdot
.65568 .62397 Mdot
.22094 .36807 Mdot
.2824 .32059 Mdot
.40352 .41405 Mdot
.3812 .42937 Mdot
.60895 .29526 Mdot
.30011 .44687 Mdot
.51288 .58532 Mdot
.65591 .60492 Mdot
.57232 .54439 Mdot
.47101 .66611 Mdot
.35887 .46316 Mdot
.45737 .28716 Mdot
.19796 .42435 Mdot
.4518 .47996 Mdot
.47804 .67992 Mdot
.47706 .66138 Mdot
.70456 .4297 Mdot
.6925 .40029 Mdot
.41825 .47132 Mdot
.66893 .59201 Mdot
.47623 .64695 Mdot
.66911 .63226 Mdot
.68132 .42722 Mdot
.66311 .41337 Mdot
.51717 .56832 Mdot
.38144 .37287 Mdot
.68477 .41922 Mdot
.62198 .56724 Mdot
.48622 .37274 Mdot
.47949 .63298 Mdot
.64634 .8075 Mdot
.23238 .35029 Mdot
.37461 .71909 Mdot
.60598 .27082 Mdot
.35079 .35039 Mdot
.69222 .59371 Mdot
.33631 .45356 Mdot
.37714 .44364 Mdot
.50197 .5759 Mdot
.6902 .58913 Mdot
.61102 .30471 Mdot
.65111 .60269 Mdot
.59065 .29795 Mdot
.65888 .45181 Mdot
.40911 .44889 Mdot
.4153 .44348 Mdot
.68023 .61618 Mdot
.7035 .41606 Mdot
.67269 .40007 Mdot
.59598 .27703 Mdot
.33629 .28807 Mdot
.68458 .43531 Mdot
.48624 .6781 Mdot
.26813 .5234 Mdot
.50748 .57415 Mdot
.38393 .4565 Mdot
.39216 .28416 Mdot
.23867 .60226 Mdot
.33705 .48475 Mdot
.50075 .59509 Mdot
.76211 .73843 Mdot
.41248 .45494 Mdot
.83211 .47355 Mdot
.51385 .562 Mdot
.46681 .71139 Mdot
.67682 .40729 Mdot
.4951 .58972 Mdot
.28633 .37472 Mdot
.69558 .49409 Mdot
.35052 .49951 Mdot
.44382 .67424 Mdot
.44623 .70413 Mdot
.56776 .48982 Mdot
.57141 .82042 Mdot
.6161 .27329 Mdot
.61866 .29892 Mdot
.66982 .44987 Mdot
.60852 .62734 Mdot
.33522 .41559 Mdot
.61862 .29532 Mdot
.44665 .6283 Mdot
.33436 .44043 Mdot
.54944 .48705 Mdot
.56497 .51162 Mdot
.49624 .68141 Mdot
.43579 .42803 Mdot
.66972 .44857 Mdot
.47192 .68385 Mdot
.56379 .49994 Mdot
.35085 .41659 Mdot
.47074 .6696 Mdot
.6501 .62496 Mdot
.48459 .53105 Mdot
.48995 .67494 Mdot
.44124 .34097 Mdot
.67538 .61536 Mdot
.55732 .48571 Mdot
.44777 .20942 Mdot
.15126 .43704 Mdot
.66218 .59506 Mdot
.68617 .40409 Mdot
.69278 .42973 Mdot
.68251 .43942 Mdot
.46371 .7022 Mdot
.66746 .43714 Mdot
.44761 .67812 Mdot
.63488 .6427 Mdot
.33419 .30203 Mdot
.60841 .28672 Mdot
.56574 .33672 Mdot
.48402 .65554 Mdot
.60687 .81755 Mdot
.54319 .86592 Mdot
.34011 .47957 Mdot
.63872 .61798 Mdot
.61493 .26263 Mdot
.46325 .373 Mdot
.61026 .29718 Mdot
.68238 .40539 Mdot
.35362 .30968 Mdot
.38394 .4681 Mdot
.57588 .64143 Mdot
.60477 .27291 Mdot
.47513 .68854 Mdot
.36984 .48196 Mdot
.65918 .39439 Mdot
.62447 .29823 Mdot
.59783 .2794 Mdot
.38967 .44976 Mdot
.4565 .71012 Mdot
.67542 .40171 Mdot
.70073 .61468 Mdot
.6279 .25136 Mdot
.34 .51039 Mdot
.41294 .44841 Mdot
.41579 .43414 Mdot
.46417 .34745 Mdot
.60795 .63141 Mdot
.67368 .6142 Mdot
.47505 .27624 Mdot
.68401 .45042 Mdot
.43566 .27375 Mdot
.60443 .78179 Mdot
.55474 .31172 Mdot
.50343 .56482 Mdot
.50422 .56286 Mdot
.40037 .45811 Mdot
.44681 .84324 Mdot
.42862 .53942 Mdot
.66012 .57806 Mdot
.5045 .57887 Mdot
.68387 .39741 Mdot
.47489 .63877 Mdot
.28832 .48002 Mdot
.3643 .3989 Mdot
.70118 .61212 Mdot
.67945 .43223 Mdot
.38821 .83111 Mdot
.61881 .28231 Mdot
.46806 .38146 Mdot
.36006 .44699 Mdot
.39468 .45798 Mdot
.67056 .60566 Mdot
.67984 .59094 Mdot
.41624 .62122 Mdot
.55254 .37305 Mdot
.6049 .66882 Mdot
.70343 .62261 Mdot
.38607 .83111 Mdot
.5347 .64396 Mdot
.46581 .66017 Mdot
.51309 .5899 Mdot
.66159 .58589 Mdot
.38645 .4415 Mdot
.46421 .71298 Mdot
.42188 .54094 Mdot
.47517 .71953 Mdot
.54207 .48676 Mdot
.49686 .39913 Mdot
.3682 .42627 Mdot
.49715 .69973 Mdot
.4723 .67835 Mdot
.42999 .70176 Mdot
.51135 .58111 Mdot
.3696 .45543 Mdot
.32679 .47483 Mdot
.4146 .46246 Mdot
.42205 .58864 Mdot
.4032 .45933 Mdot
.59847 .78486 Mdot
.48332 .3902 Mdot
.70234 .27584 Mdot
.41097 .46084 Mdot
.64836 .62623 Mdot
.40466 .44476 Mdot
.59596 .26614 Mdot
.3836 .41673 Mdot
.53688 .48499 Mdot
.6621 .61472 Mdot
.35162 .74183 Mdot
.68347 .4773 Mdot
.41185 .44002 Mdot
.61909 .31485 Mdot
.70171 .74642 Mdot
.4735 .28092 Mdot
.4178 .62139 Mdot
.48905 .67172 Mdot
.70425 .45647 Mdot
.64888 .5939 Mdot
.66119 .42148 Mdot
.42468 .42739 Mdot
.51859 .57759 Mdot
.39479 .1817 Mdot
.47261 .32521 Mdot
.38866 .44073 Mdot
.35913 .37719 Mdot
.49298 .68035 Mdot
.66803 .44517 Mdot
.39698 .73865 Mdot
.33664 .42595 Mdot
.58459 .29504 Mdot
.60382 .25747 Mdot
.71265 .3745 Mdot
.46625 .57342 Mdot
.38751 .57707 Mdot
.6704 .60765 Mdot
.69505 .43701 Mdot
.60942 .25674 Mdot
.42097 .68254 Mdot
.65039 .59458 Mdot
.63365 .61439 Mdot
.68289 .62877 Mdot
.39807 .47313 Mdot
.51383 .56821 Mdot
.46968 .5943 Mdot
.4945 .57561 Mdot
.35106 .40919 Mdot
.64331 .42827 Mdot
.49723 .56615 Mdot
.60414 .29032 Mdot
.66017 .63701 Mdot
.66084 .41143 Mdot
.39767 .44768 Mdot
.46481 .67981 Mdot
.52632 .30629 Mdot
.71462 .54749 Mdot
.5483 .48526 Mdot
.54843 .48524 Mdot
.43714 .66496 Mdot
.56386 .58838 Mdot
.62212 .63889 Mdot
.26347 .65356 Mdot
.61107 .23356 Mdot
.31244 .46925 Mdot
.63468 .36741 Mdot
.67168 .46077 Mdot
.67668 .41557 Mdot
.3838 .47124 Mdot
.71012 .43307 Mdot
.36165 .46378 Mdot
.69915 .44614 Mdot
.57385 .80217 Mdot
.38801 .40027 Mdot
.67306 .42258 Mdot
.30047 .4795 Mdot
.38634 .48334 Mdot
.48291 .6973 Mdot
.69264 .46044 Mdot
.40259 .41338 Mdot
.53293 .13472 Mdot
.68392 .60289 Mdot
.51124 .57954 Mdot
.51713 .44754 Mdot
.65293 .61882 Mdot
.44893 .66904 Mdot
.35412 .44821 Mdot
.62225 .28563 Mdot
.47104 .65745 Mdot
.7325 .43528 Mdot
.60248 .27706 Mdot
.4849 .43339 Mdot
.475 .65378 Mdot
.50698 .57084 Mdot
.58596 .2856 Mdot
.35361 .50061 Mdot
.67628 .41812 Mdot
.71449 .55296 Mdot
.49849 .59557 Mdot
.38028 .46593 Mdot
.66592 .39418 Mdot
.65012 .60765 Mdot
.39898 .43051 Mdot
.69505 .42939 Mdot
.50742 .59395 Mdot
.40015 .48029 Mdot
.36403 .47467 Mdot
.43258 .76116 Mdot
.58385 .42513 Mdot
.60646 .28808 Mdot
.4609 .63236 Mdot
.35198 .40504 Mdot
.59971 .26611 Mdot
.68048 .52225 Mdot
.4387 .45297 Mdot
.44457 .66604 Mdot
.2974 .67404 Mdot
.70616 .41227 Mdot
.66073 .59162 Mdot
.64683 .4561 Mdot
.62819 .28941 Mdot
.60106 .8602 Mdot
.51497 .58207 Mdot
.42391 .48195 Mdot
.38166 .40872 Mdot
.72106 .42865 Mdot
.47351 .67466 Mdot
.60163 .66766 Mdot
.37361 .41782 Mdot
.37327 .38033 Mdot
.38638 .45305 Mdot
.71019 .50573 Mdot
.45921 .70281 Mdot
.38449 .45452 Mdot
.34917 .50665 Mdot
.37612 .40549 Mdot
.61235 .31569 Mdot
.40803 .19482 Mdot
.35858 .49541 Mdot
.90254 .55082 Mdot
.52102 .58273 Mdot
.67526 .43237 Mdot
.44359 .34346 Mdot
.52122 .44244 Mdot
.64572 .21111 Mdot
.44509 .67754 Mdot
.43576 .7226 Mdot
.6643 .41327 Mdot
.54712 .28151 Mdot
.56302 .58331 Mdot
.36364 .47686 Mdot
.35767 .44453 Mdot
.68226 .40538 Mdot
.71348 .42451 Mdot
.52004 .5815 Mdot
.40235 .4967 Mdot
.43268 .41497 Mdot
.6438 .44705 Mdot
.40674 .45579 Mdot
.22981 .58009 Mdot
.64085 .63469 Mdot
.48525 .65153 Mdot
.68047 .61855 Mdot
.64704 .64021 Mdot
.38415 .73301 Mdot
.46721 .3633 Mdot
.69487 .62203 Mdot
.63118 .60557 Mdot
.55318 .32195 Mdot
.37651 .6649 Mdot
.60885 .31687 Mdot
.46324 .53783 Mdot
.68284 .44584 Mdot
.36926 .45319 Mdot
.4615 .70372 Mdot
.54267 .20739 Mdot
.62697 .69136 Mdot
.27747 .36642 Mdot
.3355 .46547 Mdot
.67545 .44672 Mdot
.49981 .59829 Mdot
.43903 .45341 Mdot
.4276 .27115 Mdot
.39604 .46315 Mdot
.70131 .40555 Mdot
.37777 .6674 Mdot
.70164 .55975 Mdot
.69588 .63964 Mdot
.49417 .72341 Mdot
.40491 .44397 Mdot
.45397 .69437 Mdot
.68264 .63892 Mdot
.60735 .26551 Mdot
.61442 .29035 Mdot
.41129 .43821 Mdot
.52374 .47834 Mdot
.59959 .23054 Mdot
.36773 .47923 Mdot
.38094 .49125 Mdot
.50163 .5676 Mdot
.38019 .49178 Mdot
.32994 .48145 Mdot
.34583 .47586 Mdot
.33025 .47091 Mdot
.65485 .59098 Mdot
.38409 .71337 Mdot
.41196 .4922 Mdot
.42787 .4547 Mdot
.66737 .64515 Mdot
.42879 .4419 Mdot
.66554 .59762 Mdot
.6317 .67584 Mdot
.69488 .6156 Mdot
.61351 .2889 Mdot
.66656 .39279 Mdot
.40958 .72043 Mdot
.47529 .64728 Mdot
.64359 .61906 Mdot
.58902 .30297 Mdot
.6581 .60004 Mdot
.69332 .44556 Mdot
.68744 .5483 Mdot
.50426 .62826 Mdot
.49828 .41774 Mdot
.36836 .67641 Mdot
.72155 .65385 Mdot
.70835 .42882 Mdot
.47827 .64928 Mdot
.60365 .59824 Mdot
.33706 .45381 Mdot
.61851 .27791 Mdot
.39973 .45756 Mdot
.65686 .63536 Mdot
.67953 .44602 Mdot
.40865 .66641 Mdot
.60655 .28946 Mdot
.68009 .79284 Mdot
.65464 .45756 Mdot
.38516 .41227 Mdot
.67258 .64464 Mdot
.6527 .54687 Mdot
.67945 .59396 Mdot
.33545 .29938 Mdot
.55118 .60723 Mdot
.5466 .22261 Mdot
.47752 .65848 Mdot
.49137 .58616 Mdot
.1497 .51637 Mdot
.6651 .72892 Mdot
.45931 .67996 Mdot
.62407 .43352 Mdot
.40482 .46436 Mdot
.34386 .4792 Mdot
.37532 .37454 Mdot
.46775 .71724 Mdot
.33162 .45233 Mdot
.51329 .57607 Mdot
.4731 .36215 Mdot
.4847 .57746 Mdot
.69067 .46698 Mdot
.36363 .46456 Mdot
.68837 .6371 Mdot
.6422 .6194 Mdot
.50309 .5583 Mdot
.67926 .62511 Mdot
.40404 .48441 Mdot
.48186 .65598 Mdot
.56346 .50512 Mdot
.62634 .29244 Mdot
.64017 .77133 Mdot
.59279 .24295 Mdot
.63573 .28334 Mdot
.38294 .40511 Mdot
.66468 .41085 Mdot
.82487 .49482 Mdot
.33511 .45582 Mdot
.46954 .68145 Mdot
.37829 .40917 Mdot
.3488 .48129 Mdot
.412 .48346 Mdot
.69453 .4374 Mdot
.46119 .33874 Mdot
.40704 .45501 Mdot
.69131 .63037 Mdot
.5226 .49494 Mdot
.36125 .3985 Mdot
.59079 .53448 Mdot
.53852 .486 Mdot
.70611 .65997 Mdot
.48686 .63574 Mdot
.67018 .40791 Mdot
.47188 .66374 Mdot
.4863 .7202 Mdot
.44919 .66892 Mdot
.47796 .58913 Mdot
.25664 .64239 Mdot
.8323 .46322 Mdot
.36227 .57192 Mdot
.36631 .68289 Mdot
.49962 .71403 Mdot
.77199 .46252 Mdot
.45883 .68596 Mdot
.4476 .67158 Mdot
.79842 .66542 Mdot
.44635 .69923 Mdot
.37758 .45376 Mdot
.41534 .43745 Mdot
.31433 .73282 Mdot
.6365 .30321 Mdot
.38059 .47967 Mdot
.33245 .47633 Mdot
.60619 .25671 Mdot
.43851 .75718 Mdot
.51099 .5967 Mdot
.47223 .39144 Mdot
.49284 .59047 Mdot
.39046 .4497 Mdot
.37937 .42301 Mdot
.31017 .44649 Mdot
.1831 .45514 Mdot
.55536 .23034 Mdot
.44501 .7051 Mdot
.32626 .48671 Mdot
.73104 .6363 Mdot
.35236 .4303 Mdot
.3687 .41097 Mdot
.40847 .48645 Mdot
.66773 .40814 Mdot
.45886 .64487 Mdot
.32964 .38734 Mdot
.66428 .74767 Mdot
.36259 .43356 Mdot
.58667 .24726 Mdot
.60323 .33103 Mdot
.38485 .46193 Mdot
.44185 .69468 Mdot
.34057 .47546 Mdot
.48732 .64479 Mdot
.47103 .65428 Mdot
.39569 .38316 Mdot
.46145 .60174 Mdot
.47352 .63956 Mdot
.36249 .47571 Mdot
.70547 .41879 Mdot
.6177 .78693 Mdot
.38147 .46544 Mdot
.60189 .28594 Mdot
.38727 .43195 Mdot
.61606 .31476 Mdot
.36742 .494 Mdot
.49656 .5694 Mdot
.20135 .52426 Mdot
.65865 .44456 Mdot
.63099 .26451 Mdot
.71025 .42655 Mdot
.32721 .42557 Mdot
.50379 .65259 Mdot
.70494 .56646 Mdot
.55958 .24006 Mdot
.50238 .56736 Mdot
.49321 .27038 Mdot
.52355 .50881 Mdot
.69222 .59738 Mdot
.48817 .69382 Mdot
.38149 .69156 Mdot
.5891 .53162 Mdot
.69176 .46777 Mdot
.67141 .39657 Mdot
.62331 .47551 Mdot
.77911 .68544 Mdot
.40881 .46338 Mdot
.58525 .55601 Mdot
.239 .55519 Mdot
.30067 .44354 Mdot
.31311 .49938 Mdot
.64295 .43415 Mdot
.38033 .47983 Mdot
.46284 .31506 Mdot
.6894 .43074 Mdot
.612 .30959 Mdot
.45031 .6853 Mdot
.59201 .27867 Mdot
.5727 .69654 Mdot
.41279 .6335 Mdot
.68601 .42304 Mdot
.33119 .46871 Mdot
.37898 .4764 Mdot
.47048 .71266 Mdot
.25446 .48975 Mdot
.48781 .65113 Mdot
.62462 .28167 Mdot
.66686 .45188 Mdot
.47062 .14546 Mdot
.39563 .43487 Mdot
.4828 .68085 Mdot
.68102 .47783 Mdot
.37295 .43242 Mdot
.65869 .59449 Mdot
.33175 .44854 Mdot
.48149 .68798 Mdot
.3791 .49195 Mdot
.47624 .65737 Mdot
.70317 .42365 Mdot
.41293 .43891 Mdot
.39193 .42519 Mdot
.47904 .27381 Mdot
.61001 .30461 Mdot
.48041 .64087 Mdot
.45551 .31437 Mdot
.36165 .40738 Mdot
.41121 .27381 Mdot
.41001 .45011 Mdot
.37238 .66314 Mdot
.43232 .49158 Mdot
.51256 .57336 Mdot
.37711 .40854 Mdot
.38342 .46605 Mdot
.25603 .48621 Mdot
.34737 .56603 Mdot
.4232 .5903 Mdot
.64969 .60088 Mdot
.47135 .70133 Mdot
.6918 .42598 Mdot
.69858 .45894 Mdot
.66497 .43146 Mdot
.59377 .25116 Mdot
.36022 .50642 Mdot
.37533 .46556 Mdot
.64437 .58718 Mdot
.61952 .29031 Mdot
.48117 .67567 Mdot
.61245 .28392 Mdot
.46333 .36078 Mdot
.60023 .28979 Mdot
.51287 .58677 Mdot
.7019 .54726 Mdot
.23585 .5924 Mdot
.59743 .30255 Mdot
.48314 .65073 Mdot
.51486 .49404 Mdot
.30323 .4364 Mdot
.5423 .81859 Mdot
.5843 .28902 Mdot
.64048 .48374 Mdot
.40755 .47736 Mdot
.433 .33353 Mdot
.66579 .59977 Mdot
.59125 .28045 Mdot
.68522 .62678 Mdot
.34021 .47428 Mdot
.48164 .74297 Mdot
.46899 .69106 Mdot
.64313 .63806 Mdot
.36392 .40997 Mdot
.59147 .27924 Mdot
.68244 .42019 Mdot
.37758 .66261 Mdot
.6366 .63998 Mdot
.53122 .31459 Mdot
.43622 .27539 Mdot
.67369 .45231 Mdot
.37101 .6288 Mdot
.69238 .61905 Mdot
.32386 .48385 Mdot
.41187 .53435 Mdot
.33596 .42113 Mdot
.67115 .40032 Mdot
.6763 .41487 Mdot
.71473 .66818 Mdot
.38696 .42277 Mdot
.41604 .48831 Mdot
.4681 .6328 Mdot
.67152 .45349 Mdot
.45092 .66625 Mdot
.50073 .68724 Mdot
.68787 .40541 Mdot
.48903 .64945 Mdot
.60131 .27661 Mdot
.40401 .30476 Mdot
.69287 .61931 Mdot
.66756 .58804 Mdot
.68592 .42053 Mdot
.64983 .4368 Mdot
.66372 .41153 Mdot
.34179 .42375 Mdot
.46498 .65437 Mdot
.33924 .44232 Mdot
.40261 .44137 Mdot
.50583 .60446 Mdot
.48421 .62497 Mdot
.34949 .42654 Mdot
.5638 .51569 Mdot
.58306 .29236 Mdot
.67207 .42729 Mdot
.66268 .63113 Mdot
.5251 .29369 Mdot
.69886 .62058 Mdot
.36582 .40453 Mdot
.54251 .80476 Mdot
.46685 .70017 Mdot
.60957 .29656 Mdot
.53914 .48425 Mdot
.60739 .2925 Mdot
.64146 .6358 Mdot
.43974 .65698 Mdot
.48524 .42645 Mdot
.39271 .42413 Mdot
.46552 .34891 Mdot
.45309 .2262 Mdot
.61311 .77552 Mdot
.65443 .62921 Mdot
.33973 .47675 Mdot
.50899 .56276 Mdot
.26447 .65737 Mdot
.37819 .46775 Mdot
.39246 .40426 Mdot
.5342 .46061 Mdot
.38755 .40896 Mdot
.43762 .70032 Mdot
.54935 .49103 Mdot
.35119 .49519 Mdot
.3243 .43451 Mdot
.79945 .62145 Mdot
.39259 .48163 Mdot
.40101 .42921 Mdot
.3731 .44745 Mdot
.33533 .44156 Mdot
.5003 .65115 Mdot
.56988 .47903 Mdot
.67769 .64129 Mdot
.40382 .30452 Mdot
.68641 .62851 Mdot
.68741 .41413 Mdot
.54149 .35552 Mdot
.49367 .64658 Mdot
.60694 .29283 Mdot
.59414 .55376 Mdot
.35251 .31209 Mdot
.70497 .42779 Mdot
.49956 .2568 Mdot
.59871 .31663 Mdot
.30476 .4246 Mdot
.62884 .28973 Mdot
.64466 .41376 Mdot
.66104 .59398 Mdot
.3997 .41965 Mdot
.44953 .66268 Mdot
.49052 .67416 Mdot
.34022 .41298 Mdot
.66124 .76011 Mdot
.65852 .59217 Mdot
.60611 .36316 Mdot
.39209 .47422 Mdot
.36433 .40785 Mdot
.49312 .65218 Mdot
.67031 .44553 Mdot
.52463 .50697 Mdot
.59776 .30905 Mdot
.35613 .43066 Mdot
.33868 .4821 Mdot
.46341 .35908 Mdot
.64493 .60879 Mdot
.50531 .58575 Mdot
.36995 .4666 Mdot
.47262 .3822 Mdot
.33097 .44555 Mdot
.31501 .44302 Mdot
.70256 .41064 Mdot
.38448 .38074 Mdot
.37211 .42113 Mdot
.50768 .71124 Mdot
.69172 .61813 Mdot
.47104 .6743 Mdot
.4428 .72375 Mdot
.49874 .56681 Mdot
.68373 .60522 Mdot
.35185 .42269 Mdot
.63588 .61561 Mdot
.34626 .48047 Mdot
.40154 .44913 Mdot
.65247 .62765 Mdot
.4533 .66595 Mdot
.6006 .65137 Mdot
.38439 .71218 Mdot
.35096 .47679 Mdot
.38258 .43175 Mdot
.6363 .30377 Mdot
.56596 .20232 Mdot
.38204 .41978 Mdot
.47932 .64838 Mdot
.37508 .43055 Mdot
.68362 .59069 Mdot
.61508 .27243 Mdot
.46597 .68377 Mdot
.68304 .45317 Mdot
.70233 .42509 Mdot
.65493 .47374 Mdot
.51352 .58649 Mdot
.41235 .48959 Mdot
.46131 .63222 Mdot
.48294 .62292 Mdot
.41848 .31671 Mdot
.67469 .43105 Mdot
.6111 .27166 Mdot
.37289 .47801 Mdot
.29834 .45074 Mdot
.64975 .63993 Mdot
.90917 .53437 Mdot
.48467 .42073 Mdot
.58891 .31884 Mdot
.55599 .38409 Mdot
.49962 .57374 Mdot
.39708 .4786 Mdot
.59506 .26902 Mdot
.6928 .41143 Mdot
.34364 .47933 Mdot
.4219 .49863 Mdot
.67392 .51586 Mdot
.65231 .42153 Mdot
.63467 .62334 Mdot
.69433 .45032 Mdot
.60429 .31873 Mdot
.51329 .58448 Mdot
.48166 .69523 Mdot
.39015 .46421 Mdot
.43916 .42869 Mdot
.67973 .4412 Mdot
.51755 .55939 Mdot
.41618 .44968 Mdot
.47206 .70329 Mdot
.66967 .43502 Mdot
.38659 .44688 Mdot
.27422 .6634 Mdot
.41047 .72211 Mdot
.68266 .44779 Mdot
.35222 .44324 Mdot
.28135 .46892 Mdot
.65412 .41663 Mdot
.64663 .41198 Mdot
.33828 .47688 Mdot
.58894 .28342 Mdot
.36648 .42565 Mdot
.67069 .59322 Mdot
.464 .33755 Mdot
.68207 .61331 Mdot
.42518 .26977 Mdot
.32319 .46126 Mdot
.43526 .52256 Mdot
.49716 .70925 Mdot
.61849 .24689 Mdot
.2508 .33388 Mdot
.37145 .40308 Mdot
.4573 .76799 Mdot
.46051 .33268 Mdot
.49851 .43553 Mdot
.46618 .76597 Mdot
.59322 .3038 Mdot
.65755 .6032 Mdot
.4092 .4377 Mdot
.6025 .63312 Mdot
.59228 .29673 Mdot
.42314 .26976 Mdot
.34566 .45042 Mdot
.47576 .68346 Mdot
.39609 .47206 Mdot
.47912 .6952 Mdot
.36955 .43907 Mdot
.43802 .76686 Mdot
.60251 .23091 Mdot
.33465 .29949 Mdot
.3049 .42518 Mdot
.65445 .54659 Mdot
.368 .67749 Mdot
.60753 .27563 Mdot
.36434 .48585 Mdot
.50009 .58551 Mdot
.65089 .60307 Mdot
.63269 .54241 Mdot
.6633 .41439 Mdot
.69002 .63085 Mdot
.45897 .66455 Mdot
.6455 .40556 Mdot
.51192 .55825 Mdot
.4241 .37597 Mdot
.59129 .27796 Mdot
.68343 .60292 Mdot
.38519 .46481 Mdot
.34006 .41761 Mdot
.71054 .506 Mdot
.39661 .19134 Mdot
.50322 .6661 Mdot
.7169 .77107 Mdot
.44258 .65155 Mdot
.61563 .30186 Mdot
.69864 .40688 Mdot
.38455 .44028 Mdot
.36213 .45282 Mdot
.65258 .42433 Mdot
.47132 .71133 Mdot
.63506 .28332 Mdot
.55051 .2176 Mdot
.66602 .57703 Mdot
.40517 .20861 Mdot
.46511 .68779 Mdot
.40654 .20838 Mdot
.57004 .31287 Mdot
.4198 .65265 Mdot
.30826 .29429 Mdot
.65534 .61745 Mdot
.40453 .20802 Mdot
.4782 .68445 Mdot
.40834 .46814 Mdot
.50562 .57197 Mdot
.51994 .56868 Mdot
.45396 .6903 Mdot
.67876 .4046 Mdot
.59624 .31298 Mdot
.39326 .472 Mdot
.43872 .39769 Mdot
.25385 .49123 Mdot
.65953 .45122 Mdot
.34996 .38122 Mdot
.65945 .6242 Mdot
.37618 .43196 Mdot
.61097 .25851 Mdot
.6566 .61524 Mdot
.4936 .57457 Mdot
.3576 .31104 Mdot
.354 .44782 Mdot
.52985 .48339 Mdot
.66928 .60101 Mdot
.56037 .20138 Mdot
.38917 .4245 Mdot
.69228 .61921 Mdot
.43798 .42543 Mdot
.73759 .63492 Mdot
.54677 .50653 Mdot
.66361 .72858 Mdot
.65484 .46504 Mdot
.69869 .44614 Mdot
.53342 .14023 Mdot
.65911 .23997 Mdot
.67117 .63923 Mdot
.50296 .59942 Mdot
.40584 .19213 Mdot
.68743 .62198 Mdot
.36937 .41689 Mdot
.41125 .45435 Mdot
.37779 .66792 Mdot
.29869 .46351 Mdot
.51919 .58556 Mdot
.43904 .55358 Mdot
.39655 .4876 Mdot
.33689 .38513 Mdot
.40319 .43478 Mdot
.44814 .70693 Mdot
.65888 .62107 Mdot
.19895 .66593 Mdot
.64063 .60714 Mdot
.43323 .52072 Mdot
.68247 .44597 Mdot
.64355 .45536 Mdot
.38586 .46132 Mdot
.38158 .5436 Mdot
.39583 .83918 Mdot
.41238 .45007 Mdot
.53857 .48422 Mdot
.43931 .27561 Mdot
.34722 .50001 Mdot
.45264 .65347 Mdot
.43451 .41659 Mdot
.47214 .6245 Mdot
.65481 .61301 Mdot
.59273 .30235 Mdot
.61042 .24151 Mdot
.6599 .60169 Mdot
.36341 .45313 Mdot
.60788 .24537 Mdot
.39215 .45665 Mdot
.38885 .47816 Mdot
.4674 .37502 Mdot
.61912 .2661 Mdot
.66746 .40604 Mdot
.61262 .29087 Mdot
.44338 .68309 Mdot
.79603 .7018 Mdot
.61123 .279 Mdot
.37654 .66522 Mdot
.46049 .32113 Mdot
.41485 .19748 Mdot
.4915 .6759 Mdot
.62683 .29266 Mdot
.65212 .60895 Mdot
.48701 .45333 Mdot
.35708 .66494 Mdot
.69888 .62002 Mdot
.37325 .46662 Mdot
.50106 .6533 Mdot
.44107 .6563 Mdot
.70397 .61378 Mdot
.48542 .69413 Mdot
.3898 .51119 Mdot
.35672 .47019 Mdot
.68245 .63843 Mdot
.19502 .42171 Mdot
.6662 .58691 Mdot
.3912 .74 Mdot
.3974 .49329 Mdot
.46792 .68219 Mdot
.36972 .66476 Mdot
.45184 .73393 Mdot
.51797 .57027 Mdot
.39056 .41898 Mdot
.61216 .27532 Mdot
.42402 .31038 Mdot
.67855 .44963 Mdot
.54097 .80043 Mdot
.48816 .67297 Mdot
.70557 .59935 Mdot
.48374 .69539 Mdot
.49288 .68527 Mdot
.6494 .64344 Mdot
.46535 .6985 Mdot
.36198 .43516 Mdot
.46124 .78843 Mdot
.49375 .66685 Mdot
.66712 .60899 Mdot
.62445 .28669 Mdot
.48157 .64878 Mdot
.59358 .36258 Mdot
.36962 .47413 Mdot
.68171 .46392 Mdot
.64125 .25741 Mdot
.49675 .69775 Mdot
.60773 .27432 Mdot
.6764 .43851 Mdot
.58812 .30533 Mdot
.6136 .64651 Mdot
.6112 .58524 Mdot
.26391 .39749 Mdot
.73699 .62195 Mdot
.44434 .69478 Mdot
.63603 .42056 Mdot
.35561 .43999 Mdot
.39132 .47565 Mdot
.59369 .25405 Mdot
.43509 .68459 Mdot
.67599 .75188 Mdot
.43451 .54063 Mdot
.64189 .76996 Mdot
.64825 .60233 Mdot
.58131 .35138 Mdot
.48658 .42712 Mdot
.69692 .65344 Mdot
.35934 .49968 Mdot
.5 .5742 Mdot
.38561 .45293 Mdot
.4727 .28115 Mdot
.60288 .31773 Mdot
.75007 .5022 Mdot
.32951 .43211 Mdot
.65325 .42904 Mdot
.3727 .43966 Mdot
.57445 .55645 Mdot
.32006 .4438 Mdot
.58384 .28406 Mdot
.67253 .57568 Mdot
.47563 .6472 Mdot
.62315 .30417 Mdot
.70208 .42205 Mdot
.28851 .32512 Mdot
.36504 .4202 Mdot
.40079 .48461 Mdot
.65778 .40785 Mdot
.44955 .66557 Mdot
.68274 .41345 Mdot
.6926 .62029 Mdot
.61018 .28178 Mdot
.33764 .43272 Mdot
.34489 .38296 Mdot
.72086 .42524 Mdot
.64571 .63128 Mdot
.67778 .39553 Mdot
.63565 .61804 Mdot
.50331 .57004 Mdot
.31553 .45364 Mdot
.67931 .39316 Mdot
.36189 .49936 Mdot
.35294 .59743 Mdot
.36466 .31602 Mdot
.26308 .48577 Mdot
.67177 .40222 Mdot
.65444 .22252 Mdot
.65997 .6112 Mdot
.68647 .60345 Mdot
.39634 .74882 Mdot
.44016 .8446 Mdot
.52197 .49845 Mdot
.71154 .7357 Mdot
.69291 .61986 Mdot
.67361 .60123 Mdot
.67899 .40968 Mdot
.44578 .68011 Mdot
.48995 .71452 Mdot
.66516 .39511 Mdot
.38641 .28519 Mdot
.48124 .67596 Mdot
.3332 .74824 Mdot
.6653 .45887 Mdot
.42469 .47021 Mdot
.40664 .68838 Mdot
.58399 .28602 Mdot
.45118 .28525 Mdot
.67913 .54123 Mdot
.38022 .44646 Mdot
.83254 .48099 Mdot
.66477 .41528 Mdot
.46091 .53967 Mdot
.67637 .56907 Mdot
.34676 .41716 Mdot
.37073 .44492 Mdot
.36807 .43069 Mdot
.58153 .29468 Mdot
.31521 .5559 Mdot
.38214 .44359 Mdot
.34454 .30508 Mdot
.40266 .40551 Mdot
.70932 .52277 Mdot
.61265 .29043 Mdot
.50445 .23569 Mdot
.65576 .38871 Mdot
.67348 .74314 Mdot
.39043 .40514 Mdot
.69014 .60239 Mdot
.57222 .53003 Mdot
.6543 .63125 Mdot
.68981 .66678 Mdot
.38049 .21824 Mdot
.43735 .69145 Mdot
.3321 .43024 Mdot
.65371 .45043 Mdot
.50106 .70203 Mdot
.56956 .52364 Mdot
.78921 .71121 Mdot
.701 .5883 Mdot
.63552 .85681 Mdot
.68553 .61596 Mdot
.52136 .57739 Mdot
.45767 .66785 Mdot
.31305 .51839 Mdot
.46548 .35213 Mdot
.45121 .6665 Mdot
.71786 .31322 Mdot
.47044 .62343 Mdot
.34654 .26623 Mdot
.51138 .64471 Mdot
.66766 .61395 Mdot
.70524 .60975 Mdot
.42756 .49311 Mdot
.36462 .4253 Mdot
.47221 .34674 Mdot
.30933 .4942 Mdot
.35478 .45159 Mdot
.68962 .43108 Mdot
.73724 .61838 Mdot
.60531 .63621 Mdot
.46164 .69452 Mdot
.65005 .63724 Mdot
.37207 .44202 Mdot
.35201 .47757 Mdot
.40667 .42144 Mdot
.54623 .28186 Mdot
.32574 .74434 Mdot
.40398 .44996 Mdot
.31925 .4373 Mdot
.70485 .42198 Mdot
.71394 .50407 Mdot
.75268 .71277 Mdot
.39007 .20938 Mdot
.41846 .4605 Mdot
.61347 .30032 Mdot
.61356 .25785 Mdot
.40313 .51121 Mdot
.33077 .52752 Mdot
.61607 .34434 Mdot
.38474 .46487 Mdot
.30938 .31355 Mdot
.70998 .45338 Mdot
.50537 .55875 Mdot
.67967 .44059 Mdot
.49331 .71568 Mdot
.50698 .56313 Mdot
.69569 .42445 Mdot
.36039 .30121 Mdot
.49578 .5797 Mdot
.73795 .64522 Mdot
.62671 .28885 Mdot
.39799 .42987 Mdot
.39018 .67712 Mdot
.67279 .45427 Mdot
.67682 .59888 Mdot
.4636 .66837 Mdot
.65219 .59841 Mdot
.71031 .55055 Mdot
.4042 .28083 Mdot
.51547 .57725 Mdot
.68965 .60112 Mdot
.52634 .48397 Mdot
.61516 .29678 Mdot
.68246 .6226 Mdot
.4298 .53202 Mdot
.36272 .3975 Mdot
.35367 .80004 Mdot
.39012 .48541 Mdot
.70617 .67079 Mdot
.68265 .59841 Mdot
.49688 .56367 Mdot
.39194 .46403 Mdot
.65905 .46063 Mdot
.40289 .36746 Mdot
.39302 .45541 Mdot
.68593 .45506 Mdot
.40862 .45811 Mdot
.60838 .26218 Mdot
.43719 .6583 Mdot
.45692 .32901 Mdot
.53613 .32831 Mdot
.60253 .31568 Mdot
.39394 .32826 Mdot
.38303 .41951 Mdot
.68232 .28419 Mdot
.4761 .67981 Mdot
.36761 .40435 Mdot
.43012 .2597 Mdot
.44811 .68908 Mdot
.47354 .66246 Mdot
.37934 .48892 Mdot
.67433 .58414 Mdot
.66504 .40497 Mdot
.61468 .29473 Mdot
.65236 .65286 Mdot
.38626 .44507 Mdot
.3389 .47527 Mdot
.60635 .31638 Mdot
.68065 .60308 Mdot
.34108 .42945 Mdot
.57766 .75554 Mdot
.39657 .30781 Mdot
.63999 .63125 Mdot
.35932 .39873 Mdot
.3554 .76946 Mdot
.48511 .70139 Mdot
.83249 .47725 Mdot
.60447 .23133 Mdot
.69182 .40532 Mdot
.3715 .37781 Mdot
.8897 .57435 Mdot
.62491 .28338 Mdot
.63751 .76632 Mdot
.40728 .46648 Mdot
.38757 .43699 Mdot
.44563 .70194 Mdot
.3421 .43656 Mdot
.4695 .70129 Mdot
.56453 .34314 Mdot
.45994 .84783 Mdot
.48946 .68382 Mdot
.47786 .69234 Mdot
.35623 .52664 Mdot
.58252 .23889 Mdot
.45153 .68286 Mdot
.36284 .42245 Mdot
.70767 .28764 Mdot
.36635 .5197 Mdot
.6275 .30992 Mdot
.616 .33977 Mdot
.46064 .64753 Mdot
.35401 .67967 Mdot
.36561 .52847 Mdot
.32973 .72475 Mdot
.62426 .34557 Mdot
.67719 .6361 Mdot
.35555 .48944 Mdot
.50554 .59814 Mdot
.66965 .42857 Mdot
.42635 .40328 Mdot
.38975 .42542 Mdot
.4447 .66721 Mdot
.58931 .31648 Mdot
.68372 .62543 Mdot
.37396 .49842 Mdot
.71666 .45002 Mdot
.60212 .31158 Mdot
.49402 .6587 Mdot
.37166 .71265 Mdot
.6056 .24595 Mdot
.35628 .37796 Mdot
.40931 .47047 Mdot
.40378 .49394 Mdot
.30183 .43264 Mdot
.661 .60217 Mdot
.65104 .4032 Mdot
.3597 .3775 Mdot
.47594 .40636 Mdot
.39763 .29974 Mdot
.41655 .43338 Mdot
.48027 .6484 Mdot
.64543 .61455 Mdot
.5098 .58724 Mdot
.41215 .19354 Mdot
.41259 .475 Mdot
.3336 .74934 Mdot
.53341 .26096 Mdot
.49883 .58922 Mdot
.50512 .69118 Mdot
.60999 .29493 Mdot
.38743 .49325 Mdot
.34284 .30296 Mdot
.35225 .45002 Mdot
.32977 .4908 Mdot
.68146 .40229 Mdot
.67404 .63365 Mdot
.27022 .38979 Mdot
.67064 .42443 Mdot
.47245 .66328 Mdot
.29507 .71489 Mdot
.4928 .70842 Mdot
.50129 .68545 Mdot
.45068 .61034 Mdot
.67007 .58994 Mdot
.89457 .56592 Mdot
.58044 .20477 Mdot
.41107 .43079 Mdot
.69675 .60915 Mdot
.45499 .67952 Mdot
.35678 .42198 Mdot
.4675 .70055 Mdot
.45714 .6474 Mdot
.36544 .47409 Mdot
.36055 .46904 Mdot
.33107 .3012 Mdot
.34993 .75502 Mdot
.61814 .27797 Mdot
.46796 .71128 Mdot
.34975 .73223 Mdot
.38693 .44064 Mdot
.37389 .42272 Mdot
.57394 .53281 Mdot
.6235 .3063 Mdot
.2162 .58201 Mdot
.39767 .47372 Mdot
.48145 .26957 Mdot
.37442 .41713 Mdot
.47838 .7269 Mdot
.69201 .64058 Mdot
.43076 .52646 Mdot
.68235 .39728 Mdot
.47204 .71202 Mdot
.58609 .31003 Mdot
.50959 .68103 Mdot
.24208 .61317 Mdot
.65578 .60108 Mdot
.4813 .68818 Mdot
.64223 .41087 Mdot
.67912 .60892 Mdot
.66786 .58688 Mdot
.56882 .52063 Mdot
.63931 .42996 Mdot
.59166 .32071 Mdot
.66507 .6278 Mdot
.27935 .66756 Mdot
.67078 .61376 Mdot
.23691 .61448 Mdot
.42108 .46697 Mdot
.3465 .30497 Mdot
.42213 .39674 Mdot
.42426 .49813 Mdot
.67363 .62177 Mdot
.60234 .31356 Mdot
.34545 .42463 Mdot
.49282 .68222 Mdot
.622 .29163 Mdot
.41632 .62655 Mdot
.63711 .4317 Mdot
.45706 .6373 Mdot
.63569 .60968 Mdot
.4548 .7053 Mdot
.44201 .2789 Mdot
.61478 .33602 Mdot
.58667 .52243 Mdot
.45697 .34794 Mdot
.31652 .40079 Mdot
.32821 .42803 Mdot
.34746 .42154 Mdot
.36195 .4385 Mdot
.68406 .44652 Mdot
.58323 .27399 Mdot
.48508 .6487 Mdot
.22918 .45816 Mdot
.67724 .59511 Mdot
.54173 .49098 Mdot
.30297 .42937 Mdot
.3442 .47857 Mdot
.45732 .67848 Mdot
.46468 .64198 Mdot
.33825 .56193 Mdot
.65532 .41918 Mdot
.3953 .51955 Mdot
.39052 .408 Mdot
.28655 .37256 Mdot
.67663 .61936 Mdot
.63676 .72816 Mdot
.69817 .46135 Mdot
.64672 .85447 Mdot
.67233 .42488 Mdot
.58289 .45694 Mdot
.46212 .7004 Mdot
.60061 .28301 Mdot
.36678 .46494 Mdot
.4398 .56341 Mdot
.50228 .65201 Mdot
.70185 .49272 Mdot
.60482 .29231 Mdot
.66613 .68174 Mdot
.6963 .61814 Mdot
.37279 .49885 Mdot
.37327 .417 Mdot
.34118 .46057 Mdot
.34915 .43405 Mdot
.67092 .64088 Mdot
.35275 .45942 Mdot
.63707 .63866 Mdot
.2396 .60289 Mdot
.42351 .25786 Mdot
.64468 .4235 Mdot
.7371 .48922 Mdot
.50078 .68308 Mdot
.23313 .64256 Mdot
.22523 .58382 Mdot
.36555 .31564 Mdot
.64208 .6592 Mdot
.34063 .4904 Mdot
.67571 .40626 Mdot
.60064 .61585 Mdot
.64461 .42931 Mdot
.24093 .72115 Mdot
.37672 .67206 Mdot
.69462 .68 Mdot
.34179 .45429 Mdot
.66461 .39875 Mdot
.35252 .69777 Mdot
.37825 .37255 Mdot
.60954 .24621 Mdot
.25358 .63539 Mdot
.42319 .5976 Mdot
.61706 .27258 Mdot
.37714 .47734 Mdot
.48515 .62538 Mdot
.36467 .46037 Mdot
.36874 .46916 Mdot
.41483 .45643 Mdot
.66582 .64704 Mdot
.42263 .45939 Mdot
.36335 .42953 Mdot
.42662 .1634 Mdot
.73653 .41981 Mdot
.6995 .44695 Mdot
.27784 .50015 Mdot
.6196 .29008 Mdot
.49378 .71555 Mdot
.45712 .33485 Mdot
.6818 .59356 Mdot
.33324 .55932 Mdot
.36557 .48195 Mdot
.59107 .78785 Mdot
.65862 .58696 Mdot
.58783 .29064 Mdot
.50386 .59677 Mdot
.65545 .69583 Mdot
.70652 .41101 Mdot
.51427 .59183 Mdot
.67443 .45062 Mdot
.23737 .41916 Mdot
.47386 .69787 Mdot
.31685 .40042 Mdot
.678 .6283 Mdot
.64335 .43713 Mdot
.34004 .30701 Mdot
.3774 .4273 Mdot
.67244 .40161 Mdot
.39006 .37819 Mdot
.42833 .30899 Mdot
.46145 .33506 Mdot
.64299 .41423 Mdot
.6703 .57781 Mdot
.67877 .61466 Mdot
.62131 .27464 Mdot
.4855 .69896 Mdot
.4471 .6674 Mdot
.67243 .61658 Mdot
.81479 .58877 Mdot
.38494 .44631 Mdot
.4012 .44299 Mdot
.48116 .41845 Mdot
.36595 .41336 Mdot
.63265 .31402 Mdot
.52194 .58208 Mdot
.45671 .65472 Mdot
.34755 .4223 Mdot
.34048 .43052 Mdot
.40628 .47666 Mdot
.37631 .28433 Mdot
.67776 .44288 Mdot
.39667 .48828 Mdot
.59288 .27354 Mdot
.41862 .61649 Mdot
.35665 .43684 Mdot
.35621 .37708 Mdot
.46644 .70309 Mdot
.63354 .48958 Mdot
.67543 .59756 Mdot
.65606 .44697 Mdot
.65406 .44898 Mdot
.44084 .22921 Mdot
.47686 .71529 Mdot
.51771 .58857 Mdot
.68511 .52531 Mdot
.51112 .58876 Mdot
.60267 .29259 Mdot
.53928 .50695 Mdot
.63117 .41322 Mdot
.69762 .4484 Mdot
.70846 .61332 Mdot
.35303 .40826 Mdot
.35746 .43286 Mdot
.66678 .75057 Mdot
.40976 .44662 Mdot
.6143 .27475 Mdot
.6901 .59278 Mdot
.47875 .68895 Mdot
.60469 .25915 Mdot
.6885 .60858 Mdot
.45173 .66415 Mdot
.41552 .41636 Mdot
.3655 .41868 Mdot
.46723 .66425 Mdot
.49601 .66408 Mdot
.37734 .45703 Mdot
.35847 .22935 Mdot
.4656 .64879 Mdot
.46161 .66715 Mdot
.42083 .60947 Mdot
.70873 .41958 Mdot
.39763 .3644 Mdot
.68539 .59335 Mdot
.36501 .42921 Mdot
.64623 .41872 Mdot
.6 .30161 Mdot
.48512 .65879 Mdot
.35581 .49145 Mdot
.3925 .44599 Mdot
.61281 .29977 Mdot
.62864 .27785 Mdot
.62278 .3019 Mdot
.7027 .61706 Mdot
.36213 .4756 Mdot
.45318 .67532 Mdot
.69472 .62537 Mdot
.59817 .25468 Mdot
.6289 .29824 Mdot
.31386 .28065 Mdot
.37993 .44931 Mdot
.61674 .25677 Mdot
.80996 .68668 Mdot
.31314 .29953 Mdot
.51178 .55999 Mdot
.67456 .47465 Mdot
.65516 .21924 Mdot
.641 .2547 Mdot
.66912 .63633 Mdot
.54531 .48776 Mdot
.60513 .32191 Mdot
.38216 .49709 Mdot
.39142 .43088 Mdot
.31274 .4127 Mdot
.62092 .2951 Mdot
.40441 .27954 Mdot
.43816 .69654 Mdot
.24845 .54486 Mdot
.61955 .2897 Mdot
.64136 .43282 Mdot
.72227 .43006 Mdot
.6748 .41739 Mdot
.31673 .4582 Mdot
.231 .42478 Mdot
.27884 .64656 Mdot
.21347 .57152 Mdot
.69566 .61509 Mdot
.4611 .64385 Mdot
.40817 .66145 Mdot
.47475 .66181 Mdot
.66422 .43435 Mdot
.59995 .3118 Mdot
.44157 .69755 Mdot
.66536 .58863 Mdot
.67649 .61767 Mdot
.69145 .39647 Mdot
.6773 .43552 Mdot
.68433 .4218 Mdot
.47673 .70851 Mdot
.4636 .69972 Mdot
.33674 .44509 Mdot
.49039 .6617 Mdot
.55278 .25049 Mdot
.55276 .3167 Mdot
.70882 .40345 Mdot
.6637 .60494 Mdot
.47274 .65456 Mdot
.39996 .43039 Mdot
.54533 .45029 Mdot
.66075 .3841 Mdot
.58603 .27795 Mdot
.4852 .80361 Mdot
.43632 .85226 Mdot
.33015 .43675 Mdot
.65083 .63497 Mdot
.40704 .54067 Mdot
.36444 .43853 Mdot
.68572 .40069 Mdot
.53448 .23563 Mdot
.49545 .58777 Mdot
.35854 .45188 Mdot
.41746 .42074 Mdot
.65332 .60101 Mdot
.45562 .33616 Mdot
.37439 .49741 Mdot
.56575 .49878 Mdot
.675 .57727 Mdot
.70255 .4573 Mdot
.57035 .14926 Mdot
.4554 .55448 Mdot
.48512 .29358 Mdot
.50376 .56233 Mdot
.41594 .47196 Mdot
.68987 .4344 Mdot
.59325 .26589 Mdot
.68457 .43251 Mdot
.49691 .71583 Mdot
.70608 .41208 Mdot
.4112 .44421 Mdot
.45086 .67935 Mdot
.68313 .60367 Mdot
.51392 .44322 Mdot
.24596 .44471 Mdot
.66335 .4625 Mdot
.51781 .55839 Mdot
.36069 .46833 Mdot
.27462 .66888 Mdot
.42701 .49607 Mdot
.37033 .42189 Mdot
.65353 .62914 Mdot
.45845 .68841 Mdot
.64736 .60506 Mdot
.4114 .37335 Mdot
.48117 .7519 Mdot
.67189 .59528 Mdot
.45277 .52896 Mdot
.60009 .31707 Mdot
.39588 .28334 Mdot
.39091 .46875 Mdot
.67903 .6289 Mdot
.37564 .48147 Mdot
.46495 .71228 Mdot
.377 .30297 Mdot
.38909 .31314 Mdot
.65691 .623 Mdot
.56662 .58571 Mdot
.45296 .31348 Mdot
.39618 .36376 Mdot
.68938 .62561 Mdot
.24686 .34806 Mdot
.50229 .58799 Mdot
.60008 .30889 Mdot
.63094 .28222 Mdot
.59528 .28177 Mdot
.40126 .43965 Mdot
.36119 .74884 Mdot
.6229 .27343 Mdot
.69114 .58359 Mdot
.6077 .26582 Mdot
.52982 .30751 Mdot
.66489 .75818 Mdot
.60026 .31607 Mdot
.39782 .46529 Mdot
.44114 .49748 Mdot
.54123 .48651 Mdot
.655 .46325 Mdot
.60233 .67599 Mdot
.43569 .15898 Mdot
.38352 .44036 Mdot
.43892 .76839 Mdot
.46686 .74045 Mdot
.58433 .42797 Mdot
.38014 .31595 Mdot
.51157 .47056 Mdot
.46717 .65903 Mdot
.45652 .34193 Mdot
.49697 .64946 Mdot
.31438 .40165 Mdot
.40238 .45018 Mdot
.4721 .71266 Mdot
.53063 .80007 Mdot
.23807 .34454 Mdot
.62612 .77958 Mdot
.46413 .65426 Mdot
.69165 .61801 Mdot
.65167 .6316 Mdot
.65555 .63009 Mdot
.69144 .44299 Mdot
.48267 .68958 Mdot
.40732 .48409 Mdot
.69997 .4154 Mdot
.37901 .47362 Mdot
.66279 .6199 Mdot
.3722 .31446 Mdot
.47707 .692 Mdot
.38467 .46589 Mdot
.35045 .71489 Mdot
.67021 .44904 Mdot
.61587 .29803 Mdot
.47412 .79703 Mdot
.64741 .46669 Mdot
.65227 .59015 Mdot
.49926 .71544 Mdot
.72378 .45385 Mdot
.57088 .47554 Mdot
.41806 .44002 Mdot
.40018 .42075 Mdot
.5493 .48474 Mdot
.37374 .68864 Mdot
.35392 .49458 Mdot
.70228 .42362 Mdot
.70767 .4338 Mdot
.38092 .48215 Mdot
.48638 .68574 Mdot
.609 .32491 Mdot
.59985 .24703 Mdot
.31129 .46604 Mdot
.46448 .34533 Mdot
.3452 .30535 Mdot
.34929 .42476 Mdot
.33726 .39307 Mdot
.64036 .41355 Mdot
.50996 .55859 Mdot
.46254 .35665 Mdot
.6017 .27558 Mdot
.40471 .47118 Mdot
.26 .49609 Mdot
.48723 .67308 Mdot
.66962 .40246 Mdot
.68239 .6409 Mdot
.60688 .24591 Mdot
.71077 .40815 Mdot
.38106 .48215 Mdot
.34101 .42978 Mdot
.6801 .62522 Mdot
.47785 .72621 Mdot
.61316 .30922 Mdot
.70126 .4166 Mdot
.60171 .27973 Mdot
.46761 .6972 Mdot
.48224 .65384 Mdot
.40569 .41899 Mdot
.41649 .50876 Mdot
.66508 .46071 Mdot
.32836 .48469 Mdot
.68985 .41221 Mdot
.71083 .50605 Mdot
.65015 .64023 Mdot
.37139 .40486 Mdot
.47538 .71939 Mdot
.66662 .61975 Mdot
.37889 .44063 Mdot
.55545 .48487 Mdot
.33249 .4459 Mdot
.65912 .39992 Mdot
.53997 .21561 Mdot
.59506 .29622 Mdot
.43543 .43578 Mdot
.40586 .57945 Mdot
.36138 .41573 Mdot
.69378 .45745 Mdot
.27435 .65453 Mdot
.66623 .59616 Mdot
.45525 .6988 Mdot
.62294 .44428 Mdot
.66864 .61049 Mdot
.40214 .46576 Mdot
.61193 .27932 Mdot
.48783 .64685 Mdot
.51156 .56672 Mdot
.48064 .36242 Mdot
.44898 .45096 Mdot
.36869 .51719 Mdot
.3618 .49737 Mdot
.70799 .7406 Mdot
.68447 .42512 Mdot
.45636 .67752 Mdot
.65443 .63693 Mdot
.65925 .59768 Mdot
.66983 .44558 Mdot
.42798 .59156 Mdot
.57119 .80669 Mdot
.83875 .65298 Mdot
.71318 .40988 Mdot
.59947 .27137 Mdot
.37689 .30419 Mdot
.6741 .41596 Mdot
.68306 .45015 Mdot
.64035 .40727 Mdot
.6738 .74685 Mdot
.45966 .65913 Mdot
.39272 .44492 Mdot
.41861 .7419 Mdot
.41402 .45667 Mdot
.48539 .30366 Mdot
.66251 .61891 Mdot
.45526 .6992 Mdot
.57414 .35999 Mdot
.32148 .43961 Mdot
.3664 .44862 Mdot
.60349 .3654 Mdot
.35847 .53113 Mdot
.41 .19948 Mdot
.38721 .41187 Mdot
.6844 .43973 Mdot
.42039 .69755 Mdot
.35505 .37881 Mdot
.3509 .71751 Mdot
.68218 .61388 Mdot
.51654 .57684 Mdot
.33161 .38634 Mdot
.31446 .41682 Mdot
.49802 .6515 Mdot
.43974 .69442 Mdot
.62902 .28638 Mdot
.47095 .78508 Mdot
.68388 .61104 Mdot
.65911 .72467 Mdot
.37042 .4212 Mdot
.69453 .6648 Mdot
.54516 .22511 Mdot
.37492 .44509 Mdot
.56666 .51738 Mdot
.33877 .56195 Mdot
.34523 .48482 Mdot
.21667 .56132 Mdot
.66253 .61032 Mdot
.44689 .26521 Mdot
.34796 .45369 Mdot
.67463 .40244 Mdot
.44485 .68493 Mdot
.45882 .63572 Mdot
.59516 .26198 Mdot
.57346 .225 Mdot
.51426 .85871 Mdot
.45468 .69985 Mdot
.37569 .42649 Mdot
.67203 .59879 Mdot
.51598 .57003 Mdot
.43207 .41051 Mdot
.57581 .57093 Mdot
.48643 .67125 Mdot
.3744 .37414 Mdot
.58657 .79103 Mdot
.4565 .33897 Mdot
.24632 .67137 Mdot
.65845 .62907 Mdot
.60753 .27046 Mdot
.324 .49572 Mdot
.69421 .52112 Mdot
.36747 .41745 Mdot
.4848 .30025 Mdot
.43201 .70928 Mdot
.61264 .27221 Mdot
.36375 .45088 Mdot
.34735 .49159 Mdot
.41102 .33437 Mdot
.62958 .30757 Mdot
.36376 .49655 Mdot
.3289 .43656 Mdot
.44252 .68996 Mdot
.52259 .57987 Mdot
.47987 .68568 Mdot
.36625 .46123 Mdot
.52293 .19879 Mdot
.46445 .70958 Mdot
.59902 .6588 Mdot
.58871 .24746 Mdot
.68344 .59461 Mdot
.39015 .38241 Mdot
.41983 .45284 Mdot
.2458 .68182 Mdot
.5185 .56982 Mdot
.76622 .65827 Mdot
.66035 .40173 Mdot
.38101 .18505 Mdot
.64378 .46431 Mdot
.63123 .65972 Mdot
.63965 .5307 Mdot
.35063 .38235 Mdot
.42572 .58778 Mdot
.20785 .5704 Mdot
.64369 .58778 Mdot
.22501 .63226 Mdot
.36447 .42545 Mdot
.40601 .47361 Mdot
.68719 .40845 Mdot
.66835 .66828 Mdot
.43143 .52601 Mdot
.46288 .35563 Mdot
.58802 .29562 Mdot
.47331 .67354 Mdot
.39535 .43127 Mdot
.51611 .79775 Mdot
.64566 .44763 Mdot
.25717 .46649 Mdot
.38846 .46597 Mdot
.39802 .53997 Mdot
.64686 .6626 Mdot
.68298 .60195 Mdot
.64347 .41208 Mdot
.64036 .43588 Mdot
.41555 .46756 Mdot
.67765 .64064 Mdot
.33826 .46091 Mdot
.44618 .30956 Mdot
.38256 .37781 Mdot
.60224 .29703 Mdot
.38752 .42243 Mdot
.37492 .55096 Mdot
.15476 .48486 Mdot
.32966 .42823 Mdot
.49949 .6916 Mdot
.68676 .41888 Mdot
.67256 .44133 Mdot
.4494 .66376 Mdot
.67171 .44138 Mdot
.25025 .54972 Mdot
.3621 .75466 Mdot
.60212 .28891 Mdot
.24725 .59116 Mdot
.59186 .29885 Mdot
.51619 .57867 Mdot
.37873 .45177 Mdot
.7835 .45207 Mdot
.71535 .41685 Mdot
.52518 .29456 Mdot
.66987 .61635 Mdot
.51987 .57087 Mdot
.35912 .46915 Mdot
.63234 .33828 Mdot
.66588 .42071 Mdot
.47788 .539 Mdot
.41317 .46043 Mdot
.47283 .70984 Mdot
.34653 .48313 Mdot
.32803 .51393 Mdot
.52098 .58241 Mdot
.33329 .4765 Mdot
.68851 .60844 Mdot
.47416 .70127 Mdot
.70109 .68186 Mdot
.67624 .45395 Mdot
.35874 .45899 Mdot
.37241 .42807 Mdot
.48409 .64105 Mdot
.41047 .43105 Mdot
.68535 .6359 Mdot
.91311 .49808 Mdot
.61868 .30912 Mdot
.5082 .55886 Mdot
.57258 .69656 Mdot
.33453 .47912 Mdot
.34037 .42553 Mdot
.50128 .49764 Mdot
.25423 .49013 Mdot
.68611 .599 Mdot
.36739 .51389 Mdot
.70462 .43752 Mdot
.61016 .31153 Mdot
.65959 .59051 Mdot
.35532 .46827 Mdot
.4089 .45593 Mdot
.61199 .2732 Mdot
.59216 .36694 Mdot
.63375 .27891 Mdot
.67215 .63796 Mdot
.52759 .65713 Mdot
.54693 .4496 Mdot
.3875 .45226 Mdot
.51988 .55635 Mdot
.46021 .68398 Mdot
.68874 .6286 Mdot
.31359 .55839 Mdot
.31303 .40356 Mdot
.63337 .61822 Mdot
.68381 .60539 Mdot
.41845 .44308 Mdot
.47626 .71452 Mdot
.49606 .72129 Mdot
.45885 .68096 Mdot
.42699 .25099 Mdot
.75325 .66198 Mdot
.68766 .42323 Mdot
.66585 .60547 Mdot
.64766 .41989 Mdot
.6065 .32057 Mdot
.40809 .30069 Mdot
.64923 .45493 Mdot
.45143 .71711 Mdot
.64592 .4338 Mdot
.33655 .45625 Mdot
.67577 .58604 Mdot
.66819 .45939 Mdot
.35257 .42679 Mdot
.30943 .44856 Mdot
.29808 .46426 Mdot
.59724 .32377 Mdot
.46084 .34057 Mdot
.39435 .47086 Mdot
.50409 .59575 Mdot
.38124 .46098 Mdot
.68285 .63785 Mdot
.51313 .42992 Mdot
.38976 .48687 Mdot
.71552 .41679 Mdot
.75769 .67529 Mdot
.70913 .43774 Mdot
.27852 .45554 Mdot
.37454 .46746 Mdot
.38514 .4502 Mdot
.36236 .47172 Mdot
.41726 .60922 Mdot
.64081 .60303 Mdot
.35399 .507 Mdot
.6757 .39541 Mdot
.47633 .65947 Mdot
.45478 .7116 Mdot
.51159 .50205 Mdot
.51241 .59386 Mdot
.69285 .63099 Mdot
.38524 .44841 Mdot
.47968 .53872 Mdot
.48319 .39813 Mdot
.60103 .79193 Mdot
.67416 .47786 Mdot
.69265 .45446 Mdot
.49423 .68714 Mdot
.69644 .44425 Mdot
.35469 .46513 Mdot
.37118 .37492 Mdot
.69804 .68309 Mdot
.69115 .57047 Mdot
.60851 .31132 Mdot
.3747 .47081 Mdot
.35724 .28658 Mdot
.70478 .42184 Mdot
.63925 .41917 Mdot
.33916 .46174 Mdot
.45449 .73998 Mdot
.17619 .41718 Mdot
.69691 .60807 Mdot
.29105 .68538 Mdot
.39559 .73342 Mdot
.31883 .34742 Mdot
.65957 .60085 Mdot
.56415 .51181 Mdot
.6612 .46636 Mdot
.52254 .18337 Mdot
.47259 .65916 Mdot
.61158 .3096 Mdot
.35905 .42331 Mdot
.45009 .71704 Mdot
.70426 .3966 Mdot
.48233 .64427 Mdot
.32825 .38962 Mdot
.66314 .58493 Mdot
.67079 .43253 Mdot
.70616 .61264 Mdot
.50009 .7055 Mdot
.59274 .29801 Mdot
.4792 .27438 Mdot
.2697 .66068 Mdot
.34617 .56528 Mdot
.39644 .48885 Mdot
.72869 .39197 Mdot
.40673 .48559 Mdot
.43769 .66121 Mdot
.39188 .46859 Mdot
.33668 .40732 Mdot
.64923 .46134 Mdot
.41622 .43243 Mdot
.37847 .42104 Mdot
.34996 .72145 Mdot
.37117 .44752 Mdot
.38742 .48173 Mdot
.41039 .42186 Mdot
.46635 .71659 Mdot
.41122 .42637 Mdot
.48316 .69942 Mdot
.61961 .77573 Mdot
.67412 .45287 Mdot
.60944 .31997 Mdot
.60495 .31879 Mdot
.4919 .29776 Mdot
.36336 .28583 Mdot
.4065 .69759 Mdot
.4823 .67076 Mdot
.67436 .62077 Mdot
.33662 .453 Mdot
.25754 .31836 Mdot
.51486 .20499 Mdot
.68457 .46628 Mdot
.65804 .45582 Mdot
.35293 .43558 Mdot
.42086 .84862 Mdot
.38541 .41299 Mdot
.48462 .42253 Mdot
.4022 .44079 Mdot
.36928 .40539 Mdot
.64593 .40369 Mdot
.44431 .28016 Mdot
.39698 .4881 Mdot
.49872 .6521 Mdot
.60867 .30904 Mdot
.3857 .53858 Mdot
.51031 .22588 Mdot
.38561 .73503 Mdot
.4255 .55165 Mdot
.37629 .48417 Mdot
.69648 .40855 Mdot
.47282 .6491 Mdot
.47878 .40522 Mdot
.6927 .62725 Mdot
.47776 .34834 Mdot
.23362 .6062 Mdot
.6379 .59206 Mdot
.60369 .31154 Mdot
.69793 .38897 Mdot
.41722 .46206 Mdot
.69345 .43452 Mdot
.34315 .49799 Mdot
.48792 .40284 Mdot
.60079 .29248 Mdot
.46277 .62679 Mdot
.69175 .61613 Mdot
.44483 .7122 Mdot
.26354 .48642 Mdot
.51656 .20221 Mdot
.38809 .17768 Mdot
.71298 .4192 Mdot
.22843 .49052 Mdot
.45305 .69042 Mdot
.41434 .473 Mdot
.83673 .65458 Mdot
.46429 .68687 Mdot
.47185 .71092 Mdot
.49793 .40333 Mdot
.42722 .26941 Mdot
.33338 .4889 Mdot
.46598 .64767 Mdot
.69892 .38975 Mdot
.60807 .29148 Mdot
.34772 .43242 Mdot
.33482 .38518 Mdot
.44293 .69897 Mdot
.66369 .42734 Mdot
.4619 .29401 Mdot
.68081 .43855 Mdot
.45491 .66565 Mdot
.65895 .44475 Mdot
.612 .65707 Mdot
.65142 .4564 Mdot
.40576 .43122 Mdot
.38599 .44905 Mdot
.48326 .57517 Mdot
.48227 .65385 Mdot
.34117 .42512 Mdot
.40842 .46386 Mdot
.45269 .68046 Mdot
.63409 .40027 Mdot
.2674 .51251 Mdot
.33729 .42648 Mdot
.38832 .44544 Mdot
.62064 .30921 Mdot
.44052 .32239 Mdot
.49084 .45018 Mdot
.35319 .42417 Mdot
.59493 .27932 Mdot
.47801 .707 Mdot
.37876 .45985 Mdot
.44722 .28044 Mdot
.71214 .45195 Mdot
.34799 .46742 Mdot
.51222 .57016 Mdot
.41238 .4837 Mdot
.18569 .44938 Mdot
.35858 .4641 Mdot
.4599 .66451 Mdot
.4471 .68675 Mdot
.62377 .43066 Mdot
.46991 .66556 Mdot
.51153 .56062 Mdot
.67756 .615 Mdot
.26545 .67905 Mdot
.51525 .56131 Mdot
.33551 .47567 Mdot
.58467 .20587 Mdot
.34272 .38162 Mdot
.38254 .37152 Mdot
.58726 .23393 Mdot
.50346 .56328 Mdot
.45926 .69311 Mdot
.52675 .78986 Mdot
.40115 .50509 Mdot
.69453 .62833 Mdot
.35133 .37967 Mdot
.34895 .46872 Mdot
.3438 .40305 Mdot
.49313 .74128 Mdot
.69944 .61758 Mdot
.40088 .36456 Mdot
.34746 .43252 Mdot
.2558 .49143 Mdot
.3898 .4275 Mdot
.58488 .29365 Mdot
.47452 .69087 Mdot
.69695 .43988 Mdot
.60482 .29681 Mdot
.36542 .4976 Mdot
.62059 .29034 Mdot
.69204 .43022 Mdot
.67009 .62952 Mdot
.40834 .4342 Mdot
.62597 .31352 Mdot
.59462 .30956 Mdot
.36817 .48919 Mdot
.44791 .69486 Mdot
.42872 .49412 Mdot
.37629 .45712 Mdot
.36466 .47528 Mdot
.4458 .67002 Mdot
.82915 .44577 Mdot
.40472 .47657 Mdot
.56606 .51279 Mdot
.44284 .65058 Mdot
.52309 .57479 Mdot
.70208 .43028 Mdot
.32786 .45205 Mdot
.66462 .59236 Mdot
.67591 .61466 Mdot
.71776 .42899 Mdot
.44025 .69311 Mdot
.66938 .43627 Mdot
.32978 .42638 Mdot
.36079 .37727 Mdot
.35604 .42735 Mdot
.62501 .39551 Mdot
.64895 .68739 Mdot
.49193 .6533 Mdot
.69678 .45568 Mdot
.47099 .34938 Mdot
.67971 .58846 Mdot
.65049 .39564 Mdot
.4921 .63822 Mdot
.44086 .67342 Mdot
.45645 .65693 Mdot
.59072 .28351 Mdot
.67388 .42949 Mdot
.5061 .69856 Mdot
.50985 .67496 Mdot
.35016 .47638 Mdot
.34397 .43645 Mdot
.48363 .70261 Mdot
.66274 .50379 Mdot
.59722 .30354 Mdot
.70054 .40978 Mdot
.16391 .43621 Mdot
.69793 .61361 Mdot
.35095 .72096 Mdot
.3566 .42149 Mdot
.67514 .84446 Mdot
.38583 .41275 Mdot
.38047 .42553 Mdot
.49329 .7157 Mdot
.63189 .28084 Mdot
.61003 .28883 Mdot
.45224 .69053 Mdot
.45359 .6512 Mdot
.5878 .27457 Mdot
.51088 .45636 Mdot
.19107 .42835 Mdot
.477 .39271 Mdot
.48762 .65018 Mdot
.25441 .64937 Mdot
.65213 .6199 Mdot
.42985 .68346 Mdot
.60726 .5889 Mdot
.66661 .4528 Mdot
.65825 .45961 Mdot
.6767 .62476 Mdot
.39893 .47974 Mdot
.69181 .39978 Mdot
.39392 .39998 Mdot
.67643 .67892 Mdot
.56826 .5729 Mdot
.31333 .25368 Mdot
.41111 .43505 Mdot
.36728 .54067 Mdot
.69174 .74826 Mdot
.33302 .45977 Mdot
.36643 .65459 Mdot
.61678 .30502 Mdot
.43288 .67487 Mdot
.69353 .59469 Mdot
.44399 .77303 Mdot
.38659 .45119 Mdot
.48126 .64875 Mdot
.69232 .59784 Mdot
.66788 .68736 Mdot
.56528 .49937 Mdot
.34765 .47979 Mdot
.86781 .60943 Mdot
.50164 .65323 Mdot
.69736 .43854 Mdot
.3068 .6687 Mdot
.4365 .70633 Mdot
.5701 .48272 Mdot
.70272 .39333 Mdot
.45204 .36142 Mdot
.47338 .64353 Mdot
.63268 .27468 Mdot
.47536 .67769 Mdot
.61057 .26038 Mdot
.50196 .70867 Mdot
.66264 .44235 Mdot
.36878 .45705 Mdot
.66766 .44695 Mdot
.58744 .2703 Mdot
.71362 .41861 Mdot
.69316 .5942 Mdot
.49926 .56661 Mdot
.66275 .62058 Mdot
.38862 .30128 Mdot
.32229 .57402 Mdot
.67303 .63357 Mdot
.50093 .52874 Mdot
.4113 .44685 Mdot
.47819 .72723 Mdot
.69372 .44387 Mdot
.6493 .4647 Mdot
.46204 .34225 Mdot
.4516 .66729 Mdot
.66126 .42998 Mdot
.26231 .65328 Mdot
.80843 .60278 Mdot
.33027 .41279 Mdot
.72484 .55658 Mdot
.45477 .67294 Mdot
.63843 .44513 Mdot
.48253 .42109 Mdot
.43616 .68967 Mdot
.66579 .46001 Mdot
.68852 .62527 Mdot
.66663 .59236 Mdot
.40509 .42648 Mdot
.69998 .59477 Mdot
.6599 .46464 Mdot
.24624 .48196 Mdot
.46051 .70331 Mdot
.6346 .68633 Mdot
.6068 .31497 Mdot
.68802 .44649 Mdot
.42176 .48646 Mdot
.47114 .7196 Mdot
.64677 .42891 Mdot
.48977 .85517 Mdot
.1346 .51633 Mdot
.66151 .42768 Mdot
.47528 .68939 Mdot
.48413 .6597 Mdot
.32103 .4538 Mdot
.4633 .34959 Mdot
.66504 .41922 Mdot
.78243 .4509 Mdot
.33701 .30221 Mdot
.50398 .56903 Mdot
.43033 .16159 Mdot
.39849 .48695 Mdot
.37255 .48324 Mdot
.67446 .63835 Mdot
.36713 .44493 Mdot
.46046 .64568 Mdot
.38484 .41222 Mdot
.64436 .61052 Mdot
.71455 .44167 Mdot
.38202 .45339 Mdot
.61022 .31225 Mdot
.6447 .61913 Mdot
.64451 .62817 Mdot
.65558 .44355 Mdot
.44087 .68787 Mdot
.54131 .81814 Mdot
.6791 .4382 Mdot
.3625 .47642 Mdot
.50021 .58957 Mdot
.41433 .42838 Mdot
.47857 .59373 Mdot
.44748 .64666 Mdot
.6972 .44254 Mdot
.50597 .60551 Mdot
.67028 .60349 Mdot
.65975 .46694 Mdot
.41593 .47954 Mdot
.67917 .46188 Mdot
.58325 .51526 Mdot
.68837 .26747 Mdot
.50239 .64722 Mdot
.58126 .49026 Mdot
.43761 .68335 Mdot
.50662 .56622 Mdot
.43095 .23154 Mdot
.59908 .30753 Mdot
.70818 .42877 Mdot
.60037 .65863 Mdot
.68001 .45451 Mdot
.37296 .44402 Mdot
.40985 .45603 Mdot
.68907 .40918 Mdot
.59237 .29135 Mdot
.53278 .33126 Mdot
.6316 .26427 Mdot
.48297 .68712 Mdot
.52419 .47939 Mdot
.16742 .41304 Mdot
.70785 .46101 Mdot
.67885 .62027 Mdot
.43102 .55703 Mdot
.34094 .4832 Mdot
.6979 .60733 Mdot
.64921 .63693 Mdot
.60159 .25514 Mdot
.68348 .45101 Mdot
.47213 .62542 Mdot
.66632 .58526 Mdot
.4454 .72215 Mdot
.46145 .28937 Mdot
.30813 .41252 Mdot
.31356 .35713 Mdot
.3528 .49573 Mdot
.45803 .33846 Mdot
.65975 .58691 Mdot
.40256 .45942 Mdot
.3223 .48786 Mdot
.69348 .61949 Mdot
.60588 .2555 Mdot
.54547 .6092 Mdot
.65977 .42919 Mdot
.77402 .72109 Mdot
.40296 .4296 Mdot
.37308 .45902 Mdot
.69569 .61387 Mdot
.36516 .6898 Mdot
.50007 .66523 Mdot
.44425 .69488 Mdot
.68411 .42439 Mdot
.49824 .41914 Mdot
.415 .4364 Mdot
.4094 .43835 Mdot
.67619 .40084 Mdot
.50554 .59419 Mdot
.40462 .17619 Mdot
.39351 .44742 Mdot
.6599 .60815 Mdot
.57228 .52969 Mdot
.6724 .57837 Mdot
.36691 .40085 Mdot
.3768 .43886 Mdot
.4096 .49002 Mdot
.4215 .47432 Mdot
.65835 .62246 Mdot
.35558 .49592 Mdot
.36055 .50589 Mdot
.45964 .68917 Mdot
.3881 .4853 Mdot
.33492 .30252 Mdot
.39207 .45047 Mdot
.61574 .30777 Mdot
.49364 .44839 Mdot
.36051 .46494 Mdot
.3847 .48494 Mdot
.34008 .30166 Mdot
.36223 .44368 Mdot
.69355 .59913 Mdot
.48121 .65689 Mdot
.67077 .60198 Mdot
.68414 .61646 Mdot
.64725 .43818 Mdot
.61906 .26328 Mdot
.32144 .47549 Mdot
.59064 .27217 Mdot
.31979 .4467 Mdot
.41364 .37446 Mdot
.42996 .30841 Mdot
.48435 .41996 Mdot
.60099 .32147 Mdot
.40865 .43911 Mdot
.68836 .42933 Mdot
.69488 .44811 Mdot
.54674 .48776 Mdot
.37308 .38014 Mdot
.68831 .58464 Mdot
.67949 .62896 Mdot
.55363 .31988 Mdot
.67287 .24252 Mdot
.59043 .30643 Mdot
.53722 .34784 Mdot
.41953 .42045 Mdot
.38995 .47893 Mdot
.40904 .38716 Mdot
.653 .40995 Mdot
.50105 .56348 Mdot
.69764 .39927 Mdot
.64668 .66201 Mdot
.64922 .60999 Mdot
.40855 .43215 Mdot
.38543 .83057 Mdot
.47968 .69706 Mdot
.48242 .65655 Mdot
.64459 .60906 Mdot
.70858 .43765 Mdot
.38491 .37691 Mdot
.72352 .76775 Mdot
.46029 .6362 Mdot
.62077 .31539 Mdot
.36099 .45142 Mdot
.66772 .45209 Mdot
.47127 .70196 Mdot
.62304 .31738 Mdot
.42165 .46799 Mdot
.69827 .39078 Mdot
.39823 .45935 Mdot
.24487 .57188 Mdot
.45929 .69714 Mdot
.41856 .31622 Mdot
.49131 .71205 Mdot
.65752 .62039 Mdot
.6841 .59875 Mdot
.37856 .44019 Mdot
.74671 .75205 Mdot
.42136 .69585 Mdot
.64159 .63579 Mdot
.62964 .28633 Mdot
.49562 .57468 Mdot
.62237 .27118 Mdot
.68858 .41146 Mdot
.60303 .31098 Mdot
.64695 .43248 Mdot
.66051 .50479 Mdot
.49309 .63451 Mdot
.61245 .27365 Mdot
.37053 .6253 Mdot
.37505 .37466 Mdot
.60145 .24861 Mdot
.34989 .44307 Mdot
.32618 .43667 Mdot
.66229 .41402 Mdot
.58855 .28362 Mdot
.35694 .49155 Mdot
.56857 .69473 Mdot
.68689 .60451 Mdot
.68945 .58724 Mdot
.35193 .38094 Mdot
.6376 .42881 Mdot
.49809 .644 Mdot
.4663 .32249 Mdot
.46253 .62497 Mdot
.40736 .43584 Mdot
.31668 .45616 Mdot
.50558 .68705 Mdot
.50056 .6841 Mdot
.3808 .43709 Mdot
.31803 .72331 Mdot
.3935 .49695 Mdot
.66948 .5918 Mdot
.48271 .68906 Mdot
.48578 .6587 Mdot
.65736 .46292 Mdot
.44528 .70039 Mdot
.38755 .52016 Mdot
.62557 .62219 Mdot
.38278 .51076 Mdot
.6689 .6067 Mdot
.69771 .48048 Mdot
.65514 .42028 Mdot
.60413 .66304 Mdot
.44856 .7031 Mdot
.34673 .42252 Mdot
.46018 .71145 Mdot
.62424 .2984 Mdot
.48774 .65497 Mdot
.48187 .73187 Mdot
.36854 .42083 Mdot
.36577 .49661 Mdot
.50761 .58997 Mdot
.46043 .34635 Mdot
.46622 .69453 Mdot
.33457 .42146 Mdot
.37249 .40894 Mdot
.41174 .45902 Mdot
.4559 .31544 Mdot
.46518 .71609 Mdot
.38364 .73244 Mdot
.43793 .63594 Mdot
.46279 .69923 Mdot
.14935 .53359 Mdot
.51261 .58506 Mdot
.50479 .60074 Mdot
.6876 .57636 Mdot
.39147 .44495 Mdot
.66888 .44071 Mdot
.36411 .48014 Mdot
.43479 .41685 Mdot
.36097 .46315 Mdot
.6176 .27402 Mdot
.41942 .44212 Mdot
.50341 .57723 Mdot
.68182 .44252 Mdot
.33206 .45191 Mdot
.38211 .44739 Mdot
.5125 .59274 Mdot
.47198 .71312 Mdot
.43894 .68283 Mdot
.46515 .62086 Mdot
.59676 .25715 Mdot
.65194 .62944 Mdot
.3607 .47623 Mdot
.6858 .42665 Mdot
.6717 .44558 Mdot
.45506 .71552 Mdot
.68111 .4007 Mdot
.64579 .62313 Mdot
.38146 .42694 Mdot
.65853 .62115 Mdot
.61837 .27452 Mdot
.474 .69178 Mdot
.35352 .46157 Mdot
.35689 .48246 Mdot
.44715 .68709 Mdot
.3828 .49753 Mdot
.62704 .29098 Mdot
.64714 .41004 Mdot
.49519 .65955 Mdot
.67811 .61365 Mdot
.65439 .46043 Mdot
.33621 .43568 Mdot
.18241 .63372 Mdot
.36759 .44337 Mdot
.41603 .44844 Mdot
.42133 .71201 Mdot
.39679 .40739 Mdot
.67731 .45441 Mdot
.45402 .71063 Mdot
.33061 .43175 Mdot
.34339 .29708 Mdot
.59371 .33729 Mdot
.72531 .44326 Mdot
.36427 .43108 Mdot
.24129 .66918 Mdot
.36109 .41447 Mdot
.59814 .66218 Mdot
.42981 .30871 Mdot
.65268 .54597 Mdot
.31318 .35751 Mdot
.64154 .63416 Mdot
.50294 .59382 Mdot
.64993 .43757 Mdot
.34273 .68325 Mdot
.37676 .43485 Mdot
.32444 .55535 Mdot
.35327 .46428 Mdot
.66006 .59931 Mdot
.37449 .65586 Mdot
.69247 .40481 Mdot
.39958 .18938 Mdot
.40619 .48024 Mdot
.49685 .6486 Mdot
.64287 .39659 Mdot
.50006 .59888 Mdot
.36408 .49576 Mdot
.58586 .29518 Mdot
.55862 .32347 Mdot
.40603 .51373 Mdot
.67159 .60541 Mdot
.40451 .47246 Mdot
.43832 .44763 Mdot
.83252 .52947 Mdot
.45751 .67971 Mdot
.6875 .61974 Mdot
.66946 .24361 Mdot
.40892 .45158 Mdot
.44062 .67476 Mdot
.47327 .65949 Mdot
.59765 .26258 Mdot
.64892 .65189 Mdot
.57292 .34464 Mdot
.34927 .79456 Mdot
.23674 .44548 Mdot
.65172 .40995 Mdot
.51735 .64621 Mdot
.36996 .48474 Mdot
.51816 .20162 Mdot
.68145 .61684 Mdot
.3718 .45981 Mdot
.36168 .57154 Mdot
.46098 .66821 Mdot
.39885 .45376 Mdot
.59886 .30428 Mdot
.59548 .81979 Mdot
.24656 .62576 Mdot
.25577 .69167 Mdot
.69943 .39011 Mdot
.33027 .48679 Mdot
.3788 .51933 Mdot
.52329 .575 Mdot
.34984 .40315 Mdot
.69366 .44233 Mdot
.5896 .53218 Mdot
.5974 .28647 Mdot
.47601 .70121 Mdot
.50594 .59671 Mdot
.35269 .46357 Mdot
.34491 .49838 Mdot
.62862 .2939 Mdot
.39698 .49325 Mdot
.3105 .67901 Mdot
.49558 .56071 Mdot
.64834 .45263 Mdot
.48699 .64538 Mdot
.3181 .46765 Mdot
.49626 .58468 Mdot
.36413 .42363 Mdot
.35944 .5466 Mdot
.37502 .46953 Mdot
.57674 .64203 Mdot
.44456 .68475 Mdot
.67886 .6053 Mdot
.42505 .46785 Mdot
.39219 .45879 Mdot
.58413 .45005 Mdot
.38663 .37623 Mdot
.36967 .47525 Mdot
.44109 .71014 Mdot
.47842 .69943 Mdot
.4983 .65485 Mdot
.67364 .4657 Mdot
.47265 .38213 Mdot
.66214 .61634 Mdot
.40554 .38493 Mdot
.66565 .5854 Mdot
.32867 .34825 Mdot
.61908 .27062 Mdot
.61255 .67358 Mdot
.38421 .42923 Mdot
.45648 .65906 Mdot
.19802 .41389 Mdot
.46202 .71659 Mdot
.63414 .59008 Mdot
.68323 .61278 Mdot
.46653 .6866 Mdot
.36419 .4348 Mdot
.4569 .35327 Mdot
.26641 .70803 Mdot
.67829 .58739 Mdot
.34107 .38416 Mdot
.73054 .45063 Mdot
.71126 .44986 Mdot
.14932 .51625 Mdot
.66738 .58692 Mdot
.6925 .74851 Mdot
.33644 .42715 Mdot
.45914 .7092 Mdot
.66 .63117 Mdot
.66706 .64382 Mdot
.68568 .4 Mdot
.34833 .47812 Mdot
.39408 .45773 Mdot
.51265 .57171 Mdot
.66509 .62609 Mdot
.34675 .52545 Mdot
.3478 .48169 Mdot
.67924 .67529 Mdot
.48028 .63258 Mdot
.82829 .43829 Mdot
.44953 .53667 Mdot
.35963 .57107 Mdot
.80409 .4603 Mdot
.49725 .6647 Mdot
.39697 .48095 Mdot
.38525 .3776 Mdot
.65411 .40352 Mdot
.37309 .43035 Mdot
.70022 .45399 Mdot
.65202 .60965 Mdot
.56765 .67388 Mdot
.49398 .52741 Mdot
.62123 .65113 Mdot
.36866 .44799 Mdot
.25419 .63677 Mdot
.60689 .27755 Mdot
.66393 .57496 Mdot
.50024 .67726 Mdot
.36499 .40266 Mdot
.66695 .39641 Mdot
.6871 .46118 Mdot
.46347 .66978 Mdot
.67093 .74409 Mdot
.60383 .66586 Mdot
.40946 .49368 Mdot
.69882 .42026 Mdot
.4616 .53926 Mdot
.2324 .64114 Mdot
.6435 .604 Mdot
.59855 .28393 Mdot
.65644 .44829 Mdot
.70308 .6164 Mdot
.32412 .44002 Mdot
.46734 .67522 Mdot
.50265 .65352 Mdot
.55864 .4831 Mdot
.66233 .43169 Mdot
.61249 .29744 Mdot
.56061 .48772 Mdot
.53004 .48371 Mdot
.60093 .29714 Mdot
.68295 .46672 Mdot
.49078 .67649 Mdot
.45869 .66268 Mdot
.48017 .65747 Mdot
.35103 .71742 Mdot
.44852 .64576 Mdot
.49983 .25745 Mdot
.35514 .40156 Mdot
.25975 .65902 Mdot
.35687 .40757 Mdot
.69476 .59748 Mdot
.45695 .69748 Mdot
.42598 .30973 Mdot
.42591 .43034 Mdot
.27386 .7127 Mdot
.39084 .47221 Mdot
.56951 .5223 Mdot
.39011 .44465 Mdot
.26403 .61218 Mdot
.43229 .67999 Mdot
.41818 .47166 Mdot
.6277 .61669 Mdot
.6216 .29315 Mdot
.50293 .71141 Mdot
.3763 .47736 Mdot
.58856 .7853 Mdot
.34944 .44391 Mdot
.57056 .66422 Mdot
.56894 .47892 Mdot
.6231 .23767 Mdot
.41048 .42346 Mdot
.68115 .39331 Mdot
.43654 .53049 Mdot
.25202 .65047 Mdot
.67694 .58673 Mdot
.25871 .64543 Mdot
.70256 .40863 Mdot
.3733 .66064 Mdot
.43856 .4582 Mdot
.59545 .28829 Mdot
.54983 .61011 Mdot
.67381 .59174 Mdot
.3834 .43165 Mdot
.40704 .47759 Mdot
.56953 .56617 Mdot
.2277 .62293 Mdot
.36549 .53387 Mdot
.6087 .32421 Mdot
.23845 .61878 Mdot
.36759 .47201 Mdot
.72728 .44068 Mdot
.43899 .69493 Mdot
.37975 .64218 Mdot
.37196 .68172 Mdot
.33783 .47199 Mdot
.46427 .68391 Mdot
.44031 .6927 Mdot
.20665 .36792 Mdot
.60246 .27278 Mdot
.37797 .47095 Mdot
.58199 .48894 Mdot
.35893 .47336 Mdot
.6565 .60676 Mdot
.40966 .41199 Mdot
.656 .42122 Mdot
.48197 .42576 Mdot
.67718 .4654 Mdot
.41308 .45643 Mdot
.47653 .67825 Mdot
.68828 .59799 Mdot
.6947 .5344 Mdot
.64661 .65058 Mdot
.49893 .25816 Mdot
.55259 .3013 Mdot
.59181 .30878 Mdot
.61712 .2648 Mdot
.67187 .57526 Mdot
.36908 .42708 Mdot
.46553 .33409 Mdot
.34629 .39646 Mdot
.39565 .44333 Mdot
.36971 .46788 Mdot
.66904 .55705 Mdot
.68308 .61107 Mdot
.66168 .44574 Mdot
.38145 .43611 Mdot
.33711 .41684 Mdot
.47257 .68276 Mdot
.59223 .30768 Mdot
.64398 .4369 Mdot
.58435 .28761 Mdot
.68505 .43755 Mdot
.18481 .45141 Mdot
.31913 .39546 Mdot
.62093 .28705 Mdot
.65157 .59523 Mdot
.46702 .65251 Mdot
.51827 .57481 Mdot
.68436 .41099 Mdot
.68783 .40346 Mdot
.32151 .46948 Mdot
.46828 .70081 Mdot
.44563 .69805 Mdot
.58655 .27877 Mdot
.67721 .63057 Mdot
.31182 .44081 Mdot
.3436 .4878 Mdot
.71128 .51873 Mdot
.64813 .40656 Mdot
.24451 .63269 Mdot
.42178 .66911 Mdot
.38133 .42331 Mdot
.44137 .67468 Mdot
.38318 .45789 Mdot
.46127 .55737 Mdot
.50322 .66721 Mdot
.39816 .40681 Mdot
.39526 .39063 Mdot
.65019 .41317 Mdot
.23802 .32165 Mdot
.30859 .45276 Mdot
.61159 .60239 Mdot
.3776 .48914 Mdot
.38182 .17649 Mdot
.20185 .40386 Mdot
.35585 .43208 Mdot
.41986 .4495 Mdot
.31824 .77763 Mdot
.36575 .41385 Mdot
.50787 .57256 Mdot
.43562 .41756 Mdot
.44421 .66767 Mdot
.58126 .49998 Mdot
.45991 .33996 Mdot
.60374 .26862 Mdot
.68496 .42408 Mdot
.4341 .27328 Mdot
.60918 .25913 Mdot
.45783 .66735 Mdot
.30676 .45776 Mdot
.41982 .68488 Mdot
.64217 .46154 Mdot
.33185 .51635 Mdot
.65757 .60253 Mdot
.46418 .33844 Mdot
.67628 .39762 Mdot
.67829 .6147 Mdot
.36482 .41146 Mdot
.62689 .45156 Mdot
.64293 .58841 Mdot
.21387 .34279 Mdot
.67883 .63715 Mdot
.68174 .60133 Mdot
.46424 .36181 Mdot
.60349 .26852 Mdot
.58935 .54188 Mdot
.40154 .36662 Mdot
.68945 .59576 Mdot
.40455 .20164 Mdot
.65443 .39966 Mdot
.48502 .39295 Mdot
.43087 .68833 Mdot
.33318 .38559 Mdot
.36868 .46172 Mdot
.68586 .63117 Mdot
.51346 .62563 Mdot
.58453 .43855 Mdot
.65498 .59952 Mdot
.43001 .45144 Mdot
.49752 .42689 Mdot
.49644 .57835 Mdot
.51385 .58246 Mdot
.62505 .31358 Mdot
.70916 .30558 Mdot
.4449 .6765 Mdot
.61961 .31558 Mdot
.39193 .31 Mdot
.39584 .4727 Mdot
.6573 .62388 Mdot
.50834 .59665 Mdot
.67563 .61347 Mdot
.6077 .28451 Mdot
.6284 .28637 Mdot
.45897 .68778 Mdot
.49964 .67027 Mdot
.53461 .6414 Mdot
.32021 .30261 Mdot
.34595 .46603 Mdot
.31056 .55867 Mdot
.5012 .68291 Mdot
.3558 .69259 Mdot
.59451 .27268 Mdot
.58864 .29536 Mdot
.20836 .5418 Mdot
.3366 .44621 Mdot
.57203 .52814 Mdot
.36188 .46783 Mdot
.4454 .20596 Mdot
.35193 .46069 Mdot
.67825 .40078 Mdot
.40337 .4846 Mdot
.52182 .80298 Mdot
.33164 .43601 Mdot
.36522 .46469 Mdot
.67384 .4208 Mdot
.32261 .47552 Mdot
.65929 .417 Mdot
.3958 .47995 Mdot
.56998 .31145 Mdot
.68535 .42654 Mdot
.57676 .30438 Mdot
.54721 .50834 Mdot
.50838 .58077 Mdot
.61072 .26422 Mdot
.59041 .30893 Mdot
.46589 .29636 Mdot
.48823 .68711 Mdot
.41548 .60097 Mdot
.36128 .45041 Mdot
.6405 .41343 Mdot
.64798 .62196 Mdot
.33905 .47499 Mdot
.4005 .41842 Mdot
.30978 .44845 Mdot
.46188 .68823 Mdot
.65295 .46319 Mdot
.61462 .28185 Mdot
.69149 .45305 Mdot
.57225 .31086 Mdot
.65435 .4168 Mdot
.33542 .39463 Mdot
.32105 .44567 Mdot
.37238 .51828 Mdot
.35633 .59758 Mdot
.56522 .2041 Mdot
.46547 .67245 Mdot
.50049 .58769 Mdot
.62177 .27288 Mdot
.51332 .44365 Mdot
.44763 .66749 Mdot
.68219 .40318 Mdot
.3982 .4597 Mdot
.30927 .4093 Mdot
.40638 .36991 Mdot
.45663 .73172 Mdot
.59422 .25074 Mdot
.68259 .41573 Mdot
.50177 .56907 Mdot
.478 .39264 Mdot
.3966 .73773 Mdot
.39869 .29998 Mdot
.38805 .45864 Mdot
.58842 .27191 Mdot
.47147 .70185 Mdot
.57651 .54505 Mdot
.68855 .62705 Mdot
.46255 .34784 Mdot
.36755 .448 Mdot
.73649 .6471 Mdot
.47695 .67615 Mdot
.59314 .29957 Mdot
.68629 .63118 Mdot
.59774 .27589 Mdot
.49478 .5872 Mdot
.42527 .65793 Mdot
.36586 .49547 Mdot
.35955 .46607 Mdot
.64932 .61767 Mdot
.4434 .68224 Mdot
.57108 .32169 Mdot
.57645 .56744 Mdot
.69001 .41089 Mdot
.50701 .44929 Mdot
.4754 .7007 Mdot
.73813 .6228 Mdot
.69404 .45335 Mdot
.69377 .58672 Mdot
.4508 .34009 Mdot
.64585 .62704 Mdot
.36907 .47094 Mdot
.48416 .66972 Mdot
.6762 .58538 Mdot
.70779 .50837 Mdot
.32973 .74495 Mdot
.55582 .60069 Mdot
.41167 .44869 Mdot
.60405 .67922 Mdot
.65445 .76671 Mdot
.51275 .70093 Mdot
.66177 .58914 Mdot
.37529 .44843 Mdot
.4085 .49416 Mdot
.40623 .48079 Mdot
.68987 .60921 Mdot
.69915 .55444 Mdot
.70577 .42196 Mdot
.40369 .45782 Mdot
.61172 .31294 Mdot
.65466 .42836 Mdot
.7198 .42929 Mdot
.65783 .45009 Mdot
.49882 .68299 Mdot
.30566 .42059 Mdot
.42637 .40131 Mdot
.22241 .36229 Mdot
.67993 .60253 Mdot
.50807 .58072 Mdot
.41917 .45916 Mdot
.49541 .26536 Mdot
.46489 .65532 Mdot
.67661 .41199 Mdot
.3736 .46029 Mdot
.56379 .47971 Mdot
.51047 .54672 Mdot
.67556 .43241 Mdot
.502 .67461 Mdot
.46557 .75463 Mdot
.37563 .42927 Mdot
.37041 .48668 Mdot
.45014 .67905 Mdot
.65184 .78124 Mdot
.48335 .40344 Mdot
.38344 .45565 Mdot
.6808 .60865 Mdot
.78061 .67954 Mdot
.36127 .41126 Mdot
.43283 .65799 Mdot
.50281 .56173 Mdot
.41613 .68702 Mdot
.29664 .68778 Mdot
.39224 .38365 Mdot
.54201 .68739 Mdot
.52523 .30516 Mdot
.5047 .73305 Mdot
.47071 .20531 Mdot
.58119 .57552 Mdot
.18467 .38491 Mdot
.62532 .63554 Mdot
.25099 .59409 Mdot
.47346 .84951 Mdot
.68988 .7449 Mdot
.58764 .46654 Mdot
.65877 .53171 Mdot
.65236 .47917 Mdot
.41244 .17253 Mdot
.68952 .39375 Mdot
.48124 .19503 Mdot
.35501 .4573 Mdot
.64136 .78399 Mdot
.25666 .61279 Mdot
.57585 .22496 Mdot
.61509 .66565 Mdot
.5656 .48222 Mdot
.22252 .6776 Mdot
.64823 .67397 Mdot
.17427 .54733 Mdot
.39074 .57997 Mdot
.74587 .33538 Mdot
.51734 .46118 Mdot
.45152 .27392 Mdot
.27077 .65155 Mdot
.51549 .77317 Mdot
.71324 .65366 Mdot
.25116 .51118 Mdot
.81296 .4588 Mdot
.69661 .4263 Mdot
.43552 .6851 Mdot
.63371 .53752 Mdot
.19332 .60314 Mdot
.62402 .59428 Mdot
.54106 .68849 Mdot
.56546 .58611 Mdot
.25991 .60721 Mdot
.41477 .31386 Mdot
.24797 .56735 Mdot
.56594 .34277 Mdot
.41754 .17389 Mdot
.44043 .74046 Mdot
.74333 .47109 Mdot
.51096 .4204 Mdot
.55681 .35579 Mdot
.29071 .64463 Mdot
.59886 .33052 Mdot
.58834 .33105 Mdot
.5026 .66842 Mdot
.21055 .61935 Mdot
.51872 .54437 Mdot
.38291 .31249 Mdot
.68538 .39212 Mdot
.46539 .55032 Mdot
.58807 .81916 Mdot
.64769 .76565 Mdot
.26698 .28622 Mdot
.18106 .6227 Mdot
.40215 .22885 Mdot
.56676 .54187 Mdot
.63994 .57273 Mdot
.496 .27957 Mdot
.34558 .53193 Mdot
.37946 .23765 Mdot
.37134 .54994 Mdot
.2745 .73354 Mdot
.61342 .76243 Mdot
.20055 .66071 Mdot
.44746 .74516 Mdot
.33084 .49491 Mdot
.48001 .57175 Mdot
.249 .46946 Mdot
.37467 .29132 Mdot
.20408 .64907 Mdot
.62394 .24256 Mdot
.50341 .61661 Mdot
.69326 .7399 Mdot
.30887 .67915 Mdot
.58912 .3594 Mdot
.5863 .24412 Mdot
.39 .63174 Mdot
.22967 .69865 Mdot
.54497 .68822 Mdot
.20578 .46125 Mdot
.69532 .67476 Mdot
.63635 .39005 Mdot
.71891 .42376 Mdot
.65392 .64405 Mdot
.17411 .5791 Mdot
.48171 .66558 Mdot
.23354 .32237 Mdot
.5318 .67252 Mdot
.42761 .54252 Mdot
.23465 .70733 Mdot
.34179 .24133 Mdot
.27932 .67335 Mdot
.53375 .23462 Mdot
.76295 .65885 Mdot
.27131 .46287 Mdot
.62036 .6408 Mdot
.72804 .44998 Mdot
.58067 .65936 Mdot
.1798 .59287 Mdot
.38093 .22594 Mdot
.38215 .8209 Mdot
.3751 .3158 Mdot
.66044 .35211 Mdot
.43545 .73523 Mdot
.60356 .46494 Mdot
.59869 .36907 Mdot
.19646 .65554 Mdot
.24186 .61359 Mdot
.77601 .67144 Mdot
.45229 .21874 Mdot
.3697 .691 Mdot
.59495 .69127 Mdot
.64857 .51345 Mdot
.25859 .45048 Mdot
.60382 .77889 Mdot
.35531 .49992 Mdot
.40414 .29211 Mdot
.39253 .6098 Mdot
.63958 .29375 Mdot
.4745 .39204 Mdot
.62157 .74366 Mdot
.40548 .2501 Mdot
.737 .69373 Mdot
.39211 .63705 Mdot
.49736 .70755 Mdot
.38243 .23856 Mdot
.42662 .22098 Mdot
.69562 .6985 Mdot
.66707 .24125 Mdot
.20377 .46508 Mdot
.62077 .37847 Mdot
.40473 .38953 Mdot
.24801 .5884 Mdot
.27344 .65247 Mdot
.42862 .18601 Mdot
.33573 .39194 Mdot
.2434 .33017 Mdot
.61109 .64978 Mdot
.34048 .60469 Mdot
.37559 .27462 Mdot
.35174 .60093 Mdot
.26875 .68192 Mdot
.46633 .59885 Mdot
.62587 .56508 Mdot
.52569 .61608 Mdot
.23215 .69931 Mdot
.6555 .43836 Mdot
.37486 .23623 Mdot
.61723 .625 Mdot
.70675 .51415 Mdot
.59209 .5555 Mdot
.58811 .43488 Mdot
.16432 .54166 Mdot
.68656 .73292 Mdot
.69844 .49537 Mdot
.4925 .78302 Mdot
.45817 .54421 Mdot
.3171 .56584 Mdot
.30465 .47761 Mdot
.39025 .55007 Mdot
.62714 .29067 Mdot
.35029 .64764 Mdot
.43782 .63024 Mdot
.65092 .21511 Mdot
.35681 .38813 Mdot
.52227 .46307 Mdot
.51046 .56332 Mdot
.48463 .34225 Mdot
.18314 .45062 Mdot
.29971 .47049 Mdot
.33724 .24714 Mdot
.68236 .74231 Mdot
.48108 .33337 Mdot
.59339 .36681 Mdot
.41205 .6148 Mdot
.20246 .66556 Mdot
.1563 .48191 Mdot
.59469 .80078 Mdot
.59075 .68085 Mdot
.56248 .13932 Mdot
.63424 .5566 Mdot
.26203 .3101 Mdot
.61739 .6233 Mdot
.91168 .50207 Mdot
.68892 .45665 Mdot
.52465 .19648 Mdot
.28281 .50444 Mdot
.55073 .45298 Mdot
.20191 .61439 Mdot
.29462 .67064 Mdot
.59051 .25102 Mdot
.48222 .72797 Mdot
.35431 .38372 Mdot
.21138 .64932 Mdot
.2373 .69984 Mdot
.21514 .65492 Mdot
.73047 .61346 Mdot
.27919 .70644 Mdot
.28932 .75871 Mdot
.50229 .25674 Mdot
.5457 .5453 Mdot
.43831 .45223 Mdot
.3088 .30273 Mdot
.30843 .27573 Mdot
.63777 .24927 Mdot
.27014 .4583 Mdot
.43823 .7402 Mdot
.26897 .74433 Mdot
.18168 .44494 Mdot
.24288 .54806 Mdot
.17067 .53188 Mdot
.73682 .45763 Mdot
.32924 .28264 Mdot
.15928 .517 Mdot
.523 .74995 Mdot
.65057 .6665 Mdot
.30251 .7746 Mdot
.42647 .22882 Mdot
.66107 .53105 Mdot
.5605 .79678 Mdot
.28882 .28564 Mdot
.58457 .69001 Mdot
.65661 .52759 Mdot
.33586 .53125 Mdot
.40349 .73076 Mdot
.5903 .4352 Mdot
.50992 .773 Mdot
.56792 .53471 Mdot
.36251 .27414 Mdot
.71581 .42894 Mdot
.35929 .24707 Mdot
.58008 .37681 Mdot
.55131 .54903 Mdot
.44401 .28485 Mdot
.39375 .20938 Mdot
.57437 .77218 Mdot
.24877 .68131 Mdot
.68485 .73886 Mdot
.76226 .68684 Mdot
.63606 .70039 Mdot
.39969 .59928 Mdot
.32128 .47401 Mdot
.19629 .61097 Mdot
.13844 .46874 Mdot
.15854 .52891 Mdot
.7127 .69734 Mdot
.712 .38898 Mdot
.70109 .59811 Mdot
.48694 .28207 Mdot
.5604 .44625 Mdot
.57169 .60836 Mdot
.54131 .37191 Mdot
.65391 .64702 Mdot
.60172 .8181 Mdot
.54072 .63408 Mdot
.49703 .26862 Mdot
.25579 .52538 Mdot
.32933 .51889 Mdot
.23056 .63783 Mdot
.50481 .69178 Mdot
.72103 .69048 Mdot
.37718 .23829 Mdot
.65421 .44071 Mdot
.71954 .50855 Mdot
.52412 .60957 Mdot
.31704 .48107 Mdot
.74043 .42756 Mdot
.55162 .58782 Mdot
.35689 .57088 Mdot
.71757 .39685 Mdot
.17985 .41883 Mdot
.25438 .31093 Mdot
.15852 .51337 Mdot
.40038 .22333 Mdot
.72858 .49297 Mdot
.48445 .35844 Mdot
.62731 .5702 Mdot
.62758 .66747 Mdot
.49982 .39931 Mdot
.40475 .21429 Mdot
.27583 .67406 Mdot
.48714 .59112 Mdot
.40328 .38591 Mdot
.19632 .41966 Mdot
.47072 .26495 Mdot
.4928 .36089 Mdot
.39286 .67253 Mdot
.46656 .63128 Mdot
.57443 .19413 Mdot
.52171 .78267 Mdot
.45414 .45902 Mdot
.59895 .68478 Mdot
.64369 .59974 Mdot
.50464 .67044 Mdot
.39196 .20895 Mdot
.6918 .26205 Mdot
.51878 .69971 Mdot
.50056 .53389 Mdot
.18155 .58055 Mdot
.53042 .51011 Mdot
.57804 .68057 Mdot
.43791 .78053 Mdot
.78308 .63126 Mdot
.45282 .74496 Mdot
.55699 .54291 Mdot
.60046 .53606 Mdot
.42497 .74298 Mdot
.46826 .72691 Mdot
.24679 .62296 Mdot
.1719 .59262 Mdot
.56137 .49304 Mdot
.50658 .76332 Mdot
.46987 .33325 Mdot
.59707 .45843 Mdot
.4922 .55505 Mdot
.43582 .27782 Mdot
.51574 .73669 Mdot
.19751 .51125 Mdot
.67732 .7926 Mdot
.26743 .43793 Mdot
.51726 .19193 Mdot
.4894 .28249 Mdot
.39308 .58009 Mdot
.28659 .63826 Mdot
.67201 .68147 Mdot
.3725 .48176 Mdot
.16767 .60079 Mdot
.62214 .75319 Mdot
.46739 .30739 Mdot
.65249 .50397 Mdot
.3479 .42482 Mdot
.3818 .51851 Mdot
.16098 .52559 Mdot
.41729 .7135 Mdot
.54864 .86575 Mdot
.45484 .2113 Mdot
.418 .56561 Mdot
.28961 .68629 Mdot
.33137 .25323 Mdot
.46432 .59486 Mdot
.53529 .67038 Mdot
.58669 .38249 Mdot
.30989 .26988 Mdot
.47266 .78094 Mdot
.50806 .79165 Mdot
.63197 .69349 Mdot
.2872 .75348 Mdot
.43605 .54862 Mdot
.69367 .66915 Mdot
.74058 .44931 Mdot
.41633 .44641 Mdot
.6684 .74604 Mdot
.62342 .68107 Mdot
.61468 .42496 Mdot
.33338 .52718 Mdot
.13589 .47202 Mdot
.43566 .43372 Mdot
.6736 .73217 Mdot
.53166 .86234 Mdot
.60276 .85964 Mdot
.51618 .80096 Mdot
.19281 .65099 Mdot
.49848 .789 Mdot
.5756 .685 Mdot
.66053 .58308 Mdot
.52203 .48178 Mdot
.31657 .5545 Mdot
.15872 .56944 Mdot
.72142 .29565 Mdot
.62148 .64453 Mdot
.26055 .50428 Mdot
.15722 .56999 Mdot
.42446 .41064 Mdot
.55202 .19077 Mdot
.6399 .38754 Mdot
.39201 .18762 Mdot
.27753 .27832 Mdot
.39428 .69941 Mdot
.41885 .18584 Mdot
.53007 .17977 Mdot
.54965 .25045 Mdot
.25952 .30872 Mdot
.24781 .42518 Mdot
.39829 .6801 Mdot
.38719 .23916 Mdot
.59124 .66493 Mdot
.49719 .13826 Mdot
.49114 .55444 Mdot
.55944 .57051 Mdot
.41935 .66175 Mdot
.57854 .65763 Mdot
.58088 .75518 Mdot
.53395 .53174 Mdot
.48947 .45286 Mdot
.26064 .6707 Mdot
.79088 .67218 Mdot
.46974 .80741 Mdot
.53722 .61658 Mdot
.241 .69831 Mdot
.68632 .6805 Mdot
.50531 .39326 Mdot
.30462 .66163 Mdot
.47437 .27337 Mdot
.72879 .46567 Mdot
.36046 .46293 Mdot
.17412 .5979 Mdot
.72907 .46483 Mdot
.23194 .68142 Mdot
.21815 .33413 Mdot
.17655 .52789 Mdot
.29422 .47248 Mdot
.72208 .46208 Mdot
.32522 .26934 Mdot
.32627 .27082 Mdot
.28891 .73952 Mdot
.50303 .18502 Mdot
.50094 .41442 Mdot
.54614 .51994 Mdot
.49317 .53068 Mdot
.45673 .45081 Mdot
.32494 .25622 Mdot
.42504 .59441 Mdot
.38487 .27477 Mdot
.57 .80632 Mdot
.39825 .21197 Mdot
.28439 .67236 Mdot
.47041 .28329 Mdot
.61179 .39655 Mdot
.57991 .27319 Mdot
.6474 .40512 Mdot
.35479 .80398 Mdot
.66267 .70014 Mdot
.23842 .3387 Mdot
.76332 .67652 Mdot
.60869 .77596 Mdot
.47898 .1911 Mdot
.48922 .59975 Mdot
.26108 .42785 Mdot
.73498 .32279 Mdot
.41202 .25473 Mdot
.24849 .63359 Mdot
.5991 .66583 Mdot
.38211 .70925 Mdot
.16333 .5555 Mdot
.36553 .27583 Mdot
.42182 .84533 Mdot
.72853 .37973 Mdot
.35048 .64083 Mdot
.20855 .6037 Mdot
.74894 .71446 Mdot
.49416 .35615 Mdot
.23453 .70175 Mdot
.43458 .70926 Mdot
.18376 .62728 Mdot
.66873 .63825 Mdot
.65061 .34445 Mdot
.59982 .64514 Mdot
.48379 .31299 Mdot
.48608 .31756 Mdot
.20066 .38395 Mdot
.6904 .73726 Mdot
.64917 .76664 Mdot
.62115 .37811 Mdot
.70231 .40088 Mdot
.50558 .49171 Mdot
.51646 .75137 Mdot
.36516 .80789 Mdot
.31724 .45415 Mdot
.71689 .36648 Mdot
.35953 .23734 Mdot
.62992 .56833 Mdot
.56217 .57893 Mdot
.59452 .64738 Mdot
.42042 .76852 Mdot
.32541 .28955 Mdot
.27695 .74589 Mdot
.55974 .58452 Mdot
.55943 .4279 Mdot
.36789 .6697 Mdot
.58048 .60475 Mdot
.74506 .66308 Mdot
.53613 .7056 Mdot
.51957 .51953 Mdot
.48264 .39921 Mdot
.40606 .22613 Mdot
.15774 .42723 Mdot
.25853 .71761 Mdot
.75124 .65971 Mdot
.48797 .33446 Mdot
.43341 .65806 Mdot
.42783 .26168 Mdot
.41412 .84396 Mdot
.40006 .17668 Mdot
.57121 .79354 Mdot
.39237 .21741 Mdot
.62443 .47607 Mdot
.53587 .1906 Mdot
.49696 .37866 Mdot
.20725 .60054 Mdot
.26613 .49425 Mdot
.42703 .65307 Mdot
.64646 .51718 Mdot
.4591 .32868 Mdot
.57563 .57991 Mdot
.39708 .67408 Mdot
.69367 .73325 Mdot
.42334 .84554 Mdot
.49584 .17847 Mdot
.37485 .6609 Mdot
.44952 .84044 Mdot
.49447 .63708 Mdot
.60462 .53718 Mdot
.73419 .58566 Mdot
.48236 .33 Mdot
.67667 .45899 Mdot
.38501 .53819 Mdot
.50154 .44167 Mdot
.48078 .79162 Mdot
.65433 .48476 Mdot
.6132 .25631 Mdot
.47974 .71785 Mdot
.5177 .18069 Mdot
.50192 .64863 Mdot
.16695 .41499 Mdot
.52724 .74442 Mdot
.25803 .66094 Mdot
.44465 .79684 Mdot
.75684 .4491 Mdot
.7644 .69021 Mdot
.17372 .54424 Mdot
.34288 .29853 Mdot
.4749 .72635 Mdot
.5034 .70124 Mdot
.47545 .77565 Mdot
.69293 .56435 Mdot
.18506 .57906 Mdot
.34797 .23871 Mdot
.73533 .48937 Mdot
.45011 .65179 Mdot
.55623 .52006 Mdot
.53416 .61346 Mdot
.17781 .42961 Mdot
.68862 .45376 Mdot
.21634 .68658 Mdot
.41987 .59739 Mdot
.70248 .75186 Mdot
.56913 .61897 Mdot
.47349 .40963 Mdot
.50086 .35953 Mdot
.70646 .50572 Mdot
.41314 .39371 Mdot
.42078 .56267 Mdot
.49848 .67539 Mdot
.5885 .56158 Mdot
.59553 .30925 Mdot
.65443 .22161 Mdot
.61291 .58855 Mdot
.38299 .58786 Mdot
.31471 .25809 Mdot
.50609 .68693 Mdot
.72943 .38367 Mdot
.76325 .41653 Mdot
.38569 .389 Mdot
.27882 .32797 Mdot
.33433 .78922 Mdot
.17809 .55181 Mdot
.45168 .71793 Mdot
.75095 .69127 Mdot
.58317 .34331 Mdot
.18336 .414 Mdot
.44628 .76298 Mdot
.34505 .24884 Mdot
.38153 .61708 Mdot
.16209 .48957 Mdot
.29635 .68716 Mdot
.55409 .65179 Mdot
.38683 .23287 Mdot
.58501 .44223 Mdot
.38736 .21641 Mdot
.41456 .76809 Mdot
.50602 .51624 Mdot
.39146 .19053 Mdot
.6334 .48345 Mdot
.24776 .57137 Mdot
.43751 .51029 Mdot
.56713 .61708 Mdot
.3201 .26633 Mdot
.47673 .71466 Mdot
.6105 .33181 Mdot
.26671 .52224 Mdot
.62914 .66071 Mdot
.17844 .58773 Mdot
.69367 .70133 Mdot
.36434 .23112 Mdot
.48804 .53291 Mdot
.46855 .24486 Mdot
.42492 .58905 Mdot
.36563 .31033 Mdot
.42327 .4865 Mdot
.39038 .61669 Mdot
.5562 .38035 Mdot
.20574 .39209 Mdot
.44454 .5172 Mdot
.20261 .6306 Mdot
.18789 .43868 Mdot
.45279 .77118 Mdot
.58483 .53046 Mdot
.43909 .67014 Mdot
.21692 .68121 Mdot
.29031 .30845 Mdot
.58401 .65102 Mdot
.28214 .27521 Mdot
.57376 .1916 Mdot
.46344 .84606 Mdot
.65344 .72628 Mdot
.54976 .58266 Mdot
.23695 .32377 Mdot
.62093 .75785 Mdot
.54376 .18181 Mdot
.24562 .62814 Mdot
.4221 .71192 Mdot
.23862 .71263 Mdot
.24275 .4478 Mdot
.63633 .77244 Mdot
.22329 .62221 Mdot
.48707 .7455 Mdot
.28095 .31592 Mdot
.41848 .39486 Mdot
.667 .39943 Mdot
.54316 .46238 Mdot
.427 .18234 Mdot
.5075 .7177 Mdot
.33927 .24879 Mdot
.34545 .25076 Mdot
.49184 .19767 Mdot
.72298 .49395 Mdot
.46462 .84593 Mdot
.30658 .71512 Mdot
.36448 .50927 Mdot
.45234 .72136 Mdot
.61671 .262 Mdot
.45685 .22055 Mdot
.33319 .45424 Mdot
.42248 .33361 Mdot
.38834 .62703 Mdot
.1629 .58722 Mdot
.60286 .4341 Mdot
.70544 .65734 Mdot
.44144 .66145 Mdot
.58139 .65607 Mdot
.45091 .59786 Mdot
.68856 .74768 Mdot
.32597 .26411 Mdot
.51718 .7043 Mdot
.54624 .67657 Mdot
.62589 .77549 Mdot
.39595 .24553 Mdot
.5535 .33182 Mdot
.6823 .5855 Mdot
.34233 .56448 Mdot
.3264 .7641 Mdot
.63659 .76195 Mdot
.49996 .61618 Mdot
.55093 .78021 Mdot
.51271 .51263 Mdot
.71997 .66446 Mdot
.68762 .73915 Mdot
.45993 .61734 Mdot
.19346 .53027 Mdot
.48827 .75629 Mdot
.7314 .44879 Mdot
.43658 .21775 Mdot
.52933 .7726 Mdot
.33214 .25556 Mdot
.39905 .39275 Mdot
.21081 .63362 Mdot
.46975 .30983 Mdot
.62159 .33314 Mdot
.3687 .49097 Mdot
.31812 .52803 Mdot
.16038 .52531 Mdot
.54963 .79702 Mdot
.28952 .4965 Mdot
.48612 .61777 Mdot
.2556 .30576 Mdot
.73452 .42289 Mdot
.72105 .39892 Mdot
.53479 .22064 Mdot
.47552 .42357 Mdot
.55669 .44432 Mdot
.66878 .55041 Mdot
.41784 .40007 Mdot
.54637 .32016 Mdot
.51484 .52549 Mdot
.34609 .56815 Mdot
.26042 .31673 Mdot
.34911 .79756 Mdot
.48157 .55633 Mdot
.26942 .28192 Mdot
.28868 .51515 Mdot
.43407 .72521 Mdot
.50584 .17771 Mdot
.27737 .47172 Mdot
.34209 .38811 Mdot
.61218 .33101 Mdot
.48573 .62707 Mdot
.34241 .78868 Mdot
.38448 .54539 Mdot
.63858 .31819 Mdot
.62009 .3685 Mdot
.4908 .54726 Mdot
.80112 .45044 Mdot
.61313 .65076 Mdot
.23833 .31962 Mdot
.3783 .2375 Mdot
.67553 .65157 Mdot
.4881 .78613 Mdot
.27801 .47906 Mdot
.20944 .63515 Mdot
.56774 .39614 Mdot
.1744 .55964 Mdot
.73217 .62941 Mdot
.36668 .58545 Mdot
.19326 .43089 Mdot
.39245 .29073 Mdot
.37113 .30967 Mdot
.39284 .65241 Mdot
.29328 .35742 Mdot
.51834 .57681 Mdot
.68124 .26166 Mdot
.47839 .14436 Mdot
.39069 .82817 Mdot
.69556 .75438 Mdot
.44416 .4734 Mdot
.42213 .26121 Mdot
.48587 .76123 Mdot
.50683 .40395 Mdot
.60467 .37522 Mdot
.7411 .41352 Mdot
.66253 .51456 Mdot
.7822 .67346 Mdot
.16753 .59764 Mdot
.36796 .48973 Mdot
.53335 .34987 Mdot
.60279 .22808 Mdot
.69629 .45754 Mdot
.24413 .52322 Mdot
.33068 .78454 Mdot
.68423 .58982 Mdot
.7438 .58044 Mdot
.65686 .54866 Mdot
.20296 .38305 Mdot
.72384 .55889 Mdot
.69137 .57023 Mdot
.16622 .41483 Mdot
.5925 .79914 Mdot
.39203 .73685 Mdot
.78442 .666 Mdot
.19897 .40856 Mdot
.38888 .61022 Mdot
.73676 .42954 Mdot
.18784 .61976 Mdot
.49957 .36117 Mdot
.70972 .48947 Mdot
.23676 .41031 Mdot
.38749 .22931 Mdot
.44803 .21421 Mdot
.70737 .6435 Mdot
.26853 .50303 Mdot
.64781 .19908 Mdot
.75894 .44809 Mdot
.71689 .77126 Mdot
.17949 .54626 Mdot
.34589 .76346 Mdot
.51492 .79622 Mdot
.62325 .38339 Mdot
.20717 .62519 Mdot
.34364 .25629 Mdot
.27845 .49612 Mdot
.70502 .28519 Mdot
.41512 .28781 Mdot
.45305 .26795 Mdot
.72204 .65959 Mdot
.16613 .51263 Mdot
.73385 .4834 Mdot
.25792 .40401 Mdot
.37346 .23305 Mdot
.2994 .52143 Mdot
.36354 .31355 Mdot
.31751 .75588 Mdot
.27604 .32702 Mdot
.41349 .2109 Mdot
.67099 .52185 Mdot
.58169 .32846 Mdot
.33896 .78151 Mdot
.4482 .57706 Mdot
.38074 .62369 Mdot
.53561 .86298 Mdot
.19992 .65859 Mdot
.27456 .46696 Mdot
.41252 .41425 Mdot
.1866 .37893 Mdot
.70055 .36909 Mdot
.25695 .3232 Mdot
.57495 .81951 Mdot
.45927 .20615 Mdot
.44566 .52622 Mdot
.34965 .45459 Mdot
.50633 .24362 Mdot
.41998 .72922 Mdot
.27632 .50168 Mdot
.70674 .53513 Mdot
.40703 .21506 Mdot
.38768 .58803 Mdot
.67639 .79306 Mdot
.415 .76567 Mdot
.45913 .65017 Mdot
.17952 .60955 Mdot
.22637 .48634 Mdot
.40705 .58304 Mdot
.20668 .60858 Mdot
.56284 .40714 Mdot
.54789 .32117 Mdot
.42404 .58672 Mdot
.48538 .3564 Mdot
.42884 .17967 Mdot
.44777 .84209 Mdot
.32525 .56293 Mdot
.22256 .69478 Mdot
.15423 .49021 Mdot
.45621 .65015 Mdot
.25793 .47961 Mdot
.49779 .33636 Mdot
.50197 .73809 Mdot
.6694 .53009 Mdot
.71431 .50807 Mdot
.60568 .20657 Mdot
.64938 .21932 Mdot
.35488 .43583 Mdot
.73335 .62873 Mdot
.1651 .55625 Mdot
.5965 .20423 Mdot
.16672 .56787 Mdot
.39833 .6087 Mdot
.33124 .48443 Mdot
.60824 .85867 Mdot
.57509 .68262 Mdot
.31672 .41878 Mdot
.44043 .40752 Mdot
.44803 .42606 Mdot
.36785 .47579 Mdot
.70694 .56866 Mdot
.48534 .27509 Mdot
.44879 .20291 Mdot
.18832 .61444 Mdot
.46019 .64003 Mdot
.49933 .35393 Mdot
.62698 .63223 Mdot
.44259 .32498 Mdot
.33412 .34762 Mdot
.6356 .61715 Mdot
.452 .19363 Mdot
.79871 .45291 Mdot
.57592 .3599 Mdot
.56007 .60105 Mdot
.48281 .44585 Mdot
.53122 .64992 Mdot
.47683 .18342 Mdot
.67926 .55521 Mdot
.54993 .25208 Mdot
.36906 .22974 Mdot
.38405 .67612 Mdot
.7018 .66933 Mdot
.56394 .14543 Mdot
.4952 .36439 Mdot
.72801 .60198 Mdot
.27057 .43585 Mdot
.41402 .75314 Mdot
.18943 .55232 Mdot
.55659 .32092 Mdot
.51748 .56299 Mdot
.36931 .6603 Mdot
.20073 .61337 Mdot
.64348 .61246 Mdot
.15063 .44182 Mdot
.27534 .42529 Mdot
.24566 .5307 Mdot
.3088 .73181 Mdot
.56365 .54755 Mdot
.25373 .63844 Mdot
.41531 .50167 Mdot
.54627 .42118 Mdot
.79137 .44089 Mdot
.5468 .60291 Mdot
.49542 .55178 Mdot
.51261 .7276 Mdot
.51046 .19268 Mdot
.20542 .51876 Mdot
.38108 .47098 Mdot
.61138 .24639 Mdot
.47782 .34527 Mdot
.63775 .34942 Mdot
.65978 .35269 Mdot
.64617 .66492 Mdot
.47311 .18571 Mdot
.45467 .21197 Mdot
.22853 .62255 Mdot
.21449 .66358 Mdot
.43681 .5133 Mdot
.17994 .53872 Mdot
.59666 .41236 Mdot
.58911 .75343 Mdot
.28118 .32533 Mdot
.44276 .8402 Mdot
.42901 .55982 Mdot
.45107 .45472 Mdot
.15931 .46018 Mdot
.16868 .53454 Mdot
.62046 .64937 Mdot
.59731 .67196 Mdot
.45041 .15231 Mdot
.48948 .31867 Mdot
.78663 .67273 Mdot
.68241 .52419 Mdot
.16853 .4388 Mdot
.52401 .54161 Mdot
.27528 .45304 Mdot
.40671 .62518 Mdot
.34914 .38795 Mdot
.67185 .43943 Mdot
.43504 .77765 Mdot
.39139 .65807 Mdot
.30936 .35016 Mdot
.36893 .51349 Mdot
.62455 .53022 Mdot
.42977 .66351 Mdot
.39683 .83099 Mdot
.69862 .46259 Mdot
.55915 .42378 Mdot
.64135 .80951 Mdot
.79345 .44391 Mdot
.56388 .18646 Mdot
.27902 .7313 Mdot
.62288 .66534 Mdot
.51691 .52363 Mdot
.83094 .54409 Mdot
.42899 .70161 Mdot
.45825 .72456 Mdot
.61567 .58113 Mdot
.47466 .24781 Mdot
.67179 .73698 Mdot
.49144 .85524 Mdot
.16192 .48467 Mdot
.39461 .39121 Mdot
.78914 .71359 Mdot
.3683 .23409 Mdot
.54245 .38445 Mdot
.67934 .73152 Mdot
.17333 .59278 Mdot
.64968 .50442 Mdot
.21451 .34251 Mdot
.51825 .76891 Mdot
.47502 .75132 Mdot
.46847 .26024 Mdot
.75242 .682 Mdot
.55643 .52454 Mdot
.71956 .76794 Mdot
.60812 .68964 Mdot
.45024 .27362 Mdot
.54297 .79602 Mdot
.45412 .74078 Mdot
.42399 .55773 Mdot
.53563 .73342 Mdot
.31943 .51615 Mdot
.52106 .66811 Mdot
.54472 .68653 Mdot
.55658 .34039 Mdot
.60106 .56544 Mdot
.57311 .67677 Mdot
.63337 .57251 Mdot
.39173 .69605 Mdot
.4348 .16454 Mdot
.70437 .36341 Mdot
.71497 .4328 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`2Yooooo`;o0000W_ooool001cooooo00?o0000ooooooooool0W_ooool2o`0000Wooooo0_l0
002Nooooo`007?ooool00ol0003oooooooooo`2Nooooo`;o00002_ooool2o`0000Oooooo0_l0002D
ooooo`007?ooool00ol0003oooooooooo`2Hooooo`;o00004?ooool2o`0000Oooooo0_l0002Doooo
o`007?ooool00ol0003oooooooooo`2Eooooo`;o000000?oooooo`000?l000006Oooool2o`0009Co
oooo000Looooo`03o`000?oooooooooo093ooooo0ol00002ooooo`;o00007?ooool4o`0009;ooooo
000Looooo`;o0000T?ooool4o`0002;ooooo0_l0002Booooo`007?ooool00ol0003oooooooooo`2?
ooooo`;o0000^?ooool001cooooo00?o0000ooooooooool0R_ooool2o`000;gooooo000Looooo`03
o`000?oooooooooo08Sooooo1?l0002mooooo`007?ooool00ol0003oooooooooo`27ooooo`Co0000
__ooool001cooooo00?o0000ooooooooool0Qoooool4o`000;kooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0P_ooool4o`000<?ooooo000Looooo`03
o`000?oooooooooo07Sooooo1?l000000ooooooo0000o`000007o`0001Oooooo0_l00002ooooo`;o
0000Y_ooool001cooooo00?o0000ooooooooool0N?ooool4o`000003ooooool0003o000000?o0000
1_ooool2o`0001?ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0009oooooo
000Looooo`03o`000?oooooooooo07gooooo0_l00008ooooo`?o00003Oooool2o`0000_ooooo1_l0
0003ooooo`;o0000V_ooool001cooooo00?o0000ooooooooool0N?ooool2o`000003ooooool0003o
000000;o00001Oooool2o`000003ooooool0003o000000;ooooo0_l00009ooooo`?o00001oooool2
o`0000Cooooo0_l00005ooooo`;o00001?ooool2o`0009Cooooo000Looooo`03o`000?oooooooooo
07Sooooo0_l000000ooooooo0000o`000003o`0000Cooooo0_l000000ooooooo0000o`000002oooo
o`;o00002Oooool2o`0000Sooooo0_l00008ooooo`;o00001?ooool2o`000003ooooool0003o0000
09Cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool0
0ol0003oooooooooo`1kooooo`Wo00002oooool2o`0000Oooooo0_l00008ooooo`Co00001?ooool2
o`0000Cooooo0_l00005ooooo`;o0000T?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Ooo
ool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo07gooooo
0_l000000ooooooo0000o`000002o`0000_ooooo0_l00007ooooo`?o00001oooool4o`000003oooo
ool0003o000000kooooo0_l0002@ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0POooool4o`0001Cooooo0_l0
00000ooooooo0000o`000008ooooo`?o00003_ooool2o`0001Kooooo0_l0001hooooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol00020
ooooo`Go00002Oooool2o`0000cooooo0_l00006ooooo`Co00002_ooool4o`0001Wooooo0_l0001h
ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo
00Gooooo00?o0000ooooooooool0P?ooool2o`0000_ooooo0ol000000ooooooo0000o`000002oooo
o`;o00003?ooool4o`0000Oooooo0_l00002ooooo`Co00000oooool3o`0000;ooooo0_l00029oooo
o`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0O?ooool2o`0000;ooooo0_l0000;ooooo`;o00000_ooool2o`0000;o
oooo0_l0000<ooooo`;o00002?ooool3o`0000Cooooo0_l00003ooooo`?o00000_ooool2o`000003
ooooool0003o000008Kooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj
^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo07_ooooo1ol000000ooooooo0000o`000009
ooooo`Co00006oooool2o`0001;ooooo0_l0000;ooooo`;o0000NOooool00006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0
Noooool7o`000003ooooool0003o000000Wooooo1?l0000looooo`Co0000Moooool001cooooo00?o
0000ooooooooool0N?ooool6o`0000;ooooo0_l00008ooooo`;o00000_ooool2o`0001cooooo0_l0
00000ooooooo0000o`00000Oooooo`;o0000Moooool001cooooo00?o0000ooooooooool0Moooool7
o`0000Wooooo0_l000000ooooooo0000o`000003ooooo`Co00005oooool4o`000003ooooool0003o
000001kooooo1?l0001fooooo`007?ooool00ol0003oooooooooo`1eooooo`Co00001Oooool2o`00
00Oooooo0_l00006ooooo`Go00005_ooool2o`0000;ooooo0_l0000Oooooo`Co0000M_ooool001co
oooo00?o0000ooooooooool0MOooool2o`000003ooooool0003o000000Cooooo1?l0000<ooooo`?o
000000?oooooo`000?l000003_ooool2o`0000Wooooo0ol00007ooooo`;o00001_ooool2o`00013o
oooo0_l0001fooooo`007?ooool00ol0003oooooooooo`1`ooooo`?o000000?oooooo`000?l00000
0_ooool4o`0000?ooooo0ol00005ooooo`;o000000Goooooo`000?l0003o0000ooooo`03o`00017o
oooo0_l00009ooooo`;o00000_ooool2o`0000Cooooo0_l00006ooooo`?o00000_ooool2o`0008?o
oooo000Looooo`03o`000?oooooooooo073ooooo2?l00002ooooo`;o00000oooool2o`0000Kooooo
1_l0000Cooooo`;o00003oooool2o`0000Cooooo0_l00002ooooo`;o00000_ooool7o`0008?ooooo
000Looooo`03o`000?oooooooooo07?ooooo1Ol00002ooooo`;o00003?ooool2o`0001Kooooo0_l0
0008ooooo`;o00003oooool2o`0000?ooooo1Ol00024ooooo`007?ooool00ol0003oooooooooo`1]
ooooo`;o00000_ooool2o`000003ooooool0003o000000Ko00009?ooool2o`0000Sooooo0_l00006
ooooo`;o00001Oooool2o`0000cooooo0_l00009ooooo`;o0000MOooool001cooooo00?o0000oooo
ooooool0Joooool4o`0000;ooooo0_l00004ooooo`Go0000=_ooool2o`0000Gooooo0_l00002oooo
o`;o00001?ooool2o`0000;ooooo0_l00009ooooo`;o000000?oooooo`000?l000000_l0001`oooo
o`007?ooool00ol0003oooooooooo`1[ooooo`;o00004?ooool2o`0001Gooooo0_l0000;ooooo`;o
00001oooool2o`0000oooooo1?l00002ooooo`Co000000Coooooo`000?l0003o00003?ooool4o`00
073ooooo000Looooo`03o`000?oooooooooo06[ooooo1?l00003ooooo`;o00002_ooool2o`0001Go
oooo1?l00009ooooo`;o00001oooool2o`0000oooooo3Ol00003ooooo`;o00002Oooool2o`00077o
oooo000Looooo`;o0000Joooool4o`0000?ooooo0_l0000=ooooo`;o00001Oooool2o`0000Cooooo
0_l00007ooooo`;o00005oooool3o`0000Wooooo3?l000001?oooooo0000o`000?ooool2o`0000_o
oooo0_l0001_ooooo`007?ooool00ol0003oooooooooo`1Rooooo`;o00001?ooool2o`0000;ooooo
0_l0000Booooo`Co00000oooool2o`0000Cooooo0_l0000Pooooo`?o00002_ooool9o`0000?ooooo
0_l00002ooooo`;o00002_ooool2o`0006oooooo000Looooo`03o`000?oooooooooo06;ooooo0ol0
00000ooooooo0000o`000002o`0000;ooooo0_l0000Cooooo`?o00000_ooool2o`0001Kooooo0ol0
000Kooooo`_o00001Oooool3o`0007[ooooo000Looooo`03o`000?oooooooooo06?ooooo0_l00000
0ooooooo0000o`000002o`0000;ooooo0_l0000Gooooo`Go00002_ooool2o`0000Sooooo0ol00009
ooooo`;o00004?ooool<o`0000Gooooo0_l0001jooooo`007?ooool00ol0003oooooooooo`1Voooo
o`;o00007Oooool5o`0000[ooooo0_l00008ooooo`;o00002_ooool2o`0000oooooo3Ol000000ooo
oooo0000o`00000>ooooo`;o00000_ooool2o`0006[ooooo000Looooo`03o`000?oooooooooo06Co
oooo1?l00005ooooo`;o00001_ooool2o`00013ooooo0_l00004ooooo`;o00001_ooool2o`0000Go
oooo1?l0000>ooooo`?o00002_ooool6o`000003ooooool0003o000000Co000000?oooooo`000?l0
00003_ooool2o`000004ooooool0003o0000o`0006[ooooo000Looooo`03o`000?oooooooooo067o
oooo0_l000000ooooooo0000o`000002o`0000Gooooo0_l00006ooooo`;o00002oooool2o`0000;o
oooo0ol00004ooooo`Co00001?ooool2o`0000;ooooo1ol0000>ooooo`?o00002Oooool=o`0001Go
oooo0_l0001[ooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o00001oooool2o`0000?ooooo
0_l0000Jooooo`;o00000_ooool6o`0000?ooooo0_l00005ooooo`[o00002?ooool2o`0000Gooooo
0_l00008oooooa3o0000P?ooool001cooooo00?o0000ooooooooool0F?ooool2o`0000Kooooo0_l0
0007ooooo`;o00001oooool3o`000004ooooool0003o0000ooooo`;o00001_ooool3o`0000?ooooo
1_l00002ooooo`;o00001Oooool7o`0000_ooooo0_l00005ooooo`;o00002?ooool@o`000003oooo
ool0003o000001Cooooo0_l0001Wooooo`007?ooool00ol0003oooooooooo`1Fooooo`Co00001_oo
ool2o`0000Oooooo0_l00007ooooo`?o000000Coooooo`000?l0003ooooo0_l00005ooooo`?o0000
1oooool4o`0000Wooooo1Ol000000ooooooo0000o`00000Koooooa;o00005?ooool2o`0006Oooooo
000Looooo`03o`000?oooooooooo05Cooooo1?l0000:ooooo`;o00000oooool2o`0000gooooo0_l0
0008ooooo`?o00001oooool6o`0000Kooooo0_l00002ooooo`Go00003oooool2o`0000_ooooo4Ol0
001mooooo`007?ooool00ol0003oooooooooo`1Cooooo`?o00001?ooool2o`0000Kooooo0_l00003
ooooo`;o00002Oooool2o`0000;ooooo0ol000000ooooooo0000o`000003o`000004ooooool0003o
0000o`0000Wooooo1ol00002ooooo`?o00000_ooool3o`00017ooooo0_l0000:oooooa?o00003Ooo
ool2o`0000Gooooo0_l0001Vooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00001Oooool2
o`0000kooooo0ol00003ooooo`Co00000oooool2o`000003ooooool0003o000000?o00001?ooool2
o`0000Oooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000002?ooooo4ol00002
ooooo`;o00002Oooool2o`0000Gooooo0ol0001Uooooo`007?ooool00ol0003oooooooooo`1Voooo
o`;o00000_ooool3o`0000?ooooo0ol00003ooooo`;o00001?ooool2o`0000;ooooo0_l000000ooo
oooo0000o`00000<ooooo`Ko00000oooool2o`0001kooooo4Ol00004ooooo`;o00004Oooool2o`00
06Gooooo000Looooo`03o`000?oooooooooo063ooooo0_l00004ooooo`;o00003_ooool2o`0000Co
oooo0_l00002ooooo`;o00004?ooool4o`0000Cooooo0_l0000;ooooo`;o00001_ooool2o`0000So
oooo4_l000000ooooooo0000o`00001kooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o0000
0oooool2o`0000Gooooo0_l0000Tooooo`Co00001?ooool4o`0000Wooooo0_l00006ooooo`;o0000
2?oooolEo`0001Wooooo0_l0001Pooooo`007?ooool2o`0005kooooo0_l00003ooooo`;o000000?o
ooooo`000?l000001ol00003ooooo`;o00000oooool2o`0000;ooooo1_l000000ooooooo0000o`00
0005ooooo`;o00002_ooool2o`0000Cooooo1?l0000Booooo`;o00001ooooolCo`0001_ooooo0_l0
001Pooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o00000_ooool?o`000003ooooool0003o
000000Ko000000?oooooo`000?l000001ol00005ooooo`;o00004?ooool2o`0001Cooooo0_l00006
ooooo`;o000000?oooooo`000?l000003?l00002ooooo`;o0000O?ooool001cooooo00?o0000oooo
ooooool0Coooool2o`00013ooooo0_l000000ooooooo0000o`000003ooooo`So00000_ooool3o`00
0003ooooool0003o000000Cooooo1?l0000Cooooo`;o00001?ooool2o`0000_ooooo1?l0000=oooo
o`Wo000000?oooooo`000?l000002Ol0000Fooooo`;o0000I?ooool001cooooo00?o0000oooooooo
ool0Coooool4o`0000Sooooo0_l0000>ooooo`Ko00000_ooool4o`0000Gooooo0ol00007ooooo`Co
00000_ooool3o`0000Gooooo0ol0000@ooooo`Co00002oooool2o`0000;ooooo4Ol0000Hooooo`;o
0000I?ooool001cooooo00?o0000ooooooooool0Coooool4o`0000Sooooo0_l00004ooooo`;o0000
3?ooool8o`0000;ooooo1Ol00005ooooo`Oo00000_ooool5o`0000Cooooo0_l00002ooooo`;o0000
5Oooool2o`0000?ooooo0ol00003oooooa7o00006Oooool2o`0006;ooooo000Looooo`03o`000?oo
oooooooo057ooooo0_l00005ooooo`Co00001Oooool2o`0000cooooo3_l00006ooooo`Co00002?oo
ool3o`000003ooooool0003o000000Cooooo0_l0000>ooooo`;o00001Oooool2o`0000?ooooo1?l0
0002oooooa7o00006Oooool2o`0006;ooooo000Looooo`03o`000?oooooooooo04[ooooo0_l00004
ooooo`?o00001Oooool4o`000003ooooool0003o000001?ooooo2?l0000:ooooo`Co00000_ooool2
o`0000Cooooo0_l000000ooooooo0000o`000005ooooo`?o00003?ooool2o`0000?ooooo1?l00005
ooooo`;o00000oooool=o`0000?ooooo0_l0001kooooo`007?ooool00ol0003oooooooooo`18oooo
o`Co00000oooool3o`0000Kooooo0_l00003ooooo`;o00005oooool2o`0000kooooo0_l00002oooo
o`?o00001Oooool4o`0000Cooooo0ol0000Aooooo`Go00000oooool2o`0000Cooooo0_l000000ooo
oooo0000o`000005o`000003ooooool0003o000000?ooooo1?l0000Kooooo`;o0000G?ooool001co
oooo00?o0000ooooooooool0B?ooool4o`0000?ooooo0ol00006ooooo`Co00006_ooool2o`0001;o
oooo1?l00004ooooo`Ko00005_ooool6o`0000;ooooo0_l00004ooooo`[o00002?ooool2o`0001_o
oooo0_l0001Looooo`007?ooool00ol0003oooooooooo`19ooooo`;o00002oooool6o`00023ooooo
0_l0000>ooooo`;o00000oooool2o`0000?ooooo0_l0000Booooo`;o00001Oooool3o`0000Gooooo
0_l00003ooooo`?o000000?oooooo`000?l000000_l00023ooooo`007?ooool00ol0003ooooooooo
o`1;ooooo`;o00002Oooool5o`00027ooooo0ol0000Booooo`?o00001Oooool2o`0000kooooo0ol0
0004ooooo`;o00001oooool4o`0000;ooooo0ol000000ooooooo0000o`000024ooooo`007?ooool0
0ol0003oooooooooo`13ooooo`;o00001_ooool2o`000003ooooool0003o000000Gooooo0_l0000V
ooooo`;o00000oooool5o`0000;ooooo0_l00006ooooo`Ko00000_ooool4o`0000cooooo0ol00004
ooooo`;o00002?ooool3o`0000;ooooo0ol000001?oooooo0000o`000?ooool2o`0002Kooooo0_l0
001Iooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00002?ooool3o`0000Gooooo0_l0000[
ooooo`Go00000_ooool2o`0000Gooooo1ol00002ooooo`Co000000?oooooo`000?l000005?ooool2
o`0000Oooooo0_l00005ooooo`Co00000_ooool2o`0002;ooooo0_l0001Iooooo`007?ooool00ol0
003oooooooooo`1:ooooo`;o000000?oooooo`000?l00000>_ooool2o`000004ooooool0003o0000
ooooo`Oo00002?ooool2o`00017ooooo0_l000000ooooooo0000o`000007ooooo`;o00001Oooool2
o`0000Cooooo0_l0001mooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00001_ooool2o`00
043ooooo0_l000000ooooooo0000o`000006o`0000?ooooo0_l0000Eooooo`;o000000?oooooo`00
0?l000000_l00002ooooo`;o00002?ooool2o`0000[ooooo0_l0001gooooo`007?ooool00ol0003o
ooooooooo`12ooooo`;o00001_ooool2o`0000?ooooo0_l0000Cooooo`;o00000oooool2o`00027o
oooo0_l00003ooooo`So000000?oooooo`000?l000003oooool2o`0000Oooooo1?l00002ooooo`;o
00002?ooool2o`000003ooooool0003o000000Oooooo0_l0001gooooo`007?ooool2o`0004Wooooo
0_l00002ooooo`;o000000?oooooo`000?l000004?ooool2o`000004ooooool0003o0000ooooo`Ko
000000Coooooo`000?l0003ooooo0_l0000Nooooo`So00004?ooool4o`0001[ooooo0ol000000ooo
oooo0000o`00001looooo`007?ooool00ol0003oooooooooo`17ooooo`?o00000_ooool2o`0001?o
oooo0_l00004ooooo`;o00000_ooool5o`000003ooooool0003o000000;o00007?ooool8o`0000Go
oooo1?l00007ooooo`;o00003_ooool2o`0000gooooo0_l000000ooooooo0000o`000006ooooo`;o
0000M?ooool001cooooo00?o0000ooooooooool0??ooool4o`0000Oooooo0_l0000Iooooo`;o0000
00?oooooo`000?l000001Oooool2o`0000Gooooo0_l0000Jooooo`Ko00001Oooool2o`000003oooo
ool0003o000000?o00002_ooool2o`0000?ooooo0_l00004ooooo`Go00005oooool2o`0007Cooooo
000Looooo`03o`000?oooooooooo03_ooooo1Ol00005ooooo`;o00005Oooool2o`0000Cooooo0_l0
00000ooooooo0000o`00000Xooooo`;o000000Coooooo`000?l0003o00001Oooool2o`000003oooo
ool0003o000000;o00002oooool2o`0000?ooooo0_l00004ooooo`Oo0000Roooool001cooooo00?o
0000ooooooooool0>oooool2o`0000Sooooo0_l0000Eooooo`;o00001?ooool2o`0002_ooooo0_l0
0002ooooo`_o000000?oooooo`000?l000005_ooool4o`000004ooooool0003o0000o`0000;ooooo
0_l00026ooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00005_ooool2o`0001kooooo0ol0
000?ooooo`;o00000_ooool7o`0000;ooooo1Ol0000Looooo`;o000000Coooooo`000?l0003o0000
0_ooool2o`0001[ooooo0_l0001Vooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00000ooo
ool2o`00013ooooo0_l00005ooooo`;o00007_ooool4o`0001?ooooo0_l000000ooooooo0000o`00
0004ooooo`;o00007_ooool5o`0000?ooooo0ol00002ooooo`;o00005?ooool3o`0000;ooooo0_l0
001Rooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00000oooool2o`00013ooooo0_l0000O
ooooo`Co00001?ooool3o`0001;ooooo0_l000001?oooooo0000o`000?ooool2o`00013ooooo0_l0
000?ooooo`Go00001?ooool2o`0000;ooooo0_l0000Dooooo`;o00000oooool2o`0006;ooooo000L
ooooo`03o`000?oooooooooo05Wooooo0_l0000Jooooo`So00000oooool5o`0000kooooo0ol00000
1?oooooo0000o`000?ooool2o`00013ooooo0_l00002ooooo`;o00003_ooool3o`00027ooooo0_l0
001Sooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o00005Oooool4o`000003ooooool0003o
000000Ko00001Oooool6o`0000_ooooo0ol000001?oooooo0000o`000?ooool2o`0000;ooooo0_l0
000@ooooo`;o00001oooool2o`0000Kooooo0_l00003ooooo`;o000000?oooooo`000?l000006Ooo
ool3o`0006;ooooo000Looooo`03o`000?oooooooooo03Wooooo0_l0000aoooooa?o00001Oooool4
o`0000cooooo0_l00005ooooo`;o000000?oooooo`000?l000004Oooool2o`0000Kooooo0_l0000;
ooooo`;o000000?oooooo`000?l000006_ooool2o`0000;ooooo0_l0001Nooooo`007?ooool00ol0
003oooooooooo`0iooooo`;o00000_ooool3o`0002Wooooo2Ol00002ooooo`Co000000?oooooo`00
0?l000001Ol00004ooooo`;o00003_ooool4o`0000?ooooo0_l0000?ooooo`;o00000oooool2o`00
00Sooooo0_l0000:ooooo`;o00002_ooool5o`00017ooooo0_l0001Nooooo`007?ooool00ol0003o
ooooooooo`0hooooo`;o00000oooool3o`0002Oooooo2_l0000:ooooo`Wo00004_ooool2o`0001Co
oooo0_l00003ooooo`Co00001_ooool2o`0000[ooooo1?l000000ooooooo0000o`000005ooooo`Go
00004Oooool2o`0005kooooo000Looooo`03o`000?oooooooooo03Sooooo0_l0000Jooooo`;o0000
4?ooool7o`000003ooooool0003o000000;o00002?ooool2o`000003ooooool0003o000000Ko0000
4oooool3o`0001Sooooo0_l0000Dooooo`Oo000000?oooooo`000?l000003?ooool2o`0000;ooooo
0_l0001Tooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool2o`000003
oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0?oooool2o`0001;ooooo0ol0000@ooooo`Oo
00000oooool2o`0000Sooooo2ol0000Aooooo`Ko00001?ooool2o`0002Wooooo0_l000001?oooooo
0000o`000?ooool2o`0000;ooooo0_l00002ooooo`Go000000Goooooo`000?l0003o0000ooooo`02
o`0000Cooooo0_l0001Nooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03oooooo0_l0000Booooo`;o00003ooo
ool2o`0000?ooooo0ol000000ooooooo0000o`000004ooooo`?o00000_ooool2o`0000;ooooo1?l0
0002ooooo`Go00003oooool6o`0000Cooooo0_l0000Cooooo`;o00003?ooool2o`0000;ooooo0_l0
0004ooooo`;o000000?oooooo`000?l000003Ol000001?oooooo0000o`000?l00002ooooo`;o0000
0_ooool2o`0005kooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo1Ol0
0006ooooo`03o`000?oooooooooo05;ooooo0_l0000@ooooo`;o00000oooool2o`0000;ooooo0_l0
0002ooooo`Go00000_ooool6o`0000Kooooo0ol00004ooooo`;o00003?ooool2o`0000?ooooo0ol0
000Dooooo`;o00003?ooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`000003oooo
ool0003o000001;o000000Coooooo`000?l0003o0000HOooool00003ooooool0003ooooo00;ooooo
00?o0000ooooooooool02Oooool01?m4A4CogMgMooooool00007ooooo`?o0000D_ooool2o`0000ko
oooo1?l00006ooooo`_o00000_ooool5o`0000Kooooo1Ol00002ooooo`;o00003?ooool4o`000005
ooooool0003o0000o`000?ooool00_l0000Vooooo`?o00000ooooolDo`0000;ooooo0_l0001Qoooo
o`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`00
00Oooooo00?o0000ooooooooool0?_ooool2o`00013ooooo0_l0000@ooooo`?o00001oooool6o`00
0003ooooool0003o000000?o000000?oooooo`000?l000001_l00003ooooo`;o000000?oooooo`00
0?l000003_ooool6o`000004ooooool0003o0000ooooo`?o00009oooool2o`000003ooooool0003o
000001Co00000oooool2o`00063ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo
00[ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0mooooo`?o00004?ooool2o`00
00oooooo0ol00005oooooaSo00000oooool2o`0000Gooooo0_l0000:ooooo`Co00000oooool2o`00
0003ooooool0003o0000013ooooo0_l0000GoooooaWo00000_ooool2o`00063ooooo00001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0m
ooooo`;o00002_ooool2o`0000Sooooo0_l0000;ooooo`Co00001OoooolGo`000004ooooool0003o
0000o`0000;ooooo0_l000000ooooooo0000o`000002o`0000Wooooo0_l00003ooooo`;o000000?o
ooooo`000?l000004oooool2o`0000Wooooo0_l0000<oooooa[o0000Hoooool00006ooooooo^k^ko
<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo03;ooooo
0ol00003ooooo`;o00000oooool2o`0000[ooooo0_l00008ooooo`;o00002oooool4o`0000Cooooo
1Ol00002ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000005o`000003oooo
ool0003o000000?o00000_ooool2o`000003ooooool0003o000000_ooooo0_l00003ooooo`;o0000
0_ooool2o`0001Oooooo0_l00004ooooo`;o00002Oooool2o`000003ooooool0003o000000So0000
00?oooooo`000?l000001_l000000ooooooo0000o`000005o`0000Kooooo0_l0001Jooooo`007?oo
ool00ol0003oooooooooo`0booooo`?o000000?oooooo`000?l000000_l00003ooooo`;o00008Ooo
ool4o`0000;ooooo2ol000000ooooooo0000o`00000=o`000003ooooool0003o000000;o00000ooo
ool3o`0000gooooo1?l000001?oooooo0000o`000?l0000<ooooo`;o00002Oooool2o`0000oooooo
0_l000000ooooooo0000o`000008o`000003ooooool0003o000000[o000000Coooooo`000?l0003o
00001_ooool2o`0000Gooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`0fooooo`?o0000
0oooool2o`0000_ooooo0_l0000Eooooo`Go000000Coooooo`000?l0003ooooo6Ol000000ooooooo
0000o`000002o`0000;ooooo0ol000000ooooooo0000o`00000:ooooo`?o00000_ooool2o`0000;o
oooo0ol00008ooooo`?o00006ooooolLo`0000?ooooo0ol00007ooooo`;o0000Doooool001cooooo
00?o0000ooooooooool0=oooool2o`0000;ooooo1?l00008ooooo`Co00005?ooool3o`000003oooo
ool0003o000000;o00000_oooolNo`0000Kooooo0_l00008ooooo`Go00000_ooool2o`0000;ooooo
0ol00009ooooo`;o00000_ooool2o`0001;ooooo0_l00003oooooago000000?oooooo`000?l00000
0_l0001Looooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00002Oooool4o`0000Sooooo0_l0
0004ooooo`;o00000_ooool2o`0000?ooooo0_l00007ooooo`;o00000oooool5o`000003ooooool0
003o000001?o000000?oooooo`000?l000000_l00002ooooo`;o00000oooool2o`000003ooooool0
003o000000Oooooo1Ol00002ooooo`;o00004_ooool2o`0000Kooooo0_l00008ooooo`Co00000ooo
ool2o`000003ooooool0003o000000;o000000?oooooo`000?l000006_l0001Jooooo`007?ooool0
0ol0003oooooooooo`0`ooooo`;o00001?ooool2o`0000;ooooo0ol0000@ooooo`;o00000_ooool2
o`0000?ooooo0_l00007ooooo`;o00000oooool2o`000003ooooool0003o0000023o000000Gooooo
o`000?l0003o0000ooooo`02o`0000Wooooo0ol00002ooooo`;o00000oooool2o`0000Wooooo0_l0
0002ooooo`;o00001_ooool2o`0000Sooooo0_l000000ooooooo0000o`000002oooooako00000ooo
ool3o`0005[ooooo000Looooo`03o`000?oooooooooo03Kooooo0_l00002ooooo`?o00008Oooool3
o`0000Kooooo7ol000001?oooooo0000o`000?ooool3o`0000cooooo0ol00007ooooo`;o00002Ooo
ool2o`00013ooooo0_l00005ooooo`;o00000_oooolNo`000003ooooool0003o000000;o0000Fooo
ool001cooooo00?o0000ooooooooool0;Oooool2o`0000?ooooo0_l0000Jooooo`;o00001?ooool2
o`0000Sooooo0ol00005ooooob3o000000Coooooo`000?l0003ooooo0ol0000=ooooo`;o00000_oo
ool2o`0001_ooooo0ol00002ooooo`;o00001Oooool2o`0000;ooooo1_l00002oooooaCo00000ooo
ool2o`0005gooooo000Looooo`03o`000?oooooooooo02gooooo0_l00003ooooo`?o00001?ooool2
o`0001?ooooo0_l00003ooooo`?o00002Oooool2o`0000?ooooo8_l000001?oooooo0000o`000?oo
ool3o`0000;ooooo0_l0000=ooooo`;o00006_ooool4o`0000kooooo1ol000000ooooooo0000o`00
000Bo`0000;ooooo0_l0000Mooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0;Oooool2
o`0000Cooooo0_l00004ooooo`;o00006?ooool2o`0000Wooooo0ol000000ooooooo0000o`00000R
o`000004ooooool0003o0000o`0000Cooooo0ol00008ooooo`;o00001?ooool2o`0000;ooooo0_l0
00001?oooooo0000o`000?ooool2o`0000oooooo0_l0000Aoooooago00004oooool2o`0000[ooooo
0_l0000nooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o00002?ooool2o`00013ooooo0_l0
00000ooooooo0000o`00000@ooooo`;o00000_ooool:o`0000;ooooo6?l00002ooooo`;o00001?oo
ool2o`0000Wooooo0_l00004ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o0000
1_ooool3o`0000Kooooo0_l0000;ooooo`;o00000oooool3o`0000;ooooo5Ol00002ooooo`;o0000
4oooool3o`0000Wooooo0ol0000mooooo`007?ooool00ol0003oooooooooo`0gooooo`Co00003Ooo
ool6o`00013ooooo0_l000001?oooooo0000o`000?ooool3o`000003ooooool0003o000000;o0000
00?oooooo`000?l000006?l00004ooooo`;o00003?ooool2o`0000;ooooo0_l00002ooooo`Go0000
2oooool3o`0000Kooooo0_l0000;ooooo`;o00000oooool4o`000003ooooool0003o000000oo0000
00?oooooo`000?l000000oooool4o`000003ooooool0003o000000?ooooo0ol00009ooooo`;o0000
2Oooool3o`0003gooooo000Looooo`;o0000>Oooool3o`0000gooooo0_l000000ooooooo0000o`00
0003ooooo`;o00002oooool3o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l00000
7_l000001?oooooo0000o`000?ooool2o`000004ooooool0003o0000ooooo`;o00001_ooool2o`00
0004ooooool0003o0000o`0000;ooooo0_l000000ooooooo0000o`000007ooooo`?o00002_ooool2
o`0000_ooooo0ol00003oooooaGo000000?oooooo`000?l000000_l000000ooooooo0000o`000002
o`000003ooooool0003o000000?ooooo0ol00005ooooo`?o00000oooool2o`0000Oooooo0_l0000n
ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00005_ooool2o`0000Cooooo0ol00004oooo
o`;o000000?oooooo`000?l00000:?l000001?oooooo0000o`000?ooool5o`0000Oooooo1?l0000?
ooooo`Co00002Oooool2o`0000_ooooo0ol000000ooooooo0000o`00000No`0000oooooo0ol00003
ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0>?ooool2o`0000gooooo1Ol00008oooo
o`Go00001?ooool2o`000003ooooool0003o000000Go000000?oooooo`000?l000008?l000000ooo
oooo0000o`000002ooooo`;o00002Oooool3o`0000Gooooo0_l0000;ooooo`;o00002Oooool2o`00
00;ooooo0_l0000;oooooa[o00000_ooool2o`0000?ooooo0_l0000Booooo`;o00000_ooool2o`00
04?ooooo000Looooo`03o`000?oooooooooo033ooooo0_l0000=ooooo`;o00001_ooool5o`0000So
oooo0_l00007ooooo`;o000000?oooooo`000?l000001Ol000000ooooooo0000o`000003o`000003
ooooool0003o000001So00000oooool2o`0000?ooooo0_l0000@ooooo`Co00001?ooool2o`0000ko
oooo0_l00002ooooo`;o00003OoooolGo`0000Sooooo0_l0000Cooooo`;o000000?oooooo`000?l0
0000@oooool001cooooo00?o0000ooooooooool0<?ooool2o`0000gooooo0_l0000Cooooo`;o0000
1oooool2o`000003ooooool0003o000000_o000000?oooooo`000?l000006?l00002ooooo`?o0000
0oooool2o`00013ooooo1_l00002ooooo`;o000000?oooooo`000?l000004Oooool2o`0000_ooooo
5ol00003ooooo`Co00001_ooool2o`0000Cooooo0_l00008ooooo`;o00002?ooool2o`0003cooooo
000Looooo`03o`000?oooooooooo03kooooo0_l0000@ooooo`;o00000_ooool3o`0000Kooooo0_l0
0002ooooo`_o000000?oooooo`000?l000006Ol00002ooooo`;o00006_ooool2o`0000Gooooo0_l0
000:ooooo`Co00000oooool2o`0000_ooooo5?l00006ooooo`Co00001_ooool2o`0000Cooooo0_l0
000Booooo`;o0000??ooool001cooooo00?o0000ooooooooool0:Oooool2o`0001?ooooo0_l0000=
ooooo`;o000000?oooooo`000?l000000oooool2o`000003ooooool0003o000000Cooooo0_l00000
0ooooooo0000o`000009o`000003ooooool0003o000001Wo00006_ooool3o`0001Cooooo1?l0000B
ooooo`Ko000000?oooooo`000?l000002?l00009ooooo`;o00000oooool2o`0001_ooooo0_l0000l
ooooo`007?ooool00ol0003oooooooooo`0Xooooo`?o00008_ooool2o`0000Oooooo1?l00002oooo
o`Co000000?oooooo`000?l000002Ol000000ooooooo0000o`00000Io`000003ooooool0003o0000
00;ooooo0_l0000Cooooo`Go0000:_ooool2o`0000?ooooo0_l00006ooooo`Co00003?ooool2o`00
01[ooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0Xooooo`;o00005oooool2o`0000ko
oooo0_l00003ooooo`Co00000_ooool3o`0000Kooooo9_l00002ooooo`;o00005_ooool3o`0000ko
oooo0_l0000?ooooo`;o00002?ooool2o`0000Cooooo0_l00007ooooo`;o0000:?ooool3o`0003co
oooo000Looooo`03o`000?oooooooooo047ooooo0_l0000=ooooo`?o00001?ooool5o`0000;ooooo
0ol00004ooooob;o000000?oooooo`000?l000001Oooool2o`00017ooooo0_l00002ooooo`?o0000
2_ooool5o`0000oooooo0_l00007ooooo`;o00001Oooool5o`0002oooooo0_l0000looooo`007?oo
ool00ol0003oooooooooo`0_ooooo`;o00006oooool2o`0000;ooooo0_l00005ooooo`;o000000?o
ooooo`000?l000000_ooool3o`0000;ooooo0_l00002oooooako000000?oooooo`000?l000000_l0
00000ooooooo0000o`000002ooooo`;o00004Oooool2o`0000;ooooo1?l000000ooooooo0000o`00
0005ooooo`Ko00006?ooool2o`0000Gooooo1Ol00003ooooo`;o00002_ooool2o`000003ooooool0
003o000001_ooooo0_l0000looooo`007?ooool00ol0003oooooooooo`0_ooooo`Co00004oooool2
o`0000Cooooo0_l000000ooooooo0000o`000003o`0000oooooo9Ol00003ooooo`;o00006Oooool4
o`000003ooooool0003o000000[o00004oooool4o`0000?ooooo0_l00006ooooo`;o00001?ooool2
o`0000[ooooo0_l000000ooooooo0000o`00000Kooooo`;o0000??ooool001cooooo00?o0000oooo
ooooool0;oooool4o`0001?ooooo0_l00007ooooo`Go00001_ooool2o`0000Wooooo2Ol00002oooo
o`;o000000?oooooo`000?l000004ol0000Oooooo`?o000000?oooooo`000?l000001ol000000ooo
oooo0000o`000002ooooo`;o00003_ooool5o`0000?ooooo0_l0000@ooooo`;o00001_ooool3o`00
05_ooooo000Looooo`03o`000?oooooooooo02kooooo0_l000000ooooooo0000o`00000@ooooo`;o
000000Coooooo`000?l0003o00001_ooool2o`0000Wooooo0_l00009ooooo`[o000000Coooooo`00
0?l0003ooooo4_l00004ooooo`;o00005Oooool2o`0000[ooooo1Ol000000ooooooo0000o`000003
o`0000;ooooo0_l0000>ooooo`Go000000?oooooo`000?l000004_ooool2o`0000Kooooo0ol0000L
ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0;_ooool2o`0001?ooooo0_l000000ooo
oooo0000o`000002o`0000Gooooo1_l0000<ooooo`;o00000oooool4o`000003ooooool0003o0000
00Wo000000?oooooo`000?l000002ol00003ooooo`Co00005Oooool2o`000004ooooool0003o0000
ooooo`;o00001?ooool2o`000003ooooool0003o000000;ooooo1?l00002ooooo`;o00005?ooool2
o`0000Wooooo0_l00002ooooo`Co00001Oooool4o`0001gooooo1?l0000mooooo`007?ooool00ol0
003oooooooooo`18ooooo`;o00000oooool8o`0000;ooooo0_l000000ooooooo0000o`000005oooo
o`;o00000oooool4o`0000;ooooo5ol00002ooooo`Go00000_ooool2o`00017ooooo0_l00002oooo
o`;o000000Coooooo`000?l0003o00002_ooool3o`0000;ooooo0_l0000Pooooo`;o00000_ooool4
o`0000Gooooo1?l0000Mooooo`;o00006oooool2o`0002;ooooo000Looooo`;o0000C_ooool2o`00
00;ooooo0_l00003ooooo`?o000000?oooooo`000?l000001_ooool3o`0000Oooooo5Ol00002oooo
o`Ko00000oooool2o`00013ooooo0ol00005ooooo`?o00002_ooool3o`0000;ooooo0ol0001Zoooo
o`;o00008_ooool001cooooo00?o0000ooooooooool0DOooool2o`000003ooooool0003o000000Co
00002?ooool3o`0000Sooooo2?l0000<ooooo`Co00006Oooool2o`0000;ooooo0_l0000?ooooo`?o
00000oooool2o`0001?ooooo1?l000000ooooooo0000o`00000?ooooo`;o00002_ooool2o`0003;o
oooo0_l0000Sooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o000000?oooooo`000?l00000
0_ooool3o`0001?ooooo1Ol0000<ooooo`Ko000000?oooooo`000?l000006_ooool4o`000005oooo
ool0003o0000o`000?ooool00_l000000ooooooo0000o`000002ooooo`?o00006Oooool4o`000003
ooooool0003o000000gooooo1?l0000:ooooo`;o0000<_ooool2o`0002?ooooo000Looooo`03o`00
0?oooooooooo05Wooooo0_l0000@ooooo`;o000000?oooooo`000?l000001Ol00004ooooo`Co0000
0_ooool2o`0000?ooooo1?l00002ooooo`;o00006?ooool9o`000003ooooool0003o000000;ooooo
0ol0000Oooooo`;o00003?ooool6o`0002?ooooo0_l0000looooo`007?ooool00ol0003ooooooooo
o`0`ooooo`Co00002?ooool2o`00013ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l0
000<ooooo`?o00000_ooool2o`0000Kooooo0ol00003ooooo`Co00000_ooool3o`0000;ooooo0_l0
0004ooooo`;o00005oooool2o`000004ooooool0003o0000ooooo`;o00000oooool2o`0000?ooooo
0ol0000Iooooo`;o00000oooool2o`0000cooooo0_l00002ooooo`;o00008oooool2o`0003cooooo
000Looooo`03o`000?oooooooooo02Sooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l0
0008ooooo`?o00003oooool2o`0000?ooooo0_l000000ooooooo0000o`000004o`0000Sooooo1_l0
0007ooooo`;o000000?oooooo`000?l000001Oooool2o`0000;ooooo1?l00007ooooo`;o000000?o
ooooo`000?l000004_ooool4o`0000kooooo0ol00004ooooo`;o00004_ooool3o`0000;ooooo0_l0
0002ooooo`;o00002Oooool3o`0006Cooooo000Looooo`03o`000?oooooooooo02Sooooo0_l00003
ooooo`;o000000?oooooo`000?l000002oooool4o`0000gooooo0_l0000:ooooo`;o00001_ooool4
o`000004ooooool0003o0000o`0000;ooooo0_l00003ooooo`ko000000Coooooo`000?l0003o0000
2_ooool2o`0001;ooooo0_l00002ooooo`;o00001oooool2o`000003ooooool0003o000000?o0000
1?ooool2o`0001;ooooo0_l00003ooooo`?o000000?oooooo`000?l000002_ooool2o`0006Cooooo
000Looooo`03o`000?oooooooooo03oooooo0_l0000;ooooo`Co00000oooool2o`0000Wooooo0_l0
0002ooooo`;o00000oooool3o`0000;ooooo0_l00005ooooo`co00002_ooool3o`0001Wooooo0_l0
0007ooooo`;o000000Coooooo`000?l0003ooooo0ol00004ooooo`;o00005oooool4o`000003oooo
ool0003o000000?ooooo0_l00003ooooo`;o00009?ooool2o`0003kooooo000Looooo`03o`000?oo
oooooooo033ooooo0ol0000;ooooo`;o00003?ooool2o`000003ooooool0003o000000;ooooo0_l0
0009ooooo`;o00003Oooool2o`0001Wooooo1?l000000ooooooo0000o`00000Dooooo`?o00002ooo
ool2o`0000;ooooo0_l00004ooooo`;o00006?ooool3o`000003ooooool0003o000000;o000000?o
ooooo`000?l000000oooool2o`0002Cooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0W
ooooo`;o00001oooool3o`0000?ooooo0_l00006ooooo`;o00003oooool2o`0001?ooooo0_l00002
ooooo`?o00000_ooool2o`000004ooooool0003o0000ooooo`;o00004oooool2o`0000?ooooo1?l0
000<ooooo`Co00000_ooool3o`0000_ooooo0_l00002ooooo`?o00006?ooool3o`0000Oooooo0ol0
0007ooooo`;o00009Oooool2o`0003cooooo000Looooo`03o`000?oooooooooo02Oooooo0_l00007
ooooo`;o00000_ooool4o`0000?ooooo0_l0000?ooooo`;o00005_ooool2o`0000;ooooo0ol00002
ooooo`;o000000?oooooo`000?l000000ol0000Cooooo`Co00000oooool2o`0000Wooooo1ol00009
ooooo`;o00002_ooool2o`0000;ooooo1?l00009ooooo`;o00000oooool2o`0000;ooooo1Ol00000
1?oooooo0000o`000?ooool2o`0000Wooooo0_l0000Uooooo`;o0000??ooool001cooooo00?o0000
ooooooooool0;Oooool2o`0000Cooooo0ol00005ooooo`;o00003oooool2o`0001_ooooo0_l00002
ooooo`;o00000_ooool4o`0000gooooo0_l00004ooooo`Co00003_ooool4o`000003ooooool0003o
000000Wooooo0_l00009ooooo`Co000000?oooooo`000?l000000_l00009ooooo`;o00000oooool2
o`0000Cooooo0ol000001?oooooo0000o`000?ooool2o`0000?ooooo0_l00002ooooo`;o0000?ooo
ool2o`0002Cooooo000Looooo`03o`000?oooooooooo02gooooo0_l00004ooooo`;o00000_ooool2
o`0003Sooooo1?l00004ooooo`?o00001_ooool2o`0000[ooooo0_l00003ooooo`;o00000oooool2
o`000003ooooool0003o000000;ooooo0_l0000Dooooo`Co00000oooool2o`000003ooooool0003o
000000;o00001oooool2o`0000gooooo0_l00003ooooo`;o00000_ooool2o`0003oooooo0_l0000T
ooooo`007?ooool00ol0003oooooooooo`0booooo`;o00000oooool2o`0000Oooooo0_l0000_oooo
o`;o000000?oooooo`000?l000000oooool3o`0000;ooooo1?l00003ooooo`Ko00000oooool8o`00
0004ooooool0003o0000o`0000cooooo0_l0000<ooooo`;o00001Oooool3o`000003ooooool0003o
000000;o00001oooool2o`0000gooooo0_l00005ooooo`;o0000Ioooool001cooooo00?o0000oooo
ooooool0<_ooool2o`000003ooooool0003o000000Wooooo0_l0000;ooooo`;o00009Oooool2o`00
00;ooooo0_l00004ooooo`Co00000oooool6o`0000?ooooo2?l000000ooooooo0000o`00000<oooo
o`?o00002Oooool2o`000003ooooool0003o000000?o00000_ooool3o`0000cooooo0_l0000=oooo
o`;o00001Oooool2o`0002Sooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0eooooo`Co
00004_ooool4o`0002;ooooo0_l00005ooooo`?o00003?ooool2o`0000Gooooo0_l000000ooooooo
0000o`000009ooooo`;o00001?ooool2o`000003ooooool0003o000000Kooooo0_l00002ooooo`Co
000000Coooooo`000?l0003o00004Oooool2o`0000Cooooo0ol00003ooooo`;o00001?ooool2o`00
00;ooooo0ol000000ooooooo0000o`00000Tooooo`;o0000?Oooool001cooooo0_l0000fooooo`Co
00004_ooool2o`000003ooooool0003o0000027ooooo0_l00002ooooo`?o000000?oooooo`000?l0
00000_l0000;ooooo`Co00000_ooool2o`0000?ooooo1?l00005ooooo`;o00001?ooool2o`0000Wo
oooo1?l00002ooooo`;o000000?oooooo`000?l000006?ooool4o`000003ooooool0003o000000?o
00000_ooool2o`0000;ooooo1_l0000kooooo`;o00009_ooool001cooooo00?o0000ooooooooool0
=_ooool2o`0000;ooooo0_l0000Booooo`;o00009Oooool3o`0000?ooooo0_l00009ooooo`Oo0000
1_ooool4o`0000Kooooo0_l0000@ooooo`;o00003?ooool2o`0001?ooooo0_l000001?oooooo0000
o`000?ooool2o`0000;ooooo0ol00003ooooo`Co0000>oooool2o`0002Kooooo000Looooo`03o`00
0?oooooooooo037ooooo0ol00002ooooo`;o00000_ooool2o`0000kooooo0_l0000Gooooo`;o0000
00?oooooo`000?l000007Oooool8o`0000?ooooo1?l00005ooooo`;o000000Coooooo`000?l0003o
00001_ooool2o`00013ooooo0_l000001?oooooo0000o`000?ooool2o`0000_ooooo0_l0000:oooo
o`;o000000?oooooo`000?l000000_ooool4o`000003ooooool0003o000000;o00000_ooool2o`00
05oooooo000Looooo`03o`000?oooooooooo037ooooo0ol000000ooooooo0000o`00000Cooooo`;o
00005Oooool4o`000003ooooool0003o000000?o00006_ooool6o`0000Gooooo1?l00005ooooo`;o
000000?oooooo`000?l000000_ooool7o`00013ooooo0_l000001?oooooo0000o`000?ooool2o`00
00Sooooo0_l000000ooooooo0000o`00000:ooooo`;o000000?oooooo`000?l000001?ooool3o`00
00Gooooo0ol00004ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0=Oooool2o`0000co
oooo0_l00006ooooo`;o00005?ooool3o`0000;ooooo1_l0000Iooooo`Go000000?oooooo`000?l0
00004?ooool;o`00017ooooo1?l0000:ooooo`;o00005oooool2o`0000Gooooo0_l00005ooooo`;o
0000FOooool001cooooo00?o0000ooooooooool0@?ooool2o`000003ooooool0003o000000Kooooo
0_l0000Fooooo`;o000000?oooooo`000?l000000_ooool5o`0001Gooooo0ol00004ooooo`;o0000
2oooool2o`0000?ooooo2ol0000=ooooo`;o00000_ooool4o`0000;ooooo0_l00007ooooo`;o0000
4oooool2o`0000;ooooo1?l0000jooooo`;o0000:?ooool001cooooo00?o0000ooooooooool0<?oo
ool4o`0000cooooo0_l0000;ooooo`;o00005?ooool2o`0000Kooooo1ol0000Booooo`;o00004_oo
ool2o`0000?ooooo2ol0000=ooooo`Co00001_ooool2o`0000Gooooo1Ol0000=ooooo`;o00000ooo
ool2o`0000;ooooo1?l0000jooooo`;o0000:?ooool001cooooo00?o0000ooooooooool0;oooool5
o`0000cooooo1?l00008ooooo`?o00005?ooool2o`0000Sooooo1ol0000Nooooo`;o00001?ooool2
o`0000?ooooo3?l00009ooooo`;o00000oooool2o`0000gooooo2?l0000:ooooo`;o00000oooool2
o`0000?ooooo0_l0001Uooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00003oooool4o`00
00Sooooo0ol0000Fooooo`;o00002Oooool4o`0001kooooo1?l00002ooooo`?o00000_ooool<o`00
00Wooooo0_l000000ooooooo0000o`000004o`0000gooooo1_l00006ooooo`Go00000_ooool4o`00
00?ooooo0_l0000iooooo`;o0000:_ooool001cooooo00?o0000ooooooooool0IOooool2o`0001?o
oooo0_l0000Booooo`;o00001?ooool2o`0000?ooooo0ol000000ooooooo0000o`000009o`0000_o
oooo1?l00002ooooo`;o00005oooool7o`0000;ooooo0ol00004ooooo`;o0000>Oooool2o`0002[o
oooo000Looooo`03o`000?oooooooooo03Gooooo1Ol00009ooooo`;o00000_ooool2o`00037ooooo
1?l00002ooooo`;o00003?ooool2o`0000[ooooo0_l000000ooooooo0000o`000009o`0000_ooooo
0_l00002ooooo`;o00002oooool2o`0000[ooooo2ol000000ooooooo0000o`00000@ooooo`;o0000
FOooool001cooooo00?o0000ooooooooool0=Oooool5o`0000Wooooo1_l0000booooo`?o00000_oo
ool2o`0001_ooooo2ol00007ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0000_ooooo
0_l0000:ooooo`;o000000?oooooo`000?l000001_l000000ooooooo0000o`000003o`0000gooooo
0_l0000/ooooo`;o0000:oooool001cooooo00?o0000ooooooooool0<Oooool2o`0000?ooooo0_l0
000=ooooo`;o0000;?ooool2o`0000Cooooo0ol00004ooooo`;o00001?ooool3o`0001?ooooo3?l0
0007ooooo`;o000000?oooooo`000?l000000_l0000=ooooo`;o00002?ooool3o`0000;ooooo4Ol0
0008ooooo`;o00006Oooool2o`0001Cooooo0_l0000[ooooo`007?ooool00ol0003oooooooooo`0a
ooooo`;o00000oooool2o`0001Gooooo0_l0000Tooooo`;o00001?ooool3o`0000Wooooo1?l0000?
ooooo`oo00002?ooool2o`0000;ooooo0ol0000;ooooo`Co00001Oooool2o`000003ooooool0003o
000001Co00002?ooool2o`0001Sooooo0ol00011ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^
k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0
=?ooool5o`00013ooooo0_l00002ooooo`?o0000=Oooool4o`0000cooooo0_l000000ooooooo0000
o`00000<o`0000_ooooo1?l0000<ooooo`Co00000_ooool2o`000003ooooool0003o000001?o0000
00Coooooo`000?l0003o00008_ooool2o`0004;ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMg
M`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0d
ooooo`Go00002_ooool2o`0000Cooooo0_l00003ooooo`;o0000=Oooool4o`0000[ooooo1?l00000
0ooooooo0000o`000003ooooo`So00003?ooool3o`0000cooooo0_l00005ooooo`;o00000_ooool2
o`000003ooooool0003o000000oo000000Coooooo`000?l0003ooooo0_l0000dooooo`;o0000;_oo
ool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool0<oooool4o`0000cooooo0_l0000Xooooo`Go00003?oo
ool2o`0000Gooooo0ol00007ooooo`;o00000_ooool5o`0000?ooooo2Ol0000=ooooo`?o00003?oo
ool2o`0000_ooooo6?l0000dooooo`;o0000;_ooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0000cooooo`Co00001?oo
ool2o`0000?ooooo0_l00008ooooo`;o00007oooool7o`0000cooooo0_l00003ooooo`Go00001ooo
ool2o`000003ooooool0003o000000Co00000oooool8o`0000_ooooo1_l0000<ooooo`;o000000?o
ooooo`000?l000000oooool2o`0000;ooooo5ol00006ooooo`;o00006?ooool2o`0004Cooooo0000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<
c006ooooo`03o`000?oooooooooo03?ooooo0_l00006ooooo`;o00000oooool2o`0000Kooooo1?l0
000Oooooo`;o00000_ooool2o`0001;ooooo1?l0000;ooooo`;o00002Oooool2o`000004ooooool0
003o0000o`0000_ooooo1_l00005ooooo`;o00001oooool3o`0000?ooooo0ol000000ooooooo0000
o`00000Bo`0000Wooooo0_l0000Hooooo`;o0000A?ooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo03Oooooo0_l0
0006ooooo`?o00001_ooool4o`0000Gooooo0_l0000Hooooo`;o00004Oooool2o`0000Cooooo0ol0
000Fooooo`;o00000_ooool2o`0000?ooooo0_l00005ooooo`Co00001Oooool2o`000003ooooool0
003o000000Kooooo0ol00004oooooa3o000000?oooooo`000?l000001_l0000eooooo`;o0000<Ooo
ool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`00
0?oooooooooo03Oooooo0_l00003ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Sooooo
1?l0000Wooooo`Go00001?ooool3o`0000Sooooo0_l0000Eooooo`;o00001Oooool4o`0000Gooooo
0_l00009ooooo`;o00001Oooool@o`000003ooooool0003o000000?o000000?oooooo`000?l00000
0ol0000booooo`;o0000<Oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<co
A4A4o`000?l@4106ooooo`03o`000?oooooooooo03Wooooo0_l000000ooooooo0000o`000002o`00
00Kooooo0_l000000ooooooo0000o`000002o`0000?ooooo1?l0000Oooooo`Co00001?ooool3o`00
00Cooooo0_l0000;ooooo`;o00001oooool2o`00013ooooo0_l00002ooooo`?o00001_ooool2o`00
00Kooooo0_l00007oooooaGo000000?oooooo`000?l000001?l00005ooooo`;o0000:_ooool2o`00
03;ooooo000Looooo`03o`000?oooooooooo03Wooooo0_l00003ooooo`;o00002Oooool4o`0002Ko
oooo1?l000001?oooooo0000o`000?ooool2o`0000Gooooo1?l0000<ooooo`;o00001?ooool4o`00
00?ooooo0ol00005ooooo`;o000000Coooooo`000?l0003o00001oooool5o`0000Kooooo0_l00000
0ooooooo0000o`000004oooooaco00001Oooool2o`000003ooooool0003o000002Oooooo0_l0000b
ooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00001_ooool2o`0000?ooooo0_l00002oooo
o`Co0000:_ooool2o`000003ooooool0003o000000Kooooo0ol0000<ooooo`?o00000oooool6o`00
0003ooooool0003o000000;o00001?ooool2o`0000;ooooo0_l00007ooooo`Go00002Oooool2o`00
00Cooooo6ol00009ooooo`;o00004_ooool2o`0004Oooooo000Looooo`03o`000?oooooooooo03Oo
oooo1?l00006ooooo`;o00000_ooool4o`0000?ooooo0_l0000Zooooo`;o00002Oooool3o`0000co
oooo1_l000000ooooooo0000o`000003o`0000?ooooo0_l00009ooooo`;o00002Oooool2o`0000co
oooo1ol000000ooooooo0000o`00000Do`0000Wooooo0_l0000Booooo`;o0000Aoooool001cooooo
00?o0000ooooooooool0=oooool3o`0000Kooooo0_l00003ooooo`Co00000oooool2o`0002Gooooo
2Ol00004ooooo`;o000000Coooooo`000?l0003o00003?ooool6o`000004ooooool0003o0000o`00
00Oooooo0_l00007ooooo`;o00005?ooool2o`000003ooooool0003o000000Go000000?oooooo`00
0?l000001ol00002ooooo`_o00002Oooool2o`0002Cooooo0_l0000eooooo`007?ooool00ol0003o
ooooooooo`0hooooo`;o00001?ooool4o`0000[ooooo0_l0000Uooooo`Go00000_ooool2o`0000Co
oooo0_l000000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l000000_ooool7o`0000;o
oooo0ol00003ooooo`;o000000?oooooo`000?l000007Oooool2o`0000;ooooo0ol00003oooooaGo
00002Oooool2o`0000oooooo0_l0000Eooooo`;o0000=Oooool001cooooo00?o0000ooooooooool0
>?ooool2o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o00001Oooool3o`0000Wooooo
0_l0000Kooooo`;o00001?ooool2o`0000Gooooo0ol00005ooooo`;o000000?oooooo`000?l00000
0_ooool5o`0000;ooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00002_ooool2o`0001;o
oooo1?l00004ooooo`go000000?oooooo`000?l000002?l00009ooooo`?o00003oooool2o`0004co
oooo000Looooo`03o`000?oooooooooo03Sooooo0_l00006ooooo`?o00000_ooool2o`0000Gooooo
1Ol00007ooooo`;o00008Oooool3o`0000Cooooo0ol00006ooooo`;o00000oooool6o`0000;ooooo
1ol0000=ooooo`;o00004_ooool4o`0000?ooooo6?l0000:ooooo`Go00003?ooool2o`0004gooooo
000Looooo`03o`000?oooooooooo043ooooo0_l00005ooooo`;o00001_ooool2o`0000Sooooo0_l0
000Qooooo`;o00003Oooool2o`0000?ooooo1?l00002ooooo`Wo00001?ooool2o`0000Gooooo0_l0
000Eooooo`;o00000oooool3o`0000;ooooo5Ol0000:ooooo`Co00003?ooool2o`0004gooooo000L
ooooo`03o`000?oooooooooo04Oooooo0ol00005ooooo`?o00001oooool2o`0001?ooooo0_l00008
ooooo`;o00004Oooool4o`0000?ooooo0ol000000ooooooo0000o`000003o`000003ooooool0003o
000000Gooooo0_l00005ooooo`;o00002oooool3o`0000cooooo3?l000000ooooooo0000o`00000;
o`0000;ooooo0_l00002ooooo`;o00003_ooool2o`00057ooooo000Looooo`03o`000?oooooooooo
04Sooooo0_l00006ooooo`?o00001?ooool2o`0000;ooooo0_l0000Aooooo`;o00002?ooool2o`00
017ooooo1Ol000000ooooooo0000o`00000=o`0000;ooooo1?l00004ooooo`;o00002oooool3o`00
00Gooooo0_l00002ooooo`Wo00000oooool=o`000003ooooool0003o000000?ooooo0_l00002oooo
o`;o00001?ooool2o`0000Sooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`0oooooo`Co
00003?ooool4o`0000Cooooo0_l00002ooooo`;o00004Oooool3o`0001cooooo5?l000000ooooooo
0000o`000002o`0000?ooooo0ol0000Aooooo`Co00000_ooool5o`0000Wooooo2?l0000Booooo`?o
0000Foooool001cooooo0_l0000looooo`;o00000_ooool4o`0000_ooooo0ol000000ooooooo0000
o`000003o`0001Oooooo0ol0000;ooooo`;o00001oooool2o`0000Gooooo5_l00007ooooo`;o0000
1Oooool2o`0000Sooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l000000ooooooo0000
o`000006ooooo`Go000000?oooooo`000?l000000_ooool2o`00017ooooo0_l0001Looooo`007?oo
ool00ol0003oooooooooo`0kooooo`?o00001?ooool2o`0000[ooooo0_l000000ooooooo0000o`00
0004o`0001cooooo1Ol00004ooooo`;o00001oooool4o`0000?ooooo5_l00005ooooo`Co00001Ooo
ool2o`0000Sooooo0_l00003ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000Kooooo
1?l00002ooooo`;o00000_ooool2o`0000Gooooo0_l00003ooooo`;o000000?oooooo`000?l00000
8oooool3o`0003[ooooo000Looooo`03o`000?oooooooooo03cooooo0ol00003ooooo`;o00002ooo
ool5o`000003ooooool0003o000001cooooo1Ol00003ooooo`;o00002Oooool8o`000003ooooool0
003o0000017o00001Oooool3o`0000kooooo0ol00004ooooo`;o000000Coooooo`000?l0003o0000
3oooool2o`0000Wooooo1?l000001?oooooo0000o`000?ooool2o`0000_ooooo0ol0000Eooooo`?o
0000>_ooool001cooooo00?o0000ooooooooool0??ooool3o`0000cooooo0_l00002ooooo`Oo0000
2Oooool2o`0001?ooooo1_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l00000
0_l000000ooooooo0000o`00000Fo`0000Kooooo0ol0000>ooooo`?o00001?ooool3o`000003oooo
ool0003o000000Cooooo0_l00002ooooo`?o00000_ooool2o`0000gooooo0ol00003ooooo`;o0000
1oooool3o`000004ooooool0003o0000o`0005;ooooo000Looooo`03o`000?oooooooooo03cooooo
0ol00003ooooo`;o00001oooool2o`0000?ooooo0_l00002ooooo`?o00002?ooool2o`0000oooooo
2_l00007ooooo`;o000000?oooooo`000?l000006_l00008ooooo`;o00003?ooool2o`000004oooo
ool0003o0000ooooo`;o000000?oooooo`000?l000001?l00004ooooo`;o00000_ooool7o`0000[o
oooo0_l00002ooooo`;o00000_ooool3o`0000Cooooo1_l0000:ooooo`;o0000B_ooool001cooooo
00?o0000ooooooooool0?Oooool3o`0000;ooooo0_l0000@ooooo`Go00005oooool9o`0000Sooooo
0_l00005oooooa?o000000?oooooo`000?l000001?l00003ooooo`;o00003oooool2o`0000Cooooo
0_l000000ooooooo0000o`000005o`000004ooooool0003o0000o`0000Cooooo1?l0000:ooooo`Co
00001?ooool4o`0000Gooooo0ol0000;ooooo`Co000000?oooooo`000?l00000Aoooool001cooooo
00?o0000ooooooooool0?Oooool3o`0000_ooooo0_l00004ooooo`;o00000_ooool4o`0000?ooooo
0_l00002ooooo`;o00004_ooool2o`000003ooooool0003o000000Sooooo0_l000001?oooooo0000
o`000?l00004oooooaOo00000oooool2o`0000?ooooo0_l0000Cooooo`Co000000Coooooo`000?l0
003ooooo0ol00006ooooo`;o00000oooool2o`0000Gooooo2_l0000Eooooo`;o00000oooool2o`00
04Oooooo000Looooo`03o`000?oooooooooo04_ooooo0ol00003ooooo`;o00000_ooool6o`000005
ooooool0003o0000o`000?ooool00_l0000Booooo`;o000000?oooooo`000?l000000oooool3o`00
00Gooooo0ol00004oooooaSo00001_ooool3o`0000Wooooo0_l00007ooooo`Oo00002_ooool2o`00
00Cooooo0_l00007ooooo`Ko00005?ooool7o`0004[ooooo000Looooo`03o`000?oooooooooo04co
oooo0_l00008ooooo`Go00000_ooool2o`000003ooooool0003o0000017ooooo0ol000000ooooooo
0000o`000006o`0000[ooooo6ol00005ooooo`;o00000oooool2o`0000Gooooo0ol00006ooooo`Co
000000?oooooo`000?l000001?ooool2o`0000Cooooo0_l00008ooooo`;o00000oooool2o`0001;o
oooo1?l00002ooooo`Oo0000B_ooool001cooooo00?o0000ooooooooool0AOooool2o`0000Gooooo
0_l00005ooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo0ol0000<ooooo`;o0000
0_ooool3o`0000?ooooo1?l000000ooooooo0000o`000004ooooo`;o00000ooooolHo`000003oooo
ool0003o000000[ooooo0_l00004ooooo`Ko00001_ooool2o`0000Oooooo0_l0000=ooooo`Go0000
00?oooooo`000?l000004_ooool4o`0000Cooooo0_l0001=ooooo`007?ooool00ol0003ooooooooo
o`13ooooo`Co000000?oooooo`000?l000000_ooool5o`0000;ooooo1Ol00003ooooo`;o00001?oo
ool2o`0000Wooooo0_l000000ooooooo0000o`000002ooooo`Co00001oooool2o`0000Cooooo0ol0
00000ooooooo0000o`00000Go`000003ooooool0003o0000013ooooo0_l000001?oooooo0000o`00
0?l00002ooooo`;o00000_ooool2o`0000Gooooo0_l0000<ooooo`Go000000Coooooo`000?l0003o
oooo1?l0000?ooooo`;o00001oooool2o`0000Sooooo0_l00013ooooo`007?ooool00ol0003ooooo
ooooo`13ooooo`;o00000oooool2o`0000;ooooo1Ol00003ooooo`;o00001?ooool3o`0000oooooo
0_l00005ooooo`Co00003_ooool2o`000003ooooool0003o000001Oo000000?oooooo`000?l00000
2Oooool2o`0000Sooooo0_l00003ooooo`;o000000?oooooo`000?l000001_ooool2o`000003oooo
ool0003o000000Wooooo0ol00006ooooo`Go00003_ooool2o`0000Kooooo0_l00008ooooo`?o0000
@oooool001cooooo00?o0000ooooooooool0@oooool2o`0001Gooooo1Ol0000=ooooo`;o00001Ooo
ool2o`000003ooooool0003o000000Sooooo0_l000000ooooooo0000o`000002o`000003ooooool0
003o000001Wo00002Oooool3o`0000Sooooo0_l00006ooooo`;o000000?oooooo`000?l000001_oo
ool2o`0000?ooooo0_l00004ooooo`;o00001_ooool2o`0000;ooooo0_l0000Aooooo`;o00000ooo
ool2o`0000Sooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`1?ooooo`;o00003?ooool2
o`0000gooooo0_l00002ooooo`;o000000?oooooo`000?l000001Ol00006ooooo`;o000000?ooooo
o`000?l000000ooooolKo`0000Wooooo0ol0000;ooooo`;o000000?oooooo`000?l000000oooool2
o`0000Cooooo0_l00005ooooo`;o00001?ooool2o`0000Kooooo0_l00007ooooo`;o00001_ooool4
o`0000;ooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00002?ooool2o`00
01oooooo0_l00002ooooo`;o00000_ooool2o`0000_ooooo0_l00003oooooaSo00004oooool2o`00
00?ooooo0_l000000ooooooo0000o`000009ooooo`?o00001_ooool2o`0001?ooooo0_l00004oooo
o`Ko00000_ooool2o`0005?ooooo000Looooo`03o`000?oooooooooo04Gooooo1?l00002ooooo`;o
00008_ooool2o`0000;ooooo0_l00007ooooo`;o00000_ooool2o`0000?ooooo0_l00004oooooaSo
00004_ooool3o`00017ooooo0_l00006ooooo`;o00002oooool2o`0000Cooooo0_l00006ooooo`;o
0000Foooool001cooooo0_l00018ooooo`Ko00008_ooool2o`0000;ooooo0_l00007ooooo`;o0000
0_ooool2o`0000?ooooo0_l000000ooooooo0000o`00000Bo`0000;ooooo2Ol0000?ooooo`;o0000
4oooool2o`0000Kooooo0_l00009ooooo`;o00001?ooool3o`0001Sooooo0_l00018ooooo`007?oo
ool00ol0003oooooooooo`18ooooo`?o0000<Oooool2o`0000Oooooo0_l000000ooooooo0000o`00
000Bo`0000;ooooo1?l000000ooooooo0000o`000002o`0002Cooooo0_l00006ooooo`;o00002Ooo
ool2o`0000Gooooo0_l0000Hooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0BOooool2
o`0000Sooooo0_l00002ooooo`;o00003Oooool2o`00027ooooo4_l00003ooooo`?o00000oooool2
o`0000Cooooo0_l0002Mooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00002?ooool2o`00
00;ooooo0_l0000=ooooo`;o00003Oooool2o`000003ooooool0003o000000oooooo4Ol00002oooo
o`Oo00001oooool2o`00057ooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o
00002Oooool2o`0001kooooo0_l000001?oooooo0000o`000?l00009ooooo`?o00000_ooool2o`00
0003ooooool0003o000000_o00000oooool7o`0004cooooo1?l0000:ooooo`;o0000B_ooool001co
oooo00?o0000ooooooooool0B_ooool2o`0000Wooooo0_l00005ooooo`;o00000_ooool2o`0000co
oooo0_l00005ooooo`;o000000Coooooo`000?l0003o00002Oooool3o`0000Kooooo3?l00002oooo
o`Oo0000COooool4o`0000[ooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o
00002_ooool2o`000004ooooool0003o0000o`0000cooooo0_l00006ooooo`Co00001oooool2o`00
00_ooooo4_l000000ooooooo0000o`00002Vooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o
00000oooool2o`0000[ooooo0_l000000ooooooo0000o`000003ooooo`;o00002?ooool2o`0000Ko
oooo0_l00009ooooo`?o00001_ooool2o`000003ooooool0003o000000;o000000Coooooo`000?l0
003ooooo2_l00002ooooo`;o0000EOooool2o`0004oooooo000Looooo`03o`000?oooooooooo04_o
oooo0_l0000?ooooo`;o00001_ooool2o`000003ooooool0003o000000Gooooo0_l00007ooooo`;o
00002?ooool3o`0000Gooooo2_l00004ooooo`;o00000oooool3o`0002_ooooo0_l00004ooooo`Co
00009?ooool2o`0004oooooo000Looooo`03o`000?oooooooooo05oooooo0_l00006ooooo`;o0000
3_ooool2o`0000cooooo0_l00002ooooo`[o000000Coooooo`000?l0003ooooo1Ol00007ooooo`;o
00009Oooool3o`0000?ooooo1_l0001cooooo`007?ooool00ol0003oooooooooo`1Gooooo`;o0000
1_ooool5o`0000[ooooo0_l00009ooooo`;o00000_ooool4o`0000Cooooo0_l00004ooooo`;o0000
0_ooool7o`0000;ooooo1?l00007ooooo`;o00009_ooool2o`0000Oooooo0_l000000ooooooo0000
o`000004o`0006cooooo000Looooo`03o`000?oooooooooo05Gooooo1?l00008ooooo`?o00002_oo
ool2o`0000Wooooo0ol000000ooooooo0000o`000002o`0000Wooooo0_l00003ooooo`Go00001Ooo
ool2o`0000Gooooo0_l00008ooooo`;o0000:oooool6o`000003ooooool0003o000000?ooooo0_l0
001Tooooo`007?ooool00ol0003oooooooooo`1Eooooo`;o00003Oooool2o`0000Wooooo0_l00008
ooooo`Ko00002oooool2o`0000?ooooo0_l0000>ooooo`?o00000_ooool2o`0000Cooooo0_l0000Z
ooooo`;o00000oooool5o`0000?ooooo0_l0000?ooooo`;o0000Doooool001cooooo00?o0000oooo
ooooool0F_ooool2o`0000Sooooo0_l00008ooooo`?o00002_ooool4o`0000Gooooo0_l00005oooo
o`;o00000oooool2o`0000;ooooo0ol00005ooooo`;o000000?oooooo`000?l000000oooool2o`00
033ooooo0_l00003ooooo`Co00000oooool2o`00013ooooo0_l0001Cooooo`007?ooool00ol0003o
ooooooooo`1Dooooo`;o00001?ooool2o`0000[ooooo0ol00005ooooo`;o00002oooool2o`0000Oo
oooo1?l00003ooooo`;o000000?oooooo`000?l000000_l00002ooooo`?o00000_ooool2o`000003
ooooool0003o000000Wooooo0_l0000Mooooo`;o00003Oooool4o`000003ooooool0003o000000?o
00000oooool2o`0000kooooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`1Dooooo`Co0000
3_ooool5o`00017ooooo0_l00008ooooo`;o000000?oooooo`000?l000000oooool3o`0000Sooooo
0ol0000;ooooo`;o00006_ooool2o`000003ooooool0003o000000cooooo1Ol000000ooooooo0000
o`000003o`000003ooooool0003o0000013ooooo0_l0001Eooooo`007?ooool2o`0005Oooooo0_l0
000Aooooo`;o00001oooool2o`0000Sooooo0ol0000:ooooo`;o00003?ooool2o`000003ooooool0
003o000000Sooooo1?l0000Kooooo`;o00003oooool5o`0000?ooooo0ol000000ooooooo0000o`00
001Wooooo`007?ooool00ol0003oooooooooo`1Jooooo`;o00003Oooool2o`0000Oooooo0_l00009
ooooo`;o00001?ooool2o`0001;ooooo1?l00009ooooo`Co00005?ooool2o`0000Sooooo0_l0000=
ooooo`;o000000?oooooo`000?l000000oooool5o`0000gooooo0_l0001Hooooo`007?ooool00ol0
003oooooooooo`1Jooooo`;o00001oooool2o`0000Kooooo1Ol00002ooooo`;o00003oooool2o`00
00Kooooo0_l00006ooooo`;o00001?ooool4o`0001_ooooo0ol000000ooooooo0000o`000008oooo
o`;o00004?ooool2o`0000Cooooo1?l0000=ooooo`;o0000F?ooool001cooooo00?o0000oooooooo
ool0F_ooool2o`0000Oooooo0_l00006ooooo`Go00000_ooool2o`0001Oooooo0_l00006ooooo`;o
00001_ooool2o`0001_ooooo0ol0000;ooooo`;o00001Oooool2o`0000Cooooo0ol0001cooooo`00
7?ooool00ol0003oooooooooo`1Jooooo`;o00004Oooool3o`0001Wooooo0_l000001?oooooo0000
o`000?l0000;ooooo`;o00001Oooool2o`00023ooooo0_l000000ooooooo0000o`000003ooooo`Co
00001?ooool3o`0007?ooooo000Looooo`03o`000?oooooooooo06Kooooo0_l00005ooooo`?o0000
4oooool2o`0000Cooooo0_l000001?oooooo0000o`000?l00005ooooo`;o00001?ooool2o`0000Go
oooo0_l0000Pooooo`;o00001_ooool2o`0000;ooooo1_l0001dooooo`007?ooool00ol0003ooooo
ooooo`1Vooooo`;o00001oooool3o`00017ooooo1?l00004ooooo`;o00001?ooool5o`0000oooooo
0_l0000Tooooo`;o00000_ooool4o`0001?ooooo0ol0001Pooooo`007?ooool00ol0003ooooooooo
o`1_ooooo`?o00004Oooool4o`0000Cooooo0_l00002ooooo`Go00003_ooool2o`000004ooooool0
003o0000ooooo`;o00003Oooool2o`0001;ooooo1?l0000Fooooo`Co0000H?ooool001cooooo00?o
0000ooooooooool0Goooool2o`0002_ooooo0_l000000ooooooo0000o`000006ooooo`;o00002Ooo
ool4o`0000;ooooo0_l0000=ooooo`;o00002Oooool8o`000003ooooool0003o000000;o00005_oo
ool2o`0006;ooooo000Looooo`03o`000?oooooooooo05oooooo0_l00003ooooo`;o00009?ooool4
o`0000Wooooo0_l0000;ooooo`;o00006_ooool:o`0007oooooo000Looooo`03o`000?oooooooooo
06Cooooo0_l00004ooooo`;o00007_ooool2o`0000[ooooo0_l0000Gooooo`;o00003oooool4o`00
0004ooooool0003o0000ooooo`;o00001_ooool2o`0007Oooooo000Looooo`03o`000?oooooooooo
06Sooooo1?l0000Nooooo`;o00002Oooool3o`0000Cooooo0_l00008ooooo`;o00001oooool2o`00
00[ooooo0_l00002ooooo`Go000000Coooooo`000?l0003ooooo0_l00003ooooo`;o000000?ooooo
o`000?l00000Moooool001cooooo00?o0000ooooooooool0J?ooool2o`0002_ooooo1?l00002oooo
o`?o00002?ooool2o`0001?ooooo0ol000000ooooooo0000o`000002ooooo`Co000000?oooooo`00
0?l000000oooool2o`0007[ooooo000Looooo`03o`000?oooooooooo06Wooooo1?l0000Rooooo`;o
000000?oooooo`000?l000000_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l0
00001oooool2o`0001;ooooo0ol00004ooooo`Go0000P_ooool00006ooooooo^k^ko<S8bo`000?lb
<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooo
oooo06Wooooo1?l000000ooooooo0000o`00000Oooooo`;o000000?oooooo`000?l000000_l00002
ooooo`;o00001?ooool2o`000003ooooool0003o000000Cooooo0_l0000=ooooo`Co000000?ooooo
o`000?l000000_ooool2o`000003ooooool0003o000001Cooooo0ol0001^ooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo
00?o0000ooooooooool0K_ooool2o`0001gooooo0_l00007ooooo`Co00000oooool2o`0000;ooooo
1?l00008ooooo`Co000000?oooooo`000?l000000_ooool4o`0000Gooooo0_l0000Gooooo`?o0000
K_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool0K_ooool3o`0001cooooo0_l00007ooooo`?o0000
1?ooool2o`0000Cooooo0ol00003ooooo`So000000?oooooo`000?l000002Oooool2o`0008[ooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RH
oc8b<P06ooooo`?o0000Koooool2o`0002Wooooo0_l00008ooooo`Co000000?oooooo`000?l00000
0ol00009ooooo`;o00001?ooool2o`0001Cooooo0_l0001dooooo`0000?oooooo`000?ooool00_oo
ool00ol0003oooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003ooooo
ooooo`1`ooooo`;o0000:?ooool3o`0000Oooooo1?l00004ooooo`;o00000oooool2o`0000;ooooo
1?l00004ooooo`;o00005?ooool2o`0007Cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oo
oooooooo00Wooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo073ooooo
0_l000000ooooooo0000o`00000Pooooo`;o00001?ooool2o`0000oooooo0_l00003ooooo`;o0000
0_ooool3o`0001Cooooo1?l0001iooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05
o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`1cooooo`;o00008?ooool2o`00
03Gooooo1?l0001iooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o
0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`2Uooooo`;o00007oooool2o`00087ooooo000L
ooooo`03o`000?oooooooooo0:Gooooo1?l00003ooooo`;o00003Oooool2o`0000?ooooo0ol00003
ooooo`;o0000POooool001cooooo00?o0000ooooooooool0N?ooool2o`0002gooooo0_l00003oooo
o`;o00002?ooool3o`0000;ooooo0_l000000ooooooo0000o`000003o`0008Kooooo000Looooo`03
o`000?oooooooooo07Sooooo0_l0000looooo`?o00001Oooool2o`0008Wooooo000Looooo`03o`00
0?oooooooooo07_ooooo0_l0003<ooooo`007?ooool00ol0003oooooooooo`1iooooo`Ko0000b_oo
ool001cooooo00?o0000ooooooooool0NOooool3o`000003ooooool0003o00000<[ooooo000Loooo
o`03o`000?oooooooooo07gooooo0_l0003:ooooo`007?ooool00ol0003oooooooooo`1mooooo`;o
00003Oooool4o`000;Wooooo000Looooo`03o`000?oooooooooo07gooooo0_l0000=ooooo`Co0000
^Oooool001cooooo00?o0000ooooooooool0Poooool5o`0000?ooooo1Ol00003ooooo`;o0000@ooo
ool2o`0006oooooo000Looooo`03o`000?oooooooooo08?ooooo1Ol00003ooooo`;o00001Oooool3
o`000003ooooool0003o0000043ooooo0_l0001_ooooo`007?ooool2o`0008Kooooo0_l00003oooo
o`;o00001_ooool2o`0000;ooooo0_l0002aooooo`007?ooool00ol0003oooooooooo`2:ooooo`;o
00003oooool3o`0002kooooo1?l0001iooooo`007?ooool00ol0003oooooooooo`2Kooooo`?o0000
1Oooool2o`0001gooooo0_l00007ooooo`Go0000NOooool001cooooo00?o0000ooooooooool0Xooo
ool4o`0000;ooooo0_l0000Dooooo`Go00001oooool2o`0007cooooo000Looooo`03o`000?oooooo
oooo0:Gooooo0_l00002ooooo`?o00004oooool3o`0008Oooooo000Looooo`03o`000?oooooooooo
0:[ooooo0_l000001?oooooo0000o`000?l0002Iooooo`007?ooool00ol0003oooooooooo`2]oooo
o`?o0000VOooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Booooo`Co000000?o410@oooo
ooooool00oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`?o0000
oooooom:ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooo
oooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003o
ooooooooo`3ooooooe;ooooo000Booooo`03oeEEEOmVIVKo00000?ooooooE?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00:Gooooo00Co410@o`000?l0003ooooo0_l000000ol@
413oooooooooo`0Eooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?l@
413oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP2@ooooo`00Y_ooool01Ol0003ooooooooo
oooooooo000000Wooooo1_l00009ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmEEEGo
MgMgoooooonHV9So8B4Q00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`2@ooooo`00Y_ooool01Ol0
003ooooooooooooooooo000001cooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool@41000oooool00ol@413oooooooooo`2>ooooo`00Y_ooool01Ol0003ooooooooo
oooooooo000000Wooooo1_l0000<ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@03ooooo`05o`000?ooooooooooooooool00000T?ooool00:Kooooo00Go0000ohN7Qooo
ooooZJVYo`00000Jooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000oeEEEOl0003o410@olc<c003
ooooo`05o`000?ooooooooooooooool00000T?ooool00:Gooooo00?o410@o`000?mgMgL00_l00000
0onHV9Soooooooooo`0Iooooo`03okZj^_lQ8B7ooooo00;ooooo00?oEEEEohN7Qoooool01Oooool0
1Ol@413ooooooooooooooooo410@093ooooo0033ooooo`05oa0@4?nHV9SooooookZj^_l000000ooo
ool00ooMgMgo410@oiRHV005ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0T?ooool00<?ooooo00Go
ZJVYoa0@4?l0003o410@ojVYZ@04ooooo`04olc<c?m4A4Co0000oa0@40?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP2@ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(366) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.44009 .63712 Mdot
.4425 .67992 Mdot
.66605 .48406 Mdot
.40377 .46893 Mdot
.65311 .27377 Mdot
.68038 .47049 Mdot
.64742 .62369 Mdot
.64828 .62084 Mdot
.667 .45159 Mdot
.21546 .59376 Mdot
.66848 .65175 Mdot
.42968 .46451 Mdot
.6536 .63666 Mdot
.39391 .44665 Mdot
.48954 .46194 Mdot
.34939 .39051 Mdot
.40428 .67438 Mdot
.63241 .34026 Mdot
.36147 .38762 Mdot
.70824 .48371 Mdot
.26471 .39408 Mdot
.38715 .4562 Mdot
.47277 .66706 Mdot
.3937 .45006 Mdot
.35089 .44708 Mdot
.45651 .66635 Mdot
.45044 .63717 Mdot
.35636 .45053 Mdot
.41846 .41034 Mdot
.66807 .64559 Mdot
.57721 .4901 Mdot
.24432 .3283 Mdot
.33996 .45675 Mdot
.32886 .56596 Mdot
.67292 .61975 Mdot
.70328 .67715 Mdot
.71418 .45294 Mdot
.61686 .63269 Mdot
.68189 .62687 Mdot
.67942 .64405 Mdot
.67528 .65 Mdot
.45877 .66216 Mdot
.62005 .65792 Mdot
.73726 .60174 Mdot
.40675 .45017 Mdot
.41433 .5715 Mdot
.70958 .5878 Mdot
.36451 .4041 Mdot
.42393 .69117 Mdot
.68524 .49173 Mdot
.51798 .27113 Mdot
.6234 .6331 Mdot
.49715 .60161 Mdot
.84577 .64953 Mdot
.66163 .63 Mdot
.35571 .39878 Mdot
.68654 .43292 Mdot
.38277 .42233 Mdot
.39023 .47951 Mdot
.29822 .53181 Mdot
.36955 .4327 Mdot
.64438 .30852 Mdot
.44691 .62104 Mdot
.73071 .45014 Mdot
.6646 .45356 Mdot
.61653 .63771 Mdot
.4445 .71261 Mdot
.65708 .647 Mdot
.42556 .42814 Mdot
.68289 .48876 Mdot
.4024 .40223 Mdot
.66572 .65286 Mdot
.46688 .65006 Mdot
.40341 .46322 Mdot
.58955 .78756 Mdot
.69391 .59179 Mdot
.73439 .48474 Mdot
.27834 .46124 Mdot
.58494 .26426 Mdot
.54458 .45243 Mdot
.3984 .46295 Mdot
.83463 .49488 Mdot
.50567 .41558 Mdot
.42405 .68287 Mdot
.48986 .60889 Mdot
.56692 .68301 Mdot
.35453 .41787 Mdot
.57376 .49916 Mdot
.34094 .38534 Mdot
.66202 .35384 Mdot
.68103 .4394 Mdot
.41737 .67168 Mdot
.40477 .45739 Mdot
.42411 .44581 Mdot
.28249 .69141 Mdot
.41322 .39998 Mdot
.38466 .47905 Mdot
.54118 .61453 Mdot
.65192 .66343 Mdot
.45199 .41412 Mdot
.58979 .35947 Mdot
.50647 .568 Mdot
.35587 .40067 Mdot
.69304 .44699 Mdot
.45639 .62025 Mdot
.33503 .4408 Mdot
.6439 .64299 Mdot
.39742 .45939 Mdot
.64622 .6734 Mdot
.43059 .69721 Mdot
.40043 .48272 Mdot
.64172 .28982 Mdot
.28639 .43758 Mdot
.46874 .66291 Mdot
.34178 .66268 Mdot
.37011 .44632 Mdot
.38609 .41538 Mdot
.44491 .68118 Mdot
.70506 .48004 Mdot
.80594 .49405 Mdot
.46566 .65261 Mdot
.67915 .64609 Mdot
.40739 .6784 Mdot
.30867 .46193 Mdot
.71096 .47684 Mdot
.51559 .5741 Mdot
.51824 .57427 Mdot
.43017 .27425 Mdot
.39549 .46986 Mdot
.29524 .35091 Mdot
.68738 .45634 Mdot
.46121 .67356 Mdot
.66271 .6415 Mdot
.39378 .38074 Mdot
.44662 .65362 Mdot
.64225 .62301 Mdot
.6234 .2811 Mdot
.64678 .33319 Mdot
.45847 .68693 Mdot
.34859 .69514 Mdot
.59878 .64193 Mdot
.66258 .66605 Mdot
.51533 .27279 Mdot
.42433 .68352 Mdot
.62803 .30509 Mdot
.63393 .63611 Mdot
.4686 .18345 Mdot
.37895 .4814 Mdot
.49161 .28275 Mdot
.83071 .52167 Mdot
.51843 .27146 Mdot
.23932 .41666 Mdot
.63508 .29168 Mdot
.64088 .62322 Mdot
.38674 .39869 Mdot
.43408 .66721 Mdot
.45018 .65546 Mdot
.41358 .41411 Mdot
.34935 .45748 Mdot
.39795 .4356 Mdot
.34002 .45224 Mdot
.57579 .57507 Mdot
.40335 .45666 Mdot
.4537 .80212 Mdot
.43339 .6599 Mdot
.34399 .44491 Mdot
.70871 .4641 Mdot
.4528 .38786 Mdot
.6172 .65193 Mdot
.39754 .47571 Mdot
.35207 .45747 Mdot
.43276 .41841 Mdot
.68072 .64469 Mdot
.58483 .79891 Mdot
.61462 .23468 Mdot
.66437 .60184 Mdot
.7162 .69753 Mdot
.6955 .46379 Mdot
.3664 .42532 Mdot
.61755 .30853 Mdot
.43799 .38216 Mdot
.41685 .45112 Mdot
.52412 .26817 Mdot
.37394 .47065 Mdot
.2432 .4069 Mdot
.33063 .47134 Mdot
.57224 .67154 Mdot
.43732 .78273 Mdot
.41043 .46601 Mdot
.22995 .57701 Mdot
.49941 .29118 Mdot
.64085 .51748 Mdot
.66579 .64 Mdot
.68538 .48245 Mdot
.69605 .48387 Mdot
.62539 .61607 Mdot
.36716 .60826 Mdot
.20845 .56688 Mdot
.42469 .41277 Mdot
.50443 .57142 Mdot
.41007 .69496 Mdot
.63626 .29337 Mdot
.45617 .68667 Mdot
.83415 .47061 Mdot
.56096 .43871 Mdot
.55224 .49397 Mdot
.59727 .3316 Mdot
.69243 .49382 Mdot
.50689 .57548 Mdot
.62376 .31 Mdot
.40243 .4282 Mdot
.43021 .69619 Mdot
.50283 .2867 Mdot
.42488 .37351 Mdot
.18175 .63397 Mdot
.45087 .63901 Mdot
.39812 .29588 Mdot
.65936 .63177 Mdot
.67654 .42383 Mdot
.35393 .41912 Mdot
.38069 .43837 Mdot
.44283 .70061 Mdot
.38146 .40113 Mdot
.53059 .48281 Mdot
.35804 .46332 Mdot
.72836 .44603 Mdot
.64741 .24534 Mdot
.62158 .61363 Mdot
.59653 .30786 Mdot
.46941 .65525 Mdot
.6115 .82231 Mdot
.70413 .44819 Mdot
.46217 .44838 Mdot
.65609 .65442 Mdot
.62816 .27668 Mdot
.69864 .44141 Mdot
.65079 .31833 Mdot
.40754 .47625 Mdot
.71151 .44527 Mdot
.6459 .30278 Mdot
.5328 .51558 Mdot
.33903 .44882 Mdot
.40618 .25063 Mdot
.62794 .63536 Mdot
.41296 .66945 Mdot
.41647 .43304 Mdot
.49168 .60203 Mdot
.43453 .47597 Mdot
.45022 .30751 Mdot
.50248 .59487 Mdot
.50366 .56446 Mdot
.52949 .43212 Mdot
.60939 .31197 Mdot
.68469 .72688 Mdot
.56732 .51345 Mdot
.4041 .6738 Mdot
.42082 .4528 Mdot
.65611 .70889 Mdot
.63004 .63006 Mdot
.39641 .42409 Mdot
.6257 .70588 Mdot
.63392 .63406 Mdot
.38871 .41691 Mdot
.67651 .64091 Mdot
.4408 .65844 Mdot
.51754 .47077 Mdot
.41472 .6519 Mdot
.41254 .44355 Mdot
.6747 .64455 Mdot
.69099 .48235 Mdot
.45586 .66554 Mdot
.39363 .45965 Mdot
.38089 .46728 Mdot
.49699 .57595 Mdot
.36713 .47354 Mdot
.55483 .62943 Mdot
.36042 .40725 Mdot
.66558 .48745 Mdot
.41557 .40358 Mdot
.55685 .33327 Mdot
.67271 .3266 Mdot
.44296 .69685 Mdot
.50132 .59501 Mdot
.69338 .43524 Mdot
.51924 .50068 Mdot
.37233 .28111 Mdot
.40135 .45326 Mdot
.49756 .59216 Mdot
.42638 .28924 Mdot
.62048 .65469 Mdot
.32599 .39626 Mdot
.74283 .42107 Mdot
.6829 .44047 Mdot
.5065 .57244 Mdot
.43646 .38684 Mdot
.4475 .71974 Mdot
.37293 .38692 Mdot
.7109 .44878 Mdot
.41548 .65338 Mdot
.39836 .39302 Mdot
.69092 .58077 Mdot
.489 .60301 Mdot
.65328 .66512 Mdot
.54233 .60904 Mdot
.38017 .41126 Mdot
.67846 .48559 Mdot
.45738 .65449 Mdot
.66146 .6247 Mdot
.46858 .65994 Mdot
.51647 .29144 Mdot
.42412 .30033 Mdot
.47029 .58492 Mdot
.6045 .32055 Mdot
.41817 .17436 Mdot
.66407 .60111 Mdot
.44755 .39987 Mdot
.70137 .41052 Mdot
.41786 .75914 Mdot
.69152 .4438 Mdot
.35509 .70644 Mdot
.68256 .43628 Mdot
.37029 .39186 Mdot
.67323 .46778 Mdot
.28142 .70107 Mdot
.3639 .45829 Mdot
.66197 .45743 Mdot
.58906 .55307 Mdot
.3682 .46168 Mdot
.44612 .65255 Mdot
.20384 .39168 Mdot
.35746 .5838 Mdot
.36065 .59545 Mdot
.68926 .43036 Mdot
.36135 .72292 Mdot
.35451 .44386 Mdot
.37976 .37911 Mdot
.43875 .66791 Mdot
.43057 .47988 Mdot
.61342 .32644 Mdot
.63876 .33447 Mdot
.49359 .22175 Mdot
.27932 .31643 Mdot
.3567 .62275 Mdot
.45166 .66009 Mdot
.62932 .24156 Mdot
.5781 .79064 Mdot
.48962 .60306 Mdot
.64699 .62086 Mdot
.62873 .77868 Mdot
.36988 .37604 Mdot
.49619 .67693 Mdot
.52821 .48137 Mdot
.42044 .6534 Mdot
.482 .55426 Mdot
.65895 .6227 Mdot
.35804 .5949 Mdot
.20161 .5344 Mdot
.3989 .43444 Mdot
.62419 .64769 Mdot
.41712 .48678 Mdot
.56996 .50311 Mdot
.41088 .26778 Mdot
.73706 .52383 Mdot
.41148 .44326 Mdot
.63634 .76224 Mdot
.41719 .44358 Mdot
.44314 .2725 Mdot
.40148 .42478 Mdot
.45163 .6496 Mdot
.42862 .40478 Mdot
.56265 .51946 Mdot
.47966 .14727 Mdot
.55825 .42798 Mdot
.64295 .32575 Mdot
.39083 .44623 Mdot
.38919 .4312 Mdot
.64544 .31168 Mdot
.41828 .66111 Mdot
.41969 .43561 Mdot
.71846 .72189 Mdot
.40252 .45974 Mdot
.62268 .62955 Mdot
.48936 .33603 Mdot
.27084 .30669 Mdot
.35769 .42788 Mdot
.44722 .71941 Mdot
.66049 .66589 Mdot
.64424 .65258 Mdot
.32152 .3892 Mdot
.62663 .63436 Mdot
.38689 .39966 Mdot
.49005 .33644 Mdot
.45816 .70011 Mdot
.32914 .38275 Mdot
.42526 .65082 Mdot
.6793 .23376 Mdot
.6347 .62819 Mdot
.49168 .59753 Mdot
.35772 .63487 Mdot
.64303 .63483 Mdot
.65686 .25139 Mdot
.42489 .39892 Mdot
.3937 .35889 Mdot
.40367 .70522 Mdot
.67725 .48381 Mdot
.50564 .58463 Mdot
.66174 .62834 Mdot
.40442 .45155 Mdot
.34281 .42396 Mdot
.62433 .63812 Mdot
.24598 .47859 Mdot
.57804 .49 Mdot
.41332 .44591 Mdot
.43539 .65235 Mdot
.46178 .67062 Mdot
.33265 .39997 Mdot
.41781 .44068 Mdot
.68341 .47651 Mdot
.49813 .59236 Mdot
.50336 .5915 Mdot
.51589 .56847 Mdot
.68522 .4263 Mdot
.42437 .17152 Mdot
.65943 .66725 Mdot
.25159 .32142 Mdot
.57923 .75754 Mdot
.30427 .41653 Mdot
.70964 .47187 Mdot
.37528 .4388 Mdot
.35238 .40862 Mdot
.67387 .64149 Mdot
.38794 .21297 Mdot
.38623 .37871 Mdot
.42455 .64472 Mdot
.62212 .63827 Mdot
.42348 .48259 Mdot
.59395 .61911 Mdot
.63082 .2847 Mdot
.34813 .63791 Mdot
.62646 .63086 Mdot
.45744 .69615 Mdot
.62623 .63092 Mdot
.39192 .43229 Mdot
.4389 .39001 Mdot
.42357 .65018 Mdot
.65762 .29289 Mdot
.41833 .42251 Mdot
.39469 .41656 Mdot
.65585 .3918 Mdot
.59281 .78525 Mdot
.64021 .26016 Mdot
.3692 .39627 Mdot
.3966 .35789 Mdot
.65691 .2979 Mdot
.40346 .4111 Mdot
.40907 .40055 Mdot
.2931 .3523 Mdot
.62066 .66309 Mdot
.63354 .26975 Mdot
.45765 .15713 Mdot
.44852 .63838 Mdot
.55872 .62372 Mdot
.51082 .56939 Mdot
.67545 .60698 Mdot
.51513 .48483 Mdot
.49973 .58039 Mdot
.59941 .73826 Mdot
.49472 .86073 Mdot
.50341 .58507 Mdot
.70656 .42747 Mdot
.30473 .69695 Mdot
.41199 .40403 Mdot
.41388 .43736 Mdot
.61142 .32026 Mdot
.43836 .6863 Mdot
.45812 .79482 Mdot
.66839 .60344 Mdot
.37694 .45205 Mdot
.46221 .63849 Mdot
.5709 .68039 Mdot
.50126 .5753 Mdot
.61902 .29964 Mdot
.65143 .27925 Mdot
.41517 .43309 Mdot
.39899 .28529 Mdot
.45575 .66191 Mdot
.39363 .45955 Mdot
.38509 .41382 Mdot
.71799 .44427 Mdot
.43172 .69571 Mdot
.70829 .46014 Mdot
.48571 .59363 Mdot
.32515 .74486 Mdot
.75274 .67846 Mdot
.62925 .63854 Mdot
.46323 .53556 Mdot
.62296 .61296 Mdot
.68129 .55535 Mdot
.49909 .59232 Mdot
.39109 .4582 Mdot
.4726 .6814 Mdot
.39596 .46009 Mdot
.40344 .45896 Mdot
.40872 .44428 Mdot
.3553 .62458 Mdot
.58309 .27072 Mdot
.61573 .31549 Mdot
.37694 .40773 Mdot
.70045 .4289 Mdot
.5792 .66603 Mdot
.22591 .63342 Mdot
.38646 .44202 Mdot
.38731 .41516 Mdot
.43992 .71834 Mdot
.38625 .48475 Mdot
.64044 .63016 Mdot
.41814 .65487 Mdot
.3478 .41058 Mdot
.59661 .36025 Mdot
.4175 .42939 Mdot
.45618 .55811 Mdot
.64541 .61513 Mdot
.44602 .42339 Mdot
.35578 .48078 Mdot
.49838 .59354 Mdot
.50539 .58346 Mdot
.50207 .56055 Mdot
.61951 .63324 Mdot
.7149 .44107 Mdot
.73205 .47906 Mdot
.37556 .49062 Mdot
.37713 .39765 Mdot
.41771 .37079 Mdot
.6463 .46855 Mdot
.58348 .51527 Mdot
.35325 .68293 Mdot
.40914 .48787 Mdot
.66618 .43329 Mdot
.54187 .61377 Mdot
.2649 .43168 Mdot
.41511 .6641 Mdot
.68101 .4065 Mdot
.64849 .65041 Mdot
.64867 .29557 Mdot
.47996 .24581 Mdot
.46036 .64883 Mdot
.46762 .69557 Mdot
.68939 .4723 Mdot
.49368 .34774 Mdot
.87871 .60159 Mdot
.68532 .45211 Mdot
.54509 .49254 Mdot
.44364 .66486 Mdot
.33966 .45515 Mdot
.44362 .29245 Mdot
.48774 .35482 Mdot
.66279 .44541 Mdot
.38249 .46781 Mdot
.70337 .28279 Mdot
.68234 .47639 Mdot
.41221 .36443 Mdot
.69056 .42981 Mdot
.63956 .66384 Mdot
.6923 .45328 Mdot
.45316 .63246 Mdot
.39422 .46898 Mdot
.85651 .63449 Mdot
.51024 .44072 Mdot
.38181 .46166 Mdot
.62668 .62737 Mdot
.66484 .54482 Mdot
.39725 .42947 Mdot
.62293 .33449 Mdot
.70867 .43035 Mdot
.70258 .54216 Mdot
.38694 .39081 Mdot
.67243 .46941 Mdot
.47043 .69734 Mdot
.66516 .40914 Mdot
.59524 .36383 Mdot
.50579 .5874 Mdot
.43613 .66122 Mdot
.7032 .62463 Mdot
.67674 .6501 Mdot
.3418 .40832 Mdot
.37668 .41807 Mdot
.42927 .66041 Mdot
.52061 .51222 Mdot
.31683 .41197 Mdot
.4 .46099 Mdot
.69993 .46813 Mdot
.71985 .48023 Mdot
.48988 .45438 Mdot
.70554 .44749 Mdot
.39182 .35718 Mdot
.43657 .65472 Mdot
.37044 .38746 Mdot
.46541 .66128 Mdot
.42139 .45008 Mdot
.59586 .60449 Mdot
.41548 .67839 Mdot
.45702 .46163 Mdot
.39024 .47245 Mdot
.37608 .68627 Mdot
.37531 .4133 Mdot
.41113 .45201 Mdot
.72519 .46709 Mdot
.63812 .3151 Mdot
.32415 .40446 Mdot
.67337 .57455 Mdot
.65003 .28512 Mdot
.24778 .45414 Mdot
.71145 .476 Mdot
.64225 .27175 Mdot
.46783 .22527 Mdot
.50285 .59379 Mdot
.63805 .32158 Mdot
.51898 .58806 Mdot
.62809 .64269 Mdot
.4768 .62627 Mdot
.37356 .46656 Mdot
.32054 .73923 Mdot
.57863 .49174 Mdot
.4939 .58248 Mdot
.40889 .41981 Mdot
.37675 .43423 Mdot
.46293 .63915 Mdot
.83376 .47725 Mdot
.72465 .48071 Mdot
.35614 .46754 Mdot
.46131 .64725 Mdot
.8331 .50646 Mdot
.6611 .45399 Mdot
.61441 .29935 Mdot
.68078 .62021 Mdot
.39865 .66824 Mdot
.49002 .59885 Mdot
.63634 .62647 Mdot
.73851 .47505 Mdot
.52797 .2664 Mdot
.37763 .38698 Mdot
.70988 .46724 Mdot
.51957 .271 Mdot
.32114 .40075 Mdot
.6198 .6199 Mdot
.70702 .61281 Mdot
.42144 .67899 Mdot
.62396 .63813 Mdot
.61987 .32874 Mdot
.40688 .68443 Mdot
.42224 .65295 Mdot
.63842 .63444 Mdot
.4142 .77971 Mdot
.42775 .29002 Mdot
.65234 .60943 Mdot
.45715 .31115 Mdot
.52082 .27193 Mdot
.49025 .5902 Mdot
.61998 .30003 Mdot
.64205 .2411 Mdot
.45852 .66359 Mdot
.62295 .78168 Mdot
.51866 .27021 Mdot
.38354 .47915 Mdot
.64693 .30284 Mdot
.57337 .65591 Mdot
.68798 .68418 Mdot
.63763 .62848 Mdot
.6541 .39824 Mdot
.64939 .30279 Mdot
.40745 .47318 Mdot
.30987 .24833 Mdot
.35938 .44433 Mdot
.63279 .63744 Mdot
.52922 .48194 Mdot
.44191 .69381 Mdot
.61904 .65469 Mdot
.53051 .48217 Mdot
.35978 .40088 Mdot
.36851 .44774 Mdot
.58164 .28954 Mdot
.42264 .6933 Mdot
.4871 .59258 Mdot
.39089 .46625 Mdot
.38685 .41933 Mdot
.3373 .41134 Mdot
.32752 .27519 Mdot
.33383 .5029 Mdot
.33402 .42649 Mdot
.66201 .43194 Mdot
.43686 .3832 Mdot
.36384 .47468 Mdot
.44433 .72219 Mdot
.5801 .34568 Mdot
.48625 .58819 Mdot
.41199 .43241 Mdot
.41305 .44337 Mdot
.68134 .62764 Mdot
.42859 .28963 Mdot
.48981 .35843 Mdot
.6766 .49272 Mdot
.68442 .50605 Mdot
.42955 .44633 Mdot
.42876 .66759 Mdot
.60909 .29908 Mdot
.34697 .36547 Mdot
.42925 .6427 Mdot
.42666 .44932 Mdot
.71253 .43362 Mdot
.50036 .58788 Mdot
.35275 .35985 Mdot
.64179 .30457 Mdot
.60005 .64361 Mdot
.25407 .45066 Mdot
.69553 .47942 Mdot
.35042 .43479 Mdot
.71985 .49782 Mdot
.67395 .45542 Mdot
.49592 .57636 Mdot
.45373 .43574 Mdot
.44486 .65777 Mdot
.45875 .69373 Mdot
.55824 .3052 Mdot
.68997 .42585 Mdot
.63067 .45052 Mdot
.6303 .65659 Mdot
.38041 .40777 Mdot
.60981 .67635 Mdot
.45475 .69397 Mdot
.42961 .27352 Mdot
.64791 .27393 Mdot
.63632 .63123 Mdot
.51171 .59632 Mdot
.41352 .6728 Mdot
.46031 .6894 Mdot
.40537 .45508 Mdot
.3846 .44995 Mdot
.65966 .52959 Mdot
.4942 .2879 Mdot
.67639 .63628 Mdot
.62263 .28755 Mdot
.67299 .48905 Mdot
.37995 .3924 Mdot
.42637 .68235 Mdot
.27846 .29288 Mdot
.37855 .41212 Mdot
.69974 .42893 Mdot
.444 .67776 Mdot
.613 .31065 Mdot
.61925 .32608 Mdot
.405 .46632 Mdot
.24627 .40469 Mdot
.64391 .63838 Mdot
.44756 .6514 Mdot
.39738 .65363 Mdot
.3736 .4065 Mdot
.38724 .44605 Mdot
.32104 .47267 Mdot
.61121 .63742 Mdot
.32841 .45067 Mdot
.65488 .30922 Mdot
.4644 .67611 Mdot
.38955 .46424 Mdot
.64443 .31016 Mdot
.49479 .68172 Mdot
.49804 .58426 Mdot
.66597 .46603 Mdot
.62756 .33585 Mdot
.63179 .30967 Mdot
.64508 .27892 Mdot
.63062 .77704 Mdot
.49028 .63081 Mdot
.58134 .20824 Mdot
.38679 .46993 Mdot
.52139 .27229 Mdot
.33735 .398 Mdot
.62343 .65513 Mdot
.67377 .48062 Mdot
.40484 .44438 Mdot
.38592 .47 Mdot
.26017 .44989 Mdot
.35407 .38985 Mdot
.36614 .38355 Mdot
.44546 .69383 Mdot
.39379 .6584 Mdot
.68831 .48488 Mdot
.83031 .53849 Mdot
.21088 .33098 Mdot
.42753 .41767 Mdot
.49286 .34565 Mdot
.41556 .6679 Mdot
.68155 .62409 Mdot
.45533 .30576 Mdot
.64458 .69271 Mdot
.45272 .68111 Mdot
.3731 .3911 Mdot
.26807 .46828 Mdot
.65059 .29369 Mdot
.39542 .43489 Mdot
.66229 .64566 Mdot
.39665 .43511 Mdot
.61818 .63715 Mdot
.36261 .71023 Mdot
.49794 .37493 Mdot
.37259 .4684 Mdot
.41325 .40034 Mdot
.28727 .36984 Mdot
.3853 .44486 Mdot
.74913 .50925 Mdot
.44179 .67459 Mdot
.45975 .44853 Mdot
.35582 .39709 Mdot
.34819 .58094 Mdot
.39738 .41159 Mdot
.50315 .50407 Mdot
.36631 .43206 Mdot
.40745 .20598 Mdot
.39854 .479 Mdot
.3656 .4276 Mdot
.66754 .62505 Mdot
.68105 .63757 Mdot
.39043 .72275 Mdot
.49105 .57758 Mdot
.57209 .66708 Mdot
.39304 .41528 Mdot
.69473 .49467 Mdot
.40328 .33354 Mdot
.63483 .31316 Mdot
.46308 .67629 Mdot
.61794 .86665 Mdot
.64928 .66819 Mdot
.69967 .42553 Mdot
.56457 .49559 Mdot
.67107 .42123 Mdot
.70157 .41173 Mdot
.39532 .69952 Mdot
.62173 .29704 Mdot
.41836 .43436 Mdot
.33639 .56551 Mdot
.6109 .7747 Mdot
.3727 .40571 Mdot
.67635 .49934 Mdot
.36201 .32613 Mdot
.55395 .29438 Mdot
.62123 .33972 Mdot
.62827 .2968 Mdot
.65852 .62555 Mdot
.67225 .486 Mdot
.4077 .48939 Mdot
.64206 .27138 Mdot
.68163 .48163 Mdot
.51433 .5921 Mdot
.57643 .3233 Mdot
.45562 .65966 Mdot
.35941 .71887 Mdot
.41172 .58068 Mdot
.66194 .6647 Mdot
.68109 .58148 Mdot
.48142 .6465 Mdot
.40663 .66408 Mdot
.49883 .56836 Mdot
.66659 .43547 Mdot
.47704 .62916 Mdot
.39747 .46694 Mdot
.42502 .37342 Mdot
.41594 .43478 Mdot
.61031 .31477 Mdot
.4029 .41436 Mdot
.67709 .47658 Mdot
.6647 .6195 Mdot
.68526 .43801 Mdot
.64918 .62306 Mdot
.22187 .3606 Mdot
.40167 .47332 Mdot
.38896 .44854 Mdot
.49014 .33801 Mdot
.45974 .68799 Mdot
.32368 .56995 Mdot
.69708 .42851 Mdot
.68795 .43338 Mdot
.36256 .39317 Mdot
.41301 .69384 Mdot
.64098 .25675 Mdot
.47066 .31669 Mdot
.36849 .4289 Mdot
.44 .67554 Mdot
.36446 .3913 Mdot
.62508 .57152 Mdot
.50275 .42867 Mdot
.47117 .66565 Mdot
.4841 .14574 Mdot
.39237 .47436 Mdot
.44846 .45803 Mdot
.42565 .49477 Mdot
.31713 .28902 Mdot
.32627 .39928 Mdot
.44502 .63847 Mdot
.36352 .4741 Mdot
.42849 .67286 Mdot
.67853 .45018 Mdot
.62604 .66143 Mdot
.43279 .67121 Mdot
.36447 .45527 Mdot
.21463 .32749 Mdot
.66841 .61987 Mdot
.39771 .44043 Mdot
.67055 .6393 Mdot
.46245 .62198 Mdot
.43921 .69091 Mdot
.52006 .58412 Mdot
.54681 .49257 Mdot
.64023 .6331 Mdot
.37686 .39836 Mdot
.58857 .79367 Mdot
.37212 .38673 Mdot
.68311 .50467 Mdot
.41547 .39846 Mdot
.42868 .44137 Mdot
.4245 .16598 Mdot
.51483 .50959 Mdot
.76488 .66917 Mdot
.58621 .64944 Mdot
.57765 .80043 Mdot
.4078 .71165 Mdot
.62206 .33967 Mdot
.46935 .54316 Mdot
.50879 .58983 Mdot
.65773 .4382 Mdot
.40511 .44872 Mdot
.50692 .66742 Mdot
.63785 .61257 Mdot
.6317 .32098 Mdot
.37351 .47032 Mdot
.6568 .42989 Mdot
.44939 .53485 Mdot
.63799 .62671 Mdot
.4594 .66194 Mdot
.45371 .68561 Mdot
.58287 .26322 Mdot
.38671 .46308 Mdot
.38667 .45399 Mdot
.67219 .62032 Mdot
.36158 .49615 Mdot
.64029 .27898 Mdot
.58915 .55143 Mdot
.66403 .64605 Mdot
.50409 .42514 Mdot
.42495 .69625 Mdot
.37604 .43625 Mdot
.48735 .33569 Mdot
.52419 .80993 Mdot
.2389 .63142 Mdot
.63506 .29668 Mdot
.38412 .28399 Mdot
.44648 .63862 Mdot
.66357 .63991 Mdot
.48106 .22373 Mdot
.41585 .38803 Mdot
.37763 .43018 Mdot
.35804 .27621 Mdot
.46802 .31562 Mdot
.56035 .49723 Mdot
.30447 .44895 Mdot
.46299 .29534 Mdot
.36383 .39231 Mdot
.34341 .42245 Mdot
.42775 .45142 Mdot
.41288 .39567 Mdot
.43359 .67731 Mdot
.3507 .59439 Mdot
.68761 .4656 Mdot
.24701 .62375 Mdot
.66316 .50102 Mdot
.35532 .444 Mdot
.36499 .39592 Mdot
.26903 .60492 Mdot
.43084 .32 Mdot
.44853 .66821 Mdot
.40024 .69414 Mdot
.6712 .66033 Mdot
.36109 .38728 Mdot
.69584 .42702 Mdot
.42385 .49473 Mdot
.66888 .45663 Mdot
.43524 .6779 Mdot
.71968 .45545 Mdot
.69231 .64227 Mdot
.71044 .46607 Mdot
.66388 .43335 Mdot
.65189 .61667 Mdot
.41856 .68925 Mdot
.37017 .42017 Mdot
.64942 .61666 Mdot
.63772 .2567 Mdot
.61065 .31627 Mdot
.41701 .62592 Mdot
.33479 .44738 Mdot
.38314 .3747 Mdot
.70454 .59449 Mdot
.71469 .44823 Mdot
.47861 .35857 Mdot
.41719 .68034 Mdot
.60839 .30242 Mdot
.4295 .67691 Mdot
.56839 .24391 Mdot
.63631 .30125 Mdot
.49092 .60741 Mdot
.44151 .24454 Mdot
.62427 .61003 Mdot
.43753 .43318 Mdot
.39616 .65368 Mdot
.66996 .45212 Mdot
.6221 .63197 Mdot
.57755 .66134 Mdot
.35073 .46125 Mdot
.47452 .60615 Mdot
.44688 .62501 Mdot
.50503 .59128 Mdot
.66178 .64246 Mdot
.40542 .60261 Mdot
.37895 .45857 Mdot
.62049 .61324 Mdot
.41842 .40276 Mdot
.34348 .67784 Mdot
.67212 .52172 Mdot
.52895 .62609 Mdot
.3679 .39207 Mdot
.66069 .45374 Mdot
.36609 .39207 Mdot
.32412 .7099 Mdot
.44774 .26079 Mdot
.42968 .44811 Mdot
.41103 .30765 Mdot
.69814 .57806 Mdot
.42541 .68154 Mdot
.34414 .36946 Mdot
.49188 .58601 Mdot
.34823 .42829 Mdot
.12921 .50579 Mdot
.64154 .31621 Mdot
.59044 .3173 Mdot
.36929 .46092 Mdot
.3959 .46256 Mdot
.25717 .44222 Mdot
.36194 .70107 Mdot
.52077 .57976 Mdot
.38261 .42656 Mdot
.32843 .29205 Mdot
.66526 .6254 Mdot
.39816 .39177 Mdot
.41507 .45004 Mdot
.6426 .50502 Mdot
.66823 .63012 Mdot
.71431 .46867 Mdot
.50432 .59286 Mdot
.71272 .4855 Mdot
.65531 .27927 Mdot
.39305 .29274 Mdot
.39609 .26981 Mdot
.49852 .43493 Mdot
.62944 .33484 Mdot
.35392 .43342 Mdot
.533 .61731 Mdot
.37266 .45816 Mdot
.62379 .3024 Mdot
.66816 .64572 Mdot
.43885 .67356 Mdot
.35196 .70388 Mdot
.50094 .57181 Mdot
.36265 .41489 Mdot
.6099 .3303 Mdot
.43611 .66578 Mdot
.49422 .81795 Mdot
.43657 .6849 Mdot
.64707 .62609 Mdot
.62344 .61835 Mdot
.6362 .30722 Mdot
.42902 .67765 Mdot
.71775 .47972 Mdot
.61464 .67332 Mdot
.43639 .45778 Mdot
.69187 .64536 Mdot
.47392 .63968 Mdot
.47252 .65111 Mdot
.45162 .70796 Mdot
.35155 .40207 Mdot
.45279 .32657 Mdot
.31306 .46979 Mdot
.67078 .62048 Mdot
.6537 .43949 Mdot
.48634 .28118 Mdot
.33222 .53586 Mdot
.50048 .39971 Mdot
.35272 .36627 Mdot
.40439 .41557 Mdot
.41453 .43105 Mdot
.3332 .42071 Mdot
.57012 .55882 Mdot
.40249 .47258 Mdot
.67507 .63929 Mdot
.67595 .46325 Mdot
.37042 .42974 Mdot
.49282 .59279 Mdot
.58186 .51271 Mdot
.6336 .26881 Mdot
.34546 .64158 Mdot
.40217 .64017 Mdot
.43663 .66713 Mdot
.71031 .45084 Mdot
.72092 .46066 Mdot
.62317 .28141 Mdot
.63607 .62432 Mdot
.44018 .68677 Mdot
.41293 .20246 Mdot
.64898 .28729 Mdot
.41114 .43075 Mdot
.48957 .33705 Mdot
.29905 .30392 Mdot
.41614 .41504 Mdot
.40917 .4416 Mdot
.48794 .58345 Mdot
.6892 .42405 Mdot
.22634 .65194 Mdot
.42664 .78267 Mdot
.63886 .31209 Mdot
.62856 .27954 Mdot
.45178 .71106 Mdot
.38653 .40612 Mdot
.64564 .64118 Mdot
.42054 .28853 Mdot
.6803 .5661 Mdot
.56553 .67666 Mdot
.68036 .55481 Mdot
.4161 .4255 Mdot
.32175 .65 Mdot
.42649 .40825 Mdot
.45956 .61954 Mdot
.44863 .7025 Mdot
.45104 .66323 Mdot
.66312 .62308 Mdot
.53037 .26533 Mdot
.67292 .65189 Mdot
.54735 .60865 Mdot
.4496 .64217 Mdot
.52984 .50307 Mdot
.68894 .43211 Mdot
.34274 .39426 Mdot
.62225 .29808 Mdot
.64474 .36964 Mdot
.35253 .36373 Mdot
.38678 .28665 Mdot
.70989 .47161 Mdot
.41211 .67879 Mdot
.33892 .39818 Mdot
.57984 .6703 Mdot
.49843 .34924 Mdot
.70757 .56658 Mdot
.51198 .65605 Mdot
.6455 .3074 Mdot
.21509 .58219 Mdot
.64123 .28226 Mdot
.63551 .63238 Mdot
.39518 .47349 Mdot
.38669 .40804 Mdot
.4118 .45162 Mdot
.4023 .3841 Mdot
.6631 .6295 Mdot
.43523 .45687 Mdot
.55653 .33252 Mdot
.51721 .58193 Mdot
.56743 .52935 Mdot
.62509 .32717 Mdot
.62796 .656 Mdot
.67441 .4586 Mdot
.50591 .56452 Mdot
.60389 .31845 Mdot
.33411 .40583 Mdot
.36637 .45546 Mdot
.51847 .58161 Mdot
.32607 .38615 Mdot
.36454 .37741 Mdot
.68372 .47088 Mdot
.57022 .50629 Mdot
.64154 .26635 Mdot
.63864 .28989 Mdot
.62513 .64516 Mdot
.42888 .67698 Mdot
.63768 .26913 Mdot
.65841 .47806 Mdot
.39339 .39011 Mdot
.42 .40522 Mdot
.47375 .64181 Mdot
.52204 .26915 Mdot
.63326 .26886 Mdot
.32706 .44725 Mdot
.46789 .67283 Mdot
.44458 .62562 Mdot
.38314 .42745 Mdot
.42035 .47508 Mdot
.43582 .7209 Mdot
.6209 .28569 Mdot
.62571 .64966 Mdot
.5154 .41117 Mdot
.65059 .66658 Mdot
.45851 .65608 Mdot
.42957 .37607 Mdot
.41702 .69077 Mdot
.34895 .45905 Mdot
.77199 .69448 Mdot
.40569 .47161 Mdot
.40579 .54086 Mdot
.59511 .45016 Mdot
.68751 .43004 Mdot
.67535 .43192 Mdot
.49859 .59016 Mdot
.42539 .64552 Mdot
.37338 .35524 Mdot
.62385 .29215 Mdot
.57842 .79986 Mdot
.44981 .72188 Mdot
.66356 .43462 Mdot
.70507 .42785 Mdot
.6686 .64242 Mdot
.40076 .41254 Mdot
.37432 .43773 Mdot
.71144 .46577 Mdot
.65232 .54862 Mdot
.42179 .66955 Mdot
.3871 .45405 Mdot
.33564 .41912 Mdot
.68504 .4652 Mdot
.68865 .617 Mdot
.47946 .63727 Mdot
.34886 .40498 Mdot
.44273 .2655 Mdot
.61647 .6467 Mdot
.35276 .41862 Mdot
.43704 .42899 Mdot
.62997 .31373 Mdot
.37629 .27975 Mdot
.51582 .27297 Mdot
.66158 .66857 Mdot
.49684 .59622 Mdot
.41531 .41647 Mdot
.68136 .43212 Mdot
.32569 .41623 Mdot
.36794 .81823 Mdot
.51434 .58765 Mdot
.37891 .45664 Mdot
.38279 .495 Mdot
.46561 .66026 Mdot
.39111 .45992 Mdot
.59824 .60016 Mdot
.70333 .46152 Mdot
.37729 .45558 Mdot
.24837 .41422 Mdot
.66789 .6426 Mdot
.34627 .36808 Mdot
.64982 .30016 Mdot
.54863 .49676 Mdot
.20583 .38877 Mdot
.6457 .46564 Mdot
.63399 .32785 Mdot
.39597 .41245 Mdot
.682 .49408 Mdot
.68256 .62233 Mdot
.38118 .52166 Mdot
.3535 .42661 Mdot
.66133 .66364 Mdot
.65825 .61881 Mdot
.63977 .3075 Mdot
.7339 .76591 Mdot
.42789 .45488 Mdot
.39135 .43796 Mdot
.63253 .81581 Mdot
.43159 .72341 Mdot
.39862 .43886 Mdot
.38402 .4137 Mdot
.62774 .63551 Mdot
.53902 .23664 Mdot
.38395 .28465 Mdot
.5859 .55403 Mdot
.61729 .64435 Mdot
.70585 .49668 Mdot
.70382 .46859 Mdot
.63858 .32545 Mdot
.44443 .67828 Mdot
.60931 .30235 Mdot
.69313 .45672 Mdot
.41137 .44593 Mdot
.64009 .65473 Mdot
.19887 .48458 Mdot
.63848 .61741 Mdot
.6482 .46026 Mdot
.46034 .62014 Mdot
.29428 .70988 Mdot
.39568 .83865 Mdot
.43952 .53887 Mdot
.61142 .62973 Mdot
.6346 .31338 Mdot
.43808 .79183 Mdot
.3699 .42923 Mdot
.32432 .69285 Mdot
.39391 .43579 Mdot
.49781 .68285 Mdot
.67549 .4809 Mdot
.51588 .59067 Mdot
.34936 .45992 Mdot
.38071 .28489 Mdot
.64806 .6186 Mdot
.64955 .64876 Mdot
.36283 .47338 Mdot
.64471 .62813 Mdot
.37506 .4454 Mdot
.68 .46279 Mdot
.75815 .71451 Mdot
.36401 .43663 Mdot
.4525 .46467 Mdot
.60889 .62406 Mdot
.40345 .63297 Mdot
.72 .49245 Mdot
.33624 .61382 Mdot
.57435 .68321 Mdot
.64658 .64002 Mdot
.35199 .62899 Mdot
.70921 .4439 Mdot
.50423 .56422 Mdot
.71288 .49054 Mdot
.38548 .4349 Mdot
.4139 .42051 Mdot
.33212 .42206 Mdot
.38852 .41317 Mdot
.30389 .67757 Mdot
.35916 .37807 Mdot
.23417 .5303 Mdot
.3868 .46968 Mdot
.41469 .53794 Mdot
.67343 .64819 Mdot
.44681 .4601 Mdot
.5288 .41535 Mdot
.41451 .46545 Mdot
.40313 .70384 Mdot
.63347 .65987 Mdot
.66958 .71394 Mdot
.66479 .62873 Mdot
.68342 .43782 Mdot
.6468 .62059 Mdot
.38173 .47732 Mdot
.46105 .66968 Mdot
.70073 .44782 Mdot
.44013 .53395 Mdot
.65309 .44865 Mdot
.38185 .4616 Mdot
.62777 .60514 Mdot
.70767 .43399 Mdot
.39419 .37493 Mdot
.46 .67292 Mdot
.36773 .25424 Mdot
.47366 .61461 Mdot
.39648 .45502 Mdot
.39901 .44913 Mdot
.51988 .57919 Mdot
.64108 .62312 Mdot
.42021 .69612 Mdot
.63352 .49668 Mdot
.60569 .31003 Mdot
.44947 .67177 Mdot
.4265 .49487 Mdot
.49486 .34429 Mdot
.46877 .66255 Mdot
.31454 .29794 Mdot
.63293 .63528 Mdot
.46324 .64577 Mdot
.39745 .50333 Mdot
.24479 .61697 Mdot
.64087 .28743 Mdot
.72197 .47358 Mdot
.47562 .30514 Mdot
.70396 .46671 Mdot
.59694 .61074 Mdot
.72897 .44799 Mdot
.67131 .63182 Mdot
.38611 .3288 Mdot
.53014 .48293 Mdot
.63303 .61741 Mdot
.60365 .62498 Mdot
.69237 .46716 Mdot
.33439 .44201 Mdot
.5651 .51843 Mdot
.38092 .35436 Mdot
.43399 .37457 Mdot
.64254 .6672 Mdot
.45902 .64141 Mdot
.40688 .68192 Mdot
.46283 .43951 Mdot
.45206 .68969 Mdot
.68898 .44784 Mdot
.49458 .44331 Mdot
.35825 .63422 Mdot
.66577 .65081 Mdot
.57413 .49755 Mdot
.36177 .39696 Mdot
.6736 .47218 Mdot
.68637 .44667 Mdot
.65796 .61965 Mdot
.27088 .65311 Mdot
.40282 .36013 Mdot
.41852 .72886 Mdot
.45801 .64565 Mdot
.46605 .65763 Mdot
.43356 .69875 Mdot
.53111 .26283 Mdot
.62209 .63248 Mdot
.43173 .64249 Mdot
.39454 .38169 Mdot
.39332 .40856 Mdot
.50869 .57888 Mdot
.61235 .30559 Mdot
.41181 .38545 Mdot
.37195 .35525 Mdot
.38169 .42889 Mdot
.69161 .42966 Mdot
.33105 .32974 Mdot
.51638 .57937 Mdot
.69187 .42551 Mdot
.68818 .42664 Mdot
.49854 .59385 Mdot
.38091 .32686 Mdot
.23504 .6544 Mdot
.37063 .47692 Mdot
.39555 .69762 Mdot
.67086 .4353 Mdot
.61551 .37943 Mdot
.42033 .54256 Mdot
.38347 .39951 Mdot
.58669 .53722 Mdot
.6803 .45679 Mdot
.40941 .71334 Mdot
.38514 .43988 Mdot
.4968 .57062 Mdot
.64574 .2921 Mdot
.33343 .49528 Mdot
.48843 .58267 Mdot
.42369 .678 Mdot
.63846 .42391 Mdot
.46323 .63906 Mdot
.72229 .4481 Mdot
.36046 .35962 Mdot
.86914 .61614 Mdot
.67147 .44965 Mdot
.59492 .79671 Mdot
.5319 .48575 Mdot
.36628 .44479 Mdot
.70857 .45636 Mdot
.45761 .71299 Mdot
.6156 .64629 Mdot
.4664 .33302 Mdot
.42812 .68261 Mdot
.50744 .56413 Mdot
.50561 .58 Mdot
.6866 .4662 Mdot
.44835 .64685 Mdot
.43814 .44142 Mdot
.45405 .68413 Mdot
.64673 .65573 Mdot
.35104 .4563 Mdot
.57215 .66794 Mdot
.45394 .43497 Mdot
.45888 .68347 Mdot
.65039 .4485 Mdot
.65754 .29448 Mdot
.36153 .454 Mdot
.6525 .71238 Mdot
.39542 .41177 Mdot
.67025 .6417 Mdot
.59236 .41919 Mdot
.20333 .48812 Mdot
.4043 .42666 Mdot
.36053 .3988 Mdot
.69118 .63593 Mdot
.40178 .4257 Mdot
.42036 .41412 Mdot
.40339 .60467 Mdot
.46923 .66489 Mdot
.37228 .42796 Mdot
.69535 .47752 Mdot
.23227 .45512 Mdot
.40416 .46404 Mdot
.60082 .5958 Mdot
.35413 .27184 Mdot
.57626 .39322 Mdot
.44908 .37911 Mdot
.43278 .27379 Mdot
.39675 .4453 Mdot
.38208 .4012 Mdot
.36745 .4757 Mdot
.32251 .65651 Mdot
.69493 .46074 Mdot
.66045 .46048 Mdot
.65039 .31748 Mdot
.35199 .27683 Mdot
.64147 .29742 Mdot
.68138 .61817 Mdot
.55961 .4952 Mdot
.51664 .57252 Mdot
.42831 .67594 Mdot
.40754 .45779 Mdot
.6531 .45871 Mdot
.37761 .43786 Mdot
.34893 .42543 Mdot
.68864 .45163 Mdot
.68096 .45049 Mdot
.64299 .45063 Mdot
.65148 .29387 Mdot
.4441 .66725 Mdot
.39202 .47679 Mdot
.65044 .28573 Mdot
.33513 .41525 Mdot
.50983 .39111 Mdot
.44683 .66655 Mdot
.45814 .68528 Mdot
.41018 .66296 Mdot
.3601 .43634 Mdot
.3583 .46694 Mdot
.67219 .65342 Mdot
.47337 .64098 Mdot
.63987 .63779 Mdot
.70836 .45801 Mdot
.68061 .47516 Mdot
.38613 .43439 Mdot
.3568 .49321 Mdot
.61903 .32456 Mdot
.71141 .4404 Mdot
.48377 .60292 Mdot
.65121 .31123 Mdot
.41724 .43625 Mdot
.70647 .46304 Mdot
.61572 .32875 Mdot
.25786 .65212 Mdot
.5336 .69084 Mdot
.65315 .31147 Mdot
.35451 .46673 Mdot
.30949 .52055 Mdot
.45876 .26336 Mdot
.62826 .27127 Mdot
.67051 .65045 Mdot
.37666 .41592 Mdot
.57619 .57369 Mdot
.64688 .27102 Mdot
.5073 .27231 Mdot
.69407 .45091 Mdot
.4456 .39542 Mdot
.28705 .42564 Mdot
.36266 .62705 Mdot
.65722 .2896 Mdot
.46123 .68036 Mdot
.47437 .66973 Mdot
.40969 .42984 Mdot
.55318 .49554 Mdot
.66914 .61307 Mdot
.72099 .46224 Mdot
.65853 .46154 Mdot
.47149 .67917 Mdot
.50008 .43358 Mdot
.6983 .47572 Mdot
.38175 .40653 Mdot
.66339 .27537 Mdot
.36809 .38349 Mdot
.56229 .27286 Mdot
.21593 .43843 Mdot
.45328 .38644 Mdot
.65714 .29876 Mdot
.6736 .61763 Mdot
.66726 .62237 Mdot
.6552 .62298 Mdot
.68853 .47437 Mdot
.45743 .30461 Mdot
.66082 .47004 Mdot
.59088 .82607 Mdot
.64314 .3157 Mdot
.44225 .18587 Mdot
.41467 .39286 Mdot
.36717 .44773 Mdot
.38539 .38719 Mdot
.33526 .42638 Mdot
.3955 .44599 Mdot
.66672 .66175 Mdot
.70145 .49044 Mdot
.67944 .5607 Mdot
.43326 .65361 Mdot
.48795 .81653 Mdot
.69073 .43202 Mdot
.48646 .58874 Mdot
.61704 .31643 Mdot
.37503 .2664 Mdot
.66 .31397 Mdot
.71672 .44438 Mdot
.42565 .43895 Mdot
.45384 .71029 Mdot
.40125 .2093 Mdot
.39965 .46148 Mdot
.71406 .44455 Mdot
.68734 .49833 Mdot
.25408 .63567 Mdot
.30432 .43905 Mdot
.65994 .54171 Mdot
.48596 .34524 Mdot
.6481 .32633 Mdot
.33525 .45092 Mdot
.40831 .28598 Mdot
.69195 .45857 Mdot
.66641 .44738 Mdot
.61276 .28971 Mdot
.39986 .74516 Mdot
.43447 .64328 Mdot
.44107 .61723 Mdot
.65391 .66293 Mdot
.36707 .45347 Mdot
.6965 .46946 Mdot
.45862 .61542 Mdot
.52573 .36265 Mdot
.65766 .62997 Mdot
.70184 .42713 Mdot
.39252 .41113 Mdot
.40387 .42435 Mdot
.64208 .30034 Mdot
.59008 .47713 Mdot
.38107 .35441 Mdot
.58186 .79902 Mdot
.49148 .37492 Mdot
.53286 .48558 Mdot
.37729 .43035 Mdot
.42904 .69595 Mdot
.49852 .59299 Mdot
.61916 .30132 Mdot
.32762 .40911 Mdot
.31907 .73219 Mdot
.43997 .63462 Mdot
.64065 .63627 Mdot
.48885 .59672 Mdot
.39676 .29669 Mdot
.39209 .4118 Mdot
.39335 .43579 Mdot
.35339 .4001 Mdot
.27116 .69652 Mdot
.67246 .47833 Mdot
.43752 .6973 Mdot
.64838 .30451 Mdot
.43868 .68993 Mdot
.72112 .4389 Mdot
.57501 .49976 Mdot
.39203 .47936 Mdot
.42342 .64261 Mdot
.44654 .68459 Mdot
.66766 .6448 Mdot
.651 .61598 Mdot
.65682 .48206 Mdot
.37917 .4174 Mdot
.51685 .57089 Mdot
.44255 .63923 Mdot
.71524 .4783 Mdot
.64063 .30013 Mdot
.59473 .61224 Mdot
.38378 .46948 Mdot
.68962 .46424 Mdot
.35867 .35967 Mdot
.43654 .6571 Mdot
.70363 .43452 Mdot
.50022 .56516 Mdot
.61717 .29181 Mdot
.41376 .41806 Mdot
.70533 .55191 Mdot
.49275 .5762 Mdot
.36036 .44729 Mdot
.21674 .45611 Mdot
.55363 .49603 Mdot
.4933 .66095 Mdot
.68727 .48309 Mdot
.50504 .56801 Mdot
.44833 .69959 Mdot
.23223 .59291 Mdot
.66551 .45543 Mdot
.27212 .4694 Mdot
.52288 .47894 Mdot
.35691 .46805 Mdot
.42575 .68056 Mdot
.57658 .31132 Mdot
.5474 .79923 Mdot
.46923 .27012 Mdot
.37924 .45307 Mdot
.70344 .46726 Mdot
.64374 .2914 Mdot
.64782 .64818 Mdot
.61952 .66774 Mdot
.58514 .25226 Mdot
.67334 .4271 Mdot
.40811 .45781 Mdot
.45955 .64211 Mdot
.64151 .63238 Mdot
.25347 .44792 Mdot
.66923 .48531 Mdot
.70015 .47677 Mdot
.39261 .39446 Mdot
.64089 .29568 Mdot
.56435 .57939 Mdot
.66857 .47381 Mdot
.69739 .49258 Mdot
.40683 .59592 Mdot
.64367 .32958 Mdot
.34514 .41108 Mdot
.46282 .44022 Mdot
.40927 .39517 Mdot
.54494 .82577 Mdot
.50751 .56765 Mdot
.43061 .65494 Mdot
.40331 .44238 Mdot
.70227 .58557 Mdot
.67024 .45987 Mdot
.48579 .3462 Mdot
.6803 .61005 Mdot
.64678 .61761 Mdot
.70271 .45962 Mdot
.38052 .44422 Mdot
.69538 .65009 Mdot
.63627 .32511 Mdot
.34457 .41085 Mdot
.35104 .46077 Mdot
.47895 .65354 Mdot
.64325 .65663 Mdot
.22918 .45099 Mdot
.64421 .64928 Mdot
.62475 .6379 Mdot
.48089 .62289 Mdot
.41 .42962 Mdot
.69813 .43468 Mdot
.66312 .42082 Mdot
.33424 .45868 Mdot
.63281 .37957 Mdot
.42183 .65218 Mdot
.73938 .45748 Mdot
.31372 .73129 Mdot
.42471 .41327 Mdot
.48817 .60191 Mdot
.52065 .63863 Mdot
.62663 .61589 Mdot
.40682 .43316 Mdot
.4275 .67184 Mdot
.68524 .49125 Mdot
.6984 .47217 Mdot
.41413 .38646 Mdot
.6657 .62021 Mdot
.61183 .32396 Mdot
.6892 .44435 Mdot
.51484 .42133 Mdot
.38159 .45915 Mdot
.6552 .69508 Mdot
.6916 .44252 Mdot
.21913 .32776 Mdot
.70593 .59294 Mdot
.46778 .65861 Mdot
.37307 .39539 Mdot
.47593 .67392 Mdot
.6409 .3274 Mdot
.72848 .46919 Mdot
.67499 .63351 Mdot
.31331 .40024 Mdot
.82374 .55148 Mdot
.69009 .47186 Mdot
.43581 .67677 Mdot
.40923 .44746 Mdot
.35517 .619 Mdot
.36689 .43135 Mdot
.53872 .23182 Mdot
.63745 .26583 Mdot
.60106 .60752 Mdot
.67238 .62103 Mdot
.36084 .3998 Mdot
.64361 .27925 Mdot
.65698 .42627 Mdot
.68888 .45253 Mdot
.80983 .61633 Mdot
.49065 .5766 Mdot
.70846 .41479 Mdot
.36058 .44007 Mdot
.71636 .4729 Mdot
.33392 .53686 Mdot
.65711 .61795 Mdot
.41153 .39831 Mdot
.67998 .42048 Mdot
.50465 .8043 Mdot
.48982 .34382 Mdot
.38048 .45684 Mdot
.37156 .49767 Mdot
.67012 .63557 Mdot
.437 .79142 Mdot
.67857 .48378 Mdot
.33281 .41023 Mdot
.68005 .61309 Mdot
.40993 .33746 Mdot
.62835 .49903 Mdot
.44448 .66683 Mdot
.69187 .42003 Mdot
.6286 .65202 Mdot
.44818 .40272 Mdot
.61272 .31673 Mdot
.66179 .48313 Mdot
.6608 .43174 Mdot
.35328 .45334 Mdot
.34274 .40496 Mdot
.37723 .49991 Mdot
.4178 .67013 Mdot
.62743 .63893 Mdot
.34566 .42597 Mdot
.50781 .38125 Mdot
.33737 .42892 Mdot
.62759 .64468 Mdot
.79713 .70891 Mdot
.42435 .43651 Mdot
.38 .46701 Mdot
.34418 .62857 Mdot
.41629 .69439 Mdot
.46976 .67486 Mdot
.49745 .3836 Mdot
.36592 .42019 Mdot
.5257 .50462 Mdot
.44081 .66928 Mdot
.43602 .68036 Mdot
.52694 .50414 Mdot
.35653 .46122 Mdot
.46423 .61058 Mdot
.64221 .6307 Mdot
.64737 .61725 Mdot
.46568 .66088 Mdot
.36528 .38593 Mdot
.68114 .62114 Mdot
.28649 .64688 Mdot
.71294 .43882 Mdot
.40276 .28709 Mdot
.44998 .68505 Mdot
.4906 .33339 Mdot
.63453 .63278 Mdot
.2394 .33709 Mdot
.31055 .29254 Mdot
.43184 .43305 Mdot
.40809 .42949 Mdot
.63002 .3103 Mdot
.32118 .39051 Mdot
.50171 .59279 Mdot
.65332 .62246 Mdot
.57008 .55761 Mdot
.45186 .66302 Mdot
.36679 .42154 Mdot
.49058 .28468 Mdot
.20868 .39242 Mdot
.44355 .4932 Mdot
.44258 .67946 Mdot
.45742 .66548 Mdot
.7045 .4765 Mdot
.71949 .44747 Mdot
.39382 .47826 Mdot
.67003 .62671 Mdot
.46645 .65126 Mdot
.63243 .64829 Mdot
.69204 .45703 Mdot
.6913 .43372 Mdot
.51416 .5823 Mdot
.42753 .36809 Mdot
.70027 .45584 Mdot
.62443 .57917 Mdot
.50804 .38278 Mdot
.47369 .63717 Mdot
.61804 .82107 Mdot
.25307 .3199 Mdot
.34597 .68743 Mdot
.64479 .29137 Mdot
.3925 .32973 Mdot
.67983 .64495 Mdot
.35768 .40235 Mdot
.39436 .43085 Mdot
.50103 .57568 Mdot
.68235 .63948 Mdot
.62492 .31933 Mdot
.652 .61746 Mdot
.61871 .29623 Mdot
.65972 .45519 Mdot
.4043 .46184 Mdot
.41358 .46444 Mdot
.6513 .64847 Mdot
.71481 .46651 Mdot
.70657 .43341 Mdot
.63565 .2853 Mdot
.36973 .26656 Mdot
.68712 .4644 Mdot
.44797 .68589 Mdot
.25876 .48362 Mdot
.50521 .57883 Mdot
.38525 .44076 Mdot
.42763 .27257 Mdot
.22844 .57374 Mdot
.33102 .42724 Mdot
.48922 .59329 Mdot
.73892 .76172 Mdot
.40146 .46685 Mdot
.83306 .50292 Mdot
.51572 .57397 Mdot
.41697 .69124 Mdot
.70485 .44189 Mdot
.48864 .58377 Mdot
.31631 .33787 Mdot
.68426 .52511 Mdot
.33032 .44771 Mdot
.43266 .64362 Mdot
.41108 .66801 Mdot
.57267 .5027 Mdot
.54131 .8265 Mdot
.64853 .30328 Mdot
.63288 .32253 Mdot
.66768 .46137 Mdot
.59056 .628 Mdot
.3807 .37974 Mdot
.63509 .32008 Mdot
.44627 .60819 Mdot
.36649 .39355 Mdot
.55573 .49748 Mdot
.56584 .52396 Mdot
.45352 .69594 Mdot
.44711 .45301 Mdot
.66864 .4604 Mdot
.43764 .6758 Mdot
.56672 .51232 Mdot
.39648 .39271 Mdot
.44893 .66516 Mdot
.63096 .6301 Mdot
.48794 .53151 Mdot
.45235 .68693 Mdot
.47263 .33773 Mdot
.65007 .64387 Mdot
.56391 .49725 Mdot
.4791 .20611 Mdot
.15844 .41035 Mdot
.66485 .62218 Mdot
.71281 .44654 Mdot
.69576 .46855 Mdot
.68281 .46493 Mdot
.42086 .67976 Mdot
.67651 .45074 Mdot
.43273 .64906 Mdot
.60489 .64335 Mdot
.36692 .27873 Mdot
.63567 .30451 Mdot
.58221 .33677 Mdot
.46437 .66692 Mdot
.57759 .82721 Mdot
.51925 .86891 Mdot
.33793 .42256 Mdot
.63026 .61918 Mdot
.65407 .29217 Mdot
.48682 .38045 Mdot
.62933 .31292 Mdot
.70957 .44485 Mdot
.38773 .28994 Mdot
.37419 .44419 Mdot
.55161 .65055 Mdot
.64298 .29165 Mdot
.43556 .68188 Mdot
.35458 .4403 Mdot
.69595 .41791 Mdot
.63821 .32717 Mdot
.63549 .28883 Mdot
.3939 .44497 Mdot
.41239 .68113 Mdot
.70744 .43676 Mdot
.6695 .6631 Mdot
.66635 .28529 Mdot
.31935 .46025 Mdot
.40747 .46464 Mdot
.42355 .45781 Mdot
.49135 .35137 Mdot
.58807 .63247 Mdot
.65067 .64188 Mdot
.50797 .27556 Mdot
.67536 .47351 Mdot
.46997 .26838 Mdot
.57346 .79141 Mdot
.57995 .30669 Mdot
.50762 .56846 Mdot
.50916 .56745 Mdot
.38997 .45726 Mdot
.41847 .83562 Mdot
.41159 .52852 Mdot
.67113 .60556 Mdot
.50102 .57984 Mdot
.71544 .43903 Mdot
.47008 .64116 Mdot
.28981 .42823 Mdot
.41314 .38872 Mdot
.6719 .66192 Mdot
.68708 .45806 Mdot
.36156 .8164 Mdot
.64389 .3123 Mdot
.49036 .39074 Mdot
.38255 .41598 Mdot
.3879 .45162 Mdot
.65832 .6356 Mdot
.67496 .63645 Mdot
.40651 .59469 Mdot
.56855 .37902 Mdot
.57084 .67783 Mdot
.66814 .66882 Mdot
.35955 .8162 Mdot
.50948 .66303 Mdot
.45424 .65343 Mdot
.49897 .59713 Mdot
.66939 .61427 Mdot
.40057 .43997 Mdot
.41477 .69057 Mdot
.4026 .52749 Mdot
.42016 .70685 Mdot
.54841 .49615 Mdot
.51511 .41172 Mdot
.40369 .41544 Mdot
.44633 .70923 Mdot
.44213 .67263 Mdot
.4009 .66074 Mdot
.50339 .58781 Mdot
.37983 .42747 Mdot
.33034 .41554 Mdot
.39731 .47157 Mdot
.41065 .56788 Mdot
.39072 .46036 Mdot
.56743 .7939 Mdot
.50361 .40147 Mdot
.72619 .30715 Mdot
.39536 .46795 Mdot
.62868 .63015 Mdot
.40578 .45661 Mdot
.63964 .27722 Mdot
.41859 .42334 Mdot
.54366 .49378 Mdot
.64659 .63222 Mdot
.32344 .71479 Mdot
.667 .49975 Mdot
.41464 .46036 Mdot
.62691 .33485 Mdot
.67221 .76873 Mdot
.50593 .28027 Mdot
.40842 .59509 Mdot
.45394 .68395 Mdot
.68912 .49474 Mdot
.65622 .61007 Mdot
.68426 .43658 Mdot
.43743 .45256 Mdot
.50957 .5909 Mdot
.42356 .17105 Mdot
.50291 .32937 Mdot
.40219 .44194 Mdot
.40828 .36149 Mdot
.45137 .69293 Mdot
.67038 .45671 Mdot
.36205 .70993 Mdot
.37794 .38725 Mdot
.61577 .2907 Mdot
.64901 .27732 Mdot
.74044 .41709 Mdot
.4631 .56063 Mdot
.36886 .55059 Mdot
.65629 .63627 Mdot
.69156 .47462 Mdot
.65308 .28145 Mdot
.4035 .64199 Mdot
.65724 .61173 Mdot
.62711 .61531 Mdot
.6434 .6575 Mdot
.37661 .45947 Mdot
.51223 .57935 Mdot
.46616 .57905 Mdot
.49486 .57072 Mdot
.39896 .38703 Mdot
.6625 .42981 Mdot
.50261 .56513 Mdot
.63135 .3022 Mdot
.62406 .64608 Mdot
.6907 .43061 Mdot
.39902 .45227 Mdot
.43884 .66605 Mdot
.55358 .30555 Mdot
.71127 .58964 Mdot
.55508 .49557 Mdot
.55521 .49557 Mdot
.43131 .6333 Mdot
.55252 .60233 Mdot
.59733 .63777 Mdot
.24755 .62636 Mdot
.65529 .25395 Mdot
.32043 .40978 Mdot
.65795 .38546 Mdot
.66199 .47252 Mdot
.69894 .44676 Mdot
.37119 .44543 Mdot
.70716 .48173 Mdot
.3679 .42392 Mdot
.68823 .48373 Mdot
.54278 .80895 Mdot
.42912 .40863 Mdot
.6914 .44725 Mdot
.30184 .42357 Mdot
.36183 .45402 Mdot
.43313 .69521 Mdot
.6765 .48865 Mdot
.43169 .43198 Mdot
.55619 .13802 Mdot
.66569 .6463 Mdot
.50425 .58634 Mdot
.52878 .45848 Mdot
.63899 .62729 Mdot
.43984 .64382 Mdot
.37733 .41157 Mdot
.64391 .31721 Mdot
.45797 .65626 Mdot
.73202 .48794 Mdot
.63939 .29214 Mdot
.49542 .44711 Mdot
.46181 .6567 Mdot
.50666 .57588 Mdot
.62281 .28365 Mdot
.33161 .45016 Mdot
.69672 .44778 Mdot
.71111 .59617 Mdot
.48783 .59239 Mdot
.3747 .44024 Mdot
.7029 .42296 Mdot
.64734 .61935 Mdot
.41608 .44552 Mdot
.69723 .47035 Mdot
.49325 .59679 Mdot
.37218 .46454 Mdot
.3586 .43142 Mdot
.39053 .741 Mdot
.59712 .43094 Mdot
.63388 .30326 Mdot
.46118 .62064 Mdot
.40096 .38426 Mdot
.64287 .28085 Mdot
.67724 .55084 Mdot
.43413 .47594 Mdot
.43875 .63809 Mdot
.27849 .64662 Mdot
.71993 .46501 Mdot
.66618 .61823 Mdot
.64821 .45563 Mdot
.64627 .32414 Mdot
.57803 .86777 Mdot
.50492 .59162 Mdot
.39843 .48781 Mdot
.42156 .41376 Mdot
.72166 .48261 Mdot
.44551 .67139 Mdot
.56837 .67645 Mdot
.41199 .41506 Mdot
.42153 .37316 Mdot
.3895 .44243 Mdot
.7025 .54249 Mdot
.41843 .67617 Mdot
.38737 .44089 Mdot
.32645 .45706 Mdot
.41997 .4062 Mdot
.62079 .32982 Mdot
.43761 .18663 Mdot
.33787 .44593 Mdot
.89875 .56735 Mdot
.50829 .59686 Mdot
.68483 .45439 Mdot
.47446 .34113 Mdot
.53369 .45365 Mdot
.67887 .23299 Mdot
.43137 .64684 Mdot
.39421 .68821 Mdot
.69225 .43468 Mdot
.57969 .27768 Mdot
.55311 .5976 Mdot
.35621 .43259 Mdot
.38308 .41297 Mdot
.7095 .44475 Mdot
.71656 .47773 Mdot
.50828 .59519 Mdot
.36824 .47886 Mdot
.45265 .43722 Mdot
.65144 .44586 Mdot
.3962 .46253 Mdot
.22138 .55025 Mdot
.61524 .63446 Mdot
.46775 .66408 Mdot
.64937 .64973 Mdot
.61445 .64263 Mdot
.35217 .70324 Mdot
.49109 .36962 Mdot
.65809 .66316 Mdot
.63015 .60873 Mdot
.57522 .31862 Mdot
.35811 .6305 Mdot
.61794 .32808 Mdot
.45977 .53428 Mdot
.67802 .46933 Mdot
.38177 .42635 Mdot
.41884 .67904 Mdot
.57591 .21102 Mdot
.58832 .70376 Mdot
.30514 .33135 Mdot
.34657 .40978 Mdot
.67325 .4638 Mdot
.48721 .59616 Mdot
.43432 .47628 Mdot
.46209 .26469 Mdot
.38371 .45424 Mdot
.72155 .45703 Mdot
.35883 .63293 Mdot
.7007 .60363 Mdot
.65216 .67433 Mdot
.44022 .7252 Mdot
.4067 .45648 Mdot
.4228 .66568 Mdot
.63761 .66437 Mdot
.64827 .28817 Mdot
.63597 .31288 Mdot
.41606 .45903 Mdot
.53159 .48602 Mdot
.64418 .245 Mdot
.35603 .43686 Mdot
.35361 .45605 Mdot
.50504 .56931 Mdot
.35286 .45599 Mdot
.32771 .42246 Mdot
.34575 .42146 Mdot
.33687 .41286 Mdot
.66273 .61249 Mdot
.35542 .68019 Mdot
.37999 .48416 Mdot
.41834 .47559 Mdot
.62377 .65945 Mdot
.42949 .46642 Mdot
.66441 .62712 Mdot
.59265 .68747 Mdot
.66267 .65983 Mdot
.6365 .31109 Mdot
.70383 .42224 Mdot
.37576 .68587 Mdot
.46584 .6507 Mdot
.63411 .62165 Mdot
.61457 .29951 Mdot
.65914 .62159 Mdot
.68468 .47838 Mdot
.68938 .58365 Mdot
.48848 .64316 Mdot
.51289 .43095 Mdot
.34719 .64154 Mdot
.68942 .69151 Mdot
.70868 .4779 Mdot
.46594 .65554 Mdot
.59664 .60327 Mdot
.35819 .40286 Mdot
.64677 .30896 Mdot
.39018 .45652 Mdot
.62344 .64248 Mdot
.67604 .46667 Mdot
.39411 .62992 Mdot
.63297 .30417 Mdot
.65242 .80971 Mdot
.65274 .45937 Mdot
.42188 .42028 Mdot
.62762 .6622 Mdot
.65608 .56789 Mdot
.67209 .63822 Mdot
.36838 .27657 Mdot
.53328 .62153 Mdot
.58117 .2256 Mdot
.45982 .66359 Mdot
.48765 .57736 Mdot
.14919 .49062 Mdot
.63221 .74628 Mdot
.43698 .66067 Mdot
.63781 .43223 Mdot
.38786 .46346 Mdot
.34124 .42317 Mdot
.42268 .36717 Mdot
.41537 .69823 Mdot
.35412 .39941 Mdot
.50743 .58527 Mdot
.49667 .36952 Mdot
.48448 .56647 Mdot
.67376 .49337 Mdot
.36819 .42591 Mdot
.64386 .66739 Mdot
.63264 .62131 Mdot
.51054 .56274 Mdot
.64358 .65218 Mdot
.37307 .47114 Mdot
.46316 .66548 Mdot
.56547 .51734 Mdot
.64269 .32506 Mdot
.60918 .78553 Mdot
.63875 .25398 Mdot
.65756 .32302 Mdot
.42407 .41105 Mdot
.69408 .4336 Mdot
.8231 .5248 Mdot
.35464 .40315 Mdot
.43882 .67188 Mdot
.41936 .41147 Mdot
.34283 .4271 Mdot
.38168 .47859 Mdot
.69098 .47439 Mdot
.49085 .34104 Mdot
.39712 .4625 Mdot
.64968 .66527 Mdot
.52703 .50137 Mdot
.41069 .38569 Mdot
.59019 .54892 Mdot
.54505 .49495 Mdot
.66732 .69354 Mdot
.47752 .64645 Mdot
.69999 .43659 Mdot
.45404 .66222 Mdot
.43001 .71629 Mdot
.44006 .64399 Mdot
.47499 .57424 Mdot
.24213 .61501 Mdot
.83472 .49268 Mdot
.34137 .54103 Mdot
.34383 .64825 Mdot
.44626 .72091 Mdot
.7713 .50364 Mdot
.43183 .66418 Mdot
.43738 .64444 Mdot
.78203 .69469 Mdot
.41499 .6635 Mdot
.38528 .43397 Mdot
.41977 .46066 Mdot
.29029 .70609 Mdot
.6506 .33795 Mdot
.36185 .44687 Mdot
.33411 .41811 Mdot
.65084 .27854 Mdot
.39478 .73735 Mdot
.49392 .60222 Mdot
.49318 .40232 Mdot
.48681 .58307 Mdot
.39426 .44574 Mdot
.41228 .42472 Mdot
.33419 .38965 Mdot
.18831 .42419 Mdot
.59129 .23332 Mdot
.40961 .66849 Mdot
.32076 .42746 Mdot
.7052 .6787 Mdot
.38996 .40222 Mdot
.41273 .40479 Mdot
.37685 .47702 Mdot
.698 .43458 Mdot
.45806 .63327 Mdot
.37553 .35468 Mdot
.63256 .76429 Mdot
.39493 .41315 Mdot
.63173 .25429 Mdot
.61103 .33947 Mdot
.38041 .44282 Mdot
.41591 .65719 Mdot
.34206 .41899 Mdot
.47299 .65819 Mdot
.45986 .65333 Mdot
.43748 .38816 Mdot
.45864 .58576 Mdot
.4691 .64091 Mdot
.3567 .43111 Mdot
.71414 .46957 Mdot
.58669 .79832 Mdot
.37568 .44102 Mdot
.63321 .29714 Mdot
.40886 .43637 Mdot
.62398 .33216 Mdot
.34396 .44958 Mdot
.50016 .5672 Mdot
.19867 .49342 Mdot
.66523 .44888 Mdot
.6634 .30319 Mdot
.71213 .47738 Mdot
.36733 .3811 Mdot
.47799 .67523 Mdot
.70245 .61344 Mdot
.59684 .24221 Mdot
.50564 .56968 Mdot
.52561 .27154 Mdot
.52675 .51576 Mdot
.67647 .64823 Mdot
.4392 .69792 Mdot
.35674 .65661 Mdot
.58867 .54606 Mdot
.67469 .49498 Mdot
.70718 .42942 Mdot
.62315 .48131 Mdot
.75834 .71429 Mdot
.39163 .4669 Mdot
.58181 .56924 Mdot
.2311 .52269 Mdot
.3236 .38766 Mdot
.30316 .44654 Mdot
.65852 .43429 Mdot
.36158 .44673 Mdot
.49536 .31594 Mdot
.69319 .46614 Mdot
.62269 .32413 Mdot
.42869 .65619 Mdot
.63197 .28277 Mdot
.53607 .70936 Mdot
.40275 .60413 Mdot
.69775 .45896 Mdot
.33968 .41117 Mdot
.36417 .44394 Mdot
.4187 .696 Mdot
.25431 .44664 Mdot
.46929 .66553 Mdot
.64842 .31602 Mdot
.66449 .46038 Mdot
.4953 .14402 Mdot
.41052 .44539 Mdot
.44429 .68455 Mdot
.66502 .49891 Mdot
.4017 .42281 Mdot
.66354 .61845 Mdot
.35742 .39704 Mdot
.43891 .68782 Mdot
.35211 .45539 Mdot
.46013 .66132 Mdot
.70825 .47164 Mdot
.41636 .46068 Mdot
.41673 .43649 Mdot
.512 .2735 Mdot
.62449 .31827 Mdot
.47196 .649 Mdot
.48867 .31375 Mdot
.40923 .39511 Mdot
.44596 .26494 Mdot
.40377 .46302 Mdot
.35426 .62861 Mdot
.41107 .49741 Mdot
.5086 .58249 Mdot
.41899 .4099 Mdot
.37591 .44291 Mdot
.25694 .44254 Mdot
.32648 .53227 Mdot
.4122 .56958 Mdot
.6525 .61535 Mdot
.42479 .68649 Mdot
.69817 .46568 Mdot
.68264 .49231 Mdot
.6795 .44523 Mdot
.64057 .26228 Mdot
.33366 .46065 Mdot
.37283 .43607 Mdot
.65332 .60184 Mdot
.63892 .31782 Mdot
.44688 .6798 Mdot
.63944 .30708 Mdot
.48777 .36585 Mdot
.62986 .29781 Mdot
.50081 .59409 Mdot
.70074 .58732 Mdot
.22637 .56326 Mdot
.61992 .30489 Mdot
.46727 .66158 Mdot
.5194 .49978 Mdot
.33049 .382 Mdot
.51071 .82204 Mdot
.61919 .2855 Mdot
.63538 .49187 Mdot
.37944 .47051 Mdot
.46562 .32896 Mdot
.66261 .62856 Mdot
.63054 .2834 Mdot
.64632 .65822 Mdot
.34285 .41789 Mdot
.42988 .73736 Mdot
.43126 .67735 Mdot
.61354 .6385 Mdot
.41023 .39966 Mdot
.63129 .28273 Mdot
.69831 .45432 Mdot
.35973 .6284 Mdot
.60775 .63949 Mdot
.55671 .31359 Mdot
.47045 .27008 Mdot
.66813 .46641 Mdot
.3559 .59623 Mdot
.65771 .65977 Mdot
.32076 .42416 Mdot
.38712 .51855 Mdot
.37955 .38389 Mdot
.70527 .43238 Mdot
.69926 .44602 Mdot
.67997 .70156 Mdot
.41613 .43097 Mdot
.38599 .48528 Mdot
.46591 .62679 Mdot
.66606 .46552 Mdot
.4426 .64377 Mdot
.45462 .70307 Mdot
.71294 .4488 Mdot
.47104 .66457 Mdot
.63907 .29055 Mdot
.43801 .29583 Mdot
.65798 .66027 Mdot
.6717 .62201 Mdot
.69977 .45756 Mdot
.66368 .43855 Mdot
.69293 .43317 Mdot
.3845 .38982 Mdot
.45728 .64769 Mdot
.3697 .39774 Mdot
.40796 .45369 Mdot
.48958 .6087 Mdot
.477 .62811 Mdot
.39033 .39785 Mdot
.56415 .52779 Mdot
.61605 .28771 Mdot
.68714 .44884 Mdot
.62998 .64254 Mdot
.55445 .29297 Mdot
.66326 .66515 Mdot
.41329 .39621 Mdot
.50999 .80896 Mdot
.42366 .68125 Mdot
.62943 .31181 Mdot
.54615 .49338 Mdot
.63123 .30692 Mdot
.61459 .63575 Mdot
.43733 .62849 Mdot
.49759 .44004 Mdot
.41799 .43647 Mdot
.49218 .35333 Mdot
.48534 .22337 Mdot
.58218 .78617 Mdot
.62836 .63602 Mdot
.34016 .41991 Mdot
.51225 .57088 Mdot
.24795 .63019 Mdot
.37199 .4393 Mdot
.42999 .41611 Mdot
.5458 .47066 Mdot
.42494 .41856 Mdot
.40821 .6607 Mdot
.55456 .50133 Mdot
.33342 .44261 Mdot
.35888 .38506 Mdot
.78696 .65319 Mdot
.36684 .45842 Mdot
.41833 .44622 Mdot
.38902 .42799 Mdot
.36657 .39476 Mdot
.47639 .67256 Mdot
.57707 .49139 Mdot
.63249 .66249 Mdot
.43784 .29554 Mdot
.64623 .66026 Mdot
.70585 .45496 Mdot
.55963 .35999 Mdot
.47539 .66414 Mdot
.63082 .30666 Mdot
.59196 .5672 Mdot
.38655 .29191 Mdot
.70638 .47541 Mdot
.53328 .25766 Mdot
.61124 .31908 Mdot
.33732 .3738 Mdot
.64667 .32482 Mdot
.67193 .42068 Mdot
.66503 .62033 Mdot
.42545 .43778 Mdot
.44376 .63998 Mdot
.45325 .68681 Mdot
.38697 .38133 Mdot
.62981 .77656 Mdot
.66471 .61654 Mdot
.61914 .37419 Mdot
.37238 .45418 Mdot
.41126 .39811 Mdot
.47143 .66992 Mdot
.67137 .45881 Mdot
.52788 .51398 Mdot
.61571 .3112 Mdot
.39261 .40574 Mdot
.33455 .42481 Mdot
.488 .36387 Mdot
.643 .61607 Mdot
.49709 .58693 Mdot
.36932 .43204 Mdot
.49443 .39189 Mdot
.35898 .39483 Mdot
.34247 .38746 Mdot
.71849 .46183 Mdot
.4302 .37961 Mdot
.40929 .41623 Mdot
.45733 .72296 Mdot
.65777 .65882 Mdot
.44513 .66865 Mdot
.39816 .69181 Mdot
.50355 .56664 Mdot
.66335 .6471 Mdot
.39459 .39768 Mdot
.62878 .61681 Mdot
.34185 .42513 Mdot
.39958 .45586 Mdot
.62912 .63365 Mdot
.44414 .64577 Mdot
.5731 .65735 Mdot
.35591 .67879 Mdot
.34831 .42513 Mdot
.4068 .4319 Mdot
.65022 .33826 Mdot
.60042 .20909 Mdot
.41591 .42484 Mdot
.46694 .65568 Mdot
.40429 .42422 Mdot
.67724 .63829 Mdot
.64853 .30165 Mdot
.43595 .66973 Mdot
.67302 .47478 Mdot
.70633 .47218 Mdot
.64585 .48101 Mdot
.50139 .59434 Mdot
.38098 .48282 Mdot
.46146 .62077 Mdot
.4764 .62414 Mdot
.45212 .31003 Mdot
.68559 .45317 Mdot
.64693 .29725 Mdot
.3597 .43981 Mdot
.31671 .39421 Mdot
.61623 .64355 Mdot
.9066 .5499 Mdot
.49855 .43415 Mdot
.60414 .31643 Mdot
.57144 .3909 Mdot
.5006 .57238 Mdot
.37173 .46084 Mdot
.63788 .27853 Mdot
.71121 .45686 Mdot
.34096 .42322 Mdot
.39259 .49595 Mdot
.66931 .54118 Mdot
.67648 .43003 Mdot
.62142 .62206 Mdot
.68236 .48241 Mdot
.61417 .32612 Mdot
.50248 .59237 Mdot
.4339 .69263 Mdot
.38031 .44862 Mdot
.4501 .45302 Mdot
.67995 .46354 Mdot
.5196 .57455 Mdot
.40888 .46763 Mdot
.42392 .68882 Mdot
.67952 .45123 Mdot
.3955 .44132 Mdot
.25677 .63654 Mdot
.37601 .68799 Mdot
.67645 .47051 Mdot
.38002 .40797 Mdot
.28803 .41756 Mdot
.68155 .42835 Mdot
.67505 .42071 Mdot
.33876 .41977 Mdot
.6269 .28356 Mdot
.40299 .41334 Mdot
.66972 .62926 Mdot
.49353 .34071 Mdot
.6548 .64886 Mdot
.45973 .26292 Mdot
.33815 .40319 Mdot
.41878 .51818 Mdot
.44422 .71589 Mdot
.66108 .27523 Mdot
.27446 .30429 Mdot
.41792 .39978 Mdot
.41331 .75577 Mdot
.49132 .33444 Mdot
.50939 .44811 Mdot
.42142 .75645 Mdot
.61668 .30292 Mdot
.65585 .62287 Mdot
.41532 .45715 Mdot
.58194 .63561 Mdot
.62061 .29623 Mdot
.4577 .2626 Mdot
.36861 .40633 Mdot
.43931 .67939 Mdot
.37635 .45711 Mdot
.43253 .69007 Mdot
.3945 .4219 Mdot
.39586 .74907 Mdot
.64724 .24679 Mdot
.3675 .27652 Mdot
.33732 .3742 Mdot
.65788 .56816 Mdot
.34659 .64263 Mdot
.6427 .29665 Mdot
.34827 .43986 Mdot
.49423 .5826 Mdot
.65154 .6175 Mdot
.63419 .55832 Mdot
.69079 .43447 Mdot
.64811 .66456 Mdot
.44823 .65009 Mdot
.67581 .41631 Mdot
.51659 .56904 Mdot
.45771 .38401 Mdot
.63163 .28164 Mdot
.6654 .64594 Mdot
.3778 .44402 Mdot
.38539 .38449 Mdot
.70291 .54287 Mdot
.42599 .18079 Mdot
.46851 .6879 Mdot
.69059 .79136 Mdot
.44177 .62584 Mdot
.62916 .32172 Mdot
.71864 .45674 Mdot
.40071 .43754 Mdot
.37837 .42006 Mdot
.67473 .43191 Mdot
.41971 .6955 Mdot
.65686 .32279 Mdot
.58515 .22141 Mdot
.67555 .60951 Mdot
.43511 .19977 Mdot
.43246 .67141 Mdot
.4365 .19981 Mdot
.59358 .30607 Mdot
.41127 .61924 Mdot
.33886 .26875 Mdot
.64128 .62843 Mdot
.43445 .19906 Mdot
.43967 .68241 Mdot
.38746 .46808 Mdot
.50524 .57567 Mdot
.51556 .58493 Mdot
.42614 .66285 Mdot
.70785 .44158 Mdot
.61227 .31386 Mdot
.37486 .45434 Mdot
.46452 .41332 Mdot
.25328 .44837 Mdot
.66063 .45481 Mdot
.39913 .36025 Mdot
.63578 .63545 Mdot
.40367 .42585 Mdot
.65362 .28477 Mdot
.64402 .62829 Mdot
.49448 .5694 Mdot
.39191 .29215 Mdot
.37759 .41132 Mdot
.53685 .49144 Mdot
.6625 .63244 Mdot
.59432 .2074 Mdot
.41585 .43382 Mdot
.6575 .65978 Mdot
.45099 .4495 Mdot
.71431 .67674 Mdot
.54889 .51635 Mdot
.63061 .74571 Mdot
.64938 .46915 Mdot
.6879 .48334 Mdot
.5576 .14363 Mdot
.69035 .27043 Mdot
.62922 .65593 Mdot
.48816 .59939 Mdot
.43535 .1835 Mdot
.65135 .65741 Mdot
.40991 .4102 Mdot
.40094 .46564 Mdot
.35872 .63342 Mdot
.30943 .4063 Mdot
.5055 .59784 Mdot
.42732 .54221 Mdot
.36613 .46636 Mdot
.38446 .35631 Mdot
.41463 .45107 Mdot
.41014 .67201 Mdot
.63883 .63308 Mdot
.18366 .64055 Mdot
.64092 .6123 Mdot
.4154 .51628 Mdot
.67771 .4691 Mdot
.64625 .45391 Mdot
.38137 .44367 Mdot
.35487 .5161 Mdot
.36949 .82565 Mdot
.40556 .46485 Mdot
.54558 .49328 Mdot
.4735 .27066 Mdot
.3279 .44735 Mdot
.45007 .63563 Mdot
.45329 .43909 Mdot
.46924 .61877 Mdot
.64551 .62576 Mdot
.61738 .30119 Mdot
.65562 .26352 Mdot
.65876 .624 Mdot
.37876 .42128 Mdot
.65359 .26657 Mdot
.38822 .44886 Mdot
.36737 .45314 Mdot
.49033 .38326 Mdot
.65465 .2989 Mdot
.69903 .43303 Mdot
.6347 .31136 Mdot
.42604 .64957 Mdot
.77662 .72754 Mdot
.64227 .30283 Mdot
.35807 .6308 Mdot
.49331 .32214 Mdot
.44454 .19062 Mdot
.45287 .68876 Mdot
.64302 .32557 Mdot
.64761 .62156 Mdot
.49314 .46549 Mdot
.33847 .62977 Mdot
.66362 .66486 Mdot
.37086 .43478 Mdot
.47549 .67521 Mdot
.43916 .62857 Mdot
.67415 .66406 Mdot
.43703 .69556 Mdot
.35571 .48378 Mdot
.35844 .42421 Mdot
.63761 .66384 Mdot
.20602 .39024 Mdot
.67161 .61968 Mdot
.35705 .7116 Mdot
.36454 .47172 Mdot
.43777 .67072 Mdot
.35122 .63 Mdot
.40238 .71058 Mdot
.51348 .58459 Mdot
.42093 .43121 Mdot
.64516 .30127 Mdot
.45759 .30452 Mdot
.67278 .46842 Mdot
.50806 .80471 Mdot
.45252 .68416 Mdot
.68698 .65409 Mdot
.43502 .69478 Mdot
.44842 .69619 Mdot
.61398 .648 Mdot
.42429 .67867 Mdot
.39335 .41322 Mdot
.42163 .77889 Mdot
.46059 .68339 Mdot
.65402 .63386 Mdot
.64487 .31955 Mdot
.46773 .65821 Mdot
.60588 .37068 Mdot
.3619 .43518 Mdot
.66675 .48337 Mdot
.67392 .2954 Mdot
.44641 .70759 Mdot
.64363 .29595 Mdot
.68041 .45904 Mdot
.61233 .30151 Mdot
.58624 .64965 Mdot
.60939 .59276 Mdot
.28716 .35762 Mdot
.71664 .66673 Mdot
.41746 .65862 Mdot
.6586 .42148 Mdot
.38534 .40939 Mdot
.37078 .45411 Mdot
.64053 .26497 Mdot
.41784 .6461 Mdot
.64458 .77039 Mdot
.41991 .53108 Mdot
.61088 .78435 Mdot
.65028 .61507 Mdot
.59398 .35621 Mdot
.49876 .44061 Mdot
.6534 .68501 Mdot
.33566 .45125 Mdot
.50067 .57296 Mdot
.38931 .44164 Mdot
.50518 .2804 Mdot
.61343 .32382 Mdot
.7437 .54316 Mdot
.36648 .38617 Mdot
.67206 .43519 Mdot
.39558 .42516 Mdot
.57062 .56983 Mdot
.34819 .38914 Mdot
.62196 .28113 Mdot
.68052 .61386 Mdot
.46604 .65094 Mdot
.63466 .33006 Mdot
.70868 .47002 Mdot
.31736 .29679 Mdot
.40552 .40858 Mdot
.37046 .46809 Mdot
.68976 .42593 Mdot
.4422 .64205 Mdot
.70385 .45075 Mdot
.65702 .66057 Mdot
.63987 .30345 Mdot
.37503 .39167 Mdot
.39366 .35887 Mdot
.72377 .47977 Mdot
.62168 .63319 Mdot
.71233 .43313 Mdot
.6269 .61832 Mdot
.50483 .57241 Mdot
.33579 .39569 Mdot
.71431 .4317 Mdot
.33742 .45215 Mdot
.33464 .56506 Mdot
.39934 .29866 Mdot
.26389 .44093 Mdot
.70459 .43423 Mdot
.68676 .24808 Mdot
.64951 .62885 Mdot
.66672 .64843 Mdot
.36058 .72244 Mdot
.41226 .83613 Mdot
.52592 .50478 Mdot
.6826 .7596 Mdot
.6576 .66057 Mdot
.66353 .63652 Mdot
.70462 .4453 Mdot
.43 .64912 Mdot
.43493 .71435 Mdot
.70195 .42314 Mdot
.42194 .27258 Mdot
.44669 .68006 Mdot
.30674 .72234 Mdot
.65903 .46527 Mdot
.40337 .48235 Mdot
.3842 .64918 Mdot
.62082 .28284 Mdot
.4847 .28179 Mdot
.68061 .57216 Mdot
.39327 .43478 Mdot
.83255 .51017 Mdot
.69129 .43624 Mdot
.45657 .53535 Mdot
.68419 .60706 Mdot
.39231 .38958 Mdot
.39009 .42496 Mdot
.40046 .41735 Mdot
.61339 .28891 Mdot
.29781 .51754 Mdot
.39672 .43603 Mdot
.37809 .28365 Mdot
.43581 .42201 Mdot
.70431 .56058 Mdot
.63502 .31113 Mdot
.53817 .23595 Mdot
.6923 .41096 Mdot
.64186 .76145 Mdot
.42839 .41592 Mdot
.67029 .65035 Mdot
.57151 .54311 Mdot
.62614 .63759 Mdot
.64661 .69315 Mdot
.411 .20465 Mdot
.41501 .65245 Mdot
.37055 .38667 Mdot
.65695 .45228 Mdot
.45037 .71345 Mdot
.56935 .53649 Mdot
.76872 .73635 Mdot
.69006 .64301 Mdot
.61368 .86718 Mdot
.65464 .65293 Mdot
.51142 .5929 Mdot
.44535 .65121 Mdot
.29793 .47178 Mdot
.49137 .35677 Mdot
.44262 .64421 Mdot
.74048 .34532 Mdot
.46802 .61612 Mdot
.37968 .24783 Mdot
.48843 .66707 Mdot
.64907 .63649 Mdot
.67881 .66159 Mdot
.40277 .49607 Mdot
.40203 .41127 Mdot
.49866 .35292 Mdot
.30235 .44032 Mdot
.37483 .41349 Mdot
.69304 .46653 Mdot
.7179 .66372 Mdot
.58346 .63815 Mdot
.42588 .67242 Mdot
.61822 .64053 Mdot
.39327 .42532 Mdot
.34827 .4263 Mdot
.42836 .44229 Mdot
.57866 .27814 Mdot
.30013 .71813 Mdot
.40011 .45812 Mdot
.35125 .38463 Mdot
.71106 .47142 Mdot
.70608 .54177 Mdot
.72731 .73907 Mdot
.42007 .19741 Mdot
.40243 .47379 Mdot
.62889 .31842 Mdot
.65548 .28603 Mdot
.36921 .49306 Mdot
.31046 .48339 Mdot
.62577 .35992 Mdot
.37757 .44362 Mdot
.3402 .2868 Mdot
.69652 .49584 Mdot
.51201 .56476 Mdot
.68042 .46309 Mdot
.43834 .71771 Mdot
.51078 .56969 Mdot
.70164 .46792 Mdot
.3951 .2836 Mdot
.4941 .57451 Mdot
.7128 .68447 Mdot
.64531 .32271 Mdot
.4161 .44434 Mdot
.36944 .64165 Mdot
.66629 .46724 Mdot
.66672 .63839 Mdot
.44784 .65721 Mdot
.65635 .6158 Mdot
.70776 .59269 Mdot
.43927 .27116 Mdot
.50796 .58806 Mdot
.67114 .64936 Mdot
.53308 .49156 Mdot
.63206 .31767 Mdot
.64734 .65351 Mdot
.41205 .52339 Mdot
.41204 .3858 Mdot
.3263 .78082 Mdot
.36288 .45885 Mdot
.6687 .7021 Mdot
.66944 .64322 Mdot
.50364 .56301 Mdot
.3812 .45036 Mdot
.65417 .46456 Mdot
.44327 .36858 Mdot
.38974 .44946 Mdot
.67365 .47863 Mdot
.39566 .46494 Mdot
.6504 .28602 Mdot
.43366 .62843 Mdot
.48876 .32958 Mdot
.55858 .32841 Mdot
.61397 .32144 Mdot
.42935 .31794 Mdot
.4166 .42545 Mdot
.70645 .31817 Mdot
.44194 .67748 Mdot
.41473 .39772 Mdot
.46465 .25366 Mdot
.42431 .65717 Mdot
.45554 .66293 Mdot
.35389 .45263 Mdot
.67761 .62541 Mdot
.6977 .43027 Mdot
.63314 .31585 Mdot
.61048 .66172 Mdot
.39712 .44059 Mdot
.34077 .41849 Mdot
.61629 .32548 Mdot
.66395 .64367 Mdot
.3806 .39254 Mdot
.54415 .76469 Mdot
.43067 .29757 Mdot
.61799 .63081 Mdot
.40903 .38437 Mdot
.32608 .74676 Mdot
.43342 .70036 Mdot
.83296 .50651 Mdot
.64916 .24818 Mdot
.71544 .4514 Mdot
.41977 .36912 Mdot
.88402 .59266 Mdot
.64747 .31746 Mdot
.60647 .78005 Mdot
.38797 .46652 Mdot
.40485 .43916 Mdot
.4124 .66558 Mdot
.37674 .397 Mdot
.424 .68465 Mdot
.58031 .34475 Mdot
.43189 .84218 Mdot
.4467 .69238 Mdot
.43404 .687 Mdot
.32926 .48705 Mdot
.62566 .24543 Mdot
.43134 .65552 Mdot
.40268 .40777 Mdot
.73081 .31912 Mdot
.33652 .48141 Mdot
.63758 .33763 Mdot
.62427 .35542 Mdot
.45889 .63759 Mdot
.33289 .64526 Mdot
.33686 .49252 Mdot
.30537 .69655 Mdot
.63718 .3645 Mdot
.63482 .65781 Mdot
.34028 .4381 Mdot
.49001 .59977 Mdot
.6847 .44743 Mdot
.45316 .42208 Mdot
.41541 .43485 Mdot
.4381 .63906 Mdot
.60585 .31396 Mdot
.64621 .65619 Mdot
.34574 .4586 Mdot
.70582 .49632 Mdot
.61626 .31729 Mdot
.46717 .67666 Mdot
.34423 .68029 Mdot
.65182 .26569 Mdot
.40546 .36064 Mdot
.38635 .46981 Mdot
.37024 .47796 Mdot
.33014 .37934 Mdot
.65889 .62522 Mdot
.68391 .41822 Mdot
.4089 .36214 Mdot
.49374 .41899 Mdot
.43204 .28957 Mdot
.42495 .45729 Mdot
.46736 .65663 Mdot
.63918 .6195 Mdot
.49865 .59208 Mdot
.44171 .18618 Mdot
.3855 .47454 Mdot
.30706 .72356 Mdot
.56694 .26059 Mdot
.49125 .58572 Mdot
.4583 .70782 Mdot
.63071 .31116 Mdot
.35698 .46306 Mdot
.37633 .28134 Mdot
.3743 .41087 Mdot
.32092 .43273 Mdot
.7111 .44182 Mdot
.63438 .65326 Mdot
.29555 .35068 Mdot
.68853 .44608 Mdot
.45456 .66245 Mdot
.27292 .68821 Mdot
.4396 .71202 Mdot
.45608 .70202 Mdot
.44777 .59233 Mdot
.67195 .62628 Mdot
.88956 .58359 Mdot
.61654 .21373 Mdot
.42319 .45314 Mdot
.66976 .65772 Mdot
.43566 .65634 Mdot
.3988 .40167 Mdot
.42365 .68215 Mdot
.45587 .63426 Mdot
.35992 .43196 Mdot
.36212 .4257 Mdot
.36353 .27743 Mdot
.32135 .73008 Mdot
.64653 .30868 Mdot
.41768 .69222 Mdot
.32265 .70386 Mdot
.40154 .44018 Mdot
.40945 .41919 Mdot
.57298 .54604 Mdot
.63426 .33186 Mdot
.20829 .55293 Mdot
.37592 .45931 Mdot
.51487 .26931 Mdot
.41282 .4152 Mdot
.42274 .71764 Mdot
.64725 .67245 Mdot
.41256 .51957 Mdot
.71454 .43796 Mdot
.42002 .69685 Mdot
.60784 .3056 Mdot
.4675 .70187 Mdot
.23071 .58522 Mdot
.65659 .62027 Mdot
.43867 .68776 Mdot
.66971 .41771 Mdot
.65768 .64457 Mdot
.67251 .62129 Mdot
.56884 .53343 Mdot
.65713 .42979 Mdot
.60497 .31966 Mdot
.63414 .64189 Mdot
.2613 .64073 Mdot
.65021 .63913 Mdot
.22553 .58645 Mdot
.40043 .47854 Mdot
.38022 .28399 Mdot
.45233 .41315 Mdot
.39647 .49712 Mdot
.64347 .64541 Mdot
.61509 .3193 Mdot
.38773 .39338 Mdot
.45017 .69406 Mdot
.63984 .32086 Mdot
.40693 .59904 Mdot
.65366 .43062 Mdot
.45734 .62351 Mdot
.6328 .61276 Mdot
.41462 .67471 Mdot
.476 .27421 Mdot
.62195 .35115 Mdot
.58691 .53697 Mdot
.485 .34982 Mdot
.35838 .35998 Mdot
.36726 .38309 Mdot
.39121 .39316 Mdot
.3908 .41449 Mdot
.67822 .47084 Mdot
.62447 .2733 Mdot
.46949 .66101 Mdot
.23643 .41877 Mdot
.67032 .63679 Mdot
.54693 .5001 Mdot
.3331 .37701 Mdot
.34208 .42269 Mdot
.43743 .65779 Mdot
.46281 .63539 Mdot
.3179 .52631 Mdot
.68106 .43074 Mdot
.36258 .49657 Mdot
.42716 .41939 Mdot
.31656 .33619 Mdot
.64689 .64675 Mdot
.60269 .74176 Mdot
.68172 .49396 Mdot
.62518 .86571 Mdot
.68919 .4478 Mdot
.5919 .46501 Mdot
.4215 .67688 Mdot
.63457 .29397 Mdot
.36939 .4287 Mdot
.42913 .55015 Mdot
.47722 .67421 Mdot
.69063 .52637 Mdot
.63028 .30413 Mdot
.62419 .69965 Mdot
.66226 .66208 Mdot
.34477 .45831 Mdot
.41222 .41403 Mdot
.35603 .40907 Mdot
.3847 .40136 Mdot
.62817 .65733 Mdot
.36607 .4155 Mdot
.60905 .63796 Mdot
.22929 .57441 Mdot
.45783 .25079 Mdot
.66713 .42688 Mdot
.72946 .53119 Mdot
.45675 .70001 Mdot
.21843 .61467 Mdot
.21687 .55431 Mdot
.40024 .29851 Mdot
.60223 .6678 Mdot
.3296 .43404 Mdot
.70484 .4403 Mdot
.58669 .61874 Mdot
.66323 .43105 Mdot
.22082 .69722 Mdot
.35657 .63736 Mdot
.65532 .70653 Mdot
.36202 .40586 Mdot
.70046 .42567 Mdot
.32889 .66502 Mdot
.42494 .36616 Mdot
.65488 .2688 Mdot
.23978 .608 Mdot
.41296 .57589 Mdot
.64953 .30348 Mdot
.3624 .44294 Mdot
.4775 .6293 Mdot
.37269 .42507 Mdot
.36627 .43214 Mdot
.40221 .4693 Mdot
.62174 .66064 Mdot
.40789 .47617 Mdot
.39835 .41214 Mdot
.45404 .1578 Mdot
.74446 .47366 Mdot
.68804 .48456 Mdot
.27256 .45522 Mdot
.63912 .31776 Mdot
.4389 .71796 Mdot
.48793 .33569 Mdot
.67362 .63961 Mdot
.31337 .52273 Mdot
.35238 .4375 Mdot
.55995 .79619 Mdot
.66717 .6124 Mdot
.6211 .2888 Mdot
.48991 .59717 Mdot
.61632 .712 Mdot
.72117 .46406 Mdot
.4985 .5998 Mdot
.66973 .46574 Mdot
.25325 .38065 Mdot
.4283 .68658 Mdot
.35887 .35981 Mdot
.64049 .653 Mdot
.65721 .43676 Mdot
.37316 .28442 Mdot
.40796 .42503 Mdot
.70545 .43434 Mdot
.43409 .37881 Mdot
.4618 .30371 Mdot
.49173 .33724 Mdot
.66965 .42009 Mdot
.67836 .61446 Mdot
.65208 .64655 Mdot
.65078 .30841 Mdot
.43443 .69893 Mdot
.4397 .64106 Mdot
.6479 .64183 Mdot
.80584 .61876 Mdot
.39541 .43956 Mdot
.40556 .45328 Mdot
.49571 .43195 Mdot
.40977 .40422 Mdot
.64323 .34391 Mdot
.50933 .59696 Mdot
.45246 .64028 Mdot
.39092 .3937 Mdot
.37929 .39264 Mdot
.37907 .469 Mdot
.41178 .26991 Mdot
.67756 .46307 Mdot
.36591 .467 Mdot
.63451 .27978 Mdot
.40904 .59113 Mdot
.38851 .40898 Mdot
.40524 .35965 Mdot
.42145 .68315 Mdot
.62983 .49965 Mdot
.66751 .63641 Mdot
.66131 .44974 Mdot
.65826 .45101 Mdot
.47324 .2248 Mdot
.4226 .70421 Mdot
.5028 .5993 Mdot
.6823 .55597 Mdot
.49847 .59456 Mdot
.62917 .30206 Mdot
.54154 .51572 Mdot
.65368 .41584 Mdot
.68587 .48393 Mdot
.68074 .66449 Mdot
.40114 .38793 Mdot
.392 .40798 Mdot
.63513 .76758 Mdot
.40688 .46147 Mdot
.6466 .30287 Mdot
.67927 .64314 Mdot
.43686 .68575 Mdot
.64913 .2798 Mdot
.66326 .65204 Mdot
.4443 .64305 Mdot
.43835 .43906 Mdot
.40667 .40794 Mdot
.45222 .65797 Mdot
.46418 .68244 Mdot
.38204 .43465 Mdot
.38941 .21254 Mdot
.46081 .64324 Mdot
.44787 .65444 Mdot
.41115 .5856 Mdot
.71623 .47188 Mdot
.43952 .36291 Mdot
.67586 .64153 Mdot
.39961 .41364 Mdot
.67195 .42451 Mdot
.62184 .30623 Mdot
.46238 .67064 Mdot
.33891 .44026 Mdot
.3986 .44697 Mdot
.6289 .31736 Mdot
.65415 .31531 Mdot
.63507 .32815 Mdot
.67031 .66545 Mdot
.35659 .43083 Mdot
.43796 .65185 Mdot
.65585 .66486 Mdot
.64498 .26937 Mdot
.64243 .33082 Mdot
.34497 .2568 Mdot
.39051 .43519 Mdot
.65781 .28705 Mdot
.79305 .71272 Mdot
.34407 .2737 Mdot
.5156 .57061 Mdot
.65975 .49078 Mdot
.6872 .24396 Mdot
.67452 .29176 Mdot
.62968 .65174 Mdot
.55139 .49757 Mdot
.61421 .3304 Mdot
.35167 .46273 Mdot
.4118 .4395 Mdot
.35166 .36706 Mdot
.63685 .32208 Mdot
.43945 .26985 Mdot
.41162 .65731 Mdot
.24012 .51034 Mdot
.63935 .31747 Mdot
.65766 .43274 Mdot
.72217 .48373 Mdot
.69646 .44606 Mdot
.33367 .39952 Mdot
.24509 .38698 Mdot
.2637 .61958 Mdot
.2063 .54213 Mdot
.66385 .6601 Mdot
.46012 .63421 Mdot
.39458 .62597 Mdot
.4564 .66364 Mdot
.67678 .44633 Mdot
.61503 .31555 Mdot
.41337 .65947 Mdot
.67021 .62031 Mdot
.64841 .64585 Mdot
.7209 .44274 Mdot
.68334 .45799 Mdot
.69794 .45682 Mdot
.42443 .69806 Mdot
.42263 .6778 Mdot
.36514 .3976 Mdot
.46268 .67686 Mdot
.58878 .25063 Mdot
.57645 .31272 Mdot
.72847 .4569 Mdot
.65711 .62902 Mdot
.46041 .65524 Mdot
.41671 .44622 Mdot
.5579 .4603 Mdot
.69803 .4101 Mdot
.62648 .27775 Mdot
.44867 .79982 Mdot
.40957 .84371 Mdot
.36438 .3892 Mdot
.62069 .63879 Mdot
.38273 .52218 Mdot
.39222 .41685 Mdot
.71484 .44346 Mdot
.56848 .23682 Mdot
.48984 .58188 Mdot
.37719 .41662 Mdot
.43661 .44458 Mdot
.65496 .61826 Mdot
.48636 .33658 Mdot
.3465 .45778 Mdot
.56885 .51146 Mdot
.68146 .61793 Mdot
.68708 .49417 Mdot
.59603 .15639 Mdot
.44903 .54548 Mdot
.51523 .29505 Mdot
.50915 .5667 Mdot
.39104 .47648 Mdot
.6906 .46858 Mdot
.6373 .27452 Mdot
.68937 .46281 Mdot
.44269 .72049 Mdot
.72002 .46482 Mdot
.41014 .4616 Mdot
.43378 .65253 Mdot
.66451 .646 Mdot
.52568 .45468 Mdot
.25773 .40241 Mdot
.65611 .46868 Mdot
.52036 .57349 Mdot
.36292 .42538 Mdot
.25633 .642 Mdot
.40136 .49743 Mdot
.40776 .41496 Mdot
.62801 .63545 Mdot
.42963 .66546 Mdot
.64749 .6159 Mdot
.44905 .37888 Mdot
.43234 .74672 Mdot
.66845 .63183 Mdot
.4449 .52657 Mdot
.61174 .32059 Mdot
.43127 .27239 Mdot
.37656 .45081 Mdot
.64062 .65425 Mdot
.3578 .44405 Mdot
.41551 .69048 Mdot
.4118 .28873 Mdot
.42354 .30147 Mdot
.63606 .63293 Mdot
.55626 .59927 Mdot
.4862 .31231 Mdot
.43843 .36158 Mdot
.65047 .66096 Mdot
.26918 .31723 Mdot
.49402 .58681 Mdot
.61701 .31297 Mdot
.65344 .32011 Mdot
.63246 .28782 Mdot
.40891 .45205 Mdot
.3313 .72277 Mdot
.65263 .30838 Mdot
.68704 .63383 Mdot
.64833 .28879 Mdot
.5568 .30629 Mdot
.63339 .77506 Mdot
.61242 .31979 Mdot
.38276 .45669 Mdot
.42565 .50347 Mdot
.54764 .4958 Mdot
.65028 .46679 Mdot
.56663 .68604 Mdot
.46243 .15447 Mdot
.40015 .43648 Mdot
.39687 .7511 Mdot
.41477 .72666 Mdot
.59723 .43375 Mdot
.41496 .30237 Mdot
.51937 .47845 Mdot
.45547 .65383 Mdot
.48605 .34294 Mdot
.47547 .66909 Mdot
.35532 .35989 Mdot
.39898 .4569 Mdot
.41988 .69753 Mdot
.49679 .80317 Mdot
.25965 .31438 Mdot
.59515 .79203 Mdot
.45698 .64678 Mdot
.6578 .65871 Mdot
.62454 .63642 Mdot
.62794 .63731 Mdot
.68519 .47509 Mdot
.4385 .68997 Mdot
.37623 .47424 Mdot
.71264 .46422 Mdot
.36677 .44258 Mdot
.64141 .63541 Mdot
.40698 .299 Mdot
.43393 .68598 Mdot
.37658 .44395 Mdot
.32503 .68417 Mdot
.66854 .46112 Mdot
.63167 .31922 Mdot
.43615 .79086 Mdot
.64378 .46908 Mdot
.66093 .60981 Mdot
.44573 .72174 Mdot
.71382 .50142 Mdot
.57869 .48756 Mdot
.41948 .4636 Mdot
.42482 .43905 Mdot
.55623 .49521 Mdot
.34976 .65404 Mdot
.33556 .44293 Mdot
.70752 .47117 Mdot
.70423 .48098 Mdot
.35986 .44865 Mdot
.44328 .691 Mdot
.61665 .33663 Mdot
.64687 .26276 Mdot
.3215 .40677 Mdot
.49214 .34919 Mdot
.3788 .28404 Mdot
.39115 .39666 Mdot
.38552 .36344 Mdot
.66641 .41839 Mdot
.51514 .56791 Mdot
.48765 .36093 Mdot
.63987 .29024 Mdot
.38234 .46555 Mdot
.25759 .45294 Mdot
.45189 .68345 Mdot
.70281 .43256 Mdot
.63678 .66578 Mdot
.6528 .26653 Mdot
.72657 .46232 Mdot
.35993 .44877 Mdot
.38031 .39266 Mdot
.64398 .65298 Mdot
.4221 .71644 Mdot
.62364 .3249 Mdot
.71261 .46577 Mdot
.63734 .29308 Mdot
.42619 .67995 Mdot
.46482 .66386 Mdot
.42972 .4394 Mdot
.38645 .49997 Mdot
.65799 .46732 Mdot
.32393 .42556 Mdot
.70881 .45541 Mdot
.70322 .543 Mdot
.61629 .64414 Mdot
.41744 .40167 Mdot
.42036 .70688 Mdot
.64282 .63842 Mdot
.39777 .43173 Mdot
.56233 .49618 Mdot
.36026 .39581 Mdot
.69459 .42202 Mdot
.57357 .21846 Mdot
.62273 .29778 Mdot
.44131 .46161 Mdot
.39027 .5562 Mdot
.40562 .40178 Mdot
.67846 .48714 Mdot
.25826 .62767 Mdot
.66589 .62694 Mdot
.41977 .66978 Mdot
.63264 .44299 Mdot
.65291 .63585 Mdot
.38493 .46125 Mdot
.64238 .30379 Mdot
.47203 .66089 Mdot
.51167 .57623 Mdot
.50381 .37116 Mdot
.44879 .47235 Mdot
.3383 .47924 Mdot
.33847 .44978 Mdot
.67898 .76395 Mdot
.6953 .4587 Mdot
.43781 .65626 Mdot
.62095 .64269 Mdot
.66177 .62113 Mdot
.67107 .45846 Mdot
.41804 .57168 Mdot
.54022 .81314 Mdot
.82619 .677 Mdot
.72728 .46465 Mdot
.64069 .2847 Mdot
.41164 .28992 Mdot
.69711 .44469 Mdot
.67499 .47251 Mdot
.66829 .41465 Mdot
.64226 .7651 Mdot
.45186 .64657 Mdot
.39973 .44696 Mdot
.37883 .71452 Mdot
.40131 .46875 Mdot
.5148 .30597 Mdot
.64234 .63466 Mdot
.41945 .67006 Mdot
.58792 .36504 Mdot
.35264 .38693 Mdot
.38452 .42216 Mdot
.61664 .37562 Mdot
.33147 .49349 Mdot
.43971 .19166 Mdot
.42334 .4215 Mdot
.68356 .4668 Mdot
.39468 .65571 Mdot
.4043 .36081 Mdot
.32514 .68708 Mdot
.65434 .64919 Mdot
.50882 .58862 Mdot
.37795 .35474 Mdot
.35333 .37021 Mdot
.47476 .67189 Mdot
.41468 .65588 Mdot
.64903 .32229 Mdot
.43074 .77788 Mdot
.65796 .64946 Mdot
.62528 .74124 Mdot
.40822 .41457 Mdot
.65207 .69332 Mdot
.57971 .22775 Mdot
.39201 .42905 Mdot
.56691 .52989 Mdot
.31836 .52641 Mdot
.33731 .42901 Mdot
.21003 .53108 Mdot
.65132 .63049 Mdot
.48168 .26125 Mdot
.3676 .40949 Mdot
.70646 .43668 Mdot
.4257 .65179 Mdot
.45916 .62302 Mdot
.64036 .27327 Mdot
.61184 .231 Mdot
.48843 .85874 Mdot
.41867 .67003 Mdot
.4078 .42307 Mdot
.66536 .6339 Mdot
.51247 .58271 Mdot
.45449 .43145 Mdot
.56953 .58403 Mdot
.45277 .68155 Mdot
.42185 .36621 Mdot
.55545 .79894 Mdot
.48666 .33974 Mdot
.22859 .6441 Mdot
.63024 .63827 Mdot
.64583 .29277 Mdot
.31359 .43942 Mdot
.6899 .5544 Mdot
.40848 .40885 Mdot
.51432 .30208 Mdot
.39784 .66961 Mdot
.64739 .29924 Mdot
.38104 .42071 Mdot
.33351 .43714 Mdot
.44608 .32767 Mdot
.6405 .33759 Mdot
.34018 .45003 Mdot
.36307 .38846 Mdot
.42021 .65384 Mdot
.511 .59561 Mdot
.4396 .68481 Mdot
.37266 .42676 Mdot
.55442 .20094 Mdot
.41664 .68726 Mdot
.56898 .6662 Mdot
.63428 .25562 Mdot
.67352 .64137 Mdot
.43397 .3846 Mdot
.40957 .47162 Mdot
.22719 .65526 Mdot
.51405 .58466 Mdot
.7464 .6918 Mdot
.6951 .42418 Mdot
.40913 .17203 Mdot
.64222 .46455 Mdot
.59447 .66751 Mdot
.63945 .54712 Mdot
.39999 .36177 Mdot
.41489 .56796 Mdot
.20095 .54143 Mdot
.65247 .60183 Mdot
.21169 .6043 Mdot
.40183 .41119 Mdot
.38132 .46767 Mdot
.71026 .45072 Mdot
.62359 .68621 Mdot
.41349 .51948 Mdot
.48819 .35989 Mdot
.61816 .2929 Mdot
.44638 .67043 Mdot
.41351 .44313 Mdot
.48067 .79907 Mdot
.65259 .44703 Mdot
.26429 .42128 Mdot
.37802 .44748 Mdot
.37156 .51832 Mdot
.60546 .67298 Mdot
.66613 .64517 Mdot
.67094 .41907 Mdot
.65492 .43482 Mdot
.39416 .47445 Mdot
.63263 .66186 Mdot
.35317 .40776 Mdot
.47935 .30696 Mdot
.42865 .37491 Mdot
.62593 .30463 Mdot
.41668 .43124 Mdot
.35007 .52191 Mdot
.1573 .45828 Mdot
.36893 .384 Mdot
.45144 .70542 Mdot
.70154 .45739 Mdot
.676 .45776 Mdot
.44311 .64064 Mdot
.67549 .45709 Mdot
.24141 .51572 Mdot
.33186 .72969 Mdot
.63135 .29921 Mdot
.23711 .56187 Mdot
.61902 .29763 Mdot
.50756 .5898 Mdot
.38768 .43458 Mdot
.7859 .49088 Mdot
.72406 .47199 Mdot
.55441 .2938 Mdot
.6473 .6395 Mdot
.51422 .58665 Mdot
.36108 .42493 Mdot
.64642 .36168 Mdot
.68821 .44008 Mdot
.47972 .53681 Mdot
.39758 .4696 Mdot
.42124 .69552 Mdot
.3397 .42775 Mdot
.31017 .46467 Mdot
.50844 .59658 Mdot
.33471 .41844 Mdot
.6634 .65199 Mdot
.42607 .68927 Mdot
.66361 .70994 Mdot
.66854 .46986 Mdot
.37072 .41959 Mdot
.405 .42066 Mdot
.4736 .65181 Mdot
.42252 .45312 Mdot
.64127 .66425 Mdot
.91323 .51291 Mdot
.62825 .32994 Mdot
.51385 .56689 Mdot
.53595 .70939 Mdot
.33352 .42107 Mdot
.38214 .38975 Mdot
.50502 .50236 Mdot
.25397 .4471 Mdot
.67082 .64594 Mdot
.33727 .47422 Mdot
.69842 .48203 Mdot
.62065 .32419 Mdot
.66622 .61625 Mdot
.35933 .42217 Mdot
.39773 .46437 Mdot
.64644 .2994 Mdot
.60494 .37474 Mdot
.65803 .31862 Mdot
.63057 .65547 Mdot
.49799 .67947 Mdot
.5595 .45954 Mdot
.39068 .44336 Mdot
.52287 .57152 Mdot
.43398 .66418 Mdot
.64821 .66222 Mdot
.29638 .52038 Mdot
.35327 .3609 Mdot
.62435 .6177 Mdot
.66323 .64723 Mdot
.41675 .46593 Mdot
.42237 .70299 Mdot
.44217 .72454 Mdot
.43597 .66091 Mdot
.46096 .24457 Mdot
.73025 .69612 Mdot
.69841 .46054 Mdot
.65721 .63122 Mdot
.67288 .42608 Mdot
.61543 .33 Mdot
.44219 .29239 Mdot
.65065 .45522 Mdot
.40599 .68651 Mdot
.66174 .43497 Mdot
.35566 .40409 Mdot
.6772 .62876 Mdot
.66052 .46815 Mdot
.3926 .40065 Mdot
.33204 .39122 Mdot
.3083 .40721 Mdot
.60801 .32639 Mdot
.49014 .34289 Mdot
.37634 .45494 Mdot
.49056 .59625 Mdot
.37993 .43918 Mdot
.63821 .66372 Mdot
.52643 .44245 Mdot
.36181 .45967 Mdot
.72427 .47196 Mdot
.73424 .70668 Mdot
.70287 .48446 Mdot
.29076 .40437 Mdot
.37062 .4362 Mdot
.39175 .44059 Mdot
.36055 .42848 Mdot
.40691 .58468 Mdot
.64425 .61002 Mdot
.32951 .45916 Mdot
.7109 .43157 Mdot
.45872 .6633 Mdot
.41063 .68174 Mdot
.51545 .50745 Mdot
.49605 .60039 Mdot
.65108 .66676 Mdot
.39351 .44031 Mdot
.48214 .53688 Mdot
.50234 .41001 Mdot
.57004 .8013 Mdot
.65957 .49477 Mdot
.67867 .48387 Mdot
.44846 .69851 Mdot
.68757 .48023 Mdot
.36193 .41987 Mdot
.41915 .36548 Mdot
.66004 .71022 Mdot
.69261 .61588 Mdot
.6197 .3226 Mdot
.36746 .43781 Mdot
.39233 .26901 Mdot
.71112 .4713 Mdot
.66332 .42142 Mdot
.35327 .4087 Mdot
.40467 .72014 Mdot
.18709 .38754 Mdot
.67084 .65724 Mdot
.27074 .65832 Mdot
.36173 .70345 Mdot
.35463 .31849 Mdot
.65933 .62328 Mdot
.56498 .52402 Mdot
.65291 .47282 Mdot
.55302 .18595 Mdot
.45756 .65935 Mdot
.6224 .32375 Mdot
.3996 .40458 Mdot
.40529 .68571 Mdot
.72938 .4479 Mdot
.47083 .65415 Mdot
.37394 .35592 Mdot
.67072 .61487 Mdot
.68221 .45064 Mdot
.67791 .66377 Mdot
.44851 .71523 Mdot
.62013 .29753 Mdot
.51206 .27413 Mdot
.25267 .6337 Mdot
.32531 .53126 Mdot
.36549 .46722 Mdot
.74895 .44116 Mdot
.37515 .47464 Mdot
.43347 .63082 Mdot
.37713 .45168 Mdot
.3844 .37479 Mdot
.64717 .46228 Mdot
.42558 .45633 Mdot
.41317 .42252 Mdot
.3239 .69158 Mdot
.38799 .42619 Mdot
.36362 .45387 Mdot
.43053 .44406 Mdot
.41461 .69634 Mdot
.42731 .44895 Mdot
.43222 .69697 Mdot
.58866 .78725 Mdot
.668 .46722 Mdot
.61771 .33169 Mdot
.61463 .32676 Mdot
.521 .29973 Mdot
.39863 .2693 Mdot
.3805 .65856 Mdot
.45144 .67739 Mdot
.64466 .64548 Mdot
.35847 .40215 Mdot
.2829 .29013 Mdot
.54642 .20619 Mdot
.66845 .48799 Mdot
.65622 .45873 Mdot
.38662 .40516 Mdot
.39437 .83795 Mdot
.42166 .42123 Mdot
.49801 .43602 Mdot
.40831 .45318 Mdot
.41572 .40031 Mdot
.67705 .41545 Mdot
.4782 .27571 Mdot
.3662 .46715 Mdot
.47478 .67291 Mdot
.621 .32072 Mdot
.35774 .51227 Mdot
.54318 .22638 Mdot
.35311 .70563 Mdot
.40944 .53719 Mdot
.35583 .44645 Mdot
.71589 .45691 Mdot
.4637 .65015 Mdot
.49665 .41767 Mdot
.65265 .6645 Mdot
.50333 .35591 Mdot
.22324 .57779 Mdot
.64527 .60124 Mdot
.61704 .31863 Mdot
.72828 .43609 Mdot
.40011 .47346 Mdot
.69244 .47179 Mdot
.32635 .44376 Mdot
.50584 .41526 Mdot
.62835 .30011 Mdot
.46262 .61533 Mdot
.65936 .65788 Mdot
.40483 .67682 Mdot
.26409 .44158 Mdot
.54799 .20364 Mdot
.41596 .16615 Mdot
.7201 .47371 Mdot
.22891 .45173 Mdot
.42563 .66216 Mdot
.38867 .47544 Mdot
.82394 .67883 Mdot
.43293 .67003 Mdot
.4202 .6956 Mdot
.51536 .41613 Mdot
.46176 .26287 Mdot
.32493 .43107 Mdot
.46161 .64255 Mdot
.7287 .43748 Mdot
.63223 .307 Mdot
.38463 .39937 Mdot
.38185 .35531 Mdot
.4131 .66142 Mdot
.68173 .44185 Mdot
.49439 .29272 Mdot
.68264 .46289 Mdot
.44523 .64707 Mdot
.6653 .44921 Mdot
.58042 .66381 Mdot
.65128 .4573 Mdot
.41934 .45084 Mdot
.39319 .44119 Mdot
.48357 .56399 Mdot
.46483 .66389 Mdot
.38317 .39013 Mdot
.39095 .46671 Mdot
.43383 .6549 Mdot
.66113 .40819 Mdot
.25989 .47087 Mdot
.37837 .38803 Mdot
.39755 .44272 Mdot
.63023 .33166 Mdot
.47371 .31903 Mdot
.49802 .46206 Mdot
.3948 .3997 Mdot
.63384 .28584 Mdot
.42585 .69801 Mdot
.37997 .43674 Mdot
.48106 .27633 Mdot
.69956 .49576 Mdot
.355 .41728 Mdot
.51018 .57963 Mdot
.38211 .47911 Mdot
.19174 .41815 Mdot
.36568 .42179 Mdot
.44878 .65092 Mdot
.42571 .6547 Mdot
.63853 .42964 Mdot
.45202 .66154 Mdot
.51506 .57097 Mdot
.65129 .64562 Mdot
.24593 .65224 Mdot
.51701 .57447 Mdot
.33739 .41818 Mdot
.62141 .21562 Mdot
.391 .35635 Mdot
.4283 .36684 Mdot
.63072 .2429 Mdot
.50846 .56725 Mdot
.42611 .66928 Mdot
.4916 .79332 Mdot
.36629 .48551 Mdot
.65435 .66639 Mdot
.40044 .3595 Mdot
.35447 .41866 Mdot
.39299 .37626 Mdot
.44239 .74103 Mdot
.66594 .66397 Mdot
.44189 .36405 Mdot
.38434 .39922 Mdot
.25508 .44832 Mdot
.41375 .43615 Mdot
.61684 .28967 Mdot
.43363 .68271 Mdot
.69065 .47792 Mdot
.62719 .30709 Mdot
.34062 .45219 Mdot
.63963 .31882 Mdot
.69498 .46817 Mdot
.63509 .64702 Mdot
.41813 .45461 Mdot
.63512 .3391 Mdot
.61362 .30946 Mdot
.34774 .44532 Mdot
.41943 .66121 Mdot
.40459 .4972 Mdot
.38146 .43377 Mdot
.35834 .43221 Mdot
.43717 .64192 Mdot
.83403 .47549 Mdot
.37801 .46741 Mdot
.56679 .52528 Mdot
.4422 .62528 Mdot
.51429 .59182 Mdot
.70175 .47558 Mdot
.35053 .39767 Mdot
.66775 .62266 Mdot
.65093 .64403 Mdot
.71753 .48271 Mdot
.41612 .65498 Mdot
.67833 .45177 Mdot
.37 .38301 Mdot
.40992 .3625 Mdot
.39483 .40401 Mdot
.64761 .40309 Mdot
.6086 .70205 Mdot
.46996 .67036 Mdot
.68183 .4883 Mdot
.49696 .35536 Mdot
.67701 .6342 Mdot
.68543 .41296 Mdot
.47916 .65242 Mdot
.43055 .64125 Mdot
.45107 .64184 Mdot
.62813 .28509 Mdot
.68641 .4516 Mdot
.45747 .71341 Mdot
.4706 .69717 Mdot
.34818 .42437 Mdot
.37845 .39839 Mdot
.43175 .69987 Mdot
.65569 .5232 Mdot
.61913 .30563 Mdot
.71768 .46015 Mdot
.17148 .40774 Mdot
.66723 .66086 Mdot
.32481 .69096 Mdot
.39898 .40122 Mdot
.65397 .85771 Mdot
.42205 .42135 Mdot
.41082 .42695 Mdot
.43832 .71771 Mdot
.65517 .31944 Mdot
.63492 .30747 Mdot
.42517 .66153 Mdot
.45164 .63455 Mdot
.62928 .27647 Mdot
.52057 .46645 Mdot
.20076 .39704 Mdot
.49741 .40388 Mdot
.46983 .6644 Mdot
.23897 .62178 Mdot
.63755 .62741 Mdot
.4132 .64365 Mdot
.60351 .59572 Mdot
.66366 .46083 Mdot
.6541 .46301 Mdot
.64243 .64973 Mdot
.37183 .46307 Mdot
.71935 .44655 Mdot
.4327 .41133 Mdot
.63423 .6997 Mdot
.56136 .5867 Mdot
.34339 .23192 Mdot
.41903 .45698 Mdot
.34071 .50795 Mdot
.66128 .76928 Mdot
.34922 .40484 Mdot
.34964 .6202 Mdot
.62829 .32513 Mdot
.42147 .63815 Mdot
.67986 .64643 Mdot
.40215 .75773 Mdot
.39136 .44223 Mdot
.4676 .65791 Mdot
.67611 .64866 Mdot
.62715 .70588 Mdot
.56828 .51197 Mdot
.3434 .42529 Mdot
.85921 .63046 Mdot
.47595 .67533 Mdot
.69181 .4775 Mdot
.28846 .64037 Mdot
.40301 .66693 Mdot
.57645 .49539 Mdot
.72979 .4432 Mdot
.47856 .36472 Mdot
.46722 .64522 Mdot
.65945 .31443 Mdot
.44351 .6753 Mdot
.65259 .2864 Mdot
.45007 .71851 Mdot
.66951 .45035 Mdot
.37788 .42735 Mdot
.66876 .45764 Mdot
.63013 .27318 Mdot
.72113 .47334 Mdot
.68004 .64582 Mdot
.50404 .56685 Mdot
.64069 .63577 Mdot
.42322 .28942 Mdot
.3039 .53832 Mdot
.6338 .65235 Mdot
.50709 .53264 Mdot
.40771 .46275 Mdot
.42263 .71787 Mdot
.68605 .47764 Mdot
.64584 .46693 Mdot
.49077 .3451 Mdot
.44237 .64511 Mdot
.67807 .44142 Mdot
.24642 .62603 Mdot
.79804 .63351 Mdot
.37555 .37474 Mdot
.71948 .60097 Mdot
.44039 .65184 Mdot
.64794 .44237 Mdot
.49634 .43465 Mdot
.41523 .6506 Mdot
.65874 .46693 Mdot
.65001 .66008 Mdot
.6687 .62465 Mdot
.42311 .44654 Mdot
.68455 .64922 Mdot
.65289 .4701 Mdot
.2485 .43943 Mdot
.41868 .67776 Mdot
.59532 .69906 Mdot
.61709 .3245 Mdot
.68068 .47434 Mdot
.39431 .48893 Mdot
.41715 .70362 Mdot
.66575 .43166 Mdot
.46292 .85284 Mdot
.13399 .49243 Mdot
.6799 .44033 Mdot
.43501 .68256 Mdot
.46125 .67055 Mdot
.34189 .3968 Mdot
.49006 .35343 Mdot
.68871 .43859 Mdot
.78502 .48998 Mdot
.37 .27943 Mdot
.50577 .57215 Mdot
.45748 .15644 Mdot
.36778 .46768 Mdot
.35477 .44309 Mdot
.63176 .65748 Mdot
.38825 .42158 Mdot
.45932 .63557 Mdot
.4217 .41995 Mdot
.64138 .61654 Mdot
.70643 .48973 Mdot
.3875 .43822 Mdot
.62038 .32489 Mdot
.63484 .62225 Mdot
.62427 .62992 Mdot
.66363 .44653 Mdot
.42056 .65134 Mdot
.50961 .82149 Mdot
.68207 .46115 Mdot
.356 .43159 Mdot
.49189 .587 Mdot
.42784 .45187 Mdot
.47484 .57934 Mdot
.44716 .62553 Mdot
.68914 .4798 Mdot
.4896 .61027 Mdot
.66036 .63442 Mdot
.65173 .4731 Mdot
.38725 .47994 Mdot
.66594 .47944 Mdot
.58403 .52983 Mdot
.71356 .29963 Mdot
.48021 .66875 Mdot
.58515 .50423 Mdot
.42098 .64642 Mdot
.50889 .57195 Mdot
.4634 .22588 Mdot
.6174 .31088 Mdot
.70856 .47777 Mdot
.57025 .66594 Mdot
.67037 .47335 Mdot
.392 .42684 Mdot
.3984 .46517 Mdot
.71078 .45259 Mdot
.6241 .29217 Mdot
.55504 .33236 Mdot
.66396 .30318 Mdot
.44035 .68868 Mdot
.53185 .48703 Mdot
.17837 .38464 Mdot
.69245 .50034 Mdot
.64711 .64913 Mdot
.41729 .5431 Mdot
.33546 .42634 Mdot
.67241 .65741 Mdot
.61799 .63974 Mdot
.64786 .27288 Mdot
.67466 .4735 Mdot
.4692 .62004 Mdot
.67249 .61827 Mdot
.4003 .69049 Mdot
.49425 .28764 Mdot
.34506 .36596 Mdot
.34986 .32587 Mdot
.33412 .44386 Mdot
.48811 .33971 Mdot
.66791 .61339 Mdot
.39022 .45977 Mdot
.31667 .42917 Mdot
.65842 .66081 Mdot
.65093 .27696 Mdot
.52663 .62383 Mdot
.67755 .43979 Mdot
.75168 .74584 Mdot
.41913 .44784 Mdot
.37812 .43172 Mdot
.66488 .65951 Mdot
.34152 .65563 Mdot
.46624 .68587 Mdot
.41732 .65864 Mdot
.69571 .458 Mdot
.51255 .43234 Mdot
.42061 .45964 Mdot
.41481 .45763 Mdot
.7085 .43672 Mdot
.49215 .59566 Mdot
.43317 .16743 Mdot
.39761 .44827 Mdot
.65254 .62731 Mdot
.57159 .54278 Mdot
.67947 .6172 Mdot
.41488 .39321 Mdot
.39824 .42897 Mdot
.37748 .48054 Mdot
.39658 .48219 Mdot
.63719 .63352 Mdot
.33572 .44522 Mdot
.33403 .46009 Mdot
.42948 .66703 Mdot
.36161 .45697 Mdot
.3677 .2793 Mdot
.39413 .44748 Mdot
.62618 .32622 Mdot
.50149 .46001 Mdot
.36614 .42353 Mdot
.35971 .45374 Mdot
.37338 .27957 Mdot
.38667 .41666 Mdot
.67591 .6502 Mdot
.46225 .6657 Mdot
.66197 .63423 Mdot
.65326 .65199 Mdot
.66036 .4388 Mdot
.65613 .29596 Mdot
.3249 .41511 Mdot
.63276 .27698 Mdot
.34597 .39103 Mdot
.45057 .38093 Mdot
.46339 .30335 Mdot
.49844 .43338 Mdot
.61122 .32642 Mdot
.41364 .4574 Mdot
.6938 .46444 Mdot
.6841 .4814 Mdot
.55283 .49777 Mdot
.42136 .37283 Mdot
.6847 .63385 Mdot
.64088 .65469 Mdot
.57623 .31618 Mdot
.70166 .27268 Mdot
.61315 .30384 Mdot
.55665 .35138 Mdot
.4384 .44465 Mdot
.36733 .45451 Mdot
.44549 .39823 Mdot
.68371 .42356 Mdot
.50681 .56572 Mdot
.72356 .44926 Mdot
.60535 .6722 Mdot
.64497 .61987 Mdot
.42018 .45324 Mdot
.35891 .81556 Mdot
.43146 .69184 Mdot
.46296 .66649 Mdot
.64258 .61596 Mdot
.70236 .48413 Mdot
.43034 .37483 Mdot
.69781 .78857 Mdot
.4604 .62468 Mdot
.62865 .3366 Mdot
.37903 .41854 Mdot
.66482 .46123 Mdot
.42434 .68691 Mdot
.63103 .33993 Mdot
.40033 .4794 Mdot
.72789 .43871 Mdot
.38793 .45542 Mdot
.23563 .54087 Mdot
.42289 .67205 Mdot
.4522 .30956 Mdot
.43707 .71351 Mdot
.63902 .63167 Mdot
.66989 .64445 Mdot
.39798 .43124 Mdot
.72253 .77432 Mdot
.39662 .65388 Mdot
.61469 .63578 Mdot
.64965 .3226 Mdot
.49637 .57068 Mdot
.6537 .30605 Mdot
.70867 .45394 Mdot
.61709 .31754 Mdot
.66362 .43427 Mdot
.65394 .5237 Mdot
.48114 .64758 Mdot
.64638 .30022 Mdot
.35531 .5929 Mdot
.42245 .36717 Mdot
.64837 .26566 Mdot
.37828 .40605 Mdot
.35989 .38719 Mdot
.69028 .43338 Mdot
.62644 .28348 Mdot
.3395 .44088 Mdot
.53206 .70795 Mdot
.66598 .64919 Mdot
.68336 .63719 Mdot
.40125 .36114 Mdot
.65584 .4284 Mdot
.4794 .66294 Mdot
.498 .32487 Mdot
.46234 .61299 Mdot
.41602 .45475 Mdot
.33517 .39786 Mdot
.46033 .70506 Mdot
.45596 .70068 Mdot
.40161 .43241 Mdot
.29456 .69569 Mdot
.36019 .47154 Mdot
.67043 .62711 Mdot
.43888 .68967 Mdot
.46276 .67108 Mdot
.65201 .4671 Mdot
.4134 .66395 Mdot
.35481 .49274 Mdot
.61348 .61924 Mdot
.34944 .47879 Mdot
.65684 .63453 Mdot
.68213 .51178 Mdot
.68009 .43126 Mdot
.57206 .67105 Mdot
.41314 .66842 Mdot
.39002 .39315 Mdot
.41343 .68536 Mdot
.63793 .32708 Mdot
.46653 .66923 Mdot
.42753 .72555 Mdot
.4073 .41245 Mdot
.34138 .4513 Mdot
.4957 .59296 Mdot
.48834 .34906 Mdot
.4276 .67682 Mdot
.37787 .38312 Mdot
.41609 .40634 Mdot
.39747 .46788 Mdot
.48908 .31499 Mdot
.41398 .69481 Mdot
.35182 .70258 Mdot
.43672 .61111 Mdot
.42267 .67668 Mdot
.14682 .50805 Mdot
.50171 .59233 Mdot
.48917 .60265 Mdot
.68883 .62286 Mdot
.39922 .44573 Mdot
.67444 .4543 Mdot
.35325 .43514 Mdot
.45339 .43939 Mdot
.36815 .42308 Mdot
.6489 .3052 Mdot
.41875 .46547 Mdot
.50121 .57778 Mdot
.68002 .46624 Mdot
.35491 .39933 Mdot
.39322 .43697 Mdot
.49677 .59938 Mdot
.41966 .69786 Mdot
.42255 .64675 Mdot
.46391 .60941 Mdot
.64328 .27055 Mdot
.62694 .63481 Mdot
.35513 .4304 Mdot
.69471 .46071 Mdot
.6721 .45997 Mdot
.4087 .68667 Mdot
.71184 .44027 Mdot
.63075 .62622 Mdot
.41014 .42854 Mdot
.63861 .63287 Mdot
.649 .30623 Mdot
.43275 .68277 Mdot
.36457 .4171 Mdot
.34689 .43271 Mdot
.42545 .65499 Mdot
.35191 .46364 Mdot
.64423 .32452 Mdot
.67639 .41987 Mdot
.46722 .67814 Mdot
.65275 .64554 Mdot
.6511 .46278 Mdot
.37165 .39223 Mdot
.1702 .60774 Mdot
.38983 .4215 Mdot
.4098 .46703 Mdot
.38815 .67277 Mdot
.43131 .42212 Mdot
.66889 .47112 Mdot
.41082 .68014 Mdot
.36801 .38654 Mdot
.37719 .27613 Mdot
.60277 .34221 Mdot
.71899 .49409 Mdot
.39782 .41374 Mdot
.22405 .64187 Mdot
.40613 .4006 Mdot
.56707 .67019 Mdot
.46325 .30362 Mdot
.6558 .56692 Mdot
.34945 .32613 Mdot
.61619 .63413 Mdot
.49101 .5934 Mdot
.66329 .43915 Mdot
.32171 .65022 Mdot
.40154 .42748 Mdot
.30565 .51732 Mdot
.36176 .41851 Mdot
.66092 .62285 Mdot
.35778 .62191 Mdot
.71623 .45139 Mdot
.42897 .17947 Mdot
.37656 .4705 Mdot
.47596 .66804 Mdot
.67468 .4094 Mdot
.48705 .59695 Mdot
.3409 .44938 Mdot
.61675 .29138 Mdot
.57957 .3198 Mdot
.37319 .49739 Mdot
.65886 .63642 Mdot
.38118 .46578 Mdot
.43677 .47198 Mdot
.8282 .55764 Mdot
.43649 .65882 Mdot
.65292 .65629 Mdot
.69869 .27428 Mdot
.40163 .46272 Mdot
.42944 .64207 Mdot
.45764 .66032 Mdot
.6424 .27604 Mdot
.6087 .65928 Mdot
.58716 .3469 Mdot
.32184 .7746 Mdot
.24734 .405 Mdot
.68217 .42269 Mdot
.49282 .66884 Mdot
.35216 .4425 Mdot
.54961 .20321 Mdot
.65139 .64983 Mdot
.37676 .43092 Mdot
.34073 .54053 Mdot
.44683 .65457 Mdot
.39351 .45487 Mdot
.61946 .3077 Mdot
.56607 .82824 Mdot
.23376 .59827 Mdot
.23581 .66569 Mdot
.72889 .43812 Mdot
.32394 .42814 Mdot
.34672 .48706 Mdot
.51433 .59209 Mdot
.39922 .38088 Mdot
.68701 .4766 Mdot
.58914 .54664 Mdot
.63051 .29296 Mdot
.42698 .6911 Mdot
.49097 .59856 Mdot
.36204 .41774 Mdot
.32733 .44463 Mdot
.64417 .32762 Mdot
.36422 .47132 Mdot
.29082 .6505 Mdot
.50371 .55988 Mdot
.65145 .45272 Mdot
.47248 .65863 Mdot
.32771 .40775 Mdot
.49206 .57909 Mdot
.40279 .4098 Mdot
.33485 .51264 Mdot
.36883 .43749 Mdot
.55236 .65098 Mdot
.42564 .65148 Mdot
.66119 .64291 Mdot
.40523 .48144 Mdot
.38618 .44934 Mdot
.59396 .45718 Mdot
.43156 .37468 Mdot
.36085 .43577 Mdot
.40374 .67253 Mdot
.4292 .69219 Mdot
.47263 .67547 Mdot
.66083 .47936 Mdot
.49446 .39181 Mdot
.6449 .63305 Mdot
.44359 .39416 Mdot
.67202 .61774 Mdot
.36651 .32118 Mdot
.65196 .30329 Mdot
.57613 .68366 Mdot
.4096 .43219 Mdot
.44996 .6436 Mdot
.21042 .38236 Mdot
.41192 .69276 Mdot
.64037 .59863 Mdot
.65588 .64963 Mdot
.43385 .67207 Mdot
.39498 .41519 Mdot
.4837 .35583 Mdot
.24538 .68249 Mdot
.67723 .63233 Mdot
.3894 .35771 Mdot
.7237 .49959 Mdot
.69922 .49389 Mdot
.14882 .49054 Mdot
.67223 .62084 Mdot
.66212 .7696 Mdot
.37712 .3878 Mdot
.41421 .68212 Mdot
.62871 .64075 Mdot
.62426 .65783 Mdot
.71523 .4428 Mdot
.34536 .42451 Mdot
.38791 .45098 Mdot
.50959 .58125 Mdot
.63584 .64076 Mdot
.32216 .48295 Mdot
.34182 .42687 Mdot
.63639 .69706 Mdot
.47426 .6373 Mdot
.83419 .46791 Mdot
.44056 .53166 Mdot
.33867 .53968 Mdot
.80597 .49461 Mdot
.46462 .68367 Mdot
.36994 .46199 Mdot
.43061 .37587 Mdot
.68754 .42049 Mdot
.40349 .42219 Mdot
.68556 .48992 Mdot
.64701 .62184 Mdot
.53501 .68662 Mdot
.49932 .52987 Mdot
.59026 .65533 Mdot
.38629 .424 Mdot
.24025 .60938 Mdot
.64117 .29727 Mdot
.67431 .60526 Mdot
.45934 .69535 Mdot
.41303 .39346 Mdot
.70348 .42577 Mdot
.67157 .48481 Mdot
.4467 .65803 Mdot
.63925 .76189 Mdot
.57088 .67436 Mdot
.37659 .4829 Mdot
.70761 .46706 Mdot
.45753 .53513 Mdot
.21786 .61324 Mdot
.64554 .61247 Mdot
.63287 .29243 Mdot
.66059 .45111 Mdot
.67124 .66528 Mdot
.35544 .3883 Mdot
.44336 .66555 Mdot
.47649 .67597 Mdot
.56582 .49476 Mdot
.67758 .44323 Mdot
.63024 .31541 Mdot
.56648 .49966 Mdot
.53698 .49176 Mdot
.62528 .30336 Mdot
.66706 .48724 Mdot
.45197 .68864 Mdot
.44921 .64846 Mdot
.46145 .66525 Mdot
.32526 .68697 Mdot
.44829 .62553 Mdot
.53351 .25837 Mdot
.40472 .38374 Mdot
.24301 .63161 Mdot
.40497 .39081 Mdot
.6783 .64935 Mdot
.42159 .67031 Mdot
.4595 .30413 Mdot
.43623 .45565 Mdot
.25249 .68695 Mdot
.37353 .45215 Mdot
.56941 .53517 Mdot
.39899 .44432 Mdot
.25176 .58431 Mdot
.41807 .64145 Mdot
.39348 .47833 Mdot
.61908 .61505 Mdot
.63859 .32145 Mdot
.45075 .72097 Mdot
.36198 .44228 Mdot
.55732 .79344 Mdot
.37723 .40606 Mdot
.54031 .67574 Mdot
.57623 .49121 Mdot
.66471 .26431 Mdot
.42927 .44575 Mdot
.71556 .4331 Mdot
.42162 .52428 Mdot
.23641 .62275 Mdot
.67718 .63054 Mdot
.24387 .6181 Mdot
.72007 .46016 Mdot
.3557 .6263 Mdot
.431 .47943 Mdot
.62818 .29236 Mdot
.5311 .62431 Mdot
.67201 .63126 Mdot
.40726 .43261 Mdot
.37888 .47009 Mdot
.56403 .57982 Mdot
.2155 .59483 Mdot
.33776 .49915 Mdot
.61653 .33567 Mdot
.22655 .59093 Mdot
.36299 .43245 Mdot
.72267 .49218 Mdot
.41362 .6561 Mdot
.36496 .60955 Mdot
.34945 .64694 Mdot
.34282 .41548 Mdot
.43532 .66811 Mdot
.4165 .65465 Mdot
.22408 .3381 Mdot
.6418 .28901 Mdot
.36883 .44054 Mdot
.58604 .50272 Mdot
.35682 .42751 Mdot
.65212 .62389 Mdot
.43709 .43234 Mdot
.68017 .43243 Mdot
.49449 .43958 Mdot
.66319 .48161 Mdot
.40071 .46792 Mdot
.44336 .67686 Mdot
.67319 .6466 Mdot
.69285 .56977 Mdot
.60805 .65671 Mdot
.53265 .25906 Mdot
.58117 .29553 Mdot
.61244 .30702 Mdot
.65418 .29603 Mdot
.68019 .61273 Mdot
.40369 .41677 Mdot
.49544 .33744 Mdot
.39609 .37233 Mdot
.40248 .44903 Mdot
.36798 .43238 Mdot
.67581 .58651 Mdot
.65745 .64882 Mdot
.66628 .45194 Mdot
.40273 .4327 Mdot
.38238 .38187 Mdot
.43867 .67577 Mdot
.61343 .30617 Mdot
.65795 .43678 Mdot
.62012 .28437 Mdot
.68561 .46611 Mdot
.19057 .42026 Mdot
.36204 .35685 Mdot
.64201 .31712 Mdot
.65786 .61311 Mdot
.45925 .64795 Mdot
.51098 .58844 Mdot
.70666 .45041 Mdot
.71432 .4472 Mdot
.32986 .40956 Mdot
.42379 .68309 Mdot
.41553 .66208 Mdot
.62684 .27862 Mdot
.63842 .65382 Mdot
.33976 .38545 Mdot
.3337 .43168 Mdot
.70559 .5566 Mdot
.6789 .41843 Mdot
.2309 .60506 Mdot
.41053 .6314 Mdot
.41298 .4266 Mdot
.43019 .64245 Mdot
.38364 .44033 Mdot
.45682 .54822 Mdot
.46783 .68882 Mdot
.43242 .42204 Mdot
.4359 .3988 Mdot
.67902 .42359 Mdot
.26135 .29326 Mdot
.32802 .39477 Mdot
.60569 .60553 Mdot
.35274 .45158 Mdot
.40905 .16418 Mdot
.21588 .37227 Mdot
.39141 .40618 Mdot
.41239 .47007 Mdot
.29298 .75495 Mdot
.40937 .40441 Mdot
.50628 .57794 Mdot
.45369 .44019 Mdot
.43741 .63905 Mdot
.58374 .51447 Mdot
.48948 .34191 Mdot
.64466 .28715 Mdot
.69639 .45859 Mdot
.46844 .26772 Mdot
.65217 .2838 Mdot
.44578 .65102 Mdot
.32233 .39938 Mdot
.40092 .64392 Mdot
.64213 .46007 Mdot
.31241 .46823 Mdot
.65647 .62253 Mdot
.49352 .34172 Mdot
.71033 .43407 Mdot
.65185 .64614 Mdot
.41016 .40172 Mdot
.63342 .45044 Mdot
.65152 .60179 Mdot
.23361 .31404 Mdot
.6353 .65998 Mdot
.66614 .6439 Mdot
.48853 .36727 Mdot
.64456 .28679 Mdot
.58794 .55591 Mdot
.44233 .36708 Mdot
.67611 .64562 Mdot
.43428 .19267 Mdot
.68946 .41833 Mdot
.50488 .40455 Mdot
.41112 .64801 Mdot
.37984 .35484 Mdot
.37341 .42902 Mdot
.64407 .66146 Mdot
.49487 .64136 Mdot
.59605 .44454 Mdot
.65744 .61872 Mdot
.42357 .47366 Mdot
.51013 .43991 Mdot
.49531 .57393 Mdot
.50402 .59105 Mdot
.63404 .33845 Mdot
.73211 .33769 Mdot
.432 .64596 Mdot
.62727 .33586 Mdot
.42617 .29891 Mdot
.3757 .45713 Mdot
.63527 .6338 Mdot
.49221 .60019 Mdot
.65203 .64329 Mdot
.63685 .30246 Mdot
.64846 .32192 Mdot
.43036 .66551 Mdot
.46279 .68961 Mdot
.51006 .65998 Mdot
.35169 .27715 Mdot
.35481 .4152 Mdot
.29377 .52067 Mdot
.45728 .70008 Mdot
.33256 .65914 Mdot
.63622 .28069 Mdot
.61879 .29304 Mdot
.20347 .51139 Mdot
.36411 .39818 Mdot
.57148 .54123 Mdot
.36415 .42592 Mdot
.47653 .20244 Mdot
.36424 .41559 Mdot
.70992 .43824 Mdot
.37244 .47062 Mdot
.48749 .8048 Mdot
.36654 .38952 Mdot
.36887 .42729 Mdot
.69325 .44702 Mdot
.326 .41523 Mdot
.68601 .43253 Mdot
.36995 .46031 Mdot
.59421 .30437 Mdot
.69457 .46024 Mdot
.60411 .29616 Mdot
.54903 .51824 Mdot
.50195 .58493 Mdot
.65084 .2902 Mdot
.61145 .30641 Mdot
.49781 .29582 Mdot
.4437 .69356 Mdot
.40421 .57714 Mdot
.3801 .4184 Mdot
.66663 .41839 Mdot
.63338 .62641 Mdot
.34116 .41828 Mdot
.4269 .4369 Mdot
.33254 .39115 Mdot
.43106 .66852 Mdot
.64893 .46604 Mdot
.64191 .3081 Mdot
.67861 .48184 Mdot
.59657 .30357 Mdot
.68166 .42862 Mdot
.38332 .36373 Mdot
.34807 .39076 Mdot
.34133 .48246 Mdot
.33818 .56556 Mdot
.59983 .21066 Mdot
.44511 .66182 Mdot
.49315 .58519 Mdot
.65222 .3072 Mdot
.52495 .45509 Mdot
.43997 .64161 Mdot
.71095 .44304 Mdot
.38762 .45547 Mdot
.34721 .3639 Mdot
.44566 .37295 Mdot
.40558 .70966 Mdot
.64105 .26223 Mdot
.70198 .45203 Mdot
.50438 .57053 Mdot
.49835 .40385 Mdot
.36188 .70879 Mdot
.43305 .29 Mdot
.38477 .44525 Mdot
.63065 .27508 Mdot
.42451 .68702 Mdot
.57417 .55846 Mdot
.64896 .66114 Mdot
.48983 .35131 Mdot
.3857 .423 Mdot
.71054 .68601 Mdot
.44523 .67586 Mdot
.61944 .29899 Mdot
.64442 .66181 Mdot
.63737 .28628 Mdot
.48967 .58079 Mdot
.41812 .62345 Mdot
.34213 .45013 Mdot
.3644 .42342 Mdot
.63886 .62392 Mdot
.42667 .64899 Mdot
.59047 .31662 Mdot
.5708 .58057 Mdot
.70997 .45455 Mdot
.51694 .46031 Mdot
.42698 .69008 Mdot
.71784 .66714 Mdot
.68034 .48424 Mdot
.68635 .63847 Mdot
.48138 .33919 Mdot
.62631 .6296 Mdot
.36472 .43318 Mdot
.45299 .67842 Mdot
.67786 .62861 Mdot
.70053 .54461 Mdot
.30376 .71873 Mdot
.54014 .61502 Mdot
.40628 .46377 Mdot
.56766 .68964 Mdot
.62326 .78252 Mdot
.46576 .71729 Mdot
.66805 .61727 Mdot
.38918 .43037 Mdot
.37536 .48235 Mdot
.37638 .4709 Mdot
.66367 .65334 Mdot
.69881 .59606 Mdot
.71185 .47191 Mdot
.39229 .46039 Mdot
.62116 .32677 Mdot
.67383 .43568 Mdot
.71964 .48319 Mdot
.66025 .45325 Mdot
.45491 .69882 Mdot
.33985 .3711 Mdot
.4539 .41931 Mdot
.2414 .33163 Mdot
.66421 .64281 Mdot
.50181 .58461 Mdot
.40411 .47379 Mdot
.52849 .26638 Mdot
.45668 .64842 Mdot
.70152 .44468 Mdot
.37715 .4326 Mdot
.57136 .49169 Mdot
.51734 .55514 Mdot
.68496 .45468 Mdot
.46251 .69418 Mdot
.4175 .74328 Mdot
.40557 .4242 Mdot
.35086 .44448 Mdot
.43362 .65173 Mdot
.62131 .79658 Mdot
.50137 .41577 Mdot
.38588 .44009 Mdot
.65861 .64594 Mdot
.76056 .70903 Mdot
.40772 .39827 Mdot
.4281 .62634 Mdot
.50885 .56554 Mdot
.3955 .64601 Mdot
.2761 .6605 Mdot
.43515 .38739 Mdot
.50464 .70488 Mdot
.55272 .30451 Mdot
.45503 .73861 Mdot
.50189 .20416 Mdot
.57418 .58776 Mdot
.19939 .35604 Mdot
.60229 .63399 Mdot
.24043 .56496 Mdot
.44556 .8455 Mdot
.6592 .76592 Mdot
.59458 .47586 Mdot
.65837 .55336 Mdot
.64374 .48805 Mdot
.44075 .16508 Mdot
.72099 .43859 Mdot
.51163 .19441 Mdot
.36974 .41609 Mdot
.61071 .79821 Mdot
.24473 .585 Mdot
.61473 .23145 Mdot
.58044 .67431 Mdot
.57243 .49445 Mdot
.20555 .65143 Mdot
.60652 .68732 Mdot
.17001 .52019 Mdot
.37302 .55383 Mdot
.76645 .36817 Mdot
.52736 .47058 Mdot
.48573 .27036 Mdot
.25514 .62464 Mdot
.47691 .77648 Mdot
.67729 .69049 Mdot
.2459 .47117 Mdot
.81552 .49154 Mdot
.70066 .46975 Mdot
.41793 .64665 Mdot
.63457 .55363 Mdot
.18404 .57586 Mdot
.62533 .59946 Mdot
.50334 .70606 Mdot
.5549 .59986 Mdot
.2481 .57906 Mdot
.44855 .30668 Mdot
.23859 .5357 Mdot
.58152 .34433 Mdot
.44596 .16731 Mdot
.39463 .71571 Mdot
.73719 .5158 Mdot
.52553 .43334 Mdot
.57297 .35952 Mdot
.27531 .61705 Mdot
.60768 .33586 Mdot
.60026 .33247 Mdot
.46653 .68959 Mdot
.19921 .59147 Mdot
.52437 .55597 Mdot
.4175 .29951 Mdot
.71883 .43422 Mdot
.46255 .54353 Mdot
.55833 .82686 Mdot
.61657 .7806 Mdot
.29368 .26094 Mdot
.16975 .59636 Mdot
.43299 .21951 Mdot
.56482 .55469 Mdot
.64805 .58804 Mdot
.52677 .28141 Mdot
.32154 .49121 Mdot
.4107 .22423 Mdot
.34639 .51977 Mdot
.25265 .70867 Mdot
.58227 .77339 Mdot
.18555 .63495 Mdot
.40013 .72445 Mdot
.31927 .43806 Mdot
.48066 .55988 Mdot
.2548 .42598 Mdot
.41011 .27662 Mdot
.1899 .62252 Mdot
.66508 .27151 Mdot
.4875 .62488 Mdot
.66277 .76173 Mdot
.28918 .65081 Mdot
.60142 .36667 Mdot
.631 .25143 Mdot
.37614 .60074 Mdot
.21099 .67356 Mdot
.50785 .70508 Mdot
.21105 .42652 Mdot
.65521 .70217 Mdot
.6646 .40218 Mdot
.72257 .47854 Mdot
.61631 .65081 Mdot
.16712 .55266 Mdot
.45551 .67303 Mdot
.25637 .29407 Mdot
.49693 .69362 Mdot
.41072 .53055 Mdot
.21523 .68273 Mdot
.37305 .22273 Mdot
.26042 .64649 Mdot
.56767 .23583 Mdot
.74245 .69263 Mdot
.28004 .41393 Mdot
.5948 .64038 Mdot
.72053 .49905 Mdot
.55165 .6684 Mdot
.17152 .5663 Mdot
.41169 .21264 Mdot
.35489 .80488 Mdot
.40997 .30104 Mdot
.6887 .38032 Mdot
.39153 .70697 Mdot
.60864 .47136 Mdot
.6119 .37801 Mdot
.18207 .62972 Mdot
.23044 .58566 Mdot
.75617 .70226 Mdot
.48406 .2159 Mdot
.34555 .65672 Mdot
.55793 .70278 Mdot
.64503 .53051 Mdot
.27028 .40511 Mdot
.57285 .78842 Mdot
.33303 .4499 Mdot
.43883 .28284 Mdot
.37843 .58115 Mdot
.65736 .33217 Mdot
.49519 .40306 Mdot
.58924 .75573 Mdot
.43865 .24057 Mdot
.70865 .72287 Mdot
.37836 .60566 Mdot
.44486 .71483 Mdot
.41372 .22567 Mdot
.45794 .21501 Mdot
.65972 .7232 Mdot
.69686 .27153 Mdot
.20835 .43067 Mdot
.64016 .39024 Mdot
.44221 .40057 Mdot
.23792 .55888 Mdot
.25766 .62561 Mdot
.45784 .18119 Mdot
.38356 .3616 Mdot
.26663 .30099 Mdot
.58268 .65434 Mdot
.32266 .57149 Mdot
.41046 .26018 Mdot
.3337 .56841 Mdot
.24884 .6552 Mdot
.46296 .58351 Mdot
.62916 .57805 Mdot
.50523 .63074 Mdot
.21326 .67421 Mdot
.66772 .44233 Mdot
.40607 .22199 Mdot
.60146 .62349 Mdot
.7005 .55054 Mdot
.58951 .56878 Mdot
.60004 .44024 Mdot
.16076 .51489 Mdot
.65522 .75413 Mdot
.68774 .52767 Mdot
.45303 .78117 Mdot
.45277 .53826 Mdot
.2993 .52896 Mdot
.30693 .42038 Mdot
.36578 .52554 Mdot
.64452 .32435 Mdot
.33346 .61333 Mdot
.43589 .60646 Mdot
.68348 .23847 Mdot
.40713 .37161 Mdot
.53248 .47242 Mdot
.51287 .57248 Mdot
.51074 .35029 Mdot
.18895 .4197 Mdot
.30638 .41337 Mdot
.36871 .22795 Mdot
.6511 .76228 Mdot
.50904 .34036 Mdot
.60613 .37481 Mdot
.40105 .58849 Mdot
.18701 .63995 Mdot
.15912 .45512 Mdot
.56396 .80946 Mdot
.55552 .69149 Mdot
.58649 .14545 Mdot
.6382 .57212 Mdot
.28825 .28267 Mdot
.60285 .62162 Mdot
.91147 .51715 Mdot
.67475 .4824 Mdot
.55607 .19888 Mdot
.27579 .45956 Mdot
.56303 .46289 Mdot
.19132 .58678 Mdot
.27618 .64339 Mdot
.63677 .25986 Mdot
.42708 .72157 Mdot
.40414 .36547 Mdot
.19687 .62247 Mdot
.21804 .6747 Mdot
.20003 .62818 Mdot
.71091 .66141 Mdot
.25776 .68027 Mdot
.26621 .73513 Mdot
.53585 .2577 Mdot
.5451 .55932 Mdot
.43403 .47536 Mdot
.33941 .27647 Mdot
.33892 .25199 Mdot
.67342 .28405 Mdot
.28045 .40958 Mdot
.3931 .71478 Mdot
.24732 .72044 Mdot
.18824 .41428 Mdot
.23502 .51441 Mdot
.16828 .50458 Mdot
.73053 .505 Mdot
.36197 .26051 Mdot
.15877 .49037 Mdot
.48196 .75715 Mdot
.60818 .67885 Mdot
.27865 .75196 Mdot
.45849 .22266 Mdot
.66047 .55339 Mdot
.52863 .80283 Mdot
.31767 .2605 Mdot
.54835 .70174 Mdot
.65534 .54828 Mdot
.31424 .48871 Mdot
.36868 .69985 Mdot
.60212 .44029 Mdot
.47049 .77533 Mdot
.56672 .54734 Mdot
.39705 .25777 Mdot
.71564 .48179 Mdot
.39107 .23066 Mdot
.59392 .3835 Mdot
.54972 .56329 Mdot
.47768 .28048 Mdot
.42369 .19816 Mdot
.54191 .78005 Mdot
.22999 .65467 Mdot
.65364 .75945 Mdot
.73877 .71634 Mdot
.59796 .71391 Mdot
.38574 .57266 Mdot
.32595 .41368 Mdot
.18611 .58358 Mdot
.1423 .44413 Mdot
.15659 .50246 Mdot
.67966 .72491 Mdot
.73758 .4382 Mdot
.68306 .65233 Mdot
.51808 .2832 Mdot
.57258 .45526 Mdot
.55546 .61946 Mdot
.55844 .37846 Mdot
.61452 .6545 Mdot
.57231 .82725 Mdot
.51746 .6504 Mdot
.52949 .26992 Mdot
.24791 .48721 Mdot
.3101 .47171 Mdot
.21643 .60991 Mdot
.45771 .70811 Mdot
.68922 .71996 Mdot
.40845 .22449 Mdot
.6648 .44348 Mdot
.71237 .54786 Mdot
.50394 .62341 Mdot
.31643 .42198 Mdot
.74524 .48009 Mdot
.53946 .60404 Mdot
.33599 .53899 Mdot
.73874 .44945 Mdot
.19069 .38878 Mdot
.27982 .2834 Mdot
.15841 .48676 Mdot
.43079 .21375 Mdot
.72022 .5339 Mdot
.50781 .36731 Mdot
.63148 .58265 Mdot
.59026 .67707 Mdot
.5179 .41196 Mdot
.43492 .20539 Mdot
.2568 .64721 Mdot
.48262 .5799 Mdot
.44194 .39489 Mdot
.20772 .38812 Mdot
.50534 .26313 Mdot
.51539 .37053 Mdot
.3737 .63728 Mdot
.46502 .6236 Mdot
.60829 .20248 Mdot
.48527 .78609 Mdot
.45232 .47773 Mdot
.5624 .69565 Mdot
.64894 .61021 Mdot
.46735 .69204 Mdot
.42192 .19735 Mdot
.71715 .29329 Mdot
.47404 .71761 Mdot
.50772 .53775 Mdot
.17441 .55378 Mdot
.53298 .51793 Mdot
.54374 .69213 Mdot
.39808 .76491 Mdot
.7686 .66528 Mdot
.40418 .72617 Mdot
.55539 .55568 Mdot
.60023 .55097 Mdot
.38356 .71651 Mdot
.41395 .7102 Mdot
.2343 .59547 Mdot
.16363 .56646 Mdot
.56587 .50514 Mdot
.46471 .76576 Mdot
.49935 .33782 Mdot
.60406 .46479 Mdot
.4993 .55342 Mdot
.46994 .27243 Mdot
.47049 .74473 Mdot
.19661 .47983 Mdot
.6494 .80931 Mdot
.28393 .39112 Mdot
.54811 .19374 Mdot
.52028 .28391 Mdot
.37568 .55434 Mdot
.27184 .6106 Mdot
.63015 .70096 Mdot
.35606 .44199 Mdot
.15858 .57501 Mdot
.59079 .76515 Mdot
.49906 .30821 Mdot
.64675 .52054 Mdot
.38989 .39549 Mdot
.34926 .48765 Mdot
.15947 .49889 Mdot
.38424 .67539 Mdot
.52483 .86925 Mdot
.48636 .20876 Mdot
.40236 .54689 Mdot
.26922 .65929 Mdot
.36289 .2332 Mdot
.46095 .57908 Mdot
.50155 .6907 Mdot
.60068 .38949 Mdot
.34036 .24668 Mdot
.43162 .77409 Mdot
.47113 .79227 Mdot
.59325 .70639 Mdot
.26424 .72955 Mdot
.4229 .53755 Mdot
.65191 .69674 Mdot
.7376 .4987 Mdot
.41179 .46642 Mdot
.6367 .76334 Mdot
.58515 .69255 Mdot
.62976 .42566 Mdot
.31243 .48317 Mdot
.13939 .4478 Mdot
.44304 .45934 Mdot
.64149 .75096 Mdot
.50684 .86419 Mdot
.57972 .86736 Mdot
.48113 .80211 Mdot
.17893 .6251 Mdot
.46039 .78812 Mdot
.54056 .69718 Mdot
.66989 .61074 Mdot
.52907 .48902 Mdot
.29898 .51599 Mdot
.1527 .54383 Mdot
.7437 .32659 Mdot
.59377 .64574 Mdot
.25577 .46216 Mdot
.15118 .54455 Mdot
.44839 .43224 Mdot
.58427 .19616 Mdot
.66976 .4018 Mdot
.42105 .17628 Mdot
.30502 .25379 Mdot
.36775 .66301 Mdot
.4481 .17971 Mdot
.56044 .18324 Mdot
.58517 .25057 Mdot
.28555 .2814 Mdot
.26406 .3841 Mdot
.37758 .64326 Mdot
.41855 .22711 Mdot
.55992 .67363 Mdot
.52087 .13887 Mdot
.49783 .55246 Mdot
.55295 .58576 Mdot
.40933 .62586 Mdot
.55004 .66689 Mdot
.54759 .76446 Mdot
.53624 .54208 Mdot
.49599 .46468 Mdot
.24228 .64355 Mdot
.77298 .70168 Mdot
.43376 .80073 Mdot
.51658 .63152 Mdot
.2216 .67301 Mdot
.64557 .70444 Mdot
.52391 .40548 Mdot
.28718 .63333 Mdot
.50772 .27243 Mdot
.71908 .51073 Mdot
.36807 .42258 Mdot
.16533 .57168 Mdot
.71945 .51009 Mdot
.21432 .65511 Mdot
.23878 .30573 Mdot
.17463 .50006 Mdot
.29947 .41739 Mdot
.71045 .50688 Mdot
.35713 .24772 Mdot
.35835 .24925 Mdot
.26603 .71442 Mdot
.53304 .18577 Mdot
.51627 .42763 Mdot
.54687 .53013 Mdot
.49892 .5328 Mdot
.45875 .47024 Mdot
.35618 .23531 Mdot
.41483 .57354 Mdot
.41992 .2618 Mdot
.53898 .81269 Mdot
.42825 .20177 Mdot
.26568 .64546 Mdot
.5029 .28237 Mdot
.62955 .40279 Mdot
.62083 .27104 Mdot
.67847 .41715 Mdot
.32766 .78517 Mdot
.62444 .71772 Mdot
.26048 .30898 Mdot
.74082 .70741 Mdot
.57775 .78605 Mdot
.50908 .19032 Mdot
.48117 .5912 Mdot
.2789 .38376 Mdot
.75654 .3549 Mdot
.44589 .24597 Mdot
.23481 .60607 Mdot
.56673 .67437 Mdot
.35431 .67564 Mdot
.15841 .5291 Mdot
.40026 .25986 Mdot
.39489 .83456 Mdot
.7515 .42399 Mdot
.33391 .60681 Mdot
.19914 .57569 Mdot
.72309 .74061 Mdot
.51719 .36546 Mdot
.21535 .67678 Mdot
.39977 .66999 Mdot
.17201 .60089 Mdot
.62829 .65324 Mdot
.67401 .37149 Mdot
.57478 .64999 Mdot
.51328 .31644 Mdot
.51516 .32168 Mdot
.21648 .35366 Mdot
.65955 .75884 Mdot
.61804 .78182 Mdot
.64064 .39004 Mdot
.72553 .4526 Mdot
.50998 .49722 Mdot
.47421 .75727 Mdot
.33765 .78992 Mdot
.3374 .39629 Mdot
.74356 .40653 Mdot
.39083 .22076 Mdot
.63464 .58156 Mdot
.55351 .59354 Mdot
.5688 .65348 Mdot
.38129 .7478 Mdot
.35764 .26614 Mdot
.25476 .72178 Mdot
.54926 .59941 Mdot
.57299 .43613 Mdot
.34831 .63474 Mdot
.56648 .61418 Mdot
.71983 .69765 Mdot
.49531 .72154 Mdot
.52311 .52673 Mdot
.50161 .41116 Mdot
.43681 .21743 Mdot
.16639 .39962 Mdot
.23764 .69274 Mdot
.728 .69448 Mdot
.51497 .34186 Mdot
.42883 .62663 Mdot
.46243 .25525 Mdot
.3874 .83234 Mdot
.42857 .16711 Mdot
.5397 .80038 Mdot
.4226 .20616 Mdot
.62388 .48201 Mdot
.56734 .19434 Mdot
.51746 .38973 Mdot
.19819 .57254 Mdot
.26384 .45004 Mdot
.42112 .62056 Mdot
.64374 .53413 Mdot
.49079 .32982 Mdot
.56742 .59245 Mdot
.37804 .63815 Mdot
.66288 .75554 Mdot
.39636 .83496 Mdot
.52514 .17877 Mdot
.35724 .62663 Mdot
.42068 .83304 Mdot
.4809 .65191 Mdot
.60452 .55202 Mdot
.72336 .63294 Mdot
.51058 .33637 Mdot
.6659 .47469 Mdot
.35692 .51159 Mdot
.51174 .4536 Mdot
.44204 .78695 Mdot
.64537 .49637 Mdot
.65576 .28398 Mdot
.42421 .70896 Mdot
.54789 .18286 Mdot
.47907 .67025 Mdot
.17763 .38656 Mdot
.4863 .75307 Mdot
.24103 .63346 Mdot
.40747 .78449 Mdot
.7572 .49503 Mdot
.74102 .71916 Mdot
.16979 .51706 Mdot
.37657 .27734 Mdot
.41951 .71447 Mdot
.45342 .71413 Mdot
.43319 .76946 Mdot
.69463 .60756 Mdot
.17801 .55206 Mdot
.37921 .22077 Mdot
.7275 .53118 Mdot
.44848 .63205 Mdot
.55632 .53122 Mdot
.51381 .62831 Mdot
.18682 .39951 Mdot
.67619 .47989 Mdot
.19903 .66119 Mdot
.40901 .57498 Mdot
.67324 .77366 Mdot
.54976 .62994 Mdot
.49072 .42281 Mdot
.52297 .36902 Mdot
.69865 .54148 Mdot
.44685 .40836 Mdot
.40529 .5451 Mdot
.4588 .69291 Mdot
.58472 .57434 Mdot
.61434 .30978 Mdot
.68672 .24692 Mdot
.61108 .59513 Mdot
.36565 .55984 Mdot
.34518 .23604 Mdot
.46098 .70519 Mdot
.75153 .42941 Mdot
.7731 .46081 Mdot
.42998 .39164 Mdot
.30636 .29902 Mdot
.30796 .76805 Mdot
.17334 .5246 Mdot
.4057 .68769 Mdot
.72524 .72053 Mdot
.59516 .34705 Mdot
.19504 .38385 Mdot
.40228 .74662 Mdot
.37681 .23058 Mdot
.36676 .5865 Mdot
.16421 .46218 Mdot
.27588 .65989 Mdot
.52672 .66669 Mdot
.4178 .22079 Mdot
.59594 .44849 Mdot
.41765 .20412 Mdot
.37635 .74663 Mdot
.50989 .52096 Mdot
.42064 .17901 Mdot
.63 .49153 Mdot
.23826 .54017 Mdot
.42084 .51077 Mdot
.54801 .62851 Mdot
.35143 .24424 Mdot
.42268 .70352 Mdot
.61723 .34476 Mdot
.25766 .4824 Mdot
.59275 .66865 Mdot
.17066 .5612 Mdot
.65805 .72541 Mdot
.39539 .21512 Mdot
.49263 .5338 Mdot
.50288 .24293 Mdot
.41409 .56888 Mdot
.40017 .29339 Mdot
.39672 .48996 Mdot
.37636 .58714 Mdot
.5717 .38691 Mdot
.22116 .36081 Mdot
.43243 .51712 Mdot
.19019 .60331 Mdot
.19567 .4074 Mdot
.40983 .758 Mdot
.58434 .54469 Mdot
.43083 .63794 Mdot
.19988 .65548 Mdot
.31946 .28144 Mdot
.55733 .6589 Mdot
.30999 .25099 Mdot
.60716 .19984 Mdot
.43507 .84084 Mdot
.61959 .74194 Mdot
.53914 .59976 Mdot
.26006 .29522 Mdot
.58981 .76962 Mdot
.57465 .18662 Mdot
.23254 .6006 Mdot
.3888 .67259 Mdot
.21879 .68826 Mdot
.25345 .40597 Mdot
.60535 .78617 Mdot
.21128 .5941 Mdot
.43676 .74258 Mdot
.30902 .28823 Mdot
.45027 .41045 Mdot
.70229 .4282 Mdot
.55456 .47255 Mdot
.45597 .17733 Mdot
.45701 .72766 Mdot
.3709 .22982 Mdot
.37733 .23255 Mdot
.52247 .19751 Mdot
.71426 .53409 Mdot
.43622 .84086 Mdot
.2841 .68779 Mdot
.33578 .46657 Mdot
.40457 .69269 Mdot
.65543 .29286 Mdot
.48875 .21824 Mdot
.35408 .40131 Mdot
.45618 .32809 Mdot
.37438 .59632 Mdot
.1552 .56154 Mdot
.61485 .43683 Mdot
.66611 .69137 Mdot
.43798 .6327 Mdot
.5533 .66469 Mdot
.44628 .5807 Mdot
.65781 .76833 Mdot
.35769 .24292 Mdot
.47131 .7208 Mdot
.51196 .69391 Mdot
.59492 .78787 Mdot
.4281 .23478 Mdot
.57313 .33091 Mdot
.68076 .63223 Mdot
.32172 .52976 Mdot
.30016 .73989 Mdot
.60551 .77546 Mdot
.48556 .62257 Mdot
.51746 .78666 Mdot
.51635 .51834 Mdot
.68701 .69931 Mdot
.65663 .76019 Mdot
.4593 .6024 Mdot
.19053 .50083 Mdot
.44172 .75394 Mdot
.72544 .49823 Mdot
.46808 .21299 Mdot
.49268 .77799 Mdot
.36384 .23555 Mdot
.43796 .40348 Mdot
.19783 .6061 Mdot
.50119 .31134 Mdot
.63001 .35228 Mdot
.3467 .44732 Mdot
.30076 .48384 Mdot
.1589 .49866 Mdot
.51711 .80227 Mdot
.2842 .44851 Mdot
.47823 .61756 Mdot
.28134 .27871 Mdot
.74083 .47729 Mdot
.74047 .45193 Mdot
.56828 .22271 Mdot
.48871 .43786 Mdot
.56922 .45348 Mdot
.67344 .57843 Mdot
.44809 .41771 Mdot
.56955 .31749 Mdot
.51967 .53253 Mdot
.32545 .53434 Mdot
.28616 .28867 Mdot
.32191 .77787 Mdot
.48446 .54978 Mdot
.29623 .25703 Mdot
.2782 .47129 Mdot
.39224 .69193 Mdot
.53535 .17884 Mdot
.28277 .42199 Mdot
.39092 .36193 Mdot
.61873 .34492 Mdot
.47776 .63229 Mdot
.31523 .76778 Mdot
.35831 .51898 Mdot
.65211 .34896 Mdot
.63744 .38231 Mdot
.49739 .54664 Mdot
.80476 .48542 Mdot
.58392 .65547 Mdot
.2618 .29141 Mdot
.40955 .22388 Mdot
.62908 .67126 Mdot
.44882 .78321 Mdot
.28041 .43024 Mdot
.19635 .60773 Mdot
.58248 .40319 Mdot
.16897 .5328 Mdot
.70839 .67347 Mdot
.3477 .55508 Mdot
.20258 .39928 Mdot
.42768 .27935 Mdot
.40579 .29404 Mdot
.37784 .6194 Mdot
.32438 .32416 Mdot
.50988 .59008 Mdot
.70748 .29409 Mdot
.50293 .14357 Mdot
.36359 .81348 Mdot
.66563 .77528 Mdot
.43346 .48941 Mdot
.45664 .25385 Mdot
.44064 .75807 Mdot
.52389 .41675 Mdot
.61949 .38473 Mdot
.75196 .46515 Mdot
.65817 .53556 Mdot
.76302 .70356 Mdot
.15875 .57181 Mdot
.34722 .4457 Mdot
.55304 .35421 Mdot
.64679 .24371 Mdot
.6808 .48934 Mdot
.23815 .48588 Mdot
.30445 .76276 Mdot
.67833 .63768 Mdot
.73389 .62474 Mdot
.66114 .57123 Mdot
.21898 .35261 Mdot
.71837 .60378 Mdot
.69278 .61562 Mdot
.17688 .38651 Mdot
.56167 .80761 Mdot
.35821 .70773 Mdot
.7664 .69675 Mdot
.21222 .37711 Mdot
.37441 .58107 Mdot
.74018 .48299 Mdot
.17671 .59284 Mdot
.52162 .37084 Mdot
.69862 .52598 Mdot
.25381 .37285 Mdot
.41824 .21737 Mdot
.47956 .21088 Mdot
.66867 .68244 Mdot
.2633 .45976 Mdot
.67902 .21873 Mdot
.75996 .4936 Mdot
.69059 .79153 Mdot
.1753 .51885 Mdot
.31765 .73962 Mdot
.4792 .7975 Mdot
.64406 .39425 Mdot
.19521 .59754 Mdot
.37586 .23778 Mdot
.27445 .45038 Mdot
.72836 .31677 Mdot
.44958 .28011 Mdot
.48767 .26458 Mdot
.68984 .69575 Mdot
.16604 .48523 Mdot
.72555 .52564 Mdot
.2792 .3639 Mdot
.40455 .21853 Mdot
.28626 .4772 Mdot
.39808 .29598 Mdot
.29216 .73093 Mdot
.30323 .29813 Mdot
.4437 .2036 Mdot
.66797 .54686 Mdot
.59633 .32719 Mdot
.31178 .75969 Mdot
.44089 .56253 Mdot
.36618 .59248 Mdot
.511 .86524 Mdot
.18513 .63275 Mdot
.28184 .41744 Mdot
.43764 .43586 Mdot
.20184 .35022 Mdot
.73163 .40838 Mdot
.28198 .29453 Mdot
.54485 .82592 Mdot
.4906 .20404 Mdot
.43458 .52362 Mdot
.36816 .41106 Mdot
.54018 .24408 Mdot
.38158 .69701 Mdot
.27072 .4572 Mdot
.70361 .57389 Mdot
.43728 .20658 Mdot
.37086 .5607 Mdot
.64844 .80967 Mdot
.37649 .74378 Mdot
.45661 .63865 Mdot
.16952 .58308 Mdot
.22773 .44769 Mdot
.3922 .55961 Mdot
.19674 .5807 Mdot
.57748 .41464 Mdot
.57068 .31841 Mdot
.41277 .56667 Mdot
.50896 .36525 Mdot
.45759 .17484 Mdot
.41924 .83455 Mdot
.30642 .52605 Mdot
.20452 .66964 Mdot
.1563 .46375 Mdot
.4542 .63596 Mdot
.26102 .43501 Mdot
.52344 .34363 Mdot
.45231 .74179 Mdot
.66834 .55551 Mdot
.70708 .546 Mdot
.64353 .22088 Mdot
.68261 .24361 Mdot
.38793 .40697 Mdot
.71015 .67274 Mdot
.16008 .52977 Mdot
.63372 .21643 Mdot
.1607 .54159 Mdot
.3849 .58093 Mdot
.32651 .42584 Mdot
.5853 .86687 Mdot
.5405 .69472 Mdot
.35612 .37222 Mdot
.46264 .42627 Mdot
.46081 .44754 Mdot
.35947 .43472 Mdot
.7036 .61656 Mdot
.51759 .27565 Mdot
.47988 .19976 Mdot
.17777 .58744 Mdot
.46006 .62913 Mdot
.52225 .36298 Mdot
.60624 .63035 Mdot
.47556 .32205 Mdot
.37272 .32195 Mdot
.62743 .61773 Mdot
.48239 .19089 Mdot
.80176 .48832 Mdot
.58949 .36513 Mdot
.54465 .61474 Mdot
.49013 .45921 Mdot
.50432 .6707 Mdot
.50638 .18243 Mdot
.68444 .58926 Mdot
.58546 .25198 Mdot
.40006 .21445 Mdot
.36312 .64117 Mdot
.6627 .69969 Mdot
.589 .15182 Mdot
.51725 .37433 Mdot
.71198 .652 Mdot
.28824 .38844 Mdot
.37505 .72846 Mdot
.18438 .52432 Mdot
.57855 .31697 Mdot
.5174 .57781 Mdot
.35169 .62572 Mdot
.19026 .5858 Mdot
.63927 .61715 Mdot
.15724 .41521 Mdot
.29685 .37832 Mdot
.23875 .49435 Mdot
.28513 .70528 Mdot
.56115 .56061 Mdot
.2396 .611 Mdot
.38315 .4934 Mdot
.56075 .43048 Mdot
.79656 .47797 Mdot
.52964 .61808 Mdot
.5035 .55224 Mdot
.46518 .73687 Mdot
.54115 .19386 Mdot
.20313 .48682 Mdot
.37021 .44303 Mdot
.65622 .27026 Mdot
.50402 .35276 Mdot
.65748 .37217 Mdot
.68807 .38068 Mdot
.60482 .67584 Mdot
.50284 .18451 Mdot
.48621 .20941 Mdot
.21635 .59446 Mdot
.19873 .6373 Mdot
.42006 .51253 Mdot
.17662 .51106 Mdot
.61147 .41711 Mdot
.55627 .76314 Mdot
.30909 .29675 Mdot
.41415 .83181 Mdot
.4151 .54486 Mdot
.44987 .47499 Mdot
.1641 .43254 Mdot
.16596 .50743 Mdot
.59054 .65283 Mdot
.56316 .68145 Mdot
.47609 .14921 Mdot
.51801 .323 Mdot
.76813 .70255 Mdot
.67952 .55375 Mdot
.17579 .40975 Mdot
.52842 .55308 Mdot
.28805 .40296 Mdot
.39511 .59657 Mdot
.39887 .36632 Mdot
.67716 .45588 Mdot
.39505 .76103 Mdot
.37534 .62451 Mdot
.34363 .31946 Mdot
.33846 .47449 Mdot
.62463 .54542 Mdot
.42279 .62889 Mdot
.36962 .81709 Mdot
.6821 .49545 Mdot
.57303 .43193 Mdot
.61297 .82257 Mdot
.7981 .4805 Mdot
.59604 .19338 Mdot
.25699 .70608 Mdot
.58693 .67415 Mdot
.52132 .53091 Mdot
.82553 .57221 Mdot
.40015 .66042 Mdot
.40729 .70039 Mdot
.61591 .58957 Mdot
.50928 .24631 Mdot
.6399 .75519 Mdot
.46463 .85307 Mdot
.16445 .45723 Mdot
.43539 .39936 Mdot
.76863 .73846 Mdot
.39945 .21876 Mdot
.5589 .39214 Mdot
.64748 .75146 Mdot
.16506 .56655 Mdot
.6444 .52031 Mdot
.23433 .31374 Mdot
.47938 .77311 Mdot
.42577 .74347 Mdot
.50349 .25808 Mdot
.7274 .7126 Mdot
.55625 .53588 Mdot
.69339 .78865 Mdot
.57033 .70103 Mdot
.48449 .26992 Mdot
.50992 .80077 Mdot
.40451 .72107 Mdot
.40848 .54182 Mdot
.49507 .74441 Mdot
.30327 .46821 Mdot
.48627 .69144 Mdot
.50791 .70355 Mdot
.57383 .34143 Mdot
.59883 .57727 Mdot
.5397 .68879 Mdot
.63974 .58572 Mdot
.36608 .65988 Mdot
.46221 .16006 Mdot
.73374 .40158 Mdot
.71211 .48396 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0;7ooooo0_l0002Fooooo`007?ooool0
0ol0003oooooooooo`2Uooooo`;o00002_ooool2o`0009Kooooo000Looooo`03o`000?oooooooooo
09gooooo0_l000000ooooooo0000o`000003ooooo`;o00002_ooool2o`0009Kooooo000Looooo`03
o`000?oooooooooo09Sooooo0ol00002ooooo`;o000000?oooooo`000?l000003oooool2o`0000So
oooo0_l0002<ooooo`007?ooool00ol0003oooooooooo`2Gooooo`Co00008?ooool2o`0008cooooo
000Looooo`;o0000V?ooool2o`0002?ooooo0_l0002;ooooo`007?ooool00ol0003oooooooooo`2A
ooooo`?o0000:?ooool4o`0008Wooooo000Looooo`03o`000?oooooooooo093ooooo1?l0000Zoooo
o`;o0000ROooool001cooooo00?o0000ooooooooool0T?ooool4o`000;Gooooo000Looooo`03o`00
0?oooooooooo087ooooo1?l000000ooooooo0000o`000003ooooo`;o00001Oooool2o`000;Gooooo
000Looooo`03o`000?oooooooooo087ooooo1?l000000ooooooo0000o`000007o`000;[ooooo000L
ooooo`03o`000?oooooooooo087ooooo0_l00003ooooo`Go00000_ooool2o`000;[ooooo000Loooo
o`03o`000?oooooooooo087ooooo0_l000000ooooooo0000o`000002o`0000Wooooo0_l0002foooo
o`007?ooool00ol0003oooooooooo`24ooooo`?o00002Oooool3o`000;Kooooo000Looooo`03o`00
0?oooooooooo08Gooooo1Ol00004ooooo`Go00005?ooool2o`000003ooooool0003o000009gooooo
000Looooo`03o`000?oooooooooo08Gooooo1ol00002ooooo`;o000000Coooooo`000?l0003ooooo
0_l0000:ooooo`?o00001?ooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o0000
UOooool001cooooo00?o0000ooooooooool0R_ooool4o`0000Kooooo0_l0000:ooooo`?o00001_oo
ool2o`0000?ooooo1_l00003ooooo`;o0000T?ooool001cooooo00?o0000ooooooooool0R_ooool5
o`0001?ooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l0002@ooooo`0000Koooooonk^
k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0ROoo
ool6o`0000[ooooo0_l00007ooooo`;o00002?ooool4o`0000kooooo0_l00029ooooo`0000Kooooo
ogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Ko
oooo00?o0000ooooooooool0ROooool4o`0000cooooo0_l00007ooooo`;o00002?ooool4o`0000Go
oooo0_l00003ooooo`;o00000_ooool2o`0008Wooooo00000ooooooo410@ooooo`02ooooo`03oa0@
4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`25ooooo`?o0000
00Coooooo`000?l0003o00003?ooool2o`0000Sooooo0_l00002ooooo`;o00002Oooool2o`0000;o
oooo0_l00003ooooo`;o00001Oooool2o`0008Kooooo00000ooooooo0000ooooo`02ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0008;ooooo0_l000000ooooooo0000
o`000005o`0000_ooooo0ol0000<ooooo`;o00002?ooool3o`0000kooooo0ol00025ooooo`0000?o
ooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00Gooooo00?o
0000ooooooooool0POooool8o`000003ooooool0003o000000;o00002Oooool3o`0000;ooooo0_l0
00000ooooooo0000o`00000=ooooo`Co00004?ooool2o`0008Gooooo00000ooooooo410@ooooo`02
ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`21
ooooo`Oo00000_ooool4o`0000[ooooo1_l000000ooooooo0000o`00000=ooooo`?o00002?ooool2
o`0000;ooooo1?l00028ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj
^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`1oooooo`;o00002Oooool2o`0000cooooo
1?l0000Kooooo`Co00000_ooool4o`0008Sooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo07[ooooo1ol000000ooo
oooo0000o`000004ooooo`;o00001oooool2o`000003ooooool0003o000000;ooooo1?l0000Koooo
o`;o00001_ooool2o`0000?ooooo0_l00023ooooo`007?ooool00ol0003oooooooooo`1jooooo`co
00000_ooool4o`0000Gooooo0_l000000ooooooo0000o`000003ooooo`Co00006_ooool2o`0000_o
oooo1?l00002ooooo`;o0000OOooool001cooooo00?o0000ooooooooool0Moooool2o`0000;ooooo
0_l000000ooooooo0000o`000002o`0000;ooooo0_l00003ooooo`?o00003Oooool4o`0001[ooooo
0_l000000ooooooo0000o`00000:ooooo`;o00000_ooool2o`000003ooooool0003o000000[ooooo
0_l0001^ooooo`007?ooool00ol0003oooooooooo`1eooooo`Co00000_ooool2o`000003ooooool0
003o000000Ko00000oooool2o`0000Kooooo0_l00006ooooo`?o000000?oooooo`000?l000005_oo
ool2o`0000?ooooo0_l0000Aooooo`;o00002_ooool2o`0006kooooo000Looooo`03o`000?oooooo
oooo07Gooooo0_l00009ooooo`Ko00002oooool7o`000005ooooool0003o0000o`000?ooool00_l0
000>ooooo`;o00001_ooool2o`0000;ooooo0_l0002>ooooo`007?ooool00ol0003oooooooooo`1d
ooooo`Go00000_ooool2o`0000Kooooo0ol0000=ooooo`Go00005Oooool2o`0000[ooooo0_l0002>
ooooo`007?ooool00ol0003oooooooooo`1/ooooo`;o00001?ooool7o`0000;ooooo0_l0000^oooo
o`;o00003oooool2o`0000Gooooo0ol0000Cooooo`;o0000K_ooool001cooooo00?o0000oooooooo
ool0K?ooool2o`0000;ooooo1?l00003ooooo`;o00003_ooool2o`0002;ooooo0_l00008ooooo`;o
00001Oooool2o`0000Gooooo0ol0000Cooooo`;o0000K_ooool001cooooo00?o0000ooooooooool0
K?ooool2o`0000;ooooo1?l00002ooooo`;o00003oooool2o`0002;ooooo0_l00008ooooo`;o0000
3Oooool2o`0001Cooooo0_l0001]ooooo`007?ooool00ol0003oooooooooo`1`ooooo`;o00001?oo
ool2o`0001?ooooo0_l0000Cooooo`;o00007?ooool2o`0000Wooooo0_l00002ooooo`;o00002ooo
ool2o`0006gooooo000Looooo`03o`000?oooooooooo06kooooo1?l0000Iooooo`Co00000oooool2
o`0000Cooooo0_l00006ooooo`;o00002_ooool2o`0000Oooooo0_l00007ooooo`;o00001oooool4
o`0000;ooooo1?l00009ooooo`?o0000K?ooool001cooooo00?o0000ooooooooool0HOooool2o`00
00Sooooo0_l000000ooooooo0000o`000003o`0000Gooooo0_l0000Booooo`?o00000oooool2o`00
00Cooooo0_l00008ooooo`;o00002?ooool2o`0000Oooooo0_l0000@ooooo`;o00001?ooool4o`00
00Wooooo0ol0001/ooooo`007?ooool2o`0006;ooooo0_l00007ooooo`?o00000oooool3o`0000Go
oooo0_l00006ooooo`;o00003oooool2o`0000oooooo0_l0000Fooooo`?o00003?ooool2o`0000?o
oooo0ol000000ooooooo0000o`000007ooooo`;o0000K?ooool001cooooo00?o0000ooooooooool0
Goooool4o`0000Oooooo0_l00008ooooo`;o00002_ooool2o`0000oooooo1?l0000Uooooo`?o0000
3?ooool2o`000003ooooool0003o000000?ooooo0ol0001eooooo`007?ooool00ol0003ooooooooo
o`1Mooooo`Co00002oooool2o`0000Kooooo0_l00007ooooo`;o00004_ooool4o`0000_ooooo0_l0
0007ooooo`?o00007Oooool5o`0000?ooooo0_l0001fooooo`007?ooool00ol0003oooooooooo`1L
ooooo`?o00001?ooool2o`0000Oooooo0_l00004ooooo`;o00002Oooool3o`0000;ooooo0_l0000:
ooooo`;o00002Oooool2o`0000Gooooo0_l00007ooooo`?o00002?ooool2o`0001Cooooo1?l0001k
ooooo`007?ooool00ol0003oooooooooo`1Looooo`;o00001Oooool2o`0000gooooo0_l0000:oooo
o`;o00000_ooool2o`000003ooooool0003o000000Oooooo0_l000001?oooooo0000o`000?l00005
ooooo`Co00000oooool2o`0000Oooooo0_l00009ooooo`;o00001?ooool2o`0000oooooo1Ol00000
1?oooooo0000o`000?ooool2o`0007?ooooo000Looooo`03o`000?oooooooooo073ooooo0_l00002
ooooo`Co00002_ooool2o`000003ooooool0003o000000Gooooo0ol00002ooooo`Go00001Oooool2
o`0000?ooooo0_l00006ooooo`?o00003oooool2o`0000oooooo2?l000000ooooooo0000o`00001c
ooooo`007?ooool00ol0003oooooooooo`1Zooooo`;o00001?ooool2o`0000;ooooo1?l00004oooo
o`Co00000_ooool2o`0000Oooooo1?l00005ooooo`Co00000_ooool2o`0000Oooooo2?l0000?oooo
o`;o00003_ooool9o`0000Wooooo0_l0001[ooooo`007?ooool00ol0003oooooooooo`1Zooooo`Co
000000?oooooo`000?l000002oooool4o`0000;ooooo0_l000000ooooooo0000o`000007o`0000Oo
oooo0ol00002ooooo`;o00001Oooool9o`0000Wooooo0_l00005ooooo`;o00002_ooool=o`000003
ooooool0003o000000Kooooo0_l000001?oooooo0000o`000?l0001Wooooo`007?ooool00ol0003o
ooooooooo`1Wooooo`;o00000_ooool3o`000003ooooool0003o000000;o000000Coooooo`000?l0
003ooooo0_l00008ooooo`;o00000_ooool9o`0000Oooooo1_l00006ooooo`So00002_ooool2o`00
017ooooo3?l000001?oooooo0000o`000?l00009ooooo`?o0000Ioooool001cooooo00?o0000oooo
ooooool0F?ooool2o`0000gooooo0_l00002ooooo`;o00000_ooool:o`0000Sooooo0_l00004oooo
o`?o00001?ooool2o`0000Oooooo1?l00006ooooo`Go00004_ooool3o`0000gooooo3_l00009oooo
o`;o0000J?ooool001cooooo00?o0000ooooooooool0F?ooool4o`0000Sooooo0_l00009ooooo`;o
000000?oooooo`000?l000001Ol0000>ooooo`;o00000_ooool2o`000003ooooool0003o000000Oo
oooo0_l000000ooooooo0000o`000002o`0000;ooooo0ol00002ooooo`Co00003oooool3o`0000_o
oooo3Ol0000>ooooo`;o0000I_ooool001cooooo00?o0000ooooooooool0Eoooool5o`0000Sooooo
0_l0000?ooooo`Ko00000_ooool3o`000003ooooool0003o000000Sooooo0_l0000:ooooo`;o0000
00?oooooo`000?l000000_l00002ooooo`?o00000_ooool4o`0001cooooo3_l00002ooooo`Co0000
2?ooool2o`0006Kooooo000Looooo`03o`000?oooooooooo05Oooooo1?l00006ooooo`Co00001_oo
ool2o`0000Sooooo1ol000000ooooooo0000o`000005o`000003ooooool0003o000000;o00004ooo
ool3o`000003ooooool0003o000000?ooooo0_l0000Loooooa7o000000?oooooo`000?l000000_l0
001`ooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o00001Oooool3o`0000Kooooo1?l00002
ooooo`;o00000_ooool2o`0000gooooo1?l000001?oooooo0000o`000?ooool2o`000003ooooool0
003o000000Co000000?oooooo`000?l000003oooool5o`0000;ooooo0_l0000Cooooo`;o00002?oo
oolAo`0000?ooooo0_l0001`ooooo`007?ooool00ol0003oooooooooo`1@ooooo`?o00001?ooool3
o`0000Oooooo0_l00004ooooo`;o00004Oooool:o`0000;ooooo2?l00005ooooo`;o00002?ooool3
o`0000Cooooo0_l0000:ooooo`;o00001oooool2o`0000Sooooo4Ol00003ooooo`;o00002Oooool2
o`000003ooooool0003o000006;ooooo000Looooo`03o`000?oooooooooo053ooooo0ol00004oooo
o`?o00001Oooool6o`0001Oooooo1_l00006ooooo`Go00001_ooool2o`0000Sooooo0ol00004oooo
o`;o00002_ooool2o`0000Oooooo0_l00005ooooo`;o00000oooool?o`0000?ooooo0_l00009oooo
o`;o000000?oooooo`000?l00000H_ooool001cooooo0_l0001Dooooo`;o00002_ooool6o`0001So
oooo1_l000000ooooooo0000o`000004o`000003ooooool0003o0000017ooooo0_l00005ooooo`;o
00006OoooolDo`00013ooooo0_l0001Sooooo`007?ooool00ol0003oooooooooo`1Cooooo`Co0000
1_ooool2o`000003ooooool0003o000001cooooo2ol00008ooooo`Co00003_ooool4o`0000Wooooo
0_l0000;ooooo`?o00000_oooolDo`0000kooooo0_l0001Sooooo`007?ooool00ol0003ooooooooo
o`1:ooooo`;o00002?ooool3o`0000Kooooo0_l0000Sooooo`?o00002Oooool7o`0000;ooooo0ol0
0009ooooo`;o00002oooool4o`0000Gooooo0_l00002ooooo`?o00000_oooolAo`000003ooooool0
003o000001;ooooo0_l0001Oooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o00001Oooool2
o`000003ooooool0003o000002cooooo0_l0000:ooooo`Co00001Oooool3o`0000Cooooo0_l00003
ooooo`;o00002oooool4o`0000Gooooo0_l00002ooooo`?o000000?oooooo`000?l000004?l0000E
ooooo`;o0000Goooool001cooooo00?o0000ooooooooool0B?ooool2o`0000Oooooo0_l0000loooo
o`Co00001oooool3o`000004ooooool0003o0000o`00013ooooo0_l00004ooooo`?o00001ooooolD
o`0007Cooooo000Looooo`03o`000?oooooooooo04Sooooo0_l00007ooooo`;o00001?ooool2o`00
03Sooooo0_l000001?oooooo0000o`000?l00003ooooo`Oo00000_ooool2o`0000cooooo0_l00004
ooooo`?o00000_ooool2o`0000;ooooo1ol00002ooooo`co00005?ooool2o`0005kooooo000Loooo
o`03o`000?oooooooooo04Sooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l00000
0ooooooo0000o`00000Cooooo`;o000000?oooooo`000?l000005oooool2o`0000[ooooo1?l00003
ooooo`Co00001?ooool2o`00013ooooo1Ol00002ooooo`;o00000_oooolDo`0000kooooo0_l00005
ooooo`?o0000GOooool001cooooo00?o0000ooooooooool0C_ooool2o`0000Cooooo0_l0000Foooo
o`;o000000?oooooo`000?l000000_ooool4o`00017ooooo0_l0000<ooooo`?o00000oooool2o`00
00Kooooo0ol0000>ooooo`Go00000_ooool2o`0000;ooooo5?l0000>ooooo`;o00001_ooool2o`00
05gooooo000Looooo`03o`000?oooooooooo04kooooo0_l0000Fooooo`;o00001_ooool2o`0000;o
oooo1Ol0000Pooooo`;o00000oooool4o`0000Cooooo0ol0000@ooooo`;o00002?ooool@o`000003
ooooool0003o000007Gooooo000Looooo`03o`000?oooooooooo04;ooooo0ol00007ooooo`;o0000
6?ooool2o`0000Kooooo0_l00002ooooo`;o00001?ooool4o`00017ooooo1Ol000000ooooooo0000
o`000009ooooo`Co00004?ooool2o`0000?ooooo0_l00005ooooo`;o00000_ooool?o`0000Kooooo
0_l0000Eooooo`;o0000FOooool001cooooo00?o0000ooooooooool0@Oooool4o`0000Kooooo0ol0
000Aooooo`;o00001oooool2o`0000kooooo1_l0000?ooooo`Go000000?oooooo`000?l000001_oo
ool3o`0000;ooooo0_l0000?ooooo`?o00000_ooool2o`0000Kooooo0ol000000ooooooo0000o`00
000;o`0000?ooooo0_l00003ooooo`;o00005Oooool2o`0005Wooooo000Looooo`03o`000?oooooo
oooo047ooooo0_l00008ooooo`;o00004_ooool2o`0000Oooooo0_l0000Booooo`;o000000?ooooo
o`000?l000004oooool2o`0000Gooooo0ol0000Cooooo`;o00000oooool2o`0000Kooooo0ol00000
0ooooooo0000o`00000<o`0000;ooooo0_l0001eooooo`007?ooool00ol0003oooooooooo`15oooo
o`;o00000oooool2o`0001Oooooo0_l0000Jooooo`Co00004Oooool4o`0000;ooooo1_l00002oooo
o`;o00003Oooool2o`0000Kooooo0_l00007oooooa3o00006?ooool2o`0005gooooo000Looooo`03
o`000?oooooooooo04Gooooo0_l00003ooooo`;o00005oooool2o`0001cooooo0_l0000Cooooo`;o
000000?oooooo`000?l000001Ol00002ooooo`;o00004oooool4o`0000Oooooo3?l000001?oooooo
0000o`000?l0000Hooooo`;o0000GOooool001cooooo00?o0000ooooooooool0U_ooool2o`000003
ooooool0003o000000Co00000oooool6o`0000oooooo1?l00005ooooo`;o000000?oooooo`000?l0
00000ol000000ooooooo0000o`000004o`0007[ooooo000Looooo`03o`000?oooooooooo09[ooooo
1Ol00005ooooo`Co00004Oooool4o`000003ooooool0003o000000;o00000oooool2o`0000Kooooo
0_l0000Nooooo`;o0000F_ooool001cooooo0_l0000oooooo`;o00007?ooool2o`0003cooooo1_l0
0002ooooo`;o00005Oooool4o`000003ooooool0003o000000Gooooo0_l00009ooooo`;o00006ooo
ool2o`0005[ooooo000Looooo`03o`000?oooooooooo03kooooo0_l00003ooooo`;o00005_ooool3
o`0003cooooo2_l0000=ooooo`;o00004oooool2o`000003ooooool0003o000000Gooooo0_l00000
0ooooooo0000o`00001dooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00001?ooool2o`00
01Kooooo0_l0000Eooooo`;o000000?oooooo`000?l000001_l0000Looooo`Wo00003_ooool3o`00
00[ooooo0_l00007ooooo`Go00002?ooool2o`0001gooooo0_l0001Eooooo`007?ooool00ol0003o
ooooooooo`0mooooo`;o00006oooool2o`0001?ooooo1Ol000000ooooooo0000o`00000;o`0001Ko
oooo2_l0000>ooooo`Co00000_ooool2o`0000Cooooo0ol00008ooooo`;o0000:Oooool2o`0005Go
oooo000Looooo`03o`000?oooooooooo04Cooooo0_l0000Dooooo`;o00004oooool4o`0000Kooooo
2_l00008ooooo`;o00002oooool2o`000003ooooool0003o000000Wooooo0ol00009ooooo`;o0000
0_ooool2o`0000Cooooo1?l00007ooooo`;o00001Oooool2o`0007Wooooo000Looooo`03o`000?oo
oooooooo04Cooooo0_l0000Aooooo`;o00004oooool5o`0000Sooooo1?l000000ooooooo0000o`00
0008o`0000?ooooo0ol0000:ooooo`;o000000?oooooo`000?l000001Oooool7o`0001;ooooo1Ol0
000;ooooo`;o000000?oooooo`000?l00000NOooool001cooooo00?o0000ooooooooool0Eoooool2
o`0001?ooooo1Ol00008ooooo`;o00000oooool;o`0000?ooooo0_l0000:ooooo`;o000000?ooooo
o`000?l000001?ooool7o`0001?ooooo1ol00009ooooo`;o0000:?ooool2o`0005;ooooo000Loooo
o`03o`000?oooooooooo04;ooooo0_l0000Fooooo`;o00003oooool7o`0000_ooooo0_l00002oooo
o`;o000000?oooooo`000?l000000ol00003ooooo`;o00003Oooool8o`000003ooooool0003o0000
00;o00006?ooool3o`0000_ooooo0_l00002ooooo`;o00000oooool2o`0001cooooo0_l0001Boooo
o`007?ooool00ol0003oooooooooo`12ooooo`;o00002oooool2o`0000Wooooo0_l0000>ooooo`?o
00000_ooool3o`0000Cooooo0_l000001?oooooo0000o`000?ooool3o`0000;ooooo0_l000000ooo
oooo0000o`000005o`0000;ooooo0_l0000=ooooo`Ko00000_ooool4o`0001Wooooo0_l00002oooo
o`;o00001oooool2o`0000;ooooo0_l00003ooooo`;o0000L?ooool001cooooo00?o0000oooooooo
ool0@Oooool2o`0000cooooo0_l0000<ooooo`;o00002Oooool4o`0000Gooooo1ol000000ooooooo
0000o`000003o`0000Oooooo1_l00002ooooo`;o00003Oooool4o`0000Cooooo0_l0000<ooooo`;o
00003Oooool6o`0008;ooooo000Looooo`03o`000?oooooooooo047ooooo0_l0000<ooooo`;o0000
3?ooool2o`0000Wooooo0_l00007ooooo`Go00000_ooool8o`0000Sooooo0ol00003ooooo`?o0000
2Oooool2o`0000Gooooo0_l0000?ooooo`;o000000?oooooo`000?l000003?ooool3o`0000Cooooo
0_l0000@ooooo`;o0000Joooool001cooooo00?o0000ooooooooool0=_ooool2o`0000Cooooo0_l0
0003ooooo`;o00003?ooool2o`000003ooooool0003o000000?ooooo0_l0000>ooooo`?o00001?oo
ool2o`0000?ooooo0ol000000ooooooo0000o`00000:o`0000Gooooo1Ol000000ooooooo0000o`00
0003o`0000Oooooo1_l000000ooooooo0000o`00000Booooo`;o00001_ooool2o`0000Gooooo0ol0
0003ooooo`?o00003oooool2o`0006_ooooo000Looooo`03o`000?oooooooooo03Kooooo0_l00000
1?oooooo0000o`000?ooool2o`0000?ooooo0_l00009ooooo`;o00001?ooool2o`0000?ooooo0_l0
000<ooooo`Go000000?oooooo`000?l000003_l00003ooooo`Oo00001?ooool4o`0000;ooooo1?l0
0009ooooo`Co000000?oooooo`000?l000004oooool2o`0000Gooooo0_l00006ooooo`;o00001?oo
ool2o`0000Gooooo0_l0001eooooo`007?ooool00ol0003oooooooooo`0fooooo`;o000000Cooooo
o`000?l0003o00000oooool3o`0000[ooooo0_l0000<ooooo`;o00002Oooool3o`000003ooooool0
003o000001[o00001Oooool3o`0000;ooooo0_l0000;ooooo`;o00001_ooool2o`00013ooooo0_l0
0007ooooo`;o00002oooool2o`0000Cooooo0_l0001eooooo`0000Koooooonk^k_lb<S;o0000oc8b
<_o^k^h5ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0
>_ooool2o`0000?ooooo0ol0000@ooooo`;o00001Oooool3o`0000Wooooo0_l000001?oooooo0000
o`000?l00002oooooaSo00000oooool5o`0000oooooo0ol00003ooooo`Co00003?ooool2o`0000;o
oooo0ol00006ooooo`;o00002oooool2o`0000?ooooo0_l0001fooooo`0000KoooooogMgMonHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
03kooooo1?l0000@ooooo`;o00001Oooool2o`0000Sooooo0_l000000ooooooo0000o`000006o`00
00;ooooo4?l000000ooooooo0000o`000002o`0000?ooooo0_l00002ooooo`?o00003_ooool2o`00
00?ooooo0_l0000>ooooo`;o00000oooool2o`0001Cooooo0_l00002ooooo`;o0000M_ooool00003
ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo00?o0000oooooooo
ool0<_ooool2o`0000Gooooo0_l00003ooooo`;o00008_oooolMo`0000;ooooo1ol00002ooooo`Ko
00003oooool2o`0002cooooo0_l00002ooooo`;o0000M_ooool00003ooooool0003ooooo00;ooooo
00?o0000ooooooooool02Oooool01?m4A4CogMgMooooool00007ooooo`?o0000<_ooool2o`0000Go
oooo0_l00003ooooo`;o00004?ooool2o`0000Sooooo0_l00006ooooo`;o000000?oooooo`000?l0
00001Ol00002ooooo`So000000?oooooo`000?l000003ol00002ooooo`Ko00003?ooool6o`0001Oo
oooo0_l0000>ooooo`;o00001?ooool4o`000003ooooool0003o000000;o00004oooool2o`0005co
oooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`1<ooooo`Ko00000_ooool2o`0000Cooooo0ol00004ooooo`;o
00000_ooool3o`000003ooooool0003o000001ko00000_ooool5o`0000cooooo1_l00004ooooo`;o
00004Oooool2o`0000kooooo0_l00004ooooo`;o00000oooool4o`0001?ooooo0_l0001Looooo`00
00?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo
00?o0000ooooooooool0=?ooool2o`0000Kooooo0_l0000=ooooo`Ko00000oooool2o`0000Gooooo
0_l00003ooooo`?o00000_oooolUo`000003ooooool0003o000000;o00003oooool4o`0000Cooooo
0_l0000[ooooo`?o000000?oooooo`000?l000000_l0000?ooooo`;o00000_ooool2o`0005Wooooo
00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l000001oooool00ol0003o
ooooooooo`0`ooooo`;o00000_ooool3o`0000Gooooo0_l0000=ooooo`;o00002_ooool2o`0000Oo
oooo0_l000000ooooooo0000o`00000>o`000003ooooool0003o000000go000000?oooooo`000?l0
00001Ol00002ooooo`Co00003_ooool2o`0000?ooooo0_l0000]ooooo`?o000000?oooooo`000?l0
00000_l00002ooooo`Go00002?ooool2o`0000;ooooo0_l0001Iooooo`0000Koooooonk^k_lb<S;o
0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0;oooool3o`00
00?ooooo0_l00002ooooo`;o00004_ooool2o`0000Sooooo0_l00007ooooo`;o000000?oooooo`00
0?l000002_l000000ooooooo0000o`00000Fo`000003ooooool0003o000000Cooooo0_l00002oooo
o`;o00002_ooool4o`000003ooooool0003o000000;ooooo0_l0000>ooooo`;o00006oooool2o`00
0004ooooool0003o0000ooooo`Wo0000IOooool001cooooo00?o0000ooooooooool0;oooool2o`00
00Sooooo1?l0000=ooooo`;o000000?oooooo`000?l000002?ooool5o`0000;ooooo1?l00004oooo
o`So000000?oooooo`000?l000006_l00003ooooo`?o00000_ooool2o`0000Wooooo1Ol000000ooo
oooo0000o`000004o`0000kooooo0_l00009ooooo`;o00003?ooool2o`0000;ooooo2ol00002oooo
o`;o00002Oooool2o`0005[ooooo000Looooo`03o`000?oooooooooo03[ooooo0ol0000<ooooo`?o
00001_ooool2o`0000Cooooo1?l00002ooooo`Co00001?ooool2o`000003ooooool0003o0000023o
00000oooool4o`0000_ooooo1?l00002ooooo`Go00005Oooool2o`0000Cooooo0_l0000<ooooo`oo
00003Oooool2o`0005[ooooo000Looooo`03o`000?oooooooooo03Wooooo0ol0000=ooooo`;o0000
1oooool2o`0000Cooooo0_l00004ooooo`Co000000Goooooo`000?l0003o0000ooooo`0Uo`000003
ooooool0003o000000?o00002_ooool3o`0000Cooooo0_l0000Hooooo`;o00003Oooool2o`0000Co
oooo4Ol0000:ooooo`;o000000?oooooo`000?l00000Eoooool001cooooo00?o0000ooooooooool0
>Oooool2o`0000Kooooo0_l0000<ooooo`;o00001oooool4o`0000;ooooo0_l00003ooooob?o0000
0_ooool4o`000003ooooool0003o000000;o00000_ooool2o`0000Oooooo0_l00002ooooo`;o0000
0_ooool2o`0000cooooo0_l0000Eooooo`;o000000?oooooo`000?l000001?ooool2o`000003oooo
ool0003o000000go00003?ooool2o`0005Oooooo000Looooo`03o`000?oooooooooo043ooooo0ol0
000<ooooo`;o00001_ooool2o`000003ooooool0003o000000Oooooo9Ol00002ooooo`;o00001ooo
ool2o`0000_ooooo0_l000001?oooooo0000o`000?l0000<ooooo`;o00002_ooool2o`0000Wooooo
0_l000000ooooooo0000o`000003oooooa?o00003?ooool2o`0005Oooooo000Looooo`03o`000?oo
oooooooo03;ooooo0_l0000<ooooo`;o00004?ooool2o`0000?ooooo0_l000000ooooooo0000o`00
0007ooooo`Wo000000?oooooo`000?l000007Ol00002ooooo`Co00002oooool5o`000003ooooool0
003o000000;ooooo0ol00008ooooo`;o00000_ooool2o`0000Kooooo0_l0000;ooooo`?o00000ooo
oolFo`0000Wooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`0booooo`;o00007Oooool3
o`00017ooooo1_l00002oooooaoo00000_ooool4o`0000_ooooo1?l00002ooooo`;o00000_ooool3
o`0000cooooo0_l00006ooooo`;o00001?ooool2o`0000Gooooo0_l00004oooooaOo000000?ooooo
o`000?l00000G_ooool001cooooo00?o0000ooooooooool0@_ooool2o`0000Wooooo0_l00002oooo
o`;o00001_ooool2o`0000?ooooo0ol000000ooooooo0000o`000002o`0000?ooooo9?l00002oooo
o`?o000000?oooooo`000?l000001_ooool5o`0000;ooooo0_l0000>ooooo`;o00000_ooool2o`00
00Oooooo0ol00002ooooo`;o00002ooooolGo`000004ooooool0003o0000ooooo`;o0000Foooool0
01cooooo00?o0000ooooooooool0@_ooool2o`0000Wooooo0_l000000ooooooo0000o`000002o`00
00Gooooo0_l00003ooooo`?o000000?oooooo`000?l000000_l00003ooooob7o000000?oooooo`00
0?l000000_ooool3o`000003ooooool0003o000000Kooooo1Ol00002ooooo`;o00000oooool2o`00
00Wooooo0_l0000;ooooo`?o00002?ooool2o`0000?ooooo2?l000000ooooooo0000o`00000>o`00
0004ooooool0003o0000ooooo`;o000000?oooooo`000?l00000F?ooool001cooooo00?o0000oooo
ooooool0:oooool2o`0002?ooooo1?l0000BooooobOo00004?ooool3o`0000;ooooo0_l00003oooo
o`;o00005Oooool2o`0000[ooooo0_l00003ooooo`?o00000_ooool3o`000003ooooool0003o0000
00ko000000?oooooo`000?l000001?ooool2o`0005Sooooo000Looooo`03o`000?oooooooooo02[o
oooo0ol0000Iooooo`;o00001oooool2o`0000Sooooo0_l00004ooooo`;o00001OoooolWo`0000;o
oooo0_l000000ooooooo0000o`000009ooooo`;o00000oooool2o`0001[ooooo0_l0000?ooooo`?o
00000_ooool3o`000003ooooool0003o0000017o000000?oooooo`000?l00000Foooool001cooooo
0_l0000[ooooo`;o00006_ooool3o`0000Kooooo1Ol000000ooooooo0000o`000002ooooo`;o0000
1?ooool2o`0000Kooooo9Ol00003ooooo`;o000000?oooooo`000?l000002Oooool2o`0000?ooooo
0_l00009ooooo`;o00003oooool2o`0000Wooooo0ol000000ooooooo0000o`00000Po`0005[ooooo
000Looooo`03o`000?oooooooooo033ooooo0_l0000Eooooo`?o00000oooool7o`000003ooooool0
003o0000013ooooo1ol000000ooooooo0000o`00000Ho`000004ooooool0003o0000ooooo`?o0000
2oooool2o`0000Gooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l00006ooooo`?o
00001_ooool2o`0000Wooooo0ol000000ooooooo0000o`00000Mo`000003ooooool0003o000005[o
oooo000Looooo`03o`000?oooooooooo02oooooo1Ol0000?ooooo`;o00000oooool2o`0000?ooooo
0_l000000ooooooo0000o`000002ooooo`?o00003oooool2o`000003ooooool0003o000001ko0000
00Coooooo`000?l0003ooooo0ol0000;ooooo`;o00001Oooool2o`0000?ooooo1Ol00009ooooo`?o
00001Oooool2o`0000oooooo7Ol000000ooooooo0000o`00001Kooooo`007?ooool00ol0003ooooo
ooooo`0_ooooo`;o000000?oooooo`000?l000003oooool2o`0000gooooo1ol0000;ooooobCo0000
0_ooool6o`000003ooooool0003o000000Sooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo
0_l00007ooooo`?o00002Oooool2o`0000kooooo7_l000000ooooooo0000o`000009ooooo`;o0000
D?ooool001cooooo00?o0000ooooooooool0;oooool2o`000003ooooool0003o000001_ooooo0_l0
00000ooooooo0000o`000002ooooo`?o00002?ooool2o`000004ooooool0003o0000ooooo`Co0000
0ooooolIo`000003ooooool0003o000000;ooooo1ol00008ooooo`Ko00000oooool2o`0000_ooooo
1?l0000;ooooo`;o00002ooooolMo`0000gooooo0_l0001@ooooo`007?ooool00ol0003ooooooooo
o`0_ooooo`;o000000?oooooo`000?l000006oooool2o`00013ooooo0_l00006ooooo`;o00001?oo
oolHo`000003ooooool0003o000000Gooooo0_l0000:ooooo`Go00001Oooool2o`0000cooooo0_l0
0007ooooo`;o00000_ooool2o`0000_ooooo1ol000000ooooooo0000o`00000Co`0000Kooooo0_l0
000Iooooo`;o0000??ooool001cooooo00?o0000ooooooooool0DOooool6o`0000Sooooo0_l00000
0ooooooo0000o`000005ooooo`;o00001?oooolGo`0000;ooooo0_l00007ooooo`;o00002Oooool2
o`0000Kooooo0ol000000ooooooo0000o`000004ooooo`;o00003?ooool2o`0000oooooo7_l00005
ooooo`;o00006Oooool2o`0003cooooo000Looooo`03o`000?oooooooooo04cooooo0_l00003oooo
o`So00001?ooool7o`000004ooooool0003o0000ooooo`;o00001_oooolDo`0000;ooooo0_l00002
ooooo`;o00000_ooool2o`000003ooooool0003o0000017ooooo0_l00002ooooo`?o00000oooool4
o`00013ooooo0_l00009oooooako00000oooool2o`0001_ooooo0_l0000looooo`007?ooool00ol0
003oooooooooo`1<ooooo`;o00002Oooool4o`0000;ooooo0_l00002ooooo`;o00000_ooool2o`00
0003ooooool0003o000000;o00001OoooolBo`000003ooooool0003o000000;o000000Coooooo`00
0?l0003o00000_ooool2o`0001Wooooo0_l00005ooooo`;o00002_ooool3o`0000?ooooo0_l0000<
ooooo`;o000000?oooooo`000?l000005?l00003ooooo`Co00006oooool2o`0003cooooo000Loooo
o`03o`000?oooooooooo03cooooo0_l0000>ooooo`;o00002oooool2o`0000oooooo0_l00002oooo
o`;o00000_ooool>o`000004ooooool0003o0000ooooo`?o000000Coooooo`000?l0003o00000ooo
ool3o`0001Cooooo0ol0000Dooooo`?o00004ooooolGo`000003ooooool0003o000000Co00003ooo
ool2o`0000[ooooo0_l0000looooo`007?ooool00ol0003oooooooooo`0looooo`;o00003_ooool2
o`0000;ooooo0_l0000?ooooo`?o000000?oooooo`000?l000000oooool3o`000003ooooool0003o
000000;o00000_ooool>o`0000Cooooo1?l00005ooooo`;o00005?ooool6o`0001cooooo0_l00005
ooooo`;o00000_oooolJo`000004ooooool0003o0000o`0000oooooo0_l00018ooooo`007?ooool0
0ol0003oooooooooo`0booooo`;o00002Oooool2o`0000_ooooo0_l00004ooooo`;o00003?ooool2
o`000005ooooool0003o0000o`000?ooool00_l00003ooooo`?o00000oooool2o`000004ooooool0
003o0000ooooo`Ko000000?oooooo`000?l000000ol00004ooooo`;o00007?ooool2o`0000;ooooo
0ol0000Looooo`;o00001Oooool2o`0000;ooooo6?l000000ooooooo0000o`000002o`00013ooooo
0_l000000ooooooo0000o`000015ooooo`007?ooool00ol0003oooooooooo`0`ooooo`Co00002Ooo
ool3o`0000[ooooo0_l000001?oooooo0000o`000?ooool2o`0000cooooo0_l00002ooooo`;o0000
0oooool2o`0000Cooooo1Ol000000ooooooo0000o`000003ooooo`So000000Coooooo`000?l0003o
oooo0_l00003ooooo`;o00006Oooool2o`0000;ooooo0ol0000=ooooo`;o00004oooool2o`0000Go
oooo4_l000001?oooooo0000o`000?ooool3o`0001Cooooo0ol00015ooooo`007?ooool00ol0003o
ooooooooo`0Xooooo`;o00000oooool2o`000003ooooool0003o000000cooooo0_l0000=ooooo`;o
00004oooool2o`000003ooooool0003o000000;o000000Coooooo`000?l0003ooooo0ol00006oooo
o`;o00001?ooool4o`000004ooooool0003o0000ooooo`;o00000oooool2o`0001gooooo2?l00006
ooooo`Co00003oooool6o`0000Cooooo2_l00002ooooo`[o000000?oooooo`000?l000003oooool2
o`0000Cooooo0_l00002ooooo`;o00001?ooool2o`0003cooooo000Looooo`03o`000?oooooooooo
02Sooooo0_l00003ooooo`;o000000?oooooo`000?l000002oooool2o`0000_ooooo0_l0000Ioooo
o`;o000000?oooooo`000?l000000_l00004ooooo`;o00000_ooool4o`000003ooooool0003o0000
00;ooooo0_l00007ooooo`?o00000oooool2o`0001_ooooo4Ol0000?ooooo`Co00001Oooool3o`00
00;ooooo4_l00009ooooo`?o00001_ooool2o`0000Gooooo0_l000000ooooooo0000o`000004oooo
o`;o0000??ooool001cooooo00?o0000ooooooooool0<?ooool2o`0000_ooooo0_l0000;ooooo`;o
00007?ooool3o`0000Gooooo1ol00002ooooo`;o000000?oooooo`000?l000001_l00002ooooo`?o
00000oooool2o`0001Cooooo0_l00009ooooo`co00004Oooool2o`0000;ooooo0_l00002ooooo`;o
00000oooool<o`0000?ooooo1?l00002ooooo`;o00001?ooool3o`0000gooooo0_l00007ooooo`;o
0000??ooool001cooooo0_l0000aooooo`;o00000oooool2o`0000?ooooo0_l0000^ooooo`;o0000
1_ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000002?l0000Nooooo`;o0000
00?oooooo`000?l000000_l00005ooooo`So000000?oooooo`000?l000003oooool4o`0000;ooooo
0_l00004ooooo`?o000000Coooooo`000?l0003ooooo1Ol000001?oooooo0000o`000?ooool6o`00
00;ooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`0_ooooo`?o000000?oooooo`000?l0
00000_l00003ooooo`;o0000;Oooool3o`0000_ooooo0_l000001?oooooo0000o`000?ooool2o`00
00Sooooo0_l0000Gooooo`;o00000oooool5o`0000Cooooo1?l00002ooooo`Go000000Coooooo`00
0?l0003o00002oooool3o`0000Wooooo0ol000000ooooooo0000o`000002o`000003ooooool0003o
000000Gooooo1ol0000<ooooo`;o00004_ooool2o`0003cooooo000Looooo`03o`000?oooooooooo
02Kooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0ol0000dooooo`Co00004?ooool2
o`0000Sooooo0_l0000Gooooo`;o00000_ooool2o`000004ooooool0003o0000o`0000[ooooo1?l0
0002ooooo`?o00004?ooool2o`0000_ooooo0ol00006ooooo`;o00001?ooool2o`0000cooooo0_l0
000Booooo`;o0000??ooool001cooooo00?o0000ooooooooool09_ooool2o`0000Cooooo0_l00004
ooooo`;o00000_ooool2o`0001;ooooo0_l0000Oooooo`;o00006?ooool2o`0001cooooo0ol0000>
ooooo`?o00005_ooool2o`0000cooooo0_l00006ooooo`;o000000?oooooo`000?l000002?ooool2
o`0001Wooooo0_l0000looooo`007?ooool00ol0003oooooooooo`0fooooo`;o00001_ooool2o`00
00[ooooo0_l0000Mooooo`;o00001Oooool2o`0001?ooooo0_l0000Looooo`Co000000?oooooo`00
0?l000002_ooool3o`0000;ooooo0_l0000Oooooo`;o00002_ooool2o`0000Sooooo0_l0000Ioooo
o`;o00006?ooool2o`0002;ooooo000Looooo`03o`000?oooooooooo037ooooo1?l00009ooooo`;o
00002Oooool4o`00013ooooo0_l000000ooooooo0000o`000007ooooo`;o00001Oooool2o`00017o
oooo1?l00002ooooo`;o00006_ooool6o`000004ooooool0003o0000ooooo`;o00000oooool3o`00
00;ooooo0ol0000Nooooo`;o00004?ooool2o`0003Kooooo0ol0000Rooooo`007?ooool00ol0003o
ooooooooo`0aooooo`Ko00004_ooool4o`00013ooooo0_l000000ooooooo0000o`00000;ooooo`;o
000000Coooooo`000?l0003o00000_ooool2o`0000?ooooo0_l00006ooooo`Co00000oooool2o`00
01Wooooo0_l000000ooooooo0000o`000002o`000004ooooool0003o0000ooooo`;o00000_ooool3
o`0000Cooooo0_l0000@ooooo`Co00007?ooool2o`0003Kooooo0_l0000Sooooo`007?ooool00ol0
003oooooooooo`0dooooo`?o00004?ooool2o`0001?ooooo0ol00002ooooo`?o00002Oooool3o`00
0003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000002o`0000Kooooo1?l0000Loooo
o`Co00000oooool2o`0000Cooooo0_l00002ooooo`?o00005_ooool4o`000003ooooool0003o0000
00Cooooo0_l0000aooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0=Oooool2o`000003
ooooool0003o000000gooooo0_l0000Cooooo`;o00000_ooool6o`0000Sooooo0_l00003ooooo`;o
00000oooool3o`0000Oooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool2o`0001?o
oooo0_l0000@ooooo`;o00006?ooool2o`000003ooooool0003o000000Cooooo0_l000001?oooooo
0000o`000?ooool4o`0000Oooooo0_l00002ooooo`;o00006_ooool4o`0003gooooo000Looooo`03
o`000?oooooooooo033ooooo0_l00003ooooo`;o000000?oooooo`000?l000009?ooool4o`0000;o
oooo0_l0000=ooooo`;o00002_ooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`00
00;ooooo0_l0000Gooooo`;o00002oooool4o`0001[ooooo0ol00006ooooo`Oo00001oooool2o`00
00;ooooo0_l0000Jooooo`;o0000?oooool001cooooo00?o0000ooooooooool0<?ooool2o`0000oo
oooo0_l00005ooooo`;o00004oooool3o`0000Gooooo0ol0000Gooooo`;o000000Coooooo`000?l0
003ooooo0_l00004ooooo`;o00003_ooool2o`000004ooooool0003o0000ooooo`;o00000_ooool3
o`0000Kooooo0_l000000ooooooo0000o`000004o`0000?ooooo0_l0000Booooo`;o00000_ooool2
o`0000Sooooo0_l0000;ooooo`;o0000G_ooool001cooooo00?o0000ooooooooool0<?ooool2o`00
0003ooooool0003o000000Wooooo0_l000000ooooooo0000o`000005ooooo`Co00004Oooool2o`00
00Kooooo0ol0000Jooooo`;o000000?oooooo`000?l000001?ooool2o`000004ooooool0003o0000
ooooo`Co00001_ooool5o`000003ooooool0003o000000;ooooo0ol00006ooooo`;o000000Cooooo
o`000?l0003ooooo0ol00003ooooo`;o00004Oooool3o`0000;ooooo0_l0000@ooooo`Co000000?o
ooooo`000?l00000G_ooool001cooooo00?o0000ooooooooool0<oooool2o`0000Wooooo0_l0000:
ooooo`;o00004oooool2o`0000Gooooo1Ol0000Fooooo`Co000000?oooooo`000?l000000oooool2
o`000003ooooool0003o000000Go00000oooool3o`000003ooooool0003o000000;o000000?ooooo
o`000?l000003_ooool2o`0000;ooooo0_l00004ooooo`;o00004?ooool2o`0000?ooooo0_l0000@
ooooo`Co00008_ooool2o`0003gooooo000Looooo`03o`000?oooooooooo037ooooo0_l0000;oooo
o`;o00002Oooool3o`0001?ooooo0_l00007ooooo`Go00004oooool5o`000003ooooool0003o0000
00?ooooo0_l00002ooooo`;o00001oooool3o`0000Kooooo0_l0000>ooooo`;o00000_ooool3o`00
00?ooooo0_l0000Fooooo`;o000000?oooooo`000?l000001oooool2o`000003ooooool0003o0000
02Kooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0]ooooo`?o000000?oooooo`000?l0
00002oooool3o`0000Sooooo0ol0000Mooooo`Co00004oooool9o`0000Wooooo0_l000000ooooooo
0000o`00000Cooooo`;o00002_ooool2o`0000;ooooo0_l0000Gooooo`Go00001oooool5o`0000[o
oooo0_l0001Iooooo`007?ooool00ol0003oooooooooo`0]ooooo`?o00003oooool2o`0003kooooo
0ol000000ooooooo0000o`000004o`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l00000
1oooool2o`0000[ooooo0_l00008ooooo`Co00000_ooool4o`0000Wooooo0_l00003ooooo`;o0000
1_ooool3o`0000Wooooo1_l00008ooooo`;o0000FOooool001cooooo0_l00015ooooo`;o0000;_oo
ool2o`0000Wooooo0ol00006ooooo`;o00001?ooool2o`000003ooooool0003o000000Oooooo0_l0
0002ooooo`;o00005?ooool4o`0000?ooooo0ol000000ooooooo0000o`000006ooooo`;o00000ooo
ool2o`0000;ooooo0ol00002ooooo`;o000000?oooooo`000?l000001_ooool6o`0003gooooo0_l0
000Tooooo`007?ooool00ol0003oooooooooo`0cooooo`Go00002?ooool2o`0000;ooooo0_l0000^
ooooo`?o00004Oooool2o`0000Oooooo0_l00006ooooo`?o00000_ooool4o`0000Kooooo0_l0000A
ooooo`?o000000?oooooo`000?l000000_l00007ooooo`;o00001?ooool5o`0000?ooooo0ol00005
ooooo`?o00009Oooool2o`0001Wooooo0_l0000Tooooo`007?ooool00ol0003oooooooooo`0coooo
o`Go00002?ooool2o`000003ooooool0003o000002Sooooo0_l00006ooooo`?o00000oooool2o`00
01cooooo0_l00003ooooo`Co00000_ooool2o`000004ooooool0003o0000o`0000Oooooo0_l00000
0ooooooo0000o`000005ooooo`?o00000oooool2o`0000Oooooo0_l00006ooooo`Go00000_ooool5
o`0000?ooooo0_l0000Uooooo`;o0000?oooool001cooooo00?o0000ooooooooool0@oooool2o`00
00Gooooo0_l0000Qooooo`;o00001?ooool2o`000003ooooool0003o000000?ooooo0ol0000Boooo
o`;o00001_ooool2o`0000Kooooo0_l00002ooooo`;o000000?oooooo`000?l000001?ooool2o`00
00;ooooo0_l000000ooooooo0000o`000003o`0000;ooooo0_l0000=ooooo`;o00002Oooool2o`00
00;ooooo1Ol00003ooooo`;o00009_ooool2o`0003kooooo000Looooo`03o`000?oooooooooo02oo
oooo0_l00003ooooo`;o00004?ooool2o`000004ooooool0003o0000o`0002Oooooo1?l00005oooo
o`;o00003Oooool2o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`;o00001Oooool5o`00
00Wooooo1?l00002ooooo`Ko00004Oooool2o`0000gooooo0_l00006ooooo`;o00009_ooool2o`00
03kooooo000Looooo`03o`000?oooooooooo02oooooo1ol0000@ooooo`;o000000Coooooo`000?l0
003o00006oooool5o`0000Wooooo0_l0000Dooooo`;o00001_ooool2o`0000Cooooo0ol00003oooo
o`Ko00002_ooool2o`0000;ooooo0_l0000Tooooo`;o00001_ooool3o`0006Gooooo000Looooo`03
o`000?oooooooooo037ooooo1Ol0000:ooooo`;o00002?ooool2o`0001_ooooo1Ol0000Fooooo`?o
00005?ooool3o`000003ooooool0003o000000Oo00004oooool2o`000004ooooool0003o0000o`00
01;ooooo0ol00005ooooo`;o00001oooool2o`0003cooooo0_l0000Wooooo`007?ooool00ol0003o
ooooooooo`0`ooooo`Co00002Oooool2o`000003ooooool0003o000002?ooooo0_l00002ooooo`;o
00003oooool2o`0000Kooooo1?l0000Gooooo`_o00003_ooool2o`000004ooooool0003o0000oooo
o`?o00002?ooool2o`0000?ooooo0_l00003ooooo`Co00001?ooool2o`0000;ooooo0_l0000Yoooo
o`;o00005_ooool2o`0002Oooooo000Looooo`03o`000?oooooooooo033ooooo1?l00004ooooo`;o
00000oooool2o`0000Oooooo0ol0000Looooo`;o00004oooool2o`0000Gooooo1Ol0000Aooooo`;o
00001?ooool;o`0000kooooo0ol000000ooooooo0000o`00000;ooooo`;o00000oooool2o`0000Go
oooo0_l00002ooooo`Co00000_ooool2o`0000;ooooo0_l0000Uooooo`;o0000?oooool001cooooo
00?o0000ooooooooool0<?ooool2o`0000Kooooo0_l00003ooooo`;o00001_ooool4o`0003Oooooo
1Ol0000Booooo`;o00000_ooool<o`00013ooooo0_l000000ooooooo0000o`000003ooooo`;o0000
2?ooool2o`0000cooooo0_l00006ooooo`Co0000I_ooool001cooooo00?o0000ooooooooool0??oo
ool2o`0000Oooooo1?l00004ooooo`;o00007_ooool2o`0000Oooooo1Ol00005ooooo`Co00002Ooo
ool2o`0000?ooooo1_l000000ooooooo0000o`00000<o`0000cooooo1Ol00007ooooo`;o00001_oo
ool5o`0000_ooooo1?l00002ooooo`Co0000J?ooool001cooooo00?o0000ooooooooool0<oooool2
o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`;o00002?ooool4o`0001gooooo0_l00000
0ooooooo0000o`000004ooooo`Go00001Oooool4o`0000Wooooo0_l00003ooooo`Ko000000?ooooo
o`000?l000003?l0000<ooooo`Go00003oooool5o`0000gooooo0_l000001?oooooo0000o`000?l0
000nooooo`;o0000:_ooool001cooooo00?o0000ooooooooool0<oooool2o`000004ooooool0003o
0000ooooo`?o00001_ooool2o`0000;ooooo0ol00003ooooo`Co00008?ooool2o`000003ooooool0
003o000000;ooooo0_l00007ooooo`Co00003Oooool6o`0000?ooooo3Ol00009ooooo`;o000000?o
ooooo`000?l000001?l0000@ooooo`;o000000Coooooo`000?l0003ooooo0_l00007ooooo`;o0000
0_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000hooooo`;o0000:_ooool001cooooo00?o
0000ooooooooool0=_ooool2o`0000;ooooo0_l0000:ooooo`?o0000:_ooool2o`0000;ooooo0_l0
0006ooooo`Go00003Oooool2o`0000Kooooo3_l00009ooooo`;o000000?oooooo`000?l000000_oo
ool2o`0000_ooooo0_l00006ooooo`;o000000?oooooo`000?l000001oooool2o`000003ooooool0
003o000000?ooooo0_l000000ooooooo0000o`00001Tooooo`0000Koooooonk^k_lb<S;o0000oc8b
<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000oooooooo
ool0=_ooool2o`0000Gooooo0_l00002ooooo`?o00000_ooool4o`0002Kooooo0_l000000ooooooo
0000o`00000:ooooo`Co00002oooool2o`0000Wooooo3Ol0000:ooooo`;o00000oooool2o`0000_o
oooo1?l0000Eooooo`;o000000?oooooo`000?l000000_ooool3o`0003Kooooo0_l0000/ooooo`00
00KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So
8B4Q00Kooooo00?o0000ooooooooool0<oooool2o`000003ooooool0003o000000Gooooo0_l00002
ooooo`Co00000oooool2o`0002Cooooo1ol000000ooooooo0000o`000005ooooo`;o000000Cooooo
o`000?l0003o00002oooool2o`0000[ooooo2ol0000;ooooo`;o00000oooool2o`0000Sooooo1_l0
000Iooooo`Oo0000=_ooool2o`0002cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooo
oooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo03?ooooo0_l0
0007ooooo`;o00001?ooool3o`0000?ooooo0_l0000Tooooo`Go00000oooool2o`0000Gooooo0_l0
00001?oooooo0000o`000?l0000Gooooo`[o00001oooool2o`0000;ooooo1?l0000<ooooo`?o0000
00?oooooo`000?l000000_ooool2o`0000?ooooo0_l0000Aooooo`Ko0000I?ooool00003ooooool0
003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo
0ol0000dooooo`;o00001?ooool4o`0000[ooooo0_l0000/ooooo`;o00002?ooool2o`0000oooooo
0_l00006ooooo`Wo00002Oooool2o`0000;ooooo1?l0000;ooooo`?o00001_ooool2o`0000?ooooo
1_l00002ooooo`?o00003oooool2o`0000Cooooo0_l0000/ooooo`;o0000;Oooool00003ooooool0
003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo
00?o0000ooooooooool0=?ooool2o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o0000
1?ooool4o`0000Wooooo0_l0000Pooooo`?o00001_ooool3o`0000Sooooo0_l00005ooooo`;o0000
0oooool2o`000003ooooool0003o000000Go00002oooool2o`0000?ooooo0_l0000<ooooo`;o0000
00?oooooo`000?l000001Oooool2o`0000Cooooo1?l00002ooooo`Go00001oooool2o`0000Cooooo
0_l00004ooooo`;o0000;?ooool2o`0002gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oo
oooooooo00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`0dooooo`;o00001_oo
ool3o`0000;ooooo0_l00004ooooo`Go00002?ooool2o`0001?ooooo0_l00008ooooo`?o000000?o
ooooo`000?l000001_ooool2o`0000Wooooo0_l000000ooooooo0000o`000004ooooo`;o000000?o
ooooo`000?l000000oooool3o`0000gooooo1Ol0000>ooooo`Go00001Oooool3o`0000Gooooo0_l0
0004ooooo`Ko00000_ooool4o`0000Cooooo0_l0001Qooooo`0000KoooooogMgMonHV9SooooooiRH
V?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0=?ooool2o`0000Kooooo
0_l00005ooooo`;o00001Oooool2o`0000Wooooo0_l0000Booooo`;o00002?ooool3o`0001Cooooo
0_l000000ooooooo0000o`000004ooooo`;o00001_ooool3o`0000kooooo1?l0000=ooooo`Co0000
1_oooolEo`0000;ooooo0_l00002ooooo`;o0000IOooool00006ooooooo^k^ko<S8bo`000?lb<S;o
k^k^3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo04?ooooo0_l00005oooo
o`?o00002?ooool2o`0001;ooooo0_l0000Oooooo`;o00001Oooool4o`000003ooooool0003o0000
00?ooooo0_l0000?ooooo`?o00001Oooool2o`0000Oooooo0ol00005oooooa?o000000?oooooo`00
0?l000000_ooool2o`000003ooooool0003o000000;o0000IOooool001cooooo00?o0000oooooooo
ool0@oooool2o`0000Kooooo0ol00008ooooo`;o00004Oooool2o`00027ooooo0_l00003ooooo`Wo
00003_ooool3o`000004ooooool0003o0000o`0000Gooooo0_l00005ooooo`;o00002?oooolJo`00
0004ooooool0003o0000o`0001oooooo0ol0000Aooooo`;o0000<Oooool001cooooo00?o0000oooo
ooooool0B_ooool4o`0000Cooooo0_l00002ooooo`;o00005_ooool4o`0000Gooooo0_l00009oooo
o`;o000000?oooooo`000?l000001Oooool3o`000003ooooool0003o000000Go000000?oooooo`00
0?l000003_ooool3o`0000Kooooo0_l00008ooooo`Co000000Coooooo`000?l0003ooooo0_l00000
0ooooooo0000o`00000Fo`0000?ooooo0_l0000Oooooo`?o00004Oooool2o`00037ooooo000Loooo
o`03o`000?oooooooooo03Kooooo0_l00002ooooo`Co00002oooool3o`000003ooooool0003o0000
00;o000000?oooooo`000?l000006_ooool4o`0000Cooooo0ol00009ooooo`Go00001_ooool2o`00
0003ooooool0003o000000_o00000oooool2o`0000Gooooo1?l00006ooooo`?o00002Oooool2o`00
0003ooooool0003o000000?o000000Coooooo`000?l0003ooooo5Ol00003ooooo`;o00002?ooool2
o`0005cooooo000Looooo`03o`000?oooooooooo03Kooooo0_l00002ooooo`Go00002_ooool2o`00
0003ooooool0003o000000Co00007Oooool5o`0000;ooooo0_l00004ooooo`;o00000oooool2o`00
0004ooooool0003o0000ooooo`?o00000_ooool4o`000003ooooool0003o000000?o000000?ooooo
o`000?l000001?l00003ooooo`;o00001Oooool4o`0000Oooooo0_l00008ooooo`;o00000_ooool4
o`0000Cooooo5_l00003ooooo`;o00002?ooool2o`0005cooooo000Looooo`03o`000?oooooooooo
03Oooooo0_l00004ooooo`;o00003Oooool3o`000003ooooool0003o000001Sooooo2_l00008oooo
o`;o00000oooool2o`000003ooooool0003o000000[o00000_ooool4o`000003ooooool0003o0000
00?ooooo0_l00002ooooo`;o000000?oooooo`000?l000000oooool2o`0000Cooooo1?l0000:oooo
o`;o00000ooooolKo`0003Oooooo0_l0000dooooo`007?ooool00ol0003oooooooooo`0gooooo`?o
00003?ooool2o`0000;ooooo1_l0000:ooooo`;o00003_ooool9o`0000Wooooo0_l000001?oooooo
0000o`000?ooool2o`0000;ooooo1ol000000ooooooo0000o`000004o`0000?ooooo0_l00003oooo
o`;o00000_ooool2o`000004ooooool0003o0000o`0000Sooooo1?l00009ooooo`;o00000ooooolM
o`0000[ooooo0_l0000Fooooo`;o00004_ooool2o`0003Cooooo000Looooo`03o`000?oooooooooo
03Oooooo1?l00002ooooo`;o00001oooool2o`0000;ooooo0ol000000ooooooo0000o`000002o`00
00Sooooo0_l0000Aooooo`;o000000Coooooo`000?l0003o00000oooool2o`0000Oooooo0_l00000
0ooooooo0000o`000004ooooo`;o000000Coooooo`000?l0003ooooo1ol000000ooooooo0000o`00
0002o`0000[ooooo0_l0000Cooooo`Co00000oooool2o`000003ooooool0003o000001[o00002?oo
ool2o`0001Kooooo0_l0000Aooooo`;o0000=Oooool001cooooo00?o0000ooooooooool0>?ooool3
o`0000;ooooo0_l0000@ooooo`?o00002?ooool2o`00017ooooo0_l000000ooooooo0000o`000004
ooooo`?o00001_ooool2o`0000Cooooo0_l000000ooooooo0000o`00000;o`000003ooooool0003o
000000;o00002oooool2o`0001;ooooo0ol000001?oooooo0000o`000?l00002oooooago0000<ooo
ool2o`0003Gooooo000Looooo`03o`000?oooooooooo03Sooooo0ol0000:ooooo`;o00001?ooool2
o`0000?ooooo0ol00003ooooo`;o00000_ooool2o`00013ooooo0ol00003ooooo`Co000000?ooooo
o`000?l000001_ooool2o`0000?ooooo5?l00003ooooo`Co00001_ooool2o`0001?ooooo0_l00000
0ooooooo0000o`00000Co`000003ooooool0003o000000[o0000J_ooool001cooooo00?o0000oooo
ooooool0AOooool4o`0000;ooooo0_l00003ooooo`Go000000Coooooo`000?l0003o00003oooool2
o`0000;ooooo0ol00003ooooo`Co000000?oooooo`000?l000001?ooool4o`000003ooooool0003o
000001_o00007_ooool6o`000003ooooool0003o000001Go000000Coooooo`000?l0003o0000J_oo
ool001cooooo00?o0000ooooooooool0Aoooool2o`0000Oooooo1Ol00002ooooo`Co00003Oooool2
o`0000;ooooo1?l00009ooooo`;o00000_ooool3o`0000;ooooo6Ol0000Pooooo`Co00001OoooolK
o`00033ooooo0_l0000hooooo`007?ooool2o`00043ooooo0_l00005ooooo`;o00001?ooool2o`00
00;ooooo0_l00007ooooo`Co00002?ooool2o`0000Gooooo1?l00009ooooo`;o00001ooooolIo`00
00Wooooo0_l00009ooooo`?o00001Oooool2o`0000;ooooo0ol00006oooooaWo000000?oooooo`00
0?l000000oooool2o`0002[ooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0mooooo`Co
000000?oooooo`000?l000000_ooool5o`000005ooooool0003o0000o`000?ooool00_l00002oooo
o`;o00001?ooool3o`0000Sooooo0_l00004ooooo`;o000000?oooooo`000?l000003?ooool3o`00
00Cooooo5ol0000:ooooo`;o00002Oooool3o`0000?ooooo2Ol00006ooooo`oo000000?oooooo`00
0?l000001ol000000ooooooo0000o`000003ooooo`;o00005oooool2o`0004_ooooo000Looooo`03
o`000?oooooooooo03gooooo0_l00003ooooo`;o00000_ooool5o`0000;ooooo0_l00005ooooo`;o
00003oooool2o`0000Cooooo1ol00006ooooo`;o00000_ooool3o`0000?ooooo6?l00009ooooo`;o
00003?ooool2o`0000;ooooo0ol000000ooooooo0000o`000003o`0000Cooooo5ol00002ooooo`;o
00007oooool2o`0004_ooooo000Looooo`03o`000?oooooooooo03gooooo0_l0000Eooooo`Co0000
3Oooool2o`000003ooooool0003o000000?ooooo0_l000001?oooooo0000o`000?ooool2o`0000?o
oooo0_l00002ooooo`Co000000?oooooo`000?l000005Ol00004ooooo`;o00001?ooool3o`0000co
oooo0_l00003ooooo`Co00002?ooool3o`000003ooooool0003o000001?o00002?ooool2o`0006Co
oooo000Looooo`03o`000?oooooooooo03gooooo0_l0000Eooooo`Co00003oooool3o`000003oooo
ool0003o000000Kooooo0ol00008oooooaco00000_ooool2o`0000Cooooo0_l0000<ooooo`;o0000
1_ooool3o`0000Oooooo0ol000000ooooooo0000o`00000Co`0000Sooooo1?l0001Rooooo`007?oo
ool00ol0003oooooooooo`19ooooo`;o00007?ooool2o`0000;ooooo0_l00007ooooo`;o00002?oo
ool7o`000003ooooool0003o000001;o000000?oooooo`000?l000001?ooool3o`0000?ooooo0_l0
0006ooooo`?o00000oooool6o`0000;ooooo0_l000000ooooooo0000o`000003oooooaKo00002_oo
ool2o`0000oooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00002?ooool2
o`0003;ooooo7Ol000001?oooooo0000o`000?l00002ooooo`?o00001?ooool2o`0000Kooooo0_l0
0003ooooo`Oo00000_ooool2o`000003ooooool0003o000000?ooooo0_l00002ooooo`oo00003Ooo
ool2o`0000kooooo0ol0001Aooooo`007?ooool00ol0003oooooooooo`0oooooo`Oo0000=?oooolP
o`0000;ooooo0_l00002ooooo`;o00003Oooool2o`000003ooooool0003o000000Co000000?ooooo
o`000?l000001?l00002ooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo1?l00000
0ooooooo0000o`000002o`0000_ooooo0ol0000@ooooo`;o0000D_ooool001cooooo00?o0000oooo
ooooool0@Oooool5o`0002Wooooo0_l00008ooooo`Co00000_oooolKo`0000?ooooo0_l0000=oooo
o`;o00001?ooool6o`000003ooooool0003o000000?o00000oooool5o`0000Sooooo1?l0000?oooo
o`Go00008oooool2o`0003kooooo000Looooo`03o`000?oooooooooo04;ooooo0ol0000;ooooo`;o
00003Oooool2o`0000_ooooo0_l000001?oooooo0000o`000?l00007ooooo`;o00001OoooolAo`00
0003ooooool0003o000000Ko00000oooool3o`0000cooooo0_l00006ooooo`Co00001?ooool2o`00
00?ooooo0ol0000Mooooo`;o000000?oooooo`000?l000002oooool2o`0001Gooooo0ol0000noooo
o`007?ooool00ol0003oooooooooo`12ooooo`;o00002?ooool2o`0000;ooooo0_l0000=ooooo`;o
00002oooool2o`000004ooooool0003o0000o`0000kooooo6?l00005ooooo`?o00004oooool6o`00
00Wooooo0_l0000Aooooo`;o00002_ooool2o`0000kooooo0_l0000Eooooo`;o0000?oooool001co
oooo00?o0000ooooooooool0@_ooool2o`0000Sooooo0_l0000Hooooo`;o00001oooool2o`0000Go
oooo0_l00008oooooaSo00001Oooool3o`0000[ooooo0_l00007ooooo`?o000000?oooooo`000?l0
00003_ooool2o`0000Oooooo0_l00003ooooo`;o00001Oooool2o`0000Gooooo0ol0001Sooooo`00
7?ooool00ol0003oooooooooo`13ooooo`;o00002Oooool2o`0000Gooooo0_l00002ooooo`;o0000
2oooool2o`0000Gooooo0_l00007ooooo`;o00001?ooool2o`0000;ooooo5_l0000Dooooo`Co0000
1_ooool3o`0000Kooooo0_l00002ooooo`;o00001?ooool2o`0000Oooooo0_l0000:ooooo`;o0000
1Oooool3o`0006?ooooo000Looooo`03o`000?oooooooooo04?ooooo0_l00004ooooo`;o00000ooo
ool2o`0000Gooooo0_l000001?oooooo0000o`000?l0000:ooooo`?o00001Oooool2o`0000Oooooo
0_l00004oooooa[o00001?ooool2o`0000?ooooo0_l00009ooooo`Go00000_ooool2o`0000;ooooo
0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`0000_ooooo0_l00005ooooo`;o0000
00?oooooo`000?l000000_ooool2o`0000oooooo1?l0001Hooooo`007?ooool00ol0003ooooooooo
o`19ooooo`;o00003Oooool2o`0000;ooooo0_l00007ooooo`?o00001_ooool2o`0000cooooo6_l0
0004ooooo`;o00000_ooool3o`0000;ooooo0_l00005ooooo`Go00000_ooool4o`0000Gooooo0_l0
000Booooo`Go00000_ooool2o`000003ooooool0003o000000;ooooo0_l0000;ooooo`;o00000_oo
ool4o`0000Kooooo0_l000000ooooooo0000o`00001=ooooo`007?ooool00ol0003oooooooooo`14
ooooo`;o00003_ooool2o`0000Kooooo0_l000000ooooooo0000o`00000=ooooo`;o00002?ooool2
o`0000?ooooo0ol000000ooooooo0000o`00000Do`0000Oooooo0_l00003ooooo`;o00001oooool2
o`0000Gooooo0_l00009ooooo`;o00002oooool2o`000003ooooool0003o000000?o00000_ooool2
o`0000Gooooo0_l00007ooooo`?o000000?oooooo`000?l000002_ooool4o`000003ooooool0003o
000004gooooo000Looooo`;o0000AOooool2o`0000kooooo0_l00002ooooo`;o00001Oooool2o`00
017ooooo1?l00002ooooo`;o00000oooool2o`0000;ooooo4_l000001?oooooo0000o`000?l0000E
ooooo`Co00001Oooool2o`0000Oooooo0_l00002ooooo`;o00000oooool6o`0000?ooooo0_l00000
0ooooooo0000o`000002o`0000;ooooo1?l00008ooooo`?o000000?oooooo`000?l000002_ooool4
o`00053ooooo000Looooo`03o`000?oooooooooo05Sooooo0_l0000;ooooo`;o00002?ooool2o`00
0003ooooool0003o000000;o00001oooool6o`000003ooooool0003o000000Go000000?oooooo`00
0?l000002?l0000:ooooo`?o00002oooool2o`000003ooooool0003o000000;ooooo0_l00004oooo
o`;o00001Oooool2o`0000?ooooo1Ol00002ooooo`;o000000?oooooo`000?l000001?l00002oooo
o`Co00005Oooool7o`00053ooooo000Looooo`03o`000?oooooooooo053ooooo0_l00007ooooo`Co
00002?ooool2o`0000Sooooo1Ol00007ooooo`;o00000_ooool2o`0000?ooooo1?l00005ooooo`Oo
00003?ooool3o`0000Kooooo0_l00006ooooo`;o00002?ooool4o`0000Sooooo0ol00004ooooo`;o
000000?oooooo`000?l000006?ooool4o`0000?ooooo1_l0001Aooooo`007?ooool00ol0003ooooo
ooooo`1>ooooo`Co00001oooool5o`0000Sooooo0_l00007ooooo`Go00001oooool2o`0000;ooooo
0ol000000ooooooo0000o`000003o`0000Gooooo1_l0000=ooooo`;o00001oooool3o`00017ooooo
0_l00008ooooo`?o00001oooool5o`0001Gooooo1?l00004ooooo`;o00002_ooool2o`0004Sooooo
000Looooo`03o`000?oooooooooo04kooooo0_l00003ooooo`;o00001oooool2o`0000Sooooo0_l0
0008ooooo`Co00002oooool9o`0000;ooooo2Ol0000Gooooo`;o00004_ooool2o`0000Cooooo0_l0
000:ooooo`So00004?ooool2o`0000Wooooo0_l00009ooooo`?o0000B?ooool001cooooo00?o0000
ooooooooool0Doooool2o`00013ooooo0_l00009ooooo`;o00001Oooool4o`000003ooooool0003o
000000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000002Ol000000ooooooo0000o`00000X
ooooo`;o00001?ooool2o`0000[ooooo0_l00004ooooo`;o00004?ooool2o`0000;ooooo0_l00004
ooooo`?o00002Oooool2o`0004Wooooo000Looooo`03o`000?oooooooooo04gooooo0_l0000?oooo
o`?o00001?ooool2o`0000[ooooo0_l00004ooooo`Co000000?oooooo`000?l000000_ooool2o`00
00?ooooo1Ol000000ooooooo0000o`000003o`0000Cooooo1?l0000_ooooo`;o00004oooool2o`00
00[ooooo0_l00002ooooo`?o00000oooool2o`0005Gooooo000Looooo`03o`000?oooooooooo04go
oooo1?l0000=ooooo`Co00001_ooool2o`0000Oooooo0ol00007ooooo`;o00000oooool2o`0000Co
oooo3Ol00002ooooo`?o00001Oooool2o`0002Sooooo0_l0000:ooooo`;o00001oooool2o`0000Co
oooo0_l00002ooooo`Co00000oooool2o`0005[ooooo000Looooo`03o`000?oooooooooo04oooooo
0_l0000?ooooo`;o00001_ooool2o`0000Oooooo0ol00007ooooo`;o000000?oooooo`000?l00000
0_l000000ooooooo0000o`000002ooooo`co00000_ooool2o`0000Kooooo0_l0000cooooo`?o0000
1?ooool2o`0000Oooooo0_l00002ooooo`;o0000HOooool001cooooo00?o0000ooooooooool0D_oo
ool2o`0001Cooooo0_l0000<ooooo`;o00001_ooool4o`000005ooooool0003o0000o`000?ooool0
0_l00002ooooo`?o00000oooool2o`0003oooooo0_l00005ooooo`Co00006oooool2o`0004oooooo
000Looooo`03o`000?oooooooooo05;ooooo0_l00007ooooo`;o00001Oooool5o`000003ooooool0
003o000000cooooo0_l0000<ooooo`;o00002oooool2o`0004Sooooo0_l0000Kooooo`;o0000Cooo
ool001cooooo00?o0000ooooooooool0Doooool2o`0000Kooooo0_l00005ooooo`Go0000h_ooool0
01cooooo00?o0000ooooooooool0Doooool2o`0002Oooooo0_l0000:ooooo`;o00001_ooool2o`00
0003ooooool0003o000002[ooooo0_l0000Wooooo`;o00003?ooool2o`00057ooooo000Looooo`03
o`000?oooooooooo05kooooo0_l00003ooooo`?o00005Oooool3o`0000[ooooo0_l00002ooooo`;o
000000Goooooo`000?l0003o0000ooooo`02o`0002[ooooo0ol00003ooooo`Co00007_ooool3o`00
00cooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o00000oooool5o`0000oo
oooo0_l00002ooooo`;o000000?oooooo`000?l000001?ooool2o`000004ooooool0003o0000oooo
o`Co000000?oooooo`000?l000001?ooool2o`0000Kooooo0_l0000Qooooo`;o00000oooool4o`00
01kooooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`1Vooooo`;o00003oooool3o`0000Co
oooo0ol00003ooooo`;o000000?oooooo`000?l000000ol00009ooooo`;o00001_ooool2o`0002[o
oooo0ol0000Tooooo`;o0000Eoooool001cooooo0_l0001Wooooo`;o00003oooool3o`0000?ooooo
1?l00008ooooo`;o0000?_ooool3o`000003ooooool0003o0000027ooooo0_l0001Gooooo`007?oo
ool00ol0003oooooooooo`1Gooooo`;o00009?ooool2o`0000gooooo0_l0000<ooooo`;o0000<Ooo
ool6o`0007Kooooo000Looooo`03o`000?oooooooooo05Oooooo0_l00002ooooo`;o00009_ooool4
o`0000Gooooo0_l00008ooooo`;o000000Coooooo`000?l0003o00007?ooool2o`0000;ooooo0_l0
000>ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`00001cooooo`007?ooool0
0ol0003oooooooooo`1Kooooo`;o00001Oooool2o`0001_ooooo2?l00004ooooo`;o00002Oooool2
o`000003ooooool0003o000001gooooo0_l00002ooooo`;o00003_ooool2o`0000?ooooo1Ol00004
ooooo`;o0000KOooool001cooooo00?o0000ooooooooool0Goooool2o`000003ooooool0003o0000
01Wooooo1_l000000ooooooo0000o`000005ooooo`;o00009?ooool2o`0001Sooooo1?l000000ooo
oooo0000o`000003o`0000Gooooo0_l0000@ooooo`;o0000Foooool001cooooo00?o0000oooooooo
ool0Goooool2o`0001cooooo0ol0000Cooooo`;o00006?ooool3o`000003ooooool0003o000000Wo
oooo0_l0000<ooooo`Go000000?oooooo`000?l000000ol00004ooooo`;o00004?ooool3o`0005_o
oooo000Looooo`03o`000?oooooooooo063ooooo0_l000000ooooooo0000o`00000Iooooo`;o0000
2Oooool2o`0000Sooooo0_l0000Hooooo`?o00003?ooool2o`0000cooooo1Ol00003ooooo`?o0000
0_ooool4o`00013ooooo0_l0001Looooo`007?ooool00ol0003oooooooooo`1Pooooo`;o000000?o
ooooo`000?l000009?ooool2o`00037ooooo0_l0000=ooooo`;o000000?oooooo`000?l000000_oo
ool3o`0000;ooooo0_l0001`ooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o00008Oooool2
o`0000_ooooo0_l000000ooooooo0000o`00000Oooooo`;o00001_ooool4o`0000Gooooo0_l00002
ooooo`;o00001?ooool2o`000003ooooool0003o000000kooooo0_l0001Pooooo`007?ooool00ol0
003oooooooooo`1Uooooo`;o00007_ooool2o`000003ooooool0003o000000_ooooo1Ol00002oooo
o`;o00006oooool2o`0000Kooooo1?l00003ooooo`Co00002?ooool2o`000003ooooool0003o0000
00kooooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`1Uooooo`?o00006oooool4o`000003
ooooool0003o000000Gooooo0_l00006ooooo`;o00000oooool2o`0000kooooo0_l0000Cooooo`;o
000000?oooooo`000?l000001Ol0001nooooo`007?ooool00ol0003oooooooooo`1Vooooo`?o0000
6?ooool4o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`?o00006oooool2o`0000oooooo
0_l00002ooooo`So0000P?ooool001cooooo00?o0000ooooooooool0Ioooool2o`0001Sooooo0_l0
0004ooooo`;o000000?oooooo`000?l000001?l00002ooooo`;o00001_ooool2o`0000Sooooo0_l0
000Booooo`Oo00000_ooool4o`0000;ooooo0_l00020ooooo`007?ooool00ol0003oooooooooo`1Z
ooooo`;o00007_ooool4o`0000Cooooo0_l00006ooooo`;o00002?ooool2o`00013ooooo2Ol00002
ooooo`?o00006Oooool4o`0006Sooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ
8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Zooooo`;o0000
7_ooool3o`0000Sooooo0_l00005ooooo`;o00004oooool2o`0000;ooooo1Ol000001?oooooo0000
o`000?ooool2o`0001gooooo1?l0001Xooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5oooo
o`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0Roooool2
o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0001?ooooo0ol00000
0ooooooo0000o`000004ooooo`Go00001_ooool2o`0001Gooooo0_l0001Zooooo`0000?ooooooa0@
4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`29ooooo`;o00000oooool2o`000003ooooool0003o000000Gooooo0_l0000B
ooooo`Co000000Coooooo`000?l0003o00001?ooool7o`0000Cooooo0_l000000ooooooo0000o`00
0021ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9So
oooooiRHV?lb<S801_ooool3o`0008Wooooo0_l00003ooooo`Co00001_ooool3o`0000?ooooo0_l0
0002ooooo`Co00000_ooool2o`0000;ooooo1?l000000ooooooo0000o`000002ooooo`;o000000?o
ooooo`000?l000000ol00006ooooo`;o0000Q?ooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool02Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0L?oo
ool2o`0001kooooo0_l00007ooooo`Co000000?oooooo`000?l000001_l00002ooooo`;o00002ooo
ool2o`0009;ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go410@
okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo073ooooo0_l0000Yooooo`;o00000ooo
ool4o`0000?ooooo0_l00004ooooo`;o00001?ooool2o`0001[ooooo0ol0001gooooo`0000Kooooo
ogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003o
ooooooooo`2Rooooo`;o00000oooool2o`0000;ooooo1?l00004ooooo`;o00006_ooool3o`0007Oo
oooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06
ooooo`03o`000?oooooooooo077ooooo0ol0000gooooo`?o00007?ooool2o`0007gooooo000Loooo
o`03o`000?oooooooooo077ooooo1Ol0000Uooooo`Co00003Oooool2o`0001cooooo0_l0001moooo
o`007?ooool00ol0003oooooooooo`1aooooo`Go00009Oooool4o`0000?ooooo0_l0000Qooooo`;o
0000P_ooool001cooooo00?o0000ooooooooool0X_ooool2o`0001oooooo1?l00022ooooo`007?oo
ool00ol0003oooooooooo`1dooooo`;o0000=_ooool3o`0000?ooooo2?l00002ooooo`;o00001Ooo
ool2o`0008Cooooo000Looooo`03o`000?oooooooooo07Cooooo0_l0000fooooo`?o00000oooool8
o`0000;ooooo0_l0002;ooooo`007?ooool00ol0003oooooooooo`1jooooo`;o000000?oooooo`00
0?l000001?ooool4o`000<;ooooo000Looooo`03o`000?oooooooooo07[ooooo0_l000000ooooooo
0000o`000003ooooo`Go0000`_ooool001cooooo00?o0000ooooooooool0O?ooool3o`0000?ooooo
1?l00033ooooo`007?ooool00ol0003oooooooooo`1looooo`?o00000_ooool2o`0000Kooooo0ol0
002mooooo`007?ooool00ol0003oooooooooo`21ooooo`;o00001_ooool3o`000003ooooool0003o
00000;[ooooo000Looooo`03o`000?oooooooooo08gooooo0_l0002jooooo`007?ooool2o`0009Co
oooo0_l0002dooooo`007?ooool00ol0003oooooooooo`2Cooooo`;o0000]?ooool001cooooo00?o
0000ooooooooool0Voooool2o`0003Cooooo0_l0001fooooo`007?ooool00ol0003oooooooooo`2K
ooooo`Co0000<_ooool2o`0007Kooooo000Looooo`03o`000?oooooooooo09gooooo0_l00002oooo
o`?o0000YOooool001cooooo00?o0000ooooooooool0XOooool3o`0001Cooooo1?l00008ooooo`Go
0000P?ooool001cooooo00?o0000ooooooooool0YOooool4o`0000oooooo1?l00008ooooo`Go0000
P?ooool001cooooo00?o0000ooooooooool0YOooool4o`000:3ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001;ooooo1?l000000ol@413ooooo
ooooo`03ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo0ol0003o
oooood[ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000oooooooo
ool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oo
oooooooo0?ooooooD_ooool001;ooooo00?oEEEEofIVI_l00000oooooomDooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00YOooool01?l@413o0000o`000?ooool2o`000003oa0@
4?oooooooooo01Gooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oa0@
4?o<c<`00oooool01Oo^k^ko<S8bo`000?l@413oc<c<093ooooo002Vooooo`05o`000?oooooooooo
ooooool000002Oooool6o`0000Wooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B400oooool01OmEEEGoMgMgoooooonHV9So8B4Q093ooooo002Vooooo`05o`00
0?ooooooooooooooool000007?ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo08kooooo002Vooooo`05o`000?oooooooooo
ooooool000002Oooool6o`0000cooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003oV9RHoooooonH
V9So8B4Q00?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@2@ooooo`00Y_ooool01Ol0003oQhN7oooo
oonYZJWo000001[ooooo00?o410@o`000?nj^[X00oooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000oeEEEOl0003o410@olc<c02@ooooo`00YOooool00ol@413o0000ogMgM`02o`000003
oiRHV?oooooooooo01Wooooo00?o^[Zjob4Q8Oooool00_ooool00omEEEGoQhN7ooooo`05ooooo`03
oeEEEOn7QhOooooo09;ooooo0033ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool00ooMgMgo
410@oiRHV005ooooo`03omgMgOl@413oV9RH09;ooooo0033ooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT01?ooool01?o<c<coA4A4o`000?l@4104ooooo`04olc<c?m4A4Co0000oa0@493ooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(372) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.439 .62891 Mdot
.40606 .66284 Mdot
.66017 .48733 Mdot
.37572 .44987 Mdot
.68816 .31056 Mdot
.67872 .48515 Mdot
.64274 .65112 Mdot
.64559 .65027 Mdot
.6852 .46419 Mdot
.20722 .56516 Mdot
.6265 .6807 Mdot
.40706 .47101 Mdot
.63272 .66158 Mdot
.38873 .43105 Mdot
.491 .47337 Mdot
.3996 .36174 Mdot
.38999 .63112 Mdot
.63743 .35404 Mdot
.41245 .36868 Mdot
.68894 .51798 Mdot
.28667 .35381 Mdot
.37798 .42667 Mdot
.43225 .6792 Mdot
.38563 .43169 Mdot
.36379 .39423 Mdot
.42308 .66692 Mdot
.4438 .63699 Mdot
.3653 .39915 Mdot
.43363 .43182 Mdot
.63109 .6775 Mdot
.58286 .50385 Mdot
.26722 .29911 Mdot
.34518 .39674 Mdot
.31592 .53027 Mdot
.65868 .66706 Mdot
.66804 .71293 Mdot
.71293 .50275 Mdot
.60926 .63407 Mdot
.65796 .67684 Mdot
.64092 .6858 Mdot
.63323 .68565 Mdot
.4275 .6663 Mdot
.5901 .65371 Mdot
.72356 .64321 Mdot
.39127 .44501 Mdot
.40683 .552 Mdot
.6994 .63051 Mdot
.40792 .384 Mdot
.38953 .6555 Mdot
.66779 .50786 Mdot
.55086 .27629 Mdot
.6167 .63688 Mdot
.48083 .60305 Mdot
.83383 .67176 Mdot
.64253 .66595 Mdot
.40346 .37269 Mdot
.71174 .46844 Mdot
.40591 .41176 Mdot
.36219 .44443 Mdot
.28797 .49244 Mdot
.3906 .40299 Mdot
.66021 .33708 Mdot
.44797 .61207 Mdot
.73122 .50583 Mdot
.68183 .46371 Mdot
.60526 .63671 Mdot
.39147 .69506 Mdot
.62396 .6681 Mdot
.42416 .44846 Mdot
.66735 .503 Mdot
.43117 .4153 Mdot
.62381 .67875 Mdot
.44177 .66253 Mdot
.37877 .44609 Mdot
.55772 .79457 Mdot
.68677 .6345 Mdot
.71955 .53232 Mdot
.28168 .41595 Mdot
.62178 .26974 Mdot
.5554 .46465 Mdot
.37653 .44051 Mdot
.8335 .52473 Mdot
.51892 .43083 Mdot
.39671 .6484 Mdot
.47415 .61013 Mdot
.5317 .68751 Mdot
.39143 .38326 Mdot
.57742 .51307 Mdot
.39115 .35232 Mdot
.67497 .38263 Mdot
.70401 .46832 Mdot
.40296 .63622 Mdot
.38393 .44516 Mdot
.40812 .45808 Mdot
.26256 .6618 Mdot
.43882 .41948 Mdot
.35926 .43893 Mdot
.52068 .62577 Mdot
.60871 .67409 Mdot
.46253 .43866 Mdot
.60332 .36531 Mdot
.50815 .57649 Mdot
.40286 .37416 Mdot
.70495 .48302 Mdot
.45392 .61633 Mdot
.35388 .38332 Mdot
.62192 .65581 Mdot
.379 .43805 Mdot
.59933 .68033 Mdot
.38829 .66645 Mdot
.36801 .45744 Mdot
.67263 .32024 Mdot
.29901 .38858 Mdot
.43256 .674 Mdot
.32384 .62521 Mdot
.37869 .40815 Mdot
.41277 .41104 Mdot
.4059 .6659 Mdot
.68731 .51265 Mdot
.80337 .52885 Mdot
.43901 .66419 Mdot
.63948 .68662 Mdot
.38986 .63543 Mdot
.31187 .40775 Mdot
.69431 .515 Mdot
.51048 .58856 Mdot
.51196 .59041 Mdot
.46605 .26928 Mdot
.37066 .44176 Mdot
.32761 .31671 Mdot
.69422 .48349 Mdot
.41905 .67532 Mdot
.63167 .67111 Mdot
.43859 .38682 Mdot
.43028 .64977 Mdot
.64072 .64656 Mdot
.6674 .2958 Mdot
.65168 .35761 Mdot
.40991 .68281 Mdot
.32417 .65866 Mdot
.58172 .63782 Mdot
.61442 .68474 Mdot
.54809 .27773 Mdot
.39625 .64911 Mdot
.65571 .31961 Mdot
.62323 .64562 Mdot
.49836 .18363 Mdot
.35476 .43706 Mdot
.52455 .28521 Mdot
.8259 .55117 Mdot
.55123 .27667 Mdot
.25324 .37811 Mdot
.66864 .31606 Mdot
.63986 .6456 Mdot
.42538 .40023 Mdot
.41456 .64721 Mdot
.42992 .65428 Mdot
.42713 .43263 Mdot
.35277 .40068 Mdot
.40014 .432 Mdot
.34924 .39291 Mdot
.5701 .58777 Mdot
.38385 .44349 Mdot
.41877 .79456 Mdot
.42057 .64193 Mdot
.35942 .38957 Mdot
.70024 .50542 Mdot
.47553 .40817 Mdot
.593 .64768 Mdot
.36851 .44833 Mdot
.35508 .40181 Mdot
.43867 .44422 Mdot
.64202 .68698 Mdot
.55309 .80554 Mdot
.65255 .24768 Mdot
.66569 .64157 Mdot
.6852 .72846 Mdot
.69211 .49447 Mdot
.39478 .39728 Mdot
.64795 .3132 Mdot
.4662 .40177 Mdot
.39708 .45458 Mdot
.55713 .27375 Mdot
.35907 .42286 Mdot
.25947 .36854 Mdot
.32706 .41437 Mdot
.54018 .67507 Mdot
.39928 .7715 Mdot
.38253 .45545 Mdot
.22359 .5481 Mdot
.53093 .29523 Mdot
.63464 .52959 Mdot
.63457 .67323 Mdot
.67261 .49846 Mdot
.67862 .50816 Mdot
.63019 .6294 Mdot
.35829 .57564 Mdot
.20348 .53809 Mdot
.43635 .43636 Mdot
.5053 .57857 Mdot
.37868 .65225 Mdot
.66792 .31862 Mdot
.40844 .6805 Mdot
.83664 .5003 Mdot
.57308 .44997 Mdot
.55785 .50469 Mdot
.61651 .32942 Mdot
.67255 .51514 Mdot
.50469 .58411 Mdot
.65004 .31918 Mdot
.40886 .43253 Mdot
.38881 .66514 Mdot
.53455 .29079 Mdot
.46099 .38815 Mdot
.1697 .60801 Mdot
.44314 .63991 Mdot
.43459 .28471 Mdot
.63983 .66471 Mdot
.70773 .45315 Mdot
.39007 .38341 Mdot
.39153 .41539 Mdot
.39316 .68001 Mdot
.42078 .39749 Mdot
.53713 .49173 Mdot
.35473 .40871 Mdot
.7318 .5018 Mdot
.68797 .26914 Mdot
.62684 .62509 Mdot
.62899 .30474 Mdot
.43932 .66847 Mdot
.58247 .83173 Mdot
.71035 .4923 Mdot
.45943 .4666 Mdot
.61707 .67067 Mdot
.67224 .29544 Mdot
.71284 .48401 Mdot
.6589 .34952 Mdot
.37615 .45899 Mdot
.71743 .49607 Mdot
.66505 .33442 Mdot
.53394 .52319 Mdot
.35124 .39006 Mdot
.44091 .24113 Mdot
.61938 .64063 Mdot
.40146 .63168 Mdot
.4115 .44681 Mdot
.47781 .59989 Mdot
.41159 .47995 Mdot
.48391 .30694 Mdot
.48692 .59889 Mdot
.50795 .57127 Mdot
.54112 .44658 Mdot
.63899 .31173 Mdot
.64905 .75025 Mdot
.56773 .52608 Mdot
.39018 .63064 Mdot
.39899 .45872 Mdot
.61275 .72588 Mdot
.62508 .64001 Mdot
.41017 .42545 Mdot
.58378 .71404 Mdot
.62509 .64479 Mdot
.41283 .41443 Mdot
.64099 .68204 Mdot
.42428 .64773 Mdot
.5237 .48021 Mdot
.41327 .62137 Mdot
.40058 .44783 Mdot
.63657 .68247 Mdot
.67575 .50259 Mdot
.4235 .66587 Mdot
.37725 .43418 Mdot
.36547 .42622 Mdot
.49813 .57775 Mdot
.35296 .42188 Mdot
.53373 .63695 Mdot
.40307 .38231 Mdot
.65791 .49134 Mdot
.43734 .42424 Mdot
.57907 .33709 Mdot
.68579 .36443 Mdot
.39503 .67666 Mdot
.48632 .59825 Mdot
.71458 .47569 Mdot
.52264 .50625 Mdot
.4077 .26417 Mdot
.38585 .44049 Mdot
.48682 .59302 Mdot
.46183 .28419 Mdot
.59338 .65061 Mdot
.36968 .35255 Mdot
.75791 .47017 Mdot
.70442 .4706 Mdot
.50614 .58092 Mdot
.46275 .40819 Mdot
.39402 .70555 Mdot
.42242 .37814 Mdot
.71413 .49775 Mdot
.41322 .62293 Mdot
.43538 .40342 Mdot
.68469 .61951 Mdot
.47611 .5997 Mdot
.60851 .6766 Mdot
.52363 .62117 Mdot
.41313 .40307 Mdot
.66673 .49709 Mdot
.43344 .65981 Mdot
.64778 .66344 Mdot
.43491 .67176 Mdot
.54621 .29714 Mdot
.4592 .29505 Mdot
.4709 .57235 Mdot
.62891 .31743 Mdot
.44714 .16583 Mdot
.66568 .64042 Mdot
.46531 .42399 Mdot
.73093 .45457 Mdot
.37597 .74064 Mdot
.70678 .47984 Mdot
.32733 .67075 Mdot
.7071 .46756 Mdot
.4185 .38007 Mdot
.6765 .47865 Mdot
.26064 .67194 Mdot
.3638 .40745 Mdot
.67697 .46434 Mdot
.58654 .5677 Mdot
.36341 .41233 Mdot
.43104 .64854 Mdot
.21792 .36064 Mdot
.3466 .55087 Mdot
.35096 .56253 Mdot
.71511 .46866 Mdot
.32942 .69006 Mdot
.37002 .39465 Mdot
.42959 .37537 Mdot
.4154 .65195 Mdot
.40565 .48048 Mdot
.63181 .32683 Mdot
.64312 .35215 Mdot
.52611 .22454 Mdot
.30685 .28797 Mdot
.3463 .58759 Mdot
.42639 .65902 Mdot
.67044 .25832 Mdot
.54644 .79615 Mdot
.47639 .6002 Mdot
.64492 .6492 Mdot
.59591 .79078 Mdot
.42222 .36412 Mdot
.45519 .69206 Mdot
.53472 .49023 Mdot
.41816 .6263 Mdot
.4873 .55077 Mdot
.64874 .66043 Mdot
.34817 .56162 Mdot
.19918 .50535 Mdot
.40159 .43236 Mdot
.60357 .64618 Mdot
.38713 .47662 Mdot
.57279 .51636 Mdot
.44742 .25926 Mdot
.72268 .56441 Mdot
.40014 .44682 Mdot
.60269 .77523 Mdot
.40369 .45174 Mdot
.47843 .26942 Mdot
.41158 .43012 Mdot
.43551 .65092 Mdot
.44551 .42969 Mdot
.56219 .53126 Mdot
.5052 .14752 Mdot
.57116 .43958 Mdot
.64973 .34823 Mdot
.38807 .42776 Mdot
.40112 .42163 Mdot
.65864 .34022 Mdot
.41149 .63025 Mdot
.41172 .45047 Mdot
.68843 .74832 Mdot
.38081 .44351 Mdot
.6188 .6346 Mdot
.51855 .34316 Mdot
.29735 .27921 Mdot
.38673 .39048 Mdot
.39377 .70497 Mdot
.61267 .68272 Mdot
.61195 .6599 Mdot
.36446 .34649 Mdot
.61894 .6393 Mdot
.42497 .40128 Mdot
.51906 .34379 Mdot
.4042 .6936 Mdot
.376 .34463 Mdot
.42294 .62828 Mdot
.71099 .26014 Mdot
.6306 .64288 Mdot
.48043 .59451 Mdot
.34543 .59859 Mdot
.63015 .65229 Mdot
.69541 .28038 Mdot
.44708 .42236 Mdot
.44219 .3578 Mdot
.36785 .66418 Mdot
.66721 .49455 Mdot
.49676 .59169 Mdot
.64425 .66537 Mdot
.38881 .44314 Mdot
.37577 .37757 Mdot
.61372 .64003 Mdot
.2464 .43977 Mdot
.58362 .50372 Mdot
.3991 .44943 Mdot
.42738 .6386 Mdot
.42187 .67392 Mdot
.37749 .35784 Mdot
.40641 .45111 Mdot
.67562 .49174 Mdot
.48693 .5936 Mdot
.48994 .59632 Mdot
.51393 .58317 Mdot
.71399 .46207 Mdot
.45331 .16423 Mdot
.61134 .68306 Mdot
.27547 .29263 Mdot
.5458 .76323 Mdot
.33029 .36459 Mdot
.69573 .51079 Mdot
.38862 .41032 Mdot
.3956 .37639 Mdot
.63847 .68039 Mdot
.41963 .19973 Mdot
.43422 .37949 Mdot
.42546 .62281 Mdot
.61129 .63912 Mdot
.39534 .47807 Mdot
.58687 .62146 Mdot
.67091 .30564 Mdot
.3347 .6006 Mdot
.62138 .63765 Mdot
.40521 .68951 Mdot
.62113 .6375 Mdot
.40108 .42476 Mdot
.46296 .41246 Mdot
.42228 .62636 Mdot
.67952 .33409 Mdot
.42229 .44173 Mdot
.41591 .41982 Mdot
.67923 .41322 Mdot
.56093 .79264 Mdot
.68375 .28477 Mdot
.41545 .38257 Mdot
.44434 .35787 Mdot
.67585 .33801 Mdot
.42442 .42356 Mdot
.43603 .4177 Mdot
.32496 .31778 Mdot
.58683 .65959 Mdot
.67762 .29186 Mdot
.48509 .15531 Mdot
.44234 .6371 Mdot
.53979 .63144 Mdot
.51029 .58073 Mdot
.6697 .65339 Mdot
.51957 .49189 Mdot
.49746 .58361 Mdot
.56326 .74551 Mdot
.46964 .85856 Mdot
.49523 .5905 Mdot
.72801 .47743 Mdot
.28346 .66557 Mdot
.43485 .42275 Mdot
.40646 .44652 Mdot
.63474 .31932 Mdot
.39936 .66353 Mdot
.42221 .78803 Mdot
.66751 .64545 Mdot
.37717 .41612 Mdot
.44815 .64792 Mdot
.53606 .6846 Mdot
.50153 .58013 Mdot
.65595 .30785 Mdot
.68427 .31655 Mdot
.41067 .44577 Mdot
.43534 .27445 Mdot
.42649 .66359 Mdot
.37733 .43415 Mdot
.41351 .40918 Mdot
.7232 .49846 Mdot
.38983 .66592 Mdot
.70306 .5027 Mdot
.48005 .5863 Mdot
.29752 .71831 Mdot
.7319 .71101 Mdot
.61782 .64302 Mdot
.46151 .5319 Mdot
.62845 .62551 Mdot
.6738 .58566 Mdot
.48738 .59419 Mdot
.37762 .43119 Mdot
.42422 .68901 Mdot
.37781 .43671 Mdot
.3819 .44423 Mdot
.39756 .44488 Mdot
.3446 .58906 Mdot
.61964 .27507 Mdot
.64134 .31745 Mdot
.41389 .39792 Mdot
.72325 .47577 Mdot
.54905 .66846 Mdot
.21266 .60454 Mdot
.39036 .4222 Mdot
.41353 .41204 Mdot
.38767 .6985 Mdot
.35752 .44657 Mdot
.63331 .64839 Mdot
.41507 .62583 Mdot
.38998 .37396 Mdot
.60888 .36664 Mdot
.41511 .44596 Mdot
.45449 .54869 Mdot
.64788 .64375 Mdot
.45043 .44804 Mdot
.34074 .42667 Mdot
.48616 .59491 Mdot
.49764 .59046 Mdot
.50869 .56649 Mdot
.61217 .63532 Mdot
.72348 .49464 Mdot
.71755 .52791 Mdot
.34938 .44757 Mdot
.4199 .39074 Mdot
.45708 .38297 Mdot
.65383 .4678 Mdot
.58348 .53002 Mdot
.33143 .6447 Mdot
.3768 .47081 Mdot
.69471 .45189 Mdot
.52172 .62508 Mdot
.27781 .38793 Mdot
.40682 .62993 Mdot
.71367 .43945 Mdot
.61636 .66199 Mdot
.67182 .33082 Mdot
.51437 .24718 Mdot
.43942 .65709 Mdot
.41397 .697 Mdot
.68204 .49392 Mdot
.51907 .35716 Mdot
.87063 .62084 Mdot
.69665 .47946 Mdot
.55068 .50215 Mdot
.41964 .65459 Mdot
.34628 .39529 Mdot
.47805 .29034 Mdot
.51209 .36377 Mdot
.68515 .45734 Mdot
.36581 .42795 Mdot
.72675 .31939 Mdot
.67511 .49087 Mdot
.45475 .3727 Mdot
.71631 .46927 Mdot
.60042 .6665 Mdot
.69933 .48604 Mdot
.44729 .63251 Mdot
.37059 .43986 Mdot
.8458 .65585 Mdot
.51861 .45464 Mdot
.37073 .42395 Mdot
.6241 .6363 Mdot
.6578 .56816 Mdot
.40558 .42865 Mdot
.63194 .3409 Mdot
.72746 .48144 Mdot
.69053 .57656 Mdot
.42956 .3929 Mdot
.67465 .47915 Mdot
.41678 .70007 Mdot
.69609 .43234 Mdot
.60771 .37062 Mdot
.49452 .59427 Mdot
.42038 .6453 Mdot
.6823 .67553 Mdot
.63461 .68685 Mdot
.38481 .36838 Mdot
.40619 .40365 Mdot
.41877 .63853 Mdot
.52305 .51821 Mdot
.35017 .36031 Mdot
.37868 .44132 Mdot
.69102 .50074 Mdot
.70196 .52333 Mdot
.49248 .46711 Mdot
.71182 .49294 Mdot
.44054 .35475 Mdot
.42585 .6413 Mdot
.4202 .3764 Mdot
.43175 .67072 Mdot
.40165 .45801 Mdot
.59213 .61113 Mdot
.39609 .63934 Mdot
.4486 .47636 Mdot
.36633 .43842 Mdot
.353 .64374 Mdot
.40904 .39975 Mdot
.39229 .44976 Mdot
.71399 .51778 Mdot
.65222 .33575 Mdot
.36408 .35721 Mdot
.67021 .60693 Mdot
.67978 .32186 Mdot
.2533 .41313 Mdot
.69521 .5148 Mdot
.68281 .30096 Mdot
.50071 .2248 Mdot
.48792 .5981 Mdot
.64791 .34048 Mdot
.50321 .60267 Mdot
.61232 .64474 Mdot
.46167 .63494 Mdot
.36214 .41959 Mdot
.29364 .71193 Mdot
.58376 .50567 Mdot
.4925 .58109 Mdot
.41923 .43398 Mdot
.39332 .41031 Mdot
.44804 .64908 Mdot
.83532 .50716 Mdot
.70736 .52635 Mdot
.3497 .41179 Mdot
.44113 .65624 Mdot
.83027 .53622 Mdot
.67844 .46159 Mdot
.6531 .30412 Mdot
.66307 .67112 Mdot
.38727 .62526 Mdot
.47885 .5948 Mdot
.63338 .64341 Mdot
.72785 .52607 Mdot
.56103 .27223 Mdot
.42596 .38233 Mdot
.69907 .50816 Mdot
.55238 .27631 Mdot
.36133 .35396 Mdot
.62318 .62809 Mdot
.6912 .66179 Mdot
.399 .64374 Mdot
.61334 .63986 Mdot
.63418 .33278 Mdot
.38448 .64053 Mdot
.41998 .62727 Mdot
.6278 .64852 Mdot
.37659 .76317 Mdot
.46308 .28525 Mdot
.65532 .64412 Mdot
.49037 .31161 Mdot
.5534 .2774 Mdot
.4847 .58597 Mdot
.65624 .30891 Mdot
.68274 .26214 Mdot
.42622 .66695 Mdot
.59039 .79303 Mdot
.55166 .27539 Mdot
.35855 .43802 Mdot
.66556 .33531 Mdot
.5472 .65816 Mdot
.64576 .71531 Mdot
.63272 .6454 Mdot
.67872 .4179 Mdot
.66698 .33726 Mdot
.3771 .45679 Mdot
.3393 .22728 Mdot
.37364 .39827 Mdot
.62121 .64523 Mdot
.53575 .49083 Mdot
.396 .67298 Mdot
.59214 .65047 Mdot
.53716 .49117 Mdot
.40629 .37757 Mdot
.3764 .40729 Mdot
.61628 .29042 Mdot
.38725 .65679 Mdot
.48144 .58618 Mdot
.37088 .43473 Mdot
.41011 .41413 Mdot
.37785 .36724 Mdot
.35986 .25282 Mdot
.31961 .45679 Mdot
.36423 .37402 Mdot
.69081 .44779 Mdot
.46487 .40319 Mdot
.35001 .4217 Mdot
.39133 .70619 Mdot
.59727 .34838 Mdot
.48392 .58095 Mdot
.40937 .44284 Mdot
.40107 .44818 Mdot
.65679 .67719 Mdot
.46389 .28501 Mdot
.51297 .36831 Mdot
.66175 .50379 Mdot
.66545 .52561 Mdot
.41447 .46146 Mdot
.41239 .6427 Mdot
.64827 .30081 Mdot
.39789 .33915 Mdot
.42944 .625 Mdot
.40863 .46139 Mdot
.72776 .48659 Mdot
.49142 .59087 Mdot
.40381 .33692 Mdot
.66172 .33208 Mdot
.58216 .63922 Mdot
.26059 .40872 Mdot
.6804 .50407 Mdot
.37445 .38782 Mdot
.69949 .5367 Mdot
.68748 .47182 Mdot
.49711 .57734 Mdot
.45349 .45765 Mdot
.42615 .65104 Mdot
.40723 .68863 Mdot
.5869 .30729 Mdot
.71786 .4654 Mdot
.64442 .45175 Mdot
.59902 .65517 Mdot
.41594 .40122 Mdot
.57199 .67782 Mdot
.40428 .68519 Mdot
.46553 .26841 Mdot
.68523 .30775 Mdot
.62932 .64554 Mdot
.49202 .60609 Mdot
.3996 .6341 Mdot
.4102 .68643 Mdot
.38623 .4451 Mdot
.38265 .42237 Mdot
.65065 .54832 Mdot
.52651 .29108 Mdot
.64488 .67964 Mdot
.66431 .30089 Mdot
.66142 .49746 Mdot
.42452 .38885 Mdot
.39814 .64989 Mdot
.30619 .26689 Mdot
.41163 .40209 Mdot
.72279 .47539 Mdot
.40852 .66286 Mdot
.64302 .31217 Mdot
.6357 .32962 Mdot
.37795 .44963 Mdot
.26337 .36604 Mdot
.6268 .6542 Mdot
.43251 .64896 Mdot
.39207 .61473 Mdot
.41258 .39398 Mdot
.38703 .42405 Mdot
.3185 .41751 Mdot
.59919 .63453 Mdot
.33876 .39102 Mdot
.66682 .34596 Mdot
.41897 .67948 Mdot
.37183 .43226 Mdot
.65907 .33823 Mdot
.45205 .69563 Mdot
.49325 .58586 Mdot
.67302 .47268 Mdot
.63455 .34574 Mdot
.65362 .3261 Mdot
.68125 .31172 Mdot
.59769 .78938 Mdot
.46843 .64456 Mdot
.61391 .21735 Mdot
.36625 .43324 Mdot
.55388 .27783 Mdot
.38397 .35912 Mdot
.59531 .65163 Mdot
.66712 .4889 Mdot
.39525 .44146 Mdot
.36574 .43245 Mdot
.26706 .40706 Mdot
.40468 .36461 Mdot
.41763 .36896 Mdot
.39807 .67635 Mdot
.38533 .6175 Mdot
.67278 .50286 Mdot
.82399 .56733 Mdot
.23056 .3035 Mdot
.43467 .44157 Mdot
.51896 .35466 Mdot
.40451 .63262 Mdot
.66019 .67461 Mdot
.48882 .30581 Mdot
.59803 .70388 Mdot
.40924 .67291 Mdot
.42082 .38191 Mdot
.26925 .42512 Mdot
.67423 .3306 Mdot
.39991 .42924 Mdot
.62778 .67233 Mdot
.40012 .43055 Mdot
.60763 .63699 Mdot
.33304 .67443 Mdot
.51723 .38803 Mdot
.36011 .42005 Mdot
.43854 .41985 Mdot
.31743 .33169 Mdot
.38743 .42178 Mdot
.73653 .55234 Mdot
.41048 .65887 Mdot
.45613 .46704 Mdot
.40422 .37153 Mdot
.33663 .54683 Mdot
.42115 .41902 Mdot
.50561 .50835 Mdot
.38919 .39977 Mdot
.43869 .19554 Mdot
.36754 .45206 Mdot
.39244 .39746 Mdot
.65041 .66796 Mdot
.64765 .68346 Mdot
.35295 .68847 Mdot
.49264 .575 Mdot
.54172 .67027 Mdot
.41616 .41747 Mdot
.67412 .51765 Mdot
.44595 .32904 Mdot
.65213 .33129 Mdot
.41787 .67855 Mdot
.5964 .87529 Mdot
.60418 .67671 Mdot
.7248 .47204 Mdot
.56958 .50813 Mdot
.70311 .44679 Mdot
.73097 .45628 Mdot
.36464 .65622 Mdot
.65921 .30807 Mdot
.41167 .44892 Mdot
.32327 .53047 Mdot
.57847 .78407 Mdot
.41248 .39261 Mdot
.66019 .51242 Mdot
.40449 .30702 Mdot
.58436 .29774 Mdot
.62922 .3459 Mdot
.66229 .31393 Mdot
.6457 .66134 Mdot
.66284 .49367 Mdot
.37532 .47105 Mdot
.6828 .30035 Mdot
.67108 .4951 Mdot
.4964 .60387 Mdot
.6006 .32202 Mdot
.4283 .66215 Mdot
.32845 .68528 Mdot
.40545 .55967 Mdot
.61428 .68302 Mdot
.67707 .61837 Mdot
.45415 .66461 Mdot
.39921 .62423 Mdot
.50309 .57227 Mdot
.69425 .45373 Mdot
.46075 .63974 Mdot
.37342 .44184 Mdot
.46112 .38804 Mdot
.4098 .44713 Mdot
.63771 .31441 Mdot
.4214 .42561 Mdot
.6719 .48741 Mdot
.6546 .6626 Mdot
.7076 .47099 Mdot
.64407 .65222 Mdot
.24086 .32995 Mdot
.37225 .45074 Mdot
.38539 .42643 Mdot
.51879 .34553 Mdot
.41036 .68481 Mdot
.31114 .5342 Mdot
.72136 .47311 Mdot
.71237 .46992 Mdot
.41166 .37421 Mdot
.38143 .65218 Mdot
.68421 .28091 Mdot
.50332 .31908 Mdot
.39313 .40062 Mdot
.40901 .65782 Mdot
.41395 .37436 Mdot
.62622 .58877 Mdot
.51295 .4434 Mdot
.43208 .67736 Mdot
.50934 .14633 Mdot
.36636 .4421 Mdot
.43704 .47389 Mdot
.40203 .48917 Mdot
.3492 .26517 Mdot
.36927 .35458 Mdot
.4407 .63442 Mdot
.35022 .42096 Mdot
.40753 .64575 Mdot
.69447 .47262 Mdot
.59188 .65825 Mdot
.41054 .64852 Mdot
.36697 .40659 Mdot
.23482 .30002 Mdot
.65614 .66502 Mdot
.39557 .43342 Mdot
.63798 .6768 Mdot
.45659 .6227 Mdot
.39646 .66798 Mdot
.50678 .5999 Mdot
.55249 .50247 Mdot
.63033 .64941 Mdot
.41936 .39108 Mdot
.5567 .80076 Mdot
.42182 .37722 Mdot
.66435 .52311 Mdot
.44133 .41896 Mdot
.41718 .45824 Mdot
.45297 .15884 Mdot
.51759 .51485 Mdot
.74643 .70134 Mdot
.56312 .64886 Mdot
.54608 .80605 Mdot
.36771 .67397 Mdot
.62984 .34643 Mdot
.47013 .53904 Mdot
.49419 .59851 Mdot
.68421 .44925 Mdot
.39162 .44301 Mdot
.4714 .68245 Mdot
.64352 .6357 Mdot
.64528 .33425 Mdot
.35909 .42227 Mdot
.68512 .4428 Mdot
.44344 .52892 Mdot
.63457 .64488 Mdot
.42795 .66669 Mdot
.40727 .67731 Mdot
.61931 .26875 Mdot
.37165 .42897 Mdot
.37979 .42549 Mdot
.65773 .66724 Mdot
.33961 .45022 Mdot
.67886 .3082 Mdot
.58673 .56613 Mdot
.62836 .67408 Mdot
.51518 .44005 Mdot
.3862 .66143 Mdot
.39122 .41026 Mdot
.51685 .34226 Mdot
.49282 .81048 Mdot
.22564 .60255 Mdot
.66504 .32026 Mdot
.4201 .26964 Mdot
.4413 .63578 Mdot
.63354 .67129 Mdot
.51372 .225 Mdot
.44841 .40616 Mdot
.39716 .40984 Mdot
.39231 .25678 Mdot
.50075 .31761 Mdot
.56515 .50914 Mdot
.31402 .39432 Mdot
.4965 .29588 Mdot
.41306 .37463 Mdot
.37751 .37722 Mdot
.40886 .46306 Mdot
.44186 .41466 Mdot
.40526 .65304 Mdot
.34042 .56008 Mdot
.68658 .48857 Mdot
.23506 .59518 Mdot
.65124 .50935 Mdot
.37058 .39526 Mdot
.41268 .37855 Mdot
.25913 .57566 Mdot
.46642 .31763 Mdot
.41839 .66113 Mdot
.37213 .649 Mdot
.62405 .68799 Mdot
.41221 .36807 Mdot
.72148 .47094 Mdot
.39939 .4881 Mdot
.68294 .46864 Mdot
.40527 .65491 Mdot
.71512 .50808 Mdot
.65877 .69017 Mdot
.7003 .50787 Mdot
.69232 .45022 Mdot
.65079 .65049 Mdot
.38843 .65022 Mdot
.40104 .39853 Mdot
.6495 .64839 Mdot
.68157 .2791 Mdot
.63692 .31577 Mdot
.42102 .60174 Mdot
.34798 .38822 Mdot
.43277 .37221 Mdot
.69422 .63885 Mdot
.71707 .50022 Mdot
.50382 .36683 Mdot
.39548 .64178 Mdot
.64563 .30318 Mdot
.40421 .64913 Mdot
.60264 .25044 Mdot
.66197 .3248 Mdot
.47529 .60817 Mdot
.47606 .24044 Mdot
.63034 .62415 Mdot
.43377 .45619 Mdot
.39035 .61459 Mdot
.68718 .46676 Mdot
.61621 .63565 Mdot
.54932 .66333 Mdot
.3506 .40427 Mdot
.46726 .59883 Mdot
.44743 .61761 Mdot
.49095 .59726 Mdot
.63036 .67063 Mdot
.40165 .57755 Mdot
.37213 .4202 Mdot
.62573 .62411 Mdot
.43976 .42477 Mdot
.32291 .64061 Mdot
.65903 .54177 Mdot
.50401 .63707 Mdot
.41653 .37813 Mdot
.67821 .46115 Mdot
.41506 .3765 Mdot
.29945 .67803 Mdot
.48311 .25778 Mdot
.41348 .46246 Mdot
.44741 .3001 Mdot
.69025 .61761 Mdot
.39849 .64854 Mdot
.39484 .3411 Mdot
.48863 .58297 Mdot
.37783 .38338 Mdot
.1296 .48296 Mdot
.65339 .33973 Mdot
.61721 .31361 Mdot
.3647 .4129 Mdot
.37583 .43773 Mdot
.26646 .39971 Mdot
.33491 .66364 Mdot
.51018 .59669 Mdot
.40248 .41349 Mdot
.36169 .26883 Mdot
.64885 .66665 Mdot
.43589 .40189 Mdot
.39671 .45261 Mdot
.63684 .51276 Mdot
.64557 .67103 Mdot
.70202 .51218 Mdot
.48933 .59825 Mdot
.69269 .5225 Mdot
.68651 .31855 Mdot
.42943 .28032 Mdot
.43268 .25874 Mdot
.50692 .44908 Mdot
.63614 .34593 Mdot
.3788 .38976 Mdot
.51005 .62858 Mdot
.3691 .41468 Mdot
.65603 .31396 Mdot
.63104 .67764 Mdot
.41037 .65553 Mdot
.32515 .66812 Mdot
.50291 .57674 Mdot
.39968 .38879 Mdot
.62672 .32989 Mdot
.41646 .64818 Mdot
.46245 .81541 Mdot
.39975 .66083 Mdot
.64047 .65202 Mdot
.6274 .62957 Mdot
.65724 .32865 Mdot
.40336 .64918 Mdot
.69991 .5216 Mdot
.57715 .67349 Mdot
.41884 .47061 Mdot
.65667 .69197 Mdot
.45361 .65405 Mdot
.44462 .66621 Mdot
.39783 .69591 Mdot
.39808 .37163 Mdot
.48595 .32754 Mdot
.31241 .41603 Mdot
.65681 .6667 Mdot
.67898 .44797 Mdot
.51958 .28296 Mdot
.31764 .49805 Mdot
.51653 .41477 Mdot
.40479 .34308 Mdot
.42102 .42764 Mdot
.41193 .44434 Mdot
.36728 .37024 Mdot
.56614 .57201 Mdot
.37315 .45107 Mdot
.6412 .68023 Mdot
.68213 .4777 Mdot
.3936 .40275 Mdot
.48416 .59041 Mdot
.58225 .52743 Mdot
.67781 .2908 Mdot
.33125 .60407 Mdot
.40153 .60617 Mdot
.41543 .6495 Mdot
.71206 .49858 Mdot
.71283 .51189 Mdot
.66709 .29589 Mdot
.63481 .64214 Mdot
.39975 .66556 Mdot
.44389 .19293 Mdot
.67776 .32339 Mdot
.41033 .44139 Mdot
.51852 .34433 Mdot
.32933 .27752 Mdot
.42789 .43477 Mdot
.40012 .44423 Mdot
.48796 .57761 Mdot
.71807 .46322 Mdot
.21107 .624 Mdot
.3888 .76898 Mdot
.65473 .33438 Mdot
.67161 .29873 Mdot
.39796 .69937 Mdot
.42026 .40569 Mdot
.62466 .65653 Mdot
.45634 .28232 Mdot
.67452 .59855 Mdot
.53193 .68078 Mdot
.67291 .58472 Mdot
.41764 .44286 Mdot
.30632 .61415 Mdot
.44124 .43295 Mdot
.45591 .61713 Mdot
.39645 .68726 Mdot
.42352 .66037 Mdot
.6502 .66389 Mdot
.56345 .2713 Mdot
.62973 .6847 Mdot
.52995 .6204 Mdot
.44078 .64266 Mdot
.53295 .51004 Mdot
.71381 .46976 Mdot
.3914 .3599 Mdot
.65877 .30938 Mdot
.6572 .39031 Mdot
.40421 .34054 Mdot
.42286 .27281 Mdot
.69613 .51083 Mdot
.39338 .63782 Mdot
.38586 .36013 Mdot
.54797 .67322 Mdot
.52273 .35986 Mdot
.69754 .60557 Mdot
.48051 .67045 Mdot
.66156 .33736 Mdot
.20845 .5535 Mdot
.67739 .31242 Mdot
.62772 .64537 Mdot
.36838 .44415 Mdot
.41882 .40706 Mdot
.39309 .45023 Mdot
.44214 .39526 Mdot
.64369 .66692 Mdot
.41734 .46969 Mdot
.57894 .33629 Mdot
.50628 .59638 Mdot
.56608 .54202 Mdot
.63789 .33504 Mdot
.59793 .65377 Mdot
.68512 .47394 Mdot
.50937 .57261 Mdot
.62971 .31547 Mdot
.37681 .36218 Mdot
.36796 .40828 Mdot
.50737 .59686 Mdot
.37145 .34585 Mdot
.41747 .3616 Mdot
.68017 .488 Mdot
.57223 .51953 Mdot
.68371 .29354 Mdot
.67129 .31767 Mdot
.60714 .64485 Mdot
.40391 .64865 Mdot
.68066 .29432 Mdot
.65825 .47797 Mdot
.43381 .39682 Mdot
.43884 .42786 Mdot
.45205 .65651 Mdot
.55501 .2746 Mdot
.67755 .2906 Mdot
.33989 .38788 Mdot
.42371 .67996 Mdot
.44596 .61703 Mdot
.40198 .41435 Mdot
.39119 .47033 Mdot
.38449 .69897 Mdot
.66364 .29784 Mdot
.60272 .64824 Mdot
.52949 .42663 Mdot
.60598 .67599 Mdot
.4325 .66206 Mdot
.46315 .39243 Mdot
.38623 .65095 Mdot
.35103 .40169 Mdot
.75244 .72342 Mdot
.37589 .45379 Mdot
.39021 .52045 Mdot
.60562 .45813 Mdot
.71412 .46701 Mdot
.70374 .45836 Mdot
.48881 .59179 Mdot
.42565 .62418 Mdot
.42437 .34321 Mdot
.66313 .30597 Mdot
.54681 .80558 Mdot
.39627 .70964 Mdot
.69159 .45088 Mdot
.72682 .47711 Mdot
.63405 .67663 Mdot
.42195 .42263 Mdot
.38902 .40909 Mdot
.70134 .5084 Mdot
.64752 .56938 Mdot
.40745 .63819 Mdot
.37988 .42593 Mdot
.37131 .37061 Mdot
.6856 .48612 Mdot
.67235 .66926 Mdot
.45839 .65243 Mdot
.39401 .37144 Mdot
.4783 .26192 Mdot
.59731 .6427 Mdot
.3894 .38219 Mdot
.43587 .45323 Mdot
.64973 .32717 Mdot
.41191 .26381 Mdot
.54853 .27797 Mdot
.6128 .68607 Mdot
.48359 .59654 Mdot
.42601 .43553 Mdot
.70851 .46357 Mdot
.36031 .36497 Mdot
.34086 .80169 Mdot
.49986 .59983 Mdot
.37393 .41945 Mdot
.35367 .45786 Mdot
.4327 .67022 Mdot
.3761 .43175 Mdot
.59614 .60815 Mdot
.6985 .4998 Mdot
.37404 .41773 Mdot
.264 .37432 Mdot
.63347 .6761 Mdot
.39731 .3411 Mdot
.66917 .33548 Mdot
.55338 .5067 Mdot
.22046 .35772 Mdot
.65512 .46487 Mdot
.64184 .34207 Mdot
.4198 .41832 Mdot
.6649 .50861 Mdot
.66267 .67348 Mdot
.35783 .49158 Mdot
.38411 .38653 Mdot
.61421 .68162 Mdot
.65209 .65756 Mdot
.65854 .33219 Mdot
.70896 .78733 Mdot
.40734 .46489 Mdot
.39569 .42599 Mdot
.60362 .8276 Mdot
.38141 .69983 Mdot
.39731 .4339 Mdot
.4131 .40811 Mdot
.61908 .64055 Mdot
.57286 .24198 Mdot
.41992 .27022 Mdot
.58306 .56838 Mdot
.60055 .64108 Mdot
.68391 .52759 Mdot
.69319 .50431 Mdot
.6461 .34404 Mdot
.40822 .66358 Mdot
.6466 .30347 Mdot
.6968 .48861 Mdot
.39779 .44778 Mdot
.60745 .65851 Mdot
.20123 .45371 Mdot
.642 .64008 Mdot
.66148 .46006 Mdot
.45623 .61861 Mdot
.27208 .68037 Mdot
.36904 .82588 Mdot
.43129 .53004 Mdot
.60455 .63035 Mdot
.65187 .33122 Mdot
.40161 .78122 Mdot
.39372 .40206 Mdot
.30225 .65891 Mdot
.39856 .42797 Mdot
.45576 .6963 Mdot
.66799 .49037 Mdot
.49877 .60336 Mdot
.3506 .40255 Mdot
.41654 .26965 Mdot
.64728 .64864 Mdot
.61857 .66226 Mdot
.35028 .41997 Mdot
.63762 .65107 Mdot
.38246 .41213 Mdot
.68501 .48061 Mdot
.73519 .74186 Mdot
.38374 .39934 Mdot
.44147 .47821 Mdot
.60513 .62621 Mdot
.40317 .60155 Mdot
.69973 .53236 Mdot
.32535 .57758 Mdot
.53871 .68756 Mdot
.62632 .65687 Mdot
.34043 .59262 Mdot
.71716 .49351 Mdot
.50842 .57135 Mdot
.69179 .52662 Mdot
.39641 .41908 Mdot
.42119 .43793 Mdot
.36502 .37063 Mdot
.41569 .41196 Mdot
.285 .64515 Mdot
.41239 .35834 Mdot
.23056 .49817 Mdot
.36643 .43306 Mdot
.40006 .52127 Mdot
.6328 .68329 Mdot
.43406 .47498 Mdot
.54249 .4304 Mdot
.38715 .45934 Mdot
.36826 .66219 Mdot
.59828 .65904 Mdot
.62885 .73524 Mdot
.64526 .66789 Mdot
.70658 .46931 Mdot
.64506 .64889 Mdot
.35858 .43464 Mdot
.42228 .67275 Mdot
.70857 .48955 Mdot
.43133 .52627 Mdot
.67304 .45367 Mdot
.37081 .42395 Mdot
.63461 .62239 Mdot
.72423 .48467 Mdot
.44036 .3794 Mdot
.41894 .67396 Mdot
.40208 .23819 Mdot
.46406 .61402 Mdot
.38234 .43587 Mdot
.38838 .43699 Mdot
.50988 .59572 Mdot
.64004 .64571 Mdot
.38388 .65815 Mdot
.63068 .50252 Mdot
.63707 .30877 Mdot
.4157 .66412 Mdot
.4033 .48973 Mdot
.52105 .35366 Mdot
.43289 .67375 Mdot
.34668 .27318 Mdot
.62332 .64449 Mdot
.44322 .65604 Mdot
.36761 .47828 Mdot
.23385 .58846 Mdot
.67391 .31728 Mdot
.70703 .52031 Mdot
.50825 .30769 Mdot
.69473 .50332 Mdot
.5926 .6155 Mdot
.73097 .50362 Mdot
.64566 .67397 Mdot
.42936 .31773 Mdot
.5366 .49178 Mdot
.63704 .63589 Mdot
.59736 .62525 Mdot
.68776 .49361 Mdot
.35212 .38408 Mdot
.56475 .53065 Mdot
.43112 .34604 Mdot
.46675 .39094 Mdot
.60043 .67172 Mdot
.44468 .64885 Mdot
.38656 .63824 Mdot
.46362 .45931 Mdot
.40437 .67906 Mdot
.70211 .48017 Mdot
.50051 .45674 Mdot
.34612 .59807 Mdot
.62542 .67779 Mdot
.57818 .51151 Mdot
.40963 .37647 Mdot
.67317 .48168 Mdot
.70164 .47728 Mdot
.6512 .65789 Mdot
.25455 .62406 Mdot
.44911 .36346 Mdot
.37213 .70122 Mdot
.44106 .65218 Mdot
.43516 .66856 Mdot
.38877 .67039 Mdot
.56451 .26877 Mdot
.61579 .63593 Mdot
.43115 .627 Mdot
.43862 .38834 Mdot
.42167 .41337 Mdot
.50326 .58847 Mdot
.64657 .30764 Mdot
.44729 .40123 Mdot
.42299 .34245 Mdot
.40013 .4134 Mdot
.71709 .46994 Mdot
.36989 .30291 Mdot
.50747 .59376 Mdot
.71945 .46654 Mdot
.71613 .46467 Mdot
.486 .59531 Mdot
.42386 .31381 Mdot
.21899 .62635 Mdot
.35267 .42723 Mdot
.36593 .65368 Mdot
.69831 .45698 Mdot
.62676 .391 Mdot
.40799 .52755 Mdot
.42292 .39803 Mdot
.58503 .5521 Mdot
.69015 .47779 Mdot
.36827 .6768 Mdot
.39182 .42026 Mdot
.50048 .57303 Mdot
.67283 .32555 Mdot
.32044 .44635 Mdot
.48869 .57729 Mdot
.4009 .64493 Mdot
.65971 .43216 Mdot
.44824 .64913 Mdot
.72407 .50255 Mdot
.41235 .34087 Mdot
.85994 .63634 Mdot
.69009 .46647 Mdot
.56303 .8048 Mdot
.53802 .49441 Mdot
.37774 .4043 Mdot
.70633 .50063 Mdot
.4035 .70598 Mdot
.59685 .64217 Mdot
.49805 .33559 Mdot
.39855 .6516 Mdot
.51053 .5731 Mdot
.50073 .58745 Mdot
.68556 .48801 Mdot
.43667 .64601 Mdot
.42931 .46162 Mdot
.40818 .67645 Mdot
.61056 .66348 Mdot
.3553 .40056 Mdot
.54145 .67119 Mdot
.45415 .45701 Mdot
.41162 .6804 Mdot
.66996 .45244 Mdot
.67851 .33541 Mdot
.36625 .40384 Mdot
.60994 .72826 Mdot
.42009 .41738 Mdot
.63573 .67766 Mdot
.60594 .42838 Mdot
.20508 .45681 Mdot
.41107 .43339 Mdot
.40789 .37676 Mdot
.66104 .68576 Mdot
.41087 .4308 Mdot
.43175 .43592 Mdot
.39949 .57873 Mdot
.4313 .6756 Mdot
.3961 .40385 Mdot
.68147 .50259 Mdot
.23762 .41661 Mdot
.37873 .44738 Mdot
.60006 .60511 Mdot
.38802 .2521 Mdot
.59013 .40287 Mdot
.47607 .39701 Mdot
.46855 .26922 Mdot
.39089 .43366 Mdot
.42112 .39812 Mdot
.35161 .42437 Mdot
.30611 .62075 Mdot
.69432 .49232 Mdot
.67348 .46524 Mdot
.6589 .3486 Mdot
.38586 .25639 Mdot
.66694 .32667 Mdot
.66523 .66935 Mdot
.56498 .50706 Mdot
.51207 .58776 Mdot
.40465 .64752 Mdot
.38506 .44809 Mdot
.66768 .46023 Mdot
.39064 .41225 Mdot
.38076 .38255 Mdot
.69881 .48201 Mdot
.6956 .47486 Mdot
.65982 .45217 Mdot
.67465 .33134 Mdot
.41766 .65653 Mdot
.36478 .44378 Mdot
.67959 .32278 Mdot
.37301 .36819 Mdot
.52671 .40604 Mdot
.41918 .65861 Mdot
.41037 .68118 Mdot
.40316 .62576 Mdot
.38139 .39584 Mdot
.35187 .41191 Mdot
.62816 .68482 Mdot
.4524 .65541 Mdot
.62526 .65084 Mdot
.70483 .50147 Mdot
.67507 .48867 Mdot
.3971 .41957 Mdot
.33719 .44472 Mdot
.63666 .3279 Mdot
.72152 .49254 Mdot
.47366 .59666 Mdot
.66242 .34505 Mdot
.40947 .44882 Mdot
.69947 .50309 Mdot
.63174 .33034 Mdot
.24143 .62348 Mdot
.4965 .69846 Mdot
.664 .34656 Mdot
.34905 .41042 Mdot
.29883 .47907 Mdot
.49376 .26214 Mdot
.67335 .28962 Mdot
.6289 .6819 Mdot
.40777 .40245 Mdot
.57069 .58652 Mdot
.68573 .30333 Mdot
.54061 .27628 Mdot
.70223 .48622 Mdot
.46585 .41874 Mdot
.30446 .3768 Mdot
.35207 .59229 Mdot
.68128 .33082 Mdot
.41455 .68001 Mdot
.43154 .68197 Mdot
.41048 .43969 Mdot
.55842 .50634 Mdot
.66239 .65822 Mdot
.7119 .51288 Mdot
.67104 .4647 Mdot
.42387 .6867 Mdot
.50893 .44788 Mdot
.68453 .50394 Mdot
.41758 .40167 Mdot
.69409 .31581 Mdot
.41927 .37054 Mdot
.59598 .27745 Mdot
.22375 .40311 Mdot
.47651 .40629 Mdot
.67547 .33886 Mdot
.66098 .66526 Mdot
.65302 .66614 Mdot
.64684 .65727 Mdot
.67995 .49443 Mdot
.49087 .30489 Mdot
.66623 .47188 Mdot
.56159 .83327 Mdot
.65469 .34085 Mdot
.47217 .18232 Mdot
.44481 .41198 Mdot
.37559 .40613 Mdot
.43049 .3883 Mdot
.36575 .37446 Mdot
.38986 .43254 Mdot
.61936 .68507 Mdot
.68079 .51857 Mdot
.67302 .59162 Mdot
.42548 .63751 Mdot
.45583 .81332 Mdot
.71502 .47114 Mdot
.48367 .58168 Mdot
.64153 .3189 Mdot
.41058 .25114 Mdot
.67041 .35188 Mdot
.72199 .49821 Mdot
.41545 .45552 Mdot
.39986 .70027 Mdot
.43273 .19785 Mdot
.37815 .44116 Mdot
.71973 .49732 Mdot
.66787 .51713 Mdot
.24013 .60707 Mdot
.31895 .38418 Mdot
.65303 .56315 Mdot
.51321 .35253 Mdot
.65435 .35311 Mdot
.3455 .3912 Mdot
.44457 .27715 Mdot
.69464 .48858 Mdot
.68733 .46117 Mdot
.65471 .2956 Mdot
.35926 .71921 Mdot
.43253 .63031 Mdot
.44413 .60421 Mdot
.61014 .6751 Mdot
.37023 .40817 Mdot
.68813 .49852 Mdot
.45611 .60951 Mdot
.54554 .37555 Mdot
.64101 .66258 Mdot
.72521 .47482 Mdot
.41922 .41432 Mdot
.41299 .43191 Mdot
.665 .32942 Mdot
.5967 .48739 Mdot
.43126 .34618 Mdot
.55017 .80522 Mdot
.51142 .38768 Mdot
.53911 .49437 Mdot
.39684 .40957 Mdot
.38842 .66395 Mdot
.48663 .59446 Mdot
.6547 .30919 Mdot
.36672 .36121 Mdot
.29276 .70394 Mdot
.4401 .62571 Mdot
.62732 .65092 Mdot
.47965 .59177 Mdot
.43328 .28518 Mdot
.41848 .41436 Mdot
.39837 .42738 Mdot
.40076 .37176 Mdot
.25113 .66795 Mdot
.66779 .48568 Mdot
.39164 .67216 Mdot
.66519 .33772 Mdot
.39688 .66669 Mdot
.73041 .49413 Mdot
.57847 .51387 Mdot
.3634 .44602 Mdot
.42554 .62008 Mdot
.40406 .66987 Mdot
.6315 .67681 Mdot
.65086 .64921 Mdot
.65458 .48263 Mdot
.40794 .40565 Mdot
.51316 .58628 Mdot
.43925 .63348 Mdot
.69783 .51899 Mdot
.66452 .32802 Mdot
.58926 .61659 Mdot
.36507 .43011 Mdot
.68874 .4896 Mdot
.41046 .33994 Mdot
.42387 .6429 Mdot
.72131 .48277 Mdot
.50546 .57005 Mdot
.65824 .30016 Mdot
.42351 .43595 Mdot
.69423 .58847 Mdot
.49457 .57503 Mdot
.37163 .40015 Mdot
.22178 .42066 Mdot
.55876 .50689 Mdot
.45815 .67902 Mdot
.67321 .5004 Mdot
.50723 .57562 Mdot
.39731 .68412 Mdot
.22407 .56442 Mdot
.68127 .46553 Mdot
.27295 .42564 Mdot
.52908 .48756 Mdot
.34991 .41252 Mdot
.39951 .64816 Mdot
.60478 .31011 Mdot
.51602 .80145 Mdot
.50366 .27033 Mdot
.37745 .41846 Mdot
.69395 .50323 Mdot
.6724 .32337 Mdot
.61832 .66066 Mdot
.5836 .66575 Mdot
.62149 .25939 Mdot
.70372 .45314 Mdot
.38538 .44867 Mdot
.44436 .64995 Mdot
.63182 .65015 Mdot
.26082 .40599 Mdot
.66143 .49094 Mdot
.68513 .50626 Mdot
.43115 .40086 Mdot
.668 .32482 Mdot
.5569 .59213 Mdot
.66865 .47946 Mdot
.67678 .51742 Mdot
.40222 .57203 Mdot
.64921 .35199 Mdot
.38688 .37232 Mdot
.46332 .45989 Mdot
.44015 .41211 Mdot
.51504 .828 Mdot
.50898 .57679 Mdot
.42331 .63604 Mdot
.39617 .43944 Mdot
.69347 .62757 Mdot
.68119 .47163 Mdot
.5128 .35357 Mdot
.67051 .65963 Mdot
.64739 .64691 Mdot
.69963 .49817 Mdot
.38634 .41683 Mdot
.66015 .69523 Mdot
.64475 .34168 Mdot
.3864 .37179 Mdot
.35127 .40397 Mdot
.44768 .6711 Mdot
.60758 .66173 Mdot
.23528 .41292 Mdot
.61538 .65833 Mdot
.61432 .64012 Mdot
.46486 .63086 Mdot
.41081 .43985 Mdot
.71783 .47893 Mdot
.69394 .44056 Mdot
.3382 .39892 Mdot
.64539 .39536 Mdot
.42014 .62638 Mdot
.73673 .51318 Mdot
.28805 .70302 Mdot
.43596 .43679 Mdot
.47625 .59746 Mdot
.49337 .65053 Mdot
.63149 .63014 Mdot
.40613 .43873 Mdot
.40807 .64428 Mdot
.66795 .50733 Mdot
.68712 .5018 Mdot
.44823 .40348 Mdot
.65442 .66374 Mdot
.63245 .32342 Mdot
.70505 .47827 Mdot
.52714 .43664 Mdot
.37292 .42268 Mdot
.60823 .71096 Mdot
.70788 .47913 Mdot
.23973 .29996 Mdot
.69564 .63684 Mdot
.43546 .67031 Mdot
.41847 .38527 Mdot
.43063 .68566 Mdot
.64724 .34771 Mdot
.717 .52023 Mdot
.64648 .6773 Mdot
.34988 .35223 Mdot
.8161 .58066 Mdot
.68276 .49428 Mdot
.40649 .65472 Mdot
.39511 .44645 Mdot
.34507 .58393 Mdot
.39014 .40004 Mdot
.57217 .23711 Mdot
.68106 .29006 Mdot
.59885 .61324 Mdot
.65715 .66796 Mdot
.4077 .37777 Mdot
.68034 .31099 Mdot
.68568 .4404 Mdot
.69818 .48271 Mdot
.79794 .64502 Mdot
.49265 .57395 Mdot
.73496 .46243 Mdot
.37838 .39765 Mdot
.7016 .51622 Mdot
.31915 .4994 Mdot
.65234 .65597 Mdot
.43916 .41681 Mdot
.71199 .45307 Mdot
.47223 .80337 Mdot
.51689 .35189 Mdot
.37455 .42086 Mdot
.34596 .45605 Mdot
.64132 .67486 Mdot
.40049 .78056 Mdot
.66799 .49533 Mdot
.37288 .36416 Mdot
.66827 .66334 Mdot
.45245 .33573 Mdot
.62607 .50647 Mdot
.41815 .65662 Mdot
.72186 .46143 Mdot
.60245 .6512 Mdot
.46441 .42717 Mdot
.63824 .31696 Mdot
.65782 .48441 Mdot
.68954 .44675 Mdot
.35999 .3995 Mdot
.38749 .36698 Mdot
.34986 .46182 Mdot
.40451 .63556 Mdot
.61602 .6421 Mdot
.37714 .38051 Mdot
.52579 .39545 Mdot
.36627 .37684 Mdot
.60968 .64573 Mdot
.77942 .73406 Mdot
.41594 .45352 Mdot
.36524 .42525 Mdot
.33232 .59151 Mdot
.38297 .65438 Mdot
.42414 .68256 Mdot
.51573 .39757 Mdot
.39832 .39458 Mdot
.52868 .5111 Mdot
.41481 .65471 Mdot
.40335 .65716 Mdot
.52996 .51076 Mdot
.35535 .4065 Mdot
.46039 .60324 Mdot
.63387 .65005 Mdot
.64797 .64713 Mdot
.43223 .67065 Mdot
.41629 .37045 Mdot
.66253 .67203 Mdot
.2713 .61662 Mdot
.72392 .49182 Mdot
.43908 .27704 Mdot
.40546 .67336 Mdot
.52009 .3406 Mdot
.62665 .64475 Mdot
.26142 .30736 Mdot
.34203 .268 Mdot
.42725 .45407 Mdot
.4101 .43809 Mdot
.65244 .32488 Mdot
.36373 .34726 Mdot
.48817 .5964 Mdot
.64649 .65537 Mdot
.56625 .57081 Mdot
.424 .66097 Mdot
.39787 .39599 Mdot
.52338 .2872 Mdot
.22293 .36087 Mdot
.42821 .49569 Mdot
.4065 .66263 Mdot
.42419 .66717 Mdot
.68863 .50976 Mdot
.72178 .50159 Mdot
.36508 .4468 Mdot
.65008 .67045 Mdot
.44054 .66346 Mdot
.6092 .65063 Mdot
.696 .48783 Mdot
.71431 .4729 Mdot
.50395 .5949 Mdot
.46443 .38114 Mdot
.70133 .49404 Mdot
.62712 .5963 Mdot
.52585 .3971 Mdot
.45503 .65082 Mdot
.58913 .83119 Mdot
.27715 .29121 Mdot
.32344 .6505 Mdot
.67291 .32415 Mdot
.43548 .32094 Mdot
.64085 .68652 Mdot
.40371 .37678 Mdot
.40325 .42657 Mdot
.50121 .58032 Mdot
.64736 .6853 Mdot
.6433 .32715 Mdot
.65022 .65116 Mdot
.65783 .30489 Mdot
.67646 .46137 Mdot
.38019 .44635 Mdot
.38641 .45781 Mdot
.61975 .66359 Mdot
.7038 .51124 Mdot
.72397 .48352 Mdot
.673 .31063 Mdot
.40485 .2502 Mdot
.68734 .48751 Mdot
.40391 .67218 Mdot
.25725 .44362 Mdot
.50147 .58609 Mdot
.39107 .42063 Mdot
.46365 .26707 Mdot
.22245 .54468 Mdot
.36009 .37344 Mdot
.48206 .58841 Mdot
.71429 .78361 Mdot
.37549 .44606 Mdot
.83072 .53281 Mdot
.51064 .58852 Mdot
.38581 .65137 Mdot
.71618 .48896 Mdot
.48831 .57838 Mdot
.35298 .30769 Mdot
.66976 .55027 Mdot
.34297 .3882 Mdot
.43122 .62894 Mdot
.40098 .62948 Mdot
.5755 .5164 Mdot
.51148 .82838 Mdot
.66612 .33693 Mdot
.64481 .33659 Mdot
.67808 .47083 Mdot
.57795 .62819 Mdot
.43017 .37687 Mdot
.64739 .33654 Mdot
.44789 .59423 Mdot
.41479 .37804 Mdot
.56055 .50865 Mdot
.56498 .53634 Mdot
.40256 .68571 Mdot
.43663 .47056 Mdot
.6796 .47086 Mdot
.40796 .6558 Mdot
.56736 .52486 Mdot
.43439 .40173 Mdot
.42111 .65966 Mdot
.62587 .64075 Mdot
.49165 .53251 Mdot
.4058 .67707 Mdot
.50331 .34112 Mdot
.62389 .66102 Mdot
.56852 .50968 Mdot
.51082 .20703 Mdot
.16788 .38384 Mdot
.65197 .66453 Mdot
.71721 .49781 Mdot
.68843 .49735 Mdot
.68468 .48406 Mdot
.39807 .64375 Mdot
.69279 .47125 Mdot
.42827 .63368 Mdot
.58802 .63854 Mdot
.40192 .26084 Mdot
.65914 .32637 Mdot
.60116 .33711 Mdot
.42638 .67363 Mdot
.5481 .83297 Mdot
.49566 .86921 Mdot
.37166 .37372 Mdot
.63342 .63494 Mdot
.67744 .33145 Mdot
.50656 .39402 Mdot
.6501 .32602 Mdot
.71658 .49436 Mdot
.42388 .2762 Mdot
.38311 .41097 Mdot
.52501 .65642 Mdot
.67188 .32297 Mdot
.40187 .65776 Mdot
.37343 .39307 Mdot
.72558 .46163 Mdot
.64501 .3451 Mdot
.67073 .3139 Mdot
.39023 .43062 Mdot
.39154 .63992 Mdot
.72194 .48716 Mdot
.62163 .68855 Mdot
.69129 .32836 Mdot
.32346 .40218 Mdot
.38065 .45138 Mdot
.4002 .4633 Mdot
.51605 .36064 Mdot
.57294 .63218 Mdot
.62618 .66082 Mdot
.54077 .27969 Mdot
.6732 .48381 Mdot
.5045 .26869 Mdot
.54186 .79631 Mdot
.6102 .3052 Mdot
.50868 .57768 Mdot
.51012 .57762 Mdot
.37804 .42977 Mdot
.39027 .82532 Mdot
.39373 .51129 Mdot
.66818 .64959 Mdot
.4986 .58409 Mdot
.72561 .49293 Mdot
.45033 .65444 Mdot
.30668 .37845 Mdot
.4464 .40611 Mdot
.62434 .68973 Mdot
.69262 .48413 Mdot
.33482 .79919 Mdot
.65738 .33919 Mdot
.50821 .40553 Mdot
.41063 .40804 Mdot
.38229 .42612 Mdot
.63558 .66523 Mdot
.64369 .67873 Mdot
.40163 .57084 Mdot
.58353 .38794 Mdot
.53663 .68185 Mdot
.61909 .69196 Mdot
.33296 .79883 Mdot
.47574 .67772 Mdot
.43317 .65625 Mdot
.4838 .5988 Mdot
.66156 .65965 Mdot
.39701 .43619 Mdot
.38503 .64973 Mdot
.38257 .50627 Mdot
.37706 .67121 Mdot
.55331 .50608 Mdot
.52911 .42718 Mdot
.42082 .42701 Mdot
.39331 .69267 Mdot
.41229 .65799 Mdot
.39406 .62014 Mdot
.49293 .59295 Mdot
.40047 .41105 Mdot
.36686 .36605 Mdot
.37059 .44489 Mdot
.40192 .54751 Mdot
.37557 .43154 Mdot
.53593 .79802 Mdot
.51929 .41661 Mdot
.74599 .34136 Mdot
.37181 .44034 Mdot
.62383 .63901 Mdot
.38512 .44596 Mdot
.67946 .30569 Mdot
.42166 .44249 Mdot
.54889 .50304 Mdot
.63451 .65426 Mdot
.29824 .68373 Mdot
.65391 .50861 Mdot
.38868 .45652 Mdot
.6344 .34416 Mdot
.64077 .78766 Mdot
.5382 .28432 Mdot
.404 .57176 Mdot
.40821 .67621 Mdot
.66981 .51393 Mdot
.65786 .64828 Mdot
.70795 .46918 Mdot
.42239 .46799 Mdot
.49379 .59999 Mdot
.45243 .16362 Mdot
.53121 .3385 Mdot
.39597 .4383 Mdot
.45267 .36731 Mdot
.40246 .68115 Mdot
.68394 .46981 Mdot
.33262 .67413 Mdot
.42602 .38281 Mdot
.65731 .2983 Mdot
.68411 .31264 Mdot
.75707 .46536 Mdot
.46337 .55169 Mdot
.35333 .51973 Mdot
.63412 .6637 Mdot
.68143 .49729 Mdot
.68381 .32015 Mdot
.40305 .60805 Mdot
.65728 .65078 Mdot
.63218 .63007 Mdot
.60701 .66252 Mdot
.37003 .41858 Mdot
.50492 .59117 Mdot
.46693 .56687 Mdot
.49871 .57183 Mdot
.43871 .39695 Mdot
.69182 .44663 Mdot
.50698 .57135 Mdot
.65932 .32071 Mdot
.60522 .64498 Mdot
.7159 .47 Mdot
.38571 .4378 Mdot
.4171 .65087 Mdot
.58186 .30835 Mdot
.70071 .63267 Mdot
.56039 .50672 Mdot
.56052 .50674 Mdot
.43453 .61719 Mdot
.53804 .6145 Mdot
.58205 .63481 Mdot
.23515 .59777 Mdot
.69437 .28347 Mdot
.35639 .35953 Mdot
.67998 .40857 Mdot
.66518 .47432 Mdot
.70843 .48757 Mdot
.38017 .40878 Mdot
.68858 .5156 Mdot
.39679 .39807 Mdot
.67332 .5017 Mdot
.5117 .81091 Mdot
.44302 .43393 Mdot
.70387 .48184 Mdot
.32379 .37085 Mdot
.36645 .40404 Mdot
.39081 .66656 Mdot
.66368 .49912 Mdot
.42784 .45331 Mdot
.57936 .14385 Mdot
.62906 .67568 Mdot
.49458 .59224 Mdot
.53782 .47041 Mdot
.63484 .64597 Mdot
.43548 .63612 Mdot
.41142 .40065 Mdot
.65421 .34266 Mdot
.43213 .66174 Mdot
.71575 .53415 Mdot
.67002 .32041 Mdot
.5005 .46004 Mdot
.4335 .66513 Mdot
.50431 .58433 Mdot
.66592 .29763 Mdot
.34241 .39039 Mdot
.70629 .48647 Mdot
.69964 .64055 Mdot
.48195 .5865 Mdot
.38702 .41022 Mdot
.72831 .47086 Mdot
.64633 .64857 Mdot
.40133 .4516 Mdot
.68786 .49969 Mdot
.48163 .59477 Mdot
.36312 .41728 Mdot
.38444 .39266 Mdot
.35187 .71267 Mdot
.61019 .43924 Mdot
.65946 .32385 Mdot
.45654 .6199 Mdot
.44125 .39478 Mdot
.67907 .31218 Mdot
.66955 .57902 Mdot
.41095 .47972 Mdot
.43772 .62883 Mdot
.26324 .61711 Mdot
.70923 .51392 Mdot
.65653 .66234 Mdot
.66374 .4566 Mdot
.65323 .34988 Mdot
.55517 .87294 Mdot
.49062 .59751 Mdot
.36604 .46122 Mdot
.43302 .43605 Mdot
.70323 .52605 Mdot
.41455 .66033 Mdot
.53471 .68045 Mdot
.4253 .43253 Mdot
.45889 .38707 Mdot
.39103 .42541 Mdot
.6905 .57692 Mdot
.39984 .63976 Mdot
.39169 .4228 Mdot
.33218 .39777 Mdot
.43804 .42877 Mdot
.63392 .33457 Mdot
.46764 .18216 Mdot
.3525 .38774 Mdot
.89346 .58436 Mdot
.48917 .6046 Mdot
.6945 .48029 Mdot
.50431 .34522 Mdot
.54383 .46615 Mdot
.7106 .25914 Mdot
.42875 .6306 Mdot
.37024 .64264 Mdot
.71429 .4744 Mdot
.61555 .28096 Mdot
.54005 .61045 Mdot
.38149 .39119 Mdot
.41321 .40679 Mdot
.71662 .49425 Mdot
.69947 .51948 Mdot
.48997 .60302 Mdot
.34992 .42827 Mdot
.45134 .45888 Mdot
.67266 .45111 Mdot
.37598 .43802 Mdot
.21743 .52033 Mdot
.60602 .63443 Mdot
.43097 .67409 Mdot
.6175 .66247 Mdot
.59927 .63876 Mdot
.32549 .66736 Mdot
.51195 .38155 Mdot
.61235 .67844 Mdot
.63695 .62699 Mdot
.60095 .31728 Mdot
.34667 .59477 Mdot
.63357 .33083 Mdot
.45692 .53032 Mdot
.67826 .4828 Mdot
.40228 .41256 Mdot
.39763 .64186 Mdot
.60852 .21944 Mdot
.54944 .70918 Mdot
.33841 .30128 Mdot
.3892 .37261 Mdot
.67986 .47618 Mdot
.47921 .59005 Mdot
.41123 .48005 Mdot
.49696 .26398 Mdot
.37845 .42277 Mdot
.71602 .50978 Mdot
.34698 .59699 Mdot
.68897 .65113 Mdot
.60387 .68502 Mdot
.38816 .70728 Mdot
.38574 .44685 Mdot
.41146 .63651 Mdot
.59871 .66618 Mdot
.67681 .32374 Mdot
.65282 .33219 Mdot
.39067 .45724 Mdot
.53764 .4946 Mdot
.68533 .26758 Mdot
.37774 .39274 Mdot
.35771 .40147 Mdot
.50664 .57691 Mdot
.35713 .40111 Mdot
.35917 .36943 Mdot
.38067 .37832 Mdot
.37652 .36782 Mdot
.65956 .65467 Mdot
.33415 .6415 Mdot
.35402 .44109 Mdot
.38855 .4689 Mdot
.5916 .65565 Mdot
.40629 .47193 Mdot
.64671 .66691 Mdot
.55505 .69176 Mdot
.6171 .67996 Mdot
.6544 .33149 Mdot
.7293 .47045 Mdot
.35282 .64339 Mdot
.44064 .66257 Mdot
.63509 .63921 Mdot
.65314 .30434 Mdot
.64991 .66005 Mdot
.67497 .49427 Mdot
.68362 .62298 Mdot
.46195 .66067 Mdot
.5232 .44588 Mdot
.33301 .60405 Mdot
.64907 .72131 Mdot
.69165 .51401 Mdot
.43681 .66684 Mdot
.59342 .61028 Mdot
.4039 .37754 Mdot
.66115 .3396 Mdot
.37876 .42975 Mdot
.60871 .64222 Mdot
.67926 .47983 Mdot
.39061 .59746 Mdot
.6584 .32359 Mdot
.6239 .82371 Mdot
.66695 .46052 Mdot
.42746 .44147 Mdot
.59261 .65962 Mdot
.65446 .59316 Mdot
.63998 .67752 Mdot
.40348 .25916 Mdot
.50966 .63245 Mdot
.61517 .23411 Mdot
.42676 .66804 Mdot
.4898 .5726 Mdot
.15147 .4652 Mdot
.59697 .75834 Mdot
.42111 .64572 Mdot
.65846 .43798 Mdot
.3718 .43021 Mdot
.37478 .37609 Mdot
.46132 .37906 Mdot
.37953 .65821 Mdot
.40172 .37186 Mdot
.49723 .59348 Mdot
.51688 .38191 Mdot
.49008 .56207 Mdot
.65967 .50288 Mdot
.39541 .39919 Mdot
.60119 .67271 Mdot
.63401 .63788 Mdot
.51316 .57344 Mdot
.61202 .65927 Mdot
.35822 .42272 Mdot
.42692 .6718 Mdot
.56526 .52963 Mdot
.64976 .34745 Mdot
.57699 .7952 Mdot
.68216 .27631 Mdot
.66504 .35738 Mdot
.43723 .43464 Mdot
.71616 .47502 Mdot
.8176 .55523 Mdot
.40056 .3748 Mdot
.41186 .65446 Mdot
.4333 .43322 Mdot
.37343 .37914 Mdot
.3578 .43586 Mdot
.68128 .49663 Mdot
.51856 .34907 Mdot
.37636 .43897 Mdot
.60624 .67413 Mdot
.53041 .50795 Mdot
.44649 .40109 Mdot
.58797 .56378 Mdot
.55008 .50436 Mdot
.62078 .71503 Mdot
.45138 .66326 Mdot
.71748 .48173 Mdot
.42553 .66234 Mdot
.38069 .68944 Mdot
.43552 .63651 Mdot
.4777 .56435 Mdot
.23141 .58648 Mdot
.83393 .52252 Mdot
.32594 .50499 Mdot
.32833 .61068 Mdot
.39294 .70601 Mdot
.76333 .54477 Mdot
.41648 .64326 Mdot
.43366 .63423 Mdot
.76357 .72273 Mdot
.4071 .62946 Mdot
.39718 .41859 Mdot
.3944 .46167 Mdot
.26867 .6766 Mdot
.65557 .36442 Mdot
.373 .40125 Mdot
.37005 .36926 Mdot
.68437 .31533 Mdot
.35515 .70827 Mdot
.4789 .60177 Mdot
.50895 .4175 Mdot
.48726 .57652 Mdot
.38966 .43118 Mdot
.41632 .43941 Mdot
.38197 .35176 Mdot
.19667 .39362 Mdot
.62671 .24273 Mdot
.39947 .6288 Mdot
.34709 .3713 Mdot
.67078 .71417 Mdot
.42507 .40601 Mdot
.43466 .42392 Mdot
.35604 .43076 Mdot
.71783 .47876 Mdot
.44923 .63761 Mdot
.42629 .3437 Mdot
.59904 .77662 Mdot
.41875 .41786 Mdot
.67586 .27305 Mdot
.62216 .34118 Mdot
.38753 .41635 Mdot
.4117 .62593 Mdot
.37871 .37452 Mdot
.43963 .67257 Mdot
.43541 .66098 Mdot
.46283 .40999 Mdot
.45854 .57169 Mdot
.44997 .65376 Mdot
.38315 .39099 Mdot
.70128 .51261 Mdot
.55491 .80523 Mdot
.38685 .41137 Mdot
.66399 .31887 Mdot
.4043 .44192 Mdot
.63396 .33925 Mdot
.35526 .39261 Mdot
.5045 .57196 Mdot
.20001 .46313 Mdot
.68535 .46122 Mdot
.67915 .34502 Mdot
.69515 .51621 Mdot
.41916 .36753 Mdot
.43225 .68762 Mdot
.68657 .66362 Mdot
.63378 .25165 Mdot
.50686 .57765 Mdot
.55801 .27738 Mdot
.52841 .52262 Mdot
.6355 .6857 Mdot
.3921 .67417 Mdot
.34005 .61825 Mdot
.58654 .56088 Mdot
.65984 .50554 Mdot
.72712 .4798 Mdot
.62618 .48527 Mdot
.73542 .74167 Mdot
.37075 .43587 Mdot
.57717 .58243 Mdot
.22826 .49019 Mdot
.36778 .34603 Mdot
.3138 .39216 Mdot
.68632 .44701 Mdot
.37294 .40096 Mdot
.52661 .32213 Mdot
.68902 .49376 Mdot
.63882 .33024 Mdot
.42157 .63518 Mdot
.67258 .30484 Mdot
.49717 .71575 Mdot
.3986 .57809 Mdot
.69723 .4938 Mdot
.38079 .36862 Mdot
.37718 .40217 Mdot
.38313 .65729 Mdot
.26207 .40459 Mdot
.43083 .67606 Mdot
.65799 .34592 Mdot
.6766 .46798 Mdot
.5201 .14555 Mdot
.39771 .44684 Mdot
.40311 .66774 Mdot
.65271 .50671 Mdot
.41345 .42936 Mdot
.65497 .66102 Mdot
.40575 .3728 Mdot
.39845 .66521 Mdot
.35705 .40038 Mdot
.4288 .66687 Mdot
.6947 .50961 Mdot
.39051 .45841 Mdot
.40895 .4485 Mdot
.54485 .27808 Mdot
.64389 .32584 Mdot
.44579 .6639 Mdot
.52061 .31874 Mdot
.44017 .41203 Mdot
.48138 .26183 Mdot
.37909 .44637 Mdot
.34291 .59257 Mdot
.38203 .48165 Mdot
.50031 .59167 Mdot
.43437 .43168 Mdot
.38526 .41213 Mdot
.26611 .40007 Mdot
.3126 .49345 Mdot
.40403 .54957 Mdot
.65212 .64998 Mdot
.39382 .65186 Mdot
.69202 .49784 Mdot
.66583 .50686 Mdot
.69879 .47054 Mdot
.68373 .28768 Mdot
.33623 .40112 Mdot
.38964 .40718 Mdot
.65835 .63604 Mdot
.65081 .33845 Mdot
.40781 .66678 Mdot
.65872 .3316 Mdot
.50986 .37681 Mdot
.66218 .3162 Mdot
.48678 .59703 Mdot
.69212 .62963 Mdot
.22137 .53376 Mdot
.6523 .31231 Mdot
.43268 .67216 Mdot
.52287 .50534 Mdot
.3779 .34462 Mdot
.47985 .82116 Mdot
.66228 .29635 Mdot
.63368 .49584 Mdot
.36211 .42709 Mdot
.49762 .33124 Mdot
.64441 .66615 Mdot
.67141 .30415 Mdot
.60844 .66514 Mdot
.38028 .37449 Mdot
.38159 .71762 Mdot
.40444 .65095 Mdot
.60123 .636 Mdot
.43739 .41748 Mdot
.67216 .30418 Mdot
.70149 .49163 Mdot
.34872 .59311 Mdot
.59386 .63543 Mdot
.58333 .31571 Mdot
.50486 .27042 Mdot
.67421 .47438 Mdot
.34603 .56259 Mdot
.61415 .67551 Mdot
.34906 .36902 Mdot
.36252 .49035 Mdot
.42842 .38082 Mdot
.7239 .48182 Mdot
.70924 .48737 Mdot
.63857 .72723 Mdot
.41293 .44563 Mdot
.35719 .44698 Mdot
.45603 .63203 Mdot
.67349 .47241 Mdot
.43697 .63876 Mdot
.40087 .69339 Mdot
.71545 .49928 Mdot
.43291 .67646 Mdot
.67101 .31866 Mdot
.47249 .29294 Mdot
.61399 .67611 Mdot
.6558 .66846 Mdot
.69952 .4947 Mdot
.69007 .45366 Mdot
.7157 .47377 Mdot
.42864 .39018 Mdot
.43915 .65357 Mdot
.41502 .38416 Mdot
.38888 .44726 Mdot
.47409 .60967 Mdot
.46111 .63801 Mdot
.42798 .40237 Mdot
.56292 .53991 Mdot
.65853 .29609 Mdot
.70029 .47917 Mdot
.61389 .64573 Mdot
.5851 .2964 Mdot
.61529 .6846 Mdot
.4417 .41547 Mdot
.47811 .80837 Mdot
.398 .64695 Mdot
.65103 .32534 Mdot
.55161 .5031 Mdot
.65558 .32377 Mdot
.60432 .6349 Mdot
.44087 .61628 Mdot
.50467 .45368 Mdot
.40979 .44953 Mdot
.51622 .363 Mdot
.51797 .22518 Mdot
.55048 .79212 Mdot
.61925 .64121 Mdot
.37606 .37369 Mdot
.51043 .58324 Mdot
.23488 .60155 Mdot
.38631 .40743 Mdot
.43802 .44132 Mdot
.55562 .48213 Mdot
.4317 .44123 Mdot
.40258 .62302 Mdot
.55829 .51217 Mdot
.35053 .38432 Mdot
.41075 .36442 Mdot
.77139 .68354 Mdot
.36553 .40977 Mdot
.40237 .45378 Mdot
.40395 .42029 Mdot
.41437 .37906 Mdot
.43185 .68496 Mdot
.58244 .5053 Mdot
.59607 .6617 Mdot
.47234 .29262 Mdot
.60701 .66693 Mdot
.70571 .49773 Mdot
.57711 .36754 Mdot
.43698 .67816 Mdot
.65562 .32322 Mdot
.58907 .5811 Mdot
.42273 .27782 Mdot
.69084 .51055 Mdot
.5672 .26357 Mdot
.63541 .31828 Mdot
.38669 .34124 Mdot
.65338 .35074 Mdot
.70418 .44705 Mdot
.65395 .66344 Mdot
.41616 .45478 Mdot
.43948 .63539 Mdot
.40644 .67784 Mdot
.43414 .38336 Mdot
.59687 .78877 Mdot
.65728 .65992 Mdot
.62955 .38658 Mdot
.37269 .41296 Mdot
.43916 .41644 Mdot
.42875 .68037 Mdot
.68288 .47177 Mdot
.52961 .5209 Mdot
.64467 .31396 Mdot
.42359 .41083 Mdot
.36609 .37323 Mdot
.51042 .37446 Mdot
.64578 .64258 Mdot
.49061 .58768 Mdot
.39104 .40255 Mdot
.51185 .40664 Mdot
.40796 .37243 Mdot
.39267 .35486 Mdot
.70981 .5111 Mdot
.46199 .39743 Mdot
.42275 .43173 Mdot
.40392 .71585 Mdot
.61485 .67495 Mdot
.41678 .65834 Mdot
.37178 .64638 Mdot
.5069 .57337 Mdot
.62707 .67388 Mdot
.43052 .40558 Mdot
.63324 .63231 Mdot
.37392 .3775 Mdot
.38286 .43934 Mdot
.62165 .64082 Mdot
.43613 .64181 Mdot
.54643 .65961 Mdot
.33493 .63997 Mdot
.38041 .38196 Mdot
.4073 .43812 Mdot
.65514 .36443 Mdot
.63366 .22057 Mdot
.41812 .44232 Mdot
.43731 .66755 Mdot
.41329 .4322 Mdot
.64379 .68124 Mdot
.6673 .33571 Mdot
.41289 .65048 Mdot
.67074 .4831 Mdot
.6927 .50845 Mdot
.64636 .48052 Mdot
.48684 .59765 Mdot
.35521 .44018 Mdot
.45665 .62026 Mdot
.46221 .63134 Mdot
.48564 .30982 Mdot
.69591 .48027 Mdot
.66964 .33096 Mdot
.378 .3968 Mdot
.35633 .34875 Mdot
.60028 .6401 Mdot
.90269 .56587 Mdot
.50715 .44837 Mdot
.63121 .31382 Mdot
.58566 .40057 Mdot
.50243 .57704 Mdot
.36613 .41496 Mdot
.67789 .30567 Mdot
.70774 .50291 Mdot
.37446 .37591 Mdot
.36156 .46621 Mdot
.66101 .56517 Mdot
.70548 .45792 Mdot
.6232 .63017 Mdot
.67099 .49634 Mdot
.63254 .32681 Mdot
.48884 .59652 Mdot
.3929 .66473 Mdot
.38223 .41783 Mdot
.44091 .47056 Mdot
.68435 .48095 Mdot
.51264 .5915 Mdot
.38041 .45477 Mdot
.39145 .65321 Mdot
.69422 .47406 Mdot
.39404 .43133 Mdot
.24272 .60795 Mdot
.35231 .64562 Mdot
.67631 .48252 Mdot
.4156 .40099 Mdot
.30871 .36925 Mdot
.71029 .46079 Mdot
.7073 .44946 Mdot
.37455 .37274 Mdot
.66893 .30107 Mdot
.4223 .42494 Mdot
.64731 .67158 Mdot
.52093 .3494 Mdot
.62111 .66682 Mdot
.49473 .26184 Mdot
.38298 .36292 Mdot
.39976 .50539 Mdot
.3912 .69868 Mdot
.69248 .3153 Mdot
.30144 .27713 Mdot
.4418 .4215 Mdot
.37142 .73543 Mdot
.52056 .34192 Mdot
.51638 .46108 Mdot
.37848 .73842 Mdot
.6519 .30845 Mdot
.64723 .65778 Mdot
.39087 .45559 Mdot
.56448 .63619 Mdot
.65909 .30643 Mdot
.49276 .2612 Mdot
.40938 .3892 Mdot
.40537 .65956 Mdot
.37209 .41748 Mdot
.39416 .66129 Mdot
.41142 .42274 Mdot
.35641 .72357 Mdot
.68803 .27094 Mdot
.40253 .25893 Mdot
.3867 .34156 Mdot
.6561 .59407 Mdot
.33219 .60511 Mdot
.66809 .32705 Mdot
.36801 .38877 Mdot
.4926 .58145 Mdot
.64995 .65079 Mdot
.63281 .57658 Mdot
.71351 .47308 Mdot
.60569 .67242 Mdot
.43387 .64855 Mdot
.70896 .44616 Mdot
.51404 .58423 Mdot
.48111 .4025 Mdot
.67283 .30344 Mdot
.6292 .67528 Mdot
.38524 .4142 Mdot
.43184 .38568 Mdot
.69093 .57747 Mdot
.45574 .17367 Mdot
.41789 .69139 Mdot
.66326 .80934 Mdot
.44423 .61566 Mdot
.64361 .33278 Mdot
.71328 .50829 Mdot
.39938 .43534 Mdot
.40556 .40633 Mdot
.70319 .45783 Mdot
.3841 .65722 Mdot
.66415 .35688 Mdot
.61904 .23058 Mdot
.66824 .65682 Mdot
.46544 .19517 Mdot
.41025 .64834 Mdot
.46682 .19548 Mdot
.62658 .30294 Mdot
.41251 .59373 Mdot
.37167 .24753 Mdot
.6355 .64835 Mdot
.46477 .19428 Mdot
.40291 .66189 Mdot
.36788 .43253 Mdot
.50368 .58316 Mdot
.50293 .59804 Mdot
.4155 .63739 Mdot
.71827 .49102 Mdot
.64003 .31441 Mdot
.3739 .41518 Mdot
.47654 .43452 Mdot
.26049 .40647 Mdot
.67754 .46177 Mdot
.44645 .3621 Mdot
.62507 .64684 Mdot
.41154 .43246 Mdot
.68196 .32398 Mdot
.63714 .65056 Mdot
.49897 .57045 Mdot
.42825 .27944 Mdot
.41175 .40074 Mdot
.54221 .4999 Mdot
.64044 .66762 Mdot
.62719 .21808 Mdot
.41049 .44665 Mdot
.61403 .67533 Mdot
.44346 .46807 Mdot
.68369 .71295 Mdot
.54913 .52616 Mdot
.59526 .75744 Mdot
.6564 .4687 Mdot
.67339 .5011 Mdot
.58165 .1497 Mdot
.71733 .30756 Mdot
.59892 .65424 Mdot
.47768 .59427 Mdot
.46534 .17847 Mdot
.61211 .66849 Mdot
.42848 .42718 Mdot
.37589 .44473 Mdot
.34678 .59741 Mdot
.34195 .3564 Mdot
.48685 .60384 Mdot
.41648 .52963 Mdot
.35798 .41452 Mdot
.43443 .35012 Mdot
.39549 .45264 Mdot
.39741 .63161 Mdot
.6294 .6483 Mdot
.17091 .61475 Mdot
.64591 .63772 Mdot
.39465 .50195 Mdot
.67826 .48245 Mdot
.66227 .45504 Mdot
.38712 .41754 Mdot
.335 .47706 Mdot
.34299 .80983 Mdot
.37918 .44939 Mdot
.55103 .50291 Mdot
.50782 .27132 Mdot
.34071 .38795 Mdot
.44435 .63457 Mdot
.45126 .46029 Mdot
.46077 .6199 Mdot
.64008 .65062 Mdot
.65374 .30771 Mdot
.69316 .29727 Mdot
.64735 .66084 Mdot
.40482 .40732 Mdot
.69106 .30092 Mdot
.38485 .42576 Mdot
.37071 .4083 Mdot
.50925 .39713 Mdot
.67336 .33762 Mdot
.7196 .47835 Mdot
.65345 .32997 Mdot
.42409 .62802 Mdot
.75576 .75244 Mdot
.66324 .33134 Mdot
.34658 .59503 Mdot
.52417 .32878 Mdot
.47457 .18757 Mdot
.40533 .67907 Mdot
.64986 .34814 Mdot
.64464 .65011 Mdot
.49483 .47589 Mdot
.32622 .59256 Mdot
.61569 .68468 Mdot
.38959 .40491 Mdot
.42957 .68629 Mdot
.44215 .61754 Mdot
.62635 .69319 Mdot
.39243 .67008 Mdot
.33928 .43061 Mdot
.39005 .38958 Mdot
.59903 .6656 Mdot
.22045 .35908 Mdot
.65802 .66636 Mdot
.3279 .67668 Mdot
.35267 .41892 Mdot
.41257 .65277 Mdot
.33945 .59344 Mdot
.36454 .6717 Mdot
.50173 .59654 Mdot
.41667 .44885 Mdot
.66581 .33266 Mdot
.49103 .30483 Mdot
.67569 .47876 Mdot
.47582 .80409 Mdot
.40734 .67503 Mdot
.64569 .69539 Mdot
.39195 .66765 Mdot
.39894 .68123 Mdot
.59358 .64358 Mdot
.40057 .64581 Mdot
.41795 .41644 Mdot
.38331 .76378 Mdot
.41289 .68185 Mdot
.63574 .661 Mdot
.65365 .34519 Mdot
.43576 .66998 Mdot
.61687 .38008 Mdot
.38363 .39697 Mdot
.66104 .48704 Mdot
.694 .3391 Mdot
.39361 .69085 Mdot
.66904 .32723 Mdot
.68834 .47904 Mdot
.6498 .30456 Mdot
.56304 .64909 Mdot
.61143 .60483 Mdot
.31761 .32205 Mdot
.68805 .70562 Mdot
.41229 .62801 Mdot
.68822 .43803 Mdot
.4171 .40667 Mdot
.37183 .41156 Mdot
.68332 .29109 Mdot
.41945 .61896 Mdot
.6113 .78494 Mdot
.40486 .5173 Mdot
.57864 .79418 Mdot
.65109 .64783 Mdot
.607 .3615 Mdot
.50583 .45418 Mdot
.60482 .69873 Mdot
.34564 .39153 Mdot
.50222 .57762 Mdot
.39167 .425 Mdot
.5375 .28435 Mdot
.63367 .32399 Mdot
.73095 .58297 Mdot
.41724 .37172 Mdot
.69941 .4579 Mdot
.4089 .42519 Mdot
.56525 .58293 Mdot
.3987 .35988 Mdot
.66622 .29467 Mdot
.66801 .66444 Mdot
.44056 .66292 Mdot
.64126 .34463 Mdot
.69617 .50896 Mdot
.34978 .27235 Mdot
.42755 .42293 Mdot
.35919 .4184 Mdot
.71766 .46531 Mdot
.43773 .63656 Mdot
.70799 .49367 Mdot
.61325 .67548 Mdot
.66165 .32961 Mdot
.42176 .38404 Mdot
.44217 .35776 Mdot
.70661 .5253 Mdot
.61475 .63615 Mdot
.72798 .486 Mdot
.63073 .63196 Mdot
.5051 .57979 Mdot
.38277 .35673 Mdot
.73041 .48513 Mdot
.34665 .3925 Mdot
.32151 .52984 Mdot
.43583 .28777 Mdot
.27386 .39731 Mdot
.72212 .4831 Mdot
.71699 .27886 Mdot
.63899 .65532 Mdot
.6279 .67753 Mdot
.32884 .68954 Mdot
.38444 .82507 Mdot
.52888 .51128 Mdot
.65144 .78036 Mdot
.61359 .67601 Mdot
.63678 .67001 Mdot
.71315 .49091 Mdot
.42666 .63119 Mdot
.3843 .69001 Mdot
.7276 .47066 Mdot
.45816 .26609 Mdot
.4075 .66678 Mdot
.28242 .6932 Mdot
.6685 .46756 Mdot
.37061 .45984 Mdot
.37483 .61031 Mdot
.66464 .2953 Mdot
.51795 .28347 Mdot
.67559 .60616 Mdot
.39926 .42697 Mdot
.82918 .53987 Mdot
.71259 .47476 Mdot
.45288 .5306 Mdot
.67504 .65622 Mdot
.43343 .39556 Mdot
.40704 .42009 Mdot
.41778 .4255 Mdot
.6556 .29533 Mdot
.28901 .47608 Mdot
.39929 .43098 Mdot
.41379 .26785 Mdot
.43917 .44767 Mdot
.69416 .5982 Mdot
.65376 .33012 Mdot
.57199 .24124 Mdot
.72416 .45126 Mdot
.60817 .7755 Mdot
.43682 .44051 Mdot
.62882 .68166 Mdot
.56909 .5564 Mdot
.61595 .64066 Mdot
.59986 .70519 Mdot
.44211 .19481 Mdot
.41326 .62196 Mdot
.42051 .37573 Mdot
.67528 .45792 Mdot
.39667 .70078 Mdot
.56745 .54948 Mdot
.74673 .76055 Mdot
.65506 .69034 Mdot
.59204 .87546 Mdot
.61746 .66853 Mdot
.49358 .60291 Mdot
.43193 .6469 Mdot
.29757 .42238 Mdot
.51465 .3667 Mdot
.43671 .6392 Mdot
.75867 .37932 Mdot
.4609 .61462 Mdot
.41398 .23408 Mdot
.44912 .6844 Mdot
.63113 .65776 Mdot
.63213 .69508 Mdot
.37113 .47407 Mdot
.42359 .42265 Mdot
.52194 .36391 Mdot
.31598 .38609 Mdot
.40864 .39941 Mdot
.68863 .49385 Mdot
.69023 .70337 Mdot
.56541 .63788 Mdot
.40687 .64329 Mdot
.60525 .63882 Mdot
.40788 .42318 Mdot
.37946 .38247 Mdot
.41605 .45868 Mdot
.61432 .28137 Mdot
.27676 .68889 Mdot
.38113 .44053 Mdot
.4031 .35847 Mdot
.69727 .51157 Mdot
.69365 .57707 Mdot
.69961 .76337 Mdot
.45062 .18925 Mdot
.37254 .45189 Mdot
.64576 .32971 Mdot
.68227 .32646 Mdot
.34495 .44826 Mdot
.305 .43341 Mdot
.63314 .37337 Mdot
.38549 .41387 Mdot
.37392 .26472 Mdot
.67536 .52018 Mdot
.51318 .57655 Mdot
.68497 .48111 Mdot
.38644 .69661 Mdot
.51012 .58102 Mdot
.69222 .5021 Mdot
.43145 .27194 Mdot
.49639 .57454 Mdot
.68111 .71859 Mdot
.65279 .34794 Mdot
.40231 .45114 Mdot
.35735 .60499 Mdot
.67227 .47368 Mdot
.63662 .67337 Mdot
.4276 .65342 Mdot
.65383 .65374 Mdot
.69724 .63646 Mdot
.47482 .26742 Mdot
.49517 .59636 Mdot
.63014 .68194 Mdot
.53821 .49954 Mdot
.64769 .33193 Mdot
.6128 .66261 Mdot
.39274 .50676 Mdot
.44727 .4018 Mdot
.29954 .75887 Mdot
.36253 .40714 Mdot
.62486 .72387 Mdot
.6339 .67769 Mdot
.50859 .5698 Mdot
.38101 .41918 Mdot
.66448 .4651 Mdot
.47534 .38282 Mdot
.38484 .42746 Mdot
.66834 .48682 Mdot
.37397 .43874 Mdot
.67938 .32306 Mdot
.4376 .61366 Mdot
.51902 .33601 Mdot
.58178 .33127 Mdot
.63578 .32165 Mdot
.465 .31518 Mdot
.41804 .44311 Mdot
.72529 .35465 Mdot
.40801 .6608 Mdot
.44145 .41781 Mdot
.49949 .25318 Mdot
.41873 .63202 Mdot
.42555 .66403 Mdot
.3612 .39929 Mdot
.65614 .67388 Mdot
.72062 .47507 Mdot
.64946 .33159 Mdot
.57931 .65811 Mdot
.39523 .43284 Mdot
.37763 .37337 Mdot
.63438 .32719 Mdot
.63033 .67304 Mdot
.42485 .38951 Mdot
.51008 .76791 Mdot
.46544 .29348 Mdot
.61211 .63343 Mdot
.44611 .39863 Mdot
.29831 .72046 Mdot
.3877 .67191 Mdot
.83012 .53629 Mdot
.68966 .27342 Mdot
.71502 .50275 Mdot
.45887 .38121 Mdot
.87669 .61136 Mdot
.65663 .34607 Mdot
.57429 .78907 Mdot
.36934 .43204 Mdot
.39975 .43968 Mdot
.40364 .62892 Mdot
.41999 .38985 Mdot
.39508 .64975 Mdot
.59761 .3472 Mdot
.40412 .83386 Mdot
.39956 .67629 Mdot
.3971 .66005 Mdot
.31942 .43534 Mdot
.66755 .26097 Mdot
.42323 .63709 Mdot
.4268 .42025 Mdot
.74978 .35308 Mdot
.3267 .4271 Mdot
.64162 .35442 Mdot
.63092 .3677 Mdot
.44733 .64453 Mdot
.31807 .60801 Mdot
.32352 .44243 Mdot
.28411 .66508 Mdot
.64589 .38252 Mdot
.60092 .65793 Mdot
.36183 .3835 Mdot
.47828 .59577 Mdot
.7001 .47629 Mdot
.45972 .44617 Mdot
.40941 .44672 Mdot
.43686 .62933 Mdot
.63441 .3122 Mdot
.60987 .66342 Mdot
.3487 .39997 Mdot
.68389 .52722 Mdot
.64035 .31916 Mdot
.42094 .682 Mdot
.32318 .64309 Mdot
.69022 .29874 Mdot
.4509 .36514 Mdot
.3661 .43273 Mdot
.35172 .42816 Mdot
.37749 .34252 Mdot
.64617 .6615 Mdot
.71594 .45385 Mdot
.45295 .36843 Mdot
.50601 .43409 Mdot
.46716 .28557 Mdot
.40226 .46409 Mdot
.43681 .66853 Mdot
.64132 .64207 Mdot
.48737 .59367 Mdot
.47164 .18253 Mdot
.36247 .43562 Mdot
.2826 .69453 Mdot
.60142 .26609 Mdot
.4885 .58221 Mdot
.40407 .70141 Mdot
.65204 .32608 Mdot
.35411 .40815 Mdot
.41194 .26529 Mdot
.41017 .39739 Mdot
.34355 .37548 Mdot
.72008 .49353 Mdot
.60525 .65477 Mdot
.32799 .31654 Mdot
.70329 .47875 Mdot
.42555 .66292 Mdot
.25343 .65925 Mdot
.38787 .6905 Mdot
.4022 .69364 Mdot
.44793 .57728 Mdot
.65167 .67135 Mdot
.88298 .60168 Mdot
.651 .22749 Mdot
.40178 .46077 Mdot
.62377 .6851 Mdot
.42419 .64157 Mdot
.42982 .41237 Mdot
.3972 .64754 Mdot
.44772 .63728 Mdot
.38503 .39399 Mdot
.39163 .39353 Mdot
.39826 .25896 Mdot
.29492 .70147 Mdot
.66121 .33919 Mdot
.38544 .65268 Mdot
.29897 .67132 Mdot
.39723 .43715 Mdot
.42006 .43402 Mdot
.57034 .55949 Mdot
.64036 .34616 Mdot
.20438 .52384 Mdot
.36981 .41792 Mdot
.54824 .27404 Mdot
.42566 .43311 Mdot
.37562 .68723 Mdot
.60039 .67981 Mdot
.39212 .5035 Mdot
.7258 .4916 Mdot
.38321 .65883 Mdot
.64246 .30576 Mdot
.41356 .70234 Mdot
.22347 .5566 Mdot
.65001 .65705 Mdot
.3984 .66494 Mdot
.7021 .44288 Mdot
.62655 .66776 Mdot
.65697 .66824 Mdot
.56718 .54633 Mdot
.68556 .44292 Mdot
.62989 .31675 Mdot
.61737 .64811 Mdot
.24663 .61211 Mdot
.62883 .65953 Mdot
.21823 .55777 Mdot
.36899 .4535 Mdot
.41603 .26868 Mdot
.46338 .4376 Mdot
.36515 .47051 Mdot
.61909 .65632 Mdot
.63809 .32014 Mdot
.42871 .39596 Mdot
.40112 .68101 Mdot
.64936 .34157 Mdot
.40288 .57487 Mdot
.68082 .44174 Mdot
.45348 .62216 Mdot
.63879 .63226 Mdot
.39866 .63621 Mdot
.51001 .27505 Mdot
.62857 .36145 Mdot
.58527 .55187 Mdot
.51117 .35752 Mdot
.4102 .34009 Mdot
.41867 .36945 Mdot
.43096 .39849 Mdot
.41573 .41489 Mdot
.67712 .48392 Mdot
.67007 .28885 Mdot
.43467 .67303 Mdot
.2496 .38055 Mdot
.64026 .67554 Mdot
.55079 .50963 Mdot
.38133 .34193 Mdot
.37598 .37643 Mdot
.42362 .64419 Mdot
.45038 .64419 Mdot
.30545 .48607 Mdot
.70889 .46226 Mdot
.34015 .45114 Mdot
.4329 .44281 Mdot
.35305 .30632 Mdot
.61938 .65944 Mdot
.56698 .74942 Mdot
.66474 .50831 Mdot
.60385 .87495 Mdot
.70225 .48032 Mdot
.60017 .47396 Mdot
.4009 .64249 Mdot
.66685 .31757 Mdot
.39385 .40138 Mdot
.42024 .53691 Mdot
.43185 .68654 Mdot
.67588 .55412 Mdot
.65739 .32102 Mdot
.58181 .70679 Mdot
.61556 .68122 Mdot
.34813 .39934 Mdot
.42638 .4318 Mdot
.39843 .37963 Mdot
.42267 .40068 Mdot
.59678 .65483 Mdot
.40165 .39229 Mdot
.59631 .63449 Mdot
.22319 .54539 Mdot
.49264 .24926 Mdot
.69751 .448 Mdot
.71497 .57073 Mdot
.4031 .69221 Mdot
.20739 .58593 Mdot
.21275 .5248 Mdot
.4367 .28784 Mdot
.5695 .66716 Mdot
.3531 .37752 Mdot
.71752 .48793 Mdot
.57674 .62163 Mdot
.69233 .44808 Mdot
.20275 .67222 Mdot
.34373 .6007 Mdot
.61133 .72318 Mdot
.40509 .38289 Mdot
.72522 .47263 Mdot
.31101 .62876 Mdot
.46312 .37807 Mdot
.69125 .30459 Mdot
.22995 .57959 Mdot
.40604 .55564 Mdot
.66659 .33788 Mdot
.37697 .40029 Mdot
.46095 .64011 Mdot
.39866 .40312 Mdot
.3891 .39977 Mdot
.37453 .44844 Mdot
.58913 .65667 Mdot
.37655 .4593 Mdot
.42116 .42026 Mdot
.48166 .1555 Mdot
.73632 .52526 Mdot
.67277 .50235 Mdot
.27789 .4106 Mdot
.65096 .33859 Mdot
.38687 .69731 Mdot
.51736 .34241 Mdot
.63981 .67934 Mdot
.30188 .4817 Mdot
.37394 .39035 Mdot
.52853 .79947 Mdot
.66189 .65655 Mdot
.66269 .30065 Mdot
.47986 .59295 Mdot
.57598 .71959 Mdot
.71104 .51407 Mdot
.48214 .60146 Mdot
.67586 .47503 Mdot
.27507 .34393 Mdot
.39519 .65468 Mdot
.4107 .3402 Mdot
.60946 .65779 Mdot
.68414 .44792 Mdot
.4086 .26742 Mdot
.41413 .43578 Mdot
.72256 .48374 Mdot
.46501 .39683 Mdot
.49508 .30451 Mdot
.52032 .34511 Mdot
.70184 .4448 Mdot
.66627 .66412 Mdot
.62203 .66359 Mdot
.66395 .34257 Mdot
.3891 .67125 Mdot
.43689 .63314 Mdot
.62505 .65855 Mdot
.7936 .64792 Mdot
.39561 .43073 Mdot
.38791 .44476 Mdot
.50466 .44636 Mdot
.43344 .42165 Mdot
.6476 .36505 Mdot
.48986 .60533 Mdot
.44313 .64288 Mdot
.4305 .3988 Mdot
.42397 .38848 Mdot
.36312 .42579 Mdot
.44828 .26157 Mdot
.68333 .47879 Mdot
.35728 .41498 Mdot
.67542 .30408 Mdot
.40406 .56838 Mdot
.41899 .40931 Mdot
.45086 .36372 Mdot
.39531 .64672 Mdot
.62719 .50706 Mdot
.63896 .67322 Mdot
.68113 .45907 Mdot
.67738 .45788 Mdot
.50604 .22505 Mdot
.37975 .66911 Mdot
.48462 .60369 Mdot
.67475 .58673 Mdot
.48545 .59595 Mdot
.65855 .31859 Mdot
.54201 .52447 Mdot
.68162 .43136 Mdot
.67193 .50021 Mdot
.63425 .69827 Mdot
.43959 .39923 Mdot
.42149 .41178 Mdot
.60173 .78043 Mdot
.38198 .44895 Mdot
.66536 .33507 Mdot
.64141 .68524 Mdot
.39917 .66171 Mdot
.68276 .3156 Mdot
.62301 .67608 Mdot
.43819 .63949 Mdot
.43107 .46024 Mdot
.42869 .4231 Mdot
.42845 .65797 Mdot
.41616 .68402 Mdot
.39532 .4156 Mdot
.42108 .19946 Mdot
.44403 .65197 Mdot
.43 .65149 Mdot
.40563 .56399 Mdot
.70196 .51548 Mdot
.47405 .37481 Mdot
.63994 .6819 Mdot
.42052 .42241 Mdot
.70315 .45003 Mdot
.65212 .31492 Mdot
.42218 .6744 Mdot
.35857 .38418 Mdot
.39008 .43602 Mdot
.64654 .32885 Mdot
.66309 .34999 Mdot
.64234 .34318 Mdot
.62203 .69106 Mdot
.3833 .39079 Mdot
.42875 .64061 Mdot
.61014 .67822 Mdot
.68508 .29986 Mdot
.64765 .35197 Mdot
.3778 .23707 Mdot
.39793 .42426 Mdot
.68322 .32868 Mdot
.77474 .73796 Mdot
.37735 .25264 Mdot
.51258 .5852 Mdot
.65223 .49435 Mdot
.71742 .27349 Mdot
.69604 .33543 Mdot
.60355 .65148 Mdot
.55604 .50797 Mdot
.62962 .33149 Mdot
.35012 .40591 Mdot
.40345 .44565 Mdot
.40361 .34321 Mdot
.64699 .33977 Mdot
.47503 .26606 Mdot
.40747 .62308 Mdot
.23756 .47573 Mdot
.65127 .33861 Mdot
.68568 .44535 Mdot
.70361 .52713 Mdot
.70758 .48521 Mdot
.37893 .35807 Mdot
.26481 .35058 Mdot
.25248 .5912 Mdot
.20319 .51288 Mdot
.61768 .68121 Mdot
.44976 .64077 Mdot
.3912 .59458 Mdot
.42532 .66518 Mdot
.69624 .46887 Mdot
.64079 .31714 Mdot
.40808 .62572 Mdot
.65666 .66628 Mdot
.62105 .66034 Mdot
.72713 .49772 Mdot
.69074 .48094 Mdot
.69913 .4928 Mdot
.38463 .66301 Mdot
.40061 .64396 Mdot
.41201 .37995 Mdot
.41726 .67863 Mdot
.62549 .25826 Mdot
.60417 .31146 Mdot
.72413 .51103 Mdot
.64176 .66172 Mdot
.43403 .663 Mdot
.40119 .45242 Mdot
.56854 .47191 Mdot
.7286 .45285 Mdot
.67075 .29515 Mdot
.41335 .79144 Mdot
.38276 .83275 Mdot
.41459 .37255 Mdot
.60934 .6388 Mdot
.35946 .49276 Mdot
.41453 .41769 Mdot
.7213 .49676 Mdot
.60249 .24372 Mdot
.49013 .5776 Mdot
.40752 .40334 Mdot
.42535 .46297 Mdot
.65108 .65433 Mdot
.51581 .34295 Mdot
.35008 .39968 Mdot
.56964 .52438 Mdot
.66549 .66914 Mdot
.66844 .51192 Mdot
.62136 .16609 Mdot
.44429 .53729 Mdot
.5445 .30086 Mdot
.51046 .57683 Mdot
.36442 .44256 Mdot
.68567 .49284 Mdot
.67898 .30056 Mdot
.6898 .48862 Mdot
.38992 .70303 Mdot
.70942 .51388 Mdot
.38423 .45251 Mdot
.42651 .63725 Mdot
.62865 .6745 Mdot
.53454 .46701 Mdot
.27692 .36215 Mdot
.66314 .46903 Mdot
.51377 .591 Mdot
.39242 .39412 Mdot
.24132 .61335 Mdot
.36989 .47445 Mdot
.42314 .42967 Mdot
.61937 .64072 Mdot
.4146 .64211 Mdot
.64895 .64619 Mdot
.47614 .3967 Mdot
.38574 .73041 Mdot
.64394 .67198 Mdot
.43646 .52157 Mdot
.63477 .31976 Mdot
.46715 .26749 Mdot
.37814 .41533 Mdot
.60825 .65856 Mdot
.37262 .397 Mdot
.38556 .64997 Mdot
.44793 .28067 Mdot
.45862 .29611 Mdot
.62762 .64605 Mdot
.54322 .61135 Mdot
.51829 .31679 Mdot
.47361 .37289 Mdot
.60926 .67073 Mdot
.29524 .28863 Mdot
.48915 .58533 Mdot
.64416 .31614 Mdot
.66074 .35291 Mdot
.67002 .31012 Mdot
.3909 .44766 Mdot
.30411 .69239 Mdot
.66535 .3439 Mdot
.65727 .6836 Mdot
.67642 .32441 Mdot
.5851 .30858 Mdot
.60033 .78779 Mdot
.63582 .31933 Mdot
.37579 .4228 Mdot
.40448 .49615 Mdot
.55258 .50561 Mdot
.65892 .4665 Mdot
.53072 .69076 Mdot
.48938 .15313 Mdot
.40015 .43438 Mdot
.35737 .72626 Mdot
.36948 .69707 Mdot
.61013 .44188 Mdot
.45066 .29526 Mdot
.52513 .48676 Mdot
.43328 .65762 Mdot
.51392 .34995 Mdot
.43311 .68199 Mdot
.40681 .33832 Mdot
.38173 .43901 Mdot
.38262 .65953 Mdot
.46383 .80139 Mdot
.28463 .28607 Mdot
.56319 .80004 Mdot
.43977 .65247 Mdot
.61494 .67491 Mdot
.61526 .63922 Mdot
.61787 .64156 Mdot
.67762 .49204 Mdot
.39677 .66655 Mdot
.35766 .42768 Mdot
.70332 .50835 Mdot
.38009 .40393 Mdot
.62865 .65121 Mdot
.44315 .28994 Mdot
.39787 .65919 Mdot
.38466 .41305 Mdot
.30432 .64939 Mdot
.67891 .47126 Mdot
.64644 .33278 Mdot
.39957 .77979 Mdot
.65105 .46807 Mdot
.66045 .65071 Mdot
.39253 .70663 Mdot
.6927 .53679 Mdot
.58472 .50087 Mdot
.39338 .46303 Mdot
.41442 .45515 Mdot
.56166 .50656 Mdot
.33321 .61618 Mdot
.3526 .38501 Mdot
.69439 .50877 Mdot
.68622 .5127 Mdot
.36999 .40033 Mdot
.3984 .67185 Mdot
.62704 .3393 Mdot
.6878 .29201 Mdot
.35932 .35792 Mdot
.51734 .3584 Mdot
.41454 .26839 Mdot
.42912 .4019 Mdot
.43618 .35933 Mdot
.69815 .44105 Mdot
.51374 .58208 Mdot
.51069 .37091 Mdot
.67154 .31908 Mdot
.36759 .42641 Mdot
.26343 .41059 Mdot
.40739 .67389 Mdot
.72226 .48056 Mdot
.59728 .66738 Mdot
.69059 .30047 Mdot
.71827 .51494 Mdot
.36994 .40043 Mdot
.4246 .38936 Mdot
.61141 .65991 Mdot
.37546 .68528 Mdot
.63875 .33171 Mdot
.70235 .50924 Mdot
.66853 .31938 Mdot
.40022 .64813 Mdot
.42923 .67197 Mdot
.42001 .45739 Mdot
.35673 .46695 Mdot
.66595 .46855 Mdot
.35233 .37052 Mdot
.70728 .50023 Mdot
.69122 .57771 Mdot
.59973 .64057 Mdot
.44001 .4232 Mdot
.37716 .67136 Mdot
.6262 .65336 Mdot
.40369 .43012 Mdot
.56731 .50839 Mdot
.40879 .37427 Mdot
.72317 .46538 Mdot
.60664 .22639 Mdot
.65918 .30959 Mdot
.42545 .47452 Mdot
.3767 .53029 Mdot
.43319 .41683 Mdot
.66574 .49869 Mdot
.2458 .59926 Mdot
.64761 .66788 Mdot
.40611 .63677 Mdot
.64953 .44569 Mdot
.63328 .66074 Mdot
.3725 .42649 Mdot
.66258 .3321 Mdot
.43676 .67417 Mdot
.50682 .58801 Mdot
.52317 .38433 Mdot
.43454 .48277 Mdot
.32897 .42394 Mdot
.34984 .39065 Mdot
.64786 .78403 Mdot
.69621 .49154 Mdot
.42501 .64349 Mdot
.60612 .64127 Mdot
.65156 .66189 Mdot
.68298 .47134 Mdot
.4111 .5533 Mdot
.50928 .8149 Mdot
.81203 .70056 Mdot
.7178 .51677 Mdot
.67558 .31444 Mdot
.44776 .28185 Mdot
.70912 .48488 Mdot
.67377 .48285 Mdot
.70042 .43921 Mdot
.60872 .77923 Mdot
.43809 .64842 Mdot
.39051 .43718 Mdot
.34575 .67802 Mdot
.37432 .44714 Mdot
.54339 .31268 Mdot
.62995 .65167 Mdot
.40566 .63671 Mdot
.60148 .37169 Mdot
.40405 .36126 Mdot
.40684 .41342 Mdot
.62732 .38742 Mdot
.31942 .44391 Mdot
.46982 .18776 Mdot
.42763 .44293 Mdot
.68349 .48566 Mdot
.38754 .61578 Mdot
.45007 .36496 Mdot
.30396 .65251 Mdot
.62057 .66655 Mdot
.49522 .59743 Mdot
.42854 .34504 Mdot
.40588 .34717 Mdot
.43056 .68361 Mdot
.41115 .62415 Mdot
.65621 .35084 Mdot
.39182 .76481 Mdot
.6222 .66991 Mdot
.58917 .75197 Mdot
.42371 .4297 Mdot
.60486 .70766 Mdot
.61378 .236 Mdot
.40405 .42359 Mdot
.56551 .54248 Mdot
.30584 .4862 Mdot
.36614 .37687 Mdot
.20764 .50118 Mdot
.63811 .6575 Mdot
.51671 .26291 Mdot
.40675 .39027 Mdot
.72141 .48645 Mdot
.42266 .62939 Mdot
.4546 .62262 Mdot
.68124 .30148 Mdot
.64881 .24363 Mdot
.46299 .85595 Mdot
.40518 .63612 Mdot
.41583 .43466 Mdot
.64024 .67052 Mdot
.50253 .59426 Mdot
.45659 .45409 Mdot
.56179 .59598 Mdot
.409 .67328 Mdot
.46099 .37758 Mdot
.5241 .80182 Mdot
.51534 .34651 Mdot
.21401 .61558 Mdot
.61878 .64357 Mdot
.6724 .32622 Mdot
.32991 .3819 Mdot
.68109 .5871 Mdot
.42887 .42508 Mdot
.54315 .30837 Mdot
.38549 .62619 Mdot
.66843 .33293 Mdot
.40636 .40925 Mdot
.35517 .38049 Mdot
.48023 .32831 Mdot
.64441 .35667 Mdot
.35138 .39121 Mdot
.41365 .37076 Mdot
.41768 .62646 Mdot
.49179 .60504 Mdot
.40097 .66354 Mdot
.39729 .40375 Mdot
.58551 .20752 Mdot
.389 .64738 Mdot
.539 .66958 Mdot
.67841 .27589 Mdot
.63831 .68007 Mdot
.46208 .405 Mdot
.37979 .45803 Mdot
.21154 .62752 Mdot
.50206 .59693 Mdot
.7233 .72292 Mdot
.72254 .46778 Mdot
.43733 .16222 Mdot
.65223 .46338 Mdot
.56265 .66808 Mdot
.63598 .56478 Mdot
.44692 .36455 Mdot
.40681 .54889 Mdot
.19798 .51255 Mdot
.65767 .63539 Mdot
.20198 .57574 Mdot
.42356 .42244 Mdot
.36535 .42684 Mdot
.71212 .49847 Mdot
.58129 .69028 Mdot
.39327 .50388 Mdot
.51133 .36975 Mdot
.65879 .30175 Mdot
.4157 .66053 Mdot
.40157 .44848 Mdot
.44623 .79542 Mdot
.67336 .45239 Mdot
.28011 .37803 Mdot
.38213 .41544 Mdot
.34849 .48431 Mdot
.56996 .67363 Mdot
.63029 .67561 Mdot
.70341 .44496 Mdot
.68186 .4453 Mdot
.36729 .44391 Mdot
.59654 .66103 Mdot
.39686 .37653 Mdot
.51181 .3101 Mdot
.46299 .39069 Mdot
.6552 .31739 Mdot
.41305 .44619 Mdot
.33175 .48372 Mdot
.16263 .43208 Mdot
.41987 .37176 Mdot
.39795 .69296 Mdot
.70082 .49592 Mdot
.68686 .47475 Mdot
.43887 .63568 Mdot
.68709 .47398 Mdot
.23832 .4815 Mdot
.30402 .7005 Mdot
.66167 .31862 Mdot
.23153 .53205 Mdot
.65727 .30626 Mdot
.49351 .59765 Mdot
.39749 .42119 Mdot
.78211 .53001 Mdot
.71016 .52042 Mdot
.58494 .29715 Mdot
.6272 .65727 Mdot
.5006 .59884 Mdot
.39149 .39225 Mdot
.65657 .38367 Mdot
.7079 .47482 Mdot
.48263 .53557 Mdot
.37186 .44375 Mdot
.38488 .65814 Mdot
.36971 .3775 Mdot
.31203 .41056 Mdot
.4894 .60442 Mdot
.37059 .36975 Mdot
.62313 .67618 Mdot
.39205 .65519 Mdot
.62114 .72956 Mdot
.67171 .47688 Mdot
.4018 .39877 Mdot
.41679 .43105 Mdot
.44489 .66732 Mdot
.40092 .46025 Mdot
.60136 .66785 Mdot
.91216 .52796 Mdot
.63756 .34002 Mdot
.51339 .58008 Mdot
.49704 .71579 Mdot
.36743 .37058 Mdot
.42728 .38834 Mdot
.50753 .50686 Mdot
.26158 .40509 Mdot
.63248 .68007 Mdot
.33077 .41736 Mdot
.68119 .50866 Mdot
.63778 .32871 Mdot
.65828 .66031 Mdot
.39226 .38945 Mdot
.37527 .44059 Mdot
.66783 .33229 Mdot
.61631 .38445 Mdot
.66653 .35442 Mdot
.60035 .65448 Mdot
.45683 .69384 Mdot
.57013 .47103 Mdot
.3906 .42687 Mdot
.51705 .58991 Mdot
.41718 .64522 Mdot
.60714 .67018 Mdot
.28745 .47947 Mdot
.40462 .3382 Mdot
.62854 .62978 Mdot
.6269 .67382 Mdot
.38953 .46177 Mdot
.38032 .66745 Mdot
.38972 .7077 Mdot
.42058 .64495 Mdot
.49556 .24345 Mdot
.70325 .72731 Mdot
.69624 .49521 Mdot
.63959 .66267 Mdot
.70362 .45199 Mdot
.63069 .33157 Mdot
.47668 .29007 Mdot
.66676 .45702 Mdot
.38217 .64207 Mdot
.68966 .44974 Mdot
.401 .37624 Mdot
.65256 .67591 Mdot
.66746 .47041 Mdot
.42758 .40692 Mdot
.37883 .35179 Mdot
.33994 .35714 Mdot
.62793 .32482 Mdot
.51743 .35094 Mdot
.37414 .41669 Mdot
.48075 .59242 Mdot
.39054 .41488 Mdot
.59953 .66574 Mdot
.53661 .45612 Mdot
.36094 .40727 Mdot
.71041 .5205 Mdot
.70759 .73583 Mdot
.68384 .51444 Mdot
.31658 .35775 Mdot
.38825 .40517 Mdot
.39344 .42722 Mdot
.38833 .39321 Mdot
.40054 .5619 Mdot
.64912 .63812 Mdot
.33352 .39976 Mdot
.72812 .48375 Mdot
.42654 .66694 Mdot
.38974 .63959 Mdot
.51831 .51276 Mdot
.48071 .6006 Mdot
.60618 .6765 Mdot
.3943 .42897 Mdot
.48553 .53618 Mdot
.51665 .42523 Mdot
.53864 .80587 Mdot
.65013 .49965 Mdot
.66799 .49548 Mdot
.3979 .68328 Mdot
.67521 .49802 Mdot
.39577 .39076 Mdot
.4593 .37605 Mdot
.61727 .7286 Mdot
.67666 .6679 Mdot
.63845 .32635 Mdot
.38492 .40281 Mdot
.42883 .25724 Mdot
.69741 .51154 Mdot
.69409 .44114 Mdot
.39642 .37715 Mdot
.36341 .68578 Mdot
.2008 .35821 Mdot
.62502 .68578 Mdot
.25369 .62922 Mdot
.33405 .66646 Mdot
.39436 .29741 Mdot
.64831 .66102 Mdot
.56411 .53626 Mdot
.65716 .47256 Mdot
.58297 .19254 Mdot
.42934 .66357 Mdot
.63895 .32963 Mdot
.42788 .41541 Mdot
.38221 .6411 Mdot
.73146 .50361 Mdot
.44115 .66822 Mdot
.42503 .34429 Mdot
.66176 .66091 Mdot
.69615 .476 Mdot
.63072 .6959 Mdot
.39494 .70126 Mdot
.65804 .30707 Mdot
.54482 .27874 Mdot
.23903 .60512 Mdot
.31161 .49218 Mdot
.35682 .41498 Mdot
.75558 .49373 Mdot
.35682 .42741 Mdot
.43699 .61614 Mdot
.37762 .41615 Mdot
.43363 .37316 Mdot
.65898 .46179 Mdot
.40349 .46406 Mdot
.41876 .43892 Mdot
.30206 .65757 Mdot
.40516 .4186 Mdot
.36776 .40538 Mdot
.41744 .46056 Mdot
.38049 .65575 Mdot
.40974 .46159 Mdot
.3892 .66753 Mdot
.55684 .79412 Mdot
.67346 .47481 Mdot
.63094 .33451 Mdot
.63241 .32772 Mdot
.54941 .30587 Mdot
.43523 .2587 Mdot
.36759 .61757 Mdot
.41165 .66933 Mdot
.61965 .65725 Mdot
.40451 .3773 Mdot
.31117 .26454 Mdot
.57778 .21197 Mdot
.65935 .49344 Mdot
.67095 .46157 Mdot
.42106 .40516 Mdot
.36773 .82502 Mdot
.42637 .44212 Mdot
.50611 .45007 Mdot
.38954 .44744 Mdot
.44005 .42101 Mdot
.71025 .44623 Mdot
.51206 .27671 Mdot
.35736 .41524 Mdot
.43002 .6843 Mdot
.64046 .32545 Mdot
.33677 .47258 Mdot
.57608 .23187 Mdot
.32576 .67002 Mdot
.39351 .51844 Mdot
.36872 .39672 Mdot
.71107 .5064 Mdot
.43993 .66069 Mdot
.50934 .4327 Mdot
.60852 .6756 Mdot
.52548 .36789 Mdot
.21703 .54889 Mdot
.65194 .62966 Mdot
.63989 .32062 Mdot
.73858 .49237 Mdot
.37112 .44916 Mdot
.68411 .49634 Mdot
.34175 .38474 Mdot
.51916 .43051 Mdot
.65978 .31648 Mdot
.45843 .61115 Mdot
.61641 .67577 Mdot
.38883 .63318 Mdot
.27386 .39794 Mdot
.57918 .20958 Mdot
.44398 .15755 Mdot
.70495 .51926 Mdot
.23486 .41373 Mdot
.41585 .6365 Mdot
.36369 .43943 Mdot
.80957 .70257 Mdot
.41165 .64791 Mdot
.38429 .65758 Mdot
.52863 .43156 Mdot
.49673 .26209 Mdot
.34978 .37455 Mdot
.44491 .65182 Mdot
.73804 .49386 Mdot
.6559 .32475 Mdot
.42372 .39897 Mdot
.43208 .34763 Mdot
.40668 .62679 Mdot
.70267 .47045 Mdot
.52622 .29635 Mdot
.6863 .48287 Mdot
.43541 .64371 Mdot
.68521 .46148 Mdot
.55114 .66578 Mdot
.66641 .45864 Mdot
.39925 .45658 Mdot
.39339 .42888 Mdot
.48982 .55961 Mdot
.42921 .672 Mdot
.42769 .38947 Mdot
.37056 .43506 Mdot
.42472 .63893 Mdot
.69079 .42916 Mdot
.2606 .42934 Mdot
.42587 .38381 Mdot
.39346 .43385 Mdot
.63777 .34314 Mdot
.5063 .32196 Mdot
.50092 .47261 Mdot
.42935 .40775 Mdot
.67188 .30956 Mdot
.38538 .6639 Mdot
.39267 .4142 Mdot
.51482 .27757 Mdot
.6779 .52231 Mdot
.39224 .38334 Mdot
.50352 .59011 Mdot
.35774 .43674 Mdot
.20101 .38733 Mdot
.39696 .39508 Mdot
.43335 .64966 Mdot
.42098 .63151 Mdot
.65957 .43622 Mdot
.42528 .66024 Mdot
.51205 .5852 Mdot
.62261 .6626 Mdot
.22955 .62383 Mdot
.51109 .58982 Mdot
.37398 .37108 Mdot
.65632 .23015 Mdot
.43979 .35331 Mdot
.46527 .37953 Mdot
.67226 .26019 Mdot
.50976 .57697 Mdot
.40982 .64151 Mdot
.45732 .79142 Mdot
.34541 .4362 Mdot
.60834 .67847 Mdot
.4474 .36171 Mdot
.39084 .38362 Mdot
.43929 .38049 Mdot
.39327 .72765 Mdot
.61803 .68609 Mdot
.47545 .37639 Mdot
.42362 .39857 Mdot
.26235 .40618 Mdot
.40735 .4459 Mdot
.65864 .29821 Mdot
.40046 .65655 Mdot
.67846 .49874 Mdot
.65382 .32017 Mdot
.34986 .39303 Mdot
.65053 .33983 Mdot
.68833 .49646 Mdot
.61238 .65141 Mdot
.39505 .45718 Mdot
.63956 .3544 Mdot
.64445 .31149 Mdot
.36258 .39163 Mdot
.41245 .63112 Mdot
.3735 .47658 Mdot
.39586 .41477 Mdot
.38357 .39275 Mdot
.43488 .63154 Mdot
.83586 .50533 Mdot
.36385 .42386 Mdot
.56582 .53782 Mdot
.44458 .61518 Mdot
.49654 .6036 Mdot
.68698 .50684 Mdot
.39873 .36782 Mdot
.65297 .66663 Mdot
.6241 .66177 Mdot
.69866 .52357 Mdot
.41302 .62451 Mdot
.6931 .47336 Mdot
.42101 .37168 Mdot
.45358 .36929 Mdot
.42602 .4113 Mdot
.67051 .41926 Mdot
.56836 .70791 Mdot
.4273 .67969 Mdot
.66693 .50187 Mdot
.51983 .36622 Mdot
.64726 .67902 Mdot
.71809 .4493 Mdot
.44861 .67008 Mdot
.43094 .62476 Mdot
.44151 .64342 Mdot
.66917 .30356 Mdot
.69765 .4801 Mdot
.40338 .70629 Mdot
.41699 .70002 Mdot
.38089 .38151 Mdot
.42037 .39255 Mdot
.38714 .67006 Mdot
.64647 .53927 Mdot
.65125 .31223 Mdot
.7102 .50957 Mdot
.18154 .37949 Mdot
.62006 .68486 Mdot
.30301 .65678 Mdot
.43027 .41211 Mdot
.63298 .86921 Mdot
.4266 .44235 Mdot
.41363 .43925 Mdot
.38642 .6966 Mdot
.6628 .35355 Mdot
.65654 .32761 Mdot
.41609 .63572 Mdot
.44559 .6343 Mdot
.67312 .29613 Mdot
.52762 .47684 Mdot
.21382 .36603 Mdot
.51281 .41898 Mdot
.43211 .67569 Mdot
.22719 .59297 Mdot
.63361 .64485 Mdot
.41492 .61431 Mdot
.60367 .60571 Mdot
.67561 .4677 Mdot
.66565 .46379 Mdot
.61396 .65734 Mdot
.36422 .41621 Mdot
.72246 .50076 Mdot
.44408 .43724 Mdot
.5904 .70874 Mdot
.55208 .59936 Mdot
.3746 .21351 Mdot
.39476 .45909 Mdot
.32428 .464 Mdot
.62885 .78674 Mdot
.39444 .37163 Mdot
.33916 .58423 Mdot
.64085 .33535 Mdot
.42533 .61477 Mdot
.64005 .68728 Mdot
.36235 .73535 Mdot
.39184 .42728 Mdot
.43592 .66968 Mdot
.6349 .68563 Mdot
.58506 .71427 Mdot
.56898 .52478 Mdot
.37538 .37863 Mdot
.84884 .6516 Mdot
.43 .68664 Mdot
.67945 .49947 Mdot
.27424 .60982 Mdot
.39342 .62511 Mdot
.58092 .50961 Mdot
.73518 .4996 Mdot
.50255 .37476 Mdot
.44576 .65767 Mdot
.66959 .35197 Mdot
.41047 .66088 Mdot
.68033 .32497 Mdot
.3964 .70607 Mdot
.68808 .46535 Mdot
.39959 .40907 Mdot
.68202 .46919 Mdot
.67453 .29319 Mdot
.70621 .51968 Mdot
.6406 .68711 Mdot
.50712 .57387 Mdot
.62787 .65078 Mdot
.45884 .28375 Mdot
.29251 .49956 Mdot
.60581 .65392 Mdot
.51168 .53778 Mdot
.38181 .45056 Mdot
.37549 .68748 Mdot
.67621 .49471 Mdot
.65442 .46615 Mdot
.51734 .35354 Mdot
.43602 .63982 Mdot
.70059 .46701 Mdot
.23406 .5974 Mdot
.78437 .6632 Mdot
.42711 .3669 Mdot
.70638 .64542 Mdot
.4297 .64283 Mdot
.67023 .4474 Mdot
.50464 .44885 Mdot
.41442 .62074 Mdot
.66693 .46859 Mdot
.60949 .66955 Mdot
.65145 .66847 Mdot
.40642 .45772 Mdot
.64422 .6916 Mdot
.65905 .46994 Mdot
.25812 .39819 Mdot
.39865 .64089 Mdot
.556 .70436 Mdot
.63558 .3266 Mdot
.67574 .48807 Mdot
.36269 .4589 Mdot
.37704 .66562 Mdot
.69478 .45041 Mdot
.43651 .8478 Mdot
.13581 .46873 Mdot
.70264 .46793 Mdot
.40109 .65772 Mdot
.42165 .67346 Mdot
.38973 .36109 Mdot
.5144 .36267 Mdot
.70931 .47426 Mdot
.78132 .52936 Mdot
.40521 .26213 Mdot
.50581 .58016 Mdot
.48484 .15457 Mdot
.35794 .41652 Mdot
.37096 .39447 Mdot
.59917 .6564 Mdot
.40902 .41674 Mdot
.4487 .64211 Mdot
.42762 .44116 Mdot
.64445 .64166 Mdot
.68546 .52163 Mdot
.39413 .42214 Mdot
.63715 .32921 Mdot
.6353 .6401 Mdot
.62013 .63566 Mdot
.68528 .45863 Mdot
.41955 .62483 Mdot
.47865 .82051 Mdot
.68745 .48151 Mdot
.38216 .39062 Mdot
.48788 .58395 Mdot
.40874 .46334 Mdot
.47675 .56827 Mdot
.44747 .61851 Mdot
.67632 .4989 Mdot
.47347 .61238 Mdot
.63756 .66657 Mdot
.6559 .47275 Mdot
.36022 .44209 Mdot
.66285 .48197 Mdot
.58279 .54468 Mdot
.73421 .33543 Mdot
.43824 .68382 Mdot
.58699 .5186 Mdot
.42234 .6213 Mdot
.50787 .58205 Mdot
.49635 .22483 Mdot
.64603 .31476 Mdot
.69161 .51383 Mdot
.54036 .66918 Mdot
.67017 .48032 Mdot
.40605 .42265 Mdot
.37502 .44177 Mdot
.71092 .5 Mdot
.66327 .30622 Mdot
.57759 .33639 Mdot
.67976 .34521 Mdot
.39847 .66723 Mdot
.53772 .4955 Mdot
.1919 .3563 Mdot
.67147 .52267 Mdot
.61698 .66043 Mdot
.40446 .52691 Mdot
.36603 .37451 Mdot
.62641 .68724 Mdot
.60555 .63832 Mdot
.68565 .30638 Mdot
.67277 .48332 Mdot
.46036 .62211 Mdot
.6598 .66538 Mdot
.37459 .6448 Mdot
.52658 .29081 Mdot
.39565 .33855 Mdot
.39108 .30342 Mdot
.35023 .3854 Mdot
.5166 .34686 Mdot
.66152 .65803 Mdot
.3759 .43084 Mdot
.34057 .37274 Mdot
.61392 .67692 Mdot
.68533 .31343 Mdot
.50166 .63503 Mdot
.70141 .46556 Mdot
.72772 .76939 Mdot
.40163 .45513 Mdot
.39612 .41084 Mdot
.61876 .68178 Mdot
.32477 .61814 Mdot
.41658 .68825 Mdot
.41215 .62794 Mdot
.69701 .49152 Mdot
.52257 .44717 Mdot
.39572 .46186 Mdot
.39011 .4553 Mdot
.72265 .48772 Mdot
.48188 .59287 Mdot
.46204 .16187 Mdot
.38858 .43531 Mdot
.64164 .65711 Mdot
.5692 .55608 Mdot
.6647 .66764 Mdot
.44469 .4125 Mdot
.40643 .42929 Mdot
.35434 .43512 Mdot
.36501 .45313 Mdot
.62783 .6472 Mdot
.35082 .38674 Mdot
.33696 .40043 Mdot
.41316 .64297 Mdot
.36338 .40539 Mdot
.40276 .26153 Mdot
.38806 .43149 Mdot
.63907 .33488 Mdot
.50525 .47096 Mdot
.39597 .39627 Mdot
.36508 .40265 Mdot
.40882 .26299 Mdot
.41205 .41236 Mdot
.63372 .68624 Mdot
.42622 .67127 Mdot
.63841 .66786 Mdot
.6175 .66679 Mdot
.68675 .45139 Mdot
.67646 .33595 Mdot
.35983 .36406 Mdot
.67538 .29958 Mdot
.39576 .35975 Mdot
.4765 .39935 Mdot
.49661 .30434 Mdot
.50722 .44766 Mdot
.63027 .32594 Mdot
.38931 .45401 Mdot
.6907 .49335 Mdot
.6726 .49655 Mdot
.55747 .50842 Mdot
.45889 .38658 Mdot
.65453 .683 Mdot
.60793 .65896 Mdot
.60278 .31477 Mdot
.72682 .30815 Mdot
.64859 .30681 Mdot
.57565 .35805 Mdot
.4278 .46363 Mdot
.36942 .40876 Mdot
.46428 .42228 Mdot
.71389 .45855 Mdot
.5094 .57438 Mdot
.7244 .50375 Mdot
.57021 .6726 Mdot
.64472 .64698 Mdot
.39797 .45837 Mdot
.33231 .7981 Mdot
.39238 .662 Mdot
.42594 .67231 Mdot
.64554 .64215 Mdot
.68351 .51376 Mdot
.46416 .39085 Mdot
.67104 .80719 Mdot
.45442 .62607 Mdot
.63517 .34735 Mdot
.40702 .40614 Mdot
.67613 .46877 Mdot
.39327 .65189 Mdot
.63642 .35278 Mdot
.36864 .45414 Mdot
.73654 .49497 Mdot
.37895 .42717 Mdot
.23125 .50955 Mdot
.40583 .64062 Mdot
.48572 .30934 Mdot
.38589 .69045 Mdot
.63087 .64789 Mdot
.63314 .67861 Mdot
.40423 .43009 Mdot
.697 .79482 Mdot
.39092 .61479 Mdot
.60442 .63495 Mdot
.65669 .35159 Mdot
.50007 .5728 Mdot
.6678 .34276 Mdot
.70842 .49924 Mdot
.64073 .31979 Mdot
.69178 .45068 Mdot
.64518 .53957 Mdot
.45327 .66574 Mdot
.6672 .33287 Mdot
.34514 .55931 Mdot
.46117 .37902 Mdot
.6881 .29679 Mdot
.41584 .39809 Mdot
.41115 .36701 Mdot
.71387 .47181 Mdot
.66865 .30058 Mdot
.35865 .38483 Mdot
.49302 .71463 Mdot
.62683 .67721 Mdot
.65033 .68456 Mdot
.44791 .3642 Mdot
.68397 .44124 Mdot
.44148 .67902 Mdot
.52776 .33265 Mdot
.45882 .60687 Mdot
.39326 .45527 Mdot
.38134 .35782 Mdot
.40604 .70031 Mdot
.40234 .69215 Mdot
.4046 .43379 Mdot
.2739 .66521 Mdot
.34981 .41714 Mdot
.64989 .67092 Mdot
.39714 .66666 Mdot
.42201 .67497 Mdot
.66039 .46699 Mdot
.40545 .62861 Mdot
.336 .44369 Mdot
.61485 .62508 Mdot
.33738 .42296 Mdot
.6361 .66359 Mdot
.66455 .53218 Mdot
.70792 .46185 Mdot
.5402 .67455 Mdot
.40231 .63119 Mdot
.43023 .39754 Mdot
.38853 .64417 Mdot
.64483 .34477 Mdot
.42578 .67665 Mdot
.37846 .7005 Mdot
.42514 .42736 Mdot
.35139 .39264 Mdot
.48539 .59255 Mdot
.51418 .35739 Mdot
.40358 .64745 Mdot
.42737 .37861 Mdot
.43541 .42709 Mdot
.37281 .44243 Mdot
.52102 .32016 Mdot
.38129 .65374 Mdot
.32534 .66664 Mdot
.44012 .59525 Mdot
.40163 .6433 Mdot
.1471 .48283 Mdot
.48852 .59597 Mdot
.47634 .59921 Mdot
.66821 .67501 Mdot
.39138 .43635 Mdot
.68868 .47159 Mdot
.37676 .38997 Mdot
.45124 .46051 Mdot
.39758 .39795 Mdot
.66502 .33865 Mdot
.392 .46339 Mdot
.50021 .58235 Mdot
.68214 .48233 Mdot
.4025 .37244 Mdot
.39724 .42762 Mdot
.48145 .59973 Mdot
.38225 .65982 Mdot
.42322 .62282 Mdot
.46051 .60104 Mdot
.68375 .30018 Mdot
.61888 .63972 Mdot
.38244 .38944 Mdot
.69423 .49211 Mdot
.6824 .47298 Mdot
.3841 .64326 Mdot
.72194 .49264 Mdot
.62858 .63883 Mdot
.41188 .43944 Mdot
.62944 .64805 Mdot
.66436 .33951 Mdot
.40009 .65578 Mdot
.39953 .39176 Mdot
.37285 .38448 Mdot
.42067 .63149 Mdot
.34955 .40679 Mdot
.65129 .3484 Mdot
.7088 .4498 Mdot
.4203 .68308 Mdot
.62336 .66381 Mdot
.66276 .46278 Mdot
.41925 .38154 Mdot
.16078 .58169 Mdot
.40981 .41821 Mdot
.38153 .45538 Mdot
.37202 .62829 Mdot
.4346 .44639 Mdot
.67095 .47792 Mdot
.39126 .63829 Mdot
.41841 .37337 Mdot
.41292 .26068 Mdot
.61593 .34365 Mdot
.69848 .53313 Mdot
.41962 .42084 Mdot
.20994 .61342 Mdot
.43439 .41605 Mdot
.53567 .67394 Mdot
.49646 .3046 Mdot
.654 .59189 Mdot
.39068 .30356 Mdot
.60739 .63461 Mdot
.48287 .58978 Mdot
.6894 .45377 Mdot
.30625 .61438 Mdot
.40914 .43144 Mdot
.29589 .4753 Mdot
.3966 .38991 Mdot
.64942 .66215 Mdot
.34753 .58698 Mdot
.71556 .50333 Mdot
.45868 .17301 Mdot
.36058 .42475 Mdot
.43434 .68145 Mdot
.70743 .43862 Mdot
.47864 .59084 Mdot
.35265 .39101 Mdot
.658 .29952 Mdot
.60497 .31756 Mdot
.34708 .45636 Mdot
.63497 .66597 Mdot
.36684 .42552 Mdot
.41579 .47869 Mdot
.82036 .58595 Mdot
.42247 .64403 Mdot
.61381 .66889 Mdot
.72391 .31058 Mdot
.37819 .44389 Mdot
.42984 .62457 Mdot
.42856 .66424 Mdot
.68145 .3064 Mdot
.57931 .65544 Mdot
.60306 .34936 Mdot
.2952 .75188 Mdot
.26455 .36614 Mdot
.71296 .45659 Mdot
.45381 .68599 Mdot
.36923 .39248 Mdot
.58078 .2093 Mdot
.61848 .66419 Mdot
.3961 .40924 Mdot
.32534 .50436 Mdot
.42955 .65063 Mdot
.38136 .43275 Mdot
.64977 .31399 Mdot
.53656 .83273 Mdot
.22497 .56984 Mdot
.21869 .63832 Mdot
.7378 .49454 Mdot
.35069 .37231 Mdot
.33204 .43449 Mdot
.4964 .60387 Mdot
.44181 .38987 Mdot
.67746 .49465 Mdot
.587 .56148 Mdot
.66595 .31289 Mdot
.39103 .65759 Mdot
.47946 .59511 Mdot
.39734 .38978 Mdot
.34215 .3855 Mdot
.65022 .3508 Mdot
.35277 .41837 Mdot
.27515 .6197 Mdot
.51006 .56664 Mdot
.66896 .45565 Mdot
.4389 .67267 Mdot
.36753 .36038 Mdot
.49293 .57691 Mdot
.42518 .42202 Mdot
.31977 .46991 Mdot
.38604 .40396 Mdot
.52577 .65668 Mdot
.4228 .62911 Mdot
.62967 .67027 Mdot
.37242 .46076 Mdot
.38373 .42381 Mdot
.60338 .46537 Mdot
.46504 .39082 Mdot
.38239 .39628 Mdot
.39065 .62959 Mdot
.39116 .66043 Mdot
.42655 .68478 Mdot
.65928 .4793 Mdot
.51189 .40655 Mdot
.63292 .65316 Mdot
.46471 .41744 Mdot
.66003 .66462 Mdot
.40772 .30323 Mdot
.66838 .33946 Mdot
.5403 .688 Mdot
.40829 .44072 Mdot
.4398 .64425 Mdot
.22623 .35125 Mdot
.38152 .65063 Mdot
.64801 .62379 Mdot
.62098 .66812 Mdot
.4101 .65001 Mdot
.41714 .41922 Mdot
.50853 .36421 Mdot
.2269 .65534 Mdot
.6492 .6781 Mdot
.43865 .35424 Mdot
.70423 .53995 Mdot
.67796 .52014 Mdot
.1511 .46515 Mdot
.65725 .66772 Mdot
.62977 .78716 Mdot
.4252 .3826 Mdot
.39193 .64169 Mdot
.61502 .64392 Mdot
.59343 .65426 Mdot
.72221 .49632 Mdot
.37796 .37959 Mdot
.38286 .42597 Mdot
.50191 .59117 Mdot
.61961 .64889 Mdot
.31506 .43068 Mdot
.37258 .3784 Mdot
.59184 .70624 Mdot
.45528 .65117 Mdot
.83704 .49752 Mdot
.43153 .52456 Mdot
.32345 .50316 Mdot
.80329 .52938 Mdot
.41604 .68532 Mdot
.36411 .41397 Mdot
.46393 .39232 Mdot
.71819 .4587 Mdot
.41477 .43054 Mdot
.66862 .50603 Mdot
.64409 .64976 Mdot
.49884 .69424 Mdot
.5043 .53316 Mdot
.56428 .65435 Mdot
.40621 .41602 Mdot
.23026 .58095 Mdot
.66692 .32631 Mdot
.67007 .65054 Mdot
.40697 .69049 Mdot
.44344 .41213 Mdot
.72709 .4742 Mdot
.66317 .49194 Mdot
.42652 .65293 Mdot
.60557 .77543 Mdot
.53785 .67815 Mdot
.35271 .4376 Mdot
.69726 .5064 Mdot
.45411 .5306 Mdot
.207 .58452 Mdot
.6492 .64151 Mdot
.66725 .31464 Mdot
.67964 .45943 Mdot
.62301 .69169 Mdot
.40654 .36444 Mdot
.41893 .65476 Mdot
.43027 .68739 Mdot
.57098 .50747 Mdot
.69894 .46768 Mdot
.64855 .32861 Mdot
.57034 .51244 Mdot
.54228 .50019 Mdot
.65592 .31595 Mdot
.65894 .49178 Mdot
.40479 .67812 Mdot
.43561 .64802 Mdot
.42618 .67035 Mdot
.30409 .65238 Mdot
.44811 .61923 Mdot
.56736 .26432 Mdot
.44378 .39604 Mdot
.22967 .60283 Mdot
.44043 .4048 Mdot
.63663 .68768 Mdot
.40668 .63851 Mdot
.49287 .30466 Mdot
.41932 .46935 Mdot
.23361 .65942 Mdot
.37522 .41318 Mdot
.56762 .54816 Mdot
.39253 .43576 Mdot
.24392 .55535 Mdot
.42142 .61535 Mdot
.36483 .44654 Mdot
.62383 .62456 Mdot
.64829 .34088 Mdot
.39712 .70927 Mdot
.37729 .39968 Mdot
.52579 .79655 Mdot
.41515 .39709 Mdot
.50678 .68258 Mdot
.58172 .50507 Mdot
.69891 .30063 Mdot
.4145 .46102 Mdot
.73031 .48708 Mdot
.40531 .51208 Mdot
.22445 .59385 Mdot
.65087 .67699 Mdot
.23274 .58954 Mdot
.71225 .51119 Mdot
.34479 .59067 Mdot
.40626 .48041 Mdot
.66532 .31018 Mdot
.50669 .63521 Mdot
.64665 .67416 Mdot
.40683 .43886 Mdot
.36215 .42636 Mdot
.55647 .59258 Mdot
.20709 .56623 Mdot
.32282 .45169 Mdot
.62759 .33821 Mdot
.21864 .56231 Mdot
.38672 .3969 Mdot
.70305 .53355 Mdot
.41001 .6236 Mdot
.35591 .57654 Mdot
.33423 .60931 Mdot
.38175 .37316 Mdot
.41414 .64891 Mdot
.41357 .62453 Mdot
.24462 .30918 Mdot
.67322 .31954 Mdot
.38331 .40499 Mdot
.58812 .51696 Mdot
.38633 .38959 Mdot
.64461 .65508 Mdot
.43379 .45549 Mdot
.70747 .4628 Mdot
.50134 .45343 Mdot
.65972 .48279 Mdot
.37446 .44595 Mdot
.40907 .6617 Mdot
.63379 .68229 Mdot
.68538 .6063 Mdot
.58059 .6527 Mdot
.56647 .26498 Mdot
.61476 .2953 Mdot
.64547 .30888 Mdot
.67497 .3349 Mdot
.66862 .66298 Mdot
.41967 .42784 Mdot
.52344 .34631 Mdot
.44215 .37693 Mdot
.39 .44051 Mdot
.38994 .40143 Mdot
.67387 .62362 Mdot
.62252 .66918 Mdot
.68437 .46387 Mdot
.40481 .43489 Mdot
.43094 .38071 Mdot
.40834 .65673 Mdot
.64695 .30874 Mdot
.68498 .44837 Mdot
.6635 .29607 Mdot
.68513 .4871 Mdot
.1995 .38952 Mdot
.41342 .33882 Mdot
.65311 .34081 Mdot
.65664 .65269 Mdot
.43969 .65537 Mdot
.49673 .59867 Mdot
.71004 .49558 Mdot
.71766 .49932 Mdot
.36949 .36232 Mdot
.39641 .64838 Mdot
.40843 .62894 Mdot
.67073 .29633 Mdot
.60734 .65709 Mdot
.38971 .35168 Mdot
.35981 .37711 Mdot
.69492 .59387 Mdot
.71146 .45037 Mdot
.22116 .57647 Mdot
.41258 .60345 Mdot
.41492 .44098 Mdot
.43016 .62558 Mdot
.39089 .41889 Mdot
.45447 .54087 Mdot
.41687 .69169 Mdot
.43572 .44675 Mdot
.4555 .42355 Mdot
.70999 .45491 Mdot
.2873 .26685 Mdot
.37276 .35239 Mdot
.60571 .61313 Mdot
.36119 .39809 Mdot
.43624 .15473 Mdot
.23329 .34124 Mdot
.42265 .41006 Mdot
.38335 .45996 Mdot
.26882 .72995 Mdot
.43306 .42161 Mdot
.50269 .586 Mdot
.45126 .4611 Mdot
.43642 .62867 Mdot
.58384 .5292 Mdot
.51714 .34968 Mdot
.6758 .31993 Mdot
.69686 .49242 Mdot
.50304 .26785 Mdot
.68181 .32199 Mdot
.43223 .64714 Mdot
.36355 .35339 Mdot
.39938 .60843 Mdot
.65472 .45916 Mdot
.3125 .41427 Mdot
.64783 .65815 Mdot
.52064 .35051 Mdot
.72592 .48609 Mdot
.62234 .66326 Mdot
.43569 .41945 Mdot
.64785 .45144 Mdot
.65692 .63463 Mdot
.25606 .28653 Mdot
.59957 .66008 Mdot
.63136 .67509 Mdot
.51021 .37856 Mdot
.67599 .3195 Mdot
.58515 .57033 Mdot
.47503 .38071 Mdot
.63684 .68411 Mdot
.46447 .18766 Mdot
.72044 .45789 Mdot
.52006 .41976 Mdot
.41111 .6163 Mdot
.43025 .34608 Mdot
.39589 .40534 Mdot
.6049 .66673 Mdot
.46842 .65784 Mdot
.60744 .45245 Mdot
.6518 .65679 Mdot
.39583 .47203 Mdot
.51861 .45393 Mdot
.49766 .57488 Mdot
.49061 .59637 Mdot
.63883 .35302 Mdot
.7506 .37186 Mdot
.42959 .63042 Mdot
.63435 .34555 Mdot
.46117 .29399 Mdot
.37173 .41692 Mdot
.62627 .64577 Mdot
.47898 .59765 Mdot
.62531 .66241 Mdot
.66122 .32612 Mdot
.65579 .35008 Mdot
.41481 .6428 Mdot
.41211 .68864 Mdot
.47732 .67473 Mdot
.38555 .25665 Mdot
.39349 .38209 Mdot
.28512 .48 Mdot
.40349 .69277 Mdot
.31548 .6223 Mdot
.67589 .30651 Mdot
.6593 .30232 Mdot
.20282 .48145 Mdot
.41098 .37946 Mdot
.56921 .55451 Mdot
.39284 .39547 Mdot
.50807 .20307 Mdot
.40033 .39066 Mdot
.72233 .48986 Mdot
.35828 .42185 Mdot
.45411 .80182 Mdot
.41631 .37477 Mdot
.39469 .40035 Mdot
.70505 .48322 Mdot
.36125 .36442 Mdot
.71165 .46773 Mdot
.36562 .41318 Mdot
.62837 .30145 Mdot
.69455 .49174 Mdot
.6432 .29689 Mdot
.54905 .52813 Mdot
.49463 .58931 Mdot
.6768 .32757 Mdot
.64514 .3079 Mdot
.52899 .30007 Mdot
.39711 .67443 Mdot
.39622 .55417 Mdot
.40766 .4071 Mdot
.69841 .4412 Mdot
.63079 .64098 Mdot
.3782 .37353 Mdot
.41858 .45478 Mdot
.37951 .35198 Mdot
.4124 .64529 Mdot
.65811 .46564 Mdot
.6592 .33453 Mdot
.66924 .49337 Mdot
.63178 .30091 Mdot
.71026 .46109 Mdot
.43445 .35849 Mdot
.39813 .361 Mdot
.32985 .42803 Mdot
.32503 .5307 Mdot
.63324 .22205 Mdot
.42277 .65401 Mdot
.48994 .58311 Mdot
.66584 .34269 Mdot
.53366 .46735 Mdot
.43678 .63399 Mdot
.71897 .49428 Mdot
.3788 .42688 Mdot
.39796 .33784 Mdot
.47575 .38878 Mdot
.36706 .67077 Mdot
.68406 .28791 Mdot
.70572 .49303 Mdot
.50567 .57768 Mdot
.51374 .41895 Mdot
.33275 .67278 Mdot
.46809 .28618 Mdot
.38689 .42134 Mdot
.67451 .29574 Mdot
.39325 .6521 Mdot
.57034 .57187 Mdot
.60823 .6697 Mdot
.5148 .36024 Mdot
.40674 .41497 Mdot
.67799 .71969 Mdot
.4106 .66282 Mdot
.65667 .30767 Mdot
.60492 .66732 Mdot
.67313 .3131 Mdot
.49042 .5766 Mdot
.42219 .60002 Mdot
.35311 .39213 Mdot
.39488 .39463 Mdot
.63766 .64427 Mdot
.42479 .62812 Mdot
.61756 .31298 Mdot
.56382 .59284 Mdot
.70878 .50058 Mdot
.52385 .47157 Mdot
.39182 .65663 Mdot
.68966 .70585 Mdot
.66869 .49687 Mdot
.65277 .6867 Mdot
.51089 .34447 Mdot
.62215 .637 Mdot
.38723 .39874 Mdot
.41139 .67134 Mdot
.65317 .6762 Mdot
.68904 .57881 Mdot
.28004 .68936 Mdot
.51927 .62627 Mdot
.38028 .44957 Mdot
.53089 .69459 Mdot
.59072 .79395 Mdot
.41261 .71513 Mdot
.65834 .66223 Mdot
.40187 .42133 Mdot
.35226 .43618 Mdot
.36017 .42488 Mdot
.62223 .67709 Mdot
.68958 .64078 Mdot
.69773 .51245 Mdot
.37611 .43309 Mdot
.63621 .33174 Mdot
.70069 .45971 Mdot
.70079 .52525 Mdot
.67808 .46053 Mdot
.40223 .68946 Mdot
.38971 .3402 Mdot
.46198 .44342 Mdot
.26385 .30228 Mdot
.63118 .67293 Mdot
.49484 .58892 Mdot
.37367 .45361 Mdot
.56152 .27225 Mdot
.43833 .6538 Mdot
.71176 .48823 Mdot
.3949 .41019 Mdot
.577 .50504 Mdot
.52072 .56814 Mdot
.69433 .48056 Mdot
.41001 .69213 Mdot
.37279 .7208 Mdot
.41385 .43329 Mdot
.36619 .39272 Mdot
.42701 .63653 Mdot
.58952 .80799 Mdot
.51455 .4309 Mdot
.39188 .42107 Mdot
.62566 .66909 Mdot
.73834 .73698 Mdot
.43707 .41467 Mdot
.43248 .6079 Mdot
.51079 .57543 Mdot
.39141 .60917 Mdot
.25886 .63105 Mdot
.46151 .40885 Mdot
.46156 .71309 Mdot
.58117 .30747 Mdot
.40569 .73069 Mdot
.53327 .20735 Mdot
.56653 .59895 Mdot
.21691 .32749 Mdot
.5903 .63157 Mdot
.23447 .53529 Mdot
.41809 .83878 Mdot
.62642 .78324 Mdot
.60086 .48542 Mdot
.65361 .57645 Mdot
.64192 .48964 Mdot
.46948 .16089 Mdot
.73053 .4938 Mdot
.54211 .19797 Mdot
.40371 .39602 Mdot
.57895 .80838 Mdot
.23719 .55649 Mdot
.65206 .2446 Mdot
.54695 .67768 Mdot
.57733 .50808 Mdot
.19133 .62454 Mdot
.5674 .69111 Mdot
.16897 .49341 Mdot
.35821 .52387 Mdot
.78243 .40204 Mdot
.53517 .48086 Mdot
.51994 .27215 Mdot
.24316 .59621 Mdot
.43937 .77341 Mdot
.63221 .71673 Mdot
.24758 .4316 Mdot
.81413 .52469 Mdot
.69022 .50233 Mdot
.41926 .61945 Mdot
.63243 .5715 Mdot
.17816 .54857 Mdot
.63188 .61629 Mdot
.45993 .71405 Mdot
.5415 .61206 Mdot
.24079 .55004 Mdot
.48234 .30585 Mdot
.23429 .50371 Mdot
.5987 .34657 Mdot
.4747 .16404 Mdot
.35757 .67881 Mdot
.72222 .55717 Mdot
.53662 .44787 Mdot
.58894 .36563 Mdot
.26414 .58758 Mdot
.62169 .33606 Mdot
.61838 .33076 Mdot
.41537 .6914 Mdot
.1914 .56322 Mdot
.52582 .56989 Mdot
.45306 .29287 Mdot
.73198 .48907 Mdot
.46141 .53815 Mdot
.5286 .83051 Mdot
.58413 .79103 Mdot
.32241 .23827 Mdot
.16135 .56999 Mdot
.46424 .21457 Mdot
.56121 .56751 Mdot
.65272 .61506 Mdot
.55759 .28746 Mdot
.31227 .44156 Mdot
.44235 .21514 Mdot
.32869 .48042 Mdot
.23274 .68201 Mdot
.55036 .77914 Mdot
.17327 .60876 Mdot
.35963 .6912 Mdot
.33779 .37991 Mdot
.48622 .55483 Mdot
.26855 .38418 Mdot
.44653 .26809 Mdot
.17871 .59553 Mdot
.69699 .31077 Mdot
.46805 .6354 Mdot
.63 .77988 Mdot
.27346 .62023 Mdot
.61286 .37474 Mdot
.67461 .2695 Mdot
.36775 .56986 Mdot
.19469 .6476 Mdot
.4655 .71323 Mdot
.2204 .3926 Mdot
.61008 .71854 Mdot
.69409 .42592 Mdot
.70568 .52384 Mdot
.59321 .64653 Mdot
.16333 .52634 Mdot
.41702 .67016 Mdot
.28176 .26758 Mdot
.45219 .70426 Mdot
.39325 .51279 Mdot
.19807 .65716 Mdot
.40526 .20771 Mdot
.2448 .61781 Mdot
.60158 .24273 Mdot
.71853 .72389 Mdot
.30016 .36807 Mdot
.57771 .63705 Mdot
.70031 .53805 Mdot
.52042 .67365 Mdot
.16648 .53976 Mdot
.44301 .20326 Mdot
.32768 .78619 Mdot
.44598 .29273 Mdot
.7147 .41373 Mdot
.3581 .66675 Mdot
.61503 .47753 Mdot
.62308 .3889 Mdot
.17042 .60354 Mdot
.22317 .55704 Mdot
.73382 .73127 Mdot
.51619 .21749 Mdot
.32853 .61901 Mdot
.5198 .70849 Mdot
.63889 .54627 Mdot
.29095 .36238 Mdot
.54124 .79322 Mdot
.34406 .39009 Mdot
.47396 .27978 Mdot
.36831 .55176 Mdot
.66382 .36397 Mdot
.51078 .41818 Mdot
.55569 .76233 Mdot
.47271 .23607 Mdot
.67677 .74881 Mdot
.37044 .57473 Mdot
.39174 .69793 Mdot
.4454 .21719 Mdot
.48987 .21342 Mdot
.62021 .74139 Mdot
.72275 .30766 Mdot
.21689 .39697 Mdot
.65724 .40673 Mdot
.45998 .42549 Mdot
.23244 .52882 Mdot
.24554 .59721 Mdot
.48723 .18026 Mdot
.43444 .35606 Mdot
.29289 .27395 Mdot
.55724 .65495 Mdot
.31025 .53578 Mdot
.44644 .25148 Mdot
.32083 .53321 Mdot
.23206 .62683 Mdot
.46316 .57013 Mdot
.6318 .59655 Mdot
.47998 .64407 Mdot
.19679 .6482 Mdot
.69156 .45907 Mdot
.43775 .21196 Mdot
.59521 .62419 Mdot
.68983 .58568 Mdot
.58614 .58241 Mdot
.6123 .44772 Mdot
.16033 .48853 Mdot
.62148 .77111 Mdot
.67362 .55465 Mdot
.41494 .77346 Mdot
.44827 .53222 Mdot
.28917 .48908 Mdot
.33217 .36711 Mdot
.3451 .4916 Mdot
.6516 .34852 Mdot
.32239 .57709 Mdot
.43841 .59001 Mdot
.7145 .26633 Mdot
.4497 .3808 Mdot
.54095 .48292 Mdot
.50988 .58524 Mdot
.53363 .36277 Mdot
.19792 .38917 Mdot
.33457 .36188 Mdot
.40118 .21239 Mdot
.61768 .77819 Mdot
.53435 .35176 Mdot
.6174 .38471 Mdot
.39432 .56375 Mdot
.17418 .61386 Mdot
.16471 .42871 Mdot
.53285 .81352 Mdot
.51879 .69705 Mdot
.61033 .15392 Mdot
.63961 .5926 Mdot
.31713 .25797 Mdot
.59832 .62292 Mdot
.91005 .53249 Mdot
.66662 .49147 Mdot
.58706 .20567 Mdot
.27967 .41461 Mdot
.57336 .47426 Mdot
.18415 .55895 Mdot
.2614 .61408 Mdot
.68095 .28236 Mdot
.37803 .69479 Mdot
.44899 .37129 Mdot
.18545 .59509 Mdot
.20127 .64853 Mdot
.18796 .60085 Mdot
.6809 .70237 Mdot
.23905 .65221 Mdot
.24451 .70959 Mdot
.56964 .26374 Mdot
.54187 .57401 Mdot
.41082 .4793 Mdot
.37252 .25481 Mdot
.37109 .23195 Mdot
.6982 .32709 Mdot
.30196 .36421 Mdot
.35673 .6775 Mdot
.22729 .69495 Mdot
.19796 .38399 Mdot
.23251 .48079 Mdot
.16909 .47778 Mdot
.71312 .54677 Mdot
.39621 .24303 Mdot
.16124 .46412 Mdot
.44159 .75593 Mdot
.56983 .68116 Mdot
.25586 .72724 Mdot
.49107 .22094 Mdot
.65545 .57703 Mdot
.497 .80383 Mdot
.34864 .23875 Mdot
.5104 .70779 Mdot
.6501 .56974 Mdot
.30683 .43944 Mdot
.34132 .66106 Mdot
.6145 .44747 Mdot
.4322 .77116 Mdot
.56387 .56014 Mdot
.43269 .24688 Mdot
.69692 .5217 Mdot
.42365 .21837 Mdot
.60656 .39252 Mdot
.54539 .57804 Mdot
.51118 .28137 Mdot
.4542 .19087 Mdot
.50931 .78249 Mdot
.21422 .62679 Mdot
.62022 .77595 Mdot
.71256 .74386 Mdot
.55896 .72005 Mdot
.37486 .54506 Mdot
.362 .36347 Mdot
.17933 .55606 Mdot
.14845 .41981 Mdot
.15763 .47642 Mdot
.64291 .74767 Mdot
.74558 .49422 Mdot
.64082 .69234 Mdot
.54898 .28878 Mdot
.58307 .46566 Mdot
.53688 .62839 Mdot
.57421 .38828 Mdot
.58824 .65015 Mdot
.54274 .83243 Mdot
.48766 .6634 Mdot
.56194 .276 Mdot
.24696 .44909 Mdot
.3089 .41919 Mdot
.20598 .58125 Mdot
.40349 .70124 Mdot
.65319 .74476 Mdot
.44018 .21499 Mdot
.6882 .45758 Mdot
.70024 .58528 Mdot
.47945 .63487 Mdot
.34449 .36717 Mdot
.73542 .53005 Mdot
.52153 .61748 Mdot
.32105 .50207 Mdot
.74028 .50596 Mdot
.20445 .35906 Mdot
.30788 .25833 Mdot
.16126 .46052 Mdot
.46176 .20837 Mdot
.70595 .57182 Mdot
.52761 .38057 Mdot
.6354 .60208 Mdot
.55488 .68036 Mdot
.53188 .42741 Mdot
.46544 .20083 Mdot
.24101 .61855 Mdot
.48471 .5713 Mdot
.46289 .41856 Mdot
.22256 .35694 Mdot
.54002 .26664 Mdot
.53437 .38432 Mdot
.36348 .6015 Mdot
.45703 .62643 Mdot
.64086 .21498 Mdot
.44974 .78382 Mdot
.43945 .48682 Mdot
.52454 .70115 Mdot
.65251 .64206 Mdot
.41514 .69394 Mdot
.45244 .18963 Mdot
.73845 .32832 Mdot
.42307 .7188 Mdot
.51282 .5435 Mdot
.17058 .52709 Mdot
.53395 .52571 Mdot
.50695 .69853 Mdot
.35989 .7433 Mdot
.75081 .69733 Mdot
.3622 .69416 Mdot
.5521 .56881 Mdot
.5986 .56652 Mdot
.34905 .68025 Mdot
.37197 .67353 Mdot
.22584 .56704 Mdot
.15842 .5403 Mdot
.56832 .5177 Mdot
.42419 .76058 Mdot
.52664 .34759 Mdot
.61197 .47149 Mdot
.50736 .55759 Mdot
.5042 .2727 Mdot
.42547 .74189 Mdot
.19957 .449 Mdot
.62061 .82306 Mdot
.31078 .34851 Mdot
.5786 .1998 Mdot
.55094 .28965 Mdot
.36104 .52498 Mdot
.26135 .58127 Mdot
.58708 .7093 Mdot
.37311 .39486 Mdot
.15245 .54933 Mdot
.5581 .7719 Mdot
.52982 .31395 Mdot
.63942 .53411 Mdot
.42894 .39972 Mdot
.33362 .4355 Mdot
.16097 .47262 Mdot
.36633 .63114 Mdot
.50135 .87007 Mdot
.51816 .21054 Mdot
.38784 .52499 Mdot
.25202 .63027 Mdot
.39555 .21681 Mdot
.46096 .56618 Mdot
.45875 .70191 Mdot
.61327 .39934 Mdot
.37235 .2271 Mdot
.39191 .76098 Mdot
.43535 .78761 Mdot
.55426 .71199 Mdot
.2428 .70367 Mdot
.41004 .52416 Mdot
.60552 .71137 Mdot
.72224 .54307 Mdot
.38384 .45714 Mdot
.6031 .77641 Mdot
.54707 .69741 Mdot
.64782 .43267 Mdot
.30672 .43278 Mdot
.14517 .42378 Mdot
.42864 .47374 Mdot
.60706 .76498 Mdot
.4824 .86325 Mdot
.55685 .87268 Mdot
.44707 .79838 Mdot
.16782 .59898 Mdot
.42361 .78182 Mdot
.50281 .70381 Mdot
.66443 .65578 Mdot
.53438 .49689 Mdot
.29021 .47417 Mdot
.14969 .51854 Mdot
.762 .35959 Mdot
.57331 .64286 Mdot
.25889 .4205 Mdot
.14811 .51939 Mdot
.44835 .45527 Mdot
.61577 .20588 Mdot
.70052 .42834 Mdot
.4503 .16822 Mdot
.33437 .23212 Mdot
.35084 .62298 Mdot
.47759 .17715 Mdot
.5902 .19056 Mdot
.6214 .25785 Mdot
.31417 .25672 Mdot
.28743 .34544 Mdot
.36741 .60611 Mdot
.45032 .21955 Mdot
.5274 .67801 Mdot
.54456 .14225 Mdot
.50596 .55595 Mdot
.54313 .60007 Mdot
.41077 .59851 Mdot
.51914 .67237 Mdot
.51368 .76786 Mdot
.53636 .55325 Mdot
.49828 .47495 Mdot
.22707 .61485 Mdot
.75299 .72978 Mdot
.39891 .78978 Mdot
.49046 .64372 Mdot
.20474 .64662 Mdot
.60125 .71746 Mdot
.53874 .42059 Mdot
.27394 .60286 Mdot
.54099 .27645 Mdot
.70033 .5481 Mdot
.39793 .39765 Mdot
.15955 .54539 Mdot
.70062 .54765 Mdot
.19942 .62792 Mdot
.26204 .27864 Mdot
.17596 .47277 Mdot
.32342 .36626 Mdot
.69004 .54058 Mdot
.39042 .23011 Mdot
.3918 .23178 Mdot
.24508 .68723 Mdot
.56281 .19057 Mdot
.52744 .44276 Mdot
.54633 .54042 Mdot
.50439 .53609 Mdot
.44948 .48221 Mdot
.38866 .21796 Mdot
.40777 .55404 Mdot
.45608 .25462 Mdot
.50801 .81435 Mdot
.45877 .19565 Mdot
.25035 .6167 Mdot
.53514 .28616 Mdot
.64608 .41465 Mdot
.66678 .28399 Mdot
.71132 .44886 Mdot
.30104 .76371 Mdot
.58419 .72704 Mdot
.28578 .28115 Mdot
.71549 .73631 Mdot
.54611 .79143 Mdot
.53931 .19364 Mdot
.47889 .58083 Mdot
.30555 .34332 Mdot
.77363 .38842 Mdot
.48057 .24256 Mdot
.22507 .57757 Mdot
.53387 .67834 Mdot
.33396 .63701 Mdot
.15657 .5031 Mdot
.43619 .24951 Mdot
.36785 .82148 Mdot
.76421 .47169 Mdot
.32306 .57096 Mdot
.19334 .54741 Mdot
.69487 .76463 Mdot
.53693 .37902 Mdot
.19857 .65084 Mdot
.38769 .62674 Mdot
.16317 .57446 Mdot
.60096 .65192 Mdot
.69589 .40129 Mdot
.55077 .65201 Mdot
.54158 .32421 Mdot
.54258 .33041 Mdot
.23547 .32399 Mdot
.62639 .77655 Mdot
.5856 .7925 Mdot
.65783 .40672 Mdot
.72378 .50704 Mdot
.51287 .50227 Mdot
.43286 .75451 Mdot
.31051 .76918 Mdot
.3846 .35802 Mdot
.76146 .4505 Mdot
.42284 .20808 Mdot
.6385 .60201 Mdot
.54162 .60691 Mdot
.54328 .65645 Mdot
.34469 .72046 Mdot
.39167 .24745 Mdot
.23419 .69589 Mdot
.53504 .61257 Mdot
.58525 .44622 Mdot
.33549 .5976 Mdot
.55162 .62207 Mdot
.68991 .72863 Mdot
.45072 .72631 Mdot
.52539 .53429 Mdot
.5157 .42636 Mdot
.46805 .2131 Mdot
.1773 .37223 Mdot
.21899 .66643 Mdot
.70051 .72606 Mdot
.53928 .35374 Mdot
.43319 .60863 Mdot
.49733 .25447 Mdot
.36055 .81842 Mdot
.4573 .16069 Mdot
.50824 .8021 Mdot
.45342 .19887 Mdot
.62664 .48595 Mdot
.59826 .20236 Mdot
.53419 .40457 Mdot
.19272 .54432 Mdot
.27076 .40663 Mdot
.42516 .59865 Mdot
.6382 .55039 Mdot
.52079 .33674 Mdot
.55771 .60373 Mdot
.36884 .60222 Mdot
.62966 .77399 Mdot
.36928 .82204 Mdot
.55439 .18298 Mdot
.34637 .59119 Mdot
.39205 .82288 Mdot
.45039 .67009 Mdot
.60297 .56768 Mdot
.70298 .67749 Mdot
.53653 .34748 Mdot
.66622 .4783 Mdot
.33614 .47146 Mdot
.51832 .46584 Mdot
.40475 .77697 Mdot
.64007 .5007 Mdot
.6838 .32434 Mdot
.37862 .67621 Mdot
.57758 .18897 Mdot
.43605 .68452 Mdot
.19085 .35822 Mdot
.44566 .75296 Mdot
.22741 .60464 Mdot
.37134 .76735 Mdot
.74782 .53982 Mdot
.71514 .74627 Mdot
.1691 .49026 Mdot
.41224 .26165 Mdot
.3742 .68131 Mdot
.39952 .70393 Mdot
.39247 .75645 Mdot
.68277 .6567 Mdot
.17434 .52517 Mdot
.41134 .20651 Mdot
.7129 .57044 Mdot
.44527 .62843 Mdot
.55507 .54244 Mdot
.48801 .64047 Mdot
.19874 .36978 Mdot
.66905 .48979 Mdot
.18417 .63519 Mdot
.40135 .5536 Mdot
.64227 .79222 Mdot
.52751 .63819 Mdot
.5018 .43805 Mdot
.54188 .38251 Mdot
.6869 .57457 Mdot
.46018 .43353 Mdot
.39071 .5243 Mdot
.40762 .68799 Mdot
.58012 .58709 Mdot
.64476 .31211 Mdot
.71699 .27735 Mdot
.61389 .60719 Mdot
.35191 .52862 Mdot
.37687 .21752 Mdot
.40672 .70092 Mdot
.76248 .47859 Mdot
.7748 .5054 Mdot
.45546 .41388 Mdot
.3375 .27361 Mdot
.28247 .74437 Mdot
.17186 .49769 Mdot
.38105 .64308 Mdot
.69648 .74733 Mdot
.60953 .34931 Mdot
.20976 .35398 Mdot
.36127 .72152 Mdot
.40957 .21615 Mdot
.35663 .55488 Mdot
.16918 .4352 Mdot
.2587 .63046 Mdot
.49393 .67692 Mdot
.44914 .21298 Mdot
.60671 .45636 Mdot
.44856 .19563 Mdot
.34063 .71884 Mdot
.5129 .52577 Mdot
.45013 .1708 Mdot
.62921 .4965 Mdot
.23372 .50861 Mdot
.40015 .49994 Mdot
.52573 .63721 Mdot
.38415 .22597 Mdot
.38018 .66829 Mdot
.62579 .35035 Mdot
.25642 .44242 Mdot
.56061 .66978 Mdot
.16614 .53472 Mdot
.61901 .74315 Mdot
.42713 .20295 Mdot
.49759 .53568 Mdot
.53741 .24614 Mdot
.40607 .5495 Mdot
.43657 .28272 Mdot
.36459 .46219 Mdot
.36679 .5571 Mdot
.58607 .39625 Mdot
.24008 .33019 Mdot
.41767 .5105 Mdot
.18096 .57566 Mdot
.20675 .37652 Mdot
.36885 .73729 Mdot
.58209 .55925 Mdot
.43248 .62166 Mdot
.18545 .62914 Mdot
.35147 .25823 Mdot
.52937 .66332 Mdot
.33962 .22972 Mdot
.63936 .21219 Mdot
.40705 .83284 Mdot
.58362 .75178 Mdot
.5224 .61414 Mdot
.28582 .26861 Mdot
.55751 .77625 Mdot
.60483 .19533 Mdot
.22344 .57213 Mdot
.37288 .62806 Mdot
.20116 .66285 Mdot
.27134 .36601 Mdot
.57324 .79535 Mdot
.20302 .56552 Mdot
.38852 .72709 Mdot
.34021 .26397 Mdot
.46257 .43522 Mdot
.72484 .47612 Mdot
.56466 .48437 Mdot
.48509 .17604 Mdot
.4048 .72052 Mdot
.40356 .21455 Mdot
.41024 .21824 Mdot
.55305 .20167 Mdot
.70018 .57056 Mdot
.40818 .833 Mdot
.26447 .6579 Mdot
.33403 .40782 Mdot
.37648 .6479 Mdot
.67789 .33292 Mdot
.52098 .22047 Mdot
.40088 .37313 Mdot
.48896 .32948 Mdot
.36552 .56545 Mdot
.15053 .53612 Mdot
.62892 .44275 Mdot
.61877 .71232 Mdot
.43981 .6218 Mdot
.5232 .66976 Mdot
.44499 .56644 Mdot
.62508 .78527 Mdot
.39075 .22557 Mdot
.42025 .72055 Mdot
.47124 .70376 Mdot
.56298 .79566 Mdot
.46104 .22879 Mdot
.59486 .33162 Mdot
.65204 .68019 Mdot
.30856 .49021 Mdot
.27543 .71289 Mdot
.57327 .78413 Mdot
.46746 .63151 Mdot
.48424 .78751 Mdot
.51878 .52399 Mdot
.64719 .72705 Mdot
.6234 .77727 Mdot
.45853 .58965 Mdot
.19134 .47195 Mdot
.39653 .74203 Mdot
.70636 .53957 Mdot
.50005 .21261 Mdot
.45682 .77718 Mdot
.39669 .21926 Mdot
.4543 .42895 Mdot
.18813 .57811 Mdot
.53161 .31765 Mdot
.6355 .36666 Mdot
.35979 .39241 Mdot
.2965 .43572 Mdot
.16043 .47243 Mdot
.48508 .80247 Mdot
.29238 .4007 Mdot
.46523 .62122 Mdot
.30954 .25413 Mdot
.73026 .52801 Mdot
.74085 .50794 Mdot
.60137 .23001 Mdot
.49528 .4527 Mdot
.57993 .4641 Mdot
.67094 .61197 Mdot
.45627 .44269 Mdot
.5955 .31726 Mdot
.52274 .54045 Mdot
.3117 .4957 Mdot
.31479 .26333 Mdot
.2954 .7555 Mdot
.48987 .54794 Mdot
.32495 .23477 Mdot
.27844 .42665 Mdot
.36623 .6471 Mdot
.56464 .18384 Mdot
.3008 .37455 Mdot
.44032 .36026 Mdot
.62683 .35126 Mdot
.45989 .64492 Mdot
.28899 .74419 Mdot
.33795 .48157 Mdot
.65979 .37484 Mdot
.65167 .39913 Mdot
.50486 .54984 Mdot
.8038 .52076 Mdot
.55798 .65588 Mdot
.28785 .26517 Mdot
.44121 .21457 Mdot
.58886 .67165 Mdot
.41099 .77461 Mdot
.29512 .38308 Mdot
.1865 .57987 Mdot
.59603 .41298 Mdot
.16679 .5062 Mdot
.6757 .71064 Mdot
.33328 .52087 Mdot
.21541 .36796 Mdot
.4635 .27424 Mdot
.44203 .28468 Mdot
.37014 .58704 Mdot
.36077 .29711 Mdot
.49467 .59943 Mdot
.72889 .3308 Mdot
.52755 .14572 Mdot
.33644 .79618 Mdot
.63395 .79287 Mdot
.4123 .4892 Mdot
.49155 .25217 Mdot
.39674 .74621 Mdot
.53728 .43195 Mdot
.63162 .39696 Mdot
.7489 .51632 Mdot
.65047 .55535 Mdot
.74159 .73206 Mdot
.15296 .54609 Mdot
.36175 .39162 Mdot
.57195 .36191 Mdot
.68725 .2669 Mdot
.66577 .50233 Mdot
.23823 .449 Mdot
.27918 .73847 Mdot
.64515 .68174 Mdot
.7164 .66713 Mdot
.65961 .59894 Mdot
.23824 .32285 Mdot
.70479 .64878 Mdot
.67697 .66756 Mdot
.19006 .35825 Mdot
.53054 .81135 Mdot
.3298 .67194 Mdot
.74597 .72584 Mdot
.2288 .34613 Mdot
.36408 .55098 Mdot
.72791 .53201 Mdot
.16871 .56591 Mdot
.54031 .3845 Mdot
.68331 .5567 Mdot
.27646 .33721 Mdot
.44949 .20951 Mdot
.51149 .21187 Mdot
.61939 .70494 Mdot
.267 .41683 Mdot
.70938 .24148 Mdot
.75153 .53825 Mdot
.66328 .80949 Mdot
.1744 .4918 Mdot
.29106 .71241 Mdot
.4445 .79374 Mdot
.66354 .41118 Mdot
.1866 .56955 Mdot
.40919 .22334 Mdot
.28153 .4053 Mdot
.74748 .35092 Mdot
.48428 .27838 Mdot
.52239 .26664 Mdot
.65032 .72471 Mdot
.16901 .45826 Mdot
.71013 .56455 Mdot
.30757 .32734 Mdot
.43618 .20807 Mdot
.28454 .43139 Mdot
.43456 .2848 Mdot
.2685 .70334 Mdot
.33394 .27261 Mdot
.47424 .20056 Mdot
.66085 .5715 Mdot
.61804 .32393 Mdot
.2857 .73512 Mdot
.43629 .55018 Mdot
.35652 .56052 Mdot
.48676 .86473 Mdot
.17307 .60649 Mdot
.30125 .37068 Mdot
.4322 .45797 Mdot
.21984 .32192 Mdot
.75206 .45462 Mdot
.31004 .2685 Mdot
.51496 .82814 Mdot
.52216 .20621 Mdot
.42226 .51637 Mdot
.40608 .39172 Mdot
.57404 .24974 Mdot
.35403 .65496 Mdot
.27534 .41295 Mdot
.69455 .61358 Mdot
.46789 .20244 Mdot
.3574 .53041 Mdot
.61964 .82331 Mdot
.34067 .71534 Mdot
.44575 .6441 Mdot
.16252 .55651 Mdot
.23444 .40986 Mdot
.3796 .53422 Mdot
.19036 .55258 Mdot
.59094 .42465 Mdot
.59638 .31794 Mdot
.40413 .54704 Mdot
.52907 .37849 Mdot
.48653 .17368 Mdot
.39087 .82429 Mdot
.29565 .48544 Mdot
.18885 .64377 Mdot
.16118 .43765 Mdot
.44613 .63838 Mdot
.27274 .39188 Mdot
.54665 .35512 Mdot
.40367 .73282 Mdot
.66264 .58188 Mdot
.6951 .58214 Mdot
.67932 .23956 Mdot
.71383 .27305 Mdot
.42029 .4075 Mdot
.67828 .71014 Mdot
.15819 .50364 Mdot
.66896 .23305 Mdot
.15787 .51559 Mdot
.37516 .55275 Mdot
.35544 .37131 Mdot
.56253 .87271 Mdot
.5031 .7014 Mdot
.40917 .35081 Mdot
.46891 .44766 Mdot
.45791 .46617 Mdot
.38237 .39468 Mdot
.68634 .6671 Mdot
.54974 .28097 Mdot
.51132 .20074 Mdot
.1704 .5604 Mdot
.45217 .63286 Mdot
.54219 .37621 Mdot
.59751 .62909 Mdot
.5078 .3254 Mdot
.41429 .30584 Mdot
.63154 .63197 Mdot
.51304 .19216 Mdot
.8 .52413 Mdot
.60283 .37181 Mdot
.52489 .62568 Mdot
.492 .4711 Mdot
.4673 .68594 Mdot
.53606 .1854 Mdot
.68 .6297 Mdot
.62183 .25916 Mdot
.43171 .203 Mdot
.35006 .60447 Mdot
.61734 .71908 Mdot
.61376 .16072 Mdot
.53564 .38831 Mdot
.68422 .6957 Mdot
.31683 .34586 Mdot
.34012 .69614 Mdot
.18288 .49673 Mdot
.6049 .31508 Mdot
.50917 .59304 Mdot
.34064 .58959 Mdot
.18321 .55803 Mdot
.64272 .64047 Mdot
.16616 .38883 Mdot
.32946 .33756 Mdot
.23783 .45829 Mdot
.26381 .67612 Mdot
.55676 .57355 Mdot
.22936 .58251 Mdot
.35397 .45586 Mdot
.57348 .4418 Mdot
.79655 .51534 Mdot
.5059 .62936 Mdot
.51061 .5581 Mdot
.41694 .733 Mdot
.57156 .19927 Mdot
.20504 .45546 Mdot
.38182 .40709 Mdot
.6916 .30714 Mdot
.52683 .36463 Mdot
.6749 .39694 Mdot
.71418 .41396 Mdot
.56816 .67748 Mdot
.53273 .1873 Mdot
.51805 .21118 Mdot
.208 .56585 Mdot
.18587 .61035 Mdot
.39965 .50108 Mdot
.17663 .48386 Mdot
.62622 .42583 Mdot
.52262 .76706 Mdot
.34051 .27173 Mdot
.38572 .82076 Mdot
.40224 .5277 Mdot
.43589 .48468 Mdot
.17145 .40528 Mdot
.16642 .48078 Mdot
.56585 .65154 Mdot
.52844 .68599 Mdot
.50197 .14918 Mdot
.54488 .33192 Mdot
.74747 .73087 Mdot
.67202 .5832 Mdot
.18571 .38093 Mdot
.52959 .56632 Mdot
.31347 .35715 Mdot
.38857 .56965 Mdot
.44524 .37019 Mdot
.68912 .47467 Mdot
.35686 .7382 Mdot
.36701 .59123 Mdot
.3824 .29602 Mdot
.33156 .41754 Mdot
.6224 .56149 Mdot
.4273 .6073 Mdot
.34231 .8006 Mdot
.66465 .51038 Mdot
.58561 .44205 Mdot
.58405 .83213 Mdot
.7977 .5174 Mdot
.62732 .20434 Mdot
.23699 .67895 Mdot
.55304 .67713 Mdot
.52405 .53879 Mdot
.81661 .60028 Mdot
.39321 .61977 Mdot
.37311 .658 Mdot
.61962 .60364 Mdot
.54411 .24994 Mdot
.60587 .76884 Mdot
.43825 .84818 Mdot
.16982 .4302 Mdot
.45471 .42424 Mdot
.74665 .76242 Mdot
.43122 .20738 Mdot
.57373 .40283 Mdot
.6132 .76681 Mdot
.15985 .54031 Mdot
.63761 .53345 Mdot
.25686 .28621 Mdot
.4415 .77062 Mdot
.37944 .72389 Mdot
.53874 .26133 Mdot
.69909 .74072 Mdot
.55467 .54729 Mdot
.66611 .80704 Mdot
.53184 .70646 Mdot
.51875 .27161 Mdot
.47751 .80045 Mdot
.36311 .68707 Mdot
.39358 .52239 Mdot
.45394 .74629 Mdot
.30401 .41682 Mdot
.43769 .70164 Mdot
.46563 .71198 Mdot
.59257 .34389 Mdot
.59725 .59026 Mdot
.50344 .69565 Mdot
.64472 .60859 Mdot
.34962 .62042 Mdot
.4899 .15899 Mdot
.75439 .44504 Mdot
.69259 .52093 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2]ooooo`;o00002Oooool2o`00
08oooooo000Looooo`03o`000?oooooooooo0:3ooooo1?l000001?oooooo0000o`000?ooool2o`00
00?ooooo0_l00009ooooo`;o0000Soooool001cooooo00?o0000ooooooooool0Woooool5o`000004
ooooool0003o0000ooooo`;o00003oooool2o`0008kooooo000Looooo`;o0000W?ooool2o`0000;o
oooo0_l0000Hooooo`;o0000S_ooool001cooooo00?o0000ooooooooool0R_ooool2o`0000gooooo
1?l0000Uooooo`;o0000QOooool001cooooo00?o0000ooooooooool0R_ooool4o`000003ooooool0
003o000000Sooooo1?l0000Uooooo`;o0000QOooool001cooooo00?o0000ooooooooool0R_ooool4
o`000003ooooool0003o000000?o000000?oooooo`000?l000001?ooool2o`0002Oooooo0_l00023
ooooo`007?ooool00ol0003oooooooooo`2:ooooo`;o000000?oooooo`000?l000001Ol000001?oo
oooo0000o`000?l0000/ooooo`Co0000POooool001cooooo00?o0000ooooooooool0SOooool4o`00
00Gooooo0_l0000^ooooo`;o0000POooool001cooooo00?o0000ooooooooool0S_ooool3o`000;So
oooo000Looooo`03o`000?oooooooooo08kooooo1Ol00007ooooo`;o0000[Oooool001cooooo00?o
0000ooooooooool0T?ooool5o`0000;ooooo0_l000000ooooooo0000o`00002]ooooo`007?ooool0
0ol0003oooooooooo`2Cooooo`;o00000_ooool2o`000004ooooool0003o0000o`000:cooooo000L
ooooo`03o`000?oooooooooo09Cooooo1?l00003ooooo`;o000000?oooooo`000?l000004?ooool2
o`0000;ooooo0_l0002Cooooo`007?ooool00ol0003oooooooooo`2Cooooo`Go00001_ooool2o`00
00Wooooo0ol00004ooooo`;o00000_ooool2o`0009?ooooo000Looooo`03o`000?oooooooooo08oo
oooo0_l00002ooooo`Go00004Oooool3o`0000Oooooo0_l00003ooooo`;o00000_ooool2o`0008_o
oooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0
003oooooooooo`2<ooooo`;o000000Coooooo`000?l0003o00000oooool2o`0000cooooo0_l00006
ooooo`;o00001_ooool2o`0000?ooooo1_l0002;ooooo`0000KoooooogMgMonHV9SooooooiRHV?mg
MgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0
Roooool;o`0000gooooo0_l00006ooooo`;o00003Oooool2o`0000Gooooo0_l00026ooooo`0000?o
oooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o
0000ooooooooool0QOooool2o`0000;ooooo3Ol0000Fooooo`;o00002?ooool4o`0000Oooooo0_l0
0026ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7o
k^k^00Kooooo0ol00025ooooo`Ko00001Oooool2o`000003ooooool0003o000000?o00002Oooool3
o`0000Sooooo0_l00002ooooo`;o00001?ooool4o`0000Gooooo0_l00028ooooo`0000?oooooo`00
0?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000oooo
ooooool0Qoooool3o`0000;ooooo0_l00005ooooo`Go00002Oooool3o`0000;ooooo0_l00008oooo
o`;o00002Oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0007oooooo00000ooooooo
410@ooooo`02ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`20ooooo`Co00000_ooool8o`0000Cooooo0_l0000>ooooo`;o00000_ooool2o`000003
ooooool0003o000000oooooo0ol00007ooooo`;o00000_ooool2o`0007oooooo00001_ooooooMgMg
oiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooo
oooo083ooooo1?l00002ooooo`Ko00000_ooool2o`0000;ooooo0_l0000>ooooo`;o000000?ooooo
o`000?l000000_ooool2o`0000gooooo1?l0000@ooooo`;o0000Noooool00006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0
M_ooool2o`0000Oooooo0_l00009ooooo`Ko00000oooool3o`0000Gooooo0_l00002ooooo`;o0000
00Coooooo`000?l0003ooooo0_l0000Aooooo`?o00004Oooool2o`0007_ooooo000Looooo`03o`00
0?oooooooooo07Kooooo0ol00002ooooo`Wo00000_ooool2o`0000?ooooo1Ol00003ooooo`?o0000
1Oooool2o`0000;ooooo0_l00003ooooo`;o00007_ooool2o`0000;ooooo0_l00002ooooo`;o0000
Noooool001cooooo00?o0000ooooooooool0Moooool2o`0000;ooooo1?l00002ooooo`?o00000_oo
ool2o`0000Gooooo1?l0000;ooooo`;o00001_ooool3o`0001_ooooo1?l00002ooooo`Co0000OOoo
ool001cooooo00?o0000ooooooooool0OOooool2o`0000;ooooo0_l0000<ooooo`;o00002oooool2
o`0000Oooooo1?l0000Iooooo`;o00001_ooool2o`0007gooooo000Looooo`03o`000?oooooooooo
06[ooooo0_l00009ooooo`;o00000_ooool4o`0000Cooooo0_l0000Jooooo`Wo000000?oooooo`00
0?l000006?ooool2o`0000Oooooo0_l00004ooooo`;o0000Moooool001cooooo00?o0000oooooooo
ool0J_ooool3o`0000Sooooo0_l00002ooooo`Co00005Oooool2o`0000Wooooo2Ol0000Jooooo`?o
00000_ooool2o`0000Wooooo0ol0001fooooo`007?ooool00ol0003oooooooooo`1Yooooo`Co0000
2?ooool2o`0000Cooooo0ol0000Dooooo`;o00008oooool2o`0000Oooooo0_l00003ooooo`;o0000
2_ooool2o`0000?ooooo0_l0001aooooo`007?ooool00ol0003oooooooooo`1Vooooo`;o000000?o
ooooo`000?l000002_ooool2o`0000Gooooo0_l00005ooooo`;o00004Oooool2o`0001oooooo0_l0
000;ooooo`;o00004?ooool2o`00077ooooo000Looooo`03o`000?oooooooooo06Gooooo0ol00006
ooooo`;o00001oooool2o`0000Kooooo0_l00002ooooo`;o00004Oooool2o`0001kooooo0_l0000<
ooooo`;o00004oooool2o`0006kooooo000Looooo`03o`000?oooooooooo06Gooooo0_l00007oooo
o`;o00001oooool2o`0000Cooooo1?l0000:ooooo`;o00002_ooool3o`0001cooooo0_l00008oooo
o`;o00001_ooool2o`0000oooooo0_l00008ooooo`;o0000I?ooool001cooooo00?o0000oooooooo
ool0OOooool2o`0000cooooo0_l0000:ooooo`?o00000oooool2o`0000cooooo0_l00009ooooo`;o
00002?ooool2o`0000Kooooo0_l00005ooooo`?o00004Oooool2o`0006Cooooo000Looooo`03o`00
0?oooooooooo07Gooooo0_l00004ooooo`;o00003?ooool2o`00017ooooo0ol00004ooooo`;o0000
1_ooool2o`0001?ooooo0_l0000=ooooo`?o0000Moooool001cooooo0_l0001fooooo`;o00000ooo
ool3o`0000?ooooo1?l00005ooooo`?o000000?oooooo`000?l000003Oooool2o`0000Gooooo0_l0
0008ooooo`;o00002?ooool2o`0000Oooooo0_l00008ooooo`;o00001?ooool2o`0007Oooooo000L
ooooo`03o`000?oooooooooo067ooooo0_l0000>ooooo`;o00000_ooool4o`000003ooooool0003o
000000Cooooo1?l00006ooooo`;o000000Coooooo`000?l0003ooooo0_l0000:ooooo`Co00003Ooo
ool2o`0000Sooooo0_l00007ooooo`;o00002?ooool2o`0007gooooo000Looooo`03o`000?oooooo
oooo063ooooo1Ol00009ooooo`;o000000?oooooo`000?l000000_ooool4o`000003ooooool0003o
000000;o00002_ooool2o`0000Kooooo0_l00007ooooo`;o00000oooool2o`0002Kooooo0ol0000=
ooooo`;o0000LOooool001cooooo00?o0000ooooooooool0H?ooool5o`0000Wooooo0_l0000:oooo
o`Oo000000?oooooo`000?l000001?ooool4o`0000;ooooo0_l00009ooooo`;o000000?oooooo`00
0?l000003Oooool2o`0001Wooooo0ol0000<ooooo`Co00002_ooool2o`0006Cooooo000Looooo`03
o`000?oooooooooo067ooooo1?l00006ooooo`;o00002Oooool2o`0000Kooooo1_l00005ooooo`?o
00000_ooool2o`0000Sooooo0ol000000ooooooo0000o`000002o`0000Cooooo0_l00005ooooo`;o
00001oooool3o`0000oooooo0_l0000=ooooo`Co000000?oooooo`000?l000001oooool2o`0006Co
oooo000Looooo`03o`000?oooooooooo05Sooooo1?l00004ooooo`Go00001_ooool2o`000003oooo
ool0003o000000Kooooo0_l00008ooooo`Co00003Oooool:o`0000;ooooo0ol00004ooooo`Co0000
1?ooool2o`0000Kooooo0ol00009ooooo`;o00006?ooool3o`0000Oooooo0_l0001Sooooo`007?oo
ool00ol0003oooooooooo`1Hooooo`Co00001?ooool3o`0000Sooooo0_l000000ooooooo0000o`00
0002ooooo`;o00003Oooool6o`0000Kooooo0_l00002ooooo`Wo00001_ooool2o`0000Cooooo0_l0
0004ooooo`;o00001_ooool2o`0000[ooooo0_l00003ooooo`?o00003oooool2o`0000;ooooo0ol0
0006ooooo`;o0000Hoooool001cooooo00?o0000ooooooooool0FOooool4o`0000Cooooo0_l00006
ooooo`Oo00000_ooool2o`0000oooooo1ol00003ooooo`;o00001?ooool3o`0000;ooooo0_l00006
ooooo`?o00000_ooool2o`0000[ooooo1Ol0000?ooooo`?o00003oooool3o`0000;ooooo0_l00006
ooooo`?o0000H_ooool001cooooo00?o0000ooooooooool0Foooool2o`0000cooooo1ol0000Foooo
o`Oo00001_ooool2o`0000_ooooo1ol00005ooooo`Wo00004?ooool2o`00017ooooo1_l00006oooo
o`?o0000H_ooool001cooooo00?o0000ooooooooool0DOooool2o`0000[ooooo0ol00007ooooo`;o
00007Oooool3o`000003ooooool0003o000000?o00001?ooool2o`000003ooooool0003o000000;o
oooo0_l00006ooooo`?o00001oooool9o`0000Wooooo0_l00005ooooo`;o00004_ooool3o`0000Wo
oooo0_l0001Rooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o00001_ooool2o`0000;ooooo
0ol00007ooooo`;o00007Oooool6o`000003ooooool0003o000000?o00001?ooool2o`0000;ooooo
0_l00006ooooo`Go00001Oooool7o`0000_ooooo0_l00004ooooo`;o00004oooool3o`0000;ooooo
0_l00005ooooo`;o0000H_ooool001cooooo00?o0000ooooooooool0D?ooool2o`0000Oooooo0_l0
000]ooooo`ko00003?ooool7o`000004ooooool0003o0000o`0000;ooooo0_l0000Cooooo`;o0000
3oooool2o`0000;ooooo0ol00002ooooo`;o0000JOooool001cooooo00?o0000ooooooooool0Cooo
ool3o`0000Oooooo0_l000000ooooooo0000o`000002ooooo`;o00009oooool5o`0000?ooooo1Ol0
000>ooooo`Go000000Coooooo`000?l0003o00000_ooool4o`0002;ooooo0ol00002ooooo`;o0000
0_ooool2o`0006Wooooo000Looooo`03o`000?oooooooooo04oooooo0_l00005ooooo`;o00001?oo
ool2o`0000;ooooo0_l0000Xooooo`Co00002Oooool3o`0000cooooo0ol000000ooooooo0000o`00
0003ooooo`Co00004Oooool2o`00013ooooo2?l0001[ooooo`007?ooool00ol0003oooooooooo`1F
ooooo`;o0000=?ooool9o`000003ooooool0003o000000;o00003Oooool5o`0000?ooooo0_l0000C
ooooo`;o00002oooool2o`000003ooooool0003o000000So0000Joooool001cooooo00?o0000oooo
ooooool0E_ooool2o`0001Wooooo0_l00005ooooo`;o00000_ooool2o`0000oooooo2?l000000ooo
oooo0000o`000006ooooo`;o00001oooool4o`0000?ooooo0_l0000:ooooo`;o00002?ooool2o`00
00Oooooo0_l00002ooooo`ko0000J_ooool001cooooo0_l0001:ooooo`?o00001oooool2o`0001Go
oooo0_l00005ooooo`;o00001Oooool2o`0000;ooooo0_l0000@ooooo`;o000000?oooooo`000?l0
00002oooool2o`0000Oooooo0ol00003ooooo`?o00002_ooool2o`0000cooooo0ol00002oooooaCo
0000J?ooool001cooooo00?o0000ooooooooool0Aoooool5o`0000Kooooo0ol0000Eooooo`;o0000
2?ooool2o`0000Gooooo0_l00004ooooo`;o00002oooool2o`0000cooooo1?l00008ooooo`;o0000
0oooool2o`0001Wooooo0ol00003oooooa?o0000J?ooool001cooooo00?o0000ooooooooool0Aooo
ool2o`0000Sooooo0ol0000Kooooo`;o00000oooool2o`0000Gooooo0_l00003ooooo`Go00005?oo
ool7o`000003ooooool0003o000000cooooo0_l00008ooooo`Co00001Oooool2o`0000Cooooo0ol0
0002oooooa;o00001_ooool4o`00063ooooo000Looooo`03o`000?oooooooooo04cooooo0_l00003
ooooo`;o00007?ooool2o`0000oooooo0_l000000ooooooo0000o`00000Dooooo`Go00000oooool3
o`0000Wooooo1?l00008ooooo`Co00001?ooool3o`0000Oooooo5_l00004ooooo`Go0000Goooool0
01cooooo00?o0000ooooooooool0C?ooool2o`0003Sooooo0_l0000Booooo`Co00001?ooool2o`00
00Cooooo0_l00003ooooo`;o00002_ooool3o`0000Cooooo0ol00002ooooo`;o00000_oooolEo`00
0003ooooool0003o000000Kooooo0ol0001Oooooo`007?ooool00ol0003oooooooooo`1Wooooo`;o
00007Oooool2o`0000_ooooo0_l00007ooooo`;o00001oooool2o`000003ooooool0003o000000?o
oooo0_l0000;ooooo`;o00001?ooool3o`0000;ooooo0_l00002oooooaOo0000JOooool001cooooo
00?o0000ooooooooool0I_ooool3o`0001oooooo0_l00009ooooo`?o00002Oooool3o`0000?ooooo
0_l00002ooooo`;o00003oooool2o`0000;ooooo1Ol00006oooooaOo00002?ooool2o`0005oooooo
000Looooo`03o`000?oooooooooo04Cooooo0_l00004ooooo`;o00005oooool2o`000003ooooool0
003o0000023ooooo1?l00008ooooo`;o00002Oooool4o`0000;ooooo1_l0000Cooooo`Go00001_oo
oolDo`0000_ooooo0_l0001Oooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00000oooool3
o`0001Oooooo0_l0000Uooooo`;o00005Oooool2o`0000Cooooo0_l00003ooooo`;o00004Oooool2
o`0000Cooooo0_l000000ooooooo0000o`00000Bo`0006gooooo000Looooo`03o`000?oooooooooo
04?ooooo0_l00004ooooo`;o00005Oooool2o`0002_ooooo0_l00009ooooo`Co00001Oooool2o`00
00Cooooo0_l00003ooooo`;o00005_ooool3o`000003ooooool0003o000001;o000000?oooooo`00
0?l000000_l0000;ooooo`;o0000Foooool001cooooo00?o0000ooooooooool0@oooool2o`0000Go
oooo0ol0000Cooooo`;o000000?oooooo`000?l00000:?ooool2o`0000Wooooo1Ol000000ooooooo
0000o`000007ooooo`;o00000oooool3o`0000[ooooo0_l00002ooooo`;o00001Oooool3o`000003
ooooool0003o000001;o000000?oooooo`000?l000000_l00008ooooo`;o000000?oooooo`000?l0
0000Foooool001cooooo00?o0000ooooooooool0B_ooool3o`0001Kooooo0_l0000fooooo`;o0000
00?oooooo`000?l000002?ooool2o`0000;ooooo0ol0000:ooooo`;o00000_ooool2o`0000Kooooo
0_l000000ooooooo0000o`00000Bo`0000;ooooo0_l00009ooooo`Co0000G?ooool001cooooo00?o
0000ooooooooool0E_ooool2o`0000oooooo0_l0000Dooooo`Go00003Oooool2o`0000gooooo0_l0
0005ooooo`;o000000Coooooo`000?l0003o00003Oooool2o`0000Gooooo0_l00005oooooaGo0000
0oooool2o`0000_ooooo0_l0001Looooo`007?ooool00ol0003oooooooooo`18ooooo`;o00003?oo
ool2o`0000oooooo0_l0000Aooooo`_o00002_ooool2o`0000gooooo1?l00003ooooo`;o00000_oo
ool2o`0000gooooo0_l00005ooooo`;o00001Oooool7o`000003ooooool0003o000000[o00001?oo
ool2o`0000oooooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`18ooooo`;o00003?ooool2
o`0000Sooooo0_l0000Dooooo`oo000000Coooooo`000?l0003o00005oooool7o`0001Kooooo0_l0
0005oooooa?o000000?oooooo`000?l000001?ooool2o`0000oooooo0_l0001Hooooo`007?ooool0
0ol0003oooooooooo`17ooooo`;o00003Oooool2o`0000;ooooo0_l00004ooooo`;o000000?ooooo
o`000?l000003Oooool8o`0000Gooooo0ol00004ooooo`Go00005Oooool9o`0000;ooooo0_l0000@
ooooo`Co00000oooool2o`0000?ooooo3_l00002ooooo`;o0000K_ooool001cooooo0_l00018oooo
o`;o00002Oooool2o`0000Kooooo0_l00005ooooo`Co00002oooool7o`0000Wooooo0ol00004oooo
o`Co00005Oooool2o`000003ooooool0003o000000Co00000_ooool2o`00017ooooo1_l00003oooo
oa3o00000_ooool2o`0001Cooooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`10ooooo`;o
00001?ooool2o`0000[ooooo0_l00005ooooo`;o00001_ooool2o`0000_ooooo3?l000000ooooooo
0000o`000004ooooo`;o00001_ooool4o`0001Kooooo1?l00003ooooo`?o00004Oooool6o`0000?o
oooo0ol000000ooooooo0000o`00000;o`0001Oooooo0ol0001Gooooo`007?ooool00ol0003ooooo
ooooo`0kooooo`;o00000oooool2o`0000?ooooo0ol0000Aooooo`;o00001oooool2o`0000Oooooo
0_l000000ooooooo0000o`000002ooooo`co00002oooool4o`0001Kooooo1?l00003ooooo`?o0000
00?oooooo`000?l000006?ooool2o`000003ooooool0003o000000_o00004?ooool2o`0000Kooooo
0_l0001Gooooo`007?ooool00ol0003oooooooooo`0jooooo`?o000000Coooooo`000?l0003o0000
0oooool3o`0001_ooooo0ol00006ooooo`;o00000oooool6o`000003ooooool0003o000000So0000
00?oooooo`000?l000001Oooool6o`0001?ooooo1_l00006ooooo`;o00001oooool2o`0001?ooooo
1_l00002ooooo`?o00004Oooool2o`0000[ooooo0_l0001Cooooo`007?ooool00ol0003ooooooooo
o`0jooooo`;o00000_ooool3o`0000;ooooo1?l0000?ooooo`;o00000oooool2o`0000Kooooo0_l0
0004ooooo`;o00000oooool8o`000003ooooool0003o000000go00000oooool7o`0001;ooooo1_l0
0002ooooo`;o00002_ooool3o`0000Sooooo0_l00005ooooo`;o00001_ooool2o`0000;ooooo0_l0
000Nooooo`;o0000Doooool001cooooo00?o0000ooooooooool0@_ooool5o`0000_ooooo1_l00003
ooooo`;o000000?oooooo`000?l000001Oooool2o`000004ooooool0003o0000o`0000?ooooo0_l0
00000ooooooo0000o`00000:o`000003ooooool0003o000000Oo00001?ooool6o`00013ooooo2?l0
00000ooooooo0000o`00000:ooooo`;o00001?ooool2o`0000;ooooo0ol00005ooooo`;o00001Ooo
ool4o`000003ooooool0003o000000Gooooo0_l0001/ooooo`007?ooool00ol0003oooooooooo`12
ooooo`;o00003Oooool5o`0000Sooooo0_l000000ooooooo0000o`000002ooooo`;o000000?ooooo
o`000?l000000_ooool4o`000003ooooool0003o000000Wo00000_ooool;o`0000Cooooo1Ol0000>
ooooo`Wo00003oooool2o`0000;ooooo0_l00002ooooo`Co00001Oooool4o`0000;ooooo1?l00000
0ooooooo0000o`000005ooooo`;o0000K?ooool001cooooo00?o0000ooooooooool0=_ooool2o`00
00Gooooo0_l00003ooooo`;o00003Oooool2o`0000_ooooo0_l000000ooooooo0000o`000002oooo
o`;o000000?oooooo`000?l000000_oooolOo`0000;ooooo1Ol0000>ooooo`Go00000_ooool2o`00
00oooooo0_l00006ooooo`Co00001Oooool4o`0002?ooooo0_l0001Gooooo`007?ooool00ol0003o
ooooooooo`0fooooo`;o00001Oooool2o`0001?ooooo0_l0000:ooooo`;o00001Oooool2o`0000Co
oooo7?l000001?oooooo0000o`000?l00002ooooo`Go00001?ooool2o`0000Oooooo0_l000000ooo
oooo0000o`000009ooooo`;o00004Oooool5o`0000Gooooo0_l00007ooooo`;o00006oooool2o`00
05Oooooo000Looooo`03o`000?oooooooooo03oooooo0_l0000>ooooo`;o000000?oooooo`000?l0
00000oooool2o`0000Gooooo1?l00009ooooo`oo000000?oooooo`000?l000003_l000000ooooooo
0000o`000002ooooo`Go000000Coooooo`000?l0003o00001_ooool2o`000003ooooool0003o0000
00Cooooo0_l00002ooooo`?o00005?ooool2o`0000Gooooo0_l00007ooooo`;o0000M?ooool001co
oooo00?o0000ooooooooool0=oooool4o`0000Cooooo0_l0000<ooooo`Co00001_ooool2o`0000Ko
oooo0ol00008ooooo`;o00000oooool;o`0000?ooooo4ol000000ooooooo0000o`000002o`0000;o
oooo0_l00009ooooo`?o00000oooool2o`000004ooooool0003o0000o`0001Oooooo0_l0000/oooo
o`;o0000E?ooool001cooooo00?o0000ooooooooool0<oooool2o`0000;ooooo1?l00002ooooo`;o
00003_ooool2o`0000Gooooo0_l00006ooooo`;o00001_ooool2o`000004ooooool0003o0000oooo
o`?o000000?oooooo`000?l000001?l000000ooooooo0000o`000003o`000003ooooool0003o0000
013o000000Coooooo`000?l0003ooooo1?l00002ooooo`;o00002_ooool;o`0001Kooooo0ol00007
ooooo`;o000000?oooooo`000?l000001?ooool2o`0001[ooooo0_l0001Dooooo`007?ooool00ol0
003oooooooooo`0cooooo`;o00002?ooool3o`0001Cooooo0_l000000ooooooo0000o`000003oooo
o`;o00001Oooool3o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000004o`00
0003ooooool0003o000000Oo000000?oooooo`000?l000003?l00004ooooo`;o00001?ooool2o`00
00Wooooo1_l00002ooooo`Co00003?ooool2o`0000Sooooo0ol000001?oooooo0000o`000?l00003
ooooo`;o000000?oooooo`000?l000001?ooool2o`00073ooooo000Looooo`03o`000?oooooooooo
03;ooooo0_l00009ooooo`?o00005oooool2o`0000Cooooo0_l00004ooooo`;o00001Oooool9o`00
0003ooooool0003o000000go000000?oooooo`000?l000002?l00003ooooo`Go000000?oooooo`00
0?l000002Oooool4o`0000Cooooo0_l0000;ooooo`;o000000?oooooo`000?l000002oooool4o`00
00Oooooo0_l0000Sooooo`;o0000D?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2
ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo03;ooooo0_l00008
ooooo`?o00001Oooool2o`0000oooooo0_l00006ooooo`;o00000oooool2o`0000Kooooo8?l00000
1?oooooo0000o`000?l00004ooooo`Co000000?oooooo`000?l000002?ooool2o`000003ooooool0
003o000000Cooooo0_l0000;ooooo`;o00002?ooool2o`0000Cooooo0ol00008ooooo`;o00008ooo
ool2o`00053ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0??ooool2o`0000Gooooo0ol0000?ooooo`;o0000
2oooool2o`0000Sooooo6ol000000ooooooo0000o`000004o`0000Gooooo0_l00002ooooo`;o0000
2?ooool3o`0000?ooooo0_l0000Booooo`;o00001?ooool2o`0000Kooooo0_l00003ooooo`;o0000
1oooool2o`00073ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo1Ol0
0006ooooo`03o`000?oooooooooo04?ooooo0_l0000;ooooo`;o000000?oooooo`000?l000000_l0
000;ooooo`;o00001?ooool8o`000003ooooool0003o000001co00000oooool3o`0000;ooooo0_l0
0009ooooo`Co000000?oooooo`000?l000004_ooool2o`0000Kooooo0_l00004ooooo`;o00000ooo
ool4o`0000Gooooo0_l0001`ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09
ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol00015ooooo`;o00002Oooool2o`000003ooooool0
003o000000;o00001?ooool2o`0000Sooooo0_l000000ooooooo0000o`000002o`000003ooooool0
003o0000027o00000_ooool4o`000003ooooool0003o000000;o00002Oooool2o`00017ooooo0_l0
00000ooooooo0000o`000002o`0000Gooooo0_l0000;ooooo`;o00003?ooool2o`0001[ooooo0_l0
001=ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGo
ooooo`0000Oooooo00?o0000ooooooooool0=?ooool2o`0000oooooo0_l0000:ooooo`?o00001?oo
ool2o`000003ooooool0003o000000Sooooo0_l00002ooooo`?o00000_oooolRo`0000;ooooo1?l0
00000ooooooo0000o`000002o`0000Kooooo0_l00004ooooo`;o000000?oooooo`000?l000002ooo
ool2o`000003ooooool0003o000000;o00008?ooool2o`0001[ooooo0_l0001=ooooo`0000?ooooo
oa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000
ooooooooool0=?ooool2o`0001_ooooo1Ol00002ooooo`;o00002?ooool2o`0000Gooooo0_l00003
ooooob;o00000_ooool3o`0000;ooooo0_l00008ooooo`Co00000_ooool2o`000003ooooool0003o
000002Kooooo0_l00005ooooo`;o0000K_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg3?oo
ool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo04Sooooo0_l00007ooooo`Go000000?o
ooooo`000?l000002Oooool2o`0000Gooooo0_l00003oooooaco000000?oooooo`000?l000000_l0
0003ooooo`?o00000_ooool2o`0000[ooooo0_l0000]ooooo`Co00000oooool2o`0006kooooo0000
1_ooooook^k^oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooo
ooooo`18ooooo`?o00001?ooool2o`000003ooooool0003o000000;ooooo0ol00009ooooo`;o0000
0oooool2o`0000Gooooo8Ol000001?oooooo0000o`000?ooool2o`0000oooooo0_l0000Hooooo`;o
00003_ooool2o`0000Cooooo0_l00003ooooo`;o00002Oooool2o`0006?ooooo000Looooo`03o`00
0?oooooooooo04Wooooo0_l00004ooooo`;o00000_ooool2o`000003ooooool0003o000000;o0000
1Oooool2o`000003ooooool0003o000000;o000000Coooooo`000?l0003o00001?oooolPo`0000;o
oooo0_l000001?oooooo0000o`000?l0000<ooooo`Go00005oooool2o`0000kooooo0_l00009oooo
o`;o00002Oooool2o`0006?ooooo000Looooo`03o`000?oooooooooo02gooooo0_l0000Eooooo`;o
00000oooool2o`0000Gooooo0_l000000ooooooo0000o`000003ooooo`;o00001Oooool7o`0000;o
oooo0_l00004ooooob3o00001Oooool3o`0000cooooo1Ol00004ooooo`;o0000:Oooool2o`000003
ooooool0003o000006kooooo000Looooo`03o`000?oooooooooo02_ooooo1?l0000Eooooo`;o0000
2_ooool2o`0000_ooooo0_l00002ooooo`;o00001?ooool2o`000003ooooool0003o000000;ooooo
1_l000000ooooooo0000o`00000Ho`000004ooooool0003o0000ooooo`;o00003_ooool4o`0000Co
oooo0_l0000?ooooo`;o00006?ooool2o`00077ooooo000Looooo`03o`000?oooooooooo02_ooooo
0_l0000Wooooo`Go00001?ooool2o`0000Oooooo0ol000001Ooooooo0000o`000?l0003ooooo027o
000000?oooooo`000?l000000ol0000?ooooo`;o00000_ooool3o`00017ooooo0_l0000:ooooo`;o
00005?ooool2o`0006Wooooo000Looooo`03o`000?oooooooooo03;ooooo0ol0000Looooo`;o0000
00?oooooo`000?l000000ol0000:ooooo`;o000000Goooooo`000?l0003o0000ooooo`03o`000003
ooooool0003o000001oo000000?oooooo`000?l000000ol0000>ooooo`Co000000Goooooo`000?l0
003o0000ooooo`02o`0001?ooooo0_l00005ooooo`;o00004oooool5o`0006Oooooo000Looooo`03
o`000?oooooooooo037ooooo1?l0000Hooooo`;o00000_ooool2o`0000Kooooo0_l00004ooooo`?o
000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000;ooooo1?l000000ooooooo
0000o`00000Jo`000003ooooool0003o000000;o00003Oooool6o`000004ooooool0003o0000oooo
o`?o00004oooool2o`0000cooooo0_l00002ooooo`;o00001Oooool2o`000003ooooool0003o0000
00?o0000Ioooool001cooooo00?o0000ooooooooool0<Oooool4o`0001Sooooo0_l0000:ooooo`;o
00000_ooool5o`0000;ooooo0_l00002ooooo`?o000000Coooooo`000?l0003ooooo8?l00003oooo
o`?o00000_ooool2o`0000Sooooo0ol00003ooooo`?o000000?oooooo`000?l000008_ooool2o`00
0004ooooool0003o0000o`0000Gooooo0_l00002ooooo`;o0000JOooool001cooooo00?o0000oooo
ooooool0<Oooool4o`0001Oooooo0_l0000?ooooo`;o000000?oooooo`000?l000000_ooool2o`00
00;ooooo0ol000001?oooooo0000o`000?oooolMo`000003ooooool0003o000000?ooooo0ol00002
ooooo`;o00001_ooool2o`0000?ooooo0_l000000ooooooo0000o`00000=ooooo`;o00002_ooool2
o`0000kooooo0_l00008ooooo`;o00000_ooool6o`0006?ooooo000Looooo`03o`000?oooooooooo
037ooooo0_l0000Iooooo`;o00000_ooool2o`0000kooooo1?l000000ooooooo0000o`000008oooo
oako00000oooool5o`0000[ooooo0_l00002ooooo`?o00000_ooool2o`0000cooooo0ol000000ooo
oooo0000o`000006ooooo`;o00001Oooool2o`0000Oooooo0_l00005ooooo`go0000Hoooool001co
oooo00?o0000ooooooooool0D?ooool2o`00013ooooo1Ol00002ooooo`?o00000ooooolNo`0000?o
oooo1?l0000<ooooo`;o000000Coooooo`000?l0003ooooo1?l0000=ooooo`;o000000?oooooo`00
0?l000001_ooool2o`0000Gooooo0_l00004ooooo`;o00002?ooool4o`000003ooooool0003o0000
00Go00003?ooool2o`0005Kooooo000Looooo`03o`000?oooooooooo03gooooo0_l0000;ooooo`;o
000000Coooooo`000?l0003ooooo0_l0000Booooo`;o00000ooooolOo`000003ooooool0003o0000
00;o00000_ooool2o`000004ooooool0003o0000ooooo`;o00002Oooool4o`0000;ooooo0_l00003
ooooo`?o00003?ooool2o`0000Oooooo0ol00009ooooo`;o00001Oooool2o`000003ooooool0003o
000000co00002_ooool2o`0005Kooooo000Looooo`;o0000?_ooool2o`0000_ooooo0_l000000ooo
oooo0000o`00000Fooooo`;o00001?ooool7o`000003ooooool0003o000001?o00000_ooool3o`00
00;ooooo0_l00004ooooo`;o00002Oooool4o`0000;ooooo0_l00003ooooo`?o00002?ooool2o`00
00[ooooo1?l00008ooooo`?o00000_ooool2o`000003ooooool0003o0000017o00002oooool2o`00
05?ooooo000Looooo`03o`000?oooooooooo03kooooo0ol0000Tooooo`;o00001?ooool2o`0000Ko
oooo4ol000000ooooooo0000o`000003o`0000;ooooo0_l000000ooooooo0000o`00000:ooooo`Ko
00000_ooool2o`0000oooooo0_l0000:ooooo`;o00002_ooool3o`0000;ooooo0_l000001?oooooo
0000o`000?l00002ooooo`Go000000?oooooo`000?l000002Ol00004ooooo`;o00000_ooool2o`00
05?ooooo000Looooo`03o`000?oooooooooo03?ooooo0_l00009ooooo`?o00002Oooool2o`0001So
oooo0_l00007ooooo`Co00000_oooolIo`0000;ooooo1Ol0000:ooooo`Ko00000_ooool2o`0000Co
oooo0_l0000Dooooo`;o00004?ooool7o`000003ooooool0003o000000_o000000Coooooo`000?l0
003o00001?ooool2o`0005Oooooo000Looooo`03o`000?oooooooooo037ooooo1?l0000:ooooo`;o
00002Oooool2o`0001Sooooo0_l00007ooooo`Co000000?oooooo`000?l000004ol000001?oooooo
0000o`000?l00004ooooo`?o000000?oooooo`000?l000002_ooool2o`0000?ooooo0_l00005oooo
o`;o00005?ooool2o`0000kooooo6ol0001Mooooo`007?ooool00ol0003oooooooooo`0aooooo`;o
00002_ooool2o`0002Oooooo0_l00006ooooo`;o00000_oooolHo`0000Gooooo0_l00002ooooo`;o
00002_ooool2o`0000?ooooo0_l0000;ooooo`;o00001_ooool2o`0001Gooooo3ol000000ooooooo
0000o`000008o`000003ooooool0003o000005cooooo000Looooo`03o`000?oooooooooo02gooooo
0ol000000ooooooo0000o`00000:ooooo`;o00009oooool2o`0000Sooooo1Ol00007ooooo`go0000
1oooool3o`0000Wooooo0_l00007ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo
0_l00006ooooo`?o00001?ooool2o`0000kooooo3_l000000ooooooo0000o`000008o`0000;ooooo
0_l00005ooooo`;o0000EOooool001cooooo00?o0000ooooooooool0:?ooool2o`0000?ooooo0ol0
000dooooo`;o00002_ooool5o`000005ooooool0003o0000o`000?ooool00ol00003ooooo`;o0000
0_ooool3o`0000?ooooo1?l00002ooooo`?o00002Oooool2o`0000;ooooo0_l00003ooooo`;o0000
0oooool5o`0000Kooooo0_l00003ooooo`;o00001?ooool2o`0000kooooo6ol00007ooooo`;o0000
EOooool001cooooo00?o0000ooooooooool0:?ooool2o`0000Kooooo0ol00002ooooo`;o00000ooo
ool2o`0001oooooo0_l00007ooooo`;o00000oooool3o`0000Oooooo1_l000000ooooooo0000o`00
0003o`000003ooooool0003o000000;ooooo0_l000001?oooooo0000o`000?ooool4o`0000kooooo
0_l000001?oooooo0000o`000?l00004ooooo`;o00000oooool2o`0000Sooooo0_l00008ooooo`;o
00000_ooool2o`0000_ooooo6ol00007ooooo`Co0000Doooool001cooooo00?o0000ooooooooool0
<?ooool3o`0000;ooooo0_l00003ooooo`;o00003Oooool2o`0000oooooo1?l0000;ooooo`?o0000
2?ooool4o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000Cooooo1_l00002ooooo`;o
00003?ooool5o`0000Gooooo1?l0000;ooooo`?o00001oooool2o`0000;ooooo0_l0000<oooooaWo
00002_ooool2o`0005?ooooo000Looooo`03o`000?oooooooooo033ooooo0_l000000ooooooo0000
o`00000Dooooo`;o00003_ooool6o`0000[ooooo0_l00009ooooo`Co00000_ooool2o`000003oooo
ool0003o000000?ooooo0ol000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000;o
00003Oooool3o`0000Kooooo1?l0000<ooooo`;o00003?ooool2o`0000cooooo6Ol00009ooooo`;o
0000Doooool001cooooo00?o0000ooooooooool09_ooool2o`0000Cooooo0_l00004ooooo`?o0000
2Oooool2o`0000Sooooo1?l0000=ooooo`?o000000Coooooo`000?l0003o00001oooool2o`000003
ooooool0003o000000Sooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000000?o
00001?ooool2o`000003ooooool0003o000000;o00005_ooool2o`0000;ooooo1?l00003ooooo`;o
00004Oooool2o`0000Sooooo0_l000000ooooooo0000o`00000Ao`000003ooooool0003o000000Co
00002Oooool2o`0005?ooooo000Looooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`;o0000
1?ooool2o`0000;ooooo0_l00006ooooo`;o00002?ooool4o`00013ooooo1_l00005ooooo`Go0000
00?oooooo`000?l000002Oooool2o`0000Kooooo0_l00007ooooo`?o00000_ooool2o`0001[ooooo
1?l00003ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Oooooo0_l00004ooooo`;o0000
00?oooooo`000?l000006?l0001Nooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00001?oo
ool2o`0002;ooooo1?l000001?oooooo0000o`000?l00006ooooo`;o00000oooool2o`0000oooooo
0ol000000ooooooo0000o`000006ooooo`?o00006_ooool3o`0000[ooooo0_l00008ooooo`?o0000
1oooool2o`0000Sooooo6_l0001Mooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o000000?o
ooooo`000?l000000_l0000?ooooo`;o00004_ooool2o`0000Gooooo0_l00009ooooo`;o00000ooo
ool3o`0000[ooooo0ol000000ooooooo0000o`000007ooooo`;o00006?ooool8o`00017ooooo0_l0
000=ooooo`;o00000ooooolLo`0005_ooooo000Looooo`03o`000?oooooooooo03?ooooo1?l0000?
ooooo`;o00004_ooool2o`0000Gooooo0ol00008ooooo`;o00000oooool3o`0000_ooooo0_l00006
ooooo`;o00007?ooool2o`0000?ooooo0ol0000Pooooo`;o000000?oooooo`000?l000007_l00002
ooooo`;o0000EOooool001cooooo00?o0000ooooooooool0<oooool3o`0000;ooooo0_l0000=oooo
o`;o00006Oooool3o`0000cooooo0_l0000=ooooo`;o00001Oooool2o`00027ooooo0ol0000Loooo
o`?o00001?oooolPo`0000;ooooo0_l0000Hooooo`;o0000>oooool001cooooo0_l0000eooooo`;o
00000_ooool2o`0000Kooooo0_l00005ooooo`;o00004_ooool2o`0000Kooooo0ol0000Hooooo`Co
0000:?ooool4o`0000cooooo0_l0000=ooooo`Go000000?oooooo`000?l000000_oooolJo`0001oo
oooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0_ooooo`?o00003_ooool2o`0000Kooooo
0_l0000Aooooo`;o00001oooool4o`0001Cooooo1?l0000Sooooo`;o00001_ooool3o`000003oooo
ool0003o000000;o00001oooool2o`0000gooooo0_l000001?oooooo0000o`000?ooool2o`000003
ooooool0003o000001Wo00007oooool2o`0003_ooooo000Looooo`03o`000?oooooooooo02oooooo
1Ol00009ooooo`;o00002Oooool2o`0001_ooooo0ol0000Aooooo`;o000000?oooooo`000?l00000
0_l0000Qooooo`Co000000Coooooo`000?l0003ooooo0_l00004ooooo`go00003?ooool3o`0000Go
oooo7?l000000ooooooo0000o`000009ooooo`;o00004_ooool2o`0003_ooooo000Looooo`03o`00
0?oooooooooo03;ooooo0_l00009ooooo`;o00002?ooool3o`0002oooooo0_l000000ooooooo0000
o`000002o`0000Cooooo0_l0000Jooooo`?o00000oooool5o`0000Cooooo3Ol0000<ooooo`;o0000
1_ooool7o`0000;ooooo4?l000001?oooooo0000o`000?ooool2o`0000Wooooo0_l0000Booooo`;o
0000>oooool001cooooo00?o0000ooooooooool0?Oooool3o`0000Oooooo0ol0000booooo`;o0000
0_ooool2o`0000;ooooo0_l0000Jooooo`;o00000oooool2o`000004ooooool0003o0000o`0000Co
oooo2?l000001?oooooo0000o`000?l0000@ooooo`;o00000oooool8o`000003ooooool0003o0000
00ko00000oooool2o`0005_ooooo000Looooo`03o`000?oooooooooo033ooooo0_l0000;ooooo`?o
0000??ooool2o`0000;ooooo0_l00003ooooo`;o00007Oooool3o`000003ooooool0003o000000So
oooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000kooooo0_l00006ooooo`Ko
000000?oooooo`000?l000003?l00004ooooo`;o000000?oooooo`000?l000003_ooool2o`0004So
oooo000Looooo`03o`000?oooooooooo02cooooo0ol000000ooooooo0000o`00000Aooooo`;o0000
:_ooool2o`0000_ooooo0_l00002ooooo`;o00000oooool2o`0001gooooo1?l0000=ooooo`Co0000
0_ooool2o`0001Sooooo4ol00007ooooo`;o00003_ooool2o`0004Sooooo000Looooo`03o`000?oo
oooooooo02cooooo0ol0000Dooooo`;o00009?ooool2o`0000Cooooo0_l0000:ooooo`Go00002_oo
ool2o`0001[ooooo1_l00009ooooo`?o00000oooool2o`0001Oooooo4ol0000Hooooo`Co00002?oo
ool2o`0003cooooo000Looooo`03o`000?oooooooooo037ooooo0_l00002ooooo`;o00002?ooool4
o`0002Kooooo0_l00006ooooo`?o00001_ooool6o`000003ooooool0003o000000Gooooo1?l0000G
ooooo`Co000000?oooooo`000?l000001?l000000ooooooo0000o`000004ooooo`;o00007Oooool6
o`000003ooooool0003o000000So00001?ooool4o`0001?ooooo0ol00002ooooo`;o00001?ooool2
o`0003cooooo000Looooo`03o`000?oooooooooo037ooooo0_l000001?oooooo0000o`000?l00008
ooooo`Co00001Oooool2o`0002Gooooo1Ol00006ooooo`?o00000_ooool4o`000003ooooool0003o
000000;ooooo0_l00002ooooo`;o00005Oooool4o`0000?ooooo1?l000000ooooooo0000o`000003
ooooo`?o00000_ooool3o`0000kooooo0_l00008ooooo`;o00001?ooool2o`000003ooooool0003o
000000Go000000?oooooo`000?l000000_ooool4o`0000gooooo0_l00004ooooo`?o00000_ooool2
o`0000Cooooo0_l0000Gooooo`;o00008oooool001cooooo00?o0000ooooooooool0=?ooool2o`00
01;ooooo0_l0000Iooooo`Go00001oooool3o`0000Gooooo0_l00006ooooo`Co000000?oooooo`00
0?l000000_ooool2o`0000;ooooo2?l00008ooooo`;o00004Oooool2o`0000;ooooo0ol00003oooo
o`?o00003_ooool2o`0000Sooooo0_l00004ooooo`;o000000?oooooo`000?l000001?l00002oooo
o`?o000000?oooooo`000?l000000_l0000=ooooo`;o00001Oooool2o`00027ooooo0_l0000Soooo
o`007?ooool00ol0003oooooooooo`0booooo`;o00004?ooool2o`0000;ooooo0_l0000Gooooo`Oo
00002?ooool2o`0000Gooooo0ol0000>ooooo`;o00001?ooool6o`0000Gooooo0_l000000ooooooo
0000o`000004o`0000Gooooo0_l0000:ooooo`?o00001?ooool2o`0000oooooo0ol00006ooooo`;o
00002Oooool4o`0000;ooooo0ol000000ooooooo0000o`000002o`0000gooooo0_l0000>ooooo`;o
00006?ooool2o`0002?ooooo000Looooo`03o`000?oooooooooo02gooooo0_l00003ooooo`;o0000
2_ooool2o`0000Cooooo0_l00002ooooo`;o00005oooool2o`000003ooooool0003o000001;ooooo
0_l0000;ooooo`;o00001_ooool2o`0000?ooooo0_l00005ooooo`?o00000_ooool6o`0000;ooooo
0ol0000:ooooo`?o00005Oooool3o`0000oooooo1_l00002ooooo`;o00002Oooool2o`0001Sooooo
0_l0000mooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o000000?oooooo`000?l000000_l0
000:ooooo`;o0000AOooool2o`0000Kooooo0_l000000ooooooo0000o`000002o`000003ooooool0
003o000000?ooooo0_l00004ooooo`Co00000_ooool2o`0000Kooooo0_l00003ooooo`?o00006?oo
ool2o`0000;ooooo0_l00008ooooo`So00002oooool3o`0001Sooooo0_l0000mooooo`007?ooool0
0ol0003oooooooooo`0`ooooo`Co00001oooool2o`0000Sooooo0_l00019ooooo`;o00000oooool2
o`0000cooooo0_l000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l000000ol00004
ooooo`;o00004_ooool2o`0000;ooooo0_l00008ooooo`;o00000oooool3o`0000?ooooo0_l00006
ooooo`;o00000oooool2o`0001Cooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0^oooo
o`Co00002Oooool2o`0000Sooooo0_l0000Sooooo`;o00002_ooool2o`0000Oooooo0ol0000Ioooo
o`;o00001_ooool2o`0000_ooooo0ol000000ooooooo0000o`000004ooooo`;o00004?ooool2o`00
01;ooooo0_l00002ooooo`;o000000?oooooo`000?l000002oooool2o`0005?ooooo000Looooo`;o
0000;oooool4o`0000Cooooo0_l00003ooooo`;o00001_ooool4o`0000Cooooo0_l0000Mooooo`;o
000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000Oooooo0ol00008ooooo`;o
00001?ooool2o`0000Wooooo0_l00003ooooo`;o00003_ooool2o`0000;ooooo0ol0000Eooooo`;o
00000_ooool2o`0000Cooooo0_l00008ooooo`;o00000_ooool2o`0002;ooooo0_l0000oooooo`00
7?ooool00ol0003oooooooooo`0^ooooo`;o00001_ooool2o`0000;ooooo0_l00004ooooo`;o0000
00?oooooo`000?l000001_ooool2o`00023ooooo0_l00004ooooo`Go00001Oooool7o`0000Kooooo
0_l00004ooooo`;o000000?oooooo`000?l000001_ooool2o`0000?ooooo0_l00008ooooo`;o0000
2Oooool2o`0000?ooooo0_l0000@ooooo`;o00000_ooool2o`0000Cooooo1?l0000Aooooo`;o0000
6oooool2o`0003oooooo000Looooo`03o`000?oooooooooo037ooooo0_l00004ooooo`;o000000?o
ooooo`000?l000001?ooool2o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000008_oo
ool2o`000003ooooool0003o000000?o00001Oooool7o`0000oooooo0_l00005ooooo`;o00001Ooo
ool2o`0000Oooooo0_l00009ooooo`;o00000oooool2o`0001Cooooo0_l00005ooooo`Go00002ooo
ool2o`0000;ooooo0_l0000Iooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0<Oooool2
o`000004ooooool0003o0000ooooo`?o00002Oooool4o`0000;ooooo0_l000000ooooooo0000o`00
000Mooooo`?o00000_ooool2o`000003ooooool0003o000000_ooooo0_l0000Hooooo`?o00001?oo
ool3o`0000oooooo1?l00002ooooo`;o00005Oooool2o`0000Gooooo0_l000000ooooooo0000o`00
000;ooooo`;o00007Oooool2o`00047ooooo000Looooo`03o`000?oooooooooo03Cooooo0_l00002
ooooo`Co00001oooool2o`0002Kooooo1ol0000<ooooo`Co00006Oooool2o`0000Cooooo0ol0000?
ooooo`Co00000_ooool4o`0000Wooooo0_l00008ooooo`;o0000Moooool001cooooo00?o0000oooo
ooooool0<oooool2o`0000Gooooo0_l00002ooooo`Co000000?oooooo`000?l000000_l0000Voooo
o`Go000000?oooooo`000?l000001oooool6o`0000_ooooo0_l00003ooooo`;o00000oooool2o`00
00;ooooo0_l00004ooooo`;o00001Oooool2o`00017ooooo0_l00002ooooo`;o00001Oooool2o`00
00?ooooo0_l00003ooooo`;o000000?oooooo`000?l000003_ooool2o`0000;ooooo0_l0000hoooo
o`;o00009_ooool001cooooo00?o0000ooooooooool0<oooool2o`0000Cooooo0_l00003ooooo`Co
00000oooool3o`0002_ooooo0_l00005ooooo`Co00000_ooool2o`0000_ooooo0_l00003ooooo`Co
000000?oooooo`000?l000002?ooool3o`000004ooooool0003o0000ooooo`;o00001_ooool2o`00
0003ooooool0003o000000Gooooo0ol00002ooooo`?o00002Oooool2o`0000;ooooo0_l000001?oo
oooo0000o`000?l0000>ooooo`;o00000_ooool2o`0001oooooo0_l0000Gooooo`;o00009_ooool0
01cooooo00?o0000ooooooooool0<Oooool2o`0000Kooooo0_l0000:ooooo`?o00007Oooool2o`00
00gooooo0_l00004ooooo`;o00000oooool3o`0000oooooo2?l000001Ooooooo0000o`000?l0003o
oooo00Ko000000?oooooo`000?l000000_l00007ooooo`;o000000?oooooo`000?l000000_l00003
ooooo`?o00000oooool2o`0000Sooooo0_l00003ooooo`;o000000Coooooo`000?l0003o00002ooo
ool6o`0002;ooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00001?ooool2
o`0000Gooooo0_l00005ooooo`;o00002Oooool2o`0001?ooooo0_l0000:ooooo`;o000000Cooooo
o`000?l0003o00002?ooool2o`00013ooooo1_l00003ooooo`_o00000_ooool2o`0000?ooooo0_l0
0003ooooo`;o000000Coooooo`000?l0003o00000oooool2o`0000kooooo0_l00003ooooo`;o0000
0_ooool2o`0000Kooooo0_l00003ooooo`Ko0000Hoooool001cooooo00?o0000ooooooooool0<Ooo
ool2o`0000Cooooo1?l00003ooooo`;o00001?ooool3o`0000Wooooo0_l0000Cooooo`?o00002?oo
ool3o`0000;ooooo0_l00007ooooo`?o00003Oooool2o`0000_ooooo2_l00007ooooo`?o00000_oo
ool2o`0001Oooooo0_l00005ooooo`;o00002?ooool5o`0006Wooooo000Looooo`03o`000?oooooo
oooo037ooooo0_l00006ooooo`;o00001?ooool2o`0000?ooooo1Ol00008ooooo`;o00004_ooool3
o`0000Sooooo0_l0000<ooooo`?o00003Oooool2o`0000Sooooo3Ol00008ooooo`;o00003Oooool2
o`0000cooooo0_l00005ooooo`Co000000?oooooo`000?l000001?ooool4o`0002Gooooo0_l00012
ooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00001_ooool2o`0000Cooooo0ol00005oooo
o`;o00002?ooool2o`0001Oooooo1?l0000Zooooo`go00003oooool2o`0000;ooooo0_l000001?oo
oooo0000o`000?l0000Eooooo`;o000000Coooooo`000?l0003o00001Oooool2o`0000[ooooo0_l0
000Iooooo`;o00005oooool2o`0002Wooooo000Looooo`03o`000?oooooooooo043ooooo0_l00005
ooooo`;o00002Oooool2o`0001Kooooo1Ol00005ooooo`;o00008_ooool=o`0000oooooo2Ol0000I
ooooo`Go000000?oooooo`000?l000001?l00008ooooo`;o00006oooool2o`0001Gooooo0_l0000Y
ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00001Oooool3o`0000Cooooo0_l00002oooo
o`;o00005oooool4o`0000Cooooo0ol0000Eooooo`;o00001?ooool2o`0000Gooooo3_l0000?oooo
o`?o000000?oooooo`000?l000000oooool2o`0000Sooooo0_l0000=ooooo`Co000000?oooooo`00
0?l000001?l0000Uooooo`;o0000@?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2
ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo04Gooooo1Ol0
0004ooooo`;o00005_ooool4o`000003ooooool0003o000000Co00000_ooool2o`0000gooooo0_l0
0007ooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`oo00002oooool4o`0000Wooooo
0_l00008ooooo`;o00000_ooool2o`0000?ooooo0_l00004ooooo`;o00001Oooool2o`0006Wooooo
00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRH
V?lQ8B401_ooool00ol0003oooooooooo`0fooooo`;o000000?oooooo`000?l000002_ooool9o`00
01Sooooo1?l000000ooooooo0000o`000004o`0000[ooooo0_l00005ooooo`;o00001oooool2o`00
0003ooooool0003o000000Kooooo3ol0000<ooooo`Co00004oooool3o`000003ooooool0003o0000
00?ooooo0_l00004ooooo`;o00001Oooool2o`0006Wooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
03?ooooo0_l000001?oooooo0000o`000?ooool2o`0000gooooo1_l0000Kooooo`;o000000Cooooo
o`000?l0003o00003?ooool2o`0000Gooooo0_l000001?oooooo0000o`000?l00003ooooo`;o0000
1oooool@o`0000Wooooo0_l000001?oooooo0000o`000?ooool3o`0001;ooooo0ol00007ooooo`;o
00000oooool2o`0000Gooooo0_l0000Uooooo`;o0000@_ooool00003ooooool0003ooooo00;ooooo
00?o0000ooooooooool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0000cooooo`?o
00000oooool2o`0000_ooooo1Ol000000ooooooo0000o`000007ooooo`;o00004_ooool2o`000004
ooooool0003o0000o`0000?ooooo1?l00005ooooo`;o00000_ooool2o`000004ooooool0003o0000
ooooo`?o00002_ooool4o`000003ooooool0003o000000[o00002_ooool2o`000003ooooool0003o
000000;ooooo0_l0000Eooooo`?o00001?ooool2o`0000?ooooo0_l00005ooooo`;o00009Oooool2
o`0001Cooooo0_l0000/ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09oooo
o`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0dooooo`?o00000_ooool2
o`0000Kooooo0_l00003ooooo`Ko00002Oooool2o`00017ooooo0ol000000ooooooo0000o`000008
o`0000Wooooo0_l000001?oooooo0000o`000?ooool2o`0000Kooooo0_l00003ooooo`;o00001?oo
ool:o`0000oooooo0_l0000<ooooo`?o000000?oooooo`000?l000000_l00004ooooo`?o00002_oo
ool2o`000003ooooool0003o000000;ooooo0_l0000jooooo`;o0000;?ooool00003ooooool@413o
oooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooo
oooo03?ooooo1?l0000:ooooo`;o00000oooool2o`0000;ooooo0ol0000Gooooo`;o00000_ooool3
o`0000?ooooo1?l00002ooooo`;o00001Oooool2o`000004ooooool0003o0000o`0000Kooooo1?l0
0002ooooo`;o000000Coooooo`000?l0003o00000oooool3o`000003ooooool0003o000000Co0000
3?ooool2o`0000?ooooo0_l0000;ooooo`Co000000?oooooo`000?l000000_l00007ooooo`;o0000
1_ooool4o`000003ooooool0003o000000;ooooo0_l0001Xooooo`0000KoooooogMgMonHV9Sooooo
oiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0<oooool4o`0000;o
oooo0_l0000?ooooo`Co00001oooool2o`0000gooooo0_l000000ooooooo0000o`000002o`0000_o
oooo0_l00003ooooo`;o000000Coooooo`000?l0003o00001_ooool4o`0000?ooooo1Ol00003oooo
o`?o00004Oooool5o`0000kooooo0ol00004ooooo`;o00002?ooool2o`0000Kooooo0_l00011oooo
o`;o0000;_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@
4106ooooo`03o`000?oooooooooo03Cooooo0ol00002ooooo`;o00001Oooool4o`0000;ooooo0_l0
0003ooooo`?o00000oooool2o`0000;ooooo0_l00009ooooo`;o00001Oooool2o`0000gooooo0_l0
0002ooooo`Co00001Oooool5o`0000;ooooo0_l000001Ooooooo0000o`000?l0003ooooo00Co0000
00?oooooo`000?l000003_ooool2o`0000;ooooo1Ol0000>ooooo`Ko00003Oooool2o`0000Cooooo
0_l00006ooooo`;o0000>Oooool2o`0002kooooo000Looooo`03o`000?oooooooooo03Cooooo0ol0
0009ooooo`Co00000_ooool2o`0000?ooooo1Ol000000ooooooo0000o`000003o`0000[ooooo0_l0
0004ooooo`;o000000?oooooo`000?l000000_l00007ooooo`;o00000oooool5o`0000Cooooo1_l0
00000ooooooo0000o`00000:o`00017ooooo0_l00003ooooo`;o00003oooool7o`0000Kooooo0_l0
0005ooooo`;o00001_ooool2o`0000;ooooo1?l0001Yooooo`007?ooool00ol0003oooooooooo`1;
ooooo`Go00000_ooool6o`0000Sooooo0_l00004ooooo`Oo000000?oooooo`000?l000001?ooool2
o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`Ko000000?oooooo`000?l000002_l0000A
ooooo`Co00003_ooool2o`000004ooooool0003o0000o`0000_ooooo0_l0000=ooooo`;o000000Co
ooooo`000?l0003o0000>Oooool2o`00033ooooo000Looooo`03o`000?oooooooooo03[ooooo0_l0
0005ooooo`;o00001?ooool2o`0000;ooooo0_l00002ooooo`;o00001?ooool3o`0000Sooooo0_l0
00000ooooooo0000o`000002ooooo`;o00001Oooool2o`0000cooooo4Ol000000ooooooo0000o`00
0005o`00017ooooo1?l00005ooooo`;o00001oooool2o`000004ooooool0003o0000ooooo`?o0000
0oooool2o`000003ooooool0003o000000?o00000oooool2o`0000Kooooo0_l000001?oooooo0000
o`000?l0000jooooo`;o0000<?ooool001cooooo00?o0000ooooooooool0>_ooool2o`000003oooo
ool0003o000000;ooooo1?l00002ooooo`?o000000?oooooo`000?l000000_ooool2o`0001;ooooo
1?l00007ooooo`;o00001Oooool2o`0000;ooooo4Ol000000ooooooo0000o`000003ooooo`Co0000
4Oooool4o`0000Kooooo0_l00007ooooo`;o00001?ooool5o`000004ooooool0003o0000ooooo`Ko
00000_ooool2o`0000Kooooo0_l000001?oooooo0000o`000?ooool2o`0006[ooooo000Looooo`03
o`000?oooooooooo03Wooooo0_l00002ooooo`;o00000_ooool4o`0000?ooooo0_l00004ooooo`Co
00003oooool2o`0000;ooooo0_l0000<ooooo`Co00000_ooool4o`000003ooooool0003o000000oo
000000?oooooo`000?l000000ol0000<ooooo`?o000000?oooooo`000?l000000_l00002ooooo`;o
00002oooool2o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`Ko00000oooool2o`0000Oo
oooo0_l00002ooooo`Co0000J?ooool001cooooo00?o0000ooooooooool0>Oooool2o`0001?ooooo
1?l0000?ooooo`;o00004?ooool4o`0000Cooooo6ol0000;ooooo`?o00001oooool3o`0000Sooooo
0_l00004ooooo`Co000000?oooooo`000?l000000_l00002ooooo`Oo00000_ooool2o`0000Oooooo
0_l00002ooooo`Go0000Ioooool001cooooo00?o0000ooooooooool0>?ooool2o`0002oooooo0_l0
000@oooooa_o00000_ooool2o`0000Gooooo1Ol00003ooooo`;o000000?oooooo`000?l000000_l0
0006ooooo`Oo000000?oooooo`000?l000004Ol00003ooooo`;o00001oooool2o`000003ooooool0
003o000000;o0000<_ooool2o`0003?ooooo000Looooo`03o`000?oooooooooo03Sooooo0_l00009
ooooo`;o00009?ooool2o`0000kooooo4?l000000ooooooo0000o`000004o`0000;ooooo1?l00002
ooooo`;o000000?oooooo`000?l000000_ooool4o`0000Cooooo1Ol00008ooooo`;o00000_oooolI
o`000003ooooool0003o000000;o00001Oooool2o`000004ooooool0003o0000o`0003?ooooo0_l0
000cooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00008?ooool2o`0000;ooooo0_l00004
ooooo`;o00001?ooool2o`000003ooooool0003o000001Ko00000_ooool2o`0000Oooooo0_l0000;
ooooo`;o00002_ooool4o`000003ooooool0003o000001Oo00000_ooool2o`0000Kooooo1Ol00006
ooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0>_ooool2o`0000?ooooo0_l0000Hoooo
o`;o00002_ooool2o`000004ooooool0003o0000o`0000Cooooo0_l00004oooooaco000000?ooooo
o`000?l000000_l00002ooooo`;o00000_ooool2o`0001Sooooo0_l00005oooooaKo000000Cooooo
o`000?l0003o00001Oooool2o`0000Cooooo0_l00003ooooo`;o00005_ooool2o`0004Sooooo000L
ooooo`03o`000?oooooooooo03[ooooo1ol0000Hooooo`;o00001?ooool2o`0000Oooooo0_l00005
ooooo`;o00000_oooolNo`000003ooooool0003o000000;o00000_ooool2o`0000;ooooo0_l0000E
ooooo`;o00002?ooool2o`000003ooooool0003o000001;o000000?oooooo`000?l000002_ooool3
o`0001[ooooo0ol00018ooooo`007?ooool2o`0003gooooo1?l0000:ooooo`;o00004oooool2o`00
00Cooooo0_l0000<ooooob3o00002_ooool2o`00013ooooo0_l00002ooooo`?o00000ooooolOo`00
00Cooooo0_l00003ooooo`;o00006oooool2o`00013ooooo0_l0000gooooo`007?ooool00ol0003o
ooooooooo`0mooooo`;o00001oooool2o`0000;ooooo0_l0000Cooooo`;o00001?ooool2o`0000So
oooo0_l00002ooooo`;o00000_oooolLo`0000[ooooo0_l0000@ooooo`Co000000?oooooo`000?l0
00000_ooool=o`000003ooooool0003o0000013o00001?ooool2o`00037ooooo0ol0000gooooo`00
7?ooool00ol0003oooooooooo`0mooooo`;o00001oooool2o`0000[ooooo0_l0000:ooooo`?o0000
1Oooool2o`0000Oooooo0_l00002ooooo`Co000000?oooooo`000?l000006?l00002ooooo`;o0000
4Oooool2o`0000Cooooo0ol000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00002oooooago
000000?oooooo`000?l00000<oooool2o`0003Sooooo000Looooo`03o`000?oooooooooo03gooooo
0_l00009ooooo`;o00001Oooool2o`000003ooooool0003o000000[ooooo0ol00005ooooo`;o0000
0oooool2o`0000Kooooo1?l000000ooooooo0000o`00000Go`000003ooooool0003o000000;o0000
4Oooool2o`0000Cooooo0ol00008ooooo`;o000000?oooooo`000?l000001?l000000ooooooo0000
o`00000Eo`000004ooooool0003o0000ooooo`;o0000J_ooool001cooooo00?o0000ooooooooool0
?_ooool2o`0000Sooooo0_l00005ooooo`;o000000?oooooo`000?l000001Oooool2o`0000kooooo
1?l00007ooooo`;o00000_oooolLo`0000Oooooo0_l0000;ooooo`;o00001?ooool3o`0000[ooooo
7Ol00003ooooo`Co00007?ooool2o`0004cooooo000Looooo`03o`000?oooooooooo03kooooo0_l0
0003ooooo`;o00002Oooool2o`0000Gooooo0_l000001?oooooo0000o`000?l0000;ooooo`;o0000
00?oooooo`000?l000001_ooool2o`000004ooooool0003o0000ooooo`ko000000?oooooo`000?l0
00002_l00009ooooo`;o00002oooool2o`0000Gooooo0_l00002ooooo`Co00000oooool2o`0000;o
oooo6Ol000001?oooooo0000o`000?ooool2o`0000Sooooo0_l0000Dooooo`;o0000C?ooool001co
oooo00?o0000ooooooooool0@oooool2o`0000Wooooo0_l00005ooooo`;o000000?oooooo`000?l0
00000oooool2o`0000Oooooo1Ol00006ooooo`Co00000_oooolJo`0000Oooooo0_l0000<ooooo`;o
00000oooool3o`000004ooooool0003o0000ooooo`Go00000oooool2o`0000;ooooo6?l000001Ooo
oooo0000o`000?l0003ooooo00;o00002?ooool2o`0006;ooooo000Looooo`03o`000?oooooooooo
03kooooo0_l0000Aooooo`;o00002_ooool2o`0000Oooooo1?l00009oooooa[o000000Coooooo`00
0?l0003o00001oooool2o`0000_ooooo0ol00002ooooo`Oo000000Coooooo`000?l0003ooooo0_l0
00000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000005Ol000000ooooooo0000o`00
000booooo`;o0000??ooool001cooooo00?o0000ooooooooool0?_ooool2o`00017ooooo1Ol0000A
ooooo`?o00001_ooool2o`000003ooooool0003o000000Co000000?oooooo`000?l000001ol00000
0ooooooo0000o`000007o`0000[ooooo0_l00004ooooo`;o00001_ooool2o`0000?ooooo2?l00003
ooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000001Ko00000oooool2
o`0000Gooooo0_l0000Xooooo`;o0000??ooool001cooooo00?o0000ooooooooool0BOooool2o`00
00Oooooo1Ol00007ooooo`;o00001oooool2o`0000Cooooo1Ol00002ooooo`;o000000?oooooo`00
0?l000000ooooolBo`0000?ooooo0_l00004ooooo`;o00001?ooool2o`0000Wooooo2_l00003oooo
o`?o00001ooooolHo`0000?ooooo0_l00005ooooo`;o0000I_ooool001cooooo00?o0000oooooooo
ool0B?ooool3o`0000[ooooo0_l00007ooooo`;o00003Oooool5o`0000Cooooo0_l00004oooooa;o
00000oooool2o`0000;ooooo1?l00008ooooo`;o00001Oooool5o`000003ooooool0003o000000;o
00000oooool3o`0000Oooooo0_l000000ooooooo0000o`00000@o`0002?ooooo0_l0001@ooooo`00
7?ooool00ol0003oooooooooo`18ooooo`;o00004oooool2o`0000Sooooo0_l00009ooooo`;o0000
0_ooool2o`0000Gooooo4?l000000ooooooo0000o`000002o`0000;ooooo0ol0000:ooooo`;o0000
1Oooool5o`0000Sooooo0_l00009ooooo`;o000000?oooooo`000?l000004?l0000Rooooo`;o0000
D?ooool001cooooo00?o0000ooooooooool0C?ooool2o`0000Sooooo0ol00004ooooo`;o00002?oo
ool2o`0000Kooooo0_l000000ooooooo0000o`000002ooooo`Co00000oooool@o`000003ooooool0
003o000000;o00000_ooool2o`0001;ooooo1_l0000Booooo`;o000000?oooooo`000?l000003Ol0
00000ooooooo0000o`00001dooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00002?ooool3
o`0000Kooooo0_l00006ooooo`;o00001_ooool5o`0000;ooooo5Ol00005ooooo`;o00005oooool5
o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`0000[ooooo2_l00002ooooo`?o0000MOooool0
01cooooo00?o0000ooooooooool0A_ooool4o`0000kooooo0_l00005ooooo`;o00001_ooool2o`00
00Sooooo0ol00003ooooo`oo00002Oooool4o`0000_ooooo1?l00007ooooo`;o00001_ooool2o`00
00;ooooo0_l00002ooooo`;o00002_ooool;o`000003ooooool0003o000000;o00001Oooool2o`00
06gooooo000Looooo`03o`000?oooooooooo04Kooooo1?l0000>ooooo`;o00004Oooool2o`0000Go
oooo1?l000000ooooooo0000o`000009o`000003ooooool0003o000000[ooooo1?l0000;ooooo`Go
00000_ooool2o`0000;ooooo0_l00003ooooo`;o00004Oooool2o`0000Gooooo1?l00002ooooo`;o
00000oooool2o`0000Gooooo0_l0000Dooooo`;o0000Eoooool001cooooo0_l0001Mooooo`;o0000
00?oooooo`000?l000002_ooool2o`0000Oooooo3_l000001?oooooo0000o`000?l00004ooooo`;o
00001?ooool3o`0000_ooooo1Ol00002ooooo`Co00001Oooool2o`00017ooooo0_l00007ooooo`;o
00008oooool3o`0001;ooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o0000
1oooool2o`0000Cooooo1?l000000ooooooo0000o`00000Dooooo`Go000000?oooooo`000?l00000
1Ol000001?oooooo0000o`000?l00004ooooo`;o00000oooool4o`0000;ooooo0_l00009ooooo`;o
00001Oooool2o`0000Sooooo0_l0000;ooooo`?o00001?ooool2o`0001;ooooo0_l000000ooooooo
0000o`00000Aooooo`;o00004_ooool3o`0004?ooooo000Looooo`03o`000?oooooooooo04_ooooo
0_l00007ooooo`;o00001?ooool3o`0001?ooooo0_l00008ooooo`Oo00000_ooool2o`0000[ooooo
0_l00004ooooo`;o00002Oooool4o`0000Gooooo0_l00006ooooo`;o00000_ooool2o`0000;ooooo
0_l000000ooooooo0000o`000005o`0000;ooooo0_l0000Booooo`;o000000?oooooo`000?l00000
9Oooool2o`0004Cooooo000Looooo`03o`000?oooooooooo04cooooo0_l0000Rooooo`;o00002?oo
ool7o`00027ooooo0_l000000ooooooo0000o`000002ooooo`;o00001?ooool2o`0000Cooooo0_l0
0002ooooo`Go00000oooool3o`0001Cooooo0ol000000ooooooo0000o`00000<ooooo`;o0000GOoo
ool001cooooo00?o0000ooooooooool0C?ooool2o`0000Sooooo0_l00003ooooo`?o00004Oooool2
o`0000cooooo0_l0000Cooooo`?o00004?ooool2o`0000Sooooo0ol00008ooooo`Co00000oooool3
o`000003ooooool0003o000000kooooo1ol0000>ooooo`;o0000GOooool001cooooo00?o0000oooo
ooooool0E_ooool2o`0000?ooooo0ol0000=ooooo`;o00000_ooool2o`0000kooooo0_l000000ooo
oooo0000o`00000>ooooo`?o00001oooool4o`00013ooooo0_l00008ooooo`;o00001?ooool2o`00
00?ooooo0ol00002ooooo`;o00000_ooool2o`0000Gooooo0ol00002ooooo`;o0000KOooool001co
oooo00?o0000ooooooooool0GOooool2o`0000cooooo0ol00003ooooo`;o00001Oooool2o`0000Go
oooo1Ol000001?oooooo0000o`000?l0000Dooooo`Co00004_ooool2o`0000?ooooo0_l00007oooo
o`Co000000Coooooo`000?l0003o00000_ooool2o`0000;ooooo0_l00008ooooo`?o0000K_ooool0
01cooooo00?o0000ooooooooool0GOooool2o`0000cooooo0ol00002ooooo`Co000000Coooooo`00
0?l0003ooooo0_l00006ooooo`;o00000oooool3o`0002[ooooo0_l00003ooooo`;o00002Oooool5
o`0000Sooooo0_l00007ooooo`?o00003?ooool2o`0000Sooooo0_l000000ooooooo0000o`00001C
ooooo`007?ooool00ol0003oooooooooo`1`ooooo`Co000000Coooooo`000?l0003ooooo0_l0000E
ooooo`;o0000<_ooool2o`0000;ooooo0_l00006ooooo`;o00003oooool2o`0000Cooooo0ol00006
ooooo`Co000000?oooooo`000?l00000Doooool001cooooo00?o0000ooooooooool0Coooool2o`00
01oooooo0_l00006ooooo`Ko00004Oooool2o`0002Wooooo0_l00006ooooo`Oo00000oooool5o`00
00[ooooo0ol00002ooooo`?o00000oooool2o`0000Oooooo1?l0001Fooooo`007?ooool00ol0003o
ooooooooo`1?ooooo`;o00000oooool2o`0002Cooooo1?l000001?oooooo0000o`000?l0000hoooo
o`;o00001_ooool2o`000004ooooool0003o0000o`0000Cooooo1?l0000;ooooo`?o00000oooool2
o`0000Sooooo2?l0001Fooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o00000oooool2o`00
01Oooooo0_l000000ooooooo0000o`000003ooooo`;o00000oooool3o`0000;ooooo0_l00012oooo
o`;o00006?ooool2o`0000Oooooo1_l00008ooooo`;o0000C_ooool001cooooo00?o0000oooooooo
ool0Eoooool4o`0001Gooooo2Ol0000;ooooo`;o0000@_ooool2o`0001Sooooo0_l000000ooooooo
0000o`000005ooooo`;o00002_ooool3o`0004kooooo000Looooo`03o`000?oooooooooo05Oooooo
0_l0000Gooooo`;o00000_ooool5o`0000Cooooo0_l00007ooooo`;o0000?_ooool2o`0001Oooooo
0_l00004ooooo`;o00001?ooool3o`0000[ooooo0_l0001?ooooo`007?ooool00ol0003ooooooooo
o`1Hooooo`Co00005Oooool2o`0000?ooooo0_l00005ooooo`;o00001oooool2o`0003gooooo0ol0
0008ooooo`;o00003Oooool2o`0000?ooooo0_l00005ooooo`;o0000G?ooool001cooooo00?o0000
ooooooooool0F?ooool4o`0001Gooooo0_l0000:ooooo`;o00004Oooool2o`00027ooooo0_l0000@
ooooo`;o00001_ooool2o`000003ooooool0003o000000[ooooo1?l00004ooooo`;o0000Hoooool0
01cooooo0_l0001nooooo`;o00004Oooool2o`00027ooooo0ol0000Gooooo`Co00001oooool2o`00
00;ooooo1?l00004ooooo`;o0000Hoooool001cooooo00?o0000ooooooooool0G?ooool2o`0002_o
oooo0_l00002ooooo`;o00009Oooool2o`0000Cooooo1?l0000Aooooo`;o00001oooool2o`0001So
oooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`1Looooo`;o00007_ooool2o`0000_ooooo
0_l000001?oooooo0000o`000?l0000[ooooo`Ko0000<_ooool2o`0005Gooooo000Looooo`03o`00
0?oooooooooo05cooooo1?l0000Looooo`;o00002?ooool2o`0000Cooooo0_l0000`ooooo`;o0000
;oooool2o`0005Sooooo000Looooo`03o`000?oooooooooo05kooooo0_l0000Gooooo`;o00000ooo
ool2o`0000Sooooo0_l0000Vooooo`;o000000?oooooo`000?l000002oooool2o`0001oooooo0_l0
000>ooooo`;o0000F?ooool001cooooo00?o0000ooooooooool0G_ooool2o`0001Oooooo1?l00000
0ooooooo0000o`00000`ooooo`;o000000?oooooo`000?l000003_ooool4o`0001Wooooo0ol0000>
ooooo`;o0000F?ooool001cooooo00?o0000ooooooooool0HOooool2o`0001;ooooo0_l00002oooo
o`Go00009?ooool3o`000003ooooool0003o000001Wooooo1?l0000Iooooo`;o00002Oooool2o`00
05kooooo000Looooo`03o`000?oooooooooo067ooooo0_l0000Booooo`;o00001?ooool2o`000003
ooooool0003o000000Wooooo0_l000000ooooooo0000o`00000Dooooo`?o000000?oooooo`000?l0
00002_ooool2o`0000gooooo0_l00003ooooo`;o00008Oooool2o`0005kooooo000Looooo`03o`00
0?oooooooooo07kooooo0_l00002ooooo`?o00001?ooool5o`0002Cooooo0_l0000<ooooo`Co0000
0_ooool2o`000003ooooool0003o000007kooooo000Looooo`03o`000?oooooooooo083ooooo1Ol0
0006ooooo`;o00001?ooool2o`0001cooooo1?l0000<ooooo`Go000000?oooooo`000?l000001?l0
001nooooo`007?ooool00ol0003oooooooooo`1nooooo`Co00001?ooool2o`0000Wooooo0_l0000L
ooooo`Co00003?ooool5o`000003ooooool0003o000000Co00001Oooool2o`0007Oooooo000Loooo
o`03o`000?oooooooooo07kooooo0ol00005ooooo`;o00001_ooool2o`0001;ooooo0_l0000Boooo
o`Co00001_ooool5o`0000;ooooo1?l00004ooooo`?o00004_ooool2o`0006?ooooo000Looooo`03
o`000?oooooooooo06Oooooo0_l0000Looooo`;o00000oooool2o`0000;ooooo0_l0000:ooooo`;o
00001_ooool2o`0001;ooooo1?l00005ooooo`;o00000_ooool2o`0000;ooooo1?l000001?oooooo
0000o`000?ooool2o`00017ooooo1?l0001Sooooo`007?ooool00ol0003oooooooooo`1Wooooo`;o
00005Oooool2o`0000?ooooo1?l00003ooooo`;o00001Oooool2o`0000Oooooo0_l0000Booooo`;o
00001oooool2o`000003ooooool0003o000000;ooooo0ol00007ooooo`?o000000?oooooo`000?l0
00005?ooool2o`0006Gooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44oooo
o`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1nooooo`;o00000oooool3
o`0000Oooooo0_l00002ooooo`;o00006Oooool8o`0000?ooooo2Ol0000:ooooo`;o000000?ooooo
o`000?l00000N_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go
8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo06[ooooo0_l0000Hooooo`;o0000
1oooool2o`0001Sooooo0_l00003ooooo`Wo000000?oooooo`000?l000001_l0000<ooooo`;o0000
00?oooooo`000?l000004?ooool2o`0006Sooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oo
oooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo06Sooooo
1Ol0000Pooooo`;o00002?ooool2o`0000kooooo2Ol00003ooooo`;o000000?oooooo`000?l00000
0_l0000Uooooo`;o0000J?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Ooo
ool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0001Xooooo`Go00008?ooool2o`000004oooo
ool0003o0000ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000Gooooo0_l000000ooo
oooo0000o`000006o`0000Gooooo1?l0002Dooooo`0000?oooooo`000?ooool00_ooool00ol0003o
ooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`1[oooo
o`;o00008oooool2o`000004ooooool0003o0000ooooo`?o000000?oooooo`000?l000000_ooool2
o`000004ooooool0003o0000ooooo`Co00000oooool2o`000003ooooool0003o000000Go0000U?oo
ool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol@413o^[Zjoooooonj
^[[o410@00Kooooo00?o0000ooooooooool0K?ooool2o`0002Wooooo0ol00004ooooo`;o00002ooo
ool2o`000003ooooool0003o000000;o000000?oooooo`000?l000000oooool2o`0000;ooooo0_l0
000Fooooo`Co0000LOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zj
oooooonj^[[o000000Kooooo00?o0000ooooooooool0K?ooool2o`0002[ooooo0_l00002ooooo`;o
00001?ooool2o`0000Gooooo0_l0000=ooooo`;o00000_ooool2o`0001Kooooo1?l0001aooooo`00
00Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool0
0ol0003oooooooooo`2@ooooo`Co00002?ooool2o`0000?ooooo0ol00005ooooo`;o0000W_ooool0
01cooooo00?o0000ooooooooool0LOooool2o`0001gooooo1?l0000=ooooo`?o00001Oooool2o`00
09kooooo000Looooo`03o`000?oooooooooo077ooooo0_l000000ooooooo0000o`000004ooooo`;o
00007?ooool2o`000:oooooo000Looooo`03o`000?oooooooooo07Cooooo0_l00003ooooo`Go0000
6_ooool2o`0002_ooooo1?l00020ooooo`007?ooool00ol0003oooooooooo`1dooooo`;o00000ooo
ool5o`0002Cooooo1?l0000Jooooo`;o00000oooool4o`00083ooooo000Looooo`03o`000?oooooo
oooo07Cooooo0_l0000/ooooo`Co00000_ooool2o`0001;ooooo0_l00002ooooo`;o0000Qoooool0
01cooooo00?o0000ooooooooool0NOooool2o`0000Gooooo0ol0000Uooooo`;o000000?oooooo`00
0?l000000ol00003ooooo`;o00001?ooool5o`0008_ooooo000Looooo`03o`000?oooooooooo07Wo
oooo0_l00005ooooo`?o0000:?ooool5o`0000?ooooo0_l00004ooooo`?o0000SOooool001cooooo
00?o0000ooooooooool0Q?ooool2o`000<?ooooo000Looooo`03o`000?oooooooooo08Cooooo0_l0
0033ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
08[ooooo0ol0002looooo`007?ooool2o`0008_ooooo0ol0002looooo`007?ooool00ol0003ooooo
ooooo`2Cooooo`;o0000]?ooool001cooooo00?o0000ooooooooool0Toooool4o`000;;ooooo000L
ooooo`03o`000?oooooooooo09Gooooo0_l0002booooo`007?ooool00ol0003oooooooooo`2Ioooo
o`?o0000[Oooool001cooooo00?o0000ooooooooool0VOooool3o`000:gooooo000Looooo`03o`00
0?oooooooooo09gooooo1?l0000Yooooo`;o0000OOooool001cooooo00?o0000ooooooooool0WOoo
ool4o`00013ooooo1?l0000Eooooo`;o0000OOooool001cooooo00?o0000ooooooooool0/Oooool4
o`0000Sooooo1Ol00027ooooo`007?ooool00ol0003oooooooooo`2mooooo`Go0000Qoooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Booooo`Co0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05
ooooo`?o0000oooooom:ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03
o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?oo
ool00ol0003oooooooooo`3ooooooe;ooooo000Booooo`03oeEEEOmVIVKo00000?ooooooE?ooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Gooooo00Co410@o`000?l0003ooooo
0_l000000ol@413oooooooooo`0Eooooo`05oiRHV?l@413o0000oc8b<_o<c<`01Oooool00ol0003o
k^k^ooooo`03ooooo`Go0000T?ooool00:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko
00002Oooool01Ol@413o^[ZjoooooomgMgOo<S8b00Gooooo00?oEEEEojVYZOooool00oooool01OnH
V9So8B4Qonk^k_ooooooA4A4093ooooo002Vooooo`05o`000?ooooooooooooooool000007?ooool0
0ol0003oooooooooo`03ooooo`03ojVYZOmEEEGooooo00Cooooo00?oV9RHob4Q8Oo^k^h0TOooool0
0:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00003?ooool00onYZJWo410@ooooo`05
ooooo`03ob4Q8Ooooooooooo00Cooooo00?oV9RHob4Q8Oo^k^h0T?ooool00:Kooooo00Go0000ohN7
QoooooooZJVYo`00000Jooooo`03oa0@4?l0003o^[Zj00Kooooo00?oEEEEolc<c?ooool01Oooool0
0omgMgOoIVIVooooo`2?ooooo`00YOooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo
01Wooooo00?o^[Zjob4Q8Oooool01Oooool00onYZJWoMgMgooooo`06ooooo`03o`000?oooooooooo
08kooooo0033ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01Ol@413ooooooooooooooooo
<S8b00?ooooo00Go0000okZj^_ooooooV9RHoa0@402@ooooo`00`oooool01OnYZJWo410@o`000?l@
413oZJVY00?ooooo1Ol00003ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0T?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(378) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.42467 .63311 Mdot
.38149 .63265 Mdot
.6703 .48979 Mdot
.36919 .39956 Mdot
.70746 .35508 Mdot
.68663 .50014 Mdot
.62182 .68796 Mdot
.62448 .68955 Mdot
.7057 .4938 Mdot
.20297 .53604 Mdot
.58597 .68437 Mdot
.37948 .44618 Mdot
.60638 .68262 Mdot
.39187 .40112 Mdot
.48834 .48175 Mdot
.44946 .36649 Mdot
.39448 .60024 Mdot
.64667 .35845 Mdot
.45419 .38123 Mdot
.66955 .53274 Mdot
.3154 .31749 Mdot
.39235 .38928 Mdot
.38126 .66845 Mdot
.3903 .39821 Mdot
.40797 .36197 Mdot
.38427 .65107 Mdot
.41996 .64483 Mdot
.40629 .366 Mdot
.41833 .44184 Mdot
.5909 .68609 Mdot
.58631 .51778 Mdot
.29309 .27198 Mdot
.38617 .34944 Mdot
.30917 .49242 Mdot
.61908 .70571 Mdot
.62484 .73951 Mdot
.69394 .53958 Mdot
.61085 .6495 Mdot
.61157 .70982 Mdot
.59077 .70023 Mdot
.58655 .694 Mdot
.38664 .65485 Mdot
.57654 .64891 Mdot
.70388 .68213 Mdot
.37994 .40823 Mdot
.40224 .53356 Mdot
.68147 .67254 Mdot
.4413 .39412 Mdot
.37957 .61515 Mdot
.66159 .51096 Mdot
.5832 .28614 Mdot
.61677 .65832 Mdot
.46707 .59913 Mdot
.82018 .69374 Mdot
.60714 .69262 Mdot
.44649 .38039 Mdot
.7196 .51829 Mdot
.41626 .41066 Mdot
.36694 .38595 Mdot
.28553 .4516 Mdot
.41771 .39279 Mdot
.67028 .35769 Mdot
.44181 .61069 Mdot
.71034 .55375 Mdot
.70381 .49055 Mdot
.60596 .64794 Mdot
.35144 .65654 Mdot
.59579 .67626 Mdot
.40073 .44368 Mdot
.66474 .50599 Mdot
.42906 .43135 Mdot
.58571 .68054 Mdot
.39827 .66401 Mdot
.37396 .39878 Mdot
.52511 .7966 Mdot
.66886 .67862 Mdot
.69336 .5692 Mdot
.29509 .37238 Mdot
.65922 .28278 Mdot
.56427 .47823 Mdot
.37816 .39368 Mdot
.82921 .55486 Mdot
.52719 .44678 Mdot
.38973 .61686 Mdot
.45848 .60907 Mdot
.49595 .68682 Mdot
.43348 .38055 Mdot
.57895 .52755 Mdot
.44459 .34931 Mdot
.68441 .41026 Mdot
.71491 .51203 Mdot
.40291 .61384 Mdot
.37701 .40193 Mdot
.38208 .43433 Mdot
.24592 .6301 Mdot
.43249 .43854 Mdot
.36988 .3807 Mdot
.49467 .63307 Mdot
.57986 .6688 Mdot
.45485 .45681 Mdot
.61759 .372 Mdot
.5047 .58908 Mdot
.44537 .38149 Mdot
.70362 .52168 Mdot
.44273 .61906 Mdot
.40317 .34722 Mdot
.60659 .67129 Mdot
.38174 .39416 Mdot
.56671 .67078 Mdot
.36891 .6229 Mdot
.3589 .40189 Mdot
.68943 .3561 Mdot
.32423 .3443 Mdot
.38476 .66478 Mdot
.31381 .58575 Mdot
.40844 .38334 Mdot
.42 .41653 Mdot
.37877 .63434 Mdot
.67087 .52587 Mdot
.79609 .56383 Mdot
.39511 .66322 Mdot
.58934 .69967 Mdot
.3925 .60323 Mdot
.33435 .35738 Mdot
.67438 .53345 Mdot
.49618 .60219 Mdot
.49609 .60431 Mdot
.50202 .27053 Mdot
.3741 .39009 Mdot
.36576 .28908 Mdot
.69706 .51305 Mdot
.37629 .65337 Mdot
.59665 .68381 Mdot
.4586 .41104 Mdot
.40198 .64654 Mdot
.62475 .68414 Mdot
.70572 .32799 Mdot
.65471 .37156 Mdot
.36736 .65207 Mdot
.30742 .61817 Mdot
.57371 .63722 Mdot
.5752 .67963 Mdot
.58029 .28728 Mdot
.38884 .61689 Mdot
.68332 .34228 Mdot
.61588 .66892 Mdot
.52824 .18778 Mdot
.36737 .37819 Mdot
.55653 .29279 Mdot
.81762 .58116 Mdot
.58348 .28657 Mdot
.27287 .34158 Mdot
.69124 .34978 Mdot
.62505 .68287 Mdot
.43751 .41837 Mdot
.39861 .63161 Mdot
.39775 .64924 Mdot
.4109 .43754 Mdot
.39356 .35603 Mdot
.39484 .41272 Mdot
.3934 .34956 Mdot
.56348 .59968 Mdot
.37854 .40087 Mdot
.38546 .78289 Mdot
.40521 .63351 Mdot
.40665 .35534 Mdot
.68373 .53064 Mdot
.48261 .43165 Mdot
.58436 .6467 Mdot
.36697 .39299 Mdot
.39539 .35825 Mdot
.41955 .45205 Mdot
.59113 .70206 Mdot
.52081 .80728 Mdot
.68822 .2667 Mdot
.64748 .68969 Mdot
.65004 .75481 Mdot
.68682 .5167 Mdot
.42418 .39343 Mdot
.68476 .33106 Mdot
.47521 .42691 Mdot
.37624 .42037 Mdot
.5897 .28423 Mdot
.38408 .37138 Mdot
.28148 .33249 Mdot
.35111 .35934 Mdot
.50801 .67451 Mdot
.36333 .75535 Mdot
.36802 .40889 Mdot
.22164 .51886 Mdot
.561 .30392 Mdot
.62847 .53899 Mdot
.59623 .68724 Mdot
.67161 .50497 Mdot
.66839 .51683 Mdot
.62956 .66173 Mdot
.35456 .54397 Mdot
.20251 .5091 Mdot
.41921 .44608 Mdot
.50124 .59013 Mdot
.37169 .60809 Mdot
.6887 .35137 Mdot
.36832 .64843 Mdot
.836 .52996 Mdot
.58324 .46282 Mdot
.56178 .51641 Mdot
.6438 .32931 Mdot
.65971 .5205 Mdot
.49576 .59531 Mdot
.68111 .33729 Mdot
.39883 .42117 Mdot
.37042 .62205 Mdot
.56503 .29948 Mdot
.47782 .41349 Mdot
.16037 .58176 Mdot
.4171 .64742 Mdot
.4716 .28012 Mdot
.60678 .68987 Mdot
.72723 .50115 Mdot
.43251 .37949 Mdot
.40721 .39907 Mdot
.36127 .63829 Mdot
.43687 .41368 Mdot
.54175 .50123 Mdot
.39045 .36143 Mdot
.71256 .55132 Mdot
.72334 .29919 Mdot
.62834 .65444 Mdot
.66979 .31331 Mdot
.39283 .66643 Mdot
.55294 .8376 Mdot
.69929 .53096 Mdot
.44667 .47499 Mdot
.58925 .67207 Mdot
.70833 .3305 Mdot
.70746 .52852 Mdot
.66174 .36697 Mdot
.3621 .40803 Mdot
.70139 .53882 Mdot
.67462 .3601 Mdot
.53401 .5306 Mdot
.39725 .34932 Mdot
.47629 .23729 Mdot
.61686 .66309 Mdot
.40453 .60902 Mdot
.38983 .43009 Mdot
.4676 .59435 Mdot
.38531 .45986 Mdot
.51642 .31268 Mdot
.47338 .5967 Mdot
.50764 .58322 Mdot
.54967 .46194 Mdot
.67895 .32325 Mdot
.61063 .76805 Mdot
.5666 .53861 Mdot
.39485 .60001 Mdot
.37514 .42555 Mdot
.56809 .73163 Mdot
.62112 .6675 Mdot
.40575 .41985 Mdot
.54325 .71232 Mdot
.61765 .67021 Mdot
.41688 .41808 Mdot
.59316 .6978 Mdot
.40139 .64042 Mdot
.52737 .48957 Mdot
.41728 .60899 Mdot
.38231 .41952 Mdot
.5904 .69432 Mdot
.67064 .51043 Mdot
.38525 .65077 Mdot
.38475 .39111 Mdot
.38582 .37792 Mdot
.49759 .58565 Mdot
.37872 .36753 Mdot
.50996 .6417 Mdot
.4403 .38919 Mdot
.66526 .49182 Mdot
.42761 .44014 Mdot
.60158 .34368 Mdot
.69196 .39726 Mdot
.36482 .63595 Mdot
.47363 .59573 Mdot
.71538 .52531 Mdot
.52463 .51218 Mdot
.44442 .25332 Mdot
.38207 .40089 Mdot
.47849 .59078 Mdot
.49712 .28564 Mdot
.58283 .64844 Mdot
.42597 .3346 Mdot
.76014 .52123 Mdot
.71341 .5139 Mdot
.49976 .59287 Mdot
.46791 .43327 Mdot
.34876 .67292 Mdot
.45412 .39665 Mdot
.69789 .53724 Mdot
.41661 .61063 Mdot
.44223 .42592 Mdot
.67021 .66036 Mdot
.46669 .59365 Mdot
.57738 .67012 Mdot
.49917 .62936 Mdot
.42754 .4122 Mdot
.6686 .5004 Mdot
.3942 .65573 Mdot
.61294 .69647 Mdot
.38766 .6652 Mdot
.57474 .30687 Mdot
.49406 .29661 Mdot
.47549 .56572 Mdot
.66602 .32211 Mdot
.47629 .16063 Mdot
.64824 .68844 Mdot
.46354 .44619 Mdot
.74269 .50907 Mdot
.33703 .71546 Mdot
.70735 .52145 Mdot
.30702 .63024 Mdot
.71742 .51395 Mdot
.45021 .39695 Mdot
.6904 .49491 Mdot
.24284 .64078 Mdot
.3996 .36847 Mdot
.69984 .48663 Mdot
.58237 .58252 Mdot
.39573 .3702 Mdot
.40339 .64631 Mdot
.23513 .33042 Mdot
.34068 .51641 Mdot
.34634 .52919 Mdot
.72155 .52038 Mdot
.30362 .6516 Mdot
.41252 .36805 Mdot
.46071 .39619 Mdot
.39468 .63514 Mdot
.37923 .45581 Mdot
.66198 .33041 Mdot
.65106 .35958 Mdot
.55865 .23192 Mdot
.33771 .26289 Mdot
.34212 .5527 Mdot
.39207 .64917 Mdot
.70776 .28171 Mdot
.51425 .79653 Mdot
.46652 .59428 Mdot
.62505 .68859 Mdot
.56172 .79834 Mdot
.46269 .38006 Mdot
.40582 .69178 Mdot
.53924 .49957 Mdot
.418 .61844 Mdot
.49352 .55192 Mdot
.61656 .69609 Mdot
.34351 .52768 Mdot
.20072 .47657 Mdot
.39511 .41426 Mdot
.59881 .65123 Mdot
.36319 .43794 Mdot
.57362 .52993 Mdot
.48449 .25715 Mdot
.70241 .60184 Mdot
.38273 .41849 Mdot
.56762 .78317 Mdot
.38185 .42523 Mdot
.5136 .27246 Mdot
.40251 .4228 Mdot
.40329 .65128 Mdot
.4342 .44734 Mdot
.56013 .54279 Mdot
.53109 .15081 Mdot
.58196 .45298 Mdot
.65709 .35959 Mdot
.39474 .39954 Mdot
.40486 .41023 Mdot
.66716 .35868 Mdot
.41151 .61612 Mdot
.38824 .43267 Mdot
.65568 .7714 Mdot
.37727 .39858 Mdot
.61986 .65866 Mdot
.54478 .35558 Mdot
.32663 .25461 Mdot
.42579 .38147 Mdot
.34878 .67197 Mdot
.57524 .67654 Mdot
.59667 .66368 Mdot
.41947 .32541 Mdot
.61738 .66199 Mdot
.43632 .41879 Mdot
.54505 .35636 Mdot
.35889 .66149 Mdot
.43172 .33055 Mdot
.41842 .62361 Mdot
.74035 .2899 Mdot
.62209 .67356 Mdot
.47358 .58916 Mdot
.34009 .56247 Mdot
.61405 .67778 Mdot
.72745 .31668 Mdot
.4405 .44304 Mdot
.47907 .37611 Mdot
.35207 .61552 Mdot
.67075 .49892 Mdot
.48447 .59654 Mdot
.60874 .69401 Mdot
.38061 .40486 Mdot
.42597 .36235 Mdot
.61216 .65734 Mdot
.25303 .40201 Mdot
.58704 .51757 Mdot
.38043 .41888 Mdot
.41066 .63633 Mdot
.37852 .65496 Mdot
.43298 .3457 Mdot
.38399 .42762 Mdot
.67907 .5019 Mdot
.47802 .5914 Mdot
.47702 .5959 Mdot
.50388 .59789 Mdot
.726 .51359 Mdot
.48254 .16024 Mdot
.57406 .67637 Mdot
.30232 .26605 Mdot
.51172 .76289 Mdot
.37332 .32522 Mdot
.67745 .53068 Mdot
.41068 .39429 Mdot
.4396 .37804 Mdot
.59271 .69445 Mdot
.45168 .19036 Mdot
.46081 .40227 Mdot
.42386 .61864 Mdot
.61052 .65464 Mdot
.3697 .44524 Mdot
.58457 .62793 Mdot
.70068 .34158 Mdot
.32848 .5628 Mdot
.6202 .663 Mdot
.36138 .65673 Mdot
.62012 .66272 Mdot
.40186 .41132 Mdot
.46592 .43707 Mdot
.41986 .62116 Mdot
.68476 .37107 Mdot
.40111 .43787 Mdot
.41376 .42301 Mdot
.7008 .44096 Mdot
.52821 .79505 Mdot
.71891 .32035 Mdot
.4464 .39779 Mdot
.48061 .37638 Mdot
.67958 .37185 Mdot
.41654 .43135 Mdot
.43131 .43578 Mdot
.36265 .28965 Mdot
.56852 .65262 Mdot
.71298 .32842 Mdot
.51286 .15678 Mdot
.41895 .64436 Mdot
.51875 .63688 Mdot
.50295 .59424 Mdot
.6429 .70142 Mdot
.52214 .49859 Mdot
.49213 .5902 Mdot
.52637 .7459 Mdot
.44474 .85344 Mdot
.48481 .59445 Mdot
.72514 .53217 Mdot
.26607 .63152 Mdot
.42641 .43774 Mdot
.38663 .42484 Mdot
.67119 .32629 Mdot
.378 .62747 Mdot
.38794 .77662 Mdot
.64643 .69386 Mdot
.40123 .38499 Mdot
.41385 .65677 Mdot
.50111 .68382 Mdot
.49743 .59005 Mdot
.69258 .33257 Mdot
.70036 .35945 Mdot
.38985 .42865 Mdot
.47246 .27003 Mdot
.38822 .65209 Mdot
.38482 .39117 Mdot
.4221 .41608 Mdot
.70451 .54462 Mdot
.37044 .62323 Mdot
.68728 .5312 Mdot
.48123 .58005 Mdot
.27226 .68859 Mdot
.70833 .7406 Mdot
.61374 .66259 Mdot
.46048 .52864 Mdot
.6294 .65599 Mdot
.66157 .61613 Mdot
.4777 .59225 Mdot
.38786 .39035 Mdot
.37176 .67146 Mdot
.38252 .39262 Mdot
.37705 .39983 Mdot
.38278 .41473 Mdot
.34018 .55367 Mdot
.65741 .28724 Mdot
.67766 .3293 Mdot
.43255 .40946 Mdot
.72204 .52947 Mdot
.51988 .66748 Mdot
.20289 .5749 Mdot
.40063 .40021 Mdot
.41942 .4177 Mdot
.34764 .65976 Mdot
.36103 .38721 Mdot
.61908 .67878 Mdot
.41639 .6152 Mdot
.43717 .37132 Mdot
.62219 .37315 Mdot
.39302 .43322 Mdot
.45456 .54185 Mdot
.63215 .68696 Mdot
.43471 .45996 Mdot
.36117 .36793 Mdot
.47647 .59223 Mdot
.48601 .5961 Mdot
.50991 .57775 Mdot
.61323 .65298 Mdot
.70716 .54244 Mdot
.69096 .56398 Mdot
.35322 .38793 Mdot
.44203 .40796 Mdot
.47732 .40804 Mdot
.67285 .47373 Mdot
.58136 .54487 Mdot
.31842 .60334 Mdot
.35707 .42398 Mdot
.71876 .49125 Mdot
.49611 .63252 Mdot
.2991 .34738 Mdot
.40888 .61188 Mdot
.73609 .48648 Mdot
.59738 .6681 Mdot
.68053 .36361 Mdot
.5487 .25399 Mdot
.39948 .65876 Mdot
.36306 .67313 Mdot
.68145 .5074 Mdot
.54113 .37116 Mdot
.86083 .64052 Mdot
.70177 .51313 Mdot
.55469 .5129 Mdot
.39369 .64051 Mdot
.38842 .34911 Mdot
.51181 .29447 Mdot
.53324 .37767 Mdot
.70956 .48864 Mdot
.38443 .3791 Mdot
.74402 .35975 Mdot
.6794 .50102 Mdot
.48155 .39611 Mdot
.72189 .52144 Mdot
.57964 .66007 Mdot
.69784 .51876 Mdot
.42598 .64106 Mdot
.37585 .38889 Mdot
.83332 .6772 Mdot
.52296 .4679 Mdot
.39107 .38156 Mdot
.62267 .66396 Mdot
.64717 .59052 Mdot
.40038 .41679 Mdot
.65153 .34153 Mdot
.72137 .53537 Mdot
.67457 .6089 Mdot
.44673 .4143 Mdot
.68871 .49367 Mdot
.36443 .67895 Mdot
.72333 .46983 Mdot
.62048 .37828 Mdot
.48104 .59719 Mdot
.40216 .6356 Mdot
.64794 .71777 Mdot
.58648 .69603 Mdot
.4366 .36245 Mdot
.42381 .40723 Mdot
.40753 .62924 Mdot
.52418 .52395 Mdot
.40297 .32903 Mdot
.37838 .3957 Mdot
.68125 .51932 Mdot
.67698 .5483 Mdot
.49072 .47678 Mdot
.69976 .53251 Mdot
.47892 .37178 Mdot
.40764 .63748 Mdot
.45408 .39391 Mdot
.38628 .66172 Mdot
.37722 .42755 Mdot
.59214 .62197 Mdot
.39605 .61067 Mdot
.43176 .4789 Mdot
.37495 .38493 Mdot
.34327 .59965 Mdot
.42856 .40722 Mdot
.37661 .41215 Mdot
.68845 .55212 Mdot
.66775 .34973 Mdot
.42004 .33503 Mdot
.65963 .64307 Mdot
.69283 .36171 Mdot
.26535 .37376 Mdot
.67508 .53399 Mdot
.71053 .34258 Mdot
.53386 .22906 Mdot
.47452 .59646 Mdot
.66186 .35044 Mdot
.48113 .61001 Mdot
.60766 .6581 Mdot
.43462 .64674 Mdot
.38924 .37218 Mdot
.26927 .68157 Mdot
.58672 .5197 Mdot
.492 .58449 Mdot
.40372 .43123 Mdot
.41249 .39884 Mdot
.41272 .65783 Mdot
.83367 .5371 Mdot
.68131 .55573 Mdot
.3825 .36024 Mdot
.40132 .65937 Mdot
.82416 .56647 Mdot
.70253 .48611 Mdot
.69328 .32678 Mdot
.62137 .71026 Mdot
.39338 .59413 Mdot
.4722 .58907 Mdot
.62322 .67616 Mdot
.70272 .56737 Mdot
.59375 .28301 Mdot
.45296 .40235 Mdot
.68128 .53165 Mdot
.58465 .28634 Mdot
.41662 .33022 Mdot
.62509 .6554 Mdot
.66393 .70654 Mdot
.39513 .61587 Mdot
.61193 .6569 Mdot
.65936 .33584 Mdot
.38539 .60284 Mdot
.41811 .62088 Mdot
.61613 .67424 Mdot
.34098 .74207 Mdot
.49822 .28696 Mdot
.63727 .69013 Mdot
.52222 .31821 Mdot
.58541 .28755 Mdot
.48384 .58304 Mdot
.69202 .33382 Mdot
.71888 .28902 Mdot
.38555 .6541 Mdot
.55651 .79988 Mdot
.58413 .28533 Mdot
.37006 .3799 Mdot
.6742 .36119 Mdot
.52144 .65788 Mdot
.59663 .73301 Mdot
.62129 .67675 Mdot
.70192 .44537 Mdot
.67359 .36389 Mdot
.36427 .4065 Mdot
.36999 .20953 Mdot
.41292 .37353 Mdot
.61487 .66684 Mdot
.54033 .50025 Mdot
.36825 .63289 Mdot
.58134 .64777 Mdot
.54185 .50076 Mdot
.44541 .38727 Mdot
.40808 .38064 Mdot
.65443 .29952 Mdot
.37679 .61466 Mdot
.48208 .58088 Mdot
.38094 .38643 Mdot
.41591 .41546 Mdot
.4315 .3555 Mdot
.39409 .235 Mdot
.32117 .40488 Mdot
.41714 .3492 Mdot
.71713 .48406 Mdot
.47297 .4284 Mdot
.37559 .36624 Mdot
.34705 .67268 Mdot
.61624 .35257 Mdot
.48707 .57824 Mdot
.39075 .42571 Mdot
.38235 .42023 Mdot
.61007 .70906 Mdot
.49899 .28684 Mdot
.5326 .38305 Mdot
.66022 .50387 Mdot
.65175 .53297 Mdot
.38686 .44328 Mdot
.40179 .6267 Mdot
.69098 .3203 Mdot
.4502 .33665 Mdot
.42399 .62332 Mdot
.38149 .4375 Mdot
.71762 .53939 Mdot
.48264 .5921 Mdot
.45456 .33647 Mdot
.6749 .35551 Mdot
.57405 .63817 Mdot
.27425 .36859 Mdot
.67253 .51416 Mdot
.41964 .36821 Mdot
.67424 .56257 Mdot
.7022 .50081 Mdot
.49733 .5845 Mdot
.43781 .4672 Mdot
.39917 .64405 Mdot
.36281 .65706 Mdot
.61673 .31364 Mdot
.72615 .51836 Mdot
.66311 .46044 Mdot
.58678 .6534 Mdot
.43069 .41302 Mdot
.54079 .67263 Mdot
.36337 .65065 Mdot
.5016 .26953 Mdot
.70729 .35111 Mdot
.61932 .674 Mdot
.4716 .60814 Mdot
.40199 .60951 Mdot
.36539 .6566 Mdot
.37794 .40369 Mdot
.39794 .39263 Mdot
.6399 .56371 Mdot
.55751 .29917 Mdot
.59731 .69988 Mdot
.70123 .3318 Mdot
.66435 .49765 Mdot
.44657 .40835 Mdot
.3893 .61888 Mdot
.33634 .24394 Mdot
.42769 .41054 Mdot
.72194 .52902 Mdot
.3824 .63482 Mdot
.68206 .32642 Mdot
.66323 .33412 Mdot
.37046 .40085 Mdot
.28634 .3299 Mdot
.61063 .67531 Mdot
.40365 .64773 Mdot
.39947 .58833 Mdot
.43527 .40565 Mdot
.39787 .39747 Mdot
.33846 .36403 Mdot
.59981 .64201 Mdot
.37955 .34355 Mdot
.66971 .37068 Mdot
.3734 .65667 Mdot
.38388 .38592 Mdot
.66886 .35754 Mdot
.40152 .6933 Mdot
.48806 .58909 Mdot
.69195 .48854 Mdot
.65016 .34799 Mdot
.67672 .34467 Mdot
.70146 .35385 Mdot
.56338 .79715 Mdot
.43568 .65637 Mdot
.64561 .23068 Mdot
.37974 .38221 Mdot
.58579 .28802 Mdot
.43811 .35216 Mdot
.58459 .6499 Mdot
.67488 .49497 Mdot
.38455 .41085 Mdot
.38017 .38143 Mdot
.2817 .3663 Mdot
.45128 .3724 Mdot
.45735 .38419 Mdot
.36672 .6373 Mdot
.39136 .58703 Mdot
.66849 .509 Mdot
.81409 .59652 Mdot
.25259 .27706 Mdot
.41521 .44799 Mdot
.54182 .36836 Mdot
.40596 .61225 Mdot
.61549 .7103 Mdot
.52112 .31194 Mdot
.55557 .70037 Mdot
.37429 .64242 Mdot
.45003 .39991 Mdot
.2788 .38341 Mdot
.68208 .36534 Mdot
.39721 .41166 Mdot
.59357 .68072 Mdot
.39611 .41226 Mdot
.60815 .65012 Mdot
.31142 .63318 Mdot
.53213 .4051 Mdot
.38731 .37064 Mdot
.43195 .43856 Mdot
.35463 .30004 Mdot
.40009 .39721 Mdot
.71596 .5918 Mdot
.3867 .63436 Mdot
.44193 .47448 Mdot
.44754 .37964 Mdot
.33028 .51103 Mdot
.41785 .42693 Mdot
.50674 .51243 Mdot
.41965 .38958 Mdot
.47012 .18921 Mdot
.36326 .39554 Mdot
.42296 .3913 Mdot
.61067 .70003 Mdot
.59774 .70478 Mdot
.32529 .64549 Mdot
.49536 .57896 Mdot
.51122 .66988 Mdot
.41588 .42235 Mdot
.65971 .5243 Mdot
.4851 .33675 Mdot
.67153 .34662 Mdot
.37349 .65485 Mdot
.57501 .88196 Mdot
.57381 .66861 Mdot
.72646 .52655 Mdot
.5725 .5213 Mdot
.72668 .4914 Mdot
.74181 .51125 Mdot
.35293 .6084 Mdot
.694 .33534 Mdot
.38895 .43162 Mdot
.31603 .49279 Mdot
.54494 .78842 Mdot
.43638 .40451 Mdot
.65316 .51445 Mdot
.44798 .29858 Mdot
.61561 .30567 Mdot
.64591 .34679 Mdot
.69062 .34313 Mdot
.61353 .69414 Mdot
.66801 .49581 Mdot
.35613 .42373 Mdot
.71095 .34183 Mdot
.67319 .50154 Mdot
.47566 .60762 Mdot
.62881 .32451 Mdot
.39012 .65278 Mdot
.30388 .6462 Mdot
.40232 .54071 Mdot
.57621 .67768 Mdot
.66434 .65879 Mdot
.4099 .67175 Mdot
.40612 .60098 Mdot
.50397 .58233 Mdot
.71766 .49271 Mdot
.43082 .65173 Mdot
.3754 .39218 Mdot
.47801 .41336 Mdot
.3885 .42859 Mdot
.67654 .3245 Mdot
.41233 .42996 Mdot
.6798 .49677 Mdot
.61924 .70104 Mdot
.71506 .51671 Mdot
.62159 .68943 Mdot
.26294 .30058 Mdot
.36675 .39781 Mdot
.39514 .39652 Mdot
.54433 .35825 Mdot
.36635 .65474 Mdot
.30481 .49655 Mdot
.72261 .52666 Mdot
.71879 .51982 Mdot
.4506 .38712 Mdot
.37494 .60888 Mdot
.72012 .31469 Mdot
.53412 .3274 Mdot
.42075 .39394 Mdot
.38714 .63248 Mdot
.45183 .38849 Mdot
.62407 .60933 Mdot
.5183 .45774 Mdot
.38232 .66688 Mdot
.53492 .14996 Mdot
.37152 .38717 Mdot
.41552 .47183 Mdot
.37828 .46388 Mdot
.3837 .24581 Mdot
.42556 .33627 Mdot
.42038 .64062 Mdot
.37642 .36585 Mdot
.39749 .62447 Mdot
.70585 .5073 Mdot
.5758 .65221 Mdot
.39611 .62883 Mdot
.40271 .37104 Mdot
.25735 .27369 Mdot
.61829 .70308 Mdot
.39192 .40861 Mdot
.59515 .6921 Mdot
.43997 .62933 Mdot
.37261 .62888 Mdot
.48537 .60941 Mdot
.55658 .5135 Mdot
.61668 .67683 Mdot
.44143 .40794 Mdot
.52419 .80287 Mdot
.45445 .39542 Mdot
.65161 .52918 Mdot
.43574 .43931 Mdot
.39024 .44337 Mdot
.48154 .15483 Mdot
.51911 .51987 Mdot
.72538 .73104 Mdot
.54345 .64734 Mdot
.51403 .80679 Mdot
.34592 .62628 Mdot
.64607 .34753 Mdot
.4719 .53651 Mdot
.4772 .60068 Mdot
.71137 .48045 Mdot
.3818 .40773 Mdot
.42785 .68708 Mdot
.63532 .67783 Mdot
.66567 .34322 Mdot
.38458 .37108 Mdot
.7132 .47469 Mdot
.43823 .52222 Mdot
.62273 .67801 Mdot
.38658 .65553 Mdot
.3702 .64455 Mdot
.65626 .28142 Mdot
.38692 .38436 Mdot
.39415 .39071 Mdot
.61789 .70517 Mdot
.34285 .39096 Mdot
.70263 .34932 Mdot
.58264 .581 Mdot
.59224 .68185 Mdot
.52141 .45489 Mdot
.37179 .61769 Mdot
.41175 .3968 Mdot
.54356 .3543 Mdot
.46184 .80631 Mdot
.21596 .57248 Mdot
.68618 .35039 Mdot
.45738 .26178 Mdot
.41949 .64246 Mdot
.59743 .68563 Mdot
.54651 .23105 Mdot
.4533 .43095 Mdot
.41438 .40213 Mdot
.42802 .24298 Mdot
.53172 .32554 Mdot
.5679 .52155 Mdot
.34226 .346 Mdot
.52898 .30214 Mdot
.45113 .38833 Mdot
.42738 .36363 Mdot
.38142 .43935 Mdot
.43969 .43642 Mdot
.39002 .62663 Mdot
.33558 .52473 Mdot
.6885 .5088 Mdot
.22694 .56555 Mdot
.64779 .51096 Mdot
.41258 .36892 Mdot
.44816 .39232 Mdot
.25384 .54516 Mdot
.50058 .32305 Mdot
.38738 .64301 Mdot
.36568 .60397 Mdot
.57955 .6892 Mdot
.45434 .38039 Mdot
.72453 .52467 Mdot
.37536 .46075 Mdot
.70149 .49478 Mdot
.38833 .62764 Mdot
.69273 .54518 Mdot
.60884 .71846 Mdot
.68228 .53252 Mdot
.71776 .48777 Mdot
.62799 .69279 Mdot
.38278 .61137 Mdot
.426 .40002 Mdot
.62905 .69081 Mdot
.7188 .31124 Mdot
.67518 .32501 Mdot
.42733 .58933 Mdot
.39392 .34616 Mdot
.46488 .3936 Mdot
.67467 .68246 Mdot
.69844 .54114 Mdot
.52545 .38089 Mdot
.394 .61181 Mdot
.68801 .32068 Mdot
.39312 .62354 Mdot
.63648 .26232 Mdot
.68112 .35096 Mdot
.46047 .6059 Mdot
.51112 .24185 Mdot
.63102 .6556 Mdot
.40926 .45604 Mdot
.39731 .58728 Mdot
.7054 .49728 Mdot
.61696 .65701 Mdot
.52211 .66241 Mdot
.38883 .35635 Mdot
.46147 .59021 Mdot
.43831 .62078 Mdot
.47665 .59743 Mdot
.59644 .68248 Mdot
.40206 .55701 Mdot
.39523 .38146 Mdot
.62778 .65261 Mdot
.42968 .44195 Mdot
.31031 .6005 Mdot
.64578 .55577 Mdot
.47412 .64335 Mdot
.45064 .39392 Mdot
.70262 .48562 Mdot
.45102 .3914 Mdot
.27903 .64272 Mdot
.51864 .26081 Mdot
.38578 .44325 Mdot
.48345 .29992 Mdot
.67508 .65801 Mdot
.39068 .61837 Mdot
.44801 .33762 Mdot
.48843 .58328 Mdot
.42449 .36847 Mdot
.13234 .46023 Mdot
.66511 .35382 Mdot
.65195 .31674 Mdot
.39629 .3716 Mdot
.38055 .39166 Mdot
.28317 .35951 Mdot
.31684 .62141 Mdot
.49025 .60843 Mdot
.41317 .40829 Mdot
.39732 .25067 Mdot
.6107 .69829 Mdot
.44402 .4248 Mdot
.37711 .41846 Mdot
.63416 .5168 Mdot
.60446 .69691 Mdot
.68102 .5375 Mdot
.47506 .5974 Mdot
.67044 .5406 Mdot
.70074 .36231 Mdot
.46657 .27436 Mdot
.46982 .25399 Mdot
.51045 .46231 Mdot
.65118 .34878 Mdot
.42155 .37359 Mdot
.48145 .63517 Mdot
.39813 .37642 Mdot
.68816 .33818 Mdot
.59077 .68614 Mdot
.38971 .63251 Mdot
.30567 .6278 Mdot
.50115 .5872 Mdot
.43336 .39164 Mdot
.65444 .33124 Mdot
.39836 .63389 Mdot
.43161 .80866 Mdot
.38053 .62621 Mdot
.61961 .68659 Mdot
.62755 .65986 Mdot
.67591 .34936 Mdot
.3927 .62281 Mdot
.67563 .54471 Mdot
.54859 .66663 Mdot
.39148 .45629 Mdot
.60595 .71827 Mdot
.41412 .66388 Mdot
.39888 .66837 Mdot
.35454 .66068 Mdot
.44359 .37545 Mdot
.51713 .33539 Mdot
.33148 .36444 Mdot
.61741 .70428 Mdot
.70709 .4752 Mdot
.55206 .29003 Mdot
.31122 .4565 Mdot
.52744 .43196 Mdot
.45581 .34518 Mdot
.4103 .43045 Mdot
.39152 .42908 Mdot
.4211 .34891 Mdot
.56056 .58472 Mdot
.36691 .39873 Mdot
.59447 .69687 Mdot
.69466 .49933 Mdot
.41923 .39562 Mdot
.47957 .58656 Mdot
.58054 .54227 Mdot
.71361 .32703 Mdot
.32447 .56566 Mdot
.40918 .58533 Mdot
.39688 .63378 Mdot
.69588 .53609 Mdot
.68919 .54626 Mdot
.70551 .3279 Mdot
.62507 .67665 Mdot
.37641 .62915 Mdot
.47503 .18756 Mdot
.69015 .36183 Mdot
.39229 .42589 Mdot
.54443 .35687 Mdot
.36272 .25518 Mdot
.41012 .43915 Mdot
.38452 .4171 Mdot
.49099 .57814 Mdot
.728 .51625 Mdot
.19896 .5952 Mdot
.35299 .75062 Mdot
.67 .35088 Mdot
.70606 .33433 Mdot
.35304 .66571 Mdot
.42919 .41869 Mdot
.6074 .67398 Mdot
.49213 .28263 Mdot
.66276 .63274 Mdot
.49769 .68009 Mdot
.66081 .61472 Mdot
.39648 .43385 Mdot
.29743 .57641 Mdot
.42688 .4472 Mdot
.44335 .62078 Mdot
.3583 .64841 Mdot
.38981 .64736 Mdot
.61434 .69844 Mdot
.59627 .28222 Mdot
.58521 .69043 Mdot
.50783 .6288 Mdot
.41331 .64867 Mdot
.53446 .51721 Mdot
.7198 .5207 Mdot
.44385 .35878 Mdot
.69282 .33624 Mdot
.66591 .41097 Mdot
.45543 .34154 Mdot
.46018 .26554 Mdot
.6777 .53107 Mdot
.39464 .60751 Mdot
.43945 .35475 Mdot
.51696 .67225 Mdot
.54347 .37474 Mdot
.68185 .64409 Mdot
.44139 .67705 Mdot
.67076 .35911 Mdot
.20584 .52446 Mdot
.69853 .35236 Mdot
.6186 .67263 Mdot
.3707 .38993 Mdot
.42704 .41859 Mdot
.37672 .41325 Mdot
.45529 .42012 Mdot
.60692 .69393 Mdot
.38972 .45404 Mdot
.60163 .34287 Mdot
.48674 .60642 Mdot
.5629 .55441 Mdot
.66057 .33914 Mdot
.5864 .65221 Mdot
.69923 .49992 Mdot
.50789 .58534 Mdot
.66764 .32103 Mdot
.43172 .34969 Mdot
.4022 .37273 Mdot
.48747 .60731 Mdot
.42727 .32906 Mdot
.46091 .37496 Mdot
.68528 .5028 Mdot
.57236 .53294 Mdot
.71564 .3331 Mdot
.691 .35303 Mdot
.60297 .65356 Mdot
.39342 .62299 Mdot
.71343 .33322 Mdot
.67486 .48208 Mdot
.44671 .41955 Mdot
.42672 .44302 Mdot
.41107 .66539 Mdot
.58749 .28489 Mdot
.71355 .32662 Mdot
.38262 .34203 Mdot
.37559 .66154 Mdot
.4378 .6196 Mdot
.41215 .40819 Mdot
.36627 .43207 Mdot
.34545 .65945 Mdot
.70269 .3278 Mdot
.59633 .65173 Mdot
.53922 .4436 Mdot
.57596 .66854 Mdot
.39209 .65651 Mdot
.4774 .41782 Mdot
.38068 .61014 Mdot
.39095 .35532 Mdot
.73113 .75036 Mdot
.36601 .40293 Mdot
.3764 .49457 Mdot
.61605 .46786 Mdot
.72225 .51838 Mdot
.72176 .5042 Mdot
.48055 .59106 Mdot
.42313 .62045 Mdot
.46961 .35271 Mdot
.69716 .33625 Mdot
.51473 .80639 Mdot
.34968 .67989 Mdot
.71697 .48786 Mdot
.72427 .53157 Mdot
.59313 .68822 Mdot
.41534 .42913 Mdot
.4119 .39416 Mdot
.68265 .53385 Mdot
.6391 .58993 Mdot
.40372 .61909 Mdot
.39378 .39094 Mdot
.42484 .35275 Mdot
.68996 .50672 Mdot
.63573 .71289 Mdot
.42012 .66355 Mdot
.44105 .37224 Mdot
.51398 .26443 Mdot
.59362 .64612 Mdot
.43274 .37794 Mdot
.41292 .45567 Mdot
.67403 .34211 Mdot
.44878 .25402 Mdot
.58065 .28758 Mdot
.57324 .68051 Mdot
.4737 .59259 Mdot
.40765 .43794 Mdot
.72135 .51207 Mdot
.41529 .33886 Mdot
.31417 .7829 Mdot
.47991 .60564 Mdot
.39683 .38296 Mdot
.34889 .40066 Mdot
.38721 .66219 Mdot
.38657 .38922 Mdot
.5972 .62063 Mdot
.68638 .52527 Mdot
.39833 .38243 Mdot
.2859 .33702 Mdot
.59324 .68741 Mdot
.45003 .33889 Mdot
.67596 .36453 Mdot
.55651 .51744 Mdot
.23824 .32748 Mdot
.67557 .47229 Mdot
.6575 .34797 Mdot
.41742 .42568 Mdot
.65914 .51037 Mdot
.61946 .71119 Mdot
.34307 .45002 Mdot
.42691 .37645 Mdot
.57719 .6763 Mdot
.62202 .6972 Mdot
.67341 .35277 Mdot
.68307 .80695 Mdot
.37982 .43971 Mdot
.39879 .40656 Mdot
.57412 .83607 Mdot
.34317 .65972 Mdot
.3921 .41048 Mdot
.42289 .41516 Mdot
.61665 .66276 Mdot
.60604 .2522 Mdot
.4572 .26229 Mdot
.57864 .58285 Mdot
.59918 .64681 Mdot
.66321 .54189 Mdot
.67994 .52357 Mdot
.6583 .35293 Mdot
.38165 .63498 Mdot
.68869 .32159 Mdot
.69429 .51783 Mdot
.38083 .41653 Mdot
.59389 .65973 Mdot
.20738 .42349 Mdot
.6312 .68126 Mdot
.68564 .47225 Mdot
.44256 .62334 Mdot
.25287 .64853 Mdot
.34265 .81083 Mdot
.42434 .5201 Mdot
.60682 .64284 Mdot
.67148 .34636 Mdot
.36697 .76611 Mdot
.41985 .39535 Mdot
.28553 .62162 Mdot
.39791 .40996 Mdot
.40654 .695 Mdot
.67444 .49649 Mdot
.47746 .60836 Mdot
.38993 .35546 Mdot
.45375 .26088 Mdot
.62721 .68976 Mdot
.59849 .67006 Mdot
.37729 .36523 Mdot
.61898 .68373 Mdot
.40675 .38885 Mdot
.69412 .50345 Mdot
.71074 .76716 Mdot
.41751 .38397 Mdot
.4222 .47732 Mdot
.60795 .64009 Mdot
.41011 .58148 Mdot
.67442 .55732 Mdot
.32042 .53999 Mdot
.50317 .68671 Mdot
.60793 .6756 Mdot
.33539 .55618 Mdot
.70301 .5371 Mdot
.50791 .58351 Mdot
.66887 .54508 Mdot
.40547 .405 Mdot
.40178 .43465 Mdot
.41885 .34726 Mdot
.42057 .41937 Mdot
.27073 .61035 Mdot
.45905 .3687 Mdot
.23179 .46618 Mdot
.38002 .38225 Mdot
.38692 .49982 Mdot
.58788 .69181 Mdot
.41167 .47105 Mdot
.55261 .44693 Mdot
.36786 .4159 Mdot
.3537 .61356 Mdot
.58315 .65504 Mdot
.58535 .74746 Mdot
.60698 .6956 Mdot
.71574 .51475 Mdot
.62544 .68852 Mdot
.37322 .37778 Mdot
.37956 .65447 Mdot
.70039 .52804 Mdot
.42356 .51661 Mdot
.70026 .47567 Mdot
.39111 .38163 Mdot
.63449 .65624 Mdot
.7154 .53674 Mdot
.46539 .40355 Mdot
.37723 .6522 Mdot
.43718 .22705 Mdot
.45003 .61539 Mdot
.38533 .39606 Mdot
.38621 .40245 Mdot
.49048 .60759 Mdot
.62507 .68309 Mdot
.37276 .61401 Mdot
.632 .50593 Mdot
.6779 .31991 Mdot
.38389 .64225 Mdot
.37972 .46546 Mdot
.54391 .36763 Mdot
.38513 .66488 Mdot
.38164 .25305 Mdot
.61679 .66849 Mdot
.40307 .66062 Mdot
.34984 .43228 Mdot
.22679 .55903 Mdot
.69266 .35444 Mdot
.68167 .54907 Mdot
.53941 .31574 Mdot
.68158 .52426 Mdot
.59315 .62572 Mdot
.71081 .55219 Mdot
.60204 .69803 Mdot
.47142 .31855 Mdot
.54115 .50119 Mdot
.63105 .67404 Mdot
.59875 .63466 Mdot
.68501 .51238 Mdot
.40077 .34643 Mdot
.56276 .54264 Mdot
.47403 .35819 Mdot
.48194 .41589 Mdot
.57484 .66373 Mdot
.41037 .65593 Mdot
.38824 .60281 Mdot
.45264 .47075 Mdot
.36762 .6441 Mdot
.70435 .51789 Mdot
.50187 .46823 Mdot
.34093 .56215 Mdot
.58743 .68121 Mdot
.58009 .52613 Mdot
.44797 .38825 Mdot
.68553 .49396 Mdot
.70643 .51586 Mdot
.62101 .69674 Mdot
.24187 .59343 Mdot
.48186 .38432 Mdot
.3363 .66041 Mdot
.40495 .65636 Mdot
.38981 .66315 Mdot
.36597 .62669 Mdot
.59759 .27963 Mdot
.61642 .6568 Mdot
.42295 .62652 Mdot
.45748 .41259 Mdot
.42321 .42421 Mdot
.49076 .59828 Mdot
.68705 .32523 Mdot
.45569 .42656 Mdot
.46873 .35133 Mdot
.41225 .40619 Mdot
.72189 .5224 Mdot
.41253 .28487 Mdot
.48946 .605 Mdot
.7264 .51993 Mdot
.7255 .51704 Mdot
.47603 .59254 Mdot
.46622 .31232 Mdot
.20617 .59722 Mdot
.37417 .37073 Mdot
.35567 .60626 Mdot
.71879 .49883 Mdot
.63602 .40389 Mdot
.39759 .5096 Mdot
.43779 .41535 Mdot
.58148 .5671 Mdot
.69937 .50659 Mdot
.34473 .62953 Mdot
.40288 .40105 Mdot
.50188 .58211 Mdot
.68523 .36037 Mdot
.32607 .39221 Mdot
.49163 .57834 Mdot
.39533 .61818 Mdot
.68242 .45015 Mdot
.41284 .65795 Mdot
.70317 .54782 Mdot
.46142 .34549 Mdot
.84893 .65681 Mdot
.7074 .49954 Mdot
.53047 .80799 Mdot
.54233 .50369 Mdot
.411 .38061 Mdot
.69074 .53259 Mdot
.35471 .67843 Mdot
.59338 .64561 Mdot
.52754 .34438 Mdot
.38805 .62019 Mdot
.50839 .58637 Mdot
.49024 .59574 Mdot
.68838 .50762 Mdot
.40823 .64858 Mdot
.40321 .45684 Mdot
.37121 .64459 Mdot
.59192 .66428 Mdot
.39646 .35778 Mdot
.51063 .67077 Mdot
.4388 .46692 Mdot
.36969 .65106 Mdot
.69722 .47238 Mdot
.68314 .37158 Mdot
.40398 .36912 Mdot
.5661 .73358 Mdot
.41846 .42542 Mdot
.59325 .69036 Mdot
.61808 .44015 Mdot
.21084 .42617 Mdot
.39936 .42352 Mdot
.44681 .38744 Mdot
.61259 .71709 Mdot
.40151 .4224 Mdot
.41388 .44274 Mdot
.39996 .55743 Mdot
.38292 .6649 Mdot
.41939 .39865 Mdot
.6743 .51352 Mdot
.24823 .37964 Mdot
.37279 .39967 Mdot
.60171 .61909 Mdot
.42324 .23781 Mdot
.6024 .41495 Mdot
.48843 .42078 Mdot
.50438 .27086 Mdot
.39013 .404 Mdot
.43654 .41433 Mdot
.37526 .36853 Mdot
.29624 .58297 Mdot
.68984 .51753 Mdot
.69643 .48421 Mdot
.66216 .36611 Mdot
.42128 .24155 Mdot
.68154 .35649 Mdot
.62552 .7106 Mdot
.56825 .51957 Mdot
.49838 .60193 Mdot
.39476 .62297 Mdot
.37495 .40485 Mdot
.69269 .47654 Mdot
.40974 .39705 Mdot
.42695 .37058 Mdot
.70091 .51627 Mdot
.70483 .50962 Mdot
.68481 .46566 Mdot
.68193 .36618 Mdot
.3913 .63977 Mdot
.36911 .3871 Mdot
.69202 .36234 Mdot
.42709 .35219 Mdot
.53895 .42372 Mdot
.38992 .64235 Mdot
.36865 .65077 Mdot
.40842 .60527 Mdot
.41909 .37964 Mdot
.38496 .36135 Mdot
.5842 .68931 Mdot
.412 .66473 Mdot
.6128 .67282 Mdot
.68922 .53189 Mdot
.68116 .49952 Mdot
.40525 .40583 Mdot
.34394 .38537 Mdot
.6655 .33329 Mdot
.70686 .53986 Mdot
.46717 .58966 Mdot
.6666 .36607 Mdot
.38734 .42929 Mdot
.68473 .52832 Mdot
.65908 .33307 Mdot
.2284 .59342 Mdot
.45671 .69895 Mdot
.66717 .36878 Mdot
.38272 .35915 Mdot
.29776 .43534 Mdot
.52858 .26686 Mdot
.71136 .32321 Mdot
.58658 .68736 Mdot
.42558 .40783 Mdot
.56427 .59858 Mdot
.71077 .34629 Mdot
.57343 .28494 Mdot
.69936 .52119 Mdot
.46639 .44204 Mdot
.33435 .33409 Mdot
.34809 .55828 Mdot
.68852 .36933 Mdot
.37109 .65317 Mdot
.37943 .6703 Mdot
.3936 .42524 Mdot
.56196 .51798 Mdot
.63074 .70349 Mdot
.68799 .54629 Mdot
.69425 .48192 Mdot
.37232 .66859 Mdot
.51295 .46142 Mdot
.67514 .51654 Mdot
.43123 .41437 Mdot
.70959 .36144 Mdot
.45743 .3868 Mdot
.6304 .28751 Mdot
.23563 .36891 Mdot
.4846 .4297 Mdot
.67897 .37215 Mdot
.62305 .70637 Mdot
.61451 .70131 Mdot
.6184 .69352 Mdot
.67973 .50627 Mdot
.52311 .31116 Mdot
.68625 .48279 Mdot
.53192 .83665 Mdot
.66489 .35583 Mdot
.50222 .18273 Mdot
.44513 .43494 Mdot
.40861 .37931 Mdot
.45121 .41014 Mdot
.41849 .35091 Mdot
.39084 .40265 Mdot
.57848 .6831 Mdot
.66388 .52858 Mdot
.66129 .62354 Mdot
.41091 .63399 Mdot
.42475 .80592 Mdot
.71945 .52258 Mdot
.48662 .57865 Mdot
.67667 .3305 Mdot
.44698 .24153 Mdot
.67156 .37878 Mdot
.70355 .54364 Mdot
.38961 .43982 Mdot
.35372 .66804 Mdot
.46443 .19051 Mdot
.37829 .39523 Mdot
.70226 .54138 Mdot
.65563 .52123 Mdot
.23003 .57726 Mdot
.35234 .33785 Mdot
.64283 .58329 Mdot
.53758 .36496 Mdot
.65752 .36789 Mdot
.38931 .34639 Mdot
.48125 .2747 Mdot
.69309 .51592 Mdot
.709 .49349 Mdot
.69766 .31904 Mdot
.32364 .68521 Mdot
.42057 .63107 Mdot
.44367 .59659 Mdot
.58001 .67014 Mdot
.40388 .37487 Mdot
.68129 .51543 Mdot
.44831 .60608 Mdot
.56169 .39198 Mdot
.60952 .69042 Mdot
.72459 .5292 Mdot
.42057 .42319 Mdot
.40179 .42475 Mdot
.67849 .35662 Mdot
.60224 .49828 Mdot
.47411 .35842 Mdot
.51798 .80652 Mdot
.52688 .40485 Mdot
.54355 .50384 Mdot
.41451 .40174 Mdot
.3712 .62087 Mdot
.4771 .59205 Mdot
.69109 .33287 Mdot
.42253 .34065 Mdot
.2692 .6726 Mdot
.42798 .62992 Mdot
.6138 .67472 Mdot
.47547 .58593 Mdot
.47037 .28032 Mdot
.42002 .42273 Mdot
.39838 .4096 Mdot
.44526 .37758 Mdot
.23396 .63753 Mdot
.67794 .49314 Mdot
.36637 .62978 Mdot
.67231 .36264 Mdot
.37395 .62808 Mdot
.715 .5457 Mdot
.57978 .52855 Mdot
.36626 .38775 Mdot
.4252 .61505 Mdot
.37465 .63568 Mdot
.59163 .68604 Mdot
.62927 .69206 Mdot
.66785 .48408 Mdot
.42276 .40971 Mdot
.50069 .60074 Mdot
.42058 .63865 Mdot
.67501 .54031 Mdot
.67944 .35526 Mdot
.5885 .62542 Mdot
.38194 .37969 Mdot
.68888 .51122 Mdot
.46005 .34344 Mdot
.40548 .63705 Mdot
.71419 .53413 Mdot
.50644 .58074 Mdot
.69857 .32657 Mdot
.40504 .43591 Mdot
.67842 .62387 Mdot
.49684 .58037 Mdot
.41038 .37256 Mdot
.23105 .38634 Mdot
.56217 .51852 Mdot
.41009 .68338 Mdot
.67056 .507 Mdot
.50469 .58778 Mdot
.36068 .64507 Mdot
.22015 .53549 Mdot
.70236 .49127 Mdot
.28247 .38336 Mdot
.53314 .49645 Mdot
.38221 .36075 Mdot
.39164 .61897 Mdot
.63714 .31421 Mdot
.4846 .79868 Mdot
.53763 .27612 Mdot
.3994 .38613 Mdot
.68116 .5235 Mdot
.68676 .35838 Mdot
.59989 .66941 Mdot
.56066 .65761 Mdot
.65758 .27301 Mdot
.72454 .4989 Mdot
.3746 .40552 Mdot
.40913 .65667 Mdot
.6168 .67842 Mdot
.27525 .36597 Mdot
.66878 .49308 Mdot
.67375 .51881 Mdot
.44096 .42224 Mdot
.68349 .35607 Mdot
.54787 .60395 Mdot
.68381 .48936 Mdot
.66162 .5253 Mdot
.40138 .55178 Mdot
.65461 .3633 Mdot
.43597 .36744 Mdot
.4522 .47111 Mdot
.43972 .4342 Mdot
.48512 .82598 Mdot
.50504 .58973 Mdot
.41141 .63105 Mdot
.38669 .41106 Mdot
.67653 .66969 Mdot
.69841 .49502 Mdot
.53693 .36605 Mdot
.63918 .70651 Mdot
.62893 .6888 Mdot
.68827 .52533 Mdot
.40416 .39453 Mdot
.61001 .72283 Mdot
.65936 .34956 Mdot
.43592 .36661 Mdot
.38978 .35663 Mdot
.39937 .67359 Mdot
.59139 .66137 Mdot
.24645 .37638 Mdot
.60027 .66615 Mdot
.61264 .65794 Mdot
.43987 .64145 Mdot
.39365 .42561 Mdot
.71465 .52976 Mdot
.72114 .47846 Mdot
.37516 .34802 Mdot
.65488 .41249 Mdot
.41898 .62009 Mdot
.71562 .56059 Mdot
.26505 .67187 Mdot
.41854 .44607 Mdot
.46835 .59127 Mdot
.46059 .65755 Mdot
.63027 .66359 Mdot
.39199 .42078 Mdot
.39897 .62402 Mdot
.66207 .51052 Mdot
.67822 .51671 Mdot
.455 .42866 Mdot
.61802 .70136 Mdot
.6655 .32806 Mdot
.70764 .51914 Mdot
.53526 .45265 Mdot
.39344 .38311 Mdot
.56284 .71163 Mdot
.70859 .52191 Mdot
.26277 .27341 Mdot
.67654 .67999 Mdot
.38895 .66463 Mdot
.44581 .40209 Mdot
.37752 .67316 Mdot
.65621 .35749 Mdot
.69074 .55642 Mdot
.60011 .70024 Mdot
.40183 .3227 Mdot
.80472 .60995 Mdot
.68157 .50824 Mdot
.389 .62861 Mdot
.38036 .41292 Mdot
.34105 .54898 Mdot
.41987 .39068 Mdot
.60511 .24712 Mdot
.71574 .3274 Mdot
.60158 .62603 Mdot
.61672 .70507 Mdot
.44605 .38836 Mdot
.7014 .35273 Mdot
.7141 .47263 Mdot
.69997 .51612 Mdot
.78303 .6728 Mdot
.49569 .57797 Mdot
.74151 .51901 Mdot
.41622 .37776 Mdot
.67874 .54069 Mdot
.31243 .45807 Mdot
.62385 .69658 Mdot
.43489 .43715 Mdot
.73013 .50298 Mdot
.44058 .79756 Mdot
.5409 .36491 Mdot
.39593 .38407 Mdot
.34451 .398 Mdot
.59855 .69433 Mdot
.3658 .76522 Mdot
.67077 .4999 Mdot
.42795 .34843 Mdot
.63367 .70871 Mdot
.49016 .3462 Mdot
.62624 .51214 Mdot
.39137 .64028 Mdot
.73206 .51533 Mdot
.59382 .65307 Mdot
.46119 .44868 Mdot
.67566 .32677 Mdot
.67015 .48652 Mdot
.71631 .48199 Mdot
.40165 .36124 Mdot
.43901 .36324 Mdot
.34394 .40591 Mdot
.40416 .61459 Mdot
.61276 .66042 Mdot
.42551 .3658 Mdot
.53927 .41297 Mdot
.4183 .35324 Mdot
.60465 .65614 Mdot
.76063 .75803 Mdot
.39076 .43894 Mdot
.38655 .3773 Mdot
.32705 .55398 Mdot
.37493 .61094 Mdot
.37433 .66441 Mdot
.52928 .4151 Mdot
.42799 .39477 Mdot
.53016 .51764 Mdot
.39198 .63612 Mdot
.38546 .62719 Mdot
.53144 .51749 Mdot
.39262 .3608 Mdot
.4549 .59446 Mdot
.61794 .68009 Mdot
.62913 .68924 Mdot
.38664 .6621 Mdot
.45566 .38526 Mdot
.62001 .71038 Mdot
.26062 .58472 Mdot
.70956 .541 Mdot
.47598 .27339 Mdot
.37245 .63969 Mdot
.54681 .35301 Mdot
.61852 .67144 Mdot
.28655 .27949 Mdot
.37611 .24774 Mdot
.40214 .44982 Mdot
.39473 .4243 Mdot
.67729 .34292 Mdot
.41875 .32569 Mdot
.47612 .59488 Mdot
.62007 .69252 Mdot
.56078 .58355 Mdot
.38945 .64815 Mdot
.42663 .39536 Mdot
.55514 .29481 Mdot
.24054 .33018 Mdot
.41026 .48696 Mdot
.38185 .63292 Mdot
.38452 .6523 Mdot
.6734 .52408 Mdot
.70134 .54566 Mdot
.36655 .38928 Mdot
.60831 .70062 Mdot
.39669 .66386 Mdot
.60101 .65768 Mdot
.69448 .51674 Mdot
.71754 .52338 Mdot
.4858 .60397 Mdot
.48536 .40533 Mdot
.69242 .52447 Mdot
.62628 .61857 Mdot
.53914 .41467 Mdot
.41769 .66144 Mdot
.5597 .83785 Mdot
.30419 .26477 Mdot
.30878 .61011 Mdot
.68641 .35934 Mdot
.47661 .32397 Mdot
.59036 .70072 Mdot
.44445 .3847 Mdot
.40113 .41393 Mdot
.49705 .59005 Mdot
.59683 .70578 Mdot
.67055 .33724 Mdot
.62692 .69286 Mdot
.69546 .33112 Mdot
.70096 .48425 Mdot
.37438 .39991 Mdot
.36836 .41386 Mdot
.59791 .67143 Mdot
.68276 .53827 Mdot
.7161 .53586 Mdot
.69771 .34799 Mdot
.44095 .23939 Mdot
.68981 .50895 Mdot
.37273 .63749 Mdot
.26301 .40445 Mdot
.49188 .59511 Mdot
.40231 .40045 Mdot
.49992 .26782 Mdot
.22091 .51536 Mdot
.41311 .34525 Mdot
.48037 .5833 Mdot
.68869 .80377 Mdot
.37244 .39649 Mdot
.82511 .56314 Mdot
.49635 .60222 Mdot
.38001 .61016 Mdot
.70566 .53377 Mdot
.49106 .57906 Mdot
.39462 .28565 Mdot
.6542 .56963 Mdot
.38705 .34347 Mdot
.42125 .62878 Mdot
.40532 .60683 Mdot
.57626 .53048 Mdot
.48169 .82604 Mdot
.67334 .36289 Mdot
.66339 .34465 Mdot
.69688 .49176 Mdot
.57038 .6308 Mdot
.46001 .39806 Mdot
.66476 .3465 Mdot
.4485 .58398 Mdot
.44973 .39292 Mdot
.5635 .52038 Mdot
.56224 .54845 Mdot
.36226 .65006 Mdot
.41454 .46902 Mdot
.69792 .49313 Mdot
.38859 .63048 Mdot
.5665 .53732 Mdot
.44284 .42419 Mdot
.38961 .64473 Mdot
.62102 .66854 Mdot
.49491 .53442 Mdot
.36975 .64325 Mdot
.53153 .35095 Mdot
.60271 .67443 Mdot
.57108 .52262 Mdot
.54269 .21225 Mdot
.17941 .35766 Mdot
.61519 .69994 Mdot
.70007 .53971 Mdot
.68239 .51501 Mdot
.69112 .50488 Mdot
.39443 .61514 Mdot
.70583 .50503 Mdot
.41563 .63229 Mdot
.58287 .63925 Mdot
.43826 .24878 Mdot
.67864 .34957 Mdot
.62362 .33887 Mdot
.38117 .65905 Mdot
.51825 .83477 Mdot
.47212 .86677 Mdot
.4242 .35563 Mdot
.62933 .67012 Mdot
.68419 .368 Mdot
.5211 .41211 Mdot
.67519 .34171 Mdot
.70201 .53714 Mdot
.4612 .26907 Mdot
.40797 .38904 Mdot
.49582 .65831 Mdot
.6868 .3577 Mdot
.38425 .62628 Mdot
.4159 .37041 Mdot
.73471 .51634 Mdot
.65695 .35332 Mdot
.69395 .34945 Mdot
.39275 .40248 Mdot
.39192 .60756 Mdot
.71125 .53706 Mdot
.57768 .68817 Mdot
.70057 .37192 Mdot
.35232 .35032 Mdot
.37028 .40405 Mdot
.37402 .43102 Mdot
.53751 .37456 Mdot
.56228 .63346 Mdot
.60403 .67645 Mdot
.57295 .28845 Mdot
.68378 .49524 Mdot
.53859 .27458 Mdot
.50983 .79608 Mdot
.645 .31024 Mdot
.5042 .59055 Mdot
.50523 .59106 Mdot
.38943 .39027 Mdot
.36261 .81256 Mdot
.37738 .48582 Mdot
.64406 .69786 Mdot
.49225 .59142 Mdot
.71046 .54264 Mdot
.4105 .66318 Mdot
.33691 .33507 Mdot
.45121 .43051 Mdot
.5786 .69108 Mdot
.69562 .51196 Mdot
.30848 .7798 Mdot
.66736 .35675 Mdot
.52044 .42354 Mdot
.42179 .41316 Mdot
.39442 .39337 Mdot
.60414 .68604 Mdot
.59718 .69836 Mdot
.40045 .5504 Mdot
.59705 .39963 Mdot
.50234 .68107 Mdot
.57395 .69023 Mdot
.30675 .77929 Mdot
.43389 .68335 Mdot
.39736 .65313 Mdot
.4719 .59512 Mdot
.62854 .70392 Mdot
.38995 .41089 Mdot
.3806 .60863 Mdot
.36558 .47498 Mdot
.35633 .62322 Mdot
.55658 .51687 Mdot
.53874 .4441 Mdot
.4107 .43003 Mdot
.35364 .65391 Mdot
.38814 .63555 Mdot
.40207 .59418 Mdot
.48148 .59495 Mdot
.41459 .40555 Mdot
.42174 .34505 Mdot
.37113 .39203 Mdot
.39598 .52733 Mdot
.3865 .3887 Mdot
.50408 .79707 Mdot
.53 .43374 Mdot
.76095 .37779 Mdot
.37602 .39007 Mdot
.62108 .66586 Mdot
.37676 .40338 Mdot
.70485 .34693 Mdot
.40022 .4377 Mdot
.55253 .51338 Mdot
.61438 .68235 Mdot
.27694 .64928 Mdot
.65039 .50998 Mdot
.37045 .41448 Mdot
.65114 .34613 Mdot
.6078 .80278 Mdot
.56963 .293 Mdot
.40327 .55213 Mdot
.3714 .6444 Mdot
.65875 .51806 Mdot
.63554 .69459 Mdot
.71669 .51577 Mdot
.3952 .45685 Mdot
.47611 .60196 Mdot
.48159 .15945 Mdot
.55666 .35214 Mdot
.38767 .4105 Mdot
.48275 .38941 Mdot
.36525 .64485 Mdot
.70136 .49641 Mdot
.31111 .63293 Mdot
.4526 .40288 Mdot
.69876 .32383 Mdot
.7029 .3559 Mdot
.7612 .51607 Mdot
.4655 .54621 Mdot
.34281 .48398 Mdot
.60495 .68437 Mdot
.67829 .50921 Mdot
.69749 .36225 Mdot
.41096 .58801 Mdot
.63285 .69626 Mdot
.63079 .66407 Mdot
.59002 .66144 Mdot
.39537 .37884 Mdot
.4894 .6016 Mdot
.47135 .56023 Mdot
.50111 .57996 Mdot
.4508 .42104 Mdot
.71819 .48358 Mdot
.50696 .5829 Mdot
.68375 .34607 Mdot
.60116 .65199 Mdot
.72099 .52195 Mdot
.38456 .39997 Mdot
.3962 .63606 Mdot
.6108 .31516 Mdot
.68231 .6748 Mdot
.56382 .5186 Mdot
.56395 .51863 Mdot
.43137 .61556 Mdot
.51981 .62391 Mdot
.57484 .63525 Mdot
.22659 .56806 Mdot
.72597 .32126 Mdot
.41106 .33188 Mdot
.69997 .43667 Mdot
.68398 .48363 Mdot
.70188 .52685 Mdot
.4086 .38513 Mdot
.67028 .52983 Mdot
.42445 .39582 Mdot
.66969 .50827 Mdot
.48066 .80811 Mdot
.42881 .44869 Mdot
.70399 .52019 Mdot
.36254 .32872 Mdot
.40401 .3694 Mdot
.37051 .62431 Mdot
.66497 .50007 Mdot
.40311 .44983 Mdot
.6026 .15217 Mdot
.59123 .68322 Mdot
.48291 .59549 Mdot
.5449 .4829 Mdot
.62195 .6788 Mdot
.4164 .6394 Mdot
.42887 .40952 Mdot
.66336 .35705 Mdot
.39211 .65596 Mdot
.68949 .56891 Mdot
.68808 .35434 Mdot
.5014 .47095 Mdot
.39077 .65942 Mdot
.4953 .5953 Mdot
.70394 .3292 Mdot
.38526 .34451 Mdot
.7015 .52455 Mdot
.67953 .68346 Mdot
.48204 .58152 Mdot
.41014 .39265 Mdot
.73036 .52641 Mdot
.62661 .68917 Mdot
.38044 .42265 Mdot
.68022 .51587 Mdot
.47412 .58985 Mdot
.39181 .37203 Mdot
.42298 .38064 Mdot
.31863 .67649 Mdot
.62245 .45021 Mdot
.68098 .34823 Mdot
.44187 .62532 Mdot
.45484 .4195 Mdot
.6997 .35313 Mdot
.6577 .60668 Mdot
.38459 .45913 Mdot
.42417 .63228 Mdot
.25213 .58618 Mdot
.68539 .545 Mdot
.62124 .70215 Mdot
.68931 .47133 Mdot
.65801 .36356 Mdot
.53229 .87565 Mdot
.47629 .59745 Mdot
.35499 .40633 Mdot
.41529 .44374 Mdot
.67773 .55236 Mdot
.38681 .63895 Mdot
.50066 .67971 Mdot
.4094 .43603 Mdot
.47645 .41247 Mdot
.39786 .4018 Mdot
.67458 .60932 Mdot
.39884 .61395 Mdot
.40049 .4017 Mdot
.36683 .34628 Mdot
.42527 .44301 Mdot
.65776 .33704 Mdot
.49781 .18156 Mdot
.3998 .34888 Mdot
.88672 .60197 Mdot
.47075 .60493 Mdot
.69987 .51174 Mdot
.53156 .35559 Mdot
.55164 .4794 Mdot
.74004 .2886 Mdot
.41871 .62929 Mdot
.36636 .59913 Mdot
.71629 .52429 Mdot
.65303 .29161 Mdot
.52345 .62064 Mdot
.42238 .37698 Mdot
.42417 .41448 Mdot
.70212 .53711 Mdot
.67584 .54204 Mdot
.47218 .6033 Mdot
.37042 .3705 Mdot
.43463 .46739 Mdot
.70032 .47324 Mdot
.38034 .39191 Mdot
.21781 .49051 Mdot
.60744 .647 Mdot
.38366 .66349 Mdot
.59763 .6692 Mdot
.59873 .64484 Mdot
.30623 .62693 Mdot
.52859 .39802 Mdot
.57854 .67318 Mdot
.63514 .66403 Mdot
.63083 .32027 Mdot
.34188 .5593 Mdot
.66036 .33414 Mdot
.45473 .52634 Mdot
.68824 .49857 Mdot
.41395 .40774 Mdot
.39554 .61359 Mdot
.64029 .23223 Mdot
.51099 .70786 Mdot
.37608 .27733 Mdot
.43732 .36951 Mdot
.69443 .49646 Mdot
.47673 .58393 Mdot
.38495 .45969 Mdot
.53155 .26912 Mdot
.39605 .38854 Mdot
.69281 .54714 Mdot
.34202 .56136 Mdot
.6652 .69696 Mdot
.56727 .6763 Mdot
.34486 .6729 Mdot
.37627 .4045 Mdot
.40658 .62119 Mdot
.5781 .6591 Mdot
.68916 .36158 Mdot
.67104 .34777 Mdot
.37113 .41683 Mdot
.54187 .50379 Mdot
.72135 .29651 Mdot
.41901 .37433 Mdot
.39823 .36023 Mdot
.50341 .58892 Mdot
.3979 .35956 Mdot
.41308 .34151 Mdot
.42903 .36725 Mdot
.43024 .35491 Mdot
.63117 .69996 Mdot
.32206 .60001 Mdot
.36295 .38143 Mdot
.36483 .42832 Mdot
.57718 .65048 Mdot
.37879 .44652 Mdot
.60894 .69655 Mdot
.51904 .69004 Mdot
.58045 .67661 Mdot
.67232 .34867 Mdot
.73149 .52628 Mdot
.34315 .59939 Mdot
.39727 .66331 Mdot
.62751 .67503 Mdot
.69318 .32703 Mdot
.61784 .69676 Mdot
.67654 .50325 Mdot
.66881 .66478 Mdot
.42071 .67051 Mdot
.5295 .46062 Mdot
.32629 .56585 Mdot
.60258 .74031 Mdot
.67309 .53041 Mdot
.39195 .66334 Mdot
.59381 .62165 Mdot
.4441 .38558 Mdot
.66888 .36041 Mdot
.38977 .39094 Mdot
.60612 .65379 Mdot
.69129 .49789 Mdot
.39476 .57222 Mdot
.68082 .34716 Mdot
.59471 .83465 Mdot
.69174 .47621 Mdot
.40677 .44242 Mdot
.57581 .65322 Mdot
.64716 .62143 Mdot
.59572 .69435 Mdot
.43983 .24755 Mdot
.48077 .63876 Mdot
.64829 .2476 Mdot
.38502 .65538 Mdot
.49381 .57479 Mdot
.15659 .44003 Mdot
.56026 .76443 Mdot
.40203 .6365 Mdot
.68202 .45445 Mdot
.38584 .38499 Mdot
.42597 .36033 Mdot
.48369 .4033 Mdot
.36842 .61246 Mdot
.44582 .37837 Mdot
.48306 .59839 Mdot
.53287 .39844 Mdot
.49727 .56483 Mdot
.65909 .50267 Mdot
.42294 .3953 Mdot
.57467 .66471 Mdot
.62784 .67313 Mdot
.50997 .58781 Mdot
.59731 .66349 Mdot
.3834 .37077 Mdot
.38262 .65821 Mdot
.56344 .5417 Mdot
.65766 .35881 Mdot
.54371 .80018 Mdot
.71945 .30741 Mdot
.66559 .38009 Mdot
.42112 .44568 Mdot
.71687 .5262 Mdot
.80813 .58609 Mdot
.44359 .38039 Mdot
.39121 .6333 Mdot
.41711 .44238 Mdot
.4235 .36141 Mdot
.37136 .37827 Mdot
.67874 .50864 Mdot
.54316 .3621 Mdot
.37959 .3927 Mdot
.57787 .66747 Mdot
.53224 .51491 Mdot
.455 .42628 Mdot
.58404 .57879 Mdot
.55352 .51477 Mdot
.5726 .72148 Mdot
.40735 .66974 Mdot
.71217 .53099 Mdot
.38884 .65041 Mdot
.34759 .64541 Mdot
.41604 .63986 Mdot
.48475 .56116 Mdot
.22455 .55705 Mdot
.82998 .55263 Mdot
.31811 .46468 Mdot
.32057 .57173 Mdot
.34802 .67312 Mdot
.74792 .58485 Mdot
.40268 .63074 Mdot
.41741 .63617 Mdot
.74351 .74905 Mdot
.40931 .6117 Mdot
.4062 .40553 Mdot
.3709 .42411 Mdot
.25008 .64488 Mdot
.65695 .38218 Mdot
.41058 .37443 Mdot
.42402 .3505 Mdot
.70127 .35846 Mdot
.32181 .6704 Mdot
.4669 .59682 Mdot
.51889 .43473 Mdot
.4907 .5767 Mdot
.39204 .40208 Mdot
.39733 .43063 Mdot
.43757 .34233 Mdot
.20796 .36374 Mdot
.66109 .25765 Mdot
.40451 .60509 Mdot
.39783 .33511 Mdot
.62895 .74116 Mdot
.43218 .42196 Mdot
.42533 .43824 Mdot
.3745 .3743 Mdot
.71479 .52967 Mdot
.42319 .64727 Mdot
.4709 .35384 Mdot
.56421 .78385 Mdot
.41709 .42471 Mdot
.71491 .30105 Mdot
.64276 .34015 Mdot
.40499 .39553 Mdot
.41416 .61235 Mdot
.4295 .36251 Mdot
.39059 .66959 Mdot
.39445 .65816 Mdot
.46706 .43489 Mdot
.46077 .56218 Mdot
.41056 .66252 Mdot
.42348 .37841 Mdot
.68029 .53722 Mdot
.52257 .80722 Mdot
.40911 .39296 Mdot
.68702 .34848 Mdot
.38844 .42026 Mdot
.65433 .34054 Mdot
.40067 .35363 Mdot
.50504 .58257 Mdot
.20521 .43341 Mdot
.70764 .49186 Mdot
.68118 .37923 Mdot
.67441 .53536 Mdot
.45907 .38313 Mdot
.37847 .67637 Mdot
.65767 .70906 Mdot
.66966 .26756 Mdot
.503 .58978 Mdot
.58991 .28793 Mdot
.52897 .52937 Mdot
.58775 .69585 Mdot
.3651 .63191 Mdot
.33176 .57927 Mdot
.58265 .57585 Mdot
.65738 .50593 Mdot
.72239 .53394 Mdot
.63308 .4894 Mdot
.71101 .76699 Mdot
.37977 .38691 Mdot
.57182 .59533 Mdot
.23027 .45795 Mdot
.42314 .32698 Mdot
.34266 .34439 Mdot
.7136 .47986 Mdot
.41074 .37423 Mdot
.55509 .33322 Mdot
.68562 .51358 Mdot
.66518 .33614 Mdot
.41152 .62894 Mdot
.70203 .3419 Mdot
.45692 .71482 Mdot
.3988 .55651 Mdot
.69029 .52082 Mdot
.43357 .35933 Mdot
.41235 .37901 Mdot
.37281 .61306 Mdot
.27699 .36452 Mdot
.38233 .66483 Mdot
.66295 .36288 Mdot
.69755 .48868 Mdot
.54518 .1501 Mdot
.38142 .41589 Mdot
.37602 .63329 Mdot
.65048 .50766 Mdot
.40426 .42424 Mdot
.62108 .70059 Mdot
.44785 .38192 Mdot
.37606 .62799 Mdot
.39828 .35915 Mdot
.38688 .65644 Mdot
.67746 .52883 Mdot
.37035 .41774 Mdot
.38716 .42857 Mdot
.57714 .28726 Mdot
.67198 .33686 Mdot
.40118 .66749 Mdot
.5503 .32896 Mdot
.4398 .43414 Mdot
.51687 .26479 Mdot
.37385 .39918 Mdot
.338 .55654 Mdot
.35967 .44225 Mdot
.48615 .599 Mdot
.41927 .44224 Mdot
.40784 .39169 Mdot
.28269 .35988 Mdot
.30728 .45117 Mdot
.39872 .53014 Mdot
.62948 .69324 Mdot
.3851 .6165 Mdot
.68408 .51848 Mdot
.66098 .50888 Mdot
.71001 .50945 Mdot
.71812 .32471 Mdot
.37116 .34896 Mdot
.4138 .39391 Mdot
.64507 .68212 Mdot
.66488 .35071 Mdot
.37875 .63666 Mdot
.67398 .35255 Mdot
.5278 .39272 Mdot
.6887 .345 Mdot
.4749 .59473 Mdot
.6749 .6722 Mdot
.22078 .50415 Mdot
.68768 .33374 Mdot
.38599 .66355 Mdot
.52492 .51134 Mdot
.43357 .33171 Mdot
.44948 .81597 Mdot
.70266 .32506 Mdot
.6375 .49755 Mdot
.3828 .37585 Mdot
.52757 .33972 Mdot
.6081 .69436 Mdot
.70205 .34037 Mdot
.58852 .6637 Mdot
.43059 .36381 Mdot
.33952 .6861 Mdot
.39156 .62475 Mdot
.60204 .6442 Mdot
.43268 .43653 Mdot
.70236 .34093 Mdot
.69447 .52336 Mdot
.34431 .55827 Mdot
.59192 .64002 Mdot
.61113 .32141 Mdot
.5388 .27632 Mdot
.69182 .49057 Mdot
.34151 .52821 Mdot
.58255 .67261 Mdot
.40087 .33465 Mdot
.34637 .44891 Mdot
.45582 .40171 Mdot
.71748 .53468 Mdot
.70255 .52739 Mdot
.59282 .74241 Mdot
.39149 .43081 Mdot
.36037 .38763 Mdot
.43239 .6424 Mdot
.69249 .48877 Mdot
.41468 .64308 Mdot
.35728 .65904 Mdot
.69783 .53925 Mdot
.38339 .66692 Mdot
.69003 .35364 Mdot
.50639 .29645 Mdot
.58188 .67281 Mdot
.61499 .70428 Mdot
.69085 .52326 Mdot
.71471 .48934 Mdot
.71765 .52506 Mdot
.44832 .41131 Mdot
.40262 .65598 Mdot
.44484 .39903 Mdot
.37718 .40742 Mdot
.45875 .60824 Mdot
.43223 .65 Mdot
.43738 .42149 Mdot
.55988 .55173 Mdot
.7003 .32215 Mdot
.70411 .5159 Mdot
.6084 .65998 Mdot
.61668 .30447 Mdot
.57593 .67999 Mdot
.43885 .43702 Mdot
.44691 .80307 Mdot
.39179 .61704 Mdot
.67623 .34205 Mdot
.55546 .51391 Mdot
.67959 .34488 Mdot
.60557 .64594 Mdot
.4353 .61735 Mdot
.50711 .46601 Mdot
.38725 .43009 Mdot
.53693 .37727 Mdot
.55067 .23175 Mdot
.51814 .79298 Mdot
.61631 .66321 Mdot
.42799 .3596 Mdot
.50096 .59677 Mdot
.22565 .57173 Mdot
.41221 .39072 Mdot
.41953 .44995 Mdot
.56343 .49507 Mdot
.41172 .44567 Mdot
.40902 .60231 Mdot
.56038 .52318 Mdot
.39874 .34549 Mdot
.45523 .37534 Mdot
.75324 .71216 Mdot
.3993 .37106 Mdot
.37985 .4252 Mdot
.40736 .41231 Mdot
.4487 .39378 Mdot
.37868 .67346 Mdot
.58558 .51939 Mdot
.57861 .65542 Mdot
.50627 .2961 Mdot
.58544 .66384 Mdot
.69235 .53028 Mdot
.59363 .37808 Mdot
.38507 .67161 Mdot
.6801 .34456 Mdot
.58532 .59539 Mdot
.46007 .27036 Mdot
.67437 .52649 Mdot
.6007 .27435 Mdot
.67246 .32592 Mdot
.44102 .33307 Mdot
.65773 .36461 Mdot
.72733 .49224 Mdot
.61791 .70091 Mdot
.39053 .44001 Mdot
.41887 .64103 Mdot
.36945 .64441 Mdot
.45777 .40633 Mdot
.56258 .79635 Mdot
.62418 .70153 Mdot
.6381 .39928 Mdot
.4016 .37927 Mdot
.43517 .43692 Mdot
.37824 .66644 Mdot
.69936 .49663 Mdot
.53015 .52764 Mdot
.68212 .32916 Mdot
.42689 .42393 Mdot
.41914 .35025 Mdot
.52883 .39002 Mdot
.63168 .68503 Mdot
.48514 .58877 Mdot
.41825 .39297 Mdot
.524 .4243 Mdot
.44943 .38289 Mdot
.44544 .35348 Mdot
.6871 .5432 Mdot
.47311 .42314 Mdot
.40804 .43355 Mdot
.35517 .69218 Mdot
.58357 .67273 Mdot
.38936 .63994 Mdot
.3666 .60208 Mdot
.50586 .58517 Mdot
.59177 .68065 Mdot
.43647 .4252 Mdot
.63066 .66737 Mdot
.42465 .36063 Mdot
.38208 .39771 Mdot
.61854 .66531 Mdot
.41166 .64499 Mdot
.5202 .65918 Mdot
.32322 .59853 Mdot
.42703 .36983 Mdot
.39315 .42168 Mdot
.65664 .38198 Mdot
.66564 .2363 Mdot
.39713 .43402 Mdot
.39188 .66424 Mdot
.4017 .42512 Mdot
.5955 .6998 Mdot
.67478 .36304 Mdot
.39516 .63206 Mdot
.68246 .49312 Mdot
.67684 .52618 Mdot
.65929 .48167 Mdot
.47439 .59539 Mdot
.36494 .38063 Mdot
.44169 .62585 Mdot
.43742 .6422 Mdot
.5179 .31591 Mdot
.70069 .51295 Mdot
.67939 .36178 Mdot
.41658 .37692 Mdot
.40994 .32289 Mdot
.59956 .64614 Mdot
.89747 .58242 Mdot
.51084 .46172 Mdot
.66985 .32058 Mdot
.59818 .41289 Mdot
.50063 .58733 Mdot
.39584 .37375 Mdot
.70402 .34608 Mdot
.69025 .53536 Mdot
.42581 .35991 Mdot
.34941 .41275 Mdot
.64939 .58742 Mdot
.72317 .50491 Mdot
.62446 .65755 Mdot
.67218 .50236 Mdot
.66269 .3307 Mdot
.47633 .5954 Mdot
.37342 .62403 Mdot
.4018 .39075 Mdot
.42062 .47135 Mdot
.69345 .50303 Mdot
.49598 .60542 Mdot
.36752 .40677 Mdot
.38261 .61535 Mdot
.70462 .50799 Mdot
.39332 .40647 Mdot
.23253 .57815 Mdot
.34183 .60125 Mdot
.68713 .49682 Mdot
.4307 .41265 Mdot
.3415 .32803 Mdot
.72451 .51059 Mdot
.72856 .49667 Mdot
.42708 .35746 Mdot
.70319 .33531 Mdot
.41362 .4304 Mdot
.60522 .69863 Mdot
.54509 .36289 Mdot
.59552 .67355 Mdot
.52954 .26668 Mdot
.43671 .35556 Mdot
.38163 .48217 Mdot
.34961 .6616 Mdot
.70829 .36077 Mdot
.33118 .25295 Mdot
.43439 .44106 Mdot
.33286 .70799 Mdot
.54683 .35455 Mdot
.51975 .47306 Mdot
.33878 .71318 Mdot
.69003 .32998 Mdot
.61815 .69399 Mdot
.37218 .41552 Mdot
.54969 .63696 Mdot
.69504 .33363 Mdot
.52769 .26576 Mdot
.43768 .39947 Mdot
.38415 .63019 Mdot
.39748 .38041 Mdot
.3772 .62228 Mdot
.40876 .42001 Mdot
.32112 .69101 Mdot
.72346 .30159 Mdot
.43882 .24712 Mdot
.4411 .33347 Mdot
.64848 .623 Mdot
.3253 .56676 Mdot
.68172 .35774 Mdot
.41432 .36277 Mdot
.49172 .58487 Mdot
.62708 .69249 Mdot
.62775 .59623 Mdot
.71692 .52284 Mdot
.579 .66619 Mdot
.40466 .64841 Mdot
.73092 .4934 Mdot
.50315 .59897 Mdot
.49159 .42516 Mdot
.70324 .34064 Mdot
.59164 .68313 Mdot
.40605 .39246 Mdot
.45431 .40794 Mdot
.67499 .6101 Mdot
.48566 .17022 Mdot
.36706 .66909 Mdot
.63524 .82476 Mdot
.43757 .61693 Mdot
.66603 .34105 Mdot
.69116 .54387 Mdot
.39159 .413 Mdot
.42111 .40806 Mdot
.72168 .50331 Mdot
.37378 .61341 Mdot
.66475 .3789 Mdot
.65193 .24457 Mdot
.6386 .70407 Mdot
.49602 .19468 Mdot
.39617 .62846 Mdot
.49738 .19529 Mdot
.66731 .31119 Mdot
.41826 .57731 Mdot
.40599 .23105 Mdot
.62028 .6806 Mdot
.49534 .19362 Mdot
.38103 .62944 Mdot
.38138 .38308 Mdot
.49595 .59392 Mdot
.48304 .60591 Mdot
.40734 .6254 Mdot
.70554 .53653 Mdot
.67863 .32601 Mdot
.40041 .38133 Mdot
.47506 .45299 Mdot
.27476 .36646 Mdot
.70172 .48543 Mdot
.48039 .38235 Mdot
.61599 .67111 Mdot
.40045 .42361 Mdot
.69329 .36443 Mdot
.6192 .6831 Mdot
.5018 .57855 Mdot
.46544 .27323 Mdot
.42895 .4098 Mdot
.54592 .50931 Mdot
.60438 .69115 Mdot
.65895 .23297 Mdot
.38924 .42899 Mdot
.58263 .67244 Mdot
.424 .47075 Mdot
.64711 .7428 Mdot
.54831 .53572 Mdot
.55849 .76314 Mdot
.67587 .4753 Mdot
.67018 .50775 Mdot
.60568 .15838 Mdot
.73725 .34993 Mdot
.58731 .65289 Mdot
.47181 .58817 Mdot
.4954 .17723 Mdot
.58794 .6678 Mdot
.41687 .43599 Mdot
.37386 .39589 Mdot
.34175 .5617 Mdot
.39115 .32256 Mdot
.4699 .60282 Mdot
.40758 .5149 Mdot
.38959 .36652 Mdot
.47584 .36445 Mdot
.37644 .41727 Mdot
.40148 .60592 Mdot
.61717 .67555 Mdot
.16085 .58865 Mdot
.63558 .68078 Mdot
.3755 .47534 Mdot
.68852 .49838 Mdot
.68776 .46924 Mdot
.40381 .39556 Mdot
.32789 .42921 Mdot
.31676 .79188 Mdot
.37124 .40148 Mdot
.55488 .51364 Mdot
.54164 .27745 Mdot
.38382 .34236 Mdot
.42232 .64247 Mdot
.43456 .46835 Mdot
.44429 .62573 Mdot
.62072 .68567 Mdot
.69158 .33072 Mdot
.71974 .34049 Mdot
.61514 .69523 Mdot
.41989 .40783 Mdot
.71615 .34474 Mdot
.3956 .39581 Mdot
.40412 .37539 Mdot
.5231 .41502 Mdot
.67777 .36956 Mdot
.71648 .53049 Mdot
.67326 .34691 Mdot
.41912 .62392 Mdot
.73393 .77602 Mdot
.67617 .35635 Mdot
.34175 .55951 Mdot
.55242 .34037 Mdot
.50474 .18866 Mdot
.36803 .64478 Mdot
.65721 .35959 Mdot
.62399 .68886 Mdot
.49285 .48387 Mdot
.32059 .55406 Mdot
.57616 .68035 Mdot
.41568 .39276 Mdot
.37649 .67295 Mdot
.43536 .61977 Mdot
.5776 .69578 Mdot
.36853 .62836 Mdot
.35674 .37117 Mdot
.42812 .38384 Mdot
.57899 .65889 Mdot
.23806 .32875 Mdot
.61888 .70497 Mdot
.30578 .63659 Mdot
.38075 .36567 Mdot
.39299 .63304 Mdot
.33426 .5568 Mdot
.34423 .62394 Mdot
.48309 .60395 Mdot
.3931 .43659 Mdot
.67633 .35956 Mdot
.52327 .31111 Mdot
.68975 .49429 Mdot
.44431 .79861 Mdot
.37195 .64262 Mdot
.59285 .71262 Mdot
.37029 .62591 Mdot
.36353 .64274 Mdot
.58799 .64479 Mdot
.39437 .61845 Mdot
.41781 .42345 Mdot
.3471 .74386 Mdot
.3692 .6536 Mdot
.60839 .68527 Mdot
.66119 .35899 Mdot
.38936 .66464 Mdot
.62723 .39 Mdot
.41926 .38245 Mdot
.67126 .4901 Mdot
.70103 .38045 Mdot
.35474 .65148 Mdot
.682 .35866 Mdot
.69734 .50564 Mdot
.69083 .32478 Mdot
.54326 .64755 Mdot
.61375 .62318 Mdot
.35406 .29232 Mdot
.65304 .73804 Mdot
.41338 .61482 Mdot
.71647 .47172 Mdot
.42636 .41719 Mdot
.40223 .37784 Mdot
.71657 .32953 Mdot
.42225 .61059 Mdot
.57656 .79503 Mdot
.39085 .49782 Mdot
.54528 .79933 Mdot
.63074 .6913 Mdot
.62146 .36682 Mdot
.50836 .46652 Mdot
.56132 .69449 Mdot
.38935 .34665 Mdot
.50004 .58786 Mdot
.39844 .40231 Mdot
.56896 .29298 Mdot
.6662 .329 Mdot
.71254 .62083 Mdot
.45548 .38721 Mdot
.71902 .50049 Mdot
.40525 .4186 Mdot
.55845 .59493 Mdot
.44942 .36375 Mdot
.70559 .32575 Mdot
.63261 .70929 Mdot
.39701 .66349 Mdot
.65528 .35031 Mdot
.67885 .52963 Mdot
.38495 .25264 Mdot
.41974 .43312 Mdot
.3878 .36918 Mdot
.72608 .51821 Mdot
.41699 .64124 Mdot
.69674 .52981 Mdot
.58195 .67207 Mdot
.6769 .35381 Mdot
.44884 .40246 Mdot
.47906 .37606 Mdot
.68072 .55404 Mdot
.61532 .65597 Mdot
.71833 .53901 Mdot
.62908 .66499 Mdot
.50007 .59131 Mdot
.43748 .34851 Mdot
.72165 .53899 Mdot
.39027 .34777 Mdot
.31435 .49204 Mdot
.47294 .28388 Mdot
.29213 .35644 Mdot
.71466 .53476 Mdot
.7436 .31445 Mdot
.61563 .6867 Mdot
.5891 .68313 Mdot
.30323 .65109 Mdot
.35705 .8116 Mdot
.53032 .51785 Mdot
.61857 .7973 Mdot
.58169 .67253 Mdot
.60025 .68835 Mdot
.70216 .53243 Mdot
.41729 .62879 Mdot
.3497 .64702 Mdot
.7299 .52601 Mdot
.49479 .26593 Mdot
.37864 .63638 Mdot
.26105 .66143 Mdot
.69042 .48176 Mdot
.35855 .40589 Mdot
.37707 .57751 Mdot
.70443 .32544 Mdot
.5504 .29046 Mdot
.66378 .64277 Mdot
.39905 .41036 Mdot
.82251 .57009 Mdot
.71498 .52312 Mdot
.4499 .52572 Mdot
.64711 .704 Mdot
.44748 .41823 Mdot
.40891 .41506 Mdot
.41007 .42675 Mdot
.69838 .31931 Mdot
.28918 .43319 Mdot
.39543 .41157 Mdot
.45086 .2584 Mdot
.41909 .45441 Mdot
.67873 .63524 Mdot
.67326 .34726 Mdot
.60516 .25138 Mdot
.73929 .50391 Mdot
.57295 .78468 Mdot
.41824 .44874 Mdot
.58669 .68708 Mdot
.56496 .56941 Mdot
.61372 .65973 Mdot
.55685 .7022 Mdot
.47339 .18916 Mdot
.41703 .60961 Mdot
.45475 .39328 Mdot
.70134 .48086 Mdot
.35176 .6671 Mdot
.56379 .5622 Mdot
.72374 .78337 Mdot
.60421 .71592 Mdot
.57052 .88172 Mdot
.59162 .67143 Mdot
.4744 .60509 Mdot
.40524 .64586 Mdot
.31112 .37464 Mdot
.53449 .38133 Mdot
.41418 .6433 Mdot
.77196 .41463 Mdot
.4478 .61639 Mdot
.4489 .22516 Mdot
.39771 .68397 Mdot
.60937 .68025 Mdot
.58073 .70171 Mdot
.35284 .42681 Mdot
.41665 .43033 Mdot
.54158 .37908 Mdot
.34753 .33952 Mdot
.42868 .40669 Mdot
.68532 .51328 Mdot
.65606 .73653 Mdot
.55056 .63804 Mdot
.39936 .6223 Mdot
.60508 .64925 Mdot
.40647 .41696 Mdot
.42611 .36932 Mdot
.38905 .44258 Mdot
.65155 .29178 Mdot
.25625 .65722 Mdot
.38024 .39703 Mdot
.45277 .36444 Mdot
.67809 .53275 Mdot
.67724 .61024 Mdot
.67018 .78523 Mdot
.48142 .18514 Mdot
.36591 .39898 Mdot
.66981 .34063 Mdot
.6919 .36653 Mdot
.34895 .38845 Mdot
.31522 .38315 Mdot
.63997 .38417 Mdot
.40642 .39258 Mdot
.40961 .24796 Mdot
.65975 .52822 Mdot
.50809 .59112 Mdot
.6937 .50367 Mdot
.34774 .65665 Mdot
.50259 .59445 Mdot
.68093 .52125 Mdot
.46871 .26673 Mdot
.49838 .58121 Mdot
.64388 .74658 Mdot
.65877 .3612 Mdot
.38132 .42339 Mdot
.35374 .57015 Mdot
.69075 .48854 Mdot
.5972 .68931 Mdot
.39761 .64676 Mdot
.62725 .69634 Mdot
.67819 .67935 Mdot
.51035 .26983 Mdot
.47944 .59943 Mdot
.58726 .68844 Mdot
.5416 .50826 Mdot
.66893 .34345 Mdot
.59444 .66552 Mdot
.37512 .48007 Mdot
.45524 .42704 Mdot
.27392 .73457 Mdot
.39875 .36719 Mdot
.57825 .73341 Mdot
.59227 .68874 Mdot
.5087 .58175 Mdot
.40019 .38998 Mdot
.68706 .47741 Mdot
.49476 .40554 Mdot
.39401 .39626 Mdot
.67747 .49425 Mdot
.37864 .3908 Mdot
.69165 .36245 Mdot
.43484 .61161 Mdot
.54702 .34774 Mdot
.60563 .33713 Mdot
.67011 .32855 Mdot
.49937 .32012 Mdot
.39669 .43441 Mdot
.73832 .39218 Mdot
.38405 .6332 Mdot
.43676 .43861 Mdot
.53434 .25843 Mdot
.41328 .62387 Mdot
.38748 .6515 Mdot
.40283 .36222 Mdot
.61118 .70694 Mdot
.72026 .52822 Mdot
.67008 .34462 Mdot
.55968 .6518 Mdot
.39234 .40809 Mdot
.42932 .3607 Mdot
.6641 .33174 Mdot
.59419 .68318 Mdot
.44624 .40912 Mdot
.47598 .76518 Mdot
.49985 .29595 Mdot
.61394 .65155 Mdot
.45641 .42405 Mdot
.27283 .69101 Mdot
.36405 .6276 Mdot
.82399 .56656 Mdot
.72459 .30533 Mdot
.69543 .54127 Mdot
.48011 .40598 Mdot
.86765 .63058 Mdot
.66203 .3619 Mdot
.54103 .79321 Mdot
.3827 .38392 Mdot
.3879 .41478 Mdot
.40738 .60844 Mdot
.44282 .40722 Mdot
.3876 .61631 Mdot
.61691 .35113 Mdot
.37687 .82295 Mdot
.36754 .63811 Mdot
.37985 .62367 Mdot
.33033 .38075 Mdot
.70569 .28403 Mdot
.41042 .63188 Mdot
.42137 .43123 Mdot
.76398 .38883 Mdot
.34346 .3704 Mdot
.64886 .36113 Mdot
.63887 .37597 Mdot
.41615 .65328 Mdot
.31037 .56933 Mdot
.33104 .38695 Mdot
.26678 .63091 Mdot
.65208 .399 Mdot
.5871 .65571 Mdot
.41166 .35381 Mdot
.47101 .58999 Mdot
.70633 .51409 Mdot
.44881 .46111 Mdot
.38847 .42796 Mdot
.42334 .63238 Mdot
.67405 .32092 Mdot
.59144 .66378 Mdot
.38922 .35295 Mdot
.66327 .54139 Mdot
.67574 .32982 Mdot
.37285 .66088 Mdot
.3101 .60288 Mdot
.71685 .34184 Mdot
.48244 .38657 Mdot
.38013 .38184 Mdot
.37245 .37097 Mdot
.4328 .32913 Mdot
.61368 .69455 Mdot
.73242 .50536 Mdot
.48239 .39083 Mdot
.5123 .4495 Mdot
.50197 .28796 Mdot
.37542 .43382 Mdot
.39095 .6645 Mdot
.62906 .68212 Mdot
.47817 .59174 Mdot
.50171 .18284 Mdot
.37527 .3806 Mdot
.26105 .66287 Mdot
.63606 .27711 Mdot
.48905 .58254 Mdot
.35576 .67233 Mdot
.67608 .34332 Mdot
.39017 .36071 Mdot
.44886 .25546 Mdot
.43114 .40648 Mdot
.39218 .33602 Mdot
.70503 .53938 Mdot
.5943 .65651 Mdot
.36621 .28899 Mdot
.70621 .51802 Mdot
.38838 .65079 Mdot
.23704 .62842 Mdot
.35169 .64872 Mdot
.35784 .66024 Mdot
.44988 .56634 Mdot
.60877 .70229 Mdot
.8748 .62036 Mdot
.68356 .24549 Mdot
.37603 .43 Mdot
.58132 .68626 Mdot
.40678 .63637 Mdot
.43034 .42883 Mdot
.39076 .61674 Mdot
.42237 .64649 Mdot
.4222 .38199 Mdot
.42573 .38796 Mdot
.43435 .2462 Mdot
.27142 .66966 Mdot
.66922 .36016 Mdot
.37865 .61086 Mdot
.27985 .63536 Mdot
.38918 .41141 Mdot
.40418 .43202 Mdot
.566 .57267 Mdot
.6537 .35131 Mdot
.20451 .49475 Mdot
.3958 .37837 Mdot
.58109 .28357 Mdot
.40919 .43658 Mdot
.34492 .64221 Mdot
.56805 .67043 Mdot
.37357 .4759 Mdot
.71162 .5419 Mdot
.37153 .61427 Mdot
.68424 .32079 Mdot
.36196 .67974 Mdot
.22055 .52757 Mdot
.62095 .69558 Mdot
.37627 .62776 Mdot
.72708 .4862 Mdot
.5974 .67842 Mdot
.61632 .70506 Mdot
.56372 .55897 Mdot
.71357 .47513 Mdot
.66744 .32199 Mdot
.60979 .66432 Mdot
.23575 .58216 Mdot
.60657 .67856 Mdot
.21516 .52876 Mdot
.36276 .39786 Mdot
.45319 .25979 Mdot
.45634 .45616 Mdot
.35009 .41984 Mdot
.60442 .66887 Mdot
.67329 .32895 Mdot
.44347 .41683 Mdot
.36476 .64378 Mdot
.66179 .35253 Mdot
.40276 .55479 Mdot
.7095 .47058 Mdot
.4385 .62829 Mdot
.63425 .67184 Mdot
.40007 .61043 Mdot
.5435 .28125 Mdot
.63808 .36691 Mdot
.58173 .56688 Mdot
.53437 .37027 Mdot
.45986 .34353 Mdot
.4577 .38524 Mdot
.44295 .42005 Mdot
.41786 .42095 Mdot
.68655 .49822 Mdot
.7095 .32022 Mdot
.38673 .66591 Mdot
.26826 .34419 Mdot
.59739 .69366 Mdot
.55304 .51962 Mdot
.43639 .33075 Mdot
.42666 .36165 Mdot
.40424 .63768 Mdot
.41891 .65387 Mdot
.30229 .44284 Mdot
.72255 .51114 Mdot
.34282 .39202 Mdot
.4127 .44746 Mdot
.39436 .28441 Mdot
.60172 .67 Mdot
.53044 .75038 Mdot
.65924 .50996 Mdot
.58268 .88233 Mdot
.70432 .51809 Mdot
.60802 .48373 Mdot
.39744 .61661 Mdot
.68921 .34969 Mdot
.42046 .3951 Mdot
.41335 .52343 Mdot
.37836 .675 Mdot
.65937 .5766 Mdot
.68275 .34464 Mdot
.54215 .70378 Mdot
.57845 .67678 Mdot
.38882 .35229 Mdot
.41098 .43658 Mdot
.43978 .38334 Mdot
.43531 .41698 Mdot
.58421 .65224 Mdot
.43142 .39589 Mdot
.59563 .64056 Mdot
.22155 .51607 Mdot
.52755 .2534 Mdot
.72236 .48937 Mdot
.69558 .60733 Mdot
.35899 .65888 Mdot
.20001 .55642 Mdot
.21282 .49533 Mdot
.47375 .28416 Mdot
.54324 .66222 Mdot
.40414 .34291 Mdot
.70732 .53426 Mdot
.57007 .62639 Mdot
.7183 .48553 Mdot
.18685 .64642 Mdot
.33792 .56404 Mdot
.56639 .72807 Mdot
.4408 .39117 Mdot
.72635 .52723 Mdot
.30005 .59029 Mdot
.48592 .40187 Mdot
.71394 .34916 Mdot
.22405 .55038 Mdot
.40214 .5369 Mdot
.673 .364 Mdot
.41364 .37785 Mdot
.43078 .6521 Mdot
.42113 .40072 Mdot
.41962 .38949 Mdot
.36985 .39757 Mdot
.57332 .65074 Mdot
.36206 .40857 Mdot
.41678 .42751 Mdot
.50962 .15651 Mdot
.71364 .56921 Mdot
.66885 .50853 Mdot
.29255 .36815 Mdot
.66484 .35095 Mdot
.34767 .65778 Mdot
.54396 .35455 Mdot
.59424 .69511 Mdot
.30005 .43802 Mdot
.41787 .3693 Mdot
.49689 .79769 Mdot
.6317 .70227 Mdot
.70059 .33033 Mdot
.47456 .58728 Mdot
.53595 .71844 Mdot
.68684 .54661 Mdot
.46893 .59744 Mdot
.69258 .49233 Mdot
.30214 .31014 Mdot
.38344 .61922 Mdot
.46023 .34389 Mdot
.59641 .66082 Mdot
.71159 .4791 Mdot
.44548 .25668 Mdot
.39908 .42721 Mdot
.71453 .53538 Mdot
.4767 .42219 Mdot
.52712 .31115 Mdot
.54576 .35804 Mdot
.72646 .48841 Mdot
.63052 .70842 Mdot
.59917 .67343 Mdot
.66882 .36532 Mdot
.3655 .62766 Mdot
.41985 .63683 Mdot
.60568 .67486 Mdot
.77829 .67604 Mdot
.3944 .40785 Mdot
.37887 .40492 Mdot
.50842 .45989 Mdot
.42598 .43625 Mdot
.65115 .3788 Mdot
.47072 .60618 Mdot
.41455 .65013 Mdot
.44232 .42015 Mdot
.44652 .40777 Mdot
.38464 .37592 Mdot
.48552 .25968 Mdot
.69454 .50098 Mdot
.38861 .36618 Mdot
.70398 .34294 Mdot
.4026 .54883 Mdot
.42503 .4201 Mdot
.48309 .38472 Mdot
.39024 .61472 Mdot
.62712 .51253 Mdot
.59858 .6915 Mdot
.70593 .48665 Mdot
.70329 .48257 Mdot
.53906 .23006 Mdot
.36018 .62171 Mdot
.46874 .6016 Mdot
.6624 .61771 Mdot
.47519 .59289 Mdot
.68531 .3439 Mdot
.54143 .5329 Mdot
.70933 .46049 Mdot
.66985 .50607 Mdot
.58226 .70701 Mdot
.44968 .42341 Mdot
.42449 .42319 Mdot
.56696 .7884 Mdot
.37289 .40312 Mdot
.67427 .36083 Mdot
.59141 .70021 Mdot
.37947 .62626 Mdot
.69983 .35793 Mdot
.58756 .67845 Mdot
.41465 .64448 Mdot
.40533 .45702 Mdot
.4206 .43394 Mdot
.3938 .65036 Mdot
.36946 .65882 Mdot
.40832 .40269 Mdot
.4531 .19031 Mdot
.40705 .65811 Mdot
.40032 .64746 Mdot
.40338 .54504 Mdot
.67933 .54031 Mdot
.49739 .39612 Mdot
.59257 .69677 Mdot
.4144 .42796 Mdot
.72548 .49513 Mdot
.68567 .3358 Mdot
.37836 .65564 Mdot
.40812 .3514 Mdot
.38768 .40388 Mdot
.67094 .34068 Mdot
.6652 .37114 Mdot
.65693 .3495 Mdot
.57633 .69101 Mdot
.42371 .37843 Mdot
.40935 .63916 Mdot
.57714 .67191 Mdot
.71275 .34189 Mdot
.65365 .36225 Mdot
.41176 .22172 Mdot
.4011 .40825 Mdot
.6918 .36855 Mdot
.75538 .76198 Mdot
.41218 .23668 Mdot
.50109 .59947 Mdot
.65737 .49423 Mdot
.74459 .30736 Mdot
.70439 .37802 Mdot
.59486 .65386 Mdot
.55905 .51903 Mdot
.65615 .33329 Mdot
.38713 .35706 Mdot
.38537 .42129 Mdot
.45496 .3448 Mdot
.66193 .34908 Mdot
.51065 .2684 Mdot
.41253 .60609 Mdot
.24044 .44145 Mdot
.66498 .35119 Mdot
.71335 .47771 Mdot
.67794 .55384 Mdot
.70332 .52493 Mdot
.43417 .34706 Mdot
.28959 .31654 Mdot
.24545 .56139 Mdot
.20413 .4838 Mdot
.57993 .67809 Mdot
.42112 .65048 Mdot
.39469 .56973 Mdot
.38651 .65204 Mdot
.70969 .50632 Mdot
.6775 .32866 Mdot
.41183 .60911 Mdot
.61763 .704 Mdot
.60183 .67173 Mdot
.70897 .54653 Mdot
.69718 .50873 Mdot
.69217 .52195 Mdot
.36918 .61822 Mdot
.39601 .61731 Mdot
.44672 .3933 Mdot
.37314 .65434 Mdot
.66181 .27261 Mdot
.63608 .3153 Mdot
.70022 .55376 Mdot
.61079 .69087 Mdot
.39236 .65843 Mdot
.37988 .42304 Mdot
.57711 .48468 Mdot
.74175 .50668 Mdot
.70774 .3292 Mdot
.37975 .77884 Mdot
.35625 .81955 Mdot
.45337 .38679 Mdot
.6089 .65273 Mdot
.34427 .4518 Mdot
.41478 .42098 Mdot
.70387 .54223 Mdot
.63587 .25573 Mdot
.49267 .57963 Mdot
.42467 .40812 Mdot
.39833 .45479 Mdot
.62449 .69504 Mdot
.54246 .35489 Mdot
.39108 .35365 Mdot
.56883 .53727 Mdot
.62602 .7106 Mdot
.65923 .51535 Mdot
.64639 .17831 Mdot
.44072 .52978 Mdot
.57277 .31068 Mdot
.50601 .59036 Mdot
.37003 .38604 Mdot
.68444 .51012 Mdot
.70851 .34067 Mdot
.6903 .51168 Mdot
.34718 .66733 Mdot
.68557 .54512 Mdot
.371 .40754 Mdot
.41157 .63448 Mdot
.59203 .6823 Mdot
.54125 .47974 Mdot
.30263 .32521 Mdot
.68397 .47901 Mdot
.49751 .60533 Mdot
.42563 .3891 Mdot
.23006 .58341 Mdot
.35199 .42704 Mdot
.41015 .43305 Mdot
.61678 .66312 Mdot
.40305 .62824 Mdot
.63071 .68918 Mdot
.48866 .42045 Mdot
.34333 .70478 Mdot
.60264 .69574 Mdot
.42846 .51378 Mdot
.67091 .32662 Mdot
.50318 .26879 Mdot
.40233 .38569 Mdot
.59466 .6603 Mdot
.41302 .37185 Mdot
.38086 .60911 Mdot
.48428 .27902 Mdot
.49348 .29763 Mdot
.61802 .67291 Mdot
.52734 .621 Mdot
.54837 .32661 Mdot
.49784 .3938 Mdot
.58353 .66722 Mdot
.32442 .26293 Mdot
.48656 .5857 Mdot
.68031 .33047 Mdot
.6622 .37197 Mdot
.69678 .34551 Mdot
.37765 .40946 Mdot
.28086 .65833 Mdot
.6693 .36767 Mdot
.60826 .71308 Mdot
.68837 .36187 Mdot
.61442 .31496 Mdot
.56587 .7959 Mdot
.67213 .32693 Mdot
.39479 .38592 Mdot
.38319 .47406 Mdot
.55592 .51633 Mdot
.67988 .47504 Mdot
.49423 .69011 Mdot
.51667 .15502 Mdot
.39272 .41347 Mdot
.32173 .69457 Mdot
.33583 .65456 Mdot
.6222 .45261 Mdot
.48641 .29531 Mdot
.52867 .4952 Mdot
.39613 .65413 Mdot
.53892 .36223 Mdot
.38052 .67167 Mdot
.45708 .33967 Mdot
.38198 .39667 Mdot
.37037 .6146 Mdot
.43179 .79479 Mdot
.3125 .26028 Mdot
.53046 .80313 Mdot
.40394 .65565 Mdot
.58367 .67277 Mdot
.61408 .65836 Mdot
.61479 .66198 Mdot
.6802 .5033 Mdot
.37401 .6279 Mdot
.37878 .37318 Mdot
.68402 .53553 Mdot
.41239 .38279 Mdot
.61423 .67604 Mdot
.47975 .28797 Mdot
.38101 .62381 Mdot
.40683 .39144 Mdot
.28955 .61158 Mdot
.6972 .49276 Mdot
.66756 .34306 Mdot
.36481 .76424 Mdot
.66911 .47309 Mdot
.63555 .69755 Mdot
.34765 .67385 Mdot
.66912 .559 Mdot
.58871 .51436 Mdot
.36972 .42478 Mdot
.38879 .43856 Mdot
.56511 .51863 Mdot
.32489 .57718 Mdot
.40099 .34733 Mdot
.67774 .52785 Mdot
.67012 .52515 Mdot
.40914 .37106 Mdot
.37043 .63329 Mdot
.64831 .33881 Mdot
.71883 .33218 Mdot
.41453 .33238 Mdot
.53929 .37224 Mdot
.45165 .25912 Mdot
.43857 .42193 Mdot
.47416 .37742 Mdot
.72448 .48179 Mdot
.50457 .59677 Mdot
.52998 .38593 Mdot
.68992 .35437 Mdot
.38694 .37981 Mdot
.27676 .37006 Mdot
.37282 .64167 Mdot
.71701 .53313 Mdot
.57541 .65968 Mdot
.71609 .3441 Mdot
.69313 .55289 Mdot
.40904 .37105 Mdot
.4462 .40888 Mdot
.59627 .66326 Mdot
.34588 .63977 Mdot
.66389 .33719 Mdot
.68282 .53537 Mdot
.68831 .35244 Mdot
.39208 .61954 Mdot
.38391 .66041 Mdot
.39317 .44551 Mdot
.34602 .41362 Mdot
.68729 .48055 Mdot
.40486 .33755 Mdot
.69161 .53313 Mdot
.67526 .61045 Mdot
.5985 .64612 Mdot
.43099 .44126 Mdot
.35632 .62339 Mdot
.61108 .67449 Mdot
.39808 .41555 Mdot
.5702 .52119 Mdot
.44887 .38539 Mdot
.73022 .51962 Mdot
.6389 .23898 Mdot
.69284 .33677 Mdot
.40042 .4652 Mdot
.3659 .50084 Mdot
.42952 .4335 Mdot
.66675 .50096 Mdot
.23738 .56972 Mdot
.60866 .6976 Mdot
.40419 .61687 Mdot
.67003 .45708 Mdot
.60748 .68296 Mdot
.38973 .38411 Mdot
.67529 .35628 Mdot
.38748 .66846 Mdot
.49369 .59994 Mdot
.5383 .40128 Mdot
.4139 .4778 Mdot
.34809 .36703 Mdot
.3952 .34872 Mdot
.61509 .80032 Mdot
.69155 .51878 Mdot
.40535 .63837 Mdot
.60439 .65116 Mdot
.6174 .69863 Mdot
.69971 .49646 Mdot
.40711 .53636 Mdot
.47843 .81201 Mdot
.7964 .72344 Mdot
.69226 .55405 Mdot
.69581 .35315 Mdot
.48407 .28019 Mdot
.70449 .52599 Mdot
.68502 .49507 Mdot
.72649 .48082 Mdot
.5737 .78863 Mdot
.40678 .6514 Mdot
.38675 .40466 Mdot
.32256 .63472 Mdot
.3709 .39638 Mdot
.57067 .32323 Mdot
.61449 .67737 Mdot
.404 .61645 Mdot
.61492 .37992 Mdot
.45252 .36836 Mdot
.41513 .41218 Mdot
.63622 .39991 Mdot
.32612 .38982 Mdot
.5001 .18788 Mdot
.40651 .44341 Mdot
.68912 .50461 Mdot
.39395 .5868 Mdot
.48188 .38631 Mdot
.28856 .61479 Mdot
.59549 .67302 Mdot
.47857 .6004 Mdot
.47232 .3562 Mdot
.45615 .35104 Mdot
.3781 .67108 Mdot
.41465 .61015 Mdot
.65948 .36654 Mdot
.35513 .74663 Mdot
.59309 .67546 Mdot
.5517 .75598 Mdot
.41058 .43354 Mdot
.56041 .70636 Mdot
.64702 .2493 Mdot
.40429 .41361 Mdot
.5623 .55478 Mdot
.3026 .44297 Mdot
.41817 .35314 Mdot
.20943 .4716 Mdot
.61303 .68655 Mdot
.55119 .27001 Mdot
.4355 .39833 Mdot
.71131 .53633 Mdot
.41727 .62456 Mdot
.43883 .62905 Mdot
.70917 .34268 Mdot
.68376 .26191 Mdot
.43776 .85023 Mdot
.40416 .61559 Mdot
.40108 .42837 Mdot
.6016 .69176 Mdot
.48521 .60261 Mdot
.44268 .46555 Mdot
.55288 .60679 Mdot
.37391 .64253 Mdot
.48425 .40157 Mdot
.49261 .79965 Mdot
.54107 .35871 Mdot
.20277 .58623 Mdot
.61422 .66378 Mdot
.68443 .36059 Mdot
.36938 .33609 Mdot
.66749 .61964 Mdot
.41907 .43512 Mdot
.57083 .31864 Mdot
.39117 .59374 Mdot
.67736 .36208 Mdot
.41879 .41001 Mdot
.40575 .34641 Mdot
.512 .33626 Mdot
.6499 .3658 Mdot
.39686 .35005 Mdot
.45387 .38428 Mdot
.41761 .61816 Mdot
.47207 .60674 Mdot
.37873 .62878 Mdot
.41999 .39973 Mdot
.6161 .21825 Mdot
.38523 .61021 Mdot
.50846 .66938 Mdot
.71699 .30564 Mdot
.59284 .69409 Mdot
.46886 .43041 Mdot
.36468 .40931 Mdot
.19901 .59889 Mdot
.48309 .60448 Mdot
.69769 .75117 Mdot
.72786 .52183 Mdot
.46557 .15538 Mdot
.67222 .47029 Mdot
.53505 .66499 Mdot
.62915 .5827 Mdot
.47963 .38567 Mdot
.40157 .53045 Mdot
.19893 .48386 Mdot
.64495 .68113 Mdot
.19602 .54648 Mdot
.4168 .43021 Mdot
.38516 .37816 Mdot
.696 .53607 Mdot
.54556 .68424 Mdot
.37478 .47693 Mdot
.53083 .38462 Mdot
.6979 .32863 Mdot
.38702 .64014 Mdot
.38244 .42091 Mdot
.41305 .78712 Mdot
.70084 .47485 Mdot
.30385 .33837 Mdot
.40384 .3898 Mdot
.33675 .43899 Mdot
.54061 .66882 Mdot
.59196 .68431 Mdot
.72748 .48936 Mdot
.71002 .4748 Mdot
.37035 .38899 Mdot
.57965 .65527 Mdot
.44034 .37916 Mdot
.54268 .31869 Mdot
.47829 .416 Mdot
.68503 .34026 Mdot
.39132 .43129 Mdot
.32435 .43852 Mdot
.17057 .40621 Mdot
.45703 .38851 Mdot
.356 .65669 Mdot
.69068 .52508 Mdot
.6997 .50195 Mdot
.41833 .64096 Mdot
.7004 .50172 Mdot
.2406 .44749 Mdot
.27964 .6677 Mdot
.68641 .34646 Mdot
.23048 .50195 Mdot
.69426 .33205 Mdot
.47747 .59942 Mdot
.40386 .40678 Mdot
.77178 .56894 Mdot
.68438 .55163 Mdot
.61638 .30512 Mdot
.60797 .67652 Mdot
.48096 .60521 Mdot
.42668 .38697 Mdot
.66276 .40393 Mdot
.71214 .51938 Mdot
.48574 .53574 Mdot
.37283 .39223 Mdot
.37362 .61448 Mdot
.42118 .35684 Mdot
.33335 .35977 Mdot
.471 .60479 Mdot
.42441 .3514 Mdot
.58753 .67857 Mdot
.38127 .61694 Mdot
.5763 .73855 Mdot
.6882 .49005 Mdot
.42615 .40085 Mdot
.40477 .4279 Mdot
.39854 .66931 Mdot
.37567 .42871 Mdot
.57928 .66137 Mdot
.90999 .54328 Mdot
.65646 .34289 Mdot
.50579 .59475 Mdot
.45678 .71485 Mdot
.42116 .34933 Mdot
.44889 .40893 Mdot
.50871 .5112 Mdot
.27632 .36505 Mdot
.58978 .68901 Mdot
.3544 .3611 Mdot
.66961 .51854 Mdot
.66568 .3345 Mdot
.62471 .70238 Mdot
.4293 .38575 Mdot
.37749 .39278 Mdot
.67755 .3611 Mdot
.6267 .39495 Mdot
.66739 .37821 Mdot
.5889 .65366 Mdot
.40802 .69354 Mdot
.57875 .48374 Mdot
.39636 .40178 Mdot
.50177 .60516 Mdot
.4012 .63268 Mdot
.58234 .66572 Mdot
.28714 .43715 Mdot
.45539 .33857 Mdot
.62828 .66092 Mdot
.59173 .68048 Mdot
.36798 .42034 Mdot
.36189 .62039 Mdot
.34575 .67419 Mdot
.40254 .63556 Mdot
.53023 .24777 Mdot
.67322 .75516 Mdot
.68858 .52069 Mdot
.60863 .68918 Mdot
.72501 .4976 Mdot
.65711 .33369 Mdot
.51053 .29401 Mdot
.69273 .47365 Mdot
.38251 .60218 Mdot
.71577 .48519 Mdot
.44313 .38211 Mdot
.60632 .70492 Mdot
.68817 .48273 Mdot
.43319 .42415 Mdot
.43498 .34013 Mdot
.38828 .32236 Mdot
.65958 .32758 Mdot
.54164 .36396 Mdot
.39926 .38213 Mdot
.47567 .58698 Mdot
.40734 .39795 Mdot
.57942 .6592 Mdot
.54405 .47053 Mdot
.39736 .36577 Mdot
.6846 .5519 Mdot
.67848 .76208 Mdot
.66763 .52544 Mdot
.35368 .31954 Mdot
.41489 .39155 Mdot
.39694 .40469 Mdot
.4244 .38469 Mdot
.39745 .54121 Mdot
.6375 .68223 Mdot
.36791 .34765 Mdot
.72019 .53734 Mdot
.3857 .6544 Mdot
.39055 .606 Mdot
.51991 .51792 Mdot
.4688 .59591 Mdot
.57567 .66898 Mdot
.39559 .40604 Mdot
.48893 .53688 Mdot
.52574 .44157 Mdot
.50685 .80559 Mdot
.65226 .4992 Mdot
.67066 .5 Mdot
.36156 .64444 Mdot
.67368 .50616 Mdot
.42991 .38977 Mdot
.48361 .39991 Mdot
.57257 .73614 Mdot
.64269 .71249 Mdot
.66814 .33337 Mdot
.41532 .38704 Mdot
.46584 .25165 Mdot
.67821 .53285 Mdot
.72117 .47922 Mdot
.43975 .3794 Mdot
.33567 .64064 Mdot
.21715 .32941 Mdot
.58163 .68783 Mdot
.24025 .59854 Mdot
.31504 .62449 Mdot
.43604 .28497 Mdot
.61565 .69602 Mdot
.56138 .54821 Mdot
.67546 .47812 Mdot
.61253 .20295 Mdot
.3895 .65467 Mdot
.66577 .33583 Mdot
.4263 .4293 Mdot
.383 .60162 Mdot
.71143 .55239 Mdot
.39451 .66758 Mdot
.46996 .35434 Mdot
.62762 .7047 Mdot
.70424 .51074 Mdot
.57951 .70163 Mdot
.35063 .66702 Mdot
.6941 .33344 Mdot
.57698 .28793 Mdot
.22929 .57532 Mdot
.30661 .4497 Mdot
.38815 .36585 Mdot
.74775 .54525 Mdot
.37822 .3726 Mdot
.43325 .61524 Mdot
.40142 .38547 Mdot
.46485 .39494 Mdot
.68181 .47198 Mdot
.37644 .43493 Mdot
.39936 .43276 Mdot
.28562 .62027 Mdot
.4095 .41275 Mdot
.40412 .37127 Mdot
.3898 .44534 Mdot
.37132 .611 Mdot
.38246 .4388 Mdot
.36864 .62429 Mdot
.52427 .79599 Mdot
.69096 .49021 Mdot
.65515 .33601 Mdot
.66182 .33132 Mdot
.57688 .31593 Mdot
.47238 .25446 Mdot
.36718 .5813 Mdot
.37809 .64188 Mdot
.60394 .66964 Mdot
.4446 .38583 Mdot
.34176 .24212 Mdot
.60868 .22202 Mdot
.66525 .49384 Mdot
.69551 .47986 Mdot
.43022 .41886 Mdot
.34134 .80979 Mdot
.40536 .44186 Mdot
.50935 .46309 Mdot
.3773 .4081 Mdot
.43264 .44005 Mdot
.73178 .49405 Mdot
.54536 .28303 Mdot
.38848 .36635 Mdot
.37746 .67132 Mdot
.67037 .33406 Mdot
.33029 .4226 Mdot
.60851 .24201 Mdot
.3057 .62971 Mdot
.37921 .49382 Mdot
.41038 .36793 Mdot
.69052 .54063 Mdot
.3977 .66156 Mdot
.51629 .44828 Mdot
.57831 .66955 Mdot
.54359 .38389 Mdot
.21505 .51975 Mdot
.64391 .67238 Mdot
.6742 .3305 Mdot
.72632 .54651 Mdot
.36755 .39567 Mdot
.68067 .51055 Mdot
.38668 .34085 Mdot
.5275 .44651 Mdot
.68757 .34332 Mdot
.44864 .60936 Mdot
.58386 .67405 Mdot
.39247 .60093 Mdot
.29195 .35702 Mdot
.60992 .21973 Mdot
.47191 .15199 Mdot
.68017 .54635 Mdot
.24586 .37726 Mdot
.40822 .62499 Mdot
.37254 .38351 Mdot
.79372 .72558 Mdot
.39703 .62946 Mdot
.37362 .61377 Mdot
.53761 .44812 Mdot
.53147 .26719 Mdot
.40076 .33882 Mdot
.40781 .6585 Mdot
.72482 .54744 Mdot
.67884 .34577 Mdot
.4375 .41649 Mdot
.47453 .3606 Mdot
.41038 .60897 Mdot
.71245 .51241 Mdot
.55654 .30478 Mdot
.69303 .50574 Mdot
.40964 .64601 Mdot
.7074 .49194 Mdot
.52319 .66458 Mdot
.69187 .47458 Mdot
.37637 .42406 Mdot
.39537 .40512 Mdot
.49775 .56223 Mdot
.38387 .66041 Mdot
.44824 .41022 Mdot
.38045 .38636 Mdot
.40934 .63462 Mdot
.71811 .46309 Mdot
.26896 .38902 Mdot
.45167 .40386 Mdot
.39082 .40663 Mdot
.65429 .34646 Mdot
.53675 .33082 Mdot
.50041 .48132 Mdot
.43379 .42579 Mdot
.69806 .34625 Mdot
.36898 .61935 Mdot
.40869 .39971 Mdot
.54801 .28407 Mdot
.66087 .53224 Mdot
.43395 .38132 Mdot
.48941 .59984 Mdot
.37049 .37882 Mdot
.2133 .35722 Mdot
.42696 .39389 Mdot
.40341 .64883 Mdot
.41463 .62537 Mdot
.68323 .45347 Mdot
.39054 .64891 Mdot
.50064 .59929 Mdot
.60046 .6737 Mdot
.21655 .59407 Mdot
.49573 .60348 Mdot
.42712 .35556 Mdot
.68911 .24891 Mdot
.47882 .36972 Mdot
.48709 .40331 Mdot
.7098 .28427 Mdot
.50544 .59023 Mdot
.40189 .6236 Mdot
.42417 .7845 Mdot
.35879 .37649 Mdot
.57558 .67119 Mdot
.48129 .38185 Mdot
.43288 .38032 Mdot
.46378 .40459 Mdot
.34875 .7035 Mdot
.5769 .68334 Mdot
.49793 .39781 Mdot
.43779 .41615 Mdot
.27685 .36599 Mdot
.38757 .42538 Mdot
.69972 .32468 Mdot
.38469 .62446 Mdot
.67527 .50862 Mdot
.68201 .34108 Mdot
.3941 .35003 Mdot
.66364 .35168 Mdot
.68302 .5144 Mdot
.60328 .66086 Mdot
.37371 .42062 Mdot
.64771 .35982 Mdot
.68346 .32695 Mdot
.40839 .35934 Mdot
.41145 .61769 Mdot
.35385 .43137 Mdot
.4093 .40287 Mdot
.42248 .37987 Mdot
.42046 .63381 Mdot
.83449 .53516 Mdot
.38683 .3755 Mdot
.56294 .5501 Mdot
.43804 .61614 Mdot
.47589 .6074 Mdot
.67438 .52051 Mdot
.44593 .37223 Mdot
.61401 .70147 Mdot
.60207 .67481 Mdot
.67439 .54608 Mdot
.41573 .61208 Mdot
.70449 .50664 Mdot
.45778 .38886 Mdot
.48245 .39193 Mdot
.4283 .42578 Mdot
.69239 .44318 Mdot
.52974 .70571 Mdot
.37779 .66458 Mdot
.66528 .50465 Mdot
.53904 .38138 Mdot
.59941 .70173 Mdot
.73591 .50037 Mdot
.40096 .67332 Mdot
.42482 .62384 Mdot
.4131 .64971 Mdot
.70148 .33818 Mdot
.70183 .5143 Mdot
.3546 .6788 Mdot
.36458 .67903 Mdot
.42759 .36993 Mdot
.4408 .40975 Mdot
.36514 .62558 Mdot
.63694 .55122 Mdot
.68722 .33284 Mdot
.6882 .54233 Mdot
.19402 .3517 Mdot
.5791 .68333 Mdot
.28672 .61931 Mdot
.43091 .42897 Mdot
.61221 .8791 Mdot
.40554 .44219 Mdot
.39578 .42802 Mdot
.34773 .65663 Mdot
.66399 .37438 Mdot
.67656 .34811 Mdot
.40899 .62458 Mdot
.42334 .64262 Mdot
.70837 .33196 Mdot
.53228 .48727 Mdot
.23001 .33581 Mdot
.52281 .43585 Mdot
.38339 .66564 Mdot
.21909 .56319 Mdot
.62222 .67718 Mdot
.42103 .60209 Mdot
.60566 .62099 Mdot
.6969 .48763 Mdot
.68892 .47736 Mdot
.60023 .66453 Mdot
.39349 .3725 Mdot
.70241 .54559 Mdot
.4289 .45108 Mdot
.54924 .70618 Mdot
.54099 .61047 Mdot
.40657 .19874 Mdot
.37245 .42198 Mdot
.32284 .41294 Mdot
.59488 .80006 Mdot
.44124 .37275 Mdot
.33483 .54818 Mdot
.66232 .34102 Mdot
.42727 .6076 Mdot
.58936 .70064 Mdot
.32573 .7066 Mdot
.39637 .40312 Mdot
.38965 .66456 Mdot
.58747 .69533 Mdot
.54432 .71264 Mdot
.56809 .53755 Mdot
.42519 .36281 Mdot
.83669 .67277 Mdot
.37678 .67365 Mdot
.67533 .50974 Mdot
.26477 .57756 Mdot
.40036 .59789 Mdot
.58314 .52414 Mdot
.71803 .55088 Mdot
.52215 .39065 Mdot
.40421 .66332 Mdot
.67076 .37825 Mdot
.38488 .63544 Mdot
.69103 .36448 Mdot
.35011 .67474 Mdot
.70684 .49705 Mdot
.41607 .40399 Mdot
.70055 .49429 Mdot
.71066 .3288 Mdot
.6811 .54779 Mdot
.58987 .70095 Mdot
.50572 .58582 Mdot
.61421 .67518 Mdot
.49438 .28463 Mdot
.28874 .45925 Mdot
.59551 .65646 Mdot
.51409 .54379 Mdot
.37148 .40425 Mdot
.34469 .64253 Mdot
.67702 .5043 Mdot
.6742 .47283 Mdot
.54079 .36682 Mdot
.41332 .64337 Mdot
.71376 .50849 Mdot
.22552 .56767 Mdot
.76785 .69155 Mdot
.46443 .38537 Mdot
.68532 .68737 Mdot
.40782 .64142 Mdot
.69792 .46838 Mdot
.50791 .46197 Mdot
.41835 .60926 Mdot
.68835 .48124 Mdot
.58489 .6667 Mdot
.61104 .70108 Mdot
.38083 .43233 Mdot
.59185 .70789 Mdot
.67874 .47733 Mdot
.27434 .359 Mdot
.39706 .61378 Mdot
.51779 .7027 Mdot
.66572 .33178 Mdot
.68215 .49954 Mdot
.3545 .40252 Mdot
.36019 .61785 Mdot
.71944 .48983 Mdot
.41049 .83991 Mdot
.1401 .44507 Mdot
.71436 .5107 Mdot
.38393 .62561 Mdot
.37876 .6544 Mdot
.44233 .35886 Mdot
.53551 .37666 Mdot
.71345 .52017 Mdot
.77097 .56853 Mdot
.44176 .25078 Mdot
.50023 .59197 Mdot
.51252 .15595 Mdot
.38808 .36736 Mdot
.41331 .36885 Mdot
.58609 .65409 Mdot
.41297 .41554 Mdot
.41924 .65142 Mdot
.40705 .44237 Mdot
.63154 .68369 Mdot
.666 .53502 Mdot
.40187 .40389 Mdot
.66477 .33451 Mdot
.62698 .67586 Mdot
.62032 .66049 Mdot
.70899 .4898 Mdot
.41968 .61795 Mdot
.44822 .81521 Mdot
.69482 .50609 Mdot
.42314 .37726 Mdot
.48718 .58359 Mdot
.38126 .4395 Mdot
.48304 .564 Mdot
.43777 .62234 Mdot
.67374 .50753 Mdot
.45658 .61302 Mdot
.60384 .68818 Mdot
.67383 .47771 Mdot
.36769 .38336 Mdot
.67671 .48757 Mdot
.57957 .55963 Mdot
.74924 .37363 Mdot
.38449 .67738 Mdot
.58687 .53318 Mdot
.42291 .61503 Mdot
.5 .59465 Mdot
.5296 .2285 Mdot
.68241 .33086 Mdot
.67314 .5302 Mdot
.51009 .66893 Mdot
.68433 .49098 Mdot
.40607 .4151 Mdot
.37623 .39332 Mdot
.69413 .53601 Mdot
.69705 .33662 Mdot
.60029 .34326 Mdot
.68191 .37963 Mdot
.37434 .62952 Mdot
.54182 .50459 Mdot
.20776 .32841 Mdot
.65653 .53016 Mdot
.59929 .66818 Mdot
.39345 .50753 Mdot
.41873 .35121 Mdot
.58149 .6902 Mdot
.6056 .6492 Mdot
.70856 .34976 Mdot
.68386 .49465 Mdot
.44264 .62885 Mdot
.62156 .70571 Mdot
.37108 .60179 Mdot
.55763 .29888 Mdot
.44825 .33476 Mdot
.43445 .29075 Mdot
.39794 .34594 Mdot
.54206 .35932 Mdot
.62999 .70296 Mdot
.38737 .3887 Mdot
.38826 .33291 Mdot
.58108 .67318 Mdot
.7033 .3571 Mdot
.47188 .64169 Mdot
.71533 .50808 Mdot
.70271 .79131 Mdot
.37861 .42535 Mdot
.41306 .40159 Mdot
.58029 .67937 Mdot
.31582 .57889 Mdot
.36759 .66416 Mdot
.41334 .61463 Mdot
.69202 .51946 Mdot
.52859 .46172 Mdot
.37168 .42551 Mdot
.37197 .41465 Mdot
.71148 .53782 Mdot
.47599 .5879 Mdot
.49122 .15963 Mdot
.38784 .40217 Mdot
.61527 .68951 Mdot
.5651 .56911 Mdot
.62603 .7095 Mdot
.44462 .43532 Mdot
.4003 .41779 Mdot
.36876 .37665 Mdot
.36081 .39569 Mdot
.61722 .67368 Mdot
.39814 .34711 Mdot
.37259 .34868 Mdot
.40183 .62758 Mdot
.40065 .36716 Mdot
.43917 .24963 Mdot
.39125 .40057 Mdot
.66154 .33966 Mdot
.50575 .48031 Mdot
.42553 .39382 Mdot
.40388 .36748 Mdot
.44554 .25246 Mdot
.41845 .41649 Mdot
.58641 .69486 Mdot
.38258 .65717 Mdot
.60306 .68929 Mdot
.59337 .67073 Mdot
.71301 .48456 Mdot
.68087 .37082 Mdot
.41492 .33777 Mdot
.70732 .33757 Mdot
.44728 .36173 Mdot
.48774 .42307 Mdot
.52857 .3111 Mdot
.51105 .46112 Mdot
.66117 .32918 Mdot
.37235 .41288 Mdot
.68692 .51486 Mdot
.6731 .50348 Mdot
.56046 .51967 Mdot
.47676 .41193 Mdot
.60513 .71047 Mdot
.59405 .66027 Mdot
.63363 .31806 Mdot
.74653 .34818 Mdot
.68883 .32597 Mdot
.59382 .36779 Mdot
.4015 .4574 Mdot
.40287 .37433 Mdot
.4629 .44501 Mdot
.72837 .50991 Mdot
.50691 .58731 Mdot
.70306 .54883 Mdot
.54137 .66769 Mdot
.62701 .68733 Mdot
.37468 .42426 Mdot
.30611 .77845 Mdot
.37554 .62162 Mdot
.38177 .65766 Mdot
.63188 .6846 Mdot
.66777 .52452 Mdot
.47938 .41605 Mdot
.64353 .82335 Mdot
.43611 .63401 Mdot
.64951 .35005 Mdot
.42191 .40919 Mdot
.69674 .48877 Mdot
.38475 .61606 Mdot
.64682 .35666 Mdot
.36201 .39818 Mdot
.72224 .5479 Mdot
.39228 .39037 Mdot
.23162 .47821 Mdot
.40118 .61955 Mdot
.518 .3154 Mdot
.35051 .64799 Mdot
.61826 .67653 Mdot
.59119 .68865 Mdot
.39837 .41604 Mdot
.67055 .8133 Mdot
.39805 .58776 Mdot
.60566 .64606 Mdot
.65955 .36766 Mdot
.50172 .58168 Mdot
.67161 .36884 Mdot
.69303 .53347 Mdot
.67546 .33054 Mdot
.71719 .48781 Mdot
.63597 .55155 Mdot
.40837 .67225 Mdot
.67682 .36094 Mdot
.34029 .5247 Mdot
.48357 .40327 Mdot
.71655 .33872 Mdot
.43344 .41091 Mdot
.45419 .37859 Mdot
.71818 .52233 Mdot
.70342 .33458 Mdot
.40795 .35187 Mdot
.45243 .71377 Mdot
.58874 .68198 Mdot
.60015 .70789 Mdot
.48057 .38526 Mdot
.71245 .47229 Mdot
.38849 .67564 Mdot
.55494 .34508 Mdot
.45173 .60089 Mdot
.37369 .41734 Mdot
.43621 .34867 Mdot
.35724 .67202 Mdot
.35864 .65831 Mdot
.39537 .41763 Mdot
.25677 .63237 Mdot
.37882 .36336 Mdot
.60777 .70062 Mdot
.37412 .62822 Mdot
.3779 .65592 Mdot
.68152 .47611 Mdot
.40873 .60962 Mdot
.34336 .38453 Mdot
.61904 .64665 Mdot
.35956 .36489 Mdot
.60599 .68616 Mdot
.64968 .54248 Mdot
.72224 .5102 Mdot
.50819 .67402 Mdot
.40533 .60928 Mdot
.44324 .4189 Mdot
.38683 .60796 Mdot
.6571 .35285 Mdot
.37889 .6608 Mdot
.34095 .66012 Mdot
.4138 .43365 Mdot
.39616 .35083 Mdot
.47822 .58941 Mdot
.53693 .37058 Mdot
.39436 .62199 Mdot
.45687 .399 Mdot
.42352 .44045 Mdot
.37454 .39209 Mdot
.55053 .33055 Mdot
.37361 .60991 Mdot
.3063 .62619 Mdot
.44216 .5855 Mdot
.39715 .61775 Mdot
.15019 .45783 Mdot
.47666 .59467 Mdot
.46717 .5932 Mdot
.62664 .71483 Mdot
.38782 .40529 Mdot
.7031 .50172 Mdot
.42005 .37176 Mdot
.43455 .46851 Mdot
.42491 .39646 Mdot
.67157 .36318 Mdot
.3687 .42405 Mdot
.49461 .59112 Mdot
.69101 .50175 Mdot
.44602 .37951 Mdot
.39779 .40856 Mdot
.46988 .5952 Mdot
.36979 .61467 Mdot
.42267 .61744 Mdot
.45599 .59148 Mdot
.71166 .34194 Mdot
.61706 .66217 Mdot
.42406 .37678 Mdot
.68995 .51734 Mdot
.69823 .49693 Mdot
.38358 .60421 Mdot
.70715 .54021 Mdot
.62392 .66939 Mdot
.39459 .42647 Mdot
.6174 .67546 Mdot
.67061 .36323 Mdot
.3852 .62373 Mdot
.43086 .39373 Mdot
.42031 .36457 Mdot
.41452 .62511 Mdot
.38584 .35729 Mdot
.65772 .36073 Mdot
.72945 .49774 Mdot
.37194 .66147 Mdot
.59967 .67466 Mdot
.68602 .47483 Mdot
.44941 .39879 Mdot
.15424 .55545 Mdot
.41193 .41687 Mdot
.36759 .40813 Mdot
.37293 .58987 Mdot
.41361 .45076 Mdot
.68684 .49007 Mdot
.39255 .60624 Mdot
.45511 .38969 Mdot
.44973 .25126 Mdot
.63578 .34335 Mdot
.67345 .55751 Mdot
.41509 .42663 Mdot
.19915 .58421 Mdot
.43114 .43384 Mdot
.50349 .67361 Mdot
.52841 .31136 Mdot
.64667 .61966 Mdot
.4341 .2908 Mdot
.60878 .64828 Mdot
.47951 .58512 Mdot
.71419 .4889 Mdot
.29731 .57665 Mdot
.39995 .42105 Mdot
.29576 .43138 Mdot
.43099 .38985 Mdot
.61542 .69722 Mdot
.34346 .55242 Mdot
.6955 .54211 Mdot
.48854 .1702 Mdot
.38375 .37346 Mdot
.38159 .6722 Mdot
.73173 .48319 Mdot
.47552 .58465 Mdot
.3985 .35081 Mdot
.69879 .32568 Mdot
.63562 .32002 Mdot
.34513 .39844 Mdot
.60313 .68564 Mdot
.38729 .37879 Mdot
.38967 .46181 Mdot
.80901 .61438 Mdot
.40398 .63662 Mdot
.58876 .66911 Mdot
.7431 .35148 Mdot
.37572 .39697 Mdot
.42452 .62304 Mdot
.38864 .6544 Mdot
.70558 .34854 Mdot
.56115 .64982 Mdot
.62134 .35259 Mdot
.26987 .72678 Mdot
.2877 .32986 Mdot
.72893 .50739 Mdot
.40402 .68695 Mdot
.41319 .36609 Mdot
.6115 .2196 Mdot
.59655 .67056 Mdot
.41452 .40095 Mdot
.31761 .46392 Mdot
.4009 .64654 Mdot
.38798 .39425 Mdot
.68519 .33315 Mdot
.50676 .83317 Mdot
.2203 .54084 Mdot
.20466 .60988 Mdot
.72412 .54788 Mdot
.40236 .33782 Mdot
.34509 .37608 Mdot
.47566 .60761 Mdot
.45905 .4148 Mdot
.6779 .50499 Mdot
.5831 .57646 Mdot
.69286 .34503 Mdot
.37866 .61756 Mdot
.47239 .58955 Mdot
.43145 .39038 Mdot
.38697 .34149 Mdot
.65575 .36261 Mdot
.38128 .36541 Mdot
.26415 .58712 Mdot
.5108 .57848 Mdot
.69552 .47421 Mdot
.38998 .66908 Mdot
.42348 .34055 Mdot
.495 .58098 Mdot
.41851 .43109 Mdot
.31764 .42146 Mdot
.41492 .38876 Mdot
.49668 .65847 Mdot
.41759 .62436 Mdot
.59645 .68177 Mdot
.35888 .40786 Mdot
.39701 .39414 Mdot
.61261 .47497 Mdot
.4803 .41593 Mdot
.41922 .38086 Mdot
.39573 .59953 Mdot
.37622 .61962 Mdot
.37476 .66886 Mdot
.67535 .48353 Mdot
.52405 .42422 Mdot
.61462 .68055 Mdot
.46558 .44111 Mdot
.62238 .70553 Mdot
.44983 .29498 Mdot
.67335 .3667 Mdot
.50471 .6871 Mdot
.39155 .42361 Mdot
.41138 .64933 Mdot
.24523 .32099 Mdot
.37624 .60779 Mdot
.64321 .66334 Mdot
.59417 .67388 Mdot
.39461 .62929 Mdot
.41496 .42389 Mdot
.53014 .37786 Mdot
.21126 .62689 Mdot
.60176 .70302 Mdot
.47774 .37085 Mdot
.67886 .56908 Mdot
.66149 .52929 Mdot
.15622 .44001 Mdot
.61701 .70505 Mdot
.59591 .80062 Mdot
.45224 .40234 Mdot
.39115 .60898 Mdot
.61062 .66027 Mdot
.58042 .65038 Mdot
.70495 .54261 Mdot
.42657 .36587 Mdot
.39475 .3939 Mdot
.48745 .59968 Mdot
.61089 .66678 Mdot
.32775 .37744 Mdot
.42323 .36009 Mdot
.55061 .70313 Mdot
.41769 .66181 Mdot
.83678 .52707 Mdot
.42338 .51509 Mdot
.31602 .46247 Mdot
.79591 .56433 Mdot
.36871 .66019 Mdot
.39504 .3715 Mdot
.47827 .41763 Mdot
.7312 .51151 Mdot
.40401 .42587 Mdot
.66343 .50963 Mdot
.62396 .68833 Mdot
.45992 .69511 Mdot
.50737 .53737 Mdot
.54269 .65172 Mdot
.41241 .41267 Mdot
.22417 .55169 Mdot
.68183 .35623 Mdot
.64537 .69887 Mdot
.36177 .65932 Mdot
.44347 .43478 Mdot
.72676 .52918 Mdot
.66948 .49479 Mdot
.39763 .64555 Mdot
.57041 .784 Mdot
.50458 .67746 Mdot
.3649 .3781 Mdot
.68116 .52866 Mdot
.45138 .52598 Mdot
.1998 .55503 Mdot
.63502 .68569 Mdot
.6919 .34756 Mdot
.70468 .48567 Mdot
.57654 .69227 Mdot
.45254 .3732 Mdot
.3933 .63995 Mdot
.37685 .67461 Mdot
.57404 .52088 Mdot
.71225 .50768 Mdot
.67224 .34204 Mdot
.57217 .52562 Mdot
.54594 .50959 Mdot
.68649 .33972 Mdot
.66599 .49246 Mdot
.36851 .64351 Mdot
.40596 .64928 Mdot
.38314 .65647 Mdot
.28872 .61463 Mdot
.43763 .62353 Mdot
.60079 .27513 Mdot
.45622 .42116 Mdot
.22003 .57282 Mdot
.44593 .42835 Mdot
.58703 .69821 Mdot
.40317 .6187 Mdot
.52501 .31111 Mdot
.3918 .45548 Mdot
.21754 .63044 Mdot
.40274 .38191 Mdot
.56405 .56089 Mdot
.38875 .40627 Mdot
.24059 .52592 Mdot
.42473 .60673 Mdot
.36666 .38893 Mdot
.62636 .65196 Mdot
.66175 .35111 Mdot
.35025 .67974 Mdot
.41423 .37785 Mdot
.4941 .7945 Mdot
.43393 .40976 Mdot
.47047 .68374 Mdot
.58497 .5192 Mdot
.72249 .34538 Mdot
.38696 .44291 Mdot
.72009 .54044 Mdot
.38963 .49252 Mdot
.21613 .56399 Mdot
.60401 .70395 Mdot
.22546 .56004 Mdot
.68899 .54525 Mdot
.34024 .55519 Mdot
.37984 .45622 Mdot
.69483 .34203 Mdot
.47726 .64146 Mdot
.60253 .69898 Mdot
.39226 .4215 Mdot
.38347 .37549 Mdot
.5473 .60438 Mdot
.20268 .53708 Mdot
.3261 .39786 Mdot
.64952 .33805 Mdot
.21496 .53334 Mdot
.42074 .3854 Mdot
.67714 .56085 Mdot
.41412 .60865 Mdot
.35218 .54432 Mdot
.32685 .5709 Mdot
.43223 .36395 Mdot
.39698 .63228 Mdot
.41608 .61258 Mdot
.26791 .28165 Mdot
.69036 .3559 Mdot
.41293 .38654 Mdot
.58827 .53145 Mdot
.42629 .38053 Mdot
.61911 .69106 Mdot
.40952 .45562 Mdot
.72126 .51071 Mdot
.50335 .46555 Mdot
.67328 .48626 Mdot
.37205 .39566 Mdot
.38364 .63464 Mdot
.58904 .69185 Mdot
.67148 .6441 Mdot
.56443 .64773 Mdot
.59987 .27577 Mdot
.6526 .30326 Mdot
.68557 .3255 Mdot
.68014 .36898 Mdot
.63439 .70854 Mdot
.40922 .42933 Mdot
.54808 .35988 Mdot
.46856 .40083 Mdot
.38344 .40513 Mdot
.41867 .39127 Mdot
.6611 .66584 Mdot
.59396 .67547 Mdot
.70536 .49286 Mdot
.39454 .41819 Mdot
.4576 .40249 Mdot
.38789 .6313 Mdot
.68677 .32647 Mdot
.7122 .4802 Mdot
.7035 .32559 Mdot
.68889 .50678 Mdot
.21142 .35948 Mdot
.46215 .3431 Mdot
.66417 .35454 Mdot
.63057 .69722 Mdot
.40121 .65771 Mdot
.47865 .60256 Mdot
.69667 .53263 Mdot
.69945 .54101 Mdot
.42504 .34388 Mdot
.38957 .61659 Mdot
.41044 .61236 Mdot
.70707 .33072 Mdot
.59479 .65899 Mdot
.44355 .34753 Mdot
.41184 .3477 Mdot
.67924 .63028 Mdot
.73098 .49958 Mdot
.21544 .54723 Mdot
.42009 .58831 Mdot
.39545 .4301 Mdot
.42378 .62437 Mdot
.40383 .39969 Mdot
.45348 .53501 Mdot
.36639 .66864 Mdot
.41489 .45174 Mdot
.45086 .44558 Mdot
.72783 .50418 Mdot
.31547 .24289 Mdot
.4293 .3366 Mdot
.60908 .6292 Mdot
.40355 .36159 Mdot
.46328 .14816 Mdot
.25388 .31126 Mdot
.42686 .4229 Mdot
.36529 .41368 Mdot
.24626 .70302 Mdot
.42566 .43598 Mdot
.49269 .59582 Mdot
.43462 .46894 Mdot
.42374 .63136 Mdot
.58184 .54403 Mdot
.54177 .36252 Mdot
.69145 .35791 Mdot
.6912 .51979 Mdot
.53721 .27362 Mdot
.69452 .36278 Mdot
.40515 .64624 Mdot
.41919 .33117 Mdot
.40729 .58641 Mdot
.67705 .46837 Mdot
.33236 .36286 Mdot
.61823 .69455 Mdot
.54451 .36407 Mdot
.71603 .5384 Mdot
.59966 .67363 Mdot
.42968 .43652 Mdot
.66788 .46084 Mdot
.64486 .67998 Mdot
.28088 .26068 Mdot
.58398 .65611 Mdot
.59296 .68502 Mdot
.5277 .39471 Mdot
.69193 .35767 Mdot
.58082 .58491 Mdot
.49552 .40315 Mdot
.58952 .69576 Mdot
.49487 .1866 Mdot
.73327 .5112 Mdot
.5303 .4367 Mdot
.41747 .60161 Mdot
.47341 .35806 Mdot
.418 .39916 Mdot
.5838 .66249 Mdot
.42963 .66853 Mdot
.61861 .46248 Mdot
.62258 .69666 Mdot
.36982 .43782 Mdot
.52305 .46729 Mdot
.4991 .58248 Mdot
.47728 .59637 Mdot
.64818 .3579 Mdot
.7642 .40749 Mdot
.41922 .62956 Mdot
.65014 .34769 Mdot
.49592 .29582 Mdot
.39774 .37984 Mdot
.61752 .67167 Mdot
.47 .59222 Mdot
.60204 .67607 Mdot
.67968 .35118 Mdot
.65949 .36544 Mdot
.40254 .62893 Mdot
.36521 .66091 Mdot
.43637 .68081 Mdot
.42098 .24175 Mdot
.43544 .38137 Mdot
.2849 .43801 Mdot
.35892 .65989 Mdot
.30565 .58362 Mdot
.70233 .34587 Mdot
.69783 .32962 Mdot
.20625 .45198 Mdot
.44657 .39217 Mdot
.56523 .56754 Mdot
.42474 .3904 Mdot
.53976 .20794 Mdot
.43214 .39358 Mdot
.70954 .53885 Mdot
.38417 .37033 Mdot
.42179 .79417 Mdot
.45296 .39016 Mdot
.42167 .39534 Mdot
.70352 .52185 Mdot
.41639 .33914 Mdot
.7201 .51766 Mdot
.39678 .37256 Mdot
.66998 .31075 Mdot
.69044 .51743 Mdot
.68773 .31354 Mdot
.54796 .53776 Mdot
.4856 .59302 Mdot
.68614 .36464 Mdot
.68582 .3244 Mdot
.55874 .30905 Mdot
.36773 .63493 Mdot
.3912 .53203 Mdot
.42132 .41021 Mdot
.72465 .48213 Mdot
.62371 .67265 Mdot
.42964 .36129 Mdot
.39275 .44239 Mdot
.43553 .34082 Mdot
.39956 .62847 Mdot
.67919 .47408 Mdot
.6718 .35497 Mdot
.67314 .49928 Mdot
.67441 .31156 Mdot
.72427 .51086 Mdot
.47334 .37595 Mdot
.44873 .36476 Mdot
.34677 .37045 Mdot
.3177 .49313 Mdot
.66538 .23776 Mdot
.39528 .64301 Mdot
.48894 .58436 Mdot
.67011 .36707 Mdot
.54017 .47995 Mdot
.41901 .63774 Mdot
.70373 .53895 Mdot
.39249 .39014 Mdot
.45002 .33496 Mdot
.49222 .41214 Mdot
.34722 .6227 Mdot
.71826 .32514 Mdot
.69585 .52759 Mdot
.50219 .58934 Mdot
.52381 .43582 Mdot
.31168 .63145 Mdot
.50279 .28876 Mdot
.40032 .39656 Mdot
.70931 .33221 Mdot
.38457 .61617 Mdot
.56501 .58498 Mdot
.58371 .66607 Mdot
.53658 .37393 Mdot
.41363 .41272 Mdot
.63972 .7469 Mdot
.38323 .63668 Mdot
.69304 .33296 Mdot
.58324 .66284 Mdot
.69575 .35032 Mdot
.49317 .57892 Mdot
.42812 .58759 Mdot
.39849 .35174 Mdot
.42637 .3917 Mdot
.62495 .68027 Mdot
.41931 .6244 Mdot
.65257 .31632 Mdot
.55564 .60399 Mdot
.69235 .53461 Mdot
.52802 .48244 Mdot
.37994 .61755 Mdot
.65528 .73831 Mdot
.67017 .50137 Mdot
.60237 .71148 Mdot
.53768 .35571 Mdot
.62105 .66309 Mdot
.41956 .38701 Mdot
.37634 .64308 Mdot
.60674 .70556 Mdot
.67352 .61127 Mdot
.2593 .65744 Mdot
.49282 .63344 Mdot
.3716 .40235 Mdot
.49357 .69394 Mdot
.55686 .80092 Mdot
.36228 .69544 Mdot
.62298 .7033 Mdot
.40547 .4108 Mdot
.36574 .37693 Mdot
.38334 .37322 Mdot
.58618 .67832 Mdot
.66958 .68554 Mdot
.67795 .53393 Mdot
.38526 .38975 Mdot
.66191 .33593 Mdot
.71886 .50309 Mdot
.67575 .54957 Mdot
.70282 .4851 Mdot
.3599 .65458 Mdot
.4435 .33357 Mdot
.45282 .45981 Mdot
.28931 .27489 Mdot
.59472 .6839 Mdot
.48605 .59283 Mdot
.36504 .40126 Mdot
.59423 .28306 Mdot
.402 .65551 Mdot
.70344 .52988 Mdot
.4132 .40023 Mdot
.58057 .51932 Mdot
.51773 .5846 Mdot
.69955 .51172 Mdot
.36256 .66375 Mdot
.33334 .68884 Mdot
.40109 .42604 Mdot
.41071 .36337 Mdot
.41244 .63418 Mdot
.5568 .81492 Mdot
.52242 .44664 Mdot
.40215 .40138 Mdot
.5957 .67794 Mdot
.71452 .76285 Mdot
.43451 .43476 Mdot
.43469 .60032 Mdot
.50717 .58902 Mdot
.39808 .58315 Mdot
.24543 .59997 Mdot
.46609 .43404 Mdot
.41599 .71026 Mdot
.61017 .31448 Mdot
.36012 .71144 Mdot
.56455 .21491 Mdot
.55827 .60903 Mdot
.23691 .29968 Mdot
.58751 .63585 Mdot
.23305 .50524 Mdot
.39113 .8292 Mdot
.59204 .79631 Mdot
.60665 .4954 Mdot
.64473 .59989 Mdot
.64903 .4903 Mdot
.49851 .16011 Mdot
.71535 .54553 Mdot
.57259 .20567 Mdot
.42929 .40041 Mdot
.54633 .81388 Mdot
.23396 .52735 Mdot
.68717 .26342 Mdot
.5143 .67668 Mdot
.58014 .52252 Mdot
.17984 .59707 Mdot
.53175 .68795 Mdot
.1712 .46689 Mdot
.34779 .48939 Mdot
.79363 .43647 Mdot
.54092 .49166 Mdot
.55362 .27912 Mdot
.23519 .56677 Mdot
.40334 .76454 Mdot
.58308 .72835 Mdot
.25551 .39333 Mdot
.80867 .55813 Mdot
.6796 .51966 Mdot
.42197 .61112 Mdot
.62683 .59024 Mdot
.1757 .52115 Mdot
.63328 .64638 Mdot
.41413 .7108 Mdot
.52492 .62173 Mdot
.23797 .5206 Mdot
.515 .31136 Mdot
.23488 .47172 Mdot
.61814 .35017 Mdot
.50376 .16437 Mdot
.33361 .63323 Mdot
.70088 .59436 Mdot
.54463 .46325 Mdot
.60482 .37404 Mdot
.25759 .55684 Mdot
.64531 .33536 Mdot
.64508 .33046 Mdot
.36569 .66705 Mdot
.1872 .5347 Mdot
.52166 .58642 Mdot
.48864 .29321 Mdot
.72052 .54237 Mdot
.46132 .53404 Mdot
.49866 .82997 Mdot
.55048 .79676 Mdot
.35273 .21865 Mdot
.15588 .5434 Mdot
.49597 .21404 Mdot
.55592 .57995 Mdot
.6474 .65148 Mdot
.58748 .29764 Mdot
.31967 .38939 Mdot
.47453 .21045 Mdot
.32253 .43434 Mdot
.21507 .65396 Mdot
.518 .77959 Mdot
.16379 .58225 Mdot
.33019 .64767 Mdot
.38236 .33655 Mdot
.49314 .55568 Mdot
.28937 .34519 Mdot
.48353 .26599 Mdot
.17052 .56822 Mdot
.71535 .35647 Mdot
.43994 .64692 Mdot
.59553 .79376 Mdot
.26229 .5879 Mdot
.62421 .38337 Mdot
.71351 .29617 Mdot
.36388 .54013 Mdot
.18085 .62106 Mdot
.42076 .71096 Mdot
.23341 .35976 Mdot
.56455 .72228 Mdot
.72053 .461 Mdot
.68 .55175 Mdot
.58543 .64619 Mdot
.16281 .50003 Mdot
.3794 .64752 Mdot
.30931 .2434 Mdot
.40264 .70034 Mdot
.37733 .48729 Mdot
.1833 .63089 Mdot
.43802 .19652 Mdot
.23278 .58774 Mdot
.63486 .25468 Mdot
.69195 .75217 Mdot
.33042 .32779 Mdot
.56807 .63674 Mdot
.67503 .56469 Mdot
.48696 .67412 Mdot
.16468 .51309 Mdot
.4746 .19822 Mdot
.30104 .76509 Mdot
.48229 .29163 Mdot
.73574 .45255 Mdot
.34007 .61963 Mdot
.6228 .48465 Mdot
.63259 .40099 Mdot
.16155 .57707 Mdot
.2202 .52802 Mdot
.70958 .75797 Mdot
.54841 .22365 Mdot
.31959 .57968 Mdot
.48106 .70784 Mdot
.63082 .56009 Mdot
.31965 .32408 Mdot
.5092 .79285 Mdot
.38778 .34509 Mdot
.50871 .28296 Mdot
.36191 .52178 Mdot
.66475 .38634 Mdot
.52076 .43521 Mdot
.52129 .76289 Mdot
.50723 .23694 Mdot
.64188 .77073 Mdot
.36731 .5455 Mdot
.35024 .66076 Mdot
.47757 .21318 Mdot
.5221 .21622 Mdot
.57853 .75145 Mdot
.74265 .34868 Mdot
.22897 .36433 Mdot
.67141 .42672 Mdot
.45598 .44772 Mdot
.23156 .49851 Mdot
.23747 .56773 Mdot
.51683 .18316 Mdot
.47425 .3726 Mdot
.32167 .24959 Mdot
.53402 .65369 Mdot
.304 .49823 Mdot
.48277 .24892 Mdot
.31385 .49561 Mdot
.21866 .5971 Mdot
.4664 .56195 Mdot
.63013 .62016 Mdot
.44805 .65396 Mdot
.1828 .62157 Mdot
.71307 .49533 Mdot
.46994 .20621 Mdot
.59587 .63301 Mdot
.67456 .61975 Mdot
.58202 .59619 Mdot
.62415 .45782 Mdot
.163 .46244 Mdot
.58585 .78338 Mdot
.65777 .57666 Mdot
.37884 .76038 Mdot
.44462 .52616 Mdot
.28712 .44771 Mdot
.37601 .32716 Mdot
.33379 .44881 Mdot
.65779 .36106 Mdot
.31729 .53933 Mdot
.44119 .57909 Mdot
.74282 .29808 Mdot
.47217 .4057 Mdot
.54718 .49414 Mdot
.49874 .59862 Mdot
.55266 .37914 Mdot
.2098 .35931 Mdot
.38015 .32426 Mdot
.43428 .20077 Mdot
.58264 .78963 Mdot
.55616 .36739 Mdot
.62763 .39536 Mdot
.39108 .54095 Mdot
.16415 .58746 Mdot
.17289 .40267 Mdot
.50138 .81291 Mdot
.48081 .69676 Mdot
.63407 .16475 Mdot
.63576 .61724 Mdot
.3481 .23652 Mdot
.60052 .63342 Mdot
.90747 .54815 Mdot
.67255 .49646 Mdot
.61752 .21655 Mdot
.29324 .37155 Mdot
.58173 .48685 Mdot
.18043 .53092 Mdot
.25074 .58338 Mdot
.71778 .31589 Mdot
.343 .65207 Mdot
.47759 .39434 Mdot
.17719 .56726 Mdot
.18706 .62164 Mdot
.17904 .573 Mdot
.64257 .73482 Mdot
.22335 .62262 Mdot
.22459 .6825 Mdot
.60303 .27466 Mdot
.53572 .58869 Mdot
.38437 .45859 Mdot
.40733 .23818 Mdot
.40441 .21601 Mdot
.70926 .37152 Mdot
.33341 .32467 Mdot
.33343 .63188 Mdot
.20918 .66823 Mdot
.21052 .35433 Mdot
.23514 .44746 Mdot
.17306 .45134 Mdot
.68933 .58093 Mdot
.4314 .23067 Mdot
.16668 .43815 Mdot
.40272 .74739 Mdot
.537 .67673 Mdot
.23456 .70086 Mdot
.52397 .22379 Mdot
.64626 .601 Mdot
.46569 .79993 Mdot
.38117 .22082 Mdot
.47136 .7073 Mdot
.6412 .5909 Mdot
.31479 .38873 Mdot
.32446 .61747 Mdot
.62658 .45747 Mdot
.39571 .7611 Mdot
.55929 .57248 Mdot
.46888 .24183 Mdot
.67349 .5426 Mdot
.45669 .21047 Mdot
.61784 .40379 Mdot
.53834 .5922 Mdot
.54404 .28779 Mdot
.48494 .18765 Mdot
.47679 .7795 Mdot
.20162 .59796 Mdot
.58505 .78797 Mdot
.68443 .76891 Mdot
.52005 .71865 Mdot
.36712 .51632 Mdot
.41736 .33891 Mdot
.17589 .52838 Mdot
.15688 .39576 Mdot
.16166 .45058 Mdot
.60342 .76424 Mdot
.73464 .54831 Mdot
.58847 .70574 Mdot
.57884 .29849 Mdot
.59198 .47741 Mdot
.51556 .63478 Mdot
.58819 .40102 Mdot
.57644 .64624 Mdot
.51282 .83358 Mdot
.45153 .67015 Mdot
.59408 .28684 Mdot
.25232 .41172 Mdot
.32576 .36829 Mdot
.19923 .55181 Mdot
.35548 .67173 Mdot
.61392 .76364 Mdot
.47242 .20986 Mdot
.71157 .49135 Mdot
.68342 .62118 Mdot
.4506 .64473 Mdot
.39485 .33108 Mdot
.7126 .57274 Mdot
.49678 .62628 Mdot
.31396 .46116 Mdot
.72277 .55628 Mdot
.22095 .32994 Mdot
.33801 .23623 Mdot
.16706 .43457 Mdot
.49305 .20742 Mdot
.68732 .60688 Mdot
.54303 .3975 Mdot
.63408 .62844 Mdot
.52166 .67854 Mdot
.54167 .44447 Mdot
.49618 .2006 Mdot
.22878 .58852 Mdot
.48985 .57052 Mdot
.46276 .44225 Mdot
.2406 .32657 Mdot
.57408 .27528 Mdot
.5491 .40155 Mdot
.36137 .56844 Mdot
.43751 .63473 Mdot
.67206 .23135 Mdot
.41551 .77629 Mdot
.42189 .48386 Mdot
.48609 .70062 Mdot
.63694 .68736 Mdot
.36464 .67007 Mdot
.48319 .18594 Mdot
.7546 .36615 Mdot
.37318 .70421 Mdot
.51549 .55081 Mdot
.17012 .50038 Mdot
.53385 .53331 Mdot
.46822 .69857 Mdot
.32419 .7163 Mdot
.73041 .72705 Mdot
.33122 .65101 Mdot
.54689 .58205 Mdot
.59523 .58243 Mdot
.32483 .63661 Mdot
.35014 .62564 Mdot
.22157 .53808 Mdot
.15634 .51411 Mdot
.56892 .53037 Mdot
.38587 .74878 Mdot
.55048 .36182 Mdot
.62067 .47954 Mdot
.51186 .56627 Mdot
.53798 .27851 Mdot
.38281 .72959 Mdot
.20623 .41888 Mdot
.59112 .83365 Mdot
.34641 .3126 Mdot
.60874 .20989 Mdot
.58052 .2995 Mdot
.35054 .49106 Mdot
.25552 .5507 Mdot
.54649 .70671 Mdot
.41464 .37115 Mdot
.14927 .5236 Mdot
.5247 .77304 Mdot
.55854 .32437 Mdot
.63176 .54438 Mdot
.44035 .42024 Mdot
.34626 .37668 Mdot
.16548 .44662 Mdot
.36406 .59048 Mdot
.47788 .86816 Mdot
.55004 .21672 Mdot
.37521 .49858 Mdot
.23836 .59968 Mdot
.42888 .20446 Mdot
.4639 .55812 Mdot
.41091 .70019 Mdot
.62413 .41129 Mdot
.40539 .21148 Mdot
.35454 .74242 Mdot
.40108 .77808 Mdot
.51573 .71053 Mdot
.22324 .67622 Mdot
.39884 .50702 Mdot
.5608 .71152 Mdot
.69831 .58051 Mdot
.3674 .41131 Mdot
.56808 .78448 Mdot
.50947 .69623 Mdot
.66652 .44682 Mdot
.31739 .38202 Mdot
.1532 .40005 Mdot
.40437 .46671 Mdot
.5707 .77351 Mdot
.45809 .85942 Mdot
.53395 .87556 Mdot
.4142 .79008 Mdot
.15947 .57255 Mdot
.38852 .7705 Mdot
.46345 .70366 Mdot
.63508 .70263 Mdot
.53799 .50525 Mdot
.29064 .43091 Mdot
.14967 .4933 Mdot
.77581 .39412 Mdot
.55975 .64084 Mdot
.26928 .38031 Mdot
.148 .49428 Mdot
.43035 .46375 Mdot
.64636 .21934 Mdot
.72676 .46688 Mdot
.47976 .16364 Mdot
.36513 .21374 Mdot
.34418 .58354 Mdot
.50724 .17847 Mdot
.61945 .20159 Mdot
.6573 .27155 Mdot
.34482 .23517 Mdot
.31705 .31064 Mdot
.3667 .57284 Mdot
.48245 .21657 Mdot
.49358 .67761 Mdot
.56846 .14838 Mdot
.51111 .56383 Mdot
.53003 .61218 Mdot
.41742 .58184 Mdot
.48578 .67309 Mdot
.47967 .76534 Mdot
.53475 .5645 Mdot
.49704 .48316 Mdot
.21543 .58491 Mdot
.73144 .75603 Mdot
.36566 .77489 Mdot
.45904 .65161 Mdot
.19056 .61944 Mdot
.55731 .71864 Mdot
.54964 .43782 Mdot
.2655 .57071 Mdot
.57376 .28516 Mdot
.67738 .57723 Mdot
.4253 .39656 Mdot
.15689 .51902 Mdot
.67752 .5768 Mdot
.18737 .60006 Mdot
.28751 .25339 Mdot
.18055 .44592 Mdot
.36272 .32564 Mdot
.66734 .56289 Mdot
.42454 .21693 Mdot
.42608 .2188 Mdot
.22644 .65834 Mdot
.59232 .19929 Mdot
.53478 .45815 Mdot
.54421 .55051 Mdot
.50769 .54049 Mdot
.43414 .48389 Mdot
.42183 .20465 Mdot
.40368 .53592 Mdot
.49253 .25368 Mdot
.47715 .81135 Mdot
.48951 .19376 Mdot
.23874 .5865 Mdot
.56642 .29465 Mdot
.66039 .43092 Mdot
.70818 .31186 Mdot
.73155 .49773 Mdot
.27543 .73995 Mdot
.54376 .72737 Mdot
.31377 .25586 Mdot
.68792 .76254 Mdot
.51392 .79166 Mdot
.56957 .20103 Mdot
.48307 .57492 Mdot
.33984 .30856 Mdot
.78598 .4229 Mdot
.51564 .24468 Mdot
.21929 .54835 Mdot
.50033 .67774 Mdot
.32268 .59598 Mdot
.15784 .47728 Mdot
.47253 .24516 Mdot
.34112 .80602 Mdot
.76618 .52067 Mdot
.31798 .53356 Mdot
.19132 .51903 Mdot
.66483 .78605 Mdot
.55248 .39605 Mdot
.18429 .62422 Mdot
.39363 .59548 Mdot
.15727 .54777 Mdot
.5915 .65267 Mdot
.71518 .43442 Mdot
.5273 .65225 Mdot
.56776 .33609 Mdot
.56791 .34298 Mdot
.25729 .29549 Mdot
.59146 .78988 Mdot
.55192 .79857 Mdot
.67213 .4269 Mdot
.70123 .55071 Mdot
.51439 .50728 Mdot
.39339 .74424 Mdot
.28424 .74603 Mdot
.43873 .35133 Mdot
.7701 .49674 Mdot
.45536 .19945 Mdot
.6365 .62943 Mdot
.52641 .61774 Mdot
.51738 .65691 Mdot
.31215 .68696 Mdot
.42684 .23404 Mdot
.21561 .66862 Mdot
.51633 .62271 Mdot
.59589 .4582 Mdot
.32967 .56011 Mdot
.53589 .62833 Mdot
.65615 .75541 Mdot
.40574 .71992 Mdot
.52583 .54185 Mdot
.52452 .44256 Mdot
.49971 .21321 Mdot
.19042 .34517 Mdot
.2028 .63897 Mdot
.66977 .75409 Mdot
.5602 .36971 Mdot
.43476 .60172 Mdot
.53226 .25948 Mdot
.33399 .80218 Mdot
.48629 .1575 Mdot
.47687 .79886 Mdot
.48441 .19594 Mdot
.63337 .48993 Mdot
.62847 .2143 Mdot
.54659 .42221 Mdot
.19107 .51602 Mdot
.28587 .36547 Mdot
.43033 .58666 Mdot
.63023 .5653 Mdot
.54837 .34881 Mdot
.54699 .6134 Mdot
.36836 .57005 Mdot
.5946 .78803 Mdot
.34251 .80675 Mdot
.5834 .19098 Mdot
.3419 .55602 Mdot
.36402 .81017 Mdot
.40297 .67419 Mdot
.59975 .58392 Mdot
.67513 .7167 Mdot
.55916 .36279 Mdot
.68257 .48701 Mdot
.33012 .4211 Mdot
.52169 .47714 Mdot
.36939 .76217 Mdot
.64226 .50066 Mdot
.69476 .36558 Mdot
.35418 .62888 Mdot
.60686 .1988 Mdot
.38227 .67638 Mdot
.20646 .33028 Mdot
.40634 .74514 Mdot
.21741 .57455 Mdot
.33699 .7461 Mdot
.72897 .58174 Mdot
.68748 .771 Mdot
.17167 .46376 Mdot
.44906 .25203 Mdot
.34713 .63484 Mdot
.35234 .67317 Mdot
.3542 .73749 Mdot
.65591 .70389 Mdot
.1741 .49827 Mdot
.444 .19608 Mdot
.69357 .60667 Mdot
.42841 .63525 Mdot
.55227 .55352 Mdot
.45733 .64895 Mdot
.21343 .34056 Mdot
.6757 .49672 Mdot
.17183 .60872 Mdot
.39666 .53323 Mdot
.60994 .80717 Mdot
.50183 .6431 Mdot
.50682 .45284 Mdot
.55692 .39931 Mdot
.67137 .60556 Mdot
.45315 .4532 Mdot
.37792 .49898 Mdot
.36331 .65651 Mdot
.57509 .59973 Mdot
.68331 .3277 Mdot
.74381 .31247 Mdot
.61692 .62689 Mdot
.34281 .49378 Mdot
.40936 .20279 Mdot
.35746 .67333 Mdot
.76181 .52869 Mdot
.768 .54942 Mdot
.45619 .43857 Mdot
.37157 .25242 Mdot
.25838 .71858 Mdot
.17368 .47101 Mdot
.38064 .60233 Mdot
.66534 .77117 Mdot
.62737 .35131 Mdot
.2272 .3248 Mdot
.32495 .68849 Mdot
.44288 .20588 Mdot
.35094 .52253 Mdot
.17695 .40863 Mdot
.24534 .5994 Mdot
.45647 .68053 Mdot
.48097 .2096 Mdot
.61743 .46613 Mdot
.47964 .19143 Mdot
.309 .68514 Mdot
.51468 .53085 Mdot
.47979 .16618 Mdot
.63261 .4995 Mdot
.234 .47701 Mdot
.38018 .47601 Mdot
.49975 .6424 Mdot
.41773 .21187 Mdot
.36116 .62109 Mdot
.64053 .352 Mdot
.26239 .40331 Mdot
.53204 .66714 Mdot
.16485 .50815 Mdot
.57786 .75305 Mdot
.45925 .19482 Mdot
.50162 .53879 Mdot
.57179 .25452 Mdot
.4009 .5308 Mdot
.47342 .27845 Mdot
.35347 .40734 Mdot
.36123 .52698 Mdot
.59879 .40834 Mdot
.26205 .30085 Mdot
.40305 .49671 Mdot
.17495 .54772 Mdot
.2209 .34635 Mdot
.33097 .70995 Mdot
.57812 .57392 Mdot
.4281 .62102 Mdot
.17363 .60229 Mdot
.38563 .23942 Mdot
.49943 .66409 Mdot
.37059 .21183 Mdot
.67027 .22828 Mdot
.37959 .82216 Mdot
.54642 .75489 Mdot
.49863 .62377 Mdot
.31384 .24444 Mdot
.52462 .77748 Mdot
.63437 .20779 Mdot
.21841 .54306 Mdot
.37423 .58991 Mdot
.18583 .63665 Mdot
.29562 .32904 Mdot
.54009 .79977 Mdot
.19866 .53636 Mdot
.34494 .70127 Mdot
.37384 .24384 Mdot
.45593 .45454 Mdot
.72321 .53019 Mdot
.57223 .49737 Mdot
.51446 .17851 Mdot
.35663 .69857 Mdot
.43681 .20333 Mdot
.44367 .20817 Mdot
.58349 .21001 Mdot
.68207 .60408 Mdot
.38071 .82242 Mdot
.24825 .62595 Mdot
.36447 .35336 Mdot
.37186 .60445 Mdot
.68368 .36938 Mdot
.55329 .22728 Mdot
.44464 .379 Mdot
.51969 .33755 Mdot
.36108 .53526 Mdot
.1488 .51065 Mdot
.6432 .45278 Mdot
.57076 .71705 Mdot
.43118 .62501 Mdot
.49085 .6704 Mdot
.44611 .55615 Mdot
.59079 .79802 Mdot
.42458 .21249 Mdot
.37088 .70506 Mdot
.42693 .70359 Mdot
.53019 .79854 Mdot
.49436 .22789 Mdot
.61902 .33485 Mdot
.60336 .70656 Mdot
.30427 .44751 Mdot
.25285 .68364 Mdot
.53999 .78779 Mdot
.44159 .64219 Mdot
.45169 .78298 Mdot
.52011 .5298 Mdot
.60231 .74525 Mdot
.58843 .78997 Mdot
.45889 .57827 Mdot
.19582 .44354 Mdot
.35484 .72204 Mdot
.68085 .56977 Mdot
.5323 .21657 Mdot
.42207 .77064 Mdot
.43022 .20711 Mdot
.4467 .44896 Mdot
.1818 .54971 Mdot
.55979 .32858 Mdot
.64234 .37521 Mdot
.40556 .35723 Mdot
.30515 .38791 Mdot
.16496 .44646 Mdot
.45361 .79778 Mdot
.31258 .35618 Mdot
.44624 .62773 Mdot
.33968 .2325 Mdot
.7059 .5698 Mdot
.72303 .5577 Mdot
.63376 .24208 Mdot
.49606 .46501 Mdot
.58902 .47614 Mdot
.66014 .6499 Mdot
.44472 .45814 Mdot
.62444 .32099 Mdot
.52356 .54881 Mdot
.30622 .45381 Mdot
.34571 .24125 Mdot
.27012 .73083 Mdot
.49573 .54983 Mdot
.35517 .21558 Mdot
.28806 .38335 Mdot
.35907 .60118 Mdot
.59356 .19256 Mdot
.33 .33278 Mdot
.47663 .3794 Mdot
.64082 .35321 Mdot
.42667 .65672 Mdot
.26423 .71827 Mdot
.3293 .43526 Mdot
.66314 .39579 Mdot
.6626 .41783 Mdot
.50983 .55633 Mdot
.79813 .55626 Mdot
.53457 .65436 Mdot
.31606 .24139 Mdot
.47339 .20962 Mdot
.56262 .66293 Mdot
.37513 .76085 Mdot
.32079 .34043 Mdot
.17994 .55158 Mdot
.6079 .42521 Mdot
.16787 .47975 Mdot
.63549 .73972 Mdot
.32487 .48312 Mdot
.23143 .33748 Mdot
.49932 .27541 Mdot
.47866 .28191 Mdot
.36845 .55725 Mdot
.40098 .27737 Mdot
.47693 .60192 Mdot
.7442 .37015 Mdot
.55242 .15084 Mdot
.30973 .77658 Mdot
.60096 .8066 Mdot
.38897 .47093 Mdot
.52657 .25626 Mdot
.35601 .72693 Mdot
.54692 .44872 Mdot
.64132 .41085 Mdot
.73225 .56386 Mdot
.64019 .57288 Mdot
.71847 .75846 Mdot
.15016 .52033 Mdot
.40769 .35857 Mdot
.58972 .37283 Mdot
.7227 .29607 Mdot
.66415 .50439 Mdot
.24394 .41293 Mdot
.25546 .71208 Mdot
.59621 .70133 Mdot
.6927 .7056 Mdot
.65144 .63035 Mdot
.26039 .29433 Mdot
.68287 .69098 Mdot
.6433 .71229 Mdot
.2056 .3304 Mdot
.49911 .81034 Mdot
.30906 .63107 Mdot
.72376 .75282 Mdot
.24857 .31606 Mdot
.35767 .52002 Mdot
.70322 .57232 Mdot
.16373 .5387 Mdot
.55505 .40147 Mdot
.66551 .58221 Mdot
.304 .30444 Mdot
.48112 .2061 Mdot
.54356 .21727 Mdot
.57092 .70703 Mdot
.27875 .37561 Mdot
.73798 .26661 Mdot
.73367 .58043 Mdot
.63528 .8249 Mdot
.17684 .46505 Mdot
.26694 .68225 Mdot
.4111 .78529 Mdot
.68077 .43303 Mdot
.18143 .54124 Mdot
.44299 .21332 Mdot
.29843 .36256 Mdot
.76175 .38693 Mdot
.51849 .2826 Mdot
.55655 .27399 Mdot
.60519 .74403 Mdot
.17502 .43169 Mdot
.69004 .59955 Mdot
.34196 .29589 Mdot
.46826 .20182 Mdot
.29344 .38658 Mdot
.47157 .28021 Mdot
.2471 .67357 Mdot
.36753 .25116 Mdot
.50492 .20192 Mdot
.64999 .59531 Mdot
.64892 .32466 Mdot
.26132 .70815 Mdot
.4339 .53983 Mdot
.35157 .52833 Mdot
.46263 .86136 Mdot
.16383 .57992 Mdot
.33133 .32972 Mdot
.40684 .45611 Mdot
.24031 .29438 Mdot
.76054 .50462 Mdot
.34061 .24565 Mdot
.48506 .82612 Mdot
.55375 .21266 Mdot
.41014 .50439 Mdot
.43398 .39896 Mdot
.60757 .26028 Mdot
.34075 .60893 Mdot
.28892 .37077 Mdot
.67915 .65327 Mdot
.49873 .20265 Mdot
.34812 .49658 Mdot
.59015 .83379 Mdot
.30936 .68074 Mdot
.41535 .65227 Mdot
.15852 .52972 Mdot
.2461 .37353 Mdot
.3694 .5059 Mdot
.18763 .52431 Mdot
.60267 .4369 Mdot
.62529 .32143 Mdot
.39829 .52765 Mdot
.54476 .3954 Mdot
.5157 .17625 Mdot
.36306 .81153 Mdot
.29364 .44296 Mdot
.17558 .61738 Mdot
.16873 .41185 Mdot
.42034 .64713 Mdot
.29233 .35163 Mdot
.56685 .37057 Mdot
.35885 .71329 Mdot
.65243 .60865 Mdot
.67885 .61657 Mdot
.71227 .26203 Mdot
.74189 .30691 Mdot
.42755 .41985 Mdot
.63923 .73988 Mdot
.15943 .47768 Mdot
.70161 .25356 Mdot
.15819 .4897 Mdot
.3688 .52434 Mdot
.40847 .34014 Mdot
.53974 .87615 Mdot
.46385 .70139 Mdot
.45812 .35733 Mdot
.46157 .46282 Mdot
.44447 .4743 Mdot
.42043 .37988 Mdot
.65626 .71168 Mdot
.58119 .29072 Mdot
.54291 .2059 Mdot
.16613 .53309 Mdot
.42898 .64272 Mdot
.55821 .39287 Mdot
.59831 .63741 Mdot
.53792 .33467 Mdot
.45624 .29979 Mdot
.62965 .66564 Mdot
.54393 .19741 Mdot
.79323 .56011 Mdot
.61605 .38001 Mdot
.50026 .63304 Mdot
.48974 .47996 Mdot
.4223 .68955 Mdot
.56574 .19232 Mdot
.6644 .67354 Mdot
.65793 .27285 Mdot
.46371 .19565 Mdot
.34492 .56849 Mdot
.5706 .72513 Mdot
.63834 .17213 Mdot
.5498 .40562 Mdot
.64757 .73071 Mdot
.35446 .31093 Mdot
.31186 .65695 Mdot
.18491 .46939 Mdot
.63612 .31807 Mdot
.49151 .60524 Mdot
.33594 .55342 Mdot
.17961 .53008 Mdot
.63139 .68199 Mdot
.1772 .36282 Mdot
.3711 .30612 Mdot
.24251 .42288 Mdot
.24541 .64485 Mdot
.55082 .58656 Mdot
.22302 .55318 Mdot
.35054 .39814 Mdot
.5842 .4549 Mdot
.79106 .55277 Mdot
.4767 .63585 Mdot
.51398 .56794 Mdot
.37153 .71779 Mdot
.6017 .20876 Mdot
.21094 .42477 Mdot
.41063 .38604 Mdot
.7126 .35204 Mdot
.54576 .38051 Mdot
.68968 .42373 Mdot
.73535 .45272 Mdot
.53687 .67333 Mdot
.56268 .19404 Mdot
.54996 .21737 Mdot
.20366 .53673 Mdot
.17598 .58292 Mdot
.38008 .47707 Mdot
.17996 .45706 Mdot
.63945 .43813 Mdot
.48873 .76506 Mdot
.37474 .25102 Mdot
.35781 .80714 Mdot
.39122 .50742 Mdot
.41633 .48024 Mdot
.1813 .37849 Mdot
.17002 .45445 Mdot
.54577 .649 Mdot
.49291 .6854 Mdot
.5282 .15227 Mdot
.56979 .34444 Mdot
.72518 .75723 Mdot
.65999 .61257 Mdot
.19816 .35265 Mdot
.52635 .58138 Mdot
.34946 .31904 Mdot
.38601 .54487 Mdot
.47526 .39284 Mdot
.70113 .50396 Mdot
.32146 .70972 Mdot
.36516 .56042 Mdot
.42385 .28073 Mdot
.35534 .36111 Mdot
.61759 .5777 Mdot
.4316 .59774 Mdot
.31541 .78181 Mdot
.65776 .5124 Mdot
.59654 .45416 Mdot
.55462 .83818 Mdot
.79195 .55441 Mdot
.65757 .21888 Mdot
.21936 .65034 Mdot
.52092 .67555 Mdot
.52466 .54691 Mdot
.80429 .62826 Mdot
.40113 .59336 Mdot
.36147 .61051 Mdot
.62185 .62513 Mdot
.57886 .25873 Mdot
.57001 .77724 Mdot
.41225 .84043 Mdot
.17793 .40362 Mdot
.44947 .44588 Mdot
.72372 .78503 Mdot
.46344 .20017 Mdot
.5865 .41617 Mdot
.57695 .77689 Mdot
.15779 .51399 Mdot
.63034 .54368 Mdot
.28176 .26037 Mdot
.40515 .7621 Mdot
.33792 .69454 Mdot
.57342 .2699 Mdot
.66818 .76577 Mdot
.5516 .55863 Mdot
.63811 .82287 Mdot
.49326 .70564 Mdot
.55248 .27852 Mdot
.44578 .79517 Mdot
.33482 .64224 Mdot
.38042 .49817 Mdot
.41368 .7399 Mdot
.32087 .36755 Mdot
.38374 .69239 Mdot
.4208 .70992 Mdot
.61302 .34839 Mdot
.59573 .60499 Mdot
.46483 .69609 Mdot
.64184 .64038 Mdot
.34286 .58146 Mdot
.5179 .16136 Mdot
.76523 .49173 Mdot
.67088 .53867 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0Toooool2o`0001Gooooo
0_l000000ooooooo0000o`000006ooooo`;o0000T_ooool001cooooo0_l0002Dooooo`;o000000?o
ooooo`000?l000004?ooool4o`000004ooooool0003o0000ooooo`;o00000oooool2o`0000Wooooo
0_l00027ooooo`007?ooool00ol0003oooooooooo`2Cooooo`;o000000Coooooo`000?l0003ooooo
0_l00007ooooo`Co00000_ooool3o`0000Gooooo0_l0000>ooooo`;o0000Qoooool001cooooo00?o
0000ooooooooool0Toooool2o`0000Cooooo1Ol00004ooooo`Co00006oooool2o`0008Kooooo000L
ooooo`03o`000?oooooooooo09Oooooo2Ol00004ooooo`;o00006oooool2o`0008Kooooo000Loooo
o`03o`000?oooooooooo09Oooooo1?l00003ooooo`Co00000_ooool2o`0002Cooooo0_l0001moooo
o`007?ooool00ol0003oooooooooo`2Hooooo`;o00001_ooool2o`0002Sooooo0_l0001mooooo`00
7?ooool00ol0003oooooooooo`2Hooooo`Go0000;oooool2o`0007_ooooo000Looooo`03o`000?oo
oooooooo09[ooooo0ol0000_ooooo`;o0000Noooool001cooooo00?o0000ooooooooool0WOooool2
o`0000;ooooo0_l000000ooooooo0000o`00000Xooooo`;o0000NOooool001cooooo00?o0000oooo
ooooool0WOooool3o`000003ooooool0003o000000?o0000:?ooool2o`0007Wooooo000Looooo`03
o`000?oooooooooo09kooooo0ol00002ooooo`?o0000Xoooool001cooooo00?o0000ooooooooool0
Uoooool5o`000003ooooool0003o000000;o00000oooool2o`000:?ooooo000Looooo`03o`000?oo
oooooooo08oooooo0_l00002ooooo`Wo000000?oooooo`000?l000000ol00006ooooo`;o0000Wooo
ool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`00
0?oooooooooo08oooooo0_l00002ooooo`Oo000000?oooooo`000?l000001Ol00006ooooo`;o0000
2_ooool2o`0000Cooooo0_l000000ooooooo0000o`00002:ooooo`0000KoooooogMgMonHV9Sooooo
oiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000oooo
ooooool0Roooool3o`0000?ooooo1?l00003ooooo`So00004oooool3o`0000Cooooo0_l000000ooo
oooo0000o`00002:ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03
oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0P?ooool2o`0000Wooooo0ol00002ooooo`Go
000000?oooooo`000?l000000_ooool2o`000004ooooool0003o0000o`0000gooooo0_l00004oooo
o`;o00002?ooool2o`0000;ooooo0_l00026ooooo`0000?oooooo`000?ooool00_ooool00ol0003o
ooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol00020ooooo`?o00001_ooool2o`0000Go
oooo0_l000000ooooooo0000o`000003o`0000Gooooo1Ol0000;ooooo`;o00001_ooool2o`0000Ko
oooo0_l00002ooooo`Ko0000P_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
3?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo087ooooo0_l00002ooooo`;o0000
00?oooooo`000?l000001?l00005ooooo`Co00000_ooool2o`0000;ooooo1Ol0000;ooooo`;o0000
1_ooool3o`0000_ooooo1?l00022ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0QOooool2o`000003ooooool0
003o000000Co00001oooool2o`0000;ooooo0_l000000ooooooo0000o`00000>ooooo`?o00001ooo
ool2o`0000Sooooo0_l00008ooooo`;o0000OOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
2oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0M?ooool3o`0000Wo
oooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o00000oooool4o`0000;o
oooo0_l0000>ooooo`?o00002oooool2o`0000Cooooo1?l00006ooooo`;o0000OOooool00006oooo
ooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000
ooooooooool0Loooool4o`0000Wooooo0_l00002ooooo`Co00001?ooool2o`0000?ooooo0_l00003
ooooo`Co00000oooool4o`0000cooooo0_l000000ooooooo0000o`000002ooooo`;o00001?ooool2
o`0000Kooooo0_l00004ooooo`;o0000Ooooool001cooooo00?o0000ooooooooool0L?ooool2o`00
0003ooooool0003o000000_ooooo0_l00004ooooo`;o00001?ooool2o`0000Wooooo1?l00002oooo
o`Co00001Oooool2o`000003ooooool0003o000000;ooooo1Ol00002ooooo`;o00003_ooool3o`00
0003ooooool0003o000007oooooo000Looooo`03o`000?oooooooooo06oooooo0ol00006ooooo`;o
00001_ooool2o`0000Cooooo0ol0000@ooooo`;o00002oooool2o`000003ooooool0003o000000;o
oooo1?l0000Aooooo`Go00001oooool2o`0000;ooooo0_l0001eooooo`007?ooool00ol0003ooooo
ooooo`1_ooooo`;o00001oooool2o`0000Sooooo0_l00003ooooo`;o00007Oooool2o`0000Kooooo
0_l0000Booooo`?o00002Oooool2o`0000;ooooo0_l0001eooooo`007?ooool00ol0003ooooooooo
o`22ooooo`;o00001_ooool2o`0000;ooooo0_l0000Fooooo`;o00001_ooool4o`00013ooooo0_l0
0025ooooo`007?ooool00ol0003oooooooooo`28ooooo`Co00000_ooool2o`0000gooooo0_l00009
ooooo`Go00000oooool2o`0001cooooo0_l00006ooooo`;o0000LOooool001cooooo00?o0000oooo
ooooool0Joooool2o`0001?ooooo0_l00006ooooo`;o00004oooool2o`0000Wooooo1Ol000001Ooo
oooo0000o`000?l0003ooooo00;o00006?ooool4o`0000;ooooo0_l00002ooooo`?o0000L?ooool0
01cooooo00?o0000ooooooooool0J_ooool5o`0000gooooo0_l00002ooooo`Co00000oooool2o`00
01Sooooo0_l0000;ooooo`?o000000?oooooo`000?l000006?ooool2o`0000Cooooo1?l000000ooo
oooo0000o`00001`ooooo`007?ooool00ol0003oooooooooo`1Zooooo`Go00002oooool4o`0000?o
oooo0ol00002ooooo`?o00000_ooool2o`0000[ooooo0_l00008ooooo`;o0000:Oooool2o`0000Ko
oooo0_l0001cooooo`007?ooool00ol0003oooooooooo`1Sooooo`;o00001_ooool4o`0000_ooooo
0_l00005ooooo`;o00000_ooool4o`0000;ooooo1?l00006ooooo`Co00002Oooool2o`0001kooooo
0_l00006ooooo`Co00001_ooool2o`0007?ooooo000Looooo`03o`000?oooooooooo067ooooo1?l0
0005ooooo`Go00001oooool2o`000003ooooool0003o000000[ooooo1_l00002ooooo`;o00001_oo
ool3o`0000[ooooo1?l0000Looooo`;o00001_ooool2o`0000Cooooo0_l00008ooooo`;o0000KOoo
ool001cooooo00?o0000ooooooooool0HOooool3o`0000Kooooo0ol00009ooooo`;o000000?ooooo
o`000?l000001_ooool2o`0000Kooooo1?l00009ooooo`;o000000?oooooo`000?l000002Oooool2
o`0000;ooooo0_l0000Gooooo`;o00002oooool4o`0000Sooooo1?l0001[ooooo`007?ooool2o`00
06Kooooo0_l0000=ooooo`Co00001Oooool2o`0000;ooooo0_l00008ooooo`Go00001?ooool2o`00
00?ooooo0_l0000=ooooo`;o00005oooool2o`0000_ooooo0ol0000;ooooo`;o0000Joooool001co
oooo00?o0000ooooooooool0F_ooool2o`0000Wooooo1Ol00008ooooo`Wo00000_ooool2o`0000co
oooo1Ol00004ooooo`Co00001?ooool2o`0000[ooooo0_l00004ooooo`;o00001_ooool2o`0000Wo
oooo0_l00007ooooo`;o00005?ooool2o`0006Oooooo000Looooo`03o`000?oooooooooo05[ooooo
0_l00006ooooo`;o00000_ooool4o`0000Sooooo0_l000001?oooooo0000o`000?ooool3o`0001;o
oooo1?l00004ooooo`?o00000_ooool4o`0000Wooooo1Ol00002ooooo`;o00001_ooool2o`0001;o
oooo0ol00006ooooo`;o00002oooool2o`0006Oooooo000Looooo`03o`000?oooooooooo05Sooooo
0_l00008ooooo`;o0000:Oooool5o`0000Sooooo0_l00009ooooo`Oo00003?ooool2o`0000Sooooo
0_l00007ooooo`;o00001_ooool2o`0007Cooooo000Looooo`03o`000?oooooooooo05Sooooo0_l0
0008ooooo`;o00000_ooool2o`0000;ooooo0_l0000Sooooo`Co00001oooool2o`0000Oooooo1?l0
0002ooooo`;o00003Oooool2o`0000Sooooo0_l00007ooooo`;o00003Oooool3o`0000Oooooo0_l0
001Sooooo`007?ooool00ol0003oooooooooo`1Nooooo`?o00001Oooool2o`0000;ooooo0_l0000U
ooooo`Go00000oooool2o`0000;ooooo0_l00004ooooo`?o00000_ooool3o`00023ooooo0_l00009
ooooo`;o00000_ooool4o`0000Kooooo0_l00006ooooo`;o0000Foooool001cooooo00?o0000oooo
ooooool0G_ooool3o`00037ooooo1_l000000ooooooo0000o`000002ooooo`Wo00000_ooool3o`00
00Cooooo0_l00005ooooo`;o00007_ooool2o`0000Cooooo0_l0000>ooooo`;o0000Foooool001co
oooo00?o0000ooooooooool0D?ooool4o`0000Oooooo0_l0000eooooo`?o000000Coooooo`000?l0
003o00001_ooool6o`0000Cooooo1?l00002ooooo`;o00001Oooool2o`0001[ooooo0ol0001doooo
o`007?ooool00ol0003oooooooooo`1>ooooo`Ko00001_ooool3o`0003Kooooo0ol000000ooooooo
0000o`000002o`0000?ooooo0_l00003ooooo`;o00001_ooool2o`0000Cooooo0_l00004ooooo`;o
00001_ooool3o`00013ooooo0ol0001dooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o0000
2Oooool3o`0001[ooooo0_l00007ooooo`;o00004oooool4o`000004ooooool0003o0000o`0000;o
oooo0_l0000;ooooo`?o00000_ooool3o`0000Cooooo0_l00005ooooo`Co00002Oooool2o`0007co
oooo000Looooo`03o`000?oooooooooo05?ooooo0_l00004ooooo`;o00006oooool2o`0000Oooooo
0_l00005ooooo`;o00003Oooool9o`0000?ooooo0_l00002ooooo`;o00001?ooool4o`000003oooo
ool0003o000000_ooooo0ol0000;ooooo`;o00001?ooool3o`0000kooooo0_l0001Uooooo`007?oo
ool00ol0003oooooooooo`1Cooooo`;o00009oooool2o`0000Cooooo0_l00002ooooo`;o00000_oo
ool2o`0000Wooooo1_l000000ooooooo0000o`000002o`000003ooooool0003o000000;ooooo0_l0
0006ooooo`?o00001_ooool:o`00017ooooo0ol0000=ooooo`Co0000I?ooool001cooooo00?o0000
ooooooooool0Loooool2o`0000Oooooo0_l00004ooooo`;o00001_ooool2o`0000[ooooo1?l00003
ooooo`Go00002oooool3o`0000Kooooo2Ol0000:ooooo`;o00001oooool2o`0000gooooo1?l00000
0ooooooo0000o`000005ooooo`;o0000F_ooool001cooooo00?o0000ooooooooool0Koooool2o`00
0004ooooool0003o0000o`0001Cooooo0_l0000=ooooo`?o00000oooool4o`0000_ooooo1Ol00004
ooooo`Wo00002_ooool2o`0000Gooooo1?l0000Booooo`;o00001Oooool2o`0005[ooooo000Loooo
o`03o`000?oooooooooo04[ooooo0_l00004ooooo`?o00007?ooool2o`000003ooooool0003o0000
01Gooooo0_l00003ooooo`;o00002Oooool4o`0000Gooooo0_l0000;ooooo`Co000000Coooooo`00
0?l0003o00000_ooool2o`0001Gooooo0_l0000Kooooo`;o0000F_ooool001cooooo00?o0000oooo
ooooool0B_ooool2o`0000Cooooo0ol0000Hooooo`;o00008Oooool2o`0000[ooooo2_l0000=oooo
o`;o000000Goooooo`000?l0003o0000ooooo`02o`000003ooooool0003o000002Oooooo0_l00000
0ooooooo0000o`000004ooooo`;o0000F_ooool001cooooo0_l0001:ooooo`;o00001_ooool3o`00
01Oooooo0_l00002ooooo`;o00007Oooool4o`0000Oooooo0_l00002ooooo`Ko00003_ooool2o`00
0003ooooool0003o000000;ooooo1Ol0000Dooooo`;o00004Oooool2o`000003ooooool0003o0000
00Cooooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00001_ooool3o`0000_o
oooo0_l0000>ooooo`;o00007oooool2o`0000Oooooo0_l0000=ooooo`;o00001oooool5o`0000?o
oooo0_l0000:ooooo`;o00002Oooool3o`00017ooooo0_l000000ooooooo0000o`00001Pooooo`00
7?ooool00ol0003oooooooooo`1Oooooo`;o00005?ooool2o`00037ooooo0_l00007ooooo`?o0000
0oooool2o`0000_ooooo0ol00009ooooo`;o00004oooool5o`0000?ooooo0ol0001Iooooo`007?oo
ool00ol0003oooooooooo`1Nooooo`;o00000oooool2o`0000Kooooo0_l00002ooooo`;o00001?oo
ool2o`0003_ooooo0_l00002ooooo`?o00002oooool2o`0000Sooooo0_l00006ooooo`;o00003Ooo
ool5o`0000?ooooo0ol0001Iooooo`007?ooool00ol0003oooooooooo`1?ooooo`;o00003Oooool2
o`0000?ooooo0_l00006ooooo`Ko00008oooool2o`0000kooooo1_l00008ooooo`;o00000_ooool2
o`0000gooooo0_l00007ooooo`;o00001Oooool4o`0000?ooooo0_l00004ooooo`;o00000_ooool2
o`0000Kooooo0_l0001Iooooo`007?ooool00ol0003oooooooooo`1=ooooo`Co00002Oooool2o`00
017ooooo0_l0000Uooooo`;o00003_ooool6o`000003ooooool0003o000000_ooooo0_l00008oooo
o`Go00001?ooool2o`0000?ooooo0_l00003ooooo`Co00000oooool2o`0000Cooooo0_l000000ooo
oooo0000o`000003o`0000Cooooo0_l0001Iooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o
00002oooool2o`0000Oooooo0_l00009ooooo`?o00009?ooool2o`0000Oooooo0_l00004ooooo`Co
00000oooool4o`0000Oooooo1?l00008ooooo`Co00001?ooool3o`0000?ooooo0_l00006ooooo`;o
00001Oooool2o`0000Cooooo1Ol00004ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0
C?ooool2o`0001Gooooo0_l00009ooooo`?o00002Oooool3o`0000;ooooo1?l0000Booooo`;o0000
1oooool3o`0000Gooooo0_l00005ooooo`;o00001oooool2o`0000_ooooo0_l00002ooooo`Ko0000
2?ooool=o`000004ooooool0003o0000ooooo`Co0000Goooool001cooooo00?o0000ooooooooool0
A_ooool2o`0000Cooooo0_l0000Aooooo`;o00000oooool2o`0000?ooooo0_l00007ooooo`;o0000
0_ooool7o`0000;ooooo1?l000001?oooooo0000o`000?l0000@ooooo`;o00001_ooool2o`0000So
oooo0_l00007ooooo`;o00000_ooool2o`0000_ooooo0_l00002ooooo`Co00001?ooool2o`0000Co
oooo5Ol0001Oooooo`007?ooool00ol0003oooooooooo`10ooooo`;o000000Coooooo`000?l0003o
oooo0_l00002ooooo`;o00004?ooool2o`000003ooooool0003o000000?ooooo0_l00002ooooo`Go
00001Oooool2o`0000;ooooo1?l00005ooooo`;o00000oooool7o`0000cooooo0_l0000@ooooo`?o
00000_ooool3o`000003ooooool0003o000001Cooooo0_l00003ooooo`Co000000?oooooo`000?l0
00005?l0001Qooooo`007?ooool00ol0003oooooooooo`0oooooo`?o000000Coooooo`000?l0003o
00000oooool3o`0000cooooo1_l0000:ooooo`;o000000?oooooo`000?l000001Oooool2o`0000;o
oooo0_l00005ooooo`Co000000?oooooo`000?l000002?l0000Nooooo`?o000000Goooooo`000?l0
003o0000ooooo`02o`0001Wooooo0ol000000ooooooo0000o`00000Eo`00067ooooo000Looooo`03
o`000?oooooooooo03oooooo0_l00003ooooo`;o00000oooool3o`0000cooooo1?l0000;ooooo`Go
00003_ooool2o`000004ooooool0003o0000o`0000;ooooo3_l0000Dooooo`;o00001Oooool2o`00
00;ooooo1?l0000Booooo`;o00001oooool2o`000003ooooool0003o000001Go0000HOooool001co
oooo00?o0000ooooooooool0Aoooool2o`00013ooooo0_l00004ooooo`;o00001_ooool5o`0000?o
oooo0_l00003ooooo`;o00000_ooool:o`000003ooooool0003o000000Go00000_ooool6o`0000So
oooo0_l00007ooooo`Co00001?ooool2o`0000Cooooo0_l00002ooooo`;o00002_ooool2o`0000;o
oooo0_l00007ooooo`[o000000?oooooo`000?l000003?l0001Rooooo`007?ooool00ol0003ooooo
ooooo`12ooooo`;o00000oooool2o`0000cooooo0_l00002ooooo`;o00001?ooool2o`0000?ooooo
0_l00007ooooo`Co00000oooool2o`0000;ooooo5?l00002ooooo`Go00001oooool2o`0000Oooooo
1?l000000ooooooo0000o`000006ooooo`;o00000oooool2o`0000[ooooo0_l00004ooooo`;o0000
1?oooolGo`000004ooooool0003o0000o`00067ooooo000Looooo`03o`000?oooooooooo04;ooooo
0_l0000?ooooo`Co00003Oooool4o`0000Cooooo0ol00009ooooo`Co00000_ooool:o`0000;ooooo
0_l00002ooooo`Ko00005?ooool2o`0000Kooooo0_l00003ooooo`;o00002?ooool3o`0000Gooooo
0_l00002oooooago0000HOooool001cooooo00?o0000ooooooooool0>_ooool2o`0000Sooooo0_l0
000=ooooo`;o00001Oooool2o`000003ooooool0003o000000Oooooo0_l00003ooooo`?o00001Ooo
ool3o`0000;ooooo4?l000000ooooooo0000o`000003o`0000;ooooo1?l00007ooooo`;o00002ooo
ool2o`0000Cooooo1?l00003ooooo`;o00002?ooool3o`0000Wooooo0_l000000ooooooo0000o`00
0003o`000003ooooool0003o000001?o0000H?ooool001cooooo0_l0000kooooo`;o00002?ooool2
o`0001Cooooo0_l000000ooooooo0000o`00000<ooooo`;o00000_ooool2o`0000;ooooo1Ol00002
oooooaGo000000?oooooo`000?l000000_l00007ooooo`;o00003?ooool2o`0000?ooooo1?l0000A
ooooo`Co00001ooooolHo`000003ooooool0003o000000?ooooo1Ol0001Hooooo`007?ooool00ol0
003oooooooooo`0kooooo`Co00007?ooool2o`0001;ooooo0_l00002ooooo`Go00000_ooool6o`00
0003ooooool0003o000000co000000?oooooo`000?l000000oooool2o`0001;ooooo0_l00003oooo
o`;o000000?oooooo`000?l000004?ooool7o`0000;ooooo0_l000000ooooooo0000o`00000Eo`00
00Kooooo1Ol0001Hooooo`007?ooool00ol0003oooooooooo`0kooooo`Co00000_ooool2o`0001So
oooo0_l00005ooooo`;o00003oooool2o`0000Gooooo5Ol000000ooooooo0000o`000003ooooo`?o
00004Oooool7o`000003ooooool0003o0000017ooooo1_l00002ooooo`Co000000?oooooo`000?l0
00005?l00007ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0=oooool2o`0000Oooooo
1?l00004ooooo`;o00002oooool2o`000004ooooool0003o0000ooooo`;o00001Oooool2o`0000Go
oooo0_l00003ooooo`;o00002Oooool:o`0000;ooooo2Ol00003ooooo`;o00000_ooool3o`00017o
oooo1ol0000Noooooa7o000000?oooooo`000?l000000_l000000ooooooo0000o`000007ooooo`;o
0000FOooool001cooooo00?o0000ooooooooool0=_ooool3o`0000Oooooo1?l00004ooooo`;o0000
2oooool2o`000003ooooool0003o000000?ooooo0_l00009ooooo`?o00000oooool4o`0000Kooooo
3Ol000000ooooooo0000o`000008o`000003ooooool0003o000000?ooooo0_l0000Cooooo`Ko0000
00?oooooo`000?l000006_oooolGo`0000Wooooo0_l0001Iooooo`007?ooool00ol0003ooooooooo
o`0fooooo`;o00002?ooool2o`0000Gooooo0_l0000=ooooo`Go00000_ooool2o`0000Wooooo1?l0
0003ooooo`Co00000ooooolGo`000004ooooool0003o0000o`0000Gooooo0ol0000Booooo`Ko0000
00?oooooo`000?l000006ooooolFo`0000cooooo0_l0001Fooooo`007?ooool00ol0003ooooooooo
o`10ooooo`;o00001Oooool4o`0000[ooooo2?l00008ooooo`Oo000000?oooooo`000?l000000_oo
ool3o`0000;ooooo5_l00002ooooo`Go00001?ooool2o`0001;ooooo1?l00002ooooo`;o00002_oo
ool2o`0000Oooooo0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o000000co00004Ooo
ool2o`0005Kooooo000Looooo`03o`000?oooooooooo04Wooooo0_l0000:ooooo`?o00000_ooool4
o`0000Oooooo0ol00004ooooo`?o000000?oooooo`000?l000000_l000000ooooooo0000o`00000L
o`0000Cooooo0ol0000@ooooo`Go00000_ooool5o`0000Oooooo0_l00006ooooo`?o00000oooool2
o`0000Cooooo3_l000001?oooooo0000o`000?ooool2o`0000Wooooo0_l0001Iooooo`007?ooool0
0ol0003oooooooooo`1<ooooo`;o00001?ooool2o`0000;ooooo0ol000000ooooooo0000o`000002
o`0000?ooooo0_l00009ooooo`?o000000?oooooo`000?l000000ooooolDo`000003ooooool0003o
000000So00000_ooool4o`00013ooooo1Ol00003ooooo`Co00001_ooool2o`0000?ooooo0_l00002
ooooo`?o00001Oooool2o`0000;ooooo3?l00003ooooo`;o000000?oooooo`000?l000002Oooool4
o`0005Oooooo000Looooo`03o`000?oooooooooo03Oooooo0_l0000Cooooo`;o00001?ooool2o`00
00?ooooo0_l00008ooooo`;o00001?ooool2o`0000?ooooo0ol00002ooooo`_o000000?oooooo`00
0?l000005Ol00002ooooo`Co00003_ooool7o`0000gooooo0ol00002ooooo`;o00000oooool2o`00
00Cooooo0ol00005ooooo`Co00002Oooool2o`0000gooooo0_l000000ooooooo0000o`00001Doooo
o`007?ooool00ol0003oooooooooo`0gooooo`;o00004oooool3o`0000Gooooo0_l0000Aooooo`?o
00000_ooool3o`0000;ooooo8Ol000001?oooooo0000o`000?ooool4o`0000gooooo2ol0000;oooo
o`;o00001Oooool4o`0000Cooooo0_l00002ooooo`;o00000_ooool4o`000004ooooool0003o0000
o`0000Cooooo0ol0000@ooooo`;o0000E?ooool001cooooo00?o0000ooooooooool0COooool2o`00
00Gooooo0_l000000ooooooo0000o`000003o`0000Oooooo0_l00003ooooo`;o00000_ooool2o`00
00Cooooo8ol00002ooooo`Co00003?ooool;o`0001;ooooo0_l000000ooooooo0000o`000003oooo
o`;o00000_ooool8o`000004ooooool0003o0000o`0000Cooooo0_l0001Wooooo`007?ooool00ol0
003oooooooooo`17ooooo`;o00003_ooool7o`000003ooooool0003o000000;ooooo0_l00003oooo
o`;o00000_ooool2o`000003ooooool0003o000001Wo000000?oooooo`000?l000002?l00003oooo
o`?o00003Oooool3o`0000;ooooo0_l0000Hooooo`;o00000oooool2o`0000Cooooo1?l0000Noooo
o`;o0000Doooool001cooooo00?o0000ooooooooool0Aoooool2o`0000_ooooo0_l00006ooooo`;o
000000?oooooo`000?l000000_ooool7o`0000;ooooo7_l000000ooooooo0000o`000008o`0000?o
oooo0ol0000;ooooo`Co00007_ooool2o`0000[ooooo0_l0000Nooooo`;o0000Doooool00006oooo
ooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04oooo
o`03o`000?oooooooooo04oooooo0_l00003ooooo`;o00003Oooool5o`0000Cooooo1?l00003oooo
ob;o00000_ooool4o`0000?ooooo0_l00006ooooo`Co00002?ooool3o`0001?ooooo0_l0000Roooo
o`;o00001_ooool2o`0005?ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;oooool2o`0001kooooo0_l0000E
ooooo`;o00001?ooool2o`0000?ooooo9?l00002ooooo`Co00000oooool2o`0000Sooooo0_l00003
ooooo`;o000000?oooooo`000?l000000ol0000Cooooo`;o00002_ooool2o`0001Kooooo0_l0000:
ooooo`;o0000Coooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool5o`00
00Kooooo00?o0000ooooooooool0;_ooool3o`0003Gooooo0_l00004ooooo`Co000000?oooooo`00
0?l000008_l00002ooooo`Co00000oooool2o`0000Sooooo0ol00002ooooo`;o000000Coooooo`00
0?l0003o00002oooool2o`0000Sooooo0_l000000ooooooo0000o`000003ooooo`;o00000_ooool2
o`0000Oooooo0_l0000Iooooo`;o0000Coooool00003ooooool0003ooooo00;ooooo00?o0000oooo
ooooool02Oooool01?m4A4CogMgMooooool00007ooooo`?o0000;_ooool2o`0000Cooooo0_l0000H
ooooo`;o00000_ooool2o`0001;ooooo0_l00004ooooob3o000000?oooooo`000?l000001ol00003
ooooo`?o000000Coooooo`000?l0003o00002?ooool;o`0000Sooooo0_l000000ooooooo0000o`00
000:ooooo`?o00000oooool2o`0000_ooooo0_l0001Zooooo`0000?oooooo`000?ooool00_ooool0
0ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0=?oo
ool4o`0001Kooooo0_l00002ooooo`;o00004Oooool2o`0000Gooooo8?l000000ooooooo0000o`00
000=o`000003ooooool0003o000000Sooooo1_l00002ooooo`Co00002?ooool2o`0000Sooooo0_l0
0003ooooo`?o00001_ooool2o`0007Cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooo
oooo00[ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0dooooo`Co00006_ooool2
o`00017ooooo0_l00005ooooo`;o000000?oooooo`000?l000009?l000000ooooooo0000o`000004
o`000003ooooool0003o000000Sooooo1?l00004ooooo`;o00003_ooool2o`0000Cooooo0_l00004
ooooo`;o00001_ooool2o`0001oooooo0_l0001Cooooo`0000KoooooogMgMonHV9SooooooiRHV?mg
MgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0<oooool2o`000003ooooool0
003o000001Kooooo0_l0000OooooobCo00001?ooool2o`0000?ooooo0_l00008ooooo`;o00005ooo
ool2o`0000Kooooo0_l00004ooooo`;o00000_ooool2o`0000;ooooo0_l00004ooooo`;o00005ooo
ool2o`0005?ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool0
1_ooool00ol0003oooooooooo`0cooooo`;o00005oooool4o`0001Gooooo0_l00006ooooo`?o0000
0ooooolPo`0000Cooooo0ol00002ooooo`;o00002?ooool4o`000003ooooool0003o000001;ooooo
0ol00005ooooo`;o00001?ooool2o`0000;ooooo0_l00002ooooo`;o00001?ooool2o`0001[ooooo
0_l0001@ooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00005oooool2o`0000Kooooo0ol0
0003oooooago000000?oooooo`000?l000001?ooool4o`0000_ooooo1?l000000ooooooo0000o`00
000>ooooo`;o00000_ooool3o`00017ooooo0_l0000Rooooo`;o0000D?ooool001cooooo00?o0000
ooooooooool0?oooool2o`0002;ooooo0_l00003ooooo`;o00001?ooool2o`0000Cooooo7_l00005
ooooo`Ko00007_ooool2o`0001Kooooo0_l0001dooooo`007?ooool00ol0003oooooooooo`0ooooo
o`Co00002?ooool2o`0001Kooooo0_l00003ooooo`;o00001?ooool4o`0000;ooooo7ol00003oooo
o`?o00000_ooool2o`0000Sooooo0ol00003ooooo`;o000000?oooooo`000?l00000;?ooool2o`00
01gooooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`10ooooo`?o00002?ooool2o`0001_o
oooo0_l00005ooooo`?o00000_oooolOo`0000?ooooo0ol00002ooooo`?o00001oooool3o`0000?o
oooo0_l000000ooooooo0000o`00000Booooo`;o00004_ooool3o`0000?ooooo0_l0000Mooooo`;o
0000C?ooool001cooooo00?o0000ooooooooool0@Oooool2o`0001Sooooo0_l0000:ooooo`;o0000
1_ooool2o`0000;ooooo4ol000000ooooooo0000o`000009o`0000?ooooo1?l000000ooooooo0000
o`000002o`0002Cooooo0_l0000?ooooo`;o000000Coooooo`000?l0003o0000L?ooool001cooooo
00?o0000ooooooooool0=Oooool2o`0000Sooooo0_l0000Iooooo`Co00002Oooool2o`0000Gooooo
0ol00002ooooo`;o000000?oooooo`000?l000004_l000000ooooooo0000o`000005o`0000;ooooo
1?l000001?oooooo0000o`000?l0000<ooooo`;o0000:Oooool2o`0000Cooooo0_l0001^ooooo`00
7?ooool00ol0003oooooooooo`0cooooo`Co00002?ooool2o`0001Wooooo1Ol00006ooooo`Co0000
1Oooool3o`0000;ooooo0_l000000ooooooo0000o`00000Go`0000Gooooo0_l00003ooooo`;o0000
2_ooool5o`0001Kooooo0_l0000Gooooo`;o00001Oooool2o`0000?ooooo0_l0000Gooooo`;o0000
BOooool001cooooo00?o0000ooooooooool0;oooool2o`000004ooooool0003o0000o`0002Cooooo
0ol000001?oooooo0000o`000?l00005ooooo`Co000000?oooooo`000?l000001_ooool4o`000005
ooooool0003o0000o`000?ooool05?l000000ooooooo0000o`000002ooooo`;o00003oooool5o`00
00Gooooo0_l0000?ooooo`;o00000oooool2o`0000Gooooo0_l0000Booooo`;o00000oooool2o`00
01Oooooo0_l00019ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o000000?oooooo`000?l0
00005_ooool2o`0000gooooo0_l000000ooooooo0000o`000003o`0000Gooooo0_l00002ooooo`;o
00001Oooool5o`0000;ooooo5Ol00003ooooo`;o000000Coooooo`000?l0003o00004Oooool2o`00
00Kooooo0_l0000Dooooo`;o00001Oooool2o`0000oooooo0_l000000ooooooo0000o`00001Woooo
o`007?ooool00ol0003oooooooooo`0Zooooo`;o00001_ooool2o`0000?ooooo0_l00003ooooo`;o
00003?ooool2o`00013ooooo1Ol0000@ooooo`;o000000?oooooo`000?l000000_oooolEo`000004
ooooool0003o0000o`0000;ooooo0ol0000Aooooo`;o00000_ooool3o`0002oooooo0_l000000ooo
oooo0000o`00001Wooooo`007?ooool00ol0003oooooooooo`0Zooooo`;o00001_ooool2o`0000?o
oooo0_l00003ooooo`;o00002oooool3o`0000kooooo0_l00003ooooo`;o00002?ooool2o`0000;o
oooo0_l00005ooooo`;o000000Goooooo`000?l0003o0000ooooo`0@o`0000;ooooo2?l0000>oooo
o`Oo000000?oooooo`000?l000001Ol0000Sooooo`;o00002Oooool2o`0006Oooooo000Looooo`;o
0000<_ooool3o`000003ooooool0003o000000Sooooo0_l00008ooooo`?o00003Oooool3o`0000?o
oooo0ol00007ooooo`;o000000Coooooo`000?l0003o00002?ooool2o`0000Kooooo0_l000000ooo
oooo0000o`000007o`0000;ooooo0_l000000ooooooo0000o`000002o`0000oooooo1ol000001?oo
oooo0000o`000?ooool4o`0001Cooooo0_l0000=ooooo`;o00000oooool2o`0000oooooo0_l0001L
ooooo`007?ooool00ol0003oooooooooo`0aooooo`;o000000Coooooo`000?l0003o00002?ooool2
o`0001Sooooo0_l00005ooooo`;o00002_ooool2o`0000gooooo3?l000000ooooooo0000o`000005
ooooo`?o00001Oooool2o`0000Sooooo0_l00003ooooo`;o00000_ooool2o`0000gooooo0ol00002
ooooo`;o00001_ooool2o`0000Gooooo0_l0000;ooooo`;o00003oooool2o`0005cooooo000Loooo
o`03o`000?oooooooooo02gooooo0_l00005ooooo`;o000000?oooooo`000?l000003_ooool2o`00
01Oooooo1?l0000Cooooo`oo00001oooool5o`0000Gooooo0_l00008ooooo`;o00000_ooool3o`00
00;ooooo0_l0000=ooooo`?o00000_ooool2o`0000Oooooo0ol00003ooooo`;o00001oooool2o`00
00;ooooo0_l0000?ooooo`;o0000G?ooool001cooooo00?o0000ooooooooool09oooool2o`0000Co
oooo0_l00008ooooo`;o00003_ooool2o`00017ooooo0_l00005ooooo`?o00004_ooool=o`0000Ko
oooo0_l00002ooooo`Go00003oooool6o`000003ooooool0003o000000;o00004_ooool2o`0000Oo
oooo0ol0000:ooooo`Co00002oooool2o`000003ooooool0003o0000067ooooo000Looooo`03o`00
0?oooooooooo02Oooooo0_l00008ooooo`;o000000?oooooo`000?l000009?ooool2o`0000Kooooo
1?l0000@ooooo`Oo00002oooool3o`0000?ooooo0ol000000ooooooo0000o`00000=ooooo`Co0000
0oooool2o`0000?ooooo1?l00009ooooo`;o00002Oooool2o`0000gooooo0ol0000<ooooo`Go0000
HOooool001cooooo00?o0000ooooooooool0<Oooool2o`000003ooooool0003o000000;o00004?oo
ool2o`0001Wooooo0ol0000Aooooo`?o00001?ooool4o`0000Kooooo1_l00004ooooo`;o00002Ooo
ool2o`000003ooooool0003o000000;o00000_ooool2o`0000Gooooo1?l00009ooooo`;o00002?oo
ool3o`0001Cooooo0_l00008ooooo`;o000000?oooooo`000?l00000Goooool001cooooo00?o0000
ooooooooool0=?ooool6o`0000kooooo0_l0000^ooooo`;o000000Coooooo`000?l0003ooooo1ol0
00001?oooooo0000o`000?ooool5o`000003ooooool0003o000000cooooo1_l00003ooooo`;o0000
1Oooool2o`0001Gooooo0ol0000@ooooo`?o000000Goooooo`000?l0003o0000ooooo`02o`0000;o
oooo0_l00002ooooo`?o0000Goooool001cooooo00?o0000ooooooooool0=Oooool2o`000003oooo
ool0003o000000Kooooo0_l00007ooooo`;o0000;_ooool4o`0000Gooooo1_l000000ooooooo0000
o`000004ooooo`;o00003_ooool2o`0000Cooooo0_l00006ooooo`;o00009oooool<o`000003oooo
ool0003o000000Co0000H?ooool001cooooo00?o0000ooooooooool0<?ooool2o`0000cooooo1?l0
0006ooooo`?o0000:?ooool2o`000003ooooool0003o000000?o00002?ooool4o`0000Gooooo0ol0
000=ooooo`;o00001oooool3o`0001Cooooo0_l00005ooooo`;o00004OoooolAo`0006;ooooo000L
ooooo`03o`000?oooooooooo033ooooo0_l000000ooooooo0000o`000009ooooo`;o00002?ooool2
o`0002Wooooo0_l000000ooooooo0000o`000002o`0000Wooooo1?l00002ooooo`;o000000Cooooo
o`000?l0003o00003?ooool3o`0000?ooooo0_l00003ooooo`;o00001?ooool2o`000003ooooool0
003o000000?ooooo0_l00006ooooo`?o00001?ooool2o`000003ooooool0003o000000oooooo4Ol0
001Qooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o000000?oooooo`000?l000004oooool2
o`0001cooooo0_l0000>ooooo`Co00002Oooool4o`0000;ooooo0_l0000@ooooo`;o000000?ooooo
o`000?l000000ol00005ooooo`;o00000_ooool5o`0000?ooooo0_l00007ooooo`;o00001oooool2
o`0000[ooooo0_l00003oooooaGo0000GOooool001cooooo00?o0000ooooooooool0?Oooool4o`00
02Gooooo0_l00004ooooo`;o00002Oooool3o`0000_ooooo0_l00002ooooo`;o00004?ooool6o`00
00Oooooo0_l00003ooooo`;o00002Oooool2o`0000Sooooo0_l00003ooooo`;o00002Oooool2o`00
0003ooooool0003o000001Ko0000G?ooool001cooooo00?o0000ooooooooool0?Oooool4o`0002_o
oooo0ol00008ooooo`;o00002Oooool2o`000003ooooool0003o000000;ooooo0_l0000Aooooo`;o
00002_ooool3o`0000gooooo0ol00007ooooo`;o00000oooool2o`000003ooooool0003o000000Wo
oooo1ol000000ooooooo0000o`00000>o`0005cooooo000Looooo`03o`000?oooooooooo033ooooo
0_l0000Aooooo`;o00007?ooool3o`0000Wooooo0ol00007ooooo`;o00000_ooool2o`0000Gooooo
0_l0000Tooooo`?o000000?oooooo`000?l000002oooool2o`0000oooooo0_l00003ooooo`;o0000
0ooooolGo`0000[ooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`0/ooooo`?o000000?o
ooooo`000?l000003Oooool6o`0001cooooo1?l00007ooooo`Co00001oooool2o`0000;ooooo0_l0
000[ooooo`;o00000_ooool4o`0000?ooooo0_l0000<ooooo`;o00001oooool2o`0000?ooooo0_l0
00000ooooooo0000o`00000Ho`0000Wooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`0/
ooooo`?o00001_ooool2o`0000Sooooo1?l00005ooooo`;o00005Oooool2o`000004ooooool0003o
0000o`0000Oooooo0ol00007ooooo`Co000000?oooooo`000?l000000_ooool2o`0002Gooooo1Ol0
0003ooooo`;o00000oooool2o`000003ooooool0003o000000Sooooo0ol00008ooooo`;o00001Ooo
oolJo`0000[ooooo0_l0001Aooooo`007?ooool2o`0003;ooooo0_l000001?oooooo0000o`000?l0
000Aooooo`;o00005Oooool2o`0000cooooo0_l00004ooooo`;o000000?oooooo`000?l000001Ol0
0002ooooo`;o00009Oooool2o`000003ooooool0003o000000?o00002?ooool2o`0000Sooooo0_l0
0008ooooo`Go000000?oooooo`000?l000000_ooool@o`0000;ooooo1ol00009ooooo`;o0000DOoo
ool001cooooo00?o0000ooooooooool0<Oooool2o`000003ooooool0003o000000kooooo0_l00000
0ooooooo0000o`00000Zooooo`;o00000_ooool2o`000003ooooool0003o000000Gooooo0_l0000X
ooooo`Co00006oooool2o`000004ooooool0003o0000oooooaCo00000_ooool8o`0000Gooooo0_l0
001Dooooo`007?ooool00ol0003oooooooooo`14ooooo`;o000000Coooooo`000?l0003o0000:_oo
ool2o`0000Gooooo1Ol000000ooooooo0000o`00000Pooooo`;o00001_ooool4o`0001_ooooo0_l0
0004oooooaoo00001?ooool2o`0005Cooooo000Looooo`03o`000?oooooooooo02gooooo0_l00003
ooooo`;o00002_ooool2o`0000Sooooo0_l0000Nooooo`;o00002_ooool2o`0000Gooooo1Ol0000S
ooooo`;o00001_ooool5o`0001[ooooo0_l00003oooooago000000?oooooo`000?l00000F_ooool0
01cooooo00?o0000ooooooooool0;Oooool7o`0000[ooooo0_l0000Xooooo`;o00004oooool2o`00
00Sooooo0_l0000Hooooo`;o00001?ooool2o`0000?ooooo1ol0000Eooooo`;o00001Oooool2o`00
0003ooooool0003o000001So000000?oooooo`000?l00000F_ooool001cooooo00?o0000oooooooo
ool0;oooool5o`0000Kooooo0_l00008ooooo`;o00009Oooool2o`0000Oooooo0_l0000;ooooo`;o
00000oooool3o`0001Sooooo0_l00004ooooo`Go00001?ooool5o`0000Kooooo0_l0000;ooooo`Co
00001?ooool4o`000003ooooool0003o000001So00001?ooool2o`0005Cooooo000Looooo`03o`00
0?oooooooooo02gooooo1?l00009ooooo`;o00001_ooool4o`0002Gooooo0_l00003ooooo`;o0000
0_ooool2o`0000_ooooo0_l00003ooooo`;o00007Oooool2o`000003ooooool0003o000000;o0000
1?ooool7o`0000;ooooo1?l0000=ooooo`;o00001?ooool4o`000003ooooool0003o000001So0000
1?ooool2o`0005Cooooo000Looooo`03o`000?oooooooooo02gooooo1?l00004ooooo`;o00000ooo
ool2o`0000Kooooo1?l00004ooooo`;o00008_ooool6o`0000oooooo0_l000000ooooooo0000o`00
0003ooooo`;o00006?ooool2o`000004ooooool0003o0000o`0000Gooooo3Ol0000Dooooo`Co0000
00?oooooo`000?l000004ol00002ooooo`;o00001?ooool4o`0005;ooooo000Looooo`03o`000?oo
oooooooo02gooooo0_l00006ooooo`;o00000_ooool2o`0000Cooooo0_l00009ooooo`;o00007Ooo
ool4o`000003ooooool0003o000000;ooooo1?l0000=ooooo`;o00001_ooool7o`0001Gooooo0_l0
0009ooooo`;o000000?oooooo`000?l000001Ol0000Eoooooa_o00001oooool4o`0005;ooooo000L
ooooo`03o`000?oooooooooo02gooooo0_l00006ooooo`;o00000_ooool2o`0000Cooooo0_l00000
0ooooooo0000o`000002o`0000;ooooo1?l0000Mooooo`Oo00000_ooool4o`0000Oooooo0ol0000=
ooooo`Oo00004oooool3o`0000cooooo1_l0000Dooooo`;o000000?oooooo`000?l000003ol00000
0ooooooo0000o`000005o`0000Sooooo0_l0000Fooooo`;o0000>oooool001cooooo00?o0000oooo
ooooool0<?ooool2o`0000?ooooo1?l00009ooooo`Co00000_ooool2o`00027ooooo1Ol00002oooo
o`;o00001oooool6o`0000[ooooo0_l00005ooooo`;o00003oooool4o`000003ooooool0003o0000
00;o00002Oooool8o`0001?ooooo6_l0000:ooooo`;o00005_ooool2o`0003_ooooo000Looooo`03
o`000?oooooooooo033ooooo1?l00003ooooo`Co00001oooool4o`0001kooooo0_l0000<ooooo`;o
00001oooool6o`0000[ooooo0_l00003ooooo`Co00001_ooool2o`000003ooooool0003o000000Co
oooo1?l00003ooooo`Ko00001Oooool4o`0000;ooooo0_l0000Coooooa[o00008Oooool3o`0003_o
oooo000Looooo`03o`000?oooooooooo037ooooo0ol00005ooooo`;o00000_ooool3o`0000;ooooo
1?l0000Nooooo`;o00003?ooool2o`0000Wooooo1_l0000=ooooo`Co00000_ooool2o`0000;ooooo
2Ol00007ooooo`Ko00001?ooool4o`0000?ooooo0_l0000Cooooo`;o00000ooooolDo`0002;ooooo
0_l0000looooo`007?ooool00ol0003oooooooooo`0aooooo`;o00001?ooool2o`0000Cooooo0ol0
0004ooooo`;o00007Oooool3o`0000cooooo0_l00007ooooo`So00001_ooool2o`0000Gooooo0_l0
0004ooooo`;o00000oooool2o`0000;ooooo1?l00004ooooo`;o00001Oooool2o`0000?ooooo1?l0
000Aooooo`;o00002_ooool8o`000003ooooool0003o000000[o00008_ooool2o`0003cooooo000L
ooooo`03o`000?oooooooooo02oooooo0_l00006ooooo`;o00002_ooool3o`0001gooooo0ol00009
ooooo`;o000000?oooooo`000?l000001_ooool7o`0000Sooooo0_l00005ooooo`;o00003oooool4
o`0000;ooooo0_l00009ooooo`?o00001?ooool2o`0000gooooo0ol00004ooooo`;o00000ooooolE
o`0003_ooooo0_l0000Sooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00001?ooool2o`00
00Gooooo0_l00004ooooo`?o00002_ooool2o`0001kooooo0_l00003ooooo`;o00001?ooool2o`00
00?ooooo0_l0000Booooo`;o00003_ooool2o`0000;ooooo0_l00009ooooo`?o00001?ooool2o`00
00kooooo0_l00004ooooo`;o00001?oooolEo`0000Gooooo0_l0000cooooo`;o00008oooool001co
oooo0_l0000`ooooo`;o00001?ooool4o`0000?ooooo0_l00004ooooo`Go00002?ooool2o`0001So
oooo1?l00007ooooo`;o00002?ooool3o`0001;ooooo0_l00008ooooo`;o00001Oooool5o`0000Co
oooo0_l00004ooooo`;o00008?ooool:o`000003ooooool0003o000000So000000?oooooo`000?l0
00000_ooool2o`0000Gooooo0_l0000[ooooo`;o00009?ooool001cooooo00?o0000ooooooooool0
=oooool2o`0000Cooooo0_l00005ooooo`?o00002?ooool2o`0001?ooooo0_l000000ooooooo0000
o`000005o`00013ooooo0ol0000Looooo`;o00001Oooool4o`0000Gooooo0_l000000ooooooo0000
o`000003o`0001Kooooo0_l0000;ooooo`Oo000000?oooooo`000?l000001Ol00004ooooo`;o0000
2Oooool2o`0000Gooooo0_l0000;ooooo`;o00005oooool2o`0002Cooooo000Looooo`03o`000?oo
oooooooo02kooooo0_l00007ooooo`;o00001?ooool2o`0000Kooooo0_l00009ooooo`;o00004_oo
ool2o`000003ooooool0003o000000Go00001_ooool2o`0000Sooooo0ol0000<ooooo`;o00003Ooo
ool3o`0000?ooooo0_l0000<ooooo`Go00005_ooool2o`000003ooooool0003o000000Oooooo2?l0
00001?oooooo0000o`000?ooool3o`000003ooooool0003o000001Cooooo1?l00009ooooo`;o0000
?Oooool001cooooo00?o0000ooooooooool0;_ooool2o`0000gooooo0_l00006ooooo`?o00002?oo
ool2o`0001Gooooo2?l00004ooooo`?o00002?ooool3o`0000cooooo0_l00004ooooo`Co00001Ooo
ool2o`0000Cooooo0_l0000;ooooo`;o00000_ooool2o`0000?ooooo0_l0000?ooooo`;o00000ooo
ool2o`0000Kooooo0ol000001?oooooo0000o`000?ooool2o`0000Sooooo0_l0000Dooooo`Co0000
0_ooool2o`0000Gooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`13ooooo`;o000000?o
ooooo`000?l000001?ooool2o`0001Wooooo0_l00002ooooo`Co00001?ooool2o`0000Wooooo0_l0
000Booooo`Go00000oooool2o`0000;ooooo0_l0000?ooooo`;o00000_ooool2o`0000?ooooo0_l0
000?ooooo`;o00002_ooool5o`0000_ooooo1?l0000Eooooo`;o00000oooool2o`0000?ooooo0_l0
000oooooo`007?ooool00ol0003oooooooooo`13ooooo`;o000000?oooooo`000?l000001?ooool2
o`0001Sooooo0ol000001?oooooo0000o`000?l0000Qooooo`;o00000_ooool4o`000003ooooool0
003o000000?o00000_ooool2o`0000;ooooo0ol00005ooooo`;o00001oooool2o`0001Cooooo0_l0
00000ooooooo0000o`000007ooooo`Go00000oooool2o`0000Kooooo0_l00003ooooo`;o00004ooo
ool2o`0000Oooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0dooooo`Co00002oooool2
o`000004ooooool0003o0000ooooo`;o00005_ooool2o`0000?ooooo0_l00002ooooo`Co00001?oo
ool2o`0001[ooooo0_l00007ooooo`Co00000oooool2o`0000;ooooo0ol00005ooooo`;o00002?oo
ool2o`0000?ooooo0_l0000>ooooo`;o000000?oooooo`000?l000000oooool2o`0000Cooooo1?l0
00001Ooooooo0000o`000?l0003ooooo00;o00000_ooool2o`0000Cooooo0_l0000;ooooo`;o0000
1_ooool2o`0000Oooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00000_oo
ool4o`0000[ooooo0_l00002ooooo`;o000000?oooooo`000?l000002?ooool2o`0000cooooo0_l0
00000ooooooo0000o`000002o`0000Cooooo0_l000001?oooooo0000o`000?ooool4o`0000Kooooo
0_l0000Mooooo`;o00001_ooool2o`0000gooooo1?l00003ooooo`;o00005_ooool2o`0000Kooooo
0_l000001Ooooooo0000o`000?l0003ooooo00?o000000?oooooo`000?l000004Oooool2o`0000ko
oooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00001?ooool2o`0000Kooooo
0_l00002ooooo`Wo00002?ooool2o`0000oooooo1?l00007ooooo`;o00000_ooool3o`0000Kooooo
0_l0000Kooooo`Ko00004oooool4o`0000;ooooo0ol0000Aooooo`;o00002oooool2o`0000Kooooo
0_l000000ooooooo0000o`00000Qooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0<Ooo
ool2o`0000?ooooo0_l00006ooooo`;o00000oooool3o`000004ooooool0003o0000o`0000Sooooo
0_l00009ooooo`;o00001?ooool2o`000003ooooool0003o000000_ooooo0_l00002ooooo`;o0000
2oooool2o`0000_ooooo0_l00006ooooo`So000000?oooooo`000?l000005?ooool4o`0000Wooooo
0_l00005ooooo`;o00001?ooool2o`0000Cooooo0_l0001_ooooo`007?ooool00ol0003ooooooooo
o`0`ooooo`Co00004oooool3o`0000Sooooo0_l00009ooooo`;o00001?ooool7o`0000;ooooo0_l0
0006ooooo`;o000000?oooooo`000?l000002?ooool2o`000003ooooool0003o000000Kooooo0_l0
0003ooooo`;o00001_ooool;o`0000?ooooo0_l00008ooooo`;o00001_ooool3o`0000Wooooo0_l0
000;ooooo`;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000008ooooo`Co00006Ooo
ool2o`00047ooooo000Looooo`03o`000?oooooooooo033ooooo1?l000000ooooooo0000o`000006
ooooo`;o00000oooool2o`0000?ooooo1?l00003ooooo`;o000000?oooooo`000?l000002_ooool2
o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o00000_ooool2o`0000Kooooo0_l00008
ooooo`;o000000Coooooo`000?l0003ooooo0_l00006ooooo`Co00001oooool<o`000004ooooool0
003o0000ooooo`;o00001Oooool2o`000003ooooool0003o000000?o00000_ooool3o`0000?ooooo
0ol00008ooooo`;o00000_ooool2o`0000Gooooo0_l00006ooooo`;o000000?oooooo`000?l00000
2?ooool4o`0000;ooooo0_l0000Eooooo`;o00006?ooool2o`0002Oooooo000Looooo`03o`000?oo
oooooooo03;ooooo0_l000000ooooooo0000o`000006ooooo`?o00000_ooool2o`0000?ooooo1Ol0
0002ooooo`;o000000Coooooo`000?l0003o00002Oooool2o`000003ooooool0003o000000;o0000
2?ooool2o`0000gooooo1Ol000001?oooooo0000o`000?l00003ooooo`?o00000_ooool4o`0000Ko
oooo4_l00006ooooo`?o000000?oooooo`000?l000000_l00002ooooo`?o00000oooool3o`0000So
oooo0_l00002ooooo`Co00000oooool2o`0001Wooooo0_l0000Booooo`;o00006oooool2o`0002Oo
oooo000Looooo`03o`000?oooooooooo037ooooo0ol0000:ooooo`;o00001oooool5o`0000;ooooo
0_l000001?oooooo0000o`000?l0000:ooooo`;o00000_ooool2o`0000oooooo1Ol00003ooooo`Go
000000Goooooo`000?l0003o0000ooooo`05o`0000;ooooo0_l00004oooooa;o00000_ooool2o`00
00;ooooo0_l00003ooooo`;o00005oooool2o`0000;ooooo1Ol0000booooo`;o0000A?ooool00006
ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<
c006ooooo`03o`000?oooooooooo037ooooo0_l0000@ooooo`;o000000Coooooo`000?l0003o0000
0_ooool2o`00017ooooo0_l0000Cooooo`Go00000oooool6o`0000Cooooo1?l00007oooooa?o0000
1oooool3o`0001_ooooo0_l00002ooooo`Co00005Oooool2o`0006;ooooo00001_ooooooMgMgoiRH
V?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0
003oooooooooo`0gooooo`;o00001?ooool4o`0000;ooooo0_l000000ooooooo0000o`000003oooo
o`;o00006?ooool2o`0001Cooooo0ol000000ooooooo0000o`00000;ooooo`;o00000_ooool2o`00
00;ooooo3ol00008ooooo`;o00001Oooool2o`0000;ooooo0_l000001?oooooo0000o`000?l0000<
ooooo`;o00001Oooool2o`0000oooooo0_l00003ooooo`;o00007_ooool2o`0004;ooooo00000ooo
oooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo03Oooooo1?l00002ooooo`Co00000_ooool2o`0000Gooooo1?l0000C
ooooo`;o00000_ooool2o`0000Gooooo0_l00005ooooo`;o00001oooool4o`0000Sooooo0ol00000
0ooooooo0000o`000002ooooo`;o00000_ooool?o`0000oooooo2_l0000<ooooo`;o00001?ooool3
o`0000_ooooo0_l00002ooooo`;o00008oooool2o`0004;ooooo00000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000=Oooool2
o`0000;ooooo0_l00002ooooo`?o00002_ooool4o`0001?ooooo0_l000001?oooooo0000o`000?l0
0004ooooo`?o00000oooool6o`000003ooooool0003o000000Wo000000Goooooo`000?l0003o0000
ooooo`03o`0000Cooooo0_l00003ooooo`ko00004Oooool3o`000003ooooool0003o000001Gooooo
0_l0000<ooooo`;o00000_ooool2o`0003[ooooo0_l0000[ooooo`0000?oooooo`000?ooool00_oo
ool00ol0003oooooooooo`09ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003ooooo
ooooo`0eooooo`;o0000:_ooool2o`000003ooooool0003o000000Gooooo0_l00003ooooo`Oo0000
00?oooooo`000?l000001?l000000ooooooo0000o`000006o`0000;ooooo0_l00003ooooo`?o0000
00Coooooo`000?l0003ooooo3?l0000=ooooo`;o000000?oooooo`000?l000002oooool2o`0000ko
oooo0_l00006ooooo`;o00000_ooool2o`0000Cooooo0_l0000jooooo`;o0000:oooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`00
0?oooooooooo03Cooooo0_l0000eooooo`;o00000_ooool3o`000003ooooool0003o000000Wo0000
00?oooooo`000?l000002?l00005ooooo`;o000000Goooooo`000?l0003o0000ooooo`0<o`0000go
oooo1_l0000:ooooo`;o00001oooool2o`0000Oooooo1?l00002ooooo`?o000000?oooooo`000?l0
00001?l0001Yooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH
00Sooooo00?o0000ooooooooool0=?ooool2o`0000Wooooo0_l0000Cooooo`;o00001?ooool2o`00
00Gooooo0_l00008ooooo`;o00000_ooool2o`000003ooooool0003o000001Go000000?oooooo`00
0?l000001?l000000ooooooo0000o`000002ooooo`Wo00002_ooool2o`0000;ooooo0_l00002oooo
o`Co00004oooool2o`0000Oooooo1Ol00002ooooo`?o000000?oooooo`000?l000000ol0000Roooo
o`;o0000AOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@
4106ooooo`03o`000?oooooooooo03oooooo0_l0000Cooooo`;o00001?ooool2o`0000Gooooo0_l0
000<ooooo`;o000000?oooooo`000?l000007?l000000ooooooo0000o`000006ooooo`;o00003Ooo
ool2o`0000;ooooo1?l0000Sooooo`;o00000_ooool3o`0002Sooooo0ol00014ooooo`007?ooool0
0ol0003oooooooooo`0eooooo`;o00008oooool2o`0000Cooooo0_l00004ooooo`;o00001oooool4
o`000003ooooool0003o000001Oo000000Coooooo`000?l0003ooooo0_l0000Dooooo`;o00001Ooo
ool2o`0001Sooooo0_l000000ooooooo0000o`000006ooooo`;o00001?ooool2o`0002Sooooo0_l0
0014ooooo`007?ooool00ol0003oooooooooo`0eooooo`Oo00007Oooool2o`0000Gooooo0_l00000
1?oooooo0000o`000?ooool2o`0000?ooooo0_l00004oooooaSo000000?oooooo`000?l000001?l0
000Fooooo`Co00004oooool6o`0000Gooooo1Ol000000ooooooo0000o`000003ooooo`Wo00002?oo
ool2o`0003;ooooo0_l0000_ooooo`007?ooool00ol0003oooooooooo`0gooooo`Go00002Oooool2
o`0001;ooooo0_l00008ooooo`;o00001_ooool4o`000003ooooool0003o000001co00004?ooool2
o`0000Cooooo1_l0000Cooooo`Ko000000?oooooo`000?l000000_l000000ooooooo0000o`000003
ooooo`?o00000_ooool9o`0000Sooooo0_l0000booooo`;o0000;oooool001cooooo00?o0000oooo
ooooool0>?ooool2o`0000Oooooo0_l00002ooooo`;o00001_ooool2o`00017ooooo0_l000000ooo
oooo0000o`000007ooooo`Ko000000?oooooo`000?l000006_l0000?ooooo`;o00001?ooool3o`00
00kooooo0_l00003ooooo`Go000000?oooooo`000?l000000_ooool4o`0000Oooooo0_l00002oooo
o`;o00001?ooool2o`0006kooooo000Looooo`03o`000?oooooooooo03Sooooo0_l00007ooooo`Co
00001?ooool2o`000004ooooool0003o0000o`0000Cooooo0_l0000;ooooo`?o00002Oooool5o`00
00;ooooo5_l00002ooooo`Co00003oooool2o`000003ooooool0003o000000Oooooo0_l00009oooo
o`?o00000_ooool5o`000003ooooool0003o000000;o000000?oooooo`000?l000000oooool3o`00
00?ooooo0_l00007ooooo`;o00009_ooool2o`0001?ooooo0_l0000aooooo`007?ooool00ol0003o
ooooooooo`0hooooo`;o00002Oooool2o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o
000000?oooooo`000?l000002oooool4o`0000Gooooo0_l000001?oooooo0000o`000?ooool2o`00
00;ooooo5_l000000ooooooo0000o`000002o`0000kooooo1ol00007ooooo`;o00001oooool2o`00
0003ooooool0003o000000Kooooo0ol000000ooooooo0000o`000006ooooo`?o00000oooool2o`00
0003ooooool0003o000000Cooooo0_l0000Vooooo`;o00004oooool2o`00037ooooo000Looooo`03
o`000?oooooooooo03Wooooo0_l0000Eooooo`;o000000?oooooo`000?l000000_ooool2o`0000Oo
oooo1?l000001Ooooooo0000o`000?l0003ooooo00;o00000_ooool2o`0000Cooooo5_l000000ooo
oooo0000o`00000;ooooo`Co000000?oooooo`000?l000000ol00003ooooo`?o00002?ooool2o`00
00;ooooo1_l00002ooooo`;o000000Coooooo`000?l0003o00004_ooool2o`0000Cooooo0_l0001^
ooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00000oooool2o`0000Sooooo0_l0000=oooo
o`;o00001oooool2o`0000?ooooo0ol00005ooooo`;o00000ooooolGo`000003ooooool0003o0000
00_ooooo1?l00009ooooo`?o00002?ooool2o`0000Cooooo1?l000000ooooooo0000o`000002o`00
0004ooooool0003o0000ooooo`;o00002Oooool2o`0000[ooooo0_l0000iooooo`;o0000<oooool0
01cooooo00?o0000ooooooooool0?_ooool2o`0000Sooooo0_l000000ooooooo0000o`00000:oooo
o`;o00004?ooool2o`000004ooooool0003o0000o`0000?ooooo7?l00008ooooo`Co00001Oooool2
o`000003ooooool0003o000000_ooooo0_l000000ooooooo0000o`000003ooooo`;o000000?ooooo
o`000?l000002?l00009ooooo`;o00000oooool4o`0003kooooo0_l0000cooooo`007?ooool00ol0
003oooooooooo`0iooooo`;o00004?ooool5o`0000Oooooo0_l00006ooooo`;o00001Oooool2o`00
0004ooooool0003o0000ooooo`?o00000_oooolMo`000003ooooool0003o000000Gooooo0ol00006
ooooo`;o000000?oooooo`000?l000003_ooool2o`0000?ooooo0_l000000ooooooo0000o`000007
o`0000;ooooo0_l00003ooooo`;o00001_ooool6o`0000;ooooo0_l0001]ooooo`007?ooool00ol0
003oooooooooo`0iooooo`;o00004Oooool4o`0000Kooooo0_l00007ooooo`;o00001Oooool4o`00
00?ooooo2_l000001?oooooo0000o`000?ooool=o`000003ooooool0003o000000;o00000_ooool4
o`0001[ooooo0ol00004ooooo`;o000000?oooooo`000?l000003_l00003ooooo`;o00002_ooool2
o`0000;ooooo0_l0001]ooooo`007?ooool2o`0004Gooooo0_l00008ooooo`;o00001_ooool2o`00
00Oooooo0_l00007ooooo`;o00000_ooool:o`000003ooooool0003o000001Co00001?ooool2o`00
01Gooooo0_l00003ooooo`?o00000_oooolDo`0000;ooooo0_l00005ooooo`;o00000_ooool2o`00
07Cooooo000Looooo`03o`000?oooooooooo04;ooooo1?l0000Iooooo`;o00001oooool3o`000004
ooooool0003o0000oooooaSo000000Coooooo`000?l0003o00000oooool2o`000003ooooool0003o
000001Gooooo1?l000000ooooooo0000o`000003oooooaCo000000?oooooo`000?l000000_l00004
ooooo`;o00000_ooool2o`0000Cooooo0_l0001^ooooo`007?ooool00ol0003oooooooooo`12oooo
o`;o00000_ooool2o`0000Sooooo0ol00005ooooo`;o00002?ooool2o`0000Gooooo0_l00002oooo
oaWo000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00000_ooool2o`0000Wooooo0ol00004
ooooo`Co00000_ooool2o`0000Kooooo0_l00003oooooaGo00002?ooool2o`000003ooooool0003o
000000;o0000=Oooool2o`0003Oooooo000Looooo`03o`000?oooooooooo04Kooooo0_l00008oooo
o`?o00001Oooool2o`0000Sooooo0_l00006oooooaco000000Coooooo`000?l0003ooooo0_l00006
ooooo`;o00002Oooool3o`0000Cooooo1?l0000:ooooo`;o00000ooooolEo`0000Sooooo1Ol0000g
ooooo`;o0000=oooool001cooooo00?o0000ooooooooool0DOooool2o`0001Oooooo7Ol0000Goooo
o`;o00001Oooool3o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`;o00000_oooolHo`00
00Kooooo0ol0001aooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00003oooool2o`0000Co
oooo0_l0000Dooooo`Co000000?oooooo`000?l000004ol0000Gooooo`;o00001Oooool3o`000003
ooooool0003o000000Go00000oooool2o`0000;ooooo2_l000000ooooooo0000o`000004o`000003
ooooool0003o000000Co00001?ooool4o`0007;ooooo000Looooo`03o`000?oooooooooo043ooooo
1?l0000@ooooo`;o000000?oooooo`000?l000003?ooool2o`0000Kooooo1?l00002oooooa7o0000
00Coooooo`000?l0003ooooo0_l00005ooooo`;o00002oooool2o`0000?ooooo0ol000000ooooooo
0000o`000002ooooo`;o000000?oooooo`000?l000000_l00004oooooaOo00002?ooool2o`0000?o
oooo0_l0001_ooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00002Oooool2o`0000?ooooo
1?l0000?ooooo`;o00001OoooolAo`000003ooooool0003o000000?o00000_ooool2o`000003oooo
ool0003o000000Gooooo0_l00009ooooo`Co00000_ooool6o`0000Gooooo0ol00006oooooaSo0000
00?oooooo`000?l000001Oooool2o`000003ooooool0003o000000?o00007oooool2o`0000oooooo
0_l0000kooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00001_ooool2o`0000?ooooo1?l0
000>ooooo`;o00001_ooool8o`000003ooooool0003o000000Go00000_ooool5o`0000Wooooo0_l0
000<ooooo`;o00001?ooool7o`0000Cooooo0ol00006ooooo`;o000000?oooooo`000?l000004ol0
00000ooooooo0000o`000005ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Mooooo`Co0000
3_ooool3o`0003_ooooo000Looooo`03o`000?oooooooooo04Gooooo0_l0000Mooooo`;o00002?oo
ool3o`000004ooooool0003o0000o`0000;ooooo1Ol0000@ooooo`;o00000oooool2o`0000[ooooo
2ol00003ooooo`;o00001ooooolFo`000004ooooool0003o0000ooooo`;o00001Oooool2o`000003
ooooool0003o000000;o00007Oooool2o`00013ooooo0_l0000looooo`007?ooool00ol0003ooooo
ooooo`15ooooo`;o00001oooool2o`0000?ooooo0ol0000;ooooo`;o00002oooool3o`000004oooo
ool0003o0000o`0000cooooo0_l00006ooooo`?o00001Oooool2o`0000[ooooo1?l00005ooooo`;o
00003_ooool:o`000003ooooool0003o000000[o000000?oooooo`000?l000001Oooool6o`0000Ko
oooo0_l0001Vooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00001oooool2o`0000?ooooo
0ol0000;ooooo`;o00000_ooool2o`0000Cooooo0_l0000@ooooo`;o00000_ooool2o`0000Kooooo
0ol00009ooooo`;o00001Oooool2o`000004ooooool0003o0000o`0000_ooooo0_l00009oooooaGo
000000?oooooo`000?l000001_ooool5o`0000Kooooo0_l0001Vooooo`007?ooool00ol0003ooooo
ooooo`1Eooooo`;o00002_ooool3o`000005ooooool0003o0000o`000?ooool01?l0000@ooooo`Co
00001?ooool4o`0000cooooo0_l00005ooooo`Ko00001oooool2o`0000;ooooo0_l00009oooooaGo
00000_ooool2o`0000Gooooo0_l00003ooooo`;o0000K?ooool001cooooo00?o0000ooooooooool0
EOooool2o`0000_ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00001Oooool2o`0000Oo
oooo0_l00004ooooo`?o00000oooool4o`0001Cooooo0_l000000ooooooo0000o`000003ooooo`;o
00000_ooool2o`0000cooooo5_l00002ooooo`;o00002Oooool3o`0001Wooooo0_l0001Aooooo`00
7?ooool00ol0003oooooooooo`1Eooooo`;o00003_ooool2o`0000?ooooo0_l00004ooooo`Co0000
1Oooool2o`0000Cooooo1?l0000?ooooo`;o00002Oooool2o`0000Kooooo0_l0000<ooooo`;o0000
0_oooolFo`000003ooooool0003o000000[ooooo0_l0000Jooooo`;o00003oooool2o`00043ooooo
000Looooo`03o`000?oooooooooo06Gooooo0_l00003ooooo`;o00001?ooool4o`0000_ooooo1?l0
000>ooooo`Go00000_ooool2o`0000?ooooo0_l00003ooooo`;o00003oooool2o`0000?ooooo0_l0
00000ooooooo0000o`00000Co`0000Cooooo0_l0000aooooo`;o0000@?ooool001cooooo0_l00019
ooooo`;o00008_ooool2o`0000;ooooo0_l0000=ooooo`;o000000?oooooo`000?l000003Oooool5
o`0000;ooooo1?l00006ooooo`;o00003Oooool2o`0000Gooooo6?l00004ooooo`;o0000Loooool0
01cooooo00?o0000ooooooooool0B?ooool2o`0000;ooooo0_l0000Nooooo`Co00001Oooool2o`00
00Sooooo0_l000000ooooooo0000o`000003ooooo`;o00002_ooool2o`0000Gooooo0_l00008oooo
o`;o00001_ooool2o`000003ooooool0003o000000;o00001Oooool3o`000003ooooool0003o0000
01;o000000?oooooo`000?l00000M_ooool001cooooo00?o0000ooooooooool0C?ooool2o`0000?o
oooo0_l0000Cooooo`Co00000_ooool4o`0000Gooooo0_l0000@ooooo`;o00002_ooool4o`0000;o
oooo0_l000000ooooooo0000o`000004ooooo`Co00000_ooool2o`0000;ooooo2?l00002ooooo`;o
000000?oooooo`000?l000005Ol000001?oooooo0000o`000?ooool2o`0000Oooooo0_l0001Zoooo
o`007?ooool00ol0003oooooooooo`1Aooooo`;o00004_ooool5o`0001Wooooo1?l0000>ooooo`;o
00000_ooool2o`000003ooooool0003o000000Cooooo1?l00002ooooo`;o00001?ooool3o`000003
ooooool0003o000000;ooooo0_l000000ooooooo0000o`00000Co`0000Cooooo1?l00007ooooo`;o
0000J_ooool001cooooo00?o0000ooooooooool0Coooool2o`0001Cooooo0_l000000ooooooo0000
o`000002o`0000Gooooo0_l0000@ooooo`Co00002?ooool2o`0001?ooooo0_l00007ooooo`;o0000
0oooool3o`0000Sooooo0_l000000ooooooo0000o`00000=o`0000;ooooo0ol0000Mooooo`;o0000
E_ooool001cooooo00?o0000ooooooooool0Coooool2o`0001Gooooo0_l00002ooooo`;o00001Ooo
ool2o`0001cooooo1?l0000Jooooo`;o00000oooool3o`000003ooooool0003o000000Gooooo0_l0
00000ooooooo0000o`000003o`0000?ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l0
0005ooooo`;o00005oooool2o`0005Kooooo000Looooo`03o`000?oooooooooo053ooooo1?l0000B
ooooo`;o00000_ooool2o`0000Wooooo0_l00009ooooo`;o00003oooool2o`0001;ooooo0_l00003
ooooo`;o00001Oooool2o`0000?ooooo0_l00008ooooo`Go00000oooool2o`0000Gooooo0_l00007
ooooo`;o0000Koooool001cooooo00?o0000ooooooooool0D?ooool4o`0001cooooo0_l00003oooo
o`;o00002Oooool2o`0002?ooooo0_l00003ooooo`;o00001Oooool2o`000003ooooool0003o0000
00;o00002Oooool3o`0000_ooooo0_l0000^ooooo`;o0000B?ooool001cooooo00?o0000oooooooo
ool0E?ooool2o`0001[ooooo0_l00012ooooo`Co00002_ooool2o`0003[ooooo0ol00018ooooo`00
7?ooool00ol0003oooooooooo`1Dooooo`;o00006_ooool2o`0000Oooooo0_l0000booooo`;o0000
1Oooool4o`0000;ooooo0_l0000]ooooo`;o00004oooool2o`0004Wooooo000Looooo`03o`000?oo
oooooooo05Cooooo0_l0000Jooooo`;o00001oooool2o`0003;ooooo0_l00005ooooo`?o00000ooo
ool2o`0001?ooooo0_l0000Gooooo`?o0000G_ooool001cooooo00?o0000ooooooooool0E?ooool3
o`0005gooooo0ol000000ooooooo0000o`000004ooooo`;o00003Oooool4o`0001Oooooo0_l0001O
ooooo`007?ooool00ol0003oooooooooo`1Eooooo`;o00006?ooool2o`0004?ooooo1_l00004oooo
o`;o00003Oooool2o`000004ooooool0003o0000o`0007Kooooo000Looooo`03o`000?oooooooooo
05Kooooo0_l0000Cooooo`;o00000_ooool2o`0001;ooooo0_l0000aooooo`?o00001oooool2o`00
00Gooooo1ol00002ooooo`?o00003oooool2o`0006Gooooo000Looooo`03o`000?oooooooooo05Ko
oooo0_l0000Cooooo`Ko00002oooool2o`0000;ooooo0_l000000ooooooo0000o`00000hooooo`;o
000000Coooooo`000?l0003o00001?ooool9o`0001;ooooo0_l0001Uooooo`007?ooool00ol0003o
ooooooooo`1Iooooo`;o00003oooool2o`000003ooooool0003o000000?o00002_ooool2o`000004
ooooool0003o0000o`0002Gooooo0_l0000Aooooo`;o000000Coooooo`000?l0003ooooo0ol00009
ooooo`Co0000NOooool001cooooo0_l0001Jooooo`;o00003oooool2o`0000?ooooo0ol00008oooo
o`;o00000oooool2o`0002Kooooo1?l0000?ooooo`;o00004?ooool3o`00013ooooo0_l00009oooo
o`;o00000_ooool2o`0005Wooooo000Looooo`03o`000?oooooooooo06oooooo0_l00009ooooo`;o
0000;Oooool2o`0000gooooo0_l0000Looooo`;o00001Oooool4o`0000Kooooo0_l000000ooooooo
0000o`000002ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0L_ooool2o`0003[ooooo
0ol00007ooooo`;o00005Oooool4o`0000?ooooo0ol00004ooooo`;o00002?ooool5o`0005gooooo
000Looooo`03o`000?oooooooooo07;ooooo0_l00003ooooo`;o0000=Oooool3o`0001kooooo1?l0
0004ooooo`;o00002_ooool2o`000003ooooool0003o000000Co00001oooool2o`0005Cooooo000L
ooooo`03o`000?oooooooooo07Cooooo1Ol00004ooooo`;o000000?oooooo`000?l000008?ooool2
o`0000;ooooo0_l0000:ooooo`;o00004?ooool2o`0001?ooooo0_l000000ooooooo0000o`000005
ooooo`Go00002_ooool3o`0005Cooooo000Looooo`03o`000?oooooooooo05kooooo0_l0000Coooo
o`Go00001Oooool5o`0001Gooooo0ol000000ooooooo0000o`000005ooooo`;o00000_ooool2o`00
00[ooooo0_l0000<ooooo`;o00000_ooool2o`0000oooooo0_l00002ooooo`;o000000?oooooo`00
0?l000001_ooool2o`0000cooooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o
00004oooool2o`0000[ooooo0_l0000Fooooo`?o000000?oooooo`000?l000005Oooool2o`0000co
oooo0_l000000ooooooo0000o`00000@ooooo`;o00001?ooool2o`0000Kooooo0_l0001Tooooo`00
7?ooool00ol0003oooooooooo`1jooooo`;o00002Oooool2o`0003cooooo0_l00008ooooo`;o0000
0_ooool2o`000003ooooool0003o000000Gooooo0ol00005ooooo`;o0000I?ooool001cooooo00?o
0000ooooooooool0Loooool2o`0000Gooooo0_l00009ooooo`;o00008?ooool2o`0000gooooo0_l0
000Eooooo`;o00000_ooool2o`000003ooooool0003o000000Kooooo0_l0000=ooooo`;o0000G?oo
ool001cooooo00?o0000ooooooooool0H?ooool3o`00013ooooo0_l00003ooooo`Co00000oooool2
o`0000;ooooo0_l0000Rooooo`;o00003?ooool5o`00037ooooo0_l0001Looooo`007?ooool00ol0
003oooooooooo`1Pooooo`Go00004oooool4o`0000?ooooo0_l00002ooooo`;o00004_ooool2o`00
00_ooooo0_l000000ooooooo0000o`00000<ooooo`;o000000?oooooo`000?l00000Soooool001co
oooo00?o0000ooooooooool0H?ooool5o`0001Cooooo0_l00007ooooo`;o00000_ooool2o`0000Oo
oooo0_l00006ooooo`;o00002oooool2o`0000kooooo1?l00003ooooo`;o00006Oooool2o`0000oo
oooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`1Rooooo`;o00005Oooool2o`0000Oooooo
0_l00002ooooo`;o00001oooool2o`0001_ooooo0_l00006ooooo`Co00000_ooool5o`0001Gooooo
1?l0000?ooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0P_ooool3o`0002Oooooo0ol0
0005ooooo`;o000000?oooooo`000?l000001_l0000Eooooo`;o00002_ooool2o`0006Oooooo0000
1_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<
c<`01_ooool00ol0003oooooooooo`1Sooooo`;o00007_ooool4o`0001Kooooo0_l00003ooooo`Go
00001Oooool3o`0000Sooooo2Ol0000Pooooo`;o0000Ioooool00006oooooomgMgOoV9RHoooooonH
V9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooo
oooo06?ooooo0_l0000Pooooo`;o00000_ooool6o`0000kooooo0_l000000ooooooo0000o`000008
o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`?o00000_ooool2o`0000?ooooo0ol00005
ooooo`;o0000P_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0ROooool6o`000003ooooool0003o
000000;ooooo0_l000001?oooooo0000o`000?ooool;o`0000;ooooo0ol00002ooooo`[o00000_oo
ool2o`0000;ooooo1?l00004ooooo`?o0000P_ooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool02Oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0001Yooooo`;o00008_oo
ool2o`000003ooooool0003o000000;ooooo0_l000001?oooooo0000o`000?ooool6o`0000Oooooo
1?l000001Ooooooo0000o`000?l0003ooooo00Go00001oooool4o`0000;ooooo1?l0000Fooooo`;o
0000Joooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Oo<c<co0000
o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0JOooool5o`0001Sooooo0_l00005ooooo`;o
00000oooool2o`0000gooooo1Ol000000ooooooo0000o`000002o`0000Kooooo0_l0000<ooooo`;o
000000?oooooo`000?l000006?ooool2o`0006_ooooo00000ooooooo410@ooooo`02ooooo`03oa0@
4?oooooooooo00Wooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo06_o
oooo0ol00002ooooo`;o00005?ooool4o`0000Sooooo0_l00004ooooo`;o00001oooool7o`000003
ooooool0003o000001Cooooo0_l000000ooooooo0000o`00000Fooooo`;o0000KOooool00006oooo
oomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000
ooooooooool0Joooool3o`0000;ooooo1Ol0000Cooooo`;o00003Oooool3o`0000Cooooo0ol00004
ooooo`?o000000?oooooo`000?l000005oooool2o`0001Kooooo0_l0001]ooooo`0000Koooooonk^
k_lb<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003ooooo
ooooo`1/ooooo`;o00000_ooool5o`0001Wooooo0_l00007ooooo`?o00001?ooool3o`0000gooooo
0_l000000ooooooo0000o`00000Sooooo`;o0000LOooool001cooooo00?o0000ooooooooool0S_oo
ool2o`0001kooooo0_l000000ooooooo0000o`00000Sooooo`;o0000LOooool001cooooo00?o0000
ooooooooool0L?ooool2o`0000Kooooo0_l0003?ooooo`007?ooool00ol0003oooooooooo`1`oooo
o`;o00001Oooool3o`00057ooooo1?l0001jooooo`007?ooool00ol0003oooooooooo`1gooooo`?o
00007oooool3o`0002oooooo1?l0001jooooo`007?ooool00ol0003oooooooooo`1kooooo`;o0000
7?ooool3o`0000;ooooo0_l0002Yooooo`007?ooool00ol0003oooooooooo`1kooooo`;o00008Ooo
ool2o`000003ooooool0003o000000;o00005oooool2o`0008_ooooo000Looooo`03o`000?oooooo
oooo0:7ooooo1_l00002ooooo`;o00001Oooool2o`0000Gooooo0_l00003ooooo`?o0000R_ooool0
01cooooo00?o0000ooooooooool0P_ooool2o`00027ooooo0_l00002ooooo`;o00001Oooool4o`00
00?ooooo0_l00004ooooo`;o0000R_ooool001cooooo00?o0000ooooooooool0P_ooool2o`0002co
oooo1?l0002Eooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo0_l0002;ooooo`;o0000_Oooool001cooooo00?o0000oooo
ooooool0R_ooool2o`000003ooooool0003o00000;[ooooo000Looooo`03o`000?oooooooooo08go
oooo0_l0002jooooo`007?ooool00ol0003oooooooooo`2Aooooo`Co0000]?ooool001cooooo00?o
0000ooooooooool0TOooool4o`000;Cooooo000Looooo`03o`000?oooooooooo09Kooooo0ol0002`
ooooo`007?ooool00ol0003oooooooooo`2Fooooo`?o0000/?ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Yooooo`Go0000Voooool001cooooo00?o
0000ooooooooool0ZOooool5o`0001Gooooo0_l00024ooooo`007?ooool00ol0003oooooooooo`2f
ooooo`Go00002?ooool2o`0008Cooooo000Looooo`03o`000?oooooooooo0;Kooooo1Ol0002>oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`004_ooool4o`00
0003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool0
1Oooool3o`000?ooooooB_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool0
0ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Co
oooo00?o0000ooooooooool0oooooomBooooo`004_ooool00omEEEGoIVIVo`00003ooooooeCooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo002Uooooo`04oa0@4?l0003o0000oooo
o`;o000000?o410@ooooooooool05Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo00?o0000
onk^k_ooool00oooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<093ooooo002Vooooo`05o`000?oooooo
ooooooooool000002Oooool6o`0000Wooooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`03oeEE
EOnYZJWooooo00?ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@2@ooooo`00Y_ooool01Ol0003ooooo
oooooooooooo000001cooooo00?o0000ooooooooool00oooool00onYZJWoEEEEooooo`03ooooo`05
o`000?ooooooooooooooool00000T?ooool00:Kooooo00Go0000ooooooooooooooooo`000009oooo
o`Ko00003?ooool00onYZJWo410@ooooo`05ooooo`03ob4Q8Ooooooooooo00;ooooo00Go<S8boiRH
V?ooooooV9RHoc8b<P2@ooooo`00Y_ooool01Ol0003oQhN7oooooonYZJWo000001[ooooo00?o410@
o`000?nj^[X01_ooool00omEEEGoc<c<ooooo`02ooooo`05olc<c?l0003o0000o`000?o<c<`0T?oo
ool00:Gooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Iooooo`03okZj^_lQ8B7o
oooo00Gooooo00?oZJVYogMgMoooool00_ooool01Ol@413o^[Zjoooooonj^[[o410@093ooooo0033
ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01Ol@413ooooooooooooooooo<S8b00?ooooo
00Go0000okZj^_oooooo^[Zjo`00002@ooooo`00`oooool01OnYZJWo410@o`000?l@413oZJVY00?o
oooo1Ol00003ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0T?ooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(384) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.39146 .63526 Mdot
.37211 .60307 Mdot
.69138 .50536 Mdot
.40357 .35087 Mdot
.71074 .39563 Mdot
.69835 .52628 Mdot
.58119 .71349 Mdot
.58204 .71658 Mdot
.71333 .53804 Mdot
.20278 .50643 Mdot
.56263 .6785 Mdot
.37105 .39496 Mdot
.57646 .69675 Mdot
.4139 .37125 Mdot
.48294 .48673 Mdot
.47609 .39264 Mdot
.4019 .58918 Mdot
.66641 .36014 Mdot
.46903 .40744 Mdot
.6631 .53624 Mdot
.34981 .28649 Mdot
.42497 .36812 Mdot
.33936 .63269 Mdot
.41607 .3689 Mdot
.45357 .36536 Mdot
.35621 .61879 Mdot
.37864 .64166 Mdot
.44972 .36715 Mdot
.39671 .41805 Mdot
.56442 .68333 Mdot
.58776 .53202 Mdot
.32147 .24737 Mdot
.44487 .3337 Mdot
.3093 .45302 Mdot
.56756 .71868 Mdot
.57578 .75442 Mdot
.67278 .55788 Mdot
.60403 .68169 Mdot
.56025 .71488 Mdot
.55157 .69067 Mdot
.55418 .68398 Mdot
.35335 .6238 Mdot
.57459 .65399 Mdot
.67929 .71722 Mdot
.40283 .36249 Mdot
.40048 .51605 Mdot
.65594 .71124 Mdot
.44618 .41011 Mdot
.38487 .58996 Mdot
.67093 .51494 Mdot
.61427 .30042 Mdot
.60268 .69447 Mdot
.45694 .59207 Mdot
.80482 .71538 Mdot
.56785 .69963 Mdot
.46265 .40432 Mdot
.70339 .56541 Mdot
.4152 .39851 Mdot
.41217 .34332 Mdot
.29084 .41073 Mdot
.43165 .39248 Mdot
.68357 .37126 Mdot
.4267 .61241 Mdot
.67835 .58491 Mdot
.71456 .53391 Mdot
.6015 .67704 Mdot
.33233 .60692 Mdot
.57628 .68481 Mdot
.38456 .40413 Mdot
.67708 .51318 Mdot
.41017 .42146 Mdot
.5656 .67676 Mdot
.35115 .64119 Mdot
.40851 .35382 Mdot
.49203 .79319 Mdot
.6406 .71878 Mdot
.6648 .59369 Mdot
.31697 .33266 Mdot
.69564 .30266 Mdot
.57079 .49258 Mdot
.41568 .35582 Mdot
.82173 .58518 Mdot
.53116 .46243 Mdot
.38897 .59959 Mdot
.44213 .60579 Mdot
.45965 .68058 Mdot
.45218 .3974 Mdot
.57802 .54202 Mdot
.48271 .37192 Mdot
.69047 .4364 Mdot
.70494 .55772 Mdot
.39716 .6079 Mdot
.40743 .35752 Mdot
.38006 .38109 Mdot
.23297 .59684 Mdot
.40998 .42918 Mdot
.41867 .34294 Mdot
.46443 .63403 Mdot
.56922 .66759 Mdot
.43613 .45932 Mdot
.63259 .37988 Mdot
.49257 .60264 Mdot
.4607 .40463 Mdot
.69065 .55446 Mdot
.42031 .62457 Mdot
.45859 .34617 Mdot
.58645 .69404 Mdot
.41676 .35943 Mdot
.55171 .66143 Mdot
.37152 .58706 Mdot
.39039 .3466 Mdot
.69452 .38538 Mdot
.36008 .30742 Mdot
.34376 .63137 Mdot
.31209 .54627 Mdot
.43632 .3807 Mdot
.41255 .40449 Mdot
.36932 .60216 Mdot
.66882 .53125 Mdot
.78392 .5988 Mdot
.34986 .63792 Mdot
.55114 .68948 Mdot
.39938 .59096 Mdot
.37253 .31687 Mdot
.66584 .53942 Mdot
.47615 .60789 Mdot
.47482 .60945 Mdot
.53743 .27813 Mdot
.41589 .35091 Mdot
.40794 .26947 Mdot
.69388 .54359 Mdot
.35109 .6151 Mdot
.57003 .68772 Mdot
.45066 .42925 Mdot
.36584 .63014 Mdot
.58653 .71511 Mdot
.72955 .37194 Mdot
.66365 .37662 Mdot
.34786 .60857 Mdot
.30013 .5758 Mdot
.57299 .64436 Mdot
.55602 .66936 Mdot
.61116 .30131 Mdot
.38859 .59887 Mdot
.70417 .37183 Mdot
.59373 .70133 Mdot
.55823 .19589 Mdot
.41746 .3396 Mdot
.58692 .30486 Mdot
.80571 .61146 Mdot
.61446 .30087 Mdot
.29749 .30774 Mdot
.70064 .38282 Mdot
.58783 .71492 Mdot
.42416 .42114 Mdot
.37877 .61678 Mdot
.36194 .62862 Mdot
.3937 .40732 Mdot
.44846 .34653 Mdot
.40426 .3777 Mdot
.45127 .34012 Mdot
.55634 .61064 Mdot
.40922 .35853 Mdot
.35386 .76731 Mdot
.37952 .62341 Mdot
.45644 .35747 Mdot
.67377 .54243 Mdot
.47549 .44899 Mdot
.5843 .6579 Mdot
.40689 .34653 Mdot
.4485 .35036 Mdot
.39579 .4299 Mdot
.5504 .69248 Mdot
.48801 .80388 Mdot
.72085 .29071 Mdot
.60988 .73003 Mdot
.61171 .77582 Mdot
.68609 .5358 Mdot
.4346 .39782 Mdot
.71493 .36423 Mdot
.46626 .44438 Mdot
.38856 .36598 Mdot
.62107 .29905 Mdot
.43487 .35025 Mdot
.30848 .29955 Mdot
.3983 .32051 Mdot
.47514 .66975 Mdot
.33003 .73483 Mdot
.39369 .35474 Mdot
.22409 .4894 Mdot
.58941 .31691 Mdot
.62397 .54576 Mdot
.56664 .68835 Mdot
.68441 .51623 Mdot
.67362 .52246 Mdot
.60896 .70404 Mdot
.3553 .51366 Mdot
.20562 .48005 Mdot
.39631 .42313 Mdot
.48866 .60193 Mdot
.38156 .57878 Mdot
.69801 .38176 Mdot
.35187 .60576 Mdot
.83222 .55953 Mdot
.59127 .47697 Mdot
.56383 .52859 Mdot
.67926 .3382 Mdot
.66383 .52058 Mdot
.48031 .60269 Mdot
.70793 .36682 Mdot
.39843 .3851 Mdot
.3733 .58762 Mdot
.59395 .31239 Mdot
.47488 .43584 Mdot
.15383 .55526 Mdot
.37481 .64183 Mdot
.50844 .28266 Mdot
.57015 .69868 Mdot
.72309 .5553 Mdot
.4525 .39615 Mdot
.42131 .38562 Mdot
.35544 .59325 Mdot
.42636 .41803 Mdot
.5446 .51139 Mdot
.44396 .34853 Mdot
.68088 .58415 Mdot
.75265 .33404 Mdot
.61297 .6961 Mdot
.71199 .33772 Mdot
.34678 .63918 Mdot
.52281 .8397 Mdot
.68144 .55603 Mdot
.42975 .47166 Mdot
.57504 .67675 Mdot
.72931 .37557 Mdot
.68779 .56197 Mdot
.6715 .37468 Mdot
.38878 .35138 Mdot
.67713 .56352 Mdot
.68353 .37619 Mdot
.53261 .53786 Mdot
.454 .34324 Mdot
.5117 .23941 Mdot
.59911 .69828 Mdot
.40255 .60389 Mdot
.38736 .38282 Mdot
.4611 .58809 Mdot
.3707 .41649 Mdot
.54669 .32445 Mdot
.46358 .59239 Mdot
.50007 .59746 Mdot
.55539 .47757 Mdot
.71649 .35311 Mdot
.57009 .77942 Mdot
.56342 .55049 Mdot
.40224 .58916 Mdot
.38282 .36979 Mdot
.52554 .72507 Mdot
.59807 .70449 Mdot
.40255 .39096 Mdot
.5061 .70239 Mdot
.59365 .7035 Mdot
.40971 .4019 Mdot
.55508 .69025 Mdot
.37126 .62507 Mdot
.52907 .49872 Mdot
.40972 .60925 Mdot
.39313 .36928 Mdot
.55644 .68661 Mdot
.67979 .51929 Mdot
.35681 .6193 Mdot
.42062 .36133 Mdot
.43181 .35647 Mdot
.48998 .5959 Mdot
.43331 .34213 Mdot
.48266 .64258 Mdot
.44955 .40662 Mdot
.6852 .50354 Mdot
.40491 .42582 Mdot
.6241 .35339 Mdot
.69362 .4255 Mdot
.36032 .59265 Mdot
.46459 .5917 Mdot
.6953 .56676 Mdot
.52512 .51815 Mdot
.48173 .24903 Mdot
.41067 .36185 Mdot
.4728 .58962 Mdot
.53145 .29359 Mdot
.58254 .65798 Mdot
.47718 .34561 Mdot
.74957 .57095 Mdot
.70257 .55778 Mdot
.48524 .6032 Mdot
.45475 .44732 Mdot
.31797 .62585 Mdot
.45582 .41842 Mdot
.67628 .55918 Mdot
.40783 .61074 Mdot
.42549 .42955 Mdot
.64701 .70057 Mdot
.46094 .58715 Mdot
.56535 .66646 Mdot
.46958 .63137 Mdot
.42092 .40948 Mdot
.68473 .51144 Mdot
.35513 .63069 Mdot
.56871 .70714 Mdot
.34474 .63393 Mdot
.60183 .32053 Mdot
.52746 .30499 Mdot
.48182 .5655 Mdot
.707 .34388 Mdot
.50566 .15875 Mdot
.61152 .72932 Mdot
.44804 .45519 Mdot
.73324 .56458 Mdot
.30253 .68484 Mdot
.69297 .55764 Mdot
.29612 .58686 Mdot
.70511 .56089 Mdot
.45197 .41656 Mdot
.70416 .52644 Mdot
.22844 .60802 Mdot
.44491 .36327 Mdot
.71493 .52764 Mdot
.57668 .5972 Mdot
.44192 .36097 Mdot
.36661 .63115 Mdot
.25512 .30141 Mdot
.33981 .4802 Mdot
.34631 .49554 Mdot
.70343 .56818 Mdot
.28585 .60877 Mdot
.45094 .37387 Mdot
.46339 .42027 Mdot
.37415 .61574 Mdot
.36767 .40857 Mdot
.70029 .34766 Mdot
.66968 .36204 Mdot
.5907 .24398 Mdot
.37111 .24192 Mdot
.3434 .51906 Mdot
.36028 .62368 Mdot
.74016 .31015 Mdot
.48176 .79161 Mdot
.4603 .5876 Mdot
.5832 .71681 Mdot
.52647 .8009 Mdot
.47851 .40834 Mdot
.35562 .67407 Mdot
.54203 .50948 Mdot
.40118 .61976 Mdot
.49789 .55638 Mdot
.57134 .71077 Mdot
.34361 .4932 Mdot
.20615 .44812 Mdot
.40298 .37855 Mdot
.59524 .67524 Mdot
.36491 .38022 Mdot
.57213 .54328 Mdot
.52143 .26157 Mdot
.67817 .63579 Mdot
.39425 .3692 Mdot
.53148 .78567 Mdot
.3877 .37228 Mdot
.54799 .28152 Mdot
.39868 .38926 Mdot
.36263 .6349 Mdot
.41065 .43819 Mdot
.55655 .55368 Mdot
.55743 .15734 Mdot
.59049 .46775 Mdot
.67463 .36432 Mdot
.41632 .3736 Mdot
.41041 .38676 Mdot
.68115 .37 Mdot
.39973 .61418 Mdot
.38466 .38339 Mdot
.62111 .79065 Mdot
.41074 .35664 Mdot
.60431 .69699 Mdot
.56703 .37233 Mdot
.35807 .23346 Mdot
.44649 .39304 Mdot
.31858 .62457 Mdot
.55829 .6678 Mdot
.58618 .68086 Mdot
.47333 .3297 Mdot
.6003 .69786 Mdot
.42282 .42036 Mdot
.56703 .37321 Mdot
.3341 .61344 Mdot
.48152 .34229 Mdot
.39651 .6245 Mdot
.76616 .32231 Mdot
.59356 .70893 Mdot
.47036 .58623 Mdot
.34103 .52802 Mdot
.58487 .70323 Mdot
.75156 .35912 Mdot
.41808 .43981 Mdot
.49748 .40426 Mdot
.3561 .57373 Mdot
.68773 .51193 Mdot
.47163 .59705 Mdot
.56767 .70167 Mdot
.40636 .36177 Mdot
.46267 .37866 Mdot
.60062 .69045 Mdot
.2652 .36593 Mdot
.58852 .53174 Mdot
.39286 .36741 Mdot
.37936 .62932 Mdot
.35042 .61797 Mdot
.47708 .36325 Mdot
.38671 .37564 Mdot
.69246 .52024 Mdot
.47185 .58994 Mdot
.46697 .59324 Mdot
.48544 .60872 Mdot
.71234 .56584 Mdot
.51198 .15959 Mdot
.55709 .66714 Mdot
.33155 .24229 Mdot
.47753 .75633 Mdot
.42689 .30408 Mdot
.66984 .53885 Mdot
.42709 .38716 Mdot
.45894 .39939 Mdot
.55783 .68836 Mdot
.48397 .18512 Mdot
.45873 .42455 Mdot
.40491 .62244 Mdot
.60139 .68692 Mdot
.36527 .39137 Mdot
.5854 .64126 Mdot
.71426 .38257 Mdot
.32912 .52572 Mdot
.60118 .70066 Mdot
.33995 .60975 Mdot
.60136 .70041 Mdot
.40824 .38408 Mdot
.45158 .44944 Mdot
.39974 .62316 Mdot
.68317 .39354 Mdot
.38791 .39894 Mdot
.40429 .40078 Mdot
.71865 .47473 Mdot
.49497 .79201 Mdot
.74361 .36491 Mdot
.44778 .41505 Mdot
.49893 .40432 Mdot
.67863 .39037 Mdot
.40057 .40851 Mdot
.41016 .42635 Mdot
.40448 .26931 Mdot
.56217 .65142 Mdot
.73425 .37426 Mdot
.54108 .16159 Mdot
.37802 .64075 Mdot
.49469 .63932 Mdot
.48694 .60581 Mdot
.5986 .73564 Mdot
.52296 .50537 Mdot
.48243 .59646 Mdot
.48969 .73907 Mdot
.4198 .8453 Mdot
.4738 .59558 Mdot
.69991 .57798 Mdot
.25327 .59551 Mdot
.40495 .42304 Mdot
.39023 .37626 Mdot
.70953 .35079 Mdot
.3749 .59689 Mdot
.35556 .76105 Mdot
.60657 .73252 Mdot
.43194 .37482 Mdot
.36656 .64668 Mdot
.46568 .6779 Mdot
.48607 .59953 Mdot
.7178 .37058 Mdot
.70085 .39575 Mdot
.3885 .38178 Mdot
.50955 .27254 Mdot
.35642 .62277 Mdot
.42059 .36141 Mdot
.41411 .4064 Mdot
.67649 .57147 Mdot
.3726 .5884 Mdot
.67522 .54545 Mdot
.48475 .58202 Mdot
.24995 .6563 Mdot
.68296 .76684 Mdot
.59767 .69568 Mdot
.45993 .52603 Mdot
.61275 .69806 Mdot
.64489 .64681 Mdot
.47081 .59052 Mdot
.42241 .36409 Mdot
.33268 .63053 Mdot
.41842 .35967 Mdot
.40946 .35684 Mdot
.39779 .36763 Mdot
.34143 .51946 Mdot
.69456 .30672 Mdot
.71211 .35784 Mdot
.42671 .41232 Mdot
.69822 .57434 Mdot
.49055 .66354 Mdot
.19685 .54431 Mdot
.41777 .37957 Mdot
.41134 .40434 Mdot
.32654 .6097 Mdot
.40427 .3402 Mdot
.58695 .70837 Mdot
.4034 .61556 Mdot
.46287 .39312 Mdot
.63642 .38035 Mdot
.38658 .38812 Mdot
.45565 .53735 Mdot
.59119 .72212 Mdot
.41161 .44981 Mdot
.41301 .32958 Mdot
.46987 .58998 Mdot
.47302 .59755 Mdot
.50571 .59176 Mdot
.60397 .68703 Mdot
.67935 .57178 Mdot
.66256 .58546 Mdot
.39239 .3374 Mdot
.4352 .41891 Mdot
.47694 .43204 Mdot
.69711 .49476 Mdot
.57717 .55947 Mdot
.31526 .56187 Mdot
.36921 .36433 Mdot
.72322 .54393 Mdot
.46609 .63371 Mdot
.32748 .31132 Mdot
.4023 .60864 Mdot
.74001 .5419 Mdot
.58355 .68354 Mdot
.68377 .38343 Mdot
.58256 .26608 Mdot
.35517 .63761 Mdot
.32696 .62896 Mdot
.69023 .52545 Mdot
.55882 .38884 Mdot
.84926 .66072 Mdot
.69618 .54802 Mdot
.55712 .52418 Mdot
.36885 .61855 Mdot
.44702 .33537 Mdot
.5441 .30485 Mdot
.5498 .39529 Mdot
.71914 .53674 Mdot
.43035 .3558 Mdot
.75367 .40171 Mdot
.69329 .52005 Mdot
.48865 .42284 Mdot
.70304 .56907 Mdot
.57595 .66351 Mdot
.68991 .54746 Mdot
.38625 .64188 Mdot
.41819 .35201 Mdot
.81905 .69848 Mdot
.52427 .47992 Mdot
.43112 .36346 Mdot
.60205 .70288 Mdot
.63334 .61135 Mdot
.40283 .38444 Mdot
.68377 .34918 Mdot
.69435 .5779 Mdot
.65522 .6398 Mdot
.43572 .42547 Mdot
.70391 .52401 Mdot
.32439 .63798 Mdot
.73804 .51887 Mdot
.63352 .38684 Mdot
.46874 .59591 Mdot
.37618 .62244 Mdot
.60421 .74723 Mdot
.55236 .68538 Mdot
.46926 .3845 Mdot
.4225 .404 Mdot
.3848 .62223 Mdot
.52394 .52981 Mdot
.46065 .32491 Mdot
.41398 .35672 Mdot
.68132 .53199 Mdot
.65828 .55679 Mdot
.48537 .48273 Mdot
.68056 .55749 Mdot
.49967 .39947 Mdot
.37669 .62798 Mdot
.45798 .41678 Mdot
.34693 .62954 Mdot
.38249 .3724 Mdot
.59208 .63878 Mdot
.39686 .60061 Mdot
.41355 .468 Mdot
.42036 .34945 Mdot
.34582 .56035 Mdot
.42577 .40792 Mdot
.39708 .3617 Mdot
.66321 .56771 Mdot
.68972 .36422 Mdot
.4733 .3434 Mdot
.64083 .68151 Mdot
.69369 .39207 Mdot
.283 .33688 Mdot
.66593 .54024 Mdot
.72106 .38806 Mdot
.56685 .23818 Mdot
.46463 .59266 Mdot
.68555 .36054 Mdot
.45886 .60846 Mdot
.5975 .68815 Mdot
.3933 .64865 Mdot
.43722 .356 Mdot
.24799 .6487 Mdot
.58768 .53394 Mdot
.48739 .59166 Mdot
.3933 .39591 Mdot
.42356 .39059 Mdot
.365 .64671 Mdot
.82888 .56701 Mdot
.65769 .56858 Mdot
.43953 .33983 Mdot
.35583 .63959 Mdot
.81471 .59699 Mdot
.71681 .52917 Mdot
.72296 .3655 Mdot
.56774 .72382 Mdot
.4031 .58092 Mdot
.46932 .58559 Mdot
.59209 .71094 Mdot
.6721 .59579 Mdot
.62532 .29814 Mdot
.45027 .42123 Mdot
.67159 .54167 Mdot
.61567 .30073 Mdot
.47103 .33482 Mdot
.61006 .69623 Mdot
.62844 .74173 Mdot
.39192 .60344 Mdot
.60078 .68991 Mdot
.69533 .34975 Mdot
.3946 .58456 Mdot
.39894 .62206 Mdot
.58921 .70404 Mdot
.3083 .71711 Mdot
.5323 .29517 Mdot
.59524 .72672 Mdot
.55161 .33072 Mdot
.6162 .302 Mdot
.48372 .58591 Mdot
.7164 .37135 Mdot
.74963 .32039 Mdot
.35368 .62232 Mdot
.52166 .80163 Mdot
.61534 .29968 Mdot
.41934 .34267 Mdot
.68243 .3768 Mdot
.49469 .65549 Mdot
.54722 .734 Mdot
.59021 .70955 Mdot
.72104 .48035 Mdot
.67997 .37885 Mdot
.39236 .35153 Mdot
.40155 .19537 Mdot
.44667 .37836 Mdot
.59488 .69935 Mdot
.54316 .51027 Mdot
.36468 .59303 Mdot
.58128 .65634 Mdot
.5448 .51099 Mdot
.45574 .40816 Mdot
.43852 .37888 Mdot
.69375 .31786 Mdot
.38298 .5874 Mdot
.4846 .58318 Mdot
.42318 .35587 Mdot
.41126 .39992 Mdot
.47071 .37459 Mdot
.42956 .22211 Mdot
.33899 .35482 Mdot
.46582 .35903 Mdot
.72707 .53573 Mdot
.46278 .44497 Mdot
.43143 .33831 Mdot
.31694 .62531 Mdot
.6373 .35872 Mdot
.4894 .58345 Mdot
.39126 .38055 Mdot
.39249 .36966 Mdot
.55963 .71302 Mdot
.53302 .29515 Mdot
.54763 .40118 Mdot
.67384 .50941 Mdot
.6478 .53424 Mdot
.37684 .39367 Mdot
.38468 .61633 Mdot
.72592 .35695 Mdot
.49202 .35598 Mdot
.40067 .62657 Mdot
.37732 .38453 Mdot
.68909 .57788 Mdot
.47462 .59254 Mdot
.49504 .35628 Mdot
.68773 .37318 Mdot
.57348 .64527 Mdot
.29395 .33118 Mdot
.67893 .52288 Mdot
.45443 .37949 Mdot
.65205 .57635 Mdot
.70609 .54048 Mdot
.49078 .59476 Mdot
.4169 .45925 Mdot
.36709 .62586 Mdot
.34059 .61069 Mdot
.64753 .32472 Mdot
.70917 .56934 Mdot
.68288 .47822 Mdot
.585 .66516 Mdot
.42245 .41252 Mdot
.51487 .66556 Mdot
.34663 .6053 Mdot
.5371 .27702 Mdot
.71262 .39268 Mdot
.59133 .70677 Mdot
.45311 .60395 Mdot
.40072 .60338 Mdot
.34262 .61148 Mdot
.40626 .35898 Mdot
.42385 .37468 Mdot
.62864 .57479 Mdot
.58684 .3116 Mdot
.55581 .6941 Mdot
.7235 .37456 Mdot
.68199 .50716 Mdot
.43936 .42166 Mdot
.38715 .60063 Mdot
.36831 .22461 Mdot
.42241 .4088 Mdot
.69838 .57397 Mdot
.37055 .60526 Mdot
.71663 .35819 Mdot
.69941 .35127 Mdot
.40356 .35227 Mdot
.31439 .29718 Mdot
.58519 .69928 Mdot
.36554 .63247 Mdot
.40887 .57664 Mdot
.43174 .41266 Mdot
.41931 .37606 Mdot
.37751 .32148 Mdot
.5994 .66714 Mdot
.43827 .32321 Mdot
.67301 .3832 Mdot
.34654 .61625 Mdot
.42488 .35859 Mdot
.68301 .37012 Mdot
.35149 .67381 Mdot
.48085 .59319 Mdot
.70894 .52285 Mdot
.67712 .3533 Mdot
.69891 .36818 Mdot
.70514 .39203 Mdot
.52797 .79992 Mdot
.3904 .65596 Mdot
.67607 .24782 Mdot
.42571 .35273 Mdot
.61649 .3025 Mdot
.47687 .37342 Mdot
.58391 .66053 Mdot
.69355 .51246 Mdot
.40216 .36763 Mdot
.42652 .35277 Mdot
.30293 .32857 Mdot
.47347 .39893 Mdot
.46969 .41052 Mdot
.3606 .59489 Mdot
.40206 .5714 Mdot
.67874 .51718 Mdot
.80062 .62591 Mdot
.27652 .25211 Mdot
.3929 .42146 Mdot
.56033 .38587 Mdot
.40033 .60777 Mdot
.56254 .71836 Mdot
.55121 .32394 Mdot
.52165 .68743 Mdot
.36029 .60456 Mdot
.44941 .41825 Mdot
.29542 .34439 Mdot
.68379 .38615 Mdot
.40613 .37958 Mdot
.57109 .68394 Mdot
.40516 .37874 Mdot
.60201 .68069 Mdot
.3001 .58886 Mdot
.542 .42432 Mdot
.4371 .35299 Mdot
.40947 .42873 Mdot
.39711 .27688 Mdot
.42034 .37814 Mdot
.68982 .62678 Mdot
.37248 .60844 Mdot
.424 .46892 Mdot
.46423 .40416 Mdot
.32934 .47346 Mdot
.40405 .40723 Mdot
.50653 .51623 Mdot
.43566 .39258 Mdot
.50173 .18704 Mdot
.40068 .34555 Mdot
.4359 .3959 Mdot
.56492 .70669 Mdot
.55304 .69895 Mdot
.31125 .59766 Mdot
.4941 .58878 Mdot
.47986 .66567 Mdot
.40593 .40267 Mdot
.6611 .52432 Mdot
.51745 .35523 Mdot
.69457 .36525 Mdot
.3484 .61469 Mdot
.55365 .88676 Mdot
.56239 .6633 Mdot
.70443 .57495 Mdot
.57331 .53493 Mdot
.72949 .54557 Mdot
.7308 .56668 Mdot
.35864 .56895 Mdot
.71603 .37387 Mdot
.38579 .38321 Mdot
.31563 .45322 Mdot
.51067 .78733 Mdot
.43343 .41298 Mdot
.65964 .5156 Mdot
.49006 .30062 Mdot
.64707 .31824 Mdot
.67332 .35122 Mdot
.70667 .37777 Mdot
.57076 .70683 Mdot
.68676 .50801 Mdot
.3684 .36416 Mdot
.72194 .38758 Mdot
.68814 .51526 Mdot
.4565 .60412 Mdot
.66046 .33306 Mdot
.35637 .6249 Mdot
.28768 .60303 Mdot
.40191 .52382 Mdot
.55854 .66885 Mdot
.64164 .69978 Mdot
.35822 .65663 Mdot
.40928 .59546 Mdot
.49749 .59593 Mdot
.7213 .54516 Mdot
.38656 .65122 Mdot
.41511 .35281 Mdot
.4752 .43579 Mdot
.38795 .38053 Mdot
.71419 .35273 Mdot
.39882 .40317 Mdot
.69629 .51787 Mdot
.57013 .71599 Mdot
.70147 .56089 Mdot
.57981 .71371 Mdot
.2878 .27308 Mdot
.40274 .34854 Mdot
.41927 .37312 Mdot
.56583 .37518 Mdot
.34484 .61038 Mdot
.30517 .45762 Mdot
.70042 .57287 Mdot
.7017 .5658 Mdot
.46046 .41078 Mdot
.38434 .58171 Mdot
.74692 .35656 Mdot
.56215 .34117 Mdot
.43216 .39541 Mdot
.37436 .60753 Mdot
.46043 .41223 Mdot
.6168 .63253 Mdot
.5197 .4706 Mdot
.34106 .63175 Mdot
.56092 .1568 Mdot
.41583 .34748 Mdot
.39464 .45045 Mdot
.36596 .42033 Mdot
.41984 .23145 Mdot
.47655 .34773 Mdot
.38123 .63886 Mdot
.43225 .33874 Mdot
.3853 .61131 Mdot
.70308 .54762 Mdot
.5727 .65568 Mdot
.3807 .61285 Mdot
.44413 .36772 Mdot
.28178 .24897 Mdot
.56843 .71633 Mdot
.40692 .37351 Mdot
.56149 .68925 Mdot
.4098 .63507 Mdot
.37041 .59366 Mdot
.46262 .60929 Mdot
.55907 .52511 Mdot
.58726 .70542 Mdot
.43468 .41852 Mdot
.49114 .79967 Mdot
.4571 .41787 Mdot
.64969 .5302 Mdot
.41278 .43256 Mdot
.37876 .39568 Mdot
.51019 .15399 Mdot
.51926 .52475 Mdot
.70252 .75786 Mdot
.5261 .64595 Mdot
.48159 .8024 Mdot
.34459 .58015 Mdot
.67297 .35181 Mdot
.47373 .53552 Mdot
.46296 .59723 Mdot
.72568 .52937 Mdot
.40406 .36391 Mdot
.38029 .6778 Mdot
.60177 .71855 Mdot
.69407 .35894 Mdot
.43533 .35053 Mdot
.72958 .5229 Mdot
.43434 .51505 Mdot
.59016 .71123 Mdot
.3527 .62433 Mdot
.35644 .6034 Mdot
.6923 .30065 Mdot
.42735 .3609 Mdot
.42429 .37036 Mdot
.56706 .71726 Mdot
.3743 .33864 Mdot
.70952 .38919 Mdot
.57695 .59575 Mdot
.56924 .68305 Mdot
.52362 .4686 Mdot
.37699 .58574 Mdot
.42517 .38911 Mdot
.56634 .37078 Mdot
.43125 .79742 Mdot
.21022 .54172 Mdot
.69767 .37909 Mdot
.49495 .26061 Mdot
.37951 .63968 Mdot
.56883 .68895 Mdot
.57898 .24182 Mdot
.43602 .43973 Mdot
.42129 .39364 Mdot
.4644 .23511 Mdot
.56 .33908 Mdot
.56865 .53437 Mdot
.38531 .31 Mdot
.55957 .31394 Mdot
.45992 .41184 Mdot
.46255 .38069 Mdot
.37598 .38668 Mdot
.41794 .43402 Mdot
.38071 .60627 Mdot
.33575 .48863 Mdot
.69292 .53299 Mdot
.2228 .53508 Mdot
.65495 .513 Mdot
.45026 .37461 Mdot
.45391 .4127 Mdot
.25354 .51383 Mdot
.53142 .33612 Mdot
.36475 .61509 Mdot
.37573 .57173 Mdot
.55297 .67707 Mdot
.46989 .40681 Mdot
.70351 .57273 Mdot
.36438 .415 Mdot
.71026 .53557 Mdot
.3792 .60546 Mdot
.66883 .56251 Mdot
.55506 .72067 Mdot
.67152 .54298 Mdot
.72493 .53993 Mdot
.58271 .72101 Mdot
.38889 .5898 Mdot
.42988 .40239 Mdot
.58526 .72115 Mdot
.74721 .35132 Mdot
.71301 .35234 Mdot
.42882 .58379 Mdot
.45228 .33723 Mdot
.47053 .41926 Mdot
.64621 .7213 Mdot
.67411 .56298 Mdot
.54183 .39906 Mdot
.39501 .59969 Mdot
.72382 .35584 Mdot
.3846 .60698 Mdot
.66921 .27899 Mdot
.6948 .37537 Mdot
.44641 .60025 Mdot
.54588 .24891 Mdot
.61419 .69796 Mdot
.38739 .4262 Mdot
.4072 .57452 Mdot
.71056 .54042 Mdot
.60372 .69345 Mdot
.49459 .65908 Mdot
.44529 .34236 Mdot
.45933 .58235 Mdot
.41521 .62659 Mdot
.46536 .59434 Mdot
.57113 .68716 Mdot
.4053 .54147 Mdot
.43271 .36737 Mdot
.61362 .69383 Mdot
.40637 .42933 Mdot
.30677 .55971 Mdot
.63439 .56329 Mdot
.44131 .64378 Mdot
.45483 .41498 Mdot
.71718 .52879 Mdot
.45723 .41368 Mdot
.26392 .60474 Mdot
.55349 .26985 Mdot
.37621 .39316 Mdot
.5182 .30742 Mdot
.65226 .6974 Mdot
.3881 .60145 Mdot
.49025 .35692 Mdot
.48624 .58863 Mdot
.45701 .38305 Mdot
.13747 .4374 Mdot
.68453 .36487 Mdot
.6925 .33211 Mdot
.44102 .36236 Mdot
.41855 .35742 Mdot
.30629 .32253 Mdot
.31005 .57767 Mdot
.46725 .61027 Mdot
.41561 .39453 Mdot
.43445 .23812 Mdot
.566 .70568 Mdot
.42792 .43019 Mdot
.39108 .36521 Mdot
.6368 .51989 Mdot
.56256 .69858 Mdot
.66724 .54665 Mdot
.46422 .59366 Mdot
.65872 .54428 Mdot
.70026 .39809 Mdot
.50389 .27571 Mdot
.50689 .25563 Mdot
.50993 .47343 Mdot
.67758 .35421 Mdot
.45105 .38514 Mdot
.4502 .63541 Mdot
.43788 .36706 Mdot
.71034 .37241 Mdot
.56429 .68323 Mdot
.37514 .60975 Mdot
.29541 .5848 Mdot
.4911 .59937 Mdot
.44188 .4039 Mdot
.69247 .34352 Mdot
.37647 .6181 Mdot
.40156 .79769 Mdot
.37748 .59799 Mdot
.58069 .71096 Mdot
.60884 .70167 Mdot
.69401 .37027 Mdot
.38508 .60615 Mdot
.65957 .55194 Mdot
.52759 .65921 Mdot
.37517 .4141 Mdot
.55257 .71831 Mdot
.36352 .65252 Mdot
.34954 .64582 Mdot
.33153 .6116 Mdot
.46444 .39928 Mdot
.54481 .34946 Mdot
.36696 .32158 Mdot
.5672 .71625 Mdot
.72542 .52069 Mdot
.58297 .30188 Mdot
.31414 .41313 Mdot
.53336 .44956 Mdot
.49259 .3684 Mdot
.39735 .40144 Mdot
.38892 .3836 Mdot
.46832 .36128 Mdot
.5536 .59641 Mdot
.40212 .34906 Mdot
.55676 .69065 Mdot
.70321 .53334 Mdot
.42973 .39497 Mdot
.47779 .58656 Mdot
.57672 .55677 Mdot
.7357 .37274 Mdot
.32484 .52761 Mdot
.41635 .57627 Mdot
.37609 .61673 Mdot
.67606 .55652 Mdot
.66624 .56119 Mdot
.72949 .37177 Mdot
.59313 .71256 Mdot
.37254 .59677 Mdot
.50641 .18626 Mdot
.6916 .39003 Mdot
.39177 .38203 Mdot
.56634 .37369 Mdot
.39843 .23755 Mdot
.39238 .4079 Mdot
.39625 .37019 Mdot
.49195 .58553 Mdot
.71245 .56861 Mdot
.19018 .56571 Mdot
.31997 .72824 Mdot
.68982 .36657 Mdot
.72456 .37884 Mdot
.32614 .6172 Mdot
.41667 .414 Mdot
.5846 .69573 Mdot
.52723 .28955 Mdot
.6446 .66831 Mdot
.4626 .67441 Mdot
.64437 .64487 Mdot
.38783 .39166 Mdot
.29577 .53795 Mdot
.40296 .43164 Mdot
.41968 .62632 Mdot
.34454 .60134 Mdot
.36132 .62038 Mdot
.56839 .70964 Mdot
.628 .29749 Mdot
.55643 .68083 Mdot
.48036 .63222 Mdot
.37102 .64037 Mdot
.53459 .52423 Mdot
.70178 .56716 Mdot
.47687 .38305 Mdot
.71455 .37388 Mdot
.67165 .43113 Mdot
.49384 .36346 Mdot
.4978 .26523 Mdot
.66972 .53929 Mdot
.39854 .59699 Mdot
.47625 .37706 Mdot
.48593 .66775 Mdot
.55977 .39297 Mdot
.66012 .6817 Mdot
.39662 .67231 Mdot
.68255 .37271 Mdot
.20745 .49516 Mdot
.70335 .38955 Mdot
.59209 .7055 Mdot
.41304 .34799 Mdot
.41526 .41202 Mdot
.39605 .36228 Mdot
.44269 .43348 Mdot
.56656 .6998 Mdot
.37447 .40989 Mdot
.62434 .35258 Mdot
.46579 .60689 Mdot
.558 .56614 Mdot
.69415 .3528 Mdot
.58506 .66389 Mdot
.70512 .53757 Mdot
.49869 .59984 Mdot
.70877 .34396 Mdot
.47422 .36772 Mdot
.44255 .36837 Mdot
.46574 .60805 Mdot
.47855 .33826 Mdot
.48037 .4035 Mdot
.69564 .5265 Mdot
.57017 .54595 Mdot
.73289 .37997 Mdot
.69767 .38467 Mdot
.59712 .68092 Mdot
.38519 .60689 Mdot
.73099 .37971 Mdot
.69831 .5031 Mdot
.43309 .42871 Mdot
.40341 .4275 Mdot
.36036 .65179 Mdot
.61877 .29952 Mdot
.73594 .37226 Mdot
.44165 .3241 Mdot
.34281 .62203 Mdot
.41569 .62536 Mdot
.41523 .39346 Mdot
.37112 .37425 Mdot
.32483 .60921 Mdot
.72777 .37081 Mdot
.59313 .67314 Mdot
.54492 .46088 Mdot
.56491 .6648 Mdot
.35369 .62958 Mdot
.4724 .43868 Mdot
.38824 .58717 Mdot
.44719 .34339 Mdot
.70864 .77496 Mdot
.39731 .3506 Mdot
.36714 .46227 Mdot
.62567 .47983 Mdot
.7054 .56733 Mdot
.7157 .55686 Mdot
.47415 .5907 Mdot
.4027 .62381 Mdot
.50034 .37791 Mdot
.71697 .37641 Mdot
.48225 .80208 Mdot
.31484 .63619 Mdot
.7243 .53979 Mdot
.69928 .57708 Mdot
.56382 .68611 Mdot
.40118 .40588 Mdot
.42772 .38818 Mdot
.67075 .5443 Mdot
.62712 .60955 Mdot
.39268 .61266 Mdot
.42396 .37008 Mdot
.46845 .36787 Mdot
.69522 .53323 Mdot
.58544 .73818 Mdot
.36963 .65584 Mdot
.46501 .39563 Mdot
.54888 .2731 Mdot
.59294 .66549 Mdot
.45405 .39531 Mdot
.3902 .42855 Mdot
.70007 .36456 Mdot
.48609 .25074 Mdot
.61146 .30163 Mdot
.55315 .66919 Mdot
.46738 .58914 Mdot
.39156 .40467 Mdot
.70929 .56248 Mdot
.46941 .34568 Mdot
.28845 .76219 Mdot
.46117 .60328 Mdot
.43204 .36966 Mdot
.37738 .3447 Mdot
.34689 .63066 Mdot
.42295 .36243 Mdot
.59704 .63962 Mdot
.67932 .54049 Mdot
.43305 .3708 Mdot
.31329 .3032 Mdot
.56463 .68591 Mdot
.49112 .3591 Mdot
.68054 .38082 Mdot
.55809 .52861 Mdot
.25881 .29851 Mdot
.70014 .49529 Mdot
.68428 .35635 Mdot
.40455 .40603 Mdot
.66881 .51336 Mdot
.56556 .72269 Mdot
.3435 .40046 Mdot
.45168 .39067 Mdot
.56056 .66892 Mdot
.57457 .71693 Mdot
.68962 .37031 Mdot
.6568 .82455 Mdot
.37476 .38661 Mdot
.41132 .37957 Mdot
.54408 .84107 Mdot
.32253 .6094 Mdot
.40523 .3743 Mdot
.41534 .40677 Mdot
.59925 .69789 Mdot
.63851 .26696 Mdot
.49479 .26111 Mdot
.57275 .59699 Mdot
.59735 .67159 Mdot
.65292 .54411 Mdot
.677 .5345 Mdot
.68093 .36008 Mdot
.37009 .60479 Mdot
.72368 .35724 Mdot
.68889 .54359 Mdot
.3953 .36662 Mdot
.58702 .67624 Mdot
.21719 .39394 Mdot
.59483 .71862 Mdot
.71031 .50271 Mdot
.41715 .62904 Mdot
.23727 .61486 Mdot
.31693 .79363 Mdot
.41907 .50935 Mdot
.60379 .67171 Mdot
.69479 .36506 Mdot
.3346 .74701 Mdot
.43031 .39535 Mdot
.27535 .58199 Mdot
.40792 .3797 Mdot
.35728 .67778 Mdot
.6924 .51313 Mdot
.45729 .60549 Mdot
.44643 .34256 Mdot
.49128 .25876 Mdot
.58425 .71918 Mdot
.58278 .68544 Mdot
.43322 .33906 Mdot
.58266 .70958 Mdot
.43057 .38148 Mdot
.69979 .5354 Mdot
.68543 .78996 Mdot
.43979 .38835 Mdot
.40293 .46103 Mdot
.60535 .66904 Mdot
.41702 .57191 Mdot
.65312 .56834 Mdot
.32156 .50203 Mdot
.46744 .68063 Mdot
.58348 .69672 Mdot
.33647 .52085 Mdot
.67918 .56368 Mdot
.5001 .59782 Mdot
.65518 .54961 Mdot
.41527 .38573 Mdot
.39015 .39684 Mdot
.46782 .35794 Mdot
.41066 .40616 Mdot
.26175 .57388 Mdot
.48274 .3969 Mdot
.23768 .43465 Mdot
.42585 .35303 Mdot
.37707 .47228 Mdot
.55706 .68346 Mdot
.39095 .44717 Mdot
.55934 .46421 Mdot
.38637 .35912 Mdot
.35867 .57274 Mdot
.58153 .66302 Mdot
.54116 .74885 Mdot
.56525 .70049 Mdot
.70341 .56013 Mdot
.58356 .71717 Mdot
.4235 .34409 Mdot
.3513 .61823 Mdot
.68417 .55522 Mdot
.41729 .50541 Mdot
.7209 .51712 Mdot
.43108 .36353 Mdot
.61637 .69929 Mdot
.68855 .57423 Mdot
.46378 .4264 Mdot
.35262 .61469 Mdot
.4724 .22102 Mdot
.42967 .61825 Mdot
.41632 .36346 Mdot
.41073 .36619 Mdot
.468 .60961 Mdot
.58766 .71501 Mdot
.37973 .58391 Mdot
.63786 .51053 Mdot
.71753 .34915 Mdot
.36437 .6117 Mdot
.36675 .42302 Mdot
.56239 .38533 Mdot
.34383 .63174 Mdot
.41854 .23817 Mdot
.59463 .70188 Mdot
.35608 .64198 Mdot
.35661 .37562 Mdot
.22381 .52885 Mdot
.69769 .38688 Mdot
.66048 .5599 Mdot
.56812 .32905 Mdot
.67751 .53604 Mdot
.59381 .64336 Mdot
.67907 .58374 Mdot
.5602 .69687 Mdot
.50914 .33092 Mdot
.54394 .51124 Mdot
.60058 .71421 Mdot
.59966 .65783 Mdot
.68847 .53164 Mdot
.4576 .34344 Mdot
.55914 .55393 Mdot
.50178 .38431 Mdot
.47939 .43795 Mdot
.56728 .66182 Mdot
.36434 .64371 Mdot
.3966 .58686 Mdot
.4361 .47037 Mdot
.35531 .60146 Mdot
.69395 .55297 Mdot
.49931 .47711 Mdot
.34195 .52796 Mdot
.56649 .67848 Mdot
.57954 .54086 Mdot
.45716 .41016 Mdot
.70173 .52132 Mdot
.69673 .55357 Mdot
.57407 .71571 Mdot
.23344 .56159 Mdot
.49581 .4121 Mdot
.31545 .61042 Mdot
.36022 .64007 Mdot
.34714 .63355 Mdot
.36697 .58734 Mdot
.62969 .29501 Mdot
.60355 .69289 Mdot
.39673 .62903 Mdot
.44859 .42969 Mdot
.40905 .4113 Mdot
.47425 .602 Mdot
.72029 .36012 Mdot
.44074 .4379 Mdot
.50017 .37623 Mdot
.41696 .39288 Mdot
.7024 .56968 Mdot
.45646 .27633 Mdot
.46888 .60685 Mdot
.70838 .57056 Mdot
.70938 .56815 Mdot
.46924 .59006 Mdot
.50534 .32201 Mdot
.19688 .56727 Mdot
.42795 .34029 Mdot
.36272 .56813 Mdot
.71742 .55144 Mdot
.64389 .41703 Mdot
.38985 .48804 Mdot
.42603 .4197 Mdot
.57599 .58182 Mdot
.69999 .54207 Mdot
.34194 .58231 Mdot
.41786 .38199 Mdot
.49592 .59509 Mdot
.68889 .38486 Mdot
.35004 .34257 Mdot
.49222 .58609 Mdot
.39003 .60526 Mdot
.70322 .47726 Mdot
.36502 .64689 Mdot
.67435 .57355 Mdot
.49667 .36908 Mdot
.83613 .67757 Mdot
.70998 .54366 Mdot
.49723 .80605 Mdot
.54486 .51363 Mdot
.43987 .38153 Mdot
.67593 .54934 Mdot
.31872 .63471 Mdot
.5929 .66481 Mdot
.55359 .35901 Mdot
.38561 .60047 Mdot
.49837 .60103 Mdot
.47605 .59974 Mdot
.69374 .53221 Mdot
.36739 .63676 Mdot
.38297 .42275 Mdot
.35694 .60409 Mdot
.5825 .67631 Mdot
.44936 .35087 Mdot
.47897 .66646 Mdot
.41806 .45962 Mdot
.35014 .60894 Mdot
.71976 .51115 Mdot
.68155 .3927 Mdot
.44622 .36755 Mdot
.52396 .72733 Mdot
.40534 .407 Mdot
.56191 .68704 Mdot
.62843 .45422 Mdot
.22042 .39621 Mdot
.39673 .38686 Mdot
.45683 .40904 Mdot
.55844 .72218 Mdot
.39856 .38814 Mdot
.39317 .4146 Mdot
.40336 .54125 Mdot
.3429 .63012 Mdot
.42689 .39647 Mdot
.68087 .52342 Mdot
.26343 .34478 Mdot
.40675 .35331 Mdot
.60087 .63951 Mdot
.45916 .22905 Mdot
.61257 .42936 Mdot
.48647 .44141 Mdot
.53959 .27876 Mdot
.41061 .37039 Mdot
.42559 .41809 Mdot
.4301 .33969 Mdot
.29376 .54441 Mdot
.68694 .53917 Mdot
.71418 .52279 Mdot
.67241 .37407 Mdot
.45745 .2324 Mdot
.68998 .37916 Mdot
.57211 .72796 Mdot
.56952 .53256 Mdot
.47815 .60884 Mdot
.38569 .60803 Mdot
.40323 .35715 Mdot
.7153 .51247 Mdot
.42414 .38735 Mdot
.45672 .38641 Mdot
.69331 .54897 Mdot
.70069 .54833 Mdot
.7092 .49512 Mdot
.68318 .38673 Mdot
.36888 .61599 Mdot
.41364 .34548 Mdot
.69279 .39192 Mdot
.47008 .36839 Mdot
.54653 .44242 Mdot
.36608 .6167 Mdot
.34983 .60809 Mdot
.40809 .60151 Mdot
.44448 .38747 Mdot
.44056 .34313 Mdot
.55671 .67952 Mdot
.36139 .65183 Mdot
.58858 .70042 Mdot
.67569 .54756 Mdot
.69542 .52082 Mdot
.41445 .38576 Mdot
.37901 .33504 Mdot
.70154 .35234 Mdot
.68027 .56929 Mdot
.46461 .58402 Mdot
.67475 .37675 Mdot
.38688 .37999 Mdot
.6761 .54135 Mdot
.69646 .34764 Mdot
.21919 .56218 Mdot
.41578 .69151 Mdot
.67292 .37975 Mdot
.44008 .3391 Mdot
.3063 .39165 Mdot
.56247 .27729 Mdot
.73676 .36766 Mdot
.56029 .68032 Mdot
.42321 .40575 Mdot
.5572 .60976 Mdot
.71891 .39086 Mdot
.60488 .2984 Mdot
.68881 .55025 Mdot
.45196 .45315 Mdot
.37431 .30041 Mdot
.34961 .52635 Mdot
.68713 .39496 Mdot
.3489 .61168 Mdot
.33727 .63356 Mdot
.39286 .3828 Mdot
.56363 .53005 Mdot
.58055 .72842 Mdot
.66559 .56043 Mdot
.71402 .51898 Mdot
.3352 .62734 Mdot
.51298 .47301 Mdot
.67919 .52615 Mdot
.42171 .41364 Mdot
.71056 .40115 Mdot
.46757 .41258 Mdot
.66475 .30281 Mdot
.2511 .33655 Mdot
.47873 .44774 Mdot
.67813 .39036 Mdot
.57064 .72277 Mdot
.56684 .7115 Mdot
.57442 .71174 Mdot
.69002 .52321 Mdot
.55318 .32323 Mdot
.70798 .51324 Mdot
.50166 .83607 Mdot
.68254 .36619 Mdot
.53242 .18725 Mdot
.4246 .43728 Mdot
.43987 .37852 Mdot
.44306 .42511 Mdot
.46575 .36193 Mdot
.41212 .37068 Mdot
.55692 .67268 Mdot
.66183 .52962 Mdot
.64421 .65636 Mdot
.38186 .62782 Mdot
.39453 .79433 Mdot
.70026 .56808 Mdot
.48888 .58362 Mdot
.71073 .3582 Mdot
.4837 .23794 Mdot
.67152 .39412 Mdot
.67618 .5697 Mdot
.38024 .39093 Mdot
.3248 .62017 Mdot
.49631 .18737 Mdot
.41435 .35648 Mdot
.67629 .56645 Mdot
.65878 .52137 Mdot
.22377 .54634 Mdot
.39979 .30645 Mdot
.62984 .60119 Mdot
.55772 .38169 Mdot
.66831 .37329 Mdot
.44818 .33361 Mdot
.51771 .27901 Mdot
.68976 .54138 Mdot
.7154 .54033 Mdot
.73067 .35821 Mdot
.29477 .6447 Mdot
.39045 .63163 Mdot
.43836 .59091 Mdot
.56832 .66826 Mdot
.44149 .37127 Mdot
.68431 .52976 Mdot
.43606 .60318 Mdot
.57353 .41095 Mdot
.57115 .70149 Mdot
.70098 .57568 Mdot
.40798 .408 Mdot
.39684 .38975 Mdot
.68836 .37676 Mdot
.60716 .50945 Mdot
.50175 .38457 Mdot
.48532 .80266 Mdot
.53686 .42446 Mdot
.54621 .51399 Mdot
.42168 .39362 Mdot
.37469 .58743 Mdot
.47052 .5901 Mdot
.71675 .36993 Mdot
.47324 .3521 Mdot
.24917 .63876 Mdot
.39758 .63362 Mdot
.58746 .70204 Mdot
.47498 .58431 Mdot
.5073 .28263 Mdot
.40796 .40719 Mdot
.40842 .38005 Mdot
.46405 .40163 Mdot
.22004 .60568 Mdot
.69695 .5138 Mdot
.36538 .58963 Mdot
.68037 .37692 Mdot
.3719 .59415 Mdot
.68467 .58092 Mdot
.57859 .54313 Mdot
.41017 .34365 Mdot
.40933 .61886 Mdot
.36609 .59994 Mdot
.56492 .68397 Mdot
.58454 .72184 Mdot
.68995 .49965 Mdot
.41971 .4043 Mdot
.48078 .60918 Mdot
.38265 .63752 Mdot
.66177 .54642 Mdot
.69003 .37666 Mdot
.58898 .64068 Mdot
.42871 .35365 Mdot
.69127 .53472 Mdot
.49642 .3664 Mdot
.37613 .62605 Mdot
.68889 .57141 Mdot
.50088 .5946 Mdot
.72626 .36796 Mdot
.39123 .40074 Mdot
.65802 .65853 Mdot
.49391 .5909 Mdot
.44628 .37545 Mdot
.24411 .35355 Mdot
.5637 .53059 Mdot
.35852 .66732 Mdot
.68206 .5169 Mdot
.49363 .60149 Mdot
.34934 .59917 Mdot
.22065 .50613 Mdot
.71324 .53341 Mdot
.29953 .34385 Mdot
.53554 .50563 Mdot
.43908 .33998 Mdot
.38797 .60269 Mdot
.67322 .32619 Mdot
.45329 .79089 Mdot
.5705 .28749 Mdot
.43025 .37365 Mdot
.67785 .53519 Mdot
.69124 .38473 Mdot
.58418 .68664 Mdot
.54873 .65234 Mdot
.69233 .29245 Mdot
.72237 .55264 Mdot
.40231 .35721 Mdot
.36293 .6434 Mdot
.58593 .70602 Mdot
.29571 .32873 Mdot
.68867 .50666 Mdot
.67633 .52708 Mdot
.42579 .42633 Mdot
.6913 .38048 Mdot
.53818 .61373 Mdot
.70316 .51644 Mdot
.66226 .52559 Mdot
.4033 .53551 Mdot
.66973 .36725 Mdot
.46512 .3891 Mdot
.43563 .47051 Mdot
.41903 .43265 Mdot
.45495 .81954 Mdot
.49237 .60329 Mdot
.38504 .62611 Mdot
.40275 .36962 Mdot
.65128 .70916 Mdot
.70841 .53337 Mdot
.55679 .38281 Mdot
.59173 .73676 Mdot
.58664 .72025 Mdot
.68021 .54228 Mdot
.42435 .38119 Mdot
.55678 .72739 Mdot
.68451 .3584 Mdot
.46572 .3883 Mdot
.44579 .34351 Mdot
.34828 .65136 Mdot
.58416 .67452 Mdot
.26198 .34197 Mdot
.58689 .68573 Mdot
.60051 .69131 Mdot
.40162 .64562 Mdot
.39257 .38306 Mdot
.6919 .56893 Mdot
.73322 .53007 Mdot
.43308 .32392 Mdot
.6614 .42972 Mdot
.40022 .62181 Mdot
.68352 .59484 Mdot
.24543 .63841 Mdot
.3958 .42249 Mdot
.46424 .58585 Mdot
.42276 .65732 Mdot
.6081 .70596 Mdot
.39596 .37875 Mdot
.38623 .6123 Mdot
.67165 .51489 Mdot
.68137 .5281 Mdot
.43905 .43899 Mdot
.56915 .715 Mdot
.70425 .34836 Mdot
.69489 .55653 Mdot
.53969 .46864 Mdot
.43068 .3665 Mdot
.5245 .69935 Mdot
.69336 .559 Mdot
.2878 .24864 Mdot
.64892 .71884 Mdot
.34577 .63435 Mdot
.44371 .41736 Mdot
.3347 .63585 Mdot
.67572 .36215 Mdot
.66346 .57488 Mdot
.55734 .69655 Mdot
.45901 .31679 Mdot
.78966 .63918 Mdot
.6897 .52603 Mdot
.37854 .60665 Mdot
.39856 .36477 Mdot
.34242 .51506 Mdot
.43475 .39325 Mdot
.63726 .26165 Mdot
.73701 .37356 Mdot
.6016 .64799 Mdot
.56631 .71609 Mdot
.45537 .40917 Mdot
.70574 .39118 Mdot
.73098 .5205 Mdot
.69295 .54802 Mdot
.7653 .69942 Mdot
.49502 .588 Mdot
.72622 .57314 Mdot
.44472 .38411 Mdot
.66386 .54879 Mdot
.315 .41479 Mdot
.5765 .71851 Mdot
.41286 .43039 Mdot
.72441 .55753 Mdot
.40975 .78721 Mdot
.56065 .38201 Mdot
.43077 .36938 Mdot
.37273 .34316 Mdot
.56154 .69275 Mdot
.33342 .74589 Mdot
.68712 .51256 Mdot
.47265 .36436 Mdot
.5832 .73396 Mdot
.5194 .36657 Mdot
.62951 .51776 Mdot
.36842 .61642 Mdot
.71742 .56895 Mdot
.59061 .67171 Mdot
.44481 .45609 Mdot
.71237 .35424 Mdot
.69212 .50291 Mdot
.72783 .5331 Mdot
.45063 .35906 Mdot
.47033 .38629 Mdot
.3669 .34934 Mdot
.39712 .60921 Mdot
.59881 .69345 Mdot
.45972 .38145 Mdot
.54798 .43206 Mdot
.46441 .3644 Mdot
.59689 .6844 Mdot
.7411 .78047 Mdot
.38144 .39096 Mdot
.43257 .35681 Mdot
.32809 .51687 Mdot
.3834 .5833 Mdot
.33964 .62398 Mdot
.53757 .43427 Mdot
.43563 .40145 Mdot
.5303 .52404 Mdot
.37244 .61409 Mdot
.37859 .60272 Mdot
.53158 .52407 Mdot
.44562 .3501 Mdot
.44986 .58725 Mdot
.58512 .70763 Mdot
.58652 .7206 Mdot
.34675 .63015 Mdot
.46705 .41095 Mdot
.56629 .72259 Mdot
.25498 .5516 Mdot
.68178 .5726 Mdot
.51278 .27664 Mdot
.36178 .60108 Mdot
.56952 .36974 Mdot
.59308 .70488 Mdot
.31432 .25408 Mdot
.41207 .23228 Mdot
.38318 .41257 Mdot
.39413 .38325 Mdot
.70085 .3676 Mdot
.47279 .32972 Mdot
.46721 .59203 Mdot
.5763 .71318 Mdot
.55391 .59526 Mdot
.36047 .6207 Mdot
.43424 .40066 Mdot
.58523 .30686 Mdot
.26105 .30082 Mdot
.39458 .46641 Mdot
.37202 .60353 Mdot
.3551 .62002 Mdot
.67197 .53122 Mdot
.67389 .56985 Mdot
.40941 .34455 Mdot
.56295 .70479 Mdot
.35034 .63978 Mdot
.59344 .68243 Mdot
.68981 .54316 Mdot
.69825 .56715 Mdot
.46676 .60417 Mdot
.48863 .42992 Mdot
.68289 .5457 Mdot
.61896 .64533 Mdot
.54766 .43371 Mdot
.36751 .65274 Mdot
.52967 .84085 Mdot
.33358 .24121 Mdot
.30348 .56844 Mdot
.69035 .3851 Mdot
.51262 .33869 Mdot
.55093 .69084 Mdot
.4571 .40611 Mdot
.40564 .38418 Mdot
.48582 .5993 Mdot
.55193 .69945 Mdot
.70227 .35886 Mdot
.58166 .72005 Mdot
.72066 .37098 Mdot
.717 .5263 Mdot
.40773 .35459 Mdot
.38884 .35805 Mdot
.58137 .68535 Mdot
.66775 .54847 Mdot
.68956 .57418 Mdot
.70612 .3859 Mdot
.47733 .23435 Mdot
.69346 .53434 Mdot
.36364 .59973 Mdot
.2752 .36689 Mdot
.47771 .60024 Mdot
.4182 .38126 Mdot
.53565 .27498 Mdot
.22372 .48586 Mdot
.4654 .35179 Mdot
.4815 .58424 Mdot
.66273 .82195 Mdot
.40928 .35182 Mdot
.81622 .59373 Mdot
.47627 .608 Mdot
.38781 .58665 Mdot
.6829 .56369 Mdot
.49137 .58646 Mdot
.43887 .27295 Mdot
.63823 .58341 Mdot
.44616 .32892 Mdot
.39324 .6302 Mdot
.40498 .60195 Mdot
.57461 .54432 Mdot
.45167 .81929 Mdot
.68065 .37778 Mdot
.69135 .35816 Mdot
.70986 .52958 Mdot
.56752 .63778 Mdot
.461 .42146 Mdot
.69069 .36021 Mdot
.45013 .57636 Mdot
.45482 .4139 Mdot
.56456 .53252 Mdot
.55795 .55988 Mdot
.34635 .60429 Mdot
.39301 .44633 Mdot
.70947 .53151 Mdot
.37666 .60748 Mdot
.56352 .54916 Mdot
.42692 .42896 Mdot
.36376 .61821 Mdot
.59713 .70511 Mdot
.49685 .53714 Mdot
.35735 .60196 Mdot
.55629 .36608 Mdot
.58171 .69119 Mdot
.57154 .53593 Mdot
.57449 .22175 Mdot
.19296 .33209 Mdot
.56801 .71129 Mdot
.67577 .56303 Mdot
.68517 .53059 Mdot
.69719 .53331 Mdot
.39228 .60235 Mdot
.70485 .54611 Mdot
.38622 .62961 Mdot
.58433 .65104 Mdot
.47529 .24311 Mdot
.69502 .37258 Mdot
.65019 .34461 Mdot
.34742 .62335 Mdot
.48787 .83249 Mdot
.44829 .8615 Mdot
.46637 .37084 Mdot
.60219 .71071 Mdot
.68402 .39024 Mdot
.52967 .43177 Mdot
.70103 .36523 Mdot
.67853 .5628 Mdot
.49883 .26912 Mdot
.43089 .38263 Mdot
.46404 .6554 Mdot
.69174 .3843 Mdot
.37897 .60111 Mdot
.45072 .37835 Mdot
.71978 .57016 Mdot
.67955 .35964 Mdot
.70236 .38462 Mdot
.41293 .37249 Mdot
.3968 .59457 Mdot
.68504 .57103 Mdot
.55204 .67571 Mdot
.69762 .40555 Mdot
.40044 .31507 Mdot
.40043 .35355 Mdot
.37739 .37529 Mdot
.55453 .39217 Mdot
.55596 .63708 Mdot
.58068 .69308 Mdot
.60373 .30183 Mdot
.6998 .52056 Mdot
.57162 .28603 Mdot
.47757 .79055 Mdot
.68352 .32468 Mdot
.49091 .60363 Mdot
.49151 .60441 Mdot
.42304 .36561 Mdot
.33576 .79729 Mdot
.3665 .45136 Mdot
.60154 .73409 Mdot
.48139 .59752 Mdot
.68189 .57478 Mdot
.36047 .64954 Mdot
.37782 .30148 Mdot
.43367 .4383 Mdot
.55047 .67823 Mdot
.694 .54161 Mdot
.28309 .75852 Mdot
.68298 .36851 Mdot
.52707 .4419 Mdot
.41624 .40494 Mdot
.42194 .37148 Mdot
.5722 .6953 Mdot
.55707 .69333 Mdot
.40207 .53371 Mdot
.60864 .41377 Mdot
.4675 .67543 Mdot
.54662 .67646 Mdot
.2815 .75789 Mdot
.38723 .67595 Mdot
.35849 .63134 Mdot
.4638 .59048 Mdot
.5777 .72666 Mdot
.40408 .37244 Mdot
.38888 .58589 Mdot
.35717 .43306 Mdot
.35878 .58018 Mdot
.55831 .52812 Mdot
.54434 .46132 Mdot
.39784 .40155 Mdot
.33629 .60482 Mdot
.37183 .61045 Mdot
.40896 .58506 Mdot
.47113 .59429 Mdot
.41849 .39501 Mdot
.47062 .35703 Mdot
.41184 .34916 Mdot
.39286 .50707 Mdot
.42339 .36218 Mdot
.4721 .79089 Mdot
.53592 .45132 Mdot
.77039 .41559 Mdot
.41732 .35259 Mdot
.59939 .70326 Mdot
.40583 .35793 Mdot
.71321 .38853 Mdot
.38751 .39801 Mdot
.55463 .52416 Mdot
.58105 .70469 Mdot
.26055 .61216 Mdot
.65862 .51202 Mdot
.39001 .35941 Mdot
.67962 .3523 Mdot
.57368 .81365 Mdot
.59959 .30608 Mdot
.40525 .53652 Mdot
.3572 .60406 Mdot
.66412 .51862 Mdot
.59034 .72797 Mdot
.70325 .56153 Mdot
.37752 .41712 Mdot
.46114 .59796 Mdot
.5109 .15861 Mdot
.57832 .36958 Mdot
.40363 .37026 Mdot
.49394 .41678 Mdot
.35304 .60092 Mdot
.70897 .53666 Mdot
.29983 .58868 Mdot
.44952 .42136 Mdot
.7283 .36479 Mdot
.70556 .39418 Mdot
.75281 .56605 Mdot
.46843 .54365 Mdot
.33964 .44316 Mdot
.57414 .69569 Mdot
.68708 .52353 Mdot
.6972 .39606 Mdot
.41715 .58031 Mdot
.58608 .72662 Mdot
.60815 .70658 Mdot
.5832 .67324 Mdot
.4349 .36601 Mdot
.47107 .60388 Mdot
.47778 .55897 Mdot
.49713 .59278 Mdot
.43709 .43195 Mdot
.72813 .53547 Mdot
.49969 .59703 Mdot
.70066 .37451 Mdot
.59663 .67815 Mdot
.70192 .5688 Mdot
.41249 .36389 Mdot
.37374 .61766 Mdot
.64016 .32625 Mdot
.65642 .71326 Mdot
.56534 .53093 Mdot
.56546 .53098 Mdot
.41381 .62032 Mdot
.49714 .62986 Mdot
.57453 .64327 Mdot
.22193 .53748 Mdot
.74861 .36579 Mdot
.46683 .33382 Mdot
.7165 .46953 Mdot
.70595 .51204 Mdot
.68584 .55589 Mdot
.43475 .38157 Mdot
.66559 .53421 Mdot
.43251 .39915 Mdot
.68037 .51731 Mdot
.44979 .80037 Mdot
.40477 .43482 Mdot
.69199 .55394 Mdot
.41289 .30272 Mdot
.446 .36778 Mdot
.37201 .58914 Mdot
.68129 .50919 Mdot
.38384 .41336 Mdot
.62596 .16301 Mdot
.56733 .6826 Mdot
.47158 .59542 Mdot
.54954 .49576 Mdot
.58891 .71088 Mdot
.37933 .63544 Mdot
.42408 .40929 Mdot
.68061 .36613 Mdot
.35415 .62914 Mdot
.66179 .59156 Mdot
.69505 .38311 Mdot
.49857 .47925 Mdot
.35066 .63098 Mdot
.47997 .60241 Mdot
.72744 .37273 Mdot
.44435 .32845 Mdot
.68735 .55418 Mdot
.65155 .72148 Mdot
.48402 .58369 Mdot
.42841 .38601 Mdot
.7089 .57656 Mdot
.58412 .71846 Mdot
.38928 .36969 Mdot
.68343 .52899 Mdot
.47018 .58703 Mdot
.43871 .35843 Mdot
.44566 .39069 Mdot
.29286 .63377 Mdot
.63333 .46392 Mdot
.69736 .37364 Mdot
.41502 .63116 Mdot
.44243 .43287 Mdot
.70379 .39072 Mdot
.642 .63403 Mdot
.37033 .41511 Mdot
.39189 .63438 Mdot
.24566 .55385 Mdot
.66501 .55744 Mdot
.57098 .71854 Mdot
.71366 .50437 Mdot
.67202 .36893 Mdot
.50913 .87595 Mdot
.46507 .59421 Mdot
.38157 .3488 Mdot
.39392 .41694 Mdot
.65659 .56217 Mdot
.36833 .61167 Mdot
.46592 .67417 Mdot
.39363 .40474 Mdot
.47349 .43486 Mdot
.41531 .37731 Mdot
.65524 .64033 Mdot
.39509 .60523 Mdot
.41637 .37986 Mdot
.42201 .31786 Mdot
.40213 .4261 Mdot
.69322 .34953 Mdot
.52819 .18512 Mdot
.45579 .34505 Mdot
.87856 .62028 Mdot
.45497 .59935 Mdot
.69623 .54555 Mdot
.55519 .37101 Mdot
.55723 .49334 Mdot
.76596 .32068 Mdot
.39106 .6292 Mdot
.37692 .56833 Mdot
.69666 .5668 Mdot
.69064 .30997 Mdot
.50278 .62755 Mdot
.44858 .38807 Mdot
.41671 .40766 Mdot
.67861 .56287 Mdot
.66128 .54893 Mdot
.45726 .59775 Mdot
.42429 .33712 Mdot
.41319 .45743 Mdot
.72177 .51436 Mdot
.41824 .35731 Mdot
.22255 .46082 Mdot
.60282 .67685 Mdot
.34437 .62928 Mdot
.58288 .68423 Mdot
.59767 .66921 Mdot
.2963 .5839 Mdot
.53999 .41742 Mdot
.56432 .66853 Mdot
.61182 .70778 Mdot
.66411 .32995 Mdot
.34304 .5255 Mdot
.69712 .34924 Mdot
.4532 .52266 Mdot
.70037 .52685 Mdot
.41641 .39513 Mdot
.39409 .6022 Mdot
.67092 .24889 Mdot
.47313 .70029 Mdot
.41679 .26058 Mdot
.46443 .39161 Mdot
.70522 .53112 Mdot
.47801 .58315 Mdot
.37049 .41609 Mdot
.56514 .27992 Mdot
.42691 .37142 Mdot
.6679 .56469 Mdot
.34314 .52753 Mdot
.63158 .73467 Mdot
.54871 .66516 Mdot
.31523 .6255 Mdot
.40443 .35801 Mdot
.39219 .61613 Mdot
.57424 .66177 Mdot
.69097 .38903 Mdot
.69325 .36554 Mdot
.38819 .3612 Mdot
.54433 .51363 Mdot
.75143 .33029 Mdot
.44905 .38384 Mdot
.44922 .35492 Mdot
.49151 .602 Mdot
.44935 .35397 Mdot
.46725 .3476 Mdot
.46075 .38499 Mdot
.47032 .37325 Mdot
.58212 .7269 Mdot
.31967 .55888 Mdot
.41044 .33828 Mdot
.3728 .36961 Mdot
.5751 .65543 Mdot
.37047 .39529 Mdot
.56592 .70293 Mdot
.48437 .6835 Mdot
.56375 .67123 Mdot
.69304 .36705 Mdot
.71029 .5769 Mdot
.34564 .56012 Mdot
.35098 .63974 Mdot
.59656 .7131 Mdot
.72273 .3657 Mdot
.57177 .71241 Mdot
.68973 .51882 Mdot
.64444 .70544 Mdot
.37024 .6617 Mdot
.53246 .47469 Mdot
.32669 .52819 Mdot
.55372 .74581 Mdot
.66711 .53624 Mdot
.34815 .63547 Mdot
.59374 .6392 Mdot
.45604 .40646 Mdot
.68052 .37268 Mdot
.42256 .36617 Mdot
.59905 .68322 Mdot
.70252 .52931 Mdot
.40235 .5558 Mdot
.69831 .37288 Mdot
.5651 .84247 Mdot
.71471 .51142 Mdot
.38876 .40793 Mdot
.57245 .65633 Mdot
.63366 .65195 Mdot
.5598 .69058 Mdot
.4768 .24226 Mdot
.44896 .63901 Mdot
.68001 .26546 Mdot
.35231 .62301 Mdot
.49558 .58359 Mdot
.16454 .41485 Mdot
.52251 .7634 Mdot
.37524 .62296 Mdot
.70425 .48164 Mdot
.4264 .36011 Mdot
.4642 .37681 Mdot
.48748 .42844 Mdot
.37623 .57972 Mdot
.46385 .40246 Mdot
.469 .59781 Mdot
.54399 .41754 Mdot
.50054 .57341 Mdot
.67335 .50804 Mdot
.43213 .39772 Mdot
.56632 .66215 Mdot
.59844 .7121 Mdot
.49884 .60277 Mdot
.58676 .68145 Mdot
.43477 .34909 Mdot
.34877 .62367 Mdot
.55992 .55308 Mdot
.67571 .36389 Mdot
.50962 .79986 Mdot
.74869 .34568 Mdot
.66725 .39252 Mdot
.39794 .42457 Mdot
.6959 .56847 Mdot
.79488 .6171 Mdot
.46016 .40307 Mdot
.37485 .61154 Mdot
.39565 .41736 Mdot
.46195 .37623 Mdot
.42145 .34281 Mdot
.68777 .52361 Mdot
.56355 .37923 Mdot
.41723 .35685 Mdot
.56796 .66565 Mdot
.53265 .52176 Mdot
.44001 .43739 Mdot
.57837 .59372 Mdot
.55543 .5256 Mdot
.52933 .71253 Mdot
.35596 .65319 Mdot
.68925 .56765 Mdot
.35818 .62197 Mdot
.33702 .59583 Mdot
.37868 .63553 Mdot
.49069 .5641 Mdot
.2218 .52695 Mdot
.82287 .58287 Mdot
.31933 .42177 Mdot
.32036 .53275 Mdot
.31734 .62602 Mdot
.72528 .62258 Mdot
.38111 .61962 Mdot
.38329 .63363 Mdot
.72235 .77333 Mdot
.40271 .60865 Mdot
.41509 .38662 Mdot
.38096 .36726 Mdot
.23506 .61141 Mdot
.66114 .39151 Mdot
.44483 .377 Mdot
.46923 .3648 Mdot
.70242 .39537 Mdot
.2975 .62527 Mdot
.45859 .58989 Mdot
.52368 .45133 Mdot
.49256 .5839 Mdot
.41307 .37168 Mdot
.39045 .38984 Mdot
.48153 .36067 Mdot
.22195 .3348 Mdot
.69382 .27733 Mdot
.40608 .59982 Mdot
.45617 .32843 Mdot
.58147 .7578 Mdot
.41738 .41862 Mdot
.40381 .42232 Mdot
.42651 .34304 Mdot
.69207 .56898 Mdot
.38046 .645 Mdot
.50096 .37921 Mdot
.52835 .78569 Mdot
.40501 .40516 Mdot
.74644 .33599 Mdot
.67429 .34545 Mdot
.42374 .38231 Mdot
.40482 .61149 Mdot
.46468 .38093 Mdot
.34394 .64075 Mdot
.35317 .63292 Mdot
.45337 .44823 Mdot
.46571 .55782 Mdot
.36077 .64902 Mdot
.44794 .38973 Mdot
.667 .54593 Mdot
.48968 .80407 Mdot
.4277 .3852 Mdot
.69984 .3786 Mdot
.39494 .37521 Mdot
.68757 .34981 Mdot
.4539 .35057 Mdot
.49823 .59643 Mdot
.21412 .40425 Mdot
.7158 .53797 Mdot
.67795 .39972 Mdot
.66455 .54101 Mdot
.47233 .41009 Mdot
.33363 .64051 Mdot
.61947 .74332 Mdot
.70354 .28894 Mdot
.49043 .60251 Mdot
.62063 .30275 Mdot
.52805 .5361 Mdot
.55337 .68593 Mdot
.36308 .5901 Mdot
.3318 .54189 Mdot
.57699 .59066 Mdot
.66941 .50963 Mdot
.6961 .57758 Mdot
.64322 .49659 Mdot
.68574 .78981 Mdot
.42218 .35492 Mdot
.56548 .60798 Mdot
.23689 .42627 Mdot
.47583 .3336 Mdot
.38593 .30895 Mdot
.72742 .52966 Mdot
.44506 .37699 Mdot
.58058 .34847 Mdot
.68786 .5329 Mdot
.6995 .35414 Mdot
.3872 .62467 Mdot
.71501 .38345 Mdot
.41671 .7062 Mdot
.40197 .53984 Mdot
.68466 .5415 Mdot
.46947 .37985 Mdot
.44183 .38173 Mdot
.38027 .58327 Mdot
.29801 .32732 Mdot
.3427 .62962 Mdot
.67544 .37133 Mdot
.71236 .52763 Mdot
.57065 .15779 Mdot
.39614 .36689 Mdot
.3688 .59935 Mdot
.65993 .51008 Mdot
.39834 .39166 Mdot
.57168 .7175 Mdot
.4625 .40596 Mdot
.37335 .5957 Mdot
.44978 .35391 Mdot
.35196 .62534 Mdot
.67122 .53737 Mdot
.38665 .36142 Mdot
.38737 .37929 Mdot
.60807 .30101 Mdot
.70342 .35969 Mdot
.35148 .64668 Mdot
.57683 .34367 Mdot
.41914 .43268 Mdot
.55155 .27381 Mdot
.40807 .35388 Mdot
.33912 .52178 Mdot
.35971 .38642 Mdot
.47043 .59991 Mdot
.39729 .41935 Mdot
.42839 .38356 Mdot
.30565 .32288 Mdot
.31158 .40759 Mdot
.39626 .51108 Mdot
.58386 .72249 Mdot
.38713 .59546 Mdot
.68338 .5342 Mdot
.67155 .51323 Mdot
.70387 .55224 Mdot
.74062 .3706 Mdot
.42807 .3221 Mdot
.42875 .38974 Mdot
.61041 .72464 Mdot
.68723 .36276 Mdot
.36733 .60373 Mdot
.69009 .37062 Mdot
.54053 .41193 Mdot
.70393 .37767 Mdot
.46642 .5914 Mdot
.64896 .71183 Mdot
.22456 .47445 Mdot
.71423 .3685 Mdot
.34525 .63106 Mdot
.52547 .51744 Mdot
.48264 .34469 Mdot
.41974 .80655 Mdot
.72988 .36766 Mdot
.6474 .50242 Mdot
.43151 .35205 Mdot
.55433 .35407 Mdot
.56697 .70112 Mdot
.71637 .3823 Mdot
.58064 .67278 Mdot
.46439 .38285 Mdot
.3061 .64525 Mdot
.38294 .60641 Mdot
.60025 .67075 Mdot
.41109 .42806 Mdot
.71612 .38287 Mdot
.68474 .54695 Mdot
.34562 .52521 Mdot
.59269 .65836 Mdot
.63941 .33152 Mdot
.57165 .28776 Mdot
.70773 .5244 Mdot
.34187 .49329 Mdot
.56892 .67118 Mdot
.4588 .33016 Mdot
.34639 .3984 Mdot
.4535 .42229 Mdot
.69133 .57443 Mdot
.68579 .55682 Mdot
.54613 .74493 Mdot
.3876 .38487 Mdot
.40309 .34006 Mdot
.39252 .64505 Mdot
.70916 .5235 Mdot
.37545 .63712 Mdot
.33503 .61052 Mdot
.67492 .56078 Mdot
.34149 .63253 Mdot
.69664 .38427 Mdot
.5388 .30636 Mdot
.56809 .67076 Mdot
.56559 .71397 Mdot
.68306 .5435 Mdot
.72173 .54052 Mdot
.69725 .5683 Mdot
.43922 .42442 Mdot
.35897 .63796 Mdot
.44531 .41497 Mdot
.40212 .35994 Mdot
.44304 .60439 Mdot
.38902 .65041 Mdot
.42259 .42285 Mdot
.55532 .56298 Mdot
.73041 .36327 Mdot
.69533 .55162 Mdot
.59663 .69015 Mdot
.64846 .31724 Mdot
.55655 .66985 Mdot
.41679 .43368 Mdot
.41632 .79317 Mdot
.38962 .60145 Mdot
.7012 .36624 Mdot
.55776 .52524 Mdot
.69998 .37057 Mdot
.60194 .67458 Mdot
.41543 .62282 Mdot
.50568 .47603 Mdot
.38619 .3805 Mdot
.55316 .39508 Mdot
.58298 .24304 Mdot
.48548 .78843 Mdot
.59869 .69797 Mdot
.46591 .37717 Mdot
.48337 .60661 Mdot
.2202 .541 Mdot
.43108 .38702 Mdot
.39598 .42759 Mdot
.56933 .50878 Mdot
.39079 .41571 Mdot
.41059 .59833 Mdot
.56073 .53461 Mdot
.45642 .34069 Mdot
.47478 .40268 Mdot
.73297 .73869 Mdot
.4427 .36471 Mdot
.3865 .37117 Mdot
.40968 .39 Mdot
.45319 .41386 Mdot
.33517 .63694 Mdot
.58666 .53372 Mdot
.5759 .65971 Mdot
.53872 .30598 Mdot
.57852 .66999 Mdot
.67843 .54912 Mdot
.60856 .39136 Mdot
.33971 .63897 Mdot
.70052 .37078 Mdot
.58028 .61021 Mdot
.49777 .2702 Mdot
.67084 .53375 Mdot
.63334 .28983 Mdot
.71064 .35134 Mdot
.48713 .3491 Mdot
.67099 .3699 Mdot
.72946 .54658 Mdot
.5693 .71462 Mdot
.38064 .39174 Mdot
.37975 .6383 Mdot
.35613 .60281 Mdot
.45247 .42597 Mdot
.5272 .79892 Mdot
.5737 .72109 Mdot
.64559 .41189 Mdot
.43695 .37206 Mdot
.41325 .43049 Mdot
.33964 .62857 Mdot
.7077 .5353 Mdot
.52932 .5344 Mdot
.7148 .36077 Mdot
.41186 .41483 Mdot
.46649 .36165 Mdot
.54223 .40891 Mdot
.59225 .7209 Mdot
.47935 .59126 Mdot
.43175 .393 Mdot
.53071 .44266 Mdot
.46306 .40727 Mdot
.48109 .37728 Mdot
.66704 .55656 Mdot
.46453 .44137 Mdot
.39426 .40158 Mdot
.31549 .65603 Mdot
.56981 .67201 Mdot
.36818 .61448 Mdot
.3771 .57083 Mdot
.4969 .59928 Mdot
.57009 .68221 Mdot
.42002 .42432 Mdot
.60551 .70917 Mdot
.4632 .37629 Mdot
.41365 .36086 Mdot
.59827 .70101 Mdot
.37202 .6366 Mdot
.49295 .65651 Mdot
.32116 .55765 Mdot
.45739 .38586 Mdot
.39567 .38033 Mdot
.66095 .39119 Mdot
.69605 .25571 Mdot
.38807 .39236 Mdot
.34758 .63628 Mdot
.39652 .38991 Mdot
.55477 .69271 Mdot
.68119 .37877 Mdot
.37724 .61412 Mdot
.70017 .51791 Mdot
.6728 .53488 Mdot
.67961 .49352 Mdot
.46546 .59173 Mdot
.41325 .33927 Mdot
.41443 .63171 Mdot
.39847 .64583 Mdot
.54775 .328 Mdot
.69573 .54696 Mdot
.68442 .3811 Mdot
.44562 .38383 Mdot
.46625 .3215 Mdot
.59792 .67133 Mdot
.89096 .5996 Mdot
.51044 .47299 Mdot
.71095 .34491 Mdot
.60858 .42744 Mdot
.4906 .59919 Mdot
.43912 .36329 Mdot
.71304 .38754 Mdot
.67373 .55118 Mdot
.46442 .37633 Mdot
.36916 .35441 Mdot
.63486 .60756 Mdot
.7164 .55791 Mdot
.60818 .69822 Mdot
.68668 .51503 Mdot
.70074 .34837 Mdot
.46691 .59254 Mdot
.37446 .59114 Mdot
.42694 .3777 Mdot
.39938 .45303 Mdot
.69978 .53452 Mdot
.47405 .61026 Mdot
.39528 .35333 Mdot
.38649 .59258 Mdot
.70184 .54711 Mdot
.4094 .37419 Mdot
.22626 .54719 Mdot
.34379 .5612 Mdot
.70095 .52472 Mdot
.42276 .41235 Mdot
.38392 .297 Mdot
.71321 .56292 Mdot
.72748 .55122 Mdot
.46685 .37441 Mdot
.72173 .37867 Mdot
.39934 .40483 Mdot
.56189 .70029 Mdot
.56498 .38033 Mdot
.57826 .68365 Mdot
.5634 .27721 Mdot
.47397 .37692 Mdot
.36915 .44771 Mdot
.32684 .61184 Mdot
.70924 .40013 Mdot
.36305 .23238 Mdot
.41115 .43282 Mdot
.29903 .67505 Mdot
.56912 .37143 Mdot
.52007 .48379 Mdot
.30381 .68213 Mdot
.71872 .3667 Mdot
.5739 .71164 Mdot
.39039 .36086 Mdot
.53726 .63848 Mdot
.71818 .37306 Mdot
.5617 .27607 Mdot
.43843 .41138 Mdot
.37543 .60353 Mdot
.43443 .36889 Mdot
.37848 .59289 Mdot
.40385 .39417 Mdot
.29164 .65269 Mdot
.75244 .33739 Mdot
.47575 .2416 Mdot
.48707 .34969 Mdot
.63452 .65426 Mdot
.32563 .52885 Mdot
.68901 .38014 Mdot
.45604 .37094 Mdot
.4869 .59182 Mdot
.58209 .72006 Mdot
.61868 .61624 Mdot
.69815 .56634 Mdot
.57031 .66588 Mdot
.36549 .63383 Mdot
.73167 .54849 Mdot
.48408 .60914 Mdot
.48972 .44453 Mdot
.71704 .38306 Mdot
.56766 .68294 Mdot
.42698 .38222 Mdot
.44777 .42527 Mdot
.65557 .64137 Mdot
.51582 .17054 Mdot
.33228 .62524 Mdot
.60683 .83748 Mdot
.41765 .62223 Mdot
.69617 .35792 Mdot
.66874 .56005 Mdot
.40275 .3748 Mdot
.41998 .40216 Mdot
.71634 .55612 Mdot
.381 .58423 Mdot
.66691 .3904 Mdot
.6834 .26277 Mdot
.59134 .73507 Mdot
.52672 .19864 Mdot
.38107 .61267 Mdot
.52806 .19957 Mdot
.70959 .33428 Mdot
.42342 .56927 Mdot
.44125 .21966 Mdot
.58615 .71005 Mdot
.52605 .19738 Mdot
.3748 .60053 Mdot
.42601 .35482 Mdot
.48162 .60175 Mdot
.46332 .60481 Mdot
.38843 .61956 Mdot
.68119 .56558 Mdot
.71473 .35552 Mdot
.43477 .37216 Mdot
.46344 .46278 Mdot
.29504 .32921 Mdot
.71677 .52796 Mdot
.49533 .41042 Mdot
.5919 .7025 Mdot
.39713 .38788 Mdot
.69301 .39456 Mdot
.58334 .70964 Mdot
.49876 .59151 Mdot
.50284 .27432 Mdot
.42391 .4095 Mdot
.54799 .51923 Mdot
.5677 .69676 Mdot
.68933 .25154 Mdot
.38795 .38148 Mdot
.56913 .67117 Mdot
.40261 .45446 Mdot
.60594 .76545 Mdot
.54573 .54475 Mdot
.52075 .76168 Mdot
.70052 .49826 Mdot
.68118 .51721 Mdot
.62976 .16968 Mdot
.74806 .3946 Mdot
.58559 .66526 Mdot
.4698 .58468 Mdot
.52576 .18002 Mdot
.57733 .67387 Mdot
.39826 .41201 Mdot
.41084 .3528 Mdot
.34284 .52777 Mdot
.4481 .31071 Mdot
.45606 .59654 Mdot
.40123 .49766 Mdot
.44077 .35199 Mdot
.5004 .39147 Mdot
.3918 .36413 Mdot
.40365 .59953 Mdot
.58868 .70546 Mdot
.15346 .56231 Mdot
.59981 .72056 Mdot
.36407 .43628 Mdot
.70066 .52701 Mdot
.71222 .50098 Mdot
.42328 .38121 Mdot
.33712 .37813 Mdot
.29137 .77207 Mdot
.40368 .35305 Mdot
.55718 .52488 Mdot
.57437 .28906 Mdot
.44289 .32533 Mdot
.38209 .64115 Mdot
.4134 .45841 Mdot
.4171 .63136 Mdot
.58223 .71179 Mdot
.7189 .3683 Mdot
.73155 .38773 Mdot
.57101 .70893 Mdot
.41934 .40106 Mdot
.72515 .39108 Mdot
.42008 .37335 Mdot
.44116 .37183 Mdot
.5312 .43439 Mdot
.67843 .38686 Mdot
.69284 .57085 Mdot
.69516 .36675 Mdot
.39663 .62513 Mdot
.71158 .79785 Mdot
.68754 .3747 Mdot
.34289 .52567 Mdot
.57711 .35624 Mdot
.53502 .19393 Mdot
.35494 .60232 Mdot
.67473 .36438 Mdot
.58215 .71587 Mdot
.48848 .48912 Mdot
.32153 .51555 Mdot
.55654 .67015 Mdot
.4307 .39081 Mdot
.33425 .63493 Mdot
.41344 .6254 Mdot
.54561 .68207 Mdot
.36791 .59029 Mdot
.40536 .32945 Mdot
.44568 .39594 Mdot
.57551 .66227 Mdot
.25848 .29969 Mdot
.56785 .71807 Mdot
.29273 .59305 Mdot
.4357 .34261 Mdot
.37564 .61289 Mdot
.3353 .5212 Mdot
.34333 .57804 Mdot
.46476 .60287 Mdot
.38425 .39099 Mdot
.68479 .37705 Mdot
.55333 .32319 Mdot
.70417 .52541 Mdot
.41351 .78853 Mdot
.35904 .60292 Mdot
.54625 .70538 Mdot
.37087 .59 Mdot
.35369 .59814 Mdot
.58806 .65932 Mdot
.38944 .60463 Mdot
.40625 .40524 Mdot
.31386 .71985 Mdot
.34752 .61094 Mdot
.57515 .69925 Mdot
.67773 .3663 Mdot
.34598 .63468 Mdot
.63717 .4005 Mdot
.44203 .38904 Mdot
.69225 .50628 Mdot
.69862 .41303 Mdot
.33914 .60284 Mdot
.68835 .38099 Mdot
.69969 .53973 Mdot
.72287 .36191 Mdot
.52578 .64612 Mdot
.61025 .64848 Mdot
.39497 .26993 Mdot
.61334 .76316 Mdot
.40204 .61373 Mdot
.73285 .52009 Mdot
.41595 .4108 Mdot
.43837 .37171 Mdot
.73622 .37617 Mdot
.41138 .61293 Mdot
.54057 .80027 Mdot
.38014 .4714 Mdot
.51108 .79922 Mdot
.5866 .72278 Mdot
.63789 .37303 Mdot
.50713 .47663 Mdot
.53071 .67986 Mdot
.44819 .33389 Mdot
.48971 .5993 Mdot
.41505 .37803 Mdot
.59895 .306 Mdot
.70439 .3496 Mdot
.68938 .65629 Mdot
.4652 .41239 Mdot
.7163 .55294 Mdot
.40339 .39001 Mdot
.55075 .60625 Mdot
.47786 .38981 Mdot
.73119 .36933 Mdot
.58158 .73343 Mdot
.35073 .6397 Mdot
.6804 .35689 Mdot
.67156 .53873 Mdot
.42196 .23827 Mdot
.40171 .41314 Mdot
.43822 .35236 Mdot
.7092 .56921 Mdot
.37826 .63727 Mdot
.681 .55294 Mdot
.56875 .67051 Mdot
.69021 .37371 Mdot
.44626 .41917 Mdot
.4975 .4042 Mdot
.65781 .56584 Mdot
.60343 .69136 Mdot
.68987 .57816 Mdot
.60605 .70675 Mdot
.48676 .6022 Mdot
.47846 .36865 Mdot
.69299 .58058 Mdot
.44896 .33574 Mdot
.3141 .45245 Mdot
.50963 .28728 Mdot
.31739 .31941 Mdot
.68895 .57224 Mdot
.76516 .3539 Mdot
.57808 .70693 Mdot
.56604 .68064 Mdot
.2856 .60833 Mdot
.33046 .79576 Mdot
.53045 .52426 Mdot
.58435 .81008 Mdot
.56813 .6705 Mdot
.56799 .69225 Mdot
.6819 .55964 Mdot
.39071 .62797 Mdot
.33796 .59759 Mdot
.70858 .57611 Mdot
.53096 .27229 Mdot
.36751 .60346 Mdot
.24321 .62752 Mdot
.71148 .51576 Mdot
.38658 .34885 Mdot
.38638 .55356 Mdot
.73069 .36864 Mdot
.58127 .30224 Mdot
.64431 .68092 Mdot
.40799 .38095 Mdot
.81241 .60061 Mdot
.69659 .56504 Mdot
.44776 .52104 Mdot
.60468 .73867 Mdot
.43456 .42834 Mdot
.40806 .39256 Mdot
.3996 .39885 Mdot
.73097 .35883 Mdot
.2981 .39079 Mdot
.40553 .37784 Mdot
.48833 .25559 Mdot
.3953 .43215 Mdot
.65777 .67176 Mdot
.69483 .36696 Mdot
.63763 .26607 Mdot
.73257 .55996 Mdot
.53651 .78846 Mdot
.3951 .42507 Mdot
.56063 .68029 Mdot
.55897 .5816 Mdot
.59988 .69357 Mdot
.52222 .68908 Mdot
.50488 .18762 Mdot
.40901 .60982 Mdot
.45917 .41663 Mdot
.71925 .52343 Mdot
.32414 .61862 Mdot
.5583 .57417 Mdot
.70032 .80443 Mdot
.55207 .71465 Mdot
.549 .88606 Mdot
.57721 .67886 Mdot
.45747 .60063 Mdot
.36779 .63234 Mdot
.33652 .3319 Mdot
.54981 .39935 Mdot
.37495 .63696 Mdot
.7801 .45071 Mdot
.42682 .62038 Mdot
.48378 .22128 Mdot
.34594 .66127 Mdot
.58012 .69928 Mdot
.54355 .68811 Mdot
.36281 .36806 Mdot
.40125 .408 Mdot
.55678 .39744 Mdot
.39299 .30651 Mdot
.42628 .40777 Mdot
.68794 .53244 Mdot
.61735 .76255 Mdot
.53843 .63928 Mdot
.38794 .61156 Mdot
.6004 .67792 Mdot
.40536 .39071 Mdot
.45727 .38484 Mdot
.37846 .39395 Mdot
.68903 .30979 Mdot
.23923 .6236 Mdot
.41361 .35887 Mdot
.48009 .39134 Mdot
.66876 .54082 Mdot
.65738 .64194 Mdot
.63975 .80425 Mdot
.51249 .18511 Mdot
.40083 .34862 Mdot
.69896 .36045 Mdot
.69115 .39519 Mdot
.38535 .33698 Mdot
.33921 .33785 Mdot
.64871 .39258 Mdot
.42701 .38261 Mdot
.44643 .23702 Mdot
.65841 .52855 Mdot
.4944 .60537 Mdot
.69941 .53511 Mdot
.32899 .60657 Mdot
.48643 .60581 Mdot
.67954 .53324 Mdot
.50605 .26841 Mdot
.49419 .59252 Mdot
.60234 .76765 Mdot
.67448 .3669 Mdot
.38911 .37069 Mdot
.35694 .53899 Mdot
.70818 .52183 Mdot
.56532 .68986 Mdot
.36411 .62657 Mdot
.57961 .72174 Mdot
.65091 .71801 Mdot
.54517 .27838 Mdot
.46562 .59705 Mdot
.55975 .68138 Mdot
.5433 .51746 Mdot
.69592 .36145 Mdot
.58334 .67936 Mdot
.36419 .44286 Mdot
.44001 .43802 Mdot
.24994 .70847 Mdot
.44553 .36163 Mdot
.53351 .72894 Mdot
.56281 .68555 Mdot
.50209 .59599 Mdot
.42707 .37591 Mdot
.71074 .50902 Mdot
.50041 .42962 Mdot
.41913 .37194 Mdot
.69602 .51415 Mdot
.4183 .3553 Mdot
.69246 .39171 Mdot
.42035 .61451 Mdot
.571 .36399 Mdot
.63002 .34621 Mdot
.70757 .35194 Mdot
.5306 .33253 Mdot
.3876 .3923 Mdot
.74564 .42991 Mdot
.37262 .60548 Mdot
.41403 .43292 Mdot
.56862 .26932 Mdot
.39318 .62205 Mdot
.35677 .6217 Mdot
.45075 .3611 Mdot
.56157 .71237 Mdot
.69731 .57231 Mdot
.69561 .36298 Mdot
.54881 .64869 Mdot
.40755 .37373 Mdot
.4659 .37902 Mdot
.70133 .35015 Mdot
.56917 .68526 Mdot
.43845 .42198 Mdot
.44235 .75654 Mdot
.53275 .30505 Mdot
.60518 .68598 Mdot
.44259 .43657 Mdot
.25027 .65899 Mdot
.3649 .58654 Mdot
.81452 .5971 Mdot
.75264 .34279 Mdot
.67248 .56064 Mdot
.48159 .43068 Mdot
.85695 .65041 Mdot
.67577 .36975 Mdot
.50704 .79193 Mdot
.42597 .35653 Mdot
.39972 .37224 Mdot
.40466 .60444 Mdot
.43657 .41895 Mdot
.38851 .59742 Mdot
.63844 .35719 Mdot
.35031 .80937 Mdot
.36043 .59612 Mdot
.37927 .5958 Mdot
.36053 .33308 Mdot
.73871 .31269 Mdot
.3837 .62601 Mdot
.40385 .41363 Mdot
.77285 .42568 Mdot
.38386 .32583 Mdot
.66653 .36332 Mdot
.64978 .38139 Mdot
.37057 .64559 Mdot
.31 .53047 Mdot
.359 .33743 Mdot
.2541 .59477 Mdot
.65685 .41376 Mdot
.58441 .66716 Mdot
.46016 .36004 Mdot
.46752 .58587 Mdot
.69803 .55241 Mdot
.42906 .45992 Mdot
.38845 .38004 Mdot
.39115 .63406 Mdot
.71419 .3478 Mdot
.58253 .67563 Mdot
.44694 .33959 Mdot
.65323 .54343 Mdot
.71062 .35698 Mdot
.34226 .61969 Mdot
.30619 .56184 Mdot
.72765 .38872 Mdot
.49519 .41418 Mdot
.42621 .35294 Mdot
.42619 .33901 Mdot
.48233 .34061 Mdot
.57056 .70714 Mdot
.72492 .56007 Mdot
.49271 .41814 Mdot
.51347 .46307 Mdot
.53563 .29675 Mdot
.37614 .37878 Mdot
.34692 .63578 Mdot
.592 .71785 Mdot
.47164 .59029 Mdot
.53194 .18727 Mdot
.42358 .34763 Mdot
.24298 .62906 Mdot
.67004 .2934 Mdot
.48726 .58835 Mdot
.32307 .6261 Mdot
.6999 .36688 Mdot
.44416 .34764 Mdot
.48623 .25218 Mdot
.42817 .40968 Mdot
.4512 .32536 Mdot
.67918 .56724 Mdot
.58925 .6747 Mdot
.40843 .26948 Mdot
.69491 .55466 Mdot
.35769 .62189 Mdot
.22419 .59614 Mdot
.33858 .59952 Mdot
.33444 .61183 Mdot
.45366 .55988 Mdot
.56241 .70658 Mdot
.865 .6397 Mdot
.71398 .26712 Mdot
.3796 .37473 Mdot
.55709 .67595 Mdot
.37741 .62656 Mdot
.4125 .4211 Mdot
.38947 .60038 Mdot
.38006 .64405 Mdot
.44399 .3909 Mdot
.44051 .39648 Mdot
.47112 .23967 Mdot
.25166 .63523 Mdot
.68089 .37265 Mdot
.38649 .5861 Mdot
.26633 .59687 Mdot
.40332 .37197 Mdot
.39305 .39691 Mdot
.55985 .58503 Mdot
.67817 .35688 Mdot
.20873 .46578 Mdot
.43544 .36611 Mdot
.61269 .29767 Mdot
.39321 .40498 Mdot
.33622 .59277 Mdot
.55383 .66149 Mdot
.36278 .4365 Mdot
.6831 .5751 Mdot
.37843 .58319 Mdot
.72138 .3538 Mdot
.32258 .63833 Mdot
.22207 .49823 Mdot
.57479 .71516 Mdot
.37366 .59571 Mdot
.7331 .54005 Mdot
.57538 .68702 Mdot
.56604 .71571 Mdot
.55846 .57089 Mdot
.72964 .52361 Mdot
.70832 .34466 Mdot
.59397 .69376 Mdot
.22892 .55099 Mdot
.58016 .69612 Mdot
.21642 .49942 Mdot
.39827 .34636 Mdot
.49069 .25754 Mdot
.43811 .45949 Mdot
.36462 .36099 Mdot
.58723 .69103 Mdot
.7096 .35452 Mdot
.43087 .42499 Mdot
.35366 .59969 Mdot
.68378 .36183 Mdot
.40541 .53927 Mdot
.72863 .51594 Mdot
.40924 .63392 Mdot
.60529 .71395 Mdot
.39882 .60353 Mdot
.57574 .29292 Mdot
.65356 .37 Mdot
.57625 .58162 Mdot
.55316 .3872 Mdot
.49625 .36652 Mdot
.46918 .41142 Mdot
.42878 .42655 Mdot
.40801 .40404 Mdot
.69965 .52503 Mdot
.73736 .36322 Mdot
.34382 .63396 Mdot
.29171 .31033 Mdot
.56145 .69161 Mdot
.55383 .52994 Mdot
.48464 .34428 Mdot
.46362 .37845 Mdot
.37495 .62556 Mdot
.37258 .64772 Mdot
.30882 .39905 Mdot
.71101 .56248 Mdot
.37363 .33934 Mdot
.39111 .41859 Mdot
.43826 .27161 Mdot
.58478 .68872 Mdot
.49394 .74417 Mdot
.66916 .51312 Mdot
.56161 .8879 Mdot
.69377 .55305 Mdot
.61527 .49471 Mdot
.39218 .60592 Mdot
.69974 .38112 Mdot
.43089 .39571 Mdot
.40907 .50906 Mdot
.33418 .63866 Mdot
.6416 .59413 Mdot
.70161 .37287 Mdot
.50666 .69346 Mdot
.56155 .66994 Mdot
.44677 .33864 Mdot
.39424 .40662 Mdot
.45428 .40283 Mdot
.4228 .41845 Mdot
.58311 .66195 Mdot
.43692 .40472 Mdot
.59606 .66202 Mdot
.22427 .48656 Mdot
.56217 .26322 Mdot
.72735 .54256 Mdot
.67257 .64116 Mdot
.33647 .6108 Mdot
.19655 .52612 Mdot
.21718 .46593 Mdot
.51036 .28776 Mdot
.52186 .65676 Mdot
.46098 .34233 Mdot
.68372 .56556 Mdot
.56659 .63419 Mdot
.7269 .53766 Mdot
.17312 .62009 Mdot
.33874 .52903 Mdot
.52411 .72037 Mdot
.44826 .40807 Mdot
.70394 .57534 Mdot
.29698 .55084 Mdot
.49097 .42719 Mdot
.72021 .39427 Mdot
.22239 .52059 Mdot
.40102 .51964 Mdot
.6796 .3786 Mdot
.4434 .38213 Mdot
.38633 .65148 Mdot
.42605 .39879 Mdot
.43572 .39251 Mdot
.40597 .35045 Mdot
.56951 .65317 Mdot
.38825 .3517 Mdot
.40304 .40643 Mdot
.53799 .16079 Mdot
.68285 .60284 Mdot
.6794 .51705 Mdot
.31505 .32935 Mdot
.68699 .36288 Mdot
.32805 .60771 Mdot
.56662 .37111 Mdot
.5582 .68974 Mdot
.30788 .39415 Mdot
.45264 .37899 Mdot
.46519 .79083 Mdot
.5821 .72861 Mdot
.72434 .37279 Mdot
.47292 .58507 Mdot
.49811 .7095 Mdot
.66478 .56008 Mdot
.45964 .59117 Mdot
.70711 .52643 Mdot
.33361 .28036 Mdot
.38445 .59592 Mdot
.49638 .367 Mdot
.588 .6793 Mdot
.72655 .52785 Mdot
.48294 .2526 Mdot
.39379 .38898 Mdot
.68854 .57258 Mdot
.46979 .44146 Mdot
.55698 .32346 Mdot
.56715 .37513 Mdot
.73121 .54228 Mdot
.57905 .73114 Mdot
.58056 .68731 Mdot
.67647 .37736 Mdot
.36606 .58761 Mdot
.38403 .6357 Mdot
.58292 .6943 Mdot
.76017 .70287 Mdot
.40852 .37565 Mdot
.40554 .36026 Mdot
.50768 .47116 Mdot
.40526 .42163 Mdot
.65757 .38614 Mdot
.45398 .60108 Mdot
.37114 .64223 Mdot
.42809 .42613 Mdot
.43974 .42127 Mdot
.4325 .35399 Mdot
.52248 .26437 Mdot
.70189 .53431 Mdot
.44037 .35075 Mdot
.71561 .38517 Mdot
.40382 .53271 Mdot
.4128 .41085 Mdot
.49696 .41229 Mdot
.39095 .59854 Mdot
.63038 .51788 Mdot
.56415 .69173 Mdot
.71841 .53221 Mdot
.71944 .52648 Mdot
.57186 .23987 Mdot
.36419 .5802 Mdot
.45623 .59489 Mdot
.64545 .64896 Mdot
.46827 .59 Mdot
.70345 .37437 Mdot
.53921 .54089 Mdot
.72993 .50229 Mdot
.68202 .51588 Mdot
.54141 .69442 Mdot
.43487 .43286 Mdot
.41052 .41201 Mdot
.53104 .79117 Mdot
.4034 .35493 Mdot
.68276 .37655 Mdot
.55198 .69099 Mdot
.37685 .5972 Mdot
.70116 .39436 Mdot
.56878 .67755 Mdot
.37453 .63816 Mdot
.38444 .42454 Mdot
.40187 .41458 Mdot
.3597 .62608 Mdot
.34261 .61577 Mdot
.41844 .38785 Mdot
.48535 .18527 Mdot
.36046 .64303 Mdot
.36439 .62945 Mdot
.4038 .52888 Mdot
.66444 .54864 Mdot
.50754 .42085 Mdot
.55563 .68936 Mdot
.40131 .40415 Mdot
.7259 .54916 Mdot
.71139 .36887 Mdot
.34968 .61845 Mdot
.45932 .35455 Mdot
.40989 .36801 Mdot
.6996 .36134 Mdot
.67015 .38096 Mdot
.68255 .35709 Mdot
.54839 .67753 Mdot
.44805 .3899 Mdot
.37581 .63044 Mdot
.56372 .66706 Mdot
.72355 .3881 Mdot
.6698 .36575 Mdot
.44638 .21111 Mdot
.41068 .38236 Mdot
.69027 .3968 Mdot
.73534 .78442 Mdot
.44794 .2261 Mdot
.48184 .60851 Mdot
.67471 .5015 Mdot
.76744 .3445 Mdot
.70255 .41211 Mdot
.591 .67333 Mdot
.56043 .53054 Mdot
.69357 .34593 Mdot
.44388 .34139 Mdot
.39278 .37298 Mdot
.49214 .36782 Mdot
.68669 .35978 Mdot
.54553 .27689 Mdot
.40966 .60402 Mdot
.24839 .40784 Mdot
.68685 .36313 Mdot
.72837 .52689 Mdot
.6562 .56437 Mdot
.68805 .55607 Mdot
.47714 .36549 Mdot
.31873 .28585 Mdot
.243 .53087 Mdot
.20908 .45498 Mdot
.56213 .67144 Mdot
.37662 .64639 Mdot
.40159 .55298 Mdot
.35597 .62133 Mdot
.70609 .54995 Mdot
.71244 .35717 Mdot
.40651 .60701 Mdot
.5675 .71628 Mdot
.58346 .68944 Mdot
.67931 .57705 Mdot
.69723 .54132 Mdot
.68471 .54396 Mdot
.37434 .58419 Mdot
.39102 .60521 Mdot
.45179 .41251 Mdot
.34875 .61402 Mdot
.69656 .29282 Mdot
.67176 .32685 Mdot
.67036 .57779 Mdot
.57155 .70291 Mdot
.35215 .63143 Mdot
.38856 .36963 Mdot
.58375 .49857 Mdot
.73362 .56244 Mdot
.72994 .3739 Mdot
.34801 .7624 Mdot
.33033 .80411 Mdot
.46341 .41149 Mdot
.60134 .68393 Mdot
.34396 .40259 Mdot
.40633 .40088 Mdot
.67704 .5687 Mdot
.66811 .27237 Mdot
.49192 .58788 Mdot
.42234 .40514 Mdot
.37983 .41636 Mdot
.57804 .71851 Mdot
.56523 .37129 Mdot
.44806 .34195 Mdot
.56583 .54956 Mdot
.5727 .72843 Mdot
.66612 .51681 Mdot
.67108 .19297 Mdot
.43839 .52302 Mdot
.59932 .32439 Mdot
.49282 .60415 Mdot
.41526 .34573 Mdot
.68986 .52983 Mdot
.72091 .38569 Mdot
.69163 .53634 Mdot
.32052 .61837 Mdot
.66503 .55768 Mdot
.39757 .35577 Mdot
.38171 .62861 Mdot
.56869 .68301 Mdot
.54551 .49261 Mdot
.33401 .29279 Mdot
.70778 .50808 Mdot
.47541 .61092 Mdot
.43942 .39693 Mdot
.22259 .55228 Mdot
.36181 .36854 Mdot
.39577 .40319 Mdot
.59904 .69825 Mdot
.38367 .61829 Mdot
.58812 .7219 Mdot
.48689 .44118 Mdot
.30701 .67191 Mdot
.5626 .69659 Mdot
.42167 .5039 Mdot
.70915 .35088 Mdot
.53861 .27643 Mdot
.43174 .37617 Mdot
.58716 .67728 Mdot
.44809 .3772 Mdot
.38883 .58649 Mdot
.52032 .2841 Mdot
.52686 .30605 Mdot
.59149 .70512 Mdot
.50837 .62782 Mdot
.57532 .34106 Mdot
.50908 .41851 Mdot
.57424 .66974 Mdot
.35606 .2408 Mdot
.48299 .58958 Mdot
.7129 .36071 Mdot
.668 .38009 Mdot
.70782 .38349 Mdot
.40039 .36118 Mdot
.26249 .6213 Mdot
.67484 .3799 Mdot
.55623 .71481 Mdot
.69024 .38861 Mdot
.64453 .32585 Mdot
.53027 .79904 Mdot
.70987 .35198 Mdot
.42877 .36911 Mdot
.36929 .43675 Mdot
.55771 .52749 Mdot
.70475 .50107 Mdot
.45735 .68366 Mdot
.54445 .16024 Mdot
.40276 .37605 Mdot
.29161 .65731 Mdot
.31833 .60459 Mdot
.63311 .46614 Mdot
.5209 .30243 Mdot
.5305 .50369 Mdot
.35719 .63108 Mdot
.55979 .37887 Mdot
.33714 .63594 Mdot
.49572 .36101 Mdot
.41456 .36044 Mdot
.37716 .58258 Mdot
.40078 .78374 Mdot
.34259 .23754 Mdot
.4971 .8009 Mdot
.36004 .63874 Mdot
.56988 .6721 Mdot
.60107 .69266 Mdot
.59877 .69598 Mdot
.69229 .52203 Mdot
.37208 .59408 Mdot
.4305 .34627 Mdot
.67031 .54668 Mdot
.43851 .38374 Mdot
.58653 .70288 Mdot
.51558 .29319 Mdot
.37985 .59679 Mdot
.42822 .38254 Mdot
.28199 .57196 Mdot
.70933 .53064 Mdot
.69541 .36022 Mdot
.33239 .7447 Mdot
.69267 .49186 Mdot
.58902 .72938 Mdot
.31663 .62697 Mdot
.64948 .56939 Mdot
.59087 .52825 Mdot
.37946 .36756 Mdot
.38068 .38907 Mdot
.56662 .53116 Mdot
.32452 .53878 Mdot
.45728 .34453 Mdot
.67214 .53674 Mdot
.6688 .53023 Mdot
.44693 .37328 Mdot
.3658 .59493 Mdot
.68214 .34604 Mdot
.73638 .3793 Mdot
.46939 .33658 Mdot
.55684 .38981 Mdot
.48913 .25649 Mdot
.42356 .42413 Mdot
.4917 .40616 Mdot
.73379 .53458 Mdot
.48683 .60826 Mdot
.54443 .40439 Mdot
.69599 .38463 Mdot
.43105 .35871 Mdot
.2964 .33231 Mdot
.36025 .60286 Mdot
.69173 .573 Mdot
.57031 .66013 Mdot
.72544 .39055 Mdot
.66598 .57184 Mdot
.44689 .37319 Mdot
.43857 .4218 Mdot
.58618 .68026 Mdot
.33869 .59064 Mdot
.6979 .35389 Mdot
.66976 .54573 Mdot
.69687 .38211 Mdot
.38767 .60346 Mdot
.34712 .62655 Mdot
.37938 .40024 Mdot
.36434 .35587 Mdot
.70984 .51219 Mdot
.46181 .33648 Mdot
.67598 .55049 Mdot
.65579 .64186 Mdot
.59707 .67026 Mdot
.40774 .42993 Mdot
.35869 .5803 Mdot
.58615 .69943 Mdot
.40298 .3818 Mdot
.57105 .53442 Mdot
.46037 .40886 Mdot
.71265 .57182 Mdot
.67 .25563 Mdot
.71405 .37432 Mdot
.38072 .43251 Mdot
.35965 .46699 Mdot
.40959 .42325 Mdot
.68252 .51071 Mdot
.23309 .53919 Mdot
.565 .70317 Mdot
.39496 .61116 Mdot
.69087 .47816 Mdot
.57673 .69791 Mdot
.42854 .36344 Mdot
.6872 .37397 Mdot
.3427 .6372 Mdot
.47537 .60492 Mdot
.54863 .42038 Mdot
.39493 .45695 Mdot
.39221 .32445 Mdot
.45289 .34086 Mdot
.58111 .81242 Mdot
.68683 .54151 Mdot
.37475 .62689 Mdot
.59916 .67952 Mdot
.5703 .71286 Mdot
.70802 .53545 Mdot
.40575 .52079 Mdot
.44777 .80431 Mdot
.77943 .74542 Mdot
.66508 .57275 Mdot
.70063 .38849 Mdot
.52004 .28534 Mdot
.68791 .55777 Mdot
.7007 .52158 Mdot
.73579 .53384 Mdot
.53743 .79286 Mdot
.3646 .63777 Mdot
.40882 .36738 Mdot
.31244 .58852 Mdot
.40801 .35063 Mdot
.5958 .33743 Mdot
.58549 .70353 Mdot
.39526 .61072 Mdot
.62823 .38964 Mdot
.47737 .3953 Mdot
.41342 .39792 Mdot
.64404 .41247 Mdot
.35108 .34067 Mdot
.53052 .19229 Mdot
.38814 .40869 Mdot
.69637 .53122 Mdot
.40435 .57246 Mdot
.4947 .41401 Mdot
.2802 .57507 Mdot
.57865 .68343 Mdot
.46416 .59751 Mdot
.50118 .38201 Mdot
.49019 .37603 Mdot
.33613 .63365 Mdot
.40716 .60935 Mdot
.6706 .37282 Mdot
.32144 .72409 Mdot
.57525 .68181 Mdot
.51375 .75244 Mdot
.39573 .40397 Mdot
.52413 .69307 Mdot
.67887 .26705 Mdot
.40725 .38731 Mdot
.55738 .56644 Mdot
.30908 .39915 Mdot
.46439 .3642 Mdot
.21534 .44239 Mdot
.5766 .7042 Mdot
.58475 .28241 Mdot
.43771 .40919 Mdot
.68546 .57054 Mdot
.39486 .62477 Mdot
.40891 .63469 Mdot
.71981 .38761 Mdot
.71607 .28489 Mdot
.41259 .8415 Mdot
.39617 .61008 Mdot
.39382 .39147 Mdot
.56563 .69446 Mdot
.46726 .60262 Mdot
.42248 .46064 Mdot
.54387 .61624 Mdot
.36003 .60435 Mdot
.48903 .42706 Mdot
.4611 .79247 Mdot
.56286 .37527 Mdot
.19511 .55599 Mdot
.597 .69686 Mdot
.68823 .38436 Mdot
.42402 .31125 Mdot
.64934 .65213 Mdot
.40017 .41375 Mdot
.59646 .33263 Mdot
.40169 .57902 Mdot
.6832 .37975 Mdot
.41699 .40083 Mdot
.46047 .34737 Mdot
.54003 .35085 Mdot
.66401 .36902 Mdot
.45339 .34361 Mdot
.46609 .4097 Mdot
.40122 .61928 Mdot
.45454 .6021 Mdot
.37416 .59832 Mdot
.42617 .39745 Mdot
.64589 .23282 Mdot
.39108 .59095 Mdot
.47678 .6652 Mdot
.74727 .34289 Mdot
.55824 .68828 Mdot
.45658 .44555 Mdot
.39013 .35336 Mdot
.18975 .56957 Mdot
.46438 .6034 Mdot
.67042 .77607 Mdot
.7087 .57248 Mdot
.49373 .15188 Mdot
.69614 .49125 Mdot
.51014 .66015 Mdot
.61924 .59949 Mdot
.49253 .41372 Mdot
.39917 .51243 Mdot
.20378 .45539 Mdot
.61086 .72392 Mdot
.19393 .51679 Mdot
.40142 .4081 Mdot
.43132 .35596 Mdot
.67613 .55661 Mdot
.51674 .67402 Mdot
.36368 .43834 Mdot
.54557 .40293 Mdot
.72421 .36985 Mdot
.3673 .61268 Mdot
.39191 .37012 Mdot
.38133 .77444 Mdot
.72163 .51661 Mdot
.33449 .30355 Mdot
.42857 .37922 Mdot
.34168 .3876 Mdot
.51598 .66251 Mdot
.56675 .68364 Mdot
.73143 .54352 Mdot
.72747 .52167 Mdot
.41345 .34732 Mdot
.57744 .66033 Mdot
.45853 .40054 Mdot
.57086 .33235 Mdot
.47436 .43764 Mdot
.7069 .37175 Mdot
.38716 .38508 Mdot
.3306 .39017 Mdot
.18113 .38077 Mdot
.46572 .41377 Mdot
.33596 .60797 Mdot
.68158 .54441 Mdot
.70382 .53931 Mdot
.37938 .63792 Mdot
.70438 .5397 Mdot
.24795 .41408 Mdot
.25959 .63188 Mdot
.70148 .37687 Mdot
.23404 .4718 Mdot
.71917 .37114 Mdot
.46423 .59629 Mdot
.41307 .38467 Mdot
.75458 .60706 Mdot
.66087 .56452 Mdot
.64804 .31778 Mdot
.5827 .69703 Mdot
.46227 .60325 Mdot
.44195 .39668 Mdot
.66674 .42224 Mdot
.69753 .56037 Mdot
.488 .5371 Mdot
.41304 .35064 Mdot
.38029 .58487 Mdot
.46389 .37028 Mdot
.37072 .31844 Mdot
.45525 .59923 Mdot
.46896 .36605 Mdot
.56866 .67757 Mdot
.38479 .59259 Mdot
.53224 .73544 Mdot
.7057 .52083 Mdot
.42932 .4029 Mdot
.39596 .39444 Mdot
.34898 .64648 Mdot
.38039 .37318 Mdot
.57464 .66394 Mdot
.9067 .55886 Mdot
.68758 .35251 Mdot
.4894 .60734 Mdot
.41657 .70623 Mdot
.46815 .36181 Mdot
.44138 .4232 Mdot
.5085 .51531 Mdot
.29713 .32783 Mdot
.56092 .68366 Mdot
.40343 .32259 Mdot
.67337 .52444 Mdot
.70093 .35334 Mdot
.57388 .72208 Mdot
.44464 .39782 Mdot
.416 .35488 Mdot
.68409 .37914 Mdot
.63604 .40656 Mdot
.66882 .39101 Mdot
.58659 .66736 Mdot
.3585 .67687 Mdot
.58543 .49754 Mdot
.41479 .37583 Mdot
.47949 .6127 Mdot
.37866 .61968 Mdot
.57436 .66813 Mdot
.29521 .39519 Mdot
.49492 .35931 Mdot
.60859 .70287 Mdot
.57022 .68213 Mdot
.38212 .36283 Mdot
.36648 .58044 Mdot
.31511 .62729 Mdot
.37637 .62272 Mdot
.56448 .25758 Mdot
.64109 .77889 Mdot
.68391 .5398 Mdot
.57175 .70032 Mdot
.72374 .55146 Mdot
.69431 .34681 Mdot
.54294 .30423 Mdot
.71613 .50937 Mdot
.39282 .58169 Mdot
.72537 .5365 Mdot
.45822 .40387 Mdot
.55924 .7064 Mdot
.7094 .51478 Mdot
.41731 .42084 Mdot
.48092 .35684 Mdot
.44464 .30892 Mdot
.69911 .34396 Mdot
.56161 .38106 Mdot
.43365 .37151 Mdot
.47414 .58528 Mdot
.4224 .38538 Mdot
.57598 .66278 Mdot
.54883 .48482 Mdot
.44565 .35908 Mdot
.66091 .56503 Mdot
.64785 .78491 Mdot
.66676 .52907 Mdot
.39925 .29303 Mdot
.43148 .38962 Mdot
.41233 .37721 Mdot
.44276 .39385 Mdot
.39722 .52265 Mdot
.60091 .72228 Mdot
.42356 .31943 Mdot
.69227 .5784 Mdot
.35345 .62269 Mdot
.39675 .59194 Mdot
.52014 .52281 Mdot
.46076 .58987 Mdot
.56425 .66479 Mdot
.41062 .37626 Mdot
.4913 .53875 Mdot
.53024 .45777 Mdot
.47479 .80013 Mdot
.6668 .50352 Mdot
.68696 .51254 Mdot
.35058 .59894 Mdot
.68542 .51834 Mdot
.44126 .4005 Mdot
.48909 .42579 Mdot
.52919 .73158 Mdot
.59618 .74192 Mdot
.70345 .35431 Mdot
.4359 .38801 Mdot
.50283 .25236 Mdot
.66877 .54096 Mdot
.73283 .531 Mdot
.45784 .40036 Mdot
.32598 .592 Mdot
.23579 .30153 Mdot
.55598 .67712 Mdot
.23091 .56657 Mdot
.30708 .58057 Mdot
.47763 .28148 Mdot
.57078 .70978 Mdot
.55714 .5595 Mdot
.69984 .50043 Mdot
.64148 .2169 Mdot
.35445 .62594 Mdot
.70014 .35435 Mdot
.40871 .4175 Mdot
.39337 .58153 Mdot
.67961 .58436 Mdot
.34718 .64167 Mdot
.49995 .37989 Mdot
.57631 .72625 Mdot
.69946 .5486 Mdot
.54266 .68779 Mdot
.32335 .61838 Mdot
.71785 .3723 Mdot
.60777 .30167 Mdot
.22336 .54448 Mdot
.31126 .40604 Mdot
.44027 .35004 Mdot
.72611 .59191 Mdot
.43035 .34531 Mdot
.41568 .62 Mdot
.43159 .37522 Mdot
.46942 .42024 Mdot
.70667 .49957 Mdot
.37593 .38028 Mdot
.39003 .39325 Mdot
.27578 .58066 Mdot
.41026 .39234 Mdot
.44454 .36913 Mdot
.37756 .39789 Mdot
.37983 .5807 Mdot
.37699 .38637 Mdot
.37049 .58775 Mdot
.49124 .79243 Mdot
.70739 .52337 Mdot
.69131 .34722 Mdot
.69975 .34822 Mdot
.60252 .32965 Mdot
.50943 .25663 Mdot
.37554 .5532 Mdot
.36247 .607 Mdot
.58634 .69084 Mdot
.45626 .40687 Mdot
.37412 .22344 Mdot
.63884 .23608 Mdot
.68455 .50495 Mdot
.71593 .51805 Mdot
.41733 .41503 Mdot
.31563 .79241 Mdot
.38816 .40615 Mdot
.50857 .47393 Mdot
.40153 .3603 Mdot
.40954 .43039 Mdot
.73197 .5493 Mdot
.57736 .29477 Mdot
.44019 .35077 Mdot
.33566 .63352 Mdot
.7045 .35647 Mdot
.3421 .36985 Mdot
.6401 .25654 Mdot
.29485 .58658 Mdot
.36924 .46214 Mdot
.45003 .372 Mdot
.67039 .55625 Mdot
.35224 .63849 Mdot
.51852 .4624 Mdot
.56685 .66685 Mdot
.5573 .40273 Mdot
.21741 .4904 Mdot
.61481 .71688 Mdot
.70925 .35645 Mdot
.69627 .58873 Mdot
.40534 .34811 Mdot
.68758 .52645 Mdot
.44585 .32614 Mdot
.53155 .46223 Mdot
.70502 .3757 Mdot
.43363 .60859 Mdot
.56903 .67276 Mdot
.40027 .58845 Mdot
.31706 .31991 Mdot
.63992 .23384 Mdot
.49983 .14956 Mdot
.66128 .55599 Mdot
.2612 .34287 Mdot
.38928 .61984 Mdot
.41938 .34663 Mdot
.77655 .74763 Mdot
.38038 .61403 Mdot
.38066 .58437 Mdot
.54273 .46488 Mdot
.5652 .27794 Mdot
.45863 .33497 Mdot
.36072 .64389 Mdot
.69424 .58876 Mdot
.69879 .3705 Mdot
.42514 .42007 Mdot
.50111 .38712 Mdot
.40583 .60625 Mdot
.70309 .55608 Mdot
.58509 .31767 Mdot
.6975 .53565 Mdot
.3701 .63585 Mdot
.71562 .53784 Mdot
.49532 .66091 Mdot
.71526 .50977 Mdot
.38511 .36887 Mdot
.41137 .37579 Mdot
.50141 .57023 Mdot
.34711 .62653 Mdot
.43983 .42368 Mdot
.42299 .35535 Mdot
.38039 .62719 Mdot
.73612 .50847 Mdot
.28378 .35104 Mdot
.44785 .42148 Mdot
.4084 .37182 Mdot
.68256 .35382 Mdot
.56437 .34494 Mdot
.49724 .48782 Mdot
.41711 .42238 Mdot
.70797 .38476 Mdot
.37365 .58479 Mdot
.42128 .38728 Mdot
.57985 .29591 Mdot
.65679 .53284 Mdot
.45179 .39815 Mdot
.47217 .60245 Mdot
.42032 .3424 Mdot
.22832 .32807 Mdot
.43576 .40023 Mdot
.36456 .63312 Mdot
.3925 .62391 Mdot
.70523 .48123 Mdot
.36008 .6222 Mdot
.48152 .60818 Mdot
.58108 .68869 Mdot
.20734 .56341 Mdot
.47501 .60864 Mdot
.46809 .3723 Mdot
.71952 .27128 Mdot
.50062 .39715 Mdot
.49174 .42825 Mdot
.74212 .31352 Mdot
.49235 .60386 Mdot
.38771 .61448 Mdot
.39235 .77286 Mdot
.40709 .33326 Mdot
.56251 .6657 Mdot
.4966 .4098 Mdot
.45199 .3969 Mdot
.461 .42676 Mdot
.31102 .67099 Mdot
.55511 .67212 Mdot
.50743 .42233 Mdot
.42559 .42013 Mdot
.29751 .32863 Mdot
.39018 .37746 Mdot
.72829 .36622 Mdot
.38074 .60033 Mdot
.6851 .5209 Mdot
.70477 .37009 Mdot
.45169 .34118 Mdot
.68564 .36251 Mdot
.68595 .53086 Mdot
.59278 .6864 Mdot
.3864 .36502 Mdot
.66645 .36157 Mdot
.71706 .35955 Mdot
.45539 .36317 Mdot
.39816 .61574 Mdot
.3609 .37337 Mdot
.41865 .38887 Mdot
.44608 .38994 Mdot
.38754 .63375 Mdot
.82999 .56495 Mdot
.43387 .35591 Mdot
.55843 .5617 Mdot
.41872 .62114 Mdot
.45683 .6039 Mdot
.67546 .52884 Mdot
.46904 .39721 Mdot
.56642 .71111 Mdot
.58104 .69066 Mdot
.65803 .55292 Mdot
.40598 .61192 Mdot
.70282 .54612 Mdot
.46623 .41421 Mdot
.49215 .4191 Mdot
.41208 .4173 Mdot
.71126 .47409 Mdot
.49326 .69692 Mdot
.34097 .62632 Mdot
.6785 .51253 Mdot
.55384 .39969 Mdot
.55594 .69733 Mdot
.73162 .55615 Mdot
.34962 .65219 Mdot
.40084 .62728 Mdot
.37025 .64098 Mdot
.71793 .38026 Mdot
.6953 .54873 Mdot
.31847 .63526 Mdot
.32444 .63816 Mdot
.45766 .38629 Mdot
.43258 .41913 Mdot
.36685 .58604 Mdot
.62838 .55865 Mdot
.71479 .36742 Mdot
.66815 .55636 Mdot
.20869 .32462 Mdot
.55738 .67308 Mdot
.27717 .57957 Mdot
.41294 .42171 Mdot
.59177 .8874 Mdot
.38812 .40665 Mdot
.39169 .38665 Mdot
.329 .60655 Mdot
.6677 .38396 Mdot
.69551 .37006 Mdot
.3901 .62004 Mdot
.38297 .64176 Mdot
.72816 .37716 Mdot
.53486 .49768 Mdot
.24896 .30673 Mdot
.5278 .45259 Mdot
.3425 .63123 Mdot
.21505 .53272 Mdot
.5905 .71049 Mdot
.4183 .60217 Mdot
.60414 .64296 Mdot
.71255 .52619 Mdot
.71219 .51041 Mdot
.58808 .68501 Mdot
.43921 .36039 Mdot
.67465 .57066 Mdot
.40489 .43719 Mdot
.51328 .69487 Mdot
.5287 .6194 Mdot
.43887 .18792 Mdot
.38415 .36568 Mdot
.33793 .36213 Mdot
.55976 .80887 Mdot
.46475 .39615 Mdot
.33617 .51284 Mdot
.69374 .35522 Mdot
.41809 .60934 Mdot
.55036 .69022 Mdot
.29354 .67281 Mdot
.41356 .37621 Mdot
.34619 .63483 Mdot
.55364 .6854 Mdot
.5071 .70264 Mdot
.56506 .54969 Mdot
.46185 .37859 Mdot
.82272 .69397 Mdot
.33404 .63599 Mdot
.68442 .52159 Mdot
.26063 .54417 Mdot
.40655 .58922 Mdot
.58306 .53867 Mdot
.68634 .58743 Mdot
.53574 .41033 Mdot
.35541 .64519 Mdot
.67108 .39299 Mdot
.37089 .60768 Mdot
.69112 .39283 Mdot
.31774 .62854 Mdot
.71154 .54137 Mdot
.42043 .39595 Mdot
.71011 .5345 Mdot
.73227 .37423 Mdot
.66094 .55814 Mdot
.55044 .69078 Mdot
.49623 .59991 Mdot
.58729 .7026 Mdot
.52906 .29209 Mdot
.29267 .41864 Mdot
.59014 .67588 Mdot
.51431 .55057 Mdot
.40119 .35448 Mdot
.33575 .59307 Mdot
.68939 .5198 Mdot
.69859 .49486 Mdot
.55992 .38407 Mdot
.3743 .63646 Mdot
.70687 .5545 Mdot
.22087 .5371 Mdot
.74878 .71825 Mdot
.47633 .4129 Mdot
.6575 .72419 Mdot
.37287 .63094 Mdot
.72108 .50688 Mdot
.50693 .47281 Mdot
.41009 .61002 Mdot
.7103 .51366 Mdot
.57586 .67066 Mdot
.56462 .70784 Mdot
.38095 .3785 Mdot
.54758 .69923 Mdot
.70344 .50232 Mdot
.29625 .32262 Mdot
.39453 .60361 Mdot
.48075 .69501 Mdot
.70257 .35138 Mdot
.69602 .52175 Mdot
.38398 .34603 Mdot
.36571 .57769 Mdot
.72472 .54257 Mdot
.3848 .82908 Mdot
.14689 .42142 Mdot
.70559 .55642 Mdot
.37945 .60041 Mdot
.35106 .61763 Mdot
.47572 .38271 Mdot
.55211 .39432 Mdot
.69779 .5619 Mdot
.75364 .60683 Mdot
.47893 .24589 Mdot
.48633 .6028 Mdot
.54067 .16064 Mdot
.43939 .35118 Mdot
.45069 .37512 Mdot
.58422 .66503 Mdot
.40965 .39693 Mdot
.37432 .64607 Mdot
.38895 .40812 Mdot
.59322 .72011 Mdot
.65915 .53647 Mdot
.4149 .38184 Mdot
.70027 .35268 Mdot
.5954 .71326 Mdot
.60327 .69891 Mdot
.71802 .5373 Mdot
.40263 .62015 Mdot
.41846 .80569 Mdot
.69812 .53756 Mdot
.44876 .38878 Mdot
.48522 .5882 Mdot
.37578 .38681 Mdot
.4888 .5665 Mdot
.41351 .62803 Mdot
.68456 .51919 Mdot
.43729 .6127 Mdot
.57011 .69549 Mdot
.6981 .49891 Mdot
.41471 .34258 Mdot
.69842 .50874 Mdot
.57429 .57407 Mdot
.75787 .41295 Mdot
.33683 .64549 Mdot
.58454 .54749 Mdot
.40762 .61827 Mdot
.48403 .60464 Mdot
.56271 .23708 Mdot
.7138 .36252 Mdot
.6673 .5361 Mdot
.47877 .66482 Mdot
.70264 .51811 Mdot
.40672 .38964 Mdot
.41474 .35394 Mdot
.67523 .55494 Mdot
.71655 .37665 Mdot
.62283 .35324 Mdot
.67844 .4006 Mdot
.37106 .59539 Mdot
.54414 .51432 Mdot
.22571 .30131 Mdot
.65393 .53093 Mdot
.58472 .68554 Mdot
.38523 .48408 Mdot
.46575 .36244 Mdot
.55378 .67865 Mdot
.60076 .67818 Mdot
.71472 .39229 Mdot
.70021 .52023 Mdot
.41303 .63465 Mdot
.56949 .72096 Mdot
.38273 .57338 Mdot
.58699 .3113 Mdot
.49134 .35292 Mdot
.47764 .28824 Mdot
.45568 .34045 Mdot
.56353 .37606 Mdot
.57978 .72745 Mdot
.4237 .36302 Mdot
.44724 .31946 Mdot
.567 .67031 Mdot
.70534 .39525 Mdot
.43918 .64263 Mdot
.70815 .55543 Mdot
.67727 .81122 Mdot
.38549 .37079 Mdot
.42123 .39216 Mdot
.56154 .67218 Mdot
.31483 .53977 Mdot
.33676 .61984 Mdot
.4022 .61351 Mdot
.68654 .54236 Mdot
.53134 .47549 Mdot
.3803 .3688 Mdot
.39112 .36021 Mdot
.68483 .57177 Mdot
.47352 .58619 Mdot
.52063 .16075 Mdot
.41155 .36767 Mdot
.5755 .70722 Mdot
.55914 .58132 Mdot
.573 .72771 Mdot
.42387 .43715 Mdot
.40191 .38475 Mdot
.41979 .33975 Mdot
.39769 .34425 Mdot
.59035 .70475 Mdot
.45559 .34183 Mdot
.42999 .32271 Mdot
.38384 .6169 Mdot
.44639 .36332 Mdot
.47626 .24416 Mdot
.4142 .3705 Mdot
.6944 .35382 Mdot
.50347 .48772 Mdot
.43501 .39907 Mdot
.44749 .36627 Mdot
.4828 .24844 Mdot
.41178 .40289 Mdot
.55332 .68451 Mdot
.34976 .62273 Mdot
.56867 .69505 Mdot
.57892 .68039 Mdot
.72403 .53468 Mdot
.67995 .39006 Mdot
.46935 .34402 Mdot
.7226 .38245 Mdot
.47751 .38716 Mdot
.48485 .44303 Mdot
.55837 .32349 Mdot
.51074 .47252 Mdot
.70005 .34617 Mdot
.39319 .35947 Mdot
.68754 .53487 Mdot
.68673 .51635 Mdot
.56171 .53137 Mdot
.47416 .43456 Mdot
.55542 .71015 Mdot
.58676 .67666 Mdot
.66821 .32857 Mdot
.75908 .39098 Mdot
.72085 .36196 Mdot
.61081 .38029 Mdot
.38171 .42227 Mdot
.44151 .37001 Mdot
.44723 .45409 Mdot
.7175 .56352 Mdot
.49615 .60173 Mdot
.67388 .57449 Mdot
.51741 .66144 Mdot
.58591 .71808 Mdot
.38368 .36845 Mdot
.28088 .75694 Mdot
.37773 .59119 Mdot
.34899 .62257 Mdot
.59282 .72078 Mdot
.66752 .52837 Mdot
.47583 .4379 Mdot
.61562 .83695 Mdot
.40161 .63902 Mdot
.67491 .35455 Mdot
.41957 .40335 Mdot
.71182 .52706 Mdot
.38726 .59488 Mdot
.66768 .35878 Mdot
.39717 .34611 Mdot
.69126 .58765 Mdot
.42395 .36843 Mdot
.23665 .44719 Mdot
.3911 .61119 Mdot
.5479 .32746 Mdot
.33804 .59861 Mdot
.58846 .70681 Mdot
.56221 .68461 Mdot
.40268 .38227 Mdot
.64368 .8296 Mdot
.40781 .5754 Mdot
.60196 .67475 Mdot
.66978 .37402 Mdot
.49614 .59463 Mdot
.67519 .38241 Mdot
.67645 .55201 Mdot
.70998 .35739 Mdot
.72448 .53981 Mdot
.62747 .55925 Mdot
.35656 .65615 Mdot
.68387 .37846 Mdot
.34039 .4892 Mdot
.48735 .42842 Mdot
.72951 .3858 Mdot
.42616 .41377 Mdot
.47124 .40529 Mdot
.69945 .56695 Mdot
.72254 .37808 Mdot
.45898 .3549 Mdot
.41181 .70493 Mdot
.56689 .6799 Mdot
.55321 .70383 Mdot
.49382 .4132 Mdot
.73002 .51946 Mdot
.34003 .64599 Mdot
.57839 .36162 Mdot
.44293 .59473 Mdot
.38973 .3627 Mdot
.47757 .36836 Mdot
.32426 .62593 Mdot
.33668 .61017 Mdot
.40008 .38027 Mdot
.24369 .59772 Mdot
.43528 .33896 Mdot
.56257 .70427 Mdot
.37191 .59437 Mdot
.34922 .61839 Mdot
.70625 .50338 Mdot
.40432 .60624 Mdot
.37852 .33453 Mdot
.61059 .68354 Mdot
.41112 .32684 Mdot
.57308 .6971 Mdot
.64173 .54542 Mdot
.71146 .56162 Mdot
.47546 .66931 Mdot
.40275 .60449 Mdot
.42963 .42605 Mdot
.39335 .59048 Mdot
.68004 .3594 Mdot
.34488 .62337 Mdot
.32018 .60975 Mdot
.39753 .40718 Mdot
.45257 .34377 Mdot
.4739 .58837 Mdot
.55532 .38776 Mdot
.3864 .60704 Mdot
.45659 .4212 Mdot
.40134 .42212 Mdot
.41451 .35204 Mdot
.57688 .3454 Mdot
.38264 .58153 Mdot
.29659 .58322 Mdot
.44293 .57819 Mdot
.39109 .60649 Mdot
.15611 .43288 Mdot
.4678 .59208 Mdot
.46169 .58697 Mdot
.57282 .7322 Mdot
.4086 .36857 Mdot
.70588 .54179 Mdot
.45177 .38268 Mdot
.41344 .45856 Mdot
.43218 .39981 Mdot
.67959 .37698 Mdot
.37931 .36659 Mdot
.48323 .5987 Mdot
.69952 .53142 Mdot
.46302 .40345 Mdot
.40913 .37916 Mdot
.46218 .58972 Mdot
.37655 .58221 Mdot
.40512 .62085 Mdot
.453 .58395 Mdot
.72251 .38787 Mdot
.59997 .69776 Mdot
.44969 .38908 Mdot
.68714 .53917 Mdot
.70688 .53462 Mdot
.39285 .58445 Mdot
.68032 .56983 Mdot
.59847 .70747 Mdot
.39232 .38449 Mdot
.5889 .70564 Mdot
.67909 .37646 Mdot
.38153 .60031 Mdot
.43836 .40321 Mdot
.45772 .37687 Mdot
.3927 .62366 Mdot
.44294 .34037 Mdot
.67415 .36583 Mdot
.72753 .55242 Mdot
.34128 .61973 Mdot
.57984 .68819 Mdot
.7105 .50563 Mdot
.44974 .41725 Mdot
.15065 .52913 Mdot
.40806 .39634 Mdot
.39406 .35408 Mdot
.38436 .56373 Mdot
.39124 .42323 Mdot
.7048 .51966 Mdot
.39796 .59397 Mdot
.46268 .41413 Mdot
.48693 .24824 Mdot
.66336 .34708 Mdot
.65248 .56833 Mdot
.40258 .40412 Mdot
.19185 .55423 Mdot
.41091 .42496 Mdot
.47023 .66886 Mdot
.55819 .32376 Mdot
.6334 .64945 Mdot
.47736 .28822 Mdot
.60317 .67905 Mdot
.47919 .58532 Mdot
.72171 .53981 Mdot
.29563 .53819 Mdot
.39898 .386 Mdot
.30521 .38784 Mdot
.44185 .4013 Mdot
.56986 .71013 Mdot
.34475 .51917 Mdot
.672 .5615 Mdot
.51866 .17116 Mdot
.43342 .35137 Mdot
.33745 .6373 Mdot
.7384 .53768 Mdot
.47625 .58326 Mdot
.45402 .34581 Mdot
.72701 .36703 Mdot
.67046 .33021 Mdot
.37337 .34342 Mdot
.57202 .69423 Mdot
.43192 .35844 Mdot
.37342 .42134 Mdot
.79416 .64279 Mdot
.37589 .62461 Mdot
.57694 .67516 Mdot
.75435 .39476 Mdot
.41134 .35474 Mdot
.40135 .62649 Mdot
.35441 .62503 Mdot
.71278 .39002 Mdot
.55163 .64758 Mdot
.64266 .3575 Mdot
.24633 .69988 Mdot
.31599 .2971 Mdot
.72001 .5613 Mdot
.35253 .66795 Mdot
.45285 .37281 Mdot
.64145 .23382 Mdot
.58117 .68363 Mdot
.4224 .39332 Mdot
.31896 .42096 Mdot
.3654 .62923 Mdot
.41891 .36546 Mdot
.71351 .36635 Mdot
.47651 .82949 Mdot
.22005 .51141 Mdot
.19385 .58064 Mdot
.69336 .58874 Mdot
.45987 .33495 Mdot
.38486 .32939 Mdot
.45651 .60411 Mdot
.44933 .43182 Mdot
.68958 .52092 Mdot
.57745 .59132 Mdot
.70599 .38065 Mdot
.38278 .59089 Mdot
.46903 .58607 Mdot
.44167 .40191 Mdot
.44613 .32697 Mdot
.67116 .36693 Mdot
.43619 .34291 Mdot
.25837 .55341 Mdot
.50601 .5927 Mdot
.71809 .51207 Mdot
.34383 .63975 Mdot
.47384 .35243 Mdot
.49222 .59037 Mdot
.40201 .4105 Mdot
.32956 .37245 Mdot
.43412 .38843 Mdot
.46504 .65554 Mdot
.39526 .62475 Mdot
.5718 .68697 Mdot
.38535 .35027 Mdot
.42212 .37423 Mdot
.62128 .48635 Mdot
.47713 .43793 Mdot
.44346 .3882 Mdot
.40298 .5891 Mdot
.37962 .5904 Mdot
.33613 .62901 Mdot
.69851 .50458 Mdot
.53078 .44259 Mdot
.58276 .70453 Mdot
.45089 .45222 Mdot
.57031 .72161 Mdot
.49097 .29651 Mdot
.67755 .38131 Mdot
.46905 .68103 Mdot
.39338 .38001 Mdot
.36919 .63952 Mdot
.26705 .29216 Mdot
.38597 .58183 Mdot
.61936 .70812 Mdot
.57717 .68238 Mdot
.37977 .61186 Mdot
.40433 .40247 Mdot
.54701 .39544 Mdot
.19863 .5975 Mdot
.55696 .70064 Mdot
.49899 .39858 Mdot
.65433 .58764 Mdot
.65935 .52967 Mdot
.16416 .41487 Mdot
.56652 .71635 Mdot
.5609 .80958 Mdot
.44959 .42085 Mdot
.39549 .59509 Mdot
.59772 .6919 Mdot
.57976 .65749 Mdot
.67764 .56999 Mdot
.46031 .38219 Mdot
.42157 .37196 Mdot
.47085 .60121 Mdot
.59265 .69605 Mdot
.35803 .33109 Mdot
.4628 .37488 Mdot
.51553 .6914 Mdot
.36743 .65304 Mdot
.83339 .55652 Mdot
.41669 .50373 Mdot
.31767 .41945 Mdot
.78364 .59927 Mdot
.34094 .61657 Mdot
.44061 .36117 Mdot
.47366 .43873 Mdot
.7192 .56546 Mdot
.397 .39245 Mdot
.6735 .51499 Mdot
.58252 .71567 Mdot
.41952 .68831 Mdot
.50842 .5421 Mdot
.5239 .64917 Mdot
.41166 .3953 Mdot
.2223 .52185 Mdot
.69035 .37921 Mdot
.60316 .73516 Mdot
.33798 .61219 Mdot
.42281 .43596 Mdot
.70333 .57682 Mdot
.68867 .50832 Mdot
.36523 .62566 Mdot
.53409 .78716 Mdot
.47069 .6723 Mdot
.41461 .33786 Mdot
.67378 .53925 Mdot
.44944 .52161 Mdot
.19654 .52479 Mdot
.59542 .72305 Mdot
.70302 .38179 Mdot
.71832 .53037 Mdot
.54753 .67868 Mdot
.47397 .4 Mdot
.36927 .61782 Mdot
.33357 .63729 Mdot
.57495 .53479 Mdot
.70658 .5528 Mdot
.69912 .36313 Mdot
.57182 .53894 Mdot
.54796 .51947 Mdot
.70808 .37241 Mdot
.68582 .50444 Mdot
.3564 .60144 Mdot
.36549 .63556 Mdot
.35064 .62253 Mdot
.28041 .5749 Mdot
.41242 .62918 Mdot
.63337 .29064 Mdot
.44341 .4346 Mdot
.2142 .54204 Mdot
.42847 .43369 Mdot
.55087 .6872 Mdot
.39277 .61198 Mdot
.555 .32329 Mdot
.3755 .41311 Mdot
.20452 .60038 Mdot
.43519 .37466 Mdot
.55865 .57288 Mdot
.40801 .36976 Mdot
.24186 .49615 Mdot
.4169 .6083 Mdot
.40977 .34448 Mdot
.61296 .69273 Mdot
.68495 .36086 Mdot
.31527 .63603 Mdot
.44369 .38261 Mdot
.46241 .78735 Mdot
.42745 .41361 Mdot
.43212 .67807 Mdot
.58612 .53358 Mdot
.73217 .3918 Mdot
.37708 .39325 Mdot
.69088 .58054 Mdot
.37773 .46421 Mdot
.21189 .53344 Mdot
.5581 .70345 Mdot
.22224 .5298 Mdot
.66676 .56 Mdot
.34144 .52098 Mdot
.36794 .40928 Mdot
.71002 .37969 Mdot
.44491 .64177 Mdot
.55975 .6978 Mdot
.39546 .37942 Mdot
.43209 .35249 Mdot
.53746 .6141 Mdot
.20232 .50744 Mdot
.34778 .34711 Mdot
.68407 .34588 Mdot
.21559 .50394 Mdot
.4401 .39151 Mdot
.65408 .57464 Mdot
.40824 .60749 Mdot
.35304 .51337 Mdot
.32696 .53318 Mdot
.46529 .38393 Mdot
.3776 .61582 Mdot
.40571 .61262 Mdot
.29354 .25605 Mdot
.69525 .386 Mdot
.4353 .38581 Mdot
.58632 .54567 Mdot
.44764 .39283 Mdot
.57674 .71171 Mdot
.38762 .42586 Mdot
.71025 .56147 Mdot
.50125 .47514 Mdot
.6956 .505 Mdot
.40964 .35121 Mdot
.37119 .60612 Mdot
.5578 .68439 Mdot
.6508 .68214 Mdot
.55732 .64678 Mdot
.6324 .29125 Mdot
.69217 .32069 Mdot
.71925 .35946 Mdot
.68019 .38767 Mdot
.58425 .73445 Mdot
.39747 .39966 Mdot
.5686 .37741 Mdot
.46971 .42525 Mdot
.40718 .36444 Mdot
.43358 .39256 Mdot
.63623 .70793 Mdot
.5758 .68271 Mdot
.71382 .53703 Mdot
.39925 .37978 Mdot
.45477 .42362 Mdot
.37567 .60742 Mdot
.71928 .36117 Mdot
.72634 .52946 Mdot
.72999 .36854 Mdot
.69463 .53222 Mdot
.22606 .33038 Mdot
.49817 .36589 Mdot
.68335 .36475 Mdot
.5828 .72513 Mdot
.35692 .63818 Mdot
.46251 .59959 Mdot
.6789 .55472 Mdot
.67474 .56371 Mdot
.47315 .35727 Mdot
.38912 .59927 Mdot
.40272 .60982 Mdot
.72825 .37546 Mdot
.58813 .67674 Mdot
.48292 .36939 Mdot
.4634 .35359 Mdot
.65842 .66608 Mdot
.72764 .5545 Mdot
.21398 .51747 Mdot
.42353 .58301 Mdot
.38998 .38785 Mdot
.3995 .62741 Mdot
.41946 .38252 Mdot
.45331 .53066 Mdot
.33227 .62438 Mdot
.39212 .42549 Mdot
.43126 .44889 Mdot
.72135 .5582 Mdot
.34533 .22179 Mdot
.47878 .34978 Mdot
.60709 .65499 Mdot
.4515 .36114 Mdot
.49016 .14459 Mdot
.27724 .2829 Mdot
.41242 .41419 Mdot
.3863 .35653 Mdot
.2257 .67466 Mdot
.40512 .42115 Mdot
.47762 .60128 Mdot
.41365 .45906 Mdot
.39247 .63345 Mdot
.57776 .55866 Mdot
.5622 .37951 Mdot
.69463 .38822 Mdot
.68589 .54176 Mdot
.57035 .28497 Mdot
.69456 .39421 Mdot
.36742 .63257 Mdot
.47286 .33754 Mdot
.41486 .57695 Mdot
.70148 .4926 Mdot
.36863 .32052 Mdot
.57353 .7119 Mdot
.56409 .38153 Mdot
.68822 .5759 Mdot
.5807 .68787 Mdot
.40836 .42534 Mdot
.68911 .48054 Mdot
.61142 .72309 Mdot
.30757 .23699 Mdot
.58187 .66453 Mdot
.56669 .68479 Mdot
.53993 .41405 Mdot
.6951 .38844 Mdot
.57504 .59935 Mdot
.5023 .4275 Mdot
.5546 .6869 Mdot
.52548 .18983 Mdot
.72159 .56552 Mdot
.53588 .45397 Mdot
.41637 .60093 Mdot
.5013 .38419 Mdot
.42566 .39558 Mdot
.57835 .66797 Mdot
.38137 .66344 Mdot
.62887 .47496 Mdot
.57537 .71728 Mdot
.36948 .38188 Mdot
.52443 .47941 Mdot
.4936 .59405 Mdot
.46676 .59373 Mdot
.66822 .35993 Mdot
.77261 .44395 Mdot
.3911 .6297 Mdot
.67733 .35309 Mdot
.52919 .30437 Mdot
.43499 .36882 Mdot
.5923 .70408 Mdot
.46477 .58731 Mdot
.57996 .69098 Mdot
.69393 .37436 Mdot
.67147 .37169 Mdot
.38279 .61834 Mdot
.33849 .61534 Mdot
.39012 .67439 Mdot
.45716 .23254 Mdot
.45279 .39909 Mdot
.29279 .39641 Mdot
.33557 .61173 Mdot
.30371 .54426 Mdot
.71169 .38661 Mdot
.72334 .37085 Mdot
.21359 .42298 Mdot
.4526 .41175 Mdot
.55937 .57975 Mdot
.43773 .39685 Mdot
.5714 .21704 Mdot
.43932 .40414 Mdot
.6828 .57087 Mdot
.4355 .34955 Mdot
.39068 .78229 Mdot
.46008 .41381 Mdot
.43136 .39676 Mdot
.69045 .55446 Mdot
.47005 .3467 Mdot
.7042 .56539 Mdot
.44045 .36341 Mdot
.71216 .33509 Mdot
.68731 .53969 Mdot
.72672 .3469 Mdot
.54513 .54682 Mdot
.47565 .59488 Mdot
.68723 .389 Mdot
.7201 .35852 Mdot
.58651 .3224 Mdot
.36299 .59396 Mdot
.38911 .51049 Mdot
.41833 .4033 Mdot
.73373 .53501 Mdot
.59552 .70945 Mdot
.46565 .37978 Mdot
.38068 .3963 Mdot
.48094 .35794 Mdot
.38217 .61558 Mdot
.70412 .49966 Mdot
.6868 .37045 Mdot
.68962 .51388 Mdot
.71622 .33807 Mdot
.71279 .56303 Mdot
.49176 .40471 Mdot
.47666 .39068 Mdot
.38923 .3262 Mdot
.31718 .45354 Mdot
.69593 .25721 Mdot
.36695 .62171 Mdot
.48561 .58982 Mdot
.6757 .3798 Mdot
.5443 .49269 Mdot
.38258 .63586 Mdot
.67855 .56574 Mdot
.42424 .36856 Mdot
.49244 .35355 Mdot
.49455 .43497 Mdot
.3475 .57779 Mdot
.74047 .37116 Mdot
.68221 .55075 Mdot
.49011 .60178 Mdot
.52889 .45264 Mdot
.30099 .58725 Mdot
.53629 .29771 Mdot
.42103 .37816 Mdot
.72864 .37767 Mdot
.38709 .59479 Mdot
.55822 .59698 Mdot
.57535 .66939 Mdot
.55391 .3914 Mdot
.41222 .39657 Mdot
.59695 .76676 Mdot
.3692 .60719 Mdot
.71771 .37121 Mdot
.5776 .66764 Mdot
.70281 .38644 Mdot
.49278 .58751 Mdot
.4302 .58146 Mdot
.45355 .34674 Mdot
.43745 .39873 Mdot
.58992 .71393 Mdot
.39628 .62563 Mdot
.69331 .33202 Mdot
.54729 .61399 Mdot
.67531 .55229 Mdot
.52985 .49289 Mdot
.38369 .59191 Mdot
.61645 .76374 Mdot
.68554 .51306 Mdot
.55298 .70908 Mdot
.56076 .37165 Mdot
.60166 .70129 Mdot
.438 .39134 Mdot
.36065 .60661 Mdot
.55918 .70731 Mdot
.65441 .64258 Mdot
.24215 .62348 Mdot
.46238 .63418 Mdot
.40317 .35368 Mdot
.45612 .68729 Mdot
.52206 .80275 Mdot
.32028 .66227 Mdot
.57178 .72088 Mdot
.41018 .38757 Mdot
.41626 .33775 Mdot
.43332 .35078 Mdot
.56772 .67634 Mdot
.63951 .72476 Mdot
.66782 .54172 Mdot
.422 .36134 Mdot
.69734 .35158 Mdot
.71414 .55486 Mdot
.65685 .55785 Mdot
.71764 .52847 Mdot
.3408 .60724 Mdot
.48858 .35039 Mdot
.43389 .46082 Mdot
.31731 .24995 Mdot
.56881 .68597 Mdot
.47611 .59499 Mdot
.39782 .34924 Mdot
.62579 .29822 Mdot
.3589 .6371 Mdot
.68445 .55917 Mdot
.42252 .39181 Mdot
.58184 .53407 Mdot
.5087 .6001 Mdot
.69609 .54524 Mdot
.33437 .61722 Mdot
.30116 .64932 Mdot
.39556 .38996 Mdot
.45382 .36868 Mdot
.38247 .62899 Mdot
.52299 .8172 Mdot
.52585 .46171 Mdot
.41729 .38138 Mdot
.57481 .68523 Mdot
.68976 .7862 Mdot
.41362 .42855 Mdot
.42971 .59712 Mdot
.49504 .60338 Mdot
.40753 .5699 Mdot
.23618 .56755 Mdot
.4522 .44732 Mdot
.37147 .6964 Mdot
.63951 .32572 Mdot
.32047 .68333 Mdot
.59556 .2267 Mdot
.5503 .61835 Mdot
.25915 .27303 Mdot
.58895 .65095 Mdot
.23628 .47508 Mdot
.36477 .81686 Mdot
.55633 .80469 Mdot
.61225 .50579 Mdot
.6319 .62315 Mdot
.66423 .49687 Mdot
.52781 .16272 Mdot
.68504 .58103 Mdot
.60278 .21745 Mdot
.43179 .40523 Mdot
.51274 .81458 Mdot
.23523 .49779 Mdot
.71943 .28695 Mdot
.4818 .67167 Mdot
.58056 .53728 Mdot
.17135 .56922 Mdot
.49921 .68029 Mdot
.17663 .44057 Mdot
.34371 .45019 Mdot
.79998 .47115 Mdot
.54477 .50289 Mdot
.58626 .29139 Mdot
.23132 .53636 Mdot
.36926 .75061 Mdot
.53675 .72313 Mdot
.26906 .35704 Mdot
.79908 .59156 Mdot
.67994 .53118 Mdot
.41067 .6135 Mdot
.61761 .60866 Mdot
.17666 .49346 Mdot
.62024 .68643 Mdot
.36962 .69645 Mdot
.5048 .62835 Mdot
.23976 .49084 Mdot
.54547 .32295 Mdot
.24026 .44013 Mdot
.64003 .35599 Mdot
.53302 .16816 Mdot
.32657 .58592 Mdot
.67579 .627 Mdot
.54971 .47849 Mdot
.62003 .38477 Mdot
.25611 .52495 Mdot
.67977 .34275 Mdot
.68071 .33937 Mdot
.33321 .62217 Mdot
.18663 .50589 Mdot
.5118 .60239 Mdot
.523 .30045 Mdot
.69067 .5823 Mdot
.46176 .53126 Mdot
.46834 .82522 Mdot
.51592 .79727 Mdot
.38409 .20248 Mdot
.15343 .51667 Mdot
.52774 .21829 Mdot
.54929 .59173 Mdot
.62867 .69361 Mdot
.61634 .31184 Mdot
.3428 .34187 Mdot
.50686 .21037 Mdot
.33026 .38569 Mdot
.19993 .6249 Mdot
.4852 .77443 Mdot
.15713 .55541 Mdot
.31582 .59881 Mdot
.4411 .3189 Mdot
.49807 .56059 Mdot
.31633 .30999 Mdot
.52028 .27052 Mdot
.16546 .5405 Mdot
.71858 .39997 Mdot
.39968 .64969 Mdot
.55962 .80285 Mdot
.25623 .55441 Mdot
.6358 .39257 Mdot
.74571 .32905 Mdot
.36386 .51189 Mdot
.16963 .59403 Mdot
.37679 .69825 Mdot
.24977 .32843 Mdot
.52298 .71307 Mdot
.73795 .506 Mdot
.6582 .5623 Mdot
.5854 .65837 Mdot
.16557 .4736 Mdot
.35797 .6122 Mdot
.3385 .22195 Mdot
.35463 .68189 Mdot
.36664 .45329 Mdot
.171 .60412 Mdot
.47099 .18955 Mdot
.22472 .55644 Mdot
.66702 .27123 Mdot
.66365 .77693 Mdot
.36918 .29534 Mdot
.56476 .64147 Mdot
.65218 .57985 Mdot
.45167 .6691 Mdot
.16611 .48619 Mdot
.50629 .19745 Mdot
.27562 .74201 Mdot
.51759 .29771 Mdot
.74904 .49596 Mdot
.33922 .57445 Mdot
.63167 .49393 Mdot
.64093 .41356 Mdot
.15556 .55033 Mdot
.22167 .49868 Mdot
.68417 .78189 Mdot
.58048 .23431 Mdot
.3187 .54054 Mdot
.44212 .70052 Mdot
.62175 .57097 Mdot
.35518 .29186 Mdot
.47697 .78714 Mdot
.44683 .33109 Mdot
.54246 .2922 Mdot
.35938 .49102 Mdot
.66588 .40084 Mdot
.52566 .45188 Mdot
.4867 .75705 Mdot
.54172 .24329 Mdot
.60465 .78811 Mdot
.36806 .51836 Mdot
.32803 .61099 Mdot
.50991 .21385 Mdot
.55437 .22356 Mdot
.53631 .75194 Mdot
.75456 .39234 Mdot
.24436 .33314 Mdot
.68232 .44911 Mdot
.43789 .4531 Mdot
.2353 .4682 Mdot
.23356 .5373 Mdot
.54647 .19015 Mdot
.4946 .40093 Mdot
.3524 .22841 Mdot
.51175 .65153 Mdot
.30437 .45946 Mdot
.51905 .25265 Mdot
.31359 .45637 Mdot
.20898 .56638 Mdot
.4722 .5592 Mdot
.6217 .64808 Mdot
.4076 .65534 Mdot
.17147 .5944 Mdot
.71637 .54491 Mdot
.50226 .20498 Mdot
.59698 .65365 Mdot
.65501 .65319 Mdot
.5769 .61047 Mdot
.63527 .47089 Mdot
.16876 .43648 Mdot
.54873 .79006 Mdot
.6405 .59401 Mdot
.34516 .74261 Mdot
.44201 .52034 Mdot
.29306 .40634 Mdot
.43094 .30697 Mdot
.33594 .40071 Mdot
.67394 .36621 Mdot
.31833 .50136 Mdot
.44326 .57151 Mdot
.76743 .33264 Mdot
.47138 .42935 Mdot
.55174 .50609 Mdot
.4803 .60672 Mdot
.56698 .39838 Mdot
.22437 .33038 Mdot
.43547 .30644 Mdot
.46762 .1933 Mdot
.54615 .79588 Mdot
.57361 .38615 Mdot
.63681 .40703 Mdot
.39087 .5201 Mdot
.15684 .56072 Mdot
.18374 .37712 Mdot
.46975 .80737 Mdot
.44238 .69 Mdot
.65773 .17791 Mdot
.62567 .64472 Mdot
.38065 .21885 Mdot
.60101 .65708 Mdot
.90375 .56413 Mdot
.69077 .51164 Mdot
.6472 .23122 Mdot
.31496 .33218 Mdot
.5882 .50036 Mdot
.18018 .50264 Mdot
.24469 .55134 Mdot
.74483 .35821 Mdot
.32762 .60198 Mdot
.48499 .42166 Mdot
.17213 .53898 Mdot
.17558 .59414 Mdot
.17331 .54471 Mdot
.59811 .75774 Mdot
.21099 .59181 Mdot
.20678 .65427 Mdot
.63564 .29023 Mdot
.5268 .60228 Mdot
.37027 .41421 Mdot
.44319 .22693 Mdot
.4384 .20452 Mdot
.70852 .40856 Mdot
.37308 .29327 Mdot
.32687 .58481 Mdot
.19321 .64064 Mdot
.22573 .32559 Mdot
.24264 .41483 Mdot
.18018 .4252 Mdot
.66354 .60764 Mdot
.46687 .22352 Mdot
.17501 .41247 Mdot
.36622 .73259 Mdot
.50873 .66958 Mdot
.21511 .67328 Mdot
.55686 .23154 Mdot
.6331 .62482 Mdot
.43472 .79118 Mdot
.41479 .20705 Mdot
.4319 .69977 Mdot
.6288 .61104 Mdot
.33682 .34251 Mdot
.31983 .57355 Mdot
.63797 .47062 Mdot
.36139 .74596 Mdot
.55318 .58427 Mdot
.50516 .24294 Mdot
.6595 .54832 Mdot
.49 .20706 Mdot
.62775 .41664 Mdot
.52893 .60502 Mdot
.57539 .29941 Mdot
.51594 .18861 Mdot
.44455 .77109 Mdot
.19239 .56839 Mdot
.54837 .79468 Mdot
.65519 .79103 Mdot
.48232 .71048 Mdot
.36314 .486 Mdot
.47072 .34699 Mdot
.17585 .50042 Mdot
.16761 .37184 Mdot
.16865 .42491 Mdot
.56188 .77352 Mdot
.70717 .59295 Mdot
.54634 .69503 Mdot
.6074 .31229 Mdot
.59917 .49025 Mdot
.49051 .63759 Mdot
.59974 .41642 Mdot
.57512 .65213 Mdot
.48242 .83063 Mdot
.40998 .6677 Mdot
.62504 .30197 Mdot
.26323 .37568 Mdot
.35798 .32476 Mdot
.19644 .52172 Mdot
.32331 .62523 Mdot
.57214 .77557 Mdot
.50483 .20933 Mdot
.71839 .54057 Mdot
.66235 .65586 Mdot
.41377 .64822 Mdot
.45365 .32192 Mdot
.68245 .60613 Mdot
.46698 .6283 Mdot
.31593 .41815 Mdot
.69123 .59471 Mdot
.23983 .3018 Mdot
.36972 .21764 Mdot
.17567 .4089 Mdot
.52446 .21111 Mdot
.66548 .63947 Mdot
.55389 .41669 Mdot
.62422 .66051 Mdot
.48976 .67314 Mdot
.54752 .46172 Mdot
.52709 .20483 Mdot
.22033 .55732 Mdot
.49341 .57659 Mdot
.44713 .45205 Mdot
.26148 .29753 Mdot
.60731 .28887 Mdot
.55922 .4209 Mdot
.36565 .53962 Mdot
.40239 .63994 Mdot
.7017 .25108 Mdot
.38277 .76386 Mdot
.40486 .46845 Mdot
.44749 .69368 Mdot
.59645 .72505 Mdot
.33019 .62549 Mdot
.51422 .18638 Mdot
.76482 .4057 Mdot
.3295 .67708 Mdot
.51552 .55902 Mdot
.17305 .4736 Mdot
.53217 .54065 Mdot
.42867 .69155 Mdot
.29227 .685 Mdot
.70812 .75402 Mdot
.3153 .60181 Mdot
.53998 .59377 Mdot
.58952 .5982 Mdot
.31443 .5898 Mdot
.35002 .58061 Mdot
.22172 .50868 Mdot
.15736 .4877 Mdot
.56737 .54281 Mdot
.35029 .73127 Mdot
.57009 .37977 Mdot
.6299 .48981 Mdot
.51117 .57792 Mdot
.57057 .28988 Mdot
.3437 .70959 Mdot
.21643 .38946 Mdot
.56117 .84102 Mdot
.3889 .28572 Mdot
.63818 .22372 Mdot
.60887 .31336 Mdot
.34598 .45255 Mdot
.25468 .51912 Mdot
.51041 .69584 Mdot
.44948 .37796 Mdot
.14902 .49765 Mdot
.49094 .7682 Mdot
.58458 .33895 Mdot
.62565 .55138 Mdot
.42602 .42464 Mdot
.38657 .32982 Mdot
.17298 .42086 Mdot
.37315 .55986 Mdot
.45412 .86346 Mdot
.58176 .22726 Mdot
.36689 .46695 Mdot
.22876 .56778 Mdot
.46251 .19623 Mdot
.46873 .55481 Mdot
.36343 .68468 Mdot
.63319 .42508 Mdot
.43901 .20014 Mdot
.32035 .71927 Mdot
.36847 .76409 Mdot
.47811 .70268 Mdot
.20594 .64765 Mdot
.39033 .48559 Mdot
.52279 .69935 Mdot
.67083 .60998 Mdot
.39062 .35596 Mdot
.53195 .78718 Mdot
.47269 .68944 Mdot
.68323 .46717 Mdot
.34239 .33647 Mdot
.16352 .37636 Mdot
.38394 .43706 Mdot
.53336 .77571 Mdot
.4336 .85257 Mdot
.51077 .87604 Mdot
.38276 .77753 Mdot
.15405 .54594 Mdot
.35547 .75476 Mdot
.4233 .696 Mdot
.58653 .73162 Mdot
.53977 .51418 Mdot
.30007 .38822 Mdot
.15264 .46795 Mdot
.78481 .4298 Mdot
.55191 .64194 Mdot
.28583 .34261 Mdot
.15083 .46904 Mdot
.40745 .45071 Mdot
.67589 .23633 Mdot
.74111 .51537 Mdot
.50948 .16249 Mdot
.39684 .19895 Mdot
.34625 .54789 Mdot
.53702 .18372 Mdot
.64811 .21603 Mdot
.69182 .29091 Mdot
.37702 .21729 Mdot
.35173 .28101 Mdot
.37283 .5452 Mdot
.51478 .21836 Mdot
.4585 .67215 Mdot
.59266 .15734 Mdot
.51102 .57461 Mdot
.51383 .62148 Mdot
.42288 .5744 Mdot
.45048 .66824 Mdot
.44607 .75691 Mdot
.5307 .57578 Mdot
.49337 .48901 Mdot
.20757 .55409 Mdot
.70888 .78006 Mdot
.33435 .75642 Mdot
.42232 .65267 Mdot
.1792 .59161 Mdot
.51777 .7086 Mdot
.55667 .45577 Mdot
.26249 .53744 Mdot
.60517 .29865 Mdot
.65403 .59899 Mdot
.43234 .40017 Mdot
.15733 .49242 Mdot
.65408 .59841 Mdot
.17841 .57169 Mdot
.31471 .23044 Mdot
.18835 .41938 Mdot
.41254 .3004 Mdot
.64772 .57495 Mdot
.45898 .2083 Mdot
.46066 .2105 Mdot
.21045 .62817 Mdot
.6215 .21179 Mdot
.53875 .47336 Mdot
.54049 .55997 Mdot
.50886 .54573 Mdot
.41784 .47452 Mdot
.45539 .19537 Mdot
.40233 .51911 Mdot
.52889 .2591 Mdot
.4465 .80354 Mdot
.52044 .1962 Mdot
.23129 .55509 Mdot
.59617 .30748 Mdot
.67138 .45015 Mdot
.74017 .35074 Mdot
.72939 .55281 Mdot
.25133 .71445 Mdot
.50476 .7189 Mdot
.34385 .23357 Mdot
.65907 .78566 Mdot
.48147 .78652 Mdot
.5997 .21238 Mdot
.48719 .57785 Mdot
.38016 .28128 Mdot
.79342 .45784 Mdot
.55039 .25245 Mdot
.21781 .51862 Mdot
.46592 .67242 Mdot
.32073 .55545 Mdot
.16228 .45142 Mdot
.50889 .24703 Mdot
.31515 .78838 Mdot
.75731 .56865 Mdot
.31882 .49566 Mdot
.19314 .49043 Mdot
.63369 .80453 Mdot
.56332 .41551 Mdot
.17262 .59705 Mdot
.40281 .58274 Mdot
.1544 .52094 Mdot
.58897 .66908 Mdot
.73006 .47115 Mdot
.50325 .65091 Mdot
.5915 .35126 Mdot
.59043 .35886 Mdot
.28157 .26865 Mdot
.55497 .79805 Mdot
.51729 .79948 Mdot
.68318 .44951 Mdot
.67199 .57511 Mdot
.51438 .51231 Mdot
.35667 .72764 Mdot
.25943 .72101 Mdot
.47773 .37263 Mdot
.7694 .54366 Mdot
.488 .19514 Mdot
.6258 .6622 Mdot
.5075 .62549 Mdot
.48985 .65473 Mdot
.28499 .64855 Mdot
.46252 .226 Mdot
.19927 .64034 Mdot
.49218 .62867 Mdot
.60473 .47168 Mdot
.33048 .52339 Mdot
.51926 .63281 Mdot
.61962 .77731 Mdot
.36319 .70386 Mdot
.52437 .54952 Mdot
.52876 .45849 Mdot
.53141 .21804 Mdot
.20554 .31875 Mdot
.18923 .61071 Mdot
.63677 .77783 Mdot
.57687 .38855 Mdot
.42896 .59909 Mdot
.56654 .27015 Mdot
.30819 .78385 Mdot
.51538 .15758 Mdot
.4457 .79066 Mdot
.5156 .1973 Mdot
.64348 .49697 Mdot
.65786 .22987 Mdot
.55458 .441 Mdot
.19319 .48752 Mdot
.30793 .32757 Mdot
.43237 .58014 Mdot
.62075 .57762 Mdot
.57193 .3653 Mdot
.53595 .62147 Mdot
.37409 .54314 Mdot
.55791 .79679 Mdot
.3165 .78926 Mdot
.61228 .20266 Mdot
.34312 .52228 Mdot
.33689 .79489 Mdot
.3511 .65436 Mdot
.59408 .60014 Mdot
.64215 .74889 Mdot
.57773 .38125 Mdot
.70339 .5135 Mdot
.34253 .36828 Mdot
.52226 .48747 Mdot
.33646 .7431 Mdot
.65273 .50463 Mdot
.69389 .39659 Mdot
.35342 .58397 Mdot
.63569 .21224 Mdot
.33589 .64288 Mdot
.22413 .30317 Mdot
.36935 .7308 Mdot
.21129 .54375 Mdot
.30529 .7214 Mdot
.70226 .61895 Mdot
.65881 .79293 Mdot
.17739 .43748 Mdot
.48629 .24884 Mdot
.34247 .5869 Mdot
.32025 .62665 Mdot
.31937 .71358 Mdot
.61774 .73986 Mdot
.17728 .47134 Mdot
.47682 .18994 Mdot
.67078 .64013 Mdot
.39255 .63853 Mdot
.54794 .56405 Mdot
.4209 .65074 Mdot
.23057 .31229 Mdot
.69329 .5143 Mdot
.16208 .58195 Mdot
.39484 .51371 Mdot
.57661 .81809 Mdot
.47235 .64317 Mdot
.50641 .46524 Mdot
.56745 .41859 Mdot
.65263 .63502 Mdot
.43405 .45581 Mdot
.36919 .46825 Mdot
.34139 .61044 Mdot
.56952 .61257 Mdot
.71647 .36017 Mdot
.76577 .35127 Mdot
.61265 .65491 Mdot
.33987 .45489 Mdot
.4423 .19203 Mdot
.32347 .62773 Mdot
.74934 .57662 Mdot
.75251 .59169 Mdot
.4384 .44647 Mdot
.40775 .23611 Mdot
.23614 .69119 Mdot
.17876 .44452 Mdot
.39147 .58043 Mdot
.63268 .79158 Mdot
.6497 .35506 Mdot
.24711 .29665 Mdot
.29512 .64904 Mdot
.47641 .19987 Mdot
.34966 .48928 Mdot
.1875 .38258 Mdot
.23617 .56703 Mdot
.41562 .67575 Mdot
.51296 .2108 Mdot
.62733 .47824 Mdot
.51092 .19137 Mdot
.28267 .64673 Mdot
.51478 .53608 Mdot
.5097 .1651 Mdot
.64069 .50462 Mdot
.23903 .44572 Mdot
.36736 .43857 Mdot
.4699 .64247 Mdot
.45175 .20204 Mdot
.36546 .58038 Mdot
.66406 .35427 Mdot
.27472 .36587 Mdot
.5056 .6623 Mdot
.16685 .48141 Mdot
.53607 .75374 Mdot
.49152 .19096 Mdot
.50355 .54286 Mdot
.60552 .26776 Mdot
.39859 .51257 Mdot
.51018 .28125 Mdot
.37873 .34954 Mdot
.35951 .49678 Mdot
.60949 .4227 Mdot
.28678 .27334 Mdot
.39106 .47516 Mdot
.17217 .51942 Mdot
.23786 .31721 Mdot
.29757 .67738 Mdot
.57234 .58812 Mdot
.40614 .62562 Mdot
.16454 .57513 Mdot
.42123 .22547 Mdot
.46747 .66035 Mdot
.40247 .19761 Mdot
.6997 .24765 Mdot
.35285 .80878 Mdot
.5089 .75054 Mdot
.46906 .62646 Mdot
.34358 .22312 Mdot
.49132 .77294 Mdot
.66307 .22363 Mdot
.21775 .51353 Mdot
.38586 .56447 Mdot
.17289 .60991 Mdot
.32536 .29616 Mdot
.50618 .79886 Mdot
.19826 .50682 Mdot
.3082 .6674 Mdot
.40926 .2283 Mdot
.4376 .45811 Mdot
.69896 .57555 Mdot
.57793 .51132 Mdot
.54387 .18503 Mdot
.31652 .66555 Mdot
.47032 .19627 Mdot
.47734 .20242 Mdot
.61348 .22245 Mdot
.66105 .63515 Mdot
.35395 .80913 Mdot
.2359 .59239 Mdot
.41895 .32171 Mdot
.38314 .57605 Mdot
.68297 .39107 Mdot
.5853 .23866 Mdot
.46227 .40254 Mdot
.54693 .35171 Mdot
.36049 .50593 Mdot
.15003 .48498 Mdot
.65659 .46756 Mdot
.52926 .70648 Mdot
.4052 .62984 Mdot
.45657 .66583 Mdot
.44859 .54964 Mdot
.55524 .80613 Mdot
.45873 .20376 Mdot
.32787 .67759 Mdot
.38212 .69241 Mdot
.49681 .796 Mdot
.5278 .23231 Mdot
.64577 .34192 Mdot
.55622 .70525 Mdot
.30956 .4039 Mdot
.23285 .65258 Mdot
.50606 .78593 Mdot
.40345 .64629 Mdot
.41997 .77335 Mdot
.51972 .53567 Mdot
.55503 .75157 Mdot
.55193 .79751 Mdot
.46207 .57122 Mdot
.20386 .41572 Mdot
.3177 .6955 Mdot
.65569 .58926 Mdot
.56455 .22495 Mdot
.38883 .75889 Mdot
.46406 .19915 Mdot
.42592 .44897 Mdot
.1788 .52092 Mdot
.58527 .34349 Mdot
.65255 .38055 Mdot
.45485 .35854 Mdot
.32502 .34401 Mdot
.17246 .42073 Mdot
.42269 .78829 Mdot
.34289 .31713 Mdot
.41768 .63317 Mdot
.3713 .21431 Mdot
.6753 .60013 Mdot
.69155 .59604 Mdot
.66506 .25833 Mdot
.49209 .47395 Mdot
.59627 .48925 Mdot
.63997 .69004 Mdot
.42346 .4549 Mdot
.65576 .33043 Mdot
.52215 .55747 Mdot
.31 .41062 Mdot
.37837 .223 Mdot
.24653 .7044 Mdot
.49964 .55459 Mdot
.38638 .19979 Mdot
.30582 .34309 Mdot
.36752 .56585 Mdot
.62224 .20491 Mdot
.36851 .29902 Mdot
.49307 .40796 Mdot
.66368 .3553 Mdot
.37913 .65346 Mdot
.2414 .69057 Mdot
.33623 .38494 Mdot
.66539 .41257 Mdot
.67026 .43746 Mdot
.51118 .56474 Mdot
.78748 .59168 Mdot
.51233 .65198 Mdot
.34591 .22047 Mdot
.50574 .20926 Mdot
.55015 .65578 Mdot
.34172 .74254 Mdot
.35583 .30451 Mdot
.1767 .52293 Mdot
.61783 .43954 Mdot
.1722 .45338 Mdot
.58943 .75911 Mdot
.32389 .44227 Mdot
.25031 .30818 Mdot
.53462 .28295 Mdot
.51491 .28616 Mdot
.3713 .53075 Mdot
.44328 .26581 Mdot
.46176 .59827 Mdot
.75245 .4104 Mdot
.57764 .15908 Mdot
.28406 .755 Mdot
.56699 .81616 Mdot
.37307 .43458 Mdot
.56124 .26611 Mdot
.31941 .70153 Mdot
.55296 .4657 Mdot
.64876 .42573 Mdot
.70392 .60413 Mdot
.62794 .58716 Mdot
.69429 .78234 Mdot
.15031 .49433 Mdot
.4554 .36177 Mdot
.60572 .38662 Mdot
.75245 .32979 Mdot
.67753 .51178 Mdot
.2547 .37812 Mdot
.2337 .68412 Mdot
.55405 .69444 Mdot
.66446 .73873 Mdot
.63615 .6646 Mdot
.28503 .26755 Mdot
.65404 .72761 Mdot
.59719 .74204 Mdot
.22319 .30335 Mdot
.46754 .80435 Mdot
.29811 .5873 Mdot
.70037 .7773 Mdot
.27107 .28749 Mdot
.35533 .48798 Mdot
.67335 .60195 Mdot
.16187 .51117 Mdot
.56522 .42081 Mdot
.64615 .60318 Mdot
.33573 .27566 Mdot
.5129 .20719 Mdot
.57555 .22704 Mdot
.53287 .69314 Mdot
.29723 .33719 Mdot
.76395 .29362 Mdot
.70768 .61829 Mdot
.6069 .83762 Mdot
.18251 .43854 Mdot
.2458 .64971 Mdot
.37919 .77241 Mdot
.69494 .45872 Mdot
.17962 .51258 Mdot
.47706 .20775 Mdot
.32355 .32404 Mdot
.77063 .42407 Mdot
.55158 .29275 Mdot
.58986 .28661 Mdot
.55725 .75121 Mdot
.18399 .40552 Mdot
.66725 .63106 Mdot
.38106 .27099 Mdot
.50038 .19999 Mdot
.31127 .34514 Mdot
.50841 .28276 Mdot
.22849 .64211 Mdot
.40322 .23441 Mdot
.53584 .20759 Mdot
.63571 .61805 Mdot
.68722 .33651 Mdot
.23909 .67938 Mdot
.43316 .53157 Mdot
.35094 .49588 Mdot
.43828 .855 Mdot
.15747 .55302 Mdot
.37035 .29688 Mdot
.38562 .42446 Mdot
.26291 .26808 Mdot
.75656 .55526 Mdot
.37306 .22658 Mdot
.45491 .81968 Mdot
.58518 .22345 Mdot
.40054 .48698 Mdot
.43616 .40829 Mdot
.64028 .27547 Mdot
.34175 .56659 Mdot
.31008 .33193 Mdot
.65686 .69195 Mdot
.52973 .20736 Mdot
.3444 .45886 Mdot
.56018 .84102 Mdot
.28384 .64118 Mdot
.37051 .64433 Mdot
.15767 .50274 Mdot
.26202 .33934 Mdot
.36332 .47423 Mdot
.18865 .49581 Mdot
.61246 .45121 Mdot
.65673 .33077 Mdot
.39526 .50822 Mdot
.55593 .41463 Mdot
.54491 .18286 Mdot
.3361 .79625 Mdot
.30041 .40039 Mdot
.16489 .59065 Mdot
.1789 .38641 Mdot
.37773 .64354 Mdot
.31865 .31532 Mdot
.58324 .389 Mdot
.31973 .68543 Mdot
.63792 .63569 Mdot
.65865 .64992 Mdot
.74181 .28761 Mdot
.76531 .34429 Mdot
.4147 .4131 Mdot
.59454 .76064 Mdot
.16386 .45172 Mdot
.73141 .27736 Mdot
.16169 .4637 Mdot
.36602 .49571 Mdot
.46454 .34254 Mdot
.51669 .87727 Mdot
.42374 .69395 Mdot
.48858 .384 Mdot
.44621 .46708 Mdot
.42696 .47001 Mdot
.44494 .38856 Mdot
.61709 .74492 Mdot
.61135 .30479 Mdot
.57436 .21528 Mdot
.16506 .50553 Mdot
.38868 .64415 Mdot
.56973 .41217 Mdot
.59909 .66092 Mdot
.56506 .34913 Mdot
.4966 .3036 Mdot
.60601 .70748 Mdot
.5749 .20668 Mdot
.7812 .59599 Mdot
.62924 .38956 Mdot
.47082 .63467 Mdot
.48441 .48533 Mdot
.37397 .67846 Mdot
.5955 .20298 Mdot
.63718 .71485 Mdot
.69266 .29235 Mdot
.49581 .19263 Mdot
.34638 .53503 Mdot
.52741 .71702 Mdot
.6627 .18596 Mdot
.55941 .42493 Mdot
.60473 .75629 Mdot
.3988 .28611 Mdot
.29241 .61226 Mdot
.19042 .44227 Mdot
.6715 .32889 Mdot
.47038 .60804 Mdot
.33714 .51826 Mdot
.17946 .50187 Mdot
.59444 .71911 Mdot
.19032 .33739 Mdot
.41854 .28649 Mdot
.25227 .38846 Mdot
.23043 .61191 Mdot
.54341 .59823 Mdot
.22086 .52326 Mdot
.38153 .34299 Mdot
.59273 .46939 Mdot
.77993 .58992 Mdot
.44535 .63653 Mdot
.51246 .58044 Mdot
.33102 .69356 Mdot
.63119 .22204 Mdot
.22065 .39479 Mdot
.43476 .3837 Mdot
.71743 .39572 Mdot
.56015 .39934 Mdot
.70134 .45231 Mdot
.74875 .49619 Mdot
.50968 .66678 Mdot
.59273 .20458 Mdot
.58171 .22794 Mdot
.20338 .50711 Mdot
.16915 .55509 Mdot
.36739 .44007 Mdot
.18656 .4305 Mdot
.65045 .45355 Mdot
.4551 .75712 Mdot
.41098 .23522 Mdot
.3308 .79107 Mdot
.38305 .48309 Mdot
.3981 .46122 Mdot
.1936 .35236 Mdot
.17674 .42839 Mdot
.52888 .64692 Mdot
.4566 .67916 Mdot
.5549 .15862 Mdot
.59192 .36027 Mdot
.70187 .78121 Mdot
.64375 .64197 Mdot
.21294 .32512 Mdot
.51887 .59658 Mdot
.39367 .29164 Mdot
.38666 .52253 Mdot
.48324 .42045 Mdot
.70304 .54172 Mdot
.29009 .6767 Mdot
.36835 .53316 Mdot
.46595 .27414 Mdot
.40496 .32291 Mdot
.60963 .59328 Mdot
.42849 .59429 Mdot
.28951 .76104 Mdot
.66613 .51432 Mdot
.60564 .46783 Mdot
.52462 .84051 Mdot
.78067 .59119 Mdot
.68673 .23668 Mdot
.20441 .62059 Mdot
.48967 .67056 Mdot
.52317 .5553 Mdot
.78857 .656 Mdot
.40863 .58365 Mdot
.36929 .57374 Mdot
.61605 .65407 Mdot
.61268 .27235 Mdot
.53334 .77977 Mdot
.38657 .82973 Mdot
.18882 .37758 Mdot
.42947 .44831 Mdot
.70037 .8059 Mdot
.49573 .19732 Mdot
.59665 .43185 Mdot
.53972 .78105 Mdot
.15886 .48746 Mdot
.62456 .55088 Mdot
.30854 .23672 Mdot
.37075 .74833 Mdot
.30361 .65737 Mdot
.60717 .28345 Mdot
.63565 .78728 Mdot
.54691 .56941 Mdot
.60966 .836 Mdot
.45464 .69846 Mdot
.58519 .29075 Mdot
.4148 .7852 Mdot
.32407 .59348 Mdot
.37106 .46796 Mdot
.37558 .72644 Mdot
.35143 .32479 Mdot
.33536 .6649 Mdot
.37661 .69722 Mdot
.63508 .3555 Mdot
.59252 .62177 Mdot
.42503 .68926 Mdot
.62771 .67846 Mdot
.34442 .54578 Mdot
.54614 .16723 Mdot
.76598 .53982 Mdot
.66013 .54219 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Kooooo`;o0000[?ooool001co
oooo00?o0000ooooooooool0Voooool2o`000:cooooo000Looooo`03o`000?oooooooooo09oooooo
0_l0002Xooooo`007?ooool2o`0009kooooo1?l0002Xooooo`007?ooool00ol0003oooooooooo`2M
ooooo`;o00000oooool2o`0000kooooo0_l0002Eooooo`007?ooool00ol0003oooooooooo`2Poooo
o`Ko00002_ooool4o`0000;ooooo1?l00003ooooo`;o0000R_ooool001cooooo00?o0000oooooooo
ool0X?ooool7o`000004ooooool0003o0000ooooo`Co000000Coooooo`000?l0003o00000oooool4
o`0000?ooooo0_l00009ooooo`;o0000Ooooool001cooooo00?o0000ooooooooool0X_ooool2o`00
0004ooooool0003o0000ooooo`;o000000?oooooo`000?l000000_l0000Iooooo`;o0000Ooooool0
01cooooo00?o0000ooooooooool0X_ooool2o`0000Gooooo0_l00003ooooo`;o0000VOooool001co
oooo00?o0000ooooooooool0Y?ooool3o`0000;ooooo0_l00003ooooo`;o00006Oooool2o`0007ko
oooo000Looooo`03o`000?oooooooooo0:Cooooo0ol0000Rooooo`;o0000O_ooool001cooooo00?o
0000ooooooooool0d_ooool2o`0007Gooooo000Looooo`03o`000?oooooooooo0:Oooooo0_l0000Y
ooooo`;o0000MOooool001cooooo00?o0000ooooooooool0Yoooool2o`0000;ooooo1?l0002Joooo
o`007?ooool00ol0003oooooooooo`2Iooooo`?o000000?oooooo`000?l000001_l00003ooooo`Oo
00009?ooool2o`0007Cooooo000Looooo`03o`000?oooooooooo08_ooooo0_l00008ooooo`Oo0000
00?oooooo`000?l000001ol000000ooooooo0000o`000002o`0000;ooooo0ol0000Sooooo`;o0000
M?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03
o`000?oooooooooo08_ooooo0ol00006ooooo`Go00000oooool3o`0000?ooooo1?l000000ooooooo
0000o`000002o`0000?ooooo0_l0000Vooooo`;o0000LOooool00006oooooomgMgOoV9RHoooooonH
V9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooo
oooo07oooooo0_l0000;ooooo`;o00000_ooool7o`0000Cooooo1?l00003ooooo`;o000000?ooooo
o`000?l000000_ooool3o`0000Kooooo0_l0000Rooooo`;o0000LOooool00003ooooool@413ooooo
00;ooooo00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo
07[ooooo0_l000000ooooooo0000o`000002o`0000oooooo2Ol00002ooooo`So000000?oooooo`00
0?l000001_l00006ooooo`;o0000UOooool00003ooooool0003ooooo00;ooooo00?o0000oooooooo
ool02oooool00onHV9So8B4Qonk^kP06ooooo`?o0000NOooool3o`000003ooooool0003o000000;o
00002_ooool2o`0000;ooooo0_l00002ooooo`;o00000_ooool2o`0000Cooooo1_l000001?oooooo
0000o`000?ooool3o`0001Cooooo0_l00003ooooo`;o0000Q?ooool00003ooooool0003ooooo00;o
oooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo07Wo
oooo0_l0000@ooooo`;o00000_ooool4o`0000Cooooo0_l00006ooooo`;o00001_ooool2o`0001Co
oooo0ol00003ooooo`;o000000?oooooo`000?l00000POooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08?ooooo
0_l00006ooooo`;o00001?ooool2o`0000Cooooo0_l00002ooooo`;o00000_ooool6o`0000;ooooo
1Ol0000;ooooo`;o00001?ooool2o`0000Oooooo0_l00021ooooo`0000KoooooogMgMonHV9Sooooo
oiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`23oooo
o`;o00002?ooool2o`0000;ooooo0ol00003ooooo`;o00000_ooool2o`0000?ooooo1Ol00002oooo
o`Go00002oooool2o`0000gooooo0_l00003ooooo`;o0000O?ooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0MOoo
ool2o`0001Kooooo0_l00003ooooo`;o00003?ooool5o`0000;ooooo0_l0000>ooooo`;o00001_oo
ool2o`0000Gooooo0_l00003ooooo`;o0000O?ooool001cooooo00?o0000ooooooooool0M?ooool5
o`0002Wooooo0ol00003ooooo`?o00002oooool3o`0000Kooooo0ol0000;ooooo`Co0000N?ooool0
01cooooo00?o0000ooooooooool0KOooool2o`0000Gooooo0_l000001?oooooo0000o`000?l0000B
ooooo`;o00002?ooool2o`000003ooooool0003o000000Sooooo0_l00003ooooo`?o00002oooool2
o`0000Sooooo0_l0000;ooooo`Co0000N?ooool001cooooo00?o0000ooooooooool0J_ooool5o`00
00Gooooo1_l0000>ooooo`;o00000_ooool2o`0000Kooooo1?l000000ooooooo0000o`00000Eoooo
o`;o00001Oooool2o`000003ooooool0003o000000Oooooo0_l00004ooooo`;o000000?oooooo`00
0?l000001_ooool2o`0007?ooooo000Looooo`03o`000?oooooooooo06[ooooo1?l00006ooooo`Go
00003?ooool2o`000003ooooool0003o000000;ooooo1?l00002ooooo`Co00006_ooool2o`0000;o
oooo0_l000000ooooooo0000o`000003o`0000;ooooo0_l00003ooooo`;o00001?ooool2o`000003
ooooool0003o000000Kooooo0_l0001cooooo`007?ooool00ol0003oooooooooo`1Sooooo`;o0000
2_ooool2o`0000Cooooo0_l0000:ooooo`;o00000_ooool2o`0000Gooooo1?l000001?oooooo0000
o`000?l0000Pooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o00004_ooool2o`0007Go
oooo000Looooo`03o`000?oooooooooo06?ooooo0_l00007ooooo`;o000000?oooooo`000?l00000
0ol0000=ooooo`?o000000?oooooo`000?l000002_ooool2o`0001Gooooo0_l00007ooooo`;o0000
1_ooool2o`00017ooooo1?l00002ooooo`;o0000MOooool001cooooo00?o0000ooooooooool0H?oo
ool3o`0000Wooooo0_l00003ooooo`?o00002oooool5o`000003ooooool0003o000000[ooooo1?l0
0002ooooo`;o00003oooool2o`0000Oooooo0_l00006ooooo`;o00004Oooool4o`0000Sooooo0_l0
00000ooooooo0000o`00001/ooooo`007?ooool00ol0003oooooooooo`1Pooooo`?o00002Oooool2
o`00013ooooo2Ol00002ooooo`;o00000_ooool2o`0000Cooooo2?l00007ooooo`;o00003oooool5
o`000004ooooool0003o0000o`00013ooooo0_l0000:ooooo`;o000000?oooooo`000?l00000K?oo
ool001cooooo00?o0000ooooooooool0J?ooool3o`000003ooooool0003o000000;ooooo0_l00003
ooooo`;o00001oooool2o`0000Cooooo0ol00002ooooo`;o00000_ooool2o`0000Kooooo1_l00005
ooooo`Co00003oooool9o`0008gooooo000Looooo`03o`000?oooooooooo06Sooooo0ol00005oooo
o`;o00000oooool2o`00023ooooo0ol00006ooooo`;o00002_ooool2o`0000[ooooo1_l0002;oooo
o`007?ooool00ol0003oooooooooo`1Hooooo`Co00002Oooool2o`00033ooooo1Ol00006ooooo`;o
00002?ooool4o`0000cooooo0_l0000Hooooo`Co00001Oooool2o`0006Sooooo000Looooo`;o0000
Eoooool6o`0000Oooooo1?l0000booooo`?o00001?ooool4o`0000[ooooo0_l0000Vooooo`Co0000
0_ooool2o`000004ooooool0003o0000o`0006Oooooo000Looooo`03o`000?oooooooooo05Kooooo
0_l0000:ooooo`?o0000=?ooool3o`0000Cooooo0_l00003ooooo`;o00002?ooool2o`0002_ooooo
0_l00002ooooo`;o0000Ioooool001cooooo00?o0000ooooooooool0G?ooool2o`0000Cooooo0_l0
000eooooo`Go00000oooool3o`000003ooooool0003o000000Sooooo0_l00003ooooo`;o00005_oo
ool2o`0000Kooooo1?l00006ooooo`;o0000JOooool001cooooo00?o0000ooooooooool0G?ooool2
o`0002Kooooo0_l0000Eooooo`Co00000_ooool3o`0000;ooooo1?l0000:ooooo`;o00005Oooool3
o`0000Kooooo1?l00006ooooo`;o0000JOooool001cooooo00?o0000ooooooooool0Q?ooool2o`00
01Kooooo0ol00007ooooo`Co00002Oooool2o`0001Kooooo0_l0000=ooooo`;o0000KOooool001co
oooo00?o0000ooooooooool0FOooool2o`00037ooooo0_l0000@ooooo`;o00001_ooool2o`0000_o
oooo0_l00004ooooo`;o00001_ooool2o`0000Sooooo0ol0000;ooooo`?o00002?ooool2o`0006?o
oooo000Looooo`03o`000?oooooooooo05;ooooo0_l00004ooooo`?o00008_ooool2o`000004oooo
ool0003o0000o`0000Wooooo0_l0000@ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Wo
oooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00006ooooo`;o00002?ooool3o`0000_o
oooo0_l00009ooooo`;o0000Hoooool001cooooo00?o0000ooooooooool0D?ooool4o`0000Cooooo
1?l0000Looooo`;o00000oooool2o`000004ooooool0003o0000o`0000Sooooo0_l0000Aooooo`;o
000000Goooooo`000?l0003o0000ooooo`02o`0000;ooooo0_l00004ooooo`?o00000_ooool3o`00
00cooooo0_l0000@ooooo`;o00003oooool2o`00067ooooo000Looooo`03o`000?oooooooooo053o
oooo0_l00007ooooo`?o00003Oooool2o`0000gooooo0_l00003ooooo`;o00003?ooool2o`0000Co
oooo0_l000000ooooooo0000o`00000:ooooo`Go00001?ooool8o`0000;ooooo0_l0000>ooooo`;o
00001oooool2o`0000Oooooo0_l0000?ooooo`;o0000HOooool001cooooo00?o0000ooooooooool0
JOooool2o`0001;ooooo0_l0000Booooo`;o000000?oooooo`000?l000002_ooool2o`000004oooo
ool0003o0000o`0000Cooooo1Ol00004ooooo`?o00005_ooool2o`0000Sooooo0_l00006ooooo`;o
00002_ooool2o`0005gooooo000Looooo`03o`000?oooooooooo05Kooooo0_l0000Aooooo`;o0000
1?ooool2o`0000Oooooo0_l0000Mooooo`;o00002?ooool5o`0000Cooooo1_l00003ooooo`?o0000
1?ooool2o`0001[ooooo0_l00006ooooo`;o00002_ooool2o`0005gooooo000Looooo`03o`000?oo
oooooooo05Kooooo0_l0000<ooooo`;o00000oooool2o`0000Cooooo0_l00007ooooo`;o000000Co
ooooo`000?l0003ooooo0_l0000Gooooo`;o00002?ooool6o`0000?ooooo0_l00002ooooo`;o0000
1Oooool3o`0000;ooooo0_l00005ooooo`;o00008_ooool2o`0006;ooooo000Looooo`03o`000?oo
oooooooo05Cooooo0_l0000>ooooo`;o00002?ooool2o`0000_ooooo0_l000000ooooooo0000o`00
0004ooooo`;o00004Oooool2o`0000Wooooo1Ol0000>ooooo`Co00000oooool2o`0000?ooooo0_l0
000Nooooo`;o00000_ooool3o`0000Gooooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`1C
ooooo`?o00006?ooool4o`0000[ooooo0_l00006ooooo`;o00004Oooool2o`0000Wooooo0_l00003
ooooo`?o00000_ooool2o`0000Sooooo0ol000000ooooooo0000o`000002o`0000?ooooo0_l00007
ooooo`?o00004?ooool2o`0000;ooooo0_l00003ooooo`;o00001Oooool2o`0005[ooooo000Loooo
o`03o`000?oooooooooo05?ooooo0_l0000Dooooo`;o00001Oooool2o`0000;ooooo0ol00005oooo
o`Co00009?ooool2o`000003ooooool0003o000000;o000000Coooooo`000?l0003ooooo0_l00005
ooooo`Oo00003?ooool4o`0000Wooooo0_l00005ooooo`?o00001_ooool2o`0000cooooo0_l0001C
ooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o000000Coooooo`000?l0003o00003oooool3
o`000004ooooool0003o0000ooooo`;o00002Oooool3o`0000;ooooo0_l00003ooooo`;o00007?oo
ool2o`0000Kooooo0_l00003ooooo`?o00000oooool2o`0000Kooooo1?l00006ooooo`Co00000_oo
ool4o`0000_ooooo0_l00006ooooo`;o00005?ooool2o`0005?ooooo000Looooo`;o0000Aoooool2
o`000003ooooool0003o000000;ooooo1_l0000=ooooo`Go000000?oooooo`000?l000003?ooool7
o`0000Oooooo0_l0000Gooooo`?o00001_ooool4o`0000;ooooo0_l0000;ooooo`Co00001_ooool9
o`0001?ooooo0_l0001Zooooo`007?ooool00ol0003oooooooooo`15ooooo`?o000000Coooooo`00
0?l0003o00000oooool4o`0000gooooo1?l00005ooooo`;o00001Oooool2o`0000;ooooo1Ol00009
ooooo`;o00000oooool2o`0001;ooooo0_l000000ooooooo0000o`000005ooooo`Go00000oooool2
o`0000Sooooo1Ol00004ooooo`Wo00002oooool2o`0000Oooooo0ol0001Yooooo`007?ooool00ol0
003oooooooooo`15ooooo`;o00000oooool2o`000003ooooool0003o000000kooooo0_l00003oooo
o`;o00001Oooool2o`0000Gooooo0ol00009ooooo`Co00000_ooool2o`0000?ooooo1Ol0000Boooo
o`;o00001Oooool:o`0000[ooooo1?l000000ooooooo0000o`000002o`000003ooooool0003o0000
00Co00002oooool2o`0000Sooooo0_l0001Yooooo`007?ooool00ol0003oooooooooo`1=ooooo`?o
00002oooool4o`0000Cooooo0_l0000<ooooo`;o00001_ooool7o`0000Sooooo1?l000001?oooooo
0000o`000?l0000Eooooo`[o00002oooool3o`000004ooooool0003o0000o`0000;ooooo0_l0000G
ooooo`Co00003Oooool2o`0005[ooooo000Looooo`03o`000?oooooooooo04Oooooo0_l00005oooo
o`;o00002oooool2o`0000Kooooo0_l00002ooooo`;o00004?ooool3o`0000[ooooo0_l00005oooo
o`?o00008_ooool2o`0000Oooooo1?l00003ooooo`Co00005_ooool3o`0000gooooo0ol0001Joooo
o`007?ooool00ol0003oooooooooo`17ooooo`;o00006oooool2o`000003ooooool0003o000000co
oooo0_l00007ooooo`;o00001_ooool2o`0000Wooooo0_l0000Oooooo`;o00001oooool4o`0000?o
oooo1?l0000Vooooo`?o0000F_ooool001cooooo00?o0000ooooooooool0?oooool2o`0000Wooooo
0_l0000Gooooo`?o00001_ooool2o`0000Oooooo0_l00007ooooo`;o00001Oooool3o`0000Cooooo
1?l000000ooooooo0000o`00000Wooooo`Co00004?ooool3o`0000gooooo0_l0001Yooooo`007?oo
ool00ol0003oooooooooo`0oooooo`;o00002Oooool2o`00017ooooo0_l000001?oooooo0000o`00
0?ooool2o`0000Oooooo0_l00005ooooo`Ko00001Oooool4o`0000;ooooo1_l000000ooooooo0000
o`000005o`0000;ooooo0_l0000:ooooo`;o00002oooool2o`000003ooooool0003o000000Sooooo
0ol00003ooooo`;o00003?ooool3o`0000cooooo0ol0000@ooooo`;o00000oooool2o`0005;ooooo
000Looooo`03o`000?oooooooooo043ooooo0ol00003ooooo`;o00005Oooool2o`000003ooooool0
003o000000?ooooo0_l00007ooooo`;o000000?oooooo`000?l000000ol000000ooooooo0000o`00
0009o`0000;ooooo0_l000000ooooooo0000o`00000=o`0000[ooooo0_l0000;ooooo`Oo00001ooo
ool2o`0000;ooooo0ol0000:ooooo`Go00001_ooool2o`000004ooooool0003o0000ooooo`;o0000
4Oooool2o`0000?ooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`10ooooo`?o00000ooo
ool2o`0000Gooooo0_l0000=ooooo`Ko000000?oooooo`000?l000000_l00007ooooo`;o000000?o
ooooo`000?l000001_ooool5o`0000Cooooo0_l00005ooooo`;o000000?oooooo`000?l000001_l0
000Jooooo`Ko000000?oooooo`000?l000002?ooool2o`0000_ooooo1Ol00004ooooo`Co000000?o
ooooo`000?l000004_ooool2o`0005Wooooo000Looooo`03o`000?oooooooooo03_ooooo0_l00008
ooooo`?o00001Oooool2o`0000gooooo2Ol00005ooooo`;o00001Oooool2o`0000Kooooo0ol00004
ooooo`Co00002Oooool2o`000004ooooool0003o0000o`0000?ooooo0_l0000:ooooo`;o00002_oo
ool3o`0000Cooooo0ol00008ooooo`;o00002_ooool2o`0000?ooooo1ol00005ooooo`;o00003ooo
ool5o`0005Kooooo000Looooo`03o`000?oooooooooo03_ooooo0_l00007ooooo`Co00001?ooool2
o`0000kooooo0ol00002ooooo`Co00001Oooool2o`0000Gooooo0_l00004ooooo`;o000000?ooooo
o`000?l000001?ooool4o`0000Wooooo0ol000000ooooooo0000o`000006o`0000Wooooo0_l00005
ooooo`;o00001?ooool2o`0000Gooooo0_l00006ooooo`Co00002_ooool2o`0000?ooooo1ol00005
ooooo`;o00001?ooool3o`0000[ooooo0ol00002ooooo`;o0000D_ooool001cooooo00?o0000oooo
ooooool0>_ooool2o`0000Sooooo0_l00006ooooo`Co00002?ooool2o`0000?ooooo0_l00004oooo
o`;o00001Oooool3o`0000Cooooo0_l00003ooooo`Go000000?oooooo`000?l000000_ooool5o`00
0003ooooool0003o000000;o00000oooool=o`0000oooooo0_l0000Cooooo`;o00004oooool2o`00
00Cooooo1?l00006ooooo`Co00002?ooool4o`0000;ooooo0_l0001Booooo`007?ooool00ol0003o
ooooooooo`0jooooo`;o00004_ooool2o`000003ooooool0003o000000Gooooo0_l00003ooooo`;o
00002oooool3o`000004ooooool0003o0000ooooo`;o00000oooool2o`000004ooooool0003o0000
ooooo`;o000000?oooooo`000?l000004ol000000ooooooo0000o`000004o`0000Sooooo0_l00004
ooooo`;o00001oooool3o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00006Oooool4
o`0000Kooooo1?l00008ooooo`Co0000E_ooool001cooooo00?o0000ooooooooool0DOooool3o`00
00Gooooo0_l000000ooooooo0000o`000004o`0000Cooooo0_l00002ooooo`Ko00001Oooool5o`00
00?ooooo6ol000001?oooooo0000o`000?l00007ooooo`;o00003Oooool3o`0000;ooooo1Ol0000B
ooooo`?o00002?ooool2o`0000;ooooo1?l000000ooooooo0000o`00000;ooooo`Co00000_ooool2
o`0005;ooooo000Looooo`03o`000?oooooooooo057ooooo0ol00005ooooo`;o000000?oooooo`00
0?l000001Ol00003ooooo`;o00000_ooool6o`0000Gooooo9ol0000Hooooo`;o00000_ooool4o`00
00gooooo0_l00003ooooo`?o00000oooool2o`000003ooooool0003o000000?o000000?oooooo`00
0?l000001ol00002ooooo`;o00001Oooool4o`0000;ooooo0_l0001Booooo`007?ooool2o`0006;o
oooo0_l0000:ooooo`;o00001?ooool2o`0000;ooooo9_l0000?ooooo`?o00001Oooool2o`0000;o
oooo0ol0000>ooooo`;o00002Oooool2o`000004ooooool0003o0000ooooo`go000000?oooooo`00
0?l000000oooool4o`0005Sooooo000Looooo`03o`000?oooooooooo03_ooooo0_l0000?ooooo`;o
00002_ooool2o`0001Wooooo0_l00002oooooa_o000000Coooooo`000?l0003ooooo2?l0000>oooo
o`Ko00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000009ooooo`;o00003_oooolBo`00
00Cooooo1?l00004ooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0>oooool2o`0000oo
oooo0_l00006ooooo`;o00000_ooool2o`00013ooooo0_l00007ooooo`?o00001?oooolCo`000004
ooooool0003o0000ooooo`Wo000000?oooooo`000?l000000_l00005ooooo`;o00002?ooool4o`00
00Kooooo0_l00002ooooo`;o00002Oooool2o`0000;ooooo0ol000000ooooooo0000o`000003oooo
o`;o000000?oooooo`000?l000004Ol00005ooooo`;o00001?ooool2o`0005;ooooo000Looooo`03
o`000?oooooooooo05Cooooo0_l0000Dooooo`;o00001oooool3o`0000Cooooo8?l000000ooooooo
0000o`000002o`0000Gooooo0_l0000:ooooo`;o00001_ooool2o`0000;ooooo0_l0000=ooooo`Ko
00000ooooolHo`0000;ooooo1?l0001Gooooo`007?ooool00ol0003oooooooooo`1Zooooo`;o0000
1oooool2o`0000?ooooo8ol000001?oooooo0000o`000?l0000Aooooo`;o00001_ooool2o`0000;o
oooo0_l0000=ooooo`Co00001_oooolMo`0005Oooooo000Looooo`03o`000?oooooooooo05;ooooo
0_l00002ooooo`;o00004_ooool2o`0000Oooooo0ol00002oooooa[o000000?oooooo`000?l00000
1_l00002ooooo`?o00004Oooool2o`0000?ooooo1?l00002ooooo`;o00005oooool=o`0000;ooooo
1ol000000ooooooo0000o`000003o`0005Sooooo000Looooo`03o`000?oooooooooo05;ooooo0_l0
0002ooooo`;o00005?ooool2o`0000Cooooo1?l000000ooooooo0000o`00000Io`000003ooooool0
003o000000Ko000000?oooooo`000?l000000_l00005ooooo`;o00002_ooool2o`0000?ooooo0_l0
000Loooooago0000F?ooool001cooooo00?o0000ooooooooool0<oooool2o`00027ooooo0_l0000?
ooooo`;o00000_ooool3o`0000Cooooo0_l000000ooooooo0000o`00000Ko`000003ooooool0003o
000000Ko000000?oooooo`000?l000000_l00005ooooo`;o00002_ooool6o`000003ooooool0003o
000001Oooooo0_l000000ooooooo0000o`00000Io`0005[ooooo000Looooo`03o`000?oooooooooo
03?ooooo0_l0000booooo`;o00000_ooool2o`0000?ooooo0ol00002oooooago000000?oooooo`00
0?l000001_l0000Fooooo`Ko000000?oooooo`000?l000004Oooool2o`0000Cooooo0_l00002oooo
oa[o0000F_ooool001cooooo00?o0000ooooooooool0<Oooool2o`0000Gooooo1?l0000Cooooo`;o
000000?oooooo`000?l000005_ooool2o`0000Cooooo0ol00002ooooobSo00000_ooool2o`0001;o
oooo1?l0000Dooooo`;o00001ooooolJo`0005_ooooo000Looooo`03o`000?oooooooooo037ooooo
0_l00004ooooo`Go00004oooool2o`000003ooooool0003o000001Kooooo0_l00007ooooo`;o0000
00?oooooo`000?l000009Ol00002ooooo`;o00004?ooool6o`000003ooooool0003o000000Wooooo
0_l00005ooooo`?o00000_ooool3o`0000;ooooo6Ol0001Looooo`007?ooool00ol0003ooooooooo
o`0gooooo`Co0000>?oooolVo`0000;ooooo0_l00002ooooo`;o00004?ooool6o`000003ooooool0
003o000000Wooooo0_l000000ooooooo0000o`000002ooooo`?o00000_ooool3o`0000?ooooo6?l0
001Looooo`007?ooool00ol0003oooooooooo`0fooooo`;o000000?oooooo`000?l000009?ooool2
o`0000Oooooo1Ol00004ooooo`;o000000?oooooo`000?l000008ol00002ooooo`;o00000_ooool2
o`0000oooooo1Ol00002ooooo`;o00002?ooool2o`0000?ooooo0_l00002ooooo`;o00001_ooool2
o`000003ooooool0003o000001Go0000GOooool001cooooo00?o0000ooooooooool0=_ooool2o`00
00_ooooo0_l00009ooooo`;o00003Oooool4o`0000Oooooo1Ol00004ooooo`;o00000ooooolSo`00
00Kooooo0_l0000?ooooo`Go00000_ooool5o`0000Gooooo0_l00005ooooo`Co00001_ooool2o`00
0004ooooool0003o0000oooooaCo00001oooool2o`0005Cooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003ooooooooo
o`13ooooo`;o00002Oooool2o`0000gooooo1Ol00006ooooo`;o00002Oooool2o`000003ooooool0
003o000001Wo00000_ooool3o`000004ooooool0003o0000o`0000Gooooo0_l0000?ooooo`Co0000
1?ooool4o`0000Kooooo0_l00004ooooo`Go00000_ooool2o`0000;ooooo6Ol00005ooooo`Co0000
E?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`13ooooo`?o00005Oooool3o`0000;ooooo0_l0000Aoooooaoo
000000?oooooo`000?l000000_ooool4o`0000Cooooo0_l0000=ooooo`Ko00003_ooool2o`0000Oo
oooo0_l00002ooooo`;o00000_ooool5o`0000;ooooo4_l00003ooooo`Co0000E_ooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo00?o0000ooooooooool0
A?ooool2o`0001Gooooo0ol00002ooooo`?o00002_ooool2o`0000Kooooo9_l00003ooooo`?o0000
2oooool:o`00023ooooo1?l000000ooooooo0000o`00000;o`0000Oooooo1?l0001Fooooo`0000?o
ooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oooooo
0ol0001Nooooo`;o000000?oooooo`000?l000001_ooool2o`000004ooooool0003o0000o`0000So
oooo0_l000000ooooooo0000o`00000Lo`0000Gooooo1?l0000;ooooo`[o00005Oooool2o`0000So
oooo0_l000001?oooooo0000o`000?l00005ooooo`;o000000Coooooo`000?l0003ooooo0_l00009
ooooo`;o0000E_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?oM
gMgoEEEEooooool00007ooooo`03o`000?oooooooooo03Sooooo0_l00008ooooo`;o00005oooool2
o`000004ooooool0003o0000ooooo`;o00001_ooool2o`000003ooooool0003o000000_ooooo5Ol0
0002ooooo`[o00000_ooool4o`0000gooooo0ol000000ooooooo0000o`00000Hooooo`;o00002?oo
ool2o`0000;ooooo0_l00004ooooo`;o00000_ooool2o`0000cooooo0_l00002ooooo`;o0000D_oo
ool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00omgMgOoc<c<o`000007
ooooo`03o`000?oooooooooo03Gooooo0_l000000ooooooo0000o`000008ooooo`;o00002Oooool2
o`0000cooooo0_l00004ooooo`;o00004Oooool2o`0000?ooooo7_l000000ooooooo0000o`000002
ooooo`Co00003?ooool3o`0001cooooo0_l0000Booooo`;o000000?oooooo`000?l000004Oooool2
o`0005;ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l000001ooo
ool00ol0003oooooooooo`0eooooo`;o00005_ooool2o`0000cooooo0_l00004ooooo`;o00004Ooo
ool4o`000003ooooool0003o000000ko000000?oooooo`000?l000003_l00002ooooo`Co00002_oo
ool4o`0000Oooooo1?l0000Booooo`Go00001?ooool2o`0000[ooooo1?l0000=ooooo`;o0000E_oo
ool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`00
0?oooooooooo03;ooooo0_l000000ooooooo0000o`00000Dooooo`Co00003?ooool2o`0000Cooooo
1?l0000>ooooo`Go000000Coooooo`000?l0003ooooo7Ol00003ooooo`Co00002_ooool4o`0000?o
oooo2?l00009ooooo`;o00002?ooool4o`0000;ooooo1?l00009ooooo`?o00003oooool3o`0000;o
oooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`0booooo`;o00002oooool2o`0000[ooooo
1?l0000<ooooo`;o00001Oooool3o`0000kooooo6?l000000ooooooo0000o`000008o`000003oooo
ool0003o000000?ooooo0ol00003ooooo`;o00002?ooool3o`000003ooooool0003o000000Go0000
2?ooool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`?o00000oooool2o`0000_ooooo
0_l0000Aooooo`;o00000_ooool2o`00057ooooo000Looooo`03o`000?oooooooooo02cooooo0_l0
0006ooooo`;o00000oooool2o`0000Cooooo0_l0000Jooooo`;o00001_ooool3o`0000gooooo1ol0
00000ooooooo0000o`000002o`000003ooooool0003o000001Go00000_ooool6o`0000;ooooo0ol0
0008ooooo`_o00002?ooool2o`0000Oooooo0_l00003ooooo`;o0000N_ooool001cooooo00?o0000
ooooooooool0;?ooool2o`0000Gooooo0ol00003ooooo`;o00001oooool2o`0001oooooo0ol0000=
ooooo`;o000000?oooooo`000?l000007ol00002ooooo`Go00000oooool2o`0000Sooooo1Ol00002
ooooo`Co00003?ooool2o`00017ooooo0_l0000Pooooo`;o0000D?ooool001cooooo00?o0000oooo
ooooool0<oooool2o`0000;ooooo0_l00009ooooo`;o00001Oooool2o`0002Sooooo0_l00003oooo
oaoo00001?ooool3o`000003ooooool0003o000000;o00002?ooool3o`0000Cooooo0_l0000>oooo
o`;o00001_ooool2o`0000?ooooo0_l00004ooooo`;o00001oooool2o`0001Oooooo0_l0001@oooo
o`007?ooool00ol0003oooooooooo`0fooooo`Go00003_ooool2o`0002oooooo2ol000000ooooooo
0000o`000009o`000003ooooool0003o000000?o00000_ooool5o`000003ooooool0003o0000017o
oooo0_l0000>ooooo`?o00001Oooool2o`0000?ooooo0_l00002ooooo`;o00002Oooool2o`0000ko
oooo0_l00007ooooo`;o00000_ooool2o`0004cooooo000Looooo`03o`000?oooooooooo02oooooo
0_l00005ooooo`;o000000?oooooo`000?l00000=Oooool2o`0000Kooooo0_l000000ooooooo0000
o`00000Do`0000Cooooo2Ol000000ooooooo0000o`000007ooooo`;o00001?ooool2o`0000kooooo
0_l00003ooooo`;o00003_ooool2o`000003ooooool0003o000001Kooooo0_l0000;ooooo`;o0000
C?ooool001cooooo00?o0000ooooooooool0;oooool2o`0000;ooooo0_l0000Dooooo`;o00009Ooo
ool7o`000004ooooool0003o0000o`0000;ooooo3?l000000ooooooo0000o`000004o`0000Kooooo
0ol00004ooooo`;o00002Oooool5o`000003ooooool0003o000000kooooo0_l0000Fooooo`;o0000
1?ooool2o`0006_ooooo000Looooo`03o`000?oooooooooo02Wooooo0_l00008ooooo`;o000000?o
ooooo`000?l000000_l0000?ooooo`?o00009_ooool5o`0000;ooooo0_l00005ooooo`So000000?o
ooooo`000?l000000ol00008ooooo`Co00000oooool2o`0000[ooooo1?l0000Hooooo`;o00003ooo
ool2o`0000Cooooo0_l0001[ooooo`007?ooool00ol0003oooooooooo`0Yooooo`;o00002oooool6
o`0000Kooooo0_l00006ooooo`;o00006Oooool2o`0000Cooooo0_l00005ooooo`Co00003?ooool6
o`000003ooooool0003o000000;o00001_ooool9o`0000_ooooo1?l00003ooooo`Co00004oooool2
o`0000oooooo0_l0001aooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00000_ooool2o`00
00Kooooo0_l00006ooooo`;o00006Oooool2o`0000Cooooo0_l00006ooooo`;o00001oooool2o`00
00gooooo0_l00004ooooo`Ko00000oooool3o`0000[ooooo1?l00003ooooo`Co0000AOooool2o`00
053ooooo000Looooo`03o`000?oooooooooo03Kooooo0_l00007ooooo`;o00002?ooool3o`0002So
oooo0_l00005ooooo`?o00002Oooool3o`000003ooooool0003o000000;ooooo1ol000001Ooooooo
0000o`000?l0003ooooo00;o00003?ooool2o`0002oooooo0_l0000Kooooo`;o0000D?ooool001co
oooo0_l0000booooo`?o00002oooool2o`0000Sooooo0_l0000Gooooo`;o00002?ooool3o`0000Co
oooo0ol00005ooooo`?o00000oooool3o`0000?ooooo0ol00003ooooo`Go00001Oooool3o`0000co
oooo1_l0000Gooooo`;o00004Oooool2o`0000;ooooo0_l00004ooooo`;o00006?ooool2o`0004go
oooo000Looooo`03o`000?oooooooooo037ooooo1Ol00008ooooo`Co00007oooool4o`0000Kooooo
1?l00004ooooo`;o00001oooool8o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l00000
0_l0000Eooooo`Ko00005oooool2o`0000?ooooo0_l00005ooooo`;o00001Oooool2o`0000Sooooo
0_l0000Hooooo`;o0000COooool001cooooo00?o0000ooooooooool0=?ooool2o`0000Sooooo1?l0
000Mooooo`Ko00001_ooool2o`0000Kooooo0_l00008ooooo`Co000000Goooooo`000?l0003o0000
ooooo`02o`000005ooooool0003o0000o`000?ooool01?l0000Gooooo`Co00001Oooool2o`0001Go
oooo0_l00005ooooo`;o00003Oooool2o`0001kooooo0_l00019ooooo`007?ooool00ol0003ooooo
ooooo`15ooooo`;o00006?ooool2o`000003ooooool0003o000000Sooooo0_l0000?ooooo`Co0000
00?oooooo`000?l000000ol000000ooooooo0000o`000005o`0001Sooooo0ol00003ooooo`?o0000
00?oooooo`000?l00000:oooool2o`0001kooooo0_l00019ooooo`007?ooool00ol0003ooooooooo
o`0aooooo`;o00004_ooool2o`0001Sooooo0_l0000;ooooo`;o00001_ooool2o`000003ooooool0
003o000000Gooooo0ol00002ooooo`Co000000?oooooo`000?l000000ol00006ooooo`;o00003_oo
ool8o`0000;ooooo0ol00002ooooo`;o00005_ooool2o`0007gooooo000Looooo`03o`000?oooooo
oooo02kooooo0_l000000ooooooo0000o`00000=ooooo`;o000000?oooooo`000?l00000;?ooool8
o`0000?ooooo0_l00005ooooo`;o00002?ooool2o`0000Cooooo0_l0000<ooooo`Ko00000_ooool2
o`0000;ooooo0_l000000ooooooo0000o`000002o`0000Sooooo0_l00003ooooo`;o00001oooool2
o`0000Gooooo0_l00007ooooo`;o0000KOooool001cooooo00?o0000ooooooooool0;Oooool3o`00
013ooooo0_l000000ooooooo0000o`000004ooooo`;o00009_ooool6o`0000Gooooo0_l00002oooo
o`;o000000Coooooo`000?l0003ooooo0ol000001?oooooo0000o`000?ooool2o`0001;ooooo0_l0
0002ooooo`?o00001?ooool2o`0000;ooooo0_l0000:ooooo`?o00000_ooool2o`0000Oooooo0ol0
0004ooooo`;o00001oooool2o`0000Wooooo0_l0001Rooooo`007?ooool00ol0003oooooooooo`0]
ooooo`;o00000oooool2o`000004ooooool0003o0000o`00013ooooo0ol0000Looooo`;o00002ooo
ool2o`000004ooooool0003o0000o`0000Kooooo0_l00004ooooo`Ko00004?ooool2o`0000?ooooo
1ol00003ooooo`?o00003oooool2o`0000;ooooo0_l00008ooooo`;o00005_ooool4o`0000;ooooo
0_l0000Eooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0<_ooool2o`000004ooooool0
003o0000o`0000gooooo0_l000001?oooooo0000o`000?l0000Looooo`;o00002Oooool2o`0000?o
oooo0ol000000ooooooo0000o`000007ooooo`;o00000_ooool2o`0001;ooooo2Ol00004ooooo`Co
00003oooool2o`0000?ooooo0_l00005ooooo`;o00005oooool4o`000004ooooool0003o0000oooo
o`;o00005Oooool2o`0004Oooooo000Looooo`03o`000?oooooooooo03oooooo0_l00004ooooo`;o
00000_ooool2o`00023ooooo0_l00005ooooo`;o00001oooool2o`0000Oooooo0_l0000Hooooo`Go
00001?ooool4o`0000Cooooo1?l00009ooooo`;o00002Oooool3o`00013ooooo0_l000000ooooooo
0000o`000002ooooo`;o00000oooool2o`00067ooooo000Looooo`03o`000?oooooooooo03?ooooo
0_l0000:ooooo`;o0000:_ooool2o`0000cooooo0_l0000Oooooo`;o00000_ooool2o`0000Oooooo
0_l00006ooooo`Co00005?ooool3o`00013ooooo1Ol00002ooooo`;o00000oooool2o`00067ooooo
000Looooo`03o`000?oooooooooo02gooooo0_l00003ooooo`?o00004?ooool2o`0002_ooooo0_l0
0005ooooo`Co00007Oooool2o`0000Wooooo0_l00008ooooo`;o00005Oooool2o`0001Cooooo0_l0
0003ooooo`;o0000I_ooool001cooooo00?o0000ooooooooool0;Oooool7o`0000Oooooo0_l00008
ooooo`;o00008_ooool4o`000003ooooool0003o000000Co00001Oooool4o`000003ooooool0003o
000001Wooooo2Ol00003ooooo`?o00001oooool2o`0000gooooo0_l00006ooooo`;o0000POooool0
01cooooo00?o0000ooooooooool0;oooool3o`0000Wooooo0_l00006ooooo`Co00000oooool2o`00
01gooooo1?l000000ooooooo0000o`000003o`0000Sooooo0_l000000ooooooo0000o`00000Ioooo
o`Wo00001?ooool2o`0000Gooooo0_l00007ooooo`;o00001_ooool3o`0000Sooooo0_l0000Boooo
o`Go0000Ioooool001cooooo00?o0000ooooooooool0;Oooool4o`0000Gooooo0_l00003ooooo`;o
00000oooool2o`000003ooooool0003o000000Gooooo0_l0000Hooooo`;o00001Oooool4o`0000;o
oooo1?l0000cooooo`;o00000oooool6o`0000?ooooo0_l00007ooooo`;o00000oooool2o`0000?o
oooo0_l0000>ooooo`;o00000_ooool5o`000003ooooool0003o000006Cooooo000Looooo`03o`00
0?oooooooooo02gooooo0_l00007ooooo`;o00000_ooool2o`0000Cooooo0_l00002ooooo`;o0000
0oooool4o`0001Oooooo0_l00005ooooo`Go000000?oooooo`000?l000000_l0000:ooooo`;o0000
9oooool4o`0000?ooooo1?l00007ooooo`;o00002?ooool2o`0000?ooooo0_l00002ooooo`;o0000
1Oooool2o`0000?ooooo0_l00004ooooo`?o000000?oooooo`000?l000002_ooool3o`0005Oooooo
000Looooo`;o0000;_ooool2o`0000Kooooo1?l000000ooooooo0000o`000007ooooo`?o00000ooo
ool4o`0001Oooooo0_l00008ooooo`;o000000?oooooo`000?l000003?ooool2o`0002Oooooo1?l0
000>ooooo`?o00004?ooool2o`0000Gooooo0_l000000ooooooo0000o`000003ooooo`;o000000?o
ooooo`000?l000001Ol00009ooooo`?o0000Eoooool001cooooo00?o0000ooooooooool0<?ooool2
o`0000?ooooo1?l00009ooooo`?o00007oooool3o`0001gooooo0ol0000Rooooo`;o00000_ooool2
o`0000cooooo0_l0000?ooooo`;o000000Coooooo`000?l0003o00000oooool4o`0000;ooooo2ol0
0003ooooo`;o0000G_ooool001cooooo00?o0000ooooooooool0<?ooool4o`0000?ooooo1?l00002
ooooo`?o00000_ooool4o`0001oooooo0_l0000:ooooo`;o00002Oooool2o`0000Kooooo0ol0000O
ooooo`;o000000Goooooo`000?l0003o0000ooooo`04o`0001;ooooo0_l00007ooooo`;o000000Co
ooooo`000?l0003o00000oooool4o`000003ooooool0003o000000co000000Coooooo`000?l0003o
oooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`0aooooo`?o00001Oooool2o`0000;ooooo
0ol00004ooooo`;o0000:oooool2o`0000Sooooo1?l00002ooooo`;o000000?oooooo`000?l00000
8?ooool2o`0000;ooooo1ol00004ooooo`;o00002_ooool4o`0000Kooooo0_l00006ooooo`;o0000
00Goooooo`000?l0003o0000ooooo`07o`000003ooooool0003o000000Co00000oooool3o`0005_o
oooo000Looooo`03o`000?oooooooooo037ooooo0_l00004ooooo`;o00002_ooool3o`0000Wooooo
0_l0000Hooooo`;o00001?ooool5o`0000Oooooo1Ol000001?oooooo0000o`000?ooool2o`0001go
oooo0_l00007ooooo`Co00001Oooool2o`000003ooooool0003o000000Oooooo0_l00008ooooo`;o
00001?oooolGo`0000?ooooo0_l0001Looooo`007?ooool00ol0003oooooooooo`0^ooooo`;o0000
1oooool2o`0000;ooooo0_l00006ooooo`?o00002Oooool2o`0001Cooooo1_l000001?oooooo0000
o`000?ooool5o`0000Wooooo0ol00009ooooo`;o00005_ooool4o`0000Oooooo1?l00008ooooo`;o
00005oooool3o`000003ooooool0003o000001Co00000_ooool2o`0005[ooooo000Looooo`03o`00
0?oooooooooo02kooooo0_l00004ooooo`;o00001Oooool2o`0000Gooooo0ol0000:ooooo`;o0000
5?ooool4o`000003ooooool0003o000000;o00001_ooool2o`0000Gooooo0_l000001?oooooo0000
o`000?l00008ooooo`;o000000?oooooo`000?l000004oooool2o`0000Cooooo0_l00004ooooo`?o
00006Oooool4o`0000Gooooo7Ol0001Jooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o0000
1?ooool4o`0000Cooooo0_l00004ooooo`Go00002?ooool2o`0001Oooooo1_l00006ooooo`;o0000
1?ooool8o`0000Wooooo1_l0000Dooooo`Ko00000_ooool3o`0001Wooooo1?l00005ooooo`Co0000
00?oooooo`000?l000005Ol0001Kooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00001_oo
ool2o`0000Cooooo0_l00006ooooo`?o00002?ooool2o`0001Kooooo2Ol0000:ooooo`;o000000?o
ooooo`000?l000000ol00009ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`00017ooooo
0_l000000ooooooo0000o`000002o`0000Cooooo1?l0000Nooooo`Co000000?oooooo`000?l00000
4ol0001Mooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o00003Oooool2o`0000Kooooo0ol0
0008ooooo`;o00005Oooool3o`000003ooooool0003o000000Co00003oooool2o`00017ooooo0_l0
000Aooooo`;o000000?oooooo`000?l000000_l00004ooooo`Go00001oooool2o`0001Cooooo6Ol0
001Nooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o00004oooool5o`0000Cooooo0_l0000D
ooooo`;o00000oooool2o`0000;ooooo1?l00007ooooo`;o00002?ooool2o`0000Sooooo0_l00004
ooooo`;o000000?oooooo`000?l000004_ooool2o`0000Sooooo1ol00004ooooo`?o00004OoooolM
o`0005gooooo000Looooo`03o`000?oooooooooo047ooooo1_l00004ooooo`;o00005?ooool2o`00
0003ooooool0003o000000;o00001Oooool2o`0000Gooooo0ol00008ooooo`;o00002?ooool2o`00
00Cooooo0_l000000ooooooo0000o`000002ooooo`;o00003Oooool5o`0000Kooooo3Ol0000Boooo
oako0000G?ooool001cooooo00?o0000ooooooooool0@Oooool2o`000003ooooool0003o000000Co
00002?ooool2o`0000Sooooo0_l00006ooooo`Co00001Oooool2o`0000Gooooo0_l00009ooooo`?o
00003_ooool2o`0000Cooooo0_l00003ooooo`Go00000oooool4o`000004ooooool0003o0000o`00
00Oooooo0_l000000ooooooo0000o`000006o`0001;ooooo0_l000000ooooooo0000o`00000Jo`00
05_ooooo000Looooo`03o`000?oooooooooo03;ooooo1?l0000;ooooo`;o000000Coooooo`000?l0
003ooooo0ol00008ooooo`;o00002?ooool2o`0000Gooooo1ol00006ooooo`;o000000?oooooo`00
0?l000002_ooool3o`0000kooooo0_l00009ooooo`Go00000oooool2o`0000?ooooo1Ol00009oooo
o`Ko00005_oooolMo`0000Kooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`0booooo`Go
00001Oooool2o`0000?ooooo1_l000000ooooooo0000o`000007ooooo`;o00002Oooool2o`000003
ooooool0003o000000;ooooo0ol00002ooooo`;o00001_ooool2o`000004ooooool0003o0000oooo
o`;o00001oooool3o`0001;ooooo0_l0000:ooooo`?o00001_ooool4o`000003ooooool0003o0000
00Gooooo1Ol0000Foooooaco000000?oooooo`000?l000001_ooool3o`00057ooooo000Looooo`03
o`000?oooooooooo02kooooo0_l00005ooooo`;o00001Oooool2o`0000?ooooo0ol000001?oooooo
0000o`000?l00009ooooo`;o00002Oooool2o`000004ooooool0003o0000ooooo`;o00002?ooool3
o`0000Kooooo0ol0000Looooo`;o00002_ooool4o`0000Wooooo0ol00005ooooo`So00002_ooool2
o`0000Cooooo0_l000000ooooooo0000o`00000Jo`0000[ooooo0_l0001Aooooo`007?ooool2o`00
02oooooo0ol0000Dooooo`Co00005?ooool2o`0000?ooooo0_l00008ooooo`?o00001_ooool2o`00
01Oooooo0_l0000Booooo`?o00000_ooool2o`0000Cooooo0_l00004ooooo`Co00000oooool3o`00
00[ooooo0_l00004ooooo`;o00000_oooolCo`0000;ooooo1_l0001Mooooo`007?ooool00ol0003o
ooooooooo`0_ooooo`;o00002_ooool2o`0000?ooooo0_l00003ooooo`Co00000oooool2o`000004
ooooool0003o0000o`0000_ooooo0_l0000Gooooo`;o00000_ooool2o`0000?ooooo0_l0000=oooo
o`;o00004oooool2o`0000;ooooo0_l00008ooooo`Go00004Oooool2o`0000Sooooo4ol000000ooo
oooo0000o`000005o`0005gooooo000Looooo`03o`000?oooooooooo02kooooo0ol00002ooooo`;o
00001_ooool3o`0000;ooooo0_l00002ooooo`Go00000oooool2o`000004ooooool0003o0000o`00
01;ooooo0_l0000@ooooo`;o00000_ooool2o`0000?ooooo0_l0000Dooooo`;o00001oooool3o`00
00Gooooo0_l00009ooooo`?o00001?ooool2o`0000gooooo0_l00009oooooa[o00001_ooool2o`00
01Oooooo0_l0000looooo`007?ooool00ol0003oooooooooo`0^ooooo`?o00000_ooool2o`0000Oo
oooo0_l00006ooooo`Go00001oooool2o`0000kooooo0_l00002ooooo`?o00001_ooool2o`0000Ko
oooo0_l00008ooooo`;o00003oooool2o`0000;ooooo1Ol00005ooooo`?o00000oooool4o`0000Co
oooo0_l00003ooooo`;o00001Oooool2o`0000kooooo0_l00008oooooa[o00001_ooool2o`0001Oo
oooo0_l0000Fooooo`;o00009?ooool001cooooo00?o0000ooooooooool0;_ooool3o`0000oooooo
0_l000000ooooooo0000o`000003ooooo`;o00005_ooool2o`000003ooooool0003o000000;o0000
1Oooool3o`0000Kooooo0_l0000Iooooo`;o00000_ooool5o`0000Gooooo0_l00004ooooo`Co0000
1?ooool2o`0000?ooooo0ol00004ooooo`;o00003_ooool4o`0000Gooooo6ol0000Oooooo`;o0000
5_ooool2o`0002Cooooo000Looooo`03o`000?oooooooooo02kooooo0ol00009ooooo`;o00001?oo
ool2o`000003ooooool0003o000000;ooooo0ol0000Fooooo`;o000000?oooooo`000?l000001_oo
ool3o`0000Kooooo0_l00003ooooo`?o00007Oooool7o`0000;ooooo0_l0000:ooooo`;o000000Co
ooooo`000?l0003o00005_ooool2o`0000Gooooo6?l000000ooooooo0000o`000005ooooo`;o0000
5oooool2o`0001Kooooo0_l0000Uooooo`007?ooool00ol0003oooooooooo`0dooooo`;o00001?oo
ool4o`0000;ooooo0_l00005ooooo`Co00005?ooool2o`0000[ooooo0_l00004ooooo`Go000000?o
ooooo`000?l000000ol0000:ooooo`;o00004Oooool5o`0000Cooooo0_l0000:ooooo`;o000000?o
ooooo`000?l000007?oooolJo`000003ooooool0003o000000Gooooo0ol0000Eooooo`?o00005_oo
ool2o`0002Gooooo000Looooo`03o`000?oooooooooo03Cooooo1?l00002ooooo`Co00002Oooool4
o`0000gooooo0_l00005ooooo`;o00004?ooool3o`0000;ooooo0ol00006ooooo`Co000000?ooooo
o`000?l000000_l00004ooooo`;o00001?ooool2o`0000_ooooo0_l0000=ooooo`;o00000_ooool2
o`0001;ooooo0_l00007oooooaWo00000_ooool2o`0000Cooooo1?l0000Eooooo`;o0000?_ooool0
01cooooo00?o0000ooooooooool0<_ooool2o`0000;ooooo0_l0000Iooooo`;o00001?ooool3o`00
00Cooooo0_l00004ooooo`;o00001?ooool2o`0000Cooooo0ol000000ooooooo0000o`000005o`00
00Cooooo1?l000000ooooooo0000o`000002o`0000Cooooo0_l00004ooooo`;o00002oooool2o`00
0003ooooool0003o000000Gooooo0_l00007ooooo`;o00000oooool2o`0000gooooo1?l00005oooo
o`Co000000?oooooo`000?l000005?l00006ooooo`;o0000Eoooool001cooooo00?o0000oooooooo
ool0<_ooool2o`0001gooooo0_l00004ooooo`;o00001Oooool2o`000004ooooool0003o0000oooo
o`;o00001?ooool5o`000004ooooool0003o0000ooooo`?o00000_ooool3o`0000Kooooo1ol00004
ooooo`Co00002_ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000001Oooool2
o`0000Oooooo0_l00003ooooo`;o00003Oooool4o`0000Gooooo1?l000000ooooooo0000o`00000?
o`0000?ooooo0_l00006ooooo`;o0000Eoooool001cooooo00?o0000ooooooooool0<Oooool2o`00
00Sooooo0_l0000Iooooo`;o00002?ooool3o`0000Wooooo1?l000000ooooooo0000o`000002o`00
0003ooooool0003o000000Ko000000?oooooo`000?l000001Ol00002ooooo`?o000000?oooooo`00
0?l000000_l0000:ooooo`;o000000?oooooo`000?l000000oooool3o`0000gooooo0_l00003oooo
o`;o00003Oooool2o`0000Sooooo0_l00004ooooo`;o000000?oooooo`000?l000002_l0000;oooo
o`;o0000Eoooool001cooooo00?o0000ooooooooool0<Oooool2o`0000Sooooo0_l0000Iooooo`;o
00001?ooool3o`000003ooooool0003o000000Cooooo0_l00003ooooo`[o000000?oooooo`000?l0
00001_l000000ooooooo0000o`000002o`000003ooooool0003o000000Go00001?ooool@o`0000Co
oooo0_l0000;ooooo`Co00000oooool2o`0001?ooooo0_l00002ooooo`;o00001oooool6o`0002So
oooo0_l00010ooooo`007?ooool00ol0003oooooooooo`1Looooo`Co00001_ooool2o`0000?ooooo
0ol000000ooooooo0000o`000002oooooa3o00000oooool4o`0000Cooooo4Ol0000Aooooo`Co0000
0_ooool2o`00013ooooo0_l00002ooooo`;o00000oooool4o`0000Cooooo1_l0000Xooooo`;o0000
@?ooool001cooooo00?o0000ooooooooool0<_ooool2o`0002Sooooo1?l00002ooooo`;o00000_oo
ool2o`0000;ooooo1?l00004oooooa3o00002Oooool2o`000004ooooool0003o0000ooooo`ko0000
5oooool4o`0000kooooo0_l00007ooooo`Co00001_ooool5o`0001[ooooo0_l0000;ooooo`;o0000
@?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0
003o410@olc<c006ooooo`03o`000?oooooooooo03;ooooo1ol00008ooooo`;o00001_ooool2o`00
013ooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool2o`000004ooooool0003o0000
o`0000Cooooo4_l00005ooooo`;o00000_ooool2o`0000Cooooo3ol000000ooooooo0000o`000009
ooooo`;o000000?oooooo`000?l000001oooool2o`0000Sooooo0_l00008ooooo`?o00000_ooool5
o`0000Oooooo0ol00002ooooo`;o00001?ooool2o`0000Oooooo0_l00007ooooo`Co00000_ooool2
o`0000?ooooo0_l00012ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?oo
ool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0<oooool6o`0000Sooooo
0_l00002ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`0000;ooooo0_l00006ooooo`;o
00002Oooool2o`000004ooooool0003o0000o`0000Cooooo3?l000001Ooooooo0000o`000?l0003o
oooo00;o00001?ooool3o`0000;ooooo0_l00002oooooa?o00000_ooool2o`0000Gooooo0_l00000
0ooooooo0000o`000003o`0000;ooooo1?l00008ooooo`;o00002?ooool3o`0000Cooooo0ol00000
1?oooooo0000o`000?ooool2o`000003ooooool0003o000000?ooooo0_l00004ooooo`;o00001ooo
ool2o`0000Oooooo1?l00002ooooo`;o00000oooool2o`0004;ooooo00000ooooooo410@ooooo`02
ooooo`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo03Cooooo0_l00007ooooo`Co00001?ooool2o`000004ooooool0003o0000ooooo`;o0000
0_ooool2o`0000;ooooo0_l0000<ooooo`Co00001Oooool2o`0000;ooooo5_l00004ooooo`;o0000
0_ooool3o`000003ooooool0003o0000017o00000_ooool2o`0000Kooooo0_l000000ooooooo0000
o`000002o`0000;ooooo1?l00002ooooo`?o00001_ooool2o`0000[ooooo0_l00004ooooo`Go0000
00?oooooo`000?l000006oooool3o`0000Sooooo0_l0000Gooooo`;o0000:Oooool00003ooooool0
003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo
0ol0000mooooo`Co00002_ooool2o`0000gooooo0_l00005ooooo`Co00000_ooool2o`000003oooo
ool0003o000001[o00000_ooool4o`000004ooooool0003o0000oooooaCo00000oooool2o`0000Co
oooo0_l00008ooooo`;o00000oooool3o`0000Kooooo0_l00002ooooo`;o00000oooool2o`000003
ooooool0003o000000Cooooo1Ol0000Oooooo`;o00001oooool2o`0001Sooooo0_l0000Yooooo`00
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`01_ooool00ol0003oooooooooo`0dooooo`;o00003_ooool2o`0000cooooo0_l00006ooooo`;o
00001oooool3o`000004ooooool0003o0000oooooaWo000000?oooooo`000?l000001?ooool4o`00
0003ooooool0003o000000oo00000_ooool2o`0000?ooooo0ol00005ooooo`;o00006?ooool2o`00
00?ooooo0_l00007ooooo`;o000000?oooooo`000?l000001Oooool2o`00027ooooo0_l00013oooo
o`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`03oeEEEOn7QhOooooo00So
oooo00?o0000ooooooooool0=?ooool2o`0000kooooo1?l0000:ooooo`;o00001Oooool2o`0000Wo
oooo7ol000000ooooooo0000o`000003ooooo`;o000000Coooooo`000?l0003ooooo4?l00009oooo
o`;o00001Oooool2o`0000?ooooo0_l0000?ooooo`;o000000?oooooo`000?l000000_l00008oooo
o`;o00001?ooool2o`0000Gooooo0_l0000>ooooo`;o0000E_ooool00006oooooomgMgOoV9RHoooo
oonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo03Cooooo0_l00004
ooooo`;o00002_ooool5o`0000Kooooo0_l00006ooooo`Co00001_ooool=o`000003ooooool0003o
0000013o000000Coooooo`000?l0003ooooo1Ol00005ooooo`co00005?ooool2o`000005ooooool0
003o0000o`000?ooool00ol0000:ooooo`;o000000?oooooo`000?l000000_l00008ooooo`Co0000
6Oooool2o`0000oooooo0_l00015ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`04
olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0=?ooool2o`0000Cooooo0_l0000;oooo
o`Co00001_ooool2o`0000Sooooo0_l00006ooooob7o000000?oooooo`000?l000000_l000000ooo
oooo0000o`000008ooooo`Ko00004Oooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2
o`000004ooooool0003o0000o`0000gooooo1?l0000:ooooo`;o0000:_ooool2o`0004Gooooo000L
ooooo`03o`000?oooooooooo04Wooooo0_l0000Iooooo`Co000000?oooooo`000?l000006Ol00000
1?oooooo0000o`000?ooool2o`00027ooooo1_l0000Dooooo`;o00001?ooool2o`0001?ooooo1?l0
000Jooooo`;o0000BOooool001cooooo00?o0000ooooooooool0=Oooool2o`0000Sooooo0_l0000A
ooooo`;o00004?ooool4o`000003ooooool0003o000001_o000000Coooooo`000?l0003o00006Ooo
ool2o`0000?ooooo1?l000000ooooooo0000o`000002o`0000cooooo0_l00006ooooo`;o00001?oo
ool2o`0001?ooooo1?l0000Jooooo`;o00006_ooool2o`0002gooooo000Looooo`03o`000?oooooo
oooo03Gooooo0_l00006ooooo`Co00002Oooool3o`0000Gooooo0_l0000@oooooako000000?ooooo
o`000?l000001?l0000Jooooo`;o00000oooool4o`00017ooooo0_l0000:ooooo`?o00007?ooool2
o`00033ooooo0_l0000]ooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00000_ooool2o`00
00Oooooo0ol0000@ooooo`;o00001?oooolOo`000003ooooool0003o000000;o00003_ooool2o`00
00Wooooo0ol0000Vooooo`?o00003?ooool2o`0000;ooooo0_l0000:ooooo`;o00005_ooool2o`00
04Oooooo000Looooo`03o`000?oooooooooo047ooooo0_l00008ooooo`;o00004?ooool2o`0000Co
oooo9?l0000=ooooo`?o00001Oooool7o`0003;ooooo0_l000000ooooooo0000o`000002ooooo`;o
00008_ooool2o`0004Oooooo000Looooo`03o`000?oooooooooo04_ooooo0_l00004ooooo`;o0000
2?ooool2o`0000Kooooo0_l000000ooooooo0000o`00000Go`000003ooooool0003o000000Co0000
3?ooool5o`000003ooooool0003o000000;ooooo1_l00003ooooo`;o00003Oooool2o`0000oooooo
0_l00006ooooo`;o00001_ooool2o`0007;ooooo000Looooo`03o`000?oooooooooo04kooooo0_l0
00000ooooooo0000o`000008ooooo`;o00001_ooool3o`0000?ooooo5_l00002ooooo`Go00001ooo
ool3o`0000;ooooo1Ol000000ooooooo0000o`00000;ooooo`;o00002_ooool2o`000003ooooool0
003o000000oooooo0_l00004ooooo`Co000000Coooooo`000?l0003ooooo0_l00003ooooo`;o0000
Koooool001cooooo00?o0000ooooooooool0?Oooool2o`0000gooooo1?l0000Cooooo`Go000000?o
ooooo`000?l000004ol000000ooooooo0000o`000003o`0000Wooooo0ol00005ooooo`;o00001Ooo
ool3o`0000cooooo0_l00004ooooo`;o00000_ooool2o`0000Kooooo1?l0000:ooooo`;o00000ooo
ool:o`0002?ooooo0_l0000Fooooo`;o0000<_ooool001cooooo00?o0000ooooooooool0>oooool4
o`0000Sooooo0_l00003ooooo`?o00002Oooool2o`0000_ooooo0ol000000ooooooo0000o`00000C
o`000003ooooool0003o000000[ooooo1Ol00005ooooo`?o000000Coooooo`000?l0003ooooo0ol0
000<ooooo`;o00000oooool2o`0000;ooooo1Ol000000ooooooo0000o`000006o`0000_ooooo0_l0
0002ooooo`So00009?ooool3o`0001Gooooo0_l0000booooo`007?ooool00ol0003oooooooooo`0k
ooooo`;o00002_ooool2o`0000oooooo0_l00002ooooo`;o00000_ooool2o`0000Oooooo6?l0000:
ooooo`Co00001_ooool3o`000003ooooool0003o000000cooooo0_l00007ooooo`;o00000_ooool5
o`000003ooooool0003o000000?o000000?oooooo`000?l000000oooool4o`0000Cooooo0ol00000
1?oooooo0000o`000?l00003ooooo`;o00009Oooool2o`0004Wooooo000Looooo`03o`000?oooooo
oooo03oooooo0_l0000;ooooo`?o00002Oooool3o`000003ooooool0003o000000Co00002?ooool3
o`000003ooooool0003o000000[o000000?oooooo`000?l000001?l00002ooooo`;o00001oooool2
o`0001Sooooo1?l00005ooooo`Co00000oooool3o`0000Oooooo1?l000000ooooooo0000o`000002
o`000003ooooool0003o000000;ooooo0_l0001iooooo`007?ooool2o`00043ooooo0_l00007oooo
o`;o00000_ooool3o`0000Wooooo2?l0000=ooooo`?o000000?oooooo`000?l000001?l00003oooo
o`Ko00000oooool4o`0001Wooooo1Ol000000ooooooo0000o`000002o`0000Cooooo1ol00002oooo
o`;o000000?oooooo`000?l000000_l00002ooooo`Co00000_ooool2o`0000;ooooo0_l00002oooo
o`?o000000?oooooo`000?l00000?oooool2o`0003Cooooo000Looooo`03o`000?oooooooooo03oo
oooo0_l00007ooooo`;o00004Oooool2o`00013ooooo2Ol000001?oooooo0000o`000?ooool3o`00
00Cooooo0_l00002ooooo`;o00003?ooool2o`0000Kooooo1?l000000ooooooo0000o`000003o`00
00Wooooo0ol00002ooooo`Ko000000?oooooo`000?l000001?l000000ooooooo0000o`000003o`00
00Cooooo0_l00003ooooo`Ko0000?_ooool2o`0003Cooooo000Looooo`03o`000?oooooooooo03oo
oooo0_l0000<ooooo`?o00002oooool2o`0000;ooooo0_l00002ooooo`;o00002Oooool5o`000004
ooooool0003o0000ooooo`;o00000_ooool2o`0000Cooooo0_l00003ooooo`;o00002oooool2o`00
00Kooooo1?l00007ooooo`;o00001oooool2o`0000Cooooo1ol000000ooooooo0000o`000007o`00
00Cooooo0_l000000ooooooo0000o`000002ooooo`Co00001oooool2o`0001kooooo0_l0001;oooo
o`007?ooool00ol0003oooooooooo`1=ooooo`?o00002oooool2o`0000;ooooo0_l00002ooooo`;o
00002?ooool2o`000004ooooool0003o0000o`0000;ooooo0_l00004ooooo`;o00002Oooool2o`00
00cooooo0_l00006ooooo`?o00000oooool8o`0000Gooooo0ol00002ooooo`go00001_ooool2o`00
00Cooooo0_l00003ooooo`;o00002?ooool2o`0001kooooo0_l0000Booooo`;o0000=oooool001co
oooo00?o0000ooooooooool0I?ooool2o`0000?ooooo0_l00002ooooo`;o00001_ooool2o`000003
ooooool0003o000001[ooooo0_l00002ooooo`;o00000_ooool3o`000003ooooool0003o000000Co
00000_ooool2o`0000Cooooo1?l000000ooooooo0000o`00000<o`0000Kooooo0_l00002ooooo`;o
0000@oooool2o`0003Oooooo000Looooo`03o`000?oooooooooo063ooooo0_l000001?oooooo0000
o`000?l00003ooooo`;o00001?ooool4o`0000Gooooo0_l00007ooooo`;o00003?ooool4o`0000Co
oooo1ol00002ooooo`Ko00002?ooool2o`000003ooooool0003o000000ko00001_ooool2o`0000;o
oooo0_l00005ooooo`;o0000MOooool001cooooo00?o0000ooooooooool0H?ooool5o`0000[ooooo
1?l0000>ooooo`;o00003?ooool4o`0000;ooooo2?l00004ooooo`Co00002ooooolCo`0000_ooooo
0_l00002ooooo`;o0000MOooool001cooooo00?o0000ooooooooool0@_ooool2o`0001Sooooo0_l0
0002ooooo`?o00002oooool4o`0000Wooooo1?l0000@ooooo`ko00001?ooool2o`000003ooooool0
003o000000[ooooo4ol0000;ooooo`;o00000_ooool2o`0007Gooooo000Looooo`03o`000?oooooo
oooo04;ooooo0_l00002ooooo`;o00004oooool4o`000003ooooool0003o000000Gooooo0_l00005
ooooo`Go00001oooool5o`0000Cooooo0_l0000<ooooo`Ko00000_ooool4o`0000Oooooo0_l00008
oooooaCo00004?ooool2o`0007Gooooo000Looooo`03o`000?oooooooooo04Kooooo0_l00002oooo
o`;o00003oooool4o`0000Sooooo0_l00007ooooo`?o00000oooool6o`0000Oooooo0_l00004oooo
o`;o00001_ooool5o`0000Sooooo0_l00009ooooo`;o00000ooooolDo`0000Kooooo0_l00012oooo
o`;o0000>oooool001cooooo00?o0000ooooooooool0B_ooool2o`0001?ooooo0_l00003ooooo`;o
000000?oooooo`000?l000001_ooool3o`0000Cooooo1?l0000?ooooo`;o00001_ooool6o`0000?o
oooo0_l00002ooooo`;o00002Oooool2o`0000;ooooo5Ol000000ooooooo0000o`000003ooooo`;o
00000_ooool6o`000003ooooool0003o000003Oooooo0_l0000kooooo`007?ooool00ol0003ooooo
ooooo`18ooooo`;o00004Oooool2o`0000;ooooo0_l00003ooooo`;o00002Oooool2o`000003oooo
ool0003o000001gooooo0_l000001?oooooo0000o`000?l00003ooooo`;o00004Oooool2o`000003
ooooool0003o000001?o000000?oooooo`000?l000001?ooool6o`000003ooooool0003o000007Co
oooo000Looooo`03o`000?oooooooooo04Sooooo0_l0000Aooooo`;o00000_ooool2o`0000?ooooo
0_l0000<ooooo`;o00004Oooool3o`0000Sooooo0_l00004ooooo`;o00003_ooool2o`0000Gooooo
5_l00003ooooo`;o0000POooool001cooooo00?o0000ooooooooool0BOooool4o`0002_ooooo0_l0
0009ooooo`Ko00000oooool2o`0000;ooooo0_l00004ooooo`;o00003?ooool4o`0000Gooooo4?l0
00000ooooooo0000o`000002o`000003ooooool0003o000000Oooooo0_l00004ooooo`;o0000MOoo
ool001cooooo00?o0000ooooooooool0BOooool4o`0001Kooooo0_l00003ooooo`;o00003_ooool2
o`0000Wooooo0_l000001?oooooo0000o`000?l00003ooooo`Co00002?ooool2o`0000Oooooo1ol0
00001?oooooo0000o`000?oooolFo`000004ooooool0003o0000o`0000;ooooo0_l00002ooooo`;o
00001?ooool2o`0003?ooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`1Sooooo`;o0000
0oooool2o`0000[ooooo1Ol0000=ooooo`;o00001_ooool4o`0000Kooooo0_l00002ooooo`;o0000
0oooool4o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000006?l00002ooooo`;o
00001_ooool2o`0003Cooooo0ol00010ooooo`007?ooool2o`0004gooooo0_l0000Fooooo`;o0000
3_ooool5o`0000gooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00004ooooo`;o
00001?ooool2o`0000Sooooo0ol00005oooooaSo00001oooool5o`0002?ooooo0_l0000?ooooo`;o
0000@Oooool001cooooo00?o0000ooooooooool0C?ooool2o`0001Kooooo0_l0000<ooooo`;o0000
3_ooool2o`0000Gooooo0_l000000ooooooo0000o`000008ooooo`Co00001oooool2o`0000?ooooo
0ol00005oooooaSo00001oooool3o`0002?ooooo1?l0001Booooo`007?ooool00ol0003ooooooooo
o`1<ooooo`;o00009?ooool2o`0000kooooo1?l0000Booooo`;o00001oooool2o`0000Gooooo0_l0
0004oooooaWo00001?ooool2o`000003ooooool0003o000002?ooooo0_l0001Dooooo`007?ooool0
0ol0003oooooooooo`1=ooooo`;o00007Oooool2o`0001Kooooo0_l0000Cooooo`;o00000oooool2
o`0000Cooooo0_l00002ooooo`;o00001?oooolIo`0000Cooooo0_l000000ooooooo0000o`000003
o`0007Kooooo000Looooo`03o`000?oooooooooo04gooooo0ol0000Dooooo`;o00001_ooool2o`00
02_ooooo0_l00003ooooo`;o00001?ooool6o`0000Kooooo4ol0000<ooooo`Co0000M_ooool001co
oooo00?o0000ooooooooool0C_ooool2o`00013ooooo0_l00002ooooo`;o0000@?ooool4o`0000Ko
oooo4ol000000ooooooo0000o`000005ooooo`;o00000_ooool4o`0000Kooooo0_l0000Wooooo`;o
0000AOooool001cooooo00?o0000ooooooooool0H?ooool6o`0003[ooooo0_l00004ooooo`Co0000
1_oooolBo`0000;ooooo0_l00005ooooo`?o000000Coooooo`000?l0003o00001oooool2o`0001Co
oooo0_l0000Aooooo`;o0000AOooool001cooooo00?o0000ooooooooool0DOooool2o`0000cooooo
0_l000000ooooooo0000o`000002o`0003[ooooo0_l00004ooooo`;o00000oooool2o`0000?ooooo
4_l000000ooooooo0000o`000007ooooo`Ko00007Oooool2o`0005Sooooo000Looooo`03o`000?oo
oooooooo057ooooo0_l0000<ooooo`;o00001?ooool2o`0000oooooo0_l0000_ooooo`;o00000_oo
ool2o`0000Cooooo4?l000001?oooooo0000o`000?l00007ooooo`So0000MOooool001cooooo00?o
0000ooooooooool0I?ooool3o`0000Wooooo0_l00004ooooo`;o0000;_ooool3o`000003ooooool0
003o000000Gooooo0_l00002ooooo`_o00000_ooool3o`0000Oooooo0_l00003ooooo`?o0000MOoo
ool001cooooo00?o0000ooooooooool0I?ooool2o`0000Sooooo1?l000001?oooooo0000o`000?l0
000`ooooo`Ko00001Oooool2o`0000?ooooo2?l00003ooooo`Co00003?ooool2o`0007Kooooo000L
ooooo`03o`000?oooooooooo06Oooooo0_l00005ooooo`;o00000oooool3o`0003;ooooo0ol00003
ooooo`;o00001_ooool8o`000003ooooool0003o000000?o00001Oooool2o`0007kooooo000Loooo
o`03o`000?oooooooooo06Oooooo0_l0000booooo`;o00003?ooool2o`0000?ooooo0_l00009oooo
o`Go000000?oooooo`000?l000000_l00006ooooo`;o00002Oooool2o`0001Cooooo0_l0001Moooo
o`007?ooool00ol0003oooooooooo`1Fooooo`;o0000@oooool2o`0001gooooo1_l000000ooooooo
0000o`000002ooooo`;o000000?oooooo`000?l000002_ooool2o`0001Cooooo0_l0001Mooooo`00
7?ooool00ol0003oooooooooo`1Fooooo`;o00004?ooool6o`0002oooooo0_l0000?ooooo`;o0000
3_ooool2o`0000Gooooo0_l000000ooooooo0000o`00001oooooo`007?ooool00ol0003ooooooooo
o`1Xooooo`Ko00001?ooool2o`000003ooooool0003o000002Kooooo0_l0000?ooooo`Co00003_oo
ool2o`0000?ooooo0_l0000aooooo`?o0000C_ooool001cooooo0_l0001Zooooo`;o00001oooool5
o`0002_ooooo0_l00008ooooo`;o00000_ooool3o`0000gooooo0_l0000;ooooo`;o0000:Oooool3
o`0004kooooo000Looooo`03o`000?oooooooooo07Cooooo0_l0000/ooooo`?o00001Oooool4o`00
00?ooooo0_l00004ooooo`;o00005?ooool2o`0001?ooooo0_l0001Uooooo`007?ooool00ol0003o
ooooooooo`1Hooooo`?o00003_ooool2o`0000Gooooo0_l0000Jooooo`?o000000?oooooo`000?l0
00001Oooool2o`000003ooooool0003o000000Oooooo0_l00005ooooo`;o00001Oooool2o`0000Co
oooo0_l00008ooooo`;o00007oooool2o`0006Gooooo000Looooo`03o`000?oooooooooo05Sooooo
0ol0000>ooooo`;o00001Oooool2o`0000Wooooo0_l0000?ooooo`?o000000?oooooo`000?l00000
1Oooool2o`000003ooooool0003o000001gooooo0_l000000ooooooo0000o`000005o`0001gooooo
0_l0001Wooooo`007?ooool00ol0003oooooooooo`1Hooooo`Co00004Oooool2o`000003ooooool0
003o000000Wooooo0_l0000Xooooo`?o00004Oooool2o`000003ooooool0003o000000?o00000_oo
ool4o`0001Wooooo0_l0001Wooooo`007?ooool00ol0003oooooooooo`1Jooooo`;o00004Oooool2
o`000003ooooool0003o000000;ooooo0_l00003ooooo`;o0000:_ooool3o`0001Kooooo0_l00000
0ooooooo0000o`000004o`0001?ooooo0_l0001]ooooo`007?ooool00ol0003oooooooooo`1_oooo
o`;o00000oooool2o`0000?ooooo0_l0000Qooooo`;o00008?ooool5o`0001Oooooo0_l0001]oooo
o`007?ooool00ol0003oooooooooo`1Kooooo`;o00004_ooool2o`0000Kooooo0_l00003ooooo`;o
00003oooool2o`0000gooooo0_l0000Rooooo`;o0000Qoooool001cooooo00?o0000ooooooooool0
Foooool2o`0001[ooooo0ol00002ooooo`;o00001oooool2o`0000Kooooo0_l0000;ooooo`Co0000
2oooool2o`0000Sooooo0_l000000ooooooo0000o`00000;ooooo`;o00004Oooool2o`0000[ooooo
0_l00003ooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0N?ooool3o`0000[ooooo0_l0
000Cooooo`;o00003Oooool2o`0000Sooooo0_l000000ooooooo0000o`00000;ooooo`Co00001?oo
ool3o`0000Kooooo1?l00008ooooo`Co00000oooool2o`00063ooooo000Looooo`03o`000?oooooo
oooo07Wooooo0_l0000^ooooo`;o000000?oooooo`000?l000001oooool2o`0000kooooo0_l00004
ooooo`?o00001_ooool2o`0000Cooooo0_l00004ooooo`Co00002Oooool2o`0005[ooooo000Loooo
o`03o`000?oooooooooo063ooooo0_l0000Iooooo`;o000000?oooooo`000?l000000oooool2o`00
02Cooooo0_l000000ooooooo0000o`000007ooooo`;o00006?ooool2o`0000Wooooo0_l00002oooo
o`Ko00001oooool4o`0005[ooooo000Looooo`03o`000?oooooooooo063ooooo0_l000000ooooooo
0000o`00000Fooooo`;o000000Coooooo`000?l0003ooooo1?l000000ooooooo0000o`00000:oooo
o`;o00000oooool4o`0000Kooooo0ol00004ooooo`Co00005Oooool2o`0000Sooooo0_l00002oooo
o`;o000000?oooooo`000?l000002?ooool4o`0000_ooooo0_l0001Looooo`007?ooool00ol0003o
ooooooooo`1Sooooo`;o00000oooool2o`0001Oooooo1?l000001?oooooo0000o`000?ooool2o`00
00;ooooo1?l000001Ooooooo0000o`000?l0003ooooo00Ko00001Oooool3o`0000Cooooo1Ol00000
0ooooooo0000o`00000Aooooo`;o00000oooool2o`0000?ooooo0_l00004ooooo`?o00001oooool3
o`0006_ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ
8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Sooooo`;o00000oooool2o`0001;ooooo
0_l00005ooooo`;o00001?ooool2o`0000;ooooo1?l000001Ooooooo0000o`000?l0003ooooo00Wo
00000_ooool2o`0000Kooooo1?l000000ooooooo0000o`00000Fooooo`;o00000_ooool2o`0000Go
oooo0ol00007ooooo`;o0000K?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q
8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo06?ooooo0_l00003
ooooo`Co00004?ooool2o`0000Gooooo0_l00003ooooo`;o00002?ooool2o`0000Gooooo0_l00000
0ooooooo0000o`000002o`000004ooooool0003o0000ooooo`;o00001Oooool2o`000003ooooool0
003o000000?o00005oooool2o`0000Kooooo0_l0001eooooo`0000?ooooooa0@4?ooool00_ooool0
0ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`1Xooooo`Co00004oooool2o`0000Oooooo0_l00004ooooo`;o00001_ooool2o`0000Cooooo1?l0
00000ooooooo0000o`000003o`000004ooooool0003o0000o`0000;ooooo1ol0000`ooooo`;o0000
I?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Olb<S;oV9RHoooo
oonHV9So<S8b00Kooooo0ol0001oooooo`;o00003?ooool3o`0000Kooooo0_l000000ooooooo0000
o`000005o`000003ooooool0003o000000Oo00000_ooool2o`0000?ooooo0ol0000_ooooo`;o0000
I?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Oo<c<co0000o`00
0?l0003oc<c<00Kooooo00?o0000ooooooooool0J?ooool2o`0001[ooooo0ol00006ooooo`?o0000
1?ooool2o`0000?ooooo1?l000000ooooooo0000o`000006ooooo`?o00002?ooool3o`0001Kooooo
1?l0000Booooo`;o0000Ioooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Ooo
ool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0J?ooool2o`0000Cooooo
0ol0000Cooooo`?o00001oooool2o`0000Cooooo0ol00004ooooo`;o000000?oooooo`000?l00000
4Oooool3o`0001Kooooo1?l0000Booooo`;o0000Ioooool00006oooooomgMgOoV9RHoooooonHV9So
MgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0K_ooool3o`00
02Cooooo0_l0000Kooooo`;o00001Oooool3o`0001cooooo0_l0001_ooooo`0000Koooooonk^k_lb
<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003ooooooooo
o`2Sooooo`;o00004_ooool5o`0001cooooo0_l0001_ooooo`007?ooool00ol0003oooooooooo`1c
ooooo`;o0000;_ooool2o`000003ooooool0003o000000cooooo0_l000001?oooooo0000o`000?l0
002?ooooo`007?ooool00ol0003oooooooooo`1cooooo`;o00006_ooool3o`0001Cooooo0_l0000<
ooooo`;o00000_ooool2o`0001Wooooo0_l0001dooooo`007?ooool00ol0003oooooooooo`2?oooo
o`?o00000_ooool2o`0003cooooo0ol0001dooooo`007?ooool00ol0003oooooooooo`2Dooooo`;o
0000??ooool2o`0007Gooooo000Looooo`03o`000?oooooooooo07Wooooo0ol0000Kooooo`Co0000
<_ooool2o`0007[ooooo000Looooo`03o`000?oooooooooo07Wooooo0ol0000Kooooo`Ko0000<?oo
ool2o`0007[ooooo000Looooo`03o`000?oooooooooo09_ooooo0_l00002ooooo`;o00008?ooool5
o`0008?ooooo000Looooo`03o`000?oooooooooo09oooooo0_l00005ooooo`?o00006?ooool5o`00
08?ooooo000Looooo`03o`000?oooooooooo08;ooooo0_l0000Rooooo`Co00000oooool2o`0000?o
oooo1?l0002Cooooo`007?ooool00ol0003oooooooooo`22ooooo`;o000000?oooooo`000?l00000
8Oooool2o`0000?ooooo0_l00003ooooo`Co0000Toooool001cooooo00?o0000ooooooooool0QOoo
ool2o`000<;ooooo000Looooo`;o0000R_ooool2o`000;kooooo000Looooo`03o`000?oooooooooo
08Wooooo1?l0002looooo`007?ooool00ol0003oooooooooo`2;ooooo`;o0000_?ooool001cooooo
00?o0000ooooooooool0S_ooool2o`000;Wooooo000Looooo`03o`000?oooooooooo08kooooo1?l0
002gooooo`007?ooool00ol0003oooooooooo`2@ooooo`;o0000]oooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0:;ooooo1?l0002Sooooo`007?ooool00ol0003oooooooooo`2Rooooo`Co0000Xooo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2_oooo
o`?o0000Uoooool001cooooo00?o0000ooooooooool0[oooool3o`000003ooooool0003o000000Oo
oooo0_l0002;ooooo`007?ooool00ol0003oooooooooo`2cooooo`;o00001oooool2o`0008_ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001;ooooo1?l000000ol@
413oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo
0ol0003ooooood[ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000
ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03
o`000?oooooooooo0?ooooooD_ooool001;ooooo00?oEEEEofIVI_l00000oooooomDooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00YOooool01?l@413o0000o`000?ooool2o`00
0003oa0@4?oooooooooo01Gooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05olc<c?lQ8B7o
0000ob4Q8Oo<c<`01Oooool2o`000003oa0@4?oooooooooo08kooooo002Vooooo`05o`000?oooooo
ooooooooool000002Oooool6o`0000Wooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ob4Q
8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2?ooooo`00Y_ooool01Ol0003ooooo
oooooooooooo000001cooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooooooo
ooooo`Go0000T?ooool00:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00003?ooool0
0onYZJWo410@ooooo`02ooooo`05oc8b<_nHV9SooooooiRHV?lb<S800oooool01?m4A4CogMgMoooo
ool0002Aooooo`00Y_ooool01Ol0003oQhN7oooooonYZJWo000001[ooooo00?o410@o`000?nj^[X0
0oooool01Oo<c<co0000o`000?l0003oc<c<00?ooooo00CogMgMoeEEEOoooooo0000TOooool00:Go
oooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Iooooo`03okZj^_lQ8B7ooooo00;o
oooo00Go410@okZj^_oooooo^[Zjoa0@4004ooooo`03ogMgMoo<c<co0000097ooooo0033ooooo`05
oa0@4?nHV9SooooookZj^_l000000oooool01Ol0003o^[Zjoooooonj^[[o000000Cooooo00?ok^k^
odA4A?l00000TOooool00<?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05ojVYZOl@413o
0000oa0@4?nYZJT01Oooool00omgMgOo0000ooooo`2@ooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(390) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.34827 .61787 Mdot
.3685 .5832 Mdot
.70972 .54019 Mdot
.46079 .3385 Mdot
.70421 .4232 Mdot
.70077 .56435 Mdot
.53561 .71503 Mdot
.53367 .71722 Mdot
.69945 .58335 Mdot
.2069 .47652 Mdot
.5538 .68235 Mdot
.3969 .33963 Mdot
.5464 .70367 Mdot
.44842 .357 Mdot
.47557 .48829 Mdot
.47421 .41673 Mdot
.39661 .59004 Mdot
.69714 .37038 Mdot
.45811 .42203 Mdot
.67274 .54322 Mdot
.38858 .26194 Mdot
.45518 .36636 Mdot
.32011 .58289 Mdot
.45134 .35835 Mdot
.47262 .38714 Mdot
.34481 .58305 Mdot
.33438 .61436 Mdot
.46834 .38596 Mdot
.39941 .36917 Mdot
.55134 .6863 Mdot
.58747 .54611 Mdot
.35168 .22583 Mdot
.49415 .35352 Mdot
.31662 .41304 Mdot
.5251 .70638 Mdot
.52567 .75554 Mdot
.66359 .56591 Mdot
.57545 .71962 Mdot
.52331 .69883 Mdot
.53521 .67774 Mdot
.54248 .67669 Mdot
.33801 .58443 Mdot
.57264 .67357 Mdot
.65112 .74747 Mdot
.45193 .3434 Mdot
.40095 .49957 Mdot
.62439 .74387 Mdot
.43393 .40467 Mdot
.38667 .58171 Mdot
.68993 .53272 Mdot
.64368 .31866 Mdot
.5646 .72755 Mdot
.45087 .58611 Mdot
.78785 .73653 Mdot
.53993 .69529 Mdot
.45256 .41601 Mdot
.67364 .59641 Mdot
.42384 .36853 Mdot
.47095 .34155 Mdot
.30343 .37105 Mdot
.43622 .38206 Mdot
.70504 .3863 Mdot
.40136 .61297 Mdot
.64933 .59902 Mdot
.70376 .58123 Mdot
.57668 .71464 Mdot
.33637 .5623 Mdot
.55559 .69933 Mdot
.40289 .35033 Mdot
.69626 .53585 Mdot
.40419 .381 Mdot
.55682 .6846 Mdot
.31919 .59606 Mdot
.46144 .34485 Mdot
.45882 .78422 Mdot
.60465 .7503 Mdot
.63895 .60758 Mdot
.34542 .29828 Mdot
.72914 .32865 Mdot
.5752 .50755 Mdot
.46285 .3525 Mdot
.81104 .61544 Mdot
.53172 .47675 Mdot
.37921 .59265 Mdot
.42443 .59942 Mdot
.42313 .66847 Mdot
.44668 .40336 Mdot
.57493 .55585 Mdot
.4944 .40281 Mdot
.69298 .46112 Mdot
.67929 .5915 Mdot
.37547 .60356 Mdot
.45797 .3457 Mdot
.4184 .33238 Mdot
.22412 .56235 Mdot
.39958 .38895 Mdot
.47518 .34695 Mdot
.43361 .62741 Mdot
.56357 .68169 Mdot
.41783 .4445 Mdot
.64853 .38949 Mdot
.47419 .61018 Mdot
.45036 .41463 Mdot
.67497 .57699 Mdot
.38525 .62339 Mdot
.49316 .37368 Mdot
.55338 .71356 Mdot
.46016 .3554 Mdot
.54964 .66277 Mdot
.3812 .57044 Mdot
.44948 .32313 Mdot
.69814 .40318 Mdot
.40376 .27997 Mdot
.32443 .58407 Mdot
.31855 .50846 Mdot
.44797 .38155 Mdot
.41784 .36982 Mdot
.36826 .58049 Mdot
.6805 .54296 Mdot
.76672 .63329 Mdot
.3214 .59239 Mdot
.53568 .67681 Mdot
.39309 .59112 Mdot
.4221 .29064 Mdot
.67304 .54724 Mdot
.45472 .60512 Mdot
.45247 .60575 Mdot
.5714 .2918 Mdot
.4673 .35006 Mdot
.4525 .25907 Mdot
.68509 .5719 Mdot
.34597 .57736 Mdot
.55057 .69367 Mdot
.43077 .42228 Mdot
.33724 .59673 Mdot
.53773 .72173 Mdot
.73579 .41757 Mdot
.68327 .38075 Mdot
.34989 .57103 Mdot
.30336 .53387 Mdot
.57203 .66101 Mdot
.5512 .67081 Mdot
.64033 .31929 Mdot
.37974 .59177 Mdot
.71573 .40247 Mdot
.55203 .7236 Mdot
.58819 .20828 Mdot
.47587 .3425 Mdot
.61516 .3214 Mdot
.79036 .64188 Mdot
.64377 .31911 Mdot
.32606 .27734 Mdot
.70385 .40554 Mdot
.53884 .72316 Mdot
.41185 .39249 Mdot
.35674 .59674 Mdot
.33696 .59306 Mdot
.40648 .35723 Mdot
.48666 .36972 Mdot
.43886 .34987 Mdot
.49354 .36435 Mdot
.54874 .62136 Mdot
.45791 .34786 Mdot
.32431 .74826 Mdot
.35014 .60144 Mdot
.48176 .38334 Mdot
.67625 .55472 Mdot
.45956 .45404 Mdot
.57789 .6859 Mdot
.46544 .33892 Mdot
.48329 .37335 Mdot
.39116 .38304 Mdot
.53242 .67825 Mdot
.4547 .79505 Mdot
.74983 .31863 Mdot
.56026 .75262 Mdot
.57155 .79091 Mdot
.68816 .55979 Mdot
.4336 .38726 Mdot
.72946 .40558 Mdot
.44697 .4458 Mdot
.43844 .33145 Mdot
.65093 .31786 Mdot
.47612 .36465 Mdot
.33945 .2706 Mdot
.45798 .30759 Mdot
.44163 .66 Mdot
.29976 .71072 Mdot
.45007 .33082 Mdot
.23095 .45978 Mdot
.61538 .33379 Mdot
.62284 .55158 Mdot
.5484 .69029 Mdot
.70081 .54478 Mdot
.68932 .54013 Mdot
.56591 .73639 Mdot
.35986 .48489 Mdot
.21297 .451 Mdot
.39549 .37476 Mdot
.47053 .60803 Mdot
.39135 .56823 Mdot
.70301 .40284 Mdot
.35512 .57137 Mdot
.82536 .58896 Mdot
.59718 .4921 Mdot
.56385 .54085 Mdot
.71847 .36065 Mdot
.68024 .53273 Mdot
.46204 .60384 Mdot
.72254 .40285 Mdot
.42947 .34716 Mdot
.38211 .5723 Mdot
.62068 .32917 Mdot
.45754 .4431 Mdot
.15011 .52857 Mdot
.33189 .61183 Mdot
.54397 .29263 Mdot
.5419 .69735 Mdot
.69528 .60174 Mdot
.44778 .40305 Mdot
.4374 .36886 Mdot
.36575 .56377 Mdot
.41503 .39187 Mdot
.54573 .52199 Mdot
.48234 .36924 Mdot
.65107 .5991 Mdot
.77515 .37265 Mdot
.57525 .73307 Mdot
.74555 .37651 Mdot
.3184 .59166 Mdot
.49198 .83793 Mdot
.66963 .57071 Mdot
.41488 .45626 Mdot
.56111 .69417 Mdot
.73298 .41988 Mdot
.66779 .58055 Mdot
.69253 .38139 Mdot
.44569 .32456 Mdot
.66145 .57398 Mdot
.70041 .38927 Mdot
.52985 .54465 Mdot
.49265 .36885 Mdot
.54666 .24755 Mdot
.55853 .72686 Mdot
.38325 .60359 Mdot
.42391 .33777 Mdot
.4591 .58379 Mdot
.38171 .36123 Mdot
.57366 .3417 Mdot
.45727 .58772 Mdot
.4852 .60942 Mdot
.55868 .49342 Mdot
.74057 .39723 Mdot
.52825 .78366 Mdot
.55826 .56158 Mdot
.39692 .59004 Mdot
.42965 .32861 Mdot
.48838 .70764 Mdot
.55347 .72897 Mdot
.42588 .35322 Mdot
.47285 .68747 Mdot
.55044 .72436 Mdot
.41889 .36565 Mdot
.53892 .67995 Mdot
.34484 .59706 Mdot
.5288 .50755 Mdot
.38492 .60968 Mdot
.44039 .3367 Mdot
.54289 .67977 Mdot
.69606 .54299 Mdot
.34456 .58376 Mdot
.45997 .35991 Mdot
.46892 .36696 Mdot
.47598 .60503 Mdot
.48241 .35665 Mdot
.45223 .63767 Mdot
.43887 .40577 Mdot
.70545 .53356 Mdot
.39861 .38168 Mdot
.64633 .36599 Mdot
.6922 .44931 Mdot
.36995 .56656 Mdot
.45871 .58767 Mdot
.66823 .59079 Mdot
.52428 .52416 Mdot
.5188 .25156 Mdot
.4557 .35071 Mdot
.46683 .5909 Mdot
.56355 .3077 Mdot
.57677 .68504 Mdot
.50776 .37704 Mdot
.7264 .6162 Mdot
.67782 .58965 Mdot
.4663 .60701 Mdot
.4341 .4421 Mdot
.3067 .57271 Mdot
.43817 .41791 Mdot
.66439 .56959 Mdot
.38152 .61026 Mdot
.40943 .40171 Mdot
.61578 .73538 Mdot
.45985 .58305 Mdot
.5615 .67719 Mdot
.43885 .62533 Mdot
.41766 .38072 Mdot
.70297 .5409 Mdot
.33152 .59011 Mdot
.53448 .6996 Mdot
.3224 .58646 Mdot
.62696 .33757 Mdot
.55836 .31997 Mdot
.48526 .57095 Mdot
.73977 .3823 Mdot
.53506 .16042 Mdot
.56271 .75301 Mdot
.42858 .44665 Mdot
.7043 .61135 Mdot
.27341 .65023 Mdot
.67339 .58142 Mdot
.29629 .54298 Mdot
.67731 .59408 Mdot
.43533 .41334 Mdot
.70385 .56867 Mdot
.21786 .57407 Mdot
.46897 .38046 Mdot
.70921 .57704 Mdot
.56884 .6111 Mdot
.46945 .37713 Mdot
.33665 .59795 Mdot
.27743 .27416 Mdot
.34418 .44245 Mdot
.35072 .46148 Mdot
.67213 .59875 Mdot
.27756 .56347 Mdot
.46348 .39084 Mdot
.44625 .42566 Mdot
.35606 .59294 Mdot
.38394 .35263 Mdot
.73343 .38283 Mdot
.69962 .3729 Mdot
.62193 .2605 Mdot
.4064 .22558 Mdot
.34927 .48736 Mdot
.34149 .58882 Mdot
.76727 .34229 Mdot
.44935 .78126 Mdot
.45877 .58323 Mdot
.53432 .71875 Mdot
.49032 .79784 Mdot
.47005 .42768 Mdot
.31306 .64185 Mdot
.54291 .51975 Mdot
.36612 .61324 Mdot
.4986 .56276 Mdot
.533 .70417 Mdot
.34824 .45819 Mdot
.21546 .41995 Mdot
.43755 .34896 Mdot
.57355 .70989 Mdot
.39868 .32812 Mdot
.5687 .55602 Mdot
.55728 .2725 Mdot
.6514 .66691 Mdot
.4414 .33768 Mdot
.49464 .78197 Mdot
.43303 .33332 Mdot
.58062 .29638 Mdot
.4258 .34912 Mdot
.33118 .59792 Mdot
.39702 .40094 Mdot
.55113 .56386 Mdot
.58424 .16715 Mdot
.59667 .48352 Mdot
.70327 .37664 Mdot
.447 .36004 Mdot
.43267 .35873 Mdot
.70461 .3838 Mdot
.37081 .60897 Mdot
.421 .3364 Mdot
.58564 .80565 Mdot
.46011 .34834 Mdot
.5645 .73 Mdot
.58442 .39247 Mdot
.39112 .21617 Mdot
.44511 .39611 Mdot
.3084 .57151 Mdot
.55462 .67185 Mdot
.56349 .70728 Mdot
.51378 .35589 Mdot
.55989 .72758 Mdot
.41152 .3907 Mdot
.58415 .3934 Mdot
.33365 .56738 Mdot
.51348 .37315 Mdot
.35891 .61341 Mdot
.78768 .35637 Mdot
.54689 .72654 Mdot
.46786 .58729 Mdot
.34719 .49616 Mdot
.54541 .7152 Mdot
.7657 .40616 Mdot
.40171 .40799 Mdot
.49713 .42942 Mdot
.37068 .54698 Mdot
.70499 .54392 Mdot
.45939 .59482 Mdot
.53822 .69586 Mdot
.45402 .34656 Mdot
.46941 .40074 Mdot
.56561 .72395 Mdot
.28207 .33204 Mdot
.58831 .54577 Mdot
.44166 .33579 Mdot
.34443 .60539 Mdot
.34268 .57882 Mdot
.49466 .39444 Mdot
.42951 .33386 Mdot
.7028 .55509 Mdot
.46581 .59056 Mdot
.4592 .58985 Mdot
.46274 .61055 Mdot
.68019 .60329 Mdot
.5415 .16249 Mdot
.55354 .6704 Mdot
.36252 .22182 Mdot
.44403 .74331 Mdot
.48168 .30415 Mdot
.67643 .54933 Mdot
.43822 .37526 Mdot
.45163 .41046 Mdot
.54258 .68171 Mdot
.51642 .18419 Mdot
.44011 .425 Mdot
.36746 .6171 Mdot
.56909 .72209 Mdot
.39233 .33671 Mdot
.58202 .66341 Mdot
.7139 .41609 Mdot
.3357 .49059 Mdot
.55893 .72964 Mdot
.34298 .56744 Mdot
.55927 .72964 Mdot
.43441 .35564 Mdot
.43114 .44246 Mdot
.36229 .6146 Mdot
.68541 .40334 Mdot
.40987 .34761 Mdot
.41775 .36013 Mdot
.73065 .51376 Mdot
.46158 .78335 Mdot
.75514 .4133 Mdot
.43256 .40889 Mdot
.49904 .42962 Mdot
.68497 .39782 Mdot
.4096 .3621 Mdot
.40117 .38589 Mdot
.44889 .25798 Mdot
.56288 .66143 Mdot
.73895 .42129 Mdot
.56952 .16986 Mdot
.3345 .61312 Mdot
.46683 .63704 Mdot
.46622 .60948 Mdot
.54469 .74935 Mdot
.52187 .51219 Mdot
.46849 .60138 Mdot
.45436 .72517 Mdot
.39463 .83403 Mdot
.46238 .59528 Mdot
.66517 .60498 Mdot
.24562 .55795 Mdot
.40045 .37847 Mdot
.43221 .33684 Mdot
.73761 .39139 Mdot
.37552 .58085 Mdot
.32537 .74177 Mdot
.55547 .75257 Mdot
.45136 .37524 Mdot
.32407 .61107 Mdot
.43001 .66646 Mdot
.46951 .60531 Mdot
.72575 .41124 Mdot
.69614 .4164 Mdot
.42578 .33802 Mdot
.54567 .28184 Mdot
.3406 .58575 Mdot
.45987 .35992 Mdot
.41694 .37252 Mdot
.65499 .58081 Mdot
.38116 .57247 Mdot
.67476 .55803 Mdot
.48251 .59077 Mdot
.2311 .62234 Mdot
.65655 .7895 Mdot
.55927 .72439 Mdot
.45957 .52415 Mdot
.57387 .73441 Mdot
.62333 .67781 Mdot
.46451 .59034 Mdot
.45808 .36264 Mdot
.31701 .57871 Mdot
.46059 .35708 Mdot
.45939 .34725 Mdot
.445 .34046 Mdot
.34746 .48719 Mdot
.72887 .333 Mdot
.73361 .39927 Mdot
.41876 .38794 Mdot
.66557 .60006 Mdot
.46029 .65598 Mdot
.19465 .51301 Mdot
.4418 .3633 Mdot
.41748 .36867 Mdot
.32793 .56183 Mdot
.46513 .33102 Mdot
.54245 .71926 Mdot
.37231 .61189 Mdot
.45953 .40977 Mdot
.65234 .38895 Mdot
.41852 .34016 Mdot
.457 .53481 Mdot
.5389 .73187 Mdot
.39648 .41765 Mdot
.47426 .32747 Mdot
.46425 .58947 Mdot
.46002 .59597 Mdot
.49464 .60613 Mdot
.57126 .72371 Mdot
.65634 .58276 Mdot
.63989 .59444 Mdot
.45354 .31832 Mdot
.42074 .4003 Mdot
.46098 .44146 Mdot
.71608 .53172 Mdot
.57064 .57257 Mdot
.3222 .52323 Mdot
.41334 .31914 Mdot
.70266 .59341 Mdot
.43529 .62717 Mdot
.36137 .28091 Mdot
.37842 .60673 Mdot
.72345 .59554 Mdot
.55997 .70615 Mdot
.69398 .39499 Mdot
.61514 .2832 Mdot
.32468 .59529 Mdot
.31352 .57594 Mdot
.69777 .55673 Mdot
.5715 .40894 Mdot
.83598 .68142 Mdot
.68242 .57702 Mdot
.55772 .5359 Mdot
.35087 .59117 Mdot
.49437 .3566 Mdot
.57374 .32074 Mdot
.56095 .41531 Mdot
.7045 .58619 Mdot
.46894 .36528 Mdot
.75517 .44294 Mdot
.70334 .55565 Mdot
.47955 .44036 Mdot
.67141 .5992 Mdot
.56985 .6849 Mdot
.68041 .57115 Mdot
.34029 .61978 Mdot
.46731 .3527 Mdot
.80302 .71965 Mdot
.52301 .49055 Mdot
.46202 .37011 Mdot
.55842 .73139 Mdot
.61648 .63025 Mdot
.43204 .35082 Mdot
.72025 .37273 Mdot
.6616 .6006 Mdot
.63255 .66965 Mdot
.4183 .40595 Mdot
.70576 .56668 Mdot
.3034 .58511 Mdot
.73517 .57426 Mdot
.64737 .3969 Mdot
.45819 .59244 Mdot
.34972 .59859 Mdot
.55486 .76324 Mdot
.53981 .67558 Mdot
.47168 .40789 Mdot
.42244 .37844 Mdot
.35379 .60417 Mdot
.52219 .5357 Mdot
.50736 .34689 Mdot
.46138 .35139 Mdot
.68888 .55302 Mdot
.65409 .55826 Mdot
.47766 .48493 Mdot
.66799 .57122 Mdot
.50165 .42587 Mdot
.34443 .60267 Mdot
.44109 .41878 Mdot
.3283 .58446 Mdot
.42749 .3296 Mdot
.58662 .66207 Mdot
.3824 .59845 Mdot
.40042 .44401 Mdot
.47046 .35286 Mdot
.35715 .52991 Mdot
.42123 .38408 Mdot
.44939 .33752 Mdot
.64999 .57109 Mdot
.715 .38738 Mdot
.50614 .37419 Mdot
.61298 .71837 Mdot
.69315 .40854 Mdot
.30531 .30327 Mdot
.67248 .54793 Mdot
.71658 .42448 Mdot
.59913 .25204 Mdot
.45789 .58833 Mdot
.71527 .38213 Mdot
.43934 .60016 Mdot
.56511 .72009 Mdot
.3449 .6301 Mdot
.47185 .37069 Mdot
.23027 .61415 Mdot
.58692 .54799 Mdot
.47704 .60076 Mdot
.41652 .34871 Mdot
.4339 .37316 Mdot
.32314 .61011 Mdot
.82096 .59679 Mdot
.64518 .57132 Mdot
.48736 .3583 Mdot
.32318 .59731 Mdot
.80192 .62761 Mdot
.70915 .57938 Mdot
.73485 .41019 Mdot
.52188 .71117 Mdot
.40498 .58016 Mdot
.46759 .5863 Mdot
.54449 .72589 Mdot
.64337 .61291 Mdot
.6555 .31728 Mdot
.43192 .4151 Mdot
.67538 .55269 Mdot
.64503 .31907 Mdot
.50986 .36316 Mdot
.57159 .73247 Mdot
.58789 .76682 Mdot
.37669 .59764 Mdot
.56618 .72369 Mdot
.72897 .38164 Mdot
.39622 .58244 Mdot
.36249 .61335 Mdot
.54713 .72006 Mdot
.27923 .68908 Mdot
.56407 .30951 Mdot
.54104 .73935 Mdot
.57756 .34842 Mdot
.64531 .32032 Mdot
.47874 .59424 Mdot
.72391 .41098 Mdot
.77461 .35496 Mdot
.33976 .58369 Mdot
.48591 .79776 Mdot
.64492 .31804 Mdot
.47571 .3473 Mdot
.6992 .38893 Mdot
.46595 .6498 Mdot
.50447 .71762 Mdot
.5438 .7232 Mdot
.73311 .52158 Mdot
.69589 .38862 Mdot
.44996 .32778 Mdot
.43362 .18505 Mdot
.45684 .38965 Mdot
.55438 .7237 Mdot
.54414 .52068 Mdot
.37279 .57016 Mdot
.57661 .68223 Mdot
.54599 .52168 Mdot
.44369 .41213 Mdot
.45081 .38277 Mdot
.73029 .34544 Mdot
.38801 .57836 Mdot
.48153 .59187 Mdot
.46588 .35934 Mdot
.42117 .36579 Mdot
.47968 .40236 Mdot
.46566 .21442 Mdot
.37051 .31307 Mdot
.48773 .38802 Mdot
.71259 .58896 Mdot
.44285 .44446 Mdot
.48424 .35171 Mdot
.30591 .57228 Mdot
.66034 .36836 Mdot
.48502 .5935 Mdot
.42915 .33934 Mdot
.43953 .33627 Mdot
.52422 .69696 Mdot
.56473 .30957 Mdot
.55708 .42141 Mdot
.69406 .53023 Mdot
.65557 .53767 Mdot
.4046 .33917 Mdot
.35984 .60045 Mdot
.74452 .40414 Mdot
.51465 .38795 Mdot
.36102 .61745 Mdot
.41262 .33297 Mdot
.65849 .59652 Mdot
.4657 .59387 Mdot
.51747 .38798 Mdot
.70567 .3904 Mdot
.57258 .66235 Mdot
.31861 .29743 Mdot
.69352 .54472 Mdot
.46165 .39656 Mdot
.63644 .5799 Mdot
.69289 .57996 Mdot
.47763 .60458 Mdot
.40147 .43383 Mdot
.34215 .59476 Mdot
.34278 .56837 Mdot
.67872 .34099 Mdot
.67582 .60403 Mdot
.69967 .50447 Mdot
.57402 .69439 Mdot
.41632 .38429 Mdot
.49193 .65813 Mdot
.35141 .56805 Mdot
.57123 .29058 Mdot
.70711 .42209 Mdot
.5465 .72328 Mdot
.43723 .59499 Mdot
.38226 .60244 Mdot
.34376 .56997 Mdot
.45633 .34529 Mdot
.44851 .36758 Mdot
.61808 .58149 Mdot
.61378 .32821 Mdot
.53632 .68246 Mdot
.72783 .41649 Mdot
.70204 .53455 Mdot
.42254 .40596 Mdot
.37722 .59242 Mdot
.40153 .20923 Mdot
.41886 .38154 Mdot
.66586 .59985 Mdot
.36571 .58356 Mdot
.73638 .4019 Mdot
.73101 .38592 Mdot
.46008 .33936 Mdot
.34638 .26875 Mdot
.54863 .71413 Mdot
.33488 .59814 Mdot
.41097 .57459 Mdot
.42173 .393 Mdot
.44564 .3637 Mdot
.43017 .29623 Mdot
.58159 .7035 Mdot
.49344 .33557 Mdot
.68672 .38912 Mdot
.34231 .57531 Mdot
.46409 .36241 Mdot
.7057 .38528 Mdot
.31001 .64046 Mdot
.47007 .59822 Mdot
.70963 .56941 Mdot
.71272 .37126 Mdot
.71634 .39664 Mdot
.70119 .41589 Mdot
.49168 .79706 Mdot
.34151 .63551 Mdot
.70498 .2682 Mdot
.46976 .35935 Mdot
.6455 .32082 Mdot
.48683 .40309 Mdot
.57623 .68881 Mdot
.7084 .54917 Mdot
.44722 .34465 Mdot
.47007 .36004 Mdot
.32948 .29499 Mdot
.46792 .41925 Mdot
.45746 .42423 Mdot
.36895 .56857 Mdot
.4076 .56744 Mdot
.69621 .54049 Mdot
.7836 .6553 Mdot
.30187 .22906 Mdot
.39458 .37139 Mdot
.57386 .406 Mdot
.37774 .60519 Mdot
.52233 .703 Mdot
.5781 .34119 Mdot
.4958 .67286 Mdot
.36214 .57552 Mdot
.43219 .41214 Mdot
.31794 .30915 Mdot
.6916 .39722 Mdot
.43785 .35216 Mdot
.55401 .69349 Mdot
.43826 .35102 Mdot
.57444 .71815 Mdot
.30057 .5442 Mdot
.54698 .4436 Mdot
.47465 .3684 Mdot
.39954 .38806 Mdot
.44305 .26356 Mdot
.44401 .36535 Mdot
.66068 .65742 Mdot
.36321 .58708 Mdot
.40912 .45009 Mdot
.45435 .41706 Mdot
.33443 .43445 Mdot
.41216 .36417 Mdot
.50499 .5198 Mdot
.43821 .38595 Mdot
.5335 .18927 Mdot
.4606 .332 Mdot
.43578 .38763 Mdot
.53265 .69602 Mdot
.52953 .68386 Mdot
.31339 .55111 Mdot
.48514 .60035 Mdot
.44747 .65693 Mdot
.41677 .36281 Mdot
.67557 .53398 Mdot
.53997 .38124 Mdot
.71681 .39178 Mdot
.34491 .57543 Mdot
.53223 .88976 Mdot
.56089 .67228 Mdot
.66966 .60546 Mdot
.57201 .54832 Mdot
.70844 .59683 Mdot
.70055 .61235 Mdot
.37301 .54374 Mdot
.72137 .41234 Mdot
.42221 .33696 Mdot
.32259 .41269 Mdot
.47607 .78039 Mdot
.42264 .39483 Mdot
.67679 .52704 Mdot
.52843 .3129 Mdot
.67844 .33573 Mdot
.70949 .36749 Mdot
.71191 .4074 Mdot
.53578 .70141 Mdot
.70558 .53929 Mdot
.41212 .31878 Mdot
.71775 .42461 Mdot
.70378 .54728 Mdot
.44034 .59555 Mdot
.69522 .34928 Mdot
.3383 .58705 Mdot
.28147 .55779 Mdot
.40348 .50908 Mdot
.55439 .67272 Mdot
.60971 .73527 Mdot
.31511 .61851 Mdot
.39721 .5974 Mdot
.48345 .60752 Mdot
.69997 .59335 Mdot
.33809 .62882 Mdot
.46528 .3504 Mdot
.45801 .44323 Mdot
.42645 .33701 Mdot
.73928 .39582 Mdot
.41329 .35703 Mdot
.70645 .55621 Mdot
.52846 .7063 Mdot
.67513 .59116 Mdot
.53478 .71369 Mdot
.31483 .24796 Mdot
.46122 .33613 Mdot
.44841 .36273 Mdot
.58242 .39539 Mdot
.34624 .57051 Mdot
.31241 .41835 Mdot
.66767 .60047 Mdot
.67238 .59536 Mdot
.44659 .41763 Mdot
.39198 .57325 Mdot
.76271 .40391 Mdot
.58626 .35943 Mdot
.4342 .38383 Mdot
.36485 .58785 Mdot
.44572 .41836 Mdot
.60399 .65748 Mdot
.51799 .48172 Mdot
.32224 .58299 Mdot
.58742 .16688 Mdot
.47023 .34784 Mdot
.38503 .41201 Mdot
.37531 .36647 Mdot
.45713 .22249 Mdot
.50576 .37936 Mdot
.33796 .61384 Mdot
.48442 .35269 Mdot
.3652 .59795 Mdot
.68563 .58258 Mdot
.57086 .6739 Mdot
.36163 .59568 Mdot
.46424 .38255 Mdot
.30762 .22625 Mdot
.5273 .70521 Mdot
.4438 .3511 Mdot
.54455 .68546 Mdot
.36688 .62752 Mdot
.37607 .57506 Mdot
.44216 .6016 Mdot
.55967 .53709 Mdot
.54493 .71853 Mdot
.42055 .39957 Mdot
.45772 .79097 Mdot
.43975 .41869 Mdot
.65936 .53471 Mdot
.39997 .39519 Mdot
.40501 .34115 Mdot
.53891 .15646 Mdot
.51789 .52988 Mdot
.67853 .78153 Mdot
.51058 .64486 Mdot
.44878 .79263 Mdot
.3583 .54731 Mdot
.70889 .36771 Mdot
.47488 .53588 Mdot
.45234 .59105 Mdot
.71635 .5834 Mdot
.45126 .34515 Mdot
.33517 .65472 Mdot
.55018 .7397 Mdot
.72221 .38801 Mdot
.47608 .36521 Mdot
.72514 .57766 Mdot
.43188 .5078 Mdot
.54275 .72391 Mdot
.33711 .58436 Mdot
.36037 .5723 Mdot
.7257 .32576 Mdot
.46295 .36583 Mdot
.45278 .36654 Mdot
.52584 .70499 Mdot
.42709 .3067 Mdot
.7063 .41704 Mdot
.56907 .60962 Mdot
.55391 .69122 Mdot
.52267 .48075 Mdot
.38554 .57304 Mdot
.43581 .37415 Mdot
.58427 .39078 Mdot
.40114 .78388 Mdot
.20867 .51004 Mdot
.70527 .40104 Mdot
.53197 .26661 Mdot
.33619 .61328 Mdot
.549 .69279 Mdot
.61069 .25726 Mdot
.41583 .42077 Mdot
.43041 .37221 Mdot
.50086 .23335 Mdot
.5845 .35721 Mdot
.56742 .54692 Mdot
.4382 .29047 Mdot
.58741 .33067 Mdot
.44545 .41771 Mdot
.46776 .40195 Mdot
.4093 .33379 Mdot
.403 .40092 Mdot
.36851 .59163 Mdot
.34109 .4517 Mdot
.69315 .56404 Mdot
.22298 .50392 Mdot
.67095 .5234 Mdot
.46237 .3908 Mdot
.43933 .41291 Mdot
.25856 .48202 Mdot
.55776 .35563 Mdot
.35307 .5861 Mdot
.38973 .55683 Mdot
.54429 .67236 Mdot
.45952 .42212 Mdot
.6698 .60276 Mdot
.37686 .36042 Mdot
.6996 .57951 Mdot
.36878 .59002 Mdot
.65778 .56744 Mdot
.51559 .70188 Mdot
.67429 .55366 Mdot
.70724 .59132 Mdot
.53228 .72156 Mdot
.38873 .5839 Mdot
.42756 .38494 Mdot
.53421 .72458 Mdot
.76533 .39708 Mdot
.73879 .3948 Mdot
.42578 .58051 Mdot
.49618 .36124 Mdot
.45542 .42994 Mdot
.61143 .75219 Mdot
.6603 .57138 Mdot
.55204 .41936 Mdot
.3823 .59649 Mdot
.74374 .40244 Mdot
.36933 .5949 Mdot
.70018 .30002 Mdot
.7073 .39688 Mdot
.43339 .59186 Mdot
.58004 .26159 Mdot
.57576 .7346 Mdot
.38825 .37495 Mdot
.41042 .57181 Mdot
.69558 .58323 Mdot
.56634 .7276 Mdot
.46562 .65264 Mdot
.48839 .36395 Mdot
.4624 .57925 Mdot
.37769 .62359 Mdot
.45697 .58979 Mdot
.5515 .69465 Mdot
.40963 .53062 Mdot
.45893 .37306 Mdot
.57728 .73159 Mdot
.39751 .38685 Mdot
.31267 .52055 Mdot
.62763 .56654 Mdot
.40595 .63715 Mdot
.43885 .41496 Mdot
.7097 .57934 Mdot
.44187 .41635 Mdot
.25493 .56498 Mdot
.58702 .2847 Mdot
.40431 .33866 Mdot
.55 .32233 Mdot
.62221 .73215 Mdot
.37684 .59369 Mdot
.5123 .3891 Mdot
.47857 .59761 Mdot
.46099 .40028 Mdot
.14508 .41433 Mdot
.71116 .38364 Mdot
.73133 .36137 Mdot
.46763 .37732 Mdot
.46261 .35598 Mdot
.33448 .28992 Mdot
.31555 .53615 Mdot
.44548 .60372 Mdot
.42748 .36701 Mdot
.47237 .23165 Mdot
.53413 .69628 Mdot
.41101 .40427 Mdot
.44152 .33333 Mdot
.64479 .52648 Mdot
.53768 .68977 Mdot
.66853 .55363 Mdot
.45666 .58885 Mdot
.66366 .54693 Mdot
.69491 .4186 Mdot
.54024 .28421 Mdot
.54342 .26396 Mdot
.50622 .48202 Mdot
.71274 .37219 Mdot
.45477 .39656 Mdot
.41863 .62939 Mdot
.46156 .37737 Mdot
.71882 .40751 Mdot
.55135 .68614 Mdot
.36282 .58985 Mdot
.29592 .54138 Mdot
.47463 .60767 Mdot
.43383 .3973 Mdot
.72942 .37363 Mdot
.35442 .59601 Mdot
.37243 .78275 Mdot
.37553 .58358 Mdot
.53734 .7135 Mdot
.56697 .73501 Mdot
.7118 .39379 Mdot
.37041 .59474 Mdot
.65878 .55386 Mdot
.51163 .65379 Mdot
.38742 .35819 Mdot
.51517 .69898 Mdot
.31981 .61603 Mdot
.31469 .60024 Mdot
.33228 .56508 Mdot
.45737 .41445 Mdot
.56818 .36874 Mdot
.41467 .29236 Mdot
.52666 .70432 Mdot
.72313 .57498 Mdot
.61173 .31836 Mdot
.32679 .37051 Mdot
.53511 .46585 Mdot
.50757 .40031 Mdot
.414 .35483 Mdot
.42451 .33922 Mdot
.48801 .39067 Mdot
.54566 .60739 Mdot
.46051 .33589 Mdot
.53991 .68161 Mdot
.6973 .57294 Mdot
.4333 .38127 Mdot
.4734 .59169 Mdot
.57046 .56981 Mdot
.74149 .42054 Mdot
.33153 .49152 Mdot
.41685 .57428 Mdot
.35575 .5949 Mdot
.66643 .56721 Mdot
.65726 .56468 Mdot
.73586 .41743 Mdot
.54446 .72778 Mdot
.37464 .57901 Mdot
.53795 .1894 Mdot
.69303 .4053 Mdot
.4282 .34037 Mdot
.58337 .39386 Mdot
.43586 .2252 Mdot
.40513 .35703 Mdot
.44176 .33991 Mdot
.48561 .59636 Mdot
.67916 .60559 Mdot
.18484 .53566 Mdot
.29019 .70254 Mdot
.71301 .38867 Mdot
.72568 .41983 Mdot
.32267 .56631 Mdot
.41252 .38042 Mdot
.55109 .71227 Mdot
.5603 .30277 Mdot
.61914 .70378 Mdot
.4271 .66308 Mdot
.62323 .6753 Mdot
.41638 .34298 Mdot
.30176 .49976 Mdot
.39443 .38802 Mdot
.38365 .62445 Mdot
.3522 .56407 Mdot
.34558 .58738 Mdot
.53236 .70081 Mdot
.65837 .31686 Mdot
.54649 .67745 Mdot
.44964 .62795 Mdot
.33078 .60789 Mdot
.53334 .5317 Mdot
.67164 .59655 Mdot
.48047 .41058 Mdot
.72025 .41139 Mdot
.67465 .45009 Mdot
.51192 .3954 Mdot
.53469 .27211 Mdot
.676 .54961 Mdot
.38696 .5962 Mdot
.4836 .40589 Mdot
.45417 .65922 Mdot
.57106 .41329 Mdot
.63232 .71649 Mdot
.35064 .65404 Mdot
.70308 .38642 Mdot
.21335 .46569 Mdot
.70112 .41242 Mdot
.54792 .72358 Mdot
.46863 .34596 Mdot
.41328 .37768 Mdot
.44814 .33676 Mdot
.42256 .41978 Mdot
.53911 .69403 Mdot
.3898 .3536 Mdot
.64676 .36523 Mdot
.44667 .59992 Mdot
.55144 .57706 Mdot
.72656 .38355 Mdot
.57485 .6931 Mdot
.69478 .57725 Mdot
.48241 .61051 Mdot
.74097 .38329 Mdot
.48843 .3977 Mdot
.46271 .38174 Mdot
.44579 .60107 Mdot
.51351 .3682 Mdot
.47433 .42565 Mdot
.69933 .56228 Mdot
.56607 .55825 Mdot
.73397 .42446 Mdot
.70049 .40452 Mdot
.57059 .71534 Mdot
.36969 .59526 Mdot
.73205 .42341 Mdot
.71521 .54272 Mdot
.41532 .40686 Mdot
.39679 .38297 Mdot
.31783 .61323 Mdot
.64846 .31814 Mdot
.74208 .42019 Mdot
.4955 .33856 Mdot
.33379 .57709 Mdot
.37889 .6229 Mdot
.42827 .36615 Mdot
.41113 .32507 Mdot
.32628 .56084 Mdot
.7349 .41597 Mdot
.57365 .70683 Mdot
.54724 .4774 Mdot
.56192 .67553 Mdot
.33197 .58847 Mdot
.4541 .44401 Mdot
.39083 .58118 Mdot
.48861 .36598 Mdot
.68551 .79696 Mdot
.45532 .33197 Mdot
.36572 .42324 Mdot
.63427 .4941 Mdot
.67391 .59957 Mdot
.68767 .59852 Mdot
.46695 .5924 Mdot
.36451 .61679 Mdot
.51135 .40814 Mdot
.7201 .41449 Mdot
.44939 .79237 Mdot
.29609 .5837 Mdot
.70671 .59097 Mdot
.66501 .6036 Mdot
.54868 .68664 Mdot
.41211 .36069 Mdot
.43765 .37633 Mdot
.67271 .55417 Mdot
.61189 .62747 Mdot
.36789 .60362 Mdot
.45294 .36613 Mdot
.4828 .39622 Mdot
.69388 .56623 Mdot
.52973 .74091 Mdot
.32351 .62381 Mdot
.46022 .41253 Mdot
.58247 .28764 Mdot
.57856 .69871 Mdot
.4497 .40405 Mdot
.38862 .37913 Mdot
.72038 .39578 Mdot
.52308 .25431 Mdot
.64057 .31962 Mdot
.54789 .66833 Mdot
.46306 .58757 Mdot
.40742 .35387 Mdot
.67944 .5985 Mdot
.50154 .376 Mdot
.2642 .73981 Mdot
.44547 .59537 Mdot
.45645 .37336 Mdot
.43177 .3121 Mdot
.3271 .58525 Mdot
.45985 .36253 Mdot
.59007 .66469 Mdot
.68152 .557 Mdot
.45576 .3747 Mdot
.34494 .2738 Mdot
.54931 .68741 Mdot
.51179 .3913 Mdot
.69444 .39065 Mdot
.55783 .5399 Mdot
.28167 .27137 Mdot
.71822 .53427 Mdot
.7172 .37853 Mdot
.41336 .36377 Mdot
.68807 .53013 Mdot
.52125 .70862 Mdot
.36144 .35045 Mdot
.45092 .39969 Mdot
.55668 .67455 Mdot
.52994 .71059 Mdot
.70945 .39037 Mdot
.63077 .83987 Mdot
.40788 .33333 Mdot
.4397 .35703 Mdot
.51339 .84249 Mdot
.32349 .56008 Mdot
.44241 .34975 Mdot
.41716 .37386 Mdot
.55894 .72678 Mdot
.66955 .28591 Mdot
.53181 .2671 Mdot
.56494 .61031 Mdot
.57748 .70745 Mdot
.65708 .54614 Mdot
.68479 .55094 Mdot
.71225 .37836 Mdot
.36602 .5829 Mdot
.74255 .40388 Mdot
.68316 .56751 Mdot
.44427 .33773 Mdot
.56751 .70529 Mdot
.2305 .36533 Mdot
.54321 .73316 Mdot
.72318 .54997 Mdot
.37906 .62577 Mdot
.22572 .57983 Mdot
.29224 .77449 Mdot
.41631 .49797 Mdot
.58199 .71006 Mdot
.7171 .39186 Mdot
.30486 .72457 Mdot
.4333 .382 Mdot
.27288 .54121 Mdot
.4384 .35387 Mdot
.31494 .64723 Mdot
.70737 .54887 Mdot
.44002 .59694 Mdot
.48887 .36474 Mdot
.52841 .2638 Mdot
.5341 .72175 Mdot
.55812 .7063 Mdot
.48473 .35365 Mdot
.53938 .71507 Mdot
.4444 .37639 Mdot
.69392 .57158 Mdot
.65984 .80992 Mdot
.44404 .38798 Mdot
.39112 .4298 Mdot
.58479 .70748 Mdot
.4188 .56905 Mdot
.64176 .57054 Mdot
.32834 .46479 Mdot
.43157 .66905 Mdot
.54977 .7114 Mdot
.34285 .48724 Mdot
.6624 .5755 Mdot
.48505 .60966 Mdot
.65578 .55141 Mdot
.43524 .36301 Mdot
.41345 .3474 Mdot
.49035 .38761 Mdot
.41573 .36931 Mdot
.2588 .53633 Mdot
.4803 .42179 Mdot
.24823 .4039 Mdot
.46955 .35967 Mdot
.37343 .43823 Mdot
.54572 .67917 Mdot
.383 .40601 Mdot
.56311 .48169 Mdot
.43993 .32655 Mdot
.37335 .54747 Mdot
.57334 .6899 Mdot
.4986 .73796 Mdot
.53782 .69296 Mdot
.67673 .59213 Mdot
.53443 .71942 Mdot
.47638 .35144 Mdot
.34289 .57954 Mdot
.67159 .57219 Mdot
.41383 .4928 Mdot
.72196 .57075 Mdot
.46193 .3701 Mdot
.57783 .73599 Mdot
.66006 .59214 Mdot
.44537 .43014 Mdot
.34723 .57803 Mdot
.50744 .22033 Mdot
.40028 .61839 Mdot
.45643 .35673 Mdot
.4519 .35239 Mdot
.44659 .60329 Mdot
.53866 .72302 Mdot
.38818 .5729 Mdot
.64742 .51944 Mdot
.74405 .39327 Mdot
.35665 .58347 Mdot
.3746 .36967 Mdot
.57594 .40563 Mdot
.32409 .58439 Mdot
.45673 .2291 Mdot
.55233 .72463 Mdot
.32137 .59975 Mdot
.38894 .32531 Mdot
.22528 .49808 Mdot
.6989 .40629 Mdot
.65396 .56141 Mdot
.59352 .34677 Mdot
.68398 .55242 Mdot
.58746 .66902 Mdot
.65024 .59767 Mdot
.53754 .68696 Mdot
.53977 .35328 Mdot
.54498 .52172 Mdot
.55055 .73619 Mdot
.58686 .6921 Mdot
.69234 .5592 Mdot
.49474 .3705 Mdot
.55357 .56447 Mdot
.51026 .41335 Mdot
.46407 .44696 Mdot
.5648 .67519 Mdot
.32461 .60651 Mdot
.39525 .5857 Mdot
.42053 .45774 Mdot
.36098 .57016 Mdot
.67752 .5787 Mdot
.49362 .48279 Mdot
.34808 .49638 Mdot
.5562 .68654 Mdot
.57675 .55502 Mdot
.44384 .41442 Mdot
.70677 .56305 Mdot
.67817 .58154 Mdot
.53061 .70945 Mdot
.22934 .52868 Mdot
.49226 .43466 Mdot
.3135 .56046 Mdot
.3252 .60041 Mdot
.32423 .58749 Mdot
.37766 .56711 Mdot
.6604 .31458 Mdot
.56658 .72716 Mdot
.35614 .61672 Mdot
.42868 .421 Mdot
.41097 .37159 Mdot
.45724 .59952 Mdot
.73739 .40522 Mdot
.4202 .42262 Mdot
.51193 .4067 Mdot
.42939 .36756 Mdot
.67066 .59921 Mdot
.49956 .2777 Mdot
.44931 .60097 Mdot
.67457 .60449 Mdot
.67659 .60319 Mdot
.46369 .58917 Mdot
.53838 .34191 Mdot
.19122 .53656 Mdot
.48138 .35135 Mdot
.37719 .54525 Mdot
.69243 .5956 Mdot
.65022 .43101 Mdot
.38567 .46251 Mdot
.41379 .39285 Mdot
.56834 .59516 Mdot
.68868 .57613 Mdot
.35518 .54791 Mdot
.43955 .36418 Mdot
.48241 .60642 Mdot
.69554 .39936 Mdot
.38861 .30379 Mdot
.48544 .59701 Mdot
.37376 .59761 Mdot
.71864 .51201 Mdot
.32304 .61031 Mdot
.65241 .58193 Mdot
.5117 .40056 Mdot
.82153 .6986 Mdot
.69255 .58508 Mdot
.46334 .79867 Mdot
.5458 .52405 Mdot
.44958 .38509 Mdot
.67216 .56145 Mdot
.30079 .58154 Mdot
.57896 .69791 Mdot
.57521 .37812 Mdot
.37664 .59125 Mdot
.48146 .61113 Mdot
.46043 .59922 Mdot
.69409 .56427 Mdot
.33193 .60254 Mdot
.38767 .36894 Mdot
.36015 .57312 Mdot
.5649 .70149 Mdot
.48333 .37428 Mdot
.44637 .65752 Mdot
.4024 .43493 Mdot
.35118 .5726 Mdot
.72502 .56366 Mdot
.68494 .40146 Mdot
.46571 .3839 Mdot
.48648 .71036 Mdot
.41288 .36514 Mdot
.54667 .68508 Mdot
.63659 .47022 Mdot
.23362 .36721 Mdot
.42696 .34641 Mdot
.44419 .41354 Mdot
.51706 .70457 Mdot
.42679 .34846 Mdot
.40001 .36413 Mdot
.40787 .52986 Mdot
.32514 .58274 Mdot
.43068 .37914 Mdot
.69436 .54684 Mdot
.28256 .31256 Mdot
.46112 .34297 Mdot
.59262 .66571 Mdot
.49519 .22613 Mdot
.62043 .44552 Mdot
.47416 .45242 Mdot
.57329 .29269 Mdot
.44807 .35363 Mdot
.41454 .39126 Mdot
.48278 .35231 Mdot
.29921 .50608 Mdot
.6859 .56279 Mdot
.71278 .57306 Mdot
.69384 .3814 Mdot
.49385 .22926 Mdot
.70117 .39561 Mdot
.52283 .71933 Mdot
.56875 .54542 Mdot
.45574 .60681 Mdot
.36873 .59631 Mdot
.45651 .34153 Mdot
.7211 .56426 Mdot
.43692 .37239 Mdot
.45816 .40208 Mdot
.6805 .57521 Mdot
.68397 .5811 Mdot
.72437 .53905 Mdot
.69076 .39733 Mdot
.35373 .5895 Mdot
.4709 .34475 Mdot
.69265 .40784 Mdot
.4839 .39717 Mdot
.54993 .46077 Mdot
.35181 .58808 Mdot
.35171 .57184 Mdot
.39053 .60334 Mdot
.44814 .39178 Mdot
.48522 .36227 Mdot
.54738 .67707 Mdot
.31853 .6139 Mdot
.54958 .71806 Mdot
.67339 .55995 Mdot
.7038 .55796 Mdot
.43494 .36222 Mdot
.43409 .30681 Mdot
.73161 .38826 Mdot
.65857 .58101 Mdot
.46531 .58285 Mdot
.69388 .38416 Mdot
.42601 .336 Mdot
.67871 .55543 Mdot
.73077 .38036 Mdot
.21398 .52996 Mdot
.37524 .67571 Mdot
.68967 .38572 Mdot
.48817 .3578 Mdot
.32375 .35039 Mdot
.59491 .29327 Mdot
.7461 .41619 Mdot
.5508 .6809 Mdot
.42144 .38016 Mdot
.54965 .62065 Mdot
.71336 .42513 Mdot
.63465 .31602 Mdot
.67769 .57222 Mdot
.43224 .44661 Mdot
.42169 .27807 Mdot
.35547 .49715 Mdot
.6873 .40746 Mdot
.34799 .57372 Mdot
.31766 .58275 Mdot
.42827 .34157 Mdot
.56332 .5421 Mdot
.52832 .72685 Mdot
.65746 .56352 Mdot
.7157 .57 Mdot
.32213 .57717 Mdot
.50986 .48232 Mdot
.69167 .54718 Mdot
.4152 .3845 Mdot
.70313 .42838 Mdot
.4539 .42408 Mdot
.69806 .3234 Mdot
.26969 .3063 Mdot
.46385 .45433 Mdot
.68464 .39761 Mdot
.52412 .71221 Mdot
.53007 .7006 Mdot
.53376 .7074 Mdot
.69934 .55503 Mdot
.58009 .34046 Mdot
.71617 .5604 Mdot
.47068 .83135 Mdot
.7087 .38281 Mdot
.56271 .19607 Mdot
.40691 .40961 Mdot
.45198 .38382 Mdot
.42442 .41215 Mdot
.48522 .39047 Mdot
.44833 .35515 Mdot
.55066 .67352 Mdot
.6742 .53801 Mdot
.62107 .68981 Mdot
.34708 .60602 Mdot
.36542 .77891 Mdot
.67014 .59608 Mdot
.4845 .59351 Mdot
.73239 .39884 Mdot
.52005 .24047 Mdot
.67702 .40101 Mdot
.65616 .57893 Mdot
.41046 .3384 Mdot
.31898 .56799 Mdot
.52834 .18857 Mdot
.46174 .35161 Mdot
.65872 .57596 Mdot
.67414 .53076 Mdot
.22169 .51454 Mdot
.45498 .29418 Mdot
.61443 .61635 Mdot
.57288 .40144 Mdot
.69018 .37947 Mdot
.49605 .35481 Mdot
.55289 .28999 Mdot
.68527 .56677 Mdot
.69891 .58637 Mdot
.74737 .40639 Mdot
.27443 .5999 Mdot
.34954 .61454 Mdot
.43133 .58488 Mdot
.56269 .68135 Mdot
.45937 .38221 Mdot
.69188 .55424 Mdot
.41936 .599 Mdot
.58067 .43166 Mdot
.5402 .69947 Mdot
.66671 .60354 Mdot
.41316 .36824 Mdot
.42438 .34792 Mdot
.70256 .39288 Mdot
.61159 .52141 Mdot
.51012 .41358 Mdot
.45222 .79338 Mdot
.54176 .44355 Mdot
.5473 .52467 Mdot
.43059 .3726 Mdot
.38312 .57312 Mdot
.46466 .58991 Mdot
.7255 .41027 Mdot
.4997 .38344 Mdot
.23306 .60313 Mdot
.35455 .62047 Mdot
.5477 .7175 Mdot
.4731 .58847 Mdot
.54295 .29244 Mdot
.41381 .36764 Mdot
.43824 .35445 Mdot
.45559 .41552 Mdot
.2097 .57277 Mdot
.70955 .5531 Mdot
.37532 .56789 Mdot
.6979 .38756 Mdot
.37658 .57658 Mdot
.65451 .59695 Mdot
.57521 .55699 Mdot
.46935 .34009 Mdot
.37462 .61675 Mdot
.36894 .57653 Mdot
.55109 .68704 Mdot
.53344 .72441 Mdot
.71014 .53296 Mdot
.4209 .37603 Mdot
.45788 .60843 Mdot
.33993 .61378 Mdot
.66483 .54997 Mdot
.70356 .394 Mdot
.58451 .66372 Mdot
.47021 .36244 Mdot
.69113 .5637 Mdot
.51299 .39799 Mdot
.34602 .60097 Mdot
.66184 .5896 Mdot
.48774 .60761 Mdot
.73576 .41329 Mdot
.41071 .35061 Mdot
.63255 .69216 Mdot
.48345 .60236 Mdot
.45889 .38801 Mdot
.26061 .32268 Mdot
.56327 .54259 Mdot
.31437 .6337 Mdot
.69881 .54321 Mdot
.47603 .60993 Mdot
.35755 .56504 Mdot
.22569 .4764 Mdot
.70334 .57999 Mdot
.32267 .30837 Mdot
.53589 .51501 Mdot
.48703 .35821 Mdot
.37546 .5945 Mdot
.71078 .34699 Mdot
.42233 .77803 Mdot
.6015 .3039 Mdot
.45185 .37324 Mdot
.68482 .5521 Mdot
.69691 .40069 Mdot
.55793 .70817 Mdot
.54487 .65408 Mdot
.72454 .31684 Mdot
.6961 .59937 Mdot
.45603 .34066 Mdot
.324 .60527 Mdot
.54376 .71733 Mdot
.32107 .2952 Mdot
.70739 .53944 Mdot
.6892 .54533 Mdot
.4107 .39866 Mdot
.70066 .39743 Mdot
.52808 .62201 Mdot
.7112 .5599 Mdot
.6763 .53546 Mdot
.40678 .52313 Mdot
.69584 .37617 Mdot
.46451 .40851 Mdot
.42011 .45767 Mdot
.40407 .40012 Mdot
.42464 .8086 Mdot
.47356 .6105 Mdot
.35028 .60696 Mdot
.44567 .34588 Mdot
.61921 .74229 Mdot
.70035 .57665 Mdot
.57164 .40253 Mdot
.53647 .7446 Mdot
.53558 .72537 Mdot
.68057 .55897 Mdot
.44251 .37023 Mdot
.51327 .70995 Mdot
.71607 .38005 Mdot
.46565 .40834 Mdot
.48775 .36543 Mdot
.31073 .60694 Mdot
.56713 .70174 Mdot
.28126 .31013 Mdot
.56012 .71026 Mdot
.56483 .72435 Mdot
.35386 .63179 Mdot
.42784 .34146 Mdot
.66502 .58984 Mdot
.72337 .58485 Mdot
.48978 .33382 Mdot
.66561 .44671 Mdot
.36366 .614 Mdot
.6508 .6156 Mdot
.22955 .60332 Mdot
.3956 .37378 Mdot
.46348 .58385 Mdot
.38068 .6472 Mdot
.56377 .73704 Mdot
.43396 .34259 Mdot
.36468 .59915 Mdot
.69065 .53319 Mdot
.69159 .55049 Mdot
.41856 .42238 Mdot
.52868 .70482 Mdot
.7358 .38592 Mdot
.67507 .58222 Mdot
.54111 .48375 Mdot
.45893 .37092 Mdot
.49525 .68222 Mdot
.67248 .58281 Mdot
.31429 .22601 Mdot
.61502 .75024 Mdot
.3226 .5873 Mdot
.428 .40678 Mdot
.31348 .5842 Mdot
.70609 .37593 Mdot
.64509 .57942 Mdot
.53555 .68479 Mdot
.50781 .33381 Mdot
.77086 .66805 Mdot
.69711 .55664 Mdot
.36731 .59031 Mdot
.44794 .34013 Mdot
.34831 .48267 Mdot
.43722 .38537 Mdot
.66802 .28028 Mdot
.74241 .42136 Mdot
.59145 .67851 Mdot
.52625 .70363 Mdot
.44275 .41233 Mdot
.70213 .41566 Mdot
.72808 .57533 Mdot
.68114 .57421 Mdot
.74501 .72464 Mdot
.48649 .59987 Mdot
.69321 .61594 Mdot
.45098 .39048 Mdot
.66465 .55302 Mdot
.32727 .37207 Mdot
.52968 .71308 Mdot
.40071 .39264 Mdot
.69561 .60395 Mdot
.37993 .77239 Mdot
.57545 .40203 Mdot
.45619 .37212 Mdot
.42433 .30876 Mdot
.54171 .68675 Mdot
.30369 .72323 Mdot
.7043 .54397 Mdot
.4895 .39445 Mdot
.52844 .73483 Mdot
.5379 .39271 Mdot
.63621 .52561 Mdot
.35308 .58947 Mdot
.68403 .60886 Mdot
.57305 .70405 Mdot
.42552 .44584 Mdot
.7369 .3963 Mdot
.71092 .53809 Mdot
.71543 .58707 Mdot
.47644 .38126 Mdot
.47164 .4096 Mdot
.41404 .3102 Mdot
.37415 .60433 Mdot
.56184 .72416 Mdot
.46458 .40092 Mdot
.55214 .45122 Mdot
.48202 .392 Mdot
.56764 .71746 Mdot
.72111 .80113 Mdot
.41152 .33905 Mdot
.46893 .36782 Mdot
.33484 .48119 Mdot
.3907 .57445 Mdot
.32927 .57684 Mdot
.54127 .45261 Mdot
.4314 .39 Mdot
.52905 .53085 Mdot
.35719 .5907 Mdot
.37135 .58776 Mdot
.53033 .53109 Mdot
.48184 .3715 Mdot
.44722 .58125 Mdot
.54211 .71703 Mdot
.53537 .72552 Mdot
.32755 .5848 Mdot
.45393 .4228 Mdot
.52174 .70897 Mdot
.25501 .51745 Mdot
.65717 .58522 Mdot
.54847 .28667 Mdot
.36573 .57415 Mdot
.58748 .38987 Mdot
.54907 .72436 Mdot
.34409 .23156 Mdot
.44936 .22213 Mdot
.39513 .35805 Mdot
.42868 .3428 Mdot
.71793 .39786 Mdot
.5134 .35589 Mdot
.46043 .58925 Mdot
.53354 .7099 Mdot
.54599 .60629 Mdot
.34484 .58704 Mdot
.4312 .38825 Mdot
.61306 .32334 Mdot
.28398 .27338 Mdot
.38578 .43477 Mdot
.36802 .58345 Mdot
.34293 .58313 Mdot
.68328 .54492 Mdot
.65485 .57779 Mdot
.46836 .34005 Mdot
.5329 .69328 Mdot
.31991 .59424 Mdot
.56684 .71377 Mdot
.68386 .56803 Mdot
.66959 .59363 Mdot
.44955 .59765 Mdot
.47799 .44504 Mdot
.67908 .56368 Mdot
.60392 .67566 Mdot
.55168 .45275 Mdot
.32256 .61876 Mdot
.49899 .84012 Mdot
.36468 .22097 Mdot
.30837 .52795 Mdot
.69611 .40044 Mdot
.5408 .36264 Mdot
.53434 .67749 Mdot
.44614 .41226 Mdot
.43336 .35328 Mdot
.46943 .60504 Mdot
.52802 .68362 Mdot
.72687 .39409 Mdot
.53179 .71942 Mdot
.7279 .41287 Mdot
.71162 .57751 Mdot
.46047 .34452 Mdot
.44319 .32815 Mdot
.5575 .70485 Mdot
.66754 .55531 Mdot
.66066 .59289 Mdot
.70568 .41202 Mdot
.51345 .23523 Mdot
.69232 .5654 Mdot
.3678 .57456 Mdot
.29284 .33182 Mdot
.46149 .60065 Mdot
.44035 .36426 Mdot
.57011 .28826 Mdot
.23092 .45624 Mdot
.49354 .38124 Mdot
.47834 .59196 Mdot
.63701 .83787 Mdot
.46353 .34458 Mdot
.80396 .62437 Mdot
.45474 .60527 Mdot
.39109 .58048 Mdot
.66424 .57819 Mdot
.48448 .59711 Mdot
.48351 .27047 Mdot
.62365 .59137 Mdot
.4971 .34751 Mdot
.35254 .61531 Mdot
.3872 .60303 Mdot
.57092 .55743 Mdot
.42158 .80808 Mdot
.69727 .38835 Mdot
.72118 .38533 Mdot
.70448 .57494 Mdot
.56603 .65101 Mdot
.44325 .42459 Mdot
.71916 .38605 Mdot
.45274 .57208 Mdot
.43948 .41437 Mdot
.5637 .54448 Mdot
.55182 .57049 Mdot
.35182 .56717 Mdot
.38437 .40544 Mdot
.70261 .57606 Mdot
.36575 .58948 Mdot
.55866 .56029 Mdot
.41061 .4022 Mdot
.34911 .58754 Mdot
.55224 .72842 Mdot
.49704 .54039 Mdot
.36221 .57177 Mdot
.57626 .38534 Mdot
.55317 .70759 Mdot
.56996 .54892 Mdot
.60589 .23556 Mdot
.2084 .30733 Mdot
.53089 .70147 Mdot
.66112 .57263 Mdot
.69166 .55555 Mdot
.69459 .568 Mdot
.37806 .59702 Mdot
.6877 .58291 Mdot
.34806 .61024 Mdot
.58003 .67642 Mdot
.5122 .24398 Mdot
.7101 .39569 Mdot
.67993 .35637 Mdot
.33535 .58052 Mdot
.45681 .82599 Mdot
.4239 .85332 Mdot
.47863 .39755 Mdot
.55414 .73563 Mdot
.68828 .40077 Mdot
.53251 .45023 Mdot
.72028 .39687 Mdot
.66275 .57431 Mdot
.53562 .2764 Mdot
.44351 .37717 Mdot
.43102 .64653 Mdot
.69755 .40067 Mdot
.3731 .58692 Mdot
.45972 .3932 Mdot
.6861 .61112 Mdot
.71149 .37709 Mdot
.70374 .40811 Mdot
.44694 .35646 Mdot
.38833 .5929 Mdot
.65995 .58615 Mdot
.5438 .67087 Mdot
.69173 .42609 Mdot
.45869 .30325 Mdot
.45687 .33687 Mdot
.41925 .32809 Mdot
.56644 .41213 Mdot
.55287 .64546 Mdot
.55121 .70715 Mdot
.63275 .31926 Mdot
.70631 .5611 Mdot
.60283 .30253 Mdot
.44546 .77967 Mdot
.7216 .34931 Mdot
.47179 .61006 Mdot
.47193 .61079 Mdot
.45687 .36375 Mdot
.31 .77961 Mdot
.36587 .40856 Mdot
.54844 .75035 Mdot
.46672 .60137 Mdot
.65597 .58765 Mdot
.31884 .61051 Mdot
.42646 .28007 Mdot
.41395 .41742 Mdot
.54103 .67079 Mdot
.68673 .57065 Mdot
.25922 .73567 Mdot
.70707 .38438 Mdot
.52857 .45861 Mdot
.41895 .37339 Mdot
.45089 .36472 Mdot
.54556 .6985 Mdot
.53802 .68296 Mdot
.40534 .52065 Mdot
.61773 .43006 Mdot
.43235 .66437 Mdot
.53688 .66737 Mdot
.25777 .73495 Mdot
.34161 .65491 Mdot
.3325 .59261 Mdot
.45917 .5865 Mdot
.52691 .72234 Mdot
.44365 .34808 Mdot
.39228 .5804 Mdot
.36296 .38389 Mdot
.37359 .5547 Mdot
.55817 .53951 Mdot
.54659 .47773 Mdot
.41418 .35524 Mdot
.34229 .56242 Mdot
.36085 .58792 Mdot
.40617 .58488 Mdot
.46145 .59287 Mdot
.4281 .37 Mdot
.49353 .38751 Mdot
.46707 .34559 Mdot
.39246 .48665 Mdot
.46025 .36283 Mdot
.4403 .77942 Mdot
.53787 .46779 Mdot
.77393 .45403 Mdot
.46642 .35225 Mdot
.55543 .72957 Mdot
.457 .34439 Mdot
.70969 .41935 Mdot
.4104 .34674 Mdot
.55497 .53539 Mdot
.54242 .71157 Mdot
.24981 .57311 Mdot
.67585 .52402 Mdot
.44396 .32988 Mdot
.71549 .37219 Mdot
.53867 .81994 Mdot
.62765 .3231 Mdot
.40871 .52484 Mdot
.36037 .57325 Mdot
.68141 .53145 Mdot
.53626 .73569 Mdot
.67575 .59312 Mdot
.38736 .36149 Mdot
.45001 .59118 Mdot
.54031 .16127 Mdot
.59563 .38986 Mdot
.44546 .34695 Mdot
.48832 .4375 Mdot
.35953 .56844 Mdot
.69782 .57941 Mdot
.30028 .54408 Mdot
.43119 .41454 Mdot
.74021 .41204 Mdot
.70043 .41805 Mdot
.732 .61234 Mdot
.47098 .54342 Mdot
.34576 .39901 Mdot
.54616 .70075 Mdot
.69766 .55257 Mdot
.69359 .41471 Mdot
.41614 .57919 Mdot
.53303 .73031 Mdot
.56351 .73741 Mdot
.56751 .70006 Mdot
.46118 .37442 Mdot
.45327 .59926 Mdot
.48247 .56214 Mdot
.48514 .605 Mdot
.41776 .41338 Mdot
.71391 .58902 Mdot
.48505 .609 Mdot
.7112 .40103 Mdot
.57235 .71301 Mdot
.67081 .59806 Mdot
.45463 .35327 Mdot
.35381 .59389 Mdot
.66946 .34194 Mdot
.6247 .74555 Mdot
.56487 .54318 Mdot
.56498 .54325 Mdot
.37887 .61908 Mdot
.47004 .63029 Mdot
.57333 .66072 Mdot
.22156 .50617 Mdot
.75986 .41384 Mdot
.50753 .3611 Mdot
.72803 .50671 Mdot
.71574 .55775 Mdot
.67177 .57407 Mdot
.44634 .38046 Mdot
.67597 .54323 Mdot
.43146 .38587 Mdot
.69743 .54202 Mdot
.41903 .78771 Mdot
.39421 .39314 Mdot
.67594 .57775 Mdot
.46801 .29651 Mdot
.46537 .38388 Mdot
.38028 .57264 Mdot
.701 .53586 Mdot
.39496 .35911 Mdot
.64946 .17636 Mdot
.55342 .68906 Mdot
.4608 .59383 Mdot
.55222 .50884 Mdot
.54198 .72236 Mdot
.33935 .60985 Mdot
.41934 .38338 Mdot
.70728 .38136 Mdot
.33266 .58846 Mdot
.63743 .60359 Mdot
.70027 .40175 Mdot
.49285 .48452 Mdot
.32889 .58762 Mdot
.46193 .60346 Mdot
.73311 .41712 Mdot
.49621 .34609 Mdot
.67384 .57398 Mdot
.61798 .75232 Mdot
.48071 .5922 Mdot
.4397 .37611 Mdot
.67318 .60999 Mdot
.53429 .72104 Mdot
.43655 .33357 Mdot
.692 .55293 Mdot
.46703 .58773 Mdot
.4702 .37341 Mdot
.44639 .39429 Mdot
.27651 .58704 Mdot
.64226 .47975 Mdot
.71028 .39803 Mdot
.37526 .62663 Mdot
.4224 .41896 Mdot
.70074 .41367 Mdot
.62265 .66106 Mdot
.38226 .35971 Mdot
.3491 .61749 Mdot
.24427 .52069 Mdot
.65952 .56016 Mdot
.52702 .70872 Mdot
.72455 .55351 Mdot
.6971 .37815 Mdot
.48542 .87384 Mdot
.45686 .58958 Mdot
.43744 .3173 Mdot
.39859 .36688 Mdot
.64874 .56375 Mdot
.35826 .58622 Mdot
.43078 .66311 Mdot
.40873 .35502 Mdot
.45562 .44163 Mdot
.44316 .36021 Mdot
.63251 .67032 Mdot
.37678 .60066 Mdot
.44107 .36202 Mdot
.48142 .31928 Mdot
.39691 .38063 Mdot
.72756 .37993 Mdot
.55867 .1929 Mdot
.49229 .37147 Mdot
.86897 .63928 Mdot
.44268 .59137 Mdot
.68443 .5753 Mdot
.57389 .39034 Mdot
.56092 .50791 Mdot
.78769 .35435 Mdot
.35163 .61316 Mdot
.39079 .55355 Mdot
.66895 .59198 Mdot
.7258 .33571 Mdot
.47796 .62989 Mdot
.45065 .39572 Mdot
.41709 .3757 Mdot
.66274 .57443 Mdot
.66271 .55152 Mdot
.44628 .5905 Mdot
.48092 .34509 Mdot
.39835 .4293 Mdot
.7246 .5677 Mdot
.46259 .35563 Mdot
.23147 .43134 Mdot
.57786 .71492 Mdot
.32702 .58288 Mdot
.5591 .70585 Mdot
.57923 .70507 Mdot
.29718 .54058 Mdot
.54606 .43704 Mdot
.55994 .6778 Mdot
.56778 .73987 Mdot
.69995 .34769 Mdot
.34905 .49417 Mdot
.73047 .38238 Mdot
.45219 .51948 Mdot
.70137 .56628 Mdot
.42724 .36805 Mdot
.37921 .598 Mdot
.70001 .26896 Mdot
.43632 .68713 Mdot
.45924 .25196 Mdot
.46216 .4097 Mdot
.70041 .57279 Mdot
.47649 .5893 Mdot
.38177 .36081 Mdot
.59722 .29611 Mdot
.45273 .36933 Mdot
.65546 .56932 Mdot
.34923 .49632 Mdot
.5918 .76192 Mdot
.54418 .66282 Mdot
.30382 .57252 Mdot
.45635 .34307 Mdot
.36407 .60534 Mdot
.56951 .68155 Mdot
.6933 .40401 Mdot
.71583 .39088 Mdot
.44102 .3291 Mdot
.54519 .52393 Mdot
.77488 .36778 Mdot
.45432 .3942 Mdot
.47948 .37741 Mdot
.47345 .60937 Mdot
.48046 .37676 Mdot
.49839 .37751 Mdot
.46293 .4036 Mdot
.48034 .40117 Mdot
.52995 .72677 Mdot
.32697 .52125 Mdot
.47072 .33491 Mdot
.41631 .3232 Mdot
.57264 .67574 Mdot
.39596 .33992 Mdot
.53628 .69461 Mdot
.45014 .67247 Mdot
.55834 .67913 Mdot
.71433 .39146 Mdot
.67447 .61118 Mdot
.35689 .52962 Mdot
.32032 .59457 Mdot
.54723 .73173 Mdot
.73447 .41023 Mdot
.53196 .70553 Mdot
.70241 .55162 Mdot
.61181 .73961 Mdot
.32323 .63137 Mdot
.53259 .48768 Mdot
.33332 .49256 Mdot
.50737 .73588 Mdot
.67614 .54563 Mdot
.32284 .58949 Mdot
.58779 .66312 Mdot
.44495 .4115 Mdot
.70185 .38499 Mdot
.45615 .36351 Mdot
.57016 .71816 Mdot
.70045 .56957 Mdot
.40932 .54748 Mdot
.71151 .39841 Mdot
.53506 .84707 Mdot
.72135 .56274 Mdot
.40266 .35557 Mdot
.57048 .6744 Mdot
.61346 .68458 Mdot
.54231 .68431 Mdot
.51362 .24342 Mdot
.41635 .63269 Mdot
.70977 .28694 Mdot
.33835 .58326 Mdot
.48985 .59547 Mdot
.17526 .38984 Mdot
.48493 .75442 Mdot
.34878 .59831 Mdot
.72038 .51815 Mdot
.46331 .36463 Mdot
.47218 .40035 Mdot
.47666 .44371 Mdot
.38771 .56621 Mdot
.4549 .41586 Mdot
.45672 .59381 Mdot
.54995 .43732 Mdot
.4986 .58514 Mdot
.6938 .52872 Mdot
.43238 .38485 Mdot
.56401 .67464 Mdot
.54949 .73307 Mdot
.48109 .61233 Mdot
.56338 .70806 Mdot
.47712 .36366 Mdot
.33576 .58152 Mdot
.55443 .56369 Mdot
.70474 .37692 Mdot
.47485 .79385 Mdot
.76877 .38921 Mdot
.67501 .39889 Mdot
.39552 .37713 Mdot
.66752 .59276 Mdot
.77761 .64802 Mdot
.45071 .41338 Mdot
.36082 .59078 Mdot
.39931 .36802 Mdot
.47061 .39883 Mdot
.47661 .34903 Mdot
.69795 .55325 Mdot
.57902 .39941 Mdot
.46258 .35445 Mdot
.56359 .67893 Mdot
.53168 .52904 Mdot
.41961 .42152 Mdot
.57047 .60771 Mdot
.55555 .53679 Mdot
.4959 .69354 Mdot
.31449 .61261 Mdot
.66441 .58649 Mdot
.34234 .58637 Mdot
.34741 .55627 Mdot
.3389 .60946 Mdot
.49229 .57107 Mdot
.22353 .49627 Mdot
.81255 .61307 Mdot
.33014 .37857 Mdot
.32712 .49575 Mdot
.30584 .5729 Mdot
.69646 .65643 Mdot
.35476 .60005 Mdot
.3432 .61122 Mdot
.70051 .79531 Mdot
.37875 .60693 Mdot
.43437 .36316 Mdot
.42901 .32614 Mdot
.22407 .57661 Mdot
.67108 .39735 Mdot
.45666 .38744 Mdot
.48596 .3939 Mdot
.69739 .41693 Mdot
.28464 .576 Mdot
.45466 .58471 Mdot
.52402 .46594 Mdot
.48722 .59488 Mdot
.44773 .35635 Mdot
.42006 .3435 Mdot
.50101 .39295 Mdot
.23841 .30719 Mdot
.7242 .30089 Mdot
.39015 .60169 Mdot
.50332 .35074 Mdot
.53176 .76212 Mdot
.40975 .38471 Mdot
.40032 .37702 Mdot
.47856 .3527 Mdot
.66508 .59003 Mdot
.33433 .61877 Mdot
.51147 .40918 Mdot
.49187 .78141 Mdot
.41428 .3636 Mdot
.76991 .37589 Mdot
.71204 .36373 Mdot
.44126 .37003 Mdot
.37783 .60974 Mdot
.46958 .40321 Mdot
.31524 .59194 Mdot
.32819 .59048 Mdot
.43278 .44223 Mdot
.47089 .55784 Mdot
.31931 .61009 Mdot
.44885 .39591 Mdot
.6689 .55294 Mdot
.45626 .79548 Mdot
.4401 .37506 Mdot
.70689 .40248 Mdot
.43658 .34044 Mdot
.72317 .37607 Mdot
.48632 .37618 Mdot
.48391 .60809 Mdot
.22659 .37581 Mdot
.70118 .58492 Mdot
.67916 .40921 Mdot
.67085 .54766 Mdot
.46116 .42541 Mdot
.30849 .58907 Mdot
.57571 .76625 Mdot
.73443 .31469 Mdot
.472 .60919 Mdot
.64978 .32134 Mdot
.52566 .54246 Mdot
.5405 .67671 Mdot
.37338 .56654 Mdot
.3385 .50783 Mdot
.56911 .60436 Mdot
.68934 .52753 Mdot
.66277 .60162 Mdot
.65548 .50943 Mdot
.66018 .8098 Mdot
.46634 .3579 Mdot
.55834 .62032 Mdot
.24806 .39547 Mdot
.51387 .36171 Mdot
.43872 .28984 Mdot
.71784 .5839 Mdot
.45682 .38764 Mdot
.60236 .36715 Mdot
.69112 .55948 Mdot
.72911 .38856 Mdot
.35279 .60741 Mdot
.71399 .41723 Mdot
.37767 .69008 Mdot
.40638 .52784 Mdot
.68313 .56232 Mdot
.47487 .40515 Mdot
.4508 .38689 Mdot
.38883 .57256 Mdot
.32399 .29391 Mdot
.32553 .58229 Mdot
.69875 .3812 Mdot
.70763 .57526 Mdot
.59657 .16869 Mdot
.44465 .33863 Mdot
.37072 .57812 Mdot
.67769 .52313 Mdot
.42344 .35006 Mdot
.52812 .70859 Mdot
.45146 .41677 Mdot
.37597 .57883 Mdot
.48077 .37696 Mdot
.33563 .58455 Mdot
.67856 .54907 Mdot
.43916 .32788 Mdot
.42706 .336 Mdot
.63729 .31878 Mdot
.72679 .39542 Mdot
.31519 .60217 Mdot
.59965 .36216 Mdot
.40414 .40024 Mdot
.58487 .28866 Mdot
.46119 .34447 Mdot
.34532 .48898 Mdot
.38813 .33304 Mdot
.45596 .59591 Mdot
.39872 .37076 Mdot
.44175 .37507 Mdot
.33367 .2902 Mdot
.32548 .36529 Mdot
.3963 .49243 Mdot
.53272 .72426 Mdot
.38243 .58786 Mdot
.68821 .55631 Mdot
.691 .53181 Mdot
.68249 .58656 Mdot
.74842 .41881 Mdot
.48667 .32845 Mdot
.43688 .37803 Mdot
.56116 .74928 Mdot
.71474 .38463 Mdot
.36595 .58013 Mdot
.70941 .39089 Mdot
.54763 .43185 Mdot
.71023 .40521 Mdot
.46038 .58844 Mdot
.61603 .74459 Mdot
.23261 .44483 Mdot
.72491 .40797 Mdot
.32571 .58462 Mdot
.52468 .52354 Mdot
.51294 .37592 Mdot
.39038 .79282 Mdot
.73934 .41474 Mdot
.66097 .51422 Mdot
.4729 .36358 Mdot
.57685 .37302 Mdot
.53828 .69492 Mdot
.71567 .4175 Mdot
.56651 .69737 Mdot
.46797 .40421 Mdot
.28396 .59767 Mdot
.36923 .59335 Mdot
.57995 .70793 Mdot
.40079 .38856 Mdot
.71516 .41768 Mdot
.67882 .5662 Mdot
.35151 .4947 Mdot
.58247 .68987 Mdot
.66807 .34617 Mdot
.60261 .30422 Mdot
.70763 .5697 Mdot
.34679 .45796 Mdot
.56171 .68417 Mdot
.50415 .35412 Mdot
.36555 .34751 Mdot
.43491 .41883 Mdot
.66154 .59457 Mdot
.67099 .57476 Mdot
.50209 .73332 Mdot
.42235 .33897 Mdot
.46414 .32981 Mdot
.34482 .6264 Mdot
.70922 .57004 Mdot
.33584 .60837 Mdot
.33693 .56584 Mdot
.66243 .57 Mdot
.32174 .5838 Mdot
.70022 .40359 Mdot
.56849 .32213 Mdot
.56144 .68304 Mdot
.52741 .70157 Mdot
.68089 .56227 Mdot
.70368 .59032 Mdot
.66835 .59376 Mdot
.42145 .40816 Mdot
.32639 .59784 Mdot
.43056 .40673 Mdot
.4538 .34172 Mdot
.42651 .59732 Mdot
.34051 .62942 Mdot
.40996 .3927 Mdot
.54913 .57342 Mdot
.74329 .41137 Mdot
.67917 .57891 Mdot
.56292 .72053 Mdot
.68017 .33496 Mdot
.55158 .67156 Mdot
.4023 .39964 Mdot
.38655 .77884 Mdot
.37762 .59467 Mdot
.71941 .39748 Mdot
.5582 .53694 Mdot
.71461 .39862 Mdot
.57871 .71253 Mdot
.37974 .62115 Mdot
.50116 .48328 Mdot
.42497 .3358 Mdot
.56424 .4151 Mdot
.61453 .25891 Mdot
.45295 .77835 Mdot
.55841 .72637 Mdot
.47346 .4015 Mdot
.46214 .60811 Mdot
.219 .50947 Mdot
.44012 .37918 Mdot
.39254 .38013 Mdot
.57305 .52319 Mdot
.39762 .3643 Mdot
.39574 .60074 Mdot
.55929 .54565 Mdot
.4962 .36706 Mdot
.4676 .42228 Mdot
.71105 .76285 Mdot
.46632 .37982 Mdot
.43264 .33198 Mdot
.42943 .35934 Mdot
.43797 .41291 Mdot
.31281 .58543 Mdot
.58593 .54788 Mdot
.57162 .68124 Mdot
.56847 .32171 Mdot
.56736 .69309 Mdot
.67382 .56304 Mdot
.62129 .40715 Mdot
.31419 .58855 Mdot
.7147 .39914 Mdot
.57313 .62536 Mdot
.53463 .27734 Mdot
.68077 .54606 Mdot
.66452 .30963 Mdot
.73794 .39252 Mdot
.51424 .38067 Mdot
.69531 .37831 Mdot
.7078 .59754 Mdot
.52905 .70471 Mdot
.41011 .33915 Mdot
.33745 .61238 Mdot
.36064 .57167 Mdot
.43314 .42096 Mdot
.49096 .7958 Mdot
.5267 .71285 Mdot
.65213 .42482 Mdot
.45627 .37864 Mdot
.40094 .39308 Mdot
.32445 .58002 Mdot
.69824 .57755 Mdot
.52704 .54085 Mdot
.73273 .40308 Mdot
.40968 .3769 Mdot
.4861 .39044 Mdot
.54991 .42899 Mdot
.54016 .73201 Mdot
.47056 .59595 Mdot
.43587 .38238 Mdot
.53267 .45958 Mdot
.45129 .4179 Mdot
.489 .40693 Mdot
.66149 .56064 Mdot
.44431 .44201 Mdot
.41199 .35296 Mdot
.28735 .61132 Mdot
.56173 .68568 Mdot
.35513 .58801 Mdot
.39086 .55654 Mdot
.48081 .6096 Mdot
.55493 .69181 Mdot
.40773 .392 Mdot
.55891 .73715 Mdot
.47168 .3995 Mdot
.45773 .35311 Mdot
.55592 .72751 Mdot
.33445 .60557 Mdot
.46373 .65045 Mdot
.32855 .52046 Mdot
.45915 .4022 Mdot
.43233 .34294 Mdot
.67112 .39695 Mdot
.72451 .27822 Mdot
.41594 .34353 Mdot
.32169 .58979 Mdot
.42405 .34777 Mdot
.5366 .681 Mdot
.69666 .38946 Mdot
.35898 .59406 Mdot
.70848 .55912 Mdot
.68156 .54816 Mdot
.70044 .51924 Mdot
.45935 .58812 Mdot
.47271 .33835 Mdot
.37422 .62685 Mdot
.35046 .63041 Mdot
.5742 .34552 Mdot
.6831 .57587 Mdot
.69641 .39349 Mdot
.45185 .39116 Mdot
.5117 .34249 Mdot
.57802 .70744 Mdot
.8832 .61738 Mdot
.50684 .48176 Mdot
.74203 .3855 Mdot
.61647 .44391 Mdot
.47423 .60736 Mdot
.46575 .3765 Mdot
.71012 .41852 Mdot
.66943 .5613 Mdot
.47275 .40015 Mdot
.4167 .31378 Mdot
.61768 .62517 Mdot
.68767 .59976 Mdot
.56819 .73271 Mdot
.70297 .5458 Mdot
.7334 .38386 Mdot
.45975 .58939 Mdot
.38048 .57623 Mdot
.44671 .37156 Mdot
.38813 .41716 Mdot
.69463 .571 Mdot
.45125 .60615 Mdot
.45217 .33157 Mdot
.38494 .58495 Mdot
.68544 .5812 Mdot
.44411 .35363 Mdot
.22424 .51533 Mdot
.35495 .52996 Mdot
.70349 .56509 Mdot
.4166 .38444 Mdot
.43303 .27834 Mdot
.68237 .60157 Mdot
.70259 .60031 Mdot
.47636 .4002 Mdot
.72281 .41836 Mdot
.41212 .35856 Mdot
.53583 .68995 Mdot
.57995 .4007 Mdot
.55735 .70089 Mdot
.59582 .29326 Mdot
.48124 .40522 Mdot
.36818 .40372 Mdot
.3269 .5633 Mdot
.70181 .42638 Mdot
.39647 .2158 Mdot
.39882 .39428 Mdot
.27139 .63799 Mdot
.5866 .39165 Mdot
.51815 .49299 Mdot
.2746 .64685 Mdot
.73006 .40915 Mdot
.53359 .7069 Mdot
.44357 .33088 Mdot
.52715 .64119 Mdot
.72382 .41304 Mdot
.59429 .29195 Mdot
.42721 .39846 Mdot
.36933 .58598 Mdot
.45819 .37519 Mdot
.38097 .5805 Mdot
.42348 .35604 Mdot
.26936 .61066 Mdot
.77418 .37719 Mdot
.51254 .24249 Mdot
.51383 .38136 Mdot
.61363 .68757 Mdot
.33228 .49299 Mdot
.69976 .39569 Mdot
.46979 .3922 Mdot
.47646 .60067 Mdot
.53209 .71989 Mdot
.60541 .63584 Mdot
.67002 .59286 Mdot
.56505 .68135 Mdot
.33357 .59907 Mdot
.70932 .59948 Mdot
.46109 .61013 Mdot
.47878 .4556 Mdot
.71577 .41848 Mdot
.5533 .68953 Mdot
.44244 .37317 Mdot
.42859 .41636 Mdot
.63265 .67163 Mdot
.5462 .17477 Mdot
.3218 .57427 Mdot
.57836 .84742 Mdot
.38287 .62126 Mdot
.72428 .38904 Mdot
.65972 .5648 Mdot
.44094 .34756 Mdot
.42267 .37492 Mdot
.68864 .59839 Mdot
.38878 .574 Mdot
.67617 .39639 Mdot
.71287 .28448 Mdot
.5358 .74261 Mdot
.55754 .20696 Mdot
.36196 .59584 Mdot
.55884 .2082 Mdot
.74463 .37099 Mdot
.42565 .56554 Mdot
.47689 .21353 Mdot
.54074 .71902 Mdot
.55687 .2055 Mdot
.37204 .58343 Mdot
.468 .361 Mdot
.46388 .60405 Mdot
.44613 .59717 Mdot
.3584 .6049 Mdot
.66191 .57853 Mdot
.73734 .39866 Mdot
.45517 .37678 Mdot
.44715 .46158 Mdot
.32021 .29565 Mdot
.71012 .57849 Mdot
.49213 .4334 Mdot
.54988 .72229 Mdot
.42626 .3472 Mdot
.69147 .4107 Mdot
.53967 .71582 Mdot
.48754 .60445 Mdot
.53931 .28254 Mdot
.41911 .38337 Mdot
.54853 .52969 Mdot
.54214 .6942 Mdot
.71786 .27319 Mdot
.42559 .33749 Mdot
.56182 .68439 Mdot
.39036 .42031 Mdot
.56203 .78013 Mdot
.5419 .55314 Mdot
.48329 .75213 Mdot
.71794 .53832 Mdot
.69805 .54266 Mdot
.65385 .18355 Mdot
.74862 .43732 Mdot
.57431 .69483 Mdot
.46875 .58593 Mdot
.55628 .18694 Mdot
.56416 .69468 Mdot
.40531 .36376 Mdot
.46342 .34652 Mdot
.34895 .49648 Mdot
.50019 .32135 Mdot
.44607 .58939 Mdot
.39781 .47789 Mdot
.47742 .37008 Mdot
.50565 .41944 Mdot
.44294 .33353 Mdot
.38821 .60091 Mdot
.5457 .72002 Mdot
.14887 .53578 Mdot
.54736 .73925 Mdot
.36722 .3876 Mdot
.70139 .56661 Mdot
.72514 .54855 Mdot
.44213 .36919 Mdot
.36197 .33154 Mdot
.26729 .75064 Mdot
.45969 .33993 Mdot
.55763 .53651 Mdot
.60515 .3056 Mdot
.49607 .34092 Mdot
.33729 .61635 Mdot
.39864 .43077 Mdot
.37791 .62731 Mdot
.53744 .71543 Mdot
.72878 .41029 Mdot
.72918 .42902 Mdot
.53426 .70278 Mdot
.42331 .37371 Mdot
.72015 .42866 Mdot
.44846 .36359 Mdot
.45866 .38217 Mdot
.53398 .45252 Mdot
.68777 .39455 Mdot
.66437 .59233 Mdot
.71573 .393 Mdot
.35853 .61392 Mdot
.68917 .81766 Mdot
.7041 .39108 Mdot
.34892 .49431 Mdot
.59776 .37547 Mdot
.56535 .20374 Mdot
.36007 .5706 Mdot
.70332 .37672 Mdot
.53423 .71698 Mdot
.48218 .49164 Mdot
.3285 .47854 Mdot
.55143 .67172 Mdot
.43702 .3804 Mdot
.31401 .58321 Mdot
.376 .62235 Mdot
.533 .67003 Mdot
.3767 .57038 Mdot
.46799 .32165 Mdot
.44211 .39671 Mdot
.57014 .68329 Mdot
.28123 .27245 Mdot
.52571 .70609 Mdot
.29057 .5484 Mdot
.48319 .35861 Mdot
.35967 .59219 Mdot
.34174 .48732 Mdot
.35676 .54492 Mdot
.44896 .59587 Mdot
.41405 .34049 Mdot
.70032 .3907 Mdot
.58025 .34041 Mdot
.70473 .56792 Mdot
.38366 .77394 Mdot
.36263 .57353 Mdot
.51775 .68572 Mdot
.37894 .57246 Mdot
.36185 .56664 Mdot
.5793 .68922 Mdot
.37411 .59681 Mdot
.41471 .36475 Mdot
.28425 .69262 Mdot
.34765 .57242 Mdot
.54385 .70306 Mdot
.70473 .37951 Mdot
.32238 .58766 Mdot
.64717 .41174 Mdot
.4451 .39028 Mdot
.71003 .54182 Mdot
.69317 .43573 Mdot
.34659 .56232 Mdot
.69866 .39595 Mdot
.69044 .57431 Mdot
.7379 .40762 Mdot
.51009 .64495 Mdot
.59707 .68011 Mdot
.43893 .25605 Mdot
.57089 .78044 Mdot
.37306 .61 Mdot
.72997 .57508 Mdot
.41447 .37735 Mdot
.4573 .37974 Mdot
.73983 .42337 Mdot
.38306 .61289 Mdot
.50353 .80004 Mdot
.37569 .4376 Mdot
.47621 .79339 Mdot
.53478 .72751 Mdot
.65639 .38103 Mdot
.50288 .48411 Mdot
.51107 .66654 Mdot
.4959 .35518 Mdot
.47326 .60702 Mdot
.44239 .36018 Mdot
.62703 .32297 Mdot
.73527 .38736 Mdot
.66225 .68902 Mdot
.45104 .4223 Mdot
.69057 .59601 Mdot
.42709 .35357 Mdot
.54269 .61633 Mdot
.47769 .41577 Mdot
.73933 .41651 Mdot
.52745 .73297 Mdot
.32021 .59439 Mdot
.71391 .37597 Mdot
.67776 .55035 Mdot
.46014 .22978 Mdot
.40633 .36664 Mdot
.47578 .36871 Mdot
.67591 .60394 Mdot
.33736 .61051 Mdot
.67203 .5679 Mdot
.56198 .68352 Mdot
.70652 .39252 Mdot
.42908 .41004 Mdot
.49718 .42938 Mdot
.64715 .56814 Mdot
.56755 .72617 Mdot
.6588 .59742 Mdot
.56078 .73623 Mdot
.46845 .60722 Mdot
.49204 .39938 Mdot
.65956 .60246 Mdot
.49525 .35793 Mdot
.32121 .41198 Mdot
.54465 .29797 Mdot
.34809 .28749 Mdot
.66138 .59045 Mdot
.78022 .39604 Mdot
.53925 .7092 Mdot
.55439 .68705 Mdot
.27741 .56312 Mdot
.30495 .77762 Mdot
.52917 .53109 Mdot
.5491 .81837 Mdot
.56158 .68289 Mdot
.54593 .69299 Mdot
.66691 .574 Mdot
.35223 .61205 Mdot
.34775 .55798 Mdot
.67297 .60938 Mdot
.56598 .28486 Mdot
.36628 .58007 Mdot
.22937 .59205 Mdot
.71653 .56532 Mdot
.4439 .32126 Mdot
.39608 .5394 Mdot
.73934 .41581 Mdot
.60994 .31867 Mdot
.61662 .71726 Mdot
.43725 .35434 Mdot
.79897 .63126 Mdot
.66995 .59042 Mdot
.44636 .51675 Mdot
.55346 .75621 Mdot
.41657 .4077 Mdot
.42651 .35902 Mdot
.41757 .35486 Mdot
.74715 .40712 Mdot
.31496 .35067 Mdot
.43924 .35108 Mdot
.52544 .2598 Mdot
.38979 .38585 Mdot
.63091 .70655 Mdot
.71537 .39284 Mdot
.66866 .28493 Mdot
.70465 .60803 Mdot
.49918 .7861 Mdot
.39354 .37665 Mdot
.55115 .68123 Mdot
.55153 .59306 Mdot
.56263 .72509 Mdot
.49601 .67408 Mdot
.53652 .19052 Mdot
.38364 .60991 Mdot
.44245 .41976 Mdot
.7155 .57683 Mdot
.31945 .56671 Mdot
.55121 .58545 Mdot
.67693 .82339 Mdot
.51709 .69544 Mdot
.52737 .88855 Mdot
.56051 .69756 Mdot
.44412 .59271 Mdot
.33608 .59957 Mdot
.37108 .29671 Mdot
.55972 .41952 Mdot
.33567 .60788 Mdot
.78293 .48716 Mdot
.39545 .62074 Mdot
.51836 .22265 Mdot
.30622 .6209 Mdot
.54618 .70863 Mdot
.52669 .67295 Mdot
.40159 .32026 Mdot
.41036 .36225 Mdot
.5669 .4177 Mdot
.44694 .29096 Mdot
.42164 .3845 Mdot
.69151 .55925 Mdot
.57598 .781 Mdot
.52887 .64192 Mdot
.36631 .59988 Mdot
.5752 .71502 Mdot
.4272 .35565 Mdot
.4598 .40151 Mdot
.40614 .33972 Mdot
.72421 .33508 Mdot
.22614 .58851 Mdot
.45942 .35214 Mdot
.47965 .41737 Mdot
.67408 .55019 Mdot
.63403 .67248 Mdot
.60912 .82007 Mdot
.54373 .18946 Mdot
.45957 .33429 Mdot
.72369 .39281 Mdot
.68993 .41026 Mdot
.44378 .31255 Mdot
.37395 .30087 Mdot
.65972 .39997 Mdot
.4421 .37334 Mdot
.48374 .23226 Mdot
.67094 .53552 Mdot
.47452 .61253 Mdot
.694 .57106 Mdot
.33266 .56074 Mdot
.46571 .60923 Mdot
.68716 .55223 Mdot
.54246 .27698 Mdot
.48252 .60386 Mdot
.5582 .78094 Mdot
.70112 .37811 Mdot
.43561 .33383 Mdot
.36458 .51237 Mdot
.71002 .56812 Mdot
.54643 .68946 Mdot
.34007 .59322 Mdot
.52985 .719 Mdot
.61754 .74955 Mdot
.57847 .29282 Mdot
.45476 .59178 Mdot
.54973 .68087 Mdot
.54351 .52709 Mdot
.7211 .39096 Mdot
.56306 .70402 Mdot
.3656 .39675 Mdot
.41952 .42216 Mdot
.22811 .68123 Mdot
.47091 .37982 Mdot
.4947 .71126 Mdot
.54852 .68544 Mdot
.48827 .60892 Mdot
.44847 .37106 Mdot
.72033 .55795 Mdot
.4945 .44771 Mdot
.44948 .36222 Mdot
.70882 .55271 Mdot
.4644 .35461 Mdot
.69255 .40743 Mdot
.39179 .61575 Mdot
.59042 .38377 Mdot
.65444 .35891 Mdot
.73555 .39144 Mdot
.5576 .35158 Mdot
.41562 .34321 Mdot
.74711 .46688 Mdot
.36629 .58522 Mdot
.4007 .39662 Mdot
.60155 .28562 Mdot
.35869 .60957 Mdot
.34193 .58529 Mdot
.47458 .38271 Mdot
.52605 .69764 Mdot
.66614 .59743 Mdot
.71949 .39148 Mdot
.5446 .65143 Mdot
.44385 .35176 Mdot
.47207 .40268 Mdot
.73293 .3861 Mdot
.55213 .69191 Mdot
.42171 .4054 Mdot
.40973 .74229 Mdot
.56308 .32037 Mdot
.57322 .72352 Mdot
.42206 .42274 Mdot
.23106 .62531 Mdot
.37649 .56482 Mdot
.8017 .62774 Mdot
.77285 .38454 Mdot
.66125 .56808 Mdot
.46796 .44292 Mdot
.84457 .67084 Mdot
.70024 .38044 Mdot
.47268 .78487 Mdot
.46643 .36209 Mdot
.44195 .34387 Mdot
.38456 .60475 Mdot
.42175 .40154 Mdot
.38114 .59043 Mdot
.66214 .36687 Mdot
.32461 .79322 Mdot
.36819 .56942 Mdot
.37839 .58333 Mdot
.4052 .29852 Mdot
.76616 .34536 Mdot
.34967 .60601 Mdot
.40692 .3688 Mdot
.77621 .46317 Mdot
.44012 .30302 Mdot
.69499 .37245 Mdot
.66582 .38648 Mdot
.32708 .61251 Mdot
.31675 .49255 Mdot
.40266 .30111 Mdot
.24663 .55708 Mdot
.66149 .42694 Mdot
.57242 .69597 Mdot
.48219 .38704 Mdot
.46597 .58554 Mdot
.67963 .58181 Mdot
.41153 .4412 Mdot
.42732 .3371 Mdot
.34864 .61678 Mdot
.7427 .39054 Mdot
.56542 .70107 Mdot
.49148 .36174 Mdot
.65794 .54552 Mdot
.7334 .39776 Mdot
.33589 .57521 Mdot
.31193 .5224 Mdot
.7241 .42803 Mdot
.49078 .43598 Mdot
.46978 .3599 Mdot
.4812 .34869 Mdot
.51518 .37103 Mdot
.53543 .70135 Mdot
.69487 .60609 Mdot
.48626 .43815 Mdot
.51082 .47412 Mdot
.56689 .31156 Mdot
.41533 .32925 Mdot
.32181 .58904 Mdot
.54105 .72962 Mdot
.46535 .59067 Mdot
.56226 .196 Mdot
.47337 .35415 Mdot
.22887 .5937 Mdot
.7025 .31463 Mdot
.47964 .59767 Mdot
.3122 .57287 Mdot
.7181 .39679 Mdot
.48325 .36857 Mdot
.52328 .25582 Mdot
.4214 .38759 Mdot
.50138 .34447 Mdot
.6596 .57854 Mdot
.57004 .70573 Mdot
.453 .25922 Mdot
.67654 .5808 Mdot
.34218 .586 Mdot
.21509 .56276 Mdot
.34766 .55967 Mdot
.33529 .56647 Mdot
.45913 .55742 Mdot
.53111 .69406 Mdot
.85365 .65972 Mdot
.74198 .29169 Mdot
.42244 .32899 Mdot
.54934 .67551 Mdot
.34608 .60217 Mdot
.40561 .38267 Mdot
.37865 .59366 Mdot
.33439 .61759 Mdot
.445 .39288 Mdot
.43787 .39221 Mdot
.50783 .23944 Mdot
.23612 .59896 Mdot
.70211 .38524 Mdot
.39091 .57922 Mdot
.25928 .55678 Mdot
.44379 .34721 Mdot
.41542 .34918 Mdot
.55225 .5966 Mdot
.71199 .3744 Mdot
.21707 .43691 Mdot
.46133 .37492 Mdot
.64266 .31588 Mdot
.40824 .35499 Mdot
.34732 .55365 Mdot
.55231 .66431 Mdot
.36623 .38794 Mdot
.65647 .58882 Mdot
.38774 .57136 Mdot
.74349 .39969 Mdot
.30158 .58552 Mdot
.22806 .46861 Mdot
.53135 .70971 Mdot
.37609 .57907 Mdot
.71623 .59356 Mdot
.55348 .69919 Mdot
.52637 .70318 Mdot
.55155 .58208 Mdot
.72466 .57837 Mdot
.74031 .38393 Mdot
.55816 .72027 Mdot
.22638 .51889 Mdot
.54862 .70761 Mdot
.22226 .46982 Mdot
.45791 .33018 Mdot
.5278 .26237 Mdot
.41971 .44586 Mdot
.40738 .31619 Mdot
.55619 .71299 Mdot
.7349 .39514 Mdot
.41481 .40147 Mdot
.36088 .56784 Mdot
.71293 .38146 Mdot
.40934 .52808 Mdot
.72905 .57014 Mdot
.36677 .62653 Mdot
.5563 .73962 Mdot
.38084 .60151 Mdot
.60594 .30938 Mdot
.67544 .37546 Mdot
.56861 .59498 Mdot
.5668 .40689 Mdot
.51272 .39813 Mdot
.45642 .42446 Mdot
.41276 .40128 Mdot
.41641 .36552 Mdot
.70251 .56438 Mdot
.74979 .41205 Mdot
.32177 .58603 Mdot
.31891 .2797 Mdot
.54259 .68626 Mdot
.55291 .54024 Mdot
.51491 .37524 Mdot
.47043 .40109 Mdot
.34601 .59985 Mdot
.32759 .61615 Mdot
.32473 .35719 Mdot
.68081 .5997 Mdot
.42605 .30686 Mdot
.3956 .3675 Mdot
.48262 .26881 Mdot
.55664 .70967 Mdot
.45854 .73065 Mdot
.68849 .53016 Mdot
.5406 .89177 Mdot
.67738 .57862 Mdot
.62184 .50726 Mdot
.37431 .59938 Mdot
.70459 .40379 Mdot
.43332 .38273 Mdot
.40733 .49427 Mdot
.3105 .58708 Mdot
.62364 .60636 Mdot
.71331 .40097 Mdot
.47519 .67976 Mdot
.55715 .67612 Mdot
.49209 .36056 Mdot
.40744 .35693 Mdot
.44542 .40804 Mdot
.4127 .38917 Mdot
.57491 .6899 Mdot
.43 .39308 Mdot
.58251 .69591 Mdot
.23139 .45694 Mdot
.59549 .27852 Mdot
.70792 .59405 Mdot
.64667 .67274 Mdot
.33833 .56665 Mdot
.19707 .49527 Mdot
.22581 .43662 Mdot
.54524 .29859 Mdot
.50328 .65206 Mdot
.49786 .37038 Mdot
.66316 .58035 Mdot
.56441 .64687 Mdot
.711 .59033 Mdot
.1618 .59349 Mdot
.34498 .49648 Mdot
.48812 .70269 Mdot
.43687 .40539 Mdot
.66915 .60546 Mdot
.30237 .51183 Mdot
.48176 .44377 Mdot
.71358 .42857 Mdot
.22528 .49028 Mdot
.40201 .50393 Mdot
.69587 .38819 Mdot
.4516 .38842 Mdot
.33783 .62894 Mdot
.42841 .37936 Mdot
.43829 .38599 Mdot
.46286 .34069 Mdot
.56899 .66846 Mdot
.44494 .32428 Mdot
.41241 .3627 Mdot
.5666 .16856 Mdot
.65067 .62653 Mdot
.69678 .54096 Mdot
.34366 .29567 Mdot
.71448 .3845 Mdot
.33092 .56113 Mdot
.58442 .39115 Mdot
.54176 .68256 Mdot
.32493 .35254 Mdot
.46064 .39502 Mdot
.43376 .77867 Mdot
.52938 .72847 Mdot
.73 .41572 Mdot
.47084 .58788 Mdot
.46313 .69467 Mdot
.65719 .56277 Mdot
.45463 .58581 Mdot
.70555 .57073 Mdot
.36847 .25549 Mdot
.38067 .58666 Mdot
.5126 .39858 Mdot
.56578 .70793 Mdot
.71847 .58209 Mdot
.52015 .25552 Mdot
.4232 .34529 Mdot
.66096 .59045 Mdot
.45098 .44502 Mdot
.58373 .34073 Mdot
.58363 .39543 Mdot
.71253 .59488 Mdot
.52639 .72841 Mdot
.55561 .70491 Mdot
.69475 .38546 Mdot
.37684 .56664 Mdot
.34219 .61331 Mdot
.55136 .70997 Mdot
.73951 .72813 Mdot
.44241 .35324 Mdot
.45499 .34516 Mdot
.50355 .47967 Mdot
.40157 .37705 Mdot
.67121 .3909 Mdot
.44032 .59257 Mdot
.32956 .60966 Mdot
.41239 .40032 Mdot
.42299 .40598 Mdot
.47156 .36576 Mdot
.5582 .27551 Mdot
.69578 .57256 Mdot
.47836 .36885 Mdot
.7135 .41882 Mdot
.40673 .51998 Mdot
.41299 .3746 Mdot
.49377 .43503 Mdot
.38127 .59293 Mdot
.63724 .52559 Mdot
.54423 .68889 Mdot
.70769 .58259 Mdot
.71307 .57923 Mdot
.60391 .25443 Mdot
.37854 .55844 Mdot
.44764 .58816 Mdot
.62342 .68058 Mdot
.463 .5886 Mdot
.7129 .40314 Mdot
.53583 .5483 Mdot
.73672 .55304 Mdot
.6992 .54234 Mdot
.51968 .6765 Mdot
.41575 .4125 Mdot
.4111 .37346 Mdot
.49435 .78798 Mdot
.45835 .34066 Mdot
.69963 .38899 Mdot
.53539 .67817 Mdot
.37602 .58254 Mdot
.69697 .41519 Mdot
.55789 .68842 Mdot
.33448 .60852 Mdot
.38744 .37164 Mdot
.40524 .36799 Mdot
.33862 .58996 Mdot
.34022 .57275 Mdot
.43438 .36691 Mdot
.51775 .18456 Mdot
.32295 .60333 Mdot
.33723 .59527 Mdot
.40602 .5155 Mdot
.66516 .55329 Mdot
.50597 .44179 Mdot
.54005 .6801 Mdot
.41364 .35966 Mdot
.70209 .59826 Mdot
.72263 .40644 Mdot
.34181 .57867 Mdot
.48642 .38204 Mdot
.44996 .35219 Mdot
.72319 .39379 Mdot
.68618 .38605 Mdot
.71547 .3777 Mdot
.53887 .66886 Mdot
.4488 .39608 Mdot
.34172 .60376 Mdot
.56017 .67619 Mdot
.71935 .42574 Mdot
.697 .37527 Mdot
.48134 .20541 Mdot
.43686 .35735 Mdot
.68865 .41154 Mdot
.71495 .805 Mdot
.48397 .22122 Mdot
.45937 .60854 Mdot
.69579 .52395 Mdot
.78477 .38396 Mdot
.6963 .43622 Mdot
.57214 .70574 Mdot
.55993 .54198 Mdot
.72941 .37676 Mdot
.48839 .3622 Mdot
.43698 .33775 Mdot
.50743 .39978 Mdot
.71669 .3826 Mdot
.57899 .2913 Mdot
.38978 .60558 Mdot
.26094 .37542 Mdot
.71419 .38452 Mdot
.721 .58135 Mdot
.64684 .56628 Mdot
.67257 .57604 Mdot
.49303 .39641 Mdot
.3513 .25931 Mdot
.2453 .49966 Mdot
.21808 .42639 Mdot
.55693 .67764 Mdot
.33094 .61753 Mdot
.40833 .54381 Mdot
.34193 .58454 Mdot
.68544 .58664 Mdot
.73441 .39888 Mdot
.38387 .60713 Mdot
.52682 .70453 Mdot
.55538 .70874 Mdot
.65332 .58871 Mdot
.68821 .57326 Mdot
.68122 .56404 Mdot
.38461 .56972 Mdot
.37436 .59822 Mdot
.43746 .41094 Mdot
.34579 .5752 Mdot
.72855 .31794 Mdot
.70918 .34714 Mdot
.64773 .58545 Mdot
.53927 .7005 Mdot
.32921 .58883 Mdot
.43591 .33297 Mdot
.58831 .51312 Mdot
.70534 .60993 Mdot
.73479 .41906 Mdot
.31842 .7425 Mdot
.30531 .78649 Mdot
.44934 .42043 Mdot
.57141 .72008 Mdot
.36114 .35244 Mdot
.41846 .36202 Mdot
.65737 .57844 Mdot
.6986 .29314 Mdot
.48391 .59871 Mdot
.42148 .37895 Mdot
.38991 .36076 Mdot
.53039 .71443 Mdot
.5831 .39124 Mdot
.49026 .36489 Mdot
.56087 .56105 Mdot
.52307 .72036 Mdot
.68427 .53116 Mdot
.69533 .20992 Mdot
.4373 .51701 Mdot
.62379 .34148 Mdot
.47351 .61119 Mdot
.47146 .34623 Mdot
.6943 .55926 Mdot
.71759 .42275 Mdot
.69002 .56507 Mdot
.31531 .5663 Mdot
.65936 .56039 Mdot
.45326 .33518 Mdot
.34629 .60648 Mdot
.55369 .69062 Mdot
.54771 .50534 Mdot
.3696 .26595 Mdot
.71902 .55484 Mdot
.45196 .60726 Mdot
.43686 .39141 Mdot
.2192 .52025 Mdot
.39984 .32052 Mdot
.41147 .35506 Mdot
.5585 .72679 Mdot
.35733 .60095 Mdot
.53629 .72844 Mdot
.47472 .45239 Mdot
.27801 .63376 Mdot
.53929 .68911 Mdot
.41737 .49253 Mdot
.7373 .3913 Mdot
.57268 .29012 Mdot
.44997 .37556 Mdot
.56681 .70604 Mdot
.45876 .39038 Mdot
.39172 .58091 Mdot
.55468 .29593 Mdot
.5577 .32113 Mdot
.54777 .72282 Mdot
.48622 .63102 Mdot
.59863 .35943 Mdot
.50858 .44002 Mdot
.56535 .68845 Mdot
.38956 .2227 Mdot
.47502 .59693 Mdot
.73151 .40201 Mdot
.68492 .38462 Mdot
.70849 .41172 Mdot
.45196 .34053 Mdot
.24966 .58214 Mdot
.69114 .38665 Mdot
.52032 .69707 Mdot
.69317 .4032 Mdot
.67492 .34176 Mdot
.49379 .79653 Mdot
.73698 .39278 Mdot
.45565 .37021 Mdot
.37076 .38814 Mdot
.55766 .53887 Mdot
.72014 .54459 Mdot
.42036 .67117 Mdot
.57253 .16881 Mdot
.43979 .34796 Mdot
.26823 .61646 Mdot
.32056 .55623 Mdot
.64216 .48187 Mdot
.55288 .31656 Mdot
.53034 .51226 Mdot
.33213 .59164 Mdot
.57573 .39869 Mdot
.31522 .58486 Mdot
.5154 .39277 Mdot
.45844 .35379 Mdot
.38717 .56989 Mdot
.37097 .76836 Mdot
.37436 .21833 Mdot
.46322 .79312 Mdot
.32627 .59919 Mdot
.56171 .68582 Mdot
.56438 .72546 Mdot
.55995 .72542 Mdot
.70133 .55626 Mdot
.37674 .57666 Mdot
.47755 .35822 Mdot
.67058 .55567 Mdot
.44692 .38483 Mdot
.54653 .71684 Mdot
.54929 .30529 Mdot
.37764 .58447 Mdot
.44259 .37451 Mdot
.28268 .53155 Mdot
.70326 .57534 Mdot
.72192 .38987 Mdot
.30266 .72182 Mdot
.71264 .52534 Mdot
.53453 .73558 Mdot
.30433 .57384 Mdot
.63834 .57138 Mdot
.59147 .5421 Mdot
.42691 .32537 Mdot
.41247 .33741 Mdot
.56612 .54362 Mdot
.33116 .50298 Mdot
.49366 .37151 Mdot
.6797 .54917 Mdot
.68098 .54223 Mdot
.46113 .38756 Mdot
.37232 .57253 Mdot
.71991 .369 Mdot
.7382 .4256 Mdot
.50783 .36535 Mdot
.56935 .40981 Mdot
.52625 .26092 Mdot
.41002 .39472 Mdot
.48865 .42975 Mdot
.72072 .589 Mdot
.46445 .61094 Mdot
.55312 .42461 Mdot
.69957 .40349 Mdot
.46648 .36774 Mdot
.3212 .29833 Mdot
.36349 .57428 Mdot
.66256 .59349 Mdot
.56762 .67642 Mdot
.72071 .42839 Mdot
.64878 .57664 Mdot
.46117 .38748 Mdot
.42188 .40537 Mdot
.56397 .70698 Mdot
.35055 .55307 Mdot
.72836 .38723 Mdot
.67093 .55459 Mdot
.70209 .40223 Mdot
.37448 .59483 Mdot
.33162 .58249 Mdot
.40187 .34499 Mdot
.40853 .31319 Mdot
.71792 .56068 Mdot
.50264 .36373 Mdot
.6713 .56236 Mdot
.63276 .67225 Mdot
.57816 .70594 Mdot
.39796 .3884 Mdot
.37348 .55474 Mdot
.54902 .71519 Mdot
.43454 .35002 Mdot
.56984 .54743 Mdot
.44761 .41655 Mdot
.67821 .60829 Mdot
.69946 .27586 Mdot
.71957 .41124 Mdot
.38069 .38154 Mdot
.36009 .42836 Mdot
.40271 .3822 Mdot
.70148 .53831 Mdot
.23324 .50783 Mdot
.53551 .694 Mdot
.37078 .6042 Mdot
.70793 .50791 Mdot
.54564 .70436 Mdot
.461 .36785 Mdot
.70461 .39043 Mdot
.31778 .588 Mdot
.45613 .60238 Mdot
.55406 .44022 Mdot
.38535 .42148 Mdot
.45145 .3073 Mdot
.49393 .36586 Mdot
.54619 .8201 Mdot
.68402 .56426 Mdot
.34457 .60061 Mdot
.57312 .7157 Mdot
.53088 .70451 Mdot
.6983 .57788 Mdot
.40644 .50676 Mdot
.41716 .79174 Mdot
.76124 .76632 Mdot
.64757 .57741 Mdot
.69969 .40942 Mdot
.55426 .29723 Mdot
.67115 .57726 Mdot
.70598 .56254 Mdot
.72343 .58853 Mdot
.50019 .79117 Mdot
.32956 .60143 Mdot
.45012 .35095 Mdot
.31721 .54458 Mdot
.46398 .34281 Mdot
.61843 .35482 Mdot
.54549 .71598 Mdot
.37143 .60411 Mdot
.64137 .40112 Mdot
.47427 .4191 Mdot
.4237 .36659 Mdot
.65074 .42557 Mdot
.39047 .30257 Mdot
.56103 .20108 Mdot
.4016 .35608 Mdot
.69593 .56597 Mdot
.40896 .56899 Mdot
.49017 .43576 Mdot
.27996 .53437 Mdot
.55769 .70119 Mdot
.45315 .59158 Mdot
.51052 .41152 Mdot
.50042 .40729 Mdot
.31672 .58246 Mdot
.38222 .60903 Mdot
.69289 .3799 Mdot
.2912 .69801 Mdot
.55743 .69695 Mdot
.47664 .7405 Mdot
.41075 .35561 Mdot
.49718 .67697 Mdot
.70877 .2885 Mdot
.43106 .35593 Mdot
.55083 .57729 Mdot
.32499 .35725 Mdot
.48217 .39184 Mdot
.22534 .41357 Mdot
.54068 .70656 Mdot
.61656 .29965 Mdot
.42786 .39648 Mdot
.66048 .58603 Mdot
.35757 .6125 Mdot
.36599 .62692 Mdot
.7156 .42344 Mdot
.7452 .31162 Mdot
.3873 .82962 Mdot
.37267 .60428 Mdot
.42095 .34664 Mdot
.54286 .69131 Mdot
.45122 .59652 Mdot
.40611 .43857 Mdot
.53497 .62442 Mdot
.36215 .57519 Mdot
.47911 .44322 Mdot
.42984 .78009 Mdot
.57969 .39523 Mdot
.19111 .52514 Mdot
.55783 .72445 Mdot
.69563 .39856 Mdot
.48123 .31194 Mdot
.62606 .68466 Mdot
.40499 .36627 Mdot
.61975 .34993 Mdot
.40459 .57764 Mdot
.69692 .39157 Mdot
.42257 .37143 Mdot
.49346 .37556 Mdot
.5632 .37068 Mdot
.68821 .37546 Mdot
.49197 .36901 Mdot
.45336 .42145 Mdot
.36665 .61298 Mdot
.44006 .59349 Mdot
.37387 .58136 Mdot
.42954 .37887 Mdot
.67463 .25092 Mdot
.38875 .5862 Mdot
.44408 .65619 Mdot
.76862 .38551 Mdot
.54297 .68205 Mdot
.43575 .44136 Mdot
.4467 .32686 Mdot
.18389 .53968 Mdot
.44819 .59621 Mdot
.6423 .79732 Mdot
.67413 .6063 Mdot
.52183 .15164 Mdot
.71545 .5266 Mdot
.48616 .65425 Mdot
.60633 .6143 Mdot
.4873 .43513 Mdot
.39918 .49491 Mdot
.21253 .42716 Mdot
.56186 .74906 Mdot
.19582 .48658 Mdot
.41035 .36246 Mdot
.4692 .3662 Mdot
.6664 .56734 Mdot
.49256 .66391 Mdot
.36631 .39044 Mdot
.5546 .42316 Mdot
.73225 .41367 Mdot
.35677 .58618 Mdot
.43865 .33593 Mdot
.35127 .75774 Mdot
.72294 .57024 Mdot
.3704 .27483 Mdot
.44581 .37364 Mdot
.3643 .33871 Mdot
.49408 .656 Mdot
.55229 .68882 Mdot
.71197 .59583 Mdot
.72417 .57621 Mdot
.46936 .34585 Mdot
.5724 .68341 Mdot
.45059 .41066 Mdot
.59565 .35028 Mdot
.45675 .44421 Mdot
.71732 .40456 Mdot
.42179 .3388 Mdot
.35051 .3442 Mdot
.19431 .35569 Mdot
.4511 .42345 Mdot
.3399 .56449 Mdot
.67952 .56164 Mdot
.69265 .57741 Mdot
.33753 .61182 Mdot
.69261 .57811 Mdot
.25998 .38178 Mdot
.24445 .59389 Mdot
.70946 .40286 Mdot
.24216 .4419 Mdot
.72641 .41228 Mdot
.45429 .59074 Mdot
.4355 .36047 Mdot
.73039 .64315 Mdot
.65063 .56692 Mdot
.67964 .33539 Mdot
.54914 .71067 Mdot
.44649 .59555 Mdot
.43872 .39362 Mdot
.66927 .43858 Mdot
.67342 .58742 Mdot
.48881 .53936 Mdot
.4663 .34743 Mdot
.38802 .57424 Mdot
.47691 .3959 Mdot
.41975 .29124 Mdot
.44305 .59132 Mdot
.4847 .39489 Mdot
.55782 .6883 Mdot
.38412 .58396 Mdot
.49254 .71969 Mdot
.7094 .56554 Mdot
.42688 .38466 Mdot
.41955 .34971 Mdot
.31391 .60079 Mdot
.42453 .32868 Mdot
.56881 .68397 Mdot
.90224 .57474 Mdot
.72187 .37826 Mdot
.46777 .6116 Mdot
.37752 .69009 Mdot
.48743 .39107 Mdot
.4236 .40903 Mdot
.50695 .51917 Mdot
.32288 .29438 Mdot
.54885 .68292 Mdot
.46456 .31319 Mdot
.68811 .54126 Mdot
.73052 .38876 Mdot
.52627 .71398 Mdot
.43979 .39661 Mdot
.46381 .3523 Mdot
.69798 .39172 Mdot
.6449 .419 Mdot
.6772 .39722 Mdot
.57356 .69755 Mdot
.31574 .64639 Mdot
.59006 .51199 Mdot
.4444 .35925 Mdot
.45422 .61044 Mdot
.35364 .59845 Mdot
.56636 .68729 Mdot
.31095 .35519 Mdot
.51555 .39118 Mdot
.56604 .73556 Mdot
.55506 .69192 Mdot
.43292 .32496 Mdot
.38032 .56031 Mdot
.3024 .57422 Mdot
.3495 .5989 Mdot
.59773 .27271 Mdot
.60794 .79813 Mdot
.68415 .56052 Mdot
.54141 .69964 Mdot
.69825 .59908 Mdot
.72964 .37814 Mdot
.57271 .32003 Mdot
.72349 .56066 Mdot
.3973 .57851 Mdot
.71026 .589 Mdot
.44846 .41209 Mdot
.52894 .69186 Mdot
.71596 .56287 Mdot
.40825 .38652 Mdot
.50312 .38925 Mdot
.49733 .31769 Mdot
.73422 .37815 Mdot
.57665 .40114 Mdot
.45532 .37552 Mdot
.47162 .5887 Mdot
.43801 .36985 Mdot
.57023 .68425 Mdot
.55138 .49898 Mdot
.4734 .37831 Mdot
.65028 .56752 Mdot
.61651 .80384 Mdot
.67948 .54028 Mdot
.44994 .28044 Mdot
.43833 .38067 Mdot
.44228 .35729 Mdot
.44167 .39309 Mdot
.39911 .50624 Mdot
.5481 .74132 Mdot
.48318 .32217 Mdot
.66011 .59952 Mdot
.33926 .58378 Mdot
.39076 .59046 Mdot
.51886 .52797 Mdot
.45707 .58502 Mdot
.56149 .67495 Mdot
.4426 .35538 Mdot
.49205 .54147 Mdot
.53097 .4725 Mdot
.44254 .78943 Mdot
.68652 .52117 Mdot
.70419 .54382 Mdot
.35875 .56555 Mdot
.70031 .54735 Mdot
.4354 .39483 Mdot
.47945 .44239 Mdot
.49045 .7149 Mdot
.54305 .75347 Mdot
.73131 .39124 Mdot
.44186 .38425 Mdot
.5393 .25967 Mdot
.67397 .55031 Mdot
.72228 .58571 Mdot
.45006 .40997 Mdot
.33439 .54968 Mdot
.25642 .27501 Mdot
.5476 .67511 Mdot
.22576 .5335 Mdot
.31145 .53822 Mdot
.51768 .28713 Mdot
.53348 .70308 Mdot
.55108 .56999 Mdot
.71705 .54065 Mdot
.66965 .23421 Mdot
.33623 .5865 Mdot
.72932 .38916 Mdot
.40622 .37623 Mdot
.39772 .57867 Mdot
.65027 .59876 Mdot
.31644 .59426 Mdot
.50995 .40993 Mdot
.52612 .72069 Mdot
.68324 .58026 Mdot
.52561 .67254 Mdot
.31871 .56644 Mdot
.72417 .41238 Mdot
.63685 .31939 Mdot
.22164 .51277 Mdot
.32555 .36378 Mdot
.47897 .36821 Mdot
.69291 .63004 Mdot
.47831 .35734 Mdot
.38134 .61935 Mdot
.45083 .37507 Mdot
.45369 .42987 Mdot
.72186 .54393 Mdot
.41399 .32998 Mdot
.41666 .34519 Mdot
.27367 .53995 Mdot
.42751 .36096 Mdot
.46321 .38361 Mdot
.40199 .34264 Mdot
.38964 .56949 Mdot
.41077 .33396 Mdot
.38007 .57023 Mdot
.45812 .78331 Mdot
.70829 .56871 Mdot
.72718 .37646 Mdot
.73279 .38307 Mdot
.6262 .34662 Mdot
.54589 .26551 Mdot
.387 .53464 Mdot
.3608 .5788 Mdot
.55584 .71208 Mdot
.44492 .4119 Mdot
.4077 .20885 Mdot
.66795 .25381 Mdot
.70461 .53447 Mdot
.71755 .57055 Mdot
.41215 .38181 Mdot
.29098 .77313 Mdot
.40379 .35358 Mdot
.50459 .48214 Mdot
.45322 .34129 Mdot
.39872 .39009 Mdot
.70922 .60014 Mdot
.6073 .31121 Mdot
.47825 .36876 Mdot
.31648 .5822 Mdot
.73021 .39373 Mdot
.37082 .32375 Mdot
.67039 .27506 Mdot
.29483 .54287 Mdot
.36725 .42336 Mdot
.46438 .3891 Mdot
.66362 .56281 Mdot
.32223 .59422 Mdot
.51716 .47446 Mdot
.56233 .67885 Mdot
.56594 .42312 Mdot
.22424 .46086 Mdot
.56874 .74652 Mdot
.73302 .39653 Mdot
.66068 .61447 Mdot
.46354 .33848 Mdot
.6958 .55499 Mdot
.4978 .34337 Mdot
.53217 .47665 Mdot
.71261 .40504 Mdot
.41263 .60656 Mdot
.5609 .68545 Mdot
.39596 .58904 Mdot
.34762 .28791 Mdot
.66888 .25157 Mdot
.5277 .15025 Mdot
.65748 .55781 Mdot
.2803 .31104 Mdot
.35856 .60563 Mdot
.47248 .35017 Mdot
.7582 .76855 Mdot
.36026 .59618 Mdot
.3885 .57394 Mdot
.54465 .48074 Mdot
.59752 .29414 Mdot
.50149 .36073 Mdot
.3224 .60432 Mdot
.65912 .61325 Mdot
.71405 .39765 Mdot
.41303 .3924 Mdot
.50829 .41579 Mdot
.38394 .60639 Mdot
.67927 .5888 Mdot
.61105 .33459 Mdot
.69285 .56976 Mdot
.3341 .6037 Mdot
.70116 .58471 Mdot
.46642 .65414 Mdot
.72268 .56091 Mdot
.43282 .32998 Mdot
.4433 .35596 Mdot
.49996 .58105 Mdot
.33164 .58246 Mdot
.42217 .40806 Mdot
.46627 .35885 Mdot
.3469 .60461 Mdot
.73867 .56172 Mdot
.30419 .31625 Mdot
.42965 .4132 Mdot
.44594 .35197 Mdot
.71728 .37541 Mdot
.58786 .36341 Mdot
.49193 .49208 Mdot
.40724 .38777 Mdot
.70779 .41269 Mdot
.38384 .56984 Mdot
.43591 .36949 Mdot
.60964 .31238 Mdot
.66752 .53781 Mdot
.44587 .40338 Mdot
.45522 .59867 Mdot
.47639 .34788 Mdot
.24574 .30032 Mdot
.43235 .38948 Mdot
.3338 .59794 Mdot
.35662 .61038 Mdot
.7211 .51806 Mdot
.34302 .58774 Mdot
.4593 .60814 Mdot
.55479 .70603 Mdot
.20209 .53172 Mdot
.45321 .60517 Mdot
.47903 .39945 Mdot
.74727 .29656 Mdot
.50369 .42396 Mdot
.48263 .44467 Mdot
.7689 .3464 Mdot
.47318 .61083 Mdot
.36324 .60141 Mdot
.36206 .75688 Mdot
.46876 .32679 Mdot
.55994 .67416 Mdot
.49408 .43321 Mdot
.44684 .40295 Mdot
.44212 .42839 Mdot
.28119 .6325 Mdot
.54886 .6716 Mdot
.50553 .44288 Mdot
.41326 .39282 Mdot
.32317 .29506 Mdot
.4311 .33725 Mdot
.73904 .41302 Mdot
.37456 .58771 Mdot
.69845 .54896 Mdot
.71771 .40209 Mdot
.49294 .36574 Mdot
.71378 .38325 Mdot
.69181 .55643 Mdot
.56324 .7155 Mdot
.43671 .32927 Mdot
.69615 .37131 Mdot
.73549 .40326 Mdot
.47588 .38671 Mdot
.36817 .60894 Mdot
.39623 .32359 Mdot
.43353 .36754 Mdot
.44731 .39433 Mdot
.34595 .6142 Mdot
.82237 .59461 Mdot
.47038 .36817 Mdot
.55216 .57246 Mdot
.38472 .62076 Mdot
.44083 .59539 Mdot
.68748 .54583 Mdot
.46377 .41574 Mdot
.53013 .70001 Mdot
.55326 .70669 Mdot
.65646 .55471 Mdot
.37849 .61048 Mdot
.6867 .5813 Mdot
.45156 .42406 Mdot
.48524 .43868 Mdot
.40802 .37907 Mdot
.72465 .51103 Mdot
.45901 .68376 Mdot
.32778 .5791 Mdot
.69765 .53647 Mdot
.56348 .41988 Mdot
.53366 .6844 Mdot
.70509 .60508 Mdot
.31109 .60862 Mdot
.36084 .61803 Mdot
.32991 .6079 Mdot
.71798 .41737 Mdot
.68149 .57677 Mdot
.30015 .58216 Mdot
.3033 .58532 Mdot
.45907 .40263 Mdot
.41864 .39807 Mdot
.37823 .56586 Mdot
.62341 .56285 Mdot
.72631 .40762 Mdot
.66228 .56128 Mdot
.22532 .29857 Mdot
.55099 .67417 Mdot
.27552 .53875 Mdot
.40543 .38362 Mdot
.57172 .89421 Mdot
.40333 .35405 Mdot
.42385 .34266 Mdot
.33269 .56073 Mdot
.68152 .38892 Mdot
.71277 .39487 Mdot
.35881 .60629 Mdot
.33768 .61749 Mdot
.73064 .4204 Mdot
.5355 .50785 Mdot
.27026 .27928 Mdot
.52858 .46763 Mdot
.32374 .58333 Mdot
.21533 .50157 Mdot
.54345 .72394 Mdot
.40014 .60383 Mdot
.59419 .67142 Mdot
.70897 .57438 Mdot
.72037 .56039 Mdot
.56139 .71091 Mdot
.46856 .37493 Mdot
.65464 .57901 Mdot
.39356 .39643 Mdot
.48292 .68015 Mdot
.51588 .62608 Mdot
.47147 .18125 Mdot
.43367 .32784 Mdot
.36734 .3186 Mdot
.52355 .81255 Mdot
.45961 .4127 Mdot
.34268 .4786 Mdot
.72485 .38528 Mdot
.39387 .61094 Mdot
.53419 .67683 Mdot
.26714 .63555 Mdot
.44364 .35817 Mdot
.32234 .58789 Mdot
.54111 .67676 Mdot
.47392 .68759 Mdot
.56006 .56106 Mdot
.46871 .40028 Mdot
.80698 .71514 Mdot
.31284 .58418 Mdot
.69758 .54881 Mdot
.26243 .50995 Mdot
.40054 .58998 Mdot
.58095 .55301 Mdot
.65341 .60662 Mdot
.54313 .43042 Mdot
.31849 .60254 Mdot
.67747 .39965 Mdot
.36339 .58543 Mdot
.69105 .4077 Mdot
.3044 .57528 Mdot
.69541 .58459 Mdot
.42809 .37237 Mdot
.70043 .57864 Mdot
.73694 .42036 Mdot
.65567 .55973 Mdot
.53383 .67721 Mdot
.47972 .6098 Mdot
.54717 .71753 Mdot
.56159 .30577 Mdot
.30403 .37888 Mdot
.56972 .70722 Mdot
.5123 .55744 Mdot
.45699 .33816 Mdot
.34671 .55369 Mdot
.70161 .55211 Mdot
.71715 .53275 Mdot
.57409 .4041 Mdot
.33574 .60705 Mdot
.68261 .59058 Mdot
.2205 .5058 Mdot
.7275 .74301 Mdot
.46545 .42926 Mdot
.62507 .75447 Mdot
.33986 .6021 Mdot
.72834 .55837 Mdot
.50264 .48086 Mdot
.38456 .61035 Mdot
.71725 .56246 Mdot
.56559 .69083 Mdot
.53157 .69648 Mdot
.42132 .3316 Mdot
.5236 .68169 Mdot
.71885 .54522 Mdot
.32275 .28991 Mdot
.37802 .59927 Mdot
.44504 .68247 Mdot
.73291 .38803 Mdot
.70337 .55916 Mdot
.44145 .31748 Mdot
.38037 .55698 Mdot
.70512 .5931 Mdot
.3594 .81531 Mdot
.15623 .39766 Mdot
.68056 .59102 Mdot
.37398 .5868 Mdot
.34337 .57901 Mdot
.47936 .41006 Mdot
.56348 .41428 Mdot
.67256 .58888 Mdot
.72922 .64301 Mdot
.51593 .24768 Mdot
.46762 .60735 Mdot
.56907 .16878 Mdot
.47746 .36856 Mdot
.46228 .3914 Mdot
.57365 .69373 Mdot
.42317 .36268 Mdot
.32945 .61563 Mdot
.40263 .35583 Mdot
.54121 .73244 Mdot
.66893 .54118 Mdot
.43873 .36126 Mdot
.73062 .38777 Mdot
.54606 .73064 Mdot
.56221 .73025 Mdot
.70326 .58588 Mdot
.36694 .61434 Mdot
.3891 .79187 Mdot
.69155 .57153 Mdot
.45022 .3962 Mdot
.47808 .59684 Mdot
.40897 .33379 Mdot
.4906 .57369 Mdot
.37482 .62414 Mdot
.69926 .54722 Mdot
.41396 .60994 Mdot
.54441 .69627 Mdot
.71616 .53758 Mdot
.47305 .34313 Mdot
.71323 .54909 Mdot
.5669 .58705 Mdot
.75985 .45233 Mdot
.30706 .59586 Mdot
.58015 .56136 Mdot
.37346 .61567 Mdot
.46415 .60722 Mdot
.59519 .25041 Mdot
.73037 .40377 Mdot
.67638 .54564 Mdot
.44636 .65608 Mdot
.70972 .56101 Mdot
.4287 .35644 Mdot
.46412 .35068 Mdot
.66729 .56531 Mdot
.71959 .41436 Mdot
.64491 .36608 Mdot
.67929 .41052 Mdot
.37508 .57687 Mdot
.54489 .5245 Mdot
.24548 .27536 Mdot
.66469 .53568 Mdot
.55908 .70817 Mdot
.3811 .45604 Mdot
.4848 .39087 Mdot
.54454 .67387 Mdot
.57529 .71539 Mdot
.70906 .42329 Mdot
.70679 .56115 Mdot
.371 .62845 Mdot
.52457 .70955 Mdot
.39389 .5624 Mdot
.61399 .3279 Mdot
.51584 .38469 Mdot
.51843 .29573 Mdot
.49595 .36652 Mdot
.58004 .39611 Mdot
.52809 .72511 Mdot
.45956 .36342 Mdot
.49996 .33395 Mdot
.56093 .68163 Mdot
.69973 .41884 Mdot
.4034 .6364 Mdot
.68289 .59222 Mdot
.65191 .82875 Mdot
.43187 .33107 Mdot
.43164 .3715 Mdot
.556 .67751 Mdot
.32151 .50216 Mdot
.33096 .57272 Mdot
.37341 .60996 Mdot
.68322 .56457 Mdot
.53127 .48815 Mdot
.4273 .32645 Mdot
.44476 .33125 Mdot
.65938 .58669 Mdot
.47036 .58899 Mdot
.5501 .16541 Mdot
.45088 .35367 Mdot
.53779 .70657 Mdot
.5517 .59279 Mdot
.52349 .71969 Mdot
.40639 .40892 Mdot
.43139 .35011 Mdot
.47742 .34476 Mdot
.45792 .32809 Mdot
.54724 .72151 Mdot
.49477 .36796 Mdot
.4879 .33048 Mdot
.35884 .60023 Mdot
.46981 .38143 Mdot
.51323 .24529 Mdot
.44922 .35706 Mdot
.72614 .3846 Mdot
.49896 .49317 Mdot
.43284 .38822 Mdot
.4677 .38398 Mdot
.5198 .25119 Mdot
.41885 .36812 Mdot
.54129 .67611 Mdot
.33734 .5815 Mdot
.54402 .69462 Mdot
.56011 .70011 Mdot
.71032 .58721 Mdot
.6861 .39815 Mdot
.50271 .37421 Mdot
.72136 .42135 Mdot
.47879 .41378 Mdot
.47201 .45308 Mdot
.58505 .34079 Mdot
.5072 .48143 Mdot
.73396 .38112 Mdot
.44732 .3328 Mdot
.68947 .56047 Mdot
.70236 .54699 Mdot
.56105 .54294 Mdot
.45659 .44178 Mdot
.52294 .69293 Mdot
.56704 .70534 Mdot
.70514 .34757 Mdot
.76361 .43438 Mdot
.73616 .40683 Mdot
.62598 .39529 Mdot
.38719 .3679 Mdot
.46056 .38171 Mdot
.42755 .44501 Mdot
.68583 .60476 Mdot
.47864 .61088 Mdot
.65157 .58279 Mdot
.49628 .65526 Mdot
.53584 .72287 Mdot
.43148 .32871 Mdot
.25718 .73389 Mdot
.38224 .57858 Mdot
.33711 .58092 Mdot
.54069 .73253 Mdot
.68057 .54021 Mdot
.4589 .44515 Mdot
.58772 .84791 Mdot
.35569 .62658 Mdot
.71 .37072 Mdot
.42155 .37526 Mdot
.70779 .57448 Mdot
.38307 .58742 Mdot
.6996 .36999 Mdot
.45687 .32894 Mdot
.65688 .60994 Mdot
.4545 .36555 Mdot
.24634 .41675 Mdot
.36842 .60175 Mdot
.57442 .34494 Mdot
.34743 .55876 Mdot
.5445 .72028 Mdot
.54892 .68452 Mdot
.43399 .3499 Mdot
.61698 .84358 Mdot
.41058 .57297 Mdot
.57861 .71269 Mdot
.69122 .3804 Mdot
.48294 .60614 Mdot
.68921 .38913 Mdot
.67035 .56388 Mdot
.73265 .39773 Mdot
.70688 .59106 Mdot
.62225 .5638 Mdot
.31414 .61701 Mdot
.69848 .39106 Mdot
.34522 .45296 Mdot
.47647 .44366 Mdot
.7273 .4268 Mdot
.41748 .38848 Mdot
.46197 .42193 Mdot
.67036 .59447 Mdot
.72412 .41836 Mdot
.48586 .38224 Mdot
.37247 .68829 Mdot
.55536 .68764 Mdot
.5257 .68724 Mdot
.48922 .43503 Mdot
.72794 .57412 Mdot
.30885 .59709 Mdot
.59773 .38127 Mdot
.43369 .58725 Mdot
.4417 .33108 Mdot
.49133 .39896 Mdot
.3136 .57281 Mdot
.33904 .56631 Mdot
.43479 .34678 Mdot
.23518 .5618 Mdot
.48585 .35484 Mdot
.53307 .69267 Mdot
.3764 .57675 Mdot
.34162 .57834 Mdot
.72036 .54843 Mdot
.38255 .60587 Mdot
.43328 .30616 Mdot
.58039 .72271 Mdot
.47334 .32319 Mdot
.54456 .70004 Mdot
.64321 .54668 Mdot
.68161 .59934 Mdot
.44204 .65965 Mdot
.38285 .60407 Mdot
.41353 .40148 Mdot
.39033 .58711 Mdot
.71207 .37729 Mdot
.33374 .57911 Mdot
.3203 .55994 Mdot
.409 .35919 Mdot
.49134 .36885 Mdot
.46877 .5907 Mdot
.56862 .40757 Mdot
.37007 .59622 Mdot
.43842 .42067 Mdot
.39909 .37555 Mdot
.46571 .34946 Mdot
.59944 .36397 Mdot
.391 .57204 Mdot
.29768 .54001 Mdot
.44362 .57254 Mdot
.37309 .59905 Mdot
.16498 .40767 Mdot
.46084 .58962 Mdot
.46059 .58328 Mdot
.52204 .72512 Mdot
.44898 .35114 Mdot
.69173 .5807 Mdot
.45719 .39606 Mdot
.39869 .43101 Mdot
.43076 .38585 Mdot
.69735 .38707 Mdot
.42728 .32479 Mdot
.46744 .6032 Mdot
.69701 .56883 Mdot
.45345 .4158 Mdot
.43934 .35485 Mdot
.45853 .58532 Mdot
.38693 .56911 Mdot
.3687 .61616 Mdot
.45377 .57922 Mdot
.71821 .42509 Mdot
.55965 .72729 Mdot
.45068 .39717 Mdot
.68598 .56297 Mdot
.69833 .57649 Mdot
.39544 .58135 Mdot
.6582 .58152 Mdot
.55203 .73079 Mdot
.42633 .34198 Mdot
.54568 .72032 Mdot
.69749 .38641 Mdot
.37492 .58827 Mdot
.43185 .39359 Mdot
.46643 .39695 Mdot
.35697 .61034 Mdot
.48869 .36065 Mdot
.7016 .37731 Mdot
.70196 .60122 Mdot
.33507 .57475 Mdot
.55459 .70453 Mdot
.72193 .55377 Mdot
.43302 .41184 Mdot
.14992 .50253 Mdot
.4231 .36095 Mdot
.4507 .33081 Mdot
.39619 .55145 Mdot
.39239 .37281 Mdot
.70982 .56395 Mdot
.38953 .59306 Mdot
.44734 .4213 Mdot
.52376 .25191 Mdot
.69755 .36036 Mdot
.64128 .57044 Mdot
.41419 .36077 Mdot
.18813 .52369 Mdot
.40233 .38502 Mdot
.43629 .65872 Mdot
.58484 .34107 Mdot
.61379 .6812 Mdot
.51821 .29568 Mdot
.57662 .71707 Mdot
.47558 .59161 Mdot
.70419 .58982 Mdot
.30159 .5 Mdot
.42893 .34798 Mdot
.32336 .34692 Mdot
.43535 .39582 Mdot
.53274 .70245 Mdot
.35051 .4879 Mdot
.66034 .56853 Mdot
.54899 .17601 Mdot
.47442 .36446 Mdot
.31415 .58633 Mdot
.72402 .59196 Mdot
.47501 .58841 Mdot
.49053 .37156 Mdot
.73722 .41299 Mdot
.70803 .34971 Mdot
.42538 .30921 Mdot
.54632 .69796 Mdot
.46709 .36831 Mdot
.38104 .36686 Mdot
.77584 .67094 Mdot
.34737 .59984 Mdot
.56308 .69512 Mdot
.75699 .43762 Mdot
.46195 .34795 Mdot
.36176 .61779 Mdot
.3372 .58589 Mdot
.70858 .42016 Mdot
.54843 .65202 Mdot
.66724 .36653 Mdot
.22507 .67185 Mdot
.34825 .26874 Mdot
.68911 .60462 Mdot
.3102 .6327 Mdot
.46579 .39146 Mdot
.67037 .25165 Mdot
.55871 .70387 Mdot
.43115 .3732 Mdot
.32994 .37779 Mdot
.33793 .59582 Mdot
.45554 .35992 Mdot
.72638 .40621 Mdot
.44563 .82155 Mdot
.22431 .4815 Mdot
.18648 .55063 Mdot
.65842 .61267 Mdot
.50228 .36115 Mdot
.44208 .30643 Mdot
.44035 .59555 Mdot
.42904 .42349 Mdot
.70089 .55309 Mdot
.56955 .60509 Mdot
.70912 .40846 Mdot
.38482 .58131 Mdot
.46697 .58647 Mdot
.43485 .39599 Mdot
.49781 .34473 Mdot
.69764 .37656 Mdot
.48318 .3592 Mdot
.25847 .51863 Mdot
.49448 .60698 Mdot
.72328 .56453 Mdot
.31603 .59081 Mdot
.49995 .38391 Mdot
.48233 .60129 Mdot
.40863 .36476 Mdot
.35414 .32846 Mdot
.44058 .38272 Mdot
.4321 .64671 Mdot
.35786 .61275 Mdot
.55194 .69531 Mdot
.4419 .32102 Mdot
.44833 .36581 Mdot
.6291 .49977 Mdot
.4608 .44583 Mdot
.44681 .39118 Mdot
.39759 .59004 Mdot
.38387 .57908 Mdot
.32124 .57879 Mdot
.71482 .54453 Mdot
.53275 .45952 Mdot
.54338 .71337 Mdot
.43094 .44503 Mdot
.5246 .71078 Mdot
.52909 .30735 Mdot
.69202 .38925 Mdot
.43328 .66952 Mdot
.43109 .34089 Mdot
.3304 .60589 Mdot
.29115 .26528 Mdot
.39295 .57438 Mdot
.57819 .74232 Mdot
.55782 .69917 Mdot
.36229 .59444 Mdot
.41631 .36125 Mdot
.55816 .41558 Mdot
.18926 .5672 Mdot
.53172 .68686 Mdot
.50111 .42522 Mdot
.6339 .59684 Mdot
.67157 .53672 Mdot
.17486 .38987 Mdot
.52618 .70396 Mdot
.52481 .81348 Mdot
.43137 .41418 Mdot
.38711 .59258 Mdot
.56228 .7224 Mdot
.57521 .68263 Mdot
.65669 .58001 Mdot
.46455 .40169 Mdot
.4503 .36453 Mdot
.45518 .59702 Mdot
.55546 .7202 Mdot
.40153 .29684 Mdot
.4724 .39839 Mdot
.48665 .67692 Mdot
.32243 .61908 Mdot
.82694 .58581 Mdot
.41288 .49061 Mdot
.32895 .37644 Mdot
.76633 .63373 Mdot
.33798 .57247 Mdot
.46853 .37636 Mdot
.45584 .44472 Mdot
.6868 .60728 Mdot
.42198 .34946 Mdot
.69245 .53458 Mdot
.53457 .71729 Mdot
.37908 .67315 Mdot
.50749 .54725 Mdot
.50706 .64693 Mdot
.42535 .36366 Mdot
.22497 .49146 Mdot
.70131 .39589 Mdot
.55071 .75238 Mdot
.33873 .56825 Mdot
.40586 .40677 Mdot
.66819 .60637 Mdot
.70685 .54111 Mdot
.34153 .59338 Mdot
.49698 .78416 Mdot
.43631 .66184 Mdot
.47395 .33795 Mdot
.6789 .55222 Mdot
.44818 .51767 Mdot
.19726 .494 Mdot
.54234 .73686 Mdot
.70623 .4068 Mdot
.70915 .58123 Mdot
.53726 .669 Mdot
.46793 .42019 Mdot
.35185 .59098 Mdot
.31128 .58549 Mdot
.57372 .5485 Mdot
.68361 .58908 Mdot
.72123 .39432 Mdot
.56948 .55181 Mdot
.54845 .5299 Mdot
.71741 .40579 Mdot
.70575 .53495 Mdot
.36185 .57079 Mdot
.33198 .60032 Mdot
.33803 .5819 Mdot
.28025 .53419 Mdot
.37284 .62465 Mdot
.6645 .31046 Mdot
.42306 .42146 Mdot
.21267 .51039 Mdot
.41051 .40841 Mdot
.537 .67539 Mdot
.36863 .60328 Mdot
.58184 .34054 Mdot
.38845 .3571 Mdot
.19481 .56937 Mdot
.4529 .37813 Mdot
.55161 .58416 Mdot
.4477 .35096 Mdot
.248 .46596 Mdot
.39351 .60991 Mdot
.4687 .34038 Mdot
.57712 .73066 Mdot
.71457 .38184 Mdot
.29659 .58343 Mdot
.45143 .38889 Mdot
.43112 .77485 Mdot
.41836 .38953 Mdot
.39282 .66512 Mdot
.58541 .54779 Mdot
.72853 .4321 Mdot
.40522 .33888 Mdot
.65826 .60085 Mdot
.3735 .42741 Mdot
.2119 .50219 Mdot
.53036 .68925 Mdot
.22345 .49896 Mdot
.65859 .56358 Mdot
.34748 .48884 Mdot
.38374 .35339 Mdot
.71267 .41106 Mdot
.41085 .63531 Mdot
.53643 .68708 Mdot
.43302 .34242 Mdot
.47276 .36434 Mdot
.52718 .6223 Mdot
.20624 .47747 Mdot
.38454 .30689 Mdot
.7217 .3702 Mdot
.22082 .47425 Mdot
.44165 .38964 Mdot
.63879 .57794 Mdot
.38511 .60796 Mdot
.3578 .48387 Mdot
.33355 .49778 Mdot
.4681 .40536 Mdot
.3573 .59536 Mdot
.37751 .61088 Mdot
.32091 .23281 Mdot
.69808 .40411 Mdot
.44328 .38275 Mdot
.58251 .5594 Mdot
.44613 .39706 Mdot
.53489 .70971 Mdot
.38859 .37462 Mdot
.68073 .59837 Mdot
.49587 .48155 Mdot
.71273 .54292 Mdot
.46423 .3446 Mdot
.36509 .5846 Mdot
.5458 .68019 Mdot
.62294 .71777 Mdot
.55633 .65439 Mdot
.66349 .31102 Mdot
.72935 .34816 Mdot
.73718 .4042 Mdot
.68823 .39623 Mdot
.52903 .73612 Mdot
.41568 .35373 Mdot
.58421 .39796 Mdot
.45288 .43324 Mdot
.45207 .34837 Mdot
.43714 .38396 Mdot
.60113 .74227 Mdot
.55699 .69792 Mdot
.70062 .58295 Mdot
.43485 .34586 Mdot
.43599 .42099 Mdot
.36546 .58873 Mdot
.73565 .40555 Mdot
.71692 .58361 Mdot
.73875 .41542 Mdot
.69443 .56507 Mdot
.24311 .30266 Mdot
.5152 .39726 Mdot
.71039 .38267 Mdot
.53103 .72567 Mdot
.32507 .59678 Mdot
.44988 .59266 Mdot
.66944 .5678 Mdot
.66006 .57248 Mdot
.49557 .38832 Mdot
.37961 .59246 Mdot
.37759 .60774 Mdot
.73197 .41931 Mdot
.56782 .70639 Mdot
.49635 .40071 Mdot
.49041 .38243 Mdot
.6321 .70042 Mdot
.70093 .6028 Mdot
.21697 .48718 Mdot
.42037 .58123 Mdot
.4215 .34212 Mdot
.35945 .61734 Mdot
.43959 .36592 Mdot
.45353 .52764 Mdot
.32259 .57369 Mdot
.39151 .37598 Mdot
.41185 .42859 Mdot
.69201 .60301 Mdot
.37629 .20404 Mdot
.50621 .3818 Mdot
.59294 .6895 Mdot
.47502 .38317 Mdot
.5169 .14402 Mdot
.30282 .25674 Mdot
.4104 .37688 Mdot
.44089 .32519 Mdot
.20758 .64547 Mdot
.40182 .37641 Mdot
.46069 .60126 Mdot
.39892 .43182 Mdot
.35008 .61718 Mdot
.5713 .57184 Mdot
.5777 .39958 Mdot
.69611 .40557 Mdot
.68344 .56359 Mdot
.60169 .30143 Mdot
.69266 .41124 Mdot
.33568 .59948 Mdot
.50968 .36713 Mdot
.41548 .57509 Mdot
.71929 .53142 Mdot
.41702 .2921 Mdot
.53321 .70674 Mdot
.57874 .40186 Mdot
.65895 .59362 Mdot
.55524 .7053 Mdot
.40071 .38324 Mdot
.70692 .50988 Mdot
.56273 .74883 Mdot
.3356 .21583 Mdot
.57262 .69161 Mdot
.55133 .68915 Mdot
.54662 .43385 Mdot
.69626 .40605 Mdot
.56729 .61308 Mdot
.49748 .44654 Mdot
.54105 .6782 Mdot
.55619 .19736 Mdot
.68938 .60856 Mdot
.53762 .47013 Mdot
.39922 .60281 Mdot
.50973 .41333 Mdot
.43077 .37751 Mdot
.56855 .69124 Mdot
.33292 .63887 Mdot
.63785 .48986 Mdot
.53005 .71145 Mdot
.4041 .32945 Mdot
.52319 .49015 Mdot
.48086 .60491 Mdot
.4586 .59003 Mdot
.69951 .37095 Mdot
.77561 .48084 Mdot
.35132 .61356 Mdot
.713 .37124 Mdot
.55998 .31939 Mdot
.45851 .37565 Mdot
.54904 .72326 Mdot
.46265 .58505 Mdot
.55249 .70565 Mdot
.70783 .3957 Mdot
.69455 .37959 Mdot
.35688 .60039 Mdot
.33667 .57056 Mdot
.34421 .65415 Mdot
.49358 .22935 Mdot
.44621 .40476 Mdot
.30809 .35668 Mdot
.33657 .56689 Mdot
.30982 .50593 Mdot
.70963 .41687 Mdot
.73057 .41394 Mdot
.22474 .39455 Mdot
.43867 .41125 Mdot
.55199 .59124 Mdot
.43602 .38979 Mdot
.60276 .23037 Mdot
.4319 .39503 Mdot
.65882 .58431 Mdot
.47706 .36456 Mdot
.36093 .76628 Mdot
.44451 .4189 Mdot
.43274 .38367 Mdot
.67489 .57683 Mdot
.50128 .37724 Mdot
.67416 .59704 Mdot
.46631 .37753 Mdot
.74632 .3729 Mdot
.68565 .56346 Mdot
.75174 .39202 Mdot
.54104 .55518 Mdot
.46444 .596 Mdot
.69108 .40167 Mdot
.73865 .4038 Mdot
.61171 .33961 Mdot
.37108 .56964 Mdot
.38974 .48954 Mdot
.42107 .37413 Mdot
.72038 .58936 Mdot
.54826 .72883 Mdot
.47128 .40304 Mdot
.40632 .34224 Mdot
.50235 .39033 Mdot
.35944 .59831 Mdot
.72009 .54239 Mdot
.70773 .38826 Mdot
.70539 .54729 Mdot
.74831 .37817 Mdot
.68197 .60136 Mdot
.48925 .42874 Mdot
.47585 .4158 Mdot
.44775 .30682 Mdot
.32401 .41291 Mdot
.72451 .27982 Mdot
.34657 .59197 Mdot
.47705 .59839 Mdot
.69194 .38695 Mdot
.54635 .50522 Mdot
.34111 .61244 Mdot
.66045 .57684 Mdot
.45449 .36586 Mdot
.51651 .38529 Mdot
.48564 .44997 Mdot
.36155 .54656 Mdot
.74789 .41933 Mdot
.6745 .56707 Mdot
.47212 .60861 Mdot
.52982 .46785 Mdot
.30208 .54292 Mdot
.56736 .31265 Mdot
.44423 .36602 Mdot
.73079 .42097 Mdot
.38307 .58725 Mdot
.55035 .60841 Mdot
.56613 .68931 Mdot
.56612 .41129 Mdot
.42444 .36481 Mdot
.55149 .77823 Mdot
.36324 .58386 Mdot
.72508 .4116 Mdot
.56837 .6902 Mdot
.70273 .40968 Mdot
.48491 .59862 Mdot
.42883 .57758 Mdot
.48944 .37232 Mdot
.43441 .39037 Mdot
.54107 .725 Mdot
.35794 .61404 Mdot
.73207 .36165 Mdot
.5389 .62292 Mdot
.66948 .56327 Mdot
.52969 .50265 Mdot
.38427 .58272 Mdot
.57505 .78176 Mdot
.70299 .54307 Mdot
.52164 .69108 Mdot
.5789 .39129 Mdot
.55902 .7303 Mdot
.4404 .38764 Mdot
.36041 .57725 Mdot
.52819 .69246 Mdot
.63157 .67304 Mdot
.22907 .58799 Mdot
.43154 .62752 Mdot
.45895 .33976 Mdot
.41878 .67449 Mdot
.48633 .79903 Mdot
.28933 .62007 Mdot
.52583 .71116 Mdot
.43184 .35883 Mdot
.47523 .33925 Mdot
.47491 .36394 Mdot
.55819 .68659 Mdot
.6027 .75484 Mdot
.67269 .55028 Mdot
.46049 .36118 Mdot
.72944 .38482 Mdot
.68767 .59601 Mdot
.65203 .55911 Mdot
.71025 .57943 Mdot
.34552 .56618 Mdot
.51479 .38209 Mdot
.41604 .44502 Mdot
.3472 .22795 Mdot
.55139 .69178 Mdot
.4647 .59636 Mdot
.45635 .33162 Mdot
.65598 .31739 Mdot
.32717 .59714 Mdot
.66849 .57557 Mdot
.43246 .37265 Mdot
.58091 .54866 Mdot
.49428 .61267 Mdot
.68462 .57496 Mdot
.33092 .56995 Mdot
.27844 .60436 Mdot
.42344 .34707 Mdot
.46996 .38943 Mdot
.3464 .60727 Mdot
.48828 .81446 Mdot
.52571 .47517 Mdot
.43994 .36343 Mdot
.55462 .69791 Mdot
.66461 .80671 Mdot
.40196 .39118 Mdot
.41659 .59491 Mdot
.47645 .61159 Mdot
.41226 .56592 Mdot
.23139 .53405 Mdot
.43138 .44059 Mdot
.33108 .67309 Mdot
.66869 .34151 Mdot
.2877 .64895 Mdot
.62589 .24267 Mdot
.54261 .62731 Mdot
.28303 .24805 Mdot
.58289 .67807 Mdot
.24414 .44511 Mdot
.33907 .8017 Mdot
.51953 .80775 Mdot
.61748 .51741 Mdot
.61528 .64598 Mdot
.68309 .51468 Mdot
.55711 .16887 Mdot
.65466 .59731 Mdot
.63249 .23312 Mdot
.42657 .38843 Mdot
.47837 .81013 Mdot
.24111 .46809 Mdot
.74831 .31422 Mdot
.44885 .66226 Mdot
.57874 .55183 Mdot
.16575 .54102 Mdot
.46834 .66952 Mdot
.18522 .4143 Mdot
.34815 .40725 Mdot
.8015 .50579 Mdot
.54646 .51442 Mdot
.617 .3083 Mdot
.23186 .50517 Mdot
.33758 .73222 Mdot
.49922 .70398 Mdot
.2873 .32334 Mdot
.7853 .62489 Mdot
.68881 .55122 Mdot
.38173 .61312 Mdot
.60459 .62598 Mdot
.18105 .46548 Mdot
.58887 .72633 Mdot
.32939 .67274 Mdot
.4809 .63082 Mdot
.24632 .46084 Mdot
.57269 .34009 Mdot
.25036 .40919 Mdot
.66438 .36565 Mdot
.56247 .17567 Mdot
.33614 .54542 Mdot
.64883 .65592 Mdot
.55228 .49353 Mdot
.63441 .39773 Mdot
.26014 .49243 Mdot
.71848 .36473 Mdot
.71994 .36248 Mdot
.32549 .57263 Mdot
.18985 .47669 Mdot
.49741 .61423 Mdot
.55497 .31442 Mdot
.6575 .60282 Mdot
.46224 .52967 Mdot
.43747 .81605 Mdot
.48066 .79204 Mdot
.41623 .18999 Mdot
.15401 .48968 Mdot
.55933 .22739 Mdot
.54151 .60238 Mdot
.59586 .732 Mdot
.64343 .32959 Mdot
.37836 .30353 Mdot
.53909 .2151 Mdot
.35147 .34003 Mdot
.18749 .59511 Mdot
.45247 .76324 Mdot
.15338 .52834 Mdot
.31945 .55209 Mdot
.49603 .33068 Mdot
.49842 .56809 Mdot
.34796 .2796 Mdot
.55595 .28152 Mdot
.16355 .51239 Mdot
.71123 .43235 Mdot
.35137 .63435 Mdot
.52254 .80659 Mdot
.25593 .51981 Mdot
.64788 .4027 Mdot
.7707 .36645 Mdot
.36735 .4849 Mdot
.16102 .56671 Mdot
.33645 .67629 Mdot
.269 .29907 Mdot
.48904 .69517 Mdot
.74122 .5583 Mdot
.65005 .56403 Mdot
.57827 .68692 Mdot
.17162 .44694 Mdot
.35285 .57968 Mdot
.36881 .20363 Mdot
.31352 .65181 Mdot
.36574 .41119 Mdot
.16124 .57703 Mdot
.50408 .18689 Mdot
.2207 .52418 Mdot
.69745 .29188 Mdot
.63447 .79789 Mdot
.41419 .27238 Mdot
.56392 .65338 Mdot
.6351 .58498 Mdot
.41555 .65767 Mdot
.17092 .45901 Mdot
.53809 .20119 Mdot
.25201 .7174 Mdot
.55052 .3107 Mdot
.75322 .54235 Mdot
.35165 .54004 Mdot
.6409 .50637 Mdot
.64796 .42693 Mdot
.15245 .52337 Mdot
.22761 .46907 Mdot
.65826 .80272 Mdot
.61184 .24943 Mdot
.32541 .50343 Mdot
.40388 .68655 Mdot
.61305 .57859 Mdot
.39586 .26693 Mdot
.44499 .77601 Mdot
.49657 .35082 Mdot
.57394 .30722 Mdot
.36126 .45875 Mdot
.67052 .40986 Mdot
.52622 .4667 Mdot
.45276 .74449 Mdot
.57561 .25516 Mdot
.56602 .80056 Mdot
.37199 .49323 Mdot
.32878 .56325 Mdot
.54204 .21941 Mdot
.58636 .2356 Mdot
.4952 .74152 Mdot
.75769 .43578 Mdot
.2626 .30378 Mdot
.68916 .47293 Mdot
.4183 .43818 Mdot
.24365 .4382 Mdot
.23409 .50606 Mdot
.57623 .2013 Mdot
.49442 .42658 Mdot
.38453 .21082 Mdot
.4893 .64808 Mdot
.31153 .42039 Mdot
.55487 .26285 Mdot
.32045 .41629 Mdot
.20327 .53466 Mdot
.47734 .56097 Mdot
.60523 .67964 Mdot
.36105 .64221 Mdot
.16278 .56692 Mdot
.69612 .59027 Mdot
.53457 .2084 Mdot
.58702 .6852 Mdot
.63065 .68604 Mdot
.56981 .62497 Mdot
.64475 .48651 Mdot
.17759 .41062 Mdot
.5104 .79057 Mdot
.62289 .60621 Mdot
.31427 .72087 Mdot
.44037 .51489 Mdot
.30647 .36629 Mdot
.48601 .30973 Mdot
.35298 .3531 Mdot
.70109 .37742 Mdot
.32518 .46373 Mdot
.44551 .56668 Mdot
.78732 .36913 Mdot
.45399 .43683 Mdot
.55425 .5187 Mdot
.45919 .60648 Mdot
.57642 .41926 Mdot
.24133 .3028 Mdot
.48962 .3109 Mdot
.50103 .19026 Mdot
.5085 .79647 Mdot
.5861 .40732 Mdot
.6455 .41946 Mdot
.39305 .50126 Mdot
.15242 .53377 Mdot
.19715 .35198 Mdot
.43782 .79663 Mdot
.40414 .67644 Mdot
.68124 .19333 Mdot
.60885 .67484 Mdot
.41427 .20527 Mdot
.58803 .69158 Mdot
.89881 .58043 Mdot
.70718 .54616 Mdot
.67581 .24937 Mdot
.34305 .29795 Mdot
.59266 .51457 Mdot
.1835 .47399 Mdot
.24364 .51853 Mdot
.76001 .40616 Mdot
.33345 .55716 Mdot
.47478 .43861 Mdot
.17038 .51025 Mdot
.16685 .56628 Mdot
.17088 .51591 Mdot
.54998 .76987 Mdot
.20224 .56001 Mdot
.19131 .62543 Mdot
.66683 .31015 Mdot
.51606 .61291 Mdot
.38279 .35869 Mdot
.47947 .22137 Mdot
.47289 .19751 Mdot
.70167 .43524 Mdot
.41876 .27163 Mdot
.33663 .54465 Mdot
.17952 .61253 Mdot
.24322 .29818 Mdot
.25465 .38322 Mdot
.1905 .39925 Mdot
.63781 .62827 Mdot
.50223 .22189 Mdot
.18635 .387 Mdot
.33272 .71263 Mdot
.48259 .66111 Mdot
.19786 .64504 Mdot
.58931 .24396 Mdot
.61616 .64829 Mdot
.40435 .77759 Mdot
.4492 .19765 Mdot
.3931 .68523 Mdot
.6131 .62954 Mdot
.3699 .30437 Mdot
.32784 .53405 Mdot
.64768 .48653 Mdot
.32965 .72647 Mdot
.54578 .5952 Mdot
.54083 .25017 Mdot
.66145 .55048 Mdot
.52321 .20836 Mdot
.6358 .43119 Mdot
.51815 .61491 Mdot
.60451 .31571 Mdot
.54709 .19393 Mdot
.41309 .75735 Mdot
.18665 .53819 Mdot
.51051 .79564 Mdot
.62552 .80967 Mdot
.44616 .69647 Mdot
.36375 .45333 Mdot
.50158 .37769 Mdot
.17926 .47211 Mdot
.18062 .34823 Mdot
.17866 .39938 Mdot
.51937 .77459 Mdot
.67039 .62487 Mdot
.52553 .67832 Mdot
.63415 .32964 Mdot
.60466 .5042 Mdot
.46156 .63487 Mdot
.60838 .43391 Mdot
.57347 .67179 Mdot
.45134 .82341 Mdot
.36522 .65328 Mdot
.65461 .32088 Mdot
.27902 .3415 Mdot
.40164 .29249 Mdot
.19765 .49109 Mdot
.31321 .57209 Mdot
.52912 .77979 Mdot
.53716 .21358 Mdot
.70093 .58841 Mdot
.63667 .68918 Mdot
.36855 .63842 Mdot
.50361 .34011 Mdot
.65092 .63073 Mdot
.43658 .62208 Mdot
.32747 .37538 Mdot
.65643 .61908 Mdot
.26079 .27508 Mdot
.40248 .2028 Mdot
.18728 .38348 Mdot
.55572 .21938 Mdot
.64083 .67021 Mdot
.55977 .43687 Mdot
.60357 .69668 Mdot
.45796 .66384 Mdot
.55009 .47842 Mdot
.55808 .2134 Mdot
.21593 .52517 Mdot
.49222 .58729 Mdot
.42706 .4427 Mdot
.28467 .27036 Mdot
.63879 .30691 Mdot
.56455 .44109 Mdot
.37343 .51563 Mdot
.35604 .62763 Mdot
.72946 .2736 Mdot
.35196 .74709 Mdot
.39364 .44088 Mdot
.40952 .68019 Mdot
.54276 .7393 Mdot
.31979 .57352 Mdot
.54541 .19118 Mdot
.76829 .44573 Mdot
.29455 .64131 Mdot
.51279 .56728 Mdot
.17933 .44666 Mdot
.52918 .5476 Mdot
.38935 .67708 Mdot
.26504 .65071 Mdot
.68459 .77797 Mdot
.31757 .55419 Mdot
.53182 .60428 Mdot
.58103 .61326 Mdot
.31965 .54564 Mdot
.36437 .55022 Mdot
.2264 .47887 Mdot
.16157 .46086 Mdot
.56404 .55474 Mdot
.31792 .70909 Mdot
.58481 .40055 Mdot
.63893 .50292 Mdot
.50633 .59021 Mdot
.60123 .30624 Mdot
.30906 .68361 Mdot
.23005 .361 Mdot
.53071 .84505 Mdot
.43615 .26966 Mdot
.66676 .24105 Mdot
.63542 .33073 Mdot
.34973 .41006 Mdot
.25925 .48701 Mdot
.47921 .68136 Mdot
.45914 .39193 Mdot
.15171 .47133 Mdot
.45746 .75695 Mdot
.60753 .35702 Mdot
.62292 .55647 Mdot
.41149 .39721 Mdot
.44461 .30796 Mdot
.18355 .39528 Mdot
.38643 .54163 Mdot
.42977 .85591 Mdot
.6129 .24209 Mdot
.36553 .42935 Mdot
.22322 .5348 Mdot
.49624 .19251 Mdot
.47328 .55537 Mdot
.32137 .65753 Mdot
.64039 .44013 Mdot
.47305 .19323 Mdot
.28986 .69242 Mdot
.33794 .74611 Mdot
.44167 .6893 Mdot
.19104 .61841 Mdot
.38555 .45949 Mdot
.49317 .68252 Mdot
.64314 .63303 Mdot
.44613 .32865 Mdot
.49509 .78374 Mdot
.43642 .67732 Mdot
.69604 .49272 Mdot
.37856 .29976 Mdot
.17612 .35292 Mdot
.3809 .38861 Mdot
.49548 .77078 Mdot
.40868 .84267 Mdot
.48706 .87412 Mdot
.35286 .76099 Mdot
.15148 .51909 Mdot
.32479 .73512 Mdot
.38377 .68085 Mdot
.53163 .73521 Mdot
.5399 .52342 Mdot
.31763 .34799 Mdot
.15871 .44225 Mdot
.78863 .46605 Mdot
.54813 .64778 Mdot
.3076 .30828 Mdot
.15672 .44349 Mdot
.39352 .4169 Mdot
.70409 .25631 Mdot
.73993 .56978 Mdot
.53927 .16504 Mdot
.42916 .18803 Mdot
.35471 .51788 Mdot
.56697 .19314 Mdot
.67592 .23371 Mdot
.72385 .3151 Mdot
.41027 .20334 Mdot
.39033 .25763 Mdot
.38216 .52423 Mdot
.54686 .22516 Mdot
.42287 .66077 Mdot
.61722 .16926 Mdot
.50712 .58629 Mdot
.49472 .62729 Mdot
.42344 .57143 Mdot
.41428 .65687 Mdot
.41342 .7428 Mdot
.52464 .58645 Mdot
.48767 .49245 Mdot
.20383 .52228 Mdot
.68582 .80158 Mdot
.30535 .73489 Mdot
.38014 .6436 Mdot
.17071 .56335 Mdot
.48462 .69163 Mdot
.56028 .47398 Mdot
.26544 .50339 Mdot
.63489 .31627 Mdot
.63158 .61419 Mdot
.43056 .38618 Mdot
.16094 .4654 Mdot
.63166 .61333 Mdot
.17243 .54295 Mdot
.34313 .21008 Mdot
.19937 .39321 Mdot
.46684 .29377 Mdot
.63401 .57828 Mdot
.49359 .20443 Mdot
.49535 .20703 Mdot
.19735 .59715 Mdot
.65007 .22786 Mdot
.53991 .48774 Mdot
.53531 .56863 Mdot
.50782 .55145 Mdot
.40539 .45462 Mdot
.48911 .19062 Mdot
.4031 .50374 Mdot
.56443 .27086 Mdot
.41594 .79086 Mdot
.55151 .20302 Mdot
.22818 .52268 Mdot
.62392 .32429 Mdot
.67871 .47127 Mdot
.7598 .39737 Mdot
.70396 .60207 Mdot
.22931 .68781 Mdot
.46918 .70336 Mdot
.37547 .21477 Mdot
.62966 .80523 Mdot
.44925 .77584 Mdot
.62941 .22761 Mdot
.48709 .58714 Mdot
.42497 .26289 Mdot
.79592 .49298 Mdot
.58449 .2658 Mdot
.22084 .48836 Mdot
.43102 .66153 Mdot
.32791 .51831 Mdot
.16986 .42548 Mdot
.54468 .25522 Mdot
.29031 .76877 Mdot
.73762 .61348 Mdot
.32541 .45784 Mdot
.19889 .46157 Mdot
.60228 .81968 Mdot
.56954 .43588 Mdot
.16361 .56955 Mdot
.40325 .58235 Mdot
.15453 .49383 Mdot
.57384 .70058 Mdot
.73897 .51105 Mdot
.47739 .64705 Mdot
.61219 .3693 Mdot
.60971 .37743 Mdot
.30776 .24398 Mdot
.51729 .80086 Mdot
.48189 .79468 Mdot
.69012 .47363 Mdot
.6501 .58261 Mdot
.51288 .51713 Mdot
.32327 .7059 Mdot
.23664 .6947 Mdot
.48836 .4026 Mdot
.75946 .58961 Mdot
.5207 .19531 Mdot
.60427 .69874 Mdot
.48503 .62927 Mdot
.46003 .64872 Mdot
.26457 .60692 Mdot
.49818 .22361 Mdot
.18533 .61145 Mdot
.46357 .62803 Mdot
.61169 .48659 Mdot
.33705 .48848 Mdot
.50185 .6354 Mdot
.58154 .79386 Mdot
.32507 .67991 Mdot
.52111 .55693 Mdot
.52924 .47288 Mdot
.56289 .22772 Mdot
.22243 .29327 Mdot
.17847 .58185 Mdot
.60261 .79678 Mdot
.58869 .40971 Mdot
.41419 .59748 Mdot
.5995 .28629 Mdot
.28358 .76364 Mdot
.54465 .16108 Mdot
.41499 .77747 Mdot
.54692 .20308 Mdot
.65584 .50975 Mdot
.68608 .24871 Mdot
.55841 .4601 Mdot
.19928 .45878 Mdot
.33552 .29419 Mdot
.43163 .57561 Mdot
.61054 .58658 Mdot
.59092 .38521 Mdot
.52515 .62804 Mdot
.38283 .52232 Mdot
.51998 .80015 Mdot
.29161 .76978 Mdot
.64072 .21787 Mdot
.34906 .49077 Mdot
.3109 .77715 Mdot
.31111 .61227 Mdot
.58513 .61548 Mdot
.60611 .77374 Mdot
.59166 .40223 Mdot
.71337 .55739 Mdot
.37189 .32244 Mdot
.52074 .49652 Mdot
.30629 .72045 Mdot
.66808 .51675 Mdot
.69118 .41343 Mdot
.36756 .55486 Mdot
.66384 .22903 Mdot
.30823 .59224 Mdot
.24363 .27719 Mdot
.3354 .71105 Mdot
.20939 .51202 Mdot
.27689 .69387 Mdot
.67108 .65051 Mdot
.62983 .81157 Mdot
.18632 .41128 Mdot
.52318 .25239 Mdot
.35541 .55193 Mdot
.3087 .57332 Mdot
.28854 .68572 Mdot
.57265 .76311 Mdot
.18385 .44428 Mdot
.50978 .18813 Mdot
.6452 .67142 Mdot
.34747 .62101 Mdot
.54206 .57367 Mdot
.37823 .64196 Mdot
.24977 .28534 Mdot
.7072 .5507 Mdot
.155 .55496 Mdot
.39551 .49507 Mdot
.54254 .82483 Mdot
.44106 .6368 Mdot
.502 .47463 Mdot
.5735 .43883 Mdot
.63088 .66335 Mdot
.41525 .43903 Mdot
.36727 .43144 Mdot
.34371 .5686 Mdot
.56277 .62571 Mdot
.73449 .40347 Mdot
.78152 .39269 Mdot
.59686 .68953 Mdot
.34453 .41299 Mdot
.47548 .18566 Mdot
.31122 .57439 Mdot
.72515 .62021 Mdot
.72813 .63103 Mdot
.4179 .43053 Mdot
.44546 .22524 Mdot
.21622 .66286 Mdot
.18707 .41807 Mdot
.39696 .57612 Mdot
.59937 .80802 Mdot
.67709 .36412 Mdot
.26903 .27006 Mdot
.27337 .60536 Mdot
.50994 .19838 Mdot
.35296 .45474 Mdot
.20074 .35699 Mdot
.23147 .53356 Mdot
.37318 .66145 Mdot
.54478 .21678 Mdot
.63616 .49275 Mdot
.54236 .19575 Mdot
.26291 .60527 Mdot
.51331 .54119 Mdot
.53973 .16782 Mdot
.6517 .51519 Mdot
.24877 .41503 Mdot
.36881 .39072 Mdot
.43851 .63589 Mdot
.48607 .19678 Mdot
.37951 .55952 Mdot
.69693 .36564 Mdot
.29243 .33093 Mdot
.47963 .65572 Mdot
.17225 .45441 Mdot
.49519 .74384 Mdot
.52389 .1915 Mdot
.50322 .54763 Mdot
.63789 .28558 Mdot
.39868 .49489 Mdot
.54566 .2913 Mdot
.43308 .31573 Mdot
.36198 .46587 Mdot
.61778 .43903 Mdot
.31368 .24819 Mdot
.38431 .44575 Mdot
.17272 .49072 Mdot
.25711 .28957 Mdot
.26995 .64102 Mdot
.56454 .60118 Mdot
.36718 .61976 Mdot
.15826 .54767 Mdot
.45775 .21665 Mdot
.43433 .65101 Mdot
.43492 .18731 Mdot
.72737 .26978 Mdot
.32698 .79272 Mdot
.47232 .73808 Mdot
.43864 .62057 Mdot
.37447 .20511 Mdot
.45803 .7622 Mdot
.69071 .24251 Mdot
.22161 .48351 Mdot
.3974 .55305 Mdot
.16251 .58287 Mdot
.35933 .26833 Mdot
.4717 .79224 Mdot
.20204 .47688 Mdot
.27956 .6278 Mdot
.44589 .21776 Mdot
.41897 .44394 Mdot
.66545 .60184 Mdot
.58168 .52619 Mdot
.57348 .19552 Mdot
.28605 .62497 Mdot
.50387 .19372 Mdot
.51099 .20123 Mdot
.64279 .23869 Mdot
.63747 .66444 Mdot
.32806 .79315 Mdot
.22778 .5576 Mdot
.47988 .32238 Mdot
.39319 .56582 Mdot
.68701 .40084 Mdot
.61654 .25449 Mdot
.45317 .41477 Mdot
.56991 .37093 Mdot
.36375 .47717 Mdot
.15427 .45894 Mdot
.66754 .48616 Mdot
.49813 .6877 Mdot
.36411 .62206 Mdot
.42145 .65502 Mdot
.4516 .54625 Mdot
.51864 .80896 Mdot
.4931 .19961 Mdot
.29336 .64187 Mdot
.34032 .67109 Mdot
.46313 .78784 Mdot
.56107 .24206 Mdot
.67466 .35431 Mdot
.52732 .68955 Mdot
.3243 .36188 Mdot
.21587 .62038 Mdot
.47194 .77824 Mdot
.35583 .63316 Mdot
.3893 .75874 Mdot
.51779 .54128 Mdot
.50912 .74414 Mdot
.51424 .79961 Mdot
.46675 .57022 Mdot
.21537 .38831 Mdot
.28586 .66398 Mdot
.63422 .5994 Mdot
.59639 .23794 Mdot
.3575 .74245 Mdot
.49798 .19571 Mdot
.4074 .42521 Mdot
.17928 .49169 Mdot
.60751 .3617 Mdot
.66927 .38487 Mdot
.47967 .38328 Mdot
.35385 .30656 Mdot
.18302 .39517 Mdot
.3926 .77415 Mdot
.38095 .28567 Mdot
.37782 .62867 Mdot
.40391 .19983 Mdot
.64531 .62033 Mdot
.65669 .62097 Mdot
.69477 .27833 Mdot
.48457 .47864 Mdot
.60165 .50342 Mdot
.61007 .72687 Mdot
.40601 .43157 Mdot
.68904 .34629 Mdot
.51844 .5658 Mdot
.32311 .36855 Mdot
.41222 .20896 Mdot
.2251 .67688 Mdot
.50004 .5609 Mdot
.41827 .18768 Mdot
.33014 .3073 Mdot
.38195 .54559 Mdot
.65036 .22067 Mdot
.41394 .27529 Mdot
.48988 .43126 Mdot
.69606 .36622 Mdot
.33119 .62676 Mdot
.22101 .66179 Mdot
.35871 .33781 Mdot
.66782 .42614 Mdot
.67473 .45711 Mdot
.50863 .57412 Mdot
.77192 .62668 Mdot
.49007 .64844 Mdot
.37684 .20288 Mdot
.538 .21369 Mdot
.54729 .65749 Mdot
.31109 .7204 Mdot
.3979 .27712 Mdot
.17686 .49382 Mdot
.62542 .45551 Mdot
.17974 .42699 Mdot
.54052 .76726 Mdot
.33133 .39985 Mdot
.2716 .28056 Mdot
.56809 .29664 Mdot
.54948 .29742 Mdot
.37716 .5076 Mdot
.48577 .26311 Mdot
.45033 .59153 Mdot
.75329 .44985 Mdot
.60325 .17048 Mdot
.26 .73178 Mdot
.53213 .82112 Mdot
.37424 .38494 Mdot
.59454 .28152 Mdot
.28764 .67144 Mdot
.55602 .48255 Mdot
.65432 .44112 Mdot
.66924 .6353 Mdot
.61483 .59769 Mdot
.66965 .80339 Mdot
.15344 .46797 Mdot
.47713 .38578 Mdot
.61931 .403 Mdot
.77577 .36704 Mdot
.69705 .53503 Mdot
.26988 .34497 Mdot
.21435 .65522 Mdot
.5344 .6816 Mdot
.63324 .76618 Mdot
.61247 .70035 Mdot
.31165 .24302 Mdot
.62062 .75721 Mdot
.54433 .75431 Mdot
.24259 .27742 Mdot
.43576 .79313 Mdot
.29858 .54315 Mdot
.6764 .79902 Mdot
.29582 .26096 Mdot
.35757 .45423 Mdot
.64405 .62244 Mdot
.16322 .48331 Mdot
.57092 .44095 Mdot
.62596 .61963 Mdot
.3705 .25163 Mdot
.54462 .21294 Mdot
.60702 .24123 Mdot
.50876 .67566 Mdot
.32124 .30261 Mdot
.7868 .32187 Mdot
.67648 .65065 Mdot
.57845 .84755 Mdot
.19153 .41212 Mdot
.22811 .61558 Mdot
.34904 .75552 Mdot
.7051 .48742 Mdot
.18136 .48356 Mdot
.51107 .20691 Mdot
.35514 .29119 Mdot
.77384 .46176 Mdot
.5824 .30836 Mdot
.62136 .30392 Mdot
.51066 .74418 Mdot
.19592 .37966 Mdot
.6423 .65996 Mdot
.42366 .25365 Mdot
.53258 .20264 Mdot
.3363 .30866 Mdot
.54394 .29273 Mdot
.21294 .60952 Mdot
.44044 .22289 Mdot
.56665 .21778 Mdot
.61818 .6395 Mdot
.72662 .36358 Mdot
.21949 .6495 Mdot
.43357 .5252 Mdot
.35466 .46288 Mdot
.41345 .84559 Mdot
.15402 .52588 Mdot
.41595 .27396 Mdot
.3882 .37202 Mdot
.28713 .24351 Mdot
.73996 .60344 Mdot
.40683 .21168 Mdot
.42461 .80875 Mdot
.61605 .23835 Mdot
.39438 .46434 Mdot
.42733 .39448 Mdot
.67158 .29493 Mdot
.35362 .53416 Mdot
.33725 .29781 Mdot
.62794 .72674 Mdot
.56068 .21651 Mdot
.34794 .41774 Mdot
.52969 .84491 Mdot
.26551 .59839 Mdot
.32779 .6112 Mdot
.15994 .47535 Mdot
.28159 .30774 Mdot
.36311 .4382 Mdot
.19344 .46698 Mdot
.61992 .46703 Mdot
.69031 .34672 Mdot
.39485 .48875 Mdot
.56211 .43492 Mdot
.57437 .19333 Mdot
.31025 .77853 Mdot
.31544 .35953 Mdot
.15676 .56366 Mdot
.19177 .36132 Mdot
.33284 .61544 Mdot
.35011 .2841 Mdot
.59528 .40955 Mdot
.28712 .6516 Mdot
.61942 .66295 Mdot
.63413 .68225 Mdot
.76777 .31565 Mdot
.78298 .38412 Mdot
.41225 .37802 Mdot
.54675 .77117 Mdot
.17143 .42571 Mdot
.75816 .30376 Mdot
.16843 .43751 Mdot
.36723 .46603 Mdot
.50023 .37158 Mdot
.49314 .87606 Mdot
.38412 .67892 Mdot
.49427 .41317 Mdot
.4295 .45877 Mdot
.41194 .45288 Mdot
.44759 .39268 Mdot
.57253 .76681 Mdot
.63976 .32266 Mdot
.60559 .22879 Mdot
.16725 .47758 Mdot
.34152 .62333 Mdot
.57663 .43274 Mdot
.58496 .69585 Mdot
.58791 .36782 Mdot
.53327 .31721 Mdot
.56034 .73659 Mdot
.60559 .22 Mdot
.76381 .63125 Mdot
.6424 .40083 Mdot
.4399 .62864 Mdot
.47698 .48723 Mdot
.32939 .65335 Mdot
.62491 .21744 Mdot
.60088 .74744 Mdot
.72485 .31679 Mdot
.52803 .19401 Mdot
.35297 .50503 Mdot
.49241 .69857 Mdot
.68677 .2021 Mdot
.56434 .44496 Mdot
.55796 .7714 Mdot
.44739 .27339 Mdot
.28399 .56499 Mdot
.19944 .41541 Mdot
.70911 .34889 Mdot
.44972 .60264 Mdot
.34351 .48465 Mdot
.18284 .47331 Mdot
.54266 .73306 Mdot
.20539 .31275 Mdot
.46817 .28049 Mdot
.26653 .35546 Mdot
.21927 .57774 Mdot
.53515 .60831 Mdot
.22323 .49279 Mdot
.43821 .31381 Mdot
.59901 .48491 Mdot
.76311 .62631 Mdot
.41286 .63086 Mdot
.5066 .59306 Mdot
.29649 .66271 Mdot
.65991 .23894 Mdot
.23396 .36578 Mdot
.44465 .38135 Mdot
.71061 .42794 Mdot
.56956 .41984 Mdot
.70907 .48219 Mdot
.75294 .5427 Mdot
.48446 .65906 Mdot
.62241 .21896 Mdot
.61286 .24279 Mdot
.20742 .47717 Mdot
.1654 .52682 Mdot
.36842 .39286 Mdot
.19652 .40417 Mdot
.65873 .47125 Mdot
.42231 .74333 Mdot
.44865 .22488 Mdot
.305 .77264 Mdot
.37919 .4541 Mdot
.38776 .42853 Mdot
.2082 .32702 Mdot
.18662 .40247 Mdot
.51459 .64568 Mdot
.42 .66702 Mdot
.58202 .16828 Mdot
.61087 .37874 Mdot
.67809 .80256 Mdot
.62319 .67151 Mdot
.22975 .29869 Mdot
.50781 .60931 Mdot
.44315 .27699 Mdot
.38972 .50274 Mdot
.47267 .43724 Mdot
.69031 .57842 Mdot
.2639 .64061 Mdot
.37477 .50945 Mdot
.50712 .27663 Mdot
.46637 .31461 Mdot
.5989 .60728 Mdot
.41734 .59222 Mdot
.26513 .73857 Mdot
.68489 .52929 Mdot
.61274 .48297 Mdot
.49391 .83903 Mdot
.76383 .62727 Mdot
.71443 .25726 Mdot
.19234 .59006 Mdot
.45824 .66172 Mdot
.51955 .56335 Mdot
.76952 .68325 Mdot
.40707 .58325 Mdot
.38406 .55523 Mdot
.59961 .68826 Mdot
.64519 .29042 Mdot
.49598 .77567 Mdot
.36115 .81607 Mdot
.20233 .35206 Mdot
.41028 .42667 Mdot
.67708 .82471 Mdot
.5281 .19892 Mdot
.60397 .44913 Mdot
.50167 .77851 Mdot
.16317 .46052 Mdot
.6219 .55631 Mdot
.33667 .21561 Mdot
.33881 .73 Mdot
.2781 .61474 Mdot
.63924 .30153 Mdot
.60236 .80465 Mdot
.5407 .57925 Mdot
.58115 .84633 Mdot
.41689 .685 Mdot
.616 .30765 Mdot
.38481 .77062 Mdot
.33164 .55015 Mdot
.36866 .43137 Mdot
.34059 .70704 Mdot
.39233 .29173 Mdot
.29897 .62462 Mdot
.33606 .67512 Mdot
.6586 .36602 Mdot
.58539 .64027 Mdot
.38526 .67461 Mdot
.60042 .71763 Mdot
.35221 .51523 Mdot
.57457 .17662 Mdot
.75662 .58721 Mdot
.66662 .54582 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Tooooo`;o0000Xoooool001co
oooo00?o0000ooooooooool0Y?ooool2o`000:?ooooo000Looooo`03o`000?oooooooooo0:Sooooo
0_l0002Oooooo`007?ooool2o`000:Oooooo1?l0002Oooooo`007?ooool00ol0003oooooooooo`2V
ooooo`;o00000oooool2o`0009cooooo000Looooo`03o`000?oooooooooo0:_ooooo0_l0002Loooo
o`007?ooool00ol0003oooooooooo`2Zooooo`Go0000V_ooool001cooooo00?o0000ooooooooool0
Z_ooool7o`0009Sooooo000Looooo`03o`000?oooooooooo0:_ooooo0ol000000ooooooo0000o`00
0002o`000003ooooool0003o000000;o000000?oooooo`000?l000000_l000000ooooooo0000o`00
0029ooooo`007?ooool00ol0003oooooooooo`2/ooooo`;o00000oooool2o`000003ooooool0003o
000000;o000000?oooooo`000?l000000_l000000ooooooo0000o`000002o`0000?ooooo0_l00022
ooooo`007?ooool00ol0003oooooooooo`2^ooooo`;o00001Oooool2o`0000Wooooo0_l00003oooo
o`;o0000P_ooool001cooooo00?o0000ooooooooool0[_ooool3o`0000;ooooo0_l00002ooooo`;o
00005_ooool2o`0007Sooooo000Looooo`03o`000?oooooooooo09Gooooo0_l0000Hooooo`;o0000
0_ooool2o`0000;ooooo0_l0000Fooooo`;o0000N?ooool001cooooo00?o0000ooooooooool0UOoo
ool2o`0000gooooo0_l0000[ooooo`;o0000M_ooool001cooooo00?o0000ooooooooool0Q?ooool2
o`0000?ooooo0ol0000;ooooo`;o00001oooool2o`0000;ooooo0_l0000;ooooo`;o00007_ooool2
o`0007Kooooo000Looooo`03o`000?oooooooooo08?ooooo0ol00002ooooo`Co00002oooool2o`00
00;ooooo0_l00002ooooo`Go00001?ooool7o`0000;ooooo0_l0002Fooooo`0000Koooooonk^k_lb
<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0Poooool2
o`0000?ooooo0_l0000<ooooo`;o00000oooool9o`0000;ooooo2Ol00003ooooo`Co000000?ooooo
o`000?l000008?ooool2o`0006kooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ
8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`2Fooooo`;o0000
0_ooool2o`000003ooooool0003o000000?o00000oooool5o`0000;ooooo1?l00002ooooo`Co0000
00?oooooo`000?l000008?ooool2o`0006kooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oo
oooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`1oooooo`;o00003Ooo
ool2o`0000Kooooo0_l00002ooooo`Ko00000_ooool2o`000004ooooool0003o0000ooooo`;o0000
0_ooool4o`000003ooooool0003o000000;o00000_ooool2o`00093ooooo00000ooooooo0000oooo
o`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0007Oooooo0_l0
0006ooooo`;o00003Oooool2o`0000Kooooo0_l00004ooooo`;o00001?ooool2o`0000Cooooo1Ol0
00000ooooooo0000o`000004o`0000?ooooo0_l0000Rooooo`;o0000K?ooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooo
oooo07Cooooo1Ol00006ooooo`;o000000Coooooo`000?l0003o00005?ooool2o`0000;ooooo0_l0
0003ooooo`;o00001Oooool4o`000003ooooool0003o000000Ko000000?oooooo`000?l000008_oo
ool2o`0006cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`1dooooo`Co00001oooool6o`0001Cooooo0_l00002
ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`;o00001Oooool5o`0000Gooooo0_l0002<
ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
1_ooool00ol0003oooooooooo`1/ooooo`;o00002oooool2o`0000Cooooo1Ol0000Iooooo`;o0000
0oooool2o`0000;ooooo0_l00002ooooo`;o00001Oooool3o`0000Oooooo0_l0000Qooooo`;o0000
JOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<
00Kooooo00?o0000ooooooooool0K?ooool2o`0000Sooooo0_l000000ooooooo0000o`000005oooo
o`;o00004_ooool2o`000003ooooool0003o000001;ooooo1?l00003ooooo`;o0000:_ooool2o`00
06Wooooo000Looooo`03o`000?oooooooooo06Wooooo0ol0000:ooooo`;o00000oooool4o`0000ko
oooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Booooo`Co00000oooool4o`00
017ooooo0_l00003ooooo`;o0000Noooool001cooooo00?o0000ooooooooool0JOooool3o`0000Oo
oooo0_l000000ooooooo0000o`000003ooooo`Co00003_ooool2o`0000;ooooo0_l00005ooooo`?o
00001_ooool2o`0000Wooooo0ol00002ooooo`Go00002oooool2o`0000?ooooo0ol00003ooooo`;o
000000?oooooo`000?l00000N?ooool001cooooo00?o0000ooooooooool0L_ooool3o`0000Kooooo
0_l0000>ooooo`;o000000Coooooo`000?l0003ooooo0_l00005ooooo`?o00000oooool5o`0000;o
oooo0_l00005ooooo`;o00000oooool2o`0000kooooo0_l00003ooooo`;o00001oooool2o`0007So
oooo000Looooo`03o`000?oooooooooo063ooooo1?l0000;ooooo`;o000000?oooooo`000?l00000
1oooool2o`0000?ooooo0_l00008ooooo`Ko000000?oooooo`000?l000002_ooool4o`0000Cooooo
0_l00007ooooo`;o00000_ooool3o`0001Cooooo0_l0001nooooo`007?ooool00ol0003ooooooooo
o`1Nooooo`Ko00002Oooool4o`0000oooooo0_l00008ooooo`;o000000Goooooo`000?l0003o0000
ooooo`03o`0000Wooooo0_l0000?ooooo`;o00000_ooool3o`0000_ooooo0ol00006ooooo`;o0000
1?ooool2o`0000?ooooo0_l0001cooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o00001Ooo
ool2o`0000Gooooo0ol0000Rooooo`?o00000_ooool2o`000003ooooool0003o000000;ooooo1?l0
000Oooooo`?o00001oooool2o`0000?ooooo0_l00003ooooo`;o00000_ooool2o`0006oooooo000L
ooooo`03o`000?oooooooooo06Gooooo0_l00005ooooo`;o0000:?ooool2o`000003ooooool0003o
000000Cooooo0_l00002ooooo`;o00005_ooool2o`0000Cooooo0_l00007ooooo`;o00002_ooool4
o`0006oooooo000Looooo`03o`000?oooooooooo0:7ooooo1?l0000Fooooo`;o000000Coooooo`00
0?l0003ooooo0_l000000ooooooo0000o`000007ooooo`;o00001?ooool2o`000003ooooool0003o
0000077ooooo000Looooo`03o`000?oooooooooo06;ooooo0_l0000mooooo`Ko00002oooool2o`00
00[ooooo0_l000000ooooooo0000o`000003o`0000;ooooo0_l00003ooooo`;o00001?ooool4o`00
00Kooooo0_l0001Zooooo`007?ooool00ol0003oooooooooo`1Jooooo`;o00001?ooool4o`0003oo
oooo1?l0000;ooooo`;o00002?ooool2o`0000?ooooo1?l00003ooooo`;o00002oooool2o`0000Ko
oooo0_l0001Zooooo`007?ooool00ol0003oooooooooo`1Hooooo`Co00001?ooool5o`0003kooooo
0ol00008ooooo`;o00003?ooool2o`0001gooooo0_l0001/ooooo`007?ooool2o`0005Wooooo0_l0
0008ooooo`?o00004?ooool2o`0001[ooooo0_l0000Aooooo`Co00001?ooool4o`0000kooooo0ol0
0002ooooo`;o00004?ooool5o`000003ooooool0003o000006cooooo000Looooo`03o`000?oooooo
oooo07Cooooo0ol0000?ooooo`;o00002Oooool2o`0001;ooooo0ol00004ooooo`?o00002?ooool2
o`0000Gooooo1?l000001?oooooo0000o`000?l0000?ooooo`Go0000Koooool001cooooo00?o0000
ooooooooool0Goooool2o`0001?ooooo0_l00005ooooo`;o00002Oooool2o`0000?ooooo0_l00000
0ooooooo0000o`00000Eooooo`?o00001Oooool2o`0000Sooooo0_l00007ooooo`;o000000Cooooo
o`000?l0003o00003oooool2o`0000[ooooo0_l000000ooooooo0000o`00001Sooooo`007?ooool0
0ol0003oooooooooo`1Looooo`;o000000?oooooo`000?l000003Oooool2o`0000_ooooo0_l0000>
ooooo`;o000000Coooooo`000?l0003o00005?ooool4o`0000;ooooo0_l0000<ooooo`;o00002?oo
ool5o`0001Wooooo0_l000000ooooooo0000o`00001Sooooo`007?ooool00ol0003oooooooooo`1L
ooooo`;o00004?ooool2o`0000[ooooo0_l0000:ooooo`;o00001?ooool2o`000003ooooool0003o
000000Wooooo0_l0000;ooooo`?o000000?oooooo`000?l000000_l000000ooooooo0000o`000007
ooooo`;o00002Oooool4o`00087ooooo000Looooo`03o`000?oooooooooo05_ooooo0_l0000Goooo
o`;o00001?ooool2o`000003ooooool0003o000000Oooooo0_l00004ooooo`;o00003?ooool2o`00
00cooooo0ol00002ooooo`Go00002?ooool2o`0008gooooo000Looooo`03o`000?oooooooooo05Co
oooo0_l00003ooooo`Co00003_ooool4o`0000;ooooo0_l000000ooooooo0000o`000007ooooo`;o
00002oooool2o`0000gooooo0_l0000>ooooo`;o00000oooool2o`0000Cooooo0_l00004ooooo`;o
00009?ooool3o`0000Gooooo0_l0001Oooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o0000
0_ooool3o`00013ooooo1?l00002ooooo`;o00004?ooool3o`0000Cooooo0_l00002ooooo`;o0000
2Oooool2o`0000oooooo0_l00005ooooo`;o000000?oooooo`000?l000002?ooool2o`00023ooooo
0ol00002ooooo`;o000000Coooooo`000?l0003o0000G_ooool001cooooo00?o0000ooooooooool0
C?ooool2o`0000;ooooo0ol00003ooooo`Go00004Oooool2o`0000Oooooo0_l0000<ooooo`?o0000
1_ooool4o`00017ooooo0_l00007ooooo`Co00000oooool3o`0000[ooooo0_l0000Fooooo`;o0000
1oooool2o`0000Cooooo0_l00002ooooo`;o0000G_ooool001cooooo00?o0000ooooooooool0Booo
ool3o`0000;ooooo0ol000000ooooooo0000o`000002o`0000cooooo1?l00005ooooo`;o00001_oo
ool2o`0000Oooooo0ol00002ooooo`So000000?oooooo`000?l000004Oooool4o`0000Oooooo1?l0
0004ooooo`;o00002_ooool2o`0001Kooooo0_l00006ooooo`?o00001oooool2o`0005oooooo000L
ooooo`03o`000?oooooooooo04_ooooo0_l00007ooooo`?o00003Oooool4o`0000Gooooo0_l00003
ooooo`;o00002_ooool3o`0000Cooooo1_l00003ooooo`;o00001?ooool2o`0000Wooooo0_l00009
ooooo`Go00000_ooool2o`0000[ooooo0ol00004ooooo`;o00003oooool2o`0000Oooooo0_l00008
ooooo`;o0000Goooool001cooooo00?o0000ooooooooool0COooool2o`0000Kooooo0_l0000Goooo
o`;o00000_ooool2o`0000Cooooo0_l0000Dooooo`;o00001?ooool2o`0001Gooooo1?l00002oooo
o`;o000000?oooooo`000?l000001Oooool7o`0000;ooooo0_l00005ooooo`;o00002?ooool3o`00
00cooooo0_l0001Sooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00007_ooool3o`0000So
oooo0_l0000Zooooo`;o00001_ooool4o`0000Cooooo0ol00002ooooo`Co00000_ooool3o`0000Wo
oooo0_l00008ooooo`?o00002_ooool4o`0006?ooooo000Looooo`03o`000?oooooooooo053ooooo
0_l0000Cooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000:ooooo`;o0000
1Oooool4o`0000Cooooo1?l0000Eooooo`;o00001oooool5o`0000?ooooo1ol000000ooooooo0000
o`00000?ooooo`;o00003oooool2o`000004ooooool0003o0000o`0000Sooooo0_l0001Jooooo`00
7?ooool00ol0003oooooooooo`15ooooo`;o00002Oooool2o`0001?ooooo1_l00005ooooo`;o0000
2_ooool2o`000003ooooool0003o000000;ooooo1?l00004ooooo`Co000000?oooooo`000?l00000
0_ooool2o`0001Oooooo0_l000000ooooooo0000o`000004ooooo`Co00000oooool3o`0000kooooo
0_l00006ooooo`;o00001oooool2o`0000cooooo0_l0001Jooooo`007?ooool00ol0003ooooooooo
o`15ooooo`;o00001?ooool2o`0001Oooooo2_l00007ooooo`;o00002?ooool3o`0000Kooooo0_l0
0006ooooo`;o00000_ooool2o`0000oooooo0_l00006ooooo`Go00000oooool6o`0000;ooooo0ol0
000Fooooo`;o00001oooool2o`0000kooooo0_l0001Hooooo`007?ooool2o`0004Kooooo1?l00002
ooooo`?o00001_ooool2o`0000kooooo0ol00003ooooo`Co00001oooool4o`0000Kooooo0ol00006
ooooo`;o00002_ooool2o`0000oooooo0_l00006ooooo`Go00000oooool2o`0000;ooooo0_l00003
ooooo`Co00000_ooool2o`0000Kooooo0_l0000Booooo`;o00001Oooool2o`0000Kooooo0_l0001H
ooooo`007?ooool00ol0003oooooooooo`17ooooo`;o00000_ooool3o`0000Cooooo1?l00009oooo
o`;o00001?ooool2o`0000gooooo1Ol000001?oooooo0000o`000?l00002ooooo`;o00002_ooool2
o`0000Cooooo0_l00006ooooo`;o00005oooool2o`0000cooooo0_l00002ooooo`Co00001?ooool2
o`0001;ooooo0_l00005ooooo`;o00002Oooool2o`0005Gooooo000Looooo`03o`000?oooooooooo
043ooooo0_l00008ooooo`?o00001Oooool4o`0000;ooooo0_l00005ooooo`;o00001?ooool2o`00
0003ooooool0003o000000Gooooo0_l00003ooooo`;o000000?oooooo`000?l000001?l0000:oooo
o`co00001_ooool2o`0000gooooo0_l00005ooooo`;o000000Coooooo`000?l0003o00000_ooool2
o`0000Oooooo0ol000000ooooooo0000o`000002o`0000Cooooo0_l0000Tooooo`;o0000EOooool0
01cooooo00?o0000ooooooooool0@?ooool2o`0000Sooooo0_l00008ooooo`;o00000_ooool2o`00
00Kooooo0_l00002ooooo`?o000000?oooooo`000?l000000_l00003ooooo`;o00002?ooool2o`00
00Sooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000Go00001oooool3o`00
00_ooooo0_l00005ooooo`;o00000_ooool3o`000003ooooool0003o000000;o00001Oooool3o`00
0004ooooool0003o0000o`0000Gooooo0_l00006ooooo`?o0000L_ooool001cooooo00?o0000oooo
ooooool0?oooool2o`0001Kooooo0ol00006ooooo`;o00000_ooool3o`0000?ooooo0_l00009oooo
o`;o00002_ooool7o`000003ooooool0003o000000Co00001?ooool2o`0000Cooooo1?l0000;oooo
o`;o00001Oooool2o`0000;ooooo1?l00002ooooo`;o00001_ooool3o`000003ooooool0003o0000
00gooooo0ol0000Gooooo`;o0000FOooool001cooooo00?o0000ooooooooool0?oooool2o`0001Ko
oooo0ol00005ooooo`;o00005?ooool2o`0000[ooooo0_l000000ooooooo0000o`000003ooooo`Go
00001Oooool3o`0000?ooooo0_l0000=ooooo`;o00001_ooool3o`000004ooooool0003o0000o`00
00[ooooo0ol00006ooooo`;o000000?oooooo`000?l000000oooool4o`0000[ooooo0_l00005oooo
o`?o000000Coooooo`000?l0003ooooo0ol00005ooooo`;o0000DOooool001cooooo00?o0000oooo
ooooool0Goooool2o`0001?ooooo0_l0000;ooooo`Co00001?ooool5o`0000;ooooo0_l00002oooo
o`;o00000oooool2o`0000?ooooo0_l00009ooooo`;o00001Oooool4o`0000;ooooo0_l00009oooo
o`Co00001Oooool;o`0000_ooooo0_l00005ooooo`Ko00000_ooool3o`0000Cooooo0_l0001Aoooo
o`007?ooool00ol0003oooooooooo`1Aooooo`;o00008Oooool3o`0000Oooooo0ol000001?oooooo
0000o`000?l00005ooooo`So00000_ooool7o`0000?ooooo0ol00008ooooo`;o00001?ooool:o`00
00Wooooo1?l00002ooooo`_o00005_ooool2o`0000Gooooo0_l0000:ooooo`;o0000Boooool001co
oooo00?o0000ooooooooool0DOooool2o`0000Oooooo0_l0000Iooooo`;o00001?ooool6o`000004
ooooool0003o0000o`0000;ooooo2Ol00004ooooo`Oo00001?ooool2o`0000kooooo2_l0000:oooo
o`?o000000Coooooo`000?l0003o00000_ooool7o`0000cooooo0_l00007ooooo`;o00004_ooool2
o`0004_ooooo000Looooo`03o`000?oooooooooo043ooooo0_l0000Hooooo`;o00004oooool2o`00
00Cooooo0_l00004ooooo`Go00000_ooool>o`000003ooooool0003o000000;ooooo0ol00002oooo
o`;o00009oooool6o`0001Kooooo0_l00007ooooo`?o0000G_ooool001cooooo00?o0000oooooooo
ool0@?ooool2o`0001Kooooo0_l000000ooooooo0000o`00000Booooo`;o000000?oooooo`000?l0
00002_ooool4o`000003ooooool0003o000001?o00000_ooool5o`0001cooooo0_l00007ooooo`Co
00000_ooool5o`0001[ooooo0_l0001Nooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o0000
00?oooooo`000?l000005Oooool2o`0000Kooooo0_l00004oooooaOo00001?ooool8o`0001Sooooo
0_l00006ooooo`?o00001?ooool5o`0000[ooooo0_l0000<ooooo`Co0000G_ooool001cooooo00?o
0000ooooooooool0LOooool2o`0000Oooooo1?l00002ooooo`Co000000?oooooo`000?l000004Ol0
0003ooooo`So00008?ooool3o`0000;ooooo0_l0000?ooooo`;o00003?ooool4o`0005kooooo000L
ooooo`03o`000?oooooooooo05Oooooo0_l0000Eooooo`;o000000?oooooo`000?l000000_l00007
ooooo`?o000000?oooooo`000?l000005ol00004ooooo`;o000000?oooooo`000?l000005?ooool6
o`0000Oooooo0_l00002ooooo`?o00002oooool2o`0000;ooooo0_l0000=ooooo`;o0000Goooool0
01cooooo00?o0000ooooooooool0Eoooool2o`0001Gooooo0_l00003ooooo`;o00002?oooolLo`00
00Cooooo1ol00007ooooo`;o00002Oooool6o`0000Oooooo0_l00002ooooo`;o00003?ooool6o`00
01[ooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`1Dooooo`;o00003oooool2o`0000Oo
oooo0_l00003ooooo`;o00002_oooolKo`0000?ooooo1ol00007ooooo`;o00002_ooool2o`0000Co
oooo0_l00009ooooo`;o00002oooool4o`0000?ooooo0_l00002ooooo`Go00001?ooool2o`0000[o
oooo0ol0001Aooooo`007?ooool2o`0003Sooooo0_l0000Kooooo`;o00003Oooool4o`0000_ooooo
0ol0000:oooooaco00000_ooool6o`0001Cooooo0ol00003ooooo`?o00001_ooool4o`0000_ooooo
0_l00005ooooo`Wo00000_ooool4o`0000[ooooo0ol0001Aooooo`007?ooool00ol0003ooooooooo
o`0fooooo`?o00000oooool4o`0002?ooooo1Ol00007ooooo`;o000000?oooooo`000?l000001Ooo
ool4o`0000;ooooo7Ol000000ooooooo0000o`000003o`0000[ooooo0_l00003ooooo`;o00001Ooo
ool2o`0000Cooooo0_l00006ooooo`;o00005_ooool2o`0000;ooooo0ol00002ooooo`Co0000G_oo
ool001cooooo00?o0000ooooooooool0=_ooool2o`0000?ooooo1Ol0000Cooooo`;o00002oooool3
o`0000?ooooo0_l00007ooooo`;o000000?oooooo`000?l000001Oooool4o`0000;ooooo7Ol00000
1?oooooo0000o`000?ooool2o`000003ooooool0003o000000Oooooo0_l00003ooooo`;o00003ooo
ool2o`000003ooooool0003o0000013ooooo1?l0000Mooooo`;o00000_ooool2o`0004_ooooo000L
ooooo`03o`000?oooooooooo03_ooooo0_l000000ooooooo0000o`00000Cooooo`;o00002oooool5
o`000003ooooool0003o0000013ooooo1?l000000ooooooo0000o`00000Po`000004ooooool0003o
0000ooooo`;o00003?ooool2o`0000Oooooo0ol00002ooooo`;o000000Coooooo`000?l0003ooooo
0_l0000:ooooo`;o00001?ooool4o`0001gooooo0_l00002ooooo`;o0000Boooool001cooooo00?o
0000ooooooooool0>oooool2o`0000[ooooo0_l0000Jooooo`;o000000?oooooo`000?l000003ooo
ool8o`000003ooooool0003o000002?o00001oooool2o`0000cooooo0ol00002ooooo`;o000000?o
ooooo`000?l000003Oooool2o`0000cooooo0_l00005ooooo`;o00000_ooool2o`0005gooooo000L
ooooo`03o`000?oooooooooo03_ooooo0_l0000:ooooo`?o00005_ooool2o`0000Cooooo0_l0000?
ooooob;o000000?oooooo`000?l000002Ol00007ooooo`;o00003Oooool2o`0000;ooooo0_l00000
0ooooooo0000o`00000:ooooo`;o00000_ooool4o`0000;ooooo0_l00004ooooo`?o00000_ooool2
o`000003ooooool0003o000000Co0000GOooool001cooooo00?o0000ooooooooool0Aoooool3o`00
01Kooooo0_l00003ooooo`?o00003_ooool6o`000003ooooool0003o0000023o000000?oooooo`00
0?l000000ol0000@ooooo`;o00001?ooool2o`0000;ooooo0ol000000ooooooo0000o`000009oooo
o`;o00000_ooool5o`000003ooooool0003o000000Cooooo0ol000001Ooooooo0000o`000?l0003o
oooo00Co00003Oooool3o`0000;ooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`18oooo
o`;o00005Oooool2o`0000Cooooo1?l0000=ooooob_o000000?oooooo`000?l000000_l0000=oooo
o`Co00001?ooool2o`0000?ooooo0_l000000ooooooo0000o`00000>ooooo`Co00001oooool3o`00
0003ooooool0003o000000Go00001Oooool2o`0000Oooooo0ol00002ooooo`;o0000Boooool001co
oooo00?o0000ooooooooool0DOooool2o`0000cooooo0_l00005ooooo`?o00003Oooool2o`0000;o
oooo1_l00002ooooobCo00003Oooool4o`000003ooooool0003o000000Cooooo0_l0000Hooooo`;o
00000_ooool5o`0000;ooooo2?l00003ooooo`?o00001oooool2o`0004oooooo000Looooo`03o`00
0?oooooooooo04Kooooo0_l00009ooooo`;o00005?ooool3o`00013ooooo:ol0000Booooo`?o0000
1?ooool2o`0000;ooooo0_l0000Dooooo`;o00000_oooolAo`000004ooooool0003o0000o`0000Go
oooo1?l0001?ooooo`007?ooool00ol0003oooooooooo`0looooo`;o00002?ooool2o`0000Wooooo
0_l0000<ooooo`;o00001_ooool3o`0000kooooo9?l000000ooooooo0000o`000006o`0000Oooooo
0_l00009ooooo`;o00001Oooool2o`0000;ooooo0ol0000<ooooo`;o00001ooooolCo`000004oooo
ool0003o0000o`0000Gooooo1?l0001?ooooo`007?ooool00ol0003oooooooooo`0iooooo`;o0000
00?oooooo`000?l000004Oooool4o`0000cooooo0_l0000Aooooo`;o00001?ooool^o`0000Kooooo
0_l0000>ooooo`Co00000oooool2o`0000cooooo0_l00003ooooo`;o00000_ooool=o`000003oooo
ool0003o000000Go00002?ooool2o`0000;ooooo0_l0001<ooooo`007?ooool00ol0003ooooooooo
o`0iooooo`;o00005?ooool2o`00027ooooo1_l00003ooooob_o00004Oooool2o`0000?ooooo0_l0
000Fooooo`Co00000ooooolDo`0000Oooooo0ol00002ooooo`;o0000C?ooool001cooooo00?o0000
ooooooooool0=Oooool2o`0000;ooooo0_l00007ooooo`;o0000;oooool7o`000003ooooool0003o
000002Go000000Coooooo`000?l0003o00004Oooool2o`000003ooooool0003o000000Co00003ooo
ool3o`0000;ooooo1?l00002oooooaGo00001oooool2o`00057ooooo00001_ooooook^k^oc8b<_l0
003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003ooooo
ooooo`0eooooo`;o00001_ooool2o`0000?ooooo0_l0000_ooooo`Co000000?oooooo`000?l00000
0_oooolKo`0000;ooooo3Ol00005ooooo`;o00002_ooool6o`000003ooooool0003o000000oooooo
0ol00004ooooo`;o00000_oooolHo`0000Cooooo0_l00002ooooo`;o0000COooool00006oooooomg
MgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0hooooo`;o00000oooool2o`0000Kooooo0_l00006ooooo`;o00009?ooool3o`0000Ko
oooo9Ol000000ooooooo0000o`000002o`0000Gooooo0_l0000;ooooo`Go00002oooool2o`0000Co
oooo0_l00006ooooo`Co00000_oooolFo`0000?ooooo0_l00003ooooo`;o0000COooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo00?o0000ooooooooool0
;oooool2o`0000Gooooo1_l00009ooooo`;o00001_ooool2o`0001Wooooo0_l00003ooooo`;o0000
1?ooool2o`0000Oooooo8ol00002ooooo`Go00004Oooool5o`0000cooooo1?l00002ooooo`;o0000
0oooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000004ol00003ooooo`Co0000
0oooool2o`0004gooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Co
A4A4omgMgOoooooo00001oooool3o`0002oooooo0_l00005ooooo`;o000000Coooooo`000?l0003o
0000;?ooool2o`0000?ooooo0_l0000>ooooo`ko00000_oooolBo`0000;ooooo1Ol0000@ooooo`So
00001oooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l000000ooooooo
0000o`000002o`000003ooooool0003o000000co000000?oooooo`000?l000001?l00003ooooo`;o
0000E?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?oMgMgoEEEE
ooooool00007ooooo`03o`000?oooooooooo03Wooooo0_l000000ooooooo0000o`00000?ooooo`;o
00009Oooool2o`0000?ooooo0_l00002ooooo`_o000000?oooooo`000?l000001Ol000000ooooooo
0000o`00000<o`0000;ooooo0ol0000Booooo`So00001oooool2o`0000Kooooo1?l00007ooooo`;o
000000?oooooo`000?l000005?l00002ooooo`Co0000D_ooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool02_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo03;ooooo
0_l00008ooooo`;o00003oooool3o`0001gooooo0_l00004ooooo`?o00000oooool2o`0000Cooooo
4Ol00003ooooo`Go000000?oooooo`000?l000000_l00002ooooo`;o000000Coooooo`000?l0003o
00003oooool5o`0000;ooooo0_l00009ooooo`;o00004OoooolHo`0000;ooooo1?l0001Booooo`00
00KoooooogMgMonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000oooo
ooooool0<_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`00017ooooo0_l0000Eoooo
o`;o00001_ooool3o`0000?ooooo0_l00004ooooo`;o00001?oooolBo`000003ooooool0003o0000
00?o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00003ooo
ool4o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`;o00001_ooool2o`0000Kooooo0_l0
00000ooooooo0000o`00000Go`0005Oooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPgooooo
00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`0[ooooo`;o00002Oooool9o`0000Kooooo
0_l00006ooooo`;o00005?ooool5o`0000Cooooo1?l00003ooooo`;o00001?ooool2o`0000Gooooo
0_l000000ooooooo0000o`00000?o`000004ooooool0003o0000ooooo`;o00000oooool2o`0000?o
oooo0_l0000>ooooo`Ko00000oooool2o`000003ooooool0003o000000kooooo0_l00006ooooo`;o
000000Coooooo`000?l0003ooooo6Ol0001Dooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o
00002oooool3o`0000;ooooo0_l00006ooooo`;o00001Oooool3o`0001?ooooo1_l00004ooooo`?o
00002oooool5o`0000Cooooo0ol000000ooooooo0000o`00000<o`000003ooooool0003o000000;o
00000oooool2o`0000;ooooo0ol0000>ooooo`Ko00009OoooolAo`000003ooooool0003o000000Co
0000E?ooool001cooooo00?o0000ooooooooool0>Oooool2o`0000Oooooo0_l00008ooooo`;o0000
4oooool5o`0000Oooooo0_l0000:ooooo`Ko00001?ooool?o`000003ooooool0003o000000Go0000
1_ooool3o`0000gooooo2Ol0000Eooooo`;o00003_oooolCo`0005Sooooo000Looooo`03o`000?oo
oooooooo04;ooooo0_l0000Mooooo`;o00004?ooool3o`0000?ooooo1?l00006oooooaOo00001_oo
ool2o`0000kooooo2Ol0000Eooooo`Co00003OoooolBo`0005Sooooo000Looooo`03o`000?oooooo
oooo03?ooooo0ol000000ooooooo0000o`000008ooooo`Co0000;_ooool5o`0000Wooooo1_l00000
1?oooooo0000o`000?ooool=o`0000Gooooo1Ol0000>ooooo`;o00000_ooool2o`0001Wooooo0ol0
00000ooooooo0000o`000002o`0000Kooooo0_l000000ooooooo0000o`00000=o`0005[ooooo000L
ooooo`03o`000?oooooooooo03?ooooo0ol000000ooooooo0000o`000008ooooo`Co0000;?ooool4
o`000003ooooool0003o000000;ooooo0ol000001?oooooo0000o`000?ooool5o`0000Gooooo1?l0
00000ooooooo0000o`000006o`0000?ooooo1_l0000<ooooo`Co00005?ooool2o`0000Sooooo0ol0
00000ooooooo0000o`000002o`0000Kooooo0_l000000ooooooo0000o`000009o`000003ooooool0
003o000005_ooooo000Looooo`03o`000?oooooooooo04Oooooo0_l0000Xooooo`Go00001?ooool3
o`000003ooooool0003o000000Ko00001_ooool6o`000003ooooool0003o000000Kooooo1Ol0000=
ooooo`Co00001oooool3o`0000Oooooo0_l000000ooooooo0000o`000004ooooo`;o00000_ooool2
o`00013ooooo2_l0001Nooooo`007?ooool00ol0003oooooooooo`13ooooo`;o000000Coooooo`00
0?l0003o00008?ooool2o`0000Wooooo0_l00004ooooo`;o00000_ooool4o`0000gooooo0ol00004
ooooo`;o00000oooool4o`0000oooooo0_l00002ooooo`Go000000Coooooo`000?l0003o00001ooo
ool2o`0000Oooooo0_l0000@ooooo`Go000000?oooooo`000?l000001?ooool2o`0000Oooooo1?l0
001Cooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00003_ooool2o`000003ooooool0003o
000000?ooooo0_l0000Looooo`;o00001oooool2o`0000;ooooo0_l00002ooooo`;o00000oooool3
o`000004ooooool0003o0000o`0000[ooooo0_l00004ooooo`;o00000_ooool5o`0000;ooooo0_l0
000;ooooo`_o00003?ooool2o`0000Gooooo0_l00008ooooo`;o00001Oooool5o`0000gooooo0_l0
00000ooooooo0000o`000002o`0005?ooooo000Looooo`03o`000?oooooooooo033ooooo0_l00000
0ooooooo0000o`00000Fooooo`;o00007oooool2o`0000Cooooo0_l00002ooooo`;o00001?ooool2
o`0000;ooooo1_l000000ooooooo0000o`000003o`000004ooooool0003o0000ooooo`go00000ooo
ool3o`0000cooooo0ol00002ooooo`Go00003?ooool2o`0000Gooooo0_l00003ooooo`;o00000ooo
ool2o`0001Oooooo1Ol0001Eooooo`007?ooool00ol0003oooooooooo`0_ooooo`?o00001_ooool2
o`0000kooooo0_l000001?oooooo0000o`000?l0000Nooooo`;o00002oooool2o`000003ooooool0
003o000000;o00000_oooolDo`000003ooooool0003o000000;o00001Oooool3o`0000Wooooo1?l0
0004ooooo`Co00003?ooool4o`0000Wooooo0_l0000Nooooo`;o00000oooool2o`00057ooooo000L
ooooo`03o`000?oooooooooo02oooooo0_l00003ooooo`;o000000Coooooo`000?l0003o00003_oo
ool2o`0000;ooooo0_l0000[ooooo`;o00000oooool2o`0000?ooooo2?l000000ooooooo0000o`00
0007o`0000;ooooo1?l00002ooooo`?o00003?ooool4o`0000Cooooo0_l0000:ooooo`;o00000_oo
ool4o`0000cooooo0_l00007ooooo`;o00005oooool2o`00057ooooo000Looooo`;o0000=Oooool2
o`000003ooooool0003o000000Sooooo0_l0000Xooooo`;o00005?ooool2o`0000Cooooo1?l00008
ooooo`;o000000?oooooo`000?l000000_ooool2o`000004ooooool0003o0000o`0000Wooooo1Ol0
0002ooooo`;o00003_ooool2o`0001;ooooo0_l000000ooooooo0000o`000004ooooo`;o00004_oo
ool4o`0005Cooooo000Looooo`03o`000?oooooooooo03Cooooo0_l0000;ooooo`;o0000:?ooool3
o`000003ooooool0003o000000?o00000oooool2o`0000Oooooo1?l0000>ooooo`?o000000?ooooo
o`000?l000001?l0000=ooooo`Go000000Coooooo`000?l0003o00005Oooool2o`0000kooooo0_l0
000Hooooo`Co00000oooool2o`0004oooooo000Looooo`03o`000?oooooooooo03Cooooo0_l00007
ooooo`;o00002?ooool2o`0001gooooo0_l00004ooooo`So00000oooool3o`0000Kooooo1ol00000
0ooooooo0000o`000008ooooo`?o000000?oooooo`000?l000000_l0000>ooooo`;o00001Oooool2
o`0001Kooooo0_l0000>ooooo`;o00007oooool2o`0004oooooo000Looooo`03o`000?oooooooooo
02kooooo0_l000001?oooooo0000o`000?ooool2o`0000Oooooo0_l00006ooooo`Co00000oooool2
o`0001Sooooo0_l00005ooooo`?o00000_ooool2o`0000Cooooo1?l00007ooooo`Co000000?ooooo
o`000?l000000oooool2o`0001Wooooo0ol00004ooooo`;o000000?oooooo`000?l000008oooool2
o`0000Cooooo0_l0000Iooooo`;o0000Coooool001cooooo00?o0000ooooooooool0;_ooool2o`00
0004ooooool0003o0000ooooo`;o00001oooool2o`0000Kooooo1?l00003ooooo`;o00006?ooool3
o`0000Gooooo0ol00009ooooo`Co00003oooool2o`0001[ooooo0_l00004ooooo`;o000000?ooooo
o`000?l00000:Oooool2o`0001Wooooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`0^oooo
o`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo0_l00005ooooo`;o00002Oooool2o`00
01Oooooo0ol00006ooooo`;o000000?oooooo`000?l000000_l00004ooooo`Co0000:?ooool7o`00
01Wooooo0_l0000Wooooo`;o00001oooool2o`0000;ooooo0_l0001;ooooo`007?ooool00ol0003o
ooooooooo`0^ooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo0_l00005ooooo`Ko
00000oooool4o`0002?ooooo1?l0000`ooooo`Oo00006Oooool2o`0000?ooooo0_l0000Rooooo`;o
00002oooool2o`0004_ooooo000Looooo`03o`000?oooooooooo02kooooo0_l00007ooooo`?o0000
2_ooool4o`0000?ooooo0_l0001Eooooo`;o00001?ooool5o`0000Gooooo0_l0000Gooooo`;o0000
1Oooool2o`0000Gooooo0_l000000ooooooo0000o`00001[ooooo`007?ooool00ol0003ooooooooo
o`0^ooooo`Co00001Oooool5o`0000;ooooo1?l00002ooooo`Co0000:_ooool2o`0002_ooooo0_l0
00000ooooooo0000o`000002o`000003ooooool0003o000000;o00001oooool2o`0001kooooo0_l0
0005ooooo`;o000000?oooooo`000?l00000Joooool001cooooo00?o0000ooooooooool0<?ooool2
o`000003ooooool0003o000000Gooooo0_l00002ooooo`Co00000_ooool4o`0001oooooo0_l00003
ooooo`;o00001?ooool2o`0000Wooooo0_l0000Kooooo`;o00000oooool3o`0000;ooooo0_l00000
0ooooooo0000o`000002o`0000?ooooo0ol0000Looooo`;o0000N_ooool001cooooo00?o0000oooo
ooooool0<Oooool4o`0000[ooooo0_l00004ooooo`?o00002?ooool2o`0001Gooooo1?l000001?oo
oooo0000o`000?l0000>ooooo`;o00006oooool2o`000003ooooool0003o000000Wo00001Oooool8
o`0000kooooo0_l00008ooooo`;o00005?ooool2o`0001?ooooo0_l0001?ooooo`007?ooool00ol0
003oooooooooo`0aooooo`;o00001?ooool2o`0000_ooooo0ol00009ooooo`;o00005oooool2o`00
0005ooooool0003o0000o`000?ooool00ol000000ooooooo0000o`00000Qooooo`;o00000oooool<
o`0000Cooooo0ol00002ooooo`Co00002Oooool3o`0000;ooooo0_l00008ooooo`?o00001Oooool2
o`0000cooooo0_l0000Cooooo`;o0000Coooool001cooooo00?o0000ooooooooool0=oooool2o`00
00?ooooo0_l00005ooooo`?o00002oooool2o`0001Oooooo2Ol000000ooooooo0000o`000005oooo
o`Co00006?ooool2o`0000?ooooo0_l00002ooooo`;o00001oooool2o`000003ooooool0003o0000
013ooooo0ol00002ooooo`;o00002Oooool3o`0000Cooooo0_l0000:ooooo`;o00006?ooool2o`00
04cooooo000Looooo`03o`000?oooooooooo02kooooo0_l00004ooooo`;o000000?oooooo`000?l0
00000oooool3o`0000Cooooo1?l0000:ooooo`;o00004?ooool2o`0000?ooooo2?l0000;ooooo`Co
00000oooool4o`00017ooooo1ol00008ooooo`;o000000Coooooo`000?l0003ooooo0_l0000@oooo
o`;o00000oooool2o`0000Kooooo0_l00002ooooo`;o00004?ooool2o`0001Sooooo0_l0001<oooo
o`007?ooool00ol0003oooooooooo`0^ooooo`?o00000oooool5o`0000?ooooo0ol00006ooooo`;o
00002_ooool2o`00013ooooo0_l00002ooooo`Co00000oooool2o`0000Gooooo0_l00006ooooo`?o
000000?oooooo`000?l000000ol0000Cooooo`Oo00001Oooool3o`0000Sooooo1?l0000:ooooo`;o
00002_ooool3o`00017ooooo0_l0000Oooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0
;oooool2o`0000Gooooo0_l00004ooooo`;o00001oooool2o`00023ooooo1?l000000ooooooo0000
o`000004o`0000?ooooo0_l00006ooooo`?o000000?oooooo`000?l000000_l0000Iooooo`;o0000
1Oooool2o`0000Wooooo1?l0000Fooooo`?o00004Oooool2o`0001oooooo0_l00018ooooo`007?oo
ool2o`0004?ooooo0_l000000ooooooo0000o`000005ooooo`;o00004?ooool2o`0000Wooooo0_l0
00000ooooooo0000o`000004o`0000[ooooo0_l000000ooooooo0000o`000002ooooo`;o00008?oo
ool2o`0000Sooooo0_l0000Hooooo`;o0000O_ooool001cooooo00?o0000ooooooooool0;Oooool2
o`0001;ooooo0ol000000ooooooo0000o`000005ooooo`;o00001Oooool2o`0000Wooooo0_l00005
ooooo`Go00004Oooool3o`000003ooooool0003o000002Oooooo0_l00005ooooo`;o00003oooool3
o`0000Kooooo0_l000000ooooooo0000o`00000Aooooo`;o0000J?ooool001cooooo00?o0000oooo
ooooool0;Oooool2o`0001;ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00002Oooool2
o`0000Sooooo0_l00002ooooo`;o00000_ooool7o`0000?ooooo0_l00006ooooo`;o00000_ooool2
o`000003ooooool0003o000000;o00001oooool2o`0001gooooo1?l00002ooooo`;o00000_ooool2
o`0000?ooooo0_l00007ooooo`?o00000oooool2o`0000Cooooo0_l0000Aooooo`;o000000?ooooo
o`000?l000001Oooool2o`0001Kooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`0doooo
o`;o00002_ooool6o`0000;ooooo0_l00008ooooo`;o00002Oooool2o`0000;ooooo0_l000000ooo
oooo0000o`000004ooooo`;o00000oooool2o`0000Gooooo0ol00005ooooo`Co00001oooool2o`00
01gooooo1?l00002ooooo`Ko00000oooool2o`0000gooooo0_l00004ooooo`;o00000oooool2o`00
00oooooo0_l00004ooooo`?o000000?oooooo`000?l000004oooool2o`0004Kooooo000Looooo`03
o`000?oooooooooo037ooooo0_l000000ooooooo0000o`000006ooooo`;o00000_ooool6o`0000co
oooo0_l0000:ooooo`;o00001?ooool2o`0000gooooo0_l000000ooooooo0000o`000007ooooo`;o
00009Oooool2o`000003ooooool0003o000000Gooooo0_l00009ooooo`?o00004oooool4o`0000go
oooo0_l00002ooooo`So0000Foooool001cooooo00?o0000ooooooooool0<Oooool2o`000003oooo
ool0003o000000Kooooo0_l00002ooooo`;o00000_ooool3o`0001Oooooo0_l0000?ooooo`;o0000
0_ooool2o`000003ooooool0003o000000Sooooo0_l00008ooooo`Go00005?ooool2o`000004oooo
ool0003o0000ooooo`?o00000_ooool2o`0000_ooooo1?l0000Aooooo`;o000000?oooooo`000?l0
00000_l00003ooooo`;o00002_ooool2o`0000;ooooo0_l0001Mooooo`007?ooool00ol0003ooooo
ooooo`0^ooooo`;o00001?ooool2o`0000gooooo1Ol00003ooooo`;o00000_ooool3o`0001Gooooo
0_l00006ooooo`;o00001Oooool2o`0000Sooooo0_l00008ooooo`Oo00003oooool5o`0000Gooooo
0_l000000ooooooo0000o`000003o`0000_ooooo0_l00006ooooo`;o00002?ooool3o`0000?ooooo
0_l00003ooooo`;o00001?ooool2o`0000Cooooo0_l0001Qooooo`007?ooool00ol0003ooooooooo
o`0^ooooo`;o00003oooool2o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`?o000000Co
ooooo`000?l0003o00004?ooool2o`000003ooooool0003o000000;o00001_ooool2o`0000Sooooo
0_l00005ooooo`;o00003?ooool3o`0000oooooo0ol00009ooooo`Ko00001?ooool2o`0000_ooooo
1?l00008ooooo`;o00001Oooool4o`000003ooooool0003o000000?ooooo0_l00004ooooo`;o0000
0_ooool2o`0005gooooo000Looooo`03o`000?oooooooooo02kooooo0_l00009ooooo`?o00000ooo
ool2o`000003ooooool0003o000000Co00001?ooool2o`0001Cooooo0_l000000ooooooo0000o`00
0002o`0000oooooo0ol00005ooooo`?o00001_ooool2o`0000Oooooo0_l0000Cooooo`;o00000ooo
ool4o`0000Kooooo0_l000000ooooooo0000o`000008ooooo`;o00001_ooool2o`000003ooooool0
003o000000Kooooo1?l000001?oooooo0000o`000?ooool2o`0000Cooooo0_l00004ooooo`;o0000
GOooool001cooooo00?o0000ooooooooool0;Oooool3o`0000;ooooo0_l00005ooooo`?o00001_oo
ool4o`000003ooooool0003o000001Oooooo0_l0000>ooooo`;o00001_ooool2o`0000Kooooo0ol0
0006ooooo`;o00001Oooool4o`00017ooooo1_l00002ooooo`?o00002Oooool2o`00013ooooo0_l0
00000ooooooo0000o`000008ooooo`;o000000?oooooo`000?l000000ol00004ooooo`?o0000H_oo
ool001cooooo00?o0000ooooooooool0;Oooool3o`0000;ooooo0_l0000:ooooo`;o00000_ooool2
o`0000?ooooo0_l0000?ooooo`;o00001_ooool2o`0000kooooo0_l0000>ooooo`?o00003Oooool4
o`00013ooooo0ol000001?oooooo0000o`000?l00002ooooo`?o00009oooool9o`0000Gooooo0ol0
001Qooooo`007?ooool00ol0003oooooooooo`0]ooooo`?o00002?ooool2o`0000Cooooo0_l00002
ooooo`;o000000?oooooo`000?l000000_l0000>ooooo`?o00001Oooool2o`0000Kooooo0_l00006
ooooo`?o00002?ooool2o`0000Gooooo0_l0000>ooooo`?o00004?ooool7o`0000?ooooo0_l00000
0ooooooo0000o`00000OoooooaKo0000HOooool001cooooo00?o0000ooooooooool0;Oooool3o`00
00Sooooo1?l00002ooooo`;o00001Oooool4o`0000Oooooo0_l00004ooooo`?o00001_ooool6o`00
00;ooooo0_l00006ooooo`;o00002Oooool2o`0001Gooooo0_l00004ooooo`;o00003Oooool2o`00
00Wooooo0ol0000Mooooo`Wo00000oooool:o`0006;ooooo000Looooo`03o`000?oooooooooo03;o
oooo0_l00004ooooo`Co00005?ooool2o`0000?ooooo0ol00004ooooo`?o00000_ooool4o`0000Wo
oooo0_l0000:ooooo`;o000000?oooooo`000?l000006?ooool2o`0000;ooooo1Ol00003ooooo`?o
000000?oooooo`000?l000001oooool5o`0001cooooo0_l00002ooooo`Ko000000?oooooo`000?l0
00002ol0001Pooooo`007?ooool00ol0003oooooooooo`0booooo`Co00000_ooool2o`0001_ooooo
0_l00005ooooo`Co00000oooool2o`0000Gooooo0_l00002ooooo`Co00000oooool2o`0000?ooooo
0_l000000ooooooo0000o`000002ooooo`;o00004_ooool2o`0000Cooooo1Ol00003ooooo`?o0000
00Coooooo`000?l0003o00001_ooool6o`0000Kooooo0_l0000GoooooaCo00002?ooool2o`0005Ko
oooo000Looooo`03o`000?oooooooooo033ooooo0_l00002ooooo`;o00009_ooool4o`0000?ooooo
0ol00003ooooo`?o00001?ooool4o`000003ooooool0003o000000?o00001oooool2o`0000cooooo
0_l00004ooooo`;o00002Oooool3o`0000Cooooo0ol00008ooooo`Go00000oooool4o`0000oooooo
0_l00003oooooaOo00002?ooool2o`0005Kooooo000Looooo`;o0000<Oooool2o`0000Oooooo0_l0
000Pooooo`;o00001Oooool4o`0000;ooooo0ol00005ooooo`[o00001oooool2o`0000cooooo0_l0
000?ooooo`?o00001Oooool4o`0000Kooooo0_l000000ooooooo0000o`000006o`00013ooooo0_l0
0003oooooaSo0000Goooool001cooooo00?o0000ooooooooool0>Oooool2o`00023ooooo0_l00005
ooooo`Co00000_ooool3o`0000;ooooo1Ol000000ooooooo0000o`000006ooooo`Co00008_ooool2
o`0000Oooooo1?l00007ooooo`Ko00003?ooool2o`0000Sooooo6Ol00002ooooo`;o0000Foooool0
01cooooo00?o0000ooooooooool0;oooool2o`0001_ooooo0_l00003ooooo`;o00004?ooool3o`00
00?ooooo0_l00002ooooo`Go00000_ooool;o`0001Oooooo0_l00009ooooo`;o00000oooool2o`00
00Cooooo0_l00005ooooo`So00002oooool3o`0000Sooooo5?l000000ooooooo0000o`000002o`00
00;ooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00003Oooool2o`0000Ko
oooo0_l00004ooooo`;o00000oooool2o`0000Gooooo0_l0000:ooooo`?o00000_ooool2o`0000;o
oooo0_l00005ooooo`Wo00005?ooool2o`0000;ooooo0ol0000;ooooo`;o000000?oooooo`000?l0
00001?ooool2o`0000Cooooo2Ol0000;ooooo`?o00001oooool4o`000003ooooool0003o0000017o
000000?oooooo`000?l000000_ooool2o`0005[ooooo000Looooo`03o`000?oooooooooo03Cooooo
0_l00008ooooo`;o00000_ooool2o`000005ooooool0003o0000o`000?ooool00_l000000ooooooo
0000o`000008ooooo`Co00002?ooool=o`0000Sooooo0ol00002ooooo`;o00004oooool2o`0000;o
oooo1_l00003ooooo`?o00000_ooool4o`0000_ooooo1_l000000ooooooo0000o`00000<ooooo`;o
00001ooooolKo`000004ooooool0003o0000o`0005[ooooo000Looooo`03o`000?oooooooooo02oo
oooo0_l00002ooooo`?o00003?ooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o
00001Oooool2o`000003ooooool0003o000000Oooooo5ol000000ooooooo0000o`000002o`0000Co
oooo0_l00003ooooo`;o00003_ooool4o`0000?ooooo0ol00004ooooo`;o00002?ooool5o`0000Go
oooo0_l0000;ooooo`Co00001?oooolLo`0000;ooooo0_l0001Kooooo`007?ooool00ol0003ooooo
ooooo`0_ooooo`Ko00001Oooool4o`00017ooooo0_l00008ooooo`;o00002?ooool4o`000003oooo
ool0003o000000oo000000?oooooo`000?l000000_l00003ooooo`Go000000?oooooo`000?l00000
1?ooool2o`0000oooooo0_l00003ooooo`Co00000oooool2o`0000?ooooo0ol0000Dooooo`Co0000
1?oooolLo`0005oooooo000Looooo`03o`000?oooooooooo037ooooo0_l00007ooooo`Co00000_oo
ool2o`0001gooooo7_l00004ooooo`Oo00001?ooool5o`0000?ooooo0_l00004ooooo`Ko00000ooo
ool2o`0000Gooooo0_l00003ooooo`?o00001?ooool2o`0001Cooooo7ol00002ooooo`;o0000F_oo
ool001cooooo00?o0000ooooooooool0@?ooool2o`000003ooooool0003o000000Sooooo0_l0000@
oooooaoo00001?ooool8o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o00001?ooool4
o`0000?ooooo0_l00009ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`0001Cooooo1Ol0
0002oooooaco0000<_ooool2o`0002Kooooo000Looooo`03o`000?oooooooooo037ooooo0_l0000@
ooooo`Co00001_ooool2o`0000[ooooo0_l00004oooooa3o00000_ooool>o`000003ooooool0003o
000000Co00000_ooool2o`0001;ooooo0_l00003ooooo`;o00002Oooool2o`000003ooooool0003o
000001;ooooo0_l00005ooooo`Co000000?oooooo`000?l000007?l0000dooooo`;o00009_ooool0
01cooooo00?o0000ooooooooool0<Oooool2o`0000?ooooo0_l0000<ooooo`Co00004Oooool2o`00
00?ooooo0_l00002oooooago000000Coooooo`000?l0003ooooo1ol00004ooooo`Ko00002oooool2
o`0000_ooooo0_l000000ooooooo0000o`00000Booooo`Co00000ooooolPo`0003Kooooo0_l0000W
ooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00000oooool2o`0000kooooo0_l00005oooo
o`;o00003Oooool4o`0000;ooooo3?l000000ooooooo0000o`00000Ao`000003ooooool0003o0000
00Go00001?ooool7o`0000[ooooo0_l0000;ooooo`;o000000?oooooo`000?l000005?ooool2o`00
00Cooooo0_l000000ooooooo0000o`00000Io`0003Oooooo0_l0000Wooooo`007?ooool00ol0003o
ooooooooo`0aooooo`;o00005?ooool2o`0000Cooooo0_l00007ooooo`;o00001?oooolVo`0000Ko
oooo0ol00003ooooo`Wo00000oooool6o`000003ooooool0003o000000Cooooo0_l00006ooooo`;o
00000oooool2o`0000gooooo0_l00006ooooo`;o00000_ooool7o`000004ooooool0003o0000oooo
o`oo00002Oooool2o`0001Gooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0kooooo`;o
00002Oooool3o`0000gooooo0_l00006ooooob;o00002Oooool2o`0000;ooooo4ol000000ooooooo
0000o`000004ooooo`;o00001_ooool3o`0000;ooooo0_l0000=ooooo`;o00002_ooool>o`000003
ooooool0003o000000Wo00002Oooool3o`0001?ooooo0ol0000nooooo`0000Koooooonk^k_lb<S;o
0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000
ooooooooool0<Oooool2o`0000Sooooo0_l00009ooooo`?o00000oooool2o`0001;ooooo8?l00004
ooooo`;o00000ooooolCo`0000Gooooo0_l0000<ooooo`?o00005Oooool2o`0000Oooooo3?l00002
ooooo`_o00002_ooool2o`0001?ooooo0_l0000oooooo`0000KoooooogMgMonHV9SooooooiRHV?mg
MgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0
<Oooool2o`0000Kooooo0_l000000ooooooo0000o`000009ooooo`;o00000oooool2o`0001;ooooo
7ol00005ooooo`;o000000?oooooo`000?l000005?l00004ooooo`;o00002oooool4o`0000?ooooo
0_l0000@ooooo`;o000000?oooooo`000?l000000_l00003ooooo`ko000000?oooooo`000?l00000
1ol0000Nooooo`;o0000@?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0>Oooool2o`000003oooo
ool0003o000000_ooooo0_l00008ooooo`Co00000_ooool2o`0000Gooooo7?l000000ooooooo0000
o`000004ooooo`Ko000000?oooooo`000?l000004Ol0000Aooooo`Co00000oooool2o`0000gooooo
0_l00004ooooo`Co000000?oooooo`000?l000005Ol000000ooooooo0000o`00000Nooooo`;o0000
@?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oV9RHoooo
oonHV9So8B4Q00Kooooo0ol00017ooooo`Co00002?ooool4o`0000;ooooo0_l00007oooooako0000
0oooool5o`0000?ooooo4Ol0000@ooooo`;o00001_ooool2o`0000kooooo0_l00004ooooo`;o0000
0ooooolFo`0000Sooooo0_l0001Jooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooooooo
o`09ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`17ooooo`?o0000
2?ooool2o`000003ooooool0003o000000;o00002OoooolNo`0000;ooooo0_l00008oooooa?o0000
2_ooool2o`000003ooooool0003o000000;o00001?ooool3o`00013ooooo0_l00002ooooo`;o0000
0ooooolCo`0000[ooooo0_l0001Jooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0@Oooool2o`0000oooooo0_l0
00000ooooooo0000o`000002o`0000Sooooo0_l00002oooooaSo000000?oooooo`000?l000000_oo
ool2o`0000Wooooo4_l00002ooooo`;o00001_ooool3o`000003ooooool0003o000000;o00001?oo
ool3o`0000Oooooo0_l00006ooooo`;o00000_ooool3o`0000;ooooo0_l00002ooooo`co000000?o
ooooo`000?l00000I_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@
oiRHV008ooooo`03o`000?oooooooooo03Oooooo1?l00006ooooo`;o00003oooool4o`0000Cooooo
0_l00005oooooa;o000000?oooooo`000?l000001Ol000000ooooooo0000o`000005ooooo`;o0000
2_ooool@o`0000;ooooo0_l00007ooooo`;o000000?oooooo`000?l000000_l00003ooooo`Co0000
1oooool2o`0000_ooooo0_l00004ooooo`;o00000oooool7o`0000;ooooo0ol00007ooooo`;o0000
GOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106oooo
o`03o`000?oooooooooo03Oooooo1?l0000;ooooo`?o00002oooool2o`000004ooooool0003o0000
ooooo`;o00001OoooolJo`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000_ooooo2ol0
0002ooooo`?o00001?ooool3o`0000gooooo0ol00002ooooo`?o00001Oooool2o`0000Kooooo0_l0
0002ooooo`;o000000?oooooo`000?l000000ol00002ooooo`;o00000_ooool2o`0000?ooooo0ol0
0007ooooo`Co00005_ooool2o`0004?ooooo000Looooo`03o`000?oooooooooo03[ooooo0_l0000:
ooooo`?o00002_ooool2o`0000;ooooo0_l00009oooooaWo000000?oooooo`000?l000000ol0000M
ooooo`;o00001?ooool3o`0000Kooooo0_l00006ooooo`;o00000_ooool3o`0000Gooooo0_l00000
0ooooooo0000o`000003ooooo`;o00000_ooool2o`000003ooooool0003o000000?o00002?ooool2
o`0000Wooooo0_l00002ooooo`;o00005_ooool2o`0001Gooooo0_l0000/ooooo`007?ooool00ol0
003oooooooooo`0jooooo`;o00001_ooool2o`0000oooooo0_l00005ooooo`;o00001?oooolKo`00
00;ooooo0ol0000;ooooo`;o00006oooool2o`0000?ooooo1?l000000ooooooo0000o`00000@oooo
o`;o00000_ooool2o`0000Cooooo0_l000001?oooooo0000o`000?l00009ooooo`;o00002Oooool2
o`00037ooooo0_l0000/ooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00000oooool2o`00
013ooooo0ol000001?oooooo0000o`000?ooool2o`0000?ooooo0_l00004ooooo`Ko00000_ooool8
o`0000;ooooo0_l0000;ooooo`?o00006_ooool6o`000005ooooool0003o0000o`000?ooool00_l0
00000ooooooo0000o`00000Aooooo`;o00000oooool3o`000004ooooool0003o0000o`0000;ooooo
0_l0000@ooooo`;o00004Oooool2o`0000Cooooo0_l00016ooooo`007?ooool00ol0003ooooooooo
o`0jooooo`;o00002oooool2o`0000kooooo1?l00002ooooo`;o00001_ooool2o`000004ooooool0
003o0000ooooo`?o00000_ooool2o`000003ooooool0003o000000Ko00003Oooool5o`000003oooo
ool0003o000000?ooooo0_l00008ooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`Co
00001Oooool5o`0000Wooooo1_l00006ooooo`;o000000?oooooo`000?l000001?ooool2o`0001co
oooo0_l000000ooooooo0000o`000002ooooo`;o00001?ooool2o`0004Kooooo000Looooo`03o`00
0?oooooooooo03[ooooo0_l0000;ooooo`;o00003_ooool2o`0000oooooo2_l000000ooooooo0000
o`000004o`0000Wooooo1?l00002ooooo`Go000000?oooooo`000?l000000oooool4o`000003oooo
ool0003o000000;o000000?oooooo`000?l000001Oooool2o`000003ooooool0003o000000?ooooo
0_l00005ooooo`;o000000?oooooo`000?l000002Oooool6o`0000Cooooo0_l00003ooooo`;o0000
2oooool2o`0000[ooooo0_l00009ooooo`;o000000?oooooo`000?l000001oooool3o`0004Kooooo
000Looooo`03o`000?oooooooooo05Oooooo0ol00007ooooo`?o000000?oooooo`000?l000000ooo
ool8o`0000?ooooo1?l00009ooooo`Co00001Oooool2o`0000Sooooo0_l000000ooooooo0000o`00
0002o`0002Oooooo0ol00005ooooo`Co000000?oooooo`000?l000002oooool2o`0000[ooooo0_l0
0009ooooo`?o00002Oooool2o`0004Oooooo000Looooo`03o`000?oooooooooo05?ooooo0_l00002
ooooo`?o00001oooool3o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000002
o`0000gooooo1ol00005ooooo`?o00001?ooool4o`0000Wooooo0_l0000Pooooo`;o00002_ooool2
o`0000Oooooo0_l0000Mooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0Doooool3o`00
00_ooooo0_l00005ooooo`;o000000?oooooo`000?l000001oooool2o`0000Wooooo1Ol00007oooo
o`?o000000Coooooo`000?l0003ooooo1?l00009ooooo`;o00006Oooool2o`0000Gooooo0_l00002
ooooo`;o00003oooool2o`0003kooooo0_l0000aooooo`007?ooool00ol0003oooooooooo`1Boooo
o`Co00001_ooool2o`0000?ooooo0ol00004ooooo`;o00002?ooool4o`000004ooooool0003o0000
o`0001Gooooo0_l0000Fooooo`?o00004?ooool2o`0000Wooooo0_l0000Rooooo`;o00004_ooool2
o`0001Oooooo0_l0000aooooo`007?ooool00ol0003oooooooooo`0mooooo`;o000000?oooooo`00
0?l000004?ooool4o`0000Kooooo0_l00004ooooo`?o00003Oooool2o`0000?ooooo0ol0000>oooo
o`?o00005oooool3o`0000;ooooo0ol00006ooooo`;o00004_ooool2o`0002?ooooo0_l0000Boooo
o`;o0000B_ooool001cooooo00?o0000ooooooooool0?Oooool2o`000003ooooool0003o000000;o
oooo0_l0000?ooooo`;o00000oooool2o`0000Oooooo0_l0000Cooooo`;o00003_ooool3o`0000Oo
oooo0_l00003ooooo`;o00000_ooool2o`0000Cooooo1?l00009ooooo`Co00000_ooool2o`0000ko
oooo0_l0000cooooo`;o0000C_ooool001cooooo0_l00015ooooo`;o00003?ooool2o`000003oooo
ool0003o000000?ooooo0_l00006ooooo`?o00004oooool2o`0000oooooo0_l00007ooooo`Co0000
00?oooooo`000?l000000_ooool2o`0000?ooooo0ol0000:ooooo`?o00001?ooool2o`0000kooooo
0_l0000@ooooo`Co00007oooool2o`0004kooooo000Looooo`03o`000?oooooooooo04;ooooo0_l0
000>ooooo`;o000000?oooooo`000?l000000oooool2o`0000Kooooo0_l00003ooooo`Wo00000ooo
ool2o`00013ooooo0_l00002ooooo`;o00002?ooool3o`0000;ooooo1?l000001?oooooo0000o`00
0?ooool4o`0000Wooooo0ol000000ooooooo0000o`000003o`0001Wooooo0_l00005ooooo`Co0000
8Oooool2o`0004cooooo000Looooo`03o`000?oooooooooo04;ooooo0_l0000Qooooo`_o00000ooo
ool2o`0000kooooo1?l00003ooooo`;o000000Coooooo`000?l0003o00000_ooool4o`0000;ooooo
1ol00003ooooo`;o00002Oooool3o`000003ooooool0003o000000;o00002oooool2o`0000gooooo
0_l00002ooooo`;o00002Oooool2o`0001_ooooo0_l0001<ooooo`007?ooool00ol0003ooooooooo
o`14ooooo`;o00007oooool2o`0000kooooo0_l0000<ooooo`;o000000?oooooo`000?l000003?l0
0005ooooo`Ko00003oooool2o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`;o00000ooo
ool2o`0000Cooooo0_l00005ooooo`;o00001?ooool2o`0000Wooooo0_l0000aooooo`;o0000=_oo
ool001cooooo00?o0000ooooooooool0@oooool3o`0001?ooooo0_l00002ooooo`;o00005_ooool2
o`0000Gooooo0_l00008ooooo`go00001_ooool5o`0000oooooo1Ol000001?oooooo0000o`000?oo
ool2o`000003ooooool0003o000000?o00001oooool3o`000003ooooool0003o000000Co0000@_oo
ool2o`0003Kooooo000Looooo`03o`000?oooooooooo04?ooooo0_l0000Dooooo`;o00000_ooool2
o`0001gooooo0_l00007ooooo`Ko00000oooool2o`000003ooooool0003o000000Wooooo0_l00004
ooooo`;o00001oooool7o`0000Cooooo0_l000000ooooooo0000o`000004o`0000Kooooo0_l00002
ooooo`Co00000oooool2o`0002Gooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`1[oooo
o`;o00006?ooool6o`0000Wooooo0_l0000<ooooo`;o00001Oooool9o`0000?ooooo0_l00004oooo
o`Co00002oooool4o`0000;ooooo0_l0000Uooooo`?o00005Oooool2o`0003Sooooo000Looooo`03
o`000?oooooooooo04Gooooo0_l0000Cooooo`;o00002oooool3o`000003ooooool0003o000000[o
oooo0_l0000<ooooo`Ko00000oooool2o`0000Cooooo0_l00007ooooo`;o00002?ooool=o`000003
ooooool0003o000000;o00000_ooool4o`0000Sooooo2Ol0000Xooooo`;o00005Oooool2o`0003So
oooo000Looooo`03o`000?oooooooooo04Gooooo0_l0000Cooooo`;o00002oooool5o`0000[ooooo
1ol00003ooooo`;o00000_ooool2o`0000Cooooo0_l00002ooooo`;o00002_ooool2o`000005oooo
ool0003o0000o`000?ooool00_l00002ooooo`Co000000?oooooo`000?l000003ol00002ooooo`;o
000000?oooooo`000?l000000_l00003ooooo`Go00000_ooool2o`0007Wooooo000Looooo`03o`00
0?oooooooooo04Gooooo0_l0000Oooooo`;o000000Coooooo`000?l0003o00002_ooool2o`000003
ooooool0003o000000;o00000oooool3o`000003ooooool0003o000000Cooooo0_l0000;ooooo`Go
00000_ooool2o`000003ooooool0003o000000;ooooo4ol000000ooooooo0000o`000009o`0000?o
oooo0_l00020ooooo`007?ooool00ol0003oooooooooo`16ooooo`;o00006Oooool2o`0000?ooooo
0_l0000Aooooo`;o00001_ooool2o`0000[ooooo0_l00008ooooo`Co000000Coooooo`000?l0003o
00001ooooolJo`000004ooooool0003o0000ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Z
ooooo`;o00005?ooool2o`0003_ooooo000Looooo`03o`000?oooooooooo04Kooooo0_l0000Boooo
o`;o00001Oooool2o`0001Kooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l00007
ooooo`;o00000_ooool2o`0000Gooooo0_l00002ooooo`?o00001OoooolFo`000003ooooool0003o
000000Kooooo0ol00002ooooo`Co0000:_ooool2o`0001Cooooo0_l0000kooooo`007?ooool00ol0
003oooooooooo`17ooooo`;o00003_ooool2o`000003ooooool0003o000001Wooooo0_l00005oooo
o`;o000000?oooooo`000?l000000oooool2o`0000Cooooo1?l00003ooooo`;o00000oooool2o`00
00Kooooo0_l00004ooooo`;o000000?oooooo`000?l000004Ol000000ooooooo0000o`000004o`00
00;ooooo2_l00006ooooo`;o0000M?ooool001cooooo00?o0000ooooooooool0Aoooool2o`0000ko
oooo1Ol0000Iooooo`Co00004Oooool4o`0000Sooooo0_l00002ooooo`;o00000_ooool2o`0000Ko
oooo3Ol000000ooooooo0000o`00000;o`0000?ooooo1?l00002ooooo`?o00001_ooool2o`0007Co
oooo000Looooo`03o`000?oooooooooo04Wooooo0_l0000;ooooo`;o000000Coooooo`000?l0003o
00006oooool2o`0001[ooooo0_l00005ooooo`Go00001OoooolIo`0000gooooo0_l0001mooooo`00
7?ooool00ol0003oooooooooo`19ooooo`;o00002oooool2o`0000?ooooo0_l0000`ooooo`;o0000
1?ooool2o`0000Kooooo1?l00005oooooaSo00001?ooool3o`0004Cooooo0_l00010ooooo`007?oo
ool2o`0005cooooo0_l0000`ooooo`;o00003Oooool2o`0000Kooooo5_l00006ooooo`Go00001Ooo
ool2o`0003_ooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`1Kooooo`;o0000>?ooool2
o`0000Cooooo0_l000000ooooooo0000o`000004oooooaOo00002?ooool4o`0000?ooooo0_l0001m
ooooo`007?ooool00ol0003oooooooooo`1Kooooo`;o00002?ooool2o`0000Cooooo0_l0000Xoooo
o`;o00001?ooool2o`000003ooooool0003o000000Cooooo6?l00009ooooo`;o00000_ooool2o`00
07kooooo000Looooo`03o`000?oooooooooo05kooooo0_l00004ooooo`?o00000_ooool4o`0002go
oooo1Ol00004ooooo`;o000000?oooooo`000?l000005?l0000=ooooo`;o0000O_ooool001cooooo
00?o0000ooooooooool0G_ooool2o`0000Cooooo0_l00002ooooo`?o0000;oooool2o`000003oooo
ool0003o000000Cooooo0_l000000ooooooo0000o`00000Co`0008kooooo000Looooo`03o`000?oo
oooooooo04kooooo0_l0000Hooooo`;o0000<_ooool2o`0000Sooooo5?l0000;ooooo`;o00000ooo
ool2o`0003Kooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o00004?ooool3
o`0003Wooooo0_l00002ooooo`;o00001?oooolDo`0000Gooooo0_l00002ooooo`Ko000000?ooooo
o`000?l00000=Oooool3o`0004Gooooo000Looooo`03o`000?oooooooooo05oooooo1Ol0000hoooo
o`;o00000_ooool2o`0000Cooooo5Ol00004ooooo`;o00000_ooool2o`0000;ooooo0_l0000hoooo
o`;o0000A_ooool001cooooo00?o0000ooooooooool0Goooool2o`000003ooooool0003o000000?o
oooo0_l0000Wooooo`;o00005?oooolBo`000004ooooool0003o0000ooooo`;o00002_ooool2o`00
02Cooooo0_l0001Iooooo`007?ooool00ol0003oooooooooo`1Oooooo`;o00001_ooool2o`0002Oo
oooo0_l0000Doooooa7o00001Oooool2o`0000Cooooo0_l00004ooooo`;o00008_ooool4o`0005Wo
oooo000Looooo`03o`000?oooooooooo057ooooo0_l0000Gooooo`;o00009Oooool2o`0001Cooooo
4ol00004ooooo`;o00000_ooool2o`0000;ooooo0_l0000Tooooo`;o0000Foooool001cooooo00?o
0000ooooooooool0D?ooool3o`0000cooooo0_l00005ooooo`;o00000_ooool2o`0002Gooooo0_l0
000<ooooo`Co00001OoooolBo`0000Cooooo0_l00002ooooo`Ko0000POooool001cooooo00?o0000
ooooooooool0D?ooool4o`0000_ooooo0_l00005ooooo`;o0000;_ooool2o`0000Kooooo1Ol00005
ooooo`ko000000Coooooo`000?l0003o00002?ooool4o`0003Kooooo0_l0001;ooooo`007?ooool0
0ol0003oooooooooo`1Booooo`;o00004_ooool2o`0002kooooo0ol00004ooooo`?o00002?ooool2
o`0000;ooooo2ol0000<ooooo`;o0000=oooool2o`0004_ooooo000Looooo`03o`000?oooooooooo
05;ooooo0_l0000@ooooo`Co00002?ooool2o`0000oooooo1_l00005ooooo`;o000000?oooooo`00
0?l000001_ooool2o`0000Cooooo0_l00003ooooo`;o00001?ooool;o`0000;ooooo0_l000000ooo
oooo0000o`000005ooooo`;o00000_ooool6o`00023ooooo0_l0001Nooooo`007?ooool00ol0003o
ooooooooo`1Tooooo`Co00000_ooool2o`0000?ooooo0ol0000?ooooo`Ko00001Oooool2o`000003
ooooool0003o000000cooooo0_l00003ooooo`;o00001_ooool2o`0000Wooooo0_l000000ooooooo
0000o`000005ooooo`;o00000oooool5o`0000Oooooo0_l0000Gooooo`;o0000G_ooool001cooooo
0_l0001Dooooo`;o00004Oooool2o`0000;ooooo0_l00003ooooo`;o0000??ooool3o`0000?ooooo
1?l00008ooooo`Co000000?oooooo`000?l000000ol00007ooooo`;o0000Moooool001cooooo00?o
0000ooooooooool0Doooool2o`0004Cooooo0ol0000Aooooo`So00003?ooool8o`00083ooooo000L
ooooo`03o`000?oooooooooo06kooooo0_l00002ooooo`;o00003_ooool2o`0000gooooo0_l00006
ooooo`?o00002oooool2o`0000Cooooo2?l0000;ooooo`;o000000?oooooo`000?l000001?l00020
ooooo`007?ooool00ol0003oooooooooo`1^ooooo`;o00000_ooool2o`0000Oooooo0_l00005oooo
o`;o00003Oooool2o`0001Cooooo0_l00007ooooo`;o00003_ooool2o`0000Cooooo0_l00021oooo
o`007?ooool00ol0003oooooooooo`1Hooooo`;o00005?ooool3o`0000[ooooo0_l0000Booooo`Co
00005_ooool2o`0000Gooooo0_l00004ooooo`;o00001?ooool2o`0002Gooooo0_l0001Tooooo`00
7?ooool00ol0003oooooooooo`1Hooooo`;o00005Oooool2o`000003ooooool0003o000001_ooooo
1?l0000Fooooo`;o00001Oooool2o`0000Cooooo0ol00002ooooo`?o00003?ooool2o`0001Oooooo
0_l0000>ooooo`;o0000E?ooool001cooooo00?o0000ooooooooool0Foooool2o`0001Gooooo0_l0
00000ooooooo0000o`00000eooooo`;o000000?oooooo`000?l000001Oooool3o`0000;ooooo0_l0
000=ooooo`;o00009_ooool3o`0005Cooooo000Looooo`03o`000?oooooooooo05_ooooo0_l00002
ooooo`;o00005?ooool2o`000004ooooool0003o0000o`0002;ooooo0_l0000=ooooo`Oo0000?ooo
ool2o`0005Gooooo000Looooo`03o`000?oooooooooo05_ooooo0_l00002ooooo`;o00005oooool3
o`000003ooooool0003o000000[ooooo0_l00003ooooo`?o00003Oooool2o`0000Kooooo0_l00007
ooooo`;o000000?oooooo`000?l000003_ooool2o`0008Kooooo000Looooo`03o`000?oooooooooo
05_ooooo0_l00002ooooo`Co00004?ooool2o`0000Cooooo1Ol00002ooooo`;o000000?oooooo`00
0?l000000_l000001?oooooo0000o`000?l00002ooooo`Co00001Oooool2o`0000Gooooo1?l00004
ooooo`;o00002?ooool2o`00013ooooo0_l0000Hooooo`;o0000K?ooool001cooooo00?o0000oooo
ooooool0Goooool4o`00013ooooo0_l00005ooooo`;o00001?ooool2o`000003ooooool0003o0000
00;o000000?oooooo`000?l000001ol00005ooooo`?o00000oooool5o`0000Oooooo0_l00005oooo
o`;o000000Goooooo`000?l0003o0000ooooo`03o`00023ooooo1?l0001/ooooo`007?ooool00ol0
003oooooooooo`1Qooooo`;o00004_ooool2o`0000Sooooo0_l00007ooooo`;o000000?oooooo`00
0?l000000ol000001?oooooo0000o`000?l00002ooooo`?o00000oooool4o`0000Sooooo0_l00008
ooooo`?o000000Coooooo`000?l0003o00008?ooool2o`0006kooooo000Looooo`03o`000?oooooo
oooo05oooooo0_l0000Dooooo`;o00002?ooool2o`0000?ooooo0_l0000;ooooo`Co000000?ooooo
o`000?l000001Oooool3o`0000Sooooo0_l0002Oooooo`007?ooool00ol0003oooooooooo`1Ooooo
o`;o00008_ooool3o`0000Kooooo0_l00003ooooo`Co00002?ooool4o`000003ooooool0003o0000
01;ooooo0_l0000Iooooo`;o0000M_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2
ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo06Kooooo0ol0
000Booooo`;o00001_ooool3o`0000Cooooo4?l00005ooooo`;o000000?oooooo`000?l000004_oo
ool2o`000003ooooool0003o000001Kooooo0_l0001fooooo`0000KoooooogMgMonHV9SooooooiRH
V?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000oooooooo
ool0I_ooool3o`0001;ooooo0_l00007ooooo`;o00001?ooool2o`0000;ooooo1?l000000ooooooo
0000o`000006o`000004ooooool0003o0000o`0000;ooooo0ol0000Eooooo`;o00001Oooool2o`00
00_ooooo0_l0000<ooooo`;o00000oooool2o`0006Oooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
08[ooooo0_l00004ooooo`;o000000?oooooo`000?l000001?ooool6o`000003ooooool0003o0000
00Go00003Oooool2o`0000[ooooo1?l00006ooooo`;o000000?oooooo`000?l000002Oooool2o`00
0003ooooool0003o000000?ooooo0_l0001Wooooo`0000?oooooo`000?ooool00_ooool00ol0003o
ooooooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`0006[ooooo0_l0000Woooo
o`;o00001Oooool4o`0000;ooooo0_l000000ooooooo0000o`000002o`0000gooooo0_l0000<oooo
o`;o00001_ooool2o`0000Kooooo0_l00002ooooo`Co000000?oooooo`000?l000002Oooool2o`00
067ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Goc<c<o`000?l0
003o0000olc<c006ooooo`03o`000?oooooooooo06[ooooo0_l0000hooooo`Co00004_ooool2o`00
00Cooooo0_l00002ooooo`;o00000oooool2o`0000Oooooo2?l000000ooooooo0000o`000007oooo
o`Co0000HOooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol@413o
^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0QOooool3o`0001gooooo0ol0000Boooo
o`;o00000oooool3o`0000;ooooo0_l000000ooooooo0000o`000002o`0000Sooooo0ol0000>oooo
o`;o0000Hoooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj
^[[o000000Kooooo00?o0000ooooooooool0QOooool3o`00013ooooo0_l0000;ooooo`?o00005ooo
ool2o`0000Kooooo1?l00008ooooo`;o0000M?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^
2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0LOooool3o`0001Ko
oooo0_l0000<ooooo`;o000000?oooooo`000?l000002Oooool3o`00023ooooo0_l0001nooooo`00
7?ooool00ol0003oooooooooo`1aooooo`?o00005_ooool2o`0000oooooo0_l0000:ooooo`;o0000
1_ooool2o`0002_ooooo0_l0001[ooooo`007?ooool00ol0003oooooooooo`2=ooooo`;o00006_oo
ool4o`000004ooooool0003o0000o`0000oooooo1?l0000Hooooo`;o0000Joooool001cooooo00?o
0000ooooooooool0SOooool4o`0001Sooooo1ol0000@ooooo`Co00005?ooool2o`0006oooooo000L
ooooo`03o`000?oooooooooo08oooooo1?l0000Iooooo`;o0000:_ooool2o`0006oooooo000Loooo
o`03o`000?oooooooooo07[ooooo0_l0000Eooooo`;o00000_ooool2o`0003Wooooo0_l0001goooo
o`007?ooool00ol0003oooooooooo`1jooooo`Co00005oooool2o`0003Wooooo0_l0001gooooo`00
7?ooool00ol0003oooooooooo`1looooo`;o0000boooool001cooooo00?o0000ooooooooool0W?oo
ool4o`0002Wooooo1?l0001looooo`007?ooool00ol0003oooooooooo`21ooooo`;o00006Oooool4
o`0000?ooooo0_l0000Pooooo`;o00000_ooool4o`0007cooooo000Looooo`03o`000?oooooooooo
087ooooo1?l0000Nooooo`;o00000oooool3o`0000kooooo0_l0000:ooooo`;o0000P_ooool001co
oooo00?o0000ooooooooool0Poooool2o`0002?ooooo1?l0000<ooooo`Go0000S?ooool001cooooo
0_l0002[ooooo`;o00003?ooool2o`000003ooooool0003o000008cooooo000Looooo`03o`000?oo
oooooooo08Kooooo1?l0002oooooo`007?ooool00ol0003oooooooooo`26ooooo`Co0000_oooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`2Jooooo`;o0000[Oooool001cooooo00?o0000oooo
ooooool0V_ooool4o`000:_ooooo000Looooo`03o`000?oooooooooo09cooooo0_l0002[ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0Z?ooool3o`0009kooooo000Looooo`03o`000?oooooooooo
0:Sooooo0ol000000ooooooo0000o`00002Kooooo`007?ooool00ol0003oooooooooo`2/ooooo`;o
00002?ooool2o`00097ooooo000Looooo`03o`000?oooooooooo0;Kooooo0_l0002Aooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001;ooooo1?l000000ol@413ooooooooo
o`03ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo0ol0003ooooo
od[ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0
oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooo
oooo0?ooooooD_ooool001;ooooo00?oEEEEofIVI_l00000oooooomDooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00YOooool01?l@413o0000o`000?ooool2o`000003oa0@4?oo
oooooooo01Gooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`04oa0@4?l0003oA4A4olc<c0Co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP2@ooooo`00Y_ooool01Ol0003ooooooooooooooooo0000
00Wooooo1_l00009ooooo`05oa0@4?nj^[[oooooogMgMolb<S801Oooool00onHV9So410@omgMg@03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0T?ooool00:Kooooo00Go0000ooooooooooooooooo`00
000Looooo`03o`000?oooooooooo00Cooooo00?oQhN7oeEEEOooool00_ooool01Ol@413ooooooooo
oooooooo410@093ooooo002Vooooo`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo
00?oZJVYoa0@4?ooool00_ooool01Oo<c<co8B4Qo`000?mEEEGo000000?ooooo00Go0000oooooooo
ooooooooo`00002@ooooo`00Y_ooool01Ol0003oQhN7oooooonYZJWo000001[ooooo00?o410@o`00
0?nj^[X00oooool01OlQ8B7oQhN7oooooonHV9So000000?ooooo00Go0000ooooooooooooooooo`00
002@ooooo`00YOooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo01Wooooo00?o^[Zj
ob4Q8Oooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go410@oooooooooooooooo
oa0@402@ooooo`00`oooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00Go8B4QoiRHV?oooooo
MgMgoeEEE@03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0T?ooool00<?ooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@03ooooo`05olc<c?l@413o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^093ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(396) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.31342 .57652 Mdot
.3595 .57039 Mdot
.71251 .58921 Mdot
.50203 .36483 Mdot
.70019 .43632 Mdot
.68702 .60516 Mdot
.50474 .70063 Mdot
.50176 .70035 Mdot
.6704 .61636 Mdot
.21541 .44644 Mdot
.53907 .70129 Mdot
.45092 .30663 Mdot
.51892 .70524 Mdot
.47895 .36128 Mdot
.46758 .48665 Mdot
.45613 .41832 Mdot
.37433 .58774 Mdot
.73188 .3949 Mdot
.44011 .40987 Mdot
.68777 .56665 Mdot
.43014 .24478 Mdot
.47299 .37039 Mdot
.32641 .53672 Mdot
.4789 .36446 Mdot
.46693 .39567 Mdot
.34465 .55481 Mdot
.30726 .56619 Mdot
.46466 .39119 Mdot
.43882 .32521 Mdot
.53487 .70176 Mdot
.58567 .55976 Mdot
.38305 .20776 Mdot
.51441 .39051 Mdot
.33133 .37387 Mdot
.50478 .68809 Mdot
.47937 .74138 Mdot
.66751 .5774 Mdot
.5263 .74156 Mdot
.50847 .6828 Mdot
.5317 .68055 Mdot
.53835 .68712 Mdot
.33857 .55069 Mdot
.55609 .70542 Mdot
.62068 .77233 Mdot
.49289 .36019 Mdot
.40337 .48424 Mdot
.58902 .76905 Mdot
.43274 .37216 Mdot
.37234 .57939 Mdot
.70436 .5693 Mdot
.67108 .34045 Mdot
.51254 .73719 Mdot
.44782 .58239 Mdot
.76938 .7571 Mdot
.52301 .69498 Mdot
.43806 .39895 Mdot
.6464 .60907 Mdot
.45783 .3421 Mdot
.50555 .37303 Mdot
.32246 .3341 Mdot
.45122 .35836 Mdot
.72917 .41237 Mdot
.36539 .60445 Mdot
.63072 .60101 Mdot
.67473 .61797 Mdot
.52989 .73939 Mdot
.35353 .5358 Mdot
.52547 .71268 Mdot
.45508 .31682 Mdot
.70709 .57702 Mdot
.43296 .33456 Mdot
.53847 .70557 Mdot
.3131 .54418 Mdot
.49647 .36869 Mdot
.42583 .76934 Mdot
.56449 .77186 Mdot
.61853 .61292 Mdot
.37891 .27006 Mdot
.7578 .35946 Mdot
.57762 .52306 Mdot
.48977 .37305 Mdot
.79728 .64547 Mdot
.52947 .48923 Mdot
.3559 .5821 Mdot
.40466 .59105 Mdot
.3875 .65009 Mdot
.44062 .38169 Mdot
.5698 .56839 Mdot
.48314 .42092 Mdot
.692 .48417 Mdot
.65289 .60799 Mdot
.34262 .5854 Mdot
.49376 .36638 Mdot
.47901 .31965 Mdot
.21974 .52702 Mdot
.42199 .33857 Mdot
.5035 .37907 Mdot
.4037 .61458 Mdot
.54405 .70903 Mdot
.40852 .41359 Mdot
.66498 .40146 Mdot
.45175 .60914 Mdot
.43705 .39557 Mdot
.66414 .59331 Mdot
.34123 .60529 Mdot
.49607 .403 Mdot
.51283 .7169 Mdot
.48543 .37186 Mdot
.54672 .67848 Mdot
.37984 .56763 Mdot
.5049 .34108 Mdot
.71062 .41601 Mdot
.45229 .26401 Mdot
.32892 .54038 Mdot
.33198 .47354 Mdot
.45652 .36914 Mdot
.45344 .33757 Mdot
.36207 .56858 Mdot
.69357 .57241 Mdot
.74453 .66669 Mdot
.31878 .54255 Mdot
.53235 .68028 Mdot
.36949 .58757 Mdot
.47707 .28194 Mdot
.68622 .57029 Mdot
.43611 .59484 Mdot
.43357 .59453 Mdot
.60267 .311 Mdot
.49495 .3754 Mdot
.4979 .25856 Mdot
.6731 .59743 Mdot
.3507 .5527 Mdot
.52848 .70499 Mdot
.42189 .38817 Mdot
.32559 .55486 Mdot
.49985 .70615 Mdot
.72742 .45396 Mdot
.71231 .39436 Mdot
.35882 .55147 Mdot
.31747 .49559 Mdot
.56214 .68776 Mdot
.54556 .68867 Mdot
.66742 .34077 Mdot
.35715 .58191 Mdot
.72166 .42896 Mdot
.50582 .72147 Mdot
.61777 .2247 Mdot
.50809 .37595 Mdot
.64072 .34146 Mdot
.77165 .67203 Mdot
.67109 .34088 Mdot
.35736 .25131 Mdot
.7121 .42161 Mdot
.49921 .70804 Mdot
.42847 .34669 Mdot
.33764 .56854 Mdot
.32927 .55317 Mdot
.45448 .3231 Mdot
.49257 .39697 Mdot
.48154 .35015 Mdot
.50439 .39789 Mdot
.54029 .63164 Mdot
.49167 .36721 Mdot
.29708 .72623 Mdot
.32861 .566 Mdot
.47672 .40082 Mdot
.68392 .57869 Mdot
.44246 .44501 Mdot
.55025 .71934 Mdot
.5045 .36815 Mdot
.48608 .39647 Mdot
.41843 .33173 Mdot
.5286 .67823 Mdot
.42151 .78065 Mdot
.77462 .34914 Mdot
.50656 .75657 Mdot
.53058 .79954 Mdot
.68569 .59204 Mdot
.44554 .35888 Mdot
.72893 .44184 Mdot
.42927 .42867 Mdot
.49408 .33929 Mdot
.67887 .3403 Mdot
.48681 .38776 Mdot
.37302 .24641 Mdot
.5129 .32417 Mdot
.40845 .64458 Mdot
.273 .6838 Mdot
.50162 .34969 Mdot
.2423 .4303 Mdot
.63841 .35387 Mdot
.62592 .55857 Mdot
.53047 .70112 Mdot
.70415 .58945 Mdot
.70075 .57712 Mdot
.51138 .7449 Mdot
.36797 .45745 Mdot
.22453 .42191 Mdot
.43006 .32671 Mdot
.44935 .60573 Mdot
.38955 .56743 Mdot
.71397 .41949 Mdot
.3626 .55519 Mdot
.81554 .61812 Mdot
.60093 .50795 Mdot
.56202 .55319 Mdot
.75114 .39759 Mdot
.69689 .56217 Mdot
.44379 .59786 Mdot
.72594 .43474 Mdot
.47946 .34002 Mdot
.3786 .5697 Mdot
.64475 .34916 Mdot
.4384 .43144 Mdot
.14918 .50157 Mdot
.30775 .56254 Mdot
.57691 .30952 Mdot
.5224 .69789 Mdot
.65686 .62855 Mdot
.4414 .38255 Mdot
.46369 .35414 Mdot
.3753 .55439 Mdot
.43127 .34791 Mdot
.545 .5327 Mdot
.48859 .39393 Mdot
.63184 .60153 Mdot
.79026 .41391 Mdot
.52319 .75027 Mdot
.76391 .42464 Mdot
.31648 .54108 Mdot
.46044 .83217 Mdot
.66745 .58494 Mdot
.40686 .42985 Mdot
.53199 .7154 Mdot
.72366 .45341 Mdot
.65783 .59067 Mdot
.72261 .39985 Mdot
.50185 .33935 Mdot
.66054 .58126 Mdot
.72404 .41011 Mdot
.52585 .55123 Mdot
.49947 .40033 Mdot
.58063 .26179 Mdot
.50835 .73076 Mdot
.34813 .59082 Mdot
.48098 .32877 Mdot
.45819 .58501 Mdot
.42103 .31501 Mdot
.59613 .36314 Mdot
.45287 .58642 Mdot
.46501 .61436 Mdot
.55983 .50915 Mdot
.7448 .44405 Mdot
.4858 .7801 Mdot
.55168 .57156 Mdot
.37466 .58782 Mdot
.48966 .32859 Mdot
.45828 .68529 Mdot
.50403 .72701 Mdot
.47257 .33852 Mdot
.44248 .66973 Mdot
.50443 .72035 Mdot
.45791 .33668 Mdot
.53435 .68617 Mdot
.32997 .56034 Mdot
.52676 .51593 Mdot
.34601 .59579 Mdot
.49266 .34564 Mdot
.53677 .68996 Mdot
.70281 .5849 Mdot
.34377 .55497 Mdot
.48106 .37298 Mdot
.4792 .38291 Mdot
.45694 .60724 Mdot
.50015 .38875 Mdot
.42156 .62526 Mdot
.43486 .37714 Mdot
.71353 .57885 Mdot
.4275 .33224 Mdot
.6677 .38169 Mdot
.68898 .46899 Mdot
.37657 .55937 Mdot
.45433 .58712 Mdot
.64831 .60008 Mdot
.52176 .5303 Mdot
.55502 .26116 Mdot
.48786 .3664 Mdot
.45876 .59333 Mdot
.59234 .32729 Mdot
.55009 .71819 Mdot
.51215 .40983 Mdot
.6914 .65402 Mdot
.65369 .60529 Mdot
.44582 .60253 Mdot
.41963 .41689 Mdot
.31615 .525 Mdot
.4282 .38889 Mdot
.6654 .58038 Mdot
.34262 .59391 Mdot
.41941 .35424 Mdot
.5788 .76153 Mdot
.45962 .58493 Mdot
.5466 .70402 Mdot
.4098 .61242 Mdot
.443 .34257 Mdot
.70813 .58644 Mdot
.32855 .54809 Mdot
.51698 .69177 Mdot
.32532 .53991 Mdot
.64957 .35754 Mdot
.58504 .34049 Mdot
.48433 .57992 Mdot
.75572 .43075 Mdot
.56463 .16587 Mdot
.5091 .75865 Mdot
.41578 .42054 Mdot
.66346 .64267 Mdot
.25018 .61311 Mdot
.65931 .59542 Mdot
.30851 .50166 Mdot
.64995 .60911 Mdot
.42869 .38185 Mdot
.68503 .61003 Mdot
.2114 .53929 Mdot
.46882 .3886 Mdot
.68205 .61891 Mdot
.55847 .62399 Mdot
.47147 .38731 Mdot
.32394 .55496 Mdot
.30152 .24914 Mdot
.35484 .40334 Mdot
.3602 .42651 Mdot
.64401 .61073 Mdot
.27977 .51788 Mdot
.45781 .38967 Mdot
.4305 .40377 Mdot
.34142 .56652 Mdot
.42796 .30992 Mdot
.75042 .42958 Mdot
.73336 .39881 Mdot
.65165 .28119 Mdot
.44277 .2142 Mdot
.3591 .4576 Mdot
.33657 .55486 Mdot
.78887 .37684 Mdot
.41734 .76516 Mdot
.45836 .58451 Mdot
.50075 .70171 Mdot
.45371 .78852 Mdot
.45112 .42475 Mdot
.28218 .60059 Mdot
.54208 .5301 Mdot
.32901 .58477 Mdot
.49589 .56993 Mdot
.51273 .69275 Mdot
.35805 .42222 Mdot
.22875 .39225 Mdot
.4818 .34863 Mdot
.5292 .73416 Mdot
.45434 .30039 Mdot
.56323 .56762 Mdot
.59132 .28966 Mdot
.62232 .69521 Mdot
.49264 .34748 Mdot
.45763 .77153 Mdot
.48958 .33536 Mdot
.61058 .31634 Mdot
.47562 .33688 Mdot
.32048 .55098 Mdot
.41063 .34959 Mdot
.54455 .57282 Mdot
.61153 .18029 Mdot
.60045 .49996 Mdot
.73481 .40479 Mdot
.47563 .36066 Mdot
.47095 .34665 Mdot
.73083 .41063 Mdot
.33519 .58527 Mdot
.47955 .32486 Mdot
.54996 .81603 Mdot
.4923 .36928 Mdot
.51126 .73869 Mdot
.59671 .41466 Mdot
.42514 .20308 Mdot
.44452 .37493 Mdot
.31905 .52486 Mdot
.54683 .6927 Mdot
.52257 .72432 Mdot
.53305 .39256 Mdot
.50891 .73264 Mdot
.42978 .34511 Mdot
.59617 .41559 Mdot
.34866 .538 Mdot
.52205 .40836 Mdot
.32385 .57973 Mdot
.8045 .39154 Mdot
.50106 .71833 Mdot
.46244 .59127 Mdot
.35735 .46711 Mdot
.50876 .70945 Mdot
.76819 .45343 Mdot
.41015 .35856 Mdot
.48366 .44213 Mdot
.38469 .53663 Mdot
.70715 .59067 Mdot
.44878 .59145 Mdot
.52165 .69359 Mdot
.49101 .36334 Mdot
.45668 .40176 Mdot
.51513 .73583 Mdot
.30279 .30093 Mdot
.58666 .55934 Mdot
.49391 .34623 Mdot
.32115 .56419 Mdot
.34704 .55132 Mdot
.48611 .41551 Mdot
.48684 .33212 Mdot
.69657 .60021 Mdot
.45819 .59258 Mdot
.4529 .58861 Mdot
.44012 .60288 Mdot
.64546 .62077 Mdot
.57115 .1692 Mdot
.547 .69019 Mdot
.39457 .20501 Mdot
.41208 .72413 Mdot
.52838 .3248 Mdot
.68748 .57457 Mdot
.45817 .35732 Mdot
.43971 .39287 Mdot
.53508 .6908 Mdot
.54894 .18769 Mdot
.42667 .39839 Mdot
.32754 .58858 Mdot
.51899 .73784 Mdot
.44438 .30276 Mdot
.5675 .69335 Mdot
.71042 .43627 Mdot
.34738 .45745 Mdot
.50726 .73308 Mdot
.35587 .54413 Mdot
.5075 .73343 Mdot
.47445 .34742 Mdot
.41753 .4158 Mdot
.32543 .58307 Mdot
.69965 .41089 Mdot
.4639 .32075 Mdot
.46183 .33346 Mdot
.73474 .55658 Mdot
.42841 .7687 Mdot
.7527 .45954 Mdot
.42941 .37504 Mdot
.48616 .44319 Mdot
.70392 .40571 Mdot
.45384 .3278 Mdot
.42598 .33654 Mdot
.49431 .25634 Mdot
.55626 .6861 Mdot
.72932 .45885 Mdot
.59838 .18163 Mdot
.30835 .56501 Mdot
.43639 .62745 Mdot
.44416 .60411 Mdot
.49227 .74089 Mdot
.51926 .51852 Mdot
.4516 .60055 Mdot
.42135 .70502 Mdot
.36917 .81957 Mdot
.45113 .59332 Mdot
.63628 .6145 Mdot
.24365 .51972 Mdot
.432 .33109 Mdot
.4873 .33711 Mdot
.74683 .43854 Mdot
.36577 .57303 Mdot
.2977 .71935 Mdot
.502 .75306 Mdot
.46329 .36969 Mdot
.30329 .55876 Mdot
.39513 .649 Mdot
.45007 .60349 Mdot
.72177 .44179 Mdot
.6981 .42563 Mdot
.48217 .33091 Mdot
.57963 .2981 Mdot
.33908 .55312 Mdot
.48101 .3729 Mdot
.45037 .33805 Mdot
.64943 .58454 Mdot
.3777 .56961 Mdot
.68059 .58005 Mdot
.47293 .6018 Mdot
.21612 .58747 Mdot
.62975 .80849 Mdot
.51004 .72984 Mdot
.45886 .52296 Mdot
.52131 .75017 Mdot
.59632 .70834 Mdot
.45729 .59174 Mdot
.47771 .372 Mdot
.32633 .53283 Mdot
.48406 .37273 Mdot
.49299 .36825 Mdot
.49244 .35284 Mdot
.35756 .45688 Mdot
.7579 .36462 Mdot
.7369 .44209 Mdot
.4371 .34754 Mdot
.63968 .60838 Mdot
.42905 .6432 Mdot
.19638 .48117 Mdot
.4706 .35653 Mdot
.45432 .33678 Mdot
.34576 .52985 Mdot
.51015 .35987 Mdot
.50411 .70869 Mdot
.33431 .58831 Mdot
.44547 .40008 Mdot
.66947 .40015 Mdot
.47576 .3247 Mdot
.45784 .53384 Mdot
.49332 .71564 Mdot
.40171 .3703 Mdot
.5178 .35865 Mdot
.4578 .59106 Mdot
.44838 .59238 Mdot
.4789 .61502 Mdot
.5204 .74073 Mdot
.64862 .58698 Mdot
.62641 .59527 Mdot
.50906 .33764 Mdot
.42824 .35772 Mdot
.4416 .43173 Mdot
.72071 .58145 Mdot
.56212 .58414 Mdot
.33703 .4901 Mdot
.47404 .30411 Mdot
.6661 .62619 Mdot
.40561 .61431 Mdot
.39923 .25726 Mdot
.34222 .58948 Mdot
.68854 .63881 Mdot
.52135 .7204 Mdot
.71463 .40849 Mdot
.64571 .30484 Mdot
.31866 .54573 Mdot
.32369 .52951 Mdot
.69253 .59784 Mdot
.57883 .43044 Mdot
.82108 .70255 Mdot
.66718 .5989 Mdot
.55668 .54775 Mdot
.34008 .56226 Mdot
.51199 .39293 Mdot
.59973 .34147 Mdot
.56681 .43601 Mdot
.67179 .62201 Mdot
.48069 .38241 Mdot
.74882 .48151 Mdot
.69638 .60098 Mdot
.46209 .44189 Mdot
.64333 .61077 Mdot
.54519 .71505 Mdot
.67187 .5933 Mdot
.307 .57442 Mdot
.49232 .37652 Mdot
.78536 .7406 Mdot
.51969 .49939 Mdot
.4727 .37779 Mdot
.50605 .7338 Mdot
.5968 .64673 Mdot
.47776 .3438 Mdot
.74829 .41347 Mdot
.63719 .60705 Mdot
.60603 .69839 Mdot
.42264 .36202 Mdot
.68798 .61013 Mdot
.30503 .53133 Mdot
.71281 .62604 Mdot
.66158 .40872 Mdot
.44966 .58955 Mdot
.33134 .5644 Mdot
.50363 .765 Mdot
.53691 .6835 Mdot
.45647 .40934 Mdot
.44778 .34507 Mdot
.32813 .56997 Mdot
.51903 .54115 Mdot
.53208 .38366 Mdot
.49004 .37147 Mdot
.69177 .58776 Mdot
.66497 .56625 Mdot
.46902 .48358 Mdot
.66622 .58406 Mdot
.48962 .44154 Mdot
.32391 .5627 Mdot
.42951 .39202 Mdot
.33146 .5434 Mdot
.48759 .32703 Mdot
.57127 .69152 Mdot
.35213 .58729 Mdot
.39725 .40803 Mdot
.49425 .37895 Mdot
.37164 .50948 Mdot
.44191 .3471 Mdot
.49673 .35478 Mdot
.65162 .5749 Mdot
.7343 .42113 Mdot
.51189 .40758 Mdot
.57686 .74805 Mdot
.70197 .41729 Mdot
.33128 .27349 Mdot
.68545 .57044 Mdot
.70813 .44601 Mdot
.63017 .27049 Mdot
.45294 .58708 Mdot
.73878 .41833 Mdot
.42365 .58877 Mdot
.51639 .7329 Mdot
.30553 .58942 Mdot
.47794 .38673 Mdot
.21661 .57872 Mdot
.58464 .56158 Mdot
.46073 .60543 Mdot
.46915 .32714 Mdot
.45825 .35259 Mdot
.30342 .55745 Mdot
.80998 .62634 Mdot
.64658 .57347 Mdot
.50337 .39194 Mdot
.31543 .54641 Mdot
.78595 .65793 Mdot
.68028 .62039 Mdot
.73024 .44868 Mdot
.49802 .68885 Mdot
.39227 .58076 Mdot
.46298 .59042 Mdot
.50005 .71533 Mdot
.61901 .62082 Mdot
.68379 .34016 Mdot
.42582 .38102 Mdot
.68474 .57646 Mdot
.67243 .34094 Mdot
.52421 .40016 Mdot
.51865 .74683 Mdot
.54491 .7822 Mdot
.34917 .58309 Mdot
.51573 .73621 Mdot
.74816 .42669 Mdot
.38081 .58193 Mdot
.32638 .58226 Mdot
.50518 .71358 Mdot
.25418 .65886 Mdot
.59247 .32927 Mdot
.49114 .72535 Mdot
.59889 .36993 Mdot
.67249 .34214 Mdot
.46678 .60245 Mdot
.72052 .44009 Mdot
.79372 .39165 Mdot
.3405 .55171 Mdot
.44976 .78771 Mdot
.6725 .33996 Mdot
.50357 .37957 Mdot
.72346 .40898 Mdot
.43545 .63872 Mdot
.47411 .69147 Mdot
.50149 .71252 Mdot
.73574 .56747 Mdot
.72108 .40631 Mdot
.50323 .34655 Mdot
.46606 .17874 Mdot
.45483 .38252 Mdot
.50723 .72416 Mdot
.54337 .5312 Mdot
.37478 .56362 Mdot
.55226 .71566 Mdot
.54534 .53249 Mdot
.43413 .38724 Mdot
.45668 .37243 Mdot
.75997 .38053 Mdot
.37702 .57703 Mdot
.47121 .60226 Mdot
.48478 .37787 Mdot
.45907 .33869 Mdot
.46624 .41145 Mdot
.50231 .21205 Mdot
.41186 .28248 Mdot
.48072 .4074 Mdot
.67781 .62906 Mdot
.42593 .42474 Mdot
.50648 .38641 Mdot
.31523 .52445 Mdot
.68478 .38251 Mdot
.47387 .60482 Mdot
.48393 .3355 Mdot
.49244 .34441 Mdot
.51081 .68229 Mdot
.59309 .32937 Mdot
.56146 .4416 Mdot
.70789 .56884 Mdot
.67114 .55179 Mdot
.46143 .31159 Mdot
.33555 .57235 Mdot
.74405 .45016 Mdot
.51557 .4186 Mdot
.32265 .58441 Mdot
.47241 .3143 Mdot
.6383 .60067 Mdot
.45527 .59451 Mdot
.51945 .4192 Mdot
.72629 .41505 Mdot
.56198 .68985 Mdot
.34703 .26808 Mdot
.7002 .58483 Mdot
.4529 .39154 Mdot
.63261 .57979 Mdot
.66939 .60902 Mdot
.45903 .60788 Mdot
.39994 .39326 Mdot
.33075 .55755 Mdot
.3551 .5447 Mdot
.70973 .36261 Mdot
.64266 .61908 Mdot
.71044 .53768 Mdot
.54011 .72446 Mdot
.43884 .34371 Mdot
.46963 .64985 Mdot
.36217 .55034 Mdot
.60271 .30971 Mdot
.70266 .43714 Mdot
.50271 .71533 Mdot
.42473 .58532 Mdot
.34822 .58949 Mdot
.35482 .54655 Mdot
.49334 .36481 Mdot
.46922 .36435 Mdot
.61085 .58536 Mdot
.63789 .34823 Mdot
.53071 .68502 Mdot
.72021 .44682 Mdot
.71107 .57842 Mdot
.42538 .36407 Mdot
.35492 .5807 Mdot
.43555 .19805 Mdot
.44295 .34388 Mdot
.63998 .60829 Mdot
.3576 .569 Mdot
.73696 .44563 Mdot
.74618 .43137 Mdot
.50083 .36488 Mdot
.38105 .24541 Mdot
.51077 .71221 Mdot
.32262 .55376 Mdot
.40406 .57371 Mdot
.43451 .35305 Mdot
.47172 .36034 Mdot
.4879 .29289 Mdot
.54137 .73449 Mdot
.52704 .37167 Mdot
.71155 .401 Mdot
.34965 .54906 Mdot
.48083 .37733 Mdot
.73036 .41234 Mdot
.28022 .59861 Mdot
.45538 .59985 Mdot
.68839 .61431 Mdot
.74423 .40735 Mdot
.72711 .42682 Mdot
.70213 .42627 Mdot
.45494 .78791 Mdot
.30226 .59564 Mdot
.73183 .29136 Mdot
.48716 .38102 Mdot
.6726 .34261 Mdot
.47393 .4169 Mdot
.54657 .72118 Mdot
.70499 .59764 Mdot
.48967 .35642 Mdot
.48665 .38151 Mdot
.35998 .26645 Mdot
.44919 .41564 Mdot
.43914 .41153 Mdot
.37406 .56041 Mdot
.40512 .5671 Mdot
.70459 .58237 Mdot
.76317 .68429 Mdot
.32807 .20825 Mdot
.43167 .32436 Mdot
.5821 .42759 Mdot
.34283 .58803 Mdot
.50439 .68458 Mdot
.60062 .36248 Mdot
.47462 .6603 Mdot
.36332 .56186 Mdot
.42747 .3781 Mdot
.34513 .27829 Mdot
.71074 .40835 Mdot
.47904 .34979 Mdot
.52982 .7083 Mdot
.48024 .34987 Mdot
.52591 .73987 Mdot
.314 .50346 Mdot
.54731 .46157 Mdot
.48198 .38814 Mdot
.42271 .33777 Mdot
.49032 .26097 Mdot
.46956 .35925 Mdot
.63021 .68426 Mdot
.35239 .56907 Mdot
.4027 .4191 Mdot
.43895 .40164 Mdot
.34657 .3947 Mdot
.45429 .33069 Mdot
.50199 .52318 Mdot
.44889 .36217 Mdot
.56537 .19601 Mdot
.50689 .35881 Mdot
.44634 .36095 Mdot
.51845 .68825 Mdot
.52444 .67921 Mdot
.33077 .51274 Mdot
.47001 .60929 Mdot
.4151 .6425 Mdot
.45895 .33375 Mdot
.69267 .56017 Mdot
.55162 .40957 Mdot
.73167 .42493 Mdot
.35147 .55085 Mdot
.51079 .89102 Mdot
.5497 .69869 Mdot
.6384 .61743 Mdot
.56863 .56108 Mdot
.67024 .63245 Mdot
.65961 .64184 Mdot
.38649 .53319 Mdot
.71765 .43885 Mdot
.48017 .32647 Mdot
.33724 .37281 Mdot
.44156 .76709 Mdot
.43362 .35515 Mdot
.69403 .5538 Mdot
.56074 .33409 Mdot
.70915 .35806 Mdot
.74287 .40085 Mdot
.7154 .42883 Mdot
.51641 .69385 Mdot
.71064 .58599 Mdot
.47257 .30279 Mdot
.70899 .44689 Mdot
.70383 .59342 Mdot
.42851 .58542 Mdot
.73045 .37429 Mdot
.3362 .5519 Mdot
.28635 .51294 Mdot
.40653 .49653 Mdot
.5462 .69339 Mdot
.57122 .76099 Mdot
.29153 .56639 Mdot
.36785 .59303 Mdot
.46395 .61253 Mdot
.6639 .62436 Mdot
.30146 .58526 Mdot
.49336 .37403 Mdot
.43886 .43187 Mdot
.48312 .33096 Mdot
.74465 .44263 Mdot
.46075 .32827 Mdot
.69775 .60319 Mdot
.50776 .69034 Mdot
.65118 .60482 Mdot
.50552 .6992 Mdot
.34336 .22575 Mdot
.50428 .36334 Mdot
.47369 .36278 Mdot
.59391 .41748 Mdot
.35633 .54858 Mdot
.32661 .3799 Mdot
.64052 .61012 Mdot
.64653 .60717 Mdot
.43338 .39525 Mdot
.38555 .57258 Mdot
.76556 .45219 Mdot
.60564 .38093 Mdot
.4487 .35745 Mdot
.35251 .57049 Mdot
.43253 .39526 Mdot
.58537 .68411 Mdot
.51394 .49045 Mdot
.32809 .53829 Mdot
.61439 .18025 Mdot
.49913 .37641 Mdot
.39516 .36342 Mdot
.40904 .31829 Mdot
.495 .21916 Mdot
.50803 .41076 Mdot
.30987 .56724 Mdot
.50574 .38715 Mdot
.34152 .5751 Mdot
.66351 .60542 Mdot
.55471 .70519 Mdot
.34184 .57156 Mdot
.46415 .38539 Mdot
.3343 .20589 Mdot
.50764 .68895 Mdot
.48244 .35525 Mdot
.53283 .69476 Mdot
.32276 .59782 Mdot
.37184 .56913 Mdot
.42602 .58971 Mdot
.55857 .54921 Mdot
.50568 .71067 Mdot
.42867 .35699 Mdot
.42443 .77653 Mdot
.42876 .39088 Mdot
.6757 .55122 Mdot
.41728 .34431 Mdot
.46139 .31311 Mdot
.5679 .16243 Mdot
.51505 .53494 Mdot
.65395 .80193 Mdot
.49722 .64403 Mdot
.41617 .77735 Mdot
.37466 .53175 Mdot
.74234 .40068 Mdot
.47477 .53717 Mdot
.44516 .58583 Mdot
.68441 .62745 Mdot
.49098 .36035 Mdot
.29812 .62042 Mdot
.49674 .73281 Mdot
.73845 .4272 Mdot
.48624 .38795 Mdot
.69761 .62752 Mdot
.43091 .50086 Mdot
.50051 .71203 Mdot
.33802 .54999 Mdot
.36541 .55876 Mdot
.7547 .35554 Mdot
.47712 .3773 Mdot
.47185 .36816 Mdot
.5065 .68783 Mdot
.48777 .30271 Mdot
.70485 .43136 Mdot
.55873 .62242 Mdot
.5317 .70702 Mdot
.51931 .4907 Mdot
.38052 .57113 Mdot
.45816 .35468 Mdot
.59707 .41295 Mdot
.3718 .76576 Mdot
.21146 .47774 Mdot
.71683 .42019 Mdot
.56742 .27996 Mdot
.30924 .56588 Mdot
.52868 .70298 Mdot
.64098 .27709 Mdot
.41335 .37911 Mdot
.45756 .34915 Mdot
.53706 .238 Mdot
.60428 .37872 Mdot
.56417 .55911 Mdot
.49381 .2905 Mdot
.61152 .35149 Mdot
.43259 .39436 Mdot
.45482 .40126 Mdot
.46824 .31198 Mdot
.41533 .35102 Mdot
.35043 .5746 Mdot
.35192 .41397 Mdot
.68392 .59885 Mdot
.22785 .47215 Mdot
.68801 .54687 Mdot
.45712 .38861 Mdot
.43123 .38452 Mdot
.26922 .45022 Mdot
.57807 .37946 Mdot
.34698 .56169 Mdot
.39535 .55453 Mdot
.54107 .68457 Mdot
.44121 .41124 Mdot
.64022 .61415 Mdot
.41422 .3141 Mdot
.67339 .61375 Mdot
.35236 .57403 Mdot
.66208 .57476 Mdot
.49679 .68075 Mdot
.68342 .57639 Mdot
.67122 .62754 Mdot
.4971 .70201 Mdot
.37212 .58149 Mdot
.4444 .35247 Mdot
.4957 .70556 Mdot
.77136 .44503 Mdot
.74507 .44166 Mdot
.41931 .57553 Mdot
.50994 .39668 Mdot
.43656 .41587 Mdot
.57304 .77432 Mdot
.66153 .57878 Mdot
.55622 .43984 Mdot
.35409 .58616 Mdot
.7443 .44874 Mdot
.34736 .57666 Mdot
.72861 .32475 Mdot
.72164 .41957 Mdot
.42195 .58332 Mdot
.61266 .27956 Mdot
.52374 .75176 Mdot
.42119 .32518 Mdot
.40531 .571 Mdot
.66828 .61341 Mdot
.51401 .73886 Mdot
.43506 .64107 Mdot
.49928 .39556 Mdot
.4642 .58303 Mdot
.33331 .60093 Mdot
.45076 .58745 Mdot
.52797 .7064 Mdot
.41375 .52399 Mdot
.46839 .37599 Mdot
.526 .75067 Mdot
.42189 .33614 Mdot
.32713 .48492 Mdot
.6276 .56998 Mdot
.36804 .62217 Mdot
.42996 .38628 Mdot
.68076 .62073 Mdot
.43106 .39007 Mdot
.25278 .52427 Mdot
.6184 .30476 Mdot
.46119 .31104 Mdot
.5771 .34354 Mdot
.58682 .75931 Mdot
.35337 .58112 Mdot
.51174 .4187 Mdot
.46431 .60453 Mdot
.45028 .39346 Mdot
.15525 .39094 Mdot
.73498 .41588 Mdot
.75989 .40253 Mdot
.47008 .38572 Mdot
.48623 .37407 Mdot
.36639 .26246 Mdot
.33211 .50074 Mdot
.4281 .5915 Mdot
.46103 .34465 Mdot
.51066 .23163 Mdot
.51909 .68981 Mdot
.41883 .35763 Mdot
.49527 .34407 Mdot
.65619 .53993 Mdot
.52583 .69014 Mdot
.67943 .57217 Mdot
.45128 .58676 Mdot
.67821 .56351 Mdot
.69596 .42801 Mdot
.5743 .30003 Mdot
.57825 .27893 Mdot
.50025 .48783 Mdot
.74375 .40827 Mdot
.44927 .38488 Mdot
.38547 .6166 Mdot
.46593 .37997 Mdot
.7195 .43401 Mdot
.53501 .70168 Mdot
.34908 .56997 Mdot
.30816 .50037 Mdot
.45383 .60795 Mdot
.43788 .36604 Mdot
.75381 .41828 Mdot
.33702 .56663 Mdot
.34436 .76395 Mdot
.36297 .57472 Mdot
.50704 .70114 Mdot
.51274 .74479 Mdot
.72694 .42175 Mdot
.34822 .57735 Mdot
.6715 .56558 Mdot
.49965 .65058 Mdot
.43104 .314 Mdot
.49795 .67886 Mdot
.2965 .56318 Mdot
.30499 .54594 Mdot
.34874 .53537 Mdot
.44218 .40212 Mdot
.58633 .39128 Mdot
.469 .27984 Mdot
.50776 .68803 Mdot
.69681 .62507 Mdot
.6378 .33852 Mdot
.34808 .33121 Mdot
.53348 .48021 Mdot
.50074 .42484 Mdot
.4629 .32784 Mdot
.48072 .33035 Mdot
.4797 .40922 Mdot
.53656 .61687 Mdot
.50405 .36262 Mdot
.53381 .68813 Mdot
.67773 .60773 Mdot
.45051 .35538 Mdot
.46372 .59737 Mdot
.56235 .58138 Mdot
.73216 .45998 Mdot
.34364 .45757 Mdot
.41127 .57195 Mdot
.33906 .56711 Mdot
.66834 .58028 Mdot
.66365 .57249 Mdot
.72754 .45392 Mdot
.49889 .71686 Mdot
.36709 .57121 Mdot
.56959 .19702 Mdot
.70472 .41468 Mdot
.48272 .33511 Mdot
.59528 .41601 Mdot
.47424 .21819 Mdot
.45327 .32206 Mdot
.49141 .34949 Mdot
.47281 .60706 Mdot
.64367 .62276 Mdot
.18306 .50516 Mdot
.26411 .67437 Mdot
.73203 .42021 Mdot
.71659 .44752 Mdot
.33877 .52953 Mdot
.43984 .33902 Mdot
.51317 .7139 Mdot
.59028 .32179 Mdot
.5861 .7353 Mdot
.39227 .64559 Mdot
.59688 .70545 Mdot
.47242 .32409 Mdot
.31491 .4632 Mdot
.41785 .33654 Mdot
.33927 .60527 Mdot
.3651 .54732 Mdot
.34073 .55719 Mdot
.51485 .69047 Mdot
.6869 .33997 Mdot
.53981 .69117 Mdot
.41985 .61546 Mdot
.31045 .55823 Mdot
.53068 .53904 Mdot
.64527 .60796 Mdot
.46464 .41815 Mdot
.71755 .43742 Mdot
.67553 .46743 Mdot
.50843 .42268 Mdot
.56987 .28627 Mdot
.68704 .57446 Mdot
.35829 .58842 Mdot
.46947 .41687 Mdot
.42224 .64534 Mdot
.57711 .43474 Mdot
.5992 .74595 Mdot
.31023 .62289 Mdot
.72789 .41082 Mdot
.22377 .43604 Mdot
.70465 .4236 Mdot
.50327 .71701 Mdot
.4999 .37428 Mdot
.443 .33801 Mdot
.49669 .35306 Mdot
.41798 .37997 Mdot
.52349 .69359 Mdot
.43628 .31205 Mdot
.66831 .381 Mdot
.43236 .58885 Mdot
.54339 .58666 Mdot
.74503 .42713 Mdot
.54187 .72388 Mdot
.67268 .6086 Mdot
.46084 .61371 Mdot
.75601 .43191 Mdot
.47734 .41409 Mdot
.46363 .38345 Mdot
.43053 .58951 Mdot
.5251 .40429 Mdot
.45592 .42593 Mdot
.68823 .60274 Mdot
.55999 .56939 Mdot
.72354 .45789 Mdot
.71098 .41849 Mdot
.52346 .73506 Mdot
.34721 .57709 Mdot
.72177 .4556 Mdot
.71396 .59474 Mdot
.4201 .36203 Mdot
.42455 .33274 Mdot
.29714 .5596 Mdot
.67622 .34036 Mdot
.73289 .46006 Mdot
.5269 .3753 Mdot
.34185 .54414 Mdot
.33464 .60113 Mdot
.4622 .34504 Mdot
.4716 .30718 Mdot
.34439 .52797 Mdot
.72722 .45221 Mdot
.53113 .73243 Mdot
.54672 .49284 Mdot
.54805 .70276 Mdot
.33049 .54778 Mdot
.43526 .43046 Mdot
.37664 .58023 Mdot
.49777 .39656 Mdot
.66217 .81622 Mdot
.50392 .35499 Mdot
.37562 .37931 Mdot
.64107 .51046 Mdot
.6444 .61275 Mdot
.65264 .62047 Mdot
.45761 .59436 Mdot
.32558 .58631 Mdot
.50437 .4312 Mdot
.71535 .4394 Mdot
.41674 .77713 Mdot
.29648 .53061 Mdot
.67091 .62695 Mdot
.63711 .61264 Mdot
.53353 .69944 Mdot
.45708 .32901 Mdot
.45697 .35722 Mdot
.68207 .57562 Mdot
.59365 .64309 Mdot
.33761 .57992 Mdot
.47229 .36818 Mdot
.47137 .40944 Mdot
.68222 .60082 Mdot
.48375 .72181 Mdot
.29422 .57431 Mdot
.44497 .40314 Mdot
.6137 .30747 Mdot
.54109 .72978 Mdot
.44188 .3853 Mdot
.41849 .32829 Mdot
.73044 .4297 Mdot
.5591 .26499 Mdot
.6676 .34111 Mdot
.54453 .68331 Mdot
.45843 .58927 Mdot
.45765 .32205 Mdot
.64797 .61507 Mdot
.5046 .40753 Mdot
.24185 .71609 Mdot
.43478 .58555 Mdot
.467 .37381 Mdot
.49278 .31273 Mdot
.32987 .54284 Mdot
.4786 .37359 Mdot
.5728 .69518 Mdot
.68514 .58461 Mdot
.46546 .37363 Mdot
.37944 .24964 Mdot
.53316 .70048 Mdot
.51004 .41999 Mdot
.71835 .40642 Mdot
.5559 .55128 Mdot
.30628 .24651 Mdot
.72098 .58553 Mdot
.74276 .41727 Mdot
.45559 .33141 Mdot
.70364 .565 Mdot
.49923 .68707 Mdot
.39494 .30846 Mdot
.44521 .38315 Mdot
.54617 .69728 Mdot
.50532 .69372 Mdot
.72852 .41815 Mdot
.60535 .85268 Mdot
.46646 .31051 Mdot
.47543 .35286 Mdot
.48213 .84027 Mdot
.34169 .52554 Mdot
.4831 .35354 Mdot
.44924 .33882 Mdot
.50866 .73112 Mdot
.69865 .30843 Mdot
.56727 .28046 Mdot
.55489 .62282 Mdot
.53462 .73517 Mdot
.67146 .55888 Mdot
.69124 .58273 Mdot
.73976 .41333 Mdot
.35844 .56882 Mdot
.74192 .44945 Mdot
.67643 .59298 Mdot
.49406 .35032 Mdot
.52685 .72683 Mdot
.24708 .33783 Mdot
.49542 .7207 Mdot
.71464 .60467 Mdot
.3342 .60373 Mdot
.2185 .54391 Mdot
.2689 .75357 Mdot
.41584 .48629 Mdot
.53838 .73918 Mdot
.73178 .42521 Mdot
.27809 .69938 Mdot
.44986 .35574 Mdot
.27894 .50051 Mdot
.47773 .35077 Mdot
.283 .60809 Mdot
.70463 .59685 Mdot
.42701 .58643 Mdot
.49909 .3962 Mdot
.56414 .27635 Mdot
.49798 .70336 Mdot
.52054 .71859 Mdot
.50515 .38792 Mdot
.50658 .70371 Mdot
.45965 .36363 Mdot
.67729 .60424 Mdot
.63442 .8269 Mdot
.44988 .36885 Mdot
.39368 .38701 Mdot
.54305 .73849 Mdot
.41632 .5667 Mdot
.64341 .57181 Mdot
.34067 .42814 Mdot
.39659 .65156 Mdot
.51348 .71213 Mdot
.35361 .45561 Mdot
.65998 .58296 Mdot
.46467 .61442 Mdot
.66901 .56203 Mdot
.4682 .35028 Mdot
.46742 .32366 Mdot
.48406 .40876 Mdot
.45258 .33569 Mdot
.26252 .49839 Mdot
.46302 .42682 Mdot
.26306 .37414 Mdot
.4867 .38097 Mdot
.37897 .39792 Mdot
.53837 .692 Mdot
.39603 .35602 Mdot
.56423 .49868 Mdot
.49736 .33654 Mdot
.38668 .53824 Mdot
.54345 .72067 Mdot
.46173 .715 Mdot
.52353 .69183 Mdot
.65116 .60683 Mdot
.5002 .70215 Mdot
.50006 .38246 Mdot
.3466 .55187 Mdot
.6671 .58742 Mdot
.41299 .47928 Mdot
.69832 .6216 Mdot
.47266 .37771 Mdot
.52648 .75416 Mdot
.64281 .59718 Mdot
.42886 .40847 Mdot
.35106 .55394 Mdot
.54208 .22499 Mdot
.362 .60781 Mdot
.48248 .3689 Mdot
.48461 .36345 Mdot
.42963 .59128 Mdot
.49924 .7078 Mdot
.38278 .5715 Mdot
.65889 .53478 Mdot
.75146 .44154 Mdot
.35212 .56301 Mdot
.40642 .32068 Mdot
.58425 .42734 Mdot
.32839 .54026 Mdot
.49567 .22615 Mdot
.50549 .72256 Mdot
.31145 .54752 Mdot
.43966 .29439 Mdot
.2314 .4668 Mdot
.70841 .41834 Mdot
.66268 .56858 Mdot
.61492 .36794 Mdot
.68976 .58321 Mdot
.56897 .70147 Mdot
.63228 .59951 Mdot
.5279 .68859 Mdot
.5607 .3816 Mdot
.54418 .5323 Mdot
.49863 .73003 Mdot
.55401 .72733 Mdot
.68799 .59507 Mdot
.50043 .40211 Mdot
.5468 .57383 Mdot
.50203 .43469 Mdot
.44559 .43955 Mdot
.54998 .70409 Mdot
.30756 .5543 Mdot
.3769 .58431 Mdot
.41089 .43359 Mdot
.36762 .55751 Mdot
.66357 .59646 Mdot
.48602 .48537 Mdot
.35814 .46764 Mdot
.53658 .70638 Mdot
.57191 .5679 Mdot
.43311 .38967 Mdot
.69176 .60851 Mdot
.66119 .59905 Mdot
.50679 .69359 Mdot
.22995 .49498 Mdot
.47735 .44392 Mdot
.33005 .51983 Mdot
.31384 .54946 Mdot
.3258 .54168 Mdot
.38075 .56348 Mdot
.68927 .33789 Mdot
.51444 .73881 Mdot
.31971 .58054 Mdot
.42112 .38499 Mdot
.44703 .33333 Mdot
.44278 .5928 Mdot
.7355 .44805 Mdot
.41535 .38285 Mdot
.50543 .43032 Mdot
.46141 .34653 Mdot
.64293 .61032 Mdot
.54 .28931 Mdot
.4342 .59012 Mdot
.64173 .61893 Mdot
.64357 .61853 Mdot
.45759 .59059 Mdot
.56269 .36887 Mdot
.18934 .50535 Mdot
.50421 .3851 Mdot
.38969 .53654 Mdot
.65748 .62104 Mdot
.65556 .44536 Mdot
.38662 .4327 Mdot
.42957 .34794 Mdot
.55861 .60718 Mdot
.67067 .60313 Mdot
.37206 .53111 Mdot
.46889 .35466 Mdot
.46334 .61144 Mdot
.71208 .41198 Mdot
.43698 .27916 Mdot
.47224 .60742 Mdot
.34735 .58107 Mdot
.72621 .5531 Mdot
.30318 .55763 Mdot
.64644 .58451 Mdot
.50645 .42606 Mdot
.80527 .71982 Mdot
.66513 .61257 Mdot
.42926 .78557 Mdot
.54485 .53454 Mdot
.45443 .37255 Mdot
.67623 .58056 Mdot
.30374 .52829 Mdot
.54199 .72941 Mdot
.59172 .4001 Mdot
.35575 .57971 Mdot
.45928 .6136 Mdot
.44597 .5943 Mdot
.68411 .59976 Mdot
.31627 .55435 Mdot
.42476 .32093 Mdot
.36449 .55922 Mdot
.52768 .72271 Mdot
.48535 .39694 Mdot
.41385 .6429 Mdot
.40035 .39501 Mdot
.3586 .55341 Mdot
.70664 .6171 Mdot
.70079 .40901 Mdot
.46423 .38757 Mdot
.45553 .68795 Mdot
.45409 .33168 Mdot
.53399 .69661 Mdot
.64232 .48752 Mdot
.2502 .33938 Mdot
.47825 .33694 Mdot
.43372 .38906 Mdot
.49707 .68284 Mdot
.47675 .33767 Mdot
.44331 .32267 Mdot
.41226 .52277 Mdot
.33059 .54033 Mdot
.45121 .35218 Mdot
.69923 .58746 Mdot
.30483 .28337 Mdot
.49807 .36752 Mdot
.57439 .6964 Mdot
.53108 .22925 Mdot
.62561 .46308 Mdot
.45763 .45041 Mdot
.6043 .31207 Mdot
.48188 .36007 Mdot
.43145 .34719 Mdot
.50458 .38628 Mdot
.31233 .46925 Mdot
.68199 .59215 Mdot
.68806 .61859 Mdot
.72399 .40072 Mdot
.53014 .23239 Mdot
.71918 .41408 Mdot
.49248 .69496 Mdot
.56596 .55799 Mdot
.43586 .59654 Mdot
.34551 .5769 Mdot
.49689 .36323 Mdot
.70208 .61652 Mdot
.46024 .355 Mdot
.44774 .39213 Mdot
.66809 .59618 Mdot
.66403 .60305 Mdot
.72322 .59172 Mdot
.70988 .40798 Mdot
.34374 .56355 Mdot
.50257 .37522 Mdot
.70216 .41656 Mdot
.47227 .41085 Mdot
.54967 .47794 Mdot
.34404 .56166 Mdot
.35965 .5533 Mdot
.35526 .59472 Mdot
.449 .37516 Mdot
.49767 .39283 Mdot
.54042 .69158 Mdot
.29715 .56045 Mdot
.50774 .715 Mdot
.67823 .58042 Mdot
.69451 .6031 Mdot
.46878 .34978 Mdot
.49428 .30805 Mdot
.74465 .43357 Mdot
.65199 .58621 Mdot
.46379 .5869 Mdot
.72225 .40238 Mdot
.48328 .32981 Mdot
.68484 .58114 Mdot
.75038 .42626 Mdot
.2133 .49692 Mdot
.33714 .65186 Mdot
.71683 .40062 Mdot
.50463 .39191 Mdot
.34859 .3136 Mdot
.62488 .31404 Mdot
.73943 .45907 Mdot
.53901 .69762 Mdot
.44564 .34509 Mdot
.54104 .63108 Mdot
.70555 .44462 Mdot
.66219 .33729 Mdot
.66971 .59202 Mdot
.41837 .42217 Mdot
.47275 .26878 Mdot
.36464 .47069 Mdot
.69797 .41516 Mdot
.3552 .55191 Mdot
.32389 .53532 Mdot
.4821 .33587 Mdot
.56114 .55422 Mdot
.49057 .70428 Mdot
.66472 .57176 Mdot
.69294 .61821 Mdot
.33237 .53545 Mdot
.5045 .48901 Mdot
.69751 .58542 Mdot
.43789 .34313 Mdot
.69697 .44214 Mdot
.43634 .40826 Mdot
.72906 .34884 Mdot
.29089 .27852 Mdot
.44684 .44738 Mdot
.70374 .40547 Mdot
.49929 .69075 Mdot
.51345 .68846 Mdot
.51055 .69502 Mdot
.69471 .59796 Mdot
.60273 .36168 Mdot
.70093 .61143 Mdot
.43899 .82245 Mdot
.73413 .41337 Mdot
.59293 .2093 Mdot
.41289 .36233 Mdot
.45638 .37413 Mdot
.42277 .37175 Mdot
.4765 .40735 Mdot
.48061 .36072 Mdot
.54397 .69101 Mdot
.69081 .5631 Mdot
.59104 .72167 Mdot
.3222 .56642 Mdot
.33754 .75974 Mdot
.64486 .60648 Mdot
.4733 .60468 Mdot
.73634 .44088 Mdot
.55562 .24943 Mdot
.69312 .40694 Mdot
.65211 .58327 Mdot
.4688 .31597 Mdot
.33424 .52807 Mdot
.56045 .19433 Mdot
.49003 .37184 Mdot
.65669 .58177 Mdot
.69156 .556 Mdot
.22421 .48201 Mdot
.50906 .30325 Mdot
.59722 .62802 Mdot
.58265 .42298 Mdot
.72131 .39718 Mdot
.51527 .39194 Mdot
.58558 .30748 Mdot
.67803 .59421 Mdot
.66789 .6182 Mdot
.74615 .4525 Mdot
.26411 .55287 Mdot
.31663 .57433 Mdot
.42437 .57842 Mdot
.54386 .70817 Mdot
.46101 .38049 Mdot
.69213 .59122 Mdot
.39784 .59237 Mdot
.58324 .45285 Mdot
.5201 .69714 Mdot
.63807 .61347 Mdot
.45164 .33331 Mdot
.47551 .33482 Mdot
.72236 .41379 Mdot
.61561 .5345 Mdot
.5018 .43483 Mdot
.4193 .77855 Mdot
.54187 .46096 Mdot
.54648 .53543 Mdot
.45728 .34946 Mdot
.37853 .57073 Mdot
.45777 .59155 Mdot
.7223 .44104 Mdot
.49738 .41165 Mdot
.22132 .56643 Mdot
.31606 .58273 Mdot
.50757 .71281 Mdot
.46588 .59474 Mdot
.57599 .30923 Mdot
.45265 .33351 Mdot
.47714 .35078 Mdot
.44046 .4014 Mdot
.20318 .53904 Mdot
.70245 .60194 Mdot
.37853 .5632 Mdot
.72352 .40722 Mdot
.3706 .57055 Mdot
.63556 .5998 Mdot
.56982 .56949 Mdot
.50587 .37107 Mdot
.33325 .59343 Mdot
.36625 .5662 Mdot
.53417 .70197 Mdot
.49541 .70491 Mdot
.71657 .58044 Mdot
.44928 .34276 Mdot
.43679 .59867 Mdot
.31112 .56813 Mdot
.67822 .56669 Mdot
.722 .41516 Mdot
.56909 .69393 Mdot
.4843 .38247 Mdot
.68337 .59701 Mdot
.50902 .42466 Mdot
.3266 .56293 Mdot
.64605 .59566 Mdot
.4693 .61432 Mdot
.72919 .45113 Mdot
.46276 .323 Mdot
.60177 .72323 Mdot
.46694 .60967 Mdot
.45694 .38352 Mdot
.27993 .29397 Mdot
.56096 .55464 Mdot
.28459 .58872 Mdot
.7042 .58676 Mdot
.45388 .61003 Mdot
.36856 .55121 Mdot
.23516 .44642 Mdot
.67532 .61681 Mdot
.35066 .27762 Mdot
.53472 .5243 Mdot
.50313 .39175 Mdot
.35166 .58065 Mdot
.74495 .37749 Mdot
.39214 .76001 Mdot
.62981 .3247 Mdot
.46529 .36944 Mdot
.69043 .58367 Mdot
.71193 .41368 Mdot
.51889 .71928 Mdot
.5437 .66546 Mdot
.75292 .34509 Mdot
.65822 .62688 Mdot
.49742 .36239 Mdot
.30826 .55296 Mdot
.50629 .70896 Mdot
.35013 .26623 Mdot
.71161 .58711 Mdot
.69736 .58172 Mdot
.4225 .35151 Mdot
.71729 .41461 Mdot
.51869 .62872 Mdot
.69758 .60875 Mdot
.69312 .56213 Mdot
.41083 .51421 Mdot
.72875 .39866 Mdot
.4498 .40368 Mdot
.41059 .43338 Mdot
.41666 .35058 Mdot
.39424 .79303 Mdot
.45091 .60898 Mdot
.32335 .56924 Mdot
.48791 .35545 Mdot
.58274 .76733 Mdot
.67617 .61243 Mdot
.58106 .42402 Mdot
.48671 .72956 Mdot
.49587 .70718 Mdot
.68312 .58521 Mdot
.46446 .35942 Mdot
.48872 .68577 Mdot
.74093 .41759 Mdot
.45083 .40456 Mdot
.49737 .39577 Mdot
.2962 .55145 Mdot
.52906 .72463 Mdot
.30354 .28128 Mdot
.51829 .72253 Mdot
.51429 .73536 Mdot
.31159 .59543 Mdot
.48185 .33533 Mdot
.64758 .59746 Mdot
.69197 .63183 Mdot
.52523 .36941 Mdot
.6678 .46293 Mdot
.32679 .58358 Mdot
.62271 .62603 Mdot
.21781 .56725 Mdot
.43101 .32616 Mdot
.46168 .5869 Mdot
.33716 .62462 Mdot
.50905 .74344 Mdot
.48554 .34289 Mdot
.3399 .57526 Mdot
.70468 .57034 Mdot
.69507 .58809 Mdot
.41443 .38208 Mdot
.50916 .68968 Mdot
.74976 .43321 Mdot
.65926 .59727 Mdot
.54011 .49751 Mdot
.47039 .37529 Mdot
.47272 .66625 Mdot
.65764 .59584 Mdot
.34169 .20589 Mdot
.57747 .77322 Mdot
.32475 .54041 Mdot
.42806 .36934 Mdot
.31778 .53451 Mdot
.73722 .4065 Mdot
.64241 .57925 Mdot
.52837 .68549 Mdot
.53931 .36695 Mdot
.74847 .69614 Mdot
.69231 .59723 Mdot
.35121 .5732 Mdot
.494 .35526 Mdot
.3583 .4518 Mdot
.4489 .36097 Mdot
.69692 .30245 Mdot
.73303 .46107 Mdot
.56728 .71323 Mdot
.50793 .68736 Mdot
.43349 .38667 Mdot
.70293 .42682 Mdot
.70281 .62639 Mdot
.66929 .59596 Mdot
.72244 .74817 Mdot
.47185 .60951 Mdot
.65252 .64194 Mdot
.45127 .37718 Mdot
.67674 .56895 Mdot
.34829 .33256 Mdot
.50298 .69493 Mdot
.41991 .34228 Mdot
.65652 .63089 Mdot
.3514 .75341 Mdot
.58498 .42369 Mdot
.46804 .37316 Mdot
.48515 .30277 Mdot
.53054 .6926 Mdot
.27698 .69782 Mdot
.70672 .59037 Mdot
.47985 .41253 Mdot
.48564 .71334 Mdot
.54555 .41981 Mdot
.64481 .53775 Mdot
.34335 .56309 Mdot
.64604 .62934 Mdot
.53228 .73035 Mdot
.41366 .41811 Mdot
.74201 .44225 Mdot
.71445 .58737 Mdot
.68174 .62937 Mdot
.47361 .39563 Mdot
.45585 .41065 Mdot
.47362 .29657 Mdot
.3411 .58489 Mdot
.512 .73227 Mdot
.45246 .39751 Mdot
.55223 .46927 Mdot
.47224 .40616 Mdot
.51979 .73374 Mdot
.70091 .81988 Mdot
.46993 .31728 Mdot
.47846 .38318 Mdot
.34677 .4468 Mdot
.38334 .57354 Mdot
.33842 .54055 Mdot
.54088 .46913 Mdot
.44217 .35882 Mdot
.52633 .53756 Mdot
.3446 .56641 Mdot
.35627 .57457 Mdot
.52763 .53799 Mdot
.48611 .39464 Mdot
.4475 .57777 Mdot
.50593 .70724 Mdot
.49564 .70715 Mdot
.3306 .54299 Mdot
.43669 .40693 Mdot
.49946 .68755 Mdot
.26108 .4828 Mdot
.64695 .58964 Mdot
.58184 .30352 Mdot
.36673 .56279 Mdot
.60039 .41219 Mdot
.50355 .71888 Mdot
.37514 .21247 Mdot
.48737 .21741 Mdot
.44162 .31671 Mdot
.4817 .33702 Mdot
.727 .42867 Mdot
.53265 .39264 Mdot
.45464 .5889 Mdot
.50824 .69616 Mdot
.5369 .61581 Mdot
.34062 .55656 Mdot
.44348 .35748 Mdot
.63814 .34337 Mdot
.30875 .24829 Mdot
.38868 .39356 Mdot
.35897 .57027 Mdot
.34324 .5536 Mdot
.69414 .57642 Mdot
.65199 .58174 Mdot
.50529 .37053 Mdot
.52048 .68718 Mdot
.31559 .54318 Mdot
.52103 .73091 Mdot
.67623 .59389 Mdot
.64648 .60359 Mdot
.43711 .58808 Mdot
.46095 .44537 Mdot
.67819 .58724 Mdot
.57977 .70821 Mdot
.55169 .47065 Mdot
.29648 .56718 Mdot
.46763 .83552 Mdot
.39684 .20443 Mdot
.3231 .49121 Mdot
.71156 .41299 Mdot
.55877 .39134 Mdot
.5308 .6795 Mdot
.43549 .38946 Mdot
.47612 .34576 Mdot
.45017 .60328 Mdot
.52295 .67768 Mdot
.73641 .43406 Mdot
.49869 .70027 Mdot
.72229 .44451 Mdot
.68369 .62078 Mdot
.49621 .36781 Mdot
.49871 .34081 Mdot
.52154 .71725 Mdot
.67771 .57276 Mdot
.64251 .59815 Mdot
.70789 .42694 Mdot
.54911 .24244 Mdot
.68231 .59903 Mdot
.36753 .56418 Mdot
.31489 .29987 Mdot
.4457 .59565 Mdot
.46914 .35542 Mdot
.60199 .30721 Mdot
.24257 .42682 Mdot
.49133 .40707 Mdot
.46803 .60048 Mdot
.61189 .85128 Mdot
.49798 .3701 Mdot
.78856 .6547 Mdot
.43603 .59496 Mdot
.37755 .57972 Mdot
.65853 .58631 Mdot
.47108 .60714 Mdot
.52656 .27863 Mdot
.61273 .59442 Mdot
.52214 .38563 Mdot
.31817 .57694 Mdot
.35208 .59285 Mdot
.56524 .56929 Mdot
.39142 .79228 Mdot
.72243 .40718 Mdot
.73994 .42481 Mdot
.6802 .61435 Mdot
.55955 .67182 Mdot
.4288 .40022 Mdot
.73801 .42368 Mdot
.45597 .57195 Mdot
.4306 .38614 Mdot
.56092 .55637 Mdot
.54438 .57987 Mdot
.36302 .54986 Mdot
.39744 .3552 Mdot
.67805 .61371 Mdot
.35122 .5718 Mdot
.55225 .57028 Mdot
.4199 .35518 Mdot
.34286 .55961 Mdot
.50354 .72534 Mdot
.49541 .54388 Mdot
.36698 .55932 Mdot
.59097 .4072 Mdot
.51779 .71398 Mdot
.56632 .56128 Mdot
.63638 .25352 Mdot
.22556 .28356 Mdot
.51341 .68957 Mdot
.66128 .5801 Mdot
.69091 .59199 Mdot
.68089 .60251 Mdot
.35065 .58371 Mdot
.66424 .60725 Mdot
.319 .56995 Mdot
.559 .71061 Mdot
.54851 .25172 Mdot
.7243 .42123 Mdot
.71213 .37558 Mdot
.34024 .54705 Mdot
.42524 .81513 Mdot
.3988 .84218 Mdot
.46664 .40715 Mdot
.50119 .7329 Mdot
.70457 .40931 Mdot
.53084 .46575 Mdot
.72942 .43012 Mdot
.66115 .58226 Mdot
.57056 .29101 Mdot
.45862 .36312 Mdot
.39838 .63139 Mdot
.7124 .4141 Mdot
.35812 .57517 Mdot
.45402 .38755 Mdot
.64712 .63305 Mdot
.74007 .41168 Mdot
.70983 .42298 Mdot
.47885 .3597 Mdot
.36297 .58696 Mdot
.64808 .59157 Mdot
.54117 .68272 Mdot
.69043 .43716 Mdot
.51298 .31796 Mdot
.5012 .36053 Mdot
.48089 .31734 Mdot
.57296 .4333 Mdot
.54866 .65925 Mdot
.5175 .71175 Mdot
.65949 .34022 Mdot
.69317 .60695 Mdot
.63144 .32344 Mdot
.41385 .76309 Mdot
.75389 .38366 Mdot
.44934 .6077 Mdot
.44902 .60823 Mdot
.47615 .3712 Mdot
.28556 .75973 Mdot
.37975 .3618 Mdot
.49552 .74499 Mdot
.44987 .59936 Mdot
.64396 .59144 Mdot
.29997 .55663 Mdot
.47843 .27295 Mdot
.41361 .37423 Mdot
.53915 .68047 Mdot
.67497 .59791 Mdot
.23729 .71158 Mdot
.7319 .41296 Mdot
.52615 .47245 Mdot
.45072 .34003 Mdot
.4728 .36579 Mdot
.52295 .70213 Mdot
.5314 .68698 Mdot
.40935 .51093 Mdot
.62416 .44808 Mdot
.39788 .64739 Mdot
.53521 .67362 Mdot
.23597 .71081 Mdot
.30309 .62191 Mdot
.32672 .54979 Mdot
.45582 .58667 Mdot
.49315 .69927 Mdot
.48511 .3543 Mdot
.37875 .57984 Mdot
.38577 .33572 Mdot
.3846 .54752 Mdot
.55636 .55101 Mdot
.54601 .49303 Mdot
.46276 .32819 Mdot
.35823 .53964 Mdot
.35002 .56782 Mdot
.39013 .58423 Mdot
.4524 .59148 Mdot
.45854 .3463 Mdot
.48789 .4106 Mdot
.49922 .37305 Mdot
.39484 .46619 Mdot
.47851 .37403 Mdot
.40906 .76241 Mdot
.53653 .48256 Mdot
.77145 .49222 Mdot
.49221 .37566 Mdot
.50498 .72948 Mdot
.49451 .36501 Mdot
.70577 .43611 Mdot
.46497 .32073 Mdot
.55373 .54668 Mdot
.51089 .70476 Mdot
.24535 .53305 Mdot
.693 .55009 Mdot
.49844 .34317 Mdot
.74552 .41009 Mdot
.50304 .82153 Mdot
.65332 .34355 Mdot
.41261 .51667 Mdot
.36449 .55942 Mdot
.69798 .56165 Mdot
.48995 .71831 Mdot
.6499 .60711 Mdot
.42909 .31597 Mdot
.44278 .58477 Mdot
.56987 .16771 Mdot
.60826 .4122 Mdot
.48687 .35563 Mdot
.47253 .44426 Mdot
.36791 .55535 Mdot
.67251 .61235 Mdot
.31362 .50329 Mdot
.42563 .37981 Mdot
.73413 .45376 Mdot
.70022 .4283 Mdot
.69921 .65192 Mdot
.47211 .54486 Mdot
.36277 .35514 Mdot
.52126 .70374 Mdot
.69612 .59483 Mdot
.69733 .42329 Mdot
.4074 .57691 Mdot
.49099 .71057 Mdot
.50878 .74354 Mdot
.53058 .72405 Mdot
.46825 .37847 Mdot
.43932 .59059 Mdot
.48283 .56833 Mdot
.46748 .61187 Mdot
.418 .37047 Mdot
.6792 .62985 Mdot
.46507 .61406 Mdot
.72024 .42473 Mdot
.52639 .7351 Mdot
.64379 .60911 Mdot
.48496 .36625 Mdot
.33896 .56534 Mdot
.6983 .36227 Mdot
.58938 .77045 Mdot
.56248 .5554 Mdot
.56257 .55548 Mdot
.336 .59813 Mdot
.43989 .62234 Mdot
.56307 .68762 Mdot
.22586 .4742 Mdot
.75874 .46101 Mdot
.52301 .39849 Mdot
.73282 .54694 Mdot
.7027 .60908 Mdot
.6655 .58886 Mdot
.45681 .36711 Mdot
.69027 .56906 Mdot
.4456 .35624 Mdot
.70424 .58472 Mdot
.38884 .77004 Mdot
.41368 .34133 Mdot
.66382 .59459 Mdot
.51876 .31075 Mdot
.46401 .38723 Mdot
.37684 .56951 Mdot
.7098 .57953 Mdot
.44078 .31724 Mdot
.67299 .19219 Mdot
.53337 .70535 Mdot
.45096 .59166 Mdot
.55307 .52216 Mdot
.50132 .71014 Mdot
.31397 .56426 Mdot
.44153 .34528 Mdot
.7344 .41138 Mdot
.33097 .54829 Mdot
.61925 .60724 Mdot
.71327 .41672 Mdot
.48535 .48686 Mdot
.3291 .54517 Mdot
.44396 .59756 Mdot
.72496 .45158 Mdot
.52235 .38403 Mdot
.66646 .59035 Mdot
.58114 .77525 Mdot
.47015 .6021 Mdot
.45804 .35907 Mdot
.63808 .62494 Mdot
.49871 .70302 Mdot
.49178 .33908 Mdot
.69325 .59032 Mdot
.46144 .5912 Mdot
.47475 .38632 Mdot
.44641 .37503 Mdot
.27116 .53876 Mdot
.64859 .4975 Mdot
.72232 .42248 Mdot
.33042 .60217 Mdot
.41824 .37888 Mdot
.70342 .42415 Mdot
.5994 .68786 Mdot
.42268 .31406 Mdot
.31423 .57665 Mdot
.24818 .48683 Mdot
.66898 .57069 Mdot
.50458 .69067 Mdot
.71333 .60841 Mdot
.72899 .40102 Mdot
.46098 .86931 Mdot
.45083 .58727 Mdot
.49829 .32432 Mdot
.43966 .3235 Mdot
.65501 .56886 Mdot
.35022 .56531 Mdot
.39629 .64605 Mdot
.45812 .32363 Mdot
.43648 .42859 Mdot
.47396 .35699 Mdot
.60588 .6992 Mdot
.34608 .58471 Mdot
.47149 .35549 Mdot
.5259 .34803 Mdot
.42667 .33095 Mdot
.7485 .42449 Mdot
.58918 .20519 Mdot
.49695 .40141 Mdot
.85805 .65889 Mdot
.4349 .58242 Mdot
.66961 .59923 Mdot
.58723 .41207 Mdot
.56271 .52277 Mdot
.8048 .38911 Mdot
.31908 .5746 Mdot
.397 .55055 Mdot
.64757 .60159 Mdot
.75568 .36741 Mdot
.44933 .62504 Mdot
.44767 .38025 Mdot
.44745 .33958 Mdot
.66106 .58234 Mdot
.67578 .56646 Mdot
.43963 .58264 Mdot
.50961 .38007 Mdot
.39901 .38657 Mdot
.70345 .62006 Mdot
.48656 .37394 Mdot
.24483 .40244 Mdot
.53103 .74044 Mdot
.33191 .54178 Mdot
.52128 .71936 Mdot
.53783 .73454 Mdot
.30981 .49994 Mdot
.54682 .45555 Mdot
.54533 .7033 Mdot
.51359 .74967 Mdot
.73507 .37433 Mdot
.35896 .4654 Mdot
.74864 .42804 Mdot
.45116 .51691 Mdot
.6856 .60681 Mdot
.45996 .34483 Mdot
.35033 .585 Mdot
.72713 .29191 Mdot
.40086 .6686 Mdot
.50238 .25203 Mdot
.44748 .40253 Mdot
.67942 .61002 Mdot
.46823 .59722 Mdot
.42136 .31473 Mdot
.62675 .31699 Mdot
.46924 .36898 Mdot
.65832 .5754 Mdot
.35914 .46792 Mdot
.54897 .77894 Mdot
.54272 .67479 Mdot
.3122 .52387 Mdot
.4954 .36386 Mdot
.3336 .57806 Mdot
.54785 .71216 Mdot
.70611 .41385 Mdot
.73186 .42368 Mdot
.4969 .33984 Mdot
.54416 .53431 Mdot
.79136 .40783 Mdot
.45057 .3829 Mdot
.47877 .39604 Mdot
.4515 .60825 Mdot
.4803 .39636 Mdot
.49939 .40761 Mdot
.45024 .39814 Mdot
.46723 .41109 Mdot
.4916 .70519 Mdot
.34145 .48939 Mdot
.51096 .36687 Mdot
.47769 .31028 Mdot
.55457 .70788 Mdot
.44956 .30628 Mdot
.52144 .69113 Mdot
.41674 .65654 Mdot
.54359 .70294 Mdot
.73045 .42273 Mdot
.6386 .62717 Mdot
.37135 .50905 Mdot
.31566 .54354 Mdot
.49867 .72305 Mdot
.72987 .4484 Mdot
.51095 .6926 Mdot
.69947 .59693 Mdot
.57366 .76449 Mdot
.29114 .58548 Mdot
.53055 .49907 Mdot
.34523 .45911 Mdot
.46966 .71141 Mdot
.68928 .57126 Mdot
.32297 .54152 Mdot
.57171 .69301 Mdot
.43518 .38768 Mdot
.72821 .409 Mdot
.47605 .37046 Mdot
.52172 .73637 Mdot
.68228 .60807 Mdot
.4134 .54452 Mdot
.72269 .42365 Mdot
.5048 .84842 Mdot
.70343 .61548 Mdot
.45183 .31953 Mdot
.55413 .70566 Mdot
.58527 .71701 Mdot
.53281 .69193 Mdot
.54979 .25139 Mdot
.38211 .61923 Mdot
.73701 .31156 Mdot
.33994 .55049 Mdot
.47802 .60729 Mdot
.18883 .3648 Mdot
.44901 .73667 Mdot
.33106 .56362 Mdot
.72734 .56198 Mdot
.47841 .37727 Mdot
.45942 .40384 Mdot
.45915 .44335 Mdot
.38862 .5647 Mdot
.43982 .40105 Mdot
.44708 .58954 Mdot
.5509 .45613 Mdot
.49122 .59675 Mdot
.70812 .56679 Mdot
.44693 .35643 Mdot
.54989 .70307 Mdot
.49946 .72637 Mdot
.45807 .6141 Mdot
.52196 .7246 Mdot
.48865 .38806 Mdot
.33963 .54778 Mdot
.54772 .57316 Mdot
.73574 .40619 Mdot
.43992 .78184 Mdot
.77839 .4356 Mdot
.69225 .40477 Mdot
.42813 .32814 Mdot
.6462 .6015 Mdot
.75661 .6784 Mdot
.43778 .39469 Mdot
.34681 .56896 Mdot
.43959 .32452 Mdot
.45844 .40136 Mdot
.50259 .38122 Mdot
.69567 .59558 Mdot
.58933 .4213 Mdot
.48771 .37353 Mdot
.54637 .70686 Mdot
.52918 .53631 Mdot
.41543 .38121 Mdot
.56008 .62045 Mdot
.5541 .54805 Mdot
.47133 .67388 Mdot
.29509 .55872 Mdot
.65039 .59406 Mdot
.33964 .5546 Mdot
.36458 .53681 Mdot
.31403 .56369 Mdot
.48991 .58014 Mdot
.22988 .46509 Mdot
.79918 .64303 Mdot
.35016 .33813 Mdot
.33956 .46147 Mdot
.31487 .52481 Mdot
.66333 .68525 Mdot
.33284 .56853 Mdot
.31515 .56764 Mdot
.67838 .81485 Mdot
.34233 .58983 Mdot
.46768 .34952 Mdot
.49042 .3261 Mdot
.21739 .54098 Mdot
.68833 .40362 Mdot
.45616 .38096 Mdot
.47584 .41002 Mdot
.6987 .42646 Mdot
.28493 .52656 Mdot
.45287 .58339 Mdot
.5209 .47805 Mdot
.47546 .60643 Mdot
.47927 .36044 Mdot
.47513 .32806 Mdot
.49447 .41795 Mdot
.25696 .28117 Mdot
.75137 .32753 Mdot
.35589 .59346 Mdot
.52578 .38871 Mdot
.48422 .75291 Mdot
.43383 .34002 Mdot
.43316 .33014 Mdot
.50053 .38453 Mdot
.64744 .59767 Mdot
.3039 .5709 Mdot
.50435 .43197 Mdot
.4553 .77042 Mdot
.45646 .33202 Mdot
.78464 .41921 Mdot
.74577 .39825 Mdot
.46416 .35814 Mdot
.33978 .59097 Mdot
.45606 .40388 Mdot
.31292 .54022 Mdot
.32592 .5458 Mdot
.41869 .41632 Mdot
.47374 .56097 Mdot
.30065 .55627 Mdot
.44661 .37858 Mdot
.68012 .5719 Mdot
.42292 .78129 Mdot
.45914 .35902 Mdot
.71654 .42223 Mdot
.48842 .34448 Mdot
.74817 .41838 Mdot
.48695 .39989 Mdot
.46418 .61305 Mdot
.24243 .34835 Mdot
.67039 .61876 Mdot
.68962 .41523 Mdot
.68435 .56904 Mdot
.44214 .41594 Mdot
.30818 .53582 Mdot
.52908 .77811 Mdot
.76141 .34371 Mdot
.45012 .6073 Mdot
.67709 .34345 Mdot
.5219 .54856 Mdot
.53709 .68519 Mdot
.37869 .56112 Mdot
.35026 .47773 Mdot
.55896 .61686 Mdot
.70478 .56261 Mdot
.63717 .60898 Mdot
.66704 .52797 Mdot
.6348 .82681 Mdot
.48648 .37776 Mdot
.54917 .63251 Mdot
.2634 .3658 Mdot
.52961 .39835 Mdot
.4941 .29002 Mdot
.68578 .62861 Mdot
.45612 .38124 Mdot
.62004 .38826 Mdot
.68722 .59426 Mdot
.74264 .43248 Mdot
.32451 .57125 Mdot
.70981 .43732 Mdot
.34132 .66717 Mdot
.41091 .51999 Mdot
.68126 .58958 Mdot
.46057 .40976 Mdot
.45366 .37478 Mdot
.38363 .57128 Mdot
.35368 .26526 Mdot
.33126 .54041 Mdot
.72869 .40427 Mdot
.68223 .61673 Mdot
.62289 .18288 Mdot
.49364 .35135 Mdot
.36572 .56831 Mdot
.69468 .55019 Mdot
.47337 .33477 Mdot
.5056 .69136 Mdot
.437 .39867 Mdot
.36802 .57186 Mdot
.48047 .39666 Mdot
.33677 .54895 Mdot
.68899 .57604 Mdot
.49624 .33698 Mdot
.48402 .33093 Mdot
.66434 .34007 Mdot
.73522 .43464 Mdot
.30379 .54773 Mdot
.61829 .38336 Mdot
.41662 .35073 Mdot
.61584 .30869 Mdot
.49669 .36832 Mdot
.35571 .45832 Mdot
.43825 .29905 Mdot
.4446 .59026 Mdot
.43684 .32575 Mdot
.45979 .3606 Mdot
.36541 .26264 Mdot
.34769 .32664 Mdot
.39875 .47423 Mdot
.49512 .70438 Mdot
.36298 .58116 Mdot
.68874 .58966 Mdot
.70538 .56892 Mdot
.65855 .60612 Mdot
.74153 .46157 Mdot
.52569 .3619 Mdot
.4551 .35719 Mdot
.50722 .75372 Mdot
.73639 .41937 Mdot
.36114 .56706 Mdot
.72806 .41838 Mdot
.54908 .451 Mdot
.71618 .42629 Mdot
.45531 .5884 Mdot
.57878 .76883 Mdot
.24522 .41557 Mdot
.72359 .43928 Mdot
.32939 .54155 Mdot
.52221 .5298 Mdot
.5197 .4105 Mdot
.36169 .77496 Mdot
.7321 .45479 Mdot
.67458 .53406 Mdot
.48517 .38495 Mdot
.59433 .39497 Mdot
.52237 .6932 Mdot
.71073 .43873 Mdot
.53212 .72177 Mdot
.45427 .40327 Mdot
.27495 .54722 Mdot
.34896 .57588 Mdot
.53696 .73689 Mdot
.42333 .33865 Mdot
.7103 .43853 Mdot
.67577 .58876 Mdot
.36111 .46675 Mdot
.55101 .72453 Mdot
.69652 .36559 Mdot
.63092 .32503 Mdot
.68664 .61324 Mdot
.35682 .42179 Mdot
.54092 .70946 Mdot
.5243 .39217 Mdot
.4015 .30596 Mdot
.42584 .38739 Mdot
.64159 .60009 Mdot
.66455 .58874 Mdot
.4659 .70878 Mdot
.47934 .32791 Mdot
.51034 .358 Mdot
.30667 .58452 Mdot
.68756 .61447 Mdot
.31316 .56118 Mdot
.35227 .53905 Mdot
.66391 .57926 Mdot
.32705 .53828 Mdot
.71163 .41774 Mdot
.59437 .34288 Mdot
.54175 .70847 Mdot
.51057 .68699 Mdot
.68033 .5877 Mdot
.66855 .62452 Mdot
.64576 .60297 Mdot
.42333 .36571 Mdot
.31733 .54818 Mdot
.42955 .37136 Mdot
.49533 .36102 Mdot
.40894 .58875 Mdot
.30284 .58685 Mdot
.42691 .34594 Mdot
.54156 .58255 Mdot
.73809 .45489 Mdot
.66407 .59783 Mdot
.51445 .73101 Mdot
.71112 .35762 Mdot
.5454 .68977 Mdot
.4157 .34947 Mdot
.35781 .76024 Mdot
.35284 .58215 Mdot
.7283 .4297 Mdot
.55698 .54876 Mdot
.72431 .42626 Mdot
.53321 .73932 Mdot
.33597 .60025 Mdot
.49453 .48774 Mdot
.48264 .32857 Mdot
.57003 .43604 Mdot
.64459 .27914 Mdot
.4208 .76239 Mdot
.50851 .73029 Mdot
.46031 .4058 Mdot
.44109 .60081 Mdot
.22239 .47724 Mdot
.45546 .36069 Mdot
.42228 .32964 Mdot
.57458 .53801 Mdot
.44049 .32154 Mdot
.36293 .59486 Mdot
.55601 .55665 Mdot
.50501 .40044 Mdot
.44864 .41813 Mdot
.68792 .78445 Mdot
.46741 .38579 Mdot
.48998 .33395 Mdot
.46897 .34377 Mdot
.43045 .38348 Mdot
.31601 .53504 Mdot
.58358 .5616 Mdot
.54953 .71289 Mdot
.59442 .34243 Mdot
.53643 .71957 Mdot
.67595 .58286 Mdot
.63139 .42519 Mdot
.31492 .53756 Mdot
.7239 .42657 Mdot
.56264 .6402 Mdot
.56958 .29191 Mdot
.69201 .57531 Mdot
.69387 .33318 Mdot
.7462 .43959 Mdot
.51872 .41391 Mdot
.7273 .3998 Mdot
.66936 .63264 Mdot
.50953 .6899 Mdot
.46818 .31615 Mdot
.31074 .56562 Mdot
.36613 .55845 Mdot
.42386 .38843 Mdot
.45432 .78641 Mdot
.50099 .69271 Mdot
.65858 .43805 Mdot
.46205 .37551 Mdot
.41973 .34275 Mdot
.33222 .53857 Mdot
.67427 .61142 Mdot
.52344 .54704 Mdot
.73331 .44326 Mdot
.44115 .3353 Mdot
.47752 .40791 Mdot
.55197 .44855 Mdot
.49405 .71682 Mdot
.45777 .59877 Mdot
.45078 .35821 Mdot
.53085 .47405 Mdot
.43645 .39962 Mdot
.47547 .4209 Mdot
.66997 .5724 Mdot
.42696 .42239 Mdot
.46245 .32526 Mdot
.27228 .56202 Mdot
.53965 .71052 Mdot
.34627 .56391 Mdot
.39624 .55443 Mdot
.45948 .61242 Mdot
.53158 .70831 Mdot
.42584 .34429 Mdot
.50397 .73868 Mdot
.45922 .40277 Mdot
.48651 .36899 Mdot
.50631 .7285 Mdot
.31489 .55812 Mdot
.43298 .63892 Mdot
.34288 .48898 Mdot
.44825 .39323 Mdot
.48421 .34122 Mdot
.6886 .40328 Mdot
.75046 .30313 Mdot
.47176 .32395 Mdot
.32167 .54103 Mdot
.47538 .33439 Mdot
.53205 .68449 Mdot
.72114 .40733 Mdot
.342 .56903 Mdot
.69639 .60675 Mdot
.69125 .57776 Mdot
.71342 .55738 Mdot
.45458 .5877 Mdot
.50952 .37112 Mdot
.32945 .60174 Mdot
.30918 .59207 Mdot
.59604 .36708 Mdot
.66853 .5986 Mdot
.71777 .40934 Mdot
.45128 .37848 Mdot
.53846 .37738 Mdot
.53518 .73549 Mdot
.87417 .63572 Mdot
.50096 .48775 Mdot
.75533 .43417 Mdot
.62168 .46174 Mdot
.45361 .60754 Mdot
.46942 .38358 Mdot
.70654 .43566 Mdot
.67465 .57847 Mdot
.46002 .40415 Mdot
.47736 .30178 Mdot
.5983 .63975 Mdot
.65186 .62168 Mdot
.51445 .74412 Mdot
.70457 .59156 Mdot
.74959 .43054 Mdot
.45385 .58863 Mdot
.37326 .57253 Mdot
.46488 .36396 Mdot
.39553 .36993 Mdot
.67814 .60444 Mdot
.43213 .59451 Mdot
.50235 .35217 Mdot
.3678 .58066 Mdot
.66463 .60424 Mdot
.48027 .35622 Mdot
.22684 .48275 Mdot
.36974 .5088 Mdot
.68788 .60762 Mdot
.43889 .34397 Mdot
.48479 .27396 Mdot
.6477 .62018 Mdot
.66347 .63185 Mdot
.46353 .40718 Mdot
.71495 .44428 Mdot
.45868 .32803 Mdot
.52459 .68841 Mdot
.58981 .42265 Mdot
.52479 .71519 Mdot
.6258 .31409 Mdot
.46706 .41476 Mdot
.38353 .35566 Mdot
.34426 .53031 Mdot
.69701 .43916 Mdot
.43087 .20351 Mdot
.41702 .34317 Mdot
.25034 .59846 Mdot
.59903 .41395 Mdot
.51422 .50048 Mdot
.25161 .60891 Mdot
.7267 .44422 Mdot
.51088 .69462 Mdot
.49774 .34378 Mdot
.51971 .64514 Mdot
.71891 .44119 Mdot
.62447 .31268 Mdot
.43336 .36156 Mdot
.35706 .57245 Mdot
.46604 .37604 Mdot
.36924 .57605 Mdot
.46885 .33711 Mdot
.25543 .5665 Mdot
.78798 .41979 Mdot
.54874 .25017 Mdot
.51779 .41423 Mdot
.58442 .72023 Mdot
.34429 .45937 Mdot
.71826 .41298 Mdot
.46135 .39624 Mdot
.46018 .60506 Mdot
.49844 .70077 Mdot
.58811 .65447 Mdot
.64733 .60311 Mdot
.54521 .70969 Mdot
.32083 .55322 Mdot
.67027 .63501 Mdot
.4388 .60167 Mdot
.46346 .45564 Mdot
.71022 .43963 Mdot
.53293 .7055 Mdot
.46177 .3605 Mdot
.42322 .37973 Mdot
.60575 .70077 Mdot
.57695 .18298 Mdot
.33385 .53368 Mdot
.55017 .85454 Mdot
.33916 .60227 Mdot
.73897 .42929 Mdot
.66578 .57398 Mdot
.48449 .35153 Mdot
.45124 .34374 Mdot
.65332 .62098 Mdot
.38219 .57273 Mdot
.69515 .40285 Mdot
.73984 .30916 Mdot
.48681 .72658 Mdot
.58804 .21985 Mdot
.34188 .57187 Mdot
.58925 .2214 Mdot
.76587 .41722 Mdot
.42617 .56305 Mdot
.51291 .21278 Mdot
.50367 .70695 Mdot
.58742 .21818 Mdot
.36122 .57258 Mdot
.48436 .3802 Mdot
.44538 .59913 Mdot
.43401 .5869 Mdot
.33025 .57361 Mdot
.65689 .58531 Mdot
.74041 .4442 Mdot
.46332 .37381 Mdot
.43249 .44846 Mdot
.34908 .26658 Mdot
.68174 .62044 Mdot
.47714 .44286 Mdot
.50512 .71814 Mdot
.47726 .33654 Mdot
.69881 .41897 Mdot
.50604 .70434 Mdot
.47075 .61245 Mdot
.57357 .29813 Mdot
.44141 .3451 Mdot
.5473 .54017 Mdot
.52487 .69666 Mdot
.74413 .29739 Mdot
.48229 .33036 Mdot
.54079 .70969 Mdot
.39605 .37404 Mdot
.51685 .78625 Mdot
.53682 .56046 Mdot
.44763 .73386 Mdot
.71851 .59107 Mdot
.70415 .58576 Mdot
.67782 .19992 Mdot
.73961 .4754 Mdot
.54002 .72492 Mdot
.46417 .59067 Mdot
.58688 .19821 Mdot
.53305 .71835 Mdot
.4487 .32564 Mdot
.49604 .37092 Mdot
.3589 .46801 Mdot
.53799 .35044 Mdot
.4403 .58195 Mdot
.39782 .45595 Mdot
.48296 .39096 Mdot
.49512 .4381 Mdot
.49597 .34562 Mdot
.35457 .59204 Mdot
.50467 .71216 Mdot
.14699 .50901 Mdot
.49506 .72991 Mdot
.38902 .33827 Mdot
.68534 .60702 Mdot
.71756 .60311 Mdot
.46527 .35869 Mdot
.39888 .29511 Mdot
.24488 .72787 Mdot
.5001 .36493 Mdot
.55646 .54826 Mdot
.63333 .32641 Mdot
.52586 .37813 Mdot
.30752 .56948 Mdot
.39879 .38868 Mdot
.33282 .60442 Mdot
.50532 .70231 Mdot
.72486 .44379 Mdot
.71758 .45857 Mdot
.51454 .69314 Mdot
.45273 .34373 Mdot
.70981 .45268 Mdot
.47291 .36307 Mdot
.46061 .37975 Mdot
.53253 .46796 Mdot
.70928 .40471 Mdot
.64503 .59938 Mdot
.72995 .42463 Mdot
.32322 .57986 Mdot
.66704 .83524 Mdot
.72479 .41411 Mdot
.35884 .46551 Mdot
.61387 .39704 Mdot
.59543 .2178 Mdot
.36667 .55737 Mdot
.73481 .4049 Mdot
.50226 .70065 Mdot
.47482 .49149 Mdot
.34096 .44301 Mdot
.54525 .68981 Mdot
.45303 .35831 Mdot
.31923 .5341 Mdot
.33203 .59873 Mdot
.53032 .67251 Mdot
.37687 .56591 Mdot
.5167 .34859 Mdot
.44267 .37236 Mdot
.5468 .71387 Mdot
.30576 .24751 Mdot
.50555 .68835 Mdot
.30048 .50542 Mdot
.49902 .39007 Mdot
.34452 .56875 Mdot
.35265 .45539 Mdot
.37335 .52812 Mdot
.43796 .58679 Mdot
.47186 .32049 Mdot
.72283 .41081 Mdot
.60289 .36163 Mdot
.68624 .61018 Mdot
.35501 .75511 Mdot
.36552 .56076 Mdot
.5082 .6726 Mdot
.37612 .56878 Mdot
.37075 .55503 Mdot
.54867 .72288 Mdot
.3484 .58091 Mdot
.45585 .33288 Mdot
.2586 .66294 Mdot
.35599 .55085 Mdot
.51865 .70234 Mdot
.73406 .40808 Mdot
.32428 .5404 Mdot
.6569 .42429 Mdot
.44866 .37123 Mdot
.71154 .59109 Mdot
.68905 .45056 Mdot
.36163 .54229 Mdot
.71731 .41228 Mdot
.67316 .60327 Mdot
.73454 .44967 Mdot
.4965 .644 Mdot
.57161 .71445 Mdot
.48437 .25138 Mdot
.52715 .78949 Mdot
.33615 .58762 Mdot
.70541 .62649 Mdot
.44414 .33861 Mdot
.46158 .37698 Mdot
.72977 .46099 Mdot
.3428 .59666 Mdot
.46569 .79344 Mdot
.38082 .39707 Mdot
.44116 .78152 Mdot
.49384 .7086 Mdot
.6767 .39273 Mdot
.49651 .48893 Mdot
.49943 .65908 Mdot
.51479 .3922 Mdot
.45279 .60677 Mdot
.47368 .35625 Mdot
.6527 .3434 Mdot
.74817 .43427 Mdot
.63177 .7183 Mdot
.43474 .4039 Mdot
.65602 .6201 Mdot
.473 .33984 Mdot
.53372 .62541 Mdot
.46031 .42008 Mdot
.73134 .45589 Mdot
.486 .71068 Mdot
.31573 .54339 Mdot
.74239 .41271 Mdot
.68769 .57644 Mdot
.49903 .22752 Mdot
.44735 .32781 Mdot
.4827 .38914 Mdot
.64277 .61902 Mdot
.31222 .56384 Mdot
.67098 .58482 Mdot
.5416 .70921 Mdot
.72501 .41681 Mdot
.4267 .37335 Mdot
.48373 .44213 Mdot
.65046 .57175 Mdot
.51578 .73907 Mdot
.63781 .6018 Mdot
.50597 .73978 Mdot
.44781 .60399 Mdot
.4812 .41729 Mdot
.63486 .6088 Mdot
.51178 .39412 Mdot
.33597 .37225 Mdot
.57676 .31551 Mdot
.38285 .26146 Mdot
.64504 .59623 Mdot
.78748 .43969 Mdot
.51178 .7006 Mdot
.53545 .7051 Mdot
.27968 .51764 Mdot
.28078 .75738 Mdot
.52643 .5378 Mdot
.51333 .82202 Mdot
.54194 .70848 Mdot
.52739 .69995 Mdot
.66342 .58515 Mdot
.3203 .57412 Mdot
.36442 .53882 Mdot
.63816 .62404 Mdot
.59855 .30332 Mdot
.36139 .56721 Mdot
.21985 .55559 Mdot
.69726 .61533 Mdot
.50208 .33447 Mdot
.40314 .53328 Mdot
.73165 .45546 Mdot
.63587 .33882 Mdot
.58134 .74704 Mdot
.47682 .3498 Mdot
.78227 .66161 Mdot
.64942 .60078 Mdot
.44523 .51302 Mdot
.50058 .75598 Mdot
.42041 .36341 Mdot
.4679 .34096 Mdot
.46571 .331 Mdot
.74546 .45296 Mdot
.33843 .31454 Mdot
.48061 .35084 Mdot
.5614 .27146 Mdot
.41473 .33401 Mdot
.59839 .73701 Mdot
.72987 .42425 Mdot
.69776 .30737 Mdot
.66416 .63984 Mdot
.46154 .77712 Mdot
.4263 .32727 Mdot
.53888 .69816 Mdot
.54254 .60317 Mdot
.51217 .73366 Mdot
.4748 .66109 Mdot
.56826 .19793 Mdot
.34473 .59509 Mdot
.42987 .39408 Mdot
.6877 .62266 Mdot
.33519 .52753 Mdot
.54267 .59529 Mdot
.65398 .84006 Mdot
.50268 .67773 Mdot
.50562 .88924 Mdot
.52878 .71667 Mdot
.43547 .58351 Mdot
.3219 .55526 Mdot
.41226 .27059 Mdot
.56457 .43994 Mdot
.31349 .56066 Mdot
.78052 .52349 Mdot
.35442 .60798 Mdot
.55249 .22937 Mdot
.28367 .57023 Mdot
.51469 .70715 Mdot
.5227 .66962 Mdot
.45848 .29664 Mdot
.45436 .32843 Mdot
.57193 .43875 Mdot
.50168 .29537 Mdot
.44174 .34764 Mdot
.68758 .59442 Mdot
.53331 .79157 Mdot
.52196 .64631 Mdot
.34019 .57681 Mdot
.52817 .7385 Mdot
.47122 .34057 Mdot
.44898 .39331 Mdot
.4632 .31321 Mdot
.75434 .3664 Mdot
.21727 .55251 Mdot
.48826 .37011 Mdot
.46243 .42277 Mdot
.68541 .57348 Mdot
.60678 .70178 Mdot
.57873 .83242 Mdot
.57509 .19829 Mdot
.50474 .36053 Mdot
.73533 .43084 Mdot
.69793 .41828 Mdot
.50298 .32289 Mdot
.41633 .27409 Mdot
.67401 .40857 Mdot
.46149 .36024 Mdot
.52115 .23406 Mdot
.68817 .5586 Mdot
.45062 .61072 Mdot
.6778 .60398 Mdot
.35075 .53209 Mdot
.44382 .60364 Mdot
.69156 .58573 Mdot
.57698 .29254 Mdot
.46498 .61009 Mdot
.51287 .78576 Mdot
.7324 .40412 Mdot
.49102 .33832 Mdot
.37447 .49046 Mdot
.68975 .61373 Mdot
.53037 .6987 Mdot
.3311 .55547 Mdot
.49792 .69857 Mdot
.58059 .77297 Mdot
.60914 .31255 Mdot
.44691 .58743 Mdot
.53861 .69667 Mdot
.5419 .53674 Mdot
.73516 .42789 Mdot
.52467 .72233 Mdot
.3836 .34837 Mdot
.41512 .38204 Mdot
.20888 .6534 Mdot
.4706 .39001 Mdot
.46493 .68739 Mdot
.53444 .6986 Mdot
.46927 .61527 Mdot
.466 .36546 Mdot
.70608 .61132 Mdot
.48171 .45549 Mdot
.47458 .36369 Mdot
.70233 .60122 Mdot
.4886 .37506 Mdot
.70244 .41616 Mdot
.35153 .60332 Mdot
.60485 .40594 Mdot
.6785 .3753 Mdot
.74504 .43788 Mdot
.5787 .37516 Mdot
.47168 .32347 Mdot
.74326 .50267 Mdot
.35619 .5702 Mdot
.41671 .34592 Mdot
.63235 .30669 Mdot
.32656 .57683 Mdot
.34043 .5539 Mdot
.47133 .39484 Mdot
.51221 .68386 Mdot
.64179 .60559 Mdot
.73363 .42692 Mdot
.54304 .6623 Mdot
.48186 .35547 Mdot
.45859 .40557 Mdot
.74742 .43238 Mdot
.53049 .70565 Mdot
.42525 .36301 Mdot
.37876 .7227 Mdot
.58945 .34094 Mdot
.52258 .74222 Mdot
.41643 .38368 Mdot
.21569 .59071 Mdot
.38225 .56089 Mdot
.78568 .65807 Mdot
.78416 .4291 Mdot
.6645 .57719 Mdot
.44901 .43748 Mdot
.83066 .6918 Mdot
.73046 .40501 Mdot
.43835 .77171 Mdot
.48236 .37924 Mdot
.48819 .35134 Mdot
.34849 .59238 Mdot
.42798 .35955 Mdot
.3595 .58193 Mdot
.68735 .38135 Mdot
.29993 .77463 Mdot
.37278 .56065 Mdot
.36483 .57627 Mdot
.45879 .28101 Mdot
.78774 .38073 Mdot
.32385 .56821 Mdot
.44614 .32933 Mdot
.77394 .50059 Mdot
.49914 .30754 Mdot
.72924 .39516 Mdot
.68649 .39576 Mdot
.30414 .56132 Mdot
.32991 .45638 Mdot
.45607 .28204 Mdot
.24494 .51872 Mdot
.66652 .4391 Mdot
.53759 .72464 Mdot
.47492 .40326 Mdot
.46229 .58915 Mdot
.66155 .60033 Mdot
.4049 .40684 Mdot
.48369 .33196 Mdot
.31443 .57574 Mdot
.75221 .43887 Mdot
.52836 .72291 Mdot
.50446 .39561 Mdot
.67256 .55888 Mdot
.73796 .44115 Mdot
.34485 .54459 Mdot
.32652 .4866 Mdot
.71316 .45437 Mdot
.47552 .44425 Mdot
.48661 .38124 Mdot
.50658 .38306 Mdot
.52541 .40648 Mdot
.51626 .6935 Mdot
.65552 .63254 Mdot
.47002 .44373 Mdot
.50534 .48195 Mdot
.59475 .3316 Mdot
.47616 .31428 Mdot
.32254 .54068 Mdot
.49589 .71536 Mdot
.45771 .59239 Mdot
.59252 .20915 Mdot
.49501 .38163 Mdot
.21901 .55738 Mdot
.73225 .34024 Mdot
.46539 .6052 Mdot
.32361 .52712 Mdot
.72806 .42833 Mdot
.49011 .39422 Mdot
.55933 .26668 Mdot
.43889 .34932 Mdot
.52808 .38184 Mdot
.65522 .58428 Mdot
.52856 .7291 Mdot
.49839 .25886 Mdot
.6612 .59729 Mdot
.33992 .55436 Mdot
.21025 .52853 Mdot
.36371 .54049 Mdot
.35057 .53844 Mdot
.464 .5584 Mdot
.51889 .68583 Mdot
.84082 .68031 Mdot
.76709 .31834 Mdot
.48401 .32139 Mdot
.54221 .6918 Mdot
.32542 .56359 Mdot
.43254 .33641 Mdot
.35452 .58231 Mdot
.30481 .56964 Mdot
.44675 .37276 Mdot
.44382 .36562 Mdot
.54414 .24595 Mdot
.22523 .56151 Mdot
.72821 .40936 Mdot
.37869 .57846 Mdot
.25935 .51602 Mdot
.48596 .35418 Mdot
.46793 .32634 Mdot
.5431 .60688 Mdot
.74203 .40978 Mdot
.22961 .40827 Mdot
.46787 .37877 Mdot
.67055 .33774 Mdot
.45768 .32325 Mdot
.36494 .5339 Mdot
.5484 .68226 Mdot
.38779 .33888 Mdot
.6433 .59274 Mdot
.38392 .56985 Mdot
.74595 .44665 Mdot
.30252 .53109 Mdot
.23848 .43892 Mdot
.50705 .69431 Mdot
.36785 .57211 Mdot
.67996 .63426 Mdot
.52484 .71054 Mdot
.5084 .68719 Mdot
.54318 .59187 Mdot
.69661 .62791 Mdot
.755 .43246 Mdot
.5112 .72587 Mdot
.22845 .48604 Mdot
.51631 .70923 Mdot
.23248 .44004 Mdot
.50654 .35507 Mdot
.56358 .2747 Mdot
.40974 .41613 Mdot
.46601 .29722 Mdot
.51427 .71963 Mdot
.74133 .44053 Mdot
.42331 .35592 Mdot
.36928 .55557 Mdot
.73784 .416 Mdot
.41337 .52079 Mdot
.70717 .62263 Mdot
.32287 .59672 Mdot
.50147 .7386 Mdot
.34791 .58801 Mdot
.63347 .32997 Mdot
.70408 .38822 Mdot
.55887 .607 Mdot
.57484 .4282 Mdot
.5086 .42469 Mdot
.43824 .41084 Mdot
.42203 .35498 Mdot
.45639 .33456 Mdot
.68791 .60651 Mdot
.74613 .45719 Mdot
.32523 .53927 Mdot
.3489 .25301 Mdot
.53134 .69321 Mdot
.55049 .55055 Mdot
.52262 .40994 Mdot
.4575 .40294 Mdot
.32775 .56235 Mdot
.3016 .56545 Mdot
.34848 .31951 Mdot
.64792 .6172 Mdot
.48673 .30207 Mdot
.43593 .32238 Mdot
.52561 .27646 Mdot
.51721 .7186 Mdot
.42556 .71051 Mdot
.70397 .56532 Mdot
.51972 .89399 Mdot
.6636 .5963 Mdot
.62749 .52177 Mdot
.34584 .58233 Mdot
.71407 .42122 Mdot
.44922 .35612 Mdot
.40793 .47937 Mdot
.31204 .53524 Mdot
.60716 .61319 Mdot
.72149 .42631 Mdot
.44595 .66372 Mdot
.5453 .69921 Mdot
.50615 .39507 Mdot
.45561 .32363 Mdot
.43723 .38475 Mdot
.43195 .34466 Mdot
.54465 .72141 Mdot
.439 .35986 Mdot
.5469 .7294 Mdot
.24299 .42751 Mdot
.62695 .29887 Mdot
.67063 .63 Mdot
.61773 .70201 Mdot
.35283 .54054 Mdot
.20172 .4639 Mdot
.2387 .40774 Mdot
.5772 .31625 Mdot
.48653 .64764 Mdot
.5042 .40301 Mdot
.65578 .58766 Mdot
.55821 .66577 Mdot
.67541 .62911 Mdot
.15277 .56685 Mdot
.35542 .46681 Mdot
.459 .68125 Mdot
.43396 .3752 Mdot
.63812 .61716 Mdot
.31573 .47501 Mdot
.46528 .44632 Mdot
.70476 .44863 Mdot
.23276 .45956 Mdot
.40473 .48989 Mdot
.72139 .40606 Mdot
.45295 .37649 Mdot
.30125 .58535 Mdot
.4499 .35034 Mdot
.4489 .36226 Mdot
.50125 .36764 Mdot
.55684 .69766 Mdot
.50149 .33843 Mdot
.45568 .33019 Mdot
.59558 .17981 Mdot
.6209 .64268 Mdot
.70461 .58322 Mdot
.3769 .26786 Mdot
.73635 .41909 Mdot
.34895 .53127 Mdot
.5971 .41333 Mdot
.534 .69046 Mdot
.34958 .31539 Mdot
.45333 .3896 Mdot
.40295 .7612 Mdot
.49006 .70655 Mdot
.72263 .4481 Mdot
.46442 .59314 Mdot
.43061 .67585 Mdot
.66504 .57108 Mdot
.45188 .58402 Mdot
.68433 .61248 Mdot
.4055 .23624 Mdot
.36289 .57951 Mdot
.50829 .42495 Mdot
.52364 .72682 Mdot
.68731 .62782 Mdot
.55641 .26573 Mdot
.47643 .33233 Mdot
.64479 .59603 Mdot
.43258 .42991 Mdot
.60628 .36191 Mdot
.59505 .4176 Mdot
.67525 .63326 Mdot
.48816 .70512 Mdot
.52085 .71531 Mdot
.72233 .40372 Mdot
.38069 .56277 Mdot
.31283 .56886 Mdot
.5152 .71315 Mdot
.71664 .75153 Mdot
.47995 .35447 Mdot
.49279 .3636 Mdot
.49703 .48499 Mdot
.43424 .3308 Mdot
.69152 .39874 Mdot
.43089 .58328 Mdot
.30813 .55939 Mdot
.42246 .35383 Mdot
.42563 .36443 Mdot
.482 .38471 Mdot
.59205 .2929 Mdot
.6773 .60632 Mdot
.48498 .39108 Mdot
.70857 .43835 Mdot
.41045 .5104 Mdot
.4458 .33618 Mdot
.47935 .44492 Mdot
.35704 .58347 Mdot
.6461 .53785 Mdot
.52993 .69621 Mdot
.67682 .62161 Mdot
.68377 .62279 Mdot
.63464 .27347 Mdot
.38694 .55393 Mdot
.44287 .58202 Mdot
.59569 .71147 Mdot
.4575 .58987 Mdot
.71945 .42716 Mdot
.53139 .55538 Mdot
.72628 .6068 Mdot
.70502 .58606 Mdot
.51267 .66788 Mdot
.41717 .36876 Mdot
.44544 .33439 Mdot
.45738 .77842 Mdot
.49867 .36422 Mdot
.72373 .40934 Mdot
.53183 .68107 Mdot
.36433 .5744 Mdot
.69952 .42444 Mdot
.53563 .70912 Mdot
.31221 .5606 Mdot
.42249 .32278 Mdot
.4453 .32787 Mdot
.3335 .5532 Mdot
.35 .54603 Mdot
.46423 .35073 Mdot
.55023 .18829 Mdot
.3093 .55092 Mdot
.32713 .55425 Mdot
.40938 .50488 Mdot
.67703 .56952 Mdot
.49613 .45502 Mdot
.5351 .6874 Mdot
.45915 .32977 Mdot
.66368 .6298 Mdot
.72313 .4366 Mdot
.34653 .55065 Mdot
.48275 .4031 Mdot
.48398 .36153 Mdot
.73413 .43095 Mdot
.7127 .39894 Mdot
.74225 .41534 Mdot
.53722 .67669 Mdot
.44647 .37864 Mdot
.32113 .56145 Mdot
.54665 .70206 Mdot
.70986 .44908 Mdot
.73018 .39883 Mdot
.51659 .20467 Mdot
.47396 .35024 Mdot
.6959 .41925 Mdot
.69447 .82359 Mdot
.52012 .22219 Mdot
.43815 .59955 Mdot
.70991 .56162 Mdot
.79572 .42515 Mdot
.69113 .45173 Mdot
.53038 .73073 Mdot
.55762 .55356 Mdot
.75187 .42183 Mdot
.50085 .39468 Mdot
.49007 .34288 Mdot
.50068 .42444 Mdot
.73932 .41974 Mdot
.60987 .31101 Mdot
.35319 .59591 Mdot
.27778 .34467 Mdot
.73615 .41887 Mdot
.69055 .62858 Mdot
.65125 .57024 Mdot
.66403 .59084 Mdot
.4834 .41585 Mdot
.38621 .23766 Mdot
.2528 .46783 Mdot
.23118 .39822 Mdot
.54411 .7004 Mdot
.30272 .56824 Mdot
.41313 .54013 Mdot
.34117 .55357 Mdot
.65996 .60841 Mdot
.73782 .44253 Mdot
.3464 .59347 Mdot
.50774 .68825 Mdot
.51758 .71683 Mdot
.64128 .5913 Mdot
.67316 .60082 Mdot
.67886 .58914 Mdot
.38311 .56759 Mdot
.34709 .58178 Mdot
.43117 .38107 Mdot
.35232 .5513 Mdot
.75651 .34681 Mdot
.74355 .37708 Mdot
.63997 .58586 Mdot
.51891 .69669 Mdot
.3282 .54588 Mdot
.49165 .33794 Mdot
.59099 .52815 Mdot
.66465 .64188 Mdot
.7258 .45422 Mdot
.29128 .71973 Mdot
.28142 .76687 Mdot
.43416 .40045 Mdot
.52197 .73859 Mdot
.39403 .30995 Mdot
.46077 .33486 Mdot
.6535 .58334 Mdot
.72671 .31738 Mdot
.4695 .6079 Mdot
.44681 .34452 Mdot
.43307 .31629 Mdot
.50231 .69619 Mdot
.59581 .41336 Mdot
.50039 .397 Mdot
.55426 .57141 Mdot
.49186 .69587 Mdot
.70041 .56347 Mdot
.7189 .22896 Mdot
.43687 .51202 Mdot
.64561 .36141 Mdot
.45042 .60936 Mdot
.50153 .37646 Mdot
.68876 .59672 Mdot
.70942 .44485 Mdot
.68162 .59697 Mdot
.3305 .5247 Mdot
.66869 .57074 Mdot
.50052 .35634 Mdot
.32128 .56616 Mdot
.53214 .70649 Mdot
.54789 .51805 Mdot
.40812 .24553 Mdot
.70734 .6082 Mdot
.432 .5956 Mdot
.44391 .36423 Mdot
.2203 .48742 Mdot
.4559 .29581 Mdot
.46055 .32584 Mdot
.50836 .73068 Mdot
.3335 .57081 Mdot
.49405 .71042 Mdot
.45828 .45066 Mdot
.25682 .59236 Mdot
.52733 .69138 Mdot
.41582 .47987 Mdot
.74663 .43838 Mdot
.60413 .30935 Mdot
.46248 .3685 Mdot
.52577 .72667 Mdot
.45534 .38485 Mdot
.37775 .58015 Mdot
.58633 .31397 Mdot
.5842 .34177 Mdot
.50365 .71628 Mdot
.46069 .629 Mdot
.61778 .38064 Mdot
.49944 .45424 Mdot
.53927 .715 Mdot
.42415 .20903 Mdot
.46115 .60207 Mdot
.73322 .44174 Mdot
.71205 .39749 Mdot
.70992 .42895 Mdot
.49548 .35891 Mdot
.24307 .54187 Mdot
.71787 .40202 Mdot
.50608 .68016 Mdot
.70673 .41322 Mdot
.70512 .36267 Mdot
.45683 .7877 Mdot
.74512 .43951 Mdot
.4696 .37203 Mdot
.39271 .3379 Mdot
.55595 .55033 Mdot
.71588 .59881 Mdot
.38435 .65235 Mdot
.60103 .1809 Mdot
.48366 .35054 Mdot
.25259 .57337 Mdot
.33887 .52046 Mdot
.64865 .49958 Mdot
.58071 .33678 Mdot
.52865 .52053 Mdot
.32744 .54915 Mdot
.58637 .42039 Mdot
.31927 .53558 Mdot
.51438 .42188 Mdot
.48618 .36985 Mdot
.38488 .56827 Mdot
.34264 .74896 Mdot
.40713 .20295 Mdot
.42938 .77951 Mdot
.31588 .54903 Mdot
.53952 .7106 Mdot
.51337 .73564 Mdot
.51 .73123 Mdot
.69467 .60021 Mdot
.37062 .5707 Mdot
.49429 .38625 Mdot
.67962 .57523 Mdot
.45351 .36985 Mdot
.50773 .71134 Mdot
.57966 .324 Mdot
.36323 .57649 Mdot
.46063 .36117 Mdot
.29246 .49209 Mdot
.67905 .61373 Mdot
.73666 .42795 Mdot
.27599 .69621 Mdot
.72085 .57107 Mdot
.48896 .71729 Mdot
.31236 .52484 Mdot
.63893 .57241 Mdot
.59086 .55556 Mdot
.48908 .32331 Mdot
.47137 .31709 Mdot
.56368 .55598 Mdot
.34332 .4703 Mdot
.49835 .40227 Mdot
.68958 .57705 Mdot
.69429 .57215 Mdot
.45849 .38541 Mdot
.37217 .56514 Mdot
.74993 .40896 Mdot
.72765 .46161 Mdot
.52036 .40198 Mdot
.57647 .43119 Mdot
.56216 .27283 Mdot
.42521 .34758 Mdot
.47284 .43818 Mdot
.68697 .63343 Mdot
.44151 .60409 Mdot
.55633 .44461 Mdot
.71131 .41719 Mdot
.47715 .38101 Mdot
.34994 .26891 Mdot
.3653 .56172 Mdot
.64304 .59959 Mdot
.55081 .70665 Mdot
.7103 .45273 Mdot
.64723 .57859 Mdot
.45858 .38541 Mdot
.42537 .36309 Mdot
.52308 .72463 Mdot
.36775 .53495 Mdot
.74323 .43105 Mdot
.68057 .57465 Mdot
.71395 .41843 Mdot
.35069 .58018 Mdot
.33569 .54505 Mdot
.45616 .31306 Mdot
.467 .29548 Mdot
.70208 .61244 Mdot
.51537 .39976 Mdot
.67497 .58055 Mdot
.60574 .70152 Mdot
.53619 .73457 Mdot
.42099 .3376 Mdot
.3845 .54754 Mdot
.51 .7131 Mdot
.47955 .346 Mdot
.56658 .55994 Mdot
.43446 .39502 Mdot
.64198 .62544 Mdot
.72683 .29913 Mdot
.71722 .43684 Mdot
.40748 .32981 Mdot
.36997 .38588 Mdot
.4306 .33464 Mdot
.70881 .58272 Mdot
.23814 .47593 Mdot
.52145 .69007 Mdot
.33899 .58239 Mdot
.71776 .54465 Mdot
.51812 .70473 Mdot
.47426 .37619 Mdot
.72563 .4142 Mdot
.31933 .53851 Mdot
.43944 .59374 Mdot
.55493 .45918 Mdot
.39191 .37569 Mdot
.50822 .32061 Mdot
.5035 .39895 Mdot
.51071 .8232 Mdot
.67984 .59156 Mdot
.32609 .56172 Mdot
.52574 .7373 Mdot
.51104 .6912 Mdot
.67403 .61169 Mdot
.40878 .49446 Mdot
.38704 .77429 Mdot
.74204 .78605 Mdot
.64569 .57871 Mdot
.70625 .42068 Mdot
.58571 .31534 Mdot
.66231 .59064 Mdot
.69168 .60769 Mdot
.69066 .6342 Mdot
.46248 .78294 Mdot
.31588 .55223 Mdot
.48518 .3613 Mdot
.33512 .50901 Mdot
.49992 .36952 Mdot
.63817 .37479 Mdot
.50811 .70991 Mdot
.3395 .58281 Mdot
.65398 .41456 Mdot
.45599 .42032 Mdot
.45959 .34122 Mdot
.6571 .43911 Mdot
.43941 .27878 Mdot
.59136 .21431 Mdot
.45044 .31905 Mdot
.68336 .6023 Mdot
.40557 .56843 Mdot
.47473 .44377 Mdot
.28878 .49441 Mdot
.52467 .71568 Mdot
.44551 .58652 Mdot
.50262 .43342 Mdot
.48978 .42715 Mdot
.32307 .53469 Mdot
.34392 .59358 Mdot
.72401 .39919 Mdot
.26487 .66928 Mdot
.5281 .71339 Mdot
.44221 .7203 Mdot
.45953 .32552 Mdot
.47618 .66302 Mdot
.73613 .31315 Mdot
.47271 .34433 Mdot
.54281 .58683 Mdot
.34876 .31954 Mdot
.47247 .40616 Mdot
.23937 .38545 Mdot
.51465 .70069 Mdot
.64619 .3212 Mdot
.43522 .36059 Mdot
.64852 .59171 Mdot
.32363 .57816 Mdot
.32213 .59664 Mdot
.70776 .44428 Mdot
.77055 .34084 Mdot
.36186 .81457 Mdot
.34017 .5838 Mdot
.47393 .33061 Mdot
.52744 .69601 Mdot
.43961 .58815 Mdot
.40195 .40135 Mdot
.52641 .63205 Mdot
.36364 .56164 Mdot
.46202 .44432 Mdot
.39922 .76244 Mdot
.59133 .41717 Mdot
.19093 .49373 Mdot
.50907 .72837 Mdot
.71288 .41155 Mdot
.52735 .3366 Mdot
.59711 .71575 Mdot
.44641 .3268 Mdot
.6402 .36991 Mdot
.39381 .57846 Mdot
.71969 .40866 Mdot
.45449 .34218 Mdot
.49499 .4041 Mdot
.58075 .39384 Mdot
.72086 .39338 Mdot
.49861 .40007 Mdot
.43665 .40501 Mdot
.32956 .58497 Mdot
.4298 .58395 Mdot
.36434 .57239 Mdot
.45091 .35109 Mdot
.70187 .27212 Mdot
.36997 .58293 Mdot
.4115 .64143 Mdot
.77981 .43141 Mdot
.53496 .69137 Mdot
.42082 .41681 Mdot
.50154 .34261 Mdot
.18151 .50936 Mdot
.43694 .58673 Mdot
.61398 .81485 Mdot
.64032 .62084 Mdot
.54997 .15473 Mdot
.72224 .57379 Mdot
.46112 .64601 Mdot
.59112 .6263 Mdot
.4711 .44176 Mdot
.40141 .478 Mdot
.22528 .39922 Mdot
.50793 .75402 Mdot
.20179 .45591 Mdot
.45418 .32853 Mdot
.48001 .38293 Mdot
.66822 .58034 Mdot
.47065 .65399 Mdot
.38686 .34147 Mdot
.55829 .44326 Mdot
.72577 .44859 Mdot
.34929 .56427 Mdot
.49206 .3432 Mdot
.32318 .73739 Mdot
.69978 .62151 Mdot
.40998 .25319 Mdot
.46265 .36387 Mdot
.40133 .29999 Mdot
.47272 .64871 Mdot
.53315 .70414 Mdot
.67429 .63368 Mdot
.69731 .62622 Mdot
.50049 .37474 Mdot
.54825 .71503 Mdot
.43895 .39202 Mdot
.61643 .37147 Mdot
.43777 .43224 Mdot
.72091 .43126 Mdot
.47902 .32721 Mdot
.38156 .30512 Mdot
.21005 .33117 Mdot
.43446 .4052 Mdot
.35532 .53988 Mdot
.68029 .58616 Mdot
.67146 .60707 Mdot
.31124 .56513 Mdot
.67083 .60753 Mdot
.27639 .35104 Mdot
.23475 .55485 Mdot
.7177 .4244 Mdot
.25506 .41232 Mdot
.72151 .44293 Mdot
.44733 .58663 Mdot
.47061 .3498 Mdot
.69942 .67575 Mdot
.65497 .57192 Mdot
.71054 .35792 Mdot
.5139 .71114 Mdot
.43573 .58587 Mdot
.4432 .36729 Mdot
.67114 .45295 Mdot
.65371 .60035 Mdot
.48797 .54214 Mdot
.49691 .37348 Mdot
.38133 .57282 Mdot
.46558 .40462 Mdot
.47458 .28131 Mdot
.4354 .58241 Mdot
.47399 .40985 Mdot
.53571 .70897 Mdot
.36808 .57972 Mdot
.46021 .69549 Mdot
.69146 .61173 Mdot
.4443 .35178 Mdot
.47088 .3306 Mdot
.30382 .54616 Mdot
.48591 .32336 Mdot
.5453 .71378 Mdot
.8965 .59097 Mdot
.74588 .41997 Mdot
.44432 .60638 Mdot
.34117 .66717 Mdot
.4788 .40911 Mdot
.42413 .36792 Mdot
.50399 .52282 Mdot
.35233 .26561 Mdot
.53663 .69734 Mdot
.51679 .33501 Mdot
.6993 .57716 Mdot
.74345 .43343 Mdot
.49977 .69304 Mdot
.44154 .37026 Mdot
.49056 .3737 Mdot
.72035 .40955 Mdot
.65287 .43269 Mdot
.69591 .40357 Mdot
.53735 .72635 Mdot
.28362 .60699 Mdot
.59284 .527 Mdot
.47531 .35794 Mdot
.43211 .59909 Mdot
.33387 .56707 Mdot
.54088 .71485 Mdot
.33311 .31882 Mdot
.5153 .4209 Mdot
.51162 .74435 Mdot
.53153 .70849 Mdot
.49344 .32858 Mdot
.38765 .5568 Mdot
.30952 .52439 Mdot
.33087 .56437 Mdot
.62922 .29279 Mdot
.57435 .81261 Mdot
.68332 .58923 Mdot
.52051 .69843 Mdot
.66005 .62805 Mdot
.75116 .42347 Mdot
.59885 .34072 Mdot
.70713 .61444 Mdot
.38527 .5789 Mdot
.67532 .62774 Mdot
.43698 .39137 Mdot
.51904 .68273 Mdot
.69875 .61324 Mdot
.43105 .34041 Mdot
.49895 .41632 Mdot
.53704 .34522 Mdot
.75436 .42504 Mdot
.58644 .42288 Mdot
.46453 .3735 Mdot
.46446 .59415 Mdot
.46302 .35507 Mdot
.54602 .71469 Mdot
.55187 .51292 Mdot
.47341 .39146 Mdot
.6542 .57227 Mdot
.58501 .81868 Mdot
.69425 .56916 Mdot
.50114 .2831 Mdot
.45338 .35965 Mdot
.47623 .3554 Mdot
.44504 .3696 Mdot
.40254 .49197 Mdot
.49493 .73288 Mdot
.52598 .35258 Mdot
.63709 .60491 Mdot
.34006 .55137 Mdot
.36777 .58636 Mdot
.51604 .53316 Mdot
.45503 .58475 Mdot
.54821 .70186 Mdot
.47808 .35521 Mdot
.49093 .54476 Mdot
.52868 .4853 Mdot
.41062 .77325 Mdot
.70258 .55321 Mdot
.70677 .59016 Mdot
.36916 .55234 Mdot
.70185 .59176 Mdot
.44055 .36546 Mdot
.46231 .44375 Mdot
.45911 .69141 Mdot
.49143 .74551 Mdot
.74192 .43576 Mdot
.45186 .36472 Mdot
.57438 .27381 Mdot
.68527 .57349 Mdot
.69028 .63192 Mdot
.43895 .39086 Mdot
.35369 .52234 Mdot
.27856 .25032 Mdot
.54165 .68996 Mdot
.22523 .49963 Mdot
.32767 .50135 Mdot
.55463 .30193 Mdot
.51385 .69261 Mdot
.54376 .57924 Mdot
.71645 .59348 Mdot
.69664 .25454 Mdot
.33535 .55018 Mdot
.74228 .43306 Mdot
.43897 .3329 Mdot
.38551 .57914 Mdot
.63153 .60087 Mdot
.31206 .54216 Mdot
.50211 .43215 Mdot
.49397 .6975 Mdot
.66449 .60186 Mdot
.52147 .66854 Mdot
.33446 .52686 Mdot
.71967 .4411 Mdot
.66374 .34061 Mdot
.22453 .48036 Mdot
.34808 .32529 Mdot
.48614 .39124 Mdot
.65419 .65726 Mdot
.49581 .3864 Mdot
.33829 .59995 Mdot
.46325 .36913 Mdot
.43515 .41443 Mdot
.71791 .59806 Mdot
.47453 .31354 Mdot
.47144 .32555 Mdot
.28015 .49937 Mdot
.46662 .34252 Mdot
.46269 .38503 Mdot
.45705 .31174 Mdot
.38714 .56835 Mdot
.47011 .31329 Mdot
.37921 .56723 Mdot
.42525 .76828 Mdot
.68798 .61303 Mdot
.75055 .42058 Mdot
.74976 .42959 Mdot
.64734 .36629 Mdot
.5806 .28091 Mdot
.39613 .52481 Mdot
.3595 .56339 Mdot
.51491 .71884 Mdot
.43495 .38805 Mdot
.44203 .19862 Mdot
.69553 .27482 Mdot
.71259 .57957 Mdot
.69415 .61958 Mdot
.4383 .33959 Mdot
.26768 .75207 Mdot
.45414 .31926 Mdot
.49836 .48754 Mdot
.49542 .36033 Mdot
.42031 .33933 Mdot
.66999 .63548 Mdot
.63455 .33172 Mdot
.48496 .39096 Mdot
.32302 .53443 Mdot
.73906 .43655 Mdot
.41222 .29 Mdot
.69886 .29703 Mdot
.30665 .50138 Mdot
.37688 .37931 Mdot
.45964 .38944 Mdot
.66978 .57535 Mdot
.31774 .54402 Mdot
.5129 .48385 Mdot
.54574 .706 Mdot
.56977 .44388 Mdot
.23539 .43135 Mdot
.51545 .75661 Mdot
.73871 .44022 Mdot
.62889 .6263 Mdot
.50373 .36676 Mdot
.69321 .59503 Mdot
.52566 .38094 Mdot
.52998 .48925 Mdot
.71774 .42801 Mdot
.3837 .59994 Mdot
.53945 .70969 Mdot
.37456 .5869 Mdot
.38226 .26176 Mdot
.69635 .27253 Mdot
.55564 .15423 Mdot
.66869 .5677 Mdot
.30239 .28215 Mdot
.32973 .57418 Mdot
.49836 .37917 Mdot
.73887 .78822 Mdot
.34045 .57079 Mdot
.38202 .57261 Mdot
.54395 .49541 Mdot
.62736 .31505 Mdot
.51636 .39749 Mdot
.30795 .55158 Mdot
.6283 .62406 Mdot
.72483 .42537 Mdot
.42942 .34719 Mdot
.49899 .43605 Mdot
.34688 .59304 Mdot
.65508 .60558 Mdot
.63394 .35482 Mdot
.67848 .60223 Mdot
.31648 .55647 Mdot
.67052 .61859 Mdot
.436 .64246 Mdot
.70609 .61448 Mdot
.49104 .33255 Mdot
.47783 .35604 Mdot
.49378 .59204 Mdot
.33572 .54506 Mdot
.42384 .36599 Mdot
.48549 .37804 Mdot
.32344 .56544 Mdot
.72378 .61505 Mdot
.32901 .28524 Mdot
.42541 .37717 Mdot
.48252 .35756 Mdot
.74492 .41455 Mdot
.60654 .38495 Mdot
.48522 .49401 Mdot
.42912 .34081 Mdot
.70875 .42906 Mdot
.38241 .56755 Mdot
.46249 .35302 Mdot
.63679 .33285 Mdot
.68449 .55854 Mdot
.44017 .38092 Mdot
.44162 .59131 Mdot
.50353 .38032 Mdot
.26518 .27428 Mdot
.44308 .35922 Mdot
.32216 .55288 Mdot
.32455 .57594 Mdot
.72784 .56186 Mdot
.33868 .55558 Mdot
.43834 .59922 Mdot
.51965 .71496 Mdot
.20099 .49925 Mdot
.43469 .5943 Mdot
.46641 .4088 Mdot
.77198 .32378 Mdot
.49237 .44089 Mdot
.46644 .44759 Mdot
.78993 .38175 Mdot
.4503 .60896 Mdot
.33667 .57527 Mdot
.33362 .7369 Mdot
.51474 .35591 Mdot
.54795 .69985 Mdot
.47969 .44363 Mdot
.44096 .38152 Mdot
.42706 .40399 Mdot
.2598 .59031 Mdot
.54397 .68754 Mdot
.49569 .45572 Mdot
.42923 .34763 Mdot
.3526 .2662 Mdot
.48632 .3362 Mdot
.73252 .45351 Mdot
.35813 .57647 Mdot
.69953 .59231 Mdot
.72321 .43041 Mdot
.50252 .39855 Mdot
.73693 .41779 Mdot
.69023 .59274 Mdot
.51726 .72838 Mdot
.49393 .33572 Mdot
.73069 .39502 Mdot
.73526 .44558 Mdot
.46961 .3982 Mdot
.33343 .58332 Mdot
.45078 .296 Mdot
.46329 .35019 Mdot
.44685 .37597 Mdot
.31444 .57178 Mdot
.81173 .62403 Mdot
.47904 .38456 Mdot
.54446 .58197 Mdot
.34136 .60298 Mdot
.42925 .58529 Mdot
.69606 .58071 Mdot
.44663 .40916 Mdot
.51395 .68817 Mdot
.51858 .71367 Mdot
.66891 .56483 Mdot
.33989 .59195 Mdot
.66513 .60527 Mdot
.43463 .40626 Mdot
.46882 .44364 Mdot
.4378 .33553 Mdot
.73048 .55234 Mdot
.42623 .66651 Mdot
.33555 .54059 Mdot
.70758 .57853 Mdot
.5681 .44059 Mdot
.52745 .68345 Mdot
.66501 .63745 Mdot
.29525 .55351 Mdot
.32211 .58473 Mdot
.30989 .5578 Mdot
.71228 .44021 Mdot
.66703 .59802 Mdot
.30256 .52867 Mdot
.30478 .53143 Mdot
.44799 .39351 Mdot
.42859 .35468 Mdot
.38234 .56241 Mdot
.62364 .56754 Mdot
.72493 .44026 Mdot
.67003 .57337 Mdot
.24368 .2738 Mdot
.54374 .69192 Mdot
.28261 .49817 Mdot
.43152 .33696 Mdot
.55221 .89958 Mdot
.45339 .31918 Mdot
.47841 .33163 Mdot
.35079 .5321 Mdot
.70563 .39863 Mdot
.72655 .42306 Mdot
.32933 .57477 Mdot
.30689 .57081 Mdot
.72117 .45199 Mdot
.53424 .51776 Mdot
.29344 .25397 Mdot
.52607 .48046 Mdot
.32901 .53955 Mdot
.22016 .46981 Mdot
.50082 .71273 Mdot
.3668 .59829 Mdot
.57331 .70412 Mdot
.68395 .61705 Mdot
.70429 .61332 Mdot
.51869 .7241 Mdot
.47249 .38547 Mdot
.65083 .58269 Mdot
.41063 .34454 Mdot
.45582 .66436 Mdot
.50376 .63096 Mdot
.50432 .17883 Mdot
.4926 .33162 Mdot
.40736 .28609 Mdot
.48646 .81077 Mdot
.44445 .40272 Mdot
.35354 .44558 Mdot
.74252 .42743 Mdot
.35604 .60093 Mdot
.53071 .67884 Mdot
.24713 .59609 Mdot
.47597 .35693 Mdot
.32406 .54047 Mdot
.53751 .68586 Mdot
.44378 .66983 Mdot
.55348 .5713 Mdot
.45619 .40077 Mdot
.7896 .73619 Mdot
.31705 .53426 Mdot
.69922 .59165 Mdot
.27077 .47542 Mdot
.37876 .58824 Mdot
.57682 .5667 Mdot
.6286 .61309 Mdot
.54439 .44951 Mdot
.30638 .54891 Mdot
.69464 .40562 Mdot
.3543 .56847 Mdot
.70095 .41612 Mdot
.31176 .52572 Mdot
.66717 .61431 Mdot
.45633 .34722 Mdot
.67457 .61379 Mdot
.72744 .45672 Mdot
.66581 .5681 Mdot
.53027 .67878 Mdot
.45805 .61198 Mdot
.50736 .7123 Mdot
.59088 .32511 Mdot
.32211 .34161 Mdot
.52739 .72968 Mdot
.50834 .56392 Mdot
.5002 .36162 Mdot
.36442 .5336 Mdot
.69857 .59699 Mdot
.72097 .58317 Mdot
.58296 .4257 Mdot
.31428 .55997 Mdot
.65528 .60954 Mdot
.2248 .47384 Mdot
.70442 .76557 Mdot
.44625 .42292 Mdot
.58987 .77774 Mdot
.32167 .55923 Mdot
.71401 .61299 Mdot
.49606 .48586 Mdot
.34533 .59599 Mdot
.70013 .61351 Mdot
.53733 .71681 Mdot
.51745 .68752 Mdot
.48212 .3221 Mdot
.51834 .67289 Mdot
.71442 .59912 Mdot
.35265 .26179 Mdot
.34827 .58485 Mdot
.41043 .66488 Mdot
.74579 .43397 Mdot
.69317 .60369 Mdot
.50125 .32787 Mdot
.38867 .55254 Mdot
.66835 .62753 Mdot
.33436 .79861 Mdot
.16815 .37361 Mdot
.6539 .60846 Mdot
.35874 .57563 Mdot
.3474 .55189 Mdot
.46363 .41694 Mdot
.56952 .43519 Mdot
.65199 .60105 Mdot
.69797 .67558 Mdot
.55215 .25643 Mdot
.4469 .60356 Mdot
.59787 .1804 Mdot
.48439 .39032 Mdot
.45666 .38889 Mdot
.54034 .72379 Mdot
.46297 .33924 Mdot
.30318 .56554 Mdot
.45163 .31964 Mdot
.49452 .71821 Mdot
.68504 .56231 Mdot
.47123 .35306 Mdot
.74434 .43272 Mdot
.49847 .72097 Mdot
.50937 .7367 Mdot
.67112 .62092 Mdot
.32888 .58615 Mdot
.36044 .77392 Mdot
.67626 .60233 Mdot
.44713 .38015 Mdot
.46431 .60377 Mdot
.4678 .31171 Mdot
.4882 .58341 Mdot
.33052 .59957 Mdot
.7014 .59109 Mdot
.38439 .60229 Mdot
.52427 .69993 Mdot
.71783 .58953 Mdot
.50548 .37523 Mdot
.70798 .6 Mdot
.55754 .59877 Mdot
.75525 .49041 Mdot
.30131 .54011 Mdot
.57401 .57417 Mdot
.33296 .59182 Mdot
.44359 .60137 Mdot
.62646 .2684 Mdot
.73101 .44168 Mdot
.68943 .57145 Mdot
.41397 .6416 Mdot
.69556 .60888 Mdot
.4712 .34223 Mdot
.49237 .37328 Mdot
.67025 .57964 Mdot
.71512 .43896 Mdot
.666 .38191 Mdot
.68889 .41653 Mdot
.36945 .5699 Mdot
.54376 .53474 Mdot
.26664 .25103 Mdot
.68173 .55499 Mdot
.5193 .72047 Mdot
.38322 .42293 Mdot
.47583 .40734 Mdot
.54067 .68624 Mdot
.52809 .7388 Mdot
.70336 .4398 Mdot
.69344 .60727 Mdot
.3263 .60131 Mdot
.50179 .68953 Mdot
.39608 .56218 Mdot
.63815 .34792 Mdot
.51882 .41684 Mdot
.55491 .3126 Mdot
.50519 .40001 Mdot
.59139 .41807 Mdot
.49171 .70247 Mdot
.47765 .37358 Mdot
.53299 .36879 Mdot
.5427 .70708 Mdot
.6993 .42911 Mdot
.3646 .62126 Mdot
.65417 .61122 Mdot
.62708 .84374 Mdot
.48991 .3325 Mdot
.45878 .34996 Mdot
.54381 .69946 Mdot
.33447 .46741 Mdot
.34284 .53959 Mdot
.33643 .58784 Mdot
.67921 .59112 Mdot
.52905 .49919 Mdot
.48906 .32464 Mdot
.4983 .34521 Mdot
.64718 .59186 Mdot
.46318 .59373 Mdot
.57977 .17382 Mdot
.48301 .36283 Mdot
.51345 .69798 Mdot
.54272 .60292 Mdot
.49275 .69547 Mdot
.41291 .36132 Mdot
.4781 .34297 Mdot
.5072 .37847 Mdot
.50776 .35266 Mdot
.50425 .71475 Mdot
.50261 .40055 Mdot
.52564 .36484 Mdot
.33517 .57153 Mdot
.46878 .38991 Mdot
.54953 .25333 Mdot
.47922 .36208 Mdot
.74391 .42777 Mdot
.49282 .49651 Mdot
.44435 .35881 Mdot
.46558 .38945 Mdot
.55593 .26096 Mdot
.45565 .33764 Mdot
.53791 .6855 Mdot
.34081 .54898 Mdot
.52536 .69877 Mdot
.52643 .71762 Mdot
.6763 .62652 Mdot
.70476 .4064 Mdot
.50739 .4067 Mdot
.71259 .4459 Mdot
.4619 .41933 Mdot
.45532 .45 Mdot
.60757 .36194 Mdot
.50137 .48753 Mdot
.75212 .42814 Mdot
.49887 .34899 Mdot
.68562 .59357 Mdot
.70326 .59241 Mdot
.55855 .5546 Mdot
.43737 .42934 Mdot
.51238 .67915 Mdot
.52644 .72648 Mdot
.73992 .37609 Mdot
.75973 .47602 Mdot
.73346 .44792 Mdot
.63894 .41242 Mdot
.42481 .32016 Mdot
.46217 .38135 Mdot
.41505 .41774 Mdot
.64857 .62574 Mdot
.45611 .61203 Mdot
.64505 .58496 Mdot
.47598 .64859 Mdot
.49795 .70547 Mdot
.49079 .33031 Mdot
.23543 .70966 Mdot
.37208 .57519 Mdot
.34117 .54856 Mdot
.49413 .71783 Mdot
.69504 .56998 Mdot
.43999 .4346 Mdot
.56019 .85617 Mdot
.31405 .58992 Mdot
.74235 .40471 Mdot
.45034 .34297 Mdot
.68296 .61633 Mdot
.36391 .58123 Mdot
.7342 .39624 Mdot
.50669 .35299 Mdot
.62859 .6187 Mdot
.47347 .3695 Mdot
.26049 .38709 Mdot
.3397 .57931 Mdot
.59636 .36647 Mdot
.36389 .53944 Mdot
.504 .71117 Mdot
.53535 .6984 Mdot
.47943 .34543 Mdot
.59089 .85504 Mdot
.40471 .57215 Mdot
.533 .73937 Mdot
.72188 .39841 Mdot
.46414 .61154 Mdot
.71432 .40228 Mdot
.67321 .58089 Mdot
.73744 .44052 Mdot
.67102 .62713 Mdot
.62178 .5685 Mdot
.29177 .56437 Mdot
.72123 .40958 Mdot
.35544 .41569 Mdot
.45892 .44319 Mdot
.7163 .45523 Mdot
.43583 .34702 Mdot
.44333 .41321 Mdot
.64619 .60493 Mdot
.71599 .44522 Mdot
.48199 .40285 Mdot
.3361 .66468 Mdot
.53531 .70637 Mdot
.5193 .67755 Mdot
.4735 .44269 Mdot
.70332 .62549 Mdot
.30218 .54157 Mdot
.61254 .40306 Mdot
.42591 .57997 Mdot
.49644 .34228 Mdot
.48047 .4166 Mdot
.32543 .52776 Mdot
.3536 .54075 Mdot
.48259 .34535 Mdot
.2316 .52498 Mdot
.50511 .38915 Mdot
.521 .68704 Mdot
.37033 .57057 Mdot
.34666 .55034 Mdot
.71318 .60274 Mdot
.34605 .59179 Mdot
.49351 .30667 Mdot
.53152 .74693 Mdot
.51928 .35239 Mdot
.52139 .7018 Mdot
.65345 .55483 Mdot
.64861 .61733 Mdot
.40893 .64431 Mdot
.34745 .59087 Mdot
.42243 .35546 Mdot
.37059 .58406 Mdot
.74032 .41232 Mdot
.34026 .54518 Mdot
.33821 .52333 Mdot
.45548 .32593 Mdot
.49809 .3996 Mdot
.46052 .59417 Mdot
.57644 .42894 Mdot
.34646 .57782 Mdot
.42712 .39205 Mdot
.43321 .3287 Mdot
.49455 .37396 Mdot
.61775 .3852 Mdot
.38588 .57117 Mdot
.31047 .49957 Mdot
.44551 .56918 Mdot
.34542 .58132 Mdot
.17672 .38248 Mdot
.4547 .58932 Mdot
.45999 .58538 Mdot
.48728 .70013 Mdot
.48453 .36029 Mdot
.66816 .60866 Mdot
.45086 .3869 Mdot
.39875 .38902 Mdot
.44525 .35564 Mdot
.72343 .40653 Mdot
.48955 .32319 Mdot
.44939 .60092 Mdot
.68124 .60496 Mdot
.43878 .39961 Mdot
.47724 .35194 Mdot
.45624 .58565 Mdot
.38543 .56744 Mdot
.32903 .58876 Mdot
.45584 .57925 Mdot
.70921 .4477 Mdot
.50889 .73219 Mdot
.44673 .38125 Mdot
.68186 .59233 Mdot
.67518 .6108 Mdot
.38098 .581 Mdot
.6512 .58655 Mdot
.50224 .72701 Mdot
.48051 .33396 Mdot
.50443 .71234 Mdot
.72403 .40625 Mdot
.35774 .577 Mdot
.43959 .36171 Mdot
.45566 .39624 Mdot
.32482 .57615 Mdot
.50257 .39393 Mdot
.73319 .40393 Mdot
.66267 .63228 Mdot
.34456 .54374 Mdot
.52083 .71407 Mdot
.71059 .60826 Mdot
.42812 .37846 Mdot
.15213 .47558 Mdot
.46452 .33854 Mdot
.502 .35024 Mdot
.4014 .54905 Mdot
.42798 .32439 Mdot
.69312 .61092 Mdot
.36397 .58756 Mdot
.43252 .39971 Mdot
.55966 .26252 Mdot
.73397 .38611 Mdot
.64294 .57158 Mdot
.45869 .3307 Mdot
.18814 .49262 Mdot
.42771 .3364 Mdot
.40277 .64279 Mdot
.60733 .36223 Mdot
.58672 .71324 Mdot
.55475 .31254 Mdot
.52874 .74085 Mdot
.46574 .59856 Mdot
.66925 .62449 Mdot
.31474 .46344 Mdot
.4785 .33976 Mdot
.34866 .3106 Mdot
.43978 .36616 Mdot
.51387 .69165 Mdot
.36018 .45859 Mdot
.66362 .57685 Mdot
.57971 .18484 Mdot
.48553 .38642 Mdot
.31683 .53611 Mdot
.69026 .63666 Mdot
.46757 .59568 Mdot
.49506 .40035 Mdot
.73075 .4521 Mdot
.74293 .37965 Mdot
.48627 .3041 Mdot
.52361 .70267 Mdot
.47698 .38172 Mdot
.41695 .31873 Mdot
.75417 .69845 Mdot
.32858 .5633 Mdot
.53211 .71767 Mdot
.751 .47759 Mdot
.49377 .37047 Mdot
.32294 .58518 Mdot
.3366 .55065 Mdot
.7046 .43608 Mdot
.5463 .66489 Mdot
.69421 .38123 Mdot
.20655 .64328 Mdot
.38323 .24557 Mdot
.65112 .62759 Mdot
.28208 .58728 Mdot
.45897 .3922 Mdot
.69779 .27268 Mdot
.5228 .718 Mdot
.45698 .35018 Mdot
.3501 .33744 Mdot
.32699 .55498 Mdot
.47914 .36888 Mdot
.72612 .43962 Mdot
.41443 .8091 Mdot
.23311 .45129 Mdot
.18257 .52013 Mdot
.62809 .62303 Mdot
.51694 .39793 Mdot
.50101 .31331 Mdot
.42851 .58542 Mdot
.42035 .38831 Mdot
.6973 .59749 Mdot
.55935 .61766 Mdot
.71284 .42734 Mdot
.3712 .57842 Mdot
.46236 .59027 Mdot
.43939 .36589 Mdot
.52472 .38247 Mdot
.73022 .40028 Mdot
.49847 .39031 Mdot
.26493 .48344 Mdot
.47833 .61558 Mdot
.70414 .61738 Mdot
.31479 .53976 Mdot
.49743 .41202 Mdot
.46622 .60861 Mdot
.4509 .32837 Mdot
.38837 .29297 Mdot
.45258 .36271 Mdot
.39954 .63164 Mdot
.32363 .57854 Mdot
.52757 .70715 Mdot
.50095 .33269 Mdot
.47079 .36361 Mdot
.63557 .51535 Mdot
.44199 .43646 Mdot
.4488 .37348 Mdot
.37539 .58795 Mdot
.3728 .57627 Mdot
.33049 .53561 Mdot
.71243 .5964 Mdot
.53094 .47401 Mdot
.50964 .70659 Mdot
.41741 .41932 Mdot
.50088 .69022 Mdot
.5621 .3269 Mdot
.71713 .40403 Mdot
.39841 .65219 Mdot
.48451 .33862 Mdot
.31205 .55627 Mdot
.31689 .24088 Mdot
.38531 .5739 Mdot
.5273 .75913 Mdot
.52639 .71485 Mdot
.34361 .57151 Mdot
.45987 .33269 Mdot
.564 .4361 Mdot
.18318 .53645 Mdot
.52435 .68285 Mdot
.48895 .4408 Mdot
.61963 .59847 Mdot
.68862 .56013 Mdot
.18841 .36485 Mdot
.50761 .6875 Mdot
.48785 .81198 Mdot
.42592 .37958 Mdot
.36216 .58625 Mdot
.51314 .73157 Mdot
.55091 .7155 Mdot
.6515 .5845 Mdot
.45218 .3981 Mdot
.47274 .36516 Mdot
.44293 .59043 Mdot
.50953 .72287 Mdot
.45342 .27795 Mdot
.46031 .40256 Mdot
.46118 .66229 Mdot
.29617 .56758 Mdot
.81755 .61482 Mdot
.41188 .47629 Mdot
.34928 .33634 Mdot
.74401 .66709 Mdot
.34852 .54435 Mdot
.47141 .38611 Mdot
.43696 .4323 Mdot
.64856 .62908 Mdot
.4728 .333 Mdot
.70539 .57321 Mdot
.50217 .70109 Mdot
.34065 .64986 Mdot
.50467 .55237 Mdot
.49208 .6448 Mdot
.46311 .34156 Mdot
.23223 .46065 Mdot
.71901 .41434 Mdot
.49778 .74936 Mdot
.35207 .54196 Mdot
.41373 .35861 Mdot
.63699 .61783 Mdot
.71025 .58872 Mdot
.33183 .55658 Mdot
.45964 .77451 Mdot
.40246 .64559 Mdot
.5107 .37116 Mdot
.68718 .57884 Mdot
.44708 .51431 Mdot
.20213 .4627 Mdot
.49308 .7236 Mdot
.71245 .42414 Mdot
.67897 .62164 Mdot
.53536 .67534 Mdot
.44908 .41649 Mdot
.34092 .56285 Mdot
.31419 .53451 Mdot
.57037 .56152 Mdot
.657 .60901 Mdot
.73231 .42968 Mdot
.56508 .56382 Mdot
.54719 .54034 Mdot
.71996 .43198 Mdot
.71302 .58075 Mdot
.36765 .55843 Mdot
.31855 .55278 Mdot
.34095 .54968 Mdot
.28916 .49427 Mdot
.32867 .59874 Mdot
.69381 .33401 Mdot
.41758 .38239 Mdot
.21558 .47808 Mdot
.41597 .36216 Mdot
.534 .68045 Mdot
.3384 .58028 Mdot
.60444 .36173 Mdot
.43303 .31365 Mdot
.1885 .53778 Mdot
.46127 .37221 Mdot
.54312 .59402 Mdot
.48416 .35899 Mdot
.2593 .43574 Mdot
.35596 .60014 Mdot
.50521 .37095 Mdot
.52592 .74992 Mdot
.73857 .41757 Mdot
.29726 .5303 Mdot
.45255 .37661 Mdot
.40058 .75705 Mdot
.43549 .3483 Mdot
.35418 .64407 Mdot
.58304 .56158 Mdot
.71651 .4612 Mdot
.46225 .31192 Mdot
.63514 .60614 Mdot
.3811 .38383 Mdot
.21638 .47035 Mdot
.52176 .68276 Mdot
.2293 .46757 Mdot
.66572 .57244 Mdot
.35757 .45878 Mdot
.42738 .31035 Mdot
.71305 .43169 Mdot
.37463 .62116 Mdot
.52713 .68755 Mdot
.48499 .34171 Mdot
.48429 .38513 Mdot
.5177 .62884 Mdot
.21456 .44734 Mdot
.43154 .28037 Mdot
.75048 .41111 Mdot
.23047 .4443 Mdot
.44758 .3675 Mdot
.63632 .57778 Mdot
.34713 .59479 Mdot
.36626 .45578 Mdot
.34539 .46503 Mdot
.45399 .4043 Mdot
.33952 .56837 Mdot
.3389 .59149 Mdot
.34942 .21237 Mdot
.70975 .41652 Mdot
.45367 .36531 Mdot
.57693 .57251 Mdot
.44443 .37661 Mdot
.50921 .69709 Mdot
.42184 .32501 Mdot
.64875 .61576 Mdot
.48844 .48476 Mdot
.71234 .59366 Mdot
.49838 .37062 Mdot
.35616 .56915 Mdot
.53763 .69285 Mdot
.58863 .7473 Mdot
.55263 .67244 Mdot
.69274 .33452 Mdot
.75946 .38389 Mdot
.73595 .44738 Mdot
.70846 .40598 Mdot
.48532 .71519 Mdot
.46503 .32881 Mdot
.59483 .42017 Mdot
.4342 .41755 Mdot
.4884 .3623 Mdot
.45003 .36015 Mdot
.55976 .76526 Mdot
.52714 .71341 Mdot
.67143 .61693 Mdot
.48345 .34516 Mdot
.42556 .39064 Mdot
.3519 .57128 Mdot
.73376 .44684 Mdot
.68491 .6279 Mdot
.73124 .45478 Mdot
.68354 .60053 Mdot
.26222 .27662 Mdot
.51235 .42475 Mdot
.73529 .41468 Mdot
.49304 .70474 Mdot
.31745 .54686 Mdot
.44144 .58549 Mdot
.6697 .58282 Mdot
.66049 .57951 Mdot
.48992 .41228 Mdot
.35636 .58223 Mdot
.34092 .58952 Mdot
.7229 .45222 Mdot
.52632 .72768 Mdot
.48606 .42054 Mdot
.48702 .4058 Mdot
.6002 .73131 Mdot
.66138 .63309 Mdot
.22463 .45652 Mdot
.41152 .57754 Mdot
.47701 .32882 Mdot
.3216 .58326 Mdot
.4673 .35521 Mdot
.45352 .52584 Mdot
.33491 .53392 Mdot
.42443 .32642 Mdot
.40803 .38865 Mdot
.65382 .62766 Mdot
.40788 .1898 Mdot
.50722 .41242 Mdot
.5621 .72488 Mdot
.47135 .39548 Mdot
.54362 .14643 Mdot
.32996 .23327 Mdot
.4417 .33575 Mdot
.49855 .33602 Mdot
.19217 .616 Mdot
.43502 .33055 Mdot
.44449 .59552 Mdot
.39868 .39018 Mdot
.31509 .57692 Mdot
.56288 .58344 Mdot
.58799 .42139 Mdot
.70699 .41626 Mdot
.68022 .59066 Mdot
.63044 .32234 Mdot
.69931 .41969 Mdot
.32173 .55494 Mdot
.52129 .40354 Mdot
.40915 .57307 Mdot
.72305 .58144 Mdot
.47168 .28078 Mdot
.51078 .69423 Mdot
.58824 .42373 Mdot
.64089 .59812 Mdot
.52041 .7151 Mdot
.42797 .33435 Mdot
.71735 .54692 Mdot
.50882 .75445 Mdot
.36437 .19756 Mdot
.5414 .72165 Mdot
.53251 .70343 Mdot
.54774 .45273 Mdot
.70668 .41664 Mdot
.55705 .62601 Mdot
.4855 .45572 Mdot
.53676 .68696 Mdot
.58687 .20947 Mdot
.65037 .63197 Mdot
.5362 .48463 Mdot
.36601 .59736 Mdot
.5013 .43456 Mdot
.45278 .35158 Mdot
.53885 .71901 Mdot
.29606 .59825 Mdot
.64469 .50683 Mdot
.50468 .69427 Mdot
.46192 .30483 Mdot
.5199 .49909 Mdot
.46243 .60983 Mdot
.45215 .58842 Mdot
.73383 .39702 Mdot
.77325 .51757 Mdot
.31858 .57471 Mdot
.74444 .40754 Mdot
.58665 .33985 Mdot
.46576 .3765 Mdot
.50409 .71799 Mdot
.46014 .58741 Mdot
.51919 .71241 Mdot
.72298 .4194 Mdot
.72592 .40009 Mdot
.3338 .57021 Mdot
.34889 .54222 Mdot
.30504 .62151 Mdot
.5299 .23245 Mdot
.43952 .38244 Mdot
.32965 .32036 Mdot
.3513 .53957 Mdot
.32338 .46967 Mdot
.70717 .43379 Mdot
.72408 .4474 Mdot
.23962 .3669 Mdot
.43168 .38231 Mdot
.54307 .60136 Mdot
.44475 .3625 Mdot
.63331 .24783 Mdot
.43853 .3628 Mdot
.64899 .58942 Mdot
.48775 .38838 Mdot
.33282 .74649 Mdot
.43154 .39484 Mdot
.44812 .35608 Mdot
.66425 .59314 Mdot
.50338 .40823 Mdot
.64622 .61009 Mdot
.46902 .38459 Mdot
.7663 .41973 Mdot
.68126 .59238 Mdot
.75988 .4422 Mdot
.53573 .5624 Mdot
.45233 .59494 Mdot
.70634 .41114 Mdot
.73753 .44824 Mdot
.63375 .35997 Mdot
.37428 .56231 Mdot
.39299 .4692 Mdot
.45117 .34208 Mdot
.6864 .63351 Mdot
.50077 .7216 Mdot
.45771 .4052 Mdot
.46261 .31485 Mdot
.49739 .4168 Mdot
.3376 .57112 Mdot
.71745 .59632 Mdot
.72926 .41565 Mdot
.70473 .59426 Mdot
.76521 .42669 Mdot
.64759 .61972 Mdot
.47362 .4377 Mdot
.45816 .41878 Mdot
.5054 .31757 Mdot
.3386 .37287 Mdot
.75052 .30486 Mdot
.33647 .5596 Mdot
.46221 .60412 Mdot
.71855 .40267 Mdot
.54636 .51767 Mdot
.31288 .56748 Mdot
.65742 .58317 Mdot
.47318 .36958 Mdot
.51945 .4173 Mdot
.47074 .45371 Mdot
.37733 .53223 Mdot
.74061 .46179 Mdot
.67292 .58611 Mdot
.45062 .60703 Mdot
.52746 .48091 Mdot
.31602 .50282 Mdot
.59499 .33279 Mdot
.46901 .35967 Mdot
.72114 .45258 Mdot
.36408 .58113 Mdot
.54105 .6186 Mdot
.53898 .71613 Mdot
.57289 .43246 Mdot
.46162 .34117 Mdot
.50528 .78058 Mdot
.35587 .56764 Mdot
.72098 .44143 Mdot
.53965 .71816 Mdot
.7079 .42313 Mdot
.4707 .60822 Mdot
.42493 .57284 Mdot
.49332 .4 Mdot
.44346 .36151 Mdot
.49892 .71137 Mdot
.32274 .57956 Mdot
.76032 .40308 Mdot
.53051 .63131 Mdot
.67314 .57985 Mdot
.52759 .51174 Mdot
.36936 .57907 Mdot
.53237 .79201 Mdot
.70666 .58877 Mdot
.51181 .6774 Mdot
.5918 .41319 Mdot
.507 .73364 Mdot
.44856 .36515 Mdot
.3607 .56214 Mdot
.51806 .68243 Mdot
.60457 .70248 Mdot
.22036 .55152 Mdot
.4014 .61475 Mdot
.49984 .36422 Mdot
.38254 .65537 Mdot
.4501 .78916 Mdot
.27038 .57257 Mdot
.50167 .69118 Mdot
.47049 .3459 Mdot
.51052 .37294 Mdot
.48644 .38658 Mdot
.53732 .70813 Mdot
.56216 .77515 Mdot
.68436 .57252 Mdot
.48014 .3738 Mdot
.74597 .42973 Mdot
.65422 .61806 Mdot
.66217 .56606 Mdot
.68117 .62114 Mdot
.35866 .54486 Mdot
.5187 .41494 Mdot
.40732 .4138 Mdot
.37827 .20939 Mdot
.53035 .70485 Mdot
.45225 .5953 Mdot
.50475 .35544 Mdot
.6843 .34031 Mdot
.31861 .54812 Mdot
.66275 .58743 Mdot
.45808 .35112 Mdot
.57789 .56279 Mdot
.47551 .61928 Mdot
.67001 .59915 Mdot
.34471 .53783 Mdot
.26649 .55655 Mdot
.47542 .33341 Mdot
.46341 .39469 Mdot
.32064 .56678 Mdot
.45298 .80635 Mdot
.52275 .48649 Mdot
.46975 .3548 Mdot
.52632 .71105 Mdot
.63956 .82423 Mdot
.4221 .34143 Mdot
.39687 .58995 Mdot
.45329 .61121 Mdot
.41107 .56484 Mdot
.23143 .49975 Mdot
.41781 .41329 Mdot
.29687 .64261 Mdot
.69736 .36185 Mdot
.26212 .6106 Mdot
.65513 .26242 Mdot
.53515 .63639 Mdot
.30804 .2252 Mdot
.56006 .71289 Mdot
.25686 .4154 Mdot
.31414 .78386 Mdot
.48177 .805 Mdot
.62241 .53065 Mdot
.59497 .66815 Mdot
.6985 .54366 Mdot
.58682 .17871 Mdot
.63538 .60026 Mdot
.66122 .25247 Mdot
.44088 .35387 Mdot
.44329 .80015 Mdot
.25192 .43816 Mdot
.77326 .34395 Mdot
.41614 .64747 Mdot
.5748 .56532 Mdot
.16324 .51243 Mdot
.43808 .65536 Mdot
.19719 .38807 Mdot
.36331 .36351 Mdot
.79831 .54017 Mdot
.5465 .52607 Mdot
.64529 .32925 Mdot
.23715 .47349 Mdot
.30869 .71009 Mdot
.47282 .68089 Mdot
.30933 .29272 Mdot
.76748 .65765 Mdot
.69316 .58632 Mdot
.34135 .59595 Mdot
.58821 .64144 Mdot
.18904 .43708 Mdot
.54311 .75231 Mdot
.29543 .64196 Mdot
.45312 .62692 Mdot
.25796 .43083 Mdot
.59544 .3615 Mdot
.26491 .37923 Mdot
.69049 .38047 Mdot
.59233 .18693 Mdot
.35539 .51881 Mdot
.62057 .68184 Mdot
.55271 .50812 Mdot
.64747 .41283 Mdot
.27003 .45975 Mdot
.7502 .40286 Mdot
.75185 .40061 Mdot
.33823 .53545 Mdot
.19691 .44706 Mdot
.4792 .62082 Mdot
.58298 .33433 Mdot
.63343 .60867 Mdot
.46214 .52908 Mdot
.40648 .80228 Mdot
.44522 .78069 Mdot
.44881 .18136 Mdot
.1576 .46225 Mdot
.59055 .24155 Mdot
.53255 .61146 Mdot
.55271 .75744 Mdot
.6687 .35047 Mdot
.42254 .27671 Mdot
.57078 .22463 Mdot
.38348 .30177 Mdot
.17795 .56511 Mdot
.42074 .74591 Mdot
.15252 .50096 Mdot
.33794 .51639 Mdot
.53152 .36471 Mdot
.49513 .5765 Mdot
.38298 .25488 Mdot
.58942 .29893 Mdot
.16481 .48384 Mdot
.7023 .45181 Mdot
.30952 .59769 Mdot
.48449 .80442 Mdot
.26178 .48473 Mdot
.66034 .4146 Mdot
.78819 .40693 Mdot
.37409 .45896 Mdot
.15512 .53915 Mdot
.30175 .64712 Mdot
.29062 .27205 Mdot
.46175 .67545 Mdot
.72844 .61142 Mdot
.65631 .56947 Mdot
.54971 .72042 Mdot
.18098 .41998 Mdot
.3535 .55862 Mdot
.39968 .18869 Mdot
.28175 .61417 Mdot
.37884 .3649 Mdot
.154 .54978 Mdot
.53726 .18872 Mdot
.2211 .49113 Mdot
.72555 .31597 Mdot
.60504 .81493 Mdot
.46273 .26034 Mdot
.55808 .67476 Mdot
.62761 .58558 Mdot
.37966 .63966 Mdot
.17905 .43145 Mdot
.56987 .2096 Mdot
.23063 .69165 Mdot
.57972 .33014 Mdot
.74747 .59027 Mdot
.36874 .51994 Mdot
.64922 .52241 Mdot
.65418 .44102 Mdot
.15223 .49607 Mdot
.23798 .43936 Mdot
.63235 .82033 Mdot
.64198 .2688 Mdot
.33808 .46958 Mdot
.36729 .6661 Mdot
.60636 .58384 Mdot
.43982 .2505 Mdot
.41361 .75918 Mdot
.51907 .38862 Mdot
.60226 .3273 Mdot
.36851 .42432 Mdot
.68057 .41661 Mdot
.52339 .47915 Mdot
.42036 .72537 Mdot
.60828 .27236 Mdot
.52676 .80751 Mdot
.37863 .46981 Mdot
.34618 .53157 Mdot
.57377 .22997 Mdot
.61756 .25221 Mdot
.4582 .72007 Mdot
.75198 .47633 Mdot
.28322 .27662 Mdot
.6917 .49743 Mdot
.40975 .40448 Mdot
.25675 .40858 Mdot
.23938 .47435 Mdot
.6057 .21678 Mdot
.48027 .43863 Mdot
.41745 .19714 Mdot
.46535 .64217 Mdot
.32556 .38212 Mdot
.58904 .27923 Mdot
.33472 .37681 Mdot
.20175 .50214 Mdot
.47876 .56619 Mdot
.57934 .71275 Mdot
.31706 .61171 Mdot
.15683 .53917 Mdot
.66344 .61921 Mdot
.56658 .21658 Mdot
.5588 .72064 Mdot
.6011 .71695 Mdot
.55981 .63947 Mdot
.65172 .50451 Mdot
.18962 .38466 Mdot
.47142 .78425 Mdot
.60659 .61312 Mdot
.28656 .69603 Mdot
.43936 .51008 Mdot
.32641 .32923 Mdot
.53079 .33337 Mdot
.38302 .31175 Mdot
.73274 .40361 Mdot
.33762 .42691 Mdot
.44899 .56481 Mdot
.80182 .40703 Mdot
.43508 .42227 Mdot
.55506 .53164 Mdot
.43929 .59795 Mdot
.58072 .44102 Mdot
.26032 .27684 Mdot
.53303 .3352 Mdot
.53454 .19179 Mdot
.47009 .79049 Mdot
.59391 .42951 Mdot
.65334 .4331 Mdot
.39704 .48431 Mdot
.15083 .50655 Mdot
.21309 .32744 Mdot
.40608 .78075 Mdot
.36715 .65612 Mdot
.7044 .21085 Mdot
.58445 .70649 Mdot
.44855 .19616 Mdot
.55558 .72692 Mdot
.89257 .59711 Mdot
.70666 .59406 Mdot
.70296 .27058 Mdot
.37599 .26969 Mdot
.59539 .52933 Mdot
.19045 .44491 Mdot
.24783 .485 Mdot
.7616 .45475 Mdot
.35221 .52924 Mdot
.45611 .43729 Mdot
.17196 .48102 Mdot
.16094 .53808 Mdot
.17177 .48665 Mdot
.5011 .77033 Mdot
.19726 .52739 Mdot
.17842 .59644 Mdot
.6962 .3338 Mdot
.50432 .62064 Mdot
.42394 .31347 Mdot
.51593 .22164 Mdot
.50767 .19528 Mdot
.69483 .45124 Mdot
.46774 .26113 Mdot
.35581 .51821 Mdot
.16831 .58436 Mdot
.26266 .2724 Mdot
.27088 .35306 Mdot
.20392 .37355 Mdot
.6122 .64409 Mdot
.53731 .22584 Mdot
.20054 .36178 Mdot
.30281 .68845 Mdot
.45648 .65047 Mdot
.18308 .61669 Mdot
.62073 .26114 Mdot
.59552 .67123 Mdot
.37488 .75933 Mdot
.48407 .19282 Mdot
.3562 .66383 Mdot
.59435 .64585 Mdot
.41095 .2762 Mdot
.34504 .50314 Mdot
.65479 .50492 Mdot
.30095 .70339 Mdot
.53691 .60463 Mdot
.57547 .26383 Mdot
.67502 .56482 Mdot
.55616 .21456 Mdot
.64208 .44712 Mdot
.50666 .62224 Mdot
.63081 .33599 Mdot
.57836 .20384 Mdot
.38293 .73844 Mdot
.1845 .50753 Mdot
.47186 .78998 Mdot
.59598 .82475 Mdot
.41174 .67755 Mdot
.37039 .4175 Mdot
.50347 .40859 Mdot
.18615 .44338 Mdot
.19587 .32491 Mdot
.19166 .37383 Mdot
.47709 .76643 Mdot
.63418 .64435 Mdot
.52097 .67224 Mdot
.65867 .3501 Mdot
.60861 .51913 Mdot
.43084 .62411 Mdot
.61365 .4529 Mdot
.55774 .70325 Mdot
.41987 .81173 Mdot
.32282 .62611 Mdot
.68238 .34345 Mdot
.29876 .30983 Mdot
.45252 .27427 Mdot
.20303 .45999 Mdot
.32531 .52715 Mdot
.48582 .77564 Mdot
.56896 .22261 Mdot
.66779 .62118 Mdot
.60628 .71995 Mdot
.32356 .61069 Mdot
.53276 .37611 Mdot
.62099 .64882 Mdot
.40826 .60949 Mdot
.34783 .33556 Mdot
.62546 .63239 Mdot
.28331 .25027 Mdot
.43588 .19203 Mdot
.20172 .35834 Mdot
.58655 .23258 Mdot
.61294 .69907 Mdot
.56126 .45652 Mdot
.57061 .73074 Mdot
.42617 .64979 Mdot
.54986 .49419 Mdot
.58856 .22672 Mdot
.21605 .49222 Mdot
.48441 .59919 Mdot
.41471 .41422 Mdot
.30962 .24555 Mdot
.66816 .32887 Mdot
.56574 .46084 Mdot
.38275 .49677 Mdot
.31393 .59132 Mdot
.75485 .29829 Mdot
.32336 .72643 Mdot
.39305 .40285 Mdot
.37282 .66021 Mdot
.4922 .72645 Mdot
.33226 .5318 Mdot
.57672 .20051 Mdot
.76498 .48503 Mdot
.26864 .6004 Mdot
.50776 .57518 Mdot
.18909 .41941 Mdot
.52487 .55419 Mdot
.35171 .65524 Mdot
.24306 .61444 Mdot
.66038 .79875 Mdot
.33572 .51715 Mdot
.52267 .61289 Mdot
.56949 .62698 Mdot
.33803 .51102 Mdot
.37934 .53807 Mdot
.23559 .4488 Mdot
.16902 .4336 Mdot
.55865 .56565 Mdot
.28922 .68326 Mdot
.59461 .4228 Mdot
.64668 .51897 Mdot
.49734 .60208 Mdot
.6291 .32691 Mdot
.27954 .65338 Mdot
.24684 .33368 Mdot
.49994 .84569 Mdot
.48539 .26551 Mdot
.69404 .26154 Mdot
.65979 .35118 Mdot
.36425 .3663 Mdot
.26956 .45482 Mdot
.45089 .6651 Mdot
.45453 .38619 Mdot
.15737 .44452 Mdot
.42512 .73913 Mdot
.62692 .3778 Mdot
.62515 .56243 Mdot
.42422 .35041 Mdot
.50312 .31706 Mdot
.19704 .36982 Mdot
.39622 .53398 Mdot
.40467 .84541 Mdot
.64299 .26104 Mdot
.37422 .38677 Mdot
.22221 .50103 Mdot
.53008 .19342 Mdot
.47545 .55861 Mdot
.28777 .62208 Mdot
.64559 .4563 Mdot
.50734 .191 Mdot
.26351 .66284 Mdot
.3098 .7247 Mdot
.40666 .67085 Mdot
.17883 .58899 Mdot
.38641 .42844 Mdot
.4697 .66639 Mdot
.61569 .65123 Mdot
.50041 .34394 Mdot
.45802 .7737 Mdot
.40128 .65963 Mdot
.70385 .52227 Mdot
.42255 .27394 Mdot
.19101 .32965 Mdot
.40343 .33655 Mdot
.45803 .75779 Mdot
.38321 .82961 Mdot
.46263 .8698 Mdot
.32485 .7408 Mdot
.15178 .4919 Mdot
.29682 .71223 Mdot
.34636 .65831 Mdot
.48737 .71531 Mdot
.53829 .5327 Mdot
.34189 .31201 Mdot
.16795 .41606 Mdot
.78717 .50247 Mdot
.54513 .65986 Mdot
.33348 .27787 Mdot
.16575 .41737 Mdot
.39977 .3694 Mdot
.73049 .27887 Mdot
.72131 .62185 Mdot
.56926 .17147 Mdot
.46188 .18113 Mdot
.36678 .49425 Mdot
.59684 .20685 Mdot
.70258 .25425 Mdot
.75216 .34306 Mdot
.44413 .1937 Mdot
.43132 .24125 Mdot
.39124 .50993 Mdot
.57874 .23722 Mdot
.3878 .64305 Mdot
.64207 .18414 Mdot
.49917 .59744 Mdot
.47362 .62902 Mdot
.42068 .56812 Mdot
.37822 .63885 Mdot
.38239 .72329 Mdot
.51672 .59531 Mdot
.4807 .49346 Mdot
.20425 .4897 Mdot
.66267 .82047 Mdot
.27891 .71076 Mdot
.33579 .62094 Mdot
.16516 .5347 Mdot
.45661 .67297 Mdot
.56091 .49165 Mdot
.27493 .4692 Mdot
.66238 .33755 Mdot
.6105 .62313 Mdot
.44487 .35566 Mdot
.16777 .43795 Mdot
.61081 .62185 Mdot
.16961 .51377 Mdot
.37218 .1927 Mdot
.21356 .36741 Mdot
.51763 .30653 Mdot
.63047 .5788 Mdot
.52827 .20552 Mdot
.53005 .20861 Mdot
.18736 .56567 Mdot
.67772 .24728 Mdot
.53885 .50081 Mdot
.52879 .57651 Mdot
.50476 .55708 Mdot
.40029 .42465 Mdot
.52298 .19047 Mdot
.40562 .48993 Mdot
.5981 .28855 Mdot
.38588 .77332 Mdot
.58242 .21446 Mdot
.22971 .48951 Mdot
.64918 .3445 Mdot
.68211 .49317 Mdot
.76514 .44685 Mdot
.66437 .6342 Mdot
.20977 .66056 Mdot
.437 .68322 Mdot
.408 .19973 Mdot
.60023 .82111 Mdot
.41755 .75936 Mdot
.65829 .24646 Mdot
.47964 .599 Mdot
.47202 .25439 Mdot
.79351 .52798 Mdot
.6169 .28441 Mdot
.22846 .45769 Mdot
.39672 .64466 Mdot
.34191 .48646 Mdot
.1806 .39939 Mdot
.57931 .26986 Mdot
.26693 .74738 Mdot
.7073 .6531 Mdot
.3377 .42056 Mdot
.20874 .43253 Mdot
.57105 .83122 Mdot
.57135 .45626 Mdot
.15729 .54178 Mdot
.38839 .58253 Mdot
.1577 .46632 Mdot
.53539 .72854 Mdot
.74085 .55362 Mdot
.44896 .63879 Mdot
.62946 .3896 Mdot
.62536 .39801 Mdot
.33525 .22194 Mdot
.4786 .79734 Mdot
.44624 .78375 Mdot
.69274 .49847 Mdot
.64409 .58417 Mdot
.51006 .52167 Mdot
.29375 .68012 Mdot
.21637 .6676 Mdot
.47585 .41745 Mdot
.74079 .63306 Mdot
.55347 .20013 Mdot
.57075 .73248 Mdot
.45895 .62729 Mdot
.42898 .63683 Mdot
.25187 .56359 Mdot
.53366 .22703 Mdot
.17404 .58243 Mdot
.4329 .61808 Mdot
.61646 .50261 Mdot
.3486 .45541 Mdot
.48409 .63591 Mdot
.54281 .80452 Mdot
.29259 .65013 Mdot
.51612 .5636 Mdot
.52673 .48525 Mdot
.59402 .24231 Mdot
.24087 .26903 Mdot
.17053 .55274 Mdot
.56798 .81071 Mdot
.59589 .43192 Mdot
.39145 .59262 Mdot
.63029 .30727 Mdot
.26051 .74175 Mdot
.57405 .16828 Mdot
.3851 .75931 Mdot
.57813 .21352 Mdot
.66752 .52835 Mdot
.71282 .27037 Mdot
.55863 .47854 Mdot
.20942 .4299 Mdot
.36718 .26613 Mdot
.42955 .57099 Mdot
.60124 .59296 Mdot
.60496 .40744 Mdot
.51572 .6335 Mdot
.39147 .50768 Mdot
.48104 .79716 Mdot
.26817 .74849 Mdot
.66852 .23643 Mdot
.35894 .46148 Mdot
.28632 .75714 Mdot
.29271 .55825 Mdot
.573 .62954 Mdot
.56841 .79137 Mdot
.60084 .42488 Mdot
.70127 .60767 Mdot
.41379 .28918 Mdot
.5172 .50417 Mdot
.27926 .69494 Mdot
.6837 .53917 Mdot
.69644 .42151 Mdot
.38012 .54508 Mdot
.69091 .24888 Mdot
.30529 .53797 Mdot
.26457 .25278 Mdot
.30509 .68692 Mdot
.21183 .47964 Mdot
.25221 .66437 Mdot
.63841 .6767 Mdot
.60104 .82676 Mdot
.19857 .38515 Mdot
.55913 .26292 Mdot
.37194 .53602 Mdot
.31861 .52608 Mdot
.26217 .65508 Mdot
.52415 .77393 Mdot
.19405 .41694 Mdot
.54279 .19083 Mdot
.61656 .70048 Mdot
.31101 .57931 Mdot
.53489 .58201 Mdot
.33337 .61859 Mdot
.27074 .2601 Mdot
.70303 .5985 Mdot
.15068 .52782 Mdot
.3984 .47731 Mdot
.50793 .82727 Mdot
.41044 .62326 Mdot
.49483 .48015 Mdot
.57515 .45928 Mdot
.60567 .69066 Mdot
.40765 .40482 Mdot
.37525 .38928 Mdot
.35568 .5455 Mdot
.55382 .63936 Mdot
.73434 .44488 Mdot
.78986 .43579 Mdot
.56632 .72459 Mdot
.35861 .37027 Mdot
.50891 .18369 Mdot
.32148 .52765 Mdot
.68997 .65678 Mdot
.69526 .66563 Mdot
.41118 .39319 Mdot
.48398 .21994 Mdot
.19894 .63414 Mdot
.19881 .39164 Mdot
.38718 .57641 Mdot
.56601 .82021 Mdot
.70794 .38068 Mdot
.29252 .24549 Mdot
.26107 .55934 Mdot
.54346 .20159 Mdot
.36202 .41842 Mdot
.21664 .33201 Mdot
.23158 .4993 Mdot
.33246 .63688 Mdot
.57614 .22764 Mdot
.64304 .50936 Mdot
.57391 .20474 Mdot
.25071 .56222 Mdot
.51034 .5461 Mdot
.57 .17446 Mdot
.66366 .53212 Mdot
.26301 .38518 Mdot
.38943 .34112 Mdot
.40784 .6223 Mdot
.52052 .19631 Mdot
.38733 .55559 Mdot
.73267 .39057 Mdot
.3145 .29912 Mdot
.45222 .64592 Mdot
.18092 .42704 Mdot
.4579 .72306 Mdot
.55633 .19666 Mdot
.50079 .55253 Mdot
.66838 .30743 Mdot
.40099 .47785 Mdot
.57865 .30822 Mdot
.49431 .31829 Mdot
.36916 .43362 Mdot
.62337 .45687 Mdot
.34206 .22592 Mdot
.3859 .40881 Mdot
.17668 .46155 Mdot
.27835 .26379 Mdot
.24856 .6023 Mdot
.55477 .61323 Mdot
.32573 .5905 Mdot
.15488 .51998 Mdot
.49496 .21318 Mdot
.40147 .63564 Mdot
.46772 .18112 Mdot
.75278 .29405 Mdot
.30214 .77415 Mdot
.43842 .7178 Mdot
.41113 .60779 Mdot
.40601 .19059 Mdot
.42581 .74504 Mdot
.71696 .26406 Mdot
.23005 .45315 Mdot
.40195 .55131 Mdot
.15451 .55567 Mdot
.39615 .24638 Mdot
.43713 .77964 Mdot
.21009 .4468 Mdot
.2596 .58466 Mdot
.48334 .21244 Mdot
.40931 .41311 Mdot
.63848 .61059 Mdot
.58327 .54133 Mdot
.60292 .21038 Mdot
.26595 .57978 Mdot
.53746 .19579 Mdot
.54455 .20482 Mdot
.67099 .25858 Mdot
.61088 .69205 Mdot
.30319 .77463 Mdot
.22427 .52198 Mdot
.52373 .35257 Mdot
.39294 .56539 Mdot
.70331 .4089 Mdot
.64641 .27455 Mdot
.43897 .39837 Mdot
.58773 .39329 Mdot
.37084 .44855 Mdot
.16156 .43226 Mdot
.67479 .50778 Mdot
.47592 .6699 Mdot
.32223 .59052 Mdot
.38666 .63785 Mdot
.45429 .54529 Mdot
.4811 .80606 Mdot
.52756 .20024 Mdot
.26762 .60121 Mdot
.3043 .6415 Mdot
.42955 .77377 Mdot
.59352 .25736 Mdot
.7051 .3728 Mdot
.51957 .68007 Mdot
.34705 .32371 Mdot
.20219 .58762 Mdot
.43795 .76418 Mdot
.31295 .59807 Mdot
.36014 .73956 Mdot
.51446 .54656 Mdot
.46883 .72276 Mdot
.47561 .79527 Mdot
.46933 .57462 Mdot
.23031 .36162 Mdot
.25964 .62921 Mdot
.61864 .60147 Mdot
.62735 .25526 Mdot
.32845 .72187 Mdot
.53197 .19697 Mdot
.40634 .38256 Mdot
.18334 .46197 Mdot
.62611 .38248 Mdot
.69167 .39439 Mdot
.47474 .39938 Mdot
.38926 .27678 Mdot
.19651 .36972 Mdot
.3636 .75555 Mdot
.42438 .26341 Mdot
.33254 .60563 Mdot
.43705 .18935 Mdot
.61839 .63257 Mdot
.62537 .63528 Mdot
.72243 .30147 Mdot
.47509 .47888 Mdot
.60535 .51848 Mdot
.5724 .75463 Mdot
.40347 .39114 Mdot
.72285 .36954 Mdot
.51293 .57336 Mdot
.34434 .32982 Mdot
.44682 .19938 Mdot
.20633 .64883 Mdot
.49728 .56773 Mdot
.45064 .17934 Mdot
.35947 .27685 Mdot
.39302 .5382 Mdot
.67773 .23966 Mdot
.46322 .26305 Mdot
.47429 .44002 Mdot
.73174 .39056 Mdot
.29783 .58031 Mdot
.20342 .63252 Mdot
.3935 .2996 Mdot
.67208 .43714 Mdot
.67629 .476 Mdot
.50323 .58332 Mdot
.75145 .66077 Mdot
.4665 .64258 Mdot
.40835 .18877 Mdot
.56974 .2229 Mdot
.54573 .67087 Mdot
.28364 .69526 Mdot
.44442 .25979 Mdot
.18054 .46423 Mdot
.63035 .47282 Mdot
.1907 .40045 Mdot
.49186 .76284 Mdot
.34767 .35848 Mdot
.29483 .25512 Mdot
.59877 .3158 Mdot
.58126 .31519 Mdot
.38469 .48795 Mdot
.5273 .26978 Mdot
.4428 .58511 Mdot
.74721 .48708 Mdot
.6292 .18513 Mdot
.238 .70728 Mdot
.49662 .82137 Mdot
.39821 .33385 Mdot
.62587 .30197 Mdot
.2611 .63817 Mdot
.55652 .49885 Mdot
.65835 .45656 Mdot
.63461 .65783 Mdot
.60215 .60382 Mdot
.64499 .82148 Mdot
.15959 .44105 Mdot
.47115 .39873 Mdot
.63013 .42156 Mdot
.79232 .40672 Mdot
.70798 .57652 Mdot
.28879 .314 Mdot
.19774 .62593 Mdot
.53002 .68264 Mdot
.60051 .78788 Mdot
.57949 .73297 Mdot
.33957 .22122 Mdot
.58448 .77951 Mdot
.49255 .74747 Mdot
.26343 .25304 Mdot
.40426 .77672 Mdot
.31144 .50218 Mdot
.65228 .81782 Mdot
.32211 .23699 Mdot
.36572 .41814 Mdot
.61727 .63563 Mdot
.16778 .45504 Mdot
.57234 .4611 Mdot
.60528 .63151 Mdot
.4073 .23307 Mdot
.57588 .22347 Mdot
.63746 .25962 Mdot
.49478 .66373 Mdot
.34954 .2726 Mdot
.80629 .35093 Mdot
.64317 .67738 Mdot
.55028 .85468 Mdot
.20388 .38586 Mdot
.21432 .58062 Mdot
.32093 .73501 Mdot
.71018 .51831 Mdot
.18672 .45403 Mdot
.54485 .211 Mdot
.39141 .26495 Mdot
.77132 .49926 Mdot
.61014 .3287 Mdot
.65059 .32536 Mdot
.46994 .72286 Mdot
.2108 .35429 Mdot
.61526 .68665 Mdot
.4682 .24462 Mdot
.56472 .21006 Mdot
.36672 .27808 Mdot
.57686 .30964 Mdot
.20082 .57635 Mdot
.47853 .21665 Mdot
.59702 .23255 Mdot
.59747 .65938 Mdot
.75609 .40429 Mdot
.20286 .61909 Mdot
.43442 .52068 Mdot
.36348 .42876 Mdot
.38801 .83309 Mdot
.15348 .49841 Mdot
.46519 .26246 Mdot
.42321 .32316 Mdot
.31243 .22107 Mdot
.71136 .6462 Mdot
.44145 .20115 Mdot
.39422 .79319 Mdot
.64596 .25729 Mdot
.3931 .43668 Mdot
.43647 .35872 Mdot
.70091 .31806 Mdot
.36947 .51344 Mdot
.36889 .26928 Mdot
.59381 .75492 Mdot
.59115 .23041 Mdot
.36098 .37502 Mdot
.49888 .84538 Mdot
.25547 .55415 Mdot
.30567 .56025 Mdot
.1654 .44756 Mdot
.30408 .27911 Mdot
.37097 .39794 Mdot
.20223 .43782 Mdot
.62482 .48405 Mdot
.72445 .37029 Mdot
.39708 .46933 Mdot
.56392 .45482 Mdot
.60368 .20816 Mdot
.28576 .75859 Mdot
.33748 .32232 Mdot
.15133 .53653 Mdot
.20724 .3367 Mdot
.30548 .56668 Mdot
.38544 .25883 Mdot
.60272 .43188 Mdot
.26135 .61395 Mdot
.59645 .69035 Mdot
.60507 .71278 Mdot
.79 .3453 Mdot
.79397 .42582 Mdot
.44193 .33754 Mdot
.49847 .77045 Mdot
.18221 .39953 Mdot
.78165 .33197 Mdot
.17839 .4111 Mdot
.37311 .43464 Mdot
.50612 .40443 Mdot
.46896 .87254 Mdot
.34652 .65639 Mdot
.48098 .42824 Mdot
.41766 .43804 Mdot
.40466 .42405 Mdot
.4481 .37519 Mdot
.52519 .77732 Mdot
.6661 .34389 Mdot
.63597 .24638 Mdot
.17274 .44925 Mdot
.30597 .57931 Mdot
.57884 .45383 Mdot
.54956 .73005 Mdot
.60584 .38946 Mdot
.56383 .33893 Mdot
.50546 .73965 Mdot
.6356 .23726 Mdot
.7411 .66525 Mdot
.65513 .414 Mdot
.41027 .61552 Mdot
.46879 .48584 Mdot
.29365 .61764 Mdot
.65376 .23543 Mdot
.55952 .76911 Mdot
.75318 .34507 Mdot
.56034 .20005 Mdot
.36301 .47898 Mdot
.46539 .67767 Mdot
.71032 .22039 Mdot
.56526 .4645 Mdot
.50953 .77563 Mdot
.49702 .27381 Mdot
.28775 .51821 Mdot
.21198 .38873 Mdot
.74376 .37911 Mdot
.43329 .5914 Mdot
.3542 .45281 Mdot
.18985 .4443 Mdot
.49512 .72012 Mdot
.22229 .28905 Mdot
.51615 .28871 Mdot
.28471 .32446 Mdot
.21223 .54272 Mdot
.52591 .61688 Mdot
.23018 .46185 Mdot
.49869 .32042 Mdot
.60296 .5012 Mdot
.74064 .66135 Mdot
.37758 .61776 Mdot
.49691 .60498 Mdot
.26835 .62757 Mdot
.68739 .25908 Mdot
.25063 .33796 Mdot
.45539 .36593 Mdot
.70263 .446 Mdot
.57397 .44103 Mdot
.71213 .51308 Mdot
.74709 .59076 Mdot
.45898 .64926 Mdot
.6515 .23694 Mdot
.64295 .2618 Mdot
.21589 .44705 Mdot
.16483 .49814 Mdot
.38809 .34347 Mdot
.20978 .37814 Mdot
.66385 .49029 Mdot
.39106 .72396 Mdot
.48711 .22014 Mdot
.28067 .75205 Mdot
.3819 .41996 Mdot
.3916 .38514 Mdot
.22496 .30261 Mdot
.19964 .3767 Mdot
.50308 .64548 Mdot
.38418 .64843 Mdot
.6096 .18134 Mdot
.62628 .39917 Mdot
.65425 .82113 Mdot
.59774 .70086 Mdot
.24834 .27362 Mdot
.49482 .61808 Mdot
.49418 .27653 Mdot
.39445 .48526 Mdot
.45375 .43482 Mdot
.6694 .60597 Mdot
.24344 .60253 Mdot
.38291 .48958 Mdot
.54588 .28848 Mdot
.51768 .33767 Mdot
.58589 .61874 Mdot
.39987 .58749 Mdot
.24269 .71471 Mdot
.70104 .56176 Mdot
.61753 .49919 Mdot
.46252 .83362 Mdot
.74145 .66205 Mdot
.7403 .28015 Mdot
.18333 .55914 Mdot
.4266 .64798 Mdot
.51415 .57062 Mdot
.74729 .70963 Mdot
.39259 .58286 Mdot
.39178 .55112 Mdot
.56985 .72306 Mdot
.67563 .31252 Mdot
.45858 .76392 Mdot
.33607 .79945 Mdot
.21843 .32718 Mdot
.40765 .38546 Mdot
.65422 .84127 Mdot
.56051 .20528 Mdot
.60811 .46759 Mdot
.46338 .76832 Mdot
.17074 .43321 Mdot
.62383 .56245 Mdot
.36553 .19741 Mdot
.30971 .70782 Mdot
.2623 .56884 Mdot
.66938 .32364 Mdot
.56889 .81764 Mdot
.5331 .58784 Mdot
.55292 .85385 Mdot
.38049 .66539 Mdot
.64435 .32862 Mdot
.35609 .75173 Mdot
.351 .52132 Mdot
.37637 .38912 Mdot
.30936 .68283 Mdot
.44009 .27069 Mdot
.27665 .57665 Mdot
.30127 .64569 Mdot
.68283 .38075 Mdot
.57305 .66019 Mdot
.34721 .65224 Mdot
.5608 .74773 Mdot
.36398 .49041 Mdot
.60338 .18978 Mdot
.73764 .6319 Mdot
.68146 .56457 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0:gooooo0_l0002Jooooo`007?ooool00ol0003oooooooooo`2]ooooo`;o0000
V_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0:oooooo1?l0002F
ooooo`007?ooool00ol0003oooooooooo`2_ooooo`Co0000U_ooool001cooooo00?o0000oooooooo
ool0]Oooool2o`0009;ooooo000Looooo`03o`000?oooooooooo0;Cooooo0ol0002Booooo`007?oo
ool00ol0003oooooooooo`2dooooo`Go0000T?ooool001cooooo00?o0000ooooooooool0]Oooool4
o`00093ooooo000Looooo`03o`000?oooooooooo0;Gooooo0_l00002ooooo`;o0000S_ooool001co
oooo00?o0000ooooooooool0]Oooool2o`0000;ooooo0_l0002>ooooo`007?ooool00ol0003ooooo
ooooo`2>ooooo`?o000000?oooooo`000?l000000_l0000:ooooo`;o00006Oooool2o`000005oooo
ool0003o0000o`000?ooool01?l00023ooooo`007?ooool00ol0003oooooooooo`2>ooooo`?o0000
00?oooooo`000?l000000_l0000:ooooo`Co00005?ooool2o`000004ooooool0003o0000ooooo`?o
000000?oooooo`000?l000000_l000000ooooooo0000o`000004ooooo`;o0000N_ooool001cooooo
00?o0000ooooooooool0X_ooool2o`0000_ooooo0_l00007ooooo`?o00000_ooool4o`0000Kooooo
1?l00002ooooo`;o0000N_ooool001cooooo00?o0000ooooooooool0O_ooool5o`0000Oooooo0_l0
000Jooooo`;o00000oooool2o`0000;ooooo0_l00008ooooo`;o00000_ooool2o`000003ooooool0
003o000000Oooooo0_l0001nooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0MOooool2o`0000Oooooo1Ol00007ooooo`;o0000
00?oooooo`000?l000002_ooool2o`0000Kooooo0_l00003ooooo`_o00003oooool2o`0001Gooooo
0_l0001`ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0MOooool2o`0001?ooooo0_l000001?oo
oooo0000o`000?l00009ooooo`;o00001_ooool2o`0000;ooooo0_l000000ooooooo0000o`000005
o`0000;ooooo1Ol0000Qooooo`;o0000L?ooool00003ooooool@413ooooo00;ooooo00?o410@oooo
ooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo07?ooooo0_l0000<oooo
o`;o000000?oooooo`000?l000001?ooool6o`00017ooooo0_l00002ooooo`;o00000_ooool4o`00
00Cooooo2?l00002ooooo`;o00006oooool2o`0006oooooo00000ooooooo0000ooooo`02ooooo`03
o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0007?ooooo0_l0000<ooooo`;o
000000?oooooo`000?l000000_l00002ooooo`Go00006Oooool3o`0000;ooooo0_l000000ooooooo
0000o`000002o`000003ooooool0003o000000?o000000?oooooo`000?l000006oooool2o`0006oo
oooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool0
1Oooool00ol0003oooooooooo`1Yooooo`Co00003oooool3o`0000;ooooo0_l00003ooooo`Co0000
0_ooool2o`0001Kooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000000;o0000
0oooool3o`0000;ooooo0_l0002;ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Ioooool6o`0000cooooo0_l0
00001?oooooo0000o`000?l00007ooooo`Co00006_ooool2o`0000;ooooo0_l00003ooooo`;o0000
0oooool2o`0000?ooooo0ol00002ooooo`Ko0000Qoooool00006oooooomgMgOoV9RHoooooonHV9So
MgMg2oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0Ioooool2o`00
00Gooooo0_l00007ooooo`Co00002oooool2o`0001Oooooo0_l00007ooooo`;o00000oooool2o`00
00Gooooo0ol00004ooooo`Oo00007oooool2o`0006Kooooo00001_ooooook^k^oc8b<_l0003o<S8b
onk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo06kooooo0_l0
0006ooooo`?o00004oooool2o`0000_ooooo0_l00002ooooo`Co00000_ooool2o`0000Sooooo0_l0
0002ooooo`;o000000Goooooo`000?l0003o0000ooooo`07o`000003ooooool0003o000001oooooo
0_l0001Vooooo`007?ooool00ol0003oooooooooo`1fooooo`;o00005?ooool2o`0000Sooooo2Ol0
0004ooooo`;o00003?ooool2o`000003ooooool0003o000000;ooooo2?l000000ooooooo0000o`00
0026ooooo`007?ooool00ol0003oooooooooo`1Rooooo`;o00001oooool2o`0002Wooooo2Ol0000E
ooooo`;o00001Oooool5o`000003ooooool0003o0000023ooooo0_l0001Tooooo`007?ooool00ol0
003oooooooooo`1Rooooo`;o00001Oooool4o`0002cooooo0ol000000ooooooo0000o`000005oooo
o`?o00003_ooool4o`0000;ooooo0ol0000Uooooo`;o0000I?ooool001cooooo00?o0000oooooooo
ool0H?ooool2o`0000Oooooo1Ol0000_ooooo`?o00001?ooool3o`0000?ooooo1?l00007ooooo`Co
00000_ooool2o`0000Sooooo0_l00022ooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o0000
2Oooool3o`0002oooooo0ol00009ooooo`Go00000_ooool2o`0000Gooooo0_l00002ooooo`?o0000
1oooool2o`0001oooooo0_l0001Qooooo`007?ooool00ol0003oooooooooo`1Wooooo`;o00006?oo
ool2o`0001oooooo0_l00004ooooo`?o00001Oooool2o`0000Gooooo0_l00002ooooo`Go00009_oo
ool2o`00067ooooo000Looooo`03o`000?oooooooooo06Gooooo1?l0000Gooooo`?o00007oooool2
o`0000;ooooo1?l0000Aooooo`;o000000?oooooo`000?l000004?ooool3o`0000;ooooo0_l0001b
ooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o00004oooool2o`0000Cooooo0_l0000Toooo
o`;o00000oooool2o`0000_ooooo0_l0000Aooooo`;o00000oooool3o`0000;ooooo0_l000000ooo
oooo0000o`00001_ooooo`007?ooool00ol0003oooooooooo`1Sooooo`;o00005Oooool2o`0000co
oooo0_l0000Qooooo`;o00000_ooool2o`0000Oooooo0_l00002ooooo`?o00003?ooool2o`0000_o
oooo0_l0001_ooooo`007?ooool00ol0003oooooooooo`1Kooooo`;o00001?ooool4o`0001?ooooo
0ol00006ooooo`;o00001Oooool2o`0000[ooooo0_l0000Gooooo`Co00002oooool3o`0008[ooooo
000Looooo`03o`000?oooooooooo05_ooooo0_l000000ooooooo0000o`000003o`0001;ooooo0_l0
00001?oooooo0000o`000?l00002ooooo`;o00000_ooool2o`0000Gooooo0_l0000:ooooo`;o0000
5oooool2o`0001_ooooo0ol00005ooooo`;o00001?ooool2o`0000?ooooo0_l0001Zooooo`007?oo
ool2o`0005Cooooo0_l00002ooooo`?o00001?ooool5o`0000gooooo0_l00003ooooo`;o000000?o
ooooo`000?l000000oooool2o`0000cooooo0_l0000=ooooo`;o00000oooool2o`0000gooooo1Ol0
000Booooo`;o00000oooool3o`0000Gooooo0_l00004ooooo`;o00000oooool2o`0006[ooooo000L
ooooo`03o`000?oooooooooo05;ooooo0ol00002ooooo`?o00000_ooool2o`00013ooooo1?l00006
ooooo`?o00001_ooool2o`0000Sooooo0_l00009ooooo`;o00000_ooool2o`0000?ooooo0_l0000=
ooooo`Go00004_ooool2o`000004ooooool0003o0000ooooo`;o00001_ooool2o`0000Wooooo1?l0
001Wooooo`007?ooool00ol0003oooooooooo`1Booooo`;o00002?ooool2o`00013ooooo0_l00009
ooooo`;o00000oooool2o`000003ooooool0003o000001?ooooo0_l00005ooooo`?o00003oooool3
o`0000_ooooo0_l00009ooooo`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00002Ooo
ool4o`0006Oooooo000Looooo`03o`000?oooooooooo05Cooooo0_l0000Sooooo`;o00000oooool2
o`0000gooooo0_l00004ooooo`?o00001_ooool4o`00013ooooo0ol0000:ooooo`;o00001oooool2
o`0000?ooooo1Ol00006ooooo`;o00000oooool2o`000003ooooool0003o000006Wooooo000Loooo
o`03o`000?oooooooooo05Cooooo0_l000000ooooooo0000o`00000Fooooo`;o00000_ooool2o`00
00?ooooo0ol0000;ooooo`;o00001Oooool4o`0000;ooooo0ol00006ooooo`Co00004Oooool3o`00
00?ooooo1?l0000;ooooo`;o00000oooool4o`0000;ooooo0_l00003ooooo`;o00000oooool2o`00
0003ooooool0003o000000Gooooo0_l0001Rooooo`007?ooool00ol0003oooooooooo`1Gooooo`;o
00005Oooool8o`0000;ooooo0_l000000ooooooo0000o`000009ooooo`;o00001oooool2o`0000;o
oooo0_l00005ooooo`;o00005Oooool3o`0000?ooooo1?l0000Booooo`;o00000_ooool2o`0001;o
oooo0_l0001Rooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o00008?ooool6o`000003oooo
ool0003o000000?o00000_ooool2o`0000Gooooo0_l00007ooooo`;o00002Oooool2o`0000;ooooo
0_l0000<ooooo`;o00001oooool3o`0000Cooooo0_l0000>ooooo`?o00000_ooool2o`0001;ooooo
0_l000000ooooooo0000o`00001Sooooo`007?ooool00ol0003oooooooooo`1;ooooo`Co00000ooo
ool2o`0000Oooooo0_l0000;ooooo`;o00000oooool3o`0000Cooooo1Ol00009ooooo`;o00000_oo
ool2o`0000?ooooo0_l00009ooooo`Ko00000_ooool2o`0000Sooooo0_l00009ooooo`;o00000_oo
ool3o`0000Sooooo0_l00004ooooo`Co000000?oooooo`000?l000003oooool5o`000003ooooool0
003o000006?ooooo000Looooo`03o`000?oooooooooo04_ooooo1?l00002ooooo`?o00001?ooool2
o`000003ooooool0003o000000_ooooo0_l00004ooooo`;o000000?oooooo`000?l000002?ooool2
o`0000Gooooo0ol000000ooooooo0000o`000007ooooo`;o00001oooool4o`000004ooooool0003o
0000o`0000Oooooo0_l0000:ooooo`;o00000_ooool2o`0000Wooooo0_l00006ooooo`;o00000_oo
ool2o`0000kooooo1?l0001Wooooo`007?ooool00ol0003oooooooooo`1Aooooo`?o00001?ooool2
o`000003ooooool0003o000000;ooooo0_l00008ooooo`;o000000?oooooo`000?l000000_l00000
0ooooooo0000o`000002o`0000Kooooo0_l00005ooooo`?o000000?oooooo`000?l000000_ooool3
o`0000;ooooo0ol00003ooooo`;o00001_ooool2o`0000Sooooo0_l0000:ooooo`Co000000?ooooo
o`000?l000000_ooool2o`0000Gooooo0_l00007ooooo`Co00003_ooool2o`0000Wooooo0_l0001N
ooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00002Oooool2o`0000;ooooo0_l00008oooo
o`;o000000?oooooo`000?l000000_l00003ooooo`;o00003Oooool2o`0000Cooooo1Ol00003oooo
o`?o00000_ooool4o`0000Kooooo0_l00006ooooo`;o00002oooool3o`000005ooooool0003o0000
o`000?ooool00_l00005ooooo`;o00001oooool6o`0001Oooooo0_l00002ooooo`;o0000F_ooool0
01cooooo00?o0000ooooooooool0A_ooool2o`0000Sooooo0_l0000=ooooo`;o00001_ooool2o`00
01Sooooo0ol00004ooooo`;o00001_ooool3o`0000;ooooo1?l00006ooooo`;o00004oooool3o`00
00;ooooo0_l0000:ooooo`;o00002Oooool2o`0001_ooooo0_l0001Jooooo`007?ooool00ol0003o
ooooooooo`15ooooo`?o00005oooool2o`0000Kooooo0_l0000Hooooo`Co00007oooool2o`0000Ko
oooo1?l00005ooooo`;o00002?ooool2o`0000Cooooo0_l00022ooooo`007?ooool00ol0003ooooo
ooooo`15ooooo`;o0000>oooool3o`0001Sooooo0_l00005ooooo`;o00001_ooool4o`0000Gooooo
0ol00004ooooo`;o000000?oooooo`000?l000009oooool4o`0005gooooo000Looooo`03o`000?oo
oooooooo05Oooooo0_l00008ooooo`;o00005oooool2o`0000;ooooo0_l00002ooooo`;o00001ooo
ool2o`0000Oooooo0_l00005ooooo`Ko00005?ooool5o`0000;ooooo0ol0000:ooooo`;o00007Ooo
ool4o`0000Gooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`1Gooooo`;o00002?ooool2
o`0001Oooooo0_l00002ooooo`;o00002oooool2o`0000;ooooo1?l000000ooooooo0000o`000002
o`0000?ooooo0_l00002ooooo`;o00005_ooool4o`0000;ooooo0_l0000:ooooo`;o00005?ooool2
o`0000gooooo0_l000000ooooooo0000o`00001Fooooo`007?ooool2o`00063ooooo0_l000001?oo
oooo0000o`000?l0000Gooooo`;o000000?oooooo`000?l000002_ooool2o`0000;ooooo1?l00000
0ooooooo0000o`000002o`0001oooooo1?l000000ooooooo0000o`00000:ooooo`;o00005Oooool2
o`0000Kooooo0ol00004ooooo`;o000000?oooooo`000?l00000E_ooool001cooooo00?o0000oooo
ooooool0AOooool2o`0001Sooooo0_l000001?oooooo0000o`000?l0000Dooooo`;o000000Cooooo
o`000?l0003ooooo0_l0000:ooooo`Co000000?oooooo`000?l000001?ooool3o`000004ooooool0
003o0000o`0000Gooooo0_l0000<ooooo`;o00001Oooool4o`000004ooooool0003o0000ooooo`;o
00001?ooool2o`000003ooooool0003o000001Gooooo0_l00006ooooo`?o00001_ooool2o`0005Oo
oooo000Looooo`03o`000?oooooooooo04Gooooo0_l0000aooooo`?o00001?ooool2o`0000cooooo
1?l000001?oooooo0000o`000?ooool4o`000003ooooool0003o000000Co00000_ooool4o`0000[o
oooo0_l00007ooooo`?o00000oooool3o`0000;ooooo0ol000000ooooooo0000o`000002o`0000;o
oooo0_l00005ooooo`;o00002?ooool2o`0000oooooo0_l0001Gooooo`007?ooool00ol0003ooooo
ooooo`1Mooooo`;o00003oooool2o`0000Sooooo0_l00002ooooo`Go00001_ooool2o`0000Gooooo
0ol000000ooooooo0000o`000005o`0000Cooooo0ol00004ooooo`?o00004?ooool5o`0000Cooooo
0_l00002ooooo`;o00000oooool3o`0000;ooooo0_l00005ooooo`;o00002?ooool2o`0000cooooo
0_l000000ooooooo0000o`00001Gooooo`007?ooool00ol0003oooooooooo`1Jooooo`;o000000?o
ooooo`000?l000003?ooool2o`000003ooooool0003o000000Wooooo0_l000001?oooooo0000o`00
0?l00007ooooo`Ko00001?ooool9o`0000?ooooo1Ol00004ooooo`;o00002Oooool2o`0000Gooooo
0ol000000ooooooo0000o`000003ooooo`Ko000000?oooooo`000?l000003oooool2o`0000Gooooo
0_l0000:ooooo`Co0000F_ooool001cooooo00?o0000ooooooooool0F_ooool2o`0000kooooo0ol0
00000ooooooo0000o`000009ooooo`;o00002?ooool;o`0000;ooooo2Ol00003ooooo`;o000000Co
ooooo`000?l0003o00003_ooool2o`0000Kooooo1Ol00002ooooo`Ko00000_ooool3o`0000kooooo
0_l0000>ooooo`;o000000Coooooo`000?l0003o0000Foooool001cooooo00?o0000ooooooooool0
J?ooool4o`000004ooooool0003o0000o`00017ooooo3Ol000001Ooooooo0000o`000?l0003ooooo
00Oo00000oooool2o`000004ooooool0003o0000ooooo`;o00004oooool4o`0000?ooooo0_l00002
ooooo`;o00000_ooool3o`0001Kooooo0_l00006ooooo`;o00002oooool2o`0005;ooooo000Loooo
o`03o`000?oooooooooo06Oooooo1Ol000001?oooooo0000o`000?l0000@ooooo`?o000000?ooooo
o`000?l000000_l00002ooooo`Co000000?oooooo`000?l000005?l0000Gooooo`;o00002oooool2
o`0000?ooooo0_l0000@ooooo`;o00001_ooool2o`0000_ooooo0_l0001Booooo`007?ooool00ol0
003oooooooooo`0looooo`;o00006oooool2o`0000cooooo0_l000001?oooooo0000o`000?ooool2
o`00017ooooo0_l00003ooooob3o00000oooool2o`0000oooooo0_l000000ooooooo0000o`00000;
ooooo`;o00000oooool4o`0000Cooooo0_l0000Aooooo`;o00003?ooool2o`00053ooooo000Loooo
o`03o`000?oooooooooo03cooooo0_l00004ooooo`?o00005?ooool2o`0000_ooooo0_l00005oooo
o`;o00005OoooolMo`0000;ooooo0_l00003ooooo`;o00002Oooool2o`0000Cooooo0_l000001Ooo
oooo0000o`000?l0003ooooo00Co00001Oooool3o`0000;ooooo1?l00003ooooo`?o00004Oooool2
o`0000Gooooo0_l00005ooooo`;o0000D?ooool001cooooo00?o0000ooooooooool0>_ooool2o`00
00Gooooo1?l0000Qooooo`;o00001?ooool3o`0001;ooooo0_l000000ooooooo0000o`000006o`00
0003ooooool0003o000001;o00004_ooool2o`0000Cooooo0_l00002ooooo`;o000000?oooooo`00
0?l000000_l00005ooooo`?o00000_ooool2o`0000Gooooo0_l0000Iooooo`;o00002?ooool2o`00
04gooooo000Looooo`03o`000?oooooooooo03[ooooo0_l00005ooooo`Co00001oooool2o`0001Oo
oooo0_l00005ooooo`?o00003oooool2o`000003ooooool0003o000001_o000000?oooooo`000?l0
00000oooool2o`0000?ooooo0_l00007ooooo`;o00001Oooool3o`000003ooooool0003o000000_o
oooo0ol0000@ooooo`?o00006_ooool2o`0004gooooo000Looooo`03o`000?oooooooooo043ooooo
0_l0000:ooooo`Co00005Oooool2o`0000Kooooo0ol0000:ooooo`Oo00000_oooolNo`000003oooo
ool0003o000000;o00000_ooool3o`0000Oooooo0_l00005ooooo`?o000000?oooooo`000?l00000
2_ooool4o`0000Kooooo0_l000000ooooooo0000o`000004ooooo`Co0000JOooool001cooooo00?o
0000ooooooooool0@?ooool2o`0000_ooooo0ol0000Eooooo`;o00001oooool2o`0000[ooooo1?l0
00000ooooooo0000o`000002ooooob?o00000_ooool2o`0000Wooooo0_l00004ooooo`Go000000?o
ooooo`000?l000002?ooool5o`0000Cooooo3?l0000<ooooo`;o00002_ooool2o`00057ooooo000L
ooooo`03o`000?oooooooooo04kooooo0_l00007ooooo`;o00003?ooool2o`0001?ooooo0ol00005
ooooob3o00004Oooool2o`0000?ooooo2Ol0000:ooooo`?o000000?oooooo`000?l000003?l0000=
ooooo`;o00001Oooool2o`000003ooooool0003o000000?o0000D?ooool001cooooo00?o0000oooo
ooooool0Eoooool2o`00027ooooo0_l00006ooooob3o00002Oooool2o`0000_ooooo1?l000000ooo
oooo0000o`00000=ooooo`;o000000Coooooo`000?l0003o00000oooool7o`0001Gooooo1Ol00000
0ooooooo0000o`000004ooooo`;o0000B_ooool001cooooo0_l0001<ooooo`;o0000;?ooool2o`00
00Oooooo6Ol000000ooooooo0000o`000004o`0000;ooooo0_l000000ooooooo0000o`000002oooo
o`;o00007_ooool5o`0000;ooooo0_l000000ooooooo0000o`00000Booooo`;o00001_ooool3o`00
00Cooooo0_l00003ooooo`;o00000oooool2o`0004Gooooo000Looooo`03o`000?oooooooooo04_o
oooo0_l00007ooooo`Co00008Oooool2o`0000Oooooo8Ol000000ooooooo0000o`000003o`0000;o
oooo0_l0000Fooooo`;o00001_ooool5o`0000;ooooo1Ol0000Booooo`;o00003Oooool2o`0000So
oooo0_l00015ooooo`007?ooool00ol0003oooooooooo`11ooooo`;o00004Oooool4o`0001[ooooo
0_l00005ooooo`;o00000_ooool2o`0000Cooooo9_l0000Jooooo`;o00001Oooool4o`0000Gooooo
0_l0000Looooo`;o0000E_ooool001cooooo00?o0000ooooooooool0?_ooool2o`000003ooooool0
003o000002[ooooo0_l00003ooooo`;o00001Oooool2o`0000;ooooo0_l00002ooooobGo00009?oo
ool2o`0000?ooooo0_l0000Booooo`;o00003?ooool3o`0005Gooooo000Looooo`03o`000?oooooo
oooo03gooooo0ol00007ooooo`;o00009?ooool2o`0000Wooooo0_l00007ooooobGo000000?ooooo
o`000?l000005Oooool6o`0000Kooooo0_l00002ooooo`?o00003_ooool6o`0000gooooo0_l0001E
ooooo`007?ooool00ol0003oooooooooo`0jooooo`;o000000?oooooo`000?l000002?ooool2o`00
00Wooooo0_l0000Nooooo`?o00000_ooool3o`0000?ooooo0_l00003ooooob3o00001Oooool4o`00
01?ooooo1_l0000:ooooo`;o00003_ooool7o`0000gooooo0_l0001Eooooo`007?ooool00ol0003o
ooooooooo`0jooooo`;o00001_ooool2o`0000Kooooo0_l00006ooooo`;o00007_ooool3o`0000;o
oooo0_l00004ooooo`?o00001?ooool5o`000003ooooool0003o000001So00000oooool6o`0000Ko
oooo0_l00009ooooo`;o00001?ooool2o`0000Sooooo0_l0000>ooooo`;o00004Oooool3o`0005Go
oooo000Looooo`03o`000?oooooooooo03cooooo0_l00004ooooo`;o00001_ooool2o`0001gooooo
0_l00006ooooo`;o00002_ooool4o`0000?ooooo1ol000000ooooooo0000o`00000Fo`0000?ooooo
1_l00006ooooo`;o00002Oooool3o`0000?ooooo0_l00006ooooo`;o00006Oooool3o`0000Oooooo
0ol0001Eooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00001_ooool3o`000003ooooool0
003o0000017ooooo0_l0000Dooooo`Co00001Oooool3o`0000Wooooo1?l00002ooooo`So000000?o
ooooo`000?l000005_l00003ooooo`;o00003oooool2o`0000Gooooo0_l00003ooooo`;o00001_oo
ool2o`0000_ooooo0_l00006ooooo`;o000000Coooooo`000?l0003ooooo1_l0001Looooo`007?oo
ool00ol0003oooooooooo`0cooooo`;o00001_ooool7o`00013ooooo0_l0000Dooooo`Co00001_oo
ool2o`0000Sooooo0ol00004ooooo`;o000000?oooooo`000?l000001?l000000ooooooo0000o`00
000Eo`0000?ooooo1_l0000;ooooo`;o00003_ooool2o`0000;ooooo0_l0000;ooooo`;o00001_oo
ool2o`000003ooooool0003o000000?ooooo1ol0000<ooooo`;o0000Boooool001cooooo00?o0000
ooooooooool0?Oooool2o`000003ooooool0003o0000013ooooo0_l0000Booooo`;o000000?ooooo
o`000?l000002oooool3o`0000?ooooo0_l00005ooooob7o00000oooool6o`0000Gooooo0_l00004
ooooo`;o00001oooool2o`0000;ooooo0_l000000ooooooo0000o`00000;ooooo`;o00000oooool6
o`0000;ooooo0_l00009ooooo`?o00000oooool2o`0000Oooooo0ol0001:ooooo`007?ooool00ol0
003oooooooooo`0fooooo`;o00000_ooool2o`0001Kooooo0_l0000Booooo`;o00003_ooool4o`00
00Kooooo0_l000000ooooooo0000o`00000Go`000003ooooool0003o000000Go00000_ooool5o`00
00Oooooo0_l00004ooooo`;o00001oooool2o`0000;ooooo0_l000000ooooooo0000o`00000;oooo
o`;o00000oooool6o`0000;ooooo0_l0000:ooooo`;o000000?oooooo`000?l000000_l00007oooo
o`?o0000B_ooool001cooooo00?o0000ooooooooool0=_ooool2o`0000;ooooo0_l000000ooooooo
0000o`000002o`0000Wooooo0_l00005ooooo`?o00004_ooool2o`0000cooooo1_l000000ooooooo
0000o`00000Oo`000003ooooool0003o000000Co00000oooool5o`0001Kooooo0_l00002ooooo`;o
000000?oooooo`000?l000002oooool2o`0000Cooooo0_l0000>ooooo`;o00001?ooool4o`0005Co
oooo000Looooo`03o`000?oooooooooo02oooooo0_l0000;ooooo`Oo00001oooool2o`0000Gooooo
0ol0000Pooooo`Go00000_ooool5o`000003ooooool0003o000000;ooooo9?l0000Hooooo`;o0000
0_ooool3o`000003ooooool0003o000001Kooooo0_l00007ooooo`?o00005Oooool2o`0004Gooooo
00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@oooooooo
ool01?ooool00ol0003oooooooooo`0_ooooo`;o00002oooool3o`0000;ooooo0_l00004ooooo`;o
0000;Oooool3o`0000;ooooo0_l000000ooooooo0000o`000004o`000003ooooool0003o000000Ko
000000?oooooo`000?l000002?l000000ooooooo0000o`000002o`000003ooooool0003o000000;o
000000?oooooo`000?l000001_l00007ooooo`;o00001Oooool4o`0000Cooooo0_l00003ooooo`;o
000000?oooooo`000?l000003Oooool2o`0000Oooooo0_l00003ooooo`;o00000_ooool2o`0001;o
oooo0_l00002ooooo`;o0000AOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q
8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0mooooo`;o00002?ooool2o`00
02Cooooo0_l00009ooooo`;o000000Coooooo`000?l0003ooooo0ol000000ooooooo0000o`000003
ooooo`Ko000000?oooooo`000?l000005_l000000ooooooo0000o`000002o`0000Oooooo0_l00005
ooooo`Ko00001Oooool2o`0001;ooooo0_l000000ooooooo0000o`000002o`0000Gooooo1?l00000
0ooooooo0000o`000002o`00017ooooo0_l00002ooooo`;o0000AOooool00003ooooool@413ooooo
00;ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo00?o0000ooooooooool0=oooool2o`00
00cooooo1?l0000Tooooo`;o00001_ooool5o`0000Cooooo0_l00007ooooob?o00004_ooool3o`00
00Gooooo0_l000001?oooooo0000o`000?l0000<ooooo`;o00000oooool4o`0000;ooooo3?l00000
0ooooooo0000o`000002o`0005Oooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`0003Oooooo0_l000000ooooooo0000o`000009
ooooo`Co00000oooool2o`0002;ooooo0_l00003ooooo`Co00000oooool2o`000003ooooool0003o
000000Kooooo3Ol000000ooooooo0000o`00000;o`0000;ooooo1_l0000Booooo`;o00001Oooool2
o`0000;ooooo0ol0000:ooooo`Co00001?ooool4o`000003ooooool0003o000000Wo000000?ooooo
o`000?l000000ol000000ooooooo0000o`00001Dooooo`0000?oooooo`000?ooool00_ooool00ol0
003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0>_ooool2
o`00013ooooo0_l0000Rooooo`;o00002_ooool2o`000003ooooool0003o000000;o00001?ooool>
o`000003ooooool0003o000000Co000000?oooooo`000?l000001?l00002ooooo`Co00006?ooool4
o`0000oooooo0_l00006ooooo`Co000000?oooooo`000?l000003?l000000ooooooo0000o`000003
o`0005Cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oMgMgolc<
c?l000001oooool00ol0003oooooooooo`17ooooo`;o000000?oooooo`000?l000001?ooool2o`00
02Sooooo0_l000001?oooooo0000o`000?ooool3o`0000Cooooo1Ol000000ooooooo0000o`00000F
o`000004ooooool0003o0000o`0001?ooooo0_l00003ooooo`;o00004?ooool2o`0000;ooooo0_l0
0003oooooaSo00002?ooool4o`000003ooooool0003o000004Kooooo00001_ooooooMgMgoiRHV?oo
ooooV9RHogMgM`cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0fooooo`;o0000
3oooool2o`000003ooooool0003o000000?ooooo0ol0000Xooooo`;o000000Coooooo`000?l0003o
oooo0_l00006ooooo`Oo000000?oooooo`000?l000005ol00006ooooo`;o00002_ooool3o`000003
ooooool0003o000000?o00002?ooool2o`0000Gooooo0_l00002ooooo`;o00001?oooolEo`0000[o
oooo1?l000000ooooooo0000o`000016ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h=oooo
o`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0=_ooool2o`0001Cooooo0_l000001?oo
oooo0000o`000?l0000Mooooo`;o00004?ooool5o`0000Cooooo4ol000001?oooooo0000o`000?oo
ool7o`0000Oooooo0_l0000:ooooo`Ko000000?oooooo`000?l000002?ooool2o`000003ooooool0
003o000000Co00001oooool2o`000003ooooool0003o0000017o00002oooool2o`0004[ooooo000L
ooooo`03o`000?oooooooooo03;ooooo0ol00006ooooo`;o00003oooool2o`0000;ooooo0_l0000M
ooooo`So00002_ooool6o`0000;ooooo2Ol000000ooooooo0000o`000007o`000004ooooool0003o
0000o`0000;ooooo1Ol0000Eooooo`Go00003_ooool6o`0000Cooooo0_l000001?oooooo0000o`00
0?oooolDo`0000;ooooo0_l00006ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0<_oo
ool3o`0000;ooooo0_l000001?oooooo0000o`000?l0000]ooooo`;o00001?ooool7o`000003oooo
ool0003o000000Gooooo2?l00002oooooa?o000000Coooooo`000?l0003o00000_ooool5o`0000Ko
oooo0_l0000<ooooo`Go00002Oooool2o`0000kooooo0_l000000ooooooo0000o`00000Eo`0000;o
oooo0_l00004ooooo`?o0000Boooool001cooooo00?o0000ooooooooool0=oooool2o`000003oooo
ool0003o000000Wooooo0_l0000Sooooo`;o00001?ooool3o`000003ooooool0003o000000;ooooo
0ol00003ooooo`Co000000Goooooo`000?l0003o0000ooooo`02o`000004ooooool0003o0000oooo
o`Oo00000oooool5o`0000?ooooo2?l00006ooooo`;o00002_ooool8o`0000Sooooo0_l00007oooo
o`;o00002_oooolDo`0000;ooooo0ol00004ooooo`?o0000Boooool001cooooo00?o0000oooooooo
ool0=oooool2o`0000cooooo0_l00004ooooo`;o00007Oooool2o`0000Gooooo0_l000000ooooooo
0000o`000003ooooo`;o00000oooool4o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`00
0003ooooool0003o000000Ko00001_ooool2o`0000;ooooo1_l0000Dooooo`So00002?ooool2o`00
00Oooooo0_l0000;oooooaCo000000Coooooo`000?l0003o00001oooool3o`0004Sooooo000Loooo
o`03o`000?oooooooooo03Oooooo0_l00007ooooo`;o00002Oooool2o`0000?ooooo0_l0000Hoooo
o`?o00001?ooool3o`0000Kooooo0_l00004ooooo`;o00001_ooool4o`0000Cooooo0_l000000ooo
oooo0000o`000003ooooo`;o000000?oooooo`000?l000000oooool3o`0001Cooooo1Ol000000ooo
oooo0000o`00000:ooooo`;o00004ooooolFo`000003ooooool0003o000000Cooooo0_l000001?oo
oooo0000o`000?l00018ooooo`007?ooool00ol0003oooooooooo`0aooooo`Oo00002?ooool2o`00
00Oooooo1?l00003ooooo`;o00006Oooool2o`0000Gooooo1?l00004ooooo`;o00001?ooool4o`00
00Cooooo1_l0000:ooooo`;o00001Oooool3o`0001Cooooo1?l00003ooooo`Go00003_ooool2o`00
00cooooo5_l00005ooooo`Co0000C?ooool001cooooo00?o0000ooooooooool0<Oooool7o`0000;o
oooo0_l00004ooooo`;o00000oooool2o`0000;ooooo0_l00006ooooo`;o00008Oooool3o`0000?o
oooo1?l00004ooooo`;o00001_ooool4o`0000;ooooo0_l0000<ooooo`Co00004Oooool7o`0000Co
oooo1?l0000>ooooo`;o00001Oooool2o`0000?ooooo0_l00002ooooo`[o000000?oooooo`000?l0
00001ol00005ooooo`;o00000_ooool2o`0004[ooooo000Looooo`03o`000?oooooooooo03?ooooo
0_l00005ooooo`;o00000_ooool2o`0000Gooooo0_l000000ooooooo0000o`000002o`0000;ooooo
0_l000000ooooooo0000o`00000Rooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`Oo0000
1?ooool4o`0000?ooooo1?l0000@ooooo`Wo00006?ooool2o`000003ooooool0003o000000;o0000
0oooool2o`000003ooooool0003o000000Wo000000?oooooo`000?l000001ol00005ooooo`;o0000
00Coooooo`000?l0003o0000B_ooool001cooooo00?o0000ooooooooool0<?ooool2o`000003oooo
ool0003o000000Cooooo0_l00003ooooo`;o00002?ooool4o`0000;ooooo0_l0000Kooooo`;o0000
5oooool2o`0000Oooooo1ol000000ooooooo0000o`000008o`0001;ooooo2_l0000Fooooo`?o0000
00?oooooo`000?l000002?oooolFo`0000Oooooo0_l0001;ooooo`007?ooool00ol0003ooooooooo
o`0_ooooo`?o00001oooool3o`0000Kooooo0_l00003ooooo`Co00008?ooool2o`0000;ooooo0_l0
000Kooooo`;o00000oooool=o`0001?ooooo2_l0000Fooooo`;o00003?oooolCo`000003ooooool0
003o000000;ooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o000000?ooooo
o`000?l000000_l00004ooooo`Co00000oooool3o`0000?ooooo1?l0000Rooooo`Co00001?ooool2
o`0001;ooooo0_l000001?oooooo0000o`000?l00003ooooo`So00004oooool2o`000004ooooool0
003o0000o`0000;ooooo0_l0000@ooooo`;o00001?ooool2o`0000;ooooo0_l0000=oooooa3o0000
1Oooool4o`00053ooooo000Looooo`;o0000<oooool4o`0000Kooooo0_l00003ooooo`?o00001?oo
ool3o`0000Wooooo0_l0000Gooooo`;o00000_ooool2o`0000;ooooo0_l0000Booooo`;o00000_oo
ool2o`000005ooooool0003o0000o`000?ooool00_l0000Gooooo`Go00005Oooool2o`0000Cooooo
0_l0000=oooooaGo00001?ooool2o`0005;ooooo000Looooo`03o`000?oooooooooo03?ooooo0_l0
0004ooooo`;o00003?ooool3o`0000[ooooo0_l0000Hooooo`Go00007Oooool7o`0000;ooooo0ol0
00001?oooooo0000o`000?l0000>ooooo`?o00000_ooool2o`0000?ooooo1?l00008ooooo`;o0000
4?ooool2o`0000Cooooo1_l000000ooooooo0000o`00000<o`0000?ooooo1?l0001Aooooo`007?oo
ool00ol0003oooooooooo`0cooooo`;o00001?ooool2o`0000?ooooo0_l00005ooooo`Co00002ooo
ool2o`00017ooooo0_l00003ooooo`[o00001oooool2o`0001Cooooo1?l00002ooooo`?o000000Co
ooooo`000?l0003o00003_ooool3o`0000;ooooo0_l000000ooooooo0000o`000004o`0000Sooooo
0_l000000ooooooo0000o`000005ooooo`;o00000_ooool2o`0000;ooooo0_l0000;ooooo`ko0000
0oooool4o`00057ooooo000Looooo`03o`000?oooooooooo03Kooooo0_l00006ooooo`;o00001Ooo
ool5o`0000[ooooo0_l0000Aooooo`;o00000_ooool4o`000003ooooool0003o000000Ko00001Ooo
ool2o`0002gooooo1_l000000ooooooo0000o`000004o`0000gooooo0ol00005ooooo`;o00000_oo
ool2o`00017ooooo4?l0001Dooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00001?ooool4
o`0000Cooooo0_l00007ooooo`?o00002_ooool2o`0000gooooo0_l00006ooooo`?o00000oooool2
o`0000?ooooo0_l0000dooooo`Ko00000_ooool5o`0000gooooo0ol0000<ooooo`;o00003_ooool2
o`0000;ooooo1_l00002ooooo`Co0000E?ooool001cooooo00?o0000ooooooooool0<?ooool2o`00
00Gooooo0ol00004ooooo`;o00001oooool2o`0000Gooooo0_l0000Cooooo`;o00001?ooool2o`00
0003ooooool0003o000000;ooooo1?l00009ooooo`;o0000:_ooool2o`0000Wooooo0_l0000<oooo
o`;o00000oooool2o`0000cooooo0_l000000ooooooo0000o`00001_ooooo`007?ooool00ol0003o
ooooooooo`0`ooooo`;o00004Oooool3o`000003ooooool0003o000000Gooooo0_l00006ooooo`;o
00002_ooool2o`000003ooooool0003o000000;ooooo1Ol00002ooooo`Go00000_ooool2o`0000?o
oooo0ol0000Zooooo`;o000000Coooooo`000?l0003ooooo0ol0000@ooooo`;o00005?ooool2o`00
00;ooooo0_l0001[ooooo`007?ooool00ol0003oooooooooo`13ooooo`Go000000?oooooo`000?l0
00002oooool2o`0000[ooooo0_l000001?oooooo0000o`000?ooool6o`0000Gooooo0_l00002oooo
o`;o00000oooool3o`0002Sooooo1?l000001?oooooo0000o`000?ooool3o`0001Oooooo0_l0000A
ooooo`;o0000Joooool001cooooo00?o0000ooooooooool0;_ooool2o`0001Gooooo0ol000001?oo
oooo0000o`000?l00008ooooo`;o00003Oooool2o`0000?ooooo0_l0000Dooooo`;o00000_ooool2
o`0002?ooooo1?l0000Nooooo`;o00003Oooool2o`0001;ooooo0_l00002ooooo`;o000000?ooooo
o`000?l00000E?ooool001cooooo00?o0000ooooooooool0;_ooool2o`00017ooooo0ol000000ooo
oooo0000o`000003ooooo`;o00002?ooool2o`0000gooooo0_l00009ooooo`;o00000_ooool2o`00
00[ooooo1ol0000Booooo`;o00001?ooool2o`0000Kooooo0ol00002ooooo`;o00000oooool2o`00
0003ooooool0003o000002Cooooo0_l0000Booooo`;o00000_ooool2o`000003ooooool0003o0000
05Cooooo000Looooo`03o`000?oooooooooo03Cooooo0_l00006ooooo`;o00000oooool3o`000004
ooooool0003o0000o`0000Wooooo0ol0000Jooooo`;o00000_ooool2o`0000[ooooo1ol0000Boooo
o`;o00001?ooool2o`000003ooooool0003o000000?ooooo2?l00002ooooo`;o000000?oooooo`00
0?l00000>oooool3o`0005Oooooo000Looooo`03o`000?oooooooooo03;ooooo1?l00006ooooo`;o
00001oooool4o`0000Cooooo0_l00002ooooo`?o00004oooool2o`0000;ooooo0_l0000?ooooo`Go
00000_ooool2o`00013ooooo0_l00003ooooo`So000000Coooooo`000?l0003ooooo1ol0000Joooo
o`;o00005?ooool2o`00013ooooo0_l00004ooooo`;o0000D_ooool001cooooo00?o0000oooooooo
ool0<_ooool4o`0000kooooo0_l000000ooooooo0000o`000004ooooo`;o00000_ooool2o`0001?o
oooo0ol00002ooooo`?o00002oooool2o`000003ooooool0003o000000?o00000_ooool2o`0000oo
oooo0ol00003ooooo`So000000Coooooo`000?l0003ooooo1_l0000Kooooo`;o00001?ooool2o`00
00kooooo0_l0000@ooooo`;o00001?ooool2o`0005;ooooo000Looooo`03o`000?oooooooooo02ko
oooo0_l00004ooooo`;o00000oooool2o`0000Cooooo0_l000000ooooooo0000o`000002o`000003
ooooool0003o000000Cooooo0_l0000<ooooo`;o00002?ooool3o`0000;ooooo1?l00004ooooo`;o
00000_ooool2o`000003ooooool0003o000000Cooooo0ol0000Booooo`Co00000_ooool2o`000003
ooooool0003o000000?o000000?oooooo`000?l000000_l000000ooooooo0000o`000008ooooo`;o
00006Oooool2o`0000Gooooo0_l0000Iooooo`;o000000?oooooo`000?l000000oooool2o`00053o
oooo000Looooo`03o`000?oooooooooo02kooooo0_l00009ooooo`?o00000oooool2o`000003oooo
ool0003o000000;o000000?oooooo`000?l000004Oooool3o`0000Kooooo1?l00003ooooo`;o0000
1_ooool3o`000003ooooool0003o000000Oooooo1?l0000Cooooo`Ko00001oooool4o`0000Kooooo
1?l000000ooooooo0000o`00000Pooooo`;o00001?ooool2o`0001Kooooo0_l00003ooooo`;o0000
D?ooool001cooooo00?o0000ooooooooool0;_ooool2o`0000;ooooo0_l00006ooooo`;o00001_oo
ool2o`0000?ooooo0_l00009ooooo`;o00001?ooool4o`0000Oooooo0_l0000>ooooo`;o00001?oo
ool2o`0000Gooooo0ol0000Eooooo`Ko00003_ooool7o`000003ooooool0003o000001Wooooo0_l0
0009ooooo`;o000000?oooooo`000?l00000J_ooool001cooooo0_l0000^ooooo`?o00000_ooool2
o`0000[ooooo0_l00002ooooo`So00002?ooool2o`0000?ooooo0ol00006ooooo`?o00001?ooool3
o`0000oooooo0_l00005ooooo`;o00001_ooool2o`0001;ooooo0_l00005ooooo`Co000000?ooooo
o`000?l000001?l00003ooooo`;o000000?oooooo`000?l000002Oooool3o`0000?ooooo0_l00008
ooooo`;o00003?ooool2o`0001Sooooo0ol0001?ooooo`007?ooool00ol0003oooooooooo`0]oooo
o`?o00003_ooool2o`0000Cooooo1_l0000=ooooo`;o00001oooool5o`0000;ooooo0ol00002oooo
o`;o00004oooool2o`0000Gooooo0_l0000Iooooo`Co000000?oooooo`000?l000000ol0000Boooo
o`?o00000_ooool3o`0000Sooooo1?l0000Kooooo`;o00001oooool3o`0000;ooooo0_l0001;oooo
o`007?ooool00ol0003oooooooooo`0]ooooo`;o00002Oooool4o`0000;ooooo0_l0000Nooooo`;o
000000?oooooo`000?l000000_l00007ooooo`;o00003Oooool2o`0000Cooooo0_l0000Qooooo`;o
00006Oooool2o`0000?ooooo0_l00008ooooo`Go00001?ooool2o`0001Gooooo0_l0000<ooooo`;o
0000Boooool001cooooo00?o0000ooooooooool0;?ooool3o`0000Sooooo1Ol0000Rooooo`;o0000
2Oooool3o`0000Sooooo0ol00004ooooo`;o00001?ooool3o`0000Oooooo0_l0000Sooooo`Co0000
2oooool2o`0000_ooooo1?l00007ooooo`;o0000L?ooool001cooooo00?o0000ooooooooool0;?oo
ool2o`0000?ooooo1?l00002ooooo`;o00008?ooool2o`0000gooooo1?l00008ooooo`?o00001?oo
ool2o`0000Cooooo0ol00006ooooo`Go00006Oooool2o`0000Gooooo1Ol0000Hooooo`?o00005Ooo
ool2o`0006?ooooo000Looooo`03o`000?oooooooooo037ooooo1?l0000Looooo`;o00001_ooool2
o`0000gooooo1?l00008ooooo`;o00003?ooool2o`0000Kooooo0_l000000ooooooo0000o`000002
o`0001Kooooo0ol00005ooooo`;o00006_ooool2o`0001Oooooo0_l0001Sooooo`007?ooool00ol0
003oooooooooo`0_ooooo`;o00001oooool2o`00017ooooo0ol00003ooooo`;o00001?ooool2o`00
0003ooooool0003o000000_ooooo1Ol00004ooooo`;o00000_ooool2o`0000cooooo0_l00009oooo
o`Co00005?ooool4o`000003ooooool0003o000000;ooooo0_l0000Aooooo`?o00001oooool2o`00
0003ooooool0003o000001?ooooo0_l0000Booooo`;o0000D?ooool001cooooo00?o0000oooooooo
ool0;oooool2o`0000Oooooo0_l0000;ooooo`;o00001?ooool3o`0000Wooooo0_l000000ooooooo
0000o`00000;ooooo`;o000000?oooooo`000?l000000_ooool4o`0000;ooooo0_l0000<ooooo`?o
00001?ooool2o`0000Kooooo0_l0000<ooooo`Go000000Coooooo`000?l0003ooooo1?l00002oooo
o`Co000000?oooooo`000?l000000oooool2o`0000Oooooo0ol00004ooooo`;o00001?ooool3o`00
013ooooo1?l0000Booooo`;o000000?oooooo`000?l00000COooool001cooooo00?o0000oooooooo
ool0AOooool2o`000003ooooool0003o000000Cooooo0_l00009ooooo`;o00001_ooool5o`0000;o
oooo1Ol000001?oooooo0000o`000?l0000<ooooo`;o00000oooool3o`0000Cooooo0_l00005oooo
o`?o00003?ooool5o`0000Cooooo1?l00002ooooo`Co000000?oooooo`000?l000000oooool2o`00
00kooooo0_l00005ooooo`;o00004?ooool2o`0001Oooooo0_l0001=ooooo`007?ooool00ol0003o
ooooooooo`0]ooooo`;o00003Oooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o
00001?ooool2o`0000Wooooo0_l00004ooooo`oo000000?oooooo`000?l000001Oooool2o`0000Go
oooo0_l00004ooooo`;o00002oooool4o`0001Kooooo0_l00002ooooo`;o00003?ooool4o`0001Go
oooo0_l0000Wooooo`;o0000BOooool001cooooo00?o0000ooooooooool0;Oooool2o`0000gooooo
0_l00003ooooo`;o000000?oooooo`000?l000005oooool4o`0000Cooooo3?l00004ooooo`Co0000
6Oooool2o`0001;ooooo0_l00003ooooo`Co00000_ooool2o`0000Wooooo1?l00006ooooo`;o0000
3?ooool3o`0002Oooooo0_l00019ooooo`007?ooool00ol0003oooooooooo`0booooo`;o00006?oo
ool2o`0000oooooo1?l000000ooooooo0000o`00000=o`0000;ooooo1_l000001?oooooo0000o`00
0?ooool4o`00013ooooo0_l0000Aooooo`Co00000oooool5o`000003ooooool0003o0000017ooooo
1?l0000:ooooo`Co000000?oooooo`000?l00000L?ooool001cooooo00?o0000ooooooooool0;Ooo
ool2o`0000;ooooo0ol00004ooooo`Co00004?ooool2o`0000Kooooo0_l00009oooooa;o00000_oo
ool>o`00013ooooo0_l00003ooooo`;o00003?ooool2o`000004ooooool0003o0000o`0000;ooooo
1?l00007ooooo`;o00002oooool2o`0000Sooooo0_l00002ooooo`;o00000oooool2o`0000[ooooo
0_l0001Tooooo`007?ooool00ol0003oooooooooo`0]ooooo`Ko00001Oooool4o`0000;ooooo0_l0
00000ooooooo0000o`000002o`0000Kooooo0_l00007ooooo`;o00002?oooolPo`0000Cooooo0_l0
000Booooo`;o00003Oooool6o`000003ooooool0003o000000;o00001oooool2o`000003ooooool0
003o000001;ooooo0_l000000ooooooo0000o`000007ooooo`;o00001oooool2o`0001[ooooo0_l0
0018ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00003Oooool2o`000003ooooool0003o
000000;o00001_ooool2o`00017ooooo0_l00002oooooa;o00003_ooool3o`00017ooooo0_l00003
ooooo`Co00001_ooool2o`0000;ooooo0_l00003ooooo`;o00002_ooool2o`0001Gooooo0_l00007
ooooo`;o00000oooool2o`0000Cooooo0_l0000Hooooo`;o0000B?ooool001cooooo00?o0000oooo
ooooool0@Oooool4o`00017ooooo0_l00007oooooaKo00000oooool3o`0000Sooooo0_l0000;oooo
o`;o00001?ooool2o`0000?ooooo1?l00003ooooo`?o000000?oooooo`000?l000002?ooool3o`00
02Wooooo0_l000000ooooooo0000o`000004ooooo`;o00000oooool2o`0005gooooo000Looooo`;o
0000;oooool2o`0002Kooooo0_l00007oooooaOo00000_ooool3o`000003ooooool0003o000000?o
00003oooool2o`00013ooooo0ol000000ooooooo0000o`000007ooooo`Go0000:?ooool4o`0000Go
oooo0_l00003ooooo`;o0000GOooool001cooooo00?o0000ooooooooool0;_ooool2o`0000Cooooo
0_l0000=ooooo`?o00002Oooool2o`000003ooooool0003o000000Sooooo0_l00002oooooaKo0000
1?ooool7o`0001kooooo0ol00004ooooo`?o00001_ooool6o`00027ooooo1?l00003ooooo`Go0000
1_ooool3o`0000;ooooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00001?oo
ool2o`0000gooooo0ol00003ooooo`;o00001?ooool2o`000004ooooool0003o0000o`0000Oooooo
7?l00002ooooo`Oo00007_ooool3o`0000Gooooo1?l00006ooooo`Co00001oooool2o`0001;ooooo
0_l00004ooooo`Ko000000?oooooo`000?l000000ol00006ooooo`Oo0000F_ooool001cooooo00?o
0000ooooooooool0;_ooool2o`0000Sooooo0_l00009ooooo`?o00000oooool2o`0000Kooooo1?l0
0006oooooa?o000000Coooooo`000?l0003ooooo1ol000001?oooooo0000o`000?ooool2o`0001Co
oooo0_l00002ooooo`;o00001oooool2o`0000Oooooo0_l00006ooooo`Go00001?ooool4o`0000[o
oooo0_l00006ooooo`;o00001?ooool3o`000003ooooool0003o000000?o00001Oooool2o`0000Go
oooo0_l0001Looooo`007?ooool00ol0003oooooooooo`0hooooo`;o00002Oooool4o`0000Oooooo
0_l000000ooooooo0000o`000002ooooo`;o00001?oooolOo`0000?ooooo0_l00008ooooo`;o0000
2_ooool2o`000004ooooool0003o0000o`00017ooooo0ol00006ooooo`[o00002_ooool3o`0000co
oooo4?l00002ooooo`?o0000G_ooool001cooooo00?o0000ooooooooool0=_ooool2o`000003oooo
ool0003o000000Wooooo0ol00007ooooo`?o00001?ooool2o`0000Cooooo2Ol000000ooooooo0000
o`00000Ho`0000?ooooo0_l00003ooooo`;o00001Oooool2o`0000Kooooo1?l00007ooooo`;o0000
00?oooooo`000?l000001?ooool3o`0000Gooooo2_l0000;ooooo`;o00002_oooolBo`0000?ooooo
0ol0001Nooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00001_ooool2o`000003ooooool0
003o000000Sooooo0ol00008ooooo`Go00002?oooolSo`0000;ooooo1ol00006ooooo`?o00002?oo
ool3o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0000cooooo2?l0000<ooooo`?o0000
2?ooool?o`000004ooooool0003o0000o`0000Oooooo0_l0001Looooo`007?ooool00ol0003ooooo
ooooo`0^ooooo`;o00004oooool2o`0000cooooo0_l000000ooooooo0000o`000002ooooo`;o0000
0_oooolQo`0000?ooooo1ol000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l00000
1oooool2o`0000;ooooo0ol00003ooooo`;o00002_ooool;o`0000cooooo1?l00002oooooaCo0000
00Coooooo`000?l0003o00000_ooool2o`0000?ooooo0_l0001Looooo`007?ooool00ol0003ooooo
ooooo`1>ooooo`;o00001?ooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l00000
6ol00004ooooo`[o00001_ooool2o`0000?ooooo0_l00006ooooo`;o00000_ooool4o`0000Sooooo
1Ol00005ooooo`?o00003_ooool2o`0000;ooooo5?l000000ooooooo0000o`000003ooooo`?o0000
H?ooool001cooooo00?o0000ooooooooool0?_ooool2o`0000?ooooo0_l00009ooooo`;o00001_oo
ool2o`0000Cooooo0_l00002oooooako00000_ooool8o`0000Kooooo0_l00005ooooo`;o00001_oo
ool2o`0000;ooooo1?l00003ooooo`;o00000oooool3o`0000Oooooo0_l0000@ooooo`Co000000?o
ooooo`000?l000005_l000000ooooooo0000o`00001Pooooo`007?ooool00ol0003oooooooooo`0n
ooooo`;o00000_ooool3o`0000kooooo0_l000000ooooooo0000o`000005ooooo`;o000000?ooooo
o`000?l000001_l000000ooooooo0000o`00000Co`0000?ooooo0ol00002ooooo`?o00000_ooool7
o`0000Sooooo1Ol00009ooooo`Co000000?oooooo`000?l000001?ooool2o`0001Cooooo8?l0001P
ooooo`007?ooool00ol0003oooooooooo`0cooooo`Co00002oooool2o`0000gooooo1?l00008oooo
o`;o000000?oooooo`000?l000007?l00007oooooa3o00001Oooool3o`0000?ooooo0_l00008oooo
o`Go00001?ooool2o`0000cooooo0_l00007ooooo`;o000000?oooooo`000?l000006_l0001Poooo
o`007?ooool00ol0003oooooooooo`0cooooo`Co00001oooool2o`0000;ooooo0_l0000=ooooo`;o
00001Oooool2o`000004ooooool0003o0000ooooo`Co000000?oooooo`000?l000005?l000000ooo
oooo0000o`000004o`0000Gooooo4?l00006ooooo`;o00000oooool2o`0000Oooooo0_l000001?oo
oooo0000o`000?l00004ooooo`;o00003?ooool4o`0000?ooooo0_l00002oooooaco0000HOooool0
01cooooo00?o0000ooooooooool0=_ooool2o`0000Kooooo0_l00002ooooo`;o00003Oooool2o`00
00Gooooo1Ol000000ooooooo0000o`000004o`000003ooooool0003o000001;o00001?ooool6o`00
00?ooooo3ol0000Dooooo`;o00000_ooool2o`0001Cooooo0_l00003ooooo`;o00000_oooolLo`00
00Oooooo0_l0000^ooooo`;o0000:?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2
ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo03Kooooo0_l0
000:ooooo`;o00003?ooool3o`0000Kooooo0_l00005ooooo`Co000000?oooooo`000?l000003?l0
00001?oooooo0000o`000?ooool2o`0000;ooooo1?l000001?oooooo0000o`000?l00003ooooo`oo
00002?ooool2o`0000kooooo0_l0000Aooooo`;o00002oooool4o`000003ooooool0003o000001Go
00001_ooool2o`0002kooooo0_l0000Xooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5oooo
o`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0=_ooool2
o`0001Gooooo0_l000000ooooooo0000o`00000<ooooo`;o000000Goooooo`000?l0003o0000oooo
o`02o`000003ooooool0003o000000co00001Oooool4o`0000Sooooo3ol00006ooooo`?o00001Ooo
ool2o`0000Oooooo0_l0000Aooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo1?l0
00000ooooooo0000o`00000Eo`0003Gooooo0_l0000Yooooo`0000?ooooooa0@4?ooool00_ooool0
0ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`0fooooo`;o00005Oooool3o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`Co000000Go
ooooo`000?l0003o0000ooooo`0@o`0000Cooooo0_l0000>ooooo`go00000_ooool8o`0000Cooooo
0_l00007ooooo`;o00000_ooool2o`00013ooooo1?l000000ooooooo0000o`00000?o`000003oooo
ool0003o000000_o0000=oooool2o`0002Wooooo00000ooooooo0000ooooo`02ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000Boooool5o`0000?ooooo
0ol000001?oooooo0000o`000?l00002ooooo`;o00000oooool3o`000003ooooool0003o000000Ko
000000?oooooo`000?l000000_l000000ooooooo0000o`000004ooooo`;o00003_oooolCo`0000;o
oooo0_l0000<ooooo`?o00000_ooool2o`0001;ooooo0_l00002oooooako0000H_ooool00003oooo
ool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oEEEEo`000?l@413oc<c<00Ko
oooo00?o0000ooooooooool0Boooool4o`0000Cooooo0_l00003ooooo`;o00003?ooool7o`000003
ooooool0003o000000;o000000?oooooo`000?l000001?ooool2o`00013ooooo1_l000000ooooooo
0000o`000005o`0000Gooooo0_l0000;ooooo`Co00004Oooool2o`0000?ooooo0_l00002oooooaWo
00000_ooool3o`0006;ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo
00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`1>ooooo`;o00002?ooool2o`0000kooooo
1Ol00002ooooo`;o000000Coooooo`000?l0003o00003?ooool3o`0000Sooooo3_l00004ooooo`;o
00002oooool4o`0000?ooooo0_l0000<ooooo`;o00000oooool2o`0000?ooooo7?l00002ooooo`;o
0000Goooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008oooo
o`03o`000?oooooooooo04kooooo0_l000000ooooooo0000o`000005ooooo`;o00002Oooool4o`00
00Sooooo0_l000000ooooooo0000o`00000=ooooo`?o00002_ooool<o`0000oooooo0_l00002oooo
o`;o00000oooool2o`00017ooooo0_l00003oooooaco00000_ooool3o`0005kooooo00001_oooooo
k^k^oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003ooooooooo
o`1;ooooo`;o000000Coooooo`000?l0003ooooo0_l00005ooooo`;o00002Oooool4o`0001Sooooo
1Ol000000ooooooo0000o`000008ooooo`So000000?oooooo`000?l000003?ooool2o`000003oooo
ool0003o000000;o00000oooool2o`0000oooooo0_l00002ooooo`;o000000Coooooo`000?l0003o
oooo2?l000000ooooooo0000o`00000@o`000003ooooool0003o000000;o00006oooool2o`00047o
oooo000Looooo`03o`000?oooooooooo03Sooooo0_l000000ooooooo0000o`00000>ooooo`;o0000
00Coooooo`000?l0003ooooo0_l00005ooooo`;o00000_ooool2o`0000_ooooo0_l0000<ooooo`Co
00001?ooool5o`000003ooooool0003o000000;ooooo0_l00006ooooo`Ko000000?oooooo`000?l0
00000oooool2o`0000Oooooo0ol00002ooooo`?o00000_ooool4o`0000Oooooo0_l00004ooooo`;o
00000_ooool2o`000004ooooool0003o0000ooooo`So00000_oooolAo`000003ooooool0003o0000
01cooooo0ol00011ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o000000Coooooo`000?l0
003ooooo0_l0000Looooo`Go00002?ooool2o`0000Sooooo0_l000000ooooooo0000o`000003o`00
00kooooo0_l0000<ooooo`?o00000oooool2o`000003ooooool0003o000000Gooooo0_l00002oooo
o`?o00001?ooool2o`0000Oooooo0_l00006ooooo`Co000000Coooooo`000?l0003ooooo6Ol00002
ooooo`;o00007Oooool2o`0004;ooooo000Looooo`03o`000?oooooooooo03kooooo0_l0000Joooo
o`;o000000?oooooo`000?l000001?l00006ooooo`?o00001oooool7o`0000Oooooo0ol00004oooo
o`;o000000Coooooo`000?l0003ooooo0_l00007ooooo`?o00001_ooool3o`0000gooooo1?l0000?
ooooo`Co000000Coooooo`000?l0003ooooo6Ol00002ooooo`;o00007?ooool2o`0004?ooooo000L
ooooo`03o`000?oooooooooo03gooooo0_l0000Dooooo`;o00001Oooool2o`0000Gooooo0_l00002
ooooo`;o00000oooool2o`0000Sooooo0_l0000;ooooo`?o000000Coooooo`000?l0003ooooo1Ol0
00000ooooooo0000o`000003o`0000kooooo0_l00007ooooo`;o00001?ooool4o`000003ooooool0
003o000000Gooooo1?l00003ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`00
000Io`0001gooooo0ol00013ooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00004_ooool4
o`00013ooooo0_l0000Nooooo`;o00000oooool2o`0000?ooooo1Ol00002ooooo`;o00002?ooool2
o`0000;ooooo0ol00003ooooo`Co00000oooool2o`0000;ooooo0ol00004ooooo`Co00001_ooool4
o`0000;ooooo5ol000000ooooooo0000o`00000Mooooo`;o0000A?ooool001cooooo00?o0000oooo
ooooool0?Oooool3o`00017ooooo0_l0000[ooooo`;o00004_ooool2o`0000;ooooo0_l00008oooo
o`;o00000_ooool7o`000004ooooool0003o0000ooooo`;o00001Oooool2o`0000Wooooo0_l00002
ooooo`Co00001OoooolAo`0000gooooo0ol0001Jooooo`007?ooool00ol0003oooooooooo`0moooo
o`?o0000:?ooool2o`0001Cooooo0ol00007ooooo`;o00003oooool2o`0000Wooooo0_l000000ooo
oooo0000o`000005o`000003ooooool0003o0000013ooooo0_l00002ooooo`Co00001OoooolAo`00
00gooooo0ol0000Yooooo`;o0000;oooool001cooooo00?o0000ooooooooool0DOooool2o`0001Go
oooo0_l0000=ooooo`Go00000oooool2o`0000Oooooo1?l00002ooooo`;o00002Oooool2o`0000oo
oooo0_l00004ooooo`Go00002_ooool2o`0000Cooooo1?l0000;ooooo`Co00001?ooool2o`0003[o
oooo0_l0000_ooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00004?ooool2o`0000Wooooo
1Ol0000Fooooo`Go00000oooool2o`000004ooooool0003o0000o`0000?ooooo1?l00002ooooo`;o
00000oooool3o`0001[ooooo1Ol00006ooooo`Ko00001Oooool2o`0000Sooooo1_l00006ooooo`;o
00008_ooool2o`0004Oooooo000Looooo`03o`000?oooooooooo03oooooo0_l0000Kooooo`Go0000
3_ooool2o`0000Wooooo3Ol000000ooooooo0000o`000002o`0000?ooooo0_l000000ooooooo0000
o`000002o`0000Kooooo1_l00003ooooo`?o00004oooool4o`0000Cooooo0_l000000ooooooo0000
o`000002ooooo`;o00001?ooool6o`0000gooooo0_l0000Jooooo`?o0000Aoooool001cooooo00?o
0000ooooooooool0?oooool2o`0001gooooo0_l0000?ooooo`;o00002?ooool2o`000003ooooool0
003o000000_o00001_ooool5o`0000;ooooo0ol000000ooooooo0000o`000006o`0000?ooooo0ol0
000Eooooo`?o00000oooool2o`000003ooooool0003o000000;ooooo0_l0000Gooooo`;o00006_oo
ool2o`0004Sooooo000Looooo`;o0000@?ooool2o`0001[ooooo0_l000000ooooooo0000o`00000:
ooooo`Go00002_ooool3o`000004ooooool0003o0000o`0000?ooooo0_l00002ooooo`;o00002?oo
ool2o`0000;ooooo1?l000000ooooooo0000o`000003ooooo`;o00007Oooool2o`0000Cooooo1?l0
000Gooooo`;o0000J?ooool001cooooo00?o0000ooooooooool0@?ooool2o`0000oooooo0_l00004
ooooo`;o00000_ooool2o`0000gooooo1ol00008ooooo`?o000000Coooooo`000?l0003o00002ooo
ool2o`0000Cooooo0_l00002ooooo`;o00002?ooool2o`0001[ooooo0_l00007ooooo`;o00005ooo
ool4o`000003ooooool0003o000001Sooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`10
ooooo`;o00003Oooool4o`0000Cooooo0_l0000Dooooo`Co00000oooool2o`0000?ooooo0_l00009
ooooo`;o00001Oooool2o`0000Sooooo0_l0000Tooooo`;o00003Oooool2o`0000Gooooo0_l00009
ooooo`?o00000oooool2o`00017ooooo0_l00004ooooo`?o00005Oooool2o`0003Cooooo000Loooo
o`03o`000?oooooooooo043ooooo0_l0000=ooooo`;o00007?ooool2o`0000Gooooo0ol00008oooo
o`;o00000oooool2o`00013ooooo0_l00006ooooo`;o00003Oooool3o`0000Kooooo0_l00006oooo
o`;o00002_ooool2o`0000Gooooo0_l00009ooooo`;o00003oooool2o`000003ooooool0003o0000
00?ooooo0_l00003ooooo`?o00005_ooool2o`0003Cooooo000Looooo`03o`000?oooooooooo043o
oooo0_l0000<ooooo`Ko00005Oooool2o`0000Gooooo0_l00003ooooo`;o00002?ooool2o`000003
ooooool0003o000000Wooooo1ol00002ooooo`?o00001?ooool3o`0000gooooo0ol00006ooooo`;o
00001_ooool2o`0002gooooo0_l000000ooooooo0000o`000008ooooo`;o0000COooool001cooooo
00?o0000ooooooooool0@oooool2o`0000Wooooo1_l0000Eooooo`Co00000oooool2o`0000;ooooo
0_l00002ooooo`;o00002?ooool2o`0000?ooooo0_l00004ooooo`Oo000000?oooooo`000?l00000
0_l00004ooooo`;o00001?ooool2o`0000Sooooo0ol00002ooooo`;o00002Oooool2o`0001oooooo
0_l0000=ooooo`?o0000FOooool001cooooo00?o0000ooooooooool0@oooool2o`0000gooooo0_l0
000Gooooo`;o00001oooool2o`0000;ooooo0_l00004ooooo`Co00001Oooool2o`0000?ooooo0_l0
0007ooooo`Co00002_ooool2o`000003ooooool0003o000000Gooooo0ol00002ooooo`;o00002Ooo
ool3o`0001kooooo0_l0000=ooooo`?o0000FOooool001cooooo00?o0000ooooooooool0D_ooool2
o`0002[ooooo1?l0000:ooooo`;o00000oooool2o`0000;ooooo1?l00008ooooo`;o00000_ooool7
o`0000;ooooo1_l0000:ooooo`;o0000=oooool2o`00053ooooo000Looooo`03o`000?oooooooooo
05;ooooo0_l0000dooooo`;o00001oooool3o`000003ooooool0003o000000[ooooo0ol000001?oo
oooo0000o`000?ooool7o`000003ooooool0003o000000;o00006?ooool3o`00013ooooo0_l0000F
ooooo`;o0000D?ooool001cooooo00?o0000ooooooooool0G?ooool2o`0002Cooooo0_l00004oooo
o`;o00002?ooool3o`0000Wooooo4_l00002ooooo`;o00006?ooool3o`00013ooooo0_l0000Aoooo
o`;o00006Oooool2o`0003[ooooo000Looooo`03o`000?oooooooooo05[ooooo1?l00003ooooo`;o
00007oooool2o`0000Kooooo0_l00005ooooo`Co000000?oooooo`000?l000001_oooolBo`0001Ko
oooo0_l0000Zooooo`;o00006Oooool2o`0003[ooooo000Looooo`03o`000?oooooooooo05Gooooo
0_l00003ooooo`;o00001Oooool2o`0002Oooooo0_l00005ooooo`;o00000oooool2o`0000?ooooo
0_l000000ooooooo0000o`00000@o`000003ooooool0003o000000Oooooo0_l00008ooooo`Co0000
00?oooooo`000?l000002Oooool2o`0001kooooo0_l0001Cooooo`007?ooool00ol0003ooooooooo
o`1Eooooo`;o00002?ooool2o`0002oooooo1Ol00006ooooo`;o000000?oooooo`000?l000003ol0
0002ooooo`Co00001Oooool2o`0000?ooooo0_l00003ooooo`;o00000oooool2o`0000Wooooo0_l0
000Nooooo`;o0000Doooool001cooooo00?o0000ooooooooool0Aoooool2o`0001Kooooo0_l0000_
ooooo`Go000000?oooooo`000?l000001_oooolBo`0000?ooooo0_l000000ooooooo0000o`000006
ooooo`Oo0000AOooool2o`0003gooooo000Looooo`03o`000?oooooooooo04Oooooo0_l0000>oooo
o`?o0000=oooool3o`0000;ooooo0_l00004oooooaCo00000oooool5o`0000Kooooo0_l000000ooo
oooo0000o`000002o`000003ooooool0003o000004;ooooo0_l0000mooooo`007?ooool00ol0003o
ooooooooo`1Fooooo`Go0000=oooool2o`0000Sooooo4Ol000000ooooooo0000o`000003o`0000;o
oooo1?l00008ooooo`Co000000?oooooo`000?l000009oooool4o`0005Kooooo000Looooo`;o0000
Eoooool5o`00043ooooo6?l00002ooooo`Co00001Oooool2o`000003ooooool0003o000000Co0000
:?ooool4o`0005Kooooo000Looooo`03o`000?oooooooooo05Oooooo0_l00005ooooo`;o00009Ooo
ool2o`0001Cooooo6?l00002ooooo`?o00001_ooool2o`000004ooooool0003o0000ooooo`?o0000
@?ooool2o`00043ooooo000Looooo`03o`000?oooooooooo04[ooooo0_l0000Booooo`;o000000?o
ooooo`000?l000008_ooool2o`0001Cooooo6?l00003ooooo`;o000000Coooooo`000?l0003o0000
0_ooool2o`000003ooooool0003o000004Cooooo0_l00010ooooo`007?ooool00ol0003ooooooooo
o`19ooooo`?o00002oooool2o`0000Sooooo0_l0000Sooooo`;o00003?ooool2o`0000Cooooo6_l0
0005ooooo`?o00000_ooool2o`0002oooooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`19
ooooo`;o00003?ooool2o`0000Cooooo0_l00002ooooo`;o00008oooool2o`0000cooooo0ol00003
oooooaOo000000?oooooo`000?l000001_l000001?oooooo0000o`000?ooool2o`000003ooooool0
003o000002cooooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`19ooooo`Co00004?ooool2
o`0003?ooooo0_l000000ooooooo0000o`000003ooooob?o000000?oooooo`000?l000000ol00026
ooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o00003_ooool4o`0002cooooo0ol00003oooo
o`?o00001_oooolJo`0000Kooooo0_l00002ooooo`Go00001_ooool2o`0003Oooooo0_l00015oooo
o`007?ooool00ol0003oooooooooo`1Kooooo`Co00002?ooool2o`0000kooooo0ol0000Aooooo`?o
00000oooool2o`0000;ooooo0_l00002oooooaSo000000Coooooo`000?l0003ooooo0_l00003oooo
o`Co00000_ooool3o`0000Kooooo0_l0000gooooo`;o0000AOooool001cooooo00?o0000oooooooo
ool0GOooool2o`0000;ooooo0_l00002ooooo`Co00003_ooool3o`000003ooooool0003o000000Go
oooo0_l000000ooooooo0000o`00000:ooooo`;o00000_ooool2o`0000;ooooo2ol000000ooooooo
0000o`00000:o`0000;ooooo1?l00005ooooo`;o00000_ooool2o`0008Oooooo000Looooo`03o`00
0?oooooooooo04cooooo0_l0000?ooooo`;o00000_ooool2o`0000;ooooo0_l0000Dooooo`;o0000
1Oooool2o`000003ooooool0003o000001?ooooo7?l0002Cooooo`007?ooool00ol0003ooooooooo
o`1<ooooo`;o0000C?ooool2o`000003ooooool0003o000001Co00000oooool2o`0000Oooooo0_l0
0028ooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o00009oooool2o`0000gooooo4Ol00000
0ooooooo0000o`000005ooooo`Co000000?oooooo`000?l000000_ooool2o`0008Sooooo000Loooo
o`03o`000?oooooooooo06Gooooo0_l00002ooooo`;o00003_ooool2o`0001?ooooo0_l0000?oooo
oa3o00002Oooool2o`000003ooooool0003o000000;ooooo0_l0000looooo`;o0000B_ooool001co
oooo00?o0000ooooooooool0DOooool2o`0001;ooooo0ol000000ooooooo0000o`000006ooooo`;o
00001_ooool2o`0000_ooooo0_l00006ooooo`;o00002?ooool2o`0000;ooooo0_l000000ooooooo
0000o`00000>o`00013ooooo0_l0000jooooo`Co0000B_ooool001cooooo00?o0000ooooooooool0
DOooool2o`0001?ooooo0_l00009ooooo`;o00004oooool3o`0000oooooo0_l00002ooooo`?o0000
00?oooooo`000?l000002ol0001>ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0Dooo
ool2o`0001?ooooo0_l0000Kooooo`Co00004oooool3o`0000?ooooo1_l000000ooooooo0000o`00
0007ooooo`;o00001?ooool5o`0000;ooooo0_l0000Vooooo`;o0000H?ooool001cooooo0_l0001D
ooooo`;o00004oooool2o`0000;ooooo0_l0000Gooooo`;o00005Oooool4o`0000?ooooo2?l00007
ooooo`;o00001?ooool5o`0000;ooooo0_l0000Vooooo`;o0000H?ooool001cooooo00?o0000oooo
ooooool0Doooool3o`000003ooooool0003o000001?ooooo1_l0000Xooooo`;o00000_ooool7o`00
0004ooooool0003o0000o`0000Cooooo0_l0000fooooo`;o0000H_ooool001cooooo00?o0000oooo
ooooool0Doooool3o`000003ooooool0003o000000;o00004oooool6o`0000[ooooo0_l0000Joooo
o`;o00000oooool:o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`;o00001Oooool2o`00
02Kooooo0_l0000?ooooo`;o0000DOooool001cooooo00?o0000ooooooooool0Eoooool4o`0000oo
oooo0_l00004ooooo`Co00000_ooool2o`000004ooooool0003o0000ooooo`Co00000oooool3o`00
00_ooooo0_l0000<ooooo`Oo00000_ooool2o`0000Kooooo0_l00004ooooo`;o00000oooool4o`00
03Oooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o00003oooool2o`0000Co
oooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo2ol0000:ooooo`;o00002Oooool2o`00
00Cooooo0_l00004ooooo`;o00003?ooool4o`000003ooooool0003o000008cooooo000Looooo`03
o`000?oooooooooo06cooooo0_l00007ooooo`;o00001oooool9o`0000Cooooo0_l00004ooooo`;o
00001?ooool2o`0000?ooooo0_l00002ooooo`;o00004?ooool2o`0000;ooooo1?l0000Wooooo`;o
0000I_ooool001cooooo00?o0000ooooooooool0F?ooool2o`0001;ooooo0_l00007ooooo`;o0000
3Oooool5o`0000;ooooo0ol00003ooooo`Co00000_ooool2o`0000Oooooo0_l0000@ooooo`;o0000
0oooool7o`0002?ooooo0_l0001Vooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o00008Ooo
ool2o`0000Wooooo0ol00002ooooo`?o00000_ooool5o`0000Wooooo0ol0000Aooooo`Co00000_oo
ool6o`0000Sooooo0_l00021ooooo`007?ooool00ol0003oooooooooo`1Nooooo`?o00004?ooool3
o`0000Kooooo0ol00005ooooo`;o00001?ooool2o`000003ooooool0003o000000?ooooo1?l00006
ooooo`;o00000_ooool3o`000003ooooool0003o000000;ooooo0_l0000;ooooo`So000000?ooooo
o`000?l000002?ooool2o`00087ooooo000Looooo`03o`000?oooooooooo05kooooo0ol0000@oooo
o`?o00001_ooool2o`0000Cooooo2_l00007ooooo`?o00001_ooool2o`0000Kooooo0_l00002oooo
o`Co00001Oooool2o`0000;ooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o0000
08_ooooo000Looooo`03o`000?oooooooooo083ooooo0_l000000ooooooo0000o`00000:o`0000;o
oooo0ol00006ooooo`;o00001?ooool2o`0000Gooooo0ol00003ooooo`Co00002Oooool4o`0008_o
oooo000Looooo`03o`000?oooooooooo06;ooooo0_l0000Looooo`;o00000oooool:o`0000?ooooo
0_l000000ooooooo0000o`000003ooooo`;o00001?ooool2o`0000_ooooo0_l0000;ooooo`;o0000
8?ooool2o`0006_ooooo000Looooo`03o`000?oooooooooo06;ooooo0_l0000Tooooo`;o00000ooo
ool7o`000003ooooool0003o000000cooooo0ol0000Iooooo`;o00006oooool2o`0000kooooo0ol0
001Jooooo`007?ooool00ol0003oooooooooo`28ooooo`;o00001?ooool5o`0000;ooooo0ol0000;
ooooo`?o000000?oooooo`000?l000003?ooool2o`0000Sooooo0_l0000[ooooo`?o0000F_ooool0
0006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Q
olc<c006ooooo`03o`000?oooooooooo07_ooooo0ol0000@ooooo`Co00000_ooool4o`0000oooooo
1?l0000:ooooo`;o0000T_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Co
oooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo07_ooooo0ol0000Foooo
o`;o000000?oooooo`000?l000000_l0000>ooooo`;o0000W_ooool00003ooooool@413ooooo00;o
oooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool0JOooool2o`00027ooooo0_l00009ooooo`Co00003_ooool2o`0002Sooooo0_l0001doooo
o`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRH
V?lb<S801_ooool3o`0006Wooooo0_l0000Eooooo`;o00002_ooool2o`0001_ooooo0_l0000Voooo
o`Co0000M?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Oo<c<co
0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0P?ooool2o`0000gooooo0_l00008oooo
o`?o00004Oooool2o`0002;ooooo0_l0001fooooo`0000?ooooooa0@4?ooool00_ooool00ol@413o
ooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`23oooo
o`;o00002_ooool2o`0000Sooooo0ol0000;ooooo`;o00001?ooool2o`0001[ooooo0_l0001noooo
o`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l000001_oo
ool00ol0003oooooooooo`23ooooo`Co00004oooool3o`0000[ooooo0_l0000<ooooo`Co00004?oo
ool2o`0007kooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@06ooooo`03o`000?oooooooooo07;ooooo0_l0000Aooooo`?o00004_ooool3o`0001;o
oooo0_l00004ooooo`Co00002?ooool2o`000003ooooool0003o000001?ooooo0_l0001^ooooo`00
7?ooool00ol0003oooooooooo`1booooo`;o00004_ooool2o`0002Oooooo0_l00004ooooo`;o0000
0oooool2o`0000Gooooo0_l000000ooooooo0000o`00000:ooooo`;o000000?oooooo`000?l00000
1?ooool2o`0006kooooo000Looooo`03o`000?oooooooooo07Cooooo0_l0000Xooooo`Co000000?o
ooooo`000?l000003oooool3o`0000?ooooo0_l00003ooooo`;o00002Oooool2o`0000;ooooo1ol0
000;ooooo`;o0000Ioooool001cooooo00?o0000ooooooooool0M?ooool2o`0001Gooooo0_l0000A
ooooo`Oo00003oooool2o`0000Sooooo0ol00009ooooo`Ko000000?oooooo`000?l000000_l00009
ooooo`Co0000Ioooool001cooooo00?o0000ooooooooool0Roooool2o`0001Cooooo0ol0000Joooo
o`?o00002Oooool4o`00013ooooo0_l0001Yooooo`007?ooool00ol0003oooooooooo`1iooooo`;o
00009_ooool2o`0001?ooooo0_l00007ooooo`;o00002Oooool2o`0007gooooo000Looooo`03o`00
0?oooooooooo07Wooooo0ol0000Fooooo`;o00008_ooool4o`0008oooooo000Looooo`03o`000?oo
oooooooo07[ooooo0_l0000Fooooo`Co00008_ooool2o`0001_ooooo0_l0001booooo`007?ooool0
0ol0003oooooooooo`2Dooooo`;o00000oooool2o`0003Kooooo0_l00002ooooo`;o0000L_ooool0
01cooooo00?o0000ooooooooool0O_ooool2o`0001Wooooo0_l0000]ooooo`;o00001oooool2o`00
07Kooooo000Looooo`03o`000?oooooooooo07kooooo1?l0000Looooo`?o00009oooool2o`0000Oo
oooo0_l0001fooooo`007?ooool00ol0003oooooooooo`20ooooo`;o00007?ooool4o`000:Oooooo
000Looooo`;o0000XOooool2o`0001oooooo1?l00024ooooo`007?ooool00ol0003oooooooooo`2_
ooooo`Go00002?ooool2o`0000?ooooo1?l00024ooooo`007?ooool00ol0003oooooooooo`2_oooo
o`Go00002?ooool2o`0008_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo09;ooooo0ol0002dooooo`007?ooool00ol0003oooooooooo`2Boooo
o`Go0000/_ooool001cooooo00?o0000ooooooooool0UOooool2o`000;;ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0:3ooooo0_l0002Woooo
o`007?ooool00ol0003oooooooooo`2Pooooo`Co0000YOooool001cooooo00?o0000ooooooooool0
X_ooool2o`000003ooooool0003o00000:;ooooo000Looooo`03o`000?oooooooooo0:Gooooo0_l0
002Rooooo`007?ooool2o`000;7ooooo0_l0002Gooooo`007?ooool00ol0003oooooooooo`2`oooo
o`;o0000Uoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000B
ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooood[ooooo000Doooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003o
ooooooooo`05ooooo`?o0000oooooom:ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo
000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomB
ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Booooo`03oeEEEOmVIVKo00000?oo
ooooE?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Gooooo00Co410@o`00
0?l0003ooooo0_l000000ol@413oooooooooo`0Eooooo`05oiRHV?l@413o0000oc8b<_o<c<`00ooo
ool01?l@413o0000odA4A?o<c<`4ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0T?ooool00:Kooooo
00Go0000ooooooooooooooooo`000009ooooo`Ko00002Oooool01Ol@413o^[ZjoooooomgMgOo<S8b
00Gooooo00?oV9RHoa0@4?oMgMd00oooool01OmEEEGoMgMgoooooonHV9So8B4Q093ooooo002Voooo
o`05o`000?ooooooooooooooool000007?ooool00ol0003oooooooooo`04ooooo`03ohN7QomEEEGo
oooo00;ooooo00Go0000ooooooooooooooooo`00002@ooooo`00Y_ooool01Ol0003ooooooooooooo
oooo000000Wooooo1_l0000<ooooo`03ojVYZOl@413ooooo00;ooooo00Goc<c<ob4Q8Ol0003oEEEE
o`000003ooooo`05o`000?nHV9SooooooiRHV?lQ8B40T?ooool00:Kooooo00Go0000ohN7Qooooooo
ZJVYo`00000Jooooo`03oa0@4?l0003o^[Zj00?ooooo00Go8B4QohN7QoooooooV9RHo`000003oooo
o`05o`000?mEEEGo0000oa0@4?o<c<`0T?ooool00:Gooooo00?o410@o`000?mgMgL00_l000000onH
V9Soooooooooo`0Iooooo`03okZj^_lQ8B7ooooo00;ooooo00Go0000ooooooooooooooooo`000003
ooooo`03oeEEEOn7QhOooooo09;ooooo0033ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool0
1OlQ8B7oV9RHoooooomgMgOoEEEE00?ooooo00?ogMgMoa0@4?nHV9P0T_ooool00<?ooooo00GoZJVY
oa0@4?l0003o410@ojVYZ@03ooooo`05olc<c?l@413o0000oc8b<_o^k^h01?ooool01?o<c<coA4A4
o`000?l@412@ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(402) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.3037 .52326 Mdot
.33907 .55246 Mdot
.69269 .64037 Mdot
.50695 .39578 Mdot
.70728 .44356 Mdot
.65985 .63657 Mdot
.4905 .69017 Mdot
.48837 .68746 Mdot
.64095 .63213 Mdot
.22852 .41609 Mdot
.50595 .72169 Mdot
.51245 .30857 Mdot
.49388 .70556 Mdot
.49613 .37207 Mdot
.46009 .48216 Mdot
.44495 .39313 Mdot
.33972 .57044 Mdot
.75835 .43502 Mdot
.43847 .37335 Mdot
.69311 .60775 Mdot
.47331 .23563 Mdot
.48593 .36808 Mdot
.34562 .51018 Mdot
.49343 .37282 Mdot
.46289 .37658 Mdot
.34401 .5351 Mdot
.30777 .51294 Mdot
.4649 .37126 Mdot
.49844 .31493 Mdot
.50355 .71845 Mdot
.58272 .57316 Mdot
.41498 .19344 Mdot
.50581 .41768 Mdot
.35301 .33722 Mdot
.49928 .68417 Mdot
.4422 .71256 Mdot
.67428 .60432 Mdot
.47191 .7363 Mdot
.50505 .68428 Mdot
.52055 .70126 Mdot
.51902 .7117 Mdot
.34361 .52868 Mdot
.51793 .73333 Mdot
.58912 .79174 Mdot
.50339 .38663 Mdot
.40753 .47016 Mdot
.55151 .78679 Mdot
.46299 .33467 Mdot
.34311 .56478 Mdot
.7017 .61835 Mdot
.6961 .3653 Mdot
.46587 .71994 Mdot
.44585 .58209 Mdot
.74965 .77695 Mdot
.50486 .70536 Mdot
.44484 .35962 Mdot
.63299 .61278 Mdot
.50316 .34357 Mdot
.50447 .40231 Mdot
.34673 .30118 Mdot
.48623 .34227 Mdot
.74554 .45001 Mdot
.32437 .57825 Mdot
.62649 .60122 Mdot
.64211 .63645 Mdot
.475 .73724 Mdot
.36495 .52896 Mdot
.48936 .71429 Mdot
.51503 .32323 Mdot
.6981 .62799 Mdot
.48848 .31498 Mdot
.50167 .72296 Mdot
.33012 .50296 Mdot
.49906 .39337 Mdot
.39409 .74843 Mdot
.52197 .7837 Mdot
.60496 .61326 Mdot
.41556 .24857 Mdot
.78067 .39346 Mdot
.57809 .53883 Mdot
.49175 .38735 Mdot
.78068 .67497 Mdot
.52504 .49953 Mdot
.32591 .55477 Mdot
.38219 .57952 Mdot
.35341 .62534 Mdot
.46052 .34658 Mdot
.56271 .57994 Mdot
.4649 .41409 Mdot
.68797 .50511 Mdot
.63832 .61498 Mdot
.31508 .54651 Mdot
.49897 .38991 Mdot
.52854 .34723 Mdot
.22015 .49111 Mdot
.47369 .30816 Mdot
.49801 .40367 Mdot
.37416 .59652 Mdot
.50283 .72895 Mdot
.41597 .37138 Mdot
.68148 .41649 Mdot
.42958 .59888 Mdot
.44699 .35581 Mdot
.65931 .61243 Mdot
.30309 .56629 Mdot
.48022 .409 Mdot
.48089 .70424 Mdot
.49018 .38201 Mdot
.53068 .70662 Mdot
.36236 .56263 Mdot
.52799 .38204 Mdot
.7316 .43607 Mdot
.50236 .26059 Mdot
.34549 .51509 Mdot
.35026 .44209 Mdot
.4798 .35175 Mdot
.50326 .33654 Mdot
.34292 .55371 Mdot
.69267 .61758 Mdot
.71747 .69811 Mdot
.33632 .50674 Mdot
.52109 .70138 Mdot
.33425 .56765 Mdot
.52999 .29228 Mdot
.68997 .61072 Mdot
.42334 .58281 Mdot
.42046 .58153 Mdot
.63025 .33503 Mdot
.4933 .39398 Mdot
.54218 .2683 Mdot
.65984 .62149 Mdot
.35025 .53885 Mdot
.49767 .71428 Mdot
.44197 .34291 Mdot
.33202 .51867 Mdot
.48264 .6884 Mdot
.71489 .47578 Mdot
.74408 .42228 Mdot
.35711 .54438 Mdot
.33969 .46358 Mdot
.5365 .71941 Mdot
.52207 .71689 Mdot
.6921 .36528 Mdot
.32698 .55564 Mdot
.7284 .45191 Mdot
.47356 .7006 Mdot
.64659 .24524 Mdot
.50539 .40564 Mdot
.66304 .3645 Mdot
.74977 .70133 Mdot
.69604 .36569 Mdot
.39042 .23001 Mdot
.72849 .44015 Mdot
.48067 .68871 Mdot
.47691 .31718 Mdot
.32718 .53436 Mdot
.3357 .52138 Mdot
.51277 .32895 Mdot
.47843 .40075 Mdot
.50659 .37124 Mdot
.48992 .41371 Mdot
.52937 .6419 Mdot
.49719 .38783 Mdot
.2725 .70171 Mdot
.32421 .52563 Mdot
.46532 .38894 Mdot
.68247 .61726 Mdot
.43249 .422 Mdot
.50211 .73902 Mdot
.50689 .39908 Mdot
.47353 .39372 Mdot
.47162 .30193 Mdot
.52031 .6969 Mdot
.38895 .76033 Mdot
.7949 .38122 Mdot
.45705 .74164 Mdot
.48959 .80134 Mdot
.67114 .62777 Mdot
.48242 .33726 Mdot
.72233 .46638 Mdot
.42469 .39585 Mdot
.52182 .37609 Mdot
.70452 .3659 Mdot
.47981 .38966 Mdot
.40822 .22748 Mdot
.5463 .36339 Mdot
.37649 .62334 Mdot
.25 .65489 Mdot
.51805 .38778 Mdot
.25838 .40118 Mdot
.65808 .37656 Mdot
.63303 .56989 Mdot
.50221 .71456 Mdot
.68484 .63761 Mdot
.69317 .62638 Mdot
.46177 .72828 Mdot
.37967 .43074 Mdot
.24044 .3931 Mdot
.48812 .30793 Mdot
.42916 .59502 Mdot
.375 .56474 Mdot
.73156 .44055 Mdot
.35673 .54827 Mdot
.80294 .64686 Mdot
.60258 .52435 Mdot
.55843 .56519 Mdot
.76934 .44501 Mdot
.70104 .60763 Mdot
.42976 .58765 Mdot
.72582 .45899 Mdot
.5141 .36458 Mdot
.35911 .56326 Mdot
.66575 .37188 Mdot
.43028 .40241 Mdot
.15106 .47425 Mdot
.31122 .51081 Mdot
.60569 .33256 Mdot
.50204 .70617 Mdot
.62376 .63674 Mdot
.46025 .34776 Mdot
.49589 .3536 Mdot
.36927 .55237 Mdot
.47886 .31999 Mdot
.54275 .54348 Mdot
.4768 .39467 Mdot
.62716 .60197 Mdot
.79743 .4568 Mdot
.46942 .74418 Mdot
.76453 .47437 Mdot
.33524 .50392 Mdot
.42825 .82225 Mdot
.66838 .60966 Mdot
.40956 .39454 Mdot
.48977 .72136 Mdot
.71261 .47264 Mdot
.65789 .60644 Mdot
.75024 .43458 Mdot
.52694 .37974 Mdot
.66699 .60183 Mdot
.74464 .44416 Mdot
.52038 .55711 Mdot
.48409 .41043 Mdot
.61297 .28211 Mdot
.46754 .71005 Mdot
.31451 .55495 Mdot
.52351 .35779 Mdot
.45289 .58957 Mdot
.4782 .29322 Mdot
.61313 .38732 Mdot
.44715 .58716 Mdot
.44141 .61088 Mdot
.55904 .52457 Mdot
.73251 .48198 Mdot
.4439 .76806 Mdot
.54372 .58021 Mdot
.34007 .57066 Mdot
.52796 .36323 Mdot
.43287 .66276 Mdot
.46793 .70373 Mdot
.51241 .35706 Mdot
.41356 .64883 Mdot
.4738 .69883 Mdot
.50669 .34081 Mdot
.51784 .7084 Mdot
.32999 .52471 Mdot
.52326 .52359 Mdot
.31035 .5582 Mdot
.51565 .37888 Mdot
.51578 .7132 Mdot
.68785 .63366 Mdot
.34326 .53449 Mdot
.48716 .37728 Mdot
.4785 .37895 Mdot
.43601 .60121 Mdot
.48908 .40472 Mdot
.39332 .60649 Mdot
.46056 .33954 Mdot
.7019 .63089 Mdot
.48293 .30907 Mdot
.68777 .40034 Mdot
.68497 .48457 Mdot
.36614 .55672 Mdot
.44791 .58844 Mdot
.64321 .60668 Mdot
.51772 .53588 Mdot
.58965 .27806 Mdot
.4958 .38335 Mdot
.44714 .59496 Mdot
.61663 .35153 Mdot
.50261 .73821 Mdot
.49642 .42777 Mdot
.64872 .68079 Mdot
.64141 .61361 Mdot
.42801 .59106 Mdot
.42266 .37629 Mdot
.34086 .49217 Mdot
.44628 .34576 Mdot
.67091 .60495 Mdot
.30918 .55409 Mdot
.46262 .31559 Mdot
.53863 .77855 Mdot
.45423 .59043 Mdot
.50916 .72817 Mdot
.38226 .59473 Mdot
.49271 .32831 Mdot
.6909 .63691 Mdot
.33952 .51867 Mdot
.50402 .69749 Mdot
.34316 .51148 Mdot
.66936 .3799 Mdot
.60634 .36539 Mdot
.47828 .58987 Mdot
.75171 .47825 Mdot
.59439 .17499 Mdot
.45878 .74607 Mdot
.41837 .38154 Mdot
.62289 .65729 Mdot
.23299 .57465 Mdot
.65452 .61053 Mdot
.33109 .46683 Mdot
.63537 .61436 Mdot
.45224 .33992 Mdot
.65437 .63816 Mdot
.20939 .50389 Mdot
.46899 .37326 Mdot
.64546 .6423 Mdot
.5455 .63539 Mdot
.47131 .37479 Mdot
.33093 .5172 Mdot
.32682 .22677 Mdot
.37344 .36392 Mdot
.37544 .39022 Mdot
.6296 .61342 Mdot
.29347 .47524 Mdot
.46265 .36455 Mdot
.4366 .36246 Mdot
.33112 .53677 Mdot
.48747 .29422 Mdot
.74691 .47482 Mdot
.75723 .44049 Mdot
.67924 .30562 Mdot
.47994 .20822 Mdot
.37274 .42912 Mdot
.33869 .52862 Mdot
.80494 .41289 Mdot
.38676 .74337 Mdot
.4534 .58935 Mdot
.48656 .68721 Mdot
.41713 .77275 Mdot
.43993 .3984 Mdot
.26338 .55414 Mdot
.53956 .54043 Mdot
.30782 .53727 Mdot
.49065 .57705 Mdot
.50085 .69386 Mdot
.37407 .3851 Mdot
.24598 .36514 Mdot
.50797 .37082 Mdot
.47697 .73201 Mdot
.51551 .30394 Mdot
.55578 .57855 Mdot
.62238 .31261 Mdot
.5907 .7203 Mdot
.51408 .37992 Mdot
.42166 .75343 Mdot
.52269 .36987 Mdot
.63689 .3406 Mdot
.51498 .35904 Mdot
.33178 .51239 Mdot
.45412 .30931 Mdot
.53672 .58023 Mdot
.63909 .19691 Mdot
.60191 .51684 Mdot
.75433 .44758 Mdot
.49533 .36832 Mdot
.50521 .35888 Mdot
.74776 .44994 Mdot
.31109 .54138 Mdot
.52554 .35311 Mdot
.51432 .82133 Mdot
.49602 .38912 Mdot
.4644 .72062 Mdot
.60382 .43784 Mdot
.45958 .19448 Mdot
.46831 .34484 Mdot
.34393 .49426 Mdot
.51946 .72091 Mdot
.47881 .7175 Mdot
.53118 .42444 Mdot
.46657 .71232 Mdot
.47924 .31744 Mdot
.60299 .43874 Mdot
.36025 .52835 Mdot
.51105 .43302 Mdot
.30873 .53035 Mdot
.81639 .42737 Mdot
.47362 .69518 Mdot
.45221 .59632 Mdot
.37081 .44042 Mdot
.48596 .6974 Mdot
.7591 .49721 Mdot
.44932 .31521 Mdot
.46607 .43851 Mdot
.38947 .53617 Mdot
.68635 .63981 Mdot
.43981 .58738 Mdot
.50539 .70328 Mdot
.49979 .38605 Mdot
.45294 .37452 Mdot
.46801 .72069 Mdot
.32638 .27313 Mdot
.58397 .57268 Mdot
.51583 .38024 Mdot
.32106 .51877 Mdot
.34896 .5355 Mdot
.46829 .41079 Mdot
.52389 .36512 Mdot
.66989 .6404 Mdot
.44721 .59412 Mdot
.44553 .58841 Mdot
.42188 .58857 Mdot
.62183 .6236 Mdot
.60111 .17954 Mdot
.52184 .71882 Mdot
.42712 .19213 Mdot
.38269 .69954 Mdot
.55882 .36069 Mdot
.68771 .61585 Mdot
.49072 .34883 Mdot
.45091 .35469 Mdot
.5142 .7127 Mdot
.58148 .19576 Mdot
.43792 .35487 Mdot
.30385 .53997 Mdot
.46896 .72594 Mdot
.50604 .29953 Mdot
.53848 .72503 Mdot
.71508 .44898 Mdot
.36332 .42641 Mdot
.4654 .71159 Mdot
.36166 .53845 Mdot
.46531 .71211 Mdot
.506 .36282 Mdot
.42165 .37463 Mdot
.30692 .53384 Mdot
.724 .42566 Mdot
.51955 .33569 Mdot
.511 .34297 Mdot
.72999 .60189 Mdot
.3965 .74793 Mdot
.73795 .49786 Mdot
.45817 .33494 Mdot
.4687 .44111 Mdot
.73114 .42511 Mdot
.50965 .33145 Mdot
.47939 .3101 Mdot
.53887 .2647 Mdot
.53255 .71704 Mdot
.71435 .48242 Mdot
.62739 .19719 Mdot
.3097 .51271 Mdot
.40765 .60978 Mdot
.42519 .59113 Mdot
.45177 .71338 Mdot
.51522 .52434 Mdot
.43494 .59346 Mdot
.39135 .68017 Mdot
.34352 .80192 Mdot
.44036 .58974 Mdot
.61994 .615 Mdot
.24788 .4814 Mdot
.4889 .31221 Mdot
.52012 .36935 Mdot
.73724 .47941 Mdot
.3421 .55803 Mdot
.27287 .69437 Mdot
.45423 .734 Mdot
.48241 .35845 Mdot
.31002 .50616 Mdot
.36166 .62546 Mdot
.43136 .59406 Mdot
.71844 .45994 Mdot
.71267 .43492 Mdot
.52249 .36054 Mdot
.6102 .32061 Mdot
.34178 .53014 Mdot
.48721 .3772 Mdot
.50088 .33361 Mdot
.6554 .59702 Mdot
.35814 .56288 Mdot
.67961 .61633 Mdot
.45736 .60803 Mdot
.2054 .55217 Mdot
.60303 .82387 Mdot
.46902 .71052 Mdot
.45728 .52234 Mdot
.46785 .74263 Mdot
.5634 .73528 Mdot
.44703 .59301 Mdot
.48653 .37335 Mdot
.34727 .50701 Mdot
.48875 .38065 Mdot
.49718 .3896 Mdot
.50937 .3827 Mdot
.37158 .4279 Mdot
.78063 .39993 Mdot
.72722 .47402 Mdot
.4845 .32488 Mdot
.62833 .61008 Mdot
.39893 .62439 Mdot
.20222 .44884 Mdot
.49685 .3617 Mdot
.50434 .33704 Mdot
.36315 .51901 Mdot
.51815 .39908 Mdot
.48388 .69301 Mdot
.30814 .54349 Mdot
.44812 .36516 Mdot
.68726 .41479 Mdot
.52372 .34968 Mdot
.45743 .53391 Mdot
.46933 .68952 Mdot
.43282 .32421 Mdot
.52777 .3995 Mdot
.44802 .59299 Mdot
.43875 .58759 Mdot
.45957 .61812 Mdot
.46829 .73013 Mdot
.65304 .59821 Mdot
.6245 .59616 Mdot
.53436 .37922 Mdot
.4693 .32268 Mdot
.43236 .40375 Mdot
.70632 .63456 Mdot
.55181 .59433 Mdot
.35611 .46362 Mdot
.53026 .3225 Mdot
.63109 .6384 Mdot
.37664 .59636 Mdot
.43956 .24078 Mdot
.31176 .54955 Mdot
.64354 .66469 Mdot
.48108 .71354 Mdot
.7397 .43489 Mdot
.6737 .33024 Mdot
.33421 .50831 Mdot
.34651 .50198 Mdot
.66953 .63611 Mdot
.58157 .4515 Mdot
.8048 .72389 Mdot
.6555 .61803 Mdot
.55374 .55928 Mdot
.33422 .53421 Mdot
.50143 .41722 Mdot
.62096 .36596 Mdot
.5676 .45602 Mdot
.63741 .63785 Mdot
.47967 .38004 Mdot
.7359 .51607 Mdot
.66912 .64076 Mdot
.44736 .426 Mdot
.62905 .61324 Mdot
.49956 .73294 Mdot
.66313 .61818 Mdot
.30036 .51886 Mdot
.49087 .39139 Mdot
.76632 .76117 Mdot
.51464 .50644 Mdot
.47941 .37054 Mdot
.46427 .71154 Mdot
.57476 .66068 Mdot
.51029 .36466 Mdot
.75689 .46194 Mdot
.62724 .60836 Mdot
.57533 .72449 Mdot
.46111 .32235 Mdot
.65606 .64045 Mdot
.32642 .48961 Mdot
.67346 .66603 Mdot
.67592 .42325 Mdot
.44202 .58695 Mdot
.32724 .52742 Mdot
.45513 .75262 Mdot
.52117 .70745 Mdot
.44868 .38263 Mdot
.49448 .33417 Mdot
.32043 .52681 Mdot
.51463 .5461 Mdot
.53328 .41815 Mdot
.49309 .38719 Mdot
.67843 .6291 Mdot
.67741 .5923 Mdot
.46094 .479 Mdot
.66839 .6081 Mdot
.47186 .44134 Mdot
.32427 .52016 Mdot
.44475 .34918 Mdot
.34503 .51906 Mdot
.52803 .36033 Mdot
.54348 .72231 Mdot
.31955 .55519 Mdot
.40952 .36438 Mdot
.4905 .39444 Mdot
.38438 .49877 Mdot
.48878 .32914 Mdot
.51042 .38715 Mdot
.66323 .59105 Mdot
.7406 .46 Mdot
.4965 .42606 Mdot
.53546 .76731 Mdot
.72282 .43101 Mdot
.35985 .24797 Mdot
.68944 .6104 Mdot
.7067 .45713 Mdot
.65922 .29324 Mdot
.44672 .58758 Mdot
.7458 .46103 Mdot
.41134 .57581 Mdot
.47031 .71881 Mdot
.28746 .53558 Mdot
.47524 .38022 Mdot
.20731 .54287 Mdot
.5811 .57483 Mdot
.44114 .60301 Mdot
.51881 .3458 Mdot
.49471 .34744 Mdot
.31108 .50543 Mdot
.79621 .65541 Mdot
.65845 .58721 Mdot
.49103 .40947 Mdot
.33089 .50594 Mdot
.767 .68758 Mdot
.6433 .6422 Mdot
.71933 .47306 Mdot
.4921 .6788 Mdot
.36802 .57303 Mdot
.45338 .59607 Mdot
.47556 .69279 Mdot
.60107 .62186 Mdot
.70981 .36624 Mdot
.4506 .33797 Mdot
.68474 .61583 Mdot
.69748 .36586 Mdot
.51602 .42873 Mdot
.46572 .73623 Mdot
.50086 .78805 Mdot
.32078 .5501 Mdot
.46812 .72158 Mdot
.74679 .47166 Mdot
.35065 .57045 Mdot
.30824 .5337 Mdot
.48036 .69594 Mdot
.23339 .62733 Mdot
.6163 .35359 Mdot
.46 .69588 Mdot
.61483 .39385 Mdot
.69736 .36695 Mdot
.44967 .60547 Mdot
.71897 .45762 Mdot
.80668 .42975 Mdot
.34402 .53065 Mdot
.41371 .77126 Mdot
.69771 .36499 Mdot
.49775 .40397 Mdot
.74506 .44281 Mdot
.40582 .6208 Mdot
.45469 .66837 Mdot
.47887 .69247 Mdot
.72768 .61555 Mdot
.74548 .43883 Mdot
.52176 .38651 Mdot
.49866 .17654 Mdot
.46722 .35735 Mdot
.47202 .70353 Mdot
.54098 .54174 Mdot
.36031 .55865 Mdot
.50656 .73797 Mdot
.54314 .54336 Mdot
.45188 .34699 Mdot
.47699 .35346 Mdot
.78093 .42079 Mdot
.35049 .56621 Mdot
.45507 .60762 Mdot
.48527 .38301 Mdot
.50618 .34322 Mdot
.454 .3914 Mdot
.53918 .21505 Mdot
.45953 .26422 Mdot
.46569 .3986 Mdot
.63712 .64845 Mdot
.42358 .38921 Mdot
.49733 .40957 Mdot
.33994 .49106 Mdot
.71001 .40185 Mdot
.45719 .61017 Mdot
.51979 .3656 Mdot
.51655 .37798 Mdot
.50687 .68601 Mdot
.61688 .35369 Mdot
.56112 .46069 Mdot
.70447 .61832 Mdot
.68468 .5806 Mdot
.52067 .32288 Mdot
.32258 .53409 Mdot
.72942 .48596 Mdot
.50028 .43623 Mdot
.30389 .53363 Mdot
.52717 .33579 Mdot
.63466 .60272 Mdot
.44306 .59311 Mdot
.50577 .43881 Mdot
.74205 .44941 Mdot
.53503 .7218 Mdot
.37807 .24363 Mdot
.68603 .63227 Mdot
.45871 .36276 Mdot
.64047 .58605 Mdot
.64692 .62606 Mdot
.43794 .60314 Mdot
.41886 .34652 Mdot
.33289 .52439 Mdot
.36065 .5385 Mdot
.73891 .39004 Mdot
.62106 .62076 Mdot
.71344 .57571 Mdot
.48974 .73486 Mdot
.48869 .32477 Mdot
.44664 .63941 Mdot
.36101 .54493 Mdot
.63053 .33373 Mdot
.70862 .44555 Mdot
.4773 .69469 Mdot
.41505 .57361 Mdot
.31531 .5538 Mdot
.35889 .53938 Mdot
.49997 .3889 Mdot
.48961 .36248 Mdot
.60852 .58992 Mdot
.65861 .37105 Mdot
.51696 .7051 Mdot
.71394 .46378 Mdot
.70019 .63009 Mdot
.46238 .32508 Mdot
.32635 .55325 Mdot
.46992 .19128 Mdot
.49179 .32884 Mdot
.62868 .61005 Mdot
.33909 .55045 Mdot
.72562 .47675 Mdot
.74137 .47393 Mdot
.50578 .39498 Mdot
.41732 .22763 Mdot
.48433 .70037 Mdot
.33112 .51553 Mdot
.39053 .56806 Mdot
.47837 .32509 Mdot
.49407 .36402 Mdot
.53947 .31203 Mdot
.48667 .74309 Mdot
.53193 .40938 Mdot
.74118 .42726 Mdot
.35287 .53652 Mdot
.48335 .37802 Mdot
.74615 .45094 Mdot
.26238 .55192 Mdot
.43887 .5958 Mdot
.65279 .64358 Mdot
.75842 .45452 Mdot
.73269 .45605 Mdot
.71607 .43731 Mdot
.41822 .77225 Mdot
.28138 .54389 Mdot
.75617 .31668 Mdot
.4846 .38709 Mdot
.69741 .36739 Mdot
.45832 .40299 Mdot
.49727 .73769 Mdot
.67843 .64384 Mdot
.50483 .38198 Mdot
.48396 .38672 Mdot
.39312 .24332 Mdot
.44134 .38547 Mdot
.43708 .37524 Mdot
.36264 .55645 Mdot
.39587 .56356 Mdot
.69153 .63239 Mdot
.73967 .71239 Mdot
.35459 .19003 Mdot
.49081 .30779 Mdot
.58558 .44903 Mdot
.31319 .54879 Mdot
.50133 .68189 Mdot
.6179 .38653 Mdot
.45568 .64874 Mdot
.3508 .55204 Mdot
.4542 .33636 Mdot
.37555 .25249 Mdot
.73655 .43163 Mdot
.50587 .36856 Mdot
.49505 .71667 Mdot
.50628 .36984 Mdot
.4719 .73397 Mdot
.33742 .47053 Mdot
.54405 .47742 Mdot
.47656 .38472 Mdot
.47489 .30826 Mdot
.53641 .26952 Mdot
.49414 .36139 Mdot
.59837 .70729 Mdot
.33536 .54645 Mdot
.4096 .37897 Mdot
.4433 .36289 Mdot
.3664 .35584 Mdot
.50819 .33366 Mdot
.49756 .52609 Mdot
.48167 .3417 Mdot
.59729 .20753 Mdot
.51584 .39618 Mdot
.48121 .33885 Mdot
.50743 .69691 Mdot
.51752 .69559 Mdot
.35463 .4891 Mdot
.45022 .61098 Mdot
.38399 .62224 Mdot
.50915 .34016 Mdot
.69919 .60287 Mdot
.55356 .43496 Mdot
.73631 .45943 Mdot
.35255 .53868 Mdot
.48933 .89053 Mdot
.51655 .72661 Mdot
.61926 .6181 Mdot
.56344 .57323 Mdot
.63029 .64742 Mdot
.62032 .65476 Mdot
.39193 .5318 Mdot
.71808 .45506 Mdot
.52472 .3551 Mdot
.35937 .33548 Mdot
.40848 .74707 Mdot
.47606 .32534 Mdot
.70187 .59462 Mdot
.58472 .36203 Mdot
.73765 .38552 Mdot
.76196 .44761 Mdot
.725 .44633 Mdot
.50221 .69808 Mdot
.69358 .63725 Mdot
.52934 .31968 Mdot
.70669 .45843 Mdot
.68107 .64031 Mdot
.42034 .57458 Mdot
.76011 .40789 Mdot
.34103 .52721 Mdot
.30304 .4715 Mdot
.41041 .48639 Mdot
.51834 .72123 Mdot
.52901 .77638 Mdot
.29078 .51151 Mdot
.33004 .57041 Mdot
.44108 .60918 Mdot
.63116 .63543 Mdot
.28681 .53055 Mdot
.49326 .39176 Mdot
.43052 .40314 Mdot
.52291 .36138 Mdot
.73303 .48086 Mdot
.51349 .33843 Mdot
.66815 .64311 Mdot
.49958 .68798 Mdot
.64033 .61174 Mdot
.49204 .69022 Mdot
.3727 .20687 Mdot
.51018 .39661 Mdot
.49276 .36677 Mdot
.60014 .44047 Mdot
.35805 .54132 Mdot
.34746 .34363 Mdot
.62739 .61188 Mdot
.63498 .61118 Mdot
.44483 .35387 Mdot
.36525 .56704 Mdot
.75591 .49626 Mdot
.61981 .40438 Mdot
.48556 .33958 Mdot
.33406 .54705 Mdot
.44425 .35352 Mdot
.55984 .71093 Mdot
.50799 .49674 Mdot
.34607 .51288 Mdot
.64165 .19708 Mdot
.49544 .39886 Mdot
.42805 .31856 Mdot
.46006 .28936 Mdot
.53309 .22154 Mdot
.49093 .42523 Mdot
.30905 .51499 Mdot
.49605 .40931 Mdot
.32343 .54014 Mdot
.64718 .61973 Mdot
.51654 .73269 Mdot
.32678 .53896 Mdot
.46922 .36698 Mdot
.36128 .1882 Mdot
.50043 .68711 Mdot
.50268 .37417 Mdot
.50939 .71358 Mdot
.29452 .54826 Mdot
.35201 .56008 Mdot
.41406 .57653 Mdot
.55556 .56098 Mdot
.48319 .69516 Mdot
.4702 .32258 Mdot
.39198 .75608 Mdot
.44511 .34782 Mdot
.68859 .58214 Mdot
.46511 .30855 Mdot
.52049 .32474 Mdot
.59709 .17188 Mdot
.51107 .53947 Mdot
.6292 .81902 Mdot
.48678 .64379 Mdot
.38441 .75635 Mdot
.38274 .52977 Mdot
.76172 .44721 Mdot
.47319 .53883 Mdot
.4411 .58256 Mdot
.64291 .65138 Mdot
.5022 .38492 Mdot
.27143 .57912 Mdot
.45922 .70543 Mdot
.73763 .46684 Mdot
.4793 .38908 Mdot
.65489 .66002 Mdot
.43078 .49455 Mdot
.47859 .69145 Mdot
.34385 .52792 Mdot
.35577 .55168 Mdot
.77823 .38849 Mdot
.48172 .37417 Mdot
.48739 .36628 Mdot
.50049 .6855 Mdot
.53899 .32726 Mdot
.71472 .44215 Mdot
.54584 .63367 Mdot
.49708 .71782 Mdot
.51393 .4983 Mdot
.36003 .56474 Mdot
.49292 .34799 Mdot
.60469 .43614 Mdot
.34377 .74324 Mdot
.21881 .44494 Mdot
.73297 .44331 Mdot
.60043 .30042 Mdot
.30972 .51375 Mdot
.49966 .71372 Mdot
.66917 .3009 Mdot
.44062 .33261 Mdot
.49725 .34565 Mdot
.57268 .24917 Mdot
.61883 .40226 Mdot
.55916 .57085 Mdot
.54327 .31047 Mdot
.63116 .37543 Mdot
.44503 .35264 Mdot
.45227 .37279 Mdot
.52529 .32934 Mdot
.45945 .31182 Mdot
.32896 .54703 Mdot
.36951 .37585 Mdot
.66385 .63043 Mdot
.23741 .44014 Mdot
.69774 .5822 Mdot
.46318 .36326 Mdot
.45198 .34334 Mdot
.28569 .41899 Mdot
.59162 .40509 Mdot
.33899 .53962 Mdot
.39064 .55434 Mdot
.52253 .71102 Mdot
.43845 .3756 Mdot
.62348 .61548 Mdot
.46803 .28866 Mdot
.64483 .63225 Mdot
.33068 .54831 Mdot
.67194 .59795 Mdot
.49244 .67278 Mdot
.68411 .61497 Mdot
.63324 .64262 Mdot
.48292 .6844 Mdot
.34103 .56565 Mdot
.48667 .3337 Mdot
.47924 .6849 Mdot
.76491 .49053 Mdot
.73389 .48046 Mdot
.41217 .56757 Mdot
.49705 .41783 Mdot
.43352 .38026 Mdot
.53269 .78793 Mdot
.66933 .60077 Mdot
.55542 .45868 Mdot
.32176 .55593 Mdot
.73008 .48506 Mdot
.32529 .54548 Mdot
.7537 .35246 Mdot
.7361 .44741 Mdot
.41213 .57229 Mdot
.64294 .30246 Mdot
.46991 .74637 Mdot
.4774 .3 Mdot
.39391 .5661 Mdot
.64227 .62841 Mdot
.46578 .72288 Mdot
.40533 .62302 Mdot
.4854 .40723 Mdot
.45958 .59071 Mdot
.29959 .55669 Mdot
.44457 .58649 Mdot
.49614 .71433 Mdot
.41648 .52075 Mdot
.47911 .36594 Mdot
.47183 .74673 Mdot
.4745 .30677 Mdot
.34691 .45447 Mdot
.63482 .57836 Mdot
.32934 .59569 Mdot
.44966 .3442 Mdot
.64343 .64284 Mdot
.4474 .34806 Mdot
.25811 .48387 Mdot
.64667 .32929 Mdot
.52053 .32198 Mdot
.59784 .36931 Mdot
.54831 .77825 Mdot
.32502 .55228 Mdot
.49492 .43398 Mdot
.44571 .60503 Mdot
.45584 .36257 Mdot
.16799 .36704 Mdot
.7456 .45689 Mdot
.77361 .45123 Mdot
.47179 .37252 Mdot
.48892 .38353 Mdot
.40072 .24068 Mdot
.35412 .47509 Mdot
.4157 .57796 Mdot
.50265 .34781 Mdot
.54885 .23803 Mdot
.50671 .69849 Mdot
.45992 .31753 Mdot
.51845 .37992 Mdot
.66705 .56113 Mdot
.51029 .70521 Mdot
.685 .60848 Mdot
.44553 .58641 Mdot
.68833 .59828 Mdot
.70867 .43601 Mdot
.60484 .32239 Mdot
.61067 .30035 Mdot
.49274 .49093 Mdot
.75744 .45517 Mdot
.46242 .35497 Mdot
.34988 .59547 Mdot
.47459 .36553 Mdot
.72324 .45241 Mdot
.50369 .71852 Mdot
.33241 .54415 Mdot
.33054 .46552 Mdot
.43235 .59944 Mdot
.47153 .33421 Mdot
.75776 .46861 Mdot
.32855 .53313 Mdot
.31775 .74153 Mdot
.33785 .55678 Mdot
.49169 .6925 Mdot
.46256 .72911 Mdot
.73679 .45345 Mdot
.32516 .54644 Mdot
.68283 .5963 Mdot
.49222 .65019 Mdot
.49166 .2997 Mdot
.49407 .67227 Mdot
.29892 .50818 Mdot
.32048 .4991 Mdot
.36189 .52598 Mdot
.44483 .36491 Mdot
.59861 .4153 Mdot
.52267 .28572 Mdot
.50112 .68671 Mdot
.6548 .65757 Mdot
.66054 .36177 Mdot
.37639 .29759 Mdot
.5293 .49219 Mdot
.48209 .43169 Mdot
.51495 .34028 Mdot
.52222 .35887 Mdot
.4645 .39957 Mdot
.52584 .62538 Mdot
.51047 .39612 Mdot
.51595 .7098 Mdot
.6525 .6312 Mdot
.48833 .34056 Mdot
.44891 .6009 Mdot
.5523 .59162 Mdot
.71637 .48564 Mdot
.36016 .42579 Mdot
.4021 .56605 Mdot
.32928 .53502 Mdot
.67273 .60715 Mdot
.67409 .59715 Mdot
.71499 .47582 Mdot
.47332 .69302 Mdot
.34511 .55816 Mdot
.60125 .20937 Mdot
.72725 .43109 Mdot
.51953 .36426 Mdot
.60197 .43912 Mdot
.51309 .21691 Mdot
.51251 .32702 Mdot
.51171 .38003 Mdot
.45485 .61106 Mdot
.61916 .62549 Mdot
.18497 .47425 Mdot
.24193 .64447 Mdot
.74034 .45752 Mdot
.71118 .46274 Mdot
.35817 .51395 Mdot
.49262 .32363 Mdot
.48373 .70331 Mdot
.61592 .34576 Mdot
.54727 .75856 Mdot
.35869 .6218 Mdot
.56472 .73242 Mdot
.52243 .34634 Mdot
.33418 .42877 Mdot
.46917 .30425 Mdot
.30175 .56531 Mdot
.3662 .54363 Mdot
.33912 .53305 Mdot
.50368 .69464 Mdot
.71315 .36635 Mdot
.51617 .71616 Mdot
.39371 .59696 Mdot
.3172 .50951 Mdot
.52678 .54609 Mdot
.63328 .61137 Mdot
.451 .39814 Mdot
.71914 .45374 Mdot
.6747 .48283 Mdot
.49079 .43514 Mdot
.60225 .30747 Mdot
.68757 .61549 Mdot
.32349 .56077 Mdot
.45489 .3998 Mdot
.39149 .62565 Mdot
.57865 .45563 Mdot
.5624 .76834 Mdot
.28007 .58281 Mdot
.74614 .44784 Mdot
.23862 .40651 Mdot
.72046 .43673 Mdot
.47619 .696 Mdot
.49764 .3987 Mdot
.4957 .3262 Mdot
.51179 .38622 Mdot
.44467 .33415 Mdot
.50627 .70508 Mdot
.49759 .30211 Mdot
.68859 .39978 Mdot
.42325 .57802 Mdot
.53405 .59461 Mdot
.74353 .47036 Mdot
.49149 .73594 Mdot
.64906 .62809 Mdot
.43684 .60784 Mdot
.75134 .4792 Mdot
.46162 .40267 Mdot
.47059 .36533 Mdot
.42031 .57754 Mdot
.51636 .43154 Mdot
.44327 .40272 Mdot
.66265 .63597 Mdot
.55211 .57966 Mdot
.71078 .47772 Mdot
.73008 .43766 Mdot
.473 .72732 Mdot
.32482 .54554 Mdot
.71044 .47403 Mdot
.68967 .64521 Mdot
.4586 .32106 Mdot
.47918 .30689 Mdot
.30249 .50495 Mdot
.70165 .36569 Mdot
.71697 .48624 Mdot
.52989 .41208 Mdot
.35122 .5278 Mdot
.30037 .55766 Mdot
.50284 .34916 Mdot
.52845 .32545 Mdot
.36291 .51611 Mdot
.71552 .47381 Mdot
.47925 .73241 Mdot
.54392 .50695 Mdot
.51151 .72843 Mdot
.34099 .52034 Mdot
.42835 .40016 Mdot
.34711 .56749 Mdot
.4836 .40622 Mdot
.63898 .83271 Mdot
.51592 .39218 Mdot
.39954 .3359 Mdot
.64533 .52882 Mdot
.62796 .61537 Mdot
.62691 .62605 Mdot
.44529 .59469 Mdot
.30437 .53675 Mdot
.48625 .44016 Mdot
.71611 .45435 Mdot
.38494 .75614 Mdot
.31519 .48551 Mdot
.6334 .64185 Mdot
.62219 .61347 Mdot
.50519 .7164 Mdot
.51086 .3353 Mdot
.49021 .34759 Mdot
.684 .61345 Mdot
.57294 .6562 Mdot
.31697 .53923 Mdot
.48755 .36674 Mdot
.4582 .39291 Mdot
.66116 .63031 Mdot
.45531 .69054 Mdot
.28782 .51927 Mdot
.44559 .36791 Mdot
.64162 .33184 Mdot
.48759 .73936 Mdot
.45824 .35014 Mdot
.47283 .30001 Mdot
.7319 .46063 Mdot
.59331 .2829 Mdot
.69224 .3656 Mdot
.52568 .71132 Mdot
.44995 .59237 Mdot
.51528 .33114 Mdot
.62832 .61866 Mdot
.48745 .42015 Mdot
.22171 .69139 Mdot
.42902 .57744 Mdot
.48039 .36371 Mdot
.53924 .34441 Mdot
.34447 .51737 Mdot
.48554 .37467 Mdot
.54328 .72591 Mdot
.6778 .62261 Mdot
.47989 .36223 Mdot
.41574 .23118 Mdot
.50399 .71656 Mdot
.49266 .43386 Mdot
.74371 .43669 Mdot
.55224 .56213 Mdot
.33204 .22441 Mdot
.70387 .63839 Mdot
.74968 .46218 Mdot
.50855 .33537 Mdot
.7039 .61273 Mdot
.4946 .67885 Mdot
.4386 .27951 Mdot
.46177 .35087 Mdot
.51462 .72419 Mdot
.49567 .68744 Mdot
.74051 .45315 Mdot
.58077 .86294 Mdot
.52441 .32581 Mdot
.50188 .36582 Mdot
.45038 .83419 Mdot
.36167 .51156 Mdot
.50439 .37423 Mdot
.49963 .33285 Mdot
.46745 .71061 Mdot
.72518 .33405 Mdot
.60027 .30095 Mdot
.54236 .63383 Mdot
.47993 .73777 Mdot
.68483 .58899 Mdot
.6828 .6251 Mdot
.75074 .45777 Mdot
.33989 .55104 Mdot
.72764 .48387 Mdot
.66566 .62142 Mdot
.51242 .38272 Mdot
.47982 .72393 Mdot
.2667 .31176 Mdot
.46711 .69384 Mdot
.68392 .65228 Mdot
.2991 .56087 Mdot
.21602 .50739 Mdot
.24717 .7311 Mdot
.4174 .47503 Mdot
.48324 .74473 Mdot
.73613 .45967 Mdot
.2546 .67217 Mdot
.48767 .34002 Mdot
.29413 .46182 Mdot
.50455 .36755 Mdot
.26193 .56397 Mdot
.67879 .64311 Mdot
.4176 .57461 Mdot
.48498 .40738 Mdot
.59757 .29612 Mdot
.48289 .6857 Mdot
.48232 .71195 Mdot
.49496 .40917 Mdot
.48948 .69315 Mdot
.48609 .35241 Mdot
.6555 .62866 Mdot
.60949 .84087 Mdot
.47652 .3457 Mdot
.41573 .34059 Mdot
.48845 .74767 Mdot
.41225 .56224 Mdot
.65524 .58433 Mdot
.35837 .39196 Mdot
.36311 .62808 Mdot
.48548 .70289 Mdot
.36854 .42552 Mdot
.66544 .60257 Mdot
.44096 .61071 Mdot
.68206 .5909 Mdot
.50104 .35719 Mdot
.51985 .34127 Mdot
.4681 .40273 Mdot
.50387 .33464 Mdot
.27372 .46126 Mdot
.44839 .40781 Mdot
.28206 .34585 Mdot
.48434 .38653 Mdot
.39695 .35467 Mdot
.51469 .71589 Mdot
.43213 .31254 Mdot
.56307 .5151 Mdot
.52615 .37534 Mdot
.39073 .53816 Mdot
.49455 .73501 Mdot
.43306 .68624 Mdot
.50774 .70413 Mdot
.63837 .61314 Mdot
.48579 .68695 Mdot
.49229 .40207 Mdot
.34815 .53539 Mdot
.66604 .61099 Mdot
.41474 .46539 Mdot
.65733 .65589 Mdot
.47946 .37047 Mdot
.47238 .75114 Mdot
.64191 .60129 Mdot
.43265 .36775 Mdot
.3493 .53961 Mdot
.57637 .2352 Mdot
.32075 .57981 Mdot
.49126 .37791 Mdot
.49676 .3789 Mdot
.41785 .57815 Mdot
.48088 .68863 Mdot
.36253 .56568 Mdot
.66849 .5568 Mdot
.741 .48387 Mdot
.34126 .54406 Mdot
.45587 .28998 Mdot
.58777 .449 Mdot
.34519 .51454 Mdot
.53476 .22944 Mdot
.47244 .70108 Mdot
.32634 .50369 Mdot
.49823 .28701 Mdot
.24221 .43547 Mdot
.72806 .43571 Mdot
.67482 .59289 Mdot
.63175 .3915 Mdot
.68156 .62451 Mdot
.53573 .73234 Mdot
.62925 .60032 Mdot
.51262 .70587 Mdot
.57127 .41087 Mdot
.54184 .54292 Mdot
.46235 .70344 Mdot
.50388 .74624 Mdot
.6695 .63121 Mdot
.4846 .41267 Mdot
.53871 .58157 Mdot
.48394 .44196 Mdot
.43462 .41562 Mdot
.51223 .73027 Mdot
.31748 .50563 Mdot
.34453 .56978 Mdot
.41174 .40025 Mdot
.3591 .55182 Mdot
.65598 .61399 Mdot
.47747 .485 Mdot
.37142 .44126 Mdot
.49986 .72175 Mdot
.56519 .57967 Mdot
.44919 .34858 Mdot
.65983 .64221 Mdot
.65208 .61406 Mdot
.49674 .68874 Mdot
.23563 .46087 Mdot
.46051 .43681 Mdot
.3543 .49718 Mdot
.32731 .50638 Mdot
.34242 .51298 Mdot
.36705 .56076 Mdot
.71577 .36461 Mdot
.46603 .72317 Mdot
.30507 .529 Mdot
.44371 .33969 Mdot
.50151 .3278 Mdot
.43298 .58468 Mdot
.72338 .47732 Mdot
.44004 .33629 Mdot
.48742 .44001 Mdot
.50125 .34881 Mdot
.62916 .61272 Mdot
.57613 .31085 Mdot
.42465 .57952 Mdot
.62051 .62032 Mdot
.62215 .62042 Mdot
.44819 .59257 Mdot
.57686 .39862 Mdot
.19139 .4737 Mdot
.49533 .40702 Mdot
.39375 .53594 Mdot
.62964 .6288 Mdot
.65983 .46024 Mdot
.39494 .39837 Mdot
.47717 .31866 Mdot
.54681 .61738 Mdot
.65322 .62313 Mdot
.38096 .52857 Mdot
.49769 .35929 Mdot
.44094 .60817 Mdot
.73551 .43493 Mdot
.49048 .27033 Mdot
.45396 .61102 Mdot
.32139 .54751 Mdot
.72399 .59818 Mdot
.31073 .50542 Mdot
.6527 .59527 Mdot
.48851 .43682 Mdot
.7876 .74104 Mdot
.64127 .62564 Mdot
.39556 .76642 Mdot
.54242 .5451 Mdot
.47574 .35154 Mdot
.6769 .61356 Mdot
.32554 .48688 Mdot
.48855 .73982 Mdot
.60276 .42342 Mdot
.32777 .5534 Mdot
.43519 .60677 Mdot
.43495 .58708 Mdot
.66312 .63111 Mdot
.32573 .51054 Mdot
.48304 .29999 Mdot
.35448 .55147 Mdot
.48274 .72168 Mdot
.47277 .39334 Mdot
.38257 .62246 Mdot
.41831 .34844 Mdot
.35512 .54504 Mdot
.66798 .65746 Mdot
.72618 .42516 Mdot
.4675 .36842 Mdot
.42931 .66461 Mdot
.50743 .33402 Mdot
.50814 .71546 Mdot
.64502 .50572 Mdot
.26991 .31306 Mdot
.51606 .36158 Mdot
.45009 .34835 Mdot
.49271 .67446 Mdot
.51484 .36064 Mdot
.5036 .31741 Mdot
.41529 .51931 Mdot
.34668 .51652 Mdot
.4914 .34017 Mdot
.68305 .63351 Mdot
.32946 .2575 Mdot
.50129 .39415 Mdot
.54443 .72678 Mdot
.56669 .23841 Mdot
.62788 .48151 Mdot
.44445 .43499 Mdot
.63162 .33615 Mdot
.49839 .37498 Mdot
.47953 .3198 Mdot
.4951 .40788 Mdot
.33189 .43489 Mdot
.66918 .62513 Mdot
.64981 .64644 Mdot
.75055 .43636 Mdot
.56606 .24179 Mdot
.739 .44226 Mdot
.48212 .6773 Mdot
.56139 .57008 Mdot
.42174 .58358 Mdot
.32403 .54411 Mdot
.50371 .3913 Mdot
.66332 .65458 Mdot
.49365 .35024 Mdot
.45565 .3597 Mdot
.65858 .61704 Mdot
.64978 .61854 Mdot
.70221 .64404 Mdot
.73599 .43074 Mdot
.33518 .53767 Mdot
.49972 .40112 Mdot
.72353 .43063 Mdot
.45834 .39512 Mdot
.54653 .49348 Mdot
.33711 .53728 Mdot
.35599 .54576 Mdot
.31777 .5636 Mdot
.47058 .34848 Mdot
.48493 .40402 Mdot
.51614 .71687 Mdot
.30184 .50569 Mdot
.48038 .69882 Mdot
.67807 .61503 Mdot
.66616 .64076 Mdot
.50171 .35765 Mdot
.54162 .3378 Mdot
.73826 .47471 Mdot
.65654 .59969 Mdot
.45668 .59391 Mdot
.74852 .43654 Mdot
.52385 .36053 Mdot
.68085 .61985 Mdot
.74921 .47249 Mdot
.21733 .46324 Mdot
.30418 .62102 Mdot
.74594 .43101 Mdot
.49246 .41065 Mdot
.37884 .28289 Mdot
.65176 .33879 Mdot
.72316 .49009 Mdot
.50957 .7198 Mdot
.49296 .33202 Mdot
.53002 .64142 Mdot
.70582 .45445 Mdot
.68713 .36169 Mdot
.66326 .6158 Mdot
.41958 .38403 Mdot
.52327 .27368 Mdot
.3766 .44638 Mdot
.71977 .42762 Mdot
.35413 .54187 Mdot
.34427 .50681 Mdot
.51864 .36426 Mdot
.55724 .56591 Mdot
.47473 .68088 Mdot
.67521 .59729 Mdot
.65394 .64966 Mdot
.35065 .51435 Mdot
.49741 .49305 Mdot
.6839 .63103 Mdot
.48827 .32363 Mdot
.7005 .44917 Mdot
.43724 .37007 Mdot
.75594 .37854 Mdot
.31406 .25349 Mdot
.4358 .42652 Mdot
.73106 .42483 Mdot
.49244 .68079 Mdot
.50426 .69214 Mdot
.49805 .693 Mdot
.67071 .63771 Mdot
.62024 .3857 Mdot
.66473 .65047 Mdot
.40676 .80914 Mdot
.74728 .45449 Mdot
.62276 .2269 Mdot
.45046 .31873 Mdot
.47535 .35403 Mdot
.45483 .32939 Mdot
.46252 .39504 Mdot
.49729 .37375 Mdot
.51891 .71826 Mdot
.69667 .60538 Mdot
.55464 .74759 Mdot
.31975 .52071 Mdot
.31128 .73713 Mdot
.63446 .6099 Mdot
.45655 .60988 Mdot
.72751 .47266 Mdot
.59002 .26492 Mdot
.71699 .42069 Mdot
.6587 .5977 Mdot
.52441 .33491 Mdot
.35533 .50914 Mdot
.59264 .20485 Mdot
.49281 .38728 Mdot
.66377 .59944 Mdot
.69965 .5965 Mdot
.23161 .44902 Mdot
.552 .3323 Mdot
.57916 .63625 Mdot
.58738 .44463 Mdot
.75067 .431 Mdot
.50635 .41907 Mdot
.61441 .33069 Mdot
.66529 .62334 Mdot
.63804 .63197 Mdot
.73097 .48907 Mdot
.26464 .5059 Mdot
.3082 .52321 Mdot
.41821 .56932 Mdot
.50332 .72838 Mdot
.47197 .36131 Mdot
.67539 .6317 Mdot
.37135 .5807 Mdot
.5819 .47347 Mdot
.50177 .7036 Mdot
.62229 .61442 Mdot
.50478 .33242 Mdot
.5165 .3576 Mdot
.74106 .44501 Mdot
.61921 .5491 Mdot
.48371 .44195 Mdot
.38714 .75787 Mdot
.53829 .47595 Mdot
.5442 .54626 Mdot
.49685 .34546 Mdot
.35807 .56378 Mdot
.44762 .59324 Mdot
.71929 .45961 Mdot
.47922 .41679 Mdot
.21427 .52926 Mdot
.30045 .52939 Mdot
.48232 .6977 Mdot
.4531 .60067 Mdot
.60487 .33224 Mdot
.50532 .33356 Mdot
.50431 .36693 Mdot
.4444 .36325 Mdot
.20076 .50475 Mdot
.67259 .64543 Mdot
.3648 .55981 Mdot
.74625 .44153 Mdot
.34937 .56 Mdot
.63264 .60129 Mdot
.56242 .58093 Mdot
.50623 .40157 Mdot
.30384 .54797 Mdot
.34903 .55567 Mdot
.50301 .71797 Mdot
.47941 .68438 Mdot
.70335 .63297 Mdot
.49713 .33475 Mdot
.42121 .58506 Mdot
.30929 .51624 Mdot
.68704 .60187 Mdot
.73985 .44546 Mdot
.53988 .72536 Mdot
.48185 .38436 Mdot
.6653 .62895 Mdot
.49157 .43724 Mdot
.32569 .52267 Mdot
.64537 .60232 Mdot
.44681 .61338 Mdot
.71736 .47431 Mdot
.51766 .33649 Mdot
.56619 .74883 Mdot
.4462 .60946 Mdot
.46738 .35961 Mdot
.30154 .26786 Mdot
.55694 .56625 Mdot
.27029 .53794 Mdot
.68724 .63567 Mdot
.43137 .60092 Mdot
.36579 .54759 Mdot
.24948 .41662 Mdot
.64335 .63593 Mdot
.38186 .25219 Mdot
.53182 .53332 Mdot
.49084 .40913 Mdot
.32435 .5507 Mdot
.77066 .41537 Mdot
.36345 .73708 Mdot
.65491 .34905 Mdot
.48348 .36024 Mdot
.6815 .62528 Mdot
.73428 .43581 Mdot
.48109 .71076 Mdot
.53387 .68745 Mdot
.7766 .37608 Mdot
.62583 .63541 Mdot
.50481 .39132 Mdot
.31917 .50517 Mdot
.485 .69502 Mdot
.38171 .24222 Mdot
.69356 .63841 Mdot
.68714 .62826 Mdot
.46759 .31558 Mdot
.73744 .44087 Mdot
.50933 .63502 Mdot
.66382 .6465 Mdot
.69861 .60562 Mdot
.41418 .50884 Mdot
.75454 .43748 Mdot
.44784 .37182 Mdot
.41157 .39991 Mdot
.46129 .31212 Mdot
.3642 .77284 Mdot
.42877 .59819 Mdot
.31796 .52316 Mdot
.50484 .37986 Mdot
.54383 .78417 Mdot
.64747 .63327 Mdot
.58552 .44546 Mdot
.45359 .69866 Mdot
.47831 .68576 Mdot
.67618 .62167 Mdot
.49181 .35603 Mdot
.47998 .66984 Mdot
.748 .46159 Mdot
.44783 .37346 Mdot
.4835 .40533 Mdot
.30668 .49908 Mdot
.48246 .72449 Mdot
.32809 .25567 Mdot
.47814 .71202 Mdot
.46782 .71951 Mdot
.28833 .54355 Mdot
.51896 .36366 Mdot
.64513 .60446 Mdot
.64815 .66019 Mdot
.53072 .40768 Mdot
.66844 .47804 Mdot
.30738 .53502 Mdot
.60145 .62862 Mdot
.21062 .53069 Mdot
.4895 .30838 Mdot
.45471 .59297 Mdot
.30001 .58957 Mdot
.46095 .72461 Mdot
.51441 .37137 Mdot
.32239 .5389 Mdot
.70124 .61968 Mdot
.68002 .63137 Mdot
.43966 .33545 Mdot
.50085 .68887 Mdot
.74387 .47705 Mdot
.65269 .6117 Mdot
.53703 .50994 Mdot
.48057 .36742 Mdot
.45333 .65232 Mdot
.65305 .60978 Mdot
.36942 .18863 Mdot
.53793 .788 Mdot
.3424 .51122 Mdot
.4612 .33012 Mdot
.33947 .50071 Mdot
.75449 .45053 Mdot
.65222 .58943 Mdot
.51538 .70386 Mdot
.54997 .40376 Mdot
.72271 .72282 Mdot
.66996 .63559 Mdot
.33072 .54707 Mdot
.50819 .38527 Mdot
.37254 .42172 Mdot
.4827 .34119 Mdot
.72332 .32764 Mdot
.71701 .48747 Mdot
.52753 .74126 Mdot
.50167 .68648 Mdot
.4519 .34619 Mdot
.71639 .43808 Mdot
.66083 .66208 Mdot
.65937 .6178 Mdot
.69796 .7697 Mdot
.45248 .61203 Mdot
.61545 .65293 Mdot
.47005 .35145 Mdot
.68509 .6034 Mdot
.37646 .29871 Mdot
.49303 .68594 Mdot
.46947 .30864 Mdot
.62188 .63926 Mdot
.3246 .73053 Mdot
.58949 .44556 Mdot
.48141 .36439 Mdot
.53745 .32634 Mdot
.51038 .71057 Mdot
.25359 .67044 Mdot
.68623 .6394 Mdot
.46389 .40303 Mdot
.46271 .68471 Mdot
.5438 .44306 Mdot
.65351 .55581 Mdot
.33537 .5372 Mdot
.61619 .63411 Mdot
.48118 .73188 Mdot
.41782 .37792 Mdot
.73084 .47864 Mdot
.6961 .63926 Mdot
.63997 .65135 Mdot
.46681 .38246 Mdot
.44768 .38373 Mdot
.53011 .31112 Mdot
.31463 .54501 Mdot
.46837 .71447 Mdot
.45381 .36765 Mdot
.54909 .48562 Mdot
.46001 .39022 Mdot
.47166 .72271 Mdot
.68074 .83668 Mdot
.52458 .33753 Mdot
.47791 .37846 Mdot
.36346 .41377 Mdot
.36142 .56696 Mdot
.35151 .52292 Mdot
.53727 .48351 Mdot
.48021 .33424 Mdot
.52235 .54373 Mdot
.33305 .53932 Mdot
.33275 .5516 Mdot
.52369 .54444 Mdot
.47475 .39263 Mdot
.44772 .57838 Mdot
.48623 .69401 Mdot
.47811 .6856 Mdot
.34481 .51809 Mdot
.43827 .36851 Mdot
.49468 .6793 Mdot
.27378 .44854 Mdot
.64987 .59899 Mdot
.61149 .3264 Mdot
.35296 .55453 Mdot
.60826 .4354 Mdot
.47465 .69729 Mdot
.40687 .19704 Mdot
.52571 .21833 Mdot
.50264 .31052 Mdot
.51755 .36473 Mdot
.73113 .45685 Mdot
.53058 .42447 Mdot
.44683 .58965 Mdot
.49585 .69133 Mdot
.52617 .62432 Mdot
.33962 .53274 Mdot
.48216 .33484 Mdot
.65987 .36635 Mdot
.33471 .22607 Mdot
.40778 .3484 Mdot
.33882 .552 Mdot
.34417 .53353 Mdot
.68985 .62172 Mdot
.65968 .59653 Mdot
.50601 .40086 Mdot
.50949 .69829 Mdot
.33312 .50433 Mdot
.474 .72136 Mdot
.66472 .6218 Mdot
.63858 .60809 Mdot
.43011 .5798 Mdot
.44662 .42986 Mdot
.67185 .61931 Mdot
.54547 .73669 Mdot
.54854 .48686 Mdot
.29588 .51179 Mdot
.43565 .82687 Mdot
.4295 .19186 Mdot
.34431 .46057 Mdot
.73443 .43512 Mdot
.56666 .41955 Mdot
.52073 .69959 Mdot
.45097 .34956 Mdot
.50803 .36391 Mdot
.4316 .59401 Mdot
.51754 .69308 Mdot
.7317 .46851 Mdot
.48563 .68488 Mdot
.71678 .46278 Mdot
.64537 .64499 Mdot
.49957 .39277 Mdot
.52336 .37993 Mdot
.48387 .71236 Mdot
.68367 .60796 Mdot
.64104 .60175 Mdot
.7207 .44059 Mdot
.58382 .25599 Mdot
.66286 .62933 Mdot
.35229 .55561 Mdot
.34023 .27169 Mdot
.43354 .58757 Mdot
.49715 .35979 Mdot
.6303 .33118 Mdot
.25892 .39781 Mdot
.47474 .40757 Mdot
.45211 .60514 Mdot
.58764 .86216 Mdot
.49917 .39528 Mdot
.7702 .6844 Mdot
.42314 .58284 Mdot
.34857 .56774 Mdot
.66206 .60384 Mdot
.45263 .61032 Mdot
.56613 .29728 Mdot
.60795 .59655 Mdot
.51849 .41911 Mdot
.30704 .52568 Mdot
.31619 .55963 Mdot
.5574 .58037 Mdot
.36166 .77193 Mdot
.74567 .44058 Mdot
.74079 .46624 Mdot
.648 .63753 Mdot
.54256 .69865 Mdot
.43798 .35763 Mdot
.74043 .46433 Mdot
.45709 .57669 Mdot
.45025 .34435 Mdot
.55646 .56777 Mdot
.53569 .58753 Mdot
.36217 .54485 Mdot
.43426 .31187 Mdot
.64738 .63554 Mdot
.33202 .54653 Mdot
.5445 .57907 Mdot
.46261 .31642 Mdot
.33827 .53564 Mdot
.46899 .70199 Mdot
.49217 .54728 Mdot
.35673 .55281 Mdot
.60016 .43028 Mdot
.48545 .70763 Mdot
.56087 .57313 Mdot
.66538 .2754 Mdot
.24428 .26101 Mdot
.50346 .69274 Mdot
.66833 .60158 Mdot
.67399 .63137 Mdot
.65894 .63031 Mdot
.32114 .5516 Mdot
.6458 .6214 Mdot
.31403 .52135 Mdot
.51791 .73784 Mdot
.58374 .26643 Mdot
.73601 .45072 Mdot
.74373 .40362 Mdot
.34782 .52824 Mdot
.3934 .79968 Mdot
.373 .82804 Mdot
.45597 .38694 Mdot
.46208 .70757 Mdot
.73017 .42777 Mdot
.52576 .47819 Mdot
.73109 .45987 Mdot
.66669 .60298 Mdot
.60244 .31263 Mdot
.48604 .35118 Mdot
.36631 .61007 Mdot
.73438 .43643 Mdot
.33351 .55331 Mdot
.46252 .36029 Mdot
.61441 .63903 Mdot
.75228 .45659 Mdot
.72556 .43926 Mdot
.49742 .37156 Mdot
.32828 .56308 Mdot
.64963 .60092 Mdot
.52406 .70934 Mdot
.69711 .44423 Mdot
.54969 .35448 Mdot
.5094 .39323 Mdot
.53074 .34563 Mdot
.57464 .45392 Mdot
.53772 .67883 Mdot
.48736 .70652 Mdot
.68365 .36417 Mdot
.66202 .64223 Mdot
.6569 .34792 Mdot
.38373 .74096 Mdot
.77605 .42514 Mdot
.42793 .59634 Mdot
.4273 .59652 Mdot
.48656 .37151 Mdot
.26272 .7379 Mdot
.40967 .31942 Mdot
.45234 .71971 Mdot
.43436 .59179 Mdot
.64618 .5984 Mdot
.30814 .50328 Mdot
.5291 .28098 Mdot
.44408 .32842 Mdot
.52467 .70588 Mdot
.66029 .62317 Mdot
.21761 .68662 Mdot
.74643 .45257 Mdot
.52101 .48324 Mdot
.49992 .335 Mdot
.48982 .36661 Mdot
.49826 .70827 Mdot
.51574 .70724 Mdot
.41298 .50471 Mdot
.62737 .46725 Mdot
.36472 .62437 Mdot
.52621 .69507 Mdot
.2164 .68583 Mdot
.27502 .58108 Mdot
.33696 .51768 Mdot
.44955 .5891 Mdot
.48066 .67991 Mdot
.50461 .37655 Mdot
.34978 .56841 Mdot
.42355 .29819 Mdot
.38375 .54786 Mdot
.5528 .56201 Mdot
.54317 .507 Mdot
.51467 .34038 Mdot
.36634 .53512 Mdot
.33502 .54414 Mdot
.36267 .57462 Mdot
.44289 .58963 Mdot
.50013 .34576 Mdot
.4709 .40767 Mdot
.49798 .39761 Mdot
.40061 .4455 Mdot
.48513 .37468 Mdot
.37934 .73997 Mdot
.53266 .49514 Mdot
.76309 .5293 Mdot
.4914 .39097 Mdot
.4666 .70657 Mdot
.50055 .39007 Mdot
.71177 .44635 Mdot
.52014 .33662 Mdot
.55066 .55768 Mdot
.49114 .6976 Mdot
.24767 .49283 Mdot
.7016 .58891 Mdot
.52115 .38161 Mdot
.75735 .45764 Mdot
.4671 .81817 Mdot
.67625 .3669 Mdot
.41566 .51194 Mdot
.35429 .55158 Mdot
.70197 .60725 Mdot
.46397 .68979 Mdot
.6373 .61268 Mdot
.48911 .29977 Mdot
.43995 .58083 Mdot
.59969 .17776 Mdot
.61621 .43535 Mdot
.50423 .37888 Mdot
.45622 .43436 Mdot
.36143 .5504 Mdot
.64555 .63059 Mdot
.33699 .47022 Mdot
.45138 .33689 Mdot
.71979 .48101 Mdot
.71287 .43775 Mdot
.65739 .68153 Mdot
.47134 .54716 Mdot
.39058 .31631 Mdot
.49614 .70728 Mdot
.67445 .63669 Mdot
.71352 .43296 Mdot
.39358 .56971 Mdot
.47076 .68502 Mdot
.46075 .72454 Mdot
.48374 .72555 Mdot
.47692 .36693 Mdot
.43084 .58202 Mdot
.47931 .5759 Mdot
.44574 .61098 Mdot
.45113 .32647 Mdot
.6378 .65013 Mdot
.44163 .61074 Mdot
.73121 .44855 Mdot
.47469 .73012 Mdot
.63101 .61189 Mdot
.49457 .38004 Mdot
.33082 .53431 Mdot
.72614 .38744 Mdot
.55204 .78802 Mdot
.55836 .56723 Mdot
.55844 .56732 Mdot
.30263 .55472 Mdot
.41197 .60499 Mdot
.53743 .71922 Mdot
.23489 .44193 Mdot
.74607 .50116 Mdot
.51478 .42735 Mdot
.73003 .58945 Mdot
.668 .65004 Mdot
.66397 .61069 Mdot
.48171 .35107 Mdot
.69306 .61194 Mdot
.48458 .33628 Mdot
.68913 .63415 Mdot
.35976 .74757 Mdot
.4617 .30514 Mdot
.65795 .61299 Mdot
.55667 .34312 Mdot
.46766 .368 Mdot
.35725 .56252 Mdot
.69828 .63108 Mdot
.50179 .31026 Mdot
.69635 .21043 Mdot
.4994 .71861 Mdot
.44151 .58881 Mdot
.55205 .53546 Mdot
.4807 .6913 Mdot
.31512 .51515 Mdot
.48979 .32803 Mdot
.74906 .45304 Mdot
.34086 .52099 Mdot
.60929 .60711 Mdot
.73316 .43857 Mdot
.47698 .48637 Mdot
.34225 .51791 Mdot
.43018 .58758 Mdot
.71429 .47152 Mdot
.5195 .41806 Mdot
.66316 .61237 Mdot
.54256 .79053 Mdot
.45387 .60707 Mdot
.4892 .34925 Mdot
.6137 .62717 Mdot
.48382 .68613 Mdot
.52072 .37429 Mdot
.67688 .63182 Mdot
.4513 .59564 Mdot
.47372 .3771 Mdot
.46929 .34636 Mdot
.27803 .49201 Mdot
.65173 .51649 Mdot
.73405 .44946 Mdot
.29727 .55699 Mdot
.44574 .33325 Mdot
.71889 .43649 Mdot
.57156 .7132 Mdot
.48054 .29363 Mdot
.30423 .52373 Mdot
.25789 .45292 Mdot
.67886 .59956 Mdot
.49733 .68529 Mdot
.68029 .65435 Mdot
.75337 .44014 Mdot
.43574 .86232 Mdot
.44476 .58644 Mdot
.536 .36195 Mdot
.4998 .31449 Mdot
.66821 .58797 Mdot
.33759 .54344 Mdot
.36307 .62288 Mdot
.51465 .33269 Mdot
.4294 .3979 Mdot
.49779 .36551 Mdot
.57502 .72536 Mdot
.31759 .54863 Mdot
.49808 .36234 Mdot
.54416 .38932 Mdot
.48245 .30765 Mdot
.7487 .47034 Mdot
.61936 .22177 Mdot
.48143 .40868 Mdot
.84582 .67895 Mdot
.43132 .57575 Mdot
.65641 .61997 Mdot
.59496 .43475 Mdot
.5626 .53771 Mdot
.81708 .4245 Mdot
.30988 .52446 Mdot
.3945 .55037 Mdot
.64125 .60727 Mdot
.77886 .40333 Mdot
.42042 .6106 Mdot
.46551 .35053 Mdot
.49793 .33145 Mdot
.66658 .60296 Mdot
.68554 .60009 Mdot
.43802 .57812 Mdot
.50474 .40879 Mdot
.42141 .33945 Mdot
.66322 .6578 Mdot
.48922 .38388 Mdot
.2625 .37435 Mdot
.47608 .7394 Mdot
.34651 .51851 Mdot
.4819 .71294 Mdot
.48293 .74019 Mdot
.33234 .4656 Mdot
.54364 .47167 Mdot
.5086 .72702 Mdot
.46205 .73628 Mdot
.76373 .40925 Mdot
.37216 .43871 Mdot
.74626 .47284 Mdot
.44962 .51492 Mdot
.65758 .63652 Mdot
.50204 .34675 Mdot
.31992 .55219 Mdot
.75173 .31716 Mdot
.36737 .64477 Mdot
.54478 .26102 Mdot
.4474 .36904 Mdot
.6513 .63394 Mdot
.45408 .60342 Mdot
.47868 .29324 Mdot
.6532 .34172 Mdot
.48557 .36393 Mdot
.66891 .59569 Mdot
.37222 .44183 Mdot
.50473 .78601 Mdot
.53009 .70066 Mdot
.33651 .48848 Mdot
.50211 .39033 Mdot
.31638 .53524 Mdot
.50407 .73329 Mdot
.7291 .43153 Mdot
.73741 .45901 Mdot
.52306 .37813 Mdot
.54167 .54473 Mdot
.80039 .44952 Mdot
.46475 .35445 Mdot
.46951 .38709 Mdot
.42976 .59806 Mdot
.47015 .38856 Mdot
.4822 .41562 Mdot
.45215 .3667 Mdot
.4548 .39168 Mdot
.47529 .682 Mdot
.35948 .46405 Mdot
.51435 .40319 Mdot
.53144 .33382 Mdot
.51445 .73437 Mdot
.51134 .30721 Mdot
.50718 .70168 Mdot
.3847 .63518 Mdot
.50746 .72571 Mdot
.73755 .45723 Mdot
.61261 .63014 Mdot
.38418 .49809 Mdot
.33295 .50458 Mdot
.46781 .69708 Mdot
.71923 .47247 Mdot
.49993 .6921 Mdot
.6746 .6403 Mdot
.53246 .77985 Mdot
.27771 .53219 Mdot
.52654 .50889 Mdot
.36141 .42791 Mdot
.44337 .68212 Mdot
.69105 .61365 Mdot
.3403 .51013 Mdot
.54318 .72385 Mdot
.45224 .34788 Mdot
.74771 .44676 Mdot
.48715 .37121 Mdot
.47126 .72693 Mdot
.65458 .63481 Mdot
.41441 .54349 Mdot
.73325 .45036 Mdot
.47433 .84647 Mdot
.6652 .65468 Mdot
.51216 .32316 Mdot
.51555 .73277 Mdot
.54898 .7438 Mdot
.51206 .71183 Mdot
.58487 .26624 Mdot
.34585 .59682 Mdot
.76111 .33852 Mdot
.34469 .52967 Mdot
.46143 .61289 Mdot
.20524 .33991 Mdot
.41706 .71088 Mdot
.32776 .52689 Mdot
.7225 .61018 Mdot
.48231 .37536 Mdot
.45327 .37851 Mdot
.44511 .42646 Mdot
.3759 .56299 Mdot
.44428 .36259 Mdot
.43986 .58545 Mdot
.548 .47283 Mdot
.48038 .60691 Mdot
.70585 .61577 Mdot
.4853 .33757 Mdot
.513 .7296 Mdot
.46566 .70033 Mdot
.43367 .60635 Mdot
.47829 .71709 Mdot
.48082 .39191 Mdot
.34681 .52816 Mdot
.53969 .58106 Mdot
.75383 .44947 Mdot
.40545 .76345 Mdot
.77684 .48197 Mdot
.71656 .41906 Mdot
.48522 .30722 Mdot
.64048 .60634 Mdot
.73199 .70756 Mdot
.44819 .35534 Mdot
.33198 .54198 Mdot
.49951 .3152 Mdot
.4542 .37531 Mdot
.49565 .40386 Mdot
.67349 .63685 Mdot
.59446 .44371 Mdot
.49019 .3851 Mdot
.50658 .72948 Mdot
.52545 .54319 Mdot
.44127 .3348 Mdot
.54722 .63159 Mdot
.55083 .55894 Mdot
.45148 .65701 Mdot
.30054 .50439 Mdot
.64975 .60398 Mdot
.34077 .53119 Mdot
.37278 .53355 Mdot
.31568 .51481 Mdot
.48345 .58946 Mdot
.2409 .43383 Mdot
.78298 .67248 Mdot
.37792 .30326 Mdot
.35657 .42939 Mdot
.33948 .4911 Mdot
.62765 .70856 Mdot
.32443 .53029 Mdot
.31302 .51797 Mdot
.65626 .83191 Mdot
.31155 .54993 Mdot
.50146 .3564 Mdot
.53017 .36089 Mdot
.2154 .50472 Mdot
.71151 .41739 Mdot
.46925 .35744 Mdot
.46132 .39723 Mdot
.71269 .43576 Mdot
.29957 .48143 Mdot
.44939 .58538 Mdot
.51544 .48709 Mdot
.45849 .61161 Mdot
.49697 .37221 Mdot
.52118 .35207 Mdot
.47529 .41963 Mdot
.27722 .25704 Mdot
.77476 .35632 Mdot
.31888 .56297 Mdot
.52231 .42137 Mdot
.44296 .72913 Mdot
.48662 .31853 Mdot
.49063 .31272 Mdot
.49162 .40334 Mdot
.64486 .60451 Mdot
.30075 .51502 Mdot
.48627 .44084 Mdot
.41983 .75189 Mdot
.5087 .3366 Mdot
.78988 .46437 Mdot
.76532 .44503 Mdot
.49274 .35533 Mdot
.30929 .54932 Mdot
.45131 .37631 Mdot
.33226 .50054 Mdot
.33962 .51521 Mdot
.42225 .37543 Mdot
.47303 .56589 Mdot
.30912 .50333 Mdot
.46635 .34869 Mdot
.68556 .60863 Mdot
.39017 .76115 Mdot
.48977 .35034 Mdot
.73119 .44402 Mdot
.51445 .37468 Mdot
.75303 .4658 Mdot
.47248 .39706 Mdot
.44108 .60962 Mdot
.26153 .32216 Mdot
.63904 .6341 Mdot
.70907 .42523 Mdot
.68976 .60829 Mdot
.43685 .38222 Mdot
.32924 .49444 Mdot
.48203 .77889 Mdot
.78385 .37485 Mdot
.42893 .59653 Mdot
.70219 .36855 Mdot
.51667 .55398 Mdot
.51997 .70918 Mdot
.36678 .55877 Mdot
.36504 .45177 Mdot
.54647 .62757 Mdot
.70595 .60975 Mdot
.62546 .61013 Mdot
.67485 .55211 Mdot
.6099 .84081 Mdot
.48639 .385 Mdot
.537 .64418 Mdot
.28271 .33771 Mdot
.52441 .42814 Mdot
.54345 .30984 Mdot
.64354 .65335 Mdot
.46897 .35758 Mdot
.63325 .41094 Mdot
.66986 .63018 Mdot
.73705 .47274 Mdot
.31693 .52511 Mdot
.71382 .44955 Mdot
.30926 .63841 Mdot
.41424 .5159 Mdot
.67123 .62307 Mdot
.45099 .38575 Mdot
.47339 .35206 Mdot
.36385 .5658 Mdot
.38586 .24166 Mdot
.34709 .51716 Mdot
.75109 .44294 Mdot
.64725 .64078 Mdot
.64944 .2004 Mdot
.51131 .38292 Mdot
.34647 .55615 Mdot
.70275 .58971 Mdot
.5156 .35547 Mdot
.49753 .68655 Mdot
.44439 .35887 Mdot
.34546 .559 Mdot
.47005 .38891 Mdot
.34396 .52644 Mdot
.68733 .6181 Mdot
.52504 .37528 Mdot
.52338 .36204 Mdot
.6889 .36439 Mdot
.73065 .46775 Mdot
.31802 .49964 Mdot
.63235 .40632 Mdot
.46117 .3122 Mdot
.64352 .33314 Mdot
.49952 .3934 Mdot
.37001 .42929 Mdot
.49808 .29112 Mdot
.43706 .58441 Mdot
.49609 .31339 Mdot
.48876 .35151 Mdot
.39957 .24072 Mdot
.37654 .29378 Mdot
.40379 .45642 Mdot
.4795 .6839 Mdot
.33223 .55961 Mdot
.67499 .62841 Mdot
.70267 .61803 Mdot
.64358 .61712 Mdot
.72512 .49387 Mdot
.53569 .40183 Mdot
.4893 .34569 Mdot
.45755 .7378 Mdot
.74332 .46036 Mdot
.34371 .55246 Mdot
.74011 .45284 Mdot
.54628 .46784 Mdot
.72763 .44565 Mdot
.4478 .5898 Mdot
.53913 .7846 Mdot
.26231 .38697 Mdot
.72124 .45946 Mdot
.34503 .5162 Mdot
.5182 .53548 Mdot
.5072 .43308 Mdot
.33405 .7531 Mdot
.71779 .48022 Mdot
.68411 .5614 Mdot
.48069 .38649 Mdot
.60638 .4184 Mdot
.50605 .70379 Mdot
.71343 .45132 Mdot
.48597 .7254 Mdot
.4506 .37443 Mdot
.28003 .4978 Mdot
.32693 .54641 Mdot
.48179 .74141 Mdot
.4753 .30919 Mdot
.71327 .4509 Mdot
.66924 .61841 Mdot
.37384 .44083 Mdot
.50073 .74274 Mdot
.72438 .39003 Mdot
.65601 .34938 Mdot
.6526 .64154 Mdot
.37307 .38462 Mdot
.49997 .72668 Mdot
.51879 .42361 Mdot
.44807 .27898 Mdot
.44567 .34343 Mdot
.63861 .60298 Mdot
.66357 .6099 Mdot
.43945 .68031 Mdot
.52331 .35563 Mdot
.51966 .39794 Mdot
.29171 .52957 Mdot
.65216 .64308 Mdot
.31722 .51273 Mdot
.36223 .53178 Mdot
.67065 .60296 Mdot
.34529 .51191 Mdot
.73114 .43779 Mdot
.61521 .36748 Mdot
.5014 .72687 Mdot
.50352 .68862 Mdot
.6725 .62123 Mdot
.63375 .63815 Mdot
.63872 .60723 Mdot
.45933 .32527 Mdot
.33146 .5084 Mdot
.46099 .33236 Mdot
.50433 .38905 Mdot
.38954 .57731 Mdot
.28689 .5324 Mdot
.47564 .31562 Mdot
.53274 .5901 Mdot
.72264 .48525 Mdot
.65491 .61519 Mdot
.47036 .71531 Mdot
.73969 .38543 Mdot
.521 .71783 Mdot
.4607 .311 Mdot
.33059 .7376 Mdot
.32382 .55243 Mdot
.7309 .45859 Mdot
.55389 .56022 Mdot
.73185 .45313 Mdot
.47813 .74028 Mdot
.30155 .55723 Mdot
.48672 .48951 Mdot
.52446 .35898 Mdot
.57095 .45631 Mdot
.67255 .30323 Mdot
.39025 .74061 Mdot
.46795 .70972 Mdot
.45271 .38118 Mdot
.42448 .58786 Mdot
.23059 .44456 Mdot
.48654 .34718 Mdot
.4774 .30341 Mdot
.57433 .55297 Mdot
.50104 .31374 Mdot
.32432 .56884 Mdot
.55123 .5669 Mdot
.4898 .41583 Mdot
.43999 .38826 Mdot
.664 .80336 Mdot
.47044 .37016 Mdot
.52403 .36884 Mdot
.50673 .35576 Mdot
.45225 .34211 Mdot
.33758 .49961 Mdot
.57983 .57498 Mdot
.50536 .73473 Mdot
.61536 .36704 Mdot
.48984 .72811 Mdot
.67466 .61483 Mdot
.63845 .44453 Mdot
.33543 .50038 Mdot
.73141 .45288 Mdot
.54815 .65444 Mdot
.60143 .31354 Mdot
.68956 .61935 Mdot
.72069 .36022 Mdot
.736 .47974 Mdot
.50526 .43473 Mdot
.75306 .43776 Mdot
.62959 .64714 Mdot
.50093 .68933 Mdot
.52397 .33456 Mdot
.31121 .51435 Mdot
.35676 .55186 Mdot
.44333 .34379 Mdot
.41774 .77047 Mdot
.49281 .68317 Mdot
.66455 .45201 Mdot
.47678 .35991 Mdot
.46899 .30882 Mdot
.34885 .51668 Mdot
.64733 .63117 Mdot
.51835 .5526 Mdot
.72427 .47161 Mdot
.49596 .32307 Mdot
.4631 .39645 Mdot
.54965 .46601 Mdot
.46908 .6906 Mdot
.44192 .59709 Mdot
.48612 .34179 Mdot
.52628 .48581 Mdot
.44329 .35965 Mdot
.45873 .40852 Mdot
.67882 .60195 Mdot
.42501 .38618 Mdot
.51621 .33796 Mdot
.27078 .5116 Mdot
.49816 .72616 Mdot
.33639 .53982 Mdot
.39168 .5542 Mdot
.436 .60615 Mdot
.49578 .71821 Mdot
.4754 .314 Mdot
.46024 .71541 Mdot
.45377 .37726 Mdot
.49303 .3825 Mdot
.46807 .70653 Mdot
.32139 .51176 Mdot
.40328 .62072 Mdot
.36052 .46397 Mdot
.45501 .36099 Mdot
.51522 .36935 Mdot
.71199 .41722 Mdot
.77352 .3298 Mdot
.52216 .34565 Mdot
.33959 .50863 Mdot
.51677 .35717 Mdot
.51801 .70541 Mdot
.74484 .43964 Mdot
.32917 .53812 Mdot
.66436 .64439 Mdot
.68716 .62107 Mdot
.71364 .60396 Mdot
.44769 .58893 Mdot
.51005 .40433 Mdot
.29681 .55592 Mdot
.28867 .53903 Mdot
.61238 .39116 Mdot
.65647 .61881 Mdot
.7414 .43813 Mdot
.46892 .35219 Mdot
.54447 .4129 Mdot
.48027 .73857 Mdot
.86385 .65453 Mdot
.49348 .49102 Mdot
.74933 .48045 Mdot
.62387 .48046 Mdot
.43233 .59901 Mdot
.47314 .37061 Mdot
.7127 .44638 Mdot
.67776 .61077 Mdot
.45344 .37925 Mdot
.5326 .32102 Mdot
.57723 .65121 Mdot
.62554 .62709 Mdot
.46374 .72948 Mdot
.6833 .63937 Mdot
.74543 .47507 Mdot
.44635 .58901 Mdot
.35043 .56229 Mdot
.48814 .35788 Mdot
.4257 .32408 Mdot
.65575 .62941 Mdot
.41869 .58089 Mdot
.51675 .38963 Mdot
.33718 .56263 Mdot
.64894 .61971 Mdot
.50095 .37216 Mdot
.2343 .44977 Mdot
.38304 .49743 Mdot
.65815 .63875 Mdot
.48856 .32493 Mdot
.53441 .2844 Mdot
.62379 .62373 Mdot
.62582 .64322 Mdot
.45399 .38483 Mdot
.71238 .45883 Mdot
.5124 .33621 Mdot
.51106 .703 Mdot
.59456 .44505 Mdot
.48685 .71457 Mdot
.65269 .33888 Mdot
.45353 .39573 Mdot
.41613 .31371 Mdot
.36188 .51858 Mdot
.70232 .44566 Mdot
.46567 .19584 Mdot
.4653 .30774 Mdot
.23609 .55767 Mdot
.60637 .43717 Mdot
.50879 .50621 Mdot
.23501 .56954 Mdot
.71956 .46606 Mdot
.49851 .69311 Mdot
.52019 .38155 Mdot
.51326 .65231 Mdot
.71714 .45785 Mdot
.65157 .33745 Mdot
.47127 .3284 Mdot
.33526 .55136 Mdot
.47805 .36384 Mdot
.34289 .56149 Mdot
.51188 .35256 Mdot
.25009 .52153 Mdot
.7931 .46397 Mdot
.58389 .26472 Mdot
.50388 .43439 Mdot
.54723 .7465 Mdot
.36061 .42801 Mdot
.73923 .44082 Mdot
.4594 .37252 Mdot
.44071 .60239 Mdot
.48505 .6849 Mdot
.56696 .67178 Mdot
.63961 .60816 Mdot
.5033 .73016 Mdot
.33033 .51365 Mdot
.62947 .65045 Mdot
.42128 .58738 Mdot
.44984 .4441 Mdot
.71241 .45188 Mdot
.49906 .71829 Mdot
.48974 .35352 Mdot
.44944 .33582 Mdot
.57456 .72703 Mdot
.60771 .19537 Mdot
.35263 .5141 Mdot
.52239 .85872 Mdot
.30279 .56145 Mdot
.73646 .46836 Mdot
.67498 .60009 Mdot
.50668 .37474 Mdot
.49781 .33719 Mdot
.62699 .62692 Mdot
.36065 .56616 Mdot
.72126 .41876 Mdot
.76372 .33603 Mdot
.45549 .69548 Mdot
.61806 .23724 Mdot
.32653 .53911 Mdot
.61918 .23912 Mdot
.77103 .46684 Mdot
.42727 .56025 Mdot
.54903 .21746 Mdot
.48496 .69192 Mdot
.61751 .23534 Mdot
.33834 .55463 Mdot
.48339 .38339 Mdot
.43032 .58905 Mdot
.42694 .57778 Mdot
.31842 .53031 Mdot
.66144 .60207 Mdot
.72869 .47871 Mdot
.47882 .36032 Mdot
.42577 .4248 Mdot
.38049 .24246 Mdot
.64425 .6433 Mdot
.4602 .43542 Mdot
.47622 .69803 Mdot
.51594 .36041 Mdot
.7184 .43049 Mdot
.48863 .69293 Mdot
.44961 .61312 Mdot
.60441 .32036 Mdot
.48982 .32783 Mdot
.54454 .5506 Mdot
.50414 .70791 Mdot
.76767 .32343 Mdot
.52295 .36018 Mdot
.49968 .72669 Mdot
.42444 .32768 Mdot
.47177 .7835 Mdot
.53057 .5671 Mdot
.41609 .7079 Mdot
.69737 .64312 Mdot
.68812 .63489 Mdot
.70144 .2187 Mdot
.72462 .50677 Mdot
.48942 .7351 Mdot
.45436 .59689 Mdot
.61732 .2138 Mdot
.48848 .72403 Mdot
.50763 .32529 Mdot
.49707 .39378 Mdot
.37202 .44188 Mdot
.55605 .38824 Mdot
.43943 .57802 Mdot
.40243 .43189 Mdot
.47527 .38739 Mdot
.47688 .44104 Mdot
.51758 .38137 Mdot
.31857 .56079 Mdot
.48129 .69492 Mdot
.14783 .48198 Mdot
.45993 .70181 Mdot
.42747 .29973 Mdot
.65724 .63645 Mdot
.68832 .65208 Mdot
.49278 .35666 Mdot
.44342 .27065 Mdot
.22446 .70407 Mdot
.50505 .39451 Mdot
.5534 .55967 Mdot
.65829 .35069 Mdot
.52711 .41411 Mdot
.30514 .51535 Mdot
.4201 .34167 Mdot
.29798 .56116 Mdot
.4897 .69143 Mdot
.71876 .46405 Mdot
.70675 .47577 Mdot
.50164 .69583 Mdot
.49882 .33873 Mdot
.70386 .46482 Mdot
.4922 .36601 Mdot
.47243 .36057 Mdot
.52786 .48057 Mdot
.73711 .42815 Mdot
.64182 .60412 Mdot
.73577 .45767 Mdot
.30817 .53014 Mdot
.6454 .85055 Mdot
.74208 .44746 Mdot
.37206 .43882 Mdot
.62507 .42004 Mdot
.62498 .23638 Mdot
.35834 .55137 Mdot
.75426 .44769 Mdot
.48858 .68802 Mdot
.46762 .4891 Mdot
.35843 .40874 Mdot
.52085 .7178 Mdot
.48725 .34401 Mdot
.34094 .50167 Mdot
.29983 .55329 Mdot
.52381 .69091 Mdot
.36057 .56062 Mdot
.53349 .39062 Mdot
.4694 .3418 Mdot
.50185 .7335 Mdot
.33146 .22532 Mdot
.49957 .68496 Mdot
.32179 .46784 Mdot
.48744 .40414 Mdot
.33085 .54006 Mdot
.36779 .42504 Mdot
.383 .52498 Mdot
.43235 .57954 Mdot
.52412 .34252 Mdot
.7435 .4436 Mdot
.62042 .38565 Mdot
.65496 .63918 Mdot
.32802 .73229 Mdot
.35392 .55288 Mdot
.50567 .67484 Mdot
.3571 .56187 Mdot
.36437 .55119 Mdot
.49862 .74023 Mdot
.32214 .54826 Mdot
.5078 .3365 Mdot
.23718 .63178 Mdot
.35569 .54202 Mdot
.4965 .70433 Mdot
.75147 .45006 Mdot
.34204 .51076 Mdot
.66653 .43869 Mdot
.47377 .34598 Mdot
.69014 .64168 Mdot
.68924 .46006 Mdot
.36754 .53885 Mdot
.73913 .43957 Mdot
.65434 .62501 Mdot
.72191 .47781 Mdot
.48577 .64355 Mdot
.53282 .74247 Mdot
.52942 .25625 Mdot
.4832 .79011 Mdot
.30973 .54395 Mdot
.66383 .66348 Mdot
.49618 .32763 Mdot
.47529 .36017 Mdot
.71431 .48518 Mdot
.30777 .55708 Mdot
.42778 .78018 Mdot
.39895 .35344 Mdot
.40659 .76325 Mdot
.47528 .68529 Mdot
.69811 .40879 Mdot
.48893 .49114 Mdot
.4946 .65765 Mdot
.50558 .41887 Mdot
.43188 .59793 Mdot
.49831 .36498 Mdot
.6756 .36673 Mdot
.7415 .477 Mdot
.59852 .74319 Mdot
.43909 .3641 Mdot
.62939 .62711 Mdot
.51154 .35818 Mdot
.52342 .63409 Mdot
.44739 .39778 Mdot
.71684 .48074 Mdot
.46484 .68303 Mdot
.33312 .50455 Mdot
.75313 .45847 Mdot
.68632 .61764 Mdot
.53801 .23156 Mdot
.50528 .32518 Mdot
.47632 .38604 Mdot
.62118 .62073 Mdot
.31402 .51396 Mdot
.67032 .61227 Mdot
.50071 .72711 Mdot
.73998 .44915 Mdot
.45714 .33241 Mdot
.46614 .43854 Mdot
.66304 .58784 Mdot
.4666 .72453 Mdot
.63298 .60366 Mdot
.46083 .71803 Mdot
.42887 .59302 Mdot
.46394 .40888 Mdot
.62354 .60943 Mdot
.5006 .41771 Mdot
.35809 .33509 Mdot
.60431 .33898 Mdot
.42016 .24192 Mdot
.64423 .60205 Mdot
.78602 .48349 Mdot
.49488 .69686 Mdot
.50054 .72028 Mdot
.29337 .47506 Mdot
.25824 .73532 Mdot
.52244 .54399 Mdot
.47738 .82076 Mdot
.50154 .72703 Mdot
.50204 .7115 Mdot
.66593 .60668 Mdot
.31125 .5247 Mdot
.3717 .53586 Mdot
.61435 .62601 Mdot
.62765 .3271 Mdot
.34375 .55269 Mdot
.21504 .51861 Mdot
.65928 .65066 Mdot
.53115 .37485 Mdot
.40616 .53167 Mdot
.71722 .48054 Mdot
.65841 .36206 Mdot
.54118 .76726 Mdot
.505 .36622 Mdot
.76255 .69123 Mdot
.64321 .60788 Mdot
.44397 .50993 Mdot
.45306 .73769 Mdot
.45804 .32218 Mdot
.50855 .35357 Mdot
.51461 .34535 Mdot
.7301 .48898 Mdot
.36681 .28357 Mdot
.50562 .37062 Mdot
.59525 .29039 Mdot
.46576 .30128 Mdot
.56144 .7607 Mdot
.73604 .45741 Mdot
.72431 .3329 Mdot
.62387 .65373 Mdot
.42447 .76058 Mdot
.48328 .30519 Mdot
.50897 .71999 Mdot
.53196 .61184 Mdot
.46758 .71594 Mdot
.45607 .64937 Mdot
.60001 .21009 Mdot
.30989 .55666 Mdot
.44338 .35137 Mdot
.64749 .64944 Mdot
.35623 .50928 Mdot
.53252 .60365 Mdot
.63164 .85436 Mdot
.50031 .67509 Mdot
.48376 .88813 Mdot
.48704 .71879 Mdot
.43144 .57665 Mdot
.32941 .51545 Mdot
.45772 .25452 Mdot
.56457 .45946 Mdot
.31797 .51258 Mdot
.77311 .55925 Mdot
.31309 .57617 Mdot
.58608 .24163 Mdot
.27954 .51627 Mdot
.49054 .70214 Mdot
.51972 .68341 Mdot
.5184 .30193 Mdot
.50958 .33234 Mdot
.57238 .45907 Mdot
.54833 .31965 Mdot
.48827 .3292 Mdot
.6699 .63054 Mdot
.49037 .79402 Mdot
.51584 .65445 Mdot
.32115 .53977 Mdot
.47388 .73469 Mdot
.51022 .35679 Mdot
.45531 .36155 Mdot
.52166 .32642 Mdot
.77787 .40194 Mdot
.21303 .51594 Mdot
.49309 .38478 Mdot
.44846 .4024 Mdot
.68737 .6135 Mdot
.57531 .72803 Mdot
.54884 .84122 Mdot
.6064 .21173 Mdot
.51262 .39559 Mdot
.73335 .46582 Mdot
.71788 .42962 Mdot
.54001 .36113 Mdot
.46358 .25849 Mdot
.6908 .42087 Mdot
.48983 .35314 Mdot
.55827 .24234 Mdot
.69664 .59806 Mdot
.42762 .59933 Mdot
.656 .62887 Mdot
.36515 .52378 Mdot
.4252 .59068 Mdot
.68021 .62753 Mdot
.60835 .31462 Mdot
.44362 .60847 Mdot
.46788 .78178 Mdot
.75334 .44538 Mdot
.52096 .37317 Mdot
.38551 .47306 Mdot
.65415 .64418 Mdot
.50449 .71354 Mdot
.33486 .52392 Mdot
.48587 .68346 Mdot
.54167 .78848 Mdot
.63623 .33678 Mdot
.44133 .58431 Mdot
.51031 .71897 Mdot
.53886 .54637 Mdot
.73549 .46415 Mdot
.48121 .71824 Mdot
.4181 .30788 Mdot
.44038 .33551 Mdot
.19253 .62541 Mdot
.46889 .37582 Mdot
.44166 .66484 Mdot
.50643 .71674 Mdot
.44628 .61389 Mdot
.4873 .35952 Mdot
.67008 .65334 Mdot
.46657 .45224 Mdot
.49234 .36795 Mdot
.67308 .64491 Mdot
.48961 .38661 Mdot
.72407 .43052 Mdot
.31128 .56955 Mdot
.61431 .42912 Mdot
.70184 .39547 Mdot
.73585 .47785 Mdot
.59306 .40089 Mdot
.52238 .34514 Mdot
.73479 .53701 Mdot
.33685 .54984 Mdot
.46365 .30926 Mdot
.66031 .33181 Mdot
.31317 .52986 Mdot
.34196 .53151 Mdot
.46602 .37991 Mdot
.50668 .68823 Mdot
.63292 .60808 Mdot
.73557 .46223 Mdot
.53387 .68252 Mdot
.50226 .37364 Mdot
.45182 .37981 Mdot
.74193 .47527 Mdot
.49787 .71627 Mdot
.46297 .32429 Mdot
.35023 .6984 Mdot
.61065 .36567 Mdot
.46921 .73383 Mdot
.4405 .33725 Mdot
.2045 .55571 Mdot
.37102 .5598 Mdot
.76669 .68773 Mdot
.78571 .47451 Mdot
.67236 .60182 Mdot
.43722 .41425 Mdot
.81539 .71305 Mdot
.7516 .44488 Mdot
.40512 .75205 Mdot
.48284 .38058 Mdot
.5085 .37817 Mdot
.3139 .55665 Mdot
.46785 .32356 Mdot
.32871 .55745 Mdot
.71354 .4014 Mdot
.27649 .75382 Mdot
.36111 .5561 Mdot
.33823 .55873 Mdot
.51382 .28228 Mdot
.80342 .41774 Mdot
.31926 .5228 Mdot
.50345 .32482 Mdot
.76616 .53709 Mdot
.54466 .33827 Mdot
.75662 .43387 Mdot
.71124 .41185 Mdot
.30883 .50821 Mdot
.34822 .42235 Mdot
.5115 .28217 Mdot
.24957 .48034 Mdot
.6723 .45113 Mdot
.48789 .73272 Mdot
.46301 .38966 Mdot
.45365 .59484 Mdot
.65103 .61513 Mdot
.4162 .36252 Mdot
.52244 .36267 Mdot
.3052 .52318 Mdot
.7432 .48229 Mdot
.48304 .72252 Mdot
.49075 .41244 Mdot
.68571 .58964 Mdot
.7284 .47431 Mdot
.353 .53037 Mdot
.34661 .45627 Mdot
.70535 .46849 Mdot
.45889 .4361 Mdot
.48411 .38655 Mdot
.49932 .40797 Mdot
.51634 .43301 Mdot
.50237 .69774 Mdot
.62015 .64085 Mdot
.454 .43233 Mdot
.4978 .48662 Mdot
.61802 .356 Mdot
.5293 .33836 Mdot
.34049 .50925 Mdot
.47197 .69052 Mdot
.44691 .59368 Mdot
.62238 .22665 Mdot
.48927 .39632 Mdot
.21382 .5205 Mdot
.75803 .36935 Mdot
.44663 .60609 Mdot
.34732 .49986 Mdot
.7319 .45769 Mdot
.47759 .39637 Mdot
.59349 .28481 Mdot
.48479 .32726 Mdot
.52845 .41676 Mdot
.66074 .6003 Mdot
.47953 .72739 Mdot
.54262 .26877 Mdot
.65383 .61293 Mdot
.34118 .5313 Mdot
.20989 .49371 Mdot
.37032 .5376 Mdot
.36136 .53013 Mdot
.46563 .56174 Mdot
.50945 .69585 Mdot
.82667 .70128 Mdot
.78885 .34634 Mdot
.52998 .35205 Mdot
.51701 .71804 Mdot
.3244 .52186 Mdot
.48711 .31557 Mdot
.32474 .55379 Mdot
.30274 .51408 Mdot
.47139 .34526 Mdot
.47575 .3389 Mdot
.57955 .25925 Mdot
.21932 .52356 Mdot
.74744 .44703 Mdot
.35104 .56772 Mdot
.26741 .47601 Mdot
.50507 .37734 Mdot
.51862 .34395 Mdot
.5323 .61574 Mdot
.75513 .4558 Mdot
.24635 .38012 Mdot
.47649 .36673 Mdot
.69598 .36274 Mdot
.5146 .332 Mdot
.37442 .53022 Mdot
.5292 .71138 Mdot
.42569 .30027 Mdot
.64485 .59884 Mdot
.36548 .56511 Mdot
.73251 .48462 Mdot
.32328 .48821 Mdot
.25374 .40948 Mdot
.4964 .68932 Mdot
.34506 .559 Mdot
.63687 .65513 Mdot
.49109 .71296 Mdot
.50207 .6868 Mdot
.53332 .60009 Mdot
.65376 .65971 Mdot
.74993 .47909 Mdot
.47248 .70809 Mdot
.23544 .4528 Mdot
.48922 .70446 Mdot
.24745 .41047 Mdot
.51816 .39391 Mdot
.59713 .29423 Mdot
.41581 .37498 Mdot
.52461 .30745 Mdot
.47902 .70672 Mdot
.73105 .47687 Mdot
.46566 .31873 Mdot
.36249 .55104 Mdot
.74722 .45875 Mdot
.41629 .51697 Mdot
.66688 .66152 Mdot
.29526 .54689 Mdot
.45881 .71392 Mdot
.31609 .55241 Mdot
.65771 .35394 Mdot
.73534 .41217 Mdot
.54707 .61722 Mdot
.57792 .44909 Mdot
.49106 .437 Mdot
.43687 .37403 Mdot
.46499 .31738 Mdot
.50708 .338 Mdot
.65917 .63807 Mdot
.73025 .49282 Mdot
.34342 .51094 Mdot
.38055 .23082 Mdot
.51017 .71155 Mdot
.54644 .56024 Mdot
.51154 .43425 Mdot
.45269 .37628 Mdot
.32689 .52348 Mdot
.30318 .50986 Mdot
.37826 .28783 Mdot
.62633 .62057 Mdot
.5385 .32587 Mdot
.49588 .31014 Mdot
.5654 .29441 Mdot
.48107 .70896 Mdot
.39578 .6854 Mdot
.70393 .6132 Mdot
.49895 .89455 Mdot
.65616 .61391 Mdot
.63177 .53833 Mdot
.31943 .54701 Mdot
.73027 .44149 Mdot
.487 .33954 Mdot
.41087 .46463 Mdot
.33358 .49669 Mdot
.59339 .61584 Mdot
.73049 .45049 Mdot
.41756 .64431 Mdot
.51217 .72499 Mdot
.49292 .4137 Mdot
.51314 .33034 Mdot
.456 .34667 Mdot
.48173 .31904 Mdot
.49531 .73642 Mdot
.47712 .33194 Mdot
.49401 .74342 Mdot
.25929 .39848 Mdot
.65571 .32361 Mdot
.63158 .64489 Mdot
.58562 .72784 Mdot
.36177 .53362 Mdot
.21065 .43236 Mdot
.25594 .37949 Mdot
.60457 .33977 Mdot
.47222 .64336 Mdot
.48825 .41681 Mdot
.65879 .60303 Mdot
.54334 .68951 Mdot
.63535 .64689 Mdot
.1463 .54042 Mdot
.36927 .4396 Mdot
.43393 .65984 Mdot
.46148 .33759 Mdot
.61925 .6178 Mdot
.33558 .4412 Mdot
.4502 .43309 Mdot
.70279 .45809 Mdot
.24494 .42886 Mdot
.40877 .47767 Mdot
.74581 .43889 Mdot
.47153 .35241 Mdot
.28657 .53067 Mdot
.49206 .33825 Mdot
.4816 .34176 Mdot
.50408 .39656 Mdot
.52446 .72805 Mdot
.52743 .37873 Mdot
.50933 .3347 Mdot
.62478 .19483 Mdot
.59373 .65267 Mdot
.69079 .63311 Mdot
.41309 .24654 Mdot
.74354 .46013 Mdot
.36444 .5221 Mdot
.60461 .43652 Mdot
.51399 .71171 Mdot
.37988 .2844 Mdot
.4605 .36147 Mdot
.3737 .73844 Mdot
.47253 .68203 Mdot
.71467 .46643 Mdot
.45279 .59873 Mdot
.40012 .65333 Mdot
.67573 .59691 Mdot
.44808 .5852 Mdot
.6519 .6393 Mdot
.44379 .22299 Mdot
.3335 .55875 Mdot
.49068 .43704 Mdot
.47794 .72061 Mdot
.64514 .65365 Mdot
.59086 .28338 Mdot
.51877 .35663 Mdot
.64417 .60177 Mdot
.42666 .39861 Mdot
.6239 .38584 Mdot
.60125 .44068 Mdot
.63361 .65113 Mdot
.47117 .68026 Mdot
.48535 .71099 Mdot
.74776 .43774 Mdot
.36758 .56036 Mdot
.31004 .51761 Mdot
.48521 .70489 Mdot
.69194 .77277 Mdot
.50231 .37128 Mdot
.5006 .3879 Mdot
.48909 .48742 Mdot
.49151 .31408 Mdot
.71767 .41498 Mdot
.42505 .57446 Mdot
.31409 .50902 Mdot
.46613 .31694 Mdot
.46237 .32545 Mdot
.47888 .38273 Mdot
.62278 .31604 Mdot
.65356 .62997 Mdot
.47641 .38943 Mdot
.71216 .44981 Mdot
.41388 .50415 Mdot
.49887 .32805 Mdot
.46248 .43914 Mdot
.32573 .55645 Mdot
.65503 .55624 Mdot
.50669 .71205 Mdot
.64051 .64087 Mdot
.64442 .64677 Mdot
.66332 .2967 Mdot
.38182 .55408 Mdot
.44195 .57941 Mdot
.56192 .73832 Mdot
.44865 .59209 Mdot
.72881 .44895 Mdot
.52561 .5617 Mdot
.69834 .65555 Mdot
.68854 .6355 Mdot
.51 .67358 Mdot
.45135 .32486 Mdot
.49973 .32678 Mdot
.4209 .76164 Mdot
.50437 .3931 Mdot
.74497 .44331 Mdot
.52026 .70187 Mdot
.33945 .5576 Mdot
.71501 .4347 Mdot
.49691 .72199 Mdot
.31686 .51187 Mdot
.47974 .29943 Mdot
.5038 .32323 Mdot
.33826 .52524 Mdot
.35571 .53532 Mdot
.49897 .35312 Mdot
.58273 .19661 Mdot
.3217 .50445 Mdot
.33348 .51984 Mdot
.41299 .49725 Mdot
.68503 .6042 Mdot
.48175 .45828 Mdot
.51718 .70995 Mdot
.51165 .33782 Mdot
.62704 .64094 Mdot
.72303 .45735 Mdot
.34919 .53481 Mdot
.46833 .39617 Mdot
.49808 .37769 Mdot
.73265 .46477 Mdot
.74328 .42654 Mdot
.7509 .46045 Mdot
.5259 .70023 Mdot
.46623 .34862 Mdot
.32359 .51726 Mdot
.51081 .72724 Mdot
.70585 .461 Mdot
.75531 .43861 Mdot
.55193 .20904 Mdot
.50349 .36334 Mdot
.71484 .42951 Mdot
.67412 .84016 Mdot
.55632 .22895 Mdot
.42214 .58601 Mdot
.70982 .60928 Mdot
.79936 .46721 Mdot
.6904 .46123 Mdot
.47975 .73038 Mdot
.55363 .56453 Mdot
.75367 .4702 Mdot
.48726 .40838 Mdot
.51664 .37513 Mdot
.48202 .43126 Mdot
.74493 .46238 Mdot
.63723 .33526 Mdot
.31554 .56315 Mdot
.29838 .31614 Mdot
.74362 .45983 Mdot
.64774 .65645 Mdot
.66419 .58701 Mdot
.66149 .61084 Mdot
.46601 .40909 Mdot
.42237 .22137 Mdot
.26584 .4362 Mdot
.24836 .37064 Mdot
.51014 .72487 Mdot
.30202 .5123 Mdot
.41484 .53933 Mdot
.34277 .53193 Mdot
.64223 .61948 Mdot
.72763 .47518 Mdot
.31187 .5562 Mdot
.50096 .68681 Mdot
.4828 .70856 Mdot
.64393 .59679 Mdot
.65665 .6235 Mdot
.67045 .62099 Mdot
.36641 .56365 Mdot
.32063 .54771 Mdot
.45472 .3405 Mdot
.3527 .53949 Mdot
.77969 .37829 Mdot
.76973 .41459 Mdot
.64589 .59259 Mdot
.50157 .70217 Mdot
.34112 .51741 Mdot
.52159 .37342 Mdot
.59204 .54353 Mdot
.62386 .65667 Mdot
.71368 .47492 Mdot
.26693 .6946 Mdot
.2589 .74544 Mdot
.44122 .35981 Mdot
.47018 .72926 Mdot
.4373 .2804 Mdot
.50954 .34274 Mdot
.6599 .59858 Mdot
.75164 .34442 Mdot
.45027 .60995 Mdot
.49418 .33297 Mdot
.49361 .30302 Mdot
.49158 .68597 Mdot
.60331 .4365 Mdot
.48599 .40925 Mdot
.54619 .58053 Mdot
.48097 .67724 Mdot
.7026 .61022 Mdot
.7415 .24985 Mdot
.43652 .50809 Mdot
.66441 .38363 Mdot
.42808 .59819 Mdot
.49769 .40094 Mdot
.6684 .63276 Mdot
.70832 .45664 Mdot
.66447 .62763 Mdot
.35352 .50283 Mdot
.67862 .59937 Mdot
.512 .39069 Mdot
.31929 .52006 Mdot
.49777 .71799 Mdot
.54639 .53051 Mdot
.44841 .23202 Mdot
.67328 .65199 Mdot
.41775 .58146 Mdot
.47696 .33828 Mdot
.22635 .45396 Mdot
.51566 .29917 Mdot
.51481 .33657 Mdot
.46761 .70997 Mdot
.32279 .53174 Mdot
.47409 .68651 Mdot
.44498 .43557 Mdot
.24352 .54941 Mdot
.50996 .70727 Mdot
.41696 .46669 Mdot
.73713 .47918 Mdot
.63198 .3334 Mdot
.48311 .35717 Mdot
.47928 .72271 Mdot
.46546 .35929 Mdot
.34839 .56805 Mdot
.61386 .33747 Mdot
.60523 .36676 Mdot
.47707 .69586 Mdot
.43227 .6191 Mdot
.63234 .40372 Mdot
.48529 .45899 Mdot
.49463 .72807 Mdot
.45938 .20006 Mdot
.44338 .60149 Mdot
.72505 .4704 Mdot
.74315 .42488 Mdot
.72078 .443 Mdot
.50611 .38824 Mdot
.24308 .50127 Mdot
.74592 .43292 Mdot
.50389 .68012 Mdot
.73007 .43161 Mdot
.73388 .38915 Mdot
.41987 .77231 Mdot
.73495 .47899 Mdot
.48304 .36534 Mdot
.43268 .29936 Mdot
.55248 .56133 Mdot
.68889 .64872 Mdot
.3501 .62711 Mdot
.62974 .19666 Mdot
.50716 .37348 Mdot
.24492 .52941 Mdot
.36072 .50353 Mdot
.65196 .51867 Mdot
.60292 .36173 Mdot
.52532 .52834 Mdot
.33795 .51808 Mdot
.59179 .44253 Mdot
.34032 .50275 Mdot
.49856 .43812 Mdot
.49217 .38235 Mdot
.36811 .56448 Mdot
.31622 .72591 Mdot
.44037 .19175 Mdot
.39617 .75977 Mdot
.32953 .50765 Mdot
.49801 .72609 Mdot
.46717 .71901 Mdot
.46804 .71176 Mdot
.66868 .63908 Mdot
.34925 .56006 Mdot
.48583 .39742 Mdot
.683 .61157 Mdot
.47761 .34937 Mdot
.48371 .69724 Mdot
.60507 .34808 Mdot
.33649 .5577 Mdot
.48866 .35256 Mdot
.31132 .45527 Mdot
.64791 .63627 Mdot
.73613 .46558 Mdot
.2527 .66864 Mdot
.71271 .623 Mdot
.46369 .68871 Mdot
.33662 .48938 Mdot
.65005 .58266 Mdot
.58954 .56896 Mdot
.53135 .35689 Mdot
.52549 .33845 Mdot
.55948 .56795 Mdot
.35949 .44083 Mdot
.48257 .41073 Mdot
.68683 .61938 Mdot
.69326 .61778 Mdot
.46653 .36203 Mdot
.35605 .55849 Mdot
.76129 .45859 Mdot
.71258 .48458 Mdot
.51004 .42827 Mdot
.57889 .45208 Mdot
.59588 .292 Mdot
.47282 .31525 Mdot
.45618 .42723 Mdot
.64302 .65863 Mdot
.42248 .58991 Mdot
.55497 .46293 Mdot
.73132 .43725 Mdot
.47876 .37596 Mdot
.38139 .24454 Mdot
.35273 .5532 Mdot
.64032 .60307 Mdot
.51113 .7321 Mdot
.70417 .46513 Mdot
.6573 .59153 Mdot
.46657 .36209 Mdot
.46303 .32441 Mdot
.47892 .71829 Mdot
.37611 .53219 Mdot
.7387 .47217 Mdot
.68392 .61162 Mdot
.73236 .44 Mdot
.32414 .54967 Mdot
.34642 .52357 Mdot
.51628 .31996 Mdot
.52512 .30566 Mdot
.66526 .65184 Mdot
.50344 .42354 Mdot
.67625 .61257 Mdot
.57438 .7278 Mdot
.48136 .73873 Mdot
.47282 .30691 Mdot
.38364 .54788 Mdot
.48317 .70003 Mdot
.50922 .36745 Mdot
.56153 .57193 Mdot
.44574 .35412 Mdot
.6161 .62836 Mdot
.75152 .3248 Mdot
.71937 .45306 Mdot
.45619 .29601 Mdot
.39156 .34334 Mdot
.48566 .31296 Mdot
.69477 .63398 Mdot
.24788 .44385 Mdot
.50797 .70105 Mdot
.3156 .54184 Mdot
.71875 .58669 Mdot
.49406 .70462 Mdot
.48145 .3712 Mdot
.74241 .44828 Mdot
.33906 .50484 Mdot
.42833 .58363 Mdot
.55216 .47636 Mdot
.41899 .32975 Mdot
.54502 .35836 Mdot
.48859 .41352 Mdot
.47502 .82147 Mdot
.66867 .62317 Mdot
.32644 .52175 Mdot
.47303 .7314 Mdot
.50093 .69143 Mdot
.64696 .63119 Mdot
.41214 .4841 Mdot
.35786 .75209 Mdot
.72205 .80449 Mdot
.65573 .59078 Mdot
.72431 .43562 Mdot
.61296 .33889 Mdot
.66077 .60942 Mdot
.66046 .64161 Mdot
.64623 .66151 Mdot
.42493 .7677 Mdot
.32704 .50924 Mdot
.49878 .37898 Mdot
.35786 .48677 Mdot
.50134 .39651 Mdot
.65467 .39674 Mdot
.4852 .697 Mdot
.31552 .54248 Mdot
.66585 .43012 Mdot
.44427 .39551 Mdot
.50475 .34507 Mdot
.66278 .45344 Mdot
.49309 .27095 Mdot
.62123 .23196 Mdot
.51101 .32132 Mdot
.6604 .63205 Mdot
.39575 .56437 Mdot
.45811 .43504 Mdot
.30687 .45699 Mdot
.48637 .71464 Mdot
.44086 .58309 Mdot
.48444 .44114 Mdot
.47101 .42585 Mdot
.34389 .5056 Mdot
.31018 .5546 Mdot
.75142 .4349 Mdot
.24265 .6388 Mdot
.4897 .71693 Mdot
.41217 .69395 Mdot
.5144 .33534 Mdot
.4585 .65118 Mdot
.76031 .3402 Mdot
.50781 .35983 Mdot
.53349 .59473 Mdot
.37859 .28786 Mdot
.46016 .39042 Mdot
.25738 .35819 Mdot
.4964 .69981 Mdot
.67296 .3463 Mdot
.47358 .32924 Mdot
.64992 .60127 Mdot
.30998 .52914 Mdot
.29483 .54656 Mdot
.70758 .45523 Mdot
.79171 .37161 Mdot
.3364 .79634 Mdot
.31505 .54361 Mdot
.51883 .35302 Mdot
.50582 .70987 Mdot
.43333 .58094 Mdot
.41646 .35577 Mdot
.51711 .63984 Mdot
.3513 .55216 Mdot
.44741 .42902 Mdot
.37007 .73964 Mdot
.59765 .43993 Mdot
.19473 .46188 Mdot
.4696 .7084 Mdot
.73642 .43532 Mdot
.55217 .37613 Mdot
.56235 .74224 Mdot
.50526 .32371 Mdot
.65749 .39198 Mdot
.37226 .57185 Mdot
.74313 .43938 Mdot
.50102 .33996 Mdot
.47891 .40876 Mdot
.59215 .41804 Mdot
.75177 .42665 Mdot
.48333 .40937 Mdot
.43946 .36607 Mdot
.30801 .53774 Mdot
.42308 .57436 Mdot
.3413 .5568 Mdot
.49212 .33951 Mdot
.72716 .296 Mdot
.33761 .56517 Mdot
.38015 .62082 Mdot
.78007 .47793 Mdot
.51361 .713 Mdot
.42352 .37631 Mdot
.52388 .38256 Mdot
.18275 .47861 Mdot
.43104 .57904 Mdot
.58593 .8287 Mdot
.61812 .62219 Mdot
.57833 .16119 Mdot
.71245 .62626 Mdot
.4345 .63352 Mdot
.57432 .63537 Mdot
.45479 .43052 Mdot
.40585 .46172 Mdot
.242 .37176 Mdot
.45803 .73866 Mdot
.212 .42504 Mdot
.50942 .33223 Mdot
.47893 .37968 Mdot
.67261 .6071 Mdot
.44868 .64282 Mdot
.42394 .30225 Mdot
.55742 .46191 Mdot
.71639 .46913 Mdot
.33801 .54235 Mdot
.51738 .37697 Mdot
.29741 .71385 Mdot
.6588 .65676 Mdot
.45186 .23916 Mdot
.48724 .35558 Mdot
.44744 .2748 Mdot
.45098 .63962 Mdot
.50046 .71797 Mdot
.63277 .65104 Mdot
.65494 .6588 Mdot
.49788 .39938 Mdot
.50251 .73514 Mdot
.45113 .35352 Mdot
.63267 .39488 Mdot
.42977 .40336 Mdot
.72617 .45232 Mdot
.52364 .35473 Mdot
.42011 .27592 Mdot
.22822 .30735 Mdot
.43801 .36554 Mdot
.364 .53426 Mdot
.67389 .62026 Mdot
.64986 .62621 Mdot
.31206 .5143 Mdot
.6491 .62607 Mdot
.29669 .3224 Mdot
.23098 .51508 Mdot
.73011 .44607 Mdot
.27258 .38365 Mdot
.71746 .46084 Mdot
.44229 .58412 Mdot
.50246 .3596 Mdot
.66287 .70309 Mdot
.66735 .59057 Mdot
.73911 .38562 Mdot
.48655 .70288 Mdot
.43009 .57804 Mdot
.47396 .33926 Mdot
.67296 .4656 Mdot
.64628 .61027 Mdot
.48541 .54508 Mdot
.49586 .39555 Mdot
.35948 .56592 Mdot
.45651 .38352 Mdot
.52783 .29034 Mdot
.43204 .57598 Mdot
.4599 .39549 Mdot
.49708 .72201 Mdot
.33828 .56236 Mdot
.43451 .67046 Mdot
.65692 .64411 Mdot
.48712 .33333 Mdot
.5174 .35014 Mdot
.31902 .49866 Mdot
.52968 .35529 Mdot
.50051 .73234 Mdot
.88939 .60764 Mdot
.74991 .46584 Mdot
.42378 .59266 Mdot
.30913 .6384 Mdot
.46382 .39873 Mdot
.45865 .3272 Mdot
.49957 .526 Mdot
.38429 .24185 Mdot
.50868 .71785 Mdot
.54305 .37686 Mdot
.69216 .62572 Mdot
.73718 .47388 Mdot
.49137 .6823 Mdot
.47049 .33962 Mdot
.49177 .38845 Mdot
.74294 .44056 Mdot
.65996 .44772 Mdot
.72205 .41947 Mdot
.48674 .7337 Mdot
.26271 .56243 Mdot
.59398 .5424 Mdot
.49751 .36726 Mdot
.41543 .58363 Mdot
.32633 .53061 Mdot
.49591 .72942 Mdot
.36024 .2872 Mdot
.49983 .43783 Mdot
.46208 .72773 Mdot
.49559 .71823 Mdot
.53008 .36522 Mdot
.38059 .55689 Mdot
.33328 .4872 Mdot
.32699 .527 Mdot
.65813 .31726 Mdot
.54071 .82232 Mdot
.67258 .62438 Mdot
.50083 .70461 Mdot
.62611 .63744 Mdot
.75187 .47098 Mdot
.62021 .36524 Mdot
.66979 .65591 Mdot
.35916 .57045 Mdot
.63595 .64547 Mdot
.4504 .35193 Mdot
.51179 .694 Mdot
.6617 .65023 Mdot
.48341 .3163 Mdot
.48002 .42199 Mdot
.55751 .38284 Mdot
.75385 .47365 Mdot
.59117 .44492 Mdot
.47961 .36131 Mdot
.45206 .59942 Mdot
.49482 .35318 Mdot
.50054 .73338 Mdot
.55061 .52652 Mdot
.4695 .37935 Mdot
.66654 .59039 Mdot
.55373 .82944 Mdot
.69528 .61458 Mdot
.54783 .30147 Mdot
.48633 .34479 Mdot
.50004 .3675 Mdot
.47311 .34206 Mdot
.40708 .47996 Mdot
.45794 .70474 Mdot
.5416 .39386 Mdot
.62917 .60637 Mdot
.34401 .53016 Mdot
.33316 .56584 Mdot
.51203 .53786 Mdot
.45027 .58746 Mdot
.51237 .72809 Mdot
.50094 .36946 Mdot
.48808 .54811 Mdot
.52413 .4957 Mdot
.37974 .75156 Mdot
.7076 .596 Mdot
.68646 .63927 Mdot
.36533 .54863 Mdot
.68095 .63813 Mdot
.47387 .33599 Mdot
.44761 .42843 Mdot
.43352 .66738 Mdot
.44953 .71959 Mdot
.73433 .47433 Mdot
.48119 .34548 Mdot
.60724 .29449 Mdot
.68729 .61342 Mdot
.64652 .65924 Mdot
.45208 .35256 Mdot
.37093 .51316 Mdot
.30176 .22779 Mdot
.51834 .71619 Mdot
.2297 .46524 Mdot
.35039 .47401 Mdot
.58674 .32503 Mdot
.5016 .69487 Mdot
.53517 .5868 Mdot
.69334 .64484 Mdot
.72208 .27753 Mdot
.342 .52577 Mdot
.73632 .47288 Mdot
.49556 .31978 Mdot
.35928 .57065 Mdot
.62745 .60128 Mdot
.33031 .50105 Mdot
.48378 .43965 Mdot
.48244 .67972 Mdot
.65119 .61807 Mdot
.51876 .68141 Mdot
.35588 .50802 Mdot
.71768 .45813 Mdot
.68816 .36484 Mdot
.23227 .44751 Mdot
.37716 .29266 Mdot
.47703 .39068 Mdot
.61599 .67469 Mdot
.48676 .39913 Mdot
.30315 .55809 Mdot
.48288 .35817 Mdot
.43334 .37783 Mdot
.69176 .64864 Mdot
.52864 .33626 Mdot
.521 .34669 Mdot
.29577 .46091 Mdot
.50679 .35289 Mdot
.46883 .36541 Mdot
.51715 .31924 Mdot
.37103 .56498 Mdot
.52609 .33269 Mdot
.36202 .56217 Mdot
.39368 .74724 Mdot
.65357 .6424 Mdot
.75336 .46868 Mdot
.74623 .47449 Mdot
.66562 .38812 Mdot
.61279 .30265 Mdot
.40152 .52139 Mdot
.34617 .54987 Mdot
.47998 .70697 Mdot
.45178 .34809 Mdot
.47671 .19292 Mdot
.72111 .29866 Mdot
.70058 .63152 Mdot
.65427 .65149 Mdot
.49097 .32244 Mdot
.24604 .72948 Mdot
.51393 .32506 Mdot
.49074 .49021 Mdot
.50494 .38884 Mdot
.47132 .30734 Mdot
.62912 .65085 Mdot
.6585 .35554 Mdot
.47648 .38934 Mdot
.34396 .50536 Mdot
.73176 .4724 Mdot
.46154 .27037 Mdot
.72493 .32194 Mdot
.32894 .466 Mdot
.40092 .33567 Mdot
.46375 .36569 Mdot
.67705 .60441 Mdot
.33451 .50659 Mdot
.50653 .49035 Mdot
.50669 .72863 Mdot
.56924 .46372 Mdot
.25122 .40214 Mdot
.46336 .74695 Mdot
.72938 .47434 Mdot
.60611 .62866 Mdot
.50717 .39784 Mdot
.6725 .63484 Mdot
.52548 .41609 Mdot
.5256 .49968 Mdot
.72717 .4478 Mdot
.34768 .58245 Mdot
.49867 .72559 Mdot
.3404 .57005 Mdot
.41946 .2421 Mdot
.72188 .2963 Mdot
.58386 .16145 Mdot
.67994 .59645 Mdot
.32676 .25648 Mdot
.31759 .53025 Mdot
.49304 .39906 Mdot
.71878 .80655 Mdot
.32671 .53753 Mdot
.36055 .56604 Mdot
.54108 .50881 Mdot
.65416 .33988 Mdot
.50562 .42293 Mdot
.31982 .50416 Mdot
.607 .62553 Mdot
.73283 .4532 Mdot
.47755 .31817 Mdot
.48077 .4414 Mdot
.31244 .55613 Mdot
.64199 .61467 Mdot
.65326 .37768 Mdot
.65796 .62833 Mdot
.32421 .51176 Mdot
.63925 .63405 Mdot
.40624 .62447 Mdot
.66856 .65543 Mdot
.52568 .36822 Mdot
.50013 .36945 Mdot
.48417 .60207 Mdot
.34644 .5236 Mdot
.45963 .32571 Mdot
.48559 .38392 Mdot
.32155 .5209 Mdot
.69167 .66112 Mdot
.35703 .2585 Mdot
.45328 .33464 Mdot
.50077 .375 Mdot
.75353 .46111 Mdot
.62002 .4083 Mdot
.47776 .49374 Mdot
.48103 .31487 Mdot
.71975 .44247 Mdot
.36556 .56344 Mdot
.49631 .35199 Mdot
.66066 .35658 Mdot
.6942 .59588 Mdot
.46091 .34569 Mdot
.43299 .58339 Mdot
.49722 .40428 Mdot
.28626 .25028 Mdot
.48052 .33522 Mdot
.33153 .51474 Mdot
.31262 .52811 Mdot
.72297 .60994 Mdot
.33931 .53073 Mdot
.42262 .58592 Mdot
.48523 .70975 Mdot
.20425 .46633 Mdot
.42201 .5819 Mdot
.45513 .38858 Mdot
.79323 .35227 Mdot
.47455 .44225 Mdot
.4513 .43526 Mdot
.80516 .4186 Mdot
.42815 .59781 Mdot
.32058 .53629 Mdot
.30749 .71344 Mdot
.52609 .39701 Mdot
.51387 .72674 Mdot
.46258 .43786 Mdot
.46085 .3467 Mdot
.4343 .36154 Mdot
.24688 .54637 Mdot
.52193 .71518 Mdot
.48141 .45877 Mdot
.47704 .31824 Mdot
.38457 .24239 Mdot
.5204 .36798 Mdot
.71869 .47941 Mdot
.33231 .55386 Mdot
.67887 .63714 Mdot
.72795 .4541 Mdot
.48768 .41233 Mdot
.74506 .45955 Mdot
.6729 .63138 Mdot
.47341 .71536 Mdot
.52472 .37292 Mdot
.75758 .4345 Mdot
.72445 .47519 Mdot
.46276 .38088 Mdot
.31172 .53876 Mdot
.51078 .29617 Mdot
.49901 .35195 Mdot
.46871 .34728 Mdot
.30876 .52046 Mdot
.79831 .65299 Mdot
.4773 .37983 Mdot
.53555 .58977 Mdot
.30395 .5635 Mdot
.42146 .57483 Mdot
.68729 .62666 Mdot
.44271 .37581 Mdot
.50476 .69244 Mdot
.48601 .70825 Mdot
.68108 .59371 Mdot
.30865 .55031 Mdot
.64821 .6207 Mdot
.43745 .36693 Mdot
.45296 .43156 Mdot
.49301 .32 Mdot
.72747 .59675 Mdot
.395 .64486 Mdot
.34965 .52076 Mdot
.69726 .62972 Mdot
.56809 .46043 Mdot
.51628 .70142 Mdot
.62502 .65094 Mdot
.30413 .50041 Mdot
.30326 .53367 Mdot
.31702 .50896 Mdot
.71344 .4535 Mdot
.65628 .61738 Mdot
.32391 .48657 Mdot
.32609 .48954 Mdot
.45466 .36104 Mdot
.47169 .3213 Mdot
.36986 .56066 Mdot
.62939 .57612 Mdot
.72118 .4614 Mdot
.67832 .60287 Mdot
.26346 .25062 Mdot
.51792 .7189 Mdot
.299 .45996 Mdot
.48567 .31496 Mdot
.5333 .90349 Mdot
.5134 .32426 Mdot
.52019 .35785 Mdot
.36517 .52381 Mdot
.73577 .42148 Mdot
.73552 .45371 Mdot
.31682 .53031 Mdot
.30345 .51601 Mdot
.71163 .46963 Mdot
.5315 .52714 Mdot
.3179 .23117 Mdot
.52121 .49058 Mdot
.34607 .51463 Mdot
.22968 .43763 Mdot
.47824 .69202 Mdot
.32691 .57378 Mdot
.53953 .73401 Mdot
.64799 .64227 Mdot
.6671 .65372 Mdot
.47712 .71347 Mdot
.47317 .37453 Mdot
.65794 .59653 Mdot
.45616 .30604 Mdot
.42968 .64662 Mdot
.49341 .6345 Mdot
.53733 .18073 Mdot
.52724 .36826 Mdot
.4541 .26587 Mdot
.44884 .80328 Mdot
.44561 .3671 Mdot
.36917 .41325 Mdot
.74097 .46925 Mdot
.31566 .56976 Mdot
.52108 .6988 Mdot
.23367 .55557 Mdot
.49863 .36769 Mdot
.34182 .51059 Mdot
.51964 .71004 Mdot
.41509 .64904 Mdot
.54548 .58028 Mdot
.45335 .37322 Mdot
.77081 .75695 Mdot
.33892 .49993 Mdot
.67927 .63647 Mdot
.28593 .44143 Mdot
.34478 .57303 Mdot
.57097 .57903 Mdot
.61457 .61255 Mdot
.54112 .46592 Mdot
.32009 .50168 Mdot
.71955 .42036 Mdot
.33724 .54773 Mdot
.72255 .42968 Mdot
.33582 .4897 Mdot
.64087 .62834 Mdot
.49826 .34377 Mdot
.64545 .63311 Mdot
.71381 .47877 Mdot
.67749 .59469 Mdot
.52087 .69848 Mdot
.43473 .60496 Mdot
.48267 .69731 Mdot
.61572 .34924 Mdot
.34579 .30809 Mdot
.47847 .72669 Mdot
.50263 .56978 Mdot
.50766 .39307 Mdot
.37415 .52974 Mdot
.674 .63972 Mdot
.70542 .63623 Mdot
.58693 .44727 Mdot
.31927 .51256 Mdot
.63829 .61748 Mdot
.23383 .44155 Mdot
.67993 .78572 Mdot
.43682 .3934 Mdot
.55329 .79425 Mdot
.32588 .51675 Mdot
.67896 .65758 Mdot
.48815 .48803 Mdot
.30979 .55795 Mdot
.66282 .65134 Mdot
.49208 .72729 Mdot
.50735 .69546 Mdot
.52857 .35182 Mdot
.51583 .68407 Mdot
.687 .64852 Mdot
.38482 .23858 Mdot
.3188 .55048 Mdot
.37756 .64214 Mdot
.73918 .47558 Mdot
.6648 .64018 Mdot
.53551 .36722 Mdot
.38462 .55264 Mdot
.63141 .64098 Mdot
.30986 .7791 Mdot
.18268 .34935 Mdot
.63848 .6159 Mdot
.33352 .55398 Mdot
.34869 .53601 Mdot
.45051 .39604 Mdot
.5706 .45547 Mdot
.64453 .60968 Mdot
.66118 .70272 Mdot
.58709 .2723 Mdot
.4283 .59222 Mdot
.62688 .19575 Mdot
.47655 .38839 Mdot
.46272 .36316 Mdot
.49028 .7346 Mdot
.50779 .34769 Mdot
.30469 .51043 Mdot
.51198 .32309 Mdot
.46839 .6917 Mdot
.69329 .60091 Mdot
.5 .36131 Mdot
.73852 .47393 Mdot
.46943 .69541 Mdot
.46439 .71694 Mdot
.63781 .63643 Mdot
.3066 .5384 Mdot
.33287 .75201 Mdot
.65675 .62671 Mdot
.46531 .35005 Mdot
.44611 .60463 Mdot
.52505 .32858 Mdot
.48088 .59332 Mdot
.29843 .55357 Mdot
.68124 .63739 Mdot
.34817 .58425 Mdot
.50085 .7087 Mdot
.69783 .64162 Mdot
.50283 .40335 Mdot
.67925 .64688 Mdot
.54631 .60863 Mdot
.74504 .52604 Mdot
.31933 .49358 Mdot
.56599 .58538 Mdot
.30479 .54614 Mdot
.42669 .58927 Mdot
.6558 .2908 Mdot
.7237 .46826 Mdot
.69101 .61395 Mdot
.38284 .62127 Mdot
.66214 .64517 Mdot
.50888 .35744 Mdot
.49317 .3904 Mdot
.67434 .60819 Mdot
.7163 .45384 Mdot
.68567 .40058 Mdot
.70751 .426 Mdot
.34876 .55908 Mdot
.54118 .54503 Mdot
.28881 .2286 Mdot
.6931 .58983 Mdot
.48022 .71169 Mdot
.39396 .38514 Mdot
.46205 .39446 Mdot
.52096 .71238 Mdot
.47371 .73491 Mdot
.70731 .44839 Mdot
.66194 .64263 Mdot
.29495 .55399 Mdot
.49592 .68227 Mdot
.38696 .56102 Mdot
.65895 .37074 Mdot
.50506 .4368 Mdot
.58508 .33772 Mdot
.49012 .41571 Mdot
.59745 .4408 Mdot
.47722 .6805 Mdot
.48515 .37366 Mdot
.54125 .40692 Mdot
.50328 .72698 Mdot
.71142 .43789 Mdot
.3254 .59385 Mdot
.63601 .61815 Mdot
.60307 .85613 Mdot
.52514 .36745 Mdot
.49717 .34716 Mdot
.51074 .72422 Mdot
.35221 .4353 Mdot
.35513 .5254 Mdot
.30973 .54434 Mdot
.66878 .62244 Mdot
.52489 .50861 Mdot
.53044 .35847 Mdot
.51933 .38282 Mdot
.64869 .60056 Mdot
.45108 .59836 Mdot
.60978 .18586 Mdot
.49658 .37695 Mdot
.49764 .69731 Mdot
.53213 .61159 Mdot
.48222 .67775 Mdot
.45105 .318 Mdot
.51111 .36461 Mdot
.50274 .40619 Mdot
.52101 .39293 Mdot
.47875 .69568 Mdot
.48718 .41367 Mdot
.53385 .40415 Mdot
.3231 .53342 Mdot
.46801 .37412 Mdot
.5847 .26841 Mdot
.49557 .37257 Mdot
.74198 .47022 Mdot
.48588 .49781 Mdot
.4817 .33616 Mdot
.4667 .3709 Mdot
.59047 .27795 Mdot
.50466 .33893 Mdot
.52013 .70996 Mdot
.3466 .52962 Mdot
.50237 .70925 Mdot
.48525 .71697 Mdot
.63727 .64496 Mdot
.73171 .42609 Mdot
.4909 .42192 Mdot
.70972 .45922 Mdot
.44873 .39785 Mdot
.44258 .43348 Mdot
.62524 .38584 Mdot
.4939 .49091 Mdot
.74958 .47465 Mdot
.51656 .38558 Mdot
.66968 .62863 Mdot
.6815 .63932 Mdot
.55439 .56566 Mdot
.42989 .39922 Mdot
.50956 .68502 Mdot
.47979 .72325 Mdot
.76728 .41265 Mdot
.7482 .51378 Mdot
.722 .4754 Mdot
.64928 .43109 Mdot
.48328 .29954 Mdot
.47173 .36283 Mdot
.41898 .37742 Mdot
.62039 .63059 Mdot
.43269 .60373 Mdot
.65113 .5948 Mdot
.45586 .64064 Mdot
.4814 .68661 Mdot
.52728 .36586 Mdot
.21594 .6846 Mdot
.34669 .56279 Mdot
.34721 .52969 Mdot
.46836 .69128 Mdot
.69521 .61598 Mdot
.431 .40718 Mdot
.53315 .86168 Mdot
.29363 .53678 Mdot
.75907 .45132 Mdot
.49772 .33593 Mdot
.64798 .64101 Mdot
.33297 .56031 Mdot
.75907 .43793 Mdot
.51974 .39279 Mdot
.61058 .61844 Mdot
.4869 .3683 Mdot
.27901 .35868 Mdot
.31865 .54051 Mdot
.6128 .39056 Mdot
.37098 .53645 Mdot
.4817 .69396 Mdot
.50704 .71737 Mdot
.50963 .36706 Mdot
.56557 .86389 Mdot
.3924 .56694 Mdot
.47794 .74015 Mdot
.75051 .43265 Mdot
.44184 .60874 Mdot
.74304 .43035 Mdot
.67499 .61141 Mdot
.7284 .4734 Mdot
.63336 .64208 Mdot
.62673 .5766 Mdot
.29243 .50966 Mdot
.74343 .44135 Mdot
.3725 .37761 Mdot
.44492 .42616 Mdot
.70709 .47105 Mdot
.48373 .32352 Mdot
.43876 .3791 Mdot
.63701 .60909 Mdot
.71238 .46024 Mdot
.46786 .39527 Mdot
.30441 .6352 Mdot
.49927 .72066 Mdot
.51527 .69015 Mdot
.45693 .43301 Mdot
.6616 .66167 Mdot
.3196 .49493 Mdot
.62248 .42617 Mdot
.41971 .57063 Mdot
.52068 .37972 Mdot
.46351 .40765 Mdot
.34856 .50188 Mdot
.3622 .53427 Mdot
.51104 .37004 Mdot
.23342 .48769 Mdot
.49428 .40972 Mdot
.50992 .69873 Mdot
.34907 .55985 Mdot
.34956 .53477 Mdot
.68322 .65059 Mdot
.31256 .55434 Mdot
.5415 .33548 Mdot
.47699 .74686 Mdot
.53376 .39417 Mdot
.49801 .7067 Mdot
.66731 .57473 Mdot
.62668 .62093 Mdot
.37705 .62316 Mdot
.31402 .5545 Mdot
.46508 .31791 Mdot
.33751 .56617 Mdot
.75195 .45723 Mdot
.34932 .52722 Mdot
.35967 .50665 Mdot
.51172 .33176 Mdot
.48297 .40852 Mdot
.44814 .59676 Mdot
.57946 .44987 Mdot
.32375 .54526 Mdot
.443 .34843 Mdot
.49117 .31189 Mdot
.49405 .39307 Mdot
.63142 .40814 Mdot
.36695 .56632 Mdot
.333 .46545 Mdot
.44775 .56939 Mdot
.32004 .54609 Mdot
.19141 .35704 Mdot
.44657 .58993 Mdot
.45425 .59097 Mdot
.47299 .67688 Mdot
.49935 .37798 Mdot
.6466 .62496 Mdot
.4615 .35763 Mdot
.4199 .34204 Mdot
.4848 .33574 Mdot
.74666 .44091 Mdot
.53167 .35697 Mdot
.43265 .59222 Mdot
.65685 .63205 Mdot
.44476 .36061 Mdot
.50339 .36747 Mdot
.45068 .58875 Mdot
.36952 .56414 Mdot
.30464 .54093 Mdot
.4549 .58435 Mdot
.70632 .45933 Mdot
.46685 .71185 Mdot
.46417 .35054 Mdot
.66895 .62513 Mdot
.64838 .63141 Mdot
.35153 .57004 Mdot
.6556 .59945 Mdot
.46689 .70255 Mdot
.51941 .36154 Mdot
.48099 .6948 Mdot
.74716 .44114 Mdot
.33155 .55378 Mdot
.47616 .33331 Mdot
.45643 .36868 Mdot
.31262 .52841 Mdot
.48934 .40973 Mdot
.75394 .4457 Mdot
.62508 .64335 Mdot
.35345 .52964 Mdot
.48645 .71051 Mdot
.67698 .65331 Mdot
.45443 .33696 Mdot
.15728 .44816 Mdot
.50896 .34889 Mdot
.51794 .38833 Mdot
.39988 .54867 Mdot
.48622 .30479 Mdot
.65878 .64477 Mdot
.32882 .56415 Mdot
.44073 .35837 Mdot
.59383 .28022 Mdot
.76226 .42456 Mdot
.65474 .58394 Mdot
.51082 .33796 Mdot
.19201 .4611 Mdot
.4815 .31147 Mdot
.37041 .6209 Mdot
.62493 .38613 Mdot
.55178 .74047 Mdot
.58495 .33768 Mdot
.47392 .73777 Mdot
.45045 .60282 Mdot
.63417 .63851 Mdot
.33402 .42901 Mdot
.5139 .36353 Mdot
.37914 .28037 Mdot
.47281 .33575 Mdot
.50228 .69436 Mdot
.37351 .43059 Mdot
.67193 .60085 Mdot
.61038 .1979 Mdot
.47991 .38757 Mdot
.33788 .50099 Mdot
.64542 .66357 Mdot
.45429 .60213 Mdot
.47984 .40588 Mdot
.71801 .47654 Mdot
.76913 .41802 Mdot
.53786 .32882 Mdot
.498 .70908 Mdot
.47817 .37625 Mdot
.47232 .29322 Mdot
.7294 .7248 Mdot
.32656 .52457 Mdot
.48832 .72267 Mdot
.73762 .51291 Mdot
.49601 .39112 Mdot
.30347 .53448 Mdot
.34237 .52704 Mdot
.7109 .4457 Mdot
.53561 .68708 Mdot
.72282 .40282 Mdot
.191 .61464 Mdot
.41982 .22808 Mdot
.62077 .63358 Mdot
.26867 .53678 Mdot
.46124 .36742 Mdot
.72326 .29649 Mdot
.48365 .71381 Mdot
.4961 .34537 Mdot
.37794 .3027 Mdot
.33277 .51999 Mdot
.48979 .37416 Mdot
.72225 .46212 Mdot
.3831 .79206 Mdot
.24663 .42115 Mdot
.18221 .48916 Mdot
.60747 .6241 Mdot
.5063 .42359 Mdot
.5439 .34743 Mdot
.42035 .57458 Mdot
.44064 .34256 Mdot
.67276 .63916 Mdot
.54677 .62846 Mdot
.72443 .44365 Mdot
.34278 .56369 Mdot
.45289 .59562 Mdot
.47274 .3353 Mdot
.5235 .4171 Mdot
.75456 .44026 Mdot
.48682 .40366 Mdot
.27832 .44875 Mdot
.45853 .61827 Mdot
.66504 .65636 Mdot
.33434 .50171 Mdot
.47917 .41711 Mdot
.44587 .60844 Mdot
.50745 .32899 Mdot
.42882 .26737 Mdot
.48329 .34527 Mdot
.36766 .61047 Mdot
.30964 .52941 Mdot
.49527 .71425 Mdot
.53168 .37267 Mdot
.49088 .36391 Mdot
.64005 .53292 Mdot
.43222 .41031 Mdot
.47192 .34735 Mdot
.34086 .57113 Mdot
.34649 .56366 Mdot
.3492 .51291 Mdot
.6868 .64595 Mdot
.52638 .4858 Mdot
.48892 .69711 Mdot
.42 .37981 Mdot
.49449 .68184 Mdot
.58799 .35339 Mdot
.74423 .43389 Mdot
.36503 .62894 Mdot
.51752 .36815 Mdot
.32029 .50916 Mdot
.34362 .21944 Mdot
.36376 .5677 Mdot
.47338 .75736 Mdot
.48772 .71591 Mdot
.32782 .54037 Mdot
.51033 .34044 Mdot
.56465 .45587 Mdot
.18054 .50531 Mdot
.51494 .6987 Mdot
.47102 .44017 Mdot
.61517 .59829 Mdot
.69648 .60034 Mdot
.20479 .33996 Mdot
.50138 .68628 Mdot
.45039 .80485 Mdot
.45181 .33681 Mdot
.32798 .56203 Mdot
.46937 .71474 Mdot
.50513 .73708 Mdot
.65729 .5982 Mdot
.45319 .36799 Mdot
.49034 .36639 Mdot
.43522 .58361 Mdot
.47415 .70446 Mdot
.50772 .27629 Mdot
.45451 .37778 Mdot
.43644 .64623 Mdot
.29522 .5122 Mdot
.80538 .64343 Mdot
.41369 .46124 Mdot
.37712 .30182 Mdot
.71683 .69844 Mdot
.35589 .53315 Mdot
.47216 .37396 Mdot
.42923 .40322 Mdot
.61803 .63456 Mdot
.51663 .3537 Mdot
.69974 .62329 Mdot
.48819 .68814 Mdot
.30713 .61921 Mdot
.50026 .55698 Mdot
.47982 .6429 Mdot
.50614 .34897 Mdot
.2442 .42986 Mdot
.73871 .44226 Mdot
.45241 .7267 Mdot
.36032 .53442 Mdot
.45356 .31627 Mdot
.61784 .61819 Mdot
.69089 .63938 Mdot
.33437 .525 Mdot
.42308 .75724 Mdot
.36984 .62342 Mdot
.51136 .4052 Mdot
.68407 .61943 Mdot
.44573 .51158 Mdot
.2113 .43125 Mdot
.46293 .69505 Mdot
.72673 .44169 Mdot
.64172 .64234 Mdot
.52551 .69737 Mdot
.44092 .38646 Mdot
.33418 .53512 Mdot
.33607 .49779 Mdot
.56522 .57383 Mdot
.63985 .61814 Mdot
.73278 .46239 Mdot
.55878 .57532 Mdot
.54439 .55072 Mdot
.72513 .45175 Mdot
.70004 .63277 Mdot
.35823 .55248 Mdot
.3289 .5115 Mdot
.3461 .53006 Mdot
.30733 .45689 Mdot
.29768 .5516 Mdot
.72061 .36107 Mdot
.44251 .33629 Mdot
.22313 .44515 Mdot
.4541 .3195 Mdot
.52188 .70259 Mdot
.31709 .54004 Mdot
.62202 .38571 Mdot
.49387 .30091 Mdot
.18582 .5058 Mdot
.47934 .35765 Mdot
.53305 .60235 Mdot
.50027 .3772 Mdot
.27569 .40614 Mdot
.31582 .56892 Mdot
.50563 .40101 Mdot
.47173 .74579 Mdot
.74633 .46034 Mdot
.31633 .48555 Mdot
.47122 .35216 Mdot
.37169 .73404 Mdot
.48253 .32379 Mdot
.31914 .61476 Mdot
.57919 .57503 Mdot
.7053 .47871 Mdot
.52126 .32399 Mdot
.62617 .60703 Mdot
.40386 .33941 Mdot
.22553 .43798 Mdot
.51349 .69658 Mdot
.23983 .43606 Mdot
.67566 .59867 Mdot
.37144 .43027 Mdot
.48671 .29415 Mdot
.72083 .4467 Mdot
.33684 .59654 Mdot
.51309 .70452 Mdot
.51516 .37029 Mdot
.48 .38553 Mdot
.5083 .63498 Mdot
.22746 .4169 Mdot
.48442 .26931 Mdot
.76021 .46097 Mdot
.24488 .4145 Mdot
.47637 .34307 Mdot
.64611 .58555 Mdot
.31164 .55797 Mdot
.37842 .42823 Mdot
.36124 .43494 Mdot
.44985 .37536 Mdot
.32838 .53586 Mdot
.30841 .54925 Mdot
.37845 .19509 Mdot
.73054 .43567 Mdot
.48164 .34739 Mdot
.56966 .58406 Mdot
.46684 .34579 Mdot
.4958 .69271 Mdot
.47832 .30036 Mdot
.62822 .61955 Mdot
.47994 .485 Mdot
.68883 .6439 Mdot
.49911 .39583 Mdot
.33788 .54941 Mdot
.51354 .71591 Mdot
.55008 .76851 Mdot
.53762 .69911 Mdot
.7195 .36152 Mdot
.77997 .42552 Mdot
.72405 .4772 Mdot
.7357 .42838 Mdot
.46121 .68587 Mdot
.51557 .34308 Mdot
.60024 .44319 Mdot
.43137 .38179 Mdot
.49935 .38288 Mdot
.48406 .34187 Mdot
.5149 .77698 Mdot
.48932 .71607 Mdot
.64108 .63331 Mdot
.51159 .3707 Mdot
.44295 .34651 Mdot
.33293 .54686 Mdot
.72277 .47482 Mdot
.64313 .65213 Mdot
.71717 .47951 Mdot
.66211 .63114 Mdot
.28298 .25255 Mdot
.49581 .43932 Mdot
.74681 .45621 Mdot
.4772 .68259 Mdot
.33243 .50784 Mdot
.43802 .5805 Mdot
.67137 .60997 Mdot
.66818 .60053 Mdot
.47227 .41087 Mdot
.32614 .5552 Mdot
.31101 .54875 Mdot
.71263 .47086 Mdot
.479 .72405 Mdot
.46739 .41577 Mdot
.47125 .40254 Mdot
.56376 .75587 Mdot
.62386 .64375 Mdot
.23681 .42567 Mdot
.3994 .5696 Mdot
.52155 .35433 Mdot
.30412 .53215 Mdot
.49655 .35776 Mdot
.45265 .52497 Mdot
.35327 .51512 Mdot
.48127 .30317 Mdot
.42906 .34127 Mdot
.62246 .63468 Mdot
.43969 .17938 Mdot
.48968 .42578 Mdot
.51613 .74804 Mdot
.46561 .38038 Mdot
.5705 .15185 Mdot
.35795 .21293 Mdot
.49611 .32382 Mdot
.52735 .37534 Mdot
.17967 .58665 Mdot
.49244 .31467 Mdot
.43246 .58685 Mdot
.41924 .34328 Mdot
.30466 .52432 Mdot
.55262 .59371 Mdot
.59311 .44365 Mdot
.72833 .43354 Mdot
.66971 .62293 Mdot
.65606 .34689 Mdot
.71842 .43123 Mdot
.32959 .51518 Mdot
.51102 .4297 Mdot
.39833 .56696 Mdot
.70867 .63454 Mdot
.52527 .28827 Mdot
.49872 .69281 Mdot
.5927 .44593 Mdot
.63953 .60118 Mdot
.48538 .7105 Mdot
.48264 .3106 Mdot
.71824 .58981 Mdot
.45863 .73981 Mdot
.39336 .18242 Mdot
.49226 .73401 Mdot
.50087 .71716 Mdot
.54473 .46923 Mdot
.72779 .43352 Mdot
.54409 .63752 Mdot
.4704 .45423 Mdot
.51836 .71058 Mdot
.61716 .22592 Mdot
.61722 .63854 Mdot
.53233 .49699 Mdot
.32646 .57264 Mdot
.48311 .4414 Mdot
.49279 .34155 Mdot
.49177 .73005 Mdot
.27541 .54828 Mdot
.64866 .52567 Mdot
.49482 .68713 Mdot
.52155 .31476 Mdot
.51485 .5062 Mdot
.44075 .60666 Mdot
.44503 .58784 Mdot
.75844 .43865 Mdot
.76584 .55363 Mdot
.30938 .52432 Mdot
.75843 .45479 Mdot
.60809 .36467 Mdot
.47754 .36379 Mdot
.47578 .69718 Mdot
.4529 .59239 Mdot
.48737 .70836 Mdot
.73688 .44859 Mdot
.75208 .43715 Mdot
.32349 .53176 Mdot
.35772 .53203 Mdot
.27647 .58058 Mdot
.56585 .24183 Mdot
.4593 .34637 Mdot
.3561 .28859 Mdot
.36124 .53173 Mdot
.34246 .43624 Mdot
.71466 .44521 Mdot
.71601 .46673 Mdot
.25809 .3403 Mdot
.4541 .34176 Mdot
.53254 .61001 Mdot
.47893 .33816 Mdot
.66252 .26926 Mdot
.47452 .33297 Mdot
.65178 .60006 Mdot
.48001 .39102 Mdot
.30676 .72334 Mdot
.44392 .35271 Mdot
.48636 .33851 Mdot
.65953 .6124 Mdot
.48598 .41958 Mdot
.63186 .61361 Mdot
.47215 .37086 Mdot
.77005 .46934 Mdot
.66861 .62472 Mdot
.75096 .48808 Mdot
.52924 .569 Mdot
.44012 .59132 Mdot
.73091 .43009 Mdot
.72476 .47924 Mdot
.6522 .3828 Mdot
.36101 .55773 Mdot
.39923 .44914 Mdot
.49887 .3364 Mdot
.64251 .65837 Mdot
.47051 .69721 Mdot
.45152 .37883 Mdot
.5209 .32793 Mdot
.47835 .42104 Mdot
.32483 .5353 Mdot
.69241 .64725 Mdot
.74293 .45238 Mdot
.68107 .64136 Mdot
.76489 .47602 Mdot
.62406 .62316 Mdot
.45684 .42713 Mdot
.44618 .3949 Mdot
.5447 .35407 Mdot
.36081 .33538 Mdot
.77358 .33168 Mdot
.33451 .53021 Mdot
.4435 .60337 Mdot
.74599 .43394 Mdot
.54472 .52984 Mdot
.31131 .5167 Mdot
.66338 .60091 Mdot
.48671 .36803 Mdot
.50593 .43748 Mdot
.4559 .44485 Mdot
.3847 .53061 Mdot
.72421 .4935 Mdot
.67021 .61459 Mdot
.42958 .59665 Mdot
.52273 .49133 Mdot
.33948 .47069 Mdot
.618 .35722 Mdot
.49356 .36092 Mdot
.71132 .47025 Mdot
.33319 .56038 Mdot
.52994 .6278 Mdot
.49364 .72841 Mdot
.57476 .45311 Mdot
.50579 .34725 Mdot
.45966 .77347 Mdot
.33922 .54863 Mdot
.71824 .45912 Mdot
.49286 .73025 Mdot
.72379 .43811 Mdot
.45163 .61073 Mdot
.42151 .56618 Mdot
.47823 .40372 Mdot
.47893 .33658 Mdot
.47789 .68993 Mdot
.3081 .5297 Mdot
.7737 .45184 Mdot
.52074 .6398 Mdot
.67582 .61063 Mdot
.52399 .51989 Mdot
.34022 .56288 Mdot
.48949 .7942 Mdot
.68757 .63818 Mdot
.50943 .68273 Mdot
.59931 .43612 Mdot
.4649 .712 Mdot
.47895 .34275 Mdot
.34833 .55033 Mdot
.51138 .69283 Mdot
.57303 .72886 Mdot
.21642 .51451 Mdot
.37113 .59648 Mdot
.50536 .394 Mdot
.34824 .62988 Mdot
.41395 .77293 Mdot
.26375 .52333 Mdot
.49457 .68298 Mdot
.50563 .35813 Mdot
.51006 .40595 Mdot
.48038 .38871 Mdot
.49867 .7231 Mdot
.51967 .78597 Mdot
.68745 .61186 Mdot
.48604 .37642 Mdot
.7424 .47265 Mdot
.6298 .62413 Mdot
.67519 .59018 Mdot
.64347 .64348 Mdot
.36312 .54005 Mdot
.50507 .4354 Mdot
.41499 .37166 Mdot
.40994 .19448 Mdot
.49857 .71585 Mdot
.43977 .59143 Mdot
.51633 .39294 Mdot
.71034 .36642 Mdot
.33259 .50947 Mdot
.66373 .6077 Mdot
.49586 .34681 Mdot
.57313 .57578 Mdot
.45283 .61936 Mdot
.65669 .62021 Mdot
.35755 .52528 Mdot
.26617 .50844 Mdot
.51751 .35653 Mdot
.46163 .37268 Mdot
.31822 .5201 Mdot
.41712 .79265 Mdot
.51765 .49529 Mdot
.49793 .36025 Mdot
.49117 .71449 Mdot
.61493 .83874 Mdot
.4725 .30977 Mdot
.37073 .57908 Mdot
.43016 .60137 Mdot
.40565 .56152 Mdot
.23653 .4651 Mdot
.42303 .37104 Mdot
.2696 .60745 Mdot
.72501 .3869 Mdot
.24389 .57007 Mdot
.68264 .28579 Mdot
.52521 .64628 Mdot
.33366 .20483 Mdot
.51791 .7397 Mdot
.27429 .38658 Mdot
.29019 .76352 Mdot
.44344 .7961 Mdot
.62674 .54608 Mdot
.57084 .68944 Mdot
.70542 .58168 Mdot
.61667 .1923 Mdot
.63205 .60165 Mdot
.6885 .27522 Mdot
.48306 .33102 Mdot
.40802 .78441 Mdot
.26768 .40877 Mdot
.79393 .3752 Mdot
.38467 .62692 Mdot
.56908 .57766 Mdot
.16379 .48351 Mdot
.4083 .63627 Mdot
.21241 .36195 Mdot
.3896 .32349 Mdot
.79067 .57393 Mdot
.54468 .53768 Mdot
.67055 .35358 Mdot
.2472 .44166 Mdot
.28297 .68494 Mdot
.45379 .66168 Mdot
.33418 .26563 Mdot
.74575 .68929 Mdot
.68055 .62896 Mdot
.30724 .55541 Mdot
.56886 .65464 Mdot
.20065 .40829 Mdot
.48983 .75968 Mdot
.26844 .60664 Mdot
.42398 .61395 Mdot
.27457 .40149 Mdot
.6127 .38574 Mdot
.28377 .35069 Mdot
.7178 .40135 Mdot
.62215 .20226 Mdot
.37251 .50867 Mdot
.59045 .70469 Mdot
.55131 .5222 Mdot
.65887 .42983 Mdot
.2861 .42763 Mdot
.76564 .45174 Mdot
.76827 .44916 Mdot
.35474 .51888 Mdot
.20794 .41713 Mdot
.45871 .62204 Mdot
.60575 .35903 Mdot
.62236 .60897 Mdot
.4609 .52917 Mdot
.37552 .78381 Mdot
.41026 .76281 Mdot
.4816 .17679 Mdot
.16431 .43431 Mdot
.62089 .26083 Mdot
.52229 .61934 Mdot
.50368 .76808 Mdot
.69183 .37411 Mdot
.47214 .26262 Mdot
.60219 .23924 Mdot
.42264 .27352 Mdot
.17133 .53495 Mdot
.39115 .72257 Mdot
.15453 .47324 Mdot
.36055 .49771 Mdot
.5415 .40371 Mdot
.48904 .58479 Mdot
.42008 .23629 Mdot
.61954 .3221 Mdot
.16934 .45486 Mdot
.69927 .46045 Mdot
.28563 .5465 Mdot
.44588 .79602 Mdot
.2744 .45011 Mdot
.67306 .4287 Mdot
.79769 .44943 Mdot
.3844 .43388 Mdot
.15196 .51152 Mdot
.27368 .61307 Mdot
.31405 .24767 Mdot
.43766 .65607 Mdot
.69973 .65867 Mdot
.66927 .58929 Mdot
.50095 .73932 Mdot
.19377 .39264 Mdot
.34653 .54337 Mdot
.43077 .17736 Mdot
.25959 .57204 Mdot
.40766 .32226 Mdot
.14947 .52255 Mdot
.5705 .1951 Mdot
.22656 .45744 Mdot
.75053 .34287 Mdot
.5759 .82816 Mdot
.51182 .26013 Mdot
.54048 .70284 Mdot
.63046 .58957 Mdot
.34485 .61425 Mdot
.19056 .40342 Mdot
.60136 .22269 Mdot
.2118 .6652 Mdot
.60359 .35467 Mdot
.73182 .63698 Mdot
.38162 .51324 Mdot
.65534 .54201 Mdot
.65938 .45595 Mdot
.15489 .46842 Mdot
.25319 .40991 Mdot
.6068 .83473 Mdot
.67023 .29206 Mdot
.35525 .43864 Mdot
.33361 .63946 Mdot
.60311 .58951 Mdot
.48544 .24328 Mdot
.38386 .73677 Mdot
.51297 .42001 Mdot
.62638 .35154 Mdot
.38234 .38751 Mdot
.69668 .42635 Mdot
.51826 .48872 Mdot
.39078 .70059 Mdot
.63885 .29459 Mdot
.48748 .80856 Mdot
.38791 .44801 Mdot
.36248 .52092 Mdot
.60494 .24567 Mdot
.64739 .27326 Mdot
.42827 .6915 Mdot
.7386 .51199 Mdot
.30569 .25194 Mdot
.68998 .52182 Mdot
.42134 .35931 Mdot
.27447 .37995 Mdot
.24958 .44239 Mdot
.63469 .23642 Mdot
.46266 .43242 Mdot
.45075 .18759 Mdot
.43966 .63196 Mdot
.34616 .34594 Mdot
.6208 .30148 Mdot
.35625 .33965 Mdot
.20461 .46915 Mdot
.47626 .57304 Mdot
.54325 .74062 Mdot
.28585 .56744 Mdot
.15365 .51132 Mdot
.63464 .63005 Mdot
.59825 .22958 Mdot
.51235 .74432 Mdot
.56632 .74322 Mdot
.54589 .65337 Mdot
.65547 .52417 Mdot
.20475 .35875 Mdot
.43247 .77068 Mdot
.59285 .61591 Mdot
.26234 .66876 Mdot
.43859 .50604 Mdot
.35158 .29648 Mdot
.55708 .37109 Mdot
.42203 .2809 Mdot
.75389 .4451 Mdot
.35559 .39063 Mdot
.45185 .5662 Mdot
.81055 .44584 Mdot
.43006 .38863 Mdot
.55424 .54482 Mdot
.42474 .58567 Mdot
.5809 .46212 Mdot
.28095 .25283 Mdot
.55833 .37259 Mdot
.56813 .19792 Mdot
.43149 .77767 Mdot
.59677 .45202 Mdot
.66036 .44804 Mdot
.40261 .46912 Mdot
.15206 .47904 Mdot
.23143 .30369 Mdot
.37502 .75942 Mdot
.33281 .62903 Mdot
.72697 .23033 Mdot
.55145 .73458 Mdot
.48314 .19153 Mdot
.50617 .74679 Mdot
.88495 .61424 Mdot
.68297 .64209 Mdot
.7282 .29442 Mdot
.41198 .24792 Mdot
.59661 .54453 Mdot
.20119 .41545 Mdot
.25775 .45137 Mdot
.75043 .49744 Mdot
.36768 .52137 Mdot
.44267 .41741 Mdot
.17695 .45138 Mdot
.15787 .50971 Mdot
.17606 .45696 Mdot
.45401 .75891 Mdot
.19637 .49428 Mdot
.16829 .56765 Mdot
.72306 .36102 Mdot
.49323 .62589 Mdot
.48222 .29409 Mdot
.55249 .22772 Mdot
.54267 .19778 Mdot
.69362 .46026 Mdot
.51674 .2627 Mdot
.37284 .50793 Mdot
.15965 .55633 Mdot
.28365 .24858 Mdot
.29094 .32482 Mdot
.22049 .34815 Mdot
.587 .65556 Mdot
.57209 .23547 Mdot
.21769 .33689 Mdot
.2769 .66112 Mdot
.4293 .6358 Mdot
.171 .58853 Mdot
.6505 .28274 Mdot
.57095 .69335 Mdot
.34692 .73652 Mdot
.51912 .19263 Mdot
.32284 .63608 Mdot
.57301 .65975 Mdot
.45709 .25883 Mdot
.36469 .4832 Mdot
.65859 .525 Mdot
.2756 .67751 Mdot
.52663 .61281 Mdot
.60832 .28383 Mdot
.68565 .5978 Mdot
.58868 .22558 Mdot
.64608 .46396 Mdot
.4961 .62744 Mdot
.65361 .35949 Mdot
.60936 .21825 Mdot
.35486 .71481 Mdot
.1861 .47643 Mdot
.43301 .77741 Mdot
.56689 .83622 Mdot
.37945 .65396 Mdot
.38489 .37897 Mdot
.48598 .4199 Mdot
.19674 .41424 Mdot
.21333 .30199 Mdot
.20766 .34841 Mdot
.43693 .74838 Mdot
.60262 .65467 Mdot
.51817 .6857 Mdot
.68075 .3732 Mdot
.611 .53499 Mdot
.40295 .60585 Mdot
.61552 .47273 Mdot
.52133 .73239 Mdot
.3882 .79541 Mdot
.2891 .58855 Mdot
.70799 .36907 Mdot
.32157 .28136 Mdot
.50572 .27183 Mdot
.21273 .42874 Mdot
.34868 .50125 Mdot
.4435 .76219 Mdot
.60052 .23668 Mdot
.6357 .63449 Mdot
.57135 .74585 Mdot
.29033 .56699 Mdot
.53749 .4127 Mdot
.5925 .66156 Mdot
.3809 .59242 Mdot
.3755 .30122 Mdot
.60019 .63731 Mdot
.30694 .22772 Mdot
.46961 .18541 Mdot
.21905 .33359 Mdot
.61674 .25063 Mdot
.5816 .72492 Mdot
.55901 .4748 Mdot
.52744 .75367 Mdot
.39542 .63011 Mdot
.54737 .50877 Mdot
.6185 .24466 Mdot
.22097 .45856 Mdot
.47201 .60902 Mdot
.42029 .37228 Mdot
.33568 .22358 Mdot
.69489 .35416 Mdot
.56333 .47944 Mdot
.39213 .483 Mdot
.29262 .5385 Mdot
.77753 .32457 Mdot
.29743 .70251 Mdot
.40799 .35849 Mdot
.33864 .6338 Mdot
.46009 .69735 Mdot
.35233 .51114 Mdot
.60789 .2144 Mdot
.75527 .52263 Mdot
.2519 .55669 Mdot
.50082 .58225 Mdot
.20239 .39191 Mdot
.51905 .55996 Mdot
.3179 .62637 Mdot
.22647 .57721 Mdot
.63593 .81633 Mdot
.35886 .49744 Mdot
.51283 .61984 Mdot
.55497 .63883 Mdot
.36038 .49077 Mdot
.38445 .53816 Mdot
.24959 .41887 Mdot
.17965 .40592 Mdot
.55174 .57589 Mdot
.26463 .65471 Mdot
.59927 .44569 Mdot
.65212 .53816 Mdot
.48632 .61055 Mdot
.6537 .35108 Mdot
.25546 .6203 Mdot
.26655 .30782 Mdot
.4689 .84288 Mdot
.53325 .27389 Mdot
.71963 .28484 Mdot
.68177 .37424 Mdot
.39013 .32583 Mdot
.28583 .42317 Mdot
.42358 .64627 Mdot
.46392 .35963 Mdot
.16611 .4171 Mdot
.3953 .71509 Mdot
.64241 .40051 Mdot
.63179 .5726 Mdot
.47008 .31603 Mdot
.54345 .35318 Mdot
.21357 .34459 Mdot
.39983 .53265 Mdot
.37882 .83196 Mdot
.67138 .28379 Mdot
.39572 .34352 Mdot
.22615 .46666 Mdot
.564 .19897 Mdot
.47466 .56308 Mdot
.26325 .58175 Mdot
.64839 .47306 Mdot
.54184 .1934 Mdot
.24152 .63156 Mdot
.28442 .70037 Mdot
.3736 .64737 Mdot
.16941 .55968 Mdot
.39533 .39245 Mdot
.44879 .65156 Mdot
.58827 .66532 Mdot
.5218 .38326 Mdot
.42181 .75611 Mdot
.36773 .63631 Mdot
.70574 .55458 Mdot
.47141 .26019 Mdot
.20815 .30669 Mdot
.44845 .2991 Mdot
.42306 .73592 Mdot
.35729 .8134 Mdot
.43742 .86304 Mdot
.29905 .7174 Mdot
.15499 .46433 Mdot
.27192 .68677 Mdot
.31315 .62908 Mdot
.46341 .68673 Mdot
.53533 .54193 Mdot
.37108 .28147 Mdot
.18023 .3895 Mdot
.78042 .5385 Mdot
.53535 .67922 Mdot
.36228 .25185 Mdot
.17779 .39089 Mdot
.43102 .32341 Mdot
.75471 .30348 Mdot
.68629 .66523 Mdot
.59959 .18163 Mdot
.49481 .17843 Mdot
.37994 .47661 Mdot
.62638 .22487 Mdot
.72767 .27731 Mdot
.7759 .37371 Mdot
.47831 .18836 Mdot
.47376 .2325 Mdot
.39858 .50181 Mdot
.60975 .25458 Mdot
.35384 .6187 Mdot
.66705 .202 Mdot
.48894 .60647 Mdot
.45049 .62552 Mdot
.41783 .56276 Mdot
.3432 .61329 Mdot
.35376 .699 Mdot
.50742 .60283 Mdot
.47333 .4923 Mdot
.20912 .4567 Mdot
.63975 .83669 Mdot
.2554 .68465 Mdot
.29851 .58454 Mdot
.16258 .50577 Mdot
.43092 .65336 Mdot
.55907 .50837 Mdot
.29115 .43574 Mdot
.68729 .36193 Mdot
.59242 .62687 Mdot
.48453 .3354 Mdot
.17782 .4101 Mdot
.59324 .62504 Mdot
.17004 .48422 Mdot
.40137 .17848 Mdot
.23092 .34218 Mdot
.55702 .33695 Mdot
.63787 .58506 Mdot
.56287 .21171 Mdot
.56462 .21536 Mdot
.18064 .53412 Mdot
.704 .2697 Mdot
.53583 .51265 Mdot
.52081 .58306 Mdot
.50007 .56212 Mdot
.40627 .3867 Mdot
.55695 .19489 Mdot
.40947 .47787 Mdot
.62891 .31179 Mdot
.35683 .75107 Mdot
.61292 .23037 Mdot
.23622 .45595 Mdot
.67154 .36759 Mdot
.68146 .51516 Mdot
.75655 .49233 Mdot
.62552 .6465 Mdot
.19299 .63312 Mdot
.40751 .65995 Mdot
.44093 .1888 Mdot
.5712 .83334 Mdot
.38752 .73717 Mdot
.68585 .26872 Mdot
.46634 .60801 Mdot
.51904 .25634 Mdot
.78633 .56246 Mdot
.6468 .3078 Mdot
.24069 .42694 Mdot
.36362 .62167 Mdot
.35935 .46049 Mdot
.19457 .3731 Mdot
.61188 .29075 Mdot
.24532 .72446 Mdot
.66776 .68479 Mdot
.35585 .38375 Mdot
.2227 .40335 Mdot
.54027 .83907 Mdot
.56934 .47565 Mdot
.15376 .51393 Mdot
.36091 .5733 Mdot
.16398 .4383 Mdot
.48415 .73347 Mdot
.73538 .59739 Mdot
.4198 .62351 Mdot
.64305 .41145 Mdot
.63709 .41977 Mdot
.36334 .20293 Mdot
.43959 .78691 Mdot
.41088 .76635 Mdot
.69104 .52328 Mdot
.65075 .59372 Mdot
.50576 .52585 Mdot
.26854 .65136 Mdot
.19887 .64016 Mdot
.45972 .40506 Mdot
.71385 .67265 Mdot
.58617 .2098 Mdot
.52746 .75491 Mdot
.43013 .61681 Mdot
.39935 .61826 Mdot
.24718 .51956 Mdot
.56886 .23629 Mdot
.16542 .55347 Mdot
.4067 .59984 Mdot
.61899 .51955 Mdot
.36446 .42425 Mdot
.46695 .63415 Mdot
.5039 .80909 Mdot
.26625 .6165 Mdot
.50987 .56945 Mdot
.52199 .49515 Mdot
.62417 .26198 Mdot
.2606 .24627 Mdot
.16551 .52339 Mdot
.53317 .81955 Mdot
.59815 .45447 Mdot
.36139 .57993 Mdot
.6582 .33233 Mdot
.23927 .71849 Mdot
.60376 .17903 Mdot
.35672 .73638 Mdot
.60895 .22849 Mdot
.67543 .55267 Mdot
.73761 .29444 Mdot
.55593 .4956 Mdot
.22368 .4009 Mdot
.40155 .24392 Mdot
.42851 .56618 Mdot
.59417 .59777 Mdot
.61406 .43062 Mdot
.50656 .63906 Mdot
.39882 .49886 Mdot
.44176 .78718 Mdot
.24648 .72565 Mdot
.69525 .25806 Mdot
.37234 .4339 Mdot
.26341 .73514 Mdot
.29782 .50423 Mdot
.55773 .64147 Mdot
.52989 .80201 Mdot
.60518 .44786 Mdot
.66761 .64829 Mdot
.46359 .27024 Mdot
.51225 .51039 Mdot
.25568 .66728 Mdot
.69321 .57056 Mdot
.71382 .43136 Mdot
.3811 .54565 Mdot
.71656 .27149 Mdot
.32505 .49408 Mdot
.28652 .23026 Mdot
.27888 .65948 Mdot
.21885 .44671 Mdot
.23148 .63366 Mdot
.60516 .6981 Mdot
.57278 .83854 Mdot
.21404 .35917 Mdot
.59335 .2806 Mdot
.37899 .5346 Mdot
.34329 .49499 Mdot
.24051 .62264 Mdot
.47522 .77247 Mdot
.20778 .38945 Mdot
.57586 .19816 Mdot
.58474 .7263 Mdot
.2994 .52441 Mdot
.52631 .58914 Mdot
.29652 .58076 Mdot
.29298 .23693 Mdot
.67595 .64346 Mdot
.14904 .50054 Mdot
.40357 .46034 Mdot
.47308 .82514 Mdot
.38118 .60421 Mdot
.48626 .48208 Mdot
.57308 .4789 Mdot
.57657 .71585 Mdot
.41944 .35984 Mdot
.39601 .34593 Mdot
.36041 .53935 Mdot
.54105 .65274 Mdot
.72414 .4738 Mdot
.78986 .47929 Mdot
.52241 .74881 Mdot
.38288 .33031 Mdot
.54253 .18617 Mdot
.34543 .4986 Mdot
.64775 .68305 Mdot
.65587 .69298 Mdot
.42925 .34603 Mdot
.52277 .22037 Mdot
.18458 .60549 Mdot
.2139 .36533 Mdot
.36415 .56956 Mdot
.5328 .828 Mdot
.73962 .40705 Mdot
.31706 .22332 Mdot
.25882 .51286 Mdot
.57689 .20975 Mdot
.37777 .38047 Mdot
.23506 .30789 Mdot
.23676 .4647 Mdot
.2981 .60341 Mdot
.60703 .2435 Mdot
.64723 .528 Mdot
.6052 .21833 Mdot
.24634 .51851 Mdot
.50595 .55059 Mdot
.60062 .18493 Mdot
.6726 .55557 Mdot
.28163 .35665 Mdot
.42746 .30173 Mdot
.37827 .60324 Mdot
.55511 .20055 Mdot
.38109 .5557 Mdot
.76041 .42985 Mdot
.33981 .27105 Mdot
.4239 .63086 Mdot
.19306 .39925 Mdot
.42741 .69451 Mdot
.58882 .20661 Mdot
.4967 .557 Mdot
.69633 .3327 Mdot
.40554 .46145 Mdot
.60759 .33121 Mdot
.53746 .35279 Mdot
.38194 .39948 Mdot
.62585 .4757 Mdot
.37123 .20694 Mdot
.39967 .36664 Mdot
.18407 .43195 Mdot
.30102 .24026 Mdot
.23362 .56237 Mdot
.54284 .62337 Mdot
.30128 .54092 Mdot
.15431 .49209 Mdot
.53242 .21512 Mdot
.36958 .61428 Mdot
.50073 .17918 Mdot
.7756 .31992 Mdot
.27855 .7533 Mdot
.40858 .6918 Mdot
.38501 .59088 Mdot
.43777 .17991 Mdot
.39583 .72162 Mdot
.7414 .2879 Mdot
.24311 .42279 Mdot
.39954 .55081 Mdot
.14924 .52856 Mdot
.43471 .23078 Mdot
.40316 .76071 Mdot
.22262 .41644 Mdot
.24839 .53993 Mdot
.52118 .2125 Mdot
.41676 .37073 Mdot
.62518 .61187 Mdot
.58303 .55645 Mdot
.632 .22938 Mdot
.25623 .53268 Mdot
.57113 .20257 Mdot
.57794 .21339 Mdot
.69758 .28167 Mdot
.58093 .71715 Mdot
.27955 .7538 Mdot
.22577 .48581 Mdot
.53897 .39408 Mdot
.3809 .56335 Mdot
.72904 .42669 Mdot
.67429 .29841 Mdot
.44589 .35939 Mdot
.59979 .41709 Mdot
.38232 .41959 Mdot
.17191 .40517 Mdot
.6776 .53134 Mdot
.45862 .65569 Mdot
.29896 .5394 Mdot
.35258 .61379 Mdot
.45554 .54599 Mdot
.44299 .79713 Mdot
.56202 .20581 Mdot
.2508 .55786 Mdot
.2756 .60631 Mdot
.39694 .75353 Mdot
.62459 .2781 Mdot
.73536 .39869 Mdot
.51406 .69271 Mdot
.37612 .29133 Mdot
.19207 .55472 Mdot
.40557 .74351 Mdot
.28783 .54722 Mdot
.33312 .71617 Mdot
.50981 .55137 Mdot
.43874 .69239 Mdot
.43672 .78401 Mdot
.46766 .58268 Mdot
.24858 .33581 Mdot
.23928 .59256 Mdot
.6125 .60111 Mdot
.6568 .27682 Mdot
.30218 .69782 Mdot
.56603 .20297 Mdot
.43109 .33522 Mdot
.19109 .43181 Mdot
.64074 .40501 Mdot
.71878 .41208 Mdot
.46499 .38613 Mdot
.42893 .25516 Mdot
.21302 .3445 Mdot
.33624 .73273 Mdot
.47106 .25139 Mdot
.29736 .5627 Mdot
.47053 .18295 Mdot
.59482 .63833 Mdot
.59872 .64141 Mdot
.74739 .32718 Mdot
.4657 .47533 Mdot
.60744 .53434 Mdot
.52995 .77154 Mdot
.42328 .34394 Mdot
.75309 .40035 Mdot
.5059 .58001 Mdot
.37216 .29647 Mdot
.48174 .19447 Mdot
.19043 .62069 Mdot
.49216 .57437 Mdot
.48313 .17505 Mdot
.39208 .25217 Mdot
.39622 .53793 Mdot
.70393 .26159 Mdot
.51303 .26337 Mdot
.45746 .43026 Mdot
.75982 .42937 Mdot
.28695 .52525 Mdot
.18892 .60326 Mdot
.4363 .27302 Mdot
.67863 .44754 Mdot
.67516 .49357 Mdot
.49541 .59129 Mdot
.7262 .6931 Mdot
.4413 .63273 Mdot
.44008 .17847 Mdot
.60122 .23713 Mdot
.53361 .69588 Mdot
.25967 .66777 Mdot
.49288 .25371 Mdot
.1878 .4342 Mdot
.63256 .49089 Mdot
.20496 .37387 Mdot
.44715 .74573 Mdot
.37237 .321 Mdot
.31939 .23223 Mdot
.6255 .33977 Mdot
.60868 .33863 Mdot
.39322 .47162 Mdot
.56656 .2859 Mdot
.43972 .58101 Mdot
.73545 .52127 Mdot
.65531 .20301 Mdot
.21834 .68188 Mdot
.46073 .81668 Mdot
.44139 .29679 Mdot
.65438 .32677 Mdot
.24008 .60298 Mdot
.55483 .51433 Mdot
.6606 .47195 Mdot
.60168 .67398 Mdot
.59174 .60752 Mdot
.62068 .83656 Mdot
.16885 .4136 Mdot
.46332 .38261 Mdot
.63774 .44137 Mdot
.80162 .44798 Mdot
.69919 .62756 Mdot
.31071 .28588 Mdot
.1841 .59672 Mdot
.51824 .70233 Mdot
.56728 .80409 Mdot
.53925 .75624 Mdot
.36813 .20253 Mdot
.54703 .79482 Mdot
.44967 .72265 Mdot
.28528 .23053 Mdot
.37363 .75493 Mdot
.33444 .46832 Mdot
.62839 .83365 Mdot
.34933 .21602 Mdot
.38091 .37999 Mdot
.59273 .64285 Mdot
.17566 .42642 Mdot
.57013 .48033 Mdot
.58484 .63913 Mdot
.44525 .22033 Mdot
.60679 .23887 Mdot
.66626 .28197 Mdot
.48855 .65915 Mdot
.38077 .24774 Mdot
.82239 .38029 Mdot
.6091 .69896 Mdot
.52255 .85888 Mdot
.21961 .35982 Mdot
.20477 .54526 Mdot
.29522 .71136 Mdot
.70993 .55071 Mdot
.19584 .42411 Mdot
.57828 .22007 Mdot
.43079 .24601 Mdot
.76327 .53582 Mdot
.63386 .35286 Mdot
.67693 .35023 Mdot
.43989 .69232 Mdot
.22854 .32953 Mdot
.58551 .71067 Mdot
.51298 .2443 Mdot
.59657 .22224 Mdot
.4007 .25386 Mdot
.60562 .33269 Mdot
.19237 .54304 Mdot
.51707 .21605 Mdot
.62659 .252 Mdot
.57367 .67758 Mdot
.76934 .45382 Mdot
.18948 .58869 Mdot
.43478 .51793 Mdot
.37784 .39303 Mdot
.36203 .81745 Mdot
.15586 .47059 Mdot
.51472 .26338 Mdot
.48058 .3002 Mdot
.33826 .20113 Mdot
.67203 .68033 Mdot
.47639 .19534 Mdot
.36419 .77302 Mdot
.67423 .27992 Mdot
.3992 .404 Mdot
.47598 .32929 Mdot
.72756 .34442 Mdot
.38258 .50404 Mdot
.40347 .24677 Mdot
.55642 .77551 Mdot
.62097 .249 Mdot
.38456 .33433 Mdot
.46778 .84239 Mdot
.25414 .50949 Mdot
.31111 .5083 Mdot
.17414 .4194 Mdot
.32877 .25374 Mdot
.38945 .3559 Mdot
.21501 .40847 Mdot
.62706 .50193 Mdot
.75461 .40158 Mdot
.40243 .44984 Mdot
.56188 .47347 Mdot
.63269 .22706 Mdot
.2629 .73668 Mdot
.36498 .29012 Mdot
.14855 .50931 Mdot
.22524 .31271 Mdot
.30582 .51234 Mdot
.42316 .24004 Mdot
.60553 .45439 Mdot
.2426 .57417 Mdot
.56831 .71645 Mdot
.57129 .73912 Mdot
.80837 .37583 Mdot
.79732 .46842 Mdot
.49517 .32493 Mdot
.45209 .75823 Mdot
.19623 .3732 Mdot
.80161 .36112 Mdot
.19163 .38431 Mdot
.38488 .40101 Mdot
.49 .41941 Mdot
.44406 .86669 Mdot
.31313 .62702 Mdot
.46301 .42094 Mdot
.41571 .40719 Mdot
.40946 .38607 Mdot
.47007 .34778 Mdot
.47755 .77663 Mdot
.6901 .368 Mdot
.66507 .26783 Mdot
.18156 .42047 Mdot
.29521 .52366 Mdot
.57717 .47419 Mdot
.49731 .74552 Mdot
.61857 .41275 Mdot
.58629 .36683 Mdot
.46061 .71754 Mdot
.66457 .25828 Mdot
.71317 .69699 Mdot
.66729 .42936 Mdot
.38225 .59735 Mdot
.4611 .48151 Mdot
.26836 .57558 Mdot
.68153 .25678 Mdot
.51534 .7801 Mdot
.77683 .37608 Mdot
.59258 .2109 Mdot
.37537 .45618 Mdot
.44274 .65829 Mdot
.73307 .2406 Mdot
.56269 .48291 Mdot
.46205 .7687 Mdot
.5438 .28769 Mdot
.30461 .47547 Mdot
.22805 .36243 Mdot
.76973 .41741 Mdot
.42248 .57977 Mdot
.36922 .42222 Mdot
.20062 .41493 Mdot
.46732 .69328 Mdot
.24085 .26648 Mdot
.55844 .31089 Mdot
.3062 .29605 Mdot
.20966 .5071 Mdot
.51597 .62411 Mdot
.2418 .43087 Mdot
.5388 .35694 Mdot
.6046 .51804 Mdot
.71256 .69388 Mdot
.34 .59444 Mdot
.48544 .61294 Mdot
.24681 .58987 Mdot
.71324 .28217 Mdot
.2704 .31167 Mdot
.48201 .34924 Mdot
.70292 .45437 Mdot
.57401 .46147 Mdot
.71035 .54457 Mdot
.73125 .63758 Mdot
.43219 .63549 Mdot
.67948 .25835 Mdot
.67132 .2846 Mdot
.22896 .41665 Mdot
.16743 .46908 Mdot
.42512 .30361 Mdot
.22631 .35252 Mdot
.66536 .50991 Mdot
.3622 .69965 Mdot
.52579 .22116 Mdot
.25812 .72961 Mdot
.39355 .3813 Mdot
.41441 .33898 Mdot
.24373 .27935 Mdot
.21577 .35115 Mdot
.49532 .6469 Mdot
.34991 .62327 Mdot
.63742 .19793 Mdot
.63786 .42076 Mdot
.63069 .83684 Mdot
.56682 .72775 Mdot
.2684 .25024 Mdot
.48114 .6233 Mdot
.54202 .29061 Mdot
.40063 .46988 Mdot
.44091 .41307 Mdot
.64983 .62405 Mdot
.22885 .56349 Mdot
.39194 .47343 Mdot
.58094 .30951 Mdot
.54217 .37981 Mdot
.5713 .62739 Mdot
.37635 .57763 Mdot
.22251 .68985 Mdot
.70393 .60801 Mdot
.62001 .51633 Mdot
.43047 .8241 Mdot
.7136 .69443 Mdot
.76397 .30485 Mdot
.17752 .52813 Mdot
.396 .62853 Mdot
.50733 .57701 Mdot
.72215 .73467 Mdot
.36719 .57428 Mdot
.38878 .55113 Mdot
.52774 .74829 Mdot
.70361 .33792 Mdot
.42306 .7439 Mdot
.31149 .77998 Mdot
.23698 .30321 Mdot
.43064 .33806 Mdot
.63203 .8555 Mdot
.59271 .21645 Mdot
.60905 .48656 Mdot
.42654 .7498 Mdot
.18151 .40544 Mdot
.62998 .57246 Mdot
.3946 .18236 Mdot
.28387 .68256 Mdot
.25665 .52203 Mdot
.69683 .34912 Mdot
.53551 .82606 Mdot
.52408 .59513 Mdot
.52513 .85842 Mdot
.34645 .63976 Mdot
.66967 .35298 Mdot
.32913 .7288 Mdot
.36917 .51072 Mdot
.3972 .34557 Mdot
.28244 .655 Mdot
.49131 .26312 Mdot
.26842 .52571 Mdot
.27324 .61133 Mdot
.70746 .40019 Mdot
.5548 .6809 Mdot
.3134 .62259 Mdot
.51337 .76329 Mdot
.37731 .47096 Mdot
.63221 .20676 Mdot
.70948 .67207 Mdot
.69 .60143 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000;Oooooo0_l0002Aooooo`007?ooool00ol0003oooooooooo`2fooooo`;o0000TOooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2hooooo`Co
0000SOooool001cooooo00?o0000ooooooooool0^?ooool4o`0008gooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0__ooool2o`0008Wooooo000Loooo
o`03o`000?oooooooooo09Wooooo0_l0000Rooooo`?o0000ROooool001cooooo00?o0000oooooooo
ool0Ooooool2o`0000Oooooo0_l000000ooooooo0000o`00000<ooooo`;o00000_ooool3o`0001go
oooo1?l00028ooooo`007?ooool00ol0003oooooooooo`1oooooo`;o00001oooool5o`0000cooooo
0_l00002ooooo`Co00002_ooool2o`0001;ooooo0ol00027ooooo`007?ooool00ol0003ooooooooo
o`1looooo`;o00003?ooool3o`0000Sooooo0_l00008ooooo`;o00002_ooool2o`0001;ooooo0ol0
0027ooooo`007?ooool00ol0003oooooooooo`1looooo`;o00004Oooool2o`0000Cooooo0_l0000E
ooooo`;o00004Oooool2o`000003ooooool0003o000008Gooooo000Looooo`03o`000?oooooooooo
06oooooo0_l000000ooooooo0000o`000002o`0001Gooooo0_l00002ooooo`;o00001?ooool2o`00
0003ooooool0003o000001;ooooo0_l0000Aooooo`;o000000?oooooo`000?l00000QOooool00006
ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooo
oooo06oooooo0_l000000ooooooo0000o`000002o`0000gooooo0_l00002ooooo`?o000000?ooooo
o`000?l000002?ooool6o`0000[ooooo0_l00005ooooo`;o00005oooool2o`0008;ooooo00001_oo
ooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1_ooool00ol0003oooooooooo`1gooooo`;o00002?ooool4o`0000;ooooo0ol000000ooooooo0000
o`000005ooooo`Wo00002_ooool2o`0000Gooooo0_l00003ooooo`;o00000oooool2o`000004oooo
ool0003o0000o`0000Kooooo0_l000000ooooooo0000o`000004o`000003ooooool0003o000007_o
oooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h0
1oooool00ol0003oooooooooo`1gooooo`;o00001oooool3o`0000oooooo1?l000000ooooooo0000
o`000002o`0001;ooooo0_l00002ooooo`_o00001_ooool2o`0000?ooooo2?l0001jooooo`0000?o
ooooo`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0
001Zooooo`;o00001_ooool4o`0000[ooooo0_l0000?ooooo`;o00006_ooool2o`0000;ooooo2?l0
0009ooooo`;o00000_ooool4o`000003ooooool0003o000000Ko00000_ooool2o`0007;ooooo0000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool0
0ol0003oooooooooo`1Yooooo`?o00001_ooool4o`0001_ooooo0_l0000Nooooo`Oo00001Oooool2
o`0000Oooooo0_l00007ooooo`Co00000_ooool2o`0007;ooooo00000ooooooo410@ooooo`02oooo
o`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Yoooo
o`;o00002_ooool2o`00027ooooo0_l0000Fooooo`;o000000?oooooo`000?l000001_ooool5o`00
00[ooooo0_l0001mooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`1eooooo`;o00008Oooool2o`0001Kooooo0_l0
00000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000001_l00007ooooo`;o00004_oo
ool2o`0006Wooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c006ooooo`03o`000?oooooooooo077ooooo0_l0000cooooo`;o000000?oooooo`000?l0
00000_l00006ooooo`?o00000_ooool2o`000003ooooool0003o000000Oo000000?oooooo`000?l0
00005oooool2o`0006Wooooo000Looooo`03o`000?oooooooooo06kooooo0_l000000ooooooo0000
o`00000`ooooo`[o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo
0ol000000ooooooo0000o`000022ooooo`007?ooool00ol0003oooooooooo`1/ooooo`Co00005Ooo
ool2o`0000Kooooo0_l0000Dooooo`So00001?ooool2o`0000Oooooo0_l00003ooooo`;o00000_oo
ool3o`0001cooooo0_l0001Wooooo`007?ooool00ol0003oooooooooo`1Sooooo`;o00000oooool3
o`000003ooooool0003o000001Oooooo0_l00005ooooo`?o00005oooool5o`0000gooooo0_l00004
ooooo`Co00000oooool2o`0001Wooooo0_l0001Wooooo`007?ooool00ol0003oooooooooo`1Poooo
o`;o000000Coooooo`000?l0003ooooo1Ol0000Fooooo`;o000000?oooooo`000?l000001_ooool2
o`0002;ooooo0_l00009ooooo`;o000000?oooooo`000?l000000_l00003ooooo`Oo0000OOooool0
01cooooo00?o0000ooooooooool0FOooool3o`0000;ooooo1?l00004ooooo`Go00003Oooool2o`00
0003ooooool0003o000000Cooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00007oooool2
o`0000Cooooo0ol00008ooooo`;o00000_ooool2o`000003ooooool0003o000000So00007?ooool2
o`0005oooooo000Looooo`03o`000?oooooooooo05Wooooo0ol00002ooooo`;o00001?ooool2o`00
01;ooooo0_l000000ooooooo0000o`000006ooooo`Co00000_ooool2o`0000?ooooo0_l00006oooo
o`;o00004_ooool3o`0000Cooooo0_l0000<ooooo`;o000000Goooooo`000?l0003o0000ooooo`02
o`0000;ooooo0_l0000Looooo`;o0000Goooool001cooooo00?o0000ooooooooool0Foooool2o`00
00Oooooo0_l0000Mooooo`Co00001oooool2o`0000Kooooo0_l0000Cooooo`;o00002?ooool4o`00
00Kooooo0_l00004ooooo`Co000000?oooooo`000?l00000OOooool001cooooo00?o0000oooooooo
ool0Foooool2o`0001cooooo0_l0000:ooooo`?o00001oooool2o`0000Gooooo0_l0000Gooooo`;o
00000oooool5o`0000Kooooo1?l00002ooooo`Co000000?oooooo`000?l00000OOooool001cooooo
00?o0000ooooooooool0G_ooool2o`0001Sooooo1?l00002ooooo`;o00001Oooool3o`0000?ooooo
0_l00002ooooo`;o00007_ooool2o`000003ooooool0003o000000;o00001Oooool2o`0000?ooooo
0ol00002ooooo`;o00008oooool2o`0005gooooo000Looooo`03o`000?oooooooooo05kooooo0_l0
000Gooooo`[o00001?ooool2o`000004ooooool0003o0000ooooo`;o00003Oooool2o`0000Oooooo
0_l0000=ooooo`Co00001Oooool2o`0000Cooooo0_l00002ooooo`;o00001oooool2o`0001[ooooo
0_l0001Mooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o00001Oooool2o`0000Sooooo0_l0
000=ooooo`;o00001?ooool3o`0000;ooooo0_l000001?oooooo0000o`000?ooool3o`0000?ooooo
0_l0000@ooooo`;o00001oooool2o`00017ooooo0_l00009ooooo`;o00000_ooool3o`0000Kooooo
0_l0001iooooo`007?ooool2o`0005;ooooo1?l00003ooooo`?o00001Oooool4o`0000gooooo0ol0
0004ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`?o00004?ooool2o`0001oooooo
0_l0000=ooooo`Go00008oooool2o`0005[ooooo000Looooo`03o`000?oooooooooo05;ooooo0ol0
0003ooooo`?o00001Oooool4o`0000?ooooo0_l00009ooooo`;o00000_ooool4o`0000;ooooo1?l0
0008ooooo`;o00001oooool2o`0000;ooooo0_l00005ooooo`;o00009?ooool2o`000004ooooool0
003o0000ooooo`;o00008oooool2o`0005[ooooo000Looooo`03o`000?oooooooooo05Kooooo1?l0
0008ooooo`;o00000_ooool3o`0000Oooooo0_l00004ooooo`;o00001_ooool2o`0000Sooooo0_l0
0007ooooo`Co00001oooool2o`0000Oooooo0_l000000ooooooo0000o`00000@ooooo`;o00001_oo
ool2o`00013ooooo0_l00003ooooo`?o00000_ooool2o`0006Wooooo000Looooo`03o`000?oooooo
oooo04cooooo0_l00008ooooo`;o00003_ooool3o`0000Oooooo0_l0000Oooooo`Ko00002?ooool2
o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000000oooool2o`0000Wooooo1?l0
000:ooooo`;o00003?ooool2o`0000?ooooo0ol00002ooooo`;o000000?oooooo`000?l00000I_oo
ool001cooooo00?o0000ooooooooool0C?ooool2o`0004?ooooo0ol000001?oooooo0000o`000?l0
0004ooooo`;o000000Coooooo`000?l0003ooooo1?l00005ooooo`Co00002Oooool4o`0000[ooooo
0ol0000Hooooo`;o0000I_ooool001cooooo00?o0000ooooooooool0Boooool2o`0001cooooo0_l0
000Mooooo`;o00001_ooool4o`0000;ooooo0_l00004ooooo`;o00001Oooool3o`0000Gooooo0_l0
000=ooooo`Co00002Oooool2o`00083ooooo000Looooo`03o`000?oooooooooo04_ooooo0_l0000A
ooooo`;o00002Oooool2o`0001gooooo0_l00002ooooo`;o00000_ooool5o`0000Gooooo1?l0000<
ooooo`Co00003?ooool4o`0001Gooooo0ol00005ooooo`;o00001?ooool2o`0006Kooooo000Loooo
o`03o`000?oooooooooo05kooooo0_l00006ooooo`;o00000oooool2o`0001Wooooo0_l00002oooo
o`Co00001?ooool3o`0000Gooooo1?l00003ooooo`;o00000oooool2o`000003ooooool0003o0000
00?o00003?ooool3o`0001;ooooo0_l00002ooooo`?o00001Oooool2o`0000Cooooo0_l00002oooo
o`;o0000H_ooool001cooooo00?o0000ooooooooool0I_ooool2o`0000?ooooo0_l0000Hooooo`?o
00000_ooool2o`0000;ooooo0_l0000<ooooo`;o00000oooool2o`0000?ooooo0_l000000ooooooo
0000o`00000@ooooo`;o00004_ooool2o`000003ooooool0003o000000;o00001_ooool2o`0000Oo
oooo0_l0001Rooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o0000>?ooool2o`0000Cooooo
0_l000000ooooooo0000o`00000Aooooo`;o00006Oooool2o`0000Wooooo0_l00009ooooo`Co0000
00?oooooo`000?l000000oooool2o`0000Wooooo1?l0001Nooooo`007?ooool00ol0003ooooooooo
o`1;ooooo`;o00006?ooool2o`0000kooooo1?l0000<ooooo`;o00000oooool3o`000003ooooool0
003o000001;ooooo0ol00003ooooo`;o00004_ooool3o`0000Cooooo0_l00002ooooo`;o00001ooo
ool2o`0000?ooooo1?l00006ooooo`;o00000oooool2o`000003ooooool0003o000000;o0000G_oo
ool001cooooo00?o0000ooooooooool0HOooool2o`0000;ooooo0_l0000<ooooo`Oo00002oooool2
o`0000?ooooo0_l0000Fooooo`?o000000?oooooo`000?l000001?l00008ooooo`;o00001_ooool3
o`0000?ooooo0ol0000;ooooo`;o00000oooool3o`0000;ooooo0_l00003ooooo`;o00000oooool4
o`00067ooooo000Looooo`03o`000?oooooooooo067ooooo0_l0000=ooooo`Go00000_ooool3o`00
01Sooooo1?l00008ooooo`;o00001_ooool3o`000004ooooool0003o0000ooooo`;o00001Oooool2
o`0000Kooooo0ol00003ooooo`;o00004_ooool2o`0000;ooooo0_l0000:ooooo`;o00001Oooool2
o`0005[ooooo000Looooo`03o`000?oooooooooo073ooooo1Ol000001?oooooo0000o`000?l0000G
ooooo`Ko00002?ooool2o`0000Oooooo0ol00002ooooo`?o00003oooool2o`0000?ooooo0_l0000<
ooooo`;o00000oooool2o`0001Gooooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`1coooo
o`;o000000Coooooo`000?l0003o00005oooool2o`0000Cooooo1ol000000ooooooo0000o`000008
ooooo`;o00000_ooool2o`0000Kooooo0_l00008ooooo`;o000000?oooooo`000?l000000_l00007
ooooo`;o00000oooool3o`0000;ooooo0_l0000Aooooo`;o000000?oooooo`000?l00000Foooool0
01cooooo00?o0000ooooooooool0H?ooool2o`0000cooooo0_l00005ooooo`Co00003Oooool2o`00
00Cooooo0_l00002ooooo`;o00001?ooool7o`0000Gooooo0_l0000@ooooo`;o00002?ooool2o`00
0003ooooool0003o000000Wooooo0_l00004ooooo`Co000000?oooooo`000?l000003_ooool4o`00
0003ooooool0003o000005_ooooo000Looooo`;o0000HOooool2o`0000_ooooo0ol00005ooooo`Co
00003Oooool5o`000003ooooool0003o000000Co00000_ooool;o`0000;ooooo1Ol00008ooooo`;o
00001?ooool2o`0000Sooooo0ol00002ooooo`;o000000?oooooo`000?l000003?ooool5o`0000go
oooo1?l0001Oooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00000oooool4o`0002;ooooo
0_l00007ooooo`?o00003Oooool5o`0000?ooooo0_l00004ooooo`co000000Coooooo`000?l0003o
oooo0ol00007ooooo`;o00003oooool2o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`;o
00001oooool3o`0000gooooo0_l00009ooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0
@?ooool4o`0000;ooooo1Ol00008ooooo`;o00008_ooool2o`0000gooooo0ol00007oooooa3o0000
0_ooool7o`0001Oooooo0_l000000ooooooo0000o`000008ooooo`?o00001oooool4o`0001Kooooo
0_l000000ooooooo0000o`00001Cooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00001?oo
ool2o`000003ooooool0003o000000Sooooo0_l0000Hooooo`;o00005Oooool2o`0000[ooooo5Ol0
0002ooooo`;o00001?ooool2o`0000?ooooo0_l00003ooooo`Co00001Oooool2o`0000cooooo0_l0
0009ooooo`;o00006Oooool2o`0005?ooooo000Looooo`03o`000?oooooooooo04Gooooo0_l00002
ooooo`;o00002?ooool3o`0001Oooooo0_l0000Dooooo`?o00000oooool2o`0000Gooooo4_l00000
0ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o00000oooool4
o`0000Gooooo0_l00004ooooo`;o000000?oooooo`000?l00000O_ooool001cooooo00?o0000oooo
ooooool0AOooool2o`0000cooooo0ol00007ooooo`;o00007?ooool2o`0000Kooooo0_l00004oooo
o`;o00000ooooolCo`0000Gooooo1?l000000ooooooo0000o`00000Cooooo`Co00000_ooool5o`00
02Oooooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o00007?ooool2o`0000Co
oooo0_l00004ooooo`;o00001OoooolDo`0000;ooooo1_l00004ooooo`;o00004_ooool2o`0000?o
oooo0_l00009ooooo`;o00007?ooool4o`0000Cooooo0_l0001?ooooo`007?ooool00ol0003ooooo
ooooo`1Aooooo`;o00002_ooool2o`0001Kooooo0_l0000:ooooo`;o00001?ooool2o`0000Kooooo
4?l000000ooooooo0000o`000005o`000004ooooool0003o0000o`0000?ooooo0_l0000Aooooo`?o
000000?oooooo`000?l000002oooool2o`0001Cooooo0_l00006ooooo`;o00001_ooool2o`0004oo
oooo000Looooo`03o`000?oooooooooo057ooooo0_l00008ooooo`Co00005_ooool2o`0000Cooooo
0_l00004ooooo`;o00001?ooool4o`0000Cooooo4?l000000ooooooo0000o`00000;o`0000kooooo
0_l00004ooooo`?o000000?oooooo`000?l000002_ooool2o`0001Gooooo0_l00006ooooo`;o0000
1?ooool2o`000003ooooool0003o000004kooooo000Looooo`03o`000?oooooooooo05_ooooo0_l0
000Nooooo`;o00002Oooool5o`0000;ooooo7Ol000000ooooooo0000o`00000>ooooo`;o00001_oo
ool2o`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l000005?ooool2o`0000Kooooo0ol0
0004ooooo`;o000000?oooooo`000?l00000C_ooool001cooooo00?o0000ooooooooool0Aoooool2
o`00033ooooo0_l00009ooooo`Co00001Oooool7o`000003ooooool0003o000001;o00000_ooool2
o`0000?ooooo0_l0000?ooooo`Go00000_ooool3o`0000;ooooo0ol000000ooooooo0000o`000002
o`0000;ooooo0_l0000>ooooo`;o00001_ooool2o`0000Kooooo0_l0001@ooooo`007?ooool00ol0
003oooooooooo`13ooooo`;o00000_ooool2o`0002Sooooo0_l00006ooooo`;o00002Oooool2o`00
00;ooooo0_l000000ooooooo0000o`00000No`000003ooooool0003o000000;ooooo0_l0000?oooo
o`Go00000oooool6o`0000?ooooo0ol00002ooooo`;o00001Oooool2o`0000Oooooo0ol0000=oooo
o`;o0000D?ooool001cooooo00?o0000ooooooooool0@oooool2o`0000Sooooo0_l00009ooooo`;o
00005Oooool4o`0000Kooooo0_l00003ooooo`;o00002?ooool2o`000003ooooool0003o000001ko
000000Coooooo`000?l0003o00000_ooool2o`0000Oooooo0_l00005ooooo`Go00000oooool6o`00
0003ooooool0003o000000cooooo0_l000000ooooooo0000o`000004ooooo`?o00002Oooool3o`00
05?ooooo000Looooo`03o`000?oooooooooo03oooooo0_l00002ooooo`;o00002?ooool2o`000003
ooooool0003o000000Kooooo0_l0000Eooooo`?o00003?ooool3o`0000;ooooo1?l000001?oooooo
0000o`000?ooool9o`000003ooooool0003o000001?o00000_ooool3o`0000;ooooo0_l00007oooo
o`;o00001Oooool5o`000003ooooool0003o000000Co00000oooool3o`0000kooooo0_l0000@oooo
o`?o0000Doooool001cooooo00?o0000ooooooooool0?oooool5o`0000?ooooo0_l00007ooooo`;o
00006oooool2o`000003ooooool0003o000000Wooooo1_l00002ooooo`Oo000000?oooooo`000?l0
00001ol000000ooooooo0000o`00000Ao`0000?ooooo0_l00004ooooo`;o00003_ooool4o`0000;o
oooo0_l00002ooooo`;o00000oooool3o`0001Kooooo0_l00005ooooo`;o000000?oooooo`000?l0
0000E?ooool001cooooo00?o0000ooooooooool0@Oooool3o`0000?ooooo0_l0000?ooooo`;o0000
4oooool2o`0000cooooo1?l00005ooooo`Ko000000?oooooo`000?l000008_l00002ooooo`;o0000
4Oooool2o`0000_ooooo0_l00004ooooo`;o00004?ooool2o`0000Gooooo0_l0000:ooooo`;o0000
Boooool001cooooo0_l0000iooooo`;o00001_ooool2o`0000;ooooo0_l0000Booooo`;o00004ooo
ool2o`0000kooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo7ol0
0002ooooo`;o00004_ooool2o`000003ooooool0003o000000_ooooo0ol00003ooooo`?o00001Ooo
ool2o`0001_ooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00001_ooool8
o`00013ooooo0_l0000Tooooo`;o000000Coooooo`000?l0003ooooo0_l00006oooooako000000?o
ooooo`000?l000000_l0000<ooooo`;o00001?ooool2o`000005ooooool0003o0000o`000?ooool0
1?l00005ooooo`?o00000_ooool4o`0000Gooooo0_l0000@ooooo`;o00002oooool2o`0004Wooooo
000Looooo`03o`000?oooooooooo03[ooooo0_l00006ooooo`;o00000_ooool2o`00013ooooo0_l0
000Iooooo`;o00001_ooool5o`0000Cooooo0_l00005ooooo`Ko000000?oooooo`000?l000007Ol0
000:ooooo`;o00000oooool2o`0000;ooooo0ol000000ooooooo0000o`000002o`0000Gooooo1?l0
00000ooooooo0000o`000006ooooo`;o00004Oooool2o`0000Gooooo0_l00004ooooo`;o0000BOoo
ool001cooooo00?o0000ooooooooool0>_ooool2o`0000?ooooo0_l000000ooooooo0000o`000002
o`0000[ooooo0_l00005ooooo`?o00006Oooool2o`0000Kooooo1?l00002ooooo`;o000000Cooooo
o`000?l0003o00001?oooolVo`0000oooooo0ol00002ooooo`;o00002_ooool4o`0000Wooooo0_l0
0006ooooo`;o00004?ooool2o`0004oooooo000Looooo`03o`000?oooooooooo03oooooo2Ol00008
ooooo`;o00001Oooool2o`0002Sooooo1_l00002ooooo`Ko000000?oooooo`000?l000007Ol00003
ooooo`;o00001_ooool2o`0000Cooooo0ol00002ooooo`;o00002_ooool4o`0000Kooooo0_l00000
0ooooooo0000o`000006ooooo`?o00006?ooool2o`0004Kooooo000Looooo`03o`000?oooooooooo
047ooooo0ol00002ooooo`;o00001?ooool2o`0002Sooooo0_l00009ooooo`Co00001?oooolWo`00
00;ooooo0_l00006ooooo`;o00001?ooool5o`000003ooooool0003o000000[ooooo1?l00004oooo
o`oo00006?ooool2o`0004Kooooo000Looooo`03o`000?oooooooooo03?ooooo0_l0000=ooooo`;o
00002?ooool2o`0002Sooooo0_l00006ooooo`;o000000?oooooo`000?l000001_oooolSo`0000;o
oooo0_l0000;ooooo`;o000000Coooooo`000?l0003ooooo1ol0000;oooooaCo00002oooool2o`00
05Gooooo000Looooo`03o`000?oooooooooo03?ooooo0_l0000Fooooo`Co0000;oooool2o`0000?o
oooo1Ol000000ooooooo0000o`00000No`000003ooooool0003o000000Gooooo0_l00008ooooo`;o
000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00000<ooooo`So00000_ooool2o`00
0003ooooool0003o000000Co00003Oooool2o`0000Wooooo0_l0001:ooooo`007?ooool00ol0003o
ooooooooo`0looooo`;o000000?oooooo`000?l000002_ooool4o`0000?ooooo0_l0000_ooooo`Go
00000_ooool3o`000003ooooool0003o000001_o00001_ooool3o`0001Gooooo0_l00007ooooo`Co
00000oooool3o`000003ooooool0003o000001Wooooo0_l000000ooooooo0000o`000003o`0004Wo
oooo000Looooo`03o`000?oooooooooo03cooooo0_l000000ooooooo0000o`00000Aooooo`;o0000
8?ooool3o`0000cooooo1Ol000000ooooooo0000o`00000Po`0000;ooooo0_l000000ooooooo0000
o`000002o`0001Gooooo0_l00005ooooo`Co00001Oooool3o`000003ooooool0003o000001?ooooo
0_l00004ooooo`Go000000?oooooo`000?l000000oooool2o`0004Cooooo000Looooo`03o`000?oo
oooooooo04cooooo0_l000000ooooooo0000o`000004ooooo`;o00007Oooool7o`000003ooooool0
003o000000?ooooo0_l000000ooooooo0000o`000008o`000005ooooool0003o0000o`000?ooool0
7?l000000ooooooo0000o`00000Nooooo`Co00000_ooool2o`0001[ooooo0_l00004ooooo`?o0000
0oooool2o`0000?ooooo0_l00002ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0>ooo
ool2o`0000oooooo0_l000000ooooooo0000o`000004ooooo`;o00006Oooool2o`0000?ooooo1_l0
00000ooooooo0000o`000003ooooo`;o000000Goooooo`000?l0003o0000ooooo`05o`000003oooo
ool0003o000001ko00000oooool2o`0001gooooo0_l00002ooooo`Co00009_ooool2o`0000Oooooo
0_l00010ooooo`007?ooool00ol0003oooooooooo`0kooooo`;o00005?ooool2o`0000;ooooo0_l0
000Iooooo`;o00000oooool5o`0000;ooooo0_l00002ooooo`?o00000_ooool3o`0000;ooooo8?l0
0007ooooo`;o00004?ooool6o`0000Oooooo0_l00002ooooo`;o00004_ooool2o`0000;ooooo0_l0
001Kooooo`007?ooool00ol0003oooooooooo`0fooooo`?o00001oooool2o`0000oooooo0_l00002
ooooo`;o00006Oooool2o`0000Cooooo1?l00002ooooo`;o00000_ooool3o`0000?ooooo1?l00000
1Ooooooo0000o`000?l0003ooooo01Wo00000_ooool2o`000003ooooool0003o000000;ooooo0_l0
000@ooooo`Ko00002oooool2o`00017ooooo0ol000001?oooooo0000o`000?l0000;ooooo`;o0000
C_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413o
ooooooooo`04ooooo`03o`000?oooooooooo03Kooooo0ol00002ooooo`;o000000?oooooo`000?l0
00000_l00008ooooo`;o00009?ooool3o`0000?ooooo0ol00004ooooo`;o00001oooool9o`000003
ooooool0003o000000So00000_ooool;o`0000?ooooo1Ol00002ooooo`;o00004?ooool3o`0000?o
oooo0_l00007ooooo`Co00004Oooool2o`0000;ooooo0ol0000;ooooo`?o0000COooool00006oooo
oomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0kooooo`;o000000?oooooo`000?l000002_ooool2o`0002Gooooo0_l00004oooo
o`;o00001?ooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o0000
00_o000000?oooooo`000?l000003?l000000ooooooo0000o`000002o`0001Gooooo0ol00003oooo
o`?o00001Oooool3o`0000cooooo0_l0000Hooooo`;o0000COooool00003ooooool@413ooooo00;o
oooo00?o410@ooooooooool02Oooool5o`0000Kooooo00?o0000ooooooooool0>oooool2o`0001?o
oooo0ol0000Uooooo`;o00000oooool2o`0000;ooooo0ol00002ooooo`Co000000?oooooo`000?l0
00003?l000000ooooooo0000o`00000@o`0000cooooo0_l0000@ooooo`;o00001Oooool2o`0000Wo
oooo0_l00002ooooo`Co00001oooool2o`0000gooooo0_l0001=ooooo`0000?oooooo`000?ooool0
0_ooool00ol0003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0000kooooo`;o
00002?ooool2o`0000Oooooo1Ol00002ooooo`;o00008Oooool3o`0000;ooooo0_l00003ooooo`;o
00000oooool3o`000003ooooool0003o000000[o000000?oooooo`000?l000003Ol000000ooooooo
0000o`000002o`0000cooooo0_l00003ooooo`;o00001_ooool2o`0000Kooooo0_l0000<ooooo`?o
00001?ooool7o`0000;ooooo0_l00004ooooo`;o00001_ooool3o`0004gooooo00000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003o
ooooooooo`0dooooo`;o000000Coooooo`000?l0003ooooo0_l00009ooooo`;o00001oooool4o`00
00?ooooo0ol0000Qooooo`;o00000oooool2o`0000Sooooo0ol000000ooooooo0000o`000002o`00
0003ooooool0003o000000Co000000?oooooo`000?l000002ol00005ooooo`Co000000?oooooo`00
0?l000002oooool3o`0000Kooooo0ol00002ooooo`Go00003?ooool3o`0000Gooooo1_l00005oooo
o`;o000000?oooooo`000?l000001_ooool2o`0004kooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00[ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0dooooo`;o
000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000003ooooo`;o00001_ooool2o`00
00?ooooo0_l00002ooooo`;o000000?oooooo`000?l000006Oooool2o`0000_ooooo0_l00003oooo
o`;o00000oooool3o`0000?ooooo0_l000000ooooooo0000o`00000Ao`0000Gooooo1Ol000000ooo
oooo0000o`00000;ooooo`;o00002?ooool2o`000003ooooool0003o000000?o00004Oooool2o`00
00_ooooo1?l00003ooooo`?o0000Doooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg3?ooool0
0oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo03Kooooo0_l00005ooooo`;o00000oooool2
o`0000Kooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l0000Looooo`;o00004?ooool2
o`0000?ooooo0ol00003ooooo`;o000000?oooooo`000?l000003ol00006ooooo`?o000000?ooooo
o`000?l000002?ooool2o`0000kooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00004?oo
ool2o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`?o00001Oooool3o`0005?ooooo0000
1_ooooook^k^oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooo
ooooo`0cooooo`;o000000?oooooo`000?l000001?ooool4o`0000cooooo1Ol0000Qooooo`Co0000
4oooool4o`0000Kooooo1Ol000000ooooooo0000o`000005o`0000Oooooo0ol000000ooooooo0000
o`000002o`0000Oooooo0_l00007ooooo`;o00001?ooool2o`0000?ooooo0_l000000ooooooo0000
o`00000<ooooo`;o00001_ooool5o`0000?ooooo0_l00008ooooo`Co00002Oooool2o`0004Gooooo
000Looooo`03o`000?oooooooooo03;ooooo0ol00007ooooo`Ko00000oooool4o`0000?ooooo0ol0
000Sooooo`Co00004oooool5o`0000Gooooo0ol00002ooooo`_o00000_ooool:o`0000kooooo1_l0
0002ooooo`;o00004oooool3o`0000Kooooo1?l0000>ooooo`Co00002?ooool3o`0004Gooooo000L
ooooo`03o`000?oooooooooo03;ooooo0_l000000ooooooo0000o`000002o`0000Oooooo0_l00003
ooooo`Co00000oooool3o`0000[ooooo0_l0000Jooooo`;o000000?oooooo`000?l000004_ooool2
o`0000Gooooo0ol000000ooooooo0000o`000004o`000003ooooool0003o000000_o00002Oooool2
o`0000Oooooo1_l00004ooooo`;o00000_ooool2o`0000gooooo0_l000000ooooooo0000o`000004
ooooo`Ko00000_ooool2o`0000Wooooo0_l00002ooooo`;o00001Oooool3o`0004Gooooo000Loooo
o`03o`000?oooooooooo03Gooooo1?l00003ooooo`;o00003Oooool4o`0000[ooooo0_l0000Boooo
o`;o00001?ooool4o`000003ooooool0003o000000gooooo1?l00008ooooo`;o00000_ooool7o`00
00;ooooo2?l000000ooooooo0000o`000009ooooo`;o00002_ooool2o`0000Gooooo0_l00002oooo
o`;o00002oooool2o`0000?ooooo0_l00006ooooo`Co000000Goooooo`000?l0003o0000ooooo`02
o`0000Cooooo0_l00004ooooo`;o00002_ooool2o`00047ooooo000Looooo`03o`000?oooooooooo
03Gooooo0_l00005ooooo`;o00000oooool2o`0000Kooooo1?l0000<ooooo`;o00004_ooool2o`00
00;ooooo1_l0000@ooooo`Go000000?oooooo`000?l000001?l00002ooooo`;o000000Coooooo`00
0?l0003ooooo3?l00002ooooo`;o00005Oooool2o`0000Cooooo0_l0000@ooooo`;o00001Oooool2
o`000005ooooool0003o0000o`000?ooool01_l000000ooooooo0000o`000003o`0000;ooooo0_l0
0002ooooo`Co00002Oooool3o`00047ooooo000Looooo`03o`000?oooooooooo03Gooooo0_l0000:
ooooo`;o00001_ooool5o`0000_ooooo0_l0000>ooooo`;o00001Oooool:o`00013ooooo0_l00000
0ooooooo0000o`000004o`0000;ooooo0_l00004ooooo`Go00000_ooool4o`000003ooooool0003o
000001Kooooo0_l00003ooooo`Co00002_ooool7o`0000Kooooo0_l000000ooooooo0000o`00000>
o`000003ooooool0003o000000?ooooo1?l00006ooooo`;o000000?oooooo`000?l00000@_ooool0
01cooooo00?o0000ooooooooool0>?ooool4o`0000Gooooo0_l00008ooooo`?o00006oooool2o`00
00Gooooo0ol000000ooooooo0000o`000005o`0000Cooooo0_l0000;ooooo`Wo00001?ooool2o`00
0004ooooool0003o0000o`0000;ooooo1Ol000000ooooooo0000o`00000Fooooo`;o00000oooool2
o`0000Wooooo0_l000000ooooooo0000o`000005o`0000_ooooo4Ol0000=ooooo`;o0000AOooool0
01cooooo00?o0000ooooooooool0<_ooool2o`0000Cooooo1?l00005ooooo`;o00001oooool3o`00
00Kooooo0_l00006ooooo`;o00002oooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2
o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o00002oooool9o`0000Cooooo3Ol0000:
ooooo`;o00002oooool9o`0000Wooooo0_l0000Aoooooa?o0000E?ooool001cooooo00?o0000oooo
ooooool0<_ooool2o`0000Gooooo0_l0000;ooooo`Oo00001_ooool2o`0000Kooooo0_l0000;oooo
o`;o00000_ooool2o`000003ooooool0003o000000Ko00005_ooool:o`0000;ooooo2ol0000<oooo
o`;o00002oooool9o`0000oooooo0_l0000;oooooa?o0000E?ooool001cooooo00?o0000oooooooo
ool0<_ooool2o`0001;ooooo1Ol00002ooooo`;o00002_ooool2o`0000kooooo0_l00003ooooo`Go
000000?oooooo`000?l000000_l0000Joooooa7o00002_ooool2o`0000gooooo1_l00009ooooo`;o
00002?ooool2o`0000cooooo4_l0001Dooooo`007?ooool00ol0003oooooooooo`13ooooo`So0000
0_ooool2o`0000[ooooo0_l0000>ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo
1?l00005ooooo`;o00003_ooool4o`0000;ooooo2?l0000Aooooo`;o00002oooool8o`0000Wooooo
0ol0000AoooooaGo000000Coooooo`000?l0003o00002oooool2o`0004Cooooo000Looooo`03o`00
0?oooooooooo02oooooo0_l0000=ooooo`;o00000oooool7o`0000?ooooo0_l00006ooooo`Co0000
7_ooool2o`000003ooooool0003o000000;ooooo0_l0000>ooooo`Co00009_ooool;o`0000Wooooo
0_l00005ooooo`;o00001?ooool2o`0000Cooooo5?l000000ooooooo0000o`000002o`0000Oooooo
1_l00014ooooo`007?ooool2o`00033ooooo0_l00005ooooo`;o00001_ooool2o`0000?ooooo0_l0
0003ooooo`;o00001_ooool2o`0000?ooooo1?l0000Jooooo`;o00001Oooool2o`0000;ooooo0ol0
000Cooooo`;o00008_ooool5o`000004ooooool0003o0000ooooo`;o00004?ooool3o`000003oooo
ool0003o000000;o00001OoooolJo`0000Gooooo1?l00016ooooo`007?ooool00ol0003ooooooooo
o`0cooooo`;o000000?oooooo`000?l000003_ooool5o`0000Gooooo0_l00003ooooo`;o00002_oo
ool2o`0000[ooooo0_l00004ooooo`;o00002_ooool2o`0001?ooooo0ol0000Oooooo`Go00000ooo
ool5o`00013ooooo0ol000000ooooooo0000o`000008oooooaWo0000Coooool001cooooo00?o0000
ooooooooool0<oooool4o`0000Wooooo0_l00002ooooo`Co000000?oooooo`000?l000001Oooool2
o`0000kooooo0ol0000:ooooo`;o00001oooool2o`0000Oooooo0_l0000Dooooo`;o00000_ooool2
o`0001Kooooo0_l000000ooooooo0000o`000004o`0000Gooooo1?l0000?ooooo`?o00002ooooolE
o`000003ooooool0003o000000Oooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`0eoooo
o`;o00001?ooool3o`0000;ooooo0_l00002ooooo`Co000000?oooooo`000?l000002_ooool2o`00
00Gooooo0ol000000ooooooo0000o`00000:ooooo`?o00000_ooool2o`0000?ooooo0_l00007oooo
o`?o000000?oooooo`000?l000005?ooool3o`0001Gooooo2?l0000Iooooo`?o00001ooooolIo`00
00[ooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00002_ooool3o`0000Go
oooo0_l00004ooooo`;o00002_ooool2o`0000Gooooo0ol0000<ooooo`?o00000_ooool3o`0000co
oooo1_l0000Eooooo`;o00005Oooool:o`0001?ooooo0_l00003ooooo`;o00001ooooolIo`0000So
oooo0ol00019ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00003_ooool2o`0000;ooooo
0_l000000ooooooo0000o`000003o`0001[ooooo1Ol000000ooooooo0000o`000003ooooo`?o0000
3oooool4o`0002Kooooo1ol00002ooooo`;o00000_ooool2o`0000gooooo0_l00004ooooo`;o0000
1oooool2o`0000Sooooo2?l000000ooooooo0000o`000008o`0000?ooooo0_l00004ooooo`Go0000
Aoooool001cooooo00?o0000ooooooooool0;oooool2o`0000;ooooo0_l0000:ooooo`;o00001Ooo
ool5o`0001[ooooo2?l0000:ooooo`;o00001Oooool8o`0002Kooooo1Ol0000Gooooo`;o00003Ooo
ool2o`0000Sooooo4ol00002ooooo`?o00001_ooool3o`0004Oooooo000Looooo`03o`000?oooooo
oooo02oooooo0_l00002ooooo`;o00001Oooool2o`0000?ooooo0_l0000Nooooo`;o00002?ooool4
o`000003ooooool0003o000000Oooooo1?l000000ooooooo0000o`000005o`0002[ooooo0ol00003
ooooo`;o00000oooool3o`0000Wooooo0_l00009ooooo`;o00000_ooool2o`0000cooooo4ol00002
ooooo`;o00001oooool2o`0004Sooooo000Looooo`03o`000?oooooooooo02gooooo1?l00007oooo
o`Co00005oooool2o`0000Oooooo0_l000000ooooooo0000o`00000=ooooo`?o00001oooool3o`00
0003ooooool0003o000000Kooooo0_l0000>ooooo`;o00005Oooool<o`000004ooooool0003o0000
o`0000Wooooo0_l00002ooooo`;o00001Oooool2o`0000;ooooo0_l0000=oooooa7o00000_ooool2
o`0000Cooooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`0]ooooo`?o00002?ooool3o`00
01;ooooo0_l00004ooooo`;o00001oooool2o`000003ooooool0003o000000kooooo0_l00007oooo
o`;o00001_ooool3o`000003ooooool0003o000000cooooo1?l0000Aooooo`;o00000_ooool4o`00
0003ooooool0003o000000Ko00004?ooool2o`0000_ooooo0_l0000:oooooa7o00000oooool2o`00
00?ooooo1Ol0001:ooooo`007?ooool00ol0003oooooooooo`0/ooooo`Co00002?ooool2o`0001?o
oooo0_l0000?ooooo`;o00004oooool2o`0000Oooooo0_l00002ooooo`?o00003oooool2o`0000Ko
oooo0_l00009ooooo`Go00000oooool2o`0000Cooooo1Ol0000?ooooo`?o00002oooool4o`0000So
oooo4Ol00007ooooo`?o000000?oooooo`000?l00000B_ooool001cooooo00?o0000ooooooooool0
;?ooool2o`0000Cooooo1?l0000@ooooo`;o00001Oooool2o`000003ooooool0003o000000cooooo
0_l00003ooooo`;o00003_ooool2o`0000Oooooo0_l00004ooooo`;o00003_ooool2o`0000?ooooo
1Ol00009ooooo`Go000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l0000Booooo`?o0000
3Oooool2o`0000;ooooo0_l00007ooooo`ko00001oooool2o`000003ooooool0003o000004_ooooo
000Looooo`03o`000?oooooooooo03;ooooo1?l000000ooooooo0000o`00000=ooooo`Co00001_oo
ool2o`00017ooooo1Ol000001?oooooo0000o`000?l00003ooooo`Co00003oooool2o`00013ooooo
0_l000000ooooooo0000o`000004o`000003ooooool0003o000000Cooooo1Ol00002ooooo`;o0000
00Coooooo`000?l0003o00004Oooool2o`0001Oooooo0_l00007ooooo`So000000Coooooo`000?l0
003ooooo0_l0000:ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0;_ooool2o`0000Oo
oooo0_l0000;ooooo`;o00000_ooool2o`0000gooooo0_l0000<ooooo`?o000000?oooooo`000?l0
00000_l00002ooooo`Co00008Oooool4o`0000;ooooo1_l000001?oooooo0000o`000?ooool6o`00
00Cooooo0_l0000Booooo`;o00001_ooool2o`0001Wooooo1ol00004ooooo`Co000000?oooooo`00
0?l00000D_ooool001cooooo00?o0000ooooooooool0;_ooool2o`0000cooooo0_l00002ooooo`;o
00000_ooool2o`0000Oooooo0_l00008ooooo`;o00002oooool:o`0000?ooooo0_l0000Eooooo`;o
00003?ooool3o`0000;ooooo1Ol000001?oooooo0000o`000?ooool7o`0000?ooooo0_l000000ooo
oooo0000o`00000Gooooo`;o00003?ooool2o`0000gooooo1?l00007ooooo`;o000000?oooooo`00
0?l00000D_ooool001cooooo00?o0000ooooooooool0??ooool2o`0000;ooooo0_l0000;ooooo`;o
00002?ooool2o`0000_ooooo1ol000001?oooooo0000o`000?ooool4o`0000Kooooo0_l00007oooo
o`;o00001?ooool2o`0000gooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`00
0?l000001Ol000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000009Oooool2o`00
00gooooo1?l000000ooooooo0000o`000002ooooo`Go0000E?ooool001cooooo0_l0000^ooooo`;o
00007?ooool2o`0000[ooooo0_l00006ooooo`?o00000_ooool2o`0000;ooooo2ol00006ooooo`;o
00000oooool2o`0000;ooooo0_l0000Fooooo`;o00001Oooool4o`0000;ooooo1?l0000Mooooo`;o
00008_ooool2o`000003ooooool0003o000000Co0000E?ooool001cooooo00?o0000ooooooooool0
;Oooool2o`0000oooooo1_l00007ooooo`;o00004?ooool6o`000003ooooool0003o000000go0000
1_ooool2o`0000?ooooo0_l00002ooooo`?o00008_ooool2o`0001oooooo0_l0000Uooooo`;o0000
F?ooool001cooooo00?o0000ooooooooool0<Oooool2o`0000Cooooo1?l00003ooooo`Ko00003_oo
ool2o`0000Wooooo5_l00002ooooo`;o00000_ooool2o`0000Oooooo0ol00005ooooo`?o00005Ooo
ool3o`0000Sooooo0_l0000Oooooo`;o00003?ooool2o`0000[ooooo0_l0001Oooooo`007?ooool0
0ol0003oooooooooo`0]ooooo`;o000000Coooooo`000?l0003o00001?ooool4o`0000Gooooo1?l0
000;ooooo`;o000000Coooooo`000?l0003o00001_oooolHo`000004ooooool0003o0000o`0000co
oooo0_l00005ooooo`Co00005?ooool3o`0000;ooooo0_l00002ooooo`Go00000_ooool2o`0001[o
oooo0_l00004ooooo`;o00001_ooool2o`0000[ooooo0_l0001Oooooo`007?ooool00ol0003ooooo
ooooo`0]ooooo`Go00007Oooool3o`000004ooooool0003o0000o`0000Gooooo7?l000000ooooooo
0000o`000009ooooo`;o00001oooool3o`0001Cooooo0_l00002ooooo`;o000000?oooooo`000?l0
00001?l00002ooooo`;o00008?ooool2o`0001Kooooo0_l000000ooooooo0000o`00001Hooooo`00
7?ooool00ol0003oooooooooo`0^ooooo`;o00004Oooool4o`0000;ooooo0_l00007ooooo`;o0000
0_ooool2o`000003ooooool0003o000000;ooooo3ol000000ooooooo0000o`000007o`000004oooo
ool0003o0000ooooo`;o00002Oooool2o`0000Sooooo0ol0000Jooooo`;o00001?ooool2o`000003
ooooool0003o000000_ooooo0_l00004ooooo`;o00002?ooool2o`0000Sooooo0_l0000?ooooo`?o
000000?oooooo`000?l00000F?ooool001cooooo00?o0000ooooooooool0@Oooool4o`0000;ooooo
0_l00003ooooo`?o00002?ooool2o`000003ooooool0003o000000;ooooo5_l0000?ooooo`;o0000
1?ooool2o`0000?ooooo0_l0000Fooooo`;o00002?ooool2o`000003ooooool0003o000000_ooooo
0ol00002ooooo`?o00002?ooool2o`0000Sooooo0_l0000?ooooo`;o0000G?ooool001cooooo00?o
0000ooooooooool0;Oooool2o`0000?ooooo0_l0000>ooooo`;o00002?ooool8o`0000Kooooo0_l0
0002oooooaSo00002Oooool2o`0000;ooooo0ol00003ooooo`;o00001_ooool2o`0001?ooooo0_l0
0007ooooo`;o00004?ooool2o`0000;ooooo0_l00009ooooo`;o00002_ooool3o`0000cooooo0_l0
0005ooooo`;o0000EOooool001cooooo00?o0000ooooooooool0;Oooool2o`0000?ooooo0_l0000>
ooooo`Co00002?ooool7o`0000Cooooo0_l000000ooooooo0000o`00000Ho`0000?ooooo0_l00004
ooooo`;o00000oooool2o`0000Wooooo1?l0000;ooooo`Go000000?oooooo`000?l000000_l00007
ooooo`;o000000?oooooo`000?l000003?ooool2o`0000gooooo1Ol00008ooooo`?o00003?ooool2
o`000003ooooool0003o000000;ooooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`0]oooo
o`;o00001oooool2o`0000[ooooo1?l00006ooooo`;o00001Oooool2o`0000Cooooo7?l00003oooo
o`?o00005?ooool2o`000003ooooool0003o000000[ooooo1Ol000000ooooooo0000o`000005o`00
00Cooooo0_l000000ooooooo0000o`00000<ooooo`;o00003?ooool6o`0001[ooooo0_l00004oooo
o`;o0000Doooool001cooooo00?o0000ooooooooool0;Oooool2o`0000Oooooo0_l00009ooooo`?o
00002?ooool2o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l000000_l000000ooooooo
0000o`00000Eo`000003ooooool0003o000000?o000000?oooooo`000?l000001?l0000@ooooo`;o
00004oooool4o`0000;ooooo0ol0000Nooooo`;o00002?ooool2o`0001[ooooo0_l0001Cooooo`00
7?ooool00ol0003oooooooooo`0dooooo`;o000000?oooooo`000?l000002?ooool2o`0000gooooo
0_l00004ooooo`;o000000Coooooo`000?l0003o00000ooooolLo`000003ooooool0003o000000Co
00003oooool2o`0001;ooooo0_l00002ooooo`;o00000_ooool5o`00013ooooo0ol00007ooooo`;o
00002_ooool2o`0006oooooo000Looooo`03o`000?oooooooooo03Cooooo0_l000000ooooooo0000
o`00000Kooooo`;o00001?ooool4o`000003ooooool0003o000001ko00004_ooool2o`0000?ooooo
0_l0000;ooooo`Co00000_ooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000?o
oooo0_l00008ooooo`?o00001?ooool2o`000003ooooool0003o000000;ooooo0_l0000Iooooo`;o
00001oooool3o`0000?ooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o0000
7oooool2o`0000Gooooo0_l00004oooooa;o00000_ooool9o`0000;ooooo1_l00004ooooo`;o0000
4Oooool2o`0000[ooooo1?l00004ooooo`Go00001?ooool2o`0000?ooooo0_l0000?ooooo`;o0000
1Oooool2o`0001Wooooo0_l00007ooooo`?o00000oooool2o`0004gooooo000Looooo`03o`000?oo
oooooooo02cooooo0_l0000=ooooo`;o00000oooool2o`0000_ooooo0_l00009ooooo`Co000000?o
ooooo`000?l000005_l0000>ooooo`;o00007Oooool2o`0000;ooooo0ol000000ooooooo0000o`00
0003o`000003ooooool0003o000000_ooooo0ol0000Aooooo`;o00004?ooool2o`0006Cooooo000L
ooooo`03o`000?oooooooooo03_ooooo0_l00002ooooo`?o00002_ooool2o`0000[ooooo1_l00000
0ooooooo0000o`00000>o`000003ooooool0003o000000?o00000oooool3o`0000Sooooo0_l0000;
ooooo`;o00000oooool2o`0000?ooooo1?l00005ooooo`;o000000Coooooo`000?l0003o00000_oo
ool4o`000003ooooool0003o000000_ooooo0ol00008ooooo`;o00001oooool2o`00013ooooo0_l0
001Tooooo`007?ooool2o`00043ooooo0_l0000:ooooo`?o00002?ooool2o`000003ooooool0003o
000000?o000000?oooooo`000?l000003_l000000ooooooo0000o`000003o`0000?ooooo2?l0000@
ooooo`;o00000oooool2o`0000?ooooo1?l00003ooooo`Co00000_ooool2o`0000;ooooo1?l0000F
ooooo`;o000000?oooooo`000?l000006Oooool2o`0006Cooooo000Looooo`03o`000?oooooooooo
03;ooooo0_l0000;ooooo`;o00002_ooool2o`0000Gooooo0_l00002ooooo`;o00001?oooolJo`00
00;ooooo2?l0000Qooooo`Ko00001_ooool2o`0000Sooooo0_l0000<ooooo`;o00004?ooool3o`00
00Wooooo0_l0000@ooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0<?ooool4o`0000Oo
oooo0_l00002ooooo`;o00001oooool2o`0000Cooooo0_l00002ooooo`;o00002?oooolJo`0000;o
oooo1Ol0000Qooooo`?o000000?oooooo`000?l000000ol0000@ooooo`;o000000?oooooo`000?l0
00005?ooool3o`0000;ooooo1Ol00007ooooo`;o00004_ooool2o`0005;ooooo000Looooo`03o`00
0?oooooooooo033ooooo0_l000000ooooooo0000o`000006ooooo`;o00000_ooool2o`0000Oooooo
0ol00003ooooo`;o00003OoooolJo`000004ooooool0003o0000ooooo`;o00002_ooool2o`0001Go
oooo0ol00004ooooo`;o00001oooool4o`0000Sooooo0_l0000Dooooo`?o00000_ooool4o`0000So
oooo0_l0000Dooooo`;o0000D?ooool001cooooo00?o0000ooooooooool0<oooool2o`0001;ooooo
1?l00003ooooo`;o00000_ooool2o`0000Wooooo7ol00004ooooo`Ko000000?oooooo`000?l00000
2_ooool2o`000003ooooool0003o000000Oooooo0_l00004ooooo`Co00001Oooool5o`0002;ooooo
0_l00003ooooo`;o00006oooool2o`0000?ooooo0_l0001;ooooo`007?ooool00ol0003ooooooooo
o`17ooooo`?o00001oooool3o`0000Wooooo1?l00002ooooobKo00001_ooool2o`0000;ooooo0_l0
00000ooooooo0000o`000007ooooo`;o00001_ooool2o`0000Oooooo1?l0000Qooooo`;o00000ooo
ool2o`00023ooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00005?ooool2
o`0000Kooooo0_l00006ooooo`Co000000?oooooo`000?l000001Ol000000ooooooo0000o`000008
o`000003ooooool0003o000000Go00000oooool6o`000003ooooool0003o000000Go00001Oooool3
o`0000Gooooo0_l0000:ooooo`;o00001?ooool3o`0000Cooooo1Ol00008ooooo`;o0000Roooool0
01cooooo00?o0000ooooooooool0<oooool2o`0001Cooooo0_l000000ooooooo0000o`000003oooo
o`;o00001_ooool4o`0000Cooooo1?l000000ooooooo0000o`000008o`000003ooooool0003o0000
00Co00001?ooool5o`0000;ooooo1Ol00007ooooo`;o00004?ooool4o`0000Cooooo0ol00004oooo
o`Ko00001Oooool4o`0000_ooooo0ol0000Aooooo`;o0000J_ooool001cooooo00?o0000oooooooo
ool0B?ooool2o`000004ooooool0003o0000o`0000?ooooo1?l0000>ooooo`;o000000Coooooo`00
0?l0003o00000_ooool5o`000003ooooool0003o000000Co00001Oooool2o`0000Cooooo2?l0000=
ooooo`;o00000oooool2o`0000;ooooo0_l0000@ooooo`[o00003Oooool3o`0000Wooooo0_l00006
ooooo`;o00001Oooool2o`0001Oooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`16oooo
o`Co000000?oooooo`000?l000001_ooool2o`0000gooooo0_l00002ooooo`;o00001?ooool2o`00
00Cooooo1?l000000ooooooo0000o`000002ooooo`;o00001Oooool;o`000004ooooool0003o0000
ooooo`;o00001?ooool3o`0000;ooooo0_l00003ooooo`;o00003?ooool=o`0000cooooo1?l00009
ooooo`;o00003Oooool2o`0001Oooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`16oooo
o`;o00002_ooool6o`0000Gooooo0_l00003ooooo`Ko00002_ooool2o`000003ooooool0003o0000
00?o000000?oooooo`000?l000001_ooool=o`000003ooooool0003o000000Gooooo0_l00002oooo
o`;o00000oooool2o`0000Sooooo3Ol0000@ooooo`Co00003oooool2o`0000Cooooo0_l0001Voooo
o`007?ooool00ol0003oooooooooo`1Booooo`Oo00001?ooool2o`0000Gooooo0_l00007ooooo`;o
00000oooool2o`000004ooooool0003o0000ooooo`;o00002Oooool<o`000003ooooool0003o0000
00;ooooo0_l00005ooooo`;o00000_ooool4o`0000;ooooo0_l00004ooooo`go00004oooool2o`00
00;ooooo1?l00008ooooo`?o000000?oooooo`000?l000000_l0001Vooooo`007?ooool00ol0003o
ooooooooo`0gooooo`;o00007_ooool2o`0000Cooooo0_l0000>ooooo`;o00005?ooool?o`0000;o
oooo0_l00005ooooo`;o00000_ooool2o`0000Cooooo0_l00003ooooo`;o00002?ooool3o`0001Co
oooo3?l00005ooooo`;o000000?oooooo`000?l000001Oooool2o`00067ooooo000Looooo`03o`00
0?oooooooooo03Cooooo0_l000001?oooooo0000o`000?ooool2o`00013ooooo0_l0000<ooooo`;o
00000_ooool2o`0001Wooooo0_l0000:ooooo`oo00001?ooool3o`0000cooooo1Ol00008ooooo`;o
00002_ooool4o`0000Gooooo0_l000000ooooooo0000o`00000Ao`000003ooooool0003o000000Co
oooo0_l000000ooooooo0000o`00001Nooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5oooo
o`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0=?ooool2
o`0000Cooooo0_l0000>ooooo`Co00003?ooool2o`0000;ooooo0_l00006ooooo`;o00004?ooool3
o`0000[ooooo3ol00004ooooo`?o00000_ooool2o`0000Sooooo1Ol00003ooooo`?o00003_ooool4
o`0000Gooooo0_l00003oooooa7o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o
000005kooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0hooooo`;o00004?ooool2o`0001[ooooo
0ol000000ooooooo0000o`000004o`0000Gooooo1Ol00002ooooo`;o00002?ooool=o`0000Gooooo
0_l00003ooooo`;o00001oooool2o`0000;ooooo0_l00003ooooo`?o00004?ooool2o`0000?ooooo
0_l00004ooooo`Oo000000?oooooo`000?l000001Ol00002ooooo`Ko00001?ooool2o`000003oooo
ool0003o000005cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo03Sooooo0_l0000]ooooo`;o0000
00?oooooo`000?l000001?l00005ooooo`Go00000_ooool2o`0000;ooooo0_l00005ooooo`_o0000
5?ooool2o`000004ooooool0003o0000o`00017ooooo0_l00003ooooo`Co000000?oooooo`000?l0
00000_l00002oooooaOo00000oooool3o`000003ooooool0003o000005cooooo00000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o
0000>_ooool2o`0000kooooo0_l0000Aooooo`;o00006?ooool2o`0000Oooooo0_l00005ooooo`_o
00002?ooool2o`0000Gooooo0_l00006ooooo`;o00004_ooool2o`0000Cooooo0ol00002oooooaWo
00001_ooool4o`0005kooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo
00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo03Sooooo1?l0000>ooooo`;o
00001oooool2o`000003ooooool0003o000000Gooooo0_l0000Hooooo`?o00000_ooool2o`000004
ooooool0003o0000ooooo`;o00001?ooool:o`0000Sooooo0ol00004ooooo`;o00001_ooool2o`00
01Sooooo0_l00003ooooo`Wo000000?oooooo`000?l000003Ol00003ooooo`;o00000oooool2o`00
05kooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qooo
ool02?ooool00ol0003oooooooooo`0hooooo`;o00006Oooool5o`00023ooooo0_l00002ooooo`;o
000000Coooooo`000?l0003ooooo0_l00005ooooo`[o000000?oooooo`000?l000001?l000000ooo
oooo0000o`00000<ooooo`;o00000oooool2o`0000cooooo0_l00004ooooo`;o00000_ooool;o`00
0003ooooool0003o000001;o0000=oooool2o`0002[ooooo00001_ooooooMgMgoiRHV?ooooooV9RH
ogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`1Dooooo`?o00007?ooool3
o`0000_ooooo0_l00002ooooo`;o00000oooool9o`000003ooooool0003o000000Ko00002oooool4
o`0000?ooooo0_l0000<ooooo`;o00001?oooolMo`000003ooooool0003o000000?o00000_ooool2
o`0003Cooooo0_l0000Zooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0>_ooool2o`0001Wooooo0_l0000=ooooo`;o0000
1_ooool2o`000003ooooool0003o000000;ooooo0ol0000;ooooo`;o00000_ooool3o`0000?ooooo
2Ol00006ooooo`;o00002oooool4o`0001;ooooo0_l00002ooooo`;o000000?oooooo`000?l00000
7_l00003ooooo`Co0000<Oooool2o`0002_ooooo000Looooo`03o`000?oooooooooo03[ooooo0_l0
000Gooooo`Co00003Oooool2o`0000Kooooo0_l000000ooooooo0000o`000003ooooo`;o00002?oo
ool2o`0000Kooooo1?l00003ooooo`?o000000Coooooo`000?l0003o00001_ooool2o`0000gooooo
0_l00003ooooo`;o00003Oooool2o`0000;ooooo8_l00006ooooo`;o0000<Oooool2o`0002_ooooo
000Looooo`03o`000?oooooooooo03[ooooo0_l0000Cooooo`;o00000_ooool2o`0000[ooooo0ol0
000=ooooo`Go000000Coooooo`000?l0003ooooo0ol00003ooooo`Co00001_ooool3o`0000Cooooo
1Ol0000?ooooo`;o000000?oooooo`000?l000001_ooool2o`0000gooooo1?l00002ooooo`Oo0000
00?oooooo`000?l000005_l0001Vooooo`007?ooool00ol0003oooooooooo`0jooooo`;o00003_oo
ool2o`0000?ooooo0_l0000>ooooo`Go00002_ooool2o`000003ooooool0003o000000So00000ooo
ool4o`0000?ooooo0_l00002ooooo`;o00001?ooool4o`0000Kooooo0_l00008ooooo`Ko00001?oo
ool2o`0000kooooo1?l000001?oooooo0000o`000?ooool6o`0000;ooooo4Ol000001?oooooo0000
o`000?l00002ooooo`;o0000Hoooool001cooooo00?o0000ooooooooool0>oooool2o`0000_ooooo
1?l0000Fooooo`Co00002?ooool3o`000003ooooool0003o000000;o000000?oooooo`000?l00000
1?l000000ooooooo0000o`000002o`0000?ooooo0_l00008ooooo`;o00002?ooool2o`000004oooo
ool0003o0000o`0000Gooooo0_l000001?oooooo0000o`000?l00003ooooo`?o00001_ooool2o`00
00Gooooo0_l00002ooooo`[o00000_oooolDo`0000?ooooo0_l0001Sooooo`007?ooool00ol0003o
ooooooooo`0kooooo`;o00002oooool2o`0001Sooooo1?l00002ooooo`;o00000oooool4o`000004
ooooool0003o0000o`0000Cooooo1_l00007ooooo`;o00001oooool2o`0000_ooooo0ol00008oooo
o`?o00001?ooool2o`0000Kooooo0_l00005ooooo`;o000000?oooooo`000?l000008?l00002oooo
o`;o0000Hoooool001cooooo00?o0000ooooooooool0>oooool2o`0000[ooooo1_l0000Eooooo`;o
00001?ooool4o`000003ooooool0003o000000Cooooo0_l00008ooooo`;o00001oooool2o`000003
ooooool0003o000000?o00001_ooool2o`00013ooooo0_l00004ooooo`Co00004?ooool8o`000003
ooooool0003o000001So0000I_ooool001cooooo00?o0000ooooooooool0>oooool2o`0000[ooooo
1_l0000Booooo`;o00001?ooool2o`0000?ooooo0_l00008ooooo`;o00000oooool2o`0000Kooooo
0_l00005ooooo`Ko00001_ooool2o`0000Oooooo0_l00002ooooo`?o00000_ooool2o`0000Cooooo
1?l00007ooooo`?o00001Oooool2o`0000?ooooo8?l00006ooooo`;o0000GOooool001cooooo00?o
0000ooooooooool0?Oooool2o`0000cooooo0_l0000Booooo`Co00000_ooool2o`0000;ooooo0_l0
0002ooooo`;o00001Oooool2o`0000?ooooo0_l00006ooooo`;o00001Oooool3o`0000;ooooo1?l0
000<ooooo`;o00000_ooool6o`0000Kooooo0_l00002ooooo`;o00001?ooool5o`000003ooooool0
003o000000;o00000ooooolLo`000004ooooool0003o0000o`0000Kooooo0_l0001Mooooo`007?oo
ool00ol0003oooooooooo`0mooooo`;o00003?ooool2o`0001Cooooo0_l00006ooooo`;o00000_oo
ool2o`0000Sooooo0_l0000Dooooo`Go00001?ooool6o`0000Gooooo0_l000001Ooooooo0000o`00
0?l0003ooooo00;o00000oooool2o`0000;ooooo0_l00007ooooo`;o000000?oooooo`000?l00000
0_l00003oooooaoo00001oooool2o`0001Kooooo0_l00015ooooo`007?ooool00ol0003ooooooooo
o`1;ooooo`;o00009oooool2o`000003ooooool0003o000000Cooooo0_l00005ooooo`So00000_oo
ool4o`0000Cooooo1_l0000;ooooo`?o000000?oooooo`000?l000001?ooool2o`0000[ooooo1?l0
0005oooooaco00008?ooool2o`0004Gooooo000Looooo`03o`000?oooooooooo04_ooooo0_l0000W
ooooo`Co00001Oooool2o`0000Cooooo2Ol00004ooooo`;o00002?ooool2o`000003ooooool0003o
000000Sooooo0_l00002ooooo`;o00006_ooool6o`000003ooooool0003o000000oo000000?ooooo
o`000?l000007oooool2o`0004Kooooo000Looooo`;o0000EOooool2o`00023ooooo0_l0000;oooo
o`;o00002Oooool5o`0000Wooooo0ol00004ooooo`;o00001oooool2o`0000[ooooo0_l00003oooo
o`;o00002?oooolHo`0002;ooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o
00000oooool4o`0000;ooooo0_l0000Nooooo`;o00001?ooool2o`0000Sooooo0_l00004ooooo`Go
00002Oooool2o`0000Gooooo0ol00006ooooo`Co00001Oooool2o`000004ooooool0003o0000oooo
o`Co000000?oooooo`000?l000000_ooool<o`000003ooooool0003o000000_o000000?oooooo`00
0?l000007_ooool2o`0001Cooooo0_l0000booooo`007?ooool00ol0003oooooooooo`1=ooooo`;o
00000oooool2o`0000Cooooo0_l0000Nooooo`;o00001?ooool2o`0000Sooooo1_l000000ooooooo
0000o`000002o`0000[ooooo0_l00005ooooo`;o00002?ooool2o`0000Gooooo0ol00003ooooo`;o
00000oooool2o`0000;ooooo1Ol00002oooooa3o00001?ooool2o`0001kooooo0_l0000Dooooo`;o
0000<_ooool001cooooo00?o0000ooooooooool0E_ooool3o`0002Sooooo0_l00006ooooo`Go0000
00Coooooo`000?l0003o00002Oooool4o`0001Oooooo0ol00004ooooo`;o00002?ooool2o`0000Co
oooo2_l00002ooooo`;o00000_ooool4o`0006Sooooo000Looooo`03o`000?oooooooooo05Kooooo
0ol0000Xooooo`;o00001Oooool3o`000003ooooool0003o000000;ooooo0_l00009ooooo`;o0000
6Oooool3o`0000Cooooo0_l0000>ooooo`[o00001_ooool2o`0006[ooooo000Looooo`03o`000?oo
oooooooo047ooooo0_l0000<ooooo`Co0000=Oooool3o`000003ooooool0003o000002gooooo0_l0
000@ooooo`?o00001?ooool2o`000003ooooool0003o000000;ooooo0_l0001/ooooo`007?ooool0
0ol0003oooooooooo`11ooooo`;o00002oooool6o`0003Gooooo0_l00005ooooo`;o00001_ooool2
o`00027ooooo0_l0000Jooooo`;o00000_ooool2o`0006cooooo000Looooo`03o`000?oooooooooo
04kooooo0ol000000ooooooo0000o`00000eooooo`;o00001Oooool2o`0000Kooooo0_l00002oooo
o`?o00000oooool2o`00013ooooo0_l0000:ooooo`;o00008Oooool3o`0001Gooooo0_l0001<oooo
o`007?ooool00ol0003oooooooooo`1?ooooo`;o00001Oooool2o`0003kooooo1Ol000000ooooooo
0000o`000006o`00013ooooo0_l0000:ooooo`;o00000_ooool2o`0001gooooo0ol0000Dooooo`?o
0000C?ooool001cooooo00?o0000ooooooooool0E_ooool2o`0002?ooooo0_l0000>ooooo`;o0000
2?ooool6o`000003ooooool0003o000000Co00002?ooool3o`0000[ooooo0_l0000;ooooo`;o0000
4Oooool2o`00027ooooo0_l0000Cooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0@ooo
ool2o`0001?ooooo0_l0000Qooooo`;o00003_ooool3o`0000Gooooo4Ol000000ooooooo0000o`00
0003ooooo`?o00000oooool2o`0000Gooooo0_l0000Fooooo`;o000000?oooooo`000?l000000ooo
ool2o`0003Kooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`12ooooo`?o00002_ooool2
o`0000Oooooo0_l0000Sooooo`;o00002_ooool2o`000003ooooool0003o000000Cooooo5Ol00003
ooooo`;o00001?ooool2o`0001gooooo0_l000001?oooooo0000o`000?ooool2o`0001oooooo0_l0
001Aooooo`007?ooool00ol0003oooooooooo`12ooooo`?o00002_ooool2o`0000Cooooo0_l00000
0ooooooo0000o`00000Sooooo`;o00002_ooool2o`0000Oooooo5Ol00003ooooo`;o000000?ooooo
o`000?l000001oooool2o`0001gooooo0_l0000Gooooo`;o00001Oooool3o`00057ooooo000Loooo
o`03o`000?oooooooooo04Cooooo0ol0000>ooooo`;o0000:_ooool2o`0000Cooooo0_l00002oooo
o`;o00000oooool2o`000003ooooool0003o000001?o00000_ooool2o`000003ooooool0003o0000
00Oooooo0_l0000fooooo`;o00001?ooool3o`0005;ooooo000Looooo`03o`000?oooooooooo04Co
oooo0ol0000<ooooo`Co0000:_ooool3o`0000?ooooo0_l00002ooooo`;o00000ooooolIo`000003
ooooool0003o000000[ooooo0_l0000Iooooo`;o00004Oooool2o`0000;ooooo0_l0000:ooooo`;o
0000Doooool001cooooo00?o0000ooooooooool0Doooool4o`0000Oooooo0_l0000>ooooo`?o0000
4Oooool2o`0000?ooooo0_l00007oooooaWo000000?oooooo`000?l000000_l00008ooooo`;o0000
2Oooool3o`0000gooooo0_l0000Aooooo`?o000000?oooooo`000?l00000Goooool001cooooo0_l0
001Fooooo`;o00000_ooool2o`0000?ooooo0_l0000>ooooo`?o000000?oooooo`000?l000001Ooo
ool4o`0001?ooooo6_l000001?oooooo0000o`000?l0000Cooooo`?o00008?ooool3o`0000Wooooo
0_l0000Gooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0AOooool2o`0000kooooo0_l0
0002ooooo`;o00000_ooool2o`0001?ooooo0_l00005ooooo`Co00005?oooolIo`000004ooooool0
003o0000o`0000kooooo0_l0000Eooooo`?o00006_ooool2o`0001Oooooo0_l0000nooooo`007?oo
ool00ol0003oooooooooo`15ooooo`;o00005_ooool2o`0002Cooooo0_l0000<oooooa[o000000?o
ooooo`000?l000003_ooool2o`000003ooooool0003o000001;ooooo0ol0000Dooooo`;o0000GOoo
ool001cooooo00?o0000ooooooooool0G?ooool2o`0002Gooooo0ol0000;oooooa[o00001oooool2
o`0000Kooooo0_l00003ooooo`;o00001oooool2o`00023ooooo0_l0001Mooooo`007?ooool00ol0
003oooooooooo`1Looooo`?o000000?oooooo`000?l000008_ooool2o`0000Kooooo0_l000000ooo
oooo0000o`00000Io`0000Sooooo0_l00002ooooo`;o00000_ooool2o`0000cooooo0_l0000Roooo
o`;o00005oooool2o`0004;ooooo000Looooo`03o`000?oooooooooo05gooooo0_l000000ooooooo
0000o`000006ooooo`;o00001_ooool2o`0000_ooooo0_l0000=ooooo`;o000000?oooooo`000?l0
00005ol000000ooooooo0000o`00000:ooooo`Ko0000<Oooool2o`0001Oooooo0_l00012ooooo`00
7?ooool00ol0003oooooooooo`1:ooooo`;o00004Oooool2o`0000Wooooo0_l00006ooooo`;o0000
2oooool2o`0000oooooo0ol000000ooooooo0000o`00000Do`000003ooooool0003o000000;o0000
2?ooool2o`000005ooooool0003o0000o`000?ooool00_l0002;ooooo`007?ooool00ol0003ooooo
ooooo`1:ooooo`;o00005?ooool2o`0001Wooooo1?l0000?ooooo`?o000000?oooooo`000?l00000
5?l00002ooooo`Go00003Oooool2o`0002Wooooo0_l0001Pooooo`007?ooool00ol0003ooooooooo
o`1<ooooo`;o00004_ooool2o`000003ooooool0003o000001Kooooo1?l0000?ooooo`?o000000?o
ooooo`000?l000002Ol000000ooooooo0000o`000007o`0000?ooooo1Ol00008ooooo`Go0000:ooo
ool4o`0001Oooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00000_ooool2
o`00017ooooo0_l00002ooooo`;o00008oooool2o`000004ooooool0003o0000oooooaCo000000?o
ooooo`000?l000000_ooool4o`0000Gooooo2?l0000]ooooo`;o00005oooool2o`0004Gooooo000L
ooooo`03o`000?oooooooooo04cooooo0ol000000ooooooo0000o`00000Dooooo`Go00008Oooool2
o`0000Cooooo5ol000000ooooooo0000o`000008ooooo`Go000000?oooooo`000?l00000SOooool0
01cooooo00?o0000ooooooooool0COooool2o`000003ooooool0003o000000;o00004_ooool5o`00
00[ooooo0_l0000?ooooo`;o00002?ooool2o`0000;ooooo5?l00002ooooo`?o00000_ooool2o`00
00;ooooo0ol0000aooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0D?ooool4o`0000go
oooo0_l00005ooooo`;o00000oooool2o`000003ooooool0003o000000;o000000Goooooo`000?l0
003o0000ooooo`03o`0000[ooooo0_l00007oooooaOo00001Oooool6o`0000;ooooo0_l000000ooo
oooo0000o`00000_ooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0D_ooool2o`0000go
oooo1?l00003ooooo`;o00000oooool2o`000003ooooool0003o000000_o00004_oooolDo`000003
ooooool0003o000000;ooooo0_l00003ooooo`Co00000_ooool2o`000003ooooool0003o000004Co
oooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`1Sooooo`;o00001oooool2o`0000Kooooo
0_l000000ooooooo0000o`000004o`0000?ooooo0_l00004ooooo`;o00002Oooool2o`000003oooo
ool0003o000000_o00000_ooool3o`0000;ooooo0ol00002ooooo`Co00000_ooool3o`0000Wooooo
0_l0000kooooo`;o0000Boooool001cooooo00?o0000ooooooooool0D?ooool2o`0001[ooooo0_l0
0003ooooo`;o00001oooool5o`000004ooooool0003o0000o`0000?ooooo0_l00005ooooo`;o0000
0_oooolEo`0000;ooooo0ol00003ooooo`Co000000?oooooo`000?l000000ol00007ooooo`;o0000
R?ooool001cooooo0_l0001Aooooo`;o00007_ooool3o`0000Wooooo0ol00002ooooo`;o00001?oo
ool2o`000004ooooool0003o0000ooooo`;o00000_ooool8o`0000;ooooo0_l000000ooooooo0000
o`000003o`000003ooooool0003o000000Co00001?ooool4o`0000;ooooo1?l0002Aooooo`007?oo
ool00ol0003oooooooooo`1Fooooo`?o00003oooool3o`0000Gooooo0ol00005ooooo`;o00000_oo
ool3o`000003ooooool0003o000000?ooooo1?l000000ooooooo0000o`000004ooooo`;o00001?oo
ool2o`0000kooooo1?l0000:ooooo`;o0000Toooool001cooooo00?o0000ooooooooool0E_ooool3
o`0000oooooo0ol00006ooooo`;o00000oooool5o`000005ooooool0003o0000o`000?ooool00_l0
0003ooooo`?o00002?ooool2o`0000Cooooo0_l0000@ooooo`;o000000?oooooo`000?l000001_oo
ool2o`0004;ooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`1fooooo`;o000000?ooooo
o`000?l000001?l00006ooooo`?o00001oooool3o`0000Cooooo0_l00003ooooo`;o00002oooool2
o`000004ooooool0003o0000ooooo`;o00000oooool2o`0004;ooooo0_l0001@ooooo`007?ooool0
0ol0003oooooooooo`1Kooooo`;o00006Oooool2o`0000;ooooo2_l000001?oooooo0000o`000?l0
0004ooooo`;o000000Coooooo`000?l0003o00002Oooool2o`0000Kooooo0_l00009ooooo`;o0000
0oooool2o`00043ooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`1Kooooo`;o00007_oo
ool9o`000003ooooool0003o000000Gooooo0_l0000Eooooo`;o00003_ooool2o`00043ooooo0_l0
001Booooo`007?ooool00ol0003oooooooooo`1mooooo`;o00000oooool2o`0000;ooooo0_l00004
ooooo`;o00001?ooool2o`0000cooooo0_l00008ooooo`Co000000?oooooo`000?l000000_ooool2
o`0002[ooooo0_l0001Xooooo`007?ooool00ol0003oooooooooo`1booooo`?o00003_ooool5o`00
0004ooooool0003o0000ooooo`;o00001?ooool2o`0000?ooooo0_l00007ooooo`;o00001_ooool6
o`000003ooooool0003o000000;ooooo0_l0000Xooooo`Co0000J?ooool001cooooo00?o0000oooo
ooooool0L_ooool3o`0000kooooo1?l00002ooooo`;o00001oooool2o`0000?ooooo0_l0000?oooo
o`;o00001oooool2o`0002[ooooo0_l0001Zooooo`007?ooool00ol0003oooooooooo`1Qooooo`;o
00004?ooool2o`0001?ooooo0ol00007ooooo`;o00000oooool4o`0000Sooooo0_l00003ooooo`;o
000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00000mooooo`;o0000Eoooool001co
oooo00?o0000ooooooooool0HOooool2o`0002Cooooo1?l00009ooooo`;o000000?oooooo`000?l0
00000_l00008ooooo`?o00000_ooool5o`000003ooooool0003o0000043ooooo0_l0001Gooooo`00
7?ooool00ol0003oooooooooo`1Qooooo`;o00004oooool2o`0000Wooooo0_l00004ooooo`;o0000
00?oooooo`000?l000002?ooool3o`0000gooooo1?l000000ooooooo0000o`000004o`0009[ooooo
000Looooo`03o`000?oooooooooo07Kooooo0_l00009ooooo`;o00001oooool4o`0000Oooooo0_l0
0008ooooo`?o00000oooool3o`000003ooooool0003o000000Oo00009oooool2o`0006kooooo000L
ooooo`03o`000?oooooooooo08_ooooo0ol0000;ooooo`;o00001?ooool3o`0000?ooooo0_l00002
ooooo`Go000000Coooooo`000?l0003o00009oooool2o`0006kooooo00001_ooooook^k^oc8b<_l0
003o<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003o
ooooooooo`1iooooo`;o00002Oooool2o`0001?ooooo1Ol0000>ooooo`;o00000_ooool2o`0000[o
oooo0_l0002;ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ
8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0J_ooool2o`0000gooooo0ol00008
ooooo`;o00001_ooool3o`0000cooooo0ol0000@ooooo`Co00002_ooool2o`0008_ooooo00000ooo
oooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo06[ooooo0_l0000>ooooo`Co00003_ooool3o`0001oooooo0_l0002I
ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9Sooooo
oiRHV?lb<S801_ooool3o`0006cooooo0_l0000>ooooo`;o00004?ooool2o`0000_ooooo0_l0000;
ooooo`;o0000:_ooool2o`0007?ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00Wooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo06cooooo0_l0000P
ooooo`?o00002_ooool2o`0000_ooooo0_l0000:ooooo`;o00007_ooool2o`00013ooooo0ol0001P
ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooo
okZj^_l@41001_ooool00ol0003oooooooooo`20ooooo`;o00003Oooool2o`0000[ooooo0_l00003
ooooo`;o00004_ooool2o`00033ooooo0ol0001Pooooo`0000KoooooogMgMonHV9SooooooiRHV?mg
MgL;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`20ooooo`;o0000
6Oooool2o`0000?ooooo0_l0002Wooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05
ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`1`ooooo`;o0000eoooool001co
oooo00?o0000ooooooooool0L?ooool4o`0001kooooo1?l0000cooooo`Co0000O?ooool001cooooo
00?o0000ooooooooool0L_ooool2o`0001?ooooo0_l00009ooooo`Co000000?oooooo`000?l00000
2_ooool2o`0000Cooooo0_l0000Nooooo`Co0000O?ooool001cooooo00?o0000ooooooooool0Qooo
ool3o`0000cooooo0ol0000:ooooo`;o00001?ooool2o`000003ooooool0003o000001;ooooo0_l0
0027ooooo`007?ooool00ol0003oooooooooo`1eooooo`;o00004Oooool4o`0000[ooooo0_l0000A
ooooo`Go00002Oooool2o`0000Oooooo0_l00027ooooo`007?ooool00ol0003oooooooooo`1eoooo
o`;o00004oooool2o`0001gooooo0ol00004ooooo`;o00001Oooool2o`0000;ooooo0_l0002<oooo
o`007?ooool00ol0003oooooooooo`1gooooo`;o00005_ooool2o`0001oooooo0_l00004ooooo`;o
00000oooool2o`0000_ooooo0_l00002ooooo`;o00000oooool2o`0007Kooooo000Looooo`03o`00
0?oooooooooo07Oooooo0_l0000Fooooo`;o00008oooool4o`0000Wooooo0_l00003ooooo`Go0000
00?oooooo`000?l000000oooool2o`0000Kooooo0_l0001^ooooo`007?ooool00ol0003ooooooooo
o`2/ooooo`;o00001_ooool4o`0000Wooooo0_l000000ooooooo0000o`000002o`000004ooooool0
003o0000ooooo`;o00002Oooool4o`0006kooooo000Looooo`03o`000?oooooooooo09Cooooo0ol0
000Eooooo`;o000000?oooooo`000?l000001Oooool2o`0000[ooooo1?l0000Aooooo`;o0000L?oo
ool001cooooo00?o0000ooooooooool0U?ooool4o`0001Oooooo0_l0000Aooooo`;o0000QOooool0
01cooooo00?o0000ooooooooool0U_ooool2o`000;7ooooo000Looooo`;o0000coooool2o`0007Wo
oooo000Looooo`03o`000?oooooooooo0<3ooooo0_l00007ooooo`?o00000_ooool2o`0007Wooooo
000Looooo`03o`000?oooooooooo0:Kooooo0ol0000Gooooo`;o00001oooool3o`0007gooooo000L
ooooo`03o`000?oooooooooo08[ooooo0_l0000Jooooo`Go00004?ooool2o`0008cooooo000Loooo
o`03o`000?oooooooooo08[ooooo0_l0000Mooooo`;o00002Oooool2o`0000?ooooo1?l0002<oooo
o`007?ooool00ol0003oooooooooo`2:ooooo`Co00009_ooool2o`0000?ooooo0_l0002>ooooo`00
7?ooool00ol0003oooooooooo`2<ooooo`;o0000^oooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo09Wooooo0_l0002^ooooo`007?ooool0
0ol0003oooooooooo`2Iooooo`Co0000[?ooool001cooooo00?o0000ooooooooool0Voooool2o`00
0003ooooool0003o00000:Wooooo000Looooo`03o`000?oooooooooo09kooooo0_l0002Yooooo`00
7?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0ZOooool2o`0009kooooo000L
ooooo`03o`000?oooooooooo0:Wooooo0_l0002Nooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Booooo`Co0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05
ooooo`?o0000oooooom:ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03
o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?oo
ool00ol0003oooooooooo`3ooooooe;ooooo000Booooo`03oeEEEOmVIVKo00000?ooooooE?ooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Gooooo00Co410@o`000?l0003ooooo
0_l000000ol@413oooooooooo`0Gooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h00oooool5o`00093ooooo002Vooooo`05o`000?ooooooooooooooool000002Oooool6
o`0000cooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go
V9RHob4Q8Oo^k^koooooodA4A02@ooooo`00Y_ooool01Ol0003ooooooooooooooooo000001Sooooo
1Ol00003ooooo`05oa0@4?ooooooooooooooool@41001?ooool00onHV9So8B4Qonk^kP2Aooooo`00
Y_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l00009ooooo`04odA4A?oMgMgoooooo`00
00Cooooo00Go0000ooooooooooooooooo`000005ooooo`03oiRHV?lQ8B7ok^k^093ooooo002Voooo
o`05o`000?n7QhOoooooojVYZOl000006?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?oo
ooooooooooooool000001_ooool00omgMgOoIVIVooooo`2?ooooo`00YOooool00ol@413o0000ogMg
M`02o`000003oiRHV?oooooooooo01Oooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooo
oooooooo410@00Oooooo00?o0000ooooooooool0S_ooool00<Cooooo00?ok^k^odA4A?l000001?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go0000okZj^_ooooooV9RHoa0@402@ooooo`00
aOooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01OnHV9So
410@o`000?lQ8B7oc<c<093ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000
\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(408) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.32166 .47653 Mdot
.31909 .51865 Mdot
.65275 .67911 Mdot
.49153 .40136 Mdot
.72557 .45767 Mdot
.62959 .65388 Mdot
.47822 .69549 Mdot
.47885 .69188 Mdot
.62229 .63869 Mdot
.24629 .3861 Mdot
.46008 .7232 Mdot
.55922 .3415 Mdot
.46775 .70573 Mdot
.50515 .37585 Mdot
.45406 .47572 Mdot
.45886 .35275 Mdot
.30776 .53092 Mdot
.767 .48454 Mdot
.46739 .33247 Mdot
.67821 .65626 Mdot
.51703 .23439 Mdot
.50508 .36333 Mdot
.35812 .50186 Mdot
.50375 .37326 Mdot
.48531 .34667 Mdot
.33659 .51625 Mdot
.33179 .47254 Mdot
.49101 .34523 Mdot
.54851 .34247 Mdot
.46033 .71897 Mdot
.57908 .58623 Mdot
.44709 .18306 Mdot
.48447 .42048 Mdot
.38062 .30496 Mdot
.48718 .69928 Mdot
.41817 .67807 Mdot
.66809 .64473 Mdot
.43085 .70758 Mdot
.49088 .70378 Mdot
.48783 .72547 Mdot
.47768 .73001 Mdot
.34188 .51267 Mdot
.46393 .74051 Mdot
.5573 .80583 Mdot
.49597 .3915 Mdot
.4132 .45743 Mdot
.51322 .79742 Mdot
.51568 .3239 Mdot
.31326 .52851 Mdot
.67722 .66808 Mdot
.71839 .39282 Mdot
.43916 .68887 Mdot
.44087 .58531 Mdot
.72898 .79589 Mdot
.47277 .71626 Mdot
.48347 .3251 Mdot
.6334 .62238 Mdot
.53065 .36968 Mdot
.48775 .40422 Mdot
.37487 .27309 Mdot
.5251 .35209 Mdot
.74612 .49016 Mdot
.29365 .53255 Mdot
.63286 .61132 Mdot
.61903 .64192 Mdot
.43202 .70999 Mdot
.35904 .52679 Mdot
.45794 .70384 Mdot
.5527 .36136 Mdot
.66653 .67386 Mdot
.54233 .3339 Mdot
.45631 .71952 Mdot
.35388 .48357 Mdot
.48971 .39092 Mdot
.36484 .72169 Mdot
.4782 .78654 Mdot
.59975 .6137 Mdot
.45388 .23409 Mdot
.79734 .42928 Mdot
.57677 .55446 Mdot
.492 .37905 Mdot
.76162 .70353 Mdot
.51911 .50762 Mdot
.30913 .50997 Mdot
.35631 .56255 Mdot
.32247 .59429 Mdot
.50676 .32873 Mdot
.55409 .59037 Mdot
.46152 .38221 Mdot
.68136 .52375 Mdot
.63665 .62707 Mdot
.31036 .49802 Mdot
.49221 .38867 Mdot
.54124 .39029 Mdot
.22581 .45486 Mdot
.53342 .31251 Mdot
.48351 .39809 Mdot
.34382 .57252 Mdot
.45346 .72446 Mdot
.44458 .3288 Mdot
.6978 .43502 Mdot
.41243 .58172 Mdot
.48825 .32385 Mdot
.65237 .64048 Mdot
.28475 .51277 Mdot
.47266 .38602 Mdot
.46244 .69221 Mdot
.4955 .37415 Mdot
.49485 .73243 Mdot
.33324 .5431 Mdot
.51635 .41224 Mdot
.7505 .47003 Mdot
.55131 .26981 Mdot
.35425 .50529 Mdot
.37152 .4135 Mdot
.51516 .34977 Mdot
.53654 .3654 Mdot
.32072 .52253 Mdot
.66931 .66459 Mdot
.68578 .72638 Mdot
.35532 .49223 Mdot
.48824 .72579 Mdot
.30524 .52515 Mdot
.5738 .32062 Mdot
.67319 .65804 Mdot
.41618 .56964 Mdot
.41288 .56779 Mdot
.65335 .36266 Mdot
.48763 .38501 Mdot
.58325 .2883 Mdot
.64406 .64583 Mdot
.33816 .52295 Mdot
.46131 .7119 Mdot
.49124 .3132 Mdot
.34442 .49715 Mdot
.47488 .68709 Mdot
.70897 .48746 Mdot
.76582 .46408 Mdot
.33963 .53081 Mdot
.36426 .4389 Mdot
.49518 .74193 Mdot
.47746 .73461 Mdot
.71404 .39245 Mdot
.30899 .51123 Mdot
.73616 .47793 Mdot
.45997 .68362 Mdot
.67411 .26963 Mdot
.48735 .40839 Mdot
.68181 .39018 Mdot
.72512 .72919 Mdot
.71829 .39318 Mdot
.42438 .21384 Mdot
.74581 .47057 Mdot
.47329 .68522 Mdot
.53388 .32459 Mdot
.3287 .50035 Mdot
.34384 .502 Mdot
.54707 .36656 Mdot
.47691 .37589 Mdot
.50901 .38676 Mdot
.4754 .40024 Mdot
.51545 .65203 Mdot
.49325 .38542 Mdot
.25087 .67519 Mdot
.33504 .49363 Mdot
.4773 .35714 Mdot
.66147 .65927 Mdot
.43643 .38836 Mdot
.44713 .73134 Mdot
.49034 .40398 Mdot
.47911 .36655 Mdot
.53302 .30449 Mdot
.49146 .72238 Mdot
.35809 .73429 Mdot
.8104 .414 Mdot
.41828 .71031 Mdot
.44884 .79599 Mdot
.64437 .65741 Mdot
.52689 .34524 Mdot
.7216 .48184 Mdot
.44008 .35445 Mdot
.51272 .40455 Mdot
.7274 .39427 Mdot
.48598 .36776 Mdot
.44416 .21405 Mdot
.55028 .40517 Mdot
.34656 .59663 Mdot
.231 .62468 Mdot
.50363 .40768 Mdot
.2791 .37312 Mdot
.67408 .40133 Mdot
.64172 .58781 Mdot
.46297 .71638 Mdot
.64621 .67266 Mdot
.6626 .6707 Mdot
.4298 .69464 Mdot
.39575 .40384 Mdot
.26068 .365 Mdot
.54436 .32566 Mdot
.41475 .57935 Mdot
.3495 .55145 Mdot
.74715 .47338 Mdot
.33634 .53229 Mdot
.78787 .67486 Mdot
.60205 .54104 Mdot
.553 .5767 Mdot
.77 .49508 Mdot
.68478 .65798 Mdot
.4207 .57625 Mdot
.72913 .4801 Mdot
.51673 .39175 Mdot
.32926 .54093 Mdot
.68336 .39692 Mdot
.4417 .3622 Mdot
.15579 .4466 Mdot
.33624 .47366 Mdot
.62922 .36033 Mdot
.47064 .71387 Mdot
.60453 .63517 Mdot
.50576 .32913 Mdot
.52001 .36764 Mdot
.34829 .54237 Mdot
.53433 .32939 Mdot
.53879 .55386 Mdot
.48042 .36945 Mdot
.63319 .61216 Mdot
.79607 .5003 Mdot
.42504 .71681 Mdot
.74859 .51798 Mdot
.35637 .48874 Mdot
.39572 .80804 Mdot
.66012 .64494 Mdot
.42736 .35443 Mdot
.45181 .70699 Mdot
.70967 .4833 Mdot
.65664 .63569 Mdot
.76186 .48154 Mdot
.51618 .4102 Mdot
.66575 .63806 Mdot
.75077 .48552 Mdot
.51391 .56212 Mdot
.47384 .39066 Mdot
.64262 .30803 Mdot
.44816 .68382 Mdot
.30199 .50338 Mdot
.52896 .39445 Mdot
.44203 .59308 Mdot
.53814 .29978 Mdot
.62421 .41295 Mdot
.43853 .58913 Mdot
.41756 .59747 Mdot
.55634 .53958 Mdot
.71561 .50425 Mdot
.40414 .74726 Mdot
.53449 .58718 Mdot
.30791 .53133 Mdot
.5286 .40056 Mdot
.40958 .63954 Mdot
.45328 .68044 Mdot
.52232 .38628 Mdot
.38656 .62374 Mdot
.46126 .68305 Mdot
.53439 .3712 Mdot
.47921 .72753 Mdot
.33849 .49854 Mdot
.51796 .53018 Mdot
.29635 .50427 Mdot
.5068 .40018 Mdot
.47353 .72825 Mdot
.65179 .6723 Mdot
.33661 .51532 Mdot
.49812 .36875 Mdot
.49341 .3607 Mdot
.41705 .58706 Mdot
.47918 .3887 Mdot
.3675 .58344 Mdot
.51117 .32473 Mdot
.66913 .67714 Mdot
.54039 .32215 Mdot
.70636 .42222 Mdot
.68151 .49667 Mdot
.34152 .54272 Mdot
.43828 .59026 Mdot
.64641 .62496 Mdot
.51269 .54101 Mdot
.62176 .30193 Mdot
.49621 .38111 Mdot
.43259 .59314 Mdot
.6355 .37901 Mdot
.44793 .73109 Mdot
.47664 .42354 Mdot
.60505 .69541 Mdot
.64035 .6281 Mdot
.41636 .57651 Mdot
.44914 .3333 Mdot
.36522 .47894 Mdot
.49445 .31756 Mdot
.66553 .64301 Mdot
.29943 .49992 Mdot
.52191 .30888 Mdot
.4969 .78683 Mdot
.44275 .59429 Mdot
.45872 .72998 Mdot
.35464 .57314 Mdot
.53764 .34963 Mdot
.65274 .67605 Mdot
.34798 .50334 Mdot
.47981 .71236 Mdot
.35577 .50101 Mdot
.68605 .40431 Mdot
.62149 .39295 Mdot
.46861 .59783 Mdot
.73261 .51503 Mdot
.62442 .18766 Mdot
.41771 .71689 Mdot
.4418 .3387 Mdot
.58933 .65905 Mdot
.22165 .53584 Mdot
.65108 .63578 Mdot
.35773 .44037 Mdot
.63456 .62485 Mdot
.50379 .31825 Mdot
.62508 .65118 Mdot
.21211 .46814 Mdot
.49221 .34962 Mdot
.61614 .64854 Mdot
.52985 .64501 Mdot
.49252 .35232 Mdot
.34504 .49525 Mdot
.35278 .20737 Mdot
.40061 .32733 Mdot
.39806 .35393 Mdot
.6296 .6208 Mdot
.31842 .43824 Mdot
.49482 .33988 Mdot
.47301 .32346 Mdot
.3283 .50506 Mdot
.54584 .30798 Mdot
.72901 .50923 Mdot
.7615 .4905 Mdot
.70408 .33327 Mdot
.5174 .2078 Mdot
.39066 .40113 Mdot
.33903 .50856 Mdot
.81551 .44961 Mdot
.35884 .71613 Mdot
.44265 .59316 Mdot
.47804 .6902 Mdot
.38176 .75022 Mdot
.45176 .35752 Mdot
.25631 .50574 Mdot
.5356 .55039 Mdot
.31409 .48782 Mdot
.48342 .58331 Mdot
.48127 .70767 Mdot
.39765 .3485 Mdot
.26705 .33908 Mdot
.5098 .38805 Mdot
.43677 .7054 Mdot
.56243 .33582 Mdot
.54716 .58786 Mdot
.6495 .34034 Mdot
.5565 .74058 Mdot
.50534 .3991 Mdot
.38851 .7276 Mdot
.51828 .40155 Mdot
.65889 .36808 Mdot
.5218 .3896 Mdot
.34902 .4928 Mdot
.51368 .29688 Mdot
.52767 .58643 Mdot
.66663 .21693 Mdot
.601 .53382 Mdot
.75359 .49443 Mdot
.50793 .37343 Mdot
.51843 .37995 Mdot
.74751 .49163 Mdot
.31277 .49229 Mdot
.53422 .39273 Mdot
.47863 .82173 Mdot
.49196 .38493 Mdot
.43743 .68857 Mdot
.60588 .46067 Mdot
.49432 .19042 Mdot
.51356 .33506 Mdot
.36597 .48322 Mdot
.47202 .73497 Mdot
.4501 .69595 Mdot
.51569 .44335 Mdot
.44554 .68459 Mdot
.53547 .32729 Mdot
.60479 .4615 Mdot
.35454 .52488 Mdot
.49111 .44024 Mdot
.3207 .48405 Mdot
.82314 .46359 Mdot
.46344 .68116 Mdot
.43666 .59719 Mdot
.38733 .41498 Mdot
.47049 .69462 Mdot
.74049 .53406 Mdot
.50766 .29851 Mdot
.45499 .41819 Mdot
.38421 .53533 Mdot
.64616 .67494 Mdot
.4314 .5845 Mdot
.47504 .71593 Mdot
.4953 .38719 Mdot
.47928 .33932 Mdot
.44019 .69067 Mdot
.35202 .24908 Mdot
.58072 .58577 Mdot
.50589 .4011 Mdot
.33873 .48712 Mdot
.33995 .52031 Mdot
.46507 .38037 Mdot
.52339 .39922 Mdot
.63228 .66346 Mdot
.43331 .59279 Mdot
.43612 .58898 Mdot
.41063 .57212 Mdot
.61464 .62381 Mdot
.6312 .19359 Mdot
.47595 .73548 Mdot
.45986 .18338 Mdot
.35676 .67076 Mdot
.56828 .40091 Mdot
.66671 .66112 Mdot
.52187 .35986 Mdot
.49274 .32574 Mdot
.4725 .72681 Mdot
.61407 .20834 Mdot
.47948 .31877 Mdot
.30875 .48713 Mdot
.4367 .69516 Mdot
.55768 .3261 Mdot
.49602 .74582 Mdot
.73069 .46535 Mdot
.38362 .39655 Mdot
.44507 .68339 Mdot
.34853 .53122 Mdot
.4446 .68366 Mdot
.51544 .38251 Mdot
.44903 .33171 Mdot
.31634 .48517 Mdot
.74957 .45532 Mdot
.54515 .37665 Mdot
.53434 .37616 Mdot
.71602 .64764 Mdot
.36717 .72122 Mdot
.71742 .52569 Mdot
.51179 .31983 Mdot
.45645 .42297 Mdot
.75559 .45978 Mdot
.54352 .36679 Mdot
.53758 .32001 Mdot
.5806 .28325 Mdot
.49093 .73969 Mdot
.70473 .49521 Mdot
.65625 .21628 Mdot
.33388 .47375 Mdot
.38375 .58605 Mdot
.41308 .57498 Mdot
.42926 .67946 Mdot
.50977 .52937 Mdot
.42176 .58293 Mdot
.3647 .65163 Mdot
.31801 .78116 Mdot
.43007 .58587 Mdot
.61846 .61707 Mdot
.25893 .44371 Mdot
.54358 .33126 Mdot
.51623 .39961 Mdot
.71978 .50546 Mdot
.3169 .52364 Mdot
.25123 .6674 Mdot
.42016 .70016 Mdot
.51125 .35551 Mdot
.33713 .46962 Mdot
.3307 .5959 Mdot
.41771 .58031 Mdot
.72485 .47472 Mdot
.73575 .45464 Mdot
.52583 .39558 Mdot
.63624 .34826 Mdot
.33945 .51202 Mdot
.4982 .36876 Mdot
.53775 .36124 Mdot
.66184 .62689 Mdot
.32842 .53993 Mdot
.66047 .65685 Mdot
.43816 .60746 Mdot
.19902 .5169 Mdot
.57675 .83567 Mdot
.44905 .68507 Mdot
.45463 .52213 Mdot
.42467 .71397 Mdot
.52583 .75509 Mdot
.43399 .59215 Mdot
.50101 .36631 Mdot
.3614 .50067 Mdot
.49606 .37194 Mdot
.49194 .3865 Mdot
.50132 .3957 Mdot
.38995 .39947 Mdot
.79664 .43725 Mdot
.71773 .49204 Mdot
.5351 .33881 Mdot
.63006 .618 Mdot
.37157 .59996 Mdot
.21232 .41643 Mdot
.51372 .37229 Mdot
.53658 .36669 Mdot
.36413 .51866 Mdot
.49979 .41546 Mdot
.47235 .69047 Mdot
.3088 .49186 Mdot
.48243 .33044 Mdot
.70534 .43353 Mdot
.53565 .38948 Mdot
.45555 .53456 Mdot
.46248 .67421 Mdot
.48468 .29692 Mdot
.51049 .42313 Mdot
.43498 .59278 Mdot
.43013 .58368 Mdot
.43822 .61505 Mdot
.43301 .69899 Mdot
.65938 .62621 Mdot
.63254 .60681 Mdot
.52598 .41371 Mdot
.52644 .3218 Mdot
.44281 .36377 Mdot
.67291 .68073 Mdot
.5402 .60253 Mdot
.37602 .44324 Mdot
.56309 .3648 Mdot
.60921 .63847 Mdot
.34709 .57308 Mdot
.4811 .23189 Mdot
.30537 .49806 Mdot
.60182 .67291 Mdot
.45483 .69588 Mdot
.75588 .47508 Mdot
.69854 .35884 Mdot
.35312 .49179 Mdot
.36396 .49486 Mdot
.63563 .66063 Mdot
.57978 .4712 Mdot
.7874 .74512 Mdot
.64489 .64083 Mdot
.54923 .57049 Mdot
.33204 .50684 Mdot
.48082 .41594 Mdot
.63675 .39291 Mdot
.56425 .47393 Mdot
.61449 .64039 Mdot
.49312 .36232 Mdot
.71973 .54604 Mdot
.63151 .66314 Mdot
.44563 .39494 Mdot
.62912 .62037 Mdot
.44891 .72432 Mdot
.64916 .64652 Mdot
.32102 .47185 Mdot
.48876 .38065 Mdot
.74622 .78115 Mdot
.50849 .51176 Mdot
.50053 .35771 Mdot
.44407 .68269 Mdot
.55064 .67178 Mdot
.51536 .38782 Mdot
.74497 .50593 Mdot
.62983 .61633 Mdot
.54055 .74532 Mdot
.51913 .31323 Mdot
.62408 .65391 Mdot
.3553 .46623 Mdot
.62564 .68804 Mdot
.68986 .4408 Mdot
.43393 .58605 Mdot
.33492 .49728 Mdot
.41364 .72638 Mdot
.48322 .72919 Mdot
.46934 .34366 Mdot
.53448 .35555 Mdot
.33224 .49074 Mdot
.50912 .55072 Mdot
.51802 .43925 Mdot
.49252 .38045 Mdot
.64767 .66348 Mdot
.67876 .63529 Mdot
.45427 .47194 Mdot
.66145 .6438 Mdot
.45855 .42479 Mdot
.33943 .49089 Mdot
.49059 .31862 Mdot
.3508 .50781 Mdot
.53079 .39884 Mdot
.5039 .74456 Mdot
.3049 .50633 Mdot
.44035 .32306 Mdot
.48644 .38221 Mdot
.39228 .49655 Mdot
.53509 .34633 Mdot
.49835 .39949 Mdot
.66984 .62543 Mdot
.73432 .49345 Mdot
.47667 .42162 Mdot
.49127 .77611 Mdot
.74679 .45901 Mdot
.39003 .22693 Mdot
.67304 .65758 Mdot
.71691 .46754 Mdot
.68561 .31971 Mdot
.43783 .58917 Mdot
.7367 .49821 Mdot
.40166 .56198 Mdot
.44341 .69087 Mdot
.29391 .48131 Mdot
.4906 .35834 Mdot
.2026 .50693 Mdot
.57683 .58756 Mdot
.42081 .59203 Mdot
.53567 .38393 Mdot
.52447 .36338 Mdot
.33848 .46985 Mdot
.77996 .6837 Mdot
.66731 .61844 Mdot
.47761 .39618 Mdot
.35267 .48696 Mdot
.74548 .71608 Mdot
.61484 .64733 Mdot
.71401 .48636 Mdot
.48621 .6886 Mdot
.33682 .55286 Mdot
.43804 .59771 Mdot
.46649 .68197 Mdot
.59141 .62064 Mdot
.73297 .39519 Mdot
.50301 .31587 Mdot
.66445 .65959 Mdot
.71982 .39348 Mdot
.49642 .43929 Mdot
.42713 .7051 Mdot
.45652 .78467 Mdot
.31045 .50369 Mdot
.43956 .69136 Mdot
.73036 .50676 Mdot
.31763 .53871 Mdot
.31749 .48587 Mdot
.46792 .68817 Mdot
.21699 .59522 Mdot
.63465 .38107 Mdot
.44812 .67106 Mdot
.62493 .41892 Mdot
.71956 .39446 Mdot
.42909 .60064 Mdot
.72715 .47357 Mdot
.81348 .46873 Mdot
.34045 .51408 Mdot
.37892 .74819 Mdot
.72018 .39269 Mdot
.48327 .39808 Mdot
.7522 .48487 Mdot
.37952 .59674 Mdot
.44154 .6514 Mdot
.46924 .68513 Mdot
.7086 .6626 Mdot
.75585 .48221 Mdot
.50747 .41043 Mdot
.53135 .17863 Mdot
.50375 .34021 Mdot
.45684 .68357 Mdot
.53701 .55189 Mdot
.33317 .53965 Mdot
.45074 .73401 Mdot
.53923 .55384 Mdot
.49904 .3221 Mdot
.51251 .3477 Mdot
.79264 .46425 Mdot
.31903 .53549 Mdot
.43525 .60586 Mdot
.49304 .36954 Mdot
.53211 .37216 Mdot
.46718 .35323 Mdot
.57584 .22339 Mdot
.50952 .25879 Mdot
.47065 .36573 Mdot
.60554 .65097 Mdot
.44256 .34683 Mdot
.48108 .4035 Mdot
.36495 .47696 Mdot
.73485 .42708 Mdot
.43729 .60873 Mdot
.51921 .39711 Mdot
.50786 .40065 Mdot
.49086 .7063 Mdot
.63522 .38115 Mdot
.55695 .47753 Mdot
.68031 .66837 Mdot
.68754 .621 Mdot
.55635 .36323 Mdot
.32695 .496 Mdot
.71221 .50662 Mdot
.48025 .43619 Mdot
.31397 .48329 Mdot
.5505 .37911 Mdot
.64092 .61664 Mdot
.43006 .58933 Mdot
.48622 .44268 Mdot
.74462 .48731 Mdot
.49209 .74317 Mdot
.41071 .22432 Mdot
.65103 .67036 Mdot
.49336 .3357 Mdot
.65145 .60639 Mdot
.6321 .63897 Mdot
.41762 .58954 Mdot
.45931 .30881 Mdot
.34006 .5011 Mdot
.34749 .53058 Mdot
.76335 .42288 Mdot
.61665 .62127 Mdot
.70839 .61676 Mdot
.44194 .71749 Mdot
.5376 .3429 Mdot
.42279 .62501 Mdot
.34302 .53397 Mdot
.6539 .3614 Mdot
.72607 .45958 Mdot
.46648 .68459 Mdot
.40843 .56194 Mdot
.30358 .50307 Mdot
.34516 .52973 Mdot
.49322 .38914 Mdot
.51088 .36483 Mdot
.61165 .59813 Mdot
.67563 .39617 Mdot
.48126 .72523 Mdot
.71783 .47591 Mdot
.66751 .67608 Mdot
.51958 .31666 Mdot
.31073 .5093 Mdot
.50452 .189 Mdot
.53684 .34913 Mdot
.63044 .61818 Mdot
.32069 .51785 Mdot
.71496 .49363 Mdot
.72495 .50426 Mdot
.49108 .39942 Mdot
.4543 .21564 Mdot
.46744 .6942 Mdot
.34638 .49433 Mdot
.37212 .55648 Mdot
.53137 .33269 Mdot
.51102 .37028 Mdot
.57537 .34978 Mdot
.43587 .72402 Mdot
.5158 .43226 Mdot
.76179 .46864 Mdot
.34223 .52375 Mdot
.49614 .36519 Mdot
.74565 .49122 Mdot
.25621 .50351 Mdot
.42388 .58708 Mdot
.6196 .65422 Mdot
.75123 .5017 Mdot
.73441 .48408 Mdot
.73824 .45854 Mdot
.38275 .74974 Mdot
.28105 .48851 Mdot
.77761 .34358 Mdot
.48977 .37113 Mdot
.71956 .39486 Mdot
.46278 .36642 Mdot
.4448 .72626 Mdot
.63674 .67206 Mdot
.50007 .39032 Mdot
.48981 .37023 Mdot
.42775 .226 Mdot
.46107 .34422 Mdot
.4647 .33374 Mdot
.3373 .54036 Mdot
.38203 .55388 Mdot
.65642 .67358 Mdot
.7134 .73894 Mdot
.38095 .17462 Mdot
.54618 .32791 Mdot
.58436 .46933 Mdot
.307 .49839 Mdot
.48988 .69923 Mdot
.62951 .41215 Mdot
.43783 .63695 Mdot
.32816 .52885 Mdot
.50744 .31749 Mdot
.40812 .23194 Mdot
.75629 .46987 Mdot
.51086 .38481 Mdot
.45813 .71008 Mdot
.50999 .3858 Mdot
.43242 .7049 Mdot
.36334 .44727 Mdot
.53837 .49056 Mdot
.48784 .36202 Mdot
.53436 .31373 Mdot
.57897 .28926 Mdot
.51317 .36923 Mdot
.56476 .72598 Mdot
.32178 .51298 Mdot
.43407 .33698 Mdot
.47953 .32662 Mdot
.39393 .32065 Mdot
.54105 .36738 Mdot
.49221 .52849 Mdot
.52364 .34706 Mdot
.62886 .2235 Mdot
.49847 .41112 Mdot
.52529 .34493 Mdot
.48233 .7146 Mdot
.49048 .71982 Mdot
.37433 .48047 Mdot
.42804 .60458 Mdot
.35494 .5968 Mdot
.53601 .37284 Mdot
.68678 .65282 Mdot
.54809 .45516 Mdot
.73299 .48934 Mdot
.34019 .5246 Mdot
.46779 .88824 Mdot
.46608 .7356 Mdot
.61598 .6191 Mdot
.55651 .58466 Mdot
.60142 .64789 Mdot
.58902 .65579 Mdot
.38892 .53127 Mdot
.72866 .47129 Mdot
.53208 .39348 Mdot
.38779 .30294 Mdot
.37827 .72032 Mdot
.52982 .33056 Mdot
.69396 .64353 Mdot
.59893 .3935 Mdot
.76185 .41766 Mdot
.76007 .49745 Mdot
.73899 .47163 Mdot
.47831 .71118 Mdot
.65555 .67759 Mdot
.56433 .36086 Mdot
.7159 .46864 Mdot
.64102 .67162 Mdot
.41618 .56404 Mdot
.78016 .44776 Mdot
.34157 .50978 Mdot
.33009 .43697 Mdot
.41438 .47903 Mdot
.47072 .73426 Mdot
.48493 .78188 Mdot
.3115 .46382 Mdot
.30082 .52554 Mdot
.41779 .59596 Mdot
.61191 .63615 Mdot
.29653 .47728 Mdot
.48922 .38353 Mdot
.44158 .3631 Mdot
.52552 .39634 Mdot
.71637 .50343 Mdot
.53946 .37519 Mdot
.62922 .66406 Mdot
.48494 .70251 Mdot
.64097 .62617 Mdot
.47904 .6969 Mdot
.40231 .19157 Mdot
.49355 .40557 Mdot
.5084 .37002 Mdot
.60135 .46303 Mdot
.34287 .53009 Mdot
.37413 .31125 Mdot
.62814 .6186 Mdot
.63633 .62253 Mdot
.48749 .32152 Mdot
.33489 .54759 Mdot
.73633 .53216 Mdot
.62852 .42869 Mdot
.52684 .34999 Mdot
.32055 .51204 Mdot
.48715 .32099 Mdot
.52728 .73393 Mdot
.5011 .50062 Mdot
.35632 .50414 Mdot
.6689 .21724 Mdot
.4848 .39052 Mdot
.47806 .2916 Mdot
.51773 .2831 Mdot
.57093 .22974 Mdot
.47247 .41603 Mdot
.33219 .47475 Mdot
.48044 .40176 Mdot
.32172 .49936 Mdot
.63845 .6357 Mdot
.46241 .73897 Mdot
.32431 .50197 Mdot
.49741 .34666 Mdot
.38809 .17339 Mdot
.48604 .70268 Mdot
.50543 .38384 Mdot
.46801 .72294 Mdot
.29196 .49243 Mdot
.32367 .53327 Mdot
.40555 .56318 Mdot
.55085 .57239 Mdot
.47037 .69072 Mdot
.52727 .32263 Mdot
.36156 .72984 Mdot
.49187 .31805 Mdot
.68983 .62398 Mdot
.52579 .30494 Mdot
.55482 .36539 Mdot
.62658 .1847 Mdot
.50605 .54362 Mdot
.60464 .83283 Mdot
.47918 .64533 Mdot
.35454 .72983 Mdot
.37895 .53032 Mdot
.76011 .49711 Mdot
.47015 .54057 Mdot
.43655 .58358 Mdot
.60707 .65611 Mdot
.49689 .38916 Mdot
.25496 .5347 Mdot
.44285 .67609 Mdot
.72793 .49567 Mdot
.48612 .36699 Mdot
.61096 .67146 Mdot
.43074 .48928 Mdot
.46973 .68439 Mdot
.34268 .51245 Mdot
.33299 .53295 Mdot
.79574 .42336 Mdot
.49854 .36177 Mdot
.50707 .36408 Mdot
.4871 .70148 Mdot
.56656 .37109 Mdot
.73429 .46081 Mdot
.53041 .6431 Mdot
.45788 .71238 Mdot
.50744 .50364 Mdot
.32956 .54248 Mdot
.52337 .36179 Mdot
.6072 .45908 Mdot
.31775 .71668 Mdot
.23092 .41189 Mdot
.74553 .47638 Mdot
.62955 .32712 Mdot
.33342 .47443 Mdot
.46261 .71367 Mdot
.69462 .32817 Mdot
.49345 .30595 Mdot
.52678 .36508 Mdot
.60702 .2668 Mdot
.62782 .4267 Mdot
.55246 .58175 Mdot
.57886 .34693 Mdot
.64586 .40159 Mdot
.48856 .32085 Mdot
.48009 .33775 Mdot
.55452 .37188 Mdot
.5196 .30281 Mdot
.31787 .50755 Mdot
.39469 .33944 Mdot
.63753 .65334 Mdot
.25213 .4084 Mdot
.69594 .62592 Mdot
.49623 .33967 Mdot
.50147 .32009 Mdot
.30793 .38939 Mdot
.59853 .43057 Mdot
.32966 .51354 Mdot
.37794 .54808 Mdot
.48199 .73185 Mdot
.46574 .33437 Mdot
.62228 .61857 Mdot
.52688 .28736 Mdot
.6248 .64109 Mdot
.31762 .50962 Mdot
.67163 .63776 Mdot
.48808 .68196 Mdot
.66479 .65866 Mdot
.60737 .6435 Mdot
.47791 .68541 Mdot
.3112 .52764 Mdot
.53118 .34736 Mdot
.47495 .68201 Mdot
.7474 .53014 Mdot
.71707 .50366 Mdot
.40666 .55792 Mdot
.47789 .41229 Mdot
.45758 .33781 Mdot
.49146 .79363 Mdot
.668 .63869 Mdot
.55067 .47471 Mdot
.30559 .50815 Mdot
.71295 .50601 Mdot
.31742 .50382 Mdot
.77478 .38239 Mdot
.74338 .48163 Mdot
.40446 .5604 Mdot
.67007 .3296 Mdot
.42457 .72023 Mdot
.53813 .30755 Mdot
.37803 .5554 Mdot
.62677 .63734 Mdot
.4368 .69093 Mdot
.3787 .5989 Mdot
.47621 .38796 Mdot
.44791 .59712 Mdot
.28941 .50101 Mdot
.4367 .58748 Mdot
.46066 .71043 Mdot
.41688 .51926 Mdot
.50405 .35536 Mdot
.42564 .72145 Mdot
.53438 .31188 Mdot
.36899 .42879 Mdot
.64534 .59658 Mdot
.29723 .55683 Mdot
.49876 .3189 Mdot
.61439 .64798 Mdot
.49404 .31962 Mdot
.27154 .44489 Mdot
.67134 .35738 Mdot
.55693 .36211 Mdot
.61147 .39748 Mdot
.50835 .78915 Mdot
.31087 .5078 Mdot
.4755 .42966 Mdot
.42452 .59706 Mdot
.49118 .33346 Mdot
.18332 .34272 Mdot
.74008 .49505 Mdot
.77083 .50065 Mdot
.49465 .3516 Mdot
.49393 .37366 Mdot
.43632 .22479 Mdot
.37521 .45907 Mdot
.40741 .56442 Mdot
.52691 .37165 Mdot
.58615 .2509 Mdot
.4804 .71494 Mdot
.51898 .30811 Mdot
.50765 .40353 Mdot
.67227 .58964 Mdot
.47608 .72063 Mdot
.67136 .65421 Mdot
.43762 .58794 Mdot
.6822 .64517 Mdot
.73082 .4532 Mdot
.63055 .35009 Mdot
.63941 .32741 Mdot
.48482 .4918 Mdot
.75 .50153 Mdot
.50221 .33481 Mdot
.3153 .56269 Mdot
.50191 .35085 Mdot
.73337 .4739 Mdot
.46038 .71917 Mdot
.32224 .50934 Mdot
.35705 .43859 Mdot
.41479 .58368 Mdot
.5219 .33185 Mdot
.74269 .51104 Mdot
.33042 .50108 Mdot
.29306 .71589 Mdot
.31495 .51968 Mdot
.47732 .69806 Mdot
.42979 .69578 Mdot
.73825 .48604 Mdot
.3164 .50428 Mdot
.67977 .64152 Mdot
.48619 .65406 Mdot
.5484 .31855 Mdot
.48943 .68271 Mdot
.32373 .46421 Mdot
.34909 .47203 Mdot
.35787 .524 Mdot
.47953 .32871 Mdot
.60529 .43927 Mdot
.56937 .31006 Mdot
.48675 .70301 Mdot
.61164 .66848 Mdot
.6796 .38765 Mdot
.40951 .27089 Mdot
.52334 .50168 Mdot
.466 .41784 Mdot
.53859 .37754 Mdot
.527 .39438 Mdot
.46921 .36582 Mdot
.51351 .63285 Mdot
.49393 .4055 Mdot
.47637 .72681 Mdot
.63041 .64559 Mdot
.52725 .35336 Mdot
.42988 .5972 Mdot
.54114 .5999 Mdot
.70425 .49998 Mdot
.38111 .39536 Mdot
.39093 .55528 Mdot
.32904 .50259 Mdot
.6648 .64593 Mdot
.67352 .63834 Mdot
.70901 .48755 Mdot
.46464 .67984 Mdot
.31906 .5263 Mdot
.63254 .22615 Mdot
.75033 .4625 Mdot
.52019 .3961 Mdot
.60363 .46181 Mdot
.55187 .22142 Mdot
.54841 .36436 Mdot
.50424 .39666 Mdot
.4339 .60785 Mdot
.60987 .62492 Mdot
.19071 .44292 Mdot
.22388 .61364 Mdot
.73624 .49162 Mdot
.7164 .47401 Mdot
.36338 .51251 Mdot
.54056 .34592 Mdot
.46489 .6947 Mdot
.63626 .37327 Mdot
.50514 .77195 Mdot
.32761 .59172 Mdot
.52781 .75267 Mdot
.53738 .38664 Mdot
.35803 .39688 Mdot
.53061 .30466 Mdot
.28438 .51139 Mdot
.34974 .53654 Mdot
.33542 .51092 Mdot
.48215 .71051 Mdot
.73647 .39565 Mdot
.47173 .72999 Mdot
.36951 .57557 Mdot
.34218 .47767 Mdot
.52139 .55253 Mdot
.63447 .62165 Mdot
.46035 .3595 Mdot
.73032 .47128 Mdot
.67277 .49629 Mdot
.47215 .42806 Mdot
.63041 .33464 Mdot
.66694 .66079 Mdot
.30246 .51268 Mdot
.46221 .36214 Mdot
.36313 .60061 Mdot
.57594 .47493 Mdot
.52378 .78323 Mdot
.26115 .53813 Mdot
.74838 .48909 Mdot
.25814 .37754 Mdot
.74246 .46146 Mdot
.46477 .68409 Mdot
.48557 .39282 Mdot
.54053 .35086 Mdot
.49977 .40039 Mdot
.49789 .30934 Mdot
.4738 .71738 Mdot
.55189 .32549 Mdot
.70738 .42182 Mdot
.4185 .56706 Mdot
.52338 .60115 Mdot
.72859 .50332 Mdot
.4424 .72001 Mdot
.63144 .64151 Mdot
.41417 .59198 Mdot
.73195 .51555 Mdot
.46535 .36705 Mdot
.4996 .3471 Mdot
.41463 .56563 Mdot
.4972 .44206 Mdot
.45198 .36325 Mdot
.63172 .65553 Mdot
.54314 .58819 Mdot
.70495 .48794 Mdot
.74849 .47005 Mdot
.43811 .69875 Mdot
.31711 .50351 Mdot
.70711 .48382 Mdot
.6472 .68042 Mdot
.51693 .31001 Mdot
.53815 .31648 Mdot
.32905 .46394 Mdot
.72436 .39375 Mdot
.70429 .50094 Mdot
.5129 .4333 Mdot
.34773 .51817 Mdot
.28923 .50207 Mdot
.52584 .37261 Mdot
.55974 .36812 Mdot
.36602 .51559 Mdot
.71081 .48564 Mdot
.43776 .70723 Mdot
.53945 .51967 Mdot
.46054 .73224 Mdot
.34742 .50559 Mdot
.44108 .35949 Mdot
.31513 .53348 Mdot
.47596 .3853 Mdot
.61616 .84646 Mdot
.49999 .40839 Mdot
.43629 .3009 Mdot
.64626 .54861 Mdot
.62691 .62105 Mdot
.61717 .62731 Mdot
.431 .59167 Mdot
.31187 .48548 Mdot
.46854 .4313 Mdot
.72779 .46949 Mdot
.35507 .72963 Mdot
.34583 .45475 Mdot
.60812 .64272 Mdot
.62194 .61669 Mdot
.46284 .71985 Mdot
.54093 .37084 Mdot
.52262 .35875 Mdot
.66613 .65755 Mdot
.55004 .66638 Mdot
.31874 .49456 Mdot
.50675 .36445 Mdot
.46943 .35618 Mdot
.63613 .65128 Mdot
.44257 .66565 Mdot
.30453 .46849 Mdot
.47801 .33115 Mdot
.66569 .35974 Mdot
.43817 .72034 Mdot
.50245 .32878 Mdot
.53408 .30344 Mdot
.73027 .48629 Mdot
.62469 .30761 Mdot
.71414 .39275 Mdot
.48546 .73376 Mdot
.43732 .5936 Mdot
.54666 .37004 Mdot
.62522 .62329 Mdot
.47162 .40626 Mdot
.20402 .66606 Mdot
.42543 .57046 Mdot
.50639 .35569 Mdot
.55424 .38936 Mdot
.35183 .50614 Mdot
.4996 .3659 Mdot
.50256 .74697 Mdot
.65341 .65949 Mdot
.50729 .35454 Mdot
.45283 .21863 Mdot
.46197 .71869 Mdot
.47364 .42785 Mdot
.7566 .47916 Mdot
.54695 .57261 Mdot
.35838 .20539 Mdot
.66778 .68261 Mdot
.7388 .50171 Mdot
.53982 .36896 Mdot
.68377 .66328 Mdot
.48765 .69077 Mdot
.48777 .26514 Mdot
.50474 .33214 Mdot
.46569 .73267 Mdot
.48294 .69832 Mdot
.74025 .48882 Mdot
.55713 .87065 Mdot
.55664 .36774 Mdot
.51183 .37939 Mdot
.41834 .82413 Mdot
.36809 .51066 Mdot
.50593 .38574 Mdot
.53773 .35956 Mdot
.44763 .68411 Mdot
.74855 .36217 Mdot
.62932 .32768 Mdot
.52729 .64324 Mdot
.43443 .71312 Mdot
.68512 .63271 Mdot
.65435 .66436 Mdot
.74296 .49912 Mdot
.32073 .51878 Mdot
.71181 .50299 Mdot
.6474 .6501 Mdot
.50262 .39899 Mdot
.44494 .70043 Mdot
.28904 .28757 Mdot
.45833 .6744 Mdot
.63804 .68183 Mdot
.28556 .50584 Mdot
.21858 .47055 Mdot
.22732 .70736 Mdot
.42038 .4645 Mdot
.43316 .72393 Mdot
.73272 .48933 Mdot
.23468 .64355 Mdot
.52739 .35242 Mdot
.31825 .42725 Mdot
.51123 .38295 Mdot
.25125 .51777 Mdot
.6374 .67181 Mdot
.41192 .56324 Mdot
.47593 .38776 Mdot
.62734 .3224 Mdot
.47698 .68605 Mdot
.45687 .6963 Mdot
.47987 .40036 Mdot
.47559 .69625 Mdot
.51731 .35665 Mdot
.63456 .64633 Mdot
.58526 .85189 Mdot
.51817 .3437 Mdot
.45691 .3044 Mdot
.43587 .73116 Mdot
.40877 .55485 Mdot
.66524 .61347 Mdot
.38207 .35706 Mdot
.33218 .59876 Mdot
.46625 .69638 Mdot
.38795 .39613 Mdot
.66424 .63769 Mdot
.41708 .59696 Mdot
.68244 .63465 Mdot
.51861 .3748 Mdot
.54024 .38173 Mdot
.46945 .37122 Mdot
.53828 .36458 Mdot
.2928 .42609 Mdot
.45318 .37042 Mdot
.30487 .31963 Mdot
.49009 .37053 Mdot
.42858 .31595 Mdot
.47062 .72858 Mdot
.48385 .28858 Mdot
.55987 .53093 Mdot
.51786 .40707 Mdot
.38499 .53698 Mdot
.44471 .72164 Mdot
.41088 .65793 Mdot
.47556 .71818 Mdot
.63816 .62591 Mdot
.47779 .68936 Mdot
.48185 .38974 Mdot
.33941 .51965 Mdot
.6576 .64437 Mdot
.41887 .45148 Mdot
.61406 .66795 Mdot
.50061 .35774 Mdot
.42491 .72817 Mdot
.64837 .6203 Mdot
.46519 .32649 Mdot
.33675 .52258 Mdot
.60977 .25089 Mdot
.29071 .5338 Mdot
.499 .37325 Mdot
.49989 .37952 Mdot
.4106 .56521 Mdot
.47351 .6854 Mdot
.33212 .5449 Mdot
.67246 .58467 Mdot
.72133 .51278 Mdot
.3272 .51732 Mdot
.51264 .28146 Mdot
.58659 .4696 Mdot
.35451 .50468 Mdot
.57324 .23894 Mdot
.45885 .68274 Mdot
.35125 .48112 Mdot
.55317 .30404 Mdot
.25818 .40447 Mdot
.74863 .46692 Mdot
.67673 .63438 Mdot
.64378 .41668 Mdot
.65404 .66321 Mdot
.48993 .74981 Mdot
.63642 .61212 Mdot
.47708 .72265 Mdot
.57246 .43721 Mdot
.53784 .55315 Mdot
.44775 .67664 Mdot
.44831 .74053 Mdot
.64011 .65797 Mdot
.47299 .39392 Mdot
.52943 .58803 Mdot
.46685 .43226 Mdot
.44003 .3794 Mdot
.46008 .73393 Mdot
.34443 .47513 Mdot
.31196 .53346 Mdot
.42704 .36107 Mdot
.33619 .53573 Mdot
.64894 .63893 Mdot
.4696 .48244 Mdot
.3877 .41614 Mdot
.45591 .71689 Mdot
.55693 .59045 Mdot
.4954 .32112 Mdot
.62481 .65771 Mdot
.64655 .63612 Mdot
.48273 .70027 Mdot
.24655 .42678 Mdot
.45157 .41389 Mdot
.37093 .49205 Mdot
.35034 .48426 Mdot
.35419 .50154 Mdot
.34014 .54522 Mdot
.73923 .39421 Mdot
.43679 .69128 Mdot
.31866 .48106 Mdot
.49473 .31233 Mdot
.5423 .35735 Mdot
.42635 .57766 Mdot
.71333 .49287 Mdot
.4916 .30798 Mdot
.46944 .43184 Mdot
.52558 .37087 Mdot
.62951 .62011 Mdot
.60566 .3406 Mdot
.41956 .56865 Mdot
.61637 .62081 Mdot
.6182 .62124 Mdot
.43547 .59269 Mdot
.58133 .42707 Mdot
.19751 .44163 Mdot
.48086 .39844 Mdot
.38967 .53483 Mdot
.61683 .63051 Mdot
.6627 .47564 Mdot
.41341 .3612 Mdot
.53363 .32633 Mdot
.5334 .62574 Mdot
.63866 .64182 Mdot
.37744 .52938 Mdot
.51592 .37214 Mdot
.41805 .59514 Mdot
.75355 .47211 Mdot
.54378 .27776 Mdot
.43274 .60726 Mdot
.31327 .5024 Mdot
.71146 .64486 Mdot
.3381 .46959 Mdot
.66042 .62336 Mdot
.47036 .42857 Mdot
.76883 .76195 Mdot
.62876 .63516 Mdot
.36338 .74139 Mdot
.53831 .55524 Mdot
.51336 .34558 Mdot
.66147 .65325 Mdot
.35482 .46243 Mdot
.43849 .72153 Mdot
.60807 .44683 Mdot
.31142 .51035 Mdot
.41307 .59013 Mdot
.42664 .5803 Mdot
.63646 .65314 Mdot
.34692 .48613 Mdot
.54238 .31216 Mdot
.33187 .5318 Mdot
.44836 .70129 Mdot
.47891 .36573 Mdot
.35334 .5968 Mdot
.45789 .31018 Mdot
.33727 .52962 Mdot
.62187 .67623 Mdot
.75159 .45642 Mdot
.49508 .34592 Mdot
.40543 .64027 Mdot
.54042 .36706 Mdot
.46563 .72243 Mdot
.64447 .52416 Mdot
.29241 .28868 Mdot
.52015 .39199 Mdot
.49643 .32162 Mdot
.48803 .68427 Mdot
.52031 .39047 Mdot
.55028 .34876 Mdot
.41585 .51775 Mdot
.3538 .50722 Mdot
.52879 .35628 Mdot
.64745 .66909 Mdot
.3556 .23522 Mdot
.48975 .39385 Mdot
.50393 .74769 Mdot
.60144 .25351 Mdot
.62701 .50021 Mdot
.44145 .4074 Mdot
.65449 .36377 Mdot
.50346 .37947 Mdot
.53484 .32991 Mdot
.48043 .3991 Mdot
.35598 .4035 Mdot
.64577 .6546 Mdot
.61533 .65465 Mdot
.7606 .48359 Mdot
.60106 .25744 Mdot
.74947 .48031 Mdot
.47953 .67864 Mdot
.55504 .58157 Mdot
.41354 .56935 Mdot
.31811 .50209 Mdot
.4926 .39472 Mdot
.61918 .67038 Mdot
.52191 .36362 Mdot
.49326 .33175 Mdot
.64764 .64255 Mdot
.64109 .63694 Mdot
.66325 .68561 Mdot
.75654 .46867 Mdot
.32943 .50923 Mdot
.48523 .39752 Mdot
.74752 .45925 Mdot
.46801 .35834 Mdot
.5412 .50723 Mdot
.33072 .51085 Mdot
.3375 .53061 Mdot
.29658 .51239 Mdot
.51271 .33912 Mdot
.47793 .38396 Mdot
.47125 .7303 Mdot
.32805 .46407 Mdot
.46598 .68947 Mdot
.66078 .65497 Mdot
.62964 .66102 Mdot
.51843 .3757 Mdot
.56177 .38294 Mdot
.72278 .50224 Mdot
.66093 .62993 Mdot
.44296 .59796 Mdot
.75934 .48241 Mdot
.527 .39636 Mdot
.65792 .65994 Mdot
.7321 .50903 Mdot
.22631 .42909 Mdot
.27834 .5848 Mdot
.7621 .47533 Mdot
.47794 .39918 Mdot
.41286 .25896 Mdot
.67503 .36673 Mdot
.70679 .50834 Mdot
.46386 .7257 Mdot
.53529 .35257 Mdot
.516 .65148 Mdot
.71791 .46511 Mdot
.70918 .38885 Mdot
.65155 .64533 Mdot
.44164 .34131 Mdot
.56949 .29265 Mdot
.3912 .42347 Mdot
.74531 .45394 Mdot
.33891 .52741 Mdot
.35984 .49833 Mdot
.51951 .3955 Mdot
.55155 .57705 Mdot
.47091 .67414 Mdot
.67412 .6392 Mdot
.61512 .65971 Mdot
.35786 .50867 Mdot
.48976 .49482 Mdot
.65019 .66831 Mdot
.53798 .34158 Mdot
.71466 .45971 Mdot
.46848 .32946 Mdot
.77735 .41127 Mdot
.33855 .23148 Mdot
.43759 .39464 Mdot
.75564 .45946 Mdot
.4853 .69059 Mdot
.48458 .7094 Mdot
.48051 .70446 Mdot
.63495 .66243 Mdot
.63221 .41137 Mdot
.6222 .66748 Mdot
.37455 .79133 Mdot
.74328 .49447 Mdot
.65179 .24868 Mdot
.50869 .30195 Mdot
.51123 .34632 Mdot
.51088 .31326 Mdot
.47105 .36047 Mdot
.50415 .37779 Mdot
.47307 .73318 Mdot
.68296 .65476 Mdot
.51418 .76438 Mdot
.33659 .48699 Mdot
.28708 .71152 Mdot
.63652 .62139 Mdot
.4365 .6082 Mdot
.71885 .49102 Mdot
.6224 .28688 Mdot
.74419 .44652 Mdot
.66359 .6295 Mdot
.54922 .37753 Mdot
.3648 .50669 Mdot
.62453 .21985 Mdot
.49236 .38019 Mdot
.66562 .63411 Mdot
.69124 .64572 Mdot
.24416 .41605 Mdot
.5757 .37405 Mdot
.56131 .641 Mdot
.58714 .46539 Mdot
.76483 .47765 Mdot
.48503 .42239 Mdot
.63838 .35829 Mdot
.6453 .65081 Mdot
.62032 .63695 Mdot
.71251 .51133 Mdot
.2765 .46107 Mdot
.32596 .47921 Mdot
.41553 .56057 Mdot
.45415 .72457 Mdot
.50367 .34642 Mdot
.64332 .6626 Mdot
.33989 .5594 Mdot
.57701 .49273 Mdot
.47291 .71286 Mdot
.62158 .6173 Mdot
.54043 .36376 Mdot
.52392 .38988 Mdot
.74805 .48363 Mdot
.62181 .5655 Mdot
.46668 .4321 Mdot
.35681 .73157 Mdot
.53231 .48776 Mdot
.54016 .55668 Mdot
.52679 .36457 Mdot
.32793 .54037 Mdot
.43439 .59264 Mdot
.72568 .47509 Mdot
.46835 .39525 Mdot
.2123 .49188 Mdot
.31422 .47871 Mdot
.468 .69094 Mdot
.43488 .60026 Mdot
.62848 .36004 Mdot
.53979 .36505 Mdot
.51165 .38244 Mdot
.48033 .32737 Mdot
.20269 .47011 Mdot
.63108 .6689 Mdot
.33778 .54335 Mdot
.75397 .4848 Mdot
.32135 .53091 Mdot
.63957 .61455 Mdot
.55358 .5912 Mdot
.48914 .40548 Mdot
.30163 .4925 Mdot
.32405 .52874 Mdot
.46033 .7182 Mdot
.47547 .68193 Mdot
.66978 .67894 Mdot
.53523 .35856 Mdot
.41193 .56995 Mdot
.33165 .4757 Mdot
.67864 .6489 Mdot
.74697 .48312 Mdot
.49796 .74628 Mdot
.49074 .36672 Mdot
.6398 .65367 Mdot
.47275 .43117 Mdot
.33817 .49351 Mdot
.65069 .62353 Mdot
.42315 .6036 Mdot
.71168 .48691 Mdot
.54335 .37638 Mdot
.52761 .76683 Mdot
.42361 .60042 Mdot
.50207 .34147 Mdot
.32482 .24468 Mdot
.55114 .57727 Mdot
.27131 .48625 Mdot
.64988 .67307 Mdot
.4128 .58394 Mdot
.34674 .53822 Mdot
.26855 .38752 Mdot
.62033 .64236 Mdot
.41522 .23237 Mdot
.52754 .54178 Mdot
.47764 .39556 Mdot
.31196 .50635 Mdot
.78604 .45817 Mdot
.3372 .70953 Mdot
.67621 .37614 Mdot
.51036 .35742 Mdot
.65327 .66359 Mdot
.75221 .47189 Mdot
.45726 .69473 Mdot
.51015 .714 Mdot
.79507 .40867 Mdot
.60749 .63455 Mdot
.49295 .39594 Mdot
.34598 .47621 Mdot
.47161 .69254 Mdot
.41481 .22351 Mdot
.65484 .6783 Mdot
.65535 .66875 Mdot
.5265 .31369 Mdot
.74989 .47819 Mdot
.49893 .64126 Mdot
.62392 .66355 Mdot
.68429 .65548 Mdot
.41582 .50611 Mdot
.76211 .48659 Mdot
.47709 .33496 Mdot
.42701 .36068 Mdot
.52139 .30462 Mdot
.33524 .74813 Mdot
.41209 .58092 Mdot
.33363 .48665 Mdot
.5017 .38912 Mdot
.5039 .79328 Mdot
.62546 .64337 Mdot
.58506 .46592 Mdot
.438 .66947 Mdot
.47354 .68146 Mdot
.65331 .65783 Mdot
.51676 .36434 Mdot
.47764 .66909 Mdot
.73791 .50017 Mdot
.47579 .33617 Mdot
.47647 .38423 Mdot
.33543 .46207 Mdot
.44578 .70289 Mdot
.35407 .23358 Mdot
.4544 .69275 Mdot
.441 .68977 Mdot
.28905 .48807 Mdot
.52027 .39534 Mdot
.64928 .62486 Mdot
.60608 .66849 Mdot
.51412 .43047 Mdot
.66764 .49202 Mdot
.31567 .48618 Mdot
.58761 .62743 Mdot
.20826 .49395 Mdot
.54515 .32748 Mdot
.44155 .5963 Mdot
.27513 .54577 Mdot
.43169 .69073 Mdot
.51177 .39512 Mdot
.32242 .49789 Mdot
.67577 .6691 Mdot
.64675 .66584 Mdot
.49137 .30724 Mdot
.48507 .70434 Mdot
.72554 .50878 Mdot
.64895 .63515 Mdot
.53232 .52082 Mdot
.50357 .35747 Mdot
.43526 .63869 Mdot
.65081 .63423 Mdot
.39702 .17442 Mdot
.49757 .79514 Mdot
.35556 .50031 Mdot
.5167 .31929 Mdot
.36051 .48862 Mdot
.75137 .49652 Mdot
.66183 .61726 Mdot
.48108 .72361 Mdot
.54299 .43292 Mdot
.69397 .74743 Mdot
.63635 .66066 Mdot
.31874 .50904 Mdot
.49885 .39595 Mdot
.39167 .39183 Mdot
.52447 .34789 Mdot
.74666 .35532 Mdot
.70374 .50252 Mdot
.47708 .75241 Mdot
.48725 .70328 Mdot
.4996 .32167 Mdot
.73818 .45928 Mdot
.61491 .67705 Mdot
.64738 .64355 Mdot
.67193 .7889 Mdot
.43055 .60687 Mdot
.58635 .65389 Mdot
.51022 .34 Mdot
.67595 .64987 Mdot
.40955 .27181 Mdot
.48239 .69486 Mdot
.52987 .3091 Mdot
.6008 .63697 Mdot
.30012 .70422 Mdot
.5891 .46655 Mdot
.50632 .35702 Mdot
.5659 .37006 Mdot
.47114 .72284 Mdot
.23382 .64166 Mdot
.64632 .67463 Mdot
.46662 .36881 Mdot
.45525 .66598 Mdot
.53581 .46028 Mdot
.65901 .57948 Mdot
.32994 .5092 Mdot
.59939 .63189 Mdot
.43921 .70804 Mdot
.4432 .33497 Mdot
.71644 .49946 Mdot
.65738 .68006 Mdot
.60521 .65493 Mdot
.48332 .35321 Mdot
.46766 .34428 Mdot
.56935 .34864 Mdot
.31155 .49679 Mdot
.44542 .68704 Mdot
.48547 .33509 Mdot
.54359 .49984 Mdot
.47275 .35461 Mdot
.44112 .69428 Mdot
.66075 .85155 Mdot
.54698 .38019 Mdot
.4935 .35991 Mdot
.38514 .38157 Mdot
.33032 .54484 Mdot
.35171 .51563 Mdot
.53142 .4951 Mdot
.52743 .3409 Mdot
.51689 .54931 Mdot
.3269 .50794 Mdot
.31586 .513 Mdot
.51822 .55025 Mdot
.48068 .36642 Mdot
.44456 .58315 Mdot
.47307 .69336 Mdot
.4735 .68118 Mdot
.35145 .50693 Mdot
.47062 .32858 Mdot
.48747 .69128 Mdot
.29336 .41574 Mdot
.65633 .62443 Mdot
.63637 .35403 Mdot
.32836 .53174 Mdot
.61105 .45853 Mdot
.46283 .68317 Mdot
.43878 .18559 Mdot
.56383 .22493 Mdot
.55268 .33969 Mdot
.51827 .39506 Mdot
.73311 .48325 Mdot
.51485 .44316 Mdot
.43639 .59037 Mdot
.48048 .70122 Mdot
.51388 .63172 Mdot
.33594 .51125 Mdot
.52823 .34338 Mdot
.67793 .39183 Mdot
.3613 .20704 Mdot
.44414 .31014 Mdot
.31929 .51824 Mdot
.33808 .51568 Mdot
.66317 .66623 Mdot
.66493 .62902 Mdot
.48918 .40457 Mdot
.48233 .7168 Mdot
.35492 .48739 Mdot
.44378 .69485 Mdot
.64649 .6496 Mdot
.6418 .62264 Mdot
.42576 .57275 Mdot
.44411 .40043 Mdot
.65301 .65346 Mdot
.50336 .75479 Mdot
.54304 .501 Mdot
.31838 .4654 Mdot
.40326 .81408 Mdot
.46234 .18344 Mdot
.36735 .43617 Mdot
.7528 .47144 Mdot
.56573 .44404 Mdot
.48946 .72453 Mdot
.49643 .32291 Mdot
.5152 .38513 Mdot
.41799 .58045 Mdot
.49266 .71777 Mdot
.72393 .49163 Mdot
.47907 .68794 Mdot
.72108 .47601 Mdot
.61382 .65096 Mdot
.49028 .3911 Mdot
.51201 .40784 Mdot
.45729 .69789 Mdot
.67084 .65322 Mdot
.64739 .62002 Mdot
.74053 .46431 Mdot
.61686 .27587 Mdot
.63805 .65204 Mdot
.327 .53162 Mdot
.36776 .24771 Mdot
.42481 .57934 Mdot
.51536 .37179 Mdot
.65421 .35892 Mdot
.27985 .36991 Mdot
.47048 .38084 Mdot
.43223 .6023 Mdot
.56432 .87047 Mdot
.48836 .39224 Mdot
.74929 .713 Mdot
.4159 .56956 Mdot
.31648 .53491 Mdot
.66121 .63658 Mdot
.43127 .6059 Mdot
.59989 .32553 Mdot
.6104 .60279 Mdot
.49844 .43207 Mdot
.32304 .48002 Mdot
.29878 .50782 Mdot
.54848 .58985 Mdot
.33298 .74714 Mdot
.75447 .48371 Mdot
.72982 .49799 Mdot
.62181 .64644 Mdot
.51279 .72567 Mdot
.47772 .32061 Mdot
.731 .49632 Mdot
.45275 .58448 Mdot
.49922 .31942 Mdot
.55028 .57847 Mdot
.52576 .59394 Mdot
.34431 .53474 Mdot
.48694 .28881 Mdot
.62325 .64471 Mdot
.31991 .50996 Mdot
.53544 .58614 Mdot
.52175 .3096 Mdot
.33274 .51123 Mdot
.45547 .68025 Mdot
.48756 .55039 Mdot
.33315 .53421 Mdot
.60399 .45324 Mdot
.46227 .69788 Mdot
.55372 .5841 Mdot
.69223 .30082 Mdot
.26435 .2399 Mdot
.48362 .70915 Mdot
.66676 .63871 Mdot
.64273 .6614 Mdot
.63488 .64968 Mdot
.30925 .5049 Mdot
.636 .63566 Mdot
.33222 .4824 Mdot
.46333 .74372 Mdot
.61688 .28812 Mdot
.74034 .48371 Mdot
.76822 .43979 Mdot
.34501 .51578 Mdot
.36185 .77969 Mdot
.34673 .81092 Mdot
.47202 .35 Mdot
.44464 .67899 Mdot
.75383 .46164 Mdot
.51914 .48696 Mdot
.73056 .48509 Mdot
.66467 .63881 Mdot
.62987 .34004 Mdot
.51822 .35604 Mdot
.33504 .58225 Mdot
.75183 .47248 Mdot
.31496 .51453 Mdot
.49817 .33759 Mdot
.59411 .63638 Mdot
.74505 .49927 Mdot
.74466 .4675 Mdot
.50593 .37704 Mdot
.30398 .51754 Mdot
.65503 .62572 Mdot
.48496 .73188 Mdot
.71256 .45547 Mdot
.56004 .39781 Mdot
.49427 .40223 Mdot
.5446 .3895 Mdot
.572 .47276 Mdot
.517 .70219 Mdot
.46416 .69945 Mdot
.70494 .39085 Mdot
.62607 .6592 Mdot
.67861 .37519 Mdot
.35633 .71355 Mdot
.78682 .47133 Mdot
.4125 .5794 Mdot
.4117 .57918 Mdot
.50252 .3655 Mdot
.24171 .71441 Mdot
.45221 .28907 Mdot
.42645 .68482 Mdot
.42244 .58176 Mdot
.6535 .62122 Mdot
.33601 .46618 Mdot
.57387 .30404 Mdot
.49898 .3051 Mdot
.48823 .73013 Mdot
.64267 .64702 Mdot
.20038 .66114 Mdot
.74435 .49255 Mdot
.51426 .49077 Mdot
.53625 .36137 Mdot
.50761 .36681 Mdot
.46704 .71081 Mdot
.47836 .7255 Mdot
.41516 .50155 Mdot
.62713 .48683 Mdot
.33386 .59542 Mdot
.4983 .72241 Mdot
.19929 .66036 Mdot
.25745 .53667 Mdot
.34749 .50067 Mdot
.43928 .59135 Mdot
.47816 .67992 Mdot
.5042 .38712 Mdot
.31743 .53641 Mdot
.47071 .27566 Mdot
.37097 .54367 Mdot
.54759 .57264 Mdot
.53868 .51958 Mdot
.53835 .37741 Mdot
.35611 .53154 Mdot
.32361 .51172 Mdot
.32943 .55064 Mdot
.43265 .58779 Mdot
.52772 .36806 Mdot
.46822 .37839 Mdot
.4864 .39244 Mdot
.40997 .42383 Mdot
.49944 .36548 Mdot
.35227 .71248 Mdot
.52691 .50547 Mdot
.74952 .56456 Mdot
.48922 .38097 Mdot
.44993 .68115 Mdot
.49251 .3905 Mdot
.72905 .46166 Mdot
.54467 .3778 Mdot
.54613 .56836 Mdot
.47341 .70027 Mdot
.25729 .45311 Mdot
.6964 .63585 Mdot
.50892 .40701 Mdot
.74823 .50318 Mdot
.43109 .80955 Mdot
.69614 .39283 Mdot
.41687 .5095 Mdot
.33161 .53168 Mdot
.68591 .65773 Mdot
.45587 .66982 Mdot
.63751 .62494 Mdot
.54668 .31681 Mdot
.43681 .58203 Mdot
.62971 .19145 Mdot
.61926 .45888 Mdot
.50225 .38792 Mdot
.44928 .40931 Mdot
.33971 .53677 Mdot
.62684 .64061 Mdot
.36298 .44671 Mdot
.5043 .31572 Mdot
.70889 .49544 Mdot
.73481 .45671 Mdot
.61247 .69866 Mdot
.46859 .54984 Mdot
.42677 .28624 Mdot
.4671 .70844 Mdot
.63842 .66462 Mdot
.73729 .4538 Mdot
.37627 .55751 Mdot
.46545 .673 Mdot
.43157 .69061 Mdot
.4455 .70464 Mdot
.50213 .35367 Mdot
.42555 .57459 Mdot
.47304 .58312 Mdot
.42261 .60111 Mdot
.50778 .30833 Mdot
.6047 .65298 Mdot
.41786 .59755 Mdot
.74021 .47828 Mdot
.43692 .70221 Mdot
.63186 .62066 Mdot
.49838 .37772 Mdot
.33038 .50372 Mdot
.75108 .4176 Mdot
.514 .79861 Mdot
.55245 .57844 Mdot
.55251 .57853 Mdot
.29384 .49914 Mdot
.38992 .58156 Mdot
.49658 .74196 Mdot
.24907 .40984 Mdot
.726 .53311 Mdot
.49484 .43719 Mdot
.7195 .63283 Mdot
.62494 .66932 Mdot
.65668 .64278 Mdot
.51651 .35145 Mdot
.67465 .6602 Mdot
.52856 .34688 Mdot
.65273 .67338 Mdot
.33271 .7205 Mdot
.5226 .29886 Mdot
.65102 .6398 Mdot
.57461 .38456 Mdot
.49553 .34584 Mdot
.32764 .53898 Mdot
.66472 .67591 Mdot
.55227 .3389 Mdot
.71925 .23097 Mdot
.45807 .71482 Mdot
.43196 .58643 Mdot
.54932 .54858 Mdot
.47145 .68644 Mdot
.33717 .47958 Mdot
.53631 .34652 Mdot
.74566 .49466 Mdot
.3468 .50591 Mdot
.60814 .61016 Mdot
.74957 .47323 Mdot
.46929 .48384 Mdot
.35012 .50484 Mdot
.42121 .57656 Mdot
.71172 .48289 Mdot
.49962 .4319 Mdot
.65469 .64325 Mdot
.50333 .7986 Mdot
.43386 .60473 Mdot
.52096 .35845 Mdot
.60225 .62557 Mdot
.47723 .68713 Mdot
.51277 .40279 Mdot
.64417 .66377 Mdot
.43622 .59623 Mdot
.49221 .3555 Mdot
.51327 .33682 Mdot
.29712 .44966 Mdot
.6513 .53599 Mdot
.74066 .48127 Mdot
.28704 .50142 Mdot
.49944 .30943 Mdot
.7412 .46006 Mdot
.53893 .73458 Mdot
.54038 .30209 Mdot
.32184 .47714 Mdot
.27385 .41997 Mdot
.67481 .64386 Mdot
.4853 .6983 Mdot
.63353 .68115 Mdot
.75906 .48884 Mdot
.40979 .85283 Mdot
.43691 .58756 Mdot
.53727 .40432 Mdot
.54952 .343 Mdot
.6743 .62465 Mdot
.32561 .5138 Mdot
.33213 .59366 Mdot
.54501 .37117 Mdot
.44309 .35666 Mdot
.5109 .37492 Mdot
.54007 .74616 Mdot
.30989 .50089 Mdot
.51355 .37388 Mdot
.53655 .42314 Mdot
.54036 .32018 Mdot
.73274 .50713 Mdot
.64889 .24268 Mdot
.47346 .38651 Mdot
.83241 .6992 Mdot
.42881 .57103 Mdot
.64357 .64253 Mdot
.59741 .45711 Mdot
.56065 .55266 Mdot
.82439 .46021 Mdot
.32647 .48109 Mdot
.38525 .54536 Mdot
.6446 .62393 Mdot
.79477 .44169 Mdot
.39703 .58734 Mdot
.50779 .33531 Mdot
.53799 .35694 Mdot
.66462 .63872 Mdot
.67899 .64662 Mdot
.43598 .57836 Mdot
.48591 .41071 Mdot
.46493 .30408 Mdot
.61793 .67364 Mdot
.49377 .37417 Mdot
.28444 .34759 Mdot
.43121 .71301 Mdot
.35211 .50856 Mdot
.45579 .69634 Mdot
.43485 .71797 Mdot
.35859 .43925 Mdot
.53783 .48479 Mdot
.45894 .7288 Mdot
.42468 .70412 Mdot
.78244 .44975 Mdot
.38862 .41304 Mdot
.72932 .50724 Mdot
.44734 .51345 Mdot
.62835 .65228 Mdot
.52758 .37045 Mdot
.30798 .50455 Mdot
.7734 .3441 Mdot
.33667 .61582 Mdot
.58484 .2791 Mdot
.4788 .33276 Mdot
.6271 .64635 Mdot
.43527 .60262 Mdot
.53861 .30019 Mdot
.67597 .36948 Mdot
.50835 .36115 Mdot
.67129 .63372 Mdot
.38825 .417 Mdot
.45997 .78367 Mdot
.49822 .72779 Mdot
.36306 .47144 Mdot
.49279 .39237 Mdot
.32223 .49173 Mdot
.45171 .72853 Mdot
.75151 .46427 Mdot
.73378 .49003 Mdot
.51269 .40662 Mdot
.53751 .55473 Mdot
.80166 .4921 Mdot
.5043 .33662 Mdot
.4815 .35848 Mdot
.4132 .58139 Mdot
.48079 .36005 Mdot
.47044 .39583 Mdot
.4848 .33354 Mdot
.46761 .35373 Mdot
.47145 .67562 Mdot
.37837 .4445 Mdot
.49519 .41521 Mdot
.55557 .37803 Mdot
.45957 .73826 Mdot
.559 .33917 Mdot
.4776 .71673 Mdot
.35507 .6087 Mdot
.45881 .72698 Mdot
.73532 .48903 Mdot
.59874 .62797 Mdot
.39226 .49562 Mdot
.35467 .48748 Mdot
.45748 .67669 Mdot
.71441 .48573 Mdot
.48216 .70572 Mdot
.63576 .66683 Mdot
.48973 .78614 Mdot
.28356 .47914 Mdot
.521 .51698 Mdot
.38185 .39809 Mdot
.42488 .65648 Mdot
.67145 .66088 Mdot
.35525 .49805 Mdot
.503 .74557 Mdot
.49876 .32286 Mdot
.75023 .48944 Mdot
.50297 .36597 Mdot
.43735 .69742 Mdot
.6282 .64914 Mdot
.41396 .5411 Mdot
.73955 .48114 Mdot
.4437 .84113 Mdot
.62061 .67172 Mdot
.55109 .35993 Mdot
.46144 .73821 Mdot
.50741 .76053 Mdot
.47137 .72474 Mdot
.61788 .28799 Mdot
.3116 .56274 Mdot
.7816 .36717 Mdot
.34174 .51408 Mdot
.44241 .61266 Mdot
.22442 .31533 Mdot
.39087 .67994 Mdot
.33562 .49751 Mdot
.70504 .65855 Mdot
.49783 .36292 Mdot
.47636 .34224 Mdot
.44401 .39514 Mdot
.35151 .55089 Mdot
.48072 .32686 Mdot
.43298 .58378 Mdot
.54241 .48679 Mdot
.46824 .61251 Mdot
.68367 .66619 Mdot
.52806 .34846 Mdot
.46111 .73421 Mdot
.45344 .6769 Mdot
.41186 .58896 Mdot
.45015 .69537 Mdot
.48485 .3701 Mdot
.3444 .51493 Mdot
.53044 .58758 Mdot
.75175 .49537 Mdot
.37263 .73868 Mdot
.76347 .52468 Mdot
.74399 .44491 Mdot
.54244 .32216 Mdot
.64447 .62275 Mdot
.70414 .73479 Mdot
.48975 .3243 Mdot
.32398 .50807 Mdot
.54903 .34362 Mdot
.47969 .34049 Mdot
.48226 .39547 Mdot
.63759 .664 Mdot
.59463 .46546 Mdot
.49318 .37593 Mdot
.45586 .72837 Mdot
.5202 .54946 Mdot
.49355 .30775 Mdot
.53194 .64082 Mdot
.54608 .5695 Mdot
.43369 .64148 Mdot
.32689 .46244 Mdot
.65294 .62794 Mdot
.33789 .51166 Mdot
.36484 .53181 Mdot
.33781 .47985 Mdot
.47417 .59689 Mdot
.25705 .40291 Mdot
.76433 .70101 Mdot
.41111 .27561 Mdot
.37769 .39915 Mdot
.36465 .47676 Mdot
.59079 .72616 Mdot
.33116 .496 Mdot
.33369 .4796 Mdot
.63435 .84651 Mdot
.30489 .4982 Mdot
.51938 .37489 Mdot
.53231 .40048 Mdot
.21842 .46813 Mdot
.73787 .44096 Mdot
.50503 .34206 Mdot
.46872 .3616 Mdot
.73544 .45524 Mdot
.32706 .44459 Mdot
.44163 .58878 Mdot
.5084 .49315 Mdot
.43865 .61036 Mdot
.50528 .37681 Mdot
.53183 .38951 Mdot
.46509 .39654 Mdot
.29881 .23508 Mdot
.79396 .38648 Mdot
.29776 .51215 Mdot
.50348 .43665 Mdot
.41288 .69403 Mdot
.53969 .33569 Mdot
.54452 .33351 Mdot
.48091 .39019 Mdot
.64905 .6247 Mdot
.32322 .46958 Mdot
.46857 .43219 Mdot
.38726 .72574 Mdot
.53886 .36999 Mdot
.78472 .50933 Mdot
.76576 .49508 Mdot
.51762 .36503 Mdot
.30404 .4964 Mdot
.47648 .33976 Mdot
.35641 .48294 Mdot
.35086 .50105 Mdot
.4492 .33248 Mdot
.46896 .57165 Mdot
.33704 .46689 Mdot
.50966 .33518 Mdot
.67163 .65458 Mdot
.35908 .73524 Mdot
.52036 .35956 Mdot
.74404 .47538 Mdot
.50931 .39676 Mdot
.73913 .50651 Mdot
.47605 .36876 Mdot
.41762 .59627 Mdot
.2836 .29764 Mdot
.61908 .63874 Mdot
.73392 .44574 Mdot
.67513 .65587 Mdot
.4594 .34015 Mdot
.35667 .47387 Mdot
.43591 .76871 Mdot
.80137 .40709 Mdot
.41343 .58004 Mdot
.72466 .39644 Mdot
.51057 .55876 Mdot
.48062 .72937 Mdot
.34104 .54408 Mdot
.38216 .42876 Mdot
.53178 .63655 Mdot
.68802 .66043 Mdot
.62703 .61646 Mdot
.67685 .58061 Mdot
.58569 .85186 Mdot
.49196 .37181 Mdot
.52156 .65513 Mdot
.30563 .31176 Mdot
.50703 .44351 Mdot
.57921 .34599 Mdot
.60592 .65838 Mdot
.50473 .34189 Mdot
.64192 .43453 Mdot
.64128 .6577 Mdot
.72347 .49962 Mdot
.33144 .48678 Mdot
.72924 .46489 Mdot
.28281 .60509 Mdot
.41518 .514 Mdot
.64897 .65505 Mdot
.46889 .34709 Mdot
.51167 .3435 Mdot
.33364 .54593 Mdot
.41951 .22355 Mdot
.35353 .508 Mdot
.75545 .48919 Mdot
.61853 .64841 Mdot
.67592 .22118 Mdot
.50198 .39792 Mdot
.32166 .52669 Mdot
.69696 .63691 Mdot
.52529 .38788 Mdot
.48461 .69943 Mdot
.48355 .3244 Mdot
.31871 .52697 Mdot
.48046 .36026 Mdot
.34402 .51168 Mdot
.66436 .6625 Mdot
.51664 .40641 Mdot
.52542 .39701 Mdot
.71069 .3914 Mdot
.72403 .49011 Mdot
.3469 .47057 Mdot
.64177 .43033 Mdot
.52126 .30458 Mdot
.66742 .36105 Mdot
.48981 .39144 Mdot
.38849 .40099 Mdot
.55321 .31007 Mdot
.43091 .58099 Mdot
.54768 .33881 Mdot
.51907 .35903 Mdot
.43501 .22465 Mdot
.40986 .26778 Mdot
.41138 .43851 Mdot
.47585 .68177 Mdot
.30907 .51731 Mdot
.64612 .66057 Mdot
.67847 .66796 Mdot
.63876 .63172 Mdot
.70747 .51429 Mdot
.52178 .42848 Mdot
.52371 .35691 Mdot
.42058 .70527 Mdot
.73557 .49587 Mdot
.3222 .5227 Mdot
.74031 .48833 Mdot
.54053 .48168 Mdot
.74093 .47343 Mdot
.43718 .59097 Mdot
.49844 .79242 Mdot
.28392 .35961 Mdot
.72674 .47657 Mdot
.3531 .50573 Mdot
.51316 .5407 Mdot
.48692 .43773 Mdot
.30803 .72757 Mdot
.70808 .49378 Mdot
.68605 .59446 Mdot
.48872 .3667 Mdot
.61259 .44214 Mdot
.47492 .71667 Mdot
.72776 .46584 Mdot
.4467 .70631 Mdot
.47739 .33808 Mdot
.29941 .45376 Mdot
.31737 .50561 Mdot
.43356 .71867 Mdot
.53449 .31505 Mdot
.72786 .46548 Mdot
.65239 .6511 Mdot
.38961 .41596 Mdot
.44526 .73418 Mdot
.7496 .41982 Mdot
.67733 .37646 Mdot
.62116 .65248 Mdot
.39679 .34808 Mdot
.45285 .72008 Mdot
.49934 .43638 Mdot
.4998 .2682 Mdot
.49506 .31582 Mdot
.64466 .61918 Mdot
.65714 .64199 Mdot
.4193 .65439 Mdot
.53053 .39299 Mdot
.50156 .41604 Mdot
.30376 .47632 Mdot
.61964 .6534 Mdot
.34023 .47983 Mdot
.35407 .52777 Mdot
.66706 .64131 Mdot
.35663 .50287 Mdot
.74901 .471 Mdot
.63039 .39451 Mdot
.45373 .72168 Mdot
.48686 .70636 Mdot
.65151 .65499 Mdot
.61149 .63918 Mdot
.64242 .62215 Mdot
.51662 .31401 Mdot
.35152 .48953 Mdot
.51551 .32063 Mdot
.49447 .39402 Mdot
.3679 .56202 Mdot
.29535 .47877 Mdot
.53331 .32175 Mdot
.52267 .59632 Mdot
.70816 .50184 Mdot
.6472 .63883 Mdot
.44631 .68882 Mdot
.76369 .4179 Mdot
.47558 .73446 Mdot
.52107 .30311 Mdot
.30547 .71133 Mdot
.31005 .50709 Mdot
.73156 .48411 Mdot
.5492 .57134 Mdot
.73656 .48161 Mdot
.43189 .71506 Mdot
.29059 .50168 Mdot
.47858 .48909 Mdot
.52879 .39575 Mdot
.56774 .47462 Mdot
.69776 .3307 Mdot
.36252 .71324 Mdot
.44878 .68389 Mdot
.47379 .34402 Mdot
.41445 .57285 Mdot
.24388 .41197 Mdot
.52146 .35473 Mdot
.5375 .31119 Mdot
.57247 .5677 Mdot
.55057 .34292 Mdot
.29757 .52085 Mdot
.54483 .57652 Mdot
.47453 .40279 Mdot
.45805 .34664 Mdot
.63961 .81948 Mdot
.49567 .34927 Mdot
.52045 .40169 Mdot
.52144 .38012 Mdot
.5025 .31956 Mdot
.35997 .48596 Mdot
.57529 .58761 Mdot
.45177 .73069 Mdot
.63064 .39409 Mdot
.44642 .71157 Mdot
.65896 .65262 Mdot
.64205 .46458 Mdot
.35835 .48525 Mdot
.73659 .48108 Mdot
.5294 .66737 Mdot
.62873 .34099 Mdot
.66505 .66449 Mdot
.74421 .39029 Mdot
.71879 .50473 Mdot
.48504 .43811 Mdot
.76092 .48633 Mdot
.6011 .6474 Mdot
.48478 .70473 Mdot
.54921 .37707 Mdot
.33448 .47594 Mdot
.33384 .53384 Mdot
.49229 .31456 Mdot
.38249 .74765 Mdot
.48403 .69267 Mdot
.66992 .46675 Mdot
.5075 .35038 Mdot
.52939 .30881 Mdot
.35497 .50902 Mdot
.6274 .64207 Mdot
.5123 .55753 Mdot
.71813 .48754 Mdot
.54268 .34849 Mdot
.47046 .3621 Mdot
.54413 .48059 Mdot
.46181 .67454 Mdot
.42584 .59003 Mdot
.52542 .35175 Mdot
.51998 .49458 Mdot
.48191 .32438 Mdot
.46006 .37312 Mdot
.67284 .64586 Mdot
.44556 .34343 Mdot
.54125 .37679 Mdot
.28312 .46435 Mdot
.45204 .71792 Mdot
.32813 .51124 Mdot
.37954 .54796 Mdot
.41415 .5902 Mdot
.45703 .71125 Mdot
.53347 .31991 Mdot
.43744 .68297 Mdot
.47776 .34162 Mdot
.49604 .37749 Mdot
.45132 .68212 Mdot
.34361 .48301 Mdot
.37681 .59663 Mdot
.37908 .44457 Mdot
.49172 .33202 Mdot
.51357 .39502 Mdot
.73848 .44105 Mdot
.7933 .35768 Mdot
.53782 .38601 Mdot
.35592 .49637 Mdot
.52446 .3898 Mdot
.48192 .7261 Mdot
.75485 .48242 Mdot
.32617 .50383 Mdot
.62577 .66232 Mdot
.66151 .6644 Mdot
.6993 .65358 Mdot
.43772 .59043 Mdot
.49126 .41202 Mdot
.28751 .50031 Mdot
.29291 .48412 Mdot
.62275 .41651 Mdot
.64472 .64196 Mdot
.75421 .47884 Mdot
.50896 .33925 Mdot
.53447 .43878 Mdot
.4341 .7142 Mdot
.85226 .67364 Mdot
.48558 .49204 Mdot
.72956 .51535 Mdot
.62282 .49941 Mdot
.41508 .58344 Mdot
.49701 .35189 Mdot
.72999 .46219 Mdot
.66452 .65184 Mdot
.47591 .34284 Mdot
.56571 .36303 Mdot
.55497 .65947 Mdot
.61493 .62766 Mdot
.43038 .69653 Mdot
.64364 .67262 Mdot
.72762 .50836 Mdot
.43642 .58977 Mdot
.32084 .53301 Mdot
.51405 .36123 Mdot
.47421 .29475 Mdot
.63397 .64692 Mdot
.41058 .5669 Mdot
.50173 .40755 Mdot
.31029 .52282 Mdot
.6395 .63695 Mdot
.50646 .38106 Mdot
.24696 .41685 Mdot
.3915 .49481 Mdot
.62673 .65414 Mdot
.53743 .34289 Mdot
.57747 .30961 Mdot
.61654 .62441 Mdot
.60114 .64191 Mdot
.47203 .34745 Mdot
.72087 .4709 Mdot
.54085 .37278 Mdot
.47876 .72018 Mdot
.59441 .46675 Mdot
.45662 .7015 Mdot
.67601 .36684 Mdot
.46387 .35742 Mdot
.46113 .28565 Mdot
.36322 .51798 Mdot
.71848 .4577 Mdot
.50073 .19281 Mdot
.52615 .30437 Mdot
.22833 .51654 Mdot
.60869 .46015 Mdot
.50242 .51018 Mdot
.22454 .52978 Mdot
.72026 .47991 Mdot
.48067 .70498 Mdot
.50807 .40611 Mdot
.50333 .66279 Mdot
.72573 .47245 Mdot
.67509 .36547 Mdot
.52504 .32782 Mdot
.31759 .51493 Mdot
.50516 .35337 Mdot
.31504 .52614 Mdot
.5261 .38309 Mdot
.25371 .47692 Mdot
.78865 .50815 Mdot
.61702 .28612 Mdot
.48361 .43677 Mdot
.50498 .76225 Mdot
.38118 .39808 Mdot
.75086 .47946 Mdot
.48605 .34169 Mdot
.42076 .59134 Mdot
.47876 .6875 Mdot
.54211 .68734 Mdot
.64274 .62336 Mdot
.45306 .7257 Mdot
.34734 .49238 Mdot
.59857 .6512 Mdot
.41058 .57125 Mdot
.44352 .42211 Mdot
.72645 .46564 Mdot
.45823 .71441 Mdot
.51795 .36097 Mdot
.50265 .31367 Mdot
.53931 .74774 Mdot
.63837 .21181 Mdot
.35925 .51 Mdot
.49492 .86002 Mdot
.28805 .50667 Mdot
.72623 .49573 Mdot
.67202 .64179 Mdot
.50632 .3885 Mdot
.53368 .36084 Mdot
.6164 .62802 Mdot
.32971 .54379 Mdot
.74885 .44737 Mdot
.78406 .36448 Mdot
.44161 .66861 Mdot
.64706 .25917 Mdot
.32406 .5018 Mdot
.64802 .26137 Mdot
.7595 .51341 Mdot
.42986 .55796 Mdot
.58491 .22748 Mdot
.4738 .69108 Mdot
.64663 .25704 Mdot
.31691 .51897 Mdot
.49205 .3678 Mdot
.4203 .57728 Mdot
.42289 .56923 Mdot
.3281 .49062 Mdot
.66223 .63484 Mdot
.71529 .4979 Mdot
.50821 .35262 Mdot
.43085 .39252 Mdot
.41343 .22357 Mdot
.61453 .64883 Mdot
.45164 .41179 Mdot
.46349 .68506 Mdot
.52112 .39119 Mdot
.74313 .45526 Mdot
.47525 .6953 Mdot
.42663 .60553 Mdot
.63053 .34802 Mdot
.53645 .3464 Mdot
.54021 .56065 Mdot
.47001 .71636 Mdot
.78812 .35081 Mdot
.52652 .39563 Mdot
.45266 .7198 Mdot
.47185 .29686 Mdot
.4281 .77152 Mdot
.52326 .57311 Mdot
.39017 .67716 Mdot
.65723 .6831 Mdot
.65125 .67317 Mdot
.72439 .23972 Mdot
.70768 .53127 Mdot
.4416 .71745 Mdot
.43847 .59877 Mdot
.64728 .23366 Mdot
.449 .70739 Mdot
.54716 .35946 Mdot
.48887 .38902 Mdot
.38809 .41704 Mdot
.55463 .42236 Mdot
.43779 .57964 Mdot
.41281 .40508 Mdot
.48498 .36271 Mdot
.46195 .42717 Mdot
.50629 .40347 Mdot
.29925 .50995 Mdot
.46928 .68866 Mdot
.15143 .45467 Mdot
.44561 .67436 Mdot
.47629 .27789 Mdot
.62821 .652 Mdot
.64291 .6843 Mdot
.51658 .36569 Mdot
.49178 .25905 Mdot
.20623 .67956 Mdot
.49084 .39824 Mdot
.54877 .57075 Mdot
.67953 .3777 Mdot
.50917 .43342 Mdot
.32796 .47232 Mdot
.46248 .30546 Mdot
.2844 .50625 Mdot
.47692 .69553 Mdot
.72147 .47789 Mdot
.70335 .48411 Mdot
.48002 .70951 Mdot
.53289 .3628 Mdot
.7084 .47334 Mdot
.50885 .3691 Mdot
.50454 .3465 Mdot
.52146 .4898 Mdot
.75875 .46692 Mdot
.64676 .62221 Mdot
.73426 .48776 Mdot
.32041 .48359 Mdot
.62438 .86358 Mdot
.7464 .48601 Mdot
.38853 .41316 Mdot
.63154 .44333 Mdot
.65351 .25917 Mdot
.33573 .53494 Mdot
.75345 .49445 Mdot
.4786 .69243 Mdot
.46117 .48504 Mdot
.38116 .3756 Mdot
.47542 .73435 Mdot
.52418 .35399 Mdot
.36087 .49074 Mdot
.29271 .49751 Mdot
.49923 .71775 Mdot
.33222 .54073 Mdot
.52073 .42027 Mdot
.5162 .33443 Mdot
.4501 .72677 Mdot
.35778 .20622 Mdot
.48686 .70019 Mdot
.34964 .43854 Mdot
.47889 .38643 Mdot
.32518 .50621 Mdot
.38743 .39546 Mdot
.3815 .52614 Mdot
.42851 .57439 Mdot
.542 .38466 Mdot
.75065 .48432 Mdot
.63241 .41132 Mdot
.62453 .65228 Mdot
.30332 .70593 Mdot
.33039 .53189 Mdot
.4964 .69379 Mdot
.32783 .53852 Mdot
.34277 .53905 Mdot
.44426 .72962 Mdot
.31299 .50336 Mdot
.53854 .36918 Mdot
.22015 .5999 Mdot
.34018 .52865 Mdot
.46995 .708 Mdot
.74969 .49422 Mdot
.35572 .49973 Mdot
.67553 .45474 Mdot
.51651 .34105 Mdot
.64934 .67847 Mdot
.6956 .46871 Mdot
.35474 .53443 Mdot
.75185 .47845 Mdot
.63748 .64358 Mdot
.71215 .49263 Mdot
.47807 .64477 Mdot
.48495 .75554 Mdot
.57246 .27078 Mdot
.43994 .78199 Mdot
.30941 .49312 Mdot
.61696 .68026 Mdot
.53981 .35242 Mdot
.50652 .34902 Mdot
.70324 .49864 Mdot
.29558 .50239 Mdot
.39062 .75998 Mdot
.43139 .31473 Mdot
.37368 .73853 Mdot
.47061 .67789 Mdot
.71978 .42991 Mdot
.48097 .49123 Mdot
.48989 .66375 Mdot
.48429 .4215 Mdot
.41544 .58261 Mdot
.51148 .37525 Mdot
.69545 .39264 Mdot
.72374 .5069 Mdot
.5634 .76242 Mdot
.47452 .32555 Mdot
.61824 .62916 Mdot
.52097 .38618 Mdot
.5109 .64209 Mdot
.45784 .35838 Mdot
.70719 .49407 Mdot
.45861 .66639 Mdot
.35478 .48759 Mdot
.74425 .50115 Mdot
.66397 .66167 Mdot
.57627 .24181 Mdot
.54604 .35783 Mdot
.48668 .36261 Mdot
.61682 .62127 Mdot
.33708 .47791 Mdot
.65886 .64802 Mdot
.4531 .72113 Mdot
.74367 .48574 Mdot
.51199 .3173 Mdot
.45503 .41827 Mdot
.6705 .62159 Mdot
.43618 .69263 Mdot
.63856 .61637 Mdot
.43617 .68514 Mdot
.41589 .57807 Mdot
.46337 .37518 Mdot
.62536 .615 Mdot
.48011 .41567 Mdot
.38639 .30268 Mdot
.6263 .3669 Mdot
.45874 .22911 Mdot
.64988 .6225 Mdot
.77531 .52557 Mdot
.47597 .7038 Mdot
.45728 .71672 Mdot
.31828 .43808 Mdot
.23756 .71171 Mdot
.51697 .54958 Mdot
.44141 .8144 Mdot
.45373 .72193 Mdot
.46569 .71538 Mdot
.6612 .64116 Mdot
.32744 .48218 Mdot
.36198 .53335 Mdot
.60394 .62467 Mdot
.65237 .35489 Mdot
.32206 .52284 Mdot
.21526 .48134 Mdot
.618 .66396 Mdot
.52411 .40947 Mdot
.40535 .53027 Mdot
.70755 .49396 Mdot
.6772 .3879 Mdot
.4985 .77779 Mdot
.51243 .38287 Mdot
.7402 .71964 Mdot
.6456 .62575 Mdot
.44223 .50756 Mdot
.41733 .70473 Mdot
.5161 .31046 Mdot
.52392 .38068 Mdot
.53386 .38061 Mdot
.71188 .51068 Mdot
.39869 .25839 Mdot
.50916 .38543 Mdot
.62577 .31602 Mdot
.52682 .29867 Mdot
.52219 .77646 Mdot
.73458 .48784 Mdot
.74772 .36094 Mdot
.59226 .65448 Mdot
.38952 .73651 Mdot
.54147 .31819 Mdot
.46328 .72522 Mdot
.52008 .61889 Mdot
.4436 .68747 Mdot
.43862 .63762 Mdot
.63137 .22672 Mdot
.29744 .50254 Mdot
.48772 .31915 Mdot
.61146 .65617 Mdot
.36534 .50712 Mdot
.52121 .61041 Mdot
.60996 .86629 Mdot
.49289 .69172 Mdot
.46176 .88515 Mdot
.45294 .70339 Mdot
.42859 .57172 Mdot
.34557 .49275 Mdot
.505 .24889 Mdot
.5607 .47684 Mdot
.34084 .4804 Mdot
.76105 .59387 Mdot
.28671 .52764 Mdot
.61846 .2594 Mdot
.29386 .46668 Mdot
.4695 .70146 Mdot
.50103 .70843 Mdot
.56474 .33368 Mdot
.54278 .3675 Mdot
.56885 .47749 Mdot
.57896 .35879 Mdot
.53479 .34586 Mdot
.64098 .65791 Mdot
.44774 .7882 Mdot
.50521 .66613 Mdot
.32088 .49746 Mdot
.43307 .70656 Mdot
.52166 .38418 Mdot
.49154 .33253 Mdot
.55434 .36772 Mdot
.79417 .43999 Mdot
.21368 .4791 Mdot
.49432 .37895 Mdot
.45597 .36389 Mdot
.66864 .65921 Mdot
.53993 .74868 Mdot
.51958 .84666 Mdot
.63729 .2296 Mdot
.49584 .4074 Mdot
.72673 .49115 Mdot
.74292 .45422 Mdot
.54296 .4039 Mdot
.51257 .25462 Mdot
.70951 .43818 Mdot
.51827 .36089 Mdot
.59444 .25725 Mdot
.68816 .64689 Mdot
.41007 .58099 Mdot
.63463 .64681 Mdot
.36288 .52294 Mdot
.41341 .57474 Mdot
.65028 .66391 Mdot
.6354 .34216 Mdot
.42083 .59757 Mdot
.42438 .7685 Mdot
.75478 .49234 Mdot
.51385 .40236 Mdot
.39669 .46002 Mdot
.6199 .65556 Mdot
.46492 .7183 Mdot
.34134 .5027 Mdot
.4801 .68719 Mdot
.502 .79656 Mdot
.65908 .36442 Mdot
.43537 .58446 Mdot
.46498 .72601 Mdot
.53434 .55556 Mdot
.72895 .49186 Mdot
.45073 .6982 Mdot
.46381 .28169 Mdot
.49225 .30768 Mdot
.17915 .59762 Mdot
.49011 .35084 Mdot
.42109 .64369 Mdot
.46345 .72125 Mdot
.42238 .60356 Mdot
.51249 .36108 Mdot
.62511 .67361 Mdot
.45481 .43788 Mdot
.50733 .37006 Mdot
.63176 .66886 Mdot
.49186 .3762 Mdot
.74798 .45958 Mdot
.28862 .5182 Mdot
.61852 .45271 Mdot
.72397 .4198 Mdot
.71958 .5029 Mdot
.60072 .42669 Mdot
.53841 .38581 Mdot
.72288 .56971 Mdot
.31979 .51564 Mdot
.52424 .30424 Mdot
.68497 .36026 Mdot
.32476 .48651 Mdot
.33836 .51286 Mdot
.48482 .3509 Mdot
.48912 .70811 Mdot
.63596 .6193 Mdot
.73048 .4906 Mdot
.5125 .70778 Mdot
.50571 .38312 Mdot
.47412 .34257 Mdot
.72478 .50581 Mdot
.45959 .71267 Mdot
.52035 .31663 Mdot
.32488 .6701 Mdot
.62598 .39295 Mdot
.43091 .70347 Mdot
.49186 .30886 Mdot
.19754 .52075 Mdot
.34608 .54696 Mdot
.74511 .71624 Mdot
.77681 .51856 Mdot
.66904 .64152 Mdot
.4425 .37739 Mdot
.79899 .73429 Mdot
.75414 .49085 Mdot
.37435 .72596 Mdot
.49397 .36582 Mdot
.50437 .39222 Mdot
.30003 .50424 Mdot
.52489 .32103 Mdot
.30854 .51353 Mdot
.73917 .42773 Mdot
.25454 .73105 Mdot
.3357 .53914 Mdot
.31374 .52099 Mdot
.56337 .30277 Mdot
.81319 .45559 Mdot
.3347 .48763 Mdot
.54536 .35634 Mdot
.75333 .57221 Mdot
.56462 .38285 Mdot
.76657 .4829 Mdot
.7374 .4362 Mdot
.33516 .4702 Mdot
.37105 .39034 Mdot
.56178 .3019 Mdot
.26113 .44273 Mdot
.67895 .4643 Mdot
.44217 .71392 Mdot
.47521 .35617 Mdot
.43919 .59703 Mdot
.64496 .63596 Mdot
.4492 .32098 Mdot
.52407 .39685 Mdot
.32318 .47731 Mdot
.72346 .51288 Mdot
.44777 .70202 Mdot
.47634 .39951 Mdot
.68541 .63376 Mdot
.7181 .49327 Mdot
.34715 .52076 Mdot
.36883 .43109 Mdot
.7071 .47703 Mdot
.45066 .41247 Mdot
.48999 .3703 Mdot
.48274 .40405 Mdot
.49741 .44337 Mdot
.47869 .71115 Mdot
.5981 .63812 Mdot
.44831 .4058 Mdot
.48956 .4886 Mdot
.63582 .38341 Mdot
.54991 .38227 Mdot
.35599 .49753 Mdot
.46485 .67732 Mdot
.43336 .59238 Mdot
.65145 .24837 Mdot
.48472 .38209 Mdot
.21359 .48335 Mdot
.77896 .40095 Mdot
.42517 .59853 Mdot
.36548 .4926 Mdot
.73271 .48441 Mdot
.47964 .37144 Mdot
.62469 .30975 Mdot
.53395 .34085 Mdot
.51112 .43617 Mdot
.66321 .63305 Mdot
.44184 .70293 Mdot
.58359 .28897 Mdot
.6486 .63674 Mdot
.33804 .51208 Mdot
.21431 .45853 Mdot
.35905 .53437 Mdot
.35438 .5264 Mdot
.46317 .5668 Mdot
.48455 .71539 Mdot
.81139 .72232 Mdot
.80701 .37512 Mdot
.53849 .39481 Mdot
.47132 .73159 Mdot
.33819 .49191 Mdot
.54124 .33317 Mdot
.30932 .50858 Mdot
.3259 .47005 Mdot
.51543 .3383 Mdot
.52203 .33914 Mdot
.61319 .27934 Mdot
.21871 .48543 Mdot
.74984 .48943 Mdot
.31894 .53694 Mdot
.28414 .43803 Mdot
.50374 .38804 Mdot
.53722 .38258 Mdot
.52011 .62301 Mdot
.74778 .50053 Mdot
.26729 .3529 Mdot
.50206 .35318 Mdot
.71861 .39047 Mdot
.54556 .3705 Mdot
.36889 .52958 Mdot
.48988 .73517 Mdot
.47389 .2778 Mdot
.65217 .6206 Mdot
.33599 .54661 Mdot
.71476 .50717 Mdot
.35285 .4625 Mdot
.27368 .3809 Mdot
.48214 .70036 Mdot
.31837 .5266 Mdot
.60029 .65826 Mdot
.45987 .70508 Mdot
.48727 .70383 Mdot
.5222 .60679 Mdot
.61025 .67055 Mdot
.73055 .51461 Mdot
.4537 .6863 Mdot
.2477 .4196 Mdot
.46683 .70074 Mdot
.26704 .38162 Mdot
.50135 .41176 Mdot
.62712 .32032 Mdot
.44262 .33219 Mdot
.5671 .34287 Mdot
.45932 .69134 Mdot
.71766 .49788 Mdot
.52412 .31464 Mdot
.34056 .53779 Mdot
.73957 .49751 Mdot
.41702 .51507 Mdot
.61984 .6798 Mdot
.29395 .49113 Mdot
.43691 .68142 Mdot
.30539 .50257 Mdot
.67817 .38058 Mdot
.7619 .44776 Mdot
.53366 .62557 Mdot
.57639 .46846 Mdot
.47234 .43052 Mdot
.46534 .33265 Mdot
.52376 .31276 Mdot
.53694 .36966 Mdot
.6279 .65439 Mdot
.71134 .51547 Mdot
.35633 .50082 Mdot
.41317 .2134 Mdot
.47018 .72297 Mdot
.54096 .56959 Mdot
.49184 .44172 Mdot
.47766 .34041 Mdot
.33809 .49503 Mdot
.32821 .46765 Mdot
.41211 .26303 Mdot
.62193 .62326 Mdot
.56706 .36938 Mdot
.54869 .33467 Mdot
.59969 .32197 Mdot
.45876 .69408 Mdot
.36954 .65668 Mdot
.68346 .66373 Mdot
.47821 .89342 Mdot
.64912 .63901 Mdot
.63385 .55672 Mdot
.3126 .50089 Mdot
.74569 .47295 Mdot
.52746 .35145 Mdot
.41605 .45016 Mdot
.35896 .47967 Mdot
.58408 .61726 Mdot
.73825 .47885 Mdot
.39071 .62011 Mdot
.46311 .7309 Mdot
.47705 .40329 Mdot
.54616 .36811 Mdot
.50291 .32507 Mdot
.53652 .33143 Mdot
.44436 .72353 Mdot
.52681 .33612 Mdot
.44044 .72982 Mdot
.28021 .37056 Mdot
.68112 .35187 Mdot
.60432 .64541 Mdot
.55058 .74832 Mdot
.35225 .52861 Mdot
.22395 .40067 Mdot
.27748 .35241 Mdot
.62635 .36768 Mdot
.46073 .63956 Mdot
.47332 .40261 Mdot
.65991 .63397 Mdot
.51759 .71519 Mdot
.6055 .64879 Mdot
.14227 .51427 Mdot
.38627 .4137 Mdot
.41057 .63742 Mdot
.51292 .32436 Mdot
.61612 .6189 Mdot
.35943 .41068 Mdot
.44565 .406 Mdot
.71232 .46709 Mdot
.26219 .39867 Mdot
.41366 .46751 Mdot
.75598 .48249 Mdot
.51033 .34187 Mdot
.29614 .47738 Mdot
.53051 .35586 Mdot
.52357 .34701 Mdot
.48936 .39865 Mdot
.47434 .74204 Mdot
.51736 .40988 Mdot
.54072 .3691 Mdot
.65387 .21338 Mdot
.56866 .6576 Mdot
.65515 .67365 Mdot
.45082 .23192 Mdot
.73589 .49587 Mdot
.36328 .52155 Mdot
.60703 .45943 Mdot
.47312 .72622 Mdot
.4141 .26034 Mdot
.49577 .33646 Mdot
.347 .71086 Mdot
.46812 .67276 Mdot
.71614 .4785 Mdot
.43545 .59891 Mdot
.37212 .62666 Mdot
.67472 .63916 Mdot
.44064 .58817 Mdot
.62263 .6503 Mdot
.48257 .21601 Mdot
.31057 .51761 Mdot
.47204 .4303 Mdot
.44683 .69696 Mdot
.60667 .65927 Mdot
.62247 .30803 Mdot
.52626 .39083 Mdot
.64999 .62227 Mdot
.44041 .35768 Mdot
.63618 .41148 Mdot
.60246 .46329 Mdot
.60102 .65301 Mdot
.46665 .67011 Mdot
.45922 .69884 Mdot
.75796 .48291 Mdot
.34107 .54535 Mdot
.33142 .4771 Mdot
.46449 .69679 Mdot
.66578 .79152 Mdot
.50759 .38213 Mdot
.49414 .38923 Mdot
.48079 .48746 Mdot
.54458 .33581 Mdot
.74532 .44189 Mdot
.42218 .56618 Mdot
.33985 .47474 Mdot
.52489 .31348 Mdot
.51945 .31693 Mdot
.49068 .36289 Mdot
.64948 .34384 Mdot
.6322 .64566 Mdot
.48413 .365 Mdot
.72751 .46412 Mdot
.416 .50088 Mdot
.54083 .3552 Mdot
.45251 .4178 Mdot
.30752 .51094 Mdot
.66061 .58041 Mdot
.46741 .71995 Mdot
.61411 .64459 Mdot
.61174 .65217 Mdot
.68928 .32353 Mdot
.36491 .54725 Mdot
.43961 .58231 Mdot
.5237 .75759 Mdot
.43627 .5927 Mdot
.73879 .47648 Mdot
.51874 .56718 Mdot
.65542 .69157 Mdot
.65128 .67379 Mdot
.49954 .69315 Mdot
.50851 .30728 Mdot
.54214 .35499 Mdot
.38637 .73761 Mdot
.49149 .39656 Mdot
.7517 .48516 Mdot
.487 .7257 Mdot
.31539 .52133 Mdot
.73826 .456 Mdot
.45428 .71397 Mdot
.34048 .47895 Mdot
.54005 .30887 Mdot
.54664 .35498 Mdot
.34175 .50643 Mdot
.34555 .52526 Mdot
.52133 .37074 Mdot
.61526 .20944 Mdot
.34805 .47782 Mdot
.34413 .49916 Mdot
.41575 .49259 Mdot
.67521 .65058 Mdot
.46768 .45241 Mdot
.47733 .72784 Mdot
.53914 .3733 Mdot
.60389 .63963 Mdot
.72928 .47675 Mdot
.3407 .52014 Mdot
.47407 .3653 Mdot
.50122 .38036 Mdot
.72728 .4898 Mdot
.7634 .46892 Mdot
.74103 .50118 Mdot
.49408 .72694 Mdot
.50962 .33503 Mdot
.34119 .48856 Mdot
.46065 .73094 Mdot
.71307 .47064 Mdot
.76164 .48812 Mdot
.58711 .21856 Mdot
.5143 .38004 Mdot
.73973 .4521 Mdot
.65405 .85471 Mdot
.59197 .24137 Mdot
.41261 .57081 Mdot
.69232 .65982 Mdot
.79514 .50941 Mdot
.69633 .46964 Mdot
.43955 .70562 Mdot
.54794 .57501 Mdot
.73762 .51008 Mdot
.4764 .39101 Mdot
.50993 .39926 Mdot
.46598 .41724 Mdot
.73512 .49855 Mdot
.66045 .36297 Mdot
.29548 .51117 Mdot
.32217 .29037 Mdot
.73619 .49574 Mdot
.60696 .66355 Mdot
.67154 .62124 Mdot
.65511 .64115 Mdot
.46455 .37681 Mdot
.45913 .21061 Mdot
.28471 .40544 Mdot
.26954 .34414 Mdot
.46149 .72901 Mdot
.32585 .46852 Mdot
.41472 .53761 Mdot
.33851 .51375 Mdot
.6356 .63221 Mdot
.7171 .49348 Mdot
.29917 .50285 Mdot
.48658 .70294 Mdot
.46006 .6956 Mdot
.65227 .61829 Mdot
.64026 .64452 Mdot
.65056 .65338 Mdot
.33782 .54635 Mdot
.31264 .50205 Mdot
.50574 .32049 Mdot
.33965 .52513 Mdot
.7976 .41118 Mdot
.78558 .4571 Mdot
.65536 .61596 Mdot
.47415 .71226 Mdot
.34989 .50366 Mdot
.51422 .40298 Mdot
.59154 .55913 Mdot
.5904 .65823 Mdot
.70875 .48605 Mdot
.24569 .66767 Mdot
.238 .7225 Mdot
.47972 .32349 Mdot
.43483 .69898 Mdot
.48627 .26548 Mdot
.53391 .3748 Mdot
.66381 .63102 Mdot
.77288 .37357 Mdot
.42842 .60395 Mdot
.53521 .35443 Mdot
.54912 .32405 Mdot
.48156 .6936 Mdot
.60569 .45936 Mdot
.47536 .39086 Mdot
.53689 .58792 Mdot
.47844 .67749 Mdot
.68434 .66073 Mdot
.7628 .27229 Mdot
.43567 .50528 Mdot
.68007 .40776 Mdot
.41136 .58056 Mdot
.48445 .39492 Mdot
.63801 .65797 Mdot
.71889 .46765 Mdot
.64062 .65237 Mdot
.36795 .49966 Mdot
.67481 .64353 Mdot
.49736 .40335 Mdot
.33683 .48623 Mdot
.458 .71309 Mdot
.54323 .54271 Mdot
.48935 .22545 Mdot
.62838 .67459 Mdot
.40889 .56692 Mdot
.52315 .34002 Mdot
.23756 .42041 Mdot
.56365 .32886 Mdot
.54175 .37477 Mdot
.44828 .68382 Mdot
.32915 .49515 Mdot
.46882 .67734 Mdot
.44167 .40838 Mdot
.23804 .50603 Mdot
.4738 .72132 Mdot
.42045 .45343 Mdot
.71981 .50516 Mdot
.65544 .3611 Mdot
.5125 .35567 Mdot
.44572 .69921 Mdot
.50103 .33961 Mdot
.31617 .53497 Mdot
.63629 .36503 Mdot
.61998 .39437 Mdot
.46551 .68491 Mdot
.40623 .59943 Mdot
.64223 .42794 Mdot
.47084 .45476 Mdot
.44883 .71594 Mdot
.49483 .19587 Mdot
.42393 .59303 Mdot
.71949 .48702 Mdot
.76413 .46688 Mdot
.73893 .46594 Mdot
.49573 .39547 Mdot
.25022 .46082 Mdot
.76076 .47737 Mdot
.49267 .69919 Mdot
.75218 .46507 Mdot
.75871 .42092 Mdot
.38417 .74997 Mdot
.71842 .50317 Mdot
.50625 .35912 Mdot
.4834 .27915 Mdot
.54739 .57197 Mdot
.64488 .6823 Mdot
.31925 .59555 Mdot
.65833 .21593 Mdot
.50746 .38842 Mdot
.24543 .4855 Mdot
.37246 .50216 Mdot
.65166 .53839 Mdot
.61874 .38977 Mdot
.52033 .53526 Mdot
.34765 .50172 Mdot
.59217 .464 Mdot
.35995 .49149 Mdot
.47876 .43709 Mdot
.49589 .37647 Mdot
.33976 .54785 Mdot
.29225 .69967 Mdot
.47382 .18485 Mdot
.36478 .73403 Mdot
.35087 .48722 Mdot
.45199 .71772 Mdot
.44088 .68906 Mdot
.44723 .68518 Mdot
.63254 .66175 Mdot
.3212 .53084 Mdot
.48284 .379 Mdot
.66712 .65567 Mdot
.5159 .34648 Mdot
.46922 .69218 Mdot
.62461 .37605 Mdot
.31336 .51916 Mdot
.51824 .3594 Mdot
.33734 .42335 Mdot
.62289 .64552 Mdot
.72817 .49344 Mdot
.23306 .63969 Mdot
.68738 .67224 Mdot
.45585 .66901 Mdot
.36301 .47271 Mdot
.66089 .60876 Mdot
.58799 .58237 Mdot
.53617 .39871 Mdot
.54684 .38135 Mdot
.55349 .57932 Mdot
.3787 .4135 Mdot
.47294 .38981 Mdot
.66279 .66311 Mdot
.66965 .66498 Mdot
.49957 .34189 Mdot
.32875 .53605 Mdot
.75111 .50599 Mdot
.70249 .49723 Mdot
.48956 .43483 Mdot
.57687 .47146 Mdot
.6262 .31783 Mdot
.53113 .31855 Mdot
.45105 .39874 Mdot
.60287 .66448 Mdot
.41054 .5731 Mdot
.55001 .47865 Mdot
.74949 .47072 Mdot
.4959 .35958 Mdot
.4145 .22551 Mdot
.32906 .531 Mdot
.6461 .62042 Mdot
.45805 .73406 Mdot
.70845 .47371 Mdot
.66538 .62255 Mdot
.49955 .34196 Mdot
.52037 .31679 Mdot
.44948 .69642 Mdot
.36967 .53144 Mdot
.72468 .5006 Mdot
.66774 .65617 Mdot
.74803 .47364 Mdot
.3128 .50557 Mdot
.34796 .51194 Mdot
.55576 .35813 Mdot
.56798 .34024 Mdot
.62188 .66906 Mdot
.48255 .42471 Mdot
.662 .65212 Mdot
.53899 .74848 Mdot
.43469 .71519 Mdot
.533 .31047 Mdot
.3708 .54368 Mdot
.46698 .69284 Mdot
.51283 .38788 Mdot
.55473 .5832 Mdot
.48822 .32215 Mdot
.6039 .62696 Mdot
.77306 .35227 Mdot
.73097 .47105 Mdot
.51428 .28685 Mdot
.42459 .30705 Mdot
.54123 .32897 Mdot
.65896 .67615 Mdot
.26311 .41227 Mdot
.4787 .71706 Mdot
.31526 .49536 Mdot
.71058 .63122 Mdot
.46868 .70565 Mdot
.50083 .36012 Mdot
.74585 .48679 Mdot
.35803 .49261 Mdot
.4217 .57336 Mdot
.54666 .49111 Mdot
.4637 .29725 Mdot
.55161 .40125 Mdot
.47475 .39865 Mdot
.4393 .8147 Mdot
.64739 .65322 Mdot
.33929 .49374 Mdot
.43493 .70254 Mdot
.48322 .70618 Mdot
.62716 .64184 Mdot
.41588 .47613 Mdot
.33051 .72537 Mdot
.70152 .82156 Mdot
.66434 .62081 Mdot
.74598 .46383 Mdot
.63504 .36646 Mdot
.65591 .63973 Mdot
.62566 .6577 Mdot
.60444 .66954 Mdot
.38895 .74508 Mdot
.34846 .48628 Mdot
.50039 .38184 Mdot
.37694 .47782 Mdot
.48809 .3954 Mdot
.66777 .42029 Mdot
.47031 .69363 Mdot
.31458 .49572 Mdot
.67653 .44768 Mdot
.45685 .35523 Mdot
.52998 .37201 Mdot
.66757 .46845 Mdot
.54623 .27956 Mdot
.6502 .25396 Mdot
.55177 .35734 Mdot
.63404 .65166 Mdot
.38155 .55437 Mdot
.45036 .41076 Mdot
.33269 .42445 Mdot
.45636 .70105 Mdot
.43589 .58363 Mdot
.46721 .43149 Mdot
.46069 .40255 Mdot
.36039 .49696 Mdot
.2996 .50074 Mdot
.76229 .48246 Mdot
.22477 .60737 Mdot
.4557 .70504 Mdot
.38678 .66447 Mdot
.54262 .37347 Mdot
.44297 .6401 Mdot
.78084 .36899 Mdot
.51839 .38318 Mdot
.52284 .60121 Mdot
.41251 .26308 Mdot
.47271 .35487 Mdot
.27923 .33228 Mdot
.47411 .70658 Mdot
.69624 .37427 Mdot
.52609 .33069 Mdot
.65498 .62618 Mdot
.32279 .484 Mdot
.29379 .49082 Mdot
.71921 .46626 Mdot
.8084 .40313 Mdot
.31126 .77506 Mdot
.31318 .49614 Mdot
.52941 .38861 Mdot
.46901 .7185 Mdot
.42911 .57614 Mdot
.45261 .3156 Mdot
.50559 .64796 Mdot
.32851 .52933 Mdot
.44484 .39938 Mdot
.34338 .7121 Mdot
.5989 .4623 Mdot
.20265 .42972 Mdot
.45119 .68429 Mdot
.75378 .47312 Mdot
.55262 .41418 Mdot
.52375 .76088 Mdot
.54705 .35636 Mdot
.67141 .41574 Mdot
.34325 .5543 Mdot
.75414 .48101 Mdot
.5328 .36564 Mdot
.4721 .38488 Mdot
.59765 .44186 Mdot
.7684 .47251 Mdot
.47405 .38877 Mdot
.47352 .32714 Mdot
.3138 .48822 Mdot
.42003 .56502 Mdot
.31726 .52241 Mdot
.52958 .35665 Mdot
.74999 .32209 Mdot
.30892 .52496 Mdot
.35072 .59496 Mdot
.7686 .52162 Mdot
.47175 .72648 Mdot
.45002 .33333 Mdot
.5113 .40977 Mdot
.18773 .44746 Mdot
.42714 .57299 Mdot
.55852 .83898 Mdot
.61174 .622 Mdot
.60691 .17086 Mdot
.68537 .6748 Mdot
.40773 .61436 Mdot
.55688 .64132 Mdot
.44927 .40331 Mdot
.41253 .44583 Mdot
.26268 .34523 Mdot
.42044 .70642 Mdot
.22658 .39409 Mdot
.54279 .36729 Mdot
.49305 .36143 Mdot
.66477 .64581 Mdot
.42627 .62891 Mdot
.47162 .2788 Mdot
.55277 .47809 Mdot
.71519 .48147 Mdot
.32678 .51374 Mdot
.50895 .40098 Mdot
.27439 .68762 Mdot
.61484 .66982 Mdot
.49476 .23296 Mdot
.5154 .35926 Mdot
.49786 .26415 Mdot
.42863 .62735 Mdot
.45908 .71563 Mdot
.60051 .65266 Mdot
.61136 .67002 Mdot
.48528 .39367 Mdot
.4496 .7286 Mdot
.49379 .32525 Mdot
.64418 .4198 Mdot
.44086 .36343 Mdot
.73482 .4763 Mdot
.5315 .39263 Mdot
.46302 .25739 Mdot
.24871 .28447 Mdot
.47239 .32625 Mdot
.35412 .53007 Mdot
.65329 .65543 Mdot
.63373 .64105 Mdot
.33523 .47658 Mdot
.63342 .64044 Mdot
.32037 .29642 Mdot
.23344 .47521 Mdot
.74184 .47581 Mdot
.2947 .35647 Mdot
.72336 .47477 Mdot
.43643 .58503 Mdot
.51706 .37734 Mdot
.62272 .72355 Mdot
.67298 .62727 Mdot
.76319 .41802 Mdot
.46687 .69751 Mdot
.42643 .57161 Mdot
.52069 .3375 Mdot
.6753 .47785 Mdot
.64603 .62956 Mdot
.48131 .54784 Mdot
.48726 .38882 Mdot
.3285 .54274 Mdot
.47507 .34752 Mdot
.57252 .31754 Mdot
.42957 .57171 Mdot
.46895 .35926 Mdot
.45435 .71415 Mdot
.31121 .52336 Mdot
.41224 .64604 Mdot
.62159 .65725 Mdot
.53163 .34759 Mdot
.53103 .38581 Mdot
.34796 .47042 Mdot
.53593 .39667 Mdot
.44988 .72471 Mdot
.88082 .62483 Mdot
.73628 .50467 Mdot
.41033 .57522 Mdot
.2827 .60507 Mdot
.46936 .36462 Mdot
.51533 .31489 Mdot
.49414 .52854 Mdot
.41773 .22351 Mdot
.46438 .72393 Mdot
.5389 .41507 Mdot
.6621 .66983 Mdot
.72276 .50063 Mdot
.48377 .69081 Mdot
.51819 .33423 Mdot
.49118 .37977 Mdot
.75305 .48179 Mdot
.66578 .46387 Mdot
.74947 .44851 Mdot
.44089 .71393 Mdot
.25251 .51569 Mdot
.59359 .55806 Mdot
.50941 .37535 Mdot
.40433 .56731 Mdot
.33171 .4979 Mdot
.44875 .7182 Mdot
.39085 .26096 Mdot
.4799 .43767 Mdot
.43045 .69413 Mdot
.45693 .71107 Mdot
.52911 .40307 Mdot
.36158 .54872 Mdot
.36082 .46769 Mdot
.33518 .49685 Mdot
.68393 .34536 Mdot
.5072 .82759 Mdot
.64852 .6567 Mdot
.47153 .71227 Mdot
.60598 .63629 Mdot
.7354 .50962 Mdot
.63611 .39225 Mdot
.62386 .67582 Mdot
.32655 .54535 Mdot
.60707 .64743 Mdot
.49427 .32385 Mdot
.48779 .71552 Mdot
.62003 .66517 Mdot
.5386 .3303 Mdot
.46689 .40302 Mdot
.55829 .41863 Mdot
.73626 .51275 Mdot
.59096 .46617 Mdot
.50785 .35385 Mdot
.43415 .59878 Mdot
.52 .3663 Mdot
.44929 .72554 Mdot
.54755 .53974 Mdot
.48763 .35322 Mdot
.67245 .62659 Mdot
.52296 .83627 Mdot
.67424 .66317 Mdot
.58469 .33348 Mdot
.5232 .35339 Mdot
.50994 .37816 Mdot
.51853 .33828 Mdot
.41222 .47049 Mdot
.44157 .67505 Mdot
.53174 .42554 Mdot
.63296 .6161 Mdot
.34087 .51381 Mdot
.30543 .52277 Mdot
.50704 .54214 Mdot
.44104 .59053 Mdot
.46147 .7328 Mdot
.50862 .37992 Mdot
.48372 .55119 Mdot
.51806 .5037 Mdot
.35098 .72463 Mdot
.69807 .64492 Mdot
.64665 .67469 Mdot
.34554 .53846 Mdot
.64238 .67024 Mdot
.52243 .33534 Mdot
.44512 .39857 Mdot
.41079 .64341 Mdot
.42358 .6844 Mdot
.72099 .49852 Mdot
.52054 .34833 Mdot
.63665 .32106 Mdot
.66865 .65911 Mdot
.60518 .66662 Mdot
.49537 .32537 Mdot
.37525 .51389 Mdot
.32561 .20768 Mdot
.47382 .73169 Mdot
.23937 .43071 Mdot
.37273 .45639 Mdot
.61224 .3547 Mdot
.48082 .70892 Mdot
.52536 .59312 Mdot
.65151 .68225 Mdot
.74554 .3028 Mdot
.3434 .50973 Mdot
.723 .4991 Mdot
.54446 .34528 Mdot
.32662 .54558 Mdot
.63389 .61185 Mdot
.355 .4819 Mdot
.46676 .42917 Mdot
.47979 .68149 Mdot
.64235 .63771 Mdot
.50162 .70574 Mdot
.36599 .50574 Mdot
.72587 .47301 Mdot
.7098 .39175 Mdot
.24516 .41472 Mdot
.41065 .26691 Mdot
.48356 .36634 Mdot
.58045 .68462 Mdot
.48196 .38119 Mdot
.29115 .50272 Mdot
.51165 .35588 Mdot
.4591 .33551 Mdot
.64822 .68386 Mdot
.55124 .37996 Mdot
.53616 .38601 Mdot
.3202 .42663 Mdot
.52394 .37856 Mdot
.49839 .34557 Mdot
.55675 .35752 Mdot
.34367 .54971 Mdot
.55235 .3757 Mdot
.33306 .5426 Mdot
.36467 .7204 Mdot
.62104 .6538 Mdot
.73808 .50878 Mdot
.72856 .50849 Mdot
.68092 .41181 Mdot
.64122 .32989 Mdot
.40215 .52077 Mdot
.32601 .52391 Mdot
.45974 .69232 Mdot
.4982 .32264 Mdot
.51163 .19182 Mdot
.74415 .32485 Mdot
.66708 .67716 Mdot
.614 .66149 Mdot
.54024 .34334 Mdot
.22629 .70565 Mdot
.5507 .3629 Mdot
.48272 .49066 Mdot
.49486 .39455 Mdot
.53169 .30953 Mdot
.59803 .6516 Mdot
.67869 .38202 Mdot
.48424 .36499 Mdot
.36058 .49679 Mdot
.72107 .49465 Mdot
.51379 .26553 Mdot
.74803 .34923 Mdot
.35574 .43869 Mdot
.43816 .30071 Mdot
.49467 .34138 Mdot
.6697 .64665 Mdot
.35436 .49057 Mdot
.49898 .49412 Mdot
.45647 .72797 Mdot
.56505 .48162 Mdot
.27162 .37382 Mdot
.42034 .7191 Mdot
.71854 .49412 Mdot
.59279 .62672 Mdot
.49094 .40325 Mdot
.63861 .66214 Mdot
.50709 .43408 Mdot
.5197 .50792 Mdot
.73899 .47439 Mdot
.31195 .5476 Mdot
.45269 .71802 Mdot
.30846 .53099 Mdot
.45794 .22915 Mdot
.74492 .3224 Mdot
.61229 .17181 Mdot
.67773 .64103 Mdot
.35258 .23428 Mdot
.3276 .48993 Mdot
.48396 .38805 Mdot
.6982 .82346 Mdot
.3256 .50129 Mdot
.32963 .54364 Mdot
.53661 .52083 Mdot
.67737 .36783 Mdot
.48462 .42588 Mdot
.34687 .47593 Mdot
.59599 .62353 Mdot
.7369 .48248 Mdot
.53404 .32623 Mdot
.46457 .42974 Mdot
.29959 .50306 Mdot
.6399 .62915 Mdot
.66872 .40254 Mdot
.63626 .64793 Mdot
.34523 .48559 Mdot
.61929 .63882 Mdot
.3795 .60033 Mdot
.623 .67458 Mdot
.52256 .4023 Mdot
.50839 .37907 Mdot
.47306 .60862 Mdot
.34794 .51198 Mdot
.51678 .3146 Mdot
.49247 .37037 Mdot
.3374 .48877 Mdot
.64605 .69271 Mdot
.38713 .23628 Mdot
.50724 .31565 Mdot
.50417 .38212 Mdot
.7427 .50331 Mdot
.62809 .43237 Mdot
.47062 .49196 Mdot
.53755 .32656 Mdot
.73862 .46472 Mdot
.3368 .54572 Mdot
.52143 .36733 Mdot
.68084 .383 Mdot
.68777 .64364 Mdot
.50767 .32859 Mdot
.42725 .5771 Mdot
.48287 .39777 Mdot
.30849 .22861 Mdot
.52706 .34188 Mdot
.34716 .49417 Mdot
.32582 .48513 Mdot
.70565 .65818 Mdot
.33751 .5101 Mdot
.4133 .57097 Mdot
.4603 .69832 Mdot
.21207 .43311 Mdot
.4149 .56857 Mdot
.47014 .3511 Mdot
.81083 .38134 Mdot
.4603 .42752 Mdot
.44586 .40945 Mdot
.8146 .45622 Mdot
.41171 .58038 Mdot
.32401 .49518 Mdot
.28412 .687 Mdot
.50887 .42045 Mdot
.46354 .73338 Mdot
.45274 .416 Mdot
.50693 .32908 Mdot
.47107 .32206 Mdot
.24236 .5019 Mdot
.47838 .73364 Mdot
.4675 .45291 Mdot
.53366 .32578 Mdot
.41806 .22402 Mdot
.51762 .39902 Mdot
.70913 .49313 Mdot
.31378 .51393 Mdot
.64131 .66815 Mdot
.73411 .47889 Mdot
.47472 .39626 Mdot
.73736 .49661 Mdot
.64205 .66059 Mdot
.44843 .69101 Mdot
.5179 .40476 Mdot
.7668 .48383 Mdot
.71544 .49122 Mdot
.48178 .34938 Mdot
.3156 .49105 Mdot
.56102 .32292 Mdot
.5223 .37025 Mdot
.51226 .33673 Mdot
.32843 .47791 Mdot
.78242 .68118 Mdot
.49209 .35998 Mdot
.52535 .59625 Mdot
.28732 .50921 Mdot
.41769 .56456 Mdot
.65677 .66791 Mdot
.46945 .33597 Mdot
.48461 .70996 Mdot
.462 .69863 Mdot
.68029 .63802 Mdot
.3027 .49672 Mdot
.63812 .63696 Mdot
.47086 .32709 Mdot
.44781 .40441 Mdot
.5428 .34321 Mdot
.71522 .64227 Mdot
.36621 .61847 Mdot
.35224 .51269 Mdot
.6645 .67457 Mdot
.56424 .47825 Mdot
.48408 .72297 Mdot
.59496 .65098 Mdot
.33223 .46164 Mdot
.3134 .48296 Mdot
.34239 .47714 Mdot
.72622 .46731 Mdot
.64596 .64105 Mdot
.3535 .46105 Mdot
.35505 .46593 Mdot
.49137 .3318 Mdot
.5289 .32309 Mdot
.34399 .54677 Mdot
.63857 .59255 Mdot
.72513 .47777 Mdot
.67177 .64627 Mdot
.28437 .22927 Mdot
.47166 .73274 Mdot
.32404 .42615 Mdot
.54053 .33111 Mdot
.51492 .90592 Mdot
.551 .36176 Mdot
.52621 .39254 Mdot
.36288 .52296 Mdot
.76041 .459 Mdot
.73752 .48509 Mdot
.32703 .48937 Mdot
.32587 .47168 Mdot
.71122 .48021 Mdot
.52702 .53578 Mdot
.34312 .21115 Mdot
.5148 .49796 Mdot
.35495 .5054 Mdot
.24418 .40566 Mdot
.46906 .68429 Mdot
.29702 .52773 Mdot
.49536 .75195 Mdot
.61775 .65012 Mdot
.62252 .67204 Mdot
.4525 .69267 Mdot
.49392 .35377 Mdot
.66382 .628 Mdot
.51599 .29557 Mdot
.40402 .62485 Mdot
.48384 .63774 Mdot
.57038 .18686 Mdot
.52408 .40327 Mdot
.50359 .25841 Mdot
.41139 .7897 Mdot
.47864 .33057 Mdot
.38999 .38118 Mdot
.72778 .50035 Mdot
.29142 .5193 Mdot
.49046 .72415 Mdot
.22646 .51479 Mdot
.50939 .37673 Mdot
.35573 .49946 Mdot
.47962 .72958 Mdot
.38824 .62412 Mdot
.53622 .58754 Mdot
.48065 .33861 Mdot
.75096 .77717 Mdot
.3606 .48733 Mdot
.64212 .66807 Mdot
.30795 .40953 Mdot
.31127 .53665 Mdot
.56395 .59028 Mdot
.61268 .61462 Mdot
.53478 .47896 Mdot
.34804 .47408 Mdot
.74691 .44777 Mdot
.32179 .51516 Mdot
.74706 .45771 Mdot
.36241 .47263 Mdot
.62585 .63646 Mdot
.52865 .36507 Mdot
.62436 .64198 Mdot
.70636 .49045 Mdot
.67734 .63804 Mdot
.49053 .72384 Mdot
.41358 .58855 Mdot
.46852 .69112 Mdot
.63516 .37675 Mdot
.37367 .2793 Mdot
.44181 .70166 Mdot
.49545 .57465 Mdot
.49317 .4002 Mdot
.36888 .52916 Mdot
.63572 .66603 Mdot
.67088 .68162 Mdot
.58611 .46783 Mdot
.34175 .48157 Mdot
.6345 .62863 Mdot
.24798 .40943 Mdot
.65438 .80323 Mdot
.45206 .35157 Mdot
.5163 .80432 Mdot
.34281 .49038 Mdot
.63129 .68302 Mdot
.47989 .48788 Mdot
.29619 .50386 Mdot
.62028 .66695 Mdot
.44812 .71298 Mdot
.4836 .71368 Mdot
.53752 .3938 Mdot
.49805 .708 Mdot
.64286 .68106 Mdot
.41826 .2207 Mdot
.30889 .50279 Mdot
.34726 .61437 Mdot
.72275 .50378 Mdot
.62932 .65967 Mdot
.53354 .4073 Mdot
.36982 .54674 Mdot
.60732 .64105 Mdot
.28618 .75697 Mdot
.19979 .32502 Mdot
.63603 .62776 Mdot
.31444 .51492 Mdot
.33932 .52036 Mdot
.46134 .35713 Mdot
.56748 .47378 Mdot
.64533 .62791 Mdot
.62092 .72288 Mdot
.61973 .29518 Mdot
.41586 .57729 Mdot
.65576 .21463 Mdot
.48501 .36438 Mdot
.49599 .33923 Mdot
.44242 .7177 Mdot
.52887 .37636 Mdot
.32967 .46892 Mdot
.55104 .35977 Mdot
.46062 .67444 Mdot
.68384 .64935 Mdot
.51495 .37549 Mdot
.7234 .50182 Mdot
.45994 .67721 Mdot
.44016 .68618 Mdot
.61605 .6396 Mdot
.31217 .48779 Mdot
.30696 .72645 Mdot
.63716 .64622 Mdot
.50798 .33489 Mdot
.42512 .59714 Mdot
.55496 .371 Mdot
.47051 .60118 Mdot
.29109 .49784 Mdot
.64315 .67002 Mdot
.31229 .54976 Mdot
.46772 .71347 Mdot
.65842 .68238 Mdot
.48638 .40338 Mdot
.63593 .67478 Mdot
.53365 .61672 Mdot
.73033 .55907 Mdot
.34898 .46553 Mdot
.5566 .59544 Mdot
.30411 .49155 Mdot
.41613 .5748 Mdot
.68253 .31703 Mdot
.72065 .48426 Mdot
.67114 .66111 Mdot
.35372 .59576 Mdot
.62375 .66141 Mdot
.52066 .38322 Mdot
.49018 .38257 Mdot
.66485 .64776 Mdot
.72833 .46927 Mdot
.70377 .42234 Mdot
.73184 .44559 Mdot
.32146 .52996 Mdot
.53695 .55489 Mdot
.3116 .20835 Mdot
.6902 .63562 Mdot
.45598 .69433 Mdot
.41639 .34602 Mdot
.47115 .35965 Mdot
.47926 .7316 Mdot
.43282 .70674 Mdot
.72313 .46095 Mdot
.62569 .65944 Mdot
.28741 .49834 Mdot
.48636 .69471 Mdot
.36914 .55218 Mdot
.67607 .39588 Mdot
.48506 .44014 Mdot
.60712 .36871 Mdot
.47475 .40296 Mdot
.59845 .4631 Mdot
.47396 .67651 Mdot
.50026 .36504 Mdot
.52996 .43397 Mdot
.45498 .72364 Mdot
.73317 .45596 Mdot
.29384 .55366 Mdot
.63203 .62765 Mdot
.57981 .86587 Mdot
.52264 .40147 Mdot
.52555 .36579 Mdot
.46236 .72919 Mdot
.37352 .40557 Mdot
.35241 .5198 Mdot
.30904 .49337 Mdot
.64817 .65292 Mdot
.51923 .51626 Mdot
.53423 .39916 Mdot
.50683 .40601 Mdot
.65449 .62475 Mdot
.43393 .59755 Mdot
.63978 .2017 Mdot
.50138 .37833 Mdot
.47686 .70665 Mdot
.52027 .61864 Mdot
.47959 .67919 Mdot
.5095 .30171 Mdot
.51567 .38866 Mdot
.4854 .40606 Mdot
.50435 .41381 Mdot
.46691 .68647 Mdot
.47393 .39754 Mdot
.51885 .42933 Mdot
.32778 .49618 Mdot
.49087 .34923 Mdot
.6177 .2905 Mdot
.50459 .37545 Mdot
.72772 .50194 Mdot
.47849 .49748 Mdot
.5272 .34377 Mdot
.49255 .34651 Mdot
.6225 .30186 Mdot
.53515 .36821 Mdot
.48018 .72986 Mdot
.34305 .51556 Mdot
.46791 .71508 Mdot
.45376 .70104 Mdot
.60842 .64736 Mdot
.75564 .46112 Mdot
.47304 .4117 Mdot
.71809 .47034 Mdot
.45882 .35872 Mdot
.44057 .40479 Mdot
.63764 .41148 Mdot
.486 .49202 Mdot
.73156 .51092 Mdot
.50346 .40487 Mdot
.64267 .65676 Mdot
.64205 .67132 Mdot
.54852 .57617 Mdot
.44283 .35823 Mdot
.4933 .70672 Mdot
.44553 .6999 Mdot
.78433 .45442 Mdot
.73112 .54692 Mdot
.71389 .48999 Mdot
.65683 .45093 Mdot
.54259 .31178 Mdot
.50233 .34692 Mdot
.44468 .33439 Mdot
.60661 .62939 Mdot
.41233 .58652 Mdot
.65925 .62175 Mdot
.4359 .63058 Mdot
.47535 .685 Mdot
.52594 .40178 Mdot
.19891 .65905 Mdot
.3173 .53006 Mdot
.34341 .51607 Mdot
.46077 .6742 Mdot
.67297 .66428 Mdot
.44027 .36825 Mdot
.50659 .86453 Mdot
.3007 .48222 Mdot
.75402 .49994 Mdot
.53459 .35993 Mdot
.61879 .64907 Mdot
.30906 .5183 Mdot
.76522 .488 Mdot
.50318 .41253 Mdot
.60485 .61801 Mdot
.50525 .36444 Mdot
.30162 .33216 Mdot
.31855 .49638 Mdot
.6233 .41594 Mdot
.36069 .53364 Mdot
.47024 .68864 Mdot
.46346 .72212 Mdot
.51327 .38815 Mdot
.54112 .87021 Mdot
.37538 .55588 Mdot
.43183 .71478 Mdot
.76354 .47952 Mdot
.41878 .59628 Mdot
.76087 .47289 Mdot
.66232 .65048 Mdot
.71874 .49245 Mdot
.6079 .64296 Mdot
.63533 .59208 Mdot
.31444 .46298 Mdot
.75262 .48268 Mdot
.39743 .34089 Mdot
.44398 .39466 Mdot
.70672 .47983 Mdot
.53541 .33702 Mdot
.4634 .33758 Mdot
.63962 .62236 Mdot
.71962 .47215 Mdot
.4744 .3642 Mdot
.2786 .60125 Mdot
.45638 .71563 Mdot
.49341 .71412 Mdot
.45005 .4075 Mdot
.6156 .677 Mdot
.34906 .46712 Mdot
.62765 .44944 Mdot
.41724 .56171 Mdot
.50938 .40554 Mdot
.46374 .37348 Mdot
.36527 .49593 Mdot
.35222 .52922 Mdot
.51148 .39097 Mdot
.24081 .4503 Mdot
.47929 .40018 Mdot
.48218 .71733 Mdot
.32119 .53058 Mdot
.34102 .52039 Mdot
.63806 .68016 Mdot
.30134 .50181 Mdot
.56329 .38042 Mdot
.42873 .72366 Mdot
.52 .42263 Mdot
.46838 .71015 Mdot
.6752 .60724 Mdot
.62187 .62369 Mdot
.34718 .59656 Mdot
.30211 .50278 Mdot
.52375 .31333 Mdot
.30833 .52577 Mdot
.74429 .49952 Mdot
.34684 .51639 Mdot
.3697 .50528 Mdot
.54426 .36852 Mdot
.47433 .38747 Mdot
.43218 .59467 Mdot
.57792 .46934 Mdot
.31681 .50258 Mdot
.48933 .31706 Mdot
.54515 .33303 Mdot
.4885 .38525 Mdot
.64044 .43201 Mdot
.33747 .54819 Mdot
.35912 .43927 Mdot
.44712 .57354 Mdot
.31388 .50066 Mdot
.20899 .33161 Mdot
.43593 .59036 Mdot
.44241 .59468 Mdot
.46878 .66901 Mdot
.50136 .38197 Mdot
.63298 .63815 Mdot
.4995 .33538 Mdot
.46208 .3057 Mdot
.52901 .34676 Mdot
.75473 .48464 Mdot
.53639 .39896 Mdot
.42037 .58053 Mdot
.63206 .64912 Mdot
.48268 .32571 Mdot
.51094 .38168 Mdot
.44054 .59158 Mdot
.34187 .54844 Mdot
.3085 .4882 Mdot
.44705 .59011 Mdot
.71482 .4693 Mdot
.44613 .68448 Mdot
.50677 .33412 Mdot
.64563 .65443 Mdot
.62781 .6429 Mdot
.31868 .53911 Mdot
.66044 .6291 Mdot
.45315 .67901 Mdot
.52243 .39433 Mdot
.46916 .68829 Mdot
.75479 .48517 Mdot
.31336 .5133 Mdot
.52543 .336 Mdot
.4868 .33731 Mdot
.32556 .4853 Mdot
.47668 .3947 Mdot
.75489 .49294 Mdot
.60046 .64187 Mdot
.34805 .52071 Mdot
.46013 .69978 Mdot
.63093 .67815 Mdot
.5074 .31805 Mdot
.16555 .42024 Mdot
.52825 .37818 Mdot
.5033 .40791 Mdot
.39351 .54406 Mdot
.54365 .32028 Mdot
.62211 .6589 Mdot
.30361 .51879 Mdot
.48019 .32231 Mdot
.62538 .30465 Mdot
.77677 .47114 Mdot
.66489 .61277 Mdot
.53865 .37272 Mdot
.19991 .42924 Mdot
.53885 .32345 Mdot
.33995 .59325 Mdot
.63725 .41175 Mdot
.51121 .75843 Mdot
.60699 .3687 Mdot
.43106 .71016 Mdot
.4309 .59959 Mdot
.61148 .63961 Mdot
.35789 .39714 Mdot
.51747 .3911 Mdot
.41321 .25687 Mdot
.52188 .33411 Mdot
.4816 .70922 Mdot
.39101 .40305 Mdot
.66954 .64043 Mdot
.64091 .21499 Mdot
.48758 .36656 Mdot
.35944 .48772 Mdot
.60342 .67203 Mdot
.43593 .60198 Mdot
.47429 .38216 Mdot
.71053 .48959 Mdot
.78417 .46196 Mdot
.56457 .37307 Mdot
.4662 .71077 Mdot
.49538 .35913 Mdot
.53235 .29525 Mdot
.70196 .74939 Mdot
.33704 .49528 Mdot
.45007 .70643 Mdot
.72057 .54294 Mdot
.4905 .38617 Mdot
.31296 .48357 Mdot
.34253 .51075 Mdot
.72847 .46078 Mdot
.51186 .71336 Mdot
.7497 .43223 Mdot
.17853 .58626 Mdot
.45713 .21648 Mdot
.60441 .63198 Mdot
.26994 .48567 Mdot
.4915 .34023 Mdot
.74624 .32259 Mdot
.45587 .69825 Mdot
.52659 .36374 Mdot
.41116 .27516 Mdot
.3437 .49864 Mdot
.5015 .37003 Mdot
.72502 .47911 Mdot
.35231 .77043 Mdot
.26506 .39166 Mdot
.18559 .45779 Mdot
.59757 .62213 Mdot
.48532 .42715 Mdot
.55746 .39191 Mdot
.41619 .56405 Mdot
.48987 .31218 Mdot
.63524 .66479 Mdot
.53194 .6375 Mdot
.74073 .46947 Mdot
.31364 .5275 Mdot
.43786 .59716 Mdot
.52209 .33375 Mdot
.50461 .43374 Mdot
.75971 .48954 Mdot
.47894 .38531 Mdot
.2988 .41581 Mdot
.43666 .61461 Mdot
.61985 .67329 Mdot
.35701 .48575 Mdot
.4682 .39567 Mdot
.42354 .59947 Mdot
.54433 .36293 Mdot
.47279 .25227 Mdot
.52158 .35042 Mdot
.33664 .58296 Mdot
.32227 .48398 Mdot
.4604 .70956 Mdot
.52599 .40845 Mdot
.51013 .3668 Mdot
.6417 .55219 Mdot
.44003 .37228 Mdot
.5144 .33988 Mdot
.30836 .53228 Mdot
.31657 .53036 Mdot
.3581 .50651 Mdot
.6437 .67918 Mdot
.52008 .49459 Mdot
.47246 .69764 Mdot
.44438 .33677 Mdot
.48581 .69313 Mdot
.60519 .38404 Mdot
.7591 .47712 Mdot
.33413 .59994 Mdot
.51538 .39682 Mdot
.34455 .48018 Mdot
.37082 .20126 Mdot
.33281 .54696 Mdot
.425 .7377 Mdot
.45579 .70279 Mdot
.32349 .50352 Mdot
.53628 .37401 Mdot
.56114 .47343 Mdot
.18139 .47383 Mdot
.48569 .72054 Mdot
.4581 .42277 Mdot
.62051 .60483 Mdot
.68656 .64949 Mdot
.22394 .31538 Mdot
.48719 .70289 Mdot
.41305 .79174 Mdot
.50478 .31598 Mdot
.3045 .51646 Mdot
.44599 .68785 Mdot
.45026 .73221 Mdot
.66236 .6291 Mdot
.48469 .33495 Mdot
.50795 .36727 Mdot
.42961 .57911 Mdot
.4577 .68591 Mdot
.55852 .29191 Mdot
.47795 .34234 Mdot
.41164 .62659 Mdot
.31736 .46542 Mdot
.79074 .67132 Mdot
.41835 .44562 Mdot
.41019 .27438 Mdot
.68498 .7266 Mdot
.34737 .52429 Mdot
.49374 .35261 Mdot
.44047 .36329 Mdot
.60089 .63246 Mdot
.52747 .38752 Mdot
.67159 .67136 Mdot
.47831 .69217 Mdot
.28081 .58279 Mdot
.49465 .56083 Mdot
.47068 .64196 Mdot
.52713 .37564 Mdot
.26124 .39953 Mdot
.74932 .4801 Mdot
.4227 .69153 Mdot
.35024 .5282 Mdot
.51251 .3021 Mdot
.61413 .61898 Mdot
.65124 .6775 Mdot
.3402 .50279 Mdot
.38897 .73232 Mdot
.33932 .5955 Mdot
.49209 .41407 Mdot
.6606 .66163 Mdot
.4438 .50949 Mdot
.22485 .39965 Mdot
.4525 .67223 Mdot
.74359 .47014 Mdot
.61369 .64664 Mdot
.49585 .72446 Mdot
.46002 .34507 Mdot
.33121 .50719 Mdot
.35992 .48275 Mdot
.55837 .58543 Mdot
.63516 .62994 Mdot
.7292 .48826 Mdot
.551 .58556 Mdot
.54003 .56073 Mdot
.73479 .47508 Mdot
.66572 .67776 Mdot
.33485 .53533 Mdot
.34805 .4896 Mdot
.34235 .5154 Mdot
.3332 .42441 Mdot
.29215 .49585 Mdot
.74414 .39113 Mdot
.49458 .30944 Mdot
.23562 .41223 Mdot
.5126 .30515 Mdot
.48794 .7269 Mdot
.31801 .49513 Mdot
.63415 .41137 Mdot
.54964 .32148 Mdot
.18684 .47346 Mdot
.51049 .35195 Mdot
.5218 .60912 Mdot
.50226 .38263 Mdot
.29725 .3779 Mdot
.29199 .51826 Mdot
.48887 .40429 Mdot
.42588 .72004 Mdot
.73758 .49809 Mdot
.34694 .45539 Mdot
.51034 .34145 Mdot
.34545 .70632 Mdot
.53456 .336 Mdot
.2907 .57827 Mdot
.57453 .58759 Mdot
.70065 .48687 Mdot
.55589 .3647 Mdot
.62939 .61491 Mdot
.44135 .3034 Mdot
.23955 .40581 Mdot
.48664 .71832 Mdot
.2555 .40487 Mdot
.67345 .64086 Mdot
.38945 .4024 Mdot
.54527 .3073 Mdot
.73642 .46833 Mdot
.30354 .55978 Mdot
.47867 .72238 Mdot
.51286 .39539 Mdot
.48914 .36545 Mdot
.49805 .64107 Mdot
.24503 .38682 Mdot
.53801 .27413 Mdot
.74853 .50714 Mdot
.26395 .38532 Mdot
.51999 .34224 Mdot
.65688 .60931 Mdot
.29741 .50448 Mdot
.39521 .40056 Mdot
.38075 .40656 Mdot
.47601 .33844 Mdot
.32788 .50212 Mdot
.30356 .49582 Mdot
.40753 .18117 Mdot
.75015 .46887 Mdot
.51929 .34969 Mdot
.5613 .59441 Mdot
.51193 .33415 Mdot
.47953 .70211 Mdot
.53887 .3088 Mdot
.62443 .62377 Mdot
.47179 .48295 Mdot
.64688 .67908 Mdot
.48796 .39253 Mdot
.32076 .51638 Mdot
.46959 .7276 Mdot
.50939 .78109 Mdot
.50737 .72652 Mdot
.74304 .3915 Mdot
.79007 .47095 Mdot
.71379 .49313 Mdot
.75768 .46622 Mdot
.45271 .66582 Mdot
.53641 .37982 Mdot
.60074 .46565 Mdot
.45447 .33908 Mdot
.49758 .38479 Mdot
.52452 .34963 Mdot
.46843 .77771 Mdot
.45631 .70439 Mdot
.62127 .63945 Mdot
.51117 .39184 Mdot
.49045 .3159 Mdot
.3201 .51093 Mdot
.71476 .48983 Mdot
.60662 .65696 Mdot
.7081 .4927 Mdot
.63586 .65241 Mdot
.30496 .23078 Mdot
.47636 .43655 Mdot
.74151 .49538 Mdot
.47364 .67819 Mdot
.35243 .48992 Mdot
.43505 .58025 Mdot
.66155 .6471 Mdot
.66748 .63776 Mdot
.46731 .38307 Mdot
.30888 .5104 Mdot
.30566 .49704 Mdot
.71105 .48163 Mdot
.44438 .7 Mdot
.46226 .38599 Mdot
.47148 .37304 Mdot
.52469 .77259 Mdot
.59914 .64213 Mdot
.25406 .39526 Mdot
.38541 .55734 Mdot
.53017 .39117 Mdot
.31531 .48251 Mdot
.51683 .37026 Mdot
.45063 .52471 Mdot
.35887 .51129 Mdot
.54048 .31429 Mdot
.47497 .30687 Mdot
.60508 .63321 Mdot
.47136 .17283 Mdot
.47156 .41568 Mdot
.46236 .75114 Mdot
.48415 .35095 Mdot
.59761 .16018 Mdot
.38621 .19599 Mdot
.54227 .34924 Mdot
.51926 .40773 Mdot
.17025 .55776 Mdot
.54493 .33725 Mdot
.4242 .57813 Mdot
.46081 .30654 Mdot
.32184 .47777 Mdot
.5411 .60198 Mdot
.59326 .46523 Mdot
.75 .46538 Mdot
.64822 .65386 Mdot
.67793 .37424 Mdot
.74288 .45584 Mdot
.34585 .49273 Mdot
.49076 .43693 Mdot
.38468 .55584 Mdot
.67618 .68094 Mdot
.57098 .31419 Mdot
.481 .70499 Mdot
.5923 .46733 Mdot
.64645 .61856 Mdot
.45968 .69871 Mdot
.53986 .32355 Mdot
.70932 .63535 Mdot
.42023 .70795 Mdot
.42216 .1706 Mdot
.44393 .71883 Mdot
.46 .7158 Mdot
.53892 .48268 Mdot
.7496 .46494 Mdot
.52831 .64743 Mdot
.45797 .44216 Mdot
.47794 .72898 Mdot
.64671 .24682 Mdot
.59708 .63585 Mdot
.52663 .50718 Mdot
.29719 .52618 Mdot
.46622 .43103 Mdot
.52828 .35841 Mdot
.44604 .71486 Mdot
.27159 .49502 Mdot
.6491 .54565 Mdot
.48265 .69732 Mdot
.56215 .35293 Mdot
.5087 .51158 Mdot
.4185 .59394 Mdot
.43608 .5884 Mdot
.76408 .48875 Mdot
.75361 .58858 Mdot
.32616 .48067 Mdot
.75104 .50188 Mdot
.62351 .39213 Mdot
.50493 .35285 Mdot
.46372 .68423 Mdot
.44016 .59503 Mdot
.46248 .70002 Mdot
.74268 .48303 Mdot
.76084 .48523 Mdot
.32944 .4958 Mdot
.34973 .52507 Mdot
.25872 .5358 Mdot
.60088 .25745 Mdot
.50593 .32756 Mdot
.38597 .26197 Mdot
.3531 .52726 Mdot
.36538 .40556 Mdot
.73256 .46267 Mdot
.71693 .47924 Mdot
.27996 .31516 Mdot
.50439 .32075 Mdot
.52076 .61704 Mdot
.52443 .34204 Mdot
.68973 .29426 Mdot
.52458 .33408 Mdot
.65725 .62672 Mdot
.48508 .36882 Mdot
.28317 .69723 Mdot
.48738 .3203 Mdot
.5279 .35016 Mdot
.65252 .64063 Mdot
.47102 .40426 Mdot
.63179 .62224 Mdot
.49619 .35112 Mdot
.75722 .51533 Mdot
.64583 .65397 Mdot
.73038 .52285 Mdot
.52167 .57474 Mdot
.4286 .58631 Mdot
.75351 .46438 Mdot
.71286 .49583 Mdot
.66685 .40744 Mdot
.33455 .53979 Mdot
.40864 .42873 Mdot
.53472 .36136 Mdot
.60258 .66392 Mdot
.45986 .67908 Mdot
.47465 .34171 Mdot
.55265 .36922 Mdot
.4663 .40059 Mdot
.32681 .49859 Mdot
.64948 .68331 Mdot
.74241 .48997 Mdot
.64039 .67229 Mdot
.74863 .51924 Mdot
.6174 .62401 Mdot
.45151 .39874 Mdot
.45872 .35496 Mdot
.55402 .39765 Mdot
.38941 .30274 Mdot
.7933 .35973 Mdot
.33572 .50534 Mdot
.42294 .59417 Mdot
.76002 .47836 Mdot
.54145 .54173 Mdot
.33312 .47748 Mdot
.6643 .6351 Mdot
.5054 .36412 Mdot
.48612 .44142 Mdot
.44752 .42455 Mdot
.38086 .53086 Mdot
.70689 .5134 Mdot
.65665 .64954 Mdot
.41402 .58051 Mdot
.51645 .49909 Mdot
.36492 .44823 Mdot
.63551 .38462 Mdot
.51337 .36841 Mdot
.71052 .48063 Mdot
.30916 .5185 Mdot
.51694 .63587 Mdot
.44811 .7153 Mdot
.57226 .47199 Mdot
.52851 .37428 Mdot
.41629 .75645 Mdot
.32221 .51723 Mdot
.72541 .47404 Mdot
.44645 .71602 Mdot
.74429 .46522 Mdot
.42987 .60544 Mdot
.42185 .55988 Mdot
.47477 .37882 Mdot
.52531 .34102 Mdot
.47024 .68299 Mdot
.32072 .48326 Mdot
.77056 .5012 Mdot
.50854 .64848 Mdot
.66351 .65047 Mdot
.51863 .52682 Mdot
.31217 .52499 Mdot
.44693 .78816 Mdot
.64852 .67474 Mdot
.49474 .70439 Mdot
.60165 .45879 Mdot
.44433 .68333 Mdot
.52162 .34475 Mdot
.32735 .526 Mdot
.48853 .71443 Mdot
.53741 .74948 Mdot
.21756 .47723 Mdot
.33984 .5716 Mdot
.49128 .39823 Mdot
.31753 .59819 Mdot
.37898 .75012 Mdot
.26979 .47518 Mdot
.48514 .69406 Mdot
.51917 .38007 Mdot
.4908 .41347 Mdot
.48698 .36766 Mdot
.45433 .71646 Mdot
.4761 .78805 Mdot
.67019 .65798 Mdot
.49839 .36722 Mdot
.72634 .50414 Mdot
.62136 .6275 Mdot
.67833 .63142 Mdot
.61386 .64861 Mdot
.34884 .533 Mdot
.48489 .43869 Mdot
.44335 .32916 Mdot
.44177 .18348 Mdot
.46024 .71322 Mdot
.42815 .58606 Mdot
.50006 .40932 Mdot
.73352 .39542 Mdot
.35145 .49134 Mdot
.65909 .64053 Mdot
.52538 .36424 Mdot
.56721 .58775 Mdot
.42872 .61184 Mdot
.6435 .64286 Mdot
.35437 .52148 Mdot
.2779 .46276 Mdot
.5255 .38991 Mdot
.48753 .34348 Mdot
.33616 .48528 Mdot
.3818 .7732 Mdot
.51124 .50165 Mdot
.51521 .37282 Mdot
.45851 .70563 Mdot
.59091 .85028 Mdot
.5321 .31296 Mdot
.33929 .55808 Mdot
.41131 .58354 Mdot
.3982 .55284 Mdot
.24695 .4305 Mdot
.45253 .32849 Mdot
.24962 .5697 Mdot
.74986 .41684 Mdot
.23277 .52875 Mdot
.70786 .31224 Mdot
.51202 .6571 Mdot
.35944 .18721 Mdot
.4634 .7452 Mdot
.29639 .35926 Mdot
.26749 .74094 Mdot
.40551 .78061 Mdot
.62954 .5637 Mdot
.54251 .70888 Mdot
.70162 .6253 Mdot
.64649 .20968 Mdot
.63871 .61448 Mdot
.71377 .30088 Mdot
.53088 .34171 Mdot
.37345 .76279 Mdot
.28848 .38045 Mdot
.81008 .40712 Mdot
.3554 .60115 Mdot
.56199 .58902 Mdot
.1675 .4543 Mdot
.38078 .6116 Mdot
.23084 .33618 Mdot
.42495 .29166 Mdot
.77876 .60679 Mdot
.54132 .54907 Mdot
.69235 .38073 Mdot
.26266 .41031 Mdot
.26079 .6575 Mdot
.43869 .64615 Mdot
.36089 .24243 Mdot
.72058 .7192 Mdot
.64922 .66494 Mdot
.29679 .50059 Mdot
.54691 .66511 Mdot
.21599 .37941 Mdot
.43761 .74784 Mdot
.2487 .5688 Mdot
.39953 .59143 Mdot
.29621 .37354 Mdot
.62403 .41152 Mdot
.3066 .32422 Mdot
.74427 .42905 Mdot
.65167 .22141 Mdot
.37897 .50933 Mdot
.55796 .72366 Mdot
.54806 .53571 Mdot
.6683 .44849 Mdot
.30827 .39722 Mdot
.76105 .50121 Mdot
.766 .49882 Mdot
.35695 .51537 Mdot
.22304 .38715 Mdot
.4362 .61727 Mdot
.6224 .38687 Mdot
.62434 .61411 Mdot
.45835 .52967 Mdot
.34525 .76076 Mdot
.37698 .73829 Mdot
.51442 .17633 Mdot
.17414 .40607 Mdot
.64955 .28503 Mdot
.51069 .62593 Mdot
.4528 .76419 Mdot
.7125 .40036 Mdot
.52307 .2619 Mdot
.63263 .25881 Mdot
.46593 .25594 Mdot
.16775 .5049 Mdot
.36502 .694 Mdot
.15951 .44516 Mdot
.37491 .49447 Mdot
.53046 .43189 Mdot
.48066 .59149 Mdot
.45813 .22399 Mdot
.64525 .34985 Mdot
.17713 .42553 Mdot
.70717 .46802 Mdot
.28402 .49062 Mdot
.40767 .78091 Mdot
.29405 .41701 Mdot
.68545 .44551 Mdot
.79882 .49284 Mdot
.39891 .40817 Mdot
.15153 .48384 Mdot
.25274 .57613 Mdot
.33864 .22623 Mdot
.41458 .63535 Mdot
.65719 .69423 Mdot
.6748 .62692 Mdot
.44618 .73066 Mdot
.20991 .36513 Mdot
.33141 .52177 Mdot
.46162 .16972 Mdot
.24659 .52804 Mdot
.44928 .29097 Mdot
.14756 .49538 Mdot
.60382 .206 Mdot
.23719 .42362 Mdot
.77187 .37185 Mdot
.54739 .83766 Mdot
.55899 .27185 Mdot
.5085 .72977 Mdot
.6405 .60435 Mdot
.31329 .58121 Mdot
.20554 .37517 Mdot
.63229 .24054 Mdot
.19575 .63839 Mdot
.62128 .38279 Mdot
.70713 .68 Mdot
.38505 .51438 Mdot
.65765 .56454 Mdot
.66318 .47159 Mdot
.16057 .44034 Mdot
.27307 .38128 Mdot
.58186 .84593 Mdot
.69593 .31876 Mdot
.37565 .41006 Mdot
.30434 .60731 Mdot
.60399 .59732 Mdot
.53131 .24535 Mdot
.35693 .70915 Mdot
.49199 .42877 Mdot
.64543 .37879 Mdot
.40488 .35026 Mdot
.71702 .44271 Mdot
.51154 .49542 Mdot
.36485 .67158 Mdot
.6665 .32124 Mdot
.44842 .80329 Mdot
.40001 .4267 Mdot
.36207 .52033 Mdot
.63507 .26646 Mdot
.67513 .2984 Mdot
.40476 .66195 Mdot
.72124 .54222 Mdot
.32942 .23006 Mdot
.68417 .54558 Mdot
.45698 .3185 Mdot
.29673 .35289 Mdot
.26523 .41105 Mdot
.6626 .26024 Mdot
.45391 .40809 Mdot
.48419 .18232 Mdot
.41296 .61494 Mdot
.37259 .31349 Mdot
.64904 .32884 Mdot
.38404 .3069 Mdot
.21207 .4358 Mdot
.47075 .58013 Mdot
.49993 .75721 Mdot
.27093 .51585 Mdot
.15325 .48343 Mdot
.61955 .6339 Mdot
.62923 .24746 Mdot
.45739 .74508 Mdot
.52817 .76203 Mdot
.5277 .66619 Mdot
.65538 .54479 Mdot
.22297 .33306 Mdot
.39495 .74935 Mdot
.58338 .61742 Mdot
.24192 .63982 Mdot
.43749 .50301 Mdot
.38053 .2688 Mdot
.56159 .40999 Mdot
.46639 .26179 Mdot
.75534 .49251 Mdot
.37948 .35584 Mdot
.45109 .57082 Mdot
.81311 .48535 Mdot
.44887 .34606 Mdot
.55135 .55765 Mdot
.41621 .57184 Mdot
.57716 .48165 Mdot
.3028 .23106 Mdot
.56268 .41086 Mdot
.60173 .2087 Mdot
.39385 .75751 Mdot
.59504 .47363 Mdot
.66616 .46407 Mdot
.4096 .45566 Mdot
.15615 .45122 Mdot
.25201 .28096 Mdot
.34558 .733 Mdot
.3033 .59564 Mdot
.74862 .25155 Mdot
.5116 .75393 Mdot
.51794 .1915 Mdot
.45061 .74276 Mdot
.87586 .63184 Mdot
.64179 .6741 Mdot
.75101 .32045 Mdot
.4496 .23293 Mdot
.59642 .56008 Mdot
.21572 .38588 Mdot
.27381 .41869 Mdot
.73011 .53117 Mdot
.36709 .52156 Mdot
.44532 .38204 Mdot
.18533 .42137 Mdot
.15769 .48126 Mdot
.18376 .42691 Mdot
.41186 .73578 Mdot
.1997 .46077 Mdot
.16096 .53929 Mdot
.74652 .3912 Mdot
.48282 .62968 Mdot
.54181 .30388 Mdot
.58856 .23948 Mdot
.57778 .20503 Mdot
.70069 .46794 Mdot
.56336 .27646 Mdot
.3796 .50859 Mdot
.15368 .52875 Mdot
.30577 .22703 Mdot
.31436 .29904 Mdot
.24015 .32337 Mdot
.56201 .66284 Mdot
.60601 .25071 Mdot
.23767 .31264 Mdot
.2553 .63156 Mdot
.40251 .61475 Mdot
.16168 .56088 Mdot
.67788 .30838 Mdot
.54198 .71344 Mdot
.32123 .70961 Mdot
.55427 .19709 Mdot
.2946 .60288 Mdot
.54936 .67087 Mdot
.50532 .25279 Mdot
.38165 .47338 Mdot
.65841 .54608 Mdot
.25394 .6495 Mdot
.51509 .61942 Mdot
.63831 .30962 Mdot
.6807 .64398 Mdot
.62066 .24168 Mdot
.64746 .48145 Mdot
.48594 .63154 Mdot
.67247 .38553 Mdot
.63985 .23719 Mdot
.32972 .68699 Mdot
.19157 .44493 Mdot
.39514 .75739 Mdot
.53852 .84417 Mdot
.34999 .62589 Mdot
.40935 .34073 Mdot
.4709 .40468 Mdot
.21094 .38494 Mdot
.23289 .27969 Mdot
.2266 .32333 Mdot
.40166 .72008 Mdot
.57528 .65816 Mdot
.49856 .71053 Mdot
.70012 .39872 Mdot
.61154 .55166 Mdot
.37928 .58264 Mdot
.6138 .49256 Mdot
.46857 .74255 Mdot
.35697 .77449 Mdot
.26711 .54489 Mdot
.73089 .39763 Mdot
.34663 .25655 Mdot
.55642 .28514 Mdot
.22685 .39736 Mdot
.36565 .49518 Mdot
.40416 .73949 Mdot
.63116 .25568 Mdot
.61624 .63733 Mdot
.53356 .76466 Mdot
.27473 .51441 Mdot
.52415 .43668 Mdot
.56506 .66968 Mdot
.3529 .57111 Mdot
.40824 .27378 Mdot
.58144 .63657 Mdot
.33122 .2077 Mdot
.50348 .18309 Mdot
.23915 .30951 Mdot
.64558 .27357 Mdot
.54687 .74556 Mdot
.55371 .4909 Mdot
.47803 .7615 Mdot
.36717 .60499 Mdot
.54314 .52206 Mdot
.64726 .26727 Mdot
.23096 .42462 Mdot
.45778 .61363 Mdot
.44889 .32953 Mdot
.3623 .20477 Mdot
.71857 .38234 Mdot
.55799 .49625 Mdot
.40065 .47414 Mdot
.29808 .48365 Mdot
.79714 .35187 Mdot
.2746 .67587 Mdot
.44087 .31818 Mdot
.3087 .6014 Mdot
.44774 .67193 Mdot
.3613 .50727 Mdot
.63861 .23276 Mdot
.74032 .55716 Mdot
.24407 .51176 Mdot
.49233 .58797 Mdot
.21921 .36435 Mdot
.51237 .56488 Mdot
.29011 .59154 Mdot
.21517 .53983 Mdot
.61156 .83069 Mdot
.37385 .49375 Mdot
.50192 .62569 Mdot
.53787 .64836 Mdot
.37727 .48427 Mdot
.37683 .53729 Mdot
.26844 .38966 Mdot
.19356 .37782 Mdot
.5435 .58456 Mdot
.24434 .62434 Mdot
.59906 .46798 Mdot
.65392 .55971 Mdot
.47488 .61563 Mdot
.67443 .37794 Mdot
.23689 .5857 Mdot
.28889 .28383 Mdot
.43762 .83648 Mdot
.57676 .29473 Mdot
.74305 .31047 Mdot
.70112 .39971 Mdot
.42543 .29343 Mdot
.30802 .39319 Mdot
.39731 .62296 Mdot
.49969 .33845 Mdot
.17781 .38934 Mdot
.36919 .68607 Mdot
.65387 .42453 Mdot
.64086 .59005 Mdot
.52868 .31658 Mdot
.55299 .39699 Mdot
.23305 .31984 Mdot
.39803 .53134 Mdot
.35246 .81554 Mdot
.69743 .30995 Mdot
.42978 .30691 Mdot
.23534 .43208 Mdot
.59792 .20924 Mdot
.47082 .56812 Mdot
.24746 .5392 Mdot
.64862 .49011 Mdot
.5765 .20036 Mdot
.22408 .59937 Mdot
.26209 .6737 Mdot
.34336 .61902 Mdot
.16286 .53078 Mdot
.41544 .35409 Mdot
.42842 .63608 Mdot
.56082 .67546 Mdot
.50877 .40853 Mdot
.38811 .73091 Mdot
.33691 .60756 Mdot
.70162 .5888 Mdot
.52153 .2591 Mdot
.22743 .28425 Mdot
.50498 .28539 Mdot
.39307 .70581 Mdot
.33121 .79406 Mdot
.41151 .85379 Mdot
.27588 .69126 Mdot
.16126 .4363 Mdot
.25038 .65935 Mdot
.28607 .59442 Mdot
.45589 .66764 Mdot
.53092 .5507 Mdot
.40376 .25699 Mdot
.19565 .36258 Mdot
.76855 .57349 Mdot
.51504 .70311 Mdot
.39295 .2305 Mdot
.19292 .36396 Mdot
.4821 .29581 Mdot
.77631 .32967 Mdot
.6397 .69371 Mdot
.62995 .19565 Mdot
.52784 .18008 Mdot
.39241 .46491 Mdot
.65514 .24695 Mdot
.75079 .30251 Mdot
.79456 .40592 Mdot
.51268 .1875 Mdot
.51668 .23129 Mdot
.40312 .49892 Mdot
.63938 .27713 Mdot
.32257 .58765 Mdot
.69188 .22281 Mdot
.47802 .6122 Mdot
.42514 .61516 Mdot
.41787 .55666 Mdot
.31165 .5799 Mdot
.32831 .67066 Mdot
.49718 .60847 Mdot
.46654 .48968 Mdot
.21856 .42338 Mdot
.61726 .85026 Mdot
.23507 .65717 Mdot
.27464 .53895 Mdot
.16301 .47666 Mdot
.40618 .63111 Mdot
.55515 .52386 Mdot
.31397 .40444 Mdot
.70931 .38908 Mdot
.57823 .62772 Mdot
.52909 .34625 Mdot
.1911 .38179 Mdot
.58006 .62567 Mdot
.17378 .45436 Mdot
.43025 .1676 Mdot
.25138 .31782 Mdot
.57833 .37771 Mdot
.64895 .60401 Mdot
.59722 .22291 Mdot
.5989 .22715 Mdot
.17722 .50266 Mdot
.72847 .29477 Mdot
.53119 .52308 Mdot
.51187 .58825 Mdot
.49395 .56639 Mdot
.42745 .34585 Mdot
.59107 .20387 Mdot
.41419 .46782 Mdot
.656 .33953 Mdot
.32962 .72433 Mdot
.64263 .25091 Mdot
.24803 .42244 Mdot
.6907 .3932 Mdot
.67694 .53647 Mdot
.73682 .52893 Mdot
.59847 .64566 Mdot
.17912 .60584 Mdot
.38053 .63329 Mdot
.474 .18208 Mdot
.54289 .84195 Mdot
.36036 .70957 Mdot
.71153 .29394 Mdot
.4505 .61164 Mdot
.5642 .26882 Mdot
.77459 .59611 Mdot
.67351 .33527 Mdot
.25797 .39666 Mdot
.33267 .59259 Mdot
.37813 .43956 Mdot
.21175 .34675 Mdot
.64127 .31727 Mdot
.22573 .70032 Mdot
.62306 .70565 Mdot
.3802 .34866 Mdot
.24096 .3745 Mdot
.50999 .8433 Mdot
.56418 .49329 Mdot
.15299 .48605 Mdot
.3277 .54856 Mdot
.17341 .40997 Mdot
.43964 .71166 Mdot
.72256 .64104 Mdot
.39348 .60028 Mdot
.65285 .4343 Mdot
.64462 .44234 Mdot
.39153 .18719 Mdot
.40113 .76943 Mdot
.37703 .74236 Mdot
.6852 .54751 Mdot
.65933 .62049 Mdot
.50026 .52916 Mdot
.24789 .62056 Mdot
.18431 .61277 Mdot
.4626 .36907 Mdot
.67889 .70663 Mdot
.61857 .22416 Mdot
.47823 .76249 Mdot
.40464 .59631 Mdot
.37285 .59421 Mdot
.25087 .47587 Mdot
.60323 .25129 Mdot
.15964 .52489 Mdot
.38545 .57712 Mdot
.61906 .53713 Mdot
.38485 .39409 Mdot
.45145 .63042 Mdot
.4649 .80739 Mdot
.2463 .58059 Mdot
.50247 .57431 Mdot
.51581 .50261 Mdot
.65268 .28641 Mdot
.28133 .22524 Mdot
.16345 .49405 Mdot
.49838 .82354 Mdot
.59594 .47607 Mdot
.32663 .55355 Mdot
.68276 .36072 Mdot
.22011 .69415 Mdot
.63362 .19341 Mdot
.33072 .70905 Mdot
.63906 .24817 Mdot
.67747 .58146 Mdot
.76001 .32049 Mdot
.55088 .51094 Mdot
.24218 .37224 Mdot
.43735 .22778 Mdot
.42944 .56283 Mdot
.59057 .60354 Mdot
.61798 .45417 Mdot
.49681 .64538 Mdot
.40371 .49509 Mdot
.40302 .77009 Mdot
.22679 .70156 Mdot
.72042 .28244 Mdot
.38954 .40705 Mdot
.24242 .71147 Mdot
.32345 .46109 Mdot
.53989 .65112 Mdot
.49101 .80605 Mdot
.60495 .47024 Mdot
.62559 .66758 Mdot
.51614 .26626 Mdot
.50618 .5151 Mdot
.23585 .63818 Mdot
.69381 .60845 Mdot
.73814 .45284 Mdot
.36831 .54197 Mdot
.74036 .29646 Mdot
.35356 .47038 Mdot
.30914 .20988 Mdot
.25706 .62972 Mdot
.23066 .41352 Mdot
.21488 .60237 Mdot
.57113 .71487 Mdot
.54529 .84692 Mdot
.2327 .33359 Mdot
.62492 .30504 Mdot
.3717 .53391 Mdot
.36528 .48383 Mdot
.22366 .58938 Mdot
.42839 .75888 Mdot
.22512 .36202 Mdot
.60893 .21008 Mdot
.54987 .74683 Mdot
.31657 .47495 Mdot
.51668 .59473 Mdot
.27386 .53381 Mdot
.31603 .21611 Mdot
.63489 .66996 Mdot
.15012 .47312 Mdot
.41094 .44381 Mdot
.4382 .81829 Mdot
.35279 .58048 Mdot
.47747 .48131 Mdot
.56792 .49688 Mdot
.54339 .73681 Mdot
.45443 .31879 Mdot
.42964 .3088 Mdot
.3466 .53086 Mdot
.52392 .66561 Mdot
.7163 .48959 Mdot
.78075 .5217 Mdot
.47054 .75552 Mdot
.41558 .29717 Mdot
.5762 .19301 Mdot
.3649 .48981 Mdot
.60459 .69801 Mdot
.61361 .71143 Mdot
.47342 .31002 Mdot
.56141 .22674 Mdot
.17324 .57722 Mdot
.23228 .33938 Mdot
.3327 .54837 Mdot
.49978 .83154 Mdot
.76525 .44308 Mdot
.34218 .20381 Mdot
.26682 .46768 Mdot
.61001 .22268 Mdot
.40208 .34325 Mdot
.25584 .28488 Mdot
.24728 .43015 Mdot
.27319 .56373 Mdot
.63694 .26434 Mdot
.64798 .54799 Mdot
.63599 .23653 Mdot
.25017 .47514 Mdot
.50037 .55441 Mdot
.63119 .1994 Mdot
.67567 .58428 Mdot
.30433 .33008 Mdot
.47647 .27937 Mdot
.34919 .57908 Mdot
.58967 .2097 Mdot
.36296 .5481 Mdot
.77228 .47825 Mdot
.36729 .24716 Mdot
.39701 .60844 Mdot
.20864 .37127 Mdot
.4036 .66444 Mdot
.62101 .22115 Mdot
.49139 .56084 Mdot
.72131 .36085 Mdot
.41231 .44545 Mdot
.63144 .35889 Mdot
.54582 .39683 Mdot
.40215 .364 Mdot
.62503 .49481 Mdot
.40066 .19151 Mdot
.42814 .32616 Mdot
.19506 .40201 Mdot
.32462 .21928 Mdot
.2248 .52216 Mdot
.52897 .63201 Mdot
.30591 .48634 Mdot
.1566 .46396 Mdot
.56966 .22245 Mdot
.33898 .58694 Mdot
.53383 .18161 Mdot
.79551 .34686 Mdot
.25649 .73045 Mdot
.383 .66261 Mdot
.35867 .57062 Mdot
.46942 .17308 Mdot
.3695 .6928 Mdot
.76364 .31357 Mdot
.26113 .39299 Mdot
.39231 .5455 Mdot
.14656 .50159 Mdot
.47396 .22166 Mdot
.37098 .73547 Mdot
.23965 .38636 Mdot
.24599 .49475 Mdot
.55894 .21797 Mdot
.4458 .32812 Mdot
.62584 .61736 Mdot
.58154 .57138 Mdot
.66018 .25246 Mdot
.25703 .48553 Mdot
.60462 .21414 Mdot
.61099 .22677 Mdot
.72203 .30757 Mdot
.54745 .73782 Mdot
.25742 .73095 Mdot
.23266 .4494 Mdot
.52778 .42477 Mdot
.35889 .55264 Mdot
.75336 .45981 Mdot
.69948 .32563 Mdot
.48465 .32551 Mdot
.60624 .4409 Mdot
.39953 .38949 Mdot
.18534 .37754 Mdot
.67551 .55595 Mdot
.44462 .6437 Mdot
.30483 .48467 Mdot
.3209 .58244 Mdot
.45472 .54784 Mdot
.40525 .78172 Mdot
.59627 .21638 Mdot
.24263 .51338 Mdot
.25469 .568 Mdot
.36658 .7273 Mdot
.65341 .30383 Mdot
.76107 .43187 Mdot
.49048 .71579 Mdot
.40945 .26572 Mdot
.18557 .52193 Mdot
.37631 .71638 Mdot
.28581 .49132 Mdot
.30881 .68913 Mdot
.50409 .55558 Mdot
.41779 .66277 Mdot
.39845 .76565 Mdot
.46005 .59159 Mdot
.27003 .31126 Mdot
.22474 .55521 Mdot
.61551 .60646 Mdot
.68408 .30214 Mdot
.27913 .67092 Mdot
.5999 .21386 Mdot
.47963 .30359 Mdot
.20254 .40138 Mdot
.6513 .4287 Mdot
.74642 .43973 Mdot
.47921 .35467 Mdot
.47089 .24213 Mdot
.23247 .31975 Mdot
.31118 .70612 Mdot
.51882 .24991 Mdot
.28278 .50815 Mdot
.50412 .18078 Mdot
.5756 .63894 Mdot
.57797 .64157 Mdot
.76916 .35481 Mdot
.45758 .46828 Mdot
.60768 .55084 Mdot
.4851 .77793 Mdot
.46604 .30742 Mdot
.77538 .43722 Mdot
.49745 .58541 Mdot
.40448 .2696 Mdot
.5169 .19424 Mdot
.1775 .59279 Mdot
.48517 .58027 Mdot
.51568 .17479 Mdot
.42676 .23364 Mdot
.39212 .53645 Mdot
.72851 .2861 Mdot
.56055 .27635 Mdot
.45108 .40356 Mdot
.77214 .47762 Mdot
.30017 .47304 Mdot
.17756 .57433 Mdot
.48336 .2589 Mdot
.68755 .45999 Mdot
.67163 .50921 Mdot
.48592 .59768 Mdot
.69659 .72284 Mdot
.41483 .61641 Mdot
.47164 .172 Mdot
.63178 .25629 Mdot
.50509 .7235 Mdot
.23951 .63871 Mdot
.54114 .25889 Mdot
.19876 .40386 Mdot
.63176 .50917 Mdot
.22261 .34742 Mdot
.40993 .71566 Mdot
.40341 .28984 Mdot
.34473 .21218 Mdot
.64742 .36725 Mdot
.63079 .36632 Mdot
.40241 .45841 Mdot
.60154 .31116 Mdot
.43641 .58189 Mdot
.72052 .55189 Mdot
.68126 .22415 Mdot
.20125 .65595 Mdot
.42478 .80672 Mdot
.49489 .28032 Mdot
.67949 .35506 Mdot
.22455 .56699 Mdot
.55126 .52881 Mdot
.66106 .48721 Mdot
.56985 .68496 Mdot
.58436 .61117 Mdot
.59691 .8487 Mdot
.18111 .38574 Mdot
.4808 .35098 Mdot
.64173 .46184 Mdot
.8034 .49016 Mdot
.66801 .67403 Mdot
.33492 .26107 Mdot
.17359 .56792 Mdot
.48485 .72469 Mdot
.53421 .81519 Mdot
.49461 .76791 Mdot
.39681 .18721 Mdot
.50912 .80351 Mdot
.42221 .68725 Mdot
.3078 .21013 Mdot
.34486 .72817 Mdot
.3607 .44334 Mdot
.60494 .84659 Mdot
.37691 .19836 Mdot
.40523 .34236 Mdot
.57171 .64519 Mdot
.18681 .39733 Mdot
.56491 .49793 Mdot
.5658 .64273 Mdot
.48365 .21364 Mdot
.63678 .25915 Mdot
.69275 .30784 Mdot
.48514 .66255 Mdot
.41388 .22827 Mdot
.83508 .40953 Mdot
.57445 .71564 Mdot
.49511 .8602 Mdot
.23857 .3343 Mdot
.19961 .50988 Mdot
.27233 .68508 Mdot
.7044 .5842 Mdot
.20865 .39398 Mdot
.6113 .23414 Mdot
.47172 .23478 Mdot
.75025 .57087 Mdot
.65283 .37982 Mdot
.69992 .37797 Mdot
.41937 .66284 Mdot
.24906 .30566 Mdot
.5528 .73066 Mdot
.55682 .25274 Mdot
.6279 .23924 Mdot
.43672 .2363 Mdot
.62913 .36046 Mdot
.18762 .50974 Mdot
.55551 .2211 Mdot
.65481 .27591 Mdot
.54671 .69366 Mdot
.76405 .50298 Mdot
.17943 .55863 Mdot
.43402 .51629 Mdot
.39976 .3569 Mdot
.33583 .79869 Mdot
.16126 .44236 Mdot
.56188 .2768 Mdot
.54062 .31049 Mdot
.36416 .18397 Mdot
.62631 .70228 Mdot
.5116 .1942 Mdot
.33523 .74834 Mdot
.7003 .30587 Mdot
.41549 .36758 Mdot
.52759 .33318 Mdot
.7508 .37344 Mdot
.38934 .50354 Mdot
.43966 .23059 Mdot
.51752 .78849 Mdot
.6495 .27224 Mdot
.41723 .30032 Mdot
.43644 .83577 Mdot
.26188 .46577 Mdot
.33737 .47193 Mdot
.18604 .39076 Mdot
.35484 .23187 Mdot
.4195 .31789 Mdot
.23195 .37923 Mdot
.62638 .5201 Mdot
.77653 .43897 Mdot
.41091 .42961 Mdot
.55672 .49013 Mdot
.66085 .25001 Mdot
.2419 .71311 Mdot
.39633 .26375 Mdot
.14843 .48203 Mdot
.24565 .28959 Mdot
.33003 .47084 Mdot
.46205 .22798 Mdot
.60401 .47628 Mdot
.23063 .53363 Mdot
.53499 .73806 Mdot
.53408 .75877 Mdot
.82279 .40656 Mdot
.79239 .51099 Mdot
.54107 .34932 Mdot
.41061 .73462 Mdot
.21349 .34682 Mdot
.81791 .39054 Mdot
.20816 .3574 Mdot
.40432 .36558 Mdot
.47329 .40754 Mdot
.41848 .8585 Mdot
.28603 .59205 Mdot
.45751 .39102 Mdot
.42798 .36934 Mdot
.43076 .3447 Mdot
.51285 .33828 Mdot
.43137 .76463 Mdot
.71143 .39474 Mdot
.69219 .2928 Mdot
.19379 .39132 Mdot
.31216 .47281 Mdot
.57217 .49286 Mdot
.4424 .73471 Mdot
.62581 .43665 Mdot
.59933 .39759 Mdot
.43631 .68469 Mdot
.69181 .28277 Mdot
.68019 .72512 Mdot
.67838 .44684 Mdot
.35449 .57513 Mdot
.45478 .47503 Mdot
.25331 .53072 Mdot
.70772 .28116 Mdot
.46982 .7809 Mdot
.79527 .40866 Mdot
.62448 .22637 Mdot
.38968 .43617 Mdot
.4215 .63895 Mdot
.75471 .26249 Mdot
.55735 .49958 Mdot
.41761 .75076 Mdot
.58388 .3146 Mdot
.33252 .44094 Mdot
.24759 .3368 Mdot
.78478 .46107 Mdot
.41668 .56764 Mdot
.38897 .39214 Mdot
.21514 .38543 Mdot
.45883 .67426 Mdot
.26089 .24526 Mdot
.59052 .34467 Mdot
.33029 .2708 Mdot
.21182 .47114 Mdot
.50475 .6305 Mdot
.25851 .4003 Mdot
.54432 .40045 Mdot
.60388 .53507 Mdot
.67909 .72259 Mdot
.30588 .55819 Mdot
.47371 .61758 Mdot
.23178 .55109 Mdot
.737 .30777 Mdot
.29293 .28734 Mdot
.51803 .35092 Mdot
.71486 .46418 Mdot
.57022 .48006 Mdot
.70383 .57649 Mdot
.70623 .68061 Mdot
.40547 .61541 Mdot
.70583 .28283 Mdot
.69733 .31081 Mdot
.24671 .38663 Mdot
.17334 .43969 Mdot
.47336 .2801 Mdot
.24611 .32757 Mdot
.66322 .52925 Mdot
.33654 .67119 Mdot
.56428 .22813 Mdot
.23759 .70563 Mdot
.41717 .34189 Mdot
.45551 .30319 Mdot
.2643 .25746 Mdot
.235 .32608 Mdot
.48822 .65147 Mdot
.31892 .59152 Mdot
.66516 .21798 Mdot
.64532 .44316 Mdot
.60761 .84976 Mdot
.531 .74853 Mdot
.28959 .22879 Mdot
.46884 .62561 Mdot
.58231 .31868 Mdot
.40807 .45655 Mdot
.4457 .37585 Mdot
.63581 .63987 Mdot
.21998 .52432 Mdot
.40132 .46085 Mdot
.61022 .33825 Mdot
.53637 .41699 Mdot
.55572 .63365 Mdot
.34802 .55958 Mdot
.20482 .66435 Mdot
.68721 .65864 Mdot
.61992 .53404 Mdot
.39805 .81037 Mdot
.68049 .72311 Mdot
.78498 .33085 Mdot
.17495 .49709 Mdot
.36792 .60359 Mdot
.49915 .58227 Mdot
.69445 .7578 Mdot
.33532 .55321 Mdot
.37668 .546 Mdot
.478 .75765 Mdot
.72841 .36621 Mdot
.39156 .71555 Mdot
.28772 .75787 Mdot
.2578 .2804 Mdot
.47823 .30526 Mdot
.61049 .86739 Mdot
.6245 .23235 Mdot
.60677 .50534 Mdot
.39325 .72282 Mdot
.19561 .37731 Mdot
.63861 .58936 Mdot
.42349 .17065 Mdot
.26163 .65497 Mdot
.26124 .4758 Mdot
.72111 .37748 Mdot
.5023 .83018 Mdot
.51397 .60084 Mdot
.49768 .86013 Mdot
.3161 .60853 Mdot
.6915 .38015 Mdot
.30457 .70231 Mdot
.37505 .51098 Mdot
.43123 .30844 Mdot
.26014 .62455 Mdot
.54233 .26937 Mdot
.27486 .476 Mdot
.25244 .57411 Mdot
.7315 .425 Mdot
.53033 .70152 Mdot
.28619 .58697 Mdot
.4621 .76362 Mdot
.39086 .45655 Mdot
.66063 .22749 Mdot
.67251 .70581 Mdot
.68108 .64913 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0;kooooo0_l00029ooooo`00
7?ooool00ol0003oooooooooo`2nooooo`;o0000ROooool001cooooo00?o0000ooooooooool0R?oo
ool2o`000;oooooo000Looooo`03o`000?oooooooooo08Gooooo1Ol00008ooooo`;o000000?ooooo
o`000?l00000:_ooool4o`0008Cooooo000Looooo`03o`000?oooooooooo07Sooooo1?l000000ooo
oooo0000o`000006ooooo`?o00002_ooool2o`000003ooooool0003o000000gooooo0_l0000Koooo
o`Co0000Q?ooool001cooooo00?o0000ooooooooool0N?ooool4o`000003ooooool0003o000001Ko
oooo0_l0000<ooooo`?o0000Xoooool001cooooo00?o0000ooooooooool0POooool2o`0001gooooo
0_l000000ooooooo0000o`000003ooooo`?o0000W_ooool001cooooo00?o0000ooooooooool0Looo
ool2o`0000cooooo0_l00009ooooo`?o00000oooool2o`0000;ooooo0_l00002ooooo`;o00001?oo
ool2o`0000Kooooo1?l0002Mooooo`007?ooool00ol0003oooooooooo`1aooooo`Co00001_ooool4
o`0000cooooo1?l00003ooooo`;o00000_ooool2o`0000;ooooo0_l00004ooooo`;o000000?ooooo
o`000?l000001Oooool2o`0000[ooooo0_l0000?ooooo`?o0000Ooooool001cooooo00?o0000oooo
ooooool0LOooool2o`0000Sooooo1?l0000<ooooo`;o00002Oooool2o`0000Gooooo0_l000001?oo
oooo0000o`000?ooool2o`00017ooooo0_l0000?ooooo`?o0000Ooooool00006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo07kooooo0ol0
000Looooo`Wo00004Oooool2o`00013ooooo0ol0001mooooo`0000KoooooogMgMonHV9SooooooiRH
V?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000oooooooo
ool0N_ooool2o`0000;ooooo0ol0000Looooo`Co000000?oooooo`000?l000000_l0000Aooooo`;o
00004?ooool3o`0007gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo
00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`1gooooo`;o000000?oooooo`000?l00000
8Oooool2o`0000?ooooo1?l0000:ooooo`;o00005oooool2o`0007kooooo00000ooooooo0000oooo
o`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0007Gooooo1?l0
000gooooo`;o00001Oooool2o`00013ooooo0_l000000ooooooo0000o`00001kooooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000
ooooooooool0Joooool2o`0000Cooooo0ol000000ooooooo0000o`000010ooooo`?o00000_ooool2
o`0000;ooooo0_l0000:ooooo`;o0000Noooool00003ooooool@413ooooo00;ooooo00?o410@oooo
ooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo067ooooo0_l00003oooo
o`Co000000?oooooo`000?l000000_ooool5o`00033ooooo0_l0000Booooo`;o00000_ooool6o`00
00;ooooo0_l00023ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`1Pooooo`?o00000oooool4o`0000;ooooo0_l0
00000ooooooo0000o`000003o`0001gooooo0_l0000Aooooo`;o00005_ooool:o`0000Kooooo1?l0
001iooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`01_ooool00ol0003oooooooooo`1Pooooo`?o00002Oooool2o`0001Cooooo0_l00002ooooo`;o
00001Oooool2o`0000;ooooo0_l00006ooooo`;o00008Oooool2o`000003ooooool0003o000000Go
00001_ooool4o`000003ooooool0003o000007Kooooo000Looooo`03o`000?oooooooooo06?ooooo
0_l0000Mooooo`;o00000_ooool2o`0000Gooooo0_l000001?oooooo0000o`000?l00006ooooo`;o
00005oooool2o`0000[ooooo1Ol00009ooooo`;o00000oooool6o`0007;ooooo000Looooo`03o`00
0?oooooooooo06?ooooo0_l000000ooooooo0000o`00000Looooo`;o00002Oooool4o`0000Kooooo
0_l0000Dooooo`Go00001oooool2o`000003ooooool0003o000000Kooooo0ol00007ooooo`Oo0000
00?oooooo`000?l00000Koooool001cooooo00?o0000ooooooooool0I_ooool2o`0001[ooooo1Ol0
0003ooooo`;o00000oooool4o`0000?ooooo0_l0000Gooooo`Co00000_ooool4o`0000;ooooo0_l0
00000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000ol00006ooooo`;o00001_oo
ool3o`0000;ooooo0_l0001Zooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o00001_ooool2
o`0000Sooooo0_l0000?ooooo`;o00001Oooool7o`000003ooooool0003o000000Gooooo0_l00003
ooooo`;o00000oooool2o`0001Kooooo1_l000000ooooooo0000o`000002ooooo`?o000000?ooooo
o`000?l000002?l00007ooooo`;o00001?ooool2o`0000;ooooo0_l0001Zooooo`007?ooool00ol0
003oooooooooo`1Hooooo`Co00000oooool3o`0000Gooooo0_l000000ooooooo0000o`00000?oooo
o`?o00001Oooool2o`0000;ooooo0_l000001?oooooo0000o`000?l00004ooooo`?o00001oooool2
o`0001Kooooo1Ol00002ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`Ko00001_ooool2
o`0007Cooooo000Looooo`03o`000?oooooooooo05Wooooo0ol00003ooooo`?o00001Oooool2o`00
0003ooooool0003o000000?ooooo0ol0000:ooooo`;o00000oooool4o`0000;ooooo0_l000001Ooo
oooo0000o`000?l0003ooooo00Ko00001Oooool2o`0000;ooooo0_l00005ooooo`;o00003_ooool4
o`0000oooooo0_l00002ooooo`Go00005_ooool2o`00067ooooo000Looooo`03o`000?oooooooooo
05gooooo1?l00009ooooo`;o00000oooool3o`0000Sooooo0_l00005ooooo`Co00000_ooool2o`00
0003ooooool0003o000000;ooooo1?l00003ooooo`;o00000_ooool2o`0000;ooooo0_l00005oooo
o`;o00007Oooool2o`0000;ooooo0_l00002ooooo`Go00005_ooool2o`00067ooooo000Looooo`03
o`000?oooooooooo05;ooooo0_l00009ooooo`;o00004?ooool3o`0000Sooooo0_l0000>ooooo`;o
00001?ooool2o`0000?ooooo0_l0000=ooooo`;o00004?ooool2o`0000?ooooo0_l00006ooooo`;o
00000oooool2o`000004ooooool0003o0000o`0001Wooooo0_l0001Pooooo`007?ooool00ol0003o
ooooooooo`1Booooo`;o00007Oooool2o`0002;ooooo0_l0000Oooooo`?o00000_ooool4o`0000Oo
oooo2?l000000ooooooo0000o`00000Fooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0
DOooool2o`0001?ooooo0_l00009ooooo`;o00008_ooool2o`0001;ooooo0_l0000<ooooo`;o0000
1?ooool2o`0000Oooooo0_l00002ooooo`;o00000oooool2o`0007Sooooo000Looooo`03o`000?oo
oooooooo057ooooo0_l0000Cooooo`;o00001oooool2o`0000?ooooo0_l0000Zooooo`;o00001ooo
ool2o`0001kooooo0_l000000ooooooo0000o`000005o`0007Kooooo000Looooo`;o0000L?ooool2
o`0000?ooooo0_l0000Pooooo`;o00002?ooool2o`0000?ooooo0_l0000Dooooo`;o00000oooool4
o`0000Gooooo0_l000000ooooooo0000o`000007o`0001[ooooo0_l0001Hooooo`007?ooool00ol0
003oooooooooo`2Fooooo`;o00002?ooool2o`000003ooooool0003o000000;o00002_ooool2o`00
00Sooooo0_l00003ooooo`Co00002Oooool4o`0000;ooooo0_l0000Jooooo`;o0000F?ooool001co
oooo00?o0000ooooooooool0D_ooool2o`0001Wooooo0_l0000?ooooo`?o000000?oooooo`000?l0
00003oooool3o`0000[ooooo0_l000000ooooooo0000o`00000<ooooo`;o00002_ooool5o`0000Oo
oooo0_l00003ooooo`?o00000_ooool2o`0007Cooooo000Looooo`03o`000?oooooooooo05;ooooo
0_l0000Eooooo`;o00000_ooool2o`0000cooooo0_l000001Ooooooo0000o`000?l0003ooooo00?o
00003_ooool3o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`Co00000_ooool2o`0000Co
oooo0_l0000?ooooo`Co00001?ooool2o`0000;ooooo1?l000000ooooooo0000o`000002o`000003
ooooool0003o000007Cooooo000Looooo`03o`000?oooooooooo06Wooooo0_l0000?ooooo`Go0000
0oooool3o`0000oooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o0000
0_ooool2o`0000Cooooo0_l0000Gooooo`;o00000oooool3o`000003ooooool0003o000000;o0000
00?oooooo`000?l000007?ooool2o`0005Kooooo000Looooo`03o`000?oooooooooo07[ooooo0_l0
00000ooooooo0000o`000002ooooo`?o00004?ooool2o`0000Cooooo0ol000000ooooooo0000o`00
0003ooooo`Go00006Oooool2o`0000Sooooo0_l000000ooooooo0000o`00000Qooooo`;o0000E_oo
ool001cooooo00?o0000ooooooooool0J?ooool2o`0000kooooo0_l00006ooooo`Co00005_ooool3
o`0000;ooooo0_l00002ooooo`?o00001_ooool2o`000003ooooool0003o000000;ooooo0_l00000
0ooooooo0000o`000009ooooo`;o00002?ooool2o`000003ooooool0003o000000Oooooo0_l0001`
ooooo`007?ooool00ol0003oooooooooo`1Xooooo`;o00003?ooool4o`0000Kooooo0ol0000Loooo
o`;o00002oooool2o`000004ooooool0003o0000ooooo`?o000000?oooooo`000?l000005_ooool3
o`0000Kooooo0_l0000Kooooo`;o0000Doooool001cooooo00?o0000ooooooooool0M_ooool2o`00
00Wooooo0ol0000Aooooo`;o00005?ooool2o`0000Gooooo0ol0000@ooooo`;o00001oooool5o`00
027ooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`18ooooo`;o0000;?ooool2o`0000[o
oooo0_l0000Aooooo`Ko00004?ooool5o`0000;ooooo0ol00005ooooo`;o00001oooool4o`0000Go
oooo0_l00003ooooo`;o0000M_ooool001cooooo00?o0000ooooooooool0B?ooool2o`0000Cooooo
1?l0000Tooooo`;o00006oooool8o`0000;ooooo0_l00004ooooo`?o00001oooool3o`0000[ooooo
0_l00007ooooo`;o00001oooool2o`0000oooooo0_l00002ooooo`?o00000_ooool2o`00067ooooo
000Looooo`03o`000?oooooooooo04Kooooo0_l00005ooooo`Go00002?ooool2o`0002_ooooo0_l0
0009ooooo`?o00002?ooool2o`000004ooooool0003o0000ooooo`?o00002oooool2o`0000Kooooo
0_l0000:ooooo`;o00002?ooool2o`0000cooooo0_l00002ooooo`?o00000_ooool2o`000003oooo
ool0003o000005kooooo000Looooo`03o`000?oooooooooo04Kooooo0_l00005ooooo`Co00002Ooo
ool3o`0002[ooooo0_l00006ooooo`;o000000?oooooo`000?l000001Oooool3o`0000Cooooo0_l0
00000ooooooo0000o`000002ooooo`;o00002?ooool2o`0000Gooooo1?l00009ooooo`?o00001ooo
ool3o`0001Oooooo0_l0001Nooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00003?ooool3
o`0000Sooooo0_l0000Hooooo`;o00001Oooool2o`0000Kooooo0ol00007ooooo`Co00001oooool2
o`0000;ooooo0_l00009ooooo`;o00001?ooool4o`0000Wooooo0ol00008ooooo`;o0000Moooool0
01cooooo00?o0000ooooooooool0C?ooool2o`0001Oooooo0_l0000Hooooo`;o00001Oooool2o`00
00Kooooo0_l00006ooooo`Co00003oooool2o`0000Oooooo0_l000001?oooooo0000o`000?ooool2
o`0000_ooooo0ol0000Dooooo`?o00001?ooool2o`0000Cooooo0_l0001Nooooo`007?ooool00ol0
003oooooooooo`1Hooooo`;o00002_ooool2o`0001gooooo0_l000000ooooooo0000o`00000;oooo
o`;o000000Coooooo`000?l0003ooooo0ol00005ooooo`Go00000oooool2o`0000[ooooo0_l00000
0ooooooo0000o`00000<ooooo`;o00004?ooool2o`0000;ooooo0ol00004ooooo`;o00001?ooool2
o`0000;ooooo0_l0001Jooooo`007?ooool2o`0005Wooooo0_l00008ooooo`Co00007Oooool3o`00
00Cooooo0ol00006ooooo`;o000000Coooooo`000?l0003ooooo0ol00005ooooo`So00000_ooool2
o`0002_ooooo0_l00003ooooo`;o00001Oooool2o`0000Oooooo0_l0001Jooooo`007?ooool00ol0
003oooooooooo`1Rooooo`;o00005_ooool3o`0000Oooooo0_l00004ooooo`Co00000_ooool5o`00
00?ooooo0_l00007ooooo`go00000_ooool2o`000003ooooool0003o000000;ooooo0_l0000=oooo
o`?o00001oooool2o`0000Sooooo0_l000000ooooooo0000o`000005ooooo`;o00002?ooool4o`00
05Oooooo000Looooo`03o`000?oooooooooo04gooooo0_l0000Yooooo`Go00002Oooool4o`0000;o
oooo0_l00002ooooo`Ko000000Coooooo`000?l0003o00000_ooool4o`000003ooooool0003o0000
00co000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00003Oooool3o`0000Oooooo0_l00008
ooooo`;o000000Coooooo`000?l0003ooooo0_l00005ooooo`;o00000oooool6o`0005Oooooo000L
ooooo`03o`000?oooooooooo04[ooooo0_l000000ooooooo0000o`00000Yooooo`?o00002oooool4
o`0000?ooooo0_l00002ooooo`Wo00000_ooool4o`000003ooooool0003o000000oo00000oooool2
o`000003ooooool0003o000000cooooo0ol00003ooooo`?o00002Oooool2o`0000?ooooo1Ol00005
ooooo`;o00000oooool4o`0005Wooooo000Looooo`03o`000?oooooooooo04Wooooo0ol00008oooo
o`;o00002_ooool2o`0001?ooooo0ol0000@ooooo`;o00000oooool2o`0000;ooooo0_l00003oooo
o`;o00000ooooolGo`0000?ooooo0_l000000ooooooo0000o`000006ooooo`;o00001?ooool3o`00
00?ooooo0ol00009ooooo`;o00001Oooool2o`000003ooooool0003o000000[ooooo0_l00004oooo
o`;o0000Doooool001cooooo00?o0000ooooooooool0AOooool2o`0000;ooooo0_l00009ooooo`;o
000000?oooooo`000?l000001oooool2o`0001?ooooo0ol0000?ooooo`?o00001Oooool2o`0000[o
oooo1?l000000ooooooo0000o`00000>o`0000Kooooo0_l00002ooooo`;o00001?ooool2o`0000Go
oooo0_l0000Aooooo`;o00001_ooool2o`00013ooooo0_l0001Cooooo`007?ooool00ol0003ooooo
ooooo`15ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Oooooo0_l00006ooooo`;o0000
9?ooool5o`000003ooooool0003o000000;ooooo1?l00005ooooo`;o000000?oooooo`000?l00000
4ol00006ooooo`;o000000Coooooo`000?l0003o00002oooool3o`0000?ooooo0_l0000;ooooo`?o
000000?oooooo`000?l00000JOooool001cooooo00?o0000ooooooooool0B?ooool2o`0000Cooooo
0_l0000?ooooo`;o00006oooool2o`0000Oooooo0_l00004ooooo`;o000000?oooooo`000?l00000
0ol00002oooooa7o000000?oooooo`000?l000002?l000000ooooooo0000o`000002ooooo`Go0000
1?ooool2o`0000Oooooo0_l000000ooooooo0000o`000002o`0000Kooooo0_l00004ooooo`;o0000
00?oooooo`000?l000003_ooool4o`000003ooooool0003o000005Cooooo000Looooo`03o`000?oo
oooooooo03gooooo0_l00007ooooo`;o000000Coooooo`000?l0003o00005?ooool2o`0001[ooooo
0_l00009ooooo`;o00000_ooool2o`000003ooooool0003o000000Gooooo4Ol000000ooooooo0000
o`00000;o`0000?ooooo0_l00006ooooo`;o00001oooool2o`000003ooooool0003o000000Sooooo
0_l00005ooooo`;o000000?oooooo`000?l000003Oooool4o`000003ooooool0003o000005Cooooo
000Looooo`03o`000?oooooooooo03gooooo0_l00007ooooo`;o000000?oooooo`000?l000000ol0
000Booooo`;o00007?ooool2o`0000Oooooo0_l00003ooooo`Go00000_oooolCo`000004ooooool0
003o0000ooooo`_o00002_ooool2o`0000Sooooo0_l000001?oooooo0000o`000?ooool2o`0000_o
oooo1Ol0000=ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0@?ooool2o`0000[ooooo
0_l00009ooooo`;o00001Oooool3o`0001gooooo0_l0000<ooooo`Go00000_ooool8o`000004oooo
ool0003o0000ooooo`Co00000oooool:o`0000?ooooo0_l0000Dooooo`;o000000?oooooo`000?l0
00000ol00005ooooo`;o00001_ooool3o`0001Oooooo0_l000000ooooooo0000o`00001<ooooo`00
7?ooool00ol0003oooooooooo`10ooooo`;o00000oooool2o`000003ooooool0003o000000;o0000
2oooool2o`0000Gooooo0ol0000[ooooo`Co000000?oooooo`000?l000000ol000000ooooooo0000
o`00000Go`0000Cooooo0_l00004ooooo`;o00003Oooool2o`0000;ooooo0_l00007ooooo`?o0000
1_ooool4o`0001Gooooo0_l000000ooooooo0000o`00001<ooooo`007?ooool00ol0003ooooooooo
o`15ooooo`Oo000000?oooooo`000?l00000>_ooool2o`000003ooooool0003o000000;o000000?o
ooooo`000?l000007Ol00003ooooo`?o00001?ooool2o`0000Kooooo0_l00005ooooo`;o00003?oo
ool2o`0000Sooooo0_l0001Vooooo`007?ooool00ol0003oooooooooo`17ooooo`?o00000oooool2
o`0000Cooooo0_l0000Wooooo`?o00000_ooool2o`0000Kooooo0_l000001Ooooooo0000o`000?l0
003ooooo02Oo00002_ooool3o`0000Cooooo0ol00004ooooo`Co0000M_ooool001cooooo00?o0000
ooooooooool0>?ooool2o`0000kooooo0_l00009ooooo`?o00009_ooool7o`000003ooooool0003o
000000;ooooo0_l00002ooooo`?o000000?oooooo`000?l000009Ol00005ooooo`;o00000oooool2
o`0000Gooooo1Ol00002ooooo`Co00009?ooool4o`0004kooooo000Looooo`03o`000?oooooooooo
03Sooooo0_l00007ooooo`?o000000?oooooo`000?l000002oooool4o`0000?ooooo0_l0000Toooo
o`?o00000_ooool2o`000004ooooool0003o0000o`0000;ooooo1?l000000ooooooo0000o`000006
o`000003ooooool0003o000001Go00000oooool2o`0000;ooooo0_l00002ooooo`;o00003Oooool2
o`0000;ooooo0_l00009ooooo`;o00006oooool4o`0000Cooooo0_l00018ooooo`007?ooool2o`00
04;ooooo0ol000000ooooooo0000o`00000;ooooo`;o00001Oooool2o`0001gooooo0_l00003oooo
o`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000?ooooo1?l000001Ooo
oooo0000o`000?l0003ooooo01co00001?ooool5o`0000oooooo1?l000000ooooooo0000o`00000:
ooooo`;o00004oooool2o`0000_ooooo0_l000000ooooooo0000o`000018ooooo`007?ooool00ol0
003oooooooooo`1Cooooo`;o000000?oooooo`000?l000001Oooool2o`0001Wooooo0_l00003oooo
o`Go00003Oooool4o`000003ooooool0003o000001_o00000_ooool6o`00013ooooo1?l000000ooo
oooo0000o`000009ooooo`;o00005?ooool2o`0000Kooooo0_l00003ooooo`;o000000?oooooo`00
0?l00000B?ooool001cooooo00?o0000ooooooooool0Doooool2o`000003ooooool0003o000000Co
oooo0ol0000Iooooo`;o00001?ooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool3o`000003
ooooool0003o000001oo00000oooool2o`0000kooooo0_l00006ooooo`;o00000oooool2o`0000Oo
oooo0_l0000Dooooo`;o00001Oooool3o`0000Kooooo0_l00018ooooo`007?ooool00ol0003ooooo
ooooo`10ooooo`;o00005oooool2o`000004ooooool0003o0000o`0001Wooooo0_l00004ooooo`;o
00000oooool2o`0000;ooooo0_l00002ooooo`?o000000?oooooo`000?l000002_l000000ooooooo
0000o`00000Eo`0000Gooooo0_l00009ooooo`;o00000oooool3o`000003ooooool0003o000000;o
oooo0ol000000ooooooo0000o`000002o`000003ooooool0003o000000Cooooo0_l0000>ooooo`;o
00001Oooool2o`0000Kooooo0_l00019ooooo`007?ooool00ol0003oooooooooo`0looooo`;o0000
0_ooool2o`0000?ooooo0_l0000Booooo`;o00000_ooool2o`0002Cooooo0_l00002ooooo`;o0000
0_ooool3o`000003ooooool0003o000000Ko000000?oooooo`000?l000006Ol000000ooooooo0000
o`000002ooooo`;o00003_ooool3o`000003ooooool0003o000000;ooooo2?l00002ooooo`?o0000
0_ooool2o`0000Gooooo0_l00007ooooo`;o00003Oooool2o`0004Wooooo000Looooo`03o`000?oo
oooooooo03_ooooo0ol00002ooooo`;o00000_ooool3o`0000[ooooo0_l0000/ooooo`?o000000?o
ooooo`000?l000000_ooool2o`0000;ooooo0ol000000ooooooo0000o`000003o`000003ooooool0
003o000001oo00004oooool4o`0000?ooooo2Ol000001?oooooo0000o`000?l00009ooooo`;o0000
00?oooooo`000?l000001?ooool2o`0000[ooooo0_l0001<ooooo`007?ooool00ol0003ooooooooo
o`0kooooo`;o00000oooool2o`0000;ooooo0_l0000;ooooo`;o0000;?ooool3o`000003ooooool0
003o000000;ooooo0_l00002ooooo`?o00000_ooool2o`000003ooooool0003o0000027o00002ooo
ool2o`0000Gooooo1Ol00002ooooo`Go00000oooool3o`0000oooooo0_l0000?ooooo`?o0000C?oo
ool001cooooo00?o0000ooooooooool0@?ooool2o`0000Wooooo0_l0000:ooooo`;o0000:_ooool2
o`0000;ooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo8ol0000;ooooo`;o00001Oooool4
o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`?o00007Oooool2o`000003ooooool0003o
000004gooooo000Looooo`03o`000?oooooooooo03oooooo0ol00009ooooo`;o00002?ooool4o`00
00?ooooo0_l0000Jooooo`;o00004Oooool2o`0000;ooooo0_l000000ooooooo0000o`000003o`00
0003ooooool0003o000001So00000_ooool2o`000003ooooool0003o000001;ooooo0_l0000;oooo
o`?o00000oooool2o`00013ooooo0_l00005ooooo`;o00002Oooool2o`0004Gooooo000Looooo`03
o`000?oooooooooo03Wooooo1Ol000000ooooooo0000o`00000:ooooo`;o00000oooool2o`0000?o
oooo1?l00003ooooo`?o00006Oooool2o`0001;ooooo0ol00003ooooo`Oo00000ooooolGo`000004
ooooool0003o0000ooooo`?o00003Oooool2o`0000;ooooo0_l0000:ooooo`Co00000oooool4o`00
00Cooooo0_l00008ooooo`;o00001Oooool2o`0000Wooooo0_l00015ooooo`007?ooool00ol0003o
ooooooooo`0iooooo`Go00001?ooool2o`0000Cooooo0_l00006ooooo`;o000000?oooooo`000?l0
00000_l00003ooooo`;o000000?oooooo`000?l000006_ooool4o`0000kooooo1?l00004ooooob;o
00000oooool2o`0000gooooo0_l000001Ooooooo0000o`000?l0003ooooo00Co00001Oooool4o`00
00;ooooo0_l000000ooooooo0000o`000004ooooo`;o00007?ooool2o`0004?ooooo000Looooo`03
o`000?oooooooooo03[ooooo0_l00006ooooo`;o00001?ooool2o`0000Wooooo1?l00003ooooo`;o
00007Oooool4o`0000kooooo1?l00003oooooaOo000000?oooooo`000?l000001Ol00002ooooo`?o
000000?oooooo`000?l000002?ooool2o`0000?ooooo0_l00002ooooo`?o000000?oooooo`000?l0
00000_l00006ooooo`?o00000_ooool2o`0000Oooooo0_l0000@ooooo`;o00002_ooool2o`0004?o
oooo000Looooo`03o`000?oooooooooo03Oooooo0_l00008ooooo`?o000000?oooooo`000?l00000
0oooool4o`0000Cooooo1?l0000gooooo`;o00000ooooolLo`000003ooooool0003o000000;ooooo
0ol000000ooooooo0000o`000008ooooo`;o00000oooool2o`0000?ooooo0_l0000:ooooo`Co0000
2oooool2o`00013ooooo0_l00004ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0=_oo
ool5o`0000Kooooo0ol000000ooooooo0000o`000003ooooo`Co00001?ooool4o`0000[ooooo0_l0
000Cooooo`;o00001oooool2o`0000[ooooo0_l00005ooooo`?o00000_oooolIo`000003ooooool0
003o000001?ooooo0ol0000?ooooo`Go00001Oooool4o`000003ooooool0003o000000Kooooo0_l0
000>ooooo`;o00001_ooool2o`00047ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo
0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0fooooo`;o0000
00?oooooo`000?l000000_l00003ooooo`;o00001?ooool2o`0000Wooooo1?l0000;ooooo`;o0000
4oooool2o`0000;ooooo1?l000000ooooooo0000o`000008ooooo`Co00001Oooool2o`0000?ooooo
6Ol000001?oooooo0000o`000?l0000<ooooo`;o00001?ooool8o`0000_ooooo1?l000001Ooooooo
0000o`000?l0003ooooo00So00001Oooool3o`0001Gooooo0_l00011ooooo`0000KoooooogMgMonH
V9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo03_ooooo0_l00003ooooo`;o00001?ooool2o`0000Oooooo1Ol0000<ooooo`;o00003oooool2
o`0000Gooooo1Ol0000;ooooo`Oo00001?oooolJo`000003ooooool0003o000000?o00003?ooool2
o`0000Gooooo1ol0000;ooooo`Co000000Coooooo`000?l0003o00000oooool>o`0005Sooooo0000
0ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006ooooo`03o`000?oooooo
oooo03Wooooo0_l0000:ooooo`?o00001oooool4o`0000gooooo0_l0000?ooooo`;o00001?ooool6
o`0000gooooo1ol00002oooooa[o000000?oooooo`000?l000001?l0000;ooooo`;o00000_ooool2
o`000004ooooool0003o0000ooooo`;o00003Oooool4o`0000Cooooo0_l000001?oooooo0000o`00
0?ooool8o`0005_ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Co
A4A4omgMgOoooooo00001oooool3o`0003Wooooo0_l000000ooooooo0000o`000002o`0000Gooooo
0ol00008ooooo`?o00003Oooool2o`0001Gooooo2?l0000>ooooo`Co000000?oooooo`000?l00000
6?l000000ooooooo0000o`000005o`000003ooooool0003o000000Sooooo0_l00002ooooo`;o0000
2Oooool2o`0000Gooooo1?l00007ooooo`;o00000_ooool2o`0000Cooooo0_l0000=ooooo`;o0000
2?ooool2o`0004Cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Co
gMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`0eooooo`;o00001Oooool4o`0000Gooooo
0_l00003ooooo`Co000000Coooooo`000?l0003o00001oooool2o`0000Oooooo0_l0000<ooooo`;o
000000Coooooo`000?l0003ooooo0_l00002ooooo`Go00000oooool2o`0000Oooooo1_l000000ooo
oooo0000o`00000Mo`0000Cooooo0_l0000Gooooo`;o00001Oooool4o`0000;ooooo0_l00007oooo
o`;o00004oooool2o`0000?ooooo0_l00003ooooo`;o0000A?ooool00003ooooool@413ooooo00;o
oooo00?o410@ooooooooool02_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo03Go
oooo0_l00006ooooo`;o00002oooool8o`0000Oooooo0_l00007ooooo`;o00003?ooool2o`000004
ooooool0003o0000ooooo`Co000000?oooooo`000?l000000ol00002ooooo`;o00001oooool7o`00
00?ooooo0ol000000ooooooo0000o`00000>o`000003ooooool0003o000000Go00009?ooool2o`00
00;ooooo1?l0000Qooooo`Co000000?oooooo`000?l000000_ooool2o`00043ooooo00001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0e
ooooo`;o00004?ooool4o`000003ooooool0003o000000;o00000_ooool2o`0000cooooo0_l0000?
ooooo`;o00000oooool4o`000004ooooool0003o0000ooooo`;o00003?ooool6o`0000Cooooo0ol0
00000ooooooo0000o`00000=o`000003ooooool0003o000000Oooooo0_l0000Booooo`Ko00002?oo
ool2o`0000;ooooo0_l0000Nooooo`;o00000oooool4o`000003ooooool0003o000000;ooooo0_l0
0002ooooo`;o0000??ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000
ooooo`06ooooo`03o`000?oooooooooo03Gooooo0_l0000@ooooo`Co000000Coooooo`000?l0003o
00000oooool2o`0000cooooo0_l0000?ooooo`;o00000_ooool4o`000003ooooool0003o000001?o
oooo0_l00005oooooa3o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l000000ooooooo
0000o`00000Booooo`Ko00003?ooool2o`0001kooooo0_l00004ooooo`;o00000_ooool2o`0000Ko
oooo0_l0000looooo`007?ooool00ol0003oooooooooo`11ooooo`;o00001?ooool2o`0000?ooooo
0ol00006ooooo`;o00001Oooool3o`0001Kooooo1?l000001?oooooo0000o`000?l0000Booooo`?o
00000_ooool6o`0000;ooooo1_l00005ooooo`;o000000Coooooo`000?l0003o00000oooool4o`00
01?ooooo0_l00004ooooo`;o00001oooool2o`0001Sooooo0_l00002ooooo`;o00003Oooool2o`00
04Cooooo000Looooo`03o`000?oooooooooo03;ooooo0_l00005ooooo`;o00001_ooool2o`0000Ko
oooo0_l000001?oooooo0000o`000?l00006ooooo`;o00001Oooool3o`0001_ooooo0ol0000Boooo
o`?o00000_ooool8o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l00006
ooooo`;o00004oooool2o`0000Cooooo0_l00006ooooo`?o00002_ooool2o`0000?ooooo0_l00007
ooooo`;o000000Coooooo`000?l0003o0000Doooool001cooooo00?o0000ooooooooool0<_ooool2
o`0000Gooooo0_l00008ooooo`;o00000_ooool4o`0000;ooooo0_l00006ooooo`;o00004Oooool4
o`0000oooooo0_l00004ooooo`;o00002Oooool4o`000003ooooool0003o000000Cooooo1Ol00006
ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000003ooooo`;o00005Ooo
ool2o`0000Cooooo0_l00002ooooo`;o00000_ooool2o`0000[ooooo0ol00003ooooo`;o00001ooo
ool2o`000004ooooool0003o0000o`0000Wooooo0_l00018ooooo`007?ooool00ol0003ooooooooo
o`0fooooo`Co00002Oooool2o`0000;ooooo1?l000001?oooooo0000o`000?l0000<ooooo`;o0000
1oooool8o`0000oooooo0_l000001?oooooo0000o`000?ooool2o`0000Wooooo1?l000001?oooooo
0000o`000?l00002ooooo`Ko00001_ooool2o`000004ooooool0003o0000ooooo`Go00000oooool2
o`0000Oooooo0_l00004ooooo`;o00001oooool2o`0000?ooooo0_l00002ooooo`;o00003_ooool3
o`0000Kooooo1?l00006ooooo`;o00002Oooool2o`0004Sooooo000Looooo`03o`000?oooooooooo
03Kooooo1?l00003ooooo`?o00001_ooool2o`0000;ooooo1Ol0000<ooooo`;o00001oooool4o`00
00cooooo0_l00002ooooo`;o00001?ooool2o`000004ooooool0003o0000o`0000kooooo1ol00000
0ooooooo0000o`000002o`0000Gooooo1Ol000000ooooooo0000o`00000>ooooo`;o00001?ooool2
o`0000Oooooo0_l00003ooooo`;o000000?oooooo`000?l000005?ooool2o`0000;ooooo1_l0000?
ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0?Oooool3o`000003ooooool0003o0000
00?ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00009Oooool2o`0000;ooooo0_l00007
ooooo`?o00003oooool6o`0000?ooooo3ol00002ooooo`;o00004?ooool2o`0000Oooooo0_l00002
ooooo`?o000000?oooooo`000?l000003oooool2o`0000?ooooo0_l00006ooooo`Co000000?ooooo
o`000?l000002_ooool2o`0004Sooooo000Looooo`03o`000?oooooooooo037ooooo0_l0000>oooo
o`;o00001_ooool2o`0001cooooo0_l0000;ooooo`;o00001Oooool2o`0001Oooooo5ol00002oooo
o`;o00001oooool2o`0000oooooo0ol00002ooooo`?o000000?oooooo`000?l000003Oooool4o`00
00Wooooo0_l00002ooooo`;o000000?oooooo`000?l000000oooool2o`0004oooooo000Looooo`03
o`000?oooooooooo037ooooo0_l00002ooooo`;o00002_ooool2o`0001Kooooo0_l00009ooooo`;o
000000?oooooo`000?l000001Oooool8o`000003ooooool0003o000000;ooooo0_l00005ooooo`;o
00003?ooool2o`0000Gooooo3Ol000001?oooooo0000o`000?l00002ooooo`;o00002_ooool2o`00
00Wooooo0_l00004ooooo`;o00001?ooool2o`000003ooooool0003o000000gooooo0_l00002oooo
o`;o00001oooool2o`000003ooooool0003o000000Gooooo1?l00004ooooo`?o0000B?ooool001co
oooo00?o0000ooooooooool0<?ooool3o`0000;ooooo0_l00003ooooo`Co00004oooool2o`0000Ko
oooo0_l00009ooooo`;o00000_ooool2o`0000Cooooo1ol000001?oooooo0000o`000?l00009oooo
o`;o00003?ooool3o`0000Gooooo2?l00003ooooo`Co00000oooool2o`0001;ooooo0_l000000ooo
oooo0000o`000002o`0000Cooooo0_l00003ooooo`;o00003?ooool2o`0000Gooooo1?l00005oooo
o`Go00001?ooool5o`0000Cooooo0ol00018ooooo`007?ooool00ol0003oooooooooo`0`ooooo`?o
00001oooool4o`0001;ooooo0ol000000ooooooo0000o`00000Aooooo`?o00001_ooool3o`0000?o
oooo0ol00009ooooo`Co00002oooool2o`0000Oooooo1_l000000ooooooo0000o`000003o`0000ko
oooo0_l00008ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o00000oooool2o`0000_o
oooo0ol00007ooooo`;o00000oooool6o`0000Gooooo0_l00007ooooo`;o0000BOooool001cooooo
00?o0000ooooooooool0;oooool3o`0000Oooooo1?l0000;ooooo`;o00001_ooool2o`0000;ooooo
0_l0000Aooooo`;o00002Oooool3o`0000;ooooo0_l00009ooooo`Co00006oooool2o`00017ooooo
0_l0000<ooooo`;o00001?ooool2o`0000_ooooo0_l000000ooooooo0000o`000003o`0000gooooo
0ol000000ooooooo0000o`000002o`0000;ooooo0_l00004ooooo`;o0000COooool001cooooo0_l0
000`ooooo`;o00002?ooool2o`0000gooooo0_l000000ooooooo0000o`00000@ooooo`;o00004ooo
ool3o`0000kooooo0ol0000>ooooo`;o0000;?ooool2o`0000Cooooo0_l00008ooooo`;o000000Co
ooooo`000?l0003ooooo0ol0000Aooooo`Ko00000_ooool2o`0000Cooooo0_l00009ooooo`;o0000
@_ooool001cooooo00?o0000ooooooooool0;Oooool4o`0000;ooooo1?l0000?ooooo`;o00000ooo
ool2o`0000?ooooo0_l0000;ooooo`?o00003Oooool2o`0001;ooooo1_l0000=ooooo`?o00005ooo
ool2o`00013ooooo0_l00003ooooo`;o00002oooool2o`0000Cooooo0_l0000:ooooo`;o00001?oo
ool8o`0000Sooooo0ol00007ooooo`?o0000@_ooool001cooooo00?o0000ooooooooool0;Oooool2
o`0000Cooooo1?l00002ooooo`;o00001oooool2o`0000;ooooo0_l00008ooooo`;o00003?ooool2
o`0000gooooo0_l00006ooooo`;o00001?ooool2o`0000;ooooo1Ol000000ooooooo0000o`00000=
ooooo`?o00005oooool2o`0000kooooo1?l000000ooooooo0000o`000002o`00017ooooo0_l0000:
ooooo`ko00002Oooool3o`0000Kooooo0ol00012ooooo`007?ooool00ol0003oooooooooo`0ioooo
o`;o00000_ooool2o`0000?ooooo0_l0000:ooooo`;o00001_ooool2o`0000gooooo0_l000000ooo
oooo0000o`000005ooooo`;o00001?ooool3o`0000?ooooo2Ol0000Vooooo`;o00004_ooool9o`00
00Kooooo0_l0000=ooooo`;o00001_oooolAo`0000Kooooo0ol00007ooooo`;o000000?oooooo`00
0?l00000?oooool001cooooo00?o0000ooooooooool0;oooool2o`0000cooooo0_l0000?ooooo`;o
00001_ooool4o`0000Oooooo0ol000000ooooooo0000o`000004o`0000Cooooo0ol00004ooooo`;o
00001?ooool5o`0000Cooooo0_l0000Sooooo`;o00004Oooool7o`000003ooooool0003o000000Ko
oooo0_l00005ooooo`?o00000_ooool2o`000003ooooool0003o000000Kooooo0_l000000ooooooo
0000o`00000>o`0000Cooooo0_l000000ooooooo0000o`000008ooooo`;o0000?oooool001cooooo
00?o0000ooooooooool0;oooool2o`00023ooooo1?l00002ooooo`?o00000_ooool2o`0000?ooooo
2ol00002ooooo`Go00002Oooool2o`0000Gooooo1?l0000cooooo`So00002oooool2o`0000Gooooo
1?l000000ooooooo0000o`000005oooooaOo00001?ooool2o`000003ooooool0003o000000Sooooo
0_l0000oooooo`007?ooool00ol0003oooooooooo`0nooooo`;o000000?oooooo`000?l000000_l0
000<ooooo`Co00001oooool2o`000003ooooool0003o000000;ooooo2Ol000000ooooooo0000o`00
0004o`0000oooooo0ol0000<ooooo`;o00009?ooool<o`0001;ooooo0ol00006oooooaSo00001ooo
ool2o`0000Gooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o00002?ooool4
o`0000?ooooo0_l000000ooooooo0000o`000002o`0001Wooooo0ol000001?oooooo0000o`000?oo
ool7o`000003ooooool0003o000000Go00001?ooool2o`0000Cooooo0_l00002ooooo`;o00003?oo
ool3o`00023ooooo2_l000001?oooooo0000o`000?ooool2o`00017ooooo0ol00007ooooo`;o0000
0_oooolFo`000004ooooool0003o0000ooooo`?o00001Oooool2o`0004?ooooo000Looooo`03o`00
0?oooooooooo02gooooo0_l00002ooooo`;o00001?ooool4o`0000Kooooo1?l00003ooooo`;o0000
1?ooool5o`000003ooooool0003o000000;o00001Oooool4o`000003ooooool0003o0000017o0000
0oooool2o`0000Cooooo0_l00003ooooo`;o00002oooool2o`0001gooooo0_l000000ooooooo0000
o`000007o`0000?ooooo1?l0000Aooooo`?o00003?ooool2o`000003ooooool0003o0000017o0000
00Coooooo`000?l0003ooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`0aooooo`;o0000
3oooool3o`0000?ooooo0_l00004ooooo`Go000000?oooooo`000?l000001?l00002ooooo`Go0000
00?oooooo`000?l000002ol00002ooooo`Co00000_ooool2o`0000[ooooo0_l0000;ooooo`;o0000
6?ooool2o`0000?ooooo2_l00005ooooo`Co00004Oooool2o`0000?ooooo0_l00008oooooaOo0000
D?ooool001cooooo00?o0000ooooooooool0;Oooool5o`00013ooooo0_l0000Dooooo`;o00000_oo
ool4o`0000;ooooo4ol000001?oooooo0000o`000?l0000:ooooo`;o00004?ooool4o`00017ooooo
2Ol000001Ooooooo0000o`000?l0003ooooo00;o00005Oooool2o`0000Oooooo0_l00008oooooaOo
0000D?ooool001cooooo00?o0000ooooooooool0;Oooool5o`00013ooooo0ol00007ooooo`;o0000
0_ooool2o`0000;ooooo0_l00005oooooa[o000000Coooooo`000?l0003o00006Oooool2o`000003
ooooool0003o000000;o00004_ooool4o`0000Gooooo0_l00002ooooo`;o00005Oooool2o`00013o
oooo5_l0000=ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0;_ooool2o`0001?ooooo
0_l00007ooooo`;o00000_ooool2o`0000;ooooo0_l00002oooooago00000_ooool2o`0000oooooo
0_l00008ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000008ooooo`;o
00000_ooool5o`0001[ooooo0_l00009ooooo`;o00002oooool8o`000003ooooool0003o000000co
00003Oooool2o`0004?ooooo000Looooo`03o`000?oooooooooo047ooooo0_l0000Eoooooaoo0000
3?ooool2o`0000?ooooo0_l0000:ooooo`?o000000?oooooo`000?l000000ol00006ooooo`Go0000
00?oooooo`000?l000002?l0000Aooooo`;o00000_ooool2o`0000Gooooo0_l00002ooooo`Co0000
2OoooolGo`0000[ooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00000ooo
ool2o`0000gooooo0ol00009ooooo`;o00001oooool2o`0000;ooooo7ol00003ooooo`?o000000?o
ooooo`000?l000000_ooool2o`0000oooooo0ol000000ooooooo0000o`000003o`000004ooooool0
003o0000ooooo`Oo000000?oooooo`000?l000000_l000000ooooooo0000o`000005o`000003oooo
ool0003o000000;o00002_ooool2o`000003ooooool0003o000000Kooooo0_l00004ooooo`;o0000
2_oooolGo`0000Sooooo0ol00016ooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00000ooo
ool2o`0000;ooooo0_l00009ooooo`;o00002_ooool2o`0000Oooooo0_l00003ooooo`?o00000_oo
oolFo`000003ooooool0003o000000?ooooo0ol000000ooooooo0000o`00000Gooooo`;o000000Co
ooooo`000?l0003ooooo0_l000000ooooooo0000o`000004o`0000;ooooo0_l00006ooooo`Wo0000
3Oooool2o`0000kooooo0_l000000ooooooo0000o`000004oooooaSo00002?ooool2o`0004Oooooo
000Looooo`;o0000;Oooool2o`0000Oooooo0_l0000Dooooo`;o00003OoooolLo`0000Kooooo0_l0
00000ooooooo0000o`000002ooooo`;o00004oooool2o`0000Gooooo0_l000000ooooooo0000o`00
0004o`0000Gooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00004?ooool3o`0000gooooo
0_l000000ooooooo0000o`000004oooooaWo00001_ooool2o`0004Sooooo000Looooo`03o`000?oo
oooooooo02cooooo0_l00005ooooo`;o000000?oooooo`000?l000004oooool2o`0000?ooooo0_l0
0008oooooa3o000000?oooooo`000?l000002_l00004ooooo`;o00000_ooool2o`0000;ooooo0_l0
0005ooooo`;o00004oooool9o`0000Gooooo0_l00002ooooo`;o00005?ooool3o`0001Oooooo6?l0
0006ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0<oooool2o`000003ooooool0003o
000000Kooooo0_l0000:ooooo`;o00001?ooool2o`0000Oooooo7_l00004ooooo`;o00001_ooool2
o`0000Gooooo1?l0000Cooooo`;o000000?oooooo`000?l000000ol00003ooooo`;o00004oooool2
o`0001kooooo4Ol00002ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0>Oooool2o`00
00;ooooo0ol0000:ooooo`;o00001?ooool2o`0000Kooooo8_l00009ooooo`?o00001?ooool4o`00
017ooooo0_l00004ooooo`Co00000oooool2o`000003ooooool0003o0000013ooooo0_l00006oooo
o`;o00002oooool2o`0000[ooooo4?l00009ooooo`Go0000BOooool001cooooo00?o0000oooooooo
ool0>Oooool2o`0000;ooooo0_l0000<ooooo`?o00002_oooolRo`0000Wooooo0ol00006ooooo`Co
00003oooool4o`0000cooooo0_l0000Hooooo`;o00002oooool2o`0000[ooooo1?l000000ooooooo
0000o`000006o`0000Cooooo0_l00006ooooo`Go0000BOooool001cooooo00?o0000ooooooooool0
:oooool2o`00013ooooo0_l00007ooooo`;o00000oooool5o`0000Cooooo1?l000000ooooooo0000
o`000002oooooaSo000000Coooooo`000?l0003ooooo0_l00008ooooo`?o00000oooool2o`0000?o
oooo0_l0000Aooooo`;o00000_ooool2o`0003_ooooo1?l000000ooooooo0000o`000004o`0000Go
oooo0ol0001Dooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o00004?ooool2o`0000Oooooo
0_l00006ooooo`;o00001?ooool4o`0000;ooooo0ol00002ooooo`[o000000?oooooo`000?l00000
2Ol00004ooooo`;o00002?ooool3o`0000?ooooo0_l0000Fooooo`;o00000_ooool2o`0000Cooooo
0_l0000Kooooo`;o00006?ooool3o`0000Cooooo0ol00003ooooo`;o000000?oooooo`000?l00000
1Oooool2o`0004kooooo000Looooo`03o`000?oooooooooo03Wooooo0_l000000ooooooo0000o`00
0007ooooo`;o00001oooool2o`0000[ooooo3Ol000000ooooooo0000o`000007o`000003ooooool0
003o000000;o00002Oooool2o`0000;ooooo0ol0000:ooooo`;o00005oooool6o`0001Wooooo0_l0
000Oooooo`;o00001?ooool2o`0000Gooooo0_l000001?oooooo0000o`000?l0001=ooooo`007?oo
ool00ol0003oooooooooo`0`ooooo`;o00001oooool2o`000003ooooool0003o000000Kooooo0ol0
000FoooooaWo00000_ooool2o`0000Gooooo0_l0000>ooooo`?o00005oooool6o`0000;ooooo0_l0
000Kooooo`;o00002_ooool2o`0000Wooooo0_l00002ooooo`;o00002Oooool8o`0004gooooo000L
ooooo`03o`000?oooooooooo02kooooo1?l0000Booooo`;o00000_ooool2o`0000;ooooo0_l0000;
ooooo`;o00000_ooool<o`000003ooooool0003o000000Oo000000Coooooo`000?l0003ooooo0ol0
000Eooooo`;o00002oooool5o`000004ooooool0003o0000ooooo`;o00002?ooool4o`0001_ooooo
0_l00004ooooo`;o00001?ooool2o`0000Wooooo0_l00005ooooo`;o00001_ooool2o`0000;ooooo
0_l0001?ooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o000000?oooooo`000?l000004_oo
ool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000008ooooo`;o000000Go
ooooo`000?l0003o0000ooooo`0Fo`000005ooooool0003o0000o`000?ooool00_l000000ooooooo
0000o`000002o`0000oooooo0_l00009ooooo`Go000000?oooooo`000?l000000ol00008ooooo`;o
000000?oooooo`000?l000008?ooool2o`0000cooooo0_l00005ooooo`Go000000?oooooo`000?l0
0000F?ooool001cooooo00?o0000ooooooooool0<Oooool2o`0001;ooooo1?l00006ooooo`?o0000
0oooool2o`0000Cooooo0ol00002oooooago000000?oooooo`000?l000000_l0000>ooooo`?o0000
4Oooool5o`0000Gooooo0_l00002ooooo`;o00002oooool3o`0000Cooooo0_l0000Jooooo`;o0000
1?ooool9o`0005Sooooo000Looooo`03o`000?oooooooooo04Cooooo0_l000000ooooooo0000o`00
0006ooooo`Co00000_ooool2o`0000Cooooo0_l00004oooooa?o000000?oooooo`000?l000001ol0
0005ooooo`;o00002oooool2o`0001?ooooo1?l00005ooooo`;o00003oooool3o`0000?ooooo0ol0
0008ooooo`;o00001_ooool2o`0000kooooo0_l00003ooooo`;o0000F_ooool001cooooo00?o0000
ooooooooool0<Oooool2o`0000oooooo1?l00007ooooo`;o000000Coooooo`000?l0003o00000_oo
ool2o`0000[ooooo1Ol000000ooooooo0000o`000007o`0000Cooooo0_l000000ooooooo0000o`00
0002o`000003ooooool0003o000000Gooooo0_l0000@ooooo`;o00003?ooool2o`0000?ooooo0_l0
0002ooooo`Co000000?oooooo`000?l000003Oooool2o`0000?ooooo0_l00009ooooo`;o00001_oo
ool2o`0006oooooo000Looooo`03o`000?oooooooooo037ooooo0_l0000?ooooo`;o00002Oooool2
o`0000Cooooo1?l0000=ooooo`;o000000?oooooo`000?l000001_l00005ooooo`?o00001Oooool2
o`0000Gooooo0_l0000@ooooo`;o00002_ooool4o`0000?ooooo0_l00002ooooo`Co000000?ooooo
o`000?l000003Oooool2o`0000oooooo0_l0000Cooooo`;o0000HOooool001cooooo00?o0000oooo
ooooool0Doooool2o`000003ooooool0003o000000[ooooo0_l00002ooooo`Wo00000oooool9o`00
0003ooooool0003o000001;ooooo0_l00007ooooo`;o00001_ooool2o`0000[ooooo0_l0000Poooo
o`Go00001_ooool3o`0000Wooooo0_l00002ooooo`;o0000GOooool001cooooo0_l00019ooooo`;o
00003?ooool2o`0000[ooooo0_l00002ooooo`[o00000_ooool4o`000003ooooool0003o000000;o
000000?oooooo`000?l000004_ooool2o`0000;ooooo0_l00003ooooo`Co00001Oooool5o`0000;o
oooo1Ol000000ooooooo0000o`00000Aooooo`;o00002_ooool3o`000003ooooool0003o000000Ko
oooo0ol00009ooooo`;o00000_ooool2o`0005gooooo000Looooo`03o`000?oooooooooo04Sooooo
0_l0000Booooo`;o00001?ooool2o`0000;ooooo2_l000000ooooooo0000o`000003o`0000;ooooo
0_l00004ooooo`;o00005?ooool2o`0000?ooooo1?l00005ooooo`Ko000000?oooooo`000?l00000
0ol000001?oooooo0000o`000?ooool2o`0000kooooo0ol00008ooooo`?o00005_ooool2o`00067o
oooo000Looooo`03o`000?oooooooooo04Gooooo0_l0000Eooooo`?o00001oooool2o`000003oooo
ool0003o000000Go000000Coooooo`000?l0003ooooo2Ol000001?oooooo0000o`000?ooool2o`00
0003ooooool0003o000001Wooooo0ol00004ooooo`;o00000_ooool4o`0000Cooooo0_l00004oooo
o`;o00002Oooool2o`0000Gooooo0_l000000ooooooo0000o`000009ooooo`;o00003?ooool2o`00
00Gooooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`0dooooo`;o000000?oooooo`000?l0
00003?ooool2o`0001Kooooo1Ol00008ooooo`Go00001_ooool8o`0000?ooooo0ol000001Ooooooo
0000o`000?l0003ooooo00;o00005Oooool6o`0000Gooooo1?l000000ooooooo0000o`000007oooo
o`;o00000_ooool4o`0000[ooooo0_l00005ooooo`;o00001Oooool2o`0000oooooo0_l00002oooo
o`;o0000F_ooool001cooooo00?o0000ooooooooool0<Oooool2o`000004ooooool0003o0000oooo
o`;o00009_ooool6o`0000Gooooo1Ol000000ooooooo0000o`000002ooooo`Co00001oooool8o`00
0003ooooool0003o000001;ooooo0ol00003ooooo`?o00001oooool2o`000003ooooool0003o0000
00_ooooo1?l0000Aooooo`;o00005_ooool2o`0005kooooo000Looooo`03o`000?oooooooooo037o
oooo0_l0000Rooooo`;o00002_ooool4o`0000_ooooo0_l00002ooooo`;o00002Oooool8o`000003
ooooool0003o000001;ooooo0ol00004ooooo`;o00001oooool2o`0001Sooooo0_l000000ooooooo
0000o`000007ooooo`;o00007?ooool2o`0005Oooooo000Looooo`03o`000?oooooooooo03Gooooo
0_l0000>ooooo`;o00001_ooool4o`0000Cooooo0_l0000Yooooo`So00002oooool4o`0000Kooooo
0_l00004ooooo`Co00001Oooool4o`0000Kooooo0_l0000>ooooo`;o000000?oooooo`000?l00000
1oooool2o`0001cooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`0eooooo`;o00003_oo
ool2o`0000Kooooo1?l0000Jooooo`?o000000?oooooo`000?l000000_l0000=ooooo`[o00001Ooo
ool2o`0000;ooooo1?l0000>ooooo`;o00001Oooool5o`0000Gooooo0_l000000ooooooo0000o`00
000/ooooo`;o00001oooool3o`0005Kooooo000Looooo`03o`000?oooooooooo03Kooooo0_l0000F
ooooo`;o00006oooool8o`000003ooooool0003o000000cooooo2?l00003ooooo`Co00001?ooool2
o`0000Kooooo1?l00005ooooo`;o00001_ooool3o`0000Sooooo0_l0000/ooooo`;o00001oooool3
o`0000?ooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`0eooooo`?o00005_ooool2o`00
00_ooooo0_l0000@ooooo`Co00000oooool2o`0000?ooooo0_l00007ooooo`[o000000?oooooo`00
0?l000003_ooool4o`0000Gooooo0_l00005ooooo`Go0000;oooool2o`0001?ooooo0_l0001Aoooo
o`007?ooool00ol0003oooooooooo`0eooooo`;o00005Oooool4o`0000_ooooo0_l00005ooooo`;o
00002_ooool3o`0000Sooooo1?l00004ooooo`_o00002Oooool2o`0000?ooooo0_l0000Aooooo`Ko
00007oooool3o`0000?ooooo0_l00007ooooo`;o0000I_ooool001cooooo00?o0000ooooooooool0
C?ooool2o`0000Wooooo0ol00008ooooo`;o000000?oooooo`000?l000000_ooool3o`0000;ooooo
0ol00003ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Cooooo4?l00004ooooo`?o0000
00Coooooo`000?l0003o00000_ooool2o`0000gooooo0_l000001?oooooo0000o`000?l00008oooo
o`;o00005Oooool3o`0000;ooooo0ol00007ooooo`;o0000I_ooool001cooooo00?o0000oooooooo
ool0=_ooool2o`00017ooooo0_l0000<ooooo`Co00002_ooool2o`0000;ooooo0ol00008ooooo`;o
000000?oooooo`000?l000000_l00002ooooo`;o00000oooool?o`0000Gooooo0_l000001?oooooo
0000o`000?ooool4o`0000Sooooo3_l000000ooooooo0000o`000004o`00013ooooo0_l00008oooo
o`?o00001oooool2o`0006Kooooo000Looooo`03o`000?oooooooooo03Kooooo0_l0000=ooooo`;o
00000_ooool2o`0000kooooo0_l0000:ooooo`;o00000oooool2o`0000gooooo0_l00002ooooo`;o
00000oooool=o`0000gooooo1?l00003ooooo`;o00000oooool>o`000003ooooool0003o000000;o
00004Oooool3o`0000Sooooo0_l00007ooooo`;o00003oooool2o`0005Kooooo00001_ooooook^k^
oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool0
0ol0003oooooooooo`0fooooo`;o00003Oooool2o`0001;ooooo1?l00007ooooo`Ko000000?ooooo
o`000?l000002?ooool2o`0000Oooooo0_l00002ooooo`go00000oooool2o`0000Cooooo0_l00009
ooooo`;o00000_ooool2o`0000Cooooo2?l0000Fooooo`?o00002Oooool2o`0000Oooooo0_l0000?
ooooo`Co0000E?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go
EEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo03Kooooo0_l0000;ooooo`;o0000
5?ooool4o`0000;ooooo0_l00003ooooo`ko00000oooool5o`0000Cooooo1?l000000ooooooo0000
o`00000;o`0000;ooooo0_l00002ooooo`Co00002_ooool5o`0000Sooooo1?l0000;ooooo`;o0000
2Oooool5o`0000_ooooo0_l0000Fooooo`;o00000oooool2o`0004oooooo00000ooooooo410@oooo
o`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo03Kooooo0_l0000;ooooo`Co00004_ooool2o`0000Cooooo0_l00002ooooo`?o0000
0_ooool4o`000003ooooool0003o000000?o00000oooool5o`0000;ooooo0_l00002ooooo`;o0000
0_ooool<o`0000Cooooo1?l00002ooooo`;o00002?ooool5o`0000?ooooo0_l00003ooooo`Co0000
2oooool2o`000003ooooool0003o000000Wooooo0_l0000;ooooo`;o00006oooool2o`0004oooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oiRHV?ooooooV9RH
ob4Q8@06ooooo`?o0000=_ooool2o`0000[ooooo1Ol0000@ooooo`;o00000oooool2o`0000?ooooo
1?l00003ooooo`?o00001Oooool4o`000003ooooool0003o000000?o00000_ooool2o`0000;ooooo
0_l00002ooooo`[o00001_ooool3o`0000?ooooo0_l00007ooooo`;o000000?oooooo`000?l00000
1?ooool2o`0000kooooo0_l00004ooooo`?o0000Q?ooool00003ooooool0003ooooo00;ooooo00?o
0000ooooooooool02Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0
=_ooool2o`0000[ooooo0_l0000Cooooo`?o00000_ooool2o`0000?ooooo0_l0000=ooooo`Ko0000
3oooool7o`0000Wooooo0_l0000<ooooo`;o000000?oooooo`000?l000001?ooool2o`0000kooooo
0_l00004ooooo`Ko00001?ooool2o`000004ooooool0003o0000o`0007Oooooo00000ooooooo410@
ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003ooooo
ooooo`0fooooo`;o00003Oooool2o`00017ooooo0_l00005ooooo`;o00000_ooool2o`0000Gooooo
0_l00004ooooo`;o00000_ooool2o`0000Oooooo0_l00007ooooo`Oo00002Oooool2o`0000Kooooo
0_l00006ooooo`;o00007?ooool4o`0000;ooooo1?l000000ooooooo0000o`000004o`0000?ooooo
0_l00004ooooo`;o00006Oooool2o`0004kooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_o
oooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0hooooo`;o00002oooool2o`0001So
oooo0_l00002ooooo`;o00001Oooool2o`0000Cooooo0_l00006ooooo`;o00000oooool2o`0000Wo
oooo1_l000000ooooooo0000o`000003ooooo`Ko00001?ooool2o`0000Kooooo0_l0000Booooo`;o
00001_ooool2o`0000Kooooo0ol00005ooooo`Co00000_ooool2o`0000Cooooo0_l0000Iooooo`;o
0000C_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106
ooooo`03o`000?oooooooooo03Sooooo0_l0000;ooooo`;o00008oooool2o`000003ooooool0003o
000000Wooooo0_l00005ooooo`Go00000_ooool8o`000003ooooool0003o000000;o000000Cooooo
o`000?l0003ooooo0ol0000<ooooo`;o00004_ooool2o`0000?ooooo0_l000001?oooooo0000o`00
0?l00002ooooo`Oo00001_ooool2o`0007?ooooo000Looooo`03o`000?oooooooooo04Gooooo0_l0
000Sooooo`;o000000?oooooo`000?l000001?ooool2o`0000[ooooo1_l000000ooooooo0000o`00
0002ooooo`?o00001?ooool2o`0000?ooooo0ol0000<ooooo`;o00000oooool2o`0000kooooo0_l0
0003oooooaSo00002oooool2o`0006Gooooo000Looooo`03o`000?oooooooooo04gooooo0_l0000M
ooooo`;o00001Oooool2o`0000Kooooo0_l00006ooooo`;o00001Oooool2o`0000[ooooo0_l0000<
ooooo`?o00000oooool2o`0000kooooo1?l00003oooooaOo00001?ooool2o`0000Cooooo0_l0001U
ooooo`007?ooool00ol0003oooooooooo`17ooooo`;o00000oooool3o`0000;ooooo0_l0000Ioooo
o`;o00003?ooool7o`0000Gooooo0_l0000Looooo`?o00005OoooolMo`0000?ooooo0_l0000loooo
o`;o0000;Oooool001cooooo00?o0000ooooooooool0Aoooool2o`0000?ooooo0_l00003ooooo`;o
00006oooool2o`0000Gooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l000000ooooooo
0000o`000002ooooo`?o00003?ooool2o`0000Sooooo0_l000001?oooooo0000o`000?ooool2o`00
00;ooooo0ol0000<ooooob7o00000oooool6o`0003Sooooo0_l0000]ooooo`007?ooool00ol0003o
ooooooooo`1@ooooo`;o00007?ooool2o`0000Gooooo0_l00009ooooo`Co00000oooool2o`000003
ooooool0003o000000?ooooo0_l00004ooooo`;o00000_ooool2o`0000Cooooo1Ol00005ooooo`?o
00003?ooool;o`000003ooooool0003o000000;o00000_ooool?o`0000Gooooo1?l000000ooooooo
0000o`00001Tooooo`007?ooool00ol0003oooooooooo`1?ooooo`?o00009_ooool2o`0000Kooooo
0_l00005ooooo`;o000000?oooooo`000?l000000oooool2o`0000Sooooo0ol00004ooooo`;o0000
00?oooooo`000?l000000oooool2o`0000Oooooo0_l0000<ooooo`Co00000_ooool2o`0000?ooooo
2?l000000ooooooo0000o`000008o`0000Kooooo0_l000000ooooooo0000o`00000aooooo`;o0000
;_ooool001cooooo00?o0000ooooooooool0Coooool2o`0002Oooooo0_l00008ooooo`?o00000_oo
ool2o`000003ooooool0003o000000kooooo0_l00007ooooo`?o00000_ooool3o`0000Kooooo0_l0
0006ooooo`;o00000_ooool=o`000003ooooool0003o000001Co00000_ooool2o`000003ooooool0
003o0000037ooooo0_l0000^ooooo`007?ooool00ol0003oooooooooo`0looooo`;o00002_ooool5
o`0003?ooooo2Ol000000ooooooo0000o`000002o`0000Cooooo0_l00005ooooo`;o00002Oooool2
o`0000?ooooo0_l0000<ooooo`Co00000_oooolTo`0000;ooooo0_l0001Tooooo`007?ooool00ol0
003oooooooooo`0looooo`;o00002_ooool5o`0003?ooooo1?l000000ooooooo0000o`000002oooo
o`Go00001?ooool2o`000003ooooool0003o000000;ooooo0_l00003ooooo`;o00000_ooool2o`00
00Cooooo0ol00006ooooo`Go000000Coooooo`000?l0003o00001OoooolLo`0000?ooooo0_l00005
ooooo`Co0000H?ooool001cooooo00?o0000ooooooooool0B?ooool3o`0003Oooooo0_l000000ooo
oooo0000o`000002ooooo`Ko00001_ooool2o`000003ooooool0003o000000Cooooo0_l00002oooo
o`;o00001?ooool3o`0000Kooooo2Ol00005ooooob;o00000_ooool6o`00063ooooo000Looooo`03
o`000?oooooooooo04oooooo0_l0000aooooo`;o000000?oooooo`000?l000001?ooool4o`0000Wo
oooo0_l00004ooooo`Go00001Oooool2o`000003ooooool0003o000000Wooooo0_l00007ooooob;o
00000_ooool4o`0006;ooooo000Looooo`;o0000D?ooool2o`0002;ooooo0_l0000Gooooo`;o0000
3Oooool2o`0000?ooooo0ol000000ooooooo0000o`000002ooooo`;o000000Coooooo`000?l0003o
00003ooooolIo`0000;ooooo1_l00007ooooo`;o0000H_ooool001cooooo00?o0000ooooooooool0
?_ooool2o`00017ooooo0_l0000Pooooo`;o00003oooool2o`0000Kooooo0_l0000<ooooo`?o0000
1oooool4o`0000Cooooo0_l0000=ooooob;o00000_ooool2o`0006Sooooo000Looooo`03o`000?oo
oooooooo03kooooo0_l00009ooooo`;o00001_ooool2o`00027ooooo0_l0000<ooooo`Ko00004_oo
ool2o`0000Oooooo0_l000000ooooooo0000o`00000=ooooo`Co00000_oooolGo`000003ooooool0
003o000000So00000_ooool4o`0006Kooooo000Looooo`03o`000?oooooooooo03gooooo0_l0000:
ooooo`;o00000oooool2o`000003ooooool0003o0000027ooooo0_l0000:ooooo`Co00000_ooool2
o`0001_ooooo0_l0000<ooooo`;o00000_ooool4o`0000?ooooo0_l000000ooooooo0000o`00000N
o`0000;ooooo0_l0001Vooooo`007?ooool00ol0003oooooooooo`0mooooo`Co00003Oooool2o`00
02Wooooo0ol00003ooooo`?o00000_ooool2o`0001Cooooo0ol00003ooooo`;o00003?ooool2o`00
0003ooooool0003o000000;o00001oooool2o`0000;ooooo0ol000000ooooooo0000o`00000Co`00
0003ooooool0003o000000?o00000oooool2o`0006Gooooo000Looooo`03o`000?oooooooooo03oo
oooo0_l0000;ooooo`Co0000:Oooool3o`0000?ooooo0_l00003ooooo`;o00001_ooool2o`000003
ooooool0003o000000;o00001oooool3o`0000?ooooo0_l00004ooooo`Co00001?ooool3o`0000;o
oooo0_l0000;ooooo`?o000000?oooooo`000?l000005_l00006ooooo`;o0000IOooool001cooooo
00?o0000ooooooooool0?oooool2o`0000_ooooo1?l00007ooooo`;o00003Oooool3o`000003oooo
ool0003o000000Cooooo0_l0000Iooooo`So000000?oooooo`000?l000000ol00007ooooo`;o0000
1?ooool4o`0000Gooooo0_l00003ooooo`;o00002ooooolEo`0000;ooooo1?l0000Qooooo`;o0000
B_ooool001cooooo00?o0000ooooooooool0DOooool2o`0000Cooooo0_l0000=ooooo`?o000000?o
ooooo`000?l000001?ooool2o`000003ooooool0003o000001Kooooo3_l0000Fooooo`;o00000ooo
ool2o`0000[ooooo7Ol0000Pooooo`;o00004_ooool2o`0003Kooooo000Looooo`03o`000?oooooo
oooo04kooooo0_l000000ooooooo0000o`000002ooooo`;o00007?ooool2o`0000Kooooo0_l0000?
ooooo`ko00005Oooool2o`000003ooooool0003o000000cooooo0_l000000ooooooo0000o`000005
o`000003ooooool0003o000000_o00000oooool2o`0001oooooo0_l0000Cooooo`;o0000=_ooool0
01cooooo00?o0000ooooooooool0?oooool2o`0000gooooo0_l00005ooooo`;o00009?ooool2o`00
00Oooooo0_l00002ooooo`;o00000_ooool>o`0001Sooooo0_l0000@oooooaCo00000oooool2o`00
00Gooooo0_l0000Hooooo`;o0000Boooool001cooooo00?o0000ooooooooool0?oooool2o`0003[o
oooo0_l00007ooooo`;o00000_oooolBo`000003ooooool0003o000002Sooooo0ol000000ooooooo
0000o`00000?o`0000Sooooo0_l0000Fooooo`;o0000COooool001cooooo00?o0000ooooooooool0
EOooool2o`0001gooooo0_l0000@ooooo`?o000000?oooooo`000?l000003_l000000ooooooo0000
o`00000Hooooo`;o00000_ooool2o`0000kooooo4Ol00008ooooo`;o00005_ooool2o`0004gooooo
000Looooo`03o`000?oooooooooo05Gooooo0_l00002ooooo`;o00001_ooool2o`0000Cooooo0_l0
000;ooooo`;o00003oooool4o`000003ooooool0003o0000017o00003oooool2o`0000Oooooo0_l0
0002ooooo`;o00003?ooool2o`0000Cooooo1?l00003ooooo`;o00009?ooool2o`0004gooooo000L
ooooo`03o`000?oooooooooo05Gooooo0ol000000ooooooo0000o`000006ooooo`;o00001?ooool2
o`0000_ooooo0_l0000?oooooaWo00003_ooool2o`0001Wooooo0_l00005ooooo`;o000000?ooooo
o`000?l00000M_ooool001cooooo00?o0000ooooooooool0A?ooool2o`00013ooooo0_l0000Koooo
o`?o00003?ooool2o`0000;ooooo6ol0000=ooooo`;o00004Oooool2o`0000Wooooo1?l000001?oo
oooo0000o`000?l0001eooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00004_ooool2o`00
01Wooooo0_l0000=ooooo`;o00001?oooolDo`000003ooooool0003o000000;o00003Oooool2o`00
017ooooo1?l00007ooooo`;o00001?ooool2o`0007Gooooo000Looooo`;o0000Aoooool2o`00013o
oooo0_l000000ooooooo0000o`00000Xooooo`;o000000?oooooo`000?l000005?l0000;ooooo`;o
00005_ooool4o`0002oooooo0_l0000Eooooo`;o0000??ooool001cooooo00?o0000ooooooooool0
A_ooool2o`0001?ooooo0_l000001?oooooo0000o`000?l0000Soooooa_o00001Oooool2o`0000?o
oooo0_l0000Mooooo`;o0000:_ooool2o`0001Gooooo0_l0000looooo`007?ooool00ol0003ooooo
ooooo`16ooooo`;o000000?oooooo`000?l000004oooool5o`0000Wooooo0_l0000>ooooo`;o0000
1_oooolMo`0000;ooooo0ol0000Qooooo`?o00003Oooool4o`0001Wooooo0_l0001Cooooo`007?oo
ool00ol0003oooooooooo`16ooooo`;o000000?oooooo`000?l000005?ooool4o`0000;ooooo0_l0
00000ooooooo0000o`000005o`000004ooooool0003o0000o`0000Wooooo0_l00006ooooo`?o0000
00?oooooo`000?l000005ol00002ooooo`;o00001oooool2o`0001Wooooo0_l0000>ooooo`Co0000
K_ooool001cooooo00?o0000ooooooooool0BOooool4o`0000gooooo0_l00004ooooo`;o00000ooo
ool2o`000003ooooool0003o000000[o00004?oooolMo`000004ooooool0003o0000o`0000Oooooo
0_l0000Fooooo`;o0000:_ooool2o`0005Oooooo000Looooo`03o`000?oooooooooo04Wooooo1?l0
000=ooooo`?o00001_ooool2o`0000Oooooo0_l000000ooooooo0000o`000003o`0000?ooooo0_l0
0002ooooo`;o00001?ooool2o`000003ooooool0003o000001Wo00000oooool4o`0000Kooooo0_l0
0008ooooo`?o00002oooool2o`0002Sooooo1?l0001Gooooo`007?ooool00ol0003oooooooooo`1K
ooooo`;o00001_ooool2o`0000?ooooo0_l00007ooooo`Co00000_ooool2o`0000;ooooo0_l00002
ooooo`Co000000?oooooo`000?l000006_l00004ooooo`;o00004?ooool3o`0002gooooo0_l00005
ooooo`?o0000FOooool001cooooo00?o0000ooooooooool0B_ooool2o`0001cooooo0_l00009oooo
o`?o000000?oooooo`000?l000000oooool2o`000003ooooool0003o000000Cooooo7Ol0000?oooo
o`;o00004oooool2o`00017ooooo0_l00003ooooo`;o00001_ooool2o`0000Gooooo0_l0000Eoooo
o`;o0000@oooool001cooooo00?o0000ooooooooool0B_ooool2o`0001Cooooo0_l00005ooooo`?o
00001?ooool2o`0000?ooooo1Ol00002ooooo`Co00001Oooool2o`0000;ooooo7_l0000<ooooo`;o
000000?oooooo`000?l000001_ooool2o`0000Sooooo0_l0000Aooooo`Co000000?oooooo`000?l0
00009?ooool2o`0004?ooooo000Looooo`03o`000?oooooooooo063ooooo0_l00005ooooo`?o0000
0_ooool9o`000003ooooool0003o000000;ooooo0_l00007ooooo`;o000000Coooooo`000?l0003o
oooo5ol000000ooooooo0000o`000002o`0000oooooo0_l00006ooooo`;o00006oooool4o`0000_o
oooo0_l0001Oooooo`007?ooool00ol0003oooooooooo`1?ooooo`?o00003_ooool2o`0000[ooooo
0_l000000ooooooo0000o`000004o`0000Gooooo0ol00009ooooo`;o00000_oooolFo`000003oooo
ool0003o000000gooooo0_l0000fooooo`;o0000Goooool001cooooo00?o0000ooooooooool0Cooo
ool3o`0001_ooooo0_l000000ooooooo0000o`000005o`0000?ooooo0ol00005ooooo`;o00001_oo
oolEo`0000Wooooo0_l000000ooooooo0000o`000003ooooo`;o0000;oooool2o`0001gooooo0_l0
0017ooooo`007?ooool00ol0003oooooooooo`1]ooooo`;o00000_ooool8o`000004ooooool0003o
0000o`0000Gooooo0_l00002ooooo`;o00001?oooolAo`0000_ooooo2?l0000aooooo`;o000000?o
ooooo`000?l000006_ooool2o`0004Oooooo000Looooo`03o`000?oooooooooo05?ooooo0_l0000M
ooooo`;o000000?oooooo`000?l000000_l000001?oooooo0000o`000?l00003ooooo`;o00001?oo
ool2o`0000Kooooo0_l00002ooooo`?o000000?oooooo`000?l000001?ooool4o`0000[ooooo0_l0
00001Ooooooo0000o`000?l0003ooooo00;o0000<Oooool2o`0006?ooooo000Looooo`03o`000?oo
oooooooo05?ooooo0_l0000Mooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00003?oo
ool:o`0000Cooooo1_l0000?ooooo`;o0000BOooool2o`0004_ooooo000Looooo`03o`000?oooooo
oooo06Sooooo0ol0000<ooooo`Ko00000oooool2o`0000Sooooo0_l00003ooooo`Oo00001_ooool6
o`0000Wooooo1_l0000]ooooo`;o00007?ooool2o`0004_ooooo000Looooo`;o0000JOooool3o`00
00cooooo1?l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l00006oooo
o`;o00001oooool7o`0000Oooooo2?l0000]ooooo`Co0000Ioooool001cooooo00?o0000oooooooo
ool0Moooool4o`0000;ooooo0_l00005ooooo`;o00003?ooool2o`0000?ooooo0_l00002ooooo`Co
00000oooool2o`0000Cooooo1_l0000booooo`;o0000Ioooool001cooooo00?o0000ooooooooool0
FOooool2o`00027ooooo0ol00004ooooo`;o00004?ooool4o`000004ooooool0003o0000ooooo`Oo
00000_ooool4o`0009oooooo000Looooo`03o`000?oooooooooo05Wooooo0ol0000Oooooo`Co0000
1?ooool2o`0000;ooooo0_l0000<ooooo`;o000000?oooooo`000?l000000_l00003ooooo`Go0000
0_ooool3o`000003ooooool0003o000003;ooooo0_l0001Yooooo`007?ooool00ol0003ooooooooo
o`1Jooooo`;o00004?ooool2o`0000Sooooo0_l00003ooooo`;o00002_ooool2o`0000Wooooo0_l0
0004ooooo`;o00001_ooool4o`0000;ooooo1_l00007ooooo`;o0000:Oooool2o`0001Kooooo0_l0
001Aooooo`007?ooool00ol0003oooooooooo`1/ooooo`;o00002?ooool2o`0000Kooooo0_l00008
ooooo`;o00001Oooool2o`000003ooooool0003o000000Cooooo0_l00006ooooo`;o000000Cooooo
o`000?l0003ooooo1_l00007ooooo`;o0000@Oooool2o`00057ooooo000Looooo`03o`000?oooooo
oooo07kooooo0ol00005ooooo`Ko00000oooool2o`0000cooooo0_l00004ooooo`;o00000oooool4
o`0009gooooo000Looooo`03o`000?oooooooooo06oooooo0_l0000>ooooo`;o00001Oooool3o`00
0003ooooool0003o0000017ooooo0_l000000ooooooo0000o`000005ooooo`;o0000X?ooool001co
oooo00?o0000ooooooooool0HOooool2o`0000cooooo0ol00006ooooo`;o00001Oooool2o`0000Ko
oooo0_l0000Gooooo`;o00001Oooool2o`000:3ooooo000Looooo`03o`000?oooooooooo067ooooo
0_l0000=ooooo`;o00001_ooool2o`0001[ooooo0_l00004ooooo`Ko00001_ooool2o`0004Sooooo
0_l0001Gooooo`007?ooool00ol0003oooooooooo`1Tooooo`;o00003?ooool2o`0000cooooo0ol0
0008ooooo`;o00001oooool3o`0000?ooooo1_l00002ooooo`;o00000_ooool2o`0004Oooooo0ol0
001Gooooo`007?ooool00ol0003oooooooooo`1Tooooo`;o00003?ooool2o`0000cooooo0ol00008
ooooo`;o00001?ooool3o`000003ooooool0003o000000?ooooo0_l00006ooooo`;o00000_ooool2
o`0004Oooooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`2=ooooo`?o000000Coooooo`00
0?l0003o00000oooool3o`000004ooooool0003o0000ooooo`;o00001_ooool2o`000:7ooooo000L
ooooo`03o`000?oooooooooo07Kooooo0_l0000:ooooo`;o00002Oooool3o`0000Oooooo0ol00000
1?oooooo0000o`000?ooool2o`000004ooooool0003o0000ooooo`;o0000<?ooool2o`00077ooooo
00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q
8Oo<c<`01_ooool00ol0003oooooooooo`1Xooooo`;o00003?ooool2o`0000[ooooo0_l0000Hoooo
o`Oo000000?oooooo`000?l00000;_ooool4o`00077ooooo00001_ooooooMgMgoiRHV?ooooooV9RH
ogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003ooooooooo
o`1Xooooo`;o00006?ooool2o`0000[ooooo0_l0000<ooooo`Ko000000?oooooo`000?l00000;ooo
ool2o`0001?ooooo0_l0001Nooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`1Yooooo`;o00008ooo
ool2o`0000kooooo1?l000000ooooooo0000o`000014ooooo`;o0000G_ooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool02Oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0
001Yooooo`;o00008oooool2o`00013ooooo1Ol0000/ooooo`;o0000M_ooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool02Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o
0000ooooooooool0Q_ooool2o`0000Kooooo0_l0000<ooooo`;o00001?ooool4o`0000_ooooo0_l0
000Nooooo`;o0000M_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool0
1Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0OOooool2o`0000Oooooo1?l0
0009ooooo`;o00001oooool2o`0000Kooooo0_l0000;ooooo`;o0000U_ooool00006oooooomgMgOo
V9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000oooooooo
ool0KOooool2o`0000kooooo0ol00008ooooo`;o00002Oooool2o`000;Cooooo00001_ooooook^k^
oc8b<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooo
oooo06gooooo1?l0000=ooooo`?o00002_ooool3o`0001cooooo0_l0002Mooooo`007?ooool00ol0
003oooooooooo`1_ooooo`;o00003_ooool2o`0000[ooooo0ol0000Looooo`;o0000WOooool001co
oooo00?o0000ooooooooool0Roooool2o`0000_ooooo0_l0000booooo`;o00004_ooool2o`0006Oo
oooo000Looooo`03o`000?oooooooooo08Cooooo0_l0000Booooo`;o00001?ooool2o`0002cooooo
0_l0000Aooooo`?o0000Ioooool001cooooo00?o0000ooooooooool0Q?ooool2o`0001Sooooo0_l0
00000ooooooo0000o`00000looooo`;o0000J?ooool001cooooo00?o0000ooooooooool0Woooool4
o`00023ooooo0_l00024ooooo`007?ooool00ol0003oooooooooo`2Oooooo`;o00008?ooool4o`00
08Cooooo000Looooo`03o`000?oooooooooo08[ooooo0_l0000Cooooo`;o00001Oooool2o`0000Ko
oooo0_l00008ooooo`;o00001oooool2o`0008Kooooo000Looooo`03o`000?oooooooooo08[ooooo
0_l0000Jooooo`;o00001_ooool2o`0000;ooooo0_l00004ooooo`;o0000Soooool001cooooo00?o
0000ooooooooool0S?ooool2o`0001Cooooo0_l00009ooooo`;o00000oooool2o`0009Gooooo000L
ooooo`03o`000?oooooooooo08cooooo0_l0000Dooooo`;o000000?oooooo`000?l000001?ooool4
o`0000[ooooo0_l00006ooooo`;o000000?oooooo`000?l000001?ooool2o`0007gooooo000Loooo
o`03o`000?oooooooooo0:Gooooo0_l00004ooooo`Co00002_ooool2o`0000?ooooo0_l000000ooo
oooo0000o`000003o`0000Cooooo0_l0001mooooo`007?ooool2o`0008;ooooo0_l0000gooooo`Ko
00000_ooool2o`000003ooooool0003o000000cooooo0_l0001dooooo`007?ooool00ol0003ooooo
ooooo`21ooooo`?o0000=_ooool4o`0000Oooooo0_l0000:ooooo`Co0000M?ooool001cooooo00?o
0000ooooooooool0P_ooool4o`0004_ooooo0_l0001fooooo`007?ooool00ol0003oooooooooo`24
ooooo`;o00005oooool3o`000:Wooooo000Looooo`03o`000?oooooooooo09gooooo0ol000000ooo
oooo0000o`00000Tooooo`;o0000P?ooool001cooooo00?o0000ooooooooool0XOooool2o`0001Ko
oooo0_l00007ooooo`?o00000_ooool2o`00083ooooo000Looooo`03o`000?oooooooooo0:cooooo
0_l00003ooooo`;o000000?oooooo`000?l000000oooool2o`0000Oooooo0ol00024ooooo`007?oo
ool00ol0003oooooooooo`2/ooooo`;o00000oooool2o`000003ooooool0003o000009?ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo09;ooooo
0_l0002eooooo`007?ooool00ol0003oooooooooo`2Booooo`Co0000/oooool001cooooo00?o0000
ooooooooool0U?ooool2o`000;?ooooo000Looooo`03o`000?oooooooooo09Sooooo0_l0002_oooo
o`007?ooool00ol0003oooooooooo`2Hooooo`;o0000[oooool001cooooo0_l0003ooooood_ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0Xoooool2
o`000:Cooooo000Looooo`03o`000?oooooooooo0:?ooooo0_l0002Tooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo
00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool0
01Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;o
oooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooo
oomBooooo`004_ooool00omEEEGoIVIVo`00003ooooooeCooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo002Uooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool0
5oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Goc<c<
ob4Q8Ol0003o8B4Qolc<c02@ooooo`00Y_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l0
000<ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ob4Q
8OnHV9SooooooiRHV?lQ8B40T?ooool00:Kooooo00Go0000ooooooooooooooooo`00000Hooooo`Go
00000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go0000ooooooooooooooooo`00002@
ooooo`00Y_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l00009ooooo`04odA4A?oMgMgo
ooooo`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`05oc8b<_nHV9SooooooiRHV?lb
<S80T?ooool00:Kooooo00Go0000ohN7QoooooooZJVYo`00000Hooooo`04omgMgOmEEEGoooooo`00
00Cooooo00Go0000ooooooooooooooooo`000003ooooo`05olc<c?l0003o0000o`000?o<c<`0T?oo
ool00:Gooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Gooooo`03ogMgMoo<c<co
000000Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?nj^[[ooooookZj^_l@4100
T?ooool00<Cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00Go0000okZj^_oooooo^[Zjo`00002@ooooo`00aOooool00omgMgOo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool01OnYZJWo410@o`000?l@413oZJVY093ooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(414) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.35261 .45086 Mdot
.31669 .47372 Mdot
.60458 .69574 Mdot
.49067 .37776 Mdot
.74706 .48567 Mdot
.60697 .66215 Mdot
.45171 .7083 Mdot
.455 .70668 Mdot
.61588 .6495 Mdot
.26881 .35712 Mdot
.41971 .70151 Mdot
.5756 .38845 Mdot
.43804 .7022 Mdot
.51778 .37271 Mdot
.45011 .46887 Mdot
.50163 .32172 Mdot
.2983 .47591 Mdot
.75545 .53295 Mdot
.52031 .31265 Mdot
.64197 .69719 Mdot
.56039 .24103 Mdot
.52925 .36604 Mdot
.35204 .49732 Mdot
.51986 .36992 Mdot
.5314 .33615 Mdot
.32778 .48725 Mdot
.36124 .45462 Mdot
.53615 .34068 Mdot
.56514 .38759 Mdot
.42341 .69955 Mdot
.57552 .59832 Mdot
.47897 .17667 Mdot
.47444 .39792 Mdot
.41265 .27867 Mdot
.45462 .71705 Mdot
.40412 .64811 Mdot
.64115 .68532 Mdot
.41109 .67249 Mdot
.45401 .72183 Mdot
.43846 .73061 Mdot
.42672 .72377 Mdot
.3333 .49033 Mdot
.41199 .71969 Mdot
.52584 .81481 Mdot
.50122 .3732 Mdot
.41991 .44657 Mdot
.47496 .80148 Mdot
.56207 .3479 Mdot
.30403 .4767 Mdot
.63415 .70405 Mdot
.73736 .423 Mdot
.43063 .66686 Mdot
.42984 .58742 Mdot
.70773 .81377 Mdot
.43122 .71072 Mdot
.5407 .31972 Mdot
.63523 .6477 Mdot
.53053 .39374 Mdot
.48693 .37763 Mdot
.40552 .25049 Mdot
.54444 .37958 Mdot
.73348 .52452 Mdot
.28531 .47732 Mdot
.63945 .63766 Mdot
.61005 .64915 Mdot
.41069 .67471 Mdot
.33732 .51207 Mdot
.43503 .6916 Mdot
.55372 .40436 Mdot
.61933 .70145 Mdot
.56765 .37665 Mdot
.42079 .6963 Mdot
.3656 .48108 Mdot
.49988 .36777 Mdot
.33955 .68997 Mdot
.43417 .78072 Mdot
.60329 .62089 Mdot
.49296 .22642 Mdot
.80774 .46609 Mdot
.5738 .56982 Mdot
.51177 .36163 Mdot
.7406 .73067 Mdot
.51209 .51347 Mdot
.31789 .46255 Mdot
.32843 .53572 Mdot
.29699 .55753 Mdot
.55461 .34418 Mdot
.54419 .59944 Mdot
.48897 .34429 Mdot
.67289 .53967 Mdot
.63457 .65344 Mdot
.33011 .45727 Mdot
.50281 .36804 Mdot
.52304 .41429 Mdot
.23685 .41861 Mdot
.57799 .34738 Mdot
.49114 .3686 Mdot
.31513 .53989 Mdot
.41509 .69677 Mdot
.4909 .30092 Mdot
.7137 .45745 Mdot
.40221 .56347 Mdot
.54557 .32332 Mdot
.63378 .6729 Mdot
.29009 .45717 Mdot
.49618 .35178 Mdot
.44621 .69142 Mdot
.51722 .36216 Mdot
.44437 .73994 Mdot
.30799 .50287 Mdot
.4952 .41084 Mdot
.75465 .51379 Mdot
.59604 .29068 Mdot
.34699 .49622 Mdot
.39554 .38676 Mdot
.54334 .36858 Mdot
.5365 .39687 Mdot
.31421 .47717 Mdot
.62716 .69735 Mdot
.64988 .7504 Mdot
.35882 .4891 Mdot
.4388 .73114 Mdot
.30086 .4692 Mdot
.60184 .36254 Mdot
.63519 .69574 Mdot
.4132 .56 Mdot
.40981 .55652 Mdot
.67137 .39277 Mdot
.50485 .36154 Mdot
.61892 .31808 Mdot
.62363 .66922 Mdot
.32302 .49213 Mdot
.42997 .69774 Mdot
.55052 .31677 Mdot
.3486 .48393 Mdot
.45657 .69985 Mdot
.71367 .49858 Mdot
.77036 .51281 Mdot
.31871 .49843 Mdot
.38802 .41985 Mdot
.44468 .74696 Mdot
.42464 .72671 Mdot
.73278 .42216 Mdot
.31657 .46312 Mdot
.74056 .50956 Mdot
.45142 .68488 Mdot
.69962 .29756 Mdot
.48335 .38205 Mdot
.69695 .41787 Mdot
.6982 .75498 Mdot
.7372 .42331 Mdot
.45861 .20284 Mdot
.75178 .51092 Mdot
.45712 .69714 Mdot
.57006 .36202 Mdot
.33835 .47321 Mdot
.34383 .48635 Mdot
.54422 .40414 Mdot
.50713 .3469 Mdot
.50878 .3824 Mdot
.48506 .36604 Mdot
.49816 .66146 Mdot
.50622 .36667 Mdot
.23245 .64719 Mdot
.34727 .47481 Mdot
.51926 .33557 Mdot
.62322 .6888 Mdot
.45988 .34968 Mdot
.4064 .69928 Mdot
.48799 .37945 Mdot
.51496 .34281 Mdot
.58157 .33641 Mdot
.44389 .73184 Mdot
.33046 .70325 Mdot
.82117 .44693 Mdot
.39555 .67162 Mdot
.40849 .78334 Mdot
.61312 .67487 Mdot
.55099 .37613 Mdot
.72937 .50096 Mdot
.47729 .31899 Mdot
.49596 .39897 Mdot
.74659 .42554 Mdot
.5184 .34965 Mdot
.48007 .20614 Mdot
.53098 .43005 Mdot
.31991 .56471 Mdot
.21611 .59375 Mdot
.48992 .39415 Mdot
.30444 .34701 Mdot
.68644 .42759 Mdot
.64639 .61369 Mdot
.42684 .70107 Mdot
.60221 .6855 Mdot
.61713 .69656 Mdot
.4169 .66335 Mdot
.41731 .37582 Mdot
.2853 .33835 Mdot
.57521 .3681 Mdot
.40619 .56404 Mdot
.32041 .52278 Mdot
.75006 .5141 Mdot
.31578 .49637 Mdot
.77065 .70175 Mdot
.59928 .55776 Mdot
.54581 .58737 Mdot
.75273 .5408 Mdot
.64885 .7009 Mdot
.4149 .56703 Mdot
.7352 .50551 Mdot
.50621 .3927 Mdot
.30627 .49765 Mdot
.6975 .42387 Mdot
.47627 .32527 Mdot
.16339 .41857 Mdot
.36348 .45922 Mdot
.64658 .3909 Mdot
.43233 .70777 Mdot
.60059 .63651 Mdot
.55384 .34357 Mdot
.52867 .38317 Mdot
.32035 .51447 Mdot
.56672 .36774 Mdot
.53385 .56375 Mdot
.51395 .34569 Mdot
.63955 .63877 Mdot
.78553 .54327 Mdot
.39876 .6782 Mdot
.72274 .54903 Mdot
.36271 .48668 Mdot
.36336 .78938 Mdot
.63468 .68065 Mdot
.46191 .31915 Mdot
.42896 .68695 Mdot
.71765 .49575 Mdot
.64101 .67298 Mdot
.75209 .52934 Mdot
.49587 .40848 Mdot
.64545 .68001 Mdot
.74072 .52483 Mdot
.50661 .56636 Mdot
.49306 .35624 Mdot
.66852 .33865 Mdot
.44203 .67208 Mdot
.31813 .45452 Mdot
.51071 .40648 Mdot
.42687 .59271 Mdot
.58642 .33184 Mdot
.62944 .4388 Mdot
.42529 .58783 Mdot
.39945 .57616 Mdot
.55194 .55372 Mdot
.7055 .51607 Mdot
.36899 .71779 Mdot
.52434 .59315 Mdot
.29812 .47639 Mdot
.50797 .41095 Mdot
.3877 .61337 Mdot
.44771 .67508 Mdot
.51262 .395 Mdot
.36293 .59386 Mdot
.45256 .68593 Mdot
.53073 .39775 Mdot
.42901 .7237 Mdot
.34436 .48034 Mdot
.51165 .53585 Mdot
.31147 .45196 Mdot
.4961 .38863 Mdot
.42415 .71821 Mdot
.6069 .68943 Mdot
.32858 .48683 Mdot
.52285 .36182 Mdot
.52723 .35264 Mdot
.40457 .56986 Mdot
.49819 .35768 Mdot
.34329 .55663 Mdot
.55931 .34475 Mdot
.62122 .70543 Mdot
.57535 .36256 Mdot
.72326 .44781 Mdot
.67912 .50628 Mdot
.31412 .5092 Mdot
.4244 .58828 Mdot
.6427 .65863 Mdot
.50655 .54564 Mdot
.64974 .33207 Mdot
.51106 .36672 Mdot
.4169 .58561 Mdot
.64855 .40829 Mdot
.40707 .69937 Mdot
.46906 .39939 Mdot
.56504 .69971 Mdot
.63644 .65702 Mdot
.40959 .56381 Mdot
.496 .30523 Mdot
.37672 .47945 Mdot
.55255 .32359 Mdot
.64064 .6829 Mdot
.31861 .45117 Mdot
.57343 .33611 Mdot
.45473 .78697 Mdot
.427 .59389 Mdot
.41397 .70514 Mdot
.32744 .54458 Mdot
.55194 .38768 Mdot
.60581 .69309 Mdot
.34482 .49028 Mdot
.43781 .71659 Mdot
.35123 .49501 Mdot
.69976 .43057 Mdot
.63013 .42133 Mdot
.45707 .60305 Mdot
.7103 .53663 Mdot
.65432 .20372 Mdot
.39147 .678 Mdot
.48476 .30727 Mdot
.56643 .65439 Mdot
.21606 .49741 Mdot
.63728 .66939 Mdot
.38355 .42095 Mdot
.63461 .65035 Mdot
.55876 .33258 Mdot
.60621 .65772 Mdot
.21971 .43231 Mdot
.53394 .34465 Mdot
.60135 .65091 Mdot
.51187 .6527 Mdot
.53227 .34664 Mdot
.35066 .48325 Mdot
.37896 .19115 Mdot
.43537 .29766 Mdot
.42909 .32139 Mdot
.63314 .64364 Mdot
.35069 .40963 Mdot
.54151 .34093 Mdot
.52966 .3101 Mdot
.33389 .475 Mdot
.58749 .34596 Mdot
.71021 .5276 Mdot
.74535 .53465 Mdot
.72555 .36353 Mdot
.55482 .21297 Mdot
.4138 .37265 Mdot
.3355 .48586 Mdot
.8206 .48652 Mdot
.3348 .68433 Mdot
.42753 .59317 Mdot
.45589 .70476 Mdot
.34932 .72128 Mdot
.49048 .32278 Mdot
.26015 .45801 Mdot
.53043 .5596 Mdot
.34097 .4541 Mdot
.47455 .58792 Mdot
.44291 .71626 Mdot
.42954 .31632 Mdot
.29184 .31463 Mdot
.5078 .38389 Mdot
.41877 .67394 Mdot
.58258 .38256 Mdot
.53679 .59609 Mdot
.67177 .37161 Mdot
.52033 .75472 Mdot
.49665 .3865 Mdot
.36048 .69515 Mdot
.50045 .40167 Mdot
.67616 .39772 Mdot
.5095 .39637 Mdot
.35492 .48473 Mdot
.57106 .31525 Mdot
.51784 .59116 Mdot
.69361 .24015 Mdot
.59769 .55061 Mdot
.73568 .53244 Mdot
.52053 .37421 Mdot
.517 .38789 Mdot
.73315 .52644 Mdot
.33666 .45586 Mdot
.51571 .41001 Mdot
.44286 .8173 Mdot
.5063 .36523 Mdot
.42864 .66537 Mdot
.60311 .48249 Mdot
.52907 .19101 Mdot
.55372 .35594 Mdot
.37457 .48418 Mdot
.42029 .72186 Mdot
.43661 .68039 Mdot
.4967 .44663 Mdot
.43942 .66991 Mdot
.56888 .366 Mdot
.60178 .48321 Mdot
.33372 .5076 Mdot
.47512 .43023 Mdot
.34812 .45654 Mdot
.82493 .49995 Mdot
.45514 .68687 Mdot
.41867 .59096 Mdot
.40756 .38951 Mdot
.44841 .70077 Mdot
.71715 .56324 Mdot
.56647 .31361 Mdot
.45934 .38547 Mdot
.37193 .52705 Mdot
.60096 .68734 Mdot
.42076 .57989 Mdot
.43248 .7129 Mdot
.50512 .36962 Mdot
.53039 .32572 Mdot
.43098 .66869 Mdot
.37885 .2291 Mdot
.5776 .59804 Mdot
.49516 .38875 Mdot
.35471 .47339 Mdot
.32598 .49242 Mdot
.49363 .34405 Mdot
.5046 .40485 Mdot
.6002 .66981 Mdot
.41783 .58597 Mdot
.42289 .58593 Mdot
.40482 .55717 Mdot
.61771 .63532 Mdot
.66111 .21112 Mdot
.42309 .72592 Mdot
.49248 .17877 Mdot
.33496 .63875 Mdot
.55812 .43276 Mdot
.62653 .69357 Mdot
.53648 .38101 Mdot
.54795 .32893 Mdot
.42401 .71606 Mdot
.64618 .2252 Mdot
.53781 .31157 Mdot
.33687 .44982 Mdot
.42471 .66859 Mdot
.58451 .37157 Mdot
.44637 .75053 Mdot
.74701 .49589 Mdot
.40892 .36729 Mdot
.4394 .66868 Mdot
.32519 .50683 Mdot
.43887 .66839 Mdot
.51409 .38637 Mdot
.49629 .30412 Mdot
.34447 .45396 Mdot
.76457 .49824 Mdot
.53437 .40893 Mdot
.52653 .40021 Mdot
.69351 .69044 Mdot
.3419 .68944 Mdot
.69809 .54457 Mdot
.56248 .34095 Mdot
.45776 .39276 Mdot
.76583 .50633 Mdot
.54072 .40214 Mdot
.57531 .35875 Mdot
.61741 .3115 Mdot
.43812 .74197 Mdot
.70438 .50264 Mdot
.68448 .23889 Mdot
.362 .45753 Mdot
.36339 .55979 Mdot
.40643 .56049 Mdot
.42028 .65354 Mdot
.50338 .53338 Mdot
.41221 .57137 Mdot
.34184 .61992 Mdot
.29319 .75753 Mdot
.41869 .57968 Mdot
.62503 .63279 Mdot
.27718 .40752 Mdot
.57054 .37416 Mdot
.49991 .39754 Mdot
.70725 .51883 Mdot
.3106 .47549 Mdot
.23299 .63901 Mdot
.40259 .66384 Mdot
.53752 .36804 Mdot
.36599 .45517 Mdot
.30444 .56078 Mdot
.40916 .56685 Mdot
.73698 .49879 Mdot
.75598 .48921 Mdot
.50785 .40433 Mdot
.65658 .37925 Mdot
.33269 .48784 Mdot
.52286 .3619 Mdot
.54124 .39537 Mdot
.65206 .67001 Mdot
.30618 .49603 Mdot
.6243 .68682 Mdot
.41678 .59923 Mdot
.19697 .48189 Mdot
.55103 .84397 Mdot
.44235 .67382 Mdot
.45115 .52196 Mdot
.40034 .67568 Mdot
.48591 .76609 Mdot
.41891 .58613 Mdot
.52572 .36346 Mdot
.35557 .49873 Mdot
.5194 .36149 Mdot
.5048 .36625 Mdot
.49872 .38058 Mdot
.41365 .37069 Mdot
.80582 .47567 Mdot
.7177 .50525 Mdot
.55976 .37743 Mdot
.63485 .64181 Mdot
.34747 .57123 Mdot
.22672 .38407 Mdot
.52274 .37941 Mdot
.53541 .3975 Mdot
.34724 .51032 Mdot
.48453 .40119 Mdot
.45262 .70014 Mdot
.33362 .45272 Mdot
.5376 .32249 Mdot
.72337 .45725 Mdot
.51848 .40904 Mdot
.45253 .5354 Mdot
.45739 .67903 Mdot
.54402 .29641 Mdot
.48898 .41938 Mdot
.41953 .58722 Mdot
.42002 .57849 Mdot
.4167 .60529 Mdot
.41871 .66788 Mdot
.6508 .66812 Mdot
.64 .63264 Mdot
.5019 .42056 Mdot
.5685 .35412 Mdot
.47698 .32662 Mdot
.62528 .7102 Mdot
.52748 .609 Mdot
.39549 .42731 Mdot
.56384 .40876 Mdot
.60402 .64115 Mdot
.31881 .54176 Mdot
.52302 .2304 Mdot
.32605 .45379 Mdot
.56999 .66914 Mdot
.43931 .68514 Mdot
.75322 .52137 Mdot
.71974 .38999 Mdot
.35801 .48716 Mdot
.36363 .49449 Mdot
.60482 .6703 Mdot
.57392 .48881 Mdot
.76918 .76588 Mdot
.62878 .66756 Mdot
.5427 .58101 Mdot
.33395 .47897 Mdot
.47511 .38904 Mdot
.64697 .42118 Mdot
.55755 .48907 Mdot
.60746 .64554 Mdot
.52601 .3533 Mdot
.7018 .57221 Mdot
.59995 .66906 Mdot
.46572 .35537 Mdot
.63296 .64297 Mdot
.41251 .69355 Mdot
.62608 .6734 Mdot
.35379 .44585 Mdot
.5093 .35966 Mdot
.72547 .80025 Mdot
.50152 .5152 Mdot
.53235 .35817 Mdot
.43861 .66721 Mdot
.52465 .68002 Mdot
.50938 .38918 Mdot
.72273 .53544 Mdot
.63528 .64019 Mdot
.50319 .75891 Mdot
.5699 .33953 Mdot
.60293 .65842 Mdot
.37782 .45993 Mdot
.58141 .69178 Mdot
.70358 .46143 Mdot
.42236 .58265 Mdot
.34392 .47684 Mdot
.38302 .68931 Mdot
.43202 .72861 Mdot
.51828 .3212 Mdot
.54485 .38959 Mdot
.34851 .47071 Mdot
.50251 .55462 Mdot
.49795 .44342 Mdot
.51065 .36293 Mdot
.60995 .68062 Mdot
.65911 .68266 Mdot
.45018 .46431 Mdot
.63674 .68087 Mdot
.45834 .39558 Mdot
.35179 .47652 Mdot
.54907 .32117 Mdot
.34277 .49496 Mdot
.51034 .4115 Mdot
.45769 .75328 Mdot
.31799 .45789 Mdot
.48623 .29592 Mdot
.50705 .35866 Mdot
.39267 .49768 Mdot
.55345 .38348 Mdot
.49444 .38134 Mdot
.65931 .67103 Mdot
.72486 .51756 Mdot
.46985 .39637 Mdot
.44601 .77483 Mdot
.76082 .50114 Mdot
.42091 .21042 Mdot
.63538 .69539 Mdot
.73513 .48797 Mdot
.70865 .34934 Mdot
.42455 .58732 Mdot
.72171 .52264 Mdot
.39526 .54657 Mdot
.43439 .67152 Mdot
.32278 .43789 Mdot
.52733 .34843 Mdot
.20245 .47121 Mdot
.57259 .59927 Mdot
.40573 .57534 Mdot
.52169 .40562 Mdot
.53402 .38521 Mdot
.36671 .45636 Mdot
.76164 .71076 Mdot
.66177 .66276 Mdot
.49028 .36306 Mdot
.36198 .48336 Mdot
.72187 .74292 Mdot
.60134 .64947 Mdot
.71947 .49953 Mdot
.46244 .70846 Mdot
.30792 .51568 Mdot
.41983 .59232 Mdot
.45608 .68971 Mdot
.58981 .6241 Mdot
.75223 .42711 Mdot
.55926 .3295 Mdot
.62552 .69116 Mdot
.73879 .42379 Mdot
.47907 .43177 Mdot
.4086 .66932 Mdot
.41288 .77211 Mdot
.32507 .46018 Mdot
.4299 .6686 Mdot
.71246 .52572 Mdot
.29978 .48799 Mdot
.34488 .45538 Mdot
.45208 .69478 Mdot
.20495 .56305 Mdot
.64719 .41024 Mdot
.44476 .66176 Mdot
.6293 .44405 Mdot
.7384 .42467 Mdot
.40911 .58681 Mdot
.7393 .4997 Mdot
.81398 .50806 Mdot
.3314 .48974 Mdot
.34707 .71889 Mdot
.73926 .42309 Mdot
.49106 .3684 Mdot
.74222 .52538 Mdot
.35697 .56879 Mdot
.43266 .63929 Mdot
.4551 .69398 Mdot
.67974 .70462 Mdot
.74693 .52616 Mdot
.49066 .40093 Mdot
.56414 .18491 Mdot
.54595 .35035 Mdot
.44965 .68155 Mdot
.53198 .56142 Mdot
.30957 .4995 Mdot
.40697 .70415 Mdot
.53434 .56385 Mdot
.55401 .33188 Mdot
.54408 .3645 Mdot
.79467 .50916 Mdot
.30287 .48587 Mdot
.41341 .59556 Mdot
.52058 .35723 Mdot
.52898 .39623 Mdot
.51121 .32612 Mdot
.61179 .23695 Mdot
.55878 .2662 Mdot
.50842 .33606 Mdot
.5894 .64789 Mdot
.4832 .31336 Mdot
.48517 .37185 Mdot
.37768 .47671 Mdot
.75618 .45865 Mdot
.41559 .59955 Mdot
.50277 .39862 Mdot
.49607 .39003 Mdot
.45192 .72343 Mdot
.64778 .41031 Mdot
.54979 .49122 Mdot
.63796 .7057 Mdot
.67602 .66784 Mdot
.55598 .40744 Mdot
.34146 .46949 Mdot
.70148 .51728 Mdot
.468 .41967 Mdot
.34362 .4508 Mdot
.53906 .41344 Mdot
.64407 .6482 Mdot
.41664 .58154 Mdot
.47154 .43132 Mdot
.73533 .52164 Mdot
.44044 .7458 Mdot
.4442 .21018 Mdot
.60742 .68746 Mdot
.5428 .33659 Mdot
.65459 .642 Mdot
.62226 .65682 Mdot
.40379 .57162 Mdot
.51309 .2921 Mdot
.34274 .48297 Mdot
.32459 .50551 Mdot
.78051 .45934 Mdot
.62138 .63476 Mdot
.69494 .65875 Mdot
.41339 .68448 Mdot
.55764 .38253 Mdot
.39935 .60428 Mdot
.31938 .50381 Mdot
.67228 .39161 Mdot
.7467 .48773 Mdot
.45409 .69144 Mdot
.40533 .54997 Mdot
.31984 .45534 Mdot
.32322 .50287 Mdot
.50266 .36922 Mdot
.52908 .37268 Mdot
.61821 .61349 Mdot
.68889 .42293 Mdot
.43175 .72433 Mdot
.73147 .49453 Mdot
.6196 .70368 Mdot
.56841 .3438 Mdot
.3198 .46324 Mdot
.5391 .19132 Mdot
.55193 .38681 Mdot
.6351 .64225 Mdot
.31854 .47433 Mdot
.714 .50543 Mdot
.71125 .51993 Mdot
.49232 .37564 Mdot
.49122 .20936 Mdot
.44719 .69747 Mdot
.35218 .4837 Mdot
.34983 .53706 Mdot
.56283 .36918 Mdot
.52406 .37565 Mdot
.58828 .39437 Mdot
.40335 .68743 Mdot
.49445 .43418 Mdot
.76333 .51757 Mdot
.3248 .49645 Mdot
.52535 .35792 Mdot
.73221 .52483 Mdot
.26084 .45586 Mdot
.41185 .57521 Mdot
.59914 .65582 Mdot
.72955 .5361 Mdot
.73379 .51197 Mdot
.75588 .49491 Mdot
.35026 .72077 Mdot
.30057 .43932 Mdot
.79574 .37156 Mdot
.51784 .35504 Mdot
.73835 .42505 Mdot
.49949 .33285 Mdot
.40836 .69294 Mdot
.59573 .67848 Mdot
.50347 .37565 Mdot
.51857 .35458 Mdot
.46314 .21453 Mdot
.50839 .31675 Mdot
.51658 .31188 Mdot
.312 .50356 Mdot
.36508 .53779 Mdot
.61005 .69393 Mdot
.68485 .7632 Mdot
.40678 .16215 Mdot
.57478 .37122 Mdot
.57892 .48767 Mdot
.32712 .45508 Mdot
.45706 .71833 Mdot
.63543 .43824 Mdot
.42125 .62421 Mdot
.31338 .48691 Mdot
.56125 .33493 Mdot
.4418 .21671 Mdot
.75791 .51773 Mdot
.51097 .38316 Mdot
.42994 .69406 Mdot
.50988 .38284 Mdot
.41457 .67128 Mdot
.38673 .43184 Mdot
.5309 .5007 Mdot
.52334 .348 Mdot
.57774 .34941 Mdot
.61554 .31964 Mdot
.52549 .37727 Mdot
.52944 .73935 Mdot
.32389 .47273 Mdot
.47499 .30509 Mdot
.53621 .31734 Mdot
.42792 .29216 Mdot
.53785 .40108 Mdot
.48615 .53019 Mdot
.5483 .37472 Mdot
.65966 .2437 Mdot
.48579 .3943 Mdot
.55066 .37453 Mdot
.43774 .71986 Mdot
.44361 .72972 Mdot
.38264 .48313 Mdot
.40638 .5887 Mdot
.32887 .56642 Mdot
.53004 .39997 Mdot
.65472 .69798 Mdot
.53781 .46911 Mdot
.72812 .51398 Mdot
.32295 .49503 Mdot
.44604 .88418 Mdot
.41543 .71665 Mdot
.62179 .63285 Mdot
.54819 .59493 Mdot
.5877 .64459 Mdot
.56805 .65126 Mdot
.37983 .52514 Mdot
.74193 .49918 Mdot
.5136 .40862 Mdot
.42086 .27697 Mdot
.35279 .68811 Mdot
.56378 .36589 Mdot
.66958 .69107 Mdot
.60317 .42445 Mdot
.77941 .45303 Mdot
.73979 .53837 Mdot
.74752 .50703 Mdot
.43811 .71467 Mdot
.60752 .69647 Mdot
.56806 .40566 Mdot
.73369 .48818 Mdot
.59888 .68089 Mdot
.416 .55681 Mdot
.78944 .49155 Mdot
.33562 .48865 Mdot
.36186 .41089 Mdot
.41735 .47472 Mdot
.41957 .72002 Mdot
.44029 .77818 Mdot
.34675 .43251 Mdot
.29668 .46908 Mdot
.40048 .57542 Mdot
.6081 .64145 Mdot
.32764 .43619 Mdot
.50677 .36193 Mdot
.47578 .32601 Mdot
.50727 .4046 Mdot
.70665 .51551 Mdot
.52993 .40407 Mdot
.59757 .66817 Mdot
.44998 .71724 Mdot
.63824 .65617 Mdot
.45096 .70978 Mdot
.43171 .17986 Mdot
.48774 .3837 Mdot
.52376 .37288 Mdot
.5978 .48438 Mdot
.32135 .50102 Mdot
.40527 .28431 Mdot
.63292 .64084 Mdot
.63739 .65013 Mdot
.54549 .32074 Mdot
.30752 .50869 Mdot
.71313 .55949 Mdot
.63186 .45293 Mdot
.54688 .37965 Mdot
.32414 .47135 Mdot
.54528 .32 Mdot
.48954 .74875 Mdot
.49398 .50239 Mdot
.34923 .49718 Mdot
.69561 .24057 Mdot
.49863 .36354 Mdot
.53474 .28717 Mdot
.5726 .29883 Mdot
.6078 .24356 Mdot
.47093 .38622 Mdot
.36039 .45725 Mdot
.48652 .3697 Mdot
.33598 .46691 Mdot
.62917 .66 Mdot
.41149 .71689 Mdot
.33489 .47028 Mdot
.53852 .34805 Mdot
.41436 .16158 Mdot
.45071 .71815 Mdot
.51061 .37728 Mdot
.42377 .70889 Mdot
.31428 .44382 Mdot
.30748 .48697 Mdot
.4009 .54892 Mdot
.54419 .58309 Mdot
.45138 .6985 Mdot
.56829 .35557 Mdot
.33462 .69851 Mdot
.55028 .32178 Mdot
.67657 .67117 Mdot
.57725 .3332 Mdot
.55295 .40786 Mdot
.65596 .20072 Mdot
.49976 .54709 Mdot
.58032 .84341 Mdot
.4706 .64997 Mdot
.32799 .69852 Mdot
.36484 .52274 Mdot
.74004 .53816 Mdot
.4659 .54219 Mdot
.42632 .5832 Mdot
.58645 .65219 Mdot
.50371 .37226 Mdot
.24843 .48948 Mdot
.43869 .66129 Mdot
.72005 .51404 Mdot
.51901 .34931 Mdot
.57825 .66797 Mdot
.43038 .48535 Mdot
.45592 .69386 Mdot
.33391 .49092 Mdot
.3133 .49391 Mdot
.80714 .45924 Mdot
.52882 .35851 Mdot
.52897 .36843 Mdot
.45261 .71839 Mdot
.56501 .4132 Mdot
.75209 .49445 Mdot
.51278 .65052 Mdot
.42784 .69469 Mdot
.50039 .50675 Mdot
.30575 .49945 Mdot
.53514 .38342 Mdot
.60482 .48107 Mdot
.29454 .68666 Mdot
.24801 .37929 Mdot
.74649 .51508 Mdot
.65357 .3587 Mdot
.36133 .45787 Mdot
.42902 .69967 Mdot
.7167 .35829 Mdot
.55371 .31162 Mdot
.53321 .38812 Mdot
.63921 .29067 Mdot
.63137 .45113 Mdot
.54415 .59164 Mdot
.59386 .39048 Mdot
.65542 .42888 Mdot
.54669 .32121 Mdot
.53185 .32538 Mdot
.54835 .4113 Mdot
.57432 .32687 Mdot
.32668 .46742 Mdot
.42744 .30831 Mdot
.61265 .66771 Mdot
.27224 .3776 Mdot
.68112 .6724 Mdot
.5425 .3422 Mdot
.55661 .33242 Mdot
.33546 .36262 Mdot
.59927 .45465 Mdot
.32695 .47981 Mdot
.35948 .53327 Mdot
.42977 .72912 Mdot
.51771 .31289 Mdot
.62788 .63657 Mdot
.58036 .30849 Mdot
.61553 .65247 Mdot
.32455 .46813 Mdot
.65068 .68256 Mdot
.46843 .70273 Mdot
.62652 .6909 Mdot
.5982 .64302 Mdot
.45942 .70066 Mdot
.30323 .47463 Mdot
.55083 .38128 Mdot
.46026 .69553 Mdot
.72313 .56131 Mdot
.70693 .51602 Mdot
.40329 .54631 Mdot
.47618 .38259 Mdot
.50619 .31103 Mdot
.45 .79183 Mdot
.64672 .68158 Mdot
.5432 .48713 Mdot
.31682 .45928 Mdot
.70241 .51691 Mdot
.3298 .46545 Mdot
.79136 .41376 Mdot
.74033 .51717 Mdot
.39991 .54669 Mdot
.6934 .36016 Mdot
.39605 .68126 Mdot
.58314 .34293 Mdot
.35871 .53787 Mdot
.6202 .65198 Mdot
.42685 .6663 Mdot
.3558 .57064 Mdot
.49714 .35521 Mdot
.43167 .59866 Mdot
.3051 .44805 Mdot
.42433 .58551 Mdot
.43094 .69657 Mdot
.41546 .51717 Mdot
.53531 .36041 Mdot
.39626 .68257 Mdot
.57887 .3471 Mdot
.39201 .40646 Mdot
.65071 .62622 Mdot
.27856 .50856 Mdot
.55534 .32881 Mdot
.60035 .64954 Mdot
.55171 .32519 Mdot
.29373 .4087 Mdot
.69203 .38813 Mdot
.55743 .40689 Mdot
.61757 .42591 Mdot
.46825 .79256 Mdot
.32139 .46254 Mdot
.46641 .4083 Mdot
.40669 .58115 Mdot
.54256 .33292 Mdot
.20117 .31819 Mdot
.7259 .52304 Mdot
.75139 .54472 Mdot
.53386 .34834 Mdot
.51724 .36037 Mdot
.47248 .21492 Mdot
.39208 .45136 Mdot
.40325 .55079 Mdot
.52739 .39137 Mdot
.62187 .2701 Mdot
.43588 .71808 Mdot
.57206 .33321 Mdot
.49403 .39288 Mdot
.66974 .62355 Mdot
.42947 .71603 Mdot
.63614 .69252 Mdot
.42502 .58647 Mdot
.65468 .69168 Mdot
.75257 .4846 Mdot
.65031 .38116 Mdot
.66336 .35881 Mdot
.47733 .4907 Mdot
.72854 .53515 Mdot
.54863 .34464 Mdot
.29061 .51802 Mdot
.5376 .35536 Mdot
.74279 .50466 Mdot
.42326 .69968 Mdot
.32734 .47169 Mdot
.38316 .41837 Mdot
.40392 .56631 Mdot
.55949 .36066 Mdot
.71889 .53868 Mdot
.33846 .475 Mdot
.27089 .68754 Mdot
.31277 .47159 Mdot
.44905 .70883 Mdot
.41642 .66406 Mdot
.73353 .51607 Mdot
.32875 .46486 Mdot
.65495 .6884 Mdot
.47634 .66284 Mdot
.58287 .36067 Mdot
.46891 .70389 Mdot
.358 .43973 Mdot
.37098 .46482 Mdot
.33742 .50947 Mdot
.53556 .31876 Mdot
.60601 .46236 Mdot
.60282 .34968 Mdot
.451 .71882 Mdot
.5809 .66485 Mdot
.69496 .41555 Mdot
.44543 .2515 Mdot
.51628 .50848 Mdot
.46649 .38658 Mdot
.52775 .40454 Mdot
.50931 .40457 Mdot
.50684 .3354 Mdot
.4995 .63895 Mdot
.48792 .38392 Mdot
.42696 .72029 Mdot
.61525 .65872 Mdot
.54399 .38235 Mdot
.41184 .58556 Mdot
.52862 .60652 Mdot
.70057 .50683 Mdot
.40701 .3659 Mdot
.37888 .54039 Mdot
.33647 .47452 Mdot
.63727 .68411 Mdot
.65186 .6837 Mdot
.71364 .49866 Mdot
.4567 .68685 Mdot
.30985 .47868 Mdot
.66298 .24712 Mdot
.76059 .50715 Mdot
.50386 .3989 Mdot
.60048 .48342 Mdot
.59007 .23187 Mdot
.54736 .40362 Mdot
.49859 .38371 Mdot
.41158 .59607 Mdot
.61169 .63336 Mdot
.20029 .41124 Mdot
.21005 .58235 Mdot
.72737 .51789 Mdot
.73142 .49231 Mdot
.35043 .50637 Mdot
.55672 .3869 Mdot
.44554 .69508 Mdot
.65072 .40287 Mdot
.46194 .77588 Mdot
.30161 .5557 Mdot
.48831 .76427 Mdot
.5215 .40874 Mdot
.38583 .3674 Mdot
.58011 .33546 Mdot
.29072 .45594 Mdot
.32398 .51144 Mdot
.33183 .48374 Mdot
.44098 .71814 Mdot
.75572 .42793 Mdot
.42207 .71762 Mdot
.34579 .55058 Mdot
.36363 .46742 Mdot
.51484 .55805 Mdot
.63654 .64804 Mdot
.50016 .32692 Mdot
.74298 .50041 Mdot
.6701 .50827 Mdot
.46502 .40451 Mdot
.65321 .36627 Mdot
.62697 .69353 Mdot
.30995 .45966 Mdot
.50103 .32959 Mdot
.33787 .57106 Mdot
.56948 .49191 Mdot
.48489 .79077 Mdot
.25328 .49196 Mdot
.73585 .5255 Mdot
.2823 .34996 Mdot
.75673 .50065 Mdot
.4536 .68969 Mdot
.49675 .36596 Mdot
.55261 .39038 Mdot
.49401 .38315 Mdot
.557 .31846 Mdot
.4307 .71216 Mdot
.58046 .37003 Mdot
.72443 .4476 Mdot
.41765 .56037 Mdot
.51186 .60577 Mdot
.71384 .52107 Mdot
.41161 .68647 Mdot
.6196 .65755 Mdot
.39875 .57041 Mdot
.70966 .53686 Mdot
.50203 .33437 Mdot
.53924 .35059 Mdot
.41315 .55658 Mdot
.47977 .43588 Mdot
.48819 .32699 Mdot
.60685 .66453 Mdot
.53252 .59565 Mdot
.70936 .49755 Mdot
.75359 .51238 Mdot
.42434 .67153 Mdot
.3299 .46507 Mdot
.71456 .49528 Mdot
.59954 .69319 Mdot
.57008 .33411 Mdot
.57807 .35468 Mdot
.3622 .44281 Mdot
.74351 .42463 Mdot
.69995 .50794 Mdot
.49197 .43366 Mdot
.33264 .49821 Mdot
.30405 .4487 Mdot
.52616 .39089 Mdot
.55705 .4113 Mdot
.35161 .50952 Mdot
.71692 .49788 Mdot
.4184 .67557 Mdot
.53323 .53068 Mdot
.41357 .70861 Mdot
.34255 .4911 Mdot
.47659 .32302 Mdot
.30164 .482 Mdot
.49923 .35298 Mdot
.59365 .85744 Mdot
.488 .39201 Mdot
.48182 .27921 Mdot
.64328 .56909 Mdot
.63068 .64175 Mdot
.61861 .63913 Mdot
.41618 .58353 Mdot
.34065 .45087 Mdot
.46198 .40795 Mdot
.74255 .49714 Mdot
.32852 .6983 Mdot
.37503 .43863 Mdot
.59964 .64287 Mdot
.62824 .63482 Mdot
.42381 .70232 Mdot
.53454 .40296 Mdot
.53771 .38115 Mdot
.62859 .69119 Mdot
.52556 .67383 Mdot
.33863 .46186 Mdot
.52856 .36831 Mdot
.51216 .32936 Mdot
.6137 .6657 Mdot
.43893 .65304 Mdot
.33856 .43326 Mdot
.53307 .31913 Mdot
.68554 .39021 Mdot
.40805 .68482 Mdot
.55223 .34023 Mdot
.58261 .33541 Mdot
.72984 .51009 Mdot
.65174 .33827 Mdot
.73285 .42245 Mdot
.43237 .73339 Mdot
.42149 .58944 Mdot
.541 .40596 Mdot
.62811 .64205 Mdot
.47761 .37211 Mdot
.18892 .64041 Mdot
.42252 .56658 Mdot
.53593 .36307 Mdot
.53932 .42147 Mdot
.34475 .49482 Mdot
.52582 .3618 Mdot
.45587 .75455 Mdot
.61695 .68274 Mdot
.53709 .36332 Mdot
.48999 .21198 Mdot
.42442 .70104 Mdot
.46591 .4048 Mdot
.75006 .52469 Mdot
.53981 .58232 Mdot
.3849 .18964 Mdot
.61882 .70878 Mdot
.72044 .52705 Mdot
.5353 .40119 Mdot
.64469 .70389 Mdot
.46194 .7109 Mdot
.53858 .26507 Mdot
.55153 .34502 Mdot
.41649 .71367 Mdot
.45217 .71376 Mdot
.73168 .51925 Mdot
.53443 .87582 Mdot
.55343 .41008 Mdot
.51598 .38121 Mdot
.38608 .80998 Mdot
.35731 .5074 Mdot
.509 .37881 Mdot
.54288 .39433 Mdot
.44145 .67171 Mdot
.76804 .39218 Mdot
.65325 .35928 Mdot
.5099 .65086 Mdot
.41055 .67804 Mdot
.66703 .68111 Mdot
.61401 .68618 Mdot
.72456 .52816 Mdot
.31767 .47488 Mdot
.70391 .51324 Mdot
.62168 .67371 Mdot
.49604 .38418 Mdot
.4297 .67776 Mdot
.31379 .26571 Mdot
.45366 .6749 Mdot
.59199 .68896 Mdot
.29644 .45131 Mdot
.2264 .43372 Mdot
.20956 .68265 Mdot
.42412 .45586 Mdot
.40118 .68659 Mdot
.72801 .51377 Mdot
.21848 .61409 Mdot
.54488 .38185 Mdot
.34883 .39871 Mdot
.5127 .38252 Mdot
.25039 .47171 Mdot
.59636 .67872 Mdot
.41007 .55313 Mdot
.49712 .35489 Mdot
.65214 .35393 Mdot
.45845 .70052 Mdot
.44011 .68743 Mdot
.48758 .36797 Mdot
.44967 .70641 Mdot
.53811 .37484 Mdot
.6173 .66218 Mdot
.56163 .85992 Mdot
.54914 .36722 Mdot
.50973 .28769 Mdot
.39865 .69493 Mdot
.40659 .54535 Mdot
.66253 .65622 Mdot
.41224 .32555 Mdot
.30583 .56406 Mdot
.44493 .69726 Mdot
.41275 .36684 Mdot
.64458 .67898 Mdot
.39923 .57552 Mdot
.66301 .68283 Mdot
.52162 .38542 Mdot
.52631 .40819 Mdot
.50371 .33936 Mdot
.53836 .39771 Mdot
.31979 .39486 Mdot
.48638 .33278 Mdot
.33109 .29616 Mdot
.51846 .355 Mdot
.47083 .28897 Mdot
.42188 .71542 Mdot
.54079 .28748 Mdot
.55487 .5458 Mdot
.49812 .40678 Mdot
.37277 .52824 Mdot
.41193 .68894 Mdot
.39205 .63052 Mdot
.43076 .71423 Mdot
.63645 .65386 Mdot
.45641 .70391 Mdot
.49833 .36056 Mdot
.32626 .49156 Mdot
.63354 .67855 Mdot
.42516 .43799 Mdot
.58321 .66496 Mdot
.53237 .35826 Mdot
.39176 .69013 Mdot
.64716 .65604 Mdot
.51915 .30739 Mdot
.32261 .4906 Mdot
.64179 .27192 Mdot
.28206 .47893 Mdot
.5189 .36512 Mdot
.51339 .36937 Mdot
.40757 .55339 Mdot
.4571 .69744 Mdot
.30639 .5038 Mdot
.66942 .61687 Mdot
.70361 .52798 Mdot
.32247 .47926 Mdot
.56783 .29451 Mdot
.58119 .48828 Mdot
.34761 .49609 Mdot
.6104 .25457 Mdot
.45143 .68327 Mdot
.36601 .47716 Mdot
.59374 .34146 Mdot
.27946 .37474 Mdot
.75627 .50994 Mdot
.65805 .68132 Mdot
.65073 .44244 Mdot
.61457 .68525 Mdot
.43849 .74993 Mdot
.64231 .64093 Mdot
.42928 .71839 Mdot
.56608 .45871 Mdot
.53285 .56283 Mdot
.44326 .66608 Mdot
.40206 .71078 Mdot
.61 .67197 Mdot
.48946 .35883 Mdot
.51931 .59306 Mdot
.46074 .4087 Mdot
.4675 .34031 Mdot
.41234 .70984 Mdot
.36648 .46598 Mdot
.29945 .48011 Mdot
.45946 .3249 Mdot
.31371 .49883 Mdot
.63302 .66965 Mdot
.46344 .47838 Mdot
.40758 .39097 Mdot
.42287 .69483 Mdot
.54748 .59992 Mdot
.55217 .32778 Mdot
.59999 .66081 Mdot
.63407 .66643 Mdot
.45036 .71451 Mdot
.26336 .39328 Mdot
.45936 .37919 Mdot
.3726 .49371 Mdot
.363 .47986 Mdot
.34988 .49408 Mdot
.31214 .51033 Mdot
.75846 .42674 Mdot
.42666 .66648 Mdot
.3485 .45259 Mdot
.5537 .3188 Mdot
.54827 .39567 Mdot
.41976 .57199 Mdot
.71338 .50417 Mdot
.55173 .31219 Mdot
.46233 .40911 Mdot
.52762 .3898 Mdot
.63344 .64308 Mdot
.62627 .37554 Mdot
.41802 .56205 Mdot
.62132 .63428 Mdot
.62299 .63567 Mdot
.42009 .58754 Mdot
.5774 .45174 Mdot
.20776 .40929 Mdot
.4899 .3668 Mdot
.38032 .52758 Mdot
.61646 .64101 Mdot
.66383 .4915 Mdot
.444 .32657 Mdot
.56865 .36387 Mdot
.5184 .63199 Mdot
.624 .66324 Mdot
.36267 .52178 Mdot
.52337 .38153 Mdot
.40118 .57512 Mdot
.75452 .51758 Mdot
.59136 .30004 Mdot
.4104 .59463 Mdot
.32837 .46163 Mdot
.68917 .6891 Mdot
.36661 .45579 Mdot
.65367 .6664 Mdot
.46386 .40456 Mdot
.74932 .78224 Mdot
.62324 .65228 Mdot
.334 .71091 Mdot
.53323 .56489 Mdot
.54598 .36388 Mdot
.62803 .68573 Mdot
.37881 .45399 Mdot
.40739 .68594 Mdot
.60789 .46948 Mdot
.31931 .46424 Mdot
.39851 .56848 Mdot
.41869 .57392 Mdot
.61216 .66683 Mdot
.35965 .479 Mdot
.58315 .35084 Mdot
.31329 .49203 Mdot
.43142 .68121 Mdot
.51534 .34214 Mdot
.32712 .56615 Mdot
.51118 .29248 Mdot
.31791 .4953 Mdot
.58293 .6754 Mdot
.76523 .50054 Mdot
.53792 .34519 Mdot
.38336 .61292 Mdot
.53756 .40052 Mdot
.423 .70627 Mdot
.64066 .54235 Mdot
.31736 .26673 Mdot
.50687 .39613 Mdot
.55263 .32913 Mdot
.46685 .70514 Mdot
.50827 .39543 Mdot
.56143 .39402 Mdot
.41445 .51569 Mdot
.34527 .49694 Mdot
.54183 .3856 Mdot
.60542 .68384 Mdot
.3825 .2168 Mdot
.49712 .3701 Mdot
.45783 .75552 Mdot
.63465 .27438 Mdot
.62285 .51869 Mdot
.45494 .37108 Mdot
.67235 .39379 Mdot
.51416 .37295 Mdot
.56657 .36858 Mdot
.48906 .36711 Mdot
.38346 .37455 Mdot
.61652 .67455 Mdot
.59514 .65395 Mdot
.74931 .53001 Mdot
.63432 .27905 Mdot
.74486 .52055 Mdot
.46502 .6956 Mdot
.54714 .59202 Mdot
.40999 .55786 Mdot
.33177 .46523 Mdot
.49718 .37303 Mdot
.58537 .66873 Mdot
.533 .38295 Mdot
.54492 .33372 Mdot
.62885 .67043 Mdot
.62988 .66271 Mdot
.61337 .70851 Mdot
.75911 .51678 Mdot
.33066 .47775 Mdot
.49225 .3695 Mdot
.76113 .5019 Mdot
.50956 .32983 Mdot
.53419 .51852 Mdot
.32979 .47958 Mdot
.31747 .49622 Mdot
.30419 .45721 Mdot
.55049 .35853 Mdot
.50165 .35323 Mdot
.42157 .71737 Mdot
.3614 .44232 Mdot
.45009 .6937 Mdot
.62607 .6861 Mdot
.60048 .66633 Mdot
.52074 .38571 Mdot
.5524 .42064 Mdot
.71172 .51679 Mdot
.64889 .67185 Mdot
.42516 .59617 Mdot
.74919 .52856 Mdot
.50836 .40606 Mdot
.61983 .68646 Mdot
.71234 .52935 Mdot
.24043 .39505 Mdot
.2603 .5452 Mdot
.75764 .52468 Mdot
.48757 .36601 Mdot
.44881 .24186 Mdot
.69425 .39686 Mdot
.69671 .51744 Mdot
.41974 .70656 Mdot
.54802 .38817 Mdot
.4987 .66078 Mdot
.73706 .48677 Mdot
.72803 .41845 Mdot
.62868 .67463 Mdot
.48379 .30914 Mdot
.6081 .32473 Mdot
.40885 .40056 Mdot
.76264 .49434 Mdot
.32032 .4955 Mdot
.35618 .49634 Mdot
.5038 .39769 Mdot
.5441 .58734 Mdot
.46279 .68455 Mdot
.65164 .68458 Mdot
.59054 .65727 Mdot
.34755 .50068 Mdot
.4823 .49465 Mdot
.60806 .68542 Mdot
.55893 .38176 Mdot
.73535 .48095 Mdot
.52256 .31135 Mdot
.79271 .44589 Mdot
.36381 .21271 Mdot
.45813 .35627 Mdot
.76607 .50593 Mdot
.46025 .70973 Mdot
.44355 .72002 Mdot
.44521 .71435 Mdot
.60285 .671 Mdot
.63854 .43763 Mdot
.58982 .66715 Mdot
.34312 .76899 Mdot
.72811 .52512 Mdot
.67932 .27455 Mdot
.56678 .31855 Mdot
.54459 .36224 Mdot
.56516 .33341 Mdot
.51162 .33308 Mdot
.51583 .37273 Mdot
.4218 .72144 Mdot
.6486 .69823 Mdot
.47224 .77187 Mdot
.35379 .47162 Mdot
.26548 .68333 Mdot
.6383 .64949 Mdot
.41461 .59847 Mdot
.71962 .50487 Mdot
.6516 .31498 Mdot
.76417 .48454 Mdot
.65126 .67286 Mdot
.53852 .41182 Mdot
.35569 .50371 Mdot
.65575 .23916 Mdot
.51084 .36264 Mdot
.64893 .67728 Mdot
.66496 .69292 Mdot
.26217 .38368 Mdot
.57684 .41501 Mdot
.54439 .64331 Mdot
.58245 .48434 Mdot
.75836 .52715 Mdot
.47397 .40128 Mdot
.65663 .38872 Mdot
.61974 .67243 Mdot
.61571 .64722 Mdot
.69856 .52262 Mdot
.30032 .42086 Mdot
.35422 .45677 Mdot
.41587 .55383 Mdot
.4154 .69738 Mdot
.54144 .35437 Mdot
.60798 .67695 Mdot
.31009 .52428 Mdot
.56912 .50982 Mdot
.43417 .7097 Mdot
.62772 .63507 Mdot
.5408 .39854 Mdot
.51 .39852 Mdot
.74093 .52172 Mdot
.6223 .58402 Mdot
.46068 .4084 Mdot
.32979 .70035 Mdot
.52469 .4964 Mdot
.53512 .5667 Mdot
.53367 .3879 Mdot
.30563 .49612 Mdot
.41901 .5867 Mdot
.73723 .49965 Mdot
.48502 .35836 Mdot
.21536 .45461 Mdot
.34609 .44737 Mdot
.44999 .6964 Mdot
.41502 .59128 Mdot
.64586 .39066 Mdot
.53901 .39893 Mdot
.51325 .38266 Mdot
.53685 .31852 Mdot
.20903 .43527 Mdot
.59471 .67279 Mdot
.31104 .50669 Mdot
.74341 .52654 Mdot
.30773 .48357 Mdot
.644 .64533 Mdot
.54342 .60009 Mdot
.48631 .38009 Mdot
.32627 .44843 Mdot
.31106 .48372 Mdot
.42408 .69926 Mdot
.46058 .69582 Mdot
.62154 .7071 Mdot
.54237 .39201 Mdot
.40754 .55698 Mdot
.35955 .4578 Mdot
.64783 .69285 Mdot
.74081 .52065 Mdot
.44921 .75197 Mdot
.52168 .3535 Mdot
.61374 .66956 Mdot
.46443 .40944 Mdot
.34883 .47718 Mdot
.64663 .66021 Mdot
.40209 .58427 Mdot
.71675 .49912 Mdot
.53262 .40757 Mdot
.48799 .77671 Mdot
.40393 .58236 Mdot
.54431 .34946 Mdot
.34927 .22468 Mdot
.5436 .58744 Mdot
.287 .4379 Mdot
.60491 .68855 Mdot
.40149 .56491 Mdot
.32047 .51012 Mdot
.2926 .36003 Mdot
.61078 .65018 Mdot
.44975 .21817 Mdot
.52178 .5493 Mdot
.4909 .36251 Mdot
.32365 .46252 Mdot
.79085 .50372 Mdot
.31444 .67815 Mdot
.69361 .40534 Mdot
.53567 .36824 Mdot
.6137 .68486 Mdot
.75398 .51648 Mdot
.44149 .68715 Mdot
.47232 .73429 Mdot
.80821 .44211 Mdot
.60412 .63786 Mdot
.49614 .37428 Mdot
.36653 .46813 Mdot
.45061 .70073 Mdot
.44874 .21007 Mdot
.60664 .69656 Mdot
.61187 .6897 Mdot
.57362 .3449 Mdot
.74707 .51939 Mdot
.48633 .64775 Mdot
.59427 .66455 Mdot
.64977 .69915 Mdot
.41528 .50439 Mdot
.74864 .53256 Mdot
.53049 .32088 Mdot
.45955 .32455 Mdot
.5748 .33033 Mdot
.30822 .71936 Mdot
.40222 .5628 Mdot
.35261 .46895 Mdot
.50498 .37645 Mdot
.46385 .79514 Mdot
.61384 .65408 Mdot
.58018 .4845 Mdot
.43259 .6527 Mdot
.45992 .69408 Mdot
.61834 .68185 Mdot
.53089 .37833 Mdot
.46842 .68216 Mdot
.7209 .52505 Mdot
.52867 .32065 Mdot
.50045 .35249 Mdot
.36717 .44435 Mdot
.42833 .67967 Mdot
.38079 .21526 Mdot
.44139 .6833 Mdot
.43235 .66883 Mdot
.31272 .44043 Mdot
.5043 .3984 Mdot
.64469 .66035 Mdot
.57631 .6637 Mdot
.49272 .43094 Mdot
.66572 .50536 Mdot
.34333 .45418 Mdot
.58117 .628 Mdot
.21073 .45731 Mdot
.57442 .37041 Mdot
.42451 .59421 Mdot
.26351 .49779 Mdot
.42086 .66227 Mdot
.50187 .38981 Mdot
.33761 .46673 Mdot
.63188 .70398 Mdot
.60735 .68127 Mdot
.55166 .31133 Mdot
.44846 .71819 Mdot
.70831 .52509 Mdot
.63648 .66759 Mdot
.5259 .52998 Mdot
.53367 .3612 Mdot
.41821 .62436 Mdot
.63848 .66823 Mdot
.42411 .16331 Mdot
.45705 .79505 Mdot
.35172 .49442 Mdot
.56543 .34439 Mdot
.36598 .48792 Mdot
.73253 .5324 Mdot
.65844 .66044 Mdot
.43227 .72319 Mdot
.52563 .4489 Mdot
.66276 .76926 Mdot
.60526 .67081 Mdot
.32583 .46873 Mdot
.49784 .37886 Mdot
.41698 .36181 Mdot
.54789 .37607 Mdot
.76634 .38483 Mdot
.69842 .50975 Mdot
.42357 .74377 Mdot
.45116 .71933 Mdot
.55462 .33205 Mdot
.75543 .49563 Mdot
.57744 .67478 Mdot
.62777 .67069 Mdot
.64463 .8055 Mdot
.40821 .59254 Mdot
.56631 .64986 Mdot
.5488 .35668 Mdot
.64427 .69221 Mdot
.4455 .25227 Mdot
.45474 .71131 Mdot
.57773 .34099 Mdot
.595 .63655 Mdot
.27862 .67496 Mdot
.5843 .48575 Mdot
.53491 .36381 Mdot
.56464 .41247 Mdot
.42545 .71198 Mdot
.21778 .61206 Mdot
.60125 .68719 Mdot
.5024 .3362 Mdot
.45262 .66329 Mdot
.52431 .47052 Mdot
.65857 .60791 Mdot
.33091 .47819 Mdot
.59572 .63294 Mdot
.41902 .67699 Mdot
.48755 .30488 Mdot
.70987 .51136 Mdot
.60809 .69981 Mdot
.58566 .65084 Mdot
.52625 .33834 Mdot
.5161 .32056 Mdot
.58192 .39472 Mdot
.33209 .45749 Mdot
.43835 .67127 Mdot
.53754 .32858 Mdot
.53627 .51149 Mdot
.51639 .33059 Mdot
.43006 .67147 Mdot
.64102 .86453 Mdot
.5341 .41212 Mdot
.5278 .35227 Mdot
.4131 .35058 Mdot
.30518 .5024 Mdot
.33763 .50001 Mdot
.52415 .50374 Mdot
.55478 .37325 Mdot
.51042 .55434 Mdot
.33068 .47504 Mdot
.31995 .46857 Mdot
.51172 .55542 Mdot
.51609 .34409 Mdot
.43488 .58805 Mdot
.45071 .70259 Mdot
.4601 .69381 Mdot
.34388 .49497 Mdot
.52545 .31206 Mdot
.46141 .71124 Mdot
.31989 .38602 Mdot
.64992 .66462 Mdot
.65551 .38473 Mdot
.31136 .48919 Mdot
.60899 .48084 Mdot
.4533 .68748 Mdot
.47051 .17807 Mdot
.60119 .23724 Mdot
.57089 .38581 Mdot
.50366 .39607 Mdot
.73403 .51047 Mdot
.49581 .44603 Mdot
.42238 .58692 Mdot
.44802 .71305 Mdot
.49994 .63775 Mdot
.33177 .48435 Mdot
.55303 .37583 Mdot
.69225 .41913 Mdot
.38809 .19136 Mdot
.49251 .28775 Mdot
.31722 .47362 Mdot
.32895 .48833 Mdot
.62026 .69412 Mdot
.6527 .67301 Mdot
.4871 .37915 Mdot
.4364 .72081 Mdot
.36296 .48486 Mdot
.43241 .67398 Mdot
.6216 .67279 Mdot
.64115 .65396 Mdot
.42169 .56834 Mdot
.46115 .36192 Mdot
.62207 .67952 Mdot
.45729 .76041 Mdot
.53578 .51255 Mdot
.35339 .43769 Mdot
.37084 .79689 Mdot
.49506 .17921 Mdot
.39034 .4164 Mdot
.75468 .51653 Mdot
.55817 .46339 Mdot
.44073 .73144 Mdot
.5519 .33014 Mdot
.51172 .38756 Mdot
.40941 .56715 Mdot
.44714 .73029 Mdot
.72206 .50835 Mdot
.45818 .70375 Mdot
.73364 .49691 Mdot
.59717 .65092 Mdot
.49988 .36837 Mdot
.49427 .40199 Mdot
.43917 .68855 Mdot
.63634 .69167 Mdot
.64668 .65519 Mdot
.75364 .50193 Mdot
.64732 .30187 Mdot
.61418 .66748 Mdot
.31068 .48806 Mdot
.3966 .22827 Mdot
.41745 .57194 Mdot
.52357 .3808 Mdot
.6732 .38932 Mdot
.30535 .34397 Mdot
.49828 .34675 Mdot
.41139 .59043 Mdot
.54191 .87625 Mdot
.4982 .36773 Mdot
.72634 .74001 Mdot
.41291 .55975 Mdot
.30153 .48396 Mdot
.6433 .67651 Mdot
.40916 .59232 Mdot
.6247 .36108 Mdot
.61676 .61691 Mdot
.48053 .42328 Mdot
.35199 .4552 Mdot
.31112 .45498 Mdot
.5378 .59812 Mdot
.30623 .71838 Mdot
.74472 .52619 Mdot
.71881 .51719 Mdot
.60811 .65321 Mdot
.4724 .74239 Mdot
.53555 .31162 Mdot
.72081 .5169 Mdot
.44286 .59034 Mdot
.55549 .32975 Mdot
.54238 .58829 Mdot
.51499 .5985 Mdot
.32 .50554 Mdot
.54436 .28947 Mdot
.61091 .65325 Mdot
.3257 .47001 Mdot
.52544 .59231 Mdot
.57304 .33693 Mdot
.33036 .48152 Mdot
.44978 .67744 Mdot
.48173 .55285 Mdot
.31267 .49505 Mdot
.60259 .47527 Mdot
.44183 .6937 Mdot
.5451 .59393 Mdot
.71628 .32928 Mdot
.28556 .2204 Mdot
.44313 .71902 Mdot
.64568 .68097 Mdot
.60863 .67581 Mdot
.61442 .664 Mdot
.32296 .45996 Mdot
.62759 .65807 Mdot
.35525 .4644 Mdot
.4108 .72321 Mdot
.6467 .31634 Mdot
.73669 .5163 Mdot
.78242 .48125 Mdot
.33254 .49464 Mdot
.33144 .7552 Mdot
.32046 .79082 Mdot
.51801 .32715 Mdot
.44005 .66512 Mdot
.76336 .50796 Mdot
.51126 .49258 Mdot
.73112 .50961 Mdot
.64389 .67994 Mdot
.65167 .37159 Mdot
.5389 .3754 Mdot
.30792 .54727 Mdot
.75328 .51666 Mdot
.31778 .46877 Mdot
.54479 .34267 Mdot
.58628 .63505 Mdot
.72595 .52987 Mdot
.75376 .50766 Mdot
.51686 .37412 Mdot
.30666 .46313 Mdot
.64806 .66478 Mdot
.43265 .73181 Mdot
.73355 .47675 Mdot
.54585 .42905 Mdot
.49076 .38073 Mdot
.52693 .41624 Mdot
.56566 .48914 Mdot
.48491 .7233 Mdot
.44159 .69636 Mdot
.72307 .41989 Mdot
.59954 .66257 Mdot
.69646 .40463 Mdot
.33278 .68174 Mdot
.78563 .5193 Mdot
.40348 .56233 Mdot
.40263 .56161 Mdot
.52675 .36457 Mdot
.22279 .68961 Mdot
.50176 .27384 Mdot
.41576 .65539 Mdot
.41365 .57134 Mdot
.65018 .66011 Mdot
.36648 .45011 Mdot
.60838 .34073 Mdot
.55871 .31496 Mdot
.43701 .7336 Mdot
.62168 .6687 Mdot
.18577 .63542 Mdot
.73029 .52468 Mdot
.50661 .49535 Mdot
.54018 .39445 Mdot
.52656 .3704 Mdot
.4334 .70309 Mdot
.42914 .72154 Mdot
.41495 .50001 Mdot
.62336 .50625 Mdot
.30737 .5609 Mdot
.45276 .73648 Mdot
.18478 .63467 Mdot
.2502 .49113 Mdot
.34696 .48837 Mdot
.42484 .5897 Mdot
.46343 .69594 Mdot
.50736 .37785 Mdot
.30115 .4858 Mdot
.52194 .2686 Mdot
.3493 .52839 Mdot
.54051 .5825 Mdot
.53242 .53038 Mdot
.52771 .40427 Mdot
.33232 .51303 Mdot
.32583 .47378 Mdot
.3026 .50832 Mdot
.4201 .58267 Mdot
.53087 .39037 Mdot
.49793 .34392 Mdot
.49737 .36632 Mdot
.42369 .39999 Mdot
.52617 .36142 Mdot
.32897 .68071 Mdot
.51986 .51318 Mdot
.73157 .59747 Mdot
.50916 .36028 Mdot
.44443 .67199 Mdot
.50114 .36969 Mdot
.74803 .49159 Mdot
.53308 .40927 Mdot
.53963 .57839 Mdot
.44522 .70607 Mdot
.27444 .41485 Mdot
.67668 .68353 Mdot
.49282 .39809 Mdot
.72644 .53531 Mdot
.39515 .79549 Mdot
.7128 .42098 Mdot
.41613 .50765 Mdot
.31322 .49171 Mdot
.6505 .70105 Mdot
.45236 .66769 Mdot
.63665 .65271 Mdot
.58289 .35806 Mdot
.42743 .58251 Mdot
.65957 .20855 Mdot
.61761 .48179 Mdot
.50619 .37635 Mdot
.46032 .37271 Mdot
.31551 .50282 Mdot
.61742 .65368 Mdot
.38655 .43094 Mdot
.56011 .33044 Mdot
.70762 .50448 Mdot
.75446 .49076 Mdot
.57031 .70436 Mdot
.46417 .55254 Mdot
.46811 .26654 Mdot
.43545 .70238 Mdot
.60318 .67472 Mdot
.75736 .48925 Mdot
.35581 .53885 Mdot
.45968 .67962 Mdot
.42077 .66212 Mdot
.42672 .68027 Mdot
.53573 .35736 Mdot
.4206 .56946 Mdot
.46424 .58884 Mdot
.40264 .58209 Mdot
.56492 .32533 Mdot
.58681 .6492 Mdot
.39972 .57642 Mdot
.74207 .51271 Mdot
.42098 .67244 Mdot
.63518 .64533 Mdot
.51467 .36691 Mdot
.33604 .47617 Mdot
.77022 .45183 Mdot
.47604 .80277 Mdot
.54484 .58876 Mdot
.54489 .58886 Mdot
.31243 .44819 Mdot
.37224 .55645 Mdot
.44675 .74789 Mdot
.26863 .37858 Mdot
.7047 .55715 Mdot
.47794 .42804 Mdot
.70157 .67477 Mdot
.5903 .66997 Mdot
.63443 .67711 Mdot
.54238 .37101 Mdot
.63532 .69779 Mdot
.55021 .3788 Mdot
.60712 .69098 Mdot
.30861 .68949 Mdot
.57714 .32318 Mdot
.63356 .67161 Mdot
.57138 .42207 Mdot
.53819 .3456 Mdot
.30624 .49463 Mdot
.61667 .70167 Mdot
.57116 .38488 Mdot
.74134 .25364 Mdot
.42584 .6958 Mdot
.4202 .58139 Mdot
.54509 .56113 Mdot
.45526 .69667 Mdot
.3598 .46576 Mdot
.55391 .38448 Mdot
.72951 .52705 Mdot
.34192 .4908 Mdot
.61403 .62192 Mdot
.75144 .51566 Mdot
.4632 .4799 Mdot
.34475 .49278 Mdot
.41529 .56759 Mdot
.72015 .49613 Mdot
.48134 .42376 Mdot
.63267 .67593 Mdot
.46408 .79996 Mdot
.41218 .59353 Mdot
.53749 .37939 Mdot
.60271 .62972 Mdot
.45778 .70164 Mdot
.49668 .39708 Mdot
.60753 .67824 Mdot
.41879 .5901 Mdot
.53 .3483 Mdot
.55238 .35716 Mdot
.32796 .41518 Mdot
.6471 .55531 Mdot
.73933 .51503 Mdot
.30158 .44813 Mdot
.55833 .31985 Mdot
.75685 .49844 Mdot
.50267 .74915 Mdot
.58682 .33608 Mdot
.35248 .45157 Mdot
.29654 .38897 Mdot
.64816 .68807 Mdot
.45396 .71536 Mdot
.58891 .68589 Mdot
.74433 .53218 Mdot
.38316 .84073 Mdot
.42451 .58572 Mdot
.51455 .42119 Mdot
.56553 .3884 Mdot
.66325 .67107 Mdot
.3249 .47638 Mdot
.30575 .5587 Mdot
.53834 .40569 Mdot
.48011 .32095 Mdot
.51977 .37797 Mdot
.50258 .75965 Mdot
.32723 .4584 Mdot
.52123 .38008 Mdot
.51494 .43716 Mdot
.57676 .3602 Mdot
.71371 .52767 Mdot
.67704 .26761 Mdot
.49638 .35259 Mdot
.8179 .71935 Mdot
.42515 .56889 Mdot
.6264 .66734 Mdot
.59484 .47819 Mdot
.55685 .56742 Mdot
.82694 .49602 Mdot
.35331 .4588 Mdot
.37149 .53344 Mdot
.64215 .65667 Mdot
.80333 .48129 Mdot
.38029 .56144 Mdot
.55097 .35056 Mdot
.54553 .39283 Mdot
.64393 .67986 Mdot
.65008 .69152 Mdot
.42846 .57956 Mdot
.48101 .38387 Mdot
.52043 .2912 Mdot
.58202 .67176 Mdot
.51672 .3605 Mdot
.31041 .32293 Mdot
.40758 .67677 Mdot
.3431 .49639 Mdot
.43949 .68633 Mdot
.40706 .6819 Mdot
.38419 .41955 Mdot
.53014 .49462 Mdot
.4149 .7044 Mdot
.40626 .66785 Mdot
.79077 .49366 Mdot
.40902 .38713 Mdot
.71153 .52554 Mdot
.4444 .51225 Mdot
.60759 .66047 Mdot
.52871 .39139 Mdot
.32228 .45895 Mdot
.79175 .37224 Mdot
.31048 .58241 Mdot
.62098 .30593 Mdot
.53317 .32086 Mdot
.61222 .6567 Mdot
.41435 .59313 Mdot
.58657 .33265 Mdot
.69473 .39939 Mdot
.53192 .36822 Mdot
.65397 .67923 Mdot
.40782 .39207 Mdot
.41573 .77194 Mdot
.45069 .73953 Mdot
.37951 .4688 Mdot
.49946 .37135 Mdot
.34287 .46312 Mdot
.41106 .69917 Mdot
.75991 .50964 Mdot
.7278 .51501 Mdot
.49514 .40124 Mdot
.53239 .56421 Mdot
.79462 .53471 Mdot
.54855 .34814 Mdot
.52175 .33992 Mdot
.4033 .5639 Mdot
.52026 .34026 Mdot
.48596 .3597 Mdot
.53785 .32687 Mdot
.51144 .3267 Mdot
.46244 .68672 Mdot
.39694 .42926 Mdot
.48231 .39728 Mdot
.54613 .41531 Mdot
.40981 .71399 Mdot
.57704 .38609 Mdot
.43293 .71579 Mdot
.32906 .57752 Mdot
.41615 .70294 Mdot
.7294 .51559 Mdot
.59682 .63024 Mdot
.39301 .49668 Mdot
.36273 .48481 Mdot
.45234 .67625 Mdot
.7204 .4992 Mdot
.44517 .71635 Mdot
.59955 .67439 Mdot
.44651 .78401 Mdot
.3084 .43376 Mdot
.51406 .5233 Mdot
.40707 .36898 Mdot
.4099 .63437 Mdot
.63141 .69651 Mdot
.3536 .49274 Mdot
.45643 .7537 Mdot
.55341 .33222 Mdot
.73689 .527 Mdot
.5264 .36527 Mdot
.42423 .67027 Mdot
.6104 .65885 Mdot
.41437 .53689 Mdot
.73892 .51415 Mdot
.41284 .8324 Mdot
.58541 .67053 Mdot
.55337 .40255 Mdot
.41108 .71532 Mdot
.46327 .76656 Mdot
.42442 .71344 Mdot
.64759 .31619 Mdot
.28796 .51744 Mdot
.79822 .39687 Mdot
.33204 .49089 Mdot
.42251 .60627 Mdot
.24619 .29141 Mdot
.37031 .64713 Mdot
.34402 .47752 Mdot
.67627 .70218 Mdot
.52771 .35841 Mdot
.52621 .32529 Mdot
.46405 .3558 Mdot
.32277 .52357 Mdot
.53742 .3185 Mdot
.4227 .58066 Mdot
.53483 .49773 Mdot
.45628 .61502 Mdot
.64329 .70564 Mdot
.54866 .37955 Mdot
.41278 .71092 Mdot
.44849 .67197 Mdot
.39779 .56699 Mdot
.43707 .68018 Mdot
.51604 .35002 Mdot
.33287 .49367 Mdot
.52036 .5928 Mdot
.73356 .53186 Mdot
.34307 .70812 Mdot
.74001 .56111 Mdot
.76426 .48244 Mdot
.57658 .36329 Mdot
.64286 .65565 Mdot
.67354 .75934 Mdot
.54661 .32508 Mdot
.32926 .47262 Mdot
.56463 .38884 Mdot
.53017 .32686 Mdot
.49314 .36549 Mdot
.60319 .67378 Mdot
.59027 .48562 Mdot
.51493 .36094 Mdot
.41355 .70164 Mdot
.51375 .55494 Mdot
.55348 .31343 Mdot
.5147 .64789 Mdot
.53939 .57938 Mdot
.41708 .62602 Mdot
.36085 .43966 Mdot
.64503 .66518 Mdot
.33228 .48627 Mdot
.34307 .51859 Mdot
.35994 .46652 Mdot
.46311 .60192 Mdot
.27842 .37322 Mdot
.74371 .72816 Mdot
.44747 .25568 Mdot
.40326 .37005 Mdot
.37758 .47636 Mdot
.55337 .73774 Mdot
.3434 .47304 Mdot
.35805 .4631 Mdot
.61269 .85865 Mdot
.3255 .45354 Mdot
.52178 .38618 Mdot
.51102 .41412 Mdot
.22667 .43153 Mdot
.75996 .47499 Mdot
.54514 .35292 Mdot
.50866 .3323 Mdot
.75556 .48966 Mdot
.36012 .41869 Mdot
.4288 .58995 Mdot
.50085 .49642 Mdot
.41739 .6019 Mdot
.51694 .37335 Mdot
.51546 .4057 Mdot
.48163 .35881 Mdot
.3214 .21555 Mdot
.80875 .41737 Mdot
.30579 .45728 Mdot
.48433 .4323 Mdot
.39498 .65839 Mdot
.56456 .3774 Mdot
.56946 .37695 Mdot
.49755 .36017 Mdot
.64465 .66008 Mdot
.35619 .44515 Mdot
.46174 .40929 Mdot
.35985 .69318 Mdot
.53372 .40099 Mdot
.769 .55189 Mdot
.74743 .53947 Mdot
.53048 .37953 Mdot
.32604 .45207 Mdot
.52761 .32369 Mdot
.36771 .48151 Mdot
.34843 .4912 Mdot
.49631 .30469 Mdot
.46215 .57736 Mdot
.36693 .45169 Mdot
.55193 .35232 Mdot
.63615 .69288 Mdot
.3312 .70425 Mdot
.53631 .37939 Mdot
.74668 .51336 Mdot
.49974 .38835 Mdot
.71819 .53168 Mdot
.51119 .34179 Mdot
.40014 .57548 Mdot
.30834 .27531 Mdot
.61309 .64748 Mdot
.75618 .47841 Mdot
.63887 .69546 Mdot
.50787 .31329 Mdot
.37407 .47046 Mdot
.39267 .74754 Mdot
.81391 .43985 Mdot
.40428 .56338 Mdot
.74363 .42724 Mdot
.50355 .56274 Mdot
.4295 .72626 Mdot
.31322 .50999 Mdot
.4014 .40735 Mdot
.51541 .64323 Mdot
.65186 .70334 Mdot
.63277 .63823 Mdot
.67231 .61206 Mdot
.56207 .85993 Mdot
.51823 .35746 Mdot
.50257 .66494 Mdot
.33174 .28862 Mdot
.48838 .44266 Mdot
.59473 .38944 Mdot
.58349 .65367 Mdot
.54515 .3525 Mdot
.6458 .45815 Mdot
.61097 .6727 Mdot
.71432 .5145 Mdot
.35144 .46726 Mdot
.74627 .49446 Mdot
.26257 .56861 Mdot
.41403 .51207 Mdot
.61808 .6772 Mdot
.5161 .32319 Mdot
.54683 .36067 Mdot
.3071 .50601 Mdot
.45393 .21087 Mdot
.34451 .49717 Mdot
.74113 .53018 Mdot
.60354 .65223 Mdot
.70178 .24513 Mdot
.49685 .38284 Mdot
.31122 .4806 Mdot
.6767 .68453 Mdot
.51232 .39865 Mdot
.45243 .71559 Mdot
.54096 .31928 Mdot
.30905 .47893 Mdot
.51991 .3401 Mdot
.33532 .49166 Mdot
.62351 .69274 Mdot
.49761 .40485 Mdot
.50693 .40504 Mdot
.72931 .42087 Mdot
.72349 .50754 Mdot
.37078 .46198 Mdot
.64626 .45445 Mdot
.57473 .33019 Mdot
.68715 .39144 Mdot
.49941 .36826 Mdot
.41202 .37248 Mdot
.59101 .35026 Mdot
.42228 .57748 Mdot
.56753 .38359 Mdot
.53644 .37785 Mdot
.47104 .21456 Mdot
.44574 .24893 Mdot
.42197 .42015 Mdot
.4609 .69594 Mdot
.31075 .46637 Mdot
.61141 .67783 Mdot
.63571 .70461 Mdot
.63259 .658 Mdot
.69389 .52534 Mdot
.49958 .43367 Mdot
.53971 .38123 Mdot
.40081 .66774 Mdot
.72322 .52013 Mdot
.315 .47829 Mdot
.73217 .519 Mdot
.53278 .49202 Mdot
.74689 .50974 Mdot
.42286 .58785 Mdot
.45753 .79274 Mdot
.30987 .33432 Mdot
.73679 .50146 Mdot
.34588 .49558 Mdot
.50704 .54541 Mdot
.47229 .42471 Mdot
.28429 .69883 Mdot
.70825 .50284 Mdot
.67973 .63147 Mdot
.52065 .35157 Mdot
.61324 .46529 Mdot
.43178 .71305 Mdot
.74472 .49419 Mdot
.42618 .68209 Mdot
.52928 .32327 Mdot
.3314 .4191 Mdot
.32814 .46619 Mdot
.40537 .68207 Mdot
.57699 .35113 Mdot
.745 .49396 Mdot
.62385 .67795 Mdot
.40913 .39081 Mdot
.40343 .70164 Mdot
.76904 .45409 Mdot
.69478 .40568 Mdot
.60197 .65589 Mdot
.42867 .31598 Mdot
.41835 .69365 Mdot
.48119 .42955 Mdot
.55202 .27329 Mdot
.55338 .32245 Mdot
.64533 .65279 Mdot
.63549 .67703 Mdot
.40187 .63027 Mdot
.51263 .40688 Mdot
.48522 .40336 Mdot
.33626 .43904 Mdot
.59991 .65543 Mdot
.36117 .46836 Mdot
.3318 .50909 Mdot
.64352 .68274 Mdot
.35032 .49672 Mdot
.75306 .51352 Mdot
.63966 .42269 Mdot
.41752 .69522 Mdot
.44815 .72051 Mdot
.61972 .67911 Mdot
.6058 .64299 Mdot
.64191 .65394 Mdot
.56814 .33862 Mdot
.35911 .48453 Mdot
.564 .34469 Mdot
.49839 .37395 Mdot
.3436 .5397 Mdot
.32569 .43674 Mdot
.57183 .35845 Mdot
.51174 .60065 Mdot
.70217 .51053 Mdot
.63203 .6683 Mdot
.43831 .67316 Mdot
.78092 .45343 Mdot
.42321 .7248 Mdot
.57511 .32814 Mdot
.28318 .68198 Mdot
.32144 .46163 Mdot
.7325 .5098 Mdot
.54253 .58176 Mdot
.73717 .51214 Mdot
.40663 .67866 Mdot
.30616 .44874 Mdot
.47155 .48701 Mdot
.50994 .40727 Mdot
.56111 .49032 Mdot
.71956 .36095 Mdot
.3389 .68132 Mdot
.44256 .67277 Mdot
.52279 .32453 Mdot
.40926 .56041 Mdot
.26252 .38001 Mdot
.54098 .37786 Mdot
.58099 .34762 Mdot
.56888 .58222 Mdot
.56645 .38864 Mdot
.29738 .46455 Mdot
.53672 .58524 Mdot
.48223 .36866 Mdot
.50348 .31715 Mdot
.61489 .83275 Mdot
.53591 .34792 Mdot
.50175 .40411 Mdot
.51772 .39079 Mdot
.55745 .33279 Mdot
.36775 .48537 Mdot
.57064 .59922 Mdot
.40964 .70127 Mdot
.64003 .42231 Mdot
.4216 .68434 Mdot
.62671 .6836 Mdot
.64191 .48477 Mdot
.36715 .48424 Mdot
.7377 .51185 Mdot
.50657 .67907 Mdot
.65031 .37255 Mdot
.62299 .69443 Mdot
.76337 .42296 Mdot
.7072 .51773 Mdot
.47098 .42439 Mdot
.74768 .5318 Mdot
.58777 .64414 Mdot
.44787 .71816 Mdot
.53881 .41153 Mdot
.36095 .46018 Mdot
.31333 .49535 Mdot
.5512 .31889 Mdot
.35035 .71837 Mdot
.4577 .71067 Mdot
.67432 .4828 Mdot
.54015 .36093 Mdot
.57761 .34034 Mdot
.34495 .49877 Mdot
.61645 .65481 Mdot
.50539 .56173 Mdot
.7223 .50199 Mdot
.55607 .38993 Mdot
.51017 .33369 Mdot
.53646 .49168 Mdot
.45679 .67882 Mdot
.41202 .57837 Mdot
.54486 .37964 Mdot
.51275 .50049 Mdot
.53935 .31778 Mdot
.49292 .33662 Mdot
.64455 .68838 Mdot
.48827 .3113 Mdot
.53027 .40626 Mdot
.30985 .42384 Mdot
.41977 .692 Mdot
.32828 .47748 Mdot
.36203 .53361 Mdot
.39966 .56936 Mdot
.42836 .69347 Mdot
.57324 .35643 Mdot
.43059 .66188 Mdot
.52787 .32598 Mdot
.51431 .36453 Mdot
.44544 .67423 Mdot
.36049 .47387 Mdot
.35377 .56861 Mdot
.39741 .42938 Mdot
.54374 .33242 Mdot
.50243 .3915 Mdot
.76047 .47537 Mdot
.80961 .38625 Mdot
.52217 .40872 Mdot
.3555 .4922 Mdot
.51029 .39898 Mdot
.43204 .7255 Mdot
.74611 .52562 Mdot
.33405 .47265 Mdot
.59666 .66459 Mdot
.61981 .69177 Mdot
.67076 .69893 Mdot
.42372 .58795 Mdot
.48222 .38974 Mdot
.30306 .44735 Mdot
.3202 .43928 Mdot
.62727 .44187 Mdot
.62763 .66795 Mdot
.7489 .52283 Mdot
.54881 .35485 Mdot
.51636 .45059 Mdot
.40938 .67877 Mdot
.83936 .69288 Mdot
.47807 .49107 Mdot
.70811 .53534 Mdot
.61845 .51811 Mdot
.40439 .56641 Mdot
.53476 .35094 Mdot
.74838 .4927 Mdot
.63173 .68713 Mdot
.52547 .32535 Mdot
.56849 .40733 Mdot
.53217 .66459 Mdot
.61591 .63801 Mdot
.41686 .66483 Mdot
.60023 .68356 Mdot
.70983 .5258 Mdot
.42276 .5866 Mdot
.30587 .48494 Mdot
.53312 .37401 Mdot
.53078 .28796 Mdot
.61638 .66201 Mdot
.40695 .55435 Mdot
.48922 .3924 Mdot
.30663 .47055 Mdot
.62882 .66148 Mdot
.51333 .37681 Mdot
.2652 .3846 Mdot
.39251 .49595 Mdot
.60469 .6603 Mdot
.55756 .38241 Mdot
.60948 .34774 Mdot
.61952 .63683 Mdot
.59278 .63992 Mdot
.51927 .32551 Mdot
.73683 .49314 Mdot
.53284 .40391 Mdot
.43156 .71869 Mdot
.58979 .4868 Mdot
.43614 .68938 Mdot
.69528 .397 Mdot
.50535 .32713 Mdot
.51252 .27389 Mdot
.34663 .50938 Mdot
.74007 .48136 Mdot
.5358 .19451 Mdot
.57769 .33265 Mdot
.22699 .47593 Mdot
.6062 .48221 Mdot
.49546 .51235 Mdot
.22012 .49043 Mdot
.73021 .49881 Mdot
.44486 .71469 Mdot
.49271 .39621 Mdot
.48663 .67679 Mdot
.73917 .49784 Mdot
.69456 .39572 Mdot
.56369 .35947 Mdot
.31925 .47071 Mdot
.53711 .36035 Mdot
.30718 .47606 Mdot
.51691 .39667 Mdot
.26604 .43364 Mdot
.77447 .55078 Mdot
.64696 .314 Mdot
.47013 .42187 Mdot
.46034 .76727 Mdot
.4065 .36896 Mdot
.74641 .52094 Mdot
.53458 .33362 Mdot
.40607 .57492 Mdot
.45834 .70314 Mdot
.51352 .70037 Mdot
.64129 .65507 Mdot
.4139 .69753 Mdot
.35442 .48322 Mdot
.58167 .64677 Mdot
.40513 .55668 Mdot
.44916 .39167 Mdot
.74389 .49308 Mdot
.42627 .69579 Mdot
.53435 .37775 Mdot
.55978 .32692 Mdot
.50158 .76104 Mdot
.66844 .23211 Mdot
.34789 .50237 Mdot
.46776 .8586 Mdot
.29898 .45206 Mdot
.71926 .51278 Mdot
.64739 .68548 Mdot
.50659 .38071 Mdot
.53939 .39227 Mdot
.61735 .63913 Mdot
.30525 .5009 Mdot
.76739 .48766 Mdot
.80064 .3939 Mdot
.43787 .65468 Mdot
.67436 .28539 Mdot
.33492 .46999 Mdot
.67512 .28789 Mdot
.73443 .55006 Mdot
.43078 .55846 Mdot
.61997 .24265 Mdot
.45291 .70182 Mdot
.6741 .28301 Mdot
.31483 .47249 Mdot
.52152 .35534 Mdot
.41384 .56727 Mdot
.421 .56442 Mdot
.34666 .46724 Mdot
.64563 .67602 Mdot
.71039 .50934 Mdot
.53884 .3631 Mdot
.45248 .3553 Mdot
.4472 .20991 Mdot
.5997 .65008 Mdot
.4607 .37604 Mdot
.45219 .68907 Mdot
.50787 .39662 Mdot
.76066 .49458 Mdot
.45028 .7056 Mdot
.40473 .58839 Mdot
.65072 .3792 Mdot
.55408 .38448 Mdot
.53458 .57022 Mdot
.42995 .70798 Mdot
.80521 .37901 Mdot
.50833 .40503 Mdot
.41848 .69336 Mdot
.5283 .28859 Mdot
.38687 .7499 Mdot
.51507 .57752 Mdot
.36953 .64469 Mdot
.6072 .70245 Mdot
.60599 .68969 Mdot
.7463 .2628 Mdot
.69138 .55033 Mdot
.41319 .68425 Mdot
.41965 .59327 Mdot
.67604 .25744 Mdot
.42686 .68455 Mdot
.55036 .3999 Mdot
.50142 .36562 Mdot
.40769 .39211 Mdot
.53906 .44428 Mdot
.42968 .58189 Mdot
.43136 .37493 Mdot
.5212 .34574 Mdot
.45963 .39942 Mdot
.49358 .39159 Mdot
.30962 .45639 Mdot
.45241 .69631 Mdot
.15774 .42711 Mdot
.44173 .66232 Mdot
.52925 .27313 Mdot
.60775 .66024 Mdot
.59501 .69465 Mdot
.5296 .37884 Mdot
.54118 .26022 Mdot
.19039 .65463 Mdot
.49336 .3745 Mdot
.54216 .58113 Mdot
.69694 .40688 Mdot
.48876 .43152 Mdot
.35868 .45148 Mdot
.51722 .29101 Mdot
.29462 .4516 Mdot
.45099 .70716 Mdot
.73251 .49844 Mdot
.71035 .49427 Mdot
.44049 .71576 Mdot
.53732 .39253 Mdot
.72338 .48789 Mdot
.52471 .37284 Mdot
.54174 .35533 Mdot
.51386 .49598 Mdot
.76226 .51542 Mdot
.64479 .65663 Mdot
.73016 .51402 Mdot
.34822 .45595 Mdot
.60404 .87436 Mdot
.73762 .52214 Mdot
.40892 .38727 Mdot
.63305 .46635 Mdot
.6803 .28612 Mdot
.31388 .49781 Mdot
.73556 .53237 Mdot
.45442 .70687 Mdot
.45614 .48014 Mdot
.41002 .34447 Mdot
.42312 .72457 Mdot
.54246 .37997 Mdot
.36444 .48994 Mdot
.3121 .44691 Mdot
.45578 .73423 Mdot
.3084 .49978 Mdot
.49714 .42335 Mdot
.55529 .35789 Mdot
.41137 .69648 Mdot
.38428 .19037 Mdot
.45356 .71747 Mdot
.37786 .41688 Mdot
.50017 .35567 Mdot
.33146 .47285 Mdot
.41246 .36606 Mdot
.36986 .52081 Mdot
.42331 .57115 Mdot
.52643 .41135 Mdot
.74179 .52396 Mdot
.63878 .43759 Mdot
.60479 .6579 Mdot
.28158 .67655 Mdot
.31238 .49089 Mdot
.46735 .71638 Mdot
.30664 .49437 Mdot
.31658 .50721 Mdot
.40561 .69602 Mdot
.32728 .46186 Mdot
.53422 .40034 Mdot
.20751 .56784 Mdot
.32034 .49752 Mdot
.43705 .70515 Mdot
.73267 .52966 Mdot
.35233 .49418 Mdot
.68352 .47263 Mdot
.55057 .36365 Mdot
.60201 .69279 Mdot
.70807 .48173 Mdot
.3298 .51391 Mdot
.74789 .52095 Mdot
.62164 .66316 Mdot
.71261 .50352 Mdot
.4696 .64891 Mdot
.43308 .75191 Mdot
.6118 .2946 Mdot
.39802 .7649 Mdot
.33331 .45389 Mdot
.57703 .67881 Mdot
.55075 .39105 Mdot
.54073 .35903 Mdot
.70073 .50502 Mdot
.31204 .45064 Mdot
.35594 .73289 Mdot
.47471 .28844 Mdot
.34408 .70798 Mdot
.46083 .68878 Mdot
.74032 .45719 Mdot
.47373 .48957 Mdot
.47729 .67788 Mdot
.47392 .39947 Mdot
.40526 .56625 Mdot
.51958 .37873 Mdot
.71204 .42077 Mdot
.70843 .52202 Mdot
.5274 .77535 Mdot
.53093 .31264 Mdot
.61875 .64101 Mdot
.51227 .39367 Mdot
.496 .6495 Mdot
.49767 .32518 Mdot
.70728 .50272 Mdot
.45575 .66681 Mdot
.3627 .48496 Mdot
.72433 .53078 Mdot
.6237 .69197 Mdot
.61318 .25834 Mdot
.55081 .39817 Mdot
.52228 .34727 Mdot
.62156 .63486 Mdot
.36092 .46404 Mdot
.63091 .68127 Mdot
.41761 .69441 Mdot
.73638 .51999 Mdot
.56395 .33861 Mdot
.45932 .38559 Mdot
.66236 .66702 Mdot
.42531 .66679 Mdot
.64264 .64663 Mdot
.42839 .66231 Mdot
.40819 .56426 Mdot
.49515 .3395 Mdot
.63179 .63578 Mdot
.47496 .38833 Mdot
.41925 .27673 Mdot
.64176 .39728 Mdot
.49781 .2229 Mdot
.64677 .65885 Mdot
.75502 .56386 Mdot
.44344 .70971 Mdot
.42376 .69593 Mdot
.35052 .40944 Mdot
.21901 .6869 Mdot
.51049 .5546 Mdot
.4054 .80279 Mdot
.41731 .69537 Mdot
.42892 .70329 Mdot
.63906 .67926 Mdot
.35301 .46044 Mdot
.33876 .518 Mdot
.60508 .63006 Mdot
.67211 .38557 Mdot
.31479 .47828 Mdot
.22057 .44415 Mdot
.58947 .66217 Mdot
.50149 .41499 Mdot
.40286 .52593 Mdot
.70766 .50277 Mdot
.69221 .41565 Mdot
.45488 .77894 Mdot
.51305 .38365 Mdot
.71573 .74628 Mdot
.64161 .65874 Mdot
.43991 .50575 Mdot
.39708 .66681 Mdot
.56941 .33407 Mdot
.51814 .39336 Mdot
.52267 .40216 Mdot
.69852 .52157 Mdot
.43242 .23909 Mdot
.51001 .38183 Mdot
.65162 .34732 Mdot
.57992 .32505 Mdot
.48227 .78427 Mdot
.73023 .51431 Mdot
.76729 .39087 Mdot
.57232 .64956 Mdot
.35896 .70547 Mdot
.57879 .35814 Mdot
.41979 .70568 Mdot
.50684 .62433 Mdot
.43633 .66974 Mdot
.42269 .62526 Mdot
.66189 .24759 Mdot
.31419 .4515 Mdot
.54616 .31899 Mdot
.59043 .65352 Mdot
.35607 .50419 Mdot
.50879 .61544 Mdot
.58907 .87589 Mdot
.46563 .71355 Mdot
.4395 .88032 Mdot
.43259 .68649 Mdot
.42464 .56927 Mdot
.35318 .48214 Mdot
.5521 .25385 Mdot
.55372 .4913 Mdot
.36105 .46936 Mdot
.74469 .62705 Mdot
.28196 .47176 Mdot
.64913 .28246 Mdot
.32525 .42778 Mdot
.44242 .70263 Mdot
.46266 .72893 Mdot
.58624 .37979 Mdot
.53937 .40213 Mdot
.56199 .49336 Mdot
.5881 .4018 Mdot
.5537 .3829 Mdot
.61059 .67258 Mdot
.40594 .77403 Mdot
.48724 .68163 Mdot
.33725 .46523 Mdot
.41414 .67272 Mdot
.51427 .39322 Mdot
.54332 .33261 Mdot
.55093 .40885 Mdot
.80319 .4793 Mdot
.21933 .44227 Mdot
.51253 .36372 Mdot
.49277 .32847 Mdot
.62972 .69374 Mdot
.50215 .76192 Mdot
.49106 .84898 Mdot
.6672 .25159 Mdot
.48716 .38759 Mdot
.72372 .51023 Mdot
.76098 .49326 Mdot
.52121 .425 Mdot
.56071 .26248 Mdot
.72922 .4619 Mdot
.53451 .37803 Mdot
.6288 .27844 Mdot
.66042 .6937 Mdot
.39978 .5613 Mdot
.61691 .66246 Mdot
.34334 .51214 Mdot
.40695 .56061 Mdot
.61133 .6828 Mdot
.65693 .37345 Mdot
.40274 .57858 Mdot
.38371 .7456 Mdot
.73804 .53179 Mdot
.49746 .39775 Mdot
.40702 .4512 Mdot
.59817 .65667 Mdot
.42608 .7037 Mdot
.3419 .48483 Mdot
.45932 .70393 Mdot
.46226 .79766 Mdot
.67723 .39439 Mdot
.42467 .58282 Mdot
.42009 .70786 Mdot
.52885 .56412 Mdot
.72401 .51238 Mdot
.43529 .68204 Mdot
.51502 .27143 Mdot
.55235 .31239 Mdot
.16889 .57023 Mdot
.53197 .34333 Mdot
.40141 .62158 Mdot
.42291 .70355 Mdot
.40136 .58368 Mdot
.5329 .37237 Mdot
.58706 .67401 Mdot
.4517 .41579 Mdot
.5235 .37182 Mdot
.59519 .67318 Mdot
.51431 .35985 Mdot
.76123 .50256 Mdot
.29024 .46202 Mdot
.61779 .47581 Mdot
.74327 .44883 Mdot
.70923 .51611 Mdot
.60187 .45132 Mdot
.52274 .40909 Mdot
.70758 .60111 Mdot
.32011 .4725 Mdot
.57661 .33144 Mdot
.70581 .39127 Mdot
.34838 .46168 Mdot
.33148 .48726 Mdot
.52868 .3383 Mdot
.44884 .72301 Mdot
.63918 .6475 Mdot
.72586 .5128 Mdot
.47756 .72919 Mdot
.51131 .37718 Mdot
.52384 .32381 Mdot
.70985 .52141 Mdot
.42847 .69638 Mdot
.56883 .34434 Mdot
.30349 .63863 Mdot
.63511 .42131 Mdot
.41385 .6696 Mdot
.5518 .31322 Mdot
.19479 .48607 Mdot
.31716 .51651 Mdot
.72145 .74308 Mdot
.75685 .55849 Mdot
.64499 .68391 Mdot
.47103 .33839 Mdot
.78171 .75514 Mdot
.73875 .53042 Mdot
.34773 .69432 Mdot
.5239 .35612 Mdot
.50273 .38085 Mdot
.31558 .45374 Mdot
.5683 .35225 Mdot
.314 .46401 Mdot
.76044 .46055 Mdot
.23435 .70668 Mdot
.31157 .50119 Mdot
.31072 .47161 Mdot
.60108 .3399 Mdot
.81709 .4937 Mdot
.35233 .47056 Mdot
.55156 .39678 Mdot
.73617 .60541 Mdot
.55667 .42108 Mdot
.7561 .53172 Mdot
.75963 .46935 Mdot
.36455 .45457 Mdot
.39876 .3603 Mdot
.60026 .33867 Mdot
.28006 .40677 Mdot
.68605 .47971 Mdot
.41657 .68237 Mdot
.51794 .33332 Mdot
.42146 .59286 Mdot
.63322 .66518 Mdot
.49872 .29692 Mdot
.50606 .40357 Mdot
.35331 .45279 Mdot
.70493 .52904 Mdot
.43045 .68099 Mdot
.48631 .36566 Mdot
.6666 .68217 Mdot
.71679 .50639 Mdot
.33027 .49914 Mdot
.39173 .40955 Mdot
.71972 .49018 Mdot
.4595 .37716 Mdot
.5186 .35478 Mdot
.48538 .3734 Mdot
.48009 .43769 Mdot
.43832 .71505 Mdot
.59082 .63687 Mdot
.46167 .36807 Mdot
.48179 .48826 Mdot
.64794 .4124 Mdot
.5366 .41509 Mdot
.35449 .49299 Mdot
.45814 .68442 Mdot
.41813 .58579 Mdot
.67903 .27417 Mdot
.50654 .35709 Mdot
.21839 .44628 Mdot
.79458 .43409 Mdot
.40651 .58249 Mdot
.36705 .49279 Mdot
.73272 .51086 Mdot
.51205 .34629 Mdot
.65147 .34062 Mdot
.55754 .37835 Mdot
.49068 .43614 Mdot
.64799 .67536 Mdot
.42525 .67642 Mdot
.61911 .31894 Mdot
.63481 .66823 Mdot
.33199 .4866 Mdot
.22374 .42322 Mdot
.33468 .51689 Mdot
.33274 .50844 Mdot
.45746 .57234 Mdot
.43937 .72235 Mdot
.79517 .74307 Mdot
.82139 .40416 Mdot
.51857 .41504 Mdot
.42111 .71847 Mdot
.35028 .47622 Mdot
.56753 .37544 Mdot
.3194 .46193 Mdot
.35804 .44757 Mdot
.5522 .36044 Mdot
.55415 .36725 Mdot
.64405 .30594 Mdot
.22347 .44746 Mdot
.73662 .52672 Mdot
.30183 .4871 Mdot
.31007 .40407 Mdot
.50642 .3779 Mdot
.52361 .40615 Mdot
.50639 .62874 Mdot
.72727 .53283 Mdot
.2923 .32737 Mdot
.53604 .35697 Mdot
.73785 .42083 Mdot
.53947 .40561 Mdot
.34941 .51918 Mdot
.43692 .73783 Mdot
.52637 .27198 Mdot
.64962 .65869 Mdot
.30862 .5085 Mdot
.70272 .51883 Mdot
.37764 .45335 Mdot
.29844 .35413 Mdot
.44988 .71406 Mdot
.30913 .47847 Mdot
.57809 .65261 Mdot
.43507 .69397 Mdot
.45071 .71961 Mdot
.51012 .61167 Mdot
.57831 .66684 Mdot
.70903 .53496 Mdot
.44571 .67958 Mdot
.26562 .3871 Mdot
.44187 .69973 Mdot
.29147 .35437 Mdot
.48685 .39745 Mdot
.65226 .3518 Mdot
.48747 .30281 Mdot
.58294 .38937 Mdot
.4452 .68777 Mdot
.7121 .5103 Mdot
.57186 .34454 Mdot
.31557 .50435 Mdot
.72372 .52438 Mdot
.41591 .51309 Mdot
.57925 .67871 Mdot
.31776 .44383 Mdot
.43032 .66046 Mdot
.32191 .45623 Mdot
.69483 .40932 Mdot
.77594 .49142 Mdot
.51868 .63181 Mdot
.57071 .48563 Mdot
.46437 .40831 Mdot
.51771 .31154 Mdot
.57264 .34207 Mdot
.53309 .39921 Mdot
.6053 .66121 Mdot
.69611 .52799 Mdot
.35172 .49533 Mdot
.44623 .20079 Mdot
.42485 .71108 Mdot
.53389 .5782 Mdot
.47565 .43261 Mdot
.52839 .32509 Mdot
.3474 .47802 Mdot
.36052 .44656 Mdot
.44819 .24528 Mdot
.62531 .6396 Mdot
.56669 .41193 Mdot
.57154 .37948 Mdot
.62555 .35717 Mdot
.44282 .68841 Mdot
.34716 .62501 Mdot
.64406 .70404 Mdot
.45737 .89063 Mdot
.63306 .66982 Mdot
.63261 .57658 Mdot
.32926 .46039 Mdot
.74968 .51272 Mdot
.5458 .38124 Mdot
.42334 .43631 Mdot
.37185 .47889 Mdot
.57964 .62066 Mdot
.74062 .51173 Mdot
.36742 .59067 Mdot
.4159 .7098 Mdot
.48318 .37005 Mdot
.54201 .40454 Mdot
.5546 .33772 Mdot
.56625 .37116 Mdot
.41016 .6903 Mdot
.55833 .36871 Mdot
.40286 .69455 Mdot
.3057 .34461 Mdot
.70278 .38295 Mdot
.5932 .64335 Mdot
.51361 .76219 Mdot
.32972 .50819 Mdot
.24173 .36937 Mdot
.30314 .32726 Mdot
.64162 .39801 Mdot
.45238 .63756 Mdot
.48169 .36806 Mdot
.64475 .67407 Mdot
.48134 .73459 Mdot
.59132 .64622 Mdot
.14068 .48847 Mdot
.40702 .38786 Mdot
.38847 .61161 Mdot
.56043 .34596 Mdot
.62204 .63279 Mdot
.38602 .38286 Mdot
.45928 .3687 Mdot
.73048 .48514 Mdot
.28459 .36987 Mdot
.41848 .46021 Mdot
.74676 .52644 Mdot
.54748 .35814 Mdot
.32713 .43609 Mdot
.54283 .38676 Mdot
.54832 .37462 Mdot
.4925 .37367 Mdot
.41972 .73023 Mdot
.49671 .4092 Mdot
.53596 .40186 Mdot
.68238 .23543 Mdot
.54607 .65851 Mdot
.60895 .69303 Mdot
.48926 .22389 Mdot
.72336 .52038 Mdot
.34446 .51152 Mdot
.60457 .4814 Mdot
.42472 .71634 Mdot
.45035 .24329 Mdot
.54394 .33949 Mdot
.32402 .67916 Mdot
.46148 .68099 Mdot
.7282 .49517 Mdot
.41639 .591 Mdot
.34766 .59584 Mdot
.65222 .68478 Mdot
.42806 .58891 Mdot
.60515 .6557 Mdot
.52134 .21511 Mdot
.31158 .46754 Mdot
.46426 .40784 Mdot
.4337 .67775 Mdot
.58348 .65454 Mdot
.6496 .33876 Mdot
.51071 .40137 Mdot
.647 .65872 Mdot
.47646 .32155 Mdot
.64295 .43782 Mdot
.59893 .48474 Mdot
.58293 .64853 Mdot
.46103 .67672 Mdot
.43954 .69093 Mdot
.7478 .52798 Mdot
.31285 .5112 Mdot
.3586 .45901 Mdot
.44376 .69557 Mdot
.63842 .80754 Mdot
.51261 .3785 Mdot
.50286 .37003 Mdot
.47347 .48559 Mdot
.56768 .37942 Mdot
.76573 .47924 Mdot
.42189 .56204 Mdot
.36451 .46275 Mdot
.57288 .34368 Mdot
.5682 .34402 Mdot
.52438 .35123 Mdot
.67115 .375 Mdot
.61636 .66009 Mdot
.51917 .34635 Mdot
.7455 .49259 Mdot
.41585 .49926 Mdot
.54903 .39348 Mdot
.45775 .385 Mdot
.3157 .46201 Mdot
.65996 .60943 Mdot
.42578 .70671 Mdot
.60322 .64756 Mdot
.59423 .65079 Mdot
.7119 .35339 Mdot
.34008 .52823 Mdot
.4301 .58477 Mdot
.48334 .76789 Mdot
.42092 .58814 Mdot
.74311 .51047 Mdot
.51102 .57161 Mdot
.60491 .70944 Mdot
.6057 .69019 Mdot
.47068 .71658 Mdot
.56568 .32471 Mdot
.55021 .39408 Mdot
.3559 .70694 Mdot
.49512 .37364 Mdot
.74163 .52523 Mdot
.43744 .73003 Mdot
.31158 .47295 Mdot
.75714 .49228 Mdot
.42447 .69216 Mdot
.36191 .46765 Mdot
.58362 .34564 Mdot
.55368 .39668 Mdot
.33869 .48716 Mdot
.3261 .50038 Mdot
.52625 .3859 Mdot
.64729 .22658 Mdot
.36652 .47131 Mdot
.34659 .48491 Mdot
.41671 .49011 Mdot
.64291 .69231 Mdot
.45888 .43905 Mdot
.42733 .72198 Mdot
.53105 .40287 Mdot
.59754 .63906 Mdot
.73815 .50349 Mdot
.32651 .49303 Mdot
.51174 .33816 Mdot
.5129 .37117 Mdot
.72523 .50984 Mdot
.76453 .51797 Mdot
.72212 .52834 Mdot
.44547 .73628 Mdot
.55202 .35216 Mdot
.35468 .47631 Mdot
.41447 .70762 Mdot
.72991 .48805 Mdot
.74711 .53325 Mdot
.62174 .23289 Mdot
.51596 .38395 Mdot
.75966 .48884 Mdot
.63431 .8673 Mdot
.62645 .25936 Mdot
.40806 .55795 Mdot
.65818 .70341 Mdot
.78238 .55075 Mdot
.70888 .48243 Mdot
.42126 .676 Mdot
.54046 .58468 Mdot
.71551 .53414 Mdot
.49443 .35786 Mdot
.49769 .39068 Mdot
.46686 .38569 Mdot
.72071 .52168 Mdot
.67907 .39307 Mdot
.3041 .45611 Mdot
.34856 .26795 Mdot
.72362 .52052 Mdot
.58049 .65843 Mdot
.66333 .66681 Mdot
.63494 .67518 Mdot
.49534 .34119 Mdot
.49575 .20533 Mdot
.3096 .37698 Mdot
.29461 .31934 Mdot
.4162 .70682 Mdot
.35846 .44587 Mdot
.41493 .5339 Mdot
.33078 .48781 Mdot
.63007 .65581 Mdot
.71582 .50616 Mdot
.31594 .45252 Mdot
.45092 .71866 Mdot
.44241 .69042 Mdot
.65105 .65653 Mdot
.62253 .66571 Mdot
.62061 .67763 Mdot
.31006 .50965 Mdot
.32825 .46099 Mdot
.55876 .33637 Mdot
.32226 .49483 Mdot
.81019 .44482 Mdot
.79086 .50247 Mdot
.65449 .65607 Mdot
.43529 .71076 Mdot
.34561 .49194 Mdot
.49746 .39879 Mdot
.58954 .57494 Mdot
.568 .65343 Mdot
.71453 .49747 Mdot
.22775 .63949 Mdot
.21893 .69833 Mdot
.53723 .31528 Mdot
.42069 .66924 Mdot
.53708 .26483 Mdot
.52748 .39912 Mdot
.65018 .67417 Mdot
.78991 .40409 Mdot
.40699 .58853 Mdot
.54626 .38939 Mdot
.57954 .36758 Mdot
.45523 .70988 Mdot
.60316 .48123 Mdot
.49392 .35714 Mdot
.52652 .5943 Mdot
.46515 .6936 Mdot
.64672 .70249 Mdot
.78249 .29598 Mdot
.43397 .50327 Mdot
.69253 .4335 Mdot
.40154 .56206 Mdot
.49439 .36678 Mdot
.60868 .67045 Mdot
.73691 .48933 Mdot
.61544 .66956 Mdot
.3635 .49996 Mdot
.64843 .68787 Mdot
.49077 .38423 Mdot
.35452 .47122 Mdot
.42728 .69507 Mdot
.53873 .55423 Mdot
.53029 .22592 Mdot
.58847 .67616 Mdot
.40457 .55317 Mdot
.55388 .36893 Mdot
.25409 .38718 Mdot
.58809 .37443 Mdot
.53222 .40556 Mdot
.44214 .67219 Mdot
.34324 .47087 Mdot
.46021 .68701 Mdot
.45459 .37234 Mdot
.24001 .46334 Mdot
.4278 .71395 Mdot
.42598 .44059 Mdot
.70752 .51852 Mdot
.67403 .39134 Mdot
.53771 .36942 Mdot
.43122 .67785 Mdot
.54511 .34709 Mdot
.30128 .48384 Mdot
.6528 .39509 Mdot
.62815 .42257 Mdot
.45335 .69079 Mdot
.38707 .57251 Mdot
.64718 .45234 Mdot
.46144 .44337 Mdot
.41949 .68845 Mdot
.53031 .19657 Mdot
.40833 .57838 Mdot
.72387 .50241 Mdot
.76681 .5158 Mdot
.75161 .50226 Mdot
.4974 .37606 Mdot
.26458 .42123 Mdot
.7545 .52598 Mdot
.45971 .71952 Mdot
.75964 .51082 Mdot
.77681 .45659 Mdot
.35149 .72106 Mdot
.70824 .51598 Mdot
.53325 .365 Mdot
.53777 .27777 Mdot
.54042 .58187 Mdot
.59714 .69365 Mdot
.29416 .5585 Mdot
.68632 .23864 Mdot
.50693 .38179 Mdot
.25393 .44244 Mdot
.36748 .50274 Mdot
.6475 .55803 Mdot
.62779 .41856 Mdot
.51427 .54137 Mdot
.34608 .48911 Mdot
.58796 .48383 Mdot
.36292 .49043 Mdot
.46697 .42042 Mdot
.5152 .36381 Mdot
.31105 .51257 Mdot
.27128 .6707 Mdot
.5072 .18234 Mdot
.33676 .70299 Mdot
.36075 .4825 Mdot
.41991 .69187 Mdot
.43259 .66834 Mdot
.44069 .67199 Mdot
.60183 .66886 Mdot
.30768 .48342 Mdot
.5083 .3536 Mdot
.63091 .69083 Mdot
.54617 .36704 Mdot
.44965 .69822 Mdot
.63753 .40597 Mdot
.31213 .47026 Mdot
.53588 .37723 Mdot
.36696 .39695 Mdot
.60986 .65343 Mdot
.7222 .51276 Mdot
.21719 .60995 Mdot
.64663 .71058 Mdot
.45252 .66686 Mdot
.37877 .47052 Mdot
.66107 .64932 Mdot
.58667 .5958 Mdot
.51501 .41598 Mdot
.53329 .41273 Mdot
.54584 .58976 Mdot
.40115 .3872 Mdot
.4932 .35508 Mdot
.62174 .69195 Mdot
.62729 .6978 Mdot
.54291 .34717 Mdot
.30875 .49294 Mdot
.72778 .53952 Mdot
.7011 .50341 Mdot
.47429 .42199 Mdot
.57086 .48861 Mdot
.65175 .34922 Mdot
.57297 .35355 Mdot
.46857 .35916 Mdot
.57616 .65875 Mdot
.40423 .5576 Mdot
.54254 .49092 Mdot
.75354 .51364 Mdot
.52915 .3545 Mdot
.44852 .21182 Mdot
.31229 .48919 Mdot
.64553 .65475 Mdot
.41111 .70856 Mdot
.72327 .48817 Mdot
.658 .66717 Mdot
.54285 .3472 Mdot
.56876 .34453 Mdot
.43586 .68 Mdot
.35012 .52059 Mdot
.71413 .51611 Mdot
.63112 .6915 Mdot
.75027 .5149 Mdot
.32502 .46275 Mdot
.33756 .49506 Mdot
.55923 .40348 Mdot
.58551 .38649 Mdot
.58835 .66849 Mdot
.47181 .40366 Mdot
.62944 .68553 Mdot
.50115 .76167 Mdot
.40913 .67971 Mdot
.57882 .34452 Mdot
.34905 .52833 Mdot
.44801 .69635 Mdot
.50869 .38676 Mdot
.54645 .59335 Mdot
.54608 .32195 Mdot
.6039 .63141 Mdot
.79109 .38095 Mdot
.74354 .50073 Mdot
.57057 .30217 Mdot
.46581 .28193 Mdot
.57076 .37081 Mdot
.61103 .69776 Mdot
.28418 .38194 Mdot
.43321 .71706 Mdot
.33587 .45955 Mdot
.69307 .67527 Mdot
.4385 .70313 Mdot
.53088 .35994 Mdot
.73653 .52222 Mdot
.3603 .49082 Mdot
.4177 .56624 Mdot
.53912 .5031 Mdot
.51776 .28482 Mdot
.53283 .42798 Mdot
.48615 .36418 Mdot
.40354 .80274 Mdot
.61879 .67515 Mdot
.34915 .47816 Mdot
.41877 .67121 Mdot
.44546 .7175 Mdot
.61649 .65453 Mdot
.41902 .47085 Mdot
.30587 .69469 Mdot
.68071 .83721 Mdot
.65833 .66507 Mdot
.75711 .50527 Mdot
.65114 .39646 Mdot
.63681 .67494 Mdot
.60061 .66139 Mdot
.57423 .66492 Mdot
.35645 .71548 Mdot
.36029 .48024 Mdot
.51137 .37114 Mdot
.386 .47956 Mdot
.49514 .37003 Mdot
.6776 .44496 Mdot
.44909 .70006 Mdot
.33512 .45922 Mdot
.68579 .4671 Mdot
.49793 .32265 Mdot
.52826 .39428 Mdot
.67113 .48453 Mdot
.59323 .30307 Mdot
.67756 .2801 Mdot
.55593 .40132 Mdot
.61202 .66432 Mdot
.36426 .53798 Mdot
.46031 .37464 Mdot
.36277 .39769 Mdot
.43634 .68894 Mdot
.42564 .58274 Mdot
.46117 .40768 Mdot
.47404 .36425 Mdot
.35806 .4955 Mdot
.31812 .45169 Mdot
.75181 .5301 Mdot
.21126 .57555 Mdot
.43283 .68985 Mdot
.36558 .63309 Mdot
.53401 .40548 Mdot
.43009 .62994 Mdot
.79742 .39888 Mdot
.51422 .38957 Mdot
.51135 .6058 Mdot
.44867 .2454 Mdot
.51621 .33073 Mdot
.30472 .30833 Mdot
.44015 .70885 Mdot
.71594 .40477 Mdot
.56208 .36307 Mdot
.64771 .66513 Mdot
.3493 .45822 Mdot
.31773 .44359 Mdot
.73781 .48848 Mdot
.82057 .43483 Mdot
.28694 .75101 Mdot
.33379 .45837 Mdot
.5142 .4029 Mdot
.42771 .70772 Mdot
.42299 .57279 Mdot
.5038 .29432 Mdot
.49089 .65659 Mdot
.31322 .48754 Mdot
.46244 .36052 Mdot
.32024 .68049 Mdot
.59537 .48331 Mdot
.21477 .39742 Mdot
.44456 .67562 Mdot
.75377 .5185 Mdot
.53486 .43754 Mdot
.48347 .77079 Mdot
.55286 .39783 Mdot
.68205 .44074 Mdot
.31357 .52128 Mdot
.74694 .52422 Mdot
.53483 .39374 Mdot
.49665 .35062 Mdot
.59753 .46434 Mdot
.76625 .52226 Mdot
.49494 .35469 Mdot
.52939 .31296 Mdot
.34046 .45414 Mdot
.42074 .56033 Mdot
.31193 .4749 Mdot
.54175 .38649 Mdot
.76992 .34992 Mdot
.30378 .4711 Mdot
.3243 .56395 Mdot
.74606 .55963 Mdot
.42373 .71506 Mdot
.4972 .3055 Mdot
.4931 .40355 Mdot
.19648 .41591 Mdot
.42278 .56932 Mdot
.5318 .84576 Mdot
.61539 .63251 Mdot
.63554 .18361 Mdot
.64322 .71166 Mdot
.38516 .58714 Mdot
.53952 .64471 Mdot
.46405 .36475 Mdot
.42152 .43041 Mdot
.28721 .32021 Mdot
.40007 .66859 Mdot
.24555 .36358 Mdot
.53958 .40201 Mdot
.52656 .35271 Mdot
.63736 .68403 Mdot
.4036 .61014 Mdot
.52389 .27197 Mdot
.54542 .49092 Mdot
.72486 .49658 Mdot
.32548 .47738 Mdot
.49618 .39138 Mdot
.25456 .65922 Mdot
.58245 .6671 Mdot
.53772 .23458 Mdot
.53526 .37435 Mdot
.54891 .26801 Mdot
.40597 .61 Mdot
.42566 .69705 Mdot
.58267 .64817 Mdot
.57957 .66647 Mdot
.49584 .36642 Mdot
.40976 .69777 Mdot
.54893 .32955 Mdot
.65071 .4452 Mdot
.4748 .32624 Mdot
.74148 .50745 Mdot
.51354 .40751 Mdot
.50813 .24935 Mdot
.27136 .26288 Mdot
.52825 .31159 Mdot
.33082 .51061 Mdot
.62046 .68066 Mdot
.62149 .65907 Mdot
.36091 .46136 Mdot
.62183 .65854 Mdot
.34684 .27375 Mdot
.24216 .43579 Mdot
.74521 .51212 Mdot
.32115 .33168 Mdot
.73598 .49773 Mdot
.42542 .58393 Mdot
.51895 .38522 Mdot
.58117 .73603 Mdot
.66034 .67351 Mdot
.7805 .45353 Mdot
.44437 .69842 Mdot
.42282 .56794 Mdot
.55489 .36472 Mdot
.67802 .49087 Mdot
.63912 .66187 Mdot
.47594 .55 Mdot
.50108 .36417 Mdot
.30491 .49897 Mdot
.52227 .3278 Mdot
.60215 .3589 Mdot
.42551 .56985 Mdot
.5101 .33096 Mdot
.42436 .6923 Mdot
.30681 .47151 Mdot
.39166 .62029 Mdot
.59796 .65856 Mdot
.55083 .3818 Mdot
.5172 .40266 Mdot
.37142 .46229 Mdot
.51552 .41427 Mdot
.41279 .69454 Mdot
.87071 .64262 Mdot
.7173 .5277 Mdot
.40289 .55855 Mdot
.26248 .56859 Mdot
.50767 .33466 Mdot
.56702 .33869 Mdot
.48801 .5304 Mdot
.45197 .21054 Mdot
.42127 .70593 Mdot
.51641 .43119 Mdot
.6171 .69561 Mdot
.71304 .51514 Mdot
.45897 .7091 Mdot
.55627 .35959 Mdot
.51088 .3613 Mdot
.74559 .52398 Mdot
.66987 .48104 Mdot
.76739 .4894 Mdot
.41558 .68158 Mdot
.25245 .46918 Mdot
.59164 .57401 Mdot
.51908 .37671 Mdot
.39792 .55052 Mdot
.34195 .47453 Mdot
.41751 .68943 Mdot
.42348 .24047 Mdot
.46763 .42164 Mdot
.4179 .6634 Mdot
.42845 .69332 Mdot
.50762 .41356 Mdot
.33529 .52773 Mdot
.38015 .46332 Mdot
.34442 .4768 Mdot
.70591 .37629 Mdot
.47414 .82864 Mdot
.61631 .67766 Mdot
.43407 .70812 Mdot
.60162 .63798 Mdot
.71426 .53215 Mdot
.64641 .42059 Mdot
.58457 .67568 Mdot
.30239 .50036 Mdot
.59418 .64569 Mdot
.55 .32892 Mdot
.44261 .72538 Mdot
.59009 .66406 Mdot
.56824 .37104 Mdot
.47755 .36661 Mdot
.54381 .44254 Mdot
.71364 .53618 Mdot
.58631 .4857 Mdot
.53779 .36348 Mdot
.41515 .58989 Mdot
.52993 .38249 Mdot
.41181 .69484 Mdot
.54307 .55221 Mdot
.52902 .34238 Mdot
.66044 .67271 Mdot
.49296 .83941 Mdot
.63321 .69942 Mdot
.60663 .37449 Mdot
.54269 .3787 Mdot
.51664 .37872 Mdot
.55345 .36339 Mdot
.41691 .46413 Mdot
.43737 .65945 Mdot
.50973 .43673 Mdot
.63812 .64238 Mdot
.33183 .48999 Mdot
.30309 .46738 Mdot
.50083 .54578 Mdot
.42719 .59054 Mdot
.41379 .70994 Mdot
.51481 .37834 Mdot
.47807 .55357 Mdot
.51102 .50927 Mdot
.32557 .69308 Mdot
.67362 .69193 Mdot
.60148 .68748 Mdot
.31926 .50925 Mdot
.60088 .68091 Mdot
.55718 .36431 Mdot
.46316 .35953 Mdot
.38958 .6174 Mdot
.41165 .65398 Mdot
.71384 .51224 Mdot
.5462 .37284 Mdot
.6615 .35238 Mdot
.6298 .6937 Mdot
.57679 .66145 Mdot
.54986 .33106 Mdot
.36519 .51135 Mdot
.34972 .19023 Mdot
.42296 .72103 Mdot
.2547 .39642 Mdot
.39103 .44711 Mdot
.62953 .38767 Mdot
.44152 .71629 Mdot
.51471 .59763 Mdot
.60253 .69788 Mdot
.76654 .32991 Mdot
.33665 .49016 Mdot
.71453 .51376 Mdot
.5598 .38865 Mdot
.30234 .50065 Mdot
.64026 .63897 Mdot
.36767 .48002 Mdot
.46166 .404 Mdot
.46322 .69855 Mdot
.63003 .66408 Mdot
.46493 .72724 Mdot
.35768 .50357 Mdot
.73891 .49835 Mdot
.72829 .42111 Mdot
.26351 .38256 Mdot
.44665 .24834 Mdot
.51789 .34665 Mdot
.54806 .6885 Mdot
.50612 .35422 Mdot
.30608 .44951 Mdot
.53731 .36867 Mdot
.50891 .31012 Mdot
.59936 .69741 Mdot
.53945 .41433 Mdot
.52085 .40729 Mdot
.35078 .39838 Mdot
.52007 .39224 Mdot
.53975 .34836 Mdot
.56083 .40309 Mdot
.31437 .5172 Mdot
.5435 .41235 Mdot
.30809 .50224 Mdot
.33965 .68863 Mdot
.60067 .65648 Mdot
.7164 .53311 Mdot
.71033 .52649 Mdot
.69318 .43717 Mdot
.66485 .36129 Mdot
.39908 .5181 Mdot
.31617 .48184 Mdot
.4447 .68866 Mdot
.55318 .33153 Mdot
.54648 .19545 Mdot
.76423 .35294 Mdot
.61882 .70417 Mdot
.58814 .65842 Mdot
.55867 .38469 Mdot
.20867 .68088 Mdot
.55068 .4041 Mdot
.47532 .48921 Mdot
.498 .37466 Mdot
.57855 .34257 Mdot
.58074 .64702 Mdot
.6951 .4106 Mdot
.51924 .34644 Mdot
.35842 .49542 Mdot
.71762 .50875 Mdot
.56464 .27555 Mdot
.76762 .37833 Mdot
.38224 .41827 Mdot
.48437 .27942 Mdot
.54061 .3418 Mdot
.64089 .68727 Mdot
.35975 .48726 Mdot
.49142 .49553 Mdot
.41415 .70172 Mdot
.5578 .49696 Mdot
.29659 .34725 Mdot
.39283 .67998 Mdot
.7163 .50729 Mdot
.58893 .6284 Mdot
.48881 .37916 Mdot
.60543 .67333 Mdot
.48709 .43111 Mdot
.51268 .5139 Mdot
.74514 .50911 Mdot
.29159 .49663 Mdot
.42007 .69258 Mdot
.29878 .47618 Mdot
.49692 .22278 Mdot
.76504 .35036 Mdot
.64081 .18519 Mdot
.65338 .68733 Mdot
.37916 .21582 Mdot
.34702 .46639 Mdot
.50067 .36093 Mdot
.67736 .8389 Mdot
.33609 .47105 Mdot
.30526 .50069 Mdot
.53037 .53109 Mdot
.69657 .39796 Mdot
.47261 .4065 Mdot
.36719 .46834 Mdot
.59515 .6268 Mdot
.73644 .51292 Mdot
.56893 .36399 Mdot
.46025 .40401 Mdot
.3162 .45287 Mdot
.63533 .65733 Mdot
.6804 .42882 Mdot
.61691 .66422 Mdot
.35925 .47728 Mdot
.6132 .64766 Mdot
.35659 .57192 Mdot
.58491 .67419 Mdot
.50295 .40682 Mdot
.51552 .37766 Mdot
.46153 .61208 Mdot
.33752 .49506 Mdot
.56795 .33941 Mdot
.51966 .35715 Mdot
.35267 .47354 Mdot
.59592 .70565 Mdot
.41824 .2187 Mdot
.56196 .33287 Mdot
.5119 .37509 Mdot
.72211 .53145 Mdot
.63089 .45628 Mdot
.46452 .4891 Mdot
.57051 .36632 Mdot
.75225 .50097 Mdot
.3095 .50821 Mdot
.52941 .38432 Mdot
.6973 .41157 Mdot
.66221 .69116 Mdot
.55517 .34488 Mdot
.42085 .57221 Mdot
.49121 .36785 Mdot
.33152 .20953 Mdot
.55384 .37368 Mdot
.35273 .48418 Mdot
.34999 .46151 Mdot
.67719 .70178 Mdot
.33348 .48522 Mdot
.40884 .55854 Mdot
.44049 .69182 Mdot
.22454 .39974 Mdot
.41218 .55846 Mdot
.51546 .32662 Mdot
.82456 .41058 Mdot
.45843 .39983 Mdot
.45745 .37327 Mdot
.81827 .49407 Mdot
.40205 .56223 Mdot
.34075 .46657 Mdot
.26408 .65815 Mdot
.48782 .41471 Mdot
.41477 .71236 Mdot
.45898 .38226 Mdot
.5545 .34462 Mdot
.52751 .3079 Mdot
.24592 .45817 Mdot
.42582 .72692 Mdot
.45879 .43973 Mdot
.56907 .36326 Mdot
.45236 .21106 Mdot
.50101 .39853 Mdot
.70964 .50274 Mdot
.31752 .46768 Mdot
.60194 .67887 Mdot
.7387 .50858 Mdot
.48843 .36177 Mdot
.72339 .52203 Mdot
.60889 .67485 Mdot
.4389 .67646 Mdot
.49906 .40448 Mdot
.75569 .53242 Mdot
.7166 .5037 Mdot
.52726 .33454 Mdot
.33963 .45728 Mdot
.58932 .36763 Mdot
.52704 .38653 Mdot
.55202 .35613 Mdot
.35641 .45747 Mdot
.76443 .70818 Mdot
.52705 .3509 Mdot
.51431 .6008 Mdot
.29603 .45409 Mdot
.41794 .55832 Mdot
.61357 .69027 Mdot
.52166 .3162 Mdot
.44314 .72026 Mdot
.44113 .69373 Mdot
.65832 .68555 Mdot
.32446 .45141 Mdot
.62791 .66041 Mdot
.52614 .3112 Mdot
.46211 .36632 Mdot
.56037 .38609 Mdot
.69429 .68561 Mdot
.34112 .58775 Mdot
.34021 .49875 Mdot
.61699 .70055 Mdot
.55724 .49339 Mdot
.43548 .72581 Mdot
.5777 .64621 Mdot
.36509 .44195 Mdot
.3433 .45013 Mdot
.36408 .46697 Mdot
.74281 .49428 Mdot
.62923 .66847 Mdot
.37836 .45132 Mdot
.37781 .45942 Mdot
.5436 .33193 Mdot
.56871 .35718 Mdot
.31506 .51475 Mdot
.6449 .61862 Mdot
.73485 .50104 Mdot
.64315 .68813 Mdot
.30614 .20995 Mdot
.42091 .71972 Mdot
.35455 .39842 Mdot
.56869 .37289 Mdot
.497 .90684 Mdot
.55187 .40359 Mdot
.50967 .40248 Mdot
.34332 .51215 Mdot
.76968 .50628 Mdot
.73413 .51495 Mdot
.3472 .46553 Mdot
.3574 .44925 Mdot
.722 .49389 Mdot
.52129 .54344 Mdot
.36865 .19413 Mdot
.5077 .50273 Mdot
.3474 .49682 Mdot
.26389 .3744 Mdot
.45565 .69327 Mdot
.29139 .47153 Mdot
.44613 .75485 Mdot
.60129 .65266 Mdot
.58649 .67157 Mdot
.44041 .68133 Mdot
.53204 .34894 Mdot
.65267 .67172 Mdot
.57279 .31481 Mdot
.3809 .59719 Mdot
.47385 .64158 Mdot
.60324 .19707 Mdot
.50371 .40918 Mdot
.55299 .26374 Mdot
.37484 .76969 Mdot
.53396 .31927 Mdot
.41757 .3499 Mdot
.71586 .51775 Mdot
.29232 .46306 Mdot
.44203 .73204 Mdot
.22548 .47452 Mdot
.51783 .37742 Mdot
.35259 .49402 Mdot
.42853 .72543 Mdot
.3647 .59435 Mdot
.52594 .59381 Mdot
.5319 .32647 Mdot
.73043 .79658 Mdot
.36714 .48676 Mdot
.60253 .67938 Mdot
.33611 .38119 Mdot
.29674 .4831 Mdot
.55584 .60071 Mdot
.61926 .62762 Mdot
.52675 .4879 Mdot
.36907 .46681 Mdot
.76596 .48735 Mdot
.32187 .47365 Mdot
.76171 .4998 Mdot
.37843 .4703 Mdot
.62031 .65083 Mdot
.53384 .38981 Mdot
.61436 .65261 Mdot
.70903 .49981 Mdot
.65559 .68479 Mdot
.44223 .73193 Mdot
.3999 .568 Mdot
.45011 .69698 Mdot
.64872 .40617 Mdot
.40435 .256 Mdot
.42611 .67579 Mdot
.48711 .57852 Mdot
.49224 .37798 Mdot
.34949 .51892 Mdot
.60021 .67383 Mdot
.62268 .70978 Mdot
.58098 .4865 Mdot
.36064 .47113 Mdot
.63196 .65277 Mdot
.26749 .37811 Mdot
.62803 .81794 Mdot
.49352 .31863 Mdot
.47969 .80857 Mdot
.35388 .47869 Mdot
.58684 .68722 Mdot
.47267 .4859 Mdot
.3116 .45168 Mdot
.58885 .66583 Mdot
.42155 .68643 Mdot
.43951 .72072 Mdot
.51809 .41355 Mdot
.45915 .72763 Mdot
.5959 .691 Mdot
.45237 .20809 Mdot
.3247 .45863 Mdot
.32101 .58208 Mdot
.71044 .51835 Mdot
.60143 .66519 Mdot
.51022 .42075 Mdot
.34722 .52986 Mdot
.60044 .64146 Mdot
.26377 .73254 Mdot
.21941 .30081 Mdot
.63365 .6534 Mdot
.31701 .46862 Mdot
.32563 .49184 Mdot
.50252 .32574 Mdot
.56091 .48944 Mdot
.63987 .6602 Mdot
.57945 .73504 Mdot
.64866 .3245 Mdot
.40857 .56383 Mdot
.68405 .237 Mdot
.52015 .34676 Mdot
.54259 .34165 Mdot
.41357 .68491 Mdot
.52401 .3955 Mdot
.36123 .44904 Mdot
.55345 .40242 Mdot
.45582 .67754 Mdot
.6534 .69502 Mdot
.52008 .38226 Mdot
.71241 .51667 Mdot
.45455 .67972 Mdot
.43294 .66598 Mdot
.60959 .64609 Mdot
.33947 .45266 Mdot
.28334 .69771 Mdot
.61903 .66413 Mdot
.55133 .35041 Mdot
.40723 .58168 Mdot
.54942 .41103 Mdot
.45901 .60581 Mdot
.3097 .44658 Mdot
.60159 .68132 Mdot
.29111 .49962 Mdot
.43143 .70468 Mdot
.60845 .70258 Mdot
.4872 .37562 Mdot
.59309 .68 Mdot
.51978 .62277 Mdot
.71271 .58948 Mdot
.37448 .45633 Mdot
.54615 .60411 Mdot
.3294 .44944 Mdot
.41025 .56272 Mdot
.70592 .3465 Mdot
.72683 .50167 Mdot
.63097 .69645 Mdot
.32753 .56525 Mdot
.59596 .66268 Mdot
.51477 .39176 Mdot
.50797 .36215 Mdot
.6356 .68517 Mdot
.74304 .49737 Mdot
.72015 .44761 Mdot
.75439 .4772 Mdot
.30851 .4829 Mdot
.53176 .5642 Mdot
.33471 .19049 Mdot
.67031 .68398 Mdot
.44108 .68564 Mdot
.45115 .31274 Mdot
.51213 .33264 Mdot
.4274 .7264 Mdot
.41377 .67272 Mdot
.74362 .48696 Mdot
.59907 .66246 Mdot
.30431 .44599 Mdot
.4578 .71345 Mdot
.3458 .53319 Mdot
.68943 .42268 Mdot
.47083 .42726 Mdot
.61962 .40175 Mdot
.4822 .36893 Mdot
.59474 .484 Mdot
.46333 .68943 Mdot
.52675 .36203 Mdot
.50953 .4441 Mdot
.41662 .69739 Mdot
.75362 .48893 Mdot
.27679 .50448 Mdot
.63088 .65023 Mdot
.55745 .87299 Mdot
.50328 .40613 Mdot
.53217 .38735 Mdot
.41657 .70777 Mdot
.39846 .37724 Mdot
.33508 .50288 Mdot
.33281 .45377 Mdot
.61954 .6756 Mdot
.51227 .52218 Mdot
.51313 .41471 Mdot
.49224 .39496 Mdot
.64838 .66365 Mdot
.41565 .58905 Mdot
.66945 .22112 Mdot
.51477 .37025 Mdot
.4414 .71162 Mdot
.50704 .62409 Mdot
.46469 .69623 Mdot
.56745 .31889 Mdot
.50871 .38995 Mdot
.48456 .37773 Mdot
.4876 .4026 Mdot
.45288 .6929 Mdot
.48669 .36273 Mdot
.49683 .43269 Mdot
.3417 .47029 Mdot
.53347 .34307 Mdot
.64725 .31911 Mdot
.51803 .37193 Mdot
.71453 .51922 Mdot
.47169 .4959 Mdot
.55232 .37525 Mdot
.53624 .34302 Mdot
.65043 .33199 Mdot
.53354 .39697 Mdot
.4289 .72615 Mdot
.33156 .49281 Mdot
.43014 .70543 Mdot
.43492 .6863 Mdot
.59559 .64611 Mdot
.76492 .50801 Mdot
.47417 .3801 Mdot
.73487 .49078 Mdot
.4987 .32579 Mdot
.45561 .3678 Mdot
.6446 .43783 Mdot
.47847 .49112 Mdot
.7111 .53113 Mdot
.49161 .3907 Mdot
.61265 .67325 Mdot
.59985 .6814 Mdot
.54087 .58584 Mdot
.47918 .32215 Mdot
.45437 .72475 Mdot
.43055 .67802 Mdot
.79076 .49932 Mdot
.71136 .57558 Mdot
.71636 .50216 Mdot
.66118 .47134 Mdot
.5835 .35041 Mdot
.54053 .35329 Mdot
.48969 .30481 Mdot
.60573 .63432 Mdot
.39959 .56592 Mdot
.65393 .66437 Mdot
.41576 .61734 Mdot
.45835 .69842 Mdot
.50555 .40958 Mdot
.1845 .63329 Mdot
.30567 .48047 Mdot
.33135 .4934 Mdot
.456 .67743 Mdot
.63116 .69942 Mdot
.47228 .3303 Mdot
.48053 .8648 Mdot
.33102 .44156 Mdot
.7327 .53652 Mdot
.5407 .39241 Mdot
.60315 .65272 Mdot
.30981 .46694 Mdot
.75101 .53472 Mdot
.48749 .39997 Mdot
.60913 .62628 Mdot
.52826 .36678 Mdot
.32799 .30825 Mdot
.33698 .46271 Mdot
.62797 .44139 Mdot
.33696 .51745 Mdot
.45293 .69715 Mdot
.42222 .70401 Mdot
.50855 .38734 Mdot
.51757 .874 Mdot
.35465 .53755 Mdot
.4068 .67841 Mdot
.75537 .52855 Mdot
.40131 .57629 Mdot
.75874 .52209 Mdot
.63112 .68494 Mdot
.7181 .50598 Mdot
.59921 .64291 Mdot
.64201 .61686 Mdot
.34982 .43314 Mdot
.74451 .52425 Mdot
.43036 .30945 Mdot
.46429 .35526 Mdot
.7173 .49215 Mdot
.56132 .3761 Mdot
.51375 .31368 Mdot
.63993 .65246 Mdot
.73516 .49314 Mdot
.51271 .33769 Mdot
.25922 .56431 Mdot
.42421 .69469 Mdot
.44983 .72897 Mdot
.46209 .37016 Mdot
.57797 .67486 Mdot
.37393 .45862 Mdot
.62804 .47225 Mdot
.41824 .55603 Mdot
.49366 .39677 Mdot
.49657 .3384 Mdot
.36395 .49584 Mdot
.32941 .50856 Mdot
.50558 .38717 Mdot
.25433 .41333 Mdot
.48741 .36755 Mdot
.43595 .7209 Mdot
.30787 .4832 Mdot
.32648 .49345 Mdot
.59244 .68694 Mdot
.31898 .45328 Mdot
.55561 .41944 Mdot
.39757 .68536 Mdot
.49687 .42562 Mdot
.43454 .70423 Mdot
.67103 .64903 Mdot
.62505 .63986 Mdot
.32057 .56477 Mdot
.31879 .45428 Mdot
.57235 .34276 Mdot
.30266 .47129 Mdot
.72525 .52948 Mdot
.33331 .49652 Mdot
.36251 .50417 Mdot
.53982 .40366 Mdot
.49622 .35381 Mdot
.41559 .58609 Mdot
.57221 .48671 Mdot
.33055 .46442 Mdot
.54804 .31861 Mdot
.57027 .3766 Mdot
.50491 .36245 Mdot
.64443 .45596 Mdot
.30924 .51123 Mdot
.38455 .41967 Mdot
.44123 .58022 Mdot
.33039 .46125 Mdot
.22939 .30651 Mdot
.42192 .58656 Mdot
.4264 .59391 Mdot
.46263 .67655 Mdot
.51146 .37218 Mdot
.62354 .65707 Mdot
.54681 .34242 Mdot
.5167 .29101 Mdot
.55048 .37909 Mdot
.74408 .52694 Mdot
.51512 .41634 Mdot
.41211 .56904 Mdot
.6131 .66163 Mdot
.53976 .31942 Mdot
.51377 .38155 Mdot
.42606 .59079 Mdot
.31282 .51471 Mdot
.336 .45034 Mdot
.43422 .59364 Mdot
.73234 .48802 Mdot
.43998 .67043 Mdot
.55128 .34859 Mdot
.61659 .67436 Mdot
.61595 .65551 Mdot
.30021 .4889 Mdot
.64921 .67095 Mdot
.44787 .67365 Mdot
.50617 .39995 Mdot
.45263 .69598 Mdot
.7437 .5273 Mdot
.31784 .46708 Mdot
.55788 .36749 Mdot
.53738 .33139 Mdot
.34974 .46143 Mdot
.49111 .36128 Mdot
.73774 .53226 Mdot
.59194 .63975 Mdot
.33095 .49989 Mdot
.43935 .69228 Mdot
.58789 .68086 Mdot
.56096 .33547 Mdot
.17675 .39198 Mdot
.52215 .39591 Mdot
.48965 .39414 Mdot
.38492 .53429 Mdot
.57867 .36148 Mdot
.59687 .65974 Mdot
.30522 .46358 Mdot
.53799 .3148 Mdot
.65275 .33504 Mdot
.77512 .52152 Mdot
.66256 .65525 Mdot
.53131 .40217 Mdot
.21188 .39723 Mdot
.57348 .36342 Mdot
.31312 .55998 Mdot
.64411 .43807 Mdot
.46794 .76585 Mdot
.61948 .40177 Mdot
.4096 .67446 Mdot
.41144 .58767 Mdot
.60546 .64323 Mdot
.38567 .36767 Mdot
.50699 .39304 Mdot
.44906 .24008 Mdot
.55786 .36272 Mdot
.44176 .71714 Mdot
.41358 .37494 Mdot
.64645 .68345 Mdot
.67075 .23589 Mdot
.52012 .35043 Mdot
.36588 .48682 Mdot
.57184 .66797 Mdot
.41528 .59322 Mdot
.50047 .34973 Mdot
.71357 .50066 Mdot
.78744 .50912 Mdot
.56109 .41465 Mdot
.43307 .70223 Mdot
.52921 .3537 Mdot
.58394 .32265 Mdot
.67236 .77165 Mdot
.3467 .47735 Mdot
.42834 .6851 Mdot
.70195 .56848 Mdot
.50468 .36478 Mdot
.34259 .45027 Mdot
.33529 .48995 Mdot
.74802 .49042 Mdot
.47476 .73377 Mdot
.76971 .46856 Mdot
.16924 .55833 Mdot
.49438 .21068 Mdot
.602 .63462 Mdot
.28528 .43764 Mdot
.53918 .3379 Mdot
.7663 .35053 Mdot
.43814 .68725 Mdot
.53434 .38733 Mdot
.44753 .25531 Mdot
.34686 .48427 Mdot
.52237 .36592 Mdot
.7337 .5018 Mdot
.32293 .74442 Mdot
.28849 .36363 Mdot
.19264 .42599 Mdot
.59823 .62612 Mdot
.47265 .4088 Mdot
.54303 .42437 Mdot
.41601 .55682 Mdot
.54945 .31473 Mdot
.60098 .67271 Mdot
.51538 .64424 Mdot
.75016 .50656 Mdot
.30508 .47615 Mdot
.41997 .59188 Mdot
.5582 .36258 Mdot
.48509 .42919 Mdot
.7443 .53303 Mdot
.50118 .35487 Mdot
.32619 .38633 Mdot
.41473 .60383 Mdot
.5837 .6718 Mdot
.36577 .48426 Mdot
.48456 .35876 Mdot
.40436 .58171 Mdot
.54499 .40029 Mdot
.51841 .24746 Mdot
.54476 .37526 Mdot
.30947 .5485 Mdot
.34906 .45777 Mdot
.43156 .69601 Mdot
.50331 .41566 Mdot
.5271 .37295 Mdot
.63958 .57259 Mdot
.47047 .33386 Mdot
.55061 .36073 Mdot
.29777 .47755 Mdot
.30495 .48029 Mdot
.3491 .49972 Mdot
.59717 .68955 Mdot
.51286 .50054 Mdot
.44697 .70411 Mdot
.4887 .30637 Mdot
.45865 .71198 Mdot
.61302 .41564 Mdot
.75336 .52501 Mdot
.30767 .56564 Mdot
.50128 .39431 Mdot
.36308 .47179 Mdot
.39802 .18652 Mdot
.30619 .50652 Mdot
.38752 .70296 Mdot
.43468 .68907 Mdot
.33312 .47028 Mdot
.52918 .40078 Mdot
.55434 .48802 Mdot
.18581 .44219 Mdot
.43804 .72595 Mdot
.459 .39243 Mdot
.6286 .62322 Mdot
.65667 .69551 Mdot
.24568 .29144 Mdot
.45146 .7191 Mdot
.3765 .77229 Mdot
.56031 .33111 Mdot
.30809 .46289 Mdot
.43851 .67231 Mdot
.40775 .70186 Mdot
.65065 .67198 Mdot
.53702 .32773 Mdot
.52621 .37099 Mdot
.422 .57523 Mdot
.44836 .68358 Mdot
.60071 .32348 Mdot
.52768 .32663 Mdot
.38846 .60106 Mdot
.35252 .43713 Mdot
.77393 .69814 Mdot
.42581 .42972 Mdot
.44633 .25452 Mdot
.64892 .75045 Mdot
.32806 .50139 Mdot
.53273 .34804 Mdot
.47441 .3261 Mdot
.59746 .63359 Mdot
.5137 .40043 Mdot
.62603 .703 Mdot
.45447 .70645 Mdot
.26259 .54269 Mdot
.48784 .56395 Mdot
.46268 .64333 Mdot
.52394 .39357 Mdot
.28345 .37058 Mdot
.74497 .52031 Mdot
.40882 .65852 Mdot
.32807 .5063 Mdot
.56955 .32137 Mdot
.61976 .63175 Mdot
.60396 .69326 Mdot
.34124 .48402 Mdot
.35959 .70061 Mdot
.31255 .56211 Mdot
.48136 .39321 Mdot
.62083 .68948 Mdot
.44127 .50787 Mdot
.24288 .36845 Mdot
.44864 .66673 Mdot
.75103 .50903 Mdot
.60098 .6484 Mdot
.44874 .73613 Mdot
.50672 .31682 Mdot
.33327 .47842 Mdot
.37028 .48242 Mdot
.55018 .59591 Mdot
.6315 .65412 Mdot
.72751 .51041 Mdot
.54166 .5947 Mdot
.53437 .57024 Mdot
.74258 .50659 Mdot
.61714 .7037 Mdot
.3131 .49738 Mdot
.35723 .48203 Mdot
.3313 .49211 Mdot
.36325 .3977 Mdot
.31244 .4458 Mdot
.76328 .42385 Mdot
.55408 .31587 Mdot
.25324 .37973 Mdot
.56909 .32528 Mdot
.43801 .73152 Mdot
.33775 .46159 Mdot
.64069 .43768 Mdot
.58169 .36466 Mdot
.19159 .4409 Mdot
.54011 .36507 Mdot
.50948 .61411 Mdot
.51103 .37346 Mdot
.32376 .35207 Mdot
.29378 .46207 Mdot
.48724 .3786 Mdot
.3974 .68121 Mdot
.72223 .52322 Mdot
.37557 .44004 Mdot
.54779 .35785 Mdot
.3231 .67464 Mdot
.56172 .37462 Mdot
.27118 .53681 Mdot
.56967 .59917 Mdot
.70569 .49537 Mdot
.55451 .40807 Mdot
.63537 .6386 Mdot
.48878 .28209 Mdot
.25871 .3742 Mdot
.43996 .72571 Mdot
.27645 .37482 Mdot
.64952 .68554 Mdot
.41245 .37417 Mdot
.58745 .34486 Mdot
.74856 .50252 Mdot
.28248 .51256 Mdot
.43067 .71994 Mdot
.50191 .39103 Mdot
.52174 .35125 Mdot
.48563 .64741 Mdot
.26733 .35769 Mdot
.58671 .29369 Mdot
.72513 .53888 Mdot
.28796 .35763 Mdot
.55093 .36785 Mdot
.65818 .64898 Mdot
.31253 .45253 Mdot
.41777 .3719 Mdot
.40425 .37885 Mdot
.52778 .32241 Mdot
.33637 .47332 Mdot
.32595 .45144 Mdot
.43626 .17071 Mdot
.75544 .5126 Mdot
.54468 .37259 Mdot
.55185 .60377 Mdot
.55365 .35364 Mdot
.44667 .71255 Mdot
.58298 .345 Mdot
.62719 .64179 Mdot
.4654 .47934 Mdot
.59977 .69166 Mdot
.4978 .36763 Mdot
.32003 .47356 Mdot
.42175 .71364 Mdot
.46822 .78536 Mdot
.46453 .74212 Mdot
.76222 .42418 Mdot
.78927 .51771 Mdot
.71351 .50456 Mdot
.76209 .51442 Mdot
.45022 .66096 Mdot
.52477 .4039 Mdot
.5966 .48677 Mdot
.50162 .31076 Mdot
.50799 .37013 Mdot
.54641 .37734 Mdot
.42197 .76788 Mdot
.43371 .69019 Mdot
.61436 .64925 Mdot
.50471 .38736 Mdot
.54935 .31858 Mdot
.32492 .47055 Mdot
.71728 .50237 Mdot
.5853 .65274 Mdot
.70908 .50202 Mdot
.61248 .66603 Mdot
.32781 .21152 Mdot
.46552 .41878 Mdot
.72637 .52438 Mdot
.46218 .69109 Mdot
.35925 .48545 Mdot
.42665 .5802 Mdot
.63366 .68273 Mdot
.64714 .6807 Mdot
.49384 .34712 Mdot
.31729 .46261 Mdot
.32709 .45347 Mdot
.72053 .49494 Mdot
.42961 .67707 Mdot
.48729 .34764 Mdot
.50446 .34172 Mdot
.48482 .7813 Mdot
.59006 .63972 Mdot
.27621 .36599 Mdot
.36979 .54053 Mdot
.51326 .40528 Mdot
.34522 .4512 Mdot
.52536 .38146 Mdot
.44766 .52461 Mdot
.34673 .50279 Mdot
.58077 .35294 Mdot
.53398 .29933 Mdot
.60214 .6357 Mdot
.50288 .17017 Mdot
.4707 .38538 Mdot
.40977 .73246 Mdot
.52819 .3377 Mdot
.6249 .1713 Mdot
.41435 .18257 Mdot
.55517 .39023 Mdot
.49875 .40884 Mdot
.16384 .52947 Mdot
.56675 .38108 Mdot
.4175 .57077 Mdot
.51503 .29106 Mdot
.35222 .45216 Mdot
.52839 .60855 Mdot
.58888 .48518 Mdot
.75821 .50955 Mdot
.61871 .67608 Mdot
.69591 .40374 Mdot
.7602 .49505 Mdot
.35334 .48233 Mdot
.47503 .42551 Mdot
.36889 .5395 Mdot
.62952 .7121 Mdot
.60238 .35491 Mdot
.44506 .715 Mdot
.5875 .48702 Mdot
.6469 .65327 Mdot
.43988 .69135 Mdot
.57397 .36402 Mdot
.69034 .68007 Mdot
.39899 .66977 Mdot
.45059 .16214 Mdot
.41371 .68654 Mdot
.42598 .69798 Mdot
.53117 .4927 Mdot
.75835 .50889 Mdot
.50996 .65554 Mdot
.45301 .42244 Mdot
.42736 .72336 Mdot
.67483 .27186 Mdot
.59054 .63521 Mdot
.51959 .51483 Mdot
.29272 .46988 Mdot
.46074 .4066 Mdot
.53972 .38634 Mdot
.41861 .68562 Mdot
.28362 .44405 Mdot
.64557 .56602 Mdot
.45284 .71303 Mdot
.57081 .39902 Mdot
.50173 .51506 Mdot
.40228 .57473 Mdot
.42318 .58558 Mdot
.74926 .53475 Mdot
.73716 .62202 Mdot
.35346 .45822 Mdot
.72931 .53612 Mdot
.63256 .42059 Mdot
.53739 .35978 Mdot
.45294 .68885 Mdot
.42367 .59247 Mdot
.44035 .69484 Mdot
.73856 .51761 Mdot
.74839 .5311 Mdot
.34281 .47148 Mdot
.32938 .50388 Mdot
.25171 .48983 Mdot
.63417 .27906 Mdot
.55484 .34247 Mdot
.41791 .24108 Mdot
.33112 .508 Mdot
.39152 .37693 Mdot
.74982 .49491 Mdot
.7283 .49612 Mdot
.30499 .29203 Mdot
.55788 .33544 Mdot
.50766 .62242 Mdot
.55273 .3716 Mdot
.71429 .3224 Mdot
.55897 .36503 Mdot
.64895 .66712 Mdot
.51711 .34948 Mdot
.26257 .66865 Mdot
.54565 .31965 Mdot
.54711 .38067 Mdot
.63374 .67308 Mdot
.47894 .36938 Mdot
.63409 .64635 Mdot
.5349 .34962 Mdot
.73183 .55062 Mdot
.61714 .6743 Mdot
.70725 .54545 Mdot
.51329 .57891 Mdot
.417 .57876 Mdot
.76096 .51089 Mdot
.7104 .50643 Mdot
.67781 .43342 Mdot
.31044 .50076 Mdot
.42164 .40676 Mdot
.53936 .39336 Mdot
.57627 .65809 Mdot
.4541 .68162 Mdot
.5248 .32363 Mdot
.54807 .40879 Mdot
.47914 .36361 Mdot
.33907 .47074 Mdot
.60056 .69765 Mdot
.73164 .52161 Mdot
.59796 .68095 Mdot
.72281 .55031 Mdot
.62071 .63706 Mdot
.469 .35913 Mdot
.50039 .32318 Mdot
.53664 .42668 Mdot
.42271 .27683 Mdot
.80948 .38846 Mdot
.33691 .48149 Mdot
.40669 .57821 Mdot
.75293 .52643 Mdot
.53685 .55289 Mdot
.35921 .46064 Mdot
.647 .67729 Mdot
.52858 .36677 Mdot
.4715 .4295 Mdot
.45091 .39522 Mdot
.36775 .52356 Mdot
.69383 .52394 Mdot
.62804 .68038 Mdot
.40473 .56408 Mdot
.50939 .50425 Mdot
.38762 .43348 Mdot
.64734 .41352 Mdot
.5263 .37705 Mdot
.72085 .49399 Mdot
.3097 .46712 Mdot
.50216 .6424 Mdot
.41958 .68755 Mdot
.56601 .48843 Mdot
.52569 .39411 Mdot
.37747 .72937 Mdot
.3201 .47504 Mdot
.73784 .49873 Mdot
.41791 .68654 Mdot
.75513 .50533 Mdot
.40793 .59086 Mdot
.42362 .55703 Mdot
.50336 .34757 Mdot
.55388 .37156 Mdot
.45721 .69318 Mdot
.34861 .45594 Mdot
.75084 .54501 Mdot
.49314 .65726 Mdot
.63208 .68576 Mdot
.51216 .53262 Mdot
.30609 .47328 Mdot
.40522 .77381 Mdot
.60296 .68889 Mdot
.45768 .72388 Mdot
.59902 .48038 Mdot
.4387 .6679 Mdot
.54951 .37121 Mdot
.3151 .48421 Mdot
.44402 .72549 Mdot
.49932 .76245 Mdot
.22391 .44001 Mdot
.31098 .53734 Mdot
.4935 .37483 Mdot
.29263 .56127 Mdot
.34686 .72108 Mdot
.28833 .43048 Mdot
.4574 .71231 Mdot
.51707 .38866 Mdot
.48116 .39135 Mdot
.51903 .3505 Mdot
.42236 .69329 Mdot
.43236 .78165 Mdot
.6321 .69407 Mdot
.52433 .36127 Mdot
.71208 .52057 Mdot
.62275 .642 Mdot
.6617 .67887 Mdot
.59934 .64956 Mdot
.32461 .50829 Mdot
.47084 .42514 Mdot
.48914 .30084 Mdot
.47338 .17641 Mdot
.42832 .69721 Mdot
.41671 .57826 Mdot
.48749 .39323 Mdot
.75277 .42739 Mdot
.3575 .48563 Mdot
.63818 .67752 Mdot
.5335 .38646 Mdot
.56039 .5989 Mdot
.40548 .59546 Mdot
.62605 .66744 Mdot
.33556 .50537 Mdot
.30223 .42213 Mdot
.51081 .40005 Mdot
.53471 .33622 Mdot
.35496 .46994 Mdot
.34819 .74801 Mdot
.50418 .50562 Mdot
.52257 .38118 Mdot
.43389 .69281 Mdot
.56742 .85889 Mdot
.57702 .34724 Mdot
.30964 .52262 Mdot
.39996 .56355 Mdot
.39121 .54047 Mdot
.26342 .39647 Mdot
.50181 .30304 Mdot
.23685 .53069 Mdot
.7691 .45083 Mdot
.22843 .48778 Mdot
.73011 .3413 Mdot
.49442 .66802 Mdot
.38506 .17251 Mdot
.41067 .7252 Mdot
.32293 .33438 Mdot
.24638 .71647 Mdot
.36896 .75834 Mdot
.62949 .58339 Mdot
.51003 .7242 Mdot
.6865 .67064 Mdot
.67574 .2306 Mdot
.64339 .64477 Mdot
.73642 .32905 Mdot
.55551 .37663 Mdot
.34096 .73555 Mdot
.31424 .35432 Mdot
.82164 .4392 Mdot
.32937 .57049 Mdot
.55369 .59946 Mdot
.17432 .42482 Mdot
.35721 .58213 Mdot
.25249 .31114 Mdot
.466 .27041 Mdot
.76289 .6384 Mdot
.53675 .55989 Mdot
.7106 .41029 Mdot
.28384 .38023 Mdot
.24244 .62841 Mdot
.42637 .63298 Mdot
.38861 .22343 Mdot
.69247 .74658 Mdot
.60983 .68261 Mdot
.31501 .45017 Mdot
.52298 .67302 Mdot
.23506 .35073 Mdot
.39338 .71815 Mdot
.23614 .52978 Mdot
.38223 .56486 Mdot
.32266 .34796 Mdot
.62947 .43754 Mdot
.33297 .30053 Mdot
.7651 .46339 Mdot
.68034 .24422 Mdot
.37242 .50918 Mdot
.52318 .73744 Mdot
.54342 .54837 Mdot
.67552 .46833 Mdot
.336 .36986 Mdot
.73914 .54149 Mdot
.74589 .54202 Mdot
.3423 .50366 Mdot
.2423 .35754 Mdot
.41414 .60569 Mdot
.6325 .41591 Mdot
.63108 .63425 Mdot
.45481 .5302 Mdot
.31671 .73337 Mdot
.34719 .70778 Mdot
.54733 .17998 Mdot
.18708 .37743 Mdot
.6757 .31372 Mdot
.49765 .6313 Mdot
.40476 .74592 Mdot
.7303 .42916 Mdot
.57205 .27419 Mdot
.66142 .28321 Mdot
.51125 .24886 Mdot
.16721 .47506 Mdot
.34336 .66169 Mdot
.16744 .41672 Mdot
.37482 .49705 Mdot
.50957 .44234 Mdot
.4707 .59623 Mdot
.49646 .21813 Mdot
.6656 .38075 Mdot
.18823 .39583 Mdot
.72401 .48371 Mdot
.30388 .44086 Mdot
.37083 .75891 Mdot
.32075 .38715 Mdot
.69764 .46514 Mdot
.79102 .53621 Mdot
.4187 .38096 Mdot
.15383 .45618 Mdot
.23884 .53766 Mdot
.36387 .2079 Mdot
.3924 .61095 Mdot
.60698 .71308 Mdot
.66203 .67352 Mdot
.40622 .69809 Mdot
.22946 .33778 Mdot
.32062 .48519 Mdot
.49231 .16576 Mdot
.24228 .48414 Mdot
.49825 .27459 Mdot
.14824 .46836 Mdot
.63667 .22128 Mdot
.25319 .39005 Mdot
.78906 .40224 Mdot
.51965 .84354 Mdot
.60184 .29465 Mdot
.46537 .74447 Mdot
.64674 .63405 Mdot
.28918 .54131 Mdot
.22391 .34694 Mdot
.66216 .26293 Mdot
.1826 .6115 Mdot
.63224 .41227 Mdot
.67458 .71727 Mdot
.37857 .5134 Mdot
.65507 .5891 Mdot
.66524 .48789 Mdot
.16919 .41192 Mdot
.29778 .35445 Mdot
.5575 .85401 Mdot
.71843 .34836 Mdot
.39939 .38278 Mdot
.281 .57095 Mdot
.60848 .6104 Mdot
.57578 .25649 Mdot
.33411 .67727 Mdot
.47635 .4149 Mdot
.6591 .40785 Mdot
.43716 .31738 Mdot
.73886 .46781 Mdot
.50425 .49941 Mdot
.34313 .63953 Mdot
.69044 .35154 Mdot
.4096 .79165 Mdot
.41517 .40468 Mdot
.3437 .51005 Mdot
.6632 .29215 Mdot
.70001 .32705 Mdot
.38527 .63268 Mdot
.70235 .5677 Mdot
.35393 .21122 Mdot
.67482 .56818 Mdot
.50963 .29801 Mdot
.32325 .32827 Mdot
.28674 .38103 Mdot
.68875 .28786 Mdot
.46491 .37064 Mdot
.51757 .18138 Mdot
.39004 .58938 Mdot
.40355 .28638 Mdot
.6728 .36012 Mdot
.41657 .28038 Mdot
.22423 .40229 Mdot
.46249 .58626 Mdot
.45282 .76102 Mdot
.27224 .46331 Mdot
.1556 .45555 Mdot
.61725 .64488 Mdot
.659 .27015 Mdot
.40651 .72128 Mdot
.48857 .77253 Mdot
.50534 .67794 Mdot
.65109 .56558 Mdot
.24426 .30793 Mdot
.36092 .72048 Mdot
.57859 .62072 Mdot
.22544 .60989 Mdot
.43568 .50083 Mdot
.41187 .24678 Mdot
.54807 .43752 Mdot
.51325 .25431 Mdot
.73841 .53226 Mdot
.40969 .32457 Mdot
.44565 .57719 Mdot
.8092 .52515 Mdot
.49166 .3139 Mdot
.54683 .57009 Mdot
.412 .56121 Mdot
.56998 .49883 Mdot
.32554 .21176 Mdot
.54974 .4384 Mdot
.63486 .22395 Mdot
.35896 .73012 Mdot
.58923 .49341 Mdot
.67029 .48115 Mdot
.41754 .4443 Mdot
.16312 .42306 Mdot
.27468 .25959 Mdot
.31908 .70205 Mdot
.28056 .55741 Mdot
.76904 .27426 Mdot
.46827 .76229 Mdot
.55269 .19621 Mdot
.40263 .71483 Mdot
.8652 .64997 Mdot
.59792 .6834 Mdot
.77096 .3482 Mdot
.488 .22457 Mdot
.59479 .5761 Mdot
.23412 .35651 Mdot
.29652 .3879 Mdot
.7077 .55602 Mdot
.34931 .51361 Mdot
.47198 .3425 Mdot
.19731 .39107 Mdot
.16038 .45282 Mdot
.19502 .39653 Mdot
.37802 .70193 Mdot
.20728 .42692 Mdot
.15654 .51157 Mdot
.76553 .42399 Mdot
.47244 .63306 Mdot
.58691 .33912 Mdot
.62349 .25684 Mdot
.6124 .21705 Mdot
.71525 .48209 Mdot
.60512 .30143 Mdot
.37357 .50883 Mdot
.15043 .50171 Mdot
.32864 .20799 Mdot
.34063 .27638 Mdot
.26276 .2996 Mdot
.53786 .66672 Mdot
.63857 .27142 Mdot
.26031 .28937 Mdot
.23811 .60056 Mdot
.38003 .58646 Mdot
.1552 .53386 Mdot
.70209 .33744 Mdot
.50883 .72894 Mdot
.29868 .67921 Mdot
.5892 .20619 Mdot
.27279 .56573 Mdot
.52372 .67924 Mdot
.55332 .25817 Mdot
.39182 .47227 Mdot
.65383 .56735 Mdot
.2362 .6201 Mdot
.50225 .62455 Mdot
.66435 .34041 Mdot
.65396 .69048 Mdot
.65157 .26258 Mdot
.64587 .49917 Mdot
.47538 .63541 Mdot
.68744 .41341 Mdot
.6692 .26035 Mdot
.3084 .6558 Mdot
.20092 .41306 Mdot
.36009 .73002 Mdot
.51097 .84881 Mdot
.32443 .59372 Mdot
.44395 .30864 Mdot
.47851 .36987 Mdot
.22889 .35573 Mdot
.25441 .25827 Mdot
.24839 .29893 Mdot
.37468 .68407 Mdot
.55245 .65703 Mdot
.45833 .72949 Mdot
.71655 .42644 Mdot
.6098 .569 Mdot
.35796 .55702 Mdot
.60838 .51168 Mdot
.4149 .72573 Mdot
.32706 .74912 Mdot
.25679 .49864 Mdot
.75003 .4292 Mdot
.37317 .23579 Mdot
.60001 .31307 Mdot
.24545 .36643 Mdot
.365 .49524 Mdot
.37066 .70791 Mdot
.66028 .27953 Mdot
.6116 .6449 Mdot
.4946 .77561 Mdot
.27729 .46049 Mdot
.50373 .44392 Mdot
.53853 .67408 Mdot
.32518 .54206 Mdot
.44399 .25371 Mdot
.5695 .63484 Mdot
.35576 .19042 Mdot
.53732 .18512 Mdot
.26188 .28646 Mdot
.67229 .30102 Mdot
.50994 .75942 Mdot
.54603 .5043 Mdot
.42665 .75393 Mdot
.34231 .57537 Mdot
.53727 .53392 Mdot
.67409 .29424 Mdot
.2461 .39083 Mdot
.44343 .61367 Mdot
.49661 .3026 Mdot
.38906 .18929 Mdot
.7388 .41309 Mdot
.55018 .5106 Mdot
.40688 .47017 Mdot
.32733 .44114 Mdot
.81351 .37974 Mdot
.25523 .64711 Mdot
.48753 .2926 Mdot
.28493 .5643 Mdot
.44422 .66217 Mdot
.35146 .5023 Mdot
.66828 .25528 Mdot
.72163 .58876 Mdot
.24479 .46754 Mdot
.48273 .59212 Mdot
.23961 .33715 Mdot
.50477 .56892 Mdot
.26971 .55252 Mdot
.209 .50284 Mdot
.58731 .84187 Mdot
.37424 .49609 Mdot
.48982 .63049 Mdot
.51863 .65561 Mdot
.38307 .48712 Mdot
.35975 .52644 Mdot
.29229 .36202 Mdot
.21066 .34956 Mdot
.53363 .59233 Mdot
.22849 .59289 Mdot
.59439 .48869 Mdot
.65113 .58276 Mdot
.4633 .6182 Mdot
.69124 .40682 Mdot
.2238 .55031 Mdot
.31351 .26216 Mdot
.40615 .82646 Mdot
.61306 .3273 Mdot
.76378 .33801 Mdot
.71758 .42741 Mdot
.46672 .27182 Mdot
.33564 .36614 Mdot
.37418 .59413 Mdot
.54514 .34485 Mdot
.19256 .36123 Mdot
.34773 .65364 Mdot
.66129 .4493 Mdot
.64619 .61624 Mdot
.57303 .34972 Mdot
.53524 .42582 Mdot
.25533 .29595 Mdot
.39314 .52597 Mdot
.32598 .79613 Mdot
.72048 .33898 Mdot
.47287 .28251 Mdot
.24998 .39757 Mdot
.63137 .22403 Mdot
.46447 .57308 Mdot
.24007 .49629 Mdot
.64605 .50713 Mdot
.61081 .21194 Mdot
.2112 .56688 Mdot
.2432 .64527 Mdot
.31721 .5863 Mdot
.15927 .50245 Mdot
.44805 .31991 Mdot
.40797 .61817 Mdot
.5329 .68209 Mdot
.49214 .39978 Mdot
.35921 .69905 Mdot
.31039 .57393 Mdot
.69154 .6242 Mdot
.57 .27041 Mdot
.24873 .26256 Mdot
.56189 .29556 Mdot
.37021 .67046 Mdot
.30551 .77175 Mdot
.38492 .84196 Mdot
.25582 .66291 Mdot
.17042 .40794 Mdot
.23245 .63057 Mdot
.26607 .556 Mdot
.45286 .66553 Mdot
.52525 .55864 Mdot
.4382 .23863 Mdot
.21417 .33554 Mdot
.75189 .6069 Mdot
.48237 .72461 Mdot
.42449 .21373 Mdot
.21111 .33689 Mdot
.5407 .29364 Mdot
.79497 .35694 Mdot
.59046 .70393 Mdot
.66013 .21325 Mdot
.56093 .18592 Mdot
.40279 .45864 Mdot
.68245 .27305 Mdot
.77152 .32942 Mdot
.808 .43901 Mdot
.54702 .1912 Mdot
.55931 .23761 Mdot
.40343 .49846 Mdot
.66658 .30462 Mdot
.29705 .55013 Mdot
.71613 .24639 Mdot
.4667 .61543 Mdot
.4015 .59599 Mdot
.41938 .55204 Mdot
.28784 .53958 Mdot
.30684 .6391 Mdot
.48608 .61242 Mdot
.46086 .48602 Mdot
.23269 .3901 Mdot
.59515 .86119 Mdot
.21814 .62877 Mdot
.26528 .48936 Mdot
.16648 .44751 Mdot
.38334 .60408 Mdot
.54943 .53789 Mdot
.34246 .37669 Mdot
.72813 .41867 Mdot
.56828 .62858 Mdot
.55095 .37877 Mdot
.2076 .35331 Mdot
.57137 .62681 Mdot
.18074 .4242 Mdot
.4588 .16011 Mdot
.27476 .29475 Mdot
.57922 .41733 Mdot
.65302 .63759 Mdot
.63087 .23898 Mdot
.63237 .24388 Mdot
.17719 .4714 Mdot
.75062 .32204 Mdot
.52489 .53193 Mdot
.50198 .5921 Mdot
.48658 .56982 Mdot
.46451 .31192 Mdot
.62473 .21739 Mdot
.41885 .46055 Mdot
.6786 .37076 Mdot
.30515 .69368 Mdot
.67086 .27577 Mdot
.2656 .3896 Mdot
.70651 .42095 Mdot
.66879 .55638 Mdot
.71303 .55579 Mdot
.58614 .64237 Mdot
.16825 .57895 Mdot
.35689 .60271 Mdot
.50697 .17965 Mdot
.51536 .84716 Mdot
.33743 .67762 Mdot
.73475 .32171 Mdot
.43385 .61001 Mdot
.60555 .29122 Mdot
.75864 .62844 Mdot
.69642 .36599 Mdot
.28027 .36763 Mdot
.30624 .5577 Mdot
.39736 .42219 Mdot
.23207 .32067 Mdot
.66645 .34843 Mdot
.20839 .67526 Mdot
.57876 .71461 Mdot
.41089 .31761 Mdot
.26348 .34649 Mdot
.48032 .84426 Mdot
.55624 .50872 Mdot
.15498 .45822 Mdot
.30199 .50478 Mdot
.18594 .38124 Mdot
.41646 .67939 Mdot
.70263 .68244 Mdot
.37274 .57179 Mdot
.65878 .45765 Mdot
.64787 .4649 Mdot
.41944 .17482 Mdot
.36479 .74467 Mdot
.34634 .71227 Mdot
.67573 .57068 Mdot
.65487 .66332 Mdot
.49394 .53155 Mdot
.23188 .58859 Mdot
.17277 .58567 Mdot
.49788 .33468 Mdot
.63679 .73282 Mdot
.65019 .24302 Mdot
.42715 .75512 Mdot
.38657 .56964 Mdot
.34928 .56632 Mdot
.26275 .43325 Mdot
.63618 .27189 Mdot
.1567 .49683 Mdot
.36688 .55318 Mdot
.61629 .55497 Mdot
.41053 .3645 Mdot
.43817 .62538 Mdot
.4259 .79958 Mdot
.23265 .54348 Mdot
.49388 .57798 Mdot
.50877 .50766 Mdot
.67859 .31523 Mdot
.30282 .20615 Mdot
.16438 .46483 Mdot
.46375 .82298 Mdot
.58978 .49583 Mdot
.29982 .51009 Mdot
.70348 .39164 Mdot
.20326 .66904 Mdot
.66332 .21121 Mdot
.30808 .67803 Mdot
.6678 .27227 Mdot
.67284 .61328 Mdot
.77961 .34803 Mdot
.54392 .52419 Mdot
.26489 .34449 Mdot
.47386 .21782 Mdot
.42932 .56286 Mdot
.59033 .61226 Mdot
.61699 .47718 Mdot
.48437 .65273 Mdot
.40489 .49427 Mdot
.36641 .74559 Mdot
.20934 .67653 Mdot
.74348 .30914 Mdot
.41129 .37979 Mdot
.22361 .68648 Mdot
.3583 .43609 Mdot
.5199 .65839 Mdot
.45211 .80394 Mdot
.60025 .4914 Mdot
.59214 .6688 Mdot
.56698 .27724 Mdot
.49926 .51805 Mdot
.21987 .60824 Mdot
.68452 .65027 Mdot
.75829 .48869 Mdot
.34564 .52629 Mdot
.76188 .3234 Mdot
.37443 .46472 Mdot
.33213 .19187 Mdot
.23974 .59845 Mdot
.24745 .38076 Mdot
.2024 .57105 Mdot
.53608 .72669 Mdot
.51859 .85208 Mdot
.25454 .3088 Mdot
.65227 .33547 Mdot
.35254 .52285 Mdot
.37361 .48458 Mdot
.21163 .55584 Mdot
.38637 .73331 Mdot
.24612 .33509 Mdot
.6415 .22642 Mdot
.51299 .76074 Mdot
.34921 .44566 Mdot
.50609 .59878 Mdot
.26667 .48316 Mdot
.33954 .19788 Mdot
.59632 .67589 Mdot
.15389 .44564 Mdot
.42069 .42765 Mdot
.40321 .80656 Mdot
.32604 .55082 Mdot
.47033 .47852 Mdot
.55999 .51283 Mdot
.50718 .75118 Mdot
.50613 .29722 Mdot
.47262 .28387 Mdot
.32373 .50491 Mdot
.50222 .67789 Mdot
.71883 .50277 Mdot
.7622 .56115 Mdot
.41782 .74303 Mdot
.45375 .27348 Mdot
.60972 .20413 Mdot
.36881 .49005 Mdot
.56448 .70327 Mdot
.5718 .72093 Mdot
.53197 .30077 Mdot
.59921 .239 Mdot
.16494 .54948 Mdot
.25394 .31419 Mdot
.30568 .50799 Mdot
.46706 .83108 Mdot
.7796 .4854 Mdot
.36745 .1872 Mdot
.28562 .42534 Mdot
.64243 .2403 Mdot
.43527 .31128 Mdot
.27881 .26334 Mdot
.26384 .39618 Mdot
.25817 .52054 Mdot
.66493 .28993 Mdot
.64475 .56856 Mdot
.66574 .25906 Mdot
.26205 .43277 Mdot
.49369 .55743 Mdot
.66149 .21757 Mdot
.67175 .6168 Mdot
.33075 .3062 Mdot
.52987 .27469 Mdot
.3219 .54842 Mdot
.62379 .22349 Mdot
.33725 .52794 Mdot
.76585 .52824 Mdot
.39605 .22778 Mdot
.37521 .57955 Mdot
.22763 .34338 Mdot
.38415 .63464 Mdot
.65249 .24009 Mdot
.48476 .56392 Mdot
.74259 .39136 Mdot
.42143 .42988 Mdot
.64926 .38944 Mdot
.52561 .42186 Mdot
.43159 .33066 Mdot
.62082 .51372 Mdot
.42986 .17964 Mdot
.46925 .29646 Mdot
.20959 .37194 Mdot
.34874 .20107 Mdot
.22207 .48241 Mdot
.51341 .63855 Mdot
.33445 .44741 Mdot
.16176 .43561 Mdot
.60621 .23514 Mdot
.31198 .55333 Mdot
.56696 .18831 Mdot
.81226 .37438 Mdot
.23621 .70595 Mdot
.36147 .63117 Mdot
.33198 .54374 Mdot
.5009 .17013 Mdot
.34783 .6603 Mdot
.78327 .34064 Mdot
.28414 .36455 Mdot
.38277 .53495 Mdot
.14643 .47482 Mdot
.51334 .21917 Mdot
.34227 .70462 Mdot
.26136 .35704 Mdot
.25207 .4505 Mdot
.59614 .22882 Mdot
.49272 .30077 Mdot
.63143 .63814 Mdot
.57898 .58604 Mdot
.68681 .27944 Mdot
.26789 .43995 Mdot
.63759 .23028 Mdot
.64324 .24488 Mdot
.74379 .33583 Mdot
.51132 .75213 Mdot
.23708 .70643 Mdot
.24501 .41309 Mdot
.50517 .4335 Mdot
.33165 .52919 Mdot
.76436 .50558 Mdot
.72142 .35561 Mdot
.54172 .32111 Mdot
.60684 .46386 Mdot
.42435 .35854 Mdot
.20176 .34972 Mdot
.66864 .58063 Mdot
.43397 .6341 Mdot
.33419 .44563 Mdot
.29543 .54383 Mdot
.45197 .55051 Mdot
.36882 .75962 Mdot
.63 .23163 Mdot
.24277 .46961 Mdot
.24152 .52811 Mdot
.33998 .69583 Mdot
.67886 .33384 Mdot
.77834 .47018 Mdot
.44551 .72765 Mdot
.44519 .24711 Mdot
.18265 .48954 Mdot
.35172 .68401 Mdot
.30614 .44156 Mdot
.28801 .65909 Mdot
.49721 .55883 Mdot
.40186 .63677 Mdot
.3625 .74 Mdot
.44848 .59717 Mdot
.29444 .28847 Mdot
.21591 .5179 Mdot
.62327 .62213 Mdot
.70843 .33075 Mdot
.25974 .64181 Mdot
.63328 .22934 Mdot
.53964 .2996 Mdot
.21777 .3709 Mdot
.65771 .45291 Mdot
.7668 .47692 Mdot
.52224 .33562 Mdot
.51371 .23762 Mdot
.25472 .29583 Mdot
.28921 .67629 Mdot
.56552 .25895 Mdot
.29121 .45306 Mdot
.53769 .18289 Mdot
.56153 .6378 Mdot
.56352 .63952 Mdot
.78733 .38375 Mdot
.4526 .45996 Mdot
.60575 .56788 Mdot
.43942 .77429 Mdot
.52217 .29448 Mdot
.78831 .47794 Mdot
.48799 .58937 Mdot
.43947 .24961 Mdot
.55199 .19886 Mdot
.1677 .56534 Mdot
.47663 .58476 Mdot
.54832 .17857 Mdot
.46256 .22132 Mdot
.38379 .52897 Mdot
.75094 .31276 Mdot
.60311 .30097 Mdot
.46548 .36493 Mdot
.76616 .52762 Mdot
.33298 .43472 Mdot
.1694 .54592 Mdot
.53213 .25711 Mdot
.69884 .47571 Mdot
.66623 .52289 Mdot
.47532 .60206 Mdot
.66303 .74885 Mdot
.39162 .59161 Mdot
.50305 .1694 Mdot
.6608 .28029 Mdot
.46214 .73961 Mdot
.22325 .60874 Mdot
.58665 .27488 Mdot
.21338 .37343 Mdot
.62777 .5272 Mdot
.24358 .32144 Mdot
.38434 .67771 Mdot
.4386 .26646 Mdot
.3704 .19518 Mdot
.66391 .39705 Mdot
.64672 .39646 Mdot
.41162 .44857 Mdot
.62996 .34444 Mdot
.4271 .58214 Mdot
.70334 .57957 Mdot
.70653 .24833 Mdot
.1869 .62977 Mdot
.38901 .79124 Mdot
.55057 .28472 Mdot
.70086 .38611 Mdot
.21444 .53083 Mdot
.54608 .54212 Mdot
.65963 .50246 Mdot
.53884 .69148 Mdot
.58071 .61661 Mdot
.57359 .85792 Mdot
.19643 .3576 Mdot
.52562 .33466 Mdot
.64187 .48239 Mdot
.79721 .53242 Mdot
.62081 .70254 Mdot
.36074 .23996 Mdot
.16615 .53968 Mdot
.43557 .7275 Mdot
.50182 .82127 Mdot
.44809 .76844 Mdot
.4252 .17531 Mdot
.47149 .80618 Mdot
.40932 .65547 Mdot
.3307 .19208 Mdot
.31914 .69689 Mdot
.38537 .42567 Mdot
.58187 .85663 Mdot
.40438 .18416 Mdot
.43898 .31029 Mdot
.55424 .64475 Mdot
.2013 .36809 Mdot
.557 .5135 Mdot
.54867 .64391 Mdot
.52202 .21287 Mdot
.66504 .28407 Mdot
.71624 .33674 Mdot
.47446 .67535 Mdot
.448 .21422 Mdot
.84433 .43841 Mdot
.53898 .72721 Mdot
.46798 .85881 Mdot
.2608 .3097 Mdot
.19884 .47471 Mdot
.25268 .65668 Mdot
.69357 .61839 Mdot
.22531 .3639 Mdot
.64339 .25304 Mdot
.51329 .23096 Mdot
.73295 .60395 Mdot
.66681 .4086 Mdot
.71945 .40825 Mdot
.40395 .63733 Mdot
.27222 .28307 Mdot
.51746 .74497 Mdot
.59836 .26953 Mdot
.65823 .26087 Mdot
.47384 .22541 Mdot
.64644 .39102 Mdot
.18666 .47673 Mdot
.59335 .23194 Mdot
.68073 .30405 Mdot
.51649 .70674 Mdot
.74195 .5441 Mdot
.17271 .52916 Mdot
.43219 .5149 Mdot
.43037 .32404 Mdot
.30987 .77695 Mdot
.16963 .41381 Mdot
.60407 .30174 Mdot
.58314 .34805 Mdot
.38981 .16975 Mdot
.5809 .7109 Mdot
.54674 .1979 Mdot
.3082 .7196 Mdot
.7235 .33464 Mdot
.44461 .3324 Mdot
.56089 .36665 Mdot
.76991 .40446 Mdot
.38717 .50457 Mdot
.47665 .22074 Mdot
.47855 .79427 Mdot
.67592 .29983 Mdot
.45603 .2761 Mdot
.40491 .82551 Mdot
.27912 .42423 Mdot
.36509 .45808 Mdot
.2012 .36196 Mdot
.38161 .21375 Mdot
.45874 .28977 Mdot
.25313 .35059 Mdot
.62258 .53811 Mdot
.7889 .48016 Mdot
.42325 .40776 Mdot
.549 .5041 Mdot
.68752 .27681 Mdot
.22304 .68824 Mdot
.42986 .24339 Mdot
.15096 .45477 Mdot
.26833 .26768 Mdot
.36075 .45145 Mdot
.50135 .22256 Mdot
.5982 .49688 Mdot
.2252 .49337 Mdot
.49787 .75228 Mdot
.49514 .77041 Mdot
.83329 .43701 Mdot
.77866 .55247 Mdot
.55428 .3896 Mdot
.37741 .70057 Mdot
.23393 .32074 Mdot
.83039 .41992 Mdot
.22795 .33062 Mdot
.43351 .33194 Mdot
.47748 .37431 Mdot
.39225 .84785 Mdot
.26621 .55323 Mdot
.47963 .35132 Mdot
.4579 .33236 Mdot
.4689 .31093 Mdot
.55116 .35798 Mdot
.38881 .7415 Mdot
.72968 .42396 Mdot
.7167 .32083 Mdot
.20944 .36204 Mdot
.34594 .44091 Mdot
.56425 .50934 Mdot
.40126 .70104 Mdot
.62788 .46023 Mdot
.60292 .42765 Mdot
.42871 .66214 Mdot
.71668 .31035 Mdot
.64268 .74839 Mdot
.68826 .46636 Mdot
.32747 .54639 Mdot
.45066 .46805 Mdot
.24809 .4854 Mdot
.73171 .30817 Mdot
.42429 .77195 Mdot
.80838 .44208 Mdot
.65556 .24623 Mdot
.40592 .41781 Mdot
.40061 .61737 Mdot
.77488 .28578 Mdot
.54965 .51385 Mdot
.37899 .72177 Mdot
.61328 .35255 Mdot
.36461 .41595 Mdot
.27056 .31228 Mdot
.78844 .50784 Mdot
.415 .5593 Mdot
.41456 .36225 Mdot
.23353 .35611 Mdot
.45417 .67532 Mdot
.28221 .22557 Mdot
.60827 .3843 Mdot
.3563 .24916 Mdot
.21884 .43512 Mdot
.49205 .63589 Mdot
.28038 .37101 Mdot
.52305 .42337 Mdot
.60072 .55199 Mdot
.6408 .74602 Mdot
.28441 .51044 Mdot
.46202 .61976 Mdot
.22303 .51229 Mdot
.75811 .33539 Mdot
.31787 .26546 Mdot
.54328 .37219 Mdot
.73433 .48431 Mdot
.56313 .49618 Mdot
.69277 .60862 Mdot
.67329 .71773 Mdot
.38287 .58771 Mdot
.7299 .31 Mdot
.72032 .3399 Mdot
.26921 .35761 Mdot
.18242 .40998 Mdot
.52635 .27399 Mdot
.26907 .30373 Mdot
.65766 .54775 Mdot
.31489 .63944 Mdot
.60185 .24092 Mdot
.21934 .68045 Mdot
.45291 .30917 Mdot
.50777 .28619 Mdot
.28644 .23721 Mdot
.25722 .30188 Mdot
.47775 .65972 Mdot
.29396 .55395 Mdot
.69231 .24127 Mdot
.64859 .46558 Mdot
.58495 .85991 Mdot
.4923 .76108 Mdot
.31162 .20948 Mdot
.45803 .62667 Mdot
.61036 .35796 Mdot
.41622 .44563 Mdot
.47528 .33697 Mdot
.62388 .6601 Mdot
.21676 .48557 Mdot
.41032 .45207 Mdot
.6317 .37217 Mdot
.51357 .43122 Mdot
.54 .63753 Mdot
.31846 .529 Mdot
.18976 .63853 Mdot
.65173 .70198 Mdot
.61694 .55191 Mdot
.3657 .79223 Mdot
.64267 .74673 Mdot
.8031 .35773 Mdot
.17571 .46621 Mdot
.34319 .57417 Mdot
.48991 .58616 Mdot
.66469 .77847 Mdot
.30663 .51506 Mdot
.35775 .53168 Mdot
.42569 .74987 Mdot
.74936 .39684 Mdot
.36645 .68104 Mdot
.2652 .73343 Mdot
.2807 .25909 Mdot
.53805 .30014 Mdot
.58976 .87698 Mdot
.65541 .25279 Mdot
.60126 .52335 Mdot
.36607 .68887 Mdot
.21293 .34904 Mdot
.64426 .61466 Mdot
.45202 .16232 Mdot
.2433 .62573 Mdot
.27628 .43174 Mdot
.7419 .40846 Mdot
.46944 .83023 Mdot
.50285 .60496 Mdot
.47057 .85912 Mdot
.29122 .57279 Mdot
.70975 .40974 Mdot
.2831 .67278 Mdot
.3664 .50933 Mdot
.47481 .28384 Mdot
.24262 .59254 Mdot
.58928 .2884 Mdot
.29568 .431 Mdot
.23881 .53538 Mdot
.7524 .4556 Mdot
.49927 .71921 Mdot
.26677 .5473 Mdot
.41206 .74857 Mdot
.40349 .44662 Mdot
.68811 .2518 Mdot
.62801 .73025 Mdot
.65033 .69395 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo083ooooo0_l000000ooooooo
0000o`00000:ooooo`Co0000]_ooool001cooooo00?o0000ooooooooool0P?ooool2o`000004oooo
ool0003o0000ooooo`;o00001oooool4o`0000Wooooo0_l0002[ooooo`007?ooool00ol0003ooooo
ooooo`26ooooo`;o00005?ooool2o`000:_ooooo000Looooo`03o`000?oooooooooo07_ooooo0_l0
000=ooooo`;o00004oooool3o`0002Gooooo0_l00020ooooo`007?ooool00ol0003oooooooooo`1i
ooooo`Co00002?ooool3o`0000;ooooo0_l0000Cooooo`?o00009Oooool2o`00083ooooo000Loooo
o`03o`000?oooooooooo07Wooooo0_l0000:ooooo`?o00003Oooool5o`000:oooooo000Looooo`03
o`000?oooooooooo08Sooooo0_l0000;ooooo`Go00000_ooool3o`0000;ooooo0_l000000ooooooo
0000o`000008ooooo`;o0000VOooool001cooooo00?o0000ooooooooool0P?ooool2o`000003oooo
ool0003o000000?ooooo0_l0000Booooo`?o00000_ooool2o`000003ooooool0003o000000Gooooo
0_l000000ooooooo0000o`00000Kooooo`;o0000O?ooool001cooooo00?o0000ooooooooool0M?oo
ool2o`0000Sooooo1?l000000ooooooo0000o`00000Looooo`;o00002?ooool2o`0000Gooooo0ol0
000Fooooo`?o0000Noooool001cooooo00?o0000ooooooooool0JOooool2o`0000?ooooo1?l00002
ooooo`;o00000oooool4o`000003ooooool0003o000002_ooooo0_l00005ooooo`Co00005_ooool2
o`0007_ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_oo
ool00ol0003oooooooooo`1Xooooo`?o00000oooool4o`0000Gooooo1_l0000[ooooo`;o000000Co
ooooo`000?l0003ooooo0_l00004ooooo`;o0000Toooool00006oooooomgMgOoV9RHoooooonHV9So
MgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo
06Sooooo0_l0000:ooooo`Go000000?oooooo`000?l00000;?ooool5o`000003ooooool0003o0000
00;o0000Uoooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00onHV9So
8B4Qonk^kP07ooooo`03o`000?oooooooooo06_ooooo0_l00007ooooo`?o0000<Oooool4o`0000;o
oooo1?l0000>ooooo`;o0000Qoooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
2oooool00onHV9So8B4Qonk^kP06ooooo`?o0000Joooool2o`000003ooooool0003o000001gooooo
0_l00002ooooo`;o00006oooool4o`0000kooooo0_l0000?ooooo`;o0000M_ooool00003ooooool0
003ooooo00;ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oo
oooooooo05oooooo0_l0000=ooooo`;o00007Oooool2o`0000;ooooo0_l00005ooooo`;o00000ooo
ool2o`0001gooooo0_l00004ooooo`;o00003Oooool2o`0007Kooooo00000ooooooo410@ooooo`02
ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1O
ooooo`;o00001_ooool2o`0000Wooooo0_l0000Kooooo`;o00001oooool2o`0000?ooooo0_l0000M
ooooo`;o00001?ooool2o`0000gooooo0ol0001eooooo`0000KoooooogMgMonHV9SooooooiRHV?mg
MgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`1Pooooo`Co0000
0_ooool4o`0000Gooooo0_l000000ooooooo0000o`00000Aooooo`;o00001_ooool5o`0000Wooooo
1?l0000Tooooo`;o00003Oooool4o`0007?ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo063ooooo1?l00002oooo
o`Co00001Oooool2o`000003ooooool0003o000000Cooooo0_l0000;ooooo`?o00001Oooool5o`00
0003ooooool0003o000000?o00000oooool4o`0000Oooooo0_l00008ooooo`;o00004Oooool2o`00
00kooooo0ol0001cooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o00002oooool2o`0000?o
oooo1?l0000;ooooo`;o00001?ooool4o`0000?ooooo1Ol00006ooooo`;o00001_ooool2o`0000So
oooo0_l0000Aooooo`;o00000_ooool2o`0000[ooooo0_l0001dooooo`007?ooool00ol0003ooooo
ooooo`1Iooooo`;o00002_ooool2o`00013ooooo1?l00009ooooo`;o00001_ooool4o`0000?ooooo
0_l000001?oooooo0000o`000?l00005ooooo`;o00000oooool2o`0001kooooo0_l00002ooooo`;o
00000_ooool2o`0000Kooooo0_l000000ooooooo0000o`00001aooooo`007?ooool00ol0003ooooo
ooooo`1Iooooo`;o00004oooool2o`0000[ooooo0_l00008ooooo`;o00003Oooool2o`0000;ooooo
0_l00002ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0002;ooooo1_l00009ooooo`;o
0000LOooool001cooooo00?o0000ooooooooool0F?ooool2o`0001Cooooo0_l0000:ooooo`;o0000
6_ooool2o`0000?ooooo1_l00007ooooo`;o00007Oooool5o`000004ooooool0003o0000o`0007Wo
oooo000Looooo`03o`000?oooooooooo05Sooooo0_l0000Mooooo`;o00001?ooool2o`0001Oooooo
0_l00004ooooo`;o00002?ooool4o`0001Cooooo0_l0000:ooooo`Ko00002?ooool2o`0006oooooo
000Looooo`03o`000?oooooooooo07Oooooo0_l00004ooooo`;o00009?ooool2o`000003ooooool0
003o000001Cooooo1?l00006ooooo`;o000000?oooooo`000?l000000_l00008ooooo`;o000000?o
ooooo`000?l00000Koooool001cooooo00?o0000ooooooooool0MOooool2o`0002cooooo0_l00006
ooooo`;o00003oooool3o`0000;ooooo1?l000001?oooooo0000o`000?ooool2o`0000[ooooo0ol0
0002ooooo`;o0000KOooool001cooooo00?o0000ooooooooool0FOooool2o`0001Kooooo0_l00002
ooooo`;o00004_ooool4o`000003ooooool0003o000001?ooooo0_l00006ooooo`;o00001Oooool2
o`0000_ooooo1_l00004ooooo`;o00001Oooool3o`0000?ooooo0_l00002ooooo`?o0000K?ooool0
01cooooo00?o0000ooooooooool0FOooool2o`0001Kooooo0_l0000Aooooo`Co000000?oooooo`00
0?l000000_l000000ooooooo0000o`00000Cooooo`;o00003Oooool2o`0000_ooooo0ol00004oooo
o`;o000000?oooooo`000?l000000_ooool6o`0000Sooooo1Ol0001Yooooo`007?ooool00ol0003o
ooooooooo`24ooooo`Ko00001?ooool3o`00027ooooo0_l0000<ooooo`Co00000_ooool2o`0000;o
oooo0_l000000ooooooo0000o`000005o`0000Gooooo0_l00002ooooo`Go0000Ioooool001cooooo
00?o0000ooooooooool0L?ooool2o`00013ooooo0_l00004ooooo`;o00000oooool4o`00017ooooo
0_l000000ooooooo0000o`00000Kooooo`;o00001_ooool2o`000003ooooool0003o000000;ooooo
1Ol00003ooooo`;o00001Oooool4o`000003ooooool0003o000006;ooooo000Looooo`;o0000LOoo
ool2o`0000kooooo1?l00007ooooo`Co00004_ooool3o`000003ooooool0003o000002cooooo1?l0
0005ooooo`;o00001?ooool2o`000003ooooool0003o000006;ooooo000Looooo`03o`000?oooooo
oooo083ooooo0_l00009ooooo`Go00004Oooool4o`0000_ooooo0_l0000@ooooo`;o00002Oooool2
o`0000;ooooo0_l00002ooooo`;o00001Oooool2o`0000oooooo0_l0001Jooooo`007?ooool00ol0
003oooooooooo`1?ooooo`;o0000;oooool2o`0000[ooooo1?l0000Cooooo`;o00001?ooool2o`00
00Gooooo0_l00005ooooo`;o00002Oooool3o`0000;ooooo0_l00004ooooo`;o00000_ooool2o`00
00;ooooo0_l000000ooooooo0000o`00000Cooooo`;o0000F_ooool001cooooo00?o0000oooooooo
ool0Coooool2o`0000Gooooo0ol0000Wooooo`;o00003?ooool2o`0001Wooooo0_l000000ooooooo
0000o`000002ooooo`;o00000_ooool2o`000003ooooool0003o000000[ooooo0_l00002ooooo`?o
00002?ooool8o`0006oooooo000Looooo`03o`000?oooooooooo04gooooo0_l00005ooooo`Go0000
2Oooool2o`0004Sooooo0_l00002ooooo`Ko00004_ooool2o`0000Kooooo2?l0000Gooooo`;o0000
F?ooool001cooooo00?o0000ooooooooool0COooool2o`0000Cooooo0ol000000ooooooo0000o`00
0009ooooo`Co00009Oooool2o`0000Oooooo0_l0000Eooooo`;o00000oooool4o`0001cooooo0_l0
00000ooooooo0000o`000003ooooo`;o00005Oooool2o`0005Sooooo000Looooo`03o`000?oooooo
oooo05?ooooo0_l0000=ooooo`Co00001oooool2o`0001cooooo0_l00007ooooo`;o00004?ooool2
o`0000?ooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l00008ooooo`;o00001Ooo
ool2o`0000[ooooo0_l00004ooooo`;o0000Koooool001cooooo00?o0000ooooooooool0KOooool2
o`00027ooooo0_l00002ooooo`;o00002Oooool2o`0000;ooooo1ol00005ooooo`?o00000oooool2
o`0000Sooooo0_l00005ooooo`;o00000oooool4o`0000?ooooo0_l000000ooooooo0000o`000002
o`000003ooooool0003o000006gooooo000Looooo`03o`000?oooooooooo063ooooo0_l00009oooo
o`Co00005Oooool4o`0000Sooooo0_l00002ooooo`;o00002?ooool3o`0000;ooooo1ol00006oooo
o`;o00000_ooool4o`0000?ooooo0_l0000=ooooo`Go00001_ooool9o`0001Sooooo0_l0001Aoooo
o`007?ooool00ol0003oooooooooo`1Pooooo`;o00002Oooool2o`0001Gooooo1_l00008ooooo`;o
00001oooool3o`0000;ooooo0_l00007ooooo`?o000000?oooooo`000?l000001oooool4o`0000?o
oooo0_l0000;ooooo`Co00001oooool2o`000003ooooool0003o000000Ko00006?ooool2o`00057o
oooo000Looooo`03o`000?oooooooooo05Gooooo0_l0000[ooooo`Co00003_ooool4o`000003oooo
ool0003o000000;o00003_ooool2o`0000Oooooo0_l0000Booooo`Co00000oooool2o`0000;ooooo
0_l00002ooooo`?o000000?oooooo`000?l00000K?ooool001cooooo00?o0000ooooooooool0EOoo
ool2o`0002Wooooo0_l00002ooooo`;o00003_ooool4o`0000?ooooo0_l00004ooooo`;o000000?o
ooooo`000?l000002Oooool2o`0001kooooo0_l00002ooooo`?o000000?oooooo`000?l000000_l0
000Mooooo`;o0000Coooool001cooooo00?o0000ooooooooool0DOooool2o`0000Wooooo0_l0000:
ooooo`;o00005Oooool3o`0001?ooooo0ol00004ooooo`;o00000oooool5o`0000;ooooo1_l00000
0ooooooo0000o`00000;ooooo`;o00005_ooool2o`000003ooooool0003o000000;o000000?ooooo
o`000?l000006_ooool2o`0004oooooo000Looooo`03o`000?oooooooooo04cooooo0_l00003oooo
o`;o00002Oooool2o`000003ooooool0003o000000Oooooo0_l0000Eooooo`;o00001_ooool2o`00
00Sooooo0_l00002ooooo`?o00001?ooool2o`0000Cooooo1Ol000000ooooooo0000o`000005o`00
00gooooo1?l000000ooooooo0000o`000009ooooo`;o00001_ooool2o`0000;ooooo0_l00002oooo
o`;o0000Joooool001cooooo00?o0000ooooooooool0C?ooool2o`0000Sooooo0_l00007ooooo`;o
00009_ooool2o`0000Sooooo0_l00008ooooo`;o00000oooool8o`0000Cooooo0ol00006ooooo`;o
00001?ooool2o`000003ooooool0003o000000Go00001oooool2o`0000Kooooo0_l000000ooooooo
0000o`00001`ooooo`007?ooool00ol0003oooooooooo`1?ooooo`;o00001Oooool2o`00013ooooo
0_l0000Pooooo`;o00002Oooool2o`0000?ooooo0ol000000ooooooo0000o`000004o`0000;ooooo
0_l00004ooooo`?o00001?ooool4o`0000Cooooo0_l00003ooooo`;o000000?oooooo`000?l00000
4_ooool2o`0000Kooooo0_l0000Iooooo`;o0000COooool001cooooo0_l00015ooooo`;o00001ooo
ool4o`000003ooooool0003o000001Cooooo0_l0000Pooooo`;o00002Oooool2o`0000?ooooo1_l0
00001?oooooo0000o`000?l00005ooooo`Ko00001?ooool2o`000003ooooool0003o000000Cooooo
0_l00002ooooo`?o00005?ooool3o`0000Gooooo0_l0000Iooooo`;o0000COooool001cooooo00?o
0000ooooooooool0A?ooool2o`0000Oooooo0_l000000ooooooo0000o`000004o`0001;ooooo0_l0
000aooooo`Ko00002?ooool5o`0000Sooooo0_l00004ooooo`?o000000Coooooo`000?l0003o0000
2oooool2o`0000Gooooo1_l0001^ooooo`007?ooool00ol0003oooooooooo`17ooooo`;o00001ooo
ool2o`0000;ooooo0_l0000Booooo`;o0000;Oooool2o`000003ooooool0003o000000Go00001?oo
ool2o`0000oooooo0_l00005ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Gooooo0ol0
0005ooooo`;o00000_ooool2o`0006kooooo000Looooo`03o`000?oooooooooo04Oooooo0_l00003
ooooo`;o000000?oooooo`000?l000000_l0000<ooooo`;o00001_ooool3o`0001gooooo0ol00000
1Ooooooo0000o`000?l0003ooooo00;o00001?ooool<o`000004ooooool0003o0000ooooo`;o0000
00?oooooo`000?l000003oooool2o`0000_ooooo0_l00005ooooo`;o00005_ooool2o`0000;ooooo
0ol00002ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0C?ooool7o`000003ooooool0
003o000000Wooooo0_l00006ooooo`;o00007_ooool7o`000003ooooool0003o000000;ooooo1?l0
0002ooooo`Go000000?oooooo`000?l000003?l00002ooooo`?o00000_ooool2o`0000?ooooo0_l0
0004ooooo`;o00001?ooool2o`0000Oooooo0_l00008ooooo`;o00002oooool2o`0000;ooooo0ol0
0002ooooo`Co0000Eoooool001cooooo00?o0000ooooooooool0C_ooool3o`0000?ooooo0_l00005
ooooo`;o0000:_ooool5o`0000?ooooo0_l00002ooooo`;o00001?ooool5o`0000?ooooo3?l00002
ooooo`Wo00001oooool2o`0000Cooooo0_l00007ooooo`Co00001_ooool3o`0001Gooooo0_l0001G
ooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00003oooool2o`0000[ooooo0ol0000Toooo
o`;o00000oooool5o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0000Cooooo0_l000001?oo
oooo0000o`000?l00003ooooo`;o000000?oooooo`000?l000003Ol0000<ooooo`?o00001oooool4
o`0000Oooooo0_l0001^ooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00002?ooool2o`00
0003ooooool0003o000000gooooo1?l00003ooooo`;o00007oooool2o`0000Cooooo1?l00002oooo
o`;o00000_ooool2o`0000?ooooo0ol00002ooooo`Ko00000_ooool3o`000003ooooool0003o0000
00go000000?oooooo`000?l000000_l00008ooooo`?o00001oooool2o`0001Cooooo0ol00004oooo
o`;o00000oooool2o`0005Oooooo000Looooo`03o`000?oooooooooo04Sooooo0_l000000ooooooo
0000o`00000=ooooo`;o00001Oooool2o`0001kooooo0ol00004ooooo`;o00001oooool3o`0000;o
oooo1?l00002ooooo`Go000000?oooooo`000?l000003_l00002ooooo`?o000000?oooooo`000?l0
00000_l00003ooooo`;o000000?oooooo`000?l000002oooool2o`0001?ooooo0ol00004ooooo`;o
00000oooool2o`0000;ooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`1Kooooo`;o0000
0_ooool2o`0000Cooooo0_l0000Jooooo`?o00001?ooool2o`0000;ooooo0_l00003ooooo`?o0000
0_ooool3o`0000;ooooo8?l00004ooooo`;o000000Coooooo`000?l0003o00002_ooool2o`0000oo
oooo0_l00003ooooo`;o00001?ooool2o`0000Oooooo0_l000000ooooooo0000o`00001@ooooo`00
7?ooool00ol0003oooooooooo`16ooooo`;o00004oooool2o`0000;ooooo0_l00004ooooo`;o0000
8Oooool3o`000004ooooool0003o0000o`0000;ooooo0_l00003ooooo`?o00000_ooool3o`000003
ooooool0003o000001?o00000oooool3o`000003ooooool0003o000000Kooooo0_l0000:ooooo`;o
00003oooool4o`000003ooooool0003o000000Cooooo0_l00008ooooo`Co0000D?ooool001cooooo
00?o0000ooooooooool0@_ooool2o`0000;ooooo0_l00004ooooo`;o00004oooool2o`0000;ooooo
0_l0000Qooooo`?o00000_ooool2o`0000;ooooo0_l00002ooooo`?o00000_ooool2o`0000;ooooo
7ol0000Booooo`?o00001oooool2o`0000Oooooo0_l00003ooooo`;o00002Oooool2o`000003oooo
ool0003o000005;ooooo000Looooo`03o`000?oooooooooo047ooooo0ol00003ooooo`;o000000?o
ooooo`000?l000000_l0000;ooooo`;o00001_ooool2o`0000;ooooo0_l0000^ooooo`Co000000?o
ooooo`000?l000004ol000000ooooooo0000o`00000;o`0001?ooooo0_l00003ooooo`;o00000_oo
ool2o`0000Gooooo0_l00003ooooo`Co00001Oooool2o`0000;ooooo1?l0001Cooooo`007?ooool0
0ol0003oooooooooo`11ooooo`;o00001?ooool2o`000003ooooool0003o000000gooooo0_l0000i
ooooo`Go00000ooooolCo`000003ooooool0003o000000oo000000?oooooo`000?l000002oooool3
o`0000;ooooo0ol00009ooooo`;o00000oooool3o`000003ooooool0003o000000?ooooo0_l00004
ooooo`;o00001Oooool2o`0004cooooo000Looooo`03o`000?oooooooooo04Kooooo0_l0000:oooo
o`;o00002oooool3o`0001oooooo0_l0000Aooooo`Co00000ooooolVo`000003ooooool0003o0000
00Gooooo0_l00004ooooo`?o00000_ooool2o`00013ooooo0_l000000ooooooo0000o`00000@oooo
o`;o0000C?ooool001cooooo00?o0000ooooooooool0AOooool3o`0000[ooooo0_l00009ooooo`Go
00007oooool2o`0001?ooooo0_l00003ooooob;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o
00004?ooool2o`0006Gooooo000Looooo`;o0000?oooool2o`000003ooooool0003o000000;ooooo
0_l00002ooooo`;o00001?ooool2o`000003ooooool0003o000000Cooooo0_l00003ooooo`Co0000
1?ooool2o`0001_ooooo1?l0000<ooooo`;o00001ooooolJo`000003ooooool0003o000000Ko0000
0_ooool4o`0000cooooo0_l00003ooooo`;o00002oooool2o`0000;ooooo0_l0000=ooooo`Ko0000
C_ooool001cooooo00?o0000ooooooooool0?_ooool5o`0000Kooooo0_l00004ooooo`;o00001ooo
ool2o`0000_ooooo0_l0000Kooooo`Co00003?ooool2o`0000Cooooo0_l00003ooooo`Ko000000?o
ooooo`000?l000003?l00003ooooo`Wo00000_ooool2o`000003ooooool0003o000000_ooooo0_l0
00000ooooooo0000o`000002o`0000Gooooo0_l00004ooooo`?o000000?oooooo`000?l000003?oo
ool7o`0004kooooo000Looooo`03o`000?oooooooooo043ooooo0_l00005ooooo`?o00001oooool2
o`000003ooooool0003o000000Gooooo1?l00003ooooo`;o000000?oooooo`000?l00000:?ooool7
o`0000;ooooo0_l00002ooooo`Oo000000?oooooo`000?l000003?l00003ooooo`Ko00001Oooool2
o`000003ooooool0003o000000_ooooo0_l000000ooooooo0000o`000007ooooo`;o00001Oooool2
o`0000;ooooo0_l0000;ooooo`;o00002?ooool2o`0004Wooooo000Looooo`03o`000?oooooooooo
03cooooo0_l00009ooooo`?o000000?oooooo`000?l000001?ooool5o`0000Cooooo1Ol00003oooo
o`;o00008_ooool2o`0000Oooooo2?l00002ooooob?o00001?ooool4o`0000?ooooo0_l00007oooo
o`?o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o00001_ooool4o`0001Gooooo0_l00000
0ooooooo0000o`000016ooooo`007?ooool00ol0003oooooooooo`0kooooo`Oo00002Oooool2o`00
00Kooooo0ol00004ooooo`?o00003?ooool2o`0001?ooooo0_l00003ooooo`Go00002_ooool5o`00
00;ooooo8ol00004ooooo`Co00000oooool2o`0000Oooooo0ol000001?oooooo0000o`000?ooool2
o`0000Cooooo0_l00006ooooo`?o00006Oooool2o`0004Kooooo000Looooo`03o`000?oooooooooo
03_ooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l00005ooooo`;o00002?ooool2o`00
0003ooooool0003o000000;o00003?ooool2o`0001?ooooo2?l0000<ooooo`?o000000?oooooo`00
0?l000009?l00004ooooo`;o00001Oooool2o`0000Oooooo0_l00002ooooo`;o00002?ooool2o`00
00Kooooo1?l0001Oooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00001Oooool2o`0000Co
oooo0ol00008ooooo`Ko00003Oooool2o`0000oooooo0_l00004ooooo`Co00003?ooool5o`000003
ooooool0003o000002?o000000?oooooo`000?l000004_ooool2o`0000cooooo0_l00008ooooo`;o
0000Goooool001cooooo00?o0000ooooooooool0?_ooool4o`000003ooooool0003o000000Kooooo
0ol00009ooooo`Co00003_ooool2o`0000oooooo0_l00003ooooo`Oo00002_ooool5o`0000;ooooo
9ol0000;ooooo`;o00001?ooool3o`0000Cooooo0_l000000ooooooo0000o`00000Rooooo`Co0000
B?ooool001cooooo00?o0000ooooooooool0@?ooool5o`0000_ooooo1?l00002ooooo`Go00003_oo
ool2o`0000kooooo0_l00004ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00001_oo
ool5o`0000;ooooo6ol000000ooooooo0000o`000008o`0000Cooooo0_l00005ooooo`?o00001?oo
ool5o`0000;ooooo0_l000000ooooooo0000o`00000Rooooo`Co00000oooool2o`0004?ooooo000L
ooooo`03o`000?oooooooooo03Wooooo0_l00007ooooo`;o00003?ooool9o`0000Sooooo0_l00009
ooooo`;o00002oooool4o`000003ooooool0003o000000;ooooo1?l00002ooooo`;o00001oooool3
o`0000?ooooo0_l000000ooooooo0000o`00000Lo`0000?ooooo0_l00004ooooo`;o00001Oooool2
o`0000Sooooo0_l00002ooooo`;o00002_ooool2o`0001;ooooo0_l0000<ooooo`;o0000@oooool0
01cooooo00?o0000ooooooooool0>Oooool2o`0001;ooooo1?l000000ooooooo0000o`000003o`00
0004ooooool0003o0000o`0000Kooooo0_l00006ooooo`;o000000?oooooo`000?l000003Oooool2
o`000003ooooool0003o000000Ko00002oooool3o`0000;ooooo0_l00002oooooako00000oooool2
o`0001;ooooo1?l000000ooooooo0000o`00000<ooooo`;o00004_ooool2o`0000Gooooo0_l00003
ooooo`Co0000@oooool001cooooo00?o0000ooooooooool0>Oooool2o`0000_ooooo0_l00005oooo
o`Oo00001?ooool3o`0000kooooo0_l0000?ooooo`;o00000_ooool8o`0000_ooooo0_l00003oooo
ob;o000000?oooooo`000?l000000_l00005ooooo`;o00002oooool4o`000003ooooool0003o0000
00[ooooo0_l0000Cooooo`;o00001Oooool3o`0000?ooooo1?l00013ooooo`007?ooool00ol0003o
ooooooooo`16ooooo`;o00001oooool6o`0000Cooooo0_l00002ooooo`;o00001Oooool4o`0001;o
oooo0_l000000ooooooo0000o`000004o`0000kooooo0_l000000ooooooo0000o`00000Vo`0000Ko
oooo0_l00005ooooo`;o00001_ooool2o`0000Cooooo0_l00007ooooo`;o00004oooool2o`0000Go
oooo0_l00005ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0B?ooool2o`0000;ooooo
0_l000000ooooooo0000o`000002ooooo`;o00002?ooool2o`0000Gooooo1?l0000Eooooo`Ko0000
3_ooool2o`000003ooooool0003o000002Ko000000?oooooo`000?l000002_ooool2o`0000?ooooo
0ol000000ooooooo0000o`000003ooooo`;o00000_ooool4o`000003ooooool0003o000000Cooooo
0_l0000=ooooo`;o00003?ooool2o`0004Cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGo
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0fooooo`;o
00001?ooool2o`0000[ooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0ol00008oooo
o`;o00008_ooool2o`0000_ooooo0_l000000ooooooo0000o`000004oooooaoo000000Coooooo`00
0?l0003ooooo0_l000000ooooooo0000o`00000?ooooo`?o000000?oooooo`000?l000000_ooool9
o`0000;ooooo0_l00003ooooo`;o00001Oooool2o`0000Kooooo0ol00008ooooo`;o000000?ooooo
o`000?l00000A?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0fooooo`;o000000Coooooo`000?l0003ooooo
0_l0000<ooooo`;o00000oooool2o`000003ooooool0003o0000013ooooo0_l0000=ooooo`;o0000
3?ooool2o`0000_ooooo1Ol00002ooooo`;o00000_oooolIo`000003ooooool0003o000000Cooooo
1?l0000Aooooo`Co00000_ooool9o`000004ooooool0003o0000ooooo`;o00002_ooool2o`000003
ooooool0003o000000Cooooo0_l00007ooooo`?o0000Aoooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool02Oooool5o`0000Kooooo00?o0000ooooooooool0>Oooool2o`000003oooo
ool0003o000000?ooooo0ol000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l00000
0_l000000ooooooo0000o`00000@ooooo`;o00002?ooool3o`000004ooooool0003o0000o`00017o
oooo0_l00007ooooo`Go000000Goooooo`000?l0003o0000ooooo`0Io`0000Cooooo0_l000000ooo
oooo0000o`000002o`00013ooooo1Ol00002ooooo`;o00000_ooool2o`0000Cooooo0_l0000@oooo
o`;o00003Oooool2o`0004Sooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wo
oooo00CoA4A4omgMgOoooooo00001oooool3o`00047ooooo0ol000000ooooooo0000o`000006oooo
o`;o00007oooool3o`000003ooooool0003o000000gooooo0_l00003ooooo`;o00002Oooool3o`00
0005ooooool0003o0000o`000?ooool06ol00002ooooo`;o00000oooool2o`0000Sooooo0_l00006
ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Cooooo0_l0000Looooo`;o000000?ooooo
o`000?l00000B?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?oM
gMgoEEEEooooool00007ooooo`03o`000?oooooooooo04Gooooo0_l0000Jooooo`;o00007_ooool4
o`0000gooooo1_l00002oooooa[o000000?oooooo`000?l000001?ooool2o`0000Sooooo0_l00004
ooooo`;o00000_ooool3o`0000cooooo0_l00005ooooo`;o00003oooool2o`0000Cooooo0ol00008
ooooo`;o0000@?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00omg
MgOoc<c<o`000007ooooo`03o`000?oooooooooo03Cooooo0_l0000:ooooo`;o00005?ooool3o`00
00?ooooo0_l00003ooooo`;o00002oooool2o`0000cooooo0_l000000ooooooo0000o`000002oooo
o`Go00002_ooool6o`0000;ooooo7Ol0000Dooooo`;o00000_ooool2o`000004ooooool0003o0000
ooooo`;o00001_ooool4o`0000Cooooo0ol00005ooooo`;o00001oooool2o`0000Gooooo0_l00008
ooooo`;o0000@?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`00
0007ooooo`03o`000?oooooooooo03?ooooo0ol00002ooooo`;o00000oooool2o`000003ooooool0
003o000001Cooooo0ol00003ooooo`;o00004?ooool2o`0000;ooooo0_l00008ooooo`;o000000?o
ooooo`000?l000001?ooool3o`0000[ooooo1_l00005oooooa[o00004oooool2o`0000;ooooo0ol0
00001?oooooo0000o`000?ooool2o`0000Kooooo1?l00002ooooo`;o000000?oooooo`000?l00000
1Oooool2o`0001Wooooo0_l0000oooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03
ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0<oooool2o`0000?ooooo0_l00003ooooo`?o
00003?ooool2o`000003ooooool0003o000000Cooooo0_l0000@ooooo`;o00001Oooool2o`0000;o
oooo0_l00008ooooo`;o00006Oooool2o`0000;ooooo6ol00002ooooo`;o00002Oooool2o`0000Go
oooo0_l00002ooooo`?o00002oooool5o`0000;ooooo0_l00007ooooo`;o00003oooool2o`0000Wo
oooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0aooooo`Co00001oooool4o`0000Wooooo
0_l000001?oooooo0000o`000?ooool2o`0000Cooooo0_l0000@ooooo`;o00002?ooool4o`0000;o
oooo1_l00003ooooo`;o00003Oooool2o`0000Kooooo0_l00002ooooo`;o00000_ooool>o`000003
ooooool0003o000000;ooooo1?l00002ooooo`;o00002Oooool2o`0000?ooooo1?l00002ooooo`;o
00003?ooool5o`0000Sooooo0_l000000ooooooo0000o`00000?ooooo`;o00001?ooool2o`0004Co
oooo000Looooo`03o`000?oooooooooo037ooooo1?l00007ooooo`;o00002oooool2o`0000Oooooo
0_l0000:ooooo`;o00002?ooool2o`0000Oooooo1?l00002ooooo`Ko00000oooool2o`0000?ooooo
0_l00008ooooo`;o00000_ooool3o`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l00000
0_l000000ooooooo0000o`000002ooooo`;o00000oooool3o`0000Gooooo0_l0000>ooooo`Go0000
00?oooooo`000?l000003Oooool4o`000003ooooool0003o000000;o000000?oooooo`000?l00000
0_l000000ooooooo0000o`00000Eooooo`;o00001Oooool2o`0003gooooo000Looooo`03o`000?oo
oooooooo037ooooo0_l00002ooooo`Co00003?ooool2o`0000_ooooo0_l00003ooooo`;o00001Ooo
ool2o`000003ooooool0003o000000Gooooo0_l0000?ooooo`?o000000?oooooo`000?l000001_oo
ool2o`0000Sooooo0_l00002ooooo`[o000000Goooooo`000?l0003o0000ooooo`03o`000004oooo
ool0003o0000o`0000;ooooo1?l000001?oooooo0000o`000?l00003ooooo`;o00002?ooool2o`00
00Kooooo2?l0000<ooooo`Go000000?oooooo`000?l000000_l000000ooooooo0000o`000007o`00
00Cooooo0ol0000Cooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0<?ooool3o`0000;o
oooo1?l00002ooooo`;o00000oooool2o`0000?ooooo0_l0000@ooooo`Co00000oooool2o`000003
ooooool0003o000000?ooooo0_l0000Aooooo`;o00000_ooool2o`0000Kooooo0_l00008ooooo`;o
00001?ooool6o`0000?ooooo0_l00006ooooo`Wo00001oooool2o`0000Sooooo0_l00003ooooo`;o
000000?oooooo`000?l000000_ooool2o`0000gooooo0ol000000ooooooo0000o`000004ooooo`;o
00000_ooool>o`0005;ooooo000Looooo`03o`000?oooooooooo033ooooo0_l00009ooooo`;o0000
0oooool2o`0001Oooooo1Ol00008ooooo`;o00004Oooool3o`000003ooooool0003o000000Kooooo
1?l0000<ooooo`_o00001_ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l00000
4?ooool2o`0000?ooooo0_l0000:ooooo`;o00001_ooool4o`0000?ooooo0_l00003ooooo`;o0000
0_ooool2o`000003ooooool0003o000000Oo0000E?ooool001cooooo00?o0000ooooooooool0A?oo
ool4o`0000Wooooo1?l000000ooooooo0000o`000002ooooo`Co00000_ooool2o`0000Sooooo0_l0
00001?oooooo0000o`000?l0000:ooooo`;o000000?oooooo`000?l000001_ooool4o`0000cooooo
3Ol000001?oooooo0000o`000?l00003ooooo`;o00000oooool2o`0000;ooooo0_l0000Mooooo`;o
00001Oooool3o`0000;ooooo0_l000000ooooooo0000o`000007ooooo`;o00001Oooool2o`0000co
oooo0_l00019ooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00003Oooool2o`000003oooo
ool0003o000000?o00000oooool2o`0000Cooooo1?l000000ooooooo0000o`000008ooooo`;o0000
1?ooool6o`000003ooooool0003o000000Co00001oooool2o`0000[ooooo0_l0000=oooooa7o0000
3?ooool2o`0002Cooooo0_l00003ooooo`;o00007oooool2o`0000Oooooo0_l00002ooooo`;o0000
??ooool001cooooo00?o0000ooooooooool0<Oooool2o`0000gooooo0_l000000ooooooo0000o`00
0002o`0000Cooooo0_l00006ooooo`;o00001?ooool3o`0000;ooooo0_l00004ooooo`So00000ooo
ool4o`0000?ooooo0_l0000>ooooo`;o00002Oooool2o`0000Gooooo0_l00002ooooo`?o00000ooo
ool4o`0000Cooooo0_l00002ooooo`?o00006?ooool7o`0000gooooo0_l0000Tooooo`Ko00000_oo
ool2o`000003ooooool0003o000003Wooooo000Looooo`03o`000?oooooooooo03Wooooo1?l00007
ooooo`?o00002?ooool2o`0000;ooooo0_l00004ooooo`?o00000_ooool>o`000003ooooool0003o
000000Ko000000?oooooo`000?l000003_ooool3o`0000Sooooo0ol00004ooooo`;o000000?ooooo
o`000?l000001Oooool2o`0000Kooooo0_l000000ooooooo0000o`000002o`0001Oooooo2_l00008
ooooo`;o00009oooool6o`0000Gooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`0^oooo
o`;o00002Oooool4o`0000Kooooo0ol00009ooooo`;o00001oooool2o`0000Gooooo1_l00002oooo
o`Co00000_ooool9o`0000gooooo0ol000000ooooooo0000o`000009ooooo`;o00001oooool9o`00
00Oooooo1?l0000Iooooo`?o00001Oooool2o`0000Kooooo1?l0000Rooooo`;o00000oooool2o`00
04Cooooo000Looooo`03o`000?oooooooooo02kooooo0_l00002ooooo`;o00003oooool4o`00017o
oooo0_l00004ooooo`Oo000000?oooooo`000?l000000ol00002ooooo`Wo00001Oooool2o`0000;o
oooo0_l000000ooooooo0000o`000003o`0001Kooooo1ol00003ooooo`;o00000_ooool2o`0001co
oooo0_l00005ooooo`;o000000?oooooo`000?l000000oooool2o`0000cooooo1?l00004ooooo`;o
00003_ooool2o`0000?ooooo0_l00002ooooo`;o0000@?ooool001cooooo0_l0000cooooo`;o0000
4Oooool2o`0000Oooooo0_l0000<oooooaWo00000_ooool2o`0000;ooooo0ol000000ooooooo0000
o`000003o`000003ooooool0003o000001Oooooo0_l00004ooooo`;o000000?oooooo`000?l00000
3oooool2o`0000Kooooo0_l00007ooooo`;o00000oooool2o`0000?ooooo0_l0000Aooooo`Co0000
1?ooool2o`0000Kooooo0_l0000?ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0;Ooo
ool5o`00013ooooo0_l0000:ooooo`;o00002oooool4o`0000;ooooo5?l00002ooooo`;o00000ooo
ool2o`0000;ooooo1?l0000Pooooo`;o00004_ooool2o`0000Gooooo0ol00007ooooo`;o00000ooo
ool2o`0000;ooooo0_l0000Mooooo`;o00000oooool2o`000004ooooool0003o0000o`0004gooooo
000Looooo`03o`000?oooooooooo02gooooo1Ol0000?ooooo`?o00002?ooool2o`0000?ooooo0_l0
0008ooooo`?o000000?oooooo`000?l000005?l000001?oooooo0000o`000?l00006ooooo`;o0000
1Oooool2o`0002cooooo0_l00009ooooo`;o00002?ooool2o`0000?ooooo0_l00002ooooo`;o0000
4?ooool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`?o00000_ooool2o`000004oooo
ool0003o0000o`0004gooooo000Looooo`03o`000?oooooooooo02kooooo0ol0000@ooooo`;o0000
2Oooool2o`0000?ooooo0_l00003ooooo`;o00000oooool2o`0000;ooooo5_l000001?oooooo0000
o`000?l00006ooooo`;o00000oooool4o`0000Oooooo0_l0000Sooooo`;o00004_ooool3o`0000?o
oooo0_l00002ooooo`;o00003Oooool2o`000004ooooool0003o0000ooooo`;o00001?ooool2o`00
00?ooooo0ol00004ooooo`?o00001_ooool2o`0004Gooooo000Looooo`03o`000?oooooooooo03;o
oooo0_l0000Fooooo`;o00002Oooool3o`0000?ooooo7ol0000:ooooo`;o00002?ooool3o`00027o
oooo0_l0000:ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Gooooo0_l0000@ooooo`;o
00001_ooool2o`0000Sooooo1?l00003ooooo`;o00001_ooool2o`0004Gooooo000Looooo`03o`00
0?oooooooooo03;ooooo0_l000000ooooooo0000o`00000Cooooo`Co00001oooool2o`0000Cooooo
7ol0000:ooooo`;o00002?ooool2o`0002;ooooo0_l0000:ooooo`;o000000?oooooo`000?l00000
0_l00005ooooo`;o00000oooool2o`0000[ooooo0ol000000ooooooo0000o`000008ooooo`;o0000
00?oooooo`000?l000001oooool2o`0000cooooo0_l00014ooooo`007?ooool00ol0003ooooooooo
o`0/ooooo`;o00001oooool2o`0001Cooooo1Ol0000;oooooaoo00001_ooool2o`0000;ooooo0_l0
0008ooooo`?o00005_ooool2o`0000;ooooo0_l0000Eooooo`?o00001Oooool2o`0000?ooooo0_l0
0007ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000_ooooo0_l00005ooooo`;o0000
00Coooooo`000?l0003ooooo0_l00008ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0
;?ooool2o`0000Sooooo0_l00006ooooo`;o00002oooool2o`000003ooooool0003o000000Sooooo
0_l000000ooooooo0000o`00000Mo`0000;ooooo0_l00002ooooo`;o00000_ooool2o`0000Sooooo
0ol0000Fooooo`;o00000_ooool2o`0001Gooooo0_l00004ooooo`;o00002Oooool2o`0000?ooooo
1?l0000Gooooo`;o000000Coooooo`000?l0003ooooo0_l0001>ooooo`007?ooool00ol0003ooooo
ooooo`0/ooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`;o00000_ooool3o`0000Ko
oooo0_l00006ooooo`;o00002?ooool2o`000003ooooool0003o000001So00000_ooool2o`0000?o
oooo0_l00006ooooo`;o0000>_ooool2o`0000?ooooo0_l000000ooooooo0000o`000009ooooo`;o
00001Oooool2o`0000?ooooo0_l00009ooooo`;o00001Oooool6o`0000_ooooo0_l00015ooooo`00
7?ooool00ol0003oooooooooo`0/ooooo`;o00001Oooool2o`0000Cooooo0_l00002ooooo`;o0000
1oooool2o`00013ooooo0ol00002oooooaco000000?oooooo`000?l000002?ooool2o`0000[ooooo
0_l000000ooooooo0000o`000002o`0002Kooooo0_l000000ooooooo0000o`000003ooooo`;o0000
5?ooool2o`0000;ooooo0_l00009ooooo`;o00001Oooool6o`0000Gooooo0_l00003ooooo`?o0000
AOooool001cooooo00?o0000ooooooooool0??ooool2o`0000Kooooo0_l0000=ooooo`;o00000ooo
ool3o`0000;ooooo7ol0000Dooooo`;o000000?oooooo`000?l000000_l0000Vooooo`Oo000000?o
ooooo`000?l000001_ooool2o`0000Oooooo0ol00002ooooo`;o00001Oooool2o`000003ooooool0
003o000000Cooooo1?l00003ooooo`Go00000oooool4o`0000?ooooo0_l00016ooooo`007?ooool0
0ol0003oooooooooo`0looooo`;o00001Oooool3o`0000Gooooo1?l00004ooooo`;o00002?ooool9
o`0000;ooooo4?l000000ooooooo0000o`00000=ooooo`;o00002?ooool2o`0000;ooooo0_l0000N
ooooo`;o000000?oooooo`000?l000002Ol000000ooooooo0000o`000006ooooo`;o00001oooool3
o`0000Wooooo0_l000000ooooooo0000o`00000<o`000003ooooool0003o000000?ooooo0ol00005
ooooo`;o00001?ooool2o`00043ooooo000Looooo`03o`000?oooooooooo02[ooooo0_l0000<oooo
o`;o00000_ooool2o`0000Gooooo0_l000000ooooooo0000o`000003ooooo`Co00000oooool2o`00
00[ooooo2?l000000ooooooo0000o`00000?o`000003ooooool0003o000000gooooo0_l00008oooo
o`Wo00003?ooool2o`0000Cooooo0_l000000ooooooo0000o`00000?o`0000cooooo0_l00005oooo
o`Co00003oooool@o`0000;ooooo0_l0000<ooooo`;o0000@?ooool001cooooo00?o0000oooooooo
ool0:_ooool2o`0000cooooo0_l0000:ooooo`Co00001Oooool4o`000003ooooool0003o000000[o
oooo1_l000000ooooooo0000o`000008o`000003ooooool0003o000000Co00000oooool2o`0000Wo
oooo0_l0000=ooooo`So00001oooool2o`0000?ooooo6_l0000Cooooo`;o00000_ooool2o`0000_o
oooo4_l000000ooooooo0000o`000003ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0
A?ooool3o`0000Oooooo0ol0000?oooooaOo00002Oooool2o`0000;ooooo0_l0000Aooooo`Co0000
00?oooooo`000?l000000oooool3o`0000Cooooo3ol00005ooooo`;o000000?oooooo`000?l00000
4oooool2o`0000;ooooo0_l00007oooooaGo00000_ooool2o`0000?ooooo0_l00007ooooo`;o0000
@Oooool001cooooo00?o0000ooooooooool0;oooool2o`00017ooooo0_l000000ooooooo0000o`00
0003ooooo`;o00001?ooool4o`0000Oooooo0_l00003oooooaSo00001?ooool2o`000004ooooool0
003o0000o`0001?ooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo1_l00002ooooo`Go
00001Oooool6o`0000Gooooo0_l000000ooooooo0000o`00000PoooooaKo00001_ooool2o`0000Oo
oooo0_l000000ooooooo0000o`00000nooooo`007?ooool2o`0002kooooo1?l0000Aooooo`;o0000
1_ooool2o`0000Cooooo1?l00007ooooo`;o000000?oooooo`000?l000005?l00002ooooo`;o0000
1?ooool2o`000003ooooool0003o000000;ooooo0_l00005ooooo`;o00002Oooool2o`0000Sooooo
0ol000000ooooooo0000o`000002ooooo`Go00001Oooool6o`0000Gooooo0_l000000ooooooo0000
o`00000=ooooo`;o00004ooooolDo`0000Kooooo0_l00009ooooo`?o0000?_ooool001cooooo00?o
0000ooooooooool0;Oooool2o`000003ooooool0003o000000kooooo0_l0000Dooooo`;o00000ooo
ool2o`000003ooooool0003o000001Ko00001?ooool2o`0000Oooooo0_l00004ooooo`?o00004Ooo
ool2o`000003ooooool0003o000000?o000000Coooooo`000?l0003ooooo1?l000001?oooooo0000
o`000?l0000Mooooo`;o00000_ooool2o`0000cooooo5ol00006ooooo`;o00002Oooool2o`0003oo
oooo000Looooo`03o`000?oooooooooo033ooooo0_l0000>ooooo`;o00005?ooool2o`0000Kooooo
6?l00004ooooo`;o00001oooool2o`0000Cooooo1Ol0000?ooooo`Oo00000_ooool2o`0000?ooooo
0_l000001?oooooo0000o`000?l0000Fooooo`;o00001Oooool2o`0000;ooooo1?l00003ooooo`;o
00001Oooool9o`0000;ooooo3Ol00004ooooo`?o00001_ooool2o`0004;ooooo000Looooo`03o`00
0?oooooooooo05Oooooo1?l00003oooooaCo000000?oooooo`000?l000000ol0000;ooooo`;o0000
1_ooool3o`00017ooooo1ol00009ooooo`Co000000Coooooo`000?l0003o00004?ooool2o`0000Go
oooo0_l00004ooooo`Co000000?oooooo`000?l000001?ooool3o`000003ooooool0003o000001?o
00001?ooool4o`0000Gooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o0000
5?ooool2o`00013ooooo1?l00003oooooa;o00000oooool6o`0000[ooooo0_l00008ooooo`;o0000
3_ooool2o`0000?ooooo1Ol00003ooooo`;o00000oooool8o`0000_ooooo0_l00002ooooo`;o0000
3_ooool2o`0000Oooooo5_l000000ooooooo0000o`000004ooooo`Co0000BOooool001cooooo00?o
0000ooooooooool0;oooool2o`0001Cooooo0_l0000Aooooo`;o00001_ooool@o`0000?ooooo0_l0
0002ooooo`;o00002_ooool2o`0000Cooooo0_l00002ooooo`;o00003_ooool4o`0000;ooooo1?l0
0003ooooo`;o00000oooool5o`0000kooooo0_l00002ooooo`;o00006?oooolHo`00057ooooo000L
ooooo`03o`000?oooooooooo04;ooooo0_l0000Fooooo`?o00000oooool6o`0000?ooooo1ol0000>
ooooo`;o00000oooool2o`0000Cooooo0_l0000Cooooo`?o00001?ooool2o`0000?ooooo0_l0000I
ooooo`Co00005_oooolHo`0000Cooooo1?l0001:ooooo`007?ooool00ol0003oooooooooo`12oooo
o`;o00003?ooool2o`0000Sooooo0ol00004ooooo`Go00001?ooool7o`000003ooooool0003o0000
00;o00002?ooool2o`0000oooooo0_l0000=ooooo`;o00000oooool2o`0000Gooooo0_l0000Doooo
o`;o00000oooool4o`0000cooooo0_l00008oooooaSo000000Coooooo`000?l0003ooooo1?l0001:
ooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00003oooool6o`0000Kooooo2Ol00002oooo
o`;o00000_ooool2o`000003ooooool0003o000000gooooo0ol0000Booooo`;o00002?ooool2o`00
017ooooo0_l0000Cooooo`;o00001oooool3o`000003ooooool0003o000001?o000000?oooooo`00
0?l000002Oooool2o`0004Cooooo000Looooo`03o`000?oooooooooo03;ooooo1?l0000Eooooo`;o
00005?ooool2o`000005ooooool0003o0000o`000?ooool02?l000001?oooooo0000o`000?ooool3
o`000005ooooool0003o0000o`000?ooool00_l000000ooooooo0000o`00000=ooooo`;o00007Ooo
ool2o`0001Wooooo0_l0000Dooooo`;o000000?oooooo`000?l000005?l0000<ooooo`;o0000A?oo
ool001cooooo00?o0000ooooooooool0<_ooool4o`0000cooooo0_l00005ooooo`Co00005oooool2
o`0000;ooooo2_l00003ooooo`;o000000Coooooo`000?l0003o00005Oooool2o`0000Sooooo1Ol0
0004ooooo`;o00000_ooool4o`0001gooooo0_l0000Dooooo`;o000000?oooooo`000?l000005?l0
0008ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0;oooool2o`00017ooooo0_l00005
ooooo`?o00006oooool2o`0000Cooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o
000000;ooooo0_l00008ooooo`;o00002_ooool3o`0000Sooooo1Ol000001?oooooo0000o`000?oo
ool2o`0000;ooooo1_l0000eoooooa;o00002_ooool3o`0004Sooooo000Looooo`03o`000?oooooo
oooo02oooooo0_l0000Iooooo`;o00002?ooool2o`0000_ooooo0_l00004ooooo`;o00001?ooool:
o`0000;ooooo0_l00008ooooo`;o00002_ooool2o`0000oooooo1?l00007ooooo`;o00000_ooool2
o`0001Gooooo0_l0000Joooooa;o00002Oooool3o`0004Wooooo000Looooo`03o`000?oooooooooo
03;ooooo0_l0000Fooooo`;o00002?ooool2o`0000Cooooo0_l00005ooooo`Go00001_ooool:o`00
0003ooooool0003o000000;ooooo0_l00006ooooo`;o00007Oooool3o`0000[ooooo0_l0000Eoooo
o`;o00003oooool2o`0000[ooooo4?l0000:ooooo`;o0000B_ooool001cooooo00?o0000oooooooo
ool0<_ooool2o`0001Cooooo0_l00008ooooo`;o00001_ooool4o`0000Gooooo1ol00002ooooo`;o
00001_ooool2o`000003ooooool0003o000000;ooooo0_l0000Gooooo`;o00003Oooool2o`000003
ooooool0003o000000Kooooo0_l0000Looooo`;o00002Oooool2o`0000Kooooo0_l00008ooooo`;o
000000?oooooo`000?l000001Ol00008ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0
<oooool2o`0001?ooooo0_l00007ooooo`Co00001oooool2o`0000;ooooo0_l00004ooooo`Co0000
4oooool5o`0001;ooooo0_l00009ooooo`Co00000oooool2o`0000Kooooo1?l0000Jooooo`;o0000
1?ooool2o`0000_ooooo0_l000000ooooooo0000o`000009ooooo`Go00002Oooool2o`0004cooooo
000Looooo`;o0000<oooool3o`00013ooooo0_l0000:ooooo`Co00002?ooool2o`000004ooooool0
003o0000o`0000;ooooo1?l00004ooooo`;o00003_ooool5o`0000gooooo0_l00006ooooo`;o0000
1_ooool4o`0000?ooooo0_l00005ooooo`;o000000?oooooo`000?l000003?ooool2o`0001;ooooo
0_l00009ooooo`;o00000oooool2o`0000?ooooo0_l000001?oooooo0000o`000?l0000;ooooo`Co
0000COooool001cooooo00?o0000ooooooooool0<_ooool2o`00017ooooo0_l0000<ooooo`?o0000
1_ooool3o`0000;ooooo0ol000001?oooooo0000o`000?l00005ooooo`;o00001?ooool2o`0000Wo
oooo2?l00009ooooo`;o00000_ooool2o`0000;ooooo1?l0000;ooooo`;o00000oooool4o`000003
ooooool0003o000000cooooo0ol00004ooooo`;o00005_ooool2o`0000Sooooo0_l000001?oooooo
0000o`000?l00009ooooo`Ko0000COooool001cooooo00?o0000ooooooooool0@Oooool2o`00013o
oooo0ol00006ooooo`Co00000_ooool2o`0000Sooooo0_l00003ooooo`Ko00002Oooool8o`0000_o
oooo0_l00003ooooo`?o00001?ooool2o`000004ooooool0003o0000o`0000Kooooo1?l000000ooo
oooo0000o`00000=ooooo`;o00000oooool3o`0000Oooooo0_l00005ooooo`;o00002_ooool5o`00
013ooooo0_l000000ooooooo0000o`00001>ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o
00003?ooool2o`00013ooooo0_l00002ooooo`;o00000oooool8o`0000Sooooo0_l00003ooooo`?o
000000?oooooo`000?l000002?ooool;o`0001?ooooo1?l000001?oooooo0000o`000?l00002oooo
o`Ko00004_ooool2o`0000?ooooo0_l00008ooooo`?o00001?ooool2o`0000[ooooo1Ol00009oooo
o`;o000000?oooooo`000?l00000EOooool001cooooo00?o0000ooooooooool0<oooool2o`0000[o
oooo0_l0000Fooooo`;o00000_ooool9o`0000kooooo0_l00004ooooo`;o00001?ooool9o`000003
ooooool0003o000001?ooooo1Ol000000ooooooo0000o`000002ooooo`So00004?ooool2o`0000ko
oooo0_l0000Cooooo`Go00001?ooool4o`000003ooooool0003o000000;o0000Doooool001cooooo
00?o0000ooooooooool0<oooool2o`0000[ooooo0_l0000?ooooo`;o00000oooool2o`0000;ooooo
1?l00002ooooo`[o00001Oooool2o`0000Sooooo0_l00004ooooo`co00004?ooool3o`0000?ooooo
0ol00005ooooo`Co000000?oooooo`000?l000007oooool4o`0001?ooooo1?l00004ooooo`;o0000
0_ooool2o`000003ooooool0003o000005?ooooo000Looooo`03o`000?oooooooooo03?ooooo0_l0
000;ooooo`?o00003Oooool4o`000003ooooool0003o000000;ooooo0_l00005ooooo`;o00000_oo
ool5o`0000Gooooo1?l00006ooooo`Co000000?oooooo`000?l000002Ol0000Booooo`?o00000ooo
ool3o`0000Gooooo1?l00005ooooo`;o00003_ooool3o`0000Wooooo1_l00004ooooo`;o00001ooo
ool2o`0000oooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00002Oooool5
o`0000oooooo0_l00004ooooo`;o00003Oooool2o`000004ooooool0003o0000ooooo`Go00000ooo
ool2o`0000?ooooo0_l000000ooooooo0000o`000009o`0000Wooooo0_l00007ooooo`;o00001?oo
ool4o`0000Kooooo0_l00002ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Sooooo0ol0
0008ooooo`Co000000?oooooo`000?l000001?ooool3o`0000Kooooo0_l0001Wooooo`007?ooool0
0ol0003oooooooooo`0cooooo`;o00002Oooool2o`000003ooooool0003o000001Gooooo0_l00000
0ooooooo0000o`000004ooooo`;o00001?ooool2o`000003ooooool0003o000000?o000000?ooooo
o`000?l000000oooool2o`0000?ooooo0_l00002ooooo`[o00002Oooool4o`0000Gooooo0_l00006
ooooo`;o00001_ooool2o`0000;ooooo0_l00007ooooo`;o00000oooool2o`0000kooooo0_l0000:
ooooo`;o00001_ooool2o`000003ooooool0003o000006Cooooo000Looooo`03o`000?oooooooooo
047ooooo0_l0000Hooooo`;o00001?ooool2o`0000Cooooo0_l00002ooooo`?o00004?ooool:o`00
00Gooooo0_l00003ooooo`?o00001Oooool2o`000003ooooool0003o000000Cooooo0ol00004oooo
o`Co00003_ooool3o`0000_ooooo0_l0000Gooooo`;o0000I?ooool001cooooo00?o0000oooooooo
ool0<oooool2o`0003;ooooo0_l0000=ooooo`;o00001_ooool<o`0000;ooooo0ol00003ooooo`;o
00001_ooool2o`000003ooooool0003o000000Cooooo0ol00004ooooo`Go00003_ooool2o`0000_o
oooo0_l00009ooooo`;o00002_ooool2o`0006Kooooo000Looooo`03o`000?oooooooooo03?ooooo
0_l0000<ooooo`;o00007_ooool2o`0000;ooooo0_l00009ooooo`;o00001?ooool2o`0000Oooooo
2ol00002ooooo`;o00002Oooool2o`0001;ooooo1?l00006ooooo`;o00003oooool2o`000003oooo
ool0003o000000Gooooo0_l00003ooooo`;o00002_ooool2o`0006Kooooo000Looooo`03o`000?oo
oooooooo03Cooooo0_l0000;ooooo`;o00007_ooool6o`0000Cooooo0_l00003ooooo`;o00001_oo
ool3o`0000Cooooo3Ol00006ooooo`;o00000_ooool3o`0000;ooooo0_l0000>ooooo`Go00001Ooo
ool2o`000003ooooool0003o000000cooooo0_l000000ooooooo0000o`000005ooooo`;o0000Mooo
ool001cooooo00?o0000ooooooooool0=?ooool2o`0001;ooooo0_l0000Iooooo`;o00001_ooool2
o`0000Oooooo0_l00002ooooo`Go00000oooool>o`0000Cooooo0ol000000ooooooo0000o`000003
ooooo`;o00001oooool2o`0000Gooooo1Ol00008ooooo`;o00005oooool2o`00017ooooo0_l00000
0ooooooo0000o`00001Pooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?oo
ool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0@_ooool2o`0000?ooooo
0ol000000ooooooo0000o`00000Iooooo`;o00002_ooool6o`0000?ooooo0_l00003ooooo`_o0000
00?oooooo`000?l000001Oooool2o`0000Cooooo1?l00002ooooo`;o00000oooool5o`000003oooo
ool0003o000000Co00008Oooool2o`00017ooooo0_l000000ooooooo0000o`00001Pooooo`0000Ko
ooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q
00Kooooo00?o0000ooooooooool0@_ooool2o`0000?ooooo0_l00002ooooo`;o00006Oooool2o`00
00Gooooo0_l00003ooooo`?o000000?oooooo`000?l000000_l000000ooooooo0000o`000002oooo
o`co00000oooool2o`0000Gooooo0_l00002ooooo`;o00001?ooool2o`0000Cooooo3?l0000:oooo
o`;o0000S?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool0B_ooool2o`00027ooooo0_l00004oooo
o`;o00000oooool2o`0000Gooooo2ol00004ooooo`;o00001Oooool2o`0000[ooooo1Ol00003oooo
o`_o000000?oooooo`000?l000000ol000000ooooooo0000o`00000]ooooo`;o0000GOooool00003
ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q
00Kooooo0ol0001:ooooo`;o00009?ooool2o`0000Sooooo0_l00007ooooo`?o00000_ooool2o`00
00Oooooo1?l00002ooooo`;o00002?ooool5o`0000Gooooo2Ol000000ooooooo0000o`000003o`00
02Sooooo0_l00006ooooo`;o0000GOooool00003ooooool0003ooooo00;ooooo00?o0000oooooooo
ool02Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0B_ooool2o`00
02Cooooo0_l00007ooooo`?o00000_ooool2o`0000?ooooo1Ol00009ooooo`Co00000_ooool2o`00
00Oooooo1Ol00003ooooo`;o00001?ooool5o`0002oooooo0_l00006ooooo`?o0000G?ooool00003
ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03
o`000?oooooooooo04Cooooo0ol0000booooo`;o00000oooool2o`0000?ooooo1Ol00009ooooo`;o
00003Oooool5o`0000?ooooo0_l00004ooooo`?o00008Oooool3o`0000Sooooo0_l0000;ooooo`?o
00000oooool2o`0005Oooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@
4?nHV9P02?ooool00ol0003oooooooooo`0hooooo`;o00002Oooool5o`0003;ooooo1?l000001?oo
oooo0000o`000?l00007ooooo`;o00001oooool2o`0000Kooooo0_l00006ooooo`;o00001?ooool2
o`0001;ooooo0_l00004ooooo`;o00003_ooool3o`0000;ooooo0_l00004ooooo`;o00004Oooool2
o`0005Oooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@
1_ooool00ol0003oooooooooo`0hooooo`;o00002Oooool2o`000003ooooool0003o0000037ooooo
1Ol000001?oooooo0000o`000?l00007ooooo`;o000000?oooooo`000?l000000_ooool6o`0000Co
oooo0_l00006ooooo`;o00006?ooool2o`0000Cooooo0_l000000ooooooo0000o`000006ooooo`?o
00001oooool2o`00073ooooo000Looooo`03o`000?oooooooooo04?ooooo0_l0000dooooo`Co0000
00Coooooo`000?l0003ooooo1?l00007ooooo`;o00000_ooool2o`000004ooooool0003o0000o`00
00cooooo0_l0000Eooooo`;o00002_ooool2o`0000Kooooo0ol00006ooooo`?o00001?ooool2o`00
06[ooooo000Looooo`03o`000?oooooooooo04Wooooo0_l0000Pooooo`;o00003_ooool2o`000003
ooooool0003o000000Go00003Oooool3o`0002?ooooo0ol00005ooooo`;o00000_ooool3o`0000Ko
oooo0ol00006ooooo`;o00001Oooool2o`0000gooooo0_l0001Kooooo`007?ooool00ol0003ooooo
ooooo`19ooooo`;o00008?ooool4o`0000cooooo0_l00002ooooo`;o00000oooool3o`0000_ooooo
0_l0000;ooooo`Co00000_ooool2o`00017ooooo0ol000000ooooooo0000o`000002ooooo`;o0000
0_ooool2o`000004ooooool0003o0000o`0000cooooo0_l00005ooooo`;o00003Oooool2o`0005_o
oooo000Looooo`03o`000?oooooooooo04_ooooo0_l0000Pooooo`;o00005Oooool4o`0000?ooooo
0_l00004ooooo`;o00003?ooool4o`0000;ooooo0_l0000?ooooo`;o000000Coooooo`000?l0003o
oooo1Ol000001?oooooo0000o`000?ooool5o`0000Kooooo0_l00004ooooo`;o00001Oooool2o`00
00oooooo0_l0001Iooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00002?ooool2o`0000?o
oooo0_l000000ooooooo0000o`00000Uooooo`;o00002?ooool2o`000003ooooool0003o000000?o
oooo1_l000000ooooooo0000o`000004ooooo`;o00002?ooool2o`000004ooooool0003o0000oooo
o`;o00004_ooool3o`000004ooooool0003o0000ooooo`So000000?oooooo`000?l000002Oooool2
o`0001cooooo0_l00003ooooo`;o0000E?ooool001cooooo00?o0000ooooooooool0>?ooool3o`00
00Sooooo0_l00003ooooo`;o000000?oooooo`000?l000009Oooool3o`0000Cooooo0_l000001?oo
oooo0000o`000?ooool4o`0000Cooooo1?l0000;ooooo`;o00000oooool2o`000004ooooool0003o
0000ooooo`;o00000_ooool2o`0000kooooo0_l00005ooooo`oo000000?oooooo`000?l000000_l0
0009ooooo`;o00006?ooool2o`0005Cooooo000Looooo`03o`000?oooooooooo03Sooooo0ol0000h
ooooo`;o00001?ooool2o`0000Cooooo1?l00004ooooo`Co00002oooool3o`0000?ooooo0_l00007
ooooo`;o00003_ooool2o`0000Cooooo4?l000000ooooooo0000o`000002o`0000Wooooo0_l0001^
ooooo`007?ooool00ol0003oooooooooo`0hooooo`Co00002_ooool4o`0001Gooooo0ol000000ooo
oooo0000o`000004ooooo`;o000000?oooooo`000?l000002oooool2o`0000Cooooo0_l00008oooo
o`;o00001?ooool2o`0000Kooooo0_l00003ooooo`Go00000_ooool2o`0000Oooooo0_l00005oooo
o`Co00001?ooool7o`0000;ooooo2_l00002ooooo`;o00008_ooool2o`0005?ooooo000Looooo`03
o`000?oooooooooo03[ooooo0_l0000:ooooo`Co00001oooool2o`0000cooooo0ol000000ooooooo
0000o`000004ooooo`;o000000?oooooo`000?l000006oooool2o`0000Cooooo0_l00002ooooo`;o
000000?oooooo`000?l000001_ooool3o`0000;ooooo0ol00006ooooo`?o00001?ooool2o`0000Ko
oooo5?l000001?oooooo0000o`000?l0000Qooooo`;o00008Oooool2o`00033ooooo000Looooo`03
o`000?oooooooooo04_ooooo0_l00004ooooo`;o00008Oooool2o`0001gooooo0_l000000ooooooo
0000o`000007ooooo`;o00000oooool2o`0000Gooooo1ol00006ooooo`;o000000?oooooo`000?l0
00004_l00002ooooo`;o0000A?ooool2o`00033ooooo000Looooo`03o`000?oooooooooo04Sooooo
0_l000000ooooooo0000o`000002ooooo`;o00008oooool3o`0000Wooooo0_l0000Cooooo`;o0000
0oooool2o`000003ooooool0003o000000Cooooo0ol00005ooooo`;o000000?oooooo`000?l00000
0_l00004oooooa7o00000oooool5o`0000?ooooo0ol000000ooooooo0000o`00001aooooo`007?oo
ool2o`0004Wooooo0_l00005ooooo`;o00009?ooool2o`0000Wooooo0_l00007ooooo`;o00002_oo
ool2o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`?o00003ooooolLo`0000;ooooo0ol0
00000ooooooo0000o`000003ooooo`;o0000>?ooool2o`0003;ooooo000Looooo`03o`000?oooooo
oooo03[ooooo0_l0000Tooooo`;o00002oooool2o`0001;ooooo1_l00002ooooo`Co00002?ooool2
o`0000?ooooo0_l00006ooooo`Go00003Oooool3o`000003ooooool0003o000001Ko00000oooool2
o`0000Kooooo0_l0000hooooo`;o0000<_ooool001cooooo00?o0000ooooooooool0>_ooool2o`00
01;ooooo0_l00002ooooo`;o00003?ooool2o`0000_ooooo0_l0000>ooooo`;o00000_ooool6o`00
00?ooooo0ol0000?ooooo`;o00001?ooool2o`000003ooooool0003o000000Oooooo1?l00002oooo
ob7o00002Oooool2o`0006Wooooo000Looooo`03o`000?oooooooooo04kooooo0ol000000ooooooo
0000o`000006ooooo`;o00004?ooool3o`0000kooooo0_l00002ooooo`;o00001Oooool8o`0000Oo
oooo0_l00003ooooo`Co00001Oooool2o`0000Oooooo1?l00005oooooako00002Oooool2o`0006Wo
oooo000Looooo`03o`000?oooooooooo04oooooo0_l00009ooooo`;o00004?ooool3o`00013ooooo
0_l00003ooooo`go00001_ooool2o`0000Gooooo0ol00008ooooo`;o00003?oooolNo`0007Cooooo
000Looooo`03o`000?oooooooooo04oooooo0_l0000/ooooo`Go00000_ooool>o`0000Gooooo0_l0
0004ooooo`Co00002?ooool4o`0000Wooooo8?l00002ooooo`;o0000Koooool001cooooo00?o0000
ooooooooool0?_ooool2o`0001;ooooo1?l0000Oooooo`;o00001_oooolEo`0000_ooooo0_l0000<
ooooo`;o00002?oooolIo`000003ooooool0003o000000Go00000_ooool2o`000003ooooool0003o
000006cooooo000Looooo`03o`000?oooooooooo03kooooo0_l0000Booooo`Co00000_ooool2o`00
01_ooooo0_l00006ooooo`?o000000?oooooo`000?l000003Ol0000Fooooo`?o00000_ooool2o`00
00Sooooo0_l00002oooooago00000_ooool5o`0006cooooo000Looooo`03o`000?oooooooooo043o
oooo0_l0000Eooooo`Go00002Oooool2o`0000;ooooo0_l0000Booooo`?o000000?oooooo`000?l0
00004_l000000ooooooo0000o`000002ooooo`;o00002_ooool3o`0000;ooooo0_l0000;oooooa[o
000000?oooooo`000?l000001?ooool2o`0000;ooooo0_l000000ooooooo0000o`00001Wooooo`00
7?ooool00ol0003oooooooooo`10ooooo`;o00000_ooool2o`00017ooooo1Ol000001?oooooo0000
o`000?ooool8o`000004ooooool0003o0000o`0000gooooo7?l000001Ooooooo0000o`000?l0003o
oooo00;o00000oooool4o`0000?ooooo0ol0000?oooooago00001oooool3o`000003ooooool0003o
000006Oooooo000Looooo`03o`000?oooooooooo043ooooo0_l00002ooooo`;o00003Oooool2o`00
00?ooooo0_l00003ooooo`;o000000?oooooo`000?l000002_l00007ooooo`;o00001?ooool=o`00
0003ooooool0003o000000go000000?oooooo`000?l000000_ooool2o`0000;ooooo1?l00003oooo
o`Go00003Oooool2o`000003ooooool0003o000001[o000000?oooooo`000?l000000_ooool2o`00
00;ooooo0_l0001Wooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00000oooool2o`0000co
oooo0_l00003ooooo`;o00000_ooool2o`0000Wooooo1Ol00003ooooo`;o00000_ooool2o`000003
ooooool0003o000000Gooooo6Ol00005ooooo`;o00003?ooool2o`00013ooooo7ol00004ooooo`Co
0000Ioooool001cooooo00?o0000ooooooooool0@oooool4o`0000gooooo0_l00006ooooo`;o0000
0oooool2o`0000Kooooo1?l00002ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o
00000_oooolHo`0001Wooooo0_l0000;oooooaWo00000_ooool4o`0000;ooooo1?l0001Yooooo`00
7?ooool00ol0003oooooooooo`13ooooo`Co00003Oooool2o`0000_ooooo0_l00008ooooo`;o0000
0_ooool2o`0000;ooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo5_l0000Fooooo`;o
000000?oooooo`000?l000002OoooolLo`000004ooooool0003o0000o`0000?ooooo0ol0000^oooo
o`;o0000>_ooool001cooooo00?o0000ooooooooool0Goooool3o`0000Cooooo0_l00003ooooo`Co
00000_ooool2o`0000Wooooo6Ol0000Fooooo`;o00003?ooool2o`0000;ooooo7?l00004ooooo`;o
0000;_ooool2o`0003[ooooo000Looooo`03o`000?oooooooooo04?ooooo0_l0000Cooooo`?o0000
1?ooool3o`0000;ooooo2ol00002ooooo`;o00002ooooolGo`0002Sooooo6ol0000Pooooo`;o0000
Coooool001cooooo0_l00014ooooo`;o00004oooool3o`0000Wooooo0_l000000ooooooo0000o`00
0002o`0000Kooooo0_l00004ooooo`;o00001_ooool;o`0000;ooooo2Ol0000>ooooo`;o00003ooo
ool2o`0000Wooooo2?l000000ooooooo0000o`000009o`0000?ooooo1?l0000Mooooo`?o0000Cooo
ool001cooooo00?o0000ooooooooool0I?ooool2o`000003ooooool0003o000000Co00001?ooool2
o`0000Cooooo0_l000000ooooooo0000o`000003oooooaCo000000Coooooo`000?l0003o00003?oo
ool2o`0000oooooo0ol00005ooooo`;o00000oooool3o`000003ooooool0003o000000go00001?oo
ool3o`0001cooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`18ooooo`?o00007Oooool7
o`000004ooooool0003o0000o`0000;ooooo0_l00003ooooo`;o00001?ooool2o`000003ooooool0
003o000000ko000000Coooooo`000?l0003o00003Oooool2o`0000kooooo0ol00005ooooo`Co0000
00Goooooo`000?l0003o0000ooooo`0?o`0000Cooooo0ol0000Iooooo`;o0000Doooool001cooooo
00?o0000ooooooooool0B?ooool3o`0001kooooo0_l000001Ooooooo0000o`000?l0003ooooo00?o
00000_ooool2o`0000Sooooo0_l000000ooooooo0000o`00000@o`00013ooooo0_l0000Cooooo`;o
00000oooool2o`000003ooooool0003o000000Ko00000_ooool5o`0002Cooooo0_l0001Cooooo`00
7?ooool00ol0003oooooooooo`1Yooooo`;o00000_ooool2o`00013ooooo5_l0000Tooooo`;o0000
1_ooool:o`0000;ooooo0ol0000Tooooo`;o0000Doooool001cooooo00?o0000ooooooooool0C?oo
ool2o`0001oooooo0_l000000ooooooo0000o`00000=oooooaSo00008Oooool2o`0000Oooooo0_l0
0006ooooo`;o00000_ooool2o`0000Sooooo0_l0001`ooooo`007?ooool00ol0003oooooooooo`1<
ooooo`;o00004_ooool2o`0000_ooooo2Ol00006ooooo`;o000000Coooooo`000?l0003ooooo5Ol0
0007ooooo`;o00006?ooool2o`0001gooooo0_l0000]ooooo`;o0000@Oooool001cooooo00?o0000
ooooooooool0H?ooool2o`0000_ooooo0ol00002ooooo`Co000000?oooooo`000?l000000oooool2
o`0000;ooooo1?l000000ooooooo0000o`00000=o`0000Kooooo0_l00002ooooo`;o00005_ooool2
o`0001oooooo0_l0000]ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0KOooool3o`00
00Oooooo0_l00007oooooa?o00001_ooool3o`0000Kooooo0_l00006ooooo`;o00002_ooool2o`00
097ooooo000Looooo`03o`000?oooooooooo07Oooooo0_l00009ooooo`?o000000?oooooo`000?l0
00003Ol00002ooooo`Co00001oooool2o`0000Kooooo0ol00011ooooo`;o0000FOooool001cooooo
00?o0000ooooooooool0D_ooool2o`0001cooooo0ol00004ooooo`;o00002?ooool2o`0000;ooooo
2ol000000ooooooo0000o`000002o`0000;ooooo0_l00009ooooo`;o00001oooool2o`0001_ooooo
0_l000000ooooooo0000o`00000Pooooo`?o0000FOooool001cooooo00?o0000ooooooooool0D_oo
ool2o`0000oooooo0_l00006ooooo`;o00000oooool3o`0000Oooooo0_l00005ooooo`;o00000_oo
ool2o`0000;ooooo1_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000007Ooo
ool3o`0000gooooo0_l000000ooooooo0000o`00000Pooooo`;o0000F_ooool001cooooo00?o0000
ooooooooool0D_ooool2o`0000oooooo0_l00006ooooo`;o00003Oooool2o`0000gooooo0ol00000
0ooooooo0000o`000003o`0000Cooooo0_l000000ooooooo0000o`00000;ooooo`;o00002?ooool2
o`0000Kooooo0ol0002>ooooo`007?ooool00ol0003oooooooooo`1booooo`;o00001oooool2o`00
00gooooo1ol000001?oooooo0000o`000?l0000Aooooo`Co00001_ooool2o`0003Kooooo0_l0001O
ooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o00002oooool3o`0000Kooooo0_l00007oooo
o`Co00000oooool6o`000005ooooool0003o0000o`000?ooool00_l0000<ooooo`;o00000_ooool2
o`0003gooooo0ol0000Dooooo`;o0000BOooool001cooooo00?o0000ooooooooool0IOooool2o`00
00Kooooo0_l00004ooooo`;o00001?ooool2o`000003ooooool0003o000000;ooooo0_l00002oooo
o`Co00000oooool4o`0000Cooooo0_l000000ooooooo0000o`00000<ooooo`;o00009_ooool3o`00
00kooooo0_l00006ooooo`Co00005Oooool2o`0004Wooooo000Looooo`;o0000F_ooool2o`0000co
oooo0_l00004ooooo`;o00001?ooool2o`0000Cooooo1Ol00002ooooo`Co00000oooool2o`0000;o
oooo1?l0000<ooooo`;o00000oooool3o`0002Wooooo1Ol00003ooooo`;o00001oooool2o`0000Ko
oooo0_l0001Rooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o00003?ooool2o`00017ooooo
0_l00006ooooo`;o00000oooool9o`000003ooooool0003o000000Sooooo0_l000000ooooooo0000
o`000004o`0002Wooooo1?l00003ooooo`;o0000Loooool001cooooo00?o0000ooooooooool0G?oo
ool2o`0000[ooooo0_l0000Mooooo`Co00000_ooool6o`0000_ooooo0_l00002ooooo`;o000000?o
ooooo`000?l00000>?ooool2o`0001Wooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`1L
ooooo`;o00002_ooool2o`0000[ooooo0ol0000@ooooo`;o00001?ooool2o`000004ooooool0003o
0000o`0000cooooo1Ol000000ooooooo0000o`00000`ooooo`;o00001_ooool2o`0001Wooooo0_l0
001=ooooo`007?ooool00ol0003oooooooooo`1dooooo`?o00006?ooool4o`000003ooooool0003o
000000Kooooo2Ol0000booooo`;o00000_ooool2o`0006cooooo000Looooo`03o`000?oooooooooo
07kooooo0_l0000?ooooo`;o00000_ooool3o`0000Cooooo1ol00002ooooo`;o0000=_ooool2o`00
01Wooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`1/ooooo`;o00002?ooool2o`0000Ko
oooo0_l00005ooooo`;o00001oooool2o`0000;ooooo1?l00003ooooo`Co0000=_ooool2o`00027o
oooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o00002_ooool2o`0000Sooooo
0ol00009ooooo`Ko00001_ooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l00000
1?l0000dooooo`;o00000_ooool2o`00073ooooo000Looooo`03o`000?oooooooooo063ooooo0_l0
000Eooooo`;o00001oooool5o`000003ooooool0003o000000?ooooo1?l00003ooooo`;o00000_oo
ool2o`000003ooooool0003o000000Co00002Oooool2o`0002gooooo0_l0001`ooooo`007?ooool0
0ol0003oooooooooo`1Qooooo`;o00007Oooool2o`0000Wooooo1?l000000ooooooo0000o`000002
o`0000Oooooo1?l00009ooooo`;o0000:_ooool2o`0007?ooooo000Looooo`03o`000?oooooooooo
067ooooo0_l0000Vooooo`Co00000oooool2o`0000Sooooo0ol0000gooooo`;o00006_ooool2o`00
05Oooooo000Looooo`03o`000?oooooooooo087ooooo0_l00006ooooo`;o00000_ooool2o`0000[o
oooo0ol0001Dooooo`;o0000Eoooool001cooooo00?o0000ooooooooool0POooool2o`0000[ooooo
0_l000000ooooooo0000o`000002ooooo`;o00000oooool2o`000:kooooo000Looooo`03o`000?oo
oooooooo06Cooooo0_l0000<ooooo`;o00001oooool2o`0001?ooooo0_l00002ooooo`;o00001?oo
ool2o`000:gooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<
c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Tooooo`;o00003?ooool3o`0000Ko
oooo0_l00004ooooo`;o00002oooool2o`000004ooooool0003o0000ooooo`;o00000_ooool4o`00
0:gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9So
oooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1Vooooo`;o00002oooool4o`0000Kooooo0_l0
0002ooooo`;o00002oooool2o`000003ooooool0003o000000?o00000_ooool2o`0004oooooo0_l0
001Nooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`1Vooooo`;o00003Oooool2o`0000Kooooo0_l0
0008ooooo`;o00002?ooool4o`0005?ooooo0ol0001Nooooo`0000?oooooo`000?ooool00_ooool0
0ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`0007oooooo0ol0
0005ooooo`;o00002Oooool3o`0000;ooooo0_l0001?ooooo`;o0000Goooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool02Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o
0000ooooooooool0Ooooool3o`0000gooooo0_l00004ooooo`Co0000=Oooool2o`0007Wooooo0000
0ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go410@okZj^_oooooo^[Zjoa0@
4006ooooo`03o`000?oooooooooo07oooooo0_l0000>ooooo`;o00001?ooool2o`000003ooooool0
003o000003;ooooo1?l0001iooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`00
0?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`1jooooo`;o00007?ooool2o`0003;o
oooo0_l0001kooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000
oa0@4?nYZJT01_ooool00ol0003oooooooooo`1jooooo`;o0000:oooool2o`0003Wooooo0_l0001U
ooooo`007?ooool00ol0003oooooooooo`2<ooooo`;o00006Oooool2o`0001oooooo0_l0000Hoooo
o`;o0000IOooool001cooooo00?o0000ooooooooool0S?ooool2o`00017ooooo0_l0000Wooooo`;o
0000Ooooool001cooooo00?o0000ooooooooool0Toooool2o`0000[ooooo0_l0002Xooooo`007?oo
ool00ol0003oooooooooo`20ooooo`;o00004Oooool2o`000;Cooooo000Looooo`03o`000?oooooo
oooo083ooooo0_l0000Booooo`Co0000/Oooool001cooooo00?o0000ooooooooool0P_ooool2o`00
013ooooo1?l0000/ooooo`;o0000Poooool001cooooo00?o0000ooooooooool0P_ooool2o`00043o
oooo0_l0000Cooooo`;o0000K_ooool001cooooo00?o0000ooooooooool0NOooool2o`00027ooooo
0_l0000jooooo`?o0000K_ooool001cooooo00?o0000ooooooooool0NOooool2o`00027ooooo0_l0
0007ooooo`;o00004_ooool4o`0001_ooooo0_l0001_ooooo`007?ooool00ol0003oooooooooo`1i
ooooo`;o00007Oooool2o`0000_ooooo0_l00002ooooo`;o00001?ooool2o`0000Sooooo1?l0002<
ooooo`007?ooool00ol0003oooooooooo`1looooo`;o00006_ooool2o`0000;ooooo0_l00004oooo
o`Co00000oooool2o`0000Cooooo0_l0002Hooooo`007?ooool2o`0007gooooo0_l0000Nooooo`;o
00001?ooool5o`000:;ooooo000Looooo`03o`000?oooooooooo0:Gooooo0_l0000:ooooo`;o0000
U_ooool001cooooo00?o0000ooooooooool0U?ooool3o`0001[ooooo0_l00002ooooo`Ko00000_oo
ool2o`0000Cooooo0_l00024ooooo`007?ooool00ol0003oooooooooo`2Dooooo`?o00007?ooool9
o`000004ooooool0003o0000o`0000?ooooo0_l00024ooooo`007?ooool00ol0003oooooooooo`2H
ooooo`;o00006Oooool2o`0000Gooooo0_l00002ooooo`;o00003?ooool2o`0007_ooooo000Loooo
o`03o`000?oooooooooo09Sooooo0_l0000`ooooo`Co0000Noooool001cooooo00?o0000oooooooo
ool0b_ooool2o`0007gooooo000Looooo`03o`000?oooooooooo0:Cooooo0_l0000;ooooo`;o0000
3Oooool2o`0008Oooooo000Looooo`03o`000?oooooooooo0:Cooooo0_l00004ooooo`Co00000ooo
ool2o`0000Wooooo0_l00002ooooo`;o0000Qoooool001cooooo00?o0000ooooooooool0Roooool2
o`0001gooooo1?l0000>ooooo`;o0000Roooool001cooooo00?o0000ooooooooool0Roooool2o`00
0;cooooo000Looooo`03o`000?oooooooooo08gooooo0_l0002jooooo`007?ooool00ol0003ooooo
ooooo`2=ooooo`;o0000^_ooool001cooooo00?o0000ooooooooool0TOooool2o`000;Kooooo000L
ooooo`03o`000?oooooooooo097ooooo0_l0002fooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo09kooooo0_l0002Yooooo`007?ooool00ol0003oooooooooo`2N
ooooo`;o0000ZOooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001;o
oooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oo
oooooooo00Gooooo0ol0003ooooood[ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool0
01Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;o
oooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001;ooooo00?oEEEEofIVI_l00000oooo
oomDooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00YOooool01?l@413o0000
o`000?ooool2o`000003oa0@4?oooooooooo01Oooooo0_l000000ol@413oooooooooo`02ooooo`Co
000000?o410@ooooooooool00_ooool2o`000003oa0@4?oooooooooo08kooooo002Vooooo`05o`00
0?ooooooooooooooool000002Oooool6o`0000cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo08oooooo002Vooooo`05o`000?ooooooooooooooool0
00006?ooool5o`0000Kooooo00?o0000ooooooooool00_ooool5o`00093ooooo002Vooooo`05o`00
0?ooooooooooooooool000002Oooool6o`0000Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0
003oooooooooo`02ooooo`04odA4A?oMgMgoooooo`00097ooooo002Vooooo`05o`000?n7QhOooooo
ojVYZOl000006?ooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo00;ooooo00Co
gMgMoeEEEOoooooo0000TOooool00:Gooooo00?o410@o`000?mgMgL00_l000000onHV9Sooooooooo
o`0Gooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool00oooool00omgMgOoc<c<o`00
002Aooooo`00a?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo00?ooooo00?ok^k^
odA4A?l00000TOooool00<Gooooo00?oMgMgo`000?ooool01?ooool00omEEEGoIVIVo`000006oooo
o`03ogMgMol0003ooooo093ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000
\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(420) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.37552 .44541 Mdot
.33608 .43401 Mdot
.56352 .69195 Mdot
.52286 .35103 Mdot
.75841 .52718 Mdot
.59291 .67238 Mdot
.40957 .70817 Mdot
.41302 .71044 Mdot
.60902 .67314 Mdot
.2959 .32999 Mdot
.39804 .67181 Mdot
.56148 .42427 Mdot
.40653 .69117 Mdot
.5382 .37135 Mdot
.44827 .46268 Mdot
.55896 .31916 Mdot
.3183 .42403 Mdot
.72832 .56944 Mdot
.57769 .3252 Mdot
.59268 .71814 Mdot
.60241 .25532 Mdot
.54762 .37863 Mdot
.33558 .47584 Mdot
.54148 .37206 Mdot
.5753 .35753 Mdot
.3293 .45002 Mdot
.37757 .45296 Mdot
.57371 .3657 Mdot
.54932 .4191 Mdot
.40188 .6747 Mdot
.57244 .61093 Mdot
.51064 .17428 Mdot
.49139 .36192 Mdot
.44749 .25916 Mdot
.40539 .71527 Mdot
.39466 .62365 Mdot
.59826 .71043 Mdot
.40586 .64872 Mdot
.40325 .71791 Mdot
.38849 .70922 Mdot
.38487 .692 Mdot
.3292 .45635 Mdot
.37837 .67985 Mdot
.49496 .8189 Mdot
.53309 .35663 Mdot
.42732 .43838 Mdot
.43748 .79949 Mdot
.57907 .38905 Mdot
.32336 .42717 Mdot
.58322 .71807 Mdot
.75216 .45575 Mdot
.42625 .6624 Mdot
.41431 .58486 Mdot
.68632 .83039 Mdot
.39679 .68722 Mdot
.5902 .34875 Mdot
.62376 .68533 Mdot
.52163 .39286 Mdot
.52018 .34873 Mdot
.43757 .23355 Mdot
.53988 .39861 Mdot
.71746 .54736 Mdot
.3007 .42351 Mdot
.63294 .67823 Mdot
.60516 .66811 Mdot
.40493 .64984 Mdot
.31674 .47545 Mdot
.41377 .684 Mdot
.53028 .42176 Mdot
.57126 .70539 Mdot
.55875 .41328 Mdot
.40259 .67089 Mdot
.35748 .47697 Mdot
.53733 .35305 Mdot
.31968 .65482 Mdot
.391 .76672 Mdot
.60857 .63965 Mdot
.53203 .22549 Mdot
.81232 .50302 Mdot
.56906 .58486 Mdot
.54746 .36099 Mdot
.71819 .7559 Mdot
.50421 .51702 Mdot
.34591 .42979 Mdot
.30608 .4971 Mdot
.27979 .51667 Mdot
.57834 .38165 Mdot
.53279 .60713 Mdot
.54227 .32909 Mdot
.66281 .55311 Mdot
.61906 .68938 Mdot
.35777 .43691 Mdot
.53837 .35582 Mdot
.50456 .40459 Mdot
.25333 .38305 Mdot
.59176 .39422 Mdot
.53115 .34632 Mdot
.2956 .49803 Mdot
.39791 .66573 Mdot
.54582 .29459 Mdot
.72873 .48455 Mdot
.39898 .54627 Mdot
.59068 .35577 Mdot
.60184 .69881 Mdot
.31733 .41001 Mdot
.54685 .34014 Mdot
.41888 .69485 Mdot
.5485 .36624 Mdot
.39141 .72428 Mdot
.30423 .44911 Mdot
.49315 .38364 Mdot
.74034 .55633 Mdot
.63376 .32192 Mdot
.33242 .47104 Mdot
.42312 .36129 Mdot
.54987 .39151 Mdot
.52158 .4004 Mdot
.3314 .43368 Mdot
.57918 .70698 Mdot
.61029 .76869 Mdot
.34636 .47676 Mdot
.38852 .71008 Mdot
.32562 .42094 Mdot
.60889 .40735 Mdot
.58691 .71194 Mdot
.41159 .55383 Mdot
.4087 .5477 Mdot
.68417 .42426 Mdot
.54452 .35435 Mdot
.64656 .35556 Mdot
.59787 .68906 Mdot
.32245 .44869 Mdot
.40665 .68086 Mdot
.5974 .35163 Mdot
.34311 .46546 Mdot
.41888 .70817 Mdot
.72662 .51867 Mdot
.75625 .56139 Mdot
.31427 .45101 Mdot
.41085 .40436 Mdot
.39211 .73274 Mdot
.38196 .69349 Mdot
.74761 .45445 Mdot
.3445 .42896 Mdot
.73514 .54531 Mdot
.42718 .69506 Mdot
.72231 .3286 Mdot
.51339 .3497 Mdot
.70833 .44719 Mdot
.66963 .77817 Mdot
.75198 .45603 Mdot
.49289 .19687 Mdot
.74078 .55278 Mdot
.42121 .70703 Mdot
.57215 .40414 Mdot
.34781 .45222 Mdot
.33817 .46278 Mdot
.52269 .41336 Mdot
.55651 .34601 Mdot
.52612 .36756 Mdot
.52819 .34069 Mdot
.47702 .6697 Mdot
.54099 .3583 Mdot
.21749 .61816 Mdot
.35098 .45998 Mdot
.56988 .3466 Mdot
.58124 .69806 Mdot
.50396 .32041 Mdot
.38806 .66129 Mdot
.51937 .35042 Mdot
.56341 .34952 Mdot
.60428 .38449 Mdot
.39203 .71571 Mdot
.3074 .66822 Mdot
.82729 .47958 Mdot
.38582 .63845 Mdot
.36928 .76357 Mdot
.58582 .68273 Mdot
.54622 .40195 Mdot
.73721 .53157 Mdot
.52932 .30248 Mdot
.50454 .36958 Mdot
.76105 .45931 Mdot
.55943 .35827 Mdot
.51586 .20364 Mdot
.50754 .42971 Mdot
.29907 .5278 Mdot
.20531 .56276 Mdot
.50599 .36255 Mdot
.3342 .32388 Mdot
.69536 .45516 Mdot
.64301 .64596 Mdot
.40253 .67878 Mdot
.56945 .68159 Mdot
.57113 .69881 Mdot
.41399 .64709 Mdot
.44607 .34811 Mdot
.31406 .31408 Mdot
.57214 .41076 Mdot
.40294 .54998 Mdot
.30087 .47764 Mdot
.73673 .55405 Mdot
.31437 .44779 Mdot
.75162 .72712 Mdot
.59407 .57428 Mdot
.5369 .59714 Mdot
.72321 .57394 Mdot
.59915 .72549 Mdot
.41018 .56001 Mdot
.73628 .53882 Mdot
.51508 .37177 Mdot
.30746 .44361 Mdot
.70823 .45251 Mdot
.52813 .30699 Mdot
.17368 .39034 Mdot
.37516 .4588 Mdot
.65707 .42275 Mdot
.39968 .68712 Mdot
.60435 .65226 Mdot
.57851 .38066 Mdot
.53098 .3861 Mdot
.30399 .46766 Mdot
.56463 .40664 Mdot
.52714 .57256 Mdot
.56067 .35101 Mdot
.63245 .67955 Mdot
.76567 .58376 Mdot
.38909 .64421 Mdot
.69742 .56702 Mdot
.35137 .47847 Mdot
.33179 .76616 Mdot
.59594 .70289 Mdot
.50917 .29808 Mdot
.41449 .67578 Mdot
.73193 .51924 Mdot
.6072 .70454 Mdot
.72681 .56487 Mdot
.49543 .38072 Mdot
.60585 .71106 Mdot
.72151 .55348 Mdot
.49818 .56956 Mdot
.54162 .34058 Mdot
.68969 .37292 Mdot
.43078 .67801 Mdot
.3512 .42529 Mdot
.50359 .38613 Mdot
.40929 .5861 Mdot
.61214 .37917 Mdot
.62863 .46361 Mdot
.40892 .58166 Mdot
.3898 .55223 Mdot
.54595 .56695 Mdot
.7059 .52515 Mdot
.34109 .68116 Mdot
.51332 .59706 Mdot
.31778 .42428 Mdot
.49892 .38917 Mdot
.36922 .58181 Mdot
.43264 .68509 Mdot
.51484 .37855 Mdot
.34414 .56044 Mdot
.42699 .69657 Mdot
.518 .39515 Mdot
.38615 .69368 Mdot
.34408 .46027 Mdot
.50436 .54029 Mdot
.34679 .41844 Mdot
.51534 .36129 Mdot
.3874 .68553 Mdot
.56979 .68738 Mdot
.33008 .45047 Mdot
.55016 .37095 Mdot
.56005 .36862 Mdot
.39884 .55181 Mdot
.544 .34577 Mdot
.32151 .52446 Mdot
.58026 .38494 Mdot
.5717 .71095 Mdot
.576 .40714 Mdot
.73759 .47749 Mdot
.6781 .51715 Mdot
.30334 .45883 Mdot
.40779 .58116 Mdot
.6208 .69796 Mdot
.49915 .54908 Mdot
.67243 .367 Mdot
.54251 .36273 Mdot
.40124 .57204 Mdot
.65551 .43821 Mdot
.3887 .6617 Mdot
.48548 .36347 Mdot
.5305 .69617 Mdot
.61749 .693 Mdot
.40656 .55301 Mdot
.55237 .30136 Mdot
.37058 .48043 Mdot
.59433 .36044 Mdot
.59938 .70881 Mdot
.35346 .42342 Mdot
.5979 .38251 Mdot
.4132 .77961 Mdot
.40911 .58699 Mdot
.39081 .66958 Mdot
.30568 .50729 Mdot
.53783 .40934 Mdot
.56628 .69006 Mdot
.33543 .46574 Mdot
.39558 .69718 Mdot
.33638 .47379 Mdot
.71024 .45865 Mdot
.63202 .44901 Mdot
.44524 .60454 Mdot
.69368 .54601 Mdot
.68371 .22295 Mdot
.37913 .64119 Mdot
.53853 .29671 Mdot
.55267 .64952 Mdot
.21592 .4597 Mdot
.60745 .70002 Mdot
.40744 .40602 Mdot
.62143 .68709 Mdot
.59099 .37321 Mdot
.59628 .66978 Mdot
.23223 .39693 Mdot
.56942 .36755 Mdot
.59742 .66218 Mdot
.49199 .65812 Mdot
.56709 .36795 Mdot
.34492 .4668 Mdot
.40503 .17815 Mdot
.47534 .27751 Mdot
.46766 .29674 Mdot
.62499 .68049 Mdot
.38406 .38946 Mdot
.57554 .36999 Mdot
.58566 .32971 Mdot
.34387 .44935 Mdot
.60231 .39419 Mdot
.69995 .5365 Mdot
.71795 .56386 Mdot
.74311 .39594 Mdot
.59175 .22365 Mdot
.44374 .3451 Mdot
.33433 .45578 Mdot
.82043 .52322 Mdot
.31604 .64932 Mdot
.40994 .58692 Mdot
.41505 .71017 Mdot
.3216 .68673 Mdot
.54612 .31254 Mdot
.27464 .4131 Mdot
.52369 .56785 Mdot
.36642 .44246 Mdot
.46444 .5906 Mdot
.39867 .70261 Mdot
.46838 .29251 Mdot
.32016 .2925 Mdot
.52433 .36751 Mdot
.41414 .65715 Mdot
.57299 .42265 Mdot
.5255 .60257 Mdot
.68878 .40527 Mdot
.48309 .76219 Mdot
.51785 .36018 Mdot
.33947 .6588 Mdot
.50414 .37406 Mdot
.68863 .42865 Mdot
.51256 .37693 Mdot
.34631 .47112 Mdot
.61095 .3573 Mdot
.50718 .59448 Mdot
.71936 .26632 Mdot
.59183 .56693 Mdot
.71283 .55489 Mdot
.53737 .3745 Mdot
.52295 .37764 Mdot
.71568 .54836 Mdot
.36265 .44097 Mdot
.50301 .39399 Mdot
.40735 .80832 Mdot
.54225 .35771 Mdot
.42555 .6594 Mdot
.59581 .50267 Mdot
.56369 .19613 Mdot
.56665 .39092 Mdot
.36635 .48253 Mdot
.3825 .6858 Mdot
.42305 .67992 Mdot
.48265 .43756 Mdot
.43021 .67344 Mdot
.56786 .40646 Mdot
.5943 .50317 Mdot
.31628 .46868 Mdot
.47098 .40882 Mdot
.36814 .44884 Mdot
.82183 .53626 Mdot
.42777 .69903 Mdot
.40078 .57757 Mdot
.43271 .36386 Mdot
.41267 .70157 Mdot
.69346 .58547 Mdot
.60877 .35401 Mdot
.48672 .34883 Mdot
.35438 .50978 Mdot
.56711 .68257 Mdot
.40763 .57251 Mdot
.39566 .68956 Mdot
.5379 .35857 Mdot
.58107 .34665 Mdot
.42555 .6643 Mdot
.40636 .21334 Mdot
.57505 .61095 Mdot
.51473 .36078 Mdot
.35652 .46518 Mdot
.32361 .45138 Mdot
.54731 .33231 Mdot
.50279 .37967 Mdot
.58111 .67075 Mdot
.40191 .57322 Mdot
.40679 .57826 Mdot
.40339 .54416 Mdot
.61906 .66412 Mdot
.69034 .23191 Mdot
.38153 .69159 Mdot
.5249 .17833 Mdot
.31788 .60427 Mdot
.53659 .44857 Mdot
.5804 .7035 Mdot
.5354 .3924 Mdot
.58807 .36311 Mdot
.38899 .6839 Mdot
.67724 .24609 Mdot
.59129 .33722 Mdot
.36738 .4362 Mdot
.42156 .65884 Mdot
.58117 .41518 Mdot
.39468 .73809 Mdot
.7515 .53814 Mdot
.44067 .33979 Mdot
.43084 .67225 Mdot
.3115 .46229 Mdot
.43065 .67144 Mdot
.52358 .37429 Mdot
.55266 .30057 Mdot
.36838 .44434 Mdot
.7616 .54714 Mdot
.51391 .40822 Mdot
.51448 .3932 Mdot
.66408 .7277 Mdot
.32219 .65426 Mdot
.68206 .5565 Mdot
.5858 .38303 Mdot
.4803 .35687 Mdot
.75609 .55536 Mdot
.52128 .40851 Mdot
.57914 .40402 Mdot
.64686 .34773 Mdot
.38609 .72172 Mdot
.71319 .51663 Mdot
.71139 .2646 Mdot
.37561 .45641 Mdot
.34479 .53165 Mdot
.40431 .54789 Mdot
.41709 .64034 Mdot
.49611 .53599 Mdot
.40526 .5597 Mdot
.32358 .58537 Mdot
.26972 .73126 Mdot
.40596 .57034 Mdot
.62513 .66503 Mdot
.30262 .37412 Mdot
.56343 .41283 Mdot
.50819 .37018 Mdot
.70515 .52797 Mdot
.33 .43036 Mdot
.21843 .60964 Mdot
.3961 .63585 Mdot
.54808 .38665 Mdot
.38026 .45525 Mdot
.28569 .52109 Mdot
.4048 .55439 Mdot
.74353 .53548 Mdot
.76185 .53535 Mdot
.50445 .3817 Mdot
.67073 .41221 Mdot
.33112 .4545 Mdot
.55008 .371 Mdot
.52532 .40423 Mdot
.6201 .70971 Mdot
.30879 .44228 Mdot
.58358 .69781 Mdot
.39662 .58221 Mdot
.19922 .44741 Mdot
.52566 .84878 Mdot
.43008 .68 Mdot
.44714 .52152 Mdot
.39165 .6431 Mdot
.4457 .76853 Mdot
.40282 .57442 Mdot
.54926 .37425 Mdot
.33803 .47958 Mdot
.54967 .36784 Mdot
.54075 .35681 Mdot
.52491 .35804 Mdot
.44423 .34308 Mdot
.80877 .51432 Mdot
.7258 .52516 Mdot
.55054 .40951 Mdot
.62738 .67985 Mdot
.32678 .53886 Mdot
.24531 .35232 Mdot
.53273 .37877 Mdot
.52056 .39971 Mdot
.32556 .48159 Mdot
.49579 .36785 Mdot
.41587 .70502 Mdot
.36334 .43644 Mdot
.58688 .34933 Mdot
.73916 .48669 Mdot
.50492 .39511 Mdot
.44852 .53645 Mdot
.43569 .69391 Mdot
.59738 .32109 Mdot
.48412 .39393 Mdot
.40295 .57579 Mdot
.40783 .57107 Mdot
.39572 .58781 Mdot
.41579 .65269 Mdot
.62027 .70798 Mdot
.63563 .67242 Mdot
.49005 .40026 Mdot
.5778 .39733 Mdot
.52907 .30832 Mdot
.57366 .71838 Mdot
.51403 .61323 Mdot
.41434 .41458 Mdot
.54156 .43236 Mdot
.60502 .65809 Mdot
.29845 .50129 Mdot
.56445 .23616 Mdot
.35737 .43119 Mdot
.54982 .66111 Mdot
.42073 .68522 Mdot
.73309 .56051 Mdot
.73687 .42324 Mdot
.34688 .47502 Mdot
.34841 .48341 Mdot
.58414 .67429 Mdot
.5649 .50367 Mdot
.75048 .78578 Mdot
.60294 .69256 Mdot
.53484 .59078 Mdot
.34006 .45117 Mdot
.49994 .35277 Mdot
.65146 .44955 Mdot
.54841 .50096 Mdot
.60549 .66368 Mdot
.55908 .36806 Mdot
.68271 .59518 Mdot
.58158 .67024 Mdot
.51013 .32542 Mdot
.62532 .6798 Mdot
.39792 .6619 Mdot
.59589 .69278 Mdot
.38031 .44048 Mdot
.54793 .35737 Mdot
.70447 .81823 Mdot
.49404 .51664 Mdot
.55626 .37684 Mdot
.43109 .67006 Mdot
.49689 .68529 Mdot
.51947 .3721 Mdot
.70273 .54949 Mdot
.62865 .67855 Mdot
.46481 .76471 Mdot
.59226 .38464 Mdot
.59336 .66755 Mdot
.38546 .46343 Mdot
.54817 .68307 Mdot
.71693 .48603 Mdot
.40758 .57565 Mdot
.34719 .45829 Mdot
.36561 .6496 Mdot
.38544 .70139 Mdot
.57452 .33219 Mdot
.53157 .40432 Mdot
.35553 .45897 Mdot
.49481 .55747 Mdot
.48338 .43345 Mdot
.54598 .36068 Mdot
.57884 .68313 Mdot
.61979 .7205 Mdot
.44865 .45746 Mdot
.59743 .70468 Mdot
.47891 .36003 Mdot
.35189 .46439 Mdot
.594 .35575 Mdot
.33058 .46685 Mdot
.49952 .39146 Mdot
.40871 .74803 Mdot
.34916 .42729 Mdot
.53934 .28791 Mdot
.54768 .35456 Mdot
.38624 .49483 Mdot
.54187 .40806 Mdot
.52197 .35543 Mdot
.62731 .71355 Mdot
.71926 .53676 Mdot
.48865 .36005 Mdot
.4012 .76431 Mdot
.75567 .54997 Mdot
.45185 .19859 Mdot
.58723 .71184 Mdot
.74932 .52386 Mdot
.72775 .38151 Mdot
.40823 .58067 Mdot
.71255 .53817 Mdot
.3926 .53135 Mdot
.42623 .66992 Mdot
.3621 .41502 Mdot
.56385 .36532 Mdot
.20685 .43593 Mdot
.56878 .61135 Mdot
.39711 .55579 Mdot
.50869 .39414 Mdot
.53078 .39206 Mdot
.37977 .4569 Mdot
.74163 .73616 Mdot
.63582 .70829 Mdot
.53473 .34263 Mdot
.35247 .47613 Mdot
.69688 .76758 Mdot
.59828 .66133 Mdot
.73141 .5231 Mdot
.41814 .71744 Mdot
.29526 .46398 Mdot
.40161 .57969 Mdot
.42599 .70166 Mdot
.5929 .63565 Mdot
.7664 .46146 Mdot
.59385 .37042 Mdot
.58104 .70112 Mdot
.75351 .45667 Mdot
.47303 .4115 Mdot
.40347 .64428 Mdot
.37108 .75062 Mdot
.35249 .43462 Mdot
.42492 .66325 Mdot
.70316 .53607 Mdot
.31101 .43285 Mdot
.36739 .44584 Mdot
.41936 .70172 Mdot
.19725 .53113 Mdot
.65363 .43991 Mdot
.43768 .66849 Mdot
.62787 .46817 Mdot
.75305 .45748 Mdot
.39389 .5656 Mdot
.74402 .53759 Mdot
.8083 .54743 Mdot
.32875 .45445 Mdot
.31997 .68424 Mdot
.75404 .45605 Mdot
.53124 .34616 Mdot
.72209 .55504 Mdot
.33733 .53802 Mdot
.42651 .63281 Mdot
.42201 .70364 Mdot
.64337 .73879 Mdot
.72483 .55915 Mdot
.49957 .36973 Mdot
.59683 .1952 Mdot
.56861 .3813 Mdot
.4289 .6916 Mdot
.52525 .56992 Mdot
.30793 .44696 Mdot
.38524 .66491 Mdot
.52766 .57279 Mdot
.58891 .36992 Mdot
.5541 .38975 Mdot
.7868 .55418 Mdot
.31515 .43282 Mdot
.39425 .5762 Mdot
.55396 .3662 Mdot
.51875 .39267 Mdot
.56721 .33095 Mdot
.6463 .25556 Mdot
.60476 .28571 Mdot
.56196 .33775 Mdot
.58624 .65195 Mdot
.53672 .30079 Mdot
.52366 .34426 Mdot
.3733 .47883 Mdot
.77005 .49535 Mdot
.39541 .58149 Mdot
.50823 .37294 Mdot
.51389 .36227 Mdot
.401 .71691 Mdot
.65426 .43999 Mdot
.54069 .50158 Mdot
.5863 .72207 Mdot
.64972 .71198 Mdot
.53206 .42581 Mdot
.35299 .45288 Mdot
.7014 .52383 Mdot
.47088 .39205 Mdot
.37059 .44101 Mdot
.51437 .41622 Mdot
.62986 .69061 Mdot
.40312 .5693 Mdot
.4683 .4102 Mdot
.72092 .54717 Mdot
.38814 .7283 Mdot
.4779 .20116 Mdot
.57166 .68615 Mdot
.57983 .36695 Mdot
.64184 .68619 Mdot
.60776 .68258 Mdot
.39706 .55221 Mdot
.56943 .29866 Mdot
.34066 .46022 Mdot
.31209 .46068 Mdot
.7898 .49782 Mdot
.62192 .66551 Mdot
.67362 .69885 Mdot
.40421 .65829 Mdot
.54549 .41083 Mdot
.38005 .57547 Mdot
.31033 .45613 Mdot
.68545 .42326 Mdot
.75708 .52941 Mdot
.42328 .70135 Mdot
.40565 .5393 Mdot
.35206 .42721 Mdot
.31326 .4574 Mdot
.53729 .35621 Mdot
.54099 .38172 Mdot
.622 .63847 Mdot
.69859 .4511 Mdot
.38737 .69674 Mdot
.74348 .52825 Mdot
.57092 .70808 Mdot
.58715 .38814 Mdot
.34679 .43178 Mdot
.57352 .1981 Mdot
.53844 .4088 Mdot
.62727 .68041 Mdot
.33674 .43583 Mdot
.72223 .52301 Mdot
.70738 .5309 Mdot
.52601 .35083 Mdot
.5279 .20859 Mdot
.41435 .69888 Mdot
.34542 .46829 Mdot
.32666 .50781 Mdot
.56 .40582 Mdot
.5368 .37838 Mdot
.57792 .43088 Mdot
.39183 .65217 Mdot
.48192 .41874 Mdot
.74485 .56333 Mdot
.3194 .45306 Mdot
.55457 .37086 Mdot
.71648 .54658 Mdot
.27608 .4112 Mdot
.4027 .56134 Mdot
.5921 .66332 Mdot
.70671 .55415 Mdot
.72924 .54108 Mdot
.75743 .54196 Mdot
.32259 .68614 Mdot
.33679 .40292 Mdot
.81035 .40021 Mdot
.55492 .36201 Mdot
.75297 .45784 Mdot
.55512 .32731 Mdot
.3944 .65848 Mdot
.56994 .67311 Mdot
.53141 .3597 Mdot
.55558 .36233 Mdot
.49875 .20861 Mdot
.56601 .31995 Mdot
.57418 .3215 Mdot
.30609 .45192 Mdot
.34559 .51497 Mdot
.56852 .69288 Mdot
.65462 .78474 Mdot
.4321 .15264 Mdot
.5696 .4127 Mdot
.57007 .50344 Mdot
.35731 .43296 Mdot
.40693 .71856 Mdot
.63554 .46356 Mdot
.40598 .61016 Mdot
.32165 .43914 Mdot
.59045 .37676 Mdot
.47586 .20677 Mdot
.73968 .56078 Mdot
.52595 .36984 Mdot
.40959 .67952 Mdot
.52597 .36874 Mdot
.4102 .65117 Mdot
.40671 .42201 Mdot
.52243 .50768 Mdot
.56272 .36136 Mdot
.58976 .39602 Mdot
.6432 .35814 Mdot
.53554 .38041 Mdot
.49295 .74657 Mdot
.34103 .43979 Mdot
.52584 .29072 Mdot
.58847 .34282 Mdot
.46615 .27214 Mdot
.52005 .40485 Mdot
.47956 .53063 Mdot
.54623 .39898 Mdot
.68894 .26783 Mdot
.5032 .36114 Mdot
.5475 .40077 Mdot
.39324 .69879 Mdot
.39235 .71336 Mdot
.37666 .48448 Mdot
.39066 .56499 Mdot
.30752 .53115 Mdot
.51614 .39616 Mdot
.60726 .7272 Mdot
.52545 .47662 Mdot
.72436 .53757 Mdot
.3197 .45072 Mdot
.42408 .87838 Mdot
.38305 .67886 Mdot
.62281 .66355 Mdot
.53818 .60423 Mdot
.58611 .64898 Mdot
.55626 .64722 Mdot
.36657 .51126 Mdot
.7459 .5385 Mdot
.50304 .39074 Mdot
.45673 .25833 Mdot
.33347 .6525 Mdot
.56374 .40387 Mdot
.63086 .72896 Mdot
.59781 .45176 Mdot
.78965 .49032 Mdot
.71196 .5632 Mdot
.74172 .5477 Mdot
.39707 .69655 Mdot
.56499 .69381 Mdot
.54746 .43256 Mdot
.74818 .52329 Mdot
.57053 .67607 Mdot
.41519 .55363 Mdot
.78859 .5367 Mdot
.33188 .45735 Mdot
.39293 .39193 Mdot
.41841 .47246 Mdot
.38334 .68369 Mdot
.3962 .76584 Mdot
.38092 .41911 Mdot
.32077 .41914 Mdot
.39135 .55234 Mdot
.60817 .66141 Mdot
.36642 .41612 Mdot
.54511 .35639 Mdot
.52748 .30736 Mdot
.504 .38148 Mdot
.70735 .5254 Mdot
.51387 .39982 Mdot
.58039 .66822 Mdot
.40223 .71064 Mdot
.61946 .69356 Mdot
.40806 .7081 Mdot
.46067 .17184 Mdot
.51518 .35307 Mdot
.53948 .37691 Mdot
.58998 .50358 Mdot
.31361 .45464 Mdot
.43951 .26382 Mdot
.62661 .67779 Mdot
.62353 .6886 Mdot
.59231 .35305 Mdot
.29958 .4549 Mdot
.69043 .57952 Mdot
.62971 .47616 Mdot
.54097 .40063 Mdot
.34242 .43938 Mdot
.59263 .35212 Mdot
.44952 .7542 Mdot
.48703 .50221 Mdot
.3334 .47346 Mdot
.7211 .26682 Mdot
.53998 .34974 Mdot
.58873 .30454 Mdot
.61658 .33258 Mdot
.64291 .26289 Mdot
.49815 .34962 Mdot
.37477 .45555 Mdot
.52656 .34379 Mdot
.35264 .44727 Mdot
.60986 .68961 Mdot
.38001 .67717 Mdot
.34891 .44803 Mdot
.56793 .3741 Mdot
.44007 .15277 Mdot
.40208 .71182 Mdot
.53179 .36678 Mdot
.39457 .67909 Mdot
.35298 .4148 Mdot
.31758 .43603 Mdot
.40128 .53588 Mdot
.53601 .59298 Mdot
.41617 .70315 Mdot
.57639 .39834 Mdot
.3126 .66336 Mdot
.59426 .35715 Mdot
.64888 .71477 Mdot
.60335 .38047 Mdot
.52866 .4237 Mdot
.68491 .21976 Mdot
.49244 .54959 Mdot
.55603 .85077 Mdot
.45746 .65792 Mdot
.30603 .66347 Mdot
.34403 .50328 Mdot
.71223 .56317 Mdot
.46051 .54349 Mdot
.41146 .57956 Mdot
.58069 .65234 Mdot
.53485 .35843 Mdot
.25116 .4448 Mdot
.43413 .66434 Mdot
.7199 .53155 Mdot
.55995 .35855 Mdot
.5607 .66009 Mdot
.42922 .48225 Mdot
.42269 .70415 Mdot
.32903 .4572 Mdot
.31511 .44451 Mdot
.81284 .49529 Mdot
.55492 .37416 Mdot
.54517 .3796 Mdot
.40315 .71386 Mdot
.54299 .43628 Mdot
.75558 .53945 Mdot
.49336 .65568 Mdot
.40812 .6775 Mdot
.4932 .50767 Mdot
.30562 .44484 Mdot
.53279 .39227 Mdot
.59783 .5015 Mdot
.27503 .6538 Mdot
.26993 .3478 Mdot
.7334 .55237 Mdot
.67152 .39337 Mdot
.37486 .45655 Mdot
.40471 .68053 Mdot
.73477 .39074 Mdot
.6017 .34678 Mdot
.5278 .3927 Mdot
.66785 .32019 Mdot
.62938 .47453 Mdot
.53415 .60048 Mdot
.58741 .4283 Mdot
.65983 .4567 Mdot
.59268 .35435 Mdot
.58207 .34754 Mdot
.52316 .42256 Mdot
.60603 .37278 Mdot
.34732 .43975 Mdot
.46606 .28564 Mdot
.59179 .67933 Mdot
.29779 .34869 Mdot
.65395 .71526 Mdot
.57479 .37185 Mdot
.58991 .37188 Mdot
.36743 .33987 Mdot
.594 .47604 Mdot
.33594 .4456 Mdot
.3377 .5089 Mdot
.38389 .7001 Mdot
.57528 .32339 Mdot
.6255 .67069 Mdot
.61971 .34797 Mdot
.60657 .6746 Mdot
.34554 .43825 Mdot
.60975 .71591 Mdot
.42856 .71726 Mdot
.582 .70174 Mdot
.59889 .65514 Mdot
.42061 .71082 Mdot
.32418 .42546 Mdot
.54176 .40472 Mdot
.4248 .70845 Mdot
.69761 .58426 Mdot
.7072 .52588 Mdot
.40409 .53538 Mdot
.50648 .3472 Mdot
.56369 .3131 Mdot
.40919 .78321 Mdot
.60609 .71273 Mdot
.53382 .49619 Mdot
.34743 .42715 Mdot
.70252 .52405 Mdot
.35077 .44143 Mdot
.80316 .44596 Mdot
.72767 .5489 Mdot
.40035 .53382 Mdot
.71236 .39333 Mdot
.38457 .64524 Mdot
.60039 .39113 Mdot
.33721 .51238 Mdot
.61019 .67826 Mdot
.42387 .65869 Mdot
.33602 .53944 Mdot
.54507 .34323 Mdot
.41338 .59339 Mdot
.34116 .41152 Mdot
.40852 .57932 Mdot
.40801 .68148 Mdot
.41397 .51334 Mdot
.5549 .38061 Mdot
.38443 .64621 Mdot
.59282 .39415 Mdot
.41646 .38608 Mdot
.64458 .66465 Mdot
.27555 .45563 Mdot
.59219 .36761 Mdot
.59725 .66062 Mdot
.59276 .36169 Mdot
.32478 .37735 Mdot
.70846 .42078 Mdot
.53381 .42652 Mdot
.61614 .45243 Mdot
.42894 .78906 Mdot
.34834 .43278 Mdot
.47684 .37524 Mdot
.39468 .5599 Mdot
.58253 .3633 Mdot
.22138 .29371 Mdot
.71462 .54091 Mdot
.72148 .57678 Mdot
.5661 .37072 Mdot
.55023 .36538 Mdot
.5087 .21065 Mdot
.40289 .45027 Mdot
.40339 .53857 Mdot
.52285 .38878 Mdot
.65474 .29524 Mdot
.39348 .69581 Mdot
.5994 .37914 Mdot
.50979 .36337 Mdot
.65834 .6613 Mdot
.39185 .68848 Mdot
.58935 .71051 Mdot
.40901 .58055 Mdot
.60938 .72338 Mdot
.76261 .52835 Mdot
.66347 .41402 Mdot
.68177 .3932 Mdot
.47111 .48825 Mdot
.70664 .55252 Mdot
.57512 .37821 Mdot
.28167 .46611 Mdot
.56065 .37919 Mdot
.74126 .54333 Mdot
.40169 .6746 Mdot
.34378 .4423 Mdot
.40768 .40247 Mdot
.39977 .5493 Mdot
.56543 .39786 Mdot
.69849 .55154 Mdot
.34611 .45314 Mdot
.25182 .65694 Mdot
.33489 .43001 Mdot
.40749 .70575 Mdot
.41342 .64728 Mdot
.72511 .54287 Mdot
.35073 .44024 Mdot
.6114 .72169 Mdot
.45831 .67509 Mdot
.58598 .40661 Mdot
.42843 .71821 Mdot
.38581 .43313 Mdot
.37643 .4665 Mdot
.31769 .47305 Mdot
.58751 .34391 Mdot
.60132 .48357 Mdot
.61734 .39576 Mdot
.40181 .71244 Mdot
.5665 .65829 Mdot
.70644 .44499 Mdot
.48252 .23944 Mdot
.50834 .51274 Mdot
.49327 .3498 Mdot
.51237 .3983 Mdot
.50473 .38312 Mdot
.56088 .33578 Mdot
.48381 .64355 Mdot
.5151 .35331 Mdot
.38738 .68915 Mdot
.60138 .67761 Mdot
.53709 .39975 Mdot
.39685 .56708 Mdot
.51552 .61087 Mdot
.7063 .51737 Mdot
.43918 .33841 Mdot
.36594 .52121 Mdot
.3456 .45128 Mdot
.59559 .7067 Mdot
.61038 .71728 Mdot
.72654 .51871 Mdot
.42878 .70005 Mdot
.32675 .43157 Mdot
.69177 .27196 Mdot
.75023 .55471 Mdot
.50831 .37403 Mdot
.59291 .50316 Mdot
.62705 .24787 Mdot
.52523 .4158 Mdot
.52165 .35978 Mdot
.39249 .57514 Mdot
.61462 .65741 Mdot
.21374 .37951 Mdot
.20031 .55115 Mdot
.72023 .53888 Mdot
.74477 .52615 Mdot
.32971 .48084 Mdot
.54202 .41267 Mdot
.41554 .69613 Mdot
.65899 .43336 Mdot
.41904 .77107 Mdot
.28381 .51493 Mdot
.44835 .76732 Mdot
.50664 .39723 Mdot
.41787 .34086 Mdot
.60377 .38337 Mdot
.31864 .40941 Mdot
.30798 .46627 Mdot
.33453 .45164 Mdot
.39626 .70146 Mdot
.76968 .46251 Mdot
.38667 .68355 Mdot
.32366 .5193 Mdot
.36851 .46563 Mdot
.50731 .56301 Mdot
.62447 .68646 Mdot
.55706 .32254 Mdot
.74542 .54014 Mdot
.66696 .52071 Mdot
.47835 .37023 Mdot
.66971 .40046 Mdot
.5808 .70382 Mdot
.34107 .42183 Mdot
.55729 .32562 Mdot
.31663 .53721 Mdot
.56017 .50599 Mdot
.44671 .79147 Mdot
.25555 .44606 Mdot
.71805 .54989 Mdot
.31088 .32468 Mdot
.75312 .54784 Mdot
.42444 .69984 Mdot
.53702 .3494 Mdot
.53648 .41154 Mdot
.51991 .35625 Mdot
.60031 .35707 Mdot
.3954 .68734 Mdot
.57658 .41386 Mdot
.7388 .47751 Mdot
.41633 .55884 Mdot
.49946 .60862 Mdot
.70832 .53314 Mdot
.40152 .65756 Mdot
.6053 .6807 Mdot
.39152 .54838 Mdot
.69312 .54616 Mdot
.55713 .33072 Mdot
.56578 .3768 Mdot
.41219 .55071 Mdot
.47241 .41783 Mdot
.54332 .31462 Mdot
.5907 .67332 Mdot
.52117 .60112 Mdot
.72249 .51566 Mdot
.74072 .5548 Mdot
.42008 .66086 Mdot
.35116 .44132 Mdot
.72917 .51696 Mdot
.56177 .6875 Mdot
.59723 .37933 Mdot
.58548 .40086 Mdot
.38717 .43873 Mdot
.75808 .45805 Mdot
.70498 .51771 Mdot
.48047 .41717 Mdot
.32217 .46054 Mdot
.33961 .41123 Mdot
.52291 .38739 Mdot
.53283 .42956 Mdot
.32984 .48425 Mdot
.73017 .52026 Mdot
.41311 .65787 Mdot
.52553 .53974 Mdot
.3878 .67173 Mdot
.33345 .46437 Mdot
.5285 .30536 Mdot
.31713 .42953 Mdot
.54804 .34351 Mdot
.57141 .86587 Mdot
.50697 .35978 Mdot
.53139 .27188 Mdot
.63615 .58944 Mdot
.6245 .67736 Mdot
.6179 .66829 Mdot
.40164 .57001 Mdot
.36897 .43952 Mdot
.4737 .37505 Mdot
.74795 .53698 Mdot
.30661 .66324 Mdot
.39662 .43339 Mdot
.60057 .65607 Mdot
.62657 .66897 Mdot
.39996 .67613 Mdot
.51714 .40314 Mdot
.53566 .39362 Mdot
.58351 .70355 Mdot
.49954 .67843 Mdot
.35859 .44654 Mdot
.5452 .37918 Mdot
.56697 .33475 Mdot
.59427 .67936 Mdot
.43465 .65381 Mdot
.37515 .41737 Mdot
.58571 .34233 Mdot
.70094 .42242 Mdot
.39884 .65344 Mdot
.58082 .3767 Mdot
.60604 .38338 Mdot
.72898 .53699 Mdot
.67334 .37329 Mdot
.74766 .45472 Mdot
.38381 .70713 Mdot
.40423 .57925 Mdot
.51955 .41178 Mdot
.62255 .67618 Mdot
.51628 .34034 Mdot
.17652 .61468 Mdot
.41721 .5666 Mdot
.55244 .38261 Mdot
.51395 .42498 Mdot
.3319 .46835 Mdot
.5509 .37349 Mdot
.40682 .7482 Mdot
.58191 .68992 Mdot
.55259 .38367 Mdot
.52691 .21093 Mdot
.40134 .67625 Mdot
.47886 .37053 Mdot
.72825 .56048 Mdot
.53147 .59114 Mdot
.41124 .17718 Mdot
.56892 .71347 Mdot
.70759 .54072 Mdot
.51846 .40238 Mdot
.59383 .72503 Mdot
.41584 .71856 Mdot
.58774 .2785 Mdot
.57609 .38041 Mdot
.38612 .67709 Mdot
.40609 .71117 Mdot
.72112 .54294 Mdot
.51234 .87841 Mdot
.52883 .42582 Mdot
.52923 .3733 Mdot
.35386 .79166 Mdot
.3361 .48688 Mdot
.52981 .36602 Mdot
.52703 .4052 Mdot
.43059 .67714 Mdot
.78315 .42352 Mdot
.67108 .39394 Mdot
.49054 .65633 Mdot
.40398 .65187 Mdot
.63137 .72222 Mdot
.57714 .68971 Mdot
.70918 .54372 Mdot
.33571 .43535 Mdot
.70635 .52259 Mdot
.59258 .68927 Mdot
.51998 .35822 Mdot
.4202 .67064 Mdot
.34059 .24659 Mdot
.43638 .68795 Mdot
.55876 .68093 Mdot
.32852 .4084 Mdot
.23951 .3975 Mdot
.19409 .65724 Mdot
.42838 .44966 Mdot
.38948 .65068 Mdot
.7245 .53738 Mdot
.20617 .58425 Mdot
.53797 .40024 Mdot
.38196 .37664 Mdot
.52706 .37102 Mdot
.25894 .42729 Mdot
.57026 .67354 Mdot
.40972 .54514 Mdot
.54529 .34301 Mdot
.6709 .38889 Mdot
.41991 .71001 Mdot
.41925 .68717 Mdot
.52886 .34341 Mdot
.40957 .70528 Mdot
.54166 .39087 Mdot
.59975 .68086 Mdot
.53847 .865 Mdot
.55364 .3953 Mdot
.56505 .29194 Mdot
.38204 .65519 Mdot
.40768 .53651 Mdot
.64077 .7024 Mdot
.44863 .30014 Mdot
.28659 .52495 Mdot
.41344 .6966 Mdot
.44453 .33918 Mdot
.60577 .70993 Mdot
.38983 .55174 Mdot
.6249 .72217 Mdot
.5267 .38052 Mdot
.5096 .40066 Mdot
.55748 .33666 Mdot
.5222 .40287 Mdot
.35341 .36955 Mdot
.54095 .31813 Mdot
.36028 .27615 Mdot
.5552 .36256 Mdot
.51895 .27663 Mdot
.38826 .6818 Mdot
.59378 .30769 Mdot
.54817 .55939 Mdot
.49802 .37927 Mdot
.35572 .51096 Mdot
.40034 .65908 Mdot
.37525 .60148 Mdot
.39382 .68859 Mdot
.62005 .69086 Mdot
.41603 .71016 Mdot
.54205 .34774 Mdot
.32455 .45113 Mdot
.59681 .70103 Mdot
.43372 .42552 Mdot
.56929 .65895 Mdot
.55617 .37691 Mdot
.37575 .65007 Mdot
.62661 .69831 Mdot
.57667 .3189 Mdot
.32368 .44746 Mdot
.6714 .29791 Mdot
.29546 .42518 Mdot
.546 .36909 Mdot
.54044 .36595 Mdot
.40711 .54344 Mdot
.42099 .70719 Mdot
.30253 .4491 Mdot
.65893 .65206 Mdot
.69461 .53507 Mdot
.33427 .44147 Mdot
.61379 .32552 Mdot
.57229 .50445 Mdot
.33296 .47147 Mdot
.64521 .27611 Mdot
.42852 .69396 Mdot
.36156 .47419 Mdot
.6122 .38941 Mdot
.30621 .34712 Mdot
.74474 .55449 Mdot
.61919 .71923 Mdot
.65274 .46809 Mdot
.57827 .68957 Mdot
.38707 .73223 Mdot
.63327 .68295 Mdot
.39 .68978 Mdot
.55446 .47435 Mdot
.52611 .57144 Mdot
.43463 .67268 Mdot
.37617 .66819 Mdot
.58627 .67898 Mdot
.5371 .33949 Mdot
.50837 .5964 Mdot
.47227 .3762 Mdot
.51596 .31544 Mdot
.38589 .67188 Mdot
.37198 .46564 Mdot
.31659 .42723 Mdot
.50592 .30201 Mdot
.31098 .44866 Mdot
.60412 .69683 Mdot
.45909 .47339 Mdot
.43231 .36556 Mdot
.40508 .67241 Mdot
.53659 .60818 Mdot
.59112 .3647 Mdot
.58896 .66649 Mdot
.60771 .69621 Mdot
.40435 .70971 Mdot
.28611 .36109 Mdot
.49074 .34298 Mdot
.35986 .48774 Mdot
.356 .47475 Mdot
.33599 .47212 Mdot
.30138 .45901 Mdot
.77234 .46138 Mdot
.42367 .65869 Mdot
.37174 .44522 Mdot
.59815 .35581 Mdot
.52993 .41107 Mdot
.41152 .5674 Mdot
.72245 .52192 Mdot
.60023 .34652 Mdot
.47322 .37668 Mdot
.52441 .38825 Mdot
.62557 .68018 Mdot
.63663 .41207 Mdot
.41592 .56034 Mdot
.62203 .66495 Mdot
.62267 .66731 Mdot
.40337 .57657 Mdot
.567 .47059 Mdot
.22218 .37703 Mdot
.53164 .34443 Mdot
.36747 .51307 Mdot
.6151 .66792 Mdot
.66275 .50797 Mdot
.4856 .30169 Mdot
.56944 .40481 Mdot
.50248 .63601 Mdot
.60341 .68689 Mdot
.34106 .50135 Mdot
.5309 .38034 Mdot
.39231 .55256 Mdot
.73702 .55887 Mdot
.62911 .33496 Mdot
.3919 .57292 Mdot
.35331 .43817 Mdot
.65885 .7273 Mdot
.38016 .4562 Mdot
.62456 .70822 Mdot
.4774 .37038 Mdot
.72947 .80155 Mdot
.61209 .6809 Mdot
.3092 .67612 Mdot
.5264 .57343 Mdot
.55547 .39087 Mdot
.58704 .70009 Mdot
.39047 .4556 Mdot
.39758 .65362 Mdot
.60263 .49049 Mdot
.34568 .43186 Mdot
.39203 .54709 Mdot
.40941 .56732 Mdot
.59225 .67856 Mdot
.35407 .47201 Mdot
.59407 .39806 Mdot
.31683 .44306 Mdot
.41952 .67508 Mdot
.56412 .34929 Mdot
.30583 .53057 Mdot
.56752 .29797 Mdot
.31659 .44808 Mdot
.56024 .6667 Mdot
.76034 .5497 Mdot
.57035 .37115 Mdot
.36501 .58051 Mdot
.52015 .40411 Mdot
.39628 .67701 Mdot
.63363 .55971 Mdot
.34439 .24765 Mdot
.51196 .37461 Mdot
.59038 .36639 Mdot
.42515 .71815 Mdot
.51308 .37528 Mdot
.54196 .42078 Mdot
.41282 .51178 Mdot
.33073 .47009 Mdot
.53312 .3995 Mdot
.57311 .68209 Mdot
.40978 .20232 Mdot
.53387 .35177 Mdot
.40948 .75019 Mdot
.66516 .30052 Mdot
.61547 .53648 Mdot
.49007 .33627 Mdot
.68506 .42516 Mdot
.53706 .36815 Mdot
.56383 .40716 Mdot
.53077 .34397 Mdot
.41451 .34848 Mdot
.58837 .68538 Mdot
.58912 .65933 Mdot
.72404 .56339 Mdot
.66461 .30609 Mdot
.72751 .55422 Mdot
.42923 .71116 Mdot
.53747 .60153 Mdot
.40858 .54894 Mdot
.352 .44295 Mdot
.53134 .35319 Mdot
.56844 .66238 Mdot
.53253 .39004 Mdot
.58297 .36581 Mdot
.60045 .69382 Mdot
.60799 .69135 Mdot
.5649 .71063 Mdot
.74138 .56078 Mdot
.33967 .44784 Mdot
.53123 .34764 Mdot
.75529 .55069 Mdot
.56467 .33299 Mdot
.52554 .5272 Mdot
.33751 .44792 Mdot
.31551 .44859 Mdot
.33638 .41634 Mdot
.5625 .3909 Mdot
.54914 .3458 Mdot
.38657 .68299 Mdot
.3869 .43787 Mdot
.41901 .69946 Mdot
.58537 .69877 Mdot
.58439 .66937 Mdot
.52616 .37982 Mdot
.52744 .43415 Mdot
.71058 .52893 Mdot
.61538 .7092 Mdot
.40633 .58706 Mdot
.72492 .56233 Mdot
.50309 .38381 Mdot
.58082 .69419 Mdot
.70003 .53887 Mdot
.25956 .36175 Mdot
.25019 .50389 Mdot
.73456 .56534 Mdot
.53041 .34233 Mdot
.48556 .23152 Mdot
.70944 .42884 Mdot
.69553 .52421 Mdot
.39414 .67431 Mdot
.53469 .40633 Mdot
.47773 .6688 Mdot
.75117 .52357 Mdot
.74302 .45053 Mdot
.59665 .69542 Mdot
.53735 .29772 Mdot
.63505 .36646 Mdot
.43081 .37699 Mdot
.76306 .54243 Mdot
.31784 .44952 Mdot
.33998 .47866 Mdot
.50948 .37318 Mdot
.53501 .59669 Mdot
.43502 .70159 Mdot
.60964 .7176 Mdot
.58246 .65783 Mdot
.32974 .47432 Mdot
.47562 .49268 Mdot
.5737 .685 Mdot
.54692 .41138 Mdot
.75197 .51622 Mdot
.5797 .32557 Mdot
.80182 .48143 Mdot
.3895 .1974 Mdot
.49991 .32496 Mdot
.75668 .55504 Mdot
.41496 .71667 Mdot
.39645 .70521 Mdot
.40132 .70424 Mdot
.58207 .67319 Mdot
.6392 .46325 Mdot
.57451 .66298 Mdot
.31338 .7421 Mdot
.71393 .54376 Mdot
.70457 .30413 Mdot
.60643 .36078 Mdot
.55649 .38886 Mdot
.59439 .37684 Mdot
.5654 .33772 Mdot
.53769 .36957 Mdot
.38368 .68634 Mdot
.5995 .72351 Mdot
.43036 .77051 Mdot
.35766 .46355 Mdot
.24698 .65303 Mdot
.62463 .68866 Mdot
.39475 .57977 Mdot
.72756 .5263 Mdot
.6765 .34829 Mdot
.77068 .53002 Mdot
.61704 .711 Mdot
.51489 .41435 Mdot
.33566 .48295 Mdot
.68559 .26243 Mdot
.5463 .3607 Mdot
.61139 .71208 Mdot
.62329 .72888 Mdot
.28567 .35271 Mdot
.55969 .44227 Mdot
.52829 .64395 Mdot
.57404 .50083 Mdot
.73405 .56737 Mdot
.48813 .36569 Mdot
.66866 .4206 Mdot
.59239 .68714 Mdot
.61047 .67154 Mdot
.69379 .52939 Mdot
.33554 .3888 Mdot
.37138 .4523 Mdot
.41563 .55065 Mdot
.39773 .66628 Mdot
.56294 .38141 Mdot
.58054 .67959 Mdot
.29327 .47609 Mdot
.55862 .52441 Mdot
.39895 .68994 Mdot
.62611 .669 Mdot
.52319 .40592 Mdot
.51066 .37882 Mdot
.72408 .55181 Mdot
.61932 .60436 Mdot
.47242 .37578 Mdot
.30739 .66528 Mdot
.51647 .50188 Mdot
.52835 .57563 Mdot
.52817 .39302 Mdot
.30836 .44206 Mdot
.40266 .5749 Mdot
.74293 .53638 Mdot
.53308 .3361 Mdot
.22344 .41785 Mdot
.37464 .43883 Mdot
.41677 .70087 Mdot
.39713 .57417 Mdot
.65633 .42257 Mdot
.52188 .4044 Mdot
.52707 .37157 Mdot
.58844 .3446 Mdot
.21986 .40076 Mdot
.57394 .66907 Mdot
.30318 .4545 Mdot
.72203 .55671 Mdot
.32079 .43365 Mdot
.63179 .68795 Mdot
.53182 .60753 Mdot
.51749 .34992 Mdot
.36069 .42723 Mdot
.32309 .43551 Mdot
.40252 .67525 Mdot
.42488 .70884 Mdot
.57149 .71298 Mdot
.52825 .40334 Mdot
.40623 .54618 Mdot
.37374 .45581 Mdot
.60084 .71962 Mdot
.72489 .5511 Mdot
.39829 .74154 Mdot
.55758 .36437 Mdot
.5909 .681 Mdot
.47458 .37701 Mdot
.34959 .46234 Mdot
.62283 .70107 Mdot
.38864 .55889 Mdot
.72928 .52095 Mdot
.51359 .40549 Mdot
.44848 .77872 Mdot
.39141 .55872 Mdot
.56879 .37944 Mdot
.37453 .20802 Mdot
.53444 .59665 Mdot
.31673 .39741 Mdot
.56906 .68563 Mdot
.39747 .54664 Mdot
.30657 .46296 Mdot
.32147 .33529 Mdot
.60496 .66932 Mdot
.48473 .20952 Mdot
.51456 .55578 Mdot
.53562 .34279 Mdot
.34975 .4347 Mdot
.78478 .54997 Mdot
.29618 .64376 Mdot
.70702 .43613 Mdot
.54725 .38526 Mdot
.57799 .68867 Mdot
.73756 .55783 Mdot
.42009 .68832 Mdot
.42551 .73926 Mdot
.81611 .47567 Mdot
.60673 .6558 Mdot
.52963 .35294 Mdot
.37023 .46735 Mdot
.41406 .70364 Mdot
.4829 .20184 Mdot
.56434 .69355 Mdot
.57292 .69064 Mdot
.59017 .39091 Mdot
.72998 .55519 Mdot
.47044 .6543 Mdot
.58077 .6642 Mdot
.60066 .72487 Mdot
.41313 .50142 Mdot
.7219 .5647 Mdot
.58326 .34203 Mdot
.50605 .30176 Mdot
.60374 .37687 Mdot
.28428 .68717 Mdot
.39924 .54586 Mdot
.35948 .46128 Mdot
.53105 .36139 Mdot
.42456 .79038 Mdot
.60421 .67411 Mdot
.57168 .50058 Mdot
.42884 .64832 Mdot
.42551 .70734 Mdot
.58355 .69047 Mdot
.53612 .38593 Mdot
.44179 .70003 Mdot
.70972 .53949 Mdot
.58212 .34028 Mdot
.54909 .34423 Mdot
.38921 .44162 Mdot
.4185 .67087 Mdot
.40784 .20081 Mdot
.42312 .68624 Mdot
.42633 .66566 Mdot
.35204 .41104 Mdot
.50895 .37406 Mdot
.62104 .70018 Mdot
.56129 .65664 Mdot
.48149 .41331 Mdot
.66245 .51926 Mdot
.36759 .4439 Mdot
.5814 .63427 Mdot
.21801 .4211 Mdot
.56976 .412 Mdot
.40617 .58519 Mdot
.26436 .44898 Mdot
.41878 .64985 Mdot
.51659 .36629 Mdot
.35365 .44851 Mdot
.58129 .71651 Mdot
.57653 .6815 Mdot
.60047 .34532 Mdot
.40059 .70953 Mdot
.70063 .53356 Mdot
.60844 .69859 Mdot
.51822 .53734 Mdot
.55363 .37971 Mdot
.40236 .60845 Mdot
.60933 .70042 Mdot
.45065 .15535 Mdot
.41724 .78841 Mdot
.33715 .47384 Mdot
.58446 .38752 Mdot
.35437 .48121 Mdot
.71088 .55257 Mdot
.63393 .70572 Mdot
.38828 .69618 Mdot
.50673 .4502 Mdot
.62954 .7877 Mdot
.584 .67485 Mdot
.34568 .43964 Mdot
.52624 .3564 Mdot
.45015 .33384 Mdot
.5448 .39942 Mdot
.78182 .4157 Mdot
.70209 .51837 Mdot
.37572 .7152 Mdot
.40161 .71289 Mdot
.5891 .37042 Mdot
.75658 .54244 Mdot
.55469 .66561 Mdot
.59946 .69304 Mdot
.61627 .81936 Mdot
.39074 .56947 Mdot
.55448 .64625 Mdot
.56359 .38836 Mdot
.59739 .71667 Mdot
.48266 .24014 Mdot
.40954 .71254 Mdot
.5971 .38839 Mdot
.59858 .6486 Mdot
.2607 .64334 Mdot
.57579 .50252 Mdot
.55141 .38219 Mdot
.54251 .43555 Mdot
.39298 .68235 Mdot
.20565 .58213 Mdot
.56744 .68259 Mdot
.55704 .33267 Mdot
.44169 .67299 Mdot
.51216 .47436 Mdot
.65132 .63941 Mdot
.33938 .44825 Mdot
.60032 .6462 Mdot
.41308 .65943 Mdot
.54193 .29625 Mdot
.71349 .52452 Mdot
.56317 .69724 Mdot
.58051 .6511 Mdot
.57157 .35527 Mdot
.57295 .32978 Mdot
.56838 .43026 Mdot
.3588 .43862 Mdot
.42884 .67362 Mdot
.58318 .35525 Mdot
.52736 .52022 Mdot
.5698 .33947 Mdot
.42359 .66582 Mdot
.62156 .87572 Mdot
.51209 .41096 Mdot
.56056 .36883 Mdot
.44819 .3233 Mdot
.30289 .44718 Mdot
.32357 .46579 Mdot
.51594 .50949 Mdot
.55065 .40332 Mdot
.50285 .55854 Mdot
.34229 .44666 Mdot
.34258 .43445 Mdot
.50417 .55987 Mdot
.56289 .3516 Mdot
.4203 .58784 Mdot
.41284 .70464 Mdot
.42584 .7073 Mdot
.33125 .46775 Mdot
.58199 .32857 Mdot
.41501 .7184 Mdot
.35241 .36126 Mdot
.62218 .70548 Mdot
.66834 .41707 Mdot
.31818 .4398 Mdot
.60231 .50156 Mdot
.42613 .69814 Mdot
.50206 .17453 Mdot
.63707 .25497 Mdot
.5568 .42081 Mdot
.51101 .37194 Mdot
.73083 .54053 Mdot
.48197 .43648 Mdot
.40593 .57842 Mdot
.40388 .70664 Mdot
.48443 .64222 Mdot
.33392 .45189 Mdot
.54753 .40341 Mdot
.70284 .4479 Mdot
.41469 .17906 Mdot
.54605 .28355 Mdot
.33654 .4344 Mdot
.32886 .45162 Mdot
.57497 .69903 Mdot
.61849 .7118 Mdot
.51894 .34976 Mdot
.39194 .6981 Mdot
.35253 .47766 Mdot
.42375 .67013 Mdot
.59333 .68883 Mdot
.62335 .69389 Mdot
.41544 .56713 Mdot
.50198 .32925 Mdot
.58793 .69221 Mdot
.41013 .75445 Mdot
.52687 .52124 Mdot
.38355 .42882 Mdot
.33891 .77528 Mdot
.52762 .17917 Mdot
.41327 .39952 Mdot
.73806 .55824 Mdot
.54629 .47661 Mdot
.38978 .71226 Mdot
.58921 .36702 Mdot
.52175 .37303 Mdot
.40491 .55479 Mdot
.39528 .71767 Mdot
.72624 .53005 Mdot
.41746 .71161 Mdot
.74315 .53179 Mdot
.59302 .65911 Mdot
.53683 .35333 Mdot
.50053 .3722 Mdot
.41796 .68681 Mdot
.58997 .71012 Mdot
.62686 .69747 Mdot
.75012 .54717 Mdot
.67388 .33332 Mdot
.59302 .6805 Mdot
.31878 .43856 Mdot
.42607 .21349 Mdot
.40951 .56507 Mdot
.53165 .38019 Mdot
.68698 .42126 Mdot
.33516 .32104 Mdot
.55082 .33819 Mdot
.39429 .57027 Mdot
.52006 .87947 Mdot
.53644 .35155 Mdot
.70197 .76489 Mdot
.41131 .5533 Mdot
.31557 .4308 Mdot
.60642 .70783 Mdot
.39164 .56997 Mdot
.63894 .4001 Mdot
.62124 .64221 Mdot
.47734 .39815 Mdot
.37146 .44961 Mdot
.34488 .42003 Mdot
.52619 .60462 Mdot
.28255 .68629 Mdot
.72322 .5575 Mdot
.71576 .5329 Mdot
.601 .66893 Mdot
.42626 .74547 Mdot
.58971 .33571 Mdot
.71754 .53372 Mdot
.4299 .59264 Mdot
.59152 .36863 Mdot
.53292 .59708 Mdot
.50341 .60124 Mdot
.30942 .45809 Mdot
.59683 .31178 Mdot
.60286 .67123 Mdot
.34446 .44012 Mdot
.51455 .59646 Mdot
.5969 .38318 Mdot
.33594 .44932 Mdot
.43226 .68852 Mdot
.47489 .55425 Mdot
.31369 .44504 Mdot
.59634 .49563 Mdot
.41498 .69192 Mdot
.53473 .6027 Mdot
.73689 .36024 Mdot
.30774 .20266 Mdot
.39689 .70424 Mdot
.60542 .7117 Mdot
.58198 .67958 Mdot
.59625 .67925 Mdot
.3513 .43273 Mdot
.6104 .68743 Mdot
.36519 .45986 Mdot
.37531 .683 Mdot
.67192 .3501 Mdot
.72654 .54552 Mdot
.78618 .52549 Mdot
.32514 .45828 Mdot
.30323 .72639 Mdot
.29475 .76781 Mdot
.57218 .3376 Mdot
.43308 .66942 Mdot
.75217 .55626 Mdot
.50335 .49504 Mdot
.73012 .53776 Mdot
.60442 .70985 Mdot
.66702 .40542 Mdot
.54142 .39182 Mdot
.28967 .50575 Mdot
.73686 .55757 Mdot
.34097 .43268 Mdot
.5753 .37384 Mdot
.58796 .642 Mdot
.70864 .54591 Mdot
.74508 .55148 Mdot
.53656 .3711 Mdot
.33562 .42127 Mdot
.6203 .70464 Mdot
.38453 .7055 Mdot
.75142 .51064 Mdot
.52124 .43816 Mdot
.52022 .35279 Mdot
.50576 .40963 Mdot
.55653 .50253 Mdot
.44461 .73441 Mdot
.41271 .69275 Mdot
.73749 .45141 Mdot
.58699 .66699 Mdot
.71032 .43578 Mdot
.31444 .64679 Mdot
.7719 .56577 Mdot
.40075 .54659 Mdot
.40008 .54544 Mdot
.54843 .37571 Mdot
.20622 .66386 Mdot
.55343 .27394 Mdot
.41182 .6385 Mdot
.40653 .56107 Mdot
.62613 .70262 Mdot
.38457 .44913 Mdot
.62836 .38544 Mdot
.6033 .35354 Mdot
.38665 .71114 Mdot
.59699 .68723 Mdot
.17388 .60969 Mdot
.71553 .54501 Mdot
.49916 .49693 Mdot
.52527 .40261 Mdot
.54263 .37839 Mdot
.40388 .68648 Mdot
.38767 .69192 Mdot
.41272 .49737 Mdot
.61611 .52493 Mdot
.28819 .52159 Mdot
.40021 .72848 Mdot
.173 .60899 Mdot
.25254 .44601 Mdot
.33829 .46644 Mdot
.40786 .58247 Mdot
.42743 .7106 Mdot
.53033 .36414 Mdot
.31387 .43189 Mdot
.57303 .27637 Mdot
.32523 .49924 Mdot
.53217 .5915 Mdot
.5247 .53924 Mdot
.51249 .398 Mdot
.31264 .47293 Mdot
.34103 .44193 Mdot
.29632 .45334 Mdot
.4055 .57345 Mdot
.52493 .39157 Mdot
.55139 .33565 Mdot
.53709 .35013 Mdot
.44363 .37369 Mdot
.55136 .37358 Mdot
.31072 .64583 Mdot
.51167 .51847 Mdot
.7103 .62798 Mdot
.54742 .35765 Mdot
.43236 .67977 Mdot
.53624 .35506 Mdot
.75536 .53435 Mdot
.51296 .40746 Mdot
.53211 .58762 Mdot
.40706 .70057 Mdot
.29913 .37947 Mdot
.64376 .72426 Mdot
.50367 .3675 Mdot
.70521 .55143 Mdot
.35972 .77603 Mdot
.7261 .45145 Mdot
.41422 .50453 Mdot
.31707 .44278 Mdot
.60121 .72665 Mdot
.43949 .67859 Mdot
.62107 .69012 Mdot
.58806 .40434 Mdot
.41291 .58 Mdot
.68879 .22887 Mdot
.61142 .50297 Mdot
.5315 .36243 Mdot
.49573 .33749 Mdot
.30877 .45316 Mdot
.60695 .67687 Mdot
.4069 .42062 Mdot
.59358 .37177 Mdot
.71577 .51926 Mdot
.75978 .5368 Mdot
.53381 .70087 Mdot
.45821 .55482 Mdot
.51187 .25739 Mdot
.40533 .68843 Mdot
.57907 .6751 Mdot
.76277 .5357 Mdot
.33377 .51197 Mdot
.4367 .69556 Mdot
.41868 .64962 Mdot
.41719 .66965 Mdot
.55808 .37906 Mdot
.41379 .56684 Mdot
.45406 .59185 Mdot
.39029 .5577 Mdot
.60071 .36839 Mdot
.58264 .65096 Mdot
.38998 .55252 Mdot
.73291 .54804 Mdot
.41707 .65833 Mdot
.62527 .68317 Mdot
.54322 .36609 Mdot
.34378 .45167 Mdot
.78193 .48876 Mdot
.43888 .801 Mdot
.53552 .59812 Mdot
.53556 .59822 Mdot
.3496 .41668 Mdot
.35636 .53073 Mdot
.39439 .73536 Mdot
.2936 .34906 Mdot
.68459 .57494 Mdot
.47361 .40563 Mdot
.67717 .71289 Mdot
.5724 .66512 Mdot
.59869 .70113 Mdot
.54713 .39213 Mdot
.58622 .71362 Mdot
.54345 .40284 Mdot
.56876 .68877 Mdot
.28862 .65538 Mdot
.6107 .36862 Mdot
.6028 .69809 Mdot
.5525 .4457 Mdot
.57007 .37171 Mdot
.31 .44126 Mdot
.56915 .70406 Mdot
.55764 .42029 Mdot
.76223 .27822 Mdot
.40615 .67582 Mdot
.40627 .57279 Mdot
.53924 .573 Mdot
.42014 .70536 Mdot
.367 .46294 Mdot
.54148 .40901 Mdot
.71305 .54608 Mdot
.33336 .46369 Mdot
.61877 .64668 Mdot
.73636 .55587 Mdot
.45884 .47513 Mdot
.33347 .46714 Mdot
.41019 .56068 Mdot
.7339 .52124 Mdot
.47764 .399 Mdot
.59839 .69919 Mdot
.42559 .79518 Mdot
.39382 .57344 Mdot
.53718 .39259 Mdot
.60771 .64772 Mdot
.4186 .71012 Mdot
.50693 .36826 Mdot
.57911 .67981 Mdot
.40116 .57706 Mdot
.56487 .36751 Mdot
.56474 .39106 Mdot
.36532 .39185 Mdot
.63941 .57378 Mdot
.72914 .54704 Mdot
.33664 .40933 Mdot
.60026 .3594 Mdot
.75509 .54593 Mdot
.46467 .75586 Mdot
.60937 .38405 Mdot
.37485 .4461 Mdot
.32607 .36147 Mdot
.60371 .71713 Mdot
.40615 .71375 Mdot
.55821 .67682 Mdot
.71871 .56126 Mdot
.35601 .82608 Mdot
.40865 .57961 Mdot
.49646 .40741 Mdot
.54931 .41983 Mdot
.63211 .71473 Mdot
.33815 .44228 Mdot
.28699 .51889 Mdot
.518 .40904 Mdot
.533 .30531 Mdot
.53342 .37538 Mdot
.46414 .76532 Mdot
.35515 .43531 Mdot
.53169 .37763 Mdot
.49549 .43066 Mdot
.57929 .40564 Mdot
.70239 .53818 Mdot
.70306 .29629 Mdot
.54652 .34085 Mdot
.80234 .73912 Mdot
.4182 .56951 Mdot
.60146 .69054 Mdot
.58778 .4971 Mdot
.55113 .58116 Mdot
.8248 .53173 Mdot
.36909 .45392 Mdot
.35421 .51419 Mdot
.62196 .69631 Mdot
.80508 .52128 Mdot
.36784 .53506 Mdot
.57056 .38482 Mdot
.52977 .40681 Mdot
.60452 .70984 Mdot
.60405 .72037 Mdot
.41514 .57886 Mdot
.50985 .34997 Mdot
.57654 .30184 Mdot
.56214 .66373 Mdot
.54997 .36499 Mdot
.34013 .30128 Mdot
.40094 .64833 Mdot
.32968 .46797 Mdot
.41986 .686 Mdot
.39898 .65098 Mdot
.40819 .40405 Mdot
.52163 .50113 Mdot
.39215 .66971 Mdot
.40076 .64123 Mdot
.78903 .53879 Mdot
.43469 .36101 Mdot
.70264 .53548 Mdot
.44108 .51091 Mdot
.59483 .67215 Mdot
.52326 .39003 Mdot
.35151 .43151 Mdot
.8065 .40113 Mdot
.29012 .54539 Mdot
.65091 .34034 Mdot
.58504 .34417 Mdot
.60105 .67414 Mdot
.3959 .57505 Mdot
.6117 .38012 Mdot
.70949 .43111 Mdot
.54615 .38208 Mdot
.61554 .71596 Mdot
.4322 .36683 Mdot
.37332 .75103 Mdot
.39767 .72933 Mdot
.38113 .47224 Mdot
.53405 .3543 Mdot
.35971 .45056 Mdot
.39273 .66394 Mdot
.74766 .55619 Mdot
.72321 .53781 Mdot
.50174 .37167 Mdot
.52553 .57258 Mdot
.77893 .57618 Mdot
.5718 .38117 Mdot
.56863 .35291 Mdot
.40003 .54737 Mdot
.56777 .35196 Mdot
.53336 .33754 Mdot
.58442 .35384 Mdot
.56722 .33167 Mdot
.43304 .70348 Mdot
.41482 .41731 Mdot
.49804 .36294 Mdot
.52042 .42416 Mdot
.38087 .67387 Mdot
.56427 .42324 Mdot
.39368 .69159 Mdot
.30786 .54222 Mdot
.39428 .66973 Mdot
.72346 .53935 Mdot
.60199 .6446 Mdot
.38694 .49411 Mdot
.35232 .47748 Mdot
.43465 .68875 Mdot
.73237 .52356 Mdot
.39991 .70513 Mdot
.57663 .67251 Mdot
.40394 .77408 Mdot
.34725 .40273 Mdot
.50623 .52773 Mdot
.4384 .34156 Mdot
.39663 .61372 Mdot
.58325 .70956 Mdot
.33979 .47446 Mdot
.40727 .74772 Mdot
.58829 .36992 Mdot
.71748 .5517 Mdot
.54765 .37576 Mdot
.42063 .65979 Mdot
.5981 .6737 Mdot
.41547 .53277 Mdot
.72976 .54628 Mdot
.38193 .82039 Mdot
.56691 .6637 Mdot
.53052 .42019 Mdot
.38087 .67564 Mdot
.41877 .76273 Mdot
.39126 .68235 Mdot
.67273 .34988 Mdot
.27996 .4653 Mdot
.8107 .42718 Mdot
.32806 .45562 Mdot
.40186 .59321 Mdot
.27042 .26854 Mdot
.35434 .6136 Mdot
.34659 .45868 Mdot
.63843 .73692 Mdot
.55472 .37316 Mdot
.5786 .34272 Mdot
.50782 .32534 Mdot
.30245 .47971 Mdot
.58882 .345 Mdot
.40892 .57479 Mdot
.52623 .50533 Mdot
.44487 .61545 Mdot
.59208 .72553 Mdot
.54192 .40202 Mdot
.38546 .67292 Mdot
.43497 .6822 Mdot
.39167 .54578 Mdot
.42345 .68025 Mdot
.55815 .35639 Mdot
.32614 .45797 Mdot
.50944 .59624 Mdot
.71187 .55284 Mdot
.31857 .673 Mdot
.71116 .58908 Mdot
.77181 .52723 Mdot
.57665 .40812 Mdot
.62335 .69599 Mdot
.64066 .78038 Mdot
.59008 .35829 Mdot
.34386 .44436 Mdot
.54812 .41958 Mdot
.58034 .34757 Mdot
.53507 .34621 Mdot
.57989 .67468 Mdot
.58198 .50345 Mdot
.5491 .36359 Mdot
.3931 .66714 Mdot
.50627 .55978 Mdot
.6008 .34906 Mdot
.49582 .65268 Mdot
.53165 .58843 Mdot
.40173 .60948 Mdot
.38757 .43366 Mdot
.61724 .70323 Mdot
.33237 .45331 Mdot
.31965 .48586 Mdot
.36642 .46357 Mdot
.45174 .60394 Mdot
.30519 .34562 Mdot
.72168 .75343 Mdot
.48521 .24352 Mdot
.43444 .34275 Mdot
.37348 .4785 Mdot
.51567 .74322 Mdot
.35056 .4561 Mdot
.36813 .46019 Mdot
.59121 .86851 Mdot
.35713 .43056 Mdot
.52602 .38103 Mdot
.49806 .39532 Mdot
.24018 .39551 Mdot
.77137 .51669 Mdot
.56578 .38287 Mdot
.56319 .3345 Mdot
.76126 .5358 Mdot
.39136 .40209 Mdot
.41236 .58576 Mdot
.49366 .49702 Mdot
.39661 .585 Mdot
.53735 .37085 Mdot
.50608 .38921 Mdot
.52925 .33404 Mdot
.34475 .19858 Mdot
.81912 .44851 Mdot
.33812 .41744 Mdot
.47621 .41302 Mdot
.38492 .62826 Mdot
.55506 .41232 Mdot
.56043 .41426 Mdot
.54187 .34684 Mdot
.62123 .69999 Mdot
.38225 .44053 Mdot
.47266 .37696 Mdot
.33938 .6569 Mdot
.51761 .40064 Mdot
.74287 .58917 Mdot
.71811 .56943 Mdot
.53489 .38609 Mdot
.35842 .42991 Mdot
.58016 .34235 Mdot
.35946 .47818 Mdot
.33704 .46925 Mdot
.55272 .30108 Mdot
.45321 .58139 Mdot
.38364 .45126 Mdot
.56931 .38688 Mdot
.58917 .71076 Mdot
.30789 .66923 Mdot
.53681 .39149 Mdot
.7351 .55151 Mdot
.51736 .36358 Mdot
.7022 .54345 Mdot
.56224 .34534 Mdot
.39093 .55218 Mdot
.33541 .25565 Mdot
.60843 .66954 Mdot
.76772 .52083 Mdot
.59037 .71459 Mdot
.56546 .31638 Mdot
.37477 .47226 Mdot
.35457 .7155 Mdot
.82156 .4726 Mdot
.40121 .5479 Mdot
.75797 .46062 Mdot
.49536 .56566 Mdot
.38508 .69673 Mdot
.30227 .45921 Mdot
.4234 .38658 Mdot
.4976 .64771 Mdot
.60281 .72917 Mdot
.62799 .67506 Mdot
.66148 .64551 Mdot
.53893 .86505 Mdot
.55305 .36421 Mdot
.4799 .67315 Mdot
.36061 .26893 Mdot
.47693 .42959 Mdot
.589 .42762 Mdot
.57633 .6518 Mdot
.5662 .38253 Mdot
.64494 .48119 Mdot
.58628 .68007 Mdot
.71479 .52883 Mdot
.36038 .45951 Mdot
.75225 .53639 Mdot
.24883 .53042 Mdot
.41217 .50838 Mdot
.58715 .68785 Mdot
.57208 .33228 Mdot
.55888 .3897 Mdot
.30126 .45156 Mdot
.48861 .20351 Mdot
.33005 .46961 Mdot
.71779 .55732 Mdot
.59844 .66468 Mdot
.72636 .27183 Mdot
.52174 .35798 Mdot
.32611 .43354 Mdot
.64339 .72498 Mdot
.51127 .38078 Mdot
.40499 .71231 Mdot
.59059 .34846 Mdot
.32589 .43122 Mdot
.56773 .35149 Mdot
.32914 .45881 Mdot
.57838 .70051 Mdot
.49955 .37672 Mdot
.50347 .3816 Mdot
.74413 .4529 Mdot
.72778 .53072 Mdot
.37834 .46417 Mdot
.64594 .47805 Mdot
.6038 .3767 Mdot
.70256 .42359 Mdot
.53667 .35287 Mdot
.4421 .34502 Mdot
.60288 .39819 Mdot
.41046 .57268 Mdot
.5542 .41783 Mdot
.53826 .39089 Mdot
.50713 .21006 Mdot
.48266 .23725 Mdot
.43618 .40085 Mdot
.42508 .70912 Mdot
.33722 .42591 Mdot
.58213 .6827 Mdot
.58445 .71963 Mdot
.61398 .69106 Mdot
.68701 .53274 Mdot
.48509 .41955 Mdot
.53623 .39552 Mdot
.39346 .63781 Mdot
.71587 .53722 Mdot
.33088 .43485 Mdot
.72161 .54321 Mdot
.52398 .49898 Mdot
.73878 .54929 Mdot
.40618 .57949 Mdot
.41733 .78623 Mdot
.33982 .31213 Mdot
.74106 .53755 Mdot
.3321 .46974 Mdot
.49964 .54896 Mdot
.47128 .40004 Mdot
.2636 .66751 Mdot
.71759 .51855 Mdot
.66502 .67072 Mdot
.5588 .36189 Mdot
.60863 .48685 Mdot
.39521 .6889 Mdot
.75159 .53534 Mdot
.41583 .6702 Mdot
.58145 .34335 Mdot
.36909 .3972 Mdot
.34921 .4404 Mdot
.39675 .64993 Mdot
.58754 .39744 Mdot
.75193 .53528 Mdot
.59044 .69292 Mdot
.43368 .36525 Mdot
.38335 .66153 Mdot
.78079 .49127 Mdot
.70825 .43652 Mdot
.59458 .66548 Mdot
.46735 .29217 Mdot
.40263 .66748 Mdot
.47513 .40825 Mdot
.60027 .29296 Mdot
.59558 .35969 Mdot
.62758 .69504 Mdot
.59954 .70195 Mdot
.38562 .60533 Mdot
.50402 .38812 Mdot
.49423 .37057 Mdot
.3719 .4238 Mdot
.59311 .66367 Mdot
.36571 .46542 Mdot
.31422 .46873 Mdot
.60221 .71094 Mdot
.33451 .47407 Mdot
.73939 .5553 Mdot
.64312 .45051 Mdot
.4009 .66732 Mdot
.39894 .71051 Mdot
.58668 .69011 Mdot
.60549 .66067 Mdot
.62394 .6943 Mdot
.5918 .38312 Mdot
.34935 .47451 Mdot
.58321 .3872 Mdot
.53111 .3546 Mdot
.32027 .50769 Mdot
.3647 .41555 Mdot
.57649 .40237 Mdot
.5 .60322 Mdot
.70606 .5202 Mdot
.60459 .69547 Mdot
.42783 .67532 Mdot
.79089 .49072 Mdot
.38226 .69047 Mdot
.60565 .37438 Mdot
.2644 .65006 Mdot
.34907 .43235 Mdot
.73068 .53896 Mdot
.53449 .59139 Mdot
.7308 .54388 Mdot
.39944 .64866 Mdot
.3422 .41264 Mdot
.46599 .48386 Mdot
.50263 .38631 Mdot
.55194 .50288 Mdot
.7374 .39343 Mdot
.32071 .64632 Mdot
.43076 .67915 Mdot
.57659 .33915 Mdot
.40729 .55036 Mdot
.28651 .34956 Mdot
.53995 .39485 Mdot
.59441 .39498 Mdot
.56401 .59637 Mdot
.55022 .42049 Mdot
.32435 .41653 Mdot
.5276 .59287 Mdot
.5235 .34059 Mdot
.56085 .31657 Mdot
.58989 .8432 Mdot
.56716 .37197 Mdot
.5023 .37728 Mdot
.52041 .37996 Mdot
.59007 .3727 Mdot
.35765 .48063 Mdot
.5663 .61109 Mdot
.38986 .66436 Mdot
.6436 .45019 Mdot
.41134 .66653 Mdot
.58784 .69799 Mdot
.63767 .50441 Mdot
.35748 .47968 Mdot
.73136 .54416 Mdot
.47941 .68856 Mdot
.66535 .40635 Mdot
.57695 .70131 Mdot
.77712 .45746 Mdot
.70603 .52717 Mdot
.47056 .39946 Mdot
.72153 .56347 Mdot
.58643 .64878 Mdot
.40023 .70891 Mdot
.5152 .41435 Mdot
.37263 .45892 Mdot
.31382 .44563 Mdot
.59665 .35455 Mdot
.3232 .68356 Mdot
.41218 .71501 Mdot
.67736 .50018 Mdot
.556 .38475 Mdot
.59757 .38776 Mdot
.32918 .47098 Mdot
.60538 .67666 Mdot
.49729 .5649 Mdot
.73162 .52669 Mdot
.53958 .41403 Mdot
.56405 .33705 Mdot
.52755 .49939 Mdot
.43548 .69345 Mdot
.40099 .56312 Mdot
.54002 .39898 Mdot
.50518 .50361 Mdot
.59038 .34566 Mdot
.54793 .32558 Mdot
.59975 .71466 Mdot
.54309 .30192 Mdot
.51289 .40218 Mdot
.34832 .39471 Mdot
.40489 .66816 Mdot
.33879 .44568 Mdot
.3411 .51038 Mdot
.39317 .54823 Mdot
.40932 .67763 Mdot
.5793 .40139 Mdot
.42768 .65765 Mdot
.57942 .34479 Mdot
.5455 .36475 Mdot
.43179 .68277 Mdot
.35987 .46935 Mdot
.33364 .53741 Mdot
.41514 .41744 Mdot
.58343 .3637 Mdot
.51508 .36784 Mdot
.77161 .51726 Mdot
.82227 .41513 Mdot
.50702 .39776 Mdot
.34168 .47574 Mdot
.51031 .37938 Mdot
.3869 .69811 Mdot
.72462 .55821 Mdot
.34622 .44843 Mdot
.58275 .66592 Mdot
.57654 .69729 Mdot
.6306 .73415 Mdot
.40712 .58034 Mdot
.50534 .3553 Mdot
.33884 .40977 Mdot
.35972 .41487 Mdot
.62582 .46613 Mdot
.60178 .6918 Mdot
.72868 .55854 Mdot
.56541 .38695 Mdot
.4991 .44874 Mdot
.4025 .65124 Mdot
.82513 .71209 Mdot
.47178 .48868 Mdot
.6928 .54383 Mdot
.61072 .53582 Mdot
.4002 .54976 Mdot
.564 .37363 Mdot
.75481 .53573 Mdot
.58884 .70375 Mdot
.57808 .34216 Mdot
.54792 .43391 Mdot
.50917 .66708 Mdot
.61642 .66511 Mdot
.41388 .64833 Mdot
.56948 .67881 Mdot
.70117 .53487 Mdot
.40644 .57857 Mdot
.3182 .43369 Mdot
.54083 .38604 Mdot
.58544 .30358 Mdot
.59929 .68002 Mdot
.40625 .54371 Mdot
.50734 .36069 Mdot
.33042 .42514 Mdot
.60832 .69001 Mdot
.53298 .36903 Mdot
.28903 .35388 Mdot
.38642 .49356 Mdot
.593 .66978 Mdot
.54551 .41069 Mdot
.62621 .39221 Mdot
.61983 .6668 Mdot
.59462 .64954 Mdot
.57372 .33711 Mdot
.74769 .53016 Mdot
.51565 .40236 Mdot
.39091 .69214 Mdot
.58132 .5045 Mdot
.41603 .68426 Mdot
.71054 .42905 Mdot
.56178 .32696 Mdot
.56493 .27836 Mdot
.32534 .48035 Mdot
.75538 .51879 Mdot
.57069 .20082 Mdot
.60414 .37993 Mdot
.23187 .4361 Mdot
.59912 .50271 Mdot
.48829 .51285 Mdot
.22146 .45183 Mdot
.73951 .53078 Mdot
.40088 .70402 Mdot
.50556 .36568 Mdot
.46129 .69161 Mdot
.74552 .53587 Mdot
.70999 .42786 Mdot
.5696 .39901 Mdot
.34032 .43482 Mdot
.55555 .38201 Mdot
.32666 .4285 Mdot
.51459 .38307 Mdot
.28701 .39338 Mdot
.75018 .58912 Mdot
.67243 .34745 Mdot
.47114 .39546 Mdot
.4154 .76234 Mdot
.43786 .34156 Mdot
.72824 .55559 Mdot
.57843 .35772 Mdot
.39769 .55584 Mdot
.41802 .71139 Mdot
.48111 .70964 Mdot
.62256 .69473 Mdot
.39642 .66509 Mdot
.34719 .46989 Mdot
.57776 .64686 Mdot
.40384 .54405 Mdot
.4723 .35752 Mdot
.75189 .53378 Mdot
.40641 .67627 Mdot
.53771 .38889 Mdot
.59622 .368 Mdot
.46305 .76647 Mdot
.69728 .25595 Mdot
.32914 .47579 Mdot
.44098 .8546 Mdot
.33181 .41011 Mdot
.72052 .53038 Mdot
.60444 .71523 Mdot
.52721 .36482 Mdot
.52635 .40056 Mdot
.61694 .66724 Mdot
.30413 .44585 Mdot
.77125 .5343 Mdot
.8132 .42384 Mdot
.43379 .65508 Mdot
.69905 .31548 Mdot
.34921 .44792 Mdot
.69949 .31825 Mdot
.7059 .57356 Mdot
.42779 .56209 Mdot
.65343 .26282 Mdot
.41491 .70612 Mdot
.69904 .31288 Mdot
.33574 .432 Mdot
.55592 .36566 Mdot
.4091 .55912 Mdot
.41716 .56434 Mdot
.35784 .45578 Mdot
.60896 .70924 Mdot
.71553 .52355 Mdot
.5534 .38493 Mdot
.49275 .32399 Mdot
.48119 .20142 Mdot
.59625 .66046 Mdot
.49412 .34028 Mdot
.42411 .69842 Mdot
.5118 .37576 Mdot
.76118 .54272 Mdot
.41051 .70554 Mdot
.3893 .56364 Mdot
.66436 .41227 Mdot
.54161 .40915 Mdot
.52757 .57872 Mdot
.3984 .68471 Mdot
.81874 .40761 Mdot
.50398 .38276 Mdot
.40292 .66748 Mdot
.58329 .30301 Mdot
.34999 .71867 Mdot
.50617 .5813 Mdot
.35334 .61123 Mdot
.56178 .70023 Mdot
.56896 .68713 Mdot
.76679 .28769 Mdot
.67595 .56488 Mdot
.40415 .65795 Mdot
.40116 .58021 Mdot
.70294 .28491 Mdot
.41479 .67232 Mdot
.52924 .41574 Mdot
.53979 .35336 Mdot
.43208 .36689 Mdot
.5183 .45072 Mdot
.41568 .58116 Mdot
.46092 .34463 Mdot
.56372 .35752 Mdot
.47744 .36435 Mdot
.51086 .36211 Mdot
.34257 .41972 Mdot
.41845 .70283 Mdot
.16678 .3993 Mdot
.43555 .66774 Mdot
.58097 .28452 Mdot
.59515 .67218 Mdot
.55738 .68772 Mdot
.53526 .38495 Mdot
.58906 .27348 Mdot
.17706 .6295 Mdot
.52775 .35093 Mdot
.53423 .59074 Mdot
.7104 .43774 Mdot
.47909 .41293 Mdot
.37859 .44854 Mdot
.57333 .29976 Mdot
.32582 .40783 Mdot
.40988 .70694 Mdot
.7413 .53228 Mdot
.72507 .51392 Mdot
.39762 .69972 Mdot
.52509 .39866 Mdot
.7399 .51673 Mdot
.53975 .37776 Mdot
.56212 .38237 Mdot
.50611 .49913 Mdot
.74523 .56141 Mdot
.62414 .69767 Mdot
.72537 .5392 Mdot
.36871 .44832 Mdot
.58406 .88301 Mdot
.72183 .54934 Mdot
.43456 .36119 Mdot
.62961 .48835 Mdot
.70442 .31667 Mdot
.31196 .44792 Mdot
.7128 .55473 Mdot
.41245 .71005 Mdot
.4527 .47536 Mdot
.44569 .31765 Mdot
.38235 .69017 Mdot
.53859 .39721 Mdot
.35163 .48141 Mdot
.3498 .41559 Mdot
.40367 .72928 Mdot
.30698 .44655 Mdot
.48637 .403 Mdot
.56558 .39337 Mdot
.39492 .66259 Mdot
.41062 .17783 Mdot
.40441 .71439 Mdot
.40417 .40052 Mdot
.54659 .34615 Mdot
.34474 .44634 Mdot
.44448 .3384 Mdot
.35107 .50444 Mdot
.41521 .56995 Mdot
.50801 .40403 Mdot
.72284 .55381 Mdot
.63947 .46323 Mdot
.59515 .66873 Mdot
.26345 .64471 Mdot
.31729 .44169 Mdot
.42034 .72537 Mdot
.31048 .44128 Mdot
.30615 .45802 Mdot
.38936 .65882 Mdot
.35252 .4374 Mdot
.51822 .40057 Mdot
.19919 .53597 Mdot
.31602 .45114 Mdot
.40379 .69119 Mdot
.71289 .55038 Mdot
.33779 .47422 Mdot
.69093 .49258 Mdot
.55759 .39435 Mdot
.56384 .68808 Mdot
.72494 .5037 Mdot
.31049 .47227 Mdot
.72927 .55667 Mdot
.60187 .68491 Mdot
.72209 .5211 Mdot
.45683 .6565 Mdot
.3831 .73168 Mdot
.64535 .32665 Mdot
.35859 .73891 Mdot
.36229 .43707 Mdot
.55153 .6693 Mdot
.53466 .41038 Mdot
.5581 .38406 Mdot
.70749 .51639 Mdot
.34799 .41801 Mdot
.3258 .69941 Mdot
.52394 .27736 Mdot
.31959 .67283 Mdot
.43016 .70417 Mdot
.75594 .49062 Mdot
.46787 .48677 Mdot
.45247 .69485 Mdot
.48959 .36362 Mdot
.40113 .55045 Mdot
.53263 .37552 Mdot
.72525 .4512 Mdot
.70333 .53116 Mdot
.49109 .78178 Mdot
.58614 .33358 Mdot
.61685 .66986 Mdot
.516 .37739 Mdot
.47834 .65579 Mdot
.55448 .31925 Mdot
.71654 .51802 Mdot
.44201 .67871 Mdot
.35221 .47754 Mdot
.70692 .54573 Mdot
.57905 .70019 Mdot
.64757 .28078 Mdot
.53054 .41497 Mdot
.5629 .35978 Mdot
.62202 .66572 Mdot
.36933 .46204 Mdot
.59262 .70016 Mdot
.40153 .66709 Mdot
.72294 .54711 Mdot
.58892 .38143 Mdot
.48662 .34895 Mdot
.63368 .71166 Mdot
.42249 .65781 Mdot
.62986 .68867 Mdot
.4257 .65618 Mdot
.40494 .55197 Mdot
.54978 .32973 Mdot
.62856 .67189 Mdot
.50039 .35208 Mdot
.45488 .25797 Mdot
.65035 .42843 Mdot
.53665 .22317 Mdot
.62405 .7002 Mdot
.72729 .59634 Mdot
.40353 .70019 Mdot
.40486 .67373 Mdot
.38391 .38921 Mdot
.20281 .66121 Mdot
.50291 .55882 Mdot
.36976 .78606 Mdot
.40063 .66719 Mdot
.40174 .68177 Mdot
.60056 .7058 Mdot
.36749 .45539 Mdot
.31611 .48227 Mdot
.60971 .64953 Mdot
.68651 .41793 Mdot
.33075 .43469 Mdot
.23116 .4075 Mdot
.57861 .65965 Mdot
.49309 .39163 Mdot
.40144 .51833 Mdot
.71695 .51823 Mdot
.70333 .44486 Mdot
.41169 .77167 Mdot
.52601 .3719 Mdot
.68979 .77065 Mdot
.61984 .6974 Mdot
.43711 .50385 Mdot
.38845 .63567 Mdot
.59678 .37906 Mdot
.5181 .3819 Mdot
.51158 .39164 Mdot
.69455 .52827 Mdot
.46708 .22568 Mdot
.52704 .36833 Mdot
.67158 .38242 Mdot
.61144 .3712 Mdot
.4431 .78464 Mdot
.72512 .53939 Mdot
.78251 .42214 Mdot
.56305 .64671 Mdot
.33497 .66949 Mdot
.58326 .40408 Mdot
.39487 .67389 Mdot
.49244 .62798 Mdot
.42836 .67021 Mdot
.40823 .61212 Mdot
.69076 .27236 Mdot
.34953 .4202 Mdot
.59368 .35156 Mdot
.58433 .65575 Mdot
.33583 .48358 Mdot
.49536 .61866 Mdot
.56854 .88319 Mdot
.4189 .72258 Mdot
.41698 .87365 Mdot
.41682 .67944 Mdot
.41752 .56953 Mdot
.34738 .4683 Mdot
.5974 .26878 Mdot
.54459 .50243 Mdot
.3647 .46614 Mdot
.72446 .65846 Mdot
.29886 .41963 Mdot
.67698 .31046 Mdot
.36441 .40527 Mdot
.40807 .6961 Mdot
.41245 .73081 Mdot
.57943 .42114 Mdot
.52044 .4072 Mdot
.55267 .50613 Mdot
.57661 .43575 Mdot
.54247 .40793 Mdot
.58613 .67971 Mdot
.36582 .75164 Mdot
.45982 .69722 Mdot
.35485 .44742 Mdot
.40939 .65177 Mdot
.51705 .37871 Mdot
.5831 .36358 Mdot
.52628 .42279 Mdot
.80545 .51903 Mdot
.23008 .40595 Mdot
.54586 .3628 Mdot
.54885 .31858 Mdot
.58305 .70617 Mdot
.46367 .76737 Mdot
.46335 .84816 Mdot
.69534 .27742 Mdot
.51101 .35559 Mdot
.72555 .53231 Mdot
.76252 .54109 Mdot
.49962 .41696 Mdot
.60584 .28145 Mdot
.74614 .49297 Mdot
.5375 .38917 Mdot
.66012 .30538 Mdot
.61635 .72763 Mdot
.3965 .54335 Mdot
.59925 .68066 Mdot
.32159 .48017 Mdot
.40483 .54843 Mdot
.57804 .68559 Mdot
.67233 .40698 Mdot
.39222 .55552 Mdot
.34784 .71312 Mdot
.71471 .55614 Mdot
.50666 .36919 Mdot
.41542 .4469 Mdot
.5906 .66309 Mdot
.40005 .67896 Mdot
.33849 .46046 Mdot
.41829 .7126 Mdot
.42326 .79243 Mdot
.69056 .4258 Mdot
.40979 .57792 Mdot
.39333 .67533 Mdot
.5217 .57153 Mdot
.72372 .53359 Mdot
.42132 .67969 Mdot
.56685 .27673 Mdot
.60057 .34711 Mdot
.16164 .54336 Mdot
.56986 .36476 Mdot
.38271 .59602 Mdot
.39846 .67571 Mdot
.38821 .55807 Mdot
.54235 .38504 Mdot
.56566 .66678 Mdot
.46114 .38787 Mdot
.54048 .37622 Mdot
.57403 .66954 Mdot
.54982 .36228 Mdot
.75479 .5513 Mdot
.31568 .41301 Mdot
.61225 .49732 Mdot
.75771 .48228 Mdot
.70911 .52716 Mdot
.59694 .47338 Mdot
.50713 .39864 Mdot
.68932 .63121 Mdot
.33925 .43637 Mdot
.60426 .3784 Mdot
.72246 .42439 Mdot
.36389 .45359 Mdot
.33107 .45317 Mdot
.57258 .35731 Mdot
.3985 .71323 Mdot
.6267 .68762 Mdot
.72431 .53523 Mdot
.43366 .73764 Mdot
.53208 .36736 Mdot
.57758 .33932 Mdot
.70498 .53138 Mdot
.40706 .67878 Mdot
.58696 .3888 Mdot
.28683 .60475 Mdot
.63805 .44915 Mdot
.40968 .64926 Mdot
.59989 .3479 Mdot
.19626 .45197 Mdot
.30087 .46856 Mdot
.69639 .76774 Mdot
.72825 .59172 Mdot
.6029 .71265 Mdot
.52084 .31512 Mdot
.76383 .77523 Mdot
.71603 .55557 Mdot
.32683 .65896 Mdot
.55589 .36834 Mdot
.52593 .36154 Mdot
.34958 .42275 Mdot
.57927 .39577 Mdot
.34175 .42728 Mdot
.77352 .49812 Mdot
.21621 .68108 Mdot
.30773 .44952 Mdot
.33323 .4285 Mdot
.62101 .38667 Mdot
.81529 .53176 Mdot
.35782 .46188 Mdot
.53187 .4147 Mdot
.71527 .63656 Mdot
.53254 .43744 Mdot
.72959 .56901 Mdot
.77229 .50913 Mdot
.37979 .45402 Mdot
.43215 .33304 Mdot
.62085 .3855 Mdot
.30636 .37386 Mdot
.69401 .49783 Mdot
.40814 .66031 Mdot
.57001 .34333 Mdot
.40322 .5816 Mdot
.60819 .695 Mdot
.55455 .29519 Mdot
.50453 .37954 Mdot
.37429 .44775 Mdot
.69488 .53635 Mdot
.41906 .67394 Mdot
.52962 .34126 Mdot
.63024 .72278 Mdot
.72411 .52522 Mdot
.32004 .45913 Mdot
.41569 .39019 Mdot
.73593 .51626 Mdot
.49209 .34124 Mdot
.55543 .36252 Mdot
.52254 .3453 Mdot
.47229 .42061 Mdot
.39692 .69697 Mdot
.59341 .64614 Mdot
.49989 .3339 Mdot
.4752 .48608 Mdot
.65404 .44185 Mdot
.51207 .4157 Mdot
.34034 .47535 Mdot
.43177 .69899 Mdot
.40226 .5734 Mdot
.70434 .30369 Mdot
.54857 .35299 Mdot
.2283 .40972 Mdot
.80468 .4679 Mdot
.39377 .56061 Mdot
.35324 .4846 Mdot
.72977 .53968 Mdot
.55935 .34982 Mdot
.67265 .3757 Mdot
.54834 .40834 Mdot
.47935 .42048 Mdot
.6118 .71052 Mdot
.41814 .66535 Mdot
.6465 .35657 Mdot
.60667 .69758 Mdot
.33192 .45325 Mdot
.23812 .38835 Mdot
.31317 .47846 Mdot
.31518 .46876 Mdot
.44913 .57694 Mdot
.3926 .70228 Mdot
.7782 .76317 Mdot
.83196 .43318 Mdot
.50169 .40215 Mdot
.38546 .68344 Mdot
.35133 .46304 Mdot
.55948 .41239 Mdot
.34746 .43075 Mdot
.3814 .44391 Mdot
.56142 .39344 Mdot
.55583 .39927 Mdot
.67067 .33826 Mdot
.23383 .41013 Mdot
.71752 .55129 Mdot
.31334 .43319 Mdot
.34426 .37658 Mdot
.53001 .36333 Mdot
.50919 .39625 Mdot
.49147 .63264 Mdot
.70728 .54934 Mdot
.3212 .30431 Mdot
.55856 .37905 Mdot
.75286 .45372 Mdot
.51874 .41006 Mdot
.32561 .49079 Mdot
.38561 .71591 Mdot
.57806 .28197 Mdot
.62673 .70135 Mdot
.30042 .45509 Mdot
.70135 .52554 Mdot
.38996 .45478 Mdot
.3278 .33024 Mdot
.40435 .70902 Mdot
.32633 .43102 Mdot
.56959 .64984 Mdot
.41187 .68496 Mdot
.40115 .71259 Mdot
.49706 .61474 Mdot
.56168 .65924 Mdot
.69368 .5435 Mdot
.4283 .68765 Mdot
.28927 .35609 Mdot
.4101 .69438 Mdot
.32044 .32978 Mdot
.50073 .36473 Mdot
.67142 .38681 Mdot
.54168 .29445 Mdot
.5712 .42706 Mdot
.42136 .69201 Mdot
.71646 .52504 Mdot
.58909 .39004 Mdot
.30764 .45465 Mdot
.71212 .54051 Mdot
.41425 .5096 Mdot
.55396 .66898 Mdot
.3563 .41721 Mdot
.42741 .6558 Mdot
.35304 .42949 Mdot
.70755 .43964 Mdot
.77585 .53942 Mdot
.50276 .63582 Mdot
.56183 .5 Mdot
.47528 .3754 Mdot
.57528 .32203 Mdot
.59196 .38801 Mdot
.51818 .39854 Mdot
.5926 .67066 Mdot
.68756 .53542 Mdot
.33653 .47439 Mdot
.47918 .19283 Mdot
.39338 .68131 Mdot
.52601 .58579 Mdot
.47055 .41253 Mdot
.58012 .34436 Mdot
.34799 .46161 Mdot
.38366 .44345 Mdot
.48515 .23452 Mdot
.62221 .67248 Mdot
.54529 .43625 Mdot
.56103 .41685 Mdot
.64121 .39629 Mdot
.41968 .69023 Mdot
.32926 .59064 Mdot
.59307 .72473 Mdot
.4364 .88623 Mdot
.604 .69694 Mdot
.62724 .59711 Mdot
.35487 .43821 Mdot
.73767 .55293 Mdot
.53897 .40064 Mdot
.43278 .42346 Mdot
.36556 .47807 Mdot
.57963 .62873 Mdot
.73303 .54646 Mdot
.34915 .5576 Mdot
.38874 .67382 Mdot
.52331 .34202 Mdot
.52097 .41162 Mdot
.58421 .37587 Mdot
.56144 .40883 Mdot
.39794 .65819 Mdot
.55671 .40324 Mdot
.38725 .65658 Mdot
.33552 .32168 Mdot
.72012 .41613 Mdot
.59308 .65189 Mdot
.47598 .76884 Mdot
.31343 .46649 Mdot
.26381 .33909 Mdot
.33266 .30492 Mdot
.65004 .42907 Mdot
.44432 .6385 Mdot
.52345 .3399 Mdot
.60963 .70772 Mdot
.43864 .74201 Mdot
.58931 .6523 Mdot
.14157 .46313 Mdot
.43272 .36198 Mdot
.36994 .58001 Mdot
.57978 .38662 Mdot
.62301 .6636 Mdot
.41557 .35734 Mdot
.49662 .33424 Mdot
.7468 .51835 Mdot
.31231 .34339 Mdot
.4224 .45609 Mdot
.7245 .5592 Mdot
.56159 .38854 Mdot
.36601 .41572 Mdot
.53256 .40098 Mdot
.54633 .39893 Mdot
.52789 .34989 Mdot
.37727 .6946 Mdot
.49524 .38198 Mdot
.51852 .40359 Mdot
.70965 .26064 Mdot
.52605 .65702 Mdot
.56847 .69151 Mdot
.52763 .22233 Mdot
.71571 .53748 Mdot
.32276 .48049 Mdot
.59752 .50179 Mdot
.38918 .68463 Mdot
.48741 .23319 Mdot
.57782 .37041 Mdot
.30588 .64441 Mdot
.43689 .69758 Mdot
.7409 .52649 Mdot
.39854 .57533 Mdot
.32781 .56168 Mdot
.61017 .71807 Mdot
.41178 .58456 Mdot
.59716 .66789 Mdot
.5597 .22016 Mdot
.33713 .42712 Mdot
.4755 .37474 Mdot
.42261 .67459 Mdot
.57583 .65234 Mdot
.67112 .37394 Mdot
.50814 .38145 Mdot
.62436 .70022 Mdot
.52831 .30416 Mdot
.64426 .46368 Mdot
.5911 .50412 Mdot
.57846 .64838 Mdot
.43977 .69293 Mdot
.41622 .68837 Mdot
.72418 .56094 Mdot
.30124 .46035 Mdot
.3721 .45668 Mdot
.41429 .6947 Mdot
.61007 .82068 Mdot
.5311 .3691 Mdot
.53662 .35674 Mdot
.46775 .48253 Mdot
.55676 .41523 Mdot
.77413 .52295 Mdot
.41927 .56313 Mdot
.37306 .46235 Mdot
.59069 .38956 Mdot
.5868 .38826 Mdot
.56042 .36498 Mdot
.68754 .40842 Mdot
.60096 .67918 Mdot
.5624 .35623 Mdot
.75318 .5341 Mdot
.41378 .49669 Mdot
.53185 .41037 Mdot
.48535 .34855 Mdot
.34463 .42767 Mdot
.65235 .64163 Mdot
.39745 .67983 Mdot
.60097 .66163 Mdot
.58993 .65691 Mdot
.7305 .38569 Mdot
.31585 .49387 Mdot
.41537 .58329 Mdot
.44286 .76964 Mdot
.40398 .5778 Mdot
.73575 .54753 Mdot
.50237 .57522 Mdot
.55846 .70858 Mdot
.56838 .68743 Mdot
.42498 .72713 Mdot
.60168 .36795 Mdot
.53234 .41178 Mdot
.33152 .67125 Mdot
.52961 .35186 Mdot
.72181 .55448 Mdot
.38807 .70763 Mdot
.33284 .42977 Mdot
.76038 .53948 Mdot
.40807 .67304 Mdot
.36696 .46514 Mdot
.59868 .39357 Mdot
.53366 .41643 Mdot
.33477 .45906 Mdot
.31674 .45699 Mdot
.52766 .3851 Mdot
.67823 .24774 Mdot
.36748 .46983 Mdot
.34105 .46432 Mdot
.4156 .48804 Mdot
.59591 .71571 Mdot
.45798 .42152 Mdot
.38642 .69087 Mdot
.51515 .39976 Mdot
.60058 .65217 Mdot
.73988 .53994 Mdot
.32333 .4522 Mdot
.56402 .34251 Mdot
.53853 .36626 Mdot
.72673 .53327 Mdot
.74587 .56406 Mdot
.70751 .54251 Mdot
.39291 .72164 Mdot
.56951 .3868 Mdot
.35375 .46661 Mdot
.38928 .67154 Mdot
.74532 .52098 Mdot
.72016 .56408 Mdot
.65511 .25193 Mdot
.52648 .37462 Mdot
.76469 .53549 Mdot
.61489 .87805 Mdot
.65882 .28257 Mdot
.40654 .54734 Mdot
.61132 .73277 Mdot
.76083 .58949 Mdot
.72594 .50453 Mdot
.41552 .66099 Mdot
.53164 .5934 Mdot
.69866 .54467 Mdot
.54147 .34272 Mdot
.51405 .36376 Mdot
.49434 .34895 Mdot
.71279 .53695 Mdot
.69295 .42471 Mdot
.33686 .41566 Mdot
.37699 .24939 Mdot
.71572 .53773 Mdot
.56981 .65398 Mdot
.63494 .71166 Mdot
.6007 .70071 Mdot
.54962 .3313 Mdot
.53212 .20541 Mdot
.34027 .35217 Mdot
.32336 .29697 Mdot
.39127 .67207 Mdot
.383 .4421 Mdot
.41561 .52992 Mdot
.33022 .45288 Mdot
.61404 .68803 Mdot
.72345 .52449 Mdot
.35054 .42224 Mdot
.40186 .71229 Mdot
.41788 .69086 Mdot
.62969 .70019 Mdot
.60022 .68671 Mdot
.5885 .69011 Mdot
.30055 .45715 Mdot
.3538 .43772 Mdot
.58769 .37689 Mdot
.31953 .45012 Mdot
.81753 .47854 Mdot
.78532 .54869 Mdot
.6332 .70085 Mdot
.39862 .6916 Mdot
.33465 .46735 Mdot
.50555 .3701 Mdot
.58588 .59085 Mdot
.55521 .64875 Mdot
.72813 .51847 Mdot
.21335 .61044 Mdot
.20192 .67326 Mdot
.58985 .34123 Mdot
.41784 .65574 Mdot
.58634 .27768 Mdot
.51566 .39315 Mdot
.61492 .71119 Mdot
.80248 .43547 Mdot
.39127 .56531 Mdot
.53264 .40547 Mdot
.57703 .41193 Mdot
.41091 .71231 Mdot
.59606 .50146 Mdot
.54162 .34184 Mdot
.5153 .5985 Mdot
.43069 .70984 Mdot
.59638 .72529 Mdot
.80025 .32061 Mdot
.43153 .50104 Mdot
.70178 .46069 Mdot
.39865 .54492 Mdot
.53491 .34787 Mdot
.58671 .6773 Mdot
.75009 .52632 Mdot
.59204 .68242 Mdot
.34537 .48643 Mdot
.60412 .71721 Mdot
.51679 .35502 Mdot
.35846 .46393 Mdot
.40753 .67706 Mdot
.53269 .56492 Mdot
.57071 .23312 Mdot
.56526 .66879 Mdot
.40413 .54113 Mdot
.55416 .40006 Mdot
.27596 .35504 Mdot
.58465 .41734 Mdot
.51441 .40328 Mdot
.43078 .67822 Mdot
.35257 .45492 Mdot
.43102 .70251 Mdot
.48899 .33736 Mdot
.2493 .42184 Mdot
.39264 .68563 Mdot
.43364 .42909 Mdot
.70563 .52788 Mdot
.6875 .42305 Mdot
.54679 .38757 Mdot
.42107 .67219 Mdot
.57136 .37794 Mdot
.31544 .4306 Mdot
.66299 .42631 Mdot
.62944 .44998 Mdot
.42334 .70039 Mdot
.3755 .54379 Mdot
.6473 .47629 Mdot
.45894 .42776 Mdot
.40705 .66635 Mdot
.56561 .20198 Mdot
.39778 .55964 Mdot
.73232 .52812 Mdot
.74993 .56316 Mdot
.74862 .54629 Mdot
.5287 .35475 Mdot
.28614 .3839 Mdot
.73095 .56425 Mdot
.40966 .72195 Mdot
.7465 .55691 Mdot
.78705 .49461 Mdot
.32369 .68641 Mdot
.70837 .52655 Mdot
.54973 .38147 Mdot
.58945 .29385 Mdot
.53221 .59091 Mdot
.55965 .68728 Mdot
.27731 .51757 Mdot
.71302 .2644 Mdot
.52621 .36565 Mdot
.27031 .40147 Mdot
.34916 .49078 Mdot
.63971 .57687 Mdot
.62963 .44667 Mdot
.50699 .54643 Mdot
.33714 .46612 Mdot
.57982 .50131 Mdot
.34971 .48066 Mdot
.46978 .39316 Mdot
.54642 .36522 Mdot
.29924 .46102 Mdot
.25389 .63958 Mdot
.54045 .18417 Mdot
.31362 .66785 Mdot
.35194 .47474 Mdot
.4051 .66825 Mdot
.42672 .66544 Mdot
.42996 .67671 Mdot
.58319 .67149 Mdot
.3209 .43351 Mdot
.55196 .35208 Mdot
.58572 .70519 Mdot
.55254 .39286 Mdot
.41521 .70155 Mdot
.64391 .436 Mdot
.33549 .42888 Mdot
.53866 .39008 Mdot
.39769 .37506 Mdot
.60203 .67048 Mdot
.7224 .53239 Mdot
.20523 .57992 Mdot
.59598 .73172 Mdot
.43998 .67758 Mdot
.37907 .47401 Mdot
.64325 .6952 Mdot
.58546 .61051 Mdot
.49924 .40065 Mdot
.5113 .41089 Mdot
.53644 .59924 Mdot
.42783 .36153 Mdot
.54249 .33993 Mdot
.5777 .69875 Mdot
.57912 .70748 Mdot
.57039 .37653 Mdot
.31311 .44132 Mdot
.70381 .55696 Mdot
.70884 .51562 Mdot
.47384 .39581 Mdot
.56181 .50293 Mdot
.67137 .3843 Mdot
.5817 .39869 Mdot
.51267 .32867 Mdot
.5638 .65338 Mdot
.40269 .54401 Mdot
.53344 .49986 Mdot
.73964 .55564 Mdot
.55889 .37168 Mdot
.48281 .20342 Mdot
.3188 .4403 Mdot
.62625 .69662 Mdot
.38584 .6702 Mdot
.7397 .51691 Mdot
.62861 .7104 Mdot
.57034 .37651 Mdot
.58673 .38894 Mdot
.42282 .67881 Mdot
.32612 .49251 Mdot
.71316 .52976 Mdot
.5855 .70578 Mdot
.73619 .55467 Mdot
.35041 .43597 Mdot
.32752 .46265 Mdot
.53639 .42549 Mdot
.57575 .42557 Mdot
.57181 .66327 Mdot
.48442 .36858 Mdot
.5882 .7011 Mdot
.46259 .767 Mdot
.402 .6516 Mdot
.59502 .39183 Mdot
.32494 .49904 Mdot
.41568 .69907 Mdot
.52168 .37 Mdot
.53641 .60251 Mdot
.59185 .35471 Mdot
.60843 .65003 Mdot
.8053 .41038 Mdot
.74545 .54071 Mdot
.61469 .33748 Mdot
.5115 .26955 Mdot
.56595 .41064 Mdot
.56635 .69657 Mdot
.31113 .35411 Mdot
.39289 .69265 Mdot
.35915 .44296 Mdot
.66727 .71522 Mdot
.40599 .69202 Mdot
.55408 .37672 Mdot
.72113 .54849 Mdot
.34683 .4789 Mdot
.41314 .56229 Mdot
.53024 .5119 Mdot
.57263 .29295 Mdot
.50894 .42826 Mdot
.53052 .3403 Mdot
.3681 .78571 Mdot
.58938 .6875 Mdot
.34884 .46306 Mdot
.41508 .65526 Mdot
.39928 .70601 Mdot
.60564 .67654 Mdot
.42077 .46792 Mdot
.28508 .66093 Mdot
.65989 .85143 Mdot
.63049 .7091 Mdot
.7494 .55156 Mdot
.66085 .42757 Mdot
.60229 .7021 Mdot
.58893 .66721 Mdot
.5578 .65715 Mdot
.32977 .68019 Mdot
.35332 .47316 Mdot
.53815 .36486 Mdot
.38193 .4819 Mdot
.53275 .35013 Mdot
.68437 .47014 Mdot
.41356 .70193 Mdot
.35902 .44215 Mdot
.69409 .48847 Mdot
.55482 .31731 Mdot
.52035 .39099 Mdot
.67307 .50176 Mdot
.62981 .33932 Mdot
.70247 .31002 Mdot
.53337 .42141 Mdot
.59437 .67739 Mdot
.3445 .51479 Mdot
.49452 .3391 Mdot
.39413 .37597 Mdot
.41647 .68426 Mdot
.41084 .5787 Mdot
.47324 .37473 Mdot
.51734 .33375 Mdot
.34223 .47969 Mdot
.3528 .42341 Mdot
.72614 .5652 Mdot
.20203 .54382 Mdot
.41423 .68104 Mdot
.34836 .59952 Mdot
.51551 .40484 Mdot
.4197 .62129 Mdot
.8098 .42939 Mdot
.52052 .37636 Mdot
.49896 .60862 Mdot
.48569 .23473 Mdot
.56962 .33945 Mdot
.33352 .28706 Mdot
.40231 .69614 Mdot
.73158 .43733 Mdot
.56507 .40094 Mdot
.61968 .70468 Mdot
.36736 .45109 Mdot
.35634 .417 Mdot
.75105 .52586 Mdot
.82836 .46631 Mdot
.26412 .72444 Mdot
.359 .44053 Mdot
.50793 .38555 Mdot
.39756 .68225 Mdot
.41394 .57068 Mdot
.55986 .29555 Mdot
.47226 .66473 Mdot
.32095 .43952 Mdot
.50418 .32837 Mdot
.30181 .64581 Mdot
.58761 .50213 Mdot
.23103 .36545 Mdot
.43043 .68352 Mdot
.73563 .55907 Mdot
.51178 .44103 Mdot
.44321 .77232 Mdot
.53237 .41651 Mdot
.68963 .46666 Mdot
.29641 .47302 Mdot
.72624 .55795 Mdot
.52308 .3969 Mdot
.54785 .33971 Mdot
.592 .4845 Mdot
.74528 .56755 Mdot
.54398 .34107 Mdot
.5849 .3327 Mdot
.36612 .44219 Mdot
.41929 .56148 Mdot
.33154 .43098 Mdot
.53226 .39988 Mdot
.78658 .37907 Mdot
.32723 .42374 Mdot
.30315 .5278 Mdot
.71659 .58942 Mdot
.3896 .68295 Mdot
.55377 .30231 Mdot
.4984 .37354 Mdot
.20894 .38425 Mdot
.41582 .56848 Mdot
.50568 .84906 Mdot
.61804 .6594 Mdot
.66391 .19924 Mdot
.59185 .73061 Mdot
.36991 .55484 Mdot
.52236 .64608 Mdot
.50449 .33164 Mdot
.433 .41544 Mdot
.31539 .29743 Mdot
.39234 .63808 Mdot
.26887 .33421 Mdot
.52063 .4073 Mdot
.55979 .36809 Mdot
.59572 .70673 Mdot
.38363 .58425 Mdot
.57573 .28095 Mdot
.53631 .50043 Mdot
.73746 .52505 Mdot
.33751 .44323 Mdot
.51254 .36336 Mdot
.23829 .62911 Mdot
.56654 .66033 Mdot
.57997 .24383 Mdot
.54115 .38815 Mdot
.59699 .28532 Mdot
.38575 .58549 Mdot
.4051 .67608 Mdot
.57832 .64806 Mdot
.5636 .65917 Mdot
.53613 .34886 Mdot
.39247 .66227 Mdot
.58811 .36438 Mdot
.65239 .47041 Mdot
.52618 .3072 Mdot
.73778 .54468 Mdot
.50389 .38952 Mdot
.55348 .25144 Mdot
.29597 .24293 Mdot
.58428 .33027 Mdot
.31274 .46954 Mdot
.58592 .69151 Mdot
.60533 .68302 Mdot
.37156 .46 Mdot
.60601 .68305 Mdot
.37556 .25491 Mdot
.25733 .39745 Mdot
.7354 .54983 Mdot
.35151 .3102 Mdot
.74388 .53398 Mdot
.41022 .57926 Mdot
.52609 .37793 Mdot
.5399 .74059 Mdot
.62693 .71553 Mdot
.79052 .49087 Mdot
.41224 .6965 Mdot
.41667 .56764 Mdot
.55855 .39829 Mdot
.68074 .50583 Mdot
.61534 .69775 Mdot
.46954 .55152 Mdot
.54081 .3523 Mdot
.3055 .44397 Mdot
.57501 .34181 Mdot
.61127 .40418 Mdot
.41797 .57037 Mdot
.56479 .33449 Mdot
.4079 .67297 Mdot
.32988 .42579 Mdot
.37328 .59059 Mdot
.58908 .66395 Mdot
.54136 .40501 Mdot
.5092 .38773 Mdot
.37861 .46466 Mdot
.50043 .39892 Mdot
.39751 .66265 Mdot
.859 .66106 Mdot
.70485 .53985 Mdot
.40113 .54365 Mdot
.24876 .53041 Mdot
.56174 .33581 Mdot
.59097 .38271 Mdot
.48134 .53107 Mdot
.48647 .20285 Mdot
.39559 .67529 Mdot
.49642 .42289 Mdot
.57176 .69805 Mdot
.71316 .52856 Mdot
.41434 .71524 Mdot
.56443 .39529 Mdot
.54735 .35993 Mdot
.72542 .55681 Mdot
.67199 .49916 Mdot
.77026 .53654 Mdot
.40771 .65887 Mdot
.26207 .42452 Mdot
.58791 .59013 Mdot
.53451 .37422 Mdot
.39648 .53534 Mdot
.34836 .45566 Mdot
.40476 .66484 Mdot
.45713 .22581 Mdot
.46958 .39502 Mdot
.41523 .64809 Mdot
.40949 .67767 Mdot
.49689 .3925 Mdot
.3118 .49078 Mdot
.38549 .46669 Mdot
.34751 .45867 Mdot
.72368 .40951 Mdot
.44184 .82572 Mdot
.58557 .6866 Mdot
.40015 .68915 Mdot
.60465 .65413 Mdot
.69913 .54205 Mdot
.65093 .449 Mdot
.56176 .66727 Mdot
.3026 .44409 Mdot
.59281 .65394 Mdot
.58912 .36448 Mdot
.39311 .70827 Mdot
.57758 .66114 Mdot
.56338 .40966 Mdot
.52022 .33682 Mdot
.52274 .45113 Mdot
.69622 .54639 Mdot
.57786 .50282 Mdot
.55267 .38432 Mdot
.39778 .57325 Mdot
.532 .38695 Mdot
.39643 .66202 Mdot
.53717 .56397 Mdot
.56948 .36137 Mdot
.62757 .71504 Mdot
.46385 .83899 Mdot
.58372 .71329 Mdot
.61066 .41565 Mdot
.53992 .39669 Mdot
.5319 .37283 Mdot
.55911 .3964 Mdot
.42009 .46101 Mdot
.43367 .66096 Mdot
.49171 .4278 Mdot
.6293 .68233 Mdot
.32875 .45494 Mdot
.32911 .42125 Mdot
.49352 .54837 Mdot
.4103 .58494 Mdot
.38697 .67278 Mdot
.53182 .371 Mdot
.47137 .55517 Mdot
.5033 .5124 Mdot
.30486 .65809 Mdot
.63651 .72998 Mdot
.56739 .68297 Mdot
.30641 .46145 Mdot
.5721 .67704 Mdot
.56031 .39936 Mdot
.5055 .32778 Mdot
.37114 .58673 Mdot
.4063 .63404 Mdot
.71642 .52716 Mdot
.54706 .39621 Mdot
.68083 .38701 Mdot
.58315 .7062 Mdot
.56327 .6552 Mdot
.58747 .36656 Mdot
.34485 .49533 Mdot
.37385 .17558 Mdot
.38462 .68683 Mdot
.27568 .36317 Mdot
.40402 .44454 Mdot
.6379 .42133 Mdot
.39785 .70112 Mdot
.50325 .60036 Mdot
.56064 .69315 Mdot
.7847 .35845 Mdot
.33111 .45904 Mdot
.71565 .52848 Mdot
.54346 .41615 Mdot
.3023 .44438 Mdot
.63286 .68011 Mdot
.36033 .47713 Mdot
.47603 .36985 Mdot
.42548 .71218 Mdot
.60688 .69207 Mdot
.41571 .73107 Mdot
.33769 .48439 Mdot
.74494 .53618 Mdot
.74304 .45301 Mdot
.28733 .3519 Mdot
.48365 .23692 Mdot
.56162 .35534 Mdot
.51808 .68812 Mdot
.5505 .35055 Mdot
.3418 .41306 Mdot
.54738 .38684 Mdot
.56656 .31423 Mdot
.55875 .6917 Mdot
.5142 .41733 Mdot
.50718 .39515 Mdot
.38371 .37641 Mdot
.51973 .38271 Mdot
.56808 .37531 Mdot
.53836 .42639 Mdot
.2987 .4681 Mdot
.51808 .41912 Mdot
.3048 .4486 Mdot
.3201 .6535 Mdot
.59304 .66482 Mdot
.69994 .54401 Mdot
.70096 .53567 Mdot
.70237 .46397 Mdot
.68294 .39555 Mdot
.39551 .51113 Mdot
.32833 .43762 Mdot
.4204 .69204 Mdot
.58875 .36912 Mdot
.58114 .20374 Mdot
.78088 .38249 Mdot
.57017 .70821 Mdot
.57933 .65677 Mdot
.54494 .41289 Mdot
.19337 .65543 Mdot
.52761 .41905 Mdot
.46932 .48652 Mdot
.53026 .35461 Mdot
.59646 .39001 Mdot
.57632 .64679 Mdot
.70758 .44076 Mdot
.56236 .35637 Mdot
.34262 .47993 Mdot
.72291 .5271 Mdot
.61031 .29898 Mdot
.78321 .4087 Mdot
.40705 .40235 Mdot
.5346 .27295 Mdot
.57438 .37014 Mdot
.59678 .71127 Mdot
.34819 .47653 Mdot
.48441 .49475 Mdot
.39354 .66764 Mdot
.54839 .50906 Mdot
.32598 .32346 Mdot
.38061 .64309 Mdot
.72295 .52545 Mdot
.59166 .63852 Mdot
.52028 .35069 Mdot
.58192 .67609 Mdot
.47823 .41183 Mdot
.50476 .5176 Mdot
.73831 .5479 Mdot
.29505 .44065 Mdot
.40474 .6687 Mdot
.31867 .42438 Mdot
.53567 .22286 Mdot
.78182 .37978 Mdot
.66904 .20137 Mdot
.61006 .72013 Mdot
.40609 .20121 Mdot
.35885 .45563 Mdot
.54309 .35003 Mdot
.65651 .85288 Mdot
.34878 .44938 Mdot
.30431 .44566 Mdot
.52272 .53952 Mdot
.71175 .42999 Mdot
.48288 .37228 Mdot
.3706 .46778 Mdot
.59999 .6407 Mdot
.72966 .54367 Mdot
.56956 .40504 Mdot
.4749 .36998 Mdot
.35058 .42268 Mdot
.61647 .69251 Mdot
.68849 .45602 Mdot
.59771 .68141 Mdot
.35548 .47081 Mdot
.60839 .66974 Mdot
.33694 .54065 Mdot
.56333 .66623 Mdot
.50028 .38114 Mdot
.53269 .37136 Mdot
.45018 .6135 Mdot
.3275 .46262 Mdot
.59096 .38381 Mdot
.55377 .3653 Mdot
.35522 .46362 Mdot
.55282 .7011 Mdot
.44964 .20594 Mdot
.59273 .37501 Mdot
.53433 .367 Mdot
.70499 .54511 Mdot
.6283 .47913 Mdot
.45957 .48552 Mdot
.56907 .40743 Mdot
.75017 .54561 Mdot
.30116 .45524 Mdot
.53013 .38734 Mdot
.70985 .44179 Mdot
.61995 .72679 Mdot
.57796 .38259 Mdot
.41236 .56855 Mdot
.53178 .34598 Mdot
.35509 .19317 Mdot
.5498 .40282 Mdot
.34536 .469 Mdot
.36489 .45452 Mdot
.63982 .73674 Mdot
.33392 .45376 Mdot
.40724 .5485 Mdot
.41591 .68972 Mdot
.24153 .36688 Mdot
.41077 .55144 Mdot
.57042 .33497 Mdot
.8345 .43963 Mdot
.47612 .365 Mdot
.49193 .33801 Mdot
.81639 .53184 Mdot
.39922 .54538 Mdot
.35541 .45087 Mdot
.24781 .62741 Mdot
.48663 .38653 Mdot
.38588 .67512 Mdot
.48836 .34583 Mdot
.57786 .38196 Mdot
.58415 .32553 Mdot
.25744 .41607 Mdot
.38256 .6946 Mdot
.45777 .42258 Mdot
.57031 .40457 Mdot
.48694 .2034 Mdot
.50767 .37159 Mdot
.71927 .51916 Mdot
.34171 .43196 Mdot
.57459 .67639 Mdot
.73513 .54334 Mdot
.5342 .34049 Mdot
.71416 .53866 Mdot
.58299 .67936 Mdot
.42649 .67894 Mdot
.50064 .37672 Mdot
.72883 .56923 Mdot
.726 .52355 Mdot
.5745 .3525 Mdot
.36307 .44419 Mdot
.58983 .41236 Mdot
.52732 .38614 Mdot
.5656 .39003 Mdot
.37207 .4541 Mdot
.74472 .73356 Mdot
.56157 .36709 Mdot
.50245 .60358 Mdot
.32713 .40978 Mdot
.41701 .5571 Mdot
.57358 .69206 Mdot
.57834 .32998 Mdot
.39605 .70491 Mdot
.41465 .69122 Mdot
.61714 .72181 Mdot
.3577 .42818 Mdot
.60862 .68883 Mdot
.58265 .32817 Mdot
.50132 .33258 Mdot
.54544 .41503 Mdot
.66612 .72371 Mdot
.32056 .55347 Mdot
.32605 .46709 Mdot
.56965 .70293 Mdot
.54803 .50524 Mdot
.3887 .70158 Mdot
.57244 .64567 Mdot
.38927 .43779 Mdot
.37097 .44023 Mdot
.36926 .46547 Mdot
.75045 .53446 Mdot
.60245 .6933 Mdot
.39193 .45189 Mdot
.38578 .46289 Mdot
.58371 .36314 Mdot
.57527 .3998 Mdot
.30045 .46551 Mdot
.6418 .65288 Mdot
.74039 .53591 Mdot
.59849 .71347 Mdot
.32858 .19279 Mdot
.38439 .68423 Mdot
.38707 .37668 Mdot
.56239 .41117 Mdot
.47942 .90621 Mdot
.52882 .41968 Mdot
.50677 .38154 Mdot
.32158 .48018 Mdot
.76024 .5554 Mdot
.72649 .5428 Mdot
.35976 .4553 Mdot
.37965 .44557 Mdot
.73643 .52085 Mdot
.51404 .54991 Mdot
.39415 .18025 Mdot
.50034 .50484 Mdot
.3323 .47174 Mdot
.28875 .3448 Mdot
.42294 .70359 Mdot
.31219 .41947 Mdot
.39573 .74275 Mdot
.59627 .66315 Mdot
.56716 .66481 Mdot
.42423 .68429 Mdot
.56497 .36976 Mdot
.61942 .71103 Mdot
.61231 .35689 Mdot
.36349 .56405 Mdot
.46125 .64661 Mdot
.63561 .21126 Mdot
.49854 .38453 Mdot
.59971 .28114 Mdot
.34016 .7432 Mdot
.58624 .34318 Mdot
.45291 .3224 Mdot
.71296 .53174 Mdot
.31815 .41412 Mdot
.39054 .71411 Mdot
.23057 .43501 Mdot
.5335 .37336 Mdot
.33811 .47434 Mdot
.38495 .69503 Mdot
.34607 .56095 Mdot
.51481 .59794 Mdot
.58151 .34864 Mdot
.70964 .81489 Mdot
.35628 .48115 Mdot
.57458 .67702 Mdot
.36879 .35783 Mdot
.31138 .42848 Mdot
.54721 .6102 Mdot
.62234 .65625 Mdot
.51768 .49341 Mdot
.37337 .46733 Mdot
.77035 .53382 Mdot
.33912 .43845 Mdot
.75765 .54887 Mdot
.37888 .47377 Mdot
.61114 .67766 Mdot
.52644 .39409 Mdot
.60567 .67371 Mdot
.7207 .51701 Mdot
.6142 .71994 Mdot
.39071 .71418 Mdot
.3941 .54754 Mdot
.41642 .70128 Mdot
.65612 .43631 Mdot
.43663 .23844 Mdot
.41902 .66572 Mdot
.47771 .58097 Mdot
.52377 .35211 Mdot
.32575 .49063 Mdot
.57764 .67261 Mdot
.57163 .71648 Mdot
.57229 .50266 Mdot
.3627 .46732 Mdot
.61779 .6873 Mdot
.29236 .3485 Mdot
.601 .82973 Mdot
.54977 .31099 Mdot
.44388 .80741 Mdot
.35102 .46714 Mdot
.5555 .6776 Mdot
.46703 .48278 Mdot
.34706 .41836 Mdot
.57474 .66167 Mdot
.40996 .6675 Mdot
.39364 .70123 Mdot
.50222 .40001 Mdot
.40828 .72723 Mdot
.56051 .68423 Mdot
.48669 .20065 Mdot
.35333 .43336 Mdot
.30004 .54592 Mdot
.70815 .52931 Mdot
.58614 .66953 Mdot
.49428 .40438 Mdot
.32312 .49953 Mdot
.60201 .65572 Mdot
.24313 .70619 Mdot
.24136 .27707 Mdot
.61845 .68878 Mdot
.34056 .43197 Mdot
.32399 .45076 Mdot
.55959 .32334 Mdot
.55177 .50196 Mdot
.6173 .69727 Mdot
.53842 .73932 Mdot
.67257 .35896 Mdot
.40548 .55205 Mdot
.71107 .26245 Mdot
.56247 .35745 Mdot
.57533 .37142 Mdot
.40413 .65869 Mdot
.51786 .38794 Mdot
.38215 .44664 Mdot
.53065 .42017 Mdot
.43585 .69172 Mdot
.60642 .72455 Mdot
.52926 .37757 Mdot
.71125 .52922 Mdot
.43338 .69312 Mdot
.42812 .66366 Mdot
.60676 .66575 Mdot
.36685 .44036 Mdot
.26281 .66643 Mdot
.59924 .68316 Mdot
.57088 .38492 Mdot
.39489 .56064 Mdot
.52434 .42326 Mdot
.44742 .60728 Mdot
.34732 .41367 Mdot
.57232 .67773 Mdot
.29238 .44375 Mdot
.40176 .68494 Mdot
.56269 .70093 Mdot
.52219 .34767 Mdot
.56634 .67315 Mdot
.50481 .62676 Mdot
.69277 .61759 Mdot
.38526 .45882 Mdot
.53449 .61137 Mdot
.36249 .43052 Mdot
.40764 .55294 Mdot
.72541 .3786 Mdot
.73492 .52998 Mdot
.58288 .70918 Mdot
.30622 .52973 Mdot
.58383 .66452 Mdot
.51859 .37819 Mdot
.54549 .35768 Mdot
.59342 .70587 Mdot
.74803 .53744 Mdot
.73428 .47668 Mdot
.76682 .5188 Mdot
.32198 .43357 Mdot
.52485 .5724 Mdot
.35794 .17518 Mdot
.63464 .72458 Mdot
.42112 .68716 Mdot
.49513 .29152 Mdot
.56594 .33775 Mdot
.38378 .6952 Mdot
.40897 .65142 Mdot
.75556 .52701 Mdot
.58669 .6666 Mdot
.34075 .40967 Mdot
.41028 .71656 Mdot
.32193 .50213 Mdot
.69922 .4509 Mdot
.46928 .40391 Mdot
.62227 .43365 Mdot
.52325 .34074 Mdot
.58685 .50268 Mdot
.43181 .70599 Mdot
.55091 .37439 Mdot
.49191 .43807 Mdot
.3987 .66734 Mdot
.76051 .53421 Mdot
.27559 .45132 Mdot
.61896 .68472 Mdot
.53553 .87755 Mdot
.50104 .38043 Mdot
.52819 .39135 Mdot
.39083 .6729 Mdot
.42804 .35046 Mdot
.32 .46578 Mdot
.36204 .43658 Mdot
.58949 .68832 Mdot
.50443 .52616 Mdot
.49887 .39762 Mdot
.50656 .36433 Mdot
.62155 .70409 Mdot
.39859 .57315 Mdot
.69826 .24387 Mdot
.53991 .36757 Mdot
.40104 .69876 Mdot
.49265 .62772 Mdot
.42847 .71145 Mdot
.60668 .36137 Mdot
.51853 .37203 Mdot
.51815 .34753 Mdot
.49627 .37054 Mdot
.4213 .70133 Mdot
.53203 .33982 Mdot
.48352 .41727 Mdot
.35233 .45344 Mdot
.57064 .36577 Mdot
.67205 .35317 Mdot
.53903 .37125 Mdot
.71055 .53209 Mdot
.46581 .49339 Mdot
.54766 .40251 Mdot
.57168 .36788 Mdot
.67311 .36687 Mdot
.51985 .39742 Mdot
.38478 .6961 Mdot
.32617 .45636 Mdot
.40057 .68386 Mdot
.41796 .68159 Mdot
.59412 .65517 Mdot
.75375 .55665 Mdot
.50646 .34471 Mdot
.74799 .52671 Mdot
.55561 .32049 Mdot
.49248 .33352 Mdot
.64618 .46379 Mdot
.47214 .48876 Mdot
.69775 .53988 Mdot
.51064 .36032 Mdot
.58693 .68165 Mdot
.5709 .67688 Mdot
.53183 .59453 Mdot
.53183 .30583 Mdot
.40331 .72058 Mdot
.42059 .67167 Mdot
.78659 .5453 Mdot
.69031 .60057 Mdot
.72683 .52252 Mdot
.66216 .49199 Mdot
.59478 .39772 Mdot
.56365 .37993 Mdot
.54464 .29733 Mdot
.60928 .65394 Mdot
.39453 .54611 Mdot
.62637 .70704 Mdot
.39679 .59968 Mdot
.42128 .70872 Mdot
.499 .38598 Mdot
.17283 .60756 Mdot
.32181 .43043 Mdot
.32556 .45654 Mdot
.43604 .69167 Mdot
.58193 .7118 Mdot
.52279 .30943 Mdot
.45502 .86259 Mdot
.36736 .42392 Mdot
.70848 .55663 Mdot
.52697 .40194 Mdot
.5978 .66464 Mdot
.33598 .42548 Mdot
.72319 .56793 Mdot
.49866 .36755 Mdot
.61389 .64839 Mdot
.54664 .37814 Mdot
.35766 .28772 Mdot
.35697 .44578 Mdot
.62666 .46575 Mdot
.31482 .48051 Mdot
.41819 .70371 Mdot
.39771 .6752 Mdot
.52106 .37025 Mdot
.49469 .8752 Mdot
.33223 .51035 Mdot
.3997 .64866 Mdot
.73041 .56646 Mdot
.39187 .55335 Mdot
.7373 .5642 Mdot
.58995 .70215 Mdot
.72554 .52584 Mdot
.6001 .65579 Mdot
.63994 .65001 Mdot
.38273 .42097 Mdot
.72448 .55614 Mdot
.46951 .28683 Mdot
.50828 .32501 Mdot
.73304 .5163 Mdot
.55291 .40967 Mdot
.57144 .32115 Mdot
.62358 .69203 Mdot
.74668 .52921 Mdot
.56486 .34291 Mdot
.24637 .52577 Mdot
.40608 .67373 Mdot
.39815 .71933 Mdot
.4993 .33556 Mdot
.55522 .66567 Mdot
.38308 .46177 Mdot
.6236 .49394 Mdot
.41777 .55511 Mdot
.50553 .36661 Mdot
.55129 .3299 Mdot
.34806 .48439 Mdot
.31302 .46665 Mdot
.52037 .36766 Mdot
.2739 .37756 Mdot
.52905 .34306 Mdot
.39164 .69775 Mdot
.32124 .43345 Mdot
.32293 .45244 Mdot
.56054 .67892 Mdot
.35256 .42515 Mdot
.53107 .43528 Mdot
.38525 .64853 Mdot
.48535 .40648 Mdot
.40346 .68813 Mdot
.65273 .6941 Mdot
.6219 .67259 Mdot
.29967 .52797 Mdot
.35185 .42566 Mdot
.59112 .38854 Mdot
.326 .42318 Mdot
.70851 .54518 Mdot
.32393 .46003 Mdot
.34272 .4885 Mdot
.51997 .40885 Mdot
.5455 .34154 Mdot
.39985 .57105 Mdot
.56332 .50132 Mdot
.35207 .44151 Mdot
.59497 .35227 Mdot
.56153 .41437 Mdot
.54386 .35495 Mdot
.64354 .47928 Mdot
.29898 .45868 Mdot
.40842 .40419 Mdot
.42978 .585 Mdot
.35473 .43962 Mdot
.25242 .28208 Mdot
.40555 .57772 Mdot
.40839 .58653 Mdot
.44104 .69317 Mdot
.53713 .36537 Mdot
.60843 .68375 Mdot
.57638 .37501 Mdot
.57281 .29947 Mdot
.54336 .40321 Mdot
.7222 .55748 Mdot
.49912 .4012 Mdot
.40653 .55839 Mdot
.59745 .67714 Mdot
.58984 .34775 Mdot
.52832 .37149 Mdot
.40893 .58421 Mdot
.29905 .46438 Mdot
.36649 .43609 Mdot
.41802 .59145 Mdot
.74722 .52237 Mdot
.43031 .67453 Mdot
.57261 .38333 Mdot
.58858 .68536 Mdot
.60449 .67661 Mdot
.31066 .43369 Mdot
.61644 .70885 Mdot
.43362 .6837 Mdot
.50803 .37664 Mdot
.41883 .70283 Mdot
.72165 .5574 Mdot
.34244 .43197 Mdot
.55757 .40213 Mdot
.58124 .35783 Mdot
.36482 .45429 Mdot
.53669 .34222 Mdot
.71422 .55629 Mdot
.59374 .64889 Mdot
.31982 .4602 Mdot
.41505 .68879 Mdot
.56091 .67208 Mdot
.5898 .37713 Mdot
.19082 .36346 Mdot
.5169 .38667 Mdot
.50584 .36241 Mdot
.37504 .5189 Mdot
.5803 .40703 Mdot
.58721 .66378 Mdot
.33383 .42054 Mdot
.59053 .34121 Mdot
.67487 .3699 Mdot
.7571 .56839 Mdot
.64137 .70143 Mdot
.51565 .39935 Mdot
.22789 .36549 Mdot
.57377 .40685 Mdot
.29325 .52148 Mdot
.64558 .46397 Mdot
.42429 .76369 Mdot
.62208 .43368 Mdot
.40374 .64868 Mdot
.39551 .56819 Mdot
.60508 .66057 Mdot
.41767 .34115 Mdot
.51498 .37263 Mdot
.48571 .2299 Mdot
.56236 .39853 Mdot
.3974 .7018 Mdot
.44279 .34749 Mdot
.60464 .71351 Mdot
.69927 .26033 Mdot
.55951 .36047 Mdot
.35479 .48053 Mdot
.5528 .65982 Mdot
.39669 .57594 Mdot
.55112 .34226 Mdot
.72515 .51993 Mdot
.77855 .55638 Mdot
.53773 .43504 Mdot
.40444 .68581 Mdot
.55967 .37114 Mdot
.6161 .36796 Mdot
.64107 .79095 Mdot
.34824 .46072 Mdot
.41537 .67424 Mdot
.68264 .59026 Mdot
.54191 .35598 Mdot
.37048 .43999 Mdot
.33058 .45779 Mdot
.75613 .53305 Mdot
.42914 .73984 Mdot
.77969 .50913 Mdot
.16305 .53091 Mdot
.53136 .21045 Mdot
.60607 .65164 Mdot
.31414 .39696 Mdot
.57722 .36549 Mdot
.78303 .37988 Mdot
.41855 .68516 Mdot
.52891 .39338 Mdot
.48524 .24322 Mdot
.34179 .46421 Mdot
.54604 .37254 Mdot
.73899 .53549 Mdot
.29606 .71434 Mdot
.31692 .33816 Mdot
.20334 .3941 Mdot
.6037 .6418 Mdot
.48121 .37555 Mdot
.51787 .43119 Mdot
.4152 .55366 Mdot
.59778 .34846 Mdot
.57918 .67264 Mdot
.49734 .64877 Mdot
.74379 .54877 Mdot
.32475 .42731 Mdot
.40188 .5795 Mdot
.56273 .39861 Mdot
.47767 .40835 Mdot
.71811 .56185 Mdot
.54769 .34652 Mdot
.35901 .36214 Mdot
.39392 .58483 Mdot
.56398 .66415 Mdot
.35591 .47899 Mdot
.5324 .33602 Mdot
.39217 .55857 Mdot
.52504 .41116 Mdot
.5639 .2525 Mdot
.54412 .39643 Mdot
.29085 .5075 Mdot
.3676 .45053 Mdot
.40874 .68194 Mdot
.49349 .39332 Mdot
.54023 .38001 Mdot
.63306 .5932 Mdot
.5203 .31156 Mdot
.56039 .39259 Mdot
.31658 .42491 Mdot
.32133 .42996 Mdot
.33156 .47493 Mdot
.56254 .68318 Mdot
.50529 .50368 Mdot
.40948 .70154 Mdot
.54347 .29811 Mdot
.41198 .71657 Mdot
.61121 .44463 Mdot
.73066 .5629 Mdot
.28806 .52693 Mdot
.51196 .36879 Mdot
.36413 .46878 Mdot
.4249 .17526 Mdot
.30027 .45179 Mdot
.36525 .66136 Mdot
.41566 .68262 Mdot
.34802 .44656 Mdot
.51525 .39608 Mdot
.54515 .49931 Mdot
.19376 .41044 Mdot
.39009 .70416 Mdot
.48171 .35631 Mdot
.62972 .65448 Mdot
.61057 .72683 Mdot
.26986 .26855 Mdot
.40194 .71307 Mdot
.34167 .74641 Mdot
.59314 .37254 Mdot
.33722 .42214 Mdot
.4284 .67475 Mdot
.3876 .66374 Mdot
.6171 .71017 Mdot
.58346 .354 Mdot
.54196 .37833 Mdot
.41157 .57121 Mdot
.42649 .69211 Mdot
.62908 .36679 Mdot
.57903 .34524 Mdot
.3706 .56864 Mdot
.38315 .42767 Mdot
.75522 .7235 Mdot
.43645 .41356 Mdot
.4838 .24228 Mdot
.60916 .76851 Mdot
.31709 .45922 Mdot
.566 .36956 Mdot
.52565 .30695 Mdot
.60217 .64782 Mdot
.51001 .38311 Mdot
.57646 .71155 Mdot
.41279 .70986 Mdot
.25271 .50076 Mdot
.47994 .56591 Mdot
.45219 .64838 Mdot
.51965 .38671 Mdot
.311 .34389 Mdot
.72777 .55416 Mdot
.40372 .63599 Mdot
.31352 .46356 Mdot
.60659 .36507 Mdot
.62172 .66135 Mdot
.56488 .68939 Mdot
.33887 .45952 Mdot
.33702 .66446 Mdot
.29262 .52372 Mdot
.50129 .35848 Mdot
.57906 .69665 Mdot
.43834 .50616 Mdot
.26526 .33832 Mdot
.43765 .67601 Mdot
.74206 .55101 Mdot
.59858 .66042 Mdot
.39606 .72457 Mdot
.56426 .31873 Mdot
.34028 .45035 Mdot
.36195 .47977 Mdot
.54051 .60542 Mdot
.61643 .68799 Mdot
.72743 .53533 Mdot
.53079 .60253 Mdot
.52734 .57867 Mdot
.73926 .54468 Mdot
.569 .70673 Mdot
.31188 .44714 Mdot
.34989 .47158 Mdot
.32664 .45572 Mdot
.39453 .37599 Mdot
.35048 .41502 Mdot
.77699 .45839 Mdot
.60001 .35252 Mdot
.27592 .34847 Mdot
.60359 .36967 Mdot
.38788 .70972 Mdot
.35837 .44568 Mdot
.64167 .46343 Mdot
.58176 .40976 Mdot
.20006 .40828 Mdot
.55192 .38705 Mdot
.49617 .61729 Mdot
.53574 .36553 Mdot
.35471 .32975 Mdot
.32077 .41384 Mdot
.51955 .3495 Mdot
.38641 .64571 Mdot
.71233 .53886 Mdot
.39649 .43566 Mdot
.56201 .38854 Mdot
.30548 .64001 Mdot
.55435 .40899 Mdot
.26124 .49294 Mdot
.56507 .61094 Mdot
.71888 .51255 Mdot
.53032 .42513 Mdot
.62958 .67691 Mdot
.54061 .27701 Mdot
.2829 .34409 Mdot
.3913 .70583 Mdot
.30282 .34679 Mdot
.60675 .71669 Mdot
.44198 .34674 Mdot
.60313 .39315 Mdot
.7466 .54482 Mdot
.27761 .45954 Mdot
.38954 .69208 Mdot
.51539 .3671 Mdot
.55947 .36261 Mdot
.46992 .65392 Mdot
.29423 .33037 Mdot
.62672 .32593 Mdot
.70245 .55476 Mdot
.31663 .33249 Mdot
.55384 .39708 Mdot
.64095 .69446 Mdot
.3475 .41961 Mdot
.44788 .34396 Mdot
.43292 .352 Mdot
.5808 .34124 Mdot
.34672 .45066 Mdot
.35874 .42937 Mdot
.4645 .16363 Mdot
.7419 .55594 Mdot
.54662 .39485 Mdot
.54175 .61195 Mdot
.56888 .38902 Mdot
.40339 .70499 Mdot
.59856 .39293 Mdot
.6221 .67545 Mdot
.46076 .47471 Mdot
.56303 .68605 Mdot
.53629 .35116 Mdot
.33827 .43678 Mdot
.38959 .68046 Mdot
.42781 .78201 Mdot
.41493 .74175 Mdot
.77599 .45874 Mdot
.77713 .56368 Mdot
.72232 .52222 Mdot
.74585 .56062 Mdot
.44131 .66919 Mdot
.51123 .39506 Mdot
.58838 .50565 Mdot
.55885 .30966 Mdot
.53828 .36136 Mdot
.54293 .39894 Mdot
.37753 .74764 Mdot
.41433 .68207 Mdot
.60811 .6717 Mdot
.51992 .36706 Mdot
.59574 .35303 Mdot
.34356 .4397 Mdot
.72754 .52323 Mdot
.5791 .65196 Mdot
.71912 .51844 Mdot
.59316 .67849 Mdot
.35127 .19494 Mdot
.4697 .39067 Mdot
.71363 .5421 Mdot
.42962 .70659 Mdot
.34889 .47513 Mdot
.41294 .57793 Mdot
.59356 .70305 Mdot
.60711 .71256 Mdot
.54659 .33484 Mdot
.34542 .42931 Mdot
.35833 .43179 Mdot
.73475 .52061 Mdot
.42048 .66998 Mdot
.53956 .33041 Mdot
.55747 .33937 Mdot
.44548 .78237 Mdot
.59155 .64765 Mdot
.30345 .33878 Mdot
.3523 .51872 Mdot
.50556 .38702 Mdot
.37111 .44223 Mdot
.53156 .38218 Mdot
.444 .52448 Mdot
.32795 .47516 Mdot
.5898 .39968 Mdot
.58972 .31981 Mdot
.60588 .65265 Mdot
.53422 .17134 Mdot
.49859 .34883 Mdot
.37004 .69453 Mdot
.57282 .35631 Mdot
.65214 .18509 Mdot
.44203 .17278 Mdot
.53866 .41351 Mdot
.49655 .38215 Mdot
.16057 .50179 Mdot
.5548 .41584 Mdot
.41026 .56451 Mdot
.57116 .29858 Mdot
.3742 .4466 Mdot
.51501 .61288 Mdot
.5806 .50277 Mdot
.74647 .55524 Mdot
.58853 .68785 Mdot
.7099 .43496 Mdot
.7604 .5433 Mdot
.34731 .46854 Mdot
.47273 .40145 Mdot
.35096 .51767 Mdot
.57727 .72281 Mdot
.61382 .4006 Mdot
.40078 .70438 Mdot
.57891 .50432 Mdot
.62854 .69606 Mdot
.41603 .6889 Mdot
.57377 .40749 Mdot
.66264 .71995 Mdot
.39074 .6385 Mdot
.47855 .15702 Mdot
.40329 .65965 Mdot
.40458 .67674 Mdot
.52247 .49934 Mdot
.74711 .55484 Mdot
.4895 .66144 Mdot
.459 .39734 Mdot
.3855 .69209 Mdot
.70072 .30076 Mdot
.59341 .64472 Mdot
.51138 .52015 Mdot
.31502 .41859 Mdot
.4736 .3733 Mdot
.53162 .39793 Mdot
.40807 .66411 Mdot
.31071 .40085 Mdot
.63806 .58601 Mdot
.40704 .71149 Mdot
.5519 .42941 Mdot
.49424 .51653 Mdot
.39377 .55299 Mdot
.40722 .5783 Mdot
.72149 .56677 Mdot
.71691 .65371 Mdot
.36967 .4534 Mdot
.70655 .55402 Mdot
.63508 .44847 Mdot
.55621 .38189 Mdot
.42475 .69881 Mdot
.40574 .58331 Mdot
.4134 .69086 Mdot
.72632 .54768 Mdot
.72257 .56349 Mdot
.35175 .45488 Mdot
.31599 .46228 Mdot
.25457 .44432 Mdot
.66449 .3061 Mdot
.58005 .38031 Mdot
.45091 .22584 Mdot
.31441 .46723 Mdot
.42169 .35043 Mdot
.7539 .53868 Mdot
.74031 .52732 Mdot
.33286 .27155 Mdot
.58801 .37554 Mdot
.49345 .62598 Mdot
.5512 .40071 Mdot
.73555 .35312 Mdot
.56083 .40086 Mdot
.61921 .70649 Mdot
.55903 .35693 Mdot
.24546 .63815 Mdot
.59302 .35199 Mdot
.54013 .4014 Mdot
.60165 .69885 Mdot
.51965 .33927 Mdot
.62384 .68342 Mdot
.56526 .37263 Mdot
.70389 .57311 Mdot
.589 .68578 Mdot
.68823 .55807 Mdot
.50415 .58241 Mdot
.40506 .56818 Mdot
.74751 .55762 Mdot
.71758 .5218 Mdot
.68521 .46006 Mdot
.3074 .44853 Mdot
.43975 .38273 Mdot
.52554 .40114 Mdot
.56427 .65299 Mdot
.4315 .69437 Mdot
.5783 .33995 Mdot
.52342 .4203 Mdot
.5238 .33571 Mdot
.35057 .45163 Mdot
.55944 .69228 Mdot
.71893 .54417 Mdot
.56972 .67571 Mdot
.69734 .56885 Mdot
.62047 .6676 Mdot
.51323 .32878 Mdot
.55757 .31949 Mdot
.51213 .42919 Mdot
.45884 .25839 Mdot
.82196 .41752 Mdot
.33906 .45482 Mdot
.39639 .55816 Mdot
.72935 .5635 Mdot
.53063 .56311 Mdot
.37107 .45866 Mdot
.60942 .71078 Mdot
.54672 .37842 Mdot
.46888 .40741 Mdot
.47195 .36115 Mdot
.34813 .50539 Mdot
.6878 .53124 Mdot
.59133 .69744 Mdot
.40143 .54871 Mdot
.50189 .5068 Mdot
.40677 .42448 Mdot
.65318 .44283 Mdot
.53598 .38106 Mdot
.73546 .52012 Mdot
.33576 .42549 Mdot
.48539 .64742 Mdot
.40769 .666 Mdot
.55691 .50188 Mdot
.51969 .38855 Mdot
.3457 .69305 Mdot
.33694 .4375 Mdot
.74405 .53594 Mdot
.40689 .66385 Mdot
.74806 .55055 Mdot
.3911 .56783 Mdot
.42233 .55867 Mdot
.5542 .34318 Mdot
.55178 .40161 Mdot
.42412 .70469 Mdot
.36893 .44853 Mdot
.72089 .57676 Mdot
.47399 .66527 Mdot
.59008 .70332 Mdot
.50474 .53703 Mdot
.32786 .42631 Mdot
.36522 .75124 Mdot
.5674 .68498 Mdot
.40701 .72318 Mdot
.59185 .49996 Mdot
.43079 .67081 Mdot
.55008 .39792 Mdot
.32538 .43829 Mdot
.39405 .70994 Mdot
.46059 .76747 Mdot
.23567 .40338 Mdot
.29243 .49378 Mdot
.52753 .3512 Mdot
.27567 .5207 Mdot
.31932 .6866 Mdot
.31905 .39272 Mdot
.41078 .7156 Mdot
.52223 .37813 Mdot
.50297 .35651 Mdot
.55901 .35954 Mdot
.40585 .67131 Mdot
.38957 .76726 Mdot
.58499 .70829 Mdot
.55105 .37194 Mdot
.70744 .53184 Mdot
.61901 .67325 Mdot
.62528 .71933 Mdot
.59617 .6599 Mdot
.31021 .46338 Mdot
.47014 .40063 Mdot
.54359 .29362 Mdot
.50479 .17329 Mdot
.40635 .67891 Mdot
.4051 .56765 Mdot
.50539 .36066 Mdot
.7669 .46177 Mdot
.34746 .47376 Mdot
.60122 .70433 Mdot
.52945 .39218 Mdot
.55321 .60959 Mdot
.38739 .57015 Mdot
.60113 .6903 Mdot
.31871 .46812 Mdot
.33827 .39046 Mdot
.50944 .38051 Mdot
.57664 .36031 Mdot
.3599 .46358 Mdot
.31768 .71727 Mdot
.49689 .50713 Mdot
.531 .37942 Mdot
.4123 .68327 Mdot
.54435 .86457 Mdot
.59099 .39389 Mdot
.29332 .47371 Mdot
.396 .54487 Mdot
.38578 .52532 Mdot
.28591 .36382 Mdot
.55901 .30307 Mdot
.23075 .49129 Mdot
.78104 .48753 Mdot
.2306 .44752 Mdot
.74888 .3725 Mdot
.47156 .67853 Mdot
.41023 .16083 Mdot
.37404 .68526 Mdot
.35343 .31285 Mdot
.22725 .69049 Mdot
.33508 .72928 Mdot
.62538 .60458 Mdot
.47437 .73321 Mdot
.66095 .71257 Mdot
.70388 .25488 Mdot
.63169 .68723 Mdot
.75591 .35926 Mdot
.54836 .40578 Mdot
.31214 .7031 Mdot
.34458 .33154 Mdot
.82879 .47098 Mdot
.30806 .53531 Mdot
.54455 .60889 Mdot
.18415 .39517 Mdot
.33776 .54953 Mdot
.27714 .28735 Mdot
.50988 .26011 Mdot
.74341 .66843 Mdot
.53051 .56981 Mdot
.72494 .44195 Mdot
.3108 .35259 Mdot
.22821 .59829 Mdot
.41665 .62258 Mdot
.41685 .20871 Mdot
.66209 .77095 Mdot
.57716 .68432 Mdot
.35096 .41994 Mdot
.49717 .67816 Mdot
.25773 .32279 Mdot
.36384 .67648 Mdot
.23021 .49041 Mdot
.37028 .53756 Mdot
.35345 .32583 Mdot
.62884 .46256 Mdot
.36243 .28039 Mdot
.77694 .5021 Mdot
.70748 .27039 Mdot
.3551 .49768 Mdot
.48684 .74494 Mdot
.53724 .56016 Mdot
.68058 .48911 Mdot
.36821 .34681 Mdot
.7105 .56599 Mdot
.71614 .57087 Mdot
.32409 .47224 Mdot
.26554 .3289 Mdot
.39324 .58628 Mdot
.63587 .44453 Mdot
.62875 .66976 Mdot
.45053 .53065 Mdot
.29103 .70216 Mdot
.32272 .67253 Mdot
.58022 .18765 Mdot
.20301 .34875 Mdot
.69828 .34623 Mdot
.48319 .63522 Mdot
.36324 .7136 Mdot
.74442 .46074 Mdot
.61588 .2984 Mdot
.68762 .312 Mdot
.55671 .25184 Mdot
.16971 .44555 Mdot
.3269 .627 Mdot
.17812 .38811 Mdot
.36138 .49069 Mdot
.49172 .43573 Mdot
.45978 .59863 Mdot
.53449 .21822 Mdot
.6803 .41359 Mdot
.20259 .36601 Mdot
.74156 .5133 Mdot
.34115 .40588 Mdot
.33661 .72999 Mdot
.35343 .3624 Mdot
.70957 .48794 Mdot
.77406 .57795 Mdot
.44561 .35334 Mdot
.15875 .42857 Mdot
.23154 .49858 Mdot
.38941 .19294 Mdot
.37363 .58029 Mdot
.55912 .71409 Mdot
.62905 .71602 Mdot
.38864 .66045 Mdot
.25222 .31103 Mdot
.32778 .44278 Mdot
.52276 .16547 Mdot
.24613 .44105 Mdot
.54975 .27336 Mdot
.15147 .44153 Mdot
.66862 .24063 Mdot
.2746 .3575 Mdot
.80183 .43349 Mdot
.49261 .84589 Mdot
.63771 .32719 Mdot
.41669 .74419 Mdot
.63972 .67527 Mdot
.27557 .49688 Mdot
.24559 .31921 Mdot
.68999 .28947 Mdot
.17247 .58477 Mdot
.63622 .44148 Mdot
.63558 .74696 Mdot
.36455 .50285 Mdot
.64725 .61448 Mdot
.6651 .50492 Mdot
.18059 .38329 Mdot
.3271 .3305 Mdot
.53357 .85888 Mdot
.73714 .38028 Mdot
.42746 .3565 Mdot
.26458 .53195 Mdot
.61225 .63084 Mdot
.61733 .27624 Mdot
.31644 .64239 Mdot
.47964 .38465 Mdot
.66722 .43782 Mdot
.47749 .29391 Mdot
.75595 .50217 Mdot
.49716 .50068 Mdot
.32607 .60511 Mdot
.71003 .38466 Mdot
.37154 .77374 Mdot
.43491 .3814 Mdot
.32258 .47863 Mdot
.68841 .32218 Mdot
.72126 .35861 Mdot
.36847 .60176 Mdot
.68292 .58925 Mdot
.3789 .19558 Mdot
.66211 .58915 Mdot
.56689 .30306 Mdot
.3536 .30697 Mdot
.31413 .35364 Mdot
.71226 .31876 Mdot
.50241 .33613 Mdot
.55084 .18473 Mdot
.37463 .55768 Mdot
.43768 .2656 Mdot
.69144 .39426 Mdot
.45209 .26095 Mdot
.24096 .36926 Mdot
.45252 .58958 Mdot
.40507 .75288 Mdot
.28871 .41464 Mdot
.16065 .42771 Mdot
.61317 .67129 Mdot
.68657 .29717 Mdot
.37339 .6797 Mdot
.44895 .77498 Mdot
.47855 .6876 Mdot
.64272 .58569 Mdot
.2684 .28381 Mdot
.33275 .68525 Mdot
.5781 .62856 Mdot
.21307 .57943 Mdot
.43318 .49852 Mdot
.4445 .23051 Mdot
.52573 .44798 Mdot
.56034 .25799 Mdot
.71463 .5568 Mdot
.44582 .29928 Mdot
.43558 .58347 Mdot
.79877 .56483 Mdot
.54738 .30594 Mdot
.54075 .5818 Mdot
.40998 .55359 Mdot
.56009 .51318 Mdot
.34891 .19508 Mdot
.52796 .4497 Mdot
.66701 .24339 Mdot
.32894 .69608 Mdot
.57985 .5108 Mdot
.6725 .49922 Mdot
.42609 .43573 Mdot
.17283 .39471 Mdot
.29924 .23993 Mdot
.29662 .66738 Mdot
.26592 .51619 Mdot
.78789 .29823 Mdot
.42409 .7605 Mdot
.58723 .20563 Mdot
.37427 .67215 Mdot
.85293 .66865 Mdot
.56776 .67762 Mdot
.78769 .37724 Mdot
.52639 .22273 Mdot
.59135 .59255 Mdot
.25624 .32786 Mdot
.32596 .36056 Mdot
.68672 .57368 Mdot
.32665 .48594 Mdot
.52163 .31842 Mdot
.21273 .36078 Mdot
.16595 .42439 Mdot
.20976 .3661 Mdot
.3554 .66214 Mdot
.21927 .39332 Mdot
.15504 .48445 Mdot
.77907 .45855 Mdot
.46061 .63648 Mdot
.60709 .38741 Mdot
.65631 .27947 Mdot
.64628 .23347 Mdot
.7333 .50704 Mdot
.63911 .33611 Mdot
.35683 .49795 Mdot
.1499 .47523 Mdot
.35203 .19159 Mdot
.36927 .25739 Mdot
.28815 .27731 Mdot
.51445 .66784 Mdot
.66867 .29717 Mdot
.28547 .2675 Mdot
.22548 .5689 Mdot
.36411 .55394 Mdot
.15163 .50752 Mdot
.72251 .36925 Mdot
.47271 .73764 Mdot
.28012 .64596 Mdot
.62355 .21987 Mdot
.25804 .52624 Mdot
.49615 .68468 Mdot
.59912 .27431 Mdot
.39288 .4743 Mdot
.64503 .58789 Mdot
.22263 .58986 Mdot
.48817 .62807 Mdot
.68542 .37489 Mdot
.60913 .72226 Mdot
.68054 .28798 Mdot
.64092 .51671 Mdot
.46315 .63916 Mdot
.69837 .44268 Mdot
.69656 .28741 Mdot
.29165 .62199 Mdot
.21419 .38115 Mdot
.32999 .69591 Mdot
.48418 .85014 Mdot
.30402 .55821 Mdot
.48606 .28742 Mdot
.51884 .33936 Mdot
.2504 .32713 Mdot
.27771 .23801 Mdot
.27282 .27565 Mdot
.35736 .64589 Mdot
.53379 .65394 Mdot
.40713 .72788 Mdot
.72987 .45666 Mdot
.60535 .58666 Mdot
.33795 .52826 Mdot
.5994 .52948 Mdot
.37659 .68714 Mdot
.29954 .71954 Mdot
.257 .45194 Mdot
.76411 .46337 Mdot
.40061 .21927 Mdot
.63231 .35272 Mdot
.26848 .33665 Mdot
.34958 .48474 Mdot
.34582 .67004 Mdot
.68692 .30776 Mdot
.60899 .66659 Mdot
.45551 .77893 Mdot
.29687 .41177 Mdot
.48749 .43588 Mdot
.51277 .67538 Mdot
.30365 .50359 Mdot
.48106 .24107 Mdot
.5639 .63643 Mdot
.38029 .17602 Mdot
.57108 .19142 Mdot
.28708 .26485 Mdot
.69583 .33244 Mdot
.47206 .76597 Mdot
.53681 .51456 Mdot
.37849 .73111 Mdot
.32139 .54195 Mdot
.52982 .54405 Mdot
.69796 .32509 Mdot
.26639 .35791 Mdot
.4311 .61161 Mdot
.5529 .29939 Mdot
.41562 .17719 Mdot
.75461 .44622 Mdot
.54054 .52204 Mdot
.40929 .4697 Mdot
.36487 .42128 Mdot
.82647 .40787 Mdot
.23978 .61681 Mdot
.54057 .28565 Mdot
.26871 .52409 Mdot
.43715 .66873 Mdot
.33227 .47861 Mdot
.69609 .28166 Mdot
.70029 .61753 Mdot
.25375 .42465 Mdot
.4721 .59442 Mdot
.26337 .31077 Mdot
.4961 .57185 Mdot
.25734 .51116 Mdot
.20787 .46654 Mdot
.56304 .84991 Mdot
.361 .48986 Mdot
.47619 .6342 Mdot
.49789 .66037 Mdot
.37606 .48714 Mdot
.33738 .50337 Mdot
.32107 .33712 Mdot
.23085 .3216 Mdot
.52296 .5984 Mdot
.21712 .56105 Mdot
.58582 .5071 Mdot
.64343 .60629 Mdot
.45195 .61957 Mdot
.70406 .43722 Mdot
.21599 .51477 Mdot
.34008 .24321 Mdot
.37458 .81294 Mdot
.63857 .36835 Mdot
.78147 .36707 Mdot
.73094 .45763 Mdot
.51101 .26145 Mdot
.36772 .34324 Mdot
.35645 .56099 Mdot
.57345 .37601 Mdot
.21018 .33312 Mdot
.3312 .6191 Mdot
.66458 .47414 Mdot
.6428 .64958 Mdot
.58526 .39518 Mdot
.51086 .42721 Mdot
.28022 .27335 Mdot
.38722 .51566 Mdot
.29991 .77377 Mdot
.73997 .37035 Mdot
.52068 .27193 Mdot
.27012 .364 Mdot
.66384 .24311 Mdot
.45618 .57661 Mdot
.24048 .45391 Mdot
.64039 .52395 Mdot
.64444 .2278 Mdot
.20273 .53456 Mdot
.22803 .6156 Mdot
.29653 .54999 Mdot
.15864 .47472 Mdot
.49112 .29682 Mdot
.38848 .59574 Mdot
.50467 .68542 Mdot
.50155 .36898 Mdot
.33709 .6629 Mdot
.29009 .53627 Mdot
.67567 .66005 Mdot
.61399 .29318 Mdot
.27186 .24191 Mdot
.60985 .32607 Mdot
.35446 .63442 Mdot
.28084 .7466 Mdot
.3578 .82763 Mdot
.23927 .63277 Mdot
.18241 .37932 Mdot
.21839 .60091 Mdot
.25358 .51546 Mdot
.44081 .67598 Mdot
.51817 .5656 Mdot
.47352 .22628 Mdot
.23555 .30882 Mdot
.73097 .63836 Mdot
.44098 .73518 Mdot
.45618 .20188 Mdot
.23213 .31009 Mdot
.59464 .31591 Mdot
.81046 .38498 Mdot
.54927 .69829 Mdot
.68957 .23424 Mdot
.59391 .1959 Mdot
.40893 .45789 Mdot
.70754 .30266 Mdot
.78946 .35764 Mdot
.81631 .4722 Mdot
.58117 .19937 Mdot
.60083 .25119 Mdot
.40041 .49583 Mdot
.6905 .33631 Mdot
.28072 .50797 Mdot
.73924 .27244 Mdot
.45525 .61726 Mdot
.38377 .56835 Mdot
.41969 .55203 Mdot
.27475 .49473 Mdot
.2901 .60509 Mdot
.47406 .61488 Mdot
.45647 .48192 Mdot
.25138 .35749 Mdot
.57335 .86961 Mdot
.20487 .59986 Mdot
.26975 .43969 Mdot
.17297 .41839 Mdot
.36523 .57109 Mdot
.54215 .55047 Mdot
.37501 .35353 Mdot
.74311 .45074 Mdot
.56263 .63192 Mdot
.54391 .4034 Mdot
.22717 .3251 Mdot
.56727 .63131 Mdot
.19099 .39383 Mdot
.48687 .15594 Mdot
.30086 .27349 Mdot
.56336 .44451 Mdot
.64266 .68048 Mdot
.66309 .25963 Mdot
.66427 .26524 Mdot
.18048 .44053 Mdot
.76999 .35107 Mdot
.51733 .53914 Mdot
.49128 .59431 Mdot
.4781 .57193 Mdot
.51242 .2931 Mdot
.65763 .23507 Mdot
.42263 .45645 Mdot
.69628 .40439 Mdot
.28453 .65995 Mdot
.69678 .30466 Mdot
.28903 .35822 Mdot
.71889 .45083 Mdot
.65776 .57453 Mdot
.69039 .57425 Mdot
.58551 .64673 Mdot
.1603 .55258 Mdot
.33775 .56863 Mdot
.53981 .18144 Mdot
.48857 .84897 Mdot
.31975 .64271 Mdot
.75498 .35156 Mdot
.41763 .6042 Mdot
.64091 .32243 Mdot
.73883 .65915 Mdot
.71499 .39914 Mdot
.30774 .3408 Mdot
.28749 .5178 Mdot
.41703 .40718 Mdot
.25537 .2953 Mdot
.68643 .38292 Mdot
.19347 .64956 Mdot
.53847 .71342 Mdot
.4471 .29304 Mdot
.29015 .32014 Mdot
.45138 .84205 Mdot
.5463 .52117 Mdot
.15962 .43044 Mdot
.29854 .44903 Mdot
.20149 .35246 Mdot
.40965 .65846 Mdot
.67688 .71947 Mdot
.3566 .54203 Mdot
.66068 .48107 Mdot
.64668 .48696 Mdot
.44681 .16585 Mdot
.3322 .71275 Mdot
.32078 .67725 Mdot
.66282 .59232 Mdot
.62812 .70673 Mdot
.48703 .53295 Mdot
.22048 .55616 Mdot
.16424 .55902 Mdot
.55318 .32767 Mdot
.58951 .74828 Mdot
.68035 .26605 Mdot
.37906 .73297 Mdot
.37549 .54165 Mdot
.32857 .5347 Mdot
.28277 .39326 Mdot
.6666 .29763 Mdot
.15663 .46933 Mdot
.34898 .52728 Mdot
.61048 .57248 Mdot
.44303 .3369 Mdot
.42745 .62031 Mdot
.38746 .78598 Mdot
.22494 .50589 Mdot
.48449 .5805 Mdot
.5012 .51021 Mdot
.70093 .34771 Mdot
.3249 .18911 Mdot
.16828 .43578 Mdot
.42963 .81815 Mdot
.58015 .51321 Mdot
.29297 .45553 Mdot
.72 .42463 Mdot
.18891 .64344 Mdot
.69232 .2322 Mdot
.28972 .64404 Mdot
.69433 .30047 Mdot
.66182 .64714 Mdot
.79608 .37664 Mdot
.53548 .53526 Mdot
.29174 .31843 Mdot
.51043 .21362 Mdot
.4248 .56572 Mdot
.59285 .62606 Mdot
.61125 .49857 Mdot
.46782 .66069 Mdot
.40255 .49235 Mdot
.33351 .71379 Mdot
.19431 .65083 Mdot
.76394 .33774 Mdot
.43907 .35274 Mdot
.20723 .66051 Mdot
.38715 .42758 Mdot
.49843 .6631 Mdot
.41373 .79611 Mdot
.59152 .51057 Mdot
.57519 .66523 Mdot
.61224 .30157 Mdot
.4918 .5193 Mdot
.20791 .57794 Mdot
.66519 .69243 Mdot
.76378 .53515 Mdot
.32127 .49511 Mdot
.78064 .35185 Mdot
.37928 .46778 Mdot
.35526 .17638 Mdot
.2271 .5665 Mdot
.26911 .34905 Mdot
.19402 .53995 Mdot
.50018 .7328 Mdot
.49263 .854 Mdot
.27934 .2853 Mdot
.67433 .37038 Mdot
.32857 .49606 Mdot
.36503 .48241 Mdot
.2042 .52253 Mdot
.35237 .69664 Mdot
.27054 .30917 Mdot
.673 .24689 Mdot
.47531 .76746 Mdot
.37764 .43836 Mdot
.49473 .6009 Mdot
.27404 .4331 Mdot
.36325 .18239 Mdot
.57264 .67175 Mdot
.16034 .41811 Mdot
.43313 .41173 Mdot
.36845 .79006 Mdot
.30468 .51409 Mdot
.46503 .4743 Mdot
.54983 .52617 Mdot
.46945 .75807 Mdot
.5629 .29996 Mdot
.52057 .27298 Mdot
.31204 .4596 Mdot
.47557 .68833 Mdot
.72864 .52454 Mdot
.73508 .59558 Mdot
.37212 .71171 Mdot
.49485 .25997 Mdot
.64258 .21934 Mdot
.35671 .48394 Mdot
.52912 .70073 Mdot
.53216 .72225 Mdot
.58808 .3204 Mdot
.63542 .25687 Mdot
.1597 .52232 Mdot
.2787 .29029 Mdot
.29882 .45347 Mdot
.43485 .82686 Mdot
.78183 .53167 Mdot
.39262 .1736 Mdot
.31506 .38863 Mdot
.67342 .26224 Mdot
.47536 .28875 Mdot
.30377 .24364 Mdot
.28643 .36361 Mdot
.25257 .47602 Mdot
.69014 .3198 Mdot
.6374 .58891 Mdot
.69353 .28558 Mdot
.28193 .39294 Mdot
.48617 .55962 Mdot
.69098 .23923 Mdot
.66072 .6519 Mdot
.3604 .2858 Mdot
.58186 .28666 Mdot
.30106 .51022 Mdot
.65693 .2417 Mdot
.31341 .49204 Mdot
.74229 .57134 Mdot
.42541 .21302 Mdot
.35907 .54816 Mdot
.24994 .31607 Mdot
.36757 .60348 Mdot
.68258 .26309 Mdot
.47695 .56577 Mdot
.75959 .4238 Mdot
.43307 .41472 Mdot
.66038 .42138 Mdot
.50296 .41552 Mdot
.47 .30469 Mdot
.61323 .53178 Mdot
.45862 .17144 Mdot
.51765 .28217 Mdot
.22764 .34217 Mdot
.37311 .18582 Mdot
.22519 .4434 Mdot
.49672 .64289 Mdot
.36717 .43227 Mdot
.16979 .4072 Mdot
.6414 .25299 Mdot
.29265 .51373 Mdot
.59992 .19915 Mdot
.82571 .4022 Mdot
.21801 .68016 Mdot
.34405 .59737 Mdot
.30963 .50774 Mdot
.5322 .17102 Mdot
.33141 .62559 Mdot
.80002 .36874 Mdot
.31219 .33847 Mdot
.37168 .5187 Mdot
.14885 .44835 Mdot
.55237 .22284 Mdot
.31866 .66942 Mdot
.28754 .32932 Mdot
.26645 .40843 Mdot
.63223 .24496 Mdot
.54807 .29544 Mdot
.62712 .67425 Mdot
.57571 .60048 Mdot
.71106 .3098 Mdot
.28863 .39794 Mdot
.66939 .25071 Mdot
.67397 .26737 Mdot
.76233 .36598 Mdot
.47379 .75927 Mdot
.21882 .6806 Mdot
.26311 .37763 Mdot
.48865 .42125 Mdot
.30868 .49069 Mdot
.7552 .55451 Mdot
.73945 .38782 Mdot
.58996 .35092 Mdot
.60206 .48505 Mdot
.45849 .32984 Mdot
.22107 .32205 Mdot
.65746 .60478 Mdot
.42594 .62779 Mdot
.36786 .43025 Mdot
.28015 .50023 Mdot
.44712 .55398 Mdot
.33494 .73084 Mdot
.66252 .25139 Mdot
.25086 .427 Mdot
.23561 .48775 Mdot
.31864 .66064 Mdot
.70008 .36727 Mdot
.78596 .51154 Mdot
.39442 .71349 Mdot
.4819 .23549 Mdot
.18332 .45771 Mdot
.33321 .64853 Mdot
.34398 .40774 Mdot
.27142 .62666 Mdot
.4895 .5613 Mdot
.38779 .61188 Mdot
.3307 .70733 Mdot
.43565 .59878 Mdot
.32159 .268 Mdot
.2125 .48106 Mdot
.62606 .65103 Mdot
.72921 .36204 Mdot
.24451 .61113 Mdot
.66552 .24919 Mdot
.5943 .32333 Mdot
.23666 .34087 Mdot
.65989 .47718 Mdot
.77559 .5199 Mdot
.57147 .34923 Mdot
.55633 .24116 Mdot
.27957 .2732 Mdot
.27103 .64385 Mdot
.6093 .27789 Mdot
.32024 .40779 Mdot
.57117 .18918 Mdot
.552 .63776 Mdot
.55466 .63892 Mdot
.80155 .41356 Mdot
.45096 .45178 Mdot
.60132 .58516 Mdot
.39435 .76124 Mdot
.57879 .30676 Mdot
.79245 .5201 Mdot
.47756 .59163 Mdot
.47563 .23646 Mdot
.58691 .20832 Mdot
.16089 .53841 Mdot
.4668 .58747 Mdot
.58101 .18633 Mdot
.49872 .21483 Mdot
.37295 .51509 Mdot
.77082 .34118 Mdot
.63764 .33566 Mdot
.50621 .33195 Mdot
.74294 .57104 Mdot
.37078 .41692 Mdot
.16442 .51805 Mdot
.58007 .26697 Mdot
.71209 .49642 Mdot
.65957 .53579 Mdot
.464 .6043 Mdot
.62602 .77008 Mdot
.3757 .56014 Mdot
.53427 .17059 Mdot
.68732 .30866 Mdot
.41089 .73813 Mdot
.21107 .5783 Mdot
.62709 .30068 Mdot
.23162 .34336 Mdot
.62063 .54455 Mdot
.26768 .29646 Mdot
.37003 .64005 Mdot
.4759 .25128 Mdot
.39605 .18136 Mdot
.67488 .42801 Mdot
.65598 .42764 Mdot
.4201 .44246 Mdot
.64984 .38271 Mdot
.41265 .57952 Mdot
.68433 .60478 Mdot
.7305 .27517 Mdot
.1754 .6036 Mdot
.35395 .77018 Mdot
.60082 .30759 Mdot
.71788 .41917 Mdot
.20947 .49498 Mdot
.5393 .55427 Mdot
.65591 .51791 Mdot
.50813 .69403 Mdot
.58104 .62613 Mdot
.55064 .86429 Mdot
.21466 .32954 Mdot
.57365 .35121 Mdot
.63782 .50233 Mdot
.78261 .57383 Mdot
.57217 .70751 Mdot
.3877 .22276 Mdot
.16185 .51202 Mdot
.38797 .70335 Mdot
.47028 .82275 Mdot
.40181 .7584 Mdot
.45309 .16687 Mdot
.43463 .80325 Mdot
.40363 .63364 Mdot
.35375 .17651 Mdot
.29768 .66212 Mdot
.40764 .41272 Mdot
.55909 .86392 Mdot
.43149 .17351 Mdot
.4799 .28827 Mdot
.54016 .64358 Mdot
.21905 .33899 Mdot
.54702 .52632 Mdot
.53323 .6437 Mdot
.56001 .2179 Mdot
.69077 .31326 Mdot
.73616 .36808 Mdot
.45137 .6921 Mdot
.48246 .20556 Mdot
.85028 .46678 Mdot
.5029 .73301 Mdot
.44124 .85483 Mdot
.28607 .28657 Mdot
.20244 .44001 Mdot
.23661 .62665 Mdot
.6778 .65277 Mdot
.24567 .33439 Mdot
.67378 .27647 Mdot
.55459 .23445 Mdot
.71211 .63495 Mdot
.67579 .43822 Mdot
.73495 .44063 Mdot
.39052 .61345 Mdot
.2978 .26222 Mdot
.48062 .75255 Mdot
.63596 .29424 Mdot
.68661 .28673 Mdot
.51125 .22082 Mdot
.65689 .42287 Mdot
.18944 .44415 Mdot
.62995 .24822 Mdot
.70347 .33579 Mdot
.48311 .71535 Mdot
.7124 .57065 Mdot
.16927 .50024 Mdot
.42995 .513 Mdot
.46902 .29904 Mdot
.28483 .75233 Mdot
.1808 .38506 Mdot
.63823 .33663 Mdot
.59624 .39562 Mdot
.41502 .15853 Mdot
.54086 .70811 Mdot
.58169 .20637 Mdot
.28424 .68744 Mdot
.74324 .36568 Mdot
.486 .30632 Mdot
.56065 .40306 Mdot
.78423 .43696 Mdot
.37766 .49929 Mdot
.51369 .21689 Mdot
.44033 .79341 Mdot
.69922 .33123 Mdot
.49811 .26259 Mdot
.37327 .81171 Mdot
.30558 .38685 Mdot
.37723 .45819 Mdot
.21947 .3333 Mdot
.40867 .19949 Mdot
.5034 .27429 Mdot
.27833 .32325 Mdot
.61566 .55548 Mdot
.79231 .52279 Mdot
.44081 .38362 Mdot
.53965 .51492 Mdot
.71191 .307 Mdot
.20656 .6624 Mdot
.46448 .22915 Mdot
.15604 .42756 Mdot
.29309 .24735 Mdot
.3799 .44924 Mdot
.54038 .22359 Mdot
.58878 .51531 Mdot
.22601 .45382 Mdot
.45918 .75812 Mdot
.45605 .77419 Mdot
.83992 .46713 Mdot
.75577 .59075 Mdot
.53831 .4124 Mdot
.35526 .6609 Mdot
.25736 .29542 Mdot
.83918 .44893 Mdot
.25077 .30443 Mdot
.47214 .30578 Mdot
.51441 .34178 Mdot
.36549 .83492 Mdot
.25415 .51228 Mdot
.52962 .32792 Mdot
.50359 .30745 Mdot
.51813 .29346 Mdot
.56336 .3909 Mdot
.35244 .70744 Mdot
.74423 .4558 Mdot
.738 .35137 Mdot
.22839 .33305 Mdot
.37762 .43056 Mdot
.55387 .52324 Mdot
.38142 .66022 Mdot
.62463 .48267 Mdot
.59749 .45417 Mdot
.426 .65627 Mdot
.73859 .3405 Mdot
.60129 .76507 Mdot
.69734 .488 Mdot
.30579 .5094 Mdot
.44879 .46174 Mdot
.25207 .44084 Mdot
.75293 .33737 Mdot
.38026 .75345 Mdot
.81627 .47562 Mdot
.68508 .27016 Mdot
.42447 .40034 Mdot
.38135 .59092 Mdot
.79328 .3102 Mdot
.54008 .52539 Mdot
.34925 .68371 Mdot
.62843 .39568 Mdot
.39473 .39871 Mdot
.29677 .28949 Mdot
.78027 .55482 Mdot
.41363 .55498 Mdot
.4476 .33447 Mdot
.2556 .32751 Mdot
.4364 .68862 Mdot
.30463 .2076 Mdot
.61007 .42254 Mdot
.38372 .23144 Mdot
.23078 .39954 Mdot
.47769 .64008 Mdot
.30757 .34389 Mdot
.50105 .41589 Mdot
.59502 .5685 Mdot
.59838 .76235 Mdot
.28031 .45639 Mdot
.45075 .62093 Mdot
.22028 .47394 Mdot
.77619 .36465 Mdot
.34485 .24644 Mdot
.54639 .39351 Mdot
.75008 .51948 Mdot
.5536 .50926 Mdot
.67743 .64069 Mdot
.63376 .74714 Mdot
.3672 .55516 Mdot
.75116 .33941 Mdot
.73973 .37132 Mdot
.29633 .33047 Mdot
.1948 .38002 Mdot
.57849 .28432 Mdot
.29496 .28157 Mdot
.64885 .56471 Mdot
.29801 .60518 Mdot
.63776 .25934 Mdot
.20359 .65439 Mdot
.49735 .28892 Mdot
.56269 .28932 Mdot
.30992 .21884 Mdot
.28222 .27904 Mdot
.46064 .67049 Mdot
.27773 .51225 Mdot
.71816 .26755 Mdot
.64747 .48754 Mdot
.56262 .86742 Mdot
.45278 .76508 Mdot
.33429 .19245 Mdot
.44765 .62774 Mdot
.62253 .4014 Mdot
.42467 .43776 Mdot
.52663 .31557 Mdot
.6061 .68548 Mdot
.219 .44753 Mdot
.4179 .44732 Mdot
.64435 .40805 Mdot
.49441 .42153 Mdot
.5245 .63957 Mdot
.29846 .48488 Mdot
.17747 .61261 Mdot
.60273 .72811 Mdot
.6109 .56934 Mdot
.33405 .76956 Mdot
.60079 .76352 Mdot
.81813 .38514 Mdot
.17976 .43566 Mdot
.32229 .54096 Mdot
.47978 .58849 Mdot
.63332 .79623 Mdot
.29476 .46283 Mdot
.33534 .50669 Mdot
.37737 .72498 Mdot
.76589 .42936 Mdot
.34898 .64424 Mdot
.24443 .70702 Mdot
.30548 .23966 Mdot
.59303 .32311 Mdot
.56939 .88431 Mdot
.68458 .2774 Mdot
.59269 .54015 Mdot
.34694 .65175 Mdot
.23338 .32109 Mdot
.64154 .64709 Mdot
.48009 .15735 Mdot
.22918 .59548 Mdot
.30114 .392 Mdot
.75805 .44166 Mdot
.43717 .82644 Mdot
.49089 .60733 Mdot
.44392 .85551 Mdot
.27324 .53391 Mdot
.72409 .44141 Mdot
.26538 .64081 Mdot
.34667 .49464 Mdot
.5234 .2736 Mdot
.23001 .55978 Mdot
.62891 .31872 Mdot
.32995 .39495 Mdot
.23187 .49608 Mdot
.76666 .49124 Mdot
.46281 .73013 Mdot
.25566 .5055 Mdot
.3681 .71864 Mdot
.41412 .44153 Mdot
.71392 .27924 Mdot
.57935 .74241 Mdot
.60305 .72194 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`0008[ooooo1?l0002looooo`007?ooool00ol0003oooooooooo`29ooooo`Co00000_ooool2
o`0000Wooooo0_l0002]ooooo`007?ooool00ol0003oooooooooo`23ooooo`;o00002_ooool2o`00
00Oooooo1?l0002]ooooo`007?ooool00ol0003oooooooooo`22ooooo`?o00004oooool2o`000:oo
oooo000Looooo`03o`000?oooooooooo08;ooooo0_l00009ooooo`;o00001?ooool2o`00017ooooo
0_l0002Qooooo`007?ooool00ol0003oooooooooo`2=ooooo`Co00000_ooool2o`00017ooooo0_l0
002Qooooo`007?ooool00ol0003oooooooooo`2?ooooo`Go00005Oooool3o`0009gooooo000Loooo
o`03o`000?oooooooooo077ooooo0_l00009ooooo`;o00002?ooool4o`0000;ooooo0_l00003oooo
o`?o00002oooool5o`0000Gooooo0ol0002Mooooo`007?ooool00ol0003oooooooooo`1_ooooo`Co
00000oooool4o`0000;ooooo0_l00002ooooo`Go000000?oooooo`000?l000000_l00002ooooo`;o
00004Oooool5o`0000?ooooo0_l0002Pooooo`007?ooool00ol0003oooooooooo`1_ooooo`?o0000
1?ooool4o`0000;ooooo0ol000000ooooooo0000o`000003o`0002;ooooo0ol00002ooooo`;o0000
Voooool001cooooo00?o0000ooooooooool0L_ooool2o`0000Sooooo0ol00004ooooo`;o00008ooo
ool2o`0000;ooooo0_l0002Kooooo`007?ooool00ol0003oooooooooo`1booooo`;o000000?ooooo
o`000?l00000=Oooool2o`000003ooooool0003o000000Sooooo0_l0000Eooooo`;o0000Moooool0
01cooooo00?o0000ooooooooool0I_ooool2o`0000gooooo0_l0000hooooo`;o00001Oooool2o`00
0003ooooool0003o000001Gooooo0_l0001gooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5
ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0I_ooool5o`0000Cooooo0ol00009
ooooo`;o00006oooool2o`0001cooooo0_l0002Aooooo`0000KoooooogMgMonHV9SooooooiRHV?mg
MgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0
Ioooool4o`0000?ooooo1?l00005ooooo`;o00000_ooool2o`0001_ooooo0_l00002ooooo`;o0000
5Oooool2o`000003ooooool0003o000000Gooooo0ol00029ooooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0K?oo
ool4o`0000Oooooo0_l00002ooooo`;o00001?ooool2o`0000cooooo0_l0000;ooooo`;o00005Ooo
ool2o`0000;ooooo1?l00002ooooo`Co00004oooool2o`0007?ooooo00000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`00063ooooo0_l0000:
ooooo`;o00003Oooool2o`0000?ooooo0ol0000<ooooo`?o00001Oooool5o`0001Sooooo1ol00004
ooooo`;o00004oooool4o`00077ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`1Pooooo`;o00007_ooool3o`00
00_ooooo1?l00005ooooo`Ko00001oooool2o`0000?ooooo0_l00009ooooo`Co000000?oooooo`00
0?l000000_l0000Iooooo`;o0000LOooool00003ooooool@413ooooo00;ooooo00?o410@oooooooo
ool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05oooooo0_l0000Eooooo`;o
00003?ooool2o`0000Sooooo0_l00007ooooo`Ko000000?oooooo`000?l000001?ooool2o`0000;o
oooo0ol0000>ooooo`Co0000S?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0
003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0Goooool2o`0001Gooooo0_l0000<
ooooo`;o00004Oooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000004
ooooo`Co00003_ooool4o`0000kooooo0_l0001looooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`20ooooo`;o0000
1?ooool3o`00017ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00000oooool4o`00023o
oooo0_l0001looooo`007?ooool00ol0003oooooooooo`20ooooo`;o00001?ooool3o`0001Gooooo
0_l00002ooooo`?o00001Oooool2o`0000Kooooo0_l0002Eooooo`007?ooool00ol0003ooooooooo
o`1Qooooo`;o00006oooool2o`0002;ooooo0ol00005ooooo`;o00001_ooool2o`0001?ooooo0_l0
0004ooooo`;o00003?ooool2o`0006cooooo000Looooo`03o`000?oooooooooo067ooooo0_l0000G
ooooo`;o00000_ooool2o`0002;ooooo0_l00003ooooo`Oo00000_ooool4o`0000Sooooo0_l00009
ooooo`;o00001?ooool2o`0000_ooooo0ol0001/ooooo`007?ooool00ol0003oooooooooo`1joooo
o`;o00004oooool4o`000003ooooool0003o000000;o00003oooool7o`0000;ooooo0_l0000:oooo
o`;o00007?ooool2o`0006gooooo000Looooo`03o`000?oooooooooo08gooooo2ol00002ooooo`;o
00003Oooool2o`0002?ooooo0_l0000<ooooo`;o0000Joooool001cooooo00?o0000ooooooooool0
NOooool2o`0000oooooo0_l000000ooooooo0000o`000004ooooo`;o00001Oooool3o`0001Wooooo
0_l0000Fooooo`;o00003?ooool3o`0006[ooooo000Looooo`03o`000?oooooooooo07Wooooo0_l0
000?ooooo`;o00002oooool6o`0001?ooooo0_l00002ooooo`Co00005_ooool2o`0000;ooooo0_l0
0008ooooo`?o0000J_ooool001cooooo00?o0000ooooooooool0E_ooool2o`0000Gooooo0_l00000
0ooooooo0000o`00000Xooooo`;o00002oooool5o`0001Cooooo0_l00002ooooo`;o00007?ooool2
o`0000Sooooo0ol0001Zooooo`007?ooool00ol0003oooooooooo`1Eooooo`?o00001?ooool3o`00
0003ooooool0003o000002Sooooo0_l0000=ooooo`;o00005_ooool2o`0001oooooo1Ol00006oooo
o`;o0000J_ooool001cooooo00?o0000ooooooooool0EOooool2o`0000Gooooo0_l000000ooooooo
0000o`00000:ooooo`;o0000;?ooool3o`0001Gooooo0_l00006ooooo`;o00003oooool2o`0000Ko
oooo1Ol000000ooooooo0000o`000005ooooo`;o0000J?ooool001cooooo00?o0000ooooooooool0
Foooool2o`0000;ooooo0_l0000:ooooo`?o0000;?ooool2o`0001gooooo0_l0000=ooooo`Co0000
2?ooool7o`0000Cooooo0_l0001Xooooo`007?ooool2o`0005cooooo0_l0000>ooooo`?o00002Ooo
ool2o`0001kooooo0_l0000Gooooo`?o00003?ooool2o`0000Oooooo0ol00006ooooo`[o0000K_oo
ool001cooooo00?o0000ooooooooool0M_ooool3o`0001kooooo0_l0000Gooooo`Go00002_ooool3
o`0000Wooooo1?l00002ooooo`Co000000?oooooo`000?l000002Oooool2o`0006Kooooo000Loooo
o`03o`000?oooooooooo06Wooooo0_l00009ooooo`Co00006?ooool3o`00013ooooo0_l0000=oooo
o`?o00002oooool2o`0000Wooooo1Ol0000?ooooo`Co0000I_ooool001cooooo00?o0000oooooooo
ool0JOooool2o`0000Wooooo0_l0000Hooooo`Go00002_ooool2o`0000?ooooo0ol0000=ooooo`;o
00005oooool2o`000003ooooool0003o000000Cooooo0_l00009ooooo`;o00000_ooool2o`0006Co
oooo000Looooo`03o`000?oooooooooo05gooooo0_l0000/ooooo`;o000000Coooooo`000?l0003o
00003?ooool3o`0000;ooooo0_l0000Wooooo`Co000000?oooooo`000?l000000_ooool2o`000004
ooooool0003o0000ooooo`?o00000_ooool2o`0000;ooooo0ol0001Sooooo`007?ooool00ol0003o
ooooooooo`1Iooooo`?o000000?oooooo`000?l00000:oooool3o`00017ooooo0_l0000Iooooo`;o
00004_ooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000004o`0000Ko
oooo1Ol0001Qooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o00000oooool3o`0000Wooooo
0_l0000:ooooo`;o00005oooool2o`0001Kooooo0_l0000Eooooo`;o00000oooool2o`0001Cooooo
0_l000000ooooooo0000o`000005o`0000Cooooo0_l000001?oooooo0000o`000?l0001Qooooo`00
7?ooool00ol0003oooooooooo`1Dooooo`;o000000?oooooo`000?l000001Oooool2o`0000Gooooo
0_l000000ooooooo0000o`000007ooooo`;o00008Oooool2o`0000cooooo0_l000001Ooooooo0000
o`000?l0003ooooo00?o00000oooool3o`0000[ooooo1?l0000Kooooo`Co00000oooool2o`0000Co
oooo0_l00002ooooo`;o0000Foooool001cooooo00?o0000ooooooooool0EOooool4o`0000Gooooo
0_l00008ooooo`;o00001oooool2o`00027ooooo0_l0000:ooooo`;o00000oooool3o`000003oooo
ool0003o000000?o000000Coooooo`000?l0003o00000_ooool4o`0000Cooooo0_l000000ooooooo
0000o`000004ooooo`;o00001oooool2o`0000Oooooo0_l00004ooooo`;o00002Oooool3o`000003
ooooool0003o000005_ooooo000Looooo`03o`000?oooooooooo04_ooooo0_l00008ooooo`;o0000
00?oooooo`000?l000000_l0000Eooooo`;o00009?ooool2o`0000Oooooo0_l00003ooooo`?o0000
1?ooool2o`0000Kooooo1?l00003ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o
00001oooool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o000000?oooooo`000?l0
00001?ooool2o`0000?ooooo0_l00009ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0
Boooool2o`000003ooooool0003o000000Sooooo1_l0000Dooooo`;o00008oooool2o`0000_ooooo
1?l0000<ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000;ooooo1Ol0000;ooooo`Go
00001oooool2o`000003ooooool0003o000000Cooooo0_l0000>ooooo`;o0000Doooool001cooooo
00?o0000ooooooooool0C_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0001?ooooo
0ol0000Pooooo`;o00003_ooool2o`0000Kooooo1?l00007ooooo`Co00000oooool5o`0000cooooo
0_l000000ooooooo0000o`000009ooooo`?o000000?oooooo`000?l00000I_ooool001cooooo00?o
0000ooooooooool0Doooool2o`000003ooooool0003o000000?o00003_ooool2o`0000Gooooo0ol0
000Qooooo`So00000_ooool2o`0000_ooooo1Ol00003ooooo`;o00000oooool3o`0000?ooooo0_l0
00000ooooooo0000o`00000Fooooo`Oo000000?oooooo`000?l000004_ooool2o`0005;ooooo000L
ooooo`03o`000?oooooooooo05Kooooo1Ol00002ooooo`;o00002_ooool2o`0000Gooooo0_l0000R
ooooo`So000000Coooooo`000?l0003o00001oooool2o`0000;ooooo0_l00006ooooo`?o00000ooo
ool2o`0001kooooo1ol0000Eooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0A?ooool2
o`0000Wooooo0ol00005ooooo`;o00001?ooool2o`0000Gooooo0_l0000Wooooo`;o00001Oooool2
o`000003ooooool0003o000000Cooooo0_l00004ooooo`Ko00000oooool6o`0000;ooooo1?l00004
ooooo`;o000000?oooooo`000?l000000oooool2o`0000Gooooo0_l00004ooooo`;o00002Oooool2
o`0006_ooooo000Looooo`03o`000?oooooooooo04Cooooo0_l00009ooooo`?o000000?oooooo`00
0?l000003_ooool4o`0002Kooooo0_l00005ooooo`;o000000?oooooo`000?l000000oooool2o`00
00Cooooo1Ol00004ooooo`Wo000000Coooooo`000?l0003o00001?ooool2o`000003ooooool0003o
000000?ooooo0_l00005ooooo`;o00001?ooool2o`0000;ooooo0ol00003ooooo`;o00001?ooool2
o`0001Wooooo0_l0001;ooooo`007?ooool2o`0005Cooooo0_l0000>ooooo`Co00001?ooool2o`00
023ooooo0ol00004ooooo`?o00000oooool4o`0000Cooooo0_l00007ooooo`Co000000?oooooo`00
0?l000001_l0000:ooooo`Co00000_ooool2o`0000[ooooo1?l00003ooooo`;o000000?oooooo`00
0?l000000ol0000Iooooo`;o0000Boooool001cooooo00?o0000ooooooooool0C_ooool2o`0001Go
oooo0_l00004ooooo`;o00008?ooool3o`0000Gooooo0_l00003ooooo`;o00001Oooool2o`0000Go
oooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000_o00001Oooool3o`0000?o
oooo0_l0000:ooooo`;o00002?ooool6o`0006Gooooo000Looooo`03o`000?oooooooooo04kooooo
0_l0000Eooooo`;o000000?oooooo`000?l000001Oooool2o`0002Cooooo0ol00002ooooo`;o0000
1?ooool3o`0000Cooooo1?l00002ooooo`Wo00000_ooool9o`0001;ooooo0ol00005ooooo`;o0000
0_ooool6o`0006Cooooo000Looooo`03o`000?oooooooooo04Sooooo0ol00007ooooo`Co00004_oo
ool2o`0000Cooooo0ol0000Uooooo`;o00000_ooool2o`0000Cooooo0_l00004ooooo`Go00000ooo
ool2o`0000;ooooo0_l00004ooooo`;o00000oooool4o`0001;ooooo0ol00002ooooo`;o000000?o
ooooo`000?l000000oooool2o`000003ooooool0003o000001Wooooo0_l00019ooooo`007?ooool0
0ol0003oooooooooo`18ooooo`?o00000oooool2o`0000;ooooo1?l0000Eooooo`;o000000Cooooo
o`000?l0003o0000=?ooool5o`0000Cooooo0ol000001?oooooo0000o`000?l00009ooooo`;o0000
6?ooool2o`000003ooooool0003o000000Go000000?oooooo`000?l000006Oooool2o`0004Wooooo
000Looooo`03o`000?oooooooooo04gooooo0ol0000Booooo`;o00001oooool2o`0000;ooooo0_l0
000cooooo`Go00001?ooool4o`000003ooooool0003o000000;o00001oooool3o`0001cooooo1ol0
001Vooooo`007?ooool00ol0003oooooooooo`1<ooooo`?o00003?ooool2o`0000Gooooo0_l0000Y
ooooo`;o00005Oooool5o`0000?ooooo2_l00002ooooo`;o00000_ooool3o`0000[ooooo0_l0000A
ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`00001Sooooo`007?ooool00ol0
003oooooooooo`14ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0000;ooooo0_l00005
ooooo`;o00000_ooool2o`0000cooooo0_l0000Rooooo`Co00003oooool2o`0000Cooooo0_l00004
ooooo`;o000000?oooooo`000?l000002Ol000000ooooooo0000o`000003o`0000Wooooo1Ol00007
ooooo`;o00001Oooool2o`000003ooooool0003o000000?ooooo0_l0000Jooooo`;o0000Aoooool0
01cooooo00?o0000ooooooooool0A?ooool6o`0000Kooooo0_l00005ooooo`;o00002?ooool2o`00
00?ooooo0_l000000ooooooo0000o`000004ooooo`;o00007Oooool3o`0000_ooooo0_l000000ooo
oooo0000o`000003o`0000[ooooo0_l000001?oooooo0000o`000?l00002ooooo`[o00000_ooool4
o`0000;ooooo1_l00007ooooo`;o00001Oooool2o`000003ooooool0003o000001oooooo0_l00017
ooooo`007?ooool00ol0003oooooooooo`16ooooo`;o00001_ooool4o`000003ooooool0003o0000
00Gooooo0_l00005ooooo`;o00000oooool2o`000003ooooool0003o000000Cooooo0_l0000Moooo
o`;o00003?ooool2o`000003ooooool0003o000000Co00000oooool2o`0000;ooooo2Ol00002oooo
o`Go000000?oooooo`000?l000000oooool4o`0000;ooooo0_l000001?oooooo0000o`000?ooool2
o`0000oooooo0_l00006ooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0@_ooool2o`00
00[ooooo1?l000000ooooooo0000o`000005ooooo`Go00001?ooool3o`000003ooooool0003o0000
00?ooooo0_l000000ooooooo0000o`00000Pooooo`;o00003?ooool6o`0000?ooooo0_l000000ooo
oooo0000o`00000?o`0000oooooo0_l000000ooooooo0000o`00000>ooooo`?o00001_ooool2o`00
063ooooo000Looooo`03o`000?oooooooooo047ooooo1ol00004ooooo`;o00001_ooool2o`0000Ko
oooo0ol00004ooooo`Ko00000oooool2o`000003ooooool0003o000001Sooooo0_l00003ooooo`;o
000000?oooooo`000?l000002Oooool7o`000003ooooool0003o000000;ooooo0_l000001?oooooo
0000o`000?ooool?o`0000Sooooo0_l00002ooooo`;o00003?ooool2o`0000Gooooo0ol0001Xoooo
o`007?ooool00ol0003oooooooooo`11ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o
00001?ooool4o`0000cooooo1Ol0000Rooooo`Oo00002oooool6o`0000?ooooo1ol00003ooooo`_o
000000?oooooo`000?l000000_l00006ooooo`?o00000_ooool5o`0000Sooooo0ol00003ooooo`;o
00000oooool2o`0000kooooo0_l000000ooooooo0000o`00001Cooooo`007?ooool00ol0003ooooo
ooooo`13ooooo`;o00001?ooool2o`0000Oooooo0ol0000:ooooo`So00003Oooool2o`0000kooooo
0_l00004ooooo`Go00003?ooool6o`0000?ooooo5ol000000ooooooo0000o`000006ooooo`;o0000
0oooool5o`0000;ooooo0_l00004ooooo`;o00001?ooool2o`0000?ooooo0_l00009ooooo`;o0000
0_ooool3o`000004ooooool0003o0000ooooo`;o0000D?ooool001cooooo00?o0000ooooooooool0
@oooool2o`000003ooooool0003o000000?o00001oooool2o`0000Cooooo1?l00003ooooo`Go0000
4?ooool2o`0000kooooo0_l00003ooooo`Oo00000_ooool2o`0000Sooooo0ol00002oooooago0000
2oooool2o`0000Gooooo0_l0000Jooooo`;o00000_ooool2o`0000Gooooo0_l0001@ooooo`007?oo
ool00ol0003oooooooooo`16ooooo`Co00002_ooool2o`0000;ooooo1?l00003ooooo`Go00004?oo
ool2o`0001?ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00007ooooo`?o00000ooo
oolMo`000004ooooool0003o0000o`0000cooooo0_l00007ooooo`;o00001_ooool3o`0006Oooooo
000Looooo`;o0000?oooool2o`0001Cooooo1?l000000ooooooo0000o`000007o`0001;ooooo0_l0
000=ooooo`Ko00000oooool3o`0000_ooooo1_l000000ooooooo0000o`00000Oo`0000Cooooo0_l0
0006ooooo`;o00001_ooool4o`0000Gooooo0ol0001Wooooo`007?ooool00ol0003oooooooooo`0n
ooooo`;o00003?ooool2o`0000Kooooo1?l000000ooooooo0000o`000004o`0000;ooooo0ol00007
ooooo`;o00002Oooool2o`0000_ooooo3?l0000;ooooo`Oo000000?oooooo`000?l000008?l00002
ooooo`;o00000_ooool2o`0000[ooooo1?l0000Aooooo`?o00000oooool2o`0000?ooooo0_l00002
ooooo`;o0000COooool001cooooo00?o0000ooooooooool0?_ooool2o`0000cooooo0_l00008oooo
o`;o000000Coooooo`000?l0003o00001Oooool3o`0000Oooooo0_l00009ooooo`;o00003oooool8
o`0000Wooooo0ol00004oooooa[o000000?oooooo`000?l000002Ol00005ooooo`;o00000_ooool2
o`0000Oooooo0_l0000Booooo`?o00000oooool2o`0000?ooooo0_l00002ooooo`;o0000COooool0
01cooooo00?o0000ooooooooool0C_ooool2o`0000?ooooo1Ol00002ooooo`;o00001Oooool2o`00
017ooooo0_l0000=ooooo`;o00000_ooool2o`0000gooooo1ol00002oooooa7o00000_ooool3o`00
0003ooooool0003o000000Wo00000_ooool2o`0000Sooooo0ol00007ooooo`;o00003Oooool2o`00
00[ooooo0_l00007ooooo`Co0000B_ooool001cooooo00?o0000ooooooooool0@Oooool2o`0000_o
oooo0_l000000ooooooo0000o`000005o`000004ooooool0003o0000o`0000[ooooo0_l00007oooo
o`Co000000?oooooo`000?l000003Oooool2o`000003ooooool0003o000000?o00002oooool4o`00
0003ooooool0003o000002So00002?ooool2o`0000Sooooo0_l0000=ooooo`;o000000Coooooo`00
0?l0003ooooo0_l00004ooooo`;o00001oooool4o`0004[ooooo000Looooo`03o`000?oooooooooo
03[ooooo0_l00002ooooo`Go00000oooool3o`0000Sooooo0_l000000ooooooo0000o`000002o`00
0003ooooool0003o000000_ooooo0_l00007ooooo`Co00004oooool5o`0000_ooooo0ol000000ooo
oooo0000o`00000:o`000003ooooool0003o000001Ko00000_ooool2o`0002Kooooo0_l000000ooo
oooo0000o`000002o`0000Cooooo0_l00002ooooo`;o0000Coooool001cooooo00?o0000oooooooo
ool0>_ooool2o`0000;ooooo1?l00004ooooo`?o00000_ooool2o`0000Oooooo0_l00003ooooo`;o
0000;_ooool2o`0000cooooo0_l000000ooooooo0000o`00000Zo`0000?ooooo1Ol00009ooooo`;o
00001oooool2o`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l000001?ooool2o`0000;o
oooo1?l00004ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0Boooool2o`0002;ooooo
0_l0000Hooooo`;o00003?ooool5o`000003ooooool0003o000002?o000000Coooooo`000?l0003o
00000oooool5o`0000Wooooo0_l00007ooooo`;o00001Oooool2o`0000;ooooo1_l00009ooooo`;o
00001?ooool2o`0004Oooooo000Looooo`03o`000?oooooooooo05oooooo0ol0000=ooooo`;o0000
3?ooool2o`0000gooooo0_l00008ooooo`Go00000_oooolMo`000003ooooool0003o000000;o0000
00?oooooo`000?l000000ol0000Aooooo`?o00000_ooool3o`0000kooooo1Ol0001Hooooo`007?oo
ool00ol0003oooooooooo`14ooooo`;o00003?ooool2o`000003ooooool0003o000000Sooooo0ol0
0004ooooo`;o00001?ooool2o`0000[ooooo1ol00009ooooo`;o00000_ooool2o`0000Sooooo1Ol0
0003ooooob7o000000Coooooo`000?l0003o00004oooool3o`0000;ooooo0ol0000:ooooo`;o0000
4_ooool2o`000003ooooool0003o000004Sooooo000Looooo`03o`000?oooooooooo03Sooooo0_l0
0002ooooo`;o00001?ooool4o`0000cooooo0_l000000ooooooo0000o`000006ooooo`;o00001ooo
ool2o`0000Cooooo0_l0000:ooooo`Ko00002_ooool4o`0000[ooooo0_l00005ooooobSo00004_oo
ool2o`0000oooooo0ol000000ooooooo0000o`00000<ooooo`Co000000?oooooo`000?l00000B?oo
ool001cooooo00?o0000ooooooooool0=oooool3o`0000;ooooo0_l00002ooooo`Co00002oooool2
o`0000Sooooo0_l00002ooooo`;o0000:oooool3o`0000_ooooo0_l00002ooooobWo00002_ooool2
o`0000Gooooo0_l00003ooooo`;o00001_ooool2o`0000Cooooo0_l000000ooooooo0000o`00000<
ooooo`Co0000Boooool001cooooo00?o0000ooooooooool0=oooool2o`0000Oooooo0_l0000=oooo
o`;o00002?ooool2o`0000Gooooo0_l0000Rooooo`Co00000oooool2o`0000Gooooo0_l00004oooo
obco00000_ooool4o`0000Gooooo0_l00005ooooo`;o000000?oooooo`000?l000000_l00006oooo
o`;o00001?ooool2o`000003ooooool0003o000000cooooo0_l00007ooooo`;o000000?oooooo`00
0?l00000@Oooool001cooooo00?o0000ooooooooool0=Oooool4o`00017ooooo0_l0000Dooooo`;o
000000?oooooo`000?l000001?ooool3o`0000gooooo0_l00008ooooo`Go00002_ooool2o`000003
ooooool0003o000000?ooooo0_l00002ooooob;o000000?oooooo`000?l000000_l000000ooooooo
0000o`000002o`0000cooooo0_l000000ooooooo0000o`00000>ooooo`Go00005Oooool2o`000003
ooooool0003o0000047ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0eooooo`?o00000_ooool2o`00
00;ooooo0_l00004ooooo`;o00001?ooool2o`0000cooooo1?l00002ooooo`;o00000oooool3o`00
00?ooooo0ol00007ooooo`;o00001?ooool2o`000003ooooool0003o000000Gooooo0_l0000@oooo
o`;o00000ooooolMo`000004ooooool0003o0000ooooo`Oo000000?oooooo`000?l000000oooool2
o`0000cooooo0_l00002ooooo`;o00002?ooool2o`0000Gooooo0ol0001Kooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo03Cooooo0_l00002ooooo`Co00000_ooool2o`0000Cooooo0_l00002ooooo`Co00003?oo
ool4o`0000;ooooo0_l00002ooooo`Co000000?oooooo`000?l000001?ooool2o`0000Cooooo0_l0
0007ooooo`;o00005oooool3o`0000;ooooo7?l00002ooooo`[o00000oooool2o`000003ooooool0
003o000000;ooooo0_l00008ooooo`;o00000_ooool2o`000003ooooool0003o000000Gooooo0_l0
0006ooooo`Co0000FOooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool5
o`0000Kooooo00?o0000ooooooooool0<_ooool4o`0000;ooooo0_l0000=ooooo`Go00001?ooool2
o`0000Sooooo0_l00006ooooo`?o00000_ooool2o`0000Cooooo0_l00005ooooo`;o00001_ooool2
o`0000Gooooo0_l0000<ooooo`;o00000_ooool4o`0000;ooooo0_l000000ooooooo0000o`00000R
o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o00003?ooool2o`000003ooooool0003o
000000Gooooo0_l00008ooooo`;o00004oooool2o`0004Cooooo00000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`0003;ooooo0_l0000@
ooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o00000_ooool2o`0000Cooooo0_l0
0005ooooo`Co00001Oooool2o`000003ooooool0003o000000Gooooo0_l00005ooooo`?o00000_oo
ool5o`000003ooooool0003o000000;ooooo0_l00005ooooo`;o00000_ooool4o`000005ooooool0
003o0000o`000?ooool08Ol000000ooooooo0000o`000002ooooo`Co00001?ooool2o`0000Sooooo
0_l0000<ooooo`;o00007?ooool3o`0000?ooooo0_l0000oooooo`0000?oooooo`000?ooool00_oo
ool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0
A?ooool2o`000003ooooool0003o000000;o00002Oooool2o`0000_ooooo0_l00007ooooo`Go0000
1?ooool2o`0000Kooooo0_l00003ooooo`Co00000_ooool2o`0000;ooooo0_l00009ooooo`?o0000
0_ooool2o`000003ooooool0003o000001ko00001_ooool5o`0000cooooo1?l00004ooooo`Co0000
8_ooool2o`0000Cooooo0_l0000oooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0<oooool2o`0000Sooooo0_l0
0008ooooo`Co00002?ooool2o`0000oooooo1Ol000000ooooooo0000o`000002o`0000Gooooo0_l0
000<ooooo`Go00003oooool4o`000004ooooool0003o0000ooooob3o00001Oooool3o`0000Wooooo
0_l00004ooooo`Go00000oooool4o`0000Oooooo0_l0000Booooo`;o00002Oooool2o`000003oooo
ool0003o000003kooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l0
00001oooool00ol0003oooooooooo`0cooooo`;o00001_ooool4o`0000Oooooo1?l00009ooooo`;o
000000?oooooo`000?l000001Oooool2o`0000Cooooo2ol000000ooooooo0000o`00000Cooooo`;o
00000oooool2o`0000Wooooo2?l00002ooooo`;o000000?oooooo`000?l000006ol00004ooooo`;o
00001oooool2o`000003ooooool0003o000000Cooooo1Ol00003ooooo`;o00002Oooool2o`0001;o
oooo0_l00005ooooo`;o00000_ooool2o`000003ooooool0003o000003kooooo00001_ooooook^k^
oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`0koooo
o`;o00002Oooool4o`0000_ooooo0ol00002ooooo`;o000000?oooooo`000?l000001?ooool3o`00
0003ooooool0003o000000co00003?ooool4o`0000Cooooo0ol00008ooooo`Oo00001OoooolKo`00
0003ooooool0003o000000Gooooo0_l00006ooooo`;o00001oooool4o`000003ooooool0003o0000
02Kooooo0ol00003ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0<?ooool2o`0000;o
oooo0_l0000?ooooo`;o00002Oooool2o`0000?ooooo0_l00003ooooo`;o00001oooool5o`0000;o
oooo3_l00009ooooo`Co00001?ooool3o`0000[ooooo1Ol00004ooooo`?o000000?oooooo`000?l0
00002_l000000ooooooo0000o`000005o`000003ooooool0003o000000;o00001oooool2o`0000oo
oooo0ol00002ooooo`Co00002Oooool2o`0001;ooooo0_l00005ooooo`;o00001?ooool2o`00043o
oooo000Looooo`03o`000?oooooooooo033ooooo0_l00002ooooo`;o00003Oooool4o`0000Kooooo
0_l000000ooooooo0000o`00000;ooooo`;o00000oooool@o`000003ooooool0003o000000Ko0000
1Oooool2o`000003ooooool0003o000000cooooo0_l00003ooooo`_o00000_oooolAo`0000Cooooo
1?l0000?ooooo`;o00001_ooool4o`0000Cooooo0_l00005ooooo`;o000000Coooooo`000?l0003o
00004_ooool2o`0000_ooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0booooo`;o0000
3oooool2o`0000Sooooo1_l0000:ooooo`?o00000_ooool?o`0000;ooooo1?l000001?oooooo0000
o`000?l00005ooooo`;o00001oooool2o`0000Kooooo0_l00003ooooo`Wo00001_ooool6o`000003
ooooool0003o000000co00002?ooool2o`0000Oooooo0_l00004ooooo`Ko00000oooool5o`000003
ooooool0003o000000;o000000?oooooo`000?l000000_l00003ooooo`;o00001Oooool2o`0000Go
oooo0ol00007ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0;oooool5o`0001[ooooo
1Ol00009ooooo`Co00000oooool@o`000004ooooool0003o0000o`0000;ooooo0ol00004ooooo`;o
00001oooool2o`0000Kooooo0_l00009ooooo`?o00000oooool;o`0000Kooooo1_l00003ooooo`;o
00001?ooool2o`0000gooooo1Ol00004ooooo`Go000000Coooooo`000?l0003ooooo0_l000001?oo
oooo0000o`000?l00003ooooo`;o00001Oooool2o`0000Gooooo0ol00007ooooo`;o0000@oooool0
01cooooo00?o0000ooooooooool0;oooool3o`0001cooooo1?l0000:ooooo`;o00000ooooolEo`00
0003ooooool0003o000000?o00003Oooool2o`0000Kooooo0_l00004ooooo`;o00000oooool3o`00
00;ooooo1?l00003ooooo`Go00000oooool2o`0000?ooooo1Ol000001?oooooo0000o`000?l0000A
ooooo`Oo000000?oooooo`000?l000000_ooool4o`0000Cooooo0_l0000@ooooo`;o00003?ooool3
o`0004?ooooo000Looooo`03o`000?oooooooooo033ooooo0_l0000Sooooo`;o00002_oooolEo`00
0003ooooool0003o000000?o000000?oooooo`000?l000002_ooool2o`0000cooooo1?l00002oooo
o`;o00000_ooool5o`0000;ooooo0ol000000ooooooo0000o`000004o`0000?ooooo0_l000001?oo
oooo0000o`000?ooool2o`0000Wooooo0_l00007ooooo`;o000000?oooooo`000?l000000oooool2
o`0000?ooooo0_l00005ooooo`;o00004?ooool2o`0000[ooooo1?l00005ooooo`;o0000?Oooool0
01cooooo00?o0000ooooooooool0<oooool2o`0000;ooooo0_l00006ooooo`;o00001_ooool3o`00
00_ooooo0_l0000:oooooaGo00001?ooool2o`000003ooooool0003o000000Sooooo0_l0000@oooo
o`Go00001_ooool2o`0000;ooooo2?l00008ooooo`;o00003?ooool2o`0000Gooooo0_l00002oooo
o`?o00003Oooool4o`0001Kooooo0_l00004ooooo`;o00001oooool2o`0003gooooo000Looooo`03
o`000?oooooooooo03?ooooo0_l00002ooooo`;o00001Oooool3o`0000Kooooo0ol0000:ooooo`;o
00003OoooolFo`000003ooooool0003o000000?o00001oooool3o`00013ooooo1Ol00008ooooo`;o
000000?oooooo`000?l000001?l00009ooooo`;o00004oooool2o`0000;ooooo0_l00002ooooo`;o
000000?oooooo`000?l000001oooool4o`0000Gooooo0_l0000?ooooo`;o00001?ooool2o`0000So
oooo0_l0000looooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00001oooool2o`0000Gooooo
0_l00005ooooo`;o00001Oooool4o`0000Cooooo0_l00006ooooo`;o00000_oooolMo`0000Kooooo
1_l0000@ooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo0_l000000ooooooo0000
o`000007ooooo`;o00005oooool2o`0000?ooooo0ol00002ooooo`;o000000?oooooo`000?l00000
1Oooool2o`000004ooooool0003o0000o`0000;ooooo1_l00005ooooo`;o00005oooool2o`0003co
oooo000Looooo`03o`000?oooooooooo02kooooo0_l00003ooooo`;o00000_ooool2o`000003oooo
ool0003o000000Wooooo0_l00005ooooo`Go00002_ooool:o`0000;ooooo5_l00002ooooo`;o0000
0_ooool4o`0001_ooooo0_l0000<ooooo`Go00003_ooool2o`0000Kooooo0_l00003ooooo`?o0000
3?ooool6o`0000;ooooo0ol000000ooooooo0000o`000004ooooo`?o00003Oooool2o`0004Kooooo
000Looooo`03o`000?oooooooooo02gooooo0_l00004ooooo`;o00001Oooool2o`000003ooooool0
003o000000Cooooo0_l00002ooooo`;o00001Oooool3o`000003ooooool0003o000000Oooooo3?l0
0002oooooa;o00001?ooool2o`0000;ooooo0ol0000Hooooo`;o00001oooool2o`0000;ooooo0_l0
0003ooooo`;o000000?oooooo`000?l000003_ooool2o`0000Cooooo1?l00003ooooo`;o00003ooo
ool3o`0000gooooo0_l0000>ooooo`;o00000oooool2o`0000Gooooo0_l0000jooooo`007?ooool2
o`0002kooooo0_l0000=ooooo`?o00001?ooool3o`000003ooooool0003o000000Oooooo1?l00002
ooooo`;o00001OoooolFo`000003ooooool0003o000000Go000000Coooooo`000?l0003ooooo0_l0
0002ooooo`?o000000?oooooo`000?l000001_ooool2o`0000gooooo0_l000000ooooooo0000o`00
0002ooooo`Go000000?oooooo`000?l000004Oooool2o`0000Cooooo0_l00003ooooo`Ko000000?o
ooooo`000?l000003Oooool5o`0000;ooooo1?l00002ooooo`Co00005_ooool2o`0000Gooooo0_l0
000jooooo`007?ooool00ol0003oooooooooo`0looooo`;o00001_ooool4o`0000;ooooo0_l00004
ooooo`;o00001?ooool2o`0000?ooooo8ol000000ooooooo0000o`000006ooooo`;o00001_ooool2
o`00013ooooo0_l00002ooooo`Go00005?ooool2o`0000Cooooo0_l00003ooooo`;o00000_ooool2
o`0000oooooo0ol000000ooooooo0000o`000002ooooo`Co00000_ooool7o`0005Kooooo000Loooo
o`03o`000?oooooooooo03Sooooo0_l0000<ooooo`;o00000_ooool2o`0000[ooooo0ol00002oooo
oa7o000000?oooooo`000?l000002ol000000ooooooo0000o`000004ooooo`;o00000_ooool3o`00
00Kooooo0_l0000^ooooo`;o00004oooool2o`0000Oooooo1?l00003ooooo`;o00001?ooool3o`00
00;ooooo1_l00004ooooo`?o0000C_ooool001cooooo00?o0000ooooooooool0>?ooool2o`0000So
oooo0_l0000Booooo`?o00001?oooolNo`0000Kooooo0_l00002ooooo`?o00001_ooool2o`0004?o
oooo0_l00006ooooo`?o00000_ooool2o`000003ooooool0003o000000Cooooo0ol00002ooooo`go
0000C_ooool001cooooo00?o0000ooooooooool0:_ooool2o`0001Kooooo0_l0000Booooo`;o0000
1?oooolPo`0000Wooooo0_l00007ooooo`;o0000>?ooool2o`000003ooooool0003o000000?o0000
2oooool2o`0000?ooooo0_l0000<ooooo`;o00000_ooool7o`00053ooooo000Looooo`03o`000?oo
oooooooo02[ooooo0_l0000Dooooo`;o00005Oooool3o`0000;ooooo8?l00009ooooo`;o00001ooo
ool2o`0003Sooooo0_l000000ooooooo0000o`000003o`0000cooooo0_l00002ooooo`;o00004_oo
ool4o`0000[ooooo0_l00005ooooo`;o00000_ooool2o`000003ooooool0003o000003Oooooo000L
ooooo`03o`000?oooooooooo02oooooo0_l0000?ooooo`;o00005Oooool3o`0000?ooooo7_l00006
ooooo`;o00000_ooool2o`0002gooooo0_l0000Booooo`;o00001_ooool2o`0000Wooooo0ol0000T
ooooo`;o00001Oooool2o`0000;ooooo0_l000000ooooooo0000o`00000gooooo`007?ooool00ol0
003oooooooooo`0_ooooo`;o00004oooool2o`0001Kooooo1?l000000ooooooo0000o`00000Go`00
00Oooooo0_l000000ooooooo0000o`00000;ooooo`;o00008Oooool2o`0000Sooooo0_l00008oooo
o`;o00001_ooool2o`0000;ooooo0_l00005ooooo`;o0000:?ooool6o`0003kooooo000Looooo`03
o`000?oooooooooo02gooooo0_l000000ooooooo0000o`00000Booooo`;o00002?ooool2o`0000co
oooo0ol00002ooooo`Co000000?oooooo`000?l000003?l00002ooooo`Co00000_ooool2o`0000Ko
oooo0_l00009ooooo`Ko00003_ooool2o`0000;ooooo0_l00005ooooo`Co00002oooool3o`0000Wo
oooo0_l00003ooooo`;o00000oooool3o`0001Gooooo0_l0000Hooooo`Co0000@?ooool001cooooo
00?o0000ooooooooool0;Oooool2o`000003ooooool0003o000001cooooo0_l0000<ooooo`Go0000
00?oooooo`000?l000004Ol000000ooooooo0000o`000004ooooo`;o00004Oooool6o`0000kooooo
0_l00002ooooo`;o00001Oooool4o`0000_ooooo0_l00009ooooo`?o00000_ooool3o`0000?ooooo
0_l0000Fooooo`?o00005oooool3o`000003ooooool0003o000003kooooo000Looooo`03o`000?oo
oooooooo047ooooo0_l0000Kooooo`?o000000?oooooo`000?l000005_l0000>ooooo`;o00001ooo
ool2o`000003ooooool0003o0000037ooooo0ol00003ooooo`?o00000oooool2o`0001Oooooo0_l0
0004ooooo`;o00003Oooool2o`0000?ooooo0_l000000ooooooo0000o`00000nooooo`007?ooool0
0ol0003oooooooooo`0_ooooo`;o00004?ooool2o`0001[ooooo0_l00004ooooo`oo000000?ooooo
o`000?l000001Ol0000>ooooo`;o00001oooool8o`0002Cooooo0_l000000ooooooo0000o`000005
ooooo`;o00001Oooool2o`0000?ooooo0_l0000@ooooo`;o00000_ooool2o`0000Oooooo0_l0000=
ooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0;oooool2o`0001Sooooo0_l0000Boooo
o`;o00001Oooool?o`0000?ooooo0ol0000:ooooo`;o00003Oooool7o`0002Cooooo0_l000000ooo
oooo0000o`000002o`0000Gooooo0_l00003ooooo`?o00002?ooool2o`0000?ooooo0ol00002oooo
o`Co00000_ooool2o`000003ooooool0003o000000cooooo0_l0001=ooooo`007?ooool00ol0003o
ooooooooo`17ooooo`Co00005_ooool3o`0000;ooooo0_l000001?oooooo0000o`000?ooool4o`00
0004ooooool0003o0000o`0000;ooooo0_l00007ooooo`;o00000_ooool2o`0000oooooo1Ol0000W
ooooo`Co00001Oooool2o`0000?ooooo0ol00002ooooo`;o00001?ooool2o`0000;ooooo1?l00002
ooooo`;o00001oooool2o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`;o000000?ooooo
o`000?l00000B_ooool001cooooo00?o0000ooooooooool0@?ooool2o`0000Gooooo0_l00008oooo
o`;o00000oooool2o`0000?ooooo0_l00004ooooo`Oo00001?ooool4o`0000;ooooo0_l00006oooo
o`;o00000oooool2o`0001?ooooo0_l000001?oooooo0000o`000?ooool2o`0000Cooooo0_l00002
ooooo`;o00006?ooool4o`0000Gooooo0_l0000:ooooo`;o00002?ooool2o`00013ooooo0_l00000
1?oooooo0000o`000?ooool3o`0000;ooooo1Ol00005ooooo`;o0000@oooool001cooooo00?o0000
ooooooooool0@?ooool2o`0000Kooooo0_l00007ooooo`;o00000oooool2o`0000?ooooo0ol00002
ooooo`;o000000?oooooo`000?l000001?l00003ooooo`?o000000?oooooo`000?l000002?ooool2
o`0000;ooooo0_l00002ooooo`?o00001?ooool2o`0000Wooooo0_l00004ooooo`;o000000?ooooo
o`000?l000000ol00002ooooo`;o00001?ooool2o`0000oooooo0_l000000ooooooo0000o`000003
ooooo`;o00000_ooool2o`0001Gooooo0_l00004ooooo`;o00002Oooool2o`0000Gooooo0ol00003
ooooo`?o00001Oooool2o`0004?ooooo000Looooo`;o0000<Oooool2o`000003ooooool0003o0000
01?ooooo0_l00004ooooo`;o00001_ooool3o`0000?ooooo0ol000000ooooooo0000o`000003oooo
o`Co00000_ooool2o`0000?ooooo0_l00005ooooo`;o00001Oooool2o`0000;ooooo0ol00003oooo
o`?o00004_ooool3o`000004ooooool0003o0000ooooo`co000000?oooooo`000?l000000_l00000
0ooooooo0000o`00000:o`000003ooooool0003o0000017ooooo1?l00004ooooo`;o00001?ooool2
o`00017ooooo0_l00004ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0<?ooool2o`00
0003ooooool0003o000001Wooooo0_l00007ooooo`;o00001?ooool4o`0000Cooooo0ol00002oooo
o`Ko00000oooool2o`0000;ooooo0_l00009ooooo`?o00000oooool4o`0000kooooo0_l00002oooo
o`Go000000?oooooo`000?l000007?l000000ooooooo0000o`000006ooooo`;o00001oooool6o`00
00kooooo0_l00008ooooo`;o00001Oooool2o`0000Wooooo0_l00013ooooo`007?ooool00ol0003o
ooooooooo`0^ooooo`;o00005Oooool2o`0000Oooooo0ol00006ooooo`;o000000Coooooo`000?l0
003o00000_ooool4o`000003ooooool0003o000000;o000000?oooooo`000?l000001Ol00003oooo
o`;o00003_ooool2o`0000Gooooo0ol0000=ooooo`So00001?ooool3o`0000Cooooo5?l00002oooo
o`;o00001_ooool2o`0000Kooooo0ol00003ooooo`;o00003Oooool4o`0000Kooooo0_l00005oooo
o`;o00002Oooool2o`0004?ooooo000Looooo`03o`000?oooooooooo02kooooo0_l0000Eooooo`;o
00002?ooool3o`0000Gooooo0_l000001Ooooooo0000o`000?l0003ooooo00Go000000?oooooo`00
0?l000003?l0000;ooooo`;o00000oooool3o`0000Kooooo0ol0000>ooooo`Go00000oooool5o`00
00Gooooo1_l00005ooooo`Go00005Oooool2o`0000Cooooo0_l0000?ooooo`;o00001?ooool2o`00
00Gooooo1?l0001>ooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00007?ooool3o`0000Go
oooo0_l00002ooooo`;o000000?oooooo`000?l000000_l00006ooooo`Go00000_ooool3o`000004
ooooool0003o0000o`0000Oooooo0_l00003ooooo`?o00000oooool2o`0000;ooooo0_l0000=oooo
o`;o00000_ooool4o`000003ooooool0003o000000;ooooo0_l00004ooooo`Ko00001Oooool2o`00
0003ooooool0003o000002Sooooo1?l00003ooooo`;o000000?oooooo`000?l000001Oooool6o`00
04cooooo000Looooo`03o`000?oooooooooo037ooooo0_l0000?ooooo`;o00002oooool2o`0000;o
oooo0_l00002ooooo`?o000000?oooooo`000?l000000_ooool2o`0000Sooooo2?l00002ooooo`Co
00000oooool2o`0000Kooooo0ol00003ooooo`;o00004Oooool4o`000004ooooool0003o0000o`00
00Gooooo0_l000001?oooooo0000o`000?l00004ooooo`;o00001Oooool4o`0000oooooo0_l0000:
ooooo`;o00002?ooool=o`000003ooooool0003o000000Gooooo0_l00002ooooo`;o00001_ooool2
o`0004Cooooo000Looooo`03o`000?oooooooooo03;ooooo0_l0000>ooooo`;o00002oooool2o`00
00;ooooo0_l000000ooooooo0000o`000004o`0000Wooooo0_l00005ooooo`Go00001?ooool3o`00
00;ooooo0_l00003ooooo`;o00006oooool3o`000003ooooool0003o000000;o00001?ooool2o`00
0004ooooool0003o0000o`0000gooooo0_l0000?ooooo`;o00000oooool4o`0000?ooooo0_l00006
oooooaCo000000?oooooo`000?l000000ol00004ooooo`;o00000_ooool3o`0004Cooooo000Loooo
o`03o`000?oooooooooo033ooooo1?l0000;ooooo`;o00005Oooool2o`000003ooooool0003o0000
00?o00001oooool2o`0000Oooooo0ol00002ooooo`Go00001oooool2o`0000cooooo0_l0000=oooo
o`;o00000_ooool4o`0000?ooooo0ol00002ooooo`Ko00007oooool6o`0000Wooooo1?l000000ooo
oooo0000o`000006o`000003ooooool0003o000000Co000000?oooooo`000?l000000ol00004oooo
o`;o00000_ooool2o`0000?ooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o
00003Oooool2o`0000_ooooo0_l00002ooooo`;o00000_ooool4o`000003ooooool0003o000000?o
00001oooool2o`0000cooooo0_l00005ooooo`;o00004?ooool3o`00017ooooo0_l00005ooooo`;o
00000oooool8o`00013ooooo0_l00006ooooo`;o00001oooool2o`0000Oooooo5?l00004ooooo`Co
00000_ooool4o`0000;ooooo0_l00003ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0
C?ooool2o`0000;ooooo0_l00002ooooo`;o00000oooool8o`0000Cooooo0_l00003ooooo`;o0000
0_ooool2o`0000[ooooo0_l0000@ooooo`;o00004_ooool3o`0000Cooooo0_l00003ooooo`Go0000
00?oooooo`000?l000002oooool2o`0000?ooooo0_l00006ooooo`;o00004?oooolHo`000003oooo
ool0003o000000?ooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00002Ooo
ool2o`0000oooooo0_l00003ooooo`;o00001_ooool2o`000003ooooool0003o000000?o00002?oo
ool8o`0000[ooooo0_l00005ooooo`;o00002_ooool2o`0000Oooooo0ol00006ooooo`;o00001?oo
ool2o`0001Kooooo0_l00002ooooo`;o00005oooool4o`000003ooooool0003o000000ko000000?o
ooooo`000?l000000_l000001?oooooo0000o`000?ooool2o`0000Wooooo0_l000000ooooooo0000
o`00000oooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00002Oooool4o`0000gooooo0_l0
0003ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Gooooo0_l00003ooooo`;o00000_oo
ool2o`0000;ooooo0_l00006ooooo`Ko000000?oooooo`000?l000002_ooool2o`0000Oooooo1?l0
000>ooooo`;o00005oooool2o`0000gooooo0_l00007oooooako000000?oooooo`000?l000002Ooo
ool2o`000003ooooool0003o000003oooooo000Looooo`03o`000?oooooooooo037ooooo0_l0000:
ooooo`?o00005Oooool2o`0000Cooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo1_l0
0008ooooo`?o00001_ooool8o`0000Wooooo0_l0000:ooooo`;o000000Coooooo`000?l0003ooooo
0_l00003ooooo`;o00000oooool2o`0001Oooooo0ol0000<ooooo`;o00001ooooolNo`0000?ooooo
0_l00009ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0<Oooool2o`0000Sooooo1?l0
000Looooo`;o00001_ooool5o`000004ooooool0003o0000o`0000Wooooo0ol00007ooooo`Co0000
2oooool2o`0000gooooo0_l000000ooooooo0000o`000002ooooo`Go00005?ooool2o`0000Cooooo
0ol0000Hoooooaco00000_ooool2o`0000Wooooo0_l00010ooooo`007?ooool00ol0003ooooooooo
o`0aooooo`;o00002?ooool2o`000003ooooool0003o0000023ooooo0_l00003ooooo`;o00000_oo
ool3o`0000Cooooo0_l00004ooooo`;o00001Oooool6o`0000oooooo0_l0000<ooooo`;o00000_oo
ool6o`0001?ooooo0_l00007ooooo`;o00005OoooolDo`000003ooooool0003o000000;o00000_oo
ool2o`0004oooooo000Looooo`03o`000?oooooooooo037ooooo0_l0000;ooooo`;o00006oooool2
o`000003ooooool0003o000000;o00003_ooool2o`0000Cooooo0_l00003ooooo`So00003oooool2
o`0000gooooo0_l00005ooooo`;o00007?ooool2o`0001Gooooo6Ol00006ooooo`;o00001Oooool2
o`0004Cooooo000Looooo`;o0000?_ooool2o`0001cooooo1Ol0000:ooooo`;o00001Oooool2o`00
00Sooooo2_l0000Gooooo`Wo00001oooool2o`0002oooooo6Ol00005ooooo`?o00001Oooool2o`00
04Cooooo000Looooo`03o`000?oooooooooo033ooooo0_l0000;ooooo`;o00007_ooool2o`0000Go
oooo0_l00004ooooo`;o00001Oooool4o`0000Kooooo3?l00006ooooo`;o00001_ooool4o`0000?o
oooo1Ol00002ooooo`;o00001_ooool3o`0002Kooooo0_l00009oooooaKo00001_ooool3o`0004_o
oooo000Looooo`03o`000?oooooooooo033ooooo0_l0000Booooo`;o00007_ooool2o`0000gooooo
0ol00005ooooo`co00001_ooool2o`0000;ooooo0_l00002ooooo`Co00002_ooool2o`0000Kooooo
0_l0000Gooooo`;o00003_ooool2o`0000Cooooo0_l00003oooooaKo00001?ooool5o`0004_ooooo
000Looooo`03o`000?oooooooooo03;ooooo0_l0000@ooooo`;o000000?oooooo`000?l000005_oo
ool2o`0000_ooooo1?l00004ooooo`Co00000_ooool5o`000003ooooool0003o000000Go00002_oo
ool2o`0000;ooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo1Ol00006ooooo`;o0000
00?oooooo`000?l000005?ooool2o`0000Cooooo0_l0000>ooooo`Co00000_oooolEo`0000Cooooo
0ol0001=ooooo`007?ooool00ol0003oooooooooo`0booooo`;o00002oooool2o`0000;ooooo0_l0
0002ooooo`;o00005_ooool2o`0000Kooooo0_l00003ooooo`Ko00001?ooool2o`0000;ooooo3ol0
000Aooooo`Go000000Coooooo`000?l0003o00001_ooool4o`000003ooooool0003o000001[ooooo
0_l0000@ooooo`;o00001OoooolAo`0005Gooooo000Looooo`03o`000?oooooooooo03oooooo0_l0
0002ooooo`;o000000?oooooo`000?l000007oooool2o`0000Cooooo0_l000000ooooooo0000o`00
0002o`0000Oooooo3_l0000>ooooo`?o000000?oooooo`000?l000000ol000000ooooooo0000o`00
0002ooooo`;o00000_ooool4o`0002;ooooo0_l00007ooooo`;o00002OoooolAo`0000?ooooo1?l0
0005ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0A_ooool2o`0002;ooooo0_l00006
ooooo`;o000000?oooooo`000?l000000_ooool?o`0000oooooo0ol00003ooooo`?o00001Oooool3
o`000003ooooool0003o000000;o000000?oooooo`000?l000003?ooool4o`0000?ooooo0_l0000:
ooooo`;o00001oooool2o`0000Gooooo0_l00002ooooo`go00000_ooool2o`0000?ooooo1?l00005
ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0A_ooool2o`0002;ooooo0_l00007oooo
o`Co00000_ooool=o`0001;ooooo0_l00003ooooo`?o00001_ooool5o`0000?ooooo0_l0000<oooo
o`Co00000oooool2o`0001[ooooo0_l00003ooooo`co00000_ooool2o`0005Gooooo000Looooo`03
o`000?oooooooooo07?ooooo0_l00003ooooo`ko00004_ooool2o`0000?ooooo1?l00005ooooo`Oo
00004?ooool2o`0000Cooooo0_l00007ooooo`;o00001?ooool2o`0000Oooooo0ol00003ooooo`;o
000000?oooooo`000?l000000ol00004ooooo`?o00002_ooool2o`0004gooooo000Looooo`03o`00
0?oooooooooo043ooooo0ol0000eooooo`;o00000_ooool9o`0000Wooooo1?l0000=ooooo`;o0000
1_ooool3o`000003ooooool0003o0000013ooooo0_l0000=ooooo`;o00001?ooool2o`0000Oooooo
0ol00003ooooo`;o00000oooool3o`0000oooooo1?l0001=ooooo`007?ooool00ol0003ooooooooo
o`0oooooo`Go0000;oooool5o`0000Cooooo2Ol00009ooooo`Co00001Oooool2o`000003ooooool0
003o000000Gooooo0_l00005ooooo`;o00000_ooool2o`000003ooooool0003o000001_ooooo0_l0
000>ooooo`;o00002?ooool3o`0000oooooo0ol0001>ooooo`007?ooool00ol0003oooooooooo`0d
ooooo`;o00002Oooool2o`000003ooooool0003o000002oooooo1Ol000001?oooooo0000o`000?oo
ool9o`0000?ooooo1?l00003ooooo`;o00001_ooool2o`000003ooooool0003o000000Cooooo0ol0
0009ooooo`;o000000?oooooo`000?l000001?ooool2o`0002Gooooo0_l000000ooooooo0000o`00
000Dooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0=?ooool2o`0000Wooooo0_l0000T
ooooo`;o00003_ooool2o`0000;ooooo1_l000000ooooooo0000o`000005o`000003ooooool0003o
000000;o00002?ooool2o`0000[ooooo0_l00005ooooo`Co00002_ooool2o`0000Wooooo0ol00008
ooooo`Go00003Oooool4o`0001Cooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`15oooo
o`;o00007_ooool4o`0000cooooo2_l000000ooooooo0000o`000002o`000003ooooool0003o0000
00Sooooo0_l00002ooooo`?o00000_ooool2o`0000gooooo1Ol0000?ooooo`;o00000oooool3o`00
00Sooooo1Ol00003ooooo`;o00001Oooool2o`000003ooooool0003o000000Cooooo1?l00006oooo
o`;o000000?oooooo`000?l000000ol0001Dooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5
ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0AOoo
ool2o`00023ooooo0_l0000=ooooo`Co00001Oooool2o`0000;ooooo0ol00002ooooo`;o00001Ooo
ool3o`000003ooooool0003o000000;ooooo0ol00002ooooo`;o00002_ooool4o`0000oooooo0ol0
000<ooooo`?o00001_ooool3o`0000Cooooo0_l00007ooooo`Co00000_ooool2o`0000;ooooo0_l0
00000ooooooo0000o`000003o`0005Cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo
0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`17ooooo`;o
00008oooool2o`0000_ooooo0ol00003ooooo`;o00000_ooool3o`0000;ooooo0_l00006ooooo`;o
00001?ooool3o`0000?ooooo0_l00003ooooo`Co00000oooool5o`0000Kooooo0_l00007ooooo`;o
00002_ooool4o`0000Sooooo0_l00004ooooo`;o00003?ooool5o`0005cooooo00000ooooooo410@
ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo03oooooo0_l00005ooooo`?o00008oooool3o`0000[ooooo0ol000000ooooooo
0000o`00000;ooooo`;o00001_ooool2o`0000;ooooo0_l00008ooooo`So000000?oooooo`000?l0
00000_l00006ooooo`;o00000_ooool2o`0000oooooo0_l0000@ooooo`;o00003?ooool2o`000003
ooooool0003o000005cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo
00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000?oooool2o`0000;ooooo0_l000000ooooooo
0000o`00000Uooooo`;o00001Oooool4o`0000Gooooo0_l0000;ooooo`;o00001_ooool2o`0000Wo
oooo1Ol000000ooooooo0000o`000008o`0000[ooooo0_l0000Sooooo`;o0000Joooool00003oooo
ool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oEEEEo`000?l@413oc<c<00Ko
oooo00?o0000ooooooooool0=Oooool2o`0000cooooo0_l0000Dooooo`Ko00001Oooool4o`0000co
oooo1?l00002ooooo`;o00002?ooool2o`0000Oooooo1?l00002ooooo`;o00002?ooool5o`0000Co
oooo2?l0000Gooooo`Co00001?ooool2o`0000?ooooo0_l00006ooooo`Co0000Joooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`00
0?oooooooooo03Cooooo0ol0000<ooooo`;o00005?ooool6o`0000Gooooo1?l0000Booooo`;o0000
0oooool2o`0000?ooooo0_l00007ooooo`Co00000_ooool2o`0000Oooooo1?l00007ooooo`So0000
00?oooooo`000?l000004oooool4o`0000Cooooo0_l00003ooooo`;o00001_ooool2o`0006gooooo
00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003o
ooooooooo`0dooooo`Co00002_ooool3o`0000Oooooo0_l0000Qooooo`;o00002Oooool2o`0000?o
oooo1?l00005ooooo`;o00001?ooool2o`0000cooooo1?l00004ooooo`;o00000oooool9o`0000;o
oooo1Ol000000ooooooo0000o`00002=ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<oooo
o`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0=_ooool2o`0000[ooooo0_l00002
ooooo`;o00001?ooool2o`00027ooooo0_l00009ooooo`Go000000Coooooo`000?l0003o00001Ooo
ool2o`0000?ooooo0ol00006ooooo`;o00001_ooool2o`0000?ooooo0ol00004ooooo`Ko00001?oo
ool5o`000003ooooool0003o000001;ooooo0_l0001iooooo`007?ooool00ol0003oooooooooo`0f
ooooo`;o00002oooool2o`000003ooooool0003o000000;ooooo0_l0000Sooooo`;o00002_ooool4
o`0000kooooo1Ol00004ooooo`;o00001Oooool3o`0000?ooooo0ol0000Xooooo`;o00003Oooool2
o`000003ooooool0003o000006Oooooo000Looooo`03o`000?oooooooooo04?ooooo0_l00005oooo
o`;o00003oooool2o`0000_ooooo0_l0000Kooooo`Co00001_ooool3o`0000_ooooo0_l0000noooo
o`;o000000?oooooo`000?l00000Ioooool001cooooo00?o0000ooooooooool0Foooool2o`0000_o
oooo0_l0000Booooo`;o00001_ooool5o`0000Kooooo0_l0002hooooo`007?ooool00ol0003ooooo
ooooo`19ooooo`;o00000_ooool2o`0000Gooooo0_l0000@ooooo`Co00004_ooool2o`0000Kooooo
0_l000000ooooooo0000o`000005ooooo`;o00002oooool4o`000003ooooool0003o000001Oooooo
0_l00002ooooo`;o00009?ooool2o`0006Cooooo000Looooo`03o`000?oooooooooo03Kooooo0_l0
000Aooooo`?o000000?oooooo`000?l000001Oooool2o`00013ooooo1?l0000?ooooo`;o00003?oo
ool2o`0000Gooooo0_l0000;ooooo`Co000000?oooooo`000?l000005_ooool3o`0000;ooooo0_l0
0004ooooo`;o00005oooool2o`0000Gooooo0_l0001Tooooo`007?ooool00ol0003oooooooooo`0f
ooooo`;o00004_ooool2o`0002gooooo0_l00004ooooo`?o00001Oooool2o`0000kooooo0_l00003
ooooo`;o00005Oooool3o`0000;ooooo0ol00008ooooo`;o00005oooool2o`0006_ooooo000Loooo
o`03o`000?oooooooooo04[ooooo0_l0000Sooooo`;o00002Oooool2o`000003ooooool0003o0000
00?o00001Oooool2o`0000Wooooo0_l00003ooooo`Co000000Coooooo`000?l0003ooooo0ol0000A
ooooo`?o00000oooool2o`0000;ooooo0_l0000Uooooo`?o0000H_ooool001cooooo00?o0000oooo
ooooool0C?ooool2o`000003ooooool0003o000000oooooo0_l0000=ooooo`;o00000oooool2o`00
00Cooooo1ol000000ooooooo0000o`000002o`0000Oooooo0_l00003ooooo`?o00000_ooool4o`00
00Cooooo0ol00005ooooo`;o00001oooool2o`000003ooooool0003o000000Oooooo0ol00003oooo
o`;o00000_ooool2o`0000Sooooo0_l0000Booooo`?o00000oooool2o`0005gooooo000Looooo`03
o`000?oooooooooo03[ooooo0_l0000@ooooo`;o000000?oooooo`000?l000000ol0000<ooooo`;o
000000Coooooo`000?l0003o00003_ooool2o`000003ooooool0003o000000Oo00000_ooool4o`00
00Oooooo0_l00004ooooo`;o00000_ooool5o`0000;ooooo0_l00007ooooo`;o00000oooool2o`00
00;ooooo0_l00009ooooo`?o000000?oooooo`000?l000000ol00002ooooo`;o00002?ooool2o`00
00Kooooo0_l0000@ooooo`;o0000GOooool001cooooo00?o0000ooooooooool0>_ooool2o`0001Go
oooo1Ol000001?oooooo0000o`000?ooool<o`0000Sooooo1?l00005ooooo`Ko000000Coooooo`00
0?l0003o00004Oooool2o`0000Gooooo0ol00002ooooo`;o00001_ooool5o`000003ooooool0003o
000000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo1ol00003ooooo`?o00001Ooo
ool2o`000004ooooool0003o0000ooooo`;o00000oooool2o`0006oooooo000Looooo`03o`000?oo
oooooooo03_ooooo0_l0000Eooooo`Co000000Coooooo`000?l0003ooooo3?l00003ooooo`;o0000
0oooool4o`000003ooooool0003o000000Cooooo1?l000000ooooooo0000o`000006o`0000;ooooo
0_l00005ooooo`;o000000?oooooo`000?l000001_ooool2o`0000;ooooo0_l00006ooooo`Go0000
1Oooool5o`000003ooooool0003o000000oo00001_ooool2o`0000Cooooo0_l0001dooooo`007?oo
ool2o`0003cooooo0_l0000Eooooo`;o00003_ooool3o`0000Cooooo0_l00002ooooo`;o00001?oo
ool2o`000004ooooool0003o0000ooooo`go00000_ooool2o`0000Gooooo0_l00009ooooo`;o0000
00Coooooo`000?l0003o00004?ooool3o`0000;ooooo4Ol00002ooooo`;o00000_ooool3o`0000?o
oooo0ol00003ooooo`;o0000Koooool001cooooo00?o0000ooooooooool0>oooool2o`000003oooo
ool0003o000000gooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo0_l00008ooooo`?o0000
0_ooool2o`0000;ooooo0_l00007ooooo`Co000000?oooooo`000?l000002Ol000000ooooooo0000
o`000002o`0000[ooooo0_l000000ooooooo0000o`000003ooooo`;o00002oooool2o`0000Oooooo
4Ol00004ooooo`?o000000Coooooo`000?l0003o00000oooool3o`0000?ooooo0_l0000;ooooo`;o
0000H_ooool001cooooo00?o0000ooooooooool0>oooool2o`000003ooooool0003o000000gooooo
0ol00006ooooo`;o00000_ooool2o`0000?ooooo0_l00003ooooo`Co00000oooool2o`0000_ooooo
4ol00006ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo0ol00008ooooo`;o0000
00?oooooo`000?l000001Oooool6o`000003ooooool0003o000000ko000000?oooooo`000?l00000
0_ooool2o`0001Kooooo0_l000000ooooooo0000o`00001Oooooo`007?ooool00ol0003ooooooooo
o`0kooooo`;o000000?oooooo`000?l000000_l0000<ooooo`;o00002Oooool2o`0000Cooooo0_l0
0003ooooo`Co00000oooool2o`0000?ooooo0_l000000ooooooo0000o`000003oooooa?o00001_oo
ool2o`000003ooooool0003o000000Gooooo1Ol00007ooooo`;o00001_ooool<o`000003ooooool0
003o000000[o00002_ooool2o`0000Cooooo0_l0000>ooooo`;o00000_ooool2o`0002Gooooo0_l0
000dooooo`007?ooool00ol0003oooooooooo`0nooooo`Co00005oooool2o`0000;ooooo0_l00000
0ooooooo0000o`000004o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l000000ooooolC
o`0000Wooooo1?l00003ooooo`;o000000?oooooo`000?l000003ooooolJo`0000Gooooo0_l00002
ooooo`;o00001?ooool2o`0001;ooooo0_l0000Uooooo`;o0000=?ooool001cooooo00?o0000oooo
ooooool0?oooool2o`00017ooooo0_l00009ooooo`;o000000?oooooo`000?l000000_l00006oooo
o`;o00001?ooool2o`0000Cooooo0_l000000ooooooo0000o`00000Ao`0000[ooooo0_l00006oooo
o`;o00000_ooool3o`0000_ooooo6Ol00005ooooo`;o0000NOooool001cooooo00?o0000oooooooo
ool0D_ooool2o`0000Wooooo0_l000000ooooooo0000o`000004o`0000;ooooo0ol00002ooooo`;o
00001oooool2o`0000;ooooo5?l00004ooooo`;o00000_ooool3o`0000Wooooo0ol0000:ooooo`Oo
000000?oooooo`000?l000004Ol0000:ooooo`;o00006?ooool2o`00027ooooo0_l0000fooooo`00
7?ooool00ol0003oooooooooo`0nooooo`;o00008?ooool2o`0000;ooooo0ol000001?oooooo0000
o`000?l00002ooooo`;o00001ooooolHo`0000Cooooo0_l00003ooooo`?o00005OoooolKo`000003
ooooool0003o000000Oooooo0_l0000Hooooo`;o00008Oooool2o`0003Kooooo000Looooo`03o`00
0?oooooooooo03kooooo0_l0000Qooooo`;o000000Coooooo`000?l0003o00002oooool2o`0000;o
oooo6?l00003ooooo`;o00001Oooool2o`0000Wooooo0_l0000=oooooaco0000Noooool001cooooo
00?o0000ooooooooool0@oooool2o`0001cooooo0_l000001?oooooo0000o`000?ooool2o`0000Wo
oooo0_l00002oooooaSo00000oooool2o`0000;ooooo0_l00007ooooo`?o00000_ooool2o`0000co
oooo0ol000000ooooooo0000o`00000>o`000003ooooool0003o000000Oo0000N_ooool001cooooo
00?o0000ooooooooool0@oooool2o`00023ooooo1?l00002ooooo`;o00002OoooolHo`0000Oooooo
0_l00007ooooo`?o00003Oooool2o`000003ooooool0003o000001;o00000_ooool5o`000003oooo
ool0003o000007[ooooo000Looooo`03o`000?oooooooooo04?ooooo0_l0000Cooooo`;o00002_oo
ool3o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000001_ooool2o`000003oooo
ool0003o0000017o00004Oooool5o`0000cooooo0_l00002oooooa[o000000?oooooo`000?l00000
N_ooool001cooooo00?o0000ooooooooool0F?ooool3o`0000Wooooo0ol000000ooooooo0000o`00
0004ooooo`;o00001_oooolFo`0000_ooooo0ol00003ooooo`Go00000oooool2o`0000[ooooo6_l0
0002ooooo`;o0000N_ooool001cooooo00?o0000ooooooooool0A_ooool2o`00017ooooo0_l0000L
oooooaGo00000oooool2o`000003ooooool0003o000000?ooooo0ol0000;ooooo`;o00002_oooolJ
o`0000Wooooo0_l0001cooooo`007?ooool00ol0003oooooooooo`16ooooo`;o00007oooool2o`00
00Cooooo0_l00005ooooo`;o000000?oooooo`000?l000005Ol000001?oooooo0000o`000?ooool2
o`0000gooooo0_l0000?oooooaWo000000Goooooo`000?l0003o0000ooooo`02o`0000;ooooo0_l0
001cooooo`007?ooool00ol0003oooooooooo`1Wooooo`;o00001?ooool4o`0000?ooooo0_l00000
0ooooooo0000o`00000Eo`000004ooooool0003o0000ooooo`;o00003Oooool2o`0000Kooooo0_l0
0004ooooo`;o000000?oooooo`000?l000005_l00002ooooo`?o000000?oooooo`000?l000001Ooo
ool2o`00073ooooo000Looooo`;o0000Ioooool3o`0000Kooooo0_l00008oooooaGo00001?ooool2
o`0001Cooooo1?l00003ooooo`?o000000?oooooo`000?l000005ol000000ooooooo0000o`000008
ooooo`;o0000L?ooool001cooooo00?o0000ooooooooool0Foooool2o`0000Gooooo0_l00002oooo
o`;o00004OoooolEo`0001[ooooo1?l00004ooooo`;o000000?oooooo`000?l000000_l000000ooo
oooo0000o`00000:o`000003ooooool0003o000000So0000N_ooool001cooooo00?o0000oooooooo
ool0Boooool3o`0000gooooo0_l00005ooooo`;o00001?ooool2o`0000Gooooo0_l00008oooooa;o
00008Oooool2o`0000Oooooo3ol000000ooooooo0000o`000007o`0007_ooooo000Looooo`03o`00
0?oooooooooo04_ooooo0ol0000Jooooo`;o00001Oooool2o`0000Sooooo4_l0000>ooooo`;o0000
4Oooool2o`0000Cooooo6ol0001looooo`007?ooool00ol0003oooooooooo`1Looooo`;o00002_oo
ool3o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000000oooool@o`0000oooooo0_l0
000@ooooo`;o00001OoooolJo`0000?ooooo0_l00002ooooo`;o00000oooool2o`0002kooooo0_l0
000oooooo`007?ooool00ol0003oooooooooo`1Looooo`;o00001Oooool2o`0000?ooooo0ol00002
ooooo`Co000000Coooooo`000?l0003ooooo0ol00002ooooo`oo00004?ooool2o`00013ooooo0_l0
0005ooooo`;o000000?oooooo`000?l000004?l000000ooooooo0000o`000002o`0000?ooooo2?l0
00000ooooooo0000o`00000^ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0G_ooool2
o`0000?ooooo0_l00009ooooo`?o00000oooool4o`0000;ooooo3ol0000@ooooo`;o00006ooooolF
o`0000?ooooo2?l000000ooooooo0000o`00001_ooooo`007?ooool00ol0003oooooooooo`1Noooo
o`;o00003_ooool2o`0000Cooooo0_l00004ooooo`oo00008?ooool2o`0000cooooo5?l00008oooo
o`Co000000?oooooo`000?l000006?ooool2o`0005Gooooo000Looooo`03o`000?oooooooooo05;o
oooo0_l0000;ooooo`;o00005_ooool2o`000003ooooool0003o000000?o000000Goooooo`000?l0
003o0000ooooo`03o`0002;ooooo0_l0000=ooooo`;o000000?oooooo`000?l000003ol000000ooo
oooo0000o`000006ooooo`;o00006oooool2o`0005Gooooo000Looooo`03o`000?oooooooooo05;o
oooo0_l0000;ooooo`;o00002?ooool2o`0000cooooo0_l000000ooooooo0000o`000007o`0000;o
oooo0ol0000eooooo`oo000000?oooooo`000?l000000oooool4o`0001[ooooo0_l0001Gooooo`00
7?ooool00ol0003oooooooooo`1Dooooo`;o00004oooool3o`0000_ooooo3_l000000ooooooo0000
o`00000;ooooo`;o00002_ooool2o`0001_ooooo2_l000000ooooooo0000o`000004o`0000Gooooo
1?l0000Jooooo`;o0000Eoooool001cooooo00?o0000ooooooooool0E?ooool2o`0001?ooooo0ol0
000;ooooo`Oo00001?ooool3o`0000Kooooo1?l00004ooooo`;o000000?oooooo`000?l000001ooo
ool3o`0001[ooooo1?l00003ooooo`;o00001?ooool4o`00027ooooo0_l0001Iooooo`007?ooool0
0ol0003oooooooooo`1aooooo`;o00001?ooool2o`0000?ooooo0_l00004ooooo`;o00001Oooool6
o`0000Oooooo0_l00008ooooo`;o00009oooool2o`000004ooooool0003o0000o`0001kooooo0ol0
000Aooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0H_ooool2o`0000gooooo0_l00009
ooooo`Co00000_ooool3o`000003ooooool0003o000000Go00002Oooool2o`0001?ooooo0ol0000N
ooooo`?o00007_ooool2o`0001;ooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`1Roooo
o`;o00001oooool2o`00013ooooo0ol00003ooooo`Oo000000?oooooo`000?l000003Oooool2o`00
00Sooooo0_l00005ooooo`?o00002_ooool2o`0008oooooo000Looooo`03o`000?oooooooooo05So
oooo0_l0000Aooooo`;o00002_ooool2o`0000Cooooo0_l000001Ooooooo0000o`000?l0003ooooo
00;o000000?oooooo`000?l000004Oooool4o`0000Kooooo0_l0000Booooo`;o00000_ooool2o`00
00cooooo0ol0001looooo`007?ooool2o`0005Wooooo0_l0000Aooooo`;o00001_ooool6o`0000Oo
oooo0ol00004ooooo`;o00004oooool2o`0001kooooo0_l0000<ooooo`?o0000O?ooool001cooooo
00?o0000ooooooooool0FOooool2o`0001Sooooo1ol00006ooooo`?o00002oooool2o`0000Sooooo
0_l0001=ooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0FOooool2o`0001Sooooo0_l0
0003ooooo`;o00001_ooool3o`0000_ooooo0_l00003ooooo`;o00000oooool2o`0004_ooooo1?l0
001Pooooo`007?ooool00ol0003oooooooooo`1oooooo`;o00001Oooool2o`0000Wooooo1ol0001=
ooooo`;o0000H_ooool001cooooo00?o0000ooooooooool0M?ooool2o`0000Kooooo0_l000000ooo
oooo0000o`000002ooooo`Go00002Oooool2o`0000;ooooo0ol000000ooooooo0000o`00000Toooo
o`;o0000>?ooool2o`0004kooooo000Looooo`03o`000?oooooooooo06Sooooo0_l0000:ooooo`;o
00001Oooool6o`0000;ooooo1Ol00007ooooo`;o00000_ooool2o`000004ooooool0003o0000oooo
o`;o00009?ooool3o`0001kooooo0_l0000Gooooo`;o0000C_ooool001cooooo00?o0000oooooooo
ool0G?ooool2o`0000[ooooo0ol0000@ooooo`Ko00002oooool5o`000005ooooool0003o0000o`00
0?ooool00ol0000Wooooo`Co00006_ooool4o`0006Oooooo000Looooo`03o`000?oooooooooo05co
oooo0_l0000;ooooo`;o00001?ooool2o`0000[ooooo0_l00005ooooo`Co00000_ooool2o`0000;o
oooo1?l00002ooooo`?o00000_ooool2o`0002Wooooo0_l00004ooooo`;o00002Oooool2o`0000Oo
oooo1Ol0001Xooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o00002_ooool2o`0000?ooooo
1?l00002ooooo`;o00002?ooool2o`000003ooooool0003o000000;o00000_ooool2o`0000;ooooo
1_l0000fooooo`;o00002Oooool2o`0000Oooooo0_l0000Fooooo`;o0000Doooool001cooooo00?o
0000ooooooooool0G_ooool2o`0000[ooooo0_l00005ooooo`;o00000_ooool2o`0000Sooooo0_l0
000=ooooo`Co0000A?ooool2o`0001cooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`22
ooooo`;o00000oooool2o`0000Gooooo1?l0000:ooooo`;o0000;_ooool2o`0000Sooooo0_l0001a
ooooo`007?ooool00ol0003oooooooooo`21ooooo`?o00000oooool2o`0000?ooooo0ol0000=oooo
o`;o0000;_ooool2o`0000?ooooo0_l0001fooooo`007?ooool00ol0003oooooooooo`1dooooo`;o
00001?ooool2o`0000Gooooo0_l000000ooooooo0000o`000006ooooo`?o0000>_ooool2o`0000Ko
oooo0_l0000Mooooo`;o0000Eoooool001cooooo00?o0000ooooooooool0M?ooool2o`0000Cooooo
0_l00008ooooo`Ko00000oooool2o`0003[ooooo0_l000000ooooooo0000o`00000Rooooo`;o0000
Eoooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0
003o8B4Qolc<c006ooooo`03o`000?oooooooooo06oooooo0_l00003ooooo`;o00004?ooool4o`00
0003ooooool0003o000000;o0000?Oooool2o`0007_ooooo00001_ooooooMgMgoiRHV?ooooooV9RH
ogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003ooooooooo
o`1_ooooo`;o00004_ooool2o`000004ooooool0003o0000o`0000;ooooo0_l0000mooooo`;o0000
OOooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool0Poooool2o`0000;ooooo0_l000000ooooooo0000
o`00000nooooo`;o0000OOooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Ooo
ool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol00029ooooo`Co0000G?ooool2o`0005kooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Goc<c<o`000?l0003o0000
olc<c006ooooo`03o`000?oooooooooo08Wooooo1?l0001Looooo`;o0000G_ooool00003ooooool@
413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo
00?o0000ooooooooool0POooool2o`0000Wooooo0_l0002kooooo`0000KoooooogMgMonHV9Sooooo
oiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`1foooo
o`;o00002Oooool2o`0000Wooooo0_l0002kooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;
ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`1fooooo`;o0000Jooo
ool2o`0006Cooooo000Looooo`03o`000?oooooooooo08Sooooo0_l0000Cooooo`;o0000@_ooool4
o`0006Cooooo000Looooo`03o`000?oooooooooo07Sooooo0_l0000>ooooo`;o00004oooool2o`00
02?ooooo1?l0000Kooooo`;o0000I_ooool001cooooo00?o0000ooooooooool0N?ooool2o`0001_o
oooo0_l0000[ooooo`Co0000Poooool001cooooo00?o0000ooooooooool0L?ooool2o`0001Sooooo
1?l00007ooooo`;o0000/_ooool001cooooo00?o0000ooooooooool0L?ooool2o`0001Sooooo1?l0
000aooooo`;o00006_ooool2o`0006cooooo000Looooo`03o`000?oooooooooo0;oooooo0_l0000J
ooooo`;o0000K?ooool001cooooo00?o0000ooooooooool0Loooool2o`000=Cooooo000Looooo`03
o`000?oooooooooo07?ooooo0_l0000Nooooo`;o0000]?ooool001cooooo00?o0000ooooooooool0
Soooool2o`0000;ooooo0_l0000Wooooo`;o0000Roooool001cooooo00?o0000ooooooooool0Sooo
ool2o`0000_ooooo0_l0000Nooooo`;o0000Roooool001cooooo00?o0000ooooooooool0Toooool2
o`0000Kooooo0ol00002ooooo`;o00001Oooool2o`0000[ooooo0_l0002Dooooo`007?ooool2o`00
09Cooooo0_l00005ooooo`?o00000oooool2o`0000Gooooo0_l00008ooooo`Co00007?ooool4o`00
07Cooooo000Looooo`03o`000?oooooooooo08_ooooo0ol0000<ooooo`Co00004oooool2o`0001ko
oooo1?l0001dooooo`007?ooool00ol0003oooooooooo`2;ooooo`?o00003_ooool2o`0000cooooo
0_l0002Mooooo`007?ooool00ol0003oooooooooo`2Zooooo`;o0000WOooool001cooooo00?o0000
ooooooooool0T?ooool2o`0001Wooooo1_l000000ooooooo0000o`00002Eooooo`007?ooool00ol0
003oooooooooo`2@ooooo`;o00006Oooool6o`000005ooooool0003o0000o`000?ooool00_l0002A
ooooo`007?ooool00ol0003oooooooooo`2cooooo`;o000000?oooooo`000?l000001?ooool2o`00
08_ooooo000Looooo`03o`000?oooooooooo08Cooooo0_l0000`ooooo`;o00001?ooool2o`0008_o
oooo000Looooo`03o`000?oooooooooo08Cooooo0_l0000Gooooo`;o00002oooool2o`0001[ooooo
0_l00021ooooo`007?ooool00ol0003oooooooooo`26ooooo`;o00005Oooool2o`0000Cooooo1?l0
0003ooooo`;o00006?ooool4o`00087ooooo000Looooo`03o`000?oooooooooo08Kooooo0_l0000K
ooooo`Co00003_ooool2o`0000?ooooo0_l00008ooooo`;o0000Poooool001cooooo00?o0000oooo
ooooool0R_ooool2o`0002Wooooo0_l00003ooooo`;o0000SOooool001cooooo00?o0000oooooooo
ool0R_ooool2o`0002Wooooo0_l0002Booooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`2Hooooo`;o0000[oooool001cooooo00?o0000ooooooooool0V?oo
ool2o`000:oooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Boooo
o`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003ooooo
ooooo`05ooooo`?o0000oooooom:ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000D
ooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBoooo
o`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Booooo`03oeEEEOmVIVKo00000?oooooo
E?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Gooooo00Co410@o`000?l0
003ooooo0_l000000ol@413oooooooooo`0Gooooo`;o000000Co410@oooooooooooooooo1Ol00003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0T?ooool00:Kooooo00Go0000ooooooooooooooooo`00
0009ooooo`Ko00003?ooool00ol0003oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg093ooooo002Vooooo`05o`000?ooooooooooooooool0
00006?ooool5o`0000Cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@
093ooooo002Vooooo`05o`000?ooooooooooooooool000002Oooool6o`0000Wooooo00CoA4A4omgM
gOoooooo00001_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool00000T?oo
ool00:Kooooo00Go0000ohN7QoooooooZJVYo`00000Hooooo`04omgMgOmEEEGoooooo`0000Oooooo
00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo0000093ooooo002Uooooo`03oa0@
4?l0003oMgMg00;o000000?oV9RHooooooooool05oooool00omgMgOoc<c<o`000008ooooo`05o`00
0?ooooooooooooooool@41000oooool00ol@413oooooooooo`2>ooooo`00a?ooool00oo^k^koA4A4
o`000004ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
093ooooo0035ooooo`03ogMgMol0003ooooo00?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h0T?ooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(426) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.38007 .44706 Mdot
.36496 .41276 Mdot
.53981 .67964 Mdot
.57319 .35368 Mdot
.75265 .57508 Mdot
.57926 .69036 Mdot
.36711 .68457 Mdot
.36737 .69019 Mdot
.58934 .7041 Mdot
.32725 .30582 Mdot
.38828 .65271 Mdot
.53519 .43237 Mdot
.37838 .67149 Mdot
.56115 .37799 Mdot
.44784 .45755 Mdot
.60954 .3482 Mdot
.35783 .39164 Mdot
.69737 .58982 Mdot
.61954 .36579 Mdot
.54478 .71509 Mdot
.642 .2765 Mdot
.55682 .38913 Mdot
.32762 .43532 Mdot
.56135 .38111 Mdot
.59316 .39746 Mdot
.34722 .41537 Mdot
.37561 .45286 Mdot
.58382 .40186 Mdot
.52501 .41745 Mdot
.38863 .65847 Mdot
.56924 .62454 Mdot
.54206 .17576 Mdot
.53859 .33784 Mdot
.48386 .24651 Mdot
.36103 .68678 Mdot
.38687 .60344 Mdot
.55359 .71333 Mdot
.40361 .64092 Mdot
.35847 .68742 Mdot
.35621 .66775 Mdot
.36663 .65199 Mdot
.34092 .41839 Mdot
.36784 .64024 Mdot
.46463 .81829 Mdot
.57416 .36685 Mdot
.43437 .43323 Mdot
.40124 .79198 Mdot
.56643 .41781 Mdot
.36115 .39773 Mdot
.53812 .7102 Mdot
.76167 .49066 Mdot
.4095 .67097 Mdot
.39655 .57513 Mdot
.66516 .84562 Mdot
.37745 .65929 Mdot
.61216 .39676 Mdot
.59168 .72154 Mdot
.53469 .37422 Mdot
.57324 .34975 Mdot
.47027 .22216 Mdot
.53425 .39266 Mdot
.70667 .56432 Mdot
.33607 .38195 Mdot
.60583 .71988 Mdot
.59039 .69808 Mdot
.40263 .64139 Mdot
.31545 .42434 Mdot
.38649 .67598 Mdot
.5131 .40675 Mdot
.53629 .69334 Mdot
.53414 .4194 Mdot
.39159 .65729 Mdot
.34182 .45345 Mdot
.57884 .36838 Mdot
.30599 .61784 Mdot
.35005 .74532 Mdot
.60664 .66965 Mdot
.57062 .23098 Mdot
.81129 .53961 Mdot
.56264 .59925 Mdot
.57465 .38121 Mdot
.69487 .77875 Mdot
.49599 .51814 Mdot
.37389 .41795 Mdot
.29766 .449 Mdot
.27192 .47344 Mdot
.57183 .41334 Mdot
.52073 .6131 Mdot
.59622 .34991 Mdot
.65202 .56449 Mdot
.58441 .72042 Mdot
.37391 .43077 Mdot
.57671 .37104 Mdot
.51329 .37465 Mdot
.27531 .34909 Mdot
.57592 .42813 Mdot
.58106 .35796 Mdot
.28945 .45029 Mdot
.3915 .64876 Mdot
.59928 .30929 Mdot
.73997 .51707 Mdot
.40065 .53402 Mdot
.6063 .40333 Mdot
.56423 .71005 Mdot
.3592 .38016 Mdot
.59339 .36594 Mdot
.38021 .68669 Mdot
.56953 .38448 Mdot
.34907 .68756 Mdot
.32752 .39938 Mdot
.52444 .35232 Mdot
.71267 .58724 Mdot
.66216 .3613 Mdot
.32927 .42935 Mdot
.45583 .33829 Mdot
.54484 .39722 Mdot
.52725 .37843 Mdot
.36228 .40854 Mdot
.54169 .69816 Mdot
.56775 .77985 Mdot
.3339 .44408 Mdot
.35563 .66867 Mdot
.36614 .39504 Mdot
.59529 .44275 Mdot
.54454 .70678 Mdot
.40671 .54912 Mdot
.4074 .5419 Mdot
.69189 .45655 Mdot
.58027 .37523 Mdot
.66409 .39734 Mdot
.56896 .70225 Mdot
.34417 .40958 Mdot
.38612 .6669 Mdot
.61572 .40147 Mdot
.34004 .43363 Mdot
.37162 .69491 Mdot
.73576 .55389 Mdot
.72651 .6001 Mdot
.33572 .4054 Mdot
.4334 .39134 Mdot
.34741 .70031 Mdot
.36312 .65127 Mdot
.75735 .48886 Mdot
.37377 .41631 Mdot
.7187 .57674 Mdot
.38461 .695 Mdot
.74137 .36204 Mdot
.56783 .3446 Mdot
.71619 .4781 Mdot
.64015 .79839 Mdot
.76146 .49093 Mdot
.52699 .1957 Mdot
.71541 .58532 Mdot
.37374 .69662 Mdot
.55034 .42264 Mdot
.35422 .43144 Mdot
.33976 .42839 Mdot
.51525 .3921 Mdot
.59312 .37775 Mdot
.56158 .36596 Mdot
.58339 .35104 Mdot
.45152 .67566 Mdot
.57517 .37467 Mdot
.20623 .58843 Mdot
.34896 .43756 Mdot
.60006 .38612 Mdot
.5499 .6927 Mdot
.56069 .31387 Mdot
.38557 .63489 Mdot
.57153 .35015 Mdot
.59362 .38491 Mdot
.5971 .42785 Mdot
.35398 .67694 Mdot
.29017 .63053 Mdot
.82906 .51187 Mdot
.38228 .61315 Mdot
.33216 .73701 Mdot
.56629 .68902 Mdot
.53426 .40052 Mdot
.73272 .57087 Mdot
.58488 .30947 Mdot
.54688 .34952 Mdot
.76969 .49498 Mdot
.58279 .38882 Mdot
.55127 .20637 Mdot
.4973 .40941 Mdot
.28628 .48712 Mdot
.19871 .53181 Mdot
.55325 .34663 Mdot
.36769 .30502 Mdot
.70095 .48345 Mdot
.62932 .6827 Mdot
.386 .6613 Mdot
.55381 .67551 Mdot
.54115 .68796 Mdot
.40918 .64536 Mdot
.48384 .32479 Mdot
.34665 .29324 Mdot
.54791 .42761 Mdot
.40244 .53972 Mdot
.30178 .4228 Mdot
.71175 .58284 Mdot
.33871 .40365 Mdot
.73103 .75063 Mdot
.58633 .59005 Mdot
.52665 .60575 Mdot
.69227 .59233 Mdot
.54817 .72747 Mdot
.40269 .55309 Mdot
.72549 .57422 Mdot
.55312 .35828 Mdot
.33537 .39746 Mdot
.7155 .48275 Mdot
.5845 .31395 Mdot
.18653 .36209 Mdot
.36832 .45471 Mdot
.66123 .45469 Mdot
.37883 .66224 Mdot
.60003 .68384 Mdot
.57281 .41294 Mdot
.54428 .37829 Mdot
.31155 .41329 Mdot
.54236 .41897 Mdot
.51946 .5803 Mdot
.59068 .38454 Mdot
.60446 .72086 Mdot
.73658 .61948 Mdot
.3872 .62145 Mdot
.67834 .57558 Mdot
.33625 .44936 Mdot
.30179 .73853 Mdot
.55716 .70709 Mdot
.56234 .29537 Mdot
.39301 .67219 Mdot
.73906 .55818 Mdot
.56414 .7177 Mdot
.69838 .58394 Mdot
.52941 .35092 Mdot
.55861 .71992 Mdot
.70368 .57061 Mdot
.48899 .57144 Mdot
.59048 .36234 Mdot
.70535 .40959 Mdot
.40084 .68638 Mdot
.38055 .41848 Mdot
.53133 .35846 Mdot
.39127 .57191 Mdot
.61143 .42571 Mdot
.62182 .48626 Mdot
.39194 .56769 Mdot
.38755 .53019 Mdot
.53816 .57935 Mdot
.71421 .54404 Mdot
.3224 .64115 Mdot
.50157 .59956 Mdot
.35719 .39145 Mdot
.52465 .35843 Mdot
.35671 .54579 Mdot
.39694 .69247 Mdot
.54617 .36133 Mdot
.33011 .5251 Mdot
.38328 .69565 Mdot
.53093 .37281 Mdot
.36642 .65401 Mdot
.34509 .43188 Mdot
.49602 .54291 Mdot
.38194 .40839 Mdot
.56147 .3533 Mdot
.37322 .64953 Mdot
.54965 .67927 Mdot
.34723 .41618 Mdot
.56522 .38792 Mdot
.57237 .39437 Mdot
.39822 .53787 Mdot
.58769 .36868 Mdot
.30589 .48635 Mdot
.57073 .41633 Mdot
.53332 .69915 Mdot
.55318 .42748 Mdot
.74714 .51114 Mdot
.67824 .53082 Mdot
.31827 .40585 Mdot
.39115 .5663 Mdot
.57979 .72616 Mdot
.49084 .55123 Mdot
.68871 .40467 Mdot
.57116 .37797 Mdot
.38955 .55374 Mdot
.65637 .46782 Mdot
.38607 .63581 Mdot
.5303 .33671 Mdot
.50126 .68831 Mdot
.58034 .72099 Mdot
.40344 .54467 Mdot
.60548 .32109 Mdot
.35377 .46582 Mdot
.60518 .40843 Mdot
.55551 .7133 Mdot
.38329 .41845 Mdot
.59016 .42434 Mdot
.37319 .76569 Mdot
.39101 .57259 Mdot
.38457 .64334 Mdot
.29501 .46284 Mdot
.52505 .39934 Mdot
.54407 .67939 Mdot
.33551 .42809 Mdot
.36925 .66379 Mdot
.32957 .43432 Mdot
.7175 .48851 Mdot
.62702 .47457 Mdot
.43383 .60432 Mdot
.68704 .55301 Mdot
.71202 .24496 Mdot
.37475 .61175 Mdot
.59288 .3079 Mdot
.54621 .64888 Mdot
.22101 .42305 Mdot
.56741 .71561 Mdot
.43007 .39418 Mdot
.58822 .72097 Mdot
.59072 .4155 Mdot
.58329 .69176 Mdot
.24963 .3624 Mdot
.57915 .40032 Mdot
.58941 .68798 Mdot
.47036 .66098 Mdot
.57731 .39891 Mdot
.34 .43593 Mdot
.43087 .16845 Mdot
.51776 .26766 Mdot
.51117 .28289 Mdot
.59653 .719 Mdot
.41593 .3754 Mdot
.58068 .40549 Mdot
.62259 .37431 Mdot
.35505 .42688 Mdot
.58924 .43288 Mdot
.70196 .54628 Mdot
.69375 .57757 Mdot
.75624 .42991 Mdot
.62786 .23961 Mdot
.482 .32225 Mdot
.34442 .42195 Mdot
.81538 .55947 Mdot
.30328 .61253 Mdot
.39184 .57325 Mdot
.36854 .69225 Mdot
.30033 .64829 Mdot
.60088 .33145 Mdot
.29919 .37254 Mdot
.51587 .57488 Mdot
.37487 .43997 Mdot
.45352 .59135 Mdot
.36652 .6698 Mdot
.51159 .27938 Mdot
.35158 .27349 Mdot
.56111 .36437 Mdot
.4055 .65705 Mdot
.54703 .43829 Mdot
.51309 .60739 Mdot
.70037 .44013 Mdot
.44593 .7628 Mdot
.56396 .35485 Mdot
.32622 .6213 Mdot
.54294 .35171 Mdot
.69645 .46035 Mdot
.54664 .35873 Mdot
.3376 .43987 Mdot
.62456 .40831 Mdot
.49574 .59592 Mdot
.74311 .29506 Mdot
.58351 .58225 Mdot
.69716 .56551 Mdot
.55775 .37856 Mdot
.55036 .36759 Mdot
.7046 .56353 Mdot
.3734 .43664 Mdot
.5228 .36424 Mdot
.37264 .79519 Mdot
.57618 .37537 Mdot
.4113 .66795 Mdot
.5847 .5198 Mdot
.59793 .20563 Mdot
.55466 .41041 Mdot
.34845 .46459 Mdot
.36873 .64639 Mdot
.39386 .68299 Mdot
.47837 .42071 Mdot
.40375 .6825 Mdot
.54524 .42124 Mdot
.5831 .52003 Mdot
.32068 .41785 Mdot
.48303 .38085 Mdot
.37085 .44458 Mdot
.81404 .57228 Mdot
.38224 .69778 Mdot
.38677 .55734 Mdot
.46456 .34005 Mdot
.37273 .68327 Mdot
.67061 .60215 Mdot
.62466 .40507 Mdot
.53736 .32745 Mdot
.33573 .48191 Mdot
.55071 .6748 Mdot
.39452 .55997 Mdot
.37519 .65944 Mdot
.57394 .37219 Mdot
.60721 .3916 Mdot
.4076 .6723 Mdot
.43424 .20181 Mdot
.57217 .6252 Mdot
.56141 .35249 Mdot
.34813 .44492 Mdot
.34238 .4118 Mdot
.59793 .3575 Mdot
.53699 .35402 Mdot
.57185 .67928 Mdot
.38952 .55519 Mdot
.39147 .56327 Mdot
.4048 .53528 Mdot
.60323 .70284 Mdot
.71829 .25558 Mdot
.36399 .64974 Mdot
.55706 .18196 Mdot
.30609 .56796 Mdot
.51582 .44707 Mdot
.54499 .69587 Mdot
.5392 .38544 Mdot
.5973 .40793 Mdot
.3755 .64981 Mdot
.70658 .27061 Mdot
.62198 .38512 Mdot
.38128 .43613 Mdot
.40913 .66552 Mdot
.55689 .437 Mdot
.34867 .70943 Mdot
.73737 .58265 Mdot
.47981 .31763 Mdot
.40513 .68178 Mdot
.32264 .41097 Mdot
.4056 .681 Mdot
.55395 .36664 Mdot
.60567 .32026 Mdot
.37489 .44223 Mdot
.74041 .59239 Mdot
.51524 .38263 Mdot
.531 .36941 Mdot
.63002 .75802 Mdot
.30871 .61737 Mdot
.67004 .56315 Mdot
.57752 .41842 Mdot
.52624 .33104 Mdot
.72906 .59605 Mdot
.51888 .38586 Mdot
.55748 .42732 Mdot
.66675 .38904 Mdot
.34722 .6817 Mdot
.72608 .54324 Mdot
.73617 .29308 Mdot
.37085 .45362 Mdot
.32858 .49929 Mdot
.40435 .53903 Mdot
.41306 .63954 Mdot
.48822 .53723 Mdot
.39918 .54891 Mdot
.31063 .54866 Mdot
.24829 .70262 Mdot
.39403 .55692 Mdot
.60742 .70609 Mdot
.33504 .34567 Mdot
.53853 .42283 Mdot
.54947 .35226 Mdot
.7119 .54516 Mdot
.36386 .40529 Mdot
.20777 .57969 Mdot
.39332 .61833 Mdot
.54908 .39329 Mdot
.37629 .45568 Mdot
.27602 .47858 Mdot
.40154 .54446 Mdot
.7333 .57733 Mdot
.74933 .58342 Mdot
.53639 .35613 Mdot
.67857 .4459 Mdot
.34389 .41888 Mdot
.56515 .38788 Mdot
.52465 .3842 Mdot
.57254 .73191 Mdot
.33781 .39732 Mdot
.55182 .6941 Mdot
.38184 .55754 Mdot
.20561 .41371 Mdot
.5003 .85015 Mdot
.39878 .68747 Mdot
.4429 .52084 Mdot
.38993 .6226 Mdot
.40654 .76318 Mdot
.38967 .55687 Mdot
.56158 .38863 Mdot
.32667 .44015 Mdot
.56829 .38614 Mdot
.57656 .37365 Mdot
.56942 .36008 Mdot
.48303 .32052 Mdot
.80565 .55258 Mdot
.73086 .55824 Mdot
.53145 .40996 Mdot
.59925 .71951 Mdot
.31101 .50246 Mdot
.26798 .322 Mdot
.55222 .37636 Mdot
.52752 .37727 Mdot
.31725 .43348 Mdot
.53969 .34342 Mdot
.37169 .68915 Mdot
.37816 .43385 Mdot
.60913 .39616 Mdot
.7497 .5217 Mdot
.52297 .36601 Mdot
.44338 .53802 Mdot
.3927 .70068 Mdot
.63412 .36417 Mdot
.5059 .36077 Mdot
.38924 .55799 Mdot
.39529 .55915 Mdot
.37981 .56222 Mdot
.40825 .65339 Mdot
.57361 .73108 Mdot
.61206 .71518 Mdot
.50588 .36751 Mdot
.55926 .42191 Mdot
.58567 .31603 Mdot
.53091 .70771 Mdot
.49979 .61558 Mdot
.43234 .4046 Mdot
.5179 .42829 Mdot
.5974 .69037 Mdot
.29082 .45453 Mdot
.60464 .24881 Mdot
.37898 .4266 Mdot
.54021 .65533 Mdot
.38853 .68373 Mdot
.70495 .58457 Mdot
.7494 .45816 Mdot
.33532 .44314 Mdot
.33157 .45128 Mdot
.57197 .68373 Mdot
.55352 .51517 Mdot
.73154 .80448 Mdot
.56969 .70823 Mdot
.52517 .59949 Mdot
.35162 .42454 Mdot
.55294 .3365 Mdot
.65012 .47717 Mdot
.53795 .50953 Mdot
.59384 .69524 Mdot
.57243 .3934 Mdot
.66216 .61524 Mdot
.57262 .67941 Mdot
.56869 .3224 Mdot
.59735 .71866 Mdot
.39327 .64596 Mdot
.56458 .70203 Mdot
.38857 .44379 Mdot
.57857 .37977 Mdot
.68366 .83484 Mdot
.4865 .51624 Mdot
.56161 .39555 Mdot
.40704 .67992 Mdot
.46759 .68702 Mdot
.55486 .3621 Mdot
.69392 .55702 Mdot
.6014 .71892 Mdot
.42685 .76323 Mdot
.58274 .42269 Mdot
.58303 .68795 Mdot
.37814 .46261 Mdot
.52795 .67087 Mdot
.72879 .51556 Mdot
.3932 .56213 Mdot
.34844 .43362 Mdot
.35795 .61354 Mdot
.35997 .65902 Mdot
.61394 .37348 Mdot
.52656 .38965 Mdot
.35243 .44091 Mdot
.48637 .55931 Mdot
.47986 .41455 Mdot
.57445 .37986 Mdot
.56085 .68328 Mdot
.56839 .7387 Mdot
.44901 .45146 Mdot
.55699 .70937 Mdot
.52322 .33305 Mdot
.34594 .44058 Mdot
.60916 .40434 Mdot
.33172 .42517 Mdot
.52281 .36061 Mdot
.36149 .72968 Mdot
.37776 .41864 Mdot
.5924 .29861 Mdot
.58127 .37792 Mdot
.37554 .48422 Mdot
.52785 .40169 Mdot
.56961 .3557 Mdot
.57938 .73955 Mdot
.71768 .56052 Mdot
.5361 .33562 Mdot
.35846 .74552 Mdot
.73183 .59235 Mdot
.48264 .1912 Mdot
.54484 .70687 Mdot
.74818 .56926 Mdot
.7424 .41557 Mdot
.3917 .56631 Mdot
.71138 .55621 Mdot
.39315 .51626 Mdot
.4037 .6774 Mdot
.39337 .41124 Mdot
.57806 .39538 Mdot
.2156 .40133 Mdot
.5652 .62404 Mdot
.39439 .53902 Mdot
.52648 .36687 Mdot
.53822 .3814 Mdot
.3743 .45651 Mdot
.72026 .7595 Mdot
.59274 .74121 Mdot
.58558 .35832 Mdot
.33836 .44849 Mdot
.67115 .78961 Mdot
.59059 .68816 Mdot
.73604 .56089 Mdot
.36774 .7017 Mdot
.30574 .40873 Mdot
.38658 .55962 Mdot
.37977 .69779 Mdot
.59468 .65819 Mdot
.7745 .49748 Mdot
.59568 .41535 Mdot
.54721 .69448 Mdot
.76286 .49172 Mdot
.48305 .3841 Mdot
.40236 .63439 Mdot
.33276 .72041 Mdot
.37294 .42572 Mdot
.40799 .6711 Mdot
.70528 .54819 Mdot
.3461 .39268 Mdot
.3728 .44244 Mdot
.37529 .69083 Mdot
.19369 .49976 Mdot
.65392 .46911 Mdot
.41341 .68073 Mdot
.6206 .49012 Mdot
.76231 .49249 Mdot
.38668 .54282 Mdot
.73161 .57893 Mdot
.79665 .5865 Mdot
.34257 .41709 Mdot
.29924 .6459 Mdot
.76345 .49115 Mdot
.58123 .35793 Mdot
.70272 .57211 Mdot
.32152 .50361 Mdot
.41935 .6337 Mdot
.37583 .69506 Mdot
.60125 .76379 Mdot
.70103 .57725 Mdot
.54228 .34651 Mdot
.62918 .20956 Mdot
.5648 .4066 Mdot
.38872 .69437 Mdot
.5175 .57726 Mdot
.33318 .39972 Mdot
.38206 .63456 Mdot
.51999 .58066 Mdot
.59176 .41248 Mdot
.54818 .39988 Mdot
.76923 .5975 Mdot
.35058 .39523 Mdot
.38225 .55073 Mdot
.57183 .38874 Mdot
.53381 .37186 Mdot
.61028 .3686 Mdot
.6787 .27894 Mdot
.64453 .31581 Mdot
.60283 .37352 Mdot
.58641 .67073 Mdot
.59173 .31164 Mdot
.57846 .34978 Mdot
.35764 .46637 Mdot
.77495 .53487 Mdot
.38108 .55584 Mdot
.54722 .35372 Mdot
.55981 .35259 Mdot
.35795 .68449 Mdot
.65464 .46923 Mdot
.53064 .50879 Mdot
.53848 .7157 Mdot
.61202 .74683 Mdot
.51234 .41333 Mdot
.35615 .43608 Mdot
.7095 .5403 Mdot
.49413 .36045 Mdot
.37946 .44176 Mdot
.50871 .39243 Mdot
.59417 .72796 Mdot
.39235 .55356 Mdot
.47983 .38342 Mdot
.70904 .56668 Mdot
.34577 .69172 Mdot
.51158 .19691 Mdot
.5524 .67955 Mdot
.58692 .40599 Mdot
.61074 .72812 Mdot
.58101 .70803 Mdot
.3961 .53652 Mdot
.61847 .32548 Mdot
.34347 .42897 Mdot
.32462 .40997 Mdot
.79156 .53682 Mdot
.6045 .70553 Mdot
.6456 .73416 Mdot
.39898 .6495 Mdot
.5278 .40699 Mdot
.36951 .54187 Mdot
.32734 .40633 Mdot
.6936 .45573 Mdot
.74981 .57679 Mdot
.3778 .6948 Mdot
.40717 .53206 Mdot
.37948 .42052 Mdot
.32879 .40842 Mdot
.57597 .37032 Mdot
.55165 .38481 Mdot
.616 .67208 Mdot
.70493 .48019 Mdot
.36481 .65701 Mdot
.74002 .57174 Mdot
.53431 .69585 Mdot
.57481 .42209 Mdot
.3726 .41987 Mdot
.60756 .20925 Mdot
.52571 .39939 Mdot
.59874 .71989 Mdot
.36387 .41437 Mdot
.72991 .55416 Mdot
.71245 .54844 Mdot
.57505 .35646 Mdot
.56406 .21321 Mdot
.37537 .68366 Mdot
.33911 .43723 Mdot
.31046 .46777 Mdot
.53965 .41482 Mdot
.55373 .37967 Mdot
.55342 .44824 Mdot
.39049 .63129 Mdot
.4855 .39284 Mdot
.71323 .59558 Mdot
.33796 .40966 Mdot
.56718 .39138 Mdot
.70673 .56321 Mdot
.30128 .37104 Mdot
.39638 .54787 Mdot
.58504 .68421 Mdot
.69354 .5619 Mdot
.71945 .57007 Mdot
.73954 .5875 Mdot
.30147 .64763 Mdot
.37949 .38496 Mdot
.82129 .42922 Mdot
.57666 .38752 Mdot
.76219 .49284 Mdot
.60447 .35674 Mdot
.39189 .63927 Mdot
.55972 .67133 Mdot
.5709 .36716 Mdot
.57664 .38815 Mdot
.53417 .20824 Mdot
.61391 .35317 Mdot
.61864 .35922 Mdot
.32701 .40193 Mdot
.32726 .48317 Mdot
.54376 .68248 Mdot
.62337 .80304 Mdot
.4567 .14612 Mdot
.5448 .42739 Mdot
.55863 .51588 Mdot
.37732 .42779 Mdot
.3601 .69155 Mdot
.6299 .48715 Mdot
.39234 .5947 Mdot
.35171 .40387 Mdot
.58722 .41726 Mdot
.50988 .20185 Mdot
.7096 .58991 Mdot
.55922 .36677 Mdot
.38821 .66937 Mdot
.56034 .36632 Mdot
.40532 .64693 Mdot
.42321 .41691 Mdot
.51341 .51183 Mdot
.58146 .39269 Mdot
.5727 .42823 Mdot
.65968 .40095 Mdot
.55137 .37946 Mdot
.45606 .74735 Mdot
.36261 .42005 Mdot
.57918 .29535 Mdot
.6158 .3904 Mdot
.50643 .26109 Mdot
.52188 .38136 Mdot
.47265 .52991 Mdot
.53628 .39832 Mdot
.71586 .29544 Mdot
.55171 .34385 Mdot
.53571 .40072 Mdot
.36671 .66293 Mdot
.35561 .67443 Mdot
.36085 .47225 Mdot
.38402 .53952 Mdot
.29336 .4916 Mdot
.52888 .37234 Mdot
.55486 .7349 Mdot
.51402 .47835 Mdot
.7201 .56466 Mdot
.3404 .40867 Mdot
.40201 .87079 Mdot
.37355 .64205 Mdot
.60651 .70395 Mdot
.52744 .61192 Mdot
.58717 .66789 Mdot
.55197 .64849 Mdot
.35103 .48906 Mdot
.73221 .58049 Mdot
.52619 .36145 Mdot
.49406 .24692 Mdot
.32089 .61573 Mdot
.5435 .41638 Mdot
.5823 .75196 Mdot
.58391 .47235 Mdot
.79267 .52821 Mdot
.69063 .57405 Mdot
.72048 .58308 Mdot
.37048 .66475 Mdot
.53973 .6816 Mdot
.5225 .43234 Mdot
.74778 .56839 Mdot
.55843 .67324 Mdot
.40956 .55177 Mdot
.7779 .58168 Mdot
.34148 .42085 Mdot
.42254 .3778 Mdot
.41722 .47023 Mdot
.37087 .64548 Mdot
.35432 .74571 Mdot
.40453 .41887 Mdot
.36195 .38979 Mdot
.38941 .53158 Mdot
.59738 .69498 Mdot
.3957 .41352 Mdot
.57851 .37694 Mdot
.58392 .31399 Mdot
.53625 .35574 Mdot
.7156 .5452 Mdot
.52368 .37386 Mdot
.5729 .67735 Mdot
.36236 .67937 Mdot
.58153 .7229 Mdot
.36652 .68296 Mdot
.4891 .16728 Mdot
.56684 .34822 Mdot
.55594 .38137 Mdot
.57861 .51973 Mdot
.33175 .40703 Mdot
.47546 .25002 Mdot
.60001 .71765 Mdot
.58899 .72324 Mdot
.61016 .40141 Mdot
.31771 .40193 Mdot
.66942 .59348 Mdot
.62211 .49745 Mdot
.53281 .39494 Mdot
.36362 .42096 Mdot
.61124 .40066 Mdot
.40947 .7508 Mdot
.48061 .50005 Mdot
.32791 .43179 Mdot
.74462 .29558 Mdot
.58272 .3684 Mdot
.63155 .33942 Mdot
.64417 .37839 Mdot
.67549 .28738 Mdot
.5519 .33329 Mdot
.37083 .45258 Mdot
.58035 .35198 Mdot
.36097 .43327 Mdot
.57702 .71299 Mdot
.37112 .63921 Mdot
.35857 .4305 Mdot
.5715 .40254 Mdot
.46502 .14698 Mdot
.36152 .68032 Mdot
.564 .37057 Mdot
.38187 .65286 Mdot
.3877 .40769 Mdot
.35074 .39894 Mdot
.40375 .52596 Mdot
.52615 .60186 Mdot
.37297 .68815 Mdot
.55729 .42162 Mdot
.2967 .62578 Mdot
.60811 .40563 Mdot
.61022 .74858 Mdot
.59846 .42505 Mdot
.51133 .40846 Mdot
.71288 .24142 Mdot
.48435 .55092 Mdot
.53144 .85505 Mdot
.43742 .66705 Mdot
.28986 .62594 Mdot
.32473 .46992 Mdot
.69081 .57414 Mdot
.45413 .54434 Mdot
.39506 .56835 Mdot
.58186 .66718 Mdot
.57312 .36948 Mdot
.26204 .40173 Mdot
.41373 .67546 Mdot
.7225 .55815 Mdot
.58277 .38934 Mdot
.55682 .65843 Mdot
.4271 .47861 Mdot
.37607 .69615 Mdot
.33996 .41869 Mdot
.34217 .40226 Mdot
.81302 .53109 Mdot
.56383 .39321 Mdot
.55509 .38746 Mdot
.36076 .68323 Mdot
.51865 .43427 Mdot
.73993 .58497 Mdot
.47236 .65827 Mdot
.3891 .66669 Mdot
.48622 .50666 Mdot
.33248 .39732 Mdot
.5386 .3832 Mdot
.58689 .51901 Mdot
.26001 .61886 Mdot
.29651 .3185 Mdot
.7113 .57924 Mdot
.68296 .4293 Mdot
.37004 .45322 Mdot
.38561 .66459 Mdot
.74841 .42491 Mdot
.62322 .39745 Mdot
.53673 .37927 Mdot
.69163 .35441 Mdot
.62186 .49595 Mdot
.5231 .6078 Mdot
.56515 .45047 Mdot
.65893 .48416 Mdot
.6093 .40269 Mdot
.60715 .39279 Mdot
.50908 .40417 Mdot
.60776 .4201 Mdot
.36554 .42508 Mdot
.50813 .27295 Mdot
.5731 .69281 Mdot
.32855 .3229 Mdot
.61737 .74914 Mdot
.5783 .40611 Mdot
.59089 .41417 Mdot
.4026 .32202 Mdot
.58358 .49342 Mdot
.35486 .41865 Mdot
.31944 .47333 Mdot
.35981 .65708 Mdot
.6187 .36234 Mdot
.604 .71141 Mdot
.63946 .39686 Mdot
.58646 .70308 Mdot
.36607 .42281 Mdot
.55989 .72674 Mdot
.37727 .71087 Mdot
.54748 .69556 Mdot
.59483 .68378 Mdot
.37188 .6988 Mdot
.36282 .39721 Mdot
.53012 .39885 Mdot
.37647 .70127 Mdot
.67369 .60055 Mdot
.71517 .54538 Mdot
.40606 .52701 Mdot
.56221 .33749 Mdot
.6137 .34245 Mdot
.36988 .76846 Mdot
.55787 .72113 Mdot
.52431 .50184 Mdot
.37687 .4172 Mdot
.71072 .54114 Mdot
.36562 .42871 Mdot
.81028 .47856 Mdot
.7112 .57272 Mdot
.4031 .52345 Mdot
.72662 .4283 Mdot
.38224 .6186 Mdot
.58801 .43032 Mdot
.31926 .47702 Mdot
.58622 .70789 Mdot
.41067 .66659 Mdot
.32029 .50472 Mdot
.59021 .36733 Mdot
.39619 .58228 Mdot
.38185 .39725 Mdot
.3925 .56557 Mdot
.38619 .66868 Mdot
.41339 .50808 Mdot
.55736 .39619 Mdot
.38214 .61931 Mdot
.57723 .4286 Mdot
.44368 .36718 Mdot
.62407 .70678 Mdot
.28744 .4048 Mdot
.59665 .4128 Mdot
.59039 .68681 Mdot
.60257 .40894 Mdot
.36282 .35384 Mdot
.7203 .45485 Mdot
.51318 .41541 Mdot
.607 .47549 Mdot
.39101 .77934 Mdot
.37247 .4216 Mdot
.51192 .34391 Mdot
.39012 .53966 Mdot
.59273 .40512 Mdot
.24374 .2697 Mdot
.7105 .5591 Mdot
.69044 .59529 Mdot
.57385 .39959 Mdot
.57109 .38548 Mdot
.54463 .212 Mdot
.40605 .45231 Mdot
.40536 .52988 Mdot
.53911 .373 Mdot
.68344 .32581 Mdot
.36921 .66126 Mdot
.59422 .42313 Mdot
.55587 .34991 Mdot
.63784 .70004 Mdot
.37409 .65515 Mdot
.54724 .7071 Mdot
.39243 .56692 Mdot
.5577 .73294 Mdot
.75558 .57689 Mdot
.67016 .44739 Mdot
.69426 .42907 Mdot
.46615 .4848 Mdot
.6948 .56057 Mdot
.57249 .40946 Mdot
.28956 .41328 Mdot
.5615 .39998 Mdot
.7242 .58038 Mdot
.38862 .65822 Mdot
.36156 .42356 Mdot
.43148 .38939 Mdot
.40043 .53698 Mdot
.5486 .41366 Mdot
.68826 .55813 Mdot
.35259 .43042 Mdot
.23639 .62465 Mdot
.36733 .40918 Mdot
.36784 .6805 Mdot
.40875 .64512 Mdot
.71551 .56777 Mdot
.36673 .42801 Mdot
.55994 .73299 Mdot
.42991 .68675 Mdot
.56452 .43334 Mdot
.3768 .71148 Mdot
.39926 .43606 Mdot
.36593 .46025 Mdot
.31808 .42226 Mdot
.6142 .39119 Mdot
.59161 .50192 Mdot
.61172 .43688 Mdot
.36098 .68066 Mdot
.5646 .66086 Mdot
.71435 .47592 Mdot
.51995 .23433 Mdot
.50013 .5144 Mdot
.54573 .33079 Mdot
.52441 .3719 Mdot
.53527 .35711 Mdot
.60362 .3708 Mdot
.46607 .64636 Mdot
.56661 .3483 Mdot
.37058 .65188 Mdot
.58054 .70031 Mdot
.5324 .39101 Mdot
.38851 .54647 Mdot
.50166 .61344 Mdot
.718 .53938 Mdot
.47842 .31639 Mdot
.35246 .49713 Mdot
.35405 .42917 Mdot
.55424 .70896 Mdot
.56004 .72837 Mdot
.73568 .55387 Mdot
.38286 .69931 Mdot
.36067 .4034 Mdot
.7181 .30024 Mdot
.72296 .59273 Mdot
.54632 .35435 Mdot
.58167 .51979 Mdot
.66216 .26908 Mdot
.51453 .39636 Mdot
.56653 .35809 Mdot
.38128 .54842 Mdot
.60432 .69403 Mdot
.23094 .3481 Mdot
.19478 .52027 Mdot
.71641 .56223 Mdot
.74286 .57019 Mdot
.32036 .43501 Mdot
.52476 .40576 Mdot
.37793 .68364 Mdot
.66127 .46386 Mdot
.37769 .75862 Mdot
.27588 .4713 Mdot
.40934 .76257 Mdot
.52191 .36857 Mdot
.45471 .31862 Mdot
.59704 .42705 Mdot
.36079 .38042 Mdot
.31606 .41326 Mdot
.34851 .42024 Mdot
.3662 .66711 Mdot
.77748 .49876 Mdot
.37392 .64769 Mdot
.30778 .48088 Mdot
.35728 .45468 Mdot
.49861 .56651 Mdot
.59148 .72261 Mdot
.60733 .3517 Mdot
.73026 .58128 Mdot
.66285 .53448 Mdot
.51698 .34021 Mdot
.67965 .43568 Mdot
.54507 .69638 Mdot
.37656 .40776 Mdot
.60643 .35597 Mdot
.30143 .49926 Mdot
.5488 .51672 Mdot
.40975 .78597 Mdot
.26673 .40193 Mdot
.70476 .56605 Mdot
.34357 .30291 Mdot
.73072 .5899 Mdot
.37936 .69497 Mdot
.58177 .36556 Mdot
.52288 .40015 Mdot
.56789 .35434 Mdot
.61385 .40703 Mdot
.37669 .65798 Mdot
.55195 .43306 Mdot
.74823 .51136 Mdot
.40816 .55723 Mdot
.48621 .60962 Mdot
.71187 .55039 Mdot
.39759 .64626 Mdot
.58075 .70513 Mdot
.39066 .52898 Mdot
.68633 .55307 Mdot
.60425 .36241 Mdot
.56732 .40239 Mdot
.40857 .54695 Mdot
.47865 .39329 Mdot
.59877 .33233 Mdot
.57719 .689 Mdot
.5088 .60507 Mdot
.73427 .54837 Mdot
.71396 .58653 Mdot
.40688 .66622 Mdot
.36592 .42896 Mdot
.73854 .55416 Mdot
.54144 .67576 Mdot
.59175 .42222 Mdot
.56561 .42906 Mdot
.39646 .4425 Mdot
.76705 .49351 Mdot
.71629 .5388 Mdot
.48547 .39064 Mdot
.33258 .4154 Mdot
.38079 .396 Mdot
.54052 .37231 Mdot
.51207 .4191 Mdot
.31867 .43886 Mdot
.73721 .55778 Mdot
.40457 .65691 Mdot
.51654 .54685 Mdot
.38142 .64146 Mdot
.33562 .42582 Mdot
.58458 .3123 Mdot
.35423 .39451 Mdot
.59126 .36976 Mdot
.54906 .87174 Mdot
.55595 .34576 Mdot
.58101 .27843 Mdot
.62505 .60869 Mdot
.59841 .71646 Mdot
.59953 .70602 Mdot
.39086 .55269 Mdot
.3794 .43978 Mdot
.50807 .34383 Mdot
.73541 .58043 Mdot
.2905 .62571 Mdot
.40865 .43507 Mdot
.59563 .68601 Mdot
.60607 .71017 Mdot
.38673 .65711 Mdot
.52202 .37846 Mdot
.53806 .38634 Mdot
.54735 .69792 Mdot
.47217 .6798 Mdot
.36513 .43728 Mdot
.55551 .38729 Mdot
.60777 .37295 Mdot
.57464 .69499 Mdot
.42075 .6634 Mdot
.40113 .4165 Mdot
.61419 .38904 Mdot
.71172 .45573 Mdot
.39722 .63964 Mdot
.57843 .41219 Mdot
.6003 .42744 Mdot
.72316 .56778 Mdot
.68852 .41067 Mdot
.75737 .48913 Mdot
.35465 .66338 Mdot
.38889 .56164 Mdot
.51507 .38887 Mdot
.59755 .71477 Mdot
.57406 .34008 Mdot
.167 .58899 Mdot
.40598 .56368 Mdot
.55458 .39506 Mdot
.50294 .4043 Mdot
.33122 .42716 Mdot
.5629 .38965 Mdot
.35979 .72893 Mdot
.55733 .6888 Mdot
.55361 .39568 Mdot
.56333 .21539 Mdot
.38727 .65868 Mdot
.51745 .34047 Mdot
.70195 .58089 Mdot
.52142 .59882 Mdot
.43732 .16808 Mdot
.52981 .70137 Mdot
.70533 .55389 Mdot
.52357 .37825 Mdot
.54394 .72359 Mdot
.36571 .70039 Mdot
.63197 .30376 Mdot
.57121 .41121 Mdot
.37741 .64308 Mdot
.36372 .68361 Mdot
.71317 .56479 Mdot
.49052 .87842 Mdot
.51054 .41153 Mdot
.55669 .37106 Mdot
.32217 .76953 Mdot
.32163 .44612 Mdot
.56422 .36854 Mdot
.52429 .38643 Mdot
.40134 .68562 Mdot
.79363 .45578 Mdot
.68237 .42982 Mdot
.46936 .6593 Mdot
.40129 .64275 Mdot
.58301 .74751 Mdot
.55384 .68525 Mdot
.70397 .55661 Mdot
.36367 .41322 Mdot
.71585 .54281 Mdot
.56528 .69765 Mdot
.56662 .35559 Mdot
.39956 .67382 Mdot
.3691 .23064 Mdot
.398 .69657 Mdot
.54223 .67045 Mdot
.3714 .38583 Mdot
.25796 .36242 Mdot
.18108 .63137 Mdot
.432 .44612 Mdot
.38797 .62769 Mdot
.72035 .56467 Mdot
.19779 .55422 Mdot
.5322 .39207 Mdot
.41565 .36009 Mdot
.55836 .36822 Mdot
.2763 .38527 Mdot
.55976 .67179 Mdot
.40923 .54047 Mdot
.59048 .3673 Mdot
.68309 .42526 Mdot
.37158 .69744 Mdot
.38633 .68325 Mdot
.58188 .35376 Mdot
.36898 .68238 Mdot
.54257 .38985 Mdot
.57688 .70044 Mdot
.51536 .86732 Mdot
.54314 .40246 Mdot
.61511 .31497 Mdot
.37977 .62458 Mdot
.40893 .53032 Mdot
.60194 .73923 Mdot
.48962 .28323 Mdot
.276 .48303 Mdot
.37678 .68156 Mdot
.48424 .31722 Mdot
.55934 .71926 Mdot
.38773 .5299 Mdot
.57412 .74354 Mdot
.54866 .37203 Mdot
.52023 .37288 Mdot
.6012 .36963 Mdot
.52494 .38068 Mdot
.39038 .35138 Mdot
.59697 .33528 Mdot
.39193 .26025 Mdot
.57621 .38798 Mdot
.5686 .27874 Mdot
.3763 .64787 Mdot
.63469 .34472 Mdot
.53983 .57179 Mdot
.53319 .35119 Mdot
.33749 .48369 Mdot
.39624 .64637 Mdot
.36129 .56873 Mdot
.37501 .65712 Mdot
.5841 .722 Mdot
.36907 .69333 Mdot
.58525 .36868 Mdot
.34323 .41234 Mdot
.55905 .70678 Mdot
.44419 .4146 Mdot
.56769 .66344 Mdot
.5615 .39552 Mdot
.37134 .61783 Mdot
.58573 .73056 Mdot
.62111 .3566 Mdot
.34611 .40988 Mdot
.69752 .32843 Mdot
.32813 .38143 Mdot
.5657 .38368 Mdot
.56723 .37766 Mdot
.40787 .53718 Mdot
.37348 .69649 Mdot
.3257 .39867 Mdot
.64074 .68865 Mdot
.69579 .54441 Mdot
.35775 .41529 Mdot
.64456 .3695 Mdot
.56076 .51731 Mdot
.32923 .43003 Mdot
.67685 .30327 Mdot
.38653 .69545 Mdot
.34652 .455 Mdot
.60625 .4322 Mdot
.33805 .32308 Mdot
.71757 .58921 Mdot
.56809 .73731 Mdot
.64967 .49291 Mdot
.55486 .68595 Mdot
.34433 .69731 Mdot
.60302 .72373 Mdot
.37197 .65436 Mdot
.54113 .48318 Mdot
.5184 .57895 Mdot
.40783 .68373 Mdot
.37003 .63145 Mdot
.56981 .68783 Mdot
.58894 .35762 Mdot
.49669 .5979 Mdot
.50567 .34487 Mdot
.57359 .31602 Mdot
.37997 .63956 Mdot
.361 .45695 Mdot
.35485 .39264 Mdot
.55949 .29772 Mdot
.33481 .40224 Mdot
.5673 .71115 Mdot
.45659 .46828 Mdot
.46365 .34179 Mdot
.39161 .66077 Mdot
.52515 .61482 Mdot
.59835 .41052 Mdot
.58084 .68361 Mdot
.57037 .71408 Mdot
.36389 .68065 Mdot
.31451 .33184 Mdot
.54388 .32488 Mdot
.34076 .46431 Mdot
.34184 .45061 Mdot
.33049 .43272 Mdot
.31623 .4054 Mdot
.78013 .49775 Mdot
.41055 .66649 Mdot
.37697 .44482 Mdot
.61287 .40545 Mdot
.52019 .39399 Mdot
.4002 .55971 Mdot
.73082 .55354 Mdot
.62212 .39712 Mdot
.50655 .34514 Mdot
.54014 .37399 Mdot
.5973 .71903 Mdot
.63708 .44676 Mdot
.40713 .55816 Mdot
.60497 .70503 Mdot
.60391 .70748 Mdot
.38928 .55894 Mdot
.55302 .4826 Mdot
.24061 .34531 Mdot
.58269 .357 Mdot
.35265 .49098 Mdot
.59772 .7042 Mdot
.65902 .52495 Mdot
.53401 .29092 Mdot
.54745 .42121 Mdot
.48567 .63779 Mdot
.57448 .70625 Mdot
.32224 .46613 Mdot
.55012 .37549 Mdot
.39049 .53256 Mdot
.70866 .58636 Mdot
.65421 .37858 Mdot
.3817 .54623 Mdot
.37004 .42859 Mdot
.62302 .7577 Mdot
.37535 .45627 Mdot
.57831 .7345 Mdot
.51565 .34023 Mdot
.70964 .81955 Mdot
.58557 .7107 Mdot
.29022 .63828 Mdot
.51872 .58094 Mdot
.54779 .40159 Mdot
.55243 .69785 Mdot
.38843 .45738 Mdot
.39609 .63844 Mdot
.5927 .50898 Mdot
.37196 .41913 Mdot
.39162 .52849 Mdot
.39829 .55793 Mdot
.57402 .69288 Mdot
.34205 .44709 Mdot
.577 .43165 Mdot
.34496 .4025 Mdot
.39575 .67657 Mdot
.59424 .38513 Mdot
.29191 .49077 Mdot
.61708 .3238 Mdot
.34037 .4052 Mdot
.55284 .66236 Mdot
.73718 .59389 Mdot
.57608 .40275 Mdot
.35253 .54427 Mdot
.5227 .38064 Mdot
.38409 .65363 Mdot
.62347 .57545 Mdot
.37314 .23185 Mdot
.54848 .35716 Mdot
.59622 .41113 Mdot
.37344 .70876 Mdot
.54855 .35832 Mdot
.5197 .41357 Mdot
.41207 .50614 Mdot
.32906 .42745 Mdot
.53153 .38759 Mdot
.55696 .67821 Mdot
.43716 .19176 Mdot
.57852 .36434 Mdot
.3628 .73262 Mdot
.6918 .33156 Mdot
.60495 .5527 Mdot
.54362 .31968 Mdot
.6928 .45734 Mdot
.56406 .37571 Mdot
.54141 .41874 Mdot
.58256 .35588 Mdot
.44988 .32612 Mdot
.56577 .69233 Mdot
.5853 .67909 Mdot
.69752 .58056 Mdot
.69064 .3381 Mdot
.70645 .57568 Mdot
.38003 .70706 Mdot
.52686 .60954 Mdot
.40676 .54284 Mdot
.36477 .43052 Mdot
.57619 .36298 Mdot
.56502 .6648 Mdot
.54075 .38174 Mdot
.59062 .40693 Mdot
.56694 .70654 Mdot
.57425 .71217 Mdot
.52799 .69755 Mdot
.71107 .59116 Mdot
.35453 .42274 Mdot
.58015 .35899 Mdot
.73087 .59267 Mdot
.60754 .36974 Mdot
.5161 .53334 Mdot
.35345 .421 Mdot
.33899 .4048 Mdot
.3765 .39899 Mdot
.55171 .40733 Mdot
.58987 .37254 Mdot
.37421 .64726 Mdot
.39678 .4416 Mdot
.37669 .68909 Mdot
.5523 .69588 Mdot
.57558 .6814 Mdot
.5492 .37126 Mdot
.50801 .42293 Mdot
.71675 .54967 Mdot
.56817 .72751 Mdot
.38846 .57023 Mdot
.69876 .58015 Mdot
.53339 .3566 Mdot
.55289 .69018 Mdot
.70029 .54786 Mdot
.28351 .33019 Mdot
.24769 .46224 Mdot
.70378 .58999 Mdot
.58355 .35432 Mdot
.52245 .22748 Mdot
.72015 .46219 Mdot
.70187 .53761 Mdot
.38435 .64977 Mdot
.52594 .394 Mdot
.45256 .67451 Mdot
.74981 .56948 Mdot
.75324 .48462 Mdot
.56301 .70383 Mdot
.5919 .30842 Mdot
.64768 .41153 Mdot
.45883 .35397 Mdot
.74524 .58935 Mdot
.34012 .40677 Mdot
.3285 .44077 Mdot
.54799 .35466 Mdot
.52453 .60482 Mdot
.3891 .70508 Mdot
.55923 .72797 Mdot
.58125 .67291 Mdot
.32504 .4297 Mdot
.47011 .48959 Mdot
.55512 .68023 Mdot
.52818 .4086 Mdot
.75507 .56144 Mdot
.62071 .36708 Mdot
.80503 .51708 Mdot
.41547 .1855 Mdot
.55625 .31554 Mdot
.7299 .59609 Mdot
.36576 .69778 Mdot
.36341 .66999 Mdot
.36641 .67331 Mdot
.57108 .68134 Mdot
.63419 .48738 Mdot
.57066 .66979 Mdot
.28628 .71092 Mdot
.70745 .56002 Mdot
.72658 .33679 Mdot
.61732 .41113 Mdot
.55006 .40142 Mdot
.59086 .41935 Mdot
.60483 .37549 Mdot
.5628 .37683 Mdot
.36954 .64744 Mdot
.54884 .72551 Mdot
.38986 .76129 Mdot
.35 .44496 Mdot
.23209 .62116 Mdot
.58999 .72399 Mdot
.38115 .55381 Mdot
.73112 .56028 Mdot
.69573 .38528 Mdot
.76245 .57791 Mdot
.56887 .73002 Mdot
.51043 .39026 Mdot
.32322 .44167 Mdot
.71322 .28925 Mdot
.57454 .38012 Mdot
.56301 .72557 Mdot
.5718 .74752 Mdot
.31447 .32448 Mdot
.53555 .45036 Mdot
.51291 .6434 Mdot
.56288 .51403 Mdot
.70263 .59159 Mdot
.5323 .33893 Mdot
.67467 .45308 Mdot
.56695 .6966 Mdot
.59163 .70415 Mdot
.69722 .5406 Mdot
.37692 .36856 Mdot
.37063 .44858 Mdot
.41118 .54951 Mdot
.3911 .64893 Mdot
.56065 .40273 Mdot
.56522 .68314 Mdot
.29571 .42233 Mdot
.54672 .53589 Mdot
.37642 .66286 Mdot
.60566 .71007 Mdot
.52226 .384 Mdot
.54356 .35843 Mdot
.70662 .57153 Mdot
.61172 .6257 Mdot
.50608 .34451 Mdot
.29084 .62767 Mdot
.5082 .50453 Mdot
.52058 .58358 Mdot
.53651 .37975 Mdot
.33754 .39695 Mdot
.38935 .55708 Mdot
.73196 .57758 Mdot
.5883 .35067 Mdot
.23647 .38177 Mdot
.38465 .44151 Mdot
.37477 .68738 Mdot
.38539 .55173 Mdot
.66039 .45453 Mdot
.52323 .38181 Mdot
.55781 .36846 Mdot
.61432 .39218 Mdot
.23503 .36674 Mdot
.56612 .67251 Mdot
.3218 .40268 Mdot
.70131 .57325 Mdot
.35495 .39989 Mdot
.59807 .72683 Mdot
.51953 .61322 Mdot
.57061 .34821 Mdot
.38455 .42535 Mdot
.35527 .40287 Mdot
.3885 .65946 Mdot
.37641 .70163 Mdot
.53207 .70135 Mdot
.52641 .38605 Mdot
.40639 .53895 Mdot
.36966 .45208 Mdot
.55062 .72218 Mdot
.7077 .57175 Mdot
.35132 .71596 Mdot
.57551 .39055 Mdot
.57113 .69273 Mdot
.50805 .3453 Mdot
.34624 .43755 Mdot
.58002 .72931 Mdot
.38431 .53364 Mdot
.73612 .55767 Mdot
.51767 .37947 Mdot
.41019 .77372 Mdot
.38741 .5359 Mdot
.56672 .40578 Mdot
.40037 .19475 Mdot
.52389 .60463 Mdot
.35767 .36928 Mdot
.55041 .67773 Mdot
.39867 .53291 Mdot
.31769 .41007 Mdot
.35464 .31457 Mdot
.58935 .69869 Mdot
.51957 .20626 Mdot
.50632 .56121 Mdot
.58593 .35921 Mdot
.37141 .42382 Mdot
.76811 .59446 Mdot
.2834 .60738 Mdot
.71627 .4683 Mdot
.55019 .39191 Mdot
.55541 .68528 Mdot
.70969 .58604 Mdot
.38582 .6847 Mdot
.37669 .72934 Mdot
.81904 .50909 Mdot
.59991 .6888 Mdot
.57547 .36123 Mdot
.35826 .45694 Mdot
.37181 .68615 Mdot
.51702 .19855 Mdot
.53932 .68116 Mdot
.54954 .68324 Mdot
.57608 .42533 Mdot
.707 .57825 Mdot
.45059 .65996 Mdot
.57599 .67553 Mdot
.54956 .72781 Mdot
.41082 .49587 Mdot
.69537 .58049 Mdot
.6127 .38791 Mdot
.55958 .29754 Mdot
.60172 .42261 Mdot
.26445 .65227 Mdot
.40103 .5339 Mdot
.35279 .44526 Mdot
.5692 .36767 Mdot
.38667 .77961 Mdot
.58519 .7009 Mdot
.56054 .51332 Mdot
.41857 .65506 Mdot
.37751 .70117 Mdot
.55805 .6904 Mdot
.54595 .38261 Mdot
.39773 .7075 Mdot
.70805 .5548 Mdot
.61331 .38571 Mdot
.59115 .37118 Mdot
.39662 .44522 Mdot
.39858 .67248 Mdot
.435 .19017 Mdot
.38908 .68645 Mdot
.40708 .67386 Mdot
.38909 .40244 Mdot
.54679 .35479 Mdot
.5786 .72748 Mdot
.55815 .65637 Mdot
.4888 .3851 Mdot
.65726 .53385 Mdot
.37462 .44149 Mdot
.58382 .65072 Mdot
.22997 .38547 Mdot
.54514 .42693 Mdot
.38864 .56832 Mdot
.2764 .40217 Mdot
.41121 .65262 Mdot
.55867 .35701 Mdot
.36032 .43467 Mdot
.53762 .70792 Mdot
.5604 .68066 Mdot
.62323 .39584 Mdot
.36233 .6769 Mdot
.70439 .54505 Mdot
.56918 .71583 Mdot
.50935 .54276 Mdot
.55779 .39471 Mdot
.38779 .59031 Mdot
.56853 .71749 Mdot
.47646 .15048 Mdot
.37886 .77581 Mdot
.33003 .43494 Mdot
.5726 .42023 Mdot
.33703 .45396 Mdot
.69783 .56254 Mdot
.59119 .73886 Mdot
.36585 .65729 Mdot
.49383 .44023 Mdot
.59478 .80217 Mdot
.57145 .68388 Mdot
.36488 .42371 Mdot
.57123 .36031 Mdot
.49149 .3129 Mdot
.53528 .39738 Mdot
.79287 .44748 Mdot
.71257 .53749 Mdot
.34359 .67106 Mdot
.3606 .68091 Mdot
.59146 .41288 Mdot
.73832 .5876 Mdot
.54571 .65981 Mdot
.56685 .70532 Mdot
.58716 .83037 Mdot
.38215 .54272 Mdot
.54942 .64731 Mdot
.55458 .40679 Mdot
.5489 .71685 Mdot
.52018 .23504 Mdot
.36455 .68831 Mdot
.58569 .42724 Mdot
.5974 .67688 Mdot
.24702 .60989 Mdot
.56445 .51605 Mdot
.55464 .39399 Mdot
.51835 .43303 Mdot
.37894 .65278 Mdot
.19747 .55204 Mdot
.55105 .67497 Mdot
.60331 .36478 Mdot
.41372 .68631 Mdot
.50199 .47301 Mdot
.63699 .67295 Mdot
.35402 .42268 Mdot
.59945 .6751 Mdot
.40399 .65866 Mdot
.59599 .3092 Mdot
.72237 .54911 Mdot
.53528 .68384 Mdot
.58199 .66598 Mdot
.59299 .39385 Mdot
.6144 .36986 Mdot
.54204 .4426 Mdot
.37294 .43261 Mdot
.4026 .68191 Mdot
.60099 .39991 Mdot
.51766 .5261 Mdot
.60604 .37948 Mdot
.40517 .67253 Mdot
.60243 .88533 Mdot
.51177 .38505 Mdot
.57245 .39483 Mdot
.49016 .30366 Mdot
.32762 .39762 Mdot
.32853 .4194 Mdot
.50733 .51247 Mdot
.53576 .40531 Mdot
.49424 .56147 Mdot
.35683 .42436 Mdot
.36811 .41832 Mdot
.49552 .56297 Mdot
.59135 .38629 Mdot
.40444 .58236 Mdot
.37071 .6855 Mdot
.37784 .70145 Mdot
.33135 .42627 Mdot
.62079 .37177 Mdot
.36519 .69941 Mdot
.3886 .34269 Mdot
.57698 .73121 Mdot
.67499 .45005 Mdot
.3486 .40163 Mdot
.59149 .51979 Mdot
.38149 .69569 Mdot
.53342 .17487 Mdot
.67076 .27779 Mdot
.53113 .42522 Mdot
.5502 .35521 Mdot
.72084 .571 Mdot
.47812 .41917 Mdot
.39066 .5626 Mdot
.36575 .67765 Mdot
.467 .6449 Mdot
.34795 .41987 Mdot
.53398 .40276 Mdot
.71 .47797 Mdot
.44107 .17023 Mdot
.59802 .29672 Mdot
.3649 .41336 Mdot
.34542 .41579 Mdot
.54414 .68992 Mdot
.56999 .73179 Mdot
.5717 .34935 Mdot
.36657 .66138 Mdot
.33758 .44969 Mdot
.40195 .67605 Mdot
.56616 .69813 Mdot
.58501 .72603 Mdot
.40405 .56266 Mdot
.55908 .32027 Mdot
.55964 .69484 Mdot
.36455 .7378 Mdot
.51723 .52712 Mdot
.40041 .43095 Mdot
.30815 .74936 Mdot
.55991 .18324 Mdot
.437 .38462 Mdot
.70977 .58672 Mdot
.53353 .48349 Mdot
.35486 .67166 Mdot
.59467 .41089 Mdot
.55466 .36449 Mdot
.40141 .54484 Mdot
.35454 .68089 Mdot
.72751 .5618 Mdot
.36926 .69609 Mdot
.73653 .57464 Mdot
.5883 .6821 Mdot
.5784 .3681 Mdot
.54127 .34849 Mdot
.38605 .68171 Mdot
.54795 .70725 Mdot
.58652 .73024 Mdot
.7282 .58801 Mdot
.69527 .36908 Mdot
.57291 .69439 Mdot
.34995 .40132 Mdot
.45571 .20324 Mdot
.39951 .55635 Mdot
.5505 .37605 Mdot
.69575 .45407 Mdot
.36863 .30232 Mdot
.59672 .36686 Mdot
.38485 .54642 Mdot
.49843 .88013 Mdot
.57973 .36654 Mdot
.67689 .78719 Mdot
.40675 .54847 Mdot
.35199 .39424 Mdot
.56127 .71872 Mdot
.38273 .54388 Mdot
.64254 .43811 Mdot
.61475 .67732 Mdot
.49633 .36606 Mdot
.37303 .44711 Mdot
.37994 .40877 Mdot
.51354 .60939 Mdot
.26291 .65155 Mdot
.70138 .57476 Mdot
.71835 .55586 Mdot
.58696 .69531 Mdot
.37943 .73583 Mdot
.62184 .38283 Mdot
.71908 .55766 Mdot
.41672 .59082 Mdot
.59516 .41307 Mdot
.52211 .60457 Mdot
.49113 .60206 Mdot
.32466 .40716 Mdot
.63608 .35084 Mdot
.58648 .69819 Mdot
.36388 .423 Mdot
.5029 .59928 Mdot
.58864 .42422 Mdot
.35139 .42034 Mdot
.39384 .69482 Mdot
.46714 .55483 Mdot
.34047 .40168 Mdot
.58593 .51303 Mdot
.38094 .681 Mdot
.52354 .60981 Mdot
.75344 .39309 Mdot
.33071 .1868 Mdot
.36437 .6696 Mdot
.55787 .71991 Mdot
.56629 .68437 Mdot
.57597 .69666 Mdot
.37405 .42369 Mdot
.57915 .71242 Mdot
.35825 .44887 Mdot
.3626 .64093 Mdot
.69111 .38764 Mdot
.71375 .57014 Mdot
.78007 .57023 Mdot
.33659 .4164 Mdot
.27829 .6936 Mdot
.27012 .74202 Mdot
.60884 .37872 Mdot
.40903 .68018 Mdot
.72418 .5948 Mdot
.4962 .49468 Mdot
.72307 .56903 Mdot
.55842 .71807 Mdot
.67572 .44004 Mdot
.5415 .39013 Mdot
.28299 .46027 Mdot
.70939 .58531 Mdot
.36878 .41598 Mdot
.57671 .40744 Mdot
.58987 .66219 Mdot
.70171 .55734 Mdot
.7201 .58758 Mdot
.56095 .37647 Mdot
.37343 .40304 Mdot
.57533 .72929 Mdot
.3563 .66205 Mdot
.75717 .5543 Mdot
.50359 .42644 Mdot
.57044 .35243 Mdot
.50941 .3809 Mdot
.54559 .51257 Mdot
.40069 .73308 Mdot
.37941 .67895 Mdot
.74758 .48492 Mdot
.57911 .68228 Mdot
.72001 .46842 Mdot
.30203 .61009 Mdot
.74591 .60681 Mdot
.40214 .53558 Mdot
.40191 .53419 Mdot
.55991 .38854 Mdot
.19221 .63741 Mdot
.60314 .28844 Mdot
.40847 .63317 Mdot
.39939 .55095 Mdot
.58276 .73258 Mdot
.38648 .4513 Mdot
.6316 .42907 Mdot
.61964 .40436 Mdot
.35382 .66881 Mdot
.56989 .70072 Mdot
.16482 .58405 Mdot
.70748 .56176 Mdot
.49231 .49612 Mdot
.5262 .383 Mdot
.55547 .38471 Mdot
.38095 .6665 Mdot
.36881 .6539 Mdot
.41017 .49219 Mdot
.60539 .5419 Mdot
.27806 .47926 Mdot
.3529 .69828 Mdot
.16401 .58342 Mdot
.26327 .40255 Mdot
.33654 .43066 Mdot
.39079 .56743 Mdot
.3783 .70521 Mdot
.56627 .36822 Mdot
.34964 .39383 Mdot
.62032 .29748 Mdot
.31036 .45617 Mdot
.52213 .59935 Mdot
.51571 .54615 Mdot
.5248 .37171 Mdot
.31437 .42083 Mdot
.36064 .42111 Mdot
.31506 .40021 Mdot
.39232 .55867 Mdot
.53699 .37623 Mdot
.59849 .36443 Mdot
.58119 .36614 Mdot
.47285 .3481 Mdot
.56298 .39008 Mdot
.29836 .60906 Mdot
.50289 .52112 Mdot
.68627 .65613 Mdot
.57809 .37953 Mdot
.40078 .68851 Mdot
.57665 .36867 Mdot
.74424 .58066 Mdot
.51542 .38137 Mdot
.52269 .59576 Mdot
.37141 .67668 Mdot
.33121 .34932 Mdot
.6016 .75385 Mdot
.54768 .34777 Mdot
.69452 .55923 Mdot
.32552 .75139 Mdot
.73532 .48386 Mdot
.41233 .49909 Mdot
.3454 .4025 Mdot
.54967 .73012 Mdot
.40784 .69065 Mdot
.58558 .72239 Mdot
.56758 .43287 Mdot
.39626 .56992 Mdot
.71682 .25201 Mdot
.60098 .52181 Mdot
.56829 .3685 Mdot
.55094 .32308 Mdot
.32863 .40383 Mdot
.58494 .70461 Mdot
.42393 .41487 Mdot
.59428 .41601 Mdot
.72746 .54701 Mdot
.7461 .58412 Mdot
.50301 .69193 Mdot
.45078 .55651 Mdot
.55611 .25817 Mdot
.38004 .66895 Mdot
.56708 .67974 Mdot
.75002 .58387 Mdot
.31623 .47523 Mdot
.39296 .70233 Mdot
.41123 .65225 Mdot
.39893 .67042 Mdot
.56014 .39805 Mdot
.40257 .56114 Mdot
.44301 .59255 Mdot
.3865 .53426 Mdot
.60473 .41596 Mdot
.58381 .66731 Mdot
.38769 .53054 Mdot
.71487 .57642 Mdot
.40693 .66121 Mdot
.59478 .72096 Mdot
.56793 .38004 Mdot
.35286 .42783 Mdot
.78598 .52695 Mdot
.40288 .79381 Mdot
.52495 .60619 Mdot
.52499 .60629 Mdot
.38462 .40821 Mdot
.34193 .50179 Mdot
.34861 .70528 Mdot
.32377 .3225 Mdot
.66604 .58713 Mdot
.48755 .37592 Mdot
.64782 .7455 Mdot
.56719 .66926 Mdot
.56034 .70845 Mdot
.5432 .39521 Mdot
.54299 .70779 Mdot
.53225 .39882 Mdot
.54751 .67965 Mdot
.27358 .61899 Mdot
.61647 .41789 Mdot
.56544 .71056 Mdot
.52944 .45078 Mdot
.57533 .40284 Mdot
.33983 .39737 Mdot
.53544 .69133 Mdot
.53185 .42529 Mdot
.78152 .30445 Mdot
.38955 .66369 Mdot
.39323 .55892 Mdot
.5317 .58405 Mdot
.37374 .69424 Mdot
.35742 .45192 Mdot
.52701 .40216 Mdot
.70479 .56052 Mdot
.3362 .42537 Mdot
.61186 .68277 Mdot
.71014 .58373 Mdot
.45614 .47019 Mdot
.33317 .42753 Mdot
.40236 .55362 Mdot
.73909 .56137 Mdot
.49598 .367 Mdot
.56147 .70716 Mdot
.38842 .78482 Mdot
.38307 .54831 Mdot
.53951 .38703 Mdot
.60394 .67968 Mdot
.3706 .69613 Mdot
.54995 .35039 Mdot
.56391 .68204 Mdot
.38729 .55731 Mdot
.57643 .39713 Mdot
.55313 .4091 Mdot
.40147 .3787 Mdot
.62843 .59054 Mdot
.71372 .57292 Mdot
.37872 .39198 Mdot
.61187 .40901 Mdot
.73415 .58953 Mdot
.42654 .75486 Mdot
.60471 .42842 Mdot
.37889 .44725 Mdot
.36121 .33942 Mdot
.55386 .72224 Mdot
.36226 .68607 Mdot
.54388 .66784 Mdot
.69596 .57508 Mdot
.32872 .80914 Mdot
.39248 .5659 Mdot
.50498 .376 Mdot
.5249 .41826 Mdot
.58527 .74313 Mdot
.35897 .41889 Mdot
.27764 .47606 Mdot
.5167 .38515 Mdot
.58895 .31486 Mdot
.5558 .37553 Mdot
.42615 .7637 Mdot
.37381 .42798 Mdot
.55306 .375 Mdot
.489 .41026 Mdot
.55714 .42859 Mdot
.70314 .54874 Mdot
.72606 .32817 Mdot
.59272 .36634 Mdot
.78578 .75828 Mdot
.40589 .56652 Mdot
.57022 .70606 Mdot
.57711 .513 Mdot
.54364 .59399 Mdot
.81815 .5671 Mdot
.36718 .44804 Mdot
.33636 .48606 Mdot
.58204 .72621 Mdot
.80023 .5609 Mdot
.3573 .50853 Mdot
.56304 .40977 Mdot
.52375 .39011 Mdot
.5585 .71815 Mdot
.5533 .72556 Mdot
.39904 .5709 Mdot
.56467 .34198 Mdot
.6234 .33249 Mdot
.55742 .66131 Mdot
.57141 .3851 Mdot
.37305 .2835 Mdot
.40031 .63693 Mdot
.33021 .42523 Mdot
.38748 .68332 Mdot
.39808 .6376 Mdot
.43135 .3914 Mdot
.51293 .50476 Mdot
.38547 .64489 Mdot
.39977 .62901 Mdot
.77754 .58366 Mdot
.46747 .33709 Mdot
.70521 .5475 Mdot
.43771 .50919 Mdot
.58062 .69186 Mdot
.538 .37401 Mdot
.37529 .42304 Mdot
.81746 .43043 Mdot
.27675 .50597 Mdot
.67277 .38015 Mdot
.61219 .39062 Mdot
.58305 .69827 Mdot
.38403 .5513 Mdot
.61022 .42629 Mdot
.71983 .46421 Mdot
.55297 .38945 Mdot
.5654 .73191 Mdot
.46315 .34309 Mdot
.33442 .72124 Mdot
.35122 .698 Mdot
.36977 .46652 Mdot
.57648 .3662 Mdot
.36227 .4402 Mdot
.38852 .64169 Mdot
.71944 .59221 Mdot
.71922 .56394 Mdot
.54278 .34891 Mdot
.5178 .57988 Mdot
.75427 .61469 Mdot
.56731 .40871 Mdot
.59345 .39048 Mdot
.40136 .53573 Mdot
.59385 .38928 Mdot
.58793 .35248 Mdot
.60324 .39928 Mdot
.60984 .36946 Mdot
.38643 .70485 Mdot
.43165 .40826 Mdot
.54547 .34167 Mdot
.50679 .40528 Mdot
.3738 .63747 Mdot
.53793 .43327 Mdot
.37263 .6588 Mdot
.29317 .50346 Mdot
.38693 .64723 Mdot
.71796 .56486 Mdot
.60098 .67372 Mdot
.37644 .48392 Mdot
.33753 .44939 Mdot
.39582 .69623 Mdot
.73629 .56192 Mdot
.36517 .67262 Mdot
.56644 .67644 Mdot
.36304 .75733 Mdot
.38789 .38973 Mdot
.49778 .52991 Mdot
.47692 .31911 Mdot
.38434 .593 Mdot
.54327 .70268 Mdot
.33124 .43734 Mdot
.36007 .72856 Mdot
.59122 .41216 Mdot
.70279 .56665 Mdot
.5596 .3879 Mdot
.40795 .66578 Mdot
.5815 .6955 Mdot
.41545 .53082 Mdot
.71476 .57302 Mdot
.35133 .80535 Mdot
.56266 .66434 Mdot
.51413 .40481 Mdot
.37287 .63866 Mdot
.37562 .75011 Mdot
.37798 .65101 Mdot
.69194 .38733 Mdot
.28814 .41278 Mdot
.81905 .45771 Mdot
.34098 .41718 Mdot
.38415 .57284 Mdot
.29679 .24721 Mdot
.34251 .57881 Mdot
.34778 .43328 Mdot
.59387 .76105 Mdot
.56479 .39258 Mdot
.6089 .38683 Mdot
.56595 .32081 Mdot
.30189 .42529 Mdot
.61427 .3927 Mdot
.39472 .56274 Mdot
.51702 .51007 Mdot
.43369 .61584 Mdot
.54248 .72323 Mdot
.53212 .39685 Mdot
.37909 .63984 Mdot
.40116 .69151 Mdot
.39138 .52722 Mdot
.39383 .68351 Mdot
.58406 .38682 Mdot
.33749 .41697 Mdot
.49778 .59793 Mdot
.69826 .56333 Mdot
.30055 .63502 Mdot
.68276 .60938 Mdot
.76528 .57468 Mdot
.55354 .42865 Mdot
.58365 .72709 Mdot
.60616 .79749 Mdot
.60346 .40525 Mdot
.35968 .42461 Mdot
.52404 .41702 Mdot
.60589 .39215 Mdot
.58318 .36141 Mdot
.56813 .68021 Mdot
.57054 .51815 Mdot
.57253 .38377 Mdot
.38735 .64427 Mdot
.49766 .56328 Mdot
.62071 .39974 Mdot
.47559 .65489 Mdot
.52207 .59637 Mdot
.38761 .59114 Mdot
.40046 .43672 Mdot
.57316 .72591 Mdot
.34576 .41929 Mdot
.31109 .43676 Mdot
.35646 .45189 Mdot
.44017 .60418 Mdot
.33695 .32152 Mdot
.6987 .77636 Mdot
.52338 .23891 Mdot
.47233 .32008 Mdot
.35799 .46625 Mdot
.47836 .74234 Mdot
.35209 .43547 Mdot
.36058 .45099 Mdot
.56973 .87618 Mdot
.37941 .42601 Mdot
.54793 .3717 Mdot
.51772 .36358 Mdot
.25898 .36065 Mdot
.77043 .56206 Mdot
.56123 .40546 Mdot
.60573 .37075 Mdot
.74836 .58369 Mdot
.41878 .39143 Mdot
.39438 .57428 Mdot
.48707 .49553 Mdot
.38111 .56016 Mdot
.56142 .37705 Mdot
.52988 .36194 Mdot
.58625 .34512 Mdot
.36869 .18424 Mdot
.82514 .47957 Mdot
.37708 .40131 Mdot
.48474 .3855 Mdot
.37784 .60205 Mdot
.53219 .4157 Mdot
.53531 .42166 Mdot
.58593 .36786 Mdot
.57891 .72753 Mdot
.39046 .44388 Mdot
.50572 .34544 Mdot
.32644 .6196 Mdot
.52495 .37637 Mdot
.70983 .61853 Mdot
.69044 .58409 Mdot
.54543 .38163 Mdot
.38079 .42633 Mdot
.61025 .38714 Mdot
.34297 .45604 Mdot
.33344 .43154 Mdot
.60575 .32093 Mdot
.44279 .58286 Mdot
.38373 .453 Mdot
.56024 .41003 Mdot
.54696 .70719 Mdot
.29044 .6315 Mdot
.54051 .3861 Mdot
.71302 .58008 Mdot
.56121 .35631 Mdot
.69853 .55205 Mdot
.59673 .38072 Mdot
.38894 .53111 Mdot
.36446 .2391 Mdot
.59166 .70137 Mdot
.76542 .56775 Mdot
.54538 .71096 Mdot
.61446 .34792 Mdot
.3619 .4629 Mdot
.32552 .67356 Mdot
.82463 .5051 Mdot
.40211 .53694 Mdot
.76662 .49613 Mdot
.48642 .56741 Mdot
.36326 .65537 Mdot
.31691 .40582 Mdot
.44949 .3664 Mdot
.47855 .64968 Mdot
.55051 .73381 Mdot
.60324 .71588 Mdot
.64407 .67999 Mdot
.51584 .86742 Mdot
.57352 .38712 Mdot
.45319 .67869 Mdot
.39173 .25327 Mdot
.47652 .40981 Mdot
.56712 .45056 Mdot
.5774 .66348 Mdot
.56185 .40557 Mdot
.63901 .50314 Mdot
.56891 .6883 Mdot
.72069 .5528 Mdot
.35479 .44514 Mdot
.73967 .58144 Mdot
.24157 .49176 Mdot
.41089 .5025 Mdot
.56282 .69232 Mdot
.61236 .37253 Mdot
.55052 .40381 Mdot
.3222 .40007 Mdot
.52321 .20133 Mdot
.32906 .42661 Mdot
.69831 .57074 Mdot
.58835 .69048 Mdot
.74894 .30092 Mdot
.56778 .35708 Mdot
.35879 .40409 Mdot
.60103 .75424 Mdot
.54192 .35995 Mdot
.36254 .68357 Mdot
.61271 .3966 Mdot
.36028 .40247 Mdot
.59426 .38891 Mdot
.33843 .41958 Mdot
.54565 .69252 Mdot
.53678 .35046 Mdot
.53573 .35551 Mdot
.75408 .48698 Mdot
.72792 .56334 Mdot
.36898 .45997 Mdot
.64053 .50058 Mdot
.60192 .4225 Mdot
.71332 .45689 Mdot
.57872 .36765 Mdot
.48016 .32219 Mdot
.58842 .43547 Mdot
.39698 .56262 Mdot
.52921 .42001 Mdot
.54151 .38696 Mdot
.54296 .21116 Mdot
.51989 .23227 Mdot
.45583 .38083 Mdot
.3765 .70201 Mdot
.3716 .40814 Mdot
.56371 .68583 Mdot
.5381 .71215 Mdot
.57906 .71709 Mdot
.6864 .54175 Mdot
.48724 .39385 Mdot
.53633 .38788 Mdot
.3909 .61844 Mdot
.71475 .55819 Mdot
.3611 .40882 Mdot
.71321 .56528 Mdot
.51517 .50293 Mdot
.71714 .58173 Mdot
.39042 .56358 Mdot
.37859 .77356 Mdot
.3732 .29403 Mdot
.72949 .57711 Mdot
.33016 .42823 Mdot
.49131 .55115 Mdot
.4892 .36943 Mdot
.24667 .6342 Mdot
.72928 .54765 Mdot
.64169 .70925 Mdot
.57872 .39026 Mdot
.59907 .50596 Mdot
.37546 .65865 Mdot
.74009 .58035 Mdot
.39788 .66967 Mdot
.6103 .38863 Mdot
.40352 .38644 Mdot
.36585 .42692 Mdot
.39593 .63429 Mdot
.56947 .42796 Mdot
.74044 .5804 Mdot
.56078 .69729 Mdot
.4651 .34133 Mdot
.38091 .63047 Mdot
.78461 .52993 Mdot
.71758 .4688 Mdot
.58525 .68769 Mdot
.51034 .27889 Mdot
.39372 .65535 Mdot
.48707 .37913 Mdot
.64074 .32512 Mdot
.607 .40819 Mdot
.58879 .72933 Mdot
.5604 .70963 Mdot
.37104 .57656 Mdot
.52956 .36007 Mdot
.53609 .34429 Mdot
.395 .42467 Mdot
.58549 .68528 Mdot
.35472 .45253 Mdot
.31902 .41731 Mdot
.55607 .71681 Mdot
.32818 .43311 Mdot
.71264 .58581 Mdot
.64042 .47711 Mdot
.39276 .65326 Mdot
.36088 .67647 Mdot
.56057 .69288 Mdot
.59604 .69293 Mdot
.58534 .72667 Mdot
.58345 .42159 Mdot
.33726 .44475 Mdot
.57164 .41933 Mdot
.57505 .36372 Mdot
.30562 .46602 Mdot
.39483 .41244 Mdot
.55536 .42437 Mdot
.4875 .60395 Mdot
.71666 .54115 Mdot
.56866 .71096 Mdot
.40059 .68272 Mdot
.79372 .52857 Mdot
.3654 .64941 Mdot
.60608 .42119 Mdot
.24982 .61624 Mdot
.37323 .42186 Mdot
.72225 .57008 Mdot
.5247 .59995 Mdot
.71761 .57266 Mdot
.39891 .63593 Mdot
.38217 .39909 Mdot
.46173 .4799 Mdot
.53044 .35806 Mdot
.5412 .51214 Mdot
.75079 .4276 Mdot
.30855 .6098 Mdot
.39997 .68721 Mdot
.61049 .3823 Mdot
.40521 .54308 Mdot
.31563 .32184 Mdot
.53801 .39057 Mdot
.57881 .42987 Mdot
.55834 .60988 Mdot
.52561 .41977 Mdot
.3661 .39035 Mdot
.5169 .59925 Mdot
.58042 .34669 Mdot
.61136 .34574 Mdot
.56444 .85096 Mdot
.57322 .40094 Mdot
.53863 .35242 Mdot
.54715 .36651 Mdot
.59032 .41473 Mdot
.34029 .4563 Mdot
.56238 .62322 Mdot
.38616 .63891 Mdot
.64101 .4769 Mdot
.39867 .66319 Mdot
.55469 .69731 Mdot
.62934 .52293 Mdot
.34049 .45541 Mdot
.71764 .57323 Mdot
.448 .69423 Mdot
.67369 .44087 Mdot
.54387 .69244 Mdot
.78504 .49365 Mdot
.71326 .54532 Mdot
.48888 .36892 Mdot
.69602 .57899 Mdot
.58749 .66792 Mdot
.36258 .676 Mdot
.5106 .39038 Mdot
.36587 .45315 Mdot
.34007 .40209 Mdot
.61259 .40397 Mdot
.30271 .64507 Mdot
.36468 .69328 Mdot
.67923 .51899 Mdot
.55379 .39904 Mdot
.58659 .4271 Mdot
.3274 .4269 Mdot
.584 .70324 Mdot
.48839 .56687 Mdot
.73342 .56355 Mdot
.52261 .40499 Mdot
.60452 .37406 Mdot
.51848 .50404 Mdot
.39275 .70025 Mdot
.39406 .54752 Mdot
.53392 .39298 Mdot
.49782 .50414 Mdot
.6149 .39382 Mdot
.60068 .34954 Mdot
.55178 .71707 Mdot
.59763 .31659 Mdot
.52063 .37572 Mdot
.38882 .3796 Mdot
.39456 .6583 Mdot
.35613 .42103 Mdot
.32249 .47644 Mdot
.3928 .53027 Mdot
.38948 .66804 Mdot
.55864 .42558 Mdot
.4139 .66685 Mdot
.60767 .38919 Mdot
.57004 .38135 Mdot
.39803 .69034 Mdot
.34769 .45034 Mdot
.31771 .50224 Mdot
.43185 .40836 Mdot
.59304 .40585 Mdot
.55649 .35646 Mdot
.77041 .56277 Mdot
.83131 .444 Mdot
.52161 .36919 Mdot
.33151 .43969 Mdot
.54278 .3585 Mdot
.36344 .6576 Mdot
.70163 .57635 Mdot
.35697 .42843 Mdot
.57653 .67813 Mdot
.54688 .68951 Mdot
.58229 .7557 Mdot
.39088 .56505 Mdot
.55725 .34184 Mdot
.38051 .39392 Mdot
.3919 .41043 Mdot
.61838 .48806 Mdot
.56945 .70686 Mdot
.70366 .57967 Mdot
.55711 .40735 Mdot
.48828 .43743 Mdot
.40066 .64099 Mdot
.80955 .73116 Mdot
.46674 .48529 Mdot
.68754 .55105 Mdot
.59992 .55198 Mdot
.40065 .53768 Mdot
.56952 .39954 Mdot
.74253 .58167 Mdot
.55131 .70185 Mdot
.60904 .38605 Mdot
.52276 .43427 Mdot
.48614 .66679 Mdot
.60061 .70236 Mdot
.40865 .64671 Mdot
.55565 .67401 Mdot
.70418 .54612 Mdot
.39104 .56318 Mdot
.35282 .39793 Mdot
.54725 .38673 Mdot
.62939 .33742 Mdot
.57726 .69966 Mdot
.40714 .53684 Mdot
.55567 .34656 Mdot
.36766 .40202 Mdot
.57556 .71186 Mdot
.56206 .37252 Mdot
.31827 .32601 Mdot
.37561 .48335 Mdot
.5812 .68896 Mdot
.5279 .40689 Mdot
.62611 .43424 Mdot
.60199 .70576 Mdot
.59392 .67473 Mdot
.61016 .37884 Mdot
.74159 .57469 Mdot
.52202 .37706 Mdot
.37069 .65668 Mdot
.56976 .51907 Mdot
.38717 .67842 Mdot
.72133 .46249 Mdot
.60872 .36045 Mdot
.6139 .29756 Mdot
.31783 .43195 Mdot
.75625 .56547 Mdot
.60517 .21173 Mdot
.59994 .42482 Mdot
.2424 .39726 Mdot
.58811 .52039 Mdot
.48129 .51145 Mdot
.22824 .41428 Mdot
.73475 .57212 Mdot
.36641 .67275 Mdot
.55068 .34807 Mdot
.42598 .70156 Mdot
.73448 .57858 Mdot
.72091 .46136 Mdot
.55104 .41741 Mdot
.36662 .41671 Mdot
.55627 .39738 Mdot
.3627 .4013 Mdot
.54147 .36354 Mdot
.31643 .35822 Mdot
.71798 .62059 Mdot
.69202 .38477 Mdot
.49213 .36419 Mdot
.37192 .7485 Mdot
.47633 .31909 Mdot
.70571 .57714 Mdot
.59514 .39925 Mdot
.39493 .53958 Mdot
.36974 .69652 Mdot
.4457 .71328 Mdot
.58369 .72587 Mdot
.39074 .64661 Mdot
.33901 .43976 Mdot
.57971 .66041 Mdot
.40517 .53549 Mdot
.515 .33085 Mdot
.74178 .57913 Mdot
.38933 .66421 Mdot
.54339 .38545 Mdot
.60006 .4147 Mdot
.42502 .76463 Mdot
.7242 .28296 Mdot
.32351 .43036 Mdot
.41467 .84803 Mdot
.37437 .3897 Mdot
.72374 .55788 Mdot
.55522 .72135 Mdot
.56469 .36578 Mdot
.52853 .38255 Mdot
.59955 .70457 Mdot
.33008 .39728 Mdot
.76027 .58237 Mdot
.82174 .45399 Mdot
.41957 .6649 Mdot
.72008 .34883 Mdot
.3588 .43069 Mdot
.72014 .35182 Mdot
.6812 .5857 Mdot
.41846 .56599 Mdot
.6845 .28765 Mdot
.37063 .6889 Mdot
.7204 .34603 Mdot
.36634 .4112 Mdot
.57332 .38998 Mdot
.4023 .55148 Mdot
.40675 .56204 Mdot
.35643 .44139 Mdot
.56228 .72165 Mdot
.72476 .54991 Mdot
.55267 .39696 Mdot
.54696 .31131 Mdot
.51515 .19781 Mdot
.58982 .68585 Mdot
.54873 .32435 Mdot
.38011 .69382 Mdot
.54731 .35758 Mdot
.74289 .58916 Mdot
.36919 .68361 Mdot
.3833 .53738 Mdot
.67148 .44591 Mdot
.52697 .40239 Mdot
.51944 .58627 Mdot
.38 .65977 Mdot
.82866 .43637 Mdot
.53506 .35646 Mdot
.39389 .65569 Mdot
.62797 .33619 Mdot
.3205 .67849 Mdot
.49641 .58343 Mdot
.34132 .57626 Mdot
.53175 .68628 Mdot
.54911 .67863 Mdot
.78544 .31409 Mdot
.66161 .57528 Mdot
.39907 .64911 Mdot
.38603 .55964 Mdot
.72698 .31547 Mdot
.39578 .67033 Mdot
.51651 .39867 Mdot
.57945 .37071 Mdot
.46301 .34316 Mdot
.5021 .44366 Mdot
.39872 .57306 Mdot
.50308 .32168 Mdot
.58597 .39098 Mdot
.51918 .33594 Mdot
.55759 .35003 Mdot
.3787 .40681 Mdot
.37418 .69052 Mdot
.17824 .37152 Mdot
.41228 .67932 Mdot
.62696 .31036 Mdot
.58079 .69214 Mdot
.53636 .67473 Mdot
.5467 .38139 Mdot
.63274 .29751 Mdot
.16648 .60434 Mdot
.5759 .35815 Mdot
.5245 .59927 Mdot
.71978 .47015 Mdot
.4872 .38483 Mdot
.38037 .4503 Mdot
.62124 .3285 Mdot
.36879 .38358 Mdot
.36803 .68396 Mdot
.73465 .57413 Mdot
.73688 .54835 Mdot
.36826 .66702 Mdot
.53004 .38039 Mdot
.74601 .55911 Mdot
.55518 .38195 Mdot
.55911 .40264 Mdot
.49893 .49956 Mdot
.7142 .5943 Mdot
.58338 .72853 Mdot
.71914 .56623 Mdot
.37178 .44465 Mdot
.5644 .8897 Mdot
.70756 .56846 Mdot
.46728 .33727 Mdot
.62118 .50859 Mdot
.72495 .35025 Mdot
.33636 .40236 Mdot
.69727 .56536 Mdot
.36734 .68924 Mdot
.45043 .47064 Mdot
.48743 .29852 Mdot
.36568 .64926 Mdot
.5353 .39079 Mdot
.33486 .45195 Mdot
.38533 .40703 Mdot
.35511 .70218 Mdot
.33254 .39901 Mdot
.50045 .37097 Mdot
.55195 .41105 Mdot
.39072 .6431 Mdot
.43672 .16865 Mdot
.36106 .68498 Mdot
.42924 .3874 Mdot
.58849 .37093 Mdot
.35824 .42625 Mdot
.48431 .31656 Mdot
.33135 .47494 Mdot
.40274 .56449 Mdot
.5159 .37553 Mdot
.70418 .57182 Mdot
.63451 .4874 Mdot
.58332 .69016 Mdot
.24963 .611 Mdot
.34645 .40204 Mdot
.36801 .71165 Mdot
.34032 .39764 Mdot
.32166 .40609 Mdot
.3873 .63435 Mdot
.37032 .42753 Mdot
.52537 .37663 Mdot
.19509 .50459 Mdot
.33715 .40649 Mdot
.37739 .66854 Mdot
.70101 .56258 Mdot
.33017 .4357 Mdot
.69804 .515 Mdot
.5461 .40525 Mdot
.54324 .67693 Mdot
.73847 .53721 Mdot
.31325 .41961 Mdot
.70544 .57875 Mdot
.57501 .70406 Mdot
.73114 .55272 Mdot
.43744 .66549 Mdot
.34194 .6952 Mdot
.671 .36523 Mdot
.32387 .70385 Mdot
.37682 .43368 Mdot
.53922 .66099 Mdot
.52281 .39751 Mdot
.55523 .40044 Mdot
.7197 .5394 Mdot
.38292 .40871 Mdot
.30188 .66092 Mdot
.57433 .28128 Mdot
.30165 .63486 Mdot
.38311 .70314 Mdot
.76352 .52879 Mdot
.46324 .48308 Mdot
.41349 .70557 Mdot
.53534 .33821 Mdot
.40103 .53884 Mdot
.55543 .37491 Mdot
.73441 .48354 Mdot
.70836 .54567 Mdot
.45525 .78191 Mdot
.62073 .37931 Mdot
.59764 .70678 Mdot
.54795 .36165 Mdot
.45763 .66032 Mdot
.60654 .34564 Mdot
.72868 .54653 Mdot
.41028 .69138 Mdot
.33741 .44934 Mdot
.70058 .55605 Mdot
.54644 .69266 Mdot
.67857 .30884 Mdot
.51764 .39869 Mdot
.58318 .39194 Mdot
.60444 .70576 Mdot
.36026 .45291 Mdot
.55657 .70255 Mdot
.39329 .65383 Mdot
.71027 .56815 Mdot
.5819 .41913 Mdot
.5372 .3275 Mdot
.58851 .74219 Mdot
.41034 .665 Mdot
.59544 .72665 Mdot
.41337 .66458 Mdot
.40282 .54267 Mdot
.60036 .35614 Mdot
.60588 .7134 Mdot
.55373 .33636 Mdot
.49195 .2463 Mdot
.65199 .45925 Mdot
.57495 .22954 Mdot
.5818 .72977 Mdot
.69642 .62194 Mdot
.37038 .67283 Mdot
.39057 .66123 Mdot
.41584 .37509 Mdot
.18916 .6349 Mdot
.49429 .56175 Mdot
.33506 .76454 Mdot
.39267 .65287 Mdot
.38354 .66193 Mdot
.55846 .71261 Mdot
.36445 .44785 Mdot
.31038 .4315 Mdot
.60472 .68276 Mdot
.69577 .45122 Mdot
.36113 .40861 Mdot
.24683 .37173 Mdot
.57698 .67123 Mdot
.51678 .35915 Mdot
.40265 .5091 Mdot
.72892 .54697 Mdot
.71091 .47538 Mdot
.37021 .75703 Mdot
.55716 .36769 Mdot
.66312 .79231 Mdot
.57922 .72514 Mdot
.43417 .50114 Mdot
.3844 .61221 Mdot
.59152 .42183 Mdot
.54431 .36559 Mdot
.53091 .36666 Mdot
.69876 .54 Mdot
.50187 .21818 Mdot
.56107 .36708 Mdot
.685 .41931 Mdot
.61564 .41996 Mdot
.40517 .77837 Mdot
.71882 .56614 Mdot
.79313 .45433 Mdot
.56179 .65072 Mdot
.31884 .63124 Mdot
.56203 .42999 Mdot
.38505 .65034 Mdot
.477 .62963 Mdot
.40492 .6788 Mdot
.39585 .5985 Mdot
.71716 .3006 Mdot
.38275 .41225 Mdot
.61259 .40046 Mdot
.58355 .67264 Mdot
.32299 .44241 Mdot
.48099 .62002 Mdot
.54831 .88841 Mdot
.36688 .7073 Mdot
.39433 .86517 Mdot
.39121 .67672 Mdot
.4052 .56601 Mdot
.34028 .43891 Mdot
.63902 .29281 Mdot
.53425 .51039 Mdot
.35339 .45222 Mdot
.70087 .68773 Mdot
.33407 .37879 Mdot
.70088 .34262 Mdot
.39927 .39748 Mdot
.37515 .67547 Mdot
.3615 .71131 Mdot
.55421 .44078 Mdot
.51974 .38404 Mdot
.54168 .51561 Mdot
.55283 .45194 Mdot
.52824 .40209 Mdot
.56911 .68802 Mdot
.32889 .72115 Mdot
.42241 .70655 Mdot
.36193 .43508 Mdot
.40459 .64693 Mdot
.54709 .36312 Mdot
.5929 .40559 Mdot
.51053 .40596 Mdot
.8012 .55839 Mdot
.24584 .37046 Mdot
.5722 .38074 Mdot
.60266 .34108 Mdot
.54527 .69974 Mdot
.42569 .7656 Mdot
.43635 .84423 Mdot
.72087 .3066 Mdot
.56186 .34635 Mdot
.72528 .56265 Mdot
.74554 .58826 Mdot
.49961 .38908 Mdot
.64558 .31027 Mdot
.75578 .53019 Mdot
.54305 .38543 Mdot
.68684 .33752 Mdot
.56353 .74181 Mdot
.39819 .52946 Mdot
.57673 .69991 Mdot
.31545 .4304 Mdot
.40444 .5398 Mdot
.5581 .68373 Mdot
.68132 .44134 Mdot
.38939 .53448 Mdot
.32004 .67222 Mdot
.69734 .56776 Mdot
.54901 .35068 Mdot
.42062 .44591 Mdot
.58408 .6828 Mdot
.38484 .65867 Mdot
.34212 .42736 Mdot
.36952 .69779 Mdot
.38564 .78143 Mdot
.69923 .45798 Mdot
.39422 .56573 Mdot
.38326 .64945 Mdot
.51374 .57789 Mdot
.72313 .56206 Mdot
.39308 .68131 Mdot
.61527 .29613 Mdot
.62196 .39776 Mdot
.15736 .51705 Mdot
.58229 .39905 Mdot
.3681 .56405 Mdot
.38614 .65528 Mdot
.38406 .53274 Mdot
.54876 .38757 Mdot
.55949 .66498 Mdot
.48626 .35822 Mdot
.55692 .38194 Mdot
.56589 .67282 Mdot
.57417 .38374 Mdot
.72988 .59287 Mdot
.35703 .38161 Mdot
.60221 .51645 Mdot
.76494 .51926 Mdot
.71643 .54753 Mdot
.58652 .49136 Mdot
.52078 .36999 Mdot
.66812 .65994 Mdot
.36475 .41675 Mdot
.60126 .42377 Mdot
.73455 .45899 Mdot
.36299 .44452 Mdot
.34517 .41822 Mdot
.59161 .39582 Mdot
.3589 .67873 Mdot
.59281 .72461 Mdot
.72212 .56341 Mdot
.38661 .73191 Mdot
.56349 .37107 Mdot
.611 .38292 Mdot
.70987 .54697 Mdot
.38777 .66625 Mdot
.57411 .42237 Mdot
.27554 .56917 Mdot
.63453 .47539 Mdot
.40572 .64442 Mdot
.62077 .39847 Mdot
.20174 .41867 Mdot
.3082 .41318 Mdot
.67059 .78975 Mdot
.69632 .61673 Mdot
.55538 .71834 Mdot
.57881 .31868 Mdot
.74553 .79422 Mdot
.69862 .56818 Mdot
.31262 .62181 Mdot
.57045 .39122 Mdot
.56745 .36316 Mdot
.38127 .41495 Mdot
.56162 .42191 Mdot
.37344 .41289 Mdot
.77738 .53826 Mdot
.20037 .65455 Mdot
.33082 .40114 Mdot
.36731 .40673 Mdot
.62057 .43119 Mdot
.80813 .56942 Mdot
.35135 .44419 Mdot
.51844 .39935 Mdot
.69139 .66554 Mdot
.51106 .43016 Mdot
.69848 .59019 Mdot
.77386 .55228 Mdot
.37686 .4547 Mdot
.47144 .31139 Mdot
.62078 .43042 Mdot
.33972 .34628 Mdot
.70293 .51953 Mdot
.4006 .65506 Mdot
.60299 .38337 Mdot
.3872 .56257 Mdot
.57162 .71397 Mdot
.60691 .31453 Mdot
.53847 .35497 Mdot
.37705 .44783 Mdot
.69543 .54533 Mdot
.39645 .67529 Mdot
.58387 .3528 Mdot
.5814 .74725 Mdot
.72971 .55707 Mdot
.33264 .41311 Mdot
.44193 .37235 Mdot
.74353 .5573 Mdot
.54591 .32415 Mdot
.57636 .38813 Mdot
.57709 .34953 Mdot
.47703 .39741 Mdot
.37007 .66486 Mdot
.59395 .67023 Mdot
.55621 .32265 Mdot
.4701 .48277 Mdot
.65412 .47082 Mdot
.50789 .39087 Mdot
.33096 .43841 Mdot
.38627 .70106 Mdot
.38971 .55563 Mdot
.72641 .33631 Mdot
.58314 .3776 Mdot
.24322 .37393 Mdot
.80948 .50201 Mdot
.38892 .53932 Mdot
.33504 .45613 Mdot
.72108 .56977 Mdot
.5911 .38273 Mdot
.68737 .41299 Mdot
.53104 .40728 Mdot
.48251 .39569 Mdot
.56415 .72497 Mdot
.40263 .668 Mdot
.66372 .39838 Mdot
.56861 .71378 Mdot
.34557 .41892 Mdot
.25746 .35455 Mdot
.31068 .42655 Mdot
.31975 .41761 Mdot
.43896 .57896 Mdot
.36366 .66482 Mdot
.76061 .78233 Mdot
.83886 .46207 Mdot
.51379 .37103 Mdot
.37296 .64675 Mdot
.34665 .43936 Mdot
.53504 .41925 Mdot
.37387 .4197 Mdot
.38709 .4467 Mdot
.54902 .40791 Mdot
.54146 .40679 Mdot
.69171 .37495 Mdot
.24948 .37379 Mdot
.70318 .56645 Mdot
.34851 .3943 Mdot
.38286 .35756 Mdot
.56699 .3676 Mdot
.52461 .3688 Mdot
.47543 .63452 Mdot
.69787 .55849 Mdot
.35357 .28468 Mdot
.5604 .39841 Mdot
.76262 .4887 Mdot
.51616 .38657 Mdot
.31304 .44501 Mdot
.35016 .67392 Mdot
.62472 .30615 Mdot
.58413 .73231 Mdot
.31846 .4023 Mdot
.70874 .54123 Mdot
.38842 .45663 Mdot
.3612 .31051 Mdot
.36435 .68007 Mdot
.36074 .40269 Mdot
.56936 .65703 Mdot
.38504 .67445 Mdot
.36059 .68024 Mdot
.48309 .61597 Mdot
.55836 .65827 Mdot
.6888 .55089 Mdot
.39139 .69158 Mdot
.31843 .32797 Mdot
.37718 .67688 Mdot
.35359 .30911 Mdot
.54706 .34426 Mdot
.68404 .42333 Mdot
.59556 .307 Mdot
.54497 .44123 Mdot
.38364 .68779 Mdot
.72458 .55157 Mdot
.57542 .42424 Mdot
.32618 .40426 Mdot
.70899 .55708 Mdot
.41312 .50431 Mdot
.54273 .66164 Mdot
.3885 .41234 Mdot
.41475 .66466 Mdot
.37798 .4227 Mdot
.7163 .47141 Mdot
.76215 .58683 Mdot
.48597 .6376 Mdot
.55086 .5109 Mdot
.50987 .34404 Mdot
.61918 .36045 Mdot
.58 .42449 Mdot
.52752 .37512 Mdot
.58031 .68912 Mdot
.6861 .54362 Mdot
.32926 .4349 Mdot
.512 .18928 Mdot
.37982 .65269 Mdot
.51653 .59231 Mdot
.48031 .38611 Mdot
.60851 .38908 Mdot
.34594 .43583 Mdot
.38978 .44641 Mdot
.52231 .23026 Mdot
.59996 .71175 Mdot
.52045 .43558 Mdot
.53532 .42452 Mdot
.64631 .43495 Mdot
.38417 .68522 Mdot
.31657 .55408 Mdot
.54339 .7228 Mdot
.4154 .88016 Mdot
.56713 .71108 Mdot
.61772 .61753 Mdot
.3709 .42969 Mdot
.71327 .58294 Mdot
.53214 .39323 Mdot
.44417 .41209 Mdot
.34908 .46079 Mdot
.58136 .64426 Mdot
.7164 .5757 Mdot
.33551 .52304 Mdot
.38101 .64365 Mdot
.57971 .34778 Mdot
.51591 .38928 Mdot
.58228 .41348 Mdot
.53855 .41809 Mdot
.39473 .64288 Mdot
.53936 .41029 Mdot
.38536 .63047 Mdot
.36902 .30299 Mdot
.73297 .45095 Mdot
.59179 .67584 Mdot
.43866 .7686 Mdot
.32036 .41507 Mdot
.28994 .31069 Mdot
.36554 .28636 Mdot
.6515 .45976 Mdot
.43236 .64351 Mdot
.58058 .346 Mdot
.56378 .72142 Mdot
.39415 .7376 Mdot
.58871 .67332 Mdot
.14485 .4382 Mdot
.46515 .33819 Mdot
.35766 .54416 Mdot
.56893 .41692 Mdot
.60663 .70407 Mdot
.4493 .3349 Mdot
.55222 .3211 Mdot
.75014 .56268 Mdot
.34484 .3208 Mdot
.42445 .4541 Mdot
.7008 .57705 Mdot
.55307 .40538 Mdot
.39563 .41287 Mdot
.52994 .38806 Mdot
.53637 .39839 Mdot
.57672 .35756 Mdot
.35806 .6497 Mdot
.52816 .35163 Mdot
.52233 .37948 Mdot
.73495 .28862 Mdot
.5081 .65424 Mdot
.54486 .68147 Mdot
.5656 .22696 Mdot
.71439 .5582 Mdot
.31602 .43109 Mdot
.58654 .51924 Mdot
.37512 .65043 Mdot
.52463 .22953 Mdot
.58199 .40697 Mdot
.29351 .60769 Mdot
.39233 .70377 Mdot
.73965 .56946 Mdot
.38598 .55379 Mdot
.31313 .52503 Mdot
.5596 .72883 Mdot
.39393 .5727 Mdot
.58522 .69138 Mdot
.59727 .2308 Mdot
.37073 .40901 Mdot
.51055 .34353 Mdot
.39774 .67876 Mdot
.5767 .66353 Mdot
.68608 .41143 Mdot
.53931 .35821 Mdot
.58211 .73001 Mdot
.58417 .31082 Mdot
.64006 .48838 Mdot
.57971 .52044 Mdot
.58042 .66224 Mdot
.3978 .70201 Mdot
.38413 .68063 Mdot
.69933 .57835 Mdot
.31498 .40639 Mdot
.3674 .45153 Mdot
.37856 .68158 Mdot
.58092 .83086 Mdot
.56146 .37092 Mdot
.57527 .37005 Mdot
.46346 .47861 Mdot
.53191 .4195 Mdot
.76987 .56948 Mdot
.40921 .56285 Mdot
.36379 .45553 Mdot
.57756 .42478 Mdot
.57437 .42196 Mdot
.57639 .39287 Mdot
.69849 .44293 Mdot
.57902 .7007 Mdot
.58652 .38934 Mdot
.74259 .57979 Mdot
.41127 .49176 Mdot
.52153 .39502 Mdot
.53558 .32676 Mdot
.37483 .41543 Mdot
.63744 .67584 Mdot
.38298 .65636 Mdot
.59223 .69067 Mdot
.5872 .67787 Mdot
.74471 .41981 Mdot
.30539 .44656 Mdot
.39791 .5746 Mdot
.40354 .76361 Mdot
.3893 .5604 Mdot
.71694 .57838 Mdot
.49294 .5772 Mdot
.5236 .69504 Mdot
.5483 .67853 Mdot
.37287 .71719 Mdot
.60624 .41579 Mdot
.52069 .39677 Mdot
.31464 .63309 Mdot
.57623 .36047 Mdot
.70302 .57152 Mdot
.35708 .66597 Mdot
.3662 .40732 Mdot
.74447 .58651 Mdot
.39237 .66422 Mdot
.35603 .45326 Mdot
.58472 .43098 Mdot
.51812 .40255 Mdot
.34142 .42387 Mdot
.33214 .41002 Mdot
.54431 .37499 Mdot
.7074 .27254 Mdot
.3542 .45668 Mdot
.33994 .43138 Mdot
.41295 .48418 Mdot
.54851 .71523 Mdot
.46572 .40185 Mdot
.3686 .65233 Mdot
.52449 .37439 Mdot
.59749 .68207 Mdot
.72647 .57757 Mdot
.34142 .41201 Mdot
.60014 .37923 Mdot
.56638 .37616 Mdot
.72519 .56407 Mdot
.71401 .59677 Mdot
.70372 .5548 Mdot
.35107 .6847 Mdot
.56047 .41012 Mdot
.34541 .44341 Mdot
.38254 .64291 Mdot
.74733 .56519 Mdot
.69486 .57888 Mdot
.68655 .27534 Mdot
.55453 .36926 Mdot
.75227 .58389 Mdot
.59579 .88715 Mdot
.68798 .31071 Mdot
.40609 .54011 Mdot
.55806 .74297 Mdot
.73102 .62339 Mdot
.7393 .53865 Mdot
.40466 .66251 Mdot
.52123 .60094 Mdot
.69362 .55246 Mdot
.58892 .36412 Mdot
.55891 .35354 Mdot
.54737 .33072 Mdot
.71262 .55576 Mdot
.70226 .45713 Mdot
.37715 .39867 Mdot
.40696 .23505 Mdot
.71418 .55834 Mdot
.56917 .66025 Mdot
.59026 .74283 Mdot
.56208 .70998 Mdot
.59965 .35797 Mdot
.56796 .21069 Mdot
.37546 .33264 Mdot
.35531 .27794 Mdot
.38365 .64534 Mdot
.39009 .44523 Mdot
.4157 .5274 Mdot
.34497 .41744 Mdot
.58146 .7157 Mdot
.72974 .55607 Mdot
.38219 .41512 Mdot
.36111 .68056 Mdot
.38291 .68363 Mdot
.58827 .73344 Mdot
.57244 .70336 Mdot
.56182 .69444 Mdot
.31695 .40379 Mdot
.37073 .42863 Mdot
.58453 .41589 Mdot
.34084 .40824 Mdot
.81992 .51207 Mdot
.7693 .59328 Mdot
.59229 .73574 Mdot
.37501 .66341 Mdot
.33368 .42855 Mdot
.54732 .35044 Mdot
.58023 .60674 Mdot
.55016 .64917 Mdot
.73691 .55477 Mdot
.20273 .58089 Mdot
.18723 .64758 Mdot
.61809 .38919 Mdot
.40843 .65888 Mdot
.63086 .30242 Mdot
.53171 .37009 Mdot
.56673 .72825 Mdot
.81055 .46722 Mdot
.38444 .54029 Mdot
.52591 .39151 Mdot
.5529 .43183 Mdot
.36533 .68947 Mdot
.58508 .51867 Mdot
.5896 .36346 Mdot
.50333 .60135 Mdot
.382 .70731 Mdot
.54595 .72546 Mdot
.81583 .34593 Mdot
.42893 .49774 Mdot
.70805 .48915 Mdot
.40064 .53266 Mdot
.5819 .36252 Mdot
.57148 .68746 Mdot
.74676 .57184 Mdot
.57068 .69432 Mdot
.32816 .45206 Mdot
.5542 .72267 Mdot
.56664 .35081 Mdot
.3502 .44583 Mdot
.38919 .66582 Mdot
.52488 .57426 Mdot
.60994 .24674 Mdot
.55773 .66586 Mdot
.40584 .53294 Mdot
.53991 .40589 Mdot
.30302 .32524 Mdot
.56078 .44059 Mdot
.52035 .37746 Mdot
.40068 .68655 Mdot
.35416 .43664 Mdot
.38452 .70271 Mdot
.54213 .32008 Mdot
.2657 .38213 Mdot
.37659 .65422 Mdot
.4429 .4194 Mdot
.71245 .54545 Mdot
.69607 .4556 Mdot
.54771 .39263 Mdot
.39881 .67569 Mdot
.57001 .40679 Mdot
.35196 .39402 Mdot
.66721 .45786 Mdot
.62371 .47505 Mdot
.37835 .69421 Mdot
.36913 .51705 Mdot
.64235 .49923 Mdot
.46405 .41049 Mdot
.39686 .65935 Mdot
.60045 .2122 Mdot
.39311 .5423 Mdot
.73279 .56508 Mdot
.71869 .59838 Mdot
.72737 .58671 Mdot
.57368 .36155 Mdot
.31483 .35074 Mdot
.70158 .58634 Mdot
.36044 .69784 Mdot
.71787 .59194 Mdot
.78969 .53332 Mdot
.30253 .64783 Mdot
.71601 .54663 Mdot
.55476 .39224 Mdot
.63288 .32476 Mdot
.52226 .59882 Mdot
.53927 .67485 Mdot
.2695 .47462 Mdot
.73763 .29289 Mdot
.56355 .36525 Mdot
.29459 .36377 Mdot
.33029 .45936 Mdot
.62856 .59406 Mdot
.62418 .47241 Mdot
.49853 .54977 Mdot
.33617 .4296 Mdot
.56862 .51563 Mdot
.33383 .4498 Mdot
.49224 .36194 Mdot
.56984 .38233 Mdot
.31245 .40642 Mdot
.2406 .60676 Mdot
.57344 .19028 Mdot
.29668 .63009 Mdot
.33884 .44708 Mdot
.39461 .65857 Mdot
.40751 .67388 Mdot
.40117 .68495 Mdot
.57317 .68146 Mdot
.35511 .39989 Mdot
.58542 .37952 Mdot
.54798 .70064 Mdot
.54458 .40015 Mdot
.37367 .68604 Mdot
.64323 .46501 Mdot
.36851 .4089 Mdot
.54245 .38687 Mdot
.42973 .35689 Mdot
.58649 .69707 Mdot
.72334 .56043 Mdot
.19725 .54975 Mdot
.54456 .73273 Mdot
.40899 .68996 Mdot
.36661 .46647 Mdot
.6083 .73497 Mdot
.58299 .62726 Mdot
.51346 .36875 Mdot
.51141 .38465 Mdot
.52589 .60738 Mdot
.46042 .33815 Mdot
.59135 .36241 Mdot
.54659 .69102 Mdot
.54133 .6986 Mdot
.57071 .40544 Mdot
.34292 .39915 Mdot
.6891 .56367 Mdot
.72154 .53966 Mdot
.49461 .36401 Mdot
.5506 .51389 Mdot
.68444 .42104 Mdot
.56234 .42534 Mdot
.57116 .3269 Mdot
.56189 .65564 Mdot
.40428 .53469 Mdot
.52397 .50564 Mdot
.7126 .58623 Mdot
.5685 .395 Mdot
.51707 .20005 Mdot
.34873 .40237 Mdot
.58631 .72941 Mdot
.38063 .63848 Mdot
.74577 .55925 Mdot
.58231 .73855 Mdot
.57069 .4054 Mdot
.57377 .42233 Mdot
.39459 .68204 Mdot
.31277 .44746 Mdot
.71856 .5521 Mdot
.54742 .70097 Mdot
.71093 .5828 Mdot
.37056 .42509 Mdot
.3338 .4205 Mdot
.515 .41562 Mdot
.55013 .44247 Mdot
.5678 .66783 Mdot
.52574 .3399 Mdot
.55262 .6995 Mdot
.42454 .76506 Mdot
.40023 .64098 Mdot
.58117 .42824 Mdot
.3102 .45581 Mdot
.37572 .68523 Mdot
.55775 .3631 Mdot
.52552 .61008 Mdot
.60827 .40276 Mdot
.60367 .68286 Mdot
.81553 .44022 Mdot
.72976 .58163 Mdot
.64035 .38518 Mdot
.55846 .26957 Mdot
.54171 .423 Mdot
.53877 .68422 Mdot
.34362 .33025 Mdot
.3714 .65873 Mdot
.36897 .43563 Mdot
.63533 .74846 Mdot
.37754 .67129 Mdot
.56082 .39374 Mdot
.70793 .56751 Mdot
.3328 .44608 Mdot
.40389 .55731 Mdot
.52048 .51772 Mdot
.62081 .3191 Mdot
.4987 .40751 Mdot
.58504 .35283 Mdot
.33361 .76392 Mdot
.56464 .6941 Mdot
.34521 .43727 Mdot
.40682 .65575 Mdot
.36422 .67284 Mdot
.58427 .70339 Mdot
.42042 .46586 Mdot
.26901 .62479 Mdot
.63938 .86423 Mdot
.58527 .73891 Mdot
.72411 .59027 Mdot
.66455 .4589 Mdot
.56228 .71214 Mdot
.58034 .68402 Mdot
.55286 .65552 Mdot
.3104 .64146 Mdot
.34081 .4472 Mdot
.56768 .37525 Mdot
.368 .47307 Mdot
.57914 .36216 Mdot
.68818 .49593 Mdot
.3728 .68447 Mdot
.36968 .43506 Mdot
.70172 .51213 Mdot
.60703 .34323 Mdot
.53612 .37216 Mdot
.67337 .52013 Mdot
.65321 .38379 Mdot
.72393 .34309 Mdot
.51486 .40816 Mdot
.5763 .69418 Mdot
.32616 .48254 Mdot
.54935 .32365 Mdot
.42643 .35837 Mdot
.38736 .67888 Mdot
.39485 .56721 Mdot
.50769 .3436 Mdot
.5755 .33489 Mdot
.3293 .44328 Mdot
.38287 .41795 Mdot
.69773 .58379 Mdot
.19709 .51248 Mdot
.38894 .67502 Mdot
.33583 .56362 Mdot
.51939 .37958 Mdot
.41206 .61558 Mdot
.81798 .46012 Mdot
.55087 .36493 Mdot
.48573 .6096 Mdot
.52293 .2306 Mdot
.60595 .37937 Mdot
.36518 .26923 Mdot
.37306 .66948 Mdot
.7429 .47179 Mdot
.54626 .41538 Mdot
.57469 .72879 Mdot
.36821 .44535 Mdot
.38864 .41207 Mdot
.74789 .57169 Mdot
.83191 .4975 Mdot
.24343 .69565 Mdot
.37125 .43404 Mdot
.53491 .36058 Mdot
.38135 .65766 Mdot
.4012 .56401 Mdot
.61126 .3175 Mdot
.44862 .67133 Mdot
.35095 .40354 Mdot
.56171 .32098 Mdot
.28904 .60911 Mdot
.57637 .5179 Mdot
.25132 .33437 Mdot
.39632 .69016 Mdot
.70759 .58542 Mdot
.49734 .42798 Mdot
.40414 .7663 Mdot
.51746 .4017 Mdot
.6943 .49329 Mdot
.30065 .41818 Mdot
.70275 .57739 Mdot
.53118 .37768 Mdot
.59419 .36624 Mdot
.58194 .50132 Mdot
.71229 .59919 Mdot
.59129 .36459 Mdot
.62041 .37792 Mdot
.37486 .43963 Mdot
.4098 .56171 Mdot
.36445 .40701 Mdot
.53092 .38709 Mdot
.7996 .40918 Mdot
.36621 .39841 Mdot
.28982 .48745 Mdot
.6867 .61096 Mdot
.37652 .64978 Mdot
.60666 .32301 Mdot
.53818 .34807 Mdot
.22507 .35281 Mdot
.40391 .56393 Mdot
.47988 .84892 Mdot
.60555 .69778 Mdot
.69166 .21755 Mdot
.54156 .72937 Mdot
.36084 .52354 Mdot
.50553 .6457 Mdot
.5618 .3238 Mdot
.44746 .40117 Mdot
.34689 .27773 Mdot
.38972 .61783 Mdot
.29612 .30685 Mdot
.51973 .38424 Mdot
.57278 .39393 Mdot
.55431 .70909 Mdot
.37051 .55101 Mdot
.62289 .30415 Mdot
.52662 .50677 Mdot
.73845 .56684 Mdot
.3578 .41882 Mdot
.55805 .35208 Mdot
.22599 .59772 Mdot
.56429 .66229 Mdot
.62067 .26037 Mdot
.5452 .38805 Mdot
.63877 .3145 Mdot
.37209 .55307 Mdot
.38894 .6627 Mdot
.58028 .66186 Mdot
.56094 .65932 Mdot
.58179 .36438 Mdot
.38898 .64018 Mdot
.59616 .40874 Mdot
.64905 .4948 Mdot
.5826 .31303 Mdot
.72085 .57842 Mdot
.52804 .36098 Mdot
.59765 .26296 Mdot
.3223 .22498 Mdot
.62137 .37465 Mdot
.31718 .41765 Mdot
.55885 .69281 Mdot
.57892 .70618 Mdot
.36389 .45309 Mdot
.57938 .70677 Mdot
.40595 .24034 Mdot
.27897 .36116 Mdot
.71465 .57936 Mdot
.38511 .29307 Mdot
.73502 .57655 Mdot
.39405 .56706 Mdot
.55107 .37037 Mdot
.50031 .73732 Mdot
.57822 .7405 Mdot
.79337 .52877 Mdot
.37638 .68021 Mdot
.40507 .56399 Mdot
.54377 .40844 Mdot
.68353 .52333 Mdot
.57506 .72147 Mdot
.46215 .55214 Mdot
.5808 .37086 Mdot
.33297 .39674 Mdot
.60736 .38439 Mdot
.59973 .44117 Mdot
.40534 .56696 Mdot
.60667 .37154 Mdot
.39235 .66402 Mdot
.36691 .40207 Mdot
.35978 .55548 Mdot
.58246 .6821 Mdot
.52972 .39873 Mdot
.53347 .36272 Mdot
.36914 .46044 Mdot
.51605 .36746 Mdot
.39264 .64606 Mdot
.84566 .68016 Mdot
.70388 .55143 Mdot
.4031 .53334 Mdot
.2415 .49175 Mdot
.60407 .37136 Mdot
.58293 .42093 Mdot
.47432 .53037 Mdot
.52088 .20026 Mdot
.38467 .65191 Mdot
.49325 .39836 Mdot
.54231 .68766 Mdot
.71939 .55138 Mdot
.36583 .69581 Mdot
.54965 .41131 Mdot
.57572 .38063 Mdot
.70318 .57588 Mdot
.67214 .5182 Mdot
.7577 .58477 Mdot
.40087 .65314 Mdot
.28087 .38255 Mdot
.58204 .6062 Mdot
.55726 .37598 Mdot
.3986 .52233 Mdot
.35139 .43343 Mdot
.39644 .65592 Mdot
.49103 .21681 Mdot
.49084 .36405 Mdot
.40959 .64752 Mdot
.38951 .66824 Mdot
.51949 .36073 Mdot
.30368 .44144 Mdot
.37721 .46474 Mdot
.34825 .43405 Mdot
.73687 .44437 Mdot
.41044 .81903 Mdot
.5628 .69043 Mdot
.37754 .66368 Mdot
.59944 .68611 Mdot
.69636 .55036 Mdot
.64959 .47664 Mdot
.55449 .66329 Mdot
.3296 .39557 Mdot
.59078 .67759 Mdot
.5969 .40934 Mdot
.35946 .67006 Mdot
.57495 .67124 Mdot
.53961 .42023 Mdot
.57815 .3401 Mdot
.50538 .44543 Mdot
.68956 .55363 Mdot
.5665 .51675 Mdot
.55301 .39605 Mdot
.3863 .55162 Mdot
.54371 .3796 Mdot
.3921 .64436 Mdot
.5293 .5744 Mdot
.58554 .3968 Mdot
.57916 .74062 Mdot
.43552 .83517 Mdot
.54133 .70613 Mdot
.59711 .44833 Mdot
.53617 .3916 Mdot
.55793 .37316 Mdot
.54542 .40772 Mdot
.42064 .45956 Mdot
.41585 .67188 Mdot
.48759 .406 Mdot
.59937 .72196 Mdot
.34208 .41734 Mdot
.369 .39797 Mdot
.48544 .5498 Mdot
.39245 .57175 Mdot
.38031 .6412 Mdot
.55974 .37234 Mdot
.46365 .55585 Mdot
.49547 .5131 Mdot
.28985 .62079 Mdot
.59054 .75538 Mdot
.55073 .67517 Mdot
.31884 .40882 Mdot
.55931 .67493 Mdot
.54405 .4106 Mdot
.56325 .32136 Mdot
.35807 .55092 Mdot
.403 .6237 Mdot
.72316 .55293 Mdot
.53898 .39728 Mdot
.69418 .42333 Mdot
.54533 .69982 Mdot
.56102 .65649 Mdot
.59364 .4097 Mdot
.326 .46146 Mdot
.39786 .16381 Mdot
.37009 .64838 Mdot
.30214 .33227 Mdot
.40996 .44628 Mdot
.63757 .45343 Mdot
.36729 .6681 Mdot
.49111 .60113 Mdot
.53599 .67973 Mdot
.79971 .38802 Mdot
.33935 .42115 Mdot
.72166 .55322 Mdot
.52311 .40999 Mdot
.32906 .39563 Mdot
.6045 .72142 Mdot
.34418 .45603 Mdot
.51418 .33979 Mdot
.37585 .70459 Mdot
.57289 .71151 Mdot
.36422 .71423 Mdot
.32375 .44451 Mdot
.73371 .57851 Mdot
.75297 .48697 Mdot
.31643 .32402 Mdot
.52093 .2322 Mdot
.58697 .38829 Mdot
.49013 .68438 Mdot
.58624 .37731 Mdot
.38173 .3993 Mdot
.54865 .39278 Mdot
.61554 .34544 Mdot
.53511 .67819 Mdot
.50778 .39379 Mdot
.52445 .36699 Mdot
.4172 .35972 Mdot
.54415 .3673 Mdot
.57034 .40325 Mdot
.51613 .41818 Mdot
.30641 .41252 Mdot
.5086 .39752 Mdot
.32855 .3993 Mdot
.30669 .61661 Mdot
.58467 .68595 Mdot
.69565 .55202 Mdot
.70354 .54639 Mdot
.70888 .49219 Mdot
.6952 .43124 Mdot
.39261 .50009 Mdot
.35736 .40833 Mdot
.38311 .68685 Mdot
.59236 .41191 Mdot
.61534 .21656 Mdot
.79378 .41308 Mdot
.53364 .6958 Mdot
.57918 .66981 Mdot
.52611 .4083 Mdot
.18054 .62954 Mdot
.51349 .40168 Mdot
.4646 .4829 Mdot
.57461 .36294 Mdot
.58397 .42786 Mdot
.57794 .65931 Mdot
.71619 .4724 Mdot
.58636 .38941 Mdot
.32939 .44376 Mdot
.72763 .55749 Mdot
.64756 .33358 Mdot
.79455 .43999 Mdot
.43101 .38934 Mdot
.5847 .28072 Mdot
.57971 .40492 Mdot
.552 .71276 Mdot
.33525 .44533 Mdot
.47836 .49213 Mdot
.38744 .64509 Mdot
.53747 .51792 Mdot
.35926 .30365 Mdot
.37702 .61398 Mdot
.72879 .5564 Mdot
.59357 .66079 Mdot
.57192 .35112 Mdot
.56892 .68265 Mdot
.48725 .38345 Mdot
.49647 .51885 Mdot
.7181 .58055 Mdot
.32215 .39118 Mdot
.39413 .65846 Mdot
.3581 .39215 Mdot
.5739 .22904 Mdot
.79489 .41023 Mdot
.69662 .22016 Mdot
.55892 .73045 Mdot
.43317 .1904 Mdot
.35713 .44214 Mdot
.58371 .37122 Mdot
.63596 .86541 Mdot
.35726 .43099 Mdot
.33043 .39724 Mdot
.51381 .54603 Mdot
.72252 .46346 Mdot
.52134 .34226 Mdot
.35852 .45746 Mdot
.60062 .6683 Mdot
.71719 .57168 Mdot
.54745 .42145 Mdot
.51264 .33988 Mdot
.38195 .41561 Mdot
.57989 .7199 Mdot
.69295 .4839 Mdot
.57514 .6989 Mdot
.34377 .44751 Mdot
.59148 .70148 Mdot
.32133 .50606 Mdot
.55719 .66335 Mdot
.53364 .35343 Mdot
.55962 .37323 Mdot
.43852 .61421 Mdot
.33381 .42047 Mdot
.58206 .42154 Mdot
.57268 .38818 Mdot
.34849 .44296 Mdot
.52243 .68755 Mdot
.48102 .19777 Mdot
.59083 .41743 Mdot
.56448 .37287 Mdot
.69959 .55443 Mdot
.62032 .50001 Mdot
.45567 .48141 Mdot
.54598 .42284 Mdot
.72939 .5871 Mdot
.3191 .40262 Mdot
.54278 .37823 Mdot
.71856 .4736 Mdot
.5677 .74368 Mdot
.57077 .41358 Mdot
.40052 .56121 Mdot
.58165 .35828 Mdot
.37911 .17956 Mdot
.53562 .40423 Mdot
.33855 .43765 Mdot
.36299 .44568 Mdot
.59592 .76137 Mdot
.34616 .42071 Mdot
.40604 .54153 Mdot
.38296 .68098 Mdot
.26291 .3352 Mdot
.40719 .54651 Mdot
.60968 .375 Mdot
.8407 .46855 Mdot
.5171 .33626 Mdot
.54599 .32169 Mdot
.80926 .56924 Mdot
.40114 .5335 Mdot
.35912 .43721 Mdot
.23581 .59527 Mdot
.51487 .3537 Mdot
.37827 .64159 Mdot
.54024 .32597 Mdot
.5712 .41318 Mdot
.62367 .36845 Mdot
.27677 .37642 Mdot
.36289 .65234 Mdot
.4651 .40344 Mdot
.54839 .42165 Mdot
.52143 .20088 Mdot
.54789 .35262 Mdot
.73025 .54927 Mdot
.36978 .4161 Mdot
.56203 .67666 Mdot
.72055 .57569 Mdot
.58684 .35614 Mdot
.71216 .55764 Mdot
.56723 .68513 Mdot
.39691 .68464 Mdot
.53773 .3511 Mdot
.69783 .58993 Mdot
.73208 .55722 Mdot
.59753 .39337 Mdot
.37069 .4388 Mdot
.56789 .43941 Mdot
.54315 .37525 Mdot
.55461 .40916 Mdot
.36966 .45004 Mdot
.7236 .75694 Mdot
.57487 .39468 Mdot
.48984 .60445 Mdot
.36991 .38626 Mdot
.40951 .5563 Mdot
.54887 .68456 Mdot
.61765 .37231 Mdot
.36343 .66944 Mdot
.38134 .68031 Mdot
.56543 .73769 Mdot
.38189 .42467 Mdot
.57671 .71158 Mdot
.62144 .37146 Mdot
.55804 .32249 Mdot
.52492 .41054 Mdot
.63297 .755 Mdot
.30548 .51637 Mdot
.32883 .42198 Mdot
.53666 .69051 Mdot
.53734 .5139 Mdot
.3619 .66144 Mdot
.5733 .65574 Mdot
.39907 .44163 Mdot
.38041 .4415 Mdot
.35815 .45507 Mdot
.73994 .57926 Mdot
.56876 .7081 Mdot
.39284 .45436 Mdot
.37873 .46228 Mdot
.59382 .40563 Mdot
.55533 .42181 Mdot
.31017 .41037 Mdot
.62648 .69218 Mdot
.73059 .57574 Mdot
.55171 .71543 Mdot
.35154 .17788 Mdot
.3715 .64653 Mdot
.4201 .35978 Mdot
.5381 .42062 Mdot
.46195 .90394 Mdot
.51364 .40318 Mdot
.53828 .35741 Mdot
.31544 .4304 Mdot
.73385 .59777 Mdot
.71631 .5688 Mdot
.35796 .44272 Mdot
.38396 .44799 Mdot
.74106 .56251 Mdot
.50563 .55498 Mdot
.41956 .16956 Mdot
.4932 .50465 Mdot
.32862 .42973 Mdot
.31851 .318 Mdot
.37653 .69601 Mdot
.35217 .3845 Mdot
.34962 .71647 Mdot
.58795 .68761 Mdot
.5622 .66509 Mdot
.39123 .68639 Mdot
.57415 .39832 Mdot
.57122 .73211 Mdot
.6263 .4078 Mdot
.35228 .52962 Mdot
.44436 .65233 Mdot
.66707 .22913 Mdot
.52899 .35468 Mdot
.64097 .30931 Mdot
.30881 .71024 Mdot
.61388 .39005 Mdot
.49552 .30324 Mdot
.71692 .55309 Mdot
.35976 .38397 Mdot
.35414 .67427 Mdot
.24121 .39645 Mdot
.55784 .37476 Mdot
.33029 .43603 Mdot
.36451 .65407 Mdot
.33223 .52572 Mdot
.50292 .60071 Mdot
.60578 .39357 Mdot
.68901 .83184 Mdot
.33883 .45555 Mdot
.56163 .67695 Mdot
.40415 .33997 Mdot
.34861 .39016 Mdot
.53817 .61863 Mdot
.61045 .69599 Mdot
.50904 .4956 Mdot
.36198 .4589 Mdot
.75964 .58198 Mdot
.36292 .41778 Mdot
.73479 .59244 Mdot
.36644 .46621 Mdot
.5874 .70826 Mdot
.53494 .37891 Mdot
.58651 .70185 Mdot
.73235 .54839 Mdot
.56289 .73374 Mdot
.3542 .67446 Mdot
.39416 .53058 Mdot
.37434 .68724 Mdot
.6574 .46623 Mdot
.46972 .22658 Mdot
.40277 .66904 Mdot
.46751 .58176 Mdot
.57295 .35523 Mdot
.31318 .44484 Mdot
.56733 .67733 Mdot
.53037 .70532 Mdot
.56094 .51552 Mdot
.35101 .4514 Mdot
.58501 .71831 Mdot
.3224 .3218 Mdot
.57327 .83868 Mdot
.60367 .33174 Mdot
.40913 .80123 Mdot
.34334 .44138 Mdot
.54 .66749 Mdot
.46278 .47882 Mdot
.38215 .40849 Mdot
.57177 .66927 Mdot
.39734 .66275 Mdot
.36501 .6649 Mdot
.51619 .36916 Mdot
.3585 .70317 Mdot
.5423 .67309 Mdot
.52091 .19819 Mdot
.3746 .42546 Mdot
.2858 .50691 Mdot
.7142 .54811 Mdot
.57686 .68303 Mdot
.50587 .37225 Mdot
.3088 .45592 Mdot
.59682 .68654 Mdot
.22474 .67825 Mdot
.26537 .25425 Mdot
.58437 .71963 Mdot
.36914 .4152 Mdot
.34322 .41175 Mdot
.60868 .35429 Mdot
.54109 .51116 Mdot
.57699 .72296 Mdot
.49913 .73596 Mdot
.69029 .3967 Mdot
.40316 .54312 Mdot
.73607 .29068 Mdot
.58532 .39019 Mdot
.57911 .40619 Mdot
.3988 .64986 Mdot
.53813 .36859 Mdot
.38578 .44901 Mdot
.5142 .40485 Mdot
.3945 .69914 Mdot
.55468 .7317 Mdot
.55242 .3729 Mdot
.71717 .55034 Mdot
.39104 .69875 Mdot
.40985 .67285 Mdot
.59326 .6976 Mdot
.37706 .43898 Mdot
.24601 .63318 Mdot
.57469 .70099 Mdot
.5632 .41004 Mdot
.38996 .54036 Mdot
.50929 .40564 Mdot
.43597 .60746 Mdot
.38483 .40336 Mdot
.55908 .67543 Mdot
.31651 .39302 Mdot
.38126 .66348 Mdot
.53207 .68706 Mdot
.57519 .35084 Mdot
.55602 .66896 Mdot
.48901 .62846 Mdot
.67062 .64367 Mdot
.37934 .45944 Mdot
.52227 .61706 Mdot
.38292 .42891 Mdot
.40424 .5454 Mdot
.74038 .41267 Mdot
.73281 .5682 Mdot
.54323 .70213 Mdot
.29233 .48989 Mdot
.57831 .67825 Mdot
.54825 .36417 Mdot
.57736 .37796 Mdot
.55326 .70676 Mdot
.73502 .58079 Mdot
.74401 .50972 Mdot
.76568 .56528 Mdot
.35587 .40079 Mdot
.51709 .57953 Mdot
.38112 .16248 Mdot
.58776 .75082 Mdot
.38723 .68513 Mdot
.54406 .28478 Mdot
.60511 .37578 Mdot
.36345 .65348 Mdot
.40447 .6462 Mdot
.75048 .57407 Mdot
.57913 .6818 Mdot
.38204 .39494 Mdot
.36291 .69285 Mdot
.30755 .45909 Mdot
.70565 .48009 Mdot
.48475 .37467 Mdot
.61491 .46188 Mdot
.58019 .34661 Mdot
.57554 .5183 Mdot
.38436 .70559 Mdot
.562 .39007 Mdot
.48459 .42151 Mdot
.39126 .65076 Mdot
.74891 .58214 Mdot
.28943 .40113 Mdot
.58796 .71793 Mdot
.51374 .87959 Mdot
.53494 .35341 Mdot
.53818 .37883 Mdot
.38291 .64535 Mdot
.46362 .32729 Mdot
.32628 .41692 Mdot
.3771 .43319 Mdot
.56403 .69454 Mdot
.49607 .5279 Mdot
.5161 .36586 Mdot
.55256 .34803 Mdot
.57698 .72997 Mdot
.38698 .55223 Mdot
.72545 .26958 Mdot
.56543 .3779 Mdot
.37053 .66959 Mdot
.47723 .62937 Mdot
.37911 .70666 Mdot
.61714 .41165 Mdot
.55455 .36125 Mdot
.5727 .3472 Mdot
.53832 .34522 Mdot
.37654 .69271 Mdot
.58613 .35371 Mdot
.48762 .3906 Mdot
.35532 .43578 Mdot
.58174 .40011 Mdot
.69075 .39084 Mdot
.56148 .37867 Mdot
.71459 .55147 Mdot
.46076 .48997 Mdot
.53464 .40218 Mdot
.58023 .40199 Mdot
.68942 .40449 Mdot
.52956 .37539 Mdot
.36353 .65474 Mdot
.33911 .41618 Mdot
.38157 .66168 Mdot
.39001 .67909 Mdot
.59118 .67974 Mdot
.72574 .5958 Mdot
.56279 .33566 Mdot
.7448 .5716 Mdot
.607 .34803 Mdot
.54696 .31856 Mdot
.64231 .48867 Mdot
.46708 .48539 Mdot
.69655 .5484 Mdot
.55863 .34887 Mdot
.56798 .68953 Mdot
.55827 .67393 Mdot
.52126 .60201 Mdot
.58794 .31478 Mdot
.35711 .69042 Mdot
.39895 .67492 Mdot
.77211 .59022 Mdot
.66789 .62245 Mdot
.73336 .55706 Mdot
.65966 .51261 Mdot
.57805 .43176 Mdot
.56263 .40247 Mdot
.59852 .31192 Mdot
.60259 .68784 Mdot
.39509 .5299 Mdot
.581 .73516 Mdot
.38005 .57636 Mdot
.37321 .69793 Mdot
.52806 .35583 Mdot
.16396 .58195 Mdot
.35778 .39863 Mdot
.33857 .41582 Mdot
.39472 .69921 Mdot
.54088 .70386 Mdot
.57965 .31354 Mdot
.43002 .85781 Mdot
.39174 .42399 Mdot
.69283 .56489 Mdot
.52736 .38397 Mdot
.58796 .68991 Mdot
.37113 .40683 Mdot
.69435 .58483 Mdot
.54294 .34475 Mdot
.60797 .68303 Mdot
.55697 .38807 Mdot
.39009 .2714 Mdot
.36478 .43574 Mdot
.61937 .48784 Mdot
.31051 .42918 Mdot
.37354 .69084 Mdot
.38602 .65421 Mdot
.5573 .36267 Mdot
.4722 .87382 Mdot
.31486 .47279 Mdot
.39918 .6362 Mdot
.70015 .5881 Mdot
.38973 .53271 Mdot
.70635 .591 Mdot
.55323 .70162 Mdot
.7302 .55852 Mdot
.59543 .68543 Mdot
.62601 .68845 Mdot
.40503 .42132 Mdot
.70317 .57462 Mdot
.51231 .27468 Mdot
.56649 .32083 Mdot
.74156 .55602 Mdot
.53272 .41198 Mdot
.61698 .3575 Mdot
.58653 .72519 Mdot
.74163 .57353 Mdot
.60027 .38009 Mdot
.23998 .48679 Mdot
.39105 .66252 Mdot
.35504 .68476 Mdot
.55536 .32361 Mdot
.54644 .66004 Mdot
.37555 .46088 Mdot
.61431 .51367 Mdot
.41099 .55517 Mdot
.54997 .34854 Mdot
.60119 .35745 Mdot
.33089 .45196 Mdot
.31989 .41509 Mdot
.55975 .36093 Mdot
.29964 .3444 Mdot
.58224 .35366 Mdot
.36668 .66091 Mdot
.35541 .40011 Mdot
.34093 .41185 Mdot
.54558 .66983 Mdot
.38149 .41933 Mdot
.51029 .42634 Mdot
.38322 .62198 Mdot
.49687 .37544 Mdot
.37956 .66678 Mdot
.62124 .73389 Mdot
.59962 .71169 Mdot
.28678 .48735 Mdot
.38066 .41925 Mdot
.5787 .42439 Mdot
.36548 .39701 Mdot
.70223 .55689 Mdot
.33413 .41641 Mdot
.3255 .45239 Mdot
.51792 .38565 Mdot
.59173 .36619 Mdot
.38896 .55182 Mdot
.55219 .51251 Mdot
.36621 .42975 Mdot
.61306 .4015 Mdot
.5363 .42263 Mdot
.57946 .37506 Mdot
.63749 .50143 Mdot
.31408 .4045 Mdot
.43149 .39155 Mdot
.41622 .58467 Mdot
.36949 .43053 Mdot
.27779 .2588 Mdot
.39063 .56176 Mdot
.39039 .57153 Mdot
.39923 .70258 Mdot
.56689 .37459 Mdot
.58058 .70911 Mdot
.57635 .40872 Mdot
.62088 .32791 Mdot
.53195 .39904 Mdot
.70082 .574 Mdot
.51284 .36927 Mdot
.40075 .54887 Mdot
.57841 .6967 Mdot
.61272 .39569 Mdot
.55825 .36951 Mdot
.39128 .56988 Mdot
.30961 .4092 Mdot
.38074 .43556 Mdot
.4019 .58382 Mdot
.74775 .56717 Mdot
.40302 .68343 Mdot
.56595 .41038 Mdot
.56593 .69251 Mdot
.58342 .70246 Mdot
.34533 .39302 Mdot
.56936 .72825 Mdot
.39885 .69197 Mdot
.54381 .35554 Mdot
.37435 .69096 Mdot
.70055 .57354 Mdot
.37018 .41667 Mdot
.54061 .41021 Mdot
.59706 .40081 Mdot
.36315 .44551 Mdot
.58688 .35968 Mdot
.69692 .56759 Mdot
.59341 .67337 Mdot
.33144 .41353 Mdot
.38333 .67961 Mdot
.55023 .66587 Mdot
.58628 .41713 Mdot
.20768 .335 Mdot
.53895 .36719 Mdot
.5532 .34645 Mdot
.3648 .4986 Mdot
.55785 .43028 Mdot
.58121 .68048 Mdot
.37271 .40108 Mdot
.61859 .38938 Mdot
.69069 .40732 Mdot
.72564 .60539 Mdot
.60314 .73877 Mdot
.52521 .37435 Mdot
.24785 .33453 Mdot
.55092 .42575 Mdot
.28233 .4795 Mdot
.64157 .48875 Mdot
.38193 .75287 Mdot
.61465 .46189 Mdot
.40231 .6393 Mdot
.38684 .54605 Mdot
.59583 .69263 Mdot
.45445 .3189 Mdot
.55224 .3586 Mdot
.52243 .22596 Mdot
.54595 .41172 Mdot
.36652 .66823 Mdot
.48029 .32433 Mdot
.55618 .72029 Mdot
.72573 .2879 Mdot
.58057 .3901 Mdot
.33768 .45376 Mdot
.54495 .65553 Mdot
.38429 .55268 Mdot
.59366 .37089 Mdot
.73401 .55394 Mdot
.75774 .60024 Mdot
.5149 .42956 Mdot
.38166 .6668 Mdot
.5695 .39531 Mdot
.62352 .41746 Mdot
.60867 .80697 Mdot
.34681 .43561 Mdot
.39457 .67209 Mdot
.66233 .60869 Mdot
.57776 .3741 Mdot
.3802 .44108 Mdot
.34028 .42012 Mdot
.74602 .5798 Mdot
.38133 .73174 Mdot
.7798 .5517 Mdot
.15993 .50406 Mdot
.5678 .21568 Mdot
.60145 .68382 Mdot
.35431 .36781 Mdot
.58647 .40368 Mdot
.79607 .41025 Mdot
.38755 .68152 Mdot
.53637 .38058 Mdot
.52337 .23863 Mdot
.34044 .43187 Mdot
.56222 .38518 Mdot
.73017 .57447 Mdot
.27284 .68071 Mdot
.34984 .31667 Mdot
.21768 .36243 Mdot
.6029 .67085 Mdot
.51709 .34442 Mdot
.50267 .4148 Mdot
.40956 .55181 Mdot
.61856 .39853 Mdot
.5688 .67861 Mdot
.47804 .65077 Mdot
.72107 .58515 Mdot
.36207 .39897 Mdot
.38688 .55973 Mdot
.54616 .41206 Mdot
.48922 .37876 Mdot
.69521 .57543 Mdot
.58865 .37205 Mdot
.39499 .34406 Mdot
.379 .55766 Mdot
.5594 .66248 Mdot
.33945 .45356 Mdot
.58791 .35001 Mdot
.38827 .53647 Mdot
.51816 .39074 Mdot
.60774 .26678 Mdot
.53771 .39494 Mdot
.28347 .46248 Mdot
.36891 .44518 Mdot
.38613 .66969 Mdot
.51552 .3608 Mdot
.55312 .38335 Mdot
.62244 .61308 Mdot
.57752 .31441 Mdot
.54903 .40659 Mdot
.35571 .39105 Mdot
.35773 .39794 Mdot
.32567 .43152 Mdot
.54528 .67318 Mdot
.49792 .50423 Mdot
.37159 .67985 Mdot
.59757 .31223 Mdot
.36381 .69455 Mdot
.60007 .46882 Mdot
.70202 .58485 Mdot
.27688 .48536 Mdot
.55347 .35442 Mdot
.35146 .45347 Mdot
.45146 .1674 Mdot
.32096 .39993 Mdot
.35673 .62239 Mdot
.38829 .67726 Mdot
.35953 .42909 Mdot
.52847 .37175 Mdot
.53495 .50723 Mdot
.20515 .37902 Mdot
.36077 .66446 Mdot
.52838 .33094 Mdot
.61688 .69463 Mdot
.55808 .73701 Mdot
.29619 .24717 Mdot
.36064 .68135 Mdot
.3099 .71412 Mdot
.59324 .41623 Mdot
.37394 .40501 Mdot
.40144 .68257 Mdot
.38455 .63612 Mdot
.56934 .72959 Mdot
.60236 .39904 Mdot
.55531 .3841 Mdot
.39866 .56249 Mdot
.38654 .6927 Mdot
.64056 .41356 Mdot
.60702 .38945 Mdot
.36027 .53424 Mdot
.40088 .42961 Mdot
.73488 .74709 Mdot
.45108 .39759 Mdot
.52167 .23737 Mdot
.56645 .77934 Mdot
.33028 .41139 Mdot
.57499 .39895 Mdot
.58202 .31244 Mdot
.60018 .67771 Mdot
.53879 .3604 Mdot
.53676 .70125 Mdot
.3676 .68947 Mdot
.2508 .45846 Mdot
.47112 .56656 Mdot
.43598 .65601 Mdot
.54011 .36931 Mdot
.3434 .32103 Mdot
.70665 .57586 Mdot
.40117 .62448 Mdot
.32316 .41262 Mdot
.61423 .41449 Mdot
.60708 .70142 Mdot
.5433 .67823 Mdot
.34323 .42721 Mdot
.32236 .62649 Mdot
.2814 .48201 Mdot
.5516 .34095 Mdot
.54943 .69053 Mdot
.43529 .50377 Mdot
.29167 .31012 Mdot
.40801 .68779 Mdot
.71785 .58523 Mdot
.59144 .68782 Mdot
.35146 .69021 Mdot
.61308 .35054 Mdot
.35248 .42435 Mdot
.34468 .45923 Mdot
.53007 .61344 Mdot
.58338 .71756 Mdot
.72386 .56577 Mdot
.51897 .60866 Mdot
.51922 .58617 Mdot
.7217 .57957 Mdot
.5336 .69397 Mdot
.33695 .40187 Mdot
.33947 .44314 Mdot
.34003 .41619 Mdot
.42678 .35835 Mdot
.38605 .40668 Mdot
.78481 .49463 Mdot
.6173 .40291 Mdot
.30348 .31954 Mdot
.60717 .41735 Mdot
.3555 .66795 Mdot
.36578 .43665 Mdot
.63705 .48786 Mdot
.55871 .43322 Mdot
.21221 .37607 Mdot
.55005 .39673 Mdot
.48192 .61861 Mdot
.56635 .37346 Mdot
.38916 .31215 Mdot
.36274 .38544 Mdot
.57229 .34971 Mdot
.38433 .62053 Mdot
.71061 .55639 Mdot
.40713 .43814 Mdot
.55334 .4057 Mdot
.2936 .60346 Mdot
.53402 .41259 Mdot
.26087 .44845 Mdot
.56099 .62281 Mdot
.73227 .54311 Mdot
.51162 .4114 Mdot
.60344 .71789 Mdot
.59181 .28733 Mdot
.31189 .31659 Mdot
.36022 .66666 Mdot
.33427 .32213 Mdot
.55678 .72461 Mdot
.47957 .32369 Mdot
.59082 .43258 Mdot
.72687 .58467 Mdot
.28816 .40772 Mdot
.36994 .65546 Mdot
.55728 .35637 Mdot
.57833 .39108 Mdot
.45021 .65961 Mdot
.32538 .30595 Mdot
.65516 .36775 Mdot
.68964 .56127 Mdot
.34959 .31119 Mdot
.54187 .40369 Mdot
.60556 .73408 Mdot
.38178 .4102 Mdot
.48693 .32129 Mdot
.46831 .32861 Mdot
.6116 .38627 Mdot
.35514 .42983 Mdot
.38147 .42614 Mdot
.49217 .15995 Mdot
.71416 .58814 Mdot
.54022 .39618 Mdot
.53105 .61894 Mdot
.558 .41093 Mdot
.36671 .67593 Mdot
.58484 .43055 Mdot
.59771 .71399 Mdot
.45797 .46966 Mdot
.54387 .67524 Mdot
.58001 .36614 Mdot
.3639 .41618 Mdot
.37808 .64829 Mdot
.38882 .77191 Mdot
.36576 .7258 Mdot
.78384 .49504 Mdot
.75361 .60555 Mdot
.73052 .55368 Mdot
.71515 .5941 Mdot
.4159 .68236 Mdot
.52712 .3689 Mdot
.57674 .52148 Mdot
.61051 .33524 Mdot
.57127 .37383 Mdot
.53491 .39542 Mdot
.33723 .71745 Mdot
.38819 .67563 Mdot
.58979 .70254 Mdot
.56006 .36027 Mdot
.61308 .40237 Mdot
.36385 .42205 Mdot
.73335 .55811 Mdot
.58051 .66577 Mdot
.73049 .54857 Mdot
.57465 .69363 Mdot
.37523 .18106 Mdot
.49381 .35918 Mdot
.7087 .55899 Mdot
.38184 .70429 Mdot
.33657 .44483 Mdot
.39716 .56847 Mdot
.55529 .7051 Mdot
.55886 .72197 Mdot
.59635 .35997 Mdot
.374 .41724 Mdot
.37903 .42761 Mdot
.7401 .56141 Mdot
.40022 .67355 Mdot
.59418 .34942 Mdot
.59918 .37239 Mdot
.40739 .77666 Mdot
.59199 .67045 Mdot
.33525 .31495 Mdot
.33502 .48958 Mdot
.5318 .36014 Mdot
.3789 .44276 Mdot
.54846 .37688 Mdot
.43987 .52442 Mdot
.32327 .42898 Mdot
.57107 .4306 Mdot
.62936 .36143 Mdot
.6009 .68493 Mdot
.56533 .17625 Mdot
.55268 .33303 Mdot
.35055 .64863 Mdot
.59276 .39526 Mdot
.67907 .20143 Mdot
.46925 .16642 Mdot
.52253 .40377 Mdot
.52931 .35227 Mdot
.16034 .47469 Mdot
.53011 .41849 Mdot
.40042 .55656 Mdot
.61974 .32609 Mdot
.37792 .44713 Mdot
.50083 .61535 Mdot
.56923 .51722 Mdot
.71879 .59083 Mdot
.56377 .69351 Mdot
.71967 .46766 Mdot
.74161 .58938 Mdot
.34006 .439 Mdot
.48961 .37085 Mdot
.33332 .48803 Mdot
.53155 .71332 Mdot
.60459 .43933 Mdot
.36609 .67288 Mdot
.56738 .51843 Mdot
.58927 .73046 Mdot
.38364 .6807 Mdot
.5507 .42622 Mdot
.6287 .75234 Mdot
.38803 .61701 Mdot
.50598 .15508 Mdot
.39793 .65001 Mdot
.38825 .66247 Mdot
.51377 .50302 Mdot
.71964 .59098 Mdot
.46685 .66466 Mdot
.47888 .36932 Mdot
.36705 .65248 Mdot
.72345 .33298 Mdot
.59428 .66871 Mdot
.50261 .52285 Mdot
.35568 .3855 Mdot
.50899 .34247 Mdot
.53265 .38543 Mdot
.39877 .65854 Mdot
.35044 .36968 Mdot
.62675 .60468 Mdot
.36397 .68485 Mdot
.52642 .43144 Mdot
.48669 .51616 Mdot
.3921 .53412 Mdot
.39182 .56369 Mdot
.69384 .58253 Mdot
.6933 .68335 Mdot
.36817 .44812 Mdot
.69353 .56173 Mdot
.6309 .47448 Mdot
.55661 .39787 Mdot
.38018 .69468 Mdot
.38875 .56626 Mdot
.38111 .67881 Mdot
.71159 .57102 Mdot
.6966 .57969 Mdot
.35377 .43593 Mdot
.32645 .4127 Mdot
.26611 .40059 Mdot
.69053 .33812 Mdot
.57438 .41372 Mdot
.48422 .21618 Mdot
.32048 .41602 Mdot
.45699 .32753 Mdot
.73905 .58383 Mdot
.73847 .57006 Mdot
.36312 .2543 Mdot
.58602 .41529 Mdot
.47823 .62756 Mdot
.53778 .40384 Mdot
.75286 .3858 Mdot
.54339 .41202 Mdot
.57327 .72936 Mdot
.58395 .38774 Mdot
.23224 .60609 Mdot
.61168 .40065 Mdot
.5319 .3948 Mdot
.56406 .7099 Mdot
.57752 .34199 Mdot
.59323 .72048 Mdot
.57136 .39994 Mdot
.68004 .58455 Mdot
.56585 .69306 Mdot
.67503 .56395 Mdot
.49418 .58419 Mdot
.3944 .55459 Mdot
.71849 .59306 Mdot
.72749 .55012 Mdot
.68904 .48727 Mdot
.33135 .4004 Mdot
.46551 .35829 Mdot
.52772 .38224 Mdot
.56251 .65569 Mdot
.38845 .69813 Mdot
.61101 .38392 Mdot
.51058 .40118 Mdot
.58146 .34209 Mdot
.35605 .43349 Mdot
.53541 .67877 Mdot
.71059 .5638 Mdot
.55788 .67248 Mdot
.67743 .57795 Mdot
.60195 .70681 Mdot
.57172 .32739 Mdot
.60855 .34785 Mdot
.50015 .4099 Mdot
.49642 .24729 Mdot
.83077 .44655 Mdot
.34777 .4253 Mdot
.39253 .54 Mdot
.70079 .58442 Mdot
.5228 .57198 Mdot
.36467 .45201 Mdot
.56183 .72296 Mdot
.55674 .38827 Mdot
.48209 .37946 Mdot
.51318 .33342 Mdot
.32853 .4744 Mdot
.68802 .54091 Mdot
.55759 .69998 Mdot
.40196 .53772 Mdot
.49454 .50695 Mdot
.42219 .42034 Mdot
.65299 .47158 Mdot
.55082 .38014 Mdot
.74092 .56132 Mdot
.37098 .40665 Mdot
.46658 .65039 Mdot
.39743 .65974 Mdot
.54601 .51197 Mdot
.5383 .37032 Mdot
.324 .6514 Mdot
.36259 .41546 Mdot
.73325 .57789 Mdot
.39822 .65725 Mdot
.72359 .58888 Mdot
.38318 .54188 Mdot
.41372 .56175 Mdot
.59442 .37378 Mdot
.53751 .40498 Mdot
.3771 .69798 Mdot
.37179 .44491 Mdot
.69003 .59501 Mdot
.45013 .67152 Mdot
.55254 .70252 Mdot
.49639 .53956 Mdot
.36511 .40079 Mdot
.32842 .72057 Mdot
.54927 .67645 Mdot
.35834 .69682 Mdot
.58094 .51652 Mdot
.40621 .68047 Mdot
.53913 .40096 Mdot
.3549 .40635 Mdot
.35879 .6721 Mdot
.42244 .76518 Mdot
.25269 .36778 Mdot
.28818 .44486 Mdot
.57559 .35813 Mdot
.26732 .47828 Mdot
.29805 .6483 Mdot
.35957 .36607 Mdot
.36365 .69243 Mdot
.54961 .36722 Mdot
.55432 .34092 Mdot
.58127 .38927 Mdot
.39274 .66102 Mdot
.34893 .74559 Mdot
.54541 .70268 Mdot
.56453 .38909 Mdot
.71192 .54902 Mdot
.59683 .7107 Mdot
.57501 .7418 Mdot
.59016 .6854 Mdot
.32053 .41146 Mdot
.48771 .37041 Mdot
.59719 .30702 Mdot
.53598 .17401 Mdot
.3874 .66555 Mdot
.39472 .55427 Mdot
.554 .34513 Mdot
.77493 .49783 Mdot
.33649 .44266 Mdot
.55997 .71238 Mdot
.53772 .38036 Mdot
.54592 .61927 Mdot
.37886 .54037 Mdot
.57018 .70566 Mdot
.32308 .41805 Mdot
.37987 .3713 Mdot
.54109 .35854 Mdot
.59132 .40011 Mdot
.35132 .44684 Mdot
.29178 .68159 Mdot
.48977 .50659 Mdot
.55108 .37517 Mdot
.38648 .67413 Mdot
.52128 .8675 Mdot
.57521 .42754 Mdot
.2972 .41956 Mdot
.39725 .53023 Mdot
.38212 .50773 Mdot
.31417 .33415 Mdot
.61079 .32669 Mdot
.23097 .45227 Mdot
.78533 .52561 Mdot
.23873 .40836 Mdot
.76358 .4053 Mdot
.44263 .68666 Mdot
.43496 .15214 Mdot
.36001 .64178 Mdot
.3872 .29576 Mdot
.21047 .66338 Mdot
.30567 .69361 Mdot
.61666 .62651 Mdot
.43693 .73474 Mdot
.62749 .74695 Mdot
.73015 .28203 Mdot
.59841 .7263 Mdot
.77172 .39099 Mdot
.53279 .40528 Mdot
.28846 .66634 Mdot
.37867 .31335 Mdot
.8317 .50245 Mdot
.2936 .49613 Mdot
.5348 .61706 Mdot
.19697 .36559 Mdot
.32276 .51454 Mdot
.30446 .26538 Mdot
.55451 .26024 Mdot
.72071 .6965 Mdot
.52282 .57852 Mdot
.73512 .47536 Mdot
.3432 .32885 Mdot
.21829 .56754 Mdot
.40955 .61544 Mdot
.44517 .19828 Mdot
.63035 .79184 Mdot
.55849 .68244 Mdot
.38381 .41296 Mdot
.4697 .68005 Mdot
.28375 .29637 Mdot
.35133 .63372 Mdot
.23058 .45146 Mdot
.36116 .51113 Mdot
.3877 .30835 Mdot
.62213 .48538 Mdot
.39445 .26446 Mdot
.77936 .54313 Mdot
.73223 .29942 Mdot
.33529 .47045 Mdot
.4499 .74583 Mdot
.52923 .57059 Mdot
.68386 .511 Mdot
.40349 .32881 Mdot
.68786 .57692 Mdot
.68861 .5852 Mdot
.32326 .42396 Mdot
.29248 .3021 Mdot
.37815 .55856 Mdot
.63229 .47133 Mdot
.60745 .71143 Mdot
.44554 .53117 Mdot
.2693 .66773 Mdot
.30499 .63454 Mdot
.61275 .19916 Mdot
.22185 .32037 Mdot
.71628 .38157 Mdot
.46723 .63748 Mdot
.33409 .66938 Mdot
.75361 .49467 Mdot
.65185 .33274 Mdot
.71015 .34455 Mdot
.60083 .26424 Mdot
.17512 .41642 Mdot
.31589 .59101 Mdot
.19151 .35948 Mdot
.34214 .46811 Mdot
.48492 .41796 Mdot
.44827 .59906 Mdot
.57195 .22416 Mdot
.68919 .44729 Mdot
.22015 .33641 Mdot
.74908 .55546 Mdot
.38294 .39076 Mdot
.3069 .6943 Mdot
.3897 .34394 Mdot
.72101 .51548 Mdot
.74761 .6158 Mdot
.48183 .32927 Mdot
.1663 .40104 Mdot
.23049 .4597 Mdot
.41518 .18129 Mdot
.36144 .54505 Mdot
.52161 .70169 Mdot
.5808 .74216 Mdot
.38633 .63488 Mdot
.27791 .28553 Mdot
.35283 .41068 Mdot
.55292 .16863 Mdot
.25735 .39927 Mdot
.59962 .28651 Mdot
.15711 .41491 Mdot
.69905 .26375 Mdot
.30125 .32726 Mdot
.81012 .46513 Mdot
.46605 .84474 Mdot
.66423 .36723 Mdot
.36819 .72958 Mdot
.61436 .71847 Mdot
.27325 .45051 Mdot
.27031 .29264 Mdot
.71495 .31975 Mdot
.16528 .55825 Mdot
.63308 .46886 Mdot
.59176 .768 Mdot
.34663 .4808 Mdot
.63438 .6401 Mdot
.66247 .52256 Mdot
.19473 .35464 Mdot
.36047 .31067 Mdot
.50973 .86074 Mdot
.75155 .41395 Mdot
.46143 .33319 Mdot
.25545 .49165 Mdot
.60948 .6588 Mdot
.65456 .30392 Mdot
.30462 .60591 Mdot
.50882 .35161 Mdot
.66992 .46786 Mdot
.52265 .28241 Mdot
.76271 .54362 Mdot
.49043 .49982 Mdot
.3142 .56885 Mdot
.72487 .4197 Mdot
.33501 .74995 Mdot
.46131 .35796 Mdot
.31724 .42909 Mdot
.70955 .35584 Mdot
.73821 .39234 Mdot
.35513 .56749 Mdot
.66262 .60732 Mdot
.40423 .18314 Mdot
.64649 .60797 Mdot
.61652 .33029 Mdot
.3871 .29004 Mdot
.347 .33038 Mdot
.73222 .3525 Mdot
.55908 .32596 Mdot
.58382 .19223 Mdot
.36692 .52664 Mdot
.47361 .25151 Mdot
.70474 .43008 Mdot
.48919 .24872 Mdot
.26214 .33737 Mdot
.44159 .59045 Mdot
.35936 .73371 Mdot
.31924 .37381 Mdot
.16838 .39997 Mdot
.59384 .70575 Mdot
.71107 .32812 Mdot
.36202 .63778 Mdot
.41045 .77017 Mdot
.44734 .69353 Mdot
.63074 .60433 Mdot
.29506 .26127 Mdot
.31223 .64601 Mdot
.57964 .64345 Mdot
.20487 .5489 Mdot
.43054 .49523 Mdot
.47762 .21991 Mdot
.50697 .44209 Mdot
.60572 .27213 Mdot
.69678 .56829 Mdot
.48635 .28221 Mdot
.4231 .58418 Mdot
.78161 .60379 Mdot
.60163 .3239 Mdot
.53267 .5929 Mdot
.40563 .54769 Mdot
.54821 .5241 Mdot
.3728 .18107 Mdot
.50906 .44521 Mdot
.69751 .26671 Mdot
.30571 .65714 Mdot
.5676 .52502 Mdot
.67283 .51825 Mdot
.43422 .43007 Mdot
.18511 .36638 Mdot
.32544 .22232 Mdot
.27944 .6302 Mdot
.25972 .47351 Mdot
.8049 .32318 Mdot
.38094 .74969 Mdot
.62125 .21951 Mdot
.36622 .63327 Mdot
.83901 .68787 Mdot
.55464 .6723 Mdot
.80085 .40722 Mdot
.56438 .22712 Mdot
.58554 .60916 Mdot
.28181 .30071 Mdot
.36095 .33858 Mdot
.66795 .58508 Mdot
.31574 .43923 Mdot
.58024 .32287 Mdot
.23156 .33091 Mdot
.17429 .39613 Mdot
.2279 .336 Mdot
.34417 .62313 Mdot
.2354 .36014 Mdot
.1564 .45787 Mdot
.78673 .49467 Mdot
.44636 .64011 Mdot
.59965 .43013 Mdot
.68604 .30707 Mdot
.67879 .25403 Mdot
.74515 .54522 Mdot
.66288 .37762 Mdot
.33708 .47181 Mdot
.15206 .44925 Mdot
.37584 .17786 Mdot
.39971 .24248 Mdot
.31598 .25711 Mdot
.49188 .66634 Mdot
.69522 .32762 Mdot
.31281 .24757 Mdot
.21759 .53716 Mdot
.3533 .52183 Mdot
.15085 .4817 Mdot
.73844 .40316 Mdot
.43516 .73863 Mdot
.26642 .61061 Mdot
.65684 .23782 Mdot
.25049 .48582 Mdot
.46696 .68659 Mdot
.64056 .30023 Mdot
.38535 .47117 Mdot
.63258 .60696 Mdot
.21338 .55927 Mdot
.47293 .62977 Mdot
.70075 .41172 Mdot
.55765 .73167 Mdot
.70658 .31742 Mdot
.63242 .53352 Mdot
.44815 .64297 Mdot
.70568 .47281 Mdot
.72106 .31791 Mdot
.28026 .58635 Mdot
.23126 .34957 Mdot
.3068 .65684 Mdot
.45796 .8482 Mdot
.28971 .52022 Mdot
.53218 .27893 Mdot
.5767 .34137 Mdot
.27526 .29985 Mdot
.30254 .21919 Mdot
.29959 .25401 Mdot
.3481 .60982 Mdot
.51843 .65055 Mdot
.35762 .70306 Mdot
.7391 .48899 Mdot
.5979 .60419 Mdot
.32129 .49423 Mdot
.5875 .54536 Mdot
.36181 .64425 Mdot
.27554 .68618 Mdot
.2666 .40696 Mdot
.77212 .49932 Mdot
.42859 .20702 Mdot
.65014 .39853 Mdot
.29553 .30889 Mdot
.33187 .45343 Mdot
.3308 .63067 Mdot
.71007 .33984 Mdot
.59423 .6996 Mdot
.41745 .77535 Mdot
.33135 .37302 Mdot
.48202 .41814 Mdot
.48784 .6737 Mdot
.29425 .4577 Mdot
.51851 .23551 Mdot
.56355 .64383 Mdot
.40467 .1646 Mdot
.60449 .2018 Mdot
.31441 .24521 Mdot
.71512 .36706 Mdot
.43448 .76547 Mdot
.52644 .52168 Mdot
.33908 .69333 Mdot
.30592 .50481 Mdot
.52094 .55225 Mdot
.71792 .35912 Mdot
.29164 .32706 Mdot
.42047 .60899 Mdot
.60581 .31893 Mdot
.4419 .16848 Mdot
.76536 .48126 Mdot
.52988 .5305 Mdot
.40725 .46863 Mdot
.39208 .42065 Mdot
.83602 .43592 Mdot
.22859 .58536 Mdot
.59324 .29672 Mdot
.26049 .48238 Mdot
.4128 .68081 Mdot
.32352 .43501 Mdot
.72116 .31141 Mdot
.67685 .64381 Mdot
.27049 .38389 Mdot
.46077 .59499 Mdot
.29023 .28596 Mdot
.48676 .57347 Mdot
.25293 .469 Mdot
.21151 .43115 Mdot
.53843 .85496 Mdot
.34177 .46709 Mdot
.46082 .63663 Mdot
.47579 .66239 Mdot
.36006 .47398 Mdot
.31919 .46662 Mdot
.35423 .31628 Mdot
.25391 .29451 Mdot
.51104 .60298 Mdot
.21019 .52932 Mdot
.57396 .52245 Mdot
.63108 .62961 Mdot
.44007 .62068 Mdot
.71281 .46885 Mdot
.21315 .47952 Mdot
.36828 .22735 Mdot
.34344 .79614 Mdot
.65107 .41223 Mdot
.79574 .39718 Mdot
.74022 .49002 Mdot
.55609 .26181 Mdot
.40294 .32529 Mdot
.34413 .52657 Mdot
.57335 .40725 Mdot
.23052 .3055 Mdot
.31995 .5832 Mdot
.66374 .49864 Mdot
.62828 .68769 Mdot
.5681 .42526 Mdot
.50026 .40648 Mdot
.30743 .25255 Mdot
.38176 .50062 Mdot
.27478 .74859 Mdot
.75528 .40347 Mdot
.56939 .27474 Mdot
.2956 .33259 Mdot
.69469 .26612 Mdot
.44629 .57817 Mdot
.24789 .41264 Mdot
.63152 .54007 Mdot
.67679 .24769 Mdot
.1987 .50265 Mdot
.21679 .58497 Mdot
.28257 .51122 Mdot
.1609 .44753 Mdot
.54016 .28824 Mdot
.37311 .56625 Mdot
.47594 .68536 Mdot
.54473 .34723 Mdot
.32277 .62508 Mdot
.27734 .49587 Mdot
.65402 .6952 Mdot
.65095 .32594 Mdot
.29655 .2226 Mdot
.64139 .37061 Mdot
.3444 .59939 Mdot
.25786 .71881 Mdot
.33054 .81101 Mdot
.22661 .60131 Mdot
.19712 .35072 Mdot
.2084 .5708 Mdot
.24845 .47428 Mdot
.41091 .68877 Mdot
.51002 .57144 Mdot
.50892 .21989 Mdot
.25958 .28299 Mdot
.70667 .66752 Mdot
.39592 .73276 Mdot
.48777 .19453 Mdot
.25577 .28412 Mdot
.63369 .3565 Mdot
.82259 .41348 Mdot
.52052 .68516 Mdot
.71768 .25819 Mdot
.62654 .20999 Mdot
.40914 .45866 Mdot
.72946 .3353 Mdot
.80438 .38681 Mdot
.81974 .50529 Mdot
.61492 .21185 Mdot
.64022 .27144 Mdot
.39636 .48892 Mdot
.70984 .37142 Mdot
.27504 .46311 Mdot
.7606 .30063 Mdot
.44317 .61834 Mdot
.37589 .53691 Mdot
.41383 .55395 Mdot
.27301 .4481 Mdot
.27876 .56936 Mdot
.46103 .61598 Mdot
.45315 .47757 Mdot
.27449 .32649 Mdot
.55151 .8756 Mdot
.19522 .57059 Mdot
.28656 .39303 Mdot
.1823 .38948 Mdot
.35376 .53569 Mdot
.5333 .56155 Mdot
.41023 .33549 Mdot
.7533 .48482 Mdot
.56139 .63953 Mdot
.53209 .39966 Mdot
.24966 .29769 Mdot
.56696 .64105 Mdot
.20438 .36359 Mdot
.51448 .15493 Mdot
.32938 .25465 Mdot
.54031 .45461 Mdot
.61467 .7235 Mdot
.69319 .28457 Mdot
.69386 .29093 Mdot
.18696 .41001 Mdot
.78611 .3814 Mdot
.50855 .54446 Mdot
.47987 .59482 Mdot
.46874 .57269 Mdot
.56493 .29196 Mdot
.68911 .25662 Mdot
.42456 .45444 Mdot
.7089 .43941 Mdot
.26862 .62388 Mdot
.71939 .337 Mdot
.31805 .3298 Mdot
.72746 .48259 Mdot
.6443 .59 Mdot
.67051 .58568 Mdot
.58712 .66532 Mdot
.1553 .52675 Mdot
.32383 .53234 Mdot
.57241 .18741 Mdot
.46231 .84742 Mdot
.30798 .6063 Mdot
.77162 .38298 Mdot
.40356 .59513 Mdot
.66809 .36076 Mdot
.71564 .68785 Mdot
.72892 .43405 Mdot
.33988 .31758 Mdot
.27832 .4748 Mdot
.43742 .39394 Mdot
.28137 .27118 Mdot
.70074 .41943 Mdot
.18115 .62344 Mdot
.50363 .7048 Mdot
.48715 .27676 Mdot
.32076 .29644 Mdot
.42322 .83662 Mdot
.53519 .53054 Mdot
.16693 .40277 Mdot
.32122 .39751 Mdot
.21996 .32392 Mdot
.4022 .65442 Mdot
.64683 .75091 Mdot
.34364 .51123 Mdot
.65847 .5041 Mdot
.64072 .50807 Mdot
.47365 .16022 Mdot
.30557 .67458 Mdot
.30176 .63906 Mdot
.64685 .61197 Mdot
.58327 .73614 Mdot
.47967 .53282 Mdot
.21378 .5239 Mdot
.15868 .53287 Mdot
.60315 .35593 Mdot
.541 .75049 Mdot
.7082 .29284 Mdot
.33918 .69622 Mdot
.36908 .51557 Mdot
.31255 .49853 Mdot
.31077 .35769 Mdot
.69337 .32818 Mdot
.15937 .44235 Mdot
.33262 .49642 Mdot
.60176 .58907 Mdot
.48292 .31522 Mdot
.41874 .61749 Mdot
.35029 .76709 Mdot
.22282 .46849 Mdot
.47429 .58128 Mdot
.49365 .51045 Mdot
.71873 .38293 Mdot
.34742 .17421 Mdot
.17504 .40698 Mdot
.39644 .8093 Mdot
.56769 .52746 Mdot
.30923 .40163 Mdot
.73199 .45911 Mdot
.17718 .61749 Mdot
.72005 .25602 Mdot
.27658 .60794 Mdot
.71769 .33227 Mdot
.64409 .68203 Mdot
.80913 .40603 Mdot
.52553 .54403 Mdot
.32246 .29504 Mdot
.54672 .21517 Mdot
.41415 .56809 Mdot
.59343 .64671 Mdot
.60108 .51761 Mdot
.44588 .66786 Mdot
.39878 .48662 Mdot
.3066 .6756 Mdot
.18185 .6247 Mdot
.78136 .36784 Mdot
.47467 .32911 Mdot
.19351 .63384 Mdot
.40422 .42914 Mdot
.47555 .66497 Mdot
.37666 .7832 Mdot
.57947 .52673 Mdot
.56984 .67152 Mdot
.64869 .33706 Mdot
.48425 .51874 Mdot
.2 .54755 Mdot
.63702 .73026 Mdot
.75155 .58351 Mdot
.30863 .44941 Mdot
.79633 .3814 Mdot
.36893 .46273 Mdot
.37837 .16347 Mdot
.21926 .53448 Mdot
.29545 .31952 Mdot
.18961 .50941 Mdot
.46383 .73302 Mdot
.46714 .85272 Mdot
.30677 .26368 Mdot
.69007 .40781 Mdot
.31343 .45315 Mdot
.34705 .46357 Mdot
.2013 .48967 Mdot
.32997 .65325 Mdot
.29809 .28505 Mdot
.70275 .27114 Mdot
.43792 .76721 Mdot
.38768 .44162 Mdot
.48263 .60137 Mdot
.29432 .3872 Mdot
.38712 .16969 Mdot
.56315 .67281 Mdot
.16936 .39062 Mdot
.44902 .39611 Mdot
.33448 .76909 Mdot
.29298 .47146 Mdot
.46176 .4693 Mdot
.53854 .53658 Mdot
.43163 .75756 Mdot
.61371 .3245 Mdot
.56953 .27574 Mdot
.32558 .40924 Mdot
.44385 .69502 Mdot
.73311 .55984 Mdot
.70351 .62304 Mdot
.34259 .66673 Mdot
.53717 .25623 Mdot
.67435 .23834 Mdot
.33839 .4583 Mdot
.49813 .69334 Mdot
.4954 .71673 Mdot
.62811 .36194 Mdot
.66932 .27996 Mdot
.15747 .49571 Mdot
.30623 .26829 Mdot
.31797 .40074 Mdot
.40345 .81903 Mdot
.77277 .57817 Mdot
.41752 .16305 Mdot
.3537 .36106 Mdot
.70222 .28815 Mdot
.51946 .27757 Mdot
.33045 .22614 Mdot
.31479 .33404 Mdot
.25574 .43214 Mdot
.71141 .35324 Mdot
.62611 .6081 Mdot
.7185 .31563 Mdot
.30964 .35737 Mdot
.4778 .56042 Mdot
.71902 .26396 Mdot
.64227 .68819 Mdot
.39276 .26965 Mdot
.62761 .31345 Mdot
.29086 .46623 Mdot
.68853 .26395 Mdot
.30434 .4435 Mdot
.70838 .60073 Mdot
.45494 .20278 Mdot
.34706 .5166 Mdot
.27525 .28999 Mdot
.35439 .56929 Mdot
.71044 .28975 Mdot
.4682 .56649 Mdot
.77175 .45767 Mdot
.4478 .40017 Mdot
.66529 .45357 Mdot
.50303 .38716 Mdot
.51474 .29009 Mdot
.60241 .54819 Mdot
.48686 .16669 Mdot
.56845 .28364 Mdot
.24902 .31323 Mdot
.39766 .17356 Mdot
.23381 .40536 Mdot
.47877 .6449 Mdot
.38462 .43242 Mdot
.18043 .37885 Mdot
.67453 .27568 Mdot
.28343 .47022 Mdot
.63247 .21412 Mdot
.83581 .42999 Mdot
.20218 .65343 Mdot
.33152 .56122 Mdot
.29787 .46398 Mdot
.56327 .17563 Mdot
.32039 .58974 Mdot
.8136 .39751 Mdot
.34477 .3162 Mdot
.3599 .49721 Mdot
.15369 .4222 Mdot
.59063 .23226 Mdot
.30154 .6316 Mdot
.31784 .30431 Mdot
.28911 .36944 Mdot
.66656 .26598 Mdot
.60135 .31148 Mdot
.60301 .71496 Mdot
.57127 .61522 Mdot
.73199 .34307 Mdot
.31892 .36186 Mdot
.69933 .2751 Mdot
.70235 .29386 Mdot
.77721 .39752 Mdot
.43617 .75922 Mdot
.20293 .65382 Mdot
.28692 .34416 Mdot
.48874 .39619 Mdot
.30157 .4406 Mdot
.72851 .59509 Mdot
.75316 .4217 Mdot
.61011 .39872 Mdot
.59236 .50349 Mdot
.50182 .30994 Mdot
.24311 .29499 Mdot
.6422 .62776 Mdot
.41843 .62683 Mdot
.38685 .43071 Mdot
.27662 .45383 Mdot
.43989 .55732 Mdot
.30538 .69553 Mdot
.69316 .2753 Mdot
.26645 .38625 Mdot
.23648 .44783 Mdot
.30367 .62329 Mdot
.71631 .40307 Mdot
.78485 .55361 Mdot
.35667 .67589 Mdot
.51888 .23041 Mdot
.18743 .42652 Mdot
.32121 .61203 Mdot
.38487 .39452 Mdot
.25973 .59252 Mdot
.48093 .56247 Mdot
.37493 .58539 Mdot
.30512 .66877 Mdot
.42341 .59684 Mdot
.35108 .25042 Mdot
.21417 .44491 Mdot
.61558 .68997 Mdot
.74578 .39535 Mdot
.23379 .57934 Mdot
.69595 .27309 Mdot
.63126 .36717 Mdot
.25905 .31191 Mdot
.65771 .50096 Mdot
.77262 .56562 Mdot
.59868 .38918 Mdot
.59797 .25245 Mdot
.30674 .25234 Mdot
.25743 .60943 Mdot
.64836 .30578 Mdot
.36278 .37999 Mdot
.60431 .19947 Mdot
.54654 .64091 Mdot
.55064 .64252 Mdot
.81169 .4438 Mdot
.4519 .44439 Mdot
.59409 .60225 Mdot
.35185 .73966 Mdot
.6246 .34015 Mdot
.78826 .56245 Mdot
.46644 .59217 Mdot
.51217 .22986 Mdot
.62121 .22235 Mdot
.15708 .51205 Mdot
.45613 .58827 Mdot
.61334 .19785 Mdot
.5347 .21419 Mdot
.36083 .49478 Mdot
.78768 .37093 Mdot
.66169 .37743 Mdot
.56372 .32523 Mdot
.70908 .60083 Mdot
.39829 .41541 Mdot
.16257 .49073 Mdot
.62499 .28755 Mdot
.72602 .52433 Mdot
.65156 .54813 Mdot
.45205 .60502 Mdot
.58617 .78548 Mdot
.36803 .52863 Mdot
.56527 .17549 Mdot
.71031 .34085 Mdot
.36118 .71907 Mdot
.20303 .54779 Mdot
.66038 .33493 Mdot
.25332 .31424 Mdot
.61056 .56062 Mdot
.29461 .27309 Mdot
.36299 .60715 Mdot
.51425 .24384 Mdot
.42163 .17077 Mdot
.68029 .45957 Mdot
.6589 .45883 Mdot
.42644 .44012 Mdot
.66043 .42205 Mdot
.39622 .56936 Mdot
.66333 .62764 Mdot
.75243 .30436 Mdot
.16678 .57753 Mdot
.32033 .74383 Mdot
.63959 .34523 Mdot
.73043 .45384 Mdot
.20932 .45966 Mdot
.53089 .56499 Mdot
.64969 .53334 Mdot
.47748 .6928 Mdot
.58221 .64216 Mdot
.52763 .86791 Mdot
.23562 .30202 Mdot
.59818 .39191 Mdot
.62959 .52111 Mdot
.75936 .61279 Mdot
.53568 .69567 Mdot
.41542 .20961 Mdot
.16063 .48493 Mdot
.36012 .66232 Mdot
.43968 .81989 Mdot
.3577 .73886 Mdot
.48043 .1618 Mdot
.39885 .79514 Mdot
.40061 .62153 Mdot
.3768 .16352 Mdot
.28158 .62497 Mdot
.42766 .40348 Mdot
.53621 .8685 Mdot
.45821 .16625 Mdot
.52484 .27817 Mdot
.52865 .64291 Mdot
.23985 .31054 Mdot
.53593 .53633 Mdot
.51931 .64299 Mdot
.59719 .22845 Mdot
.71282 .34607 Mdot
.75187 .40127 Mdot
.41311 .70349 Mdot
.51687 .20201 Mdot
.85302 .49464 Mdot
.46654 .73296 Mdot
.41497 .84831 Mdot
.31407 .26553 Mdot
.21024 .406 Mdot
.22453 .59541 Mdot
.65697 .68662 Mdot
.26952 .30613 Mdot
.70153 .30403 Mdot
.59482 .24484 Mdot
.68837 .66381 Mdot
.67972 .46831 Mdot
.74612 .47496 Mdot
.37817 .58876 Mdot
.32551 .24365 Mdot
.44338 .75326 Mdot
.66811 .32604 Mdot
.71215 .31642 Mdot
.54835 .22233 Mdot
.661 .45478 Mdot
.19583 .41212 Mdot
.66465 .26961 Mdot
.72205 .37036 Mdot
.44716 .71809 Mdot
.68636 .58346 Mdot
.16911 .4719 Mdot
.42783 .51058 Mdot
.51302 .28511 Mdot
.26133 .725 Mdot
.19474 .3563 Mdot
.66192 .37844 Mdot
.58081 .43111 Mdot
.43967 .15032 Mdot
.50762 .69762 Mdot
.61612 .21948 Mdot
.26439 .65257 Mdot
.75892 .39844 Mdot
.53526 .29487 Mdot
.54188 .4134 Mdot
.79366 .47036 Mdot
.36394 .48406 Mdot
.55042 .21891 Mdot
.40341 .78652 Mdot
.7184 .3657 Mdot
.54149 .25942 Mdot
.34206 .79459 Mdot
.3408 .35681 Mdot
.37079 .45567 Mdot
.24068 .3053 Mdot
.43583 .18901 Mdot
.55018 .27161 Mdot
.30734 .29817 Mdot
.6059 .57143 Mdot
.78721 .56558 Mdot
.46629 .35898 Mdot
.52905 .52257 Mdot
.73307 .34006 Mdot
.19268 .63586 Mdot
.49937 .22097 Mdot
.16366 .40038 Mdot
.31965 .229 Mdot
.38115 .45105 Mdot
.5788 .2307 Mdot
.57625 .53085 Mdot
.23264 .4154 Mdot
.42066 .75601 Mdot
.41784 .77084 Mdot
.8428 .49689 Mdot
.72499 .62341 Mdot
.52314 .40248 Mdot
.34423 .62215 Mdot
.28353 .27138 Mdot
.84427 .47768 Mdot
.27641 .27944 Mdot
.51745 .29139 Mdot
.572 .33972 Mdot
.33857 .81978 Mdot
.24966 .4707 Mdot
.5872 .33881 Mdot
.55786 .30168 Mdot
.57143 .29461 Mdot
.55229 .40799 Mdot
.32615 .66465 Mdot
.75386 .48979 Mdot
.75539 .38385 Mdot
.25047 .30491 Mdot
.3941 .43295 Mdot
.54228 .53395 Mdot
.37884 .62809 Mdot
.61604 .50302 Mdot
.58397 .47432 Mdot
.41352 .6648 Mdot
.75684 .37265 Mdot
.55693 .77343 Mdot
.70576 .51236 Mdot
.29469 .46559 Mdot
.44846 .45645 Mdot
.26423 .39798 Mdot
.77089 .36831 Mdot
.33962 .72575 Mdot
.8192 .50902 Mdot
.71218 .29773 Mdot
.44604 .38335 Mdot
.36727 .55759 Mdot
.80961 .33546 Mdot
.52951 .53411 Mdot
.33085 .64189 Mdot
.62838 .43631 Mdot
.42221 .38648 Mdot
.32592 .26916 Mdot
.7606 .59889 Mdot
.40775 .5517 Mdot
.48842 .31332 Mdot
.2811 .30037 Mdot
.3975 .69709 Mdot
.32795 .19145 Mdot
.59632 .45283 Mdot
.41216 .21782 Mdot
.2476 .36479 Mdot
.46125 .64295 Mdot
.33961 .32039 Mdot
.50146 .38748 Mdot
.58674 .58408 Mdot
.55311 .76963 Mdot
.293 .40425 Mdot
.43887 .62225 Mdot
.22316 .43648 Mdot
.79083 .39506 Mdot
.37351 .23071 Mdot
.54152 .39528 Mdot
.75188 .56484 Mdot
.54236 .51898 Mdot
.6579 .6722 Mdot
.58932 .76752 Mdot
.3572 .52321 Mdot
.76906 .37055 Mdot
.75495 .4045 Mdot
.32771 .3063 Mdot
.21026 .35017 Mdot
.62511 .3094 Mdot
.32347 .26175 Mdot
.63752 .57969 Mdot
.28655 .56918 Mdot
.67125 .28296 Mdot
.19057 .62771 Mdot
.5462 .28313 Mdot
.61316 .31067 Mdot
.33453 .20254 Mdot
.3097 .25811 Mdot
.43445 .68126 Mdot
.27121 .46841 Mdot
.74194 .29644 Mdot
.64167 .50858 Mdot
.54022 .87232 Mdot
.41401 .76133 Mdot
.35746 .17777 Mdot
.43574 .63035 Mdot
.61814 .4407 Mdot
.43224 .43309 Mdot
.58456 .32284 Mdot
.57752 .70792 Mdot
.22646 .4105 Mdot
.4229 .44576 Mdot
.64802 .44336 Mdot
.49263 .39634 Mdot
.50905 .64014 Mdot
.29594 .43237 Mdot
.16808 .58672 Mdot
.55065 .73264 Mdot
.60199 .58576 Mdot
.3038 .74256 Mdot
.5559 .77162 Mdot
.82995 .41288 Mdot
.18693 .4054 Mdot
.30676 .50392 Mdot
.4689 .58906 Mdot
.60089 .81063 Mdot
.30602 .40771 Mdot
.31748 .46962 Mdot
.34023 .68427 Mdot
.77742 .46323 Mdot
.33852 .60806 Mdot
.22592 .679 Mdot
.33189 .2224 Mdot
.63046 .36676 Mdot
.54936 .88959 Mdot
.71115 .30576 Mdot
.58138 .55517 Mdot
.33556 .61477 Mdot
.25673 .29405 Mdot
.62799 .68438 Mdot
.50764 .15558 Mdot
.21943 .56461 Mdot
.33557 .35967 Mdot
.76923 .47663 Mdot
.40575 .81899 Mdot
.47809 .60799 Mdot
.41777 .84934 Mdot
.26277 .49346 Mdot
.73425 .4748 Mdot
.2521 .60698 Mdot
.3276 .46185 Mdot
.57279 .27733 Mdot
.22237 .52697 Mdot
.65887 .358 Mdot
.37243 .37284 Mdot
.23126 .45706 Mdot
.77253 .52989 Mdot
.42364 .73197 Mdot
.2526 .46308 Mdot
.33603 .67528 Mdot
.42123 .44061 Mdot
.73718 .30945 Mdot
.53154 .7402 Mdot
.55215 .72638 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo097ooooo1?l0002dooooo`007?ooool00ol0003oooooooooo`2;ooooo`;o0000
1?ooool4o`0000;ooooo0_l0002`ooooo`007?ooool2o`0008_ooooo0ol0000:ooooo`;o0000/?oo
ool001cooooo00?o0000ooooooooool0R_ooool2o`0001Gooooo1?l0002Tooooo`007?ooool00ol0
003oooooooooo`2Looooo`;o00000oooool4o`000:Cooooo000Looooo`03o`000?oooooooooo07So
oooo0_l0000:ooooo`;o00004?ooool4o`0000;ooooo0_l0002[ooooo`007?ooool00ol0003ooooo
ooooo`1gooooo`?o00000oooool2o`000003ooooool0003o000000;ooooo0_l0000@ooooo`Co0000
[oooool001cooooo00?o0000ooooooooool0Moooool2o`0000Cooooo0_l000000ooooooo0000o`00
0006ooooo`Ko000000?oooooo`000?l000000_l00002ooooo`;o00000oooool3o`0001?ooooo0_l0
002Gooooo`007?ooool00ol0003oooooooooo`1jooooo`;o00002Oooool2o`000003ooooool0003o
000000Co000000?oooooo`000?l000000_l00002ooooo`;o00000oooool3o`0001?ooooo0_l0002G
ooooo`007?ooool00ol0003oooooooooo`1]ooooo`;o00002oooool2o`000003ooooool0003o0000
00Kooooo0_l00005ooooo`;o00007?ooool2o`0009gooooo000Looooo`03o`000?oooooooooo06go
oooo1Ol00004ooooo`;o00001Oooool2o`0002_ooooo1?l00005ooooo`?o0000Toooool001cooooo
00?o0000ooooooooool0K_ooool4o`0000?ooooo1?l0000:ooooo`;o00009oooool2o`0000Gooooo
0ol0002Cooooo`007?ooool00ol0003oooooooooo`1dooooo`Go00001oooool2o`000003ooooool0
003o000002cooooo0ol0002Eooooo`007?ooool00ol0003oooooooooo`1Xooooo`;o00002_ooool2
o`0000[ooooo0_l000000ooooooo0000o`00000/ooooo`?o00000_ooool2o`00097ooooo000Loooo
o`03o`000?oooooooooo06Sooooo0_l0000Iooooo`;o00001?ooool3o`0001Oooooo0_l0000Aoooo
o`;o0000TOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006
ooooo`03o`000?oooooooooo06Oooooo0_l0000Pooooo`?o00003Oooool2o`0000Sooooo0_l0000A
ooooo`;o00000_ooool2o`0008gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ
8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1Wooooo`;o0000
5Oooool2o`0000[ooooo0_l0000=ooooo`Co00001Oooool2o`0000?ooooo0_l0000Aooooo`;o0000
SOooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^
kP07ooooo`03o`000?oooooooooo07kooooo0_l0000=ooooo`;o00002Oooool2o`000003ooooool0
003o000000Gooooo1ol0000Hooooo`Co0000Q?ooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool02oooool00onHV9So8B4Qonk^kP06ooooo`?o0000JOooool2o`0001kooooo0_l00002
ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Sooooo1_l0000Iooooo`Co00005?ooool2
o`0006kooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIV
I_ooool01Oooool00ol0003oooooooooo`1Yooooo`;o00007_ooool2o`0000Gooooo0_l0000@oooo
o`Ko00005_ooool2o`000003ooooool0003o000001Kooooo0_l0001^ooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0Qoooool2o`0000Oooooo0_l0000Cooooo`;o00000oooool2o`0000?ooooo0_l0000=ooooo`;o
00000_ooool2o`0008Gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj
^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo08?ooooo0_l00002ooooo`;o00007?ooool2
o`0000?ooooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l00008ooooo`Oo00000_ooool3
o`0007kooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c006ooooo`03o`000?oooooooooo08?ooooo0_l0000Uooooo`;o000000Coooooo`000?l0003o
00000oooool4o`0000Sooooo1?l000000ooooooo0000o`000002ooooo`Co0000OOooool001cooooo
00?o0000ooooooooool0P_ooool2o`0001Kooooo1?l000000ooooooo0000o`000009ooooo`;o0000
0_ooool2o`0000?ooooo1?l0000=ooooo`;o00001?ooool2o`00017ooooo0_l0001Zooooo`007?oo
ool00ol0003oooooooooo`1Oooooo`;o00008Oooool2o`0001?ooooo0_l000000ooooooo0000o`00
0005o`000003ooooool0003o000000_ooooo0_l00004ooooo`;o00003Oooool4o`0001Gooooo0ol0
001Yooooo`007?ooool00ol0003oooooooooo`1Mooooo`Co00001Oooool4o`0002_ooooo1?l00005
ooooo`;o00000_ooool2o`0000[ooooo0ol00005ooooo`;o00003?ooool4o`0001Kooooo0_l0001Y
ooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o00001_ooool5o`0000[ooooo0_l0000Ooooo
o`;o00003oooool2o`0000Kooooo0_l00004ooooo`Co00003_ooool2o`00087ooooo000Looooo`03
o`000?oooooooooo06Cooooo0ol000000ooooooo0000o`00000:ooooo`Co00007Oooool2o`0000co
oooo1_l0000;ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`0001Gooooo0_l0001boooo
o`007?ooool00ol0003oooooooooo`1Tooooo`;o00003_ooool4o`0002_ooooo1_l0000=ooooo`Co
00000_ooool4o`0001Gooooo0_l0001booooo`007?ooool00ol0003oooooooooo`1eooooo`;o0000
2Oooool2o`0002?ooooo0_l0000?ooooo`;o00001?ooool2o`0008_ooooo000Looooo`03o`000?oo
oooooooo07?ooooo0_l0000;ooooo`;o00008oooool3o`00023ooooo0_l00008ooooo`;o00000ooo
ool2o`00073ooooo000Looooo`03o`000?oooooooooo07?ooooo0_l00009ooooo`Co00009?ooool2
o`00023ooooo0_l00008ooooo`;o00000oooool2o`0000_ooooo0_l0001Sooooo`007?ooool00ol0
003oooooooooo`1Rooooo`;o00000_ooool2o`0001Kooooo1?l0000Qooooo`;o00006?ooool2o`00
02Cooooo0ol0001Sooooo`007?ooool00ol0003oooooooooo`1Looooo`?o00000oooool2o`0000;o
oooo0_l0000aooooo`Ko00001?ooool2o`0001Sooooo0_l00002ooooo`?o00005?ooool2o`0000Wo
oooo0_l0001Tooooo`007?ooool2o`0005gooooo0ol000000ooooooo0000o`000002o`0000[ooooo
0_l0000Vooooo`Wo00008_ooool3o`0001Cooooo0_l0000;ooooo`;o0000H_ooool001cooooo00?o
0000ooooooooool0D_ooool2o`0000[ooooo1?l00005ooooo`;o00001Oooool2o`0000;ooooo0_l0
0008ooooo`;o00006?ooool3o`0002Gooooo0_l0000Iooooo`;o00002_ooool2o`0006;ooooo000L
ooooo`03o`000?oooooooooo05;ooooo0_l0000:ooooo`Oo00000_ooool2o`0000Wooooo0_l00008
ooooo`;o0000;Oooool2o`0000Cooooo0_l0000;ooooo`;o00006Oooool2o`000003ooooool0003o
000000Oooooo0ol0001Qooooo`007?ooool00ol0003oooooooooo`1Gooooo`;o00000oooool2o`00
00?ooooo1?l0000Gooooo`;o00008oooool2o`0000Sooooo0ol00002ooooo`?o00004oooool2o`00
01Cooooo0_l00007ooooo`?o0000HOooool001cooooo00?o0000ooooooooool0Eoooool2o`0000?o
oooo0_l00002ooooo`;o00000oooool2o`0001Gooooo0_l0000Sooooo`;o00002Oooool2o`0000;o
oooo0ol0000;ooooo`?o00001Oooool2o`0001Cooooo0_l000000ooooooo0000o`000005ooooo`;o
0000HOooool001cooooo00?o0000ooooooooool0Goooool5o`000003ooooool0003o000001Gooooo
0_l0000Vooooo`;o00002oooool2o`0000_ooooo0ol000000ooooooo0000o`00000Aooooo`;o0000
1Oooool5o`0000Gooooo0_l0001Qooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o00004_oo
ool5o`0000;ooooo0_l0000;ooooo`;o00001oooool2o`0002Kooooo0_l0000<ooooo`;o00003_oo
ool2o`0000oooooo1?l00007ooooo`?o000000?oooooo`000?l000001?ooool2o`0005oooooo000L
ooooo`03o`000?oooooooooo04_ooooo0_l0000;ooooo`;o00000_ooool2o`0000;ooooo0_l00004
ooooo`;o00001_ooool2o`0000?ooooo0_l00006ooooo`?o00008oooool2o`0000cooooo0_l00000
0ooooooo0000o`00000=ooooo`;o00002Oooool2o`0000Gooooo0ol00008ooooo`Ko00001?ooool2
o`0005oooooo000Looooo`03o`000?oooooooooo05Sooooo0_l00002ooooo`;o00004?ooool2o`00
00_ooooo0_l0000Mooooo`;o00001Oooool4o`0000[ooooo0_l00004ooooo`;o00002_ooool2o`00
00Wooooo0ol00008ooooo`;o00000_ooool9o`0006Gooooo000Looooo`03o`000?oooooooooo05Ko
oooo0_l0000Eooooo`;o000000?oooooo`000?l00000:?ooool2o`0000Kooooo2Ol0000:ooooo`?o
000000?oooooo`000?l000004_ooool2o`0000Oooooo2ol0001Xooooo`007?ooool00ol0003ooooo
ooooo`1Aooooo`;o00000oooool2o`0001Gooooo0_l000000ooooooo0000o`00000Xooooo`;o0000
1_ooool2o`000003ooooool0003o000000Co00000oooool2o`0000Gooooo1ol0000Jooooo`;o0000
00?oooooo`000?l000003?ooool4o`0005kooooo000Looooo`03o`000?oooooooooo04oooooo1?l0
0004ooooo`;o00000_ooool4o`00013ooooo0_l00004ooooo`;o00008oooool3o`0000Gooooo0ol0
00000ooooooo0000o`000005ooooo`?o00001Oooool4o`000003ooooool0003o000001[ooooo0_l0
0005ooooo`;o00002?ooool4o`0005kooooo000Looooo`03o`000?oooooooooo04oooooo0_l00006
ooooo`;o00000_ooool4o`00013ooooo0_l00002ooooo`Co00009?ooool2o`0000Kooooo0_l00007
ooooo`?o00001_ooool2o`0000Gooooo0_l000001?oooooo0000o`000?l00005ooooo`;o00003ooo
ool2o`000003ooooool0003o000000;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l0
00000ooooooo0000o`00001Looooo`007?ooool00ol0003oooooooooo`1Fooooo`;o00006oooool2
o`0000Gooooo0_l0000Wooooo`?o00001?ooool4o`0000Kooooo0_l00006ooooo`;o000000Cooooo
o`000?l0003o00001Oooool2o`0000oooooo0_l000001?oooooo0000o`000?ooool4o`000004oooo
ool0003o0000o`0000;ooooo0_l000000ooooooo0000o`00001Looooo`007?ooool00ol0003ooooo
ooooo`1;ooooo`;o00000_ooool3o`0000;ooooo1?l0000=ooooo`;o00001_ooool2o`0000Kooooo
0_l00002ooooo`?o00009oooool3o`0000Cooooo0_l00007ooooo`Oo00004_ooool2o`00013ooooo
2Ol00004ooooo`Go0000FOooool001cooooo00?o0000ooooooooool0Boooool7o`0000;ooooo0_l0
0002ooooo`;o00001_ooool2o`0000;ooooo0ol00006ooooo`;o00001_ooool2o`0000;ooooo0ol0
000Oooooo`;o00003Oooool2o`0000Kooooo0ol000000ooooooo0000o`000002o`0000?ooooo0ol0
0004ooooo`Co00000_ooool4o`0001;ooooo1ol00004ooooo`Go0000FOooool001cooooo0_l0001>
ooooo`;o00001oooool4o`0000Kooooo0_l00002ooooo`;o00005?ooool2o`0001oooooo0_l0000D
ooooo`?o00002Oooool3o`0000Cooooo1?l00002ooooo`Co00005_ooool3o`0000?ooooo0_l00000
0ooooooo0000o`000002o`0000;ooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`19oooo
o`;o00002oooool4o`000003ooooool0003o000000Oooooo0_l00006ooooo`;o00000oooool2o`00
0003ooooool0003o000002Gooooo1?l0000Booooo`;o00005?ooool4o`000003ooooool0003o0000
00?ooooo0_l00005ooooo`;o00001_ooool2o`0000?ooooo0_l00003ooooo`;o00000oooool6o`00
00Gooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`17ooooo`Go00000_ooool2o`0000Co
oooo0_l00005ooooo`?o00001_ooool5o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l0
00009Oooool4o`0001oooooo0_l00007ooooo`Co00001?ooool4o`0000Gooooo0_l000000ooooooo
0000o`000003ooooo`;o000000Coooooo`000?l0003ooooo0_l00009ooooo`;o00001oooool2o`00
04gooooo000Looooo`03o`000?oooooooooo04Oooooo0_l000000ooooooo0000o`000002ooooo`;o
00001?ooool2o`0000Cooooo1?l00008ooooo`?o00001_ooool7o`0000Cooooo0_l0000Sooooo`;o
00006Oooool7o`0000;ooooo0_l00002ooooo`?o00000_ooool5o`0000Sooooo1Ol00005ooooo`;o
000000?oooooo`000?l000001?ooool2o`0005_ooooo000Looooo`03o`000?oooooooooo04[ooooo
0_l000001?oooooo0000o`000?ooool2o`0000Sooooo1?l0000@ooooo`Ko00000oooool2o`000004
ooooool0003o0000o`0001Sooooo0_l00004ooooo`?o000000?oooooo`000?l000003Oooool2o`00
00;ooooo0_l00005ooooo`Wo000000?oooooo`000?l000000_ooool3o`0000;ooooo1?l00009oooo
o`;o000000?oooooo`000?l000002?ooool2o`0000Cooooo0_l0001Kooooo`007?ooool00ol0003o
ooooooooo`1=ooooo`Go00004?ooool2o`0000Gooooo0_l000000ooooooo0000o`000003o`0000Ko
oooo0_l00002ooooo`;o00006?ooool2o`000003ooooool0003o000000Co00004?ooool2o`000004
ooooool0003o0000o`0000?ooooo3?l000000ooooooo0000o`000002ooooo`;o00000_ooool4o`00
01Cooooo1_l0000Aooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0Coooool2o`0000_o
oooo1Ol000000ooooooo0000o`000002o`0000?ooooo2?l0000Oooooo`;o00001?ooool6o`00013o
oooo1?l000000ooooooo0000o`000004ooooo`Wo000000?oooooo`000?l000001Ol00004ooooo`Co
00004_ooool8o`00017ooooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o0000
3Oooool2o`0000Oooooo1Ol00002ooooo`_o00004Oooool2o`0000oooooo0_l00004ooooo`Ko0000
1?ooool2o`0000[ooooo2ol000000ooooooo0000o`000002o`0000Gooooo1?l000000ooooooo0000
o`00000Jooooo`Ko00006_ooool2o`0004Gooooo000Looooo`03o`000?oooooooooo04Cooooo0_l0
000=ooooo`;o00002_ooool2o`000003ooooool0003o000000[o00004Oooool2o`0000gooooo0_l0
0008ooooo`Co00001?ooool2o`0000[ooooo2ol00002ooooo`?o00001?ooool3o`000003ooooool0
003o000000;o00000_ooool4o`0000;ooooo0_l00003ooooo`;o00000oooool2o`0002Kooooo0_l0
0015ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00003oooool2o`0000Cooooo0_l00000
1Ooooooo0000o`000?l0003ooooo00Co00001_ooool2o`00017ooooo0_l0000=ooooo`;o000000?o
ooooo`000?l000002?l0000?ooooo`_o000000?oooooo`000?l000002?ooool2o`000003ooooool0
003o000000?o00000_ooool4o`0000;ooooo0_l00003ooooo`;o00000oooool2o`000003ooooool0
003o000000;o00000_ooool2o`0000?ooooo0_l0001Oooooo`007?ooool00ol0003oooooooooo`18
ooooo`;o00002oooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000000_oo
ool4o`0000Kooooo0ol0000@ooooo`;o00004?ooool7o`000003ooooool0003o000000Wooooo0_l0
00000ooooooo0000o`000004o`000003ooooool0003o000000Kooooo0_l00007ooooo`?o000000?o
ooooo`000?l000001?l0000Dooooo`Co00000_ooool4o`000003ooooool0003o000005oooooo000L
ooooo`03o`000?oooooooooo043ooooo0_l00006ooooo`;o00000oooool3o`0000;ooooo0_l00004
ooooo`;o00000_ooool4o`0000;ooooo1?l00006ooooo`?o00001oooool2o`0000[ooooo0_l0000:
ooooo`;o00000_ooool2o`0000oooooo1ol00004ooooo`Co00001Oooool2o`0000Gooooo1?l00000
1Ooooooo0000o`000?l0003ooooo00;o00001_ooool3o`000003ooooool0003o000000Sooooo0_l0
0006ooooo`Ko00006?ooool2o`0004Cooooo000Looooo`03o`000?oooooooooo043ooooo0_l00002
ooooo`Co00001Oooool3o`000004ooooool0003o0000o`0000Sooooo0_l00004ooooo`?o00003Ooo
ool2o`0000;ooooo0_l0000:ooooo`;o00002_ooool8o`0000gooooo2_l00003ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0000Gooooo0_l00003ooooo`;o00000oooool3o`0000Cooooo0ol0
00000ooooooo0000o`000006ooooo`Co00001oooool5o`0001Sooooo0_l00014ooooo`007?ooool0
0ol0003oooooooooo`14ooooo`Co00002Oooool2o`0001oooooo0_l0000<ooooo`;o00003_ooool6
o`0000gooooo3ol000001?oooooo0000o`000?ooool4o`000003ooooool0003o000000?ooooo0_l0
0005ooooo`Co00001?ooool2o`0000[ooooo1?l00004ooooo`;o000000?oooooo`000?l000001?l0
001Mooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o00000oooool2o`0001;ooooo0_l00006
ooooo`Go000000?oooooo`000?l000004Oooool2o`0000cooooo4_l000000ooooooo0000o`000007
o`0000?ooooo0ol000001?oooooo0000o`000?ooool5o`0001Cooooo0_l000000ooooooo0000o`00
0002ooooo`;o000000?oooooo`000?l00000GOooool001cooooo00?o0000ooooooooool0B_ooool2
o`0000gooooo0_l00003ooooo`;o00002Oooool4o`0000gooooo1Ol0000Dooooo`;o00002oooool8
o`0000;ooooo4ol00004ooooo`Go00001?ooool4o`0001;ooooo0_l000000ooooooo0000o`000004
o`000003ooooool0003o000001Wooooo0_l00012ooooo`007?ooool2o`0003gooooo0_l00003oooo
o`;o00001?ooool2o`000003ooooool0003o000000[ooooo0_l0000;ooooo`;o00000oooool5o`00
02Wooooo0_l00008ooooo`?o00001Oooool2o`000003ooooool0003o000001Wo00001Oooool3o`00
01Kooooo1_l0000Kooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0??ooool2o`0000?o
oooo0_l00002ooooo`Co00003Oooool2o`0000_ooooo0_l00003ooooo`;o00002?ooool2o`0000Oo
oooo0_l0000Dooooo`;o00000oooool2o`0000[ooooo0ol00002oooooaoo00001Oooool2o`0001Ko
oooo0_l000000ooooooo0000o`000004o`0005gooooo000Looooo`03o`000?oooooooooo03cooooo
0_l00007ooooo`;o00002Oooool2o`0001Wooooo0_l00005ooooo`;o00001oooool2o`0000_ooooo
0_l00007ooooo`;o00003oooool3o`0000;ooooo5_l00002ooooo`Wo00000_ooool2o`00017ooooo
0_l00004ooooo`;o000000?oooooo`000?l000000_ooool2o`0005gooooo000Looooo`03o`000?oo
oooooooo03_ooooo0ol0000;ooooo`;o00001Oooool2o`0000oooooo1?l00004ooooo`Co00003?oo
ool2o`0000Sooooo1ol00008ooooo`Co00001?ooool2o`000003ooooool0003o000000Gooooo0_l0
00000ooooooo0000o`00000Ko`000004ooooool0003o0000o`0000;ooooo0_l00006ooooo`;o0000
2Oooool2o`0000Cooooo1?l0001Rooooo`007?ooool00ol0003oooooooooo`0iooooo`Co00001_oo
ool2o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Sooooo1Ol0
0003ooooo`;o00001?ooool2o`0000Sooooo0_l00008ooooo`Ko00002Oooool4o`0000Cooooo1Ol0
0002ooooo`;o000000?oooooo`000?l000007_l000001?oooooo0000o`000?ooool3o`0000Oooooo
1Ol0000>ooooo`;o00001_ooool2o`0005[ooooo000Looooo`03o`000?oooooooooo03Sooooo0ol0
00001?oooooo0000o`000?ooool2o`0000;ooooo0_l00008ooooo`;o000000?oooooo`000?l00000
1Oooool2o`0000?ooooo0_l00006ooooo`;o00002Oooool4o`0002Wooooo0ol00002ooooo`;o0000
00?oooooo`000?l000007_l000001?oooooo0000o`000?ooool4o`0000Oooooo1Ol0000>ooooo`;o
00001Oooool2o`0005[ooooo000Looooo`03o`000?oooooooooo03Sooooo0_l00002ooooo`;o0000
00?oooooo`000?l000002?ooool2o`0000;ooooo0ol0000:ooooo`Co00004Oooool4o`0000Cooooo
0_l0000Cooooo`Co00002?ooool2o`000003ooooool0003o000000;o00000_oooolSo`000003oooo
ool0003o000000Go00001Oooool2o`000003ooooool0003o000000;o00001_ooool2o`0000Cooooo
1?l0000?ooooo`;o000000?oooooo`000?l00000COooool001cooooo00?o0000ooooooooool0=_oo
ool2o`00017ooooo0_l000000ooooooo0000o`000002o`0000[ooooo0_l000001?oooooo0000o`00
0?l0000>ooooo`Co00001Oooool3o`0001;ooooo1?l00008ooooo`;o000000?oooooo`000?l00000
;_l00002ooooo`?o000000Coooooo`000?l0003ooooo0_l00008ooooo`;o00000oooool3o`000003
ooooool0003o000000gooooo0ol000000ooooooo0000o`000002o`0004_ooooo000Looooo`03o`00
0?oooooooooo03Kooooo0_l0000Cooooo`Co00003_ooool3o`0000Cooooo0_l00002ooooo`;o0000
1?ooool2o`0000Gooooo0_l000000ooooooo0000o`000009ooooo`;o00001oooool2o`0000cooooo
0ol000000ooooooo0000o`00000Xo`0000Gooooo0ol0000=ooooo`;o00001?ooool2o`0000;ooooo
0_l00009ooooo`;o00000_ooool2o`0000Cooooo0_l0001;ooooo`007?ooool00ol0003ooooooooo
o`11ooooo`;o00002?ooool4o`0000Oooooo0_l0000<ooooo`;o00000_ooool2o`0000_ooooo0_l0
0008ooooo`;o00000_ooool2o`000003ooooool0003o000001;ooooo0ol000000ooooooo0000o`00
0002o`000003ooooool0003o000001[o000000?oooooo`000?l000001_l00005ooooo`;o00000_oo
ool5o`0000Oooooo0_l0000Cooooo`;o0000EOooool001cooooo00?o0000ooooooooool0=oooool2
o`0000Kooooo1?l00006ooooo`;o00002oooool2o`0000oooooo1?l00005ooooo`Co00001oooool2
o`0000;ooooo0_l00005ooooo`;o00002?ooool2o`0000Oooooo1?l00003ooooobCo00000_ooool2
o`0000Gooooo0_l00002ooooo`Go000000?oooooo`000?l000003?ooool2o`0001Gooooo0_l00000
0ooooooo0000o`000018ooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00001_ooool2o`00
00Sooooo0_l00008ooooo`?o00000_ooool2o`0000gooooo1?l00004ooooo`Oo00001Oooool2o`00
00gooooo0_l000001?oooooo0000o`000?ooool2o`0000Kooooo1Ol00005ooooob?o000000?ooooo
o`000?l000002?ooool2o`0000Gooooo0_l00004ooooo`;o00001_ooool3o`0000[ooooo0_l00003
ooooo`;o00000oooool2o`000003ooooool0003o000004Sooooo000Looooo`03o`000?oooooooooo
04Oooooo0_l0000:ooooo`Oo00000_ooool2o`0000_ooooo0_l00004ooooo`So000000?oooooo`00
0?l000001Oooool2o`0000Cooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o0000
00Wooooo1Ol00002ooooobKo000000?oooooo`000?l000001?ooool2o`0000;ooooo0_l0000;oooo
o`?o00001_ooool2o`0000Wooooo0ol00003ooooo`;o00002?ooool2o`0004Kooooo000Looooo`03
o`000?oooooooooo03?ooooo0_l00003ooooo`;o00003Oooool2o`0000[ooooo0_l000000ooooooo
0000o`000004ooooo`;o00004?ooool>o`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l0
00003_ooool5o`0000;ooooo:Ol00004ooooo`;o00001oooool2o`0000Kooooo0ol0000Aooooo`;o
00001?ooool2o`0000Oooooo0ol00016ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5oooo
o`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0<oooool2o`00
00?ooooo0_l0000Oooooo`;o00002?ooool4o`0000Gooooo2Ol000000ooooooo0000o`000004o`00
00Sooooo0_l00002ooooo`Co00003?ooool5o`0000;ooooo:?l0000>ooooo`;o00001_ooool2o`00
00gooooo0_l00003ooooo`;o00001?ooool2o`0000Oooooo0_l00017ooooo`0000KoooooogMgMonH
V9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo03Gooooo0_l0000Dooooo`;o00003?ooool2o`0000Sooooo4_l00002ooooo`Co00002Oooool2
o`0000;ooooo1?l00002ooooo`;o00002?ooool6o`0000?ooooo:?l00003ooooo`;o00003_ooool2
o`0000kooooo1?l000000ooooooo0000o`00000:ooooo`Co0000B?ooool00003ooooool@413ooooo
00;ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo00?o0000ooooooooool0<oooool4o`00
01Cooooo0_l00003ooooo`Co00003ooooolCo`000003ooooool0003o000000;o00000oooool2o`00
00Sooooo0_l00004ooooo`?o00001_ooool7o`0000?ooooo:?l00003ooooo`;o000000?oooooo`00
0?l000000oooool2o`0000Kooooo0_l0000@ooooo`;o00000oooool2o`0000Cooooo0_l00002oooo
o`Co00000oooool2o`0004?ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wo
oooo00CoA4A4omgMgOoooooo00001oooool3o`00037ooooo1?l0000=ooooo`;o00001oooool2o`00
00?ooooo1Ol000000ooooooo0000o`000002ooooo`;o00001OoooolIo`000004ooooool0003o0000
ooooo`;o00003_ooool3o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`;o00000ooooolX
o`0000Kooooo0_l000000ooooooo0000o`000002o`0000oooooo0_l00005ooooo`;o00000_ooool2
o`000003ooooool0003o000000Cooooo0_l00009ooooo`;o0000@oooool00003ooooool0003ooooo
00;ooooo00?o0000ooooooooool02Oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooo
oooo037ooooo1?l00004ooooo`;o00001_ooool3o`0000Cooooo0_l00007ooooo`Co000000?ooooo
o`000?l000000_ooool3o`0000Cooooo7?l0000:ooooo`Co00000oooool2o`0000?ooooo0ol00005
ooooo`;o00000ooooolYo`0000Wooooo0_l00008ooooo`;o00001oooool2o`0000Gooooo0_l00002
ooooo`Ko00003Oooool2o`0004Cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo
00[ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0eooooo`;o00000_ooool2o`00
00Kooooo0_l00005ooooo`Co00001oooool2o`0000Gooooo0ol00003ooooo`go000000?oooooo`00
0?l000003?l0000;ooooo`Co00002?ooool2o`0000Kooooo0_l000000ooooooo0000o`000005o`00
0003ooooool0003o000002;o00004_ooool3o`0001;ooooo1Ol0000:ooooo`;o000000?oooooo`00
0?l00000A?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007
ooooo`03o`000?oooooooooo03Gooooo0_l00002ooooo`;o000000?oooooo`000?l000002?ooool2
o`0000;ooooo0_l00007ooooo`;o00001Oooool2o`0000Cooooo7ol00009ooooo`?o00000_ooool2
o`0000Cooooo0_l00002ooooo`;o00000_ooool2o`000005ooooool0003o0000o`000?ooool00ol0
00000ooooooo0000o`00000Co`000003ooooool0003o000000co00001Oooool3o`0000Wooooo1?l0
00001?oooooo0000o`000?l0000Kooooo`Co0000Aoooool00006ooooooo^k^ko<S8bo`000?lb<S;o
k^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo02oooooo0_l00008ooooo`;o
000000Coooooo`000?l0003ooooo0_l00005ooooo`Co00000oooool2o`0000_ooooo0_l00004oooo
ob3o00001_ooool2o`0000Gooooo0_l00004ooooo`;o00000_ooool3o`000003ooooool0003o0000
00;ooooo8_l00003ooooo`?o00001Oooool2o`000004ooooool0003o0000o`0000Wooooo0ol00002
ooooo`?o00002_ooool2o`000003ooooool0003o000000cooooo0ol00006ooooo`;o000000?ooooo
o`000?l00000?Oooool001cooooo00?o0000ooooooooool0;oooool2o`0000Cooooo0_l00007oooo
o`?o00001Oooool4o`0000?ooooo0_l0000;ooooo`;o00000_oooolAo`000003ooooool0003o0000
00Wo00000_ooool4o`0000Gooooo0_l00005ooooo`;o00002Oooool4o`0000Cooooo0_l000000ooo
oooo0000o`00000<o`0000?ooooo3ol000001?oooooo0000o`000?ooool2o`0000?ooooo0_l0000=
ooooo`;o00004?ooool2o`000003ooooool0003o000000cooooo0_l00007ooooo`;o000000?ooooo
o`000?l00000?Oooool001cooooo00?o0000ooooooooool0=Oooool2o`0000Oooooo0_l0000Moooo
o`?o00000_oooolIo`000004ooooool0003o0000ooooo`?o00000oooool3o`0000Cooooo0_l0000:
ooooo`Co00001oooool@o`000003ooooool0003o000000Wo00000_ooool5o`000003ooooool0003o
000001;ooooo0_l00003ooooo`;o00001_ooool2o`0000Cooooo0_l000000ooooooo0000o`00001F
ooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00005?ooool2o`0001Kooooo1?l00002oooo
oaSo00000_ooool3o`000003ooooool0003o000000?ooooo0_l00005ooooo`;o00002_ooool4o`00
00Gooooo1?l00002ooooo`ko000000?oooooo`000?l000003_l0000=ooooo`;o00001Oooool3o`00
0003ooooool0003o000000;o00001_ooool2o`0000Cooooo1Ol0001Fooooo`007?ooool00ol0003o
ooooooooo`0^ooooo`;o00002Oooool2o`0000Wooooo0_l0000Fooooo`Co000000?oooooo`000?l0
00006?l000001?oooooo0000o`000?l0000Oooooo`Ko00001OoooolLo`0000kooooo0_l00005oooo
o`;o00000_ooool2o`0000oooooo0ol0001Gooooo`007?ooool00ol0003oooooooooo`0iooooo`;o
00008oooool2o`000003ooooool0003o000001Wo00000_ooool4o`0000Oooooo0_l0000Cooooo`So
00000oooool2o`0000;ooooo4?l000000ooooooo0000o`000005o`000004ooooool0003o0000oooo
o`;o00003oooool2o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`;o00001_ooool4o`00
01;ooooo0ol00003ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0@Oooool2o`0000co
oooo0_l0000;ooooo`;o00000ooooolQo`0000Oooooo0_l0000Gooooo`Oo000000Coooooo`000?l0
003o00000oooool>o`000003ooooool0003o000000;o00000oooool2o`000003ooooool0003o0000
00oooooo0_l00002ooooo`;o000000?oooooo`000?l000001Oooool3o`0000Oooooo0_l0000Boooo
o`?o00000oooool2o`0003_ooooo000Looooo`03o`000?oooooooooo047ooooo0_l00002ooooo`;o
00002?ooool2o`0000_ooooo0_l00003oooooa[o000000?oooooo`000?l000000_l000000ooooooo
0000o`000006ooooo`;o00006_ooool4o`000004ooooool0003o0000o`0000?ooooo1ol000000ooo
oooo0000o`000004o`0000?ooooo1?l000000ooooooo0000o`000002o`0000Cooooo0_l00009oooo
o`;o00000oooool2o`0000Wooooo0_l0000Nooooo`;o000000?oooooo`000?l00000>oooool001co
oooo00?o0000ooooooooool0:oooool2o`0001Sooooo0_l0000JoooooaWo00001?ooool2o`000003
ooooool0003o000000Cooooo0_l0000Booooo`Co00001_ooool3o`0000Kooooo0_l000000ooooooo
0000o`000002ooooo`;o00001?ooool2o`0000Cooooo1?l00003ooooo`;o00000oooool3o`0000So
oooo0ol00005ooooo`Co00006_ooool2o`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l0
0000>oooool001cooooo00?o0000ooooooooool0:oooool2o`0000?ooooo0_l0000/ooooo`?o0000
0_oooolIo`000005ooooool0003o0000o`000?ooool00_l00002ooooo`Co00004_ooool4o`0000;o
oooo0_l00009ooooo`So000000?oooooo`000?l000001oooool5o`0000;ooooo0_l00006ooooo`Co
00001_ooool5o`0000?ooooo1Ol0000Jooooo`;o00001Oooool2o`0004;ooooo000Looooo`03o`00
0?oooooooooo033ooooo0_l0000@ooooo`;o00005_ooool2o`0000;ooooo0ol000001?oooooo0000
o`000?oooolKo`000003ooooool0003o000000;ooooo0ol000000ooooooo0000o`000004ooooo`;o
00003_ooool5o`0000Sooooo2?l0000:ooooo`?o00001?ooool2o`0000Sooooo0_l00005ooooo`Ko
00000oooool2o`0000_ooooo0_l0000Fooooo`;o00001?ooool2o`0003gooooo000Looooo`03o`00
0?oooooooooo02kooooo0_l000000ooooooo0000o`00000?ooooo`;o00001Oooool2o`0000Kooooo
0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000000Go000000?oooooo`000?l00000
6?l00002ooooo`;o00000_ooool3o`000003ooooool0003o000000Cooooo0_l0000>ooooo`Oo0000
2_ooool2o`0000cooooo0_l0000;ooooo`;o00002Oooool2o`000004ooooool0003o0000ooooo`;o
00003_ooool2o`00013ooooo0_l00004ooooo`;o00001?ooool2o`0003gooooo000Looooo`;o0000
;oooool2o`000003ooooool0003o000001Cooooo1?l00006ooooo`;o00000_ooool2o`0000?ooooo
0_l000000ooooooo0000o`000005o`0000;ooooo5_l00004ooooo`;o00003?ooool2o`0001Cooooo
0_l00002ooooo`Co00001?ooool2o`0000;ooooo0_l00008ooooo`;o00002oooool2o`0000Wooooo
0ol00003ooooo`Co00002_ooool2o`0001;ooooo0_l0000:ooooo`;o0000?Oooool001cooooo00?o
0000ooooooooool0Aoooool2o`0000cooooo0ol00002ooooo`?o00001Oooool2o`0000;ooooo6?l0
0002ooooo`;o00001?ooool2o`0000Kooooo0_l0000Hooooo`Ko00000_ooool2o`0000;ooooo0_l0
0008ooooo`;o00002oooool2o`0000Kooooo0ol000000ooooooo0000o`000005ooooo`;o00001_oo
ool2o`000004ooooool0003o0000o`0001;ooooo0_l00007ooooo`;o0000@?ooool001cooooo00?o
0000ooooooooool0;oooool2o`0001Kooooo0_l00005ooooo`;o00001_ooool2o`0000?ooooo0ol0
0003ooooo`?o00001?oooolFo`0000?ooooo0_l00003ooooo`;o00001_ooool2o`0001cooooo0_l0
000@ooooo`;o00002oooool2o`0000Kooooo1_l00004ooooo`Go000000?oooooo`000?l000000ol0
00000ooooooo0000o`000005ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`?o0000@?oo
ool001cooooo00?o0000ooooooooool0;oooool2o`0000oooooo0_l00005ooooo`;o00001Oooool2
o`0000Sooooo0_l00002ooooo`;o00000_ooool3o`0000?ooooo4ol000000ooooooo0000o`000005
ooooo`;o00000_ooool2o`0000Oooooo0_l0000dooooo`;o00002_ooool7o`0000;ooooo0_l00002
ooooo`Go000000?oooooo`000?l000000ol00002ooooo`?o00000oooool2o`0000Gooooo0_l00005
ooooo`;o00001_ooool2o`00047ooooo000Looooo`03o`000?oooooooooo043ooooo0_l00005oooo
o`;o00001?ooool3o`0000Kooooo1?l00002ooooo`?o000000?oooooo`000?l000001?ooool4o`00
0003ooooool0003o000000?o00000_ooool7o`0000cooooo0_l0000mooooo`;o00002_ooool6o`00
00?ooooo0_l00003ooooo`;o00001_ooool3o`000004ooooool0003o0000o`0000cooooo0_l0000;
ooooo`;o00001Oooool2o`0003[ooooo000Looooo`03o`000?oooooooooo04gooooo0ol00006oooo
o`Co000000?oooooo`000?l000000_l000001Ooooooo0000o`000?l0003ooooo00?o00001?ooool;
o`000003ooooool0003o000000cooooo0_l0000mooooo`;o00001oooool2o`0000;ooooo1?l00000
0ooooooo0000o`00000>ooooo`?o00004?ooool2o`0000Sooooo0_l00008ooooo`;o0000>_ooool0
01cooooo00?o0000ooooooooool0AOooool2o`0000Kooooo0ol00004ooooo`;o00000_ooool2o`00
0004ooooool0003o0000o`0000;ooooo2?l000000ooooooo0000o`000002o`0000;ooooo1ol0000;
ooooo`;o000000Coooooo`000?l0003o00002?ooool5o`0002_ooooo0_l00009ooooo`;o000000?o
ooooo`000?l000000_ooool3o`0000;ooooo0_l000000ooooooo0000o`000009ooooo`Co00005_oo
ool2o`0000?ooooo0_l00008ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0<oooool2
o`00013ooooo0_l00006ooooo`?o000000Coooooo`000?l0003ooooo1_l000000ooooooo0000o`00
0006ooooo`Go000000?oooooo`000?l000000_l00004ooooo`;o000000?oooooo`000?l000000ooo
ool2o`0000Kooooo0_l000000ooooooo0000o`000009ooooo`Go00002oooool2o`0001Wooooo0_l0
0003ooooo`;o00001_ooool2o`000003ooooool0003o000000Cooooo0ol00006ooooo`;o00001_oo
ool2o`000003ooooool0003o000000;o00001_ooool2o`0000kooooo0_l0000=ooooo`;o0000>_oo
ool001cooooo00?o0000ooooooooool0<?ooool2o`000003ooooool0003o000001Sooooo0_l00002
ooooo`;o000000?oooooo`000?l000000ol00002ooooo`;o00001_ooool9o`0000Gooooo0_l00000
0ooooooo0000o`000003ooooo`;o00009?ooool2o`0001Wooooo0_l00005ooooo`;o00001?ooool7
o`000004ooooool0003o0000o`0000oooooo1ol00003ooooo`;o000000Coooooo`000?l0003o0000
1Oooool2o`00057ooooo000Looooo`03o`000?oooooooooo033ooooo0_l0000@ooooo`;o00002Ooo
ool2o`0000Cooooo1ol00009ooooo`Oo00007Oooool2o`0000Kooooo0_l000001?oooooo0000o`00
0?l0000>ooooo`;o00005Oooool2o`0000Gooooo0_l00004ooooo`Oo000000?oooooo`000?l00000
4?ooool6o`0000Cooooo0_l00002ooooo`;o00001Oooool2o`0000_ooooo0_l00003ooooo`;o0000
1?ooool2o`0003Wooooo000Looooo`03o`000?oooooooooo02gooooo0_l0000Cooooo`;o00003Ooo
ool4o`000003ooooool0003o000000;o00001_ooool2o`0000Cooooo1Ol00002ooooo`;o00001ooo
ool2o`0000oooooo0_l00006ooooo`So00003?ooool2o`0000Oooooo0_l00002ooooo`;o0000;ooo
ool6o`000003ooooool0003o000000_ooooo0_l0000<ooooo`;o00000oooool2o`0000Cooooo0_l0
000iooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o000000?oooooo`000?l000007?ooool2
o`000003ooooool0003o000000?ooooo1?l00006ooooo`;o00001?ooool6o`000003ooooool0003o
000000?ooooo0_l00002ooooo`?o00002Oooool2o`0000cooooo0_l000000ooooooo0000o`000002
o`0001?ooooo1?l00002ooooo`;o00005?ooool2o`0000[ooooo0_l00009ooooo`;o000000?ooooo
o`000?l000000oooool2o`000004ooooool0003o0000ooooo`;o00000_ooool4o`0000;ooooo0_l0
001Booooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00006?ooool2o`0000;ooooo0_l00006
ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`0000Oooooo0ol00002ooooo`;o00000_oo
ool2o`0000;ooooo0ol00004ooooo`?o00000_ooool2o`00013ooooo0ol0000Cooooo`;o00006Ooo
ool3o`000003ooooool0003o000000Co00000oooool2o`0000Sooooo0ol000000ooooooo0000o`00
0002o`000003ooooool0003o000000Cooooo0ol000000ooooooo0000o`000005o`0005?ooooo000L
ooooo`03o`000?oooooooooo037ooooo0_l0000;ooooo`;o00002_ooool3o`0000;ooooo0_l00008
ooooo`Go00002oooool2o`0000?ooooo0ol0000<ooooo`?o000000Coooooo`000?l0003o00003_oo
ool2o`000004ooooool0003o0000ooooo`;o00008Oooool2o`0000Sooooo0ol000000ooooooo0000
o`000004o`0000gooooo0_l00004ooooo`;o000000?oooooo`000?l000001Oooool3o`0000;ooooo
1Ol0001Cooooo`007?ooool00ol0003oooooooooo`0_ooooo`Co00002oooool2o`0000_ooooo0_l0
0002ooooo`;o000000?oooooo`000?l000001oooool3o`0000Oooooo0_l00008ooooo`Co00003_oo
ool3o`0000Cooooo0_l00008ooooo`;o00001?ooool4o`000003ooooool0003o000000?ooooo0_l0
000Fooooo`?o00002Oooool2o`0000Oooooo0_l0000=ooooo`;o00000_ooool2o`0000Wooooo0_l0
0002ooooo`;o000000?oooooo`000?l000000_l00003ooooo`?o00004oooool2o`0003Kooooo000L
ooooo`03o`000?oooooooooo02oooooo0_l0000Qooooo`;o00000_ooool2o`0000Cooooo0_l00004
ooooo`;o000000Coooooo`000?l0003ooooo0_l00005ooooo`Ko00003Oooool2o`0000Cooooo0_l0
000@ooooo`Go00000oooool2o`0001Kooooo0_l0000:ooooo`;o00001oooool2o`0000?ooooo0_l0
0006ooooo`Co00004Oooool2o`000003ooooool0003o000000So00003?ooool2o`0000;ooooo0_l0
00000ooooooo0000o`00000fooooo`007?ooool2o`0003cooooo0_l0000Iooooo`;o00001?ooool4
o`0000;ooooo0_l00003ooooo`?o000000?oooooo`000?l000000_ooool6o`0000?ooooo0_l00002
ooooo`;o00001?ooool2o`0000Cooooo0ol0000=ooooo`;o00000_ooool4o`0000Oooooo0_l0000@
ooooo`;o000000?oooooo`000?l000002?ooool2o`0000?ooooo1?l00003ooooo`Co00001_ooool2
o`0001Oooooo1ol0000>ooooo`;o00000_ooool2o`0003Wooooo000Looooo`03o`000?oooooooooo
033ooooo0_l00009ooooo`Co00007Oooool=o`0000;ooooo0_l0000;ooooo`;o00000_ooool2o`00
00Cooooo0_l00005ooooo`?o00003?ooool2o`0000;ooooo1?l000000ooooooo0000o`000006o`00
013ooooo0_l000001?oooooo0000o`000?l00005ooooo`Co00000oooool4o`0000?ooooo0_l0000S
ooooo`;o00002_ooool2o`0000Gooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0`oooo
o`;o00002_ooool3o`0001Oooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo1ol0000A
ooooo`;o00002?ooool3o`0000Gooooo0_l0000>ooooo`Ko000000?oooooo`000?l000001_l00000
0ooooooo0000o`00000Aooooo`Co00000oooool2o`0000Kooooo0_l00004ooooo`;o0000;oooool2
o`000003ooooool0003o000000Co0000?Oooool001cooooo00?o0000ooooooooool0>_ooool2o`00
01[ooooo0_l000000ooooooo0000o`00000:ooooo`;o00002Oooool4o`0000Cooooo0_l00005oooo
o`;o000000Coooooo`000?l0003o00000_ooool2o`000003ooooool0003o000000kooooo1Ol00005
ooooo`[o000000?oooooo`000?l000003?ooool4o`0000Gooooo0_l00004ooooo`?o00002oooool2
o`0001;ooooo0ol0000Eooooo`Co0000?oooool001cooooo00?o0000ooooooooool0;oooool2o`00
00Wooooo1?l0000Jooooo`;o00004_ooool2o`0000;ooooo1?l0000;ooooo`;o00001_ooool2o`00
0003ooooool0003o000000gooooo0_l00002ooooo`;o00000_ooool5o`0000?ooooo3?l00003oooo
o`;o000000?oooooo`000?l000000_l00005ooooo`Co00001Oooool2o`0000?ooooo0_l00006oooo
o`;o00001?ooool3o`0000_ooooo0ol0000Eooooo`Go0000?_ooool001cooooo00?o0000oooooooo
ool0;oooool2o`0000_ooooo0_l0000Jooooo`;o00001_ooool2o`0000?ooooo0_l00005ooooo`?o
00001Oooool2o`0000Kooooo0_l0000Kooooo`?o000000?oooooo`000?l000001_l00006ooooo`co
000000?oooooo`000?l000000ol00003ooooo`;o00000_ooool2o`0000cooooo0_l0000;ooooo`Co
00000oooool2o`000003ooooool0003o000000;ooooo1?l0000Aooooo`;o00000oooool4o`0003ko
oooo000Looooo`03o`000?oooooooooo02oooooo0_l0000;ooooo`;o00007?ooool2o`0000Cooooo
0_l00003ooooo`;o00001_ooool2o`0000Gooooo0_l00006ooooo`;o00007?ooool2o`000003oooo
ool0003o000000;o00001?ooool2o`0000Cooooo4ol000001?oooooo0000o`000?l0000Eooooo`Co
00001?ooool4o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o00001_ooool2o`0000_o
oooo0_l00015ooooo`007?ooool00ol0003oooooooooo`0looooo`;o00007?ooool2o`0000gooooo
0_l00004ooooo`?o00003?ooool3o`0000_ooooo0_l0000<ooooo`;o000000?oooooo`000?l00000
0ol00003ooooo`Go000000Coooooo`000?l0003o00001oooool9o`000003ooooool0003o000000So
oooo0_l00008ooooo`;o00000_ooool5o`0000Gooooo0_l0000=ooooo`;o00000oooool2o`0005;o
oooo000Looooo`03o`000?oooooooooo04;ooooo0_l0000Nooooo`;o00001?ooool3o`000004oooo
ool0003o0000ooooo`Co00002oooool3o`0000[ooooo0ol0000Booooo`;o00000_ooool2o`000004
ooooool0003o0000o`0000Cooooo0_l00005ooooo`Ko00001?ooool2o`0000Sooooo0_l00007oooo
o`?o00001Oooool2o`0000cooooo0_l00006ooooo`;o00002Oooool2o`0004cooooo000Looooo`03
o`000?oooooooooo02oooooo0_l0000@ooooo`?o000000?oooooo`000?l000006oooool2o`0000Co
oooo0_l00002ooooo`;o000000?oooooo`000?l000001Ol00005ooooo`;o000000?oooooo`000?l0
00000_l000000ooooooo0000o`000006ooooo`;o00004?ooool2o`0000Gooooo0_l00008ooooo`;o
00001Oooool2o`000003ooooool0003o000001Sooooo0_l0000Dooooo`;o00002_ooool2o`0000Go
oooo0_l000000ooooooo0000o`000019ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o0000
3?ooool2o`0000;ooooo0_l00002ooooo`;o00007_ooool2o`0000Sooooo0_l00002ooooo`?o0000
1?ooool;o`0000Sooooo0_l00007ooooo`;o00001Oooool3o`0000Cooooo0_l00002ooooo`Co0000
2Oooool5o`0001oooooo0_l0000Gooooo`Co000000?oooooo`000?l000000_ooool2o`000003oooo
ool0003o000000Cooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00002ooo
ool2o`0000Gooooo0_l0000Oooooo`;o00002?ooool4o`0000Kooooo3?l00008ooooo`;o00001ooo
ool4o`0000Cooooo0_l00004ooooo`;o00000_ooool6o`0000Wooooo0_l0000Aooooo`;o00000ooo
ool2o`000003ooooool0003o000000;o00000oooool2o`0001Oooooo0_l00003ooooo`?o000000?o
ooooo`000?l000000_l00005ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0<?ooool2
o`00017ooooo0ol0000Yooooo`Co00000oooool2o`000003ooooool0003o000000So00002Oooool2
o`0000[ooooo0_l000000ooooooo0000o`000007ooooo`;o00000_ooool8o`0001[ooooo0_l00003
ooooo`;o000000?oooooo`000?l000000_l0000:ooooo`;o00000_ooool3o`0000Gooooo0_l0000:
ooooo`?o00000_ooool2o`0004[ooooo000Looooo`03o`000?oooooooooo04?ooooo0_l0000_oooo
o`oo00002Oooool2o`0000gooooo1?l0000;ooooo`?o000000?oooooo`000?l000004Oooool2o`00
00Kooooo0_l0000@ooooo`?o000000?oooooo`000?l000002?l00003ooooo`;o00002oooool2o`00
00;ooooo0_l00005ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0Koooool7o`000003
ooooool0003o000000[o00003Oooool2o`0000_ooooo0_l00002ooooo`?o00000oooool2o`0001So
oooo0_l00006ooooo`;o00004?oooolAo`0000Sooooo0_l00003ooooo`;o00002Oooool2o`0004?o
oooo000Looooo`03o`000?oooooooooo03gooooo0ol0000_ooooo`Go00001?ooool;o`0000gooooo
0_l0000;ooooo`;o00000_ooool5o`000003ooooool0003o000001;ooooo0_l0000Cooooo`;o0000
2Oooool2o`000003ooooool0003o000000Oo000000?oooooo`000?l000000_l00002ooooo`;o0000
1?ooool2o`0000?ooooo0_l0001>ooooo`007?ooool2o`0003gooooo1Ol0000Pooooo`;o00003Ooo
ool3o`0000;ooooo0_l000000ooooooo0000o`00000:o`0001Kooooo1_l00003ooooo`?o00005Ooo
ool2o`0000?ooooo0_l0000>ooooo`;o00002_oooolDo`0005Wooooo000Looooo`03o`000?oooooo
oooo03cooooo1Ol0000Pooooo`Co00003?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000;
o`0000gooooo0_l00006ooooo`Ko00001Oooool2o`0001Sooooo1?l0000Hoooooa?o00002_ooool5
o`0000Gooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`0looooo`?o00009?ooool2o`00
00cooooo0_l00002ooooo`;o000000?oooooo`000?l000002ol00006ooooo`;o00000_ooool2o`00
0003ooooool0003o000000;o00001_ooool2o`0000;ooooo0_l00003ooooo`;o00004_ooool2o`00
00Cooooo1?l0000HoooooaWo00001?ooool5o`0000Gooooo0_l00015ooooo`007?ooool00ol0003o
ooooooooo`0booooo`;o00003_ooool2o`0002gooooo0_l000001?oooooo0000o`000?ooool=o`00
00Oooooo0_l00002ooooo`;o00000_ooool3o`000004ooooool0003o0000ooooo`;o00001?ooool2
o`0001Oooooo0_l0000QoooooaSo00003?ooool2o`0000?ooooo0_l00012ooooo`007?ooool00ol0
003oooooooooo`0booooo`;o00003_ooool2o`0002Cooooo0_l0000:ooooo`;o000000?oooooo`00
0?l000003?l0000Booooo`Go000000Goooooo`000?l0003o0000ooooo`02o`0000Kooooo0_l0000H
ooooo`;o00004Oooool2o`0000Cooooo5ol00003ooooo`;o00001?ooool2o`0000;ooooo0_l00003
ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0A?ooool2o`0002;ooooo0ol00009oooo
o`?o000000?oooooo`000?l000003?l0000>ooooo`?o000000?oooooo`000?l000000oooool3o`00
0003ooooool0003o000000Kooooo0_l0000Hooooo`;o00002oooool2o`0000Cooooo0ol00003oooo
oaSo000000?oooooo`000?l000000_l00003ooooo`;o00000_ooool2o`0004Oooooo000Looooo`03
o`000?oooooooooo04?ooooo0ol0000@ooooo`Go00001Oooool4o`0000Gooooo0_l00004ooooo`So
00001?ooool7o`000004ooooool0003o0000o`0000kooooo0ol00003ooooo`?o000000?oooooo`00
0?l000002Oooool2o`0002Gooooo0_l00005ooooo`;o00000ooooolBo`000003ooooool0003o0000
00?o000000?oooooo`000?l000000_l00003ooooo`;o00001Oooool2o`000003ooooool0003o0000
047ooooo000Looooo`03o`000?oooooooooo03cooooo0_l00002ooooo`;o000000?oooooo`000?l0
00004Oooool5o`0000Gooooo1?l0000;ooooo`Go00001_ooool8o`000003ooooool0003o0000013o
oooo0_l00003ooooo`?o00001Oooool2o`0000;ooooo1?l00002ooooo`;o00004oooool2o`0001co
oooo2_l000000ooooooo0000o`000006o`0000?ooooo0ol00002ooooo`;o00001oooool5o`00047o
oooo000Looooo`03o`000?oooooooooo03cooooo0_l00002ooooo`;o0000=oooool7o`0001Gooooo
0_l00003ooooo`?o00001Oooool8o`0000;ooooo0_l0000Cooooo`;o00001?ooool2o`0000[ooooo
0_l00004ooooo`;o00000_oooolFo`0000;ooooo0_l00003ooooo`;o00002Oooool2o`0004;ooooo
000Looooo`03o`000?oooooooooo03;ooooo0_l0000gooooo`?o00001oooool2o`000005ooooool0
003o0000o`000?ooool01?l0000=ooooo`;o00002oooool4o`0000Gooooo1ol0000Mooooo`;o0000
2_ooool2o`0000?ooooo0ol000000ooooooo0000o`00000Ao`000003ooooool0003o000000Oo0000
D?ooool001cooooo00?o0000ooooooooool0<_ooool2o`0000[ooooo1?l00006ooooo`;o00008Ooo
ool3o`0000Oooooo0_l000000ooooooo0000o`00000Aooooo`Co00001Oooool4o`0000Cooooo0_l0
0005ooooo`Go00000oooool2o`0001kooooo0_l0000;ooooo`;o00000_oooolJo`000003ooooool0
003o000000;o0000C_ooool001cooooo00?o0000ooooooooool0<_ooool2o`0000[ooooo1?l00000
0ooooooo0000o`000003ooooo`;o00006_ooool2o`0001Oooooo1Ol000001?oooooo0000o`000?oo
ool2o`0000?ooooo0ol00006ooooo`Co00001Oooool2o`0000Gooooo0ol00002ooooo`Co00003Ooo
ool3o`0000kooooo0_l00008ooooo`;o00000_oooolLo`0000Cooooo0_l0001>ooooo`007?ooool0
0ol0003oooooooooo`0booooo`?o00003_ooool2o`0000;ooooo0_l0000>ooooo`;o00002oooool2
o`00013ooooo0_l00005ooooo`Go000000Coooooo`000?l0003ooooo0_l00004ooooo`;o00003ooo
ool2o`0000Kooooo0_l00002ooooo`;o00003oooool3o`0000?ooooo0_l0000Cooooo`?o000000?o
ooooo`000?l000004?l000000ooooooo0000o`000008o`0000?ooooo0_l00004ooooo`;o0000B?oo
ool001cooooo00?o0000ooooooooool0<oooool2o`0000[ooooo0_l00006ooooo`;o00003_ooool2
o`0000[ooooo0ol0000@ooooo`?o000000?oooooo`000?l000002?ooool2o`0000Kooooo0_l00002
ooooo`;o00000oooool2o`0000kooooo0_l0000Dooooo`;o00000oooool2o`0000Kooooo0_l00004
ooooo`;o00001Oooool3o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000003ol0
0004ooooo`;o000000?oooooo`000?l000001_ooool2o`0004Sooooo00001_ooooook^k^oc8b<_l0
003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003o
ooooooooo`0cooooo`;o00002_ooool2o`00013ooooo0_l0000@ooooo`?o00004Oooool5o`0000So
oooo0_l00006ooooo`;o00000_ooool2o`0000;ooooo0ol0000=ooooo`;o00000oooool2o`0000;o
oooo0_l0000<ooooo`;o00000oooool2o`0000Kooooo0_l00004ooooo`;o00001_ooool2o`0000Go
oooo4ol00006ooooo`?o0000D?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q
8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo04Gooooo0_l00002
ooooo`;o00001_ooool2o`0002Kooooo0_l000001?oooooo0000o`000?ooool2o`0000Gooooo0_l0
0004ooooo`;o00000_ooool6o`0000;ooooo0_l00003ooooo`;o00001Oooool4o`000003ooooool0
003o000000;ooooo0_l0000Iooooo`;o00003?ooool2o`0000Cooooo0ol000000ooooooo0000o`00
0002ooooo`_o00001oooool2o`00057ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooo
oooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo04Gooooo0ol0
00000ooooooo0000o`00000Qooooo`;o00003_ooool5o`0000Gooooo0_l00006ooooo`;o00000_oo
ool2o`0000Cooooo0_l00003ooooo`Go00000_ooool5o`0000[ooooo0_l0000Wooooo`;o00001_oo
ool9o`0000Gooooo0ol000000ooooooo0000o`00001Aooooo`0000?oooooo`000?ooool00_ooool0
0ol0003oooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0004Kooooo0_l0
000Dooooo`;o00003_ooool2o`0000Wooooo0_l000001?oooooo0000o`000?ooool2o`0000oooooo
0_l00009ooooo`;o000000?oooooo`000?l000002ol0000:ooooo`;o00002?ooool2o`0001Oooooo
0ol00009ooooo`So000000?oooooo`000?l000001Oooool3o`000003ooooool0003o0000057ooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oeEEEOl0003o410@
olc<c006ooooo`03o`000?oooooooooo03;ooooo0_l0000Booooo`Co00004_ooool2o`000004oooo
ool0003o0000o`0001Gooooo0_l000000ooooooo0000o`00000=ooooo`Co00000_ooool2o`0000So
oooo1Ol00002ooooo`Co00000_ooool3o`00013ooooo0_l00002ooooo`?o00002?ooool3o`0000_o
oooo0ol00009ooooo`?o00000oooool2o`0000Oooooo0_l00007ooooo`;o0000COooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`00
0?oooooooooo03;ooooo0_l0000Dooooo`Co00000_ooool4o`0000Cooooo3?l00008ooooo`;o0000
1_ooool2o`00017ooooo0_l00002ooooo`Co00000_ooool2o`0000Oooooo1Ol00005ooooo`Oo0000
4?ooool3o`0000;ooooo0_l00007ooooo`Go00000_ooool2o`0000?ooooo0_l00005ooooo`;o0000
3?ooool2o`0000Cooooo0_l000000ooooooo0000o`000007ooooo`;o0000COooool00006oooooomg
MgOoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo04[o
oooo0_l000000ooooooo0000o`000003o`000004ooooool0003o0000ooooo`go00000_ooool2o`00
00?ooooo0_l000000ooooooo0000o`000003ooooo`;o00000_ooool2o`000003ooooool0003o0000
00[ooooo0_l00003ooooo`;o00003?ooool4o`0000Oooooo1ol00008ooooo`;o00001Oooool3o`00
00_ooooo1Ol00002ooooo`;o00000oooool2o`0000Gooooo0ol0000Aooooo`;o00000oooool2o`00
05Cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_oo
ool00ol0003oooooooooo`1=ooooo`;o00001?ooool2o`0000Wooooo1Ol00002ooooo`;o00000_oo
ool2o`0000;ooooo0_l00002ooooo`;o00000oooool5o`0000Kooooo0ol00005ooooo`Co00004_oo
ool2o`0000Cooooo1Ol00008ooooo`;o00000_ooool2o`0000kooooo0_l00006ooooo`;o00000ooo
ool2o`0000Kooooo0_l0000Booooo`Ko0000E?ooool001cooooo00?o0000ooooooooool0=_ooool2
o`0001Gooooo0_l00002ooooo`;o00003Oooool3o`0000;ooooo0_l00002ooooo`;o00001_ooool2
o`0000;ooooo2Ol00003ooooo`Go00000oooool5o`0000Cooooo0_l00005ooooo`;o00001?ooool2
o`0000Cooooo2?l00009ooooo`;o00003Oooool3o`0000_ooooo0_l00009ooooo`;o00000oooool2
o`0000[ooooo1?l0001Fooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00004?ooool2o`00
00?ooooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo0_l00004ooooo`Co00000_ooool2o`00
00gooooo0_l000000ooooooo0000o`000006o`0000Cooooo0_l00005ooooo`?o00001?ooool2o`00
00Cooooo0ol0000;ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`00000Eoooo
o`;o00005oooool2o`0000?ooooo1?l00004ooooo`;o0000G?ooool001cooooo00?o0000oooooooo
ool0=oooool2o`0000oooooo0ol00009ooooo`?o000000?oooooo`000?l000000_l00003ooooo`;o
000000Coooooo`000?l0003ooooo0ol00004ooooo`;o00000_ooool2o`0000Kooooo1Ol000001?oo
oooo0000o`000?l0000:ooooo`;o00002oooool2o`0001Cooooo0_l00002ooooo`Go00007_ooool2
o`0000Oooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000ol0001L
ooooo`007?ooool00ol0003oooooooooo`0gooooo`;o000000?oooooo`000?l000003Oooool2o`00
00Wooooo0_l00002ooooo`Wo00001?ooool2o`0000Gooooo0_l00002ooooo`;o00001Oooool6o`00
00;ooooo0_l00003ooooo`;o00001Oooool2o`0000_ooooo0_l0000Hooooo`Ko00000_ooool2o`00
00Oooooo1?l00006ooooo`;o00001Oooool3o`0000[ooooo0_l00005ooooo`Co0000GOooool001co
oooo00?o0000ooooooooool0=oooool2o`000003ooooool0003o000001_ooooo0_l000000ooooooo
0000o`000003o`0000Gooooo0ol000000ooooooo0000o`00000=ooooo`Ko000000?oooooo`000?l0
00001?ooool2o`0000Cooooo0_l0000:ooooo`Co000000?oooooo`000?l000006Oooool2o`0000;o
oooo0_l00007ooooo`Co00000_ooool2o`0000;ooooo0_l00005ooooo`;o0000Loooool001cooooo
00?o0000ooooooooool0=oooool2o`0000;ooooo0_l0000?ooooo`;o00002Oooool2o`0000;ooooo
1Ol00002ooooo`Co00000_ooool2o`0000Cooooo0_l00003ooooo`?o00000_ooool8o`000004oooo
ool0003o0000ooooo`;o00001?ooool2o`0000[ooooo0ol00002ooooo`;o0000;?ooool2o`0007ko
oooo000Looooo`03o`000?oooooooooo03Oooooo0_l000001?oooooo0000o`000?l0000?ooooo`;o
00003Oooool2o`000005ooooool0003o0000o`000?ooool00_l0000:ooooo`;o00000oooool3o`00
00;ooooo1?l000000ooooooo0000o`000004o`000003ooooool0003o000000cooooo0_l00003oooo
o`;o0000/?ooool001cooooo00?o0000ooooooooool0>_ooool3o`0001kooooo0_l000001?oooooo
0000o`000?l0000Aooooo`oo000000?oooooo`000?l000002Oooool2o`0000?ooooo1?l000001?oo
oooo0000o`000?ooool2o`0000Kooooo0_l0000?ooooo`;o00005Oooool2o`0007gooooo000Loooo
o`03o`000?oooooooooo05_ooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00000
0ooooooo0000o`000007oooooa3o000000?oooooo`000?l000001Oooool2o`0000;ooooo0ol00002
ooooo`Co00001?ooool2o`0000Kooooo1Ol000000ooooooo0000o`000004ooooo`?o00000_ooool3
o`0000?ooooo0_l0000?ooooo`;o0000OOooool001cooooo00?o0000ooooooooool0GOooool7o`00
0004ooooool0003o0000ooooo`;o00001ooooolBo`0000Kooooo0_l00003ooooo`;o00000_ooool4
o`0000;ooooo0_l00006ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000004
ooooo`?o00000_ooool3o`0000?ooooo0_l00002ooooo`;o00005oooool4o`0006oooooo000Loooo
o`03o`000?oooooooooo03Wooooo0_l0000Rooooo`Co000000?oooooo`000?l000002_ooool2o`00
0003ooooool0003o0000013o00004Oooool2o`0000;ooooo0_l00006ooooo`;o00003?ooool4o`00
0003ooooool0003o000000Cooooo0_l00002ooooo`;o00005oooool4o`0006oooooo000Looooo`;o
0000>_ooool2o`0001Oooooo0_l00009ooooo`Co00001Oooool2o`0000Kooooo0_l000000ooooooo
0000o`00000Ao`0000Wooooo0_l00005ooooo`;o00000_ooool2o`0000_ooooo0_l00007ooooo`Co
000000?oooooo`000?l000001Oooool2o`0008gooooo000Looooo`03o`000?oooooooooo03gooooo
0ol0000Booooo`;o00004_ooool3o`0000Wooooo5?l00007ooooo`;o00001Oooool2o`000004oooo
ool0003o0000o`0000Oooooo0_l00002ooooo`;o00001Oooool3o`000004ooooool0003o0000oooo
o`;o000000?oooooo`000?l000000_ooool2o`0008gooooo000Looooo`03o`000?oooooooooo03go
oooo0ol0000Pooooo`;o00001Oooool2o`0000Sooooo4_l000000ooooooo0000o`000004ooooo`;o
00002_ooool3o`0000Sooooo0_l00009ooooo`?o000000?oooooo`000?l000001_l00005ooooo`;o
00000oooool2o`0001Oooooo0_l0001/ooooo`007?ooool00ol0003oooooooooo`1Nooooo`Co0000
3_oooolCo`0000Oooooo0_l00002ooooo`Go00000_ooool3o`0001?ooooo1Ol000000ooooooo0000
o`000004o`000004ooooool0003o0000o`0000;ooooo0_l00003ooooo`;o00004Oooool2o`0000Co
oooo0_l0001/ooooo`007?ooool00ol0003oooooooooo`11ooooo`;o00006oooool2o`0000Kooooo
0_l00007oooooaSo00001oooool5o`000003ooooool0003o000000?o00004_ooool<o`000005oooo
ool0003o0000o`000?ooool00ol0000Fooooo`;o00001Oooool2o`0006_ooooo000Looooo`03o`00
0?oooooooooo047ooooo0_l0000Aooooo`;o00001?ooool2o`0000[ooooo0_l00004ooooo`;o0000
00?oooooo`000?l000005_l00003ooooo`;o000000?oooooo`000?l000001Oooool2o`000004oooo
ool0003o0000ooooo`Co00003_ooool;o`000003ooooool0003o000000Co00007_ooool3o`0000?o
oooo0_l0001Uooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o00001?ooool2o`0000?ooooo
0_l00008ooooo`;o000000Coooooo`000?l0003ooooo5_l00005ooooo`;o000000Coooooo`000?l0
003o00002_ooool4o`0000[ooooo0_l00002oooooaOo00006_ooool2o`0000?ooooo0_l0001Uoooo
o`007?ooool00ol0003oooooooooo`1Oooooo`;o00000oooool4o`000004ooooool0003o0000oooo
oaWo00002Oooool2o`0000_ooooo0_l0000;ooooo`;o00000_ooool3o`000003ooooool0003o0000
017o000000?oooooo`000?l000001Oooool2o`0000Gooooo0_l0001eooooo`007?ooool00ol0003o
ooooooooo`1Pooooo`;o00000_ooool4o`000003ooooool0003o000000?ooooo5ol00009ooooo`?o
00002_ooool2o`0000gooooo5ol00003ooooo`;o00001Oooool2o`0000Gooooo0_l0001eooooo`00
7?ooool00ol0003oooooooooo`15ooooo`?o00006?ooool2o`0000;ooooo0_l00003ooooo`;o0000
1?oooolFo`0000[ooooo0_l00004ooooo`?o00004_oooolHo`0000;ooooo0_l00005ooooo`Co0000
@?ooool2o`0003Sooooo000Looooo`03o`000?oooooooooo04Gooooo0ol0000=ooooo`;o00001?oo
ool2o`0000Oooooo0_l00007oooooaSo00001?ooool2o`0000Cooooo0_l00004ooooo`?o00004_oo
oolKo`0000Cooooo0_l00002ooooo`;o00003_ooool2o`00033ooooo0_l0000hooooo`007?ooool0
0ol0003oooooooooo`1Eooooo`?o00000oooool2o`0000kooooo6_l00003ooooo`?o000000?ooooo
o`000?l000001_ooool2o`000003ooooool0003o000000;ooooo0_l00008ooooo`;o00000_oooolL
o`0000?ooooo0ol00002ooooo`;o00000oooool2o`0000Wooooo0_l0001Zooooo`007?ooool00ol0
003oooooooooo`1Fooooo`;o00004oooool2o`000003ooooool0003o000001Go00000oooool2o`00
00;ooooo0_l00006ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00004oooo
o`?o000000?oooooo`000?l000005ol00006ooooo`;o00000_ooool3o`0000?ooooo0_l0000<oooo
o`;o00000oooool2o`0002Kooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`1]oooooaOo
00004?ooool2o`000003ooooool0003o000000Kooooo0ol00004ooooo`;o000000?oooooo`000?l0
00005ol00002ooooo`;o00000_ooool2o`0000;ooooo0ol0000Aooooo`;o00000oooool2o`0002Ko
oooo0_l0000jooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o00002_ooool2o`0000Kooooo
0ol00008oooooa[o00002?ooool4o`0000Oooooo0_l00005ooooo`Co00001?ooool2o`0000;ooooo
5_l000000ooooooo0000o`000004o`000003ooooool0003o000000Oooooo0_l0001fooooo`007?oo
ool00ol0003oooooooooo`1;ooooo`;o00002_ooool2o`0000Kooooo0ol00008oooooaKo00003?oo
ool4o`0000kooooo0_l000000ooooooo0000o`000003oooooa[o000000?oooooo`000?l000001?l0
000:ooooo`;o00004oooool2o`00067ooooo000Looooo`;o0000JooooolFo`0000Oooooo0_l0000H
ooooo`;o00000ooooolIo`0000;ooooo0_l00008ooooo`;o00006Oooool2o`00067ooooo000Loooo
o`03o`000?oooooooooo04gooooo0_l0000Fooooo`;o00001_ooool2o`000003ooooool0003o0000
00ko00000_ooool2o`0000?ooooo0_l0000Gooooo`;o00001?oooolMo`0000Sooooo0_l0001loooo
o`007?ooool00ol0003oooooooooo`1=ooooo`;o00005_ooool2o`0000Oooooo1ol000000ooooooo
0000o`000008o`0000;ooooo1Ol0000Iooooo`;o00001ooooolKo`0000?ooooo0_l00020ooooo`00
7?ooool00ol0003oooooooooo`1Iooooo`;o00001_ooool2o`0000_ooooo0_l00002ooooo`?o0000
00?oooooo`000?l000000ol00002ooooo`;o00001?ooool4o`0002;ooooo6ol00003ooooo`;o0000
1?ooool2o`0007[ooooo000Looooo`03o`000?oooooooooo05Wooooo0_l00006ooooo`;o00002ooo
ool2o`0000;ooooo1ol0000Dooooo`;o00006_ooool6o`000003ooooool0003o000000[o00000_oo
ool6o`0000Wooooo0_l0001jooooo`007?ooool00ol0003oooooooooo`1Qooooo`;o00001oooool2
o`0000;ooooo0_l00003ooooo`Ko00005?ooool2o`0000kooooo0_l0000:oooooa?o00000_ooool7
o`0008Cooooo000Looooo`03o`000?oooooooooo053ooooo0_l0000Eooooo`Go00000_ooool2o`00
00;ooooo0_l000000ooooooo0000o`00000Gooooo`;o00003Oooool2o`0000cooooo3?l000000ooo
oooo0000o`00000<o`0008?ooooo000Looooo`03o`000?oooooooooo053ooooo0_l0000Eooooo`Co
00001oooool2o`0001[ooooo0_l0000Looooo`Wo00000_ooool<o`000003ooooool0003o000008?o
oooo000Looooo`03o`000?oooooooooo057ooooo0_l0000Dooooo`Ko00001_ooool2o`0003Oooooo
2Ol000000ooooooo0000o`00000;o`000003ooooool0003o000008?ooooo000Looooo`03o`000?oo
oooooooo057ooooo0_l0000Hooooo`;o00001?ooool5o`000003ooooool0003o000003?ooooo5_l0
00000ooooooo0000o`000024ooooo`007?ooool00ol0003oooooooooo`1aooooo`Go000000?ooooo
o`000?l000000ol000000ooooooo0000o`000007ooooo`;o00003?ooool2o`0001Kooooo5?l00003
ooooo`;o00001_ooool2o`0003Kooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`1aoooo
o`?o00001?ooool4o`000004ooooool0003o0000o`0000Kooooo0_l00002ooooo`;o00001oooool3
o`0000Sooooo0_l0000=oooooa;o00000_ooool3o`0000;ooooo0_l00003ooooo`;o000000?ooooo
o`000?l00000<oooool2o`0004Cooooo000Looooo`03o`000?oooooooooo05kooooo0_l00008oooo
o`;o00001_ooool5o`0000?ooooo0_l00002ooooo`Co00002_ooool2o`0000Oooooo0_l00009oooo
o`?o00003_ooool8o`000003ooooool0003o000000Go000000?oooooo`000?l000000_l00002oooo
o`;o00001_ooool2o`0007Wooooo000Looooo`03o`000?oooooooooo05Cooooo0_l00008ooooo`;o
00002?ooool2o`0000Gooooo0ol000000ooooooo0000o`000007ooooo`;o00003?ooool2o`0001?o
oooo0_l00008ooooo`;o00001oooool=o`000003ooooool0003o000008Oooooo000Looooo`03o`00
0?oooooooooo05Cooooo0_l00009ooooo`;o00000oooool2o`0000Wooooo0_l0000Wooooo`;o0000
3oooool2o`0000Oooooo3Ol000000ooooooo0000o`000027ooooo`007?ooool00ol0003ooooooooo
o`1Oooooo`;o00000oooool2o`0000Sooooo1Ol0000Kooooo`Co00001_ooool2o`0001Sooooo0_l0
00000ooooooo0000o`000007o`0000Gooooo0_l00003ooooo`;o00001Oooool2o`0001[ooooo0_l0
001Looooo`007?ooool2o`0005Oooooo0_l00008ooooo`;o00001?ooool2o`000003ooooool0003o
000000?ooooo1Ol00002ooooo`Go00001oooool2o`0000_ooooo1?l0000Jooooo`;o00002?ooool2
o`000003ooooool0003o000000;o00001Oooool5o`000004ooooool0003o0000ooooo`;o000000Co
ooooo`000?l0003o00006Oooool3o`0005cooooo000Looooo`03o`000?oooooooooo05Kooooo0_l0
0008ooooo`;o00001?ooool2o`000003ooooool0003o000000[ooooo1Ol00007ooooo`;o00002Ooo
ool2o`0001kooooo0_l0000;ooooo`Co00000_ooool5o`000004ooooool0003o0000ooooo`;o0000
00Coooooo`000?l0003ooooo0_l0000Jooooo`;o0000GOooool001cooooo00?o0000ooooooooool0
L_ooool2o`000004ooooool0003o0000ooooo`;o00002oooool5o`0000;ooooo0_l0000[ooooo`;o
000000Coooooo`000?l0003ooooo0ol00006ooooo`Co00006oooool2o`00063ooooo000Looooo`03
o`000?oooooooooo07;ooooo0_l000000ooooooo0000o`000002o`0000cooooo1ol0000]ooooo`;o
000000?oooooo`000?l000002Oooool5o`0001[ooooo0ol0000Booooo`;o0000C?ooool001cooooo
00?o0000ooooooooool0Moooool2o`0000;ooooo0_l00002ooooo`Ko00000_ooool2o`000004oooo
ool0003o0000ooooo`;o0000;_ooool3o`0000Oooooo1?l0000Kooooo`;o00004oooool2o`0004co
oooo000Looooo`03o`000?oooooooooo06Wooooo0_l0000:ooooo`;o00001?ooool2o`0000;ooooo
3?l00002ooooo`;o0000;_ooool5o`0008Oooooo000Looooo`03o`000?oooooooooo06Gooooo0_l0
0002ooooo`;o00000oooool2o`0000Cooooo0ol00009ooooo`;o00000oooool8o`0002?ooooo0_l0
000:ooooo`;o00000_ooool2o`0008Oooooo000Looooo`03o`000?oooooooooo06Gooooo0_l00002
ooooo`;o00000oooool2o`0000Cooooo0_l00005ooooo`;o00001Oooool4o`0000Gooooo0_l0000S
ooooo`?o00002Oooool2o`0008_ooooo000Looooo`03o`000?oooooooooo07Oooooo0_l00002oooo
o`;o00001Oooool4o`0002_ooooo0_l0002Fooooo`007?ooool00ol0003oooooooooo`1gooooo`;o
00001oooool6o`0002_ooooo0_l0000[ooooo`?o0000J?ooool001cooooo00?o0000ooooooooool0
N_ooool3o`0000?ooooo0ol0000=ooooo`;o00008_ooool3o`0002Oooooo0ol0001Xooooo`007?oo
ool00ol0003oooooooooo`1gooooo`;o000000Coooooo`000?l0003o00004oooool2o`0002;ooooo
0ol0000looooo`;o0000E?ooool001cooooo00?o0000ooooooooool0Moooool2o`000003ooooool0
003o000000?ooooo1?l0000hooooo`;o00006oooool2o`0001Wooooo0_l0001Dooooo`007?ooool0
0ol0003oooooooooo`1oooooo`Co0000>?ooool2o`0001Wooooo1?l0001_ooooo`0000Koooooonk^
k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo
00?o0000ooooooooool0Ooooool2o`0004Sooooo0_l00009ooooo`Co00005_ooool2o`0005Wooooo
00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRH
V?lQ8B401_ooool00ol0003oooooooooo`1[ooooo`?o00001oooool2o`0000Oooooo0ol00010oooo
o`;o00001_ooool2o`0000Wooooo0_l0000Hooooo`;o0000FOooool00003ooooool@413ooooo00;o
oooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool0Joooool3o`0000Oooooo0_l00007ooooo`;o0000@Oooool2o`0000Wooooo0_l0001koooo
o`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRH
V?lb<S801_ooool3o`00087ooooo0_l0000jooooo`;o00002?ooool2o`0000?ooooo0_l0001koooo
o`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05olc<c?l0003o0000o`00
0?o<c<`01_ooool00ol0003oooooooooo`1^ooooo`;o00004Oooool2o`0003[ooooo0_l00008oooo
o`;o00008Oooool2o`0005gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wo
oooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo06Oooooo0_l00005oooo
o`;o00003Oooool2o`0004?ooooo0_l0000Vooooo`;o0000GOooool00006oooooomgMgOoV9RHoooo
oonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0Iooo
ool3o`0001?ooooo0_l00010ooooo`;o000000?oooooo`000?l00000QOooool00006ooooooo^k^ko
<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000oooooooo
ool0J?ooool2o`0005Gooooo0_l00028ooooo`007?ooool00ol0003oooooooooo`1oooooo`Go0000
3oooool2o`000;Cooooo000Looooo`03o`000?oooooooooo06[ooooo0_l0000Cooooo`Go00001ooo
ool2o`0000Kooooo0_l0001>ooooo`;o0000I?ooool001cooooo00?o0000ooooooooool0J_ooool2
o`0001oooooo0_l0001Fooooo`;o0000I?ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`2iooooo`Co0000S?ooool001cooooo00?o0000ooooooooool0
^Oooool4o`0001oooooo0_l0001[ooooo`007?ooool00ol0003oooooooooo`26ooooo`;o00000_oo
ool2o`0004kooooo1?l0001[ooooo`007?ooool00ol0003oooooooooo`26ooooo`;o00000_ooool2
o`0002[ooooo0_l0000Rooooo`;o0000KOooool001cooooo00?o0000ooooooooool0]_ooool2o`00
097ooooo000Looooo`03o`000?oooooooooo08[ooooo0_l00008ooooo`;o0000?_ooool2o`0007?o
oooo000Looooo`03o`000?oooooooooo08?ooooo0ol00004ooooo`;o00001Oooool5o`0000;ooooo
0_l0000jooooo`;o0000Loooool001cooooo0_l00024ooooo`?o00002oooool5o`0000;ooooo0_l0
0005ooooo`;o00004oooool2o`0009?ooooo000Looooo`03o`000?oooooooooo09Cooooo0_l00009
ooooo`;o00002?ooool4o`0000Oooooo0_l0002Cooooo`007?ooool00ol0003oooooooooo`28oooo
o`;o00007oooool4o`0009cooooo000Looooo`03o`000?oooooooooo08Sooooo0_l0000Hooooo`;o
0000YOooool001cooooo00?o0000ooooooooool0O?ooool2o`0002Cooooo0_l0000Wooooo`?o0000
Noooool001cooooo00?o0000ooooooooool0O?ooool2o`0002Kooooo2?l0000Oooooo`?o0000Nooo
ool001cooooo00?o0000ooooooooool0Ooooool2o`0002?ooooo2?l0002Mooooo`007?ooool00ol0
003oooooooooo`1oooooo`;o00005Oooool2o`0001Cooooo0_l000000ooooooo0000o`00002Hoooo
o`007?ooool00ol0003oooooooooo`2Fooooo`;o00005?ooool2o`000003ooooool0003o000000Co
oooo0_l0002Booooo`007?ooool00ol0003oooooooooo`23ooooo`;o00005oooool4o`0000?ooooo
0_l0000:ooooo`;o00001?ooool2o`0009;ooooo000Looooo`03o`000?oooooooooo08?ooooo0_l0
000Gooooo`Co00000oooool2o`000:Cooooo000Looooo`03o`000?oooooooooo0<3ooooo0_l00027
ooooo`007?ooool00ol0003oooooooooo`2^ooooo`?o00000oooool2o`0000Sooooo1?l00027oooo
o`007?ooool00ol0003oooooooooo`2^ooooo`?o00000oooool2o`0000Sooooo0_l00029ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo09;ooooo0_l0002eoooo
o`007?ooool00ol0003oooooooooo`2Booooo`;o0000]Oooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`004_ooool4
o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000oooooooo
ool01Oooool3o`000?ooooooB_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?oo
ool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool0
01Cooooo00?o0000ooooooooool0oooooomBooooo`004_ooool00omEEEGoIVIVo`00003ooooooeCo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Uooooo`04oa0@4?l0003o0000
ooooo`;o000000?o410@ooooooooool05oooool2o`000004oa0@4?ooooooooooooooo`Go00000ooo
ool01Oo^k^ko<S8bo`000?l@413oc<c<093ooooo002Vooooo`05o`000?ooooooooooooooool00000
2Oooool6o`0000cooooo00?o0000ooooooooool00_ooool01OnHV9So8B4Qonk^k_ooooooA4A400?o
oooo00GoEEEEogMgMoooooooV9RHob4Q8@2@ooooo`00Y_ooool01Ol0003ooooooooooooooooo0000
01Sooooo1Ol00004ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go0000ooooooooooooooooo`00002@
ooooo`00Y_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l00009ooooo`04odA4A?oMgMgo
ooooo`0000Kooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003oV9RHoooooonHV9So8B4Q093ooooo
002Vooooo`05o`000?n7QhOoooooojVYZOl000006?ooool01?oMgMgoEEEEooooool00007ooooo`03
ogMgMomVIVKooooo00;ooooo00Go0000oeEEEOl0003o410@olc<c02@ooooo`00YOooool00ol@413o
0000ogMgM`02o`000003oiRHV?oooooooooo01Oooooo00?oMgMgolc<c?l000002?ooool01_l0003o
ooooooooooooooooEEEEohN7Qi?ooooo0034ooooo`03onk^k_m4A4Co000000Cooooo00Go0000okZj
^_ooooooV9RHoa0@4003ooooo`03omgMgOl@413oV9RH09;ooooo0035ooooo`03ogMgMol0003ooooo
00?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`04olc<c?m4A4Co0000oa0@493ooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(432) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.36879 .43642 Mdot
.38596 .40607 Mdot
.53179 .67311 Mdot
.60965 .39045 Mdot
.72941 .61959 Mdot
.5562 .71239 Mdot
.34194 .64586 Mdot
.33734 .65034 Mdot
.55292 .72816 Mdot
.36238 .28604 Mdot
.37461 .64612 Mdot
.52058 .41476 Mdot
.35645 .64806 Mdot
.58047 .39168 Mdot
.44809 .45285 Mdot
.63691 .39827 Mdot
.39761 .3836 Mdot
.67369 .59769 Mdot
.63343 .4181 Mdot
.51335 .69826 Mdot
.67781 .30366 Mdot
.56733 .39186 Mdot
.34251 .38831 Mdot
.57736 .39293 Mdot
.58223 .42619 Mdot
.37365 .3936 Mdot
.36266 .43669 Mdot
.57088 .42073 Mdot
.52395 .39141 Mdot
.36993 .65058 Mdot
.56472 .63983 Mdot
.57325 .18097 Mdot
.59798 .34702 Mdot
.5206 .24039 Mdot
.33733 .64291 Mdot
.38008 .586 Mdot
.52167 .70207 Mdot
.39061 .64672 Mdot
.33527 .64209 Mdot
.34823 .62672 Mdot
.36511 .62335 Mdot
.36723 .38972 Mdot
.36995 .61496 Mdot
.43478 .81314 Mdot
.59716 .3986 Mdot
.44006 .43047 Mdot
.36647 .77959 Mdot
.5474 .41546 Mdot
.39591 .39187 Mdot
.51049 .69226 Mdot
.76524 .52688 Mdot
.3727 .67487 Mdot
.38121 .55775 Mdot
.64458 .85931 Mdot
.36601 .63976 Mdot
.60262 .43837 Mdot
.54443 .73972 Mdot
.57314 .36772 Mdot
.61295 .38698 Mdot
.50311 .21607 Mdot
.55427 .376 Mdot
.70195 .58367 Mdot
.38235 .36041 Mdot
.561 .74895 Mdot
.55812 .72559 Mdot
.38966 .64676 Mdot
.34064 .37531 Mdot
.35489 .65888 Mdot
.5251 .37725 Mdot
.51991 .67965 Mdot
.52757 .39784 Mdot
.37199 .65249 Mdot
.33702 .41064 Mdot
.59784 .40295 Mdot
.29905 .58019 Mdot
.31264 .71745 Mdot
.59038 .70722 Mdot
.60809 .24238 Mdot
.80508 .57563 Mdot
.55471 .61246 Mdot
.58259 .40445 Mdot
.67108 .79892 Mdot
.48795 .51711 Mdot
.38592 .4155 Mdot
.30612 .39781 Mdot
.27317 .42993 Mdot
.55415 .41657 Mdot
.50764 .61716 Mdot
.62631 .39836 Mdot
.64078 .5747 Mdot
.53883 .73254 Mdot
.37503 .42246 Mdot
.59403 .40233 Mdot
.55606 .35329 Mdot
.30251 .31768 Mdot
.55069 .43204 Mdot
.60964 .39877 Mdot
.29758 .401 Mdot
.37911 .64545 Mdot
.64373 .34198 Mdot
.74421 .55446 Mdot
.40087 .52706 Mdot
.59173 .43884 Mdot
.53168 .70822 Mdot
.40251 .37075 Mdot
.60979 .41093 Mdot
.34441 .65928 Mdot
.57715 .4012 Mdot
.32792 .63904 Mdot
.36976 .36911 Mdot
.58002 .34723 Mdot
.68518 .60265 Mdot
.67937 .40552 Mdot
.34925 .38559 Mdot
.49469 .32049 Mdot
.55405 .38609 Mdot
.56466 .36397 Mdot
.38848 .40165 Mdot
.52242 .68516 Mdot
.52336 .78253 Mdot
.33925 .39829 Mdot
.34713 .62698 Mdot
.40073 .39159 Mdot
.56877 .45898 Mdot
.51912 .69192 Mdot
.3982 .5447 Mdot
.40236 .53893 Mdot
.69466 .48868 Mdot
.59167 .40677 Mdot
.67089 .43938 Mdot
.54067 .70865 Mdot
.37674 .38835 Mdot
.3622 .65336 Mdot
.60395 .44295 Mdot
.35278 .39544 Mdot
.33525 .65813 Mdot
.72938 .59837 Mdot
.68911 .62348 Mdot
.37415 .37921 Mdot
.45652 .38054 Mdot
.31771 .65265 Mdot
.36316 .61932 Mdot
.76142 .52483 Mdot
.38751 .41425 Mdot
.69708 .59967 Mdot
.34049 .67022 Mdot
.75601 .39732 Mdot
.61342 .37797 Mdot
.72004 .51027 Mdot
.61047 .81533 Mdot
.76499 .52713 Mdot
.56077 .19912 Mdot
.6883 .60295 Mdot
.33482 .6615 Mdot
.53454 .40904 Mdot
.36264 .40622 Mdot
.35746 .39292 Mdot
.54222 .36522 Mdot
.59822 .41766 Mdot
.59289 .38772 Mdot
.61741 .39405 Mdot
.42151 .67743 Mdot
.5895 .40247 Mdot
.19874 .55807 Mdot
.35413 .40478 Mdot
.59717 .42607 Mdot
.53414 .68726 Mdot
.6159 .33274 Mdot
.38353 .62548 Mdot
.61173 .38626 Mdot
.59256 .421 Mdot
.57117 .44756 Mdot
.34046 .63134 Mdot
.27964 .5913 Mdot
.82665 .54382 Mdot
.38003 .59566 Mdot
.29866 .70428 Mdot
.54885 .6999 Mdot
.54559 .38053 Mdot
.71178 .60766 Mdot
.63349 .33768 Mdot
.59901 .36511 Mdot
.77217 .53175 Mdot
.58076 .41409 Mdot
.5861 .21402 Mdot
.5089 .38078 Mdot
.28247 .44462 Mdot
.1963 .50128 Mdot
.60437 .36854 Mdot
.40403 .29159 Mdot
.70333 .51234 Mdot
.60502 .71976 Mdot
.36679 .64991 Mdot
.54822 .68133 Mdot
.5293 .67887 Mdot
.39142 .65287 Mdot
.52973 .31189 Mdot
.38236 .27697 Mdot
.53046 .41365 Mdot
.39966 .53408 Mdot
.32469 .37187 Mdot
.68825 .59859 Mdot
.37753 .38054 Mdot
.70915 .77207 Mdot
.57621 .60452 Mdot
.51514 .61246 Mdot
.66847 .59956 Mdot
.50793 .71097 Mdot
.39292 .54454 Mdot
.70327 .60394 Mdot
.59646 .37707 Mdot
.37818 .37368 Mdot
.71906 .51442 Mdot
.6328 .34367 Mdot
.20179 .3341 Mdot
.35522 .43199 Mdot
.65898 .48536 Mdot
.3641 .64307 Mdot
.57647 .72109 Mdot
.55507 .41709 Mdot
.57355 .37747 Mdot
.34322 .36723 Mdot
.5326 .40108 Mdot
.51058 .58675 Mdot
.59058 .41857 Mdot
.55894 .7488 Mdot
.70049 .64771 Mdot
.38624 .60981 Mdot
.66706 .57994 Mdot
.33653 .40423 Mdot
.27434 .70684 Mdot
.52914 .70072 Mdot
.61436 .31088 Mdot
.36057 .6629 Mdot
.72843 .60354 Mdot
.52576 .7125 Mdot
.67897 .59205 Mdot
.58517 .35034 Mdot
.52034 .70972 Mdot
.69456 .58466 Mdot
.47916 .57186 Mdot
.6112 .40708 Mdot
.71505 .44733 Mdot
.35544 .67899 Mdot
.39017 .4195 Mdot
.58325 .35703 Mdot
.37736 .54939 Mdot
.58966 .45542 Mdot
.60926 .50562 Mdot
.37904 .54559 Mdot
.39073 .51213 Mdot
.52876 .59034 Mdot
.72063 .57765 Mdot
.31328 .60152 Mdot
.4894 .60008 Mdot
.39733 .38304 Mdot
.57741 .35135 Mdot
.35121 .50965 Mdot
.34983 .67998 Mdot
.5908 .37254 Mdot
.32126 .48827 Mdot
.33944 .66945 Mdot
.5724 .36408 Mdot
.36403 .62459 Mdot
.35722 .39888 Mdot
.48703 .54385 Mdot
.40089 .41188 Mdot
.60435 .38119 Mdot
.37026 .62841 Mdot
.54288 .68003 Mdot
.37294 .39398 Mdot
.57196 .39867 Mdot
.56945 .40742 Mdot
.3974 .52882 Mdot
.60287 .40942 Mdot
.29984 .444 Mdot
.55127 .41765 Mdot
.51248 .68275 Mdot
.53389 .41624 Mdot
.74997 .54784 Mdot
.67912 .54791 Mdot
.35605 .36636 Mdot
.37897 .54343 Mdot
.53217 .73203 Mdot
.48191 .55189 Mdot
.698 .44331 Mdot
.58432 .40031 Mdot
.38382 .53198 Mdot
.65149 .49593 Mdot
.38345 .62702 Mdot
.59008 .33934 Mdot
.47636 .67826 Mdot
.53531 .72914 Mdot
.39784 .53927 Mdot
.64534 .35955 Mdot
.33944 .43132 Mdot
.58753 .44095 Mdot
.52312 .70338 Mdot
.39263 .42061 Mdot
.5644 .43962 Mdot
.33579 .74615 Mdot
.37702 .54991 Mdot
.37982 .6348 Mdot
.29754 .41518 Mdot
.54175 .37477 Mdot
.53715 .6754 Mdot
.355 .38938 Mdot
.36011 .63392 Mdot
.34491 .38864 Mdot
.7211 .52016 Mdot
.61532 .4967 Mdot
.42238 .60328 Mdot
.68913 .56525 Mdot
.73873 .26938 Mdot
.37189 .5892 Mdot
.63936 .3382 Mdot
.54448 .65452 Mdot
.231 .38759 Mdot
.52948 .71399 Mdot
.45211 .38504 Mdot
.54167 .73634 Mdot
.56868 .4339 Mdot
.55777 .71656 Mdot
.27164 .32944 Mdot
.56884 .41602 Mdot
.56508 .71869 Mdot
.44705 .6605 Mdot
.56879 .41378 Mdot
.35061 .39644 Mdot
.45652 .16197 Mdot
.56082 .26784 Mdot
.5568 .28077 Mdot
.55018 .74235 Mdot
.44644 .36549 Mdot
.56596 .41983 Mdot
.63058 .42588 Mdot
.36731 .40498 Mdot
.56158 .44587 Mdot
.70937 .56934 Mdot
.68074 .58408 Mdot
.76443 .46505 Mdot
.66236 .26043 Mdot
.52758 .30943 Mdot
.36605 .39412 Mdot
.80568 .59498 Mdot
.29704 .57503 Mdot
.37746 .55137 Mdot
.33611 .65301 Mdot
.28665 .60782 Mdot
.63916 .37349 Mdot
.33292 .33801 Mdot
.50706 .5804 Mdot
.36838 .4276 Mdot
.44199 .59028 Mdot
.3546 .63518 Mdot
.55654 .27751 Mdot
.38558 .25849 Mdot
.59428 .38672 Mdot
.37964 .66273 Mdot
.52648 .4271 Mdot
.50025 .61006 Mdot
.70657 .47537 Mdot
.40958 .75726 Mdot
.60435 .38445 Mdot
.32035 .58479 Mdot
.59533 .36309 Mdot
.69964 .49204 Mdot
.5931 .37161 Mdot
.34537 .39676 Mdot
.61272 .45061 Mdot
.48388 .59599 Mdot
.76422 .32594 Mdot
.5729 .59608 Mdot
.69304 .57813 Mdot
.57861 .38896 Mdot
.58662 .37862 Mdot
.70121 .5816 Mdot
.37005 .42478 Mdot
.57274 .3534 Mdot
.33943 .77827 Mdot
.58923 .40357 Mdot
.37699 .67318 Mdot
.57053 .53369 Mdot
.63146 .2195 Mdot
.54635 .40171 Mdot
.33575 .42641 Mdot
.36879 .62114 Mdot
.35232 .67017 Mdot
.48498 .40152 Mdot
.35974 .67858 Mdot
.5325 .40484 Mdot
.56894 .53362 Mdot
.35154 .37398 Mdot
.51378 .35414 Mdot
.36237 .42689 Mdot
.80177 .60764 Mdot
.33768 .67039 Mdot
.3802 .5317 Mdot
.50436 .32199 Mdot
.34497 .64987 Mdot
.64883 .61387 Mdot
.6141 .44875 Mdot
.59667 .33483 Mdot
.32398 .44338 Mdot
.54538 .678 Mdot
.38392 .54139 Mdot
.36528 .63746 Mdot
.59155 .40052 Mdot
.60063 .4328 Mdot
.36991 .6746 Mdot
.46226 .19442 Mdot
.56744 .64132 Mdot
.60493 .38054 Mdot
.34718 .40821 Mdot
.37374 .38795 Mdot
.62135 .40701 Mdot
.58993 .35918 Mdot
.55959 .69958 Mdot
.38308 .53296 Mdot
.38041 .54098 Mdot
.40323 .53047 Mdot
.56667 .73682 Mdot
.74441 .28175 Mdot
.36432 .61903 Mdot
.58886 .18962 Mdot
.30014 .53055 Mdot
.50439 .43351 Mdot
.52738 .68571 Mdot
.56423 .37618 Mdot
.5794 .43478 Mdot
.37142 .6311 Mdot
.73356 .29831 Mdot
.62234 .43464 Mdot
.37621 .43084 Mdot
.37662 .67059 Mdot
.53353 .42961 Mdot
.31414 .66584 Mdot
.70719 .61709 Mdot
.52505 .30509 Mdot
.36138 .67913 Mdot
.35811 .37199 Mdot
.36211 .67897 Mdot
.58907 .38136 Mdot
.64571 .35843 Mdot
.36679 .42888 Mdot
.70526 .62538 Mdot
.55166 .35879 Mdot
.57579 .36265 Mdot
.5931 .78104 Mdot
.30198 .57993 Mdot
.66225 .57056 Mdot
.55569 .42482 Mdot
.58502 .33123 Mdot
.69263 .62112 Mdot
.55169 .36265 Mdot
.53696 .4186 Mdot
.67619 .43166 Mdot
.33072 .63299 Mdot
.72949 .58321 Mdot
.75819 .32391 Mdot
.35784 .4332 Mdot
.31811 .46176 Mdot
.40134 .53431 Mdot
.39833 .64718 Mdot
.47994 .53674 Mdot
.39259 .53842 Mdot
.30358 .51076 Mdot
.22947 .67193 Mdot
.38516 .53873 Mdot
.56951 .74078 Mdot
.37334 .32466 Mdot
.52759 .40365 Mdot
.59889 .36971 Mdot
.71821 .57659 Mdot
.39233 .4005 Mdot
.2011 .54918 Mdot
.39036 .60974 Mdot
.55989 .3875 Mdot
.36264 .43927 Mdot
.27545 .4354 Mdot
.39657 .5377 Mdot
.70701 .61128 Mdot
.7201 .62389 Mdot
.58845 .36012 Mdot
.68044 .47888 Mdot
.36854 .39241 Mdot
.57197 .39859 Mdot
.55736 .36526 Mdot
.52386 .73019 Mdot
.38048 .37548 Mdot
.53466 .68951 Mdot
.37631 .52803 Mdot
.21589 .38098 Mdot
.4746 .84815 Mdot
.35319 .678 Mdot
.43834 .52035 Mdot
.38855 .61319 Mdot
.36934 .75095 Mdot
.38234 .53428 Mdot
.56976 .39575 Mdot
.3376 .39143 Mdot
.57499 .40071 Mdot
.59123 .40322 Mdot
.60199 .39193 Mdot
.5289 .30818 Mdot
.79687 .59001 Mdot
.72214 .59905 Mdot
.53425 .38703 Mdot
.55288 .74476 Mdot
.30241 .46275 Mdot
.29431 .29382 Mdot
.57876 .38348 Mdot
.56595 .36356 Mdot
.3353 .38233 Mdot
.59705 .35343 Mdot
.33972 .65323 Mdot
.3755 .4274 Mdot
.59957 .43643 Mdot
.7518 .56073 Mdot
.57181 .3545 Mdot
.43666 .53941 Mdot
.34344 .68269 Mdot
.64896 .4154 Mdot
.55476 .34184 Mdot
.38147 .53461 Mdot
.38485 .54157 Mdot
.37226 .53101 Mdot
.3846 .66063 Mdot
.52506 .73039 Mdot
.57105 .74861 Mdot
.55141 .34597 Mdot
.54043 .41396 Mdot
.63334 .34698 Mdot
.5043 .68935 Mdot
.48519 .6155 Mdot
.44938 .39742 Mdot
.51157 .40567 Mdot
.56956 .72512 Mdot
.29715 .40568 Mdot
.64289 .26794 Mdot
.38216 .42394 Mdot
.53787 .65647 Mdot
.3495 .66547 Mdot
.68281 .59584 Mdot
.75686 .49427 Mdot
.34097 .39812 Mdot
.33221 .40416 Mdot
.55649 .70236 Mdot
.54125 .5228 Mdot
.71253 .82175 Mdot
.53656 .71221 Mdot
.51418 .60667 Mdot
.36767 .40115 Mdot
.60857 .35773 Mdot
.64322 .50307 Mdot
.52717 .51426 Mdot
.56305 .72628 Mdot
.5703 .40708 Mdot
.64014 .63235 Mdot
.56001 .70029 Mdot
.62133 .34857 Mdot
.55116 .74285 Mdot
.38202 .64431 Mdot
.53809 .70439 Mdot
.37984 .43957 Mdot
.58614 .40713 Mdot
.66335 .84986 Mdot
.47932 .5139 Mdot
.56259 .39819 Mdot
.36396 .67928 Mdot
.43686 .68468 Mdot
.59378 .38036 Mdot
.6962 .57117 Mdot
.55568 .74584 Mdot
.3901 .75526 Mdot
.55831 .43249 Mdot
.56053 .7141 Mdot
.36303 .44587 Mdot
.51797 .66241 Mdot
.73495 .55039 Mdot
.38205 .54178 Mdot
.35747 .40247 Mdot
.3553 .58249 Mdot
.35714 .6226 Mdot
.62207 .42458 Mdot
.55301 .36943 Mdot
.35308 .40937 Mdot
.47724 .55965 Mdot
.48943 .39281 Mdot
.58381 .40379 Mdot
.54922 .69223 Mdot
.51747 .73281 Mdot
.45028 .44646 Mdot
.52726 .70193 Mdot
.58165 .33112 Mdot
.34969 .40377 Mdot
.59438 .44115 Mdot
.35486 .38524 Mdot
.57466 .35128 Mdot
.31962 .70004 Mdot
.38785 .41823 Mdot
.63974 .3256 Mdot
.58968 .40856 Mdot
.3633 .46388 Mdot
.5408 .37803 Mdot
.60622 .38941 Mdot
.52652 .74222 Mdot
.71148 .59158 Mdot
.59583 .34257 Mdot
.31936 .71968 Mdot
.69678 .61989 Mdot
.51298 .18821 Mdot
.51934 .69214 Mdot
.7283 .61444 Mdot
.75206 .45089 Mdot
.37934 .54398 Mdot
.71137 .58383 Mdot
.39634 .50279 Mdot
.36239 .67522 Mdot
.40791 .41691 Mdot
.57199 .41287 Mdot
.22842 .36767 Mdot
.56102 .63827 Mdot
.39409 .52597 Mdot
.57443 .35773 Mdot
.56784 .37365 Mdot
.36031 .43827 Mdot
.69784 .78054 Mdot
.54072 .75478 Mdot
.612 .40152 Mdot
.33848 .40429 Mdot
.64522 .8087 Mdot
.56583 .71956 Mdot
.7237 .60377 Mdot
.32878 .66249 Mdot
.33735 .36304 Mdot
.37891 .53313 Mdot
.33645 .66803 Mdot
.58602 .69039 Mdot
.77635 .5346 Mdot
.5736 .43781 Mdot
.5305 .68633 Mdot
.7662 .52802 Mdot
.51185 .357 Mdot
.39317 .63827 Mdot
.30021 .68191 Mdot
.37834 .41935 Mdot
.3712 .67405 Mdot
.7114 .57331 Mdot
.38916 .37764 Mdot
.36515 .42724 Mdot
.33967 .6579 Mdot
.19411 .46911 Mdot
.64845 .49672 Mdot
.3712 .68324 Mdot
.60786 .50888 Mdot
.76554 .52877 Mdot
.38671 .5215 Mdot
.70434 .61093 Mdot
.77929 .62445 Mdot
.36934 .39054 Mdot
.28599 .60564 Mdot
.76685 .52747 Mdot
.60976 .39885 Mdot
.69252 .58498 Mdot
.31174 .46525 Mdot
.40559 .64028 Mdot
.33673 .66196 Mdot
.55539 .779 Mdot
.68656 .58751 Mdot
.59738 .35829 Mdot
.66074 .22761 Mdot
.55517 .40692 Mdot
.34303 .6737 Mdot
.50877 .58322 Mdot
.37537 .3737 Mdot
.38176 .62236 Mdot
.51109 .58726 Mdot
.57128 .43292 Mdot
.55256 .38992 Mdot
.74238 .63707 Mdot
.39073 .38282 Mdot
.38011 .52293 Mdot
.57413 .40476 Mdot
.575 .36599 Mdot
.62249 .41973 Mdot
.70823 .30638 Mdot
.67569 .35455 Mdot
.6111 .42021 Mdot
.57505 .70319 Mdot
.63807 .34293 Mdot
.61572 .39024 Mdot
.34253 .43474 Mdot
.7712 .57552 Mdot
.37648 .52626 Mdot
.59675 .36873 Mdot
.60406 .37922 Mdot
.33738 .63934 Mdot
.64928 .49692 Mdot
.52058 .51236 Mdot
.50721 .69707 Mdot
.56689 .76931 Mdot
.51827 .38522 Mdot
.3595 .40995 Mdot
.71838 .57065 Mdot
.53838 .33871 Mdot
.3705 .43243 Mdot
.53533 .36382 Mdot
.54442 .74597 Mdot
.38574 .53466 Mdot
.50836 .35699 Mdot
.70126 .58678 Mdot
.32207 .64267 Mdot
.54494 .19722 Mdot
.54533 .68278 Mdot
.57068 .42532 Mdot
.56586 .75628 Mdot
.5439 .72275 Mdot
.39637 .52542 Mdot
.65316 .36736 Mdot
.35902 .39626 Mdot
.36088 .37291 Mdot
.78632 .5756 Mdot
.56643 .7392 Mdot
.61297 .76286 Mdot
.38166 .65179 Mdot
.53518 .38249 Mdot
.36747 .51009 Mdot
.36611 .3731 Mdot
.69678 .4881 Mdot
.7247 .61989 Mdot
.33768 .66357 Mdot
.40619 .5281 Mdot
.38752 .4204 Mdot
.36621 .37527 Mdot
.59442 .40146 Mdot
.56983 .38606 Mdot
.59709 .70969 Mdot
.7076 .51008 Mdot
.36179 .62506 Mdot
.71744 .61259 Mdot
.5159 .68056 Mdot
.5521 .4258 Mdot
.38322 .41599 Mdot
.6408 .22466 Mdot
.54209 .37514 Mdot
.55214 .74462 Mdot
.38385 .40625 Mdot
.72497 .59547 Mdot
.71692 .5796 Mdot
.60803 .39389 Mdot
.59956 .22299 Mdot
.34538 .65259 Mdot
.34885 .39637 Mdot
.30814 .42091 Mdot
.53432 .39557 Mdot
.57596 .38594 Mdot
.53067 .44317 Mdot
.38755 .6248 Mdot
.5088 .36498 Mdot
.68081 .61115 Mdot
.37255 .38328 Mdot
.56931 .40161 Mdot
.70287 .58324 Mdot
.33571 .33726 Mdot
.39133 .53484 Mdot
.56477 .71327 Mdot
.69209 .57408 Mdot
.70356 .59716 Mdot
.70663 .62158 Mdot
.288 .60718 Mdot
.41533 .38282 Mdot
.82852 .45842 Mdot
.57773 .40852 Mdot
.76537 .52912 Mdot
.62704 .40787 Mdot
.38539 .63627 Mdot
.55548 .68389 Mdot
.59544 .39605 Mdot
.57718 .40875 Mdot
.56924 .213 Mdot
.63712 .40474 Mdot
.63716 .41162 Mdot
.36808 .37032 Mdot
.31737 .44251 Mdot
.53556 .67713 Mdot
.59177 .81797 Mdot
.48094 .14253 Mdot
.52864 .41194 Mdot
.54598 .5245 Mdot
.3797 .42381 Mdot
.33281 .64683 Mdot
.61857 .50793 Mdot
.38136 .57812 Mdot
.38608 .39104 Mdot
.56459 .43215 Mdot
.54365 .20167 Mdot
.68132 .60305 Mdot
.59115 .386 Mdot
.36079 .65688 Mdot
.59204 .38681 Mdot
.3874 .65317 Mdot
.43508 .41609 Mdot
.50463 .51292 Mdot
.57639 .41465 Mdot
.54814 .4299 Mdot
.66462 .44306 Mdot
.5753 .38389 Mdot
.41967 .74178 Mdot
.37774 .40815 Mdot
.62891 .3173 Mdot
.61115 .43658 Mdot
.54725 .25871 Mdot
.55827 .36193 Mdot
.46558 .5282 Mdot
.54912 .38041 Mdot
.7397 .32599 Mdot
.60488 .36463 Mdot
.54614 .3815 Mdot
.35966 .6308 Mdot
.34338 .63078 Mdot
.34504 .4434 Mdot
.38574 .51657 Mdot
.28788 .44966 Mdot
.57165 .36221 Mdot
.50943 .72182 Mdot
.50514 .47547 Mdot
.70891 .5954 Mdot
.37501 .38477 Mdot
.37992 .86137 Mdot
.37369 .62227 Mdot
.56969 .73899 Mdot
.51541 .61798 Mdot
.57701 .70044 Mdot
.55122 .65761 Mdot
.33759 .45706 Mdot
.70376 .61222 Mdot
.57733 .35449 Mdot
.53163 .24226 Mdot
.31495 .57927 Mdot
.53525 .39903 Mdot
.52932 .75746 Mdot
.56484 .48392 Mdot
.789 .56609 Mdot
.68062 .58006 Mdot
.69297 .60493 Mdot
.35995 .63576 Mdot
.53097 .6743 Mdot
.51262 .4117 Mdot
.72854 .61373 Mdot
.55345 .68408 Mdot
.39943 .5483 Mdot
.75808 .62437 Mdot
.36538 .39123 Mdot
.45173 .36693 Mdot
.41429 .46559 Mdot
.3706 .62259 Mdot
.31607 .7189 Mdot
.41415 .4238 Mdot
.40136 .38366 Mdot
.39247 .51488 Mdot
.56626 .72831 Mdot
.40822 .41949 Mdot
.58894 .40601 Mdot
.6324 .34353 Mdot
.58854 .35973 Mdot
.72112 .57971 Mdot
.56665 .35909 Mdot
.56158 .69911 Mdot
.34423 .63847 Mdot
.53528 .73149 Mdot
.34309 .64424 Mdot
.51696 .16623 Mdot
.61065 .38102 Mdot
.57503 .38839 Mdot
.56459 .53245 Mdot
.36986 .3769 Mdot
.51203 .24273 Mdot
.55459 .74418 Mdot
.54124 .73844 Mdot
.59732 .44003 Mdot
.35717 .36386 Mdot
.65014 .60202 Mdot
.60936 .51585 Mdot
.55103 .3763 Mdot
.37742 .40939 Mdot
.59905 .44016 Mdot
.37104 .73967 Mdot
.47523 .49645 Mdot
.34596 .38618 Mdot
.76553 .32644 Mdot
.59994 .40597 Mdot
.65837 .38594 Mdot
.65308 .42726 Mdot
.70466 .31631 Mdot
.60864 .35276 Mdot
.35826 .43241 Mdot
.61484 .39339 Mdot
.36473 .41266 Mdot
.53762 .72143 Mdot
.3729 .61708 Mdot
.36584 .40945 Mdot
.56242 .41041 Mdot
.48957 .14415 Mdot
.34299 .6385 Mdot
.58918 .39148 Mdot
.37239 .64015 Mdot
.40604 .41246 Mdot
.38866 .38632 Mdot
.40618 .51981 Mdot
.51499 .60898 Mdot
.34098 .65361 Mdot
.53933 .41224 Mdot
.28767 .58714 Mdot
.59238 .44125 Mdot
.56444 .77001 Mdot
.57321 .4465 Mdot
.52189 .37919 Mdot
.73937 .26538 Mdot
.4757 .55067 Mdot
.50634 .85638 Mdot
.40848 .67274 Mdot
.28031 .58702 Mdot
.3182 .42442 Mdot
.68073 .5802 Mdot
.44669 .54441 Mdot
.38099 .54928 Mdot
.5736 .6974 Mdot
.594 .39879 Mdot
.28024 .36147 Mdot
.37381 .6798 Mdot
.7164 .59429 Mdot
.58027 .41429 Mdot
.5569 .67088 Mdot
.4249 .47366 Mdot
.33607 .66317 Mdot
.3664 .38906 Mdot
.38088 .3824 Mdot
.80811 .56645 Mdot
.56596 .39931 Mdot
.56838 .38984 Mdot
.34016 .64005 Mdot
.50935 .41447 Mdot
.70833 .62025 Mdot
.44994 .65768 Mdot
.36329 .6562 Mdot
.48001 .5038 Mdot
.37551 .37137 Mdot
.56623 .3747 Mdot
.57278 .53329 Mdot
.25015 .58243 Mdot
.32724 .29238 Mdot
.69103 .59551 Mdot
.68803 .46494 Mdot
.35731 .43223 Mdot
.36397 .65152 Mdot
.75718 .46024 Mdot
.61589 .44369 Mdot
.56924 .37153 Mdot
.70914 .39217 Mdot
.60911 .51442 Mdot
.51092 .61321 Mdot
.54041 .45129 Mdot
.65323 .51007 Mdot
.59554 .4403 Mdot
.59969 .43345 Mdot
.5241 .37414 Mdot
.58564 .4496 Mdot
.3746 .41285 Mdot
.55144 .27044 Mdot
.55043 .70805 Mdot
.36393 .30202 Mdot
.57497 .7725 Mdot
.56395 .4181 Mdot
.56952 .4332 Mdot
.43997 .30972 Mdot
.56989 .50596 Mdot
.37493 .40129 Mdot
.31322 .42847 Mdot
.35786 .62105 Mdot
.63509 .41479 Mdot
.56246 .7427 Mdot
.63919 .44415 Mdot
.5514 .7252 Mdot
.37698 .41227 Mdot
.5169 .71609 Mdot
.33014 .68163 Mdot
.52994 .68711 Mdot
.57243 .7187 Mdot
.33251 .66236 Mdot
.39726 .3922 Mdot
.54526 .37702 Mdot
.3328 .66858 Mdot
.65154 .61126 Mdot
.72072 .57958 Mdot
.4073 .522 Mdot
.61407 .36611 Mdot
.64319 .39092 Mdot
.33303 .74845 Mdot
.51892 .71007 Mdot
.5153 .5042 Mdot
.38866 .41669 Mdot
.71917 .57236 Mdot
.37141 .41453 Mdot
.81283 .51117 Mdot
.69687 .59145 Mdot
.40625 .51672 Mdot
.73568 .46448 Mdot
.38162 .60275 Mdot
.56054 .44269 Mdot
.3121 .43339 Mdot
.54783 .72739 Mdot
.37737 .67193 Mdot
.31062 .46629 Mdot
.60599 .4101 Mdot
.3812 .56514 Mdot
.40983 .39998 Mdot
.38016 .5441 Mdot
.36075 .65445 Mdot
.41373 .50247 Mdot
.56017 .39509 Mdot
.38174 .60362 Mdot
.5515 .43334 Mdot
.47537 .35019 Mdot
.58999 .74353 Mdot
.31226 .3602 Mdot
.5759 .43704 Mdot
.56671 .71849 Mdot
.58434 .43943 Mdot
.40383 .34008 Mdot
.72761 .49001 Mdot
.51718 .38788 Mdot
.59092 .49317 Mdot
.35499 .76417 Mdot
.38147 .41697 Mdot
.56767 .33343 Mdot
.39059 .52233 Mdot
.57659 .42964 Mdot
.2679 .24667 Mdot
.70863 .58459 Mdot
.66552 .60311 Mdot
.56613 .41104 Mdot
.57685 .40291 Mdot
.58006 .2186 Mdot
.40165 .45056 Mdot
.40576 .52484 Mdot
.57649 .37095 Mdot
.70681 .3611 Mdot
.36176 .63236 Mdot
.5689 .44185 Mdot
.60384 .37365 Mdot
.60837 .73539 Mdot
.36758 .63342 Mdot
.52129 .69375 Mdot
.37963 .54532 Mdot
.51229 .72082 Mdot
.73184 .62152 Mdot
.67039 .4798 Mdot
.70089 .46533 Mdot
.46239 .48046 Mdot
.69462 .57388 Mdot
.55759 .41484 Mdot
.3124 .36609 Mdot
.55847 .40019 Mdot
.69738 .60604 Mdot
.37014 .65038 Mdot
.37387 .40889 Mdot
.45564 .37867 Mdot
.39941 .53008 Mdot
.54021 .3994 Mdot
.68861 .56905 Mdot
.36269 .40443 Mdot
.22512 .59114 Mdot
.39064 .40523 Mdot
.34573 .64363 Mdot
.39126 .65251 Mdot
.70366 .59283 Mdot
.37267 .41515 Mdot
.51391 .72203 Mdot
.39185 .69018 Mdot
.54013 .4297 Mdot
.32975 .68212 Mdot
.39696 .43879 Mdot
.35089 .43463 Mdot
.34527 .37492 Mdot
.60876 .43622 Mdot
.57804 .51643 Mdot
.5893 .46318 Mdot
.34243 .63836 Mdot
.56299 .67862 Mdot
.71824 .50798 Mdot
.55719 .23573 Mdot
.49218 .51371 Mdot
.60438 .34456 Mdot
.56889 .3586 Mdot
.58709 .35974 Mdot
.61429 .41884 Mdot
.44641 .64664 Mdot
.61047 .38092 Mdot
.3675 .62735 Mdot
.54935 .71863 Mdot
.55502 .37389 Mdot
.38659 .52592 Mdot
.48742 .61357 Mdot
.72565 .57538 Mdot
.52347 .30378 Mdot
.34077 .46626 Mdot
.36465 .40511 Mdot
.52551 .69971 Mdot
.51616 .71768 Mdot
.72934 .59831 Mdot
.33705 .67237 Mdot
.39195 .39702 Mdot
.74118 .3314 Mdot
.68911 .61427 Mdot
.59587 .36836 Mdot
.56756 .53312 Mdot
.69451 .29482 Mdot
.53713 .36824 Mdot
.60268 .38853 Mdot
.38028 .5205 Mdot
.57341 .73124 Mdot
.25166 .31753 Mdot
.1933 .48994 Mdot
.70921 .59122 Mdot
.72165 .61305 Mdot
.33699 .38461 Mdot
.53473 .37987 Mdot
.34612 .65495 Mdot
.65782 .49314 Mdot
.339 .7397 Mdot
.27763 .42719 Mdot
.37217 .75096 Mdot
.56923 .35504 Mdot
.49601 .30312 Mdot
.57123 .4469 Mdot
.40369 .37175 Mdot
.34914 .36899 Mdot
.37 .39681 Mdot
.35649 .63312 Mdot
.77898 .53607 Mdot
.37156 .62769 Mdot
.30236 .43761 Mdot
.34683 .42329 Mdot
.48912 .56851 Mdot
.54372 .74021 Mdot
.63298 .4024 Mdot
.7016 .61126 Mdot
.65729 .54947 Mdot
.57444 .33344 Mdot
.68331 .47021 Mdot
.52709 .68605 Mdot
.39761 .40912 Mdot
.62922 .40726 Mdot
.29409 .45836 Mdot
.53671 .52351 Mdot
.3741 .77505 Mdot
.28589 .36094 Mdot
.69933 .58284 Mdot
.37966 .28595 Mdot
.69696 .61729 Mdot
.33816 .66516 Mdot
.60229 .40388 Mdot
.53955 .37428 Mdot
.60665 .38711 Mdot
.59863 .44525 Mdot
.36679 .63809 Mdot
.53133 .42246 Mdot
.75088 .54819 Mdot
.39529 .55183 Mdot
.47238 .6087 Mdot
.71539 .58051 Mdot
.38359 .64781 Mdot
.54586 .72113 Mdot
.39415 .51367 Mdot
.68813 .56495 Mdot
.62227 .41318 Mdot
.56 .40659 Mdot
.40091 .54377 Mdot
.50099 .3673 Mdot
.6375 .3744 Mdot
.55592 .70983 Mdot
.49605 .60677 Mdot
.73225 .59261 Mdot
.6865 .60288 Mdot
.37397 .67014 Mdot
.37138 .4149 Mdot
.73125 .6001 Mdot
.53517 .67142 Mdot
.5667 .43928 Mdot
.54243 .42594 Mdot
.39089 .4419 Mdot
.76989 .53009 Mdot
.72463 .57389 Mdot
.51029 .36277 Mdot
.36394 .38158 Mdot
.40982 .39817 Mdot
.57782 .37189 Mdot
.51332 .39273 Mdot
.33236 .38682 Mdot
.72731 .60223 Mdot
.379 .66216 Mdot
.5065 .55158 Mdot
.37896 .63004 Mdot
.35715 .38848 Mdot
.63302 .34142 Mdot
.39353 .38444 Mdot
.60438 .41215 Mdot
.5264 .87531 Mdot
.60641 .37015 Mdot
.62755 .2975 Mdot
.61047 .62626 Mdot
.55344 .74228 Mdot
.56083 .73662 Mdot
.38521 .53256 Mdot
.37172 .43124 Mdot
.56225 .33174 Mdot
.70667 .61441 Mdot
.28105 .58684 Mdot
.40998 .43732 Mdot
.57138 .72083 Mdot
.56558 .743 Mdot
.37042 .6478 Mdot
.56117 .36042 Mdot
.5628 .37571 Mdot
.52807 .68838 Mdot
.44367 .67735 Mdot
.36393 .41807 Mdot
.56872 .39012 Mdot
.61643 .42216 Mdot
.54973 .71054 Mdot
.39033 .67192 Mdot
.41175 .4221 Mdot
.6103 .43496 Mdot
.71809 .48995 Mdot
.38814 .64146 Mdot
.55969 .42137 Mdot
.57497 .44961 Mdot
.70775 .59923 Mdot
.69687 .44874 Mdot
.76138 .5251 Mdot
.34907 .62274 Mdot
.37946 .53699 Mdot
.54534 .3628 Mdot
.55351 .74057 Mdot
.61955 .37676 Mdot
.16033 .5633 Mdot
.3906 .55514 Mdot
.56023 .39249 Mdot
.51839 .3743 Mdot
.3527 .3858 Mdot
.56924 .39726 Mdot
.31834 .69842 Mdot
.5426 .69171 Mdot
.55919 .39204 Mdot
.59908 .22512 Mdot
.36931 .64943 Mdot
.57503 .33391 Mdot
.68399 .591 Mdot
.51022 .60495 Mdot
.46317 .16226 Mdot
.50686 .68401 Mdot
.70863 .5772 Mdot
.56243 .36135 Mdot
.50681 .70579 Mdot
.32867 .65968 Mdot
.66842 .33915 Mdot
.55542 .4148 Mdot
.37584 .62744 Mdot
.34129 .64251 Mdot
.70515 .58953 Mdot
.46857 .8759 Mdot
.51842 .38298 Mdot
.58587 .38539 Mdot
.29184 .74397 Mdot
.32927 .39436 Mdot
.59133 .39093 Mdot
.55487 .36624 Mdot
.35619 .67888 Mdot
.79927 .48839 Mdot
.68728 .46536 Mdot
.44643 .65907 Mdot
.38789 .64734 Mdot
.53008 .75341 Mdot
.54254 .68691 Mdot
.70598 .57767 Mdot
.38483 .40545 Mdot
.72249 .57764 Mdot
.54187 .70296 Mdot
.60502 .38711 Mdot
.36246 .66971 Mdot
.39896 .21821 Mdot
.34922 .684 Mdot
.53806 .66833 Mdot
.40964 .38245 Mdot
.28143 .32926 Mdot
.17068 .60522 Mdot
.43375 .44383 Mdot
.38728 .61833 Mdot
.70903 .59561 Mdot
.19351 .52423 Mdot
.55378 .37434 Mdot
.4499 .34783 Mdot
.58936 .3858 Mdot
.30144 .34692 Mdot
.55531 .68427 Mdot
.40444 .53849 Mdot
.60622 .41024 Mdot
.68874 .46147 Mdot
.33336 .6607 Mdot
.34902 .66298 Mdot
.61416 .39587 Mdot
.34451 .64592 Mdot
.56098 .38088 Mdot
.54696 .71527 Mdot
.49191 .86694 Mdot
.5478 .38745 Mdot
.6538 .35286 Mdot
.38094 .60876 Mdot
.40806 .52702 Mdot
.55199 .75956 Mdot
.53325 .27593 Mdot
.2742 .44038 Mdot
.34755 .65251 Mdot
.53035 .3056 Mdot
.52136 .70977 Mdot
.39096 .51202 Mdot
.52178 .7426 Mdot
.58156 .37881 Mdot
.56458 .35621 Mdot
.61301 .41703 Mdot
.56102 .36354 Mdot
.42777 .34005 Mdot
.63526 .37836 Mdot
.42543 .24905 Mdot
.57709 .4083 Mdot
.61626 .29407 Mdot
.37294 .63049 Mdot
.65886 .39247 Mdot
.5301 .58276 Mdot
.58838 .35373 Mdot
.32527 .44614 Mdot
.38292 .64691 Mdot
.35355 .53075 Mdot
.36676 .63574 Mdot
.53779 .73326 Mdot
.33548 .65452 Mdot
.60125 .40787 Mdot
.37382 .38891 Mdot
.53074 .70203 Mdot
.45621 .4058 Mdot
.5647 .68322 Mdot
.56258 .39807 Mdot
.37069 .59427 Mdot
.5347 .7402 Mdot
.64102 .40884 Mdot
.37772 .39007 Mdot
.71908 .36282 Mdot
.37384 .35547 Mdot
.57644 .3976 Mdot
.58308 .39681 Mdot
.40471 .53413 Mdot
.33481 .66118 Mdot
.36806 .36733 Mdot
.61455 .72363 Mdot
.70355 .56378 Mdot
.37966 .40204 Mdot
.65771 .41841 Mdot
.54782 .52638 Mdot
.3486 .38595 Mdot
.7042 .33532 Mdot
.34122 .67249 Mdot
.33904 .4149 Mdot
.58205 .45695 Mdot
.37422 .30432 Mdot
.68703 .60755 Mdot
.51792 .7314 Mdot
.64163 .51617 Mdot
.5428 .68815 Mdot
.31718 .64857 Mdot
.55623 .74981 Mdot
.367 .63063 Mdot
.52813 .48547 Mdot
.50961 .58513 Mdot
.36366 .68222 Mdot
.37199 .60828 Mdot
.55208 .70258 Mdot
.61483 .40273 Mdot
.48462 .59796 Mdot
.5587 .33143 Mdot
.62516 .34208 Mdot
.37892 .62665 Mdot
.34835 .4281 Mdot
.3951 .38295 Mdot
.61229 .31248 Mdot
.37546 .37657 Mdot
.53282 .71151 Mdot
.45541 .46321 Mdot
.50294 .32347 Mdot
.3691 .65503 Mdot
.5124 .61983 Mdot
.57898 .43708 Mdot
.56234 .70972 Mdot
.53253 .71581 Mdot
.34394 .64051 Mdot
.34831 .30695 Mdot
.6026 .33633 Mdot
.33072 .42251 Mdot
.33904 .40785 Mdot
.34708 .38828 Mdot
.35368 .36488 Mdot
.78167 .53497 Mdot
.37731 .67181 Mdot
.367 .43228 Mdot
.5982 .44382 Mdot
.54439 .36854 Mdot
.38773 .54676 Mdot
.72611 .59547 Mdot
.61455 .44322 Mdot
.55994 .33199 Mdot
.57601 .37222 Mdot
.55094 .74302 Mdot
.62799 .47715 Mdot
.39389 .55176 Mdot
.56725 .7391 Mdot
.56458 .74017 Mdot
.381 .5353 Mdot
.53841 .48722 Mdot
.26285 .31474 Mdot
.61154 .39892 Mdot
.3396 .45984 Mdot
.56024 .73429 Mdot
.6527 .54224 Mdot
.58432 .29551 Mdot
.53379 .4059 Mdot
.46819 .6371 Mdot
.54108 .71579 Mdot
.31779 .41886 Mdot
.57878 .38137 Mdot
.39329 .51664 Mdot
.68352 .59946 Mdot
.66499 .4248 Mdot
.38152 .51931 Mdot
.37419 .41822 Mdot
.58375 .77988 Mdot
.36148 .43893 Mdot
.52676 .73671 Mdot
.57274 .33269 Mdot
.69007 .83601 Mdot
.54544 .72824 Mdot
.27801 .59857 Mdot
.50969 .58714 Mdot
.55064 .39054 Mdot
.53242 .69195 Mdot
.37637 .44865 Mdot
.38798 .63886 Mdot
.57912 .52408 Mdot
.3836 .41505 Mdot
.39523 .51405 Mdot
.38745 .54368 Mdot
.55096 .70894 Mdot
.34179 .40465 Mdot
.55015 .43592 Mdot
.38256 .38476 Mdot
.35829 .66792 Mdot
.59286 .42156 Mdot
.28673 .44872 Mdot
.65268 .36496 Mdot
.37765 .38285 Mdot
.5516 .67086 Mdot
.7012 .62447 Mdot
.5651 .41454 Mdot
.34653 .50807 Mdot
.55952 .36208 Mdot
.37244 .64288 Mdot
.61086 .58925 Mdot
.40322 .21968 Mdot
.59513 .3723 Mdot
.57643 .43574 Mdot
.3282 .67596 Mdot
.59429 .37307 Mdot
.52389 .38551 Mdot
.41262 .49961 Mdot
.35076 .38447 Mdot
.5581 .37157 Mdot
.54975 .68613 Mdot
.46454 .18514 Mdot
.60178 .40097 Mdot
.32094 .70453 Mdot
.71337 .36671 Mdot
.59181 .567 Mdot
.60215 .33016 Mdot
.69565 .48938 Mdot
.58391 .39338 Mdot
.53224 .40041 Mdot
.61255 .39797 Mdot
.48988 .30973 Mdot
.54609 .70096 Mdot
.56884 .71001 Mdot
.68112 .58855 Mdot
.71114 .37412 Mdot
.69154 .58967 Mdot
.33246 .67859 Mdot
.51498 .61577 Mdot
.40139 .53946 Mdot
.36937 .41464 Mdot
.60207 .39859 Mdot
.5622 .68261 Mdot
.56866 .37587 Mdot
.57347 .42887 Mdot
.53613 .7088 Mdot
.53644 .71841 Mdot
.50697 .68095 Mdot
.68148 .60513 Mdot
.37092 .40281 Mdot
.6081 .39896 Mdot
.69572 .61949 Mdot
.61899 .4199 Mdot
.5058 .5366 Mdot
.37198 .40118 Mdot
.37695 .38148 Mdot
.40505 .40111 Mdot
.54717 .39725 Mdot
.60058 .41293 Mdot
.37193 .62763 Mdot
.39151 .44144 Mdot
.34145 .6578 Mdot
.53374 .69082 Mdot
.56057 .70399 Mdot
.58255 .37898 Mdot
.50779 .39806 Mdot
.71945 .58445 Mdot
.52282 .72316 Mdot
.37583 .54509 Mdot
.68238 .58871 Mdot
.58581 .35763 Mdot
.53832 .68839 Mdot
.70737 .56915 Mdot
.31198 .30145 Mdot
.25234 .4212 Mdot
.67763 .60003 Mdot
.61463 .39724 Mdot
.55906 .22948 Mdot
.72647 .49666 Mdot
.71146 .56277 Mdot
.37568 .64051 Mdot
.54805 .37164 Mdot
.42311 .67615 Mdot
.73002 .61502 Mdot
.75803 .52039 Mdot
.53568 .70383 Mdot
.63859 .3386 Mdot
.64631 .45328 Mdot
.4946 .33449 Mdot
.71209 .62598 Mdot
.3763 .38352 Mdot
.33839 .39285 Mdot
.59656 .37013 Mdot
.51287 .61106 Mdot
.33955 .68412 Mdot
.51573 .71677 Mdot
.57008 .70241 Mdot
.34547 .38323 Mdot
.46577 .48554 Mdot
.54709 .68564 Mdot
.5338 .38416 Mdot
.74169 .60904 Mdot
.63368 .4193 Mdot
.80265 .55261 Mdot
.44152 .177 Mdot
.61249 .33247 Mdot
.69332 .62166 Mdot
.3306 .65664 Mdot
.35269 .6328 Mdot
.35151 .63754 Mdot
.55762 .70024 Mdot
.62362 .50898 Mdot
.56433 .69128 Mdot
.26293 .67576 Mdot
.70592 .58242 Mdot
.74444 .37214 Mdot
.60135 .44932 Mdot
.55177 .39219 Mdot
.56698 .43653 Mdot
.61131 .42233 Mdot
.58228 .39269 Mdot
.36889 .62281 Mdot
.50951 .70919 Mdot
.35172 .74534 Mdot
.34827 .40981 Mdot
.22124 .58813 Mdot
.54175 .7398 Mdot
.37756 .52467 Mdot
.72051 .60068 Mdot
.70844 .42432 Mdot
.74006 .62301 Mdot
.52208 .72579 Mdot
.53932 .36245 Mdot
.33384 .39109 Mdot
.73793 .31913 Mdot
.58359 .40396 Mdot
.51985 .71734 Mdot
.51984 .74573 Mdot
.34815 .30044 Mdot
.51792 .44074 Mdot
.49829 .64182 Mdot
.55013 .52343 Mdot
.67571 .60111 Mdot
.59232 .34307 Mdot
.6748 .4848 Mdot
.54372 .70404 Mdot
.55481 .72991 Mdot
.70604 .56204 Mdot
.4167 .35998 Mdot
.35997 .42937 Mdot
.40204 .54717 Mdot
.37881 .6453 Mdot
.55585 .40122 Mdot
.55238 .69611 Mdot
.31709 .37201 Mdot
.53308 .54417 Mdot
.36296 .64092 Mdot
.56514 .74276 Mdot
.55596 .36364 Mdot
.5918 .36855 Mdot
.69556 .58722 Mdot
.59934 .64733 Mdot
.55934 .33135 Mdot
.28099 .58866 Mdot
.50058 .50454 Mdot
.51132 .59024 Mdot
.56866 .37156 Mdot
.38035 .37497 Mdot
.38202 .5341 Mdot
.70563 .61047 Mdot
.62069 .39605 Mdot
.25401 .347 Mdot
.37558 .43609 Mdot
.34217 .65471 Mdot
.38195 .52653 Mdot
.658 .48517 Mdot
.55873 .36307 Mdot
.5889 .38541 Mdot
.60822 .43685 Mdot
.25431 .33382 Mdot
.55984 .69015 Mdot
.36185 .36691 Mdot
.69042 .58492 Mdot
.39076 .39015 Mdot
.54922 .74845 Mdot
.50633 .61697 Mdot
.6126 .38365 Mdot
.38861 .42556 Mdot
.389 .39289 Mdot
.36908 .65118 Mdot
.33257 .66895 Mdot
.50955 .68425 Mdot
.5566 .36738 Mdot
.40288 .5353 Mdot
.35746 .43105 Mdot
.5129 .70683 Mdot
.69596 .58815 Mdot
.31386 .67642 Mdot
.57449 .40868 Mdot
.54926 .70617 Mdot
.56204 .33274 Mdot
.35261 .40247 Mdot
.5307 .73441 Mdot
.38692 .51228 Mdot
.72656 .60153 Mdot
.5569 .35819 Mdot
.37375 .76248 Mdot
.38956 .51669 Mdot
.55696 .40798 Mdot
.42671 .18492 Mdot
.51218 .6107 Mdot
.40168 .35638 Mdot
.54412 .67971 Mdot
.39997 .52465 Mdot
.35315 .36827 Mdot
.39121 .2993 Mdot
.55682 .7252 Mdot
.55417 .20796 Mdot
.49699 .56482 Mdot
.61134 .40241 Mdot
.37893 .41721 Mdot
.74152 .63492 Mdot
.27671 .56958 Mdot
.7214 .50158 Mdot
.56178 .38771 Mdot
.54369 .68833 Mdot
.68439 .59982 Mdot
.34774 .66344 Mdot
.33122 .70611 Mdot
.81725 .54231 Mdot
.5728 .72532 Mdot
.60353 .39716 Mdot
.34639 .426 Mdot
.34227 .65106 Mdot
.55088 .1999 Mdot
.53058 .67383 Mdot
.54073 .68216 Mdot
.5519 .42964 Mdot
.6895 .59182 Mdot
.42611 .6629 Mdot
.56482 .70025 Mdot
.50877 .71189 Mdot
.41009 .48834 Mdot
.67958 .58749 Mdot
.60943 .43354 Mdot
.61233 .3123 Mdot
.57754 .4472 Mdot
.24967 .61543 Mdot
.40118 .52713 Mdot
.34971 .41236 Mdot
.5942 .39485 Mdot
.35073 .76356 Mdot
.55203 .72306 Mdot
.54797 .52223 Mdot
.39303 .66457 Mdot
.33331 .66932 Mdot
.54201 .69308 Mdot
.56997 .38055 Mdot
.34718 .6937 Mdot
.70997 .58005 Mdot
.61178 .43261 Mdot
.60289 .41292 Mdot
.39053 .44376 Mdot
.36305 .66805 Mdot
.46218 .18342 Mdot
.34785 .6679 Mdot
.36816 .6753 Mdot
.41154 .40668 Mdot
.59587 .36913 Mdot
.53061 .73194 Mdot
.55862 .66997 Mdot
.5183 .357 Mdot
.65019 .54906 Mdot
.3671 .42822 Mdot
.57965 .67801 Mdot
.24627 .35103 Mdot
.52907 .41153 Mdot
.37656 .54316 Mdot
.29804 .35976 Mdot
.38773 .66079 Mdot
.60007 .3812 Mdot
.36311 .41276 Mdot
.51149 .69028 Mdot
.55079 .69057 Mdot
.61686 .44265 Mdot
.34631 .63677 Mdot
.71194 .57032 Mdot
.53044 .71569 Mdot
.49954 .54575 Mdot
.56189 .39475 Mdot
.37538 .56931 Mdot
.52877 .71599 Mdot
.50178 .14864 Mdot
.34267 .75803 Mdot
.34468 .38926 Mdot
.55098 .42238 Mdot
.33379 .40925 Mdot
.69624 .57666 Mdot
.53904 .75155 Mdot
.36227 .62631 Mdot
.49022 .42476 Mdot
.55902 .81235 Mdot
.55603 .70199 Mdot
.3755 .41169 Mdot
.60256 .39354 Mdot
.53892 .30352 Mdot
.54966 .37924 Mdot
.79922 .4797 Mdot
.72202 .57029 Mdot
.33311 .62363 Mdot
.34202 .63825 Mdot
.57078 .43291 Mdot
.70539 .62084 Mdot
.54508 .66358 Mdot
.537 .70812 Mdot
.55756 .83855 Mdot
.38314 .51725 Mdot
.54805 .65499 Mdot
.54924 .39914 Mdot
.51543 .70153 Mdot
.5575 .23649 Mdot
.33775 .64663 Mdot
.55909 .43839 Mdot
.5792 .71343 Mdot
.23811 .57519 Mdot
.55142 .52583 Mdot
.56138 .39204 Mdot
.50963 .41263 Mdot
.37137 .63704 Mdot
.19338 .52204 Mdot
.54566 .67842 Mdot
.61937 .41474 Mdot
.36996 .68695 Mdot
.49486 .46775 Mdot
.61533 .70694 Mdot
.3707 .40236 Mdot
.58183 .7123 Mdot
.37727 .66327 Mdot
.6414 .34092 Mdot
.72366 .58724 Mdot
.52415 .67355 Mdot
.57427 .69626 Mdot
.58476 .42441 Mdot
.62542 .42146 Mdot
.52225 .43131 Mdot
.37294 .4225 Mdot
.3588 .67731 Mdot
.58807 .43343 Mdot
.50759 .52886 Mdot
.60904 .42536 Mdot
.36748 .67326 Mdot
.58373 .89349 Mdot
.54591 .35893 Mdot
.56912 .40769 Mdot
.53679 .2952 Mdot
.37043 .36796 Mdot
.35737 .38024 Mdot
.49902 .51269 Mdot
.54119 .38501 Mdot
.48491 .56302 Mdot
.3706 .40539 Mdot
.38231 .4117 Mdot
.48612 .56466 Mdot
.5896 .41981 Mdot
.38898 .57109 Mdot
.34243 .64962 Mdot
.33329 .66991 Mdot
.3536 .38547 Mdot
.63046 .42363 Mdot
.3291 .65819 Mdot
.42617 .33056 Mdot
.52746 .73322 Mdot
.67562 .48225 Mdot
.38562 .38704 Mdot
.57736 .53473 Mdot
.33856 .66776 Mdot
.56455 .17887 Mdot
.70151 .30497 Mdot
.52171 .40347 Mdot
.59734 .3725 Mdot
.70345 .59873 Mdot
.4855 .39954 Mdot
.38018 .5396 Mdot
.34739 .63994 Mdot
.44775 .64511 Mdot
.37002 .39619 Mdot
.54296 .382 Mdot
.71328 .50902 Mdot
.46717 .16473 Mdot
.64404 .32471 Mdot
.38535 .40641 Mdot
.37218 .39231 Mdot
.53102 .68176 Mdot
.52204 .72814 Mdot
.61239 .38557 Mdot
.36047 .62971 Mdot
.33712 .40515 Mdot
.36223 .67301 Mdot
.54207 .70401 Mdot
.53646 .73666 Mdot
.38924 .55261 Mdot
.61487 .34029 Mdot
.54004 .69652 Mdot
.32311 .71193 Mdot
.50714 .52992 Mdot
.40185 .43477 Mdot
.2794 .71966 Mdot
.59183 .19136 Mdot
.46279 .37144 Mdot
.68386 .60041 Mdot
.52181 .48447 Mdot
.34449 .62853 Mdot
.57501 .43436 Mdot
.59143 .38116 Mdot
.39627 .53787 Mdot
.33793 .63464 Mdot
.71641 .59961 Mdot
.33342 .65746 Mdot
.71193 .61205 Mdot
.56875 .71395 Mdot
.59791 .40248 Mdot
.59574 .35895 Mdot
.35011 .66173 Mdot
.52178 .69429 Mdot
.5356 .74071 Mdot
.6958 .61412 Mdot
.7103 .4077 Mdot
.54912 .70864 Mdot
.38667 .38777 Mdot
.48536 .19754 Mdot
.38903 .54378 Mdot
.57838 .3819 Mdot
.69953 .48685 Mdot
.40489 .28899 Mdot
.6116 .41315 Mdot
.38387 .52236 Mdot
.47661 .8783 Mdot
.60016 .40289 Mdot
.65156 .80662 Mdot
.39857 .54417 Mdot
.39227 .38285 Mdot
.52309 .71081 Mdot
.38321 .5186 Mdot
.63612 .47182 Mdot
.5936 .71594 Mdot
.5391 .34278 Mdot
.36266 .43044 Mdot
.39901 .41147 Mdot
.50044 .61199 Mdot
.24824 .61492 Mdot
.6891 .58595 Mdot
.71586 .58982 Mdot
.55759 .72146 Mdot
.33545 .71528 Mdot
.62377 .43288 Mdot
.71474 .5914 Mdot
.40484 .586 Mdot
.57426 .43602 Mdot
.51023 .61013 Mdot
.47842 .60135 Mdot
.36281 .37156 Mdot
.65754 .39979 Mdot
.55502 .7227 Mdot
.37564 .41054 Mdot
.49079 .60004 Mdot
.56302 .43835 Mdot
.37149 .39922 Mdot
.3465 .67892 Mdot
.45872 .55385 Mdot
.38015 .3807 Mdot
.57227 .52722 Mdot
.34913 .65623 Mdot
.51117 .61507 Mdot
.76539 .42729 Mdot
.35429 .17286 Mdot
.35356 .63329 Mdot
.51982 .70922 Mdot
.55222 .69768 Mdot
.54928 .7126 Mdot
.38066 .41928 Mdot
.53949 .72316 Mdot
.3508 .41945 Mdot
.36513 .61084 Mdot
.70342 .42712 Mdot
.70056 .59238 Mdot
.76471 .61356 Mdot
.36612 .38527 Mdot
.25773 .65733 Mdot
.24711 .7137 Mdot
.61254 .4263 Mdot
.36618 .68059 Mdot
.6891 .61693 Mdot
.49012 .49238 Mdot
.70653 .5997 Mdot
.5216 .7084 Mdot
.67803 .4738 Mdot
.56028 .38016 Mdot
.28793 .41362 Mdot
.68483 .59904 Mdot
.38494 .41075 Mdot
.56189 .41741 Mdot
.58134 .69436 Mdot
.70397 .57623 Mdot
.68971 .60792 Mdot
.58196 .39098 Mdot
.39988 .40386 Mdot
.52725 .73047 Mdot
.35154 .62278 Mdot
.7481 .60166 Mdot
.50283 .40306 Mdot
.60944 .38758 Mdot
.54702 .35537 Mdot
.53401 .51863 Mdot
.35689 .72047 Mdot
.35042 .65348 Mdot
.75229 .52027 Mdot
.56221 .70748 Mdot
.72538 .50222 Mdot
.29606 .57264 Mdot
.70992 .63935 Mdot
.40123 .52946 Mdot
.40166 .52786 Mdot
.56916 .39425 Mdot
.1809 .61044 Mdot
.64754 .31531 Mdot
.39779 .63835 Mdot
.3917 .53999 Mdot
.53113 .73891 Mdot
.37526 .44361 Mdot
.61954 .46455 Mdot
.60726 .44657 Mdot
.34534 .62596 Mdot
.54242 .70879 Mdot
.15864 .55847 Mdot
.70452 .58323 Mdot
.48648 .49353 Mdot
.55956 .3656 Mdot
.57139 .38917 Mdot
.36123 .64783 Mdot
.36547 .62697 Mdot
.40881 .48448 Mdot
.5918 .55675 Mdot
.27715 .43605 Mdot
.32281 .65156 Mdot
.15791 .55791 Mdot
.28155 .36198 Mdot
.35332 .39133 Mdot
.37833 .54418 Mdot
.33187 .67483 Mdot
.59247 .39254 Mdot
.391 .38095 Mdot
.66068 .32988 Mdot
.3133 .40571 Mdot
.51091 .60563 Mdot
.50567 .55066 Mdot
.56936 .35882 Mdot
.34211 .37261 Mdot
.37567 .40705 Mdot
.35435 .3613 Mdot
.38314 .53823 Mdot
.57232 .37047 Mdot
.61541 .41244 Mdot
.60137 .40379 Mdot
.51267 .32879 Mdot
.56883 .39747 Mdot
.2923 .57153 Mdot
.49413 .52117 Mdot
.65986 .6818 Mdot
.58611 .40665 Mdot
.35464 .68042 Mdot
.59646 .40133 Mdot
.71544 .62008 Mdot
.55307 .35811 Mdot
.51198 .60259 Mdot
.35029 .64431 Mdot
.36977 .32694 Mdot
.55306 .77059 Mdot
.60036 .36437 Mdot
.6954 .57289 Mdot
.29364 .72213 Mdot
.73993 .51828 Mdot
.41201 .49201 Mdot
.38285 .38512 Mdot
.5077 .71442 Mdot
.36144 .68678 Mdot
.5388 .73486 Mdot
.54258 .43112 Mdot
.38153 .55203 Mdot
.7431 .2776 Mdot
.58703 .5377 Mdot
.59299 .39438 Mdot
.60861 .33897 Mdot
.36883 .37267 Mdot
.54916 .72465 Mdot
.4368 .4133 Mdot
.57188 .43711 Mdot
.72845 .58785 Mdot
.7157 .62305 Mdot
.47737 .68092 Mdot
.44201 .55654 Mdot
.59927 .26826 Mdot
.35898 .64829 Mdot
.55612 .696 Mdot
.72073 .62442 Mdot
.3102 .43091 Mdot
.3432 .68451 Mdot
.38804 .66042 Mdot
.36488 .66714 Mdot
.55939 .39802 Mdot
.38868 .55005 Mdot
.43161 .59144 Mdot
.38905 .5146 Mdot
.58326 .44506 Mdot
.57492 .69849 Mdot
.39083 .51253 Mdot
.69537 .59642 Mdot
.37781 .66651 Mdot
.54751 .74206 Mdot
.58092 .39824 Mdot
.36525 .40354 Mdot
.78279 .5654 Mdot
.36834 .7818 Mdot
.51318 .61235 Mdot
.51321 .61245 Mdot
.40314 .41242 Mdot
.33083 .46767 Mdot
.31591 .6597 Mdot
.35862 .3006 Mdot
.64944 .59497 Mdot
.52223 .34961 Mdot
.61544 .77188 Mdot
.56214 .68823 Mdot
.53035 .70403 Mdot
.55554 .38387 Mdot
.51697 .69174 Mdot
.54644 .37827 Mdot
.54067 .67834 Mdot
.26439 .58125 Mdot
.59797 .453 Mdot
.53208 .70955 Mdot
.51363 .44008 Mdot
.56457 .41393 Mdot
.3822 .37709 Mdot
.5203 .67804 Mdot
.52211 .40387 Mdot
.7988 .33201 Mdot
.36591 .65492 Mdot
.38362 .53934 Mdot
.52234 .59358 Mdot
.33655 .65932 Mdot
.34842 .42113 Mdot
.53981 .37798 Mdot
.70374 .5804 Mdot
.35796 .38875 Mdot
.58797 .72186 Mdot
.68661 .59826 Mdot
.4547 .46519 Mdot
.35385 .38737 Mdot
.3924 .54461 Mdot
.72571 .60578 Mdot
.53816 .34335 Mdot
.5321 .70425 Mdot
.35301 .76944 Mdot
.38176 .522 Mdot
.56274 .37716 Mdot
.58262 .71814 Mdot
.33393 .65854 Mdot
.60028 .36867 Mdot
.55228 .6944 Mdot
.38056 .5322 Mdot
.56963 .41221 Mdot
.54654 .39961 Mdot
.43331 .3725 Mdot
.6148 .60506 Mdot
.69796 .59362 Mdot
.41079 .39235 Mdot
.59517 .4454 Mdot
.7004 .61937 Mdot
.3895 .74696 Mdot
.58039 .4533 Mdot
.36766 .43554 Mdot
.39992 .32472 Mdot
.51524 .70838 Mdot
.33854 .64319 Mdot
.54077 .66773 Mdot
.68452 .58344 Mdot
.30188 .79007 Mdot
.38002 .54438 Mdot
.54511 .35108 Mdot
.52318 .39223 Mdot
.53245 .75074 Mdot
.37688 .4047 Mdot
.27773 .43244 Mdot
.55061 .36103 Mdot
.63572 .34645 Mdot
.581 .38622 Mdot
.3894 .7556 Mdot
.37715 .4211 Mdot
.58047 .3837 Mdot
.50033 .38424 Mdot
.53632 .41986 Mdot
.7094 .57197 Mdot
.7451 .3628 Mdot
.60887 .41082 Mdot
.76828 .7767 Mdot
.39006 .55758 Mdot
.53856 .71166 Mdot
.56377 .52541 Mdot
.53444 .60624 Mdot
.80724 .60183 Mdot
.35753 .42602 Mdot
.32437 .4487 Mdot
.53395 .7341 Mdot
.78927 .5995 Mdot
.34863 .47906 Mdot
.55161 .40755 Mdot
.55074 .36803 Mdot
.5216 .70851 Mdot
.51274 .71122 Mdot
.38352 .55563 Mdot
.61323 .37303 Mdot
.6545 .37699 Mdot
.55663 .67382 Mdot
.57736 .40305 Mdot
.40849 .27058 Mdot
.39094 .64058 Mdot
.35363 .38419 Mdot
.3494 .66416 Mdot
.38942 .6395 Mdot
.45459 .38119 Mdot
.50482 .50549 Mdot
.37952 .63723 Mdot
.39356 .62915 Mdot
.75698 .62606 Mdot
.50832 .31961 Mdot
.71162 .57276 Mdot
.43448 .5071 Mdot
.55592 .71441 Mdot
.57498 .37041 Mdot
.38208 .41972 Mdot
.82466 .45999 Mdot
.27083 .46565 Mdot
.68533 .4223 Mdot
.60691 .43484 Mdot
.55258 .71987 Mdot
.38118 .52495 Mdot
.58796 .45514 Mdot
.72584 .49844 Mdot
.56548 .38886 Mdot
.51853 .72475 Mdot
.50209 .32459 Mdot
.30131 .68307 Mdot
.32186 .65076 Mdot
.35369 .44331 Mdot
.59892 .40018 Mdot
.35955 .41699 Mdot
.38263 .63632 Mdot
.6867 .61149 Mdot
.70911 .59434 Mdot
.59657 .36071 Mdot
.50888 .58586 Mdot
.721 .64791 Mdot
.55499 .4102 Mdot
.58783 .42327 Mdot
.40062 .52923 Mdot
.58914 .42304 Mdot
.61893 .39769 Mdot
.59086 .43466 Mdot
.62138 .42039 Mdot
.33747 .68151 Mdot
.44714 .40224 Mdot
.60172 .35691 Mdot
.52098 .37538 Mdot
.37539 .61791 Mdot
.52198 .41698 Mdot
.36472 .63435 Mdot
.2861 .46274 Mdot
.37864 .64067 Mdot
.70759 .59366 Mdot
.58379 .71129 Mdot
.36436 .46407 Mdot
.33731 .40482 Mdot
.34751 .68186 Mdot
.72296 .60457 Mdot
.35156 .63601 Mdot
.55789 .69342 Mdot
.32499 .73473 Mdot
.41852 .38961 Mdot
.48905 .53004 Mdot
.52165 .30586 Mdot
.37324 .5707 Mdot
.52081 .68867 Mdot
.34337 .3915 Mdot
.3185 .698 Mdot
.57095 .43229 Mdot
.69741 .58177 Mdot
.5697 .39377 Mdot
.37529 .6703 Mdot
.55367 .71711 Mdot
.41258 .53077 Mdot
.69841 .59455 Mdot
.32161 .78755 Mdot
.56045 .68054 Mdot
.528 .37529 Mdot
.37439 .61823 Mdot
.3354 .73003 Mdot
.37207 .63476 Mdot
.70431 .42674 Mdot
.31064 .36595 Mdot
.82331 .48829 Mdot
.36832 .38925 Mdot
.37202 .54477 Mdot
.32498 .22786 Mdot
.3357 .5422 Mdot
.35741 .40178 Mdot
.54497 .77316 Mdot
.56701 .39993 Mdot
.60614 .43098 Mdot
.61971 .34481 Mdot
.32339 .37392 Mdot
.60781 .43712 Mdot
.38278 .54379 Mdot
.50807 .51163 Mdot
.42147 .61677 Mdot
.50583 .70505 Mdot
.5486 .37696 Mdot
.37826 .62602 Mdot
.35394 .68283 Mdot
.39513 .51268 Mdot
.35196 .6705 Mdot
.58354 .41428 Mdot
.36627 .38626 Mdot
.48573 .59811 Mdot
.69601 .57736 Mdot
.28975 .59572 Mdot
.6563 .62329 Mdot
.74536 .62036 Mdot
.53377 .41785 Mdot
.53477 .7361 Mdot
.5708 .81026 Mdot
.58745 .43801 Mdot
.37186 .40783 Mdot
.52375 .39047 Mdot
.59874 .43242 Mdot
.6074 .40241 Mdot
.55648 .69715 Mdot
.55698 .52923 Mdot
.57913 .40355 Mdot
.38079 .63817 Mdot
.48826 .56529 Mdot
.61104 .44438 Mdot
.45425 .65402 Mdot
.51124 .60296 Mdot
.37549 .57029 Mdot
.39807 .43941 Mdot
.52741 .72614 Mdot
.36927 .39413 Mdot
.32636 .38378 Mdot
.34778 .42034 Mdot
.42824 .60345 Mdot
.37302 .30261 Mdot
.67517 .79665 Mdot
.56128 .24119 Mdot
.51628 .30592 Mdot
.34285 .43486 Mdot
.44202 .73544 Mdot
.3578 .40636 Mdot
.35108 .42293 Mdot
.54824 .882 Mdot
.38304 .42377 Mdot
.58157 .37806 Mdot
.56799 .34935 Mdot
.28277 .32773 Mdot
.75767 .608 Mdot
.55399 .4034 Mdot
.61638 .41975 Mdot
.71872 .62372 Mdot
.44302 .38498 Mdot
.37933 .55487 Mdot
.48169 .49241 Mdot
.37434 .52977 Mdot
.58154 .39159 Mdot
.58028 .35792 Mdot
.6237 .38905 Mdot
.39302 .17256 Mdot
.82702 .51048 Mdot
.40372 .40385 Mdot
.51298 .35802 Mdot
.3709 .57902 Mdot
.52949 .39302 Mdot
.52656 .4009 Mdot
.60251 .40786 Mdot
.53081 .73223 Mdot
.38239 .4404 Mdot
.55871 .33184 Mdot
.32072 .58327 Mdot
.56514 .3613 Mdot
.67558 .63905 Mdot
.67301 .58963 Mdot
.57075 .37974 Mdot
.3841 .42458 Mdot
.60736 .43184 Mdot
.33615 .41392 Mdot
.35033 .38954 Mdot
.64557 .35937 Mdot
.43185 .5817 Mdot
.37147 .44306 Mdot
.5498 .40562 Mdot
.52098 .69362 Mdot
.27972 .59222 Mdot
.56412 .37753 Mdot
.69122 .59734 Mdot
.60183 .38298 Mdot
.70415 .57058 Mdot
.59866 .42141 Mdot
.39205 .51407 Mdot
.39509 .22616 Mdot
.55678 .72838 Mdot
.74919 .61435 Mdot
.51689 .69514 Mdot
.64075 .39825 Mdot
.34668 .43414 Mdot
.30916 .62723 Mdot
.8233 .53735 Mdot
.40061 .53091 Mdot
.76906 .53275 Mdot
.4768 .56759 Mdot
.36158 .62237 Mdot
.35438 .3655 Mdot
.48137 .34801 Mdot
.4586 .64877 Mdot
.50673 .71899 Mdot
.55932 .74503 Mdot
.6201 .71361 Mdot
.49239 .86709 Mdot
.57647 .40563 Mdot
.42233 .67992 Mdot
.42457 .24213 Mdot
.48894 .38787 Mdot
.54211 .45234 Mdot
.57202 .69046 Mdot
.55426 .40395 Mdot
.62833 .52329 Mdot
.55113 .70198 Mdot
.71978 .58947 Mdot
.35101 .41392 Mdot
.71005 .61791 Mdot
.24038 .45343 Mdot
.41123 .4951 Mdot
.54409 .69824 Mdot
.62128 .42352 Mdot
.54971 .394 Mdot
.36357 .36571 Mdot
.55751 .20395 Mdot
.35149 .38406 Mdot
.69004 .58181 Mdot
.56237 .71957 Mdot
.76885 .33205 Mdot
.60418 .389 Mdot
.39028 .39631 Mdot
.55236 .77066 Mdot
.59001 .368 Mdot
.34075 .64161 Mdot
.60335 .43856 Mdot
.39238 .39599 Mdot
.58979 .4232 Mdot
.36464 .38816 Mdot
.5305 .68421 Mdot
.59147 .35636 Mdot
.58825 .35907 Mdot
.7585 .52273 Mdot
.7152 .60067 Mdot
.35385 .43668 Mdot
.63019 .52133 Mdot
.57781 .44727 Mdot
.7198 .49116 Mdot
.59854 .40255 Mdot
.52534 .30905 Mdot
.56055 .44764 Mdot
.38433 .54592 Mdot
.52419 .39617 Mdot
.56362 .37873 Mdot
.57831 .21748 Mdot
.5569 .23365 Mdot
.48283 .36133 Mdot
.3324 .66947 Mdot
.3941 .40693 Mdot
.54939 .69603 Mdot
.50918 .6939 Mdot
.53646 .72553 Mdot
.69039 .55782 Mdot
.51006 .36559 Mdot
.56037 .37513 Mdot
.3885 .60825 Mdot
.71184 .58785 Mdot
.38759 .40109 Mdot
.70472 .58978 Mdot
.50699 .50393 Mdot
.69203 .6015 Mdot
.37958 .54018 Mdot
.34212 .75558 Mdot
.4092 .28115 Mdot
.70394 .6084 Mdot
.35093 .38562 Mdot
.48237 .55188 Mdot
.52769 .34455 Mdot
.23417 .59951 Mdot
.72927 .58937 Mdot
.61077 .74283 Mdot
.57653 .41137 Mdot
.58547 .52178 Mdot
.36594 .63722 Mdot
.71109 .61753 Mdot
.36494 .66578 Mdot
.60627 .43271 Mdot
.43228 .38254 Mdot
.37313 .41392 Mdot
.38945 .63316 Mdot
.54576 .42745 Mdot
.71143 .61777 Mdot
.5391 .69864 Mdot
.50473 .32308 Mdot
.38217 .61664 Mdot
.78097 .56883 Mdot
.72274 .50221 Mdot
.56227 .71562 Mdot
.55507 .2767 Mdot
.3745 .65283 Mdot
.51992 .35216 Mdot
.67021 .36683 Mdot
.58973 .44201 Mdot
.53824 .74216 Mdot
.52947 .70476 Mdot
.36119 .54257 Mdot
.581 .35654 Mdot
.59388 .35104 Mdot
.39961 .42965 Mdot
.56428 .71428 Mdot
.3462 .41945 Mdot
.3501 .3727 Mdot
.52086 .70602 Mdot
.34495 .38712 Mdot
.68626 .60147 Mdot
.63174 .50151 Mdot
.37587 .65038 Mdot
.34585 .63541 Mdot
.54211 .69645 Mdot
.56658 .72613 Mdot
.53639 .73736 Mdot
.55934 .43219 Mdot
.34083 .40041 Mdot
.55057 .42083 Mdot
.60075 .398 Mdot
.3051 .41855 Mdot
.40829 .41826 Mdot
.53669 .41392 Mdot
.47449 .60298 Mdot
.72389 .57652 Mdot
.53382 .71263 Mdot
.35663 .67629 Mdot
.78994 .56638 Mdot
.36537 .62016 Mdot
.58326 .44925 Mdot
.24001 .58107 Mdot
.38168 .41767 Mdot
.70508 .59949 Mdot
.51361 .60692 Mdot
.70022 .59679 Mdot
.39052 .63796 Mdot
.40889 .40244 Mdot
.45874 .47519 Mdot
.58266 .356 Mdot
.52999 .51746 Mdot
.75929 .46292 Mdot
.30279 .57277 Mdot
.35432 .67886 Mdot
.61138 .42923 Mdot
.40006 .5389 Mdot
.34947 .29835 Mdot
.55837 .37766 Mdot
.55222 .43554 Mdot
.55141 .62253 Mdot
.52228 .39419 Mdot
.40362 .38626 Mdot
.5054 .60392 Mdot
.61917 .38806 Mdot
.63971 .39519 Mdot
.53856 .85621 Mdot
.56469 .41113 Mdot
.59191 .35951 Mdot
.58632 .37544 Mdot
.56866 .43306 Mdot
.3343 .41297 Mdot
.55829 .63672 Mdot
.38242 .63095 Mdot
.63247 .50144 Mdot
.37036 .66264 Mdot
.53457 .69346 Mdot
.61696 .53977 Mdot
.33495 .41209 Mdot
.69971 .59708 Mdot
.41287 .69408 Mdot
.6755 .47446 Mdot
.52885 .68304 Mdot
.78699 .53024 Mdot
.71926 .57793 Mdot
.52749 .34419 Mdot
.68129 .58646 Mdot
.57722 .70057 Mdot
.34722 .63634 Mdot
.53938 .36259 Mdot
.35389 .4288 Mdot
.3796 .38066 Mdot
.5987 .4428 Mdot
.28988 .60482 Mdot
.33364 .65126 Mdot
.68012 .53945 Mdot
.55573 .39375 Mdot
.55996 .43897 Mdot
.34991 .38308 Mdot
.54949 .72315 Mdot
.47881 .56733 Mdot
.71915 .604 Mdot
.53429 .37808 Mdot
.61229 .4213 Mdot
.50987 .50559 Mdot
.34361 .68234 Mdot
.38998 .53222 Mdot
.55375 .37594 Mdot
.49109 .50267 Mdot
.60777 .4381 Mdot
.62956 .39895 Mdot
.51748 .70344 Mdot
.64121 .35151 Mdot
.56264 .35801 Mdot
.42355 .37526 Mdot
.37234 .65586 Mdot
.37336 .40338 Mdot
.3147 .43288 Mdot
.39609 .5167 Mdot
.36233 .65734 Mdot
.53837 .41741 Mdot
.38054 .6732 Mdot
.60296 .43166 Mdot
.58044 .40053 Mdot
.35149 .67938 Mdot
.3427 .41173 Mdot
.30836 .46331 Mdot
.44729 .4023 Mdot
.57644 .43027 Mdot
.59951 .37899 Mdot
.75733 .60871 Mdot
.83673 .47289 Mdot
.56852 .35515 Mdot
.34143 .3934 Mdot
.59137 .36787 Mdot
.36076 .62409 Mdot
.68781 .58718 Mdot
.36689 .40724 Mdot
.5635 .70262 Mdot
.53393 .68332 Mdot
.52954 .76126 Mdot
.37929 .542 Mdot
.60925 .36735 Mdot
.41087 .39529 Mdot
.40726 .41592 Mdot
.60538 .50666 Mdot
.53745 .71133 Mdot
.68618 .59084 Mdot
.55021 .40148 Mdot
.48678 .42173 Mdot
.3888 .64537 Mdot
.79265 .74997 Mdot
.46292 .48099 Mdot
.69033 .56424 Mdot
.58655 .56603 Mdot
.39925 .53092 Mdot
.56354 .40714 Mdot
.71295 .61978 Mdot
.52859 .6933 Mdot
.6069 .43061 Mdot
.51201 .41461 Mdot
.46329 .66349 Mdot
.56422 .73507 Mdot
.39005 .65408 Mdot
.55056 .682 Mdot
.71133 .57094 Mdot
.38016 .54045 Mdot
.39058 .38685 Mdot
.5661 .38322 Mdot
.65736 .38345 Mdot
.54779 .71526 Mdot
.40431 .53337 Mdot
.60579 .37061 Mdot
.39731 .4001 Mdot
.53749 .71949 Mdot
.58644 .39053 Mdot
.3525 .30258 Mdot
.3631 .46309 Mdot
.55854 .71322 Mdot
.53534 .38246 Mdot
.61077 .46681 Mdot
.56357 .73796 Mdot
.57804 .7101 Mdot
.61378 .42703 Mdot
.71679 .61515 Mdot
.5625 .35964 Mdot
.36505 .63088 Mdot
.55613 .52999 Mdot
.35317 .66092 Mdot
.72765 .49706 Mdot
.62765 .41218 Mdot
.65591 .32907 Mdot
.3371 .38145 Mdot
.74023 .61262 Mdot
.63878 .22701 Mdot
.57491 .44745 Mdot
.25833 .36021 Mdot
.57389 .53481 Mdot
.47487 .50843 Mdot
.2401 .37816 Mdot
.71242 .6096 Mdot
.35202 .63714 Mdot
.60207 .36743 Mdot
.38347 .70046 Mdot
.70715 .61277 Mdot
.72738 .496 Mdot
.53864 .40423 Mdot
.38307 .40964 Mdot
.55848 .39482 Mdot
.39468 .39643 Mdot
.5868 .36932 Mdot
.35383 .33046 Mdot
.68251 .64368 Mdot
.7048 .42419 Mdot
.53408 .34105 Mdot
.33159 .72712 Mdot
.52096 .30574 Mdot
.68973 .59019 Mdot
.58282 .42859 Mdot
.39428 .52702 Mdot
.33328 .65826 Mdot
.40843 .71026 Mdot
.53545 .73535 Mdot
.38053 .64299 Mdot
.34639 .3976 Mdot
.575 .68905 Mdot
.40341 .53089 Mdot
.57145 .325 Mdot
.71365 .61785 Mdot
.36541 .655 Mdot
.56596 .37958 Mdot
.57843 .44088 Mdot
.38828 .75631 Mdot
.74847 .31265 Mdot
.34359 .38291 Mdot
.38893 .83881 Mdot
.40926 .38837 Mdot
.71749 .59491 Mdot
.51686 .70848 Mdot
.59431 .39029 Mdot
.56145 .36696 Mdot
.56177 .73575 Mdot
.3731 .36954 Mdot
.73496 .62622 Mdot
.82633 .48415 Mdot
.38803 .67304 Mdot
.73648 .38474 Mdot
.36579 .40973 Mdot
.73608 .38788 Mdot
.66406 .59087 Mdot
.40506 .56434 Mdot
.71241 .31657 Mdot
.33956 .65213 Mdot
.73724 .3818 Mdot
.38818 .40599 Mdot
.57378 .40653 Mdot
.39346 .54311 Mdot
.39173 .5544 Mdot
.355 .41294 Mdot
.52165 .71358 Mdot
.72464 .5891 Mdot
.55747 .39193 Mdot
.60367 .3224 Mdot
.54882 .19879 Mdot
.56701 .71748 Mdot
.60679 .33904 Mdot
.33924 .66485 Mdot
.59425 .37152 Mdot
.7094 .62461 Mdot
.34353 .64696 Mdot
.38539 .51433 Mdot
.67215 .47862 Mdot
.53955 .37814 Mdot
.50978 .59248 Mdot
.36639 .64275 Mdot
.83499 .46516 Mdot
.58724 .35909 Mdot
.37429 .65324 Mdot
.65668 .38187 Mdot
.30181 .6328 Mdot
.486 .58431 Mdot
.33452 .53937 Mdot
.51844 .67329 Mdot
.54255 .67912 Mdot
.80188 .34175 Mdot
.64903 .5824 Mdot
.38201 .65151 Mdot
.37853 .53265 Mdot
.74738 .34873 Mdot
.36336 .66431 Mdot
.53647 .37056 Mdot
.59576 .40438 Mdot
.50192 .32465 Mdot
.49562 .42843 Mdot
.38312 .55752 Mdot
.55472 .3138 Mdot
.58136 .41758 Mdot
.5769 .33115 Mdot
.60468 .37527 Mdot
.39994 .40929 Mdot
.33952 .65661 Mdot
.19211 .34394 Mdot
.37024 .68185 Mdot
.66349 .34782 Mdot
.55581 .71472 Mdot
.52861 .66839 Mdot
.57153 .38071 Mdot
.66992 .33076 Mdot
.15846 .57909 Mdot
.60681 .39564 Mdot
.51348 .60628 Mdot
.72487 .50372 Mdot
.5165 .35699 Mdot
.36828 .43882 Mdot
.6542 .37161 Mdot
.40896 .37871 Mdot
.3428 .64622 Mdot
.71061 .61057 Mdot
.73414 .59398 Mdot
.35749 .63493 Mdot
.56451 .36692 Mdot
.73421 .60656 Mdot
.57414 .38796 Mdot
.55509 .39997 Mdot
.49252 .49797 Mdot
.68207 .61035 Mdot
.53378 .7368 Mdot
.70695 .59524 Mdot
.36302 .42774 Mdot
.54481 .89468 Mdot
.6989 .58629 Mdot
.50806 .31974 Mdot
.60812 .5263 Mdot
.74091 .38624 Mdot
.37668 .37787 Mdot
.69327 .57809 Mdot
.33811 .64959 Mdot
.44895 .46581 Mdot
.53308 .2898 Mdot
.36562 .62033 Mdot
.55681 .37579 Mdot
.33383 .40628 Mdot
.40473 .41135 Mdot
.32169 .65718 Mdot
.37499 .37268 Mdot
.54228 .34672 Mdot
.54428 .40007 Mdot
.38313 .63981 Mdot
.46259 .16276 Mdot
.33886 .64154 Mdot
.45445 .37682 Mdot
.6012 .41115 Mdot
.36956 .40736 Mdot
.53044 .30505 Mdot
.32148 .43303 Mdot
.38763 .553 Mdot
.55827 .35508 Mdot
.69378 .58572 Mdot
.624 .50906 Mdot
.55903 .71564 Mdot
.24064 .57599 Mdot
.38388 .38565 Mdot
.32449 .6765 Mdot
.38246 .37768 Mdot
.36003 .36875 Mdot
.38467 .62618 Mdot
.37521 .41797 Mdot
.56516 .36173 Mdot
.19504 .47391 Mdot
.3744 .38097 Mdot
.35866 .64532 Mdot
.6995 .57833 Mdot
.34408 .3898 Mdot
.70452 .54091 Mdot
.5463 .39145 Mdot
.537 .67323 Mdot
.74103 .5814 Mdot
.34154 .3715 Mdot
.6881 .59123 Mdot
.54308 .71524 Mdot
.72697 .59495 Mdot
.40919 .67131 Mdot
.31645 .64602 Mdot
.68723 .40769 Mdot
.29698 .66041 Mdot
.37472 .42623 Mdot
.53716 .66048 Mdot
.54236 .37234 Mdot
.55496 .39558 Mdot
.72683 .57619 Mdot
.40135 .4125 Mdot
.28576 .61947 Mdot
.62211 .29879 Mdot
.29097 .5956 Mdot
.33557 .67661 Mdot
.76216 .56943 Mdot
.45975 .47855 Mdot
.36633 .70046 Mdot
.59507 .34474 Mdot
.39901 .53235 Mdot
.5815 .38569 Mdot
.73899 .51787 Mdot
.71503 .57397 Mdot
.42026 .77605 Mdot
.62497 .43006 Mdot
.55848 .73581 Mdot
.59124 .37421 Mdot
.43357 .66179 Mdot
.6363 .39465 Mdot
.72958 .58799 Mdot
.3641 .68862 Mdot
.33727 .40472 Mdot
.70395 .57458 Mdot
.53116 .68479 Mdot
.70505 .34186 Mdot
.53745 .37089 Mdot
.57832 .41574 Mdot
.56622 .73933 Mdot
.34983 .4242 Mdot
.5322 .69766 Mdot
.3756 .65128 Mdot
.70059 .5885 Mdot
.55901 .42901 Mdot
.59651 .33477 Mdot
.53594 .75242 Mdot
.37823 .6706 Mdot
.54625 .74621 Mdot
.3816 .67131 Mdot
.39849 .53721 Mdot
.62428 .40647 Mdot
.56364 .74503 Mdot
.60911 .35815 Mdot
.52927 .24132 Mdot
.64708 .48818 Mdot
.61213 .24164 Mdot
.53184 .7362 Mdot
.66571 .64135 Mdot
.35333 .64081 Mdot
.36833 .65436 Mdot
.44646 .36513 Mdot
.1782 .60812 Mdot
.48495 .5633 Mdot
.30217 .73891 Mdot
.37616 .65 Mdot
.3656 .64778 Mdot
.52582 .70499 Mdot
.35568 .42369 Mdot
.32939 .37939 Mdot
.5813 .72125 Mdot
.69989 .48448 Mdot
.3878 .40098 Mdot
.26723 .33749 Mdot
.56801 .6975 Mdot
.56916 .3461 Mdot
.40507 .4998 Mdot
.72947 .58854 Mdot
.71448 .50686 Mdot
.33152 .73612 Mdot
.58942 .38458 Mdot
.6363 .81093 Mdot
.53229 .73083 Mdot
.43174 .49754 Mdot
.38156 .59575 Mdot
.56661 .43882 Mdot
.586 .37261 Mdot
.57822 .36136 Mdot
.70793 .56259 Mdot
.53656 .21599 Mdot
.59157 .3877 Mdot
.69171 .45637 Mdot
.59615 .45389 Mdot
.36902 .76624 Mdot
.70687 .59494 Mdot
.79892 .48689 Mdot
.56215 .66622 Mdot
.3108 .59317 Mdot
.53942 .42454 Mdot
.37545 .64154 Mdot
.46064 .62913 Mdot
.36231 .67705 Mdot
.38644 .58514 Mdot
.74029 .33178 Mdot
.39802 .41539 Mdot
.60078 .44074 Mdot
.57189 .70363 Mdot
.33309 .3916 Mdot
.46586 .61932 Mdot
.52804 .89173 Mdot
.32528 .66951 Mdot
.37168 .85484 Mdot
.35606 .66385 Mdot
.38946 .55655 Mdot
.34799 .39807 Mdot
.67512 .3246 Mdot
.52376 .51457 Mdot
.34545 .41811 Mdot
.67438 .71434 Mdot
.3803 .35618 Mdot
.71971 .37829 Mdot
.42318 .3997 Mdot
.35231 .64719 Mdot
.32078 .67246 Mdot
.53077 .43317 Mdot
.55419 .36204 Mdot
.53025 .52111 Mdot
.53071 .44811 Mdot
.54058 .37855 Mdot
.55147 .70202 Mdot
.29726 .68302 Mdot
.37892 .70379 Mdot
.36372 .4143 Mdot
.38688 .65287 Mdot
.58949 .37406 Mdot
.57647 .43003 Mdot
.52364 .37619 Mdot
.7909 .59676 Mdot
.26626 .33645 Mdot
.5819 .40218 Mdot
.63632 .38793 Mdot
.52483 .68807 Mdot
.38899 .75741 Mdot
.40992 .83714 Mdot
.74293 .33865 Mdot
.60923 .37548 Mdot
.714 .59857 Mdot
.71289 .62543 Mdot
.5284 .35975 Mdot
.67774 .34734 Mdot
.75561 .57158 Mdot
.56585 .37929 Mdot
.70779 .37394 Mdot
.51288 .73317 Mdot
.40112 .5208 Mdot
.54727 .71487 Mdot
.33587 .37958 Mdot
.40109 .53522 Mdot
.54682 .69 Mdot
.68437 .47516 Mdot
.39177 .51728 Mdot
.30319 .62718 Mdot
.69142 .57958 Mdot
.59956 .36802 Mdot
.42155 .44532 Mdot
.56519 .71171 Mdot
.36857 .647 Mdot
.35975 .39445 Mdot
.33225 .65941 Mdot
.34991 .76528 Mdot
.7032 .49034 Mdot
.38127 .54595 Mdot
.37558 .63929 Mdot
.50478 .58276 Mdot
.71314 .59673 Mdot
.35311 .66833 Mdot
.65705 .32736 Mdot
.61395 .44358 Mdot
.15611 .49121 Mdot
.5719 .41813 Mdot
.36064 .5274 Mdot
.37173 .64599 Mdot
.38676 .51137 Mdot
.5658 .38476 Mdot
.5575 .67864 Mdot
.52799 .33657 Mdot
.57482 .38942 Mdot
.55953 .69024 Mdot
.57991 .40495 Mdot
.69473 .61898 Mdot
.40066 .37161 Mdot
.58842 .53274 Mdot
.76453 .55801 Mdot
.72043 .58238 Mdot
.57242 .50436 Mdot
.56721 .355 Mdot
.64387 .68692 Mdot
.38206 .40825 Mdot
.57674 .44767 Mdot
.74175 .49517 Mdot
.35679 .42022 Mdot
.36989 .39318 Mdot
.58204 .42423 Mdot
.34271 .6356 Mdot
.54415 .74261 Mdot
.71123 .59655 Mdot
.34128 .71378 Mdot
.58848 .39123 Mdot
.61143 .42985 Mdot
.71572 .57627 Mdot
.36321 .65466 Mdot
.55145 .42553 Mdot
.27008 .53266 Mdot
.62461 .49887 Mdot
.38951 .65092 Mdot
.61189 .44365 Mdot
.21102 .3863 Mdot
.33864 .3663 Mdot
.64461 .80881 Mdot
.6654 .63447 Mdot
.51922 .70655 Mdot
.62842 .34819 Mdot
.72695 .8119 Mdot
.69234 .58045 Mdot
.30548 .58433 Mdot
.57113 .40447 Mdot
.59803 .39157 Mdot
.39426 .41702 Mdot
.54205 .41571 Mdot
.39069 .41152 Mdot
.7726 .57916 Mdot
.18721 .6274 Mdot
.37234 .37276 Mdot
.39291 .40346 Mdot
.60235 .46307 Mdot
.79583 .60616 Mdot
.34969 .41045 Mdot
.53741 .37166 Mdot
.66478 .69201 Mdot
.50607 .4084 Mdot
.67414 .59836 Mdot
.76513 .59628 Mdot
.36349 .43902 Mdot
.51568 .29832 Mdot
.6027 .46266 Mdot
.37861 .32653 Mdot
.7109 .54675 Mdot
.37785 .65813 Mdot
.60254 .42603 Mdot
.3779 .53615 Mdot
.53341 .71686 Mdot
.64809 .35084 Mdot
.59056 .36124 Mdot
.36578 .43438 Mdot
.70291 .56419 Mdot
.35965 .66783 Mdot
.61618 .39602 Mdot
.52853 .75203 Mdot
.72234 .59755 Mdot
.36588 .38061 Mdot
.47207 .3562 Mdot
.7332 .60454 Mdot
.60434 .33684 Mdot
.57704 .40849 Mdot
.6152 .38924 Mdot
.49678 .37245 Mdot
.35973 .6354 Mdot
.58063 .70517 Mdot
.61266 .34165 Mdot
.46644 .47857 Mdot
.64851 .49819 Mdot
.536 .3624 Mdot
.34221 .39215 Mdot
.33844 .67727 Mdot
.38298 .53345 Mdot
.74435 .37162 Mdot
.59126 .40988 Mdot
.26275 .33958 Mdot
.80916 .53617 Mdot
.38976 .5209 Mdot
.33112 .41077 Mdot
.70471 .59838 Mdot
.59242 .41815 Mdot
.69525 .45083 Mdot
.53667 .38438 Mdot
.50358 .36875 Mdot
.52103 .71778 Mdot
.36917 .6686 Mdot
.67017 .44033 Mdot
.53164 .71408 Mdot
.3695 .39381 Mdot
.28141 .32252 Mdot
.33339 .37559 Mdot
.35071 .37328 Mdot
.42796 .5778 Mdot
.35668 .6294 Mdot
.74251 .80036 Mdot
.84214 .49088 Mdot
.55909 .35145 Mdot
.37138 .62585 Mdot
.35118 .40372 Mdot
.52823 .39809 Mdot
.38414 .41672 Mdot
.37713 .44089 Mdot
.54527 .39553 Mdot
.54263 .3891 Mdot
.70602 .4143 Mdot
.27005 .33912 Mdot
.69787 .58192 Mdot
.38997 .38065 Mdot
.42137 .34699 Mdot
.59339 .39292 Mdot
.57141 .35725 Mdot
.45836 .63416 Mdot
.69985 .57414 Mdot
.38883 .26952 Mdot
.55919 .39842 Mdot
.76648 .52495 Mdot
.54868 .36164 Mdot
.32252 .39188 Mdot
.33898 .62726 Mdot
.66264 .342 Mdot
.5325 .73995 Mdot
.35794 .36452 Mdot
.71732 .57081 Mdot
.37654 .44814 Mdot
.39769 .29625 Mdot
.34469 .64043 Mdot
.3925 .39647 Mdot
.56767 .67781 Mdot
.35563 .6566 Mdot
.34256 .63776 Mdot
.46844 .61515 Mdot
.55853 .672 Mdot
.69211 .56472 Mdot
.34611 .67402 Mdot
.3527 .30436 Mdot
.35161 .65005 Mdot
.39002 .29371 Mdot
.60158 .36067 Mdot
.69008 .45984 Mdot
.64139 .3378 Mdot
.52437 .43032 Mdot
.34479 .66352 Mdot
.72329 .59044 Mdot
.55181 .42821 Mdot
.36603 .37107 Mdot
.70912 .58221 Mdot
.41339 .4978 Mdot
.54155 .6628 Mdot
.40258 .4176 Mdot
.38301 .67169 Mdot
.3845 .42102 Mdot
.72096 .50432 Mdot
.73577 .62941 Mdot
.46853 .6369 Mdot
.53899 .51786 Mdot
.56476 .33264 Mdot
.63683 .4129 Mdot
.55531 .43182 Mdot
.56806 .36245 Mdot
.55782 .71259 Mdot
.68963 .55888 Mdot
.34414 .3888 Mdot
.54448 .18993 Mdot
.37182 .63792 Mdot
.50594 .59733 Mdot
.50724 .35946 Mdot
.60396 .43204 Mdot
.35404 .40142 Mdot
.38086 .44183 Mdot
.55922 .23224 Mdot
.55772 .74049 Mdot
.51004 .41645 Mdot
.52463 .40437 Mdot
.64148 .46969 Mdot
.34682 .66217 Mdot
.30967 .51636 Mdot
.50683 .70485 Mdot
.39438 .87226 Mdot
.53276 .71132 Mdot
.60407 .63705 Mdot
.37388 .41944 Mdot
.689 .59968 Mdot
.55252 .37493 Mdot
.45722 .40267 Mdot
.33771 .42248 Mdot
.57797 .6687 Mdot
.69679 .59722 Mdot
.3267 .4871 Mdot
.37782 .632 Mdot
.61798 .3889 Mdot
.54571 .36339 Mdot
.56214 .4255 Mdot
.53114 .39843 Mdot
.38494 .64268 Mdot
.53821 .39115 Mdot
.38504 .61987 Mdot
.4053 .28971 Mdot
.74083 .48711 Mdot
.57581 .71053 Mdot
.40238 .76224 Mdot
.35307 .37238 Mdot
.31971 .28514 Mdot
.40114 .27258 Mdot
.64644 .48854 Mdot
.41315 .65018 Mdot
.61971 .38735 Mdot
.52284 .71463 Mdot
.35096 .72278 Mdot
.5752 .70678 Mdot
.15045 .41367 Mdot
.50541 .32043 Mdot
.35236 .5084 Mdot
.54965 .41669 Mdot
.56977 .73912 Mdot
.48802 .31769 Mdot
.60959 .33727 Mdot
.73569 .61007 Mdot
.38129 .30358 Mdot
.42399 .45184 Mdot
.68659 .58723 Mdot
.54956 .39701 Mdot
.4087 .41873 Mdot
.55671 .37072 Mdot
.5491 .3805 Mdot
.60779 .39574 Mdot
.35885 .61451 Mdot
.58367 .34981 Mdot
.56041 .3612 Mdot
.75758 .31896 Mdot
.4919 .65024 Mdot
.53729 .67728 Mdot
.60269 .23737 Mdot
.71163 .58755 Mdot
.33593 .38024 Mdot
.57241 .53346 Mdot
.37086 .63116 Mdot
.56155 .23207 Mdot
.56585 .42165 Mdot
.28735 .57007 Mdot
.34242 .68544 Mdot
.71911 .611 Mdot
.3814 .52852 Mdot
.30447 .48667 Mdot
.51561 .71783 Mdot
.37917 .55271 Mdot
.55941 .71783 Mdot
.63342 .24675 Mdot
.39274 .40714 Mdot
.56577 .33257 Mdot
.3574 .67107 Mdot
.57148 .68996 Mdot
.69403 .44945 Mdot
.58959 .36437 Mdot
.53196 .73663 Mdot
.63287 .33926 Mdot
.63045 .51097 Mdot
.56558 .53337 Mdot
.57479 .69145 Mdot
.34736 .68834 Mdot
.35038 .65917 Mdot
.68435 .58746 Mdot
.35157 .36477 Mdot
.35589 .42878 Mdot
.348 .65426 Mdot
.55118 .83808 Mdot
.58785 .38944 Mdot
.59435 .40079 Mdot
.46058 .47389 Mdot
.52618 .3969 Mdot
.75352 .61526 Mdot
.39387 .55697 Mdot
.35114 .42907 Mdot
.55328 .43025 Mdot
.55179 .42535 Mdot
.57303 .41037 Mdot
.70408 .47767 Mdot
.54809 .71741 Mdot
.58319 .41731 Mdot
.71408 .61871 Mdot
.40982 .48432 Mdot
.54418 .36995 Mdot
.59485 .33294 Mdot
.38907 .4142 Mdot
.615 .71025 Mdot
.36988 .64355 Mdot
.56518 .72228 Mdot
.57107 .71011 Mdot
.75395 .45515 Mdot
.3145 .3942 Mdot
.38244 .55839 Mdot
.36626 .75071 Mdot
.3803 .53638 Mdot
.69474 .59921 Mdot
.48293 .57798 Mdot
.50274 .67894 Mdot
.54178 .67832 Mdot
.32685 .68772 Mdot
.58517 .44596 Mdot
.54178 .37078 Mdot
.30576 .59455 Mdot
.60466 .3973 Mdot
.69328 .5848 Mdot
.35008 .626 Mdot
.39175 .40324 Mdot
.71245 .62379 Mdot
.3665 .65789 Mdot
.34667 .42109 Mdot
.55693 .4407 Mdot
.53375 .37416 Mdot
.36257 .39242 Mdot
.36788 .3787 Mdot
.57681 .37621 Mdot
.73417 .30053 Mdot
.34358 .42257 Mdot
.35481 .39434 Mdot
.41029 .47715 Mdot
.51632 .70007 Mdot
.48273 .38214 Mdot
.36612 .62562 Mdot
.56674 .35995 Mdot
.57576 .71852 Mdot
.70127 .60634 Mdot
.37296 .38727 Mdot
.60327 .42236 Mdot
.58431 .39554 Mdot
.71256 .59915 Mdot
.68089 .61296 Mdot
.70693 .57641 Mdot
.33192 .63683 Mdot
.54985 .40585 Mdot
.34689 .40498 Mdot
.37897 .63262 Mdot
.73067 .61142 Mdot
.6805 .58576 Mdot
.7154 .30257 Mdot
.58679 .38287 Mdot
.72359 .62522 Mdot
.57708 .89477 Mdot
.71308 .34329 Mdot
.4022 .53643 Mdot
.50871 .73216 Mdot
.69543 .65014 Mdot
.74123 .58343 Mdot
.3749 .66638 Mdot
.50975 .60673 Mdot
.69806 .56806 Mdot
.60828 .40741 Mdot
.6029 .37911 Mdot
.60565 .34578 Mdot
.71251 .58467 Mdot
.70684 .49001 Mdot
.40568 .40089 Mdot
.43807 .22517 Mdot
.71139 .58743 Mdot
.56682 .68114 Mdot
.53795 .75436 Mdot
.53032 .70634 Mdot
.6222 .40807 Mdot
.60313 .22097 Mdot
.41322 .31959 Mdot
.38994 .26316 Mdot
.37837 .63616 Mdot
.38156 .44115 Mdot
.41379 .52691 Mdot
.37046 .39267 Mdot
.53913 .72704 Mdot
.72322 .59682 Mdot
.39485 .41752 Mdot
.34258 .63838 Mdot
.34764 .65986 Mdot
.53648 .74466 Mdot
.542 .71247 Mdot
.54187 .6983 Mdot
.35535 .36442 Mdot
.37461 .41882 Mdot
.56282 .42896 Mdot
.37563 .38489 Mdot
.81762 .54534 Mdot
.74339 .63405 Mdot
.54059 .74991 Mdot
.36218 .63976 Mdot
.35328 .38823 Mdot
.59875 .36626 Mdot
.572 .62228 Mdot
.54918 .65712 Mdot
.72954 .59969 Mdot
.19591 .55081 Mdot
.17495 .62144 Mdot
.61459 .43702 Mdot
.38087 .66536 Mdot
.66781 .33729 Mdot
.57553 .36353 Mdot
.52136 .72265 Mdot
.81422 .49906 Mdot
.38585 .51753 Mdot
.55068 .37011 Mdot
.53235 .42139 Mdot
.33712 .64814 Mdot
.571 .53266 Mdot
.60942 .40738 Mdot
.49094 .60209 Mdot
.33383 .68064 Mdot
.50732 .70822 Mdot
.829 .37174 Mdot
.42697 .49352 Mdot
.71109 .51897 Mdot
.40145 .52561 Mdot
.60551 .40227 Mdot
.55344 .70392 Mdot
.72469 .61566 Mdot
.54777 .70651 Mdot
.32948 .40349 Mdot
.5152 .70891 Mdot
.60871 .3832 Mdot
.34772 .41058 Mdot
.36403 .6558 Mdot
.51636 .5822 Mdot
.64729 .26644 Mdot
.55541 .67774 Mdot
.40491 .52843 Mdot
.54277 .38754 Mdot
.33481 .2991 Mdot
.5355 .43589 Mdot
.56093 .35875 Mdot
.35524 .67898 Mdot
.35789 .40861 Mdot
.33665 .67739 Mdot
.60087 .32973 Mdot
.2885 .34508 Mdot
.36936 .63548 Mdot
.45299 .4122 Mdot
.71853 .57731 Mdot
.69973 .48812 Mdot
.56005 .38615 Mdot
.3605 .67019 Mdot
.55815 .4113 Mdot
.39239 .38263 Mdot
.6655 .48839 Mdot
.61128 .49641 Mdot
.33829 .66356 Mdot
.36554 .49085 Mdot
.6324 .52045 Mdot
.47666 .39349 Mdot
.37243 .65871 Mdot
.63444 .22687 Mdot
.39181 .52741 Mdot
.71717 .60462 Mdot
.68361 .61737 Mdot
.69586 .61261 Mdot
.60235 .39603 Mdot
.35041 .32356 Mdot
.67918 .59569 Mdot
.3279 .65363 Mdot
.68571 .61019 Mdot
.78523 .572 Mdot
.2891 .60733 Mdot
.72063 .58127 Mdot
.56326 .39139 Mdot
.66407 .36684 Mdot
.51112 .60521 Mdot
.53258 .66977 Mdot
.27051 .43141 Mdot
.75953 .32367 Mdot
.59438 .38912 Mdot
.32632 .33064 Mdot
.32621 .41253 Mdot
.61462 .60901 Mdot
.61174 .49434 Mdot
.48932 .55152 Mdot
.35404 .39058 Mdot
.55543 .52627 Mdot
.33469 .40362 Mdot
.53512 .33952 Mdot
.57941 .40071 Mdot
.34811 .36356 Mdot
.2319 .5728 Mdot
.60604 .20046 Mdot
.2867 .59111 Mdot
.33989 .40316 Mdot
.37213 .65613 Mdot
.36855 .67557 Mdot
.35626 .67829 Mdot
.55892 .70201 Mdot
.39087 .39025 Mdot
.59106 .41242 Mdot
.52664 .69031 Mdot
.55081 .3873 Mdot
.34291 .65271 Mdot
.63595 .49188 Mdot
.39157 .40573 Mdot
.56409 .37943 Mdot
.46402 .34225 Mdot
.5559 .72208 Mdot
.71485 .59611 Mdot
.19336 .51973 Mdot
.50269 .71606 Mdot
.36301 .68698 Mdot
.35055 .44106 Mdot
.56119 .75973 Mdot
.57713 .64673 Mdot
.56015 .34998 Mdot
.5459 .35854 Mdot
.51409 .61364 Mdot
.49992 .32031 Mdot
.61175 .4076 Mdot
.53253 .68396 Mdot
.52176 .68521 Mdot
.55966 .41119 Mdot
.38344 .3808 Mdot
.6858 .57297 Mdot
.728 .57727 Mdot
.53761 .34115 Mdot
.5386 .5209 Mdot
.69084 .45787 Mdot
.54126 .41982 Mdot
.62218 .35655 Mdot
.56197 .67164 Mdot
.40311 .52957 Mdot
.51473 .50807 Mdot
.68588 .60178 Mdot
.56669 .4042 Mdot
.55109 .20138 Mdot
.38519 .38767 Mdot
.53575 .73997 Mdot
.37965 .62596 Mdot
.73385 .60666 Mdot
.52948 .74371 Mdot
.55968 .41115 Mdot
.55119 .42523 Mdot
.35332 .67023 Mdot
.32062 .39479 Mdot
.71898 .58771 Mdot
.52589 .69015 Mdot
.68782 .59803 Mdot
.37738 .41707 Mdot
.36062 .38478 Mdot
.51839 .38815 Mdot
.52777 .43387 Mdot
.56318 .6874 Mdot
.5851 .33903 Mdot
.53138 .69295 Mdot
.38781 .75666 Mdot
.38861 .64507 Mdot
.55475 .4358 Mdot
.31337 .40525 Mdot
.34418 .65401 Mdot
.59409 .3833 Mdot
.51337 .61586 Mdot
.59432 .43973 Mdot
.5803 .72114 Mdot
.82181 .47023 Mdot
.70095 .6111 Mdot
.64518 .43437 Mdot
.60431 .28098 Mdot
.52929 .40522 Mdot
.52854 .67545 Mdot
.38048 .31233 Mdot
.36428 .63302 Mdot
.36786 .42058 Mdot
.59965 .7741 Mdot
.35642 .64708 Mdot
.56414 .39686 Mdot
.69993 .58619 Mdot
.33688 .39959 Mdot
.39164 .54851 Mdot
.51066 .52007 Mdot
.65677 .35902 Mdot
.51178 .37821 Mdot
.61685 .39667 Mdot
.30091 .73805 Mdot
.54406 .70073 Mdot
.35228 .40147 Mdot
.38167 .6622 Mdot
.35092 .63538 Mdot
.54957 .72347 Mdot
.41806 .4621 Mdot
.2585 .58714 Mdot
.61948 .87562 Mdot
.53247 .74659 Mdot
.69119 .61294 Mdot
.66227 .48911 Mdot
.52879 .70775 Mdot
.5617 .70957 Mdot
.55298 .66498 Mdot
.29919 .60161 Mdot
.34098 .40412 Mdot
.58577 .39634 Mdot
.35199 .44872 Mdot
.60434 .4003 Mdot
.68921 .52212 Mdot
.34397 .65076 Mdot
.36879 .42091 Mdot
.70791 .53936 Mdot
.63807 .39143 Mdot
.57588 .36806 Mdot
.67215 .53973 Mdot
.66191 .42981 Mdot
.74103 .37876 Mdot
.52518 .37898 Mdot
.55139 .7117 Mdot
.31657 .44146 Mdot
.6073 .33862 Mdot
.46053 .34434 Mdot
.35286 .66136 Mdot
.38122 .54799 Mdot
.56172 .33142 Mdot
.6227 .37046 Mdot
.33684 .39541 Mdot
.3927 .42007 Mdot
.67863 .59164 Mdot
.19631 .48175 Mdot
.35656 .66071 Mdot
.32897 .52602 Mdot
.55823 .3593 Mdot
.40419 .6142 Mdot
.82202 .49091 Mdot
.58938 .37803 Mdot
.47192 .60867 Mdot
.55989 .23273 Mdot
.60905 .42525 Mdot
.39916 .25564 Mdot
.35686 .64137 Mdot
.74905 .5077 Mdot
.53757 .39953 Mdot
.52704 .72957 Mdot
.35992 .42509 Mdot
.40294 .41734 Mdot
.72612 .61597 Mdot
.83146 .52843 Mdot
.22548 .665 Mdot
.37066 .42175 Mdot
.58518 .36172 Mdot
.36839 .64275 Mdot
.38664 .55115 Mdot
.65039 .35569 Mdot
.4198 .67401 Mdot
.38583 .39023 Mdot
.61676 .34277 Mdot
.28245 .57127 Mdot
.56261 .53019 Mdot
.27535 .30482 Mdot
.35016 .67771 Mdot
.68368 .59807 Mdot
.49722 .40645 Mdot
.36715 .75353 Mdot
.53409 .37326 Mdot
.69624 .5205 Mdot
.32563 .36841 Mdot
.68762 .58856 Mdot
.56781 .36641 Mdot
.61012 .41153 Mdot
.5687 .51408 Mdot
.6788 .61488 Mdot
.60953 .40899 Mdot
.62557 .4289 Mdot
.36866 .42743 Mdot
.39472 .55645 Mdot
.39107 .40201 Mdot
.55828 .37089 Mdot
.80885 .4399 Mdot
.39867 .3954 Mdot
.28553 .44501 Mdot
.65883 .62569 Mdot
.37201 .63222 Mdot
.64559 .3624 Mdot
.59366 .35579 Mdot
.2446 .32207 Mdot
.38874 .55356 Mdot
.45405 .84542 Mdot
.57235 .73438 Mdot
.71838 .23823 Mdot
.50187 .71147 Mdot
.35545 .49295 Mdot
.48927 .64354 Mdot
.61667 .3467 Mdot
.4652 .38808 Mdot
.38112 .26208 Mdot
.38742 .60663 Mdot
.32696 .28249 Mdot
.554 .36215 Mdot
.57006 .40761 Mdot
.52547 .69985 Mdot
.36681 .51753 Mdot
.66165 .33914 Mdot
.51706 .50965 Mdot
.72033 .60876 Mdot
.37633 .40373 Mdot
.60355 .37732 Mdot
.21786 .56538 Mdot
.56232 .67974 Mdot
.65866 .28352 Mdot
.5639 .38211 Mdot
.67142 .35334 Mdot
.36798 .51993 Mdot
.36654 .65372 Mdot
.57486 .69098 Mdot
.56058 .67483 Mdot
.60351 .40327 Mdot
.38349 .63493 Mdot
.57776 .43433 Mdot
.64077 .51765 Mdot
.63159 .34172 Mdot
.69676 .60229 Mdot
.57921 .35577 Mdot
.63916 .28309 Mdot
.35006 .20935 Mdot
.629 .42615 Mdot
.34778 .37181 Mdot
.54089 .6949 Mdot
.5439 .71993 Mdot
.35241 .42721 Mdot
.54373 .72064 Mdot
.43766 .23034 Mdot
.3068 .32787 Mdot
.6927 .59805 Mdot
.42111 .2812 Mdot
.70911 .61207 Mdot
.38071 .54705 Mdot
.58423 .38028 Mdot
.46364 .72713 Mdot
.5254 .74225 Mdot
.78957 .56663 Mdot
.34858 .65127 Mdot
.3897 .55465 Mdot
.54217 .39182 Mdot
.68629 .54381 Mdot
.53112 .72459 Mdot
.45401 .55127 Mdot
.59635 .4055 Mdot
.3762 .3713 Mdot
.60637 .42882 Mdot
.57374 .46012 Mdot
.38947 .55752 Mdot
.61659 .42072 Mdot
.36666 .65775 Mdot
.39679 .39968 Mdot
.35367 .51803 Mdot
.5646 .71009 Mdot
.54517 .37671 Mdot
.58288 .36164 Mdot
.3539 .43721 Mdot
.56385 .35068 Mdot
.38169 .64393 Mdot
.83076 .69983 Mdot
.7088 .57439 Mdot
.40284 .52753 Mdot
.24031 .45343 Mdot
.61423 .41941 Mdot
.55915 .43124 Mdot
.46713 .5287 Mdot
.55505 .2024 Mdot
.37403 .64228 Mdot
.5134 .36896 Mdot
.53084 .67935 Mdot
.72006 .58766 Mdot
.33219 .65462 Mdot
.54274 .39846 Mdot
.5837 .40513 Mdot
.68932 .58771 Mdot
.67043 .53816 Mdot
.7304 .62727 Mdot
.37962 .65655 Mdot
.30783 .34465 Mdot
.57359 .62192 Mdot
.58108 .38764 Mdot
.40294 .51344 Mdot
.35926 .4048 Mdot
.37516 .65564 Mdot
.52495 .21306 Mdot
.53233 .34087 Mdot
.39019 .65516 Mdot
.36218 .65749 Mdot
.57135 .34886 Mdot
.31583 .38872 Mdot
.36188 .44703 Mdot
.35697 .40252 Mdot
.74507 .48048 Mdot
.38007 .80875 Mdot
.54544 .69735 Mdot
.36262 .64262 Mdot
.57435 .7229 Mdot
.70246 .56809 Mdot
.64264 .50256 Mdot
.55297 .67292 Mdot
.37305 .36789 Mdot
.57387 .71166 Mdot
.57817 .43526 Mdot
.34966 .63017 Mdot
.56658 .69588 Mdot
.53006 .40113 Mdot
.62188 .37891 Mdot
.49761 .43081 Mdot
.69226 .56684 Mdot
.55328 .52697 Mdot
.55856 .39177 Mdot
.38265 .52734 Mdot
.57203 .3775 Mdot
.3828 .64203 Mdot
.52049 .58332 Mdot
.57612 .41982 Mdot
.52631 .74319 Mdot
.40792 .82787 Mdot
.51654 .68988 Mdot
.57186 .46507 Mdot
.5564 .37679 Mdot
.58422 .38721 Mdot
.54365 .39256 Mdot
.41868 .45665 Mdot
.37903 .67767 Mdot
.50182 .3792 Mdot
.55213 .74638 Mdot
.36882 .39023 Mdot
.40073 .39641 Mdot
.4768 .54963 Mdot
.37824 .55028 Mdot
.37847 .62875 Mdot
.58575 .38848 Mdot
.45518 .55488 Mdot
.48798 .51175 Mdot
.28136 .58223 Mdot
.53908 .76582 Mdot
.54527 .67827 Mdot
.35532 .36831 Mdot
.55343 .68612 Mdot
.54034 .39384 Mdot
.61782 .34412 Mdot
.35238 .51403 Mdot
.39742 .62333 Mdot
.72131 .59086 Mdot
.55161 .38163 Mdot
.70151 .46017 Mdot
.52482 .68815 Mdot
.5612 .67203 Mdot
.57467 .43284 Mdot
.32242 .41344 Mdot
.42188 .15485 Mdot
.36884 .62413 Mdot
.33382 .30508 Mdot
.40793 .4461 Mdot
.62879 .48194 Mdot
.35627 .63472 Mdot
.47853 .60041 Mdot
.52663 .67137 Mdot
.81129 .41827 Mdot
.36383 .38957 Mdot
.72009 .59031 Mdot
.5296 .38291 Mdot
.37245 .36754 Mdot
.55883 .74917 Mdot
.33693 .41453 Mdot
.57086 .33153 Mdot
.33075 .67212 Mdot
.53607 .71681 Mdot
.32185 .6784 Mdot
.332 .39386 Mdot
.70651 .6122 Mdot
.7574 .52264 Mdot
.35039 .30043 Mdot
.55798 .23384 Mdot
.58444 .41722 Mdot
.46373 .67769 Mdot
.59369 .41218 Mdot
.40842 .40266 Mdot
.56026 .38694 Mdot
.64296 .39502 Mdot
.52586 .66999 Mdot
.53305 .36472 Mdot
.57255 .3562 Mdot
.45142 .34722 Mdot
.58426 .37312 Mdot
.56117 .40974 Mdot
.51705 .39147 Mdot
.33645 .36553 Mdot
.5302 .36793 Mdot
.37083 .36981 Mdot
.29997 .57907 Mdot
.56319 .71412 Mdot
.7009 .56877 Mdot
.71067 .57063 Mdot
.71209 .52199 Mdot
.70169 .46729 Mdot
.39147 .48617 Mdot
.38601 .39819 Mdot
.34528 .6623 Mdot
.57217 .43308 Mdot
.64857 .2337 Mdot
.80264 .44434 Mdot
.51512 .68038 Mdot
.57032 .69802 Mdot
.53294 .38283 Mdot
.17035 .60339 Mdot
.53062 .37234 Mdot
.46109 .47843 Mdot
.60135 .39733 Mdot
.55727 .43756 Mdot
.57404 .68648 Mdot
.72068 .50516 Mdot
.583 .41721 Mdot
.33651 .39588 Mdot
.7205 .59674 Mdot
.67368 .37643 Mdot
.80139 .4717 Mdot
.45522 .37873 Mdot
.6312 .30123 Mdot
.56576 .41872 Mdot
.52091 .70058 Mdot
.33906 .40003 Mdot
.47366 .48842 Mdot
.38038 .63908 Mdot
.52623 .52288 Mdot
.39557 .28908 Mdot
.37511 .59332 Mdot
.72228 .59656 Mdot
.58443 .69352 Mdot
.61125 .3875 Mdot
.55522 .69912 Mdot
.51749 .35577 Mdot
.48832 .51792 Mdot
.69349 .60143 Mdot
.36567 .35963 Mdot
.37202 .65562 Mdot
.39747 .38428 Mdot
.61106 .24094 Mdot
.80404 .44136 Mdot
.7231 .24125 Mdot
.51432 .71895 Mdot
.46028 .18345 Mdot
.35477 .41394 Mdot
.59783 .40783 Mdot
.616 .87653 Mdot
.3647 .40857 Mdot
.37347 .36977 Mdot
.50386 .55016 Mdot
.72873 .49807 Mdot
.57997 .33776 Mdot
.3463 .42663 Mdot
.58634 .70492 Mdot
.7009 .59598 Mdot
.53362 .40617 Mdot
.5688 .33082 Mdot
.39418 .41782 Mdot
.53551 .728 Mdot
.69416 .5119 Mdot
.54706 .71289 Mdot
.34251 .40629 Mdot
.55655 .72831 Mdot
.31158 .46787 Mdot
.55571 .67527 Mdot
.58762 .3557 Mdot
.58479 .3887 Mdot
.42588 .61479 Mdot
.36066 .38477 Mdot
.55816 .43102 Mdot
.57508 .4053 Mdot
.34904 .4073 Mdot
.50493 .67325 Mdot
.51208 .1942 Mdot
.56786 .43524 Mdot
.587 .39273 Mdot
.70404 .57284 Mdot
.60737 .51805 Mdot
.45273 .47664 Mdot
.53186 .40702 Mdot
.69738 .61438 Mdot
.3586 .36509 Mdot
.57298 .37617 Mdot
.7231 .50662 Mdot
.51599 .73804 Mdot
.5533 .4159 Mdot
.38722 .54819 Mdot
.60964 .39936 Mdot
.40338 .16874 Mdot
.54227 .38404 Mdot
.34808 .39617 Mdot
.35599 .42099 Mdot
.54766 .7745 Mdot
.36821 .39506 Mdot
.4015 .53787 Mdot
.34974 .65821 Mdot
.28841 .30551 Mdot
.39995 .54274 Mdot
.61655 .42439 Mdot
.8433 .49727 Mdot
.57429 .3303 Mdot
.60434 .33399 Mdot
.79711 .60575 Mdot
.40142 .52675 Mdot
.3602 .41292 Mdot
.22837 .56213 Mdot
.5693 .34156 Mdot
.377 .62691 Mdot
.59947 .33514 Mdot
.55388 .41598 Mdot
.63575 .42055 Mdot
.30316 .34006 Mdot
.36262 .61989 Mdot
.48128 .38432 Mdot
.53402 .40689 Mdot
.55565 .20313 Mdot
.59778 .36851 Mdot
.72881 .59135 Mdot
.38537 .41153 Mdot
.55465 .68979 Mdot
.69901 .60065 Mdot
.61489 .40044 Mdot
.71083 .5853 Mdot
.5523 .6989 Mdot
.35306 .67426 Mdot
.59187 .35769 Mdot
.67391 .59792 Mdot
.72392 .59895 Mdot
.58924 .42769 Mdot
.36646 .42354 Mdot
.54117 .43839 Mdot
.57605 .37531 Mdot
.54733 .40079 Mdot
.35842 .42954 Mdot
.70136 .77809 Mdot
.57066 .40978 Mdot
.47676 .60363 Mdot
.40846 .38256 Mdot
.39704 .552 Mdot
.5393 .6822 Mdot
.62679 .42395 Mdot
.35312 .63245 Mdot
.3498 .6562 Mdot
.51579 .73 Mdot
.38652 .42398 Mdot
.53842 .72044 Mdot
.63137 .42335 Mdot
.61405 .34258 Mdot
.53011 .38434 Mdot
.59674 .77896 Mdot
.29694 .47708 Mdot
.35544 .38166 Mdot
.52226 .67815 Mdot
.52637 .51867 Mdot
.35755 .62565 Mdot
.57102 .67895 Mdot
.39463 .44237 Mdot
.37138 .43306 Mdot
.34726 .42432 Mdot
.71165 .61681 Mdot
.53608 .71127 Mdot
.38323 .44837 Mdot
.36372 .44605 Mdot
.57736 .43079 Mdot
.538 .41109 Mdot
.34289 .36512 Mdot
.59828 .73025 Mdot
.7059 .60854 Mdot
.51866 .70225 Mdot
.37487 .16524 Mdot
.37055 .62412 Mdot
.45418 .34686 Mdot
.52892 .40092 Mdot
.44429 .89994 Mdot
.52923 .37369 Mdot
.58926 .36283 Mdot
.33586 .37957 Mdot
.69675 .62557 Mdot
.70311 .59397 Mdot
.35482 .41497 Mdot
.37291 .43991 Mdot
.72642 .60755 Mdot
.49624 .55836 Mdot
.44486 .16193 Mdot
.48673 .5026 Mdot
.34838 .38541 Mdot
.35273 .29549 Mdot
.33635 .66347 Mdot
.3964 .37265 Mdot
.31266 .67688 Mdot
.56428 .71745 Mdot
.55988 .68091 Mdot
.34894 .66998 Mdot
.56731 .41073 Mdot
.5228 .72936 Mdot
.61554 .45073 Mdot
.34583 .49599 Mdot
.42204 .65661 Mdot
.69708 .25037 Mdot
.58292 .35253 Mdot
.6743 .34646 Mdot
.2826 .67129 Mdot
.60922 .43538 Mdot
.54284 .29611 Mdot
.71722 .58691 Mdot
.40241 .37584 Mdot
.34227 .62976 Mdot
.25713 .35964 Mdot
.58256 .3877 Mdot
.34387 .3901 Mdot
.36288 .62271 Mdot
.32351 .48917 Mdot
.49061 .60141 Mdot
.59761 .43317 Mdot
.66885 .84721 Mdot
.33383 .4116 Mdot
.55418 .68961 Mdot
.44101 .32757 Mdot
.39207 .37679 Mdot
.52903 .62658 Mdot
.5788 .73393 Mdot
.5017 .49495 Mdot
.34825 .43052 Mdot
.73431 .62586 Mdot
.38006 .40729 Mdot
.69957 .62188 Mdot
.35041 .44068 Mdot
.54853 .72859 Mdot
.56867 .36994 Mdot
.55232 .72464 Mdot
.73087 .59163 Mdot
.51578 .72472 Mdot
.3422 .62991 Mdot
.39731 .51819 Mdot
.34214 .6542 Mdot
.6529 .49471 Mdot
.503 .22015 Mdot
.36845 .66934 Mdot
.45668 .58074 Mdot
.60815 .39157 Mdot
.32277 .39168 Mdot
.55792 .69473 Mdot
.50511 .68727 Mdot
.54817 .52458 Mdot
.34429 .41544 Mdot
.54044 .73182 Mdot
.35708 .29968 Mdot
.54509 .84484 Mdot
.64089 .37435 Mdot
.37564 .79049 Mdot
.34751 .40203 Mdot
.53616 .66522 Mdot
.4599 .47409 Mdot
.40096 .41204 Mdot
.56536 .69166 Mdot
.37 .66127 Mdot
.35748 .63057 Mdot
.56299 .35174 Mdot
.32315 .65959 Mdot
.5372 .67013 Mdot
.55486 .20036 Mdot
.37963 .42062 Mdot
.27896 .46632 Mdot
.71844 .58091 Mdot
.56018 .70601 Mdot
.54866 .34884 Mdot
.31216 .40545 Mdot
.57193 .72185 Mdot
.20905 .64905 Mdot
.29111 .2328 Mdot
.53921 .73201 Mdot
.38589 .4105 Mdot
.37431 .38862 Mdot
.63221 .40567 Mdot
.52994 .51644 Mdot
.5318 .72738 Mdot
.46269 .72584 Mdot
.70106 .43587 Mdot
.39848 .53783 Mdot
.75837 .32125 Mdot
.58152 .41672 Mdot
.5644 .41883 Mdot
.3813 .65196 Mdot
.58033 .36836 Mdot
.37491 .44169 Mdot
.52802 .37535 Mdot
.34538 .68298 Mdot
.51063 .71819 Mdot
.58231 .38238 Mdot
.71934 .58534 Mdot
.34288 .67952 Mdot
.37159 .67631 Mdot
.56082 .72734 Mdot
.37071 .42894 Mdot
.23364 .59856 Mdot
.54519 .71347 Mdot
.55149 .40785 Mdot
.39021 .52274 Mdot
.52286 .37582 Mdot
.42412 .60701 Mdot
.40747 .40738 Mdot
.55298 .68626 Mdot
.35798 .35764 Mdot
.36376 .64637 Mdot
.5185 .67389 Mdot
.61312 .38927 Mdot
.55263 .6786 Mdot
.47273 .62774 Mdot
.64614 .66767 Mdot
.36492 .44433 Mdot
.50883 .621 Mdot
.38413 .42712 Mdot
.39808 .54033 Mdot
.75037 .44799 Mdot
.71421 .60638 Mdot
.52115 .68831 Mdot
.28728 .44774 Mdot
.56462 .7042 Mdot
.589 .37547 Mdot
.58726 .40548 Mdot
.52647 .69761 Mdot
.70608 .61436 Mdot
.74736 .54591 Mdot
.75085 .61208 Mdot
.39075 .39154 Mdot
.50817 .58532 Mdot
.40438 .1523 Mdot
.53495 .75986 Mdot
.34798 .66514 Mdot
.59344 .29262 Mdot
.61132 .42265 Mdot
.3625 .62125 Mdot
.38735 .65212 Mdot
.72746 .61832 Mdot
.56258 .70721 Mdot
.41135 .39683 Mdot
.33317 .64969 Mdot
.30951 .40953 Mdot
.70838 .51012 Mdot
.51923 .34887 Mdot
.59832 .4836 Mdot
.61909 .38786 Mdot
.56177 .53042 Mdot
.33582 .68057 Mdot
.56844 .39661 Mdot
.48985 .40077 Mdot
.37737 .64704 Mdot
.7203 .62294 Mdot
.31614 .35741 Mdot
.54306 .73429 Mdot
.49168 .87922 Mdot
.58866 .35686 Mdot
.57035 .37254 Mdot
.37798 .63548 Mdot
.5055 .31102 Mdot
.35744 .37745 Mdot
.3753 .42622 Mdot
.54333 .70036 Mdot
.48754 .52764 Mdot
.56486 .34977 Mdot
.60317 .36913 Mdot
.5281 .73233 Mdot
.38284 .52841 Mdot
.75045 .29778 Mdot
.58216 .39534 Mdot
.35611 .63885 Mdot
.46091 .62885 Mdot
.33198 .67735 Mdot
.60088 .44954 Mdot
.59445 .37974 Mdot
.61444 .384 Mdot
.59514 .35369 Mdot
.33868 .66059 Mdot
.61673 .39802 Mdot
.51285 .36232 Mdot
.35931 .40914 Mdot
.5707 .41815 Mdot
.70252 .43025 Mdot
.57989 .3922 Mdot
.71674 .58372 Mdot
.45663 .48561 Mdot
.54395 .38187 Mdot
.56829 .41775 Mdot
.69883 .44312 Mdot
.5691 .36412 Mdot
.36201 .6222 Mdot
.36801 .38726 Mdot
.36528 .64558 Mdot
.35366 .66406 Mdot
.57265 .71372 Mdot
.68994 .61887 Mdot
.61499 .36407 Mdot
.72265 .61476 Mdot
.63514 .39784 Mdot
.60499 .33086 Mdot
.63307 .51162 Mdot
.46323 .48111 Mdot
.70335 .56691 Mdot
.606 .37524 Mdot
.54961 .70171 Mdot
.553 .68444 Mdot
.50965 .60767 Mdot
.63504 .346 Mdot
.33181 .64449 Mdot
.36123 .66985 Mdot
.74806 .63171 Mdot
.6441 .64136 Mdot
.72499 .59953 Mdot
.65374 .53278 Mdot
.55089 .43668 Mdot
.55718 .40264 Mdot
.64279 .34536 Mdot
.57586 .72552 Mdot
.39838 .51842 Mdot
.52865 .73944 Mdot
.36824 .54661 Mdot
.33367 .66246 Mdot
.58153 .35252 Mdot
.158 .5564 Mdot
.39327 .39069 Mdot
.36794 .38665 Mdot
.34553 .68324 Mdot
.51767 .68809 Mdot
.62951 .3413 Mdot
.40541 .85046 Mdot
.39673 .42785 Mdot
.689 .57557 Mdot
.55935 .36687 Mdot
.56251 .71894 Mdot
.39503 .40568 Mdot
.67537 .59152 Mdot
.59864 .35739 Mdot
.58412 .72191 Mdot
.56848 .39161 Mdot
.42457 .25998 Mdot
.36496 .41704 Mdot
.60649 .50662 Mdot
.33124 .37757 Mdot
.33907 .65626 Mdot
.37259 .64512 Mdot
.59431 .38273 Mdot
.44971 .86985 Mdot
.30988 .42761 Mdot
.39057 .63857 Mdot
.67684 .59662 Mdot
.39252 .5161 Mdot
.6785 .60228 Mdot
.53033 .69455 Mdot
.72142 .59889 Mdot
.57166 .72027 Mdot
.59926 .72662 Mdot
.41335 .42589 Mdot
.69049 .58686 Mdot
.55635 .27318 Mdot
.62007 .34512 Mdot
.73236 .60295 Mdot
.53307 .38958 Mdot
.63685 .40977 Mdot
.53816 .7375 Mdot
.71772 .61448 Mdot
.60264 .42292 Mdot
.23964 .4482 Mdot
.36741 .65564 Mdot
.33504 .63833 Mdot
.61202 .34237 Mdot
.54582 .66429 Mdot
.36044 .44252 Mdot
.60091 .53077 Mdot
.3991 .55186 Mdot
.60138 .36717 Mdot
.62384 .40798 Mdot
.33131 .40458 Mdot
.35254 .3721 Mdot
.59704 .38416 Mdot
.33117 .31521 Mdot
.61446 .39597 Mdot
.36079 .62953 Mdot
.39091 .39064 Mdot
.3728 .38679 Mdot
.54185 .67035 Mdot
.39025 .4205 Mdot
.50744 .4029 Mdot
.3832 .60781 Mdot
.5349 .34924 Mdot
.36065 .64655 Mdot
.58052 .76261 Mdot
.5574 .74023 Mdot
.28286 .44488 Mdot
.38957 .42011 Mdot
.55433 .43077 Mdot
.39906 .39343 Mdot
.7046 .5764 Mdot
.36429 .38327 Mdot
.32753 .40267 Mdot
.55113 .362 Mdot
.60826 .41022 Mdot
.38438 .53008 Mdot
.54016 .51977 Mdot
.37088 .4155 Mdot
.60073 .44159 Mdot
.52645 .40249 Mdot
.59135 .40607 Mdot
.62665 .52163 Mdot
.3512 .36327 Mdot
.45465 .38134 Mdot
.40284 .57927 Mdot
.37228 .41864 Mdot
.30517 .2372 Mdot
.38054 .53888 Mdot
.37681 .54817 Mdot
.34866 .69 Mdot
.58614 .39542 Mdot
.54282 .72287 Mdot
.56065 .41775 Mdot
.65413 .3708 Mdot
.54603 .37822 Mdot
.68937 .58513 Mdot
.55913 .34997 Mdot
.39369 .53997 Mdot
.55077 .7149 Mdot
.604 .43804 Mdot
.58802 .38618 Mdot
.37787 .54717 Mdot
.34273 .36426 Mdot
.37615 .43019 Mdot
.38675 .571 Mdot
.72951 .61288 Mdot
.35869 .67865 Mdot
.55286 .41018 Mdot
.54607 .70119 Mdot
.54965 .72226 Mdot
.38842 .37744 Mdot
.52335 .72475 Mdot
.35159 .68129 Mdot
.59375 .36679 Mdot
.33925 .65713 Mdot
.6896 .58468 Mdot
.38503 .41218 Mdot
.53893 .39168 Mdot
.58361 .43087 Mdot
.35621 .421 Mdot
.61147 .40331 Mdot
.69113 .57926 Mdot
.5785 .70848 Mdot
.3646 .37984 Mdot
.35096 .65777 Mdot
.5478 .67133 Mdot
.5638 .43129 Mdot
.22702 .30702 Mdot
.58211 .36853 Mdot
.60445 .36834 Mdot
.35467 .47257 Mdot
.53628 .42223 Mdot
.56497 .70814 Mdot
.40118 .40192 Mdot
.61506 .43732 Mdot
.69979 .44567 Mdot
.68801 .62878 Mdot
.55364 .75987 Mdot
.56727 .36043 Mdot
.27146 .305 Mdot
.53321 .41293 Mdot
.281 .43609 Mdot
.6322 .51156 Mdot
.34216 .73483 Mdot
.59796 .48353 Mdot
.39088 .64459 Mdot
.38553 .52399 Mdot
.56662 .7258 Mdot
.49569 .30335 Mdot
.5958 .37648 Mdot
.55888 .22796 Mdot
.5403 .39596 Mdot
.3558 .63414 Mdot
.52536 .31086 Mdot
.51833 .70836 Mdot
.74937 .31808 Mdot
.57789 .41283 Mdot
.33433 .40929 Mdot
.54391 .6594 Mdot
.38075 .52613 Mdot
.60517 .41414 Mdot
.72806 .59747 Mdot
.72588 .63767 Mdot
.5089 .40754 Mdot
.36115 .64873 Mdot
.56701 .40523 Mdot
.60826 .45569 Mdot
.57577 .81945 Mdot
.35473 .40204 Mdot
.36136 .66426 Mdot
.64107 .62372 Mdot
.59138 .40436 Mdot
.37145 .43263 Mdot
.36534 .38992 Mdot
.71809 .62032 Mdot
.33604 .71124 Mdot
.77099 .59419 Mdot
.15983 .47767 Mdot
.60353 .22612 Mdot
.57769 .7215 Mdot
.39851 .35351 Mdot
.57178 .42379 Mdot
.80521 .44127 Mdot
.3508 .6631 Mdot
.56778 .37179 Mdot
.56124 .24091 Mdot
.35463 .39497 Mdot
.57355 .39511 Mdot
.70658 .60762 Mdot
.25425 .64408 Mdot
.38638 .30054 Mdot
.23539 .33144 Mdot
.58681 .70836 Mdot
.57446 .33671 Mdot
.50952 .38716 Mdot
.39941 .54833 Mdot
.60908 .44269 Mdot
.55804 .69673 Mdot
.45782 .64984 Mdot
.69202 .60684 Mdot
.39576 .39369 Mdot
.37905 .53346 Mdot
.54013 .39639 Mdot
.52289 .35167 Mdot
.68362 .58328 Mdot
.6002 .41187 Mdot
.4321 .33206 Mdot
.37351 .52677 Mdot
.55827 .6765 Mdot
.33553 .40974 Mdot
.62099 .39518 Mdot
.39014 .51792 Mdot
.5462 .36529 Mdot
.64848 .28943 Mdot
.55354 .37955 Mdot
.28758 .41616 Mdot
.36055 .4256 Mdot
.3599 .65497 Mdot
.5669 .3464 Mdot
.5719 .38673 Mdot
.60807 .6316 Mdot
.62795 .34161 Mdot
.54646 .39464 Mdot
.39663 .38182 Mdot
.39364 .38996 Mdot
.34442 .38474 Mdot
.54048 .67228 Mdot
.49117 .50278 Mdot
.34757 .64652 Mdot
.64207 .34551 Mdot
.33224 .65195 Mdot
.58141 .48529 Mdot
.6807 .59457 Mdot
.27441 .44292 Mdot
.59957 .37494 Mdot
.34337 .41755 Mdot
.47765 .16295 Mdot
.36215 .36474 Mdot
.35625 .59099 Mdot
.3545 .66136 Mdot
.36764 .40963 Mdot
.572 .36163 Mdot
.52458 .51142 Mdot
.21982 .34815 Mdot
.35459 .6271 Mdot
.58748 .3325 Mdot
.58663 .73324 Mdot
.51082 .72533 Mdot
.32433 .22777 Mdot
.34168 .6386 Mdot
.28298 .67591 Mdot
.57076 .43642 Mdot
.39842 .4057 Mdot
.35745 .67686 Mdot
.38252 .62618 Mdot
.52266 .72582 Mdot
.5901 .43394 Mdot
.57196 .38882 Mdot
.38547 .54744 Mdot
.34276 .6702 Mdot
.6361 .45555 Mdot
.60205 .43147 Mdot
.35536 .50107 Mdot
.40333 .43359 Mdot
.71317 .76868 Mdot
.47044 .3825 Mdot
.55931 .2392 Mdot
.52199 .78159 Mdot
.36531 .37788 Mdot
.56732 .41176 Mdot
.63125 .3407 Mdot
.58074 .71525 Mdot
.58802 .36534 Mdot
.51505 .68496 Mdot
.33801 .64998 Mdot
.25646 .41684 Mdot
.46166 .56575 Mdot
.41161 .66283 Mdot
.58058 .37035 Mdot
.3798 .3035 Mdot
.69149 .58992 Mdot
.396 .62371 Mdot
.35757 .37317 Mdot
.59587 .44989 Mdot
.5718 .73751 Mdot
.53662 .67413 Mdot
.36051 .39531 Mdot
.31544 .58922 Mdot
.27945 .43896 Mdot
.60611 .36172 Mdot
.53537 .68575 Mdot
.43265 .50065 Mdot
.32174 .28481 Mdot
.36258 .68497 Mdot
.68982 .60456 Mdot
.56675 .71983 Mdot
.32783 .64244 Mdot
.63813 .40145 Mdot
.36831 .40179 Mdot
.33545 .41818 Mdot
.51844 .62002 Mdot
.53956 .72988 Mdot
.71007 .5989 Mdot
.50634 .61282 Mdot
.50956 .59232 Mdot
.6963 .60359 Mdot
.51633 .67901 Mdot
.37744 .37803 Mdot
.34364 .40017 Mdot
.36862 .38804 Mdot
.46088 .34426 Mdot
.4056 .41109 Mdot
.78663 .53129 Mdot
.60505 .44458 Mdot
.3354 .29425 Mdot
.58575 .44752 Mdot
.34744 .62642 Mdot
.36488 .41834 Mdot
.62695 .50995 Mdot
.53596 .42611 Mdot
.22784 .34457 Mdot
.55665 .38984 Mdot
.46695 .61786 Mdot
.5871 .39456 Mdot
.42603 .3002 Mdot
.40423 .37901 Mdot
.61246 .38632 Mdot
.38379 .60668 Mdot
.71071 .58325 Mdot
.40615 .44007 Mdot
.54942 .39743 Mdot
.28785 .56602 Mdot
.53322 .39078 Mdot
.26932 .4049 Mdot
.55678 .63592 Mdot
.73403 .58622 Mdot
.51942 .38281 Mdot
.55871 .74638 Mdot
.63829 .31123 Mdot
.34523 .29307 Mdot
.35276 .62828 Mdot
.37017 .30259 Mdot
.51584 .71217 Mdot
.52454 .31021 Mdot
.56337 .44677 Mdot
.69661 .61082 Mdot
.31237 .36219 Mdot
.36535 .62926 Mdot
.59995 .37961 Mdot
.57561 .41135 Mdot
.42581 .66266 Mdot
.36033 .28587 Mdot
.66998 .41395 Mdot
.68814 .57174 Mdot
.38601 .2951 Mdot
.54599 .38717 Mdot
.55746 .75788 Mdot
.39913 .41334 Mdot
.53371 .30963 Mdot
.51075 .31263 Mdot
.6095 .43205 Mdot
.36462 .40629 Mdot
.38493 .42474 Mdot
.51929 .15955 Mdot
.68546 .60433 Mdot
.55333 .38201 Mdot
.51965 .62489 Mdot
.54784 .40457 Mdot
.3493 .63959 Mdot
.55714 .44042 Mdot
.55411 .74021 Mdot
.45659 .46458 Mdot
.53832 .67254 Mdot
.60071 .40293 Mdot
.38215 .40729 Mdot
.37372 .6328 Mdot
.35207 .7559 Mdot
.32219 .69642 Mdot
.78564 .53181 Mdot
.71997 .64061 Mdot
.7258 .59542 Mdot
.68282 .6107 Mdot
.37397 .68516 Mdot
.57353 .35925 Mdot
.56261 .5338 Mdot
.64415 .3803 Mdot
.58868 .3989 Mdot
.55163 .3779 Mdot
.304 .67742 Mdot
.35579 .66034 Mdot
.55437 .72768 Mdot
.59783 .38416 Mdot
.60024 .44212 Mdot
.37652 .41008 Mdot
.72408 .60033 Mdot
.57329 .69516 Mdot
.72946 .59083 Mdot
.55078 .7099 Mdot
.39948 .16992 Mdot
.53837 .33783 Mdot
.70751 .58297 Mdot
.3344 .6768 Mdot
.34033 .40017 Mdot
.38253 .55144 Mdot
.52931 .69809 Mdot
.51904 .71137 Mdot
.61787 .40835 Mdot
.38671 .41506 Mdot
.38134 .4246 Mdot
.7265 .60639 Mdot
.36308 .6701 Mdot
.62534 .39713 Mdot
.6086 .41787 Mdot
.37111 .76494 Mdot
.57914 .70483 Mdot
.37113 .29602 Mdot
.32332 .4525 Mdot
.5829 .35856 Mdot
.36953 .43258 Mdot
.57671 .38047 Mdot
.43515 .5246 Mdot
.34458 .38184 Mdot
.54602 .43108 Mdot
.64577 .41325 Mdot
.57644 .72234 Mdot
.59619 .18484 Mdot
.6092 .353 Mdot
.34938 .61016 Mdot
.58351 .42486 Mdot
.70535 .22014 Mdot
.49599 .16352 Mdot
.53552 .37697 Mdot
.58439 .35118 Mdot
.163 .44808 Mdot
.52595 .39494 Mdot
.38952 .5448 Mdot
.65388 .3683 Mdot
.36683 .43464 Mdot
.48628 .61536 Mdot
.55584 .52802 Mdot
.68697 .60981 Mdot
.54389 .69965 Mdot
.72514 .50149 Mdot
.70786 .62404 Mdot
.34778 .39794 Mdot
.52754 .34559 Mdot
.32191 .45016 Mdot
.50167 .6944 Mdot
.57974 .46135 Mdot
.35175 .63697 Mdot
.55393 .52886 Mdot
.53838 .74337 Mdot
.35018 .65872 Mdot
.53286 .41339 Mdot
.59102 .7766 Mdot
.38587 .60439 Mdot
.53294 .15622 Mdot
.38079 .65144 Mdot
.36652 .6529 Mdot
.50572 .50382 Mdot
.68748 .6105 Mdot
.44217 .66435 Mdot
.51411 .34508 Mdot
.36513 .62414 Mdot
.74208 .368 Mdot
.58161 .70347 Mdot
.4938 .52301 Mdot
.39897 .37568 Mdot
.5636 .33116 Mdot
.56096 .37127 Mdot
.37392 .65982 Mdot
.39525 .35424 Mdot
.61219 .62145 Mdot
.34037 .64358 Mdot
.51552 .4109 Mdot
.47952 .51384 Mdot
.39418 .51944 Mdot
.38047 .54172 Mdot
.67681 .58889 Mdot
.66678 .71042 Mdot
.35823 .4269 Mdot
.69221 .57397 Mdot
.62014 .4974 Mdot
.5581 .39531 Mdot
.33869 .66566 Mdot
.37739 .54113 Mdot
.35098 .65509 Mdot
.69864 .59092 Mdot
.68114 .58734 Mdot
.35832 .40795 Mdot
.36089 .37557 Mdot
.28542 .35992 Mdot
.71103 .37415 Mdot
.55554 .41883 Mdot
.51756 .21175 Mdot
.35261 .37294 Mdot
.49784 .31092 Mdot
.70812 .61897 Mdot
.71754 .61068 Mdot
.39537 .2409 Mdot
.56444 .42982 Mdot
.46215 .62698 Mdot
.54381 .38484 Mdot
.76563 .41992 Mdot
.53875 .39478 Mdot
.5257 .7288 Mdot
.58263 .41457 Mdot
.22334 .57295 Mdot
.59958 .44039 Mdot
.55068 .37565 Mdot
.53169 .708 Mdot
.62042 .3809 Mdot
.54634 .7404 Mdot
.56433 .40898 Mdot
.66369 .58952 Mdot
.54562 .70137 Mdot
.66836 .57081 Mdot
.4836 .58476 Mdot
.38655 .53745 Mdot
.68563 .6117 Mdot
.72631 .59067 Mdot
.6897 .51458 Mdot
.37324 .37271 Mdot
.5013 .33747 Mdot
.56126 .36623 Mdot
.56246 .67206 Mdot
.34115 .67663 Mdot
.61066 .43042 Mdot
.52844 .37142 Mdot
.6227 .3831 Mdot
.36178 .40864 Mdot
.52611 .6705 Mdot
.70461 .58685 Mdot
.55329 .68301 Mdot
.66489 .58214 Mdot
.56286 .73858 Mdot
.62244 .35758 Mdot
.63639 .39775 Mdot
.51121 .38098 Mdot
.5342 .24306 Mdot
.83592 .47559 Mdot
.36483 .39827 Mdot
.39233 .52498 Mdot
.68025 .59357 Mdot
.51419 .57935 Mdot
.35355 .42697 Mdot
.52051 .71428 Mdot
.56819 .39148 Mdot
.51339 .35307 Mdot
.56921 .32614 Mdot
.31963 .4314 Mdot
.69296 .55795 Mdot
.53485 .69715 Mdot
.40017 .53167 Mdot
.48774 .50519 Mdot
.43233 .42068 Mdot
.6471 .4987 Mdot
.57439 .38368 Mdot
.72733 .60671 Mdot
.39511 .40546 Mdot
.44586 .65058 Mdot
.37233 .65953 Mdot
.53442 .51808 Mdot
.57873 .36919 Mdot
.3133 .60961 Mdot
.38213 .40591 Mdot
.70655 .61155 Mdot
.3748 .65825 Mdot
.69158 .61149 Mdot
.38426 .51757 Mdot
.39913 .55874 Mdot
.60305 .41626 Mdot
.54245 .3856 Mdot
.33517 .66574 Mdot
.36288 .42791 Mdot
.66537 .60267 Mdot
.42144 .67386 Mdot
.5291 .69456 Mdot
.48744 .54033 Mdot
.39653 .39733 Mdot
.29699 .68225 Mdot
.5434 .67782 Mdot
.32745 .65153 Mdot
.56714 .52976 Mdot
.36289 .67909 Mdot
.54762 .3837 Mdot
.38619 .39515 Mdot
.34762 .63114 Mdot
.38569 .75634 Mdot
.27464 .33393 Mdot
.29851 .39511 Mdot
.60667 .39542 Mdot
.26742 .43559 Mdot
.28424 .60791 Mdot
.40293 .35321 Mdot
.33385 .64977 Mdot
.58667 .37783 Mdot
.60788 .36404 Mdot
.57918 .41306 Mdot
.3693 .65626 Mdot
.31179 .71756 Mdot
.52285 .68987 Mdot
.57049 .39848 Mdot
.7162 .57955 Mdot
.55525 .73754 Mdot
.52251 .74119 Mdot
.56761 .71736 Mdot
.35554 .37074 Mdot
.52524 .34536 Mdot
.64256 .3383 Mdot
.56695 .17836 Mdot
.36368 .65389 Mdot
.38692 .53755 Mdot
.60565 .36786 Mdot
.77671 .53499 Mdot
.34213 .39824 Mdot
.52706 .70601 Mdot
.56864 .3728 Mdot
.53904 .62905 Mdot
.38031 .51322 Mdot
.53883 .71144 Mdot
.35362 .37573 Mdot
.4185 .36411 Mdot
.59043 .36627 Mdot
.57856 .42598 Mdot
.34761 .41223 Mdot
.27204 .64188 Mdot
.48332 .5042 Mdot
.5795 .38207 Mdot
.35639 .65783 Mdot
.49782 .86778 Mdot
.55036 .43102 Mdot
.32033 .36964 Mdot
.40005 .52074 Mdot
.3808 .48849 Mdot
.34799 .30891 Mdot
.64734 .36814 Mdot
.23699 .41407 Mdot
.78238 .56399 Mdot
.25242 .37098 Mdot
.77379 .43915 Mdot
.40813 .68861 Mdot
.4593 .14639 Mdot
.36262 .60931 Mdot
.42333 .28401 Mdot
.19633 .63539 Mdot
.28293 .6523 Mdot
.60317 .64839 Mdot
.39931 .72895 Mdot
.58925 .77249 Mdot
.75393 .31168 Mdot
.54974 .74838 Mdot
.78335 .42378 Mdot
.53966 .38352 Mdot
.27127 .62644 Mdot
.4154 .30086 Mdot
.83058 .53363 Mdot
.28734 .4547 Mdot
.52444 .62436 Mdot
.21254 .33642 Mdot
.31318 .4768 Mdot
.3341 .24594 Mdot
.59814 .27004 Mdot
.69527 .72215 Mdot
.51423 .58597 Mdot
.74048 .5106 Mdot
.37994 .31091 Mdot
.21293 .53639 Mdot
.40226 .61349 Mdot
.47356 .19204 Mdot
.598 .80879 Mdot
.54805 .68973 Mdot
.39822 .4164 Mdot
.44076 .67805 Mdot
.31269 .27223 Mdot
.35088 .59908 Mdot
.23673 .41334 Mdot
.35358 .48258 Mdot
.4244 .29646 Mdot
.60962 .5049 Mdot
.42837 .25339 Mdot
.77312 .5845 Mdot
.75391 .3309 Mdot
.32522 .42848 Mdot
.41338 .74023 Mdot
.52023 .57932 Mdot
.68553 .53417 Mdot
.44082 .31634 Mdot
.67632 .58115 Mdot
.67074 .59062 Mdot
.34891 .37892 Mdot
.32274 .27808 Mdot
.37224 .52714 Mdot
.6219 .49508 Mdot
.56659 .74441 Mdot
.43961 .53152 Mdot
.25251 .6308 Mdot
.29464 .59541 Mdot
.64479 .21442 Mdot
.24333 .29275 Mdot
.72884 .41887 Mdot
.44971 .63766 Mdot
.32133 .62252 Mdot
.75691 .53031 Mdot
.67761 .37469 Mdot
.72792 .38015 Mdot
.64215 .28521 Mdot
.18323 .38782 Mdot
.31062 .55435 Mdot
.20739 .33117 Mdot
.33039 .42779 Mdot
.49198 .3958 Mdot
.43631 .59806 Mdot
.6086 .23553 Mdot
.69266 .48075 Mdot
.24057 .30748 Mdot
.73988 .60315 Mdot
.41442 .39107 Mdot
.28394 .65281 Mdot
.4272 .3319 Mdot
.72844 .54849 Mdot
.71254 .64739 Mdot
.52686 .31514 Mdot
.17624 .37379 Mdot
.23515 .42148 Mdot
.44095 .17292 Mdot
.3566 .50942 Mdot
.49657 .68432 Mdot
.52796 .74622 Mdot
.38394 .62607 Mdot
.30617 .26197 Mdot
.38124 .39596 Mdot
.58284 .1752 Mdot
.27512 .36004 Mdot
.64455 .31214 Mdot
.16519 .38859 Mdot
.72728 .29007 Mdot
.33273 .30057 Mdot
.81402 .49689 Mdot
.43969 .84013 Mdot
.67972 .41124 Mdot
.32451 .70257 Mdot
.57317 .75134 Mdot
.28169 .40451 Mdot
.29769 .26789 Mdot
.73608 .35324 Mdot
.16127 .53194 Mdot
.62289 .49322 Mdot
.54477 .77894 Mdot
.33261 .44563 Mdot
.61671 .6654 Mdot
.6572 .54053 Mdot
.21136 .32635 Mdot
.39697 .29631 Mdot
.48554 .85966 Mdot
.7611 .44889 Mdot
.50204 .31602 Mdot
.2533 .45148 Mdot
.59636 .69274 Mdot
.68583 .33841 Mdot
.29918 .56875 Mdot
.56199 .33732 Mdot
.66752 .49705 Mdot
.56945 .28363 Mdot
.75788 .58842 Mdot
.48456 .49719 Mdot
.30807 .53146 Mdot
.73439 .45606 Mdot
.30114 .72108 Mdot
.49642 .33774 Mdot
.33882 .37916 Mdot
.72549 .3923 Mdot
.7502 .42755 Mdot
.3477 .52962 Mdot
.64151 .62186 Mdot
.42967 .17395 Mdot
.62841 .62427 Mdot
.65019 .37377 Mdot
.42296 .27832 Mdot
.38407 .3132 Mdot
.74769 .38842 Mdot
.61459 .34796 Mdot
.61638 .2037 Mdot
.36398 .49763 Mdot
.51025 .24395 Mdot
.71248 .4665 Mdot
.5267 .24323 Mdot
.2875 .30744 Mdot
.4303 .58928 Mdot
.31854 .70478 Mdot
.36117 .34455 Mdot
.17852 .37252 Mdot
.55568 .7324 Mdot
.73144 .36241 Mdot
.36456 .60762 Mdot
.37382 .75886 Mdot
.41223 .69358 Mdot
.6156 .62086 Mdot
.32388 .24087 Mdot
.30038 .60552 Mdot
.57659 .66692 Mdot
.20096 .51831 Mdot
.42841 .49093 Mdot
.51084 .21461 Mdot
.49943 .42596 Mdot
.64758 .29557 Mdot
.69044 .57961 Mdot
.52948 .27438 Mdot
.41087 .58122 Mdot
.75797 .6411 Mdot
.64197 .36273 Mdot
.5228 .60263 Mdot
.39803 .54293 Mdot
.53541 .53141 Mdot
.39699 .16975 Mdot
.50016 .43054 Mdot
.72575 .29336 Mdot
.29059 .61562 Mdot
.55338 .53562 Mdot
.67136 .53826 Mdot
.44099 .42713 Mdot
.19983 .33831 Mdot
.353 .20706 Mdot
.2684 .59144 Mdot
.26159 .43098 Mdot
.8198 .34892 Mdot
.3405 .73119 Mdot
.65426 .23767 Mdot
.36832 .60688 Mdot
.82348 .70754 Mdot
.55012 .67981 Mdot
.81031 .43782 Mdot
.60152 .23733 Mdot
.57694 .62564 Mdot
.31047 .27588 Mdot
.39956 .32384 Mdot
.65194 .5921 Mdot
.32925 .38648 Mdot
.6286 .35493 Mdot
.2535 .302 Mdot
.18517 .36815 Mdot
.24917 .30674 Mdot
.34096 .58805 Mdot
.25548 .32799 Mdot
.16048 .43175 Mdot
.78844 .53115 Mdot
.42821 .6432 Mdot
.57377 .45113 Mdot
.71176 .33916 Mdot
.70929 .27815 Mdot
.74277 .59167 Mdot
.67509 .42193 Mdot
.32605 .43082 Mdot
.15682 .42372 Mdot
.39992 .16684 Mdot
.4316 .23206 Mdot
.34591 .23966 Mdot
.47026 .66223 Mdot
.71712 .36204 Mdot
.34202 .23016 Mdot
.21432 .50553 Mdot
.34631 .48965 Mdot
.15281 .45633 Mdot
.7494 .43841 Mdot
.39775 .73234 Mdot
.25821 .57389 Mdot
.68848 .25964 Mdot
.24972 .44569 Mdot
.43624 .68441 Mdot
.67547 .33441 Mdot
.37263 .45773 Mdot
.61692 .62388 Mdot
.20859 .52838 Mdot
.45662 .62937 Mdot
.71 .44948 Mdot
.51281 .71945 Mdot
.72883 .35044 Mdot
.62054 .54915 Mdot
.42909 .64582 Mdot
.70891 .5037 Mdot
.74181 .35136 Mdot
.27473 .54954 Mdot
.25188 .31882 Mdot
.29185 .61526 Mdot
.43202 .84296 Mdot
.28221 .4809 Mdot
.57909 .28312 Mdot
.6203 .37971 Mdot
.30305 .27463 Mdot
.32855 .20214 Mdot
.32835 .23456 Mdot
.34381 .57644 Mdot
.50543 .64751 Mdot
.3227 .65916 Mdot
.74341 .52337 Mdot
.5873 .62076 Mdot
.31165 .45476 Mdot
.57312 .55866 Mdot
.36408 .61281 Mdot
.25609 .64958 Mdot
.2846 .36517 Mdot
.77378 .53636 Mdot
.45689 .19895 Mdot
.65288 .4431 Mdot
.32626 .28416 Mdot
.33094 .40656 Mdot
.32496 .59322 Mdot
.72866 .3751 Mdot
.56021 .72921 Mdot
.38106 .76564 Mdot
.37616 .34926 Mdot
.48939 .39692 Mdot
.46361 .66907 Mdot
.29896 .40892 Mdot
.55581 .23654 Mdot
.56299 .65944 Mdot
.42905 .15608 Mdot
.63727 .21624 Mdot
.34355 .2281 Mdot
.72921 .40398 Mdot
.39794 .75866 Mdot
.51591 .52531 Mdot
.31497 .64409 Mdot
.29772 .46474 Mdot
.51111 .55843 Mdot
.73291 .39554 Mdot
.32144 .29925 Mdot
.41051 .60767 Mdot
.64618 .35663 Mdot
.46791 .1631 Mdot
.77033 .51753 Mdot
.51842 .53569 Mdot
.40226 .46299 Mdot
.39924 .42589 Mdot
.84219 .46405 Mdot
.22194 .55318 Mdot
.64033 .3234 Mdot
.26001 .44051 Mdot
.37043 .68303 Mdot
.33957 .38613 Mdot
.74264 .34407 Mdot
.65135 .66768 Mdot
.29423 .34619 Mdot
.44883 .59383 Mdot
.31979 .26353 Mdot
.47676 .57356 Mdot
.25601 .42728 Mdot
.21966 .39677 Mdot
.5133 .85716 Mdot
.33041 .42636 Mdot
.44345 .63734 Mdot
.45261 .66107 Mdot
.34439 .44483 Mdot
.31529 .41941 Mdot
.39084 .30092 Mdot
.2795 .26889 Mdot
.4987 .60545 Mdot
.20772 .49786 Mdot
.55981 .53422 Mdot
.61435 .65212 Mdot
.4265 .62215 Mdot
.71742 .50149 Mdot
.21494 .4449 Mdot
.39775 .21493 Mdot
.31335 .77635 Mdot
.6508 .45329 Mdot
.80637 .42805 Mdot
.74444 .52444 Mdot
.6001 .2721 Mdot
.44032 .31288 Mdot
.3361 .49165 Mdot
.55989 .41443 Mdot
.25333 .27883 Mdot
.31429 .54636 Mdot
.65897 .52229 Mdot
.60195 .72539 Mdot
.54569 .42384 Mdot
.5141 .37684 Mdot
.3366 .23419 Mdot
.37767 .48194 Mdot
.2511 .72087 Mdot
.76594 .43786 Mdot
.6161 .28978 Mdot
.32611 .30442 Mdot
.72327 .29252 Mdot
.43573 .57723 Mdot
.26182 .37352 Mdot
.61957 .55502 Mdot
.70724 .27108 Mdot
.19882 .47146 Mdot
.20984 .55376 Mdot
.27577 .47109 Mdot
.16591 .42082 Mdot
.59029 .29487 Mdot
.36477 .53185 Mdot
.44671 .6816 Mdot
.59866 .36112 Mdot
.31608 .58799 Mdot
.2726 .4545 Mdot
.62677 .72769 Mdot
.67852 .3665 Mdot
.32248 .20495 Mdot
.65353 .42038 Mdot
.33893 .56488 Mdot
.23717 .68869 Mdot
.30372 .79231 Mdot
.21809 .56881 Mdot
.21435 .32247 Mdot
.20257 .54022 Mdot
.25025 .43349 Mdot
.36572 .68718 Mdot
.50083 .57547 Mdot
.54408 .21896 Mdot
.28595 .25863 Mdot
.67942 .69396 Mdot
.35137 .71847 Mdot
.51894 .19173 Mdot
.28174 .25955 Mdot
.65264 .40702 Mdot
.83127 .44222 Mdot
.5032 .67158 Mdot
.74386 .28474 Mdot
.65836 .22782 Mdot
.40433 .45527 Mdot
.74734 .37055 Mdot
.81592 .41657 Mdot
.8185 .53822 Mdot
.64783 .2285 Mdot
.67616 .29758 Mdot
.39249 .47719 Mdot
.72366 .40889 Mdot
.27956 .41801 Mdot
.77963 .33067 Mdot
.42964 .6193 Mdot
.37662 .5093 Mdot
.40255 .55219 Mdot
.28214 .40202 Mdot
.27327 .53265 Mdot
.44696 .61563 Mdot
.45079 .47272 Mdot
.30162 .29787 Mdot
.52945 .87945 Mdot
.18952 .54114 Mdot
.3139 .35205 Mdot
.1944 .36082 Mdot
.34782 .5012 Mdot
.52327 .57049 Mdot
.44724 .32277 Mdot
.75807 .5206 Mdot
.56056 .65383 Mdot
.5454 .37869 Mdot
.27471 .27169 Mdot
.56556 .65781 Mdot
.22078 .33383 Mdot
.54171 .15697 Mdot
.35999 .23875 Mdot
.52167 .44803 Mdot
.57242 .7547 Mdot
.72036 .31324 Mdot
.72027 .32036 Mdot
.19655 .38005 Mdot
.79869 .41267 Mdot
.49884 .54747 Mdot
.46791 .59376 Mdot
.45874 .57174 Mdot
.61592 .30788 Mdot
.71863 .28147 Mdot
.42403 .45212 Mdot
.71643 .47516 Mdot
.25826 .5863 Mdot
.73772 .37223 Mdot
.35231 .3059 Mdot
.73173 .51604 Mdot
.6291 .60262 Mdot
.65407 .59231 Mdot
.57818 .69745 Mdot
.15331 .50135 Mdot
.31535 .4947 Mdot
.60464 .19736 Mdot
.43628 .84252 Mdot
.30253 .56935 Mdot
.78424 .41553 Mdot
.3924 .58561 Mdot
.68547 .40354 Mdot
.68955 .71402 Mdot
.73771 .47012 Mdot
.37606 .29947 Mdot
.27878 .43096 Mdot
.45907 .38254 Mdot
.30965 .24895 Mdot
.70912 .45666 Mdot
.17162 .59706 Mdot
.47396 .69213 Mdot
.52931 .26947 Mdot
.35477 .27655 Mdot
.39582 .82811 Mdot
.52313 .53654 Mdot
.17666 .3754 Mdot
.36306 .36333 Mdot
.2411 .29609 Mdot
.37931 .65864 Mdot
.61423 .77626 Mdot
.33383 .47741 Mdot
.65228 .52609 Mdot
.63014 .52763 Mdot
.49996 .15791 Mdot
.28689 .63215 Mdot
.29016 .59938 Mdot
.62826 .62926 Mdot
.53071 .74229 Mdot
.47208 .53134 Mdot
.21161 .49198 Mdot
.15621 .5071 Mdot
.62664 .40678 Mdot
.49605 .73872 Mdot
.73299 .32285 Mdot
.31347 .6474 Mdot
.36506 .48955 Mdot
.30397 .45861 Mdot
.34654 .32851 Mdot
.71536 .3628 Mdot
.16483 .41584 Mdot
.32162 .45958 Mdot
.59025 .60412 Mdot
.5288 .30362 Mdot
.40926 .618 Mdot
.31529 .74363 Mdot
.22586 .43168 Mdot
.46356 .58052 Mdot
.48656 .50874 Mdot
.73115 .42001 Mdot
.37027 .16148 Mdot
.18445 .37859 Mdot
.36432 .79677 Mdot
.55317 .53813 Mdot
.34548 .35959 Mdot
.7391 .49505 Mdot
.16821 .59135 Mdot
.74595 .2823 Mdot
.26939 .57057 Mdot
.73688 .36711 Mdot
.61962 .71585 Mdot
.81867 .43596 Mdot
.51474 .55009 Mdot
.35654 .27548 Mdot
.58247 .22215 Mdot
.39961 .56419 Mdot
.58653 .67424 Mdot
.58724 .53375 Mdot
.41799 .67141 Mdot
.39493 .476 Mdot
.28773 .63297 Mdot
.17218 .59828 Mdot
.79528 .39901 Mdot
.51814 .31391 Mdot
.18258 .60663 Mdot
.40784 .43276 Mdot
.45165 .6634 Mdot
.3415 .76561 Mdot
.56474 .53946 Mdot
.56292 .69216 Mdot
.67369 .38052 Mdot
.47699 .51631 Mdot
.19626 .51725 Mdot
.60245 .76032 Mdot
.72287 .62473 Mdot
.31574 .39741 Mdot
.80869 .41174 Mdot
.35321 .43909 Mdot
.40161 .15304 Mdot
.21615 .50264 Mdot
.32597 .2931 Mdot
.18912 .47947 Mdot
.42776 .72744 Mdot
.44176 .84823 Mdot
.33647 .24464 Mdot
.69901 .44612 Mdot
.31763 .40175 Mdot
.33515 .42445 Mdot
.20263 .45753 Mdot
.3207 .61063 Mdot
.32842 .26354 Mdot
.73011 .2987 Mdot
.40156 .76081 Mdot
.37925 .43772 Mdot
.47001 .60016 Mdot
.32585 .34791 Mdot
.41111 .15974 Mdot
.5576 .68811 Mdot
.18074 .36338 Mdot
.46916 .38142 Mdot
.30215 .74427 Mdot
.29269 .42608 Mdot
.46034 .46409 Mdot
.52578 .54378 Mdot
.39483 .75045 Mdot
.65005 .36557 Mdot
.61646 .29095 Mdot
.36237 .37327 Mdot
.40769 .69521 Mdot
.7224 .60148 Mdot
.67114 .64361 Mdot
.3339 .62015 Mdot
.57934 .26163 Mdot
.70446 .26072 Mdot
.33197 .41447 Mdot
.47095 .68351 Mdot
.46198 .70633 Mdot
.64425 .41397 Mdot
.70014 .30755 Mdot
.15817 .46956 Mdot
.33615 .24892 Mdot
.35799 .36333 Mdot
.37298 .80782 Mdot
.75306 .62239 Mdot
.44232 .15547 Mdot
.39667 .3458 Mdot
.72805 .3175 Mdot
.56482 .27797 Mdot
.35856 .21122 Mdot
.34871 .30895 Mdot
.26707 .39018 Mdot
.72763 .38945 Mdot
.6114 .62551 Mdot
.73977 .34874 Mdot
.34503 .32799 Mdot
.46874 .56002 Mdot
.7449 .29136 Mdot
.61623 .72282 Mdot
.42712 .25842 Mdot
.66323 .35193 Mdot
.29267 .41986 Mdot
.7179 .28972 Mdot
.31529 .39083 Mdot
.67559 .61499 Mdot
.48448 .19706 Mdot
.33827 .48324 Mdot
.3032 .26581 Mdot
.34688 .53154 Mdot
.73536 .31955 Mdot
.45877 .56553 Mdot
.7786 .4924 Mdot
.46601 .38675 Mdot
.66384 .48467 Mdot
.53404 .35862 Mdot
.56234 .28869 Mdot
.58894 .56255 Mdot
.51453 .16543 Mdot
.61724 .29958 Mdot
.27343 .28577 Mdot
.42228 .16427 Mdot
.24753 .36889 Mdot
.45986 .64422 Mdot
.38298 .43017 Mdot
.19367 .35076 Mdot
.70486 .30251 Mdot
.28488 .42528 Mdot
.66413 .23292 Mdot
.84261 .45788 Mdot
.18909 .62605 Mdot
.32468 .52361 Mdot
.29959 .41629 Mdot
.59408 .1839 Mdot
.31497 .55319 Mdot
.82392 .42685 Mdot
.38113 .2991 Mdot
.3487 .46926 Mdot
.16096 .39638 Mdot
.62744 .24727 Mdot
.29157 .59265 Mdot
.35195 .28324 Mdot
.31945 .33479 Mdot
.69839 .2913 Mdot
.64485 .34552 Mdot
.55944 .74433 Mdot
.56487 .63014 Mdot
.74871 .37871 Mdot
.35786 .33437 Mdot
.72676 .30298 Mdot
.72756 .32377 Mdot
.78794 .43005 Mdot
.39952 .7527 Mdot
.18979 .62638 Mdot
.31611 .31384 Mdot
.51003 .36768 Mdot
.31423 .38799 Mdot
.69253 .61993 Mdot
.76197 .4568 Mdot
.59895 .43843 Mdot
.57879 .51821 Mdot
.55111 .30354 Mdot
.2675 .26919 Mdot
.62333 .64931 Mdot
.40703 .63054 Mdot
.38677 .43004 Mdot
.28413 .40741 Mdot
.43043 .55842 Mdot
.28228 .65456 Mdot
.72125 .30287 Mdot
.28876 .34832 Mdot
.24358 .40889 Mdot
.29561 .58511 Mdot
.72696 .44036 Mdot
.77533 .5951 Mdot
.3433 .63232 Mdot
.55565 .23155 Mdot
.1948 .39598 Mdot
.31558 .57581 Mdot
.41364 .39634 Mdot
.25336 .55709 Mdot
.47168 .56222 Mdot
.36388 .55571 Mdot
.2876 .62655 Mdot
.41259 .59413 Mdot
.3825 .23629 Mdot
.22052 .40956 Mdot
.58765 .72895 Mdot
.75751 .43008 Mdot
.22782 .54678 Mdot
.7239 .30052 Mdot
.64424 .419 Mdot
.28462 .28469 Mdot
.65134 .52357 Mdot
.75841 .61097 Mdot
.59343 .42669 Mdot
.63753 .27092 Mdot
.33586 .2339 Mdot
.249 .57366 Mdot
.68066 .34129 Mdot
.40521 .372 Mdot
.63688 .21373 Mdot
.54377 .6479 Mdot
.54879 .65129 Mdot
.8177 .47429 Mdot
.45428 .43854 Mdot
.58389 .61837 Mdot
.31357 .71059 Mdot
.65257 .38741 Mdot
.77618 .60367 Mdot
.45468 .59098 Mdot
.54856 .22942 Mdot
.65447 .24078 Mdot
.15627 .48616 Mdot
.44481 .58718 Mdot
.64522 .21308 Mdot
.57031 .21895 Mdot
.34902 .46721 Mdot
.8012 .40164 Mdot
.67381 .422 Mdot
.61775 .34981 Mdot
.67606 .61546 Mdot
.40936 .42142 Mdot
.16377 .46391 Mdot
.66448 .3172 Mdot
.73345 .56032 Mdot
.64228 .56069 Mdot
.43938 .60434 Mdot
.54424 .79413 Mdot
.36566 .49962 Mdot
.59601 .18403 Mdot
.72871 .37618 Mdot
.31932 .68445 Mdot
.19924 .51728 Mdot
.68457 .37572 Mdot
.27816 .28672 Mdot
.59786 .57484 Mdot
.32397 .25202 Mdot
.35886 .5773 Mdot
.5525 .2437 Mdot
.44707 .1633 Mdot
.68051 .49061 Mdot
.6556 .4886 Mdot
.42904 .43934 Mdot
.66192 .45955 Mdot
.38163 .55143 Mdot
.64029 .64812 Mdot
.77168 .33552 Mdot
.16118 .55154 Mdot
.28934 .71266 Mdot
.66292 .39234 Mdot
.73803 .48981 Mdot
.21359 .42501 Mdot
.52135 .57373 Mdot
.64069 .54876 Mdot
.44687 .68792 Mdot
.57847 .66603 Mdot
.50423 .86894 Mdot
.25906 .27555 Mdot
.59092 .42754 Mdot
.61723 .53817 Mdot
.72767 .64738 Mdot
.51762 .68086 Mdot
.44367 .20044 Mdot
.16237 .45833 Mdot
.35537 .62513 Mdot
.40998 .81285 Mdot
.31791 .71112 Mdot
.50723 .1601 Mdot
.36455 .78242 Mdot
.39645 .61926 Mdot
.39998 .15296 Mdot
.2717 .58627 Mdot
.44557 .39767 Mdot
.51293 .87055 Mdot
.48449 .16243 Mdot
.57087 .28014 Mdot
.51894 .64342 Mdot
.26343 .28326 Mdot
.52346 .54311 Mdot
.50626 .64206 Mdot
.63306 .24417 Mdot
.73014 .38179 Mdot
.76288 .43579 Mdot
.36544 .69859 Mdot
.55103 .20324 Mdot
.85268 .52215 Mdot
.43056 .72718 Mdot
.38927 .83913 Mdot
.34441 .24735 Mdot
.22199 .3729 Mdot
.21663 .56327 Mdot
.63116 .71835 Mdot
.29647 .27988 Mdot
.72576 .3352 Mdot
.63335 .26181 Mdot
.66193 .69021 Mdot
.67905 .49791 Mdot
.75205 .51079 Mdot
.36701 .56177 Mdot
.35502 .22781 Mdot
.40681 .74745 Mdot
.69326 .36371 Mdot
.73396 .34944 Mdot
.58495 .22972 Mdot
.65869 .48542 Mdot
.20565 .38092 Mdot
.69665 .29546 Mdot
.73565 .40699 Mdot
.40993 .71427 Mdot
.67015 .58821 Mdot
.17207 .44414 Mdot
.42573 .50851 Mdot
.55932 .28342 Mdot
.23995 .69525 Mdot
.21119 .3279 Mdot
.67375 .42292 Mdot
.5533 .43798 Mdot
.46397 .14504 Mdot
.48108 .68452 Mdot
.64954 .23701 Mdot
.24957 .61575 Mdot
.77008 .43242 Mdot
.5868 .29987 Mdot
.53675 .39529 Mdot
.79797 .50412 Mdot
.34937 .45774 Mdot
.58659 .22659 Mdot
.36793 .77436 Mdot
.73257 .40238 Mdot
.58462 .26592 Mdot
.31192 .77447 Mdot
.38237 .3371 Mdot
.35695 .43473 Mdot
.26454 .27848 Mdot
.46295 .1824 Mdot
.59638 .28081 Mdot
.33972 .27641 Mdot
.59356 .5856 Mdot
.77409 .60716 Mdot
.50202 .33796 Mdot
.51823 .52671 Mdot
.75013 .37554 Mdot
.18154 .60879 Mdot
.53419 .21825 Mdot
.17359 .37345 Mdot
.34775 .21299 Mdot
.36896 .43994 Mdot
.61599 .24353 Mdot
.56119 .54296 Mdot
.24464 .37857 Mdot
.38343 .74699 Mdot
.38127 .76113 Mdot
.84217 .52625 Mdot
.68943 .64865 Mdot
.53726 .37623 Mdot
.34097 .58719 Mdot
.31199 .24933 Mdot
.84591 .50609 Mdot
.30449 .25628 Mdot
.56573 .29071 Mdot
.61859 .37514 Mdot
.312 .80266 Mdot
.2523 .42957 Mdot
.6278 .38082 Mdot
.61164 .31646 Mdot
.6222 .31351 Mdot
.54697 .39817 Mdot
.31272 .61968 Mdot
.75785 .52544 Mdot
.76835 .41774 Mdot
.27537 .27824 Mdot
.39304 .43463 Mdot
.52912 .5414 Mdot
.38053 .61231 Mdot
.60281 .52054 Mdot
.56553 .48599 Mdot
.38159 .67152 Mdot
.77091 .40629 Mdot
.51167 .77165 Mdot
.71234 .54077 Mdot
.29622 .41868 Mdot
.4489 .45166 Mdot
.28365 .35802 Mdot
.78505 .40052 Mdot
.30456 .68952 Mdot
.81741 .54222 Mdot
.7361 .3284 Mdot
.47202 .36727 Mdot
.36129 .52136 Mdot
.82363 .36137 Mdot
.51785 .53966 Mdot
.3239 .60204 Mdot
.61436 .46871 Mdot
.44838 .37754 Mdot
.3576 .25203 Mdot
.73014 .63739 Mdot
.39778 .54733 Mdot
.53531 .30319 Mdot
.30966 .27553 Mdot
.3486 .68398 Mdot
.35197 .17723 Mdot
.57204 .46883 Mdot
.44132 .20841 Mdot
.26901 .33154 Mdot
.44241 .64375 Mdot
.37583 .30211 Mdot
.53193 .35867 Mdot
.5761 .59819 Mdot
.50752 .76608 Mdot
.32034 .35924 Mdot
.42513 .62404 Mdot
.23128 .40007 Mdot
.80176 .42631 Mdot
.40348 .2186 Mdot
.5548 .38259 Mdot
.73594 .61201 Mdot
.53059 .52481 Mdot
.63403 .70232 Mdot
.54168 .77741 Mdot
.3511 .4918 Mdot
.78308 .403 Mdot
.76549 .43894 Mdot
.3629 .28657 Mdot
.22861 .32081 Mdot
.66234 .34642 Mdot
.35428 .24487 Mdot
.62411 .59213 Mdot
.28098 .53211 Mdot
.70151 .31114 Mdot
.1804 .60056 Mdot
.59521 .29162 Mdot
.65344 .34683 Mdot
.36008 .18848 Mdot
.3393 .23977 Mdot
.3991 .68564 Mdot
.27407 .42441 Mdot
.76299 .32751 Mdot
.63124 .52814 Mdot
.51747 .87485 Mdot
.37689 .75074 Mdot
.38098 .16546 Mdot
.42052 .63411 Mdot
.59909 .46856 Mdot
.43789 .43088 Mdot
.6313 .35644 Mdot
.54169 .71945 Mdot
.23877 .37482 Mdot
.42403 .44486 Mdot
.64324 .47573 Mdot
.5143 .36704 Mdot
.49372 .6391 Mdot
.31243 .38078 Mdot
.16161 .56085 Mdot
.50729 .71767 Mdot
.59035 .60058 Mdot
.27589 .7116 Mdot
.51032 .76918 Mdot
.83852 .44076 Mdot
.19718 .37563 Mdot
.29854 .46385 Mdot
.45742 .58794 Mdot
.56791 .82155 Mdot
.33821 .36245 Mdot
.31286 .42348 Mdot
.32152 .63468 Mdot
.78364 .49792 Mdot
.33364 .57322 Mdot
.21013 .64967 Mdot
.35962 .2077 Mdot
.64366 .4187 Mdot
.52929 .89301 Mdot
.73426 .33739 Mdot
.56786 .56785 Mdot
.33077 .57942 Mdot
.28263 .26855 Mdot
.603 .72188 Mdot
.53474 .15689 Mdot
.21431 .53341 Mdot
.37738 .33813 Mdot
.7747 .51272 Mdot
.37528 .80808 Mdot
.46461 .60694 Mdot
.39217 .84051 Mdot
.25974 .45259 Mdot
.73961 .50997 Mdot
.24382 .57186 Mdot
.32327 .41456 Mdot
.61986 .29375 Mdot
.21969 .49453 Mdot
.67706 .40273 Mdot
.41287 .36517 Mdot
.23642 .41874 Mdot
.76999 .56996 Mdot
.38395 .72494 Mdot
.25718 .42123 Mdot
.32126 .62711 Mdot
.4233 .44072 Mdot
.75715 .34201 Mdot
.49033 .72524 Mdot
.51144 .71157 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Hooooo`;o000000?oooooo`00
0?l00000[?ooool001cooooo00?o0000ooooooooool0TOooool4o`0000?ooooo0_l000000ooooooo
0000o`00002/ooooo`007?ooool00ol0003oooooooooo`2Aooooo`Co00002_ooool2o`000:Sooooo
000Looooo`;o0000Ooooool4o`0001gooooo0_l0002Xooooo`007?ooool00ol0003oooooooooo`1n
ooooo`Co00000oooool2o`000003ooooool0003o000000;ooooo0_l0000Kooooo`?o0000WOooool0
01cooooo00?o0000ooooooooool0P_ooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2
o`00017ooooo0_l00004ooooo`;o00000_ooool5o`0009_ooooo000Looooo`03o`000?oooooooooo
07Gooooo0_l0000;ooooo`;o00002Oooool2o`0000;ooooo1?l00002ooooo`;o000000?oooooo`00
0?l000000oooool4o`0000;ooooo0_l00005ooooo`;o0000Voooool001cooooo00?o0000oooooooo
ool0MOooool5o`0000_ooooo0_l00006ooooo`;o00000_ooool5o`000004ooooool0003o0000oooo
o`;o000000?oooooo`000?l000000_ooool4o`000:Cooooo000Looooo`03o`000?oooooooooo07Ko
oooo1?l00004ooooo`?o00001?ooool2o`0000Kooooo0_l00005ooooo`;o00001oooool2o`0000Co
oooo0ol0002Sooooo`007?ooool00ol0003oooooooooo`1mooooo`Co00008oooool2o`000:?ooooo
000Looooo`03o`000?oooooooooo06oooooo0_l0000;ooooo`Co00002?ooool2o`000003ooooool0
003o000002gooooo0_l0002=ooooo`007?ooool00ol0003oooooooooo`1_ooooo`;o00002oooool2
o`0000[ooooo0_l000001?oooooo0000o`000?l0000Vooooo`;o00001?ooool2o`0008gooooo000L
ooooo`03o`000?oooooooooo06oooooo0_l0000Kooooo`;o00009_ooool4o`00097ooooo000Loooo
o`03o`000?oooooooooo09;ooooo0ol0000Oooooo`Co00001Oooool3o`0008Wooooo000Looooo`03
o`000?oooooooooo08Oooooo0_l00009ooooo`?o0000:?ooool3o`0008Wooooo000Looooo`03o`00
0?oooooooooo077ooooo0_l0000Dooooo`;o00002_ooool2o`0000kooooo0_l00008ooooo`;o0000
3Oooool4o`0008Wooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go
00001_ooool00ol0003oooooooooo`1aooooo`;o00008oooool2o`0000_ooooo1?l00006ooooo`;o
00003Oooool2o`0008_ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44oooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`2Booooo`;o00000_ooool2
o`0000_ooooo1?l0000Eooooo`;o0000Roooool00003ooooool@413ooooo00;ooooo00?o410@oooo
ooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo097ooooo0ol00006oooo
o`;o00001oooool2o`0000Sooooo1?l000000ooooooo0000o`00000=ooooo`;o0000Q_ooool00003
ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06ooooo`?o
0000Ioooool2o`0002?ooooo0_l00003ooooo`;o00001oooool2o`00017ooooo1ol0000=ooooo`;o
0000Q_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIV
ooooo`05ooooo`03o`000?oooooooooo06Gooooo1?l0000Sooooo`;o00007oooool6o`0000kooooo
0_l000000ooooooo0000o`000023ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0IOooool2o`0000Sooooo1?l0
000Iooooo`;o00008Oooool4o`00017ooooo0_l00023ooooo`0000KoooooogMgMonHV9SooooooiRH
V?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`1^ooooo`Go
00006Oooool2o`0001Kooooo0_l0000:ooooo`;o0000Uoooool00006ooooooo^k^ko<S8bo`000?lb
<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0KOooool3
o`000003ooooool0003o000000[ooooo0_l0000Sooooo`Co000000?oooooo`000?l000003?ooool2
o`0000Cooooo0_l0000>ooooo`;o000000?oooooo`000?l00000NOooool001cooooo00?o0000oooo
ooooool0KOooool2o`0000kooooo0ol0000Pooooo`Co00000oooool2o`000004ooooool0003o0000
o`0000Sooooo0_l000001?oooooo0000o`000?ooool2o`0000kooooo0_l000000ooooooo0000o`00
001iooooo`007?ooool00ol0003oooooooooo`1nooooo`?o00007oooool2o`0000Sooooo1Ol00006
ooooo`;o000000Coooooo`000?l0003o00001Oooool2o`0000Oooooo1?l0000Dooooo`;o0000I_oo
ool001cooooo00?o0000ooooooooool0Ooooool2o`0001oooooo0_l0000;ooooo`;o00001_ooool2
o`0000;ooooo0_l00004ooooo`?o00001oooool2o`000003ooooool0003o000001?ooooo0_l0001V
ooooo`007?ooool00ol0003oooooooooo`1Vooooo`;o00005Oooool2o`0000cooooo0_l0000/oooo
o`Co00000_ooool3o`0000Sooooo1?l00005ooooo`;o0000M?ooool001cooooo00?o0000oooooooo
ool0I_ooool2o`0000?ooooo0ol00002ooooo`;o00002oooool2o`0000_ooooo0ol0000Qooooo`;o
00000_ooool2o`0000Kooooo0ol00002ooooo`?o00002?ooool4o`000004ooooool0003o0000oooo
o`?o0000M?ooool001cooooo00?o0000ooooooooool0Foooool2o`0000Wooooo0_l000000ooooooo
0000o`000003o`0000;ooooo0_l0000Fooooo`Co00008_ooool2o`000003ooooool0003o000000;o
00001Oooool2o`0001?ooooo0_l000000ooooooo0000o`000002o`0007?ooooo000Looooo`03o`00
0?oooooooooo05_ooooo0_l0000:ooooo`Go00003Oooool2o`0000gooooo0_l0000Wooooo`Co0000
3Oooool2o`0000_ooooo0_l00003ooooo`;o0000Loooool001cooooo00?o0000ooooooooool0Gooo
ool2o`0000Kooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00006ooooo`;o0000
=_ooool3o`0000cooooo1?l0000;ooooo`Co00004oooool2o`00067ooooo000Looooo`03o`000?oo
oooooooo05oooooo0_l00004ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo0_l0
000:ooooo`;o00001oooool2o`0001_ooooo1?l000000ooooooo0000o`000002o`0000Kooooo0ol0
000;ooooo`Go00003?ooool2o`0001?ooooo0ol0001Pooooo`007?ooool00ol0003oooooooooo`1U
ooooo`;o00000_ooool3o`0000?ooooo0_l0000<ooooo`;o00001oooool2o`0001[ooooo2_l00004
ooooo`;o000000?oooooo`000?l000003Oooool4o`0000Cooooo0_l00005ooooo`;o00005?ooool2
o`00063ooooo000Looooo`03o`000?oooooooooo05?ooooo0_l0000<ooooo`?o00001Oooool5o`00
0003ooooool0003o000001Gooooo0_l0000Jooooo`;o00000oooool2o`0000Oooooo0_l0000Boooo
o`;o00000_ooool4o`0007gooooo000Looooo`;o0000E?ooool2o`0000cooooo0ol00002ooooo`;o
000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00005?ooool2o`00043ooooo1?l0000Coooo
o`;o0000J?ooool001cooooo00?o0000ooooooooool0I_ooool2o`0000Sooooo0_l0000Eooooo`;o
0000E_ooool2o`0006Sooooo000Looooo`03o`000?oooooooooo05oooooo0_l0000Iooooo`;o0000
0_ooool2o`0000Oooooo0_l00030ooooo`007?ooool00ol0003oooooooooo`1Hooooo`?o00001?oo
ool2o`0001Wooooo0_l00002ooooo`;o00001_ooool3o`0002Gooooo0_l00008ooooo`;o00006Ooo
ool2o`0000Oooooo0_l00003ooooo`;o0000I_ooool001cooooo00?o0000ooooooooool0F?ooool3
o`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l000003oooool2o`000003ooooool0003o
000000Wooooo0_l0000Vooooo`;o00002?ooool2o`00013ooooo0_l00007ooooo`;o00001oooool2
o`0000?ooooo0_l0001Vooooo`007?ooool00ol0003oooooooooo`1Oooooo`?o00000_ooool2o`00
0003ooooool0003o000000oooooo0_l000000ooooooo0000o`00000mooooo`;o00003_ooool2o`00
00;ooooo0_l0000Looooo`;o0000Foooool001cooooo00?o0000ooooooooool0Doooool2o`0000;o
oooo0ol00003ooooo`Co00006_ooool2o`0000Cooooo0_l0000Uooooo`;o00001Oooool2o`000003
ooooool0003o000000Kooooo0_l00003ooooo`;o00003?ooool3o`0001cooooo0_l0001Kooooo`00
7?ooool00ol0003oooooooooo`1Cooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o0000
0oooool2o`0001Oooooo0_l00002ooooo`Co00009Oooool2o`0000Gooooo1Ol0000;ooooo`;o0000
2_ooool4o`0001?ooooo0_l00008ooooo`;o0000Foooool001cooooo00?o0000ooooooooool0D?oo
ool2o`0000Cooooo0_l00007ooooo`Go00001oooool2o`0000?ooooo0_l00006ooooo`;o00001Ooo
ool2o`0002Oooooo0ol00006ooooo`;o00003?ooool2o`0000[ooooo0_l0000Eooooo`;o0000IOoo
ool001cooooo00?o0000ooooooooool0Coooool5o`0000;ooooo0_l00005ooooo`Ko00000_ooool2
o`0000Cooooo0_l00003ooooo`;o00001_ooool2o`0000cooooo0_l0000Pooooo`?o00001_ooool2
o`000003ooooool0003o000000;o0000:oooool2o`0000Wooooo0_l0001Iooooo`007?ooool00ol0
003oooooooooo`1?ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Gooooo0_l00006oooo
o`?o00006Oooool2o`0000;ooooo0ol0000Yooooo`;o000000?oooooo`000?l000001?l00004oooo
o`;o000000?oooooo`000?l000002Oooool2o`0001Gooooo0_l000000ooooooo0000o`000006oooo
o`;o0000FOooool001cooooo00?o0000ooooooooool0D_ooool2o`000003ooooool0003o000000;o
oooo0_l00009ooooo`Co00001oooool5o`0000Cooooo0_l00007ooooo`;o00000_ooool3o`0002Wo
oooo0ol000001?oooooo0000o`000?ooool2o`0000Cooooo0_l000000ooooooo0000o`000009oooo
o`?o00000oooool2o`0001;ooooo0_l00006ooooo`;o0000FOooool001cooooo00?o0000oooooooo
ool0D_ooool2o`000003ooooool0003o000000Co00002Oooool4o`0000Oooooo1Ol00004ooooo`;o
00000oooool2o`000003ooooool0003o000000Cooooo0_l0000Zooooo`Go00005_ooool2o`0000?o
oooo0_l0000Jooooo`;o0000FOooool001cooooo00?o0000ooooooooool0Eoooool2o`0000kooooo
0_l00009ooooo`;o00002Oooool2o`000003ooooool0003o000002Oooooo0_l00008ooooo`?o0000
2?ooool2o`0000Cooooo0_l00009ooooo`;o00003_ooool2o`0000Cooooo0_l000000ooooooo0000
o`000004ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0Boooool2o`0000oooooo0_l0
0008ooooo`Go000000Coooooo`000?l0003ooooo0_l00009ooooo`?o00000oooool2o`0002Oooooo
1?l00007ooooo`;o00001?ooool6o`0000Cooooo1?l00007ooooo`;o00003Oooool3o`0000Cooooo
1Ol00004ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0Boooool2o`0000oooooo1?l0
0006ooooo`;o000000Coooooo`000?l0003ooooo1Ol00004ooooo`;o00000oooool5o`0000Oooooo
0_l0000Looooo`;o00001Oooool4o`0000_ooooo1Ol00005ooooo`Ko00001Oooool2o`0000Oooooo
0_l00004ooooo`;o00001oooool5o`0000Cooooo0_l0001Gooooo`007?ooool2o`0004cooooo0_l0
000Aooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`?o00000_ooool6o`0000;ooooo
2_l00004ooooo`;o000000Coooooo`000?l0003o00006oooool2o`0000Oooooo0_l0000<ooooo`;o
00002?ooool6o`0000Cooooo0_l00007ooooo`;o00003Oooool6o`0000?ooooo0_l0001Gooooo`00
7?ooool00ol0003oooooooooo`1?ooooo`;o00004Oooool2o`000003ooooool0003o000000Co0000
0_ooool7o`000003ooooool0003o000000Ko00001_ooool2o`0000;ooooo0_l0000Dooooo`;o0000
1oooool7o`0000;ooooo0_l0000:ooooo`;o00002?ooool3o`000003ooooool0003o000000gooooo
0_l00007ooooo`;o00000_ooool8o`0005cooooo000Looooo`03o`000?oooooooooo04Kooooo0_l0
0002ooooo`;o000000?oooooo`000?l000000_l00003ooooo`Co00000_ooool2o`0000[ooooo0_l0
00000ooooooo0000o`000002ooooo`Co000000Coooooo`000?l0003ooooo1Ol0000Sooooo`;o0000
1Oooool9o`0000;ooooo0_l0000Wooooo`;o00001_ooool4o`000003ooooool0003o000000?o0000
Goooool001cooooo00?o0000ooooooooool0A_ooool2o`0000;ooooo0_l000000ooooooo0000o`00
0005ooooo`Co00000_ooool2o`0000gooooo0_l00002ooooo`Co00001oooool2o`00017ooooo0_l0
000>ooooo`;o000000?oooooo`000?l000001?ooool8o`0001Sooooo0_l0000Jooooo`Co0000IOoo
ool001cooooo00?o0000ooooooooool0Hoooool2o`0000Sooooo0ol00008ooooo`?o00004?ooool2
o`0000kooooo0_l000000ooooooo0000o`000004o`000003ooooool0003o000000Go00001?ooool2
o`00017ooooo1Ol00004ooooo`Co00004?ooool2o`0000Cooooo0_l00007ooooo`Co0000E_ooool0
01cooooo00?o0000ooooooooool0D_ooool2o`0000oooooo0_l00003ooooo`;o00003_ooool3o`00
013ooooo0_l0000Booooo`Go000000?oooooo`000?l000000ol00006ooooo`;o00004Oooool2o`00
0003ooooool0003o000000Cooooo1Ol0000?ooooo`?o000000?oooooo`000?l000000_l00007oooo
o`Co0000E_ooool001cooooo00?o0000ooooooooool0C_ooool2o`0000;ooooo0_l0000;ooooo`;o
00001oooool2o`0001Sooooo0_l00007ooooo`;o00003_ooool2o`0000;ooooo1?l00004ooooo`;o
00006_ooool2o`0000Cooooo0_l00004ooooo`;o00000oooool2o`0000_ooooo0_l000000ooooooo
0000o`000003ooooo`Go00000_ooool4o`0005Gooooo000Looooo`03o`000?oooooooooo04;ooooo
0_l00003ooooo`;o00000oooool4o`0000Sooooo0_l00005ooooo`;o00008Oooool2o`0000[ooooo
0_l0000;ooooo`So00007Oooool2o`0000Oooooo0_l00009ooooo`;o00004?ooool2o`000003oooo
ool0003o000000?o00000_ooool5o`0005Cooooo000Looooo`03o`000?oooooooooo04;ooooo0_l0
0003ooooo`;o00000oooool2o`0000[ooooo0_l0000Dooooo`;o00001_ooool2o`0000Kooooo0_l0
000>ooooo`;o00003Oooool5o`0001?ooooo0ol00008ooooo`;o00002_ooool3o`0000Wooooo0_l0
000<ooooo`;o000000?oooooo`000?l000000ol00004ooooo`Co0000Doooool001cooooo00?o0000
ooooooooool0@Oooool2o`0000cooooo0_l00007ooooo`;o00001_ooool2o`0000[ooooo1?l00004
ooooo`Go00001Oooool2o`0000cooooo0_l0000Aooooo`?o000000?oooooo`000?l000004?ooool3
o`0001Cooooo0ol00002ooooo`?o00001?ooool2o`0000oooooo1Ol00004ooooo`Go0000D_ooool0
01cooooo00?o0000ooooooooool0@?ooool3o`0000Kooooo0_l00004ooooo`;o00000oooool3o`00
0003ooooool0003o000000Kooooo0_l00004ooooo`;o00001?ooool5o`0000?ooooo0_l000000ooo
oooo0000o`00000>ooooo`Co000000?oooooo`000?l000005Oooool2o`0000gooooo2ol00002oooo
o`Ko00003?ooool4o`000003ooooool0003o000001?ooooo1?l00002ooooo`;o000000?oooooo`00
0?l000000_l000000ooooooo0000o`000005ooooo`;o0000Aoooool001cooooo00?o0000oooooooo
ool0?_ooool4o`0000;ooooo0_l00003ooooo`;o00001?ooool2o`0000?ooooo0ol0000=ooooo`Co
00001oooool4o`0001Cooooo1?l0000Booooo`;o00004ooooolDo`0000gooooo0_l000000ooooooo
0000o`000002o`0000Oooooo0_l00005ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`Go
00001Oooool2o`0004Oooooo000Looooo`03o`000?oooooooooo03gooooo0ol000001?oooooo0000
o`000?ooool2o`0000Wooooo0_l00002ooooo`Co00003Oooool2o`0000;ooooo0ol00006ooooo`;o
00001?ooool3o`0002?ooooo1?l00007ooooo`;o000000?oooooo`000?l000001_ooool8o`0000;o
oooo2Ol00004ooooo`Go00001_ooool2o`000004ooooool0003o0000ooooo`;o00001?ooool2o`00
00Gooooo0_l000001?oooooo0000o`000?ooool2o`0000Oooooo0_l0001@ooooo`007?ooool00ol0
003oooooooooo`0mooooo`;o00000_ooool2o`0000oooooo1?l00009ooooo`;o00001oooool3o`00
00cooooo0ol00005ooooo`;o00001_ooool2o`0001Cooooo1?l00007ooooo`Go00001_ooool;o`00
00;ooooo1_l00002ooooo`Oo00001?ooool4o`0000;ooooo1?l00006ooooo`;o00001_ooool2o`00
0003ooooool0003o000005Wooooo000Looooo`03o`000?oooooooooo03_ooooo0_l00009ooooo`;o
00002_ooool4o`0000Wooooo0ol0000@ooooo`;o00002oooool2o`0000Kooooo0_l00009ooooo`?o
00004oooool5o`0000?ooooo0_l00003ooooo`;o00000oooool6o`000003ooooool0003o000000co
00001?ooool4o`0000;ooooo0_l00006ooooo`Go00001oooool2o`0000?ooooo0_l0000=ooooo`;o
0000A_ooool001cooooo00?o0000ooooooooool0>oooool2o`0000Wooooo0_l00007ooooo`;o0000
2Oooool8o`0000Cooooo0_l0000:ooooo`;o00002Oooool2o`0000Kooooo0_l00007ooooo`Oo0000
3_ooool2o`0000;ooooo0ol000001Ooooooo0000o`000?l0003ooooo00?o00000_ooool3o`0000;o
oooo0_l00002ooooo`?o000000?oooooo`000?l000001_l000000ooooooo0000o`000006o`000005
ooooool0003o0000o`000?ooool00ol00007ooooo`;o000000?oooooo`000?l000001oooool2o`00
00?ooooo0_l0000=ooooo`;o0000A_ooool001cooooo0_l0000looooo`;o00001oooool2o`0000Wo
oooo0_l00009ooooo`Ko00001_ooool2o`0000kooooo0_l00005ooooo`;o00001_ooool2o`0000Oo
oooo1?l00005ooooo`Co00002?ooool>o`000003ooooool0003o000000Co000000Coooooo`000?l0
003o00000_ooool2o`000004ooooool0003o0000ooooo`ko000000Goooooo`000?l0003o0000oooo
o`03o`0000oooooo1Ol000000ooooooo0000o`00000Eooooo`;o0000@Oooool001cooooo00?o0000
ooooooooool0>oooool2o`0000Oooooo0_l00006ooooo`;o00003?ooool2o`0000Kooooo0_l0000B
ooooo`;o00001_ooool3o`0001Kooooo1?l00008ooooo`Go00000_ooool2o`000005ooooool0003o
0000o`000?ooool03ol00002ooooo`So00000_ooool2o`000003ooooool0003o000000;o000000?o
ooooo`000?l000000_l0000Aooooo`So00005Oooool2o`00047ooooo000Looooo`03o`000?oooooo
oooo04cooooo0_l0000Dooooo`;o00004_ooool4o`0000?ooooo1?l0000Eooooo`;o00002Oooool7
o`0000Gooooo0ol000000ooooooo0000o`00000Ao`0000;ooooo1Ol000000ooooooo0000o`000005
o`000003ooooool0003o000000Co00004Oooool4o`0005[ooooo000Looooo`03o`000?oooooooooo
053ooooo0_l00004ooooo`Go00000_ooool2o`0000?ooooo1?l00006ooooo`;o00000oooool4o`00
0003ooooool0003o000000;o00000oooool4o`0000?ooooo0_l0000@ooooo`;o00002Oooool6o`00
0003ooooool0003o000000;o00000_oooolFo`0000;ooooo1Ol00003ooooo`?o000000?oooooo`00
0?l000001?ooool2o`0006oooooo000Looooo`03o`000?oooooooooo03_ooooo0_l0000Cooooo`;o
00001?ooool5o`0000;ooooo0_l00003ooooo`Co00001?ooool;o`0000?ooooo0_l0000:ooooo`;o
00004oooool2o`0000Kooooo1?l00003oooooaco00000_ooool2o`0000Gooooo0ol00002ooooo`;o
00003_ooool2o`000004ooooool0003o0000o`0000;ooooo0_l00002ooooo`;o00006?ooool2o`00
03oooooo000Looooo`03o`000?oooooooooo03Oooooo0_l00002ooooo`;o00006_ooool4o`0000Ko
oooo0ol00006ooooo`[o00001?ooool2o`0000Sooooo1?l00007ooooo`;o00002_ooool2o`0000Oo
oooo0ol00004oooooago00001oooool5o`0000_ooooo0_l00003ooooo`;o000000Coooooo`000?l0
003o00000_ooool2o`0000;ooooo0_l0000Hooooo`;o0000?oooool001cooooo00?o0000oooooooo
ool0=oooool3o`0000cooooo0_l00005ooooo`;o00002_ooool2o`0000Kooooo0ol00002ooooo`;o
00000_ooool=o`0000_ooooo1?l00007ooooo`Co00001Oooool2o`0000Oooooo1_l00003oooooako
00002?ooool5o`000003ooooool0003o000000;o000000?oooooo`000?l000000_ooool2o`0000Go
oooo0_l00006ooooo`?o0000F_ooool001cooooo00?o0000ooooooooool0=_ooool4o`0000cooooo
0_l00005ooooo`?o00004oooool5o`0000?ooooo3Ol00006ooooo`Co00001oooool2o`0000Cooooo
0_l00002ooooo`;o000000?oooooo`000?l000001_ooool7o`0000?ooooo7?l00002ooooo`;o0000
1_ooool5o`000003ooooool0003o000000;o000000?oooooo`000?l000002Oooool2o`0000Kooooo
1Ol0000Hooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0=Oooool3o`0000Cooooo0_l0
0006ooooo`;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000@ooooo`Go000000?o
ooooo`000?l000003ol00003ooooo`Go00001?ooool2o`000003ooooool0003o000000Sooooo0_l0
0009ooooo`;o00001OoooolSo`0000?ooooo0ol000000ooooooo0000o`000002o`0000Gooooo0_l0
0008ooooo`?o00001?ooool2o`000003ooooool0003o000000Co00005oooool2o`0003kooooo000L
ooooo`03o`000?oooooooooo03Gooooo1Ol00002ooooo`;o00001_ooool2o`0000Cooooo1?l00003
ooooo`;o00004_ooool2o`000003ooooool0003o000001Wo00000oooool2o`0000Kooooo1?l0000@
ooooobGo00001?ooool3o`000003ooooool0003o000000;o00001?ooool3o`000003ooooool0003o
000000Gooooo0ol000001?oooooo0000o`000?ooool2o`0000Cooooo0ol0001Gooooo`007?ooool0
0ol0003oooooooooo`0hooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o00001_oo
ool4o`0001Cooooo0_l00003ooooo`Go00000_oooolEo`0000_ooooo1Ol00002ooooo`;o00002?oo
ool2o`000005ooooool0003o0000o`000?ooool00ol000000ooooooo0000o`00000No`000003oooo
ool0003o000000;o00000_ooool2o`0000Cooooo0_l00002ooooo`;o00002Oooool2o`000003oooo
ool0003o000000;ooooo1?l0001Hooooo`007?ooool00ol0003oooooooooo`0looooo`;o000000Co
ooooo`000?l0003ooooo0_l0000Nooooo`;o00000_oooolOo`0000Cooooo0_l00005ooooo`?o0000
0_ooool2o`0000;ooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo9Ol00003ooooo`;o
00000oooool2o`0000?ooooo0_l0000@ooooo`Ko0000F_ooool001cooooo00?o0000ooooooooool0
>?ooool2o`0000Oooooo0_l00004ooooo`;o00007OoooolOo`0000Cooooo0_l000001?oooooo0000
o`000?ooool4o`000004ooooool0003o0000o`0000;ooooo1?l00002ooooo`;o000000?oooooo`00
0?l000009?l00003ooooo`;o00000oooool4o`0001Oooooo1?l0001Jooooo`007?ooool00ol0003o
ooooooooo`0booooo`;o00001?ooool2o`0000Oooooo0_l00004ooooo`;o00002_ooool2o`0000go
oooo0ol00002ooooo`?o000000?oooooo`000?l000004Ol000000ooooooo0000o`000002o`000003
ooooool0003o000000Kooooo0_l000000ooooooo0000o`000002ooooo`?o00001Oooool2o`0000Go
oooo1_l000000ooooooo0000o`00000Do`000003ooooool0003o000000Oo00000_ooool4o`000003
ooooool0003o000000;o00005Oooool8o`0005Sooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^
kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0boooo
o`;o00007oooool2o`0000gooooo1Ol000000ooooooo0000o`00000?o`000003ooooool0003o0000
00Co000000?oooooo`000?l000000ol0000=ooooo`;o00000_ooool2o`0000;ooooo0_l00006oooo
obKo00000_ooool4o`0000?ooooo1?l0000=ooooo`;o00000oooool3o`0000Cooooo0_l0001Hoooo
o`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo037ooooo0_l00009ooooo`;o00001_ooool2o`0001Oooooo0_l00003
oooooako00000_ooool3o`0001;ooooo0_l00002ooooo`?o00001OoooolVo`0000;ooooo1?l00003
ooooo`Co00003Oooool2o`0000?ooooo1?l0001Mooooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`09ooooo`Go00001_ooool00ol0003oooooooooo`0aooooo`;o00002Oooool2o`00
00Kooooo0_l000000ooooooo0000o`00000Dooooo`;o000000?oooooo`000?l000001?l000001?oo
oooo0000o`000?ooool=o`000003ooooool0003o000000Ko000000?oooooo`000?l000000_l00000
0ooooooo0000o`000005ooooo`?o00002_ooool4o`0000?ooooo0_l00003ooooobWo00000oooool2
o`0001Kooooo0_l00006ooooo`;o00002oooool2o`0004Sooooo00000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`0004Oooooo0_l0000?
ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`000003ooooool0
003o000000Ko000000?oooooo`000?l000003_l00003ooooo`;o00001Oooool3o`000003ooooool0
003o000000Oooooo0ol00003ooooo`?o00001?oooolPo`000003ooooool0003o000000Co00001?oo
ool2o`0000Cooooo0_l0000@ooooo`;o00001_ooool2o`0000Oooooo0_l00002ooooo`?o0000Aooo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?oMgMgoEEEEooooool0
0007ooooo`03o`000?oooooooooo05Cooooo0_l00002ooooo`;o00000oooool2o`0000?ooooo0ol0
0002oooooaco00002_ooool6o`0000Oooooo0ol00003ooooo`Co00000_ooool7o`000003ooooool0
003o000000?o000000?oooooo`000?l000004?l00004ooooo`?o00002oooool5o`0000cooooo0ol0
000;ooooo`;o00000_ooool2o`0000?ooooo0_l00017ooooo`0000?ooooooa0@4?ooool00_ooool0
0ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0Boooool2
o`0000Oooooo0_l00002ooooo`?o00000_ooool2o`0000?ooooo0_l00003oooooago00003?ooool2
o`0000cooooo0_l000001?oooooo0000o`000?l00002ooooo`Oo000000?oooooo`000?l000007_l0
0002ooooo`;o00001oooool4o`0000Kooooo0_l00002ooooo`Ko00002_ooool2o`00053ooooo0000
1_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l000001oooool00ol0003ooooo
ooooo`14ooooo`;o00001Oooool2o`0000cooooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo
7_l0000;ooooo`;o00003Oooool2o`000003ooooool0003o000000?o00000_ooool5o`0000;ooooo
2ol000000ooooooo0000o`00000Ao`0000;ooooo0_l00007ooooo`Co00001_ooool2o`0000;ooooo
0_l00002ooooo`;o00005_ooool2o`0004Cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPgo
oooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`0]ooooo`;o00005Oooool2o`0000?o
oooo0_l0000?ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo6?l000000ooooooo
0000o`000002o`0000Sooooo0_l00003ooooo`;o00004Oooool5o`000003ooooool0003o0000023o
000000?oooooo`000?l000001?l00005ooooo`;o000000?oooooo`000?l000001oooool2o`0001Oo
oooo0_l00003ooooo`;o000000?oooooo`000?l00000A?ooool001cooooo00?o0000ooooooooool0
;Oooool2o`0000?ooooo0_l0000Eooooo`;o00001Oooool2o`0000Gooooo0_l000001?oooooo0000
o`000?ooool4o`0000Cooooo0_l000000ooooooo0000o`00000Io`0000Oooooo0_l0000Fooooo`Ko
000000?oooooo`000?l000007Ol00002ooooo`Oo000000?oooooo`000?l000000_ooool2o`0000[o
oooo0_l0000Booooo`;o00000oooool2o`0000?ooooo0_l00002ooooo`?o0000@_ooool001cooooo
00?o0000ooooooooool0<_ooool2o`0001Gooooo0_l00003ooooo`Co00001Oooool2o`000003oooo
ool0003o000000Ko000000Coooooo`000?l0003o00000oooool2o`000003ooooool0003o000001Go
00001_ooool3o`0000kooooo0_l00006ooooo`;o00000_ooool2o`000003ooooool0003o000000?o
000000?oooooo`000?l000006?l000000ooooooo0000o`000003o`000003ooooool0003o000000;o
00005Oooool3o`0000Wooooo0ol0000<ooooo`?o0000@_ooool001cooooo00?o0000ooooooooool0
;oooool2o`000003ooooool0003o000001Gooooo0_l00003ooooo`Co00000oooool2o`0000Cooooo
0_l00003ooooo`Ko00000_ooool:o`000003ooooool0003o000000Wo00000oooool4o`0000Cooooo
0_l0000?ooooo`?o00003?oooolIo`000003ooooool0003o000000[o000000?oooooo`000?l00000
0_ooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`?o00001Oooool3o`0000Wooooo
0_l00004ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0;oooool2o`00017ooooo0_l0
000;ooooo`;o00001?ooool3o`000003ooooool0003o000000;o00001?ooool5o`0000;ooooo5?l0
00001?oooooo0000o`000?l00002ooooo`?o00001_ooool2o`0000kooooo0_l000000ooooooo0000
o`000007ooooo`ko000000?oooooo`000?l000004ol00005ooooo`;o00000_ooool2o`000003oooo
ool0003o000000;ooooo0_l00004ooooo`?o00003?ooool2o`0000?ooooo0_l00004ooooo`;o0000
1?ooool2o`0000Gooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00002_oo
ool5o`0000;ooooo2?l00004ooooo`?o00000_ooool5o`0000;ooooo2ol000001Ooooooo0000o`00
0?l0003ooooo00?o00000oooool2o`0000Gooooo0ol0000@ooooo`Co00001_ooool2o`000003oooo
ool0003o000001[o000000?oooooo`000?l000000_l00005ooooo`;o000000?oooooo`000?l00000
2oooool3o`0000gooooo1?l000000ooooooo0000o`000005ooooo`;o00000oooool3o`0000Cooooo
0_l0000oooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00005?ooool2o`0000Kooooo0_l0
00001?oooooo0000o`000?ooool5o`0000Sooooo1ol00003ooooo`go000000Coooooo`000?l0003o
00000_ooool5o`0000Oooooo0ol0000@ooooo`Go00001?oooolOo`0000;ooooo0_l0000:ooooo`;o
00000oooool2o`0000Kooooo0_l0000@ooooo`;o00000_ooool2o`0000Cooooo0_l00004ooooo`;o
0000AOooool001cooooo00?o0000ooooooooool0<?ooool2o`0001Cooooo0_l00006ooooo`;o0000
0oooool7o`0000Sooooo1Ol00004ooooo`go00001?ooool2o`000003ooooool0003o000000;o0000
7Oooool2o`0000Cooooo2?l000000ooooooo0000o`000009o`000003ooooool0003o000000co0000
1Oooool2o`0000Sooooo0_l00006ooooo`;o00004_ooool4o`0000kooooo0_l00011ooooo`007?oo
ool00ol0003oooooooooo`1Cooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o00003?oo
ool>o`0000;ooooo1ol00005ooooo`;o00001_ooool2o`00017ooooo0_l00005ooooo`Co000000?o
ooooo`000?l000005ol00006ooooo`;o00001_ooool2o`0000Sooooo0_l0000>ooooo`;o00000_oo
ool3o`000003ooooool0003o000000Wooooo0_l000000ooooooo0000o`000011ooooo`007?ooool0
0ol0003oooooooooo`1Aooooo`;o00000_ooool4o`0000Gooooo0_l00003ooooo`;o000000?ooooo
o`000?l000001?ooool>o`000003ooooool0003o000000Ko00000oooool4o`0000Kooooo0_l0000A
ooooo`?o00000oooool2o`000003ooooool0003o000000;ooooo5ol00009ooooo`;o00000_ooool4
o`0000Oooooo0_l00007ooooo`;o00001_ooool2o`0000?ooooo0_l000000ooooooo0000o`000007
ooooo`Co00001Oooool2o`000003ooooool0003o000003[ooooo000Looooo`03o`000?oooooooooo
03Cooooo0_l0000<ooooo`;o00002Oooool2o`0000;ooooo0_l00002ooooo`;o000000Coooooo`00
0?l0003o00000oooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`0000;ooooo3_l00000
1?oooooo0000o`000?l00003ooooo`;o00000_ooool3o`000003ooooool0003o000000Cooooo0_l0
000Cooooo`;o00000oooool2o`0000Kooooo1_l000000ooooooo0000o`00000=o`0000Gooooo0_l0
0002ooooo`;o00000_ooool4o`0000Oooooo0ol00006ooooo`;o00005oooool3o`0000Kooooo0_l0
00000ooooooo0000o`00000jooooo`007?ooool00ol0003oooooooooo`0aooooo`;o000000?ooooo
o`000?l000003?ooool2o`0000Kooooo0_l000000ooooooo0000o`000009ooooo`Co00000_ooool2
o`0000Kooooo1?l00002ooooo`;o000000Coooooo`000?l0003ooooo0ol000000ooooooo0000o`00
0005o`0000Cooooo0_l00002ooooo`?o000000?oooooo`000?l000001?ooool2o`0001Gooooo0_l0
00000ooooooo0000o`000007ooooo`?o000000?oooooo`000?l000001?l00002ooooo`So00001_oo
ool2o`00013ooooo1?l000001?oooooo0000o`000?l0000:ooooo`;o000000?oooooo`000?l00000
3?ooool2o`0004Kooooo000Looooo`;o0000<_ooool2o`0001Oooooo0_l00003ooooo`Co00001_oo
ool3o`0000Wooooo0ol00007ooooo`;o000000?oooooo`000?l000000oooool4o`0000Cooooo0_l0
0005ooooo`;o00001_ooool2o`0001Kooooo0_l000001?oooooo0000o`000?ooool2o`0000Cooooo
0ol000000ooooooo0000o`000004o`0000;ooooo2?l0000Hooooo`?o00000_ooool3o`0000[ooooo
0_l000000ooooooo0000o`00001Dooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o00000ooo
ool4o`0000;ooooo0_l00003ooooo`;o00001_ooool2o`000003ooooool0003o000001Sooooo0ol0
0004ooooo`;o00001_ooool2o`0001cooooo0_l00009ooooo`Wo00000_ooool4o`0000Gooooo0_l0
00000ooooooo0000o`000002o`0000cooooo0_l0000@ooooo`?o0000E_ooool001cooooo00?o0000
ooooooooool0;_ooool2o`000003ooooool0003o000000_ooooo0_l0000:ooooo`;o00002Oooool2
o`0000?ooooo1?l000001?oooooo0000o`000?ooool2o`0000Kooooo0_l00002ooooo`;o00001Ooo
ool2o`0000Wooooo0_l00002ooooo`;o00002?ooool2o`0002Wooooo1ol00002ooooo`;o00001ooo
ool2o`000003ooooool0003o000000;o00002oooool2o`0000Cooooo0_l00006ooooo`;o00001?oo
ool2o`000003ooooool0003o000001?ooooo0_l00003ooooo`;o0000>Oooool001cooooo00?o0000
ooooooooool0;_ooool2o`000003ooooool0003o000000_ooooo0_l0000Looooo`;o000000?ooooo
o`000?l000000oooool3o`0000?ooooo0ol000000ooooooo0000o`000005ooooo`;o00003Oooool2
o`0002oooooo1_l0000Hooooo`;o00001oooool3o`000004ooooool0003o0000ooooo`;o00001_oo
ool2o`0000Gooooo1?l0000Booooo`?o00000oooool2o`0003Wooooo000Looooo`03o`000?oooooo
oooo03;ooooo0_l0000Uooooo`;o00000_ooool5o`0000;ooooo0ol00004ooooo`;o00001Oooool3
o`0000[ooooo0_l00003ooooo`;o00002_ooool4o`00027ooooo1_l000000ooooooo0000o`000002
ooooo`;o00000oooool2o`0000cooooo0_l00007ooooo`;o00000_ooool2o`0000Wooooo0_l00005
ooooo`?o00004oooool2o`0000Cooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`0boooo
o`;o00008?ooool2o`000003ooooool0003o000000;o00000_ooool7o`0000Cooooo0_l000001?oo
oooo0000o`000?ooool2o`0000;ooooo0ol0000:ooooo`;o00000_ooool3o`0000Sooooo1_l00009
ooooo`;o00005oooool2o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l0000D
ooooo`?o00000_ooool2o`0000;ooooo0_l00005ooooo`;o00001_ooool3o`0001Gooooo0_l00000
0ooooooo0000o`00000iooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00002Oooool2o`00
01Oooooo1Ol00008ooooo`?o00001?ooool2o`000004ooooool0003o0000ooooo`;o00004oooool2
o`0000Wooooo1?l0000;ooooo`;o00005oooool2o`0000Oooooo0_l00002ooooo`?o00001oooool2
o`0000_ooooo0ol00003ooooo`;o00000_ooool2o`0000Kooooo0_l00006ooooo`;o00004Oooool2
o`0000;ooooo0_l0000looooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00002Oooool4o`00
01Oooooo0_l0000Fooooo`?o00005Oooool2o`0000Oooooo0_l000000ooooooo0000o`00000Roooo
o`;o00001oooool2o`0000?ooooo0_l00005ooooo`Co00002Oooool4o`00013ooooo0_l0000Boooo
o`;o00001Oooool2o`0000?ooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0looooo`?o
00007_ooool2o`0000?ooooo0_l0000;ooooo`;o00002oooool3o`0000?ooooo0_l00002ooooo`;o
00001oooool5o`0000cooooo0_l0000Vooooo`;o000000?oooooo`000?l000000_l00009ooooo`;o
000000?oooooo`000?l000001Oooool2o`000003ooooool0003o000001Wooooo0_l00004ooooo`;o
00001?ooool2o`0003_ooooo000Looooo`03o`000?oooooooooo033ooooo0_l00008ooooo`;o0000
8Oooool2o`0000?ooooo0_l00005ooooo`;o00000oooool2o`0000cooooo0ol00003ooooo`;o0000
2oooool7o`0000[ooooo0_l0000Vooooo`;o00000oooool2o`0000Oooooo1ol00004ooooo`?o0000
00?oooooo`000?l000006Oooool2o`0000Cooooo0_l00004ooooo`;o0000>oooool001cooooo00?o
0000ooooooooool0<?ooool2o`0000Sooooo1?l0000Jooooo`;o00003oooool3o`0000;ooooo0ol0
0006ooooo`;o00006Oooool4o`0003;ooooo0_l0000<ooooo`Go00000_ooool2o`0000;ooooo0_l0
000;ooooo`;o00004?ooool2o`0004Oooooo000Looooo`03o`000?oooooooooo02oooooo0_l0000;
ooooo`;o00006_ooool2o`00013ooooo0_l00003ooooo`;o00001_ooool2o`0000;ooooo0_l00004
ooooo`;o00003_ooool5o`00013ooooo1?l0000:ooooo`;o00000oooool2o`0000?ooooo0ol00007
ooooo`;o00002?ooool4o`000004ooooool0003o0000o`0000?ooooo0_l000000ooooooo0000o`00
000<ooooo`;o00006Oooool2o`0003kooooo000Looooo`03o`000?oooooooooo02oooooo0_l0000^
ooooo`;o00001?ooool3o`0000_ooooo0_l00003ooooo`;o000000?oooooo`000?l000001?ooool2
o`0000kooooo0_l000000ooooooo0000o`000002o`0000kooooo1?l000000ooooooo0000o`000007
ooooo`;o00000oooool2o`0000?ooooo0ol0000=ooooo`;o000000?oooooo`000?l000000ol00000
0ooooooo0000o`000005ooooo`Co00002oooool2o`00017ooooo0_l00006ooooo`?o0000?_ooool0
01cooooo00?o0000ooooooooool0;oooool2o`0000[ooooo0_l00004ooooo`;o00007?ooool2o`00
00Cooooo0ol000000ooooooo0000o`000002ooooo`?o00000oooool2o`0000?ooooo0_l00007oooo
o`?o00000oooool2o`0000gooooo0_l000000ooooooo0000o`000002o`0000kooooo0_l0000Noooo
o`;o000000Coooooo`000?l0003ooooo1Ol00003ooooo`;o00000oooool6o`000005ooooool0003o
0000o`000?ooool00_l000001?oooooo0000o`000?l0000:ooooo`;o00001Oooool2o`0000Gooooo
0ol00004ooooo`;o0000>Oooool001cooooo00?o0000ooooooooool0;oooool2o`0000[ooooo0_l0
0004ooooo`;o000000?oooooo`000?l000007Oooool2o`0000Cooooo0_l00002ooooo`Go000000?o
ooooo`000?l000003Oooool2o`0000?ooooo0_l0000@ooooo`Co00000_ooool2o`0001_ooooo0_l0
0005ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0000?ooooo1?l00005ooooo`;o0000
1?ooool5o`000005ooooool0003o0000o`000?ooool00_l000001?oooooo0000o`000?l00003oooo
o`;o00001Oooool2o`0000cooooo0_l00005ooooo`;o0000>Oooool001cooooo00?o0000oooooooo
ool0@?ooool2o`0000;ooooo0_l0000Mooooo`;o00002?ooool2o`000003ooooool0003o000000;o
00003_ooool3o`0000;ooooo0ol0000=ooooo`;o000000?oooooo`000?l000000_l000000ooooooo
0000o`00000Kooooo`;o00001Oooool6o`0000Gooooo1_l000000ooooooo0000o`000002ooooo`;o
00003Oooool3o`000004ooooool0003o0000o`0000?ooooo0_l00007ooooo`;o00002?ooool2o`00
00Oooooo0_l0000iooooo`007?ooool2o`0002oooooo0_l0000<ooooo`;o00000_ooool2o`0002_o
oooo0_l000000ooooooo0000o`000003o`0000_ooooo1Ol00003ooooo`?o00003?ooool2o`000003
ooooool0003o000000;o00009Oooool9o`0000;ooooo1?l00003ooooo`;o00000_ooool2o`0000[o
oooo1_l0000@ooooo`;o00002?ooool2o`0000Oooooo0_l0000iooooo`007?ooool00ol0003ooooo
ooooo`0^ooooo`;o00003?ooool2o`0000Gooooo0_l0000Xooooo`;o000000Coooooo`000?l0003o
oooo0_l00008ooooo`;o000000?oooooo`000?l000000ol00004ooooo`;o00003Oooool6o`000003
ooooool0003o000000;o000000?oooooo`000?l000004?ooool2o`0000[ooooo0_l00003ooooo`Go
000000?oooooo`000?l000004oooool2o`000003ooooool0003o000000?o00005Oooool2o`0000Co
oooo0_l00012ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00004Oooool3o`0002Sooooo
0_l0000>ooooo`;o00001?ooool2o`0000Cooooo0_l0000=ooooo`Ko000000?oooooo`000?l00000
1Ol0000?ooooo`?o00002Oooool3o`000003ooooool0003o000000Kooooo0_l0000Cooooo`So0000
1_ooool2o`0000gooooo0_l0000>ooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0;ooo
ool2o`00017ooooo0_l0000Kooooo`;o00003?ooool5o`0000;ooooo0_l000000ooooooo0000o`00
000>ooooo`Co00002oooool2o`0000;ooooo0ol00003ooooo`Ko00003oooool2o`0000[ooooo0ol0
00000ooooooo0000o`000004o`0000Gooooo0_l0000@ooooo`Oo00000oooool3o`000003ooooool0
003o000001;ooooo0_l00003ooooo`;o00001?ooool2o`0003Sooooo000Looooo`03o`000?oooooo
oooo05oooooo0_l0000=ooooo`Co00000_ooool2o`000003ooooool0003o000000So00001_ooool2
o`0000gooooo3Ol000000ooooooo0000o`000003o`0000cooooo0_l0000;ooooo`;o00000oooool5
o`0000Cooooo0_l0000<ooooo`;o000000?oooooo`000?l000001Ol00004ooooo`?o000000?ooooo
o`000?l000001_ooool2o`0000[ooooo0_l00003ooooo`;o0000?_ooool001cooooo00?o0000oooo
ooooool0??ooool3o`0002;ooooo0_l0000<ooooo`;o00001oooool:o`0001Gooooo0ol000000ooo
oooo0000o`000006o`0000;ooooo1Ol0000;ooooo`;o000000?oooooo`000?l000002?ooool2o`00
00Kooooo0_l000000ooooooo0000o`00000=ooooo`Co000000?oooooo`000?l000000oooool2o`00
00;ooooo0_l0000<ooooo`;o0000Coooool001cooooo00?o0000ooooooooool0>oooool5o`00027o
oooo0_l0000<ooooo`;o00000_ooool3o`0000;ooooo2_l00009ooooo`;o00002_ooool2o`0000;o
oooo0_l00005ooooo`;o00000_ooool8o`0000[ooooo0_l00008ooooo`;o00002?ooool3o`0000go
oooo0_l00005ooooo`;o000000?oooooo`000?l000000_ooool5o`0000;ooooo0ol00002ooooo`;o
0000DOooool001cooooo00?o0000ooooooooool0>oooool2o`000003ooooool0003o000002oooooo
0_l000000ooooooo0000o`000002o`0000;ooooo2ol00008ooooo`;o00003_ooool4o`0000?ooooo
0_l00003ooooo`[o00001oooool4o`0000Cooooo1?l00004ooooo`Ko00001?ooool2o`0000Sooooo
1?l00003ooooo`Go00001?ooool4o`000003ooooool0003o000000;o000000?oooooo`000?l00000
6Oooool2o`0003Kooooo000Looooo`03o`000?oooooooooo03_ooooo0_l0000Yooooo`?o00002Ooo
ool2o`0000?ooooo3?l00007ooooo`;o00004Oooool2o`0000Gooooo0_l000000ooooooo0000o`00
000<o`0000?ooooo1?l00004ooooo`Co00001?ooool4o`0000Cooooo1?l00008ooooo`Co00001?oo
ool2o`0000Sooooo0_l00002ooooo`Go00005oooool2o`000003ooooool0003o000003Kooooo000L
ooooo`03o`000?oooooooooo03_ooooo0_l00003ooooo`;o00009?ooool3o`0000Cooooo0_l00002
ooooo`;o00000_ooool@o`0000Gooooo0_l00007ooooo`?o00001Oooool2o`0000Cooooo0_l00000
1?oooooo0000o`000?l00002ooooo`Co000000?oooooo`000?l000001Ol000000ooooooo0000o`00
0002o`0000Sooooo0_l00005ooooo`;o00001Oooool2o`0001cooooo0_l00002ooooo`Go00004ooo
ool2o`0000;ooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00003Oooool2
o`0001;ooooo0ol000000ooooooo0000o`000004ooooo`Co00002ooooolHo`0000Kooooo0_l00006
ooooo`Go00000oooool2o`0000Cooooo0_l00002ooooo`;o00000oooool2o`0000Cooooo2?l00007
ooooo`;o00002?ooool2o`0002Oooooo0_l000000ooooooo0000o`000002o`0000;ooooo0ol0000<
ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0<Oooool2o`0000oooooo0_l0000@oooo
o`?o000000?oooooo`000?l000001?ooool4o`0000_ooooo1?l00002ooooo`[o000000?oooooo`00
0?l000001?l00007ooooo`;o00002Oooool2o`0000?ooooo0_l00004ooooo`;o00000_ooool2o`00
00?ooooo0_l00004ooooo`[o000000?oooooo`000?l000000_ooool2o`00013ooooo0_l00008oooo
o`;o00005Oooool2o`0000;ooooo2?l0000<ooooo`;o0000?Oooool001cooooo00?o0000oooooooo
ool0@Oooool3o`0003?ooooo2ol0000Fooooo`;o00001oooool2o`0000;ooooo0ol00008ooooo`[o
000000?oooooo`000?l000002?ooool2o`0000[ooooo0_l00003ooooo`;o00000oooool2o`0001Wo
oooo1_l00007ooooo`;o000000?oooooo`000?l000001?l0000mooooo`007?ooool00ol0003ooooo
ooooo`0jooooo`;o00000_ooool2o`000003ooooool0003o000002Kooooo0_l0000<ooooo`_o0000
2?ooool2o`0000cooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l00000
1?l00006ooooo`;o00000_ooool2o`0000Gooooo0_l00008ooooo`;o00002oooool2o`0000;ooooo
1Ol00006ooooo`Go00004_ooool3o`0000Sooooo0_l000000ooooooo0000o`000002o`0003oooooo
000Looooo`03o`000?oooooooooo03[ooooo0_l00002ooooo`;o0000:Oooool2o`0000Oooooo0_l0
00000ooooooo0000o`00000:o`0000Wooooo0_l000000ooooooo0000o`00000;ooooo`?o00001ooo
ool7o`0000Sooooo0ol0000?ooooo`;o00002Oooool4o`0000?ooooo1_l00004ooooo`Go00008?oo
ool2o`000003ooooool0003o000003kooooo000Looooo`03o`000?oooooooooo04Kooooo0_l0000J
ooooo`;o00001Oooool2o`0000Oooooo3ol0000<ooooo`;o00002oooool2o`0000;ooooo0ol00005
ooooo`Go00002?ooool2o`0001_ooooo0_l00007ooooo`Co00001_ooool2o`0000[ooooo0ol0000D
ooooo`;o000000?oooooo`000?l00000?_ooool001cooooo0_l0000mooooo`Co00001_ooool2o`00
00kooooo0_l0000:ooooo`;o00004?ooool=o`0001Kooooo0_l00005ooooo`Co000000?oooooo`00
0?l000008Oooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0000Gooooo0_l00008
ooooo`;o00001?ooool4o`0000;ooooo0ol0000Dooooo`;o0000@Oooool001cooooo00?o0000oooo
ooooool0<Oooool2o`0000Wooooo1_l00002ooooo`;o00004?ooool2o`0000_ooooo0_l0000Boooo
o`[o00003oooool3o`0000Cooooo1_l00003ooooo`Go00008Oooool2o`0000Cooooo0_l000001?oo
oooo0000o`000?ooool2o`0001Gooooo1?l00003ooooo`;o00003oooool2o`0004Kooooo000Loooo
o`03o`000?oooooooooo033ooooo0ol0000=ooooo`;o00000_ooool2o`0000Wooooo0_l0000@oooo
o`Co00003Oooool2o`0000?ooooo2_l0000;ooooo`;o00000_ooool3o`0000Kooooo1?l00004oooo
o`;o00006Oooool2o`0000Oooooo0_l0000Wooooo`;o00004Oooool2o`0004Kooooo000Looooo`03
o`000?oooooooooo033ooooo0_l0000;ooooo`;o00004?ooool2o`00013ooooo0_l0000?ooooo`;o
00000oooool9o`0000Sooooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo1?l00004ooooo`;o
00000oooool2o`0001;ooooo0_l00004ooooo`;o00001oooool2o`0001Gooooo0ol0000;ooooo`;o
00000_ooool2o`0000Gooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`0`ooooo`?o0000
2_ooool2o`0000Cooooo0_l000000ooooooo0000o`00000[ooooo`;o00000oooool5o`000003oooo
ool0003o000000Sooooo0_l0000;ooooo`Co000000Coooooo`000?l0003ooooo0_l00003ooooo`;o
00004_ooool2o`0000Cooooo0_l0000?ooooo`;o00003Oooool3o`0000?ooooo0ol00005ooooo`;o
00001?ooool2o`0000?ooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`0`ooooo`?o0000
4?ooool2o`000003ooooool0003o000001;ooooo0_l0000>ooooo`;o00001oooool2o`0000?ooooo
0_l00004ooooo`Co00003oooool3o`000003ooooool0003o000000?ooooo0ol000000ooooooo0000
o`00000Kooooo`?o00003oooool2o`0000gooooo0ol00002ooooo`Co00002oooool2o`0000Sooooo
1Ol00004ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0@oooool2o`00017ooooo0_l0
0002ooooo`;o000000?oooooo`000?l000000_l00009ooooo`;o00002_ooool4o`0000Cooooo1?l0
000?ooooo`?o00000oooool6o`000003ooooool0003o000001Gooooo0_l00004ooooo`?o00007_oo
ool9o`0000oooooo0_l00004ooooo`Go00001?ooool2o`0004Cooooo000Looooo`03o`000?oooooo
oooo04?ooooo0_l00006ooooo`;o00001oooool=o`0001Gooooo0_l00002ooooo`?o00005?ooool2
o`0000Cooooo0ol000000ooooooo0000o`000009ooooo`;o00003Oooool2o`0000Gooooo0_l0000E
ooooo`Co00001Oooool=o`0000Wooooo1_l00002ooooo`Go0000B_ooool001cooooo00?o0000oooo
ooooool0AOooool2o`000003ooooool0003o000000Go000000?oooooo`000?l000000_ooool2o`00
00;ooooo2Ol00002ooooo`;o00001?ooool2o`0000_ooooo0_l00002ooooo`?o00005?ooool2o`00
00Cooooo0ol00005ooooo`;o00001Oooool2o`0001Kooooo0_l0000<ooooo`;o00001Oooool4o`00
00Cooooo3ol00008ooooo`;o00000_ooool3o`0000;ooooo0ol00004ooooo`;o0000AOooool001co
oooo00?o0000ooooooooool0AOooool2o`000003ooooool0003o000000;o000000Coooooo`000?l0
003ooooo0_l0000;ooooo`;o00001?ooool2o`0000Cooooo0_l000000ooooooo0000o`000003oooo
o`;o00001Oooool2o`0000gooooo0_l000000ooooooo0000o`00000;ooooo`Co00001?ooool2o`00
00Gooooo0_l0000Fooooo`;o00003?ooool2o`0000gooooo4?l0000<ooooo`;o00000oooool2o`00
00Cooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00006?ooool2o`0000Ko
oooo0_l00009ooooo`?o00000oooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;o
oooo0_l000000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l000000oooool5o`0000Go
oooo1?l00004ooooo`;o00001_ooool6o`0002kooooo0_l000001Ooooooo0000o`000?l0003ooooo
00oo00000_ooool2o`0000Sooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o
00006?ooool2o`0000;ooooo0_l00002ooooo`;o00001?ooool2o`0000?ooooo1Ol000001?oooooo
0000o`000?l00002ooooo`;o00001_ooool2o`0000?ooooo0_l00008ooooo`;o000000?oooooo`00
0?l000001Oooool2o`0000Kooooo1?l00004ooooo`?o00001?ooool7o`000003ooooool0003o0000
02Gooooo0_l00003ooooo`?o000000?oooooo`000?l000003_l000000ooooooo0000o`000002oooo
o`;o00002?ooool2o`00053ooooo000Looooo`03o`000?oooooooooo04Cooooo0_l00008ooooo`Co
00000oooool9o`0000;ooooo0_l000001?oooooo0000o`000?l00005ooooo`;o00000oooool2o`00
00Kooooo1_l00002ooooo`;o00002oooool2o`0000;ooooo0_l00006ooooo`?o00001?ooool7o`00
0003ooooool0003o000001?ooooo0_l0000@ooooo`;o00000oooool2o`0000?ooooo5_l00008oooo
o`;o0000D?ooool001cooooo00?o0000ooooooooool0A?ooool3o`0000Wooooo0_l00003ooooo`Wo
00001Oooool2o`0000Kooooo0_l00003ooooo`;o00000oooool2o`000003ooooool0003o000000Co
00000_ooool2o`0000Kooooo0_l00002ooooo`?o000000Coooooo`000?l0003o00003_ooool4o`00
00?ooooo0_l0000Cooooo`;o00001?ooool2o`0000oooooo6Ol00005ooooo`;o00002oooool2o`00
04Sooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o
0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0cooooo`;o00004?ooool2o`0000cooooo0_l0
0002ooooo`Ko00001?ooool4o`000003ooooool0003o000000Sooooo0_l00003ooooo`?o00002_oo
ool2o`0000Cooooo0_l00002ooooo`Ko00000_ooool2o`0000cooooo0_l00002ooooo`Co00006Ooo
ool2o`0000;ooooo0_l00007ooooo`?o000000?oooooo`000?l000006Ol00003ooooo`;o00000ooo
ool2o`0000Kooooo0_l00018ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q
1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0<oooool3o`0001go
oooo0_l00002ooooo`;o000000?oooooo`000?l000000_l00002ooooo`?o00000oooool2o`0000go
oooo1Ol00008ooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00000oooool2o`0000Ko
oooo0ol00002ooooo`;o00003_ooool2o`0000oooooo0_l00006ooooo`Co00001OoooolGo`0000Ko
oooo1Ol00003ooooo`;o00000oooool2o`0004Gooooo00000ooooooo410@ooooo`02ooooo`03oa0@
4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo03Co
oooo0_l0000Booooo`;o00003Oooool2o`000003ooooool0003o000000;o00000_ooool2o`0000co
oooo0_l00008ooooo`;o00004?ooool2o`0000Wooooo0_l000000ooooooo0000o`000004o`0000?o
oooo0_l0000Cooooo`?o00005_ooool2o`0000Cooooo5ol00009ooooo`;o000000?oooooo`000?l0
00000oooool2o`0000?ooooo0_l00015ooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooo
ooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0003Cooooo0_l000000ooooooo
0000o`00000?ooooo`;o00003Oooool2o`0000;ooooo1?l00003ooooo`;o000000?oooooo`000?l0
00001oooool2o`0000Sooooo0_l0000;ooooo`Co000000?oooooo`000?l000002Oooool9o`0000Co
oooo0ol000000ooooooo0000o`00000?ooooo`;o00000oooool2o`0000_ooooo0_l00004ooooo`;o
00000ooooolHo`000003ooooool0003o000000;o00003?ooool2o`0000?ooooo0_l00015ooooo`00
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`01_ooool00ol0003oooooooooo`0dooooo`;o000000Coooooo`000?l0003o00007oooool3o`00
0004ooooool0003o0000o`0000;ooooo0_l000000ooooooo0000o`00000Aooooo`Co00002Oooool4
o`0000;ooooo0_l00009ooooo`Co00000_ooool9o`000003ooooool0003o000000;ooooo0_l0000;
ooooo`;o00000oooool2o`0000Kooooo0_l00003ooooo`;o00001?ooool2o`0000?ooooo0_l00002
ooooo`_o000000?oooooo`000?l000002ol00007ooooo`;o00001Oooool2o`000003ooooool0003o
000004Gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEEohN7
Qoooool02?ooool00ol0003oooooooooo`0dooooo`Ko00007oooool3o`0000;ooooo0_l00002oooo
o`;o00003_ooool5o`000003ooooool0003o000000?o00001Oooool2o`0000;ooooo0_l00003oooo
o`;o00001_ooool2o`000004ooooool0003o0000o`0000Cooooo2Ol00004ooooo`;o00002oooool2
o`0000?ooooo0_l00006ooooo`;o00005?oooolEo`0000?ooooo0_l00004ooooo`;o00001Oooool4
o`0004Kooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`0fooooo`?o00008?ooool3o`0000Kooooo1?l00008ooooo`;o00000_oo
ool5o`000003ooooool0003o000000?o00001Oooool2o`0000;ooooo0_l0000;ooooo`;o000000?o
ooooo`000?l000001Oooool9o`0000[ooooo0_l0000Booooo`;o00002_ooool2o`0000Oooooo5_l0
00000ooooooo0000o`000003o`0000?ooooo0_l00007ooooo`;o0000A_ooool00006ooooooo^k^ko
<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo03Oo
oooo0_l0000Dooooo`;o00003?ooool2o`0000Oooooo0_l00008ooooo`;o000000?oooooo`000?l0
00000ol00002ooooo`Co00000oooool3o`0000Gooooo0_l00004ooooo`;o00001Oooool2o`0000Co
oooo0ol00002ooooo`Oo00002_ooool2o`0001gooooo0ol00006oooooaOo000000?oooooo`000?l0
00001Ol0001Booooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00003?ooool2o`0001Cooooo
0_l000000ooooooo0000o`000006o`0000?ooooo1?l00002ooooo`Co00001?ooool2o`0000Gooooo
0_l00004ooooo`?o00001?ooool5o`0001Cooooo0_l0000Cooooo`;o00001oooool9o`000003oooo
ool0003o000000Oo00001Oooool3o`0000;ooooo0_l0001Booooo`007?ooool00ol0003ooooooooo
o`0eooooo`;o00008_ooool2o`0000Oooooo0_l00005ooooo`;o00001_ooool;o`000003ooooool0
003o000000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000002_ooool2o`0000_ooooo1_l0
000@ooooo`;o000000Coooooo`000?l0003o00001_ooool3o`0000Oooooo0_l0000;ooooo`go0000
00?oooooo`000?l000000_l00002ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0=Ooo
ool2o`0002;ooooo0_l00007ooooo`;o000000Coooooo`000?l0003ooooo0ol00003ooooo`ko0000
00?oooooo`000?l000001oooool4o`0000[ooooo0_l0000<ooooo`Oo00001_ooool2o`0000Gooooo
0ol00002ooooo`;o00001_ooool4o`000003ooooool0003o000000;ooooo0ol00002ooooo`;o0000
2Oooool@o`000005ooooool0003o0000o`000?ooool00ol00005ooooo`;o0000C_ooool001cooooo
00?o0000ooooooooool0>Oooool3o`0001Sooooo0_l00004ooooo`;o00000oooool4o`0000;ooooo
0_l000000ooooooo0000o`00000Bo`000003ooooool0003o000000Oooooo0ol00009ooooo`;o0000
0_ooool2o`0000gooooo1Ol00005ooooo`;o00001Oooool4o`0000Wooooo1?l000000ooooooo0000
o`000002ooooo`;o00000oooool3o`0000Sooooo0_l000000ooooooo0000o`00000>o`0000;ooooo
0ol00005ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0>Oooool3o`0001;ooooo0_l0
0004ooooo`;o00001?ooool2o`0000?ooooo1?l00002ooooo`;o00000ooooolAo`000003ooooool0
003o000000;ooooo0_l0000?ooooo`?o00000_ooool2o`00013ooooo0_l000000ooooooo0000o`00
0007ooooo`;o00000_ooool2o`0000Wooooo0_l00003ooooo`;o00002?ooool2o`0000Sooooo0_l0
00000ooooooo0000o`000002o`000004ooooool0003o0000ooooo`Ko00001Oooool2o`0005Gooooo
000Looooo`03o`000?oooooooooo04kooooo0_l00009ooooo`?o00000_ooool2o`0000Sooooo0_l0
00000ooooooo0000o`00000=o`000004ooooool0003o0000o`0000;ooooo0_l00003ooooo`;o0000
2_ooool3o`0001Oooooo0_l00007ooooo`;o00003?ooool2o`0000Cooooo0_l00002ooooo`;o0000
3_ooool2o`0000gooooo0_l000001?oooooo0000o`000?l0001Hooooo`007?ooool00ol0003ooooo
ooooo`0looooo`;o00006oooool3o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l00000
4ol00008ooooo`;o00001Oooool2o`0000?ooooo0_l000000ooooooo0000o`00000Kooooo`?o0000
3?ooool4o`0000Sooooo0_l00006ooooo`;o00004oooool2o`0000;ooooo1?l0001Hooooo`007?oo
ool00ol0003oooooooooo`0looooo`;o00009ooooolJo`000003ooooool0003o000000[ooooo1?l0
0004ooooo`;o00001oooool2o`0001;ooooo1Ol0000:ooooo`;o00004_ooool2o`0000;ooooo0_l0
0009ooooo`;o00000oooool3o`0000;ooooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`1E
ooooo`;o00003_oooolJo`000003ooooool0003o000000Gooooo0_l00005ooooo`;o00002oooool5
o`000003ooooool0003o000000;ooooo0_l0000;ooooo`Go00005_ooool2o`0000Gooooo1_l00009
ooooo`;o000000?oooooo`000?l000000_l00008ooooo`;o0000EOooool001cooooo00?o0000oooo
ooooool0Coooool2o`0000Cooooo0_l0000<oooooa[o00002_ooool3o`0000;ooooo1?l00002oooo
o`;o00001oooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000kooooo0_l0000F
ooooo`;o00001Oooool4o`0000;ooooo0_l0000:ooooo`;o00002_ooool2o`0005Gooooo000Loooo
o`03o`000?oooooooooo043ooooo0ol0000<ooooo`;o00004Oooool3o`0000?ooooo5Ol000000ooo
oooo0000o`000008ooooo`;o00000_ooool4o`000004ooooool0003o0000o`0000cooooo0_l0000;
ooooo`;o00002Oooool2o`0000Gooooo0ol00005ooooo`;o00000oooool2o`0000cooooo1?l00002
ooooo`;o00000_ooool4o`000003ooooool0003o000005kooooo000Looooo`;o0000@Oooool3o`00
00cooooo0_l00007ooooo`?o00001ooooolKo`000003ooooool0003o000000;ooooo0_l00009oooo
o`;o00000_ooool2o`0000Wooooo0_l00002ooooo`;o00002oooool3o`0000Sooooo0_l00005oooo
o`?o00000_ooool2o`000003ooooool0003o000000?ooooo0_l0000>ooooo`Ko00000_ooool4o`00
0003ooooool0003o000005kooooo000Looooo`03o`000?oooooooooo05Sooooo0ol00008ooooo`go
000000?oooooo`000?l000002_l00005ooooo`;o00002Oooool2o`000004ooooool0003o0000o`00
00Wooooo0_l0000?ooooo`?o00000_ooool2o`00013ooooo0_l0000Hooooo`;o0000JOooool001co
oooo00?o0000ooooooooool0D?ooool2o`0000Kooooo0_l0000;oooooaSo00002?ooool2o`0000Oo
oooo1?l0000Iooooo`Ko000000?oooooo`000?l000000_l0002Cooooo`007?ooool00ol0003ooooo
ooooo`1@ooooo`;o00002oooool2o`0000Cooooo6Ol00009ooooo`;o00000_ooool2o`0000;ooooo
1?l0000Jooooo`Ko00000_ooool3o`0009?ooooo000Looooo`03o`000?oooooooooo04Kooooo0_l0
000Eooooo`;o00001?oooolKo`0000Cooooo0_l00003ooooo`Co000000?oooooo`000?l000000ol0
0002ooooo`Co00003Oooool2o`0000Gooooo1ol000000ooooooo0000o`00002Dooooo`007?ooool0
0ol0003oooooooooo`16ooooo`;o00006_ooool2o`0000?ooooo4ol00002ooooo`;o00001?ooool2
o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool4o`0000gooooo0_l00004
ooooo`So000000?oooooo`000?l000000oooool2o`0000_ooooo0_l00007ooooo`Co0000Moooool0
01cooooo00?o0000ooooooooool0F?ooool2o`0000Sooooo0_l00002oooooaCo00001oooool2o`00
013ooooo0_l0000Booooo`ko00000oooool2o`0000_ooooo0_l00007ooooo`Co0000Moooool001co
oooo00?o0000ooooooooool0Aoooool2o`0000oooooo0_l0000:oooooaWo00001?ooool2o`000004
ooooool0003o0000o`0000cooooo0_l0000;ooooo`;o00000oooool@o`0000?ooooo0_l000000ooo
oooo0000o`00002<ooooo`007?ooool00ol0003oooooooooo`17ooooo`;o00002Oooool2o`0000Co
oooo0_l00005ooooo`;o000000?oooooo`000?l000006Ol00004ooooo`;o000000?oooooo`000?l0
00000_l00004ooooo`;o00004_ooool2o`0000?ooooo2Ol00002ooooo`Go00001_ooool2o`0008co
oooo000Looooo`03o`000?oooooooooo05;ooooo0_l00004ooooo`;o00001Oooool2o`000004oooo
ool0003o0000oooooaCo00003?ooool3o`0000?ooooo0ol00005ooooo`;o00000_ooool2o`0000Oo
oooo0_l00002oooooaCo000000?oooooo`000?l00000S_ooool001cooooo00?o0000ooooooooool0
GOooool3o`0000Gooooo5?l0000<ooooo`;o00001?ooool4o`0000Cooooo1_l00007oooooaSo0000
00?oooooo`000?l000006?ooool2o`0007Cooooo000Looooo`03o`000?oooooooooo05gooooo0ol0
0004ooooo`;o000000?oooooo`000?l000002?l000001?oooooo0000o`000?ooool3o`0000Kooooo
0_l0000:ooooo`;o000000?oooooo`000?l000001_ooool6o`0000?ooooo0_l000000ooooooo0000
o`00000Co`000003ooooool0003o000001[ooooo0_l0001dooooo`007?ooool00ol0003ooooooooo
o`19ooooo`;o00005?ooool2o`0000?ooooo1?l00003ooooo`Go00000_ooool6o`0000Kooooo0_l0
00000ooooooo0000o`000007ooooo`;o000000?oooooo`000?l000002_ooool2o`0000?ooooo5ol0
0002ooooo`;o00005?ooool2o`0007[ooooo000Looooo`03o`000?oooooooooo04Wooooo0_l0000D
ooooo`;o00001Oooool2o`0000Gooooo0ol00002ooooo`Co00001_ooool2o`0000?ooooo0_l0000:
ooooo`;o00001oooool2o`0000Sooooo6Ol00002ooooo`;o000000?oooooo`000?l000003Oooool2
o`0000Cooooo0ol0001cooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o00008Oooool3o`00
00cooooo0_l00003ooooo`?o00004_ooool2o`0000Oooooo0_l000000ooooooo0000o`00000Io`00
0003ooooool0003o000001?ooooo0ol00003ooooo`;o0000K_ooool001cooooo00?o0000oooooooo
ool0B_ooool2o`0001Sooooo0ol00006ooooo`;o00001?ooool2o`0000cooooo0ol0000KoooooaCo
000000?oooooo`000?l000001_l0000Mooooo`;o0000K_ooool001cooooo0_l0001Uooooo`?o0000
3?ooool2o`0000Cooooo0_l0000VoooooaWo0000D?ooool2o`0003gooooo000Looooo`03o`000?oo
oooooooo05gooooo0_l00005ooooo`Co00002oooool2o`0000;ooooo1?l0000Vooooo`;o000000?o
ooooo`000?l000005ol0000=ooooo`;o0000?_ooool2o`0003gooooo000Looooo`03o`000?oooooo
oooo05Gooooo0_l00006ooooo`;o00001Oooool6o`0000gooooo0_l0000Iooooo`;o00003OoooolM
o`0000Kooooo0_l00004ooooo`;o0000??ooool2o`0003oooooo000Looooo`03o`000?oooooooooo
05Gooooo0_l0000;ooooo`Co00000_ooool3o`0001Kooooo0_l0000?ooooo`;o00003OoooolOo`00
00Cooooo0_l0000?ooooo`;o0000<Oooool2o`0003oooooo000Looooo`03o`000?oooooooooo04go
oooo0_l00007ooooo`;o00000_ooool2o`0000Kooooo1Ol00002ooooo`Co00005?ooool2o`0001co
oooo7_l000000ooooooo0000o`000004ooooo`Co00003Oooool4o`0000?ooooo0_l0001[ooooo`00
7?ooool00ol0003oooooooooo`1=ooooo`;o00001oooool2o`0000;ooooo0_l00006ooooo`;o0000
00?oooooo`000?l000000_ooool4o`0001Cooooo0_l0000Loooooaco00000_ooool2o`0000Kooooo
0ol0000?ooooo`;o00000oooool2o`0006_ooooo000Looooo`03o`000?oooooooooo05Oooooo0_l0
0009ooooo`Co00000oooool2o`0000?ooooo1?l0000^oooooa_o00000_ooool2o`0000;ooooo0_l0
0002ooooo`;o00000_ooool2o`0007kooooo000Looooo`03o`000?oooooooooo04kooooo0_l00007
ooooo`;o00000oooool4o`0000?ooooo0ol00008ooooo`Co0000;oooool7o`0000;ooooo4ol00003
ooooo`?o000000?oooooo`000?l000000oooool2o`0001?ooooo0_l0001Yooooo`007?ooool00ol0
003oooooooooo`1>ooooo`;o00003?ooool4o`0000kooooo0_l00009ooooo`;o00006?ooool2o`00
00Oooooo0_l00004oooooa_o00000_ooool3o`0000;ooooo0_l0000Hooooo`;o0000JOooool001co
oooo00?o0000ooooooooool0J?ooool2o`0000oooooo0_l00003ooooo`;o00001oooool3o`0000Wo
oooo0_l00007ooooo`;o00001?oooolGo`0000;ooooo0_l00002ooooo`?o00001_ooool2o`0007oo
oooo000Looooo`03o`000?oooooooooo06Sooooo1Ol0000@ooooo`?o00001oooool3o`0000Wooooo
0_l0000<ooooo`;o000000?oooooo`000?l000004_l00003ooooo`;o00000_ooool2o`0000Oooooo
0_l0001oooooo`007?ooool00ol0003oooooooooo`1Vooooo`;o000000?oooooo`000?l000000_l0
000@ooooo`;o00003Oooool2o`0001?ooooo3_l000000ooooooo0000o`000008o`000003ooooool0
003o000000;ooooo0_l000000ooooooo0000o`000025ooooo`007?ooool00ol0003oooooooooo`1N
ooooo`;o00001_ooool4o`000003ooooool0003o000001oooooo0_l0000?ooooo`;o00001?ooool3
o`000003ooooool0003o000000Ko00000_ooool9o`000003ooooool0003o000000Gooooo0_l00025
ooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o00002?ooool4o`0000Wooooo0_l0000<oooo
o`Co00005_ooool2o`0000Gooooo5?l0002Aooooo`007?ooool00ol0003oooooooooo`1Kooooo`;o
000000?oooooo`000?l000000oooool2o`0000Gooooo0_l00009ooooo`;o00003?ooool4o`0001oo
oooo4Ol00005ooooo`;o00001Oooool2o`0008Cooooo000Looooo`03o`000?oooooooooo05_ooooo
0_l000000ooooooo0000o`000003ooooo`;o00001?ooool2o`0000Cooooo0_l00008ooooo`Co0000
0oooool2o`0002?ooooo4Ol00006ooooo`;o00001Oooool2o`0008Cooooo000Looooo`;o0000JOoo
ool3o`0000Cooooo0_l00002ooooo`co000000?oooooo`000?l000008oooool2o`000005ooooool0
003o0000o`000?ooool02?l00002ooooo`;o0000A_ooool2o`0004Wooooo000Looooo`03o`000?oo
oooooooo06Sooooo0_l00009ooooo`Ko00001?ooool3o`0002Sooooo1_l000000ooooooo0000o`00
0003o`0000;ooooo0_l00016ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0Joooool2
o`0000;ooooo0_l00003ooooo`;o00001?ooool3o`000004ooooool0003o0000ooooo`;o00009Ooo
ool6o`0000Kooooo1?l0002Aooooo`007?ooool00ol0003oooooooooo`1[ooooo`?o000000?ooooo
o`000?l000001Oooool2o`0000;ooooo0ol000001?oooooo0000o`000?ooool2o`0002Gooooo1_l0
0002ooooo`So00002?ooool2o`0008Oooooo000Looooo`03o`000?oooooooooo06cooooo1?l00006
ooooo`Co00001?ooool3o`0002Oooooo1?l00004ooooo`Go00001?ooool2o`0000Gooooo0_l00000
0ooooooo0000o`000024ooooo`007?ooool00ol0003oooooooooo`1[ooooo`;o000000?oooooo`00
0?l000000_l00002ooooo`Ko00001Oooool2o`00023ooooo0_l00005ooooo`;o000000?oooooo`00
0?l000003?ooool2o`0000Sooooo0_l00024ooooo`007?ooool00ol0003oooooooooo`1[ooooo`;o
000000?oooooo`000?l000000_l00002ooooo`?o000000?oooooo`000?l000009oooool3o`0000Oo
oooo0_l00007ooooo`;o0000;_ooool2o`0006?ooooo000Looooo`03o`000?oooooooooo06oooooo
0_l0000aooooo`;o00003?ooool2o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o0000
1_ooool2o`0001gooooo0ol0001Sooooo`007?ooool00ol0003oooooooooo`1Rooooo`;o00004?oo
ool4o`0000gooooo0_l0000Kooooo`;o00002Oooool5o`0000;ooooo0_l000000ooooooo0000o`00
0003ooooo`;o000000?oooooo`000?l000000oooool2o`0001gooooo0_l0001Tooooo`007?ooool0
0ol0003oooooooooo`1Rooooo`;o00001oooool2o`0000Oooooo1?l0000=ooooo`;o00009Oooool4
o`000003ooooool0003o000000Wooooo1Ol00003ooooo`;o00006_ooool2o`0001Cooooo0_l0001A
ooooo`007?ooool00ol0003oooooooooo`1Rooooo`;o00001oooool2o`0000Kooooo0ol0000`oooo
o`;o00001?ooool3o`0000;ooooo0_l00007ooooo`Ko00001?ooool2o`0001Wooooo0ol0000Doooo
o`;o0000DOooool001cooooo00?o0000ooooooooool0Loooool3o`00033ooooo0_l0000Booooo`;o
000000?oooooo`000?l000008?ooool2o`0006Sooooo000Looooo`03o`000?oooooooooo06Gooooo
0_l0000<ooooo`;o0000<Oooool2o`000:7ooooo000Looooo`03o`000?oooooooooo05kooooo0_l0
0005ooooo`;o00003oooool2o`000=7ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Nooooo`?o
00005Oooool2o`0003Gooooo0_l0002Jooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5oooo
o`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0Goooool2
o`0001;ooooo0_l0000hooooo`;o0000:Oooool2o`0006oooooo00000ooooooo410@ooooo`02oooo
o`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo07?ooooo0_l0001Qooooo`Co00004oooool2o`0005[ooooo00000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000H_ooool2
o`0007;ooooo0_l0000Eooooo`;o0000F_ooool00003ooooool0003ooooo00;ooooo00?o0000oooo
ooooool02Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0H_ooool2
o`0006cooooo0_l0001gooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09oooo
o`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`1eooooo`Go0000A?ooool2
o`0000kooooo1?l0001gooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj
^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`1eooooo`Go00001oooool2o`0002oooooo
0_l00002ooooo`;o00001_ooool2o`0000_ooooo0_l000000ooooooo0000o`00000Hooooo`;o0000
Goooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY
00Kooooo00?o0000ooooooooool0POooool2o`0000Kooooo0_l0000Wooooo`;o00000_ooool2o`00
00_ooooo0_l00006ooooo`;o00006oooool2o`0005oooooo000Looooo`03o`000?oooooooooo08Wo
oooo0_l0000aooooo`;o00001Oooool2o`0008Cooooo000Looooo`03o`000?oooooooooo0;Gooooo
1?l00003ooooo`;o00009_ooool2o`0006?ooooo000Looooo`03o`000?oooooooooo0;Gooooo1?l0
000[ooooo`;o0000Hoooool001cooooo00?o0000ooooooooool0OOooool2o`0000;ooooo0_l00036
ooooo`007?ooool00ol0003oooooooooo`1mooooo`;o00000_ooool2o`000<Kooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0POooool2o`0005Wooooo
0_l0001[ooooo`007?ooool00ol0003oooooooooo`1kooooo`?o00000oooool2o`0000Sooooo0_l0
000Rooooo`Co0000:Oooool2o`0006_ooooo000Looooo`03o`000?oooooooooo07_ooooo0ol0000;
ooooo`Co00008_ooool4o`0009Kooooo000Looooo`03o`000?oooooooooo08Wooooo0ol00004oooo
o`;o00006oooool2o`0009[ooooo000Looooo`03o`000?oooooooooo08cooooo0_l00002ooooo`;o
00001?ooool2o`0001Gooooo0_l0000Uooooo`?o0000L_ooool001cooooo0_l00021ooooo`;o0000
2_ooool2o`0000Sooooo0_l0000looooo`?o0000L_ooool001cooooo00?o0000ooooooooool0MOoo
ool2o`0000Wooooo0_l00037ooooo`007?ooool00ol0003oooooooooo`1eooooo`;o0000:_ooool4
o`0000Kooooo0_l0002Looooo`007?ooool00ol0003oooooooooo`1hooooo`;o00008?ooool2o`00
00Gooooo1?l00006ooooo`;o00008Oooool2o`0007Wooooo000Looooo`03o`000?oooooooooo07So
oooo0_l0000Pooooo`;o0000<_ooool2o`0007Wooooo000Looooo`03o`000?oooooooooo09cooooo
1?l0002Yooooo`007?ooool00ol0003oooooooooo`2>ooooo`;o00003?ooool6o`000003ooooool0
003o00000:Cooooo000Looooo`03o`000?oooooooooo07cooooo0_l0000@ooooo`;o00004?ooool2
o`000003ooooool0003o00000:Cooooo000Looooo`03o`000?oooooooooo07cooooo0_l0000Foooo
o`;o00003_ooool2o`000003ooooool0003o000001_ooooo0ol00022ooooo`007?ooool00ol0003o
ooooooooo`2Dooooo`;o000000?oooooo`000?l000000oooool2o`0000Kooooo0_l000001?oooooo
0000o`000?l0000Jooooo`?o0000P_ooool001cooooo00?o0000ooooooooool0Uoooool2o`0000?o
oooo0_l0000:ooooo`;o00001?ooool2o`0009Wooooo000Looooo`03o`000?oooooooooo0:kooooo
0_l0002Iooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0:Sooooo0_l0002Oooooo`007?ooool00ol0003oooooooooo`2Xooooo`;o00000oooool2o`00
00Wooooo1?l0002=ooooo`007?ooool00ol0003oooooooooo`2]ooooo`;o00002Oooool4o`0008go
oooo000Looooo`;o0000S_ooool2o`000;[ooooo000Looooo`03o`000?oooooooooo08gooooo0_l0
002jooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001;ooooo
1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooo
oooo00Gooooo0ol0003ooooood[ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Co
oooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo
000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001;ooooo00?oEEEEofIVI_l00000oooooomD
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00YOooool01?l@413o0000o`00
0?ooool2o`000003oa0@4?oooooooooo01Oooooo0_l000002Ol@413oooooooooooooooooV9RHoa0@
4?l0003o<S8bolc<c003ooooo`Go0000T?ooool00:Kooooo00Go0000ooooooooooooooooo`000009
ooooo`Ko00003?ooool00ol0003oooooooooo`02ooooo`05oa0@4?nj^[[oooooogMgMolb<S800ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A4093ooooo002Vooooo`05o`000?ooooooooooooooool00000
6?ooool5o`0000Oooooo00?o0000ooooooooool00_ooool00onHV9So8B4Qonk^kP2Aooooo`00Y_oo
ool01Ol0003ooooooooooooooooo000000Wooooo1_l00009ooooo`04odA4A?oMgMgoooooo`0000Oo
oooo00?oZJVYoa0@4?ooool01?ooool00onHV9So8B4Qonk^kP2@ooooo`00Y_ooool01Ol0003oQhN7
oooooonYZJWo000001Sooooo00CogMgMoeEEEOoooooo00001_ooool00ol@413o0000okZj^P06oooo
o`03ogMgMomVIVKooooo08oooooo002Uooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHoooooooo
ool05oooool00omgMgOoc<c<o`000007ooooo`03okZj^_lQ8B7ooooo00Kooooo00?o0000oooooooo
ool0S_ooool00<Cooooo00?ok^k^odA4A?l000001?ooool01Ol@413oV9RHoooooonj^[[o000000?o
oooo00Go0000okZj^_ooooooV9RHoa0@402@ooooo`00aOooool00omgMgOo0000ooooo`03ooooo`05
ojVYZOl@413o0000oa0@4?nYZJT00oooool01OnHV9So410@o`000?lQ8B7oc<c<093ooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(438) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.35999 .4044 Mdot
.39214 .39914 Mdot
.5292 .68028 Mdot
.61103 .4335 Mdot
.69168 .65288 Mdot
.52131 .72774 Mdot
.33734 .61032 Mdot
.32997 .60982 Mdot
.50855 .73341 Mdot
.4006 .27189 Mdot
.34702 .63945 Mdot
.53222 .38777 Mdot
.33959 .62457 Mdot
.59397 .40761 Mdot
.44851 .44818 Mdot
.63501 .44976 Mdot
.42156 .39035 Mdot
.66187 .60178 Mdot
.61904 .46144 Mdot
.49988 .68327 Mdot
.70853 .33574 Mdot
.58799 .39555 Mdot
.38035 .35447 Mdot
.59142 .40494 Mdot
.56658 .42622 Mdot
.39604 .38328 Mdot
.3558 .40023 Mdot
.56346 .41282 Mdot
.55512 .3673 Mdot
.3411 .63817 Mdot
.55649 .65736 Mdot
.60407 .18984 Mdot
.64036 .38845 Mdot
.557 .24031 Mdot
.33584 .60514 Mdot
.37418 .57108 Mdot
.50605 .69126 Mdot
.3592 .64915 Mdot
.33459 .60317 Mdot
.35233 .60205 Mdot
.36346 .61373 Mdot
.39606 .3761 Mdot
.36922 .60626 Mdot
.40526 .80354 Mdot
.59562 .42593 Mdot
.44348 .42899 Mdot
.33351 .76286 Mdot
.55431 .39397 Mdot
.41233 .39663 Mdot
.5 .67792 Mdot
.7626 .56364 Mdot
.32686 .65731 Mdot
.37002 .53298 Mdot
.62481 .87132 Mdot
.34966 .62847 Mdot
.57602 .45336 Mdot
.49558 .73327 Mdot
.61286 .39166 Mdot
.61623 .43476 Mdot
.53577 .21508 Mdot
.59589 .37845 Mdot
.69601 .61295 Mdot
.4254 .36029 Mdot
.50812 .7567 Mdot
.51372 .73673 Mdot
.35813 .64888 Mdot
.38512 .34545 Mdot
.32889 .6292 Mdot
.56748 .35888 Mdot
.51644 .67621 Mdot
.55355 .37277 Mdot
.34059 .64098 Mdot
.35748 .36426 Mdot
.59262 .42817 Mdot
.2988 .54307 Mdot
.2801 .68421 Mdot
.55776 .74182 Mdot
.64408 .25934 Mdot
.79408 .61092 Mdot
.54465 .62452 Mdot
.58336 .41388 Mdot
.64713 .81628 Mdot
.48045 .51381 Mdot
.38465 .40388 Mdot
.33047 .35075 Mdot
.28297 .38778 Mdot
.55773 .39858 Mdot
.49412 .61917 Mdot
.62132 .44706 Mdot
.62906 .58439 Mdot
.49649 .72336 Mdot
.37194 .39871 Mdot
.59092 .42425 Mdot
.61235 .36629 Mdot
.33432 .29008 Mdot
.54289 .41075 Mdot
.60438 .43693 Mdot
.31892 .35492 Mdot
.35007 .64245 Mdot
.67399 .38782 Mdot
.73954 .59482 Mdot
.39705 .52331 Mdot
.5667 .44408 Mdot
.50938 .70294 Mdot
.43446 .37573 Mdot
.59545 .44255 Mdot
.32548 .62035 Mdot
.5837 .40737 Mdot
.32895 .59642 Mdot
.41253 .3638 Mdot
.63051 .37924 Mdot
.66856 .61043 Mdot
.6847 .45018 Mdot
.388 .35842 Mdot
.53896 .31107 Mdot
.58713 .3823 Mdot
.61163 .38179 Mdot
.39737 .399 Mdot
.5176 .68183 Mdot
.4787 .7753 Mdot
.36986 .35733 Mdot
.35151 .60129 Mdot
.4169 .39797 Mdot
.54463 .45186 Mdot
.50975 .68359 Mdot
.38587 .53431 Mdot
.39132 .53344 Mdot
.69266 .52012 Mdot
.58599 .42363 Mdot
.66761 .4782 Mdot
.51458 .71139 Mdot
.40262 .38333 Mdot
.33587 .6328 Mdot
.57596 .45836 Mdot
.38256 .36616 Mdot
.322 .61293 Mdot
.70379 .64006 Mdot
.65679 .63236 Mdot
.40857 .37543 Mdot
.48126 .37182 Mdot
.30951 .60246 Mdot
.36429 .60713 Mdot
.75928 .56152 Mdot
.38693 .40447 Mdot
.67907 .61629 Mdot
.3136 .62583 Mdot
.7656 .43403 Mdot
.62473 .42869 Mdot
.71948 .54345 Mdot
.58109 .82885 Mdot
.7623 .56389 Mdot
.5941 .20675 Mdot
.67061 .61232 Mdot
.3187 .61493 Mdot
.55004 .38336 Mdot
.379 .37943 Mdot
.38767 .36899 Mdot
.59533 .3634 Mdot
.58251 .43524 Mdot
.60311 .41837 Mdot
.61432 .4413 Mdot
.38774 .6731 Mdot
.58845 .41992 Mdot
.19521 .52722 Mdot
.37551 .37157 Mdot
.57667 .43921 Mdot
.52482 .69337 Mdot
.65802 .3727 Mdot
.37005 .62841 Mdot
.61596 .43346 Mdot
.57656 .43163 Mdot
.54833 .43849 Mdot
.34527 .59906 Mdot
.27643 .55163 Mdot
.82029 .5754 Mdot
.37673 .585 Mdot
.27039 .66611 Mdot
.52595 .71484 Mdot
.58582 .37336 Mdot
.68193 .63231 Mdot
.66821 .3818 Mdot
.62665 .41049 Mdot
.76841 .56877 Mdot
.57388 .41676 Mdot
.62026 .22637 Mdot
.5441 .35757 Mdot
.2875 .40236 Mdot
.19803 .47112 Mdot
.62672 .41634 Mdot
.44223 .28448 Mdot
.70204 .54191 Mdot
.57113 .75117 Mdot
.34039 .63506 Mdot
.53802 .70153 Mdot
.52599 .68334 Mdot
.35552 .65386 Mdot
.58013 .31328 Mdot
.42037 .26642 Mdot
.54217 .38704 Mdot
.3923 .52743 Mdot
.36506 .33482 Mdot
.67466 .60911 Mdot
.4099 .37887 Mdot
.68626 .79128 Mdot
.56377 .61716 Mdot
.50289 .61743 Mdot
.65513 .60179 Mdot
.4861 .68948 Mdot
.38242 .5291 Mdot
.67905 .62326 Mdot
.61462 .41706 Mdot
.41495 .37281 Mdot
.71814 .54718 Mdot
.66468 .38991 Mdot
.21924 .30677 Mdot
.35364 .39131 Mdot
.65064 .51356 Mdot
.34597 .62882 Mdot
.53351 .74802 Mdot
.55784 .39952 Mdot
.60449 .39686 Mdot
.39037 .34178 Mdot
.55571 .3765 Mdot
.50025 .59158 Mdot
.57672 .42821 Mdot
.50616 .75494 Mdot
.66219 .6671 Mdot
.38021 .60835 Mdot
.66286 .58841 Mdot
.36241 .35949 Mdot
.25041 .67177 Mdot
.5131 .69673 Mdot
.65906 .34176 Mdot
.32691 .63706 Mdot
.69905 .64258 Mdot
.50211 .70015 Mdot
.67128 .60024 Mdot
.63167 .38631 Mdot
.49984 .69447 Mdot
.69016 .60713 Mdot
.46882 .57044 Mdot
.59947 .44191 Mdot
.71869 .4855 Mdot
.31351 .64589 Mdot
.38488 .40931 Mdot
.6262 .3926 Mdot
.3705 .52085 Mdot
.56095 .45878 Mdot
.59204 .52047 Mdot
.37343 .51794 Mdot
.39625 .49901 Mdot
.5178 .59985 Mdot
.71265 .62199 Mdot
.3131 .56432 Mdot
.47697 .59888 Mdot
.42183 .3898 Mdot
.62692 .38222 Mdot
.35085 .47578 Mdot
.31027 .64261 Mdot
.61611 .40993 Mdot
.31824 .44968 Mdot
.3138 .62447 Mdot
.61548 .38877 Mdot
.3623 .61432 Mdot
.38249 .37145 Mdot
.47782 .54248 Mdot
.40058 .41245 Mdot
.61536 .42534 Mdot
.36196 .62272 Mdot
.53532 .6965 Mdot
.3953 .38286 Mdot
.58352 .40167 Mdot
.57446 .40395 Mdot
.39395 .52146 Mdot
.59125 .43565 Mdot
.30425 .40033 Mdot
.5549 .39785 Mdot
.50593 .67363 Mdot
.54306 .38986 Mdot
.74532 .58633 Mdot
.68082 .56897 Mdot
.40332 .35129 Mdot
.37453 .51578 Mdot
.49233 .71772 Mdot
.47258 .55047 Mdot
.70067 .4815 Mdot
.58787 .41403 Mdot
.38428 .51077 Mdot
.64124 .52139 Mdot
.36874 .62987 Mdot
.63987 .3744 Mdot
.45473 .66691 Mdot
.4963 .71788 Mdot
.38822 .52955 Mdot
.66565 .40947 Mdot
.34341 .38314 Mdot
.56263 .44251 Mdot
.50651 .69309 Mdot
.38615 .41181 Mdot
.54697 .42545 Mdot
.30173 .72206 Mdot
.37006 .52122 Mdot
.35969 .63508 Mdot
.31308 .36856 Mdot
.58728 .36772 Mdot
.5334 .68736 Mdot
.38901 .36519 Mdot
.35364 .61942 Mdot
.38222 .3565 Mdot
.72005 .55324 Mdot
.59814 .51369 Mdot
.41012 .60227 Mdot
.69407 .58882 Mdot
.76334 .29567 Mdot
.36895 .57124 Mdot
.67233 .38277 Mdot
.54226 .66877 Mdot
.24553 .35358 Mdot
.50354 .70401 Mdot
.47458 .37822 Mdot
.49592 .72849 Mdot
.55324 .42231 Mdot
.51946 .73135 Mdot
.29768 .29888 Mdot
.56652 .40826 Mdot
.52351 .73885 Mdot
.42237 .65605 Mdot
.56848 .40692 Mdot
.38022 .36486 Mdot
.48215 .15868 Mdot
.60329 .27752 Mdot
.60215 .29027 Mdot
.49951 .74125 Mdot
.47721 .35858 Mdot
.56176 .40817 Mdot
.61187 .46544 Mdot
.38241 .38292 Mdot
.54214 .43151 Mdot
.71026 .60638 Mdot
.67872 .59598 Mdot
.76746 .5007 Mdot
.69451 .28561 Mdot
.5773 .31016 Mdot
.39155 .37704 Mdot
.79157 .62949 Mdot
.29725 .53788 Mdot
.36979 .52316 Mdot
.32682 .61057 Mdot
.28099 .56684 Mdot
.65212 .4264 Mdot
.3743 .31246 Mdot
.49722 .58431 Mdot
.36463 .39636 Mdot
.43004 .58753 Mdot
.35062 .61502 Mdot
.60121 .28664 Mdot
.42157 .24835 Mdot
.60466 .41925 Mdot
.33704 .65374 Mdot
.52818 .40175 Mdot
.48719 .61072 Mdot
.70744 .51034 Mdot
.37471 .74592 Mdot
.61243 .42673 Mdot
.32103 .55001 Mdot
.62659 .40648 Mdot
.69828 .52343 Mdot
.61798 .41133 Mdot
.37607 .36095 Mdot
.58498 .4719 Mdot
.47161 .59409 Mdot
.78206 .35845 Mdot
.56025 .60793 Mdot
.69351 .60213 Mdot
.59572 .40508 Mdot
.60874 .40935 Mdot
.69737 .61132 Mdot
.36747 .39581 Mdot
.62307 .3806 Mdot
.30815 .7579 Mdot
.58737 .42006 Mdot
.33113 .65945 Mdot
.55441 .54359 Mdot
.66391 .2374 Mdot
.56645 .38356 Mdot
.34362 .3775 Mdot
.36625 .61387 Mdot
.31819 .63491 Mdot
.50226 .38386 Mdot
.31606 .64933 Mdot
.552 .37939 Mdot
.55288 .54321 Mdot
.3964 .35341 Mdot
.56123 .34051 Mdot
.36171 .39033 Mdot
.78522 .64183 Mdot
.31202 .62457 Mdot
.38219 .50726 Mdot
.55074 .31402 Mdot
.33515 .61515 Mdot
.62853 .62099 Mdot
.58673 .47141 Mdot
.64533 .37079 Mdot
.32522 .39762 Mdot
.53806 .6966 Mdot
.37902 .51763 Mdot
.35164 .62627 Mdot
.59111 .42118 Mdot
.57622 .44717 Mdot
.32455 .65478 Mdot
.49044 .19123 Mdot
.55864 .65973 Mdot
.61629 .42551 Mdot
.36775 .36828 Mdot
.40129 .38076 Mdot
.60917 .44983 Mdot
.62743 .39923 Mdot
.53293 .72404 Mdot
.38332 .51077 Mdot
.37698 .51453 Mdot
.39694 .52741 Mdot
.51633 .75143 Mdot
.76817 .30977 Mdot
.36494 .60762 Mdot
.62026 .20109 Mdot
.30026 .49287 Mdot
.50571 .41445 Mdot
.52101 .68632 Mdot
.60149 .38769 Mdot
.55939 .43045 Mdot
.35989 .6259 Mdot
.75759 .32857 Mdot
.59818 .46696 Mdot
.36774 .40596 Mdot
.33149 .65721 Mdot
.53212 .40495 Mdot
.29736 .61352 Mdot
.67231 .63496 Mdot
.57385 .30518 Mdot
.31676 .65131 Mdot
.40302 .35769 Mdot
.31729 .65181 Mdot
.60725 .41265 Mdot
.66661 .40811 Mdot
.36284 .39587 Mdot
.66706 .64183 Mdot
.60693 .36718 Mdot
.6182 .39083 Mdot
.55483 .79694 Mdot
.30187 .54313 Mdot
.65762 .58099 Mdot
.55149 .40643 Mdot
.63837 .36085 Mdot
.6602 .63086 Mdot
.60483 .36981 Mdot
.54365 .39245 Mdot
.67558 .47203 Mdot
.3344 .59399 Mdot
.71584 .62961 Mdot
.77683 .35656 Mdot
.35465 .39395 Mdot
.31615 .42041 Mdot
.39326 .5291 Mdot
.36769 .65139 Mdot
.47155 .53428 Mdot
.38564 .52389 Mdot
.30264 .47247 Mdot
.21379 .63955 Mdot
.38129 .51679 Mdot
.51866 .75648 Mdot
.41499 .31298 Mdot
.54828 .37731 Mdot
.62252 .41448 Mdot
.71172 .61946 Mdot
.40117 .40129 Mdot
.19846 .51817 Mdot
.38301 .60914 Mdot
.5888 .38773 Mdot
.35447 .40304 Mdot
.28351 .39323 Mdot
.38839 .52718 Mdot
.67576 .63037 Mdot
.68043 .65017 Mdot
.626 .39912 Mdot
.67666 .51029 Mdot
.39442 .37843 Mdot
.58361 .40165 Mdot
.60648 .37606 Mdot
.48766 .7109 Mdot
.41531 .37589 Mdot
.52383 .69528 Mdot
.38031 .50167 Mdot
.2298 .34934 Mdot
.44824 .8429 Mdot
.31314 .64313 Mdot
.43299 .52004 Mdot
.38053 .61401 Mdot
.33464 .73318 Mdot
.38218 .51101 Mdot
.58532 .39885 Mdot
.37335 .35259 Mdot
.58312 .40523 Mdot
.58866 .42188 Mdot
.6044 .42771 Mdot
.5786 .30946 Mdot
.78285 .62617 Mdot
.6962 .63621 Mdot
.57017 .36865 Mdot
.50146 .74606 Mdot
.30226 .42122 Mdot
.32387 .26861 Mdot
.60099 .40368 Mdot
.61261 .3827 Mdot
.37613 .34611 Mdot
.63543 .39666 Mdot
.32924 .61312 Mdot
.36913 .40263 Mdot
.57401 .44902 Mdot
.74492 .60194 Mdot
.62192 .3809 Mdot
.42812 .53943 Mdot
.30557 .64189 Mdot
.64267 .46178 Mdot
.61389 .35486 Mdot
.3815 .51043 Mdot
.37943 .51865 Mdot
.37463 .50145 Mdot
.34255 .65568 Mdot
.48843 .71169 Mdot
.51968 .76348 Mdot
.60998 .35621 Mdot
.55082 .38908 Mdot
.6631 .39432 Mdot
.49274 .67379 Mdot
.47049 .61286 Mdot
.46549 .39327 Mdot
.52967 .37943 Mdot
.524 .74599 Mdot
.3166 .35933 Mdot
.67824 .29291 Mdot
.37526 .4058 Mdot
.53678 .66772 Mdot
.3212 .62878 Mdot
.67279 .6042 Mdot
.75894 .53117 Mdot
.37149 .35841 Mdot
.35801 .35777 Mdot
.52883 .72293 Mdot
.52873 .52697 Mdot
.69359 .83747 Mdot
.50939 .70933 Mdot
.50239 .61183 Mdot
.38602 .38154 Mdot
.63836 .40623 Mdot
.63122 .52605 Mdot
.51696 .51565 Mdot
.51703 .74146 Mdot
.57517 .40448 Mdot
.61713 .64619 Mdot
.53269 .7248 Mdot
.65317 .3961 Mdot
.50031 .74265 Mdot
.35292 .64377 Mdot
.51622 .70696 Mdot
.3671 .41641 Mdot
.58268 .41836 Mdot
.64374 .86319 Mdot
.47278 .50986 Mdot
.57975 .39378 Mdot
.31828 .6537 Mdot
.40485 .67775 Mdot
.61027 .4164 Mdot
.69967 .59947 Mdot
.50373 .74956 Mdot
.35521 .74162 Mdot
.54749 .41513 Mdot
.52311 .73252 Mdot
.35234 .41112 Mdot
.51527 .66194 Mdot
.73294 .58928 Mdot
.37764 .5164 Mdot
.37953 .37326 Mdot
.35342 .55485 Mdot
.3599 .60645 Mdot
.60086 .46016 Mdot
.60029 .37432 Mdot
.37085 .37301 Mdot
.46761 .55812 Mdot
.51251 .37308 Mdot
.58454 .41484 Mdot
.53174 .71069 Mdot
.48099 .71057 Mdot
.45166 .44203 Mdot
.51088 .69572 Mdot
.63606 .35918 Mdot
.37339 .36768 Mdot
.56831 .44849 Mdot
.39215 .36304 Mdot
.62535 .37995 Mdot
.28604 .66072 Mdot
.38398 .40684 Mdot
.67677 .36548 Mdot
.58334 .42237 Mdot
.35337 .43351 Mdot
.58389 .36858 Mdot
.60948 .43021 Mdot
.48262 .72376 Mdot
.69495 .62441 Mdot
.64158 .38133 Mdot
.28521 .68797 Mdot
.66358 .63135 Mdot
.54283 .18934 Mdot
.50985 .68387 Mdot
.6923 .64892 Mdot
.75628 .48699 Mdot
.37449 .51652 Mdot
.70166 .61986 Mdot
.40184 .49249 Mdot
.31939 .64858 Mdot
.40552 .41797 Mdot
.57082 .40906 Mdot
.24505 .33535 Mdot
.55347 .65456 Mdot
.39357 .51618 Mdot
.62142 .3861 Mdot
.60546 .38994 Mdot
.35346 .40068 Mdot
.67464 .79915 Mdot
.48932 .74676 Mdot
.60423 .44012 Mdot
.36419 .36046 Mdot
.61952 .8247 Mdot
.52353 .73996 Mdot
.69405 .63988 Mdot
.31383 .61274 Mdot
.38403 .33485 Mdot
.38035 .50735 Mdot
.31348 .62162 Mdot
.56161 .7262 Mdot
.77195 .57178 Mdot
.55388 .429 Mdot
.52282 .68945 Mdot
.76329 .56481 Mdot
.55784 .34182 Mdot
.36751 .64382 Mdot
.2767 .63564 Mdot
.37608 .39975 Mdot
.3258 .65542 Mdot
.70947 .6117 Mdot
.42018 .38207 Mdot
.36293 .39309 Mdot
.32474 .61588 Mdot
.19846 .43918 Mdot
.63758 .52158 Mdot
.3233 .66339 Mdot
.59081 .52328 Mdot
.7625 .56554 Mdot
.39064 .5051 Mdot
.67415 .62806 Mdot
.75676 .6604 Mdot
.39653 .37828 Mdot
.28063 .56485 Mdot
.76405 .56429 Mdot
.60441 .43707 Mdot
.68843 .60554 Mdot
.31013 .42425 Mdot
.38002 .64622 Mdot
.31936 .61645 Mdot
.50732 .78316 Mdot
.68201 .60185 Mdot
.6317 .40262 Mdot
.69105 .24915 Mdot
.56739 .3921 Mdot
.31165 .63095 Mdot
.49871 .58756 Mdot
.41307 .37122 Mdot
.37145 .62471 Mdot
.50072 .59223 Mdot
.55548 .42308 Mdot
.58244 .38259 Mdot
.70677 .6706 Mdot
.41698 .38728 Mdot
.38564 .50059 Mdot
.57907 .40649 Mdot
.61512 .39227 Mdot
.6034 .45739 Mdot
.73409 .33726 Mdot
.69586 .39961 Mdot
.59106 .44857 Mdot
.54333 .73525 Mdot
.6691 .38909 Mdot
.61586 .43832 Mdot
.34359 .38772 Mdot
.75949 .61561 Mdot
.38129 .50037 Mdot
.62235 .41225 Mdot
.61693 .42419 Mdot
.33843 .60274 Mdot
.63857 .52188 Mdot
.51117 .51273 Mdot
.49325 .67963 Mdot
.51793 .77904 Mdot
.55329 .36152 Mdot
.37416 .37843 Mdot
.71565 .6139 Mdot
.596 .3412 Mdot
.36312 .40228 Mdot
.58813 .35738 Mdot
.4938 .73965 Mdot
.38396 .51449 Mdot
.55296 .34106 Mdot
.69298 .6139 Mdot
.32096 .59545 Mdot
.57774 .20184 Mdot
.5353 .70055 Mdot
.56001 .4161 Mdot
.51339 .76645 Mdot
.50624 .72159 Mdot
.39522 .51802 Mdot
.66896 .41745 Mdot
.38579 .37182 Mdot
.40454 .36061 Mdot
.77466 .61346 Mdot
.51548 .753 Mdot
.57764 .78452 Mdot
.34685 .6481 Mdot
.57496 .36692 Mdot
.37098 .48188 Mdot
.40765 .36472 Mdot
.69517 .51987 Mdot
.68615 .65012 Mdot
.31834 .61829 Mdot
.40081 .52628 Mdot
.38192 .40777 Mdot
.40623 .36651 Mdot
.59182 .4243 Mdot
.59467 .39608 Mdot
.56472 .74351 Mdot
.70651 .54068 Mdot
.36101 .61312 Mdot
.68285 .63986 Mdot
.51091 .67432 Mdot
.54844 .40539 Mdot
.38209 .40199 Mdot
.67282 .24402 Mdot
.58726 .36815 Mdot
.50084 .74526 Mdot
.39044 .39753 Mdot
.7017 .636 Mdot
.70869 .62107 Mdot
.60707 .43357 Mdot
.63407 .23762 Mdot
.33255 .61714 Mdot
.37901 .36343 Mdot
.32143 .37257 Mdot
.56265 .37351 Mdot
.59746 .40171 Mdot
.52263 .42271 Mdot
.37335 .62903 Mdot
.55134 .34646 Mdot
.65779 .61571 Mdot
.40462 .37735 Mdot
.57962 .40077 Mdot
.69695 .61348 Mdot
.37759 .31269 Mdot
.38702 .52003 Mdot
.52692 .73563 Mdot
.69464 .59843 Mdot
.68515 .62038 Mdot
.66969 .63874 Mdot
.28265 .56639 Mdot
.43805 .38898 Mdot
.83197 .4877 Mdot
.57739 .41139 Mdot
.76226 .56588 Mdot
.6157 .45315 Mdot
.36174 .63967 Mdot
.5411 .70882 Mdot
.59684 .42346 Mdot
.57693 .41107 Mdot
.60387 .22245 Mdot
.63139 .45401 Mdot
.62763 .45832 Mdot
.4107 .36372 Mdot
.32009 .39672 Mdot
.53152 .68749 Mdot
.56038 .82928 Mdot
.50504 .14182 Mdot
.54194 .38523 Mdot
.53277 .52949 Mdot
.37377 .40365 Mdot
.32909 .60452 Mdot
.60254 .52478 Mdot
.37231 .56088 Mdot
.40588 .39108 Mdot
.55174 .41817 Mdot
.57685 .20599 Mdot
.66497 .60901 Mdot
.6039 .4162 Mdot
.33227 .63351 Mdot
.60356 .41728 Mdot
.35088 .65239 Mdot
.44182 .41733 Mdot
.49656 .51137 Mdot
.57134 .41361 Mdot
.54277 .40723 Mdot
.65914 .48109 Mdot
.59913 .4005 Mdot
.38443 .73061 Mdot
.3848 .39347 Mdot
.66986 .35302 Mdot
.58461 .45966 Mdot
.58744 .26435 Mdot
.60959 .375 Mdot
.45855 .52483 Mdot
.5887 .37603 Mdot
.75969 .359 Mdot
.63047 .41266 Mdot
.58545 .37421 Mdot
.35622 .61687 Mdot
.34736 .60113 Mdot
.34117 .3993 Mdot
.3913 .49946 Mdot
.29131 .40739 Mdot
.61663 .38693 Mdot
.48062 .69832 Mdot
.49972 .46887 Mdot
.6899 .62407 Mdot
.40493 .38014 Mdot
.35781 .84997 Mdot
.36811 .61931 Mdot
.51921 .75527 Mdot
.50285 .62252 Mdot
.54711 .73402 Mdot
.5472 .67594 Mdot
.33249 .41642 Mdot
.67284 .62857 Mdot
.62508 .38548 Mdot
.56874 .24385 Mdot
.31536 .54389 Mdot
.56024 .37605 Mdot
.48054 .74414 Mdot
.54573 .48517 Mdot
.77912 .60337 Mdot
.68132 .59358 Mdot
.67189 .61653 Mdot
.35183 .62044 Mdot
.52828 .68068 Mdot
.5263 .38562 Mdot
.69288 .64864 Mdot
.5397 .70756 Mdot
.38596 .53872 Mdot
.7301 .66291 Mdot
.39371 .37519 Mdot
.48211 .35876 Mdot
.41108 .45692 Mdot
.36645 .61718 Mdot
.2827 .68652 Mdot
.4118 .42445 Mdot
.42463 .39105 Mdot
.39662 .50346 Mdot
.51902 .74538 Mdot
.40443 .41984 Mdot
.58508 .42069 Mdot
.66448 .3897 Mdot
.62637 .3988 Mdot
.71148 .62397 Mdot
.61622 .38042 Mdot
.53468 .72528 Mdot
.34381 .60759 Mdot
.49478 .71955 Mdot
.33933 .6102 Mdot
.54439 .16854 Mdot
.61969 .42998 Mdot
.59471 .40153 Mdot
.54885 .54113 Mdot
.40737 .37035 Mdot
.54841 .24155 Mdot
.50307 .74705 Mdot
.4943 .72963 Mdot
.57102 .45 Mdot
.40498 .34989 Mdot
.63372 .60714 Mdot
.59261 .53038 Mdot
.59332 .37582 Mdot
.38349 .3938 Mdot
.57243 .45165 Mdot
.33506 .72204 Mdot
.47091 .49165 Mdot
.38491 .35608 Mdot
.78319 .35891 Mdot
.59168 .43141 Mdot
.66611 .43605 Mdot
.64513 .46982 Mdot
.72969 .34889 Mdot
.64217 .39978 Mdot
.35536 .39331 Mdot
.61269 .43903 Mdot
.37445 .38431 Mdot
.50314 .71488 Mdot
.36984 .6115 Mdot
.37776 .38373 Mdot
.56838 .39955 Mdot
.5139 .14425 Mdot
.34322 .6065 Mdot
.59801 .41602 Mdot
.35131 .63407 Mdot
.40653 .41435 Mdot
.4122 .38908 Mdot
.40482 .51794 Mdot
.50305 .6142 Mdot
.32964 .61426 Mdot
.55144 .38733 Mdot
.28583 .5484 Mdot
.56662 .4469 Mdot
.51501 .77852 Mdot
.55005 .43832 Mdot
.56219 .35875 Mdot
.76383 .29113 Mdot
.46669 .54869 Mdot
.48049 .85489 Mdot
.37181 .67029 Mdot
.27801 .54767 Mdot
.32964 .37496 Mdot
.68133 .59373 Mdot
.43832 .5427 Mdot
.37292 .52303 Mdot
.5459 .73034 Mdot
.59378 .42296 Mdot
.30488 .32513 Mdot
.32635 .66222 Mdot
.69584 .62954 Mdot
.57347 .41647 Mdot
.5484 .69623 Mdot
.4232 .4672 Mdot
.31786 .61703 Mdot
.39616 .37508 Mdot
.41062 .38238 Mdot
.79849 .60122 Mdot
.58022 .39694 Mdot
.5904 .39588 Mdot
.34075 .60515 Mdot
.52092 .3896 Mdot
.6715 .63856 Mdot
.42641 .65323 Mdot
.33361 .63544 Mdot
.47482 .49921 Mdot
.41471 .36911 Mdot
.60375 .3889 Mdot
.5566 .54361 Mdot
.24603 .54522 Mdot
.36158 .27079 Mdot
.6792 .60938 Mdot
.68673 .49933 Mdot
.35482 .39262 Mdot
.33803 .63341 Mdot
.76055 .4963 Mdot
.58895 .4688 Mdot
.60789 .39016 Mdot
.71922 .43221 Mdot
.59233 .52893 Mdot
.49819 .61669 Mdot
.52661 .4342 Mdot
.64311 .53363 Mdot
.56948 .4487 Mdot
.57518 .44678 Mdot
.56819 .35668 Mdot
.55901 .44993 Mdot
.37909 .39308 Mdot
.5945 .27766 Mdot
.5208 .72029 Mdot
.40292 .28746 Mdot
.52934 .78516 Mdot
.56228 .40546 Mdot
.5542 .42219 Mdot
.47866 .30361 Mdot
.55445 .51318 Mdot
.38961 .38787 Mdot
.32259 .38026 Mdot
.36101 .60526 Mdot
.62304 .45976 Mdot
.51069 .75261 Mdot
.62263 .47956 Mdot
.50951 .73023 Mdot
.38076 .39488 Mdot
.49211 .69657 Mdot
.29903 .63474 Mdot
.52196 .68944 Mdot
.53027 .74424 Mdot
.31654 .61433 Mdot
.41319 .39736 Mdot
.58835 .37147 Mdot
.31085 .62053 Mdot
.63181 .61737 Mdot
.71127 .62367 Mdot
.40478 .52074 Mdot
.63529 .41742 Mdot
.64685 .44321 Mdot
.29947 .72415 Mdot
.49832 .69367 Mdot
.5073 .50357 Mdot
.3859 .40665 Mdot
.71523 .61627 Mdot
.37612 .39111 Mdot
.81097 .54356 Mdot
.68621 .61239 Mdot
.40583 .51396 Mdot
.73937 .50117 Mdot
.37904 .59629 Mdot
.5428 .42706 Mdot
.31917 .38623 Mdot
.50571 .72815 Mdot
.33181 .6588 Mdot
.309 .4254 Mdot
.59309 .43881 Mdot
.36942 .54269 Mdot
.41952 .40697 Mdot
.37501 .51716 Mdot
.33448 .63207 Mdot
.41486 .49805 Mdot
.58157 .39063 Mdot
.37917 .59764 Mdot
.54253 .41254 Mdot
.51276 .33763 Mdot
.5463 .76775 Mdot
.34791 .32423 Mdot
.55578 .4298 Mdot
.52501 .74004 Mdot
.56032 .43826 Mdot
.44344 .33567 Mdot
.72961 .52573 Mdot
.5499 .36322 Mdot
.57118 .50342 Mdot
.3215 .74438 Mdot
.3799 .4011 Mdot
.62546 .35418 Mdot
.39298 .50955 Mdot
.56088 .4243 Mdot
.29352 .22511 Mdot
.69932 .61843 Mdot
.64964 .60564 Mdot
.56963 .40311 Mdot
.582 .40785 Mdot
.61484 .23023 Mdot
.3929 .43975 Mdot
.40217 .52304 Mdot
.61154 .39649 Mdot
.72379 .40015 Mdot
.3556 .61989 Mdot
.54864 .43031 Mdot
.62181 .4206 Mdot
.57213 .76305 Mdot
.35634 .62521 Mdot
.51083 .6862 Mdot
.37399 .51802 Mdot
.48414 .69836 Mdot
.69415 .65552 Mdot
.66462 .51014 Mdot
.70165 .50102 Mdot
.45977 .47517 Mdot
.69707 .60038 Mdot
.5615 .3991 Mdot
.34759 .32822 Mdot
.57583 .39116 Mdot
.67361 .62003 Mdot
.34136 .63824 Mdot
.38211 .39045 Mdot
.48113 .37011 Mdot
.39442 .52425 Mdot
.56425 .3786 Mdot
.69278 .59165 Mdot
.3806 .37865 Mdot
.21835 .55674 Mdot
.39636 .40239 Mdot
.34089 .61217 Mdot
.3556 .65355 Mdot
.6891 .61862 Mdot
.37626 .39256 Mdot
.48482 .69994 Mdot
.34771 .68039 Mdot
.53727 .40507 Mdot
.29853 .6353 Mdot
.38607 .42737 Mdot
.34923 .39188 Mdot
.39007 .34882 Mdot
.58239 .45729 Mdot
.56266 .5265 Mdot
.56176 .46807 Mdot
.34301 .60588 Mdot
.54914 .70878 Mdot
.71785 .54096 Mdot
.59374 .24307 Mdot
.48488 .51075 Mdot
.64522 .38724 Mdot
.61775 .38199 Mdot
.62574 .39782 Mdot
.59484 .45056 Mdot
.4252 .64366 Mdot
.61964 .42983 Mdot
.36202 .61993 Mdot
.51251 .72445 Mdot
.59805 .37817 Mdot
.3889 .50881 Mdot
.47308 .61124 Mdot
.71819 .62101 Mdot
.57194 .30341 Mdot
.33487 .42847 Mdot
.38098 .38066 Mdot
.5109 .69298 Mdot
.49022 .69736 Mdot
.7038 .64 Mdot
.30995 .6263 Mdot
.40401 .39875 Mdot
.76024 .36497 Mdot
.66135 .62159 Mdot
.62225 .41139 Mdot
.5516 .54242 Mdot
.72332 .32423 Mdot
.5882 .36116 Mdot
.60781 .42697 Mdot
.3865 .49871 Mdot
.52573 .75252 Mdot
.27543 .28848 Mdot
.19586 .46012 Mdot
.69386 .62247 Mdot
.686 .64344 Mdot
.3769 .34851 Mdot
.57662 .36535 Mdot
.33038 .61918 Mdot
.64891 .52 Mdot
.30388 .71557 Mdot
.2884 .38437 Mdot
.33744 .73376 Mdot
.62009 .37917 Mdot
.54072 .29626 Mdot
.5485 .43772 Mdot
.43487 .37693 Mdot
.39597 .34775 Mdot
.39115 .38164 Mdot
.353 .6154 Mdot
.77426 .57332 Mdot
.36305 .62295 Mdot
.30849 .39265 Mdot
.35445 .37895 Mdot
.47893 .56857 Mdot
.49488 .7331 Mdot
.62723 .45144 Mdot
.67204 .62629 Mdot
.6507 .56556 Mdot
.63071 .35828 Mdot
.68076 .50327 Mdot
.5206 .68627 Mdot
.39915 .40947 Mdot
.61906 .45344 Mdot
.29524 .41656 Mdot
.52451 .527 Mdot
.34048 .75931 Mdot
.31208 .32439 Mdot
.69503 .61034 Mdot
.4184 .27504 Mdot
.66499 .62862 Mdot
.31709 .61991 Mdot
.59487 .43269 Mdot
.58577 .36585 Mdot
.61171 .42962 Mdot
.57084 .45586 Mdot
.35148 .62798 Mdot
.53556 .39644 Mdot
.74605 .58672 Mdot
.38177 .53824 Mdot
.45839 .60562 Mdot
.70699 .62062 Mdot
.35149 .64687 Mdot
.50858 .72248 Mdot
.39822 .50362 Mdot
.69299 .58788 Mdot
.60653 .45356 Mdot
.57066 .39535 Mdot
.38812 .5361 Mdot
.53982 .34781 Mdot
.64999 .42765 Mdot
.52298 .72619 Mdot
.48317 .60672 Mdot
.71127 .6376 Mdot
.66937 .61127 Mdot
.32948 .65468 Mdot
.37581 .39127 Mdot
.70456 .64203 Mdot
.53268 .68162 Mdot
.54863 .42636 Mdot
.5419 .40082 Mdot
.37821 .42599 Mdot
.7665 .56702 Mdot
.71836 .6192 Mdot
.55417 .34527 Mdot
.40052 .36889 Mdot
.42066 .40569 Mdot
.61126 .39818 Mdot
.54152 .36703 Mdot
.3702 .34701 Mdot
.6988 .64122 Mdot
.33688 .6528 Mdot
.4958 .55399 Mdot
.36378 .63008 Mdot
.3911 .36666 Mdot
.66609 .38689 Mdot
.41755 .3897 Mdot
.59043 .43831 Mdot
.50335 .87682 Mdot
.62663 .41866 Mdot
.6683 .32684 Mdot
.59311 .64163 Mdot
.50239 .74423 Mdot
.51031 .74631 Mdot
.3848 .51249 Mdot
.36457 .40236 Mdot
.62077 .34872 Mdot
.67348 .63237 Mdot
.27886 .5475 Mdot
.40314 .43233 Mdot
.52803 .74473 Mdot
.51392 .75533 Mdot
.34359 .63703 Mdot
.61239 .37659 Mdot
.60122 .38613 Mdot
.51991 .68855 Mdot
.41445 .6708 Mdot
.3695 .38631 Mdot
.59028 .39627 Mdot
.59543 .45437 Mdot
.5185 .72085 Mdot
.34667 .6663 Mdot
.40882 .42262 Mdot
.58427 .45772 Mdot
.71977 .52462 Mdot
.36037 .64464 Mdot
.55688 .4055 Mdot
.5508 .44313 Mdot
.68584 .62475 Mdot
.69869 .48617 Mdot
.75919 .56178 Mdot
.35461 .59903 Mdot
.37859 .51071 Mdot
.59963 .36455 Mdot
.5027 .74267 Mdot
.63125 .42934 Mdot
.15662 .53755 Mdot
.37709 .53739 Mdot
.58411 .38971 Mdot
.56048 .35468 Mdot
.39025 .36146 Mdot
.58363 .39888 Mdot
.28544 .65812 Mdot
.52799 .70437 Mdot
.58403 .38869 Mdot
.63379 .23981 Mdot
.34173 .63701 Mdot
.63114 .35924 Mdot
.67752 .60182 Mdot
.49843 .60902 Mdot
.48895 .1597 Mdot
.49805 .67112 Mdot
.70521 .61325 Mdot
.61239 .37824 Mdot
.48788 .68545 Mdot
.31618 .61022 Mdot
.69497 .38225 Mdot
.56015 .39785 Mdot
.36481 .62561 Mdot
.33959 .60765 Mdot
.6929 .6184 Mdot
.44614 .87091 Mdot
.55509 .36003 Mdot
.6022 .41104 Mdot
.26373 .71572 Mdot
.36173 .35023 Mdot
.59949 .41794 Mdot
.60408 .37438 Mdot
.31392 .64638 Mdot
.80013 .5211 Mdot
.68582 .49961 Mdot
.42203 .65483 Mdot
.35585 .64868 Mdot
.48162 .73918 Mdot
.53096 .70113 Mdot
.70322 .61181 Mdot
.39178 .39793 Mdot
.71412 .62273 Mdot
.51953 .70981 Mdot
.61061 .42828 Mdot
.32275 .64396 Mdot
.42988 .20964 Mdot
.30778 .64709 Mdot
.53586 .68097 Mdot
.43299 .38943 Mdot
.30928 .29894 Mdot
.16299 .57874 Mdot
.43312 .44062 Mdot
.37764 .62169 Mdot
.68979 .62427 Mdot
.1933 .49426 Mdot
.59688 .37727 Mdot
.4854 .33962 Mdot
.6033 .41447 Mdot
.33357 .31381 Mdot
.54076 .70904 Mdot
.39329 .53461 Mdot
.59316 .43908 Mdot
.68787 .49645 Mdot
.31863 .61336 Mdot
.32337 .62662 Mdot
.61023 .43951 Mdot
.33857 .61244 Mdot
.5957 .38659 Mdot
.51332 .72043 Mdot
.46781 .86396 Mdot
.58161 .37799 Mdot
.67683 .40082 Mdot
.37722 .60519 Mdot
.40298 .52574 Mdot
.49859 .75989 Mdot
.5775 .27838 Mdot
.28069 .39855 Mdot
.33329 .61895 Mdot
.57979 .30754 Mdot
.50068 .69527 Mdot
.39645 .49908 Mdot
.47909 .72204 Mdot
.6065 .40482 Mdot
.61678 .37621 Mdot
.59459 .44845 Mdot
.60997 .3783 Mdot
.46458 .33448 Mdot
.6455 .43214 Mdot
.46025 .2431 Mdot
.57728 .41076 Mdot
.6589 .32053 Mdot
.36101 .62638 Mdot
.66413 .44223 Mdot
.5189 .59187 Mdot
.63096 .39233 Mdot
.3253 .40123 Mdot
.35166 .6459 Mdot
.35361 .49379 Mdot
.35379 .6263 Mdot
.49534 .723 Mdot
.32518 .61098 Mdot
.5912 .43345 Mdot
.40045 .38127 Mdot
.51342 .69894 Mdot
.46885 .39989 Mdot
.5477 .71404 Mdot
.57985 .39373 Mdot
.36969 .57756 Mdot
.48911 .72643 Mdot
.6346 .45736 Mdot
.4016 .38491 Mdot
.73515 .40048 Mdot
.41933 .35024 Mdot
.58664 .40537 Mdot
.59042 .41164 Mdot
.39608 .53123 Mdot
.319 .61466 Mdot
.41264 .3612 Mdot
.58167 .75312 Mdot
.70755 .59666 Mdot
.39155 .39211 Mdot
.65396 .46353 Mdot
.53416 .5317 Mdot
.38729 .35806 Mdot
.72652 .37157 Mdot
.31188 .62858 Mdot
.35564 .36821 Mdot
.55453 .4555 Mdot
.41357 .2923 Mdot
.66551 .61519 Mdot
.48222 .70937 Mdot
.62903 .53689 Mdot
.53039 .70222 Mdot
.31121 .59933 Mdot
.50347 .75362 Mdot
.35886 .62248 Mdot
.51797 .48204 Mdot
.4994 .58969 Mdot
.31712 .65637 Mdot
.3727 .59833 Mdot
.5259 .71911 Mdot
.60569 .44299 Mdot
.47218 .59605 Mdot
.61744 .3462 Mdot
.66006 .38719 Mdot
.36669 .62697 Mdot
.35183 .38403 Mdot
.42013 .38905 Mdot
.65764 .34348 Mdot
.41118 .37393 Mdot
.50759 .70562 Mdot
.45518 .45781 Mdot
.54896 .31491 Mdot
.33704 .64 Mdot
.49944 .62313 Mdot
.55767 .43192 Mdot
.52752 .73176 Mdot
.50414 .70757 Mdot
.34237 .60868 Mdot
.38653 .28813 Mdot
.6484 .37484 Mdot
.34204 .37305 Mdot
.36165 .36317 Mdot
.38422 .35804 Mdot
.40151 .34801 Mdot
.77712 .5722 Mdot
.33179 .65867 Mdot
.36098 .39899 Mdot
.57083 .4542 Mdot
.59453 .36678 Mdot
.37814 .52601 Mdot
.70278 .63666 Mdot
.58735 .46744 Mdot
.61877 .34762 Mdot
.61022 .39672 Mdot
.50008 .74262 Mdot
.61104 .50072 Mdot
.38048 .53689 Mdot
.51641 .75356 Mdot
.51326 .75226 Mdot
.38085 .51048 Mdot
.52599 .48512 Mdot
.28828 .28602 Mdot
.60578 .43861 Mdot
.33389 .4203 Mdot
.51051 .74408 Mdot
.64406 .55944 Mdot
.63186 .31456 Mdot
.55224 .3806 Mdot
.45054 .63357 Mdot
.50945 .71515 Mdot
.33254 .36904 Mdot
.603 .40308 Mdot
.39662 .50614 Mdot
.67022 .60706 Mdot
.66217 .46769 Mdot
.38766 .49866 Mdot
.37456 .39552 Mdot
.54275 .79397 Mdot
.35389 .40205 Mdot
.48578 .71838 Mdot
.62946 .35637 Mdot
.6709 .85079 Mdot
.5036 .72647 Mdot
.27323 .55835 Mdot
.49938 .59174 Mdot
.58059 .38138 Mdot
.52081 .69469 Mdot
.36355 .42318 Mdot
.36204 .64277 Mdot
.56326 .5349 Mdot
.38317 .4018 Mdot
.39885 .50503 Mdot
.37964 .52296 Mdot
.52046 .72122 Mdot
.36667 .36267 Mdot
.53993 .41463 Mdot
.40952 .38486 Mdot
.3222 .63863 Mdot
.57643 .43229 Mdot
.29045 .40645 Mdot
.66967 .41484 Mdot
.4082 .38079 Mdot
.54496 .69282 Mdot
.66466 .63879 Mdot
.56601 .40426 Mdot
.34543 .47328 Mdot
.61023 .37616 Mdot
.34871 .63586 Mdot
.59624 .60072 Mdot
.43438 .2115 Mdot
.61831 .41339 Mdot
.55692 .42906 Mdot
.30177 .62697 Mdot
.61719 .4132 Mdot
.55983 .36339 Mdot
.41401 .49415 Mdot
.38986 .35911 Mdot
.60192 .37985 Mdot
.53615 .70668 Mdot
.49188 .18237 Mdot
.5967 .43102 Mdot
.28642 .66764 Mdot
.72882 .40514 Mdot
.57652 .57878 Mdot
.64992 .36596 Mdot
.69377 .52081 Mdot
.59391 .41144 Mdot
.55598 .3759 Mdot
.60733 .43906 Mdot
.5335 .30142 Mdot
.5235 .71283 Mdot
.53263 .73678 Mdot
.67609 .59892 Mdot
.72496 .41317 Mdot
.68426 .60707 Mdot
.30236 .63155 Mdot
.50241 .6204 Mdot
.39028 .53305 Mdot
.37505 .38937 Mdot
.59882 .43033 Mdot
.54627 .71224 Mdot
.60383 .39168 Mdot
.5594 .42119 Mdot
.51169 .70727 Mdot
.50464 .71226 Mdot
.4987 .66925 Mdot
.66328 .61081 Mdot
.38614 .38511 Mdot
.60303 .4357 Mdot
.66305 .63041 Mdot
.59925 .45491 Mdot
.49522 .53697 Mdot
.38816 .38531 Mdot
.40883 .37929 Mdot
.41355 .40631 Mdot
.57154 .38183 Mdot
.58719 .43513 Mdot
.36322 .62315 Mdot
.37899 .42599 Mdot
.32567 .61717 Mdot
.5224 .69523 Mdot
.53034 .72724 Mdot
.60673 .40578 Mdot
.53102 .37262 Mdot
.70635 .62609 Mdot
.4918 .70458 Mdot
.37136 .51532 Mdot
.67738 .59961 Mdot
.62689 .39489 Mdot
.52708 .69807 Mdot
.70884 .60482 Mdot
.34431 .27663 Mdot
.26338 .38164 Mdot
.66412 .60511 Mdot
.60958 .44048 Mdot
.59509 .23713 Mdot
.7277 .53179 Mdot
.7139 .6002 Mdot
.35224 .63691 Mdot
.59486 .37122 Mdot
.39006 .67198 Mdot
.69405 .6503 Mdot
.75683 .557 Mdot
.51517 .70444 Mdot
.67159 .38329 Mdot
.63336 .48706 Mdot
.53787 .32265 Mdot
.6725 .64655 Mdot
.4068 .38028 Mdot
.37322 .35384 Mdot
.62099 .41316 Mdot
.50056 .61539 Mdot
.3028 .64168 Mdot
.4905 .69653 Mdot
.53923 .73241 Mdot
.38634 .35411 Mdot
.46256 .4804 Mdot
.53478 .70422 Mdot
.57214 .36695 Mdot
.71241 .65147 Mdot
.61885 .46227 Mdot
.795 .58784 Mdot
.46777 .17185 Mdot
.65588 .37164 Mdot
.66047 .63187 Mdot
.3202 .60883 Mdot
.35146 .61143 Mdot
.34765 .61372 Mdot
.53116 .72272 Mdot
.60821 .5269 Mdot
.5423 .72107 Mdot
.24444 .63722 Mdot
.69951 .61517 Mdot
.75746 .40951 Mdot
.57229 .46175 Mdot
.57965 .38291 Mdot
.55051 .4238 Mdot
.59024 .45006 Mdot
.59383 .40965 Mdot
.36552 .61608 Mdot
.48905 .68867 Mdot
.31665 .724 Mdot
.36713 .36993 Mdot
.21477 .55425 Mdot
.49378 .73105 Mdot
.38303 .49992 Mdot
.69352 .63588 Mdot
.71398 .46404 Mdot
.70518 .66003 Mdot
.4893 .70626 Mdot
.59336 .35942 Mdot
.36939 .35019 Mdot
.75907 .35147 Mdot
.58428 .41468 Mdot
.49386 .6988 Mdot
.47643 .72501 Mdot
.38593 .28214 Mdot
.51399 .42086 Mdot
.48433 .63926 Mdot
.53675 .52911 Mdot
.66128 .60537 Mdot
.63933 .38054 Mdot
.66956 .51479 Mdot
.51981 .71207 Mdot
.5086 .73623 Mdot
.70989 .59617 Mdot
.45112 .35935 Mdot
.35846 .39115 Mdot
.38855 .53998 Mdot
.35001 .64215 Mdot
.5733 .38963 Mdot
.53091 .71584 Mdot
.35354 .33279 Mdot
.51921 .54882 Mdot
.34774 .6265 Mdot
.51346 .75481 Mdot
.60687 .37399 Mdot
.62016 .40839 Mdot
.68888 .60928 Mdot
.58239 .66881 Mdot
.61807 .34651 Mdot
.27843 .54918 Mdot
.49402 .50231 Mdot
.50079 .59531 Mdot
.60762 .38965 Mdot
.41556 .37533 Mdot
.38209 .51059 Mdot
.67535 .62871 Mdot
.61624 .44401 Mdot
.27565 .31425 Mdot
.36495 .40992 Mdot
.32908 .61585 Mdot
.38559 .50504 Mdot
.64946 .51325 Mdot
.60902 .37605 Mdot
.60346 .41391 Mdot
.58165 .45729 Mdot
.27722 .3027 Mdot
.53986 .7173 Mdot
.40824 .35656 Mdot
.6869 .60373 Mdot
.41001 .39302 Mdot
.49751 .74642 Mdot
.49273 .61859 Mdot
.61886 .43277 Mdot
.37982 .41204 Mdot
.40604 .39413 Mdot
.3402 .63779 Mdot
.31038 .62082 Mdot
.50169 .67275 Mdot
.60432 .37648 Mdot
.39386 .53103 Mdot
.35569 .39152 Mdot
.49437 .68837 Mdot
.68839 .61007 Mdot
.29067 .62621 Mdot
.57573 .40884 Mdot
.5215 .71829 Mdot
.62068 .34977 Mdot
.37651 .36929 Mdot
.48988 .71873 Mdot
.39316 .49618 Mdot
.69854 .64037 Mdot
.61096 .3712 Mdot
.33945 .74601 Mdot
.39398 .50282 Mdot
.56754 .39394 Mdot
.45334 .17845 Mdot
.49985 .61485 Mdot
.43993 .3566 Mdot
.53632 .69721 Mdot
.39776 .52088 Mdot
.40009 .35046 Mdot
.42996 .2907 Mdot
.51309 .7353 Mdot
.58828 .2143 Mdot
.48684 .56645 Mdot
.60304 .43994 Mdot
.37804 .39913 Mdot
.70561 .66877 Mdot
.27668 .53147 Mdot
.72189 .5356 Mdot
.58947 .38945 Mdot
.53089 .70319 Mdot
.67059 .60778 Mdot
.32254 .62585 Mdot
.29334 .67216 Mdot
.81111 .57526 Mdot
.52741 .74839 Mdot
.60108 .43103 Mdot
.35205 .38109 Mdot
.33271 .61372 Mdot
.58418 .20562 Mdot
.52795 .67991 Mdot
.53258 .69615 Mdot
.54539 .40899 Mdot
.68123 .60637 Mdot
.3971 .6609 Mdot
.53632 .72811 Mdot
.48649 .6904 Mdot
.41113 .47965 Mdot
.67495 .59766 Mdot
.58391 .45592 Mdot
.65766 .34325 Mdot
.5532 .44176 Mdot
.24063 .57735 Mdot
.39724 .52356 Mdot
.36593 .37236 Mdot
.5973 .42188 Mdot
.31736 .74301 Mdot
.51133 .72957 Mdot
.53496 .52752 Mdot
.35172 .66255 Mdot
.3105 .62154 Mdot
.52671 .70467 Mdot
.6 .39457 Mdot
.3041 .6596 Mdot
.70392 .61639 Mdot
.58655 .45734 Mdot
.58882 .43731 Mdot
.37777 .42741 Mdot
.32416 .6432 Mdot
.48927 .18043 Mdot
.31849 .62923 Mdot
.32301 .6539 Mdot
.41725 .41202 Mdot
.62156 .41198 Mdot
.4913 .71651 Mdot
.54986 .69624 Mdot
.56693 .34381 Mdot
.64119 .56451 Mdot
.36345 .39565 Mdot
.56179 .71181 Mdot
.26652 .31841 Mdot
.5427 .38483 Mdot
.37285 .51402 Mdot
.32804 .32314 Mdot
.34585 .65765 Mdot
.61274 .42198 Mdot
.37357 .38294 Mdot
.50209 .67747 Mdot
.53386 .71086 Mdot
.59017 .46873 Mdot
.34583 .6083 Mdot
.71149 .60907 Mdot
.50289 .7057 Mdot
.48932 .54633 Mdot
.5827 .39193 Mdot
.36595 .54535 Mdot
.50152 .7045 Mdot
.52675 .14979 Mdot
.3093 .73584 Mdot
.38155 .35664 Mdot
.55051 .40165 Mdot
.35547 .36205 Mdot
.69722 .60393 Mdot
.48851 .74187 Mdot
.36054 .61491 Mdot
.49621 .40824 Mdot
.52289 .8179 Mdot
.52882 .72233 Mdot
.38049 .39328 Mdot
.60339 .42878 Mdot
.58879 .30863 Mdot
.59 .37598 Mdot
.80097 .51207 Mdot
.71848 .61467 Mdot
.33941 .58834 Mdot
.34284 .60545 Mdot
.55517 .42273 Mdot
.66913 .6372 Mdot
.54214 .68024 Mdot
.51275 .70773 Mdot
.52783 .84389 Mdot
.38928 .49803 Mdot
.54492 .67099 Mdot
.57105 .38409 Mdot
.50021 .68657 Mdot
.59414 .24393 Mdot
.33344 .60783 Mdot
.54433 .42162 Mdot
.54078 .74431 Mdot
.23433 .53974 Mdot
.53757 .53178 Mdot
.58508 .3905 Mdot
.52248 .38739 Mdot
.35407 .63087 Mdot
.19336 .4921 Mdot
.53801 .69718 Mdot
.60242 .45232 Mdot
.32186 .6663 Mdot
.49123 .46021 Mdot
.58625 .73778 Mdot
.38644 .38472 Mdot
.54454 .74454 Mdot
.3351 .65218 Mdot
.67266 .38645 Mdot
.70731 .63035 Mdot
.52169 .67445 Mdot
.54728 .72967 Mdot
.56932 .42703 Mdot
.6064 .46024 Mdot
.52221 .40688 Mdot
.3707 .39688 Mdot
.31624 .64727 Mdot
.56594 .43633 Mdot
.4975 .5287 Mdot
.58682 .45 Mdot
.32352 .65157 Mdot
.56565 .90033 Mdot
.60147 .36231 Mdot
.57407 .40381 Mdot
.58483 .29943 Mdot
.41371 .3632 Mdot
.39737 .36246 Mdot
.49139 .51049 Mdot
.57846 .37215 Mdot
.47493 .56246 Mdot
.38365 .38598 Mdot
.3849 .39902 Mdot
.47606 .56426 Mdot
.57526 .42806 Mdot
.37629 .55575 Mdot
.33413 .61299 Mdot
.30996 .62216 Mdot
.39113 .36207 Mdot
.61242 .46397 Mdot
.3178 .60919 Mdot
.46383 .3247 Mdot
.48836 .71544 Mdot
.67069 .5127 Mdot
.40939 .38809 Mdot
.56097 .54583 Mdot
.31489 .62237 Mdot
.59536 .1864 Mdot
.72839 .33577 Mdot
.54249 .37649 Mdot
.61922 .41529 Mdot
.68369 .62096 Mdot
.50396 .38156 Mdot
.37763 .51321 Mdot
.34428 .61148 Mdot
.42707 .64215 Mdot
.39173 .38138 Mdot
.58249 .37204 Mdot
.71254 .54089 Mdot
.49315 .16257 Mdot
.68009 .3643 Mdot
.39141 .39882 Mdot
.39644 .38147 Mdot
.52589 .68699 Mdot
.48764 .70819 Mdot
.61699 .43371 Mdot
.35744 .61685 Mdot
.36219 .36039 Mdot
.32062 .64652 Mdot
.51886 .7105 Mdot
.49235 .72453 Mdot
.37669 .53342 Mdot
.65409 .38323 Mdot
.52314 .70482 Mdot
.28779 .67838 Mdot
.497 .52981 Mdot
.39276 .42758 Mdot
.25367 .68679 Mdot
.62333 .20331 Mdot
.49204 .36054 Mdot
.66961 .60797 Mdot
.51295 .48039 Mdot
.3491 .60027 Mdot
.5569 .4269 Mdot
.60845 .4147 Mdot
.38811 .52702 Mdot
.34161 .59965 Mdot
.69138 .63205 Mdot
.32142 .61125 Mdot
.67894 .635 Mdot
.52989 .73893 Mdot
.59301 .42805 Mdot
.63035 .40246 Mdot
.3249 .62671 Mdot
.51097 .68688 Mdot
.4894 .72746 Mdot
.66608 .62496 Mdot
.71799 .44773 Mdot
.51957 .71935 Mdot
.40942 .38916 Mdot
.51486 .19616 Mdot
.38049 .52462 Mdot
.60233 .40285 Mdot
.69845 .51915 Mdot
.44302 .2819 Mdot
.59553 .44519 Mdot
.38841 .50333 Mdot
.45427 .8741 Mdot
.59406 .43034 Mdot
.62636 .82302 Mdot
.3863 .53422 Mdot
.41809 .38791 Mdot
.50137 .69714 Mdot
.38902 .49937 Mdot
.62104 .49862 Mdot
.55778 .74883 Mdot
.59732 .34516 Mdot
.35933 .39368 Mdot
.39868 .41158 Mdot
.48712 .61251 Mdot
.23921 .57708 Mdot
.68514 .60315 Mdot
.69936 .62668 Mdot
.51609 .73387 Mdot
.29726 .68573 Mdot
.60047 .46662 Mdot
.69724 .62677 Mdot
.39475 .58095 Mdot
.5554 .42782 Mdot
.49783 .61369 Mdot
.4655 .59872 Mdot
.4067 .36121 Mdot
.65983 .44909 Mdot
.51354 .73218 Mdot
.38153 .39282 Mdot
.47846 .59917 Mdot
.54687 .42349 Mdot
.38972 .38401 Mdot
.30937 .639 Mdot
.44981 .55112 Mdot
.41157 .38073 Mdot
.55666 .53714 Mdot
.33 .6225 Mdot
.49824 .61844 Mdot
.77217 .46239 Mdot
.37836 .16091 Mdot
.35154 .61265 Mdot
.49972 .69383 Mdot
.52966 .71662 Mdot
.5167 .72138 Mdot
.37749 .40169 Mdot
.5031 .7176 Mdot
.36036 .37786 Mdot
.3682 .5972 Mdot
.7084 .46695 Mdot
.68769 .61585 Mdot
.74113 .65387 Mdot
.39908 .37292 Mdot
.24258 .61826 Mdot
.22633 .68339 Mdot
.58978 .45373 Mdot
.31957 .65687 Mdot
.65964 .6243 Mdot
.48567 .48826 Mdot
.68465 .62393 Mdot
.50182 .69471 Mdot
.67419 .50577 Mdot
.59604 .38569 Mdot
.30343 .36874 Mdot
.67169 .60743 Mdot
.3877 .40065 Mdot
.56179 .40354 Mdot
.55503 .73013 Mdot
.70294 .60928 Mdot
.66706 .61681 Mdot
.59528 .40886 Mdot
.40576 .40676 Mdot
.48998 .71293 Mdot
.35623 .60128 Mdot
.72446 .64661 Mdot
.52177 .37892 Mdot
.61325 .43212 Mdot
.60327 .36046 Mdot
.52279 .52147 Mdot
.31658 .69841 Mdot
.33308 .62203 Mdot
.75107 .55651 Mdot
.52902 .73044 Mdot
.72589 .53678 Mdot
.29649 .53547 Mdot
.66927 .66 Mdot
.39595 .52538 Mdot
.39719 .52442 Mdot
.5865 .39786 Mdot
.17256 .58312 Mdot
.68391 .35176 Mdot
.37226 .64474 Mdot
.38418 .52419 Mdot
.48753 .72303 Mdot
.36247 .41686 Mdot
.59631 .48751 Mdot
.57873 .46426 Mdot
.35087 .59884 Mdot
.51551 .7131 Mdot
.1554 .53285 Mdot
.69799 .61473 Mdot
.48225 .48924 Mdot
.6076 .3782 Mdot
.59238 .39838 Mdot
.34079 .62885 Mdot
.36152 .61809 Mdot
.4094 .47482 Mdot
.57578 .5687 Mdot
.285 .39374 Mdot
.31659 .60213 Mdot
.15473 .53237 Mdot
.30647 .32546 Mdot
.38633 .36468 Mdot
.37364 .51609 Mdot
.30492 .62692 Mdot
.59857 .41952 Mdot
.41889 .38589 Mdot
.69149 .37092 Mdot
.33547 .3567 Mdot
.49907 .60985 Mdot
.49503 .5528 Mdot
.61787 .38256 Mdot
.38762 .34478 Mdot
.38467 .39114 Mdot
.40277 .34513 Mdot
.38046 .51448 Mdot
.61017 .39244 Mdot
.59966 .44795 Mdot
.59426 .43181 Mdot
.56108 .32187 Mdot
.58325 .3986 Mdot
.29274 .53409 Mdot
.48564 .51872 Mdot
.6311 .70465 Mdot
.58309 .41815 Mdot
.31231 .64684 Mdot
.59305 .42621 Mdot
.67713 .64351 Mdot
.60833 .36788 Mdot
.50052 .60744 Mdot
.34183 .61674 Mdot
.41206 .31436 Mdot
.50252 .77305 Mdot
.628 .41054 Mdot
.69827 .60027 Mdot
.26517 .68926 Mdot
.73878 .55382 Mdot
.41302 .4847 Mdot
.40937 .38526 Mdot
.48367 .69201 Mdot
.3146 .65973 Mdot
.49499 .72499 Mdot
.53807 .40695 Mdot
.37206 .52641 Mdot
.76716 .30501 Mdot
.57047 .55014 Mdot
.59715 .42057 Mdot
.65079 .38004 Mdot
.4096 .36617 Mdot
.5084 .72777 Mdot
.44505 .4142 Mdot
.55323 .42726 Mdot
.71118 .63282 Mdot
.67647 .6463 Mdot
.45561 .66871 Mdot
.43241 .55422 Mdot
.64002 .2869 Mdot
.33988 .62703 Mdot
.53335 .71886 Mdot
.68096 .65102 Mdot
.31853 .38361 Mdot
.30441 .64413 Mdot
.34633 .65754 Mdot
.32561 .6442 Mdot
.57838 .39109 Mdot
.37724 .53021 Mdot
.41984 .58895 Mdot
.39426 .50021 Mdot
.55816 .44334 Mdot
.5464 .7317 Mdot
.3962 .49952 Mdot
.68097 .6134 Mdot
.33399 .65506 Mdot
.49719 .73841 Mdot
.58814 .40995 Mdot
.38267 .38047 Mdot
.77299 .60338 Mdot
.3355 .7655 Mdot
.50075 .61667 Mdot
.50078 .61676 Mdot
.40295 .41346 Mdot
.32649 .42863 Mdot
.30302 .60789 Mdot
.39726 .28478 Mdot
.63523 .6001 Mdot
.57409 .34085 Mdot
.58135 .79202 Mdot
.54272 .71722 Mdot
.51175 .6996 Mdot
.59015 .38281 Mdot
.50746 .68205 Mdot
.58832 .37295 Mdot
.53478 .69329 Mdot
.26152 .54266 Mdot
.5688 .46254 Mdot
.50861 .70397 Mdot
.51078 .42095 Mdot
.5663 .40345 Mdot
.41545 .3783 Mdot
.51701 .67522 Mdot
.54254 .3769 Mdot
.81376 .36062 Mdot
.33572 .6371 Mdot
.38008 .51569 Mdot
.51155 .60197 Mdot
.32166 .61458 Mdot
.35728 .37794 Mdot
.58304 .36785 Mdot
.6999 .6124 Mdot
.39139 .36751 Mdot
.54799 .75263 Mdot
.6738 .60789 Mdot
.45416 .45977 Mdot
.3898 .36322 Mdot
.38206 .52865 Mdot
.69458 .64226 Mdot
.59607 .34505 Mdot
.51267 .70132 Mdot
.31995 .74977 Mdot
.38706 .5012 Mdot
.59992 .38671 Mdot
.54245 .74873 Mdot
.32089 .61221 Mdot
.62417 .41448 Mdot
.53209 .71468 Mdot
.38218 .50792 Mdot
.57027 .40673 Mdot
.56868 .38256 Mdot
.46101 .37039 Mdot
.59905 .61696 Mdot
.685 .61427 Mdot
.42606 .4002 Mdot
.56795 .45316 Mdot
.66634 .6327 Mdot
.35441 .73303 Mdot
.55406 .45044 Mdot
.35965 .40256 Mdot
.43949 .31813 Mdot
.49585 .69055 Mdot
.33671 .60616 Mdot
.53851 .68267 Mdot
.6827 .59821 Mdot
.27607 .76914 Mdot
.37476 .51732 Mdot
.60221 .35557 Mdot
.55358 .36764 Mdot
.48371 .73695 Mdot
.3875 .39107 Mdot
.28676 .38989 Mdot
.60506 .36793 Mdot
.66527 .39364 Mdot
.59935 .40661 Mdot
.35453 .74186 Mdot
.37412 .39972 Mdot
.60151 .40538 Mdot
.53089 .36145 Mdot
.54197 .39373 Mdot
.70891 .60902 Mdot
.75953 .3996 Mdot
.59481 .4417 Mdot
.74993 .79428 Mdot
.37641 .53962 Mdot
.51104 .71086 Mdot
.54898 .53369 Mdot
.52383 .61635 Mdot
.79223 .6356 Mdot
.35938 .38682 Mdot
.32384 .40446 Mdot
.49226 .72069 Mdot
.77265 .63643 Mdot
.34345 .44539 Mdot
.56443 .39027 Mdot
.59977 .37173 Mdot
.50175 .69476 Mdot
.49132 .69134 Mdot
.37205 .53204 Mdot
.62899 .42414 Mdot
.66575 .42768 Mdot
.54709 .69954 Mdot
.58212 .40836 Mdot
.44564 .26343 Mdot
.36372 .64498 Mdot
.39208 .36142 Mdot
.32238 .62776 Mdot
.36296 .64373 Mdot
.47896 .37314 Mdot
.49777 .50379 Mdot
.35715 .63709 Mdot
.37482 .63484 Mdot
.72826 .66413 Mdot
.55555 .31304 Mdot
.70993 .6113 Mdot
.43126 .50511 Mdot
.51972 .72849 Mdot
.61138 .39483 Mdot
.37811 .40308 Mdot
.82794 .48961 Mdot
.27209 .42562 Mdot
.68838 .46393 Mdot
.58105 .45458 Mdot
.51376 .72824 Mdot
.38569 .50313 Mdot
.55956 .4573 Mdot
.72683 .53335 Mdot
.59004 .39304 Mdot
.48712 .70372 Mdot
.54788 .31564 Mdot
.27724 .63697 Mdot
.31595 .60138 Mdot
.34696 .40346 Mdot
.59533 .42815 Mdot
.36817 .38189 Mdot
.35977 .63827 Mdot
.66192 .61823 Mdot
.69098 .62378 Mdot
.62928 .40485 Mdot
.49866 .59024 Mdot
.68154 .67345 Mdot
.56417 .39407 Mdot
.57203 .42888 Mdot
.39565 .52474 Mdot
.57304 .42988 Mdot
.61298 .44402 Mdot
.56736 .43967 Mdot
.60177 .45704 Mdot
.30318 .63729 Mdot
.4607 .39961 Mdot
.63508 .40291 Mdot
.56338 .35616 Mdot
.37076 .61468 Mdot
.53176 .39016 Mdot
.35451 .62369 Mdot
.28687 .42153 Mdot
.35338 .63932 Mdot
.69067 .62224 Mdot
.54748 .74439 Mdot
.35437 .4342 Mdot
.36266 .36024 Mdot
.30804 .64322 Mdot
.69285 .63973 Mdot
.3487 .61268 Mdot
.53634 .71842 Mdot
.29085 .70726 Mdot
.43648 .39591 Mdot
.48037 .52779 Mdot
.57016 .30472 Mdot
.36468 .54616 Mdot
.51364 .68281 Mdot
.37872 .35679 Mdot
.28563 .65747 Mdot
.55568 .4223 Mdot
.6945 .60808 Mdot
.5872 .39819 Mdot
.33038 .65592 Mdot
.51637 .72776 Mdot
.40523 .5305 Mdot
.68445 .61505 Mdot
.2933 .76721 Mdot
.54632 .70937 Mdot
.57241 .3592 Mdot
.37014 .61433 Mdot
.29933 .70383 Mdot
.35659 .62962 Mdot
.70938 .46655 Mdot
.34505 .32795 Mdot
.8236 .51875 Mdot
.39709 .37683 Mdot
.36857 .5126 Mdot
.35456 .21104 Mdot
.33473 .50454 Mdot
.3801 .3729 Mdot
.49512 .77159 Mdot
.58012 .39802 Mdot
.5818 .45111 Mdot
.65452 .39064 Mdot
.36271 .33565 Mdot
.58118 .45714 Mdot
.37688 .5188 Mdot
.49988 .51046 Mdot
.40644 .61825 Mdot
.48708 .68467 Mdot
.591 .37409 Mdot
.36695 .62595 Mdot
.31083 .64917 Mdot
.39925 .50336 Mdot
.31779 .63488 Mdot
.57504 .4191 Mdot
.39839 .37359 Mdot
.47331 .59635 Mdot
.69659 .6042 Mdot
.28658 .55639 Mdot
.6323 .63169 Mdot
.71326 .65971 Mdot
.54152 .39153 Mdot
.49159 .72293 Mdot
.53521 .81847 Mdot
.56333 .43958 Mdot
.38207 .3882 Mdot
.55566 .36661 Mdot
.57478 .4451 Mdot
.59985 .43658 Mdot
.53274 .71988 Mdot
.54219 .5363 Mdot
.58252 .41014 Mdot
.35684 .63884 Mdot
.47815 .56524 Mdot
.58315 .46558 Mdot
.4322 .64958 Mdot
.49972 .60754 Mdot
.36615 .54682 Mdot
.38729 .42848 Mdot
.49304 .70965 Mdot
.39323 .37982 Mdot
.36368 .34267 Mdot
.3575 .37695 Mdot
.41546 .60204 Mdot
.41228 .29031 Mdot
.65139 .81419 Mdot
.5986 .24974 Mdot
.56415 .30307 Mdot
.34373 .38802 Mdot
.40723 .7232 Mdot
.37637 .37528 Mdot
.35765 .38088 Mdot
.52679 .8861 Mdot
.376 .40639 Mdot
.60719 .40453 Mdot
.62218 .37251 Mdot
.31095 .29771 Mdot
.73417 .65047 Mdot
.57001 .38938 Mdot
.59646 .45278 Mdot
.67913 .64906 Mdot
.46519 .38148 Mdot
.36974 .52834 Mdot
.47796 .48783 Mdot
.37743 .50179 Mdot
.59453 .40862 Mdot
.62414 .39115 Mdot
.62558 .43981 Mdot
.4178 .16359 Mdot
.82494 .54112 Mdot
.41014 .40778 Mdot
.55921 .34278 Mdot
.36473 .55679 Mdot
.55992 .37006 Mdot
.5497 .37485 Mdot
.5921 .4346 Mdot
.49126 .71691 Mdot
.36931 .41904 Mdot
.61751 .34667 Mdot
.32138 .54857 Mdot
.61385 .3806 Mdot
.64349 .65213 Mdot
.66547 .59656 Mdot
.60111 .39504 Mdot
.37636 .40781 Mdot
.58258 .45285 Mdot
.35389 .36638 Mdot
.38568 .36129 Mdot
.66596 .40924 Mdot
.42082 .57864 Mdot
.35916 .4133 Mdot
.56504 .38795 Mdot
.51061 .6859 Mdot
.27634 .55248 Mdot
.60023 .38817 Mdot
.67768 .61046 Mdot
.6122 .4241 Mdot
.70599 .60419 Mdot
.58045 .43778 Mdot
.39659 .50221 Mdot
.42699 .21721 Mdot
.51094 .73712 Mdot
.72062 .65585 Mdot
.50534 .68397 Mdot
.63987 .44984 Mdot
.34676 .38923 Mdot
.30643 .58356 Mdot
.81787 .56932 Mdot
.3947 .52597 Mdot
.76515 .56971 Mdot
.46671 .56597 Mdot
.36224 .60977 Mdot
.402 .34911 Mdot
.52021 .33471 Mdot
.43822 .64462 Mdot
.47971 .69522 Mdot
.50724 .752 Mdot
.5899 .74334 Mdot
.4683 .86417 Mdot
.57938 .40888 Mdot
.38816 .67498 Mdot
.45863 .236 Mdot
.51468 .36834 Mdot
.5275 .43581 Mdot
.54903 .72381 Mdot
.56965 .38985 Mdot
.6134 .5406 Mdot
.52577 .71796 Mdot
.70234 .62927 Mdot
.36547 .37414 Mdot
.67394 .63767 Mdot
.24478 .41623 Mdot
.41263 .48824 Mdot
.52434 .7096 Mdot
.60035 .45893 Mdot
.57653 .38213 Mdot
.40999 .35665 Mdot
.59131 .21096 Mdot
.39067 .35952 Mdot
.68854 .60178 Mdot
.52081 .73704 Mdot
.78545 .36476 Mdot
.60844 .42835 Mdot
.40354 .39727 Mdot
.50184 .77274 Mdot
.61985 .40648 Mdot
.33992 .60664 Mdot
.57662 .45419 Mdot
.40537 .39823 Mdot
.57338 .43058 Mdot
.39587 .37311 Mdot
.52408 .68811 Mdot
.63043 .3973 Mdot
.62679 .39795 Mdot
.75684 .55931 Mdot
.68967 .63159 Mdot
.35008 .39571 Mdot
.61555 .53919 Mdot
.55339 .44202 Mdot
.7215 .52592 Mdot
.59333 .42868 Mdot
.5747 .30898 Mdot
.54083 .43334 Mdot
.37663 .52215 Mdot
.55137 .37076 Mdot
.59891 .38819 Mdot
.61306 .22876 Mdot
.59325 .24087 Mdot
.51871 .34577 Mdot
.30981 .6213 Mdot
.39784 .40585 Mdot
.52913 .71321 Mdot
.49758 .67823 Mdot
.49948 .71643 Mdot
.69604 .58308 Mdot
.55288 .3471 Mdot
.60049 .38358 Mdot
.38228 .60649 Mdot
.69848 .62267 Mdot
.39726 .398 Mdot
.69243 .61816 Mdot
.49993 .50243 Mdot
.67441 .61361 Mdot
.37682 .51331 Mdot
.30855 .73315 Mdot
.44696 .27435 Mdot
.67575 .62608 Mdot
.38916 .35986 Mdot
.47303 .55052 Mdot
.58237 .3402 Mdot
.22664 .56391 Mdot
.71073 .63423 Mdot
.57462 .7687 Mdot
.5743 .41194 Mdot
.56926 .53336 Mdot
.35206 .62666 Mdot
.67495 .63817 Mdot
.32655 .64322 Mdot
.58125 .45246 Mdot
.45537 .38289 Mdot
.37748 .39232 Mdot
.36797 .63812 Mdot
.54306 .40352 Mdot
.67508 .63863 Mdot
.52107 .7051 Mdot
.55118 .31504 Mdot
.3749 .61769 Mdot
.77059 .60718 Mdot
.72319 .53638 Mdot
.52337 .73481 Mdot
.59958 .28532 Mdot
.34163 .64323 Mdot
.57033 .34138 Mdot
.68606 .41434 Mdot
.56423 .44542 Mdot
.4904 .73067 Mdot
.5106 .6992 Mdot
.35967 .50426 Mdot
.62557 .39054 Mdot
.63555 .392 Mdot
.39098 .42285 Mdot
.52583 .7358 Mdot
.35715 .3754 Mdot
.39557 .35128 Mdot
.50277 .69284 Mdot
.38337 .35578 Mdot
.67052 .61005 Mdot
.61766 .52216 Mdot
.3444 .64284 Mdot
.34633 .60687 Mdot
.52444 .70675 Mdot
.52042 .74433 Mdot
.49188 .72507 Mdot
.54835 .41532 Mdot
.3695 .35957 Mdot
.5516 .40009 Mdot
.59834 .42898 Mdot
.31946 .37063 Mdot
.405 .41902 Mdot
.54761 .38806 Mdot
.46132 .60007 Mdot
.71603 .62197 Mdot
.50737 .70707 Mdot
.31584 .64436 Mdot
.78004 .60355 Mdot
.36502 .60993 Mdot
.55717 .44781 Mdot
.23543 .54512 Mdot
.37947 .40165 Mdot
.68396 .62264 Mdot
.50177 .61188 Mdot
.68354 .61747 Mdot
.36505 .64293 Mdot
.41692 .40835 Mdot
.45694 .46981 Mdot
.6267 .39116 Mdot
.51925 .51953 Mdot
.76245 .49892 Mdot
.30332 .53616 Mdot
.31309 .64489 Mdot
.58743 .45465 Mdot
.38973 .53143 Mdot
.38727 .28054 Mdot
.59719 .38286 Mdot
.54152 .41523 Mdot
.54289 .63468 Mdot
.55096 .36889 Mdot
.42442 .39374 Mdot
.49352 .60663 Mdot
.62131 .43814 Mdot
.64029 .44747 Mdot
.51234 .85911 Mdot
.56885 .40194 Mdot
.62805 .40098 Mdot
.61152 .40763 Mdot
.55375 .42152 Mdot
.35295 .36505 Mdot
.55097 .65183 Mdot
.3647 .6331 Mdot
.61853 .52227 Mdot
.3314 .64583 Mdot
.52139 .69764 Mdot
.60121 .5541 Mdot
.35431 .36459 Mdot
.68298 .61719 Mdot
.37534 .68662 Mdot
.6711 .50611 Mdot
.52361 .68592 Mdot
.78323 .5669 Mdot
.71147 .6214 Mdot
.58209 .33983 Mdot
.67771 .5977 Mdot
.54722 .7342 Mdot
.34653 .60883 Mdot
.59339 .35955 Mdot
.35501 .38758 Mdot
.41123 .38033 Mdot
.57149 .45371 Mdot
.2852 .56446 Mdot
.32648 .6078 Mdot
.68032 .56217 Mdot
.5805 .38657 Mdot
.54454 .42261 Mdot
.39024 .35765 Mdot
.50961 .7272 Mdot
.46872 .56593 Mdot
.69006 .63649 Mdot
.57749 .3642 Mdot
.59164 .45028 Mdot
.50229 .50444 Mdot
.30586 .64154 Mdot
.38776 .51682 Mdot
.59559 .37797 Mdot
.48548 .49919 Mdot
.58084 .45784 Mdot
.62507 .44831 Mdot
.50116 .68903 Mdot
.66671 .39998 Mdot
.61468 .37605 Mdot
.45036 .37728 Mdot
.33798 .64324 Mdot
.38685 .38747 Mdot
.32185 .38521 Mdot
.39855 .50887 Mdot
.33229 .63521 Mdot
.54599 .39153 Mdot
.33466 .66201 Mdot
.57868 .4486 Mdot
.58587 .41027 Mdot
.31146 .64327 Mdot
.36129 .36792 Mdot
.3074 .42197 Mdot
.46083 .39962 Mdot
.56038 .42467 Mdot
.61443 .42053 Mdot
.73348 .65109 Mdot
.83855 .50175 Mdot
.61962 .37865 Mdot
.37566 .35628 Mdot
.62057 .40756 Mdot
.36105 .6112 Mdot
.68327 .6027 Mdot
.38021 .38359 Mdot
.5335 .72882 Mdot
.52702 .69062 Mdot
.48027 .74929 Mdot
.37556 .5147 Mdot
.63091 .41709 Mdot
.42378 .40322 Mdot
.40543 .4171 Mdot
.588 .52063 Mdot
.51061 .7097 Mdot
.6796 .60314 Mdot
.56938 .38588 Mdot
.49412 .40593 Mdot
.35824 .64762 Mdot
.77455 .76844 Mdot
.46023 .47573 Mdot
.6955 .58878 Mdot
.57111 .57754 Mdot
.39386 .52471 Mdot
.57187 .39868 Mdot
.67516 .64134 Mdot
.51731 .69196 Mdot
.58262 .45155 Mdot
.52356 .38897 Mdot
.44082 .65714 Mdot
.51422 .74816 Mdot
.3529 .65435 Mdot
.53913 .70373 Mdot
.71074 .60929 Mdot
.37711 .5139 Mdot
.41307 .39041 Mdot
.59574 .39189 Mdot
.66601 .43379 Mdot
.51385 .72121 Mdot
.39617 .53038 Mdot
.6258 .41886 Mdot
.40599 .40338 Mdot
.50449 .7137 Mdot
.59768 .41309 Mdot
.39079 .28512 Mdot
.35304 .43247 Mdot
.52231 .73029 Mdot
.57515 .36699 Mdot
.58512 .48498 Mdot
.51274 .74973 Mdot
.5417 .74144 Mdot
.59067 .45528 Mdot
.68075 .64098 Mdot
.61364 .37722 Mdot
.35802 .62138 Mdot
.54129 .53691 Mdot
.3265 .62892 Mdot
.72886 .53233 Mdot
.61395 .45586 Mdot
.688 .37012 Mdot
.37865 .34681 Mdot
.70867 .65337 Mdot
.67108 .24638 Mdot
.55118 .44051 Mdot
.27912 .32555 Mdot
.55758 .54535 Mdot
.46911 .50399 Mdot
.25669 .34372 Mdot
.68098 .63392 Mdot
.34814 .61392 Mdot
.62631 .41424 Mdot
.33878 .68635 Mdot
.67484 .63147 Mdot
.72871 .5313 Mdot
.55824 .38102 Mdot
.38714 .39859 Mdot
.58098 .38916 Mdot
.40673 .39969 Mdot
.61727 .40465 Mdot
.39689 .31264 Mdot
.64831 .65864 Mdot
.71021 .46415 Mdot
.59094 .34087 Mdot
.29569 .69954 Mdot
.56938 .30438 Mdot
.68263 .60579 Mdot
.56547 .42848 Mdot
.39313 .51718 Mdot
.3207 .61161 Mdot
.37064 .70001 Mdot
.49249 .72274 Mdot
.35283 .64202 Mdot
.37618 .36213 Mdot
.55243 .72338 Mdot
.39685 .52785 Mdot
.62787 .3459 Mdot
.67679 .64042 Mdot
.33544 .63669 Mdot
.59915 .39064 Mdot
.55541 .43518 Mdot
.35344 .74239 Mdot
.76953 .34447 Mdot
.3848 .35242 Mdot
.36369 .82691 Mdot
.42791 .39595 Mdot
.69606 .63065 Mdot
.49742 .69148 Mdot
.60143 .42055 Mdot
.60763 .38061 Mdot
.5115 .7465 Mdot
.41435 .36614 Mdot
.69753 .6602 Mdot
.82704 .5142 Mdot
.34346 .6661 Mdot
.74748 .42256 Mdot
.37749 .38382 Mdot
.7465 .42574 Mdot
.65385 .59516 Mdot
.39053 .55714 Mdot
.73641 .3488 Mdot
.33007 .61238 Mdot
.74876 .41957 Mdot
.3939 .40085 Mdot
.57731 .40712 Mdot
.38348 .5284 Mdot
.37817 .53762 Mdot
.36897 .37631 Mdot
.4982 .69757 Mdot
.70661 .63202 Mdot
.58325 .38724 Mdot
.65159 .3553 Mdot
.58195 .20411 Mdot
.52596 .73968 Mdot
.64968 .37971 Mdot
.31794 .62027 Mdot
.61859 .41222 Mdot
.67062 .64356 Mdot
.3372 .61226 Mdot
.39161 .49701 Mdot
.66679 .50931 Mdot
.58265 .36775 Mdot
.49917 .59713 Mdot
.34688 .63067 Mdot
.83769 .494 Mdot
.62634 .39729 Mdot
.34118 .64329 Mdot
.66594 .43232 Mdot
.29528 .58734 Mdot
.47496 .58338 Mdot
.33362 .50169 Mdot
.51492 .67047 Mdot
.53562 .69549 Mdot
.81583 .37047 Mdot
.63775 .58981 Mdot
.34736 .64814 Mdot
.38024 .50673 Mdot
.76346 .38422 Mdot
.32694 .64067 Mdot
.58568 .36192 Mdot
.59032 .42671 Mdot
.54766 .31566 Mdot
.49989 .41077 Mdot
.37128 .53402 Mdot
.60869 .32512 Mdot
.57132 .41926 Mdot
.6326 .35667 Mdot
.62085 .42232 Mdot
.40152 .41044 Mdot
.32591 .61499 Mdot
.20815 .31687 Mdot
.32266 .66131 Mdot
.68753 .39378 Mdot
.51944 .72854 Mdot
.52656 .67335 Mdot
.60052 .39605 Mdot
.69861 .3711 Mdot
.15329 .55378 Mdot
.60476 .43324 Mdot
.50169 .61126 Mdot
.72519 .5381 Mdot
.5644 .3432 Mdot
.35839 .4063 Mdot
.66797 .42195 Mdot
.43516 .38532 Mdot
.33749 .61122 Mdot
.67891 .63295 Mdot
.71231 .63912 Mdot
.35191 .61761 Mdot
.60933 .38335 Mdot
.70382 .6472 Mdot
.59474 .40057 Mdot
.57406 .38853 Mdot
.48732 .4944 Mdot
.6594 .61546 Mdot
.49052 .7229 Mdot
.68886 .62239 Mdot
.36143 .39152 Mdot
.52533 .89813 Mdot
.69184 .61167 Mdot
.55523 .31308 Mdot
.59141 .54054 Mdot
.75162 .42394 Mdot
.4111 .37586 Mdot
.69373 .6023 Mdot
.33122 .60989 Mdot
.44803 .46036 Mdot
.57999 .29257 Mdot
.36507 .61034 Mdot
.59769 .38062 Mdot
.35796 .35986 Mdot
.40575 .4132 Mdot
.31144 .60629 Mdot
.4135 .37006 Mdot
.60014 .35015 Mdot
.56658 .38135 Mdot
.35709 .64145 Mdot
.48839 .16013 Mdot
.33831 .60528 Mdot
.48068 .36851 Mdot
.58885 .4349 Mdot
.38139 .38597 Mdot
.5798 .30704 Mdot
.32784 .38475 Mdot
.37546 .53238 Mdot
.61332 .36974 Mdot
.6888 .607 Mdot
.60865 .52706 Mdot
.52096 .732 Mdot
.2369 .54024 Mdot
.40956 .38618 Mdot
.29893 .62654 Mdot
.41524 .37901 Mdot
.40608 .35676 Mdot
.37023 .62954 Mdot
.37534 .3963 Mdot
.61356 .38088 Mdot
.19898 .44391 Mdot
.40752 .37706 Mdot
.34263 .6251 Mdot
.69875 .60791 Mdot
.38065 .35645 Mdot
.70729 .57141 Mdot
.57671 .3786 Mdot
.53396 .68511 Mdot
.72748 .629 Mdot
.38738 .3436 Mdot
.68073 .60492 Mdot
.51105 .71675 Mdot
.70406 .63679 Mdot
.37312 .66932 Mdot
.31154 .59741 Mdot
.69331 .45093 Mdot
.2818 .61156 Mdot
.36931 .40103 Mdot
.53594 .67181 Mdot
.58978 .36702 Mdot
.57828 .38668 Mdot
.7186 .62205 Mdot
.40065 .41299 Mdot
.27805 .57708 Mdot
.66409 .32754 Mdot
.28793 .55641 Mdot
.30557 .63044 Mdot
.75214 .61053 Mdot
.45745 .47319 Mdot
.31962 .67882 Mdot
.64003 .38406 Mdot
.39291 .52552 Mdot
.60006 .40694 Mdot
.73789 .55332 Mdot
.7115 .61494 Mdot
.38672 .76488 Mdot
.60285 .46549 Mdot
.50838 .74354 Mdot
.61477 .41126 Mdot
.40632 .65885 Mdot
.63651 .4471 Mdot
.71214 .63334 Mdot
.31659 .66392 Mdot
.36271 .36015 Mdot
.70396 .60786 Mdot
.52419 .68907 Mdot
.72618 .37908 Mdot
.58642 .36273 Mdot
.57129 .41574 Mdot
.51523 .75293 Mdot
.35579 .38132 Mdot
.51721 .69787 Mdot
.34352 .64317 Mdot
.6911 .61414 Mdot
.55038 .41207 Mdot
.64525 .37065 Mdot
.48604 .74102 Mdot
.33302 .65845 Mdot
.49532 .74149 Mdot
.33631 .66132 Mdot
.38981 .52862 Mdot
.61306 .45117 Mdot
.5115 .75547 Mdot
.63834 .40693 Mdot
.56616 .24248 Mdot
.63608 .5141 Mdot
.64775 .25912 Mdot
.48959 .7211 Mdot
.63617 .65529 Mdot
.34568 .61752 Mdot
.33725 .63894 Mdot
.47737 .35819 Mdot
.17016 .58101 Mdot
.47496 .56274 Mdot
.27213 .70987 Mdot
.34487 .64284 Mdot
.34193 .63281 Mdot
.50768 .69617 Mdot
.36006 .38389 Mdot
.36972 .34117 Mdot
.53937 .75032 Mdot
.69902 .51724 Mdot
.39749 .39811 Mdot
.29186 .30563 Mdot
.54092 .72792 Mdot
.62427 .37 Mdot
.40837 .49202 Mdot
.71159 .63371 Mdot
.71399 .53916 Mdot
.29668 .71006 Mdot
.60445 .41411 Mdot
.60975 .82635 Mdot
.49314 .71678 Mdot
.42977 .49391 Mdot
.37783 .58595 Mdot
.54886 .42585 Mdot
.61398 .40587 Mdot
.62038 .39204 Mdot
.71122 .59788 Mdot
.57089 .21884 Mdot
.60254 .41715 Mdot
.69182 .49237 Mdot
.56706 .46203 Mdot
.33505 .74906 Mdot
.68909 .62219 Mdot
.79995 .51958 Mdot
.5534 .69333 Mdot
.31034 .55661 Mdot
.54066 .39899 Mdot
.35115 .63743 Mdot
.44373 .62609 Mdot
.31842 .6502 Mdot
.37903 .57295 Mdot
.75938 .36539 Mdot
.39478 .413 Mdot
.57374 .4537 Mdot
.54001 .73415 Mdot
.36818 .35006 Mdot
.45037 .61628 Mdot
.5076 .89337 Mdot
.30493 .61876 Mdot
.34913 .8425 Mdot
.32459 .63347 Mdot
.376 .53795 Mdot
.37702 .36356 Mdot
.70404 .36249 Mdot
.51385 .51548 Mdot
.35779 .37399 Mdot
.64544 .73774 Mdot
.42416 .35386 Mdot
.73243 .41662 Mdot
.43512 .40533 Mdot
.33958 .62023 Mdot
.29912 .62107 Mdot
.52773 .40931 Mdot
.60701 .37163 Mdot
.51902 .52346 Mdot
.52095 .42973 Mdot
.58329 .36867 Mdot
.52594 .71829 Mdot
.27377 .63782 Mdot
.33414 .68786 Mdot
.37256 .38423 Mdot
.3506 .65192 Mdot
.61414 .4097 Mdot
.56055 .4245 Mdot
.56632 .35768 Mdot
.775 .63357 Mdot
.29081 .30476 Mdot
.58508 .41235 Mdot
.64078 .44132 Mdot
.51774 .68555 Mdot
.35415 .74364 Mdot
.3839 .8269 Mdot
.76077 .37304 Mdot
.62372 .42486 Mdot
.69051 .62962 Mdot
.67331 .64648 Mdot
.58026 .3506 Mdot
.70022 .39079 Mdot
.74558 .61452 Mdot
.59937 .39044 Mdot
.7217 .41353 Mdot
.47696 .70962 Mdot
.40065 .51757 Mdot
.51381 .72053 Mdot
.37808 .34491 Mdot
.39256 .52958 Mdot
.53178 .70714 Mdot
.68157 .50759 Mdot
.39535 .50542 Mdot
.29801 .58303 Mdot
.69124 .60168 Mdot
.62437 .41351 Mdot
.41841 .44157 Mdot
.52835 .73509 Mdot
.34356 .63499 Mdot
.38775 .37167 Mdot
.3191 .61168 Mdot
.31671 .74475 Mdot
.7025 .52256 Mdot
.37475 .51977 Mdot
.35341 .63589 Mdot
.49478 .58608 Mdot
.69151 .62811 Mdot
.31992 .63412 Mdot
.68935 .36776 Mdot
.58661 .46725 Mdot
.15787 .46567 Mdot
.56613 .412 Mdot
.36171 .49164 Mdot
.34566 .63712 Mdot
.39315 .49516 Mdot
.59413 .39209 Mdot
.54547 .70541 Mdot
.58187 .33397 Mdot
.59364 .4016 Mdot
.53961 .71714 Mdot
.5816 .4114 Mdot
.66262 .62937 Mdot
.43253 .37699 Mdot
.57189 .54541 Mdot
.7565 .59721 Mdot
.70876 .62547 Mdot
.55645 .51179 Mdot
.61894 .37737 Mdot
.61636 .71143 Mdot
.38752 .39707 Mdot
.5525 .44185 Mdot
.74354 .53206 Mdot
.3637 .38177 Mdot
.39442 .37993 Mdot
.56767 .42462 Mdot
.34455 .60417 Mdot
.49432 .73585 Mdot
.69041 .62647 Mdot
.30148 .68546 Mdot
.59793 .41527 Mdot
.58725 .45512 Mdot
.71032 .61739 Mdot
.33499 .63447 Mdot
.54823 .40478 Mdot
.27063 .49585 Mdot
.6092 .51813 Mdot
.35479 .65186 Mdot
.58416 .46569 Mdot
.22382 .35492 Mdot
.38541 .338 Mdot
.61884 .82478 Mdot
.63667 .64597 Mdot
.50091 .69195 Mdot
.65867 .39579 Mdot
.70822 .82817 Mdot
.6915 .60298 Mdot
.30509 .54775 Mdot
.57791 .40381 Mdot
.60215 .42429 Mdot
.39032 .41107 Mdot
.55046 .39127 Mdot
.39164 .40554 Mdot
.75998 .61928 Mdot
.17673 .59969 Mdot
.41173 .36865 Mdot
.39944 .40329 Mdot
.57432 .47632 Mdot
.77876 .64147 Mdot
.36759 .37123 Mdot
.58574 .3631 Mdot
.63567 .71544 Mdot
.52163 .38372 Mdot
.6619 .60244 Mdot
.74697 .63846 Mdot
.35515 .40327 Mdot
.56263 .29584 Mdot
.5746 .47611 Mdot
.4202 .3164 Mdot
.71397 .58015 Mdot
.33907 .64916 Mdot
.58079 .44439 Mdot
.37769 .50908 Mdot
.5039 .70888 Mdot
.67295 .39876 Mdot
.62599 .40162 Mdot
.35901 .3999 Mdot
.70696 .59674 Mdot
.3228 .63981 Mdot
.61176 .44123 Mdot
.48064 .73652 Mdot
.69761 .63552 Mdot
.40242 .36998 Mdot
.50741 .34364 Mdot
.70373 .64557 Mdot
.64923 .37598 Mdot
.57709 .41083 Mdot
.61623 .43745 Mdot
.53221 .35224 Mdot
.35211 .62001 Mdot
.54765 .73893 Mdot
.6519 .38487 Mdot
.46414 .47335 Mdot
.63761 .52285 Mdot
.58944 .35697 Mdot
.37726 .35623 Mdot
.30661 .6323 Mdot
.383 .51102 Mdot
.75746 .40897 Mdot
.58327 .42448 Mdot
.28643 .30745 Mdot
.80405 .5702 Mdot
.39291 .50736 Mdot
.35155 .36249 Mdot
.68473 .62185 Mdot
.57824 .42975 Mdot
.69654 .48788 Mdot
.57489 .36877 Mdot
.54275 .34883 Mdot
.49447 .69982 Mdot
.32703 .64925 Mdot
.66657 .47894 Mdot
.50488 .7059 Mdot
.39364 .37987 Mdot
.30948 .29327 Mdot
.37625 .34093 Mdot
.39592 .35221 Mdot
.417 .5748 Mdot
.35576 .61269 Mdot
.72402 .81717 Mdot
.84192 .51945 Mdot
.61533 .36717 Mdot
.36458 .62119 Mdot
.37449 .36876 Mdot
.55402 .37313 Mdot
.38222 .40311 Mdot
.36449 .41553 Mdot
.57192 .37973 Mdot
.57602 .37502 Mdot
.71272 .45472 Mdot
.29505 .307 Mdot
.69472 .60856 Mdot
.41841 .38525 Mdot
.4577 .343 Mdot
.59865 .42052 Mdot
.62003 .38304 Mdot
.44059 .63109 Mdot
.70145 .60476 Mdot
.42618 .2598 Mdot
.57791 .39108 Mdot
.7642 .56177 Mdot
.6031 .36669 Mdot
.35444 .34671 Mdot
.3457 .59474 Mdot
.68915 .38672 Mdot
.48782 .72481 Mdot
.40552 .35115 Mdot
.71483 .6133 Mdot
.36368 .42274 Mdot
.43617 .28852 Mdot
.34276 .6093 Mdot
.40497 .39865 Mdot
.55293 .7096 Mdot
.33126 .62856 Mdot
.34337 .60558 Mdot
.45352 .61203 Mdot
.54909 .69869 Mdot
.69736 .59047 Mdot
.31274 .63341 Mdot
.39113 .28683 Mdot
.33672 .62116 Mdot
.42872 .28472 Mdot
.63189 .40732 Mdot
.68959 .49519 Mdot
.67403 .38225 Mdot
.52448 .40564 Mdot
.32148 .62349 Mdot
.7043 .63211 Mdot
.54639 .40753 Mdot
.40896 .36304 Mdot
.70163 .61725 Mdot
.41447 .49219 Mdot
.53965 .67744 Mdot
.39795 .41682 Mdot
.33783 .66244 Mdot
.37893 .40576 Mdot
.72111 .53807 Mdot
.69808 .66281 Mdot
.45092 .63336 Mdot
.5274 .52149 Mdot
.62297 .35135 Mdot
.62651 .45904 Mdot
.54603 .41297 Mdot
.61456 .38393 Mdot
.52227 .72931 Mdot
.69521 .58361 Mdot
.38146 .35598 Mdot
.57636 .19459 Mdot
.35335 .6319 Mdot
.49494 .6008 Mdot
.55084 .34248 Mdot
.57942 .44982 Mdot
.37836 .36993 Mdot
.36769 .41925 Mdot
.59546 .23999 Mdot
.50648 .74661 Mdot
.52027 .39169 Mdot
.54464 .37751 Mdot
.62814 .49824 Mdot
.32346 .62424 Mdot
.30879 .47835 Mdot
.48846 .68479 Mdot
.37324 .86242 Mdot
.5077 .70547 Mdot
.58687 .65528 Mdot
.37346 .39589 Mdot
.67414 .61034 Mdot
.59553 .37646 Mdot
.4712 .3961 Mdot
.34825 .37394 Mdot
.56367 .69928 Mdot
.68109 .61493 Mdot
.32338 .44924 Mdot
.36153 .63108 Mdot
.6193 .43841 Mdot
.59963 .36524 Mdot
.55495 .41051 Mdot
.55673 .37419 Mdot
.35654 .6442 Mdot
.57042 .37303 Mdot
.37533 .62321 Mdot
.44342 .28269 Mdot
.74332 .52399 Mdot
.53908 .74073 Mdot
.36758 .75037 Mdot
.3985 .35357 Mdot
.35253 .26341 Mdot
.43857 .26457 Mdot
.6353 .51428 Mdot
.38511 .65287 Mdot
.6225 .43778 Mdot
.4983 .69906 Mdot
.31174 .69935 Mdot
.54101 .73784 Mdot
.15834 .38951 Mdot
.55201 .31294 Mdot
.35207 .47497 Mdot
.5547 .39616 Mdot
.51927 .75542 Mdot
.5311 .30817 Mdot
.65217 .37782 Mdot
.70386 .64993 Mdot
.42048 .29316 Mdot
.42135 .44714 Mdot
.6822 .60174 Mdot
.57341 .38338 Mdot
.40535 .41947 Mdot
.6017 .3782 Mdot
.58861 .37604 Mdot
.60541 .43412 Mdot
.36388 .5977 Mdot
.63116 .3847 Mdot
.6114 .37639 Mdot
.77702 .35118 Mdot
.47728 .64498 Mdot
.53277 .68922 Mdot
.63842 .25317 Mdot
.69862 .62233 Mdot
.37793 .34536 Mdot
.55624 .54371 Mdot
.35965 .62557 Mdot
.59778 .24039 Mdot
.56016 .40948 Mdot
.28778 .5323 Mdot
.30352 .64492 Mdot
.6852 .64027 Mdot
.38443 .50605 Mdot
.3024 .44715 Mdot
.48959 .69722 Mdot
.37035 .52568 Mdot
.51975 .73353 Mdot
.66756 .26765 Mdot
.39661 .40493 Mdot
.62381 .3519 Mdot
.31959 .6404 Mdot
.54889 .72315 Mdot
.69524 .48662 Mdot
.62288 .40355 Mdot
.48942 .72156 Mdot
.66707 .38393 Mdot
.61601 .53017 Mdot
.5497 .54227 Mdot
.55078 .72567 Mdot
.30504 .65187 Mdot
.32744 .62534 Mdot
.68015 .60007 Mdot
.39953 .34624 Mdot
.35632 .38858 Mdot
.33166 .62036 Mdot
.52123 .84233 Mdot
.5993 .41414 Mdot
.59232 .424 Mdot
.45898 .46853 Mdot
.5529 .37173 Mdot
.72625 .65644 Mdot
.37991 .54218 Mdot
.35302 .38643 Mdot
.54583 .41032 Mdot
.54859 .40479 Mdot
.57353 .40854 Mdot
.70437 .51206 Mdot
.51252 .72257 Mdot
.57264 .42065 Mdot
.67666 .6414 Mdot
.41028 .47492 Mdot
.59319 .36731 Mdot
.64478 .36747 Mdot
.38823 .40566 Mdot
.5851 .74109 Mdot
.34715 .63417 Mdot
.52129 .74094 Mdot
.53466 .73808 Mdot
.75777 .49124 Mdot
.34264 .34728 Mdot
.3706 .53456 Mdot
.33157 .73234 Mdot
.37967 .51077 Mdot
.67809 .61419 Mdot
.47232 .57688 Mdot
.49251 .66678 Mdot
.53555 .69422 Mdot
.29405 .64256 Mdot
.55951 .44577 Mdot
.59055 .36583 Mdot
.30447 .55717 Mdot
.6018 .43207 Mdot
.68912 .60609 Mdot
.35385 .6031 Mdot
.39869 .40229 Mdot
.67329 .64459 Mdot
.33347 .63938 Mdot
.3561 .37697 Mdot
.54155 .42318 Mdot
.5799 .36194 Mdot
.39111 .37326 Mdot
.40497 .37035 Mdot
.60697 .39933 Mdot
.75792 .33106 Mdot
.35272 .37657 Mdot
.38483 .36734 Mdot
.40923 .46756 Mdot
.50197 .68637 Mdot
.51008 .36499 Mdot
.36267 .61714 Mdot
.61569 .38113 Mdot
.53403 .74598 Mdot
.6757 .62287 Mdot
.4015 .3798 Mdot
.58319 .44275 Mdot
.59213 .41247 Mdot
.68904 .6287 Mdot
.65647 .61737 Mdot
.70466 .61142 Mdot
.33417 .59739 Mdot
.56485 .38813 Mdot
.37034 .36625 Mdot
.36143 .63244 Mdot
.69671 .64841 Mdot
.67727 .59694 Mdot
.74091 .33289 Mdot
.60491 .41108 Mdot
.6839 .65357 Mdot
.55891 .90105 Mdot
.73318 .37958 Mdot
.39267 .53139 Mdot
.47388 .70784 Mdot
.65854 .66905 Mdot
.72654 .63101 Mdot
.33181 .65254 Mdot
.49773 .61047 Mdot
.70231 .59786 Mdot
.59679 .43958 Mdot
.61632 .42323 Mdot
.64524 .3893 Mdot
.70164 .62118 Mdot
.70675 .52286 Mdot
.41439 .40635 Mdot
.46998 .22004 Mdot
.69857 .62209 Mdot
.55052 .71288 Mdot
.48724 .74452 Mdot
.50996 .70077 Mdot
.60947 .45086 Mdot
.63734 .23592 Mdot
.45176 .31349 Mdot
.4266 .25354 Mdot
.35776 .63524 Mdot
.36843 .41913 Mdot
.40799 .52713 Mdot
.39519 .38019 Mdot
.50026 .71982 Mdot
.69899 .6357 Mdot
.39043 .41178 Mdot
.34307 .60604 Mdot
.32596 .62341 Mdot
.48822 .73213 Mdot
.51249 .71444 Mdot
.52297 .70753 Mdot
.4032 .34897 Mdot
.37435 .39621 Mdot
.5528 .41409 Mdot
.40517 .38064 Mdot
.81102 .57828 Mdot
.70825 .6686 Mdot
.48998 .741 Mdot
.34865 .62508 Mdot
.38875 .36315 Mdot
.6255 .41144 Mdot
.56104 .6368 Mdot
.54573 .67429 Mdot
.703 .64092 Mdot
.19312 .5204 Mdot
.1653 .59496 Mdot
.58812 .46288 Mdot
.33707 .65658 Mdot
.69505 .37989 Mdot
.61738 .39119 Mdot
.49101 .70342 Mdot
.81355 .53078 Mdot
.39114 .50051 Mdot
.59805 .37267 Mdot
.53728 .39526 Mdot
.33172 .60834 Mdot
.55495 .54263 Mdot
.59776 .44055 Mdot
.47833 .6011 Mdot
.30173 .63469 Mdot
.48706 .68732 Mdot
.83965 .3979 Mdot
.42562 .48917 Mdot
.71017 .54995 Mdot
.39831 .52249 Mdot
.59847 .43488 Mdot
.52574 .72101 Mdot
.68778 .6473 Mdot
.52036 .71707 Mdot
.35555 .35641 Mdot
.49546 .69087 Mdot
.61642 .42974 Mdot
.36605 .37002 Mdot
.33422 .63589 Mdot
.50596 .58845 Mdot
.68187 .29159 Mdot
.54454 .70302 Mdot
.39953 .52626 Mdot
.57753 .37443 Mdot
.37071 .27795 Mdot
.52968 .41283 Mdot
.61326 .37514 Mdot
.31342 .64572 Mdot
.37445 .37643 Mdot
.30554 .63173 Mdot
.64913 .36499 Mdot
.31704 .31193 Mdot
.35491 .62813 Mdot
.46317 .40785 Mdot
.71142 .62032 Mdot
.69861 .52022 Mdot
.5902 .38742 Mdot
.3215 .64251 Mdot
.56517 .39682 Mdot
.41838 .38778 Mdot
.65833 .517 Mdot
.59341 .51231 Mdot
.31867 .61866 Mdot
.36415 .46334 Mdot
.61812 .53882 Mdot
.49711 .37868 Mdot
.33559 .64505 Mdot
.66711 .24575 Mdot
.39144 .51504 Mdot
.68815 .63517 Mdot
.65544 .62261 Mdot
.66717 .62368 Mdot
.60115 .42957 Mdot
.39129 .30458 Mdot
.66918 .60257 Mdot
.32044 .60529 Mdot
.66229 .61672 Mdot
.77426 .60992 Mdot
.28389 .56661 Mdot
.70984 .62483 Mdot
.58658 .39192 Mdot
.68002 .41534 Mdot
.49934 .60954 Mdot
.53033 .67776 Mdot
.27975 .38958 Mdot
.77809 .35625 Mdot
.6025 .42021 Mdot
.36451 .30428 Mdot
.34514 .36306 Mdot
.59856 .62128 Mdot
.59367 .51052 Mdot
.47964 .55109 Mdot
.38744 .36495 Mdot
.54118 .53299 Mdot
.36105 .35829 Mdot
.59201 .34013 Mdot
.58522 .4093 Mdot
.39627 .34253 Mdot
.2281 .53807 Mdot
.63801 .21456 Mdot
.28409 .55191 Mdot
.36644 .36047 Mdot
.33764 .64322 Mdot
.32315 .65446 Mdot
.31434 .64587 Mdot
.53068 .72481 Mdot
.40999 .39315 Mdot
.58123 .42541 Mdot
.51773 .68845 Mdot
.58398 .38019 Mdot
.33146 .6152 Mdot
.62256 .51483 Mdot
.39672 .40335 Mdot
.59846 .3889 Mdot
.50165 .33215 Mdot
.51454 .73264 Mdot
.69321 .62918 Mdot
.19354 .48981 Mdot
.47698 .69213 Mdot
.31585 .6612 Mdot
.34575 .39911 Mdot
.50846 .76658 Mdot
.56591 .66804 Mdot
.6167 .3667 Mdot
.60152 .36199 Mdot
.50163 .61815 Mdot
.54531 .3116 Mdot
.59957 .44261 Mdot
.52566 .68977 Mdot
.51693 .68136 Mdot
.56622 .39774 Mdot
.41376 .38253 Mdot
.68898 .59267 Mdot
.71884 .62341 Mdot
.59548 .34295 Mdot
.52663 .52459 Mdot
.69066 .49357 Mdot
.54621 .39429 Mdot
.64818 .40722 Mdot
.55155 .70031 Mdot
.39735 .52661 Mdot
.50634 .50755 Mdot
.66993 .6101 Mdot
.57604 .39984 Mdot
.58453 .20713 Mdot
.40852 .38827 Mdot
.48992 .72687 Mdot
.36755 .62684 Mdot
.70331 .64711 Mdot
.48394 .72693 Mdot
.56627 .39773 Mdot
.5483 .40436 Mdot
.31856 .63587 Mdot
.35041 .34818 Mdot
.70329 .62768 Mdot
.51726 .68771 Mdot
.6749 .60847 Mdot
.37725 .39772 Mdot
.39614 .36786 Mdot
.5512 .36363 Mdot
.52504 .41016 Mdot
.544 .71709 Mdot
.63701 .37152 Mdot
.5195 .69432 Mdot
.35298 .74266 Mdot
.35825 .64734 Mdot
.54304 .41682 Mdot
.33581 .35628 Mdot
.33066 .61701 Mdot
.60771 .41782 Mdot
.5006 .61991 Mdot
.56861 .44711 Mdot
.53812 .7499 Mdot
.82408 .5003 Mdot
.6717 .62569 Mdot
.63226 .47427 Mdot
.64674 .30253 Mdot
.54852 .37898 Mdot
.52581 .67963 Mdot
.42032 .30194 Mdot
.35568 .6224 Mdot
.36942 .39115 Mdot
.56204 .7923 Mdot
.3405 .624 Mdot
.58172 .39455 Mdot
.69262 .61248 Mdot
.36663 .35652 Mdot
.37983 .53151 Mdot
.50115 .51948 Mdot
.67641 .40773 Mdot
.54938 .35575 Mdot
.61185 .44206 Mdot
.27106 .70876 Mdot
.52247 .71081 Mdot
.37715 .36856 Mdot
.33911 .6548 Mdot
.34884 .61161 Mdot
.50945 .72746 Mdot
.41482 .45469 Mdot
.25416 .54862 Mdot
.60042 .88551 Mdot
.48484 .7319 Mdot
.66379 .62143 Mdot
.65444 .51723 Mdot
.50788 .70014 Mdot
.52714 .73117 Mdot
.54752 .68647 Mdot
.29618 .56254 Mdot
.36649 .36179 Mdot
.59206 .41413 Mdot
.34428 .4096 Mdot
.59909 .43301 Mdot
.68748 .54865 Mdot
.33386 .61487 Mdot
.36963 .39218 Mdot
.70999 .57066 Mdot
.64058 .4444 Mdot
.61375 .39429 Mdot
.66972 .56064 Mdot
.65724 .47156 Mdot
.75303 .41639 Mdot
.56635 .35991 Mdot
.51869 .72293 Mdot
.31977 .3955 Mdot
.65018 .37923 Mdot
.49748 .33463 Mdot
.32602 .62893 Mdot
.37366 .5218 Mdot
.62026 .34803 Mdot
.63899 .42376 Mdot
.3699 .35419 Mdot
.38657 .41154 Mdot
.67113 .59987 Mdot
.19959 .45164 Mdot
.32759 .63188 Mdot
.32811 .48847 Mdot
.6113 .37323 Mdot
.3915 .61753 Mdot
.82203 .52158 Mdot
.61044 .41157 Mdot
.45792 .60557 Mdot
.59618 .24066 Mdot
.58687 .44994 Mdot
.43488 .24711 Mdot
.34594 .62114 Mdot
.74961 .54432 Mdot
.56191 .37736 Mdot
.49043 .71207 Mdot
.36164 .3872 Mdot
.39864 .41679 Mdot
.68919 .64846 Mdot
.82724 .55901 Mdot
.21071 .63278 Mdot
.36992 .39436 Mdot
.62321 .3981 Mdot
.34745 .63242 Mdot
.37554 .52952 Mdot
.67234 .40444 Mdot
.38643 .67057 Mdot
.4065 .39038 Mdot
.65389 .38722 Mdot
.28266 .53307 Mdot
.54729 .53839 Mdot
.30262 .27756 Mdot
.31193 .64042 Mdot
.67165 .60614 Mdot
.51335 .38438 Mdot
.33266 .73541 Mdot
.58099 .3617 Mdot
.69507 .54839 Mdot
.36706 .3329 Mdot
.68225 .60322 Mdot
.61143 .38608 Mdot
.59529 .44312 Mdot
.55439 .52248 Mdot
.65351 .61897 Mdot
.59666 .44141 Mdot
.604 .46506 Mdot
.36491 .39649 Mdot
.38076 .54236 Mdot
.39906 .40119 Mdot
.60259 .37969 Mdot
.81412 .47105 Mdot
.41126 .40046 Mdot
.29033 .40256 Mdot
.63375 .63448 Mdot
.35905 .6273 Mdot
.66434 .41276 Mdot
.63193 .39778 Mdot
.26715 .29272 Mdot
.37606 .53399 Mdot
.42789 .83858 Mdot
.52346 .7539 Mdot
.74362 .26095 Mdot
.47855 .6885 Mdot
.35312 .46166 Mdot
.47382 .6395 Mdot
.65133 .39288 Mdot
.48702 .37701 Mdot
.41752 .25133 Mdot
.38215 .60378 Mdot
.36075 .2622 Mdot
.6068 .37152 Mdot
.57458 .40457 Mdot
.51078 .69302 Mdot
.37047 .48757 Mdot
.68939 .38316 Mdot
.50827 .50946 Mdot
.68763 .63996 Mdot
.38809 .39015 Mdot
.61832 .4228 Mdot
.21428 .53236 Mdot
.54807 .70965 Mdot
.69279 .31235 Mdot
.59582 .38959 Mdot
.69238 .39905 Mdot
.37215 .49017 Mdot
.33699 .63698 Mdot
.55114 .72524 Mdot
.54932 .70344 Mdot
.59621 .43353 Mdot
.36171 .6374 Mdot
.55863 .42884 Mdot
.62801 .53797 Mdot
.66489 .3872 Mdot
.67657 .61741 Mdot
.62528 .38832 Mdot
.67658 .31061 Mdot
.37893 .1964 Mdot
.60952 .46495 Mdot
.39363 .34872 Mdot
.52477 .70469 Mdot
.5081 .71985 Mdot
.35517 .38528 Mdot
.50753 .72012 Mdot
.4702 .22521 Mdot
.34008 .29903 Mdot
.67794 .61196 Mdot
.4587 .27547 Mdot
.67678 .63265 Mdot
.37382 .5205 Mdot
.60623 .40782 Mdot
.43005 .71166 Mdot
.48182 .72325 Mdot
.77962 .60385 Mdot
.33484 .61911 Mdot
.37644 .53607 Mdot
.57316 .37593 Mdot
.68842 .56801 Mdot
.49665 .71128 Mdot
.44522 .5488 Mdot
.58982 .42772 Mdot
.4152 .36942 Mdot
.58286 .44984 Mdot
.54809 .45537 Mdot
.37592 .53905 Mdot
.59623 .45355 Mdot
.33366 .63944 Mdot
.40581 .40291 Mdot
.35408 .48323 Mdot
.529 .73375 Mdot
.58852 .37126 Mdot
.62226 .39617 Mdot
.34982 .39631 Mdot
.61896 .37043 Mdot
.35295 .64333 Mdot
.81443 .7199 Mdot
.70716 .61094 Mdot
.39831 .52475 Mdot
.24472 .41624 Mdot
.59448 .45082 Mdot
.54889 .41429 Mdot
.45997 .52538 Mdot
.58866 .20892 Mdot
.34985 .63681 Mdot
.55622 .34991 Mdot
.52705 .68513 Mdot
.70406 .62842 Mdot
.32283 .60875 Mdot
.56709 .37954 Mdot
.58328 .41523 Mdot
.68411 .60422 Mdot
.66717 .55899 Mdot
.69137 .65897 Mdot
.34151 .64953 Mdot
.34214 .31259 Mdot
.56234 .63648 Mdot
.59804 .40709 Mdot
.40448 .50866 Mdot
.37852 .37582 Mdot
.33971 .6454 Mdot
.5585 .21438 Mdot
.58858 .33976 Mdot
.35222 .65515 Mdot
.33211 .63516 Mdot
.62452 .37476 Mdot
.34675 .34333 Mdot
.35128 .41197 Mdot
.3792 .37286 Mdot
.74787 .51718 Mdot
.35081 .79512 Mdot
.52579 .71039 Mdot
.34605 .62722 Mdot
.53024 .74792 Mdot
.70554 .60055 Mdot
.63055 .52549 Mdot
.54508 .69608 Mdot
.41539 .36456 Mdot
.53637 .74051 Mdot
.5583 .42988 Mdot
.35146 .6064 Mdot
.54087 .72601 Mdot
.5531 .37584 Mdot
.63186 .43162 Mdot
.50082 .41302 Mdot
.69705 .59247 Mdot
.5391 .53328 Mdot
.58398 .38806 Mdot
.38574 .50629 Mdot
.6038 .39545 Mdot
.35518 .64277 Mdot
.50989 .59069 Mdot
.56683 .41646 Mdot
.48203 .72473 Mdot
.38095 .81719 Mdot
.50813 .68063 Mdot
.54737 .46149 Mdot
.59663 .3807 Mdot
.5998 .41 Mdot
.57363 .37724 Mdot
.41522 .45027 Mdot
.33184 .66437 Mdot
.53569 .35701 Mdot
.50051 .74695 Mdot
.39652 .37771 Mdot
.41237 .40187 Mdot
.46781 .54769 Mdot
.37073 .52242 Mdot
.36471 .62856 Mdot
.59927 .41184 Mdot
.44611 .55222 Mdot
.48126 .50824 Mdot
.28002 .54322 Mdot
.4879 .75945 Mdot
.53785 .69678 Mdot
.4021 .35237 Mdot
.53844 .70933 Mdot
.56981 .3757 Mdot
.65375 .38935 Mdot
.35241 .47973 Mdot
.38207 .62846 Mdot
.70231 .63112 Mdot
.58948 .37861 Mdot
.70279 .49651 Mdot
.51769 .68559 Mdot
.55087 .70041 Mdot
.55764 .42537 Mdot
.34067 .36372 Mdot
.44583 .1487 Mdot
.3648 .61762 Mdot
.36999 .28305 Mdot
.40007 .43827 Mdot
.61285 .50483 Mdot
.35163 .6163 Mdot
.46573 .59782 Mdot
.52432 .6745 Mdot
.81927 .44901 Mdot
.39423 .37307 Mdot
.70185 .62999 Mdot
.56857 .36397 Mdot
.41523 .36394 Mdot
.50599 .75518 Mdot
.35409 .3671 Mdot
.62799 .35383 Mdot
.30656 .62341 Mdot
.50563 .71114 Mdot
.29581 .62848 Mdot
.36543 .35086 Mdot
.67474 .63055 Mdot
.75577 .55915 Mdot
.38837 .28264 Mdot
.59435 .24133 Mdot
.57349 .42167 Mdot
.43856 .66842 Mdot
.58315 .42796 Mdot
.41625 .40836 Mdot
.58952 .38786 Mdot
.64434 .44687 Mdot
.52368 .67273 Mdot
.58481 .35642 Mdot
.62133 .3831 Mdot
.48714 .33877 Mdot
.6128 .40461 Mdot
.56837 .39806 Mdot
.54703 .36583 Mdot
.38267 .33614 Mdot
.57963 .35652 Mdot
.41274 .3651 Mdot
.29988 .54209 Mdot
.52509 .73481 Mdot
.7042 .60029 Mdot
.71049 .60854 Mdot
.71139 .55324 Mdot
.70239 .50281 Mdot
.39274 .47036 Mdot
.39901 .39526 Mdot
.32285 .62304 Mdot
.55594 .42383 Mdot
.68031 .25484 Mdot
.80739 .47608 Mdot
.50989 .6737 Mdot
.54253 .72944 Mdot
.57228 .3658 Mdot
.16288 .5769 Mdot
.57766 .35914 Mdot
.45879 .4731 Mdot
.59934 .42923 Mdot
.54365 .41992 Mdot
.55309 .72047 Mdot
.72073 .53881 Mdot
.57259 .42042 Mdot
.36924 .35423 Mdot
.69675 .63383 Mdot
.68624 .42378 Mdot
.80379 .50367 Mdot
.48067 .37031 Mdot
.67137 .33218 Mdot
.56264 .40732 Mdot
.50628 .68985 Mdot
.3683 .35816 Mdot
.47029 .48358 Mdot
.35566 .63942 Mdot
.51511 .52471 Mdot
.43401 .2808 Mdot
.37271 .5787 Mdot
.69838 .63494 Mdot
.55852 .72944 Mdot
.61459 .43357 Mdot
.53046 .72004 Mdot
.56605 .34273 Mdot
.48068 .51469 Mdot
.67537 .61456 Mdot
.41272 .35121 Mdot
.33802 .64283 Mdot
.42083 .39088 Mdot
.64668 .2582 Mdot
.80911 .47296 Mdot
.74806 .26428 Mdot
.48746 .69763 Mdot
.48732 .18024 Mdot
.36794 .37672 Mdot
.58901 .43013 Mdot
.59688 .88616 Mdot
.37797 .38231 Mdot
.41444 .36653 Mdot
.49335 .55196 Mdot
.72985 .53343 Mdot
.63435 .36724 Mdot
.35151 .3816 Mdot
.55428 .73987 Mdot
.68466 .61768 Mdot
.55183 .38077 Mdot
.62625 .35166 Mdot
.38962 .41144 Mdot
.49718 .71725 Mdot
.69197 .54003 Mdot
.51516 .7194 Mdot
.36584 .36408 Mdot
.51083 .73688 Mdot
.3097 .42718 Mdot
.54588 .70056 Mdot
.62918 .39409 Mdot
.59865 .41098 Mdot
.41104 .61516 Mdot
.39617 .36789 Mdot
.54842 .41359 Mdot
.57903 .40756 Mdot
.3699 .36902 Mdot
.49617 .66363 Mdot
.54265 .19496 Mdot
.55187 .42306 Mdot
.5959 .41427 Mdot
.70497 .60633 Mdot
.59057 .53224 Mdot
.45077 .47117 Mdot
.54937 .38102 Mdot
.66699 .62609 Mdot
.40596 .35223 Mdot
.60544 .39579 Mdot
.72302 .54052 Mdot
.47692 .71525 Mdot
.55779 .39755 Mdot
.37716 .52695 Mdot
.60393 .43719 Mdot
.42802 .16072 Mdot
.58019 .37248 Mdot
.37861 .36273 Mdot
.36252 .38183 Mdot
.49808 .77458 Mdot
.39183 .37933 Mdot
.3913 .53194 Mdot
.32822 .62421 Mdot
.31744 .27867 Mdot
.38773 .53437 Mdot
.59463 .4559 Mdot
.84243 .52576 Mdot
.63058 .35414 Mdot
.65026 .37191 Mdot
.78027 .64088 Mdot
.39764 .5234 Mdot
.37198 .38048 Mdot
.22581 .5283 Mdot
.62591 .3651 Mdot
.36571 .62591 Mdot
.64693 .37223 Mdot
.55808 .39795 Mdot
.62138 .46359 Mdot
.33597 .30862 Mdot
.36382 .60748 Mdot
.50724 .36764 Mdot
.55154 .38146 Mdot
.58935 .20977 Mdot
.62304 .41276 Mdot
.70873 .6354 Mdot
.38741 .40139 Mdot
.5368 .71325 Mdot
.67936 .61826 Mdot
.6074 .44206 Mdot
.70004 .62037 Mdot
.5288 .71737 Mdot
.31552 .63921 Mdot
.62953 .39899 Mdot
.66196 .60203 Mdot
.69785 .63731 Mdot
.57028 .43323 Mdot
.36638 .39171 Mdot
.53236 .41601 Mdot
.60748 .39825 Mdot
.56805 .38369 Mdot
.35737 .39057 Mdot
.67826 .79687 Mdot
.57293 .40625 Mdot
.46353 .60085 Mdot
.43185 .38964 Mdot
.38339 .53995 Mdot
.53151 .69484 Mdot
.6072 .46254 Mdot
.35191 .61158 Mdot
.33021 .62307 Mdot
.48126 .70742 Mdot
.37868 .4093 Mdot
.50437 .71501 Mdot
.61384 .46414 Mdot
.65225 .38648 Mdot
.56802 .36498 Mdot
.55904 .79581 Mdot
.29559 .43685 Mdot
.3951 .3616 Mdot
.51942 .67669 Mdot
.51584 .52023 Mdot
.35855 .6101 Mdot
.55488 .71175 Mdot
.3828 .4287 Mdot
.3634 .40362 Mdot
.35393 .38007 Mdot
.67578 .63805 Mdot
.5098 .70843 Mdot
.37016 .42743 Mdot
.35277 .41173 Mdot
.56063 .42579 Mdot
.55132 .386 Mdot
.39052 .33997 Mdot
.55974 .75935 Mdot
.67698 .6278 Mdot
.50306 .68918 Mdot
.39854 .15481 Mdot
.36559 .61894 Mdot
.49015 .338 Mdot
.55213 .37537 Mdot
.42615 .89416 Mdot
.575 .35906 Mdot
.62407 .40206 Mdot
.37807 .3449 Mdot
.66114 .63802 Mdot
.68776 .61864 Mdot
.36706 .37731 Mdot
.36134 .41119 Mdot
.69411 .64372 Mdot
.48607 .55979 Mdot
.47015 .15742 Mdot
.48143 .49856 Mdot
.38751 .35759 Mdot
.39071 .27867 Mdot
.31773 .61743 Mdot
.42868 .37818 Mdot
.2894 .62698 Mdot
.52371 .73751 Mdot
.54572 .70932 Mdot
.317 .63177 Mdot
.57048 .40395 Mdot
.4874 .70963 Mdot
.58859 .47397 Mdot
.34323 .46172 Mdot
.39399 .65639 Mdot
.72514 .27453 Mdot
.62926 .38753 Mdot
.69747 .39041 Mdot
.26373 .62745 Mdot
.58309 .45708 Mdot
.59125 .30249 Mdot
.70276 .62598 Mdot
.43151 .38247 Mdot
.34713 .59935 Mdot
.27781 .32515 Mdot
.59862 .40853 Mdot
.38025 .35643 Mdot
.36271 .61119 Mdot
.32044 .45087 Mdot
.47808 .60039 Mdot
.57357 .44462 Mdot
.64934 .86089 Mdot
.35362 .36386 Mdot
.53663 .71277 Mdot
.47895 .32079 Mdot
.42293 .38235 Mdot
.52009 .63424 Mdot
.53152 .75772 Mdot
.49599 .4919 Mdot
.35012 .38636 Mdot
.69672 .65968 Mdot
.38697 .39498 Mdot
.66464 .635 Mdot
.3458 .39857 Mdot
.50537 .72955 Mdot
.60897 .38881 Mdot
.51048 .73078 Mdot
.71059 .63641 Mdot
.48468 .70278 Mdot
.34701 .59941 Mdot
.39886 .51181 Mdot
.32958 .61552 Mdot
.64296 .52057 Mdot
.53612 .21897 Mdot
.32616 .64919 Mdot
.44562 .57789 Mdot
.60901 .43272 Mdot
.35488 .34665 Mdot
.53543 .71945 Mdot
.49463 .67261 Mdot
.53477 .52993 Mdot
.35925 .37138 Mdot
.49802 .72426 Mdot
.39557 .28354 Mdot
.51649 .84827 Mdot
.65334 .42709 Mdot
.34365 .77573 Mdot
.3733 .3652 Mdot
.53437 .67608 Mdot
.45827 .46873 Mdot
.40054 .41258 Mdot
.54282 .72198 Mdot
.33223 .64458 Mdot
.3554 .6145 Mdot
.61798 .37077 Mdot
.31118 .60853 Mdot
.5348 .68211 Mdot
.58829 .20685 Mdot
.37588 .40156 Mdot
.27961 .42562 Mdot
.70863 .62307 Mdot
.52858 .72803 Mdot
.60646 .35655 Mdot
.33427 .35658 Mdot
.52807 .74571 Mdot
.19637 .61881 Mdot
.31817 .2132 Mdot
.49709 .72332 Mdot
.38863 .40128 Mdot
.40099 .38154 Mdot
.62415 .45326 Mdot
.51928 .51842 Mdot
.49512 .71369 Mdot
.42923 .71059 Mdot
.70485 .47494 Mdot
.38945 .52908 Mdot
.7774 .35365 Mdot
.57202 .41884 Mdot
.56186 .4063 Mdot
.34644 .64794 Mdot
.61542 .3985 Mdot
.36238 .41461 Mdot
.5724 .35924 Mdot
.30635 .64341 Mdot
.48436 .6957 Mdot
.60351 .40672 Mdot
.70553 .62657 Mdot
.30718 .63746 Mdot
.32545 .65757 Mdot
.51447 .74017 Mdot
.36526 .39956 Mdot
.22622 .56303 Mdot
.51362 .7179 Mdot
.56406 .39042 Mdot
.39257 .50955 Mdot
.56555 .35713 Mdot
.41094 .60644 Mdot
.41197 .4113 Mdot
.53807 .70913 Mdot
.40648 .34388 Mdot
.34275 .63037 Mdot
.51495 .67097 Mdot
.61457 .43586 Mdot
.54231 .70197 Mdot
.45635 .62443 Mdot
.61925 .68936 Mdot
.35402 .41027 Mdot
.49539 .62297 Mdot
.37508 .40968 Mdot
.38774 .53059 Mdot
.75486 .48414 Mdot
.68468 .63364 Mdot
.51423 .68284 Mdot
.29122 .40538 Mdot
.53324 .7305 Mdot
.61262 .41005 Mdot
.58471 .41885 Mdot
.51298 .69259 Mdot
.6731 .63189 Mdot
.74328 .58406 Mdot
.72367 .65422 Mdot
.40864 .39405 Mdot
.498 .5895 Mdot
.42764 .1447 Mdot
.48425 .74975 Mdot
.32101 .62723 Mdot
.63925 .31358 Mdot
.59011 .45027 Mdot
.36317 .60908 Mdot
.35164 .65169 Mdot
.68985 .65085 Mdot
.52949 .73058 Mdot
.4232 .40466 Mdot
.32737 .60651 Mdot
.32895 .36077 Mdot
.70734 .54089 Mdot
.57008 .33898 Mdot
.57574 .49571 Mdot
.6214 .43797 Mdot
.54647 .53846 Mdot
.30283 .63537 Mdot
.5839 .39799 Mdot
.5083 .38113 Mdot
.34783 .64209 Mdot
.68085 .64951 Mdot
.35353 .32293 Mdot
.49813 .72825 Mdot
.46909 .87657 Mdot
.62878 .39602 Mdot
.60752 .39169 Mdot
.35827 .63435 Mdot
.55199 .30471 Mdot
.39924 .36076 Mdot
.36966 .40154 Mdot
.52232 .70994 Mdot
.4791 .52501 Mdot
.61998 .37035 Mdot
.62546 .41633 Mdot
.48936 .71509 Mdot
.38538 .50726 Mdot
.77274 .32798 Mdot
.59134 .41029 Mdot
.34807 .61888 Mdot
.44405 .62581 Mdot
.30303 .62988 Mdot
.5718 .46156 Mdot
.61115 .41671 Mdot
.62018 .43375 Mdot
.63428 .39602 Mdot
.32165 .61688 Mdot
.61074 .44254 Mdot
.5579 .34553 Mdot
.37476 .37789 Mdot
.56554 .41104 Mdot
.70708 .46984 Mdot
.59324 .40719 Mdot
.70516 .62363 Mdot
.45357 .48031 Mdot
.58338 .37274 Mdot
.56472 .40883 Mdot
.70161 .48135 Mdot
.6139 .38591 Mdot
.36252 .60988 Mdot
.3986 .37562 Mdot
.34388 .63131 Mdot
.32374 .63145 Mdot
.5337 .74127 Mdot
.65927 .6269 Mdot
.63758 .41547 Mdot
.6861 .64526 Mdot
.633 .44902 Mdot
.65166 .36765 Mdot
.61905 .5313 Mdot
.46053 .47585 Mdot
.70656 .59987 Mdot
.62174 .42299 Mdot
.52505 .71643 Mdot
.5392 .70756 Mdot
.4975 .61129 Mdot
.66501 .39306 Mdot
.32975 .60239 Mdot
.32208 .64292 Mdot
.71504 .66779 Mdot
.61918 .65714 Mdot
.69843 .6383 Mdot
.64473 .55212 Mdot
.53994 .41581 Mdot
.57273 .39125 Mdot
.67149 .39218 Mdot
.53082 .75051 Mdot
.3995 .51319 Mdot
.48556 .722 Mdot
.36487 .512 Mdot
.31717 .61503 Mdot
.62855 .38662 Mdot
.15497 .53083 Mdot
.41139 .39457 Mdot
.39906 .37525 Mdot
.30628 .64382 Mdot
.51051 .68034 Mdot
.66362 .38645 Mdot
.38103 .84039 Mdot
.38792 .41967 Mdot
.69111 .59703 Mdot
.60646 .37866 Mdot
.52135 .73682 Mdot
.39951 .40595 Mdot
.66728 .5986 Mdot
.63305 .40225 Mdot
.54279 .75172 Mdot
.58875 .39649 Mdot
.46058 .25412 Mdot
.37087 .3867 Mdot
.58918 .52083 Mdot
.37275 .34102 Mdot
.32598 .61446 Mdot
.34678 .6373 Mdot
.60833 .4178 Mdot
.42682 .86328 Mdot
.31977 .37984 Mdot
.36468 .64343 Mdot
.66598 .60233 Mdot
.39626 .50483 Mdot
.66303 .60733 Mdot
.5178 .69429 Mdot
.69572 .63562 Mdot
.52861 .74461 Mdot
.56196 .75669 Mdot
.41024 .42562 Mdot
.68557 .60478 Mdot
.60007 .28192 Mdot
.65458 .39111 Mdot
.70384 .64424 Mdot
.56676 .36934 Mdot
.62821 .45707 Mdot
.49291 .72644 Mdot
.68185 .64125 Mdot
.58239 .4425 Mdot
.24479 .41079 Mdot
.33577 .63886 Mdot
.33663 .60044 Mdot
.65107 .38582 Mdot
.5426 .68152 Mdot
.35162 .40568 Mdot
.58419 .54439 Mdot
.38529 .54163 Mdot
.62615 .41365 Mdot
.61153 .45172 Mdot
.35673 .35776 Mdot
.3981 .3529 Mdot
.6084 .42065 Mdot
.3679 .2916 Mdot
.61039 .4398 Mdot
.35772 .61701 Mdot
.40963 .39347 Mdot
.40183 .37944 Mdot
.53874 .68634 Mdot
.38415 .40994 Mdot
.52709 .37747 Mdot
.37896 .60453 Mdot
.59092 .34733 Mdot
.34187 .62763 Mdot
.53469 .77921 Mdot
.50622 .74607 Mdot
.2878 .40261 Mdot
.38387 .40918 Mdot
.54613 .41139 Mdot
.41357 .39899 Mdot
.70322 .60984 Mdot
.3995 .37022 Mdot
.35395 .3553 Mdot
.6049 .36899 Mdot
.59476 .44087 Mdot
.38557 .50991 Mdot
.52822 .52369 Mdot
.37507 .39114 Mdot
.5735 .45441 Mdot
.5482 .37611 Mdot
.58637 .42305 Mdot
.61149 .53884 Mdot
.39941 .34458 Mdot
.47895 .37329 Mdot
.39183 .5725 Mdot
.37323 .39404 Mdot
.33401 .21792 Mdot
.37834 .51289 Mdot
.37066 .5192 Mdot
.30544 .65502 Mdot
.59307 .41423 Mdot
.50545 .72062 Mdot
.56074 .4031 Mdot
.66829 .42107 Mdot
.58803 .37261 Mdot
.68587 .60296 Mdot
.61592 .36583 Mdot
.38535 .52611 Mdot
.51599 .72389 Mdot
.57735 .45438 Mdot
.60239 .41334 Mdot
.37184 .51883 Mdot
.39049 .33918 Mdot
.36801 .40537 Mdot
.37435 .55422 Mdot
.69445 .64868 Mdot
.31543 .64845 Mdot
.56278 .39286 Mdot
.52332 .71292 Mdot
.51031 .72683 Mdot
.41977 .38156 Mdot
.49104 .70609 Mdot
.31035 .64552 Mdot
.62261 .40871 Mdot
.32524 .61512 Mdot
.68634 .60292 Mdot
.38662 .40145 Mdot
.57059 .37374 Mdot
.56456 .4308 Mdot
.36266 .38196 Mdot
.60247 .44045 Mdot
.69116 .60124 Mdot
.54324 .74049 Mdot
.40218 .36838 Mdot
.32897 .62503 Mdot
.54232 .69101 Mdot
.55179 .41686 Mdot
.24859 .27999 Mdot
.61601 .40009 Mdot
.62695 .41617 Mdot
.34777 .44026 Mdot
.53994 .39633 Mdot
.5307 .73295 Mdot
.40869 .4058 Mdot
.58859 .46347 Mdot
.70236 .4836 Mdot
.65388 .63889 Mdot
.50034 .76143 Mdot
.61562 .38192 Mdot
.29824 .27761 Mdot
.54531 .38656 Mdot
.28873 .3934 Mdot
.61803 .53106 Mdot
.30605 .71078 Mdot
.57535 .4955 Mdot
.36098 .64772 Mdot
.38897 .50623 Mdot
.52062 .74417 Mdot
.54037 .29643 Mdot
.61483 .41624 Mdot
.59478 .23553 Mdot
.56775 .37672 Mdot
.35192 .61546 Mdot
.57496 .31069 Mdot
.49891 .69233 Mdot
.76964 .35038 Mdot
.57365 .41382 Mdot
.35598 .36226 Mdot
.54175 .67457 Mdot
.38494 .50367 Mdot
.58963 .44 Mdot
.70312 .63884 Mdot
.6852 .66536 Mdot
.52531 .38199 Mdot
.33992 .62928 Mdot
.57526 .40067 Mdot
.57984 .47302 Mdot
.54293 .82819 Mdot
.37827 .37079 Mdot
.32617 .63876 Mdot
.61952 .63513 Mdot
.58781 .42244 Mdot
.36366 .4033 Mdot
.39481 .37457 Mdot
.67939 .64571 Mdot
.29714 .68057 Mdot
.75404 .63498 Mdot
.16275 .45166 Mdot
.63816 .2414 Mdot
.53478 .74892 Mdot
.43791 .35289 Mdot
.56171 .41585 Mdot
.8103 .47277 Mdot
.32382 .62822 Mdot
.60703 .38898 Mdot
.59851 .24944 Mdot
.38418 .36749 Mdot
.58763 .40197 Mdot
.6782 .62788 Mdot
.24129 .60519 Mdot
.42532 .2911 Mdot
.25614 .3017 Mdot
.55287 .74276 Mdot
.63053 .36253 Mdot
.5407 .36266 Mdot
.38594 .53873 Mdot
.58107 .46259 Mdot
.53405 .72093 Mdot
.43713 .64561 Mdot
.66956 .61726 Mdot
.41038 .39803 Mdot
.3803 .50771 Mdot
.5672 .37682 Mdot
.57451 .34247 Mdot
.68201 .59745 Mdot
.58767 .43426 Mdot
.46946 .3259 Mdot
.37769 .49889 Mdot
.54703 .70372 Mdot
.35681 .363 Mdot
.61729 .44359 Mdot
.39404 .50463 Mdot
.59859 .36665 Mdot
.68459 .31911 Mdot
.59253 .37939 Mdot
.3022 .37132 Mdot
.36163 .38799 Mdot
.33378 .63158 Mdot
.62262 .36851 Mdot
.59494 .39816 Mdot
.5906 .64825 Mdot
.66233 .38675 Mdot
.57364 .38013 Mdot
.42237 .38856 Mdot
.41239 .39415 Mdot
.38442 .35409 Mdot
.53718 .68738 Mdot
.48553 .49931 Mdot
.3392 .61547 Mdot
.67083 .3924 Mdot
.3249 .60725 Mdot
.55995 .49156 Mdot
.67162 .60244 Mdot
.28016 .40119 Mdot
.61816 .41845 Mdot
.35676 .37242 Mdot
.50363 .16189 Mdot
.40907 .35461 Mdot
.35693 .56592 Mdot
.32646 .63042 Mdot
.37848 .38537 Mdot
.61726 .38684 Mdot
.51489 .51225 Mdot
.23747 .31834 Mdot
.35599 .60849 Mdot
.63999 .36373 Mdot
.54262 .76003 Mdot
.47969 .70177 Mdot
.35386 .21088 Mdot
.34249 .60539 Mdot
.2629 .63255 Mdot
.55296 .42594 Mdot
.40277 .40751 Mdot
.31587 .64564 Mdot
.36883 .62868 Mdot
.48972 .70659 Mdot
.56705 .43843 Mdot
.59296 .3988 Mdot
.37649 .5246 Mdot
.31455 .62736 Mdot
.61858 .48655 Mdot
.57796 .44758 Mdot
.3546 .46926 Mdot
.39485 .42756 Mdot
.69036 .78813 Mdot
.49558 .36949 Mdot
.5963 .24719 Mdot
.47738 .77373 Mdot
.40391 .36761 Mdot
.56957 .40454 Mdot
.66518 .38577 Mdot
.54162 .74614 Mdot
.62133 .40296 Mdot
.50875 .67668 Mdot
.3308 .61006 Mdot
.26884 .37694 Mdot
.45182 .56282 Mdot
.37835 .66303 Mdot
.61377 .39987 Mdot
.41903 .29276 Mdot
.68402 .60714 Mdot
.38071 .6288 Mdot
.40198 .35808 Mdot
.56733 .45789 Mdot
.522 .75571 Mdot
.5334 .68565 Mdot
.38746 .37272 Mdot
.31566 .55361 Mdot
.28631 .39661 Mdot
.63364 .41012 Mdot
.52658 .69353 Mdot
.43047 .49754 Mdot
.35485 .26343 Mdot
.31577 .65855 Mdot
.67017 .61437 Mdot
.52412 .74083 Mdot
.32717 .59852 Mdot
.63466 .45221 Mdot
.38577 .38239 Mdot
.34966 .3696 Mdot
.50657 .62537 Mdot
.49869 .72214 Mdot
.68761 .62655 Mdot
.4933 .61487 Mdot
.49897 .5969 Mdot
.67515 .61787 Mdot
.51161 .67347 Mdot
.41151 .37648 Mdot
.37199 .3614 Mdot
.39831 .37653 Mdot
.49787 .3345 Mdot
.40703 .41328 Mdot
.78268 .56801 Mdot
.57661 .4607 Mdot
.37113 .27383 Mdot
.55961 .44784 Mdot
.35198 .60107 Mdot
.36975 .38728 Mdot
.612 .52852 Mdot
.53658 .40081 Mdot
.24664 .31428 Mdot
.58487 .38579 Mdot
.45165 .61478 Mdot
.59429 .41491 Mdot
.46427 .29448 Mdot
.4309 .38614 Mdot
.61643 .43408 Mdot
.37977 .60293 Mdot
.70175 .61905 Mdot
.39728 .433 Mdot
.57289 .38347 Mdot
.2886 .52843 Mdot
.56585 .37012 Mdot
.28567 .36361 Mdot
.54958 .65045 Mdot
.71783 .63288 Mdot
.55648 .3602 Mdot
.5064 .75265 Mdot
.67709 .34595 Mdot
.38226 .27484 Mdot
.35428 .60775 Mdot
.40939 .28959 Mdot
.49388 .69338 Mdot
.57393 .30978 Mdot
.543 .43347 Mdot
.66904 .62276 Mdot
.34789 .32559 Mdot
.35963 .62017 Mdot
.6141 .42121 Mdot
.57389 .41118 Mdot
.39681 .66075 Mdot
.39842 .27132 Mdot
.67112 .45873 Mdot
.69164 .59348 Mdot
.42486 .28546 Mdot
.58048 .37653 Mdot
.5039 .76207 Mdot
.3973 .41273 Mdot
.58429 .31261 Mdot
.55818 .30751 Mdot
.58454 .45493 Mdot
.37992 .38119 Mdot
.37693 .40858 Mdot
.54602 .16229 Mdot
.66722 .61189 Mdot
.59038 .38023 Mdot
.50867 .63005 Mdot
.56469 .38616 Mdot
.34532 .61303 Mdot
.54185 .42295 Mdot
.50327 .7429 Mdot
.45625 .45917 Mdot
.53529 .68564 Mdot
.59442 .43085 Mdot
.3884 .39666 Mdot
.35913 .62899 Mdot
.31808 .73509 Mdot
.28838 .65535 Mdot
.78162 .56865 Mdot
.67893 .66563 Mdot
.70252 .63646 Mdot
.65971 .61603 Mdot
.32571 .66729 Mdot
.61987 .38653 Mdot
.54682 .5421 Mdot
.65357 .43281 Mdot
.59115 .41783 Mdot
.59247 .37704 Mdot
.28169 .62907 Mdot
.32774 .63093 Mdot
.50979 .73449 Mdot
.60882 .4213 Mdot
.57295 .45445 Mdot
.38238 .39336 Mdot
.69695 .63819 Mdot
.54713 .72839 Mdot
.70978 .63531 Mdot
.51963 .72151 Mdot
.42415 .16154 Mdot
.59575 .34038 Mdot
.70002 .61662 Mdot
.30478 .63021 Mdot
.36929 .35908 Mdot
.37291 .52648 Mdot
.51486 .6954 Mdot
.49756 .69449 Mdot
.60474 .44796 Mdot
.38564 .40427 Mdot
.37433 .40559 Mdot
.69496 .64308 Mdot
.32282 .64487 Mdot
.62108 .44596 Mdot
.59008 .44503 Mdot
.33701 .74808 Mdot
.5463 .73814 Mdot
.41013 .28338 Mdot
.32213 .4092 Mdot
.62487 .39385 Mdot
.36242 .40154 Mdot
.60299 .40084 Mdot
.42919 .5249 Mdot
.38636 .35262 Mdot
.54052 .40758 Mdot
.63913 .46043 Mdot
.5329 .74882 Mdot
.62668 .1969 Mdot
.64231 .40029 Mdot
.35551 .58571 Mdot
.56822 .4263 Mdot
.73062 .24098 Mdot
.52237 .164 Mdot
.57957 .36448 Mdot
.63081 .38685 Mdot
.1685 .42192 Mdot
.55437 .37032 Mdot
.38022 .52598 Mdot
.66922 .41838 Mdot
.35954 .40097 Mdot
.47165 .61283 Mdot
.5413 .53485 Mdot
.66352 .61697 Mdot
.52318 .71012 Mdot
.72573 .53607 Mdot
.66953 .642 Mdot
.37697 .36333 Mdot
.58212 .34087 Mdot
.3216 .40615 Mdot
.48686 .67667 Mdot
.55291 .45986 Mdot
.34814 .61355 Mdot
.53942 .53533 Mdot
.48997 .73202 Mdot
.32783 .6249 Mdot
.54459 .38692 Mdot
.55139 .79285 Mdot
.38196 .59997 Mdot
.55949 .16039 Mdot
.34648 .64726 Mdot
.33767 .63649 Mdot
.49882 .50218 Mdot
.66329 .61776 Mdot
.41578 .65989 Mdot
.5632 .33448 Mdot
.36305 .61466 Mdot
.75589 .40522 Mdot
.54982 .73788 Mdot
.4852 .52068 Mdot
.42885 .38232 Mdot
.62187 .34885 Mdot
.60391 .38232 Mdot
.33547 .64695 Mdot
.43538 .35374 Mdot
.59508 .63581 Mdot
.33803 .60768 Mdot
.52998 .38421 Mdot
.47297 .50979 Mdot
.39637 .51012 Mdot
.3766 .5152 Mdot
.67058 .59753 Mdot
.63767 .73419 Mdot
.35918 .388 Mdot
.6948 .59844 Mdot
.60386 .51565 Mdot
.58031 .38903 Mdot
.31689 .62063 Mdot
.37454 .51277 Mdot
.33163 .62345 Mdot
.68777 .61362 Mdot
.67694 .59818 Mdot
.37526 .37647 Mdot
.40269 .36238 Mdot
.31161 .3236 Mdot
.72485 .41322 Mdot
.55657 .4012 Mdot
.55056 .21226 Mdot
.39784 .35358 Mdot
.54292 .3032 Mdot
.672 .63727 Mdot
.68418 .6388 Mdot
.42915 .23192 Mdot
.55318 .41585 Mdot
.44558 .62394 Mdot
.58076 .37395 Mdot
.77327 .45503 Mdot
.56757 .37516 Mdot
.48997 .71065 Mdot
.57434 .41852 Mdot
.21899 .53906 Mdot
.57281 .45233 Mdot
.59359 .37524 Mdot
.50956 .70283 Mdot
.62875 .43307 Mdot
.49665 .7356 Mdot
.5706 .4004 Mdot
.65395 .59418 Mdot
.52292 .71258 Mdot
.66677 .58288 Mdot
.47244 .58346 Mdot
.38282 .51726 Mdot
.661 .61793 Mdot
.70683 .63386 Mdot
.68715 .54182 Mdot
.41234 .36914 Mdot
.54611 .32563 Mdot
.60808 .38005 Mdot
.55172 .70102 Mdot
.30847 .63304 Mdot
.58626 .45484 Mdot
.57544 .35742 Mdot
.62933 .43522 Mdot
.37644 .37981 Mdot
.52389 .67335 Mdot
.69495 .61671 Mdot
.54024 .70649 Mdot
.65871 .5891 Mdot
.51185 .7496 Mdot
.64765 .4086 Mdot
.63468 .44928 Mdot
.54703 .35759 Mdot
.57152 .24513 Mdot
.83745 .50459 Mdot
.3872 .37778 Mdot
.39297 .51361 Mdot
.67184 .60162 Mdot
.50401 .58498 Mdot
.35609 .38565 Mdot
.49676 .69719 Mdot
.58873 .39619 Mdot
.56095 .3397 Mdot
.62609 .34609 Mdot
.32714 .38284 Mdot
.69913 .58474 Mdot
.51936 .70014 Mdot
.39398 .52613 Mdot
.48199 .50138 Mdot
.43638 .42189 Mdot
.63593 .52304 Mdot
.59894 .39959 Mdot
.69562 .64377 Mdot
.39974 .40588 Mdot
.42357 .64726 Mdot
.33482 .64548 Mdot
.52323 .52096 Mdot
.61402 .39755 Mdot
.31309 .57099 Mdot
.38956 .39594 Mdot
.67524 .63015 Mdot
.33733 .64669 Mdot
.66522 .62048 Mdot
.39001 .49924 Mdot
.38459 .54803 Mdot
.58671 .43915 Mdot
.57899 .37333 Mdot
.31489 .61884 Mdot
.36122 .39154 Mdot
.64975 .60515 Mdot
.38855 .67032 Mdot
.5169 .69316 Mdot
.47834 .53874 Mdot
.40746 .40118 Mdot
.27376 .63687 Mdot
.53687 .69502 Mdot
.32142 .60379 Mdot
.55159 .53885 Mdot
.31771 .6526 Mdot
.58477 .37629 Mdot
.402 .3938 Mdot
.34973 .60527 Mdot
.35089 .74196 Mdot
.30089 .30269 Mdot
.32196 .34971 Mdot
.60483 .43304 Mdot
.27531 .39414 Mdot
.27824 .56678 Mdot
.44133 .35235 Mdot
.32786 .60704 Mdot
.60949 .40904 Mdot
.63283 .41318 Mdot
.57405 .41495 Mdot
.33611 .6409 Mdot
.27947 .68425 Mdot
.51486 .68505 Mdot
.58302 .40032 Mdot
.70825 .62049 Mdot
.50492 .74175 Mdot
.48029 .72079 Mdot
.52658 .74004 Mdot
.40136 .35449 Mdot
.5789 .33947 Mdot
.67472 .38292 Mdot
.59763 .18621 Mdot
.33582 .63446 Mdot
.38296 .5177 Mdot
.62814 .41617 Mdot
.77223 .57218 Mdot
.37235 .3593 Mdot
.50795 .69776 Mdot
.60654 .39026 Mdot
.53181 .63891 Mdot
.3873 .49223 Mdot
.51137 .71101 Mdot
.39745 .35639 Mdot
.45093 .36433 Mdot
.62157 .40562 Mdot
.5644 .42309 Mdot
.36454 .37092 Mdot
.25983 .59956 Mdot
.47802 .49982 Mdot
.60264 .40397 Mdot
.33025 .62998 Mdot
.47372 .86553 Mdot
.54341 .40955 Mdot
.35882 .33204 Mdot
.39987 .51717 Mdot
.38206 .46796 Mdot
.38637 .28988 Mdot
.66294 .41908 Mdot
.24811 .37718 Mdot
.77281 .60195 Mdot
.2712 .33578 Mdot
.77904 .4738 Mdot
.36947 .68196 Mdot
.48357 .14351 Mdot
.36661 .59351 Mdot
.46107 .27844 Mdot
.18508 .60665 Mdot
.26898 .6075 Mdot
.58526 .66992 Mdot
.3629 .71637 Mdot
.54838 .78915 Mdot
.77461 .3433 Mdot
.498 .74681 Mdot
.79055 .45729 Mdot
.57842 .37037 Mdot
.2616 .58485 Mdot
.45354 .29486 Mdot
.82568 .56449 Mdot
.28953 .41283 Mdot
.51438 .63112 Mdot
.23063 .30809 Mdot
.3106 .43704 Mdot
.36557 .2296 Mdot
.63932 .28872 Mdot
.66751 .74488 Mdot
.50379 .59177 Mdot
.74026 .54672 Mdot
.41966 .30034 Mdot
.21212 .50492 Mdot
.39015 .61657 Mdot
.5019 .18999 Mdot
.56573 .82176 Mdot
.53272 .70799 Mdot
.3942 .41366 Mdot
.41083 .67175 Mdot
.34407 .25115 Mdot
.35454 .57361 Mdot
.24794 .37654 Mdot
.34902 .45082 Mdot
.46251 .29077 Mdot
.59237 .51987 Mdot
.46361 .24776 Mdot
.75905 .62476 Mdot
.77183 .36433 Mdot
.3334 .37955 Mdot
.37803 .72886 Mdot
.50971 .58644 Mdot
.68548 .55901 Mdot
.47938 .30992 Mdot
.6749 .59248 Mdot
.66215 .59633 Mdot
.39187 .35447 Mdot
.35567 .25771 Mdot
.37608 .49839 Mdot
.60577 .51408 Mdot
.51483 .75721 Mdot
.43256 .53101 Mdot
.24151 .59211 Mdot
.29198 .55663 Mdot
.67585 .23319 Mdot
.26707 .26638 Mdot
.73536 .45705 Mdot
.43085 .63504 Mdot
.32398 .58203 Mdot
.75388 .56673 Mdot
.6909 .4211 Mdot
.74003 .41816 Mdot
.67918 .31348 Mdot
.194 .35975 Mdot
.31123 .51758 Mdot
.22553 .3036 Mdot
.33814 .37887 Mdot
.51382 .37516 Mdot
.42385 .59577 Mdot
.64382 .25202 Mdot
.69082 .51331 Mdot
.26354 .27974 Mdot
.71291 .64726 Mdot
.43092 .39841 Mdot
.26992 .60776 Mdot
.4647 .32604 Mdot
.72822 .58616 Mdot
.67276 .67007 Mdot
.57732 .31527 Mdot
.1884 .34691 Mdot
.24484 .38446 Mdot
.46691 .16779 Mdot
.35694 .47677 Mdot
.48249 .66955 Mdot
.4819 .729 Mdot
.36984 .62914 Mdot
.33652 .24109 Mdot
.3982 .39046 Mdot
.61256 .18503 Mdot
.29881 .32426 Mdot
.68183 .34751 Mdot
.1754 .36272 Mdot
.75268 .31904 Mdot
.36839 .27884 Mdot
.81357 .52855 Mdot
.41327 .83203 Mdot
.68385 .45509 Mdot
.28901 .66529 Mdot
.52256 .76692 Mdot
.2995 .36109 Mdot
.32732 .2457 Mdot
.75264 .38942 Mdot
.16035 .50564 Mdot
.60681 .51273 Mdot
.49643 .77841 Mdot
.33107 .40092 Mdot
.59445 .69016 Mdot
.64987 .55863 Mdot
.23027 .29883 Mdot
.43547 .28848 Mdot
.4606 .8557 Mdot
.76543 .48452 Mdot
.54792 .30826 Mdot
.25755 .41227 Mdot
.57088 .72741 Mdot
.70992 .37837 Mdot
.29999 .53188 Mdot
.62081 .35511 Mdot
.66034 .52457 Mdot
.61521 .29711 Mdot
.74189 .63267 Mdot
.48008 .49282 Mdot
.30796 .49382 Mdot
.73837 .49288 Mdot
.2712 .68795 Mdot
.53986 .32539 Mdot
.38177 .34663 Mdot
.73533 .43072 Mdot
.75673 .46378 Mdot
.3473 .4925 Mdot
.62027 .63268 Mdot
.45544 .16791 Mdot
.60863 .63763 Mdot
.66289 .4249 Mdot
.46036 .27265 Mdot
.42381 .30363 Mdot
.7581 .42589 Mdot
.6491 .3944 Mdot
.64824 .21904 Mdot
.36409 .46913 Mdot
.54674 .24256 Mdot
.71477 .50297 Mdot
.56382 .24403 Mdot
.31645 .28033 Mdot
.41874 .58668 Mdot
.28475 .66767 Mdot
.4086 .33106 Mdot
.19095 .34546 Mdot
.50752 .73852 Mdot
.74689 .39947 Mdot
.36782 .59251 Mdot
.3394 .74226 Mdot
.37458 .68621 Mdot
.59809 .63481 Mdot
.35441 .22324 Mdot
.29706 .56597 Mdot
.56317 .69664 Mdot
.20136 .4878 Mdot
.42698 .4861 Mdot
.54378 .21436 Mdot
.50462 .40643 Mdot
.68413 .32659 Mdot
.69035 .60089 Mdot
.5732 .27592 Mdot
.39993 .5764 Mdot
.72805 .67528 Mdot
.6608 .41359 Mdot
.51173 .61083 Mdot
.38643 .53264 Mdot
.52212 .53504 Mdot
.42158 .16115 Mdot
.50331 .41183 Mdot
.75109 .32274 Mdot
.28436 .57384 Mdot
.53793 .54211 Mdot
.66843 .55927 Mdot
.44525 .42584 Mdot
.21681 .31086 Mdot
.38165 .1945 Mdot
.2641 .55195 Mdot
.27066 .39002 Mdot
.83241 .37527 Mdot
.30397 .7063 Mdot
.68567 .25982 Mdot
.37034 .59394 Mdot
.8065 .72751 Mdot
.54008 .70146 Mdot
.81583 .46884 Mdot
.6373 .25296 Mdot
.56527 .64105 Mdot
.34169 .25416 Mdot
.43909 .31715 Mdot
.63878 .59731 Mdot
.36638 .34529 Mdot
.6543 .40489 Mdot
.27819 .27464 Mdot
.19846 .34065 Mdot
.27318 .27892 Mdot
.34219 .5571 Mdot
.27906 .29758 Mdot
.16721 .40607 Mdot
.78448 .56766 Mdot
.40558 .64351 Mdot
.5496 .44428 Mdot
.73264 .37502 Mdot
.73716 .30524 Mdot
.72337 .63857 Mdot
.67585 .46451 Mdot
.33276 .38226 Mdot
.1641 .39858 Mdot
.4243 .15853 Mdot
.4644 .22647 Mdot
.37757 .22545 Mdot
.44966 .65548 Mdot
.73346 .3998 Mdot
.37274 .21568 Mdot
.21572 .47419 Mdot
.34283 .45568 Mdot
.15747 .43133 Mdot
.75483 .47458 Mdot
.3616 .71953 Mdot
.256 .53635 Mdot
.71784 .28486 Mdot
.2551 .40664 Mdot
.40415 .67759 Mdot
.70219 .37511 Mdot
.36119 .43111 Mdot
.59886 .6383 Mdot
.20828 .49735 Mdot
.43956 .62653 Mdot
.71304 .48732 Mdot
.48562 .69747 Mdot
.74645 .3865 Mdot
.60552 .5628 Mdot
.40581 .64564 Mdot
.70819 .53514 Mdot
.75809 .38724 Mdot
.27544 .51236 Mdot
.2756 .28962 Mdot
.2859 .57359 Mdot
.4061 .83441 Mdot
.28161 .44123 Mdot
.62432 .29916 Mdot
.62962 .43206 Mdot
.33336 .25228 Mdot
.35543 .18712 Mdot
.3587 .21786 Mdot
.34285 .54427 Mdot
.49409 .64498 Mdot
.31104 .60809 Mdot
.74177 .55899 Mdot
.57378 .63584 Mdot
.31169 .41211 Mdot
.55664 .56895 Mdot
.36721 .59913 Mdot
.24227 .61048 Mdot
.30994 .32781 Mdot
.7691 .57353 Mdot
.48541 .19517 Mdot
.6427 .48065 Mdot
.36004 .26354 Mdot
.35472 .35911 Mdot
.32624 .55889 Mdot
.74179 .41291 Mdot
.51282 .74072 Mdot
.34661 .7507 Mdot
.42155 .34298 Mdot
.51007 .3773 Mdot
.44011 .66157 Mdot
.31732 .36208 Mdot
.59244 .24356 Mdot
.55553 .68422 Mdot
.45334 .15042 Mdot
.66908 .23445 Mdot
.37417 .21391 Mdot
.73729 .44228 Mdot
.36306 .74624 Mdot
.50541 .52592 Mdot
.3104 .59588 Mdot
.29761 .42344 Mdot
.50016 .56241 Mdot
.74208 .43358 Mdot
.35514 .27585 Mdot
.39864 .60839 Mdot
.66806 .4059 Mdot
.4938 .16104 Mdot
.76939 .55436 Mdot
.50643 .53753 Mdot
.39664 .45097 Mdot
.39124 .42013 Mdot
.84497 .49205 Mdot
.22003 .52042 Mdot
.67758 .36246 Mdot
.26651 .3998 Mdot
.32264 .66261 Mdot
.37896 .35113 Mdot
.75979 .3791 Mdot
.62372 .68902 Mdot
.32419 .31288 Mdot
.43646 .59095 Mdot
.35154 .24416 Mdot
.46634 .57188 Mdot
.26584 .38697 Mdot
.23184 .3635 Mdot
.48749 .85665 Mdot
.33911 .37726 Mdot
.42416 .63536 Mdot
.42866 .65601 Mdot
.34021 .40091 Mdot
.32963 .36985 Mdot
.42963 .2923 Mdot
.30726 .2454 Mdot
.48618 .60619 Mdot
.20972 .46685 Mdot
.54413 .54196 Mdot
.59378 .67363 Mdot
.40995 .62312 Mdot
.71769 .53484 Mdot
.22101 .41128 Mdot
.42823 .20626 Mdot
.28492 .75396 Mdot
.63964 .48759 Mdot
.81308 .45937 Mdot
.74269 .56012 Mdot
.64146 .29146 Mdot
.47894 .30663 Mdot
.33281 .45544 Mdot
.56336 .40009 Mdot
.27825 .25362 Mdot
.31448 .50922 Mdot
.65062 .54443 Mdot
.56583 .7557 Mdot
.54588 .40005 Mdot
.55328 .35519 Mdot
.36739 .21873 Mdot
.37553 .45978 Mdot
.22943 .69117 Mdot
.77147 .47299 Mdot
.65825 .31529 Mdot
.36095 .28109 Mdot
.74895 .3217 Mdot
.42481 .57428 Mdot
.28158 .33699 Mdot
.60477 .56806 Mdot
.7352 .29742 Mdot
.20303 .44102 Mdot
.20717 .52193 Mdot
.27618 .43106 Mdot
.17355 .39463 Mdot
.63697 .3154 Mdot
.36602 .49749 Mdot
.41708 .67402 Mdot
.62994 .40644 Mdot
.3164 .55254 Mdot
.27548 .41353 Mdot
.59511 .7551 Mdot
.69443 .41224 Mdot
.34927 .18927 Mdot
.64743 .4651 Mdot
.33786 .52976 Mdot
.21929 .65661 Mdot
.27789 .77175 Mdot
.21407 .53563 Mdot
.23386 .29502 Mdot
.20092 .50929 Mdot
.25828 .39392 Mdot
.31807 .66349 Mdot
.49094 .57789 Mdot
.57891 .22318 Mdot
.31423 .23645 Mdot
.6497 .71723 Mdot
.31101 .69442 Mdot
.54958 .19322 Mdot
.30962 .23704 Mdot
.65094 .45537 Mdot
.8365 .47116 Mdot
.4937 .66217 Mdot
.76757 .31321 Mdot
.68891 .24923 Mdot
.39729 .44495 Mdot
.76048 .4078 Mdot
.82406 .4468 Mdot
.81297 .57092 Mdot
.6794 .249 Mdot
.70752 .32847 Mdot
.39045 .46128 Mdot
.73121 .44761 Mdot
.29334 .37454 Mdot
.79579 .36204 Mdot
.41384 .61965 Mdot
.38329 .48628 Mdot
.38854 .54466 Mdot
.30067 .3587 Mdot
.27385 .49565 Mdot
.4319 .61346 Mdot
.44925 .46724 Mdot
.33227 .27266 Mdot
.50711 .88137 Mdot
.18768 .51146 Mdot
.35037 .31878 Mdot
.20903 .33278 Mdot
.34617 .46728 Mdot
.51209 .57747 Mdot
.48592 .31569 Mdot
.75683 .5572 Mdot
.55417 .67542 Mdot
.58714 .37237 Mdot
.30196 .2477 Mdot
.55739 .6824 Mdot
.23986 .30504 Mdot
.56854 .16204 Mdot
.39235 .22649 Mdot
.51449 .43034 Mdot
.52187 .76912 Mdot
.7439 .34486 Mdot
.74284 .35282 Mdot
.20898 .35083 Mdot
.80736 .44452 Mdot
.48866 .54814 Mdot
.45566 .59078 Mdot
.44839 .56885 Mdot
.65999 .33812 Mdot
.74548 .30904 Mdot
.4214 .44738 Mdot
.71896 .5112 Mdot
.25405 .54786 Mdot
.75101 .40975 Mdot
.39082 .28817 Mdot
.73082 .55063 Mdot
.61278 .61245 Mdot
.64127 .59722 Mdot
.55013 .73201 Mdot
.15428 .47619 Mdot
.31297 .45611 Mdot
.63631 .21114 Mdot
.41021 .83426 Mdot
.3033 .53273 Mdot
.79255 .44885 Mdot
.38438 .57598 Mdot
.6921 .44746 Mdot
.661 .73714 Mdot
.74122 .50678 Mdot
.41521 .28789 Mdot
.28829 .3882 Mdot
.48304 .37314 Mdot
.33973 .22923 Mdot
.71155 .49382 Mdot
.16484 .57036 Mdot
.4487 .67802 Mdot
.57177 .27097 Mdot
.39158 .26151 Mdot
.36916 .8164 Mdot
.51044 .53901 Mdot
.18864 .34842 Mdot
.41016 .3538 Mdot
.26453 .26945 Mdot
.3395 .65063 Mdot
.58029 .79556 Mdot
.32945 .44007 Mdot
.6424 .54661 Mdot
.6155 .54467 Mdot
.52588 .15882 Mdot
.27733 .58816 Mdot
.2864 .55971 Mdot
.60772 .64371 Mdot
.48542 .7261 Mdot
.46445 .52829 Mdot
.21401 .46064 Mdot
.15679 .48153 Mdot
.61589 .45238 Mdot
.45966 .71618 Mdot
.75404 .35552 Mdot
.30678 .59819 Mdot
.3632 .46186 Mdot
.30431 .41663 Mdot
.38822 .30815 Mdot
.73161 .40078 Mdot
.17283 .38982 Mdot
.31948 .41789 Mdot
.57644 .61705 Mdot
.57777 .30512 Mdot
.39484 .62192 Mdot
.2834 .7165 Mdot
.23355 .39598 Mdot
.45256 .57778 Mdot
.48038 .50493 Mdot
.73759 .45796 Mdot
.39338 .15084 Mdot
.19639 .35069 Mdot
.33354 .78082 Mdot
.53752 .54473 Mdot
.39408 .33724 Mdot
.74086 .53193 Mdot
.16197 .56494 Mdot
.7695 .31038 Mdot
.26861 .53266 Mdot
.75113 .40439 Mdot
.58892 .74554 Mdot
.82449 .46619 Mdot
.50315 .55345 Mdot
.39338 .2608 Mdot
.61746 .23434 Mdot
.38501 .55398 Mdot
.56854 .70695 Mdot
.57072 .54629 Mdot
.38473 .66874 Mdot
.39276 .4611 Mdot
.27815 .58877 Mdot
.16529 .57154 Mdot
.80545 .431 Mdot
.56693 .31095 Mdot
.17475 .57907 Mdot
.40111 .42863 Mdot
.427 .6581 Mdot
.30887 .74397 Mdot
.54842 .54833 Mdot
.54065 .72097 Mdot
.68493 .42795 Mdot
.47023 .51237 Mdot
.19669 .4871 Mdot
.56417 .78172 Mdot
.6832 .65271 Mdot
.34283 .3496 Mdot
.8174 .44259 Mdot
.34837 .39808 Mdot
.42485 .14518 Mdot
.21775 .47115 Mdot
.36014 .27123 Mdot
.19244 .45012 Mdot
.39256 .71628 Mdot
.41622 .84053 Mdot
.36798 .22873 Mdot
.70147 .48398 Mdot
.34294 .353 Mdot
.34451 .3754 Mdot
.2079 .42629 Mdot
.32271 .57298 Mdot
.36095 .24542 Mdot
.75449 .32891 Mdot
.36671 .74884 Mdot
.3671 .41436 Mdot
.45714 .59704 Mdot
.3668 .31847 Mdot
.43518 .15258 Mdot
.53978 .71395 Mdot
.19437 .33652 Mdot
.49463 .3688 Mdot
.27236 .71627 Mdot
.30365 .38106 Mdot
.46028 .45868 Mdot
.51272 .54757 Mdot
.35983 .73742 Mdot
.66685 .41584 Mdot
.65869 .31677 Mdot
.40523 .36203 Mdot
.36894 .68723 Mdot
.69455 .63772 Mdot
.64002 .65821 Mdot
.34071 .58594 Mdot
.6202 .27541 Mdot
.73231 .28598 Mdot
.34941 .36569 Mdot
.44668 .67182 Mdot
.43133 .69248 Mdot
.63669 .46097 Mdot
.72689 .33884 Mdot
.1618 .44379 Mdot
.36798 .23277 Mdot
.40581 .35001 Mdot
.34366 .79339 Mdot
.72367 .66154 Mdot
.46696 .15084 Mdot
.43742 .34249 Mdot
.75028 .3496 Mdot
.60948 .28957 Mdot
.38781 .19926 Mdot
.38715 .2901 Mdot
.28556 .35083 Mdot
.73792 .4277 Mdot
.59398 .64068 Mdot
.75659 .38437 Mdot
.38634 .30715 Mdot
.45932 .55752 Mdot
.76817 .32079 Mdot
.58378 .75222 Mdot
.46292 .25275 Mdot
.68558 .39873 Mdot
.30606 .37429 Mdot
.74438 .31838 Mdot
.34513 .34481 Mdot
.65093 .61895 Mdot
.51388 .19564 Mdot
.33408 .44714 Mdot
.33336 .24431 Mdot
.34635 .4942 Mdot
.75666 .35191 Mdot
.4489 .5626 Mdot
.78006 .52749 Mdot
.48857 .37533 Mdot
.65655 .51365 Mdot
.5879 .35319 Mdot
.60933 .30064 Mdot
.57326 .57423 Mdot
.54177 .16753 Mdot
.66029 .32759 Mdot
.30048 .26039 Mdot
.44708 .15794 Mdot
.26599 .3344 Mdot
.44048 .64055 Mdot
.37277 .41108 Mdot
.20922 .32322 Mdot
.73163 .33287 Mdot
.29621 .38135 Mdot
.69435 .25518 Mdot
.84608 .48567 Mdot
.17876 .59808 Mdot
.32376 .48597 Mdot
.31478 .3693 Mdot
.62454 .19566 Mdot
.31535 .51647 Mdot
.83078 .45635 Mdot
.4202 .2886 Mdot
.34185 .43438 Mdot
.17045 .371 Mdot
.66224 .26745 Mdot
.28906 .55385 Mdot
.38917 .26727 Mdot
.35651 .30638 Mdot
.72692 .32011 Mdot
.67309 .39231 Mdot
.50749 .7515 Mdot
.55576 .64525 Mdot
.76056 .41617 Mdot
.40237 .31824 Mdot
.751 .33358 Mdot
.74897 .35655 Mdot
.79429 .46318 Mdot
.36453 .74039 Mdot
.17943 .59832 Mdot
.35006 .28794 Mdot
.55206 .34848 Mdot
.34485 .34278 Mdot
.66061 .62933 Mdot
.76554 .49251 Mdot
.57287 .4501 Mdot
.56329 .52856 Mdot
.60176 .31299 Mdot
.29393 .24518 Mdot
.60133 .66919 Mdot
.38673 .63622 Mdot
.3762 .41391 Mdot
.30138 .36336 Mdot
.41981 .55653 Mdot
.26778 .60985 Mdot
.74608 .33332 Mdot
.31709 .31449 Mdot
.25626 .3714 Mdot
.29454 .54738 Mdot
.73164 .47812 Mdot
.75849 .63492 Mdot
.3466 .60227 Mdot
.59183 .23842 Mdot
.20516 .36621 Mdot
.31607 .54042 Mdot
.426 .40413 Mdot
.25277 .52105 Mdot
.46202 .56005 Mdot
.35927 .51976 Mdot
.27909 .58317 Mdot
.40206 .59168 Mdot
.41549 .22614 Mdot
.23105 .37529 Mdot
.54519 .75737 Mdot
.76403 .46573 Mdot
.22689 .51375 Mdot
.74875 .33077 Mdot
.63462 .4643 Mdot
.31293 .25997 Mdot
.64108 .54446 Mdot
.73407 .65277 Mdot
.57375 .43623 Mdot
.674 .29586 Mdot
.36658 .21833 Mdot
.24619 .53715 Mdot
.70466 .3829 Mdot
.43597 .37706 Mdot
.66853 .23167 Mdot
.54086 .66056 Mdot
.54531 .6666 Mdot
.81961 .5048 Mdot
.4574 .43396 Mdot
.57088 .63295 Mdot
.28087 .67529 Mdot
.65909 .43846 Mdot
.75719 .64283 Mdot
.44262 .58802 Mdot
.58448 .23457 Mdot
.68602 .26327 Mdot
.15843 .4606 Mdot
.43312 .5843 Mdot
.67614 .23175 Mdot
.60543 .22879 Mdot
.34188 .43206 Mdot
.81101 .43302 Mdot
.67419 .4647 Mdot
.64988 .3975 Mdot
.65099 .61946 Mdot
.40562 .42146 Mdot
.16799 .43752 Mdot
.69679 .3538 Mdot
.73046 .60232 Mdot
.6312 .57315 Mdot
.42602 .60224 Mdot
.50116 .79523 Mdot
.36683 .47184 Mdot
.62641 .19603 Mdot
.74161 .41403 Mdot
.29072 .63686 Mdot
.19971 .48688 Mdot
.69785 .42051 Mdot
.30573 .26145 Mdot
.58311 .58666 Mdot
.35528 .23389 Mdot
.35539 .54879 Mdot
.59016 .25011 Mdot
.47254 .15898 Mdot
.67599 .52023 Mdot
.64641 .5158 Mdot
.42788 .4369 Mdot
.65492 .49324 Mdot
.37238 .52582 Mdot
.6154 .66604 Mdot
.78763 .36822 Mdot
.15864 .52549 Mdot
.26227 .67746 Mdot
.66897 .44133 Mdot
.74031 .52668 Mdot
.22185 .39134 Mdot
.51059 .58067 Mdot
.629 .56352 Mdot
.41624 .67935 Mdot
.5647 .69561 Mdot
.48019 .86751 Mdot
.28459 .25067 Mdot
.57151 .43459 Mdot
.60142 .55265 Mdot
.68894 .67505 Mdot
.51319 .67564 Mdot
.47237 .19539 Mdot
.16704 .43215 Mdot
.35755 .60738 Mdot
.38111 .80185 Mdot
.28401 .67646 Mdot
.53363 .16164 Mdot
.33193 .76559 Mdot
.38382 .62375 Mdot
.42317 .14495 Mdot
.26868 .54713 Mdot
.46132 .39508 Mdot
.48908 .87028 Mdot
.51053 .16198 Mdot
.61584 .29365 Mdot
.51119 .64595 Mdot
.28943 .25774 Mdot
.51066 .54653 Mdot
.49401 .64089 Mdot
.667 .26472 Mdot
.74186 .41973 Mdot
.7687 .47109 Mdot
.31838 .67632 Mdot
.58464 .20897 Mdot
.84933 .54937 Mdot
.3955 .7159 Mdot
.36405 .82727 Mdot
.37666 .23258 Mdot
.23741 .34102 Mdot
.21324 .53046 Mdot
.60096 .74608 Mdot
.32609 .25639 Mdot
.74577 .36944 Mdot
.66923 .28475 Mdot
.63298 .71365 Mdot
.67405 .52627 Mdot
.75231 .54741 Mdot
.36034 .52962 Mdot
.38599 .21529 Mdot
.37169 .73585 Mdot
.7099 .40573 Mdot
.75125 .38526 Mdot
.62052 .24265 Mdot
.65029 .51357 Mdot
.21869 .35054 Mdot
.72515 .32488 Mdot
.74334 .44483 Mdot
.37269 .70377 Mdot
.66266 .59464 Mdot
.17803 .41697 Mdot
.4231 .50764 Mdot
.60521 .29394 Mdot
.22127 .66349 Mdot
.22995 .30027 Mdot
.67392 .46543 Mdot
.54079 .41848 Mdot
.48819 .14263 Mdot
.45997 .67078 Mdot
.68136 .25861 Mdot
.24049 .57767 Mdot
.77619 .4672 Mdot
.63511 .32041 Mdot
.56525 .37442 Mdot
.79729 .53788 Mdot
.34161 .42029 Mdot
.62184 .23963 Mdot
.33447 .7575 Mdot
.74079 .44045 Mdot
.62608 .28133 Mdot
.28349 .75172 Mdot
.42535 .32968 Mdot
.35324 .39516 Mdot
.29067 .25346 Mdot
.48997 .17951 Mdot
.63966 .30066 Mdot
.37479 .25887 Mdot
.57923 .59747 Mdot
.7539 .64647 Mdot
.54704 .32611 Mdot
.50734 .52774 Mdot
.76242 .41291 Mdot
.17342 .58138 Mdot
.56868 .22068 Mdot
.18566 .34687 Mdot
.37697 .19968 Mdot
.35834 .40794 Mdot
.6515 .26173 Mdot
.54493 .55134 Mdot
.26165 .34356 Mdot
.34839 .73194 Mdot
.34668 .74606 Mdot
.83814 .55531 Mdot
.65365 .66609 Mdot
.58188 .36527 Mdot
.342 .55617 Mdot
.34229 .22981 Mdot
.84416 .53426 Mdot
.33447 .23563 Mdot
.6131 .30385 Mdot
.6317 .42763 Mdot
.28629 .78374 Mdot
.26135 .38973 Mdot
.63646 .43435 Mdot
.65735 .34881 Mdot
.66497 .34687 Mdot
.57045 .38214 Mdot
.3122 .57856 Mdot
.75568 .56193 Mdot
.77627 .45262 Mdot
.30266 .25367 Mdot
.38219 .42187 Mdot
.5156 .54518 Mdot
.37562 .61038 Mdot
.586 .53414 Mdot
.54678 .48795 Mdot
.33625 .66148 Mdot
.78018 .44104 Mdot
.46788 .7588 Mdot
.71418 .5736 Mdot
.31022 .37239 Mdot
.44954 .44702 Mdot
.30959 .32219 Mdot
.79508 .43372 Mdot
.27783 .64526 Mdot
.81128 .57514 Mdot
.75608 .36165 Mdot
.50407 .35395 Mdot
.36297 .48743 Mdot
.83519 .38778 Mdot
.5056 .54185 Mdot
.32596 .5668 Mdot
.59035 .48849 Mdot
.47409 .37118 Mdot
.39145 .23887 Mdot
.69031 .66687 Mdot
.38476 .53626 Mdot
.58481 .30701 Mdot
.34077 .25375 Mdot
.30746 .64664 Mdot
.37655 .16503 Mdot
.54822 .46683 Mdot
.47103 .20324 Mdot
.29444 .30062 Mdot
.42149 .64151 Mdot
.41505 .29046 Mdot
.58515 .35192 Mdot
.56335 .61029 Mdot
.46448 .75096 Mdot
.35969 .32517 Mdot
.40801 .6253 Mdot
.24409 .36501 Mdot
.80866 .45804 Mdot
.43449 .21044 Mdot
.59091 .38171 Mdot
.70313 .65122 Mdot
.51877 .52741 Mdot
.60589 .72953 Mdot
.49312 .77517 Mdot
.34823 .45925 Mdot
.79284 .43642 Mdot
.7709 .47411 Mdot
.40117 .27249 Mdot
.24955 .29248 Mdot
.68712 .39226 Mdot
.38698 .2317 Mdot
.60927 .6022 Mdot
.28157 .49469 Mdot
.72763 .34298 Mdot
.17333 .57311 Mdot
.6406 .31284 Mdot
.67945 .39357 Mdot
.38639 .17682 Mdot
.37061 .22451 Mdot
.35718 .67852 Mdot
.28565 .38197 Mdot
.78069 .36023 Mdot
.61678 .54528 Mdot
.49424 .8752 Mdot
.3421 .73448 Mdot
.40482 .15548 Mdot
.39989 .63676 Mdot
.57198 .48025 Mdot
.44091 .42974 Mdot
.65543 .4068 Mdot
.50707 .71747 Mdot
.25563 .3408 Mdot
.42139 .4413 Mdot
.63102 .50321 Mdot
.55827 .34893 Mdot
.47894 .6361 Mdot
.34475 .33783 Mdot
.15814 .53491 Mdot
.48115 .69438 Mdot
.57652 .61319 Mdot
.2513 .67733 Mdot
.46665 .75537 Mdot
.8439 .46883 Mdot
.21021 .34657 Mdot
.29853 .42245 Mdot
.44567 .585 Mdot
.53484 .8288 Mdot
.38521 .3349 Mdot
.32487 .37461 Mdot
.32284 .59009 Mdot
.78445 .53282 Mdot
.33338 .53919 Mdot
.19737 .61927 Mdot
.38848 .19589 Mdot
.63389 .46405 Mdot
.50908 .89477 Mdot
.75315 .37172 Mdot
.55261 .57805 Mdot
.33103 .54589 Mdot
.31072 .24527 Mdot
.56805 .753 Mdot
.56143 .16126 Mdot
.21378 .50194 Mdot
.42138 .32956 Mdot
.77443 .54935 Mdot
.34597 .79391 Mdot
.45082 .60373 Mdot
.36703 .82896 Mdot
.26359 .41258 Mdot
.73944 .5461 Mdot
.24093 .53602 Mdot
.34074 .36483 Mdot
.66182 .32085 Mdot
.22183 .46262 Mdot
.68265 .44812 Mdot
.44564 .36689 Mdot
.24668 .38165 Mdot
.75958 .60978 Mdot
.34587 .7099 Mdot
.2686 .381 Mdot
.32363 .58511 Mdot
.42058 .43791 Mdot
.7732 .37641 Mdot
.45864 .70276 Mdot
.48967 .6911 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Iooooo`Co00000oooool2o`00
0003ooooool0003o00000:Cooooo000Looooo`03o`000?oooooooooo08Kooooo0ol0000@ooooo`Co
00000oooool2o`000003ooooool0003o00000:Cooooo000Looooo`03o`000?oooooooooo08Kooooo
0ol00004ooooo`;o000000?oooooo`000?l000005Oooool2o`000:3ooooo000Looooo`;o0000OOoo
ool2o`0000cooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l0000Aooooo`;o0000
X?ooool001cooooo00?o0000ooooooooool0O?ooool6o`0000Sooooo0_l00008ooooo`;o0000/ooo
ool001cooooo00?o0000ooooooooool0O_ooool4o`0000Cooooo0_l00005ooooo`;o00001_ooool3
o`000003ooooool0003o000000;o00002_ooool2o`000:3ooooo000Looooo`03o`000?oooooooooo
07Oooooo0_l0000<ooooo`Co00001?ooool2o`0000Kooooo0ol000000ooooooo0000o`000004o`00
0003ooooool0003o000000;o00000oooool2o`000003ooooool0003o000000;ooooo0_l00002oooo
o`Go0000T_ooool001cooooo00?o0000ooooooooool0Moooool2o`0000_ooooo1Ol0000Booooo`Co
000000?oooooo`000?l000000_l00002ooooo`;o00000_ooool2o`0000;ooooo0_l00002ooooo`Go
0000T_ooool001cooooo00?o0000ooooooooool0Moooool2o`0000_ooooo0_l0000:ooooo`;o0000
0_ooool2o`00013ooooo0_l00004ooooo`?o0000V_ooool001cooooo00?o0000ooooooooool0T?oo
ool2o`0000;ooooo0_l0000Fooooo`?o0000V_ooool001cooooo00?o0000ooooooooool0U?ooool2
o`000;?ooooo000Looooo`03o`000?oooooooooo07[ooooo0_l0000Dooooo`;o0000]oooool001co
oooo00?o0000ooooooooool0N_ooool2o`0001Cooooo0_l00009ooooo`;o0000[?ooool001cooooo
00?o0000ooooooooool0Voooool3o`000:_ooooo000Looooo`03o`000?oooooooooo073ooooo0_l0
000Zooooo`;o00008?ooool2o`0000?ooooo0_l00024ooooo`007?ooool00ol0003oooooooooo`1^
ooooo`Co0000;Oooool2o`0000cooooo0_l0000?ooooo`Co000000?oooooo`000?l00000Q?ooool0
0006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oo
oooooooo06kooooo0_l0000/ooooo`;o000000?oooooo`000?l000003?ooool4o`0000oooooo0_l0
0027ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Q
onk^k_ooooooA4A400Kooooo00?o0000ooooooooool0Moooool5o`0001[ooooo0_l00002ooooo`Co
00001Oooool2o`0000Sooooo1?l00006ooooo`;o00003_ooool3o`0007oooooo00000ooooooo410@
ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003ooooo
ooooo`1gooooo`Go00006_ooool2o`0000;ooooo0_l00007ooooo`;o00002?ooool2o`0000Sooooo
0_l0000>ooooo`?o0000Ooooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02ooo
ool00onHV9So8B4Qonk^kP06ooooo`?o0000Moooool2o`000003ooooool0003o000003cooooo0_l0
000<ooooo`;o0000POooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool0
0omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo09Gooooo0_l0000Qooooo`Co00002_ooool3
o`00083ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`27ooooo`;o00003?ooool2o`00027ooooo1ol00008oooo
o`;o0000P?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonH
V9So410@00Kooooo00?o0000ooooooooool0Koooool2o`0001Kooooo1?l0000Tooooo`;o00002Ooo
ool5o`0000cooooo0_l0001looooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Tooooo`;o00002Oooool2o`0000Go
oooo0_l00002ooooo`;o00003?ooool3o`0001oooooo0_l000000ooooooo0000o`000002o`000003
ooooool0003o000000Oooooo0ol0000=ooooo`;o0000O?ooool001cooooo00?o0000ooooooooool0
I?ooool2o`0000?ooooo0_l00006ooooo`Oo00000_ooool2o`0000_ooooo0_l0000Qooooo`;o0000
00?oooooo`000?l000000oooool2o`0000Oooooo0_l0000>ooooo`;o0000O?ooool001cooooo00?o
0000ooooooooool0JOooool2o`0000Kooooo1_l0000@ooooo`;o00003?ooool2o`0001?ooooo0_l0
0009ooooo`?o00005oooool2o`0007Sooooo000Looooo`03o`000?oooooooooo06oooooo0_l00003
ooooo`?o00007_ooool2o`0001?ooooo0_l00009ooooo`Go00001_ooool2o`0000gooooo0_l0001h
ooooo`007?ooool00ol0003oooooooooo`1Looooo`;o00004Oooool2o`0000Cooooo1?l00003oooo
o`;o00001Oooool2o`0000kooooo1?l0000Qooooo`;o00001_ooool2o`0000Cooooo0_l00021oooo
o`007?ooool00ol0003oooooooooo`1Looooo`;o00003Oooool2o`0000Kooooo0ol000000ooooooo
0000o`000003ooooo`;o00001Oooool2o`0000kooooo1?l0000Zooooo`Oo0000POooool001cooooo
00?o0000ooooooooool0Joooool2o`0000?ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o
000000?oooooo`000?l000003?ooool2o`0003Oooooo1Ol0000?ooooo`;o000000?oooooo`000?l0
0000Koooool001cooooo00?o0000ooooooooool0H_ooool2o`0000Gooooo0_l00005ooooo`;o0000
0_ooool2o`000004ooooool0003o0000ooooo`;o00003?ooool2o`0000Oooooo0_l0000Wooooo`;o
000000?oooooo`000?l000001_ooool2o`0000Cooooo0_l00008ooooo`Go0000Koooool001cooooo
00?o0000ooooooooool0HOooool3o`0000Gooooo0_l0000@ooooo`;o00005?ooool2o`0002Oooooo
1_l00005ooooo`?o00000_ooool3o`0000Oooooo1?l0001aooooo`007?ooool00ol0003ooooooooo
o`1Qooooo`;o00001oooool2o`0000oooooo0_l0000Eooooo`;o00006_ooool2o`000004ooooool0
003o0000ooooo`;o00001_ooool4o`0000Kooooo0_l00002ooooo`Co00001_ooool2o`0001Cooooo
0_l0001Mooooo`007?ooool00ol0003oooooooooo`1Looooo`;o00000_ooool3o`0000Cooooo1Ol0
0002ooooo`;o00000_ooool2o`0001kooooo0_l0000Jooooo`;o000000?oooooo`000?l000001Ol0
0005ooooo`?o00001_ooool2o`0000Cooooo0_l00007ooooo`Co00004Oooool2o`0005gooooo000L
ooooo`03o`000?oooooooooo05cooooo1ol00004ooooo`Co00000oooool2o`0000;ooooo0_l0000A
ooooo`;o00000oooool2o`0000Oooooo0_l0000Nooooo`Go00001Oooool3o`0001Gooooo1_l00000
1?oooooo0000o`000?l0001Zooooo`007?ooool2o`0005[ooooo0_l00003ooooo`;o00002Oooool2
o`000003ooooool0003o000001Kooooo0ol00003ooooo`;o00001oooool2o`0002Oooooo1Ol0000<
ooooo`;o00001oooool2o`000004ooooool0003o0000ooooo`?o0000J_ooool001cooooo00?o0000
ooooooooool0Eoooool6o`0000;ooooo0_l00008ooooo`Go00005_ooool2o`000003ooooool0003o
000000Wooooo0ol0000Wooooo`;o000000?oooooo`000?l000002_ooool4o`0000[ooooo0_l00003
ooooo`;o0000JOooool001cooooo00?o0000ooooooooool0Eoooool2o`000004ooooool0003o0000
o`0000;ooooo0_l00005ooooo`;o00000oooool2o`0000?ooooo0_l0000Eooooo`;o00002Oooool3
o`0003Kooooo1Ol00009ooooo`;o00000oooool2o`0006Wooooo000Looooo`03o`000?oooooooooo
05[ooooo0_l00002ooooo`Ko00000_ooool2o`0000Sooooo0_l00004ooooo`;o00000oooool3o`00
00Wooooo0_l00014ooooo`Co00002Oooool3o`00017ooooo0_l0001Iooooo`007?ooool00ol0003o
ooooooooo`1Nooooo`Ko00002oooool4o`0000?ooooo0_l00003ooooo`?o00002Oooool2o`0000;o
oooo1?l0000/ooooo`;o00004?ooool5o`0000?ooooo0_l00003ooooo`?o00004Oooool3o`0005So
oooo000Looooo`03o`000?oooooooooo05?ooooo0_l0000Jooooo`Co00002?ooool2o`0000Sooooo
0_l00004ooooo`Co0000;?ooool2o`0001?ooooo0_l000000ooooooo0000o`000002o`0000Cooooo
0_l0000Booooo`;o0000F?ooool001cooooo00?o0000ooooooooool0D_ooool3o`00013ooooo0_l0
000;ooooo`;o00001oooool2o`0000Sooooo0_l0001<ooooo`Co0000L_ooool001cooooo00?o0000
ooooooooool0D_ooool2o`00017ooooo0_l000000ooooooo0000o`000007ooooo`?o000000?ooooo
o`000?l000001oooool3o`00017ooooo0_l0000Rooooo`;o0000TOooool001cooooo00?o0000oooo
ooooool0Eoooool2o`0000oooooo0_l00002ooooo`;o00000_ooool3o`0000;ooooo0_l000000ooo
oooo0000o`000004ooooo`?o00000oooool2o`0000Oooooo0_l00002ooooo`?o00008_ooool2o`00
00kooooo0_l0000Pooooo`;o0000Goooool001cooooo00?o0000ooooooooool0COooool2o`0000?o
oooo0_l000000ooooooo0000o`000002o`0000Cooooo1?l00002ooooo`;o00001oooool2o`0000;o
oooo0_l00002ooooo`?o000000Coooooo`000?l0003ooooo0_l00007ooooo`;o00001oooool2o`00
00;ooooo0ol0000Rooooo`Co00000oooool2o`000003ooooool0003o000000Cooooo0_l0000Poooo
o`;o0000Goooool001cooooo00?o0000ooooooooool0COooool2o`0000?ooooo0_l000000ooooooo
0000o`000006ooooo`Co00000_ooool2o`0000gooooo1Ol00003ooooo`?o00003?ooool2o`000003
ooooool0003o000000Cooooo0_l0000Tooooo`;o00000oooool5o`0000Kooooo0_l0001oooooo`00
7?ooool00ol0003oooooooooo`1Jooooo`;o00001oooool2o`0000gooooo1?l00004ooooo`Go0000
0_ooool2o`0000?ooooo1Ol000000ooooooo0000o`00000aooooo`;o00001oooool2o`0000cooooo
0_l00006ooooo`;o00001Oooool2o`0000?ooooo0_l0001Mooooo`007?ooool00ol0003ooooooooo
o`1Fooooo`;o00000_ooool2o`0001;ooooo0_l0000:oooooaCo0000<Oooool3o`0000[ooooo0_l0
0008ooooo`;o00001_ooool2o`0000Gooooo0_l00003ooooo`;o0000GOooool001cooooo00?o0000
ooooooooool0E_ooool2o`00017ooooo0_l00003ooooo`;o00001?ooool2o`0000Cooooo0ol00002
ooooo`go00001_ooool2o`0002cooooo1?l00008ooooo`?o00002oooool2o`0001Sooooo0_l0001C
ooooo`007?ooool00ol0003oooooooooo`18ooooo`;o00000oooool2o`0000Cooooo0_l000000ooo
oooo0000o`000009ooooo`;o00001_ooool2o`0000Wooooo0_l00004ooooo`;o00001Oooool9o`00
00Kooooo1Ol0000Tooooo`;o00001Oooool6o`0000Oooooo0_l0000:ooooo`?o00006?ooool2o`00
05?ooooo000Looooo`03o`000?oooooooooo04Sooooo0_l00003ooooo`;o00001?ooool2o`0000;o
oooo0_l00008ooooo`;o00008Oooool3o`0000Wooooo0_l000000ooooooo0000o`00000Gooooo`;o
00001Oooool2o`0000Cooooo0_l00006ooooo`;o000000?oooooo`000?l000004Oooool4o`00013o
oooo0_l00007ooooo`;o0000Doooool001cooooo0_l00018ooooo`;o00001_ooool2o`0000Kooooo
0_l00003ooooo`?o00000_ooool2o`0000Sooooo0_l0000Hooooo`;o00008oooool4o`0000Gooooo
0_l00005ooooo`;o00001_ooool4o`000003ooooool0003o000000?ooooo0_l00009ooooo`;o0000
4_ooool2o`0000Oooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`16ooooo`?o00001_oo
ool2o`0000Gooooo0_l00003ooooo`Go000000?oooooo`000?l000002?ooool2o`0000Kooooo0_l0
0006ooooo`;o00002?ooool3o`00013ooooo0_l0000@ooooo`;o000000Coooooo`000?l0003ooooo
0_l000000ooooooo0000o`000003o`0000;ooooo1?l00004ooooo`?o00000_ooool2o`0000?ooooo
1?l0001iooooo`007?ooool00ol0003oooooooooo`14ooooo`Co00000_ooool2o`0000[ooooo0_l0
00000ooooooo0000o`000005o`00013ooooo0_l000000ooooooo0000o`000005ooooo`?o00002?oo
ool3o`00013ooooo0_l0000Cooooo`;o000000?oooooo`000?l000003?l00005ooooo`;o00002Ooo
ool2o`0001cooooo0_l00007ooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0@oooool3
o`000004ooooool0003o0000ooooo`;o00003Oooool5o`0000_ooooo0_l00005ooooo`;o00002?oo
ool2o`0001cooooo0_l0000?ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`Ko00006ooo
ool2o`0001;ooooo1?l00005ooooo`?o0000DOooool001cooooo00?o0000ooooooooool0@oooool2
o`0000;ooooo0_l0000Jooooo`;o000000Coooooo`000?l0003ooooo1?l00009ooooo`?o000000Co
ooooo`000?l0003ooooo0_l00004ooooo`;o00002_ooool2o`0000Oooooo0_l0000?ooooo`[o0000
00Coooooo`000?l0003ooooo1_l00003ooooo`;o00002_ooool2o`0000[ooooo0ol00002ooooo`;o
00003oooool2o`0000Kooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`10ooooo`;o0000
2_ooool2o`0000Sooooo0_l0000;ooooo`;o000000Coooooo`000?l0003ooooo1?l00009ooooo`?o
00001?ooool2o`0000?ooooo1Ol00008ooooo`;o00002Oooool2o`0000oooooo2?l000000ooooooo
0000o`000002ooooo`Co00001?ooool2o`0000Oooooo1Ol00004ooooo`;o00001Oooool2o`0000;o
oooo0_l0000Gooooo`;o0000DOooool001cooooo00?o0000ooooooooool0@?ooool2o`0000Oooooo
0_l000000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l000002oooool2o`0000Wooooo
0_l00003ooooo`;o00002_ooool2o`000004ooooool0003o0000ooooo`;o00001?ooool2o`0000go
oooo0_l0000Booooo`?o00001oooool2o`0000oooooo1?l00005ooooo`;o00001oooool2o`0000_o
oooo0_l00004ooooo`;o000000?oooooo`000?l00000E_ooool001cooooo00?o0000ooooooooool0
@?ooool2o`0000Oooooo0_l00008ooooo`;o00003?ooool2o`0000Cooooo0_l00005ooooo`?o0000
0_ooool2o`0000[ooooo0_l0000:ooooo`;o00002oooool2o`00017ooooo0_l00005ooooo`;o0000
5oooool2o`0000Gooooo0ol00006ooooo`;o00002oooool2o`0000Cooooo1Ol00003ooooo`;o0000
DOooool001cooooo00?o0000ooooooooool0@?ooool2o`0001Gooooo0_l00004ooooo`Oo00000ooo
ool2o`0000Cooooo1_l0000Pooooo`Co000000?oooooo`000?l000004Oooool5o`0000;ooooo0_l0
000>ooooo`;o00001oooool2o`0000Gooooo0ol0000Booooo`?o00001Oooool3o`0000Cooooo0_l0
001Aooooo`007?ooool00ol0003oooooooooo`1Gooooo`;o00001?ooool7o`0000Sooooo0ol00002
ooooo`;o00008?ooool4o`0001Gooooo1?l0000Booooo`;o00003oooool4o`0000?ooooo0_l00006
ooooo`;o00000oooool3o`0000Oooooo0ol00003ooooo`;o0000D?ooool001cooooo00?o0000oooo
ooooool0HOooool2o`0000Wooooo0ol00002ooooo`;o00003_ooool2o`0000;ooooo0ol0000Goooo
o`;o0000<_ooool5o`0000;ooooo0_l00006ooooo`;o00002oooool5o`0000?ooooo0_l0001@oooo
o`007?ooool00ol0003oooooooooo`10ooooo`;o00002_ooool2o`0000Gooooo0_l0000Jooooo`Ko
00001?ooool2o`0000Kooooo0_l00002ooooo`?o00002oooool2o`0000Wooooo0ol00004ooooo`;o
00003?ooool2o`0000Cooooo0_l0000Kooooo`;o00004_ooool2o`000003ooooool0003o000000Go
0000EOooool001cooooo00?o0000ooooooooool0>oooool2o`0000?ooooo0_l0000:ooooo`;o0000
1Oooool3o`0000;ooooo0_l0000Booooo`;o000000Coooooo`000?l0003ooooo0ol00004ooooo`;o
000000?oooooo`000?l000003_ooool2o`0000Gooooo0_l00006ooooo`;o000000?oooooo`000?l0
00000oooool4o`0000cooooo0_l00004ooooo`;o00006?ooool2o`0000gooooo0_l00005ooooo`Wo
0000Eoooool001cooooo00?o0000ooooooooool0>oooool4o`0000[ooooo0_l00004ooooo`;o0000
0oooool2o`0000;ooooo0_l0000Booooo`;o00001?ooool6o`000003ooooool0003o000000?o0000
3_ooool2o`0000cooooo0ol00006ooooo`;o00002oooool@o`0001?ooooo0_l0000=ooooo`;o0000
1?ooool5o`0005cooooo000Looooo`03o`000?oooooooooo03gooooo0_l0000:ooooo`;o00001?oo
ool4o`0001Wooooo0ol00003ooooo`Ko00000_ooool8o`0000?ooooo0_l00003ooooo`;o00001Ooo
ool2o`0000Oooooo0_l00005ooooo`;o00003?oooolAo`0001;ooooo0_l0000Dooooo`?o00002ooo
ool4o`0004oooooo000Looooo`03o`000?oooooooooo03Wooooo0ol00005ooooo`;o00003Oooool3
o`0001Wooooo5_l00003ooooo`;o00000oooool2o`0000Gooooo0_l0000>ooooo`;o00000_ooool2
o`0000Gooooo0_l000000ooooooo0000o`000005o`000003ooooool0003o000000?ooooo1?l00005
ooooo`;o000000?oooooo`000?l000002?ooool4o`0000;ooooo1?l0000=ooooo`;o00000oooool2
o`0000Kooooo1?l0001?ooooo`007?ooool2o`0003[ooooo1Ol00002ooooo`Go00000_ooool2o`00
013ooooo0_l0000:ooooo`;o000000?oooooo`000?l000000_oooolFo`0000;ooooo0_l0000Ooooo
o`;o00001Oooool8o`0000Gooooo0_l000000ooooooo0000o`000003o`0000Cooooo1Ol00008oooo
o`Co00000_ooool4o`0000gooooo1?l000000ooooooo0000o`000002o`0000Cooooo0_l0001Aoooo
o`007?ooool00ol0003oooooooooo`0jooooo`Co00000_ooool2o`000003ooooool0003o000000;o
oooo0_l00003ooooo`;o00002oooool2o`0000[ooooo0_l000000ooooooo0000o`000002ooooo`Co
00000_oooolFo`0000;ooooo1?l0000Booooo`;o00001oooool2o`0000;ooooo0_l000000ooooooo
0000o`000002o`0000Gooooo1?l00002ooooo`;o00001Oooool4o`0000Sooooo0_l00002ooooo`;o
00000_ooool2o`0000?ooooo0_l00008ooooo`Ko000000?oooooo`000?l000000ol000001?oooooo
0000o`000?ooool2o`0004kooooo000Looooo`03o`000?oooooooooo04Gooooo0_l00005ooooo`;o
00005_ooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool3o`000003ooooool0003o0000
00oo00000_ooool2o`0000;ooooo1?l0000Booooo`;o00001oooool3o`0000?ooooo2?l00002oooo
o`Go00000_ooool<o`0000Cooooo0_l00004ooooo`;o00000_ooool2o`0000?ooooo0_l0000<oooo
o`So00001?ooool2o`0004kooooo000Looooo`03o`000?oooooooooo03_ooooo0_l00008ooooo`;o
00005oooool2o`0000?ooooo0ol00003ooooo`;o00001?oooolDo`0000Sooooo0_l00002ooooo`;o
00001_ooool4o`0000oooooo0_l000000ooooooo0000o`00000@o`000003ooooool0003o000000_o
00000oooool2o`0001gooooo1_l00004ooooo`Co0000C?ooool001cooooo00?o0000ooooooooool0
=Oooool2o`0000Cooooo0_l0000Qooooo`;o00000oooool2o`0000;ooooo0_l00003oooooaWo0000
00?oooooo`000?l000001oooool2o`0000Kooooo1?l000000ooooooo0000o`00000;ooooo`;o0000
00?oooooo`000?l000004Ol000000ooooooo0000o`000007ooooo`Go00002_ooool2o`0000Oooooo
0_l0000?ooooo`?o00001Oooool3o`0000;ooooo0_l00004ooooo`;o0000@_ooool001cooooo00?o
0000ooooooooool0=Oooool2o`0000Sooooo0_l00007ooooo`;o00000_ooool2o`0000_ooooo0_l0
0003ooooo`;o00000oooool2o`0000;ooooo0_l00002oooooa[o000000?oooooo`000?l000001ooo
ool2o`0000_ooooo0_l00004ooooo`;o00001Oooool2o`000003ooooool0003o000000Ko000000?o
ooooo`000?l000002ol000001?oooooo0000o`000?l00002ooooo`?o000000Coooooo`000?l0003o
oooo0_l00007ooooo`?o00001_ooool2o`0000oooooo0ol00002ooooo`;o00000_ooool2o`0000;o
oooo0_l00004ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0?oooool2o`0000Oooooo
0_l00002ooooo`;o00002oooool2o`0000?ooooo0ol000001?oooooo0000o`000?l00003ooooo`;o
000000Coooooo`000?l0003ooooo5ol00008ooooo`Co00001oooool2o`0000?ooooo0_l00002oooo
o`Co00001ooooolVo`0000Kooooo0ol000000ooooooo0000o`00000@ooooo`;o00000oooool2o`00
00;ooooo0_l00002ooooo`?o0000Boooool001cooooo00?o0000ooooooooool0=?ooool2o`0001[o
oooo0_l0000<ooooo`So000000Coooooo`000?l0003o00001?oooolGo`0000Sooooo0_l00003oooo
o`;o00000_ooool5o`0000;ooooo0_l00002ooooo`Co00001oooool2o`000003ooooool0003o0000
01So000000Goooooo`000?l0003o0000ooooo`05o`0000Wooooo1Ol00007ooooo`;o00001?ooool2
o`000003ooooool0003o000000Wooooo0_l00007ooooo`;o0000@_ooool001cooooo00?o0000oooo
ooooool0=?ooool2o`00017ooooo0_l00007ooooo`;o00002_ooool7o`000003ooooool0003o0000
00?o00000_oooolJo`0000gooooo0_l00002ooooo`Wo00001?ooool2o`0000Cooooo0_l00004oooo
oa[o00000_ooool9o`0000Sooooo1_l00006ooooo`Co00001Oooool4o`00013ooooo0_l00004oooo
o`;o0000??ooool001cooooo00?o0000ooooooooool0Aoooool2o`0000Cooooo0_l00005ooooo`;o
00001_ooool2o`0000;ooooo0_l00003ooooo`Co000000?oooooo`000?l000006Ol00003ooooo`Co
00000oooool2o`0000Gooooo1ol000000ooooooo0000o`000002ooooo`?o00000_ooool4o`000003
ooooool0003o000001_o00000oooool2o`000003ooooool0003o000000?o00003?ooool2o`000003
ooooool0003o000000Gooooo0_l00007ooooo`;o00000_ooool2o`0001;ooooo0_l0000looooo`00
7?ooool00ol0003oooooooooo`1<ooooo`?o00000oooool4o`0000Kooooo0_l000000ooooooo0000
o`000003ooooo`?o00000_oooolNo`000003ooooool0003o000000;o00000oooool2o`0000;ooooo
0_l000000ooooooo0000o`000002ooooo`;o00000_ooool6o`0000;ooooo1?l00002oooooaoo0000
00?oooooo`000?l000001?l0000<ooooo`;o00000oooool2o`0000?ooooo1?l00007ooooo`;o0000
0_ooool2o`00053ooooo000Looooo`03o`000?oooooooooo04cooooo0_l00004ooooo`Co00000ooo
ool5o`000003ooooool0003o000000?ooooo9_l00006ooooo`;o000000?oooooo`000?l000002_oo
ool6o`000003ooooool0003o000000;o00000ooooolNo`000003ooooool0003o000000Go00000_oo
ool4o`0000?ooooo1?l000000ooooooo0000o`000005ooooo`Co00001_ooool4o`0005?ooooo000L
ooooo`03o`000?oooooooooo04cooooo0_l00005ooooo`;o00000oooool4o`0000Sooooo1_l00002
ooooob3o00001?ooool2o`0000gooooo0_l00002ooooo`;o000000?oooooo`000?l000000ol00000
0ooooooo0000o`000003o`0000?ooooo5ol000000ooooooo0000o`00000;o`0000?ooooo1?l00000
0ooooooo0000o`00000<ooooo`Oo00005Oooool2o`0003cooooo000Looooo`03o`000?oooooooooo
033ooooo0_l00002ooooo`;o00006oooool5o`000003ooooool0003o000000?o00002?ooool3o`00
00Gooooo4Ol000000ooooooo0000o`000007o`000003ooooool0003o000000?o00006?ooool6o`00
0003ooooool0003o000000?o00000_oooolHo`000003ooooool0003o000000_o00000oooool2o`00
0004ooooool0003o0000o`0000gooooo1Ol0000Gooooo`;o0000??ooool00006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oo
oooooooo033ooooo0_l00002ooooo`;o00003_ooool2o`0000[ooooo0ol000001?oooooo0000o`00
0?ooool5o`0000Cooooo0_l0000:oooooa7o000000?oooooo`000?l000002?l000000ooooooo0000
o`000002o`0000Kooooo0_l0000@ooooo`?o000000Coooooo`000?l0003ooooo1_l000000ooooooo
0000o`00000No`000003ooooool0003o000000So000000Coooooo`000?l0003o00003oooool2o`00
05Kooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0=Oooool2o`0000gooooo0_l00002ooooo`;o00001_ooool2
o`0000Cooooo1_l00004ooooo`;o00000_ooool2o`0000Sooooo3ol000000ooooooo0000o`000004
o`0000;ooooo0ol000000ooooooo0000o`000006ooooo`Go00003_ooool2o`0000?ooooo2?l00000
0ooooooo0000o`00000Ho`0000;ooooo3ol0001[ooooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`09ooooo`Go00001_ooool00ol0003oooooooooo`0booooo`;o000000?oooooo`00
0?l000004Oooool2o`0000Wooooo0_l000000ooooooo0000o`000003o`0000Wooooo1?l00003oooo
oa_o000000?oooooo`000?l000000ol00006ooooo`;o000000?oooooo`000?l000004oooool_o`00
00;ooooo1Ol00007ooooo`;o000000?oooooo`000?l000000oooool2o`0000;ooooo0_l0000Hoooo
o`;o0000>_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?m4A4Co
gMgMooooool00007ooooo`?o0000<_ooool2o`0001oooooo0_l00002ooooo`;o000000Coooooo`00
0?l0003o00000_ooool2o`0000Gooooo1?l000000ooooooo0000o`00000Mo`0000Sooooo0_l00000
0ooooooo0000o`00000Aooooo`;o000000?oooooo`000?l000009?l00004ooooo`Go000000?ooooo
o`000?l000000ol00007ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0000;ooooo0_l0
000Hooooo`;o0000>_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool0
1?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo03?ooooo0_l0000Rooooo`;o000000Co
ooooo`000?l0003o00000_ooool2o`0000Cooooo1Ol000000ooooooo0000o`00000Lo`000003oooo
ool0003o0000017ooooo0_l000000ooooooo0000o`000005ooooobSo00000_ooool2o`0000;ooooo
1Ol00009ooooo`;o00001?ooool4o`0000?ooooo1?l0001Eooooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0<ooo
ool2o`0001[ooooo0_l0000:ooooo`;o00002?ooool2o`0000Kooooo0ol000000ooooooo0000o`00
000Fo`000003ooooool0003o000000Oooooo0_l00008ooooo`;o000000?oooooo`000?l000001?oo
oolUo`000004ooooool0003o0000ooooo`Co000000?oooooo`000?l000001?l00009ooooo`;o0000
1?ooool2o`0000Gooooo1Ol0001Dooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<ooooo`03
onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0A?ooool2o`0000Kooooo0_l000000ooooooo
0000o`000003o`0000Oooooo0_l00005ooooo`;o000000?oooooo`000?l000001OoooolAo`000003
ooooool0003o000000Oo00003?ooool2o`0000Sooooo1Ol00004ooooo`Co000000?oooooo`000?l0
00008Ol000000ooooooo0000o`000002o`000005ooooool0003o0000o`000?ooool00_l00004oooo
o`;o00004?ooool5o`0005Cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPgooooo00?oMgMg
o`000?ooool01_ooool00ol0003oooooooooo`14ooooo`;o00001_ooool2o`0000;ooooo1?l00002
ooooo`;o00000_ooool2o`0000Kooooo0_l00008oooooa[o00001oooool2o`00013ooooo1?l00004
ooooo`?o00000_ooool6o`000003ooooool0003o000001So00001_ooool5o`000003ooooool0003o
000000;o000000?oooooo`000?l000001oooool3o`0000?ooooo0_l000000ooooooo0000o`000002
ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0=_ooool2o`0001Cooooo0_l00008oooo
o`;o00000_ooool4o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o00001oooool7o`00
00Cooooo1_l0000:ooooo`?o00004?ooool4o`0000Gooooo0ol000000ooooooo0000o`00000Oo`00
00Kooooo1Ol000000ooooooo0000o`000002o`0000[ooooo1Ol000000ooooooo0000o`000002oooo
o`Go0000Doooool001cooooo00?o0000ooooooooool0=_ooool2o`0001Cooooo0_l0000;ooooo`;o
000000?oooooo`000?l000000ol00002ooooo`?o00000_ooool5o`0000Gooooo1?l00004ooooo`?o
000000?oooooo`000?l000000_l0000:ooooo`;o00005?ooool3o`0000Cooooo0_l000000ooooooo
0000o`00000Oo`0000Oooooo1?l00005ooooo`Co00002Oooool2o`000003ooooool0003o000000Ko
0000E?ooool001cooooo00?o0000ooooooooool0<oooool2o`0002Cooooo0_l00002ooooo`So0000
1?ooool4o`0000Gooooo1?l00002ooooo`Go00000oooool4o`0000Kooooo0_l0000Fooooo`?o0000
00?oooooo`000?l000001?ooool=o`000003ooooool0003o000000oo000000?oooooo`000?l00000
1_ooool3o`0000Cooooo1_l0000<ooooo`Go0000Eoooool001cooooo00?o0000ooooooooool0<ooo
ool2o`0000_ooooo0_l0000Cooooo`Co00001?ooool2o`000004ooooool0003o0000o`0000oooooo
0_l000000ooooooo0000o`000008o`0000;ooooo0ol00006ooooo`;o000000?oooooo`000?l00000
5oooool2o`0000Cooooo2ol00002oooooa;o000000Coooooo`000?l0003ooooo0ol00002ooooo`?o
00001?ooool2o`0000oooooo0_l000000ooooooo0000o`000003o`0005Gooooo000Looooo`03o`00
0?oooooooooo043ooooo0_l0000Cooooo`Co00002?ooool2o`0000?ooooo0_l000000ooooooo0000
o`00000:ooooo`co000000?oooooo`000?l000001oooool4o`0001Cooooo1?l00006oooooako0000
1?ooool3o`0000;ooooo0_l00005ooooo`;o00003_ooool3o`000004ooooool0003o0000ooooo`;o
00003_ooool2o`0004Gooooo000Looooo`03o`000?oooooooooo02oooooo0_l00002ooooo`;o0000
8Oooool2o`0000kooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l000000ooooooo0000
o`000005ooooo`?o000000?oooooo`000?l000000_l0000:ooooo`?o00000oooool2o`00013ooooo
1?l00005ooooo`ko00000_ooool?o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o0000
3oooool2o`0000?ooooo1?l00006ooooo`;o00001oooool2o`0000;ooooo1?l00013ooooo`007?oo
ool00ol0003oooooooooo`0_ooooo`;o00000_ooool2o`0002Oooooo0_l00003ooooo`;o00002?oo
ool2o`0000;ooooo0_l000000ooooooo0000o`000009ooooo`Co00001_ooool2o`0000Sooooo0_l0
000Dooooo`?o00000_ooool3o`0000;ooooo0_l000000ooooooo0000o`00000Go`000004ooooool0
003o0000ooooo`;o00000_ooool2o`0000oooooo0_l00005ooooo`;o00001_ooool2o`0000Oooooo
0_l00004ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0<oooool2o`0000Sooooo0_l0
000Mooooo`;o00000oooool2o`0000Cooooo0_l00002ooooo`Ko00002oooool4o`0000Gooooo1?l0
000Nooooo`?o00001?oooolOo`0000Gooooo0_l000000ooooooo0000o`00000Wooooo`;o0000BOoo
ool001cooooo00?o0000ooooooooool0<oooool2o`0000Sooooo0ol0000Hooooo`;o00003Oooool2
o`0000Cooooo0_l0000=ooooo`Co00001?ooool3o`0000;ooooo0_l00004ooooo`;o00007Oooool9
o`000003ooooool0003o000000oo00000oooool4o`0000;ooooo1_l0000Dooooo`?o00002oooool2
o`0000[ooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00002_ooool3o`00
01Sooooo0_l0000Booooo`;o00003oooool2o`0000Gooooo0ol00002ooooo`;o00001?ooool2o`00
01kooooo1ol000000ooooooo0000o`00000?o`0000Cooooo1?l00004ooooo`Co00005?ooool4o`00
00[ooooo0_l00006ooooo`;o00000_ooool2o`00047ooooo000Looooo`03o`000?oooooooooo037o
oooo0_l0000:ooooo`;o00008?ooool2o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l0
00003oooool2o`0000Kooooo0_l00007ooooo`;o00007oooool<o`000003ooooool0003o000000_o
000000?oooooo`000?l000001?l00003ooooo`;o00001Oooool2o`000003ooooool0003o000000Ko
oooo0_l00003ooooo`;o00000_ooool2o`0000kooooo0_l00002ooooo`;o00000_ooool4o`0003oo
oooo000Looooo`;o0000<_ooool2o`0000Sooooo1?l0000Pooooo`;o00000oooool3o`0000;ooooo
0_l00003ooooo`;o00003Oooool2o`0000Cooooo1?l00007ooooo`;o00007Oooool2o`000003oooo
ool0003o000001ko00000oooool2o`0000Gooooo1Ol00006ooooo`;o00000oooool2o`0000cooooo
0_l00004ooooo`;o00001_ooool4o`0003oooooo000Looooo`03o`000?oooooooooo037ooooo0_l0
0008ooooo`Co00009Oooool2o`0000;ooooo0_l00002ooooo`Co00003Oooool2o`0000Cooooo0_l0
000Xooooo`Oo000000?oooooo`000?l000005ol00002ooooo`;o00002?ooool5o`0000Gooooo0_l0
000Aooooo`?o0000Coooool001cooooo00?o0000ooooooooool0H_ooool2o`0000Cooooo0_l00002
ooooo`;o00005?ooool3o`0000_ooooo1?l0000Jooooo`Ko000000?oooooo`000?l000003?l00000
0ooooooo0000o`000006o`0000Cooooo0_l00004ooooo`;o00000_ooool2o`0000Sooooo0_l00005
ooooo`?o00002Oooool2o`0000Cooooo0_l00004ooooo`;o00001Oooool2o`0003gooooo000Loooo
o`03o`000?oooooooooo033ooooo0_l0000:ooooo`;o00001?ooool2o`0001kooooo0_l00008oooo
o`Go000000?oooooo`000?l000000_ooool2o`0000?ooooo0ol00004ooooo`;o00002_ooool6o`00
00Sooooo0_l0000@ooooo`Ko000000?oooooo`000?l000003?l000000ooooooo0000o`000009o`00
00Oooooo0_l0000Cooooo`?o00003oooool2o`0000Cooooo0ol00004ooooo`;o0000?Oooool001co
oooo00?o0000ooooooooool0<?ooool2o`0000[ooooo0_l00004ooooo`Co00009_ooool5o`000005
ooooool0003o0000o`000?ooool00_l00003ooooo`?o00004?ooool4o`0000[ooooo0_l0000@oooo
o`Co00000_ooool9o`0000;ooooo4?l00002ooooo`;o00001?ooool3o`0000;ooooo0_l00005oooo
o`?o00003?ooool2o`0000?ooooo0_l00005ooooo`;o00001?ooool2o`0004?ooooo000Looooo`03
o`000?oooooooooo033ooooo0_l0000>ooooo`;o00000_ooool2o`0002Oooooo0_l00004ooooo`;o
00000oooool2o`0000Oooooo0_l00003ooooo`;o00001_ooool2o`0001kooooo0_l00004ooooo`?o
000000?oooooo`000?l000000ol00002ooooo`Wo00000_ooool2o`0000?ooooo1_l00002ooooo`?o
00000_ooool2o`0000Cooooo1?l0000<ooooo`Co000000Coooooo`000?l0003o00001?ooool2o`00
00Sooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00002oooool2o`000003
ooooool0003o000002_ooooo1?l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o
00000oooool2o`0000Kooooo0_l000000ooooooo0000o`00000<ooooo`;o00003Oooool2o`0000?o
oooo0_l00005ooooo`Co000000Goooooo`000?l0003o0000ooooo`02o`0000Wooooo0ol00002oooo
o`;o00000_ooool2o`0000Wooooo0ol0000?ooooo`Ko00002oooool2o`000003ooooool0003o0000
00Cooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00000oooool3o`0001[o
oooo0_l0000;ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Oooooo0_l0000Aooooo`Ko
00002_ooool2o`0001;ooooo0_l00004ooooo`Go00004?ooool2o`0000;ooooo0_l00004ooooo`;o
00002?ooool2o`0001;ooooo1Ol00008ooooo`Co00001Oooool4o`0003Wooooo000Looooo`03o`00
0?oooooooooo02kooooo0_l0000Booooo`?o00006_ooool2o`0000_ooooo1_l000000ooooooo0000
o`00000<ooooo`?o00002oooool6o`0002;ooooo1_l0000=ooooo`;o00001_ooool2o`0000Cooooo
0_l00007ooooo`;o00003_ooool2o`0000Cooooo1?l00007ooooo`?o00001oooool2o`0003_ooooo
000Looooo`03o`000?oooooooooo02kooooo0_l0000aooooo`;o00002oooool4o`0000oooooo0ol0
000<ooooo`Co00008_ooool3o`0000gooooo0_l00002ooooo`;o00002Oooool2o`0000[ooooo0_l0
0007ooooo`;o00001Oooool2o`0000oooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`0_
ooooo`;o0000<?ooool2o`0000cooooo0_l00004ooooo`;o00002oooool2o`0000cooooo0_l00000
0ooooooo0000o`00000>ooooo`?o00004?ooool2o`0000kooooo0_l00005ooooo`;o00000oooool2
o`000003ooooool0003o000000Wooooo0_l00008ooooo`;o0000GOooool001cooooo00?o0000oooo
ooooool0;oooool2o`0003Cooooo0_l00008ooooo`;o00001?ooool2o`0000;ooooo0_l00007oooo
o`;o00000oooool2o`0000[ooooo1?l0000<ooooo`?o000000?oooooo`000?l000001Oooool2o`00
00[ooooo0_l0000Aooooo`;o00000oooool2o`0000_ooooo0ol00004ooooo`;o00002Oooool2o`00
00;ooooo0_l0000Hooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0??ooool4o`0002Go
oooo1?l00009ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Oooooo0_l00003ooooo`;o
00003?ooool2o`000003ooooool0003o000000;o00002oooool2o`0000Gooooo0_l0000:ooooo`Ko
00001Oooool2o`0000?ooooo1?l0000@ooooo`Co00000_ooool4o`0000Wooooo0ol000000ooooooo
0000o`00000Cooooo`;o00000oooool2o`0003Sooooo000Looooo`03o`000?oooooooooo03_ooooo
1Ol0000Wooooo`;o00001?ooool2o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`;o0000
0oooool6o`0000;ooooo0_l0000<ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000
o`00000?ooooo`;o00000_ooool2o`0000Sooooo1?l00005ooooo`;o00000oooool4o`0000oooooo
0ol00004ooooo`;o00003?ooool2o`000003ooooool0003o000001;ooooo0ol00003ooooo`;o0000
>?ooool001cooooo00?o0000ooooooooool0>oooool2o`0001Sooooo0_l000000ooooooo0000o`00
0004ooooo`Co00002oooool4o`000004ooooool0003o0000ooooo`;o00000oooool4o`000003oooo
ool0003o000000Co00000oooool2o`0000_ooooo0_l000001?oooooo0000o`000?ooool4o`0001?o
oooo0_l00003ooooo`;o00006?ooool2o`0000Wooooo0ol00004ooooo`;o00001oooool2o`0000Co
oooo0_l000000ooooooo0000o`00000Booooo`;o000000Coooooo`000?l0003ooooo0_l0000hoooo
o`007?ooool00ol0003oooooooooo`0kooooo`;o00000oooool2o`0001;ooooo0ol000000ooooooo
0000o`000004ooooo`Co00002oooool4o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`Co
00001Oooool2o`0000?ooooo0_l0000>ooooo`Go00006_ooool2o`0000gooooo1?l00007ooooo`;o
00002Oooool3o`000004ooooool0003o0000ooooo`;o00001oooool2o`0000Gooooo0_l0000Goooo
o`;o0000>oooool001cooooo0_l00011ooooo`;o00004_ooool2o`0001?ooooo0_l00008ooooo`;o
000000?oooooo`000?l000001ol00004ooooo`;o00000oooool2o`0000cooooo1_l0000Wooooo`;o
000000?oooooo`000?l000000_l0000Aooooo`?o00000_ooool2o`0000[ooooo0_l00005ooooo`Co
00004Oooool2o`0000?ooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`11ooooo`?o0000
9Oooool2o`0000Kooooo0_l00003ooooo`[o00005Oooool7o`000003ooooool0003o000000Co0000
4oooool2o`0000_ooooo0_l00004ooooo`;o00003_ooool4o`0000?ooooo0_l00002ooooo`;o0000
1_ooool2o`0000Kooooo0ol0000:ooooo`;o00000oooool4o`0000;ooooo0ol0000jooooo`007?oo
ool00ol0003oooooooooo`0`ooooo`;o00003oooool3o`0002Gooooo0_l00006ooooo`;o00001Ooo
ool8o`0000Kooooo1?l0000;ooooo`;o000000?oooooo`000?l000000oooool6o`0001?ooooo0_l0
000;ooooo`;o00001?ooool2o`0000_ooooo1_l00004ooooo`;o00000_ooool2o`0000Oooooo0_l0
000Booooo`;o00000oooool2o`0000Cooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0`
ooooo`;o00003?ooool2o`0002;ooooo0_l0000Cooooo`_o00001?ooool4o`0000cooooo0_l00000
0ooooooo0000o`000003o`000003ooooool0003o000000;o00006_ooool2o`0001Gooooo2?l00006
ooooo`;o00002Oooool2o`0005[ooooo000Looooo`03o`000?oooooooooo03Wooooo0_l00003oooo
o`;o00001_ooool2o`0000kooooo0_l0000:ooooo`;o00003oooool?o`0001?ooooo4?l0000;oooo
o`?o00002_ooool6o`0000Sooooo0_l00002ooooo`Co000000?oooooo`000?l000001?l00003oooo
o`;o00000_ooool3o`0000;ooooo0_l0000Hooooo`;o00001oooool2o`0003kooooo000Looooo`03
o`000?oooooooooo03Wooooo0_l0000;ooooo`;o00003_ooool2o`0000_ooooo0_l0000>ooooo`oo
00004oooool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`Co00002_ooool3o`0000[o
oooo1_l00003ooooo`;o00000oooool2o`000003ooooool0003o000000Co00000_ooool2o`0000Go
oooo1_l00003ooooo`;o00001oooool2o`0000oooooo0_l00007ooooo`;o0000?_ooool001cooooo
00?o0000ooooooooool0>oooool4o`0002;ooooo1?l0000<ooooo`;o00000_ooool=o`0000Oooooo
0_l0000=ooooo`Co00000oooool2o`0000;ooooo1?l0000Fooooo`;o000000?oooooo`000?l00000
0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000000Co00000_ooool4o`0000?ooooo
1?l0000>ooooo`;o00003oooool2o`0000Kooooo0_l00004ooooo`;o0000>Oooool001cooooo00?o
0000ooooooooool0>oooool4o`000003ooooool0003o000000;ooooo0_l00008ooooo`;o00004Ooo
ool2o`0000kooooo0_l000000ooooooo0000o`00000<o`0000Oooooo0_l0000?ooooo`;o00000ooo
ool2o`0000?ooooo1_l00006ooooo`;o00002Oooool4o`0000?ooooo0_l000000ooooooo0000o`00
0004ooooo`Ko00001oooool2o`0000?ooooo1ol0000Looooo`;o00001Oooool3o`0000Cooooo0_l0
000iooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00003_ooool2o`0000;ooooo0_l00008
ooooo`;o00009?ooool>o`0000Kooooo0_l00007ooooo`?o00001?ooool4o`0000Cooooo0_l00002
ooooo`Ko00001_ooool2o`000003ooooool0003o000000Kooooo1?l000000ooooooo0000o`000003
ooooo`;o00000_ooool6o`0000Cooooo0_l00002ooooo`;o00001Oooool6o`0000;ooooo1Ol00003
ooooo`;o00004?ooool2o`0000Gooooo0_l00005ooooo`;o0000>Oooool001cooooo00?o0000oooo
ooooool0<?ooool2o`0000[ooooo0_l00008ooooo`;o00004_ooool2o`0001Gooooo0_l000000ooo
oooo0000o`00000=o`0000Gooooo0_l00007ooooo`Co00000oooool2o`0000Cooooo1Ol000000ooo
oooo0000o`000007o`0000Kooooo0_l00008ooooo`;o000000?oooooo`000?l000000ol00004oooo
o`;o00002?ooool2o`0000;ooooo0_l0000=ooooo`Go00000_ooool3o`0000[ooooo0_l00008oooo
o`;o00002?ooool2o`0003Wooooo000Looooo`03o`000?oooooooooo02oooooo0_l0000;ooooo`;o
00001?ooool2o`0000;ooooo0_l0000<ooooo`Co00000_ooool2o`0000;ooooo0ol00009ooooo`;o
00001Oooool2o`000003ooooool0003o000000Wo000000Coooooo`000?l0003o00001_ooool2o`00
00Sooooo0_l00003ooooo`;o00001?ooool2o`000003ooooool0003o000000;ooooo2?l00006oooo
o`;o00001oooool3o`0000?ooooo1Ol0000Rooooo`;o00000_ooool3o`0000?ooooo0_l00005oooo
o`;o00002?ooool2o`0004?ooooo000Looooo`03o`000?oooooooooo02oooooo0ol0000@ooooo`;o
00004?ooool=o`0000Wooooo0_l00008ooooo`_o000000?oooooo`000?l000001oooool2o`0000[o
oooo0_l00007ooooo`;o00001_ooool2o`0000;ooooo1?l000000ooooooo0000o`000002ooooo`Co
00001?ooool4o`0000Gooooo0ol00006ooooo`;o00004oooool2o`000003ooooool0003o000000Co
00000_ooool3o`0000?ooooo0_l00006ooooo`;o00001oooool2o`0000Sooooo0_l0000iooooo`00
7?ooool00ol0003oooooooooo`0_ooooo`?o00004?ooool2o`0000;ooooo0_l00003ooooo`?o0000
00?oooooo`000?l000001oooool2o`000003ooooool0003o000000Co00004oooool:o`0001Oooooo
0_l000000ooooooo0000o`000003ooooo`;o00000_ooool2o`0000?ooooo0_l00003ooooo`co0000
1?ooool2o`0000Kooooo1?l000001?oooooo0000o`000?l00002ooooo`;o00004oooool2o`000003
ooooool0003o000000Co00004?ooool2o`0000;ooooo0_l0000=ooooo`;o0000>Oooool001cooooo
00?o0000ooooooooool0;oooool2o`0001;ooooo0_l000000ooooooo0000o`000006o`000003oooo
ool0003o000000cooooo1?l00002ooooo`;o00001?ooool2o`0000_ooooo1_l0000;ooooo`;o0000
3oooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`0000Sooooo1ol00009ooooo`;o0000
1Oooool4o`000004ooooool0003o0000o`00013ooooo1?l000000ooooooo0000o`000008o`0001Go
oooo0_l00007ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0@oooool2o`0000?ooooo
0ol00006ooooo`;o00001?ooool2o`0000Cooooo0ol00003ooooo`;o00001?ooool2o`000003oooo
ool0003o000000Kooooo2?l0000;ooooo`;o00000_ooool2o`0000[ooooo0_l00007ooooo`Co0000
1oooool8o`0000Oooooo1?l00005ooooo`?o00001_ooool2o`0000;ooooo0_l00009ooooo`Co0000
00?oooooo`000?l000001ol00007ooooo`;o00004_ooool2o`0000;ooooo0_l0000oooooo`007?oo
ool00ol0003oooooooooo`19ooooo`;o000000Coooooo`000?l0003ooooo1?l000001?oooooo0000
o`000?ooool2o`0000?ooooo1Ol00002ooooo`;o00000oooool2o`0000;ooooo0_l00005ooooo`?o
00000_ooool4o`0000oooooo0_l00007ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Go
oooo1?l00005ooooo`;o000000?oooooo`000?l000001?l00002ooooo`;o00000_ooool2o`0000So
oooo0ol00005ooooo`?o000000?oooooo`000?l000004oooool3o`0000Cooooo0ol000001?oooooo
0000o`000?l0000Aooooo`;o0000@oooool001cooooo0_l0001:ooooo`;o000000Coooooo`000?l0
003ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l000001?oooooo0000o`000?ooool2
o`0000Cooooo0_l000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l000001?ooool2
o`0001;ooooo0ol00004ooooo`Ko000000?oooooo`000?l000001Oooool5o`0000Oooooo0_l00000
1?oooooo0000o`000?l00002ooooo`;o00003Oooool2o`0000Kooooo0_l0000=ooooo`Co00000ooo
ool4o`0000?ooooo1Ol00002ooooo`;o00001Oooool2o`0001Kooooo0_l0000gooooo`007?ooool0
0ol0003oooooooooo`0^ooooo`;o00004_ooool2o`0000_ooooo0_l000000ooooooo0000o`000002
ooooo`Ko00001oooool4o`0000Wooooo0_l00004ooooo`;o000000?oooooo`000?l000003_ooool2
o`0000;ooooo0ol00004ooooo`Ko000000?oooooo`000?l000000_l000000ooooooo0000o`000003
ooooo`;o00001_ooool3o`0000Kooooo0_l00008ooooo`;o00003?ooool2o`0000cooooo1?l00003
ooooo`;o000000?oooooo`000?l000000_ooool4o`0000[ooooo0_l0000Fooooo`;o0000=oooool0
01cooooo00?o0000ooooooooool0;_ooool2o`0001;ooooo0ol0000=ooooo`;o00000_ooool2o`00
0003ooooool0003o000000;o00000_ooool6o`0000Kooooo0_l00002ooooo`;o00000_ooool2o`00
0004ooooool0003o0000ooooo`Co00002?ooool2o`0000;ooooo0_l00002ooooo`;o00003Oooool3
o`000003ooooool0003o000000_ooooo0_l0000Aooooo`;o00003?ooool2o`0001?ooooo0_l00000
0ooooooo0000o`000004ooooo`;o00000_ooool4o`0000;ooooo0_l0000Dooooo`;o0000>oooool0
01cooooo00?o0000ooooooooool0@oooool2o`00013ooooo0_l00002ooooo`Co00000_ooool4o`00
00?ooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000003oooo
o`;o00002?ooool2o`0000[ooooo1Ol00004ooooo`;o0000<Oooool4o`0000Cooooo0_l00004oooo
o`;o00004?ooool2o`000003ooooool0003o000000;o00000_ooool2o`00017ooooo0_l000000ooo
oooo0000o`00000kooooo`007?ooool00ol0003oooooooooo`16ooooo`;o00003Oooool2o`0000;o
oooo0_l000000ooooooo0000o`000008ooooo`;o00003Oooool2o`0001Oooooo2?l000001?oooooo
0000o`000?ooool2o`0000?ooooo0_l0000Pooooo`;o00001_ooool2o`0000;ooooo1?l00004oooo
o`?o000000?oooooo`000?l000000_l0000@ooooo`;o00000oooool4o`0001?ooooo0_l0000noooo
o`007?ooool00ol0003oooooooooo`0aooooo`;o00004oooool2o`0000oooooo1?l000001?oooooo
0000o`000?l00003ooooo`;o00003?ooool2o`0000?ooooo0_l0000Gooooo`?o00000oooool8o`00
00?ooooo0_l0000Pooooo`;o00001_ooool2o`000003ooooool0003o000000;ooooo0_l00004oooo
o`;o000000?oooooo`000?l000005oooool4o`0001;ooooo0_l0000oooooo`007?ooool00ol0003o
ooooooooo`0aooooo`;o00004oooool2o`0000oooooo1?l00002ooooo`;o00000oooool2o`0000;o
oooo0_l00008ooooo`;o00007?ooool2o`0000Cooooo2?l0000Eooooo`;o00001?ooool2o`0000So
oooo0_l00009ooooo`;o00000_ooool2o`0000Oooooo0_l000000ooooooo0000o`00000Cooooo`;o
000000?oooooo`000?l000000_l00002ooooo`?o00002Oooool4o`0003oooooo000Looooo`03o`00
0?oooooooooo03;ooooo0_l0000Sooooo`?o00002?ooool2o`0000;ooooo0_l0000<ooooo`Co0000
1?ooool2o`00013ooooo0_l00004ooooo`?o000000?oooooo`000?l000005oooool2o`0000Cooooo
0_l00008ooooo`;o00005_ooool2o`000003ooooool0003o000000Cooooo0ol0000<ooooo`;o0000
0_ooool8o`0000Cooooo0_l000000ooooooo0000o`000002o`00047ooooo000Looooo`03o`000?oo
oooooooo03;ooooo0_l000000ooooooo0000o`00000Rooooo`;o00001oooool2o`000003ooooool0
003o000000Sooooo0_l00003ooooo`Go00000oooool2o`0000Kooooo1?l0000<ooooo`?o00007ooo
ool2o`00017ooooo0_l0000Gooooo`Co00003oooool6o`0000Kooooo0_l000001?oooooo0000o`00
0?ooool2o`00043ooooo000Looooo`03o`000?oooooooooo037ooooo0_l00002ooooo`;o00004ooo
ool2o`0000_ooooo1?l00007ooooo`;o000000?oooooo`000?l000002?ooool2o`0000?ooooo1ol0
0003ooooo`;o00001?ooool4o`0000Gooooo1?l00005ooooo`;o00001?ooool2o`0000Gooooo0_l0
000;ooooo`;o00001?ooool3o`00013ooooo0_l0000Iooooo`;o00004?ooool4o`0000[ooooo0_l0
00000ooooooo0000o`000010ooooo`007?ooool00ol0003oooooooooo`0aooooo`;o000000Cooooo
o`000?l0003o00004oooool2o`0000_ooooo0_l00009ooooo`;o00004?ooool3o`0000;ooooo0_l0
00000ooooooo0000o`000002o`0000Gooooo0_l00006ooooo`Co00001Oooool2o`0000Cooooo0_l0
0004ooooo`?o00002oooool2o`0000Cooooo0ol0000Iooooo`;o00004?ooool2o`0001kooooo0_l0
0013ooooo`007?ooool00ol0003oooooooooo`0dooooo`?o00006_ooool2o`0000Cooooo0_l00004
ooooo`;o000000?oooooo`000?l000001?ooool2o`0000oooooo0_l00003ooooo`;o00002oooool2
o`0000;ooooo0_l00007ooooo`?o00001Oooool6o`0002Gooooo0_l00007ooooo`;o000000?ooooo
o`000?l000001oooool3o`0000?ooooo0_l00008ooooo`;o0000FOooool001cooooo00?o0000oooo
ooooool0=?ooool2o`0001_ooooo0_l00003ooooo`?o00000oooool3o`000003ooooool0003o0000
00?ooooo0ol00003ooooo`;o00000oooool2o`0000Gooooo0_l0000;ooooo`;o00000_ooool3o`00
0004ooooool0003o0000o`0000Oooooo0ol00004ooooo`Oo00005_ooool2o`0000gooooo0_l0000:
ooooo`;o00001_ooool4o`0000Sooooo0_l00003ooooo`?o00003Oooool2o`0004Wooooo000Loooo
o`03o`000?oooooooooo05Kooooo0ol00003ooooo`;o00001oooool2o`0000Cooooo0_l00003oooo
o`;o00001Oooool2o`0000_ooooo0ol000000ooooooo0000o`000004o`0000;ooooo0_l0000;oooo
o`?o000000Coooooo`000?l0003o00005_ooool2o`0000oooooo0_l00005ooooo`Co00001oooool4
o`0000Sooooo0ol00002ooooo`?o00003Oooool2o`0004Wooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003ooooo
ooooo`1;ooooo`;o00002_ooool2o`0000cooooo0_l00002ooooo`Co00001_ooool4o`0000Sooooo
0_l00004ooooo`;o00000oooool2o`0000Cooooo0_l00003ooooo`;o00001oooool6o`000003oooo
ool0003o000002Cooooo0_l00004ooooo`Go000000Coooooo`000?l0003ooooo1ol00009ooooo`;o
0000GOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMg
MoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo03;ooooo0_l0000Gooooo`;o00005?ooool2
o`0000;ooooo1_l00002ooooo`;o00001?ooool6o`0000Kooooo0_l00005ooooo`;o00002Oooool2
o`0000;ooooo0ol00006ooooo`Co00000oooool2o`0002Gooooo0ol00002ooooo`Go000000?ooooo
o`000?l000002?l000001?oooooo0000o`000?l00007ooooo`;o00001?ooool2o`0005Gooooo0000
0ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo03;ooooo0_l00002ooooo`?o00006?ooool2o`0000gooooo0ol0
0002ooooo`co000000?oooooo`000?l000001_l0000<ooooo`;o00002Oooool9o`0000Cooooo0ol0
0003ooooo`;o00004_ooool2o`00017ooooo1?l00002ooooo`_o000000?oooooo`000?l000001ol0
0006ooooo`;o00001?ooool2o`0005Gooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo00Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000=_ooool3o`0001Sooooo0_l0
000=ooooo`Go00000_oooolCo`0000Oooooo1?l00002ooooo`;o00002Oooool4o`000004ooooool0
003o0000o`0000?ooooo0_l00003ooooo`Co00004_ooool2o`0000Cooooo0_l00002ooooo`;o0000
1oooool2o`0000Cooooo5Ol00003ooooo`;o00000oooool2o`0000Oooooo1Ol00004ooooo`;o0000
Aoooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oEEEEo`00
0?l@413oc<c<00Kooooo00?o0000ooooooooool0>?ooool2o`00017ooooo0_l0000DoooooaGo0000
00Coooooo`000?l0003o00001oooool4o`0000;ooooo0_l00006ooooo`Ko00000oooool4o`000003
ooooool0003o000000?ooooo0_l0000Jooooo`;o00000_ooool2o`0000_ooooo5_l00004ooooo`;o
00000oooool2o`0000Oooooo1Ol00004ooooo`;o0000Aoooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo03Sooooo
0_l0000Aooooo`;o00001oooool2o`0000Wooooo1?l000000ooooooo0000o`00000@o`000003oooo
ool0003o000000;o00000oooool2o`0000;ooooo0_l0000;ooooo`Co00001_ooool3o`000003oooo
ool0003o000000;o00004Oooool2o`0001Kooooo0_l00003ooooo`;o00000_oooolBo`00017ooooo
0_l000000ooooooo0000o`00001>ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03
omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0Boooool2o`0000Kooooo0ol00002ooooo`;o
00001OoooolLo`0000?ooooo0_l0000@ooooo`;o00001?ooool2o`000004ooooool0003o0000o`00
00;ooooo0ol000000ooooooo0000o`00000>ooooo`?o00003_ooool2o`0000Gooooo0_l00008oooo
oa7o00003?ooool4o`000003ooooool0003o000000;o00001?ooool2o`0004Wooooo00001_oooooo
k^k^oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003ooooooooo
o`1;ooooo`;o00001_ooool2o`0000?ooooo0_l00003ooooo`;o00000ooooolHo`0000Sooooo0_l0
0005ooooo`;o00001?ooool3o`0000?ooooo0ol00002ooooo`[o00003oooool2o`0000;ooooo0_l0
000:ooooo`;o00003OoooolFo`0000Kooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l0
0004ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0??ooool2o`0000gooooo0_l0000@
ooooo`Co00000_oooolGo`000003ooooool0003o000000?ooooo1?l00005ooooo`;o00001?ooool2
o`0000Cooooo0_l00005ooooo`Ko00001?ooool2o`0000_ooooo0_l00002ooooo`;o00001_ooool2
o`0000Sooooo0_l00005oooooaSo00001_ooool2o`0000?ooooo0_l00003ooooo`;o0000Coooool0
01cooooo00?o0000ooooooooool0??ooool2o`0000gooooo0_l0000@oooooaco00000_ooool4o`00
0004ooooool0003o0000ooooo`;o00002_ooool2o`0000_ooooo1_l00004ooooo`;o00002oooool2
o`0000;ooooo0_l00006ooooo`;o00001oooool3o`0000Gooooo6?l0000;ooooo`;o0000E?ooool0
01cooooo00?o0000ooooooooool0??ooool2o`0001oooooo0_l000000ooooooo0000o`00000Io`00
00;ooooo0_l00002ooooo`Co00002?ooool2o`000003ooooool0003o000000_ooooo1Ol0000;oooo
o`;o00004?ooool2o`0000Oooooo0_l00006oooooaSo00002oooool2o`0005Cooooo000Looooo`03
o`000?oooooooooo05;ooooo0_l00006oooooa3o000000?oooooo`000?l000002ol000000ooooooo
0000o`000006ooooo`;o00002?ooool4o`000003ooooool0003o000000_ooooo1_l0000:ooooo`;o
00008_ooool3o`000003ooooool0003o0000017o00002oooool2o`0000Gooooo0_l0001=ooooo`00
7?ooool00ol0003oooooooooo`1Booooo`;o00001?oooolBo`000003ooooool0003o000000go0000
1oooool2o`0000Sooooo0ol0000Cooooo`Co0000;Oooool9o`000003ooooool0003o000000Ko0000
00Coooooo`000?l0003ooooo0ol0000?ooooo`;o000000?oooooo`000?l00000B_ooool001cooooo
00?o0000ooooooooool0@Oooool2o`0000oooooo0_l00004ooooo`;o00000_oooolNo`00017ooooo
0_l00002ooooo`;o00004?ooool6o`0000oooooo0_l0000>ooooo`;o00000_ooool2o`0000Kooooo
5Ol000001?oooooo0000o`000?l00002ooooo`;o00002Oooool2o`0000?ooooo0_l0001:ooooo`00
7?ooool00ol0003oooooooooo`11ooooo`;o00002Oooool2o`0000Cooooo0_l000001?oooooo0000
o`000?l00003oooooa[o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00006ooooo`Co
00001Oooool2o`0000Oooooo0_l0000;ooooo`;o00001_ooool2o`0000?ooooo0ol000001?oooooo
0000o`000?l00005ooooo`;o00001Oooool3o`0000;ooooo0_l00006oooooaGo00001_ooool2o`00
00;ooooo1?l00002ooooo`?o00001?ooool2o`0004Wooooo000Looooo`03o`000?oooooooooo04;o
oooo0_l00008ooooo`;o00001oooool3o`0000?ooooo7Ol00002ooooo`;o00000_ooool2o`0000Ko
oooo1?l000000ooooooo0000o`000009ooooo`Ko00003Oooool2o`0000;ooooo0_l00003ooooo`?o
00000_ooool2o`0000Gooooo0ol000001?oooooo0000o`000?ooool2o`0000?ooooo0_l00005oooo
oaGo000000?oooooo`000?l000001_ooool6o`0000;ooooo0_l00005ooooo`;o0000BOooool001co
oooo00?o0000ooooooooool0@_ooool2o`00017ooooo0_l00005ooooo`;o000000?oooooo`000?l0
00001ol000000ooooooo0000o`00000;o`0000[ooooo0_l00003ooooo`Co00000_ooool2o`0000Wo
oooo0_l00002ooooo`;o000000?oooooo`000?l000002_ooool2o`0000Wooooo0_l00007ooooo`Co
000000?oooooo`000?l000003OoooolEo`000003ooooool0003o000000Kooooo0_l000000ooooooo
0000o`000005ooooo`Co0000C?ooool001cooooo00?o0000ooooooooool0Eoooool2o`0000?ooooo
0_l000000ooooooo0000o`00000Fo`000003ooooool0003o000000Kooooo0_l00003ooooo`Co0000
00Coooooo`000?l0003o00002_ooool2o`0000Cooooo0_l00003ooooo`;o00003Oooool2o`000003
ooooool0003o000000Oooooo0_l00003ooooo`;o000000?oooooo`000?l000001?ooool2o`0000So
oooo2?l000000ooooooo0000o`000003o`0000Gooooo0_l00007ooooo`?o00001Oooool4o`0004co
oooo000Looooo`03o`000?oooooooooo05Oooooo0_l00006oooooaSo000000?oooooo`000?l00000
1_ooool2o`0000Cooooo0_l000000ooooooo0000o`000002o`0000[ooooo0_l00004ooooo`;o0000
0oooool2o`0000gooooo0_l00009ooooo`;o00001?ooool2o`000003ooooool0003o000000Cooooo
0_l0000:ooooo`co000000?oooooo`000?l000000_ooool2o`0000Oooooo0_l0001Fooooo`007?oo
ool2o`00063ooooo5ol00003ooooo`;o00002oooool2o`000003ooooool0003o000002Cooooo0_l0
000;ooooo`;o00003oooool2o`0000[ooooo2_l000000ooooooo0000o`000004ooooo`?o0000G?oo
ool001cooooo00?o0000ooooooooool0F_ooool2o`0000?ooooo0_l00002ooooo`oo00000_ooool2
o`0000?ooooo0_l0000:ooooo`Co00001Oooool2o`0001oooooo0ol00009ooooo`;o00003_ooool4
o`0000[ooooo1ol000000ooooooo0000o`000006o`000003ooooool0003o000000?o0000F_ooool0
01cooooo00?o0000ooooooooool0A?ooool2o`0001?ooooo0ol00003ooooo`;o00000_ooool?o`00
00[ooooo0_l00002ooooo`;o00000oooool4o`0000;ooooo0_l000000ooooooo0000o`00000Poooo
o`?o00002?ooool2o`0000Sooooo0_l00004ooooo`?o000000?oooooo`000?l000002Oooool2o`00
0004ooooool0003o0000o`0000;ooooo0_l00002ooooo`Co00000oooool2o`0005[ooooo000Loooo
o`03o`000?oooooooooo04Cooooo0_l0000Cooooo`;o00001?ooool2o`000003ooooool0003o0000
00So000000?oooooo`000?l000003Oooool3o`000004ooooool0003o0000ooooo`Ko00000_ooool2
o`0001Oooooo0_l00006ooooo`;o00000oooool3o`00017ooooo0_l00005ooooo`;o000000?ooooo
o`000?l000001Oooool2o`0000Gooooo1_l000001?oooooo0000o`000?ooool3o`0000Sooooo0_l0
001Eooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00004oooool2o`0000Cooooo0_l00000
0ooooooo0000o`000008o`0000?ooooo0_l00006ooooo`;o00001?ooool2o`0000Cooooo0_l00006
ooooo`;o00004?ooool2o`0000Gooooo0_l00006ooooo`;o00001?ooool2o`0002;ooooo0_l00007
ooooo`Co000000Coooooo`000?l0003ooooo1?l00007ooooo`;o0000EOooool001cooooo00?o0000
ooooooooool0A?ooool2o`0000kooooo0_l00003ooooo`?o00001oooool>o`0000Kooooo0_l0000G
ooooo`;o00002_ooool3o`0000cooooo1?l00005ooooo`;o00003_ooool2o`0000_ooooo1?l00004
ooooo`Go000000?oooooo`000?l000000oooool2o`0000?ooooo0_l0001Nooooo`007?ooool00ol0
003oooooooooo`1Dooooo`;o00000oooool3o`0000Wooooo0ol00004ooooo`?o00001_ooool2o`00
00;ooooo0ol00007ooooo`;o00001_ooool2o`0000?ooooo1?l00005ooooo`;o000000?oooooo`00
0?l000000_l00003ooooo`?o00001Oooool4o`0000Gooooo0_l00003ooooo`?o00001?ooool2o`00
00;ooooo0_l0000;ooooo`Co00000_ooool7o`0000?ooooo1Ol0001Sooooo`007?ooool00ol0003o
ooooooooo`1>ooooo`;o00003?ooool2o`0001Oooooo0_l00002ooooo`Co00001Oooool4o`0000Go
oooo1?l000000ooooooo0000o`000002o`0000Gooooo0_l000000ooooooo0000o`00000;o`000003
ooooool0003o000000Co00002Oooool3o`000004ooooool0003o0000ooooo`;o00004?ooool2o`00
00?ooooo0_l000000ooooooo0000o`000005ooooo`?o0000IOooool001cooooo00?o0000oooooooo
ool0C_ooool2o`000003ooooool0003o000000Gooooo0ol000000ooooooo0000o`000006ooooo`;o
00005?ooool3o`0000Gooooo1?l00007ooooo`;o00002oooool?o`000003ooooool0003o000000Ko
00002oooool2o`0001_ooooo1?l0000;ooooo`;o0000G_ooool001cooooo00?o0000ooooooooool0
C_ooool2o`000003ooooool0003o000000Gooooo1?l000000ooooooo0000o`000005ooooo`;o0000
1oooool2o`000003ooooool0003o000000Sooooo0_l00004ooooo`;o000000?oooooo`000?l00000
2Oooool2o`0000[ooooo6?l0000Zooooo`;o00002oooool2o`0005kooooo000Looooo`03o`000?oo
oooooooo04Kooooo0_l0000Booooo`;o000000?oooooo`000?l000001Oooool2o`0000Oooooo0_l0
00000ooooooo0000o`000002ooooo`;o00002_ooool2o`000003ooooool0003o000000Wooooo0_l0
000<ooooo`[o000000?oooooo`000?l000001Ol00003ooooo`;o0000U_ooool001cooooo00?o0000
ooooooooool0A_ooool2o`0000oooooo0ol00003ooooo`?o00002_ooool2o`0000Sooooo1?l0000R
ooooo`?o00000_oooolAo`000003ooooool0003o000009Kooooo000Looooo`03o`000?oooooooooo
04oooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000;o00000_ooool3o`00
00Wooooo0ol00008ooooo`Co00008?oooolEo`000004ooooool0003o0000ooooo`;o00004_ooool4
o`00083ooooo000Looooo`03o`000?oooooooooo04Oooooo0_l00006ooooo`;o000000?oooooo`00
0?l000000_l00003ooooo`;o00003_ooool2o`0000Wooooo0_l0000Booooo`;o00003OoooolHo`00
00kooooo0_l00006ooooo`Co0000P?ooool001cooooo00?o0000ooooooooool0Aoooool2o`0001So
oooo0_l0000Uooooo`;o00003OoooolHo`000003ooooool0003o000000;ooooo0_l00007ooooo`;o
0000R_ooool001cooooo00?o0000ooooooooool0HOooool4o`0003?ooooo6_l000001?oooooo0000
o`000?l0002Cooooo`007?ooool2o`0005gooooo0_l00004ooooo`?o00004?ooool2o`00027ooooo
6Ol00002ooooo`;o0000U?ooool001cooooo00?o0000ooooooooool0G?ooool4o`0000;ooooo0_l0
000Aooooo`;o00006_ooool2o`0000Gooooo6Ol00002ooooo`;o00005?ooool2o`0007kooooo000L
ooooo`03o`000?oooooooooo05_ooooo0_l000001?oooooo0000o`000?l0000Dooooo`;o00006_oo
ool2o`0000?ooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o0000013o00001?oo
ool2o`0001;ooooo0_l0001nooooo`007?ooool00ol0003oooooooooo`1Dooooo`?o00001?ooool7
o`0000_ooooo0_l0000Iooooo`;o00003?oooolLo`0000?ooooo0_l0002Booooo`007?ooool00ol0
003oooooooooo`1Dooooo`?o00001_ooool2o`000003ooooool0003o000000_ooooo0_l0000Ioooo
o`;o00003OoooolKo`000003ooooool0003o000000oooooo0_l00004ooooo`;o0000OOooool001co
oooo00?o0000ooooooooool0D_ooool2o`000004ooooool0003o0000ooooo`;o00001Oooool2o`00
017ooooo0_l00008ooooo`?o00002Oooool2o`0000Sooooo0_l00003ooooo`;o00000_oooolGo`00
0003ooooool0003o000000oooooo0_l00004ooooo`?o00000_ooool2o`0007Sooooo000Looooo`03
o`000?oooooooooo05;ooooo0_l000001?oooooo0000o`000?ooool2o`0000Gooooo0_l0000Aoooo
o`;o00002?ooool3o`0001?ooooo0_l00003ooooo`;o000000?oooooo`000?l000004ol000000ooo
oooo0000o`00000Iooooo`;o00000_ooool2o`0003Cooooo0_l00012ooooo`007?ooool00ol0003o
ooooooooo`1Nooooo`;o00002Oooool2o`0000Oooooo0_l0000=ooooo`;o00005OoooolJo`0005?o
oooo0_l00012ooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o00000oooool2o`0000Cooooo
0_l0000Fooooo`;o00005?oooolKo`000003ooooool0003o000009Cooooo000Looooo`03o`000?oo
oooooooo05kooooo0_l00003ooooo`;o00004_ooool2o`0001kooooo6_l000001Ooooooo0000o`00
0?l0003ooooo00;o00002Oooool2o`0003oooooo0_l00015ooooo`007?ooool00ol0003ooooooooo
o`1Xooooo`;o00000oooool2o`0000Sooooo1?l0000Noooooa_o00000_ooool2o`0000Wooooo0_l0
000oooooo`;o0000AOooool001cooooo00?o0000ooooooooool0HOooool2o`000003ooooool0003o
000000;ooooo2Ol00004ooooo`;o00000_ooool2o`0001oooooo1_l000000ooooooo0000o`00000@
o`0001Sooooo0_l0001looooo`007?ooool00ol0003oooooooooo`1Qooooo`;o000000?oooooo`00
0?l000000_ooool5o`0000;ooooo1?l00002ooooo`;o00008Oooool3o`0000;ooooo0ol000000ooo
oooo0000o`00000>o`0000[ooooo0_l0000>ooooo`;o000000?oooooo`000?l000000oooool2o`00
07Cooooo000Looooo`03o`000?oooooooooo06kooooo1ol0000Soooooa_o00001oooool3o`00017o
oooo0_l00003ooooo`;o0000M?ooool001cooooo00?o0000ooooooooool0HOooool6o`0000Cooooo
0_l000000ooooooo0000o`000002o`000003ooooool0003o000002?ooooo6ol000000ooooooo0000
o`000004ooooo`Co00005oooool2o`0007;ooooo000Looooo`03o`000?oooooooooo067ooooo1_l0
0003ooooo`Oo000000?oooooo`000?l000000_ooool2o`00023ooooo0_l000001?oooooo0000o`00
0?oooolDo`0000;ooooo0_l00006ooooo`;o000000?oooooo`000?l000005?ooool2o`0007;ooooo
000Looooo`;o0000IOooool2o`0000?ooooo1_l00003ooooo`Ko00006oooool2o`0000?ooooo1Ol0
00000ooooooo0000o`00000>o`0000?ooooo0_l00003ooooo`;o00001?ooool2o`000003ooooool0
003o000008Sooooo000Looooo`03o`000?oooooooooo05Sooooo0ol00009ooooo`;o00000oooool2
o`0000;ooooo0_l00004ooooo`?o00007Oooool2o`0000?ooooo1?l00004oooooa3o000000?ooooo
o`000?l000000_ooool3o`000004ooooool0003o0000o`0008gooooo000Looooo`03o`000?oooooo
oooo05Sooooo0ol0000>ooooo`;o0000:Oooool2o`0000[ooooo2Ol00004ooooo`?o00000oooool4
o`0000;ooooo0ol00002ooooo`;o0000ROooool001cooooo00?o0000ooooooooool0H?ooool2o`00
00Oooooo1?l0000Wooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`Oo000000Cooooo
o`000?l0003ooooo0ol00003ooooo`Co00002?ooool2o`0008Wooooo000Looooo`03o`000?oooooo
oooo063ooooo0_l00007ooooo`Co00009oooool2o`0000Gooooo0_l000000ooooooo0000o`000002
o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo0_l0002A
ooooo`007?ooool00ol0003oooooooooo`1Xooooo`?o00003oooool2o`0002?ooooo2?l0000?oooo
o`;o0000TOooool001cooooo00?o0000ooooooooool0E_ooool2o`0000Cooooo0_l0000:ooooo`?o
00003oooool2o`0002Gooooo1?l000000ooooooo0000o`000006ooooo`;o00001oooool2o`0003oo
oooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`1Fooooo`?o00000oooool2o`0003oooooo
1?l00005ooooo`;o00001_ooool2o`0000Oooooo0_l0000oooooo`;o0000Coooool001cooooo00?o
0000ooooooooool0Eoooool2o`0001?ooooo0_l0000Yooooo`?o00000_ooool5o`000:Sooooo000L
ooooo`03o`000?oooooooooo06cooooo0_l0000Yooooo`?o00000_ooool5o`0000?ooooo0_l0002S
ooooo`007?ooool00ol0003oooooooooo`1Yooooo`;o0000<_ooool2o`0000Gooooo0_l00004oooo
o`;o00001oooool2o`0009Cooooo000Looooo`03o`000?oooooooooo05Wooooo0_l0000>ooooo`;o
0000=_ooool2o`0000Gooooo1?l00007ooooo`;o00000oooool2o`0008oooooo000Looooo`03o`00
0?oooooooooo05Wooooo0_l00016ooooo`;o00001Oooool2o`0000kooooo0_l0000Rooooo`;o0000
Joooool001cooooo00?o0000ooooooooool0[_ooool2o`0002_ooooo0ol0001[ooooo`0000Kooooo
onk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Ko
oooo00?o0000ooooooooool0K?ooool3o`0003kooooo1?l00002ooooo`;o00001?ooool2o`00023o
oooo0_l0000Cooooo`;o0000Eoooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q
8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo06cooooo1?l0000_
ooooo`;o00003?ooool8o`0000Cooooo0_l0000Nooooo`;o00005Oooool2o`0005Oooooo00000ooo
oooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo06kooooo0_l0000_ooooo`;o00003oooool4o`0000Gooooo0_l0000L
ooooo`Co0000K_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Olb
<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0001hooooo`;o00001_ooool2o`0005Gooooo0_l0001`
ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05olc<c?l0003o0000
o`000?o<c<`01_ooool00ol0003oooooooooo`1hooooo`;o00001_ooool2o`000<Oooooo00000ooo
oooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go410@okZj^_oooooo^[Zjoa0@4006
ooooo`03o`000?oooooooooo0?ooooooB_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2ooo
ool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0oooooom:ooooo`0000Ko
ooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0
003oooooooooo`3@ooooo`;o0000Moooool001cooooo00?o0000ooooooooool0M?ooool2o`0000;o
oooo0_l0000/ooooo`;o00000_ooool2o`0002;ooooo1?l0000Eooooo`;o0000H?ooool001cooooo
00?o0000ooooooooool0M?ooool2o`0000;ooooo0_l0000/ooooo`;o00000_ooool2o`0000Sooooo
0_l0000Hooooo`;o00005oooool2o`00063ooooo000Looooo`03o`000?oooooooooo0;Cooooo0_l0
000?ooooo`;o000000?oooooo`000?l00000Ooooool001cooooo00?o0000ooooooooool0L_ooool3
o`0000Cooooo0_l0000booooo`;o00004oooool2o`000004ooooool0003o0000ooooo`;o00006?oo
ool2o`0006Gooooo000Looooo`03o`000?oooooooooo07;ooooo0ol00004ooooo`;o0000;oooool2
o`000003ooooool0003o000000?ooooo0_l00005ooooo`;o00001oooool2o`0001kooooo0_l0001U
ooooo`007?ooool00ol0003oooooooooo`1cooooo`;o00002oooool5o`0002Gooooo0_l00006oooo
o`;o00001Oooool2o`0008kooooo000Looooo`03o`000?oooooooooo083ooooo1Ol0001Iooooo`;o
0000JOooool001cooooo00?o0000ooooooooool0N?ooool2o`0000Wooooo0_l00002ooooo`;o0000
EOooool2o`0006Wooooo000Looooo`03o`000?oooooooooo06kooooo0_l00008ooooo`;o00002Ooo
ool2o`0000;ooooo0_l00005ooooo`;o00005_ooool2o`000:7ooooo000Looooo`03o`000?oooooo
oooo06kooooo0_l0000Nooooo`;o00005_ooool4o`0009oooooo000Looooo`03o`000?oooooooooo
073ooooo0_l0000booooo`;o00000_ooool2o`0009oooooo000Looooo`;o0000LOooool2o`0003;o
oooo0_l0000`ooooo`;o0000LOooool001cooooo00?o0000ooooooooool0T_ooool2o`0000Cooooo
0_l0000looooo`;o0000LOooool001cooooo00?o0000ooooooooool0T_ooool2o`0000Cooooo0_l0
00000ooooooo0000o`000006ooooo`;o0000Y?ooool001cooooo00?o0000ooooooooool0Voooool2
o`0000Kooooo0_l0000Zooooo`;o0000N?ooool001cooooo00?o0000ooooooooool0M_ooool2o`00
00oooooo0_l0000;ooooo`;o0000=oooool4o`0007Sooooo000Looooo`03o`000?oooooooooo07Ko
oooo0_l0000?ooooo`;o00002oooool6o`0003?ooooo0_l0001jooooo`007?ooool00ol0003ooooo
ooooo`2=ooooo`;o00001oooool4o`000003ooooool0003o000002[ooooo0_l00020ooooo`007?oo
ool00ol0003oooooooooo`2=ooooo`;o000000?oooooo`000?l000002Oooool2o`0002[ooooo0_l0
0020ooooo`007?ooool00ol0003oooooooooo`2@ooooo`;o00000oooool2o`0000Kooooo0_l00000
0ooooooo0000o`00002Wooooo`007?ooool00ol0003oooooooooo`2Eooooo`;o00001_ooool2o`00
0003ooooool0003o00000:Oooooo000Looooo`03o`000?oooooooooo0:7ooooo0_l0002Vooooo`00
7?ooool00ol0003oooooooooo`2Qooooo`;o00001?ooool2o`0001Gooooo0ol00028ooooo`007?oo
ool00ol0003oooooooooo`2Wooooo`;o00005Oooool3o`0008Sooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0Qoooool2o`0001Sooooo0ol0002Uoooo
o`007?ooool00ol0003oooooooooo`27ooooo`;o00006?ooool3o`0000?ooooo0_l0002Pooooo`00
7?ooool2o`000:Sooooo0_l00009ooooo`Co0000Toooool001cooooo00?o0000ooooooooool0/_oo
ool4o`0009?ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBooo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
4_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom:ooooo`005?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000
ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o0000ooooooooool0oooooomBoooo
o`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?oooooo
D_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`004_ooool00omEEEGoIVIVo`00003o
oooooeCooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Uooooo`04oa0@4?l0
003o0000ooooo`;o000000?o410@ooooooooool05oooool2o`000009oa0@4?oooooooooooooooonH
V9So410@o`000?lb<S;oc<c<00?ooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c02@ooooo`00Y_ooool0
1Ol0003ooooooooooooooooo000000Wooooo1_l0000<ooooo`03o`000?oooooooooo00;ooooo00Go
410@okZj^_ooooooMgMgoc8b<P03ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40T?ooool00:Kooooo
00Go0000ooooooooooooooooo`00000Hooooo`Go00001oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool0S_ooool00:Kooooo00Go0000ooooooooooooooooo`000009oooo
o`Ko00002Oooool01?m4A4CogMgMooooool00007ooooo`03ojVYZOl@413ooooo00;ooooo00Go<S8b
oiRHV?ooooooV9RHoc8b<P2@ooooo`00Y_ooool01Ol0003oQhN7oooooonYZJWo000001Sooooo00Co
gMgMoeEEEOoooooo00001_ooool00ol@413o0000okZj^P03ooooo`05olc<c?l0003o0000o`000?o<
c<`0T?ooool00:Gooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Gooooo`03ogMg
Moo<c<co000000Oooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413o^[Zjoooooonj^[[o410@093o
oooo0034ooooo`03onk^k_m4A4Co000000Cooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05
o`000?nj^[[ooooookZj^_l00000T?ooool00<Gooooo00?oMgMgo`000?ooool00oooool01OnYZJWo
410@o`000?l@413oZJVY00?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2@ooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(444) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.37007 .35939 Mdot
.3939 .37897 Mdot
.5192 .70103 Mdot
.58989 .45276 Mdot
.64956 .66952 Mdot
.48157 .72804 Mdot
.3372 .59275 Mdot
.33361 .58524 Mdot
.47031 .71962 Mdot
.44087 .2644 Mdot
.3131 .61596 Mdot
.57087 .37009 Mdot
.32463 .60194 Mdot
.60437 .42247 Mdot
.44897 .44284 Mdot
.61012 .48257 Mdot
.42545 .39508 Mdot
.659 .6128 Mdot
.58839 .48095 Mdot
.49721 .68195 Mdot
.73326 .37139 Mdot
.6129 .41213 Mdot
.42437 .34534 Mdot
.60581 .41903 Mdot
.57416 .40957 Mdot
.40909 .37447 Mdot
.37017 .35424 Mdot
.58416 .39933 Mdot
.60725 .36747 Mdot
.31175 .61002 Mdot
.54298 .67604 Mdot
.63447 .20201 Mdot
.64967 .44178 Mdot
.59251 .24589 Mdot
.34017 .58756 Mdot
.36925 .55915 Mdot
.49779 .69266 Mdot
.31573 .63309 Mdot
.34066 .58462 Mdot
.35071 .59627 Mdot
.34588 .61285 Mdot
.41574 .371 Mdot
.35729 .60807 Mdot
.37621 .78959 Mdot
.58893 .43321 Mdot
.44382 .42639 Mdot
.30267 .7425 Mdot
.59257 .38298 Mdot
.41122 .39359 Mdot
.49776 .67739 Mdot
.75388 .60027 Mdot
.29088 .61584 Mdot
.36715 .50334 Mdot
.60592 .88163 Mdot
.32415 .61239 Mdot
.55943 .43894 Mdot
.46162 .71021 Mdot
.62571 .43237 Mdot
.59248 .4587 Mdot
.56787 .21891 Mdot
.63121 .41143 Mdot
.67901 .64691 Mdot
.45275 .37129 Mdot
.45859 .7418 Mdot
.47106 .72639 Mdot
.31483 .63205 Mdot
.43314 .34156 Mdot
.31675 .59463 Mdot
.62277 .372 Mdot
.51247 .68839 Mdot
.60325 .36985 Mdot
.30898 .61129 Mdot
.39996 .33321 Mdot
.58603 .43159 Mdot
.30488 .50708 Mdot
.25347 .6467 Mdot
.51278 .76359 Mdot
.67786 .28127 Mdot
.77855 .64499 Mdot
.53273 .63515 Mdot
.59457 .41527 Mdot
.62324 .83084 Mdot
.47377 .50858 Mdot
.38531 .37513 Mdot
.36774 .3139 Mdot
.30007 .34829 Mdot
.59195 .3877 Mdot
.48069 .61886 Mdot
.59267 .47163 Mdot
.61613 .59381 Mdot
.4693 .70345 Mdot
.38226 .36251 Mdot
.58868 .42768 Mdot
.64963 .41256 Mdot
.3699 .26739 Mdot
.56749 .38787 Mdot
.58401 .44837 Mdot
.351 .31636 Mdot
.3125 .62054 Mdot
.68624 .43984 Mdot
.72601 .63594 Mdot
.38776 .51478 Mdot
.56012 .4235 Mdot
.49321 .70334 Mdot
.45137 .38588 Mdot
.5764 .4441 Mdot
.32352 .58729 Mdot
.60052 .41286 Mdot
.33936 .57281 Mdot
.43839 .37307 Mdot
.64986 .43183 Mdot
.66181 .62231 Mdot
.67844 .49163 Mdot
.42647 .35457 Mdot
.58587 .31221 Mdot
.624 .40568 Mdot
.63512 .42539 Mdot
.39748 .38334 Mdot
.51075 .69487 Mdot
.43627 .75694 Mdot
.41526 .33872 Mdot
.35065 .59469 Mdot
.41409 .3976 Mdot
.53893 .4279 Mdot
.50434 .68982 Mdot
.37529 .51575 Mdot
.37973 .51933 Mdot
.68606 .55052 Mdot
.58733 .42245 Mdot
.65571 .51168 Mdot
.48965 .7127 Mdot
.41344 .37964 Mdot
.31522 .60256 Mdot
.55635 .44469 Mdot
.41758 .35494 Mdot
.32704 .57992 Mdot
.66437 .66805 Mdot
.63473 .63333 Mdot
.42432 .37983 Mdot
.50865 .36587 Mdot
.31908 .56368 Mdot
.35293 .60765 Mdot
.75104 .59804 Mdot
.38651 .37758 Mdot
.66597 .63431 Mdot
.31097 .58178 Mdot
.76959 .47152 Mdot
.603 .46267 Mdot
.71381 .57706 Mdot
.55237 .83909 Mdot
.75352 .60051 Mdot
.62671 .21829 Mdot
.66257 .62505 Mdot
.32363 .57838 Mdot
.59498 .37426 Mdot
.40403 .35827 Mdot
.41793 .36072 Mdot
.6419 .39912 Mdot
.57628 .42701 Mdot
.59785 .43635 Mdot
.58744 .46134 Mdot
.35126 .66158 Mdot
.59141 .42272 Mdot
.19578 .496 Mdot
.40896 .35159 Mdot
.56979 .42601 Mdot
.50862 .71084 Mdot
.68026 .42521 Mdot
.33926 .62615 Mdot
.59306 .45759 Mdot
.5759 .42013 Mdot
.54992 .41334 Mdot
.34839 .58753 Mdot
.28059 .51249 Mdot
.81025 .60661 Mdot
.3722 .58 Mdot
.24911 .62349 Mdot
.49336 .72535 Mdot
.63009 .39923 Mdot
.65437 .64442 Mdot
.68427 .43426 Mdot
.61706 .45296 Mdot
.75853 .60536 Mdot
.58719 .40869 Mdot
.65339 .24315 Mdot
.59563 .35342 Mdot
.3005 .36206 Mdot
.20386 .44126 Mdot
.61266 .45669 Mdot
.48113 .28444 Mdot
.69662 .57185 Mdot
.53103 .77242 Mdot
.31443 .60769 Mdot
.51087 .7264 Mdot
.51561 .70265 Mdot
.31093 .63409 Mdot
.62962 .3306 Mdot
.46 .26246 Mdot
.58411 .37256 Mdot
.38266 .5143 Mdot
.41514 .31685 Mdot
.66797 .62689 Mdot
.42236 .38282 Mdot
.6626 .80817 Mdot
.54955 .62758 Mdot
.48991 .62057 Mdot
.64978 .61036 Mdot
.47954 .6752 Mdot
.37592 .50736 Mdot
.66008 .63754 Mdot
.60345 .44694 Mdot
.43214 .38114 Mdot
.7122 .58052 Mdot
.6749 .44292 Mdot
.23863 .2804 Mdot
.37599 .34719 Mdot
.63704 .53793 Mdot
.32239 .60943 Mdot
.48136 .7534 Mdot
.59131 .38827 Mdot
.61748 .42805 Mdot
.43817 .341 Mdot
.60405 .37375 Mdot
.48941 .59462 Mdot
.57888 .41762 Mdot
.45766 .73832 Mdot
.62586 .67791 Mdot
.36414 .61161 Mdot
.66283 .60428 Mdot
.40751 .33404 Mdot
.23103 .63405 Mdot
.49966 .70288 Mdot
.69214 .38417 Mdot
.30806 .59762 Mdot
.65911 .66598 Mdot
.48989 .69496 Mdot
.66963 .61893 Mdot
.64348 .43846 Mdot
.49094 .68934 Mdot
.6801 .63866 Mdot
.45828 .5671 Mdot
.57853 .44735 Mdot
.71617 .52314 Mdot
.29304 .59628 Mdot
.38201 .37922 Mdot
.63308 .4407 Mdot
.37336 .49104 Mdot
.54718 .439 Mdot
.5728 .5298 Mdot
.37712 .49051 Mdot
.40042 .4923 Mdot
.50584 .60742 Mdot
.68483 .66323 Mdot
.31946 .53062 Mdot
.46474 .59589 Mdot
.42625 .39477 Mdot
.64401 .43355 Mdot
.35463 .44248 Mdot
.2941 .59164 Mdot
.60981 .44489 Mdot
.32208 .41013 Mdot
.31225 .58106 Mdot
.62998 .43231 Mdot
.34451 .61271 Mdot
.41302 .35751 Mdot
.46851 .53895 Mdot
.39281 .3953 Mdot
.59797 .45213 Mdot
.33577 .61874 Mdot
.51276 .72069 Mdot
.40906 .37366 Mdot
.60564 .41033 Mdot
.59926 .40319 Mdot
.38692 .51047 Mdot
.5795 .43465 Mdot
.31846 .35816 Mdot
.59005 .38547 Mdot
.50357 .67756 Mdot
.58356 .37474 Mdot
.73309 .62507 Mdot
.68098 .59523 Mdot
.44099 .35754 Mdot
.37911 .48945 Mdot
.47018 .69703 Mdot
.46313 .54704 Mdot
.69665 .51819 Mdot
.5963 .41942 Mdot
.38835 .49317 Mdot
.62636 .54276 Mdot
.3367 .62659 Mdot
.66219 .42864 Mdot
.43599 .6545 Mdot
.4732 .69989 Mdot
.37887 .5127 Mdot
.66385 .46 Mdot
.37148 .33828 Mdot
.55844 .4204 Mdot
.49713 .69434 Mdot
.38153 .38232 Mdot
.55878 .40061 Mdot
.2715 .69438 Mdot
.37284 .49109 Mdot
.32445 .62401 Mdot
.33992 .32711 Mdot
.63446 .39634 Mdot
.51779 .71091 Mdot
.4221 .36002 Mdot
.33487 .61078 Mdot
.42417 .34835 Mdot
.71349 .58703 Mdot
.57831 .52427 Mdot
.39609 .60072 Mdot
.69268 .62461 Mdot
.78538 .32325 Mdot
.36577 .55759 Mdot
.68769 .43477 Mdot
.53155 .69151 Mdot
.26392 .32123 Mdot
.48871 .69849 Mdot
.49797 .37402 Mdot
.46517 .70675 Mdot
.56738 .39966 Mdot
.47797 .72831 Mdot
.32715 .27159 Mdot
.5904 .39905 Mdot
.47523 .73661 Mdot
.39685 .64734 Mdot
.59291 .39985 Mdot
.4172 .35219 Mdot
.50781 .15857 Mdot
.64408 .29586 Mdot
.64516 .31064 Mdot
.45926 .7191 Mdot
.50895 .35465 Mdot
.58715 .3956 Mdot
.58078 .47961 Mdot
.40252 .36278 Mdot
.54957 .40513 Mdot
.69452 .65066 Mdot
.67926 .62215 Mdot
.765 .53645 Mdot
.72344 .31456 Mdot
.62637 .32574 Mdot
.41246 .36777 Mdot
.77337 .66264 Mdot
.3038 .50171 Mdot
.37171 .49269 Mdot
.33131 .58278 Mdot
.28334 .5267 Mdot
.63901 .47216 Mdot
.42004 .29858 Mdot
.48648 .58628 Mdot
.38002 .35639 Mdot
.41789 .58286 Mdot
.33825 .60567 Mdot
.64381 .30604 Mdot
.45897 .24383 Mdot
.59759 .43833 Mdot
.29832 .61926 Mdot
.55617 .3796 Mdot
.47448 .60884 Mdot
.70305 .54453 Mdot
.34184 .72968 Mdot
.59529 .45005 Mdot
.32642 .51681 Mdot
.62043 .45019 Mdot
.69239 .55436 Mdot
.60957 .44729 Mdot
.41731 .34625 Mdot
.55795 .4685 Mdot
.45942 .59049 Mdot
.79622 .39212 Mdot
.54598 .61763 Mdot
.68571 .63763 Mdot
.60722 .42318 Mdot
.60768 .43753 Mdot
.68115 .64696 Mdot
.3823 .35782 Mdot
.64287 .43098 Mdot
.27928 .73467 Mdot
.59087 .42171 Mdot
.29205 .62139 Mdot
.53763 .5495 Mdot
.69485 .25897 Mdot
.61086 .38688 Mdot
.37571 .33452 Mdot
.34777 .61424 Mdot
.30605 .59022 Mdot
.53019 .37047 Mdot
.29142 .60102 Mdot
.5989 .37301 Mdot
.53625 .54885 Mdot
.43502 .35605 Mdot
.61609 .34982 Mdot
.3836 .35072 Mdot
.76467 .67447 Mdot
.31081 .57995 Mdot
.38871 .48838 Mdot
.59972 .31848 Mdot
.33205 .59335 Mdot
.61087 .62508 Mdot
.55928 .469 Mdot
.6699 .42411 Mdot
.34129 .35112 Mdot
.51445 .72257 Mdot
.38151 .4941 Mdot
.32707 .61293 Mdot
.59134 .4261 Mdot
.5636 .43267 Mdot
.29132 .61132 Mdot
.51884 .19216 Mdot
.54426 .67953 Mdot
.59844 .45313 Mdot
.40632 .3434 Mdot
.41453 .37738 Mdot
.57985 .46311 Mdot
.62751 .44584 Mdot
.49151 .7369 Mdot
.3878 .49233 Mdot
.38182 .49009 Mdot
.38612 .51829 Mdot
.46586 .74201 Mdot
.78908 .33907 Mdot
.35294 .6083 Mdot
.65109 .21607 Mdot
.30636 .45569 Mdot
.51946 .39685 Mdot
.51073 .70187 Mdot
.62492 .42123 Mdot
.56566 .4083 Mdot
.33178 .61917 Mdot
.77809 .36062 Mdot
.56834 .47138 Mdot
.37358 .36543 Mdot
.29344 .61884 Mdot
.55918 .38199 Mdot
.30106 .56528 Mdot
.64573 .6405 Mdot
.62224 .31863 Mdot
.29011 .60353 Mdot
.4366 .36405 Mdot
.29 .60433 Mdot
.60428 .43764 Mdot
.66572 .45887 Mdot
.37933 .35493 Mdot
.63744 .64508 Mdot
.6461 .41062 Mdot
.62943 .43527 Mdot
.51617 .80598 Mdot
.30791 .50747 Mdot
.65516 .5964 Mdot
.57992 .38856 Mdot
.67076 .41171 Mdot
.63897 .63248 Mdot
.64292 .41194 Mdot
.58263 .37663 Mdot
.6659 .50778 Mdot
.34418 .57448 Mdot
.68331 .66941 Mdot
.7916 .39052 Mdot
.37462 .34934 Mdot
.32401 .37823 Mdot
.38265 .51673 Mdot
.32494 .64008 Mdot
.4633 .52987 Mdot
.38086 .50507 Mdot
.30778 .43446 Mdot
.20162 .60579 Mdot
.38336 .49531 Mdot
.46609 .74911 Mdot
.45671 .31168 Mdot
.59551 .36943 Mdot
.61025 .45271 Mdot
.68579 .66117 Mdot
.39842 .3877 Mdot
.20004 .48681 Mdot
.36615 .61256 Mdot
.62009 .40967 Mdot
.36665 .35627 Mdot
.29908 .35345 Mdot
.38029 .51055 Mdot
.65185 .63916 Mdot
.64215 .65992 Mdot
.62655 .44497 Mdot
.66761 .53941 Mdot
.41268 .3708 Mdot
.60569 .4104 Mdot
.6382 .41797 Mdot
.47055 .68977 Mdot
.42979 .38351 Mdot
.50673 .71153 Mdot
.38935 .48164 Mdot
.24686 .31898 Mdot
.42112 .83437 Mdot
.29545 .59331 Mdot
.42598 .51892 Mdot
.36015 .61782 Mdot
.30303 .71085 Mdot
.38702 .49154 Mdot
.60892 .4109 Mdot
.42061 .33835 Mdot
.60222 .41142 Mdot
.58985 .42408 Mdot
.59047 .44262 Mdot
.62747 .3255 Mdot
.76413 .66068 Mdot
.66066 .65914 Mdot
.62155 .38128 Mdot
.45792 .72507 Mdot
.31027 .38012 Mdot
.35604 .24713 Mdot
.61018 .42764 Mdot
.63466 .42665 Mdot
.42549 .33543 Mdot
.63619 .44828 Mdot
.33078 .58662 Mdot
.37717 .36366 Mdot
.56108 .43291 Mdot
.72916 .64285 Mdot
.64176 .43082 Mdot
.41829 .53635 Mdot
.29115 .58957 Mdot
.62104 .49422 Mdot
.65772 .39892 Mdot
.3869 .49049 Mdot
.38116 .49521 Mdot
.38498 .47717 Mdot
.30055 .6257 Mdot
.4708 .69074 Mdot
.46604 .75777 Mdot
.65469 .3992 Mdot
.59274 .37812 Mdot
.66991 .44726 Mdot
.48866 .66849 Mdot
.45632 .60797 Mdot
.48058 .39169 Mdot
.57112 .36417 Mdot
.47335 .74337 Mdot
.347 .31964 Mdot
.70969 .32295 Mdot
.37822 .36987 Mdot
.52826 .68795 Mdot
.31372 .58855 Mdot
.6691 .62248 Mdot
.75532 .5681 Mdot
.41582 .34077 Mdot
.40338 .32963 Mdot
.48954 .7325 Mdot
.51661 .52767 Mdot
.6748 .85163 Mdot
.4883 .70671 Mdot
.48999 .6151 Mdot
.40557 .36522 Mdot
.6316 .4559 Mdot
.61481 .54459 Mdot
.50768 .51416 Mdot
.46992 .73269 Mdot
.59915 .40403 Mdot
.59371 .65632 Mdot
.49081 .73712 Mdot
.65733 .44926 Mdot
.45897 .72086 Mdot
.3133 .62387 Mdot
.4939 .71189 Mdot
.36649 .37553 Mdot
.59039 .4165 Mdot
.6249 .87477 Mdot
.46699 .50423 Mdot
.611 .4035 Mdot
.289 .60695 Mdot
.37235 .66605 Mdot
.60203 .44244 Mdot
.69142 .64027 Mdot
.45784 .73033 Mdot
.32275 .72319 Mdot
.56845 .39243 Mdot
.47928 .73247 Mdot
.35901 .36479 Mdot
.51211 .67091 Mdot
.72156 .63041 Mdot
.3813 .4921 Mdot
.40984 .35583 Mdot
.35231 .5278 Mdot
.35082 .60519 Mdot
.5708 .46562 Mdot
.63683 .41223 Mdot
.40478 .3484 Mdot
.45786 .55445 Mdot
.54879 .36013 Mdot
.59423 .41674 Mdot
.50002 .72785 Mdot
.46341 .68638 Mdot
.45298 .43725 Mdot
.49878 .7001 Mdot
.67007 .40939 Mdot
.4107 .3478 Mdot
.55807 .42894 Mdot
.4257 .3614 Mdot
.64517 .43117 Mdot
.26316 .61322 Mdot
.38287 .37655 Mdot
.7 .41333 Mdot
.58733 .41905 Mdot
.35229 .39424 Mdot
.63194 .39403 Mdot
.59117 .44914 Mdot
.45716 .69592 Mdot
.66878 .6518 Mdot
.65783 .43548 Mdot
.25702 .65171 Mdot
.64164 .63398 Mdot
.57227 .19446 Mdot
.50426 .69012 Mdot
.65126 .66595 Mdot
.75482 .52329 Mdot
.37869 .49004 Mdot
.67679 .65528 Mdot
.40614 .4857 Mdot
.2939 .60157 Mdot
.39648 .40346 Mdot
.59238 .40267 Mdot
.26499 .30474 Mdot
.54105 .67194 Mdot
.39008 .50575 Mdot
.6362 .43403 Mdot
.6243 .42565 Mdot
.36773 .35389 Mdot
.6509 .81526 Mdot
.44904 .7205 Mdot
.58191 .45055 Mdot
.40873 .33606 Mdot
.5943 .83762 Mdot
.47476 .73751 Mdot
.65689 .65966 Mdot
.3204 .57356 Mdot
.43331 .32855 Mdot
.38754 .48691 Mdot
.31428 .57907 Mdot
.52211 .75374 Mdot
.7615 .60828 Mdot
.56208 .40546 Mdot
.51004 .7061 Mdot
.7543 .60143 Mdot
.61235 .34876 Mdot
.32602 .63478 Mdot
.26562 .5851 Mdot
.38368 .36585 Mdot
.29154 .61287 Mdot
.68979 .65476 Mdot
.4302 .38927 Mdot
.38198 .35319 Mdot
.32647 .58412 Mdot
.20664 .41004 Mdot
.62206 .54208 Mdot
.28589 .62242 Mdot
.57166 .53253 Mdot
.75334 .60213 Mdot
.39479 .4939 Mdot
.65263 .63668 Mdot
.72941 .69352 Mdot
.41396 .37243 Mdot
.28321 .52484 Mdot
.75518 .60093 Mdot
.58394 .44851 Mdot
.68026 .63632 Mdot
.31731 .38285 Mdot
.34276 .64124 Mdot
.32306 .5798 Mdot
.45948 .7756 Mdot
.67883 .62916 Mdot
.62808 .4503 Mdot
.71949 .27374 Mdot
.60449 .39179 Mdot
.30535 .58367 Mdot
.48791 .59001 Mdot
.43204 .37908 Mdot
.34338 .62432 Mdot
.48987 .59543 Mdot
.5687 .40111 Mdot
.62144 .40128 Mdot
.66428 .69546 Mdot
.42237 .39166 Mdot
.39313 .48481 Mdot
.59929 .40827 Mdot
.62621 .4343 Mdot
.57321 .46485 Mdot
.75562 .37061 Mdot
.70354 .44806 Mdot
.57042 .44571 Mdot
.4953 .75204 Mdot
.68032 .44174 Mdot
.59013 .46072 Mdot
.36826 .34164 Mdot
.74074 .6539 Mdot
.39032 .48113 Mdot
.61176 .4513 Mdot
.59971 .45299 Mdot
.34296 .58723 Mdot
.62325 .54258 Mdot
.5028 .51044 Mdot
.48956 .67368 Mdot
.468 .77526 Mdot
.60717 .36225 Mdot
.40228 .35378 Mdot
.69388 .65864 Mdot
.64847 .37291 Mdot
.37381 .35963 Mdot
.64044 .38781 Mdot
.45606 .71446 Mdot
.38614 .49587 Mdot
.60676 .34514 Mdot
.67645 .64512 Mdot
.33224 .56528 Mdot
.60987 .21042 Mdot
.50972 .72391 Mdot
.57883 .399 Mdot
.46119 .75744 Mdot
.47724 .71007 Mdot
.38983 .50872 Mdot
.66424 .46624 Mdot
.41436 .36049 Mdot
.43528 .36721 Mdot
.75739 .64973 Mdot
.46481 .743 Mdot
.5414 .79958 Mdot
.30703 .6222 Mdot
.62659 .38465 Mdot
.37854 .4563 Mdot
.43381 .37166 Mdot
.68889 .55075 Mdot
.64611 .663 Mdot
.32087 .58022 Mdot
.38974 .52046 Mdot
.38082 .37545 Mdot
.43117 .37224 Mdot
.58897 .4286 Mdot
.61485 .41869 Mdot
.52272 .76618 Mdot
.70109 .57156 Mdot
.34496 .61104 Mdot
.64969 .6509 Mdot
.5083 .68192 Mdot
.57779 .38651 Mdot
.38523 .37176 Mdot
.7031 .26698 Mdot
.63419 .39668 Mdot
.45789 .72382 Mdot
.39406 .37669 Mdot
.66465 .66382 Mdot
.68167 .66056 Mdot
.5876 .44883 Mdot
.66726 .25676 Mdot
.32925 .59203 Mdot
.41752 .35031 Mdot
.34896 .3296 Mdot
.61242 .37748 Mdot
.61078 .42351 Mdot
.53476 .39917 Mdot
.3425 .6278 Mdot
.60478 .34867 Mdot
.647 .62 Mdot
.41985 .3782 Mdot
.60484 .40628 Mdot
.67914 .64797 Mdot
.4235 .30012 Mdot
.38413 .50305 Mdot
.4794 .73787 Mdot
.68882 .63538 Mdot
.6664 .64135 Mdot
.64111 .64263 Mdot
.28527 .52657 Mdot
.44795 .39641 Mdot
.83173 .51714 Mdot
.59402 .40894 Mdot
.75301 .60247 Mdot
.58554 .47151 Mdot
.32233 .62816 Mdot
.50807 .73373 Mdot
.59144 .43301 Mdot
.59408 .40841 Mdot
.63758 .23634 Mdot
.60455 .4834 Mdot
.59927 .48422 Mdot
.43701 .37227 Mdot
.3363 .35137 Mdot
.51658 .71011 Mdot
.52947 .83715 Mdot
.52912 .144 Mdot
.58473 .37129 Mdot
.51979 .53089 Mdot
.37902 .36724 Mdot
.33651 .58052 Mdot
.58334 .53658 Mdot
.3657 .54382 Mdot
.41014 .38594 Mdot
.56984 .39606 Mdot
.60932 .21445 Mdot
.65887 .61879 Mdot
.60003 .43605 Mdot
.31343 .59988 Mdot
.59896 .43625 Mdot
.3077 .62922 Mdot
.44281 .41718 Mdot
.48948 .5076 Mdot
.58851 .40528 Mdot
.57032 .3855 Mdot
.64492 .51256 Mdot
.6124 .42461 Mdot
.35112 .71442 Mdot
.39418 .36981 Mdot
.69815 .39837 Mdot
.56008 .45189 Mdot
.62655 .27715 Mdot
.64072 .41927 Mdot
.4516 .52009 Mdot
.62976 .40364 Mdot
.77534 .39366 Mdot
.61915 .45634 Mdot
.62932 .39947 Mdot
.33874 .61071 Mdot
.34847 .5915 Mdot
.35728 .35104 Mdot
.39711 .48836 Mdot
.30293 .36676 Mdot
.63251 .43182 Mdot
.46913 .67831 Mdot
.49795 .45984 Mdot
.66604 .64717 Mdot
.41755 .37986 Mdot
.33568 .83648 Mdot
.34373 .61959 Mdot
.46685 .74829 Mdot
.49027 .62536 Mdot
.50034 .75368 Mdot
.53264 .7026 Mdot
.34006 .37127 Mdot
.65128 .6362 Mdot
.63926 .43551 Mdot
.60481 .25118 Mdot
.32122 .50977 Mdot
.60902 .37694 Mdot
.44345 .71563 Mdot
.53144 .47712 Mdot
.76369 .63942 Mdot
.682 .62161 Mdot
.66069 .6283 Mdot
.33304 .61007 Mdot
.51843 .70105 Mdot
.56348 .36814 Mdot
.65181 .66607 Mdot
.50779 .73195 Mdot
.37416 .52078 Mdot
.69462 .69584 Mdot
.41532 .36865 Mdot
.51463 .35379 Mdot
.40974 .44482 Mdot
.3445 .6171 Mdot
.25522 .64976 Mdot
.40289 .41306 Mdot
.42893 .39634 Mdot
.39912 .49797 Mdot
.4696 .7382 Mdot
.39489 .40419 Mdot
.58944 .4198 Mdot
.67483 .44273 Mdot
.62714 .44496 Mdot
.68213 .66387 Mdot
.63888 .42747 Mdot
.49191 .73917 Mdot
.34252 .59571 Mdot
.47079 .69983 Mdot
.33832 .59467 Mdot
.57142 .17417 Mdot
.59787 .45905 Mdot
.61001 .42085 Mdot
.53275 .54598 Mdot
.42836 .37561 Mdot
.58399 .24618 Mdot
.4585 .72713 Mdot
.46313 .70665 Mdot
.55872 .43196 Mdot
.44298 .35675 Mdot
.6198 .61186 Mdot
.57357 .54033 Mdot
.63232 .4076 Mdot
.39318 .36885 Mdot
.55846 .43463 Mdot
.30257 .69919 Mdot
.46778 .48569 Mdot
.42614 .35029 Mdot
.79722 .39251 Mdot
.58305 .43256 Mdot
.65569 .48026 Mdot
.62508 .5008 Mdot
.74971 .38405 Mdot
.64107 .45171 Mdot
.37585 .3492 Mdot
.58755 .45814 Mdot
.39716 .35679 Mdot
.48027 .70381 Mdot
.35299 .61336 Mdot
.39945 .35925 Mdot
.59911 .39619 Mdot
.53813 .14728 Mdot
.34304 .59433 Mdot
.59827 .43017 Mdot
.31999 .6167 Mdot
.39844 .40133 Mdot
.41669 .3897 Mdot
.39647 .5159 Mdot
.49041 .61758 Mdot
.33014 .58768 Mdot
.59443 .37747 Mdot
.29097 .51055 Mdot
.55807 .42646 Mdot
.46518 .77325 Mdot
.55149 .41354 Mdot
.61746 .36712 Mdot
.78581 .31811 Mdot
.45774 .54461 Mdot
.45383 .85064 Mdot
.33007 .65582 Mdot
.28293 .50891 Mdot
.35873 .33097 Mdot
.68196 .62177 Mdot
.42922 .53866 Mdot
.37405 .49466 Mdot
.50026 .75064 Mdot
.59081 .42976 Mdot
.3351 .29355 Mdot
.28809 .62223 Mdot
.66523 .65505 Mdot
.5872 .40825 Mdot
.52267 .72642 Mdot
.42303 .45909 Mdot
.32141 .57907 Mdot
.41675 .37058 Mdot
.42029 .38525 Mdot
.78433 .63498 Mdot
.60852 .40528 Mdot
.6135 .41457 Mdot
.34267 .59131 Mdot
.55347 .37107 Mdot
.64259 .64326 Mdot
.4023 .64477 Mdot
.31192 .60209 Mdot
.47063 .49335 Mdot
.43541 .37815 Mdot
.62465 .42371 Mdot
.53968 .54987 Mdot
.24801 .50788 Mdot
.39875 .25481 Mdot
.6714 .63103 Mdot
.67959 .53145 Mdot
.37596 .34854 Mdot
.31526 .60475 Mdot
.75833 .53251 Mdot
.5612 .46705 Mdot
.62504 .42776 Mdot
.72135 .47322 Mdot
.57326 .53876 Mdot
.48515 .61811 Mdot
.5321 .41066 Mdot
.62911 .55389 Mdot
.55866 .42973 Mdot
.56328 .43157 Mdot
.62383 .37065 Mdot
.55075 .4277 Mdot
.39149 .36475 Mdot
.63609 .29382 Mdot
.48648 .72342 Mdot
.44402 .28062 Mdot
.48235 .78691 Mdot
.58985 .39455 Mdot
.56838 .39992 Mdot
.51823 .30393 Mdot
.53996 .51552 Mdot
.40164 .37123 Mdot
.34705 .33563 Mdot
.35253 .60484 Mdot
.5931 .48231 Mdot
.46153 .73891 Mdot
.5963 .4993 Mdot
.47305 .71829 Mdot
.39077 .36703 Mdot
.48265 .6842 Mdot
.29088 .58202 Mdot
.50952 .70536 Mdot
.47942 .74761 Mdot
.32225 .57642 Mdot
.41139 .39459 Mdot
.63274 .4002 Mdot
.31283 .57665 Mdot
.61545 .62065 Mdot
.68215 .66357 Mdot
.3948 .51843 Mdot
.6211 .46182 Mdot
.6281 .48284 Mdot
.26964 .69647 Mdot
.48991 .68756 Mdot
.50077 .50064 Mdot
.38435 .37814 Mdot
.69171 .66035 Mdot
.39172 .36141 Mdot
.80478 .57551 Mdot
.67376 .63869 Mdot
.39992 .51217 Mdot
.73734 .53786 Mdot
.37022 .5972 Mdot
.55356 .4011 Mdot
.34011 .34142 Mdot
.4722 .7136 Mdot
.29277 .62103 Mdot
.31597 .38415 Mdot
.57778 .43856 Mdot
.36336 .51531 Mdot
.41479 .40523 Mdot
.3788 .49092 Mdot
.31554 .60097 Mdot
.41434 .49652 Mdot
.61448 .40394 Mdot
.36988 .59924 Mdot
.56561 .389 Mdot
.5561 .33277 Mdot
.49788 .7779 Mdot
.39194 .29938 Mdot
.56309 .40664 Mdot
.4759 .73906 Mdot
.56002 .41555 Mdot
.47972 .33878 Mdot
.72616 .56161 Mdot
.60274 .36126 Mdot
.55182 .50585 Mdot
.29095 .72071 Mdot
.38469 .36937 Mdot
.66524 .40103 Mdot
.39381 .49987 Mdot
.57208 .40459 Mdot
.32019 .20542 Mdot
.67641 .65268 Mdot
.64055 .61094 Mdot
.59702 .39888 Mdot
.59935 .41152 Mdot
.64855 .2465 Mdot
.38564 .41767 Mdot
.39168 .51881 Mdot
.62023 .43434 Mdot
.7335 .44194 Mdot
.3352 .61254 Mdot
.55634 .40549 Mdot
.60531 .45552 Mdot
.53244 .7814 Mdot
.33023 .6161 Mdot
.50373 .69279 Mdot
.37753 .49096 Mdot
.47362 .67986 Mdot
.65097 .67384 Mdot
.65341 .53751 Mdot
.69678 .53553 Mdot
.45848 .4691 Mdot
.68915 .63903 Mdot
.59451 .39069 Mdot
.39206 .30245 Mdot
.61085 .39873 Mdot
.65906 .6315 Mdot
.31179 .61029 Mdot
.39546 .36606 Mdot
.50922 .36433 Mdot
.38562 .51329 Mdot
.6119 .38209 Mdot
.69098 .62709 Mdot
.40554 .35926 Mdot
.21654 .52183 Mdot
.39436 .38441 Mdot
.33727 .59717 Mdot
.3111 .63389 Mdot
.67021 .64405 Mdot
.39045 .36223 Mdot
.47373 .68121 Mdot
.30441 .65641 Mdot
.56586 .38242 Mdot
.2899 .58248 Mdot
.37702 .39834 Mdot
.37111 .3461 Mdot
.434 .34777 Mdot
.5604 .44774 Mdot
.54648 .53215 Mdot
.54381 .45238 Mdot
.34335 .5936 Mdot
.5155 .73771 Mdot
.71245 .57427 Mdot
.62932 .25567 Mdot
.47852 .5057 Mdot
.65619 .44101 Mdot
.63815 .4294 Mdot
.62762 .44394 Mdot
.5709 .45084 Mdot
.40282 .63692 Mdot
.59793 .45891 Mdot
.33832 .61695 Mdot
.47885 .71757 Mdot
.63243 .41308 Mdot
.39201 .49565 Mdot
.45928 .60677 Mdot
.69142 .6649 Mdot
.6201 .31591 Mdot
.33884 .38612 Mdot
.4039 .36052 Mdot
.50023 .69809 Mdot
.48053 .68315 Mdot
.66439 .66801 Mdot
.30781 .57966 Mdot
.40267 .38845 Mdot
.7748 .40023 Mdot
.64733 .62532 Mdot
.61237 .45074 Mdot
.53515 .54782 Mdot
.74778 .35653 Mdot
.63865 .39149 Mdot
.59261 .44558 Mdot
.39412 .48341 Mdot
.47282 .75075 Mdot
.30176 .26159 Mdot
.20239 .43068 Mdot
.66972 .64995 Mdot
.64967 .65645 Mdot
.4255 .33818 Mdot
.62865 .38508 Mdot
.32663 .59114 Mdot
.63534 .5432 Mdot
.27294 .68731 Mdot
.30693 .34447 Mdot
.30573 .71194 Mdot
.64229 .42873 Mdot
.58614 .29908 Mdot
.55063 .41261 Mdot
.4511 .38691 Mdot
.43835 .35019 Mdot
.40803 .36962 Mdot
.33887 .6075 Mdot
.76355 .60976 Mdot
.33648 .6195 Mdot
.32562 .34971 Mdot
.38706 .33955 Mdot
.46831 .5667 Mdot
.46121 .70967 Mdot
.59923 .47903 Mdot
.65261 .63417 Mdot
.64281 .58209 Mdot
.66674 .40767 Mdot
.67252 .53391 Mdot
.51048 .70147 Mdot
.39271 .39173 Mdot
.58901 .47447 Mdot
.30444 .37576 Mdot
.51275 .52709 Mdot
.30899 .73958 Mdot
.34425 .2933 Mdot
.68053 .64453 Mdot
.45845 .27111 Mdot
.645 .63232 Mdot
.31863 .58042 Mdot
.58309 .43632 Mdot
.63467 .3936 Mdot
.59282 .45102 Mdot
.55495 .4388 Mdot
.32536 .61368 Mdot
.5702 .37638 Mdot
.73369 .62545 Mdot
.37153 .51725 Mdot
.44457 .60036 Mdot
.68045 .65933 Mdot
.31069 .62508 Mdot
.47798 .71274 Mdot
.39997 .49955 Mdot
.692 .62272 Mdot
.57654 .46389 Mdot
.60413 .39603 Mdot
.37639 .51952 Mdot
.59031 .34406 Mdot
.63571 .47284 Mdot
.48364 .72878 Mdot
.47065 .60422 Mdot
.67334 .67199 Mdot
.6621 .62343 Mdot
.2939 .61446 Mdot
.3914 .36124 Mdot
.66438 .67005 Mdot
.52069 .70428 Mdot
.55956 .40182 Mdot
.57461 .38107 Mdot
.37089 .39266 Mdot
.75701 .60363 Mdot
.69284 .66365 Mdot
.60822 .34937 Mdot
.42503 .37064 Mdot
.41639 .40506 Mdot
.61852 .43495 Mdot
.59146 .35908 Mdot
.41946 .33139 Mdot
.65949 .66475 Mdot
.29881 .6182 Mdot
.48449 .55373 Mdot
.33169 .62409 Mdot
.42185 .36242 Mdot
.67862 .43979 Mdot
.42098 .39349 Mdot
.57711 .43569 Mdot
.47997 .87638 Mdot
.61097 .45803 Mdot
.70098 .36411 Mdot
.57364 .65427 Mdot
.45948 .72377 Mdot
.46354 .73169 Mdot
.38774 .49503 Mdot
.37465 .36062 Mdot
.66429 .39227 Mdot
.64864 .63919 Mdot
.28387 .50881 Mdot
.39396 .41559 Mdot
.47719 .746 Mdot
.46305 .74439 Mdot
.31376 .61158 Mdot
.64058 .42235 Mdot
.6263 .42016 Mdot
.50877 .70282 Mdot
.38472 .65994 Mdot
.39243 .3539 Mdot
.61312 .4146 Mdot
.56872 .45492 Mdot
.48479 .72146 Mdot
.30118 .64008 Mdot
.39927 .40952 Mdot
.5611 .44955 Mdot
.71621 .5594 Mdot
.31838 .63061 Mdot
.58564 .39086 Mdot
.54871 .41865 Mdot
.66307 .6439 Mdot
.69407 .52202 Mdot
.75089 .5983 Mdot
.35346 .59399 Mdot
.38494 .48825 Mdot
.64386 .40348 Mdot
.46056 .72245 Mdot
.61012 .46747 Mdot
.15595 .51162 Mdot
.36926 .51329 Mdot
.61639 .40601 Mdot
.6157 .36201 Mdot
.42581 .35882 Mdot
.60822 .40932 Mdot
.26375 .60964 Mdot
.50232 .72086 Mdot
.61722 .40549 Mdot
.66713 .25904 Mdot
.31308 .60994 Mdot
.66651 .40909 Mdot
.67512 .62523 Mdot
.48625 .61105 Mdot
.51477 .16039 Mdot
.49511 .66978 Mdot
.68498 .65379 Mdot
.63899 .42355 Mdot
.48254 .67395 Mdot
.32411 .57348 Mdot
.7099 .42987 Mdot
.59451 .38901 Mdot
.33607 .62202 Mdot
.34042 .59288 Mdot
.67258 .64727 Mdot
.42295 .86348 Mdot
.60948 .36241 Mdot
.60406 .43196 Mdot
.23873 .68546 Mdot
.40984 .32727 Mdot
.59707 .4326 Mdot
.63861 .41508 Mdot
.29282 .59697 Mdot
.79632 .55363 Mdot
.67853 .53154 Mdot
.39669 .64635 Mdot
.31295 .63008 Mdot
.44678 .71037 Mdot
.50656 .72113 Mdot
.68458 .65163 Mdot
.39464 .37805 Mdot
.68581 .66438 Mdot
.49352 .71657 Mdot
.59315 .44913 Mdot
.29967 .59937 Mdot
.46167 .20523 Mdot
.28815 .59565 Mdot
.52298 .70512 Mdot
.44107 .39734 Mdot
.34091 .27253 Mdot
.15805 .55191 Mdot
.43112 .43467 Mdot
.35202 .62407 Mdot
.66581 .64716 Mdot
.19713 .46422 Mdot
.63269 .41153 Mdot
.52321 .33624 Mdot
.60136 .43462 Mdot
.37161 .28732 Mdot
.50764 .73368 Mdot
.38117 .52205 Mdot
.57763 .43885 Mdot
.68099 .52916 Mdot
.32461 .57733 Mdot
.31704 .58881 Mdot
.58568 .45607 Mdot
.33599 .59516 Mdot
.62377 .41563 Mdot
.48218 .71614 Mdot
.44293 .85845 Mdot
.62464 .39826 Mdot
.68163 .45217 Mdot
.3641 .60778 Mdot
.3919 .52146 Mdot
.45115 .74036 Mdot
.62039 .29001 Mdot
.29447 .35882 Mdot
.32802 .59367 Mdot
.62824 .32377 Mdot
.49126 .69056 Mdot
.40053 .49257 Mdot
.45458 .69367 Mdot
.61097 .43333 Mdot
.64333 .42449 Mdot
.57215 .44867 Mdot
.63776 .42192 Mdot
.50083 .33411 Mdot
.62834 .47509 Mdot
.49593 .24284 Mdot
.59454 .40857 Mdot
.69398 .35588 Mdot
.33226 .62021 Mdot
.65205 .48465 Mdot
.50678 .59909 Mdot
.6367 .44314 Mdot
.33963 .35492 Mdot
.31133 .62446 Mdot
.35948 .46007 Mdot
.32799 .61467 Mdot
.46869 .70243 Mdot
.33009 .58154 Mdot
.58124 .4333 Mdot
.41352 .37699 Mdot
.49842 .70473 Mdot
.48164 .39674 Mdot
.51075 .74119 Mdot
.61109 .40357 Mdot
.3672 .56725 Mdot
.46117 .70121 Mdot
.60911 .48753 Mdot
.41144 .37963 Mdot
.74514 .44034 Mdot
.45344 .36017 Mdot
.60356 .41471 Mdot
.59943 .42077 Mdot
.38448 .521 Mdot
.32405 .57843 Mdot
.44071 .37107 Mdot
.54459 .77443 Mdot
.69877 .63976 Mdot
.39911 .37494 Mdot
.63699 .49852 Mdot
.52063 .5334 Mdot
.42627 .35373 Mdot
.74295 .41063 Mdot
.30746 .58235 Mdot
.39584 .33417 Mdot
.54439 .43371 Mdot
.45432 .28827 Mdot
.65628 .62271 Mdot
.46554 .68612 Mdot
.61266 .55374 Mdot
.50536 .72144 Mdot
.32182 .56224 Mdot
.45612 .73491 Mdot
.33403 .61651 Mdot
.51144 .47397 Mdot
.48858 .59241 Mdot
.2863 .6099 Mdot
.36526 .59923 Mdot
.4903 .72767 Mdot
.58099 .45432 Mdot
.45985 .59243 Mdot
.66284 .38777 Mdot
.67189 .44064 Mdot
.33683 .62378 Mdot
.38024 .34165 Mdot
.42463 .39388 Mdot
.69081 .38665 Mdot
.42781 .38024 Mdot
.4901 .70309 Mdot
.45577 .45201 Mdot
.59782 .31872 Mdot
.30858 .60758 Mdot
.48664 .62464 Mdot
.56294 .40904 Mdot
.48249 .73623 Mdot
.48646 .7009 Mdot
.341 .59568 Mdot
.4278 .27697 Mdot
.66979 .42872 Mdot
.37627 .33113 Mdot
.40483 .33561 Mdot
.42441 .35117 Mdot
.44176 .3532 Mdot
.7667 .6086 Mdot
.29283 .62085 Mdot
.3753 .35583 Mdot
.55593 .43674 Mdot
.63941 .40166 Mdot
.37549 .50122 Mdot
.66523 .66512 Mdot
.56019 .46415 Mdot
.66337 .39017 Mdot
.61952 .43334 Mdot
.45883 .72069 Mdot
.58906 .51517 Mdot
.37125 .51478 Mdot
.46531 .74433 Mdot
.46344 .74047 Mdot
.38649 .48997 Mdot
.51744 .47748 Mdot
.31645 .25992 Mdot
.58369 .451 Mdot
.33998 .37599 Mdot
.46472 .72959 Mdot
.633 .57561 Mdot
.67266 .34583 Mdot
.59867 .37392 Mdot
.43334 .62704 Mdot
.48393 .70977 Mdot
.3654 .32662 Mdot
.61138 .42927 Mdot
.3977 .50027 Mdot
.66509 .62191 Mdot
.64826 .50295 Mdot
.39491 .4843 Mdot
.38677 .36244 Mdot
.50117 .79999 Mdot
.36696 .35524 Mdot
.46376 .69365 Mdot
.66683 .40473 Mdot
.6522 .86389 Mdot
.47205 .71076 Mdot
.27599 .51861 Mdot
.48851 .59452 Mdot
.62148 .39896 Mdot
.50543 .70849 Mdot
.36129 .38192 Mdot
.32079 .63045 Mdot
.54651 .54186 Mdot
.38603 .37259 Mdot
.39953 .50128 Mdot
.37835 .49923 Mdot
.48564 .72359 Mdot
.40948 .33937 Mdot
.56104 .39007 Mdot
.41763 .38562 Mdot
.30457 .59515 Mdot
.57527 .42055 Mdot
.30232 .36589 Mdot
.66619 .4642 Mdot
.41957 .38267 Mdot
.52198 .72204 Mdot
.6372 .64058 Mdot
.59354 .39668 Mdot
.3488 .43861 Mdot
.63993 .42054 Mdot
.31702 .61544 Mdot
.58028 .60971 Mdot
.46638 .20759 Mdot
.60808 .4486 Mdot
.56471 .40635 Mdot
.30027 .5755 Mdot
.60769 .44745 Mdot
.6138 .36863 Mdot
.41453 .49107 Mdot
.42715 .35662 Mdot
.63257 .41721 Mdot
.50589 .72866 Mdot
.51934 .18341 Mdot
.58505 .43709 Mdot
.26123 .62332 Mdot
.73746 .44598 Mdot
.55982 .58778 Mdot
.6771 .41775 Mdot
.68733 .55131 Mdot
.60092 .42399 Mdot
.60458 .37357 Mdot
.58424 .45287 Mdot
.57868 .30263 Mdot
.4934 .72196 Mdot
.48376 .74408 Mdot
.67526 .62209 Mdot
.73133 .45449 Mdot
.67669 .6342 Mdot
.29716 .57955 Mdot
.48952 .62317 Mdot
.37892 .51808 Mdot
.39275 .35971 Mdot
.5863 .43871 Mdot
.51048 .73916 Mdot
.62203 .4252 Mdot
.57374 .4017 Mdot
.49119 .7078 Mdot
.48321 .7038 Mdot
.49585 .66854 Mdot
.65605 .61893 Mdot
.40236 .36697 Mdot
.58413 .44614 Mdot
.64188 .63305 Mdot
.57038 .45866 Mdot
.48473 .53447 Mdot
.40318 .36879 Mdot
.42116 .38239 Mdot
.40822 .4006 Mdot
.61576 .39066 Mdot
.57844 .43069 Mdot
.33648 .61971 Mdot
.37142 .39299 Mdot
.32606 .58573 Mdot
.50596 .71029 Mdot
.48754 .73633 Mdot
.6102 .43399 Mdot
.57563 .35983 Mdot
.67555 .662 Mdot
.47839 .68867 Mdot
.37661 .48693 Mdot
.67629 .62373 Mdot
.63131 .4426 Mdot
.50657 .71607 Mdot
.69451 .64887 Mdot
.37981 .25684 Mdot
.27992 .34447 Mdot
.65984 .61608 Mdot
.58472 .45615 Mdot
.63008 .24972 Mdot
.72357 .56718 Mdot
.70161 .6448 Mdot
.31823 .61901 Mdot
.63659 .40556 Mdot
.35423 .66094 Mdot
.65219 .6685 Mdot
.74952 .59351 Mdot
.49525 .70953 Mdot
.68665 .43544 Mdot
.61196 .51059 Mdot
.58573 .32233 Mdot
.63884 .65273 Mdot
.41887 .38136 Mdot
.41985 .3391 Mdot
.60997 .4508 Mdot
.48772 .61778 Mdot
.28893 .58884 Mdot
.48117 .68287 Mdot
.49184 .74726 Mdot
.4283 .34975 Mdot
.4606 .47428 Mdot
.5067 .72601 Mdot
.62407 .382 Mdot
.67044 .68195 Mdot
.58822 .48154 Mdot
.78246 .62235 Mdot
.49432 .17014 Mdot
.67894 .42418 Mdot
.6385 .63341 Mdot
.32843 .57572 Mdot
.34227 .60359 Mdot
.3384 .60281 Mdot
.49119 .73455 Mdot
.58934 .53994 Mdot
.501 .74267 Mdot
.23184 .59614 Mdot
.67927 .65101 Mdot
.76499 .44846 Mdot
.55248 .44702 Mdot
.61975 .39875 Mdot
.56351 .39996 Mdot
.56904 .44647 Mdot
.6025 .42315 Mdot
.34494 .61576 Mdot
.48314 .67692 Mdot
.28534 .69839 Mdot
.40459 .34381 Mdot
.21314 .5199 Mdot
.46176 .70741 Mdot
.39158 .48202 Mdot
.65914 .65653 Mdot
.71223 .5031 Mdot
.66102 .68492 Mdot
.47507 .68787 Mdot
.64298 .39388 Mdot
.41775 .33328 Mdot
.77605 .38551 Mdot
.59425 .41644 Mdot
.48321 .68703 Mdot
.44991 .69593 Mdot
.42659 .27095 Mdot
.52587 .40007 Mdot
.47166 .63502 Mdot
.52348 .53115 Mdot
.65639 .61472 Mdot
.65635 .43455 Mdot
.65935 .54231 Mdot
.49196 .71806 Mdot
.46845 .72163 Mdot
.70074 .63943 Mdot
.47981 .36318 Mdot
.38046 .34929 Mdot
.37569 .52405 Mdot
.31266 .62026 Mdot
.61052 .39575 Mdot
.49579 .73032 Mdot
.40059 .30871 Mdot
.50529 .55018 Mdot
.32533 .60982 Mdot
.46288 .74348 Mdot
.64033 .4167 Mdot
.61324 .44769 Mdot
.67777 .63914 Mdot
.56088 .68988 Mdot
.66321 .38839 Mdot
.28315 .51033 Mdot
.48869 .49808 Mdot
.48989 .59866 Mdot
.62543 .42725 Mdot
.43051 .38322 Mdot
.38719 .49112 Mdot
.65294 .63784 Mdot
.58821 .46504 Mdot
.30079 .28411 Mdot
.36901 .36743 Mdot
.32873 .58811 Mdot
.39168 .48928 Mdot
.63563 .53742 Mdot
.63944 .41965 Mdot
.60191 .43452 Mdot
.56002 .44719 Mdot
.30323 .274 Mdot
.50128 .73854 Mdot
.44111 .36528 Mdot
.68055 .63391 Mdot
.41201 .39004 Mdot
.45503 .72314 Mdot
.47933 .61781 Mdot
.59549 .45997 Mdot
.37712 .37813 Mdot
.40793 .3876 Mdot
.31176 .609 Mdot
.3122 .57653 Mdot
.4995 .67386 Mdot
.6368 .41674 Mdot
.38258 .51906 Mdot
.37774 .34816 Mdot
.48893 .68089 Mdot
.67688 .63923 Mdot
.28661 .57447 Mdot
.59545 .40643 Mdot
.48829 .723 Mdot
.66389 .39377 Mdot
.41143 .35131 Mdot
.46736 .69609 Mdot
.39916 .48587 Mdot
.65968 .6639 Mdot
.64485 .41686 Mdot
.30781 .72517 Mdot
.39777 .49475 Mdot
.60307 .39281 Mdot
.48046 .17543 Mdot
.48705 .617 Mdot
.46919 .36429 Mdot
.51288 .72192 Mdot
.38948 .51335 Mdot
.4393 .35522 Mdot
.46945 .28944 Mdot
.47167 .72489 Mdot
.62161 .22501 Mdot
.47607 .56583 Mdot
.58142 .44923 Mdot
.38537 .36688 Mdot
.66266 .69332 Mdot
.28334 .49372 Mdot
.71715 .56995 Mdot
.61884 .41104 Mdot
.50492 .72247 Mdot
.66511 .62261 Mdot
.31729 .58775 Mdot
.26491 .62979 Mdot
.80091 .60777 Mdot
.47554 .74853 Mdot
.58654 .44125 Mdot
.38287 .3398 Mdot
.33213 .59029 Mdot
.61669 .21533 Mdot
.51862 .70001 Mdot
.51128 .71863 Mdot
.57166 .38754 Mdot
.67514 .63119 Mdot
.36419 .65259 Mdot
.49131 .74227 Mdot
.47973 .67605 Mdot
.41405 .47123 Mdot
.67463 .62022 Mdot
.56206 .44739 Mdot
.69086 .38632 Mdot
.55157 .4177 Mdot
.23795 .53862 Mdot
.38778 .51516 Mdot
.40181 .34415 Mdot
.59293 .43257 Mdot
.28708 .71877 Mdot
.47458 .71948 Mdot
.52214 .52922 Mdot
.30585 .63912 Mdot
.31178 .57705 Mdot
.50135 .72 Mdot
.61804 .42304 Mdot
.27645 .61057 Mdot
.68139 .65487 Mdot
.56248 .45088 Mdot
.5773 .4336 Mdot
.37048 .39426 Mdot
.30099 .59977 Mdot
.51652 .18115 Mdot
.31161 .58704 Mdot
.29125 .60946 Mdot
.41119 .40708 Mdot
.61131 .45059 Mdot
.47015 .69562 Mdot
.52393 .72679 Mdot
.62238 .35705 Mdot
.63002 .57923 Mdot
.37993 .35517 Mdot
.52768 .74278 Mdot
.29023 .28812 Mdot
.58583 .37137 Mdot
.37858 .48682 Mdot
.36513 .29381 Mdot
.30201 .63028 Mdot
.5988 .44769 Mdot
.39792 .35543 Mdot
.50005 .67863 Mdot
.50132 .72969 Mdot
.56209 .4678 Mdot
.34293 .59769 Mdot
.69356 .65334 Mdot
.48705 .6988 Mdot
.47886 .54427 Mdot
.61389 .40558 Mdot
.36097 .51706 Mdot
.4868 .69694 Mdot
.55153 .15395 Mdot
.27929 .71019 Mdot
.42367 .34789 Mdot
.5829 .38523 Mdot
.39875 .33055 Mdot
.68669 .6418 Mdot
.45082 .71466 Mdot
.34286 .61213 Mdot
.51092 .39453 Mdot
.48677 .81864 Mdot
.48994 .73216 Mdot
.39205 .36602 Mdot
.58921 .44223 Mdot
.63647 .32852 Mdot
.63049 .40481 Mdot
.79806 .54436 Mdot
.6961 .65996 Mdot
.34821 .57035 Mdot
.34355 .59304 Mdot
.56875 .40072 Mdot
.64171 .64085 Mdot
.52731 .70716 Mdot
.49142 .70903 Mdot
.49821 .84633 Mdot
.39611 .48489 Mdot
.53267 .69523 Mdot
.61358 .39124 Mdot
.49566 .68445 Mdot
.6298 .25668 Mdot
.33693 .5872 Mdot
.55953 .39659 Mdot
.48984 .75635 Mdot
.23605 .50397 Mdot
.52374 .53406 Mdot
.61613 .40728 Mdot
.55697 .36944 Mdot
.3242 .6173 Mdot
.19738 .46211 Mdot
.514 .72301 Mdot
.57349 .45903 Mdot
.28397 .62601 Mdot
.49127 .45136 Mdot
.55145 .76192 Mdot
.40286 .36705 Mdot
.49426 .75898 Mdot
.29829 .6161 Mdot
.68574 .43862 Mdot
.67316 .66514 Mdot
.51694 .69045 Mdot
.50219 .75106 Mdot
.57523 .4119 Mdot
.57548 .47021 Mdot
.54445 .38427 Mdot
.38324 .36052 Mdot
.29333 .59885 Mdot
.56558 .41642 Mdot
.48771 .52575 Mdot
.56741 .44357 Mdot
.29332 .6071 Mdot
.54834 .90586 Mdot
.64632 .40246 Mdot
.59918 .40279 Mdot
.63142 .31621 Mdot
.43983 .37308 Mdot
.42906 .36466 Mdot
.48474 .50614 Mdot
.6265 .3916 Mdot
.46458 .55997 Mdot
.40032 .36527 Mdot
.3894 .37261 Mdot
.46562 .56195 Mdot
.57811 .41654 Mdot
.36734 .53828 Mdot
.33344 .59123 Mdot
.31088 .57709 Mdot
.4259 .35997 Mdot
.58136 .4786 Mdot
.32618 .57398 Mdot
.5013 .32458 Mdot
.46824 .69312 Mdot
.66063 .54065 Mdot
.41517 .38711 Mdot
.5436 .55285 Mdot
.31488 .58048 Mdot
.62565 .19725 Mdot
.75074 .36925 Mdot
.58911 .36577 Mdot
.60722 .45041 Mdot
.66501 .64034 Mdot
.53349 .36816 Mdot
.38303 .48952 Mdot
.33937 .59909 Mdot
.40537 .63554 Mdot
.40856 .36998 Mdot
.62907 .39527 Mdot
.70717 .57307 Mdot
.5192 .16374 Mdot
.70326 .41125 Mdot
.39367 .37818 Mdot
.41095 .37392 Mdot
.51344 .70617 Mdot
.47223 .68805 Mdot
.59361 .45875 Mdot
.33933 .61152 Mdot
.4069 .33443 Mdot
.29635 .60015 Mdot
.49264 .71631 Mdot
.46519 .70167 Mdot
.37069 .50829 Mdot
.66875 .43721 Mdot
.49925 .71702 Mdot
.25995 .63886 Mdot
.48712 .5269 Mdot
.38338 .40349 Mdot
.23174 .65162 Mdot
.65421 .21877 Mdot
.52602 .35346 Mdot
.66403 .62189 Mdot
.50761 .47232 Mdot
.34986 .59169 Mdot
.56655 .40458 Mdot
.60287 .4398 Mdot
.38023 .51015 Mdot
.34623 .58591 Mdot
.6605 .65236 Mdot
.32773 .57834 Mdot
.65035 .64422 Mdot
.48052 .74301 Mdot
.58626 .4319 Mdot
.62706 .4495 Mdot
.31764 .59004 Mdot
.50347 .69345 Mdot
.4607 .70215 Mdot
.64899 .62995 Mdot
.71801 .48782 Mdot
.48643 .72169 Mdot
.41441 .38766 Mdot
.5442 .19907 Mdot
.37771 .50141 Mdot
.61136 .42855 Mdot
.6926 .55071 Mdot
.48193 .28187 Mdot
.57473 .44652 Mdot
.39409 .4901 Mdot
.43119 .86759 Mdot
.58473 .43421 Mdot
.60156 .83638 Mdot
.3756 .516 Mdot
.42309 .3925 Mdot
.49084 .69237 Mdot
.39564 .48628 Mdot
.59985 .51673 Mdot
.51213 .76828 Mdot
.64926 .37876 Mdot
.3789 .35138 Mdot
.39156 .39302 Mdot
.47421 .61045 Mdot
.23645 .53857 Mdot
.67991 .63226 Mdot
.66971 .65681 Mdot
.47432 .7266 Mdot
.26613 .64973 Mdot
.57015 .47263 Mdot
.6683 .65496 Mdot
.38598 .57632 Mdot
.56444 .40479 Mdot
.48511 .61518 Mdot
.45261 .59411 Mdot
.43626 .36861 Mdot
.64553 .48911 Mdot
.47405 .72317 Mdot
.393 .36669 Mdot
.46632 .5964 Mdot
.56035 .39882 Mdot
.40514 .36951 Mdot
.29677 .58793 Mdot
.44071 .54647 Mdot
.42234 .38491 Mdot
.54035 .54319 Mdot
.32353 .59241 Mdot
.485 .61975 Mdot
.77343 .49803 Mdot
.40273 .15103 Mdot
.34108 .60453 Mdot
.49118 .68882 Mdot
.4944 .72972 Mdot
.4834 .71996 Mdot
.38279 .36804 Mdot
.47821 .70518 Mdot
.39333 .34276 Mdot
.3627 .59672 Mdot
.70598 .50571 Mdot
.67175 .6416 Mdot
.71034 .68956 Mdot
.42043 .3718 Mdot
.23377 .57715 Mdot
.20819 .65162 Mdot
.56641 .44969 Mdot
.28725 .61139 Mdot
.64335 .6269 Mdot
.48312 .48267 Mdot
.66307 .64249 Mdot
.49256 .6912 Mdot
.66468 .53514 Mdot
.62471 .41547 Mdot
.32811 .32821 Mdot
.66637 .62335 Mdot
.38975 .37591 Mdot
.5911 .39319 Mdot
.5119 .75502 Mdot
.68639 .64976 Mdot
.65676 .62462 Mdot
.60372 .42425 Mdot
.39974 .39499 Mdot
.47141 .69249 Mdot
.35333 .59831 Mdot
.68827 .68346 Mdot
.55985 .36353 Mdot
.59215 .4541 Mdot
.64849 .40139 Mdot
.51227 .5212 Mdot
.28179 .66928 Mdot
.32511 .59495 Mdot
.7437 .59274 Mdot
.48439 .73691 Mdot
.72106 .57169 Mdot
.30322 .4992 Mdot
.63166 .66893 Mdot
.38609 .51564 Mdot
.38737 .51587 Mdot
.61026 .41163 Mdot
.16723 .55534 Mdot
.70989 .39481 Mdot
.3317 .63788 Mdot
.3799 .50398 Mdot
.4622 .69778 Mdot
.36307 .37329 Mdot
.5699 .49479 Mdot
.55499 .45391 Mdot
.35147 .59103 Mdot
.48886 .71448 Mdot
.15515 .50706 Mdot
.67873 .64952 Mdot
.47984 .48365 Mdot
.6367 .42021 Mdot
.61199 .41742 Mdot
.32066 .60494 Mdot
.34005 .61519 Mdot
.41203 .46484 Mdot
.55841 .57758 Mdot
.30051 .35383 Mdot
.32738 .56792 Mdot
.1545 .50666 Mdot
.3371 .29388 Mdot
.42096 .35743 Mdot
.37821 .4891 Mdot
.30336 .57679 Mdot
.59538 .43251 Mdot
.4257 .3914 Mdot
.71099 .41718 Mdot
.37363 .31871 Mdot
.48681 .61205 Mdot
.48382 .55229 Mdot
.63764 .42982 Mdot
.43505 .34254 Mdot
.39615 .36857 Mdot
.44431 .35055 Mdot
.38424 .49281 Mdot
.62372 .43086 Mdot
.57476 .4527 Mdot
.58361 .43524 Mdot
.61252 .33073 Mdot
.60832 .40885 Mdot
.29954 .49747 Mdot
.4778 .51398 Mdot
.6 .72425 Mdot
.59075 .41679 Mdot
.29139 .59686 Mdot
.5878 .43088 Mdot
.64377 .65138 Mdot
.64627 .41211 Mdot
.48856 .6103 Mdot
.33309 .60019 Mdot
.45443 .31279 Mdot
.45354 .76022 Mdot
.61833 .45368 Mdot
.69 .63988 Mdot
.24106 .65358 Mdot
.73164 .58944 Mdot
.4157 .47816 Mdot
.41723 .38571 Mdot
.47562 .67551 Mdot
.28268 .61366 Mdot
.46695 .70363 Mdot
.56528 .38393 Mdot
.37162 .49744 Mdot
.78842 .33369 Mdot
.55249 .55839 Mdot
.594 .43169 Mdot
.66803 .43415 Mdot
.43393 .37371 Mdot
.47411 .71568 Mdot
.44783 .41461 Mdot
.56298 .40371 Mdot
.67576 .66896 Mdot
.64171 .65413 Mdot
.43704 .65578 Mdot
.42232 .54961 Mdot
.67705 .31329 Mdot
.32222 .60329 Mdot
.49537 .73418 Mdot
.64206 .66112 Mdot
.34057 .33914 Mdot
.2883 .59152 Mdot
.3024 .63054 Mdot
.30066 .60153 Mdot
.6124 .40108 Mdot
.37258 .50503 Mdot
.40769 .58495 Mdot
.39882 .492 Mdot
.5544 .42032 Mdot
.50032 .7518 Mdot
.40025 .49295 Mdot
.66964 .63458 Mdot
.29596 .61814 Mdot
.45938 .71528 Mdot
.60003 .41799 Mdot
.4049 .36188 Mdot
.75725 .64005 Mdot
.30471 .74562 Mdot
.48778 .61905 Mdot
.48779 .61915 Mdot
.39487 .39799 Mdot
.33148 .38672 Mdot
.30974 .56382 Mdot
.43826 .27641 Mdot
.62337 .60613 Mdot
.62967 .35932 Mdot
.54684 .80641 Mdot
.50384 .74051 Mdot
.49705 .70366 Mdot
.62487 .40874 Mdot
.50355 .6868 Mdot
.63173 .40124 Mdot
.51472 .71757 Mdot
.26535 .5042 Mdot
.55012 .44654 Mdot
.49198 .70318 Mdot
.52207 .40142 Mdot
.59441 .39649 Mdot
.42798 .3852 Mdot
.51321 .68775 Mdot
.58901 .36606 Mdot
.82619 .38996 Mdot
.31098 .60482 Mdot
.38336 .49342 Mdot
.49988 .60821 Mdot
.32576 .5806 Mdot
.39055 .34072 Mdot
.63186 .39274 Mdot
.6818 .64966 Mdot
.42122 .36307 Mdot
.49786 .76657 Mdot
.66797 .62544 Mdot
.45452 .45379 Mdot
.42422 .35962 Mdot
.376 .50662 Mdot
.65586 .66193 Mdot
.64834 .37799 Mdot
.49627 .7055 Mdot
.28964 .72644 Mdot
.39388 .48666 Mdot
.62524 .41942 Mdot
.49058 .76056 Mdot
.32682 .57848 Mdot
.61171 .45387 Mdot
.49742 .73059 Mdot
.38842 .48895 Mdot
.59423 .40112 Mdot
.61322 .3884 Mdot
.48569 .37096 Mdot
.58231 .6259 Mdot
.67147 .63852 Mdot
.42517 .40293 Mdot
.55482 .43413 Mdot
.64292 .63612 Mdot
.32191 .71408 Mdot
.54677 .42749 Mdot
.37132 .35769 Mdot
.47803 .31935 Mdot
.48922 .6835 Mdot
.33996 .58923 Mdot
.52366 .70834 Mdot
.68139 .6268 Mdot
.25176 .74665 Mdot
.37851 .49089 Mdot
.65035 .39493 Mdot
.60541 .3666 Mdot
.44984 .70846 Mdot
.39773 .37096 Mdot
.30356 .34997 Mdot
.64458 .41039 Mdot
.67285 .44649 Mdot
.60706 .42731 Mdot
.3221 .72332 Mdot
.38259 .36454 Mdot
.60885 .42885 Mdot
.57804 .35192 Mdot
.57986 .37676 Mdot
.69137 .65243 Mdot
.76883 .43806 Mdot
.57665 .44273 Mdot
.73092 .81095 Mdot
.36803 .51557 Mdot
.48808 .70906 Mdot
.53384 .5381 Mdot
.51212 .62552 Mdot
.77336 .66808 Mdot
.38507 .34705 Mdot
.33674 .35885 Mdot
.46792 .69893 Mdot
.751 .67122 Mdot
.34457 .40758 Mdot
.6038 .38849 Mdot
.63878 .40987 Mdot
.49247 .69116 Mdot
.48446 .68034 Mdot
.36876 .50362 Mdot
.60993 .46293 Mdot
.65707 .47399 Mdot
.51943 .72922 Mdot
.59895 .41184 Mdot
.48396 .26265 Mdot
.32156 .63318 Mdot
.42696 .36028 Mdot
.31541 .58875 Mdot
.32128 .63178 Mdot
.5053 .36776 Mdot
.49198 .50005 Mdot
.32111 .62317 Mdot
.34015 .63213 Mdot
.69212 .69649 Mdot
.60497 .3193 Mdot
.69049 .65465 Mdot
.42732 .50381 Mdot
.48011 .72691 Mdot
.62182 .43322 Mdot
.38199 .3694 Mdot
.82739 .51936 Mdot
.27991 .3869 Mdot
.68241 .50249 Mdot
.56143 .44386 Mdot
.47692 .72101 Mdot
.39244 .48752 Mdot
.54698 .43675 Mdot
.72248 .56854 Mdot
.61591 .41307 Mdot
.47433 .68493 Mdot
.59668 .31902 Mdot
.26565 .58625 Mdot
.32692 .56689 Mdot
.3597 .35572 Mdot
.58697 .43417 Mdot
.39558 .35069 Mdot
.32187 .6259 Mdot
.6506 .62299 Mdot
.66692 .64801 Mdot
.62417 .45051 Mdot
.48781 .59276 Mdot
.64034 .68968 Mdot
.60051 .39017 Mdot
.57543 .41498 Mdot
.38618 .51481 Mdot
.57522 .41639 Mdot
.58519 .46211 Mdot
.56386 .41995 Mdot
.57191 .46306 Mdot
.29315 .58469 Mdot
.47185 .39933 Mdot
.63085 .45219 Mdot
.61894 .36586 Mdot
.35068 .61661 Mdot
.56893 .37155 Mdot
.3308 .61389 Mdot
.29503 .38146 Mdot
.31695 .62131 Mdot
.66803 .64704 Mdot
.49804 .7606 Mdot
.35305 .3953 Mdot
.40743 .33471 Mdot
.29193 .5915 Mdot
.65618 .65852 Mdot
.33988 .60274 Mdot
.49781 .73642 Mdot
.26129 .67616 Mdot
.44177 .40227 Mdot
.47189 .52331 Mdot
.61859 .31664 Mdot
.36015 .51752 Mdot
.50746 .69235 Mdot
.42177 .34567 Mdot
.26419 .60872 Mdot
.56958 .40064 Mdot
.68195 .64262 Mdot
.61024 .41243 Mdot
.29362 .61655 Mdot
.47873 .72327 Mdot
.39321 .52641 Mdot
.6705 .63838 Mdot
.2668 .74473 Mdot
.51237 .73711 Mdot
.62741 .37674 Mdot
.35048 .61608 Mdot
.26823 .67302 Mdot
.32678 .61862 Mdot
.70707 .50536 Mdot
.38863 .30129 Mdot
.81993 .54902 Mdot
.41565 .37217 Mdot
.37507 .48279 Mdot
.3852 .19712 Mdot
.33996 .46796 Mdot
.41047 .35615 Mdot
.44784 .75547 Mdot
.60752 .40563 Mdot
.56408 .44076 Mdot
.66317 .44436 Mdot
.41253 .31617 Mdot
.55987 .44668 Mdot
.37927 .49359 Mdot
.49279 .50703 Mdot
.38741 .61785 Mdot
.48169 .67285 Mdot
.63243 .40443 Mdot
.33784 .62327 Mdot
.2884 .59898 Mdot
.40076 .49978 Mdot
.30584 .58996 Mdot
.58576 .41071 Mdot
.41942 .37159 Mdot
.46104 .5929 Mdot
.6861 .64149 Mdot
.29075 .51811 Mdot
.61132 .63571 Mdot
.67077 .68859 Mdot
.58073 .3752 Mdot
.46574 .70003 Mdot
.49983 .82203 Mdot
.56124 .41768 Mdot
.39749 .36497 Mdot
.60812 .36743 Mdot
.56423 .42969 Mdot
.5821 .44357 Mdot
.4942 .73429 Mdot
.52719 .5396 Mdot
.59752 .41295 Mdot
.31949 .6239 Mdot
.46762 .56324 Mdot
.55742 .45859 Mdot
.40996 .6415 Mdot
.48773 .61012 Mdot
.36096 .51946 Mdot
.37821 .40048 Mdot
.47637 .69257 Mdot
.41077 .3705 Mdot
.41343 .32287 Mdot
.39151 .34032 Mdot
.40144 .59966 Mdot
.45308 .28588 Mdot
.62758 .82897 Mdot
.63464 .26387 Mdot
.61237 .31253 Mdot
.3682 .34188 Mdot
.37427 .70628 Mdot
.40628 .3541 Mdot
.38863 .34259 Mdot
.50554 .88857 Mdot
.37822 .37082 Mdot
.61146 .43387 Mdot
.65018 .42303 Mdot
.34287 .27162 Mdot
.70135 .68705 Mdot
.60856 .3927 Mdot
.57021 .45429 Mdot
.64193 .65816 Mdot
.48552 .38061 Mdot
.36914 .49789 Mdot
.47573 .48212 Mdot
.38726 .47953 Mdot
.60367 .42342 Mdot
.63307 .43866 Mdot
.59927 .47006 Mdot
.44288 .15735 Mdot
.81896 .5714 Mdot
.40408 .39911 Mdot
.61391 .35049 Mdot
.36004 .5343 Mdot
.61114 .37294 Mdot
.59811 .36869 Mdot
.58062 .43483 Mdot
.46984 .69584 Mdot
.36671 .37978 Mdot
.66282 .38847 Mdot
.32669 .51524 Mdot
.63741 .42616 Mdot
.61468 .65853 Mdot
.6649 .61208 Mdot
.61799 .42423 Mdot
.37739 .37224 Mdot
.56336 .44318 Mdot
.39492 .33204 Mdot
.42312 .35478 Mdot
.66435 .4598 Mdot
.40968 .57398 Mdot
.36287 .36802 Mdot
.60618 .38782 Mdot
.50374 .69237 Mdot
.28035 .51327 Mdot
.62401 .42041 Mdot
.66944 .63027 Mdot
.59694 .44833 Mdot
.69268 .64741 Mdot
.57312 .42747 Mdot
.39962 .49662 Mdot
.45983 .21267 Mdot
.46922 .72429 Mdot
.68128 .68859 Mdot
.50108 .6867 Mdot
.61723 .48495 Mdot
.37063 .34346 Mdot
.31459 .54678 Mdot
.8086 .60087 Mdot
.38497 .51507 Mdot
.75503 .60629 Mdot
.45646 .56233 Mdot
.34903 .60906 Mdot
.44142 .3546 Mdot
.56522 .33029 Mdot
.4179 .63725 Mdot
.469 .67602 Mdot
.45923 .73554 Mdot
.55519 .76629 Mdot
.44343 .85874 Mdot
.59727 .40957 Mdot
.35178 .66316 Mdot
.49351 .2353 Mdot
.5537 .35647 Mdot
.53207 .41226 Mdot
.50691 .74829 Mdot
.60795 .39258 Mdot
.59527 .55396 Mdot
.49103 .72691 Mdot
.66984 .66064 Mdot
.40005 .34471 Mdot
.64494 .64373 Mdot
.25418 .38067 Mdot
.41478 .48278 Mdot
.49628 .7209 Mdot
.57054 .46387 Mdot
.61857 .39545 Mdot
.44234 .36607 Mdot
.62435 .22217 Mdot
.42738 .35761 Mdot
.6829 .63369 Mdot
.47477 .73291 Mdot
.79837 .39852 Mdot
.59194 .447 Mdot
.40345 .38733 Mdot
.45296 .75948 Mdot
.61463 .44645 Mdot
.34129 .5922 Mdot
.55924 .44027 Mdot
.4042 .38922 Mdot
.57486 .41712 Mdot
.41842 .36939 Mdot
.51164 .7059 Mdot
.63163 .44617 Mdot
.62828 .44461 Mdot
.74905 .59576 Mdot
.65978 .65057 Mdot
.36874 .34908 Mdot
.59757 .55306 Mdot
.55155 .41801 Mdot
.71791 .56088 Mdot
.58585 .43256 Mdot
.62369 .32326 Mdot
.54707 .40664 Mdot
.37705 .49638 Mdot
.60166 .36714 Mdot
.6235 .41926 Mdot
.64676 .24464 Mdot
.62863 .25323 Mdot
.56321 .33942 Mdot
.31136 .57645 Mdot
.39339 .38796 Mdot
.49651 .72722 Mdot
.49477 .67576 Mdot
.47666 .70144 Mdot
.69511 .61852 Mdot
.60666 .35009 Mdot
.62839 .41817 Mdot
.36721 .60967 Mdot
.67235 .65409 Mdot
.39817 .38273 Mdot
.67252 .64675 Mdot
.49426 .49892 Mdot
.66469 .62902 Mdot
.38236 .48897 Mdot
.27845 .70719 Mdot
.48553 .27436 Mdot
.65541 .6365 Mdot
.42625 .35671 Mdot
.46354 .54714 Mdot
.63748 .36405 Mdot
.22445 .52771 Mdot
.67438 .66958 Mdot
.53593 .7861 Mdot
.59182 .4067 Mdot
.552 .54092 Mdot
.32687 .61347 Mdot
.64534 .6447 Mdot
.30195 .60151 Mdot
.56291 .44177 Mdot
.47312 .38573 Mdot
.39134 .36308 Mdot
.32947 .63131 Mdot
.57373 .38318 Mdot
.64515 .64523 Mdot
.49792 .71533 Mdot
.60036 .31961 Mdot
.35164 .6206 Mdot
.75414 .64408 Mdot
.71836 .57092 Mdot
.47782 .73402 Mdot
.64217 .30406 Mdot
.30742 .61373 Mdot
.62586 .35719 Mdot
.68657 .46273 Mdot
.55747 .42398 Mdot
.45934 .70524 Mdot
.49664 .70231 Mdot
.36687 .47047 Mdot
.63466 .43898 Mdot
.64105 .44435 Mdot
.38161 .39674 Mdot
.47862 .73693 Mdot
.39238 .33923 Mdot
.43586 .35346 Mdot
.49439 .69082 Mdot
.42538 .34877 Mdot
.6638 .62377 Mdot
.59937 .53775 Mdot
.30907 .61587 Mdot
.34433 .59683 Mdot
.49851 .7193 Mdot
.47096 .73847 Mdot
.46444 .70175 Mdot
.56914 .39287 Mdot
.41364 .33988 Mdot
.58525 .38481 Mdot
.58727 .4375 Mdot
.3472 .32821 Mdot
.39569 .40394 Mdot
.5898 .3757 Mdot
.44818 .59511 Mdot
.68839 .66477 Mdot
.48885 .70364 Mdot
.29585 .59574 Mdot
.76462 .63951 Mdot
.35076 .61038 Mdot
.55068 .42504 Mdot
.23649 .50886 Mdot
.38399 .36939 Mdot
.66375 .64132 Mdot
.48935 .61493 Mdot
.6679 .63867 Mdot
.32364 .63266 Mdot
.41158 .40437 Mdot
.45633 .46373 Mdot
.63484 .44002 Mdot
.50931 .51867 Mdot
.76007 .53502 Mdot
.30982 .50046 Mdot
.29374 .59505 Mdot
.56466 .44878 Mdot
.37905 .51595 Mdot
.42785 .26976 Mdot
.62772 .41502 Mdot
.56221 .39088 Mdot
.53198 .64611 Mdot
.60196 .36569 Mdot
.42653 .39811 Mdot
.48149 .60713 Mdot
.59497 .46561 Mdot
.61812 .48354 Mdot
.48591 .85971 Mdot
.59748 .3977 Mdot
.62638 .44734 Mdot
.61014 .43941 Mdot
.56858 .39925 Mdot
.39447 .33072 Mdot
.53936 .66807 Mdot
.33014 .6264 Mdot
.60034 .53807 Mdot
.30141 .60724 Mdot
.50368 .7111 Mdot
.58289 .56506 Mdot
.39633 .33123 Mdot
.6678 .63806 Mdot
.33695 .67085 Mdot
.661 .53499 Mdot
.51269 .70359 Mdot
.77395 .60321 Mdot
.68405 .66232 Mdot
.63719 .36344 Mdot
.67751 .62264 Mdot
.50041 .75385 Mdot
.34279 .59857 Mdot
.64294 .39405 Mdot
.38051 .34527 Mdot
.42234 .38448 Mdot
.55661 .4365 Mdot
.28834 .52526 Mdot
.33291 .58056 Mdot
.67861 .58784 Mdot
.61722 .40116 Mdot
.55888 .3975 Mdot
.42831 .35565 Mdot
.47523 .71639 Mdot
.45842 .56254 Mdot
.65647 .65386 Mdot
.6298 .38498 Mdot
.56957 .44785 Mdot
.49612 .50121 Mdot
.29169 .5893 Mdot
.38661 .50111 Mdot
.6315 .41088 Mdot
.48116 .49391 Mdot
.55925 .44719 Mdot
.5969 .47535 Mdot
.49515 .68689 Mdot
.67033 .45212 Mdot
.64232 .42329 Mdot
.46977 .38238 Mdot
.30604 .61063 Mdot
.40057 .36869 Mdot
.34369 .34001 Mdot
.39719 .50413 Mdot
.31174 .60085 Mdot
.58586 .37706 Mdot
.29289 .62693 Mdot
.56401 .43581 Mdot
.59882 .41605 Mdot
.29426 .59273 Mdot
.40156 .33805 Mdot
.31514 .38057 Mdot
.47202 .39929 Mdot
.57142 .40452 Mdot
.60076 .44856 Mdot
.70027 .68747 Mdot
.83683 .53058 Mdot
.64253 .42805 Mdot
.42002 .34276 Mdot
.61429 .44751 Mdot
.3469 .60958 Mdot
.67911 .63066 Mdot
.40081 .36123 Mdot
.4886 .74015 Mdot
.5118 .71021 Mdot
.44127 .72195 Mdot
.38056 .48923 Mdot
.61644 .4596 Mdot
.42121 .40443 Mdot
.3966 .40271 Mdot
.56895 .52915 Mdot
.48872 .70805 Mdot
.67606 .62788 Mdot
.61098 .39055 Mdot
.50939 .39312 Mdot
.31538 .63116 Mdot
.75547 .7864 Mdot
.45886 .46964 Mdot
.6938 .62554 Mdot
.55437 .58622 Mdot
.38502 .5132 Mdot
.60222 .3986 Mdot
.64363 .64814 Mdot
.50509 .70315 Mdot
.56423 .44186 Mdot
.55768 .37054 Mdot
.41908 .64736 Mdot
.46529 .73677 Mdot
.30865 .63251 Mdot
.51007 .72877 Mdot
.69274 .6533 Mdot
.38226 .48967 Mdot
.41642 .391 Mdot
.61901 .418 Mdot
.656 .47858 Mdot
.48191 .71707 Mdot
.38476 .5203 Mdot
.61004 .45758 Mdot
.4014 .39277 Mdot
.48204 .70441 Mdot
.60078 .42843 Mdot
.43181 .2751 Mdot
.35203 .39283 Mdot
.48037 .73043 Mdot
.62672 .38488 Mdot
.55894 .4863 Mdot
.46378 .73724 Mdot
.49154 .755 Mdot
.56584 .45196 Mdot
.64767 .65067 Mdot
.64063 .42362 Mdot
.33471 .61523 Mdot
.52625 .54007 Mdot
.3161 .59254 Mdot
.72468 .56785 Mdot
.58331 .47233 Mdot
.70814 .41692 Mdot
.42763 .33816 Mdot
.66559 .68125 Mdot
.70157 .26946 Mdot
.55081 .41596 Mdot
.30408 .29388 Mdot
.54044 .55182 Mdot
.46419 .49796 Mdot
.27737 .31134 Mdot
.65253 .64477 Mdot
.33838 .60328 Mdot
.61387 .45513 Mdot
.29769 .6601 Mdot
.65032 .63936 Mdot
.72465 .56684 Mdot
.60491 .37842 Mdot
.39109 .37435 Mdot
.61537 .40273 Mdot
.40418 .391 Mdot
.61475 .44349 Mdot
.44154 .30684 Mdot
.61675 .66682 Mdot
.70812 .50322 Mdot
.64458 .36987 Mdot
.26506 .66731 Mdot
.61777 .31596 Mdot
.67654 .63208 Mdot
.57156 .41039 Mdot
.38921 .50618 Mdot
.32708 .57793 Mdot
.3339 .68264 Mdot
.4666 .70048 Mdot
.31442 .62255 Mdot
.41657 .34706 Mdot
.51118 .74962 Mdot
.38594 .5186 Mdot
.66965 .38926 Mdot
.64529 .64788 Mdot
.31129 .60436 Mdot
.62133 .42062 Mdot
.55838 .41162 Mdot
.32106 .7237 Mdot
.78683 .37781 Mdot
.42849 .34726 Mdot
.33894 .81226 Mdot
.42964 .40052 Mdot
.66453 .65582 Mdot
.49022 .6854 Mdot
.59542 .43584 Mdot
.63438 .4219 Mdot
.4642 .73281 Mdot
.43779 .37567 Mdot
.6532 .68082 Mdot
.82387 .54411 Mdot
.29841 .63786 Mdot
.75245 .4617 Mdot
.39922 .35906 Mdot
.75084 .46481 Mdot
.64997 .60555 Mdot
.37852 .5463 Mdot
.75576 .38335 Mdot
.33178 .58696 Mdot
.75432 .45877 Mdot
.39376 .38139 Mdot
.59786 .40701 Mdot
.37687 .50747 Mdot
.36975 .51423 Mdot
.40081 .34856 Mdot
.48775 .68993 Mdot
.67144 .6655 Mdot
.61808 .40412 Mdot
.6834 .40346 Mdot
.61432 .21341 Mdot
.47683 .73974 Mdot
.6672 .43387 Mdot
.31906 .58123 Mdot
.60914 .44829 Mdot
.63914 .64854 Mdot
.33551 .59374 Mdot
.3979 .48559 Mdot
.65596 .53713 Mdot
.63169 .39233 Mdot
.4882 .60004 Mdot
.32096 .61113 Mdot
.83685 .5229 Mdot
.62858 .44391 Mdot
.30717 .61338 Mdot
.65621 .47748 Mdot
.3005 .54632 Mdot
.4638 .58088 Mdot
.33881 .46516 Mdot
.51199 .68061 Mdot
.51368 .72003 Mdot
.82705 .3999 Mdot
.62728 .59841 Mdot
.30732 .62265 Mdot
.38769 .48627 Mdot
.77479 .42129 Mdot
.30451 .59994 Mdot
.63662 .39014 Mdot
.58641 .42851 Mdot
.59643 .31896 Mdot
.51425 .39553 Mdot
.36743 .50539 Mdot
.65626 .35559 Mdot
.58332 .40823 Mdot
.66881 .40562 Mdot
.60347 .45565 Mdot
.39436 .39449 Mdot
.3277 .58466 Mdot
.22612 .29063 Mdot
.28646 .6191 Mdot
.69716 .4438 Mdot
.47992 .72668 Mdot
.52035 .69129 Mdot
.61687 .42412 Mdot
.7174 .41589 Mdot
.15105 .52824 Mdot
.58664 .44628 Mdot
.48934 .61431 Mdot
.72016 .57285 Mdot
.61962 .35457 Mdot
.36727 .36046 Mdot
.66146 .46972 Mdot
.44642 .3939 Mdot
.33655 .59346 Mdot
.65191 .64267 Mdot
.67391 .67351 Mdot
.33604 .60835 Mdot
.63243 .42477 Mdot
.66202 .67332 Mdot
.61086 .42051 Mdot
.61191 .39595 Mdot
.48365 .4891 Mdot
.64912 .62032 Mdot
.46489 .69934 Mdot
.66686 .64551 Mdot
.38233 .35131 Mdot
.50609 .90022 Mdot
.67761 .6429 Mdot
.60464 .31922 Mdot
.5726 .55057 Mdot
.75637 .46292 Mdot
.42593 .38155 Mdot
.68573 .63793 Mdot
.33428 .5865 Mdot
.44787 .45405 Mdot
.62591 .30663 Mdot
.35039 .61076 Mdot
.63004 .41424 Mdot
.40258 .33093 Mdot
.39787 .39987 Mdot
.32053 .56763 Mdot
.4335 .37837 Mdot
.65077 .38688 Mdot
.6126 .3859 Mdot
.31764 .62572 Mdot
.51424 .16075 Mdot
.34137 .58972 Mdot
.50936 .36298 Mdot
.57925 .43198 Mdot
.3992 .36335 Mdot
.62816 .32321 Mdot
.3512 .33883 Mdot
.37049 .50626 Mdot
.64734 .4167 Mdot
.67942 .63758 Mdot
.5898 .54019 Mdot
.47837 .73011 Mdot
.23878 .5042 Mdot
.4167 .3863 Mdot
.29703 .57499 Mdot
.4272 .38559 Mdot
.43941 .36457 Mdot
.33861 .62695 Mdot
.38647 .36342 Mdot
.63696 .42616 Mdot
.20682 .41465 Mdot
.422 .38022 Mdot
.32502 .60483 Mdot
.68468 .64588 Mdot
.42323 .34701 Mdot
.70383 .6061 Mdot
.62139 .39388 Mdot
.51949 .70879 Mdot
.69864 .67202 Mdot
.4355 .34123 Mdot
.67585 .62995 Mdot
.48364 .7121 Mdot
.66626 .66625 Mdot
.33164 .65543 Mdot
.3223 .56083 Mdot
.68927 .49211 Mdot
.27996 .5633 Mdot
.37864 .36254 Mdot
.52666 .69328 Mdot
.63637 .39787 Mdot
.61589 .3991 Mdot
.69116 .66579 Mdot
.3927 .3958 Mdot
.27905 .53561 Mdot
.69767 .36497 Mdot
.2922 .51834 Mdot
.30128 .57943 Mdot
.73421 .65027 Mdot
.45642 .46711 Mdot
.28138 .64398 Mdot
.65361 .43787 Mdot
.384 .51309 Mdot
.607 .42814 Mdot
.73084 .58889 Mdot
.68913 .65795 Mdot
.3548 .74883 Mdot
.57224 .47314 Mdot
.4637 .72737 Mdot
.60814 .44426 Mdot
.37652 .65081 Mdot
.61262 .48157 Mdot
.67657 .6698 Mdot
.2819 .62055 Mdot
.40752 .3347 Mdot
.68828 .64934 Mdot
.51112 .70684 Mdot
.74113 .41917 Mdot
.63669 .39145 Mdot
.58652 .40634 Mdot
.46464 .74272 Mdot
.38657 .34167 Mdot
.50122 .70745 Mdot
.30839 .61534 Mdot
.67515 .64367 Mdot
.57401 .39153 Mdot
.66992 .42395 Mdot
.44938 .71309 Mdot
.2936 .62139 Mdot
.4561 .71693 Mdot
.29408 .6271 Mdot
.38041 .51322 Mdot
.5832 .46769 Mdot
.46133 .74281 Mdot
.63112 .45634 Mdot
.60202 .24939 Mdot
.61984 .53511 Mdot
.68112 .28141 Mdot
.46539 .69754 Mdot
.6078 .66406 Mdot
.33366 .60369 Mdot
.30967 .60715 Mdot
.50924 .35426 Mdot
.16507 .55347 Mdot
.4646 .56025 Mdot
.24574 .67839 Mdot
.30931 .61628 Mdot
.3171 .60785 Mdot
.49631 .69751 Mdot
.38811 .34584 Mdot
.41992 .32587 Mdot
.48668 .75961 Mdot
.69328 .54918 Mdot
.39823 .38298 Mdot
.32009 .27697 Mdot
.49577 .74586 Mdot
.65381 .42083 Mdot
.41091 .48676 Mdot
.67571 .66973 Mdot
.70873 .57168 Mdot
.26635 .68011 Mdot
.60206 .43559 Mdot
.58379 .83864 Mdot
.47155 .69696 Mdot
.42788 .49104 Mdot
.37258 .58166 Mdot
.5602 .40142 Mdot
.61254 .44094 Mdot
.62955 .43733 Mdot
.70084 .6417 Mdot
.60438 .22635 Mdot
.59873 .43517 Mdot
.68573 .52631 Mdot
.54935 .44518 Mdot
.30369 .72773 Mdot
.66716 .64562 Mdot
.7963 .55209 Mdot
.5287 .72443 Mdot
.31601 .52225 Mdot
.5747 .37943 Mdot
.31713 .61839 Mdot
.42681 .6203 Mdot
.29195 .60294 Mdot
.37271 .56342 Mdot
.77394 .40071 Mdot
.3878 .39087 Mdot
.55793 .43781 Mdot
.49193 .74897 Mdot
.41659 .33223 Mdot
.435 .61065 Mdot
.48706 .89346 Mdot
.30827 .57176 Mdot
.3267 .82807 Mdot
.31084 .59369 Mdot
.36845 .51327 Mdot
.41613 .34865 Mdot
.72465 .40446 Mdot
.50484 .51363 Mdot
.39408 .33885 Mdot
.61445 .75722 Mdot
.45569 .36432 Mdot
.73842 .45675 Mdot
.43686 .40852 Mdot
.32896 .59996 Mdot
.3006 .57066 Mdot
.55005 .38551 Mdot
.64246 .41483 Mdot
.50839 .52272 Mdot
.52882 .40712 Mdot
.63153 .39357 Mdot
.49091 .72726 Mdot
.26153 .58816 Mdot
.29397 .66042 Mdot
.39617 .35524 Mdot
.30771 .62859 Mdot
.60925 .4429 Mdot
.57168 .40451 Mdot
.62181 .36987 Mdot
.75411 .66837 Mdot
.3189 .27618 Mdot
.59664 .41619 Mdot
.61969 .4797 Mdot
.50886 .69823 Mdot
.32174 .72512 Mdot
.35819 .81356 Mdot
.77393 .40916 Mdot
.60424 .45957 Mdot
.66185 .65032 Mdot
.63945 .65302 Mdot
.63565 .3745 Mdot
.71174 .43791 Mdot
.72602 .65593 Mdot
.6216 .42075 Mdot
.72778 .45533 Mdot
.45898 .68428 Mdot
.39325 .51311 Mdot
.48238 .71666 Mdot
.42758 .3359 Mdot
.38193 .51659 Mdot
.5026 .72567 Mdot
.67341 .53778 Mdot
.39742 .49858 Mdot
.30369 .54338 Mdot
.6846 .63558 Mdot
.6126 .45344 Mdot
.41395 .4319 Mdot
.48072 .73892 Mdot
.31557 .61041 Mdot
.41549 .36206 Mdot
.32598 .57663 Mdot
.28653 .72061 Mdot
.69711 .55436 Mdot
.37715 .49296 Mdot
.31979 .61942 Mdot
.48398 .58746 Mdot
.66366 .65047 Mdot
.30786 .59083 Mdot
.71015 .41376 Mdot
.55968 .46336 Mdot
.16263 .44026 Mdot
.58668 .40072 Mdot
.36875 .46093 Mdot
.31449 .61344 Mdot
.39944 .48457 Mdot
.61825 .41656 Mdot
.51414 .73363 Mdot
.63592 .35618 Mdot
.60957 .41986 Mdot
.50118 .73824 Mdot
.596 .41265 Mdot
.64229 .63205 Mdot
.44829 .38736 Mdot
.55402 .55374 Mdot
.74167 .63573 Mdot
.67826 .6632 Mdot
.54138 .51399 Mdot
.64343 .42662 Mdot
.58568 .73276 Mdot
.39263 .37392 Mdot
.55095 .41765 Mdot
.73963 .56927 Mdot
.39257 .34732 Mdot
.41129 .37152 Mdot
.57621 .4092 Mdot
.34525 .59294 Mdot
.45897 .71155 Mdot
.66434 .64872 Mdot
.2692 .64983 Mdot
.59891 .42972 Mdot
.56426 .44912 Mdot
.68606 .65913 Mdot
.31329 .60271 Mdot
.5781 .38604 Mdot
.27722 .4594 Mdot
.59002 .53176 Mdot
.31097 .63187 Mdot
.55811 .45946 Mdot
.23966 .32474 Mdot
.43436 .33322 Mdot
.59357 .83766 Mdot
.61087 .65185 Mdot
.49329 .68861 Mdot
.66379 .44887 Mdot
.68945 .84302 Mdot
.68387 .63674 Mdot
.31078 .51251 Mdot
.60119 .40608 Mdot
.59246 .43858 Mdot
.38512 .38543 Mdot
.59095 .37914 Mdot
.38909 .38241 Mdot
.74039 .65733 Mdot
.16925 .57147 Mdot
.43335 .37652 Mdot
.39594 .38756 Mdot
.55041 .46956 Mdot
.7573 .67493 Mdot
.40394 .34487 Mdot
.63607 .39122 Mdot
.60423 .73535 Mdot
.55755 .36687 Mdot
.65868 .61321 Mdot
.72074 .677 Mdot
.36704 .35667 Mdot
.60961 .3045 Mdot
.55061 .46936 Mdot
.4612 .31647 Mdot
.70845 .61859 Mdot
.30211 .61647 Mdot
.56816 .43325 Mdot
.385 .48618 Mdot
.48531 .70136 Mdot
.67835 .45067 Mdot
.62411 .44667 Mdot
.37312 .35531 Mdot
.69829 .63979 Mdot
.30366 .59632 Mdot
.58565 .45885 Mdot
.44747 .70749 Mdot
.66202 .65996 Mdot
.42527 .3725 Mdot
.54919 .33796 Mdot
.66244 .67201 Mdot
.66969 .42994 Mdot
.59438 .40844 Mdot
.59091 .46049 Mdot
.58024 .34542 Mdot
.33361 .61002 Mdot
.4995 .7571 Mdot
.66516 .43896 Mdot
.46324 .46731 Mdot
.62217 .54322 Mdot
.64148 .38838 Mdot
.42114 .34406 Mdot
.30063 .58127 Mdot
.38749 .49226 Mdot
.7651 .44792 Mdot
.58555 .42024 Mdot
.31364 .27829 Mdot
.79447 .60372 Mdot
.39503 .49803 Mdot
.39383 .32841 Mdot
.66489 .64164 Mdot
.57848 .41985 Mdot
.69145 .52318 Mdot
.62572 .38587 Mdot
.59403 .34608 Mdot
.48328 .68818 Mdot
.29677 .60688 Mdot
.65442 .51212 Mdot
.48822 .70072 Mdot
.41093 .37086 Mdot
.341 .26767 Mdot
.4264 .33044 Mdot
.43549 .35458 Mdot
.40602 .57 Mdot
.34289 .60729 Mdot
.70527 .83271 Mdot
.83827 .54795 Mdot
.65064 .41477 Mdot
.33914 .61919 Mdot
.41063 .34931 Mdot
.6036 .37041 Mdot
.38438 .37252 Mdot
.36516 .37296 Mdot
.61756 .38996 Mdot
.62317 .39107 Mdot
.71154 .49465 Mdot
.32377 .27825 Mdot
.68173 .64313 Mdot
.42566 .39082 Mdot
.49199 .34388 Mdot
.59455 .43312 Mdot
.63838 .43141 Mdot
.42273 .62501 Mdot
.68881 .64563 Mdot
.46507 .25637 Mdot
.61214 .40063 Mdot
.75593 .59846 Mdot
.64444 .40797 Mdot
.40187 .31993 Mdot
.35058 .58228 Mdot
.70221 .43614 Mdot
.4612 .69926 Mdot
.4426 .35838 Mdot
.69353 .65791 Mdot
.36152 .3814 Mdot
.47531 .28797 Mdot
.34066 .59644 Mdot
.40354 .38913 Mdot
.51897 .73935 Mdot
.31811 .59634 Mdot
.34374 .59355 Mdot
.43879 .60649 Mdot
.52176 .72893 Mdot
.69455 .62886 Mdot
.30399 .58587 Mdot
.43231 .27688 Mdot
.32716 .59783 Mdot
.46842 .28297 Mdot
.62454 .45347 Mdot
.68303 .52837 Mdot
.68964 .43394 Mdot
.54831 .38291 Mdot
.31884 .58556 Mdot
.66927 .66377 Mdot
.57392 .387 Mdot
.43627 .37103 Mdot
.67896 .65379 Mdot
.41527 .48857 Mdot
.52698 .70263 Mdot
.38935 .39677 Mdot
.29469 .62962 Mdot
.38037 .37197 Mdot
.71604 .57216 Mdot
.65373 .68394 Mdot
.43378 .62684 Mdot
.51651 .52188 Mdot
.66479 .39657 Mdot
.59772 .48403 Mdot
.56887 .39044 Mdot
.63441 .42871 Mdot
.48103 .72984 Mdot
.6944 .61872 Mdot
.42404 .34734 Mdot
.60775 .20297 Mdot
.32294 .61725 Mdot
.48359 .60222 Mdot
.60419 .34517 Mdot
.56362 .43761 Mdot
.41202 .35322 Mdot
.36549 .37913 Mdot
.6307 .25281 Mdot
.46094 .72904 Mdot
.55135 .37265 Mdot
.59124 .36757 Mdot
.60817 .5188 Mdot
.31926 .58749 Mdot
.31388 .44066 Mdot
.48335 .67394 Mdot
.35188 .85049 Mdot
.49027 .70311 Mdot
.56655 .67174 Mdot
.38578 .36184 Mdot
.66673 .62708 Mdot
.6328 .40988 Mdot
.48616 .39228 Mdot
.38375 .33374 Mdot
.53531 .73124 Mdot
.66847 .6354 Mdot
.32676 .40999 Mdot
.32905 .62313 Mdot
.59296 .46399 Mdot
.6434 .40411 Mdot
.57966 .39273 Mdot
.60611 .37302 Mdot
.31562 .62721 Mdot
.61997 .38438 Mdot
.34858 .62455 Mdot
.48231 .28272 Mdot
.74014 .56109 Mdot
.48884 .75251 Mdot
.33485 .73376 Mdot
.43628 .35756 Mdot
.38778 .24642 Mdot
.47729 .26302 Mdot
.61893 .53508 Mdot
.34916 .64651 Mdot
.5964 .46639 Mdot
.48711 .69096 Mdot
.27803 .66951 Mdot
.49175 .75208 Mdot
.1684 .36564 Mdot
.60102 .31789 Mdot
.35575 .44194 Mdot
.59119 .38443 Mdot
.46685 .74848 Mdot
.5765 .30829 Mdot
.67111 .43168 Mdot
.66123 .67546 Mdot
.4607 .29054 Mdot
.41834 .43836 Mdot
.67904 .62923 Mdot
.61571 .39307 Mdot
.39595 .40454 Mdot
.63401 .41597 Mdot
.6297 .40357 Mdot
.58638 .44751 Mdot
.35965 .59676 Mdot
.64473 .43694 Mdot
.64028 .42152 Mdot
.79271 .38471 Mdot
.46414 .63888 Mdot
.51624 .71256 Mdot
.6723 .27382 Mdot
.67272 .65404 Mdot
.42734 .3362 Mdot
.53933 .54991 Mdot
.33186 .61882 Mdot
.63298 .25376 Mdot
.58486 .39521 Mdot
.29464 .49527 Mdot
.28685 .59223 Mdot
.65096 .65294 Mdot
.39058 .48922 Mdot
.30718 .4076 Mdot
.48 .68255 Mdot
.3709 .49547 Mdot
.4766 .72985 Mdot
.69903 .29307 Mdot
.39301 .38628 Mdot
.66514 .39753 Mdot
.30164 .59452 Mdot
.50705 .74781 Mdot
.68996 .52191 Mdot
.61978 .44628 Mdot
.4649 .69778 Mdot
.68173 .43669 Mdot
.59786 .5448 Mdot
.5334 .54732 Mdot
.50818 .75031 Mdot
.28239 .6006 Mdot
.31995 .59144 Mdot
.67871 .62655 Mdot
.44154 .35044 Mdot
.38088 .34654 Mdot
.32614 .5929 Mdot
.4912 .84359 Mdot
.60038 .43053 Mdot
.58941 .42891 Mdot
.4586 .46252 Mdot
.60296 .36874 Mdot
.68935 .6905 Mdot
.36955 .52103 Mdot
.37949 .34368 Mdot
.57096 .38859 Mdot
.57846 .3862 Mdot
.59447 .40454 Mdot
.69949 .54561 Mdot
.48019 .71653 Mdot
.58287 .40989 Mdot
.64465 .64889 Mdot
.41276 .46523 Mdot
.63829 .401 Mdot
.67167 .42006 Mdot
.38663 .37952 Mdot
.5497 .76473 Mdot
.31784 .61317 Mdot
.47279 .73615 Mdot
.4852 .74686 Mdot
.75595 .5275 Mdot
.38577 .31458 Mdot
.36682 .5056 Mdot
.30005 .70945 Mdot
.38564 .4892 Mdot
.66695 .63251 Mdot
.46144 .57409 Mdot
.48818 .66265 Mdot
.51454 .71888 Mdot
.27985 .589 Mdot
.55378 .42314 Mdot
.63755 .39752 Mdot
.30979 .52177 Mdot
.58609 .44259 Mdot
.68026 .6372 Mdot
.35092 .59862 Mdot
.39601 .38629 Mdot
.64048 .6509 Mdot
.30803 .60426 Mdot
.3902 .33942 Mdot
.5555 .3973 Mdot
.63266 .38535 Mdot
.41574 .36561 Mdot
.42668 .37421 Mdot
.61604 .43141 Mdot
.7781 .36341 Mdot
.38707 .33723 Mdot
.41788 .35751 Mdot
.41069 .45597 Mdot
.49734 .68579 Mdot
.54835 .35439 Mdot
.34179 .61514 Mdot
.63786 .42762 Mdot
.48241 .75224 Mdot
.6581 .63467 Mdot
.41554 .37706 Mdot
.57064 .43352 Mdot
.59934 .42273 Mdot
.66167 .64852 Mdot
.64467 .62065 Mdot
.686 .65223 Mdot
.34338 .57835 Mdot
.60589 .38776 Mdot
.40966 .34446 Mdot
.32788 .62383 Mdot
.65503 .66883 Mdot
.67739 .62168 Mdot
.76247 .36551 Mdot
.60489 .43461 Mdot
.64334 .66565 Mdot
.54145 .90603 Mdot
.74764 .41852 Mdot
.38144 .51842 Mdot
.45583 .68235 Mdot
.62297 .68045 Mdot
.6964 .67351 Mdot
.29639 .61378 Mdot
.48536 .61215 Mdot
.69424 .63996 Mdot
.57886 .44281 Mdot
.59996 .45186 Mdot
.6543 .44283 Mdot
.67566 .65599 Mdot
.70186 .55538 Mdot
.40915 .40123 Mdot
.50248 .21982 Mdot
.67289 .65389 Mdot
.51441 .74146 Mdot
.44853 .71724 Mdot
.4952 .70271 Mdot
.57983 .46424 Mdot
.67022 .25524 Mdot
.48984 .31421 Mdot
.46461 .2499 Mdot
.32304 .6226 Mdot
.36606 .3794 Mdot
.39684 .52468 Mdot
.41146 .37227 Mdot
.4747 .70395 Mdot
.66282 .6613 Mdot
.38489 .38613 Mdot
.34329 .5938 Mdot
.32113 .58921 Mdot
.45661 .70525 Mdot
.48619 .71229 Mdot
.49711 .71846 Mdot
.44232 .35496 Mdot
.38599 .36264 Mdot
.57452 .39387 Mdot
.41737 .38028 Mdot
.80038 .61077 Mdot
.66571 .6942 Mdot
.4524 .71431 Mdot
.32708 .6099 Mdot
.42363 .35866 Mdot
.61523 .4529 Mdot
.54714 .64977 Mdot
.53218 .70005 Mdot
.66331 .66802 Mdot
.19437 .4896 Mdot
.15824 .56806 Mdot
.56126 .45873 Mdot
.29686 .62232 Mdot
.71095 .42716 Mdot
.62859 .43501 Mdot
.47833 .68738 Mdot
.80863 .56219 Mdot
.39673 .48947 Mdot
.63715 .40928 Mdot
.57321 .37609 Mdot
.33561 .58589 Mdot
.53824 .54859 Mdot
.57865 .44454 Mdot
.46605 .59821 Mdot
.29389 .5822 Mdot
.48119 .67456 Mdot
.84768 .42438 Mdot
.42487 .48552 Mdot
.70468 .58182 Mdot
.38897 .51518 Mdot
.58269 .44106 Mdot
.48888 .72857 Mdot
.64855 .66121 Mdot
.48852 .72124 Mdot
.40086 .32711 Mdot
.48869 .68339 Mdot
.59573 .45576 Mdot
.40369 .343 Mdot
.31167 .60287 Mdot
.49499 .59281 Mdot
.71273 .32144 Mdot
.51492 .73129 Mdot
.38861 .51944 Mdot
.62453 .39216 Mdot
.40983 .26329 Mdot
.54999 .38825 Mdot
.64243 .42178 Mdot
.29315 .59607 Mdot
.40417 .35305 Mdot
.30016 .58045 Mdot
.67702 .41657 Mdot
.35051 .28383 Mdot
.32694 .61653 Mdot
.47226 .40587 Mdot
.68482 .66161 Mdot
.69277 .55166 Mdot
.62091 .41086 Mdot
.3005 .59738 Mdot
.59902 .39234 Mdot
.42355 .3925 Mdot
.64626 .54237 Mdot
.57341 .52149 Mdot
.32088 .58068 Mdot
.36579 .43346 Mdot
.60041 .55323 Mdot
.52555 .36756 Mdot
.30363 .61004 Mdot
.69799 .26843 Mdot
.38966 .50294 Mdot
.65617 .65132 Mdot
.64004 .62433 Mdot
.65103 .6295 Mdot
.58769 .44049 Mdot
.43461 .29562 Mdot
.66623 .61857 Mdot
.33007 .57341 Mdot
.65192 .62214 Mdot
.75758 .64636 Mdot
.28663 .52698 Mdot
.67984 .66344 Mdot
.61553 .40931 Mdot
.67879 .46436 Mdot
.48712 .61186 Mdot
.52105 .69852 Mdot
.29608 .3503 Mdot
.79284 .3901 Mdot
.59605 .4367 Mdot
.40754 .28681 Mdot
.38526 .32573 Mdot
.58128 .63062 Mdot
.57328 .51963 Mdot
.46971 .54845 Mdot
.42139 .35855 Mdot
.52684 .53594 Mdot
.40656 .33219 Mdot
.64543 .36954 Mdot
.59941 .41506 Mdot
.44171 .34496 Mdot
.22951 .50299 Mdot
.66913 .23231 Mdot
.28868 .51359 Mdot
.41076 .3379 Mdot
.30593 .61033 Mdot
.29089 .61022 Mdot
.29354 .59664 Mdot
.48946 .73527 Mdot
.41189 .39008 Mdot
.58392 .41881 Mdot
.5073 .70067 Mdot
.62417 .40168 Mdot
.33034 .58995 Mdot
.60434 .53231 Mdot
.394 .38531 Mdot
.62269 .41922 Mdot
.54293 .32857 Mdot
.4743 .72439 Mdot
.66388 .65253 Mdot
.19777 .45988 Mdot
.46593 .67321 Mdot
.28264 .61621 Mdot
.3618 .35122 Mdot
.45733 .75461 Mdot
.5481 .69127 Mdot
.65181 .4148 Mdot
.64654 .40215 Mdot
.48855 .62077 Mdot
.59322 .3144 Mdot
.57814 .44803 Mdot
.51154 .70852 Mdot
.51053 .69388 Mdot
.59904 .39361 Mdot
.42293 .38717 Mdot
.68792 .62563 Mdot
.6905 .66684 Mdot
.64801 .37495 Mdot
.51517 .52494 Mdot
.68433 .52716 Mdot
.58425 .37884 Mdot
.64312 .45785 Mdot
.52305 .73103 Mdot
.38667 .51793 Mdot
.49928 .50469 Mdot
.66326 .6233 Mdot
.60388 .40268 Mdot
.61718 .21694 Mdot
.41434 .38654 Mdot
.46154 .70198 Mdot
.33777 .62411 Mdot
.66154 .67288 Mdot
.4563 .69907 Mdot
.59908 .39364 Mdot
.57852 .38581 Mdot
.30539 .59102 Mdot
.39636 .31868 Mdot
.67173 .66059 Mdot
.50737 .69961 Mdot
.66857 .62673 Mdot
.38625 .36557 Mdot
.42346 .36701 Mdot
.60428 .36239 Mdot
.54594 .38657 Mdot
.50508 .74132 Mdot
.6621 .42513 Mdot
.50492 .70703 Mdot
.32063 .72391 Mdot
.31551 .63096 Mdot
.56242 .39243 Mdot
.37422 .3185 Mdot
.3285 .59021 Mdot
.59988 .44063 Mdot
.48751 .62203 Mdot
.5592 .42756 Mdot
.48545 .75841 Mdot
.82235 .53032 Mdot
.65287 .63355 Mdot
.60769 .49926 Mdot
.6839 .33274 Mdot
.59516 .37064 Mdot
.51744 .69864 Mdot
.46054 .29983 Mdot
.33264 .61405 Mdot
.3879 .35634 Mdot
.52378 .80353 Mdot
.32548 .60249 Mdot
.61124 .40573 Mdot
.67741 .64399 Mdot
.41274 .33555 Mdot
.37326 .50811 Mdot
.49238 .51628 Mdot
.67771 .45821 Mdot
.60228 .35506 Mdot
.58526 .45956 Mdot
.24486 .67708 Mdot
.49435 .71989 Mdot
.41241 .35149 Mdot
.29889 .62206 Mdot
.34102 .60206 Mdot
.47495 .71641 Mdot
.41298 .44376 Mdot
.2564 .51012 Mdot
.58231 .8939 Mdot
.45389 .70384 Mdot
.64995 .62616 Mdot
.64171 .54184 Mdot
.49431 .70036 Mdot
.48266 .73554 Mdot
.52776 .7158 Mdot
.30072 .52536 Mdot
.40992 .33871 Mdot
.59783 .42342 Mdot
.3535 .3624 Mdot
.58427 .4405 Mdot
.68271 .57576 Mdot
.3317 .59199 Mdot
.38704 .35708 Mdot
.70582 .60556 Mdot
.61893 .48164 Mdot
.62345 .43465 Mdot
.66594 .58295 Mdot
.64172 .50489 Mdot
.75923 .45554 Mdot
.6215 .37189 Mdot
.48344 .72279 Mdot
.33651 .35021 Mdot
.66807 .43333 Mdot
.5378 .33092 Mdot
.31589 .59217 Mdot
.37522 .49405 Mdot
.66421 .39116 Mdot
.6222 .46758 Mdot
.41674 .33664 Mdot
.382 .38248 Mdot
.66966 .61858 Mdot
.20686 .42215 Mdot
.31357 .59507 Mdot
.33293 .45182 Mdot
.64321 .41898 Mdot
.37025 .62069 Mdot
.81805 .55203 Mdot
.60632 .44023 Mdot
.4441 .60029 Mdot
.63146 .25369 Mdot
.56748 .44355 Mdot
.47183 .24421 Mdot
.33011 .6058 Mdot
.74427 .5811 Mdot
.61012 .37922 Mdot
.47242 .69222 Mdot
.38641 .34877 Mdot
.38999 .3973 Mdot
.64906 .66333 Mdot
.81941 .58913 Mdot
.19951 .59935 Mdot
.38517 .35853 Mdot
.62547 .44277 Mdot
.31956 .61252 Mdot
.372 .50313 Mdot
.67443 .45563 Mdot
.34956 .65937 Mdot
.41116 .38606 Mdot
.66529 .44111 Mdot
.28938 .4956 Mdot
.53162 .54281 Mdot
.33261 .25334 Mdot
.29723 .59023 Mdot
.66698 .6226 Mdot
.54514 .36818 Mdot
.30123 .71286 Mdot
.63361 .38611 Mdot
.6902 .57711 Mdot
.41723 .3163 Mdot
.67809 .63025 Mdot
.63068 .42792 Mdot
.57596 .44447 Mdot
.53989 .52659 Mdot
.64039 .6207 Mdot
.57764 .44421 Mdot
.57325 .47352 Mdot
.38008 .35665 Mdot
.37003 .52178 Mdot
.39696 .38592 Mdot
.63301 .41759 Mdot
.81531 .50247 Mdot
.40759 .39486 Mdot
.3034 .36204 Mdot
.61181 .63836 Mdot
.33015 .6193 Mdot
.66056 .46265 Mdot
.63231 .4473 Mdot
.29225 .26533 Mdot
.3701 .50855 Mdot
.40121 .82827 Mdot
.47054 .75021 Mdot
.76698 .28532 Mdot
.46914 .67136 Mdot
.35485 .42825 Mdot
.45961 .6334 Mdot
.65782 .44643 Mdot
.51353 .36895 Mdot
.45541 .24636 Mdot
.36881 .60671 Mdot
.39687 .2469 Mdot
.64245 .41461 Mdot
.59876 .40357 Mdot
.50012 .69801 Mdot
.37926 .46166 Mdot
.70409 .43216 Mdot
.50069 .50679 Mdot
.65268 .65448 Mdot
.39885 .37103 Mdot
.60149 .45353 Mdot
.21534 .49896 Mdot
.51388 .73807 Mdot
.72194 .34565 Mdot
.62111 .41709 Mdot
.69998 .44825 Mdot
.38188 .46503 Mdot
.3115 .60583 Mdot
.5088 .75021 Mdot
.51903 .73319 Mdot
.58285 .43806 Mdot
.32416 .62682 Mdot
.56639 .40676 Mdot
.61152 .55447 Mdot
.67711 .44021 Mdot
.66328 .63275 Mdot
.63659 .43739 Mdot
.70844 .34408 Mdot
.40866 .18648 Mdot
.57841 .47748 Mdot
.43627 .34981 Mdot
.50026 .71834 Mdot
.47963 .71091 Mdot
.38257 .3439 Mdot
.47908 .71051 Mdot
.50334 .22521 Mdot
.37789 .27612 Mdot
.66854 .63128 Mdot
.49699 .27645 Mdot
.6507 .64123 Mdot
.37605 .49298 Mdot
.60822 .43442 Mdot
.39958 .69269 Mdot
.45672 .69526 Mdot
.76414 .63985 Mdot
.32846 .59515 Mdot
.36941 .51125 Mdot
.62065 .38884 Mdot
.68758 .59669 Mdot
.47827 .69634 Mdot
.43621 .54419 Mdot
.58539 .42862 Mdot
.43555 .3786 Mdot
.56549 .44026 Mdot
.53987 .43242 Mdot
.36799 .51456 Mdot
.56961 .45482 Mdot
.30804 .60445 Mdot
.40145 .3923 Mdot
.35899 .45063 Mdot
.48206 .73876 Mdot
.63298 .40018 Mdot
.6267 .44099 Mdot
.36797 .3495 Mdot
.64998 .41977 Mdot
.31361 .62359 Mdot
.79683 .74007 Mdot
.68839 .65319 Mdot
.38805 .51711 Mdot
.25412 .38069 Mdot
.57056 .45077 Mdot
.5706 .39235 Mdot
.45297 .52051 Mdot
.6215 .21955 Mdot
.31689 .61694 Mdot
.61063 .35465 Mdot
.51528 .70511 Mdot
.67178 .66163 Mdot
.33013 .57794 Mdot
.614 .38532 Mdot
.59335 .41575 Mdot
.67858 .63229 Mdot
.6626 .58072 Mdot
.64821 .67605 Mdot
.30319 .6189 Mdot
.38249 .28805 Mdot
.54821 .64944 Mdot
.60621 .42625 Mdot
.40182 .50635 Mdot
.40699 .35617 Mdot
.30494 .61376 Mdot
.59133 .22027 Mdot
.64267 .36708 Mdot
.30784 .6327 Mdot
.31174 .60067 Mdot
.6497 .42596 Mdot
.39195 .31357 Mdot
.35768 .36574 Mdot
.40999 .35536 Mdot
.74502 .55398 Mdot
.32286 .77834 Mdot
.49653 .72263 Mdot
.324 .60873 Mdot
.47832 .75058 Mdot
.69497 .64384 Mdot
.61401 .54393 Mdot
.51996 .72535 Mdot
.44008 .37475 Mdot
.48611 .75011 Mdot
.56521 .4075 Mdot
.34714 .59989 Mdot
.49676 .74466 Mdot
.60149 .37148 Mdot
.60984 .46922 Mdot
.51432 .39737 Mdot
.69351 .631 Mdot
.52488 .53589 Mdot
.61772 .40517 Mdot
.3913 .49059 Mdot
.61854 .42683 Mdot
.3155 .62505 Mdot
.49861 .59608 Mdot
.58302 .40369 Mdot
.45594 .69658 Mdot
.35452 .80313 Mdot
.50474 .68617 Mdot
.53678 .44097 Mdot
.62953 .41339 Mdot
.60421 .42918 Mdot
.62021 .3901 Mdot
.41239 .43927 Mdot
.29047 .62837 Mdot
.58466 .34968 Mdot
.45685 .7254 Mdot
.41449 .37215 Mdot
.40806 .39664 Mdot
.45888 .54367 Mdot
.37276 .49264 Mdot
.33365 .62384 Mdot
.60241 .42947 Mdot
.43688 .54745 Mdot
.47552 .50283 Mdot
.28566 .50495 Mdot
.44387 .73639 Mdot
.51418 .72257 Mdot
.43948 .35814 Mdot
.50566 .7322 Mdot
.61813 .38547 Mdot
.66339 .44317 Mdot
.35679 .44685 Mdot
.35335 .62962 Mdot
.66844 .6616 Mdot
.6282 .40594 Mdot
.69828 .53171 Mdot
.5088 .69822 Mdot
.52235 .73094 Mdot
.56854 .40373 Mdot
.37883 .32462 Mdot
.46996 .14536 Mdot
.34274 .61669 Mdot
.40962 .26778 Mdot
.3923 .42003 Mdot
.59201 .51993 Mdot
.33732 .60726 Mdot
.45293 .59329 Mdot
.51861 .6918 Mdot
.82351 .48008 Mdot
.41756 .36805 Mdot
.66893 .66061 Mdot
.62197 .3767 Mdot
.44049 .37419 Mdot
.45747 .73849 Mdot
.39478 .33258 Mdot
.66705 .40084 Mdot
.30707 .57566 Mdot
.48467 .70414 Mdot
.29165 .57656 Mdot
.41354 .33058 Mdot
.65099 .63869 Mdot
.74799 .59555 Mdot
.42914 .27205 Mdot
.62975 .25398 Mdot
.58249 .41106 Mdot
.41459 .65642 Mdot
.58266 .42222 Mdot
.41082 .40392 Mdot
.62025 .41041 Mdot
.62408 .48456 Mdot
.51874 .68932 Mdot
.63824 .38421 Mdot
.63917 .43211 Mdot
.52529 .3353 Mdot
.61326 .43925 Mdot
.6003 .39548 Mdot
.5987 .36128 Mdot
.43215 .32929 Mdot
.63423 .38031 Mdot
.43741 .37418 Mdot
.30603 .50621 Mdot
.47887 .73566 Mdot
.69413 .64322 Mdot
.69309 .65257 Mdot
.7058 .5855 Mdot
.69756 .53722 Mdot
.39651 .45342 Mdot
.40142 .3828 Mdot
.32003 .58631 Mdot
.56843 .40184 Mdot
.70992 .27956 Mdot
.8078 .50811 Mdot
.50732 .68048 Mdot
.49681 .74789 Mdot
.62468 .38135 Mdot
.15818 .55009 Mdot
.63187 .38111 Mdot
.45778 .46704 Mdot
.58738 .43859 Mdot
.56031 .39501 Mdot
.51325 .74789 Mdot
.71556 .57279 Mdot
.58305 .40972 Mdot
.4161 .33612 Mdot
.66263 .6582 Mdot
.68402 .47062 Mdot
.80162 .5357 Mdot
.50858 .36464 Mdot
.70287 .37089 Mdot
.58851 .39578 Mdot
.49871 .69185 Mdot
.4135 .33797 Mdot
.46833 .47764 Mdot
.31828 .62325 Mdot
.50456 .52351 Mdot
.47342 .27963 Mdot
.36935 .56977 Mdot
.66291 .66029 Mdot
.51688 .7555 Mdot
.59207 .45632 Mdot
.49253 .73241 Mdot
.62137 .35534 Mdot
.47383 .50951 Mdot
.66468 .63033 Mdot
.44776 .36073 Mdot
.30641 .61037 Mdot
.42404 .39528 Mdot
.68011 .28027 Mdot
.80992 .50487 Mdot
.77107 .28885 Mdot
.47772 .68125 Mdot
.51454 .18073 Mdot
.39979 .34796 Mdot
.58313 .42925 Mdot
.5787 .89431 Mdot
.40086 .35875 Mdot
.43751 .37602 Mdot
.48232 .55111 Mdot
.72554 .56904 Mdot
.66324 .4198 Mdot
.38188 .33993 Mdot
.50812 .76098 Mdot
.6684 .63975 Mdot
.59814 .37375 Mdot
.66681 .39749 Mdot
.38441 .38512 Mdot
.47435 .70014 Mdot
.68611 .56807 Mdot
.48395 .71738 Mdot
.40788 .33952 Mdot
.46932 .72402 Mdot
.31627 .38603 Mdot
.51772 .7297 Mdot
.63373 .44333 Mdot
.60298 .42848 Mdot
.39353 .61364 Mdot
.42344 .36705 Mdot
.57075 .3917 Mdot
.5983 .40869 Mdot
.40731 .34556 Mdot
.49256 .66206 Mdot
.57278 .19993 Mdot
.56544 .39973 Mdot
.5991 .42723 Mdot
.69024 .64874 Mdot
.57165 .54199 Mdot
.44988 .46494 Mdot
.59528 .37242 Mdot
.64881 .63122 Mdot
.44226 .35976 Mdot
.61877 .42849 Mdot
.71763 .57485 Mdot
.45595 .68822 Mdot
.59281 .3872 Mdot
.37436 .50151 Mdot
.58362 .4481 Mdot
.45292 .15554 Mdot
.62743 .39346 Mdot
.41775 .34953 Mdot
.39167 .34648 Mdot
.45039 .76053 Mdot
.4105 .36909 Mdot
.38011 .51782 Mdot
.32128 .59161 Mdot
.34946 .25554 Mdot
.37653 .51733 Mdot
.56735 .45572 Mdot
.83814 .55414 Mdot
.66861 .40165 Mdot
.67362 .42509 Mdot
.7591 .67423 Mdot
.38812 .51537 Mdot
.39921 .35298 Mdot
.22834 .49416 Mdot
.65887 .41565 Mdot
.33668 .62265 Mdot
.67035 .42574 Mdot
.59274 .38761 Mdot
.59145 .4844 Mdot
.3741 .28353 Mdot
.35228 .6078 Mdot
.5436 .35682 Mdot
.59751 .37398 Mdot
.62227 .22055 Mdot
.61198 .45208 Mdot
.67161 .66894 Mdot
.38901 .37608 Mdot
.50174 .73351 Mdot
.66454 .63546 Mdot
.58249 .45524 Mdot
.67522 .65435 Mdot
.49332 .7294 Mdot
.30053 .5912 Mdot
.62934 .44682 Mdot
.65898 .61299 Mdot
.661 .6613 Mdot
.57077 .417 Mdot
.38552 .35451 Mdot
.5509 .39079 Mdot
.6172 .43143 Mdot
.61186 .38837 Mdot
.38006 .34836 Mdot
.65456 .81321 Mdot
.59625 .403 Mdot
.45036 .59598 Mdot
.43944 .39729 Mdot
.3721 .52039 Mdot
.51157 .71684 Mdot
.57621 .47327 Mdot
.34231 .60399 Mdot
.32308 .59286 Mdot
.46548 .68445 Mdot
.37785 .37487 Mdot
.48097 .70497 Mdot
.58282 .47975 Mdot
.66418 .44049 Mdot
.62104 .37687 Mdot
.52092 .80597 Mdot
.30135 .39696 Mdot
.42855 .36266 Mdot
.51455 .69142 Mdot
.50602 .51895 Mdot
.34672 .60714 Mdot
.51987 .74159 Mdot
.37435 .39818 Mdot
.37287 .3609 Mdot
.38566 .34 Mdot
.64601 .64499 Mdot
.48922 .70663 Mdot
.36502 .39084 Mdot
.35899 .36555 Mdot
.57063 .40541 Mdot
.59506 .37662 Mdot
.43843 .33883 Mdot
.5152 .77626 Mdot
.65483 .63832 Mdot
.49667 .68864 Mdot
.4225 .14678 Mdot
.3419 .61817 Mdot
.52886 .33436 Mdot
.60061 .37055 Mdot
.40726 .88657 Mdot
.62969 .37882 Mdot
.62217 .44592 Mdot
.42757 .33588 Mdot
.63491 .63907 Mdot
.66941 .64289 Mdot
.3987 .34756 Mdot
.36585 .36647 Mdot
.65484 .6627 Mdot
.47531 .55891 Mdot
.49551 .15602 Mdot
.47741 .49296 Mdot
.4267 .3535 Mdot
.43124 .2688 Mdot
.32099 .57925 Mdot
.44301 .38861 Mdot
.28455 .57505 Mdot
.47614 .7359 Mdot
.51183 .73677 Mdot
.30821 .58765 Mdot
.59688 .39996 Mdot
.47109 .68882 Mdot
.56036 .47357 Mdot
.34545 .4259 Mdot
.36082 .64933 Mdot
.7507 .30112 Mdot
.64019 .43879 Mdot
.70903 .43821 Mdot
.25421 .5808 Mdot
.5609 .44802 Mdot
.63757 .32205 Mdot
.67268 .65932 Mdot
.44364 .39195 Mdot
.34924 .58914 Mdot
.3026 .29358 Mdot
.60513 .42741 Mdot
.42299 .34667 Mdot
.34793 .61043 Mdot
.32406 .41153 Mdot
.46583 .5975 Mdot
.56388 .4284 Mdot
.63055 .87281 Mdot
.39582 .33037 Mdot
.50195 .73307 Mdot
.51798 .31988 Mdot
.43333 .3901 Mdot
.51054 .64192 Mdot
.4772 .75989 Mdot
.49204 .48679 Mdot
.37654 .34251 Mdot
.65251 .67977 Mdot
.39408 .37242 Mdot
.63984 .63731 Mdot
.36226 .35074 Mdot
.47101 .71424 Mdot
.62684 .42779 Mdot
.47325 .71953 Mdot
.6731 .67085 Mdot
.4721 .68299 Mdot
.34915 .58914 Mdot
.39566 .50679 Mdot
.32921 .58839 Mdot
.62835 .54243 Mdot
.56866 .22271 Mdot
.29646 .60618 Mdot
.43444 .57295 Mdot
.58923 .45024 Mdot
.40244 .32015 Mdot
.49645 .73626 Mdot
.49095 .66877 Mdot
.52152 .53168 Mdot
.39725 .33846 Mdot
.4698 .7051 Mdot
.4365 .27475 Mdot
.48775 .849 Mdot
.64047 .47273 Mdot
.31342 .75747 Mdot
.41252 .34639 Mdot
.52421 .69828 Mdot
.45784 .46269 Mdot
.39272 .39537 Mdot
.50101 .74356 Mdot
.3028 .60687 Mdot
.34087 .6084 Mdot
.64912 .41972 Mdot
.31949 .56907 Mdot
.52169 .70587 Mdot
.62094 .21734 Mdot
.38197 .36692 Mdot
.28726 .38616 Mdot
.68005 .6617 Mdot
.4858 .73514 Mdot
.65244 .39818 Mdot
.37195 .3184 Mdot
.47693 .74685 Mdot
.18693 .58767 Mdot
.34615 .19583 Mdot
.46978 .70383 Mdot
.38992 .37709 Mdot
.41365 .37754 Mdot
.59494 .47819 Mdot
.50947 .51746 Mdot
.47534 .69652 Mdot
.39875 .69187 Mdot
.70165 .5127 Mdot
.37993 .51334 Mdot
.79265 .38735 Mdot
.58415 .40845 Mdot
.58882 .39469 Mdot
.30689 .62172 Mdot
.61992 .43851 Mdot
.36429 .37068 Mdot
.6274 .37677 Mdot
.29046 .59126 Mdot
.47512 .67823 Mdot
.6083 .43131 Mdot
.67443 .66172 Mdot
.29655 .5858 Mdot
.28997 .6154 Mdot
.4692 .7294 Mdot
.37747 .3589 Mdot
.22411 .52691 Mdot
.48422 .71514 Mdot
.60342 .38826 Mdot
.3936 .49952 Mdot
.6211 .36868 Mdot
.39582 .6048 Mdot
.40533 .40298 Mdot
.50553 .73178 Mdot
.44746 .35018 Mdot
.31975 .60737 Mdot
.51203 .68121 Mdot
.59068 .45781 Mdot
.51374 .7295 Mdot
.44027 .61857 Mdot
.58996 .70847 Mdot
.36087 .36387 Mdot
.48228 .62297 Mdot
.37533 .37314 Mdot
.37804 .51333 Mdot
.75363 .52051 Mdot
.65508 .64736 Mdot
.50785 .69287 Mdot
.30345 .36476 Mdot
.48733 .74085 Mdot
.60841 .44161 Mdot
.59083 .41853 Mdot
.50184 .69965 Mdot
.64874 .63865 Mdot
.73163 .62261 Mdot
.6858 .68835 Mdot
.41011 .38953 Mdot
.48715 .59181 Mdot
.45115 .13963 Mdot
.44411 .7231 Mdot
.31514 .58748 Mdot
.67841 .34549 Mdot
.56884 .44656 Mdot
.35031 .6089 Mdot
.30857 .62922 Mdot
.64869 .66619 Mdot
.4846 .73743 Mdot
.42004 .40527 Mdot
.33428 .58048 Mdot
.36345 .32065 Mdot
.70193 .57195 Mdot
.62534 .35451 Mdot
.55407 .4973 Mdot
.59512 .46558 Mdot
.53085 .54271 Mdot
.2945 .58291 Mdot
.60913 .40922 Mdot
.53959 .36681 Mdot
.31147 .61837 Mdot
.64281 .65946 Mdot
.39898 .3004 Mdot
.46702 .70791 Mdot
.44583 .87177 Mdot
.6316 .4444 Mdot
.62339 .42832 Mdot
.3241 .6225 Mdot
.59984 .30997 Mdot
.43166 .36469 Mdot
.37841 .36315 Mdot
.49493 .71927 Mdot
.47091 .52029 Mdot
.65065 .42011 Mdot
.61149 .45584 Mdot
.46942 .69348 Mdot
.39066 .49115 Mdot
.79179 .35953 Mdot
.60099 .42106 Mdot
.33317 .6063 Mdot
.42719 .62003 Mdot
.2993 .5782 Mdot
.5523 .44655 Mdot
.60214 .44344 Mdot
.59589 .46187 Mdot
.63573 .44736 Mdot
.3242 .58193 Mdot
.58428 .45887 Mdot
.61248 .35203 Mdot
.4031 .35401 Mdot
.58719 .39979 Mdot
.70436 .50826 Mdot
.60448 .42161 Mdot
.6765 .65983 Mdot
.45173 .47426 Mdot
.62917 .3966 Mdot
.58865 .39806 Mdot
.69773 .51815 Mdot
.63206 .4295 Mdot
.34909 .60929 Mdot
.41765 .37276 Mdot
.31923 .60883 Mdot
.31241 .59189 Mdot
.48336 .74832 Mdot
.64096 .62895 Mdot
.62483 .46156 Mdot
.64867 .65819 Mdot
.60742 .48095 Mdot
.67753 .4197 Mdot
.60124 .54653 Mdot
.45915 .46977 Mdot
.69621 .64343 Mdot
.60375 .45682 Mdot
.49168 .72541 Mdot
.50742 .7316 Mdot
.48504 .61283 Mdot
.67298 .44595 Mdot
.33812 .57936 Mdot
.30037 .5981 Mdot
.67422 .69596 Mdot
.59335 .66938 Mdot
.66074 .66243 Mdot
.63282 .56976 Mdot
.56004 .39099 Mdot
.60884 .39596 Mdot
.68084 .44461 Mdot
.4781 .75319 Mdot
.39521 .50848 Mdot
.46117 .69595 Mdot
.37154 .47993 Mdot
.3223 .57732 Mdot
.64058 .4378 Mdot
.15489 .50509 Mdot
.41197 .39184 Mdot
.41826 .37294 Mdot
.29002 .59167 Mdot
.50656 .68775 Mdot
.67629 .43958 Mdot
.35672 .82761 Mdot
.37953 .39089 Mdot
.68739 .63151 Mdot
.63571 .41977 Mdot
.47524 .73329 Mdot
.39458 .38944 Mdot
.66618 .61478 Mdot
.62956 .45075 Mdot
.49066 .76293 Mdot
.61235 .41323 Mdot
.49743 .25437 Mdot
.39293 .35512 Mdot
.57006 .52959 Mdot
.42301 .32793 Mdot
.32811 .58441 Mdot
.3148 .61452 Mdot
.60013 .44123 Mdot
.4033 .85406 Mdot
.34377 .33562 Mdot
.3231 .63276 Mdot
.66305 .61597 Mdot
.39823 .49889 Mdot
.65752 .61671 Mdot
.50394 .70541 Mdot
.66073 .65834 Mdot
.47776 .74642 Mdot
.51819 .77488 Mdot
.40108 .41319 Mdot
.67907 .6337 Mdot
.64199 .30022 Mdot
.66284 .44482 Mdot
.66292 .67109 Mdot
.61808 .37858 Mdot
.60006 .48367 Mdot
.46428 .70342 Mdot
.64824 .65165 Mdot
.57041 .43269 Mdot
.25485 .37508 Mdot
.30928 .60586 Mdot
.34329 .58353 Mdot
.66352 .43991 Mdot
.52694 .70882 Mdot
.36212 .35851 Mdot
.5657 .55376 Mdot
.37302 .52376 Mdot
.61415 .45466 Mdot
.5816 .46681 Mdot
.40189 .32876 Mdot
.43645 .35663 Mdot
.59771 .44274 Mdot
.40863 .27531 Mdot
.5856 .45643 Mdot
.33929 .61182 Mdot
.41136 .38997 Mdot
.41609 .37713 Mdot
.52168 .71251 Mdot
.38111 .37905 Mdot
.56823 .36254 Mdot
.36584 .60728 Mdot
.64435 .37797 Mdot
.32223 .60532 Mdot
.48629 .78312 Mdot
.46102 .7283 Mdot
.30073 .36228 Mdot
.38134 .37819 Mdot
.57035 .38941 Mdot
.41049 .39571 Mdot
.68616 .65031 Mdot
.42319 .37074 Mdot
.39921 .32535 Mdot
.64365 .41128 Mdot
.57715 .44194 Mdot
.38953 .49361 Mdot
.5168 .52425 Mdot
.39112 .36059 Mdot
.55736 .43849 Mdot
.59589 .36862 Mdot
.58797 .42249 Mdot
.59314 .55196 Mdot
.44246 .34859 Mdot
.50523 .36789 Mdot
.38268 .56561 Mdot
.3874 .36069 Mdot
.36395 .20131 Mdot
.38372 .48981 Mdot
.37426 .48971 Mdot
.28031 .60463 Mdot
.59812 .42444 Mdot
.47748 .70883 Mdot
.59072 .39219 Mdot
.66212 .46905 Mdot
.63179 .40073 Mdot
.68047 .63264 Mdot
.65203 .41349 Mdot
.37923 .50678 Mdot
.48123 .72068 Mdot
.55953 .441 Mdot
.60207 .4332 Mdot
.3754 .49019 Mdot
.4384 .33777 Mdot
.37422 .36512 Mdot
.36586 .53517 Mdot
.65301 .66723 Mdot
.29184 .5998 Mdot
.60048 .38847 Mdot
.49323 .72183 Mdot
.47589 .71684 Mdot
.43011 .38882 Mdot
.47683 .68898 Mdot
.29137 .5947 Mdot
.61501 .44941 Mdot
.32726 .58413 Mdot
.68079 .63294 Mdot
.38844 .37542 Mdot
.61976 .38498 Mdot
.56909 .41145 Mdot
.39166 .34666 Mdot
.58084 .44909 Mdot
.68486 .63519 Mdot
.49358 .7554 Mdot
.4266 .37134 Mdot
.3208 .59265 Mdot
.52117 .71925 Mdot
.57108 .39523 Mdot
.27202 .25439 Mdot
.61859 .43997 Mdot
.61301 .45673 Mdot
.34798 .40209 Mdot
.57578 .37754 Mdot
.48381 .7399 Mdot
.40301 .39656 Mdot
.56153 .45986 Mdot
.69845 .52021 Mdot
.62831 .63981 Mdot
.45203 .74319 Mdot
.63703 .42808 Mdot
.32766 .25306 Mdot
.58803 .37364 Mdot
.30461 .35317 Mdot
.60012 .54609 Mdot
.27444 .68213 Mdot
.55371 .4969 Mdot
.31787 .63332 Mdot
.39329 .49343 Mdot
.47117 .7385 Mdot
.58577 .29917 Mdot
.6042 .44673 Mdot
.62966 .24799 Mdot
.61592 .38418 Mdot
.33834 .60684 Mdot
.62425 .32532 Mdot
.49121 .68719 Mdot
.78597 .38418 Mdot
.58972 .4071 Mdot
.39924 .33101 Mdot
.52943 .6996 Mdot
.39177 .4874 Mdot
.57556 .43632 Mdot
.66435 .66673 Mdot
.64278 .68096 Mdot
.56375 .36562 Mdot
.31996 .60436 Mdot
.60271 .40239 Mdot
.55431 .46713 Mdot
.5103 .8333 Mdot
.41126 .35357 Mdot
.30608 .59809 Mdot
.59835 .64261 Mdot
.58904 .42356 Mdot
.37329 .36079 Mdot
.41649 .36925 Mdot
.64402 .65475 Mdot
.26635 .64246 Mdot
.72996 .67276 Mdot
.16873 .42589 Mdot
.67133 .26114 Mdot
.4823 .75512 Mdot
.46879 .36054 Mdot
.58019 .39997 Mdot
.81117 .50455 Mdot
.31563 .59008 Mdot
.62585 .4264 Mdot
.63452 .26352 Mdot
.4174 .35703 Mdot
.60702 .4143 Mdot
.65559 .63918 Mdot
.23476 .56474 Mdot
.46515 .28917 Mdot
.27952 .27375 Mdot
.50565 .76218 Mdot
.66391 .41335 Mdot
.59112 .35559 Mdot
.37414 .52077 Mdot
.5569 .45306 Mdot
.49445 .73601 Mdot
.41647 .63811 Mdot
.65844 .62669 Mdot
.40853 .39287 Mdot
.38737 .48718 Mdot
.61541 .38373 Mdot
.63024 .36133 Mdot
.68135 .62571 Mdot
.57932 .4305 Mdot
.50708 .32523 Mdot
.38813 .47694 Mdot
.51669 .73277 Mdot
.39985 .33201 Mdot
.58932 .46568 Mdot
.39705 .49665 Mdot
.64184 .40461 Mdot
.71467 .35413 Mdot
.62891 .40914 Mdot
.32591 .33059 Mdot
.38569 .3492 Mdot
.31582 .60009 Mdot
.65399 .41878 Mdot
.61308 .41976 Mdot
.57059 .66253 Mdot
.67468 .43999 Mdot
.61846 .39182 Mdot
.42793 .39407 Mdot
.41312 .39237 Mdot
.42717 .34833 Mdot
.52009 .71285 Mdot
.48119 .49404 Mdot
.33344 .59725 Mdot
.67997 .44489 Mdot
.33232 .57876 Mdot
.54165 .48768 Mdot
.66878 .62048 Mdot
.29315 .36143 Mdot
.60434 .45103 Mdot
.39421 .33728 Mdot
.52962 .16416 Mdot
.44305 .36362 Mdot
.35631 .54525 Mdot
.31462 .59334 Mdot
.39828 .36061 Mdot
.63295 .43214 Mdot
.50624 .51029 Mdot
.25775 .28992 Mdot
.34712 .60428 Mdot
.67016 .4156 Mdot
.49111 .76953 Mdot
.46637 .68017 Mdot
.38444 .19688 Mdot
.34341 .59274 Mdot
.2518 .58609 Mdot
.56389 .40246 Mdot
.39658 .39322 Mdot
.29465 .59704 Mdot
.33772 .62585 Mdot
.47529 .68837 Mdot
.56464 .4188 Mdot
.61182 .41814 Mdot
.3754 .49865 Mdot
.31043 .58335 Mdot
.59354 .50411 Mdot
.56431 .4343 Mdot
.3575 .43672 Mdot
.38538 .40499 Mdot
.66669 .80531 Mdot
.52732 .36035 Mdot
.63219 .26063 Mdot
.43525 .75467 Mdot
.42849 .3718 Mdot
.59577 .39952 Mdot
.67845 .43876 Mdot
.49031 .75821 Mdot
.61912 .4451 Mdot
.50622 .68278 Mdot
.33393 .58621 Mdot
.28701 .33964 Mdot
.44183 .55794 Mdot
.33842 .65197 Mdot
.61779 .43804 Mdot
.45937 .28985 Mdot
.67648 .63404 Mdot
.35142 .62964 Mdot
.43559 .36393 Mdot
.5517 .4398 Mdot
.46888 .75087 Mdot
.51883 .7091 Mdot
.41438 .36231 Mdot
.32156 .52006 Mdot
.30102 .35651 Mdot
.62421 .45617 Mdot
.50954 .71234 Mdot
.42796 .49544 Mdot
.39039 .24686 Mdot
.28404 .61237 Mdot
.66089 .62572 Mdot
.47497 .73888 Mdot
.33756 .57347 Mdot
.60933 .484 Mdot
.40467 .36539 Mdot
.38808 .33154 Mdot
.49469 .62941 Mdot
.47186 .70418 Mdot
.6626 .64625 Mdot
.48034 .61462 Mdot
.48799 .59973 Mdot
.66193 .63176 Mdot
.50894 .68152 Mdot
.42574 .38218 Mdot
.41425 .34307 Mdot
.41663 .37297 Mdot
.53827 .33079 Mdot
.39926 .40088 Mdot
.77319 .60435 Mdot
.55536 .44789 Mdot
.40984 .25963 Mdot
.55251 .42544 Mdot
.35102 .59478 Mdot
.39171 .35457 Mdot
.59345 .54234 Mdot
.56838 .37937 Mdot
.26823 .28564 Mdot
.62005 .40505 Mdot
.43652 .60917 Mdot
.59795 .42596 Mdot
.503 .29535 Mdot
.44053 .39472 Mdot
.59301 .45844 Mdot
.36747 .60565 Mdot
.67754 .6549 Mdot
.38837 .41271 Mdot
.6153 .39264 Mdot
.29569 .49153 Mdot
.61691 .37824 Mdot
.30856 .32576 Mdot
.53835 .66615 Mdot
.68385 .67241 Mdot
.61103 .36364 Mdot
.45843 .73569 Mdot
.70539 .38837 Mdot
.42211 .26316 Mdot
.34706 .60265 Mdot
.45032 .28445 Mdot
.48589 .68368 Mdot
.6231 .32382 Mdot
.54893 .40722 Mdot
.65337 .62989 Mdot
.39211 .30048 Mdot
.33673 .61556 Mdot
.60009 .44859 Mdot
.59227 .40603 Mdot
.36382 .65247 Mdot
.43864 .26337 Mdot
.66011 .49734 Mdot
.68945 .6283 Mdot
.46481 .28313 Mdot
.62504 .3963 Mdot
.45439 .74599 Mdot
.39 .39279 Mdot
.63325 .33154 Mdot
.60696 .3148 Mdot
.56303 .44681 Mdot
.40289 .35987 Mdot
.37718 .37322 Mdot
.57238 .16811 Mdot
.6598 .62195 Mdot
.62724 .40766 Mdot
.49761 .63453 Mdot
.60742 .38663 Mdot
.33819 .60084 Mdot
.55599 .39717 Mdot
.46081 .72304 Mdot
.45682 .45333 Mdot
.51997 .71002 Mdot
.58444 .43484 Mdot
.39349 .37448 Mdot
.32888 .62028 Mdot
.28742 .71036 Mdot
.2674 .60533 Mdot
.77199 .60503 Mdot
.63805 .67901 Mdot
.6651 .66478 Mdot
.64924 .62076 Mdot
.286 .62927 Mdot
.63475 .4335 Mdot
.53076 .54663 Mdot
.6393 .47684 Mdot
.59423 .4243 Mdot
.63093 .40771 Mdot
.2742 .57754 Mdot
.3146 .59464 Mdot
.47031 .72147 Mdot
.59738 .4435 Mdot
.55702 .43823 Mdot
.39297 .36768 Mdot
.65985 .66107 Mdot
.50255 .75019 Mdot
.67273 .66964 Mdot
.48497 .72293 Mdot
.44907 .15595 Mdot
.6483 .37173 Mdot
.67837 .65224 Mdot
.30077 .57892 Mdot
.41377 .33939 Mdot
.37211 .4981 Mdot
.50151 .70352 Mdot
.48876 .68745 Mdot
.57736 .4574 Mdot
.38575 .37629 Mdot
.37782 .36914 Mdot
.65577 .66292 Mdot
.29885 .60011 Mdot
.59263 .47067 Mdot
.57232 .44148 Mdot
.30552 .72699 Mdot
.49803 .75579 Mdot
.45082 .27809 Mdot
.33316 .36456 Mdot
.63092 .44079 Mdot
.37399 .35859 Mdot
.61337 .42832 Mdot
.42128 .52388 Mdot
.42929 .34852 Mdot
.5676 .38495 Mdot
.61575 .49191 Mdot
.48056 .75352 Mdot
.65665 .21222 Mdot
.64082 .45213 Mdot
.35881 .5751 Mdot
.57515 .41069 Mdot
.75454 .26365 Mdot
.54857 .16788 Mdot
.63129 .38703 Mdot
.64219 .43868 Mdot
.17676 .39619 Mdot
.60516 .36887 Mdot
.37668 .50256 Mdot
.6642 .46697 Mdot
.3726 .35639 Mdot
.45756 .60805 Mdot
.52663 .53791 Mdot
.65313 .62283 Mdot
.49525 .72016 Mdot
.721 .57099 Mdot
.6392 .64631 Mdot
.41626 .34847 Mdot
.63732 .36466 Mdot
.33383 .36124 Mdot
.48153 .66692 Mdot
.54122 .43915 Mdot
.33876 .60301 Mdot
.5248 .53807 Mdot
.45809 .70609 Mdot
.3205 .59158 Mdot
.58699 .37357 Mdot
.51109 .80141 Mdot
.3709 .60257 Mdot
.58572 .16742 Mdot
.3073 .62118 Mdot
.3122 .60613 Mdot
.49325 .49853 Mdot
.6524 .62324 Mdot
.38799 .65098 Mdot
.61726 .34498 Mdot
.34465 .61338 Mdot
.76427 .44415 Mdot
.50261 .7576 Mdot
.47704 .51597 Mdot
.44051 .39167 Mdot
.66494 .3927 Mdot
.63106 .42015 Mdot
.30202 .61152 Mdot
.466 .36232 Mdot
.5762 .64713 Mdot
.33963 .59172 Mdot
.56953 .36736 Mdot
.46719 .50416 Mdot
.39528 .50327 Mdot
.38115 .49036 Mdot
.67008 .61657 Mdot
.60637 .754 Mdot
.38389 .34768 Mdot
.68892 .63552 Mdot
.58429 .52787 Mdot
.61512 .40204 Mdot
.31789 .58074 Mdot
.38071 .48689 Mdot
.32324 .5943 Mdot
.67364 .64061 Mdot
.67648 .62231 Mdot
.40462 .35374 Mdot
.43242 .36766 Mdot
.34366 .29266 Mdot
.7312 .45455 Mdot
.58892 .3883 Mdot
.58289 .21741 Mdot
.43584 .35714 Mdot
.58959 .30601 Mdot
.64379 .64227 Mdot
.65122 .65093 Mdot
.46406 .2279 Mdot
.57328 .39518 Mdot
.42904 .61824 Mdot
.62691 .39501 Mdot
.77546 .49076 Mdot
.61645 .38303 Mdot
.47295 .69103 Mdot
.58587 .40992 Mdot
.2195 .50475 Mdot
.55823 .43561 Mdot
.63292 .40744 Mdot
.49339 .70345 Mdot
.6054 .46816 Mdot
.46085 .7127 Mdot
.59993 .39838 Mdot
.65021 .60491 Mdot
.49325 .72127 Mdot
.66719 .60202 Mdot
.46119 .58059 Mdot
.38388 .49702 Mdot
.64976 .62244 Mdot
.67053 .66666 Mdot
.68134 .56892 Mdot
.4334 .37716 Mdot
.596 .32757 Mdot
.63516 .42185 Mdot
.52279 .73169 Mdot
.30144 .58287 Mdot
.56395 .44807 Mdot
.63049 .37767 Mdot
.60543 .46987 Mdot
.40237 .35631 Mdot
.51871 .6902 Mdot
.67523 .64818 Mdot
.50895 .73153 Mdot
.65739 .60288 Mdot
.46319 .7364 Mdot
.64153 .45888 Mdot
.60972 .48207 Mdot
.59934 .35512 Mdot
.60776 .25297 Mdot
.83539 .53352 Mdot
.40959 .36446 Mdot
.39135 .50313 Mdot
.66944 .62019 Mdot
.49319 .58866 Mdot
.38315 .34457 Mdot
.48662 .68848 Mdot
.61261 .4131 Mdot
.61571 .34886 Mdot
.66845 .38932 Mdot
.35139 .3373 Mdot
.69723 .62264 Mdot
.50073 .71088 Mdot
.38442 .51459 Mdot
.47747 .49582 Mdot
.43479 .42006 Mdot
.6202 .543 Mdot
.61315 .42405 Mdot
.65595 .66404 Mdot
.39479 .38959 Mdot
.40013 .64 Mdot
.303 .60976 Mdot
.51278 .52074 Mdot
.62022 .43691 Mdot
.32052 .53723 Mdot
.39476 .37512 Mdot
.65167 .63872 Mdot
.30292 .61281 Mdot
.65214 .62611 Mdot
.39632 .48697 Mdot
.37197 .5317 Mdot
.57501 .43315 Mdot
.62615 .39287 Mdot
.31752 .57825 Mdot
.38217 .35119 Mdot
.6409 .61067 Mdot
.35231 .65943 Mdot
.50411 .70371 Mdot
.46924 .53497 Mdot
.40384 .39244 Mdot
.2619 .58718 Mdot
.51482 .72043 Mdot
.33136 .57311 Mdot
.53553 .54411 Mdot
.28959 .60542 Mdot
.62754 .40023 Mdot
.40493 .38435 Mdot
.34723 .59776 Mdot
.31863 .72284 Mdot
.33088 .27503 Mdot
.35604 .31265 Mdot
.58681 .44622 Mdot
.29001 .35498 Mdot
.28031 .5264 Mdot
.47237 .35877 Mdot
.33422 .58129 Mdot
.6082 .4381 Mdot
.62119 .45784 Mdot
.58893 .40795 Mdot
.30745 .6074 Mdot
.25297 .64676 Mdot
.50713 .69526 Mdot
.60666 .40932 Mdot
.68171 .65997 Mdot
.46255 .72318 Mdot
.45666 .69291 Mdot
.47724 .74064 Mdot
.43762 .36004 Mdot
.63418 .36098 Mdot
.68993 .43458 Mdot
.62781 .19735 Mdot
.31356 .6034 Mdot
.38367 .4975 Mdot
.61419 .45745 Mdot
.7617 .60868 Mdot
.41589 .34207 Mdot
.49564 .69883 Mdot
.62441 .42672 Mdot
.52265 .64931 Mdot
.39605 .47661 Mdot
.48816 .70945 Mdot
.43375 .35963 Mdot
.47716 .36848 Mdot
.61678 .44699 Mdot
.57543 .40609 Mdot
.40186 .3423 Mdot
.25621 .55637 Mdot
.47376 .49407 Mdot
.61047 .42931 Mdot
.31638 .5962 Mdot
.44888 .86088 Mdot
.56907 .38725 Mdot
.40741 .3108 Mdot
.39301 .51212 Mdot
.38543 .44594 Mdot
.42784 .27869 Mdot
.656 .4675 Mdot
.26368 .34215 Mdot
.75729 .63865 Mdot
.29435 .30323 Mdot
.77901 .5089 Mdot
.32915 .66528 Mdot
.50787 .14355 Mdot
.36311 .59072 Mdot
.4995 .27966 Mdot
.17688 .57734 Mdot
.26548 .56193 Mdot
.56304 .69082 Mdot
.32869 .69794 Mdot
.50642 .79731 Mdot
.79172 .37631 Mdot
.45519 .72384 Mdot
.79296 .49126 Mdot
.62749 .39037 Mdot
.26011 .54286 Mdot
.49202 .29562 Mdot
.81716 .59489 Mdot
.29961 .37235 Mdot
.50392 .6372 Mdot
.25094 .28097 Mdot
.3157 .3966 Mdot
.39846 .21703 Mdot
.67664 .31539 Mdot
.63781 .76423 Mdot
.49291 .59581 Mdot
.73418 .58294 Mdot
.45992 .29799 Mdot
.21599 .47333 Mdot
.36915 .61996 Mdot
.53027 .19203 Mdot
.53387 .83088 Mdot
.5026 .72697 Mdot
.38707 .39094 Mdot
.38022 .66091 Mdot
.3773 .23388 Mdot
.35645 .55582 Mdot
.2636 .34159 Mdot
.34956 .41509 Mdot
.50113 .29176 Mdot
.5731 .52923 Mdot
.49967 .24799 Mdot
.73807 .6626 Mdot
.7855 .39919 Mdot
.3613 .33433 Mdot
.34469 .71238 Mdot
.49843 .59141 Mdot
.68272 .58594 Mdot
.51879 .30978 Mdot
.67612 .61591 Mdot
.66135 .60965 Mdot
.43144 .35415 Mdot
.39072 .24185 Mdot
.3867 .47533 Mdot
.5861 .52687 Mdot
.46316 .74712 Mdot
.42418 .52871 Mdot
.23701 .55232 Mdot
.29652 .51919 Mdot
.70551 .25515 Mdot
.29263 .24179 Mdot
.73526 .49547 Mdot
.4112 .62904 Mdot
.33422 .55321 Mdot
.74457 .60302 Mdot
.69039 .46787 Mdot
.74588 .45759 Mdot
.7105 .34755 Mdot
.20703 .33248 Mdot
.31776 .48134 Mdot
.24567 .2771 Mdot
.36792 .33409 Mdot
.54978 .36146 Mdot
.41064 .59184 Mdot
.67716 .27313 Mdot
.68397 .54433 Mdot
.28863 .25379 Mdot
.67206 .67926 Mdot
.43273 .40293 Mdot
.26655 .562 Mdot
.50205 .32581 Mdot
.71822 .62716 Mdot
.63336 .68332 Mdot
.62739 .33167 Mdot
.20258 .32067 Mdot
.25897 .34921 Mdot
.49311 .16601 Mdot
.36106 .44494 Mdot
.47556 .65972 Mdot
.45307 .70032 Mdot
.33848 .62654 Mdot
.36848 .2234 Mdot
.4046 .37974 Mdot
.64188 .19794 Mdot
.32752 .29263 Mdot
.70897 .38978 Mdot
.18768 .33738 Mdot
.77473 .34988 Mdot
.40736 .26355 Mdot
.80889 .55992 Mdot
.38663 .82045 Mdot
.67706 .49542 Mdot
.26382 .61962 Mdot
.46963 .7637 Mdot
.32517 .32219 Mdot
.35869 .22665 Mdot
.76406 .42761 Mdot
.16249 .47922 Mdot
.58703 .52584 Mdot
.44972 .76521 Mdot
.34579 .35331 Mdot
.56741 .71367 Mdot
.64043 .57617 Mdot
.25115 .27249 Mdot
.47466 .28785 Mdot
.43478 .84891 Mdot
.76425 .52038 Mdot
.59579 .3121 Mdot
.26746 .37482 Mdot
.53414 .75506 Mdot
.72575 .42182 Mdot
.30691 .49581 Mdot
.66184 .40138 Mdot
.64904 .5493 Mdot
.6572 .32181 Mdot
.71602 .67324 Mdot
.47707 .48716 Mdot
.3138 .45672 Mdot
.73652 .52966 Mdot
.24605 .65171 Mdot
.58842 .32515 Mdot
.43027 .34032 Mdot
.73844 .47021 Mdot
.75738 .50046 Mdot
.35261 .45792 Mdot
.59962 .6397 Mdot
.48155 .1651 Mdot
.58793 .64749 Mdot
.65407 .47183 Mdot
.49849 .27362 Mdot
.46373 .30232 Mdot
.76265 .46453 Mdot
.65396 .44757 Mdot
.67908 .23791 Mdot
.36709 .43972 Mdot
.58245 .24704 Mdot
.71151 .53886 Mdot
.59992 .25063 Mdot
.34844 .25693 Mdot
.40696 .58258 Mdot
.26002 .6235 Mdot
.45203 .33369 Mdot
.20543 .31904 Mdot
.46627 .72249 Mdot
.75674 .43862 Mdot
.36426 .58942 Mdot
.30775 .7212 Mdot
.33599 .67033 Mdot
.57902 .64563 Mdot
.38622 .20885 Mdot
.30161 .52865 Mdot
.53595 .72849 Mdot
.20602 .4574 Mdot
.42658 .48153 Mdot
.57608 .21886 Mdot
.52211 .38953 Mdot
.7137 .36326 Mdot
.6846 .63434 Mdot
.61565 .28619 Mdot
.38996 .57141 Mdot
.69239 .7049 Mdot
.65571 .46332 Mdot
.49955 .61706 Mdot
.37633 .51438 Mdot
.50903 .53503 Mdot
.44644 .1553 Mdot
.51786 .39522 Mdot
.77292 .35406 Mdot
.28658 .53347 Mdot
.52251 .54506 Mdot
.66411 .58132 Mdot
.44618 .42369 Mdot
.23575 .28436 Mdot
.41113 .18495 Mdot
.26685 .51262 Mdot
.28605 .35147 Mdot
.84271 .40211 Mdot
.27228 .67662 Mdot
.71479 .2854 Mdot
.36532 .5921 Mdot
.78824 .74748 Mdot
.51236 .72778 Mdot
.81735 .50012 Mdot
.67127 .27348 Mdot
.55044 .65511 Mdot
.37487 .23624 Mdot
.47767 .31831 Mdot
.62842 .60397 Mdot
.41592 .32704 Mdot
.65235 .45639 Mdot
.30511 .24937 Mdot
.2139 .31384 Mdot
.29947 .25311 Mdot
.34463 .52852 Mdot
.30557 .26957 Mdot
.17648 .38085 Mdot
.77508 .60387 Mdot
.3787 .63878 Mdot
.54702 .41967 Mdot
.74795 .41353 Mdot
.76167 .3346 Mdot
.68892 .67804 Mdot
.6663 .50206 Mdot
.35885 .33646 Mdot
.17377 .37387 Mdot
.44896 .15299 Mdot
.4979 .22597 Mdot
.41052 .21515 Mdot
.43029 .64576 Mdot
.74361 .43985 Mdot
.40459 .20468 Mdot
.22171 .44337 Mdot
.34456 .41919 Mdot
.16483 .40653 Mdot
.75444 .51104 Mdot
.32783 .70103 Mdot
.26012 .49875 Mdot
.74424 .31288 Mdot
.2659 .36941 Mdot
.37151 .66592 Mdot
.71942 .41982 Mdot
.35809 .39221 Mdot
.57915 .64962 Mdot
.21251 .46629 Mdot
.4223 .62088 Mdot
.70993 .52437 Mdot
.47578 .68005 Mdot
.75877 .42485 Mdot
.58806 .57374 Mdot
.37856 .64043 Mdot
.70292 .56657 Mdot
.76944 .42491 Mdot
.28239 .47544 Mdot
.30193 .26259 Mdot
.28843 .53351 Mdot
.38006 .82258 Mdot
.28768 .40245 Mdot
.66509 .32591 Mdot
.60688 .46809 Mdot
.3656 .23336 Mdot
.38286 .17436 Mdot
.39021 .20435 Mdot
.3449 .51134 Mdot
.48418 .64344 Mdot
.31951 .56868 Mdot
.73387 .59467 Mdot
.55777 .64857 Mdot
.3221 .3696 Mdot
.53955 .57625 Mdot
.36128 .59955 Mdot
.23489 .56963 Mdot
.34144 .29586 Mdot
.75819 .61009 Mdot
.51428 .19561 Mdot
.62299 .50831 Mdot
.39622 .24797 Mdot
.39907 .32828 Mdot
.33144 .52755 Mdot
.74881 .45239 Mdot
.46794 .72845 Mdot
.31456 .73131 Mdot
.45876 .35069 Mdot
.54359 .36356 Mdot
.41751 .65097 Mdot
.34724 .3217 Mdot
.62812 .25589 Mdot
.53511 .71394 Mdot
.47777 .14766 Mdot
.69942 .2561 Mdot
.40589 .20318 Mdot
.73872 .48124 Mdot
.33033 .72911 Mdot
.49541 .52356 Mdot
.32083 .55896 Mdot
.30527 .38275 Mdot
.48858 .56377 Mdot
.74492 .47256 Mdot
.39206 .25804 Mdot
.38258 .60932 Mdot
.66856 .45703 Mdot
.51975 .16229 Mdot
.7627 .59106 Mdot
.49469 .53612 Mdot
.39304 .43246 Mdot
.38221 .39413 Mdot
.84445 .52007 Mdot
.22299 .48737 Mdot
.70177 .40937 Mdot
.27915 .36126 Mdot
.28587 .62098 Mdot
.42571 .34184 Mdot
.77213 .41591 Mdot
.59396 .70755 Mdot
.35956 .28533 Mdot
.42394 .58612 Mdot
.38496 .2286 Mdot
.45572 .56824 Mdot
.28149 .34909 Mdot
.24752 .33165 Mdot
.46093 .8535 Mdot
.37017 .33316 Mdot
.40347 .62982 Mdot
.40447 .64694 Mdot
.35532 .35251 Mdot
.36107 .32719 Mdot
.46912 .29109 Mdot
.33671 .22456 Mdot
.47394 .60444 Mdot
.21607 .43643 Mdot
.52828 .54599 Mdot
.56955 .69394 Mdot
.39001 .62147 Mdot
.7129 .56836 Mdot
.23101 .37906 Mdot
.45956 .20162 Mdot
.2587 .72935 Mdot
.62031 .51315 Mdot
.81578 .49105 Mdot
.7346 .59583 Mdot
.6787 .3189 Mdot
.51843 .30674 Mdot
.33542 .41759 Mdot
.59506 .3926 Mdot
.30482 .23037 Mdot
.32064 .47265 Mdot
.63914 .5645 Mdot
.52363 .77495 Mdot
.57948 .38217 Mdot
.60714 .35703 Mdot
.39933 .20672 Mdot
.37585 .43377 Mdot
.21031 .66011 Mdot
.7715 .50853 Mdot
.69358 .34925 Mdot
.39927 .26394 Mdot
.77112 .35289 Mdot
.41376 .56941 Mdot
.30628 .30366 Mdot
.58771 .57864 Mdot
.76007 .32601 Mdot
.21112 .41144 Mdot
.20894 .48972 Mdot
.28328 .39214 Mdot
.18374 .36902 Mdot
.67672 .34752 Mdot
.37481 .46837 Mdot
.38755 .66241 Mdot
.62347 .4519 Mdot
.32225 .51904 Mdot
.28528 .37407 Mdot
.56058 .77599 Mdot
.69741 .4598 Mdot
.37659 .17584 Mdot
.62802 .49809 Mdot
.34216 .49345 Mdot
.20471 .62303 Mdot
.25351 .74961 Mdot
.2147 .50205 Mdot
.25527 .26883 Mdot
.20359 .4781 Mdot
.27173 .35647 Mdot
.28292 .62037 Mdot
.48029 .57831 Mdot
.61282 .23209 Mdot
.34393 .21688 Mdot
.61784 .73682 Mdot
.27683 .66315 Mdot
.57974 .19881 Mdot
.33892 .2171 Mdot
.63283 .49214 Mdot
.83832 .50034 Mdot
.48944 .65951 Mdot
.78834 .34302 Mdot
.71758 .27373 Mdot
.39154 .42585 Mdot
.76834 .4465 Mdot
.82856 .47727 Mdot
.80342 .60317 Mdot
.70906 .27299 Mdot
.7333 .36302 Mdot
.39093 .44175 Mdot
.73179 .48678 Mdot
.31504 .33456 Mdot
.80874 .39443 Mdot
.39542 .61761 Mdot
.39235 .46747 Mdot
.37497 .52968 Mdot
.32702 .32016 Mdot
.28049 .45902 Mdot
.41619 .60882 Mdot
.44869 .46087 Mdot
.36575 .25161 Mdot
.48456 .88146 Mdot
.18974 .48149 Mdot
.39414 .29564 Mdot
.22586 .30556 Mdot
.34886 .43256 Mdot
.50041 .58198 Mdot
.52582 .31486 Mdot
.74947 .59371 Mdot
.53771 .70224 Mdot
.63147 .39974 Mdot
.33094 .22626 Mdot
.5374 .7116 Mdot
.26132 .27769 Mdot
.59502 .16984 Mdot
.42611 .21843 Mdot
.52151 .40998 Mdot
.46947 .76581 Mdot
.76323 .37865 Mdot
.76093 .38744 Mdot
.22396 .32254 Mdot
.81195 .47687 Mdot
.4782 .54623 Mdot
.44339 .58603 Mdot
.43794 .56383 Mdot
.69337 .3791 Mdot
.76902 .33865 Mdot
.41843 .43861 Mdot
.7162 .54697 Mdot
.25638 .50944 Mdot
.75859 .44898 Mdot
.43212 .27816 Mdot
.72414 .58562 Mdot
.59626 .61965 Mdot
.63167 .60389 Mdot
.50489 .75402 Mdot
.15819 .45106 Mdot
.31708 .41708 Mdot
.66721 .22847 Mdot
.38395 .82264 Mdot
.31001 .49689 Mdot
.79618 .48273 Mdot
.37682 .56896 Mdot
.688 .48932 Mdot
.63039 .75669 Mdot
.73902 .54351 Mdot
.45578 .28393 Mdot
.30571 .34817 Mdot
.51028 .36658 Mdot
.37117 .21255 Mdot
.70807 .53017 Mdot
.16102 .54335 Mdot
.42671 .66288 Mdot
.61307 .28048 Mdot
.43069 .25242 Mdot
.34317 .80158 Mdot
.49801 .53805 Mdot
.20268 .32209 Mdot
.44436 .3632 Mdot
.2898 .24456 Mdot
.30144 .61822 Mdot
.54609 .80935 Mdot
.3326 .40007 Mdot
.62926 .56475 Mdot
.59772 .5581 Mdot
.55164 .163 Mdot
.2775 .54519 Mdot
.29016 .52115 Mdot
.58596 .65489 Mdot
.45822 .69898 Mdot
.45712 .52333 Mdot
.22087 .43005 Mdot
.16037 .45597 Mdot
.58587 .47105 Mdot
.43378 .68959 Mdot
.77074 .38996 Mdot
.31603 .55893 Mdot
.36453 .43142 Mdot
.31343 .3751 Mdot
.43248 .29869 Mdot
.74149 .4411 Mdot
.1833 .36439 Mdot
.3278 .37497 Mdot
.56106 .62736 Mdot
.62594 .32016 Mdot
.37249 .6237 Mdot
.25531 .68642 Mdot
.2453 .36189 Mdot
.44145 .57317 Mdot
.47524 .49936 Mdot
.7375 .49619 Mdot
.41674 .14243 Mdot
.21058 .32355 Mdot
.30445 .7619 Mdot
.5219 .54787 Mdot
.44119 .33719 Mdot
.73691 .56907 Mdot
.15876 .53826 Mdot
.79021 .33972 Mdot
.27441 .49495 Mdot
.75981 .44351 Mdot
.55388 .76819 Mdot
.82659 .49662 Mdot
.4912 .55407 Mdot
.4325 .25205 Mdot
.65131 .25128 Mdot
.37301 .53988 Mdot
.53743 .73798 Mdot
.55288 .55452 Mdot
.34729 .65763 Mdot
.39308 .44252 Mdot
.27839 .54567 Mdot
.16133 .54449 Mdot
.81161 .46361 Mdot
.61646 .322 Mdot
.17002 .55108 Mdot
.3914 .41047 Mdot
.40203 .64875 Mdot
.27929 .71903 Mdot
.53153 .55346 Mdot
.49949 .74145 Mdot
.68157 .47412 Mdot
.46419 .50677 Mdot
.20126 .45699 Mdot
.52436 .79495 Mdot
.64306 .66427 Mdot
.38564 .31621 Mdot
.82244 .47385 Mdot
.3651 .35059 Mdot
.44836 .13981 Mdot
.22397 .44021 Mdot
.39717 .2549 Mdot
.19958 .42128 Mdot
.35881 .70018 Mdot
.39033 .8296 Mdot
.40089 .21662 Mdot
.69743 .52046 Mdot
.3851 .31848 Mdot
.37821 .33339 Mdot
.21695 .39612 Mdot
.33079 .54243 Mdot
.39522 .23149 Mdot
.77525 .36101 Mdot
.33396 .73215 Mdot
.36755 .37324 Mdot
.44425 .59207 Mdot
.41375 .30187 Mdot
.45949 .1482 Mdot
.50348 .73631 Mdot
.20996 .31028 Mdot
.52638 .35997 Mdot
.246 .68596 Mdot
.32453 .33919 Mdot
.46119 .45299 Mdot
.4997 .54814 Mdot
.32714 .71955 Mdot
.66228 .46501 Mdot
.69391 .35113 Mdot
.43451 .36854 Mdot
.32965 .67003 Mdot
.65862 .65866 Mdot
.6104 .66725 Mdot
.34897 .56774 Mdot
.65875 .29681 Mdot
.75736 .31352 Mdot
.38979 .32915 Mdot
.4247 .65851 Mdot
.40292 .67619 Mdot
.61225 .49115 Mdot
.74889 .37286 Mdot
.16836 .41825 Mdot
.40132 .22054 Mdot
.44348 .35724 Mdot
.31564 .77602 Mdot
.68559 .69362 Mdot
.49168 .14922 Mdot
.47238 .34788 Mdot
.76827 .38364 Mdot
.6514 .31153 Mdot
.41801 .19056 Mdot
.42866 .27914 Mdot
.30997 .31502 Mdot
.7417 .46702 Mdot
.57452 .65303 Mdot
.76847 .42186 Mdot
.43047 .29696 Mdot
.44976 .55313 Mdot
.78832 .35164 Mdot
.54725 .77376 Mdot
.49954 .25313 Mdot
.69257 .44896 Mdot
.32958 .33269 Mdot
.76739 .34914 Mdot
.38959 .31387 Mdot
.63731 .62002 Mdot
.54313 .19849 Mdot
.33644 .40848 Mdot
.36521 .22602 Mdot
.35168 .45931 Mdot
.77375 .38601 Mdot
.43893 .55753 Mdot
.77605 .56245 Mdot
.51616 .36702 Mdot
.64403 .53912 Mdot
.64128 .38292 Mdot
.65268 .3249 Mdot
.55626 .58299 Mdot
.56865 .17293 Mdot
.69472 .36501 Mdot
.32965 .23769 Mdot
.47207 .15455 Mdot
.28855 .30233 Mdot
.42115 .63366 Mdot
.373 .37312 Mdot
.22686 .29652 Mdot
.7541 .36578 Mdot
.31629 .34054 Mdot
.72253 .28058 Mdot
.84629 .51353 Mdot
.17152 .56963 Mdot
.3286 .44902 Mdot
.34177 .32755 Mdot
.65451 .21067 Mdot
.32164 .48027 Mdot
.83421 .48612 Mdot
.46046 .28567 Mdot
.34372 .39364 Mdot
.18206 .34614 Mdot
.69438 .29239 Mdot
.29369 .51613 Mdot
.42884 .25753 Mdot
.39887 .28641 Mdot
.7515 .35165 Mdot
.68248 .44455 Mdot
.45958 .73516 Mdot
.54295 .65993 Mdot
.76692 .45489 Mdot
.44717 .31526 Mdot
.77151 .36624 Mdot
.76591 .39125 Mdot
.79599 .49671 Mdot
.33171 .72327 Mdot
.17217 .56979 Mdot
.38792 .26798 Mdot
.60566 .35073 Mdot
.38931 .31233 Mdot
.64047 .63135 Mdot
.76363 .52839 Mdot
.55971 .4332 Mdot
.5469 .53459 Mdot
.64844 .33819 Mdot
.32195 .22344 Mdot
.57656 .68718 Mdot
.35547 .63536 Mdot
.37384 .37802 Mdot
.32695 .3239 Mdot
.40883 .55167 Mdot
.26355 .5641 Mdot
.76709 .36595 Mdot
.3506 .28587 Mdot
.27374 .33607 Mdot
.30012 .51078 Mdot
.73008 .51573 Mdot
.73513 .67188 Mdot
.34745 .59231 Mdot
.62699 .25031 Mdot
.21822 .33741 Mdot
.322 .5061 Mdot
.42418 .40558 Mdot
.25819 .4849 Mdot
.45225 .55584 Mdot
.36389 .48288 Mdot
.27978 .54088 Mdot
.39044 .58968 Mdot
.44964 .22053 Mdot
.24521 .34251 Mdot
.49419 .76873 Mdot
.76474 .50187 Mdot
.23101 .48052 Mdot
.76985 .36309 Mdot
.60963 .49263 Mdot
.34347 .23831 Mdot
.62745 .56271 Mdot
.70082 .68869 Mdot
.57046 .42171 Mdot
.70624 .32632 Mdot
.39846 .20619 Mdot
.24933 .50045 Mdot
.71921 .42819 Mdot
.45233 .38682 Mdot
.69878 .25299 Mdot
.53189 .67908 Mdot
.53405 .68888 Mdot
.81739 .53527 Mdot
.46055 .4302 Mdot
.55547 .64524 Mdot
.25542 .6346 Mdot
.64576 .48144 Mdot
.73214 .67891 Mdot
.43048 .58303 Mdot
.61932 .24468 Mdot
.7152 .28927 Mdot
.1636 .43519 Mdot
.42137 .57953 Mdot
.70569 .25356 Mdot
.63949 .24322 Mdot
.34403 .3907 Mdot
.81706 .46496 Mdot
.6641 .50206 Mdot
.65234 .45022 Mdot
.6372 .62038 Mdot
.39583 .40638 Mdot
.17514 .41145 Mdot
.72032 .39528 Mdot
.71498 .64692 Mdot
.61846 .58495 Mdot
.4119 .59836 Mdot
.45782 .78803 Mdot
.37066 .44373 Mdot
.6563 .21125 Mdot
.74838 .4535 Mdot
.28019 .58342 Mdot
.2044 .45659 Mdot
.69914 .46654 Mdot
.33552 .23906 Mdot
.5668 .59597 Mdot
.38808 .21934 Mdot
.35366 .51909 Mdot
.62658 .26229 Mdot
.49808 .15781 Mdot
.66701 .54793 Mdot
.63217 .539 Mdot
.42454 .43063 Mdot
.64075 .52147 Mdot
.37214 .49704 Mdot
.5889 .6811 Mdot
.79989 .40197 Mdot
.15915 .49926 Mdot
.24025 .63913 Mdot
.6586 .48431 Mdot
.73691 .56379 Mdot
.23366 .3591 Mdot
.49917 .58528 Mdot
.61472 .57663 Mdot
.38592 .66681 Mdot
.53788 .72714 Mdot
.45545 .86379 Mdot
.31175 .22794 Mdot
.57043 .4189 Mdot
.58302 .56368 Mdot
.64692 .69367 Mdot
.51007 .68514 Mdot
.50148 .19452 Mdot
.17456 .40631 Mdot
.34887 .60443 Mdot
.35318 .78696 Mdot
.25754 .63611 Mdot
.55977 .16641 Mdot
.3014 .74529 Mdot
.35799 .62629 Mdot
.44662 .13942 Mdot
.27267 .50829 Mdot
.4747 .3949 Mdot
.46462 .86781 Mdot
.5365 .1649 Mdot
.65733 .31776 Mdot
.5042 .65115 Mdot
.31734 .23458 Mdot
.49792 .54674 Mdot
.48275 .63962 Mdot
.6984 .28966 Mdot
.74736 .4591 Mdot
.76892 .50681 Mdot
.28054 .63999 Mdot
.61745 .21884 Mdot
.84296 .57641 Mdot
.36189 .69978 Mdot
.33932 .81266 Mdot
.41043 .22191 Mdot
.25606 .31059 Mdot
.21447 .49727 Mdot
.56761 .7679 Mdot
.35783 .23632 Mdot
.76088 .40594 Mdot
.70153 .31302 Mdot
.60164 .73363 Mdot
.66513 .55288 Mdot
.74661 .58411 Mdot
.36216 .49286 Mdot
.41814 .20639 Mdot
.33866 .71919 Mdot
.71703 .45031 Mdot
.76343 .42315 Mdot
.65482 .26049 Mdot
.63663 .53787 Mdot
.23451 .3213 Mdot
.74934 .35715 Mdot
.74478 .48331 Mdot
.33671 .6866 Mdot
.66222 .60883 Mdot
.1869 .39038 Mdot
.41869 .50799 Mdot
.64829 .31585 Mdot
.20573 .63019 Mdot
.25072 .27383 Mdot
.66374 .50259 Mdot
.55867 .39323 Mdot
.51243 .14314 Mdot
.44288 .65718 Mdot
.7109 .28384 Mdot
.23776 .53895 Mdot
.77696 .5025 Mdot
.67561 .3538 Mdot
.61457 .3804 Mdot
.79187 .57128 Mdot
.34643 .37551 Mdot
.65583 .25748 Mdot
.30331 .73679 Mdot
.74259 .47926 Mdot
.6646 .30477 Mdot
.25733 .72677 Mdot
.46471 .33339 Mdot
.37225 .34962 Mdot
.31859 .23075 Mdot
.51713 .18031 Mdot
.67796 .32978 Mdot
.41205 .24663 Mdot
.56349 .60677 Mdot
.72759 .68244 Mdot
.5972 .32838 Mdot
.49693 .52573 Mdot
.76942 .45148 Mdot
.16835 .55352 Mdot
.6023 .22786 Mdot
.19971 .32091 Mdot
.40714 .18948 Mdot
.36596 .36203 Mdot
.68462 .28477 Mdot
.52798 .55613 Mdot
.28296 .31079 Mdot
.31612 .71192 Mdot
.31462 .72643 Mdot
.83086 .58397 Mdot
.61971 .67656 Mdot
.63245 .3897 Mdot
.34444 .52721 Mdot
.37394 .21344 Mdot
.83908 .56231 Mdot
.36595 .218 Mdot
.65632 .32958 Mdot
.61143 .46668 Mdot
.26181 .76321 Mdot
.27595 .35214 Mdot
.61511 .47341 Mdot
.68946 .39408 Mdot
.69571 .39075 Mdot
.61479 .3898 Mdot
.32116 .54437 Mdot
.74733 .59828 Mdot
.77892 .48815 Mdot
.33189 .23175 Mdot
.37453 .38959 Mdot
.50226 .54561 Mdot
.35883 .61326 Mdot
.56731 .54345 Mdot
.53228 .48106 Mdot
.29399 .62726 Mdot
.78445 .47659 Mdot
.4292 .73462 Mdot
.70898 .60991 Mdot
.33511 .33061 Mdot
.45021 .4418 Mdot
.34111 .29143 Mdot
.80077 .46758 Mdot
.26262 .5951 Mdot
.8011 .60763 Mdot
.77157 .39665 Mdot
.5429 .34639 Mdot
.36977 .45777 Mdot
.84422 .41463 Mdot
.49355 .54083 Mdot
.33231 .53657 Mdot
.56456 .49326 Mdot
.50043 .36739 Mdot
.42701 .23031 Mdot
.647 .68484 Mdot
.37396 .51709 Mdot
.63266 .3251 Mdot
.37383 .23572 Mdot
.28833 .59506 Mdot
.40148 .15491 Mdot
.53559 .44888 Mdot
.5012 .20249 Mdot
.32331 .27286 Mdot
.3989 .63536 Mdot
.45568 .28662 Mdot
.63935 .37945 Mdot
.54896 .62018 Mdot
.42796 .72509 Mdot
.40724 .30512 Mdot
.38712 .62368 Mdot
.26098 .33167 Mdot
.81143 .49017 Mdot
.46635 .20651 Mdot
.62615 .40887 Mdot
.66018 .67602 Mdot
.50743 .52678 Mdot
.57396 .75214 Mdot
.44682 .75982 Mdot
.34988 .4244 Mdot
.79811 .47052 Mdot
.7708 .50968 Mdot
.44147 .26512 Mdot
.27266 .2657 Mdot
.69746 .44234 Mdot
.42122 .22271 Mdot
.59347 .61027 Mdot
.28817 .45779 Mdot
.74887 .37752 Mdot
.16932 .54523 Mdot
.67943 .34473 Mdot
.68856 .44492 Mdot
.41328 .1677 Mdot
.4032 .21299 Mdot
.3139 .65813 Mdot
.30462 .34249 Mdot
.7946 .39416 Mdot
.59918 .55888 Mdot
.47052 .87351 Mdot
.31019 .7135 Mdot
.42895 .14802 Mdot
.37337 .63437 Mdot
.54849 .47464 Mdot
.44062 .4271 Mdot
.65265 .45791 Mdot
.48078 .70873 Mdot
.27642 .3088 Mdot
.4173 .43287 Mdot
.61258 .52418 Mdot
.61297 .35525 Mdot
.46529 .63098 Mdot
.38911 .30869 Mdot
.15774 .50878 Mdot
.47132 .67601 Mdot
.56121 .6232 Mdot
.23096 .64056 Mdot
.42888 .73029 Mdot
.84601 .49696 Mdot
.22576 .31845 Mdot
.30637 .38165 Mdot
.43388 .58008 Mdot
.50195 .83234 Mdot
.43425 .3293 Mdot
.35259 .33093 Mdot
.33399 .56126 Mdot
.7799 .56751 Mdot
.33743 .50476 Mdot
.18789 .58797 Mdot
.41818 .18724 Mdot
.60857 .49207 Mdot
.4888 .89503 Mdot
.76722 .40803 Mdot
.53644 .58561 Mdot
.33509 .51272 Mdot
.34051 .22471 Mdot
.52677 .77338 Mdot
.58777 .16846 Mdot
.21798 .47042 Mdot
.46163 .33323 Mdot
.76849 .58576 Mdot
.31796 .77673 Mdot
.43711 .59828 Mdot
.34232 .81466 Mdot
.27349 .37442 Mdot
.73346 .58228 Mdot
.24375 .49994 Mdot
.37848 .32536 Mdot
.69626 .3564 Mdot
.22861 .43135 Mdot
.67599 .49001 Mdot
.46992 .37323 Mdot
.26142 .34638 Mdot
.74217 .64816 Mdot
.31084 .68808 Mdot
.28591 .34334 Mdot
.33447 .55644 Mdot
.41585 .42967 Mdot
.78475 .41225 Mdot
.43623 .67926 Mdot
.48297 .67888 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0SOooool4o`000;Sooooo000Looooo`03o`000?oooooooooo08Cooooo0_l00007oooo
o`Co00004?ooool4o`0000?ooooo0_l0002Oooooo`007?ooool00ol0003oooooooooo`24ooooo`?o
00003_ooool4o`0000Sooooo1?l00003ooooo`;o000000?oooooo`000?l00000W?ooool001cooooo
00?o0000ooooooooool0QOooool2o`000003ooooool0003o000000Sooooo0_l000000ooooooo0000
o`000002o`0000?ooooo0_l0000=ooooo`;o0000W?ooool001cooooo0_l00020ooooo`;o00001ooo
ool2o`0000Cooooo0_l00002ooooo`;o00002?ooool2o`000:_ooooo000Looooo`03o`000?oooooo
oooo07oooooo0_l0000<ooooo`Co00001Oooool2o`0000Gooooo0_l0000@ooooo`;o0000V?ooool0
01cooooo00?o0000ooooooooool0Ooooool2o`0000_ooooo1Ol00005ooooo`;o00001Oooool3o`00
0003ooooool0003o000000cooooo0_l0002Hooooo`007?ooool00ol0003oooooooooo`2<ooooo`;o
00004?ooool2o`000003ooooool0003o000000Co00002?ooool2o`0009Sooooo000Looooo`03o`00
0?oooooooooo09Wooooo0_l000000ooooooo0000o`000005ooooo`Co000000Coooooo`000?l0003o
oooo0_l00002ooooo`;o0000V?ooool001cooooo00?o0000ooooooooool0Poooool2o`0001Cooooo
0_l000000ooooooo0000o`000007ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo
0000o`000002ooooo`;o00000_ooool2o`0000;ooooo0ol0002<ooooo`007?ooool00ol0003ooooo
ooooo`23ooooo`;o00006?ooool2o`0000oooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo
0ol000000ooooooo0000o`000029ooooo`007?ooool00ol0003oooooooooo`1iooooo`;o00008_oo
ool2o`0001Kooooo0ol00006ooooo`;o0000ROooool001cooooo00?o0000ooooooooool0Moooool4
o`0001gooooo0_l0000Kooooo`?o0000TOooool001cooooo00?o0000ooooooooool0Moooool2o`00
01oooooo0_l00009ooooo`?o0000Xoooool001cooooo00?o0000ooooooooool0Xoooool4o`000:;o
oooo000Looooo`03o`000?oooooooooo087ooooo1Ol0000Oooooo`;o0000X_ooool001cooooo00?o
0000ooooooooool0POooool5o`000<?ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo
0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`21ooooo`;o000000?oooooo`000?l00000
7oooool2o`000003ooooool0003o000009oooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1]oooo
o`;o00002_ooool2o`0002Cooooo0_l00002ooooo`Co000000?oooooo`000?l000003?ooool2o`00
097ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^
k^h01oooool00ol0003oooooooooo`1]ooooo`;o00002_ooool2o`0002Cooooo0_l00002ooooo`;o
00002?ooool2o`0000Oooooo0_l000000ooooooo0000o`00000<ooooo`?o00000oooool2o`0007[o
oooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h0
1_ooool3o`0007;ooooo0_l00005ooooo`;o00005oooool2o`0000_ooooo0_l0000<ooooo`;o0000
1oooool2o`000003ooooool0003o000000Oooooo0_l00003ooooo`Go000000?oooooo`000?l00000
N_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVoooo
o`05ooooo`03o`000?oooooooooo06Cooooo0_l0000<ooooo`;o00001oooool2o`000003ooooool0
003o000000;o00004?ooool2o`0000_ooooo0_l0000Qooooo`;o00001_ooool2o`0007gooooo0000
0ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1Tooooo`;o00005?ooool3o`000003ooooool0003o000000;o00000_ooool2
o`0000cooooo1?l0002cooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj
^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`1jooooo`;o00000_ooool2o`0000Cooooo
0_l0000>ooooo`;o0000;?ooool2o`0000gooooo0ol0001eooooo`0000Koooooonk^k_lb<S;o0000
oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1eoooo
o`?o00001oooool2o`000003ooooool0003o000000kooooo0_l0000^ooooo`Go00002_ooool3o`00
07Gooooo000Looooo`03o`000?oooooooooo06[ooooo1?l00005ooooo`Go00001_ooool3o`000003
ooooool0003o000000?ooooo0_l00009ooooo`;o00009_ooool2o`0000Kooooo2?l00006ooooo`;o
0000Moooool001cooooo00?o0000ooooooooool0J_ooool4o`0000Gooooo0_l00005ooooo`;o0000
0_ooool3o`0000Kooooo0_l00005ooooo`;o00003oooool2o`0001Cooooo1?l000000ooooooo0000
o`000002o`0000Oooooo1Ol00006ooooo`?o0000M_ooool001cooooo00?o0000ooooooooool0IOoo
ool2o`0000?ooooo0_l00008ooooo`;o00001?ooool2o`0000?ooooo0_l000001?oooooo0000o`00
0?ooool2o`0000Oooooo0_l0000?ooooo`;o00005?ooool4o`0000?ooooo0_l00007ooooo`Co0000
2?ooool2o`0007Kooooo000Looooo`03o`000?oooooooooo06Gooooo0_l000000ooooooo0000o`00
0003o`0000Cooooo1Ol0000<ooooo`;o000000?oooooo`000?l000005oooool4o`0001?ooooo0_l0
000:ooooo`;o00000oooool3o`00083ooooo000Looooo`03o`000?oooooooooo05oooooo0_l00000
0ooooooo0000o`000002o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`Co00001?ooool2
o`0000cooooo0_l0000:ooooo`;o00002Oooool4o`0001kooooo0ol00003ooooo`;o00003Oooool2
o`0007;ooooo000Looooo`03o`000?oooooooooo05oooooo0_l000000ooooooo0000o`000002o`00
00;ooooo0_l00009ooooo`;o00000_ooool4o`0000;ooooo0_l00008ooooo`;o00002_ooool2o`00
02_ooooo0_l000000ooooooo0000o`00000@ooooo`?o0000LOooool001cooooo00?o0000oooooooo
ool0Hoooool2o`0000?ooooo0_l00007ooooo`Co000000Coooooo`000?l0003o00001?ooool2o`00
01kooooo0_l0000Tooooo`;o00001_ooool2o`0000Wooooo0_l0001aooooo`007?ooool00ol0003o
ooooooooo`1Sooooo`;o00000_ooool4o`000003ooooool0003o000000?ooooo0_l00003ooooo`;o
00009Oooool2o`0002cooooo0_l0000<ooooo`;o0000K_ooool001cooooo00?o0000ooooooooool0
Foooool2o`0000[ooooo1?l000000ooooooo0000o`00000=ooooo`;o00008?ooool2o`00037ooooo
0_l00007ooooo`;o0000K_ooool001cooooo00?o0000ooooooooool0F_ooool3o`0001kooooo0_l0
000Dooooo`;o00000oooool2o`0000Gooooo0_l0000Kooooo`;o000000?oooooo`000?l000001_oo
ool2o`0000Gooooo1_l0001gooooo`007?ooool00ol0003oooooooooo`1Jooooo`;o00005?ooool2
o`0000Sooooo1Ol00003ooooo`;o00003?ooool3o`0000?ooooo0_l00007ooooo`;o00006?ooool3
o`000003ooooool0003o000000Kooooo0_l00002ooooo`;o000000?oooooo`000?l000000ol0001h
ooooo`007?ooool2o`00063ooooo0_l0000?ooooo`;o000000?oooooo`000?l000001Oooool5o`00
00?ooooo0_l00005ooooo`;o00001Oooool2o`000003ooooool0003o000000[ooooo0_l0000Hoooo
o`;o00001?ooool4o`0000Gooooo0ol00004ooooo`?o0000Moooool001cooooo00?o0000oooooooo
ool0EOooool2o`0000?ooooo0_l00002ooooo`?o00001_ooool3o`0000Wooooo0_l00008ooooo`?o
00002?ooool3o`0000Sooooo0_l00009ooooo`?o00007_ooool5o`0000Cooooo1?l00004ooooo`;o
00001?ooool2o`0000Oooooo1?l0001Vooooo`007?ooool00ol0003oooooooooo`1Eooooo`;o0000
0oooool2o`0000;ooooo0_l00007ooooo`?o00000oooool3o`0000Sooooo0_l00002ooooo`Co0000
2?ooool2o`0000Wooooo0_l00009ooooo`?o00008Oooool2o`0000Cooooo1?l00005ooooo`;o0000
0_ooool3o`0000Oooooo1?l0001Vooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o00000ooo
ool2o`0000Sooooo0ol00008ooooo`;o00000_ooool2o`0000?ooooo0_l00005ooooo`;o00002Ooo
ool2o`0003?ooooo1?l00005ooooo`;o00000_ooool3o`0000Kooooo0ol0001Xooooo`007?ooool0
0ol0003oooooooooo`1Nooooo`;o00000oooool2o`0001Wooooo0_l000000ooooooo0000o`000002
ooooo`;o00001?ooool2o`0000Gooooo0_l00003ooooo`Co0000;Oooool4o`0000Gooooo0_l00002
ooooo`?o00001_ooool2o`00017ooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`1Eoooo
o`;o00001?ooool2o`000003ooooool0003o000000_ooooo0_l00007ooooo`;o00002?ooool2o`00
0003ooooool0003o000000;ooooo0_l00004ooooo`?o00001?ooool2o`0000?ooooo1?l0000]oooo
o`Co00005Oooool2o`0000kooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`1?ooooo`;o
00001?ooool2o`0000Cooooo0_l00003ooooo`;o00002Oooool2o`0000Oooooo0_l00004ooooo`;o
00001Oooool2o`0000Cooooo0ol00002ooooo`;o0000DOooool4o`0006Kooooo000Looooo`03o`00
0?oooooooooo04kooooo0ol00006ooooo`;o00001oooool2o`0000?ooooo1?l00002ooooo`?o0000
3?ooool2o`0000_ooooo0ol00007ooooo`;o00002oooool2o`0003Kooooo1?l00005ooooo`?o0000
00?oooooo`000?l000000ol0001Qooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o00001ooo
ool2o`0000Kooooo0_l00003ooooo`Ko000000Coooooo`000?l0003o00002Oooool2o`0000Sooooo
0_l00004ooooo`Ko00001?ooool2o`0000Oooooo0_l00002ooooo`;o0000=_ooool4o`0000Wooooo
1Ol0001Qooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00000oooool2o`0000cooooo0_l0
00000ooooooo0000o`000003o`000003ooooool0003o000000gooooo0_l00008ooooo`;o00001?oo
ool6o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`0000;ooooo0_l0000Xooooo`;o00006Ooo
ool2o`0006Cooooo000Looooo`03o`000?oooooooooo04[ooooo1_l000000ooooooo0000o`00000?
ooooo`;o000000?oooooo`000?l000008?ooool4o`000004ooooool0003o0000ooooo`;o00000_oo
ool5o`000003ooooool0003o000000?ooooo0_l0000Sooooo`;o00000oooool2o`0000kooooo0ol0
0008ooooo`;o00000_ooool2o`00063ooooo000Looooo`03o`000?oooooooooo04Wooooo0ol00002
ooooo`;o00000oooool2o`0000Wooooo0_l0000>ooooo`;o000000?oooooo`000?l000000oooool2
o`0001Cooooo0_l000000ooooooo0000o`000005o`0000?ooooo0_l0000Xooooo`?o00004_ooool5
o`0000Kooooo0ol000000ooooooo0000o`00000<ooooo`;o0000D_ooool001cooooo00?o0000oooo
ooooool0BOooool2o`0000Sooooo0_l00006ooooo`;o000000?oooooo`000?l000003_ooool2o`00
0003ooooool0003o000000;ooooo0ol000000ooooooo0000o`000003ooooo`;o000000?oooooo`00
0?l000003?ooool6o`000003ooooool0003o000000?o0000:Oooool2o`0001Gooooo0_l00006oooo
o`Co00003_ooool4o`00053ooooo000Looooo`03o`000?oooooooooo04Kooooo0_l00008ooooo`;o
00002Oooool2o`0000kooooo0_l00008ooooo`;o00000_ooool2o`0000?ooooo0_l000000ooooooo
0000o`00000=ooooo`Wo00001_ooool2o`0002Gooooo0_l0000Fooooo`?o00001?ooool2o`00013o
oooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`16ooooo`;o00002?ooool2o`0000gooooo
0_l00006ooooo`Oo00001Oooool2o`0001cooooo0ol000000ooooooo0000o`000008ooooo`?o0000
9?ooool2o`0000?ooooo0_l0000Aooooo`?o0000J?ooool001cooooo00?o0000ooooooooool0A_oo
ool2o`0001Oooooo0_l00006ooooo`Oo00001Oooool2o`0000Oooooo0_l00007ooooo`;o000000Co
ooooo`000?l0003o00001oooool2o`0000Sooooo0_l00002ooooo`;o0000:Oooool4o`0000?ooooo
0_l0000;ooooo`;o0000J?ooool001cooooo0_l00017ooooo`;o00008oooool2o`0000kooooo1Ol0
0005ooooo`Ko00001oooool2o`0000Sooooo0_l0000Looooo`?o00004?ooool2o`0000?ooooo0_l0
000Looooo`;o0000Eoooool001cooooo00?o0000ooooooooool0D_ooool2o`0000Kooooo1?l00002
ooooo`;o00006Oooool5o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0000Oooooo0ol0
000@ooooo`;o00004Oooool5o`0000Gooooo0_l00009ooooo`;o00001Oooool2o`0001[ooooo0_l0
001Gooooo`007?ooool00ol0003oooooooooo`16ooooo`;o00002_ooool2o`0000Kooooo1?l00002
ooooo`;o00006_ooool2o`0000?ooooo1?l00007ooooo`;o00001Oooool2o`00013ooooo0_l0000A
ooooo`;o00000_ooool2o`0000Cooooo0_l00004ooooo`;o00000oooool2o`0000Gooooo0_l0001c
ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00001?ooool2o`0000Oooooo0_l00005oooo
o`Co00008Oooool2o`000004ooooool0003o0000ooooo`;o00002Oooool2o`0001Oooooo0_l0000@
ooooo`;o00000oooool2o`000003ooooool0003o000000Oooooo0_l00003ooooo`?o0000NOooool0
01cooooo00?o0000ooooooooool0@?ooool4o`0000_ooooo0_l00005ooooo`Co00005_ooool2o`00
00;ooooo0_l00005ooooo`Go000000?oooooo`000?l000003Oooool3o`0001;ooooo0_l0000@oooo
o`;o00000_ooool2o`000004ooooool0003o0000o`0000;ooooo0_l00009ooooo`Co00001_ooool2
o`0000Kooooo0_l0000<ooooo`;o00000_ooool2o`0005Gooooo000Looooo`03o`000?oooooooooo
04;ooooo0_l0000Booooo`;o00002Oooool2o`0000_ooooo1?l00002ooooo`;o00001?ooool4o`00
00Cooooo1?l00008ooooo`Ko00001oooool2o`0000[ooooo0_l0000Booooo`Go000000?oooooo`00
0?l000001Ol000000ooooooo0000o`000004ooooo`?o00001_ooool2o`0000Kooooo0_l00005oooo
o`;o00001Oooool2o`0000;ooooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`0oooooo`;o
00001Oooool2o`0000Cooooo0_l0000Cooooo`;o00001?ooool2o`0000Cooooo0ol00005ooooo`?o
000000Goooooo`000?l0003o0000ooooo`04o`000003ooooool0003o000000;o00002?ooool2o`00
00;ooooo0_l00003ooooo`?o000000?oooooo`000?l000001oooool2o`000003ooooool0003o0000
01Cooooo1_l00002ooooo`Ko00001?ooool2o`000003ooooool0003o000000Cooooo0ol0000<oooo
o`;o00004_ooool2o`0004cooooo000Looooo`03o`000?oooooooooo03gooooo1?l00004ooooo`Go
00000_ooool2o`0000Cooooo0_l0000Booooo`?o00001?ooool2o`0000?ooooo0_l000001Ooooooo
0000o`000?l0003ooooo00;o00000_ooool4o`0000;ooooo0_l0000Booooo`?o00002_ooool2o`00
01Cooooo0_l00002ooooo`Go000000?oooooo`000?l000001?l000000ooooooo0000o`000005oooo
o`;o00001Oooool2o`0000Sooooo0ol0000Eooooo`;o0000C?ooool001cooooo00?o0000oooooooo
ool0?Oooool3o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000002o`0000Ko
oooo0_l0000=ooooo`;o00000oooool2o`0000Gooooo0_l00003ooooo`;o00000oooool4o`0000?o
oooo0_l00003ooooo`Co00006?ooool4o`0001Oooooo0ol00007ooooo`;o000000?oooooo`000?l0
00001?l00003ooooo`Ko00003?ooool4o`0000gooooo0_l00006ooooo`;o0000C?ooool001cooooo
00?o0000ooooooooool0@Oooool2o`0000Oooooo0_l0000Eooooo`;o00000oooool3o`0000;ooooo
1?l00003ooooo`?o00000_oooolAo`000003ooooool0003o000001Cooooo1?l0000:ooooo`;o0000
3?ooool2o`000003ooooool0003o000000Oooooo1_l00003ooooo`;o00000_ooool2o`0000cooooo
0_l0000?ooooo`;o0000E?ooool001cooooo00?o0000ooooooooool0@?ooool2o`0000_ooooo0_l0
0002ooooo`;o00004oooool?o`000003ooooool0003o000000;ooooo4Ol0000Pooooo`Co00001Ooo
ool2o`0000Sooooo0_l00003ooooo`;o00000oooool5o`0000Cooooo0_l00005ooooo`;o0000Kooo
ool001cooooo00?o0000ooooooooool0@?ooool2o`0000_ooooo0_l00002ooooo`;o00004?ooool2
o`000003ooooool0003o000000?o00000ooooolMo`0000Cooooo0_l000001?oooooo0000o`000?l0
000:ooooo`;o00001_ooool3o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`00
000=ooooo`;o00000oooool4o`0000Gooooo0_l00005ooooo`Co00006?ooool2o`0000Kooooo0_l0
001;ooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00002?ooool2o`00013ooooo0_l0000<
ooooo`;o00000_ooool2o`0000?ooooo1?l000000ooooooo0000o`00000Ko`000004ooooool0003o
0000ooooo`?o00002_ooool2o`0000Gooooo1?l00005ooooo`Co00007?ooool2o`0000Wooooo0_l0
000Hooooo`Co00001?ooool2o`0004_ooooo000Looooo`03o`000?oooooooooo03Wooooo0_l00008
ooooo`;o00003Oooool2o`000003ooooool0003o000000?ooooo0_l00007ooooo`;o000000?ooooo
o`000?l000000oooool5o`000004ooooool0003o0000ooooo`?o000000?oooooo`000?l000005?l0
000:ooooo`;o00003?ooool2o`0000Oooooo0_l00002ooooo`;o00006_ooool2o`0002Gooooo0_l0
0005ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0C?ooool2o`0000Cooooo0_l00003
ooooo`Go00000oooool3o`000004ooooool0003o0000ooooo`;o00000oooool5o`0000Cooooo6Ol0
000;ooooo`;o00000_ooool2o`0001Gooooo0_l00007ooooo`;o00006oooool2o`0000Oooooo0_l0
000Hooooo`?o0000B_ooool001cooooo00?o0000ooooooooool0=oooool2o`0001?ooooo0_l00003
ooooo`?o00000oooool4o`0000Cooooo0ol0000Boooooa[o00002?ooool2o`0000Cooooo0_l0000?
ooooo`;o00002_ooool2o`000005ooooool0003o0000o`000?ooool00ol00002ooooo`;o00004?oo
ool4o`0000Oooooo0ol00002ooooo`;o00004oooool2o`0004_ooooo000Looooo`;o0000>?ooool2
o`0001Oooooo0ol00005ooooo`;o00000_ooool6o`0000Cooooo0_l00002ooooo`;o00001_oooolN
o`000003ooooool0003o000000?ooooo0_l0000Eooooo`;o00002_ooool3o`000004ooooool0003o
0000ooooo`Oo00004?ooool4o`0000;ooooo0_l00004ooooo`;o00000_ooool2o`0000cooooo0_l0
00000ooooooo0000o`00001?ooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00001?ooool5
o`000003ooooool0003o000000Co00001?ooool2o`0000;ooooo1Ol000000ooooooo0000o`00000N
o`000003ooooool0003o0000013ooooo0_l00002ooooo`;o00003oooool4o`0000;ooooo0_l00000
0ooooooo0000o`000003o`0001;ooooo0_l00003ooooo`?o00004?ooool2o`0000?ooooo1Ol00002
ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0EOooool3o`000005ooooool0003o0000
o`000?ooool01?l00009ooooo`Go000000?oooooo`000?l000007?l0000Dooooo`?o00000_ooool2
o`0000Cooooo1Ol00006ooooo`;o00000_ooool=o`0000;ooooo0_l00004ooooo`;o00001Oooool2
o`0000Cooooo0_l00004ooooo`;o00002Oooool3o`0000Gooooo0_l00003ooooo`;o0000Boooool0
01cooooo00?o0000ooooooooool0B?ooool2o`0000_ooooo0_l00003ooooo`Ko00001?ooool2o`00
00Cooooo0ol00004oooooago00000_ooool2o`0000Cooooo0_l0000:ooooo`;o00000oooool2o`00
00Cooooo1Ol00005ooooo`;o00000oooool2o`000003ooooool0003o000000co00001?ooool2o`00
00_ooooo0_l00004ooooo`;o00002Oooool3o`0000_ooooo0_l0001:ooooo`007?ooool00ol0003o
ooooooooo`18ooooo`;o00000_ooool2o`0000Wooooo0_l00003ooooo`Go00000oooool2o`0000?o
oooo0ol00003ooooo`;o000000?oooooo`000?l000007_l00002ooooo`Ko00002?ooool2o`0000?o
oooo0ol00004ooooo`?o00001?ooool4o`0000?ooooo0_l000000ooooooo0000o`000005o`0000;o
oooo1?l0000Hooooo`;o00001?ooool2o`0000[ooooo1Ol00002ooooo`;o0000B_ooool001cooooo
00?o0000ooooooooool0<oooool2o`0000?ooooo0_l0000Booooo`;o00002Oooool2o`0000?ooooo
1Ol00007ooooo`?o00001?oooolSo`0000;ooooo0ol000000ooooooo0000o`000007ooooo`?o0000
1?ooool2o`0000?ooooo1?l000000ooooooo0000o`000004o`0000Cooooo0_l000000ooooooo0000
o`000006o`0000;ooooo1?l0000Aooooo`Co00000_ooool2o`0000Cooooo0_l00005ooooo`;o0000
00?oooooo`000?l000001Ol0001>ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00000ooo
ool2o`0001Wooooo0_l00009ooooo`?o00001oooool2o`0000Kooooo7_l00002ooooo`;o00000ooo
ool4o`0000Kooooo1ol000001?oooooo0000o`000?ooool5o`0000;ooooo1ol00004ooooo`co0000
0oooool4o`0000oooooo1?l0000>ooooo`?o000000?oooooo`000?l000001Ol0001>ooooo`007?oo
ool00ol0003oooooooooo`0hooooo`;o00006Oooool2o`0000Wooooo0ol00004ooooo`;o00001?oo
ool2o`0000Gooooo1?l000000ooooooo0000o`00000Do`0000;ooooo0_l00006ooooo`;o000000?o
ooooo`000?l000000oooool7o`000003ooooool0003o000000Ko000000?oooooo`000?l000001_l0
0002ooooo`oo00001?ooool4o`00013ooooo0_l00007ooooo`;o00001?ooool4o`0005Gooooo000L
ooooo`03o`000?oooooooooo03Gooooo0_l0000Hooooo`;o00000_ooool4o`0000;ooooo0_l00003
ooooo`;o00000_ooool2o`000003ooooool0003o000000;o00000_ooool4o`0000?ooooo6ol00002
ooooo`;o00001?ooool2o`0000?ooooo0_l00002ooooo`;o00002?ooool2o`0000Gooooo1?l00002
ooooo`?o000000?oooooo`000?l000002_l000001?oooooo0000o`000?l00002ooooo`;o000000Co
ooooo`000?l0003o00004?ooool2o`0000Oooooo0_l00003ooooo`;o000000?oooooo`000?l00000
EOooool001cooooo00?o0000ooooooooool0=Oooool2o`0001Sooooo0_l00002ooooo`Co00000_oo
ool2o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`?o00000_ooool4o`0000?ooooo3_l0
00000ooooooo0000o`00000:o`0000Sooooo0_l00007ooooo`;o00003oooool2o`0000Cooooo6?l0
00001?oooooo0000o`000?l0000Nooooo`;o00000oooool2o`0000Kooooo0ol0001:ooooo`007?oo
ool00ol0003oooooooooo`0fooooo`;o00003oooool2o`0000Kooooo0_l0000;ooooo`;o000000?o
ooooo`000?l000001?l000000ooooooo0000o`000003ooooo`;o00001Oooool3o`000003ooooool0
003o000000Ko00000_ooool<o`0000kooooo0_l0000Eooooo`;o00000_ooool;o`000003ooooool0
003o000000ko00003?ooool2o`00013ooooo0_l00003ooooo`;o00001_ooool3o`0004[ooooo000L
ooooo`03o`000?oooooooooo03Kooooo0_l0000?ooooo`;o00001_ooool2o`0000_ooooo0_l00000
0ooooooo0000o`000004o`0000gooooo0ol00003oooooa?o00002_ooool2o`0000?ooooo0_l0000A
ooooo`?o000000?oooooo`000?l000003?l00003ooooo`oo00003?ooool2o`00017ooooo1?l00002
ooooo`;o00000oooool2o`000003ooooool0003o000004Wooooo000Looooo`03o`000?oooooooooo
05Oooooo0_l000000ooooooo0000o`000003ooooo`;o00000_ooool2o`0000?ooooo1?l00006oooo
o`;o00001?oooolBo`0000Cooooo0ol00004ooooo`?o00005Oooool4o`000003ooooool0003o0000
00_o00000_ooool>o`000003ooooool0003o000000;ooooo0_l00007ooooo`;o00004Oooool5o`00
0003ooooool0003o000000;o000000Coooooo`000?l0003ooooo0_l00019ooooo`007?ooool00ol0
003oooooooooo`0iooooo`;o00007?ooool2o`000003ooooool0003o000000Oooooo0_l00003oooo
o`Ko00001Oooool2o`000003ooooool0003o000001?o000000?oooooo`000?l000000ol00005oooo
o`;o00003_ooool2o`0000Kooooo0ol000000ooooooo0000o`00000Ko`000003ooooool0003o0000
00;ooooo1?l00005ooooo`?o000000Coooooo`000?l0003o00003oooool2o`0000;ooooo0ol00003
ooooo`?o00002Oooool2o`0003kooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ
8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0iooooo`;o00007Ooo
ool2o`0001;ooooo0_l000000ooooooo0000o`00000No`0000Wooooo1?l00006ooooo`;o00000_oo
ool2o`0000Oooooo0_l000000ooooooo0000o`00000Ko`0000Gooooo1?l00004ooooo`Co000000Co
ooooo`000?l0003o00004Oooool5o`0000?ooooo1?l00008ooooo`;o0000?_ooool00006oooooomg
MgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0fooooo`;o00002oooool2o`0001?ooooo0_l00004ooooo`;o00000oooool2o`0000Oo
oooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l000001?oooooo0000o`000?ooool9o`00
0003ooooool0003o000000?o000000?oooooo`000?l000000ol00006ooooo`Ko00001_ooool5o`00
00[ooooo8?l00003ooooo`;o00001_ooool2o`0000Gooooo0_l000000ooooooo0000o`00000=oooo
o`Go00001?ooool3o`0000;ooooo0_l00014ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413o
ooooooooo`09ooooo`Go00001_ooool00ol0003oooooooooo`0fooooo`;o00002oooool2o`0001Wo
oooo0_l00003ooooo`;o00000oooool2o`0000Gooooo0_l00004ooooo`Go000000?oooooo`000?l0
00002?l000000ooooooo0000o`000002o`000003ooooool0003o000000?o00001_ooool2o`000003
ooooool0003o000000Oooooo1ol000000ooooooo0000o`000005ooooobKo00002?ooool2o`0000;o
oooo0_l000000ooooooo0000o`00000?ooooo`?o000000Coooooo`000?l0003ooooo1?l000000ooo
oooo0000o`000004ooooo`;o0000?_ooool00003ooooool0003ooooo00;ooooo00?o0000oooooooo
ool02Oooool01?m4A4CogMgMooooool00007ooooo`?o0000F_ooool2o`0000cooooo0_l00003oooo
o`;o00001oooool3o`0000;ooooo2_l000000ooooooo0000o`000006o`0000Sooooo0_l0000;oooo
o`;o000000Goooooo`000?l0003o0000ooooo`02o`0000Cooooo4_l000000ooooooo0000o`00000B
o`0000Sooooo0_l0000Gooooo`;o000000?oooooo`000?l000000oooool2o`0000Oooooo0_l00003
ooooo`;o0000>Oooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?oM
gMgoEEEEooooool00007ooooo`03o`000?oooooooooo03Gooooo0_l0000Sooooo`;o00004Oooool2
o`0000Sooooo1?l00002ooooo`ko000000?oooooo`000?l000002?ooool2o`0000kooooo0_l00007
ooooo`[o000000?oooooo`000?l000005Ol00002ooooo`Co00000oooool2o`0000cooooo0_l00009
ooooo`;o00000oooool2o`0000Kooooo0_l0000<ooooo`;o0000>Oooool00003ooooool@413ooooo
00;ooooo00?o410@ooooooooool02_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo
03;ooooo0_l000000ooooooo0000o`00000Yooooo`;o00002?ooool4o`0000_ooooo0_l00002oooo
o`;o00000oooool6o`0000;ooooo0_l0000:ooooo`;o00004?ooool2o`0000Cooooo2ol000000ooo
oooo0000o`00000Do`0000Gooooo0ol00002ooooo`;o00001?ooool2o`0000Kooooo0_l00009oooo
o`Co000000?oooooo`000?l00000Coooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg3?ooool0
0oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo03;ooooo0_l000000ooooooo0000o`000008
ooooo`Co00007Oooool2o`0000?ooooo0ol00002ooooo`Co00003Oooool2o`000003ooooool0003o
000000;ooooo0_l00006ooooo`;o00006_ooool5o`0000?ooooo0ol000000ooooooo0000o`00000M
o`0000Cooooo0ol00008ooooo`?o00002oooool2o`0000Gooooo0_l000001?oooooo0000o`000?oo
ool2o`0004cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool0
1_ooool00ol0003oooooooooo`0eooooo`;o00002?ooool4o`0002;ooooo0ol00006ooooo`;o0000
2_ooool7o`0000gooooo0_l0000Fooooo`;o000000?oooooo`000?l000001?ooool2o`000004oooo
ool0003o0000ooooob?o00002?ooool5o`0000Wooooo0ol0000:ooooo`;o00004Oooool2o`0003Wo
oooo000Looooo`03o`000?oooooooooo03?ooooo0_l0000:ooooo`;o00008_ooool2o`0000Cooooo
0_l00003ooooo`;o00002_ooool4o`000003ooooool0003o000000_ooooo1?l0000Nooooo`?o0000
00?oooooo`000?l000001_l00002oooooako00001_ooool7o`0000Sooooo0_l00006ooooo`;o0000
5Oooool2o`0003Wooooo000Looooo`03o`000?oooooooooo03?ooooo0_l00008ooooo`;o00009?oo
ool2o`0000Cooooo0_l000000ooooooo0000o`00000<ooooo`Co00002oooool2o`000003ooooool0
003o0000023ooooo9Ol000000ooooooo0000o`000004o`0000Sooooo2?l00003ooooo`Co00001_oo
ool3o`0004oooooo000Looooo`03o`000?oooooooooo03gooooo1?l0000[ooooo`Co00003?ooool2
o`0000_ooooo0_l00002ooooo`;o00007ooooolUo`000003ooooool0003o000000Go00002oooool4
o`0000?ooooo0_l00004ooooo`Oo00005_ooool2o`0003Oooooo000Looooo`03o`000?oooooooooo
03?ooooo0_l0000:ooooo`;o0000:oooool4o`0000_ooooo0_l0000>ooooo`Co00007?ooool2o`00
0003ooooool0003o000000Co000000?oooooo`000?l000006_l00002ooooo`;o000000?oooooo`00
0?l000000ol00008ooooo`;o00003_ooool5o`0001Sooooo0_l0000gooooo`007?ooool00ol0003o
ooooooooo`0cooooo`;o00002Oooool2o`0000Cooooo0_l0000Vooooo`;o00000_ooool2o`0000Wo
oooo0_l00006ooooo`;o000000?oooooo`000?l000000oooool3o`0000Cooooo0_l0000Gooooo`;o
000000?oooooo`000?l000008Ol00002ooooo`;o000000?oooooo`000?l000000ol00008ooooo`;o
000000?oooooo`000?l000003?ooool2o`0005?ooooo000Looooo`03o`000?oooooooooo03kooooo
0_l00004ooooo`;o000000?oooooo`000?l000009Oooool4o`000004ooooool0003o0000ooooo`;o
00001?ooool2o`0000Gooooo1Ol0000:ooooo`;o00006?ooool3o`000003ooooool0003o000001oo
00000_ooool5o`0000Cooooo0_l00003ooooo`Co000000?oooooo`000?l00000HOooool001cooooo
00?o0000ooooooooool0<Oooool2o`0000oooooo0_l00003ooooo`;o00005oooool2o`0000cooooo
1?l000001?oooooo0000o`000?ooool2o`0000Cooooo0_l00005ooooo`?o00000_ooool2o`0002;o
oooo:?l000001?oooooo0000o`000?l00002ooooo`Co00000_ooool3o`0006Kooooo000Looooo`03
o`000?oooooooooo037ooooo0_l0000?ooooo`;o000000?oooooo`000?l000006Oooool2o`0000co
oooo1?l00002ooooo`;o00003?ooool4o`0000;ooooo0_l00005ooooo`;o00006oooool:o`000003
ooooool0003o000001Oo000000?oooooo`000?l000002ol00002ooooo`;o000000?oooooo`000?l0
00002Oooool2o`0000;ooooo0_l00002ooooo`;o0000DOooool001cooooo00?o0000ooooooooool0
<Oooool2o`0000cooooo0_l00003ooooo`?o00006oooool2o`0000[ooooo1?l00002ooooo`;o0000
1Oooool3o`0000Cooooo1?l00008ooooo`?o00006_oooolXo`000003ooooool0003o000000Oo0000
0_ooool2o`0000;ooooo0_l00005ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0000;o
oooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00000oooool2o`0001cooooo
0_l0000;ooooo`Go000000?oooooo`000?l000000_ooool5o`0000?ooooo0ol0000:ooooo`;o0000
6oooool2o`0000;ooooo7ol000000ooooooo0000o`00000=o`000003ooooool0003o000000Wooooo
1_l00003ooooo`?o0000Doooool001cooooo00?o0000ooooooooool0Ioooool2o`0000Oooooo1?l0
00000ooooooo0000o`000002ooooo`;o00001_ooool3o`0002Kooooo0_l00003oooooaoo00000ooo
oolBo`0000Wooooo0_l00005ooooo`Go0000DOooool001cooooo0_l0000aooooo`;o0000=Oooool3
o`0000Kooooo0ol0000Mooooo`;o00002_ooool2o`0000cooooo0_l000000ooooooo0000o`00000O
o`0000;ooooo3?l000001?oooooo0000o`000?ooool3o`0000;ooooo0_l00008ooooo`;o00000_oo
ool5o`00057ooooo000Looooo`03o`000?oooooooooo033ooooo0_l0000^ooooo`;o00001_ooool2
o`0000Oooooo0_l0000:ooooo`;o00003oooool6o`0000Sooooo0_l0000?ooooo`;o00000_oooolJ
o`000003ooooool0003o000000;ooooo0_l00004ooooo`Ko00002Oooool2o`0000;ooooo0ol00003
ooooo`;o00000_ooool5o`00057ooooo000Looooo`03o`000?oooooooooo033ooooo0_l0000<oooo
o`?o00006Oooool2o`0000Cooooo1?l0000;ooooo`;o00000oooool2o`000003ooooool0003o0000
00Cooooo0_l00003ooooo`;o00002_ooool6o`0001gooooo6_l00002ooooo`;o000000?oooooo`00
0?l000000oooool5o`0000oooooo3_l0001Booooo`007?ooool00ol0003oooooooooo`0`ooooo`;o
00002oooool4o`0001Gooooo0ol000000ooooooo0000o`000006ooooo`;o00002oooool4o`000004
ooooool0003o0000ooooo`;o00002Oooool2o`0000;ooooo0_l00006ooooo`;o00003_ooool2o`00
017ooooo1?l000000ooooooo0000o`00000Co`0000;ooooo0_l000000ooooooo0000o`000002oooo
o`?o000000?oooooo`000?l000001Oooool2o`0000_ooooo1ol0001Fooooo`007?ooool00ol0003o
ooooooooo`0looooo`?o00005oooool3o`0001Kooooo1?l000001?oooooo0000o`000?ooool2o`00
00Wooooo0_l00002ooooo`;o00001_ooool5o`0000_ooooo0_l0000Booooo`?o000000?oooooo`00
0?l000004Ol00004ooooo`;o00000_ooool6o`0000;ooooo1?l00002ooooo`;o00003_ooool7o`00
00kooooo1?l00011ooooo`007?ooool00ol0003oooooooooo`0looooo`;o00000oooool2o`0002Oo
oooo0ol0000;ooooo`;o00000_ooool2o`0000Cooooo0_l0000:ooooo`Oo00006oooool5o`000003
ooooool0003o000000go000000?oooooo`000?l000002Oooool6o`0000;ooooo1Ol000000ooooooo
0000o`00000<ooooo`;o000000?oooooo`000?l000001?l0000:ooooo`;o00000_ooool4o`00047o
oooo000Looooo`03o`000?oooooooooo047ooooo1?l0000Uooooo`?o00001_ooool2o`000003oooo
ool0003o000000;o00000_ooool2o`0000Cooooo0_l0000=ooooo`Co00006_ooool6o`000003oooo
ool0003o000000go000000?oooooo`000?l000002Oooool5o`0000Cooooo1?l000000ooooooo0000
o`00000;ooooo`?o00004?ooool3o`0004Oooooo000Looooo`03o`000?oooooooooo04;ooooo0ol0
000Oooooo`;o00003Oooool2o`000003ooooool0003o000000_ooooo0_l0000<ooooo`;o00003_oo
ool3o`0000_ooooo1Ol000000ooooooo0000o`000002o`000003ooooool0003o000000[o00001Ooo
ool3o`0000?ooooo1?l00005ooooo`;o00002oooool2o`0000?ooooo1?l00006ooooo`;o00001ooo
ool2o`0000Kooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00005?ooool2
o`0000[ooooo0_l0000Cooooo`?o000000?oooooo`000?l000001?ooool2o`0000[ooooo0_l00000
0ooooooo0000o`00000=ooooo`?o00001Oooool2o`0000?ooooo0_l00002ooooo`;o000000?ooooo
o`000?l000000_l000000ooooooo0000o`000004o`0000Cooooo0_l00002ooooo`;o000000Cooooo
o`000?l0003o00000oooool3o`0000Kooooo0_l0000;ooooo`;o00001Oooool2o`0000Kooooo0_l0
0003ooooo`;o00001oooool2o`000003ooooool0003o000000;o0000?_ooool001cooooo00?o0000
ooooooooool0<Oooool2o`0000_ooooo0_l0000Hooooo`;o00002oooool2o`0000kooooo0_l00002
ooooo`?o000000?oooooo`000?l000001?ooool2o`0000[ooooo0_l000000ooooooo0000o`000002
o`0000kooooo0_l00003ooooo`;o00000oooool2o`0000Sooooo2Ol00005ooooo`Co00000_ooool2
o`0000?ooooo0_l0000Jooooo`;o00003?ooool2o`0000Oooooo0_l00002ooooo`?o0000?_ooool0
01cooooo00?o0000ooooooooool0<Oooool2o`0000Oooooo0_l00002ooooo`;o00001oooool2o`00
01[ooooo1?l0000;ooooo`;o000000Coooooo`000?l0003o00000_ooool4o`0000Gooooo0_l00002
ooooo`;o00002oooool2o`000003ooooool0003o000000;o00002Oooool2o`0000?ooooo0_l0000=
oooooa;o00001?ooool2o`000003ooooool0003o000001Wooooo1?l0000?ooooo`;o00001oooool2
o`0003oooooo000Looooo`03o`000?oooooooooo03[ooooo0_l0000;ooooo`;o00001oooool2o`00
017ooooo0_l0000=ooooo`;o00000_ooool2o`000003ooooool0003o000000Oo000000Coooooo`00
0?l0003ooooo0ol0000;ooooo`;o000000?oooooo`000?l000000_l0000>ooooo`;o00001oooool2
o`0000Oooooo3ol00004ooooo`Ko00006?ooool4o`0000oooooo0_l0000:ooooo`;o0000??ooool0
01cooooo00?o0000ooooooooool0>oooool4o`0000Kooooo0_l00009ooooo`;o00009Oooool>o`00
0003ooooool0003o000000cooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o0000
00kooooo0_l00004ooooo`;o00002?ooool5o`000004ooooool0003o0000ooooo`Co00001Oooool6
o`0000Sooooo0_l00007ooooo`;o00000oooool2o`0000gooooo0_l0000@ooooo`;o0000??ooool0
01cooooo00?o0000ooooooooool0>oooool4o`000003ooooool0003o000000?ooooo0_l0000Eoooo
o`;o00005oooool;o`0000;ooooo0ol00002ooooo`;o00003_ooool4o`000003ooooool0003o0000
00kooooo0_l0000Dooooo`Co00001?ooool2o`0000;ooooo0_l00008ooooo`?o000000?oooooo`00
0?l000001oooool2o`0000?ooooo0_l0000<ooooo`?o00000oooool2o`0000Cooooo0ol00012oooo
o`007?ooool00ol0003oooooooooo`10ooooo`;o00001?ooool2o`0000gooooo0_l000000ooooooo
0000o`000004o`0000gooooo0_l00005ooooo`;o000000?oooooo`000?l000002Ol00003ooooo`;o
00000_ooool2o`0000cooooo1_l0000Iooooo`?o00002oooool6o`0000;ooooo0_l0000<ooooo`?o
000000?oooooo`000?l000001Oooool2o`0000Kooooo0_l0000;ooooo`;o00001?ooool2o`0000Co
oooo0ol00012ooooo`007?ooool00ol0003oooooooooo`0looooo`;o00001?ooool2o`0000;ooooo
0_l00009ooooo`;o00000_ooool2o`000003ooooool0003o000000Wo00002?ooool2o`0000Gooooo
3_l00003ooooo`;o00000_ooool2o`0000[ooooo2ol0000Booooo`;o00000_ooool3o`0000oooooo
1?l000000ooooooo0000o`000006ooooo`;o00000oooool2o`0000Wooooo0_l00006ooooo`?o0000
2Oooool2o`0000Kooooo0_l00008ooooo`;o00001?ooool2o`0003Sooooo000Looooo`;o0000<Ooo
ool2o`0000[ooooo0_l00004ooooo`;o00001oooool4o`0000;ooooo0_l0000;ooooo`Go00004Ooo
ool<o`0000?ooooo0_l0000>ooooo`;o00000_ooool2o`0000;ooooo1_l0000?ooooo`;o00003?oo
ool2o`0000;ooooo0_l00003ooooo`?o000000?oooooo`000?l000001_ooool2o`0001Oooooo0_l0
0004ooooo`;o000000?oooooo`000?l000000_l00006ooooo`;o00001Oooool2o`000004ooooool0
003o0000ooooo`;o000000?oooooo`000?l00000>?ooool001cooooo00?o0000ooooooooool0<?oo
ool2o`00013ooooo1?l000000ooooooo0000o`000006o`0000?ooooo0_l00005ooooo`;o00001?oo
ool4o`0000Oooooo0_l00008ooooo`co00001oooool2o`0000_ooooo0_l000000ooooooo0000o`00
0003ooooo`Go00007?ooool3o`0000;ooooo0_l00003ooooo`;o00001?ooool4o`0000?ooooo0ol0
0003ooooo`;o00001_ooool4o`0000cooooo0_l000000ooooooo0000o`000002ooooo`;o00002?oo
ool5o`0000Cooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0^ooooo`?o00004Oooool4
o`000003ooooool0003o000000?o000000?oooooo`000?l000000oooool2o`0000Gooooo0_l00004
ooooo`?o00000oooool2o`0000?ooooo0_l00007ooooo`ko00000oooool2o`000003ooooool0003o
000000[ooooo0ol000000ooooooo0000o`000008o`0000kooooo0_l0000<ooooo`;o00003_ooool4
o`0000?ooooo0ol00003ooooo`;o00001_ooool4o`00013ooooo0_l000000ooooooo0000o`000008
ooooo`Co0000@_ooool001cooooo00?o0000ooooooooool0;_ooool4o`0001Oooooo0_l00002oooo
o`;o000000?oooooo`000?l000000oooool2o`000004ooooool0003o0000ooooo`;o000000?ooooo
o`000?l000000_l00003ooooo`;o00003?ooool>o`0000?ooooo0_l0000=ooooo`;o000000?ooooo
o`000?l000001_l000000ooooooo0000o`000002o`0000cooooo0_l0000Booooo`;o00000_ooool2
o`0000cooooo0_l0000:ooooo`?o00003Oooool2o`0000?ooooo1Ol00008ooooo`;o0000A?ooool0
01cooooo00?o0000ooooooooool0;oooool3o`0001Oooooo0_l00005ooooo`;o000000?oooooo`00
0?l000002?l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00002ooooo`;o000000?ooooo
o`000?l000001_ooool<o`0001Kooooo0ol00007ooooo`?o00002Oooool2o`0001Gooooo0_l00000
1?oooooo0000o`000?l00005ooooo`;o000000?oooooo`000?l000003Oooool3o`0000kooooo0_l0
0004ooooo`Co00002?ooool2o`0000[ooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0_
ooooo`;o00008_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l00003
ooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`ko00005oooool2o`0000?ooooo0_l0
0002ooooo`?o00002Oooool2o`0000kooooo0_l000000ooooooo0000o`000005ooooo`;o00001_oo
ool2o`000003ooooool0003o000000gooooo0_l00007ooooo`;o00007oooool2o`0000?ooooo0_l0
000hooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00004_ooool2o`0000?ooooo1?l00006
ooooo`?o00001oooool@o`0000Sooooo0_l00006ooooo`;o00001?ooool4o`0000?ooooo0_l00003
ooooo`?o00002?ooool2o`0000Sooooo0_l00004ooooo`Go000000?oooooo`000?l000006_ooool3
o`0000Sooooo0_l00009ooooo`;o00004oooool3o`0000;ooooo0_l0000iooooo`007?ooool00ol0
003oooooooooo`12ooooo`?o00004Oooool2o`0000?ooooo1?l00002ooooo`Ko00002?ooool@o`00
00Sooooo0_l00006ooooo`Co00000_ooool3o`0000Wooooo1Ol0000@ooooo`;o00001Oooool2o`00
00?ooooo0_l00008ooooo`;o00003_ooool5o`0000Cooooo0_l0000:ooooo`;o000000?oooooo`00
0?l000004oooool2o`000003ooooool0003o000000;o0000>Oooool001cooooo00?o0000oooooooo
ool0@oooool2o`0001;ooooo1_l000001?oooooo0000o`000?ooool4o`0000oooooo2ol00006oooo
o`;o00002?ooool4o`0000?ooooo0_l00003ooooo`_o00004?ooool4o`000003ooooool0003o0000
00Kooooo0_l00007ooooo`;o00003Oooool6o`0000;ooooo1?l0000:ooooo`;o00006Oooool2o`00
03_ooooo000Looooo`03o`000?oooooooooo02gooooo0_l0000Fooooo`;o00004?ooool5o`0000;o
oooo0_l00008ooooo`;o00000_ooool2o`000003ooooool0003o000000Cooooo0ol00004ooooo`?o
00001_ooool3o`0001;ooooo3_l00004ooooo`;o00001oooool8o`0000Kooooo0_l0000Dooooo`Co
00001_ooool2o`0000gooooo1?l0001Cooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o0000
5_ooool2o`00017ooooo0ol00003ooooo`;o00001?ooool2o`0000;ooooo0_l00002ooooo`;o0000
00?oooooo`000?l000001?ooool3o`0000kooooo0_l0000;ooooo`;o00001Oooool2o`0000Gooooo
1ol00004ooooo`Co00001Oooool3o`0000;ooooo1?l00003ooooo`;o00005_ooool3o`0000?ooooo
0_l000000ooooooo0000o`000007ooooo`;o00001Oooool4o`00017ooooo0_l00003ooooo`;o0000
>oooool001cooooo00?o0000ooooooooool0Eoooool5o`0000Sooooo0_l0000;ooooo`Oo00006ooo
ool4o`0000?ooooo0_l00006ooooo`;o000000Coooooo`000?l0003o00001_ooool2o`0000Kooooo
0_l00004ooooo`;o00000oooool2o`0000;ooooo0ol0000;ooooo`?o000000?oooooo`000?l00000
0_l00004ooooo`;o000000?oooooo`000?l000001oooool2o`0000Kooooo0_l0000<ooooo`;o0000
0oooool3o`0000?ooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00005ooo
ool3o`0000_ooooo1Ol00008ooooo`;o00000_ooool2o`0000Oooooo1Ol0000>ooooo`;o00000_oo
ool2o`0000_ooooo0_l00003ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`000003oooo
ool0003o000000;o000000?oooooo`000?l000000_ooool2o`0000Kooooo0_l00002ooooo`;o0000
0oooool2o`0000Cooooo0ol00003ooooo`;o00000oooool6o`000003ooooool0003o000000Kooooo
0_l00002ooooo`;o00001oooool2o`0000Gooooo1?l0000:ooooo`;o00000oooool2o`0000Cooooo
0_l0000kooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00005oooool3o`0000_ooooo0_l0
000;ooooo`;o00000_ooool2o`0000[ooooo0ol0000=ooooo`;o00000_ooool2o`0000[ooooo0_l0
0007ooooo`?o00001oooool2o`000003ooooool0003o000000;ooooo1?l00004ooooo`?o000000?o
ooooo`000?l000000_l000000ooooooo0000o`000009ooooo`Go000000?oooooo`000?l000001ol0
0006ooooo`;o00000_ooool2o`0000Oooooo0_l00007ooooo`;o0000D_ooool001cooooo00?o0000
ooooooooool0<Oooool2o`0001Oooooo0_l00005ooooo`;o00001?ooool2o`0000Kooooo0_l00004
ooooo`;o000000?oooooo`000?l000002Oooool4o`0001?ooooo0_l00005ooooo`;o000000?ooooo
o`000?l000000_ooool2o`0000?ooooo0_l00008ooooo`_o00000oooool4o`0000?ooooo1?l00004
ooooo`co00000_ooool5o`0000?ooooo0_l00005ooooo`;o00002Oooool2o`00017ooooo0_l00007
ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0<Oooool4o`0001cooooo0_l00003oooo
o`?o00001Oooool3o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000001_ooool2
o`000003ooooool0003o000000;ooooo0_l0000Aooooo`?o00001?ooool4o`0000?ooooo0_l00004
ooooo`?o00001Oooool8o`0000Oooooo0ol00005ooooo`Go00000_ooool6o`000004ooooool0003o
0000ooooo`;o00000_ooool2o`000003ooooool0003o000000?ooooo0_l00003ooooo`Co00000_oo
ool2o`0000Gooooo0_l0000Aooooo`;o00001oooool2o`0000;ooooo0_l0000kooooo`007?ooool2
o`00037ooooo0_l000001?oooooo0000o`000?l0000Pooooo`?o00001Oooool2o`0000;ooooo0_l0
000<ooooo`;o00001Oooool2o`0000cooooo0_l00003ooooo`?o00001_ooool4o`000004ooooool0
003o0000o`0000?ooooo1?l00004ooooo`So00002?ooool2o`0000Oooooo0ol0000=ooooo`;o0000
1?ooool2o`0000Cooooo1_l00004ooooo`;o00008?ooool2o`0000?ooooo0_l0000kooooo`007?oo
ool00ol0003oooooooooo`0`ooooo`Ko00004oooool2o`0001kooooo0_l0000Fooooo`;o00000_oo
ool2o`0000Oooooo0_l00005ooooo`;o00000_ooool5o`000004ooooool0003o0000o`0000Oooooo
1_l000000ooooooo0000o`000002ooooo`Co00001Oooool4o`0000;ooooo0_l00004ooooo`;o0000
1?ooool2o`0000?ooooo0_l00005ooooo`Co00003oooool2o`0000oooooo0_l00005ooooo`?o0000
0oooool2o`0003_ooooo000Looooo`03o`000?oooooooooo033ooooo1Ol0000Dooooo`;o00001Ooo
ool2o`0001Oooooo0_l00005ooooo`;o00003oooool2o`0000_ooooo1Ol00006ooooo`Go00002_oo
ool3o`000005ooooool0003o0000o`000?ooool00_l00002ooooo`;o00001oooool4o`0000;ooooo
0_l00004ooooo`;o00002Oooool2o`0000Gooooo1ol0000<ooooo`;o00003oooool2o`0000Gooooo
0_l00004ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0<oooool2o`0001_ooooo0_l0
000Aooooo`?o00000oooool2o`0000Gooooo0_l000001?oooooo0000o`000?l0000Eooooo`?o0000
00?oooooo`000?l000001?l00002ooooo`;o00003oooool2o`0000Kooooo0_l0000<ooooo`?o0000
0_ooool2o`0001Sooooo1Ol00003ooooo`;o00007?ooool2o`0004Cooooo000Looooo`03o`000?oo
oooooooo05?ooooo0_l00002ooooo`;o00002_ooool4o`0000;ooooo0_l00008ooooo`Co00005?oo
ool3o`0000?ooooo1Ol000000ooooooo0000o`00000Gooooo`;o00003?ooool3o`0000Oooooo0_l0
000Kooooo`;o000000?oooooo`000?l000000oooool2o`0000Wooooo0_l00009ooooo`;o00002?oo
ool2o`0003[ooooo000Looooo`03o`000?oooooooooo04Wooooo0_l00007ooooo`?o00000_ooool2
o`0000Gooooo0_l000001?oooooo0000o`000?ooool3o`000004ooooool0003o0000o`0000[ooooo
0_l00002ooooo`;o00004?ooool2o`0000Cooooo1Ol000000ooooooo0000o`000002ooooo`;o0000
7Oooool2o`0000cooooo0ol000000ooooooo0000o`00000Cooooo`;o00000_ooool2o`000003oooo
ool0003o000000;ooooo0ol00009ooooo`;o00002Oooool2o`0000Sooooo0_l0000jooooo`007?oo
ool00ol0003oooooooooo`0`ooooo`;o00000_ooool2o`0001?ooooo0_l00007ooooo`;o00002_oo
ool2o`000004ooooool0003o0000ooooo`Ko00001?ooool2o`0000Cooooo0_l000000ooooooo0000
o`000002o`0000Sooooo0_l00006ooooo`;o00000oooool3o`000004ooooool0003o0000ooooo`;o
00000_ooool2o`0001gooooo0_l0000=ooooo`;o000000?oooooo`000?l000003?ooool3o`0000Co
oooo0_l000001?oooooo0000o`000?ooool3o`0000;ooooo0_l00004ooooo`;o00001_ooool2o`00
04gooooo000Looooo`03o`000?oooooooooo033ooooo0_l000001?oooooo0000o`000?l0000Coooo
o`;o00004oooool4o`0000;ooooo1Ol00004ooooo`?o00001?ooool2o`000003ooooool0003o0000
00;ooooo0_l00003ooooo`;o000000?oooooo`000?l000002oooool3o`000003ooooool0003o0000
03Cooooo0_l0000>ooooo`?o000000?oooooo`000?l000002_l00002ooooo`;o00001?ooool2o`00
00Kooooo0_l000000ooooooo0000o`000007ooooo`;o0000@Oooool001cooooo00?o0000oooooooo
ool0<oooool3o`0002?ooooo0_l00002ooooo`Go00000_ooool;o`0000;ooooo0_l000000ooooooo
0000o`000005ooooo`;o00000oooool3o`0000Kooooo0_l000000ooooooo0000o`000004ooooo`;o
00009oooool2o`0000gooooo0_l0000>ooooo`;o00000_ooool:o`0001Gooooo0_l00003ooooo`;o
00000_ooool2o`00047ooooo000Looooo`03o`000?oooooooooo03Kooooo0_l0000@ooooo`;o0000
2oooool2o`0000;ooooo5Ol00003ooooo`;o00001oooool2o`0000Gooooo0_l00006ooooo`;o0000
00?oooooo`000?l000001?ooool2o`0000Cooooo0_l0000Aooooo`;o00001Oooool2o`0000Oooooo
0_l00007ooooo`;o00001?ooool4o`0000cooooo1?l00004ooooo`Ko00006_ooool2o`0000[ooooo
0_l0000iooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00004?ooool2o`0000Gooooo0_l0
0004ooooo`;o00001?oooolCo`0000Oooooo0_l00003ooooo`;o00002Oooool2o`0000;ooooo0_l0
0007ooooo`?o00000oooool2o`0000Gooooo0_l0000:ooooo`;o00001Oooool2o`0000Oooooo0_l0
0007ooooo`;o00000oooool2o`000003ooooool0003o000000Gooooo0ol00006ooooo`;o00000ooo
ool2o`000003ooooool0003o000000Sooooo0_l0000Nooooo`;o0000>Oooool001cooooo00?o0000
ooooooooool0Coooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000005?l00005
ooooo`;o00002Oooool3o`000005ooooool0003o0000o`000?ooool00ol00007ooooo`?o00002_oo
ool2o`00013ooooo0_l0000Booooo`;o00000_ooool2o`0000;ooooo0_l00004ooooo`Co00002_oo
ool2o`000003ooooool0003o000000Cooooo0ol000001?oooooo0000o`000?l0000Iooooo`;o0000
?Oooool001cooooo00?o0000ooooooooool0>Oooool2o`0001?ooooo0_l000000ooooooo0000o`00
0002o`0000;ooooo0_l000000ooooooo0000o`00000Do`00013ooooo0ol000000ooooooo0000o`00
0004o`0000;ooooo0_l0000;ooooo`?o00000_ooool2o`0000[ooooo0_l00004ooooo`Co00004Ooo
ool2o`0000Kooooo0_l00006ooooo`;o00000_ooool3o`0000Gooooo0_l000001?oooooo0000o`00
0?ooool2o`000004ooooool0003o0000o`0000;ooooo0_l00005ooooo`;o00004_ooool2o`0003go
oooo000Looooo`03o`000?oooooooooo03Wooooo0_l0000Cooooo`;o000000?oooooo`000?l00000
0_l00002ooooo`;o000000?oooooo`000?l000005?l00002ooooo`?o00001_ooool2o`0000Wooooo
0_l00004ooooo`;o00000oooool2o`0000Kooooo1ol0000:ooooo`;o00001?ooool4o`0002Gooooo
0ol00005ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000008ooooo`Co
00003_ooool2o`00047ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44oooo
o`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`1Goooooa[o000000Cooooo
o`000?l0003o00001_ooool2o`0000Gooooo0_l00009ooooo`Oo00001_ooool6o`0002Cooooo0_l0
000Tooooo`;o00000_ooool4o`0000;ooooo0_l0000@ooooo`;o0000@Oooool00006oooooomgMgOo
V9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03
o`000?oooooooooo04Sooooo0_l00008ooooo`;o00001OoooolNo`0000_ooooo0_l00009ooooo`Co
000000?oooooo`000?l000000_l00004ooooo`Ko00005?ooool2o`0000kooooo0_l0000;ooooo`;o
00001_ooool2o`000003ooooool0003o000000gooooo0_l000000ooooooo0000o`000002o`0001Co
oooo0_l00011ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`0mooooo`;o00002Oooool2o`0000So
oooo0_l00006oooooago00002?ooool2o`000003ooooool0003o000000Kooooo0_l000000ooooooo
0000o`000002o`0000;ooooo0ol00005ooooo`Go000000?oooooo`000?l000004Oooool2o`0001;o
oooo0_l00007ooooo`;o00001_ooool2o`000003ooooool0003o000000gooooo0_l00002ooooo`Go
00004_ooool2o`00047ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo
00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000?Oooool2o`0001Wooooo6Ol000000ooooooo
0000o`000003o`0000Kooooo1?l000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l0
00001Oooool2o`0000?ooooo1?l00004ooooo`;o00009Oooool2o`0000Sooooo0_l000000ooooooo
0000o`00000Gooooo`Ko00001?ooool2o`0000Oooooo1?l00014ooooo`0000?oooooo`000?ooool0
0_ooool00ol0003oooooooooo`09ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003o
ooooooooo`0nooooo`;o00004oooool2o`0000;ooooo6_l00003ooooo`?o00001_ooool2o`0000co
oooo0_l00008ooooo`?o000000?oooooo`000?l00000;?ooool4o`0000Cooooo0_l000000ooooooo
0000o`000003o`0000[ooooo0_l0000;ooooo`;o000000?oooooo`000?l000000_l00002ooooo`?o
00001?ooool2o`000003ooooool0003o000000;o0000A?ooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo03kooooo
0_l0000Booooo`?o00000_ooool2o`000003ooooool0003o000001Ko000000Coooooo`000?l0003o
00000oooool2o`0000;ooooo0_l00004ooooo`;o00001Oooool3o`0000?ooooo0ol00002ooooo`?o
000000?oooooo`000?l000001?ooool4o`00013ooooo0_l00004ooooo`;o00003?ooool4o`0000Co
oooo0_l00002ooooo`?o00002oooool2o`0000kooooo2Ol00004ooooo`Co000000?oooooo`000?l0
0000A?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008oooo
o`03o`000?oooooooooo05;ooooo0_l00002ooooo`;o000000?oooooo`000?l000005ol000001?oo
oooo0000o`000?l00003ooooo`;o00002?ooool2o`0000Gooooo0_l00004ooooo`?o00000oooool2
o`000003ooooool0003o000000;o00000_ooool4o`00013ooooo0_l00004ooooo`;o00000_ooool2
o`0000Oooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo1?l0000<ooooo`;o00003_oo
ool5o`0000Wooooo0_l00017ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`04olc<
c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0D_ooool2o`0000;ooooo7ol00007ooooo`;o
00003?ooool2o`0000[ooooo1ol0000Pooooo`;o00001oooool2o`0000Cooooo0_l000000ooooooo
0000o`000006o`0000_ooooo0_l0000>ooooo`Co00002_ooool2o`0004Oooooo000Looooo`03o`00
0?oooooooooo05;ooooo0_l00004oooooa_o00001oooool5o`0000Wooooo0_l000000ooooooo0000
o`00000;ooooo`Ko000000?oooooo`000?l000003Oooool2o`00027ooooo2Ol00004ooooo`;o0000
0_ooool2o`0006Gooooo000Looooo`03o`000?oooooooooo05;ooooo0_l00004oooooaSo000000Co
ooooo`000?l0003ooooo0ol00003ooooo`Go00001_ooool5o`000003ooooool0003o000000_ooooo
1_l000000ooooooo0000o`00000=ooooo`?o00003Oooool2o`0000Cooooo0_l00005oooooa7o0000
0_ooool2o`0000;ooooo0_l0001Uooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00003?oo
ool2o`0000;ooooo0ol00004ooooo`Oo000000?oooooo`000?l000003ol00003ooooo`?o00000ooo
ool3o`0000Sooooo1?l0000@ooooo`Co00004_ooool2o`0000;ooooo0_l00009ooooo`;o00000ooo
ool3o`0000Gooooo4Ol000000ooooooo0000o`000002o`0000Wooooo0_l0000>ooooo`;o0000COoo
ool001cooooo00?o0000ooooooooool0?oooool2o`0000cooooo0_l00002ooooo`;o00001_oooolJ
o`0000;ooooo0_l00003ooooo`;o00002_ooool2o`000003ooooool0003o000000kooooo1?l00006
ooooo`;o00002_ooool2o`000004ooooool0003o0000o`0000Cooooo0_l00008ooooo`;o00001ooo
oolEo`0000Cooooo0_l00003ooooo`?o00003Oooool2o`0004gooooo000Looooo`03o`000?oooooo
oooo03oooooo0_l0000Aooooo`;o00001OoooolJo`0000cooooo0_l000000ooooooo0000o`000005
ooooo`;o00002?ooool2o`0000Kooooo1?l00004ooooo`;o00002_ooool2o`000003ooooool0003o
000000Gooooo0_l0000AoooooaCo00001Oooool4o`0000;ooooo0_l0001Looooo`007?ooool00ol0
003oooooooooo`0oooooo`;o00001_ooool2o`0000Wooooo0_l00005oooooa3o00000_ooool2o`00
0004ooooool0003o0000o`0000Gooooo0_l00007ooooo`;o000000Coooooo`000?l0003ooooo0_l0
000;ooooo`?o00002?ooool2o`0001[ooooo0_l0000?oooooaKo00001oooool2o`00063ooooo000L
ooooo`03o`000?oooooooooo04Oooooo0_l00006ooooo`?o00003_ooool9o`0000;ooooo0_l00003
ooooo`;o00001?ooool2o`0000Kooooo1?l00002ooooo`?o00002oooool2o`000003ooooool0003o
000000Oooooo1?l00007ooooo`;o00006?ooool2o`0000Gooooo5?l0000:ooooo`;o00000oooool2
o`0000cooooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o00000oooool4o`00
00Cooooo0_l00004ooooo`Go00001?ooool4o`0000Kooooo0_l00005ooooo`;o00001Oooool4o`00
00;ooooo0_l0000=ooooo`Co00000_ooool2o`0000?ooooo1?l00007ooooo`;o00005?ooool2o`00
00;ooooo0_l00003oooooa[o00001_ooool2o`0000?ooooo0_l00003ooooo`Go00001?ooool2o`00
04cooooo000Looooo`03o`000?oooooooooo04Oooooo0_l000000ooooooo0000o`000005ooooo`Co
00000_ooool2o`0000Cooooo1Ol00004ooooo`Co00000_ooool2o`0000Wooooo0_l00005ooooo`;o
000000Coooooo`000?l0003ooooo0_l0000=ooooo`;o00001?ooool3o`0000Kooooo0_l0000Koooo
o`;o00000_ooool2o`0000?ooooo6_l00007ooooo`;o00001oooool5o`0005;ooooo000Looooo`03
o`000?oooooooooo04Oooooo0_l00006ooooo`;o00000_ooool2o`0000?ooooo0_l0000Booooo`Co
00003Oooool6o`0000Gooooo0_l0000@ooooo`;o00001_ooool2o`0000Gooooo0_l00006ooooo`;o
00001Oooool2o`0000Gooooo0_l0000:oooooaOo00001oooool2o`0000Kooooo0ol00005ooooo`;o
0000C_ooool001cooooo00?o0000ooooooooool0C_ooool3o`0000;ooooo0_l00003ooooo`;o0000
5?ooool2o`000003ooooool0003o000000[ooooo1Ol00002ooooo`;o00000_ooool2o`0001cooooo
0_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000001?ooool3o`000003oooo
ool0003o000000kooooo5ol00002ooooo`;o00001oooool2o`0000;ooooo0ol00005ooooo`;o0000
C_ooool001cooooo0_l00011ooooo`;o00001_ooool2o`0000;ooooo1_l000001?oooooo0000o`00
0?l0000Dooooo`;o00001Oooool4o`0000;ooooo0_l000001?oooooo0000o`000?ooool5o`0000;o
oooo0_l0000Jooooo`;o00001?ooool2o`0000Kooooo0_l000000ooooooo0000o`000004ooooo`?o
000000?oooooo`000?l000001_ooool2o`0000Oooooo5?l00004ooooo`;o00001Oooool4o`0000?o
oooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00001_ooool2o`000004oooo
ool0003o0000o`0000;ooooo0_l00002ooooo`;o00004Oooool5o`0000Kooooo0ol00002ooooo`;o
000000?oooooo`000?l000002?ooool2o`0000Cooooo0_l0000Dooooo`;o00003Oooool2o`0000Ko
oooo0_l00002ooooo`;o00001_ooool2o`0000Oooooo5?l00008ooooo`;o000000?oooooo`000?l0
00000_l0001Jooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o00004_ooool2o`000003oooo
ool0003o000000?ooooo0ol00003ooooo`;o00005?ooool2o`000003ooooool0003o000000;ooooo
1?l0000Qooooo`;o00001_ooool2o`0000;ooooo1?l00005ooooo`;o00001_oooolDo`0000Sooooo
0_l00003ooooo`;o0000F_ooool001cooooo00?o0000ooooooooool0@Oooool2o`0001Wooooo1Ol0
00000ooooooo0000o`000009ooooo`Co00001oooool3o`0000Sooooo0_l000000ooooooo0000o`00
0004ooooo`;o00002Oooool2o`0000;ooooo0ol0000?ooooo`;o00003_ooool2o`0000Gooooo0_l0
0007oooooa?o00003Oooool2o`0000Gooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`11
ooooo`;o00004oooool2o`0000Cooooo0ol0000?ooooo`?o00001oooool4o`0000_ooooo0_l0000>
ooooo`;o00000_ooool3o`0000oooooo0_l00007ooooo`;o00002_ooool2o`0000Wooooo4ol0000<
ooooo`;o00001_ooool2o`000003ooooool0003o0000053ooooo000Looooo`03o`000?oooooooooo
05;ooooo0_l00002ooooo`;o00003oooool2o`0000Kooooo0_l00004ooooo`;o00000oooool2o`00
00_ooooo0_l0000@ooooo`Co00003_ooool2o`0000Wooooo0_l0000:ooooo`;o000000?oooooo`00
0?l000001_oooolBo`0000gooooo0_l00009ooooo`;o0000D?ooool001cooooo00?o0000oooooooo
ool0D_ooool2o`0000?ooooo0ol0000=ooooo`Go00002Oooool2o`0000?ooooo0_l0000Mooooo`Ko
00001?ooool2o`0000Kooooo0_l0000@ooooo`;o00000oooool2o`000003ooooool0003o000000;o
oooo0_l00002oooooa;o00004Oooool3o`0000Cooooo0_l0001@ooooo`007?ooool00ol0003ooooo
ooooo`1Cooooo`;o00000_ooool3o`0000gooooo1Ol0000Xooooo`?o00000_ooool7o`0000?ooooo
0_l00007ooooo`;o00001_ooool2o`0000Oooooo0_l0000:ooooo`;o00001?ooool=o`0000;ooooo
0ol00004ooooo`;o00000_ooool4o`0000?ooooo1Ol0001Dooooo`007?ooool00ol0003ooooooooo
o`1<ooooo`;o00000oooool6o`0002Sooooo0_l0000Cooooo`co00003?ooool3o`0000Gooooo0_l0
000@ooooo`;o00001oooool3o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`00
0002ooooo`?o00001?ooool3o`000003ooooool0003o000000;o00001Oooool5o`0005;ooooo000L
ooooo`03o`000?oooooooooo04cooooo0_l00003ooooo`Ko0000:?ooool2o`0000Wooooo0_l00008
ooooo`So000000?oooooo`000?l000001?l00006ooooo`;o00000_ooool2o`0001Oooooo1?l00000
0ooooooo0000o`000002ooooo`?o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l00008
ooooo`;o00000_ooool2o`0000Kooooo0_l000000ooooooo0000o`00001Booooo`007?ooool00ol0
003oooooooooo`1<ooooo`;o00001Oooool4o`0001;ooooo0_l0000Oooooo`;o00001?ooool2o`00
00;ooooo2Ol000000ooooooo0000o`000005o`0000Cooooo0_l00002ooooo`;o00003Oooool2o`00
00Wooooo2?l000000ooooooo0000o`000002ooooo`Go00000oooool2o`0000_ooooo0ol0001Moooo
o`007?ooool00ol0003oooooooooo`1:ooooo`Co000000?oooooo`000?l000001?ooool2o`0001;o
oooo0ol0000Tooooo`Go000000?oooooo`000?l000003Ol0000Gooooo`;o00003?ooool2o`000003
ooooool0003o000000Wo00001?ooool2o`0000_ooooo0_l0001Nooooo`007?ooool00ol0003ooooo
ooooo`1:ooooo`Co000000?oooooo`000?l000001?ooool2o`0000[ooooo0_l00007ooooo`;o0000
7Oooool2o`0000Gooooo5ol000000ooooooo0000o`000002o`0000cooooo0_l0000Booooo`Co0000
00?oooooo`000?l000000_l000000ooooooo0000o`000002ooooo`?o00000oooool2o`000003oooo
ool0003o000006Cooooo000Looooo`03o`000?oooooooooo05Gooooo0_l0000:ooooo`;o00006ooo
ool2o`0000Wooooo0_l00005ooooo`?o00000_oooolBo`000003ooooool0003o000000;o00000_oo
ool2o`0000;ooooo0ol00003ooooo`;o00004_ooool2o`0000Sooooo0_l00002ooooo`Co00000_oo
ool2o`000003ooooool0003o000006Cooooo000Looooo`03o`000?oooooooooo05Cooooo0_l0000X
ooooo`;o00003_ooool;o`000003ooooool0003o000000oo00000oooool2o`0000;ooooo1Ol0000G
ooooo`;o00000oooool3o`000003ooooool0003o000000;ooooo1Ol00009ooooo`;o0000G_ooool0
01cooooo00?o0000ooooooooool0E?ooool2o`0000?ooooo0_l0000<ooooo`;o00009OoooolMo`00
00[ooooo0_l0000Gooooo`;o00000oooool3o`000003ooooool0003o000000;ooooo1Ol00009oooo
o`;o0000G_ooool001cooooo0_l0001Eooooo`;o00000oooool2o`0000Cooooo0_l00006ooooo`;o
00002?ooool3o`0001_ooooo7?l0000booooo`;o0000J_ooool001cooooo00?o0000ooooooooool0
Goooool2o`0000Kooooo0_l00008ooooo`?o00006ooooolNo`00033ooooo0_l0001Zooooo`007?oo
ool00ol0003oooooooooo`1Gooooo`;o00007Oooool2o`0001Kooooo7ol0000@ooooo`;o00007_oo
ool2o`0006[ooooo000Looooo`03o`000?oooooooooo05Oooooo0_l000000ooooooo0000o`000002
ooooo`?o00005Oooool2o`0001Gooooo0ol000000ooooooo0000o`00000Go`0001;ooooo0ol0002:
ooooo`007?ooool00ol0003oooooooooo`1Gooooo`;o000000?oooooo`000?l000000_ooool9o`00
00Gooooo1?l0000Mooooo`Oo000000?oooooo`000?l000004_l000001?oooooo0000o`000?l00008
ooooo`;o00001Oooool2o`0008_ooooo000Looooo`03o`000?oooooooooo05kooooo2Ol00005oooo
o`Co00007?ooool8o`000003ooooool0003o000000Wo000000?oooooo`000?l000002_l00008oooo
o`;o0000T_ooool001cooooo00?o0000ooooooooool0Eoooool5o`0000_ooooo0_l000000ooooooo
0000o`00000Pooooo`Oo00000_ooool@o`000003ooooool0003o000000;o0000Woooool001cooooo
00?o0000ooooooooool0Eoooool6o`0000?ooooo0_l00002ooooo`So00008?oooolIo`000003oooo
ool0003o00000:7ooooo000Looooo`03o`000?oooooooooo053ooooo0_l00008ooooo`?o00000ooo
ool7o`000003ooooool0003o000001gooooo0_l00003ooooo`?o000000?oooooo`000?l000006?l0
000Eooooo`;o0000R?ooool001cooooo00?o0000ooooooooool0D?ooool2o`0000Sooooo0_l00003
ooooo`So000000Coooooo`000?l0003ooooo0_l0000Jooooo`;o00001ooooolMo`0001;ooooo0_l0
0028ooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00003Oooool5o`0000Cooooo1Ol0000K
ooooo`;o00001ooooolGo`0000;ooooo0ol0000=ooooo`;o0000SOooool001cooooo00?o0000oooo
ooooool0Eoooool2o`0000Wooooo0_l00005ooooo`;o00007Oooool2o`0000Kooooo6?l00002oooo
o`;o00003_ooool2o`0000Cooooo0_l00027ooooo`007?ooool00ol0003oooooooooo`1Gooooo`;o
00001_ooool2o`0000Sooooo0_l0000Mooooo`;o00000_ooool2o`0000;ooooo5ol00004ooooo`;o
00004oooool2o`0000?ooooo0_l00022ooooo`007?ooool00ol0003oooooooooo`1Oooooo`Co0000
:Oooool2o`000003ooooool0003o000001Ko00001?ooool2o`0001Sooooo0_l0000hooooo`;o0000
B?ooool001cooooo00?o0000ooooooooool0Doooool2o`0000[ooooo1?l0000/oooooaSo000000?o
ooooo`000?l00000EOooool2o`0004Sooooo000Looooo`03o`000?oooooooooo04kooooo0_l00003
ooooo`;o00002Oooool3o`0002kooooo5_l00003ooooo`;o0000D_ooool2o`0004_ooooo000Loooo
o`;o0000Coooool3o`0000gooooo0ol0000?ooooo`;o00007_ooool2o`000003ooooool0003o0000
013o0000Eoooool2o`0004_ooooo000Looooo`03o`000?oooooooooo04oooooo0_l0000Oooooo`;o
00008_ooool@o`0000;ooooo0_l0000?ooooo`;o00002?ooool2o`0008Kooooo000Looooo`03o`00
0?oooooooooo06;ooooo0_l0000Vooooo`;o00000_ooool2o`000004ooooool0003o0000o`0000Co
oooo2_l000000ooooooo0000o`000003o`0000;ooooo0_l0000;ooooo`;o00002?ooool2o`000003
ooooool0003o000000?ooooo0_l0001nooooo`007?ooool00ol0003oooooooooo`1Rooooo`;o0000
9_ooool2o`000003ooooool0003o000000Oo000000?oooooo`000?l000002Ol000001?oooooo0000
o`000?l00004ooooo`;o00006?ooool2o`0000?ooooo0_l0001nooooo`007?ooool00ol0003ooooo
ooooo`1Aooooo`;o00003?ooool2o`0002cooooo1Ol00002ooooo`Go000000?oooooo`000?l00000
2Ol0000:ooooo`;o0000V?ooool001cooooo00?o0000ooooooooool0DOooool2o`0000cooooo0_l0
000]ooooo`;o00001Oooool2o`0000Gooooo2Ol000000ooooooo0000o`000007ooooo`Co00006?oo
ool2o`0007cooooo000Looooo`03o`000?oooooooooo08kooooo0_l00005ooooo`;o00001Oooool4
o`0000?ooooo0_l000000ooooooo0000o`000007ooooo`Co00000_ooool2o`0001Cooooo0_l0001l
ooooo`007?ooool00ol0003oooooooooo`2Looooo`?o00001?ooool2o`0000Cooooo0_l00005oooo
o`;o00000oooool2o`0009;ooooo000Looooo`03o`000?oooooooooo06?ooooo0_l0000]ooooo`Co
00003oooool6o`0000;ooooo0ol00002ooooo`;o0000UOooool001cooooo00?o0000ooooooooool0
Hoooool4o`0002_ooooo1?l00008ooooo`;o00001?ooool5o`0000Cooooo0ol00002ooooo`;o0000
UOooool001cooooo00?o0000ooooooooool0I?ooool3o`0003Oooooo0_l00004ooooo`;o00000ooo
ool2o`0009kooooo000Looooo`03o`000?oooooooooo09[ooooo0_l0000=ooooo`;o0000W_ooool0
01cooooo00?o0000ooooooooool0Koooool2o`00023ooooo0_l00006ooooo`?o00003_ooool2o`00
04Kooooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`1_ooooo`;o00001Oooool2o`0001Wo
oooo0_l00006ooooo`;o00003oooool2o`0004Kooooo0_l0001Eooooo`0000Koooooonk^k_lb<S;o
0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000
ooooooooool0M_ooool2o`000=7ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ
8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2Qooooo`;o0000
1?ooool2o`000:3ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo09oooooo1?l00004ooooo`;o0000
0oooool2o`0009_ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go
<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000K?ooool2o`000003ooooool0003o000002kooooo
0_l000000ooooooo0000o`000002ooooo`;o00001?ooool2o`0009_ooooo00000ooooooo0000oooo
o`02ooooo`03o`000?oooooooooo00Wooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`00
0?oooooooooo06cooooo0_l000000ooooooo0000o`00000aooooo`Ko00001_ooool2o`0002Gooooo
0_l0001booooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj
^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`2Tooooo`?o00001oooool2o`0002?ooooo
1?l0001booooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj
^_l000001_ooool00ol0003oooooooooo`1Zooooo`;o0000@_ooool2o`0002?ooooo0_l0000Eoooo
o`;o0000GOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@
413oZJVY00Kooooo00?o0000ooooooooool0J_ooool3o`0000Cooooo0_l0001Mooooo`?o00005ooo
ool2o`0005gooooo000Looooo`03o`000?oooooooooo06_ooooo0_l00004ooooo`;o00009oooool2
o`0003Cooooo0ol0001fooooo`007?ooool00ol0003oooooooooo`1jooooo`;o00007_ooool2o`00
00?ooooo0_l0002Xooooo`007?ooool00ol0003oooooooooo`1hooooo`Co00008oooool2o`000:So
oooo000Looooo`03o`000?oooooooooo06Kooooo0_l00008ooooo`;o00001_ooool3o`0000Cooooo
0_l00038ooooo`007?ooool00ol0003oooooooooo`1Vooooo`;o00002?ooool2o`0000Wooooo0_l0
0002ooooo`;o0000:Oooool2o`0001_ooooo0ol0001oooooo`007?ooool00ol0003oooooooooo`1k
ooooo`;o00002?ooool2o`0001Sooooo0_l000000ooooooo0000o`000006ooooo`;o00006oooool3
o`0001Oooooo0_l0001Vooooo`007?ooool00ol0003oooooooooo`1Yooooo`;o00006_ooool2o`00
01Sooooo0_l000000ooooooo0000o`000004ooooo`;o00004oooool2o`000003ooooool0003o0000
01oooooo0_l0001Vooooo`007?ooool00ol0003oooooooooo`1Yooooo`;o0000?Oooool2o`0000Ko
oooo0_l00008ooooo`;o000000Coooooo`000?l0003ooooo0_l00027ooooo`007?ooool00ol0003o
ooooooooo`2Looooo`;o00004_ooool2o`0000Sooooo0_l0000Pooooo`;o0000Joooool001cooooo
00?o0000ooooooooool0W?ooool4o`0003cooooo0_l0001[ooooo`007?ooool00ol0003ooooooooo
o`29ooooo`;o00004?ooool2o`000003ooooool0003o00000:Wooooo000Looooo`;o0000L?ooool2
o`0001Sooooo0_l00005ooooo`;o00002Oooool2o`0003[ooooo0_l0001`ooooo`007?ooool00ol0
003oooooooooo`1_ooooo`;o00003_ooool2o`0000oooooo1?l00013ooooo`;o0000L?ooool001co
oooo00?o0000ooooooooool0Ooooool2o`0000_ooooo0_l00004ooooo`;o0000]Oooool001cooooo
00?o0000ooooooooool0S?ooool4o`0000[ooooo0_l0002]ooooo`007?ooool00ol0003ooooooooo
o`26ooooo`;o00001_ooool4o`0000Sooooo0_l0000dooooo`;o0000Moooool001cooooo00?o0000
ooooooooool0Q_ooool4o`0000Kooooo0_l000000ooooooo0000o`00000kooooo`;o0000Moooool0
01cooooo00?o0000ooooooooool0R?ooool2o`0000Wooooo0_l0002dooooo`007?ooool00ol0003o
ooooooooo`2=ooooo`;o00001_ooool2o`0003;ooooo0_l0001nooooo`007?ooool00ol0003ooooo
ooooo`2=ooooo`;o00001_ooool2o`000003ooooool0003o000002gooooo1?l0001nooooo`007?oo
ool00ol0003oooooooooo`2Hooooo`;o0000;Oooool2o`00083ooooo000Looooo`03o`000?oooooo
oooo09[ooooo0_l0000Uooooo`;o0000Q_ooool001cooooo00?o0000ooooooooool0POooool2o`00
01Oooooo0_l0000Uooooo`;o0000Q_ooool001cooooo00?o0000ooooooooool0POooool2o`0001go
oooo0_l0002Wooooo`007?ooool00ol0003oooooooooo`2Pooooo`;o0000Yoooool001cooooo00?o
0000ooooooooool0V_ooool3o`0001_ooooo0ol0002>ooooo`007?ooool00ol0003oooooooooo`2J
ooooo`?o00006oooool3o`0008kooooo000Looooo`;o0000X_ooool2o`000:Kooooo000Looooo`03
o`000?oooooooooo0:7ooooo0_l0002Vooooo`007?ooool00ol0003oooooooooo`2/ooooo`Co0000
VOooool001cooooo00?o0000ooooooooool0[?ooool4o`0009Wooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Booooo`Co000000?o410@ooooooooool00oooool00ol0
003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`?o0000oooooom:ooooo`005?oo
ool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool0
01Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;o
oooo000Booooo`03oeEEEOmVIVKo00000?ooooooE?ooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00:Gooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0Goooo
o`;o000000?o410@ooooooooool00oooool2o`000003oa0@4?oooooooooo00?ooooo0_l000000ol@
413oooooooooo`2>ooooo`00Y_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l0000<oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2?oooo
o`00Y_ooool01Ol0003ooooooooooooooooo000001Sooooo1Ol00003ooooo`Go00000oooool5o`00
093ooooo002Vooooo`05o`000?ooooooooooooooool000002Oooool6o`0000Wooooo00CoA4A4omgM
gOoooooo00001?ooool01?m4A4CogMgMooooool00004ooooo`04odA4A?oMgMgoooooo`00097ooooo
002Vooooo`05o`000?n7QhOoooooojVYZOl000006?ooool01?oMgMgoEEEEooooool00004ooooo`04
omgMgOmEEEGoooooo`0000Cooooo00CogMgMoeEEEOoooooo0000TOooool00:Gooooo00?o410@o`00
0?mgMgL00_l000000onHV9Soooooooooo`0Gooooo`03ogMgMoo<c<co000000Gooooo00?oMgMgolc<
c?l000001Oooool00omgMgOoc<c<o`00002Aooooo`00a?ooool00oo^k^koA4A4o`000005ooooo`03
onk^k_m4A4Co000000Gooooo00?ok^k^odA4A?l00000TOooool00<Gooooo00?oMgMgo`000?ooool0
1Oooool00omgMgOo0000ooooo`05ooooo`03ogMgMol0003ooooo093ooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(450) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.40418 .32109 Mdot
.40749 .34672 Mdot
.49129 .72589 Mdot
.57824 .44286 Mdot
.61457 .67182 Mdot
.44729 .71388 Mdot
.32472 .5837 Mdot
.32995 .57697 Mdot
.44699 .69893 Mdot
.48213 .26462 Mdot
.29198 .57494 Mdot
.62407 .37687 Mdot
.31012 .57782 Mdot
.61375 .43754 Mdot
.45005 .43627 Mdot
.57927 .4897 Mdot
.41982 .3846 Mdot
.65726 .6366 Mdot
.56145 .47467 Mdot
.48812 .69589 Mdot
.75122 .40955 Mdot
.62679 .44031 Mdot
.45581 .35453 Mdot
.61772 .43719 Mdot
.60938 .40565 Mdot
.42067 .35771 Mdot
.4082 .31836 Mdot
.62448 .40861 Mdot
.65529 .40128 Mdot
.29722 .57025 Mdot
.52305 .69565 Mdot
.66402 .21721 Mdot
.6279 .48104 Mdot
.6266 .25662 Mdot
.33105 .58325 Mdot
.36417 .55162 Mdot
.48268 .7061 Mdot
.2799 .59268 Mdot
.33405 .58186 Mdot
.33072 .59419 Mdot
.31295 .60048 Mdot
.42755 .36205 Mdot
.32894 .60431 Mdot
.34785 .77135 Mdot
.5971 .43035 Mdot
.44209 .42065 Mdot
.2743 .71918 Mdot
.63974 .40483 Mdot
.40859 .37155 Mdot
.49065 .69167 Mdot
.7393 .63584 Mdot
.279 .56232 Mdot
.3742 .47316 Mdot
.58791 .89022 Mdot
.29983 .58176 Mdot
.57391 .41535 Mdot
.44645 .68676 Mdot
.61191 .45963 Mdot
.57376 .44943 Mdot
.59918 .22736 Mdot
.63554 .45524 Mdot
.64852 .67649 Mdot
.46295 .38278 Mdot
.42295 .71007 Mdot
.44239 .7039 Mdot
.27984 .59084 Mdot
.46536 .35559 Mdot
.31394 .56792 Mdot
.66331 .41749 Mdot
.49522 .71068 Mdot
.65202 .40099 Mdot
.29478 .569 Mdot
.44713 .32834 Mdot
.5976 .42722 Mdot
.31642 .47256 Mdot
.23353 .60627 Mdot
.46216 .76842 Mdot
.70886 .30745 Mdot
.75889 .6775 Mdot
.51884 .64414 Mdot
.6176 .42556 Mdot
.59953 .84264 Mdot
.46819 .50187 Mdot
.40487 .33866 Mdot
.41488 .29088 Mdot
.32322 .3128 Mdot
.63678 .40785 Mdot
.46776 .61648 Mdot
.56721 .46484 Mdot
.6022 .60266 Mdot
.45724 .68829 Mdot
.4137 .33047 Mdot
.60276 .42701 Mdot
.65041 .46582 Mdot
.40843 .25081 Mdot
.61581 .38783 Mdot
.58007 .43538 Mdot
.39164 .28764 Mdot
.28733 .57781 Mdot
.67943 .49004 Mdot
.70388 .67527 Mdot
.37907 .49943 Mdot
.58723 .4054 Mdot
.47228 .71024 Mdot
.45499 .39185 Mdot
.5803 .42795 Mdot
.32348 .56987 Mdot
.62203 .42969 Mdot
.34154 .56727 Mdot
.44264 .38028 Mdot
.6344 .47617 Mdot
.65648 .64723 Mdot
.66188 .52697 Mdot
.44881 .36211 Mdot
.6315 .32475 Mdot
.6377 .44692 Mdot
.62431 .46391 Mdot
.40621 .35181 Mdot
.48962 .71639 Mdot
.39954 .72794 Mdot
.45552 .34455 Mdot
.33222 .59304 Mdot
.40911 .37754 Mdot
.55851 .40438 Mdot
.4887 .70838 Mdot
.37159 .49221 Mdot
.37221 .4991 Mdot
.67512 .57946 Mdot
.60774 .42304 Mdot
.63644 .53798 Mdot
.46314 .71244 Mdot
.41887 .36392 Mdot
.30589 .56993 Mdot
.56542 .41875 Mdot
.44277 .35631 Mdot
.33063 .5667 Mdot
.62475 .67835 Mdot
.62318 .63568 Mdot
.42567 .3732 Mdot
.54006 .36388 Mdot
.33268 .5419 Mdot
.32411 .602 Mdot
.73684 .63361 Mdot
.40354 .34091 Mdot
.6515 .65862 Mdot
.32146 .55535 Mdot
.76786 .50939 Mdot
.57695 .4618 Mdot
.70284 .61049 Mdot
.52454 .84604 Mdot
.73887 .63606 Mdot
.658 .23336 Mdot
.65554 .64985 Mdot
.33002 .56242 Mdot
.64507 .39907 Mdot
.43198 .3468 Mdot
.43776 .35929 Mdot
.65569 .45356 Mdot
.59743 .41734 Mdot
.59716 .43894 Mdot
.56937 .44871 Mdot
.31384 .64143 Mdot
.60913 .42653 Mdot
.20049 .4644 Mdot
.44077 .34791 Mdot
.59344 .41256 Mdot
.47587 .72753 Mdot
.67974 .47876 Mdot
.29933 .60343 Mdot
.575 .44893 Mdot
.60274 .41298 Mdot
.58261 .39491 Mdot
.33707 .5867 Mdot
.29152 .47496 Mdot
.79676 .63711 Mdot
.36215 .58013 Mdot
.23636 .57741 Mdot
.4559 .72319 Mdot
.64719 .44769 Mdot
.6362 .6536 Mdot
.67966 .48576 Mdot
.59078 .46487 Mdot
.74303 .64089 Mdot
.61891 .41602 Mdot
.68501 .26374 Mdot
.64846 .37551 Mdot
.32003 .3252 Mdot
.21374 .4119 Mdot
.58588 .46422 Mdot
.51962 .29148 Mdot
.68674 .60209 Mdot
.48816 .7828 Mdot
.30056 .57137 Mdot
.46713 .73915 Mdot
.48729 .72547 Mdot
.27656 .59102 Mdot
.67244 .36206 Mdot
.50006 .26583 Mdot
.63716 .38837 Mdot
.37601 .49515 Mdot
.46368 .32016 Mdot
.65791 .65548 Mdot
.4221 .37336 Mdot
.63839 .82268 Mdot
.53381 .63564 Mdot
.47694 .62177 Mdot
.64751 .62715 Mdot
.47693 .67615 Mdot
.37701 .48291 Mdot
.6455 .65501 Mdot
.58888 .44964 Mdot
.43187 .38051 Mdot
.7009 .61385 Mdot
.66296 .4907 Mdot
.25956 .25533 Mdot
.41946 .31877 Mdot
.61913 .55708 Mdot
.30194 .57888 Mdot
.43191 .735 Mdot
.63604 .4077 Mdot
.61237 .45104 Mdot
.46984 .35604 Mdot
.65131 .40608 Mdot
.47863 .59571 Mdot
.60671 .41376 Mdot
.42439 .70634 Mdot
.59296 .68095 Mdot
.33565 .60868 Mdot
.66119 .62969 Mdot
.45222 .33455 Mdot
.21693 .59459 Mdot
.47626 .71542 Mdot
.71116 .43329 Mdot
.30743 .56145 Mdot
.62306 .67291 Mdot
.47631 .70166 Mdot
.66349 .64977 Mdot
.62187 .47564 Mdot
.48007 .69786 Mdot
.65617 .67298 Mdot
.44774 .56166 Mdot
.57822 .43147 Mdot
.70755 .55944 Mdot
.29779 .54994 Mdot
.39885 .3393 Mdot
.61041 .46958 Mdot
.38484 .46524 Mdot
.56073 .41323 Mdot
.55397 .53344 Mdot
.38792 .46743 Mdot
.39931 .48803 Mdot
.49308 .61355 Mdot
.6426 .69072 Mdot
.32902 .49943 Mdot
.45274 .59045 Mdot
.4208 .38498 Mdot
.62579 .47361 Mdot
.36268 .40848 Mdot
.30217 .5475 Mdot
.59332 .45345 Mdot
.33296 .37108 Mdot
.32271 .55596 Mdot
.61445 .46296 Mdot
.31173 .59942 Mdot
.4378 .35386 Mdot
.45978 .5332 Mdot
.39542 .3597 Mdot
.58192 .44865 Mdot
.30061 .5953 Mdot
.47232 .73696 Mdot
.42132 .35731 Mdot
.62606 .43309 Mdot
.6299 .42398 Mdot
.38057 .49432 Mdot
.59176 .42408 Mdot
.3411 .32027 Mdot
.63673 .40453 Mdot
.49464 .69525 Mdot
.63621 .39003 Mdot
.71384 .66261 Mdot
.67511 .62666 Mdot
.45903 .37093 Mdot
.38968 .46802 Mdot
.46121 .68498 Mdot
.45409 .54137 Mdot
.68611 .55248 Mdot
.61442 .42903 Mdot
.39277 .47909 Mdot
.60775 .55892 Mdot
.29708 .60167 Mdot
.65381 .4795 Mdot
.42015 .64066 Mdot
.46199 .68966 Mdot
.37504 .49085 Mdot
.64215 .4987 Mdot
.41824 .31061 Mdot
.58786 .4025 Mdot
.4812 .70699 Mdot
.39602 .34138 Mdot
.59987 .39019 Mdot
.24566 .66408 Mdot
.3844 .46493 Mdot
.29007 .58932 Mdot
.37541 .29366 Mdot
.65267 .44804 Mdot
.48318 .73297 Mdot
.44105 .36228 Mdot
.30631 .59035 Mdot
.45296 .35655 Mdot
.70138 .62096 Mdot
.55866 .52801 Mdot
.37967 .59669 Mdot
.67637 .6672 Mdot
.80443 .35166 Mdot
.36165 .54907 Mdot
.68369 .48593 Mdot
.50792 .71754 Mdot
.28552 .29108 Mdot
.47341 .70324 Mdot
.52321 .37271 Mdot
.45186 .68702 Mdot
.60957 .39491 Mdot
.44506 .71086 Mdot
.35927 .24817 Mdot
.62855 .414 Mdot
.43737 .71442 Mdot
.37103 .63448 Mdot
.62936 .41667 Mdot
.44504 .35453 Mdot
.53376 .16171 Mdot
.68178 .32148 Mdot
.68365 .34025 Mdot
.43882 .69078 Mdot
.54333 .35477 Mdot
.62894 .409 Mdot
.55697 .46895 Mdot
.42712 .34734 Mdot
.58632 .38923 Mdot
.6598 .68878 Mdot
.66798 .65963 Mdot
.75694 .57191 Mdot
.74848 .34654 Mdot
.66974 .35465 Mdot
.42839 .35779 Mdot
.7515 .69402 Mdot
.3159 .46696 Mdot
.38279 .46565 Mdot
.33073 .57305 Mdot
.29306 .48883 Mdot
.60897 .49668 Mdot
.46611 .29808 Mdot
.47593 .5863 Mdot
.41678 .32612 Mdot
.40571 .57627 Mdot
.31253 .59092 Mdot
.6824 .33419 Mdot
.49713 .24556 Mdot
.59503 .4398 Mdot
.2809 .56842 Mdot
.60487 .37568 Mdot
.46239 .60499 Mdot
.69352 .57776 Mdot
.31145 .70944 Mdot
.58289 .44521 Mdot
.3354 .48388 Mdot
.59459 .4657 Mdot
.68212 .58435 Mdot
.59095 .45471 Mdot
.45045 .35108 Mdot
.54739 .44711 Mdot
.4475 .58476 Mdot
.80622 .42662 Mdot
.53059 .62498 Mdot
.66113 .67589 Mdot
.61389 .44034 Mdot
.59941 .44745 Mdot
.64989 .67831 Mdot
.41758 .32856 Mdot
.62632 .4717 Mdot
.25316 .70901 Mdot
.60999 .42555 Mdot
.2748 .56837 Mdot
.52108 .55158 Mdot
.72382 .28366 Mdot
.64774 .42404 Mdot
.42439 .31087 Mdot
.31392 .6025 Mdot
.31263 .556 Mdot
.56818 .36513 Mdot
.29259 .5521 Mdot
.6482 .40102 Mdot
.51989 .5507 Mdot
.45439 .36767 Mdot
.66379 .38365 Mdot
.4241 .32648 Mdot
.74049 .70509 Mdot
.32241 .55381 Mdot
.3957 .47504 Mdot
.64616 .33574 Mdot
.32173 .58012 Mdot
.59535 .62821 Mdot
.54801 .44777 Mdot
.66697 .47753 Mdot
.37053 .31104 Mdot
.47263 .73928 Mdot
.38884 .47415 Mdot
.3006 .58457 Mdot
.60551 .42825 Mdot
.58282 .41336 Mdot
.28335 .55917 Mdot
.54752 .19723 Mdot
.5231 .70021 Mdot
.58116 .44967 Mdot
.44657 .3419 Mdot
.42137 .36383 Mdot
.56414 .4462 Mdot
.60278 .46859 Mdot
.4468 .72858 Mdot
.39307 .47787 Mdot
.39102 .47081 Mdot
.37648 .50199 Mdot
.42788 .7132 Mdot
.80679 .36915 Mdot
.32369 .60235 Mdot
.68093 .23413 Mdot
.31809 .41961 Mdot
.5446 .38524 Mdot
.48422 .72232 Mdot
.62262 .45415 Mdot
.60297 .39897 Mdot
.2977 .59202 Mdot
.79456 .39384 Mdot
.55248 .45245 Mdot
.40319 .32613 Mdot
.27804 .56605 Mdot
.60869 .37871 Mdot
.31724 .53189 Mdot
.63283 .64503 Mdot
.66598 .34434 Mdot
.2893 .55307 Mdot
.449 .37353 Mdot
.28852 .55355 Mdot
.59806 .44473 Mdot
.64496 .49862 Mdot
.41722 .32494 Mdot
.62061 .64493 Mdot
.64861 .46294 Mdot
.61155 .46395 Mdot
.47777 .80896 Mdot
.31929 .4733 Mdot
.65221 .61708 Mdot
.62737 .39787 Mdot
.67625 .46798 Mdot
.62894 .63661 Mdot
.64409 .46236 Mdot
.63496 .39105 Mdot
.64818 .5373 Mdot
.34348 .5706 Mdot
.63889 .69396 Mdot
.80209 .42529 Mdot
.41661 .31883 Mdot
.34114 .33833 Mdot
.37489 .4979 Mdot
.28397 .60682 Mdot
.45564 .52342 Mdot
.38122 .48367 Mdot
.31882 .39734 Mdot
.19341 .57111 Mdot
.38908 .47676 Mdot
.42406 .72141 Mdot
.49514 .31984 Mdot
.64684 .39432 Mdot
.58627 .4587 Mdot
.64432 .6901 Mdot
.40356 .35551 Mdot
.20593 .45524 Mdot
.33793 .60948 Mdot
.63199 .44544 Mdot
.40227 .31791 Mdot
.32078 .31749 Mdot
.37703 .48926 Mdot
.63869 .64862 Mdot
.61518 .65815 Mdot
.60244 .46725 Mdot
.65385 .56534 Mdot
.42591 .35929 Mdot
.62601 .43316 Mdot
.63317 .46331 Mdot
.46522 .68055 Mdot
.42866 .3801 Mdot
.474 .7267 Mdot
.39878 .46842 Mdot
.26653 .29031 Mdot
.39317 .82242 Mdot
.3024 .54927 Mdot
.41767 .51503 Mdot
.32646 .6111 Mdot
.27501 .6849 Mdot
.39312 .4765 Mdot
.62662 .43625 Mdot
.45929 .3474 Mdot
.6239 .43054 Mdot
.60706 .42595 Mdot
.58825 .43673 Mdot
.67055 .35469 Mdot
.74122 .69305 Mdot
.62876 .66756 Mdot
.65742 .42706 Mdot
.43363 .69453 Mdot
.32587 .34155 Mdot
.39023 .22997 Mdot
.61026 .44489 Mdot
.62288 .46408 Mdot
.46457 .34695 Mdot
.60939 .47654 Mdot
.3274 .57547 Mdot
.40827 .32723 Mdot
.58053 .41227 Mdot
.70541 .68112 Mdot
.62523 .47089 Mdot
.40788 .5302 Mdot
.30016 .54467 Mdot
.59253 .50882 Mdot
.67053 .45671 Mdot
.39366 .47545 Mdot
.38801 .47484 Mdot
.39705 .45965 Mdot
.27667 .57574 Mdot
.46491 .68141 Mdot
.42058 .73242 Mdot
.66716 .45692 Mdot
.64212 .40098 Mdot
.65444 .49239 Mdot
.4848 .67455 Mdot
.44303 .60072 Mdot
.49405 .39237 Mdot
.62492 .3721 Mdot
.4317 .719 Mdot
.38604 .28922 Mdot
.73624 .35709 Mdot
.40392 .33112 Mdot
.50704 .71327 Mdot
.31788 .56213 Mdot
.66123 .65261 Mdot
.74599 .60446 Mdot
.4544 .34661 Mdot
.45133 .32759 Mdot
.44868 .72399 Mdot
.50571 .5256 Mdot
.65626 .86429 Mdot
.46701 .70779 Mdot
.47733 .6164 Mdot
.42674 .35087 Mdot
.60166 .47877 Mdot
.59523 .55779 Mdot
.49992 .51041 Mdot
.437 .70748 Mdot
.62917 .42429 Mdot
.57063 .66235 Mdot
.44622 .72808 Mdot
.63573 .48901 Mdot
.4374 .69179 Mdot
.28485 .58129 Mdot
.46603 .71592 Mdot
.38771 .33053 Mdot
.61459 .42254 Mdot
.60681 .88462 Mdot
.4622 .49711 Mdot
.63429 .43467 Mdot
.28546 .5548 Mdot
.33953 .64897 Mdot
.59265 .44574 Mdot
.664 .68055 Mdot
.42987 .69899 Mdot
.29313 .70098 Mdot
.61438 .39133 Mdot
.44274 .71474 Mdot
.3869 .3208 Mdot
.50231 .6884 Mdot
.7008 .67077 Mdot
.38975 .4722 Mdot
.43748 .35054 Mdot
.35372 .4991 Mdot
.32335 .59958 Mdot
.55729 .44499 Mdot
.63808 .45972 Mdot
.44121 .3431 Mdot
.44829 .54867 Mdot
.59663 .36019 Mdot
.61617 .42596 Mdot
.45816 .73088 Mdot
.45967 .67206 Mdot
.45432 .43169 Mdot
.47798 .71277 Mdot
.677 .4659 Mdot
.4452 .34745 Mdot
.58104 .40825 Mdot
.44234 .36563 Mdot
.62886 .47324 Mdot
.25404 .56095 Mdot
.4018 .33808 Mdot
.70785 .46406 Mdot
.61085 .42127 Mdot
.36439 .35063 Mdot
.65323 .44474 Mdot
.58219 .44133 Mdot
.44869 .67487 Mdot
.63884 .6696 Mdot
.6432 .48154 Mdot
.23549 .61237 Mdot
.63172 .63861 Mdot
.60117 .20349 Mdot
.48846 .70862 Mdot
.61801 .66868 Mdot
.74756 .55924 Mdot
.38917 .46823 Mdot
.64061 .67889 Mdot
.40812 .48198 Mdot
.29434 .55377 Mdot
.39421 .37065 Mdot
.62679 .41759 Mdot
.28763 .27622 Mdot
.52259 .6903 Mdot
.38522 .49222 Mdot
.6178 .46841 Mdot
.61778 .45551 Mdot
.4054 .31705 Mdot
.62682 .82885 Mdot
.42726 .68835 Mdot
.5768 .4358 Mdot
.45217 .33739 Mdot
.56963 .84749 Mdot
.43645 .7147 Mdot
.62606 .66541 Mdot
.33105 .55502 Mdot
.47339 .34085 Mdot
.39573 .4726 Mdot
.32502 .55599 Mdot
.47304 .76557 Mdot
.7455 .64373 Mdot
.60101 .39504 Mdot
.48049 .72501 Mdot
.73948 .63698 Mdot
.66108 .37994 Mdot
.28619 .60147 Mdot
.26929 .53604 Mdot
.41192 .33294 Mdot
.28213 .56037 Mdot
.65179 .68903 Mdot
.42708 .38418 Mdot
.42088 .32625 Mdot
.32735 .56998 Mdot
.21841 .38172 Mdot
.60294 .55721 Mdot
.26934 .56872 Mdot
.55296 .53646 Mdot
.73832 .63762 Mdot
.39533 .48513 Mdot
.64098 .64797 Mdot
.69802 .72297 Mdot
.42526 .36113 Mdot
.29303 .48703 Mdot
.74051 .63653 Mdot
.5799 .43545 Mdot
.65825 .67156 Mdot
.33278 .3436 Mdot
.30049 .61878 Mdot
.32885 .56341 Mdot
.41482 .75532 Mdot
.66299 .66524 Mdot
.60083 .47209 Mdot
.74559 .30096 Mdot
.64115 .4221 Mdot
.31638 .55143 Mdot
.47727 .5905 Mdot
.43245 .3792 Mdot
.30375 .60522 Mdot
.47904 .59668 Mdot
.61013 .39668 Mdot
.64078 .4428 Mdot
.61953 .70972 Mdot
.41796 .37964 Mdot
.39987 .47537 Mdot
.62562 .42643 Mdot
.61032 .46095 Mdot
.55919 .44489 Mdot
.77214 .40573 Mdot
.69864 .49549 Mdot
.57498 .42577 Mdot
.4436 .74497 Mdot
.67082 .49101 Mdot
.57109 .44978 Mdot
.41287 .31071 Mdot
.71594 .68905 Mdot
.39954 .46862 Mdot
.58815 .45896 Mdot
.58175 .45056 Mdot
.33323 .58454 Mdot
.60428 .55798 Mdot
.49612 .5062 Mdot
.48554 .68153 Mdot
.42105 .75724 Mdot
.65646 .39474 Mdot
.43496 .34346 Mdot
.65472 .69357 Mdot
.67987 .42605 Mdot
.40822 .32317 Mdot
.664 .44315 Mdot
.43846 .68611 Mdot
.38998 .47964 Mdot
.65664 .37157 Mdot
.64853 .67329 Mdot
.34094 .55293 Mdot
.64093 .22267 Mdot
.46786 .73669 Mdot
.62076 .40359 Mdot
.41749 .73024 Mdot
.45832 .69939 Mdot
.38332 .49493 Mdot
.64202 .50337 Mdot
.4359 .35631 Mdot
.44487 .37501 Mdot
.73514 .68371 Mdot
.42655 .71373 Mdot
.50526 .80851 Mdot
.28319 .57569 Mdot
.65781 .43336 Mdot
.38839 .4318 Mdot
.43953 .37698 Mdot
.67819 .5803 Mdot
.61634 .66286 Mdot
.32758 .56212 Mdot
.37822 .50672 Mdot
.40123 .33609 Mdot
.43713 .37514 Mdot
.60191 .42776 Mdot
.62083 .44486 Mdot
.47598 .77545 Mdot
.69099 .60265 Mdot
.31328 .59893 Mdot
.62764 .6546 Mdot
.49591 .70196 Mdot
.62655 .39473 Mdot
.40783 .33683 Mdot
.73114 .29294 Mdot
.65217 .44817 Mdot
.43443 .69354 Mdot
.40963 .34575 Mdot
.62783 .6747 Mdot
.64066 .68637 Mdot
.58111 .43823 Mdot
.69854 .2796 Mdot
.32178 .57732 Mdot
.44691 .35369 Mdot
.38762 .29647 Mdot
.65443 .41667 Mdot
.61467 .44355 Mdot
.56703 .38418 Mdot
.30179 .60722 Mdot
.65545 .37516 Mdot
.64314 .63296 Mdot
.42386 .36877 Mdot
.62946 .43049 Mdot
.64773 .67713 Mdot
.46901 .30083 Mdot
.38417 .48458 Mdot
.43898 .71873 Mdot
.66554 .67578 Mdot
.64619 .6625 Mdot
.62645 .64437 Mdot
.29508 .48904 Mdot
.44662 .39773 Mdot
.82774 .54668 Mdot
.62259 .42206 Mdot
.73791 .63794 Mdot
.56279 .46014 Mdot
.28622 .59164 Mdot
.46042 .7415 Mdot
.59828 .43217 Mdot
.62305 .42186 Mdot
.66997 .25401 Mdot
.5743 .48712 Mdot
.56995 .48501 Mdot
.44186 .37919 Mdot
.36404 .31172 Mdot
.48273 .73167 Mdot
.49937 .84164 Mdot
.55336 .14908 Mdot
.63791 .3876 Mdot
.50801 .52934 Mdot
.40692 .33014 Mdot
.33502 .57558 Mdot
.56351 .54292 Mdot
.36111 .528 Mdot
.41226 .36473 Mdot
.61386 .39454 Mdot
.64067 .2267 Mdot
.65554 .64196 Mdot
.59822 .44048 Mdot
.30771 .56724 Mdot
.59764 .43975 Mdot
.27785 .58326 Mdot
.43969 .41265 Mdot
.4837 .502 Mdot
.62246 .41548 Mdot
.61995 .38833 Mdot
.62399 .53569 Mdot
.61406 .44538 Mdot
.32031 .69398 Mdot
.41581 .34292 Mdot
.71175 .44866 Mdot
.56192 .42587 Mdot
.66306 .29604 Mdot
.63411 .46552 Mdot
.44493 .5139 Mdot
.6426 .45029 Mdot
.78611 .42924 Mdot
.59072 .46954 Mdot
.64653 .44736 Mdot
.30855 .59374 Mdot
.33344 .5898 Mdot
.39269 .31159 Mdot
.39993 .48209 Mdot
.32141 .32939 Mdot
.6167 .46466 Mdot
.46613 .67029 Mdot
.49969 .4498 Mdot
.64118 .66482 Mdot
.42098 .36758 Mdot
.31355 .82086 Mdot
.30637 .60236 Mdot
.42495 .72073 Mdot
.4779 .62677 Mdot
.44762 .75065 Mdot
.50276 .72964 Mdot
.36099 .32853 Mdot
.64032 .6465 Mdot
.6195 .47131 Mdot
.63907 .26354 Mdot
.33158 .4763 Mdot
.65274 .41351 Mdot
.42299 .68375 Mdot
.52501 .46283 Mdot
.74325 .67361 Mdot
.67019 .66085 Mdot
.65219 .65027 Mdot
.30596 .58844 Mdot
.49067 .72553 Mdot
.61564 .37126 Mdot
.6183 .66908 Mdot
.46099 .74013 Mdot
.36872 .49767 Mdot
.65277 .72118 Mdot
.42933 .36064 Mdot
.55067 .35351 Mdot
.4118 .42966 Mdot
.30876 .60163 Mdot
.23439 .61001 Mdot
.39757 .38639 Mdot
.42316 .38809 Mdot
.39487 .4924 Mdot
.43285 .71177 Mdot
.39294 .37076 Mdot
.61136 .42339 Mdot
.66295 .49056 Mdot
.60294 .46771 Mdot
.63973 .68903 Mdot
.62533 .46751 Mdot
.44546 .7304 Mdot
.32476 .58919 Mdot
.46028 .68737 Mdot
.32341 .58554 Mdot
.59823 .18305 Mdot
.57564 .45358 Mdot
.61715 .44168 Mdot
.5171 .54716 Mdot
.43227 .37449 Mdot
.61824 .25614 Mdot
.43271 .69646 Mdot
.45006 .68548 Mdot
.57923 .41055 Mdot
.4618 .37099 Mdot
.60753 .61749 Mdot
.55452 .5454 Mdot
.63992 .45429 Mdot
.41601 .34173 Mdot
.57672 .41222 Mdot
.27411 .67221 Mdot
.46592 .47888 Mdot
.45255 .35897 Mdot
.80712 .42692 Mdot
.59538 .42552 Mdot
.63101 .51098 Mdot
.59861 .51747 Mdot
.76397 .42093 Mdot
.6128 .48199 Mdot
.41793 .31966 Mdot
.57219 .44577 Mdot
.42925 .34046 Mdot
.46472 .69869 Mdot
.32043 .60506 Mdot
.42845 .34336 Mdot
.63535 .4201 Mdot
.5625 .15328 Mdot
.32647 .58878 Mdot
.6038 .43599 Mdot
.29414 .58057 Mdot
.39622 .36908 Mdot
.41427 .3733 Mdot
.38573 .50643 Mdot
.47745 .619 Mdot
.32619 .5756 Mdot
.64356 .40181 Mdot
.30247 .47438 Mdot
.58297 .40654 Mdot
.41874 .75359 Mdot
.58454 .39537 Mdot
.66202 .40811 Mdot
.80501 .3459 Mdot
.44903 .53852 Mdot
.42652 .84357 Mdot
.29024 .62809 Mdot
.29434 .47187 Mdot
.4018 .29981 Mdot
.67006 .66099 Mdot
.41989 .5324 Mdot
.3838 .46894 Mdot
.44828 .74794 Mdot
.60143 .42985 Mdot
.36978 .26739 Mdot
.27121 .56866 Mdot
.63437 .66819 Mdot
.61926 .41581 Mdot
.47906 .7466 Mdot
.42534 .45035 Mdot
.32857 .56144 Mdot
.42853 .36271 Mdot
.41895 .37322 Mdot
.76609 .66754 Mdot
.63172 .4333 Mdot
.62457 .4419 Mdot
.32915 .58686 Mdot
.60205 .36894 Mdot
.62749 .64546 Mdot
.37822 .63242 Mdot
.30501 .56684 Mdot
.46761 .48654 Mdot
.43625 .3814 Mdot
.61995 .45496 Mdot
.52294 .55226 Mdot
.25628 .47113 Mdot
.43804 .24538 Mdot
.65715 .66115 Mdot
.66703 .56084 Mdot
.4185 .31942 Mdot
.30377 .57085 Mdot
.7505 .56826 Mdot
.55039 .44506 Mdot
.61605 .457 Mdot
.71517 .51387 Mdot
.55429 .54371 Mdot
.47225 .61746 Mdot
.55821 .39256 Mdot
.61189 .56987 Mdot
.58099 .40902 Mdot
.58352 .41246 Mdot
.66453 .41644 Mdot
.57386 .40519 Mdot
.41857 .33874 Mdot
.67477 .31756 Mdot
.45337 .71557 Mdot
.48542 .2823 Mdot
.43571 .77753 Mdot
.63129 .41074 Mdot
.61045 .39576 Mdot
.55811 .31083 Mdot
.52767 .51377 Mdot
.41914 .34982 Mdot
.38353 .30022 Mdot
.32546 .60028 Mdot
.56484 .4791 Mdot
.42697 .70818 Mdot
.56987 .50265 Mdot
.44967 .70044 Mdot
.41602 .33903 Mdot
.47735 .68753 Mdot
.30364 .53938 Mdot
.48067 .72416 Mdot
.43298 .72727 Mdot
.33062 .55942 Mdot
.40825 .37256 Mdot
.64791 .4499 Mdot
.32507 .55242 Mdot
.60184 .62436 Mdot
.63988 .68884 Mdot
.38342 .50778 Mdot
.5903 .47604 Mdot
.59774 .50089 Mdot
.24404 .66631 Mdot
.48033 .69557 Mdot
.49615 .49596 Mdot
.4015 .33999 Mdot
.6512 .69358 Mdot
.42175 .33767 Mdot
.79448 .60686 Mdot
.65245 .66776 Mdot
.38974 .50533 Mdot
.72949 .57396 Mdot
.35114 .59868 Mdot
.59331 .38802 Mdot
.37229 .30385 Mdot
.45265 .69689 Mdot
.27561 .56816 Mdot
.33104 .345 Mdot
.58685 .4252 Mdot
.36554 .48428 Mdot
.40781 .38556 Mdot
.38887 .4691 Mdot
.30755 .56956 Mdot
.40976 .49491 Mdot
.63525 .43798 Mdot
.34957 .60058 Mdot
.61324 .38724 Mdot
.60353 .33906 Mdot
.44801 .77389 Mdot
.4407 .28804 Mdot
.60139 .39637 Mdot
.43604 .71679 Mdot
.59283 .40014 Mdot
.51245 .34633 Mdot
.71727 .59725 Mdot
.65368 .39026 Mdot
.53673 .50166 Mdot
.26376 .69409 Mdot
.40959 .33527 Mdot
.67726 .45847 Mdot
.39093 .48982 Mdot
.61141 .40124 Mdot
.34751 .1879 Mdot
.64239 .67711 Mdot
.63654 .62201 Mdot
.63226 .41981 Mdot
.62282 .42802 Mdot
.68067 .26664 Mdot
.3854 .3849 Mdot
.3806 .50623 Mdot
.60732 .45616 Mdot
.73539 .48441 Mdot
.30504 .5915 Mdot
.59468 .39191 Mdot
.5816 .45664 Mdot
.49148 .79077 Mdot
.29934 .58895 Mdot
.48634 .71069 Mdot
.38801 .46814 Mdot
.47083 .67562 Mdot
.61284 .67741 Mdot
.63746 .5606 Mdot
.68648 .56826 Mdot
.45852 .46249 Mdot
.66292 .6786 Mdot
.63655 .41229 Mdot
.4416 .29135 Mdot
.63859 .43221 Mdot
.649 .65078 Mdot
.29697 .57044 Mdot
.41996 .34257 Mdot
.54128 .36258 Mdot
.3782 .49626 Mdot
.65137 .42074 Mdot
.6734 .6693 Mdot
.43198 .34849 Mdot
.21992 .48668 Mdot
.40324 .35038 Mdot
.32042 .58601 Mdot
.27677 .59087 Mdot
.64598 .6672 Mdot
.42015 .33692 Mdot
.47088 .67699 Mdot
.2694 .62082 Mdot
.61682 .38321 Mdot
.30225 .53922 Mdot
.38293 .35565 Mdot
.41455 .3149 Mdot
.4607 .36123 Mdot
.56629 .42205 Mdot
.53145 .53388 Mdot
.54712 .42637 Mdot
.3274 .58857 Mdot
.46689 .75008 Mdot
.70185 .60743 Mdot
.66313 .27284 Mdot
.47332 .4992 Mdot
.63749 .48375 Mdot
.62318 .46776 Mdot
.6039 .46742 Mdot
.57018 .42992 Mdot
.38022 .62612 Mdot
.57576 .45348 Mdot
.30367 .59654 Mdot
.45363 .70514 Mdot
.63457 .45688 Mdot
.39286 .4844 Mdot
.44625 .59985 Mdot
.64946 .69628 Mdot
.66397 .34031 Mdot
.35422 .3439 Mdot
.42992 .34762 Mdot
.48036 .71246 Mdot
.47645 .68497 Mdot
.62479 .67833 Mdot
.32024 .55076 Mdot
.40588 .35965 Mdot
.78433 .43639 Mdot
.64144 .63656 Mdot
.58891 .45908 Mdot
.51903 .54945 Mdot
.76741 .39092 Mdot
.65981 .44613 Mdot
.58617 .44023 Mdot
.40104 .4747 Mdot
.42753 .72681 Mdot
.33003 .23746 Mdot
.21281 .40185 Mdot
.64084 .66953 Mdot
.62346 .65849 Mdot
.4627 .34966 Mdot
.6587 .43493 Mdot
.32147 .57476 Mdot
.61782 .56154 Mdot
.24674 .65624 Mdot
.33176 .30892 Mdot
.27752 .68644 Mdot
.62748 .47036 Mdot
.6297 .31153 Mdot
.58395 .39455 Mdot
.45428 .39242 Mdot
.46238 .36485 Mdot
.42425 .35469 Mdot
.31127 .5923 Mdot
.74734 .64513 Mdot
.30056 .59635 Mdot
.35175 .31173 Mdot
.43389 .32298 Mdot
.45759 .56264 Mdot
.44638 .68614 Mdot
.56916 .47835 Mdot
.64251 .64651 Mdot
.63353 .59861 Mdot
.67424 .46442 Mdot
.659 .56148 Mdot
.48437 .72186 Mdot
.39726 .35601 Mdot
.56387 .46623 Mdot
.32071 .33776 Mdot
.50215 .52446 Mdot
.28005 .71663 Mdot
.38132 .26856 Mdot
.6515 .67655 Mdot
.49874 .2748 Mdot
.63634 .63921 Mdot
.32646 .56058 Mdot
.59163 .42767 Mdot
.65532 .44594 Mdot
.58103 .44387 Mdot
.56951 .41393 Mdot
.29916 .58343 Mdot
.62267 .38154 Mdot
.71437 .66291 Mdot
.36892 .49168 Mdot
.43124 .59269 Mdot
.64029 .68458 Mdot
.28256 .58071 Mdot
.45675 .70158 Mdot
.39426 .49457 Mdot
.67695 .66488 Mdot
.56173 .44543 Mdot
.63789 .42456 Mdot
.37037 .49741 Mdot
.64217 .36123 Mdot
.60508 .49547 Mdot
.44789 .71622 Mdot
.45867 .59948 Mdot
.62908 .68846 Mdot
.65607 .64828 Mdot
.28239 .56269 Mdot
.42169 .33734 Mdot
.62341 .6802 Mdot
.49022 .7292 Mdot
.60018 .39134 Mdot
.62651 .38854 Mdot
.38081 .34848 Mdot
.74182 .63919 Mdot
.65152 .69632 Mdot
.65806 .37823 Mdot
.43415 .36945 Mdot
.40916 .38659 Mdot
.60606 .45505 Mdot
.64508 .37959 Mdot
.46225 .33945 Mdot
.62415 .67197 Mdot
.28222 .56783 Mdot
.47335 .55099 Mdot
.29432 .59529 Mdot
.43887 .36315 Mdot
.66945 .48936 Mdot
.41604 .37993 Mdot
.58937 .42306 Mdot
.45631 .874 Mdot
.58414 .464 Mdot
.72393 .40676 Mdot
.55273 .66354 Mdot
.43595 .69415 Mdot
.43346 .70264 Mdot
.39127 .48024 Mdot
.40833 .32416 Mdot
.6821 .44958 Mdot
.63635 .64607 Mdot
.29532 .47188 Mdot
.39126 .38569 Mdot
.43249 .72411 Mdot
.42454 .71442 Mdot
.29648 .57268 Mdot
.63103 .46671 Mdot
.62441 .45482 Mdot
.48211 .72181 Mdot
.35476 .6446 Mdot
.4286 .33531 Mdot
.6244 .44158 Mdot
.56497 .43207 Mdot
.45394 .71281 Mdot
.26827 .59594 Mdot
.39506 .37984 Mdot
.56508 .42379 Mdot
.70726 .59366 Mdot
.28256 .59143 Mdot
.63076 .40449 Mdot
.57786 .39832 Mdot
.64221 .66066 Mdot
.68324 .55542 Mdot
.73663 .63385 Mdot
.33545 .59361 Mdot
.39364 .47168 Mdot
.65331 .45739 Mdot
.43779 .6937 Mdot
.58028 .47295 Mdot
.15837 .48536 Mdot
.36981 .48553 Mdot
.63404 .4406 Mdot
.66214 .40037 Mdot
.4446 .36431 Mdot
.62788 .43492 Mdot
.25643 .55697 Mdot
.46444 .72876 Mdot
.63488 .44108 Mdot
.69851 .28203 Mdot
.29782 .57127 Mdot
.67293 .46569 Mdot
.66329 .65918 Mdot
.4742 .61109 Mdot
.54089 .16439 Mdot
.49012 .68033 Mdot
.64749 .68509 Mdot
.62853 .46609 Mdot
.47974 .67719 Mdot
.33322 .55767 Mdot
.71232 .47792 Mdot
.63761 .41112 Mdot
.29868 .59759 Mdot
.32622 .58622 Mdot
.64457 .67086 Mdot
.39895 .85357 Mdot
.65793 .39661 Mdot
.60384 .44176 Mdot
.21732 .65396 Mdot
.45702 .3294 Mdot
.60081 .43631 Mdot
.63648 .46224 Mdot
.29707 .55026 Mdot
.78793 .58584 Mdot
.6658 .56069 Mdot
.37097 .6337 Mdot
.28011 .58741 Mdot
.42973 .68008 Mdot
.4672 .7325 Mdot
.64872 .68361 Mdot
.4088 .34683 Mdot
.64317 .69225 Mdot
.46221 .71826 Mdot
.58295 .44292 Mdot
.30154 .55536 Mdot
.49416 .20528 Mdot
.29307 .54709 Mdot
.49173 .73077 Mdot
.4365 .39657 Mdot
.37554 .25074 Mdot
.15603 .52472 Mdot
.42946 .42512 Mdot
.31293 .61088 Mdot
.64106 .66461 Mdot
.20511 .43408 Mdot
.6362 .45647 Mdot
.56369 .3391 Mdot
.60017 .44079 Mdot
.41439 .26935 Mdot
.46 .7411 Mdot
.37202 .50328 Mdot
.58647 .42527 Mdot
.66854 .5591 Mdot
.33113 .56208 Mdot
.31928 .5654 Mdot
.57327 .44282 Mdot
.3218 .58401 Mdot
.62774 .45094 Mdot
.45655 .70738 Mdot
.41725 .85042 Mdot
.64519 .44333 Mdot
.66839 .49839 Mdot
.33774 .60618 Mdot
.37972 .50912 Mdot
.41782 .70694 Mdot
.66032 .3096 Mdot
.31422 .3225 Mdot
.31966 .57722 Mdot
.67104 .35272 Mdot
.47963 .69915 Mdot
.39922 .48834 Mdot
.44601 .67198 Mdot
.60478 .44813 Mdot
.63221 .46926 Mdot
.57308 .42892 Mdot
.62919 .46455 Mdot
.53722 .33838 Mdot
.59671 .49335 Mdot
.53196 .2486 Mdot
.62316 .42234 Mdot
.71962 .3976 Mdot
.29711 .59303 Mdot
.62709 .5133 Mdot
.49414 .60486 Mdot
.61239 .47365 Mdot
.36697 .31414 Mdot
.28341 .58052 Mdot
.36935 .42882 Mdot
.2995 .58626 Mdot
.45734 .68711 Mdot
.331 .57081 Mdot
.59388 .42459 Mdot
.42113 .36277 Mdot
.47411 .71562 Mdot
.49368 .39606 Mdot
.46095 .74896 Mdot
.63426 .43479 Mdot
.36163 .56328 Mdot
.45116 .68065 Mdot
.57915 .49488 Mdot
.41774 .36217 Mdot
.74829 .48151 Mdot
.47159 .37399 Mdot
.62127 .43325 Mdot
.61404 .43241 Mdot
.37433 .50399 Mdot
.33018 .56279 Mdot
.44734 .37964 Mdot
.50571 .78721 Mdot
.67167 .68263 Mdot
.41442 .34916 Mdot
.6116 .51992 Mdot
.50823 .53205 Mdot
.44943 .36143 Mdot
.7526 .45152 Mdot
.31866 .55247 Mdot
.44342 .32589 Mdot
.56151 .4089 Mdot
.49451 .29273 Mdot
.65131 .64246 Mdot
.46183 .67365 Mdot
.59348 .56594 Mdot
.46611 .73174 Mdot
.33458 .54158 Mdot
.42532 .70272 Mdot
.30122 .59254 Mdot
.50928 .46297 Mdot
.47788 .59318 Mdot
.28068 .55561 Mdot
.34377 .60066 Mdot
.4525 .72172 Mdot
.5726 .43844 Mdot
.44781 .58659 Mdot
.6834 .44444 Mdot
.65994 .48861 Mdot
.29839 .59956 Mdot
.42706 .31888 Mdot
.4194 .38308 Mdot
.70911 .43664 Mdot
.42808 .37634 Mdot
.47077 .70732 Mdot
.45729 .44575 Mdot
.64437 .33533 Mdot
.2984 .56642 Mdot
.47411 .62461 Mdot
.59984 .39778 Mdot
.44195 .72015 Mdot
.47046 .70278 Mdot
.32383 .58811 Mdot
.47043 .27485 Mdot
.66393 .48059 Mdot
.4258 .30882 Mdot
.44952 .33407 Mdot
.45052 .35863 Mdot
.46327 .36803 Mdot
.75092 .64399 Mdot
.2758 .56799 Mdot
.41265 .32238 Mdot
.57236 .41277 Mdot
.65126 .45431 Mdot
.38123 .47594 Mdot
.62726 .67626 Mdot
.55159 .44091 Mdot
.68247 .44725 Mdot
.60801 .4551 Mdot
.43739 .69161 Mdot
.56711 .52005 Mdot
.37006 .48856 Mdot
.42608 .71542 Mdot
.42726 .71054 Mdot
.39369 .47462 Mdot
.51373 .46616 Mdot
.34665 .23697 Mdot
.57723 .43723 Mdot
.35903 .33314 Mdot
.43583 .70154 Mdot
.61972 .59025 Mdot
.70377 .38678 Mdot
.64776 .40182 Mdot
.4172 .61768 Mdot
.46233 .70545 Mdot
.41224 .29958 Mdot
.60901 .44661 Mdot
.39262 .4934 Mdot
.65901 .64945 Mdot
.62584 .52798 Mdot
.40111 .47637 Mdot
.41726 .33398 Mdot
.45958 .79846 Mdot
.40342 .31747 Mdot
.45766 .6773 Mdot
.67645 .46178 Mdot
.63401 .87536 Mdot
.45456 .69509 Mdot
.28603 .48018 Mdot
.47781 .59537 Mdot
.64295 .44149 Mdot
.47539 .72371 Mdot
.3784 .3362 Mdot
.28406 .59287 Mdot
.53034 .54474 Mdot
.40767 .33784 Mdot
.39297 .49578 Mdot
.38425 .47603 Mdot
.45279 .71487 Mdot
.45123 .34115 Mdot
.60772 .38492 Mdot
.41705 .37117 Mdot
.30794 .55719 Mdot
.60195 .41279 Mdot
.32098 .32861 Mdot
.64483 .50259 Mdot
.42001 .3709 Mdot
.48024 .74328 Mdot
.62363 .64141 Mdot
.63208 .4154 Mdot
.35712 .40329 Mdot
.63204 .46559 Mdot
.29411 .57753 Mdot
.56352 .61626 Mdot
.49904 .20825 Mdot
.58912 .45435 Mdot
.60318 .3972 Mdot
.31521 .54061 Mdot
.59005 .45332 Mdot
.65922 .40756 Mdot
.41247 .48924 Mdot
.44747 .36385 Mdot
.63061 .45863 Mdot
.4617 .73653 Mdot
.54718 .1883 Mdot
.59165 .42956 Mdot
.24747 .57335 Mdot
.73887 .48747 Mdot
.5424 .59387 Mdot
.68026 .47281 Mdot
.67652 .58046 Mdot
.61112 .43525 Mdot
.65171 .40632 Mdot
.57566 .43916 Mdot
.62261 .31358 Mdot
.45827 .72124 Mdot
.43757 .72735 Mdot
.66538 .65661 Mdot
.72972 .49627 Mdot
.65787 .6674 Mdot
.31134 .54151 Mdot
.47687 .62427 Mdot
.3723 .49717 Mdot
.42393 .3379 Mdot
.59053 .43139 Mdot
.46109 .74724 Mdot
.61708 .45348 Mdot
.61469 .40085 Mdot
.46772 .71107 Mdot
.46647 .70143 Mdot
.49072 .67919 Mdot
.65265 .63955 Mdot
.42333 .34878 Mdot
.58242 .4339 Mdot
.63237 .63809 Mdot
.56254 .43643 Mdot
.47496 .52944 Mdot
.4222 .35018 Mdot
.42142 .37206 Mdot
.40328 .37513 Mdot
.64748 .43116 Mdot
.59519 .42102 Mdot
.30041 .59646 Mdot
.38107 .34888 Mdot
.3259 .57085 Mdot
.47439 .72531 Mdot
.44483 .72466 Mdot
.60385 .4478 Mdot
.63013 .37069 Mdot
.63526 .68209 Mdot
.47174 .68691 Mdot
.3889 .46378 Mdot
.66503 .65879 Mdot
.60776 .46941 Mdot
.47063 .72941 Mdot
.66091 .68763 Mdot
.41773 .24294 Mdot
.30097 .31032 Mdot
.65741 .64049 Mdot
.57275 .44228 Mdot
.6635 .26669 Mdot
.71389 .60239 Mdot
.67155 .68719 Mdot
.29128 .58076 Mdot
.64505 .45547 Mdot
.31725 .64157 Mdot
.61696 .67188 Mdot
.73627 .62924 Mdot
.46859 .71576 Mdot
.68206 .48653 Mdot
.58725 .52261 Mdot
.63312 .33528 Mdot
.61686 .65131 Mdot
.42052 .3695 Mdot
.45823 .3477 Mdot
.58782 .45722 Mdot
.4748 .61815 Mdot
.298 .54312 Mdot
.47706 .68534 Mdot
.44185 .73741 Mdot
.45456 .35984 Mdot
.45992 .46756 Mdot
.46407 .73563 Mdot
.6584 .42939 Mdot
.62461 .6969 Mdot
.56128 .47541 Mdot
.76551 .65581 Mdot
.52128 .17188 Mdot
.67872 .47807 Mdot
.62799 .63706 Mdot
.33397 .56324 Mdot
.3168 .59319 Mdot
.31527 .58978 Mdot
.44824 .7268 Mdot
.56922 .54754 Mdot
.45088 .74177 Mdot
.22634 .55343 Mdot
.6454 .67881 Mdot
.76684 .48798 Mdot
.55938 .4208 Mdot
.64233 .43998 Mdot
.6054 .39257 Mdot
.57336 .42555 Mdot
.61247 .43623 Mdot
.31007 .60127 Mdot
.48022 .681 Mdot
.25829 .66942 Mdot
.44512 .34074 Mdot
.21652 .48528 Mdot
.44826 .68506 Mdot
.40004 .47081 Mdot
.62979 .66436 Mdot
.70347 .54069 Mdot
.61691 .69563 Mdot
.46966 .68333 Mdot
.661 .44992 Mdot
.46018 .3406 Mdot
.78836 .42059 Mdot
.61644 .42584 Mdot
.47618 .69008 Mdot
.43926 .67088 Mdot
.46887 .26832 Mdot
.55304 .38618 Mdot
.46027 .62952 Mdot
.51142 .53015 Mdot
.65418 .63624 Mdot
.64163 .48043 Mdot
.64478 .56621 Mdot
.46025 .71764 Mdot
.44425 .69874 Mdot
.67395 .68287 Mdot
.50415 .36902 Mdot
.42243 .32318 Mdot
.36852 .50289 Mdot
.28765 .57769 Mdot
.641 .43022 Mdot
.45387 .7284 Mdot
.45105 .30251 Mdot
.49176 .54832 Mdot
.30275 .58161 Mdot
.42497 .71338 Mdot
.63641 .46404 Mdot
.59209 .45787 Mdot
.65438 .67139 Mdot
.53444 .70968 Mdot
.68337 .44512 Mdot
.29441 .47323 Mdot
.48477 .49222 Mdot
.47905 .6001 Mdot
.61677 .45709 Mdot
.4295 .3805 Mdot
.39344 .47626 Mdot
.64039 .64888 Mdot
.56724 .45342 Mdot
.3287 .25716 Mdot
.39664 .32537 Mdot
.32515 .57471 Mdot
.39679 .47842 Mdot
.6175 .55625 Mdot
.63251 .46488 Mdot
.60046 .44119 Mdot
.56651 .4215 Mdot
.33162 .24841 Mdot
.45211 .73864 Mdot
.45291 .3759 Mdot
.66044 .67013 Mdot
.41097 .3694 Mdot
.43204 .69209 Mdot
.46651 .61501 Mdot
.57398 .4527 Mdot
.39586 .33583 Mdot
.40981 .3639 Mdot
.29823 .56971 Mdot
.32468 .55179 Mdot
.49301 .6887 Mdot
.63344 .46177 Mdot
.37391 .50051 Mdot
.42055 .32055 Mdot
.48315 .68904 Mdot
.65378 .67068 Mdot
.3 .53203 Mdot
.6254 .42212 Mdot
.45464 .71703 Mdot
.68074 .45124 Mdot
.44246 .34972 Mdot
.4596 .68184 Mdot
.40274 .48064 Mdot
.62486 .67129 Mdot
.64115 .4662 Mdot
.27922 .70087 Mdot
.39626 .48835 Mdot
.63973 .4215 Mdot
.50817 .17598 Mdot
.47425 .61714 Mdot
.49007 .37367 Mdot
.47166 .73784 Mdot
.38098 .49925 Mdot
.45915 .36881 Mdot
.50824 .29574 Mdot
.44388 .7034 Mdot
.6535 .23949 Mdot
.46513 .56301 Mdot
.5779 .43448 Mdot
.41231 .33467 Mdot
.6178 .70664 Mdot
.29602 .45742 Mdot
.70704 .60401 Mdot
.63011 .44498 Mdot
.46514 .73199 Mdot
.65864 .65005 Mdot
.32031 .56506 Mdot
.24787 .58111 Mdot
.78687 .6395 Mdot
.4302 .72582 Mdot
.58812 .43296 Mdot
.43036 .31981 Mdot
.32472 .57865 Mdot
.64801 .22869 Mdot
.49156 .72476 Mdot
.47243 .73462 Mdot
.62021 .3906 Mdot
.65924 .66402 Mdot
.32863 .63674 Mdot
.44337 .73233 Mdot
.47712 .67726 Mdot
.4179 .46491 Mdot
.6661 .65448 Mdot
.56794 .42239 Mdot
.70927 .43623 Mdot
.58208 .39828 Mdot
.24203 .49994 Mdot
.37892 .49984 Mdot
.44282 .33849 Mdot
.59931 .43307 Mdot
.26022 .69166 Mdot
.4497 .70248 Mdot
.51062 .52796 Mdot
.27146 .59583 Mdot
.3242 .55196 Mdot
.46436 .7274 Mdot
.6175 .44933 Mdot
.26969 .55638 Mdot
.64388 .68276 Mdot
.56485 .42537 Mdot
.5916 .42196 Mdot
.37966 .35032 Mdot
.30219 .5564 Mdot
.54417 .18565 Mdot
.31808 .55934 Mdot
.28499 .55777 Mdot
.40464 .38488 Mdot
.58857 .45814 Mdot
.4619 .68404 Mdot
.48041 .74742 Mdot
.66749 .39746 Mdot
.61678 .59265 Mdot
.41761 .32551 Mdot
.48148 .75995 Mdot
.31666 .26068 Mdot
.6388 .38856 Mdot
.39033 .46516 Mdot
.40787 .27333 Mdot
.27399 .58197 Mdot
.58644 .44646 Mdot
.43091 .34056 Mdot
.49173 .69476 Mdot
.45777 .73313 Mdot
.55054 .44619 Mdot
.32305 .59054 Mdot
.65696 .69006 Mdot
.47222 .70194 Mdot
.46874 .53976 Mdot
.63349 .43822 Mdot
.36339 .48491 Mdot
.47313 .70039 Mdot
.57644 .16119 Mdot
.25307 .68179 Mdot
.45303 .35596 Mdot
.63146 .39811 Mdot
.44752 .3252 Mdot
.65851 .67921 Mdot
.43252 .68429 Mdot
.31066 .59784 Mdot
.53341 .38571 Mdot
.45063 .81445 Mdot
.44916 .72415 Mdot
.41779 .33969 Mdot
.58816 .43554 Mdot
.6774 .36131 Mdot
.64181 .45148 Mdot
.79052 .5765 Mdot
.65695 .69543 Mdot
.34811 .56551 Mdot
.32809 .58836 Mdot
.61038 .39649 Mdot
.62852 .64329 Mdot
.49469 .73358 Mdot
.4669 .712 Mdot
.46879 .84591 Mdot
.40151 .47796 Mdot
.50689 .72188 Mdot
.64601 .42982 Mdot
.48579 .69707 Mdot
.66364 .27402 Mdot
.32979 .58066 Mdot
.60266 .38812 Mdot
.43807 .74478 Mdot
.24353 .46854 Mdot
.51099 .53319 Mdot
.6327 .44096 Mdot
.60718 .36916 Mdot
.29541 .58437 Mdot
.20555 .43208 Mdot
.47194 .73933 Mdot
.56403 .4386 Mdot
.26516 .57311 Mdot
.49443 .44221 Mdot
.51347 .77773 Mdot
.42356 .34924 Mdot
.44112 .75081 Mdot
.28387 .56599 Mdot
.67936 .48911 Mdot
.63195 .68241 Mdot
.49702 .71436 Mdot
.44998 .74988 Mdot
.60843 .40777 Mdot
.55731 .45316 Mdot
.58673 .37483 Mdot
.41613 .33043 Mdot
.29612 .55171 Mdot
.59711 .40401 Mdot
.47873 .52017 Mdot
.57518 .4226 Mdot
.28878 .5572 Mdot
.53186 .91005 Mdot
.65645 .45777 Mdot
.63018 .42372 Mdot
.67311 .34415 Mdot
.44442 .38077 Mdot
.44196 .36979 Mdot
.47933 .50007 Mdot
.65221 .43944 Mdot
.45433 .55517 Mdot
.42365 .3464 Mdot
.41006 .34033 Mdot
.45517 .55738 Mdot
.607 .41257 Mdot
.36187 .51989 Mdot
.3244 .5801 Mdot
.32355 .55122 Mdot
.44368 .36503 Mdot
.55768 .46774 Mdot
.33402 .55973 Mdot
.53862 .32978 Mdot
.46175 .68069 Mdot
.64605 .56498 Mdot
.41465 .37004 Mdot
.52618 .5559 Mdot
.32467 .55776 Mdot
.65522 .21107 Mdot
.76786 .40464 Mdot
.64251 .38528 Mdot
.58707 .4548 Mdot
.64624 .66078 Mdot
.57336 .36356 Mdot
.39197 .47128 Mdot
.3195 .58865 Mdot
.38358 .62494 Mdot
.42424 .35531 Mdot
.65037 .44405 Mdot
.69676 .60527 Mdot
.54552 .16829 Mdot
.71211 .46105 Mdot
.40803 .34617 Mdot
.42222 .35911 Mdot
.483 .72705 Mdot
.4674 .6809 Mdot
.57417 .45025 Mdot
.30828 .59465 Mdot
.45159 .33448 Mdot
.29784 .55413 Mdot
.46196 .71729 Mdot
.45486 .68376 Mdot
.37352 .48067 Mdot
.6575 .48585 Mdot
.4651 .72381 Mdot
.24062 .59485 Mdot
.47804 .52136 Mdot
.3856 .3641 Mdot
.21426 .61506 Mdot
.68406 .23733 Mdot
.5654 .35275 Mdot
.65832 .64871 Mdot
.50625 .4618 Mdot
.33444 .59045 Mdot
.60604 .3973 Mdot
.59545 .4448 Mdot
.37726 .48876 Mdot
.33688 .58479 Mdot
.63392 .66262 Mdot
.33197 .56556 Mdot
.63351 .65051 Mdot
.4362 .72372 Mdot
.59738 .42757 Mdot
.60032 .47072 Mdot
.3185 .56663 Mdot
.48571 .71107 Mdot
.45014 .68096 Mdot
.64135 .64075 Mdot
.71023 .52696 Mdot
.45463 .71448 Mdot
.41385 .36976 Mdot
.57337 .2063 Mdot
.38236 .47765 Mdot
.60973 .44626 Mdot
.68224 .58109 Mdot
.52052 .28889 Mdot
.5768 .42877 Mdot
.3974 .48115 Mdot
.40732 .85877 Mdot
.59441 .42772 Mdot
.57724 .84678 Mdot
.37162 .49271 Mdot
.41835 .38084 Mdot
.47837 .70035 Mdot
.40048 .47907 Mdot
.57691 .5252 Mdot
.46241 .77218 Mdot
.67739 .43379 Mdot
.41947 .323 Mdot
.3958 .35669 Mdot
.46196 .6064 Mdot
.24035 .50004 Mdot
.6613 .66844 Mdot
.63546 .67331 Mdot
.44418 .70674 Mdot
.2429 .60913 Mdot
.55299 .4548 Mdot
.63609 .6709 Mdot
.37504 .57271 Mdot
.60378 .39609 Mdot
.47257 .61465 Mdot
.44017 .58743 Mdot
.44455 .37639 Mdot
.61982 .51466 Mdot
.4466 .70431 Mdot
.41783 .34074 Mdot
.4544 .5912 Mdot
.60255 .38994 Mdot
.4227 .35216 Mdot
.3073 .54691 Mdot
.43179 .53967 Mdot
.42086 .37473 Mdot
.52453 .54536 Mdot
.31895 .573 Mdot
.47191 .61898 Mdot
.76905 .53385 Mdot
.4273 .14332 Mdot
.31516 .59278 Mdot
.4805 .6976 Mdot
.45346 .72675 Mdot
.45433 .71066 Mdot
.40928 .33328 Mdot
.46242 .69756 Mdot
.43718 .33023 Mdot
.34233 .59828 Mdot
.69664 .54274 Mdot
.64888 .66745 Mdot
.67354 .71951 Mdot
.42989 .36628 Mdot
.23238 .53495 Mdot
.19315 .6191 Mdot
.56854 .42652 Mdot
.28015 .55727 Mdot
.63662 .63474 Mdot
.48241 .4762 Mdot
.64335 .66001 Mdot
.48016 .7007 Mdot
.65008 .56087 Mdot
.62835 .45164 Mdot
.35984 .29396 Mdot
.65901 .6515 Mdot
.40735 .34218 Mdot
.63296 .41097 Mdot
.4595 .76037 Mdot
.65174 .68392 Mdot
.65099 .64422 Mdot
.61171 .43781 Mdot
.40006 .36295 Mdot
.46446 .68313 Mdot
.33113 .59688 Mdot
.64278 .70838 Mdot
.61162 .36624 Mdot
.57787 .44552 Mdot
.65931 .45799 Mdot
.50297 .51835 Mdot
.25363 .63508 Mdot
.31715 .57551 Mdot
.73034 .62825 Mdot
.44259 .7223 Mdot
.71071 .60638 Mdot
.31556 .46434 Mdot
.6014 .66899 Mdot
.37752 .4991 Mdot
.37832 .50027 Mdot
.62637 .43776 Mdot
.165 .52704 Mdot
.72436 .44151 Mdot
.28995 .6086 Mdot
.3816 .4818 Mdot
.45403 .67901 Mdot
.38578 .32811 Mdot
.54929 .48814 Mdot
.55564 .42821 Mdot
.33643 .59051 Mdot
.46136 .71272 Mdot
.15796 .48096 Mdot
.64623 .67754 Mdot
.4791 .47727 Mdot
.63013 .46307 Mdot
.62119 .44185 Mdot
.30568 .57554 Mdot
.30616 .5971 Mdot
.41731 .45546 Mdot
.54032 .58317 Mdot
.32229 .31776 Mdot
.33723 .55319 Mdot
.15733 .48065 Mdot
.37231 .26792 Mdot
.44254 .36016 Mdot
.38924 .467 Mdot
.31752 .54428 Mdot
.60028 .43494 Mdot
.4215 .38212 Mdot
.71815 .46512 Mdot
.42333 .29748 Mdot
.47462 .61227 Mdot
.47281 .54928 Mdot
.62242 .46758 Mdot
.46606 .35696 Mdot
.41816 .3441 Mdot
.46804 .36591 Mdot
.39098 .47528 Mdot
.61232 .45734 Mdot
.57064 .43358 Mdot
.59292 .42745 Mdot
.65936 .35556 Mdot
.62836 .43479 Mdot
.31218 .46227 Mdot
.47122 .50751 Mdot
.56686 .73991 Mdot
.61452 .42299 Mdot
.29571 .54947 Mdot
.59905 .42817 Mdot
.62237 .65202 Mdot
.64733 .46398 Mdot
.47652 .61118 Mdot
.31539 .58428 Mdot
.49314 .32118 Mdot
.41149 .7326 Mdot
.59131 .46658 Mdot
.663 .67962 Mdot
.22203 .61613 Mdot
.71835 .62446 Mdot
.41781 .4751 Mdot
.41675 .37087 Mdot
.47284 .67299 Mdot
.27388 .559 Mdot
.45528 .68642 Mdot
.61559 .38382 Mdot
.38055 .47 Mdot
.80661 .36313 Mdot
.53409 .56272 Mdot
.60063 .43341 Mdot
.65827 .48385 Mdot
.43792 .37806 Mdot
.45226 .69982 Mdot
.44625 .41153 Mdot
.6029 .3945 Mdot
.63208 .68764 Mdot
.61858 .65331 Mdot
.42161 .6417 Mdot
.41215 .54273 Mdot
.70914 .34634 Mdot
.30789 .57625 Mdot
.45093 .73038 Mdot
.6144 .65946 Mdot
.37362 .30223 Mdot
.2957 .54457 Mdot
.27404 .58247 Mdot
.30018 .55731 Mdot
.6371 .43479 Mdot
.37676 .47822 Mdot
.39501 .57908 Mdot
.39852 .48673 Mdot
.5836 .4009 Mdot
.44806 .749 Mdot
.39874 .48861 Mdot
.65342 .66198 Mdot
.28037 .56647 Mdot
.44125 .68852 Mdot
.61706 .43162 Mdot
.42931 .34901 Mdot
.73629 .6747 Mdot
.27629 .7228 Mdot
.47471 .61941 Mdot
.47471 .6195 Mdot
.39542 .3636 Mdot
.34657 .34576 Mdot
.32577 .53613 Mdot
.48005 .27663 Mdot
.61183 .61332 Mdot
.67181 .40353 Mdot
.51276 .81547 Mdot
.45404 .74259 Mdot
.47418 .71374 Mdot
.63515 .44895 Mdot
.49001 .70506 Mdot
.64621 .45 Mdot
.47608 .73597 Mdot
.27587 .4669 Mdot
.5575 .42027 Mdot
.47173 .70906 Mdot
.54679 .38792 Mdot
.63268 .41607 Mdot
.42619 .37972 Mdot
.49612 .71024 Mdot
.64239 .38551 Mdot
.83586 .41965 Mdot
.30203 .56716 Mdot
.39017 .47509 Mdot
.48741 .61282 Mdot
.32955 .5663 Mdot
.43611 .32659 Mdot
.65434 .44365 Mdot
.64816 .68029 Mdot
.4379 .36296 Mdot
.44521 .76177 Mdot
.65876 .65429 Mdot
.45584 .44737 Mdot
.44282 .36365 Mdot
.37757 .48215 Mdot
.62381 .6671 Mdot
.67714 .43276 Mdot
.4723 .71422 Mdot
.26247 .70026 Mdot
.39937 .47791 Mdot
.62464 .45367 Mdot
.4378 .74973 Mdot
.33145 .56499 Mdot
.58657 .46093 Mdot
.45467 .73009 Mdot
.39526 .47532 Mdot
.62905 .41847 Mdot
.64796 .42734 Mdot
.50852 .3738 Mdot
.56492 .6321 Mdot
.65132 .6657 Mdot
.4171 .3907 Mdot
.57339 .41069 Mdot
.63243 .64058 Mdot
.29247 .69118 Mdot
.56909 .40433 Mdot
.40693 .32075 Mdot
.5141 .32698 Mdot
.48201 .69154 Mdot
.32941 .58397 Mdot
.49027 .73366 Mdot
.6663 .66518 Mdot
.2293 .72294 Mdot
.38869 .46884 Mdot
.66644 .45231 Mdot
.6543 .39885 Mdot
.43456 .67931 Mdot
.41705 .34636 Mdot
.32672 .31411 Mdot
.64732 .46208 Mdot
.65873 .49261 Mdot
.60961 .44212 Mdot
.29252 .70104 Mdot
.41221 .33155 Mdot
.6086 .44433 Mdot
.63164 .36382 Mdot
.63251 .38892 Mdot
.65497 .68849 Mdot
.77259 .47726 Mdot
.58187 .42713 Mdot
.71146 .82665 Mdot
.36798 .48751 Mdot
.46509 .70892 Mdot
.51938 .53897 Mdot
.49968 .63294 Mdot
.75105 .69882 Mdot
.42789 .32585 Mdot
.36191 .31785 Mdot
.45861 .68419 Mdot
.72501 .7032 Mdot
.35422 .36722 Mdot
.64306 .41913 Mdot
.6423 .45923 Mdot
.48011 .7006 Mdot
.48056 .68561 Mdot
.37521 .47435 Mdot
.5817 .46804 Mdot
.63228 .50644 Mdot
.47406 .74694 Mdot
.62238 .42781 Mdot
.52239 .26869 Mdot
.2836 .59658 Mdot
.44416 .36592 Mdot
.31854 .56382 Mdot
.28392 .59476 Mdot
.53503 .36595 Mdot
.48762 .49454 Mdot
.28904 .58608 Mdot
.29845 .60912 Mdot
.64971 .72096 Mdot
.65112 .33864 Mdot
.65257 .68945 Mdot
.42154 .50177 Mdot
.44732 .71184 Mdot
.6091 .45692 Mdot
.40747 .33334 Mdot
.823 .54923 Mdot
.29339 .35053 Mdot
.66824 .53655 Mdot
.5709 .41953 Mdot
.44993 .70542 Mdot
.39816 .47745 Mdot
.56229 .41138 Mdot
.7126 .60357 Mdot
.62692 .44334 Mdot
.47067 .68065 Mdot
.64333 .33528 Mdot
.26894 .5369 Mdot
.33718 .55144 Mdot
.39363 .31497 Mdot
.59535 .4294 Mdot
.43345 .33659 Mdot
.28748 .58913 Mdot
.64556 .63773 Mdot
.64096 .66602 Mdot
.59735 .46911 Mdot
.47716 .59334 Mdot
.60147 .69679 Mdot
.64026 .41735 Mdot
.60623 .40964 Mdot
.37791 .49829 Mdot
.60501 .41033 Mdot
.56769 .44816 Mdot
.59313 .40518 Mdot
.55975 .44203 Mdot
.30507 .54246 Mdot
.47961 .40017 Mdot
.60248 .4755 Mdot
.66332 .40746 Mdot
.31545 .60558 Mdot
.62167 .37691 Mdot
.30154 .58833 Mdot
.30956 .34381 Mdot
.2887 .58155 Mdot
.64234 .66658 Mdot
.44422 .75531 Mdot
.36472 .35177 Mdot
.45185 .33513 Mdot
.29987 .54633 Mdot
.62642 .66394 Mdot
.31608 .59095 Mdot
.45085 .734 Mdot
.2369 .6425 Mdot
.43701 .40048 Mdot
.46424 .5168 Mdot
.66276 .34065 Mdot
.36272 .48496 Mdot
.48914 .71244 Mdot
.45375 .35343 Mdot
.25737 .55587 Mdot
.61124 .39707 Mdot
.65405 .67673 Mdot
.6256 .43811 Mdot
.28025 .56407 Mdot
.44927 .70836 Mdot
.38001 .51529 Mdot
.6509 .66477 Mdot
.24248 .72048 Mdot
.46362 .74726 Mdot
.66366 .42563 Mdot
.3156 .60518 Mdot
.24273 .63893 Mdot
.29538 .58725 Mdot
.69784 .54251 Mdot
.4376 .28856 Mdot
.81231 .57912 Mdot
.42648 .36248 Mdot
.38888 .45877 Mdot
.41649 .18655 Mdot
.35061 .43357 Mdot
.43755 .35119 Mdot
.40892 .7254 Mdot
.63103 .43257 Mdot
.57571 .41888 Mdot
.64627 .48848 Mdot
.46154 .318 Mdot
.56687 .42106 Mdot
.38788 .47185 Mdot
.48706 .50176 Mdot
.36481 .61234 Mdot
.47904 .67536 Mdot
.64336 .45248 Mdot
.2994 .60004 Mdot
.29114 .54929 Mdot
.3946 .49537 Mdot
.31273 .55567 Mdot
.61645 .41579 Mdot
.42937 .36537 Mdot
.44901 .58717 Mdot
.65826 .67867 Mdot
.3014 .48174 Mdot
.59394 .63715 Mdot
.62448 .70454 Mdot
.63367 .38818 Mdot
.45627 .68311 Mdot
.46475 .82106 Mdot
.5924 .40224 Mdot
.4222 .34388 Mdot
.65586 .40188 Mdot
.58593 .41167 Mdot
.58413 .43094 Mdot
.45018 .72939 Mdot
.51297 .53949 Mdot
.62084 .42707 Mdot
.28768 .58548 Mdot
.45701 .55901 Mdot
.55371 .43367 Mdot
.38816 .62978 Mdot
.47575 .61072 Mdot
.36233 .48785 Mdot
.38295 .35843 Mdot
.46812 .68771 Mdot
.42503 .35746 Mdot
.46146 .32675 Mdot
.4371 .32709 Mdot
.38576 .5946 Mdot
.4935 .28991 Mdot
.60389 .84102 Mdot
.66868 .2828 Mdot
.6569 .33362 Mdot
.4127 .31081 Mdot
.34357 .68533 Mdot
.43698 .34686 Mdot
.4335 .32621 Mdot
.48463 .88944 Mdot
.40311 .33168 Mdot
.60443 .44879 Mdot
.64186 .47193 Mdot
.37779 .25023 Mdot
.661 .71604 Mdot
.64254 .4265 Mdot
.56645 .43237 Mdot
.61611 .65658 Mdot
.50447 .38207 Mdot
.37832 .46904 Mdot
.47497 .47561 Mdot
.39804 .4642 Mdot
.61256 .43737 Mdot
.6118 .46844 Mdot
.5719 .46743 Mdot
.46848 .15401 Mdot
.80922 .60132 Mdot
.40084 .36996 Mdot
.66227 .38337 Mdot
.35765 .51063 Mdot
.65589 .41073 Mdot
.64887 .39553 Mdot
.59209 .42499 Mdot
.46156 .6839 Mdot
.38482 .3342 Mdot
.68295 .44529 Mdot
.33584 .48214 Mdot
.62526 .46593 Mdot
.59018 .65924 Mdot
.6622 .6396 Mdot
.6163 .4498 Mdot
.40116 .33208 Mdot
.57287 .42012 Mdot
.44378 .32349 Mdot
.44633 .36011 Mdot
.64288 .49875 Mdot
.39826 .56768 Mdot
.38927 .32401 Mdot
.64474 .4208 Mdot
.48663 .71033 Mdot
.29119 .47566 Mdot
.62301 .45307 Mdot
.6565 .65906 Mdot
.58516 .44541 Mdot
.65978 .68588 Mdot
.59476 .41554 Mdot
.396 .49157 Mdot
.49342 .21288 Mdot
.44277 .70107 Mdot
.63504 .70956 Mdot
.48839 .70342 Mdot
.58663 .49688 Mdot
.41522 .31316 Mdot
.3272 .5176 Mdot
.79571 .63172 Mdot
.37699 .49769 Mdot
.73917 .64171 Mdot
.44625 .55661 Mdot
.31884 .60055 Mdot
.4618 .36908 Mdot
.61334 .33838 Mdot
.39841 .62627 Mdot
.46596 .6681 Mdot
.42753 .70415 Mdot
.51806 .78147 Mdot
.41777 .85079 Mdot
.62365 .42523 Mdot
.31475 .64303 Mdot
.52884 .24033 Mdot
.60322 .3586 Mdot
.55739 .39372 Mdot
.45533 .75145 Mdot
.64232 .42586 Mdot
.57519 .56262 Mdot
.45345 .72193 Mdot
.63283 .67615 Mdot
.44115 .33731 Mdot
.62937 .64695 Mdot
.2679 .34719 Mdot
.41602 .48082 Mdot
.46067 .72332 Mdot
.55836 .44254 Mdot
.64482 .43693 Mdot
.45374 .37675 Mdot
.65599 .23701 Mdot
.44678 .36461 Mdot
.66222 .67155 Mdot
.43978 .7114 Mdot
.80709 .4331 Mdot
.58454 .44059 Mdot
.40712 .35955 Mdot
.41129 .73151 Mdot
.59382 .45822 Mdot
.32739 .58648 Mdot
.57254 .41614 Mdot
.4064 .36167 Mdot
.60417 .4105 Mdot
.43063 .36355 Mdot
.48181 .72583 Mdot
.60616 .47194 Mdot
.6041 .46838 Mdot
.73528 .63135 Mdot
.63492 .66106 Mdot
.40988 .31495 Mdot
.57751 .56216 Mdot
.58184 .39849 Mdot
.7089 .59537 Mdot
.59654 .42763 Mdot
.66752 .35061 Mdot
.58218 .38982 Mdot
.38508 .47256 Mdot
.65169 .39654 Mdot
.62394 .45219 Mdot
.67893 .26434 Mdot
.66232 .27009 Mdot
.61284 .3467 Mdot
.32414 .55103 Mdot
.40002 .35281 Mdot
.45647 .72724 Mdot
.4891 .68766 Mdot
.46362 .69389 Mdot
.68147 .65999 Mdot
.65694 .37825 Mdot
.62749 .4557 Mdot
.34096 .60769 Mdot
.63902 .67414 Mdot
.40717 .35199 Mdot
.64497 .67055 Mdot
.49006 .4935 Mdot
.65448 .65436 Mdot
.39181 .47022 Mdot
.25227 .6785 Mdot
.52413 .28136 Mdot
.64303 .65036 Mdot
.44675 .36331 Mdot
.45448 .54151 Mdot
.67564 .41242 Mdot
.22798 .49136 Mdot
.63076 .68709 Mdot
.49661 .79564 Mdot
.62321 .41906 Mdot
.53537 .54428 Mdot
.30004 .58467 Mdot
.62894 .64785 Mdot
.30113 .55804 Mdot
.57392 .41893 Mdot
.48612 .38978 Mdot
.41997 .33798 Mdot
.28981 .60024 Mdot
.62456 .38931 Mdot
.62834 .64814 Mdot
.46556 .72162 Mdot
.64695 .33723 Mdot
.3138 .60839 Mdot
.73241 .67872 Mdot
.70813 .60515 Mdot
.44076 .71465 Mdot
.68098 .33139 Mdot
.2916 .56951 Mdot
.66969 .39901 Mdot
.67229 .50663 Mdot
.58426 .40457 Mdot
.44702 .68213 Mdot
.47501 .71254 Mdot
.37971 .44226 Mdot
.61294 .46978 Mdot
.61603 .47736 Mdot
.38708 .35514 Mdot
.43917 .7174 Mdot
.43834 .32701 Mdot
.45737 .36623 Mdot
.48159 .70182 Mdot
.45341 .35749 Mdot
.65713 .64999 Mdot
.57899 .54752 Mdot
.29025 .57203 Mdot
.32488 .59101 Mdot
.46307 .72444 Mdot
.43348 .71288 Mdot
.45413 .68325 Mdot
.61485 .39209 Mdot
.45375 .3446 Mdot
.63349 .39984 Mdot
.59211 .43146 Mdot
.38542 .29531 Mdot
.39353 .37085 Mdot
.64081 .39615 Mdot
.4355 .58795 Mdot
.64592 .6943 Mdot
.46965 .70653 Mdot
.30105 .55104 Mdot
.74425 .67362 Mdot
.31988 .60224 Mdot
.57577 .40327 Mdot
.24343 .47297 Mdot
.40905 .33477 Mdot
.64471 .6601 Mdot
.47673 .61599 Mdot
.64921 .66261 Mdot
.28521 .59748 Mdot
.40524 .38208 Mdot
.45704 .45713 Mdot
.61235 .47046 Mdot
.5006 .51531 Mdot
.75207 .57072 Mdot
.32176 .46624 Mdot
.29936 .54951 Mdot
.56829 .42486 Mdot
.37335 .49474 Mdot
.46999 .26737 Mdot
.63028 .45389 Mdot
.60862 .38614 Mdot
.5182 .65696 Mdot
.65225 .39505 Mdot
.41983 .38764 Mdot
.46992 .60569 Mdot
.57086 .45887 Mdot
.58725 .49587 Mdot
.45932 .85795 Mdot
.63339 .41953 Mdot
.60098 .4687 Mdot
.59852 .45046 Mdot
.61098 .39552 Mdot
.44408 .32211 Mdot
.52212 .68518 Mdot
.29216 .59605 Mdot
.57996 .54806 Mdot
.29484 .56149 Mdot
.47224 .72409 Mdot
.56337 .57208 Mdot
.44529 .32393 Mdot
.64964 .66222 Mdot
.30068 .64681 Mdot
.64586 .55995 Mdot
.48434 .72467 Mdot
.75958 .63841 Mdot
.64221 .6895 Mdot
.67566 .4115 Mdot
.66654 .65876 Mdot
.44765 .75086 Mdot
.32204 .59093 Mdot
.66083 .45005 Mdot
.42517 .32116 Mdot
.42109 .37444 Mdot
.57327 .41283 Mdot
.29835 .48831 Mdot
.3331 .57234 Mdot
.67218 .61641 Mdot
.63901 .43909 Mdot
.60144 .38835 Mdot
.44922 .3639 Mdot
.45238 .70124 Mdot
.44815 .55706 Mdot
.63019 .66071 Mdot
.65946 .43551 Mdot
.57231 .42688 Mdot
.49148 .49614 Mdot
.30097 .54475 Mdot
.38666 .4849 Mdot
.63622 .45525 Mdot
.47829 .48757 Mdot
.56578 .42136 Mdot
.56852 .47229 Mdot
.48418 .69892 Mdot
.65314 .49565 Mdot
.63208 .46814 Mdot
.48265 .38811 Mdot
.29409 .56656 Mdot
.42076 .34791 Mdot
.37772 .30295 Mdot
.39017 .49647 Mdot
.3061 .56616 Mdot
.63739 .39416 Mdot
.27083 .57537 Mdot
.58033 .41566 Mdot
.61852 .42966 Mdot
.30155 .54829 Mdot
.44597 .33368 Mdot
.331 .34159 Mdot
.47985 .40011 Mdot
.61084 .4007 Mdot
.58634 .44853 Mdot
.65951 .71612 Mdot
.83153 .55939 Mdot
.62831 .47023 Mdot
.4552 .35051 Mdot
.59268 .45858 Mdot
.31626 .59948 Mdot
.66205 .66662 Mdot
.42751 .34529 Mdot
.44282 .7282 Mdot
.47878 .72903 Mdot
.41749 .68856 Mdot
.39065 .46899 Mdot
.58749 .47014 Mdot
.41322 .38947 Mdot
.39454 .36981 Mdot
.55066 .53216 Mdot
.4662 .70894 Mdot
.66213 .66209 Mdot
.64533 .42713 Mdot
.53181 .38503 Mdot
.28064 .59016 Mdot
.73566 .8037 Mdot
.45882 .46304 Mdot
.67669 .66834 Mdot
.53701 .59198 Mdot
.3779 .49569 Mdot
.63501 .42434 Mdot
.62466 .64954 Mdot
.47938 .71964 Mdot
.57474 .4197 Mdot
.60802 .3702 Mdot
.39865 .63463 Mdot
.4311 .70794 Mdot
.27619 .58774 Mdot
.4649 .74002 Mdot
.656 .68967 Mdot
.39146 .4708 Mdot
.41346 .37407 Mdot
.62311 .44802 Mdot
.63125 .50973 Mdot
.45571 .70764 Mdot
.37475 .50334 Mdot
.58365 .46274 Mdot
.40232 .36183 Mdot
.46535 .70067 Mdot
.60646 .43724 Mdot
.47403 .27384 Mdot
.36468 .34905 Mdot
.44486 .71433 Mdot
.65771 .43366 Mdot
.54206 .47419 Mdot
.42971 .70765 Mdot
.4398 .74478 Mdot
.566 .42799 Mdot
.62622 .65334 Mdot
.62997 .46722 Mdot
.30263 .59246 Mdot
.51199 .53982 Mdot
.31552 .56637 Mdot
.71493 .60319 Mdot
.56111 .45999 Mdot
.71519 .46561 Mdot
.46421 .3505 Mdot
.62086 .6934 Mdot
.72973 .29565 Mdot
.58223 .39691 Mdot
.33237 .26577 Mdot
.52335 .55441 Mdot
.46031 .49078 Mdot
.30136 .28152 Mdot
.63465 .65239 Mdot
.31482 .58996 Mdot
.58744 .46389 Mdot
.26498 .62475 Mdot
.63746 .64746 Mdot
.71504 .60221 Mdot
.64966 .4116 Mdot
.40969 .34242 Mdot
.63675 .4382 Mdot
.40525 .36301 Mdot
.59658 .45656 Mdot
.48314 .31307 Mdot
.58917 .66881 Mdot
.69899 .54065 Mdot
.67831 .42158 Mdot
.24033 .6318 Mdot
.66199 .33955 Mdot
.65943 .66575 Mdot
.60667 .40415 Mdot
.38449 .49192 Mdot
.33192 .56461 Mdot
.30013 .65878 Mdot
.45675 .6841 Mdot
.28649 .58089 Mdot
.44927 .35113 Mdot
.45967 .7557 Mdot
.37623 .5022 Mdot
.68886 .4449 Mdot
.62636 .65013 Mdot
.3026 .56723 Mdot
.62147 .45099 Mdot
.59368 .39678 Mdot
.29154 .70129 Mdot
.80004 .41206 Mdot
.45697 .35812 Mdot
.31471 .79492 Mdot
.42244 .3916 Mdot
.63339 .66813 Mdot
.48167 .69392 Mdot
.59682 .43679 Mdot
.62718 .46193 Mdot
.43313 .70392 Mdot
.44 .38176 Mdot
.61201 .68718 Mdot
.81681 .57392 Mdot
.26741 .59183 Mdot
.75103 .50138 Mdot
.42848 .3431 Mdot
.74873 .50433 Mdot
.64748 .62288 Mdot
.36988 .53487 Mdot
.76976 .41949 Mdot
.32758 .57651 Mdot
.75357 .49856 Mdot
.40529 .34797 Mdot
.6261 .42454 Mdot
.37743 .48363 Mdot
.36957 .48696 Mdot
.43878 .34003 Mdot
.47765 .69598 Mdot
.63059 .68135 Mdot
.63655 .44119 Mdot
.6949 .45781 Mdot
.64556 .22635 Mdot
.43612 .71805 Mdot
.6573 .48356 Mdot
.32607 .56158 Mdot
.58984 .45499 Mdot
.61999 .64812 Mdot
.32296 .58293 Mdot
.40213 .47978 Mdot
.64033 .56081 Mdot
.65459 .4432 Mdot
.47741 .60102 Mdot
.29976 .57842 Mdot
.83239 .55186 Mdot
.60473 .46816 Mdot
.29183 .56913 Mdot
.63142 .50891 Mdot
.31308 .51198 Mdot
.45259 .57627 Mdot
.34932 .43055 Mdot
.49907 .70132 Mdot
.47355 .73706 Mdot
.83538 .42989 Mdot
.61662 .60816 Mdot
.28294 .57631 Mdot
.39609 .47208 Mdot
.78076 .45934 Mdot
.30387 .55937 Mdot
.65955 .44388 Mdot
.60094 .42574 Mdot
.64307 .33512 Mdot
.53768 .3856 Mdot
.37336 .47538 Mdot
.69034 .40131 Mdot
.61688 .41248 Mdot
.67813 .46253 Mdot
.5807 .45525 Mdot
.39686 .35968 Mdot
.32751 .57143 Mdot
.24564 .26551 Mdot
.27255 .5649 Mdot
.69192 .49267 Mdot
.44738 .71152 Mdot
.49891 .71638 Mdot
.61604 .44884 Mdot
.72537 .46226 Mdot
.1517 .50231 Mdot
.58324 .4359 Mdot
.47679 .61538 Mdot
.70964 .60737 Mdot
.66601 .39258 Mdot
.40005 .32049 Mdot
.63812 .50491 Mdot
.44525 .39578 Mdot
.32373 .58358 Mdot
.63592 .65067 Mdot
.62907 .69032 Mdot
.30903 .59024 Mdot
.62327 .46157 Mdot
.62011 .68193 Mdot
.61776 .44226 Mdot
.64145 .4316 Mdot
.4817 .48277 Mdot
.64515 .6348 Mdot
.45587 .68199 Mdot
.64299 .6648 Mdot
.42261 .32569 Mdot
.48723 .90099 Mdot
.65108 .67322 Mdot
.65081 .33842 Mdot
.55324 .55605 Mdot
.75492 .50239 Mdot
.4258 .37559 Mdot
.6609 .67611 Mdot
.32918 .57829 Mdot
.44872 .44708 Mdot
.6679 .33083 Mdot
.31921 .60223 Mdot
.63221 .45544 Mdot
.45014 .32821 Mdot
.3964 .36709 Mdot
.33295 .54799 Mdot
.43424 .38 Mdot
.67306 .44362 Mdot
.64931 .42471 Mdot
.28543 .58586 Mdot
.54038 .1647 Mdot
.32979 .58518 Mdot
.5419 .36151 Mdot
.59431 .42236 Mdot
.42468 .34473 Mdot
.67095 .35197 Mdot
.38875 .3028 Mdot
.3747 .47828 Mdot
.64407 .46727 Mdot
.65666 .67175 Mdot
.56967 .54788 Mdot
.44394 .7124 Mdot
.24651 .46854 Mdot
.41608 .37082 Mdot
.31232 .53782 Mdot
.42525 .37934 Mdot
.45154 .37491 Mdot
.29851 .60355 Mdot
.41617 .33414 Mdot
.62493 .4656 Mdot
.21834 .38617 Mdot
.42366 .37148 Mdot
.30744 .57926 Mdot
.65337 .68053 Mdot
.45353 .35512 Mdot
.69141 .64414 Mdot
.64754 .43792 Mdot
.48607 .73233 Mdot
.65716 .70433 Mdot
.46749 .35581 Mdot
.66058 .66361 Mdot
.4604 .70648 Mdot
.62707 .67796 Mdot
.29164 .62824 Mdot
.33503 .53989 Mdot
.67593 .5293 Mdot
.29129 .52116 Mdot
.41056 .32776 Mdot
.50272 .7196 Mdot
.65259 .45012 Mdot
.64037 .43688 Mdot
.64889 .6967 Mdot
.39509 .36014 Mdot
.28835 .49652 Mdot
.72094 .40832 Mdot
.30285 .48219 Mdot
.31507 .54476 Mdot
.70925 .68687 Mdot
.45672 .46049 Mdot
.25496 .60004 Mdot
.63557 .481 Mdot
.37739 .49478 Mdot
.60874 .44245 Mdot
.71761 .62388 Mdot
.64944 .69044 Mdot
.32497 .72855 Mdot
.55402 .45619 Mdot
.43671 .69919 Mdot
.59325 .45172 Mdot
.3447 .63679 Mdot
.58147 .49014 Mdot
.63243 .68898 Mdot
.26748 .56642 Mdot
.45192 .33519 Mdot
.65376 .68493 Mdot
.48073 .7262 Mdot
.74908 .46086 Mdot
.65853 .44511 Mdot
.62038 .41427 Mdot
.42662 .71338 Mdot
.43235 .32395 Mdot
.47357 .71977 Mdot
.29045 .57122 Mdot
.64902 .67144 Mdot
.62035 .39492 Mdot
.66711 .47742 Mdot
.43162 .68272 Mdot
.27586 .56879 Mdot
.437 .68782 Mdot
.27149 .57581 Mdot
.37545 .49238 Mdot
.56302 .45368 Mdot
.42434 .71201 Mdot
.60103 .47879 Mdot
.6362 .26131 Mdot
.59991 .55005 Mdot
.71169 .30784 Mdot
.45724 .68116 Mdot
.58175 .66793 Mdot
.31216 .58622 Mdot
.29927 .56704 Mdot
.54377 .35441 Mdot
.16302 .52543 Mdot
.45432 .55547 Mdot
.22366 .64533 Mdot
.28995 .57248 Mdot
.30144 .57372 Mdot
.47852 .70888 Mdot
.43114 .3277 Mdot
.46483 .33334 Mdot
.43474 .74581 Mdot
.68293 .57985 Mdot
.407 .35217 Mdot
.35108 .25204 Mdot
.44549 .73972 Mdot
.6482 .47238 Mdot
.41135 .48408 Mdot
.63176 .68826 Mdot
.69841 .60419 Mdot
.24105 .64746 Mdot
.59938 .44185 Mdot
.55851 .84777 Mdot
.46224 .6862 Mdot
.42526 .48892 Mdot
.36179 .58186 Mdot
.60111 .39144 Mdot
.59801 .45328 Mdot
.60997 .46508 Mdot
.67262 .68468 Mdot
.63656 .23816 Mdot
.59869 .43901 Mdot
.67388 .55758 Mdot
.55789 .41889 Mdot
.27534 .70306 Mdot
.64306 .66513 Mdot
.78804 .58431 Mdot
.48719 .74747 Mdot
.3258 .48971 Mdot
.62708 .38729 Mdot
.29136 .57952 Mdot
.41059 .61148 Mdot
.2914 .55365 Mdot
.36666 .5578 Mdot
.78344 .43697 Mdot
.39442 .35243 Mdot
.57345 .41411 Mdot
.44153 .73916 Mdot
.45978 .33876 Mdot
.42035 .60235 Mdot
.46651 .89208 Mdot
.32313 .54376 Mdot
.30446 .81153 Mdot
.31208 .5621 Mdot
.36938 .48501 Mdot
.44758 .35177 Mdot
.7361 .44868 Mdot
.49738 .50963 Mdot
.43982 .32811 Mdot
.58187 .77239 Mdot
.47178 .377 Mdot
.73727 .49737 Mdot
.43154 .40305 Mdot
.3138 .58078 Mdot
.31646 .53659 Mdot
.59478 .37702 Mdot
.64063 .46392 Mdot
.49892 .51939 Mdot
.55473 .3906 Mdot
.6534 .44413 Mdot
.45314 .72203 Mdot
.26272 .53852 Mdot
.26237 .62476 Mdot
.43002 .33901 Mdot
.27828 .58252 Mdot
.59494 .45179 Mdot
.61109 .40089 Mdot
.66363 .41428 Mdot
.72893 .70052 Mdot
.34967 .25126 Mdot
.61762 .4278 Mdot
.58811 .49269 Mdot
.48579 .71835 Mdot
.29214 .70288 Mdot
.33283 .79709 Mdot
.78185 .44628 Mdot
.57883 .45951 Mdot
.63631 .66256 Mdot
.61725 .65165 Mdot
.6701 .42617 Mdot
.71155 .48504 Mdot
.6983 .69324 Mdot
.62148 .45125 Mdot
.72549 .4975 Mdot
.45425 .66795 Mdot
.38403 .50172 Mdot
.45626 .70785 Mdot
.46574 .34816 Mdot
.37453 .49726 Mdot
.46141 .73186 Mdot
.66031 .56514 Mdot
.39359 .49157 Mdot
.31575 .50996 Mdot
.66196 .67384 Mdot
.58739 .46135 Mdot
.41174 .41591 Mdot
.43904 .72058 Mdot
.29832 .57352 Mdot
.43515 .35791 Mdot
.33221 .56237 Mdot
.2597 .6936 Mdot
.68721 .5854 Mdot
.38686 .46963 Mdot
.29159 .58218 Mdot
.47348 .58693 Mdot
.63719 .66424 Mdot
.31306 .55796 Mdot
.71846 .46183 Mdot
.55176 .43982 Mdot
.1704 .4148 Mdot
.62508 .41163 Mdot
.37976 .43313 Mdot
.29498 .57439 Mdot
.40377 .47929 Mdot
.62428 .4468 Mdot
.46662 .74625 Mdot
.67643 .40073 Mdot
.61802 .44085 Mdot
.45211 .73831 Mdot
.62046 .42557 Mdot
.63327 .6376 Mdot
.45012 .39203 Mdot
.53589 .55797 Mdot
.72054 .67213 Mdot
.63661 .68533 Mdot
.52881 .51184 Mdot
.63051 .4702 Mdot
.5522 .74968 Mdot
.41112 .3434 Mdot
.58136 .3981 Mdot
.73014 .60592 Mdot
.43372 .33233 Mdot
.42447 .35837 Mdot
.61126 .40704 Mdot
.32945 .58926 Mdot
.44303 .68594 Mdot
.639 .66399 Mdot
.24519 .60911 Mdot
.6045 .43629 Mdot
.56772 .4249 Mdot
.64546 .68904 Mdot
.30498 .5683 Mdot
.62707 .39467 Mdot
.28953 .42394 Mdot
.56954 .53908 Mdot
.27787 .5883 Mdot
.55352 .43469 Mdot
.25807 .29616 Mdot
.47214 .34694 Mdot
.56886 .84748 Mdot
.58859 .65331 Mdot
.48203 .69902 Mdot
.64535 .49141 Mdot
.67077 .85648 Mdot
.66045 .6742 Mdot
.32158 .47888 Mdot
.62827 .42711 Mdot
.59296 .43598 Mdot
.39623 .34598 Mdot
.64042 .40037 Mdot
.40129 .34585 Mdot
.71489 .69211 Mdot
.16477 .54269 Mdot
.43515 .37895 Mdot
.40194 .35382 Mdot
.54183 .4486 Mdot
.73192 .70599 Mdot
.44388 .34079 Mdot
.6583 .44459 Mdot
.57082 .751 Mdot
.60828 .36763 Mdot
.65687 .63674 Mdot
.68779 .71019 Mdot
.40249 .31829 Mdot
.65332 .32352 Mdot
.54206 .44831 Mdot
.49851 .32527 Mdot
.69217 .65991 Mdot
.28593 .56825 Mdot
.58591 .41616 Mdot
.39455 .46972 Mdot
.46948 .70199 Mdot
.66451 .49664 Mdot
.59953 .46638 Mdot
.41066 .32074 Mdot
.67116 .68251 Mdot
.30653 .55695 Mdot
.57067 .44524 Mdot
.43195 .67804 Mdot
.62895 .66928 Mdot
.43273 .37051 Mdot
.596 .34263 Mdot
.62103 .68084 Mdot
.66303 .48139 Mdot
.62318 .42214 Mdot
.5716 .45006 Mdot
.6325 .35799 Mdot
.3063 .58892 Mdot
.44603 .75303 Mdot
.65159 .48601 Mdot
.46372 .4608 Mdot
.60314 .55831 Mdot
.66435 .44396 Mdot
.45478 .35198 Mdot
.31384 .54559 Mdot
.39295 .47754 Mdot
.76706 .48743 Mdot
.6089 .42043 Mdot
.34356 .25267 Mdot
.78075 .63645 Mdot
.39275 .4891 Mdot
.44457 .31976 Mdot
.64509 .66126 Mdot
.6048 .41469 Mdot
.6803 .55594 Mdot
.65639 .43398 Mdot
.64612 .3655 Mdot
.47559 .69098 Mdot
.29169 .55888 Mdot
.63497 .53801 Mdot
.47156 .70425 Mdot
.42482 .35776 Mdot
.37529 .24652 Mdot
.46769 .34137 Mdot
.45607 .36687 Mdot
.395 .5638 Mdot
.31415 .59554 Mdot
.68641 .84699 Mdot
.83126 .57629 Mdot
.64955 .46762 Mdot
.30273 .59846 Mdot
.4438 .34815 Mdot
.65208 .40191 Mdot
.40652 .3366 Mdot
.38824 .32828 Mdot
.6489 .43198 Mdot
.65087 .4369 Mdot
.7028 .53309 Mdot
.35545 .2535 Mdot
.65348 .67681 Mdot
.42168 .38169 Mdot
.52502 .34826 Mdot
.59933 .43463 Mdot
.62166 .46877 Mdot
.40552 .6158 Mdot
.65724 .68284 Mdot
.50444 .2599 Mdot
.63742 .43436 Mdot
.74183 .63418 Mdot
.64956 .46046 Mdot
.45288 .31673 Mdot
.34311 .58222 Mdot
.70109 .48564 Mdot
.45221 .67938 Mdot
.46014 .37195 Mdot
.65462 .69295 Mdot
.37891 .33567 Mdot
.51385 .2947 Mdot
.32287 .58826 Mdot
.40601 .36099 Mdot
.47051 .75362 Mdot
.31293 .56989 Mdot
.32773 .58876 Mdot
.42467 .59841 Mdot
.47694 .74794 Mdot
.67516 .67186 Mdot
.31419 .55167 Mdot
.47458 .27581 Mdot
.31516 .57841 Mdot
.50773 .28877 Mdot
.59621 .47164 Mdot
.67086 .55884 Mdot
.68655 .48511 Mdot
.59286 .37486 Mdot
.32278 .56486 Mdot
.6305 .67825 Mdot
.62269 .39196 Mdot
.44228 .37802 Mdot
.64304 .68002 Mdot
.41418 .48679 Mdot
.49716 .72937 Mdot
.39235 .35938 Mdot
.27009 .57933 Mdot
.40396 .3336 Mdot
.70566 .60596 Mdot
.61191 .69154 Mdot
.4177 .61752 Mdot
.50691 .51964 Mdot
.67984 .45402 Mdot
.56869 .48391 Mdot
.61587 .3904 Mdot
.62088 .46475 Mdot
.44566 .71455 Mdot
.68086 .66019 Mdot
.45379 .35577 Mdot
.63814 .21489 Mdot
.29491 .58333 Mdot
.47267 .60171 Mdot
.65465 .37011 Mdot
.57839 .41661 Mdot
.44108 .35109 Mdot
.38412 .33347 Mdot
.66426 .27009 Mdot
.43343 .69903 Mdot
.59882 .36925 Mdot
.64399 .38883 Mdot
.58523 .53017 Mdot
.32141 .56655 Mdot
.32476 .40373 Mdot
.48041 .6777 Mdot
.33022 .83644 Mdot
.47085 .70749 Mdot
.54333 .6859 Mdot
.41703 .33297 Mdot
.65701 .65469 Mdot
.63784 .45587 Mdot
.50123 .39131 Mdot
.43334 .31618 Mdot
.49379 .75376 Mdot
.65212 .66143 Mdot
.33747 .37075 Mdot
.29312 .59233 Mdot
.57039 .45541 Mdot
.65229 .45762 Mdot
.62491 .40037 Mdot
.65288 .40696 Mdot
.28341 .58606 Mdot
.65435 .42898 Mdot
.30894 .60902 Mdot
.52084 .28978 Mdot
.73137 .59771 Mdot
.43809 .74 Mdot
.30464 .71315 Mdot
.45429 .3692 Mdot
.42483 .23491 Mdot
.51618 .26843 Mdot
.59893 .54979 Mdot
.30858 .62678 Mdot
.57145 .46091 Mdot
.47665 .69625 Mdot
.25066 .63512 Mdot
.44065 .74205 Mdot
.18061 .34221 Mdot
.64729 .33556 Mdot
.36367 .40808 Mdot
.63806 .40475 Mdot
.42486 .72097 Mdot
.62127 .31876 Mdot
.66384 .48272 Mdot
.61878 .68391 Mdot
.50012 .29605 Mdot
.41747 .42517 Mdot
.66307 .66545 Mdot
.64551 .4329 Mdot
.39351 .3717 Mdot
.63261 .45928 Mdot
.64263 .45021 Mdot
.58193 .43643 Mdot
.33893 .59775 Mdot
.62428 .47568 Mdot
.63145 .46621 Mdot
.8043 .41905 Mdot
.45285 .63113 Mdot
.48072 .73333 Mdot
.70375 .29854 Mdot
.63926 .67446 Mdot
.46537 .34842 Mdot
.5226 .55226 Mdot
.29805 .5919 Mdot
.66648 .27158 Mdot
.62766 .40668 Mdot
.30754 .45966 Mdot
.29364 .54432 Mdot
.62703 .65675 Mdot
.39625 .47743 Mdot
.31861 .36925 Mdot
.47639 .68408 Mdot
.38087 .46777 Mdot
.44311 .71078 Mdot
.72722 .32239 Mdot
.40097 .35115 Mdot
.67957 .45497 Mdot
.30699 .5543 Mdot
.45559 .75118 Mdot
.67858 .5545 Mdot
.59661 .46241 Mdot
.45667 .68094 Mdot
.67514 .48763 Mdot
.57765 .55411 Mdot
.51749 .54868 Mdot
.45618 .75405 Mdot
.28395 .54734 Mdot
.31828 .56943 Mdot
.66468 .66296 Mdot
.46523 .36568 Mdot
.42467 .32214 Mdot
.3196 .57535 Mdot
.46126 .84184 Mdot
.60414 .43792 Mdot
.60175 .42828 Mdot
.45947 .45607 Mdot
.65218 .39948 Mdot
.64508 .71484 Mdot
.36615 .49518 Mdot
.42516 .31946 Mdot
.61895 .39076 Mdot
.62731 .39506 Mdot
.62642 .42035 Mdot
.68964 .57799 Mdot
.45518 .70576 Mdot
.61527 .41294 Mdot
.62502 .65055 Mdot
.41782 .45618 Mdot
.65105 .45331 Mdot
.67191 .47474 Mdot
.40194 .34227 Mdot
.51142 .77987 Mdot
.29658 .57685 Mdot
.43625 .71224 Mdot
.43713 .73118 Mdot
.74843 .56335 Mdot
.43688 .30038 Mdot
.37284 .47524 Mdot
.27225 .68301 Mdot
.39361 .47318 Mdot
.65343 .65846 Mdot
.45053 .5691 Mdot
.4844 .66712 Mdot
.47506 .73678 Mdot
.28698 .53912 Mdot
.58083 .40274 Mdot
.65376 .45043 Mdot
.31989 .48842 Mdot
.58664 .43336 Mdot
.65751 .67214 Mdot
.32856 .5959 Mdot
.40291 .35286 Mdot
.61968 .65037 Mdot
.30135 .56435 Mdot
.4365 .3254 Mdot
.59744 .3865 Mdot
.66086 .43754 Mdot
.4322 .35964 Mdot
.43226 .37246 Mdot
.60853 .45138 Mdot
.79416 .39691 Mdot
.43496 .32134 Mdot
.44063 .35777 Mdot
.41506 .4438 Mdot
.48626 .69961 Mdot
.59575 .35555 Mdot
.30767 .5985 Mdot
.62443 .46684 Mdot
.43307 .73454 Mdot
.64618 .65175 Mdot
.42222 .36457 Mdot
.58746 .41777 Mdot
.61196 .43326 Mdot
.63766 .66154 Mdot
.64051 .63163 Mdot
.64954 .685 Mdot
.34067 .57594 Mdot
.64463 .4205 Mdot
.44755 .34484 Mdot
.29199 .59195 Mdot
.61857 .67367 Mdot
.66704 .6578 Mdot
.77943 .39976 Mdot
.60135 .44371 Mdot
.61257 .66531 Mdot
.52477 .9097 Mdot
.75563 .45914 Mdot
.37352 .49906 Mdot
.44994 .66507 Mdot
.5901 .68488 Mdot
.65366 .70447 Mdot
.2848 .56346 Mdot
.47319 .61184 Mdot
.66699 .68136 Mdot
.58313 .42843 Mdot
.5829 .45002 Mdot
.63378 .4839 Mdot
.63947 .67827 Mdot
.69228 .58738 Mdot
.40389 .37663 Mdot
.53532 .22471 Mdot
.63947 .67453 Mdot
.46488 .75196 Mdot
.42844 .6857 Mdot
.47389 .71155 Mdot
.56333 .44752 Mdot
.70123 .27818 Mdot
.52687 .32099 Mdot
.50323 .25283 Mdot
.29042 .58707 Mdot
.38448 .33376 Mdot
.38373 .5152 Mdot
.42393 .35885 Mdot
.46078 .69356 Mdot
.62849 .6711 Mdot
.39555 .34641 Mdot
.32716 .58865 Mdot
.3208 .56919 Mdot
.44396 .68055 Mdot
.46162 .70898 Mdot
.46282 .72267 Mdot
.46247 .36952 Mdot
.41648 .33345 Mdot
.61958 .39679 Mdot
.42053 .36763 Mdot
.78592 .6425 Mdot
.62058 .70877 Mdot
.43455 .68451 Mdot
.30339 .58317 Mdot
.44323 .36271 Mdot
.58952 .46321 Mdot
.53057 .66084 Mdot
.50373 .72716 Mdot
.62416 .67763 Mdot
.19967 .45846 Mdot
.15394 .54082 Mdot
.55655 .43381 Mdot
.27724 .57063 Mdot
.71449 .47504 Mdot
.61116 .46316 Mdot
.47241 .68596 Mdot
.7996 .59319 Mdot
.39906 .48277 Mdot
.64156 .45806 Mdot
.62616 .38335 Mdot
.33035 .57899 Mdot
.52178 .55071 Mdot
.5812 .4295 Mdot
.454 .59283 Mdot
.307 .54123 Mdot
.47857 .6769 Mdot
.85308 .4511 Mdot
.42382 .48378 Mdot
.6938 .61424 Mdot
.37985 .50072 Mdot
.58682 .42997 Mdot
.45105 .72095 Mdot
.61929 .66218 Mdot
.45606 .71621 Mdot
.4507 .32359 Mdot
.48171 .69108 Mdot
.5777 .4494 Mdot
.44497 .33941 Mdot
.30417 .56694 Mdot
.48361 .59515 Mdot
.7389 .35515 Mdot
.46837 .7453 Mdot
.37777 .50489 Mdot
.65066 .43865 Mdot
.45118 .25621 Mdot
.59384 .37871 Mdot
.63357 .46758 Mdot
.29805 .54986 Mdot
.4367 .3447 Mdot
.31383 .54459 Mdot
.68084 .47177 Mdot
.38815 .26184 Mdot
.29736 .58629 Mdot
.47901 .40529 Mdot
.64322 .68963 Mdot
.68245 .58198 Mdot
.63119 .44662 Mdot
.30405 .55477 Mdot
.63802 .41751 Mdot
.41881 .38121 Mdot
.62998 .56342 Mdot
.55452 .5239 Mdot
.32726 .56253 Mdot
.37157 .4005 Mdot
.58043 .56288 Mdot
.56235 .36337 Mdot
.2934 .56465 Mdot
.72656 .29432 Mdot
.38685 .4892 Mdot
.63196 .65896 Mdot
.6335 .63154 Mdot
.64351 .64225 Mdot
.58929 .4334 Mdot
.47755 .29782 Mdot
.66142 .6472 Mdot
.33629 .56196 Mdot
.6472 .63827 Mdot
.7358 .68056 Mdot
.2965 .48967 Mdot
.63776 .68686 Mdot
.63051 .44136 Mdot
.66155 .50635 Mdot
.47494 .61219 Mdot
.49453 .72443 Mdot
.31823 .31478 Mdot
.80336 .42477 Mdot
.59616 .43774 Mdot
.45305 .27995 Mdot
.43645 .31083 Mdot
.56352 .63691 Mdot
.55443 .52173 Mdot
.4601 .54348 Mdot
.44182 .36103 Mdot
.51345 .53562 Mdot
.4524 .33213 Mdot
.67903 .4212 Mdot
.61964 .42973 Mdot
.46984 .3604 Mdot
.23641 .4681 Mdot
.69893 .25317 Mdot
.29977 .47705 Mdot
.45283 .34072 Mdot
.29435 .56629 Mdot
.28402 .55814 Mdot
.29806 .55042 Mdot
.4467 .72566 Mdot
.41087 .36934 Mdot
.609 .41841 Mdot
.48283 .7193 Mdot
.64167 .44516 Mdot
.32422 .57707 Mdot
.58351 .54328 Mdot
.40231 .35086 Mdot
.62359 .45151 Mdot
.58751 .33361 Mdot
.44583 .70529 Mdot
.63562 .66549 Mdot
.20614 .42994 Mdot
.4628 .66345 Mdot
.27171 .56157 Mdot
.39906 .31313 Mdot
.4159 .72543 Mdot
.52246 .7147 Mdot
.65083 .46816 Mdot
.65693 .45766 Mdot
.47557 .62144 Mdot
.63922 .32916 Mdot
.57728 .43176 Mdot
.47981 .72766 Mdot
.49019 .71539 Mdot
.63715 .41837 Mdot
.42022 .37682 Mdot
.67196 .66708 Mdot
.64779 .69699 Mdot
.67861 .42883 Mdot
.50494 .52259 Mdot
.67231 .55803 Mdot
.63557 .39445 Mdot
.61381 .48743 Mdot
.47778 .74996 Mdot
.37701 .50197 Mdot
.49392 .50006 Mdot
.65699 .64918 Mdot
.63224 .4279 Mdot
.64859 .23043 Mdot
.41444 .36889 Mdot
.45112 .6814 Mdot
.29895 .60061 Mdot
.61998 .68113 Mdot
.44653 .67637 Mdot
.63715 .41843 Mdot
.62758 .39485 Mdot
.31164 .55582 Mdot
.44773 .31165 Mdot
.6339 .67767 Mdot
.48371 .71854 Mdot
.65836 .65577 Mdot
.41412 .33481 Mdot
.43613 .36648 Mdot
.65451 .39281 Mdot
.5884 .3765 Mdot
.45509 .74435 Mdot
.65601 .4775 Mdot
.47619 .72233 Mdot
.29113 .70145 Mdot
.28084 .59002 Mdot
.60804 .38724 Mdot
.42406 .2976 Mdot
.32316 .57575 Mdot
.59359 .44293 Mdot
.47467 .6223 Mdot
.58323 .40777 Mdot
.43404 .74365 Mdot
.81666 .56041 Mdot
.64306 .64638 Mdot
.58016 .50774 Mdot
.71412 .36995 Mdot
.64628 .39536 Mdot
.49167 .72294 Mdot
.49932 .30622 Mdot
.30235 .59002 Mdot
.42321 .3325 Mdot
.48574 .80854 Mdot
.3099 .57877 Mdot
.63233 .43595 Mdot
.65001 .6736 Mdot
.45542 .33974 Mdot
.37507 .48207 Mdot
.48483 .51099 Mdot
.66128 .50171 Mdot
.65387 .38202 Mdot
.56984 .44563 Mdot
.22298 .64382 Mdot
.46024 .72092 Mdot
.44287 .35059 Mdot
.27876 .57104 Mdot
.31742 .59147 Mdot
.45221 .70101 Mdot
.41427 .42951 Mdot
.2653 .4725 Mdot
.56514 .90076 Mdot
.44159 .67799 Mdot
.64371 .63922 Mdot
.62481 .56186 Mdot
.47524 .70933 Mdot
.44253 .71983 Mdot
.49004 .74087 Mdot
.31092 .49057 Mdot
.45185 .34087 Mdot
.61075 .43228 Mdot
.38137 .31877 Mdot
.58799 .43084 Mdot
.67395 .60337 Mdot
.3229 .57918 Mdot
.42194 .33209 Mdot
.69303 .64333 Mdot
.5877 .4943 Mdot
.60852 .45892 Mdot
.65999 .60685 Mdot
.61863 .52763 Mdot
.75938 .49531 Mdot
.66258 .41658 Mdot
.45221 .71234 Mdot
.36469 .31074 Mdot
.65879 .48335 Mdot
.58144 .33522 Mdot
.31577 .566 Mdot
.38497 .4692 Mdot
.6827 .44829 Mdot
.58993 .48222 Mdot
.4578 .34352 Mdot
.39625 .34179 Mdot
.66367 .64945 Mdot
.21795 .3934 Mdot
.31212 .56523 Mdot
.34303 .41592 Mdot
.63712 .46671 Mdot
.33958 .61513 Mdot
.81011 .58226 Mdot
.5963 .44782 Mdot
.43076 .59261 Mdot
.66504 .27118 Mdot
.57525 .42263 Mdot
.50939 .24752 Mdot
.30854 .58405 Mdot
.73327 .61748 Mdot
.65215 .41668 Mdot
.46535 .68385 Mdot
.42784 .32786 Mdot
.39252 .36029 Mdot
.61823 .66475 Mdot
.80806 .61879 Mdot
.19227 .56502 Mdot
.41932 .33115 Mdot
.60299 .46496 Mdot
.29787 .57787 Mdot
.37769 .47579 Mdot
.65758 .49915 Mdot
.31152 .63887 Mdot
.41281 .36573 Mdot
.65068 .48729 Mdot
.3022 .4596 Mdot
.51657 .54363 Mdot
.36463 .23267 Mdot
.30632 .54861 Mdot
.65984 .65129 Mdot
.59044 .3647 Mdot
.27335 .6868 Mdot
.66084 .43876 Mdot
.68092 .60638 Mdot
.46527 .32034 Mdot
.66174 .66552 Mdot
.61917 .46154 Mdot
.57966 .42796 Mdot
.52658 .52694 Mdot
.63546 .62923 Mdot
.58094 .42871 Mdot
.55451 .45714 Mdot
.41663 .32627 Mdot
.36616 .49649 Mdot
.40382 .35319 Mdot
.63047 .45914 Mdot
.81239 .53406 Mdot
.4054 .36933 Mdot
.32324 .32504 Mdot
.59401 .63932 Mdot
.29666 .59065 Mdot
.63733 .49932 Mdot
.60618 .47318 Mdot
.31929 .24046 Mdot
.37302 .48059 Mdot
.37401 .8146 Mdot
.42633 .72491 Mdot
.78818 .31099 Mdot
.46613 .66402 Mdot
.36223 .39206 Mdot
.44696 .62498 Mdot
.63752 .48753 Mdot
.54554 .36549 Mdot
.49406 .24782 Mdot
.34464 .60575 Mdot
.43475 .23746 Mdot
.64085 .46378 Mdot
.62934 .42371 Mdot
.48036 .71233 Mdot
.39074 .43848 Mdot
.70482 .48151 Mdot
.49486 .50232 Mdot
.62711 .6588 Mdot
.41766 .34734 Mdot
.58192 .45231 Mdot
.22123 .46541 Mdot
.46502 .74911 Mdot
.74513 .38223 Mdot
.62498 .44937 Mdot
.69411 .49603 Mdot
.39389 .44371 Mdot
.30127 .56804 Mdot
.45689 .75443 Mdot
.47217 .74942 Mdot
.58981 .42845 Mdot
.28806 .59169 Mdot
.6046 .39851 Mdot
.59229 .56638 Mdot
.66719 .48935 Mdot
.65102 .65533 Mdot
.61573 .47036 Mdot
.73359 .38198 Mdot
.43915 .17979 Mdot
.55629 .46493 Mdot
.46086 .36374 Mdot
.46479 .72547 Mdot
.45908 .70206 Mdot
.42779 .32204 Mdot
.45906 .70134 Mdot
.53683 .23051 Mdot
.41918 .26059 Mdot
.65525 .65901 Mdot
.53527 .28425 Mdot
.63623 .64887 Mdot
.38611 .46882 Mdot
.60271 .44637 Mdot
.37178 .67126 Mdot
.44835 .6742 Mdot
.7437 .67398 Mdot
.31839 .5783 Mdot
.37104 .48326 Mdot
.65132 .43338 Mdot
.68008 .62992 Mdot
.46749 .69202 Mdot
.42712 .53747 Mdot
.60041 .42503 Mdot
.43621 .38174 Mdot
.57718 .41931 Mdot
.55679 .40788 Mdot
.36846 .48626 Mdot
.56559 .43249 Mdot
.30118 .56444 Mdot
.40265 .36151 Mdot
.36746 .41848 Mdot
.43994 .72158 Mdot
.64807 .45003 Mdot
.60509 .46485 Mdot
.40865 .31473 Mdot
.6444 .47014 Mdot
.28524 .58125 Mdot
.77813 .76002 Mdot
.65127 .68719 Mdot
.37832 .50206 Mdot
.26783 .34722 Mdot
.57004 .42967 Mdot
.6166 .39282 Mdot
.44625 .51424 Mdot
.65301 .23383 Mdot
.2926 .57838 Mdot
.65998 .38716 Mdot
.48522 .72719 Mdot
.63326 .67851 Mdot
.33339 .56706 Mdot
.65045 .42527 Mdot
.61665 .42473 Mdot
.66048 .66742 Mdot
.65613 .6035 Mdot
.60982 .67921 Mdot
.28419 .57064 Mdot
.4273 .27313 Mdot
.53148 .66039 Mdot
.61044 .4409 Mdot
.39295 .5016 Mdot
.43554 .34835 Mdot
.29029 .56798 Mdot
.62306 .23042 Mdot
.67808 .4175 Mdot
.27564 .58756 Mdot
.30627 .56608 Mdot
.6388 .47321 Mdot
.44312 .30305 Mdot
.38466 .32136 Mdot
.43799 .35045 Mdot
.73659 .59046 Mdot
.29642 .75874 Mdot
.45964 .72456 Mdot
.30324 .57996 Mdot
.43099 .72984 Mdot
.66486 .68439 Mdot
.59432 .55696 Mdot
.47634 .74463 Mdot
.44351 .38193 Mdot
.43647 .73522 Mdot
.60301 .3982 Mdot
.32396 .59454 Mdot
.44663 .73957 Mdot
.65039 .40143 Mdot
.57947 .47459 Mdot
.53712 .38696 Mdot
.67283 .67367 Mdot
.51164 .53526 Mdot
.63539 .44137 Mdot
.39579 .47927 Mdot
.61393 .45136 Mdot
.28487 .58377 Mdot
.48688 .59971 Mdot
.62035 .40989 Mdot
.44691 .67459 Mdot
.32871 .78578 Mdot
.49119 .7051 Mdot
.54728 .41536 Mdot
.63278 .45469 Mdot
.60677 .44056 Mdot
.65008 .43409 Mdot
.41251 .42398 Mdot
.26819 .57689 Mdot
.63787 .36468 Mdot
.43239 .69445 Mdot
.42582 .36147 Mdot
.40492 .37138 Mdot
.45023 .5376 Mdot
.3837 .46628 Mdot
.29594 .59682 Mdot
.6059 .43916 Mdot
.42763 .54064 Mdot
.47086 .49616 Mdot
.2976 .46839 Mdot
.41343 .70221 Mdot
.47239 .73913 Mdot
.45695 .37082 Mdot
.45913 .73846 Mdot
.6526 .42863 Mdot
.64705 .48785 Mdot
.36498 .4138 Mdot
.31362 .61547 Mdot
.63144 .67579 Mdot
.63943 .45051 Mdot
.68808 .5651 Mdot
.48576 .71829 Mdot
.47694 .7496 Mdot
.60852 .39809 Mdot
.42964 .30541 Mdot
.49445 .14486 Mdot
.30746 .60006 Mdot
.45172 .26067 Mdot
.39025 .3911 Mdot
.57032 .52644 Mdot
.31063 .59086 Mdot
.44058 .58669 Mdot
.49734 .7164 Mdot
.82398 .51139 Mdot
.43123 .36225 Mdot
.63236 .67537 Mdot
.6604 .42244 Mdot
.44447 .38167 Mdot
.42413 .70646 Mdot
.4434 .32381 Mdot
.67941 .45822 Mdot
.321 .5465 Mdot
.46701 .70297 Mdot
.3062 .53583 Mdot
.45824 .33509 Mdot
.63846 .64761 Mdot
.73422 .6311 Mdot
.47136 .27005 Mdot
.66343 .27113 Mdot
.61411 .41321 Mdot
.39231 .64163 Mdot
.60556 .41922 Mdot
.40469 .38097 Mdot
.63133 .4459 Mdot
.59363 .50049 Mdot
.49898 .71358 Mdot
.66537 .43868 Mdot
.62175 .46964 Mdot
.56623 .33831 Mdot
.5999 .45295 Mdot
.63648 .42074 Mdot
.65081 .38729 Mdot
.47229 .34164 Mdot
.66563 .43288 Mdot
.44058 .38064 Mdot
.31762 .4718 Mdot
.4402 .71667 Mdot
.66446 .68364 Mdot
.65689 .68936 Mdot
.69458 .61857 Mdot
.68736 .56996 Mdot
.40325 .43591 Mdot
.40912 .3548 Mdot
.32271 .56634 Mdot
.60947 .39691 Mdot
.73692 .30731 Mdot
.80385 .54026 Mdot
.49594 .69995 Mdot
.44589 .74249 Mdot
.6592 .42914 Mdot
.15643 .5229 Mdot
.66358 .43283 Mdot
.4581 .46045 Mdot
.59106 .43213 Mdot
.60437 .38756 Mdot
.46232 .7559 Mdot
.7051 .6065 Mdot
.61552 .41301 Mdot
.45765 .34258 Mdot
.63057 .66828 Mdot
.66823 .51204 Mdot
.79495 .56758 Mdot
.54035 .36293 Mdot
.72412 .41468 Mdot
.62967 .41032 Mdot
.48376 .70615 Mdot
.45478 .34269 Mdot
.46769 .47099 Mdot
.28764 .58407 Mdot
.49508 .51969 Mdot
.51261 .2858 Mdot
.36259 .56661 Mdot
.62923 .67024 Mdot
.46599 .76408 Mdot
.57577 .44723 Mdot
.45051 .72669 Mdot
.66708 .39455 Mdot
.46811 .50281 Mdot
.65357 .65516 Mdot
.46423 .37455 Mdot
.29455 .56663 Mdot
.41827 .38367 Mdot
.71078 .30643 Mdot
.80646 .53691 Mdot
.79188 .31461 Mdot
.475 .6809 Mdot
.54218 .18499 Mdot
.43859 .33889 Mdot
.5988 .42368 Mdot
.56145 .9009 Mdot
.42972 .34436 Mdot
.43944 .38187 Mdot
.4715 .5478 Mdot
.71564 .60446 Mdot
.66111 .4742 Mdot
.42947 .31913 Mdot
.45552 .76305 Mdot
.64863 .66359 Mdot
.64745 .40121 Mdot
.68135 .45479 Mdot
.39597 .34533 Mdot
.46268 .69088 Mdot
.67638 .5962 Mdot
.45657 .70972 Mdot
.44996 .34002 Mdot
.44304 .70097 Mdot
.33091 .34679 Mdot
.47197 .74624 Mdot
.60954 .47166 Mdot
.60711 .43917 Mdot
.37366 .6081 Mdot
.43609 .36649 Mdot
.61709 .39253 Mdot
.62484 .42574 Mdot
.44524 .34378 Mdot
.48796 .66874 Mdot
.60225 .20894 Mdot
.60754 .39367 Mdot
.60717 .43521 Mdot
.65621 .68561 Mdot
.55271 .54693 Mdot
.45039 .45804 Mdot
.64588 .39739 Mdot
.64071 .64136 Mdot
.45868 .37274 Mdot
.61241 .45228 Mdot
.70686 .6089 Mdot
.44928 .66915 Mdot
.63761 .40824 Mdot
.38031 .47554 Mdot
.58016 .43494 Mdot
.4783 .15327 Mdot
.65111 .44159 Mdot
.44775 .35341 Mdot
.43356 .33108 Mdot
.40924 .73271 Mdot
.42612 .35665 Mdot
.37302 .49754 Mdot
.31873 .57072 Mdot
.38382 .2368 Mdot
.37142 .49486 Mdot
.56341 .43201 Mdot
.83055 .58234 Mdot
.68057 .4589 Mdot
.67127 .47849 Mdot
.73405 .70527 Mdot
.3791 .5003 Mdot
.43387 .3406 Mdot
.23612 .46016 Mdot
.65855 .47105 Mdot
.29882 .59858 Mdot
.66656 .47866 Mdot
.63734 .40849 Mdot
.56382 .48101 Mdot
.41648 .26656 Mdot
.32326 .60174 Mdot
.58916 .35645 Mdot
.64694 .40093 Mdot
.65383 .235 Mdot
.58778 .45973 Mdot
.62895 .6844 Mdot
.40667 .34175 Mdot
.45541 .73579 Mdot
.6498 .65794 Mdot
.57251 .44014 Mdot
.64044 .67692 Mdot
.45305 .72555 Mdot
.30841 .55165 Mdot
.60382 .47066 Mdot
.65721 .63677 Mdot
.62744 .66977 Mdot
.60104 .40765 Mdot
.42277 .32978 Mdot
.59416 .3806 Mdot
.60895 .45233 Mdot
.64727 .42613 Mdot
.42273 .32239 Mdot
.63045 .82707 Mdot
.62856 .42119 Mdot
.43767 .58894 Mdot
.43457 .39567 Mdot
.36773 .4959 Mdot
.47388 .73357 Mdot
.55642 .45786 Mdot
.31648 .59343 Mdot
.31832 .57285 Mdot
.46206 .67237 Mdot
.39932 .33393 Mdot
.46432 .7 Mdot
.55817 .47009 Mdot
.64941 .48658 Mdot
.65975 .42205 Mdot
.48309 .81017 Mdot
.31379 .35881 Mdot
.4433 .36832 Mdot
.49472 .71467 Mdot
.49742 .51521 Mdot
.31774 .59812 Mdot
.4712 .75579 Mdot
.38095 .35527 Mdot
.40623 .32325 Mdot
.43257 .32216 Mdot
.62931 .64841 Mdot
.46757 .70859 Mdot
.37689 .34618 Mdot
.38637 .32134 Mdot
.60955 .4006 Mdot
.64431 .40151 Mdot
.47175 .35385 Mdot
.46814 .78049 Mdot
.64133 .65082 Mdot
.48431 .70168 Mdot
.44684 .1411 Mdot
.30574 .60016 Mdot
.5706 .33762 Mdot
.6501 .39966 Mdot
.38744 .87723 Mdot
.66387 .42926 Mdot
.59851 .46423 Mdot
.46574 .34814 Mdot
.62156 .63953 Mdot
.64653 .66594 Mdot
.43812 .33775 Mdot
.3938 .32376 Mdot
.62259 .6673 Mdot
.46451 .55557 Mdot
.52118 .15774 Mdot
.47466 .48645 Mdot
.44995 .36153 Mdot
.47316 .26716 Mdot
.32827 .56129 Mdot
.44215 .39155 Mdot
.29716 .53165 Mdot
.43841 .71464 Mdot
.46314 .74661 Mdot
.31583 .55657 Mdot
.63135 .42027 Mdot
.46613 .6804 Mdot
.54655 .45454 Mdot
.35375 .38854 Mdot
.32397 .63327 Mdot
.77337 .32963 Mdot
.61805 .47359 Mdot
.70828 .48595 Mdot
.25577 .53396 Mdot
.56643 .42242 Mdot
.67805 .35318 Mdot
.63534 .67763 Mdot
.44189 .39387 Mdot
.33628 .58828 Mdot
.33065 .26549 Mdot
.6089 .44051 Mdot
.45368 .35476 Mdot
.31674 .60059 Mdot
.33473 .37249 Mdot
.45382 .59213 Mdot
.58669 .41065 Mdot
.61246 .88302 Mdot
.44532 .32285 Mdot
.45587 .73572 Mdot
.55795 .32519 Mdot
.43015 .38705 Mdot
.49995 .6502 Mdot
.42757 .74023 Mdot
.49003 .48029 Mdot
.4227 .31661 Mdot
.61171 .68558 Mdot
.41342 .34391 Mdot
.62826 .64007 Mdot
.39998 .31302 Mdot
.4514 .69626 Mdot
.61699 .45845 Mdot
.44887 .70135 Mdot
.62932 .68725 Mdot
.469 .67703 Mdot
.33621 .58825 Mdot
.38801 .4977 Mdot
.32512 .57527 Mdot
.60992 .5591 Mdot
.60038 .23126 Mdot
.29212 .55825 Mdot
.42343 .56591 Mdot
.58038 .44048 Mdot
.4534 .31737 Mdot
.45014 .73268 Mdot
.48668 .67631 Mdot
.50946 .53041 Mdot
.44247 .33045 Mdot
.45663 .68973 Mdot
.47836 .27451 Mdot
.45895 .84694 Mdot
.61083 .49793 Mdot
.28532 .73629 Mdot
.44749 .34796 Mdot
.4974 .72481 Mdot
.45868 .4562 Mdot
.39533 .35972 Mdot
.45067 .74252 Mdot
.29614 .56203 Mdot
.31181 .59442 Mdot
.6434 .46973 Mdot
.33198 .5491 Mdot
.49004 .73091 Mdot
.6523 .23145 Mdot
.40962 .33216 Mdot
.30089 .3491 Mdot
.63866 .6858 Mdot
.44465 .72234 Mdot
.66578 .4557 Mdot
.42112 .2964 Mdot
.43189 .72484 Mdot
.18095 .55586 Mdot
.3747 .18102 Mdot
.45736 .68895 Mdot
.40639 .34291 Mdot
.42075 .36314 Mdot
.56627 .47465 Mdot
.50098 .51405 Mdot
.46525 .68941 Mdot
.37083 .67064 Mdot
.6918 .54846 Mdot
.37515 .49222 Mdot
.80372 .42187 Mdot
.61723 .4133 Mdot
.63057 .40991 Mdot
.28352 .57516 Mdot
.60326 .45802 Mdot
.389 .32631 Mdot
.66364 .42565 Mdot
.29833 .54545 Mdot
.47231 .67531 Mdot
.6059 .44499 Mdot
.63476 .68088 Mdot
.3081 .54537 Mdot
.27873 .56165 Mdot
.43896 .70456 Mdot
.4125 .32531 Mdot
.22768 .49066 Mdot
.45841 .70873 Mdot
.643 .4186 Mdot
.39106 .48931 Mdot
.66371 .4124 Mdot
.37844 .60035 Mdot
.40026 .37509 Mdot
.45933 .73809 Mdot
.47166 .36558 Mdot
.30294 .57575 Mdot
.49882 .70207 Mdot
.57384 .44752 Mdot
.46794 .74327 Mdot
.42525 .60998 Mdot
.55827 .72447 Mdot
.3898 .32057 Mdot
.46943 .62115 Mdot
.39848 .33164 Mdot
.37427 .49107 Mdot
.74652 .55653 Mdot
.63434 .65582 Mdot
.48905 .71312 Mdot
.32253 .32753 Mdot
.44162 .72764 Mdot
.5958 .45034 Mdot
.61312 .42391 Mdot
.48013 .71484 Mdot
.63684 .64579 Mdot
.71289 .66019 Mdot
.64039 .71148 Mdot
.41001 .36729 Mdot
.47655 .59219 Mdot
.47489 .13714 Mdot
.42027 .68975 Mdot
.31948 .56288 Mdot
.70836 .38601 Mdot
.57313 .42551 Mdot
.32037 .6012 Mdot
.27832 .5838 Mdot
.61609 .6677 Mdot
.44235 .72285 Mdot
.41214 .38949 Mdot
.33387 .57348 Mdot
.40976 .29447 Mdot
.69178 .6032 Mdot
.66975 .39497 Mdot
.53843 .49001 Mdot
.57096 .45895 Mdot
.51587 .54341 Mdot
.30737 .5421 Mdot
.62829 .43567 Mdot
.58243 .36299 Mdot
.2889 .57546 Mdot
.616 .65789 Mdot
.44818 .29232 Mdot
.45271 .68916 Mdot
.4219 .86487 Mdot
.60708 .47078 Mdot
.61463 .45592 Mdot
.29103 .58785 Mdot
.64504 .32652 Mdot
.44392 .37149 Mdot
.40984 .32788 Mdot
.461 .7211 Mdot
.46371 .51364 Mdot
.64491 .47062 Mdot
.58544 .46243 Mdot
.46246 .68198 Mdot
.39514 .47922 Mdot
.80722 .39192 Mdot
.6142 .43392 Mdot
.30946 .58689 Mdot
.41103 .61123 Mdot
.31367 .54207 Mdot
.55962 .42032 Mdot
.59174 .44643 Mdot
.57306 .45511 Mdot
.60934 .47562 Mdot
.32789 .56622 Mdot
.57001 .44441 Mdot
.6613 .38467 Mdot
.43523 .34424 Mdot
.62615 .4116 Mdot
.69485 .54485 Mdot
.61467 .43723 Mdot
.63721 .68142 Mdot
.45108 .46777 Mdot
.64919 .44518 Mdot
.62824 .41187 Mdot
.68734 .55265 Mdot
.6185 .46331 Mdot
.31875 .6007 Mdot
.4272 .36445 Mdot
.3013 .57592 Mdot
.31441 .56268 Mdot
.43524 .73114 Mdot
.63284 .63499 Mdot
.59343 .47861 Mdot
.62145 .65929 Mdot
.57645 .48595 Mdot
.67965 .47449 Mdot
.58109 .55652 Mdot
.45909 .46316 Mdot
.66647 .68455 Mdot
.5799 .45639 Mdot
.45488 .72165 Mdot
.46086 .73961 Mdot
.47279 .61237 Mdot
.65912 .49229 Mdot
.33666 .57573 Mdot
.30331 .55505 Mdot
.62896 .71384 Mdot
.56715 .67768 Mdot
.62653 .67065 Mdot
.61838 .58502 Mdot
.60609 .38489 Mdot
.64009 .42883 Mdot
.67027 .49305 Mdot
.42987 .73269 Mdot
.38709 .49887 Mdot
.45371 .67715 Mdot
.38603 .45384 Mdot
.33008 .56036 Mdot
.61914 .47337 Mdot
.15788 .47905 Mdot
.40995 .37077 Mdot
.42743 .36503 Mdot
.29759 .5455 Mdot
.49153 .70759 Mdot
.6664 .48877 Mdot
.33247 .81204 Mdot
.38873 .34796 Mdot
.66732 .67213 Mdot
.62996 .46213 Mdot
.43978 .71204 Mdot
.39983 .35479 Mdot
.66261 .64329 Mdot
.60198 .47353 Mdot
.4378 .75258 Mdot
.62551 .44031 Mdot
.53457 .26101 Mdot
.42795 .33624 Mdot
.5516 .53281 Mdot
.46623 .33715 Mdot
.3279 .57159 Mdot
.29409 .57532 Mdot
.59311 .44349 Mdot
.37909 .84225 Mdot
.3789 .29994 Mdot
.2848 .5972 Mdot
.66005 .64264 Mdot
.39381 .49252 Mdot
.65486 .63901 Mdot
.47684 .72048 Mdot
.62938 .66694 Mdot
.4326 .72493 Mdot
.47166 .78059 Mdot
.39621 .38562 Mdot
.65967 .66885 Mdot
.68056 .32652 Mdot
.6456 .48863 Mdot
.62187 .68024 Mdot
.65705 .42194 Mdot
.5705 .48474 Mdot
.45304 .68422 Mdot
.62593 .65433 Mdot
.58807 .41712 Mdot
.26915 .34158 Mdot
.30035 .56611 Mdot
.33689 .58204 Mdot
.64875 .48603 Mdot
.4933 .73503 Mdot
.39497 .3175 Mdot
.54669 .55886 Mdot
.36715 .50098 Mdot
.58787 .46374 Mdot
.56263 .45164 Mdot
.45066 .32578 Mdot
.45524 .36865 Mdot
.59081 .44254 Mdot
.452 .26815 Mdot
.5729 .44308 Mdot
.30802 .59476 Mdot
.41058 .36877 Mdot
.42248 .36509 Mdot
.48564 .73621 Mdot
.39832 .33864 Mdot
.62174 .36935 Mdot
.34036 .606 Mdot
.67415 .43241 Mdot
.3059 .57704 Mdot
.43813 .77454 Mdot
.43402 .69848 Mdot
.32023 .3254 Mdot
.39922 .33821 Mdot
.61791 .39082 Mdot
.40709 .37273 Mdot
.65111 .68406 Mdot
.43277 .36799 Mdot
.45021 .32091 Mdot
.6455 .46227 Mdot
.58301 .42685 Mdot
.39303 .48048 Mdot
.50666 .52211 Mdot
.42206 .33685 Mdot
.57228 .41437 Mdot
.64732 .39372 Mdot
.60798 .42357 Mdot
.573 .56026 Mdot
.46767 .36402 Mdot
.5349 .36608 Mdot
.37386 .56036 Mdot
.41925 .33382 Mdot
.39459 .18781 Mdot
.39224 .47214 Mdot
.3861 .46464 Mdot
.27878 .55033 Mdot
.60977 .43302 Mdot
.45938 .69891 Mdot
.63337 .40997 Mdot
.63903 .50466 Mdot
.64677 .44971 Mdot
.66138 .66913 Mdot
.65221 .46747 Mdot
.37914 .48437 Mdot
.45262 .70906 Mdot
.57216 .41672 Mdot
.6019 .44068 Mdot
.38679 .46588 Mdot
.47248 .35271 Mdot
.4041 .32628 Mdot
.36099 .51439 Mdot
.61833 .67095 Mdot
.29395 .55153 Mdot
.64131 .41606 Mdot
.45826 .72101 Mdot
.45245 .70208 Mdot
.42715 .38382 Mdot
.4704 .68569 Mdot
.2971 .54809 Mdot
.59148 .4604 Mdot
.32772 .57064 Mdot
.66135 .66957 Mdot
.40687 .34102 Mdot
.65379 .42938 Mdot
.60379 .40314 Mdot
.43343 .33117 Mdot
.57775 .43403 Mdot
.66246 .67372 Mdot
.44139 .74679 Mdot
.43465 .37104 Mdot
.31755 .57077 Mdot
.4809 .74092 Mdot
.61554 .39495 Mdot
.29674 .23068 Mdot
.60136 .45767 Mdot
.58612 .46456 Mdot
.35829 .3605 Mdot
.62856 .3865 Mdot
.44016 .72388 Mdot
.40137 .36667 Mdot
.55574 .43519 Mdot
.68819 .55465 Mdot
.6132 .63863 Mdot
.41705 .71015 Mdot
.62341 .46642 Mdot
.35903 .23191 Mdot
.64003 .39263 Mdot
.32705 .31694 Mdot
.57993 .55584 Mdot
.24792 .65033 Mdot
.5382 .48939 Mdot
.28117 .59433 Mdot
.39491 .48347 Mdot
.43358 .71303 Mdot
.62934 .31154 Mdot
.58937 .4501 Mdot
.66301 .26478 Mdot
.65225 .42573 Mdot
.31156 .59154 Mdot
.66811 .35343 Mdot
.48139 .6962 Mdot
.79801 .41883 Mdot
.6217 .41742 Mdot
.44767 .32596 Mdot
.50137 .7266 Mdot
.39786 .47677 Mdot
.5878 .42245 Mdot
.62564 .67712 Mdot
.60475 .68493 Mdot
.61623 .36953 Mdot
.30598 .57471 Mdot
.63205 .4267 Mdot
.54567 .44519 Mdot
.47823 .83476 Mdot
.44033 .35065 Mdot
.30614 .55991 Mdot
.57851 .64661 Mdot
.60728 .42502 Mdot
.40677 .32341 Mdot
.42953 .36189 Mdot
.62017 .65465 Mdot
.24457 .599 Mdot
.69991 .70622 Mdot
.17763 .40021 Mdot
.70248 .28458 Mdot
.43226 .73766 Mdot
.49135 .37066 Mdot
.62128 .40538 Mdot
.8078 .53648 Mdot
.31753 .56477 Mdot
.61786 .45707 Mdot
.66855 .28241 Mdot
.44078 .35716 Mdot
.62274 .43612 Mdot
.64118 .65193 Mdot
.23549 .5236 Mdot
.50428 .29503 Mdot
.30495 .24804 Mdot
.45281 .76253 Mdot
.6666 .46934 Mdot
.64469 .37524 Mdot
.36871 .49765 Mdot
.55801 .42726 Mdot
.44913 .73069 Mdot
.39658 .62698 Mdot
.65132 .64717 Mdot
.40711 .36852 Mdot
.39552 .47271 Mdot
.65227 .42493 Mdot
.67176 .40658 Mdot
.66698 .66416 Mdot
.59584 .42155 Mdot
.54518 .32999 Mdot
.39919 .46166 Mdot
.46968 .74754 Mdot
.44765 .32726 Mdot
.5675 .45492 Mdot
.39467 .4895 Mdot
.65041 .4573 Mdot
.73757 .39301 Mdot
.63664 .45243 Mdot
.35666 .29586 Mdot
.42694 .32748 Mdot
.30849 .56945 Mdot
.65012 .47134 Mdot
.6192 .44383 Mdot
.5485 .67387 Mdot
.66401 .48873 Mdot
.64782 .43414 Mdot
.4229 .38574 Mdot
.4105 .37224 Mdot
.45507 .35816 Mdot
.48389 .73571 Mdot
.4783 .4877 Mdot
.31849 .58313 Mdot
.66899 .49308 Mdot
.33398 .56982 Mdot
.53031 .47621 Mdot
.66219 .65069 Mdot
.3121 .32493 Mdot
.58535 .45292 Mdot
.44064 .327 Mdot
.55579 .1698 Mdot
.45657 .37537 Mdot
.35541 .52778 Mdot
.31412 .56538 Mdot
.42656 .34291 Mdot
.61676 .46514 Mdot
.49935 .50628 Mdot
.28018 .26331 Mdot
.32017 .59692 Mdot
.67294 .47116 Mdot
.43928 .7608 Mdot
.46335 .66973 Mdot
.41566 .18619 Mdot
.32829 .5881 Mdot
.25143 .53881 Mdot
.60449 .39434 Mdot
.39898 .35956 Mdot
.29884 .55124 Mdot
.29818 .60192 Mdot
.46956 .68386 Mdot
.5946 .40494 Mdot
.62043 .44202 Mdot
.38271 .47344 Mdot
.32012 .55592 Mdot
.56858 .50761 Mdot
.58197 .41481 Mdot
.36489 .4024 Mdot
.38645 .367 Mdot
.64239 .82016 Mdot
.56624 .35809 Mdot
.66616 .27879 Mdot
.3992 .72512 Mdot
.4356 .37279 Mdot
.63114 .41904 Mdot
.66974 .48862 Mdot
.43804 .74705 Mdot
.59706 .46108 Mdot
.49403 .70218 Mdot
.32927 .57783 Mdot
.30994 .30573 Mdot
.43211 .55092 Mdot
.29761 .62737 Mdot
.60287 .45603 Mdot
.49896 .29514 Mdot
.65787 .66712 Mdot
.3112 .61445 Mdot
.44813 .373 Mdot
.56512 .41404 Mdot
.42499 .72482 Mdot
.4853 .73219 Mdot
.43429 .3571 Mdot
.33081 .4875 Mdot
.32213 .32015 Mdot
.59478 .47354 Mdot
.47546 .72918 Mdot
.42417 .49347 Mdot
.42774 .23592 Mdot
.27633 .55777 Mdot
.65391 .64879 Mdot
.4356 .71589 Mdot
.34011 .56757 Mdot
.57878 .49088 Mdot
.42607 .35016 Mdot
.43819 .31791 Mdot
.48292 .63244 Mdot
.45866 .69103 Mdot
.64003 .66131 Mdot
.46788 .61237 Mdot
.47725 .60065 Mdot
.65084 .65351 Mdot
.49656 .70171 Mdot
.42529 .37584 Mdot
.45144 .34715 Mdot
.42639 .36369 Mdot
.58201 .33513 Mdot
.39691 .36894 Mdot
.75858 .63958 Mdot
.56136 .42171 Mdot
.45062 .25266 Mdot
.57764 .40402 Mdot
.33247 .59325 Mdot
.42753 .33497 Mdot
.57323 .55076 Mdot
.62032 .3827 Mdot
.29207 .25908 Mdot
.63647 .4433 Mdot
.42207 .60096 Mdot
.60812 .43362 Mdot
.54156 .30288 Mdot
.43665 .39469 Mdot
.57421 .44959 Mdot
.34337 .60501 Mdot
.64132 .67935 Mdot
.38735 .37909 Mdot
.64567 .43225 Mdot
.30879 .45599 Mdot
.65656 .42077 Mdot
.33655 .29247 Mdot
.52169 .68262 Mdot
.63863 .69667 Mdot
.65869 .39931 Mdot
.42678 .70402 Mdot
.72195 .43517 Mdot
.4638 .25914 Mdot
.32138 .59602 Mdot
.49107 .28784 Mdot
.47975 .68942 Mdot
.6671 .35112 Mdot
.58446 .39053 Mdot
.6454 .64458 Mdot
.44116 .28928 Mdot
.30352 .59442 Mdot
.58605 .44803 Mdot
.62401 .41913 Mdot
.32815 .63658 Mdot
.47999 .2631 Mdot
.6391 .5268 Mdot
.67132 .67003 Mdot
.50439 .28852 Mdot
.6472 .4422 Mdot
.41747 .71367 Mdot
.39487 .3556 Mdot
.67515 .36445 Mdot
.65229 .33429 Mdot
.56913 .4225 Mdot
.42992 .34652 Mdot
.40014 .33258 Mdot
.59856 .177 Mdot
.65507 .64518 Mdot
.63731 .45044 Mdot
.48646 .63858 Mdot
.64614 .42091 Mdot
.31715 .58864 Mdot
.59809 .38667 Mdot
.43761 .69425 Mdot
.45833 .44711 Mdot
.48565 .73353 Mdot
.59366 .42785 Mdot
.41121 .3443 Mdot
.29513 .59009 Mdot
.26054 .6826 Mdot
.26279 .55206 Mdot
.7572 .64034 Mdot
.60176 .68183 Mdot
.62742 .67587 Mdot
.64509 .63519 Mdot
.26449 .57775 Mdot
.61702 .46709 Mdot
.51516 .54754 Mdot
.60986 .50092 Mdot
.60855 .42967 Mdot
.63902 .45344 Mdot
.28291 .53039 Mdot
.31296 .56596 Mdot
.44561 .70008 Mdot
.58996 .44274 Mdot
.57217 .41408 Mdot
.41691 .3411 Mdot
.62692 .66872 Mdot
.45052 .74943 Mdot
.62947 .68586 Mdot
.45292 .71385 Mdot
.4745 .15327 Mdot
.68023 .4244 Mdot
.6439 .67865 Mdot
.31477 .54389 Mdot
.45415 .34423 Mdot
.38065 .4709 Mdot
.47685 .71731 Mdot
.47963 .69464 Mdot
.5677 .43922 Mdot
.40414 .33964 Mdot
.4042 .33046 Mdot
.62305 .66805 Mdot
.30008 .55543 Mdot
.56753 .46358 Mdot
.58046 .42387 Mdot
.27705 .7025 Mdot
.44504 .75067 Mdot
.49171 .28092 Mdot
.35567 .32367 Mdot
.60857 .46802 Mdot
.40918 .32281 Mdot
.61064 .44781 Mdot
.41163 .5193 Mdot
.45642 .35946 Mdot
.61749 .38607 Mdot
.58648 .50358 Mdot
.43134 .73461 Mdot
.68574 .23045 Mdot
.61234 .4821 Mdot
.35268 .57452 Mdot
.60929 .40702 Mdot
.7768 .28779 Mdot
.5748 .1751 Mdot
.65872 .43829 Mdot
.62024 .47491 Mdot
.18779 .37085 Mdot
.65354 .40137 Mdot
.38092 .47815 Mdot
.64193 .50389 Mdot
.40929 .3209 Mdot
.44436 .60091 Mdot
.51282 .53764 Mdot
.64813 .63976 Mdot
.46057 .72192 Mdot
.71076 .60569 Mdot
.62164 .64643 Mdot
.44782 .35175 Mdot
.67533 .41324 Mdot
.35763 .32049 Mdot
.47894 .66851 Mdot
.55385 .41327 Mdot
.31525 .59017 Mdot
.51108 .5375 Mdot
.44516 .68195 Mdot
.31841 .57001 Mdot
.63923 .39171 Mdot
.47085 .80299 Mdot
.34933 .60286 Mdot
.61169 .17731 Mdot
.28422 .57494 Mdot
.30124 .56876 Mdot
.48913 .493 Mdot
.64725 .63941 Mdot
.3595 .63735 Mdot
.66443 .37729 Mdot
.31141 .59985 Mdot
.76696 .48375 Mdot
.44882 .75582 Mdot
.47017 .50949 Mdot
.43759 .39281 Mdot
.68246 .44996 Mdot
.62695 .45863 Mdot
.29092 .56475 Mdot
.4869 .37306 Mdot
.55626 .65517 Mdot
.32691 .58502 Mdot
.62277 .37389 Mdot
.4624 .49705 Mdot
.38952 .49416 Mdot
.39051 .47052 Mdot
.66483 .64769 Mdot
.57336 .76926 Mdot
.42646 .32518 Mdot
.66552 .67592 Mdot
.56399 .53337 Mdot
.6373 .43766 Mdot
.32589 .56029 Mdot
.39167 .46691 Mdot
.317 .57365 Mdot
.65076 .66867 Mdot
.66606 .6577 Mdot
.43635 .34536 Mdot
.44192 .37376 Mdot
.38052 .26794 Mdot
.72956 .49634 Mdot
.63448 .40563 Mdot
.61423 .22687 Mdot
.45423 .36875 Mdot
.63429 .31939 Mdot
.62949 .64529 Mdot
.62877 .65553 Mdot
.49972 .22932 Mdot
.61772 .3966 Mdot
.41325 .60953 Mdot
.64942 .44243 Mdot
.77199 .52675 Mdot
.65333 .4251 Mdot
.46638 .68354 Mdot
.61714 .41549 Mdot
.22511 .47041 Mdot
.57568 .41278 Mdot
.64047 .45458 Mdot
.4723 .71046 Mdot
.57663 .4699 Mdot
.44422 .68782 Mdot
.63413 .42215 Mdot
.64767 .62243 Mdot
.45866 .7207 Mdot
.66458 .62915 Mdot
.44995 .57563 Mdot
.3882 .47875 Mdot
.64494 .63669 Mdot
.62932 .6816 Mdot
.67183 .59601 Mdot
.43475 .3793 Mdot
.64414 .34453 Mdot
.62769 .46251 Mdot
.47723 .75031 Mdot
.31372 .54737 Mdot
.56853 .42392 Mdot
.66506 .42826 Mdot
.57604 .47181 Mdot
.43275 .3446 Mdot
.49842 .71458 Mdot
.64532 .6737 Mdot
.46229 .74083 Mdot
.65583 .62498 Mdot
.42989 .70663 Mdot
.61174 .48725 Mdot
.5788 .48883 Mdot
.6516 .38008 Mdot
.64212 .26581 Mdot
.82974 .56241 Mdot
.4297 .354 Mdot
.38756 .4908 Mdot
.66278 .65088 Mdot
.48199 .59023 Mdot
.42789 .32291 Mdot
.47768 .69393 Mdot
.62572 .44048 Mdot
.66349 .38204 Mdot
.68773 .44522 Mdot
.3894 .30188 Mdot
.68105 .66524 Mdot
.47057 .7215 Mdot
.37682 .49676 Mdot
.47415 .48929 Mdot
.43056 .41197 Mdot
.60096 .55761 Mdot
.61486 .44576 Mdot
.62239 .66928 Mdot
.39988 .35503 Mdot
.37632 .62864 Mdot
.2933 .56409 Mdot
.50354 .51794 Mdot
.6049 .45745 Mdot
.3305 .50752 Mdot
.41149 .34561 Mdot
.6389 .64822 Mdot
.29014 .56615 Mdot
.64588 .64107 Mdot
.40039 .48022 Mdot
.3649 .51187 Mdot
.59068 .4202 Mdot
.65092 .44027 Mdot
.32732 .55776 Mdot
.42257 .32551 Mdot
.63701 .62193 Mdot
.31468 .63973 Mdot
.4783 .71937 Mdot
.46077 .52904 Mdot
.40417 .36384 Mdot
.26355 .53776 Mdot
.4743 .73802 Mdot
.33713 .56259 Mdot
.51996 .54559 Mdot
.28724 .55407 Mdot
.64481 .44671 Mdot
.41018 .35897 Mdot
.32622 .59332 Mdot
.2893 .70003 Mdot
.36378 .25153 Mdot
.3985 .28607 Mdot
.58336 .436 Mdot
.3102 .31921 Mdot
.2899 .48802 Mdot
.49668 .36789 Mdot
.33328 .57426 Mdot
.59905 .44818 Mdot
.59173 .47254 Mdot
.62054 .41715 Mdot
.29808 .56545 Mdot
.23311 .6064 Mdot
.48684 .71485 Mdot
.62735 .43353 Mdot
.641 .68601 Mdot
.43891 .69547 Mdot
.449 .67263 Mdot
.43575 .71911 Mdot
.45352 .37135 Mdot
.67443 .40723 Mdot
.6866 .48561 Mdot
.65728 .21143 Mdot
.30443 .56883 Mdot
.38778 .47901 Mdot
.58668 .46624 Mdot
.74562 .64411 Mdot
.4533 .34751 Mdot
.47718 .70936 Mdot
.61676 .45605 Mdot
.5108 .6605 Mdot
.40438 .46691 Mdot
.46483 .70922 Mdot
.45018 .36942 Mdot
.49851 .37449 Mdot
.59432 .46028 Mdot
.61311 .4047 Mdot
.44403 .33732 Mdot
.26191 .5139 Mdot
.47069 .48739 Mdot
.60866 .44587 Mdot
.31233 .56828 Mdot
.4233 .85381 Mdot
.61777 .38854 Mdot
.45694 .30853 Mdot
.38418 .50061 Mdot
.39117 .42205 Mdot
.47059 .27665 Mdot
.63083 .50098 Mdot
.28295 .30949 Mdot
.7365 .67337 Mdot
.32097 .27391 Mdot
.77365 .54404 Mdot
.29174 .63845 Mdot
.53237 .1465 Mdot
.3473 .59242 Mdot
.53781 .28758 Mdot
.17193 .5474 Mdot
.27295 .51855 Mdot
.53616 .71026 Mdot
.29781 .6746 Mdot
.46441 .79745 Mdot
.80492 .41018 Mdot
.43176 .69268 Mdot
.79043 .5255 Mdot
.65378 .43905 Mdot
.26714 .50216 Mdot
.53003 .30314 Mdot
.8052 .62477 Mdot
.31634 .33478 Mdot
.49312 .6434 Mdot
.27304 .25544 Mdot
.32831 .35743 Mdot
.43247 .20867 Mdot
.7088 .34892 Mdot
.60658 .77975 Mdot
.48176 .59787 Mdot
.72226 .61851 Mdot
.49891 .30411 Mdot
.22448 .44186 Mdot
.33822 .6146 Mdot
.5588 .19821 Mdot
.50288 .83626 Mdot
.46054 .73263 Mdot
.39389 .35211 Mdot
.34914 .64523 Mdot
.41198 .22088 Mdot
.35577 .5448 Mdot
.28293 .309 Mdot
.35781 .37599 Mdot
.53955 .2994 Mdot
.55423 .53283 Mdot
.53604 .2544 Mdot
.71125 .69696 Mdot
.79464 .4347 Mdot
.40492 .30284 Mdot
.31394 .69171 Mdot
.48667 .59446 Mdot
.67533 .6153 Mdot
.55882 .31614 Mdot
.66918 .65102 Mdot
.65981 .63494 Mdot
.453 .36464 Mdot
.4274 .23124 Mdot
.39865 .45867 Mdot
.56556 .53266 Mdot
.42314 .71768 Mdot
.41482 .52361 Mdot
.23961 .51221 Mdot
.30711 .4837 Mdot
.7333 .2798 Mdot
.3195 .21939 Mdot
.72847 .53341 Mdot
.3917 .61943 Mdot
.34283 .53455 Mdot
.72908 .63827 Mdot
.67699 .51079 Mdot
.74501 .49775 Mdot
.73494 .38585 Mdot
.22217 .30623 Mdot
.32996 .44651 Mdot
.26737 .25206 Mdot
.4144 .30583 Mdot
.59805 .36148 Mdot
.39695 .58557 Mdot
.70805 .29814 Mdot
.67256 .57339 Mdot
.31523 .23009 Mdot
.62631 .69489 Mdot
.42582 .39569 Mdot
.2743 .51864 Mdot
.53936 .33083 Mdot
.69848 .6681 Mdot
.59755 .68793 Mdot
.67086 .36272 Mdot
.21851 .29529 Mdot
.27675 .31632 Mdot
.5197 .16757 Mdot
.36872 .41282 Mdot
.47197 .65685 Mdot
.4421 .67528 Mdot
.29855 .60312 Mdot
.40158 .20949 Mdot
.41354 .35607 Mdot
.67059 .2136 Mdot
.36036 .26584 Mdot
.72489 .43598 Mdot
.20181 .31283 Mdot
.79289 .382 Mdot
.44864 .25585 Mdot
.80007 .5909 Mdot
.35981 .8054 Mdot
.66052 .52971 Mdot
.25154 .56799 Mdot
.42186 .74189 Mdot
.35694 .28922 Mdot
.3914 .21127 Mdot
.76979 .46684 Mdot
.16779 .45254 Mdot
.56633 .53172 Mdot
.4081 .73926 Mdot
.37566 .3124 Mdot
.53541 .7341 Mdot
.62898 .5927 Mdot
.27356 .2477 Mdot
.51323 .29453 Mdot
.40822 .83934 Mdot
.7574 .55612 Mdot
.6414 .32752 Mdot
.28218 .33987 Mdot
.4903 .77044 Mdot
.73245 .46652 Mdot
.3193 .46116 Mdot
.67314 .45901 Mdot
.63398 .57038 Mdot
.6931 .35605 Mdot
.68182 .70753 Mdot
.47546 .48067 Mdot
.32524 .42067 Mdot
.72877 .56587 Mdot
.22651 .6133 Mdot
.63632 .33919 Mdot
.46433 .35351 Mdot
.73451 .50988 Mdot
.75191 .53711 Mdot
.36215 .42487 Mdot
.5806 .64327 Mdot
.50811 .16556 Mdot
.56714 .65382 Mdot
.62827 .50347 Mdot
.53665 .28139 Mdot
.50201 .30921 Mdot
.76134 .50354 Mdot
.63143 .48645 Mdot
.70852 .25985 Mdot
.37347 .40849 Mdot
.61682 .25688 Mdot
.70266 .5737 Mdot
.63428 .2623 Mdot
.38281 .23793 Mdot
.39463 .57677 Mdot
.2463 .57395 Mdot
.48625 .34753 Mdot
.22166 .29353 Mdot
.44214 .69763 Mdot
.76059 .47877 Mdot
.34938 .59116 Mdot
.27928 .69661 Mdot
.29961 .64599 Mdot
.55914 .65313 Mdot
.41895 .19822 Mdot
.31181 .49406 Mdot
.49534 .75175 Mdot
.21501 .42727 Mdot
.42647 .47922 Mdot
.60744 .22784 Mdot
.5512 .37954 Mdot
.7351 .40378 Mdot
.66296 .673 Mdot
.65523 .30408 Mdot
.3795 .56653 Mdot
.6519 .72842 Mdot
.63054 .49771 Mdot
.48662 .62184 Mdot
.37283 .49123 Mdot
.49692 .53204 Mdot
.47181 .15234 Mdot
.54289 .38445 Mdot
.79075 .38674 Mdot
.29644 .49592 Mdot
.50776 .5446 Mdot
.65783 .60458 Mdot
.44473 .41857 Mdot
.25629 .25911 Mdot
.4414 .17862 Mdot
.27663 .47453 Mdot
.30657 .31621 Mdot
.85055 .42921 Mdot
.24605 .64357 Mdot
.74113 .31399 Mdot
.34874 .59383 Mdot
.76891 .76714 Mdot
.46751 .74117 Mdot
.81481 .53159 Mdot
.70281 .29807 Mdot
.53274 .66704 Mdot
.40961 .22267 Mdot
.51388 .32595 Mdot
.61853 .61263 Mdot
.46149 .33266 Mdot
.62664 .49121 Mdot
.33364 .22675 Mdot
.23114 .28804 Mdot
.32739 .22979 Mdot
.34844 .49939 Mdot
.33433 .24466 Mdot
.18831 .35611 Mdot
.76063 .63893 Mdot
.34871 .62793 Mdot
.57496 .39877 Mdot
.75689 .45378 Mdot
.78246 .36557 Mdot
.64334 .70422 Mdot
.6477 .53257 Mdot
.40077 .30331 Mdot
.18583 .34961 Mdot
.4741 .15029 Mdot
.53178 .23083 Mdot
.4446 .20918 Mdot
.41273 .63366 Mdot
.74683 .48116 Mdot
.43736 .19761 Mdot
.23219 .41301 Mdot
.35313 .38078 Mdot
.17481 .38192 Mdot
.74801 .54731 Mdot
.29737 .67786 Mdot
.27062 .46209 Mdot
.76724 .34311 Mdot
.28128 .33472 Mdot
.33851 .6488 Mdot
.72627 .46582 Mdot
.37048 .34764 Mdot
.55852 .65754 Mdot
.22127 .43547 Mdot
.40554 .61208 Mdot
.70083 .5601 Mdot
.47306 .67782 Mdot
.76529 .46433 Mdot
.56902 .58141 Mdot
.34823 .62908 Mdot
.69299 .59814 Mdot
.77526 .46358 Mdot
.29516 .43966 Mdot
.33022 .23835 Mdot
.29845 .49631 Mdot
.35389 .80744 Mdot
.29975 .3655 Mdot
.69924 .36162 Mdot
.57773 .47103 Mdot
.39935 .21853 Mdot
.41059 .1641 Mdot
.42263 .1945 Mdot
.35255 .47703 Mdot
.4749 .64312 Mdot
.33209 .54863 Mdot
.71976 .62966 Mdot
.53967 .65869 Mdot
.34169 .33034 Mdot
.52218 .58056 Mdot
.33866 .60046 Mdot
.23489 .52795 Mdot
.37794 .27015 Mdot
.74165 .64543 Mdot
.54343 .20031 Mdot
.59826 .52436 Mdot
.43422 .23832 Mdot
.44885 .32346 Mdot
.33876 .49678 Mdot
.74923 .49275 Mdot
.43885 .70293 Mdot
.28529 .70842 Mdot
.48401 .36492 Mdot
.58887 .36143 Mdot
.39639 .63744 Mdot
.38626 .29075 Mdot
.662 .27282 Mdot
.49953 .74011 Mdot
.50254 .14784 Mdot
.72788 .28068 Mdot
.4385 .19635 Mdot
.73326 .5201 Mdot
.30025 .70803 Mdot
.48636 .51868 Mdot
.33418 .53644 Mdot
.32001 .34444 Mdot
.47691 .56262 Mdot
.74111 .51173 Mdot
.43133 .24684 Mdot
.3614 .60639 Mdot
.64927 .49836 Mdot
.54596 .16688 Mdot
.7504 .6272 Mdot
.48374 .53191 Mdot
.39356 .40792 Mdot
.38877 .35264 Mdot
.84056 .54826 Mdot
.23094 .45434 Mdot
.71125 .45949 Mdot
.29683 .32555 Mdot
.27048 .56701 Mdot
.4598 .35266 Mdot
.7791 .45377 Mdot
.56209 .72289 Mdot
.39941 .26483 Mdot
.41153 .57911 Mdot
.41957 .21735 Mdot
.44516 .56251 Mdot
.30192 .3143 Mdot
.2661 .30164 Mdot
.43374 .84762 Mdot
.41763 .30645 Mdot
.38231 .62036 Mdot
.3806 .63415 Mdot
.38912 .31206 Mdot
.40595 .29815 Mdot
.50781 .29746 Mdot
.3674 .20683 Mdot
.46219 .60073 Mdot
.22671 .40664 Mdot
.51296 .54648 Mdot
.54143 .71238 Mdot
.36712 .61489 Mdot
.70294 .60169 Mdot
.2445 .34843 Mdot
.49162 .20128 Mdot
.23507 .70302 Mdot
.59651 .52832 Mdot
.81441 .52295 Mdot
.72032 .63085 Mdot
.71043 .35323 Mdot
.55837 .31338 Mdot
.34504 .37883 Mdot
.63565 .41411 Mdot
.33252 .2095 Mdot
.33239 .43751 Mdot
.62496 .58189 Mdot
.47888 .78263 Mdot
.63027 .39311 Mdot
.65735 .38801 Mdot
.43226 .19862 Mdot
.38006 .4035 Mdot
.19414 .62839 Mdot
.76596 .54411 Mdot
.72037 .38954 Mdot
.44012 .25421 Mdot
.78928 .38548 Mdot
.40279 .56279 Mdot
.33482 .27418 Mdot
.5691 .58622 Mdot
.78135 .35627 Mdot
.223 .38274 Mdot
.2153 .45739 Mdot
.29621 .35549 Mdot
.19638 .34406 Mdot
.70676 .38868 Mdot
.38815 .44385 Mdot
.35811 .64664 Mdot
.59608 .46957 Mdot
.3315 .48638 Mdot
.30085 .33734 Mdot
.52485 .79007 Mdot
.68742 .50487 Mdot
.40423 .16484 Mdot
.60122 .51595 Mdot
.35315 .45851 Mdot
.19377 .58841 Mdot
.23093 .72625 Mdot
.2202 .46831 Mdot
.27823 .24425 Mdot
.21069 .44686 Mdot
.28962 .32175 Mdot
.26851 .56619 Mdot
.46971 .57681 Mdot
.64525 .24529 Mdot
.37468 .20044 Mdot
.58419 .75223 Mdot
.24978 .62694 Mdot
.60921 .20835 Mdot
.36926 .20015 Mdot
.60529 .51218 Mdot
.83665 .52971 Mdot
.48539 .6639 Mdot
.80578 .37366 Mdot
.74389 .30095 Mdot
.39067 .39869 Mdot
.77062 .48579 Mdot
.82948 .50798 Mdot
.79007 .63465 Mdot
.73632 .2999 Mdot
.75284 .40014 Mdot
.39458 .41891 Mdot
.72532 .52551 Mdot
.34279 .29963 Mdot
.81811 .42742 Mdot
.37496 .61114 Mdot
.40335 .45237 Mdot
.36687 .51037 Mdot
.35946 .28768 Mdot
.29281 .42346 Mdot
.40035 .6013 Mdot
.44943 .45384 Mdot
.40138 .23554 Mdot
.46187 .87975 Mdot
.19567 .45123 Mdot
.44202 .28496 Mdot
.2446 .27949 Mdot
.35693 .39643 Mdot
.48833 .58431 Mdot
.56691 .32087 Mdot
.73618 .62942 Mdot
.508 .72915 Mdot
.64754 .44887 Mdot
.36117 .2078 Mdot
.50323 .73803 Mdot
.28465 .25218 Mdot
.62114 .18047 Mdot
.46095 .21492 Mdot
.54257 .39449 Mdot
.4216 .74473 Mdot
.77768 .41395 Mdot
.77381 .42348 Mdot
.24111 .29549 Mdot
.81244 .50954 Mdot
.46801 .54189 Mdot
.43148 .57912 Mdot
.42771 .55672 Mdot
.71383 .42674 Mdot
.78888 .36964 Mdot
.41762 .42549 Mdot
.70781 .58186 Mdot
.26535 .47189 Mdot
.76015 .48897 Mdot
.47447 .27709 Mdot
.71146 .62034 Mdot
.58002 .62479 Mdot
.62305 .61359 Mdot
.45185 .75449 Mdot
.16508 .42579 Mdot
.32778 .37859 Mdot
.69686 .24883 Mdot
.35751 .80766 Mdot
.3222 .46254 Mdot
.79504 .51693 Mdot
.36867 .56487 Mdot
.6741 .52691 Mdot
.59816 .7722 Mdot
.73106 .57966 Mdot
.49607 .28816 Mdot
.32956 .31234 Mdot
.54196 .36417 Mdot
.40352 .19939 Mdot
.69882 .56532 Mdot
.16031 .51592 Mdot
.40771 .64657 Mdot
.65161 .29698 Mdot
.47097 .25011 Mdot
.31797 .78371 Mdot
.4864 .53417 Mdot
.2185 .29663 Mdot
.45844 .37547 Mdot
.3164 .22182 Mdot
.28384 .56918 Mdot
.51243 .81802 Mdot
.34453 .35973 Mdot
.61343 .57969 Mdot
.57788 .56714 Mdot
.57742 .17038 Mdot
.28696 .50516 Mdot
.30053 .48462 Mdot
.56377 .66226 Mdot
.44892 .67741 Mdot
.45008 .51684 Mdot
.23201 .40017 Mdot
.16702 .43026 Mdot
.56316 .45973 Mdot
.41648 .66504 Mdot
.78252 .42551 Mdot
.33072 .53383 Mdot
.37032 .39773 Mdot
.33062 .33652 Mdot
.47597 .30104 Mdot
.74435 .48252 Mdot
.19613 .3396 Mdot
.34623 .33461 Mdot
.5444 .63499 Mdot
.66904 .34743 Mdot
.34214 .61719 Mdot
.23151 .65459 Mdot
.26058 .32984 Mdot
.43057 .56621 Mdot
.47122 .49269 Mdot
.73082 .53399 Mdot
.44032 .13617 Mdot
.22672 .29741 Mdot
.27727 .74046 Mdot
.50682 .54758 Mdot
.47515 .35227 Mdot
.72735 .60549 Mdot
.15861 .51119 Mdot
.80774 .36981 Mdot
.28658 .45822 Mdot
.76261 .48345 Mdot
.51657 .78298 Mdot
.82491 .52727 Mdot
.4793 .55192 Mdot
.47273 .25008 Mdot
.68344 .27222 Mdot
.36556 .52431 Mdot
.49557 .75881 Mdot
.53474 .55868 Mdot
.30861 .63654 Mdot
.39667 .42066 Mdot
.288 .50575 Mdot
.16047 .517 Mdot
.81371 .49662 Mdot
.66156 .34634 Mdot
.16853 .52253 Mdot
.38955 .37739 Mdot
.37733 .63559 Mdot
.25312 .69143 Mdot
.51478 .55491 Mdot
.44979 .73936 Mdot
.66486 .51418 Mdot
.45909 .49955 Mdot
.21002 .42705 Mdot
.48441 .80064 Mdot
.61321 .66356 Mdot
.43683 .30192 Mdot
.82368 .50537 Mdot
.40403 .31411 Mdot
.4721 .137 Mdot
.23469 .40981 Mdot
.43636 .24509 Mdot
.21041 .39303 Mdot
.32724 .67963 Mdot
.36404 .81547 Mdot
.43491 .20876 Mdot
.68702 .55468 Mdot
.43641 .30387 Mdot
.42762 .3118 Mdot
.22963 .36713 Mdot
.33893 .51688 Mdot
.43082 .22222 Mdot
.79191 .39437 Mdot
.30376 .71144 Mdot
.39056 .32899 Mdot
.43175 .58485 Mdot
.46149 .29998 Mdot
.48419 .14665 Mdot
.45495 .73911 Mdot
.22723 .28498 Mdot
.56506 .35783 Mdot
.22354 .65418 Mdot
.35322 .30287 Mdot
.46301 .44694 Mdot
.48698 .54559 Mdot
.29734 .69771 Mdot
.63949 .50173 Mdot
.72036 .3918 Mdot
.44291 .3755 Mdot
.29335 .64392 Mdot
.62786 .6657 Mdot
.58317 .67107 Mdot
.34979 .56192 Mdot
.69389 .32467 Mdot
.77922 .3428 Mdot
.4405 .31725 Mdot
.40518 .64327 Mdot
.37635 .65753 Mdot
.58279 .50085 Mdot
.76543 .40879 Mdot
.17774 .39287 Mdot
.43578 .21274 Mdot
.46197 .37143 Mdot
.28929 .75603 Mdot
.64107 .71614 Mdot
.51669 .15059 Mdot
.50117 .35733 Mdot
.78143 .41896 Mdot
.68857 .34238 Mdot
.44897 .18547 Mdot
.47136 .27731 Mdot
.33886 .28354 Mdot
.73863 .50667 Mdot
.55374 .66199 Mdot
.77482 .46043 Mdot
.47425 .2986 Mdot
.44046 .54663 Mdot
.80491 .38339 Mdot
.50891 .78701 Mdot
.53645 .25985 Mdot
.68413 .49672 Mdot
.36082 .29743 Mdot
.78634 .38142 Mdot
.44074 .30195 Mdot
.63145 .6277 Mdot
.57225 .20566 Mdot
.34685 .36868 Mdot
.39832 .21155 Mdot
.3614 .42619 Mdot
.78611 .4212 Mdot
.42914 .5505 Mdot
.76673 .59684 Mdot
.54965 .36373 Mdot
.62708 .55992 Mdot
.6685 .43802 Mdot
.68953 .35953 Mdot
.53861 .58869 Mdot
.59532 .18158 Mdot
.71845 .40883 Mdot
.36041 .21814 Mdot
.49748 .15416 Mdot
.31438 .27323 Mdot
.40272 .62326 Mdot
.39623 .33068 Mdot
.2462 .27096 Mdot
.77163 .40053 Mdot
.34314 .3047 Mdot
.74816 .30857 Mdot
.84322 .54156 Mdot
.1674 .54057 Mdot
.33885 .41279 Mdot
.3779 .29417 Mdot
.68362 .22861 Mdot
.3336 .44544 Mdot
.83416 .51609 Mdot
.50023 .29073 Mdot
.35658 .35121 Mdot
.19562 .32197 Mdot
.72323 .32144 Mdot
.3046 .48024 Mdot
.46981 .25497 Mdot
.44453 .27676 Mdot
.77153 .38517 Mdot
.67249 .49327 Mdot
.42807 .7039 Mdot
.52606 .67385 Mdot
.76763 .49407 Mdot
.48715 .32413 Mdot
.78765 .40021 Mdot
.77776 .42724 Mdot
.79287 .53045 Mdot
.30164 .7021 Mdot
.16806 .54064 Mdot
.42858 .25529 Mdot
.65623 .37849 Mdot
.4404 .30019 Mdot
.63128 .63638 Mdot
.75609 .56403 Mdot
.57912 .41181 Mdot
.53154 .53675 Mdot
.6861 .37655 Mdot
.35105 .20435 Mdot
.5491 .70285 Mdot
.31629 .62065 Mdot
.39299 .33442 Mdot
.359 .29059 Mdot
.39801 .5447 Mdot
.27032 .52019 Mdot
.78362 .40004 Mdot
.3885 .26356 Mdot
.29512 .30341 Mdot
.31148 .47577 Mdot
.72231 .55272 Mdot
.70626 .70503 Mdot
.33182 .58992 Mdot
.66055 .26667 Mdot
.23357 .30988 Mdot
.33269 .47235 Mdot
.41597 .39261 Mdot
.26959 .44942 Mdot
.44267 .54958 Mdot
.37728 .45268 Mdot
.28928 .50162 Mdot
.37641 .58646 Mdot
.48462 .21995 Mdot
.26242 .31163 Mdot
.44205 .76178 Mdot
.75961 .53809 Mdot
.24037 .44754 Mdot
.78664 .39683 Mdot
.58051 .50108 Mdot
.37571 .22024 Mdot
.61105 .57743 Mdot
.66038 .71717 Mdot
.59733 .41029 Mdot
.73315 .36126 Mdot
.43132 .19791 Mdot
.25856 .4643 Mdot
.72333 .47409 Mdot
.45607 .39266 Mdot
.72722 .27719 Mdot
.51375 .70128 Mdot
.51133 .71414 Mdot
.8111 .56573 Mdot
.46296 .42613 Mdot
.53802 .65505 Mdot
.23824 .58999 Mdot
.61866 .50794 Mdot
.70189 .71103 Mdot
.41857 .57599 Mdot
.65264 .25929 Mdot
.74142 .31834 Mdot
.17174 .40978 Mdot
.40957 .5727 Mdot
.73342 .27801 Mdot
.67213 .26164 Mdot
.35779 .34792 Mdot
.81921 .49723 Mdot
.64496 .53198 Mdot
.62818 .48724 Mdot
.63114 .6279 Mdot
.39299 .37399 Mdot
.18519 .38565 Mdot
.73422 .4396 Mdot
.68735 .68786 Mdot
.6037 .59528 Mdot
.39726 .59183 Mdot
.41568 .77189 Mdot
.37739 .41432 Mdot
.68533 .22937 Mdot
.74853 .49382 Mdot
.28946 .53566 Mdot
.21335 .42656 Mdot
.68881 .51001 Mdot
.36699 .22001 Mdot
.54973 .60255 Mdot
.42192 .20891 Mdot
.35712 .4866 Mdot
.6611 .27943 Mdot
.52392 .1598 Mdot
.65406 .57291 Mdot
.61383 .55685 Mdot
.42147 .41871 Mdot
.621 .54278 Mdot
.38116 .46993 Mdot
.56098 .69282 Mdot
.80798 .43648 Mdot
.16281 .47277 Mdot
.22408 .59868 Mdot
.63527 .51546 Mdot
.72787 .60019 Mdot
.24854 .3286 Mdot
.48727 .58778 Mdot
.59813 .58734 Mdot
.35596 .65023 Mdot
.4982 .75089 Mdot
.43007 .8578 Mdot
.34005 .20767 Mdot
.59938 .40857 Mdot
.56342 .57068 Mdot
.60569 .70312 Mdot
.49548 .70624 Mdot
.53103 .19784 Mdot
.1849 .38077 Mdot
.32179 .59806 Mdot
.32632 .76843 Mdot
.23949 .59154 Mdot
.5858 .17436 Mdot
.27325 .72215 Mdot
.32046 .61541 Mdot
.47028 .13641 Mdot
.28355 .47051 Mdot
.48507 .39637 Mdot
.43964 .8632 Mdot
.56261 .17121 Mdot
.69327 .35096 Mdot
.49631 .66006 Mdot
.34662 .21411 Mdot
.4855 .54387 Mdot
.47214 .63839 Mdot
.72667 .31843 Mdot
.74622 .49911 Mdot
.76348 .5426 Mdot
.25538 .59387 Mdot
.64898 .23244 Mdot
.83359 .60333 Mdot
.33036 .67933 Mdot
.3151 .79538 Mdot
.44533 .2159 Mdot
.27731 .28202 Mdot
.22048 .46393 Mdot
.53251 .78325 Mdot
.39124 .22019 Mdot
.7704 .44375 Mdot
.72944 .34581 Mdot
.56825 .74939 Mdot
.65257 .57704 Mdot
.73515 .62035 Mdot
.37366 .46074 Mdot
.45125 .20175 Mdot
.3083 .69848 Mdot
.71419 .49479 Mdot
.76992 .46218 Mdot
.68715 .28252 Mdot
.61866 .55692 Mdot
.25269 .29347 Mdot
.76875 .39144 Mdot
.73961 .52172 Mdot
.30352 .66355 Mdot
.66056 .6345 Mdot
.1987 .36441 Mdot
.41117 .50579 Mdot
.68618 .34742 Mdot
.1937 .59585 Mdot
.27304 .24894 Mdot
.6446 .53232 Mdot
.60326 .38558 Mdot
.53687 .14655 Mdot
.4296 .64319 Mdot
.73771 .31216 Mdot
.24179 .50025 Mdot
.77224 .53793 Mdot
.70495 .39693 Mdot
.65395 .4212 Mdot
.78186 .60406 Mdot
.36619 .33131 Mdot
.68793 .27943 Mdot
.27482 .71295 Mdot
.73768 .51807 Mdot
.69894 .33516 Mdot
.23382 .70013 Mdot
.49831 .34451 Mdot
.41372 .31742 Mdot
.34779 .21072 Mdot
.5447 .18486 Mdot
.70944 .36652 Mdot
.45094 .24062 Mdot
.54684 .61352 Mdot
.69612 .71415 Mdot
.64543 .34593 Mdot
.48744 .52112 Mdot
.77085 .49058 Mdot
.16644 .52512 Mdot
.63461 .23939 Mdot
.21546 .29573 Mdot
.43801 .1826 Mdot
.3973 .32094 Mdot
.71479 .31201 Mdot
.51113 .5573 Mdot
.30775 .2808 Mdot
.28711 .68801 Mdot
.28547 .70322 Mdot
.82035 .61227 Mdot
.58835 .68022 Mdot
.65724 .44133 Mdot
.34846 .49746 Mdot
.40653 .20063 Mdot
.83077 .59018 Mdot
.39844 .20397 Mdot
.69225 .36581 Mdot
.58154 .47316 Mdot
.2389 .74138 Mdot
.29508 .31743 Mdot
.58297 .48283 Mdot
.70506 .44596 Mdot
.71213 .44039 Mdot
.64771 .42975 Mdot
.33199 .51666 Mdot
.73293 .63368 Mdot
.77601 .524 Mdot
.36255 .21293 Mdot
.38546 .34534 Mdot
.48935 .54282 Mdot
.32761 .60791 Mdot
.54874 .54806 Mdot
.52464 .46827 Mdot
.27131 .576 Mdot
.78339 .51253 Mdot
.39925 .70284 Mdot
.69492 .64874 Mdot
.3683 .29586 Mdot
.45141 .43543 Mdot
.37719 .26653 Mdot
.80197 .50183 Mdot
.26161 .54386 Mdot
.78709 .63934 Mdot
.78201 .43268 Mdot
.5883 .34832 Mdot
.38 .43001 Mdot
.85063 .44176 Mdot
.48205 .53688 Mdot
.33962 .50903 Mdot
.54555 .48498 Mdot
.52875 .36662 Mdot
.46382 .22704 Mdot
.60706 .69092 Mdot
.37024 .493 Mdot
.67446 .35583 Mdot
.40842 .222 Mdot
.29363 .54681 Mdot
.42665 .14704 Mdot
.54097 .4241 Mdot
.53178 .2062 Mdot
.3548 .24885 Mdot
.37567 .62501 Mdot
.49582 .29111 Mdot
.66958 .4335 Mdot
.53334 .62766 Mdot
.40081 .6936 Mdot
.45646 .30137 Mdot
.36279 .6168 Mdot
.28117 .30051 Mdot
.80998 .52254 Mdot
.49886 .20712 Mdot
.63561 .45005 Mdot
.61787 .68399 Mdot
.49714 .5234 Mdot
.53929 .76892 Mdot
.40691 .7314 Mdot
.35774 .38713 Mdot
.79881 .50498 Mdot
.76513 .54527 Mdot
.48272 .26549 Mdot
.29747 .24092 Mdot
.69286 .49151 Mdot
.45657 .21854 Mdot
.57717 .61632 Mdot
.30047 .42201 Mdot
.76447 .41389 Mdot
.16863 .51686 Mdot
.70928 .38498 Mdot
.68034 .49379 Mdot
.44073 .16124 Mdot
.43688 .20561 Mdot
.27686 .62546 Mdot
.32955 .30731 Mdot
.80425 .42892 Mdot
.57943 .56816 Mdot
.44638 .8698 Mdot
.28164 .68879 Mdot
.45351 .14304 Mdot
.34183 .62456 Mdot
.53852 .45604 Mdot
.43828 .42071 Mdot
.62678 .49238 Mdot
.46137 .70192 Mdot
.30038 .27931 Mdot
.41506 .41844 Mdot
.59061 .53716 Mdot
.6615 .38951 Mdot
.45291 .62347 Mdot
.43975 .29637 Mdot
.16049 .48235 Mdot
.46837 .66991 Mdot
.54468 .63059 Mdot
.21552 .60215 Mdot
.40024 .69848 Mdot
.84491 .52524 Mdot
.24341 .29154 Mdot
.32139 .3433 Mdot
.4223 .5731 Mdot
.46939 .83218 Mdot
.47385 .34198 Mdot
.39266 .29809 Mdot
.34254 .54755 Mdot
.77021 .60157 Mdot
.34717 .47017 Mdot
.18191 .55597 Mdot
.44869 .18206 Mdot
.57938 .49987 Mdot
.46856 .89386 Mdot
.77587 .44556 Mdot
.52001 .59069 Mdot
.34371 .47912 Mdot
.37156 .20736 Mdot
.48273 .78237 Mdot
.61383 .17852 Mdot
.22684 .43906 Mdot
.49527 .34513 Mdot
.75711 .62158 Mdot
.29157 .75687 Mdot
.42376 .5906 Mdot
.31804 .79763 Mdot
.2885 .33881 Mdot
.72162 .61783 Mdot
.25248 .46427 Mdot
.42919 .3058 Mdot
.72144 .39799 Mdot
.2399 .4009 Mdot
.65846 .52516 Mdot
.48663 .38089 Mdot
.27985 .31348 Mdot
.71867 .6837 Mdot
.2801 .66086 Mdot
.30805 .30901 Mdot
.34307 .53992 Mdot
.41281 .4141 Mdot
.79161 .44873 Mdot
.42097 .65829 Mdot
.4799 .68311 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo08_ooooo0_l00008ooooo`Co0000/?oo
ool001cooooo00?o0000ooooooooool0Roooool4o`0000Kooooo1?l0002`ooooo`007?ooool00ol0
003oooooooooo`27ooooo`;o00001?ooool2o`000003ooooool0003o00000;Oooooo000Looooo`03
o`000?oooooooooo08Oooooo0_l00007ooooo`;o00002?ooool2o`000003ooooool0003o000000[o
oooo1?l0002Looooo`007?ooool00ol0003oooooooooo`27ooooo`;o00003Oooool2o`0000;ooooo
0_l000000ooooooo0000o`000002o`0000?ooooo0_l00003ooooo`Co00000oooool2o`0009Oooooo
000Looooo`;o0000Uoooool4o`0000Gooooo0_l00003ooooo`;o00002_ooool2o`000003ooooool0
003o000009Cooooo000Looooo`03o`000?oooooooooo09Cooooo1_l00004ooooo`;o00004oooool2
o`0009Cooooo000Looooo`03o`000?oooooooooo09Cooooo0_l00008ooooo`;o00001_ooool2o`00
0:7ooooo000Looooo`03o`000?oooooooooo08_ooooo0_l0000Iooooo`;o00000_ooool2o`0000_o
oooo0_l0002@ooooo`007?ooool00ol0003oooooooooo`20ooooo`Co00001oooool2o`0001Cooooo
0_l00007ooooo`Co00002Oooool2o`00093ooooo000Looooo`03o`000?oooooooooo083ooooo1?l0
000Mooooo`;o00000_ooool2o`0000Gooooo1?l0002Iooooo`007?ooool00ol0003oooooooooo`2U
ooooo`?o00001Oooool3o`000003ooooool0003o000000;o00000oooool2o`0008oooooo000Loooo
o`03o`000?oooooooooo0:Kooooo0_l00009ooooo`Co00000_ooool3o`000003ooooool0003o0000
08cooooo000Looooo`03o`000?oooooooooo0:7ooooo0_l0000Dooooo`;o00000_ooool2o`0000;o
oooo0_l00002ooooo`;o0000Q?ooool001cooooo00?o0000ooooooooool0M_ooool2o`0001?ooooo
0ol0000Cooooo`;o00007?ooool2o`0000;ooooo1Ol00021ooooo`007?ooool00ol0003ooooooooo
o`1fooooo`;o00004oooool5o`0002kooooo0ol00003ooooo`Co0000POooool001cooooo00?o0000
ooooooooool0Poooool3o`0000Gooooo0_l000000ooooooo0000o`00000Looooo`?o00003oooool3
o`0008Sooooo000Looooo`03o`000?oooooooooo06gooooo0_l0000=ooooo`;o00001Oooool3o`00
00Sooooo0_l0000Looooo`Co0000VOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2
ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo06gooooo0_l0000=ooooo`;o0000<?ooool2
o`0009Wooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`26ooooo`;o00000oooool2o`000;cooooo
00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00ol0003oooooooooo`1oooooo`;o00000oooool9o`0001cooooo0_l00003ooooo`;o00000_oo
ool2o`0009Gooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RH
ob4Q8Oo^k^h01_ooool3o`0007Cooooo1?l00007ooooo`?o00000_ooool2o`0000;ooooo1?l00003
ooooo`;o00002oooool2o`0000_ooooo0_l00002ooooo`?o00000_ooool2o`0009Gooooo00000ooo
oooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0
003oooooooooo`1^ooooo`;o00001?ooool4o`0000Kooooo1?l00008ooooo`;o00000oooool2o`00
00_ooooo0ol0000:ooooo`;o00000_ooool2o`0000Oooooo0_l00007ooooo`;o0000R?ooool00003
ooooool@413ooooo00;ooooo00?o410@ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo06_ooooo0_l000000ooooooo0000o`000002ooooo`Go00001oooool2o`0000Go
oooo0_l00002ooooo`?o000000?oooooo`000?l000003_ooool3o`0000Wooooo0_l0000;ooooo`;o
00001oooool5o`0008Gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj
^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo06Sooooo0_l000000ooooooo0000o`000002
o`0000?ooooo1Ol00004ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`0000;ooooo0ol0
00000ooooooo0000o`00000?ooooo`;o00005_ooool2o`0000Sooooo1?l0000=ooooo`?o0000MOoo
ool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Ko
oooo00?o0000ooooooooool0J?ooool2o`0000?ooooo0_l00003ooooo`;o00001oooool2o`000004
ooooool0003o0000o`0000Wooooo0_l00006ooooo`;o00002Oooool2o`0002gooooo0_l00003oooo
o`?o00000_ooool2o`00077ooooo000Looooo`03o`000?oooooooooo06gooooo0_l00002ooooo`?o
00002_ooool2o`0000Gooooo0_l00003ooooo`;o000000?oooooo`000?l000000oooool2o`0000Wo
oooo0_l0000]ooooo`;o00001_ooool4o`00077ooooo000Looooo`03o`000?oooooooooo06Cooooo
0_l0000;ooooo`Co000000?oooooo`000?l000000oooool2o`000003ooooool0003o000000;ooooo
0_l000000ooooooo0000o`000006ooooo`;o00000_ooool2o`0000Oooooo0_l0000hooooo`;o0000
Loooool001cooooo00?o0000ooooooooool0Hoooool3o`0000gooooo0_l000000ooooooo0000o`00
0003ooooo`;o00001?ooool3o`0000Cooooo0_l00007ooooo`;o00001oooool2o`00033ooooo0_l0
001kooooo`007?ooool00ol0003oooooooooo`1Sooooo`;o00001?ooool2o`0001Kooooo0_l00005
ooooo`;o00002Oooool2o`0001Gooooo0_l0000Cooooo`;o00000oooool2o`0000Kooooo1?l0001i
ooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o00001?ooool2o`0000;ooooo1?l0000@oooo
o`;o00005_ooool2o`0000[ooooo0_l00008ooooo`Co00004_ooool2o`000003ooooool0003o0000
00;o000000?oooooo`000?l000000oooool5o`0000Wooooo0ol0001/ooooo`007?ooool00ol0003o
ooooooooo`1Mooooo`;o00001?ooool2o`0000;ooooo0_l00008ooooo`Co00001_ooool2o`0000[o
oooo0_l0000Fooooo`;o00002?ooool4o`0001;ooooo0_l000000ooooooo0000o`000003ooooo`;o
00001_ooool5o`0000Kooooo0ol0001/ooooo`007?ooool00ol0003oooooooooo`1]ooooo`;o0000
0_ooool4o`0000Cooooo0_l00004ooooo`;o00001Oooool3o`0003Kooooo0_l0000>ooooo`Go0000
1Oooool2o`0006kooooo000Looooo`03o`000?oooooooooo06Oooooo0ol00003ooooo`;o00002_oo
ool2o`0000Cooooo0_l00005ooooo`Go0000?oooool3o`0000?ooooo0ol00006ooooo`?o0000KOoo
ool001cooooo00?o0000ooooooooool0GOooool2o`0000Gooooo0_l000001?oooooo0000o`000?l0
000?ooooo`;o00002Oooool2o`0000?ooooo0_l00004ooooo`;o00005oooool2o`00023ooooo0ol0
0003ooooo`;o00002?ooool2o`0006gooooo000Looooo`03o`000?oooooooooo05Oooooo0_l00004
ooooo`;o00001Oooool2o`0000?ooooo0_l0000Iooooo`;o00001?ooool3o`0000;ooooo0_l0000=
ooooo`;o00002?ooool2o`0002Cooooo0_l0001iooooo`007?ooool00ol0003oooooooooo`1Eoooo
o`Co00001_ooool2o`0000Oooooo0ol00005ooooo`?o00000oooool2o`00013ooooo1Ol0000@oooo
o`?o00000_ooool2o`0000Gooooo0_l0000Sooooo`;o00003oooool2o`0006Sooooo000Looooo`;o
0000E?ooool4o`0000;ooooo0_l00004ooooo`;o00001oooool2o`0000Cooooo1_l00002ooooo`?o
00002?ooool2o`0000Gooooo0_l0000;ooooo`?o00001Oooool2o`0000?ooooo0_l00005ooooo`;o
0000=?ooool2o`0006Sooooo000Looooo`03o`000?oooooooooo057ooooo1_l00002ooooo`;o0000
4Oooool8o`0000;ooooo0ol00008ooooo`;o00001?ooool2o`0000;ooooo0_l00002ooooo`;o0000
1?ooool3o`0000Sooooo0_l00008ooooo`;o0000:_ooool2o`0000Oooooo0_l0001Xooooo`007?oo
ool00ol0003oooooooooo`1Aooooo`;o00000_ooool2o`00013ooooo0_l00003ooooo`;o00000_oo
ool2o`0001Gooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`0000Wooooo
0_l00008ooooo`;o00006Oooool2o`000003ooooool0003o000000cooooo0_l00007ooooo`;o0000
J?ooool001cooooo00?o0000ooooooooool0D?ooool2o`0000Wooooo0_l00006ooooo`;o00000_oo
ool2o`0001_ooooo0_l00008ooooo`?o00000_ooool2o`0000_ooooo0_l00008ooooo`;o00006Ooo
ool2o`000004ooooool0003o0000ooooo`;o00000oooool2o`0000Gooooo0_l00009ooooo`;o0000
IOooool001cooooo00?o0000ooooooooool0D?ooool2o`0000Gooooo0_l00002ooooo`;o00001_oo
ool2o`0001Gooooo0_l00008ooooo`;o00002Oooool2o`0000;ooooo0_l00003ooooo`?o00001Ooo
ool2o`0000Sooooo0_l0000Nooooo`Co00000_ooool2o`0000Gooooo1_l00005ooooo`;o0000IOoo
ool001cooooo00?o0000ooooooooool0C?ooool2o`0000Wooooo0_l0000?ooooo`;o00001oooool2
o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l0
000?ooooo`Ko00001?ooool2o`0002Wooooo1Ol00004ooooo`?o00000oooool4o`0006cooooo000L
ooooo`03o`000?oooooooooo04cooooo0_l0000Jooooo`;o00001oooool2o`000003ooooool0003o
000000Co00001?ooool2o`0000?ooooo0ol00009ooooo`;o00001?ooool3o`000003ooooool0003o
000000Cooooo0_l00003ooooo`Co00009Oooool2o`0000Cooooo0ol00003ooooo`;o0000K_ooool0
01cooooo00?o0000ooooooooool0C?ooool2o`0001Cooooo0_l000000ooooooo0000o`00000>oooo
o`Go00001oooool4o`0000;ooooo0_l00006ooooo`;o00001?ooool3o`0000cooooo1?l0000[oooo
o`Co00000oooool2o`0006gooooo000Looooo`03o`000?oooooooooo04cooooo0_l0000<ooooo`;o
00001_ooool2o`000003ooooool0003o000000;ooooo0_l0000Fooooo`;o00001?ooool2o`0000Co
oooo0_l00006ooooo`Go00001?ooool2o`0003?ooooo1?l00003ooooo`;o0000KOooool001cooooo
00?o0000ooooooooool0C?ooool2o`0000cooooo0_l00002ooooo`;o00002Oooool2o`0002;ooooo
1?l00004ooooo`Go00001?ooool2o`0003?ooooo1?l00005ooooo`;o000000Coooooo`000?l0003o
00001_ooool4o`0005gooooo000Looooo`03o`000?oooooooooo04cooooo0_l00008ooooo`;o0000
1_ooool4o`0002gooooo0_l00004ooooo`?o00000_ooool4o`0000Sooooo0_l00003ooooo`;o0000
9_ooool4o`0000Cooooo0ol000001?oooooo0000o`000?l00006ooooo`Co0000GOooool001cooooo
00?o0000ooooooooool0A_ooool2o`0000kooooo0_l00006ooooo`Co00002?ooool2o`0001;ooooo
0_l0000<ooooo`;o00003?ooool4o`0000Gooooo0_l000000ooooooo0000o`000002ooooo`?o0000
:?ooool2o`0000Cooooo0_l00002ooooo`?o00001Oooool4o`0005kooooo000Looooo`03o`000?oo
oooooooo04Kooooo0ol0000Qooooo`;o00001?ooool3o`0000Oooooo0ol000000ooooooo0000o`00
000:ooooo`Co00003_ooool3o`000003ooooool0003o000000Go00000oooool3o`0003?ooooo0_l0
0005ooooo`;o00004?ooool2o`0004kooooo000Looooo`03o`000?oooooooooo04Oooooo0_l00002
ooooo`;o00001_ooool2o`0000Cooooo0_l0000Eooooo`?o00001oooool3o`0000Kooooo0_l00005
ooooo`Ko00003?ooool7o`0000;ooooo0_l00004ooooo`;o0000C?ooool2o`0004kooooo000Loooo
o`03o`000?oooooooooo04?ooooo0ol00005ooooo`;o000000?oooooo`000?l000000oooool2o`00
00Cooooo0_l0000?ooooo`;o00001Oooool2o`0000?ooooo1_l00005ooooo`Co00001oooool4o`00
00gooooo1Ol000000ooooooo0000o`000002o`00047ooooo1?l0001Mooooo`007?ooool00ol0003o
ooooooooo`12ooooo`Ko00000oooool2o`000003ooooool0003o000000;o00006?ooool2o`0000Co
oooo0ol000000ooooooo0000o`000008o`0000;ooooo0ol00002ooooo`?o00000oooool2o`0000Oo
oooo1Ol00004ooooo`So0000:oooool2o`0000;ooooo0_l0000:ooooo`Co00001?ooool4o`0005go
oooo000Looooo`;o0000@oooool3o`000003ooooool0003o000000Sooooo0_l000000ooooooo0000
o`000003ooooo`;o00004_ooool2o`0000;ooooo0ol000001?oooooo0000o`000?ooool7o`000003
ooooool0003o000000?o000000Coooooo`000?l0003o00000_ooool3o`0000Cooooo2?l00006oooo
o`Co00002?ooool2o`0002?ooooo0_l00002ooooo`;o00002_ooool4o`0000Gooooo1?l000000ooo
oooo0000o`00001Iooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00000oooool2o`0000;o
oooo0_l0000>ooooo`;o000000?oooooo`000?l000001?ooool8o`000003ooooool0003o000000Co
00001_ooool4o`000003ooooool0003o000000?o000000?oooooo`000?l000000_l00005ooooo`;o
00002?ooool2o`000004ooooool0003o0000o`0002?ooooo0_l0000Hooooo`;o000000?oooooo`00
0?l00000FOooool001cooooo00?o0000ooooooooool0A?ooool2o`0001Kooooo0_l00003ooooo`;o
00001?ooool2o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`Co00000_ooool2o`000003
ooooool0003o000000;o000000Coooooo`000?l0003o00000_ooool6o`000003ooooool0003o0000
00gooooo0_l00008ooooo`;o00000_ooool2o`0002?ooooo0_l0000?ooooo`?o00001oooool2o`00
05_ooooo000Looooo`03o`000?oooooooooo04Cooooo0_l00002ooooo`;o00003_ooool2o`0000Co
oooo1Ol00004ooooo`?o00002Oooool2o`0000gooooo2_l00005ooooo`;o00002oooool3o`00017o
oooo0_l0000Oooooo`;o00003Oooool3o`0000Oooooo0_l000000ooooooo0000o`00001Hooooo`00
7?ooool00ol0003oooooooooo`0nooooo`;o00002?ooool2o`0000Sooooo0_l00003ooooo`?o0000
1?ooool4o`0000?ooooo1Ol00005ooooo`;o00000_ooool5o`0000?ooooo1Ol00002ooooo`Oo0000
00?oooooo`000?l000000_ooool2o`000003ooooool0003o000000Kooooo0_l00004ooooo`;o0000
4Oooool2o`0001;ooooo0_l000000ooooooo0000o`000008ooooo`;o00003oooool2o`0000Kooooo
1Ol0000;ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0?_ooool2o`0001;ooooo0_l0
0002ooooo`?o00001Oooool4o`0000;ooooo1Ol00006ooooo`;o00000_ooool5o`0000?ooooo2_l0
00000ooooooo0000o`000003o`0000?ooooo0ol00008ooooo`;o00005oooool2o`0001;ooooo0_l0
00000ooooooo0000o`00000Iooooo`;o00001_ooool3o`0000gooooo0ol0001:ooooo`007?ooool0
0ol0003oooooooooo`1Fooooo`;o00001?ooool7o`000003ooooool0003o000000?o00002Oooool3
o`0000?ooooo0_l00002oooooaWo00002?ooool2o`0001?ooooo0_l0000Booooo`;o00000_ooool2
o`0000_ooooo0_l0000?ooooo`;o00000oooool2o`0000kooooo0_l0001:ooooo`007?ooool00ol0
003oooooooooo`0looooo`;o00007?ooool4o`0000?ooooo1_l00004ooooo`;o00000oooool4o`00
00Cooooo7Ol00007ooooo`?o00002?ooool2o`0000_ooooo0_l0000@ooooo`;o00000_ooool2o`00
00_ooooo0_l000000ooooooo0000o`00000;ooooo`?o00000oooool2o`0005[ooooo000Looooo`03
o`000?oooooooooo03cooooo0_l0000Looooo`;o000000?oooooo`000?l000000oooool5o`0000Co
oooo0_l00003ooooo`;o00001ooooolHo`0000;ooooo0_l00005ooooo`Ko00000oooool2o`0000;o
oooo0_l00008ooooo`;o000000?oooooo`000?l000004oooool2o`0000Gooooo0_l00008ooooo`;o
00000_ooool2o`0000Oooooo0ol0001Oooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o0000
3_ooool2o`0000?ooooo1Ol00009ooooo`Co00001_oooolJo`0000Kooooo0_l00002ooooo`;o0000
0oooool2o`0000cooooo0_l0000Fooooo`;o000000?oooooo`000?l000001?l00007ooooo`;o0000
0oooool2o`0006Wooooo000Looooo`03o`000?oooooooooo04gooooo0_l00002ooooo`;o00004_oo
ool2o`0000Cooooo0_l00005ooooo`?o00001OoooolJo`0000oooooo0_l00006ooooo`Co00007Ooo
ool4o`0000Gooooo0_l00002ooooo`;o00007?ooool2o`00053ooooo000Looooo`03o`000?oooooo
oooo057ooooo0_l00005ooooo`;o00002Oooool2o`0000Kooooo1?l00002ooooo`Co00001?oooolL
o`0001Kooooo1?l0000:ooooo`Co00003Oooool2o`000003ooooool0003o000000Go000000?ooooo
o`000?l000000_ooool3o`0000?ooooo0_l0000Fooooo`;o0000D?ooool001cooooo00?o0000oooo
ooooool0F?ooool2o`0000Cooooo0_l00003ooooo`?o00000_ooool2o`000003ooooool0003o0000
00;o00000_ooool2o`0000Cooooo1?l000000ooooooo0000o`00000Ho`0001Gooooo0_l00007oooo
o`Co000000?oooooo`000?l000000_l00006ooooo`;o00001Oooool2o`000003ooooool0003o0000
00Go00001_ooool2o`0000?ooooo0_l0001Xooooo`007?ooool00ol0003oooooooooo`0looooo`;o
00005_ooool2o`0000;ooooo1?l00002ooooo`;o00001?ooool6o`000003ooooool0003o000000[o
oooo0_l00004oooooa_o00004oooool2o`0000Kooooo1Ol00008ooooo`;o000000?oooooo`000?l0
00001_ooool2o`000003ooooool0003o000000;o000000Coooooo`000?l0003o00001?ooool2o`00
06gooooo000Looooo`03o`000?oooooooooo03Oooooo0_l00003ooooo`;o00005_ooool2o`0000;o
oooo1?l00005ooooo`;o000000?oooooo`000?l000001?l00005ooooo`;o00003?oooolKo`0000Ko
oooo0_l0000Cooooo`;o00002Oooool4o`0000Wooooo1?l00004ooooo`Ko000000?oooooo`000?l0
00000_l0000Gooooo`;o00000_ooool2o`0004kooooo000Looooo`03o`000?oooooooooo03Oooooo
0_l00003ooooo`;o00005Oooool2o`0000cooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o
00000oooool4o`0000Cooooo1_l00002oooooaSo000000?oooooo`000?l000000_ooool2o`000004
ooooool0003o0000o`0000?ooooo0_l0000Iooooo`;o00000oooool2o`0000Sooooo0ol00003oooo
o`Ko00000_ooool3o`0000Gooooo0_l00004ooooo`;o00001?ooool2o`0000Cooooo0_l00002oooo
o`;o00001oooool2o`0004Gooooo000Looooo`;o0000>_ooool2o`00017ooooo0_l00005ooooo`;o
00001oooool4o`0000Sooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo9Ol00002oooo
o`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo0_l0000Booooo`;o00001_ooool2o`00
00Wooooo0_l00003ooooo`Go00000oooool4o`0000?ooooo0ol00004ooooo`;o00001?ooool2o`00
017ooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00004Oooool2o`0000ko
oooo1?l0000@ooooo`;o000000?oooooo`000?l000000oooool2o`000003ooooool0003o000001co
00003_ooool2o`0000Kooooo0_l00003ooooo`;o00001Oooool2o`0001Sooooo1Ol00003ooooo`;o
00000oooool3o`0001cooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`0iooooo`;o0000
8Oooool2o`0001;ooooo0_l000000ooooooo0000o`000003ooooo`go000000?oooooo`000?l00000
4Ol0000Dooooo`Co00000oooool2o`0000Kooooo1?l0000Booooo`;o000000?oooooo`000?l00000
0ol00003ooooo`;o00001?ooool2o`0000Kooooo0ol0000<ooooo`;o00001Oooool2o`0004Kooooo
000Looooo`03o`000?oooooooooo03Wooooo0_l0000Qooooo`;o00001?ooool2o`0000?ooooo0_l0
0003ooooo`;o00002_oooolOo`0000Sooooo0_l0000<ooooo`;o00001Oooool2o`0000Kooooo1_l0
0008ooooo`;o00001_ooool2o`0000;ooooo0ol00003ooooo`?o00003?ooool3o`0000cooooo0_l0
001=ooooo`007?ooool00ol0003oooooooooo`1Rooooo`;o00000oooool2o`0000?ooooo0_l00003
ooooo`;o00001_ooool2o`000003ooooool0003o000000Go000000?oooooo`000?l000003_l00000
0ooooooo0000o`000008ooooo`;o00002oooool2o`0000Kooooo0_l00003ooooo`;o000000?ooooo
o`000?l000001?l00008ooooo`;o000000?oooooo`000?l000001oooool4o`0000;ooooo0_l00000
0ooooooo0000o`000009ooooo`;o00005_ooool2o`0004Gooooo000Looooo`03o`000?oooooooooo
03gooooo0_l0000Oooooo`;o00004Oooool2o`0000Oooooo7Ol00002ooooo`;o00003oooool7o`00
00;ooooo1Ol000001?oooooo0000o`000?ooool4o`0000?ooooo0_l00004ooooo`Oo00001_ooool4
o`0000?ooooo1?l00009ooooo`;o00003_ooool2o`0000Kooooo0_l00015ooooo`007?ooool00ol0
003oooooooooo`0mooooo`;o00002?ooool2o`0001Gooooo0_l00004ooooo`;o00001oooool4o`00
00Wooooo0_l000000ooooooo0000o`00000Ho`0000;ooooo0_l00003ooooo`Co00001_ooool9o`00
00;ooooo1Ol00004ooooo`;o000000?oooooo`000?l000001?l000001?oooooo0000o`000?ooool4
o`000003ooooool0003o000000Sooooo0_l00003ooooo`;o00001?ooool2o`0001Gooooo0_l00006
ooooo`;o0000AOooool001cooooo00?o0000ooooooooool0>Oooool2o`0000cooooo0_l0000Koooo
o`;o00000_ooool4o`000003ooooool0003o000000;o00002Oooool>o`000003ooooool0003o0000
00[o00001oooool6o`0000Kooooo0_l0000Eooooo`co00001_ooool3o`0000oooooo0ol0000Foooo
o`;o00001?ooool3o`0004Cooooo000Looooo`03o`000?oooooooooo03Wooooo0_l0000]ooooo`Co
00004?oooolKo`0000?ooooo1_l000000ooooooo0000o`000003ooooo`;o00004oooool4o`0000?o
oooo1?l000000ooooooo0000o`000002o`0000?ooooo1_l0000@ooooo`;o00005_ooool2o`0000Co
oooo0ol00014ooooo`007?ooool00ol0003oooooooooo`1Wooooo`;o00001oooool2o`0000Wooooo
7?l00003ooooo`?o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00004oooool4o`0000;o
oooo0ol00002ooooo`?o00001Oooool8o`0000Gooooo0_l0000Uooooo`;o0000AOooool001cooooo
00?o0000ooooooooool0>?ooool2o`0000Wooooo0_l0000Rooooo`;o00000oooool2o`000004oooo
ool0003o0000o`0000Sooooo6?l00003ooooo`;o00000oooool2o`0001?ooooo0_l0000:ooooo`Co
00000_ooool3o`0000;ooooo0ol00005ooooo`So00001Oooool2o`0001oooooo0_l0001;ooooo`00
7?ooool00ol0003oooooooooo`0eooooo`;o000000?oooooo`000?l000002Oooool4o`0002Gooooo
0_l000000ooooooo0000o`000009ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo
0000o`00000;o`0000?ooooo0_l00005ooooo`;o00001?ooool2o`0000_ooooo1?l00003ooooo`;o
00001oooool2o`0000Gooooo1_l00004ooooo`So00005?ooool2o`0000;ooooo0_l0000<ooooo`Co
00000_ooool2o`0004Gooooo000Looooo`03o`000?oooooooooo03Gooooo0_l000000ooooooo0000
o`000009ooooo`Co0000:Oooool2o`0000Oooooo1_l000001Ooooooo0000o`000?l0003ooooo00Ko
000000Coooooo`000?l0003o00001Oooool2o`0000_ooooo0_l00007ooooo`Wo00000_ooool2o`00
00Sooooo3?l000000ooooooo0000o`000002o`000003ooooool0003o000000Co00002oooool4o`00
00Gooooo0ol000000ooooooo0000o`000007ooooo`;o00001?ooool3o`0000;ooooo0_l00015oooo
o`007?ooool00ol0003oooooooooo`0hooooo`;o00002Oooool2o`0002[ooooo0ol00007ooooo`Ko
000000?oooooo`000?l000002?l0000?ooooo`?o00003Oooool9o`0000Oooooo5_l000000ooooooo
0000o`000003o`0000cooooo1?l000000ooooooo0000o`000003ooooo`;o00002?ooool4o`0000Co
oooo0_l0001:ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool2o`00
0003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0=_ooool2o`0000Wooooo1?l0000Zoooo
o`;o000000?oooooo`000?l000001oooool2o`0000Gooooo1_l00002ooooo`So00001oooool3o`00
0003ooooool0003o000000;o00003oooool4o`0000Gooooo5ol000000ooooooo0000o`000004o`00
00_ooooo0_l00002ooooo`;o00001?ooool2o`0000Oooooo0ol00006ooooo`;o00000_ooool2o`00
04Gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0=_ooool2o`0000Wooooo1?l0000[ooooo`Co00001oooool2
o`0000Kooooo3ol00008ooooo`;o000000?oooooo`000?l000000_l0000;ooooo`;o00000oooool3
o`0000Gooooo0ol000000ooooooo0000o`00000Eo`000004ooooool0003o0000o`0000Wooooo0_l0
0003ooooo`;o00001?ooool2o`0000Sooooo0_l00004ooooo`Co00000_ooool2o`0004Gooooo0000
0ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006ooooo`03o`000?oooooo
oooo03Kooooo0_l0000@ooooo`;o00006_ooool2o`0000[ooooo0_l00003ooooo`;o00001?ooool2
o`0000[ooooo1Ol000000ooooooo0000o`000009ooooo`Co000000?oooooo`000?l000003Oooool2
o`0000Wooooo1Ol000000ooooooo0000o`00000Eo`000004ooooool0003o0000o`0000Wooooo0_l0
0003ooooo`?o00002?ooool2o`0000Kooooo1ol00019ooooo`0000?oooooo`000?ooool00_ooool0
0ol0003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0000fooooo`;o00002Ooo
ool2o`0000Gooooo1?l0000Hooooo`;o00002_ooool2o`000003ooooool0003o000000;o00001?oo
ool2o`0000_ooooo1?l000000ooooooo0000o`000009ooooo`;o00007Oooool?o`000003ooooool0
003o0000017o00000_ooool2o`0000Sooooo0ol00008ooooo`;o00001?ooool7o`0004_ooooo0000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo00001ooo
ool00ol0003oooooooooo`11ooooo`;o00001oooool2o`0001[ooooo0_l00008ooooo`;o000000?o
ooooo`000?l000000_l000000ooooooo0000o`00000>ooooo`Co00003?ooool2o`0001Sooooo0_l0
00000ooooooo0000o`00000No`000003ooooool0003o000000;o00000_ooool2o`0000gooooo0_l0
0009ooooo`?o0000D?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool0
0omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo04Kooooo0_l0000Nooooo`;o00002_ooool2
o`0000;ooooo1?l00002ooooo`;o00006_ooool2o`0001Oooooo5?l000000ooooooo0000o`000006
o`0000;ooooo2Ol0000=ooooo`?o00000_ooool2o`0000Sooooo1?l0001@ooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0=?oo
ool2o`0000cooooo0_l00002ooooo`;o000000?oooooo`000?l000009oooool2o`0000;ooooo0_l0
0004ooooo`;o00002_ooool2o`0000?ooooo0_l0000Rooooo`Co000000?oooooo`000?l000005Ol0
0002ooooo`_o00003?ooool3o`0000Oooooo0_l00003ooooo`;o00002Oooool4o`0004Gooooo0000
1_ooooook^k^oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooo
ooooo`0dooooo`;o00003?ooool2o`0000Cooooo0ol0000Oooooo`;o00001oooool3o`000003oooo
ool0003o000000Wooooo0_l00004ooooo`;o000000?oooooo`000?l000000_l0000OoooooaGo0000
00?oooooo`000?l000001ol00002ooooo`Co000000?oooooo`000?l000000_ooool2o`0000gooooo
0_l00007ooooo`;o00000oooool2o`0000;ooooo0_l00005ooooo`Co0000AOooool001cooooo00?o
0000ooooooooool0=?ooool2o`0001;ooooo0_l0000Pooooo`Co00001Oooool3o`000003ooooool0
003o000000Wooooo1Ol00004ooooo`Co00007ooooolQo`000003ooooool0003o000000Co00000_oo
ool2o`0000gooooo0_l0000<ooooo`;o00000_ooool2o`0004kooooo000Looooo`03o`000?oooooo
oooo06Cooooo1?l00004ooooo`;o00001_ooool2o`0000Kooooo0ol00003ooooo`Go00001?ooool4
o`0002;ooooo2Ol000000ooooooo0000o`000003o`000003ooooool0003o000001?o00000_ooool3
o`0001Wooooo1?l00002ooooo`Co000000?oooooo`000?l000000_l00009ooooo`;o0000>oooool0
01cooooo00?o0000ooooooooool0F_ooool3o`000003ooooool0003o000000Cooooo1?l0000:oooo
o`;o00001oooool4o`0000?ooooo0_l00007ooooo`?o00007_ooool2o`0000?ooooo9?l00004oooo
o`;o00006Oooool:o`000003ooooool0003o000000;o00002Oooool2o`0003_ooooo000Looooo`03
o`000?oooooooooo03;ooooo0_l0000=ooooo`?o00005_ooool3o`000003ooooool0003o000001;o
oooo0_l00007ooooo`;o00001Oooool4o`0000;ooooo0_l00009ooooo`;o00005oooool4o`000003
ooooool0003o000002Go000000?oooooo`000?l000002Oooool2o`0001;ooooo1?l00005ooooo`?o
00000_ooool2o`00047ooooo000Looooo`03o`000?oooooooooo03;ooooo0ol0000:ooooo`Go0000
:_ooool2o`0000;ooooo1?l00002ooooo`;o00002?ooool4o`0000;ooooo0_l00009ooooo`;o0000
6Oooool2o`000003ooooool0003o000002Go000000?oooooo`000?l000002Oooool2o`0001?ooooo
1Ol00003ooooo`?o00000_ooool2o`0000Cooooo0_l00002ooooo`;o0000=oooool001cooooo00?o
0000ooooooooool0<oooool2o`0000[ooooo0_l0000]ooooo`;o00001?ooool2o`0000;ooooo1?l0
0006ooooo`?o00002oooool2o`0001kooooo6ol000000ooooooo0000o`00000=o`0000Sooooo0_l0
000Eooooo`Co00000oooool3o`0000Sooooo0_l00002ooooo`;o0000=oooool001cooooo00?o0000
ooooooooool0?oooool2o`0000?ooooo0_l0000Xooooo`;o00002?ooool4o`0000?ooooo0_l0000=
ooooo`Co00007_oooolZo`0000Wooooo0_l00002ooooo`?o00004?ooool3o`000003ooooool0003o
000000;ooooo0ol00014ooooo`007?ooool00ol0003oooooooooo`14ooooo`Co00005?ooool2o`00
00[ooooo0_l0000Aooooo`;o00000_ooool2o`0000gooooo0ol0000NooooobSo00003?ooool2o`00
00;ooooo0ol000000ooooooo0000o`00000>ooooo`;o000000?oooooo`000?l000000oooool2o`00
04Cooooo000Looooo`03o`000?oooooooooo04Gooooo0ol0000Dooooo`;o00002_ooool2o`0000ko
oooo0_l000000ooooooo0000o`00000Pooooo`;o00004?ooool2o`000003ooooool0003o000002?o
00003Oooool2o`000003ooooool0003o000000;ooooo0_l0000Sooooo`;o0000=oooool001cooooo
00?o0000ooooooooool0AOooool2o`0002;ooooo0_l0000=ooooo`Ko00001Oooool2o`0000cooooo
0_l0000:ooooo`;o00003_oooolYo`000004ooooool0003o0000ooooo`Co00000oooool2o`000004
ooooool0003o0000ooooo`;o00003Oooool6o`0001Cooooo0_l0000gooooo`007?ooool00ol0003o
ooooooooo`11ooooo`;o00001oooool2o`0000Sooooo0_l0000Aooooo`Co00003oooool4o`0000Go
oooo0_l00009ooooo`Oo00005ooooolZo`000004ooooool0003o0000ooooo`Co00000oooool4o`00
00Kooooo0_l00009ooooo`Ko000000?oooooo`000?l00000B_ooool001cooooo0_l0000dooooo`;o
00001oooool2o`0000?ooooo0_l00007ooooo`;o00002?ooool2o`00017ooooo0_l0000Fooooo`;o
00001Oooool2o`0000Kooooo1ol0000:ooooo`;o00002oooool6o`000003ooooool0003o000002;o
00000_ooool3o`0000Oooooo0_l00006ooooo`;o00001?ooool2o`0000[ooooo0_l0000Booooo`;o
0000=_ooool001cooooo00?o0000ooooooooool0<oooool2o`0000Oooooo0_l000000ooooooo0000
o`000006ooooo`;o0000;_ooool2o`000003ooooool0003o000000?ooooo0_l00003ooooo`Co0000
1_ooool2o`0000oooooo0_l0000=ooooobWo00000_ooool3o`0001Gooooo0ol00005ooooo`;o0000
5_ooool2o`0003Kooooo000Looooo`03o`000?oooooooooo03gooooo1?l000000ooooooo0000o`00
0003ooooo`;o00004?ooool2o`000003ooooool0003o000000?ooooo0_l0000<ooooo`;o00001_oo
ool2o`000005ooooool0003o0000o`000?ooool00_l00004ooooo`;o00002?ooool5o`0001Sooooo
0_l000000ooooooo0000o`00000/o`0000;ooooo0_l0000Booooo`;o00001Oooool2o`0004kooooo
000Looooo`03o`000?oooooooooo03gooooo0_l00003ooooo`;o00001Oooool2o`0000kooooo0_l0
00000ooooooo0000o`000005o`000003ooooool0003o000000Wooooo0_l00005ooooo`;o00000ooo
ool5o`0000Cooooo0_l00009ooooo`Ko00003?ooool2o`0000Sooooo0_l00003ooooo`Go000000?o
ooooo`000?l000007?l000000ooooooo0000o`000004o`0000?ooooo0_l00003ooooo`Go00002?oo
ool4o`0000Cooooo1?l0001=ooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00001Oooool2
o`0000?ooooo0_l00003ooooo`Co00000_ooool2o`0000Sooooo2Ol0000?ooooo`;o000000?ooooo
o`000?l000001Ol00004ooooo`;o00002oooool4o`0000cooooo0ol00003ooooo`;o00002?oooolP
o`0000Kooooo1?l00007ooooo`So00001_ooool4o`000003ooooool0003o000000Go0000COooool0
01cooooo00?o0000ooooooooool0?Oooool2o`0000Gooooo0_l00008ooooo`Co00000_ooool4o`00
00[ooooo1Ol0000Aooooo`Go000000?oooooo`000?l000000_l00002ooooo`;o00002Oooool5o`00
00kooooo0ol00002ooooo`;o00002?ooool7o`000003ooooool0003o000001Oo00001Oooool3o`00
00Sooooo0_l000001?oooooo0000o`000?ooool4o`0000Wooooo1Ol0001?ooooo`007?ooool00ol0
003oooooooooo`14ooooo`?o00000_ooool5o`0000Sooooo1?l00003ooooo`;o00001?ooool4o`00
00Kooooo0_l00008ooooo`_o00003Oooool2o`000003ooooool0003o000000;o00003Oooool2o`00
00;ooooo0_l00008ooooo`Co000000?oooooo`000?l000007?l000000ooooooo0000o`000003o`00
00_ooooo0_l000000ooooooo0000o`000002o`0000[ooooo0_l0001Aooooo`007?ooool00ol0003o
ooooooooo`0aooooo`;o00004Oooool3o`0000;ooooo1Ol00002ooooo`Co00001?ooool2o`0000;o
oooo0ol00004ooooo`?o00000_ooool2o`0000?ooooo0_l00007ooooo`[o00005?ooool2o`00017o
oooo0_l00003ooooo`;o00000oooool3o`000003ooooool0003o000002Co00003?ooool2o`00063o
oooo000Looooo`03o`000?oooooooooo037ooooo0_l0000Hooooo`;o00000oooool4o`0000;ooooo
0_l00003ooooo`_o00000_ooool2o`0000Gooooo0_l00004ooooo`co00000oooool2o`00017ooooo
1?l0000=ooooo`;o00000_ooool2o`0000Gooooo2?l000000ooooooo0000o`00000Co`0000;ooooo
0_l000000ooooooo0000o`000003o`0000Wooooo0_l000000ooooooo0000o`00000>ooooo`;o0000
D?ooool001cooooo00?o0000ooooooooool0<?ooool2o`0002Cooooo0_l000000ooooooo0000o`00
0002o`000003ooooool0003o000000?o00000_ooool2o`000003ooooool0003o000000;ooooo0_l0
00000ooooooo0000o`000004ooooo`co00000oooool2o`000003ooooool0003o000000_ooooo0_l0
00000ooooooo0000o`000004o`0000_ooooo0_l00009ooooo`Co000000?oooooo`000?l000000_oo
ool=o`000003ooooool0003o000000Gooooo0_l00002ooooo`?o000000?oooooo`000?l000002Ooo
ool2o`0000gooooo0_l00002ooooo`;o0000D?ooool001cooooo00?o0000ooooooooool0;oooool3
o`0002Oooooo0_l00003ooooo`?o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000007
oooooa3o00000_ooool2o`0000_ooooo0_l000000ooooooo0000o`000004o`0001Kooooo1?l00003
ooooo`So000000Coooooo`000?l0003o00000_ooool2o`000003ooooool0003o000000;o00000_oo
ool7o`000003ooooool0003o000000Kooooo0_l000000ooooooo0000o`000008ooooo`?o00000_oo
ool2o`0005Cooooo000Looooo`03o`000?oooooooooo02oooooo0ol0000Aooooo`;o00006Oooool4
o`0000Kooooo0ol00007oooooa?o000000?oooooo`000?l000003_ooool5o`0001;ooooo0_l00004
ooooo`Ko000000?oooooo`000?l000000_l00005ooooo`;o00000oooool>o`0000?ooooo1?l00003
ooooo`Go00001_ooool2o`000004ooooool0003o0000o`0000?ooooo1Ol0001@ooooo`007?ooool0
0ol0003oooooooooo`0`ooooo`;o00004Oooool3o`0001Cooooo2?l00002ooooo`;o00000_ooool3
o`0000Gooooo1_l000000ooooooo0000o`000007o`0000;ooooo0ol000000ooooooo0000o`00000<
ooooo`Ko00004Oooool6o`0000Cooooo1Ol00009ooooo`?o00000_ooool5o`000003ooooool0003o
000000go00000oooool5o`0000Kooooo0ol00005ooooo`Ko0000D?ooool001cooooo00?o0000oooo
ooooool0A?ooool4o`0001;ooooo1Ol00002ooooo`;o000000?oooooo`000?l000001?l00006oooo
oa3o00000_ooool3o`000003ooooool0003o000000[ooooo2_l0000?ooooo`;o00000_ooool2o`00
00Kooooo1_l00006ooooo`?o00000_ooool2o`000004ooooool0003o0000ooooo`ko000000?ooooo
o`000?l000003Oooool2o`0000Gooooo1_l0001@ooooo`007?ooool00ol0003oooooooooo`16oooo
o`;o00005Oooool2o`0000;ooooo0ol00002ooooo`;o00002oooool<o`0000;ooooo0_l00003oooo
o`;o00002_ooool2o`000003ooooool0003o000000?ooooo0ol0000>ooooo`;o00002oooool5o`00
0004ooooool0003o0000ooooo`;o00001Oooool2o`0000Cooooo3Ol00002ooooo`Co00000oooool2
o`0000Wooooo0ol000001?oooooo0000o`000?ooool3o`00053ooooo000Looooo`03o`000?oooooo
oooo05[ooooo0_l000000ooooooo0000o`000003ooooo`;o00001_ooool2o`000003ooooool0003o
000000Cooooo2ol00003ooooo`;o00000oooool2o`0000[ooooo0_l000000ooooooo0000o`000004
ooooo`Co00006Oooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000000_l0
0004ooooo`;o00000_ooool5o`0000;ooooo2?l00002ooooo`?o00000oooool2o`0000;ooooo0ol0
00000ooooooo0000o`000007o`000003ooooool0003o000000cooooo1?l00011ooooo`007?ooool2
o`0004_ooooo0ol0000=ooooo`;o000000?oooooo`000?l000002?ooool2o`000004ooooool0003o
0000ooooo`Co00000_ooool;o`0000Oooooo0_l0000:ooooo`ko00003?ooool2o`0000_ooooo2?l0
0002ooooo`?o00001?ooool8o`000003ooooool0003o000000?o00000oooool2o`0000;ooooo0_l0
0008ooooo`?o000000?oooooo`000?l000001Ol0000>ooooo`;o000000?oooooo`000?l000000_l0
0011ooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00006_ooool3o`0000Kooooo0_l00005
ooooo`;o00002oooool2o`0000Cooooo1?l00003ooooo`[o00001oooool2o`0000[ooooo0_l00000
0ooooooo0000o`000006o`000003ooooool0003o000000cooooo0_l00008ooooo`;o000000?ooooo
o`000?l000001_l00002ooooo`;o00001?ooool8o`0000;ooooo0ol00006ooooo`;o00004_ooool6
o`0000_ooooo0ol00016ooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00008oooool2o`00
00Cooooo0ol0000<ooooo`;o00002_ooool9o`0000Gooooo0_l0000@ooooo`?o00000_ooool2o`00
00;ooooo0ol0000Eooooo`;o00000_ooool4o`0000Sooooo0_l000000ooooooo0000o`000006o`00
00?ooooo0_l00002ooooo`;o00000_ooool2o`0000oooooo0_l000000ooooooo0000o`000004o`00
00_ooooo0_l00006ooooo`Co0000?Oooool001cooooo00?o0000ooooooooool0FOooool3o`0000Oo
oooo0_l00003ooooo`;o000000?oooooo`000?l000000oooool2o`000003ooooool0003o000000;o
oooo1_l00005ooooo`;o00004Oooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`0001Co
oooo0_l00002ooooo`;o00000_ooool2o`0000Kooooo0_l00002ooooo`?o00001oooool2o`0000;o
oooo0ol00002ooooo`;o00003Oooool3o`0000Sooooo0_l0000<ooooo`;o00000_ooool4o`0003go
oooo000Looooo`03o`000?oooooooooo033ooooo0_l0000Hooooo`;o00001Oooool2o`0000oooooo
0ol00006ooooo`;o00000oooool2o`000003ooooool0003o000000?ooooo0_l0000Cooooo`;o0000
1?ooool4o`0000?ooooo0_l00002ooooo`?o00001oooool2o`0001?ooooo0_l00002ooooo`;o0000
1Oooool3o`0000Wooooo0ol000000ooooooo0000o`000002ooooo`;o00001oooool2o`0000Cooooo
1?l00007ooooo`;o00000oooool2o`0000Oooooo0_l00002ooooo`;o0000?oooool001cooooo00?o
0000ooooooooool0<?ooool2o`000003ooooool0003o000001Gooooo0_l00005ooooo`;o00003ooo
ool2o`0000Cooooo1?l00006ooooo`?o00000oooool3o`0000Wooooo0_l00007ooooo`?o00000ooo
ool2o`0000Wooooo0ol00007ooooo`;o00005_ooool3o`0000?ooooo1?l000000ooooooo0000o`00
0007ooooo`?o00003_ooool2o`0000Kooooo0_l0000<ooooo`;o000000?oooooo`000?l000002?oo
ool2o`000003ooooool0003o000003cooooo000Looooo`03o`000?oooooooooo033ooooo0_l00000
0ooooooo0000o`00000Oooooo`?o00004?ooool5o`0000Kooooo0_l00004ooooo`?o00001oooool4
o`0000Sooooo0_l00003ooooo`;o00000oooool4o`000003ooooool0003o000000Co00004Oooool2
o`0000Wooooo0ol000001?oooooo0000o`000?ooool2o`0000?ooooo0_l0000Mooooo`Co00004?oo
ool2o`0000_ooooo0_l0000looooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00000_ooool2
o`0001oooooo0ol00004ooooo`;o00002_ooool2o`0000Wooooo0_l0000>ooooo`;o00003?ooool2
o`0000Kooooo2ol0000=ooooo`;o00000_ooool2o`0000Gooooo0_l00002ooooo`;o00000_ooool2
o`0002Gooooo1?l0000Eooooo`Co0000@_ooool001cooooo00?o0000ooooooooool0;oooool6o`00
01Cooooo0_l0000@ooooo`;o00005_ooool2o`0000kooooo0_l0000;ooooo`;o00001_ooool2o`00
0004ooooool0003o0000ooooo`Go00003Oooool2o`0000?ooooo0_l000001?oooooo0000o`000?oo
ool2o`0000;ooooo0_l0000Aooooo`;o00005?ooool2o`0000;ooooo0_l0000:ooooo`;o00000ooo
ool2o`0000Cooooo1?l00008ooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0;oooool5
o`0001Gooooo0_l0000Uooooo`Go00003_ooool2o`0000gooooo0_l00003ooooo`;o00001_ooool5
o`0000?ooooo0_l00007ooooo`Co000000Coooooo`000?l0003ooooo0_l00004ooooo`?o00001?oo
ool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`?o00000_ooool3o`0000Wooooo0_l0
0003ooooo`;o00003Oooool3o`0000?ooooo0_l00009ooooo`;o00001Oooool2o`0003Sooooo000L
ooooo`03o`000?oooooooooo03;ooooo0_l0000Eooooo`;o00003Oooool2o`0000?ooooo0ol00003
ooooo`;o00002oooool4o`0000gooooo0_l00002ooooo`;o00002oooool2o`0000?ooooo1?l00003
ooooo`;o000000Coooooo`000?l0003o00000oooool2o`0000Kooooo0_l000000ooooooo0000o`00
0002o`0000Cooooo0_l00002ooooo`;o00001Oooool2o`000003ooooool0003o000000;ooooo1Ol0
0002ooooo`;o00000_ooool3o`0000Wooooo0_l0000Booooo`;o00001Oooool2o`0000Gooooo0_l0
00000ooooooo0000o`000002ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0B?ooool2
o`0000Gooooo0_l00007ooooo`Co000000Coooooo`000?l0003o00000oooool2o`0000?ooooo0_l0
0002ooooo`;o00001_ooool2o`0000_ooooo0_l00002ooooo`;o00002oooool2o`0000Gooooo0ol0
0002ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o00001?ooool3o`000004ooooool0
003o0000o`0000Cooooo0_l0000;ooooo`;o00001Oooool3o`0000;ooooo0_l0000;ooooo`;o0000
1oooool3o`0000[ooooo0_l00006ooooo`;o00001?ooool3o`0000Gooooo0_l0000kooooo`007?oo
ool00ol0003oooooooooo`18ooooo`;o00001?ooool3o`000003ooooool0003o000000;o00001?oo
ool2o`0000Cooooo1Ol000000ooooooo0000o`000003o`000003ooooool0003o000000Kooooo0_l0
000Aooooo`;o00001Oooool2o`0000;ooooo0_l00005ooooo`?o00001_ooool3o`0000Cooooo0_l0
0004ooooo`?o000000?oooooo`000?l000001oooool2o`0000Wooooo0_l000001?oooooo0000o`00
0?l00002ooooo`;o00001?ooool2o`0000Wooooo0_l00007ooooo`?o00001?ooool2o`000004oooo
ool0003o0000ooooo`?o00002Oooool4o`0004?ooooo000Looooo`03o`000?oooooooooo02kooooo
0_l00003ooooo`;o00006Oooool2o`0000;ooooo1?l00004ooooo`;o00000_ooool7o`000003oooo
ool0003o000000?o000000?oooooo`000?l000006Oooool4o`0000?ooooo1?l00002ooooo`?o0000
0_ooool2o`0000Oooooo1Ol00002ooooo`;o00001Oooool2o`0000?ooooo0_l00005ooooo`;o0000
3?ooool3o`0000;ooooo0_l00004ooooo`;o00002?ooool4o`0000gooooo0_l000000ooooooo0000
o`000002ooooo`;o00002?ooool4o`0000Wooooo0_l0000iooooo`007?ooool00ol0003ooooooooo
o`0^ooooo`;o00000_ooool3o`0001cooooo0_l00007ooooo`go000000Goooooo`000?l0003o0000
ooooo`02o`0000;ooooo0_l0000<ooooo`;o00000_ooool2o`0000?ooooo1?l00005ooooo`Oo0000
0oooool3o`0000Cooooo1_l00002ooooo`?o00001?ooool2o`000003ooooool0003o000000;o0000
0oooool2o`0000[ooooo0_l0000Fooooo`Go00004Oooool5o`0000Sooooo0_l0000;ooooo`;o0000
>Oooool001cooooo00?o0000ooooooooool0<_ooool4o`0001_ooooo0_l00006ooooo`ko000000?o
ooooo`000?l000000_ooool2o`0000;ooooo0_l0000<ooooo`;o00000_ooool2o`0000Oooooo0_l0
0005ooooo`;o000000?oooooo`000?l000000oooool3o`0000Cooooo2ol00002ooooo`Co000000?o
ooooo`000?l000000_l000000ooooooo0000o`000002o`0000[ooooo0_l0000Fooooo`?o00003_oo
ool2o`0000?ooooo1Ol0000@ooooo`;o0000?_ooool001cooooo0_l0000eooooo`;o00008OoooolC
o`0000;ooooo0_l00004ooooo`;o00005?ooool8o`0000Gooooo0ol00002ooooo`Co00000oooool8
o`0000Gooooo1?l00003ooooo`Ko00001?ooool2o`0001cooooo0_l0000@ooooo`;o00001?ooool2
o`00017ooooo0ol00002ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0A_ooool2o`00
00[ooooo0_l00003ooooo`;o000000?oooooo`000?l000004Ol00005ooooo`?o00004oooool3o`00
0003ooooool0003o000000;o00001_ooool4o`0000;ooooo0_l00006ooooo`Co00003_ooool4o`00
00Gooooo0_l0000Jooooo`Co00002?ooool2o`0001oooooo0_l000000ooooooo0000o`000002o`00
03[ooooo000Looooo`03o`000?oooooooooo03Oooooo0_l0000=ooooo`;o00002?ooool6o`000003
ooooool0003o000001Co00001_ooool2o`0001;ooooo0_l00004ooooo`Go000000?oooooo`000?l0
00000oooool2o`0000Sooooo1ol00007ooooo`;o00001_ooool3o`0000;ooooo0_l000000ooooooo
0000o`000002ooooo`?o00004_ooool5o`0000Wooooo0_l00006ooooo`;o000000?oooooo`000?l0
00005oooool2o`0003cooooo000Looooo`03o`000?oooooooooo03Oooooo0_l0000Gooooo`;o0000
0_ooool9o`000003ooooool0003o000000_o00002?ooool2o`000003ooooool0003o000000oooooo
0_l00004ooooo`So00003Oooool3o`000005ooooool0003o0000o`000?ooool00_l00002ooooo`Co
00001?ooool2o`000003ooooool0003o000000;ooooo2_l000000ooooooo0000o`000004ooooo`;o
00001Oooool9o`0000;ooooo1?l0000;ooooo`;o000000?oooooo`000?l000004Oooool2o`0000?o
oooo0_l0000mooooo`007?ooool00ol0003oooooooooo`1?ooooo`;o00001?oooolGo`0000;ooooo
0_l00002ooooo`?o000000?oooooo`000?l000001oooool2o`0000cooooo2?l00002ooooo`;o0000
4Oooool2o`0000;ooooo0_l00006ooooo`Go00000oooool6o`000003ooooool0003o000000[o0000
00?oooooo`000?l000001Ol00007ooooo`Co00002oooool2o`0001Cooooo0_l00003ooooo`;o0000
?Oooool001cooooo00?o0000ooooooooool0>oooool2o`0001;ooooo0_l00002oooooaWo000000Co
ooooo`000?l0003o00000_ooool4o`0000;ooooo0_l00003ooooo`Co00001Oooool4o`0000?ooooo
0ol000000ooooooo0000o`000002o`0000;ooooo0_l0000Aooooo`;o00002oooool4o`0000;ooooo
0_l00006oooooa;o00001Oooool2o`000003ooooool0003o000000Sooooo0_l00004ooooo`;o0000
00?oooooo`000?l000004?ooool2o`0000Cooooo0_l0000mooooo`007?ooool00ol0003ooooooooo
o`0kooooo`;o00004Oooool2o`0000?ooooo7?l00003ooooo`Co00000_ooool2o`0000?ooooo0ol0
0006ooooo`Co00001Oooool2o`0002Oooooo0_l00003ooooo`;o00003oooool2o`000003ooooool0
003o000000;o00001_ooool3o`000003ooooool0003o000000Sooooo0_l00005ooooo`Co00002_oo
ool2o`0000Cooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`0kooooo`;o00004Oooool2
o`0000Cooooo6_l00008ooooo`;o00001_ooool2o`000003ooooool0003o000000cooooo0_l0000R
ooooo`;o00000oooool2o`0000Wooooo0_l00005ooooo`;o00003oooool2o`0001?ooooo1?l0000:
ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0>oooool2o`0000oooooo0ol00003oooo
oaco000000?oooooo`000?l000001Oooool2o`0000Wooooo0_l00002ooooo`;o00001oooool2o`00
02?ooooo0_l0000>ooooo`;o00001Oooool2o`0000Gooooo0_l00004ooooo`;o00000_ooool2o`00
00?ooooo0_l00007ooooo`;o00001Oooool4o`0001;ooooo0_l00011ooooo`007?ooool00ol0003o
ooooooooo`19ooooo`;o000000Coooooo`000?l0003o00000ooooolKo`0000;ooooo0_l0000;oooo
o`;o00000_ooool2o`0000;ooooo0ol00007ooooo`?o00001?ooool2o`0002cooooo0_l0000;oooo
o`?o00001?ooool2o`0000?ooooo0ol000000ooooooo0000o`000007ooooo`;o00004_ooool2o`00
00Oooooo0_l00002ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0BOooool2o`0000;o
oooo0_l00003ooooo`Go000000?oooooo`000?l000004ol00005ooooo`;o00002?ooool3o`000003
ooooool0003o000000Co00000_ooool2o`0000Gooooo0_l00004ooooo`;o00003oooool2o`0000go
oooo0_l0000<ooooo`;o00000_ooool2o`0000Oooooo0_l00006ooooo`Oo00000oooool2o`0000Ko
oooo0_l0000Aooooo`;o00001Oooool2o`0000Cooooo0_l0000mooooo`007?ooool00ol0003ooooo
ooooo`1=ooooo`;o00001OoooolJo`0000Cooooo0_l00009ooooo`;o00000oooool2o`0000Cooooo
0_l00004ooooo`;o00002oooool2o`0000Wooooo0_l00004ooooo`;o00001oooool2o`0000cooooo
1_l0000?ooooo`Co00001_ooool2o`0000Kooooo0_l0000@ooooo`;o00001Oooool3o`0000Cooooo
0_l0000mooooo`007?ooool00ol0003oooooooooo`1EoooooaWo00002Oooool2o`0000Cooooo0_l0
0009ooooo`Go000000?oooooo`000?l000001_ooool3o`0000;ooooo0_l0000?ooooo`;o00001ooo
ool2o`0000Sooooo0_l00004ooooo`;o00004oooool5o`0001gooooo0_l00005ooooo`;o00001Ooo
ool2o`0003gooooo000Looooo`03o`000?oooooooooo03_ooooo0_l0000=ooooo`;o00002_oooolF
o`0000;ooooo0_l00007ooooo`;o00001?ooool2o`0000Oooooo0_l00002ooooo`?o000000?ooooo
o`000?l000000_l00004ooooo`Oo00002?ooool2o`0000Cooooo0_l00008ooooo`;o00002?ooool2
o`0000Gooooo0_l0000Cooooo`Co00003?ooool2o`0000oooooo0_l00002ooooo`;o00002?ooool2
o`0003gooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0kooooo`;o00003Oooool2o`0000?ooooo
0_l00002ooooo`;o000000?oooooo`000?l000005?l000001?oooooo0000o`000?l0000=ooooo`;o
00001oooool6o`0000?ooooo0ol00005ooooo`Co00002_ooool2o`0000Cooooo0ol0000Gooooo`?o
000000?oooooo`000?l000005oooool2o`0000Oooooo0_l0000Cooooo`;o00002?ooool2o`0003go
oooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B401_ooool00ol0003oooooooooo`0kooooo`;o00001_ooool2o`0000Gooooo0_l00003
ooooo`;o00000_ooool3o`000003ooooool0003o000001;o00000_ooool3o`0000Sooooo1?l00000
0ooooooo0000o`000009ooooo`;o00001_ooool2o`0000Gooooo1Ol0000?ooooo`?o00004_ooool2
o`0000?ooooo0_l00002ooooo`;o00002oooool4o`0000Sooooo0_l000000ooooooo0000o`00000>
ooooo`;o00002Oooool2o`0004Oooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo
00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo03_ooooo0_l00006
ooooo`Co00000oooool4o`000003ooooool0003o000000;ooooo0ol00002oooooaGo000000?ooooo
o`000?l000001oooool5o`0000[ooooo0_l00005ooooo`;o00000_ooool2o`0000Cooooo1Ol0000T
ooooo`;o00002?ooool2o`0000[ooooo1?l00003ooooo`;o00000oooool2o`000003ooooool0003o
000000;ooooo0ol00009ooooo`;o0000D_ooool00003ooooool0003ooooo00;ooooo00?o0000oooo
ooooool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol00012ooooo`;o000000?ooooo
o`000?l000001Oooool2o`000003ooooool0003o000000Sooooo0ol000000ooooooo0000o`000009
o`0000;ooooo1_l00007ooooo`;o00001Oooool2o`0000Gooooo0ol00004ooooo`?o00000_ooool3
o`0000;ooooo1_l0000Cooooo`;o00003oooool2o`0000Sooooo0_l00005ooooo`;o00001?ooool2
o`0000;ooooo1?l00002ooooo`;o000000?oooooo`000?l000000oooool3o`0000[ooooo0_l0000;
ooooo`;o00001_ooool2o`0003cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo04;ooooo0_l00004
ooooo`;o00003oooool2o`0000;ooooo3?l000000ooooooo0000o`000004o`0000;ooooo0_l0000:
ooooo`;o00001Oooool2o`0000Gooooo0ol00003ooooo`;o000000?oooooo`000?l000000_l00004
ooooo`;o00004?ooool2o`0000oooooo0_l0000?ooooo`?o00000oooool@o`000004ooooool0003o
0000o`0000Cooooo0_l00005ooooo`;o00000_ooool2o`0000Oooooo0_l00006ooooo`;o0000??oo
ool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08
ooooo`03o`000?oooooooooo04Sooooo0_l000001?oooooo0000o`000?l0000;ooooo`?o000000?o
ooooo`000?l000001ol000000ooooooo0000o`000005o`0000Cooooo0_l00002ooooo`;o00002_oo
ool2o`0000kooooo0_l000000ooooooo0000o`000006ooooo`;o00009_ooool2o`0000_ooooo0ol0
0004ooooo`;o00001?ooool8o`000004ooooool0003o0000o`0000Cooooo0_l00009ooooo`;o0000
0_ooool2o`0004Wooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nH
V9P02?ooool00ol0003oooooooooo`18ooooo`Ko00002oooool3o`000005ooooool0003o0000o`00
0?ooool00ol00002ooooo`Oo00001_ooool2o`000003ooooool0003o000000Sooooo1?l00002oooo
o`;o00003?ooool5o`0000;ooooo0_l0000Xooooo`;o00003?ooool2o`0000_ooooo1Ol0000Ioooo
o`;o00001oooool2o`00043ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<
odA4A?l0003o410@1_ooool00ol0003oooooooooo`12ooooo`;o00000_ooool5o`0001Kooooo1ol0
0002ooooo`?o00001_ooool5o`0000Sooooo1?l00002ooooo`;o00003?ooool5o`0000;ooooo0ol0
000@ooooo`;o00004oooool6o`0000oooooo0_l00004ooooo`Go00009?ooool2o`00043ooooo000L
ooooo`03o`000?oooooooooo04;ooooo1_l0000Fooooo`;o000000?oooooo`000?l000000ol00004
ooooo`?o00001Oooool4o`0000[ooooo0_l00002ooooo`;o00003_ooool5o`0000?ooooo0_l0000@
ooooo`;o00000oooool2o`0000?ooooo0_l00008ooooo`?o00000_ooool2o`0000Oooooo0_l00005
ooooo`?o00001?ooool4o`0000Gooooo0_l000000ooooooo0000o`00000Gooooo`;o0000A?ooool0
01cooooo00?o0000ooooooooool0>oooool2o`0000Oooooo0_l0000>ooooo`;o00002?ooool2o`00
00?ooooo0_l00006ooooo`;o00001Oooool2o`0000Cooooo0_l000000ooooooo0000o`000007oooo
o`;o00003_ooool5o`000003ooooool0003o000001Oooooo0_l00003ooooo`;o00002?ooool2o`00
00Oooooo0_l00003ooooo`;o00001Oooool2o`0000Gooooo1?l000000ooooooo0000o`000002oooo
o`;o000000Coooooo`000?l0003o00001Oooool2o`0000oooooo0_l00014ooooo`007?ooool00ol0
003oooooooooo`0kooooo`;o00005Oooool4o`0000gooooo0_l00006ooooo`;o00002Oooool7o`00
00;ooooo0_l0000<ooooo`Co00001?ooool4o`000003ooooool0003o000000gooooo0_l0000>oooo
o`;o00001Oooool2o`0000Wooooo0_l00002ooooo`Co00003Oooool2o`000003ooooool0003o0000
00?o00000oooool2o`0000Gooooo0_l0000>ooooo`;o0000AOooool001cooooo00?o0000oooooooo
ool0COooool2o`0000?ooooo0_l00002ooooo`;o00000oooool4o`0000;ooooo0_l00008ooooo`;o
000000?oooooo`000?l000001_ooool5o`0000;ooooo1?l0000<ooooo`Co00001Oooool3o`00013o
oooo0_l0000>ooooo`;o00000oooool4o`0000Oooooo0_l00004ooooo`Co00001Oooool2o`0000_o
oooo0ol00008ooooo`;o00004?ooool2o`0004Gooooo000Looooo`03o`000?oooooooooo03_ooooo
0_l0000@ooooo`;o00001oooool2o`0000?ooooo1?l00002ooooo`;o00002_ooool3o`0000Oooooo
1Ol000001?oooooo0000o`000?l0000?ooooo`;o000000?oooooo`000?l000000oooool2o`00013o
oooo0_l00002ooooo`;o00003oooool2o`0000Wooooo1?l00002ooooo`;o00000_ooool3o`0000;o
oooo0ol0000;ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o0000Eoooool001cooooo
00?o0000ooooooooool0>oooool2o`0000gooooo0_l0000?ooooo`;o00002Oooool2o`0000Gooooo
0_l00006ooooo`Oo00001_ooool2o`0000_ooooo0_l000000ooooooo0000o`000005ooooo`;o0000
1?ooool2o`0000cooooo0_l00005ooooo`;o00005?ooool5o`0000Cooooo0ol00003ooooo`;o0000
2oooool2o`000003ooooool0003o000000Co00004?ooool2o`0004Sooooo000Looooo`03o`000?oo
oooooooo04[ooooo0_l00002ooooo`?o00004?ooool2o`0000?ooooo0ol00003ooooo`;o00000ooo
ool2o`0000;ooooo1Ol00003ooooo`?o00000_ooool2o`0001Gooooo0_l00004ooooo`;o00002Ooo
ool2o`000003ooooool0003o000000Cooooo0ol00007ooooo`;o00002?ooool9o`000003ooooool0
003o000000;o00005Oooool5o`0000_ooooo0_l000000ooooooo0000o`000002o`0004Sooooo000L
ooooo`03o`000?oooooooooo04_ooooo0_l000001?oooooo0000o`000?l0000:ooooo`;o00001?oo
ool3o`0000?ooooo0_l00003ooooo`;o00000oooool2o`0000;ooooo1?l00004ooooo`?o00005_oo
ool2o`0000;ooooo0_l0000>ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Sooooo0_l0
0004ooooo`;o000000?oooooo`000?l000003Ol0000Dooooo`;o000000Coooooo`000?l0003o0000
0oooool3o`0000Gooooo1ol00018ooooo`007?ooool00ol0003oooooooooo`19ooooo`Go00003Ooo
ool2o`0000Cooooo1?l0000Gooooo`;o00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`00
000<ooooo`?o000000?oooooo`000?l000000_l0000Kooooo`;o00000_ooool2o`0000Cooooo0_l0
00000ooooooo0000o`00000=o`0000Sooooo0_l0000:ooooo`;o000000?oooooo`000?l000000_l0
0002ooooo`?o00001_ooool3o`0004_ooooo000Looooo`03o`000?oooooooooo04Gooooo0_l00002
ooooo`;o000000?oooooo`000?l000003_ooool4o`0000;ooooo0ol00009ooooo`Go00002Oooool2
o`0000;ooooo0ol00002ooooo`;o000000?oooooo`000?l000003Oooool2o`0000?ooooo0_l00007
ooooo`;o00004Oooool3o`0000_ooooo3ol00008ooooo`;o00003Oooool6o`0000Wooooo0_l0001<
ooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00001?ooool2o`0000oooooo1?l0000:oooo
o`?o000000?oooooo`000?l000000ol0000>ooooo`;o00008_ooool2o`00017ooooo0_l0000<oooo
oa3o00001oooool3o`0000gooooo1Ol0001Gooooo`007?ooool2o`0004cooooo1?l0000?ooooo`;o
00002_ooool3o`0000?ooooo0_l0000]ooooo`;o00009?oooolCo`0000Kooooo0_l0001Yooooo`00
7?ooool00ol0003oooooooooo`13ooooo`Ko00001?ooool2o`00027ooooo0_l0000]ooooo`;o0000
2_ooool2o`0000Cooooo1Ol00005ooooo`;o00002?oooolCo`0001gooooo0_l0001Booooo`007?oo
ool00ol0003oooooooooo`13ooooo`Ko00000oooool2o`00013ooooo0_l0000Gooooo`;o00003?oo
ool2o`0000oooooo0_l0000=ooooo`;o00001?ooool3o`0000?ooooo1Ol00005ooooo`;o00001ooo
ool9o`000003ooooool0003o000000Oo00007_ooool2o`0005;ooooo000Looooo`03o`000?oooooo
oooo04cooooo0_l00009ooooo`;o00001Oooool2o`0001Oooooo0_l0000<ooooo`;o00003oooool2
o`0000Gooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o
000000;ooooo1?l00008ooooo`;o00001_oooolDo`000005ooooool0003o0000o`000?ooool00_l0
0005ooooo`;o0000Hoooool001cooooo00?o0000ooooooooool0C?ooool2o`0000Wooooo0_l00006
ooooo`;o00008oooool2o`0000Sooooo0_l00003ooooo`?o00001?ooool2o`000003ooooool0003o
000000?ooooo0_l00005ooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`;o00001?oo
ool2o`0000Gooooo6Ol000000ooooooo0000o`000005ooooo`;o0000Hoooool001cooooo00?o0000
ooooooooool0C?ooool2o`00017ooooo0_l0000Sooooo`;o00002?ooool4o`000004ooooool0003o
0000o`0000Cooooo0_l0000=ooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`;o0000
00?oooooo`000?l000002?oooolHo`0000Cooooo0_l00003ooooo`;o00003oooool2o`0005;ooooo
000Looooo`03o`000?oooooooooo04cooooo0_l00002ooooo`;o00008oooool2o`0001Cooooo0_l0
00000ooooooo0000o`000002o`000004ooooool0003o0000o`0000;ooooo1Ol0000<ooooo`;o0000
3_ooool5o`0000;ooooo0_l000000ooooooo0000o`00000Fo`0000Cooooo0ol0000Cooooo`;o0000
D_ooool001cooooo00?o0000ooooooooool0D?ooool2o`0000?ooooo0_l0000Nooooo`;o00005?oo
ool5o`0000;ooooo2?l000000ooooooo0000o`00000:ooooo`;o00001Oooool2o`0000[ooooo1?l0
0002ooooo`;o00000_oooolFo`0000Kooooo0_l00004ooooo`;o00000oooool2o`000003ooooool0
003o000005Wooooo000Looooo`03o`000?oooooooooo05Gooooo0_l00006ooooo`;o0000;Oooool8
o`000003ooooool0003o000000Go00002oooool2o`0000Gooooo0_l0000CoooooaOo00001oooool2
o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000000oooool2o`0005Cooooo000Loooo
o`03o`000?oooooooooo04kooooo0_l0000=ooooo`;o00002?ooool3o`0001kooooo0ol000000ooo
oooo0000o`00000@o`0001Kooooo0_l00005ooooo`;o00001Oooool3o`000003ooooool0003o0000
00ko00002oooool2o`0000Oooooo0ol00006ooooo`;o0000E?ooool001cooooo00?o0000oooooooo
ool0C_ooool2o`000003ooooool0003o000000;ooooo0_l00006ooooo`;o00002?ooool3o`0001ko
oooo0ol000000ooooooo0000o`00000@o`0000Sooooo0_l0000<ooooo`;o00001Oooool4o`000003
ooooool0003o000000;o00000_oooolCo`0000Sooooo0_l00007ooooo`?o0000G?ooool001cooooo
00?o0000ooooooooool0C_ooool2o`000003ooooool0003o000000;ooooo0ol0000Dooooo`;o0000
6?oooolFo`0000[ooooo0_l00005ooooo`;o00003Oooool3o`000003ooooool0003o000000Ko0000
00?oooooo`000?l000003_l00008ooooo`;o00000oooool2o`0000?ooooo0_l0001Looooo`007?oo
ool00ol0003oooooooooo`1Eooooo`Oo00004?ooool2o`0001Kooooo6_l000000ooooooo0000o`00
0005ooooo`;o00001Oooool2o`0000gooooo1?l000000ooooooo0000o`000004o`0000;ooooo4?l0
0002ooooo`;o00001_ooool5o`0000?ooooo0_l0001Looooo`007?ooool00ol0003oooooooooo`1?
ooooo`Co00000_ooool2o`000003ooooool0003o000000?o00001Oooool2o`00023ooooo6_l00000
0ooooooo0000o`000005ooooo`;o00002_ooool2o`0000[ooooo0_l000000ooooooo0000o`000002
o`0000Cooooo3?l000000ooooooo0000o`000003ooooo`;o00001_ooool4o`0006;ooooo000Loooo
o`03o`000?oooooooooo04oooooo1Ol00007ooooo`;o00001Oooool4o`0001Sooooo0_l00009oooo
o`Co00000oooool6o`000003ooooool0003o000000Ko00001oooool2o`0000[ooooo0_l0000=oooo
o`[o000000?oooooo`000?l000001_l0000;ooooo`;o00000oooool2o`0000Oooooo0_l000000ooo
oooo0000o`00001Gooooo`007?ooool00ol0003oooooooooo`1Aooooo`?o00000oooool2o`0000Co
oooo0_l000000ooooooo0000o`000002ooooo`;o00006?ooool2o`0000Sooooo3Ol00002ooooo`So
00001oooool2o`0001Sooooo0_l00003ooooo`Go00000_ooool8o`0000_ooooo0_l00002ooooo`;o
00002?ooool2o`000003ooooool0003o000005Oooooo000Looooo`;o0000BOooool2o`0000Sooooo
0_l00003ooooo`;o000000?oooooo`000?l000001_l0000Looooo`;o00002?oooolDo`000004oooo
ool0003o0000o`0000?ooooo0_l000000ooooooo0000o`00000Hooooo`;o00001Oooool2o`0000?o
oooo0_l000001?oooooo0000o`000?l0000Aooooo`;o00001?ooool2o`0000Gooooo0_l0001Goooo
o`007?ooool00ol0003oooooooooo`18ooooo`?o00001oooool2o`0000;ooooo1ol000000ooooooo
0000o`00000Nooooo`;o00000oooool2o`000003ooooool0003o000001So00000oooool2o`000003
ooooool0003o000000Oooooo0_l0000@ooooo`;o00001?ooool2o`0000Cooooo0_l00002ooooo`?o
00003_ooool2o`0000Cooooo0ol00002ooooo`;o0000F_ooool001cooooo00?o0000ooooooooool0
BOooool2o`0000_ooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000001kooooo
0_l00003oooooaGo000000?oooooo`000?l000001?l0000@ooooo`;o00004?ooool2o`0000;ooooo
1?l00004ooooo`;o00000_ooool3o`0000Kooooo0_l00004ooooo`Co00001?ooool7o`0005[ooooo
000Looooo`03o`000?oooooooooo04oooooo0_l00008ooooo`;o00000oooool2o`000003ooooool0
003o0000027ooooo6ol0000;ooooo`;o00006Oooool3o`0000;ooooo0_l000000ooooooo0000o`00
000;ooooo`Co00000_ooool2o`0000Sooooo0ol0001Looooo`007?ooool00ol0003oooooooooo`1?
ooooo`;o00001Oooool2o`000003ooooool0003o000000Cooooo1?l0000Qoooooaco000000Cooooo
o`000?l0003o00001_ooool4o`0001Oooooo0ol000000ooooooo0000o`000004o`0000gooooo1_l0
001Wooooo`007?ooool00ol0003oooooooooo`1Fooooo`?o00001_ooool2o`0002?ooooo7?l00000
1?oooooo0000o`000?l00002ooooo`;o00001?ooool2o`0001_ooooo0_l000000ooooooo0000o`00
0002o`0000;ooooo0ol00009ooooo`;o0000JOooool001cooooo00?o0000ooooooooool0Boooool2
o`0000Sooooo1?l0000]oooooago00000oooool2o`0002Cooooo1?l00002ooooo`?o00000_ooool2
o`00073ooooo000Looooo`03o`000?oooooooooo04Oooooo0_l00002ooooo`;o00002?ooool3o`00
02kooooo6?l00002ooooo`?o00004?ooool2o`0001[ooooo0ol00005ooooo`;o00001_ooool2o`00
06Sooooo000Looooo`03o`000?oooooooooo04Oooooo0_l0000<ooooo`?o00009_ooool2o`000003
ooooool0003o000000;o000000?oooooo`000?l000006ol0000?ooooo`?o00006_ooool3o`0000go
oooo0_l0001Xooooo`007?ooool00ol0003oooooooooo`17ooooo`;o00007Oooool2o`0001Kooooo
0_l000000ooooooo0000o`000002o`000003ooooool0003o000001_o00003oooool2o`0001cooooo
0_l0001gooooo`007?ooool00ol0003oooooooooo`1Vooooo`;o00005_oooolUo`0002gooooo0_l0
001gooooo`007?ooool00ol0003oooooooooo`20ooooo`Oo000000?oooooo`000?l000005Ol0000;
ooooo`;o0000WOooool001cooooo00?o0000ooooooooool0FOooool2o`0002gooooo1_l000000ooo
oooo0000o`00000>o`000003ooooool0003o000000Sooooo0_l0002Mooooo`007?ooool00ol0003o
ooooooooo`1:ooooo`;o00002_ooool2o`000003ooooool0003o000002Kooooo0_l00002oooooaSo
00000_ooool3o`0001;ooooo0_l0002Cooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o0000
2_ooool2o`0002Wooooo0_l00002oooooaGo000000?oooooo`000?l000000_ooool2o`0001?ooooo
0_l0002Cooooo`007?ooool00ol0003oooooooooo`25ooooo`;o00000_oooolCo`000:gooooo000L
ooooo`;o0000R_oooolCo`0000;ooooo0_l0000@ooooo`;o00000oooool3o`00097ooooo000Loooo
o`03o`000?oooooooooo08Cooooo0_l00004ooooo`oo00001?ooool3o`00013ooooo0_l00003oooo
o`?o00000_ooool2o`0008gooooo000Looooo`03o`000?oooooooooo05[ooooo0ol0000Vooooo`Co
00000oooool2o`000003ooooool0003o000000So00001_ooool2o`0001_ooooo0_l0002=ooooo`00
7?ooool00ol0003oooooooooo`1Jooooo`Go00009?ooool4o`0000Kooooo0ol00002ooooo`;o0000
00?oooooo`000?l000000_ooool2o`0000;ooooo0_l0001Jooooo`;o0000C_ooool001cooooo00?o
0000ooooooooool0GOooool2o`0002cooooo2Ol00005ooooo`;o00000_ooool2o`0005[ooooo0_l0
001>ooooo`007?ooool00ol0003oooooooooo`2;ooooo`Oo00000_ooool4o`000;7ooooo000Loooo
o`03o`000?oooooooooo06Kooooo0_l0000Zooooo`Ko00004oooool2o`0000Wooooo0_l0000noooo
o`;o0000DOooool001cooooo00?o0000ooooooooool0I_ooool2o`0000Gooooo0_l0000Dooooo`;o
00003Oooool2o`0000Sooooo0_l0000=ooooo`;o00002Oooool2o`000003ooooool0003o000000Co
oooo0_l0000eooooo`;o0000DOooool001cooooo00?o0000ooooooooool0KOooool2o`0001Cooooo
0_l00006ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l00003ooooo`;o0000
6oooool2o`0000Cooooo0_l00028ooooo`007?ooool00ol0003oooooooooo`2:ooooo`?o000000?o
ooooo`000?l000001oooool2o`0000[ooooo0_l0002Tooooo`007?ooool00ol0003oooooooooo`2:
ooooo`;o00002?ooool3o`0000_ooooo1Ol0000Jooooo`;o0000Q_ooool001cooooo00?o0000oooo
ooooool0I?ooool2o`0002kooooo0ol000000ooooooo0000o`000003o`0000Gooooo1Ol00002oooo
o`;o00005_ooool2o`0008Kooooo000Looooo`03o`000?oooooooooo06Cooooo0_l000000ooooooo
0000o`00000_ooooo`Go00001?ooool5o`0000?ooooo0_l0002Nooooo`007?ooool00ol0003ooooo
ooooo`1Wooooo`;o0000<oooool2o`0000?ooooo0ol00003ooooo`;o0000X?ooool00006ooooooo^
k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006oooo
o`03o`000?oooooooooo09cooooo0_l00009ooooo`;o0000X?ooool00006oooooomgMgOoV9RHoooo
oonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oo
oooooooo06?ooooo0ol00002ooooo`;o0000:Oooool2o`0000Wooooo0_l0002Yooooo`0000?ooooo
oa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`1Sooooo`?o00000_ooool2o`0002Sooooo0ol00005ooooo`;o00000_oo
ool2o`000:Wooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8b
oiRHV?ooooooV9RHoc8b<P06ooooo`?o0000T_ooool2o`000003ooooool0003o000000?ooooo0_l0
001?ooooo`;o0000G?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0LOooool2o`0002;ooooo0_l0
001Dooooo`;o0000G?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool0
1Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0Koooool4o`0002Cooooo0_l0
00000ooooooo0000o`000004ooooo`;o0000Yoooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0Goooool2o`0000Oo
oooo0_l00005ooooo`?o00009Oooool5o`0000Cooooo0_l0002Wooooo`0000Koooooonk^k_lb<S;o
0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`1O
ooooo`;o00001oooool2o`0000Wooooo0_l000000ooooooo0000o`00000Gooooo`;o00002?ooool2
o`0000Sooooo0_l0002Tooooo`007?ooool00ol0003oooooooooo`1cooooo`;o000000?oooooo`00
0?l000005oooool2o`0001;ooooo0_l0002Tooooo`007?ooool00ol0003oooooooooo`1Rooooo`;o
0000;oooool2o`0000kooooo0_l0000Xooooo`;o0000N_ooool001cooooo00?o0000ooooooooool0
H_ooool2o`0001Sooooo0_l0000Eooooo`;o0000=oooool3o`0007[ooooo000Looooo`03o`000?oo
oooooooo07cooooo0_l0001;ooooo`;o000000?oooooo`000?l000005Oooool2o`0006Cooooo000L
ooooo`03o`000?oooooooooo0<Sooooo0ol0000Hooooo`;o0000I?ooool001cooooo00?o0000oooo
ooooool0UOooool2o`00037ooooo0_l0001oooooo`007?ooool00ol0003oooooooooo`1Xooooo`;o
0000:oooool2o`000003ooooool0003o000000Kooooo0_l0002Wooooo`007?ooool00ol0003ooooo
ooooo`1Xooooo`;o00005oooool2o`0001Gooooo0_l00006ooooo`;o0000Yoooool001cooooo00?o
0000ooooooooool0Moooool2o`0000Sooooo0_l00004ooooo`;o00002Oooool2o`0000[ooooo0_l0
000Oooooo`?o0000Qoooool001cooooo00?o0000ooooooooool0Moooool2o`0000kooooo0_l00009
ooooo`;o000000?oooooo`000?l000001oooool2o`0000Oooooo0_l0000?ooooo`;o00001Oooool3
o`0008Oooooo000Looooo`03o`000?oooooooooo08Wooooo0_l00006ooooo`;o00000_ooool2o`00
013ooooo0_l00009ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Qooooo`;o0000K?ooool0
01cooooo0_l00025ooooo`;o00000oooool2o`0000Kooooo0_l0000Oooooo`;o000000?oooooo`00
0?l000009?ooool2o`0006cooooo000Looooo`03o`000?oooooooooo07kooooo0_l00004ooooo`Co
0000`Oooool001cooooo00?o0000ooooooooool0O_ooool2o`000003ooooool0003o000000?ooooo
1?l00007ooooo`;o0000@oooool2o`00077ooooo000Looooo`03o`000?oooooooooo087ooooo0_l0
0005ooooo`;o00001oooool2o`0004?ooooo0_l0001aooooo`007?ooool00ol0003oooooooooo`25
ooooo`;o00001?ooool2o`0004Cooooo0_l0001fooooo`007?ooool00ol0003oooooooooo`25oooo
o`;o00001?ooool2o`0004Cooooo0_l0001fooooo`007?ooool00ol0003oooooooooo`2=ooooo`;o
0000^_ooool001cooooo00?o0000ooooooooool0SOooool2o`000003ooooool0003o00000;Oooooo
000Looooo`03o`000?oooooooooo07[ooooo0_l0000Dooooo`;o0000>?ooool2o`0007gooooo000L
ooooo`03o`000?oooooooooo07[ooooo0_l0000Fooooo`;o0000=_ooool2o`0007gooooo000Loooo
o`03o`000?oooooooooo09;ooooo0_l0000_ooooo`;o0000Q?ooool001cooooo00?o0000oooooooo
ool0`Oooool4o`0008Cooooo000Looooo`03o`000?oooooooooo09[ooooo0_l0000Uooooo`;o0000
Q_ooool001cooooo00?o0000ooooooooool0U?ooool2o`0000Cooooo0_l0000Oooooo`;o0000S?oo
ool001cooooo00?o0000ooooooooool0U?ooool2o`0002Gooooo0_l0002<ooooo`007?ooool00ol0
003oooooooooo`2Dooooo`;o0000/oooool001cooooo0_l0002Looooo`;o00005_ooool3o`0009?o
oooo000Looooo`03o`000?oooooooooo09_ooooo0_l0000Fooooo`?o0000Toooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Wooooo`Co0000W_ooool0
01cooooo00?o0000ooooooooool0Yoooool4o`0009kooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`004_ooool4o`000003
oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Ooo
ool3o`000?ooooooB_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0
003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo
00?o0000ooooooooool0oooooomBooooo`004_ooool00omEEEGoIVIVo`00003ooooooeCooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo002Uooooo`04oa0@4?l0003o0000ooooo`;o
000000?o410@ooooooooool05oooool2o`000003oa0@4?oooooooooo00;ooooo00GoA4A4o`000?l0
003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0T?ooool00:Kooooo00Go0000oooo
ooooooooooooo`000009ooooo`Ko00003?ooool00ol0003oooooooooo`06ooooo`09ogMgMolb<S;o
oooooooooomgMgOoV9RHoooooonHV9SoMgMg093ooooo002Vooooo`05o`000?ooooooooooooooool0
00006?ooool5o`0000Sooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`2>oooo
o`00Y_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l00009ooooo`04odA4A?oMgMgooooo
o`0000Sooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo08kooooo002V
ooooo`05o`000?n7QhOoooooojVYZOl000006?ooool01?oMgMgoEEEEooooool00005ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo0000093ooooo002Uooooo`03
oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool05oooool00omgMgOoc<c<o`000005ooooo`03
o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@402@ooooo`00a?ooool00oo^k^ko
A4A4o`000005ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`2@oooo
o`00aOooool00omgMgOo0000ooooo`04ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
093ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(456) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.45375 .3042 Mdot
.44058 .32008 Mdot
.4464 .73881 Mdot
.5964 .42787 Mdot
.59201 .6679 Mdot
.42459 .69442 Mdot
.29928 .5656 Mdot
.3088 .56675 Mdot
.43532 .68512 Mdot
.52298 .27311 Mdot
.29261 .53283 Mdot
.67096 .41272 Mdot
.2981 .54944 Mdot
.62218 .45456 Mdot
.45217 .4288 Mdot
.56022 .47574 Mdot
.42034 .35434 Mdot
.64562 .67014 Mdot
.55465 .4525 Mdot
.46283 .7151 Mdot
.76198 .44934 Mdot
.62519 .46619 Mdot
.46693 .36454 Mdot
.62431 .45774 Mdot
.64807 .43296 Mdot
.44003 .33639 Mdot
.45851 .30587 Mdot
.6537 .44712 Mdot
.67644 .45738 Mdot
.29995 .53495 Mdot
.49551 .71415 Mdot
.69241 .23509 Mdot
.59646 .48867 Mdot
.65853 .27205 Mdot
.30416 .57084 Mdot
.35643 .54785 Mdot
.45101 .72039 Mdot
.2676 .53874 Mdot
.30775 .57238 Mdot
.2976 .57646 Mdot
.28107 .56454 Mdot
.44043 .34434 Mdot
.29163 .58142 Mdot
.32069 .74903 Mdot
.62069 .4382 Mdot
.44115 .41086 Mdot
.24878 .69372 Mdot
.66433 .45446 Mdot
.42154 .33582 Mdot
.46763 .71189 Mdot
.7194 .66974 Mdot
.2928 .51619 Mdot
.38968 .44775 Mdot
.57067 .89717 Mdot
.29019 .54223 Mdot
.61587 .41252 Mdot
.44222 .67595 Mdot
.5984 .45952 Mdot
.58596 .42898 Mdot
.62958 .24027 Mdot
.61629 .47879 Mdot
.61154 .69305 Mdot
.4603 .38484 Mdot
.40682 .67609 Mdot
.42883 .68442 Mdot
.26921 .53689 Mdot
.4774 .36969 Mdot
.30862 .54909 Mdot
.6707 .47599 Mdot
.45931 .72996 Mdot
.67455 .45589 Mdot
.29958 .53231 Mdot
.48177 .34313 Mdot
.62402 .43746 Mdot
.33281 .4401 Mdot
.22096 .56394 Mdot
.41107 .75624 Mdot
.73637 .33685 Mdot
.7356 .70813 Mdot
.50317 .6514 Mdot
.63565 .45303 Mdot
.57604 .85166 Mdot
.46392 .49401 Mdot
.44465 .3141 Mdot
.46669 .28456 Mdot
.35078 .28206 Mdot
.66034 .45544 Mdot
.45595 .61224 Mdot
.56604 .44046 Mdot
.58675 .60998 Mdot
.44813 .6868 Mdot
.45739 .31856 Mdot
.62706 .44157 Mdot
.62362 .49759 Mdot
.44924 .24129 Mdot
.6618 .42076 Mdot
.60515 .4263 Mdot
.43857 .27068 Mdot
.28724 .53041 Mdot
.65644 .53063 Mdot
.67442 .70999 Mdot
.37542 .47826 Mdot
.63335 .41561 Mdot
.4411 .71462 Mdot
.45062 .38755 Mdot
.61266 .42389 Mdot
.31089 .55858 Mdot
.63363 .45856 Mdot
.32674 .56611 Mdot
.43875 .36843 Mdot
.60364 .49 Mdot
.63905 .68075 Mdot
.63724 .55402 Mdot
.45535 .36303 Mdot
.67273 .34769 Mdot
.62475 .47772 Mdot
.60278 .47288 Mdot
.43554 .32157 Mdot
.45012 .73157 Mdot
.37185 .69182 Mdot
.47548 .35883 Mdot
.29978 .57702 Mdot
.41777 .34176 Mdot
.60157 .39722 Mdot
.45442 .7256 Mdot
.37615 .46587 Mdot
.3719 .47449 Mdot
.6601 .60656 Mdot
.63326 .44378 Mdot
.61184 .55561 Mdot
.43427 .70787 Mdot
.43398 .33769 Mdot
.30392 .54242 Mdot
.60434 .4088 Mdot
.45495 .35523 Mdot
.31854 .56096 Mdot
.59576 .67629 Mdot
.61846 .6452 Mdot
.43109 .34939 Mdot
.57657 .36746 Mdot
.33802 .53478 Mdot
.28773 .57561 Mdot
.71725 .66753 Mdot
.44196 .314 Mdot
.62758 .68605 Mdot
.32297 .54621 Mdot
.76016 .54706 Mdot
.57578 .44011 Mdot
.68646 .64332 Mdot
.49765 .84989 Mdot
.7189 .66992 Mdot
.68759 .25163 Mdot
.63673 .68269 Mdot
.32179 .55743 Mdot
.67185 .45085 Mdot
.45609 .34242 Mdot
.44883 .35204 Mdot
.63574 .49539 Mdot
.63274 .43257 Mdot
.61227 .44108 Mdot
.5829 .42688 Mdot
.28003 .61252 Mdot
.6308 .44655 Mdot
.2096 .43278 Mdot
.46094 .35049 Mdot
.63382 .42597 Mdot
.43184 .7283 Mdot
.65874 .52285 Mdot
.27151 .55744 Mdot
.58752 .4292 Mdot
.63907 .43365 Mdot
.63349 .40367 Mdot
.30796 .57721 Mdot
.30841 .43964 Mdot
.78005 .66678 Mdot
.34326 .57721 Mdot
.23338 .52958 Mdot
.42225 .70728 Mdot
.63106 .48625 Mdot
.62276 .6694 Mdot
.65732 .52769 Mdot
.58157 .44838 Mdot
.72237 .6746 Mdot
.64504 .44876 Mdot
.71444 .28731 Mdot
.68649 .42069 Mdot
.34469 .29279 Mdot
.22756 .383 Mdot
.57935 .44521 Mdot
.55672 .3054 Mdot
.67213 .63214 Mdot
.44473 .78351 Mdot
.30068 .53819 Mdot
.41879 .72839 Mdot
.44257 .73602 Mdot
.26617 .53665 Mdot
.70417 .40441 Mdot
.53941 .2768 Mdot
.6744 .43438 Mdot
.37657 .47146 Mdot
.49966 .33867 Mdot
.63393 .68888 Mdot
.42881 .34637 Mdot
.6138 .83479 Mdot
.51735 .64101 Mdot
.46431 .62123 Mdot
.64129 .65309 Mdot
.4668 .68966 Mdot
.38654 .45843 Mdot
.62712 .67874 Mdot
.59616 .43857 Mdot
.43092 .36027 Mdot
.68407 .64661 Mdot
.63426 .52334 Mdot
.28155 .23194 Mdot
.46814 .31659 Mdot
.59795 .5702 Mdot
.29397 .54261 Mdot
.39853 .70017 Mdot
.66008 .45479 Mdot
.60716 .45702 Mdot
.48276 .37167 Mdot
.67012 .46118 Mdot
.46759 .59476 Mdot
.6406 .43736 Mdot
.4108 .67394 Mdot
.56526 .67766 Mdot
.29862 .58962 Mdot
.65046 .66352 Mdot
.48129 .35074 Mdot
.20861 .55411 Mdot
.43968 .72108 Mdot
.71509 .4842 Mdot
.31186 .53966 Mdot
.5987 .67167 Mdot
.45 .7127 Mdot
.64201 .68724 Mdot
.59273 .47816 Mdot
.45527 .71288 Mdot
.61882 .69764 Mdot
.43781 .55422 Mdot
.60776 .4235 Mdot
.69349 .59416 Mdot
.31446 .52204 Mdot
.43854 .30948 Mdot
.59005 .46557 Mdot
.39998 .44736 Mdot
.60113 .40318 Mdot
.53776 .53218 Mdot
.4012 .45218 Mdot
.39362 .48028 Mdot
.47964 .61731 Mdot
.59836 .69901 Mdot
.34043 .46854 Mdot
.44154 .58348 Mdot
.42086 .3553 Mdot
.59673 .4798 Mdot
.37567 .37386 Mdot
.31835 .52367 Mdot
.59464 .44354 Mdot
.35057 .33424 Mdot
.32312 .54737 Mdot
.59749 .46385 Mdot
.28109 .56265 Mdot
.45365 .3501 Mdot
.45176 .52557 Mdot
.42032 .3197 Mdot
.59301 .43302 Mdot
.27812 .55039 Mdot
.42364 .7314 Mdot
.44073 .33682 Mdot
.63205 .46325 Mdot
.64262 .4625 Mdot
.37961 .47265 Mdot
.62352 .43155 Mdot
.37002 .28829 Mdot
.66298 .45224 Mdot
.4688 .71646 Mdot
.6729 .43592 Mdot
.6883 .69716 Mdot
.6608 .66151 Mdot
.45911 .37541 Mdot
.40203 .45425 Mdot
.45264 .68795 Mdot
.44554 .53377 Mdot
.67031 .58392 Mdot
.63093 .452 Mdot
.39596 .46731 Mdot
.58663 .56908 Mdot
.27126 .55424 Mdot
.62348 .50869 Mdot
.40751 .62557 Mdot
.44992 .69218 Mdot
.37921 .46586 Mdot
.60937 .51648 Mdot
.46999 .30771 Mdot
.6355 .41378 Mdot
.44925 .71993 Mdot
.43422 .30853 Mdot
.64967 .41136 Mdot
.22434 .63206 Mdot
.39977 .44668 Mdot
.27792 .5391 Mdot
.41692 .26982 Mdot
.63611 .49058 Mdot
.43422 .73793 Mdot
.44869 .35621 Mdot
.2851 .55197 Mdot
.46253 .36381 Mdot
.68327 .65433 Mdot
.54215 .52586 Mdot
.36156 .58782 Mdot
.64236 .70534 Mdot
.82036 .38049 Mdot
.35508 .54508 Mdot
.66289 .52892 Mdot
.47012 .7383 Mdot
.30943 .26353 Mdot
.44701 .71138 Mdot
.55151 .37471 Mdot
.44592 .68099 Mdot
.65465 .42343 Mdot
.42551 .69082 Mdot
.39323 .22911 Mdot
.65115 .45471 Mdot
.41749 .68668 Mdot
.34573 .61737 Mdot
.64916 .45732 Mdot
.45809 .35649 Mdot
.56017 .16815 Mdot
.71456 .35285 Mdot
.71552 .37689 Mdot
.43362 .67278 Mdot
.58167 .36094 Mdot
.65554 .45079 Mdot
.55443 .44565 Mdot
.45254 .33816 Mdot
.63763 .40114 Mdot
.61322 .71086 Mdot
.63857 .69732 Mdot
.74364 .60643 Mdot
.76911 .38081 Mdot
.70339 .39365 Mdot
.44438 .34325 Mdot
.72639 .72317 Mdot
.33312 .43441 Mdot
.39843 .44629 Mdot
.31299 .56516 Mdot
.30867 .45349 Mdot
.57938 .4958 Mdot
.50744 .31025 Mdot
.46521 .58415 Mdot
.46259 .31949 Mdot
.39367 .56711 Mdot
.28768 .55787 Mdot
.71503 .36912 Mdot
.53536 .25403 Mdot
.61012 .43956 Mdot
.29045 .52098 Mdot
.65665 .39971 Mdot
.45145 .59913 Mdot
.67925 .60937 Mdot
.28404 .6859 Mdot
.59714 .4322 Mdot
.34915 .45154 Mdot
.58308 .45162 Mdot
.66754 .61317 Mdot
.59199 .44248 Mdot
.46508 .35936 Mdot
.5605 .42325 Mdot
.43625 .57732 Mdot
.8118 .46136 Mdot
.51451 .62993 Mdot
.62023 .70334 Mdot
.61927 .45546 Mdot
.60439 .44534 Mdot
.61107 .69538 Mdot
.46148 .32143 Mdot
.59811 .47891 Mdot
.23008 .68165 Mdot
.6321 .4468 Mdot
.28412 .51773 Mdot
.50554 .55012 Mdot
.75018 .31064 Mdot
.65262 .47491 Mdot
.4745 .31245 Mdot
.28049 .56714 Mdot
.31842 .54085 Mdot
.61467 .37307 Mdot
.30975 .51952 Mdot
.67217 .45442 Mdot
.50458 .54905 Mdot
.45684 .37038 Mdot
.69288 .43571 Mdot
.46712 .32621 Mdot
.71333 .73312 Mdot
.32477 .54501 Mdot
.40015 .46578 Mdot
.68612 .36406 Mdot
.30066 .56128 Mdot
.58148 .6314 Mdot
.56077 .42373 Mdot
.64146 .51639 Mdot
.40918 .28111 Mdot
.42246 .73329 Mdot
.39784 .45955 Mdot
.28784 .54418 Mdot
.62741 .44437 Mdot
.62519 .4181 Mdot
.29853 .51746 Mdot
.57651 .20649 Mdot
.49392 .71923 Mdot
.5915 .43293 Mdot
.47054 .35199 Mdot
.43551 .33987 Mdot
.58054 .42341 Mdot
.58592 .45954 Mdot
.41313 .70298 Mdot
.39695 .46638 Mdot
.40119 .45815 Mdot
.3727 .48037 Mdot
.41004 .68033 Mdot
.82104 .39957 Mdot
.28725 .57552 Mdot
.70926 .25488 Mdot
.33499 .38518 Mdot
.58092 .38271 Mdot
.44165 .73176 Mdot
.60966 .46676 Mdot
.64835 .42213 Mdot
.2795 .54611 Mdot
.80676 .4279 Mdot
.56244 .42736 Mdot
.45049 .30632 Mdot
.28949 .51781 Mdot
.65959 .40567 Mdot
.3323 .51322 Mdot
.62448 .66004 Mdot
.70164 .37952 Mdot
.30682 .51767 Mdot
.44856 .3693 Mdot
.30597 .51743 Mdot
.60659 .44347 Mdot
.61237 .51821 Mdot
.46362 .31925 Mdot
.6128 .65091 Mdot
.62291 .49451 Mdot
.59495 .4622 Mdot
.44026 .80618 Mdot
.33544 .44101 Mdot
.64495 .64247 Mdot
.6631 .4394 Mdot
.65688 .51449 Mdot
.6239 .65017 Mdot
.61843 .49013 Mdot
.6716 .4365 Mdot
.62431 .55903 Mdot
.32629 .56925 Mdot
.59393 .69949 Mdot
.80793 .46045 Mdot
.46576 .31395 Mdot
.3659 .30355 Mdot
.37411 .47431 Mdot
.26023 .55636 Mdot
.44873 .51537 Mdot
.38797 .46236 Mdot
.33539 .36186 Mdot
.18941 .53573 Mdot
.39606 .46218 Mdot
.40064 .68491 Mdot
.5283 .3346 Mdot
.67619 .44603 Mdot
.58519 .44126 Mdot
.59984 .69977 Mdot
.43057 .32155 Mdot
.21628 .4238 Mdot
.30144 .59168 Mdot
.62294 .47217 Mdot
.45297 .30048 Mdot
.34717 .2861 Mdot
.38166 .46492 Mdot
.62739 .66814 Mdot
.60176 .65762 Mdot
.58667 .45814 Mdot
.63596 .58748 Mdot
.44172 .34169 Mdot
.63195 .46324 Mdot
.60868 .48033 Mdot
.45784 .68736 Mdot
.42878 .35717 Mdot
.43103 .72611 Mdot
.40684 .46049 Mdot
.28814 .26366 Mdot
.36467 .80708 Mdot
.31757 .52561 Mdot
.4083 .50808 Mdot
.288 .58546 Mdot
.25101 .65647 Mdot
.39797 .46513 Mdot
.62915 .46482 Mdot
.47654 .36246 Mdot
.63361 .46049 Mdot
.63031 .44462 Mdot
.60899 .43311 Mdot
.70395 .39384 Mdot
.71469 .72271 Mdot
.60729 .67169 Mdot
.65719 .48278 Mdot
.42641 .67162 Mdot
.34752 .3071 Mdot
.42592 .21751 Mdot
.61264 .45363 Mdot
.60177 .47174 Mdot
.4827 .3643 Mdot
.58451 .47069 Mdot
.30835 .56412 Mdot
.4547 .31165 Mdot
.62395 .41556 Mdot
.67504 .71455 Mdot
.59793 .47746 Mdot
.39754 .52151 Mdot
.31853 .51907 Mdot
.56781 .50626 Mdot
.65307 .50546 Mdot
.39897 .46456 Mdot
.39698 .45954 Mdot
.4095 .44847 Mdot
.28012 .52342 Mdot
.4571 .68791 Mdot
.39076 .69443 Mdot
.64837 .50412 Mdot
.66871 .45165 Mdot
.62337 .51909 Mdot
.4725 .69139 Mdot
.43069 .59144 Mdot
.5052 .39484 Mdot
.67238 .40663 Mdot
.40939 .6864 Mdot
.43129 .2698 Mdot
.75731 .39433 Mdot
.44851 .3096 Mdot
.47104 .73477 Mdot
.31529 .55008 Mdot
.63831 .68864 Mdot
.73136 .63974 Mdot
.4726 .35939 Mdot
.48555 .34446 Mdot
.41761 .70138 Mdot
.49663 .52122 Mdot
.63807 .87552 Mdot
.43987 .70866 Mdot
.4648 .61576 Mdot
.44927 .33911 Mdot
.57825 .46838 Mdot
.5741 .56502 Mdot
.49437 .50512 Mdot
.4221 .68235 Mdot
.642 .46208 Mdot
.54864 .66451 Mdot
.41314 .70216 Mdot
.60223 .50257 Mdot
.43163 .67248 Mdot
.28267 .53009 Mdot
.43321 .71238 Mdot
.42948 .29801 Mdot
.63707 .44906 Mdot
.58939 .89282 Mdot
.45859 .48904 Mdot
.63432 .47076 Mdot
.30282 .51602 Mdot
.30766 .62627 Mdot
.60244 .43965 Mdot
.62058 .70821 Mdot
.42079 .67182 Mdot
.26684 .67582 Mdot
.65939 .42343 Mdot
.42107 .69104 Mdot
.43181 .29209 Mdot
.47916 .70988 Mdot
.67178 .70674 Mdot
.39965 .45846 Mdot
.45638 .34862 Mdot
.36037 .4678 Mdot
.28819 .57321 Mdot
.57452 .42077 Mdot
.61455 .48303 Mdot
.46551 .3489 Mdot
.43941 .54088 Mdot
.64724 .37846 Mdot
.63463 .45204 Mdot
.41807 .71433 Mdot
.45651 .67361 Mdot
.45616 .42496 Mdot
.44271 .72095 Mdot
.65862 .51335 Mdot
.46451 .35378 Mdot
.62678 .41319 Mdot
.44752 .35917 Mdot
.59961 .48249 Mdot
.26082 .50976 Mdot
.44225 .31116 Mdot
.70077 .51255 Mdot
.63645 .4454 Mdot
.38977 .31068 Mdot
.63913 .48939 Mdot
.60063 .4301 Mdot
.44656 .66736 Mdot
.61175 .68073 Mdot
.61057 .5018 Mdot
.22111 .57102 Mdot
.62592 .65411 Mdot
.62944 .21622 Mdot
.45403 .72566 Mdot
.59772 .66621 Mdot
.73467 .5943 Mdot
.40163 .45406 Mdot
.60535 .68788 Mdot
.40432 .47855 Mdot
.31009 .52231 Mdot
.41143 .32851 Mdot
.64716 .45605 Mdot
.31233 .25031 Mdot
.49689 .70807 Mdot
.38341 .4739 Mdot
.59534 .47006 Mdot
.60557 .46298 Mdot
.45636 .30248 Mdot
.60252 .83995 Mdot
.4213 .66327 Mdot
.60235 .42413 Mdot
.47896 .3527 Mdot
.54551 .85441 Mdot
.41656 .68626 Mdot
.6072 .66849 Mdot
.32857 .55011 Mdot
.49749 .36004 Mdot
.40201 .46336 Mdot
.32437 .54842 Mdot
.42157 .75957 Mdot
.72447 .67732 Mdot
.64878 .4169 Mdot
.43682 .73063 Mdot
.71936 .6708 Mdot
.69282 .43012 Mdot
.2648 .54976 Mdot
.28728 .49377 Mdot
.45431 .31795 Mdot
.29678 .51732 Mdot
.60598 .70463 Mdot
.42585 .35971 Mdot
.46531 .32336 Mdot
.31331 .56132 Mdot
.23372 .35432 Mdot
.58168 .56622 Mdot
.27698 .51674 Mdot
.53655 .53578 Mdot
.71798 .67134 Mdot
.39282 .47492 Mdot
.6293 .66976 Mdot
.66332 .74799 Mdot
.43987 .34195 Mdot
.30874 .45167 Mdot
.72056 .67044 Mdot
.60497 .42619 Mdot
.62124 .69859 Mdot
.35496 .30864 Mdot
.26667 .57867 Mdot
.32016 .55769 Mdot
.37722 .72297 Mdot
.62972 .69855 Mdot
.58219 .46143 Mdot
.76893 .33001 Mdot
.65023 .46944 Mdot
.32381 .53983 Mdot
.46639 .58887 Mdot
.43205 .3597 Mdot
.27293 .56199 Mdot
.46796 .59593 Mdot
.65418 .42558 Mdot
.63028 .47905 Mdot
.57764 .7132 Mdot
.42187 .3481 Mdot
.40211 .4687 Mdot
.63837 .46017 Mdot
.59642 .45907 Mdot
.57684 .42098 Mdot
.78338 .44206 Mdot
.68191 .53764 Mdot
.61041 .4189 Mdot
.40079 .71576 Mdot
.64472 .52772 Mdot
.58331 .42823 Mdot
.46555 .30368 Mdot
.68621 .72014 Mdot
.40716 .46102 Mdot
.58599 .4427 Mdot
.59095 .4338 Mdot
.30522 .57324 Mdot
.58308 .56731 Mdot
.49139 .50048 Mdot
.46955 .69983 Mdot
.38146 .72554 Mdot
.68177 .45011 Mdot
.46096 .34392 Mdot
.6071 .71084 Mdot
.68209 .48537 Mdot
.45667 .30923 Mdot
.65201 .49522 Mdot
.4349 .66911 Mdot
.39442 .46563 Mdot
.69247 .4165 Mdot
.61395 .69119 Mdot
.33625 .5519 Mdot
.67064 .23825 Mdot
.42075 .7273 Mdot
.65561 .4399 Mdot
.38902 .69209 Mdot
.44127 .69586 Mdot
.38058 .47528 Mdot
.6098 .52124 Mdot
.45025 .34933 Mdot
.44394 .36682 Mdot
.70873 .71463 Mdot
.4083 .68017 Mdot
.47006 .8119 Mdot
.28644 .52623 Mdot
.65213 .48692 Mdot
.39998 .40721 Mdot
.43819 .36374 Mdot
.66333 .60818 Mdot
.60064 .6614 Mdot
.32055 .55597 Mdot
.3716 .48758 Mdot
.44297 .3097 Mdot
.43753 .36054 Mdot
.6259 .44118 Mdot
.61788 .4624 Mdot
.42812 .77144 Mdot
.67609 .63346 Mdot
.28233 .56371 Mdot
.61644 .6624 Mdot
.46555 .72302 Mdot
.66476 .43566 Mdot
.44842 .31581 Mdot
.75645 .3211 Mdot
.6355 .49029 Mdot
.42768 .67153 Mdot
.44288 .32144 Mdot
.60074 .67568 Mdot
.6002 .69396 Mdot
.60299 .42815 Mdot
.72716 .3054 Mdot
.30324 .56018 Mdot
.46013 .35778 Mdot
.43436 .27618 Mdot
.66365 .47307 Mdot
.61625 .45693 Mdot
.61513 .38754 Mdot
.27076 .56325 Mdot
.69084 .42183 Mdot
.63735 .6578 Mdot
.43317 .34489 Mdot
.63614 .46516 Mdot
.61064 .69277 Mdot
.50921 .31397 Mdot
.3885 .46559 Mdot
.4155 .69042 Mdot
.62453 .70648 Mdot
.62152 .68359 Mdot
.6192 .65425 Mdot
.3106 .454 Mdot
.44131 .388 Mdot
.82009 .57639 Mdot
.64123 .45551 Mdot
.71747 .67161 Mdot
.56666 .4344 Mdot
.27326 .53952 Mdot
.41306 .72435 Mdot
.61961 .43982 Mdot
.64162 .45579 Mdot
.70023 .27495 Mdot
.55777 .47124 Mdot
.55562 .46763 Mdot
.43872 .36707 Mdot
.40024 .28096 Mdot
.43464 .73673 Mdot
.47013 .84292 Mdot
.57804 .15709 Mdot
.67526 .43382 Mdot
.49786 .5253 Mdot
.45183 .31187 Mdot
.31418 .56932 Mdot
.54504 .54393 Mdot
.35821 .51481 Mdot
.42922 .33296 Mdot
.65762 .42632 Mdot
.67059 .24235 Mdot
.64179 .67499 Mdot
.6113 .44242 Mdot
.30696 .54289 Mdot
.61174 .44173 Mdot
.27438 .52962 Mdot
.4368 .40113 Mdot
.47953 .49529 Mdot
.64709 .45116 Mdot
.6643 .42425 Mdot
.59887 .54887 Mdot
.61401 .45692 Mdot
.29261 .67015 Mdot
.44922 .32579 Mdot
.71048 .49849 Mdot
.59565 .41058 Mdot
.69603 .31988 Mdot
.60811 .48242 Mdot
.43909 .5063 Mdot
.62498 .48338 Mdot
.79157 .46567 Mdot
.57761 .45287 Mdot
.63071 .48558 Mdot
.28355 .55605 Mdot
.30252 .57626 Mdot
.44173 .28954 Mdot
.39675 .47575 Mdot
.34529 .29645 Mdot
.59754 .46678 Mdot
.46147 .67557 Mdot
.50434 .44045 Mdot
.61696 .68024 Mdot
.43237 .34161 Mdot
.29152 .80315 Mdot
.2761 .56068 Mdot
.40197 .68467 Mdot
.46584 .62705 Mdot
.40122 .72497 Mdot
.45873 .74642 Mdot
.39266 .29348 Mdot
.62975 .66804 Mdot
.59417 .47324 Mdot
.67097 .28043 Mdot
.34682 .44422 Mdot
.665 .46959 Mdot
.41659 .65816 Mdot
.52731 .44682 Mdot
.7185 .70525 Mdot
.63988 .69894 Mdot
.63442 .68072 Mdot
.28666 .55063 Mdot
.44597 .73819 Mdot
.6656 .40078 Mdot
.59768 .66662 Mdot
.41419 .7237 Mdot
.37088 .47102 Mdot
.60707 .73733 Mdot
.44254 .3452 Mdot
.59116 .36068 Mdot
.41759 .41217 Mdot
.27793 .56199 Mdot
.22075 .56833 Mdot
.40542 .34682 Mdot
.4216 .36069 Mdot
.38895 .48108 Mdot
.41572 .68201 Mdot
.41023 .32838 Mdot
.63476 .44686 Mdot
.63426 .52323 Mdot
.58667 .45888 Mdot
.59779 .69561 Mdot
.60062 .4757 Mdot
.41101 .7034 Mdot
.29539 .56842 Mdot
.4505 .68892 Mdot
.29709 .56529 Mdot
.62473 .1952 Mdot
.5832 .43261 Mdot
.61944 .45851 Mdot
.50254 .54495 Mdot
.43443 .35597 Mdot
.65051 .27089 Mdot
.42467 .67223 Mdot
.44553 .6782 Mdot
.62382 .41342 Mdot
.46292 .37659 Mdot
.59576 .6244 Mdot
.53689 .54588 Mdot
.61978 .48247 Mdot
.45029 .32549 Mdot
.62041 .41266 Mdot
.24996 .64229 Mdot
.46542 .47175 Mdot
.46045 .3647 Mdot
.81263 .46157 Mdot
.62434 .435 Mdot
.60011 .5236 Mdot
.57315 .51935 Mdot
.77197 .45917 Mdot
.58436 .47869 Mdot
.46659 .31598 Mdot
.58841 .426 Mdot
.45974 .33753 Mdot
.44527 .70135 Mdot
.2837 .57509 Mdot
.45683 .33794 Mdot
.64891 .46424 Mdot
.58739 .16227 Mdot
.29693 .56976 Mdot
.61887 .44577 Mdot
.28841 .53716 Mdot
.41424 .32761 Mdot
.42398 .34051 Mdot
.37602 .49059 Mdot
.46467 .61847 Mdot
.30742 .56322 Mdot
.66887 .45321 Mdot
.31921 .44039 Mdot
.62937 .41335 Mdot
.38051 .72046 Mdot
.63523 .40534 Mdot
.6763 .46656 Mdot
.8212 .3741 Mdot
.44098 .53057 Mdot
.39871 .8337 Mdot
.25961 .58933 Mdot
.31161 .43694 Mdot
.45394 .28623 Mdot
.63965 .69899 Mdot
.41077 .52399 Mdot
.39792 .45051 Mdot
.40262 .72212 Mdot
.6237 .44163 Mdot
.40759 .24735 Mdot
.2794 .51708 Mdot
.61028 .67635 Mdot
.64538 .44889 Mdot
.42739 .74555 Mdot
.43013 .44242 Mdot
.32176 .55583 Mdot
.44046 .34552 Mdot
.42698 .34352 Mdot
.74422 .69846 Mdot
.63444 .46811 Mdot
.62259 .46475 Mdot
.30023 .57113 Mdot
.65391 .39035 Mdot
.61971 .65585 Mdot
.35493 .61605 Mdot
.30633 .5402 Mdot
.46598 .47918 Mdot
.43362 .36454 Mdot
.60735 .46469 Mdot
.50716 .55105 Mdot
.2707 .43578 Mdot
.47881 .24347 Mdot
.62884 .692 Mdot
.64977 .58666 Mdot
.46714 .31631 Mdot
.30235 .54085 Mdot
.73723 .6031 Mdot
.5658 .42085 Mdot
.60318 .46201 Mdot
.70109 .55235 Mdot
.53688 .54406 Mdot
.46003 .6149 Mdot
.60197 .38988 Mdot
.59195 .58079 Mdot
.62627 .41368 Mdot
.62632 .41804 Mdot
.6726 .47522 Mdot
.62178 .40612 Mdot
.45423 .32667 Mdot
.70873 .34727 Mdot
.42671 .70074 Mdot
.52523 .29303 Mdot
.39166 .7569 Mdot
.65522 .45403 Mdot
.65483 .42493 Mdot
.59783 .3245 Mdot
.51862 .50907 Mdot
.44563 .33167 Mdot
.42886 .27732 Mdot
.28957 .57555 Mdot
.55475 .45871 Mdot
.41261 .67627 Mdot
.55178 .49304 Mdot
.43587 .6886 Mdot
.45241 .32439 Mdot
.46049 .70181 Mdot
.32255 .51595 Mdot
.4375 .73023 Mdot
.40449 .69352 Mdot
.32472 .55476 Mdot
.42061 .33659 Mdot
.63003 .48774 Mdot
.32731 .54465 Mdot
.58914 .62882 Mdot
.59801 .69554 Mdot
.37411 .49125 Mdot
.57306 .46027 Mdot
.57114 .49721 Mdot
.22283 .63455 Mdot
.45709 .71113 Mdot
.49336 .48987 Mdot
.44075 .31187 Mdot
.60394 .70809 Mdot
.45704 .32919 Mdot
.78026 .63746 Mdot
.62062 .69169 Mdot
.37927 .49129 Mdot
.71622 .609 Mdot
.32241 .58995 Mdot
.64463 .40459 Mdot
.41252 .27652 Mdot
.43984 .68884 Mdot
.28524 .51791 Mdot
.35267 .30996 Mdot
.6194 .42807 Mdot
.37746 .45438 Mdot
.41251 .35006 Mdot
.40099 .45472 Mdot
.30485 .54379 Mdot
.40112 .4899 Mdot
.63165 .47267 Mdot
.31937 .59084 Mdot
.66029 .41826 Mdot
.64986 .35802 Mdot
.4003 .75617 Mdot
.48878 .29211 Mdot
.64851 .41847 Mdot
.41467 .68733 Mdot
.64061 .41541 Mdot
.54262 .35607 Mdot
.70305 .63192 Mdot
.68282 .44348 Mdot
.52737 .49287 Mdot
.2402 .66533 Mdot
.45084 .31676 Mdot
.66171 .5086 Mdot
.38784 .4759 Mdot
.65218 .43074 Mdot
.37506 .17282 Mdot
.60765 .68813 Mdot
.63161 .64093 Mdot
.64767 .46179 Mdot
.63559 .4585 Mdot
.71048 .29001 Mdot
.39703 .34439 Mdot
.37302 .48793 Mdot
.59922 .45429 Mdot
.72894 .52596 Mdot
.28352 .55153 Mdot
.64494 .40922 Mdot
.58453 .43708 Mdot
.4507 .7921 Mdot
.28312 .54552 Mdot
.45073 .72584 Mdot
.40094 .45303 Mdot
.46339 .68522 Mdot
.58652 .67251 Mdot
.61756 .57864 Mdot
.67143 .59882 Mdot
.46 .45585 Mdot
.62041 .70624 Mdot
.65652 .45916 Mdot
.48975 .29674 Mdot
.63899 .47325 Mdot
.63217 .67874 Mdot
.29962 .53483 Mdot
.4521 .32956 Mdot
.57841 .36662 Mdot
.377 .47388 Mdot
.65788 .47536 Mdot
.63748 .70608 Mdot
.4546 .34302 Mdot
.22876 .45172 Mdot
.43447 .31854 Mdot
.29509 .56269 Mdot
.26647 .53652 Mdot
.61751 .68576 Mdot
.45662 .32736 Mdot
.46286 .6869 Mdot
.24593 .57762 Mdot
.66418 .41626 Mdot
.32158 .51466 Mdot
.40984 .31361 Mdot
.46542 .30865 Mdot
.46782 .37065 Mdot
.60351 .41107 Mdot
.51848 .53216 Mdot
.57387 .40739 Mdot
.29776 .5705 Mdot
.4153 .73869 Mdot
.68599 .64008 Mdot
.69435 .29387 Mdot
.46958 .49181 Mdot
.60464 .49919 Mdot
.59908 .474 Mdot
.5875 .45928 Mdot
.60219 .41732 Mdot
.35805 .61115 Mdot
.5834 .43257 Mdot
.27874 .55375 Mdot
.43474 .69526 Mdot
.6144 .47859 Mdot
.39222 .47234 Mdot
.43416 .59101 Mdot
.60179 .70943 Mdot
.70037 .37402 Mdot
.37983 .30662 Mdot
.45406 .34084 Mdot
.44462 .72273 Mdot
.46151 .69867 Mdot
.5958 .67629 Mdot
.32614 .54101 Mdot
.42892 .32548 Mdot
.78845 .47328 Mdot
.63514 .66047 Mdot
.58629 .4433 Mdot
.50398 .54763 Mdot
.78187 .42679 Mdot
.64502 .49448 Mdot
.60425 .43265 Mdot
.40362 .46828 Mdot
.40027 .69068 Mdot
.35953 .2165 Mdot
.227 .37354 Mdot
.6129 .6824 Mdot
.61078 .66215 Mdot
.47848 .36525 Mdot
.65174 .48829 Mdot
.30537 .5589 Mdot
.59718 .5742 Mdot
.22551 .62318 Mdot
.36113 .27871 Mdot
.25324 .6584 Mdot
.59983 .47911 Mdot
.66923 .33239 Mdot
.63485 .40422 Mdot
.44983 .38762 Mdot
.46779 .37333 Mdot
.44455 .33834 Mdot
.28602 .55757 Mdot
.72622 .67865 Mdot
.27719 .5511 Mdot
.3844 .28068 Mdot
.47573 .3311 Mdot
.44715 .55656 Mdot
.4424 .67543 Mdot
.55822 .4578 Mdot
.63115 .67003 Mdot
.62201 .61513 Mdot
.65522 .51158 Mdot
.641 .58513 Mdot
.44204 .73158 Mdot
.42499 .31779 Mdot
.56248 .44113 Mdot
.34255 .30385 Mdot
.49347 .51961 Mdot
.25403 .69126 Mdot
.42194 .251 Mdot
.61322 .69565 Mdot
.53823 .28646 Mdot
.62982 .65851 Mdot
.32126 .55395 Mdot
.61998 .43278 Mdot
.64038 .49138 Mdot
.59732 .43026 Mdot
.61191 .40864 Mdot
.28823 .54251 Mdot
.66865 .418 Mdot
.68881 .69736 Mdot
.37489 .46406 Mdot
.41893 .58288 Mdot
.60124 .69217 Mdot
.28146 .52853 Mdot
.43894 .69592 Mdot
.38757 .48267 Mdot
.64455 .70371 Mdot
.57894 .4221 Mdot
.64604 .4687 Mdot
.37196 .4715 Mdot
.68402 .39705 Mdot
.57673 .49237 Mdot
.42315 .69622 Mdot
.44764 .59305 Mdot
.59163 .68886 Mdot
.63811 .68151 Mdot
.29551 .5189 Mdot
.45726 .32899 Mdot
.59341 .67725 Mdot
.44333 .74039 Mdot
.64951 .4127 Mdot
.66825 .42871 Mdot
.41138 .30782 Mdot
.72141 .67297 Mdot
.60361 .71093 Mdot
.69157 .42707 Mdot
.43881 .35414 Mdot
.41294 .35199 Mdot
.59975 .45293 Mdot
.68329 .42591 Mdot
.48638 .35811 Mdot
.60031 .67163 Mdot
.29186 .52166 Mdot
.46263 .54548 Mdot
.27478 .54662 Mdot
.4464 .35472 Mdot
.64306 .52587 Mdot
.42052 .34746 Mdot
.62304 .42928 Mdot
.4325 .8697 Mdot
.57851 .44436 Mdot
.73606 .45268 Mdot
.53077 .66926 Mdot
.429 .67304 Mdot
.4224 .67665 Mdot
.39452 .46723 Mdot
.45634 .30997 Mdot
.6724 .50384 Mdot
.62706 .664 Mdot
.3126 .43705 Mdot
.40108 .34543 Mdot
.40633 .69069 Mdot
.40576 .67983 Mdot
.29724 .53546 Mdot
.60493 .48023 Mdot
.6101 .4686 Mdot
.44014 .72983 Mdot
.32524 .6244 Mdot
.46331 .33447 Mdot
.62283 .46452 Mdot
.59467 .4153 Mdot
.42913 .69977 Mdot
.25544 .54142 Mdot
.40652 .33819 Mdot
.601 .41123 Mdot
.69331 .62718 Mdot
.27082 .53814 Mdot
.65996 .44808 Mdot
.62832 .40353 Mdot
.62094 .67903 Mdot
.66736 .58596 Mdot
.71696 .66774 Mdot
.30315 .57978 Mdot
.40175 .46097 Mdot
.63079 .4955 Mdot
.43114 .67409 Mdot
.56876 .45309 Mdot
.16404 .45863 Mdot
.37986 .45742 Mdot
.62853 .47247 Mdot
.68189 .45813 Mdot
.45033 .36049 Mdot
.63105 .46545 Mdot
.26536 .50658 Mdot
.42334 .7187 Mdot
.62851 .47334 Mdot
.72715 .30801 Mdot
.29931 .53591 Mdot
.65297 .51184 Mdot
.63474 .695 Mdot
.46239 .60916 Mdot
.56738 .17168 Mdot
.47358 .69941 Mdot
.60517 .6982 Mdot
.60375 .47771 Mdot
.46798 .69267 Mdot
.32774 .55408 Mdot
.70251 .52316 Mdot
.65805 .45889 Mdot
.27518 .55095 Mdot
.2984 .56819 Mdot
.61375 .68638 Mdot
.37419 .84127 Mdot
.68147 .45276 Mdot
.61278 .44745 Mdot
.19983 .62188 Mdot
.48895 .34797 Mdot
.61696 .44336 Mdot
.6118 .48281 Mdot
.31381 .52171 Mdot
.7751 .61748 Mdot
.64839 .58618 Mdot
.34569 .61674 Mdot
.27265 .53358 Mdot
.42572 .65906 Mdot
.42285 .7238 Mdot
.60691 .69809 Mdot
.44142 .32124 Mdot
.59778 .70073 Mdot
.42937 .7102 Mdot
.59952 .4313 Mdot
.31355 .53002 Mdot
.52719 .21008 Mdot
.3126 .5157 Mdot
.44436 .74232 Mdot
.43163 .38076 Mdot
.41246 .23416 Mdot
.15706 .49695 Mdot
.43096 .412 Mdot
.27661 .57506 Mdot
.61707 .68003 Mdot
.21712 .40421 Mdot
.61572 .4799 Mdot
.60643 .35036 Mdot
.61198 .44414 Mdot
.4602 .26155 Mdot
.41298 .72362 Mdot
.36967 .47997 Mdot
.6191 .4278 Mdot
.65124 .58543 Mdot
.32278 .55768 Mdot
.31289 .55313 Mdot
.59239 .42494 Mdot
.29738 .56304 Mdot
.6155 .47014 Mdot
.43463 .69921 Mdot
.39095 .83985 Mdot
.63299 .48289 Mdot
.64111 .53203 Mdot
.30151 .58911 Mdot
.37161 .49146 Mdot
.40214 .67244 Mdot
.69575 .3356 Mdot
.33867 .29034 Mdot
.30229 .55818 Mdot
.70454 .39131 Mdot
.45403 .71355 Mdot
.39345 .48047 Mdot
.44468 .66266 Mdot
.60644 .44993 Mdot
.60445 .4829 Mdot
.60606 .41879 Mdot
.60532 .47747 Mdot
.57469 .3476 Mdot
.57123 .48608 Mdot
.56775 .26053 Mdot
.64122 .45614 Mdot
.73453 .4434 Mdot
.27829 .54635 Mdot
.59685 .52437 Mdot
.4811 .6081 Mdot
.58833 .47014 Mdot
.40376 .28287 Mdot
.28235 .52878 Mdot
.3826 .39859 Mdot
.28569 .54414 Mdot
.44898 .68602 Mdot
.31522 .56397 Mdot
.62432 .43343 Mdot
.43621 .33911 Mdot
.43812 .7193 Mdot
.50379 .39743 Mdot
.41064 .73249 Mdot
.63419 .47077 Mdot
.3498 .5619 Mdot
.44783 .67505 Mdot
.55926 .48327 Mdot
.4347 .33584 Mdot
.74412 .52237 Mdot
.47537 .38222 Mdot
.62979 .45932 Mdot
.62749 .45305 Mdot
.37061 .48205 Mdot
.32155 .55782 Mdot
.44335 .37164 Mdot
.46668 .79234 Mdot
.62896 .71409 Mdot
.44328 .32715 Mdot
.5844 .52628 Mdot
.49737 .52808 Mdot
.4563 .36323 Mdot
.75484 .49302 Mdot
.32398 .54208 Mdot
.48051 .33903 Mdot
.6047 .4011 Mdot
.53236 .30514 Mdot
.63892 .67295 Mdot
.45791 .67716 Mdot
.57272 .57283 Mdot
.4226 .72228 Mdot
.33919 .53508 Mdot
.41385 .67182 Mdot
.28081 .54909 Mdot
.51155 .45141 Mdot
.46692 .59186 Mdot
.29787 .51313 Mdot
.31083 .58892 Mdot
.4215 .70336 Mdot
.59626 .42249 Mdot
.43648 .57908 Mdot
.67663 .50028 Mdot
.63054 .5199 Mdot
.27348 .55262 Mdot
.47374 .32313 Mdot
.4208 .35243 Mdot
.71159 .48807 Mdot
.43057 .35376 Mdot
.44238 .71163 Mdot
.46025 .43915 Mdot
.68464 .36311 Mdot
.30401 .53407 Mdot
.46199 .62322 Mdot
.64681 .41859 Mdot
.41645 .69342 Mdot
.44556 .70871 Mdot
.29546 .56698 Mdot
.51253 .28241 Mdot
.63669 .51666 Mdot
.47619 .31118 Mdot
.47949 .34892 Mdot
.45895 .36284 Mdot
.46695 .37551 Mdot
.73031 .67763 Mdot
.28561 .51786 Mdot
.46099 .31291 Mdot
.61574 .4099 Mdot
.63041 .49242 Mdot
.39301 .45523 Mdot
.59912 .67633 Mdot
.57077 .41737 Mdot
.67405 .50228 Mdot
.60067 .45448 Mdot
.4317 .67234 Mdot
.54922 .51666 Mdot
.37782 .46096 Mdot
.40666 .6812 Mdot
.41129 .67811 Mdot
.3996 .46381 Mdot
.51518 .45376 Mdot
.37814 .21762 Mdot
.60125 .42498 Mdot
.38882 .29724 Mdot
.4251 .67779 Mdot
.60416 .60273 Mdot
.72308 .43432 Mdot
.6713 .45509 Mdot
.4028 .60545 Mdot
.43907 .70324 Mdot
.46576 .29261 Mdot
.61019 .45304 Mdot
.38703 .48049 Mdot
.63913 .6845 Mdot
.59887 .54093 Mdot
.40229 .47021 Mdot
.45708 .32342 Mdot
.41855 .78973 Mdot
.4543 .30112 Mdot
.45382 .67761 Mdot
.65925 .51052 Mdot
.61632 .88527 Mdot
.44209 .6893 Mdot
.30224 .44413 Mdot
.46681 .59416 Mdot
.63303 .48036 Mdot
.43387 .72542 Mdot
.41387 .29893 Mdot
.27062 .53993 Mdot
.51545 .5439 Mdot
.44759 .3161 Mdot
.38612 .48299 Mdot
.39448 .45769 Mdot
.42693 .69985 Mdot
.47489 .35446 Mdot
.65718 .41179 Mdot
.42732 .34069 Mdot
.31552 .5374 Mdot
.63877 .43287 Mdot
.34498 .29577 Mdot
.61266 .5221 Mdot
.42933 .34284 Mdot
.42885 .7436 Mdot
.61761 .65005 Mdot
.65158 .4584 Mdot
.37109 .36738 Mdot
.60641 .48052 Mdot
.29131 .53573 Mdot
.54666 .62028 Mdot
.53218 .21376 Mdot
.59134 .44101 Mdot
.64935 .42064 Mdot
.32894 .52545 Mdot
.59293 .44117 Mdot
.67448 .46536 Mdot
.4064 .48556 Mdot
.45313 .36277 Mdot
.6106 .47577 Mdot
.41682 .72164 Mdot
.5754 .19708 Mdot
.61814 .43346 Mdot
.2473 .52211 Mdot
.73238 .52832 Mdot
.525 .5971 Mdot
.66106 .51894 Mdot
.66163 .60791 Mdot
.62332 .45167 Mdot
.67019 .46158 Mdot
.59811 .42468 Mdot
.66302 .33349 Mdot
.425 .70826 Mdot
.40797 .69585 Mdot
.63855 .69387 Mdot
.71996 .53667 Mdot
.62425 .69597 Mdot
.32645 .52431 Mdot
.46456 .62392 Mdot
.37319 .47214 Mdot
.45824 .33132 Mdot
.61567 .43318 Mdot
.41123 .73073 Mdot
.60706 .46165 Mdot
.65431 .4329 Mdot
.43782 .71116 Mdot
.44425 .70455 Mdot
.47459 .6981 Mdot
.6414 .67079 Mdot
.44898 .33516 Mdot
.60809 .42761 Mdot
.62668 .65419 Mdot
.58823 .41637 Mdot
.46642 .52213 Mdot
.44713 .33466 Mdot
.42931 .34484 Mdot
.41552 .33642 Mdot
.64604 .47866 Mdot
.62838 .43296 Mdot
.27701 .5511 Mdot
.41147 .30817 Mdot
.31155 .56078 Mdot
.43216 .72556 Mdot
.41484 .69863 Mdot
.60632 .44907 Mdot
.67597 .40691 Mdot
.59995 .68651 Mdot
.45746 .69756 Mdot
.4032 .44874 Mdot
.63656 .69544 Mdot
.58852 .4636 Mdot
.42707 .72482 Mdot
.61476 .71084 Mdot
.45737 .2357 Mdot
.32544 .27979 Mdot
.6438 .67463 Mdot
.59248 .42439 Mdot
.69452 .28738 Mdot
.69891 .63661 Mdot
.62768 .71695 Mdot
.28675 .53493 Mdot
.62335 .4877 Mdot
.28315 .61369 Mdot
.59427 .66844 Mdot
.71758 .66348 Mdot
.43476 .71457 Mdot
.66055 .52894 Mdot
.56464 .52323 Mdot
.67529 .36024 Mdot
.60591 .65375 Mdot
.43067 .3424 Mdot
.47521 .3621 Mdot
.58761 .44156 Mdot
.46231 .61657 Mdot
.3176 .51568 Mdot
.46166 .69942 Mdot
.40399 .70712 Mdot
.46172 .3666 Mdot
.46073 .46073 Mdot
.4189 .72311 Mdot
.65607 .48478 Mdot
.5834 .69699 Mdot
.55408 .45357 Mdot
.74452 .68778 Mdot
.54874 .17718 Mdot
.65749 .52204 Mdot
.62294 .64985 Mdot
.32372 .55991 Mdot
.28814 .56317 Mdot
.28988 .55976 Mdot
.41526 .7028 Mdot
.5498 .54953 Mdot
.40701 .71715 Mdot
.22883 .5101 Mdot
.60812 .69182 Mdot
.76255 .52735 Mdot
.59538 .4066 Mdot
.63396 .47928 Mdot
.65283 .4179 Mdot
.609 .41757 Mdot
.62294 .45309 Mdot
.27892 .56277 Mdot
.46619 .69711 Mdot
.23575 .6382 Mdot
.47048 .35049 Mdot
.22508 .4507 Mdot
.44427 .67624 Mdot
.40588 .46363 Mdot
.61069 .67046 Mdot
.68854 .5759 Mdot
.57888 .69407 Mdot
.45853 .69276 Mdot
.6441 .49707 Mdot
.48332 .35858 Mdot
.79559 .45658 Mdot
.63487 .4522 Mdot
.45812 .70353 Mdot
.43812 .65732 Mdot
.51104 .27486 Mdot
.59419 .38459 Mdot
.44966 .62347 Mdot
.50086 .52649 Mdot
.64384 .66792 Mdot
.60919 .4996 Mdot
.62636 .58599 Mdot
.42879 .70809 Mdot
.43371 .68258 Mdot
.63191 .71528 Mdot
.52599 .37606 Mdot
.4685 .32307 Mdot
.36794 .47771 Mdot
.28754 .53061 Mdot
.64245 .47383 Mdot
.41732 .70875 Mdot
.49577 .31426 Mdot
.47929 .54354 Mdot
.29167 .54451 Mdot
.40691 .67924 Mdot
.61078 .48372 Mdot
.58934 .44484 Mdot
.61891 .69523 Mdot
.50255 .72629 Mdot
.67627 .50077 Mdot
.31152 .43827 Mdot
.48269 .48565 Mdot
.4679 .59958 Mdot
.60354 .4627 Mdot
.42921 .35825 Mdot
.39829 .46516 Mdot
.62837 .66989 Mdot
.57643 .42999 Mdot
.35849 .23389 Mdot
.44364 .30061 Mdot
.30756 .56201 Mdot
.39809 .46983 Mdot
.59618 .56892 Mdot
.60721 .48056 Mdot
.61169 .44449 Mdot
.60411 .41092 Mdot
.36161 .22633 Mdot
.40953 .7153 Mdot
.45065 .37365 Mdot
.62387 .69955 Mdot
.42471 .33532 Mdot
.42566 .66889 Mdot
.45489 .61033 Mdot
.58275 .43142 Mdot
.43725 .30558 Mdot
.42826 .33075 Mdot
.30103 .53553 Mdot
.32761 .54382 Mdot
.4713 .70938 Mdot
.60995 .47979 Mdot
.37203 .47715 Mdot
.46837 .31926 Mdot
.46342 .70671 Mdot
.61908 .69434 Mdot
.3201 .50406 Mdot
.64239 .45785 Mdot
.42627 .70268 Mdot
.66975 .50481 Mdot
.46053 .35254 Mdot
.45382 .68411 Mdot
.40002 .47565 Mdot
.60142 .67157 Mdot
.61386 .48952 Mdot
.25399 .67401 Mdot
.39156 .47848 Mdot
.64993 .46818 Mdot
.53647 .18016 Mdot
.4619 .61534 Mdot
.50428 .38245 Mdot
.42266 .73143 Mdot
.37655 .47896 Mdot
.46076 .37423 Mdot
.54505 .30909 Mdot
.43023 .68537 Mdot
.68356 .25744 Mdot
.45433 .55797 Mdot
.60452 .42437 Mdot
.45334 .31906 Mdot
.57674 .70883 Mdot
.31437 .42307 Mdot
.69167 .63733 Mdot
.62235 .47038 Mdot
.42183 .72156 Mdot
.63848 .68481 Mdot
.31363 .55393 Mdot
.24418 .5296 Mdot
.76937 .6702 Mdot
.40322 .69097 Mdot
.61262 .43177 Mdot
.47553 .32649 Mdot
.30368 .56333 Mdot
.67777 .24537 Mdot
.44733 .73822 Mdot
.42514 .72989 Mdot
.66349 .42695 Mdot
.62779 .69527 Mdot
.29335 .61207 Mdot
.40832 .70361 Mdot
.46638 .69108 Mdot
.42168 .46282 Mdot
.64072 .69249 Mdot
.60527 .41227 Mdot
.71192 .48763 Mdot
.63243 .40622 Mdot
.25319 .46226 Mdot
.3751 .47871 Mdot
.47077 .3478 Mdot
.61933 .441 Mdot
.23707 .66247 Mdot
.43446 .68997 Mdot
.50066 .52415 Mdot
.2581 .54102 Mdot
.32722 .5438 Mdot
.42412 .71771 Mdot
.61152 .46082 Mdot
.28428 .50819 Mdot
.6046 .69359 Mdot
.5996 .41192 Mdot
.62546 .4306 Mdot
.40893 .30909 Mdot
.3132 .53141 Mdot
.57228 .19399 Mdot
.31779 .54846 Mdot
.30071 .51774 Mdot
.41077 .34768 Mdot
.58708 .44257 Mdot
.45367 .68783 Mdot
.42873 .7473 Mdot
.68791 .45476 Mdot
.60139 .60423 Mdot
.4636 .31996 Mdot
.42944 .75899 Mdot
.34496 .23647 Mdot
.67522 .43544 Mdot
.40364 .45147 Mdot
.4544 .26345 Mdot
.2716 .5278 Mdot
.59804 .43537 Mdot
.4608 .33915 Mdot
.46661 .71521 Mdot
.41634 .71559 Mdot
.56508 .42181 Mdot
.29344 .56755 Mdot
.61012 .70964 Mdot
.44724 .70963 Mdot
.4594 .53293 Mdot
.63052 .47124 Mdot
.3754 .45421 Mdot
.44896 .70942 Mdot
.6016 .17144 Mdot
.2309 .65155 Mdot
.46305 .36357 Mdot
.66509 .4424 Mdot
.4841 .34056 Mdot
.61599 .70322 Mdot
.42845 .6638 Mdot
.28162 .56061 Mdot
.5636 .38267 Mdot
.4147 .8053 Mdot
.41777 .70189 Mdot
.45301 .32634 Mdot
.61011 .43265 Mdot
.70783 .40379 Mdot
.62339 .48312 Mdot
.77854 .6082 Mdot
.60878 .71413 Mdot
.3347 .5657 Mdot
.29841 .57101 Mdot
.65443 .42559 Mdot
.62139 .65512 Mdot
.44705 .74595 Mdot
.43666 .71096 Mdot
.43971 .84268 Mdot
.40127 .47216 Mdot
.46692 .74159 Mdot
.64624 .47692 Mdot
.46012 .71524 Mdot
.69486 .29523 Mdot
.30525 .56851 Mdot
.65245 .41139 Mdot
.39718 .71272 Mdot
.25673 .43407 Mdot
.4997 .52957 Mdot
.62751 .47143 Mdot
.65846 .39343 Mdot
.2854 .54008 Mdot
.21772 .40232 Mdot
.42196 .73271 Mdot
.5879 .41816 Mdot
.26859 .51915 Mdot
.49969 .43419 Mdot
.47436 .78521 Mdot
.44872 .33555 Mdot
.3969 .72156 Mdot
.29443 .52192 Mdot
.65647 .52995 Mdot
.59765 .6844 Mdot
.45899 .73349 Mdot
.40302 .72557 Mdot
.64605 .43402 Mdot
.56736 .42758 Mdot
.63868 .38825 Mdot
.4591 .32086 Mdot
.31243 .52215 Mdot
.64148 .42189 Mdot
.47134 .51263 Mdot
.61287 .41759 Mdot
.30416 .5203 Mdot
.51616 .91285 Mdot
.63424 .49806 Mdot
.643 .46257 Mdot
.70705 .38062 Mdot
.4401 .37017 Mdot
.44457 .36121 Mdot
.4755 .49308 Mdot
.64226 .48618 Mdot
.4446 .54827 Mdot
.45121 .33454 Mdot
.44753 .31936 Mdot
.44522 .5507 Mdot
.6417 .43671 Mdot
.35934 .50157 Mdot
.30215 .56369 Mdot
.32746 .54274 Mdot
.44908 .36006 Mdot
.55587 .44393 Mdot
.32657 .55681 Mdot
.57641 .34037 Mdot
.45583 .68505 Mdot
.6275 .58514 Mdot
.42663 .33819 Mdot
.50954 .55521 Mdot
.32265 .55011 Mdot
.68373 .22767 Mdot
.77945 .44147 Mdot
.67914 .43275 Mdot
.5897 .43977 Mdot
.62297 .68276 Mdot
.62096 .37313 Mdot
.4013 .45935 Mdot
.29268 .56316 Mdot
.36239 .61032 Mdot
.44402 .33857 Mdot
.63681 .4871 Mdot
.68141 .63715 Mdot
.5722 .17615 Mdot
.70686 .50929 Mdot
.44141 .32028 Mdot
.43978 .33838 Mdot
.43775 .73389 Mdot
.4588 .68902 Mdot
.58546 .42968 Mdot
.28272 .5564 Mdot
.48084 .35034 Mdot
.31215 .52559 Mdot
.42997 .70944 Mdot
.4498 .68126 Mdot
.38578 .45417 Mdot
.62761 .51614 Mdot
.42692 .71606 Mdot
.23107 .54804 Mdot
.47049 .51379 Mdot
.40741 .32114 Mdot
.20165 .57783 Mdot
.71235 .2585 Mdot
.60958 .36237 Mdot
.63922 .68335 Mdot
.50878 .45092 Mdot
.30335 .57735 Mdot
.65119 .42299 Mdot
.60503 .44143 Mdot
.38219 .4645 Mdot
.30867 .57603 Mdot
.61467 .67277 Mdot
.32047 .56073 Mdot
.62276 .66472 Mdot
.40959 .69226 Mdot
.62354 .4374 Mdot
.58281 .45982 Mdot
.31149 .55291 Mdot
.44992 .7257 Mdot
.44691 .67442 Mdot
.63355 .66434 Mdot
.69548 .56379 Mdot
.42821 .70129 Mdot
.42632 .33743 Mdot
.60238 .2177 Mdot
.39259 .4577 Mdot
.61091 .45356 Mdot
.6675 .60999 Mdot
.55779 .30282 Mdot
.60943 .42146 Mdot
.39635 .47293 Mdot
.38267 .84768 Mdot
.62162 .43504 Mdot
.55337 .85426 Mdot
.37582 .46646 Mdot
.42142 .34955 Mdot
.45233 .71341 Mdot
.39939 .47312 Mdot
.55668 .52456 Mdot
.41248 .76081 Mdot
.67461 .49237 Mdot
.46646 .32022 Mdot
.42302 .31769 Mdot
.45091 .6004 Mdot
.25124 .46242 Mdot
.62579 .69926 Mdot
.60673 .68014 Mdot
.42801 .68768 Mdot
.22833 .56559 Mdot
.56115 .4297 Mdot
.60907 .67928 Mdot
.36128 .5679 Mdot
.65027 .42007 Mdot
.46057 .61217 Mdot
.4285 .57885 Mdot
.4428 .3674 Mdot
.59051 .52281 Mdot
.43133 .6883 Mdot
.45221 .32681 Mdot
.44329 .58449 Mdot
.65175 .41311 Mdot
.44576 .33591 Mdot
.32178 .52782 Mdot
.42326 .53108 Mdot
.42711 .34625 Mdot
.50993 .54399 Mdot
.30581 .55588 Mdot
.45958 .6163 Mdot
.75894 .5694 Mdot
.45209 .13777 Mdot
.28759 .56135 Mdot
.45577 .71292 Mdot
.41829 .70731 Mdot
.43098 .69897 Mdot
.45192 .31559 Mdot
.44477 .6984 Mdot
.47295 .33841 Mdot
.30978 .58683 Mdot
.68116 .57683 Mdot
.61884 .68847 Mdot
.63171 .74222 Mdot
.43849 .3486 Mdot
.23912 .49281 Mdot
.18151 .58641 Mdot
.60313 .41472 Mdot
.29676 .51385 Mdot
.63135 .65453 Mdot
.48327 .46967 Mdot
.62208 .67973 Mdot
.45323 .71501 Mdot
.63115 .58224 Mdot
.61521 .47094 Mdot
.39633 .26714 Mdot
.63766 .68639 Mdot
.44411 .31783 Mdot
.65583 .45547 Mdot
.40798 .74464 Mdot
.60858 .70078 Mdot
.63765 .67448 Mdot
.62092 .45295 Mdot
.42193 .3242 Mdot
.45572 .6891 Mdot
.2968 .57831 Mdot
.59508 .7191 Mdot
.66212 .39228 Mdot
.59339 .42885 Mdot
.6376 .50013 Mdot
.49568 .51353 Mdot
.23242 .59758 Mdot
.30281 .55515 Mdot
.71141 .66225 Mdot
.41523 .69532 Mdot
.69497 .64014 Mdot
.33306 .43172 Mdot
.57993 .66429 Mdot
.37476 .4771 Mdot
.37455 .47899 Mdot
.62753 .46507 Mdot
.16612 .49814 Mdot
.72706 .48893 Mdot
.26314 .56044 Mdot
.38945 .46093 Mdot
.4505 .67605 Mdot
.42784 .2958 Mdot
.53978 .4728 Mdot
.58567 .40924 Mdot
.30564 .57877 Mdot
.43312 .70642 Mdot
.16401 .45441 Mdot
.60949 .69171 Mdot
.47984 .47088 Mdot
.60697 .47752 Mdot
.62111 .46191 Mdot
.29871 .54447 Mdot
.27967 .55617 Mdot
.4231 .44971 Mdot
.52242 .58552 Mdot
.34884 .28636 Mdot
.3336 .55086 Mdot
.16338 .45418 Mdot
.41075 .24832 Mdot
.45142 .35648 Mdot
.40221 .45277 Mdot
.32873 .53192 Mdot
.61805 .44247 Mdot
.42264 .35269 Mdot
.71307 .51162 Mdot
.47583 .29663 Mdot
.46268 .61051 Mdot
.46226 .54355 Mdot
.59875 .47326 Mdot
.47738 .37075 Mdot
.44974 .32848 Mdot
.47479 .37636 Mdot
.39795 .46229 Mdot
.60059 .45876 Mdot
.59937 .41918 Mdot
.62097 .43373 Mdot
.69603 .393 Mdot
.63141 .46581 Mdot
.33 .42932 Mdot
.46605 .49976 Mdot
.53202 .75094 Mdot
.63663 .44924 Mdot
.31331 .51986 Mdot
.62395 .43901 Mdot
.61214 .65692 Mdot
.62108 .49397 Mdot
.46453 .6101 Mdot
.29426 .55706 Mdot
.52602 .33628 Mdot
.38206 .69499 Mdot
.58035 .45017 Mdot
.61991 .7069 Mdot
.20854 .57769 Mdot
.6994 .65821 Mdot
.41754 .47389 Mdot
.42734 .34027 Mdot
.46551 .68312 Mdot
.28882 .5114 Mdot
.44827 .68362 Mdot
.66313 .41612 Mdot
.39543 .44908 Mdot
.82146 .39292 Mdot
.51633 .56318 Mdot
.61976 .44224 Mdot
.62875 .5152 Mdot
.43651 .36326 Mdot
.43773 .69057 Mdot
.4433 .40242 Mdot
.65032 .41784 Mdot
.59407 .68948 Mdot
.60729 .65592 Mdot
.4095 .62664 Mdot
.40256 .53377 Mdot
.73518 .38449 Mdot
.29881 .54677 Mdot
.41424 .70763 Mdot
.60048 .6581 Mdot
.41444 .27564 Mdot
.31543 .51534 Mdot
.27121 .52824 Mdot
.31161 .53019 Mdot
.63562 .47318 Mdot
.38929 .45395 Mdot
.38184 .57078 Mdot
.39361 .47869 Mdot
.63311 .40947 Mdot
.40208 .72325 Mdot
.39303 .48038 Mdot
.62592 .68949 Mdot
.29141 .51954 Mdot
.43717 .67288 Mdot
.62958 .45523 Mdot
.45246 .34078 Mdot
.71086 .7065 Mdot
.25061 .69781 Mdot
.46211 .61782 Mdot
.4621 .61792 Mdot
.41742 .32274 Mdot
.3704 .3093 Mdot
.33601 .52288 Mdot
.52093 .28604 Mdot
.60042 .62204 Mdot
.68763 .46225 Mdot
.47956 .81953 Mdot
.40857 .7204 Mdot
.4396 .71828 Mdot
.62149 .47613 Mdot
.45792 .72357 Mdot
.62836 .4864 Mdot
.42681 .73406 Mdot
.29249 .43126 Mdot
.59297 .40553 Mdot
.44165 .71346 Mdot
.5841 .38453 Mdot
.65128 .45934 Mdot
.42715 .35466 Mdot
.46051 .72994 Mdot
.67894 .43302 Mdot
.84257 .44947 Mdot
.30497 .53764 Mdot
.39774 .46148 Mdot
.47443 .61546 Mdot
.31811 .56019 Mdot
.47476 .33512 Mdot
.64102 .48963 Mdot
.60869 .6952 Mdot
.44586 .35374 Mdot
.39726 .73818 Mdot
.63539 .68863 Mdot
.45863 .44063 Mdot
.44919 .35853 Mdot
.38739 .45809 Mdot
.60405 .66818 Mdot
.67489 .49157 Mdot
.4381 .71694 Mdot
.23869 .67195 Mdot
.39955 .47137 Mdot
.61127 .46837 Mdot
.39506 .71868 Mdot
.32056 .56007 Mdot
.58302 .44268 Mdot
.41659 .71063 Mdot
.39975 .4657 Mdot
.64739 .45838 Mdot
.64982 .47688 Mdot
.53064 .3786 Mdot
.54774 .63556 Mdot
.62164 .68967 Mdot
.41697 .36097 Mdot
.61805 .40933 Mdot
.62586 .6563 Mdot
.26665 .66525 Mdot
.61695 .40262 Mdot
.4565 .30647 Mdot
.54747 .33912 Mdot
.46098 .70853 Mdot
.30235 .56984 Mdot
.44163 .74337 Mdot
.63269 .70057 Mdot
.20892 .6984 Mdot
.40102 .45431 Mdot
.64972 .50123 Mdot
.67755 .45427 Mdot
.43165 .66135 Mdot
.44721 .32834 Mdot
.35454 .28322 Mdot
.6219 .49293 Mdot
.6287 .52213 Mdot
.61527 .45236 Mdot
.26627 .6758 Mdot
.45549 .31762 Mdot
.61242 .4521 Mdot
.6769 .39754 Mdot
.67145 .43269 Mdot
.60884 .70681 Mdot
.77038 .51651 Mdot
.61442 .42485 Mdot
.69183 .84132 Mdot
.37714 .4589 Mdot
.43797 .70763 Mdot
.50629 .53665 Mdot
.48635 .63855 Mdot
.72569 .72736 Mdot
.46988 .32872 Mdot
.39633 .28538 Mdot
.45167 .68499 Mdot
.69552 .73182 Mdot
.37349 .32812 Mdot
.65407 .46882 Mdot
.61841 .48685 Mdot
.45328 .71491 Mdot
.46371 .70201 Mdot
.38995 .44947 Mdot
.57337 .44778 Mdot
.60054 .51908 Mdot
.42237 .74172 Mdot
.6356 .45804 Mdot
.56018 .28162 Mdot
.2669 .54355 Mdot
.44895 .36097 Mdot
.31404 .55165 Mdot
.26874 .54174 Mdot
.56932 .36876 Mdot
.48505 .48807 Mdot
.28052 .53588 Mdot
.26797 .56415 Mdot
.60377 .73599 Mdot
.69024 .36891 Mdot
.60646 .70559 Mdot
.41358 .49695 Mdot
.42616 .69333 Mdot
.59932 .45593 Mdot
.45038 .31391 Mdot
.81483 .57924 Mdot
.31147 .31721 Mdot
.6473 .56476 Mdot
.61034 .41275 Mdot
.43249 .69201 Mdot
.39938 .46999 Mdot
.60436 .40292 Mdot
.69738 .63761 Mdot
.62231 .46715 Mdot
.46076 .69075 Mdot
.68378 .36278 Mdot
.28679 .49434 Mdot
.33481 .54879 Mdot
.44263 .29232 Mdot
.62056 .43641 Mdot
.46562 .33948 Mdot
.27652 .53764 Mdot
.6378 .66464 Mdot
.61586 .68065 Mdot
.58197 .45639 Mdot
.46624 .59183 Mdot
.56649 .69599 Mdot
.65401 .46573 Mdot
.64347 .43381 Mdot
.37545 .47625 Mdot
.64228 .43338 Mdot
.58194 .42593 Mdot
.63796 .41979 Mdot
.5801 .41903 Mdot
.32245 .52079 Mdot
.48311 .40057 Mdot
.58093 .46566 Mdot
.67784 .46611 Mdot
.27995 .5714 Mdot
.66941 .41154 Mdot
.28476 .54691 Mdot
.32928 .30967 Mdot
.28466 .53324 Mdot
.61614 .68218 Mdot
.39763 .72893 Mdot
.38977 .3116 Mdot
.48054 .35097 Mdot
.31762 .52052 Mdot
.60875 .66776 Mdot
.28938 .56118 Mdot
.41172 .71044 Mdot
.21787 .60734 Mdot
.43226 .38546 Mdot
.4579 .50865 Mdot
.69941 .3742 Mdot
.37482 .45403 Mdot
.45212 .72872 Mdot
.46579 .36275 Mdot
.26696 .50583 Mdot
.65472 .42681 Mdot
.61472 .69794 Mdot
.62683 .46453 Mdot
.29286 .5181 Mdot
.42993 .69313 Mdot
.37088 .49989 Mdot
.62217 .68884 Mdot
.22056 .69501 Mdot
.41306 .73287 Mdot
.66484 .483 Mdot
.28022 .57113 Mdot
.22313 .60281 Mdot
.28264 .54156 Mdot
.68246 .5768 Mdot
.48635 .29172 Mdot
.8009 .60893 Mdot
.43948 .34365 Mdot
.40442 .44233 Mdot
.44836 .17948 Mdot
.36581 .40118 Mdot
.45585 .34892 Mdot
.38267 .68767 Mdot
.63483 .46726 Mdot
.61562 .41598 Mdot
.61354 .5099 Mdot
.49892 .33609 Mdot
.60482 .41091 Mdot
.39891 .45663 Mdot
.48302 .4953 Mdot
.33972 .60053 Mdot
.46842 .69 Mdot
.6239 .4849 Mdot
.27369 .5536 Mdot
.31015 .51606 Mdot
.38743 .48364 Mdot
.31873 .54071 Mdot
.6441 .44666 Mdot
.43888 .34764 Mdot
.43771 .5798 Mdot
.61611 .70269 Mdot
.31724 .44756 Mdot
.57987 .63871 Mdot
.58175 .7071 Mdot
.67252 .43239 Mdot
.45103 .68204 Mdot
.43019 .81569 Mdot
.6391 .41683 Mdot
.45242 .33221 Mdot
.67638 .45824 Mdot
.62874 .41938 Mdot
.61209 .42793 Mdot
.41449 .70627 Mdot
.49998 .5363 Mdot
.63566 .45644 Mdot
.28035 .53461 Mdot
.44685 .55266 Mdot
.57912 .41245 Mdot
.36759 .61438 Mdot
.46386 .60935 Mdot
.37287 .45695 Mdot
.40809 .31591 Mdot
.45477 .69572 Mdot
.44272 .34017 Mdot
.49436 .34603 Mdot
.4751 .33615 Mdot
.36919 .58543 Mdot
.53178 .30205 Mdot
.58035 .85034 Mdot
.69981 .30568 Mdot
.69487 .36414 Mdot
.46536 .30364 Mdot
.31549 .66103 Mdot
.4593 .34687 Mdot
.47325 .33311 Mdot
.46417 .88866 Mdot
.44739 .30916 Mdot
.60556 .44982 Mdot
.61213 .49372 Mdot
.41498 .23416 Mdot
.61492 .73542 Mdot
.647 .47282 Mdot
.59606 .41624 Mdot
.60331 .65702 Mdot
.52262 .38563 Mdot
.39429 .44651 Mdot
.47565 .46907 Mdot
.40882 .45518 Mdot
.62179 .45352 Mdot
.59173 .46566 Mdot
.56726 .4446 Mdot
.49482 .15365 Mdot
.79586 .63076 Mdot
.41731 .33036 Mdot
.692 .43526 Mdot
.35876 .48537 Mdot
.66953 .46785 Mdot
.67658 .4483 Mdot
.62285 .43216 Mdot
.45357 .68743 Mdot
.42376 .29926 Mdot
.67564 .5009 Mdot
.34996 .44978 Mdot
.60182 .4748 Mdot
.571 .65708 Mdot
.64738 .67631 Mdot
.61043 .45996 Mdot
.44524 .30769 Mdot
.61207 .41453 Mdot
.48234 .33724 Mdot
.45443 .35986 Mdot
.61015 .51701 Mdot
.38689 .55966 Mdot
.43429 .29517 Mdot
.65362 .47094 Mdot
.45124 .72578 Mdot
.30799 .44028 Mdot
.61086 .46671 Mdot
.63014 .69025 Mdot
.59834 .43397 Mdot
.61418 .70872 Mdot
.63258 .42926 Mdot
.39006 .48108 Mdot
.5275 .21817 Mdot
.43109 .68291 Mdot
.58899 .71715 Mdot
.45763 .7216 Mdot
.56393 .48799 Mdot
.46663 .30769 Mdot
.33855 .49325 Mdot
.77945 .66168 Mdot
.37536 .47506 Mdot
.71806 .67521 Mdot
.43678 .54886 Mdot
.28455 .56985 Mdot
.46421 .37549 Mdot
.65872 .35938 Mdot
.38044 .61201 Mdot
.46174 .6727 Mdot
.41567 .67377 Mdot
.48031 .78918 Mdot
.39149 .84031 Mdot
.63866 .45798 Mdot
.28118 .61461 Mdot
.56409 .25127 Mdot
.65351 .37948 Mdot
.60061 .39035 Mdot
.40608 .73108 Mdot
.64746 .47234 Mdot
.55481 .5663 Mdot
.42185 .70434 Mdot
.60282 .67996 Mdot
.47052 .34596 Mdot
.6208 .65847 Mdot
.28522 .3162 Mdot
.41304 .47949 Mdot
.42476 .71167 Mdot
.57801 .4191 Mdot
.63868 .47976 Mdot
.45088 .37474 Mdot
.68584 .25519 Mdot
.45205 .36256 Mdot
.62424 .70167 Mdot
.42152 .68675 Mdot
.81139 .46791 Mdot
.60286 .43157 Mdot
.42991 .32625 Mdot
.38236 .69377 Mdot
.58993 .44619 Mdot
.29909 .56939 Mdot
.61393 .412 Mdot
.42767 .32708 Mdot
.64169 .43285 Mdot
.44096 .34772 Mdot
.43745 .73219 Mdot
.5857 .46469 Mdot
.58693 .46022 Mdot
.71605 .66536 Mdot
.61655 .67277 Mdot
.4612 .30465 Mdot
.55702 .56615 Mdot
.63218 .40623 Mdot
.69479 .62909 Mdot
.62299 .43674 Mdot
.70225 .38787 Mdot
.63338 .39909 Mdot
.397 .4551 Mdot
.67756 .45061 Mdot
.61222 .46722 Mdot
.70885 .28731 Mdot
.69351 .29079 Mdot
.65991 .36893 Mdot
.32792 .54278 Mdot
.43002 .31748 Mdot
.41961 .71032 Mdot
.46878 .70739 Mdot
.44795 .69683 Mdot
.65259 .70055 Mdot
.69089 .4269 Mdot
.61113 .47169 Mdot
.30571 .59208 Mdot
.60808 .68344 Mdot
.4361 .3224 Mdot
.6142 .68656 Mdot
.48769 .48709 Mdot
.63273 .68563 Mdot
.40197 .45819 Mdot
.23022 .64794 Mdot
.56173 .29515 Mdot
.62906 .6734 Mdot
.45283 .36187 Mdot
.44589 .53393 Mdot
.68562 .47216 Mdot
.23755 .45545 Mdot
.59361 .68823 Mdot
.45777 .79795 Mdot
.64427 .45427 Mdot
.52006 .54372 Mdot
.28748 .54378 Mdot
.62011 .65876 Mdot
.3116 .53162 Mdot
.61382 .41463 Mdot
.49418 .39355 Mdot
.4557 .32766 Mdot
.26798 .54947 Mdot
.66675 .42845 Mdot
.6195 .65845 Mdot
.42868 .71514 Mdot
.68683 .36608 Mdot
.27775 .57291 Mdot
.70624 .7103 Mdot
.69257 .63861 Mdot
.41982 .68937 Mdot
.71405 .36546 Mdot
.29712 .52995 Mdot
.68869 .45679 Mdot
.6466 .54026 Mdot
.63154 .41279 Mdot
.44406 .67271 Mdot
.441 .7183 Mdot
.39496 .4172 Mdot
.59144 .46746 Mdot
.58798 .47545 Mdot
.41494 .31391 Mdot
.41664 .68973 Mdot
.47602 .33695 Mdot
.46041 .37184 Mdot
.45342 .71675 Mdot
.46226 .3646 Mdot
.63759 .68379 Mdot
.55862 .55099 Mdot
.29404 .53009 Mdot
.29429 .56952 Mdot
.42531 .71457 Mdot
.41544 .68316 Mdot
.44957 .68018 Mdot
.65939 .42459 Mdot
.47389 .35786 Mdot
.66498 .44554 Mdot
.61658 .43448 Mdot
.4311 .27434 Mdot
.4107 .32858 Mdot
.67152 .44558 Mdot
.42366 .57886 Mdot
.59921 .70481 Mdot
.44232 .71022 Mdot
.31585 .52598 Mdot
.71959 .70523 Mdot
.28431 .57212 Mdot
.62485 .40605 Mdot
.25627 .43808 Mdot
.45075 .31603 Mdot
.62273 .681 Mdot
.46428 .61511 Mdot
.62302 .68629 Mdot
.26727 .54495 Mdot
.41257 .34468 Mdot
.45903 .45049 Mdot
.59059 .46759 Mdot
.49399 .51016 Mdot
.73873 .60546 Mdot
.33882 .43402 Mdot
.31566 .52305 Mdot
.60402 .41375 Mdot
.37541 .46971 Mdot
.51202 .27402 Mdot
.61432 .47348 Mdot
.65742 .41373 Mdot
.50153 .66648 Mdot
.67893 .44905 Mdot
.4194 .35812 Mdot
.45892 .60218 Mdot
.57413 .43562 Mdot
.56449 .4867 Mdot
.4326 .85376 Mdot
.64847 .46243 Mdot
.58467 .45841 Mdot
.60067 .44579 Mdot
.65529 .4251 Mdot
.48344 .33623 Mdot
.4981 .70198 Mdot
.27288 .54621 Mdot
.55947 .55172 Mdot
.30568 .52823 Mdot
.43141 .72286 Mdot
.5437 .57501 Mdot
.48319 .33841 Mdot
.62359 .68646 Mdot
.26955 .61553 Mdot
.62641 .58026 Mdot
.44037 .73335 Mdot
.74061 .67226 Mdot
.59897 .6977 Mdot
.68618 .47118 Mdot
.63791 .69606 Mdot
.40117 .72525 Mdot
.29257 .56682 Mdot
.64381 .49704 Mdot
.47144 .32379 Mdot
.42745 .34624 Mdot
.61668 .41056 Mdot
.31377 .45375 Mdot
.31549 .56616 Mdot
.65987 .64709 Mdot
.63253 .47627 Mdot
.65143 .4107 Mdot
.45461 .36428 Mdot
.43682 .69163 Mdot
.43858 .54953 Mdot
.61408 .66856 Mdot
.65211 .489 Mdot
.60695 .41735 Mdot
.48862 .48985 Mdot
.31898 .51985 Mdot
.38929 .46789 Mdot
.61671 .47941 Mdot
.47711 .48085 Mdot
.60331 .41041 Mdot
.56143 .44945 Mdot
.45754 .71599 Mdot
.62177 .52093 Mdot
.60493 .48206 Mdot
.48935 .39257 Mdot
.30132 .53052 Mdot
.44818 .33242 Mdot
.4203 .27728 Mdot
.3839 .48183 Mdot
.30733 .5409 Mdot
.671 .44148 Mdot
.27369 .52195 Mdot
.62173 .41763 Mdot
.63213 .45563 Mdot
.31758 .52388 Mdot
.47701 .34658 Mdot
.35337 .30695 Mdot
.48345 .40053 Mdot
.65222 .42983 Mdot
.59583 .43621 Mdot
.61314 .73493 Mdot
.82272 .58821 Mdot
.60058 .47981 Mdot
.46973 .36205 Mdot
.58893 .44561 Mdot
.28358 .56671 Mdot
.62785 .69873 Mdot
.45456 .33777 Mdot
.41093 .69979 Mdot
.43305 .7318 Mdot
.40756 .66014 Mdot
.40207 .45602 Mdot
.57525 .4521 Mdot
.41468 .35762 Mdot
.41228 .32781 Mdot
.53515 .53046 Mdot
.43857 .70861 Mdot
.63151 .69615 Mdot
.64822 .475 Mdot
.56136 .38239 Mdot
.27048 .53638 Mdot
.71541 .82016 Mdot
.46024 .45638 Mdot
.64211 .70624 Mdot
.51979 .59493 Mdot
.37723 .47303 Mdot
.64472 .46656 Mdot
.61551 .65661 Mdot
.43919 .72631 Mdot
.61424 .4157 Mdot
.65927 .39515 Mdot
.38032 .61877 Mdot
.41689 .67832 Mdot
.26867 .53331 Mdot
.4168 .72703 Mdot
.60938 .70858 Mdot
.40142 .45849 Mdot
.42291 .34067 Mdot
.61581 .46521 Mdot
.60009 .52228 Mdot
.43399 .6986 Mdot
.37111 .48135 Mdot
.57941 .44294 Mdot
.42453 .32461 Mdot
.44419 .70315 Mdot
.61892 .44839 Mdot
.5157 .28193 Mdot
.39071 .30928 Mdot
.42278 .69257 Mdot
.65182 .48701 Mdot
.53913 .45511 Mdot
.41578 .6773 Mdot
.39833 .71347 Mdot
.59911 .41387 Mdot
.61562 .6604 Mdot
.60379 .47955 Mdot
.28155 .55015 Mdot
.49896 .53651 Mdot
.31062 .54993 Mdot
.69984 .63751 Mdot
.56534 .43395 Mdot
.70931 .51255 Mdot
.4796 .36636 Mdot
.58301 .69175 Mdot
.75508 .32408 Mdot
.6328 .40513 Mdot
.36288 .24167 Mdot
.50716 .55334 Mdot
.45762 .48298 Mdot
.32788 .25486 Mdot
.62252 .66713 Mdot
.28952 .55943 Mdot
.58057 .44558 Mdot
.24221 .5834 Mdot
.62715 .66612 Mdot
.70011 .63656 Mdot
.66454 .46637 Mdot
.44561 .31995 Mdot
.6322 .47403 Mdot
.42577 .32717 Mdot
.59319 .44722 Mdot
.51855 .32879 Mdot
.5662 .66654 Mdot
.68363 .57524 Mdot
.68295 .48135 Mdot
.22185 .59422 Mdot
.69887 .37265 Mdot
.62656 .69634 Mdot
.64751 .42957 Mdot
.38326 .47301 Mdot
.3212 .56001 Mdot
.27087 .62969 Mdot
.45065 .68322 Mdot
.28402 .53116 Mdot
.46415 .35853 Mdot
.40856 .73923 Mdot
.37245 .48053 Mdot
.68352 .49985 Mdot
.61696 .65826 Mdot
.30512 .53818 Mdot
.61197 .46468 Mdot
.64261 .413 Mdot
.26535 .67595 Mdot
.80865 .44692 Mdot
.46542 .36713 Mdot
.29115 .775 Mdot
.42026 .36456 Mdot
.60975 .67552 Mdot
.45917 .71047 Mdot
.6142 .44013 Mdot
.60599 .47432 Mdot
.42132 .6772 Mdot
.43611 .36773 Mdot
.57989 .68296 Mdot
.806 .60354 Mdot
.25763 .53645 Mdot
.743 .54041 Mdot
.45707 .33787 Mdot
.74001 .54314 Mdot
.64154 .64778 Mdot
.36389 .52539 Mdot
.77793 .45685 Mdot
.30751 .56474 Mdot
.74627 .5378 Mdot
.43797 .31888 Mdot
.64041 .45972 Mdot
.38625 .45941 Mdot
.37863 .45895 Mdot
.46654 .34572 Mdot
.45505 .70972 Mdot
.59752 .68248 Mdot
.62928 .47483 Mdot
.68607 .50919 Mdot
.67531 .24261 Mdot
.41378 .68821 Mdot
.62754 .51427 Mdot
.32015 .55474 Mdot
.59107 .44184 Mdot
.61085 .65289 Mdot
.29887 .56363 Mdot
.4002 .47449 Mdot
.62063 .57961 Mdot
.6416 .48958 Mdot
.46628 .59996 Mdot
.2934 .54064 Mdot
.8244 .58089 Mdot
.5875 .46048 Mdot
.2976 .52996 Mdot
.60011 .52143 Mdot
.32817 .48307 Mdot
.4419 .56974 Mdot
.3644 .39776 Mdot
.46894 .72338 Mdot
.42441 .73255 Mdot
.84056 .46012 Mdot
.60513 .61877 Mdot
.28577 .52632 Mdot
.40259 .46306 Mdot
.78118 .49778 Mdot
.31203 .53512 Mdot
.64615 .49324 Mdot
.62725 .43954 Mdot
.68356 .36252 Mdot
.57004 .38247 Mdot
.38808 .4493 Mdot
.70584 .45613 Mdot
.64697 .44449 Mdot
.66137 .51147 Mdot
.58537 .43573 Mdot
.42169 .32024 Mdot
.31213 .56217 Mdot
.26631 .24186 Mdot
.28379 .51466 Mdot
.6732 .53519 Mdot
.42645 .6932 Mdot
.45993 .73569 Mdot
.61132 .45948 Mdot
.72242 .50795 Mdot
.15539 .47584 Mdot
.60665 .42892 Mdot
.4644 .61451 Mdot
.69371 .64098 Mdot
.68973 .44843 Mdot
.44983 .30035 Mdot
.60605 .52064 Mdot
.43971 .38524 Mdot
.29876 .56464 Mdot
.62435 .66707 Mdot
.5904 .69089 Mdot
.28647 .55424 Mdot
.60388 .47069 Mdot
.58978 .6778 Mdot
.61913 .45917 Mdot
.64144 .47484 Mdot
.48159 .47626 Mdot
.63835 .66113 Mdot
.4514 .68076 Mdot
.61794 .68187 Mdot
.46681 .32461 Mdot
.46883 .90037 Mdot
.61547 .69341 Mdot
.68998 .36855 Mdot
.53455 .5572 Mdot
.74706 .54126 Mdot
.42958 .35122 Mdot
.61988 .70329 Mdot
.30699 .56685 Mdot
.45142 .4397 Mdot
.70374 .36299 Mdot
.28388 .57152 Mdot
.61414 .47584 Mdot
.48422 .34457 Mdot
.41578 .32588 Mdot
.33483 .54296 Mdot
.43287 .36178 Mdot
.66348 .49815 Mdot
.65306 .47636 Mdot
.27847 .53384 Mdot
.56691 .17194 Mdot
.30184 .57079 Mdot
.57936 .36589 Mdot
.62666 .43287 Mdot
.45325 .33489 Mdot
.70457 .3903 Mdot
.43645 .28141 Mdot
.38788 .45267 Mdot
.61621 .49285 Mdot
.62005 .69739 Mdot
.55018 .54995 Mdot
.42364 .69073 Mdot
.26005 .43393 Mdot
.42696 .33977 Mdot
.32827 .51971 Mdot
.42679 .35356 Mdot
.45001 .37206 Mdot
.27097 .55719 Mdot
.45626 .32246 Mdot
.60187 .47434 Mdot
.23349 .35854 Mdot
.43107 .34644 Mdot
.29578 .54754 Mdot
.61163 .69974 Mdot
.4642 .36347 Mdot
.66958 .68266 Mdot
.63986 .48215 Mdot
.43732 .73963 Mdot
.60842 .72278 Mdot
.4799 .37078 Mdot
.6291 .69599 Mdot
.4373 .70213 Mdot
.59767 .67731 Mdot
.26056 .58981 Mdot
.34 .53254 Mdot
.65505 .56055 Mdot
.31074 .48764 Mdot
.45646 .31416 Mdot
.46276 .73914 Mdot
.63451 .49147 Mdot
.63554 .47655 Mdot
.6012 .70944 Mdot
.41967 .31989 Mdot
.304 .46074 Mdot
.73272 .45514 Mdot
.31856 .44822 Mdot
.32718 .53113 Mdot
.67865 .7188 Mdot
.45842 .45386 Mdot
.24158 .55043 Mdot
.60343 .49512 Mdot
.37758 .47167 Mdot
.61449 .45172 Mdot
.69874 .65763 Mdot
.60344 .70393 Mdot
.29771 .70484 Mdot
.56118 .43093 Mdot
.42732 .67696 Mdot
.59641 .44269 Mdot
.31212 .61636 Mdot
.56151 .47683 Mdot
.59337 .69107 Mdot
.27612 .51471 Mdot
.48055 .35105 Mdot
.60943 .70316 Mdot
.4363 .73159 Mdot
.74928 .50286 Mdot
.64427 .49314 Mdot
.64718 .44863 Mdot
.40861 .67994 Mdot
.47405 .33081 Mdot
.43498 .72131 Mdot
.29488 .52986 Mdot
.61569 .69064 Mdot
.66122 .43152 Mdot
.64168 .51639 Mdot
.42761 .66209 Mdot
.28506 .5184 Mdot
.43272 .66936 Mdot
.27413 .5224 Mdot
.37828 .46786 Mdot
.57259 .42895 Mdot
.40719 .67796 Mdot
.57785 .46805 Mdot
.66805 .27781 Mdot
.57812 .55797 Mdot
.73879 .3374 Mdot
.45274 .68134 Mdot
.55848 .66761 Mdot
.29123 .55497 Mdot
.30395 .53512 Mdot
.58226 .36069 Mdot
.16428 .49681 Mdot
.44457 .54859 Mdot
.20613 .61139 Mdot
.29347 .53006 Mdot
.29879 .53996 Mdot
.44599 .71904 Mdot
.47062 .33237 Mdot
.49344 .35284 Mdot
.39446 .71255 Mdot
.66815 .60895 Mdot
.43583 .32237 Mdot
.38399 .23139 Mdot
.4048 .71153 Mdot
.61857 .49958 Mdot
.40694 .48108 Mdot
.59344 .68998 Mdot
.68315 .63626 Mdot
.22101 .61307 Mdot
.61043 .44376 Mdot
.53389 .85389 Mdot
.45241 .68979 Mdot
.42109 .48642 Mdot
.3422 .57862 Mdot
.65017 .41351 Mdot
.59742 .44667 Mdot
.5931 .46181 Mdot
.6297 .71586 Mdot
.66709 .2537 Mdot
.61309 .4424 Mdot
.65705 .58547 Mdot
.59422 .40494 Mdot
.2503 .67599 Mdot
.61771 .68209 Mdot
.77535 .61598 Mdot
.43645 .75191 Mdot
.33903 .45779 Mdot
.66913 .42755 Mdot
.28798 .5344 Mdot
.39567 .59952 Mdot
.30812 .51982 Mdot
.35686 .55489 Mdot
.78749 .47396 Mdot
.42499 .31412 Mdot
.61613 .41146 Mdot
.40263 .70848 Mdot
.48448 .35705 Mdot
.40673 .59145 Mdot
.44608 .88921 Mdot
.33197 .53355 Mdot
.28253 .79293 Mdot
.31308 .54439 Mdot
.37995 .45665 Mdot
.46233 .35755 Mdot
.738 .49335 Mdot
.49196 .50406 Mdot
.47632 .33878 Mdot
.54818 .78275 Mdot
.47456 .38408 Mdot
.72848 .53722 Mdot
.42784 .38542 Mdot
.29664 .55406 Mdot
.33093 .52012 Mdot
.64726 .39489 Mdot
.61437 .4877 Mdot
.49143 .51407 Mdot
.59655 .38765 Mdot
.63974 .48921 Mdot
.42161 .70411 Mdot
.2782 .49447 Mdot
.24029 .58359 Mdot
.46139 .33756 Mdot
.2755 .52907 Mdot
.59728 .4439 Mdot
.65223 .43019 Mdot
.67331 .47305 Mdot
.70014 .72946 Mdot
.38232 .23056 Mdot
.63353 .4541 Mdot
.56551 .48228 Mdot
.44528 .73044 Mdot
.26582 .6777 Mdot
.30799 .77758 Mdot
.78428 .48397 Mdot
.57945 .43847 Mdot
.61608 .67482 Mdot
.60627 .65417 Mdot
.67121 .48486 Mdot
.70001 .52899 Mdot
.66395 .72448 Mdot
.61172 .46477 Mdot
.71484 .53797 Mdot
.45256 .66469 Mdot
.37693 .48372 Mdot
.43413 .69921 Mdot
.4831 .36546 Mdot
.37434 .47334 Mdot
.41946 .71799 Mdot
.64295 .58895 Mdot
.3885 .47946 Mdot
.32999 .48092 Mdot
.6223 .70277 Mdot
.58306 .44351 Mdot
.41458 .39387 Mdot
.41413 .69165 Mdot
.2974 .53736 Mdot
.44836 .34924 Mdot
.32322 .55845 Mdot
.2365 .66456 Mdot
.67273 .61539 Mdot
.39953 .45364 Mdot
.28557 .53589 Mdot
.46287 .58428 Mdot
.6152 .67647 Mdot
.31697 .54265 Mdot
.71437 .50874 Mdot
.57186 .41655 Mdot
.18106 .38923 Mdot
.65153 .45011 Mdot
.39279 .40617 Mdot
.2948 .53502 Mdot
.40212 .4744 Mdot
.61762 .46585 Mdot
.41568 .73448 Mdot
.69341 .45849 Mdot
.62073 .45902 Mdot
.40973 .71502 Mdot
.63693 .45543 Mdot
.6276 .65448 Mdot
.44513 .38474 Mdot
.5183 .55823 Mdot
.69405 .70506 Mdot
.59848 .69031 Mdot
.51978 .5066 Mdot
.60249 .4819 Mdot
.51663 .76118 Mdot
.4458 .32167 Mdot
.63179 .40558 Mdot
.71524 .64145 Mdot
.46899 .33723 Mdot
.44166 .34005 Mdot
.64811 .4356 Mdot
.29902 .57268 Mdot
.43978 .67238 Mdot
.61645 .67788 Mdot
.23026 .56512 Mdot
.61892 .44645 Mdot
.60333 .41341 Mdot
.60125 .69975 Mdot
.30503 .54084 Mdot
.66508 .43591 Mdot
.30706 .39012 Mdot
.55061 .54058 Mdot
.26972 .53408 Mdot
.5781 .41313 Mdot
.27841 .26946 Mdot
.49177 .36527 Mdot
.5447 .85434 Mdot
.57041 .65236 Mdot
.45582 .71494 Mdot
.61247 .51176 Mdot
.65232 .86858 Mdot
.6208 .70183 Mdot
.33675 .44665 Mdot
.63891 .46273 Mdot
.61264 .43666 Mdot
.43143 .31117 Mdot
.66825 .45016 Mdot
.43642 .31463 Mdot
.68455 .72276 Mdot
.16331 .51332 Mdot
.43411 .36173 Mdot
.43071 .31948 Mdot
.55287 .42585 Mdot
.70341 .73406 Mdot
.46951 .34968 Mdot
.64439 .49274 Mdot
.53589 .76175 Mdot
.65931 .3922 Mdot
.64531 .67008 Mdot
.64955 .73708 Mdot
.45307 .30091 Mdot
.69147 .3511 Mdot
.55332 .42551 Mdot
.53065 .33965 Mdot
.66501 .69903 Mdot
.29431 .52477 Mdot
.62607 .42255 Mdot
.40364 .45958 Mdot
.44557 .70742 Mdot
.63602 .52872 Mdot
.5855 .45543 Mdot
.45991 .30985 Mdot
.62834 .71375 Mdot
.31503 .5359 Mdot
.5876 .42501 Mdot
.42855 .65883 Mdot
.60598 .67289 Mdot
.43723 .35363 Mdot
.64308 .36 Mdot
.59121 .67695 Mdot
.63536 .51667 Mdot
.64142 .45605 Mdot
.58348 .42859 Mdot
.67719 .38949 Mdot
.28638 .55118 Mdot
.39948 .72702 Mdot
.62015 .51195 Mdot
.46568 .45432 Mdot
.58196 .56736 Mdot
.65196 .49581 Mdot
.46804 .36259 Mdot
.32611 .53141 Mdot
.39714 .46597 Mdot
.76287 .52682 Mdot
.63618 .44337 Mdot
.37535 .23113 Mdot
.76326 .66801 Mdot
.38922 .47659 Mdot
.48528 .33444 Mdot
.62196 .68196 Mdot
.63884 .43651 Mdot
.66413 .58569 Mdot
.65045 .48627 Mdot
.68661 .40465 Mdot
.45717 .704 Mdot
.30536 .52389 Mdot
.61034 .55513 Mdot
.44512 .71051 Mdot
.44236 .34011 Mdot
.41166 .23034 Mdot
.49065 .36032 Mdot
.45878 .37128 Mdot
.38404 .55628 Mdot
.28517 .56221 Mdot
.66765 .86005 Mdot
.82085 .60455 Mdot
.62198 .49788 Mdot
.2767 .5544 Mdot
.46288 .35301 Mdot
.67389 .45695 Mdot
.44746 .31454 Mdot
.43122 .29702 Mdot
.64632 .48007 Mdot
.64343 .48395 Mdot
.68746 .56876 Mdot
.38917 .23321 Mdot
.61428 .69751 Mdot
.42302 .35245 Mdot
.55834 .35591 Mdot
.61782 .44155 Mdot
.59734 .47328 Mdot
.38965 .60323 Mdot
.61312 .70452 Mdot
.54328 .27066 Mdot
.6362 .4733 Mdot
.72248 .66834 Mdot
.62502 .49401 Mdot
.49288 .33348 Mdot
.31724 .57794 Mdot
.68659 .5302 Mdot
.44892 .67477 Mdot
.45985 .37651 Mdot
.60715 .71022 Mdot
.41482 .29868 Mdot
.55068 .30835 Mdot
.29479 .56615 Mdot
.42793 .32639 Mdot
.41839 .7453 Mdot
.30646 .54897 Mdot
.29788 .5709 Mdot
.41162 .58789 Mdot
.4251 .74505 Mdot
.63825 .70833 Mdot
.32267 .53866 Mdot
.51614 .28423 Mdot
.29936 .55439 Mdot
.54538 .30188 Mdot
.57946 .45809 Mdot
.6538 .58582 Mdot
.66693 .52896 Mdot
.64525 .39153 Mdot
.31514 .55556 Mdot
.59969 .67965 Mdot
.66424 .43014 Mdot
.43972 .36656 Mdot
.60592 .69074 Mdot
.40917 .48388 Mdot
.45145 .74441 Mdot
.41752 .31848 Mdot
.26974 .5248 Mdot
.44706 .31087 Mdot
.68995 .63909 Mdot
.57739 .6885 Mdot
.40336 .60533 Mdot
.49918 .51522 Mdot
.66725 .50642 Mdot
.55519 .46594 Mdot
.66077 .42356 Mdot
.60003 .47038 Mdot
.4231 .69338 Mdot
.65178 .70067 Mdot
.46392 .36397 Mdot
.66746 .23 Mdot
.28616 .53915 Mdot
.46182 .59908 Mdot
.69149 .41384 Mdot
.61938 .41669 Mdot
.45835 .3519 Mdot
.42314 .29859 Mdot
.69532 .29112 Mdot
.42426 .6744 Mdot
.65081 .38892 Mdot
.67803 .43799 Mdot
.56362 .53231 Mdot
.3128 .55549 Mdot
.34109 .36824 Mdot
.46815 .69368 Mdot
.30831 .82028 Mdot
.4423 .71179 Mdot
.51708 .69726 Mdot
.45771 .32277 Mdot
.63401 .68768 Mdot
.61723 .48117 Mdot
.51572 .39284 Mdot
.47929 .32473 Mdot
.44439 .76021 Mdot
.62561 .68816 Mdot
.35532 .33357 Mdot
.2768 .54339 Mdot
.57714 .43256 Mdot
.62955 .49482 Mdot
.66009 .4401 Mdot
.67044 .46271 Mdot
.27674 .53326 Mdot
.65301 .48212 Mdot
.27429 .56995 Mdot
.55805 .30374 Mdot
.71724 .63333 Mdot
.39977 .7076 Mdot
.27733 .68949 Mdot
.45584 .37108 Mdot
.46335 .22952 Mdot
.5544 .28092 Mdot
.57717 .55745 Mdot
.27262 .59294 Mdot
.57261 .43768 Mdot
.45421 .70919 Mdot
.23002 .59775 Mdot
.40036 .71096 Mdot
.19489 .31918 Mdot
.68704 .36413 Mdot
.37653 .37347 Mdot
.66351 .4533 Mdot
.40172 .68483 Mdot
.66261 .33897 Mdot
.63631 .51811 Mdot
.5874 .67978 Mdot
.53718 .30901 Mdot
.42089 .40811 Mdot
.62961 .69873 Mdot
.64304 .47823 Mdot
.41013 .32939 Mdot
.61128 .47784 Mdot
.62507 .48338 Mdot
.6053 .42809 Mdot
.30556 .58452 Mdot
.59468 .48024 Mdot
.60558 .48034 Mdot
.81143 .45375 Mdot
.4427 .6229 Mdot
.43189 .73624 Mdot
.73195 .32633 Mdot
.60797 .68382 Mdot
.48247 .36555 Mdot
.50685 .55101 Mdot
.27979 .5463 Mdot
.69742 .29309 Mdot
.65674 .4478 Mdot
.32568 .42623 Mdot
.31383 .51353 Mdot
.61488 .66342 Mdot
.39861 .46847 Mdot
.33595 .33347 Mdot
.46201 .69773 Mdot
.39649 .44709 Mdot
.42429 .68912 Mdot
.75157 .35464 Mdot
.4321 .31719 Mdot
.66645 .50696 Mdot
.31709 .53431 Mdot
.40633 .73095 Mdot
.66206 .58388 Mdot
.58725 .45044 Mdot
.45235 .68056 Mdot
.65092 .52729 Mdot
.5572 .55772 Mdot
.50265 .54661 Mdot
.40606 .73477 Mdot
.30411 .50937 Mdot
.30883 .55385 Mdot
.63293 .69829 Mdot
.4711 .37504 Mdot
.47055 .32416 Mdot
.30394 .5574 Mdot
.43149 .83717 Mdot
.61703 .44666 Mdot
.62534 .44127 Mdot
.46157 .44952 Mdot
.67576 .45423 Mdot
.5977 .72755 Mdot
.37094 .46689 Mdot
.47222 .32221 Mdot
.66262 .42619 Mdot
.66498 .43651 Mdot
.64448 .45761 Mdot
.67511 .60878 Mdot
.43511 .69706 Mdot
.6458 .44356 Mdot
.61549 .65758 Mdot
.42339 .45084 Mdot
.6308 .49178 Mdot
.64892 .51712 Mdot
.43956 .31336 Mdot
.47222 .78677 Mdot
.29325 .53743 Mdot
.41819 .68456 Mdot
.4049 .69896 Mdot
.73537 .59832 Mdot
.48645 .30695 Mdot
.38772 .44889 Mdot
.24851 .65412 Mdot
.40062 .4624 Mdot
.62881 .68749 Mdot
.4401 .56216 Mdot
.47448 .68099 Mdot
.42562 .73371 Mdot
.30833 .50412 Mdot
.62984 .409 Mdot
.63555 .49249 Mdot
.33381 .45642 Mdot
.6113 .43073 Mdot
.62029 .69832 Mdot
.29456 .5756 Mdot
.43226 .31959 Mdot
.60965 .65435 Mdot
.30706 .53565 Mdot
.47584 .33453 Mdot
.64866 .40602 Mdot
.65219 .49075 Mdot
.44505 .34729 Mdot
.43568 .35455 Mdot
.60487 .45392 Mdot
.80588 .43127 Mdot
.47755 .33058 Mdot
.45213 .35395 Mdot
.42214 .43219 Mdot
.45868 .71757 Mdot
.64541 .37333 Mdot
.27944 .55847 Mdot
.60058 .47456 Mdot
.3997 .70015 Mdot
.62988 .67715 Mdot
.43542 .34103 Mdot
.62621 .42494 Mdot
.62571 .45165 Mdot
.61769 .67544 Mdot
.63549 .65443 Mdot
.60652 .69977 Mdot
.31908 .57244 Mdot
.65383 .47069 Mdot
.46862 .35418 Mdot
.27653 .54242 Mdot
.5944 .67033 Mdot
.63908 .6955 Mdot
.7916 .43514 Mdot
.60944 .4459 Mdot
.59491 .66179 Mdot
.50884 .91198 Mdot
.75659 .50013 Mdot
.37262 .47508 Mdot
.44904 .65875 Mdot
.56094 .68339 Mdot
.60497 .72088 Mdot
.297 .52122 Mdot
.4614 .60955 Mdot
.62354 .71078 Mdot
.61392 .42629 Mdot
.59221 .43438 Mdot
.60125 .49642 Mdot
.60514 .68648 Mdot
.678 .61839 Mdot
.41493 .33819 Mdot
.56828 .23485 Mdot
.60803 .68404 Mdot
.41332 .739 Mdot
.42328 .66223 Mdot
.44108 .71676 Mdot
.57851 .42415 Mdot
.72964 .304 Mdot
.56268 .33293 Mdot
.54173 .26272 Mdot
.28028 .53751 Mdot
.42349 .29889 Mdot
.37338 .50091 Mdot
.44096 .33978 Mdot
.44659 .69396 Mdot
.60414 .67378 Mdot
.43043 .311 Mdot
.29753 .57032 Mdot
.31004 .55613 Mdot
.44178 .66881 Mdot
.43608 .7046 Mdot
.42641 .71324 Mdot
.46486 .37602 Mdot
.457 .32246 Mdot
.65967 .43283 Mdot
.43207 .34124 Mdot
.76805 .67314 Mdot
.57851 .71203 Mdot
.4308 .66527 Mdot
.29044 .54577 Mdot
.45013 .35839 Mdot
.58241 .44625 Mdot
.51131 .66971 Mdot
.46085 .74487 Mdot
.59588 .67549 Mdot
.20925 .42725 Mdot
.15247 .51309 Mdot
.58299 .41293 Mdot
.28509 .52012 Mdot
.70592 .52051 Mdot
.5953 .46134 Mdot
.45846 .69706 Mdot
.78656 .62368 Mdot
.39595 .47567 Mdot
.61847 .4856 Mdot
.67015 .42219 Mdot
.3072 .56811 Mdot
.50635 .54929 Mdot
.61169 .42514 Mdot
.4428 .58592 Mdot
.32407 .52078 Mdot
.46742 .69158 Mdot
.85575 .47807 Mdot
.42074 .48243 Mdot
.67749 .64641 Mdot
.37512 .48028 Mdot
.61475 .42973 Mdot
.42129 .70162 Mdot
.60419 .66235 Mdot
.42766 .70351 Mdot
.48749 .34024 Mdot
.46108 .70794 Mdot
.58922 .43078 Mdot
.47157 .3497 Mdot
.30593 .53948 Mdot
.47224 .59558 Mdot
.75987 .39177 Mdot
.41734 .73511 Mdot
.37207 .48488 Mdot
.64169 .48469 Mdot
.49369 .25779 Mdot
.64627 .39602 Mdot
.60649 .48312 Mdot
.31466 .5222 Mdot
.46103 .34586 Mdot
.32658 .53012 Mdot
.66217 .51839 Mdot
.42897 .24681 Mdot
.28456 .54255 Mdot
.48235 .40466 Mdot
.59949 .69857 Mdot
.66776 .61092 Mdot
.62141 .47183 Mdot
.31522 .53189 Mdot
.65266 .46429 Mdot
.42149 .35015 Mdot
.61012 .57934 Mdot
.53927 .52064 Mdot
.32 .55618 Mdot
.38373 .36475 Mdot
.55982 .56735 Mdot
.60688 .37035 Mdot
.30238 .52887 Mdot
.75231 .32251 Mdot
.38628 .47215 Mdot
.61658 .66899 Mdot
.62883 .64878 Mdot
.63419 .66742 Mdot
.61293 .43285 Mdot
.51657 .31032 Mdot
.64223 .6838 Mdot
.32632 .55997 Mdot
.63866 .66622 Mdot
.70978 .71181 Mdot
.31194 .45487 Mdot
.59811 .69243 Mdot
.62601 .46967 Mdot
.63291 .53528 Mdot
.46298 .61055 Mdot
.4507 .73968 Mdot
.34473 .28372 Mdot
.80931 .45976 Mdot
.61287 .43986 Mdot
.49812 .28473 Mdot
.48337 .32021 Mdot
.54616 .64032 Mdot
.53942 .51798 Mdot
.45104 .53639 Mdot
.45022 .35628 Mdot
.50142 .53237 Mdot
.48326 .349 Mdot
.68398 .48085 Mdot
.63256 .45659 Mdot
.48021 .37423 Mdot
.24882 .434 Mdot
.72687 .27665 Mdot
.31628 .44266 Mdot
.47661 .35512 Mdot
.30172 .53059 Mdot
.29967 .51726 Mdot
.31438 .52271 Mdot
.41522 .70077 Mdot
.4247 .3352 Mdot
.638 .44229 Mdot
.44222 .7288 Mdot
.62875 .48065 Mdot
.30483 .56223 Mdot
.56273 .54731 Mdot
.43339 .31805 Mdot
.61268 .4667 Mdot
.63246 .34923 Mdot
.43014 .68823 Mdot
.61327 .67583 Mdot
.21849 .40031 Mdot
.46043 .66531 Mdot
.28479 .5122 Mdot
.4504 .2948 Mdot
.38997 .68724 Mdot
.48824 .73416 Mdot
.62321 .49927 Mdot
.63485 .49835 Mdot
.46294 .62031 Mdot
.67992 .35452 Mdot
.60682 .42288 Mdot
.43467 .73178 Mdot
.45128 .73127 Mdot
.65142 .46431 Mdot
.42528 .34721 Mdot
.63722 .70407 Mdot
.60018 .70895 Mdot
.6789 .4883 Mdot
.49666 .51808 Mdot
.65533 .58546 Mdot
.66982 .44083 Mdot
.58431 .48627 Mdot
.4258 .74754 Mdot
.37299 .4806 Mdot
.49037 .49405 Mdot
.63808 .68296 Mdot
.63995 .46649 Mdot
.67841 .24727 Mdot
.42738 .33723 Mdot
.44764 .67571 Mdot
.27304 .55399 Mdot
.59021 .67693 Mdot
.44447 .66708 Mdot
.65137 .46435 Mdot
.66524 .43644 Mdot
.31817 .53982 Mdot
.49122 .32587 Mdot
.60226 .68177 Mdot
.44342 .729 Mdot
.63397 .68943 Mdot
.45445 .32082 Mdot
.44201 .35399 Mdot
.68178 .44706 Mdot
.64059 .39076 Mdot
.40839 .72296 Mdot
.6267 .50902 Mdot
.43529 .72524 Mdot
.26495 .67607 Mdot
.27076 .53629 Mdot
.65662 .41447 Mdot
.47646 .29716 Mdot
.30542 .56078 Mdot
.606 .43936 Mdot
.4622 .62089 Mdot
.62886 .41446 Mdot
.395 .70984 Mdot
.80704 .59044 Mdot
.63157 .67042 Mdot
.55874 .50176 Mdot
.73611 .41225 Mdot
.67517 .44705 Mdot
.44845 .73709 Mdot
.53477 .3199 Mdot
.28361 .54853 Mdot
.46199 .32825 Mdot
.44863 .8078 Mdot
.29713 .54961 Mdot
.63213 .46951 Mdot
.61456 .69268 Mdot
.47971 .35593 Mdot
.386 .45637 Mdot
.47893 .50412 Mdot
.63207 .53111 Mdot
.68747 .43197 Mdot
.58645 .42488 Mdot
.20568 .60971 Mdot
.42629 .70987 Mdot
.46006 .3532 Mdot
.28641 .52107 Mdot
.28963 .56273 Mdot
.43688 .69131 Mdot
.41938 .4128 Mdot
.28055 .4366 Mdot
.54881 .90602 Mdot
.44005 .66476 Mdot
.63596 .66488 Mdot
.60446 .57642 Mdot
.44359 .71657 Mdot
.41708 .69365 Mdot
.44021 .74844 Mdot
.32537 .45809 Mdot
.47566 .35465 Mdot
.62612 .45029 Mdot
.42378 .28859 Mdot
.61463 .43095 Mdot
.66097 .6314 Mdot
.30211 .56196 Mdot
.46151 .32693 Mdot
.67137 .68136 Mdot
.56501 .48452 Mdot
.59702 .45632 Mdot
.64977 .63251 Mdot
.59213 .53792 Mdot
.75316 .53469 Mdot
.67069 .47501 Mdot
.42857 .69796 Mdot
.40128 .2803 Mdot
.62949 .5152 Mdot
.62618 .34968 Mdot
.31105 .55 Mdot
.39857 .45169 Mdot
.67384 .503 Mdot
.56941 .46796 Mdot
.47854 .35935 Mdot
.4342 .3089 Mdot
.64236 .68703 Mdot
.23278 .36539 Mdot
.31037 .54611 Mdot
.35819 .38123 Mdot
.61004 .48597 Mdot
.30357 .59692 Mdot
.79837 .61216 Mdot
.60225 .44315 Mdot
.41844 .58276 Mdot
.69607 .29243 Mdot
.61292 .41766 Mdot
.54684 .25742 Mdot
.29169 .55063 Mdot
.71687 .65256 Mdot
.66194 .47226 Mdot
.45574 .69036 Mdot
.4684 .32987 Mdot
.41703 .31922 Mdot
.60102 .66361 Mdot
.79338 .6478 Mdot
.18927 .53 Mdot
.46059 .32416 Mdot
.58877 .45662 Mdot
.29293 .53892 Mdot
.39107 .45242 Mdot
.62731 .52675 Mdot
.27738 .60881 Mdot
.42879 .33398 Mdot
.61894 .51227 Mdot
.32044 .4257 Mdot
.50261 .54114 Mdot
.39804 .21598 Mdot
.3203 .52866 Mdot
.63833 .68675 Mdot
.64129 .38028 Mdot
.2494 .65834 Mdot
.65122 .49141 Mdot
.66689 .63604 Mdot
.50088 .3389 Mdot
.62848 .69788 Mdot
.60142 .46708 Mdot
.61222 .4234 Mdot
.51562 .52438 Mdot
.63089 .64785 Mdot
.6123 .42466 Mdot
.56093 .43183 Mdot
.46238 .31942 Mdot
.37014 .46844 Mdot
.43268 .32047 Mdot
.6101 .47586 Mdot
.80531 .5657 Mdot
.421 .3322 Mdot
.3484 .29267 Mdot
.57998 .6405 Mdot
.28019 .54451 Mdot
.60445 .51405 Mdot
.58485 .46578 Mdot
.34757 .21851 Mdot
.38546 .45381 Mdot
.34651 .79749 Mdot
.40049 .68854 Mdot
.80702 .33752 Mdot
.46257 .6676 Mdot
.37654 .35425 Mdot
.43556 .61482 Mdot
.60413 .50255 Mdot
.58406 .3691 Mdot
.5328 .25621 Mdot
.31111 .59255 Mdot
.47401 .23453 Mdot
.61463 .48782 Mdot
.64263 .46191 Mdot
.44471 .72265 Mdot
.40377 .41665 Mdot
.69226 .52686 Mdot
.4909 .49645 Mdot
.61366 .66492 Mdot
.44679 .32931 Mdot
.58927 .43476 Mdot
.23211 .43222 Mdot
.41372 .73604 Mdot
.762 .42104 Mdot
.61549 .46723 Mdot
.67583 .53788 Mdot
.40766 .42487 Mdot
.30393 .53734 Mdot
.40649 .73571 Mdot
.42037 .74249 Mdot
.61809 .43159 Mdot
.27443 .54027 Mdot
.64967 .42298 Mdot
.57156 .57305 Mdot
.64004 .52471 Mdot
.62995 .68363 Mdot
.5927 .4699 Mdot
.75129 .42293 Mdot
.47036 .17667 Mdot
.5566 .44064 Mdot
.46646 .37209 Mdot
.42562 .71684 Mdot
.43985 .69841 Mdot
.47249 .32636 Mdot
.44035 .69792 Mdot
.57043 .24124 Mdot
.46282 .25397 Mdot
.62942 .68928 Mdot
.57262 .29857 Mdot
.62554 .66603 Mdot
.39945 .45221 Mdot
.60727 .44774 Mdot
.34652 .64751 Mdot
.44638 .66646 Mdot
.71895 .70558 Mdot
.30077 .55739 Mdot
.38244 .45538 Mdot
.64687 .48246 Mdot
.66385 .6663 Mdot
.45148 .69879 Mdot
.41843 .52888 Mdot
.62762 .4388 Mdot
.43345 .36482 Mdot
.61674 .41739 Mdot
.59775 .39853 Mdot
.37836 .45769 Mdot
.59501 .41583 Mdot
.30692 .53553 Mdot
.42503 .32454 Mdot
.37996 .38626 Mdot
.41403 .69291 Mdot
.63009 .48792 Mdot
.59016 .45803 Mdot
.46014 .30346 Mdot
.61536 .49488 Mdot
.28295 .53036 Mdot
.75858 .77946 Mdot
.60638 .70276 Mdot
.37365 .48134 Mdot
.28516 .31623 Mdot
.60225 .41712 Mdot
.66019 .42666 Mdot
.44038 .50657 Mdot
.68281 .25144 Mdot
.28972 .53489 Mdot
.68855 .44051 Mdot
.43964 .73564 Mdot
.60123 .6819 Mdot
.32029 .56245 Mdot
.65336 .47743 Mdot
.63601 .45185 Mdot
.62597 .69808 Mdot
.64583 .62737 Mdot
.58265 .67377 Mdot
.29116 .52462 Mdot
.47429 .26983 Mdot
.5122 .66901 Mdot
.61698 .45272 Mdot
.38316 .48886 Mdot
.45702 .34616 Mdot
.29762 .52813 Mdot
.65347 .24455 Mdot
.68513 .4772 Mdot
.26832 .53303 Mdot
.30746 .54102 Mdot
.60872 .49179 Mdot
.49012 .31288 Mdot
.4283 .29135 Mdot
.45679 .34903 Mdot
.72274 .62583 Mdot
.27179 .73667 Mdot
.42329 .71146 Mdot
.29347 .54417 Mdot
.40114 .69481 Mdot
.62014 .71131 Mdot
.57317 .56398 Mdot
.42479 .74155 Mdot
.43886 .37045 Mdot
.40172 .70235 Mdot
.64876 .42144 Mdot
.29158 .57068 Mdot
.40561 .71211 Mdot
.67321 .45574 Mdot
.56714 .45492 Mdot
.56896 .38331 Mdot
.63419 .70893 Mdot
.49979 .53177 Mdot
.6285 .47387 Mdot
.39706 .46986 Mdot
.6076 .45841 Mdot
.28027 .53184 Mdot
.47503 .60141 Mdot
.6507 .44508 Mdot
.44507 .66572 Mdot
.30377 .76527 Mdot
.45899 .72406 Mdot
.57895 .40079 Mdot
.61507 .47604 Mdot
.61553 .44959 Mdot
.64527 .48197 Mdot
.41693 .40488 Mdot
.26956 .52252 Mdot
.68118 .40091 Mdot
.42513 .67069 Mdot
.43992 .3426 Mdot
.41918 .33369 Mdot
.44221 .52971 Mdot
.39886 .44764 Mdot
.27437 .54884 Mdot
.6166 .44848 Mdot
.41886 .53187 Mdot
.46764 .48869 Mdot
.31525 .43389 Mdot
.39816 .6682 Mdot
.42238 .73296 Mdot
.45722 .37392 Mdot
.414 .7208 Mdot
.65201 .48072 Mdot
.61447 .50996 Mdot
.37768 .38038 Mdot
.27656 .58109 Mdot
.60227 .67872 Mdot
.62269 .48058 Mdot
.67304 .59623 Mdot
.44529 .73039 Mdot
.42497 .74656 Mdot
.65243 .42568 Mdot
.47996 .30955 Mdot
.51951 .14728 Mdot
.27819 .55947 Mdot
.49486 .26259 Mdot
.39877 .35282 Mdot
.55152 .52507 Mdot
.2868 .55611 Mdot
.42897 .57821 Mdot
.45816 .73516 Mdot
.82056 .54279 Mdot
.44232 .34757 Mdot
.60316 .67914 Mdot
.66398 .47987 Mdot
.43981 .37095 Mdot
.41043 .67392 Mdot
.48185 .3373 Mdot
.66485 .50903 Mdot
.32949 .53645 Mdot
.44343 .70591 Mdot
.32471 .51298 Mdot
.48599 .35356 Mdot
.62779 .66718 Mdot
.71497 .66507 Mdot
.51329 .27726 Mdot
.69458 .29209 Mdot
.64501 .44285 Mdot
.37204 .62399 Mdot
.6355 .44005 Mdot
.41282 .34313 Mdot
.62215 .47173 Mdot
.56826 .49533 Mdot
.46158 .73355 Mdot
.65683 .49314 Mdot
.59673 .47384 Mdot
.60933 .35004 Mdot
.5988 .44777 Mdot
.64889 .46544 Mdot
.68288 .43857 Mdot
.49566 .36074 Mdot
.6613 .48916 Mdot
.43698 .36721 Mdot
.33407 .43942 Mdot
.41794 .69003 Mdot
.61996 .71054 Mdot
.61029 .70904 Mdot
.67756 .65144 Mdot
.67243 .60063 Mdot
.41268 .41768 Mdot
.4352 .32533 Mdot
.31369 .55634 Mdot
.65364 .42529 Mdot
.76079 .33731 Mdot
.79551 .57229 Mdot
.46694 .72126 Mdot
.40344 .7145 Mdot
.6571 .48494 Mdot
.15775 .49512 Mdot
.65893 .48868 Mdot
.4598 .45383 Mdot
.61527 .43386 Mdot
.6539 .41209 Mdot
.41073 .74139 Mdot
.68931 .63956 Mdot
.64587 .44381 Mdot
.47922 .35871 Mdot
.60787 .67347 Mdot
.64185 .54306 Mdot
.78379 .59924 Mdot
.57709 .36681 Mdot
.73408 .46133 Mdot
.65478 .45246 Mdot
.45177 .7212 Mdot
.47648 .35735 Mdot
.46854 .46429 Mdot
.28171 .53367 Mdot
.48753 .51385 Mdot
.55033 .29912 Mdot
.34954 .56478 Mdot
.60537 .6737 Mdot
.41382 .75338 Mdot
.58993 .42858 Mdot
.41665 .70467 Mdot
.68937 .45107 Mdot
.46368 .49493 Mdot
.63156 .68554 Mdot
.46398 .37968 Mdot
.30156 .53094 Mdot
.41981 .35258 Mdot
.73803 .33573 Mdot
.79867 .56889 Mdot
.81029 .34112 Mdot
.46309 .69367 Mdot
.57031 .19308 Mdot
.4674 .34503 Mdot
.62797 .43692 Mdot
.54506 .90591 Mdot
.45679 .33951 Mdot
.43569 .3674 Mdot
.46117 .54183 Mdot
.70037 .63882 Mdot
.63412 .51067 Mdot
.47526 .32517 Mdot
.40486 .74558 Mdot
.62189 .68629 Mdot
.67159 .45427 Mdot
.66899 .50722 Mdot
.43161 .31064 Mdot
.44948 .69373 Mdot
.66273 .62384 Mdot
.43287 .7005 Mdot
.47488 .35313 Mdot
.43135 .68307 Mdot
.35215 .31157 Mdot
.42047 .73923 Mdot
.58801 .46664 Mdot
.61719 .44949 Mdot
.3521 .59729 Mdot
.44198 .35396 Mdot
.66064 .42672 Mdot
.63869 .4592 Mdot
.46785 .35205 Mdot
.4766 .684 Mdot
.63105 .2218 Mdot
.65384 .42065 Mdot
.6214 .44835 Mdot
.61112 .70566 Mdot
.53512 .54741 Mdot
.45231 .45128 Mdot
.67352 .44928 Mdot
.63275 .66428 Mdot
.45762 .37615 Mdot
.60587 .45738 Mdot
.69066 .64217 Mdot
.44799 .66231 Mdot
.66044 .45637 Mdot
.39276 .45414 Mdot
.60566 .4262 Mdot
.50435 .15405 Mdot
.63948 .48645 Mdot
.46097 .35839 Mdot
.46979 .33635 Mdot
.37983 .69537 Mdot
.44402 .34079 Mdot
.37334 .47296 Mdot
.30782 .55478 Mdot
.41993 .22287 Mdot
.37423 .46894 Mdot
.59297 .41444 Mdot
.81959 .61045 Mdot
.66621 .50978 Mdot
.64714 .51926 Mdot
.70589 .73341 Mdot
.37494 .4794 Mdot
.46278 .34195 Mdot
.24916 .42688 Mdot
.63156 .50687 Mdot
.27447 .5519 Mdot
.64065 .51691 Mdot
.6601 .4564 Mdot
.55305 .46156 Mdot
.46155 .2593 Mdot
.28712 .5747 Mdot
.63837 .37189 Mdot
.67151 .45374 Mdot
.68366 .25278 Mdot
.58495 .44284 Mdot
.5943 .68441 Mdot
.44393 .31705 Mdot
.41322 .71547 Mdot
.62718 .6843 Mdot
.59447 .4232 Mdot
.60671 .68636 Mdot
.41893 .70617 Mdot
.31971 .53355 Mdot
.58512 .46203 Mdot
.64551 .67031 Mdot
.60451 .67224 Mdot
.64186 .42801 Mdot
.46381 .32663 Mdot
.6464 .39808 Mdot
.60408 .45452 Mdot
.65042 .47577 Mdot
.46916 .32277 Mdot
.60607 .83847 Mdot
.64466 .45984 Mdot
.42583 .58001 Mdot
.4299 .37847 Mdot
.37143 .46847 Mdot
.42677 .7305 Mdot
.56234 .43221 Mdot
.28782 .56301 Mdot
.30571 .55522 Mdot
.45831 .67579 Mdot
.44221 .30713 Mdot
.44413 .70186 Mdot
.55475 .44688 Mdot
.6174 .51075 Mdot
.66366 .47942 Mdot
.44619 .80877 Mdot
.33184 .32372 Mdot
.44669 .36154 Mdot
.45638 .73276 Mdot
.49081 .50967 Mdot
.28534 .56714 Mdot
.41887 .748 Mdot
.40778 .31304 Mdot
.45476 .30741 Mdot
.47542 .32969 Mdot
.62023 .65947 Mdot
.43958 .70961 Mdot
.4074 .30573 Mdot
.43088 .29214 Mdot
.65152 .42874 Mdot
.66954 .45322 Mdot
.48668 .37045 Mdot
.42118 .77302 Mdot
.62776 .67218 Mdot
.45557 .71825 Mdot
.47159 .1378 Mdot
.27713 .55808 Mdot
.6143 .35008 Mdot
.67436 .45363 Mdot
.36673 .8661 Mdot
.66212 .48598 Mdot
.5867 .45303 Mdot
.48312 .36545 Mdot
.61607 .64741 Mdot
.61883 .68563 Mdot
.468 .34402 Mdot
.44073 .2977 Mdot
.60286 .66764 Mdot
.45422 .54985 Mdot
.54742 .16268 Mdot
.47349 .47954 Mdot
.45669 .36372 Mdot
.51487 .27439 Mdot
.32171 .55555 Mdot
.4364 .37896 Mdot
.31774 .50199 Mdot
.41813 .68754 Mdot
.41288 .73177 Mdot
.31924 .54424 Mdot
.64681 .46141 Mdot
.45842 .68777 Mdot
.55432 .43078 Mdot
.36931 .35074 Mdot
.28773 .60686 Mdot
.79285 .35949 Mdot
.59168 .47383 Mdot
.69581 .53005 Mdot
.26894 .4902 Mdot
.60346 .41136 Mdot
.70962 .39288 Mdot
.60316 .68283 Mdot
.43624 .38124 Mdot
.30641 .57748 Mdot
.3609 .24133 Mdot
.61664 .45134 Mdot
.46463 .36338 Mdot
.28323 .56801 Mdot
.35226 .3355 Mdot
.44263 .58524 Mdot
.62993 .41921 Mdot
.59503 .89159 Mdot
.48389 .3375 Mdot
.41355 .71579 Mdot
.59869 .33744 Mdot
.42725 .36533 Mdot
.48729 .65888 Mdot
.3921 .70417 Mdot
.49004 .47342 Mdot
.4713 .31718 Mdot
.58057 .6809 Mdot
.4469 .32398 Mdot
.62237 .65255 Mdot
.45157 .29539 Mdot
.43957 .68725 Mdot
.60254 .46353 Mdot
.43477 .68846 Mdot
.59259 .68766 Mdot
.46174 .68579 Mdot
.30634 .57741 Mdot
.38182 .48163 Mdot
.30702 .56223 Mdot
.58885 .56979 Mdot
.63107 .24428 Mdot
.30601 .5238 Mdot
.41305 .55671 Mdot
.60032 .42843 Mdot
.49297 .33432 Mdot
.4122 .70882 Mdot
.47304 .69398 Mdot
.49896 .52654 Mdot
.47672 .34211 Mdot
.44682 .68731 Mdot
.51953 .28341 Mdot
.4302 .84216 Mdot
.58063 .49825 Mdot
.25965 .71278 Mdot
.46573 .35569 Mdot
.45376 .74127 Mdot
.46075 .44961 Mdot
.42022 .31968 Mdot
.40649 .71777 Mdot
.3061 .52968 Mdot
.2847 .55935 Mdot
.61449 .49372 Mdot
.33352 .54385 Mdot
.44233 .74139 Mdot
.68202 .24884 Mdot
.45295 .3154 Mdot
.31946 .31523 Mdot
.59939 .69211 Mdot
.4165 .69688 Mdot
.6471 .50278 Mdot
.47371 .29413 Mdot
.40532 .69095 Mdot
.17865 .5236 Mdot
.4036 .16893 Mdot
.44776 .68741 Mdot
.44283 .31734 Mdot
.4357 .33895 Mdot
.55833 .45231 Mdot
.49464 .50892 Mdot
.45195 .69485 Mdot
.34537 .64702 Mdot
.67625 .5814 Mdot
.37824 .46751 Mdot
.81027 .45673 Mdot
.64648 .4454 Mdot
.65556 .45277 Mdot
.2871 .52625 Mdot
.59525 .45224 Mdot
.43317 .29633 Mdot
.6648 .48302 Mdot
.31704 .51835 Mdot
.4644 .68574 Mdot
.61035 .45003 Mdot
.60046 .68506 Mdot
.32299 .52677 Mdot
.29296 .51561 Mdot
.42574 .68209 Mdot
.45947 .31466 Mdot
.23725 .45484 Mdot
.43459 .7016 Mdot
.6545 .46842 Mdot
.38821 .47551 Mdot
.67468 .4713 Mdot
.3594 .59097 Mdot
.41343 .33475 Mdot
.41434 .72069 Mdot
.47992 .37768 Mdot
.29746 .5421 Mdot
.46824 .72399 Mdot
.58803 .42779 Mdot
.41755 .73272 Mdot
.41169 .59882 Mdot
.52442 .73632 Mdot
.43614 .29348 Mdot
.45715 .61755 Mdot
.44262 .30533 Mdot
.37859 .46576 Mdot
.73374 .59165 Mdot
.6202 .66916 Mdot
.4516 .7291 Mdot
.34702 .29482 Mdot
.41057 .69856 Mdot
.5993 .44386 Mdot
.63511 .44855 Mdot
.44282 .72398 Mdot
.62755 .66424 Mdot
.68773 .69503 Mdot
.59299 .72167 Mdot
.4257 .33316 Mdot
.46568 .59046 Mdot
.49916 .13725 Mdot
.41144 .66149 Mdot
.31525 .55208 Mdot
.72742 .43235 Mdot
.60881 .41738 Mdot
.2852 .57175 Mdot
.27437 .53013 Mdot
.59661 .66483 Mdot
.41465 .69552 Mdot
.41397 .35717 Mdot
.31509 .56732 Mdot
.46194 .28562 Mdot
.67679 .63417 Mdot
.69112 .45169 Mdot
.53078 .47697 Mdot
.57414 .43572 Mdot
.50198 .54082 Mdot
.32394 .52217 Mdot
.6305 .46603 Mdot
.63189 .37549 Mdot
.29026 .53059 Mdot
.60278 .65785 Mdot
.49472 .2998 Mdot
.44499 .68332 Mdot
.39723 .85587 Mdot
.58711 .46429 Mdot
.60329 .4603 Mdot
.27986 .53848 Mdot
.68467 .3528 Mdot
.44527 .36392 Mdot
.45577 .31352 Mdot
.42656 .71066 Mdot
.45779 .50546 Mdot
.61571 .49562 Mdot
.58082 .44331 Mdot
.45536 .68664 Mdot
.39683 .46931 Mdot
.81877 .42467 Mdot
.62608 .45376 Mdot
.2895 .55285 Mdot
.39617 .59931 Mdot
.32754 .5266 Mdot
.59599 .40647 Mdot
.60118 .43926 Mdot
.57957 .43311 Mdot
.58511 .46985 Mdot
.31701 .55939 Mdot
.58786 .42421 Mdot
.69075 .43708 Mdot
.46045 .34442 Mdot
.65205 .45088 Mdot
.67933 .57854 Mdot
.62293 .45524 Mdot
.60159 .68731 Mdot
.45187 .46129 Mdot
.63484 .48676 Mdot
.65281 .4527 Mdot
.67168 .58437 Mdot
.59969 .46752 Mdot
.2844 .56989 Mdot
.43835 .34529 Mdot
.29657 .54079 Mdot
.31348 .54699 Mdot
.40353 .69802 Mdot
.62778 .65169 Mdot
.57346 .4646 Mdot
.6084 .66151 Mdot
.55953 .46991 Mdot
.65972 .5199 Mdot
.56037 .56086 Mdot
.4605 .45651 Mdot
.62192 .71251 Mdot
.58359 .43617 Mdot
.42284 .70545 Mdot
.41442 .7232 Mdot
.46098 .60994 Mdot
.62921 .52214 Mdot
.31547 .5704 Mdot
.31465 .53141 Mdot
.58415 .72083 Mdot
.54093 .68154 Mdot
.60313 .67222 Mdot
.60157 .59723 Mdot
.65598 .41059 Mdot
.64321 .4725 Mdot
.64378 .5289 Mdot
.3984 .69705 Mdot
.3805 .48227 Mdot
.4505 .67382 Mdot
.40289 .43424 Mdot
.32361 .55551 Mdot
.59246 .47438 Mdot
.16409 .45257 Mdot
.423 .33582 Mdot
.43802 .34579 Mdot
.31655 .51779 Mdot
.45764 .72614 Mdot
.63905 .52387 Mdot
.30839 .79377 Mdot
.4215 .30919 Mdot
.62865 .70536 Mdot
.60755 .47688 Mdot
.42105 .68712 Mdot
.42824 .31851 Mdot
.64554 .68041 Mdot
.58195 .4635 Mdot
.39412 .72234 Mdot
.6246 .46511 Mdot
.57114 .27409 Mdot
.46215 .33432 Mdot
.53586 .5313 Mdot
.49227 .35649 Mdot
.31225 .56252 Mdot
.29343 .53471 Mdot
.60512 .43917 Mdot
.35422 .82782 Mdot
.42208 .2755 Mdot
.26723 .5445 Mdot
.64422 .67851 Mdot
.38821 .48048 Mdot
.64303 .67151 Mdot
.43686 .72464 Mdot
.60822 .67176 Mdot
.40583 .69139 Mdot
.42504 .77469 Mdot
.40473 .34558 Mdot
.62426 .69824 Mdot
.71369 .3592 Mdot
.61278 .50954 Mdot
.59225 .67668 Mdot
.66126 .47865 Mdot
.55609 .46731 Mdot
.44834 .67995 Mdot
.61496 .66089 Mdot
.62712 .42502 Mdot
.28692 .31064 Mdot
.30525 .53565 Mdot
.31027 .57447 Mdot
.61663 .5098 Mdot
.445 .74613 Mdot
.44414 .29482 Mdot
.5282 .55986 Mdot
.3681 .47441 Mdot
.58096 .44563 Mdot
.57406 .42718 Mdot
.48617 .34243 Mdot
.457 .37153 Mdot
.60475 .43704 Mdot
.49605 .27106 Mdot
.5918 .42487 Mdot
.2825 .55625 Mdot
.42494 .3346 Mdot
.43517 .34154 Mdot
.43554 .74202 Mdot
.43838 .30877 Mdot
.67018 .40137 Mdot
.30508 .59058 Mdot
.67157 .49066 Mdot
.29736 .54526 Mdot
.39293 .75341 Mdot
.42509 .67448 Mdot
.34488 .29296 Mdot
.4396 .30922 Mdot
.66191 .42549 Mdot
.41972 .33613 Mdot
.6081 .70037 Mdot
.43895 .35206 Mdot
.48869 .33735 Mdot
.61992 .49138 Mdot
.61538 .42565 Mdot
.39507 .46884 Mdot
.49843 .51777 Mdot
.45787 .32912 Mdot
.61469 .41078 Mdot
.67687 .44547 Mdot
.63292 .44423 Mdot
.5527 .56351 Mdot
.47538 .37518 Mdot
.56911 .36885 Mdot
.36332 .55633 Mdot
.45847 .32521 Mdot
.42574 .17764 Mdot
.40079 .46035 Mdot
.40104 .44765 Mdot
.29747 .50821 Mdot
.62493 .44976 Mdot
.44217 .69651 Mdot
.65687 .45491 Mdot
.60693 .52089 Mdot
.62911 .48673 Mdot
.62535 .6997 Mdot
.62504 .49999 Mdot
.38658 .46134 Mdot
.43128 .69657 Mdot
.61318 .41207 Mdot
.61297 .44555 Mdot
.40109 .44958 Mdot
.48839 .36969 Mdot
.4513 .30722 Mdot
.35976 .4921 Mdot
.59626 .66809 Mdot
.31102 .52017 Mdot
.65576 .46546 Mdot
.42516 .70812 Mdot
.43628 .69225 Mdot
.42603 .35938 Mdot
.45745 .69551 Mdot
.31496 .51981 Mdot
.58635 .44574 Mdot
.31297 .56191 Mdot
.625 .69992 Mdot
.44463 .31687 Mdot
.65224 .48197 Mdot
.64652 .42642 Mdot
.46965 .33631 Mdot
.60486 .42409 Mdot
.6228 .70308 Mdot
.39855 .71672 Mdot
.43809 .35561 Mdot
.30732 .55369 Mdot
.42966 .74208 Mdot
.65846 .42801 Mdot
.32228 .20922 Mdot
.59463 .45083 Mdot
.57916 .44564 Mdot
.37957 .32076 Mdot
.67036 .42747 Mdot
.41244 .69465 Mdot
.42009 .32782 Mdot
.58084 .41369 Mdot
.67272 .58644 Mdot
.6053 .6431 Mdot
.39959 .67447 Mdot
.60027 .47346 Mdot
.3917 .21452 Mdot
.67344 .44106 Mdot
.35442 .28569 Mdot
.55928 .55994 Mdot
.22674 .61635 Mdot
.53072 .47621 Mdot
.26709 .54067 Mdot
.39372 .47308 Mdot
.41542 .68332 Mdot
.6689 .33234 Mdot
.59594 .43915 Mdot
.69399 .28528 Mdot
.65425 .47889 Mdot
.28674 .55737 Mdot
.70237 .39173 Mdot
.45739 .71226 Mdot
.80526 .45418 Mdot
.64506 .45195 Mdot
.48373 .34131 Mdot
.45792 .74392 Mdot
.39977 .4691 Mdot
.62264 .4278 Mdot
.59736 .67587 Mdot
.57489 .67986 Mdot
.66606 .39886 Mdot
.29959 .54442 Mdot
.641 .4657 Mdot
.55975 .42184 Mdot
.44683 .83278 Mdot
.4582 .35111 Mdot
.31267 .53761 Mdot
.56041 .64799 Mdot
.63127 .44437 Mdot
.4552 .30803 Mdot
.44165 .34595 Mdot
.6087 .65759 Mdot
.23306 .55208 Mdot
.66524 .73454 Mdot
.18947 .37462 Mdot
.73081 .31093 Mdot
.3971 .7029 Mdot
.50735 .38012 Mdot
.65459 .44188 Mdot
.80015 .56838 Mdot
.31281 .55113 Mdot
.60422 .46366 Mdot
.69967 .30522 Mdot
.45277 .35386 Mdot
.62756 .46154 Mdot
.62691 .6728 Mdot
.24398 .48281 Mdot
.54132 .30816 Mdot
.33177 .22503 Mdot
.40283 .74337 Mdot
.64303 .51099 Mdot
.68429 .41922 Mdot
.37089 .47099 Mdot
.58961 .40947 Mdot
.41298 .70644 Mdot
.37818 .6125 Mdot
.63602 .67748 Mdot
.42278 .33241 Mdot
.40182 .46334 Mdot
.65494 .47846 Mdot
.68561 .46583 Mdot
.63415 .70019 Mdot
.62826 .43369 Mdot
.5842 .34076 Mdot
.41041 .45228 Mdot
.41816 .73852 Mdot
.48288 .34244 Mdot
.57524 .43131 Mdot
.39008 .47836 Mdot
.62772 .49314 Mdot
.75263 .43447 Mdot
.61933 .47873 Mdot
.39223 .26829 Mdot
.46811 .32895 Mdot
.30528 .54461 Mdot
.62115 .50054 Mdot
.61817 .46077 Mdot
.5245 .68183 Mdot
.63586 .52252 Mdot
.64355 .48044 Mdot
.42212 .35775 Mdot
.42232 .33748 Mdot
.46337 .36604 Mdot
.43366 .74035 Mdot
.47709 .48098 Mdot
.29653 .55949 Mdot
.64208 .5283 Mdot
.31842 .56475 Mdot
.52778 .46118 Mdot
.64039 .68748 Mdot
.33574 .29244 Mdot
.59068 .43756 Mdot
.47769 .33838 Mdot
.5823 .17874 Mdot
.45423 .37602 Mdot
.35488 .51402 Mdot
.31098 .5481 Mdot
.45597 .33596 Mdot
.59721 .46712 Mdot
.49468 .50086 Mdot
.30416 .23892 Mdot
.28757 .56863 Mdot
.65129 .51528 Mdot
.39315 .7341 Mdot
.45968 .67335 Mdot
.44746 .17898 Mdot
.29873 .57105 Mdot
.2628 .49379 Mdot
.65148 .41892 Mdot
.42368 .3211 Mdot
.31444 .52414 Mdot
.27176 .5551 Mdot
.45814 .69322 Mdot
.63915 .42072 Mdot
.62059 .46132 Mdot
.39518 .45409 Mdot
.32176 .54627 Mdot
.55053 .49977 Mdot
.62362 .41839 Mdot
.37786 .36675 Mdot
.40647 .32386 Mdot
.61767 .83264 Mdot
.61125 .36704 Mdot
.69734 .30084 Mdot
.37239 .68899 Mdot
.43773 .35761 Mdot
.64784 .46038 Mdot
.64354 .52549 Mdot
.3962 .71543 Mdot
.58879 .44984 Mdot
.46362 .72268 Mdot
.30747 .56671 Mdot
.33657 .27583 Mdot
.4229 .54215 Mdot
.26461 .59 Mdot
.59712 .45109 Mdot
.53621 .30799 Mdot
.62447 .69582 Mdot
.27477 .57818 Mdot
.4481 .3683 Mdot
.60654 .40601 Mdot
.39933 .68796 Mdot
.43668 .73899 Mdot
.44854 .34819 Mdot
.34402 .45543 Mdot
.3482 .28843 Mdot
.57734 .45932 Mdot
.43054 .72901 Mdot
.4188 .49035 Mdot
.46654 .23124 Mdot
.29231 .5118 Mdot
.63646 .68066 Mdot
.415 .68647 Mdot
.32522 .56581 Mdot
.55965 .47738 Mdot
.44947 .33824 Mdot
.48181 .32946 Mdot
.47103 .63492 Mdot
.44709 .69014 Mdot
.61923 .6774 Mdot
.45641 .60817 Mdot
.46616 .59953 Mdot
.63122 .68221 Mdot
.46632 .723 Mdot
.4291 .35095 Mdot
.46955 .35795 Mdot
.43848 .34419 Mdot
.6268 .3497 Mdot
.41493 .3277 Mdot
.73934 .6734 Mdot
.59749 .40811 Mdot
.49258 .25399 Mdot
.62623 .4078 Mdot
.29996 .57734 Mdot
.46285 .33334 Mdot
.55326 .5535 Mdot
.66672 .41801 Mdot
.3175 .23503 Mdot
.62733 .47545 Mdot
.40866 .5902 Mdot
.62351 .4486 Mdot
.57938 .3166 Mdot
.43166 .37873 Mdot
.58617 .42927 Mdot
.30937 .59147 Mdot
.60542 .68882 Mdot
.40078 .33699 Mdot
.64376 .478 Mdot
.32705 .4226 Mdot
.66184 .47754 Mdot
.36797 .26463 Mdot
.49851 .69884 Mdot
.59283 .70229 Mdot
.68014 .45615 Mdot
.41489 .67334 Mdot
.72625 .48323 Mdot
.50608 .26365 Mdot
.28892 .56917 Mdot
.52979 .29962 Mdot
.46081 .70525 Mdot
.7019 .38847 Mdot
.63567 .40109 Mdot
.63409 .67093 Mdot
.48925 .29388 Mdot
.28036 .55217 Mdot
.59618 .43577 Mdot
.64455 .45493 Mdot
.29281 .61175 Mdot
.52103 .27109 Mdot
.61164 .54481 Mdot
.63448 .706 Mdot
.54222 .30139 Mdot
.63562 .48398 Mdot
.39815 .67718 Mdot
.42296 .31654 Mdot
.70567 .40807 Mdot
.69111 .36386 Mdot
.60661 .41308 Mdot
.45503 .34045 Mdot
.44392 .30706 Mdot
.62456 .18902 Mdot
.63952 .67789 Mdot
.62147 .47862 Mdot
.47475 .64253 Mdot
.6544 .47194 Mdot
.2916 .56091 Mdot
.64916 .40663 Mdot
.43068 .67433 Mdot
.4612 .44059 Mdot
.43636 .74013 Mdot
.62103 .43447 Mdot
.44514 .32215 Mdot
.27989 .54302 Mdot
.23774 .65269 Mdot
.27573 .50401 Mdot
.73774 .67418 Mdot
.57364 .67649 Mdot
.59954 .67618 Mdot
.63821 .66153 Mdot
.26477 .52242 Mdot
.59588 .4686 Mdot
.50061 .54511 Mdot
.5802 .50167 Mdot
.62759 .44744 Mdot
.6199 .48127 Mdot
.30337 .49374 Mdot
.31003 .54726 Mdot
.4337 .6847 Mdot
.60402 .43644 Mdot
.61475 .41055 Mdot
.45135 .32609 Mdot
.60502 .67122 Mdot
.40352 .7254 Mdot
.59363 .68626 Mdot
.42779 .69941 Mdot
.50061 .15361 Mdot
.68348 .4837 Mdot
.60739 .69047 Mdot
.32742 .5298 Mdot
.47456 .35788 Mdot
.39515 .45003 Mdot
.43884 .72271 Mdot
.45726 .7099 Mdot
.59097 .42019 Mdot
.44337 .31393 Mdot
.44916 .30953 Mdot
.60262 .6684 Mdot
.31273 .52868 Mdot
.56732 .4392 Mdot
.61666 .42253 Mdot
.2519 .67554 Mdot
.39952 .72346 Mdot
.53117 .29225 Mdot
.38702 .29004 Mdot
.59004 .46303 Mdot
.45769 .30988 Mdot
.60972 .45472 Mdot
.40118 .51143 Mdot
.46389 .36754 Mdot
.6636 .41998 Mdot
.56315 .49756 Mdot
.39834 .69955 Mdot
.71341 .25114 Mdot
.584 .47854 Mdot
.33442 .57338 Mdot
.64705 .43406 Mdot
.79716 .31291 Mdot
.60115 .18563 Mdot
.64925 .48999 Mdot
.592 .47623 Mdot
.20147 .34591 Mdot
.67522 .45691 Mdot
.39168 .45699 Mdot
.60978 .52173 Mdot
.45859 .3087 Mdot
.43209 .59175 Mdot
.5003 .53437 Mdot
.63852 .66837 Mdot
.42572 .71074 Mdot
.69513 .63947 Mdot
.61344 .65252 Mdot
.46251 .35773 Mdot
.68482 .47307 Mdot
.39021 .28744 Mdot
.47053 .68072 Mdot
.59064 .40052 Mdot
.28957 .55996 Mdot
.49867 .53401 Mdot
.44253 .67097 Mdot
.30834 .5542 Mdot
.67359 .43955 Mdot
.43142 .79801 Mdot
.31849 .59222 Mdot
.63735 .19016 Mdot
.28773 .52669 Mdot
.30329 .53764 Mdot
.48687 .48655 Mdot
.63816 .66747 Mdot
.33102 .61892 Mdot
.69582 .42629 Mdot
.2806 .56269 Mdot
.76346 .52327 Mdot
.40063 .73221 Mdot
.4647 .50165 Mdot
.43239 .37725 Mdot
.6727 .50413 Mdot
.60841 .47249 Mdot
.30055 .52684 Mdot
.49964 .38238 Mdot
.53598 .65958 Mdot
.29974 .56822 Mdot
.67075 .40807 Mdot
.45881 .48899 Mdot
.38468 .47907 Mdot
.4011 .45746 Mdot
.64443 .6859 Mdot
.53923 .77954 Mdot
.46947 .32726 Mdot
.62443 .70655 Mdot
.5461 .53285 Mdot
.633 .47432 Mdot
.32119 .55339 Mdot
.40373 .45451 Mdot
.30448 .55428 Mdot
.6189 .69073 Mdot
.6383 .69501 Mdot
.4602 .34579 Mdot
.44204 .36355 Mdot
.42085 .25026 Mdot
.71976 .53675 Mdot
.66095 .4518 Mdot
.64444 .24045 Mdot
.45606 .37081 Mdot
.67457 .34217 Mdot
.62151 .65738 Mdot
.61689 .66399 Mdot
.53573 .23653 Mdot
.65875 .43127 Mdot
.39868 .59786 Mdot
.63723 .48569 Mdot
.76277 .56257 Mdot
.65555 .47927 Mdot
.45653 .69081 Mdot
.64468 .44699 Mdot
.236 .4366 Mdot
.61908 .41224 Mdot
.62001 .4831 Mdot
.44094 .71476 Mdot
.56856 .44863 Mdot
.44009 .67482 Mdot
.64637 .46461 Mdot
.64169 .64732 Mdot
.42561 .70832 Mdot
.65288 .66382 Mdot
.43925 .56867 Mdot
.3943 .46337 Mdot
.63771 .66312 Mdot
.59652 .68183 Mdot
.65851 .62271 Mdot
.43364 .36167 Mdot
.68486 .37457 Mdot
.60588 .47508 Mdot
.4252 .74742 Mdot
.32515 .53354 Mdot
.60496 .41343 Mdot
.66423 .48544 Mdot
.56677 .45075 Mdot
.45853 .34233 Mdot
.4604 .73414 Mdot
.61186 .68859 Mdot
.41464 .72543 Mdot
.64741 .65433 Mdot
.41667 .6767 Mdot
.58277 .48481 Mdot
.56014 .47442 Mdot
.68703 .42859 Mdot
.67406 .28316 Mdot
.82055 .5913 Mdot
.44838 .34295 Mdot
.38552 .47428 Mdot
.64069 .68793 Mdot
.47086 .58978 Mdot
.47195 .32696 Mdot
.45649 .70798 Mdot
.62453 .46534 Mdot
.69341 .43334 Mdot
.6819 .50027 Mdot
.43736 .28106 Mdot
.64921 .70477 Mdot
.43187 .7197 Mdot
.37592 .47383 Mdot
.47238 .48226 Mdot
.42876 .39633 Mdot
.57974 .56615 Mdot
.614 .45769 Mdot
.60108 .66886 Mdot
.42808 .31868 Mdot
.35284 .61299 Mdot
.30273 .52846 Mdot
.49633 .51316 Mdot
.59668 .45309 Mdot
.34089 .47896 Mdot
.44426 .32299 Mdot
.62777 .66805 Mdot
.29892 .52701 Mdot
.63641 .66819 Mdot
.39837 .47429 Mdot
.36264 .48953 Mdot
.62653 .42913 Mdot
.64044 .4857 Mdot
.32416 .55135 Mdot
.46692 .32448 Mdot
.63211 .64113 Mdot
.28043 .61083 Mdot
.43857 .72523 Mdot
.45314 .52121 Mdot
.42433 .3271 Mdot
.2794 .49404 Mdot
.42433 .73388 Mdot
.32648 .5608 Mdot
.50554 .54368 Mdot
.3047 .51683 Mdot
.62971 .48391 Mdot
.43249 .32822 Mdot
.29396 .57204 Mdot
.26334 .67433 Mdot
.39878 .23275 Mdot
.44717 .27219 Mdot
.60662 .42905 Mdot
.3347 .28743 Mdot
.30561 .45223 Mdot
.51598 .37698 Mdot
.31392 .56744 Mdot
.6034 .4453 Mdot
.57606 .45668 Mdot
.64479 .45083 Mdot
.30461 .53329 Mdot
.22056 .56418 Mdot
.44847 .72884 Mdot
.63219 .46451 Mdot
.60065 .69391 Mdot
.43139 .67609 Mdot
.44719 .66546 Mdot
.41269 .6887 Mdot
.45389 .37161 Mdot
.68765 .46639 Mdot
.66693 .52932 Mdot
.6857 .22824 Mdot
.30437 .54057 Mdot
.39396 .46328 Mdot
.57798 .44759 Mdot
.72454 .67767 Mdot
.47081 .35926 Mdot
.44478 .7182 Mdot
.60447 .46228 Mdot
.49482 .67196 Mdot
.4115 .46075 Mdot
.4376 .70758 Mdot
.45211 .36797 Mdot
.51626 .3814 Mdot
.58807 .44757 Mdot
.65078 .43504 Mdot
.47266 .34787 Mdot
.27663 .47434 Mdot
.4691 .4802 Mdot
.61079 .45256 Mdot
.30771 .54772 Mdot
.39708 .84424 Mdot
.66278 .42291 Mdot
.49875 .32373 Mdot
.3776 .48241 Mdot
.40019 .3956 Mdot
.51263 .28447 Mdot
.59822 .51189 Mdot
.30505 .2798 Mdot
.7112 .70528 Mdot
.35009 .24833 Mdot
.76296 .57877 Mdot
.26145 .60341 Mdot
.55727 .15237 Mdot
.31913 .58526 Mdot
.57522 .30202 Mdot
.17031 .51687 Mdot
.29013 .47973 Mdot
.50419 .72646 Mdot
.27089 .64753 Mdot
.42305 .79014 Mdot
.81376 .4444 Mdot
.42515 .6691 Mdot
.7829 .55974 Mdot
.644 .48706 Mdot
.28211 .46397 Mdot
.56686 .31677 Mdot
.78994 .65391 Mdot
.33837 .30124 Mdot
.48123 .64971 Mdot
.29637 .23187 Mdot
.34738 .32152 Mdot
.46732 .20501 Mdot
.73463 .38767 Mdot
.57421 .79111 Mdot
.4705 .59806 Mdot
.70477 .65289 Mdot
.53473 .31761 Mdot
.23763 .41076 Mdot
.30167 .59581 Mdot
.58744 .20856 Mdot
.47277 .83813 Mdot
.41842 .71774 Mdot
.42465 .3137 Mdot
.3184 .6243 Mdot
.4477 .21277 Mdot
.35223 .54019 Mdot
.30508 .27938 Mdot
.37524 .33666 Mdot
.57717 .31342 Mdot
.53805 .53146 Mdot
.57206 .26708 Mdot
.67965 .72692 Mdot
.79863 .47088 Mdot
.45805 .291 Mdot
.28654 .66756 Mdot
.47497 .59548 Mdot
.66234 .64598 Mdot
.59903 .32943 Mdot
.64579 .69035 Mdot
.64796 .6697 Mdot
.45744 .36777 Mdot
.46538 .22649 Mdot
.41066 .44781 Mdot
.54745 .53215 Mdot
.40213 .68175 Mdot
.40504 .51549 Mdot
.24978 .47294 Mdot
.32239 .45039 Mdot
.75876 .30643 Mdot
.34705 .19952 Mdot
.71529 .57 Mdot
.373 .60605 Mdot
.34625 .52442 Mdot
.70799 .67157 Mdot
.653 .54525 Mdot
.73716 .53723 Mdot
.75176 .42703 Mdot
.23909 .2813 Mdot
.34728 .41392 Mdot
.29016 .22883 Mdot
.46854 .30054 Mdot
.64892 .38037 Mdot
.38304 .57657 Mdot
.73576 .32607 Mdot
.65693 .60003 Mdot
.34276 .209 Mdot
.58572 .69502 Mdot
.4225 .37239 Mdot
.29168 .48009 Mdot
.57732 .34129 Mdot
.66972 .7049 Mdot
.56682 .68523 Mdot
.70303 .40515 Mdot
.2359 .27111 Mdot
.29744 .2863 Mdot
.54683 .17259 Mdot
.38092 .37966 Mdot
.46705 .66082 Mdot
.44079 .66281 Mdot
.27125 .55669 Mdot
.43562 .1997 Mdot
.43707 .32951 Mdot
.69821 .23177 Mdot
.39594 .24442 Mdot
.72914 .48338 Mdot
.21767 .28923 Mdot
.80697 .41491 Mdot
.49116 .25684 Mdot
.78725 .6214 Mdot
.33307 .78689 Mdot
.63634 .55607 Mdot
.25467 .51613 Mdot
.38681 .70543 Mdot
.39278 .26309 Mdot
.42511 .19985 Mdot
.76932 .5064 Mdot
.17622 .42558 Mdot
.54813 .53108 Mdot
.37612 .70303 Mdot
.41626 .28302 Mdot
.49894 .74897 Mdot
.61524 .60785 Mdot
.29703 .22482 Mdot
.55009 .30814 Mdot
.38093 .82682 Mdot
.74496 .59109 Mdot
.68165 .35312 Mdot
.30075 .30788 Mdot
.44388 .77307 Mdot
.7296 .51061 Mdot
.33691 .42871 Mdot
.65565 .50782 Mdot
.61557 .58718 Mdot
.72079 .3973 Mdot
.64126 .73432 Mdot
.47541 .47399 Mdot
.3418 .38623 Mdot
.71549 .60096 Mdot
.21308 .5736 Mdot
.67834 .36573 Mdot
.47757 .36807 Mdot
.7234 .54844 Mdot
.74036 .57304 Mdot
.37558 .39291 Mdot
.56337 .64474 Mdot
.53531 .16943 Mdot
.54703 .65656 Mdot
.59622 .51337 Mdot
.57398 .29566 Mdot
.53691 .323 Mdot
.75385 .54219 Mdot
.5986 .49702 Mdot
.73594 .28423 Mdot
.38488 .37495 Mdot
.64922 .27158 Mdot
.68893 .60721 Mdot
.66632 .27863 Mdot
.41899 .22375 Mdot
.38178 .56864 Mdot
.2457 .523 Mdot
.50978 .36393 Mdot
.23936 .26927 Mdot
.43295 .68005 Mdot
.75788 .51894 Mdot
.32257 .5849 Mdot
.25432 .66946 Mdot
.26856 .61434 Mdot
.53914 .65708 Mdot
.4523 .19161 Mdot
.32606 .46196 Mdot
.44648 .75944 Mdot
.22815 .39747 Mdot
.42475 .47759 Mdot
.63778 .24111 Mdot
.59172 .38007 Mdot
.74757 .44683 Mdot
.62376 .70304 Mdot
.69053 .32821 Mdot
.36757 .56125 Mdot
.60822 .74444 Mdot
.59747 .50797 Mdot
.47349 .62478 Mdot
.37761 .46529 Mdot
.48662 .52668 Mdot
.49788 .15234 Mdot
.57831 .38206 Mdot
.80432 .42031 Mdot
.31183 .46144 Mdot
.49405 .54098 Mdot
.64752 .62913 Mdot
.4435 .4094 Mdot
.27796 .2355 Mdot
.47237 .17582 Mdot
.29277 .43827 Mdot
.33103 .28482 Mdot
.85586 .45645 Mdot
.22552 .60834 Mdot
.76412 .34478 Mdot
.32067 .58646 Mdot
.74876 .78621 Mdot
.41801 .73036 Mdot
.80821 .56315 Mdot
.73112 .32576 Mdot
.51194 .67693 Mdot
.44543 .21405 Mdot
.54732 .3382 Mdot
.60879 .62357 Mdot
.4907 .35195 Mdot
.5935 .49843 Mdot
.36316 .20714 Mdot
.24983 .26359 Mdot
.35632 .20944 Mdot
.35607 .46826 Mdot
.36457 .22321 Mdot
.20255 .33188 Mdot
.74163 .67268 Mdot
.31644 .60979 Mdot
.625 .40213 Mdot
.75892 .49451 Mdot
.79914 .3977 Mdot
.59586 .71439 Mdot
.6225 .55413 Mdot
.45305 .28862 Mdot
.20016 .32586 Mdot
.49991 .15054 Mdot
.56577 .24118 Mdot
.47961 .20803 Mdot
.39769 .61896 Mdot
.74263 .52215 Mdot
.47084 .19477 Mdot
.24698 .38358 Mdot
.36976 .34243 Mdot
.18746 .35742 Mdot
.73573 .58275 Mdot
.27083 .65115 Mdot
.28708 .42693 Mdot
.78651 .37488 Mdot
.30036 .30305 Mdot
.30651 .62594 Mdot
.72256 .51094 Mdot
.39852 .30728 Mdot
.53775 .66171 Mdot
.23447 .40494 Mdot
.38994 .59993 Mdot
.68643 .59395 Mdot
.46373 .68921 Mdot
.76534 .50425 Mdot
.54942 .58535 Mdot
.31588 .61064 Mdot
.67841 .62911 Mdot
.77517 .50264 Mdot
.31337 .40563 Mdot
.35976 .21731 Mdot
.3137 .46219 Mdot
.3278 .78906 Mdot
.31689 .33124 Mdot
.72484 .40403 Mdot
.56845 .45021 Mdot
.4342 .20808 Mdot
.43853 .15652 Mdot
.45561 .18859 Mdot
.36792 .4443 Mdot
.46569 .64438 Mdot
.33391 .54335 Mdot
.69982 .66315 Mdot
.51981 .66582 Mdot
.3685 .29677 Mdot
.50535 .58202 Mdot
.30406 .5859 Mdot
.24285 .48653 Mdot
.41799 .25153 Mdot
.72001 .6788 Mdot
.57294 .20934 Mdot
.57383 .52788 Mdot
.47361 .23527 Mdot
.48618 .33944 Mdot
.34909 .46541 Mdot
.74272 .53259 Mdot
.42674 .68098 Mdot
.25916 .6828 Mdot
.4988 .37723 Mdot
.63896 .37654 Mdot
.3774 .62087 Mdot
.43178 .27111 Mdot
.6933 .29365 Mdot
.45241 .75288 Mdot
.52787 .151 Mdot
.75389 .30739 Mdot
.47182 .1937 Mdot
.72103 .55771 Mdot
.27321 .68397 Mdot
.479 .51174 Mdot
.34052 .5265 Mdot
.34041 .3099 Mdot
.46522 .55869 Mdot
.7305 .55 Mdot
.47225 .2432 Mdot
.33577 .59629 Mdot
.61726 .52079 Mdot
.57253 .17475 Mdot
.73297 .66196 Mdot
.47421 .52515 Mdot
.40016 .37741 Mdot
.41852 .3125 Mdot
.83335 .57665 Mdot
.24386 .42187 Mdot
.70628 .50813 Mdot
.31852 .29323 Mdot
.27968 .51573 Mdot
.47274 .36563 Mdot
.78036 .49217 Mdot
.52838 .73414 Mdot
.44266 .25258 Mdot
.39951 .5696 Mdot
.4552 .21089 Mdot
.43524 .55478 Mdot
.32595 .2832 Mdot
.28695 .27384 Mdot
.40614 .83907 Mdot
.47094 .30323 Mdot
.36135 .60665 Mdot
.35779 .61753 Mdot
.43644 .28784 Mdot
.45846 .28715 Mdot
.5444 .31082 Mdot
.39887 .19244 Mdot
.45143 .59499 Mdot
.24143 .37768 Mdot
.49869 .54369 Mdot
.50915 .72734 Mdot
.34252 .6024 Mdot
.68793 .63443 Mdot
.26109 .31969 Mdot
.52424 .20553 Mdot
.21428 .6755 Mdot
.57292 .53242 Mdot
.80894 .55492 Mdot
.70017 .66428 Mdot
.73548 .39276 Mdot
.59832 .32687 Mdot
.36201 .34112 Mdot
.65448 .46001 Mdot
.36081 .1913 Mdot
.34918 .40438 Mdot
.60816 .596 Mdot
.43379 .77989 Mdot
.66776 .43621 Mdot
.68641 .44124 Mdot
.46587 .19477 Mdot
.39014 .36932 Mdot
.18132 .59654 Mdot
.75478 .57934 Mdot
.73742 .43399 Mdot
.48255 .25311 Mdot
.80315 .41902 Mdot
.39206 .55441 Mdot
.36594 .24907 Mdot
.54995 .59032 Mdot
.79882 .38772 Mdot
.23848 .35505 Mdot
.22624 .42518 Mdot
.31398 .32178 Mdot
.21136 .31985 Mdot
.72522 .43592 Mdot
.40301 .42261 Mdot
.32944 .62645 Mdot
.58081 .456 Mdot
.34489 .45424 Mdot
.32101 .30401 Mdot
.4891 .79769 Mdot
.66659 .54347 Mdot
.43204 .15649 Mdot
.57508 .51808 Mdot
.37043 .42734 Mdot
.18678 .55312 Mdot
.21038 .70203 Mdot
.23069 .43491 Mdot
.30221 .22166 Mdot
.22215 .41576 Mdot
.31106 .29026 Mdot
.27763 .51475 Mdot
.45918 .57311 Mdot
.67579 .26232 Mdot
.40608 .18732 Mdot
.54925 .76284 Mdot
.23022 .58746 Mdot
.63792 .2216 Mdot
.40021 .1864 Mdot
.57793 .51445 Mdot
.83144 .55913 Mdot
.47565 .67637 Mdot
.81967 .40464 Mdot
.76741 .33005 Mdot
.39807 .36392 Mdot
.76691 .52495 Mdot
.82666 .53877 Mdot
.77325 .66516 Mdot
.76072 .32896 Mdot
.76577 .439 Mdot
.40243 .39237 Mdot
.71212 .56272 Mdot
.37506 .27074 Mdot
.82355 .46076 Mdot
.35334 .59955 Mdot
.41464 .4404 Mdot
.36418 .48801 Mdot
.39596 .26217 Mdot
.31038 .38954 Mdot
.38502 .5904 Mdot
.45166 .44685 Mdot
.43872 .22491 Mdot
.43916 .87625 Mdot
.20562 .42082 Mdot
.48956 .28844 Mdot
.26474 .25494 Mdot
.37143 .35948 Mdot
.47657 .58428 Mdot
.6084 .33441 Mdot
.71744 .66364 Mdot
.46591 .74711 Mdot
.63049 .48702 Mdot
.39219 .19257 Mdot
.45771 .75248 Mdot
.30928 .22885 Mdot
.64683 .19394 Mdot
.49671 .2166 Mdot
.57639 .3881 Mdot
.38535 .70885 Mdot
.78686 .45022 Mdot
.78101 .46048 Mdot
.25997 .27 Mdot
.80867 .54227 Mdot
.45851 .53519 Mdot
.42022 .57 Mdot
.41802 .54769 Mdot
.72018 .47678 Mdot
.80475 .40158 Mdot
.42107 .40859 Mdot
.69442 .61579 Mdot
.28065 .43605 Mdot
.75526 .52875 Mdot
.51599 .28566 Mdot
.69306 .65392 Mdot
.56393 .62817 Mdot
.61482 .62601 Mdot
.40301 .73247 Mdot
.17488 .40031 Mdot
.34466 .34208 Mdot
.72474 .27177 Mdot
.33111 .78936 Mdot
.33957 .43027 Mdot
.78905 .55118 Mdot
.35672 .56193 Mdot
.65223 .55797 Mdot
.56471 .78322 Mdot
.71768 .6148 Mdot
.53439 .30038 Mdot
.35807 .28169 Mdot
.57918 .3678 Mdot
.43652 .19015 Mdot
.68451 .59854 Mdot
.16278 .48792 Mdot
.39184 .62877 Mdot
.68623 .31924 Mdot
.51177 .25533 Mdot
.29373 .76297 Mdot
.47631 .52774 Mdot
.2358 .27238 Mdot
.45583 .3774 Mdot
.34372 .20158 Mdot
.29205 .52361 Mdot
.47964 .82187 Mdot
.36475 .32226 Mdot
.59505 .59069 Mdot
.55742 .57141 Mdot
.60332 .18094 Mdot
.30316 .46948 Mdot
.31612 .45033 Mdot
.54173 .66582 Mdot
.44638 .66998 Mdot
.44393 .50897 Mdot
.24723 .37135 Mdot
.17665 .40434 Mdot
.56732 .43413 Mdot
.40598 .64383 Mdot
.78894 .46198 Mdot
.33941 .52097 Mdot
.38296 .36117 Mdot
.35411 .30256 Mdot
.51472 .31437 Mdot
.73967 .52352 Mdot
.21122 .31559 Mdot
.37283 .2999 Mdot
.52735 .63972 Mdot
.70367 .38404 Mdot
.30711 .59964 Mdot
.21227 .62158 Mdot
.27876 .30022 Mdot
.4203 .55732 Mdot
.46865 .48536 Mdot
.7178 .5705 Mdot
.4642 .13217 Mdot
.24446 .27264 Mdot
.25242 .71706 Mdot
.49279 .54409 Mdot
.49227 .36938 Mdot
.71239 .64094 Mdot
.16161 .48355 Mdot
.82184 .40021 Mdot
.30451 .42339 Mdot
.759 .52333 Mdot
.47876 .79033 Mdot
.81946 .55807 Mdot
.46797 .54689 Mdot
.51344 .25561 Mdot
.71309 .2963 Mdot
.3613 .50956 Mdot
.44756 .76513 Mdot
.5171 .5589 Mdot
.27437 .60507 Mdot
.40435 .39529 Mdot
.30426 .4703 Mdot
.1628 .48894 Mdot
.81159 .52973 Mdot
.69819 .38119 Mdot
.17058 .49341 Mdot
.40341 .3349 Mdot
.35359 .61856 Mdot
.23064 .66207 Mdot
.49908 .55292 Mdot
.40768 .71406 Mdot
.63785 .5435 Mdot
.45506 .49157 Mdot
.22283 .39742 Mdot
.44529 .79953 Mdot
.59695 .6605 Mdot
.48601 .30893 Mdot
.821 .53696 Mdot
.45608 .29927 Mdot
.49635 .13677 Mdot
.24972 .38043 Mdot
.47703 .24273 Mdot
.22481 .36538 Mdot
.29872 .65528 Mdot
.33755 .79811 Mdot
.4698 .20562 Mdot
.67146 .5862 Mdot
.48522 .31126 Mdot
.47654 .3157 Mdot
.24566 .33948 Mdot
.34603 .49404 Mdot
.4674 .2183 Mdot
.80421 .42865 Mdot
.2765 .68771 Mdot
.43405 .29867 Mdot
.42004 .57554 Mdot
.50372 .31245 Mdot
.5095 .148 Mdot
.41102 .7179 Mdot
.24585 .26092 Mdot
.60973 .36658 Mdot
.20531 .62155 Mdot
.38746 .27361 Mdot
.46606 .44061 Mdot
.47523 .54013 Mdot
.27089 .67283 Mdot
.60697 .51798 Mdot
.73682 .43659 Mdot
.44185 .36549 Mdot
.26331 .61065 Mdot
.60827 .66988 Mdot
.55889 .67039 Mdot
.33852 .56242 Mdot
.72413 .35762 Mdot
.79762 .37328 Mdot
.48377 .33002 Mdot
.38842 .626 Mdot
.35177 .63624 Mdot
.56078 .49278 Mdot
.77612 .44624 Mdot
.18998 .36761 Mdot
.47121 .20983 Mdot
.46285 .37692 Mdot
.26481 .73378 Mdot
.59427 .72738 Mdot
.54223 .15499 Mdot
.52556 .36795 Mdot
.78932 .45521 Mdot
.7191 .37991 Mdot
.4807 .18427 Mdot
.51327 .28536 Mdot
.37087 .25723 Mdot
.72844 .54546 Mdot
.53209 .66735 Mdot
.77522 .49948 Mdot
.51373 .31123 Mdot
.43183 .53823 Mdot
.81773 .41548 Mdot
.4704 .79276 Mdot
.57284 .27295 Mdot
.66228 .53672 Mdot
.39749 .26995 Mdot
.80103 .41473 Mdot
.48874 .31058 Mdot
.62683 .64345 Mdot
.60123 .217 Mdot
.36546 .33067 Mdot
.43241 .20116 Mdot
.37499 .39429 Mdot
.7933 .45732 Mdot
.41988 .54156 Mdot
.75246 .63027 Mdot
.58981 .36834 Mdot
.60653 .57516 Mdot
.66116 .49339 Mdot
.71739 .4017 Mdot
.52112 .59142 Mdot
.62175 .19351 Mdot
.73015 .45633 Mdot
.39219 .20204 Mdot
.5235 .15689 Mdot
.34262 .24758 Mdot
.38582 .60967 Mdot
.44045 .30319 Mdot
.26678 .24691 Mdot
.78404 .4366 Mdot
.37502 .27499 Mdot
.77079 .33844 Mdot
.83689 .56987 Mdot
.16647 .51091 Mdot
.35435 .37767 Mdot
.42037 .2709 Mdot
.71133 .24903 Mdot
.35066 .41296 Mdot
.83054 .54616 Mdot
.538 .30342 Mdot
.38047 .31255 Mdot
.21109 .2986 Mdot
.74818 .35358 Mdot
.32045 .44651 Mdot
.51129 .26034 Mdot
.49074 .27895 Mdot
.7867 .42005 Mdot
.6467 .53009 Mdot
.41642 .67386 Mdot
.50474 .68677 Mdot
.76228 .53305 Mdot
.51944 .34063 Mdot
.79919 .4352 Mdot
.784 .46403 Mdot
.7849 .56414 Mdot
.27476 .67793 Mdot
.16717 .51089 Mdot
.4712 .25115 Mdot
.69038 .42714 Mdot
.48893 .30809 Mdot
.62609 .65178 Mdot
.74317 .5988 Mdot
.62296 .41418 Mdot
.51801 .53538 Mdot
.7111 .42465 Mdot
.38077 .18821 Mdot
.51876 .71528 Mdot
.27847 .58895 Mdot
.43454 .303 Mdot
.39534 .26441 Mdot
.38836 .53617 Mdot
.2873 .48077 Mdot
.79546 .43524 Mdot
.42972 .24845 Mdot
.31953 .27401 Mdot
.32761 .4429 Mdot
.70872 .58822 Mdot
.67315 .73362 Mdot
.30089 .57501 Mdot
.69173 .28686 Mdot
.25093 .28397 Mdot
.34855 .44039 Mdot
.41584 .36306 Mdot
.28658 .41529 Mdot
.43383 .54136 Mdot
.39494 .42831 Mdot
.30514 .46621 Mdot
.35941 .57986 Mdot
.52019 .22475 Mdot
.28211 .28316 Mdot
.39503 .73674 Mdot
.74853 .57381 Mdot
.25481 .4153 Mdot
.79888 .43162 Mdot
.55921 .49257 Mdot
.40914 .20603 Mdot
.59207 .58792 Mdot
.61447 .73626 Mdot
.63779 .42723 Mdot
.75411 .39952 Mdot
.46483 .19385 Mdot
.27372 .42949 Mdot
.71701 .51847 Mdot
.45184 .38885 Mdot
.75332 .30351 Mdot
.48398 .72261 Mdot
.47568 .73542 Mdot
.80077 .59602 Mdot
.46494 .42079 Mdot
.51899 .66188 Mdot
.23063 .54293 Mdot
.58837 .51412 Mdot
.66762 .73844 Mdot
.40716 .56651 Mdot
.68375 .2779 Mdot
.76415 .34966 Mdot
.18275 .38431 Mdot
.3981 .56353 Mdot
.75888 .30442 Mdot
.7025 .28342 Mdot
.38285 .30946 Mdot
.81733 .52961 Mdot
.61931 .55249 Mdot
.59556 .49533 Mdot
.62651 .64344 Mdot
.40824 .33151 Mdot
.19815 .36014 Mdot
.7381 .4849 Mdot
.65008 .72093 Mdot
.58719 .60348 Mdot
.38263 .58214 Mdot
.37668 .74612 Mdot
.38823 .3827 Mdot
.71295 .24995 Mdot
.74175 .53358 Mdot
.31071 .50206 Mdot
.22642 .39685 Mdot
.66864 .54768 Mdot
.39956 .20463 Mdot
.5324 .60636 Mdot
.4566 .20296 Mdot
.36934 .45385 Mdot
.69276 .30068 Mdot
.5503 .16509 Mdot
.63738 .59486 Mdot
.59256 .56855 Mdot
.4226 .40101 Mdot
.5974 .55569 Mdot
.39585 .44948 Mdot
.53175 .70099 Mdot
.81167 .47125 Mdot
.1697 .44588 Mdot
.21451 .557 Mdot
.60516 .53075 Mdot
.71352 .63576 Mdot
.26604 .3002 Mdot
.4756 .58806 Mdot
.57981 .59479 Mdot
.327 .6293 Mdot
.45031 .76003 Mdot
.40409 .84939 Mdot
.36895 .19018 Mdot
.64025 .42746 Mdot
.54374 .57353 Mdot
.56823 .70386 Mdot
.46236 .72649 Mdot
.56089 .20546 Mdot
.19806 .35553 Mdot
.28803 .57085 Mdot
.30084 .74652 Mdot
.23127 .54438 Mdot
.61183 .18552 Mdot
.24785 .69696 Mdot
.2822 .58568 Mdot
.49443 .13594 Mdot
.30051 .43485 Mdot
.49138 .39793 Mdot
.41417 .8564 Mdot
.58902 .18076 Mdot
.7217 .39092 Mdot
.48402 .67154 Mdot
.37671 .19674 Mdot
.47403 .5381 Mdot
.46213 .63766 Mdot
.75125 .34999 Mdot
.7382 .53844 Mdot
.75228 .57799 Mdot
.24509 .54218 Mdot
.67886 .24942 Mdot
.82128 .63011 Mdot
.30177 .65506 Mdot
.29153 .77549 Mdot
.48129 .215 Mdot
.30056 .25573 Mdot
.2314 .43091 Mdot
.49691 .79211 Mdot
.42583 .20834 Mdot
.77373 .48251 Mdot
.75233 .38205 Mdot
.53331 .76021 Mdot
.63652 .59855 Mdot
.7183 .65526 Mdot
.39227 .43536 Mdot
.48519 .20171 Mdot
.28117 .67452 Mdot
.70163 .5366 Mdot
.77021 .50169 Mdot
.71669 .30769 Mdot
.59745 .56991 Mdot
.27267 .26739 Mdot
.78307 .42717 Mdot
.72786 .55911 Mdot
.27451 .63572 Mdot
.64863 .66957 Mdot
.21322 .33909 Mdot
.40014 .49946 Mdot
.71667 .3861 Mdot
.18548 .56095 Mdot
.29645 .22594 Mdot
.61901 .55271 Mdot
.65362 .40924 Mdot
.5617 .15287 Mdot
.41977 .62936 Mdot
.76119 .34278 Mdot
.2529 .46254 Mdot
.76199 .57304 Mdot
.72105 .44634 Mdot
.65934 .47701 Mdot
.76749 .6359 Mdot
.39876 .29526 Mdot
.71733 .30444 Mdot
.24938 .68682 Mdot
.72603 .55581 Mdot
.72786 .37104 Mdot
.21322 .67231 Mdot
.52575 .35778 Mdot
.46379 .31004 Mdot
.37773 .19374 Mdot
.57272 .19321 Mdot
.73266 .40883 Mdot
.49098 .24162 Mdot
.52999 .61756 Mdot
.66043 .74071 Mdot
.68588 .37668 Mdot
.47961 .51425 Mdot
.76634 .52949 Mdot
.16797 .49613 Mdot
.66527 .25476 Mdot
.23263 .27173 Mdot
.46968 .17939 Mdot
.44639 .29853 Mdot
.74132 .34235 Mdot
.49538 .55509 Mdot
.33518 .25422 Mdot
.26189 .66121 Mdot
.25961 .67725 Mdot
.80669 .64021 Mdot
.56093 .67817 Mdot
.64554 .49048 Mdot
.35683 .46591 Mdot
.43979 .19184 Mdot
.81921 .61793 Mdot
.43175 .19385 Mdot
.7184 .40975 Mdot
.56941 .4537 Mdot
.21778 .71862 Mdot
.31776 .28612 Mdot
.56485 .46683 Mdot
.70348 .49772 Mdot
.71377 .49081 Mdot
.64749 .47804 Mdot
.34166 .49265 Mdot
.71302 .66738 Mdot
.76743 .5597 Mdot
.39412 .1975 Mdot
.41893 .30654 Mdot
.47758 .53716 Mdot
.28959 .58342 Mdot
.53146 .54841 Mdot
.5251 .45317 Mdot
.27378 .52251 Mdot
.77691 .54849 Mdot
.37899 .66939 Mdot
.67171 .6871 Mdot
.40732 .26981 Mdot
.4535 .42818 Mdot
.41656 .24826 Mdot
.79858 .53613 Mdot
.27598 .49815 Mdot
.76961 .67002 Mdot
.78695 .46951 Mdot
.63586 .36368 Mdot
.39234 .40247 Mdot
.85434 .46919 Mdot
.47189 .53038 Mdot
.34728 .48173 Mdot
.53789 .46894 Mdot
.56048 .36957 Mdot
.50144 .22965 Mdot
.57383 .68761 Mdot
.3748 .46617 Mdot
.70658 .39599 Mdot
.44411 .21316 Mdot
.31318 .51588 Mdot
.45207 .14143 Mdot
.56547 .40622 Mdot
.56264 .21455 Mdot
.3881 .22907 Mdot
.35237 .61014 Mdot
.53381 .3035 Mdot
.66551 .49045 Mdot
.51705 .63263 Mdot
.38265 .66248 Mdot
.49984 .31373 Mdot
.33645 .60366 Mdot
.30389 .27199 Mdot
.8043 .55493 Mdot
.53186 .21252 Mdot
.6208 .47694 Mdot
.58661 .67969 Mdot
.4888 .51786 Mdot
.50323 .7793 Mdot
.37809 .69414 Mdot
.37321 .34887 Mdot
.79476 .53951 Mdot
.75381 .58049 Mdot
.52351 .27416 Mdot
.32338 .21855 Mdot
.6746 .53443 Mdot
.49293 .21969 Mdot
.56091 .62043 Mdot
.31797 .38792 Mdot
.77401 .45174 Mdot
.17144 .48793 Mdot
.72854 .43092 Mdot
.65728 .53357 Mdot
.46875 .1576 Mdot
.47137 .20286 Mdot
.25057 .58413 Mdot
.35887 .27731 Mdot
.80934 .46395 Mdot
.55893 .57269 Mdot
.4219 .86412 Mdot
.25691 .66139 Mdot
.4786 .14057 Mdot
.30699 .60524 Mdot
.54477 .43422 Mdot
.43756 .40972 Mdot
.59349 .49976 Mdot
.44117 .70039 Mdot
.32678 .25291 Mdot
.4176 .39838 Mdot
.56889 .54206 Mdot
.68825 .44394 Mdot
.44134 .61478 Mdot
.48875 .30277 Mdot
.1665 .45547 Mdot
.46306 .67635 Mdot
.52772 .63516 Mdot
.20544 .56288 Mdot
.38113 .66602 Mdot
.84058 .55368 Mdot
.26273 .2662 Mdot
.34215 .30881 Mdot
.4113 .56368 Mdot
.43736 .82843 Mdot
.49724 .36103 Mdot
.44163 .27973 Mdot
.34114 .54467 Mdot
.75573 .63464 Mdot
.36361 .43794 Mdot
.17965 .52353 Mdot
.47997 .18065 Mdot
.55863 .49058 Mdot
.44848 .89124 Mdot
.77864 .48379 Mdot
.50395 .59338 Mdot
.35844 .44636 Mdot
.40343 .19345 Mdot
.4382 .78114 Mdot
.63954 .19153 Mdot
.24037 .40814 Mdot
.52187 .35918 Mdot
.74077 .65603 Mdot
.26704 .73468 Mdot
.41131 .58045 Mdot
.29435 .77797 Mdot
.30757 .30633 Mdot
.70422 .65222 Mdot
.26702 .42978 Mdot
.47952 .30974 Mdot
.73613 .44343 Mdot
.25544 .37163 Mdot
.6327 .55102 Mdot
.49676 .38764 Mdot
.30116 .28354 Mdot
.6902 .7154 Mdot
.25439 .62965 Mdot
.33387 .27864 Mdot
.34508 .53329 Mdot
.41499 .39178 Mdot
.79334 .48569 Mdot
.41137 .63964 Mdot
.46475 .69904 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0Toooool2o`000;Cooooo000Looooo`03o`00
0?oooooooooo09?ooooo0_l0002dooooo`007?ooool00ol0003oooooooooo`2?ooooo`;o00001?oo
ool2o`0000Kooooo0ol0002Yooooo`007?ooool00ol0003oooooooooo`2?ooooo`;o00001?ooool2
o`000003ooooool0003o000000?ooooo0ol0002Yooooo`007?ooool00ol0003oooooooooo`2?oooo
o`;o00001oooool2o`000:oooooo000Looooo`03o`000?oooooooooo0:Gooooo0_l0002Rooooo`00
7?ooool00ol0003oooooooooo`2Oooooo`;o000000Coooooo`000?l0003ooooo0_l0002Rooooo`00
7?ooool2o`0009kooooo1?l000000ooooooo0000o`000004ooooo`;o00001oooool4o`0009Cooooo
000Looooo`03o`000?oooooooooo08Wooooo1?l0000@ooooo`Go00001?ooool4o`0000;ooooo0_l0
0003ooooo`Co0000U?ooool001cooooo00?o0000ooooooooool0ROooool4o`0000Sooooo0_l00009
ooooo`;o00001?ooool2o`0000Cooooo0_l0000:ooooo`;o0000Soooool001cooooo00?o0000oooo
ooooool0UOooool2o`0001Oooooo0_l00008ooooo`;o000000?oooooo`000?l00000S?ooool001co
oooo00?o0000ooooooooool0[_ooool3o`0000[ooooo0_l0002<ooooo`007?ooool00ol0003ooooo
ooooo`1oooooo`;o0000;_ooool2o`000003ooooool0003o000009Gooooo000Looooo`03o`000?oo
oooooooo07oooooo0_l0000Yooooo`;o00001_ooool5o`0000Wooooo0_l00027ooooo`007?ooool0
0ol0003oooooooooo`1fooooo`;o0000<_ooool2o`0000;ooooo0_l00004ooooo`Co00002?ooool2
o`0008Oooooo000Looooo`03o`000?oooooooooo07Kooooo0_l0000?ooooo`;o00003?ooool3o`00
01Kooooo0_l00006ooooo`;o0000TOooool001cooooo00?o0000ooooooooool0Qoooool2o`0000Go
oooo0_l00005ooooo`Go00004?ooool2o`0000;ooooo0_l00006ooooo`;o000000Coooooo`000?l0
003ooooo0_l00002ooooo`;o0000Qoooool001cooooo00?o0000ooooooooool0S_ooool2o`0000Go
oooo0_l000000ooooooo0000o`00000@ooooo`;o00003Oooool2o`000003ooooool0003o000000;o
oooo0_l00027ooooo`007?ooool00ol0003oooooooooo`1nooooo`Co00005_ooool2o`0002Gooooo
0_l00002ooooo`;o0000Q?ooool001cooooo00?o0000ooooooooool0M?ooool2o`0000;ooooo0_l0
0004ooooo`Co00002?ooool2o`0000Cooooo0_l0000]ooooo`;o00000_ooool2o`0000;ooooo0_l0
0002ooooo`;o0000O?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo
1Ol00006ooooo`03o`000?oooooooooo077ooooo0_l000001?oooooo0000o`000?ooool3o`0000;o
oooo1Ol00007ooooo`Go00000_ooool3o`000004ooooool0003o0000ooooo`;o00007Oooool3o`00
00kooooo0ol00002ooooo`?o0000Noooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo077ooooo0_l0
0004ooooo`;o00000oooool5o`0000Oooooo0_l000000ooooooo0000o`000002ooooo`;o00000_oo
ool5o`0001gooooo0ol0000>ooooo`?o00000oooool4o`0007Wooooo00000ooooooo410@ooooo`02
ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`1]
ooooo`;o00002?ooool2o`0000?ooooo0_l00008ooooo`;o00000_ooool2o`0000Sooooo0ol0000O
ooooo`?o00003_ooool2o`0000Gooooo0_l0001iooooo`0000?oooooo`000?ooool00_ooool00ol0
003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0001/ooooo`?o00003Oooool2o`00
00Sooooo0_l000001?oooooo0000o`000?l00005ooooo`;o00000_ooool2o`0000?ooooo0_l0000K
ooooo`;o0000T?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00omg
MgOoIVIVooooo`05ooooo`03o`000?oooooooooo06cooooo0_l0000>ooooo`Co000000?oooooo`00
0?l000001_ooool2o`0000Kooooo0_l000001?oooooo0000o`000?l00003ooooo`;o00002oooool2
o`0000Wooooo0_l0002Eooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0=oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0IOooool2o`0000Gooooo0_l00004oooo
o`;o00002_ooool2o`000003ooooool0003o000000Cooooo1?l00009ooooo`?o000000?oooooo`00
0?l000003Oooool2o`0000Wooooo0_l00003ooooo`;o00000_ooool2o`0008cooooo00001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oo
oooooooo06Gooooo0_l00005ooooo`;o00000_ooool4o`0001?ooooo1?l00005ooooo`;o00000ooo
ool2o`000003ooooool0003o000000gooooo0_l0000=ooooo`?o00000_ooool2o`0008cooooo0000
1_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03
o`000?oooooooooo073ooooo0_l00009ooooo`;o00004?ooool5o`0000?ooooo0_l00002ooooo`;o
00003?ooool4o`0000Sooooo0_l000000ooooooo0000o`00002Aooooo`007?ooool00ol0003ooooo
ooooo`1]ooooo`;o00000_ooool2o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l00000
1oooool2o`0000Cooooo0ol00004ooooo`;o00000oooool2o`0000?ooooo0_l00008ooooo`?o0000
2?ooool2o`0000_ooooo0_l00007ooooo`;o0000O_ooool001cooooo00?o0000ooooooooool0IOoo
ool2o`0000Kooooo0_l00002ooooo`;o00001?ooool2o`0000Gooooo0_l00007ooooo`;o00002ooo
ool2o`0000Kooooo1?l00008ooooo`;o00005_ooool2o`0000Oooooo1?l0001looooo`007?ooool0
0ol0003oooooooooo`1Nooooo`;o00001Oooool2o`0000cooooo0_l0000?ooooo`?o00005Oooool2
o`0002_ooooo1?l0001looooo`007?ooool00ol0003oooooooooo`1Mooooo`?o00002?ooool2o`00
00Sooooo0ol0000?ooooo`?o00001?ooool2o`0000Kooooo0_l0000@ooooo`;o00008_ooool2o`00
00oooooo0_l0001]ooooo`007?ooool00ol0003oooooooooo`1Kooooo`Co00000_ooool2o`0000Go
oooo0_l00008ooooo`;o00001?ooool6o`0000Cooooo0_l00007ooooo`;o00001_ooool2o`0000[o
oooo0_l00004ooooo`;o0000;_ooool2o`0000?ooooo0ol0001/ooooo`007?ooool00ol0003ooooo
ooooo`1Hooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00003_ooool2o`0000?ooooo
2_l00002ooooo`;o00003oooool3o`0000Wooooo0_l0000dooooo`;o00001?ooool2o`0000;ooooo
0_l0001Xooooo`007?ooool00ol0003oooooooooo`1Gooooo`?o00000oooool2o`0000Cooooo0_l0
0007ooooo`;o00000oooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`000003ooooool0
003o000000;ooooo0ol0000<ooooo`;o000000?oooooo`000?l000000_l0000Booooo`;o00002Ooo
ool2o`0002Kooooo1?l0001Xooooo`007?ooool00ol0003oooooooooo`1Gooooo`;o00001_ooool2
o`0000;ooooo0_l00007ooooo`;o00005?ooool3o`0000cooooo0_l00003ooooo`;o00004_ooool2
o`0000Wooooo0_l0000Oooooo`;o00001Oooool2o`0006[ooooo000Looooo`03o`000?oooooooooo
05?ooooo0_l0000:ooooo`;o00004?ooool3o`0001[ooooo0_l00007ooooo`;o00000oooool2o`00
01Kooooo1?l0000Aooooo`Co000000?oooooo`000?l000001_ooool4o`0006oooooo000Looooo`03
o`000?oooooooooo05?ooooo0_l0000Looooo`?o00002Oooool2o`0000oooooo0_l00006ooooo`Co
00000_ooool2o`0001Kooooo1?l0000Aooooo`Co000000?oooooo`000?l000000_l00004ooooo`Co
0000Koooool001cooooo00?o0000ooooooooool0Doooool2o`0001Oooooo1?l00003ooooo`;o0000
2?ooool2o`0000;ooooo1Ol00002ooooo`;o00003?ooool4o`0002oooooo0_l00005ooooo`;o0000
1_ooool4o`0000Oooooo0_l0001Tooooo`007?ooool2o`0005Cooooo0_l0000=ooooo`;o00002?oo
ool4o`0000?ooooo0_l0000<ooooo`Ko000000?oooooo`000?l000002oooool2o`0001cooooo0_l0
000Tooooo`Go00001Oooool3o`0006?ooooo000Looooo`03o`000?oooooooooo05;ooooo0_l0000>
ooooo`;o00000_ooool5o`0001Wooooo0ol00005ooooo`;o00001Oooool4o`0000;ooooo0_l00000
0ooooooo0000o`000004ooooo`;o00001_ooool2o`0000Oooooo0_l0000Oooooo`?o00000_ooool5
o`0000Gooooo0ol0001Sooooo`007?ooool00ol0003oooooooooo`1Booooo`;o00002_ooool2o`00
00Kooooo1Ol0000:ooooo`;o00005Oooool2o`0000Gooooo0_l00004ooooo`;o000000Coooooo`00
0?l0003o00000oooool3o`0000Cooooo0ol00002ooooo`;o00009?ooool3o`0000?ooooo0ol00006
ooooo`?o0000Hoooool001cooooo00?o0000ooooooooool0C?ooool2o`00013ooooo0_l0000Eoooo
o`;o00006oooool2o`0000Sooooo0ol00003ooooo`?o00001?ooool2o`0000?ooooo0_l00005oooo
o`;o00008oooool2o`0000Sooooo0_l0001Sooooo`007?ooool00ol0003oooooooooo`1<ooooo`?o
00002oooool2o`0000Gooooo0_l0000Aooooo`;o00001_ooool3o`00017ooooo1?l00009ooooo`;o
00000_ooool3o`0000Sooooo0_l00007ooooo`;o00008Oooool2o`0006oooooo000Looooo`03o`00
0?oooooooooo04gooooo0_l00003ooooo`;o000000?oooooo`000?l000000oooool2o`0000Gooooo
0_l0000Aooooo`;o00001_ooool3o`00017ooooo0_l0000;ooooo`;o00000_ooool2o`0000Wooooo
0_l00008ooooo`;o00008?ooool2o`0006oooooo000Looooo`03o`000?oooooooooo04[ooooo0_l0
0005ooooo`?o000000?oooooo`000?l000000_l0000Mooooo`;o00001?ooool3o`0000;ooooo0_l0
00000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000002Oooool2o`0001Gooooo0_l0
0007ooooo`;o00006?ooool2o`0007Oooooo000Looooo`03o`000?oooooooooo04Sooooo1_l00003
ooooo`;o00001?ooool4o`0000Cooooo0_l0000Eooooo`;o00000_ooool5o`0000;ooooo0_l00000
1Ooooooo0000o`000?l0003ooooo00Go000000?oooooo`000?l000001_ooool2o`0000Gooooo0_l0
0006ooooo`?o00001Oooool2o`0000Oooooo0_l0000Gooooo`Go00005?ooool2o`0005oooooo000L
ooooo`03o`000?oooooooooo04Sooooo0ol000000ooooooo0000o`00000;ooooo`;o00001?ooool2
o`0000?ooooo0_l00004ooooo`;o00002_ooool2o`0000;ooooo0_l00006ooooo`Go000000Cooooo
o`000?l0003o00000oooool2o`0000gooooo0_l00003ooooo`Ko00000oooool2o`0000Wooooo0_l0
000Gooooo`;o000000?oooooo`000?l000003?ooool2o`0000Kooooo0_l0001Oooooo`007?ooool0
0ol0003oooooooooo`1Oooooo`;o00000oooool4o`000004ooooool0003o0000o`0000Gooooo0ol0
0002ooooo`;o00002_ooool5o`000005ooooool0003o0000o`000?ooool00_l0000>ooooo`;o0000
1?ooool3o`000003ooooool0003o000000?ooooo0_l00009ooooo`;o00007Oooool2o`0000?ooooo
0_l00004ooooo`;o00001_ooool2o`0005oooooo000Looooo`03o`000?oooooooooo04[ooooo0_l0
000<ooooo`;o00001Oooool2o`0000Gooooo0_l000000ooooooo0000o`000003ooooo`Ko00001Ooo
ool2o`0000?ooooo2Ol000000ooooooo0000o`000004o`0000kooooo0_l00005ooooo`?o00002_oo
ool4o`00027ooooo1?l000000ooooooo0000o`00001]ooooo`007?ooool00ol0003oooooooooo`1:
ooooo`;o00000_ooool2o`0000Sooooo0_l00003ooooo`?o00000oooool2o`000003ooooool0003o
000000;o00000_ooool7o`0000Kooooo0_l00002ooooo`So00001Oooool2o`0000Cooooo1_l00008
ooooo`;o00000oooool4o`0000Wooooo1?l0000Rooooo`?o00001Oooool4o`0000Wooooo0_l0001L
ooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00002Oooool2o`0000gooooo0ol00003oooo
o`;o00000oooool3o`000003ooooool0003o000000?o00000oooool2o`0000Gooooo1?l00007oooo
o`;o00000_ooool2o`0000?ooooo1ol00005ooooo`;o000000?oooooo`000?l000000oooool4o`00
00Cooooo0_l0000`ooooo`Wo00001Oooool2o`0005cooooo000Looooo`03o`000?oooooooooo04?o
oooo0_l0000Looooo`;o00001_ooool3o`000004ooooool0003o0000o`0000Cooooo0_l00004oooo
o`?o00002Oooool8o`000003ooooool0003o000000;o00001oooool3o`0000cooooo1?l0000`oooo
o`?o00000_ooool4o`0006?ooooo000Looooo`03o`000?oooooooooo067ooooo0_l000000ooooooo
0000o`000003ooooo`Ko00002oooool6o`0000Oooooo3?l000000ooooooo0000o`000002o`0000;o
oooo0ol0000:ooooo`Co00002?ooool2o`0002Sooooo1?l00002ooooo`;o0000I?ooool001cooooo
00?o0000ooooooooool0@Oooool2o`00027ooooo0_l00006ooooo`?o00001Oooool2o`0000Gooooo
1Ol00006ooooo`_o00000oooool5o`0000;ooooo0_l0000:ooooo`;o00002_ooool2o`000004oooo
ool0003o0000o`0002Cooooo1?l00003ooooo`;o0000Hoooool001cooooo0_l00012ooooo`;o0000
4?ooool2o`0000;ooooo0_l0000Aooooo`Co00001_ooool3o`0000Cooooo0_l00006ooooo`;o0000
00?oooooo`000?l000002_l00002ooooo`;o000000?oooooo`000?l000000_ooool4o`0000Wooooo
1_l000000ooooooo0000o`000005ooooo`?o00009?ooool4o`0000?ooooo0_l0001Sooooo`007?oo
ool00ol0003oooooooooo`1Cooooo`;o00000_ooool2o`0000Gooooo0_l00005ooooo`;o00000ooo
ool4o`000003ooooool0003o000000;ooooo1?l0000<ooooo`;o000000Coooooo`000?l0003ooooo
3_l00004ooooo`Co00002Oooool<o`0000?ooooo0_l0000Tooooo`Co00001?ooool2o`0000;ooooo
0_l00006ooooo`Co0000E?ooool001cooooo00?o0000ooooooooool0G_ooool4o`0000?ooooo0_l0
0005ooooo`Go00000_ooool2o`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l000000ol0
0003ooooo`ko00000oooool3o`0000cooooo1_l00002ooooo`?o00000oooool2o`0002Kooooo0ol0
0003ooooo`;o000000Coooooo`000?l0003o00001_ooool4o`0005Cooooo000Looooo`03o`000?oo
oooooooo05Wooooo0_l00003ooooo`Co00001Oooool2o`0000;ooooo1ol00003ooooo`;o000000?o
ooooo`000?l000000ol000001?oooooo0000o`000?ooool6o`000003ooooool0003o000000go0000
00?oooooo`000?l000000ol00004ooooo`;o000000?oooooo`000?l000000oooool:o`0002cooooo
0ol00003ooooo`;o000000?oooooo`000?l000000_l00004ooooo`Go0000E?ooool001cooooo00?o
0000ooooooooool0FOooool2o`0000?ooooo0_l00007ooooo`;o00000_ooool2o`0000;ooooo0ol0
0003ooooo`;o000000?oooooo`000?l000000ol00004oooooaco00000_ooool7o`0000Cooooo1ol0
0007ooooo`;o0000;_ooool4o`0000Cooooo0_l0000=ooooo`;o0000B?ooool001cooooo00?o0000
ooooooooool0@Oooool2o`0001Kooooo0_l00009ooooo`;o00002Oooool2o`0000Oooooo0_l00000
0ooooooo0000o`000004oooooaSo000000?oooooo`000?l000002Ol0000?ooooo`;o00000_ooool2
o`0004Gooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`0looooo`;o00000oooool2o`00
00kooooo0_l00006ooooo`;o00001_ooool2o`000003ooooool0003o000001_ooooo0_l000000ooo
oooo0000o`00000Co`0000Cooooo0_l00004ooooo`;o00001Oooool2o`0000Sooooo0_l00002oooo
o`;o00008Oooool2o`000003ooooool0003o000006Wooooo000Looooo`03o`000?oooooooooo03co
oooo0_l00003ooooo`;o00003_ooool2o`0000kooooo0ol00009ooooo`;o00001?ooool2o`0000?o
oooo0_l00007ooooo`;o000000?oooooo`000?l000004_l000000ooooooo0000o`00000?ooooo`?o
0000;_ooool2o`000003ooooool0003o0000017ooooo0ol0001Eooooo`007?ooool00ol0003ooooo
ooooo`0mooooo`;o00008oooool2o`0000Cooooo0_l00003ooooo`;o00001?ooool2o`0000?ooooo
0_l00006oooooa_o000000?oooooo`000?l000000_l0000;ooooo`;o00004Oooool2o`0002[ooooo
0ol00004ooooo`?o0000EOooool001cooooo00?o0000ooooooooool0?Oooool2o`0002Wooooo0_l0
000<ooooo`;o00002?oooolJo`0000;ooooo1?l00005ooooo`;o00005oooool3o`0001cooooo0_l0
000;ooooo`?o00001?ooool4o`0005Cooooo000Looooo`03o`000?oooooooooo03kooooo0_l0000S
ooooo`;o00003_ooool2o`000003ooooool0003o000000Wooooo6_l0000:ooooo`;o00006?ooool2
o`0001Cooooo0ol00005ooooo`;o00005?ooool5o`00057ooooo000Looooo`03o`000?oooooooooo
03kooooo0_l0000Sooooo`;o00001?ooool2o`0000?ooooo1?l000000ooooooo0000o`00000:oooo
o`go000000?oooooo`000?l000003ol0000:ooooo`;o00002Oooool2o`0000[ooooo0_l000000ooo
oooo0000o`00000@ooooo`Co00007Oooool3o`00057ooooo000Looooo`03o`000?oooooooooo06Wo
oooo0_l00003ooooo`Co00001?ooool2o`0000Kooooo1?l000000ooooooo0000o`00000Ko`0000Oo
oooo0ol00004ooooo`;o00000oooool2o`0000[ooooo0_l000000ooooooo0000o`00000@ooooo`;o
00002?ooool2o`0000_ooooo0ol00005ooooo`;o00000_ooool2o`0000Wooooo0_l00015ooooo`00
7?ooool00ol0003oooooooooo`12ooooo`;o00002?ooool2o`0002Cooooo0_l00002ooooo`;o0000
1_ooool4o`000003ooooool0003o000001So000000Coooooo`000?l0003o00001?ooool6o`0000?o
oooo0_l00007ooooo`Go00000oooool2o`0001;ooooo0_l00009ooooo`;o00002oooool3o`0000Go
oooo0_l00002ooooo`;o00002Oooool3o`0004Cooooo000Looooo`03o`000?oooooooooo04;ooooo
0_l00008ooooo`;o00007_ooool2o`0000Cooooo1?l00007ooooo`;o00000ooooolDo`000003oooo
ool0003o000000Co00000_ooool2o`0000Cooooo0_l00002ooooo`;o00000oooool2o`0000Oooooo
1Ol0000Gooooo`;o00000_ooool2o`0001Cooooo0_l00004ooooo`?o00003Oooool2o`0004Cooooo
000Looooo`03o`000?oooooooooo03kooooo0_l0000/ooooo`;o00001_ooool2o`0000Oooooo7ol0
00000ooooooo0000o`00000Hooooo`;o00007_ooool2o`0000Wooooo0_l00009ooooo`;o00001?oo
ool3o`0005?ooooo000Looooo`;o0000?oooool2o`0003Cooooo0ol00008ooooo`Go000000?ooooo
o`000?l000006?l0000Hooooo`;o00002?ooool5o`0000;ooooo1?l0000;ooooo`;o00002Oooool2
o`0000cooooo0_l00002ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0M?ooool3o`00
00Oooooo0_l00002ooooo`;o000000?oooooo`000?l000006?l0000Rooooo`Go00000_ooool4o`00
00kooooo1Ol00005ooooo`;o00002Oooool3o`0000;ooooo0_l0001Cooooo`007?ooool00ol0003o
ooooooooo`0mooooo`;o00002Oooool4o`0002_ooooo0_l00005ooooo`;o00000_ooool2o`000003
ooooool0003o000001So00003Oooool2o`0000Cooooo0_l0000Uooooo`Ko00001Oooool2o`0000Wo
oooo0ol0001Gooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00000_ooool2o`0000Wooooo
1?l0000Yooooo`Co00002_oooolMo`0000Kooooo0ol00003ooooo`;o00001?ooool2o`0001Wooooo
1?l000000ooooooo0000o`000005ooooo`;o00002Oooool2o`000003ooooool0003o000000Oooooo
0_l0000<ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0>Oooool2o`0000;ooooo0_l0
0009ooooo`;o00007oooool2o`0000[ooooo0_l00002ooooo`;o00002?ooool9o`000003ooooool0
003o0000017o00001_ooool3o`00013ooooo0_l000000ooooooo0000o`000004ooooo`;o00002Ooo
ool4o`000003ooooool0003o000000Cooooo1Ol00004ooooo`;o000000Coooooo`000?l0003ooooo
0_l0000Eooooo`;o0000BOooool001cooooo00?o0000ooooooooool0AOooool2o`000003ooooool0
003o000001oooooo0_l0000>ooooo`;o00000oooool2o`0000?ooooo6?l000000ooooooo0000o`00
0002o`0000;ooooo0_l0000Dooooo`?o000000?oooooo`000?l000001?ooool2o`0000Oooooo0_l0
000;ooooo`So000000Coooooo`000?l0003ooooo0_l0001Sooooo`007?ooool00ol0003ooooooooo
o`0jooooo`;o00002Oooool2o`000003ooooool0003o0000027ooooo0_l00008ooooo`So000000?o
ooooo`000?l000001OoooolFo`000003ooooool0003o000000Cooooo0_l00003ooooo`;o00003?oo
ool2o`000003ooooool0003o000000Co00001?ooool3o`0000Kooooo0_l00006ooooo`;o00001?oo
ool7o`0000Cooooo0_l0001Sooooo`007?ooool00ol0003oooooooooo`0jooooo`;o00004Oooool4
o`0001[ooooo0_l00008ooooo`Co00000_ooool2o`0000Sooooo0_l00003ooooo`co000000?ooooo
o`000?l000001Ol00009ooooo`;o00002Oooool2o`000004ooooool0003o0000ooooo`Ko00000ooo
ool4o`0000Oooooo0_l00005ooooo`;o00001oooool2o`0000Kooooo0_l00003ooooo`;o0000G_oo
ool001cooooo00?o0000ooooooooool0>_ooool2o`0000[ooooo0_l00005ooooo`Co00009Oooool5
o`0000[ooooo0_l00004oooooa;o00004_ooool2o`000003ooooool0003o000000gooooo0_l00000
0ooooooo0000o`000002o`000004ooooool0003o0000ooooo`Co00002oooool2o`0000;ooooo0ol0
0007ooooo`;o00004Oooool2o`000003ooooool0003o000000Kooooo0_l00010ooooo`007?ooool0
0ol0003oooooooooo`0jooooo`;o00002_ooool2o`0000?ooooo0_l0000Rooooo`;o00001Oooool5
o`0000?ooooo0_l00008ooooo`?o00001?ooool;o`0000Cooooo0_l00004ooooo`;o000000?ooooo
o`000?l000000_l00004ooooo`;o00004oooool4o`000004ooooool0003o0000ooooo`Co00002ooo
ool2o`0000;ooooo0ol00003ooooo`;o00005Oooool2o`000003ooooool0003o000000Kooooo0_l0
0010ooooo`007?ooool00ol0003oooooooooo`1;ooooo`Co00008?ooool4o`0000Cooooo0ol00004
ooooo`;o00002?ooool4o`0000Cooooo1Ol000000ooooooo0000o`000002o`0000Cooooo0_l00000
1?oooooo0000o`000?ooool2o`000003ooooool0003o000000;o00004Oooool2o`0000kooooo1_l0
0009ooooo`;o00000_ooool5o`000004ooooool0003o0000o`0000kooooo0_l0000?ooooo`;o0000
@?ooool001cooooo00?o0000ooooooooool0>?ooool2o`0000cooooo0_l00005ooooo`;o00008_oo
ool2o`0000Cooooo1Ol0000<ooooo`Co000000?oooooo`000?l000000oooool3o`000004ooooool0
003o0000o`0000Kooooo1?l000000ooooooo0000o`00000=ooooo`Co000000?oooooo`000?l00000
1Ol0000>ooooo`Go00003Oooool5o`0000;ooooo0_l00003ooooo`;o00001?ooool2o`0000?ooooo
0_l0000?ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0>?ooool2o`0000cooooo0_l0
0005ooooo`;o00005Oooool2o`0000?ooooo1?l0000;ooooo`Co00002oooool:o`000003ooooool0
003o000000;ooooo0ol00005ooooo`Co00001?ooool2o`0000_ooooo1?l000000ooooooo0000o`00
0002o`000004ooooool0003o0000o`0000Cooooo0_l0000Jooooo`?o00000_ooool2o`0000Cooooo
0_l00004ooooo`;o00003Oooool2o`0004Oooooo000Looooo`03o`000?oooooooooo03Oooooo0_l0
000Wooooo`?o000000?oooooo`000?l000000oooool4o`0000_ooooo0_l0000=ooooo`[o00003Ooo
ool2o`0000Kooooo0_l0000?ooooo`;o00001Oooool4o`0000;ooooo0_l00006ooooo`;o00000_oo
ool3o`0000Gooooo0_l00006ooooo`?o00000_ooool4o`0000;ooooo0_l0000Cooooo`;o0000Aooo
ool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413ooooo
ooooo`04ooooo`03o`000?oooooooooo03Oooooo0_l0000Wooooo`?o00004oooool2o`0000Oooooo
0_l00002ooooo`;o00001oooool2o`000003ooooool0003o000000[ooooo1?l00005ooooo`;o0000
4Oooool2o`0000Kooooo0ol0000:ooooo`Wo00000oooool2o`0000Cooooo1ol00002ooooo`;o0000
0_ooool2o`0000Kooooo0_l0000Booooo`;o0000@?ooool00006oooooomgMgOoV9RHoooooonHV9So
MgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`16ooooo`;o
0000;_ooool2o`0000Kooooo1?l000000ooooooo0000o`000003ooooo`;o00004Oooool4o`000003
ooooool0003o000000;ooooo0_l0000Xooooo`;o00000_ooool3o`0000Gooooo0_l00002ooooo`Oo
00001_ooool2o`0000Gooooo0ol0000Booooo`;o0000@?ooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool02Oooool5o`0000Kooooo00?o0000ooooooooool0AOooool3o`0002_ooooo
0_l000001?oooooo0000o`000?ooool2o`0000?ooooo1?l00002ooooo`;o00000_ooool2o`0001;o
oooo0_l00002ooooo`;o00007?ooool4o`0000Sooooo0_l00002ooooo`;o00000_ooool2o`000004
ooooool0003o0000ooooo`Co00001_ooool2o`0000;ooooo0_l00009ooooo`?o00003?ooool2o`00
00Gooooo0_l00010ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04
odA4A?oMgMgoooooo`0000Oooooo0ol0000eooooo`;o00003?ooool5o`0002_ooooo0_l00004oooo
o`;o000000?oooooo`000?l000001_ooool4o`0000;ooooo1?l0000;ooooo`;o000000?oooooo`00
0?l000000_ooool2o`0001Kooooo0_l00002ooooo`Oo00000_ooool4o`000005ooooool0003o0000
o`000?ooool00_l00002ooooo`Wo00002_ooool3o`0000Wooooo0_l0000=ooooo`Co00000oooool2
o`00043ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEE
EOoooooo00001oooool00ol0003oooooooooo`0eooooo`?o00002oooool2o`0000?ooooo0_l0000H
ooooo`;o00002_ooool2o`0000?ooooo0_l00007ooooo`;o00001_ooool4o`0000;ooooo1?l0000;
ooooo`;o00006Oooool2o`0000;ooooo0_l00002ooooo`Oo00000_ooool8o`000005ooooool0003o
0000o`000?ooool01_l000000ooooooo0000o`000002o`0000Cooooo0ol000001?oooooo0000o`00
0?ooool2o`0001Sooooo0_l00002ooooo`;o0000@Oooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo03Kooooo0_l0
000;ooooo`;o00000oooool4o`0001Kooooo0_l0000:ooooo`;o00003?ooool4o`0000Cooooo0ol0
0005ooooo`;o00002oooool2o`0001Wooooo0_l000001?oooooo0000o`000?ooool6o`000003oooo
ool0003o000000[o000000?oooooo`000?l000001?l00002ooooo`Co000000?oooooo`000?l00000
1?ooool3o`0000Cooooo1?l0000Jooooo`;o0000@Oooool00006oooooomgMgOoV9RHoooooonHV9So
MgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo04Wooooo0ol0000booooo`;o
00001?ooool3o`000003ooooool0003o000000Co0000:Oooool@o`000003ooooool0003o000000;o
00000_ooool6o`0000;ooooo1?l00007ooooo`;o00000oooool2o`0000;ooooo0ol0001Looooo`00
00Koooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000oooo
ooooool0BOooool2o`0000Cooooo0_l00008ooooo`;o00004_ooool3o`0001Cooooo0_l00002oooo
o`Ko0000:_ooool4o`000003ooooool0003o000001Go00000_ooool2o`0000Gooooo0_l00007oooo
o`;o00000oooool2o`0001?ooooo1?l00002ooooo`;o0000@Oooool001cooooo00?o0000oooooooo
ool0A?ooool2o`0000Wooooo0_l00008ooooo`;o00004_ooool3o`0000gooooo1?l000000ooooooo
0000o`000002o`00033ooooo8_l00005ooooo`;o00008Oooool4o`0000;ooooo0_l00011ooooo`00
7?ooool00ol0003oooooooooo`0oooooo`;o00000oooool2o`0003Oooooo1?l000000ooooooo0000
o`00000?ooooo`;o00007OoooolUo`0000?ooooo1Ol0000Eooooo`;o00001_ooool2o`0000?ooooo
0_l00016ooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00000_ooool2o`0000Oooooo0_l0
000Aooooo`;o000000?oooooo`000?l000000oooool2o`0001Kooooo1?l0000@ooooo`;o00007Ooo
ool4o`000003ooooool0003o000000ko000000?oooooo`000?l000003_l00002ooooo`Go00001?oo
ool2o`0000_ooooo0_l00002ooooo`;o00001_ooool2o`0000?ooooo0_l00003ooooo`;o0000@Ooo
ool001cooooo00?o0000ooooooooool0=_ooool2o`0000Sooooo0_l000001?oooooo0000o`000?oo
ool2o`0000Cooooo0ol0000;ooooo`;o00000oooool2o`000003ooooool0003o000000Go00003?oo
ool2o`0000Sooooo1?l0000=ooooo`;o00007_oooolXo`0000;ooooo1_l00003ooooo`;o00002ooo
ool2o`0000Sooooo0ol00005ooooo`;o00000_ooool2o`00047ooooo000Looooo`03o`000?oooooo
oooo03Kooooo0_l00008ooooo`;o00001?ooool3o`0000Cooooo0_l00004ooooo`Co00000oooool2
o`0000Sooooo1Ol000001?oooooo0000o`000?l00008ooooo`;o00001_ooool2o`00013ooooo0ol0
000Nooooo`;o000000?oooooo`000?l000008ol00002ooooo`Ko00002Oooool2o`0000Gooooo0_l0
0008ooooo`?o00001?ooool3o`0004Gooooo000Looooo`03o`000?oooooooooo043ooooo0_l00005
ooooo`?o00000oooool2o`000003ooooool0003o000000Go00001?ooool2o`0000Kooooo0_l00002
ooooo`Ko00004?ooool2o`0000Kooooo0_l00008ooooo`?o00007_ooool_o`0000Wooooo0ol00000
0ooooooo0000o`00000Booooo`Co0000AOooool001cooooo00?o0000ooooooooool0@?ooool2o`00
00Gooooo1?l00002ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`000003ooooool0003o
000000;ooooo0_l000001?oooooo0000o`000?ooool4o`0000?ooooo1?l0000@ooooo`;o000000?o
ooooo`000?l000001?ooool2o`0001Sooooo0_l0000<ooooo`;o00000ooooolYo`000004ooooool0
003o0000o`0000Sooooo0ol00002ooooo`;o00000oooool2o`0000Sooooo2Ol00015ooooo`007?oo
ool00ol0003oooooooooo`17ooooo`Co00001Oooool2o`0000;ooooo0_l000000ooooooo0000o`00
0002ooooo`;o000000?oooooo`000?l000001?l00004ooooo`?o00001oooool2o`0000Sooooo0_l0
00000ooooooo0000o`00000>ooooo`;o000000?oooooo`000?l000002oooool2o`0000cooooo0_l0
0005oooooaKo000000?oooooo`000?l000003ol000000ooooooo0000o`000008ooooo`?o00000_oo
ool2o`0000?ooooo0_l00002ooooo`;o00001?ooool7o`0004Oooooo000Looooo`03o`000?oooooo
oooo053ooooo0_l00009ooooo`;o00000oooool6o`000003ooooool0003o000000;o00000_ooool2
o`0000?ooooo0_l0000<ooooo`;o000000?oooooo`000?l000000oooool2o`0000Gooooo1ol0000:
ooooo`;o00003ooooolIo`000003ooooool0003o000000?o000000?oooooo`000?l000002ol0000=
ooooo`;o00002?ooool2o`0000;ooooo1?l0001<ooooo`007?ooool00ol0003oooooooooo`0coooo
o`;o0000:Oooool2o`0000?ooooo0ol000000ooooooo0000o`000002o`0000;ooooo0_l00002oooo
o`;o000000?oooooo`000?l000002?ooool4o`000003ooooool0003o000000?ooooo0_l00007oooo
o`Go00002_ooool2o`0000kooooo1_l00002oooooaGo000000?oooooo`000?l000000ol000000ooo
oooo0000o`000008o`0000Sooooo0_l00003ooooo`;o00002oooool5o`0000Sooooo0_l00012oooo
o`007?ooool00ol0003oooooooooo`0cooooo`;o0000:Oooool2o`0000?ooooo0ol00004ooooo`;o
000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000Cooooo2_l0000;ooooo`;o
000000?oooooo`000?l000005?ooool2o`0000Kooooo;_l00008ooooo`;o00000oooool2o`0000;o
oooo0_l00003ooooo`;o00000_ooool2o`0000Wooooo1?l00007ooooo`;o0000>Oooool001cooooo
0_l0000cooooo`;o00004Oooool4o`0001Oooooo1ol00003ooooo`;o00000_ooool2o`0000[ooooo
2_l00002ooooo`;o00001oooool5o`0000kooooo0_l00004ooooo`;o00001_ooool_o`00013ooooo
0_l00003ooooo`;o00000_ooool2o`0000;ooooo0_l00005ooooo`;o00002Oooool2o`0003Wooooo
000Looooo`03o`000?oooooooooo037ooooo0ol0000Aooooo`Ko00005Oooool7o`0000Gooooo1?l0
0004oooooa3o00000_ooool2o`0000Oooooo1ol0000<ooooo`Co000000?oooooo`000?l000000_oo
ool2o`0000?ooooo;ol0000;ooooo`?o00002oooool2o`0000;ooooo0ol00003ooooo`Co0000@ooo
ool001cooooo00?o0000ooooooooool0<Oooool3o`0001Gooooo0_l0000Fooooo`?o00000_ooool2
o`000003ooooool0003o000000?o00001_ooool?o`0000kooooo1Ol0000>ooooo`;o000000?ooooo
o`000?l000000_ooool2o`0000?ooooo;ol00002ooooo`;o00001_ooool4o`0000cooooo0_l00002
ooooo`Co000000?oooooo`000?l000000_l0000<ooooo`;o0000=Oooool001cooooo00?o0000oooo
ooooool0<_ooool2o`0002_ooooo0_l000000ooooooo0000o`000002ooooo`;o000000Coooooo`00
0?l0003o00002Oooool?o`0000_ooooo0_l000000ooooooo0000o`00000Dooooo`;o00001_ooool4
o`0000;ooooo7ol000000ooooooo0000o`000007o`0000;ooooo0_l00006ooooo`Co00002_ooool5
o`0000;ooooo0ol00002ooooo`?o00000_ooool2o`0000?ooooo0_l00003ooooo`;o0000=Oooool0
01cooooo00?o0000ooooooooool0C_ooool3o`0000Oooooo0_l00005ooooo`;o000000?oooooo`00
0?l000000_ooool2o`0000kooooo3_l000000ooooooo0000o`000008ooooo`;o000000?oooooo`00
0?l000000_l0000Booooo`;o00001_ooool2o`0000Cooooo7_l00002ooooo`;o00001?ooool2o`00
00gooooo0_l0000:ooooo`;o000000?oooooo`000?l000000_l00005ooooo`?o00000_ooool2o`00
00?ooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`1>ooooo`?o00001oooool2o`0000Go
oooo0_l000000ooooooo0000o`000002ooooo`;o00001_ooool5o`0000;ooooo3Ol00003ooooo`;o
00003Oooool2o`0001_ooooo0_l000000ooooooo0000o`00000Mo`000003ooooool0003o000000Co
000000Coooooo`000?l0003o00007Oooool4o`0000Cooooo0ol00013ooooo`007?ooool00ol0003o
ooooooooo`1Oooooo`;o00002_ooool2o`000003ooooool0003o000000?o000000?oooooo`000?l0
00000ol000000ooooooo0000o`000005o`0001Kooooo1?l0000@ooooo`;o00001?ooool6o`000003
ooooool0003o000001Wo000000?oooooo`000?l000001?l000001?oooooo0000o`000?l0000Noooo
o`?o000000?oooooo`000?l000000_ooool2o`0000cooooo0_l0000eooooo`007?ooool00ol0003o
ooooooooo`1=ooooo`;o00004?ooool2o`0000[ooooo0_l00003ooooo`;o00000_ooool=o`0000?o
oooo0_l0000=ooooo`;o00000_ooool6o`0000kooooo0ol00003ooooo`?o00001?oooolNo`000003
ooooool0003o000000;ooooo0_l0000Oooooo`;o00000_ooool2o`0000;ooooo0_l0000<ooooo`;o
0000=Oooool001cooooo00?o0000ooooooooool0;oooool2o`0001cooooo0_l00007ooooo`;o0000
7?ooool=o`0000?ooooo0_l0000=ooooo`;o00000_ooool6o`0000cooooo0_l000000ooooooo0000
o`000003ooooo`Co00001_oooolNo`0000;ooooo0_l00009ooooo`;o00005?ooool2o`0000Kooooo
0_l00013ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00009Oooool2o`0000?ooooo0_l0
000>ooooo`;o00001oooool@o`0000;ooooo0_l0000<ooooo`Co000000?oooooo`000?l000003_oo
ool2o`0000Oooooo0ol00005oooooaoo00000_ooool2o`0000Wooooo0_l0000Zooooo`;o0000=Ooo
ool001cooooo00?o0000ooooooooool0C?ooool2o`0000cooooo0ol0000:ooooo`;o00000_ooool4
o`0000Gooooo2_l00002ooooo`Co000000Coooooo`000?l0003o00002Oooool2o`000003ooooool0
003o000000?o00006Oooool4o`0000Cooooo0_l000000ooooooo0000o`00000Go`0000Cooooo0_l0
000<ooooo`?o00003Oooool2o`0001Sooooo0_l0000eooooo`007?ooool00ol0003oooooooooo`0a
ooooo`;o00006Oooool2o`0000cooooo0_l0000;ooooo`;o00001?ooool2o`0000;ooooo0_l00002
ooooo`Wo00000_ooool3o`0000;ooooo0_l0000:ooooo`;o000000?oooooo`000?l000001Ol0000G
ooooo`Ko00000_ooool2o`0000?ooooo6Ol00002ooooo`;o00002?ooool2o`0000;ooooo0ol00000
0ooooooo0000o`00000:ooooo`Go000000?oooooo`000?l00000BOooool001cooooo00?o0000oooo
ooooool0<Oooool2o`000003ooooool0003o000001Gooooo0_l0000Dooooo`;o00003_ooool;o`00
00Cooooo0ol00002ooooo`;o00002_ooool2o`000003ooooool0003o000000?ooooo1?l0000Foooo
o`Go00000_ooool2o`0000;ooooo0_l00002oooooaKo000000Coooooo`000?l0003o00001oooool3
o`0000;ooooo0_l00002ooooo`;o00002oooool4o`000003ooooool0003o000004Wooooo000Loooo
o`03o`000?oooooooooo037ooooo0_l000000ooooooo0000o`00000Eooooo`;o00001oooool2o`00
00_ooooo0_l00008ooooo`;o00001?ooool:o`0000Cooooo0_l00003ooooo`;o00002_ooool3o`00
0004ooooool0003o0000o`0000?ooooo1Ol0000Cooooo`Co00000_ooool2o`0000Cooooo7Ol00008
ooooo`?o00000_ooool2o`00013ooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`0`oooo
o`;o00000_ooool2o`0001Cooooo0_l00006ooooo`Co000000?oooooo`000?l000000ol00003oooo
o`;o00002Oooool5o`0000;ooooo0_l00002ooooo`Co00001_ooool2o`0000?ooooo0_l0000:oooo
o`;o000000?oooooo`000?l000002_l00009ooooo`;o00001Oooool2o`000004ooooool0003o0000
ooooo`;o000000?oooooo`000?l000001?oooolKo`0000_ooooo0_l00006ooooo`;o00000oooool4
o`0000Gooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`0_ooooo`Oo00005?ooool2o`00
00Kooooo0_l00002ooooo`Ko00000oooool2o`0000Wooooo0_l000000ooooooo0000o`00000Doooo
o`;o00003_ooool2o`0000;ooooo1?l000000ooooooo0000o`00000:ooooo`;o00001Oooool2o`00
0003ooooool0003o000000Oo00000_ooool5o`000003ooooool0003o0000017o00002oooool4o`00
00Oooooo0_l00003ooooo`Co00001Oooool2o`0004gooooo000Looooo`;o0000<?ooool2o`000004
ooooool0003o0000o`00027ooooo0_l0000Iooooo`;o00000_ooool3o`0000Kooooo0_l00003oooo
o`;o00003_ooool3o`0000Kooooo0ol0000@ooooo`;o000000Goooooo`000?l0003o0000ooooo`05
o`0000;ooooo3?l000000ooooooo0000o`000006o`0000;ooooo0_l00002ooooo`Co00001Oooool4
o`0000gooooo0_l00002ooooo`Ko0000COooool001cooooo00?o0000ooooooooool0E_ooool2o`00
00Sooooo1_l0000;ooooo`;o00000_ooool3o`0000Kooooo0_l0000Cooooo`?o00000_ooool2o`00
00;ooooo0ol0000@ooooo`;o000000?oooooo`000?l000001Oooool2o`0000;ooooo0_l000000ooo
oooo0000o`000007o`0000;ooooo0_l000001?oooooo0000o`000?l00005ooooo`Ko00005?ooool4
o`000003ooooool0003o000000?o0000Coooool001cooooo00?o0000ooooooooool0D_ooool3o`00
0003ooooool0003o000000Sooooo1_l0000Kooooo`;o00002?ooool2o`0000Cooooo0_l00005oooo
o`;o00000_ooool3o`0000Kooooo0_l0000>ooooo`;o00001oooool4o`0000Oooooo0_l00003oooo
o`Go00000_ooool4o`0000kooooo0_l00007ooooo`;o00000oooool5o`0004oooooo000Looooo`03
o`000?oooooooooo03;ooooo0ol0000Booooo`;o00002?ooool4o`0000Cooooo0_l00002ooooo`Co
00004Oooool2o`0000gooooo0_l00008ooooo`?o00000oooool2o`0000Wooooo0ol00006ooooo`;o
00003_ooool2o`0000Oooooo0_l00003ooooo`Wo000000Coooooo`000?l0003ooooo2?l00003oooo
o`;o00001Oooool4o`000003ooooool0003o000000;o00002oooool2o`00057ooooo000Looooo`03
o`000?oooooooooo02kooooo0_l000000ooooooo0000o`000002o`0001;ooooo0_l00008ooooo`;o
00001_ooool8o`000003ooooool0003o000000;ooooo1?l00006ooooo`Co00002oooool2o`0000_o
oooo0_l00003ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`Co00001_ooool2o`00
01Cooooo0_l000000ooooooo0000o`00000<o`000004ooooool0003o0000ooooo`Oo00001?ooool2
o`0000?ooooo1_l000000ooooooo0000o`000002o`0005kooooo000Looooo`03o`000?oooooooooo
02kooooo0_l000001?oooooo0000o`000?ooool2o`0001Wooooo0_l00005oooooaCo00001_ooool3
o`0000cooooo0ol0000<ooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`Go00003ooo
ool2o`0000Oooooo0_l000001?oooooo0000o`000?oooolGo`0000_ooooo0_l000001?oooooo0000
o`000?l0000@ooooo`;o0000DOooool001cooooo00?o0000ooooooooool0=?ooool2o`0001Wooooo
0_l00003oooooaKo00001oooool2o`0000gooooo0_l0000<ooooo`;o00002oooool5o`0000_ooooo
0_l00002ooooo`;o00001Oooool4o`0000Gooooo1_l00002ooooo`ko00004?ooool2o`0000_ooooo
0_l00002ooooo`;o0000DOooool001cooooo00?o0000ooooooooool0C?ooool3o`0000?ooooo6ol0
000@ooooo`;o00004?ooool2o`0000?ooooo0_l00005ooooo`Go00002oooool2o`0000Oooooo1Ol0
0003ooooo`;o000000?oooooo`000?l000003?l000000ooooooo0000o`000002ooooo`?o00002ooo
ool4o`000003ooooool0003o000000Kooooo0ol00002ooooo`Co0000Doooool001cooooo00?o0000
ooooooooool0=_ooool3o`0001?ooooo0ol00003oooooago00000oooool2o`0000Wooooo0_l00003
ooooo`;o00002oooool2o`0000?ooooo1?l00006ooooo`?o00000oooool2o`0000Gooooo0ol00000
0ooooooo0000o`000002o`000003ooooool0003o000000Cooooo5Ol00003ooooo`;o00003?ooool4
o`0000Gooooo0_l000000ooooooo0000o`000002o`0000?ooooo1?l0001Booooo`007?ooool00ol0
003oooooooooo`0fooooo`?o00003oooool2o`0000;ooooo0_l00006oooooaGo00000_ooool4o`00
00?ooooo0_l0000>ooooo`Co00002Oooool2o`0000Gooooo0ol000000ooooooo0000o`000002oooo
o`?o00000oooool2o`0000Kooooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l000000ooo
oooo0000o`000002ooooo`?o00001oooool2o`000003ooooool0003o000000[o00001_ooool2o`00
0003ooooool0003o000000Oooooo1Ol00004ooooo`Go00003oooool2o`00047ooooo000Looooo`03
o`000?oooooooooo03[ooooo0_l0000<ooooo`;o00000_ooool2o`0000Kooooo5Ol00002ooooo`;o
00005oooool4o`0000?ooooo0ol00008ooooo`?o000000?oooooo`000?l000000_ooool3o`0000Co
oooo0_l00003ooooo`?o000000?oooooo`000?l000000oooool2o`000004ooooool0003o0000o`00
00Sooooo0_l00005ooooo`oo00001?ooool7o`0000Sooooo0_l000000ooooooo0000o`000003oooo
o`Go00003Oooool4o`00047ooooo000Looooo`03o`000?oooooooooo03[ooooo0_l0000Goooooa_o
00004Oooool2o`0000?ooooo1?l00003ooooo`Co00000_ooool2o`0000?ooooo0_l00006ooooo`?o
00001?ooool2o`0000?ooooo0ol000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l0
00002Oooool2o`0000Oooooo1_l000001?oooooo0000o`000?l00003ooooo`;o00000_ooool2o`00
0003ooooool0003o000000gooooo0_l00002ooooo`;o000000?oooooo`000?l000003_ooool2o`00
04?ooooo000Looooo`03o`000?oooooooooo03[ooooo0_l0000Dooooo`;o000000?oooooo`000?l0
00006Ol0000<ooooo`;o00000oooool2o`0000Sooooo0_l00002ooooo`Ko00000oooool3o`0000Go
oooo1Ol00002ooooo`;o00001?ooool2o`000003ooooool0003o000000gooooo0_l0000;ooooo`;o
00001_ooool3o`0000;ooooo1Ol00004ooooo`;o00000_ooool4o`000004ooooool0003o0000oooo
o`Oo000000?oooooo`000?l000002_ooool2o`0000Gooooo1?l0000nooooo`007?ooool00ol0003o
ooooooooo`1?ooooo`?o000000?oooooo`000?l000005?l00006ooooo`;o00002Oooool2o`0000Wo
oooo0_l00002ooooo`Co00000_ooool2o`000003ooooool0003o000000;ooooo0ol00004ooooo`Ko
00003?ooool2o`0000cooooo1?l0000=ooooo`;o00000oooool2o`0000?ooooo1?l00004ooooo`;o
00000_ooool4o`000004ooooool0003o0000ooooo`Go00003Oooool4o`0000Gooooo1?l0000noooo
o`007?ooool00ol0003oooooooooo`17ooooo`;o00000oooool2o`000005ooooool0003o0000o`00
0?ooool06_l00002ooooo`;o00005?ooool3o`000003ooooool0003o000000;o00001Oooool2o`00
00?ooooo0ol00002ooooo`_o00001?ooool6o`0000Cooooo0_l00008ooooo`;o00000_ooool2o`00
00Kooooo1Ol00005ooooo`;o00005_ooool6o`0000_ooooo0_l00003ooooo`;o00000_ooool2o`00
043ooooo000Looooo`03o`000?oooooooooo04Oooooo0_l00003ooooo`;o00001OoooolJo`0000?o
oooo0_l0000Booooo`Co00002_ooool4o`0000;ooooo0_l00002ooooo`_o00000oooool5o`0000Co
oooo1?l0000<ooooo`;o00001_ooool4o`000003ooooool0003o000000?ooooo0_l0000Booooo`;o
00000_ooool2o`0000;ooooo1?l0000>ooooo`;o00000_ooool2o`000003ooooool0003o000003go
oooo000Looooo`;o0000B?ooool2o`0000;ooooo0_l00005ooooo`go000000?oooooo`000?l00000
2Ol00005ooooo`;o00004_ooool2o`0000Cooooo1Ol000001?oooooo0000o`000?ooool3o`0000Wo
oooo1?l00006ooooo`Co00000_ooool2o`000004ooooool0003o0000o`0000[ooooo0_l00009oooo
o`;o00001?ooool2o`0000?ooooo0_l0000@ooooo`Co00002?ooool2o`0000Cooooo0_l000000ooo
oooo0000o`00000<ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0>Oooool2o`0000Go
oooo0_l00006ooooo`;o000000?oooooo`000?l000001OoooolIo`0001oooooo1Ol000000ooooooo
0000o`00000<ooooo`Go00001_ooool2o`0000Cooooo1Ol0000;ooooo`;o00001?ooool3o`0000;o
oooo0ol0000Cooooo`;o00001Oooool4o`0000kooooo0_l000000ooooooo0000o`00000?ooooo`;o
0000>_ooool001cooooo00?o0000ooooooooool0>Oooool2o`0000Gooooo1?l00004ooooo`;o0000
1oooool2o`000003ooooool0003o000001Go00001Oooool4o`0000Gooooo0_l000000ooooooo0000
o`000004ooooo`;o000000?oooooo`000?l000000oooool2o`000003ooooool0003o000000kooooo
0ol000001?oooooo0000o`000?l00006ooooo`;o00001?ooool4o`0000[ooooo0_l00002ooooo`Ko
00000oooool2o`0001?ooooo0_l00006ooooo`;o00005oooool4o`0000Sooooo0_l0000jooooo`00
7?ooool00ol0003oooooooooo`12ooooo`;o00003OoooolGo`0000Sooooo1?l00005ooooo`Go0000
1?ooool2o`000003ooooool0003o000000?ooooo0_l000001?oooooo0000o`000?ooool2o`000003
ooooool0003o000000Sooooo0_l00003ooooo`Go000000?oooooo`000?l000000_l00005ooooo`?o
00001?ooool2o`0000Cooooo0_l00002ooooo`?o00000_ooool2o`0000;ooooo0_l00003ooooo`;o
00005?ooool5o`0000[ooooo0_l00003ooooo`;o00001Oooool4o`000003ooooool0003o000000;o
oooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00001?ooool2o`00017ooooo
5_l00002ooooo`;o00000_ooool4o`0000;ooooo0_l00004ooooo`;o00000_ooool2o`0000_ooooo
0_l00003ooooo`;o000000?oooooo`000?l000003oooool3o`000003ooooool0003o000000Kooooo
1?l00004ooooo`;o00003Oooool2o`0000Oooooo0ol0000Aooooo`Co000000?oooooo`000?l00000
2Oooool3o`0000?ooooo0_l00007ooooo`;o000000?oooooo`000?l000000_ooool2o`0003gooooo
000Looooo`03o`000?oooooooooo03Wooooo0_l00004ooooo`;o00000oooool5o`0000[ooooo5Ol0
00001?oooooo0000o`000?l00002ooooo`Co00000_ooool2o`0000Sooooo0_l000001?oooooo0000
o`000?l00007ooooo`;o00005oooool2o`0000[ooooo1?l00002ooooo`Go00004oooool2o`000003
ooooool0003o000000_ooooo0_l00004ooooo`;o00003_ooool2o`0000Gooooo0_l00005ooooo`?o
0000A?ooool001cooooo00?o0000ooooooooool0A?ooool5o`0000[ooooo0_l00002oooooa7o0000
00?oooooo`000?l000000oooool2o`0000;ooooo0_l00004ooooo`;o00000_ooool4o`000004oooo
ool0003o0000o`0000Oooooo0_l0000Sooooo`Co00000_ooool:o`0000kooooo0_l0000<ooooo`Co
00004oooool2o`0000Kooooo0_l00003ooooo`Co0000AOooool001cooooo00?o0000ooooooooool0
A?ooool2o`0000oooooo4ol0000:ooooo`;o00001?ooool2o`0000;ooooo1?l00005ooooo`;o0000
1?ooool3o`0002?ooooo0ol00005ooooo`Oo00007?ooool2o`0000Oooooo0_l0000<ooooo`;o0000
2_ooool3o`0000[ooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`12ooooo`Co00003ooo
oolAo`0000?ooooo0_l0000=ooooo`;o00002oooool2o`0000Gooooo0_l00003ooooo`;o00006_oo
ool2o`0000;ooooo0ol00002ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`;o0000
5oooool2o`0000Wooooo0_l00006ooooo`Co00000oooool2o`0000Wooooo0_l0000;ooooo`;o0000
>oooool001cooooo00?o0000ooooooooool0?_ooool6o`0000Sooooo0_l00005ooooo`;o000000?o
ooooo`000?l000003Ol00004ooooo`Go00002oooool2o`0000[ooooo1ol00005ooooo`;o00006_oo
ool2o`0000Oooooo0_l00006ooooo`;o000000?oooooo`000?l000000_ooool2o`0001;ooooo1Ol0
000?ooooo`Ko000000?oooooo`000?l000004Oooool2o`0000;ooooo0_l0000looooo`007?ooool0
0ol0003oooooooooo`0nooooo`Co00002_ooool2o`0000Gooooo0_l000000ooooooo0000o`000003
ooooo`[o00001_ooool3o`0000?ooooo0_l00006ooooo`;o00001oooool2o`0000;ooooo1_l0000D
ooooo`;o00006oooool2o`0000;ooooo0ol000000ooooooo0000o`000003o`0000kooooo1_l0000C
ooooo`;o000000?oooooo`000?l000003oooool5o`000003ooooool0003o000003cooooo000Loooo
o`03o`000?oooooooooo04[ooooo0ol000000ooooooo0000o`000006ooooo`;o00000_ooool3o`00
00;ooooo0ol00003ooooo`;o00002_ooool2o`0000Kooooo0_l00007ooooo`Co000000Coooooo`00
0?l0003ooooo1?l00005ooooo`;o00000_ooool2o`0000Oooooo0_l0000Kooooo`;o00000oooool2
o`0000;ooooo1Ol00008ooooo`;o000000?oooooo`000?l000000_l0000Aooooo`;o00001?ooool2
o`0001;ooooo0_l000000ooooooo0000o`00000oooooo`007?ooool00ol0003oooooooooo`0goooo
o`;o00003_ooool2o`000005ooooool0003o0000o`000?ooool00_l00008ooooo`Co00000oooool4
o`000004ooooool0003o0000o`0000_ooooo1?l00003ooooo`;o00001oooool4o`0000Kooooo0_l0
0005ooooo`;o00000_ooool2o`0000gooooo0_l00007ooooo`;o00003?ooool2o`0000Gooooo0_l0
0002ooooo`Ko000000?oooooo`000?l000002?l0000Booooo`;o0000G?ooool001cooooo00?o0000
ooooooooool0=oooool2o`0000kooooo0_l00008ooooo`?o00000oooool5o`000003ooooool0003o
000000Co000000Coooooo`000?l0003o00002_ooool5o`0000?ooooo0_l00006ooooo`?o00001Ooo
ool2o`000003ooooool0003o000000Kooooo1Ol0000=ooooo`;o00001oooool2o`0000cooooo0ol0
0004ooooo`;o00000_ooool2o`000003ooooool0003o000000co00002Oooool2o`0000[ooooo0_l0
000Booooo`;o00000oooool2o`00043ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo
0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`14ooooo`;o
00002oooool3o`000003ooooool0003o000000;o00001?ooool6o`000004ooooool0003o0000o`00
00[ooooo0_l00006ooooo`;o00001Oooool3o`0000Gooooo0ol00003ooooo`;o00001?ooool3o`00
00Wooooo0_l00004ooooo`;o00001oooool2o`0000gooooo0_l0000=ooooo`;o00003?ooool4o`00
00?ooooo0_l00007ooooo`;o000000?oooooo`000?l000004_ooool2o`0000?ooooo0_l00010oooo
o`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonH
V9So8B4Q00Kooooo00?o0000ooooooooool0=oooool2o`0000_ooooo0_l0000?ooooo`;o00001ooo
ool5o`000003ooooool0003o000000?ooooo0_l00004ooooo`;o00003oooool2o`0000Kooooo0ol0
0003ooooo`?o00000oooool5o`0000Oooooo0_l00003ooooo`Co00004?ooool2o`0000Gooooo1?l0
0007ooooo`;o00002_ooool2o`0000;ooooo1?l0000<ooooo`;o00004oooool2o`0000Gooooo0_l0
0010ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`0gooooo`;o00003_ooool3o`0001Cooooo1?l0
0007ooooo`;o00001?ooool2o`0000[ooooo1Ol00002ooooo`;o00002oooool2o`000003ooooool0
003o000000Go00003?ooool4o`00013ooooo0_l00005ooooo`Co00001oooool2o`0000Gooooo0_l0
0002ooooo`?o00000_ooool2o`0000kooooo0_l000000ooooooo0000o`00000;ooooo`;o00000ooo
ool2o`0004Oooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000
oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000AOooool5o`0000Oooooo0_l0000=ooooo`;o00002Ooo
ool3o`000003ooooool0003o000000[ooooo1Ol00002ooooo`;o00002oooool:o`0002;ooooo0_l0
0003ooooo`;o00002Oooool2o`0000Gooooo0_l00002ooooo`?o00000_ooool2o`0000Sooooo0_l0
0004ooooo`Go00002oooool2o`0000Gooooo0_l00015ooooo`0000?oooooo`000?ooool00_ooool0
0ol0003oooooooooo`09ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003ooooooooo
o`15ooooo`;o00002_ooool2o`0000;ooooo0_l00009ooooo`;o00002?ooool4o`0000Cooooo0_l0
00000ooooooo0000o`000004ooooo`;o00000_ooool2o`00013ooooo0_l00004ooooo`;o00004?oo
ool2o`00013ooooo0_l00003ooooo`;o00004Oooool2o`0000;ooooo0_l0000<ooooo`;o00001Ooo
ool4o`0001;ooooo0_l00003ooooo`;o0000@?ooool00003ooooool@413ooooo00;ooooo00?o410@
ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo03oooooo0_l00002
ooooo`;o000000?oooooo`000?l000003Oooool3o`0000;ooooo0_l00004ooooo`;o00002?ooool2
o`0000Kooooo0_l000000ooooooo0000o`000003ooooo`;o00000oooool2o`00013ooooo1?l00004
ooooo`;o00003_ooool2o`0001Gooooo0_l00002ooooo`;o00003Oooool4o`000005ooooool0003o
0000o`000?ooool00_l00007ooooo`;o00001Oooool4o`0000Wooooo0_l00005ooooo`;o00001Ooo
ool2o`00043ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P0
2?ooool00ol0003oooooooooo`0oooooo`;o00000_ooool2o`000003ooooool0003o000000[ooooo
0_l00002ooooo`?o000000?oooooo`000?l000000_l00005ooooo`;o00002_ooool5o`0000?ooooo
1Ol0000Dooooo`Go00001?ooool2o`00023ooooo0_l00007ooooo`;o00003Oooool4o`000005oooo
ool0003o0000o`000?ooool00_l00007ooooo`;o00004_ooool2o`0000Gooooo0_l00004ooooo`;o
0000@Oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106
ooooo`03o`000?oooooooooo03oooooo0_l00003ooooo`;o00003?ooool4o`000005ooooool0003o
0000o`000?ooool00ol00005ooooo`;o00002_ooool7o`000004ooooool0003o0000o`00013ooooo
1?l00002ooooo`Go000000?oooooo`000?l000008oooool2o`0000Wooooo0_l0000=ooooo`Co0000
1Oooool2o`0000Gooooo0_l0000Iooooo`;o00001?ooool2o`00047ooooo000Looooo`03o`000?oo
oooooooo04Cooooo1?l0000<ooooo`;o00000_ooool2o`0000Sooooo0_l00004ooooo`;o00000ooo
ool5o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0000_ooooo1?l00003ooooo`Co000000?o
ooooo`000?l000000_l0000>ooooo`;o00005oooool2o`0000?ooooo0_l0000=ooooo`Go00001?oo
ool2o`0000Gooooo0_l0000Aooooo`;o00003?ooool2o`00047ooooo000Looooo`03o`000?oooooo
oooo03gooooo1_l00003ooooo`;o00006_ooool2o`0000Cooooo0_l00003ooooo`Go00001Oooool3
o`0000?ooooo0_l0000Booooo`Co00000oooool2o`0000kooooo0_l00004ooooo`;o00000_ooool2
o`0000_ooooo1?l0000Eooooo`;o00007_ooool2o`0000;ooooo0_l00008ooooo`;o0000@Oooool0
01cooooo00?o0000ooooooooool0?Oooool6o`0000?ooooo0_l0000Looooo`Co00003Oooool4o`00
01?ooooo1?l00002ooooo`?o000000?oooooo`000?l000005_ooool2o`0000;ooooo0_l0000:oooo
o`?o000000?oooooo`000?l000003_ooool3o`0002Oooooo0_l0001;ooooo`007?ooool00ol0003o
ooooooooo`16ooooo`;o00006?ooool2o`0000;ooooo1Ol0000<ooooo`;o00000oooool2o`0000Go
oooo0_l00009ooooo`Co00000_ooool6o`0001_ooooo0_l00009ooooo`;o00000_ooool4o`0000So
oooo0_l00002ooooo`?o00002?ooool2o`0000Sooooo0_l0000Cooooo`;o0000Boooool001cooooo
00?o0000ooooooooool0Coooool2o`0000?ooooo0_l0000:ooooo`;o00001?ooool3o`00017ooooo
1?l00003ooooo`;o00000_ooool2o`0000gooooo0_l0000=ooooo`;o00003_ooool2o`0000Oooooo
0_l00006ooooo`;o00002?ooool3o`0000Sooooo0_l00002ooooo`?o00001oooool2o`0000Sooooo
0_l0000<ooooo`;o00001_ooool2o`00043ooooo000Looooo`03o`000?oooooooooo04Gooooo0_l0
0008ooooo`;o00000oooool2o`00013ooooo0_l0000Dooooo`;o00001oooool2o`0001cooooo0ol0
000Cooooo`;o000000?oooooo`000?l000004Oooool2o`0000;ooooo0_l00002ooooo`Co00000ooo
ool2o`000003ooooool0003o000000;ooooo0_l0000:ooooo`;o00003?ooool2o`0000Kooooo0_l0
0010ooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00003_ooool2o`0001Sooooo0_l0000T
ooooo`;o00003Oooool2o`0000;ooooo0_l00004ooooo`;o00002Oooool2o`0001Cooooo0_l00002
oooooa3o000000Coooooo`000?l0003o00002oooool2o`000003ooooool0003o000000?ooooo0_l0
001=ooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00000_ooool2o`0000[ooooo0_l0000H
ooooo`;o00004Oooool2o`0000kooooo0_l000000ooooooo0000o`000003ooooo`;o00003?ooool2
o`0000Cooooo0_l00009ooooo`;o00006_ooool2o`0000?ooooo2?l00002ooooo`;o00001?ooool2
o`0000Kooooo0_l000000ooooooo0000o`000003ooooo`;o00001_ooool2o`0004Gooooo000Loooo
o`03o`000?oooooooooo04Wooooo0_l00002ooooo`;o0000<oooool2o`0000kooooo0_l00002oooo
o`;o00000_ooool2o`0000Sooooo0_l00002ooooo`;o00001?ooool2o`0000Wooooo0_l00006oooo
o`;o00001Oooool4o`0000;ooooo0_l0000;ooooo`Oo00000_ooool3o`0000?ooooo0_l0000Foooo
o`;o0000AOooool001cooooo00?o0000ooooooooool0COooool2o`00037ooooo0_l0000Booooo`Co
00003?ooool2o`0000gooooo0_l0000<ooooo`;o00000_ooool2o`000003ooooool0003o000000;o
00000_ooool2o`0000?ooooo0_l00003ooooo`So00001?ooool3o`0006;ooooo000Looooo`03o`00
0?oooooooooo04Oooooo0_l0000;ooooo`;o00005_ooool3o`00017ooooo0_l0000Booooo`;o0000
0oooool2o`0001Oooooo0ol0000?ooooo`?o000000Coooooo`000?l0003o00000_ooool2o`0000Co
oooo0_l00003ooooo`Co00008_ooool2o`0004Wooooo000Looooo`;o0000B?ooool2o`000003oooo
ool0003o000000Sooooo0_l0000Fooooo`?o0000:_ooool2o`0000Gooooo0_l0000@ooooo`;o0000
0_ooool2o`0000_ooooo2?l00002ooooo`;o00001?ooool2o`0000?ooooo0_l00007ooooo`;o0000
0_ooool2o`0001Oooooo0_l00019ooooo`007?ooool00ol0003oooooooooo`17ooooo`;o000000Co
ooooo`000?l0003ooooo0_l00005ooooo`;o00001oooool3o`00043ooooo0_l0000Dooooo`;o0000
2Oooool@o`0000Oooooo1?l000000ooooooo0000o`000002ooooo`;o00000_ooool3o`0001Gooooo
0_l0001:ooooo`007?ooool00ol0003oooooooooo`1=ooooo`Co00003?ooool3o`0002Cooooo0_l0
00000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000002oooool2o`0000kooooo0_l0
00000ooooooo0000o`000006ooooo`;o00001ooooolBo`0000Wooooo0_l000000ooooooo0000o`00
0004o`0000?ooooo0_l00005ooooo`;o00003_ooool2o`0004[ooooo000Looooo`03o`000?oooooo
oooo04Oooooo0_l00004ooooo`Ko00004?ooool2o`0001cooooo1Ol000001Ooooooo0000o`000?l0
003ooooo00;o000000?oooooo`000?l000001?ooool2o`0000Gooooo0_l00008ooooo`;o00000ooo
ool3o`000003ooooool0003o000000Kooooo0_l00005oooooa7o00001Oooool2o`0000[ooooo0_l0
0009ooooo`;o000000?oooooo`000?l000002_ooool2o`0004kooooo000Looooo`03o`000?oooooo
oooo04Oooooo1?l00005ooooo`?o00004?ooool2o`0001Cooooo0_l00006ooooo`?o000000?ooooo
o`000?l000000ol000000ooooooo0000o`000004o`0000?ooooo0_l0000?ooooo`;o00000oooool3
o`000003ooooool0003o000000Wooooo0_l00002oooooa7o000000Goooooo`000?l0003o0000oooo
o`02o`0000_ooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l0000;ooooo`Co0000C_oo
ool001cooooo00?o0000ooooooooool0BOooool3o`0000Oooooo0_l00004ooooo`;o00007Oooool3
o`0000?ooooo0_l00005ooooo`Go000000?oooooo`000?l000001?l000001?oooooo0000o`000?l0
000:ooooo`;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000;ooooo1?l0
0003ooooo`;o00000_oooolEo`0000;ooooo0_l0000:ooooo`;o000000?oooooo`000?l000000_l0
000=ooooo`;o000000Coooooo`000?l0003ooooo0_l0001=ooooo`007?ooool00ol0003ooooooooo
o`1:ooooo`;o00000oooool2o`0000;ooooo0_l00004ooooo`Co00006_ooool3o`0000Cooooo0_l0
0006ooooo`[o00000_ooool3o`0000[ooooo0_l000000ooooooo0000o`000003o`0000;ooooo0_l0
00000ooooooo0000o`000004ooooo`Co00001ooooolDo`0000?ooooo0_l0000>ooooo`Go00002ooo
ool4o`0000;ooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00001_ooool2
o`0000?ooooo0_l000000ooooooo0000o`000002o`0000Gooooo0_l0000Jooooo`;o00001_ooool2
o`000003ooooool0003o0000013o00001Oooool2o`0000;ooooo0_l00003ooooo`?o00001?ooool2
o`0000Oooooo0_l00005oooooaSo00004Oooool2o`000003ooooool0003o000000;o00000oooool3
o`0000Oooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00001_ooool2o`00
00;ooooo2?l00002ooooo`;o00009?oooolGo`0000;ooooo1?l00002ooooo`;o00001?ooool2o`00
01;ooooo4?l000000ooooooo0000o`000007o`00017ooooo0_l000000ooooooo0000o`000003o`00
00;ooooo0ol00007ooooo`;o0000DOooool001cooooo00?o0000ooooooooool0@_ooool2o`0000[o
oooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000;o00009?oooolGo`0000;o
oooo0_l0000:ooooo`;o00003Oooool4o`000003ooooool0003o000000;ooooo5_l0000Dooooo`Ko
0000G_ooool001cooooo00?o0000ooooooooool0Aoooool2o`0000Oooooo0_l000001?oooooo0000
o`000?ooool2o`0002Oooooo3?l00002ooooo`Go000000?oooooo`000?l000000ol0000?ooooo`;o
00000oooool2o`0000Cooooo1?l000000ooooooo0000o`00000Go`0000Kooooo0_l0000>ooooo`Go
0000G_ooool001cooooo00?o0000ooooooooool0Aoooool2o`0000Oooooo0_l00003ooooo`;o0000
0_ooool2o`0002?ooooo3_l000000ooooooo0000o`00000:o`0000kooooo0_l00003ooooo`;o0000
1?ooool4o`0000?ooooo0_l00002oooooa?o00001_ooool2o`00077ooooo000Looooo`03o`000?oo
oooooooo04gooooo0_l00006ooooo`?o000000?oooooo`000?l000006_ooool2o`0000;ooooo1?l0
00000ooooooo0000o`00000Fo`000003ooooool0003o000000Oooooo0_l0000Booooo`;o000000Co
ooooo`000?l0003o00000_oooolDo`0000Kooooo0_l0000Fooooo`;o0000FOooool001cooooo00?o
0000ooooooooool0COooool4o`0000Gooooo0_l0000Mooooo`;o00000_ooool4o`000003ooooool0
003o000001So00002?ooool2o`0001Gooooo6Ol00006ooooo`;o00005_ooool2o`0005Wooooo000L
ooooo`03o`000?oooooooooo04Cooooo0_l00007ooooo`Co00009?ooool5o`000004ooooool0003o
0000oooooa[o00007?ooool2o`0000;ooooo6?l0000<ooooo`;o0000Joooool001cooooo00?o0000
ooooooooool0@?ooool2o`0000;ooooo0_l00007ooooo`?o00009oooool3o`000004ooooool0003o
0000oooooa[o00001_ooool2o`0000Cooooo0_l0000>ooooo`;o00000_ooool4o`0000;ooooo4?l0
0006ooooo`;o00001_ooool2o`00013ooooo0_l0001Iooooo`007?ooool2o`00047ooooo0ol0000:
ooooo`?o0000;_oooolJo`0000Kooooo0_l00004ooooo`;o00000oooool2o`0000oooooo0_l00000
0ooooooo0000o`00000?o`0000;ooooo0_l00002ooooo`;o00001_ooool2o`00013ooooo0_l0001I
ooooo`007?ooool00ol0003oooooooooo`11ooooo`;o00006_ooool2o`0001Oooooo0_l00004oooo
oa?o00000_ooool7o`0000Kooooo0_l00009ooooo`;o00002_ooool2o`0000Kooooo3?l000001Ooo
oooo0000o`000?l0003ooooo00Co00001?ooool2o`0000Kooooo0_l00006ooooo`;o0000HOooool0
01cooooo00?o0000ooooooooool0GOooool2o`0001Oooooo0_l00002oooooaGo00000_ooool6o`00
00Oooooo0_l0000Eooooo`;o00000_ooool2o`0000;ooooo5?l00005ooooo`;o00001_ooool2o`00
00?ooooo0_l000000ooooooo0000o`000003ooooo`;o0000G?ooool001cooooo00?o0000oooooooo
ool0NOooool3o`000003ooooool0003o000000;o000000?oooooo`000?l000004ol000000ooooooo
0000o`000004ooooo`;o00006?ooool3o`0000Cooooo4?l00007ooooo`?o00002Oooool3o`000003
ooooool0003o000000?ooooo0_l0001Looooo`007?ooool00ol0003oooooooooo`1Aooooo`;o0000
9_ooool2o`000003ooooool0003o000001Wo000000?oooooo`000?l000000oooool2o`0001Wooooo
0_l00004oooooa3o00002Oooool2o`0000Wooooo0ol0001Tooooo`007?ooool00ol0003ooooooooo
o`1>ooooo`;o000000?oooooo`000?l00000:OoooolKo`0000Kooooo0_l00006ooooo`;o00004Ooo
ool2o`0000;ooooo1?l00002ooooo`;o00000_ooool5o`0000cooooo0_l00003ooooo`;o00001?oo
ool3o`0006Cooooo000Looooo`03o`000?oooooooooo04?ooooo0_l00009ooooo`;o0000:?ooool2
o`0000?ooooo6_l00006ooooo`;o00001_ooool2o`0001Gooooo1?l00008ooooo`?o00003?ooool7
o`0000Cooooo0_l0001Uooooo`007?ooool00ol0003oooooooooo`13ooooo`;o0000<_ooool3o`00
00;ooooo6ol00002ooooo`;o00000_ooool2o`0001_ooooo0_l000001Ooooooo0000o`000?l0003o
oooo00?o00002oooool2o`0000Sooooo1?l00007ooooo`;o00000_ooool2o`0005oooooo000Loooo
o`03o`000?oooooooooo07Oooooo0ol00002oooooa_o00000_ooool2o`0000Cooooo0ol0000Hoooo
o`;o000000?oooooo`000?l000000_ooool3o`0000_ooooo0_l00003ooooo`;o00001Oooool2o`00
00Oooooo0_l00002ooooo`;o0000Goooool001cooooo00?o0000ooooooooool0N?ooool2o`0000?o
oooo1?l000000ooooooo0000o`00000Bo`0000Wooooo1Ol0000Iooooo`?o00005?ooool2o`0000?o
oooo0_l00005ooooo`;o00001_ooool2o`0005oooooo000Looooo`03o`000?oooooooooo07gooooo
5ol0000>ooooo`;o00006Oooool3o`0001Wooooo0_l00003ooooo`Co00001_ooool2o`0005oooooo
000Looooo`03o`000?oooooooooo05;ooooo0ol0000WoooooaSo000000?oooooo`000?l000000_l0
0002ooooo`;o00002oooool2o`0001Kooooo0_l000001?oooooo0000o`000?l00007ooooo`;o0000
1Oooool2o`000003ooooool0003o000000Gooooo0_l000001?oooooo0000o`000?ooool2o`0006?o
oooo000Looooo`03o`000?oooooooooo05;ooooo1Ol0000Uooooo`?o000000Coooooo`000?l0003o
oooo3Ol000001Ooooooo0000o`000?l0003ooooo00Co00000_ooool2o`0000[ooooo0ol0000Foooo
o`Ko00001oooool4o`0000?ooooo1Ol00008ooooo`;o000000?oooooo`000?l00000Hoooool001co
oooo00?o0000ooooooooool0EOooool2o`0002Kooooo0_l00002oooooa7o000000?oooooo`000?l0
00000_l0000@ooooo`;o00006?ooool2o`000003ooooool0003o000000Wooooo0_l00002ooooo`Co
0000L_ooool001cooooo00?o0000ooooooooool0Ooooool5o`000003ooooool0003o000000oo0000
;?ooool2o`0000Gooooo0_l00008ooooo`;o0000M?ooool001cooooo00?o0000ooooooooool0G_oo
ool2o`0001Oooooo0_l00006ooooo`Co000000?oooooo`000?l000001?l00002ooooo`[o0000;?oo
ool2o`0000Gooooo0_l00009ooooo`;o0000Loooool001cooooo0_l0001Oooooo`;o00001?ooool2
o`00017ooooo0_l00007ooooo`;o00000_ooool6o`000003ooooool0003o000000;o00000_ooool2
o`000003ooooool0003o000000Sooooo0_l00009ooooo`;o0000:Oooool2o`0007?ooooo000Loooo
o`03o`000?oooooooooo06Cooooo0_l0000Fooooo`;o00001Oooool2o`0000Gooooo0ol00002oooo
o`Co00002oooool2o`0000Wooooo0_l0002Nooooo`007?ooool00ol0003oooooooooo`1kooooo`Go
00000_ooool3o`0000Gooooo0_l00003ooooo`Co0000]_ooool001cooooo00?o0000ooooooooool0
Noooool2o`000003ooooool0003o000000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000?o
oooo1?l0000Hooooo`;o0000W_ooool001cooooo00?o0000ooooooooool0G?ooool2o`0002Cooooo
0_l000001?oooooo0000o`000?ooool2o`0000?ooooo1?l0000Cooooo`;o00000oooool3o`0000?o
oooo0_l0002Hooooo`007?ooool00ol0003oooooooooo`1Looooo`;o000000?oooooo`000?l00000
8Oooool2o`0000[ooooo0_l0000Dooooo`;o00001?ooool2o`0000?ooooo0_l0002Hooooo`007?oo
ool00ol0003oooooooooo`1Oooooo`;o0000;Oooool2o`000;Wooooo000Looooo`03o`000?oooooo
oooo08Oooooo0_l00030ooooo`007?ooool00ol0003oooooooooo`1Kooooo`;o0000:?ooool4o`00
00?ooooo0_l0002kooooo`007?ooool00ol0003oooooooooo`1Kooooo`?o00000_ooool2o`0002?o
oooo0ol00004ooooo`;o0000^oooool001cooooo00?o0000ooooooooool0G?ooool2o`0000;ooooo
0_l0000Wooooo`Co00004oooool2o`0000Wooooo0_l00016ooooo`;o0000E?ooool001cooooo00?o
0000ooooooooool0ROooool6o`0000Oooooo0_l00008ooooo`;o00002Oooool2o`000003ooooool0
003o000000Cooooo0_l0000mooooo`;o0000E?ooool001cooooo00?o0000ooooooooool0J?ooool2
o`0002?ooooo0_l00007ooooo`;o00005_ooool2o`0000Cooooo0_l0000iooooo`;o0000F?ooool0
01cooooo00?o0000ooooooooool0Ioooool3o`0001[ooooo1?l0000>ooooo`Co00007Oooool2o`00
03Kooooo0_l0001Hooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool0
1Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0F?ooool2o`0000Kooooo0_l0
0005ooooo`?o00006_ooool4o`0000Oooooo0_l00003ooooo`?o000000?oooooo`000?l000001?oo
ool2o`0001Oooooo0_l0002@ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0F?ooool2o`0000Ko
oooo0_l0000;ooooo`;o00008?ooool2o`0000?ooooo0ol00007ooooo`;o0000ZOooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool0J_ooool2o`000003ooooool0003o000001Wooooo0_l00003ooooo`;o
00000_ooool2o`0000Sooooo0_l0002/ooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooo
ooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`0005_ooooo0_l0000=ooooo`;o
00007?ooool2o`0000?ooooo0_l00002ooooo`;o00002?ooool2o`000:cooooo00000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03
o`000?oooooooooo05_ooooo0_l0000Vooooo`;o00001_ooool2o`000;cooooo00000ooooooo410@
ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03
o`000?oooooooooo07?ooooo0_l0000>ooooo`;o00001_ooool5o`000;Wooooo00001_ooooooMgMg
oiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooo
oooo07?ooooo0_l0000Hooooo`?o00001Oooool2o`000;;ooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo08Sooooo
0_l0000;ooooo`;o0000/_ooool001cooooo00?o0000ooooooooool0R?ooool2o`000;oooooo000L
ooooo`03o`000?oooooooooo063ooooo0_l0000fooooo`;o0000Boooool2o`0006;ooooo000Loooo
o`03o`000?oooooooooo063ooooo0_l0000fooooo`;o0000Boooool2o`0006;ooooo000Looooo`03
o`000?oooooooooo06oooooo0_l00007ooooo`;o00004?ooool2o`000;gooooo000Looooo`03o`00
0?oooooooooo06oooooo0_l00007ooooo`;o00004?ooool2o`000;gooooo000Looooo`03o`000?oo
oooooooo07kooooo0_l0000=ooooo`;o0000=_ooool2o`0008;ooooo000Looooo`03o`000?oooooo
oooo07kooooo0_l00008ooooo`;o00000oooool2o`0003Gooooo0ol00022ooooo`007?ooool00ol0
003oooooooooo`1kooooo`;o00000oooool2o`0000Kooooo0_l0000<ooooo`;o0000:?ooool3o`00
0003ooooool0003o000008?ooooo000Looooo`03o`000?oooooooooo07Kooooo0_l00003ooooo`;o
00000oooool2o`0000Kooooo0_l000000ooooooo0000o`000008ooooo`?o0000:?ooool3o`0001[o
oooo0_l0001Zooooo`007?ooool00ol0003oooooooooo`1fooooo`;o00001Oooool2o`0000Wooooo
0_l000000ooooooo0000o`000008ooooo`;o0000A_ooool2o`0006[ooooo000Looooo`03o`000?oo
oooooooo07Wooooo0_l00002ooooo`;o000000?oooooo`000?l000007?ooool2o`000:Wooooo000L
ooooo`;o0000N_ooool2o`0000Gooooo0_l0000Looooo`;o00005oooool4o`0008kooooo000Loooo
o`03o`000?oooooooooo07gooooo0_l0000:ooooo`;o00007oooool2o`000004ooooool0003o0000
ooooo`;o00001Oooool4o`0008kooooo000Looooo`03o`000?oooooooooo07gooooo0_l00004oooo
o`;o00001?ooool2o`0001oooooo0_l000001?oooooo0000o`000?ooool2o`0009Oooooo000Loooo
o`03o`000?oooooooooo08?ooooo0_l0001@ooooo`;o0000L_ooool001cooooo00?o0000oooooooo
ool0QOooool2o`0004kooooo0_l0001booooo`007?ooool00ol0003oooooooooo`1cooooo`;o0000
4?ooool2o`000<;ooooo000Looooo`03o`000?oooooooooo07?ooooo0_l0000Dooooo`;o0000AOoo
ool2o`0007Oooooo000Looooo`03o`000?oooooooooo08Wooooo0_l00015ooooo`;o0000Moooool0
01cooooo00?o0000ooooooooool0Roooool2o`0003kooooo0_l0001looooo`007?ooool00ol0003o
ooooooooo`2;ooooo`;o0000?_ooool2o`0007cooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0a?ooool2o`0008?ooooo000Looooo`03o`000?oooooo
oooo08gooooo0_l00004ooooo`;o0000;oooool2o`0008?ooooo000Looooo`03o`000?oooooooooo
08gooooo0ol00003ooooo`;o00009oooool4o`0008Wooooo000Looooo`03o`000?oooooooooo08ko
oooo0_l0000/ooooo`Co0000ROooool001cooooo00?o0000ooooooooool0]_ooool2o`00097ooooo
000Looooo`;o0000U_ooool2o`0001oooooo0_l0002Aooooo`007?ooool00ol0003oooooooooo`2E
ooooo`;o0000/_ooool001cooooo00?o0000ooooooooool0[Oooool4o`0009Sooooo000Looooo`03
o`000?oooooooooo0:gooooo1?l0002Hooooo`007?ooool00ol0003oooooooooo`2Rooooo`Co0000
Xoooool001cooooo00?o0000ooooooooool0X_ooool4o`000:?ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001;ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oo
oooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
oooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo0ol0003ooooood[ooooo000Dooooo`03
o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?oo
ool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool0
01;ooooo00?oEEEEofIVI_l00000oooooomDooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00YOooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo01Oooooo0_l0
00000ol@413oooooooooo`02ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8b
o`000?l@413oc<c<093ooooo002Vooooo`05o`000?ooooooooooooooool000002Oooool6o`0000co
oooo00?o0000ooooooooool01_ooool02OmgMgOo<S8booooooooooooEEEEogMgMoooooooV9RHob4Q
8@2@ooooo`00Y_ooool01Ol0003ooooooooooooooooo000001Sooooo1Ol00008ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool0S_ooool00:Kooooo00Go0000oooooooooooooooo
o`000009ooooo`Ko00002Oooool01?m4A4CogMgMooooool00008ooooo`09ogMgMolb<S;ooooooooo
ool0003oV9RHoooooonHV9So8B4Q093ooooo002Vooooo`05o`000?n7QhOoooooojVYZOl000006?oo
ool01?oMgMgoEEEEooooool00005ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003o
EEEEo`000?l@413oc<c<093ooooo002Uooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHoooooooo
ool05oooool00omgMgOoc<c<o`000005ooooo`03o`000?oooooooooo00Cooooo00?oEEEEohN7Qooo
ool0T_ooool00<Cooooo00?ok^k^odA4A?l000001Oooool00ol0003oooooooooo`04ooooo`03omgM
gOl@413oV9RH09;ooooo0035ooooo`03ogMgMol0003ooooo00Cooooo1?l00004ooooo`04olc<c?m4
A4Co0000oa0@493ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(462) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.50177 .31337 Mdot
.48375 .31342 Mdot
.39517 .72906 Mdot
.63618 .4379 Mdot
.58048 .66774 Mdot
.41033 .67948 Mdot
.27838 .5274 Mdot
.2822 .53776 Mdot
.42307 .68308 Mdot
.56194 .28976 Mdot
.30485 .50423 Mdot
.69372 .46834 Mdot
.29213 .51827 Mdot
.62703 .47192 Mdot
.45666 .42083 Mdot
.56216 .45364 Mdot
.44238 .31668 Mdot
.61784 .70626 Mdot
.57022 .43197 Mdot
.41967 .7246 Mdot
.76525 .49039 Mdot
.61831 .47821 Mdot
.46762 .35918 Mdot
.62531 .4749 Mdot
.66121 .48147 Mdot
.47148 .32026 Mdot
.504 .31838 Mdot
.6517 .49438 Mdot
.66327 .51214 Mdot
.30606 .51204 Mdot
.45983 .7276 Mdot
.71918 .2554 Mdot
.58392 .47054 Mdot
.68803 .29147 Mdot
.27707 .53623 Mdot
.34347 .5433 Mdot
.40649 .71939 Mdot
.28205 .4883 Mdot
.27845 .54102 Mdot
.27042 .53591 Mdot
.27142 .5131 Mdot
.46512 .32399 Mdot
.26466 .53757 Mdot
.29542 .72293 Mdot
.64082 .46533 Mdot
.44411 .39715 Mdot
.22651 .66675 Mdot
.65358 .50537 Mdot
.45715 .30506 Mdot
.42623 .72476 Mdot
.6949 .70114 Mdot
.31548 .49061 Mdot
.40892 .43173 Mdot
.55406 .90246 Mdot
.29594 .50731 Mdot
.65926 .44493 Mdot
.43305 .68139 Mdot
.61054 .45088 Mdot
.62641 .42951 Mdot
.65876 .25728 Mdot
.60291 .47432 Mdot
.57761 .69693 Mdot
.45543 .37175 Mdot
.40477 .65251 Mdot
.41998 .67713 Mdot
.28515 .48776 Mdot
.47619 .37172 Mdot
.29592 .52793 Mdot
.64642 .52231 Mdot
.41054 .73279 Mdot
.66238 .51041 Mdot
.30823 .50994 Mdot
.4955 .35945 Mdot
.64318 .46793 Mdot
.35386 .4102 Mdot
.21638 .52064 Mdot
.36634 .72769 Mdot
.75969 .36834 Mdot
.70923 .73617 Mdot
.48579 .65655 Mdot
.63515 .48477 Mdot
.55267 .85807 Mdot
.46129 .4854 Mdot
.48994 .31342 Mdot
.51548 .29655 Mdot
.38142 .25666 Mdot
.64913 .50386 Mdot
.44503 .60671 Mdot
.59344 .42397 Mdot
.56992 .61536 Mdot
.42869 .69435 Mdot
.49524 .32812 Mdot
.64106 .47248 Mdot
.59545 .49566 Mdot
.49151 .23965 Mdot
.68143 .47617 Mdot
.64331 .44536 Mdot
.48875 .26729 Mdot
.3041 .49781 Mdot
.62366 .55589 Mdot
.63928 .73829 Mdot
.37953 .45238 Mdot
.66723 .45892 Mdot
.40392 .70667 Mdot
.44842 .36963 Mdot
.64927 .45086 Mdot
.28888 .53488 Mdot
.62924 .48441 Mdot
.29723 .55216 Mdot
.44616 .33775 Mdot
.58785 .47501 Mdot
.60471 .71211 Mdot
.60822 .57079 Mdot
.45971 .34712 Mdot
.70722 .37858 Mdot
.60844 .4821 Mdot
.60099 .46001 Mdot
.47908 .30938 Mdot
.40136 .72663 Mdot
.35409 .65501 Mdot
.47797 .36375 Mdot
.27127 .53819 Mdot
.44907 .3061 Mdot
.65319 .41932 Mdot
.40753 .72594 Mdot
.39011 .44013 Mdot
.38018 .44692 Mdot
.64182 .6318 Mdot
.64236 .47882 Mdot
.58541 .56357 Mdot
.40515 .69613 Mdot
.46645 .31527 Mdot
.30056 .52015 Mdot
.65311 .43241 Mdot
.46506 .34252 Mdot
.29206 .54292 Mdot
.58021 .67562 Mdot
.61115 .66499 Mdot
.45465 .31905 Mdot
.61782 .37986 Mdot
.3292 .53281 Mdot
.26595 .52805 Mdot
.69297 .69901 Mdot
.48818 .31088 Mdot
.59213 .70731 Mdot
.30583 .5376 Mdot
.74639 .5837 Mdot
.60703 .42727 Mdot
.66499 .6746 Mdot
.4716 .85058 Mdot
.69431 .70125 Mdot
.71508 .27261 Mdot
.60143 .71189 Mdot
.29712 .54341 Mdot
.66346 .50573 Mdot
.47529 .33833 Mdot
.46385 .3354 Mdot
.60499 .5053 Mdot
.65238 .47168 Mdot
.63419 .45842 Mdot
.62498 .42622 Mdot
.25351 .57652 Mdot
.63852 .47785 Mdot
.22301 .40139 Mdot
.4724 .34622 Mdot
.6588 .46779 Mdot
.38941 .70756 Mdot
.62544 .55021 Mdot
.27055 .50347 Mdot
.62779 .43082 Mdot
.65509 .47664 Mdot
.67479 .44548 Mdot
.27634 .54538 Mdot
.33012 .40696 Mdot
.76044 .69512 Mdot
.31841 .56517 Mdot
.24134 .48242 Mdot
.39917 .68475 Mdot
.60667 .49389 Mdot
.60282 .6929 Mdot
.62434 .55372 Mdot
.60698 .4345 Mdot
.6972 .70568 Mdot
.64468 .48961 Mdot
.74097 .31338 Mdot
.70043 .47893 Mdot
.3728 .26535 Mdot
.24515 .35494 Mdot
.60727 .43166 Mdot
.59168 .32503 Mdot
.65312 .66158 Mdot
.40222 .77557 Mdot
.30342 .51481 Mdot
.38171 .69736 Mdot
.39317 .72353 Mdot
.28159 .4864 Mdot
.7223 .45394 Mdot
.5769 .29506 Mdot
.67948 .49317 Mdot
.38596 .44543 Mdot
.52013 .36071 Mdot
.59475 .71378 Mdot
.45539 .31569 Mdot
.58904 .84449 Mdot
.50029 .64366 Mdot
.4516 .61942 Mdot
.62455 .68618 Mdot
.43965 .70626 Mdot
.40096 .44082 Mdot
.59771 .70281 Mdot
.62814 .4421 Mdot
.446 .32633 Mdot
.66186 .67791 Mdot
.6001 .53416 Mdot
.30416 .21054 Mdot
.50364 .33439 Mdot
.57498 .57639 Mdot
.29707 .51111 Mdot
.38512 .66401 Mdot
.64944 .50331 Mdot
.61752 .45821 Mdot
.48207 .37614 Mdot
.65415 .51252 Mdot
.4571 .59198 Mdot
.65259 .48007 Mdot
.40954 .65392 Mdot
.54348 .67166 Mdot
.26625 .55275 Mdot
.62626 .69995 Mdot
.4894 .36335 Mdot
.20665 .51326 Mdot
.39837 .70931 Mdot
.70399 .53239 Mdot
.30607 .52478 Mdot
.5854 .67455 Mdot
.41077 .71355 Mdot
.60314 .71795 Mdot
.58901 .45901 Mdot
.41424 .71794 Mdot
.57816 .70609 Mdot
.42871 .54474 Mdot
.64703 .44633 Mdot
.67469 .62633 Mdot
.32279 .51304 Mdot
.48834 .30482 Mdot
.59798 .44856 Mdot
.41537 .4369 Mdot
.6521 .42479 Mdot
.52517 .52685 Mdot
.41298 .44311 Mdot
.38848 .46563 Mdot
.46577 .61938 Mdot
.56483 .69294 Mdot
.35573 .43774 Mdot
.43127 .5746 Mdot
.44209 .31777 Mdot
.59058 .46214 Mdot
.39516 .33938 Mdot
.32352 .5169 Mdot
.62305 .44259 Mdot
.3738 .30165 Mdot
.30522 .53836 Mdot
.60573 .4518 Mdot
.27322 .51142 Mdot
.46813 .33909 Mdot
.44507 .51619 Mdot
.46616 .29539 Mdot
.62971 .43706 Mdot
.28292 .50097 Mdot
.38276 .7036 Mdot
.47152 .32111 Mdot
.62433 .48418 Mdot
.63083 .49444 Mdot
.38679 .44833 Mdot
.64824 .46425 Mdot
.40309 .26282 Mdot
.65424 .5032 Mdot
.42569 .72846 Mdot
.67689 .49419 Mdot
.65761 .72703 Mdot
.63645 .69758 Mdot
.45671 .361 Mdot
.41198 .44588 Mdot
.43052 .69816 Mdot
.43817 .52436 Mdot
.6503 .61172 Mdot
.6337 .47974 Mdot
.39811 .45625 Mdot
.56451 .57264 Mdot
.27312 .50099 Mdot
.59246 .50934 Mdot
.39806 .60959 Mdot
.42554 .6996 Mdot
.39195 .44209 Mdot
.58133 .51152 Mdot
.51064 .32674 Mdot
.66991 .45815 Mdot
.40522 .71751 Mdot
.48531 .30031 Mdot
.68054 .46142 Mdot
.20764 .59913 Mdot
.41554 .43595 Mdot
.2924 .49455 Mdot
.46258 .25674 Mdot
.60713 .50162 Mdot
.38624 .71819 Mdot
.46065 .33746 Mdot
.28559 .50699 Mdot
.46402 .35413 Mdot
.6593 .68606 Mdot
.53044 .51892 Mdot
.34247 .57383 Mdot
.59548 .72989 Mdot
.83317 .40939 Mdot
.34272 .54129 Mdot
.63103 .55793 Mdot
.42202 .74455 Mdot
.33498 .23905 Mdot
.40982 .71011 Mdot
.58361 .38132 Mdot
.43192 .68847 Mdot
.67415 .47606 Mdot
.41363 .67827 Mdot
.42822 .21473 Mdot
.64326 .49707 Mdot
.4105 .66864 Mdot
.32149 .59575 Mdot
.63959 .49713 Mdot
.46599 .34599 Mdot
.58704 .17786 Mdot
.74118 .3883 Mdot
.73906 .41831 Mdot
.42862 .67075 Mdot
.6234 .37582 Mdot
.64967 .49782 Mdot
.57389 .42662 Mdot
.47679 .33316 Mdot
.67864 .44395 Mdot
.56725 .7139 Mdot
.59351 .72241 Mdot
.72533 .63949 Mdot
.78506 .41647 Mdot
.72512 .43969 Mdot
.46829 .32732 Mdot
.69875 .74957 Mdot
.35488 .40456 Mdot
.41491 .43479 Mdot
.28582 .54065 Mdot
.32878 .42093 Mdot
.56755 .47671 Mdot
.54074 .33174 Mdot
.45561 .58024 Mdot
.49771 .33269 Mdot
.38238 .55571 Mdot
.28134 .51184 Mdot
.74 .40875 Mdot
.57283 .26941 Mdot
.63457 .45588 Mdot
.31199 .49345 Mdot
.69159 .44776 Mdot
.44122 .59157 Mdot
.66093 .63925 Mdot
.26007 .66 Mdot
.63356 .44045 Mdot
.36882 .42159 Mdot
.60563 .43691 Mdot
.6494 .64058 Mdot
.62179 .43993 Mdot
.46862 .35394 Mdot
.59457 .41277 Mdot
.426 .5678 Mdot
.81274 .49647 Mdot
.49813 .63236 Mdot
.57583 .71194 Mdot
.62479 .46936 Mdot
.62674 .45221 Mdot
.57536 .69779 Mdot
.49543 .33307 Mdot
.59237 .46207 Mdot
.21022 .6532 Mdot
.63896 .47921 Mdot
.30846 .48542 Mdot
.49132 .54541 Mdot
.77341 .33912 Mdot
.62832 .50865 Mdot
.51097 .3336 Mdot
.26875 .51527 Mdot
.30759 .53083 Mdot
.66151 .39845 Mdot
.32251 .50696 Mdot
.66104 .5085 Mdot
.4906 .54419 Mdot
.4568 .35447 Mdot
.69644 .49513 Mdot
.49538 .34005 Mdot
.68385 .75802 Mdot
.30819 .53791 Mdot
.40148 .45776 Mdot
.71765 .4004 Mdot
.28238 .52622 Mdot
.56832 .63501 Mdot
.59484 .41312 Mdot
.60635 .53165 Mdot
.45422 .26308 Mdot
.38098 .70448 Mdot
.40528 .45006 Mdot
.29331 .50603 Mdot
.63873 .47379 Mdot
.66069 .45628 Mdot
.31865 .49638 Mdot
.6056 .21992 Mdot
.45672 .73221 Mdot
.62852 .43571 Mdot
.47795 .35599 Mdot
.46576 .31754 Mdot
.62489 .42275 Mdot
.6003 .44273 Mdot
.3967 .67447 Mdot
.39921 .45625 Mdot
.40846 .45008 Mdot
.37622 .45426 Mdot
.40714 .65802 Mdot
.83188 .42999 Mdot
.26577 .52767 Mdot
.73554 .27777 Mdot
.35657 .35295 Mdot
.6261 .39381 Mdot
.39417 .71926 Mdot
.6101 .46373 Mdot
.6711 .47217 Mdot
.28795 .4994 Mdot
.81453 .46228 Mdot
.59612 .41565 Mdot
.49836 .31261 Mdot
.31256 .48966 Mdot
.69044 .45694 Mdot
.33903 .50537 Mdot
.6103 .68629 Mdot
.72745 .42125 Mdot
.3225 .50269 Mdot
.45209 .3468 Mdot
.32228 .50185 Mdot
.62947 .45374 Mdot
.58284 .51539 Mdot
.49857 .33328 Mdot
.60581 .66743 Mdot
.59675 .49237 Mdot
.60534 .44935 Mdot
.40387 .79812 Mdot
.35634 .41133 Mdot
.63013 .67232 Mdot
.66594 .49328 Mdot
.6227 .54142 Mdot
.61423 .67479 Mdot
.59676 .48502 Mdot
.67535 .49417 Mdot
.59716 .57156 Mdot
.29568 .55404 Mdot
.56107 .69201 Mdot
.80901 .49595 Mdot
.50388 .33077 Mdot
.39597 .2752 Mdot
.38191 .44728 Mdot
.26099 .49938 Mdot
.44317 .50602 Mdot
.39865 .4456 Mdot
.35692 .32902 Mdot
.19002 .49998 Mdot
.40218 .45176 Mdot
.39532 .65462 Mdot
.55644 .35248 Mdot
.67138 .50365 Mdot
.61641 .43412 Mdot
.56529 .69406 Mdot
.47506 .30482 Mdot
.23087 .3927 Mdot
.26832 .55699 Mdot
.61192 .47799 Mdot
.50335 .30951 Mdot
.37673 .25984 Mdot
.39383 .4431 Mdot
.60631 .6953 Mdot
.59577 .66605 Mdot
.6024 .44241 Mdot
.61498 .6055 Mdot
.46805 .32411 Mdot
.62429 .48408 Mdot
.59779 .46872 Mdot
.43433 .70067 Mdot
.44676 .32287 Mdot
.39029 .70507 Mdot
.41052 .45555 Mdot
.31113 .23949 Mdot
.336 .78827 Mdot
.32133 .51876 Mdot
.39848 .49821 Mdot
.26099 .54116 Mdot
.23113 .62641 Mdot
.40059 .45598 Mdot
.62146 .48172 Mdot
.47779 .36674 Mdot
.62754 .48495 Mdot
.64 .47671 Mdot
.6397 .45225 Mdot
.72551 .43992 Mdot
.68544 .74905 Mdot
.59279 .68118 Mdot
.62856 .51723 Mdot
.42434 .66402 Mdot
.3736 .27776 Mdot
.46272 .21006 Mdot
.62326 .46253 Mdot
.60139 .45865 Mdot
.48485 .37169 Mdot
.58867 .44909 Mdot
.28356 .53557 Mdot
.49809 .32049 Mdot
.66194 .45334 Mdot
.63957 .74176 Mdot
.59348 .4609 Mdot
.38864 .51108 Mdot
.32719 .51084 Mdot
.55486 .49146 Mdot
.61862 .53049 Mdot
.40161 .45605 Mdot
.40484 .44953 Mdot
.42002 .44242 Mdot
.30311 .48679 Mdot
.43342 .70072 Mdot
.37849 .65712 Mdot
.61356 .52534 Mdot
.65994 .50514 Mdot
.59059 .52227 Mdot
.44391 .70886 Mdot
.41987 .5805 Mdot
.51333 .39778 Mdot
.69815 .45988 Mdot
.40375 .66149 Mdot
.48023 .26287 Mdot
.77245 .43356 Mdot
.49514 .3136 Mdot
.42339 .74228 Mdot
.29808 .53411 Mdot
.59857 .71673 Mdot
.71197 .67327 Mdot
.47497 .36138 Mdot
.49884 .36227 Mdot
.40082 .67728 Mdot
.48978 .51479 Mdot
.62034 .88539 Mdot
.40759 .70192 Mdot
.45253 .61365 Mdot
.47429 .33037 Mdot
.58479 .44527 Mdot
.55307 .56612 Mdot
.49081 .49856 Mdot
.4167 .66978 Mdot
.63079 .49374 Mdot
.52832 .66322 Mdot
.39727 .67398 Mdot
.58066 .48928 Mdot
.42742 .66885 Mdot
.30146 .49354 Mdot
.40122 .69785 Mdot
.48174 .28785 Mdot
.63953 .48454 Mdot
.57256 .89947 Mdot
.45652 .48055 Mdot
.61924 .48889 Mdot
.32173 .49802 Mdot
.27911 .598 Mdot
.63094 .44858 Mdot
.57324 .71634 Mdot
.42058 .66017 Mdot
.24424 .64859 Mdot
.67743 .47795 Mdot
.41057 .67442 Mdot
.48462 .28442 Mdot
.4409 .72569 Mdot
.6364 .73595 Mdot
.40721 .44975 Mdot
.47085 .34109 Mdot
.37538 .43693 Mdot
.26796 .52561 Mdot
.61721 .41716 Mdot
.59883 .47549 Mdot
.47672 .34994 Mdot
.43135 .53115 Mdot
.68851 .41439 Mdot
.63553 .48344 Mdot
.39139 .68593 Mdot
.44328 .68586 Mdot
.46009 .41712 Mdot
.40027 .7121 Mdot
.62472 .5417 Mdot
.47242 .35101 Mdot
.66522 .45288 Mdot
.45779 .3381 Mdot
.59045 .46558 Mdot
.28306 .46631 Mdot
.49002 .30919 Mdot
.68042 .55439 Mdot
.64262 .48208 Mdot
.42513 .27999 Mdot
.60986 .50388 Mdot
.63756 .44282 Mdot
.4396 .67373 Mdot
.58845 .69076 Mdot
.58606 .49206 Mdot
.21436 .52849 Mdot
.61415 .68071 Mdot
.65696 .23255 Mdot
.40716 .72565 Mdot
.58726 .67019 Mdot
.7165 .62766 Mdot
.41188 .44549 Mdot
.57883 .68924 Mdot
.39676 .47012 Mdot
.3206 .5104 Mdot
.45043 .29521 Mdot
.63941 .49506 Mdot
.33833 .22733 Mdot
.46324 .72181 Mdot
.38752 .45236 Mdot
.5981 .45428 Mdot
.61137 .45844 Mdot
.50446 .31366 Mdot
.57813 .84852 Mdot
.42234 .65241 Mdot
.64313 .44165 Mdot
.48516 .36308 Mdot
.52176 .85841 Mdot
.40995 .66754 Mdot
.59447 .67879 Mdot
.30875 .54288 Mdot
.50752 .37532 Mdot
.4048 .45629 Mdot
.30564 .53972 Mdot
.37376 .73638 Mdot
.69907 .70827 Mdot
.67581 .46725 Mdot
.39115 .7139 Mdot
.69464 .70208 Mdot
.69988 .48944 Mdot
.27077 .49507 Mdot
.3126 .46202 Mdot
.49386 .32507 Mdot
.31771 .49491 Mdot
.56616 .70249 Mdot
.44272 .32365 Mdot
.49643 .33697 Mdot
.28841 .53855 Mdot
.25225 .32803 Mdot
.55994 .56863 Mdot
.30238 .47918 Mdot
.52326 .53117 Mdot
.69301 .70245 Mdot
.39156 .46023 Mdot
.6062 .69793 Mdot
.62618 .76801 Mdot
.46676 .32244 Mdot
.32903 .41904 Mdot
.69603 .70184 Mdot
.64327 .44514 Mdot
.57914 .70897 Mdot
.38199 .27932 Mdot
.25113 .5264 Mdot
.29553 .54242 Mdot
.35046 .68229 Mdot
.58518 .71638 Mdot
.59505 .44175 Mdot
.78904 .36018 Mdot
.63013 .50387 Mdot
.31177 .53376 Mdot
.45639 .58545 Mdot
.44723 .32643 Mdot
.26775 .50781 Mdot
.45736 .59332 Mdot
.67189 .47782 Mdot
.61077 .48848 Mdot
.54096 .70761 Mdot
.44824 .31251 Mdot
.4012 .46101 Mdot
.63035 .48967 Mdot
.60955 .44918 Mdot
.62046 .41879 Mdot
.78905 .47944 Mdot
.65622 .57179 Mdot
.65198 .44586 Mdot
.37775 .67623 Mdot
.61037 .54564 Mdot
.62435 .42714 Mdot
.50983 .32019 Mdot
.65278 .74634 Mdot
.41037 .4563 Mdot
.61609 .43529 Mdot
.62744 .43559 Mdot
.27635 .53926 Mdot
.56122 .57005 Mdot
.48863 .49378 Mdot
.43553 .71601 Mdot
.35365 .68423 Mdot
.67373 .50837 Mdot
.47726 .34359 Mdot
.56347 .71022 Mdot
.65765 .53306 Mdot
.50084 .32008 Mdot
.61896 .52113 Mdot
.43112 .66811 Mdot
.39873 .45363 Mdot
.70772 .4726 Mdot
.5804 .69803 Mdot
.31651 .54672 Mdot
.69874 .25688 Mdot
.38362 .69769 Mdot
.65967 .49074 Mdot
.37719 .65507 Mdot
.4179 .69527 Mdot
.38512 .4515 Mdot
.58071 .51827 Mdot
.46677 .33552 Mdot
.45052 .34057 Mdot
.67904 .74185 Mdot
.40551 .65652 Mdot
.43595 .81026 Mdot
.30647 .49427 Mdot
.62202 .51531 Mdot
.41412 .38171 Mdot
.44865 .33316 Mdot
.64505 .63433 Mdot
.59304 .66847 Mdot
.29715 .54166 Mdot
.37139 .46433 Mdot
.49136 .30882 Mdot
.45047 .33035 Mdot
.64081 .47127 Mdot
.61806 .4701 Mdot
.38179 .75503 Mdot
.65671 .66338 Mdot
.27298 .51294 Mdot
.60383 .68181 Mdot
.41986 .73153 Mdot
.67062 .49078 Mdot
.49142 .3181 Mdot
.7785 .35065 Mdot
.60682 .50076 Mdot
.42522 .66489 Mdot
.48448 .31648 Mdot
.58525 .67862 Mdot
.5703 .68989 Mdot
.64055 .44419 Mdot
.75243 .33333 Mdot
.28423 .5282 Mdot
.46634 .34848 Mdot
.48553 .27084 Mdot
.63998 .51639 Mdot
.62207 .46688 Mdot
.66454 .41586 Mdot
.26508 .50806 Mdot
.70334 .47986 Mdot
.61962 .69039 Mdot
.4599 .31811 Mdot
.6249 .4889 Mdot
.57739 .69606 Mdot
.54123 .33553 Mdot
.39632 .44892 Mdot
.40663 .66919 Mdot
.57704 .71804 Mdot
.59062 .70084 Mdot
.60961 .6762 Mdot
.33052 .42168 Mdot
.44168 .36443 Mdot
.80872 .60615 Mdot
.63607 .49061 Mdot
.6924 .70266 Mdot
.5985 .42079 Mdot
.28786 .49153 Mdot
.38082 .69011 Mdot
.63881 .46493 Mdot
.63606 .49102 Mdot
.72795 .29861 Mdot
.56225 .44921 Mdot
.56203 .44591 Mdot
.44693 .33642 Mdot
.44192 .2602 Mdot
.387 .71741 Mdot
.44178 .84103 Mdot
.60341 .16807 Mdot
.68073 .49273 Mdot
.49001 .51902 Mdot
.49605 .31825 Mdot
.28445 .54462 Mdot
.52916 .54035 Mdot
.35606 .50552 Mdot
.46633 .30921 Mdot
.6736 .47986 Mdot
.69877 .26114 Mdot
.61114 .70934 Mdot
.63257 .45791 Mdot
.30117 .52292 Mdot
.63337 .45812 Mdot
.29482 .48653 Mdot
.43942 .38252 Mdot
.47736 .4881 Mdot
.64376 .49233 Mdot
.68029 .48045 Mdot
.57357 .5515 Mdot
.62099 .46473 Mdot
.26873 .64366 Mdot
.48509 .32481 Mdot
.69529 .54387 Mdot
.64511 .42665 Mdot
.72452 .34753 Mdot
.59578 .47006 Mdot
.43393 .49729 Mdot
.60495 .48607 Mdot
.79146 .50272 Mdot
.59853 .43478 Mdot
.6069 .49312 Mdot
.28127 .5075 Mdot
.27329 .53974 Mdot
.49494 .28918 Mdot
.39328 .46355 Mdot
.37285 .26851 Mdot
.60294 .45328 Mdot
.44532 .69029 Mdot
.51093 .43315 Mdot
.59129 .69511 Mdot
.46206 .31581 Mdot
.26973 .78345 Mdot
.27131 .50792 Mdot
.39716 .65504 Mdot
.45336 .62677 Mdot
.37189 .68492 Mdot
.4081 .74553 Mdot
.43135 .26807 Mdot
.60778 .69678 Mdot
.5943 .45592 Mdot
.70002 .30119 Mdot
.3677 .41507 Mdot
.6435 .51512 Mdot
.41675 .64399 Mdot
.53748 .43399 Mdot
.69002 .7336 Mdot
.59412 .72431 Mdot
.60105 .7092 Mdot
.28733 .50785 Mdot
.39505 .72821 Mdot
.69672 .45061 Mdot
.587 .67045 Mdot
.382 .69031 Mdot
.38215 .44275 Mdot
.56062 .74344 Mdot
.46564 .32641 Mdot
.63453 .37827 Mdot
.42724 .39266 Mdot
.27155 .50968 Mdot
.2148 .52555 Mdot
.43234 .30713 Mdot
.43893 .32304 Mdot
.38522 .46342 Mdot
.41145 .66393 Mdot
.44892 .29458 Mdot
.6403 .4816 Mdot
.60009 .53404 Mdot
.60164 .44279 Mdot
.56713 .69011 Mdot
.59697 .46083 Mdot
.39486 .67315 Mdot
.27478 .52615 Mdot
.42846 .69751 Mdot
.27781 .52505 Mdot
.65092 .21052 Mdot
.62088 .429 Mdot
.62222 .47037 Mdot
.48938 .53963 Mdot
.45184 .32539 Mdot
.68047 .28987 Mdot
.42293 .66329 Mdot
.43375 .68586 Mdot
.66338 .45133 Mdot
.45922 .36482 Mdot
.58324 .63222 Mdot
.52153 .54248 Mdot
.60236 .48026 Mdot
.48589 .32567 Mdot
.66203 .44839 Mdot
.23051 .61061 Mdot
.46663 .46485 Mdot
.46187 .35262 Mdot
.81354 .4966 Mdot
.64555 .46692 Mdot
.57393 .51791 Mdot
.55586 .50901 Mdot
.77326 .49836 Mdot
.58202 .45545 Mdot
.50302 .33295 Mdot
.63099 .43015 Mdot
.48124 .33988 Mdot
.416 .70225 Mdot
.26421 .52524 Mdot
.47927 .33723 Mdot
.63343 .50041 Mdot
.61274 .1742 Mdot
.27435 .52862 Mdot
.63315 .46616 Mdot
.29941 .50296 Mdot
.45462 .296 Mdot
.45591 .30923 Mdot
.37256 .47003 Mdot
.45212 .61652 Mdot
.28361 .53408 Mdot
.65883 .50637 Mdot
.34057 .4089 Mdot
.66657 .45447 Mdot
.35475 .6789 Mdot
.67515 .4484 Mdot
.65769 .51845 Mdot
.83443 .40233 Mdot
.43403 .52089 Mdot
.37049 .82098 Mdot
.24158 .54309 Mdot
.33361 .40466 Mdot
.5057 .29331 Mdot
.59384 .7242 Mdot
.40227 .51367 Mdot
.41242 .43967 Mdot
.37488 .68265 Mdot
.63927 .46932 Mdot
.44734 .23394 Mdot
.30468 .4812 Mdot
.59144 .68702 Mdot
.64477 .48991 Mdot
.37895 .72122 Mdot
.43736 .43624 Mdot
.29827 .54243 Mdot
.46417 .32459 Mdot
.45616 .31289 Mdot
.71919 .72726 Mdot
.6215 .48811 Mdot
.61828 .47527 Mdot
.27473 .53272 Mdot
.69228 .43306 Mdot
.60932 .67838 Mdot
.33287 .59565 Mdot
.30351 .5207 Mdot
.46603 .4717 Mdot
.44495 .33137 Mdot
.61076 .46076 Mdot
.49268 .54654 Mdot
.29078 .40263 Mdot
.52023 .24993 Mdot
.58862 .71162 Mdot
.62896 .60859 Mdot
.50315 .33355 Mdot
.30151 .5179 Mdot
.7189 .6363 Mdot
.60377 .41302 Mdot
.61102 .45587 Mdot
.68017 .58672 Mdot
.52181 .54056 Mdot
.44848 .61104 Mdot
.65294 .41163 Mdot
.5704 .58638 Mdot
.66459 .4531 Mdot
.66135 .45694 Mdot
.64898 .52276 Mdot
.66627 .44247 Mdot
.48701 .32981 Mdot
.73665 .38118 Mdot
.40662 .685 Mdot
.56174 .31161 Mdot
.35313 .72522 Mdot
.64662 .4995 Mdot
.67292 .47751 Mdot
.63649 .34507 Mdot
.51314 .50197 Mdot
.4784 .3238 Mdot
.47924 .26892 Mdot
.26693 .52905 Mdot
.56656 .43733 Mdot
.41091 .65709 Mdot
.5461 .47643 Mdot
.42071 .68584 Mdot
.48788 .32707 Mdot
.42587 .71374 Mdot
.33167 .50727 Mdot
.39179 .71417 Mdot
.39542 .66239 Mdot
.30174 .5437 Mdot
.45571 .30481 Mdot
.60512 .49389 Mdot
.31084 .5389 Mdot
.57682 .6344 Mdot
.56735 .69014 Mdot
.37123 .47055 Mdot
.5864 .4381 Mdot
.56052 .47917 Mdot
.20615 .60193 Mdot
.41679 .71811 Mdot
.49274 .4834 Mdot
.48858 .30835 Mdot
.56292 .70538 Mdot
.48653 .33353 Mdot
.76238 .667 Mdot
.58345 .70412 Mdot
.37414 .47181 Mdot
.698 .64217 Mdot
.28896 .56764 Mdot
.68155 .45123 Mdot
.45799 .26059 Mdot
.42254 .68942 Mdot
.30931 .48643 Mdot
.37911 .28037 Mdot
.64917 .45895 Mdot
.39747 .43091 Mdot
.43795 .31078 Mdot
.411 .44598 Mdot
.29956 .52176 Mdot
.39055 .4793 Mdot
.61621 .48682 Mdot
.28553 .56685 Mdot
.6824 .47305 Mdot
.68931 .38836 Mdot
.35907 .72488 Mdot
.53072 .31064 Mdot
.67436 .46876 Mdot
.40778 .66657 Mdot
.67174 .46222 Mdot
.57189 .36822 Mdot
.68409 .66509 Mdot
.68032 .50246 Mdot
.52441 .48179 Mdot
.22058 .63528 Mdot
.49248 .32111 Mdot
.6285 .53993 Mdot
.38817 .45756 Mdot
.66588 .48152 Mdot
.40241 .16025 Mdot
.57985 .69122 Mdot
.62135 .66592 Mdot
.63468 .49832 Mdot
.63031 .48636 Mdot
.73728 .31593 Mdot
.42418 .30502 Mdot
.37204 .46526 Mdot
.61591 .45005 Mdot
.71423 .56524 Mdot
.28541 .50534 Mdot
.67895 .45711 Mdot
.61884 .43191 Mdot
.41097 .7863 Mdot
.2902 .5023 Mdot
.40415 .72299 Mdot
.41223 .44399 Mdot
.43997 .70096 Mdot
.572 .66843 Mdot
.59487 .59103 Mdot
.65249 .62677 Mdot
.463 .44953 Mdot
.57427 .71452 Mdot
.64316 .50337 Mdot
.53015 .31676 Mdot
.61992 .49472 Mdot
.60096 .70641 Mdot
.30605 .51169 Mdot
.48354 .32916 Mdot
.62008 .37969 Mdot
.38424 .448 Mdot
.63288 .51342 Mdot
.5894 .72749 Mdot
.47402 .33714 Mdot
.24315 .41747 Mdot
.47996 .30665 Mdot
.27938 .52154 Mdot
.28205 .48642 Mdot
.5868 .69838 Mdot
.48777 .33226 Mdot
.43825 .70252 Mdot
.23483 .52962 Mdot
.68661 .47166 Mdot
.33197 .50522 Mdot
.45379 .28579 Mdot
.50706 .32556 Mdot
.46629 .36444 Mdot
.65157 .43371 Mdot
.50771 .5274 Mdot
.61821 .40865 Mdot
.27412 .52995 Mdot
.37352 .70555 Mdot
.66524 .67125 Mdot
.72238 .31803 Mdot
.46764 .48385 Mdot
.58363 .48606 Mdot
.59738 .45886 Mdot
.60198 .44347 Mdot
.64777 .43761 Mdot
.33686 .59201 Mdot
.62111 .42913 Mdot
.28018 .50358 Mdot
.41503 .6891 Mdot
.60214 .47252 Mdot
.39286 .4576 Mdot
.42349 .58058 Mdot
.5608 .70582 Mdot
.72755 .41424 Mdot
.41281 .27731 Mdot
.47542 .33574 Mdot
.40049 .71519 Mdot
.42886 .71195 Mdot
.58024 .67565 Mdot
.31252 .53584 Mdot
.47123 .30541 Mdot
.78678 .51069 Mdot
.61659 .69258 Mdot
.6159 .43575 Mdot
.49029 .54262 Mdot
.79091 .46373 Mdot
.61265 .51387 Mdot
.6377 .44748 Mdot
.40283 .46124 Mdot
.3922 .65838 Mdot
.38963 .19901 Mdot
.24476 .34614 Mdot
.58753 .69262 Mdot
.60025 .67685 Mdot
.47876 .36994 Mdot
.62115 .51588 Mdot
.28615 .52971 Mdot
.57463 .58067 Mdot
.20922 .58913 Mdot
.39355 .25442 Mdot
.23309 .62871 Mdot
.59345 .46294 Mdot
.70327 .35989 Mdot
.67541 .4468 Mdot
.44785 .36925 Mdot
.46529 .36643 Mdot
.47238 .32546 Mdot
.28099 .51022 Mdot
.70079 .70956 Mdot
.28138 .5011 Mdot
.42141 .25743 Mdot
.49838 .34906 Mdot
.43764 .54825 Mdot
.43341 .68095 Mdot
.57145 .43597 Mdot
.60715 .69932 Mdot
.608 .63134 Mdot
.62083 .53757 Mdot
.61965 .60454 Mdot
.39456 .71947 Mdot
.47201 .29795 Mdot
.58793 .4236 Mdot
.36843 .27471 Mdot
.48688 .51282 Mdot
.23136 .66422 Mdot
.46474 .24137 Mdot
.57622 .69964 Mdot
.57518 .30528 Mdot
.61445 .68787 Mdot
.2992 .54096 Mdot
.64534 .46216 Mdot
.60997 .50668 Mdot
.6351 .43979 Mdot
.65855 .43816 Mdot
.2949 .5056 Mdot
.68841 .47456 Mdot
.65816 .72716 Mdot
.39056 .43785 Mdot
.40792 .57101 Mdot
.57254 .68916 Mdot
.3016 .49153 Mdot
.41666 .69328 Mdot
.38335 .46423 Mdot
.59878 .72983 Mdot
.62319 .42086 Mdot
.62784 .49987 Mdot
.38261 .44357 Mdot
.71007 .44553 Mdot
.56701 .47241 Mdot
.40811 .67921 Mdot
.43751 .58473 Mdot
.56762 .68241 Mdot
.60341 .71201 Mdot
.3162 .49556 Mdot
.48681 .33363 Mdot
.57746 .67469 Mdot
.39203 .72783 Mdot
.67949 .46293 Mdot
.67934 .48603 Mdot
.45739 .2829 Mdot
.69645 .70415 Mdot
.56119 .70857 Mdot
.70069 .48598 Mdot
.45626 .32762 Mdot
.43716 .31252 Mdot
.61745 .45013 Mdot
.69417 .48478 Mdot
.49225 .37014 Mdot
.587 .6756 Mdot
.31252 .49518 Mdot
.45281 .53775 Mdot
.28349 .49673 Mdot
.4604 .33464 Mdot
.60847 .54261 Mdot
.44755 .31124 Mdot
.64998 .46247 Mdot
.40866 .86348 Mdot
.60701 .43076 Mdot
.73679 .49995 Mdot
.50835 .67129 Mdot
.42542 .6673 Mdot
.4195 .66547 Mdot
.39756 .45506 Mdot
.50019 .32047 Mdot
.64226 .54227 Mdot
.60907 .69157 Mdot
.33457 .40487 Mdot
.42827 .30578 Mdot
.39893 .66167 Mdot
.40297 .65433 Mdot
.3046 .51011 Mdot
.59575 .46636 Mdot
.6087 .46481 Mdot
.39376 .71628 Mdot
.29754 .59911 Mdot
.48595 .34169 Mdot
.61861 .47543 Mdot
.64264 .42937 Mdot
.40866 .68666 Mdot
.26504 .48711 Mdot
.43847 .30037 Mdot
.64964 .43176 Mdot
.67465 .65925 Mdot
.28618 .48936 Mdot
.65532 .49887 Mdot
.6715 .44286 Mdot
.59422 .69795 Mdot
.64742 .61295 Mdot
.69262 .69917 Mdot
.27195 .54381 Mdot
.40657 .45364 Mdot
.60121 .50037 Mdot
.42637 .66998 Mdot
.5875 .43241 Mdot
.17305 .43136 Mdot
.39798 .43509 Mdot
.61462 .48355 Mdot
.66864 .51433 Mdot
.45853 .3413 Mdot
.62191 .48381 Mdot
.28944 .46531 Mdot
.39116 .69303 Mdot
.61391 .48386 Mdot
.75238 .33612 Mdot
.30498 .51218 Mdot
.61828 .53606 Mdot
.5913 .71816 Mdot
.45113 .60574 Mdot
.59433 .18227 Mdot
.44011 .71624 Mdot
.56988 .69557 Mdot
.59725 .4639 Mdot
.4387 .70931 Mdot
.3053 .54495 Mdot
.68188 .56257 Mdot
.64451 .50433 Mdot
.2797 .50015 Mdot
.27609 .52861 Mdot
.58447 .6954 Mdot
.34882 .8266 Mdot
.67163 .51031 Mdot
.62879 .46089 Mdot
.18626 .58969 Mdot
.50082 .36606 Mdot
.63435 .4636 Mdot
.59751 .47302 Mdot
.32273 .51224 Mdot
.7581 .64814 Mdot
.62746 .60771 Mdot
.32143 .59523 Mdot
.29087 .48775 Mdot
.42577 .65059 Mdot
.38718 .69643 Mdot
.57097 .69654 Mdot
.48362 .3149 Mdot
.56305 .69421 Mdot
.4008 .69295 Mdot
.63591 .44228 Mdot
.31558 .51961 Mdot
.56048 .21986 Mdot
.32648 .50363 Mdot
.39247 .7306 Mdot
.43659 .35071 Mdot
.45083 .22311 Mdot
.16119 .46846 Mdot
.43672 .39597 Mdot
.26008 .52251 Mdot
.59153 .6951 Mdot
.23312 .37475 Mdot
.60172 .47434 Mdot
.64903 .37206 Mdot
.63136 .4591 Mdot
.50686 .26552 Mdot
.38129 .68946 Mdot
.37462 .45286 Mdot
.64926 .45855 Mdot
.63031 .60778 Mdot
.29779 .54425 Mdot
.29433 .53385 Mdot
.63524 .43304 Mdot
.27981 .52397 Mdot
.61005 .47045 Mdot
.41194 .69138 Mdot
.36413 .82674 Mdot
.60988 .49356 Mdot
.6073 .54793 Mdot
.26835 .55382 Mdot
.36973 .47027 Mdot
.39987 .6467 Mdot
.72572 .3663 Mdot
.36628 .26283 Mdot
.28563 .52632 Mdot
.72673 .43656 Mdot
.41287 .71747 Mdot
.38826 .46571 Mdot
.44029 .66708 Mdot
.62361 .45551 Mdot
.59326 .4683 Mdot
.64937 .44202 Mdot
.5984 .46465 Mdot
.61336 .363 Mdot
.56578 .46489 Mdot
.60256 .27846 Mdot
.6355 .49087 Mdot
.73803 .49108 Mdot
.28679 .49871 Mdot
.57166 .51826 Mdot
.46783 .60966 Mdot
.59236 .4507 Mdot
.4469 .2626 Mdot
.30207 .49246 Mdot
.39954 .36857 Mdot
.29245 .50401 Mdot
.42981 .69429 Mdot
.28801 .54187 Mdot
.64696 .46599 Mdot
.46686 .31782 Mdot
.3988 .70672 Mdot
.51107 .39944 Mdot
.37401 .69659 Mdot
.61916 .48876 Mdot
.33011 .55514 Mdot
.43714 .68385 Mdot
.55686 .46292 Mdot
.46845 .31514 Mdot
.73248 .56183 Mdot
.47094 .37917 Mdot
.62663 .48078 Mdot
.63103 .47667 Mdot
.37384 .45591 Mdot
.29662 .54348 Mdot
.44756 .34471 Mdot
.42852 .79062 Mdot
.57858 .72776 Mdot
.48081 .31965 Mdot
.56282 .51891 Mdot
.48876 .52178 Mdot
.46013 .34803 Mdot
.74917 .53431 Mdot
.30978 .53552 Mdot
.49716 .35656 Mdot
.65567 .42543 Mdot
.56648 .3241 Mdot
.61022 .70631 Mdot
.44202 .69056 Mdot
.55166 .57429 Mdot
.38811 .69505 Mdot
.33005 .53336 Mdot
.41336 .65463 Mdot
.28625 .50183 Mdot
.51764 .44194 Mdot
.45669 .58874 Mdot
.31996 .49101 Mdot
.27629 .55955 Mdot
.40171 .6818 Mdot
.64006 .43531 Mdot
.42617 .56956 Mdot
.64807 .54148 Mdot
.59655 .52772 Mdot
.27656 .5007 Mdot
.50272 .34275 Mdot
.44413 .31517 Mdot
.69868 .53584 Mdot
.45076 .32151 Mdot
.40686 .70606 Mdot
.46457 .43284 Mdot
.71656 .39903 Mdot
.30835 .51472 Mdot
.44979 .62095 Mdot
.67315 .46814 Mdot
.40546 .67179 Mdot
.41086 .70717 Mdot
.27593 .52493 Mdot
.55159 .29936 Mdot
.60192 .52844 Mdot
.51304 .33278 Mdot
.48846 .36138 Mdot
.46192 .34991 Mdot
.46364 .3674 Mdot
.70551 .70887 Mdot
.30961 .48667 Mdot
.50145 .3266 Mdot
.66051 .44227 Mdot
.60239 .49742 Mdot
.40643 .4421 Mdot
.58342 .67789 Mdot
.61204 .41311 Mdot
.64454 .54185 Mdot
.61652 .45144 Mdot
.42753 .66877 Mdot
.53822 .50695 Mdot
.39475 .43686 Mdot
.4035 .65591 Mdot
.4091 .65741 Mdot
.40265 .45563 Mdot
.52118 .44349 Mdot
.41027 .20212 Mdot
.64178 .44105 Mdot
.42583 .2704 Mdot
.42078 .66855 Mdot
.58648 .61241 Mdot
.729 .48504 Mdot
.65971 .50867 Mdot
.39055 .59094 Mdot
.41114 .69787 Mdot
.51432 .30691 Mdot
.62262 .45999 Mdot
.3845 .46148 Mdot
.60217 .71457 Mdot
.57266 .54139 Mdot
.40036 .46235 Mdot
.49122 .33063 Mdot
.37878 .77409 Mdot
.50386 .31099 Mdot
.43919 .6893 Mdot
.62553 .53976 Mdot
.59918 .89374 Mdot
.42337 .69161 Mdot
.32352 .41076 Mdot
.45645 .59116 Mdot
.61146 .492 Mdot
.3923 .707 Mdot
.46209 .27827 Mdot
.28477 .49031 Mdot
.50188 .53976 Mdot
.49069 .31753 Mdot
.3823 .46363 Mdot
.40516 .44578 Mdot
.40743 .68469 Mdot
.4795 .36109 Mdot
.68512 .46449 Mdot
.45873 .31158 Mdot
.30965 .52611 Mdot
.65562 .47589 Mdot
.37262 .26791 Mdot
.58276 .52072 Mdot
.45863 .31417 Mdot
.38049 .71993 Mdot
.6097 .67012 Mdot
.6403 .49943 Mdot
.39169 .33243 Mdot
.59637 .46743 Mdot
.30192 .50488 Mdot
.52992 .62177 Mdot
.5655 .22435 Mdot
.62236 .43884 Mdot
.67306 .47122 Mdot
.32908 .52142 Mdot
.62362 .44024 Mdot
.65631 .51703 Mdot
.39593 .47706 Mdot
.45862 .34515 Mdot
.60268 .46792 Mdot
.38515 .69035 Mdot
.60379 .20974 Mdot
.64384 .46091 Mdot
.26193 .47386 Mdot
.71792 .5672 Mdot
.50804 .59757 Mdot
.62782 .54824 Mdot
.6434 .63361 Mdot
.63016 .47219 Mdot
.65397 .51282 Mdot
.63981 .43802 Mdot
.69807 .36057 Mdot
.39995 .68778 Mdot
.3974 .66612 Mdot
.59545 .72017 Mdot
.70225 .57409 Mdot
.58277 .70997 Mdot
.32825 .51971 Mdot
.45204 .62268 Mdot
.38301 .44467 Mdot
.48546 .33565 Mdot
.64288 .45857 Mdot
.37543 .69492 Mdot
.61331 .45944 Mdot
.66534 .48433 Mdot
.40463 .70148 Mdot
.41309 .70342 Mdot
.44198 .71522 Mdot
.61367 .70577 Mdot
.47734 .32847 Mdot
.64387 .44882 Mdot
.61461 .68125 Mdot
.6358 .42455 Mdot
.45957 .51312 Mdot
.47677 .32647 Mdot
.45702 .31517 Mdot
.45037 .30176 Mdot
.62054 .5043 Mdot
.64958 .4688 Mdot
.28123 .50102 Mdot
.45746 .28317 Mdot
.28769 .53665 Mdot
.39126 .70562 Mdot
.40085 .67335 Mdot
.62432 .45514 Mdot
.70039 .46053 Mdot
.57666 .68455 Mdot
.42658 .70865 Mdot
.4164 .43995 Mdot
.59267 .7198 Mdot
.59857 .44652 Mdot
.3889 .70057 Mdot
.56818 .71485 Mdot
.49834 .23594 Mdot
.35237 .25325 Mdot
.61316 .70998 Mdot
.63572 .43287 Mdot
.72262 .31114 Mdot
.67915 .66923 Mdot
.57701 .72956 Mdot
.30037 .50014 Mdot
.6012 .48757 Mdot
.25596 .57858 Mdot
.58255 .66951 Mdot
.69419 .69543 Mdot
.40045 .70066 Mdot
.62822 .55673 Mdot
.54873 .51449 Mdot
.70931 .3943 Mdot
.59998 .66535 Mdot
.46006 .31494 Mdot
.47661 .36538 Mdot
.61856 .43604 Mdot
.4503 .61366 Mdot
.32904 .50572 Mdot
.42847 .71261 Mdot
.38646 .67136 Mdot
.46191 .35534 Mdot
.46321 .45435 Mdot
.38538 .69287 Mdot
.62667 .5175 Mdot
.55379 .68759 Mdot
.56885 .43297 Mdot
.72027 .7178 Mdot
.57671 .18603 Mdot
.62389 .54866 Mdot
.61369 .67383 Mdot
.29695 .54628 Mdot
.27646 .51595 Mdot
.28033 .51478 Mdot
.39827 .67608 Mdot
.53258 .54656 Mdot
.38178 .68062 Mdot
.24006 .46746 Mdot
.57689 .69356 Mdot
.75178 .56588 Mdot
.6457 .42323 Mdot
.6127 .49232 Mdot
.67768 .46997 Mdot
.65197 .44367 Mdot
.6287 .47224 Mdot
.2716 .51067 Mdot
.43401 .71284 Mdot
.21782 .60567 Mdot
.47901 .35531 Mdot
.23908 .41677 Mdot
.43421 .68311 Mdot
.40759 .45828 Mdot
.59579 .68334 Mdot
.66858 .60769 Mdot
.55114 .68483 Mdot
.43074 .70561 Mdot
.61113 .51521 Mdot
.48783 .36873 Mdot
.7975 .49318 Mdot
.6355 .48373 Mdot
.42295 .71337 Mdot
.43633 .65676 Mdot
.55113 .29048 Mdot
.64341 .40194 Mdot
.43943 .61662 Mdot
.4927 .52062 Mdot
.61774 .70366 Mdot
.58616 .48872 Mdot
.60505 .60123 Mdot
.4021 .69117 Mdot
.42413 .68003 Mdot
.58168 .73081 Mdot
.54642 .38424 Mdot
.49887 .3391 Mdot
.37504 .44961 Mdot
.30411 .49821 Mdot
.62146 .4985 Mdot
.39513 .68155 Mdot
.52802 .33796 Mdot
.46812 .53597 Mdot
.29455 .50981 Mdot
.4043 .65481 Mdot
.5963 .47303 Mdot
.61754 .43863 Mdot
.57981 .70456 Mdot
.46572 .7367 Mdot
.64756 .54168 Mdot
.33336 .40595 Mdot
.48268 .47914 Mdot
.45708 .5972 Mdot
.61059 .45642 Mdot
.44625 .32391 Mdot
.40073 .45621 Mdot
.60555 .69738 Mdot
.61533 .42308 Mdot
.38933 .2146 Mdot
.49646 .30232 Mdot
.28457 .53353 Mdot
.39759 .45974 Mdot
.57325 .57455 Mdot
.59679 .46793 Mdot
.63092 .45894 Mdot
.65207 .43408 Mdot
.39244 .2081 Mdot
.38501 .68075 Mdot
.45146 .35286 Mdot
.58035 .71204 Mdot
.46052 .30703 Mdot
.42504 .66098 Mdot
.44415 .60427 Mdot
.62134 .42813 Mdot
.4894 .30102 Mdot
.46713 .30738 Mdot
.30594 .5133 Mdot
.31164 .53852 Mdot
.43154 .7243 Mdot
.59889 .46923 Mdot
.3782 .45006 Mdot
.5018 .33653 Mdot
.42499 .71904 Mdot
.58055 .70418 Mdot
.33596 .48827 Mdot
.63471 .49248 Mdot
.4049 .68571 Mdot
.63875 .54171 Mdot
.47058 .34668 Mdot
.4343 .69558 Mdot
.3952 .46553 Mdot
.58805 .67635 Mdot
.59444 .48091 Mdot
.23252 .64551 Mdot
.38852 .46259 Mdot
.63091 .50304 Mdot
.56535 .18806 Mdot
.45006 .61219 Mdot
.51295 .38954 Mdot
.38217 .70287 Mdot
.37966 .45359 Mdot
.45822 .36103 Mdot
.579 .32815 Mdot
.42023 .67899 Mdot
.71133 .27831 Mdot
.44439 .55054 Mdot
.64436 .44381 Mdot
.49251 .32505 Mdot
.54175 .70196 Mdot
.33755 .39136 Mdot
.67155 .6691 Mdot
.61321 .47685 Mdot
.38819 .6939 Mdot
.60139 .71435 Mdot
.29406 .53493 Mdot
.25529 .48004 Mdot
.7488 .69934 Mdot
.39553 .65997 Mdot
.64265 .45508 Mdot
.50167 .34603 Mdot
.28189 .53043 Mdot
.70568 .26497 Mdot
.39621 .72938 Mdot
.38456 .70341 Mdot
.67732 .48262 Mdot
.58566 .71267 Mdot
.26383 .57911 Mdot
.39261 .67145 Mdot
.4383 .70747 Mdot
.42217 .46228 Mdot
.59849 .72067 Mdot
.65234 .43621 Mdot
.69919 .53546 Mdot
.67292 .44822 Mdot
.27115 .42661 Mdot
.37896 .45286 Mdot
.48117 .35443 Mdot
.63761 .46507 Mdot
.21789 .63209 Mdot
.41895 .68554 Mdot
.49316 .51823 Mdot
.26881 .48686 Mdot
.31127 .53834 Mdot
.39234 .69304 Mdot
.6163 .46351 Mdot
.31076 .47629 Mdot
.57341 .69217 Mdot
.64829 .43118 Mdot
.6501 .46513 Mdot
.45355 .28264 Mdot
.31422 .52026 Mdot
.60061 .20614 Mdot
.30078 .5351 Mdot
.31973 .49836 Mdot
.43765 .30844 Mdot
.61726 .43605 Mdot
.43127 .69866 Mdot
.37961 .72433 Mdot
.6782 .51239 Mdot
.58397 .61319 Mdot
.498 .33372 Mdot
.38013 .73973 Mdot
.37444 .21593 Mdot
.67931 .49433 Mdot
.41487 .44335 Mdot
.50212 .26578 Mdot
.29277 .48354 Mdot
.63188 .4426 Mdot
.48065 .34156 Mdot
.42363 .72672 Mdot
.38938 .68557 Mdot
.60237 .41333 Mdot
.27467 .52372 Mdot
.56601 .71059 Mdot
.41124 .70921 Mdot
.45138 .52419 Mdot
.61674 .48512 Mdot
.39578 .42968 Mdot
.41248 .71057 Mdot
.62706 .18479 Mdot
.21284 .62024 Mdot
.46457 .3545 Mdot
.66483 .4965 Mdot
.49996 .35931 Mdot
.57318 .70822 Mdot
.4285 .65792 Mdot
.27547 .50997 Mdot
.60158 .38814 Mdot
.37935 .79139 Mdot
.40054 .67771 Mdot
.48663 .32855 Mdot
.64065 .45311 Mdot
.72549 .45262 Mdot
.60416 .48432 Mdot
.76226 .63909 Mdot
.56277 .71489 Mdot
.30767 .55547 Mdot
.274 .53096 Mdot
.67205 .47794 Mdot
.61077 .67893 Mdot
.39476 .73658 Mdot
.40414 .70026 Mdot
.41105 .83667 Mdot
.39817 .46351 Mdot
.41803 .74583 Mdot
.62182 .50367 Mdot
.4168 .72317 Mdot
.72283 .31956 Mdot
.27902 .53547 Mdot
.68235 .46254 Mdot
.37635 .67256 Mdot
.27548 .40137 Mdot
.49066 .5236 Mdot
.6149 .48212 Mdot
.6946 .43857 Mdot
.2957 .50177 Mdot
.23387 .373 Mdot
.381 .70356 Mdot
.63494 .42552 Mdot
.2924 .47604 Mdot
.50565 .42846 Mdot
.43573 .78537 Mdot
.47689 .32838 Mdot
.37029 .68064 Mdot
.31393 .49751 Mdot
.62361 .55528 Mdot
.57676 .68185 Mdot
.40891 .73503 Mdot
.37292 .68609 Mdot
.659 .48113 Mdot
.60383 .41731 Mdot
.68234 .42596 Mdot
.49443 .33091 Mdot
.32174 .51191 Mdot
.66695 .46885 Mdot
.46582 .50403 Mdot
.6544 .44696 Mdot
.31951 .50357 Mdot
.50104 .91415 Mdot
.60303 .50642 Mdot
.631 .4948 Mdot
.73151 .42279 Mdot
.44618 .3404 Mdot
.45451 .33676 Mdot
.47361 .48563 Mdot
.6137 .50491 Mdot
.43576 .5392 Mdot
.47902 .33038 Mdot
.48878 .31978 Mdot
.43619 .54184 Mdot
.65385 .48029 Mdot
.35968 .48452 Mdot
.281 .52911 Mdot
.31222 .53774 Mdot
.45808 .33996 Mdot
.57691 .42522 Mdot
.30214 .54606 Mdot
.61472 .35706 Mdot
.43484 .69752 Mdot
.60601 .60067 Mdot
.46005 .30984 Mdot
.4942 .5511 Mdot
.303 .53966 Mdot
.71077 .24673 Mdot
.78535 .47922 Mdot
.68514 .49203 Mdot
.62182 .43702 Mdot
.59206 .7017 Mdot
.66715 .40058 Mdot
.40758 .45155 Mdot
.27819 .51961 Mdot
.34234 .59171 Mdot
.4719 .32505 Mdot
.60938 .49991 Mdot
.66129 .66782 Mdot
.59934 .18742 Mdot
.68891 .55208 Mdot
.4842 .31436 Mdot
.46967 .32086 Mdot
.39035 .71752 Mdot
.43367 .70271 Mdot
.62537 .42944 Mdot
.28042 .50728 Mdot
.48909 .3629 Mdot
.31886 .51523 Mdot
.4017 .69305 Mdot
.43403 .69094 Mdot
.40349 .43612 Mdot
.59399 .52142 Mdot
.3951 .69432 Mdot
.23244 .50016 Mdot
.46479 .5051 Mdot
.44816 .28919 Mdot
.19417 .54024 Mdot
.73853 .2818 Mdot
.65442 .38522 Mdot
.60301 .7139 Mdot
.51466 .44197 Mdot
.27326 .54155 Mdot
.67222 .47417 Mdot
.63056 .45163 Mdot
.3944 .44313 Mdot
.27741 .54501 Mdot
.59633 .68858 Mdot
.29359 .54439 Mdot
.60616 .68913 Mdot
.4008 .66522 Mdot
.64299 .4675 Mdot
.59719 .44115 Mdot
.29378 .5325 Mdot
.4035 .72219 Mdot
.4369 .68264 Mdot
.61285 .69565 Mdot
.6748 .59683 Mdot
.40701 .68669 Mdot
.46037 .30925 Mdot
.63102 .23324 Mdot
.4043 .44449 Mdot
.62251 .46083 Mdot
.6492 .63723 Mdot
.59299 .32257 Mdot
.64952 .4466 Mdot
.39478 .46097 Mdot
.35743 .83431 Mdot
.64413 .4647 Mdot
.52981 .85891 Mdot
.38942 .44049 Mdot
.44678 .31322 Mdot
.41177 .71603 Mdot
.39638 .4631 Mdot
.5424 .51658 Mdot
.3672 .73478 Mdot
.6465 .53502 Mdot
.49969 .33593 Mdot
.46996 .29629 Mdot
.44065 .59261 Mdot
.26889 .42671 Mdot
.58185 .71355 Mdot
.58646 .68619 Mdot
.41736 .67863 Mdot
.22302 .5203 Mdot
.59297 .41659 Mdot
.58841 .68769 Mdot
.34439 .55859 Mdot
.67417 .47107 Mdot
.4492 .60832 Mdot
.41802 .56816 Mdot
.44945 .34007 Mdot
.56753 .51487 Mdot
.41863 .68182 Mdot
.48583 .32805 Mdot
.43309 .57585 Mdot
.68068 .4643 Mdot
.47504 .32566 Mdot
.32202 .52211 Mdot
.41561 .52069 Mdot
.45409 .3145 Mdot
.49658 .53942 Mdot
.28887 .5287 Mdot
.44797 .61238 Mdot
.74317 .60398 Mdot
.47707 .13451 Mdot
.27798 .51407 Mdot
.41457 .71836 Mdot
.39682 .68138 Mdot
.41024 .6879 Mdot
.4939 .32123 Mdot
.41781 .6999 Mdot
.49031 .35142 Mdot
.27524 .55656 Mdot
.66101 .6073 Mdot
.5851 .70091 Mdot
.58655 .75653 Mdot
.46043 .32441 Mdot
.25438 .45231 Mdot
.17353 .55374 Mdot
.64971 .43641 Mdot
.31898 .49104 Mdot
.6175 .68399 Mdot
.48595 .46356 Mdot
.59419 .69934 Mdot
.41122 .71781 Mdot
.60905 .59875 Mdot
.60921 .47047 Mdot
.43604 .24831 Mdot
.59958 .71484 Mdot
.48742 .31547 Mdot
.64578 .50076 Mdot
.36623 .71003 Mdot
.57002 .70003 Mdot
.60814 .70685 Mdot
.62781 .47025 Mdot
.46545 .29909 Mdot
.43159 .70092 Mdot
.26897 .53728 Mdot
.55161 .71611 Mdot
.69717 .43732 Mdot
.63314 .43563 Mdot
.605 .51178 Mdot
.49041 .50704 Mdot
.21807 .55802 Mdot
.28846 .52545 Mdot
.68756 .69386 Mdot
.40331 .67182 Mdot
.6744 .67221 Mdot
.35513 .40183 Mdot
.56728 .66122 Mdot
.38005 .45075 Mdot
.3784 .45306 Mdot
.62044 .48019 Mdot
.17077 .4686 Mdot
.71807 .53463 Mdot
.26098 .50308 Mdot
.40043 .44541 Mdot
.43818 .68617 Mdot
.47989 .28472 Mdot
.54263 .45546 Mdot
.63393 .41744 Mdot
.27399 .54485 Mdot
.40564 .6942 Mdot
.17332 .42735 Mdot
.57771 .69459 Mdot
.48233 .46493 Mdot
.59929 .46573 Mdot
.62007 .47297 Mdot
.29692 .51662 Mdot
.27849 .50569 Mdot
.4293 .44606 Mdot
.50531 .58478 Mdot
.37861 .26019 Mdot
.31392 .54529 Mdot
.17268 .4272 Mdot
.45118 .23566 Mdot
.46205 .33996 Mdot
.41315 .44423 Mdot
.32359 .52784 Mdot
.63568 .46434 Mdot
.44543 .3162 Mdot
.69659 .55386 Mdot
.51997 .31523 Mdot
.45124 .60729 Mdot
.45263 .53564 Mdot
.59781 .45817 Mdot
.47581 .37235 Mdot
.48317 .32645 Mdot
.47127 .37411 Mdot
.40297 .45316 Mdot
.61261 .45256 Mdot
.6447 .43634 Mdot
.64498 .46348 Mdot
.71973 .43918 Mdot
.62179 .48427 Mdot
.35242 .39909 Mdot
.46251 .49106 Mdot
.49599 .75655 Mdot
.63912 .48431 Mdot
.3239 .50961 Mdot
.64175 .4686 Mdot
.60369 .67326 Mdot
.59604 .49048 Mdot
.45293 .60748 Mdot
.28409 .51789 Mdot
.55346 .35424 Mdot
.36677 .65678 Mdot
.60411 .43467 Mdot
.57354 .71468 Mdot
.20071 .53868 Mdot
.67501 .68948 Mdot
.41377 .47045 Mdot
.45907 .31139 Mdot
.44319 .6994 Mdot
.31385 .48258 Mdot
.43126 .69197 Mdot
.68601 .47128 Mdot
.41197 .43666 Mdot
.83299 .42272 Mdot
.49955 .55998 Mdot
.63671 .46586 Mdot
.59494 .52109 Mdot
.44783 .33176 Mdot
.42014 .68872 Mdot
.44445 .38662 Mdot
.67607 .46886 Mdot
.56926 .68387 Mdot
.60061 .66852 Mdot
.40052 .61092 Mdot
.3936 .52319 Mdot
.75414 .42595 Mdot
.29481 .51777 Mdot
.39399 .67844 Mdot
.59433 .66566 Mdot
.46039 .26062 Mdot
.32814 .50443 Mdot
.29213 .4836 Mdot
.31467 .51821 Mdot
.61806 .49118 Mdot
.40567 .43826 Mdot
.36885 .55942 Mdot
.38957 .46412 Mdot
.67141 .45234 Mdot
.37371 .68352 Mdot
.38807 .46536 Mdot
.58836 .70774 Mdot
.3133 .4929 Mdot
.43098 .67384 Mdot
.63015 .47938 Mdot
.47463 .33416 Mdot
.68173 .73462 Mdot
.22809 .67134 Mdot
.45 .61492 Mdot
.44998 .61502 Mdot
.46106 .29521 Mdot
.40055 .27972 Mdot
.33581 .52053 Mdot
.55875 .30396 Mdot
.58775 .63132 Mdot
.67352 .51813 Mdot
.44732 .8191 Mdot
.38055 .68411 Mdot
.40035 .70748 Mdot
.60776 .47803 Mdot
.41152 .72731 Mdot
.605 .49139 Mdot
.38317 .70852 Mdot
.31437 .39814 Mdot
.64317 .42037 Mdot
.40509 .70649 Mdot
.63072 .39676 Mdot
.63927 .49973 Mdot
.44749 .32018 Mdot
.41177 .73361 Mdot
.68475 .49228 Mdot
.84616 .47935 Mdot
.30543 .51788 Mdot
.40357 .45216 Mdot
.46115 .61605 Mdot
.2923 .54209 Mdot
.49446 .35083 Mdot
.61121 .50604 Mdot
.57429 .69592 Mdot
.46082 .33364 Mdot
.36152 .69935 Mdot
.59615 .71464 Mdot
.46304 .43428 Mdot
.45927 .3392 Mdot
.40163 .44112 Mdot
.59223 .67595 Mdot
.64698 .53459 Mdot
.40052 .70526 Mdot
.21865 .64242 Mdot
.3975 .46187 Mdot
.60949 .46585 Mdot
.37035 .67755 Mdot
.2941 .54407 Mdot
.61317 .4331 Mdot
.39325 .68226 Mdot
.40123 .45751 Mdot
.63745 .49647 Mdot
.62472 .50711 Mdot
.55286 .38547 Mdot
.53117 .63653 Mdot
.58563 .70401 Mdot
.4351 .32188 Mdot
.66228 .44334 Mdot
.61321 .68325 Mdot
.24492 .63734 Mdot
.66446 .43536 Mdot
.50231 .31745 Mdot
.57896 .35469 Mdot
.42166 .71891 Mdot
.27658 .53354 Mdot
.39003 .72953 Mdot
.5865 .7201 Mdot
.19084 .67345 Mdot
.41133 .44552 Mdot
.61522 .52391 Mdot
.66647 .51032 Mdot
.43124 .65743 Mdot
.48195 .32396 Mdot
.38558 .25795 Mdot
.5971 .49021 Mdot
.59509 .52911 Mdot
.62561 .46471 Mdot
.24371 .64852 Mdot
.4948 .32584 Mdot
.62452 .46189 Mdot
.70511 .44645 Mdot
.67843 .49087 Mdot
.56678 .70666 Mdot
.76195 .55516 Mdot
.64941 .45295 Mdot
.67232 .85489 Mdot
.39534 .43468 Mdot
.40731 .69948 Mdot
.49502 .5315 Mdot
.47183 .64292 Mdot
.69798 .75322 Mdot
.49535 .34367 Mdot
.43672 .26271 Mdot
.43225 .69513 Mdot
.66335 .75643 Mdot
.40104 .29472 Mdot
.63372 .50676 Mdot
.59871 .48222 Mdot
.41133 .71778 Mdot
.42848 .7156 Mdot
.40846 .43385 Mdot
.59777 .43034 Mdot
.57501 .51165 Mdot
.37655 .71317 Mdot
.63072 .48624 Mdot
.59626 .30098 Mdot
.27779 .49136 Mdot
.45737 .34044 Mdot
.29611 .53405 Mdot
.28124 .49078 Mdot
.60844 .37903 Mdot
.48459 .48148 Mdot
.29642 .49505 Mdot
.26228 .50777 Mdot
.55762 .74086 Mdot
.72042 .40695 Mdot
.56593 .70386 Mdot
.40446 .48862 Mdot
.41205 .68028 Mdot
.61447 .45061 Mdot
.49386 .31855 Mdot
.80282 .60916 Mdot
.33306 .28748 Mdot
.62166 .58598 Mdot
.65552 .44077 Mdot
.41639 .68514 Mdot
.39821 .46072 Mdot
.655 .42696 Mdot
.6774 .67003 Mdot
.61603 .47576 Mdot
.43379 .70529 Mdot
.7159 .39851 Mdot
.31224 .46248 Mdot
.31654 .5442 Mdot
.4957 .29272 Mdot
.64237 .46451 Mdot
.48368 .3461 Mdot
.29224 .4927 Mdot
.61545 .69806 Mdot
.59042 .69435 Mdot
.59987 .43884 Mdot
.45608 .58856 Mdot
.53715 .68937 Mdot
.63588 .50515 Mdot
.65761 .47942 Mdot
.38121 .44994 Mdot
.65728 .47841 Mdot
.62475 .42506 Mdot
.66663 .46523 Mdot
.62539 .41979 Mdot
.32833 .51424 Mdot
.48266 .39812 Mdot
.58993 .44374 Mdot
.65967 .51864 Mdot
.26495 .51947 Mdot
.69337 .46653 Mdot
.28976 .50444 Mdot
.3529 .27973 Mdot
.30057 .49723 Mdot
.58923 .69537 Mdot
.36655 .6884 Mdot
.42495 .28063 Mdot
.48829 .36307 Mdot
.32562 .51257 Mdot
.59597 .6796 Mdot
.27883 .51532 Mdot
.39019 .67856 Mdot
.20414 .57137 Mdot
.43614 .35777 Mdot
.45296 .49942 Mdot
.72676 .41441 Mdot
.39536 .42923 Mdot
.40427 .72621 Mdot
.46728 .35676 Mdot
.29149 .4653 Mdot
.67113 .47914 Mdot
.57545 .70249 Mdot
.62058 .47934 Mdot
.31483 .49264 Mdot
.41421 .68355 Mdot
.36716 .48305 Mdot
.58658 .70406 Mdot
.20133 .66881 Mdot
.37536 .69815 Mdot
.63657 .5234 Mdot
.26532 .51929 Mdot
.20936 .56548 Mdot
.29321 .49996 Mdot
.66237 .60753 Mdot
.52897 .31006 Mdot
.78573 .63828 Mdot
.46512 .32281 Mdot
.41946 .43208 Mdot
.48068 .17618 Mdot
.38513 .37058 Mdot
.47031 .3407 Mdot
.36972 .65138 Mdot
.62242 .48823 Mdot
.65705 .44778 Mdot
.58563 .50465 Mdot
.5205 .35865 Mdot
.65258 .43464 Mdot
.40827 .44724 Mdot
.48099 .48835 Mdot
.31315 .58139 Mdot
.44092 .70688 Mdot
.60332 .48607 Mdot
.27585 .5015 Mdot
.32506 .50278 Mdot
.3827 .46525 Mdot
.30786 .53099 Mdot
.64601 .48781 Mdot
.46146 .32426 Mdot
.42741 .57046 Mdot
.57356 .70785 Mdot
.33761 .41581 Mdot
.56772 .64152 Mdot
.5468 .69891 Mdot
.67958 .49085 Mdot
.43417 .69227 Mdot
.39621 .80613 Mdot
.66971 .46291 Mdot
.48156 .33058 Mdot
.66262 .51273 Mdot
.66161 .45953 Mdot
.64567 .45266 Mdot
.3952 .6777 Mdot
.48907 .53044 Mdot
.63216 .48582 Mdot
.29713 .49416 Mdot
.43761 .54407 Mdot
.62495 .41488 Mdot
.34872 .59543 Mdot
.45243 .60645 Mdot
.39253 .43086 Mdot
.45069 .2864 Mdot
.42604 .70549 Mdot
.46988 .32443 Mdot
.50915 .36591 Mdot
.49398 .35165 Mdot
.35226 .57205 Mdot
.56649 .32096 Mdot
.5569 .85706 Mdot
.72728 .33166 Mdot
.72459 .40145 Mdot
.50973 .32006 Mdot
.29083 .63383 Mdot
.47398 .34319 Mdot
.49467 .34863 Mdot
.44411 .88613 Mdot
.49465 .31231 Mdot
.62328 .45465 Mdot
.59104 .484 Mdot
.45366 .22369 Mdot
.56705 .74377 Mdot
.62517 .50247 Mdot
.64349 .4313 Mdot
.59733 .66661 Mdot
.54023 .39102 Mdot
.41233 .4329 Mdot
.47817 .46304 Mdot
.41558 .45014 Mdot
.62774 .47125 Mdot
.59931 .44951 Mdot
.59216 .42667 Mdot
.52198 .15632 Mdot
.77907 .65948 Mdot
.45648 .29934 Mdot
.69587 .49466 Mdot
.36481 .45723 Mdot
.64945 .51652 Mdot
.66988 .50557 Mdot
.64734 .46409 Mdot
.43152 .69826 Mdot
.47507 .2845 Mdot
.64672 .54151 Mdot
.37008 .42012 Mdot
.5986 .46081 Mdot
.55652 .65488 Mdot
.61567 .71221 Mdot
.61652 .46215 Mdot
.49406 .30933 Mdot
.65574 .44377 Mdot
.50039 .35649 Mdot
.46133 .34432 Mdot
.5817 .51261 Mdot
.37581 .5492 Mdot
.48723 .28911 Mdot
.63178 .50746 Mdot
.40462 .72338 Mdot
.32963 .40754 Mdot
.61075 .46487 Mdot
.59081 .71173 Mdot
.63312 .44231 Mdot
.56899 .71233 Mdot
.65525 .4693 Mdot
.38586 .46416 Mdot
.56174 .22879 Mdot
.42228 .67797 Mdot
.54827 .71271 Mdot
.41195 .72574 Mdot
.5587 .46791 Mdot
.50842 .32511 Mdot
.34869 .47145 Mdot
.76013 .69032 Mdot
.38215 .44856 Mdot
.69236 .70592 Mdot
.42806 .53905 Mdot
.2688 .51994 Mdot
.46088 .36499 Mdot
.69643 .39117 Mdot
.36455 .5945 Mdot
.4471 .68692 Mdot
.41482 .65763 Mdot
.44313 .79017 Mdot
.36469 .82731 Mdot
.63239 .48929 Mdot
.25452 .57939 Mdot
.59859 .26811 Mdot
.69298 .41711 Mdot
.65165 .41134 Mdot
.37174 .6929 Mdot
.62586 .5027 Mdot
.53535 .56514 Mdot
.40117 .68268 Mdot
.58434 .68298 Mdot
.48237 .35337 Mdot
.60885 .682 Mdot
.30543 .28809 Mdot
.40592 .47361 Mdot
.39723 .68963 Mdot
.62245 .41842 Mdot
.61498 .49734 Mdot
.45118 .35419 Mdot
.71348 .27619 Mdot
.45812 .34412 Mdot
.57947 .714 Mdot
.41376 .67224 Mdot
.81099 .50308 Mdot
.63781 .44564 Mdot
.47157 .30665 Mdot
.3676 .65585 Mdot
.61694 .43958 Mdot
.27544 .5302 Mdot
.65826 .44291 Mdot
.46912 .3051 Mdot
.65739 .47768 Mdot
.46267 .32615 Mdot
.3908 .71578 Mdot
.59509 .44567 Mdot
.60051 .44367 Mdot
.6921 .69698 Mdot
.5972 .69019 Mdot
.50649 .3191 Mdot
.53738 .56518 Mdot
.67275 .44812 Mdot
.67597 .66133 Mdot
.6433 .46672 Mdot
.72586 .43212 Mdot
.67658 .43934 Mdot
.40848 .44443 Mdot
.66893 .50773 Mdot
.61098 .46634 Mdot
.73584 .31282 Mdot
.72164 .31462 Mdot
.69763 .40363 Mdot
.31261 .53797 Mdot
.47681 .30202 Mdot
.39536 .68439 Mdot
.42985 .7219 Mdot
.42085 .70142 Mdot
.61058 .73076 Mdot
.70019 .48588 Mdot
.60651 .46691 Mdot
.27176 .55995 Mdot
.58424 .68906 Mdot
.47902 .31035 Mdot
.58453 .69588 Mdot
.48749 .48057 Mdot
.59611 .71097 Mdot
.40895 .45047 Mdot
.21239 .61635 Mdot
.59744 .3151 Mdot
.60322 .70054 Mdot
.45903 .34426 Mdot
.43849 .52455 Mdot
.6663 .52476 Mdot
.25307 .42053 Mdot
.56996 .68267 Mdot
.42007 .79399 Mdot
.63912 .49214 Mdot
.50634 .53993 Mdot
.29351 .50551 Mdot
.60825 .68171 Mdot
.3134 .51915 Mdot
.65677 .44522 Mdot
.49736 .39577 Mdot
.48702 .33159 Mdot
.27419 .4961 Mdot
.67845 .48519 Mdot
.60798 .68088 Mdot
.39673 .69535 Mdot
.71802 .40304 Mdot
.26239 .52042 Mdot
.67652 .73796 Mdot
.67223 .67046 Mdot
.41076 .67233 Mdot
.73968 .40417 Mdot
.3092 .5062 Mdot
.67797 .51402 Mdot
.61424 .55994 Mdot
.66822 .45511 Mdot
.43575 .67904 Mdot
.40114 .70882 Mdot
.41168 .39385 Mdot
.59737 .45052 Mdot
.58755 .45447 Mdot
.46094 .28856 Mdot
.40796 .66977 Mdot
.49424 .3527 Mdot
.4587 .35854 Mdot
.41015 .7191 Mdot
.46336 .3544 Mdot
.60131 .71315 Mdot
.54016 .54871 Mdot
.30772 .50363 Mdot
.2735 .52626 Mdot
.39535 .69194 Mdot
.41065 .6645 Mdot
.43474 .68991 Mdot
.6764 .47902 Mdot
.47684 .36177 Mdot
.66197 .49893 Mdot
.64216 .45998 Mdot
.48118 .26721 Mdot
.44944 .29491 Mdot
.66762 .50149 Mdot
.41305 .56758 Mdot
.56148 .69906 Mdot
.40785 .70514 Mdot
.3201 .51833 Mdot
.69121 .73359 Mdot
.26683 .52217 Mdot
.66819 .44407 Mdot
.27481 .405 Mdot
.49286 .32049 Mdot
.59343 .70058 Mdot
.45215 .61277 Mdot
.58914 .70354 Mdot
.27715 .49249 Mdot
.4415 .30636 Mdot
.46263 .44424 Mdot
.59655 .45016 Mdot
.48936 .50353 Mdot
.72035 .63861 Mdot
.36055 .40467 Mdot
.32258 .51494 Mdot
.65081 .43641 Mdot
.38661 .44318 Mdot
.55205 .28963 Mdot
.60654 .47055 Mdot
.68395 .46698 Mdot
.48137 .67456 Mdot
.67144 .50703 Mdot
.43893 .31972 Mdot
.44854 .59707 Mdot
.60815 .42433 Mdot
.55981 .46621 Mdot
.406 .84712 Mdot
.63468 .49924 Mdot
.6003 .44144 Mdot
.62451 .44881 Mdot
.67309 .47785 Mdot
.50227 .35638 Mdot
.46673 .7157 Mdot
.28201 .49562 Mdot
.54083 .54959 Mdot
.31405 .51189 Mdot
.39261 .7029 Mdot
.52481 .57386 Mdot
.50048 .35761 Mdot
.58931 .70412 Mdot
.24577 .57915 Mdot
.6039 .59532 Mdot
.39249 .71936 Mdot
.71769 .70415 Mdot
.56631 .69216 Mdot
.66744 .52417 Mdot
.59359 .72114 Mdot
.37168 .68519 Mdot
.27496 .52237 Mdot
.61089 .51489 Mdot
.50047 .3416 Mdot
.45438 .31472 Mdot
.66078 .44358 Mdot
.33348 .42177 Mdot
.28701 .54355 Mdot
.64021 .67945 Mdot
.61398 .48931 Mdot
.68215 .46133 Mdot
.45854 .34748 Mdot
.41887 .68863 Mdot
.42979 .53993 Mdot
.59888 .68488 Mdot
.62125 .51672 Mdot
.65079 .44173 Mdot
.48788 .48328 Mdot
.3269 .51211 Mdot
.39484 .45154 Mdot
.60262 .47502 Mdot
.47777 .47429 Mdot
.6517 .43298 Mdot
.58096 .42921 Mdot
.41411 .7218 Mdot
.58941 .52364 Mdot
.59422 .46785 Mdot
.4906 .3937 Mdot
.31041 .51005 Mdot
.47915 .32658 Mdot
.46851 .26443 Mdot
.3818 .46075 Mdot
.30321 .52195 Mdot
.67055 .4981 Mdot
.29746 .48095 Mdot
.65916 .45355 Mdot
.63107 .48204 Mdot
.3229 .51685 Mdot
.48766 .35856 Mdot
.3804 .27785 Mdot
.48312 .39817 Mdot
.66673 .48073 Mdot
.62962 .44087 Mdot
.56537 .74259 Mdot
.8104 .61713 Mdot
.59334 .46381 Mdot
.47127 .36026 Mdot
.61651 .43861 Mdot
.27095 .51629 Mdot
.58363 .71495 Mdot
.47818 .33496 Mdot
.39731 .67076 Mdot
.3882 .7116 Mdot
.40632 .64052 Mdot
.41069 .44798 Mdot
.59639 .43345 Mdot
.43519 .31813 Mdot
.45193 .2952 Mdot
.52326 .52501 Mdot
.40691 .70065 Mdot
.588 .71631 Mdot
.62462 .50465 Mdot
.59825 .38751 Mdot
.28689 .48813 Mdot
.69506 .83559 Mdot
.46319 .45006 Mdot
.59496 .73038 Mdot
.50312 .5952 Mdot
.38511 .44724 Mdot
.62873 .49781 Mdot
.60612 .67567 Mdot
.3949 .71264 Mdot
.65639 .44646 Mdot
.69463 .44136 Mdot
.36444 .60007 Mdot
.41415 .66219 Mdot
.28658 .48533 Mdot
.38136 .69486 Mdot
.56614 .70897 Mdot
.40835 .45058 Mdot
.45483 .30861 Mdot
.61455 .46906 Mdot
.57408 .51605 Mdot
.41208 .69043 Mdot
.37458 .45508 Mdot
.60914 .43074 Mdot
.46778 .30133 Mdot
.41407 .70251 Mdot
.63084 .46702 Mdot
.55449 .29903 Mdot
.42667 .27903 Mdot
.41065 .67681 Mdot
.6217 .51507 Mdot
.54923 .43816 Mdot
.41355 .66046 Mdot
.37705 .67348 Mdot
.64708 .43229 Mdot
.6044 .6794 Mdot
.59567 .46522 Mdot
.28572 .50295 Mdot
.48804 .53052 Mdot
.29599 .53012 Mdot
.67997 .67022 Mdot
.59685 .42017 Mdot
.69164 .55458 Mdot
.47966 .37133 Mdot
.55691 .6825 Mdot
.77705 .35397 Mdot
.67366 .44702 Mdot
.39473 .22203 Mdot
.49229 .54895 Mdot
.45645 .47493 Mdot
.35607 .23169 Mdot
.60433 .69092 Mdot
.28051 .51429 Mdot
.60828 .43264 Mdot
.22962 .53818 Mdot
.60765 .69346 Mdot
.6804 .66933 Mdot
.64499 .51291 Mdot
.48723 .31836 Mdot
.61548 .48797 Mdot
.46729 .30365 Mdot
.61853 .44259 Mdot
.5465 .34875 Mdot
.54834 .66259 Mdot
.66345 .60622 Mdot
.65967 .53054 Mdot
.2096 .55539 Mdot
.7266 .41242 Mdot
.58408 .71227 Mdot
.66391 .47836 Mdot
.38816 .45144 Mdot
.29466 .54454 Mdot
.2474 .59694 Mdot
.43302 .69307 Mdot
.30172 .49539 Mdot
.4686 .35268 Mdot
.36895 .7033 Mdot
.37595 .4544 Mdot
.65747 .54346 Mdot
.60637 .67852 Mdot
.30497 .51836 Mdot
.6131 .46523 Mdot
.67484 .4605 Mdot
.24284 .64859 Mdot
.81268 .48206 Mdot
.46518 .35954 Mdot
.26855 .75265 Mdot
.43564 .32659 Mdot
.59182 .68603 Mdot
.41879 .71918 Mdot
.63594 .45994 Mdot
.60159 .46304 Mdot
.41851 .66505 Mdot
.44476 .33571 Mdot
.55916 .67449 Mdot
.79144 .63279 Mdot
.27067 .48369 Mdot
.72823 .57789 Mdot
.47947 .33743 Mdot
.72454 .58027 Mdot
.62648 .67902 Mdot
.35803 .51909 Mdot
.78001 .49491 Mdot
.2827 .53516 Mdot
.73228 .57558 Mdot
.4825 .31015 Mdot
.63186 .49154 Mdot
.40012 .44154 Mdot
.39638 .43565 Mdot
.47974 .34961 Mdot
.4164 .71553 Mdot
.57836 .68055 Mdot
.6132 .48531 Mdot
.66053 .55064 Mdot
.70332 .26183 Mdot
.40655 .66636 Mdot
.59399 .51921 Mdot
.29771 .54064 Mdot
.62148 .43894 Mdot
.60394 .66811 Mdot
.27981 .52576 Mdot
.39603 .46471 Mdot
.59807 .59295 Mdot
.61169 .5066 Mdot
.45563 .59716 Mdot
.29861 .5096 Mdot
.81286 .61008 Mdot
.60076 .44413 Mdot
.3094 .50661 Mdot
.57422 .51486 Mdot
.34309 .45584 Mdot
.43193 .56114 Mdot
.38384 .36662 Mdot
.42374 .73338 Mdot
.38257 .70528 Mdot
.84246 .49065 Mdot
.59188 .62957 Mdot
.30596 .49375 Mdot
.40547 .45625 Mdot
.77565 .5362 Mdot
.31039 .5218 Mdot
.61409 .51401 Mdot
.64299 .47174 Mdot
.71574 .39816 Mdot
.6109 .3896 Mdot
.40731 .43252 Mdot
.70035 .51195 Mdot
.64983 .48842 Mdot
.62799 .54208 Mdot
.62071 .43195 Mdot
.46745 .29672 Mdot
.28709 .53797 Mdot
.28774 .21998 Mdot
.30896 .4823 Mdot
.64477 .56734 Mdot
.4123 .68047 Mdot
.40904 .73727 Mdot
.61739 .46287 Mdot
.70899 .55071 Mdot
.1623 .44861 Mdot
.64201 .44806 Mdot
.45232 .61217 Mdot
.6729 .67288 Mdot
.68445 .50702 Mdot
.50123 .30702 Mdot
.57825 .51581 Mdot
.44082 .35957 Mdot
.27895 .52625 Mdot
.60538 .69227 Mdot
.56484 .68361 Mdot
.28409 .5092 Mdot
.60369 .45956 Mdot
.5733 .67329 Mdot
.6215 .47025 Mdot
.62012 .49791 Mdot
.48322 .47006 Mdot
.61823 .69455 Mdot
.43539 .69137 Mdot
.59035 .69681 Mdot
.49645 .33882 Mdot
.45079 .89823 Mdot
.57924 .70044 Mdot
.72026 .40648 Mdot
.51755 .55434 Mdot
.73265 .5787 Mdot
.45202 .31921 Mdot
.57562 .7116 Mdot
.28108 .53605 Mdot
.4562 .43299 Mdot
.73179 .40068 Mdot
.26708 .52135 Mdot
.60439 .47124 Mdot
.49724 .36157 Mdot
.45749 .29592 Mdot
.31981 .5399 Mdot
.44631 .32855 Mdot
.63135 .53282 Mdot
.62787 .50981 Mdot
.29617 .4921 Mdot
.59389 .18249 Mdot
.27579 .53392 Mdot
.62121 .37934 Mdot
.64872 .46747 Mdot
.47983 .3325 Mdot
.72704 .43524 Mdot
.48936 .27759 Mdot
.40562 .43599 Mdot
.59392 .48587 Mdot
.57908 .70702 Mdot
.53286 .54703 Mdot
.41256 .67654 Mdot
.27917 .40118 Mdot
.45913 .31085 Mdot
.33273 .51424 Mdot
.44806 .31916 Mdot
.45169 .35069 Mdot
.27032 .50306 Mdot
.49153 .32944 Mdot
.59905 .46051 Mdot
.25196 .33201 Mdot
.45705 .31737 Mdot
.29319 .51514 Mdot
.57248 .70142 Mdot
.46557 .35561 Mdot
.63857 .71731 Mdot
.6141 .4999 Mdot
.38776 .72229 Mdot
.56079 .72537 Mdot
.47838 .37416 Mdot
.58619 .7142 Mdot
.41106 .69557 Mdot
.58155 .67754 Mdot
.24214 .54368 Mdot
.3326 .53099 Mdot
.62904 .58442 Mdot
.33072 .46115 Mdot
.49772 .32404 Mdot
.41215 .74176 Mdot
.60557 .50066 Mdot
.6155 .49255 Mdot
.56039 .70558 Mdot
.46532 .29504 Mdot
.32391 .42805 Mdot
.73239 .50329 Mdot
.33875 .41663 Mdot
.32306 .52668 Mdot
.64372 .74512 Mdot
.46161 .44753 Mdot
.24299 .49908 Mdot
.58493 .48077 Mdot
.38643 .44618 Mdot
.62581 .46378 Mdot
.67443 .68895 Mdot
.56487 .70024 Mdot
.2735 .67837 Mdot
.59237 .41731 Mdot
.42256 .66957 Mdot
.62501 .44389 Mdot
.28196 .58884 Mdot
.56279 .45465 Mdot
.56728 .68491 Mdot
.30198 .47696 Mdot
.48826 .36312 Mdot
.56922 .70322 Mdot
.39034 .71425 Mdot
.74148 .54403 Mdot
.61252 .5121 Mdot
.64615 .49094 Mdot
.4059 .65661 Mdot
.49712 .34782 Mdot
.39561 .70501 Mdot
.30828 .5042 Mdot
.58171 .69923 Mdot
.67158 .48593 Mdot
.60655 .5318 Mdot
.42777 .65541 Mdot
.30904 .48676 Mdot
.42953 .66666 Mdot
.29777 .48157 Mdot
.38991 .44319 Mdot
.61102 .42036 Mdot
.40487 .65413 Mdot
.58465 .44496 Mdot
.69716 .29823 Mdot
.55676 .55907 Mdot
.76173 .36897 Mdot
.43577 .6926 Mdot
.53866 .6644 Mdot
.28507 .51403 Mdot
.30737 .51537 Mdot
.62409 .37577 Mdot
.16898 .46753 Mdot
.43571 .53953 Mdot
.19321 .57713 Mdot
.30747 .50311 Mdot
.30115 .51442 Mdot
.40354 .71393 Mdot
.49304 .34638 Mdot
.50439 .37036 Mdot
.37359 .67192 Mdot
.64978 .63631 Mdot
.47883 .31007 Mdot
.41794 .21539 Mdot
.38417 .67498 Mdot
.59162 .4941 Mdot
.39783 .47328 Mdot
.56828 .68404 Mdot
.66315 .66708 Mdot
.20622 .57775 Mdot
.63099 .45751 Mdot
.50972 .85698 Mdot
.42894 .69944 Mdot
.41442 .48114 Mdot
.31665 .56597 Mdot
.67934 .46411 Mdot
.62189 .44608 Mdot
.60424 .44795 Mdot
.57924 .72988 Mdot
.69559 .27266 Mdot
.6334 .45963 Mdot
.63644 .60951 Mdot
.64468 .42091 Mdot
.22894 .64735 Mdot
.59005 .69672 Mdot
.75844 .64669 Mdot
.38526 .73537 Mdot
.35684 .42719 Mdot
.68102 .48511 Mdot
.30141 .50097 Mdot
.38253 .58488 Mdot
.3216 .50617 Mdot
.34184 .54899 Mdot
.7857 .51146 Mdot
.47339 .29576 Mdot
.65996 .44408 Mdot
.38426 .67166 Mdot
.49008 .36852 Mdot
.39489 .57814 Mdot
.42582 .88478 Mdot
.32486 .53023 Mdot
.26109 .77239 Mdot
.30209 .52881 Mdot
.39842 .43446 Mdot
.46806 .3505 Mdot
.73015 .5369 Mdot
.4885 .49733 Mdot
.49313 .35391 Mdot
.51392 .78803 Mdot
.47029 .38038 Mdot
.71217 .57478 Mdot
.43337 .35646 Mdot
.28752 .51892 Mdot
.33416 .51558 Mdot
.687 .43822 Mdot
.5958 .47953 Mdot
.48589 .50714 Mdot
.64687 .40623 Mdot
.61039 .50438 Mdot
.40121 .68233 Mdot
.30376 .45928 Mdot
.22791 .53887 Mdot
.48224 .34145 Mdot
.29624 .48699 Mdot
.6244 .44507 Mdot
.66641 .48106 Mdot
.65079 .52165 Mdot
.66876 .75454 Mdot
.41598 .2144 Mdot
.63313 .48298 Mdot
.56309 .46071 Mdot
.39767 .72156 Mdot
.24312 .65049 Mdot
.28401 .7552 Mdot
.78079 .52196 Mdot
.61256 .42884 Mdot
.5954 .69119 Mdot
.60019 .66603 Mdot
.64377 .52836 Mdot
.67848 .56701 Mdot
.62502 .74886 Mdot
.6129 .46502 Mdot
.69606 .57506 Mdot
.44435 .67263 Mdot
.37656 .46021 Mdot
.41168 .69091 Mdot
.48497 .37259 Mdot
.38288 .44631 Mdot
.38948 .68949 Mdot
.62234 .60896 Mdot
.38605 .46144 Mdot
.34464 .45295 Mdot
.57754 .7132 Mdot
.61255 .43347 Mdot
.42438 .36582 Mdot
.4048 .66873 Mdot
.30301 .5115 Mdot
.46576 .3337 Mdot
.29761 .54503 Mdot
.21722 .63432 Mdot
.65456 .64403 Mdot
.41096 .44408 Mdot
.29902 .4996 Mdot
.4534 .57992 Mdot
.59365 .69143 Mdot
.30532 .53083 Mdot
.69867 .55159 Mdot
.61379 .41317 Mdot
.19466 .36363 Mdot
.64759 .4947 Mdot
.40845 .37908 Mdot
.30401 .50765 Mdot
.39746 .46571 Mdot
.61487 .47097 Mdot
.37608 .70126 Mdot
.68312 .51531 Mdot
.62241 .47176 Mdot
.38536 .68066 Mdot
.63371 .48678 Mdot
.61509 .68208 Mdot
.44469 .3622 Mdot
.50202 .55483 Mdot
.66326 .73352 Mdot
.57217 .68641 Mdot
.51473 .49912 Mdot
.59282 .46643 Mdot
.47982 .76662 Mdot
.48631 .31961 Mdot
.6728 .44711 Mdot
.69551 .67516 Mdot
.48792 .34782 Mdot
.46936 .32335 Mdot
.65882 .4835 Mdot
.27325 .53309 Mdot
.43298 .67559 Mdot
.59305 .69337 Mdot
.22506 .51911 Mdot
.63257 .46643 Mdot
.65048 .43553 Mdot
.56621 .69474 Mdot
.30244 .52006 Mdot
.67065 .49112 Mdot
.32919 .35856 Mdot
.53461 .53673 Mdot
.28737 .48634 Mdot
.6234 .41467 Mdot
.30019 .24508 Mdot
.49735 .37678 Mdot
.52091 .85828 Mdot
.55596 .65108 Mdot
.41317 .71984 Mdot
.58448 .50659 Mdot
.63425 .87942 Mdot
.57702 .71115 Mdot
.35672 .41683 Mdot
.62846 .49098 Mdot
.63831 .45719 Mdot
.4814 .29949 Mdot
.6608 .50381 Mdot
.48366 .30609 Mdot
.65069 .74848 Mdot
.16526 .48335 Mdot
.44723 .32915 Mdot
.47638 .3038 Mdot
.58131 .41343 Mdot
.67248 .75858 Mdot
.47892 .35405 Mdot
.61276 .5119 Mdot
.50003 .76703 Mdot
.69542 .43688 Mdot
.61759 .70614 Mdot
.60717 .75651 Mdot
.50316 .30997 Mdot
.72273 .38487 Mdot
.58214 .41322 Mdot
.55838 .3564 Mdot
.62861 .73067 Mdot
.31188 .49982 Mdot
.65742 .4601 Mdot
.40897 .45294 Mdot
.41181 .70637 Mdot
.60201 .54121 Mdot
.60413 .44029 Mdot
.50268 .32317 Mdot
.57794 .72701 Mdot
.31085 .52471 Mdot
.63101 .42905 Mdot
.42819 .65213 Mdot
.59115 .68089 Mdot
.4556 .32605 Mdot
.68399 .38983 Mdot
.57528 .67335 Mdot
.60073 .5275 Mdot
.6357 .49098 Mdot
.62424 .42744 Mdot
.70746 .4343 Mdot
.28675 .50783 Mdot
.3692 .68661 Mdot
.5894 .51124 Mdot
.46914 .44834 Mdot
.56021 .56991 Mdot
.61873 .52153 Mdot
.46941 .35894 Mdot
.32196 .52672 Mdot
.39959 .45606 Mdot
.75222 .56537 Mdot
.64438 .48078 Mdot
.40814 .21396 Mdot
.74247 .69786 Mdot
.38847 .4592 Mdot
.50551 .35564 Mdot
.59224 .7004 Mdot
.65232 .47838 Mdot
.64398 .61177 Mdot
.62073 .51329 Mdot
.70898 .45662 Mdot
.42194 .71304 Mdot
.31739 .50799 Mdot
.58403 .56256 Mdot
.40928 .7079 Mdot
.46972 .32405 Mdot
.44931 .21942 Mdot
.49734 .37356 Mdot
.45771 .35677 Mdot
.3731 .54632 Mdot
.27601 .51319 Mdot
.6492 .8719 Mdot
.8071 .63272 Mdot
.59435 .49467 Mdot
.27775 .5033 Mdot
.47186 .34912 Mdot
.66098 .51093 Mdot
.49153 .3163 Mdot
.48375 .28833 Mdot
.61991 .50531 Mdot
.61563 .50466 Mdot
.66677 .60056 Mdot
.42402 .21775 Mdot
.57548 .70177 Mdot
.44591 .31622 Mdot
.59298 .36785 Mdot
.63638 .46381 Mdot
.59671 .45752 Mdot
.37562 .58771 Mdot
.57071 .70738 Mdot
.58053 .28853 Mdot
.6183 .49183 Mdot
.69856 .7001 Mdot
.59829 .49376 Mdot
.51468 .35621 Mdot
.28374 .55395 Mdot
.6615 .56657 Mdot
.43797 .684 Mdot
.45688 .36258 Mdot
.56384 .70953 Mdot
.46344 .27856 Mdot
.58505 .32761 Mdot
.27633 .52362 Mdot
.4698 .305 Mdot
.37273 .71513 Mdot
.29523 .52596 Mdot
.27387 .5304 Mdot
.40011 .57516 Mdot
.37745 .71901 Mdot
.58977 .72959 Mdot
.31208 .53221 Mdot
.5546 .30168 Mdot
.28803 .52172 Mdot
.58034 .32115 Mdot
.59571 .43843 Mdot
.63305 .60891 Mdot
.63602 .55985 Mdot
.68636 .43272 Mdot
.29372 .53708 Mdot
.58229 .68039 Mdot
.6751 .48579 Mdot
.44793 .33663 Mdot
.57666 .69123 Mdot
.39945 .47634 Mdot
.39943 .73843 Mdot
.46304 .29284 Mdot
.29189 .48053 Mdot
.49342 .31327 Mdot
.66945 .67065 Mdot
.55293 .67938 Mdot
.39118 .59088 Mdot
.49368 .50911 Mdot
.63544 .54166 Mdot
.56256 .44428 Mdot
.6783 .47858 Mdot
.60145 .4568 Mdot
.41026 .67756 Mdot
.6094 .73059 Mdot
.46509 .35568 Mdot
.6953 .24812 Mdot
.29678 .50196 Mdot
.45158 .5949 Mdot
.70835 .46926 Mdot
.6586 .45119 Mdot
.46962 .34432 Mdot
.47431 .28352 Mdot
.72332 .31522 Mdot
.4217 .66491 Mdot
.69049 .43025 Mdot
.67973 .49719 Mdot
.54665 .52646 Mdot
.29233 .53505 Mdot
.36251 .3351 Mdot
.43817 .71029 Mdot
.28626 .80214 Mdot
.40669 .70608 Mdot
.48769 .70554 Mdot
.4921 .33081 Mdot
.59568 .7131 Mdot
.60165 .47673 Mdot
.52911 .39649 Mdot
.50623 .34647 Mdot
.39398 .74982 Mdot
.58918 .70677 Mdot
.37914 .30085 Mdot
.28808 .49604 Mdot
.61423 .4247 Mdot
.60054 .49848 Mdot
.66283 .49274 Mdot
.65351 .51365 Mdot
.29503 .49041 Mdot
.6248 .51307 Mdot
.26237 .51606 Mdot
.59319 .32349 Mdot
.69832 .66724 Mdot
.38211 .66965 Mdot
.25341 .66353 Mdot
.45587 .35436 Mdot
.50297 .23095 Mdot
.59081 .30004 Mdot
.55593 .55831 Mdot
.24959 .54826 Mdot
.60461 .42465 Mdot
.41619 .71454 Mdot
.21604 .55854 Mdot
.38058 .67234 Mdot
.21115 .29664 Mdot
.71837 .4006 Mdot
.396 .33889 Mdot
.65378 .50419 Mdot
.39678 .65503 Mdot
.69826 .367 Mdot
.60163 .52974 Mdot
.56965 .6738 Mdot
.57072 .32793 Mdot
.42917 .38783 Mdot
.58499 .71641 Mdot
.61863 .50107 Mdot
.44827 .29511 Mdot
.60122 .46936 Mdot
.605 .48617 Mdot
.64194 .44637 Mdot
.27199 .55098 Mdot
.58871 .46158 Mdot
.59605 .46682 Mdot
.81397 .48881 Mdot
.43334 .61372 Mdot
.38528 .71461 Mdot
.75627 .35631 Mdot
.58383 .68917 Mdot
.48406 .37231 Mdot
.4924 .54647 Mdot
.288 .4997 Mdot
.72521 .31761 Mdot
.65311 .49683 Mdot
.34855 .39553 Mdot
.3286 .50128 Mdot
.60227 .68134 Mdot
.39866 .45909 Mdot
.35812 .30157 Mdot
.42992 .71149 Mdot
.41348 .43482 Mdot
.4141 .67619 Mdot
.7715 .38883 Mdot
.47874 .30368 Mdot
.63439 .54165 Mdot
.31316 .52526 Mdot
.37199 .69285 Mdot
.64157 .60938 Mdot
.61067 .43918 Mdot
.43614 .69171 Mdot
.61697 .54928 Mdot
.53812 .55604 Mdot
.48921 .5414 Mdot
.36966 .69714 Mdot
.32511 .49036 Mdot
.2918 .53057 Mdot
.58794 .7188 Mdot
.46801 .37043 Mdot
.49952 .34123 Mdot
.28688 .52759 Mdot
.40197 .82958 Mdot
.63147 .46471 Mdot
.64044 .47076 Mdot
.46536 .44342 Mdot
.66472 .50966 Mdot
.55295 .72793 Mdot
.38537 .43866 Mdot
.50228 .34108 Mdot
.67734 .48163 Mdot
.67005 .49158 Mdot
.63625 .49398 Mdot
.65668 .63777 Mdot
.41384 .69052 Mdot
.64995 .48713 Mdot
.60572 .67665 Mdot
.42909 .44748 Mdot
.60301 .49734 Mdot
.61385 .53789 Mdot
.48685 .30824 Mdot
.43359 .78646 Mdot
.30136 .50772 Mdot
.41229 .66788 Mdot
.3926 .66625 Mdot
.71712 .63161 Mdot
.5234 .32974 Mdot
.4072 .43184 Mdot
.22895 .62365 Mdot
.40458 .45467 Mdot
.59183 .70911 Mdot
.43044 .55326 Mdot
.45225 .69801 Mdot
.38266 .7073 Mdot
.329 .48482 Mdot
.66976 .45019 Mdot
.6059 .50253 Mdot
.3519 .42595 Mdot
.64289 .45334 Mdot
.57868 .70792 Mdot
.26934 .53259 Mdot
.47764 .30525 Mdot
.60274 .66873 Mdot
.30802 .51821 Mdot
.4959 .35119 Mdot
.68333 .45451 Mdot
.62068 .51801 Mdot
.4654 .32971 Mdot
.45383 .32539 Mdot
.61918 .45519 Mdot
.81313 .46596 Mdot
.50042 .34983 Mdot
.46435 .33935 Mdot
.43212 .42181 Mdot
.41445 .7237 Mdot
.68701 .40708 Mdot
.27601 .50734 Mdot
.59797 .45999 Mdot
.38648 .66447 Mdot
.60068 .7038 Mdot
.46471 .31804 Mdot
.65545 .46185 Mdot
.63137 .47451 Mdot
.59565 .69299 Mdot
.62023 .68558 Mdot
.5694 .69745 Mdot
.28712 .55119 Mdot
.63214 .5075 Mdot
.47499 .35511 Mdot
.28866 .49531 Mdot
.58175 .67085 Mdot
.59502 .72159 Mdot
.79867 .47142 Mdot
.62863 .45721 Mdot
.58663 .6653 Mdot
.49349 .91275 Mdot
.74997 .54076 Mdot
.38022 .44781 Mdot
.44418 .66352 Mdot
.53646 .67762 Mdot
.55816 .72142 Mdot
.31567 .49893 Mdot
.4502 .60582 Mdot
.57399 .72077 Mdot
.64794 .45335 Mdot
.62805 .43692 Mdot
.58289 .48136 Mdot
.57994 .68832 Mdot
.65981 .64816 Mdot
.44851 .30252 Mdot
.60086 .25019 Mdot
.58367 .68934 Mdot
.37211 .7051 Mdot
.424 .6526 Mdot
.40232 .70795 Mdot
.62187 .42171 Mdot
.75476 .33186 Mdot
.59762 .34967 Mdot
.57892 .27961 Mdot
.29508 .49573 Mdot
.47474 .284 Mdot
.36857 .48488 Mdot
.46919 .32257 Mdot
.42224 .69839 Mdot
.5892 .67996 Mdot
.48042 .2985 Mdot
.27416 .5296 Mdot
.29049 .53285 Mdot
.43594 .67321 Mdot
.40856 .69587 Mdot
.39694 .69208 Mdot
.46134 .36601 Mdot
.49194 .33005 Mdot
.66922 .48648 Mdot
.46213 .31539 Mdot
.74716 .70226 Mdot
.54213 .70589 Mdot
.43003 .66116 Mdot
.29299 .50924 Mdot
.45993 .33994 Mdot
.60964 .43418 Mdot
.48956 .6761 Mdot
.41046 .74551 Mdot
.5807 .67519 Mdot
.22299 .3963 Mdot
.15399 .48483 Mdot
.63 .41795 Mdot
.30848 .48834 Mdot
.6864 .56064 Mdot
.60647 .44922 Mdot
.42761 .70898 Mdot
.76978 .65332 Mdot
.39286 .46297 Mdot
.59954 .48132 Mdot
.68629 .47975 Mdot
.28044 .53714 Mdot
.49223 .54461 Mdot
.64776 .45073 Mdot
.43257 .57711 Mdot
.32936 .51465 Mdot
.4389 .7082 Mdot
.85555 .50541 Mdot
.41434 .47788 Mdot
.65563 .67765 Mdot
.37775 .45485 Mdot
.64545 .45599 Mdot
.40291 .68062 Mdot
.5956 .67173 Mdot
.405 .68745 Mdot
.50403 .36052 Mdot
.42216 .71854 Mdot
.62818 .43287 Mdot
.48034 .356 Mdot
.30404 .5199 Mdot
.46104 .59385 Mdot
.77522 .43025 Mdot
.37679 .70295 Mdot
.37308 .46046 Mdot
.61398 .50334 Mdot
.53567 .26877 Mdot
.68603 .43965 Mdot
.59432 .46967 Mdot
.32277 .51335 Mdot
.47588 .34443 Mdot
.32349 .52553 Mdot
.62914 .54845 Mdot
.4717 .23955 Mdot
.2933 .50221 Mdot
.48245 .4017 Mdot
.56599 .69303 Mdot
.64951 .63827 Mdot
.61147 .47647 Mdot
.31459 .52216 Mdot
.63601 .50339 Mdot
.4464 .31368 Mdot
.58778 .58964 Mdot
.52907 .51292 Mdot
.29653 .54139 Mdot
.4041 .32843 Mdot
.53989 .56675 Mdot
.65349 .39287 Mdot
.3122 .50968 Mdot
.77469 .35224 Mdot
.3902 .45296 Mdot
.59994 .68738 Mdot
.6179 .67542 Mdot
.61104 .69885 Mdot
.64184 .45585 Mdot
.5495 .33053 Mdot
.60557 .71588 Mdot
.29961 .54788 Mdot
.6149 .70007 Mdot
.68034 .73935 Mdot
.33165 .42273 Mdot
.57003 .68784 Mdot
.61562 .48006 Mdot
.60002 .54689 Mdot
.45151 .60744 Mdot
.39868 .73324 Mdot
.37427 .25761 Mdot
.81056 .49512 Mdot
.63555 .45859 Mdot
.53919 .30142 Mdot
.51314 .34355 Mdot
.52941 .64113 Mdot
.52977 .50964 Mdot
.44306 .52736 Mdot
.4615 .33882 Mdot
.49156 .52664 Mdot
.49305 .36347 Mdot
.66119 .53042 Mdot
.63042 .48275 Mdot
.47753 .37642 Mdot
.26666 .40141 Mdot
.75232 .3021 Mdot
.33742 .4108 Mdot
.48084 .36285 Mdot
.3105 .51042 Mdot
.3194 .49706 Mdot
.32223 .51381 Mdot
.39966 .67489 Mdot
.46059 .30696 Mdot
.64644 .48142 Mdot
.39584 .71746 Mdot
.60883 .4879 Mdot
.28324 .53096 Mdot
.54409 .5449 Mdot
.47936 .30535 Mdot
.61167 .4666 Mdot
.67353 .37561 Mdot
.41808 .68079 Mdot
.59329 .68934 Mdot
.2348 .37113 Mdot
.44913 .67662 Mdot
.31035 .48062 Mdot
.5026 .3012 Mdot
.38003 .65202 Mdot
.44682 .74451 Mdot
.59455 .49719 Mdot
.60342 .50732 Mdot
.45046 .61789 Mdot
.71321 .38775 Mdot
.64692 .44516 Mdot
.38922 .71299 Mdot
.4025 .72737 Mdot
.63512 .50245 Mdot
.45183 .31389 Mdot
.58959 .72592 Mdot
.55997 .70453 Mdot
.65283 .53405 Mdot
.49048 .51168 Mdot
.63462 .60901 Mdot
.67014 .4971 Mdot
.57656 .46432 Mdot
.37745 .72262 Mdot
.37623 .45464 Mdot
.48885 .48743 Mdot
.60234 .71293 Mdot
.6259 .49325 Mdot
.7063 .26703 Mdot
.46143 .30993 Mdot
.43664 .68448 Mdot
.27492 .50152 Mdot
.57419 .67288 Mdot
.43842 .67256 Mdot
.63505 .50242 Mdot
.67032 .49163 Mdot
.30845 .52993 Mdot
.51728 .34949 Mdot
.58233 .68356 Mdot
.39671 .71874 Mdot
.59439 .71415 Mdot
.49183 .32707 Mdot
.45835 .33038 Mdot
.67623 .50575 Mdot
.6834 .43017 Mdot
.37864 .68614 Mdot
.59463 .51216 Mdot
.3932 .70812 Mdot
.24246 .64868 Mdot
.28726 .48822 Mdot
.68291 .46762 Mdot
.52022 .31608 Mdot
.28464 .53072 Mdot
.63286 .45189 Mdot
.44981 .61827 Mdot
.66551 .4553 Mdot
.37576 .66974 Mdot
.79352 .62023 Mdot
.60712 .69991 Mdot
.54908 .48658 Mdot
.74883 .45744 Mdot
.66964 .50405 Mdot
.39764 .72942 Mdot
.56622 .33844 Mdot
.28793 .50412 Mdot
.49024 .33727 Mdot
.41272 .80181 Mdot
.29169 .51739 Mdot
.61905 .48619 Mdot
.57941 .6993 Mdot
.48417 .36529 Mdot
.4022 .43842 Mdot
.47492 .49636 Mdot
.59862 .54155 Mdot
.69368 .49132 Mdot
.63002 .42808 Mdot
.19302 .57529 Mdot
.39942 .68993 Mdot
.46975 .34649 Mdot
.30903 .49018 Mdot
.27749 .51671 Mdot
.41915 .68848 Mdot
.42857 .39402 Mdot
.30137 .40314 Mdot
.53313 .90971 Mdot
.43655 .66756 Mdot
.61405 .6974 Mdot
.58183 .58499 Mdot
.40393 .71018 Mdot
.40578 .67247 Mdot
.38843 .73405 Mdot
.34352 .42724 Mdot
.48011 .36188 Mdot
.63279 .47449 Mdot
.47507 .27605 Mdot
.64434 .45656 Mdot
.64345 .65961 Mdot
.28238 .52807 Mdot
.49101 .33617 Mdot
.64099 .71584 Mdot
.56141 .46346 Mdot
.6126 .44876 Mdot
.63453 .65956 Mdot
.5676 .53628 Mdot
.74035 .57275 Mdot
.64685 .52167 Mdot
.40976 .68511 Mdot
.44332 .25998 Mdot
.59556 .52163 Mdot
.66792 .37513 Mdot
.29611 .53053 Mdot
.41189 .44135 Mdot
.6442 .5423 Mdot
.57622 .44496 Mdot
.48098 .36653 Mdot
.48515 .30054 Mdot
.60365 .718 Mdot
.25109 .33844 Mdot
.2994 .52767 Mdot
.37851 .34804 Mdot
.59432 .47462 Mdot
.27029 .56452 Mdot
.78287 .64153 Mdot
.62768 .44951 Mdot
.40742 .57086 Mdot
.72399 .31671 Mdot
.65439 .44704 Mdot
.58333 .27396 Mdot
.28909 .51257 Mdot
.6956 .6856 Mdot
.63863 .51476 Mdot
.43061 .70199 Mdot
.49331 .34325 Mdot
.46214 .29297 Mdot
.59213 .67038 Mdot
.77556 .67594 Mdot
.19092 .4946 Mdot
.49268 .33393 Mdot
.60581 .44285 Mdot
.29992 .50824 Mdot
.40762 .4378 Mdot
.59415 .53374 Mdot
.25147 .5713 Mdot
.46517 .3094 Mdot
.58853 .51094 Mdot
.34352 .39448 Mdot
.49026 .53567 Mdot
.43222 .20347 Mdot
.32016 .52266 Mdot
.59992 .7155 Mdot
.68424 .41555 Mdot
.22957 .62832 Mdot
.61949 .51758 Mdot
.64808 .66552 Mdot
.52162 .36087 Mdot
.5846 .71492 Mdot
.60555 .45596 Mdot
.64944 .45018 Mdot
.50711 .5189 Mdot
.6195 .67498 Mdot
.64847 .45099 Mdot
.59148 .41779 Mdot
.49762 .3325 Mdot
.38355 .43986 Mdot
.4775 .30611 Mdot
.60234 .46749 Mdot
.79412 .59713 Mdot
.45923 .30276 Mdot
.37709 .26552 Mdot
.56797 .64299 Mdot
.28974 .49917 Mdot
.57878 .5059 Mdot
.59333 .44591 Mdot
.3765 .19984 Mdot
.4035 .43556 Mdot
.31913 .77699 Mdot
.39355 .65702 Mdot
.82336 .36442 Mdot
.44982 .68042 Mdot
.39937 .31816 Mdot
.42586 .60386 Mdot
.58184 .49001 Mdot
.62758 .38361 Mdot
.57067 .27168 Mdot
.2768 .56368 Mdot
.5142 .23896 Mdot
.59589 .47985 Mdot
.63132 .49423 Mdot
.40059 .71522 Mdot
.41802 .39531 Mdot
.66864 .56466 Mdot
.48892 .48981 Mdot
.6007 .68156 Mdot
.48093 .32395 Mdot
.62518 .43461 Mdot
.2479 .39992 Mdot
.37399 .70189 Mdot
.77222 .46127 Mdot
.6126 .46944 Mdot
.64853 .57038 Mdot
.42204 .40786 Mdot
.30534 .51685 Mdot
.36944 .69837 Mdot
.37493 .71274 Mdot
.64546 .45987 Mdot
.28851 .4927 Mdot
.67121 .47353 Mdot
.55056 .57435 Mdot
.60545 .53943 Mdot
.59558 .70785 Mdot
.59614 .45282 Mdot
.76106 .46553 Mdot
.50217 .17725 Mdot
.57983 .4229 Mdot
.4644 .36429 Mdot
.39382 .69372 Mdot
.41521 .69569 Mdot
.49927 .34401 Mdot
.41585 .69581 Mdot
.60347 .25737 Mdot
.50752 .25757 Mdot
.59098 .71059 Mdot
.6084 .31884 Mdot
.60678 .69228 Mdot
.41198 .44238 Mdot
.62598 .45567 Mdot
.32383 .62139 Mdot
.43984 .67251 Mdot
.69051 .73389 Mdot
.28583 .52446 Mdot
.40061 .43504 Mdot
.61917 .5073 Mdot
.63751 .70259 Mdot
.42167 .70542 Mdot
.41055 .51851 Mdot
.64386 .47165 Mdot
.44466 .33156 Mdot
.65663 .44977 Mdot
.64937 .41805 Mdot
.39679 .43439 Mdot
.64273 .43006 Mdot
.30808 .51802 Mdot
.46831 .30168 Mdot
.39757 .35366 Mdot
.40396 .66939 Mdot
.60504 .49407 Mdot
.60558 .44438 Mdot
.50643 .31726 Mdot
.5923 .48728 Mdot
.30147 .49395 Mdot
.73849 .79812 Mdot
.56749 .7006 Mdot
.37613 .45583 Mdot
.30536 .28812 Mdot
.64791 .43751 Mdot
.67512 .48118 Mdot
.43538 .49751 Mdot
.71051 .27189 Mdot
.30186 .50287 Mdot
.68868 .4998 Mdot
.39103 .72068 Mdot
.58155 .68285 Mdot
.29244 .54531 Mdot
.62751 .51066 Mdot
.63639 .48476 Mdot
.58267 .71291 Mdot
.63134 .65229 Mdot
.5666 .66842 Mdot
.31041 .49707 Mdot
.52044 .27946 Mdot
.49056 .67509 Mdot
.62609 .46644 Mdot
.37731 .46954 Mdot
.47307 .34072 Mdot
.31084 .50523 Mdot
.68224 .26224 Mdot
.66385 .52814 Mdot
.2863 .48499 Mdot
.30314 .52213 Mdot
.59003 .47977 Mdot
.5236 .33664 Mdot
.48063 .28133 Mdot
.4708 .34166 Mdot
.70407 .65951 Mdot
.24929 .71252 Mdot
.39658 .68821 Mdot
.29548 .51137 Mdot
.39099 .66157 Mdot
.57118 .71879 Mdot
.55224 .56487 Mdot
.37822 .71458 Mdot
.4452 .33997 Mdot
.38729 .66692 Mdot
.67197 .47173 Mdot
.27144 .5253 Mdot
.3844 .6759 Mdot
.66115 .50982 Mdot
.58407 .43349 Mdot
.60949 .38988 Mdot
.58504 .72723 Mdot
.49014 .52584 Mdot
.61348 .48407 Mdot
.397 .45906 Mdot
.61649 .459 Mdot
.29869 .49247 Mdot
.46307 .6009 Mdot
.65164 .49119 Mdot
.43933 .67109 Mdot
.28006 .7418 Mdot
.41239 .72843 Mdot
.62652 .40717 Mdot
.60468 .47218 Mdot
.62817 .46416 Mdot
.61811 .50537 Mdot
.42619 .38217 Mdot
.29252 .47888 Mdot
.70673 .45149 Mdot
.42391 .66225 Mdot
.46625 .32276 Mdot
.45629 .30233 Mdot
.43537 .52007 Mdot
.4146 .43671 Mdot
.28097 .4982 Mdot
.62965 .46485 Mdot
.41088 .52137 Mdot
.46616 .48071 Mdot
.33754 .40207 Mdot
.39444 .64224 Mdot
.38111 .7041 Mdot
.45583 .35817 Mdot
.38396 .68784 Mdot
.62442 .51126 Mdot
.58622 .50525 Mdot
.39614 .34681 Mdot
.25617 .53049 Mdot
.58488 .68177 Mdot
.60529 .48178 Mdot
.65398 .62457 Mdot
.39769 .72153 Mdot
.37701 .72082 Mdot
.67063 .47716 Mdot
.51683 .33208 Mdot
.5453 .15267 Mdot
.27407 .50767 Mdot
.53702 .27445 Mdot
.42253 .31291 Mdot
.53833 .51746 Mdot
.28257 .51027 Mdot
.41853 .5676 Mdot
.40745 .73562 Mdot
.81318 .57422 Mdot
.46359 .32731 Mdot
.58522 .68273 Mdot
.63686 .52083 Mdot
.44559 .34103 Mdot
.40912 .65362 Mdot
.49983 .35628 Mdot
.63232 .54237 Mdot
.32006 .53263 Mdot
.41164 .7035 Mdot
.33482 .50336 Mdot
.49389 .36745 Mdot
.60726 .6948 Mdot
.69096 .69664 Mdot
.55287 .29347 Mdot
.72261 .31615 Mdot
.65013 .48619 Mdot
.35423 .60358 Mdot
.64708 .47843 Mdot
.4428 .30524 Mdot
.61192 .47712 Mdot
.55898 .47683 Mdot
.41162 .73682 Mdot
.62453 .5238 Mdot
.59573 .45765 Mdot
.65188 .37232 Mdot
.62166 .44769 Mdot
.6324 .50094 Mdot
.68423 .49782 Mdot
.50451 .37553 Mdot
.63064 .52486 Mdot
.44564 .3356 Mdot
.35521 .40965 Mdot
.40882 .67109 Mdot
.57149 .71795 Mdot
.56645 .71005 Mdot
.65456 .68332 Mdot
.65359 .62884 Mdot
.42448 .3991 Mdot
.47649 .31097 Mdot
.29222 .53627 Mdot
.67179 .47733 Mdot
.78108 .36869 Mdot
.78279 .60404 Mdot
.42195 .73103 Mdot
.38087 .67661 Mdot
.62761 .5185 Mdot
.16221 .46663 Mdot
.62817 .52262 Mdot
.46302 .44754 Mdot
.64208 .45851 Mdot
.68281 .46391 Mdot
.3693 .70688 Mdot
.6687 .67105 Mdot
.64977 .48731 Mdot
.48215 .36656 Mdot
.59214 .68295 Mdot
.61002 .56062 Mdot
.76837 .63021 Mdot
.61841 .37947 Mdot
.73215 .50886 Mdot
.64769 .49829 Mdot
.40685 .72061 Mdot
.47954 .36389 Mdot
.47122 .45814 Mdot
.2986 .49484 Mdot
.48189 .50653 Mdot
.58572 .31863 Mdot
.32914 .55712 Mdot
.59024 .68092 Mdot
.36839 .72453 Mdot
.6304 .43254 Mdot
.39777 .67838 Mdot
.68217 .50938 Mdot
.46088 .48624 Mdot
.59529 .71011 Mdot
.45913 .36841 Mdot
.31015 .51055 Mdot
.44321 .31486 Mdot
.76118 .36702 Mdot
.78657 .60062 Mdot
.82618 .36794 Mdot
.43356 .70887 Mdot
.59867 .20498 Mdot
.48084 .35014 Mdot
.64576 .47092 Mdot
.5293 .90933 Mdot
.47797 .33784 Mdot
.44465 .33517 Mdot
.45182 .53373 Mdot
.68028 .67154 Mdot
.59985 .52015 Mdot
.50244 .34501 Mdot
.36387 .71052 Mdot
.58851 .70254 Mdot
.66057 .50819 Mdot
.63767 .54324 Mdot
.48182 .29932 Mdot
.42409 .70037 Mdot
.64514 .65119 Mdot
.41005 .69052 Mdot
.48031 .3605 Mdot
.42236 .67832 Mdot
.37826 .28174 Mdot
.37651 .70912 Mdot
.59526 .44815 Mdot
.62903 .46571 Mdot
.32966 .58057 Mdot
.45835 .33034 Mdot
.6754 .48139 Mdot
.63136 .4897 Mdot
.47603 .35348 Mdot
.45231 .70144 Mdot
.65895 .23833 Mdot
.67602 .4731 Mdot
.63212 .46935 Mdot
.56885 .70709 Mdot
.51968 .5441 Mdot
.45593 .44522 Mdot
.6663 .50516 Mdot
.61237 .69517 Mdot
.45547 .36069 Mdot
.61655 .45709 Mdot
.6695 .67376 Mdot
.44242 .66782 Mdot
.64843 .50449 Mdot
.40717 .44076 Mdot
.64369 .4458 Mdot
.53125 .15791 Mdot
.61151 .5022 Mdot
.46648 .34954 Mdot
.48926 .34797 Mdot
.36366 .65712 Mdot
.47009 .32594 Mdot
.38247 .44555 Mdot
.29057 .53008 Mdot
.45719 .2141 Mdot
.38638 .44192 Mdot
.64128 .4272 Mdot
.80536 .63839 Mdot
.63397 .54378 Mdot
.61209 .53868 Mdot
.67534 .75808 Mdot
.37832 .45367 Mdot
.47993 .34451 Mdot
.26735 .39501 Mdot
.59879 .5137 Mdot
.27813 .50057 Mdot
.60558 .53158 Mdot
.64812 .5043 Mdot
.56269 .44044 Mdot
.50751 .26323 Mdot
.26629 .52663 Mdot
.68145 .40371 Mdot
.66089 .50777 Mdot
.71134 .2734 Mdot
.61497 .43458 Mdot
.57398 .68006 Mdot
.48774 .31477 Mdot
.38743 .68335 Mdot
.59322 .70606 Mdot
.63818 .43404 Mdot
.58091 .68952 Mdot
.39807 .68121 Mdot
.315 .52675 Mdot
.59711 .44373 Mdot
.61763 .70641 Mdot
.59034 .6792 Mdot
.66181 .47421 Mdot
.49275 .33782 Mdot
.68551 .44275 Mdot
.61823 .45462 Mdot
.62588 .5071 Mdot
.49959 .33935 Mdot
.58158 .84739 Mdot
.63437 .49511 Mdot
.4152 .56894 Mdot
.43621 .34707 Mdot
.38458 .44034 Mdot
.38514 .7052 Mdot
.59343 .41836 Mdot
.27647 .51558 Mdot
.2894 .5283 Mdot
.44314 .68921 Mdot
.49232 .30634 Mdot
.41496 .70164 Mdot
.57363 .42751 Mdot
.5879 .50798 Mdot
.63671 .52033 Mdot
.41044 .80226 Mdot
.35428 .29266 Mdot
.4556 .33887 Mdot
.4066 .73258 Mdot
.48615 .50276 Mdot
.27149 .51768 Mdot
.37248 .71902 Mdot
.45094 .28456 Mdot
.5006 .31696 Mdot
.49916 .348 Mdot
.60797 .68251 Mdot
.40674 .70222 Mdot
.45195 .27992 Mdot
.48356 .28379 Mdot
.66725 .47948 Mdot
.65945 .50664 Mdot
.48821 .37728 Mdot
.37626 .75423 Mdot
.60343 .69874 Mdot
.41132 .72183 Mdot
.49682 .13694 Mdot
.27453 .50623 Mdot
.65679 .37335 Mdot
.66373 .50874 Mdot
.34511 .8533 Mdot
.63247 .52342 Mdot
.60762 .43988 Mdot
.48501 .37259 Mdot
.60893 .66589 Mdot
.58755 .69949 Mdot
.482 .35025 Mdot
.49373 .29676 Mdot
.59153 .67465 Mdot
.44472 .54178 Mdot
.57427 .17093 Mdot
.47409 .47271 Mdot
.46007 .34871 Mdot
.55455 .29036 Mdot
.29843 .54222 Mdot
.44006 .34955 Mdot
.33502 .48432 Mdot
.41054 .66976 Mdot
.3759 .69695 Mdot
.30493 .53365 Mdot
.63443 .49748 Mdot
.43438 .7014 Mdot
.58162 .41651 Mdot
.3924 .31552 Mdot
.25891 .57098 Mdot
.80898 .39011 Mdot
.59185 .4551 Mdot
.67318 .56754 Mdot
.29238 .4525 Mdot
.65142 .43391 Mdot
.73036 .43838 Mdot
.58197 .68483 Mdot
.43929 .35266 Mdot
.27512 .54426 Mdot
.39247 .22153 Mdot
.62714 .46573 Mdot
.46599 .356 Mdot
.2696 .51738 Mdot
.37556 .30271 Mdot
.43239 .57644 Mdot
.66242 .46017 Mdot
.57817 .89864 Mdot
.50187 .35739 Mdot
.3874 .68381 Mdot
.63905 .35779 Mdot
.44012 .32984 Mdot
.47089 .6677 Mdot
.37563 .66457 Mdot
.49214 .46694 Mdot
.50543 .33673 Mdot
.56094 .67308 Mdot
.48534 .32185 Mdot
.61244 .67672 Mdot
.50364 .30278 Mdot
.42362 .68812 Mdot
.60933 .45575 Mdot
.42025 .68482 Mdot
.56955 .6818 Mdot
.43827 .70098 Mdot
.27511 .54413 Mdot
.38076 .459 Mdot
.28416 .53313 Mdot
.56657 .57386 Mdot
.66044 .26147 Mdot
.31773 .50844 Mdot
.40359 .54559 Mdot
.6386 .44178 Mdot
.51429 .3569 Mdot
.39175 .67773 Mdot
.44283 .71137 Mdot
.49078 .52043 Mdot
.49092 .35595 Mdot
.42754 .69381 Mdot
.55778 .30097 Mdot
.40168 .8347 Mdot
.56751 .48003 Mdot
.23675 .68758 Mdot
.47184 .35299 Mdot
.40164 .73722 Mdot
.46449 .44346 Mdot
.46605 .29531 Mdot
.38095 .68077 Mdot
.31301 .51335 Mdot
.27857 .51059 Mdot
.59244 .48553 Mdot
.31787 .54035 Mdot
.39097 .72802 Mdot
.70974 .26907 Mdot
.4947 .322 Mdot
.34175 .28518 Mdot
.5713 .68815 Mdot
.4032 .67381 Mdot
.61242 .52306 Mdot
.51933 .3114 Mdot
.39781 .66116 Mdot
.18024 .49082 Mdot
.43254 .15971 Mdot
.428 .69456 Mdot
.48683 .31391 Mdot
.46666 .3173 Mdot
.57516 .43141 Mdot
.4903 .50236 Mdot
.42479 .70296 Mdot
.32245 .62094 Mdot
.65629 .61071 Mdot
.39014 .44286 Mdot
.81218 .49195 Mdot
.64867 .48864 Mdot
.64795 .499 Mdot
.30691 .49486 Mdot
.61522 .44598 Mdot
.48594 .28927 Mdot
.63651 .52338 Mdot
.32687 .50932 Mdot
.44039 .70179 Mdot
.62539 .4593 Mdot
.57827 .68406 Mdot
.32382 .52134 Mdot
.3158 .49012 Mdot
.41929 .67273 Mdot
.49927 .32691 Mdot
.25274 .42 Mdot
.41007 .69274 Mdot
.63436 .50692 Mdot
.38863 .45747 Mdot
.65327 .52107 Mdot
.33949 .57621 Mdot
.44905 .29982 Mdot
.38425 .68798 Mdot
.47603 .37838 Mdot
.29872 .51424 Mdot
.4227 .7335 Mdot
.62932 .43061 Mdot
.37829 .7007 Mdot
.40008 .58555 Mdot
.4886 .74312 Mdot
.48927 .28899 Mdot
.44579 .61284 Mdot
.49365 .3054 Mdot
.3917 .44156 Mdot
.71561 .62507 Mdot
.60168 .69061 Mdot
.40364 .72606 Mdot
.37513 .26725 Mdot
.3978 .66974 Mdot
.62557 .44692 Mdot
.63892 .48276 Mdot
.39858 .71437 Mdot
.60919 .69211 Mdot
.65723 .72523 Mdot
.54966 .71929 Mdot
.46298 .30669 Mdot
.45566 .58698 Mdot
.52424 .13999 Mdot
.41107 .64401 Mdot
.29642 .5353 Mdot
.73424 .4816 Mdot
.65196 .44336 Mdot
.26758 .52226 Mdot
.29453 .48684 Mdot
.58684 .66851 Mdot
.40275 .67143 Mdot
.43482 .31759 Mdot
.28612 .54401 Mdot
.51199 .29632 Mdot
.65732 .66421 Mdot
.68397 .50986 Mdot
.53182 .46271 Mdot
.60808 .42438 Mdot
.48974 .53526 Mdot
.32827 .5165 Mdot
.62112 .48342 Mdot
.67668 .40662 Mdot
.30552 .50065 Mdot
.59665 .66698 Mdot
.53305 .32068 Mdot
.42957 .68962 Mdot
.3721 .84476 Mdot
.59669 .44618 Mdot
.61261 .45547 Mdot
.29414 .49586 Mdot
.71714 .38618 Mdot
.45314 .33935 Mdot
.49771 .32296 Mdot
.39897 .69066 Mdot
.45324 .49627 Mdot
.59209 .48825 Mdot
.61038 .43185 Mdot
.43329 .69862 Mdot
.3972 .45847 Mdot
.82637 .45756 Mdot
.62969 .47549 Mdot
.28638 .51147 Mdot
.3831 .58473 Mdot
.32718 .52224 Mdot
.64638 .42363 Mdot
.63066 .44721 Mdot
.61666 .42657 Mdot
.58991 .44882 Mdot
.29217 .54069 Mdot
.63183 .42891 Mdot
.6934 .49645 Mdot
.47655 .34331 Mdot
.64725 .4955 Mdot
.65926 .60859 Mdot
.62681 .47285 Mdot
.57702 .68615 Mdot
.45399 .45549 Mdot
.60851 .4978 Mdot
.64615 .49707 Mdot
.65178 .61252 Mdot
.60391 .45496 Mdot
.26869 .5199 Mdot
.46306 .32263 Mdot
.29963 .51274 Mdot
.29986 .53074 Mdot
.39184 .66485 Mdot
.6163 .67872 Mdot
.58302 .44168 Mdot
.59902 .67442 Mdot
.56499 .44742 Mdot
.62629 .54822 Mdot
.54067 .55981 Mdot
.46345 .4502 Mdot
.57202 .72113 Mdot
.61856 .43084 Mdot
.40089 .68421 Mdot
.38251 .69005 Mdot
.44978 .60608 Mdot
.59554 .52946 Mdot
.28496 .54656 Mdot
.31479 .5214 Mdot
.54339 .71741 Mdot
.51542 .68154 Mdot
.58922 .67808 Mdot
.58253 .60593 Mdot
.68513 .46262 Mdot
.623 .49873 Mdot
.60955 .54626 Mdot
.3866 .6619 Mdot
.37958 .45923 Mdot
.43944 .68354 Mdot
.41941 .41971 Mdot
.30014 .54347 Mdot
.59198 .4559 Mdot
.17354 .42559 Mdot
.45854 .3061 Mdot
.46244 .3226 Mdot
.327 .50831 Mdot
.41033 .72887 Mdot
.60448 .53787 Mdot
.28472 .77293 Mdot
.47087 .28988 Mdot
.58081 .72044 Mdot
.60016 .46571 Mdot
.41317 .67205 Mdot
.47469 .30111 Mdot
.61115 .71498 Mdot
.59285 .44286 Mdot
.3672 .68112 Mdot
.61897 .47732 Mdot
.60644 .29328 Mdot
.48532 .34061 Mdot
.52369 .52594 Mdot
.50103 .3723 Mdot
.28693 .53829 Mdot
.30368 .5062 Mdot
.63261 .45098 Mdot
.32887 .81088 Mdot
.47037 .26374 Mdot
.27747 .49215 Mdot
.61102 .7131 Mdot
.38518 .46228 Mdot
.61458 .70698 Mdot
.39447 .70915 Mdot
.59343 .68206 Mdot
.39806 .66178 Mdot
.38006 .75783 Mdot
.43224 .30605 Mdot
.5814 .71149 Mdot
.74006 .3963 Mdot
.58523 .50373 Mdot
.57654 .67367 Mdot
.63446 .51815 Mdot
.56275 .44546 Mdot
.43417 .68906 Mdot
.60368 .67926 Mdot
.65587 .46255 Mdot
.30742 .28267 Mdot
.30736 .51676 Mdot
.27926 .54514 Mdot
.58763 .50624 Mdot
.39276 .73512 Mdot
.49703 .29651 Mdot
.51119 .55695 Mdot
.37748 .44583 Mdot
.60864 .43294 Mdot
.6142 .42033 Mdot
.50096 .36149 Mdot
.45641 .35566 Mdot
.63428 .44982 Mdot
.53844 .28434 Mdot
.63479 .4325 Mdot
.28044 .50704 Mdot
.46124 .30684 Mdot
.4641 .31808 Mdot
.38569 .72326 Mdot
.48862 .30421 Mdot
.69932 .4519 Mdot
.27117 .55778 Mdot
.64288 .5324 Mdot
.29578 .51566 Mdot
.35436 .72013 Mdot
.42221 .66561 Mdot
.37298 .2655 Mdot
.48928 .30555 Mdot
.67744 .48074 Mdot
.45515 .30396 Mdot
.56994 .6992 Mdot
.45796 .32661 Mdot
.50738 .3587 Mdot
.59688 .48729 Mdot
.64921 .45421 Mdot
.39665 .45681 Mdot
.49236 .51157 Mdot
.48704 .33424 Mdot
.65938 .44234 Mdot
.67243 .50348 Mdot
.64175 .47877 Mdot
.53354 .56193 Mdot
.47228 .37373 Mdot
.60817 .37905 Mdot
.34947 .54913 Mdot
.49056 .33275 Mdot
.45707 .17095 Mdot
.40642 .4525 Mdot
.41584 .43771 Mdot
.32108 .48472 Mdot
.63266 .47317 Mdot
.41787 .69646 Mdot
.64699 .50116 Mdot
.5788 .51656 Mdot
.60523 .49233 Mdot
.58129 .71346 Mdot
.59557 .49954 Mdot
.39881 .4436 Mdot
.41225 .68676 Mdot
.65774 .44239 Mdot
.63056 .46049 Mdot
.41472 .44004 Mdot
.49096 .37765 Mdot
.4984 .31403 Mdot
.36267 .46833 Mdot
.58476 .67055 Mdot
.32261 .5086 Mdot
.63756 .5063 Mdot
.40015 .68786 Mdot
.41812 .68857 Mdot
.44308 .32342 Mdot
.42799 .70714 Mdot
.32475 .51044 Mdot
.61398 .43674 Mdot
.28779 .53858 Mdot
.58091 .71331 Mdot
.48831 .31531 Mdot
.62413 .51227 Mdot
.6661 .47517 Mdot
.48917 .34783 Mdot
.64479 .44399 Mdot
.57772 .71389 Mdot
.37503 .67638 Mdot
.45466 .32786 Mdot
.29134 .52909 Mdot
.38149 .7188 Mdot
.67267 .4817 Mdot
.34812 .19032 Mdot
.61611 .445 Mdot
.60671 .43173 Mdot
.40987 .28809 Mdot
.68205 .48532 Mdot
.40165 .66903 Mdot
.46127 .29973 Mdot
.6271 .41686 Mdot
.65303 .61483 Mdot
.59885 .65465 Mdot
.39606 .64712 Mdot
.59876 .45904 Mdot
.42506 .20116 Mdot
.67296 .49872 Mdot
.38512 .26004 Mdot
.53974 .5587 Mdot
.2109 .58116 Mdot
.53199 .46188 Mdot
.28008 .48944 Mdot
.39322 .45929 Mdot
.41055 .66459 Mdot
.70298 .3598 Mdot
.62756 .44213 Mdot
.72214 .30884 Mdot
.62747 .51225 Mdot
.28145 .51074 Mdot
.72489 .4372 Mdot
.41619 .71916 Mdot
.80771 .48985 Mdot
.64174 .49142 Mdot
.49903 .35952 Mdot
.40681 .74279 Mdot
.39894 .46034 Mdot
.65106 .46125 Mdot
.58195 .67642 Mdot
.5543 .67208 Mdot
.69777 .44778 Mdot
.29723 .51746 Mdot
.62716 .49405 Mdot
.5937 .41178 Mdot
.41616 .82744 Mdot
.47011 .34386 Mdot
.30832 .52398 Mdot
.54429 .64753 Mdot
.64073 .47746 Mdot
.50055 .31785 Mdot
.46452 .3259 Mdot
.60108 .67123 Mdot
.23301 .50367 Mdot
.62709 .75698 Mdot
.20412 .34919 Mdot
.7557 .33929 Mdot
.38196 .66532 Mdot
.51791 .38816 Mdot
.65708 .49175 Mdot
.78823 .60002 Mdot
.2959 .53269 Mdot
.61008 .45737 Mdot
.72715 .33113 Mdot
.4648 .33989 Mdot
.62357 .47921 Mdot
.60243 .69861 Mdot
.26059 .44398 Mdot
.5752 .32716 Mdot
.35936 .205 Mdot
.36329 .707 Mdot
.60784 .52743 Mdot
.69955 .47715 Mdot
.38218 .44273 Mdot
.63862 .4207 Mdot
.39407 .67664 Mdot
.36179 .59474 Mdot
.60472 .70797 Mdot
.46082 .30413 Mdot
.40468 .45618 Mdot
.62834 .51264 Mdot
.66922 .52038 Mdot
.58787 .72102 Mdot
.64886 .46918 Mdot
.62378 .35854 Mdot
.41838 .4474 Mdot
.3754 .70694 Mdot
.49725 .35968 Mdot
.6128 .42297 Mdot
.38775 .46148 Mdot
.6004 .49555 Mdot
.75944 .47731 Mdot
.60454 .47715 Mdot
.43099 .24843 Mdot
.49383 .3425 Mdot
.29892 .52262 Mdot
.59284 .49705 Mdot
.61963 .46984 Mdot
.49905 .6864 Mdot
.60147 .53429 Mdot
.61755 .50269 Mdot
.4413 .32045 Mdot
.4567 .30648 Mdot
.46362 .35662 Mdot
.38488 .72001 Mdot
.47773 .47441 Mdot
.28262 .52123 Mdot
.60777 .54453 Mdot
.2898 .54522 Mdot
.53354 .4471 Mdot
.60132 .71723 Mdot
.36258 .26448 Mdot
.62436 .43692 Mdot
.49479 .35451 Mdot
.6092 .19107 Mdot
.4531 .35812 Mdot
.35394 .50488 Mdot
.29777 .52941 Mdot
.48041 .33557 Mdot
.60235 .45333 Mdot
.492 .49437 Mdot
.32909 .21706 Mdot
.27131 .5205 Mdot
.61637 .53793 Mdot
.36024 .69398 Mdot
.44541 .68696 Mdot
.47968 .17553 Mdot
.27409 .53128 Mdot
.28517 .4543 Mdot
.67594 .47043 Mdot
.46907 .29873 Mdot
.32106 .51553 Mdot
.27282 .50182 Mdot
.43013 .70574 Mdot
.66655 .46666 Mdot
.62034 .4723 Mdot
.40836 .44221 Mdot
.30486 .53683 Mdot
.54308 .48526 Mdot
.65961 .45545 Mdot
.39824 .33123 Mdot
.44579 .29066 Mdot
.59273 .84274 Mdot
.65701 .39067 Mdot
.72502 .32598 Mdot
.35537 .65273 Mdot
.45286 .3287 Mdot
.63598 .49782 Mdot
.60892 .54255 Mdot
.37357 .67476 Mdot
.61259 .44006 Mdot
.4178 .73027 Mdot
.28145 .53643 Mdot
.36559 .25026 Mdot
.41464 .53126 Mdot
.24497 .54363 Mdot
.61756 .44722 Mdot
.5699 .32694 Mdot
.58301 .71008 Mdot
.25687 .52619 Mdot
.45235 .34551 Mdot
.65572 .43156 Mdot
.39235 .65615 Mdot
.38756 .72118 Mdot
.46668 .3334 Mdot
.36248 .42488 Mdot
.37756 .2619 Mdot
.59215 .43838 Mdot
.38824 .70701 Mdot
.41127 .48391 Mdot
.5064 .2336 Mdot
.31644 .48548 Mdot
.6027 .71041 Mdot
.40852 .6663 Mdot
.29556 .55109 Mdot
.56059 .45567 Mdot
.47511 .3302 Mdot
.50529 .35098 Mdot
.45823 .63706 Mdot
.4255 .69605 Mdot
.59477 .69554 Mdot
.44568 .60251 Mdot
.45555 .59667 Mdot
.5976 .70789 Mdot
.42074 .73192 Mdot
.45187 .31871 Mdot
.47286 .3576 Mdot
.46405 .3222 Mdot
.66848 .37525 Mdot
.45545 .29639 Mdot
.71614 .70528 Mdot
.64763 .42627 Mdot
.53431 .26432 Mdot
.66821 .44684 Mdot
.27122 .53867 Mdot
.48657 .34072 Mdot
.53513 .55109 Mdot
.68705 .47419 Mdot
.34389 .21379 Mdot
.61162 .4836 Mdot
.39696 .57709 Mdot
.63296 .47144 Mdot
.61613 .3362 Mdot
.4372 .34791 Mdot
.6264 .42981 Mdot
.27501 .56142 Mdot
.57806 .6898 Mdot
.43198 .29884 Mdot
.61925 .50169 Mdot
.35004 .39194 Mdot
.63563 .51789 Mdot
.40172 .24258 Mdot
.46821 .71258 Mdot
.5583 .69425 Mdot
.66789 .51253 Mdot
.41414 .65667 Mdot
.71823 .52995 Mdot
.54697 .27719 Mdot
.27148 .52187 Mdot
.56498 .31847 Mdot
.4238 .71641 Mdot
.72542 .43292 Mdot
.67735 .44306 Mdot
.60835 .70185 Mdot
.53061 .31299 Mdot
.28311 .50321 Mdot
.6302 .44102 Mdot
.6387 .49268 Mdot
.26335 .57859 Mdot
.56028 .28731 Mdot
.58333 .54979 Mdot
.58613 .7253 Mdot
.5772 .32053 Mdot
.61069 .49681 Mdot
.3937 .64849 Mdot
.47033 .29557 Mdot
.72219 .45851 Mdot
.72163 .4007 Mdot
.65287 .43802 Mdot
.47625 .33652 Mdot
.49354 .30775 Mdot
.65034 .20407 Mdot
.60706 .71049 Mdot
.60585 .47926 Mdot
.46176 .6469 Mdot
.6317 .50861 Mdot
.27982 .51706 Mdot
.68331 .45548 Mdot
.42596 .66985 Mdot
.46558 .43443 Mdot
.38688 .72198 Mdot
.64435 .46391 Mdot
.48555 .31919 Mdot
.29071 .49819 Mdot
.21911 .62157 Mdot
.30216 .46745 Mdot
.71427 .70598 Mdot
.55401 .66962 Mdot
.5839 .67808 Mdot
.61788 .69493 Mdot
.28653 .47652 Mdot
.59989 .45359 Mdot
.48755 .53957 Mdot
.56579 .48474 Mdot
.63607 .47501 Mdot
.60317 .47946 Mdot
.32593 .46779 Mdot
.29817 .52811 Mdot
.42257 .68145 Mdot
.63443 .44887 Mdot
.65954 .44215 Mdot
.48596 .32693 Mdot
.59133 .6789 Mdot
.37341 .68611 Mdot
.57172 .68114 Mdot
.40823 .68523 Mdot
.52756 .15701 Mdot
.65989 .53224 Mdot
.57768 .69226 Mdot
.32441 .5254 Mdot
.47747 .3624 Mdot
.41128 .43762 Mdot
.39683 .70965 Mdot
.4178 .71738 Mdot
.63736 .42953 Mdot
.48918 .31212 Mdot
.49561 .31408 Mdot
.5909 .67501 Mdot
.31644 .51807 Mdot
.59613 .42362 Mdot
.65247 .45328 Mdot
.23045 .64698 Mdot
.37145 .68299 Mdot
.56763 .31094 Mdot
.42415 .2649 Mdot
.60043 .44699 Mdot
.50115 .32144 Mdot
.62087 .46001 Mdot
.39134 .50092 Mdot
.46352 .3583 Mdot
.68334 .47581 Mdot
.55408 .48037 Mdot
.38525 .66352 Mdot
.73918 .27389 Mdot
.58184 .45526 Mdot
.30597 .56043 Mdot
.65958 .48178 Mdot
.8154 .33844 Mdot
.6276 .19957 Mdot
.61813 .51469 Mdot
.59004 .45708 Mdot
.21771 .32148 Mdot
.66235 .51137 Mdot
.40443 .44309 Mdot
.58069 .51892 Mdot
.50244 .32108 Mdot
.42133 .58099 Mdot
.48992 .52853 Mdot
.6133 .70205 Mdot
.39846 .68994 Mdot
.6747 .67157 Mdot
.606 .66968 Mdot
.46805 .35075 Mdot
.66491 .52524 Mdot
.42848 .26324 Mdot
.44904 .69754 Mdot
.64129 .41468 Mdot
.28004 .51461 Mdot
.48844 .52795 Mdot
.43548 .67611 Mdot
.29129 .53029 Mdot
.67438 .49754 Mdot
.39292 .78701 Mdot
.28471 .56766 Mdot
.6627 .20584 Mdot
.30709 .49574 Mdot
.30484 .51654 Mdot
.48676 .48004 Mdot
.61368 .70099 Mdot
.30371 .59505 Mdot
.7051 .48421 Mdot
.27287 .51123 Mdot
.75346 .56204 Mdot
.36709 .69254 Mdot
.46081 .49274 Mdot
.4382 .34616 Mdot
.64263 .54263 Mdot
.60443 .46461 Mdot
.31308 .50661 Mdot
.50578 .38927 Mdot
.51607 .6604 Mdot
.27656 .52982 Mdot
.69626 .46176 Mdot
.45675 .48049 Mdot
.38419 .45831 Mdot
.40896 .44924 Mdot
.60652 .71831 Mdot
.50446 .78454 Mdot
.4962 .3425 Mdot
.57693 .71801 Mdot
.53232 .52724 Mdot
.61571 .48892 Mdot
.29954 .54057 Mdot
.41282 .44697 Mdot
.28978 .52667 Mdot
.58325 .70207 Mdot
.59454 .72073 Mdot
.47537 .34362 Mdot
.4513 .33614 Mdot
.46333 .24034 Mdot
.70201 .57415 Mdot
.6528 .50189 Mdot
.67321 .25779 Mdot
.45613 .35426 Mdot
.70854 .37216 Mdot
.60986 .68146 Mdot
.60329 .68357 Mdot
.57142 .2498 Mdot
.66997 .48474 Mdot
.38597 .58358 Mdot
.61051 .49944 Mdot
.74781 .59756 Mdot
.62844 .51363 Mdot
.4308 .70282 Mdot
.64607 .48836 Mdot
.25204 .4038 Mdot
.66146 .44705 Mdot
.6021 .48095 Mdot
.40372 .70661 Mdot
.59082 .42942 Mdot
.4321 .67843 Mdot
.63143 .49848 Mdot
.62671 .67843 Mdot
.40023 .68838 Mdot
.6283 .70034 Mdot
.42931 .55972 Mdot
.40048 .45154 Mdot
.61647 .69643 Mdot
.57811 .67949 Mdot
.64152 .64911 Mdot
.44694 .32883 Mdot
.71552 .41375 Mdot
.60084 .46342 Mdot
.37703 .72208 Mdot
.31916 .52867 Mdot
.6516 .43693 Mdot
.63501 .5246 Mdot
.58684 .43049 Mdot
.47685 .34065 Mdot
.41011 .73649 Mdot
.58163 .69491 Mdot
.38109 .69205 Mdot
.62839 .6889 Mdot
.4146 .66073 Mdot
.57629 .46249 Mdot
.56287 .45216 Mdot
.69561 .48772 Mdot
.70305 .30427 Mdot
.80781 .62019 Mdot
.47072 .33106 Mdot
.38821 .45431 Mdot
.60132 .71769 Mdot
.46019 .58724 Mdot
.49838 .34401 Mdot
.41863 .71543 Mdot
.61873 .47732 Mdot
.69845 .4928 Mdot
.65518 .5434 Mdot
.49026 .27775 Mdot
.60501 .73242 Mdot
.39509 .7011 Mdot
.38358 .44744 Mdot
.47242 .47515 Mdot
.43359 .37314 Mdot
.55819 .56821 Mdot
.6203 .46493 Mdot
.58922 .67422 Mdot
.47445 .30107 Mdot
.33031 .59296 Mdot
.31268 .50966 Mdot
.49116 .50674 Mdot
.61542 .44745 Mdot
.35349 .44962 Mdot
.48442 .31872 Mdot
.6066 .69549 Mdot
.31227 .50541 Mdot
.61197 .70072 Mdot
.3951 .46339 Mdot
.36536 .46488 Mdot
.65197 .46493 Mdot
.61258 .5027 Mdot
.30354 .54132 Mdot
.49663 .33882 Mdot
.62166 .66636 Mdot
.25372 .57443 Mdot
.39515 .71123 Mdot
.44688 .51184 Mdot
.46593 .30252 Mdot
.305 .45928 Mdot
.38179 .70648 Mdot
.29924 .54851 Mdot
.49245 .53864 Mdot
.32212 .50029 Mdot
.60739 .49105 Mdot
.47243 .30987 Mdot
.27144 .52835 Mdot
.24112 .64669 Mdot
.435 .21897 Mdot
.49772 .27304 Mdot
.64189 .4481 Mdot
.36216 .26011 Mdot
.32603 .41928 Mdot
.5316 .38586 Mdot
.28522 .54305 Mdot
.62629 .45126 Mdot
.59323 .4364 Mdot
.64261 .49061 Mdot
.30928 .51467 Mdot
.2159 .52101 Mdot
.401 .72322 Mdot
.62332 .48467 Mdot
.57066 .69008 Mdot
.42564 .6721 Mdot
.44073 .67156 Mdot
.40537 .66572 Mdot
.4544 .35335 Mdot
.67165 .52104 Mdot
.63606 .56016 Mdot
.71263 .24748 Mdot
.30247 .51935 Mdot
.40042 .45119 Mdot
.60369 .43211 Mdot
.69909 .70858 Mdot
.47329 .35956 Mdot
.40344 .71229 Mdot
.61144 .45716 Mdot
.47397 .68306 Mdot
.4138 .45808 Mdot
.40715 .6991 Mdot
.45499 .3485 Mdot
.53139 .3888 Mdot
.61402 .4387 Mdot
.66101 .48454 Mdot
.48257 .35608 Mdot
.29879 .43903 Mdot
.46924 .47292 Mdot
.62334 .46044 Mdot
.29685 .52641 Mdot
.37043 .83226 Mdot
.68034 .47869 Mdot
.52631 .34757 Mdot
.3778 .45857 Mdot
.41382 .36638 Mdot
.55142 .30176 Mdot
.57531 .50079 Mdot
.32921 .25337 Mdot
.68215 .73352 Mdot
.38079 .22694 Mdot
.74694 .61263 Mdot
.24023 .56285 Mdot
.58288 .16121 Mdot
.28484 .56152 Mdot
.61111 .32231 Mdot
.17229 .48575 Mdot
.31292 .44709 Mdot
.46761 .73661 Mdot
.24871 .61793 Mdot
.38293 .77581 Mdot
.81821 .47898 Mdot
.42461 .66081 Mdot
.77032 .59351 Mdot
.6147 .50733 Mdot
.30332 .42934 Mdot
.60228 .33584 Mdot
.77162 .68206 Mdot
.36411 .27224 Mdot
.46704 .65665 Mdot
.32041 .21056 Mdot
.37143 .29034 Mdot
.5029 .20636 Mdot
.75305 .42977 Mdot
.54098 .79795 Mdot
.45942 .5962 Mdot
.6821 .68501 Mdot
.56659 .33629 Mdot
.2552 .38063 Mdot
.26866 .56224 Mdot
.61609 .22291 Mdot
.44361 .83658 Mdot
.38903 .68857 Mdot
.47317 .29523 Mdot
.28996 .5979 Mdot
.48439 .20985 Mdot
.34121 .53765 Mdot
.32927 .253 Mdot
.40145 .30184 Mdot
.61356 .33318 Mdot
.52559 .52597 Mdot
.60693 .28576 Mdot
.64466 .75177 Mdot
.79732 .50745 Mdot
.50899 .30151 Mdot
.26306 .64091 Mdot
.46337 .59432 Mdot
.64244 .6779 Mdot
.63834 .35003 Mdot
.60541 .72192 Mdot
.6203 .70626 Mdot
.45833 .35257 Mdot
.50437 .22826 Mdot
.42104 .44214 Mdot
.53361 .52635 Mdot
.39833 .65316 Mdot
.39551 .50522 Mdot
.26741 .43573 Mdot
.34201 .41924 Mdot
.7813 .33431 Mdot
.37474 .18249 Mdot
.69618 .60405 Mdot
.35566 .58906 Mdot
.34329 .52165 Mdot
.68198 .70198 Mdot
.62256 .56836 Mdot
.72208 .57496 Mdot
.7605 .46975 Mdot
.25745 .25793 Mdot
.36905 .38405 Mdot
.31355 .20772 Mdot
.51337 .31788 Mdot
.6897 .41743 Mdot
.36965 .56435 Mdot
.75967 .35604 Mdot
.63807 .6241 Mdot
.37067 .19086 Mdot
.55735 .68589 Mdot
.43357 .33679 Mdot
.31437 .44781 Mdot
.61587 .35797 Mdot
.63401 .73471 Mdot
.54248 .67804 Mdot
.72112 .4551 Mdot
.25449 .24837 Mdot
.32028 .25945 Mdot
.57448 .18107 Mdot
.39904 .34592 Mdot
.45502 .67147 Mdot
.43787 .66578 Mdot
.271 .5028 Mdot
.47027 .19419 Mdot
.47498 .31465 Mdot
.72437 .25217 Mdot
.4332 .22877 Mdot
.72156 .52961 Mdot
.23508 .26673 Mdot
.81677 .44824 Mdot
.53331 .26727 Mdot
.77064 .65109 Mdot
.30681 .76504 Mdot
.60791 .57271 Mdot
.27354 .46969 Mdot
.3687 .665 Mdot
.43134 .24421 Mdot
.45945 .19256 Mdot
.76241 .54558 Mdot
.18786 .39842 Mdot
.5344 .52502 Mdot
.35635 .66347 Mdot
.46424 .26744 Mdot
.45983 .75607 Mdot
.59904 .6212 Mdot
.32105 .20414 Mdot
.58445 .32739 Mdot
.35322 .81142 Mdot
.72725 .62465 Mdot
.71466 .38624 Mdot
.32221 .27926 Mdot
.39758 .76399 Mdot
.71736 .55255 Mdot
.35917 .39913 Mdot
.6214 .53461 Mdot
.59461 .59935 Mdot
.73857 .44296 Mdot
.59573 .75212 Mdot
.47708 .46767 Mdot
.36309 .35387 Mdot
.69712 .63405 Mdot
.20591 .53312 Mdot
.71141 .40166 Mdot
.4769 .37087 Mdot
.70536 .58448 Mdot
.72305 .60742 Mdot
.3936 .36138 Mdot
.54797 .64475 Mdot
.56314 .17675 Mdot
.52824 .65611 Mdot
.57361 .5025 Mdot
.60974 .31596 Mdot
.56806 .34122 Mdot
.74004 .57948 Mdot
.58088 .48107 Mdot
.76072 .31043 Mdot
.40323 .34022 Mdot
.67931 .29057 Mdot
.67075 .63878 Mdot
.69559 .29898 Mdot
.4563 .21476 Mdot
.36901 .55759 Mdot
.25949 .47476 Mdot
.52529 .37776 Mdot
.25824 .24649 Mdot
.42495 .67721 Mdot
.74815 .55824 Mdot
.28874 .56331 Mdot
.23326 .64069 Mdot
.245 .57752 Mdot
.51974 .65756 Mdot
.48623 .18925 Mdot
.34356 .43124 Mdot
.39604 .75025 Mdot
.24537 .36844 Mdot
.4207 .4741 Mdot
.66673 .25831 Mdot
.63935 .39653 Mdot
.75079 .49119 Mdot
.57842 .71467 Mdot
.72072 .357 Mdot
.35349 .55273 Mdot
.56335 .75193 Mdot
.57587 .49507 Mdot
.46006 .62613 Mdot
.39148 .44052 Mdot
.47834 .519 Mdot
.52477 .15537 Mdot
.6224 .39221 Mdot
.81348 .45432 Mdot
.33086 .42965 Mdot
.48222 .53444 Mdot
.63274 .65487 Mdot
.44583 .39597 Mdot
.3003 .21385 Mdot
.50399 .1767 Mdot
.31426 .40467 Mdot
.3583 .25772 Mdot
.8586 .48378 Mdot
.21069 .57183 Mdot
.78344 .37689 Mdot
.28663 .56357 Mdot
.72812 .8044 Mdot
.38 .69872 Mdot
.79753 .59453 Mdot
.75556 .35565 Mdot
.48836 .68427 Mdot
.48227 .21066 Mdot
.57881 .35395 Mdot
.59749 .63591 Mdot
.50098 .36909 Mdot
.57684 .48144 Mdot
.39308 .19085 Mdot
.26964 .24079 Mdot
.38571 .19229 Mdot
.37104 .43671 Mdot
.39557 .2056 Mdot
.21909 .30825 Mdot
.71875 .70448 Mdot
.28538 .58356 Mdot
.66994 .43939 Mdot
.75346 .53515 Mdot
.81166 .43042 Mdot
.55431 .71003 Mdot
.59439 .56522 Mdot
.50495 .29568 Mdot
.21665 .30268 Mdot
.52653 .15376 Mdot
.59921 .25702 Mdot
.51541 .21207 Mdot
.3855 .60224 Mdot
.73083 .56168 Mdot
.50502 .19646 Mdot
.26585 .35539 Mdot
.39422 .30764 Mdot
.20259 .33314 Mdot
.71789 .61652 Mdot
.24879 .62203 Mdot
.30879 .39413 Mdot
.80188 .4075 Mdot
.32212 .27474 Mdot
.2779 .59746 Mdot
.70868 .55312 Mdot
.43827 .27853 Mdot
.51735 .66227 Mdot
.25198 .37536 Mdot
.37605 .58481 Mdot
.66748 .62517 Mdot
.4373 .70499 Mdot
.75868 .54383 Mdot
.53016 .58542 Mdot
.28492 .5842 Mdot
.65944 .65918 Mdot
.76892 .54147 Mdot
.33626 .37397 Mdot
.38993 .19976 Mdot
.33249 .43067 Mdot
.30217 .76754 Mdot
.33813 .30047 Mdot
.74038 .45035 Mdot
.58942 .43041 Mdot
.46993 .20228 Mdot
.46666 .15165 Mdot
.48919 .18682 Mdot
.39083 .41795 Mdot
.45449 .64823 Mdot
.31858 .54005 Mdot
.67452 .69405 Mdot
.49849 .66984 Mdot
.40016 .26971 Mdot
.48961 .58084 Mdot
.27065 .55153 Mdot
.2592 .44709 Mdot
.46025 .24064 Mdot
.6939 .70932 Mdot
.60251 .22271 Mdot
.555 .52063 Mdot
.51395 .23966 Mdot
.50306 .35954 Mdot
.36511 .43374 Mdot
.72912 .57089 Mdot
.42046 .67265 Mdot
.23647 .65533 Mdot
.50483 .38581 Mdot
.68233 .40988 Mdot
.36086 .60153 Mdot
.48116 .26438 Mdot
.72142 .31765 Mdot
.40162 .74734 Mdot
.55394 .15719 Mdot
.77688 .3355 Mdot
.50585 .19553 Mdot
.70233 .59279 Mdot
.24968 .65765 Mdot
.4736 .50372 Mdot
.33701 .52494 Mdot
.3651 .27998 Mdot
.45465 .55244 Mdot
.71318 .58615 Mdot
.51406 .24804 Mdot
.30752 .57728 Mdot
.58603 .52115 Mdot
.59955 .186 Mdot
.71108 .69467 Mdot
.46661 .51661 Mdot
.41556 .34235 Mdot
.46622 .28984 Mdot
.82279 .60512 Mdot
.26165 .39058 Mdot
.68831 .5512 Mdot
.343 .26495 Mdot
.30526 .48023 Mdot
.47297 .36539 Mdot
.77559 .5307 Mdot
.49292 .74054 Mdot
.48798 .24972 Mdot
.38851 .55782 Mdot
.49167 .20961 Mdot
.42613 .54504 Mdot
.35264 .25619 Mdot
.30942 .24866 Mdot
.37818 .82784 Mdot
.51368 .32205 Mdot
.34117 .58869 Mdot
.33642 .59713 Mdot
.4898 .28385 Mdot
.50933 .2968 Mdot
.57808 .32978 Mdot
.4307 .1816 Mdot
.44132 .5876 Mdot
.26003 .34987 Mdot
.486 .53784 Mdot
.47312 .73668 Mdot
.31694 .58328 Mdot
.66828 .66579 Mdot
.28031 .29312 Mdot
.5572 .21464 Mdot
.19649 .64732 Mdot
.55385 .52679 Mdot
.79932 .58675 Mdot
.67469 .69509 Mdot
.75276 .4356 Mdot
.63728 .34744 Mdot
.38575 .3072 Mdot
.64096 .5024 Mdot
.38921 .17598 Mdot
.37036 .37355 Mdot
.58897 .60647 Mdot
.38986 .76748 Mdot
.67252 .49242 Mdot
.68591 .50043 Mdot
.50011 .19539 Mdot
.40893 .33296 Mdot
.17203 .56475 Mdot
.73816 .61337 Mdot
.74404 .4805 Mdot
.52511 .26145 Mdot
.8126 .45303 Mdot
.38185 .54395 Mdot
.39868 .22889 Mdot
.53099 .59085 Mdot
.81235 .41974 Mdot
.25727 .3286 Mdot
.24177 .39369 Mdot
.33543 .29165 Mdot
.2285 .29651 Mdot
.73068 .48611 Mdot
.41849 .40334 Mdot
.30258 .60157 Mdot
.59916 .43798 Mdot
.36364 .42381 Mdot
.34449 .27462 Mdot
.45401 .79941 Mdot
.63807 .57233 Mdot
.45996 .15082 Mdot
.55755 .50724 Mdot
.39206 .40093 Mdot
.18398 .51753 Mdot
.19208 .6774 Mdot
.24615 .40235 Mdot
.32668 .20135 Mdot
.23788 .38522 Mdot
.33502 .26251 Mdot
.30352 .47798 Mdot
.4493 .56733 Mdot
.70396 .28262 Mdot
.43783 .17776 Mdot
.51348 .76809 Mdot
.21822 .54588 Mdot
.66564 .23836 Mdot
.43148 .1761 Mdot
.56043 .5022 Mdot
.82268 .58866 Mdot
.45582 .69255 Mdot
.82997 .43569 Mdot
.78767 .3603 Mdot
.41747 .32547 Mdot
.75691 .56339 Mdot
.82006 .56966 Mdot
.75332 .69417 Mdot
.78172 .35934 Mdot
.77188 .47917 Mdot
.41554 .36233 Mdot
.69263 .59705 Mdot
.41004 .24834 Mdot
.82486 .49434 Mdot
.3312 .58242 Mdot
.42602 .43307 Mdot
.3669 .46288 Mdot
.43518 .24407 Mdot
.33254 .35791 Mdot
.37081 .57624 Mdot
.45594 .44072 Mdot
.47717 .22019 Mdot
.41652 .87091 Mdot
.2195 .39068 Mdot
.53203 .30584 Mdot
.28585 .23223 Mdot
.39318 .32407 Mdot
.46524 .58203 Mdot
.64856 .35624 Mdot
.694 .69556 Mdot
.41732 .74982 Mdot
.60585 .49384 Mdot
.42351 .18081 Mdot
.40764 .75025 Mdot
.33465 .20806 Mdot
.67205 .21016 Mdot
.53307 .22386 Mdot
.6208 .39609 Mdot
.36538 .66785 Mdot
.79045 .48745 Mdot
.78221 .49827 Mdot
.28017 .24644 Mdot
.80063 .57483 Mdot
.45023 .52653 Mdot
.41013 .55885 Mdot
.40927 .53667 Mdot
.71231 .52554 Mdot
.81646 .434 Mdot
.42934 .38856 Mdot
.67657 .64798 Mdot
.30151 .40262 Mdot
.74361 .56732 Mdot
.55429 .3033 Mdot
.66927 .68541 Mdot
.54823 .62983 Mdot
.60445 .64086 Mdot
.36872 .69352 Mdot
.18761 .37467 Mdot
.3669 .30913 Mdot
.75026 .29665 Mdot
.30513 .76784 Mdot
.36165 .40095 Mdot
.77812 .58511 Mdot
.33948 .55464 Mdot
.62518 .58084 Mdot
.53047 .78934 Mdot
.69944 .64809 Mdot
.56944 .3193 Mdot
.38981 .25684 Mdot
.62122 .38089 Mdot
.47004 .18486 Mdot
.66576 .6294 Mdot
.16869 .45926 Mdot
.3794 .60958 Mdot
.71623 .34588 Mdot
.55187 .26857 Mdot
.27079 .73957 Mdot
.46816 .51938 Mdot
.25434 .24958 Mdot
.45386 .36072 Mdot
.37122 .18415 Mdot
.31156 .49699 Mdot
.44782 .82141 Mdot
.39158 .29049 Mdot
.5748 .59742 Mdot
.53751 .57091 Mdot
.62938 .1948 Mdot
.32323 .43768 Mdot
.33613 .41849 Mdot
.52046 .66566 Mdot
.43844 .67695 Mdot
.439 .49975 Mdot
.26627 .34385 Mdot
.18929 .37829 Mdot
.59965 .42085 Mdot
.40084 .62553 Mdot
.78968 .49918 Mdot
.33936 .51894 Mdot
.40418 .32458 Mdot
.382 .27419 Mdot
.54657 .33504 Mdot
.72717 .56296 Mdot
.22837 .29245 Mdot
.40503 .27222 Mdot
.51021 .64155 Mdot
.72801 .42711 Mdot
.27368 .5694 Mdot
.19753 .58812 Mdot
.29921 .2733 Mdot
.41105 .54635 Mdot
.46786 .47767 Mdot
.69886 .6046 Mdot
.48839 .13039 Mdot
.26351 .2495 Mdot
.23021 .69221 Mdot
.48042 .53754 Mdot
.49668 .37926 Mdot
.69261 .67456 Mdot
.16805 .45524 Mdot
.83255 .43058 Mdot
.32743 .39109 Mdot
.74861 .56226 Mdot
.4416 .79101 Mdot
.81012 .5889 Mdot
.45761 .5395 Mdot
.5534 .26909 Mdot
.73954 .32296 Mdot
.35928 .49743 Mdot
.39871 .75706 Mdot
.50075 .55545 Mdot
.24938 .5659 Mdot
.41689 .36648 Mdot
.3242 .43876 Mdot
.16857 .46023 Mdot
.8051 .56268 Mdot
.72437 .42328 Mdot
.17628 .46368 Mdot
.43635 .29765 Mdot
.3312 .59756 Mdot
.212 .63159 Mdot
.48496 .54778 Mdot
.38454 .67867 Mdot
.60625 .55917 Mdot
.45244 .48316 Mdot
.23962 .36843 Mdot
.40727 .79241 Mdot
.58956 .66557 Mdot
.52208 .332 Mdot
.81433 .56858 Mdot
.50593 .31032 Mdot
.52138 .13912 Mdot
.26879 .35237 Mdot
.51845 .24868 Mdot
.24255 .33861 Mdot
.27403 .6279 Mdot
.31121 .77763 Mdot
.50545 .20755 Mdot
.65171 .61427 Mdot
.52022 .33451 Mdot
.5104 .33754 Mdot
.26472 .31339 Mdot
.35327 .47233 Mdot
.50488 .22009 Mdot
.812 .46331 Mdot
.25267 .66168 Mdot
.4869 .29218 Mdot
.40957 .56411 Mdot
.5364 .33481 Mdot
.5356 .15232 Mdot
.38413 .68363 Mdot
.2655 .23841 Mdot
.65544 .38973 Mdot
.19126 .58868 Mdot
.42522 .25201 Mdot
.47044 .43482 Mdot
.46496 .53227 Mdot
.24826 .64577 Mdot
.57941 .51252 Mdot
.74261 .48338 Mdot
.44999 .3376 Mdot
.24107 .57246 Mdot
.59448 .68074 Mdot
.53825 .6667 Mdot
.31385 .55458 Mdot
.74849 .39411 Mdot
.81246 .40436 Mdot
.50692 .35187 Mdot
.37483 .60682 Mdot
.32943 .61212 Mdot
.55388 .47446 Mdot
.78082 .48449 Mdot
.20492 .34255 Mdot
.50743 .2122 Mdot
.45905 .36508 Mdot
.24253 .70969 Mdot
.55045 .72711 Mdot
.56853 .16251 Mdot
.54717 .3786 Mdot
.79166 .4923 Mdot
.74141 .42194 Mdot
.51317 .18717 Mdot
.55186 .30283 Mdot
.40477 .23641 Mdot
.71129 .58203 Mdot
.51014 .66903 Mdot
.76941 .53841 Mdot
.54646 .33185 Mdot
.42396 .528 Mdot
.82671 .44776 Mdot
.43273 .79179 Mdot
.60798 .2921 Mdot
.63135 .5645 Mdot
.43768 .25087 Mdot
.81129 .44858 Mdot
.52356 .334 Mdot
.6177 .66759 Mdot
.62986 .23247 Mdot
.39114 .29764 Mdot
.46717 .19507 Mdot
.39308 .36297 Mdot
.79508 .49412 Mdot
.41153 .53064 Mdot
.73373 .66221 Mdot
.63438 .38491 Mdot
.58361 .58421 Mdot
.62936 .52761 Mdot
.73433 .44876 Mdot
.50426 .59131 Mdot
.64794 .20862 Mdot
.72918 .50515 Mdot
.42445 .18967 Mdot
.55031 .16284 Mdot
.37243 .2258 Mdot
.37105 .59297 Mdot
.49311 .30191 Mdot
.28822 .22468 Mdot
.79097 .47375 Mdot
.40996 .25196 Mdot
.79004 .36945 Mdot
.82727 .59825 Mdot
.16909 .48064 Mdot
.37507 .34429 Mdot
.46721 .25901 Mdot
.73719 .27154 Mdot
.37211 .38316 Mdot
.82325 .57629 Mdot
.57255 .32243 Mdot
.41257 .28176 Mdot
.22827 .27618 Mdot
.76865 .3878 Mdot
.34081 .41513 Mdot
.55162 .27412 Mdot
.53385 .29336 Mdot
.79682 .45597 Mdot
.61274 .54936 Mdot
.41558 .65831 Mdot
.4785 .69759 Mdot
.75059 .57111 Mdot
.54456 .35895 Mdot
.806 .47073 Mdot
.78435 .50164 Mdot
.77207 .5974 Mdot
.25152 .65144 Mdot
.16986 .48053 Mdot
.51454 .25664 Mdot
.69958 .48619 Mdot
.52491 .33118 Mdot
.61516 .67799 Mdot
.72508 .63209 Mdot
.66237 .45143 Mdot
.50642 .53087 Mdot
.72057 .47781 Mdot
.41063 .1752 Mdot
.48538 .72371 Mdot
.25429 .54284 Mdot
.48712 .29647 Mdot
.4346 .24582 Mdot
.37946 .52641 Mdot
.31045 .44762 Mdot
.8024 .47112 Mdot
.47295 .24136 Mdot
.34596 .24818 Mdot
.34829 .41239 Mdot
.68992 .6214 Mdot
.63678 .75693 Mdot
.27297 .53705 Mdot
.71999 .3102 Mdot
.2699 .2599 Mdot
.37 .41163 Mdot
.43301 .32399 Mdot
.3085 .38328 Mdot
.42572 .5312 Mdot
.41379 .40877 Mdot
.32481 .43419 Mdot
.34038 .56778 Mdot
.55588 .23539 Mdot
.30365 .2573 Mdot
.3605 .69739 Mdot
.73177 .60822 Mdot
.27404 .38449 Mdot
.80642 .46696 Mdot
.55261 .47448 Mdot
.44329 .19592 Mdot
.57145 .59382 Mdot
.56685 .74456 Mdot
.66006 .47123 Mdot
.7686 .43989 Mdot
.49898 .1942 Mdot
.2943 .39679 Mdot
.70062 .55921 Mdot
.44931 .37207 Mdot
.77648 .33122 Mdot
.4434 .73568 Mdot
.42974 .74426 Mdot
.78647 .62593 Mdot
.46779 .41404 Mdot
.49867 .66563 Mdot
.23386 .49523 Mdot
.56804 .50223 Mdot
.6303 .76043 Mdot
.39691 .55494 Mdot
.71214 .2998 Mdot
.78304 .38234 Mdot
.19665 .35886 Mdot
.38747 .55228 Mdot
.78147 .33207 Mdot
.73009 .30791 Mdot
.41623 .27933 Mdot
.81121 .56193 Mdot
.59122 .56214 Mdot
.57967 .47796 Mdot
.61748 .66744 Mdot
.44453 .29607 Mdot
.21384 .335 Mdot
.7317 .52947 Mdot
.6053 .74376 Mdot
.56906 .6088 Mdot
.36861 .56915 Mdot
.34343 .71094 Mdot
.40498 .34948 Mdot
.73871 .27258 Mdot
.72786 .57176 Mdot
.3308 .4825 Mdot
.24352 .36786 Mdot
.64159 .57684 Mdot
.43272 .19314 Mdot
.51529 .60738 Mdot
.49194 .20182 Mdot
.39022 .42685 Mdot
.7209 .32523 Mdot
.57725 .17369 Mdot
.61783 .61353 Mdot
.56991 .57331 Mdot
.42976 .37821 Mdot
.57317 .55989 Mdot
.41198 .43736 Mdot
.50135 .70533 Mdot
.81063 .50638 Mdot
.17989 .41863 Mdot
.21195 .51476 Mdot
.57725 .52921 Mdot
.69438 .6696 Mdot
.28565 .27412 Mdot
.46426 .58613 Mdot
.56017 .59853 Mdot
.3001 .60388 Mdot
.40027 .75302 Mdot
.37772 .83867 Mdot
.39796 .17572 Mdot
.66131 .47291 Mdot
.5249 .57225 Mdot
.53568 .69749 Mdot
.41505 .73229 Mdot
.59095 .21752 Mdot
.21387 .33068 Mdot
.26968 .52299 Mdot
.27719 .72157 Mdot
.23405 .49642 Mdot
.63785 .1999 Mdot
.2256 .67033 Mdot
.25761 .5388 Mdot
.51934 .13801 Mdot
.32256 .40175 Mdot
.49359 .39811 Mdot
.38842 .84737 Mdot
.61571 .19373 Mdot
.74104 .43514 Mdot
.46466 .68531 Mdot
.40703 .18266 Mdot
.46421 .53013 Mdot
.45123 .63823 Mdot
.77158 .38345 Mdot
.72309 .57604 Mdot
.73557 .61213 Mdot
.25135 .49013 Mdot
.70674 .26933 Mdot
.80606 .65669 Mdot
.27689 .62774 Mdot
.26891 .75318 Mdot
.51805 .21966 Mdot
.32508 .23213 Mdot
.24718 .39875 Mdot
.46164 .79491 Mdot
.46132 .201 Mdot
.77045 .52169 Mdot
.76966 .42053 Mdot
.4973 .76556 Mdot
.61771 .61719 Mdot
.69666 .68813 Mdot
.41257 .41723 Mdot
.51991 .20646 Mdot
.25778 .64819 Mdot
.68035 .57329 Mdot
.76402 .54097 Mdot
.74268 .33544 Mdot
.57449 .57595 Mdot
.294 .24345 Mdot
.792 .46398 Mdot
.70977 .59435 Mdot
.25089 .60443 Mdot
.62103 .7062 Mdot
.23034 .31457 Mdot
.38962 .48845 Mdot
.738 .4296 Mdot
.18129 .52578 Mdot
.32043 .20516 Mdot
.59101 .56231 Mdot
.68452 .46024 Mdot
.58724 .16216 Mdot
.41271 .61568 Mdot
.78097 .3748 Mdot
.27081 .42685 Mdot
.74624 .60729 Mdot
.72247 .49796 Mdot
.63329 .51559 Mdot
.74917 .66644 Mdot
.4398 .2704 Mdot
.74332 .33202 Mdot
.22731 .65912 Mdot
.70789 .59125 Mdot
.75011 .41056 Mdot
.19568 .64386 Mdot
.54915 .37135 Mdot
.50514 .32604 Mdot
.40787 .17998 Mdot
.60098 .20536 Mdot
.74638 .45437 Mdot
.53128 .25037 Mdot
.51331 .61898 Mdot
.62168 .76144 Mdot
.71595 .41665 Mdot
.47375 .50619 Mdot
.75558 .56765 Mdot
.17307 .46651 Mdot
.69387 .2736 Mdot
.25101 .24909 Mdot
.50197 .18003 Mdot
.49898 .3023 Mdot
.76358 .37476 Mdot
.48138 .54981 Mdot
.36438 .23136 Mdot
.24083 .63254 Mdot
.23738 .64945 Mdot
.78999 .66762 Mdot
.53821 .67293 Mdot
.61456 .51131 Mdot
.37293 .43448 Mdot
.47358 .1871 Mdot
.80449 .64547 Mdot
.4656 .18774 Mdot
.73275 .45828 Mdot
.58781 .43294 Mdot
.19869 .69531 Mdot
.34294 .25866 Mdot
.57245 .44401 Mdot
.68602 .5435 Mdot
.70096 .53771 Mdot
.62206 .50543 Mdot
.3508 .47025 Mdot
.68833 .69855 Mdot
.75316 .59471 Mdot
.4261 .18569 Mdot
.46818 .28628 Mdot
.46765 .52923 Mdot
.2627 .53914 Mdot
.51619 .54514 Mdot
.53291 .44034 Mdot
.29736 .4814 Mdot
.76488 .58383 Mdot
.36662 .63869 Mdot
.63994 .72065 Mdot
.45027 .2534 Mdot
.45786 .4203 Mdot
.45792 .23723 Mdot
.79043 .57018 Mdot
.3019 .46208 Mdot
.74907 .69915 Mdot
.78605 .50696 Mdot
.67842 .39303 Mdot
.40778 .37431 Mdot
.85528 .4969 Mdot
.46352 .52195 Mdot
.35771 .45252 Mdot
.54207 .45194 Mdot
.5963 .37815 Mdot
.53937 .23877 Mdot
.54936 .67903 Mdot
.38892 .43969 Mdot
.72697 .44259 Mdot
.48079 .20946 Mdot
.32662 .50416 Mdot
.4777 .13815 Mdot
.60566 .40447 Mdot
.5935 .22759 Mdot
.42238 .21391 Mdot
.32974 .59062 Mdot
.56826 .32244 Mdot
.63528 .52876 Mdot
.5005 .63499 Mdot
.3717 .63411 Mdot
.5321 .3369 Mdot
.30901 .58319 Mdot
.32835 .24654 Mdot
.79435 .58713 Mdot
.56506 .22295 Mdot
.60673 .4777 Mdot
.56877 .67353 Mdot
.48241 .51056 Mdot
.46683 .78322 Mdot
.36172 .65629 Mdot
.39689 .31324 Mdot
.78582 .5738 Mdot
.73706 .61448 Mdot
.56237 .29098 Mdot
.34985 .19892 Mdot
.64645 .56713 Mdot
.52994 .22668 Mdot
.54457 .62242 Mdot
.34009 .35612 Mdot
.77721 .49048 Mdot
.17795 .45843 Mdot
.73587 .47972 Mdot
.62503 .5591 Mdot
.49734 .15685 Mdot
.5066 .20503 Mdot
.23631 .53733 Mdot
.39102 .25309 Mdot
.80971 .49933 Mdot
.53884 .57243 Mdot
.39715 .85641 Mdot
.2363 .6323 Mdot
.50431 .14061 Mdot
.27444 .57562 Mdot
.56532 .41981 Mdot
.44112 .39468 Mdot
.57621 .48321 Mdot
.41437 .69808 Mdot
.35478 .22993 Mdot
.42634 .37298 Mdot
.54964 .53933 Mdot
.68599 .50291 Mdot
.43151 .60475 Mdot
.52714 .3247 Mdot
.17586 .42811 Mdot
.44596 .69159 Mdot
.51078 .63691 Mdot
.20114 .52322 Mdot
.36969 .63648 Mdot
.83295 .58227 Mdot
.2833 .24279 Mdot
.36723 .27906 Mdot
.40137 .5524 Mdot
.40596 .82125 Mdot
.50685 .37586 Mdot
.49443 .27882 Mdot
.32612 .54218 Mdot
.73696 .6662 Mdot
.38634 .41099 Mdot
.18134 .49059 Mdot
.512 .1832 Mdot
.5529 .47209 Mdot
.4286 .88708 Mdot
.77516 .52238 Mdot
.48856 .59377 Mdot
.38015 .41798 Mdot
.4357 .18319 Mdot
.39463 .7706 Mdot
.6649 .20738 Mdot
.25832 .37826 Mdot
.54363 .37293 Mdot
.72008 .68866 Mdot
.24468 .71058 Mdot
.4002 .56815 Mdot
.27152 .75583 Mdot
.32966 .27743 Mdot
.68164 .68435 Mdot
.287 .39725 Mdot
.51639 .3322 Mdot
.73973 .49064 Mdot
.27491 .34386 Mdot
.60306 .56557 Mdot
.50111 .39248 Mdot
.3246 .25681 Mdot
.65784 .74239 Mdot
.234 .59602 Mdot
.36226 .25255 Mdot
.33731 .53166 Mdot
.42474 .36284 Mdot
.78965 .52284 Mdot
.40607 .62351 Mdot
.43138 .71385 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0Voooool2o`000:cooooo000Looooo`03o`00
0?oooooooooo09Oooooo0_l00002ooooo`;o0000[?ooool001cooooo00?o0000ooooooooool0Uooo
ool2o`0000Gooooo0_l00005ooooo`;o0000X_ooool001cooooo00?o0000ooooooooool0Uoooool2
o`0000Gooooo1?l00003ooooo`Co0000X?ooool001cooooo00?o0000ooooooooool0X?ooool2o`00
00Cooooo0ol0002Pooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo0_l0002Cooooo`Co00004Oooool2o`000004ooooool0
003o0000ooooo`;o0000V_ooool001cooooo00?o0000ooooooooool0T_ooool4o`0000Sooooo0_l0
0006ooooo`?o000000Coooooo`000?l0003ooooo0_l0002Jooooo`007?ooool00ol0003ooooooooo
o`29ooooo`;o00004oooool2o`0000Kooooo1Ol00005ooooo`;o0000Uoooool001cooooo00?o0000
ooooooooool0Ooooool2o`0000Sooooo0_l0000Mooooo`?o00001?ooool3o`0000?ooooo0_l00003
ooooo`?o0000S?ooool001cooooo00?o0000ooooooooool0Ooooool2o`0002kooooo0_l00004oooo
o`;o00000oooool3o`0008cooooo000Looooo`03o`000?oooooooooo0<3ooooo0_l00027ooooo`00
7?ooool00ol0003oooooooooo`2Aooooo`;o00009?ooool2o`0000Oooooo0_l00027ooooo`007?oo
ool00ol0003oooooooooo`22ooooo`;o00003Oooool2o`0002Cooooo0ol00009ooooo`;o0000Q?oo
ool001cooooo00?o0000ooooooooool0Noooool2o`000003ooooool0003o000000;ooooo0_l00004
ooooo`Co00003?ooool2o`0000Gooooo0ol0000Aooooo`;o00000oooool2o`000003ooooool0003o
000000Kooooo0_l00024ooooo`007?ooool00ol0003oooooooooo`1kooooo`;o000000Coooooo`00
0?l0003ooooo0_l00003ooooo`Ko00003?ooool2o`0000Gooooo0ol0000Aooooo`;o00000_ooool2
o`0000;ooooo0_l0002<ooooo`007?ooool00ol0003oooooooooo`1eooooo`?o00002?ooool3o`00
00?ooooo1_l0000Cooooo`;o00000_ooool2o`0001;ooooo0_l00004ooooo`;o0000R_ooool001co
oooo00?o0000ooooooooool0MOooool3o`0000Sooooo0_l00005ooooo`Go00002Oooool3o`0000?o
oooo0_l00006ooooo`;o00004oooool2o`0000?ooooo1?l00007ooooo`;o0000Ooooool001cooooo
00?o0000ooooooooool0KOooool2o`0001Oooooo0ol0000:ooooo`Go00000_ooool3o`0000Kooooo
0_l0000?ooooo`;o00000_ooool2o`0000Gooooo0_l00007ooooo`;o0000Ooooool00006ooooooo^
k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo06go
oooo0_l00006ooooo`;o00000oooool4o`0000Sooooo0_l000000ooooooo0000o`000006ooooo`Co
00001Oooool2o`0001Sooooo0_l0000<ooooo`Co0000Poooool00006oooooomgMgOoV9RHoooooonH
V9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooo
oooo07Gooooo0_l00003ooooo`Co00002oooool2o`000003ooooool0003o000000?ooooo0_l00000
1?oooooo0000o`000?l00007ooooo`Go00007oooool4o`0000?ooooo0_l0001nooooo`0000?ooooo
oa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000
ooooooooool0K_ooool2o`0000Oooooo0_l00002ooooo`;o00003oooool2o`0000Kooooo0ol00007
ooooo`Go00009Oooool5o`0007cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0006Kooooo0_l00006ooooo`;o00001oooool2o`00
00;ooooo0_l00005ooooo`;o00000_ooool2o`0000[ooooo0_l000000ooooooo0000o`000005oooo
o`;o0000:_ooool2o`000003ooooool0003o000007cooooo00000ooooooo0000ooooo`02ooooo`03
o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`1Tooooo`Co
00002Oooool2o`0000[ooooo0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o000000Oo
oooo0_l000000ooooooo0000o`000005ooooo`;o00000oooool2o`0001cooooo0_l0000>ooooo`;o
00000_ooool2o`0007Cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Rooooo`Go00000_ooool2o`0000Kooooo
0_l00009ooooo`?o00002_ooool2o`0001Gooooo0ol00002ooooo`;o00006?ooool2o`0000kooooo
0_l00002ooooo`?o0000Loooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o
^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0Goooool2o`000003ooooool0003o0000
00;o00000oooool2o`00017ooooo0_l0000Eooooo`;o00000oooool6o`0000;ooooo0ol000001?oo
oooo0000o`000?l0000Iooooo`;o00003Oooool3o`0000;ooooo0_l000000ooooooo0000o`00001`
ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
1_ooool00ol0003oooooooooo`1Nooooo`?o00000oooool2o`0000Kooooo0_l0000=ooooo`;o0000
1?ooool8o`0000Oooooo1Ol00003ooooo`Ko00000oooool2o`000003ooooool0003o000000_ooooo
0_l0000=ooooo`;o00003_ooool2o`0000Gooooo0_l0001`ooooo`007?ooool00ol0003ooooooooo
o`1Nooooo`;o00001oooool2o`0000?ooooo0_l00008ooooo`;o00000oooool2o`0000Cooooo2?l0
0007ooooo`?o00007_ooool2o`0000Wooooo0_l0002;ooooo`007?ooool00ol0003oooooooooo`1J
ooooo`;o00002oooool2o`0000gooooo0_l00004ooooo`;o00002?ooool2o`0000;ooooo0_l00002
ooooo`;o00001oooool2o`0000Oooooo0_l00003ooooo`;o00002oooool2o`0000Sooooo0_l00003
ooooo`;o0000Q_ooool001cooooo00?o0000ooooooooool0F_ooool2o`00023ooooo0_l0000<oooo
o`;o00000_ooool4o`0000Gooooo0_l00007ooooo`;o00000oooool2o`0000;ooooo0_l00007oooo
o`Co00002_ooool3o`000003ooooool0003o000008?ooooo000Looooo`03o`000?oooooooooo05[o
oooo0_l0000>ooooo`;o00002Oooool2o`000003ooooool0003o000000;ooooo0_l0000Aooooo`?o
00005_ooool3o`0000Wooooo0_l00007ooooo`;o000000?oooooo`000?l000000_ooool2o`0008?o
oooo000Looooo`03o`000?oooooooooo06[ooooo0_l00004ooooo`;o00000oooool2o`000003oooo
ool0003o000000Cooooo0_l00009ooooo`;o00005Oooool2o`0000Kooooo0_l00009ooooo`;o0000
2?ooool2o`0008[ooooo000Looooo`03o`000?oooooooooo05Wooooo0_l0000;ooooo`;o00002?oo
ool2o`000003ooooool0003o000000Wooooo0_l00009ooooo`;o00005Oooool3o`00013ooooo0_l0
000Dooooo`;o00001oooool2o`0007Gooooo000Looooo`03o`000?oooooooooo05Wooooo0_l0000;
ooooo`;o00002?ooool2o`000003ooooool0003o000000_ooooo0_l0000<ooooo`?o00003Oooool5
o`0000kooooo0_l0000Fooooo`;o00001oooool2o`0007Gooooo000Looooo`03o`000?oooooooooo
05?ooooo0_l0000<ooooo`;o00001_ooool2o`0001Gooooo0_l0000<ooooo`Go00000_ooool2o`00
00Gooooo1?l00003ooooo`;o00001_ooool2o`0000Cooooo0_l0000Oooooo`Co0000Loooool001co
oooo00?o0000ooooooooool0Doooool3o`0000;ooooo0_l00007ooooo`;o00001_ooool2o`0001Co
oooo0_l0000@ooooo`Oo00001?ooool2o`0000Gooooo0_l00006ooooo`;o00009Oooool4o`0007?o
oooo000Looooo`03o`000?oooooooooo05Cooooo0_l00002ooooo`;o00000_ooool4o`0001oooooo
0_l00007ooooo`Co00001_ooool3o`000003ooooool0003o00000;7ooooo000Looooo`03o`000?oo
oooooooo04kooooo1?l00005ooooo`;o00000oooool4o`000003ooooool0003o000000Cooooo0_l0
0004ooooo`;o00004_ooool2o`0000Gooooo1?l0000Gooooo`Co0000=oooool2o`0000?ooooo0ol0
001Sooooo`007?ooool2o`0004oooooo1_l00003ooooo`;o00002?ooool2o`0000Cooooo0_l00004
ooooo`;o00001?ooool2o`0000cooooo0_l00003ooooo`Ko00003oooool2o`0000Kooooo1?l00002
ooooo`;o00002oooool2o`0000Oooooo0_l0000Mooooo`;o00000oooool3o`000003ooooool0003o
0000063ooooo000Looooo`03o`000?oooooooooo04oooooo0_l000000ooooooo0000o`00000Coooo
o`;o00001_ooool2o`000004ooooool0003o0000o`0000Kooooo0ol00003ooooo`;o00000oooool2
o`0000;ooooo0_l00003ooooo`;o00002_ooool2o`0000Sooooo0_l00002ooooo`;o00002oooool2
o`0000Oooooo0_l0000Uooooo`?o0000H?ooool001cooooo00?o0000ooooooooool0D?ooool2o`00
00gooooo0_l00005ooooo`?o00001_ooool5o`0000;ooooo2?l00007ooooo`;o00002?ooool2o`00
00;ooooo0_l0000<ooooo`Co00006_ooool3o`00013ooooo0_l000000ooooooo0000o`000002o`00
00Kooooo0_l00005ooooo`;o0000HOooool001cooooo00?o0000ooooooooool0D?ooool2o`0000;o
oooo0_l00009ooooo`;o00000oooool4o`0000Cooooo0_l000000ooooooo0000o`000003o`0000;o
oooo1ol00008ooooo`;o00001Oooool2o`0000?ooooo1Ol0000;ooooo`Co00000_ooool2o`0001Ko
oooo0ol0000@ooooo`Oo00001_ooool2o`0006Sooooo000Looooo`03o`000?oooooooooo05Cooooo
0_l0000>ooooo`;o00000oooool2o`000003ooooool0003o000000Cooooo0ol00002ooooo`Co0000
1?ooool2o`0000Kooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000Go0000
00Coooooo`000?l0003o00001_ooool2o`0000Cooooo0_l000000ooooooo0000o`00000Wooooo`;o
00001Oooool2o`0000?ooooo1?l0001Vooooo`007?ooool00ol0003oooooooooo`19ooooo`;o0000
7_ooool2o`000003ooooool0003o000000Cooooo1ol00006ooooo`;o00001Oooool3o`000004oooo
ool0003o0000ooooo`;o000000Coooooo`000?l0003ooooo1?l000000ooooooo0000o`000003o`00
00;ooooo1?l00006ooooo`?o0000;_ooool2o`0000Gooooo0ol0001Uooooo`007?ooool00ol0003o
ooooooooo`19ooooo`;o00008Oooool2o`0000Oooooo1?l00005ooooo`;o00001_ooool4o`000003
ooooool0003o000000Kooooo0_l00003ooooo`Go00000_ooool4o`0000Kooooo0ol00003ooooo`?o
00001?ooool2o`0000Oooooo0_l0000Pooooo`Co0000I?ooool001cooooo00?o0000ooooooooool0
GOooool2o`0001Cooooo1?l00007ooooo`Co00001Oooool3o`000003ooooool0003o000000_ooooo
1?l00002ooooo`;o00002_ooool2o`0000?ooooo0ol00004ooooo`;o00000_ooool2o`0000?ooooo
0_l0000Mooooo`;o00000_ooool4o`0000Kooooo0_l0001Kooooo`007?ooool00ol0003ooooooooo
o`16ooooo`;o00004Oooool2o`0000;ooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0ol0
0002ooooo`;o00000oooool2o`000003ooooool0003o000001Gooooo0_l00005ooooo`;o00002ooo
ool2o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`0002;ooooo0_l00003ooooo`?o00001_oo
ool2o`0005_ooooo000Looooo`03o`000?oooooooooo04Kooooo0_l0000Aooooo`;o00002_ooool4
o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`Oo00000oooool3o`0000;ooooo0ol00000
1?oooooo0000o`000?l00002ooooo`;o00000_ooool2o`000004ooooool0003o0000o`0000;ooooo
0_l00002ooooo`Co00001_ooool2o`0000Cooooo0_l000001?oooooo0000o`000?l00007ooooo`;o
00001_ooool2o`00027ooooo0ol00005ooooo`;o0000G?ooool001cooooo00?o0000ooooooooool0
H?ooool2o`0000?ooooo1?l00006ooooo`;o00000_ooool7o`0000Cooooo0_l00002ooooo`?o0000
00Coooooo`000?l0003o00000_ooool2o`0000;ooooo1_l00003ooooo`;o000000?oooooo`000?l0
00000_l00006ooooo`;o00001oooool2o`0000Sooooo0_l00006ooooo`;o00007oooool4o`0000Ko
oooo0ol0001Kooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o00002Oooool2o`0000[ooooo
0_l00009ooooo`;o00000_ooool2o`0000Oooooo1?l000000ooooooo0000o`000007o`0000kooooo
0_l0000Dooooo`;o00007_ooool2o`0000Wooooo0_l0001Kooooo`007?ooool00ol0003ooooooooo
o`1Oooooo`;o00001oooool2o`000003ooooool0003o000001Cooooo0_l0000;oooooa7o00003?oo
ool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0008Kooooo000Looooo`03o`000?oooooo
oooo04Kooooo0_l0000Gooooo`;o00001oooool3o`0000[ooooo0_l00004ooooo`;o00001?ooool2
o`0000[ooooo1?l000000ooooooo0000o`000003o`0000;ooooo1_l0000@ooooo`Ko00001?ooool2
o`0000Oooooo0_l0000Eooooo`;o000000?oooooo`000?l00000Joooool001cooooo00?o0000oooo
ooooool0A_ooool2o`0000oooooo0_l0000@ooooo`;o00001?ooool2o`0000Cooooo0_l00004oooo
o`;o00000_ooool2o`0000cooooo1?l000000ooooooo0000o`000004o`0000;ooooo0_l000000ooo
oooo0000o`000002ooooo`;o00001oooool2o`0000?ooooo0ol000000ooooooo0000o`000003oooo
o`;o00001oooool3o`0001Gooooo0_l000000ooooooo0000o`00001[ooooo`007?ooool00ol0003o
ooooooooo`11ooooo`;o00001?ooool2o`0000kooooo0_l0000Fooooo`;o00002_ooool2o`0000;o
oooo0_l00009ooooo`;o000000?oooooo`000?l000003Ol000000ooooooo0000o`000007o`0000Co
oooo0_l00004ooooo`;o00001_ooool2o`0000Oooooo0_l0000Looooo`;o00002?ooool2o`0000Go
oooo0_l0001Gooooo`007?ooool2o`0004;ooooo0_l00004ooooo`;o00008Oooool2o`0000Gooooo
0_l00003ooooo`?o00000_ooool2o`0000cooooo7Ol00005ooooo`;o00000_ooool4o`0000Wooooo
1?l0000Nooooo`Co00000_ooool2o`0000?ooooo0_l00005ooooo`;o0000Eoooool001cooooo00?o
0000ooooooooool0@oooool2o`0002Gooooo0_l00005ooooo`;o00000oooool3o`0000Kooooo0_l0
0008ooooo`Co000000?oooooo`000?l000005?l00007ooooo`;o00000_ooool5o`0000Sooooo1?l0
000Nooooo`Go000000?oooooo`000?l000002oooool2o`0005Kooooo000Looooo`03o`000?oooooo
oooo04?ooooo0_l0000aooooo`;o00000_ooool4o`000003ooooool0003o000000Gooooo1Ol00000
0ooooooo0000o`00000Do`000003ooooool0003o000000Cooooo0_l00004ooooo`Go00000oooool2
o`0002Sooooo0_l0000>ooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0@oooool2o`00
02kooooo0_l00005ooooo`Co00002?oooolOo`0000?ooooo0ol0000:ooooo`Co0000;Oooool5o`00
00Sooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00003Oooool2o`0001oo
oooo0_l00008ooooo`;o00001oooool2o`0000;ooooo6Ol00002ooooo`;o000000Coooooo`000?l0
003o00002?ooool4o`0002oooooo2Ol00004ooooo`;o0000E?ooool001cooooo00?o0000oooooooo
ool0Aoooool2o`0000Wooooo0_l0000Xooooo`?o00001oooool2o`0000;ooooo3?l000000ooooooo
0000o`000009o`0000?ooooo0_l000001?oooooo0000o`000?l00008ooooo`;o00002Oooool2o`00
00;ooooo0_l0000Sooooo`;o00000_ooool4o`0005[ooooo000Looooo`03o`000?oooooooooo04Oo
oooo0_l0000cooooo`Co00002Oooool=o`000003ooooool0003o000000ko000000?oooooo`000?l0
00002_ooool3o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`0002?ooooo0ol00002ooooo`;o
0000Foooool001cooooo00?o0000ooooooooool0@oooool2o`0003Wooooo0_l00009ooooo`ko0000
00?oooooo`000?l000002ol00004ooooo`;o00002Oooool8o`000003ooooool0003o000000?ooooo
0ol0000Rooooo`?o00000_ooool2o`0005_ooooo000Looooo`03o`000?oooooooooo04?ooooo0_l0
000gooooo`;o00000_ooool2o`0000;ooooo0_l00003oooooaco00000_ooool4o`0000Wooooo1ol0
00001?oooooo0000o`000?l00004ooooo`;o00008Oooool4o`0000;ooooo0_l0001Kooooo`007?oo
ool00ol0003oooooooooo`1>ooooo`Co00007_ooool2o`0000[ooooo0_l00002ooooo`;o00000_oo
ool2o`0000?ooooo6ol00003ooooo`;o00002oooool;o`0002Oooooo1?l0001Oooooo`007?ooool0
0ol0003oooooooooo`12ooooo`;o00002_ooool4o`0001kooooo0_l00009ooooo`;o000000?ooooo
o`000?l000000_l00008oooooaoo00000oooool5o`0000Cooooo1ol0000/ooooo`;o00001?ooool2
o`000003ooooool0003o000000Gooooo1?l0001=ooooo`007?ooool00ol0003oooooooooo`0noooo
o`;o00000_ooool2o`0000[ooooo0_l0000Rooooo`;o00001oooool2o`000004ooooool0003o0000
ooooo`;o00002?oooolNo`000003ooooool0003o000000Go00001oooool2o`0000[ooooo0_l0000R
ooooo`;o00000oooool3o`000003ooooool0003o000000Gooooo1?l0001=ooooo`007?ooool00ol0
003oooooooooo`0nooooo`;o00000_ooool2o`0000Oooooo0_l000000ooooooo0000o`00000Roooo
o`;o00003Oooool2o`0000Kooooo0_l00002ooooob?o00001?ooool2o`0000[ooooo0_l00002oooo
o`;o00009oooool2o`0000;ooooo0_l00006ooooo`?o00002Oooool2o`0004;ooooo000Looooo`03
o`000?oooooooooo04_ooooo0_l000000ooooooo0000o`00000]ooooo`Co00002?ooool2o`0000;o
oooo5ol00002ooooo`Go00002Oooool3o`0000Wooooo0_l00002ooooo`;o0000:oooool3o`0000?o
oooo0_l0000<ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0?oooool2o`0001;ooooo
0_l000000ooooooo0000o`00000Nooooo`;o00001Oooool4o`0000;ooooo0_l00008oooooaGo0000
00?oooooo`000?l000004?ooool2o`0003_ooooo0_l00003ooooo`;o0000D?ooool001cooooo00?o
0000ooooooooool0?oooool2o`0000_ooooo0_l00005ooooo`;o000000?oooooo`000?l000007_oo
ool2o`0000Gooooo0ol00003ooooo`;o00001Oooool3o`000003ooooool0003o000001Go00000_oo
ool2o`0002;ooooo0_l0000Hooooo`;o000000?oooooo`000?l00000Goooool001cooooo0_l00010
ooooo`;o00002oooool2o`0000?ooooo0_l0000Tooooo`;o00001?ooool5o`0000Sooooo0ol00002
oooooaCo000000Coooooo`000?l0003ooooo0_l00005ooooo`;o00003_ooool2o`0000_ooooo0ol0
000Gooooo`;o000000?oooooo`000?l000003oooool2o`0004kooooo000Looooo`03o`000?oooooo
oooo03oooooo0_l0000@ooooo`;o000000?oooooo`000?l000006_ooool4o`0000?ooooo0_l00004
ooooo`;o000000?oooooo`000?l000002?ooool3o`0000;ooooo5?l000000ooooooo0000o`000008
ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Cooooo0_l0000<ooooo`;o0000:_ooool3
o`0004kooooo000Looooo`03o`000?oooooooooo04cooooo0_l00005ooooo`?o00005Oooool2o`00
00?ooooo1?l00009ooooo`;o00002_ooool4o`0000;ooooo3?l000000ooooooo0000o`000007o`00
00_ooooo1?l00004ooooo`;o00002_ooool2o`0000Wooooo0_l0000Eooooo`;o00002_ooool3o`00
00?ooooo0ol0001>ooooo`007?ooool00ol0003oooooooooo`0looooo`;o00003_ooool2o`0000Go
oooo0_l0000Booooo`?o000000?oooooo`000?l000007?ooool4o`0000;ooooo6?l00006ooooo`;o
000000?oooooo`000?l000000_l00004ooooo`;o00002_ooool2o`000003ooooool0003o000000?o
oooo0_l000000ooooooo0000o`00000@ooooo`;o00000oooool2o`0000[ooooo0ol00005ooooo`Co
0000Boooool001cooooo00?o0000ooooooooool0??ooool2o`0002Wooooo0ol0000Booooo`;o0000
1Oooool2o`000003ooooool0003o000000;ooooo6Ol00002ooooo`?o00001Oooool2o`0001Cooooo
0ol000000ooooooo0000o`000003ooooo`;o00004Oooool4o`0001Oooooo1?l0001;ooooo`007?oo
ool00ol0003oooooooooo`0looooo`;o0000?_ooool2o`0000Gooooo0_l000000ooooooo0000o`00
0004ooooo`?o000000?oooooo`000?l000004_l000001?oooooo0000o`000?l0000Kooooo`;o0000
6_ooool2o`0000Oooooo0_l0000Booooo`;o00002_ooool2o`0003oooooo000Looooo`03o`000?oo
oooooooo03cooooo0_l0000<ooooo`Co0000:oooool2o`0000?ooooo0_l00003ooooo`Go00001?oo
ool4o`000003ooooool0003o000000ko000000?oooooo`000?l000004_ooool2o`0000Gooooo0_l0
000Pooooo`;o00001oooool2o`0000Wooooo0ol00004ooooo`;o000000?oooooo`000?l000002Ooo
ool3o`0003kooooo000Looooo`03o`000?oooooooooo04Wooooo1Ol0000[ooooo`;o00000oooool2
o`0000Cooooo0_l00008ooooo`So000000?oooooo`000?l000002Ol0000=ooooo`;o00001Oooool2
o`0000Gooooo0_l0000@ooooo`?o00003Oooool2o`000003ooooool0003o000000oooooo0ol00004
ooooo`;o000000?oooooo`000?l000002_ooool2o`0003kooooo000Looooo`03o`000?oooooooooo
03Wooooo0_l0000=ooooo`?o00000oooool2o`0001[ooooo0_l00009ooooo`;o00000_ooool2o`00
00Kooooo0_l00004ooooo`Co00000oooool4o`0000;ooooo3ol0000:ooooo`Co00007_ooool5o`00
0003ooooool0003o000000;o00002Oooool2o`00013ooooo0_l00004ooooo`;o0000COooool001co
oooo00?o0000ooooooooool0>Oooool3o`0000cooooo0_l00004ooooo`Co00006?ooool2o`0000Wo
oooo0_l0000:ooooo`;o00001?ooool4o`0000[ooooo3_l00004ooooo`;o00001?ooool3o`0000ko
oooo0_l00007ooooo`;o000000?oooooo`000?l000001_ooool2o`000003ooooool0003o000000;o
00002Oooool2o`00013ooooo0_l00004ooooo`?o0000C?ooool001cooooo00?o0000ooooooooool0
>_ooool2o`0001?ooooo0ol0000_ooooo`Co00000oooool2o`0000_ooooo2ol000000ooooooo0000
o`000004ooooo`;o00001Oooool2o`0000[ooooo0_l00002ooooo`;o00000_ooool2o`000003oooo
ool0003o000000;o000000?oooooo`000?l000005_ooool2o`0000Oooooo0_l0000>ooooo`;o0000
C?ooool001cooooo00?o0000ooooooooool0Coooool2o`0000Cooooo0_l00009ooooo`;o00004_oo
ool3o`0000[ooooo1?l00002ooooo`;o00000_ooool2o`0000Sooooo0_l00007ooooo`;o00003_oo
ool2o`0000[ooooo0_l00006ooooo`;o000000?oooooo`000?l000000ol0000Mooooo`;o00000_oo
ool2o`0000[ooooo0_l00002ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0B_ooool2
o`0000Wooooo0_l00009ooooo`;o00004_ooool3o`00013ooooo0ol000000ooooooo0000o`000002
o`00017ooooo0_l00007ooooo`;o00000oooool4o`0000gooooo0_l00007ooooo`Co00001Oooool2
o`00017ooooo1Ol0000=ooooo`?o00000_ooool2o`0004cooooo000Looooo`03o`000?oooooooooo
04Cooooo0_l00004ooooo`;o00001Oooool2o`0003Gooooo0_l00003ooooo`;o00004Oooool6o`00
00?ooooo0_l000000ooooooo0000o`000002ooooo`;o00003Oooool6o`0000Gooooo0_l00005oooo
o`?o00001_ooool4o`0000Kooooo0ol00006ooooo`;o00001oooool3o`0000[ooooo0_l00014oooo
o`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooo
oooo00Cooooo00?o0000ooooooooool0A?ooool2o`000003ooooool0003o000000;ooooo0_l00004
ooooo`;o00005?ooool2o`000003ooooool0003o000000;ooooo0_l0000Booooo`;o00000oooool3
o`0001;ooooo0_l000000ooooooo0000o`000005o`0000?ooooo0_l000000ooooooo0000o`00000B
ooooo`Go000000?oooooo`000?l000000_l00006ooooo`Co00001Oooool7o`0000gooooo1?l00006
ooooo`;o00002_ooool2o`0004Cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ
8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0AOooool4o`0000;ooooo0_l0
0006ooooo`;o00001oooool2o`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l000001?l0
000Booooo`Co000000Coooooo`000?l0003ooooo1Ol0000=ooooo`Go00001oooool2o`0001cooooo
1Ol000000ooooooo0000o`000002ooooo`;o00001oooool2o`0000?ooooo0_l00003ooooo`;o0000
2?ooool4o`0005Sooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo1Ol0
0006ooooo`03o`000?oooooooooo03Wooooo0_l0000:ooooo`;o00001_ooool2o`0000Cooooo0_l0
0005ooooo`Co00000oooool3o`0000Sooooo1ol0000Aooooo`Co00000_ooool5o`0000[ooooo0_l0
0002ooooo`?o00000_ooool3o`0000?ooooo0_l0000Looooo`;o000000Coooooo`000?l0003ooooo
0_l00005ooooo`;o00003_ooool4o`0000Kooooo0_l0001Jooooo`0000?oooooo`000?ooool00_oo
ool00ol0003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0000iooooo`;o0000
2_ooool2o`0000Gooooo0ol00004ooooo`;o000000Goooooo`000?l0003o0000ooooo`03o`000003
ooooool0003o000000;ooooo0_l000000ooooooo0000o`000003ooooo`;o00000oooool5o`0000So
oooo0_l00006ooooo`Co00004Oooool2o`0000;ooooo0_l00003ooooo`?o0000:?ooool2o`0000Co
oooo1?l0000<ooooo`Wo00007oooool2o`0003cooooo00000ooooooo0000ooooo`02ooooo`03o`00
0?oooooooooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`15ooooo`;o
00001Oooool4o`0000?ooooo0_l000001?oooooo0000o`000?l00002ooooo`;o000000?oooooo`00
0?l000000_ooool2o`000003ooooool0003o000000;ooooo0ol00004ooooo`Co00002?ooool2o`00
00Kooooo0_l0000Cooooo`;o00009_ooool2o`0000[ooooo0ol00005ooooo`;o00000oooool2o`00
00?ooooo0_l00002ooooo`_o00005_ooool2o`0000Gooooo0_l0000looooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooooooo
ool0C_ooool2o`0000Kooooo0_l0000:ooooo`;o00000oooool6o`0000?ooooo0ol0000@ooooo`Co
0000>_ooool2o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`;o00002?ooool5o`0000;o
oooo0_l00005ooooo`;o00001?ooool3o`0001;ooooo0_l000000ooooooo0000o`000005ooooo`;o
0000??ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007oooo
o`03o`000?oooooooooo06Gooooo3Ol00002ooooo`;o00001?ooool2o`0000Oooooo1?l0000foooo
o`;o00001_ooool2o`000003ooooool0003o000000Kooooo0_l00006ooooo`Go00002Oooool4o`00
00?ooooo0_l000000ooooooo0000o`00000?ooooo`;o00002?ooool2o`0003cooooo00001_oooooo
k^k^oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`1U
ooooo`;o00000oooool8o`0000;ooooo0_l00004ooooo`;o00006?ooool2o`0002?ooooo0_l00002
ooooo`Go000000Goooooo`000?l0003o0000ooooo`02o`0000Cooooo0_l000000ooooooo0000o`00
0008ooooo`Co00001oooool2o`000004ooooool0003o0000o`0000Gooooo0_l0001Gooooo`007?oo
ool00ol0003oooooooooo`0gooooo`;o00004Oooool3o`0001cooooo1?l00003ooooo`;o00000_oo
ool2o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`;o00003_ooool4o`0002?ooooo0_l0
00000ooooooo0000o`000004o`000003ooooool0003o000000Oo000000?oooooo`000?l000000_l0
0003ooooo`;o00001?ooool5o`0000Kooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o0000
3Oooool2o`0004cooooo000Looooo`03o`000?oooooooooo03Oooooo0_l0000Aooooo`?o000000?o
ooooo`000?l000005_ooool7o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0
003o000000Gooooo1?l00003ooooo`;o00001_ooool3o`00023ooooo0_l00003ooooo`;o000000?o
ooooo`000?l000001?l000000ooooooo0000o`00000=o`0000;ooooo0_l00006ooooo`?o00001_oo
ool2o`000003ooooool0003o000000;ooooo0_l00008ooooo`;o00000oooool2o`0000Oooooo0_l0
0013ooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o00005_ooool7o`0000Gooooo1?l0000>
ooooo`;o00000oooool2o`0000Kooooo0_l0000Qooooo`;o00000oooool@o`0000;ooooo1ol0000E
ooooo`Go000000?oooooo`000?l000001oooool2o`0000cooooo0_l00005ooooo`;o0000??ooool0
01cooooo00?o0000ooooooooool0=?ooool3o`0001gooooo0_l0000Booooo`;o00000_ooool2o`00
0003ooooool0003o000000?o00001oooool2o`0003[ooooo2Ol000000ooooooo0000o`000006o`00
0003ooooool0003o000000Oo00001oooool2o`0000_ooooo1Ol000000ooooooo0000o`000002oooo
o`;o00006?ooool2o`0003cooooo000Looooo`03o`000?oooooooooo03Cooooo0ol0000Mooooo`;o
00002Oooool2o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o000000Coooooo`000?l0
003o00002Oooool4o`00027ooooo0_l0000Eooooo`Wo000000?oooooo`000?l000004?l00007oooo
o`Co00002oooool2o`000003ooooool0003o000000?ooooo0_l00005ooooo`;o00002_ooool2o`00
00Cooooo0ol0000looooo`007?ooool00ol0003oooooooooo`0eooooo`;o0000:?ooool2o`0000Co
oooo0_l000000ooooooo0000o`000002ooooo`;o00001Oooool2o`0000Oooooo0ol00002ooooo`?o
000000?oooooo`000?l000000_l00007ooooo`;o000000?oooooo`000?l000002oooool4o`0000Oo
oooo0_l00008oooooako00001oooool5o`0000Wooooo0_l00002ooooo`;o00000oooool2o`0000Co
oooo0ol0000:ooooo`?o00000oooool3o`0003cooooo000Looooo`03o`000?oooooooooo03Gooooo
0_l0000Looooo`;o00004Oooool2o`0000Cooooo0_l00005ooooo`Go00001?ooool=o`000003oooo
ool0003o000000Cooooo0_l000000ooooooo0000o`000002o`0000_ooooo0_l00007ooooo`;o0000
2?ooool4o`000003ooooool0003o000001Oo000000?oooooo`000?l000001Oooool5o`0000;ooooo
0_l00004ooooo`;o00000oooool2o`0000;ooooo0_l00004ooooo`;o00003?ooool2o`0000?ooooo
0_l0000mooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00002?ooool2o`0000Kooooo0ol0
0008ooooo`;o00000oooool3o`000003ooooool0003o000000_o00001?ooool2o`0000Oooooo1?l0
000Hooooo`;o00000oooool4o`0000?ooooo7ol000001?oooooo0000o`000?ooool3o`000003oooo
ool0003o000000;ooooo1Ol00002ooooo`;o00000_ooool2o`0000?ooooo0_l0000Booooo`;o0000
?Oooool001cooooo00?o0000ooooooooool0GOooool2o`0000Kooooo0ol00008ooooo`;o00001_oo
ool?o`0000Wooooo0_l0000Aooooo`?o00000oooool2o`0000Cooooo0_l00002ooooo`?o00001?oo
oolPo`000004ooooool0003o0000ooooo`?o00001Oooool5o`000003ooooool0003o000000Sooooo
0_l0001Aooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o00009?ooool@o`000003ooooool0
003o000000Kooooo0_l000000ooooooo0000o`00000>ooooo`Go000000?oooooo`000?l000002?oo
ool2o`000005ooooool0003o0000o`000?ooool02Ol000000ooooooo0000o`00000Go`000004oooo
ool0003o0000ooooo`Co00000oooool2o`0000;ooooo0_l0001Kooooo`007?ooool00ol0003ooooo
ooooo`0aooooo`;o00007Oooool3o`0000kooooo0ol0000Cooooo`Go000000?oooooo`000?l00000
1ol00002ooooo`;o00001_ooool7o`0000oooooo0_l00002ooooo`;o00001oooool6o`000003oooo
ool0003o000001oo00000_ooool8o`0000Kooooo0_l0000Gooooo`?o00000_ooool2o`0003kooooo
000Looooo`;o0000<_ooool2o`0001cooooo0ol00009ooooo`;o00001?ooool3o`0000_ooooo0ol0
0004ooooo`Ko000000?oooooo`000?l000001ol00002ooooo`;o00002?ooool5o`0001?ooooo1?l0
0005ooooo`?o00001OoooolQo`000003ooooool0003o000000;o000000?oooooo`000?l000001?oo
ool2o`000003ooooool0003o000000;o00005Oooool3o`0000;ooooo0_l0000nooooo`007?ooool0
0ol0003oooooooooo`0cooooo`;o00006_ooool2o`0000Sooooo1?l0000?ooooo`;o000000Cooooo
o`000?l0003o00001?ooool?o`0000_ooooo0_l000000ooooooo0000o`00000Gooooo`;o00001?oo
ool3o`0000Cooooo7ol00002ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo1?l0
0003ooooo`Co00004oooool2o`0004?ooooo000Looooo`03o`000?oooooooooo03?ooooo0_l00000
0ooooooo0000o`00000Qooooo`;o00004Oooool2o`0000Gooooo0_l000000ooooooo0000o`00000=
o`0000_ooooo0_l000000ooooooo0000o`000002o`0001Gooooo0_l00004ooooo`?o00001?oooolO
o`000003ooooool0003o000000?o00001?ooool2o`0000;ooooo0ol000000ooooooo0000o`000003
ooooo`;o00003_ooool2o`0000?ooooo0_l00003ooooo`;o0000?_ooool001cooooo00?o0000oooo
ooooool0<oooool2o`000003ooooool0003o000002Oooooo0_l00007ooooo`;o00000_ooool2o`00
00Gooooo4_l0000@ooooo`;o00004_ooool2o`0000Sooooo0_l00006ooooobWo00000oooool2o`00
0003ooooool0003o000000?ooooo0_l00006ooooo`;o00001_ooool2o`0000Sooooo0_l0000noooo
o`007?ooool00ol0003oooooooooo`0cooooo`;o000000?oooooo`000?l000009_ooool3o`000003
ooooool0003o000000Cooooo0_l00009ooooo`ko00001?ooool2o`0000gooooo0_l00002ooooo`Co
00003Oooool2o`0000Kooooo1Ol000001Ooooooo0000o`000?l0003ooooo02;o000000?oooooo`00
0?l000000_l0000Eooooo`;o00001?ooool2o`0000Gooooo0ol00012ooooo`007?ooool00ol0003o
ooooooooo`0aooooo`Oo00004_ooool2o`0000cooooo1Ol000000ooooooo0000o`000002ooooo`;o
00000_ooool2o`0000_ooooo1?l000000ooooooo0000o`000006o`0000Gooooo0_l0000=ooooo`;o
000000?oooooo`000?l000001Ol0000;ooooo`;o00001_ooool5o`000004ooooool0003o0000o`00
00;ooooo6?l000000ooooooo0000o`000008o`0001Cooooo0_l00008ooooo`;o00000oooool5o`00
04;ooooo000Looooo`03o`000?oooooooooo037ooooo1_l0000Cooooo`;o00002Oooool2o`000003
ooooool0003o000000?o000000?oooooo`000?l000001_ooool2o`0000Kooooo0_l00002ooooo`[o
000000?oooooo`000?l000001?ooool2o`0001;ooooo1?l000000ooooooo0000o`00000Dooooo`;o
00001_oooolJo`000003ooooool0003o000000Go000000Coooooo`000?l0003o00000_ooool2o`00
00oooooo0_l0000<ooooo`Go0000@oooool001cooooo00?o0000ooooooooool0<Oooool2o`000003
ooooool0003o000001_ooooo0_l00002ooooo`;o00005oooool3o`000003ooooool0003o000000Go
00001?ooool2o`000004ooooool0003o0000ooooo`Co00003Oooool4o`000003ooooool0003o0000
01Gooooo0_l00002ooooo`;o00001?ooool2o`000003ooooool0003o000001ko000000?oooooo`00
0?l000000_ooool2o`0000oooooo0_l00008ooooo`;o000000?oooooo`000?l000000_l00015oooo
o`007?ooool00ol0003oooooooooo`1Aooooo`;o00001_ooool4o`000004ooooool0003o0000oooo
o`;o00002oooool3o`0000Gooooo0_l00005ooooo`Go00000oooool2o`0000[ooooo0_l000000ooo
oooo0000o`000003o`0001Gooooo2Ol00004oooooaCo000000?oooooo`000?l000003?l000001?oo
oooo0000o`000?ooool2o`0001Wooooo0_l000000ooooooo0000o`000017ooooo`007?ooool00ol0
003oooooooooo`1?ooooo`Co00001_ooool4o`000003ooooool0003o000000?o00006?ooool5o`00
00?ooooo0_l0000<ooooo`;o000000?oooooo`000?l000001_l0000Booooo`Ko000000?oooooo`00
0?l000000_oooolUo`000003ooooool0003o000000;o00000oooool2o`0000?ooooo0_l00006oooo
o`;o00000_ooool2o`0000;ooooo0ol00008ooooo`;o00001oooool2o`0003Sooooo000Looooo`03
o`000?oooooooooo03;ooooo0ol0000Fooooo`;o00000_ooool2o`0000[ooooo2Ol00004ooooo`;o
00002_ooool2o`0000Gooooo0_l00006ooooo`;o00002_ooool4o`000003ooooool0003o000000?o
oooo1Ol00009ooooo`;o00001oooool4o`000003ooooool0003o000002Ko00000oooool3o`0000?o
oooo0_l00003ooooo`Go00000oooool2o`0000;ooooo0_l00002ooooo`?o00001_ooool4o`0000Oo
oooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00000_ooool4o`0001Gooooo
0_l00007ooooo`;o00000_oooolCo`0000Kooooo0_l000000ooooooo0000o`00000<ooooo`?o0000
2_ooool9o`0000;ooooo1?l00009ooooo`;o00001?ooool2o`000003ooooool0003o000000;ooooo
0_l000000ooooooo0000o`00000Ho`000003ooooool0003o000000So00000_ooool5o`0000Kooooo
1ol0000:ooooo`;o00002?ooool2o`0000gooooo0_l0000dooooo`007?ooool00ol0003ooooooooo
o`0^ooooo`;o00001?ooool2o`0001cooooo1?l000000ooooooo0000o`00000Bo`0000Kooooo0_l0
00000ooooooo0000o`000005ooooo`;o00000oooool4o`0000kooooo2?l000000ooooooo0000o`00
000@ooooo`Co00000oooool2o`0000?ooooo6?l000000ooooooo0000o`000008o`0000;ooooo1Ol0
0006ooooo`?o00003_ooool2o`000003ooooool0003o000000Kooooo0_l0000<ooooo`;o0000=?oo
ool001cooooo00?o0000ooooooooool0=oooool2o`0001Gooooo0_l00002oooooaKo000000?ooooo
o`000?l000004?ooool2o`0000?ooooo0_l0000@ooooo`;o00000oooool3o`000003ooooool0003o
000001;ooooo0ol00007oooooa_o00000_ooool7o`000003ooooool0003o000000;o00002_ooool2
o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo0_l00004ooooo`Co00001oooool2
o`0003Wooooo000Looooo`03o`000?oooooooooo03Oooooo0_l000000ooooooo0000o`00000<oooo
o`;o00001?ooool2o`0000Cooooo5?l0000Zooooo`;o00001oooool3o`0001;ooooo0_l00005oooo
obKo000000Coooooo`000?l0003o00002oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool3
o`000003ooooool0003o000000;o00000_ooool3o`0000;ooooo0_l00004ooooo`;o0000>Oooool0
01cooooo00?o0000ooooooooool0>_ooool2o`0000cooooo0_l0000:ooooo`?o000000?oooooo`00
0?l000003Ol0000:ooooo`;o00002oooool2o`0000Wooooo0ol00003ooooo`;o000000?oooooo`00
0?l000000oooool2o`0000;ooooo0ol0000Iooooo`;o00000ooooolFo`0000;ooooo2?l000000ooo
oooo0000o`000002o`0000Kooooo0_l0000>ooooo`;o000000?oooooo`000?l000000_ooool3o`00
00;ooooo0ol00002ooooo`;o00002?ooool2o`0003Gooooo000Looooo`;o0000>oooool2o`0000co
oooo0_l000000ooooooo0000o`000004ooooo`;o00000_oooolDo`0000Sooooo0_l00008ooooo`;o
000000?oooooo`000?l000002Oooool4o`0000;ooooo0_l00006ooooo`;o00000_ooool3o`0000Go
oooo0_l0000Booooo`;o00001?oooolRo`0000Sooooo0_l00003ooooo`;o00002Oooool2o`000003
ooooool0003o000000?o00001?ooool3o`0000cooooo0_l0000eooooo`007?ooool00ol0003ooooo
ooooo`0jooooo`;o00003?ooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000
o`00000Eo`0000Cooooo0_l0000:ooooo`;o00003_ooool2o`0000;ooooo0_l00003ooooo`Co0000
0_ooool4o`0000Gooooo0_l0000=ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000
o`000002ooooob3o00003?ooool4o`0000gooooo1?l00004ooooo`?o0000@oooool001cooooo00?o
0000ooooooooool0B?ooool2o`0000Oooooo6ol00003ooooo`?o00002oooool2o`0000gooooo0_l0
0005ooooo`Go000000?oooooo`000?l000000ol00005ooooo`;o00001_ooool2o`0000Cooooo0ol0
00000ooooooo0000o`000006o`0000?ooooo7Ol0000<ooooo`?o00004?ooool5o`0000;ooooo0ol0
000<ooooo`;o0000=Oooool001cooooo00?o0000ooooooooool0DOoooolKo`0000Cooooo0_l00009
ooooo`Co00003Oooool2o`0000Gooooo0_l000001?oooooo0000o`000?ooool6o`0000Wooooo0_l0
00000ooooooo0000o`000004ooooo`;o00001Oooool7o`000003ooooool0003o000000_o00001?oo
ool<o`0000cooooo0ol0000@ooooo`;o000000?oooooo`000?l000000_ooool2o`0000gooooo0_l0
000eooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00004ooooolFo`00017ooooo0_l00002
ooooo`;o00003?ooool2o`0000?ooooo0_l00005ooooo`Ko00002Oooool2o`0000Oooooo0_l00004
oooooaGo00000_ooool>o`0000Cooooo0_l00008ooooo`;o00003oooool3o`0004_ooooo000Loooo
o`03o`000?oooooooooo03oooooo1?l0000?oooooaWo00005?ooool2o`0000cooooo0_l00003oooo
o`Co00001?ooool4o`0000[ooooo0_l00002ooooo`Co00001OoooolRo`000003ooooool0003o0000
00;o00001?ooool2o`0001Wooooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o
00001oooool2o`0000;ooooo0_l0000;oooooa_o00001?ooool2o`0000oooooo0_l00006ooooo`;o
000000?oooooo`000?l000001Oooool2o`0000;ooooo0_l000001?oooooo0000o`000?l00003oooo
o`;o00001_ooool7o`0000?ooooo2Ol000000ooooooo0000o`000002o`0000;ooooo4Ol000000ooo
oooo0000o`000002o`000003ooooool0003o000006gooooo000Looooo`03o`000?oooooooooo03So
oooo0_l00004ooooo`;o00000_ooool5o`0000[ooooo7Ol00003ooooo`;o00002Oooool2o`0000Co
oooo0ol00004ooooo`?o00001oooool3o`0000;ooooo0_l000001?oooooo0000o`000?l00003oooo
o`;o00001_ooool4o`0000Cooooo1?l000000ooooooo0000o`000009o`0000;ooooo2_l000000ooo
oooo0000o`000004o`0000;ooooo0ol0000Mooooo`Ko000000?oooooo`000?l00000B_ooool001co
oooo00?o0000ooooooooool0=oooool2o`0000Gooooo0_l00002ooooo`?o00002OoooolPo`0000[o
oooo0_l00002ooooo`;o00001?ooool3o`0000Cooooo1?l000001?oooooo0000o`000?l00002oooo
o`;o00001_ooool3o`0000Sooooo0ol000000ooooooo0000o`000002ooooo`;o000000?oooooo`00
0?l000001oooool6o`0000?ooooo2_l000000ooooooo0000o`000002o`0000;ooooo1?l0000<oooo
o`;o00004?ooool6o`000003ooooool0003o000004[ooooo000Looooo`03o`000?oooooooooo03Oo
oooo0_l00009ooooo`;o00001Oooool2o`0000?ooooo6_l00002ooooo`;o00003?ooool2o`0000co
oooo0_l00003ooooo`Ko00000oooool2o`0000Gooooo0ol00003ooooo`;o00000oooool6o`0000;o
oooo1?l00006ooooo`;o00000_ooool:o`000003ooooool0003o000000Ko00001Oooool3o`0000go
oooo0_l000001?oooooo0000o`000?ooool2o`0005gooooo000Looooo`03o`000?oooooooooo04;o
oooo0_l00005ooooo`;o00001Oooool2o`000003ooooool0003o000001Oo00005_ooool3o`000003
ooooool0003o000000;o00000_ooool2o`0000Gooooo0ol00005ooooo`Co00000_ooool2o`0000?o
oooo1Ol00005ooooo`;o00001_ooool2o`0000Cooooo1_l000000ooooooo0000o`000002ooooo`Ko
00000oooool4o`0000_ooooo0_l00003ooooo`?o000000?oooooo`000?l000003?ooool2o`0004oo
oooo000Looooo`03o`000?oooooooooo03oooooo0_l0000?ooooo`;o00000_oooolHo`0001Kooooo
0ol00002ooooo`?o00001Oooool2o`0000;ooooo0_l00004ooooo`Ko00000_ooool2o`0000?ooooo
0_l0000Eooooo`Ko00000_ooool3o`000003ooooool0003o000000;ooooo2?l0000:ooooo`Co0000
0_ooool3o`0000Sooooo0ol00005ooooo`;o0000Coooool001cooooo00?o0000ooooooooool0?Ooo
ool4o`0000Gooooo1Ol00005oooooaCo00000oooool2o`0000;ooooo0_l0000Dooooo`;o00003?oo
ool2o`0000?ooooo0_l00002ooooo`Ko00003?ooool2o`0000Wooooo0_l00006ooooo`_o000000?o
ooooo`000?l000000oooool6o`0000_ooooo0ol00003ooooo`;o00000_ooool2o`0000Gooooo0ol0
0003ooooo`Co0000Coooool001cooooo00?o0000ooooooooool0>oooool4o`0000Oooooo1Ol00005
oooooaKo00001Oooool3o`0001?ooooo0_l00004ooooo`Go000000?oooooo`000?l000001?l00000
0ooooooo0000o`000002ooooo`_o00000oooool6o`0000?ooooo0_l00004ooooo`?o00001ooooolB
o`0000kooooo0ol00007ooooo`;o00001Oooool2o`0000;ooooo1_l0001?ooooo`007?ooool00ol0
003oooooooooo`0kooooo`;o00003_ooool3o`000003ooooool0003o000000?o000000?oooooo`00
0?l000004Ol00004ooooo`;o00002_ooool2o`0000gooooo1Ol000000ooooooo0000o`000002oooo
o`;o00002?ooool8o`0000;ooooo1Ol00003ooooo`Co00001Oooool2o`0000Oooooo1Ol00002oooo
o`ko00001oooool2o`000003ooooool0003o000000gooooo0_l000001?oooooo0000o`000?ooool5
o`00057ooooo000Looooo`03o`000?oooooooooo04?ooooo0_l00006ooooo`?o000000?oooooo`00
0?l000001?ooool@o`000003ooooool0003o000000Cooooo0_l00007ooooo`;o000000?oooooo`00
0?l000001Oooool2o`000003ooooool0003o000000?ooooo1Ol0000>ooooo`Co00001_ooool4o`00
0003ooooool0003o000000;ooooo0_l0000@ooooo`Go00001?ooool7o`0000;ooooo0ol00007oooo
o`;o000000?oooooo`000?l000003Oooool2o`0000Cooooo0ol0001Cooooo`007?ooool2o`0004Co
oooo0_l00008ooooo`;o00001_ooool;o`0000;ooooo0ol00006ooooo`;o000000?oooooo`000?l0
00001Oooool3o`0000Oooooo0_l000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l0
00002_ooool6o`0000Gooooo0_l00003ooooo`Go00003?ooool2o`0000?ooooo3?l00008ooooo`;o
00001oooool2o`0000Gooooo0_l0000?ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0
=Oooool2o`0001Kooooo0_l00004ooooo`Co000000?oooooo`000?l000001Ol0000<ooooo`;o0000
00Coooooo`000?l0003o00001Oooool2o`0000;ooooo0_l00003ooooo`;o00001oooool4o`000004
ooooool0003o0000ooooo`;o00001oooool2o`000004ooooool0003o0000o`0000_ooooo1?l00009
ooooo`;o000000?oooooo`000?l000001oooool8o`0000Sooooo0_l00007ooooo`Go000000?ooooo
o`000?l000000ol0001Rooooo`007?ooool00ol0003oooooooooo`0eooooo`;o00002Oooool2o`00
017ooooo1ol00002ooooo`?o000000?oooooo`000?l000000_l00003ooooo`?o000000?oooooo`00
0?l000000_ooool2o`0000Oooooo1?l000000ooooooo0000o`000002o`0000Oooooo0_l00006oooo
o`;o00003Oooool2o`000003ooooool0003o000000;o00001Oooool2o`0000[ooooo0_l0000>oooo
o`?o00003oooool2o`000003ooooool0003o000000?o000000Coooooo`000?l0003ooooo0_l0000=
ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0@?ooool5o`0000kooooo1Ol00008oooo
o`Co00000oooool3o`000004ooooool0003o0000o`0000Kooooo0_l00002ooooo`Co000000?ooooo
o`000?l000000_ooool2o`0000Gooooo0_l0000Eooooo`;o000000?oooooo`000?l000000_l00005
ooooo`?o00000oooool2o`0000?ooooo0_l00009ooooo`;o000000Coooooo`000?l0003ooooo1_l0
000<ooooo`;o00000_ooool2o`000003ooooool0003o000000gooooo0_l00003ooooo`;o0000Dooo
ool001cooooo00?o0000ooooooooool0@_ooool3o`0000Gooooo0_l00008ooooo`Co000000Cooooo
o`000?l0003o00001?ooool2o`0000[ooooo0_l00006ooooo`;o00001?ooool2o`0000Gooooo0_l0
0005ooooo`?o00005?ooool2o`0000Wooooo1?l00003ooooo`;o00000oooool2o`0000;ooooo1?l0
0003ooooo`Go000000?oooooo`000?l000001?l0000=ooooo`?o00000oooool2o`0000Kooooo1?l0
0003ooooo`Go00003_ooool4o`0004?ooooo000Looooo`03o`000?oooooooooo03Cooooo0_l0000:
ooooo`;o00002?ooool2o`000003ooooool0003o000000Gooooo1?l000001?oooooo0000o`000?l0
0007ooooo`?o00003_ooool2o`0000_ooooo0_l00006ooooo`;o00007oooool3o`0000?ooooo0_l0
0008ooooo`Go000000?oooooo`000?l000000_l00005ooooo`;o00002?ooool4o`0000?ooooo0ol0
0007ooooo`;o00000_ooool4o`0000?ooooo1Ol0000>ooooo`Co0000@oooool001cooooo00?o0000
ooooooooool0=?ooool2o`0000[ooooo0_l0000;ooooo`;o00001Oooool4o`000004ooooool0003o
0000o`0000Oooooo0ol00005ooooo`;o00001oooool2o`0000Sooooo0_l000000ooooooo0000o`00
0003o`000003ooooool0003o000000Gooooo0_l0000Jooooo`Co00000_ooool4o`0000Kooooo0_l0
00001?oooooo0000o`000?ooool2o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`;o0000
0oooool8o`0000Wooooo0ol00007ooooo`Ko00004Oooool4o`00043ooooo000Looooo`03o`000?oo
oooooooo03oooooo1?l00008ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o00000_oo
ool3o`0000oooooo0_l00002ooooo`;o00000oooool2o`0000Sooooo0_l000000ooooooo0000o`00
0003o`000003ooooool0003o000000Gooooo0_l0000Gooooo`;o00000_ooool3o`0000Cooooo1?l0
0008ooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000000ol0
0004ooooo`Co00002_ooool2o`0000;ooooo0_l00002ooooo`Oo00002Oooool2o`0000Kooooo1?l0
0010ooooo`007?ooool00ol0003oooooooooo`0kooooo`;o00000_ooool4o`0000Sooooo0_l00000
0ooooooo0000o`000002o`0000?ooooo0_l0000Eooooo`;o000000?oooooo`000?l000003Oooool2
o`000003ooooool0003o000000Cooooo1?l0000Looooo`;o00000_ooool2o`0000;ooooo0_l00000
0ooooooo0000o`000004o`0000Kooooo0_l00002ooooo`;o00001oooool2o`0000;ooooo1?l00006
ooooo`;o00000oooool4o`0000;ooooo0_l000000ooooooo0000o`000003o`000004ooooool0003o
0000ooooo`;o00002Oooool4o`000003ooooool0003o000000;ooooo0_l00013ooooo`007?ooool0
0ol0003oooooooooo`0kooooo`;o00000_ooool2o`0000_ooooo0_l000001?oooooo0000o`000?oo
ool2o`000003ooooool0003o000000Wooooo0_l00009ooooo`?o00001oooool2o`0000Kooooo0ol0
0008ooooo`?o00007?ooool2o`0000Kooooo0_l00003ooooo`Go00005?ooool2o`0000[ooooo0_l0
0003ooooo`Co00000_ooool2o`000003ooooool0003o000000?o00003oooool2o`0000?ooooo0_l0
0002ooooo`;o00000_ooool2o`0003oooooo000Looooo`03o`000?oooooooooo03_ooooo0_l00002
ooooo`Co00002Oooool2o`000004ooooool0003o0000ooooo`;o00003?ooool4o`0000?ooooo0_l0
0002ooooo`;o00002?ooool2o`0000Kooooo0_l00006ooooo`?o000000?oooooo`000?l000001Ooo
ool2o`0000Wooooo0_l0000Jooooo`;o00003_ooool2o`0000Cooooo0_l0000Hooooo`Go000000?o
ooooo`000?l000006Oooool2o`0003oooooo000Looooo`03o`000?oooooooooo047ooooo0_l00009
ooooo`;o000000Coooooo`000?l0003ooooo0_l00005ooooo`;o00001_ooool4o`0000;ooooo0ol0
000<ooooo`;o000000Coooooo`000?l0003o00002Oooool3o`0000;ooooo0_l00004ooooo`;o0000
00?oooooo`000?l000001_ooool2o`0000?ooooo0_l0000Eooooo`Go00002oooool4o`0001Kooooo
1?l00003ooooo`;o00000oooool4o`0000Cooooo0_l0000Dooooo`;o0000??ooool001cooooo00?o
0000ooooooooool0??ooool2o`0001_ooooo0_l00006ooooo`Co00000oooool2o`0000cooooo0_l0
00001?oooooo0000o`000?l00002ooooo`;o00002_ooool4o`0000;ooooo1Ol0000;ooooo`;o0000
1_ooool2o`0000cooooo0_l000001?oooooo0000o`000?l0000:ooooo`;o000000?oooooo`000?l0
00003_ooool2o`0000Kooooo1Ol00009ooooo`;o00001?ooool2o`0000;ooooo0_l00003ooooo`Co
00002Oooool2o`0003cooooo000Looooo`03o`000?oooooooooo03Wooooo1Ol00002ooooo`;o0000
5_ooool2o`0000gooooo0_l00002ooooo`;o00000oooool2o`0000Cooooo0_l00003ooooo`;o0000
00?oooooo`000?l000003?ooool2o`0000;ooooo1Ol0000Cooooo`?o00002oooool2o`0000?ooooo
1?l00007ooooo`;o00004Oooool2o`0000Oooooo1?l0000Cooooo`;o00000oooool4o`000003oooo
ool0003o000000;ooooo0_l00010ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o
8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0>Oooool3o`00
00Cooooo0_l0000Fooooo`;o00003Oooool6o`0000?ooooo0_l00003ooooo`;o00001?ooool2o`00
00kooooo0ol00002ooooo`Go00001_ooool2o`0000?ooooo0_l00007ooooo`;o00002oooool2o`00
00?ooooo1Ol0000Pooooo`Co00004_ooool2o`0000_ooooo0_l00002ooooo`;o0000@?ooool00006
oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q
8@06ooooo`03o`000?oooooooooo04Sooooo0_l00003ooooo`;o00004?ooool2o`0000Cooooo0_l0
00000ooooooo0000o`000003o`000003ooooool0003o000000;ooooo1Ol0000Dooooo`[o00001_oo
ool2o`0000?ooooo0_l0000Dooooo`?o00001Oooool4o`0001Gooooo0_l00004ooooo`;o000000Co
ooooo`000?l0003ooooo0_l0000<ooooo`;o00000oooool3o`0000Gooooo0ol00018ooooo`0000?o
oooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`10ooooo`;o00001_ooool2o`0000?ooooo0_l00008ooooo`;o0000
00Coooooo`000?l0003ooooo1?l00004ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o
00000_ooool3o`0001Wooooo1Ol0000=ooooo`?o00003oooool2o`0000?ooooo0_l00004ooooo`;o
000000?oooooo`000?l000000_l0000Cooooo`;o00001?ooool2o`0000Cooooo0_l0000:ooooo`Co
00001?ooool2o`0000?ooooo1Ol00008ooooo`;o0000?_ooool00003ooooool0003ooooo00;ooooo
00?o0000ooooooooool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0000oooooo`?o
00005Oooool2o`000004ooooool0003o0000ooooo`Co00001oooool2o`0000Gooooo1_l00004oooo
o`;o00004_ooool2o`0000Cooooo0_l0000<ooooo`;o00003oooool2o`0000Wooooo0_l00002oooo
o`?o00004Oooool2o`0001Sooooo0_l0000;ooooo`;o00002oooool2o`0003kooooo00000ooooooo
0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006oooo
o`03o`000?oooooooooo03oooooo0_l00002ooooo`;o00002Oooool2o`0000kooooo0ol0000>oooo
o`Co00001_ooool2o`0000cooooo0ol00003ooooo`Co00000_ooool2o`0002Cooooo0_l000000ooo
oooo0000o`000003ooooo`;o000000Coooooo`000?l0003o00003Oooool3o`0000Oooooo0ol0000=
ooooo`;o00002_ooool4o`0000Gooooo0_l00002ooooo`;o0000@?ooool00003ooooool@413ooooo
00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo
04?ooooo0_l00009ooooo`;o00003_ooool2o`0001Kooooo1?l00004ooooo`;o00001oooool3o`00
00?ooooo1?l00003ooooo`;o00003_ooool2o`0000oooooo0_l00002ooooo`;o000000?oooooo`00
0?l000001_ooool;o`0000?ooooo1Ol00007ooooo`?o00001_ooool2o`000003ooooool0003o0000
00;ooooo0ol00009ooooo`;o00001Oooool4o`0000;ooooo0_l00010ooooo`0000KoooooogMgMonH
V9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0Aoooool2
o`0001kooooo0_l0000=ooooo`Co00001?ooool2o`0000gooooo1?l00003ooooo`;o00003_ooool2
o`0000oooooo0_l00004ooooo`;o00002OoooolAo`00013ooooo0_l000001?oooooo0000o`000?l0
0002ooooo`;o00004?ooool2o`000003ooooool0003o000004?ooooo00001_ooooook^k^oc8b<_l0
003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`17ooooo`;o
00007_ooool2o`0001Gooooo0_l00002ooooo`;o00001Oooool2o`0000;ooooo1?l0000Tooooo`;o
00000oooool3o`0000Sooooo0_l00006ooooo`Ko00006?ooool3o`000003ooooool0003o000001?o
oooo0_l00013ooooo`007?ooool00ol0003oooooooooo`11ooooo`;o00002_ooool2o`0003?ooooo
0_l00005ooooo`So000000?oooooo`000?l000003oooool2o`00013ooooo0_l00003ooooo`;o0000
2Oooool2o`0000Sooooo0ol0000Cooooo`;o00001Oooool2o`0001Gooooo0_l00014ooooo`007?oo
ool00ol0003oooooooooo`11ooooo`Co00002?ooool2o`0001Kooooo0_l0000Tooooo`;o000000Go
ooooo`000?l0003o0000ooooo`04o`0000gooooo0_l00003ooooo`;o00005Oooool2o`0000Cooooo
0_l0000Eooooo`;o00001oooool2o`0001Oooooo0_l00003ooooo`;o0000A?ooool001cooooo00?o
0000ooooooooool0@Oooool4o`0000;ooooo0_l00004ooooo`;o00005_ooool2o`0001Wooooo0_l0
000<ooooo`?o00000oooool2o`0001;ooooo0_l00003ooooo`;o00004?ooool2o`0000[ooooo0_l0
0004ooooo`;o00002Oooool2o`0000Oooooo0_l000000ooooooo0000o`00000Dooooo`;o00000ooo
ool2o`0004Cooooo000Looooo`03o`000?oooooooooo04Oooooo0_l0000<ooooo`?o00009_ooool4
o`0000gooooo1Ol0000Iooooo`;o00007?ooool2o`0000?ooooo0ol00002ooooo`Co00003?ooool2
o`000003ooooool0003o000001;ooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`17oooo
o`?o00002oooool3o`0002Kooooo0_l0000@ooooo`Co00006_ooool2o`0000cooooo0_l0000Boooo
o`?o000000?oooooo`000?l000000ol0000<ooooo`;o00003oooool2o`0000Cooooo0_l0001;oooo
o`007?ooool00ol0003oooooooooo`11ooooo`Co00000_ooool6o`0000kooooo0_l0000Hooooo`;o
00009oooool2o`0000kooooo0_l0000:ooooo`Co00001?ooool2o`0000Wooooo0ol000001?oooooo
0000o`000?ooool2o`0000Wooooo0_l00004ooooo`;o000000?oooooo`000?l000003?ooool2o`00
00Gooooo0_l00003ooooo`;o0000AOooool001cooooo00?o0000ooooooooool0@Oooool5o`0000?o
oooo1Ol0000=ooooo`;o00005oooool3o`0001[ooooo0_l0000;ooooo`?o000000?oooooo`000?l0
00001Oooool2o`0000[ooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000;o
oooo0_l00009ooooo`Co00003_ooool2o`0000Cooooo1Ol0000Cooooo`;o00000oooool2o`0004Go
oooo000Looooo`03o`000?oooooooooo04Cooooo0_l00006ooooo`;o00009Oooool3o`0000[ooooo
0_l0000=ooooo`Co00003?ooool2o`000003ooooool0003o000000Gooooo0_l0000:ooooo`;o0000
00?oooooo`000?l000001?ooool2o`0000oooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o
00003_ooool4o`0000[ooooo0_l00005ooooo`;o00001Oooool2o`0004Gooooo000Looooo`03o`00
0?oooooooooo04?ooooo0_l00003ooooo`;o00002?ooool2o`0001oooooo0_l00007ooooo`;o0000
0_ooool2o`0000gooooo0_l00005ooooo`;o00002_ooool2o`0000Cooooo0_l0000;ooooo`;o0000
2_ooool2o`0000cooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00001oooool2o`0000Go
oooo1?l0000:ooooo`;o00001?ooool3o`0000Gooooo0_l00015ooooo`007?ooool00ol0003ooooo
ooooo`0looooo`;o00001Oooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`0000?ooooo
1?l0000Vooooo`Co00000_ooool4o`00013ooooo0_l00007ooooo`;o000000?oooooo`000?l00000
1?ooool2o`0000Cooooo0_l00005ooooo`;o00002_ooool2o`0000cooooo1?l0000<ooooo`;o0000
4_ooool2o`0000Gooooo0_l00006ooooo`;o0000AOooool001cooooo00?o0000ooooooooool0??oo
ool2o`0000Wooooo2?l000000ooooooo0000o`000002ooooo`;o00009_ooool4o`0000;ooooo1?l0
000:ooooo`Co00002oooool2o`0000cooooo0ol0000Mooooo`;o00000_ooool4o`0000?ooooo0_l0
0005ooooo`;o00004Oooool3o`0000gooooo0_l00015ooooo`007?ooool2o`0003gooooo0_l00009
ooooo`_o00007_ooool2o`0000;ooooo0_l00002ooooo`;o00000_ooool3o`000003ooooool0003o
000000?ooooo1?l00007ooooo`Co00006Oooool2o`0000;ooooo0_l0000Fooooo`;o00000_ooool3
o`0000?ooooo0_l00003ooooo`;o00001Oooool2o`00017ooooo0_l00003ooooo`;o0000D?ooool0
01cooooo00?o0000ooooooooool0@Oooool2o`0000Kooooo1?l000000ooooooo0000o`00000Ooooo
o`?o00000_ooool2o`000004ooooool0003o0000o`0000?ooooo3?l0000Xooooo`;o00003?ooool2
o`0000Sooooo0ol00002ooooo`;o00009_ooool3o`00053ooooo000Looooo`03o`000?oooooooooo
047ooooo0_l00006ooooo`;o00000_ooool2o`00023ooooo0_l000000ooooooo0000o`000002o`00
0003ooooool0003o000000?ooooo2Ol00002ooooo`Go00002?ooool2o`0000Cooooo0_l00009oooo
o`;o000000?oooooo`000?l000001oooool2o`0000cooooo0_l00009ooooo`;o0000:_ooool2o`00
00[ooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`16ooooo`;o00001Oooool3o`000003
ooooool0003o000001oooooo0ol00002ooooo`;o000000?oooooo`000?l000004?l00008ooooo`;o
00001?ooool2o`0000Sooooo0ol000000ooooooo0000o`00000:ooooo`;o00005?ooool2o`000004
ooooool0003o0000ooooo`Co00000oooool3o`0000Oooooo0_l0000Fooooo`;o00001oooool2o`00
04Gooooo000Looooo`03o`000?oooooooooo04Kooooo0ol00005ooooo`Go00007Oooool2o`0000;o
oooo1?l000000ooooooo0000o`000006o`000003ooooool0003o000000Ko00000oooool2o`0001Go
oooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o00003Oooool2o`00
00Gooooo0_l000001?oooooo0000o`000?ooool4o`0000?ooooo1Ol00005ooooo`;o00002?ooool2
o`0000cooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`16ooooo`?o00001_ooool2o`00
01oooooo0_l000000ooooooo0000o`00000Jo`0000Kooooo0_l00007ooooo`;o00001?ooool3o`00
0004ooooool0003o0000ooooo`;o000000?oooooo`000?l000002Oooool?o`0000Oooooo0_l00000
0ooooooo0000o`000003o`0000?ooooo0_l00003ooooo`;o00002_ooool3o`0000;ooooo0_l00002
ooooo`;o00001oooool2o`0004[ooooo000Looooo`03o`000?oooooooooo03kooooo0_l00006oooo
o`;o0000:oooool2o`000003ooooool0003o000001Ko00001oooool2o`0000Oooooo0_l000001Ooo
oooo0000o`000?l0003ooooo00;o00001?ooool2o`0000?ooooo0_l00002ooooo`Co000000?ooooo
o`000?l000002Ol000001?oooooo0000o`000?l00007ooooo`;o00000_ooool8o`0000?ooooo0ol0
000;ooooo`;o00000_ooool2o`0000;ooooo0_l00007ooooo`;o0000B_ooool001cooooo00?o0000
ooooooooool0>_ooool2o`0000;ooooo0_l00006ooooo`;o0000;_oooolIo`000003ooooool0003o
000000cooooo0_l000001?oooooo0000o`000?l00007ooooo`Co000000?oooooo`000?l000005?l0
0003ooooo`;o00002Oooool7o`0000?ooooo0_l00003ooooo`;o0000I?ooool001cooooo00?o0000
ooooooooool0>_ooool3o`0003Wooooo7?l00007ooooo`Go00003Oooool4o`000003ooooool0003o
000000;o000000?oooooo`000?l000004?l00002ooooo`;o00002Oooool7o`0000;ooooo0ol00003
ooooo`;o00004oooool2o`0004oooooo000Looooo`03o`000?oooooooooo03_ooooo0_l0000Hoooo
o`;o00006Oooool2o`0000?ooooo2ol000000ooooooo0000o`000005o`000003ooooool0003o0000
00;o000000?oooooo`000?l000002Oooool5o`0000cooooo1?l000000ooooooo0000o`000003o`00
00?ooooo4?l000000ooooooo0000o`000002ooooo`?o00000_ooool5o`0000Oooooo0ol0000Hoooo
o`;o0000Coooool001cooooo00?o0000ooooooooool0EOooool2o`0001Oooooo1?l00002oooooaCo
000000?oooooo`000?l000000_l000000ooooooo0000o`000006ooooo`;o00003?ooool2o`0000Co
oooo1?l000000ooooooo0000o`000002o`000003ooooool0003o0000013o00000_ooool2o`0000;o
oooo0ol00002ooooo`Co00008_ooool2o`00053ooooo000Looooo`03o`000?oooooooooo06kooooo
0ol00003oooooaCo000000?oooooo`000?l000000ol00005ooooo`;o000000?oooooo`000?l00000
0oooool2o`000003ooooool0003o000000Cooooo0_l00009ooooo`Co000000?oooooo`000?l00000
4ol00008ooooo`?o00000_ooool2o`0000;ooooo0_l00002ooooo`;o00005oooool2o`00053ooooo
000Looooo`03o`000?oooooooooo04Wooooo0_l0000Tooooo`;o00000_oooolLo`0000Cooooo0_l0
0006ooooo`;o000000?oooooo`000?l000002oooool2o`0000;ooooo1?l000000ooooooo0000o`00
000Do`0000Sooooo0_l00002ooooo`?o000000?oooooo`000?l000000_ooool2o`0000Kooooo0_l0
001Qooooo`007?ooool00ol0003oooooooooo`17ooooo`Co0000:?ooool4o`000003ooooool0003o
000001Go000000?oooooo`000?l000006Oooool2o`0000?ooooo5ol000000ooooooo0000o`00000=
ooooo`;o00001Oooool2o`0000Kooooo0_l0000;ooooo`;o0000E?ooool001cooooo00?o0000oooo
ooooool0?Oooool2o`0000Sooooo0_l0000Xooooo`;o000000?oooooo`000?l000006Ol000000ooo
oooo0000o`00000PoooooaGo00004?ooool2o`0000?ooooo1?l00003ooooo`;o00003?ooool4o`00
05Cooooo000Looooo`03o`000?oooooooooo03gooooo0_l0000booooo`;o000000?oooooo`000?l0
00005_l00002ooooo`?o00001oooool2o`00013ooooo0_l00002ooooo`;o00000_oooolEo`0000Co
oooo0_l0000:ooooo`;o00000oooool4o`0000?ooooo0_l00008ooooo`;o00000_ooool4o`0005Co
oooo000Looooo`;o0000L_oooolPo`0000Oooooo0_l0000@ooooo`Ko00000oooool<o`000003oooo
ool0003o000000Co00000_ooool2o`000003ooooool0003o000000gooooo1ol0000<ooooo`Go0000
Eoooool001cooooo00?o0000ooooooooool0L_oooolLo`000003ooooool0003o000001_ooooo0_l0
0004oooooaGo000000Coooooo`000?l0003ooooo0_l0000=ooooo`;o000000?oooooo`000?l00000
0_l00004ooooo`?o00001oooool3o`0005Oooooo000Looooo`03o`000?oooooooooo07;ooooo6ol0
000>ooooo`;o00000_ooool2o`0000_ooooo0_l00004oooooaKo00000oooool2o`00013ooooo1?l0
0003ooooo`Co00001oooool2o`0005Sooooo000Looooo`03o`000?oooooooooo04_ooooo0ol0000N
ooooo`;o00001?oooolBo`000003ooooool0003o000000Oo00003Oooool2o`0000;ooooo0_l0000;
ooooo`;o00000_oooolHo`0001Gooooo1_l000001?oooooo0000o`000?l0001Rooooo`007?ooool0
0ol0003oooooooooo`1;ooooo`Co00007Oooool2o`0000Cooooo0ol000000ooooooo0000o`00000<
o`000003ooooool0003o000000Oo00001_ooool2o`0001Sooooo1?l000000ooooooo0000o`00000A
o`0001Sooooo1Ol0001Vooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00009_oooolIo`00
00Kooooo0_l0000Gooooo`Co00000_oooolCo`0000Kooooo0_l0001kooooo`007?ooool00ol0003o
ooooooooo`1_ooooo`;o00001?oooolDo`000003ooooool0003o000000;o00001_ooool2o`0001Oo
oooo1?l00002oooooa;o00001oooool2o`0001Sooooo0_l0001Qooooo`007?ooool00ol0003ooooo
ooooo`1Fooooo`;o00001?ooool2o`00017ooooo0_l00004oooooaGo00002Oooool2o`0000Gooooo
0_l0000Cooooo`;o000000?oooooo`000?l000000_ooool=o`0000Wooooo0_l0000Hooooo`;o0000
HOooool001cooooo00?o0000ooooooooool0E_ooool2o`0000Cooooo0_l0000Aooooo`Co000000Co
ooooo`000?l0003ooooo4ol000000ooooooo0000o`000006ooooo`;o00001Oooool2o`0001Kooooo
0_l00002ooooo`?o00000_ooool8o`0000Wooooo0_l00004ooooo`;o0000MOooool001cooooo00?o
0000ooooooooool0Koooool7o`0000;ooooo0_l000000ooooooo0000o`000007o`000003ooooool0
003o000000?o000000?oooooo`000?l000001Oooool2o`0001_ooooo1Ol00004ooooo`Wo00004Ooo
ool2o`0001;ooooo0_l0001Qooooo`007?ooool00ol0003oooooooooo`1cooooo`;o00001_ooool>
o`0000Sooooo0ol0000Kooooo`?o00001_ooool=o`0000?ooooo0_l00008ooooo`;o00004_ooool2
o`00067ooooo000Looooo`03o`000?oooooooooo07Cooooo0_l00003ooooo`oo00001?ooool2o`00
00?ooooo0_l0000Vooooo`;o00000_ooool3o`000003ooooool0003o000000;o00000oooool5o`00
00Oooooo0_l00004ooooo`Go0000J_ooool001cooooo00?o0000ooooooooool0M?ooool4o`000003
ooooool0003o000000Wo00000_ooool2o`0000Cooooo0_l00006ooooo`Co0000<_ooool4o`0000Ko
oooo0_l00002ooooo`Oo00001?ooool2o`0006Cooooo000Looooo`03o`000?oooooooooo05Cooooo
0_l000000ooooooo0000o`00000Mooooo`Co00000_ooool8o`00013ooooo1?l00004ooooo`;o0000
4oooool2o`0001Wooooo0_l0000:ooooo`?o00002?ooool2o`0006Cooooo000Looooo`03o`000?oo
oooooooo05Cooooo0_l000000ooooooo0000o`00000Oooooo`;o00001_ooool4o`000003ooooool0
003o000000?o00000oooool2o`0000cooooo0ol0000Cooooo`Go00002oooool2o`0000Wooooo0ol0
0003ooooo`;o00001Oooool2o`0006kooooo000Looooo`03o`000?oooooooooo07oooooo2ol00003
ooooo`;o00003?ooool2o`0001Gooooo1?l0000;ooooo`;o00002_ooool2o`000003ooooool0003o
000000;o0000MOooool001cooooo0_l0001mooooo`[o0000@Oooool2o`0000Oooooo0_l00009oooo
o`;o00000_ooool2o`0006Sooooo000Looooo`03o`000?oooooooooo05Cooooo0_l0000Pooooo`;o
00001?ooool4o`000004ooooool0003o0000ooooo`;o0000;Oooool2o`0000Wooooo0_l00007oooo
o`;o00001Oooool4o`0000Wooooo0_l00002ooooo`;o0000J?ooool001cooooo00?o0000oooooooo
ool0E?ooool2o`0000?ooooo0_l0000Kooooo`Co00001?ooool2o`0001;ooooo0_l00009ooooo`;o
00005?ooool2o`0000Kooooo0_l000001?oooooo0000o`000?ooool2o`0000Gooooo0_l000001?oo
oooo0000o`000?ooool2o`0000Cooooo0ol00008ooooo`;o0000J?ooool001cooooo00?o0000oooo
ooooool0E?ooool2o`0000?ooooo0_l0000Mooooo`;o00001?ooool2o`0001;ooooo0_l00009oooo
o`;o00007?ooool2o`0000Cooooo0_l00005ooooo`Go00001oooool8o`0006gooooo000Looooo`03
o`000?oooooooooo07Sooooo0_l0001<ooooo`;o000000?oooooo`000?l000003?ooool5o`0006go
oooo000Looooo`03o`000?oooooooooo063ooooo0_l0000Kooooo`;o00006Oooool2o`0000Cooooo
0_l0000Vooooo`;o0000POooool001cooooo00?o0000ooooooooool0G_ooool4o`0001Wooooo1?l0
000Iooooo`;o00001?ooool3o`0000;ooooo0_l0000Sooooo`;o0000Ooooool001cooooo00?o0000
ooooooooool0DOooool2o`0000Kooooo0_l00003ooooo`?o00006_ooool3o`00027ooooo0_l00002
ooooo`;o00008oooool2o`0007oooooo000Looooo`03o`000?oooooooooo057ooooo0_l00006oooo
o`;o00007?ooool4o`000004ooooool0003o0000ooooo`;o0000b?ooool001cooooo00?o0000oooo
ooooool0HOooool2o`000003ooooool0003o0000017ooooo1?l00004ooooo`;o0000b?ooool001co
oooo00?o0000ooooooooool0HOooool2o`000003ooooool0003o00000>?ooooo000Looooo`03o`00
0?oooooooooo05Cooooo0_l0000nooooo`;o00002_ooool2o`000:Oooooo000Looooo`03o`000?oo
oooooooo05Cooooo0_l0000Cooooo`;o00004Oooool2o`0000Cooooo0_l00005ooooo`?o00002?oo
ool2o`0000[ooooo0_l000000ooooooo0000o`00002Tooooo`007?ooool00ol0003oooooooooo`1Y
ooooo`;o00003?ooool2o`0000?ooooo0_l00004ooooo`;o00000oooool7o`0001Gooooo0_l00004
ooooo`;o0000W_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Go
c<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo07Oooooo0_l00008ooooo`;o0000
0_ooool6o`000003ooooool0003o000001_ooooo0_l0002Nooooo`0000KoooooogMgMonHV9Sooooo
oiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000oooo
ooooool0POooool2o`0000;ooooo0_l00002ooooo`;o00001oooool2o`000;Gooooo00000ooooooo
410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo07oooooo0_l0000?ooooo`Co00006?ooool2o`0003kooooo0_l0001Koooo
o`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRH
V?lb<S801_ooool3o`0005Wooooo0_l0000Tooooo`;o000000?oooooo`000?l000003?ooool2o`00
01[ooooo0_l0000nooooo`;o0000Foooool00003ooooool0003ooooo00;ooooo00?o0000oooooooo
ool02Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0FOooool2o`00
02;ooooo0_l00003ooooo`;o0000IOooool2o`0005kooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00Wooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo
07gooooo0_l0001Zooooo`;o0000G_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool0
1Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0Ioooool2o`0000Kooooo0_l0
000Iooooo`;o0000_Oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@
o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0Ioooool2o`0000Kooooo0_l0000Iooooo`;o
0000_Oooool001cooooo00?o0000ooooooooool0S_ooool2o`000;Wooooo000Looooo`03o`000?oo
oooooooo07Gooooo0_l00009ooooo`;o00003?ooool2o`000;Wooooo000Looooo`03o`000?oooooo
oooo07Gooooo0_l00009ooooo`;o00003?ooool2o`000;Wooooo000Looooo`03o`000?oooooooooo
06kooooo0_l00003ooooo`;o00000_ooool2o`0000[ooooo0_l00034ooooo`007?ooool00ol0003o
ooooooooo`1^ooooo`;o00000oooool2o`0000;ooooo0_l00006ooooo`;o00000_ooool2o`000<Co
oooo000Looooo`03o`000?oooooooooo073ooooo0_l00003ooooo`;o00002?ooool2o`000<Sooooo
000Looooo`03o`000?oooooooooo073ooooo0_l00003ooooo`;o00002?ooool2o`000003ooooool0
003o000000Sooooo0_l0001@ooooo`;o0000JOooool001cooooo00?o0000ooooooooool0Moooool2
o`0000Kooooo0_l000000ooooooo0000o`000008ooooo`;o0000D?ooool2o`0006Wooooo000Loooo
o`03o`000?oooooooooo07Oooooo0_l0000Cooooo`;o0000;oooool2o`0008[ooooo000Looooo`03
o`000?oooooooooo07Gooooo0_l0000Eooooo`;o0000;_ooool3o`0008[ooooo000Looooo`03o`00
0?oooooooooo07Gooooo0_l00003ooooo`;o00001?ooool2o`0003Kooooo0ol000000ooooooo0000
o`00002;ooooo`007?ooool2o`0007_ooooo0_l00004ooooo`;o00004oooool2o`00027ooooo0ol0
002>ooooo`007?ooool00ol0003oooooooooo`1/ooooo`;o00009oooool2o`00043ooooo0_l0001`
ooooo`007?ooool00ol0003oooooooooo`1/ooooo`;o00003oooool2o`0002?ooooo0_l000000ooo
oooo0000o`000003o`0000Kooooo0ol0000Tooooo`;o0000L?ooool001cooooo00?o0000oooooooo
ool0OOooool2o`0002?ooooo0_l000000ooooooo0000o`000003o`0000Kooooo0ol0002Fooooo`00
7?ooool00ol0003oooooooooo`21ooooo`;o0000a_ooool001cooooo00?o0000ooooooooool0POoo
ool2o`000<Kooooo000Looooo`03o`000?oooooooooo08Cooooo0_l00033ooooo`007?ooool00ol0
003oooooooooo`24ooooo`;o0000BOooool2o`0007Sooooo000Looooo`03o`000?oooooooooo0<oo
oooo0_l0001hooooo`007?ooool00ol0003oooooooooo`3:ooooo`;o0000OOooool001cooooo00?o
0000ooooooooool0b_ooool2o`0007gooooo000Looooo`03o`000?oooooooooo08Oooooo0_l00004
ooooo`;o0000=oooool2o`00087ooooo000Looooo`03o`000?oooooooooo08Oooooo0_l00004oooo
o`;o0000=oooool2o`00087ooooo000Looooo`03o`000?oooooooooo08Oooooo0_l00030ooooo`00
7?ooool00ol0003oooooooooo`2oooooo`;o0000R?ooool001cooooo00?o0000ooooooooool0Sooo
ool2o`0002Oooooo0_l00005ooooo`;o0000R?ooool001cooooo0_l0002@ooooo`;o00009Oooool4
o`0008oooooo000Looooo`03o`000?oooooooooo0;3ooooo0_l00004ooooo`;o0000TOooool001co
oooo00?o0000ooooooooool0/?ooool2o`0009Oooooo000Looooo`03o`000?oooooooooo0:Sooooo
0ol0002Nooooo`007?ooool00ol0003oooooooooo`2Mooooo`Co00001oooool3o`0009kooooo000L
ooooo`03o`000?oooooooooo09gooooo1?l0002Xooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Booooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3o
oooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom:oooo
o`005?ooool00ol0003oooooooooo`05ooooo`?o0000oooooom:ooooo`005?ooool00ol0003ooooo
ooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000
ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Booooo`03
oeEEEOmVIVKo00000?ooooooE?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0:Gooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0Gooooo`;o000000Wo410@
ooooooooooooooooonk^k_lb<S;o0000oa0@4?o<c<`00oooool5o`00093ooooo002Vooooo`05o`00
0?ooooooooooooooool000002Oooool6o`0000cooooo00?o0000ooooooooool00_ooool01OmEEEGo
MgMgoooooonHV9So8B4Q00?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A02@ooooo`00Y_ooool01Ol0
003ooooooooooooooooo000001Sooooo1Ol00003ooooo`05o`000?ooooooooooooooool000001?oo
ool00onHV9So8B4Qonk^kP2Aooooo`00Y_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l0
0009ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000oiRHV?ooooooV9RHob4Q8@05ooooo`03
oiRHV?lQ8B7ok^k^093ooooo002Vooooo`05o`000?n7QhOoooooojVYZOl000006?ooool01?oMgMgo
EEEEooooool00004ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00omgMgOoIVIVooooo`2?
ooooo`00YOooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo01Oooooo00?oMgMgolc<
c?l000001?ooool00omEEEGoQhN7ooooo`09ooooo`03o`000?oooooooooo08kooooo0034ooooo`03
onk^k_m4A4Co000000Cooooo00?ogMgMoa0@4?nHV9P01Oooool01Ol0003o^[ZjoooooonHV9So410@
093ooooo0035ooooo`03ogMgMol0003ooooo00Cooooo00Coc<c<odA4A?l0003o410@0oooool01OnH
V9So410@o`000?lQ8B7oc<c<093ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(468) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.53236 .3386 Mdot
.52023 .32668 Mdot
.35194 .69682 Mdot
.6653 .48073 Mdot
.57251 .67798 Mdot
.39469 .6724 Mdot
.28014 .48007 Mdot
.2714 .49089 Mdot
.3988 .68543 Mdot
.59736 .31347 Mdot
.31114 .48797 Mdot
.68561 .52712 Mdot
.2933 .48583 Mdot
.63079 .48779 Mdot
.46419 .41321 Mdot
.58333 .43977 Mdot
.48568 .29073 Mdot
.57494 .73238 Mdot
.60196 .42618 Mdot
.3701 .71198 Mdot
.76072 .53176 Mdot
.6223 .48182 Mdot
.47621 .33735 Mdot
.62763 .48736 Mdot
.6423 .5221 Mdot
.50766 .31896 Mdot
.53018 .34352 Mdot
.62525 .52206 Mdot
.62729 .54341 Mdot
.30373 .49401 Mdot
.41818 .73191 Mdot
.74407 .27775 Mdot
.60429 .45289 Mdot
.7147 .31425 Mdot
.27031 .48692 Mdot
.32452 .53208 Mdot
.36359 .69571 Mdot
.31184 .45596 Mdot
.26669 .49203 Mdot
.26698 .48326 Mdot
.28916 .46606 Mdot
.50097 .31428 Mdot
.26216 .48183 Mdot
.27275 .69338 Mdot
.64184 .49803 Mdot
.45262 .38022 Mdot
.20767 .63889 Mdot
.62103 .53085 Mdot
.50694 .29683 Mdot
.37586 .71733 Mdot
.66654 .72919 Mdot
.32833 .48208 Mdot
.42599 .42347 Mdot
.53787 .90615 Mdot
.30491 .48293 Mdot
.6727 .49964 Mdot
.40712 .69034 Mdot
.64176 .46361 Mdot
.66617 .46643 Mdot
.68628 .27788 Mdot
.61816 .46632 Mdot
.55303 .69635 Mdot
.46232 .3444 Mdot
.40552 .64362 Mdot
.40156 .67887 Mdot
.31407 .45791 Mdot
.47573 .35634 Mdot
.28506 .49462 Mdot
.609 .53971 Mdot
.36136 .71278 Mdot
.62709 .54148 Mdot
.30681 .49438 Mdot
.49534 .36212 Mdot
.64064 .50127 Mdot
.37941 .38373 Mdot
.22003 .47681 Mdot
.3332 .68552 Mdot
.77833 .40112 Mdot
.6805 .76128 Mdot
.46677 .6592 Mdot
.6225 .50185 Mdot
.52933 .86189 Mdot
.46056 .47618 Mdot
.52409 .3318 Mdot
.55391 .32358 Mdot
.41375 .23675 Mdot
.61772 .52607 Mdot
.43501 .60011 Mdot
.63899 .4328 Mdot
.55205 .61827 Mdot
.39341 .69685 Mdot
.51529 .34414 Mdot
.63516 .50174 Mdot
.59502 .47692 Mdot
.53438 .2468 Mdot
.66575 .53076 Mdot
.66201 .49058 Mdot
.53753 .27943 Mdot
.31683 .48238 Mdot
.58946 .56433 Mdot
.60016 .7593 Mdot
.39342 .42672 Mdot
.66642 .51284 Mdot
.37065 .68345 Mdot
.45883 .34005 Mdot
.66 .49792 Mdot
.27671 .49301 Mdot
.62072 .49586 Mdot
.26954 .51716 Mdot
.47678 .30639 Mdot
.60542 .45718 Mdot
.55792 .72808 Mdot
.57889 .57671 Mdot
.48017 .32139 Mdot
.73402 .41502 Mdot
.61454 .47495 Mdot
.62871 .458 Mdot
.51987 .32008 Mdot
.35684 .69852 Mdot
.34466 .62113 Mdot
.47966 .34897 Mdot
.2654 .48576 Mdot
.49793 .28984 Mdot
.68806 .47005 Mdot
.36117 .70288 Mdot
.40956 .42226 Mdot
.39792 .42237 Mdot
.62071 .65491 Mdot
.63041 .50583 Mdot
.56067 .56164 Mdot
.37927 .67776 Mdot
.50764 .31142 Mdot
.2934 .49437 Mdot
.67967 .48622 Mdot
.48673 .32286 Mdot
.27124 .50293 Mdot
.57046 .68497 Mdot
.59515 .6923 Mdot
.49697 .30175 Mdot
.6598 .40465 Mdot
.30732 .52176 Mdot
.27142 .4744 Mdot
.66471 .72709 Mdot
.52489 .3287 Mdot
.55223 .71448 Mdot
.28193 .51007 Mdot
.72673 .61854 Mdot
.65288 .44691 Mdot
.63885 .70321 Mdot
.44611 .84815 Mdot
.66586 .72922 Mdot
.74016 .29587 Mdot
.55495 .72528 Mdot
.27314 .50747 Mdot
.62997 .53883 Mdot
.49558 .33049 Mdot
.49166 .31812 Mdot
.59329 .4901 Mdot
.64311 .51037 Mdot
.64544 .48909 Mdot
.66696 .46229 Mdot
.23598 .53659 Mdot
.62952 .50178 Mdot
.24074 .37081 Mdot
.4879 .33159 Mdot
.6509 .51328 Mdot
.36197 .67252 Mdot
.59053 .55821 Mdot
.29496 .45926 Mdot
.66633 .46873 Mdot
.64109 .51494 Mdot
.68516 .50498 Mdot
.26224 .49595 Mdot
.35616 .37739 Mdot
.73827 .72183 Mdot
.2908 .54141 Mdot
.26138 .43871 Mdot
.38494 .66568 Mdot
.60395 .4806 Mdot
.5699 .71497 Mdot
.58977 .562 Mdot
.65004 .45198 Mdot
.66848 .73344 Mdot
.62361 .5133 Mdot
.76422 .34125 Mdot
.6869 .53616 Mdot
.40314 .24315 Mdot
.26619 .32818 Mdot
.65149 .45033 Mdot
.62415 .34938 Mdot
.62979 .68976 Mdot
.36136 .7601 Mdot
.29969 .49371 Mdot
.36432 .65993 Mdot
.35327 .68928 Mdot
.31208 .4539 Mdot
.72533 .50658 Mdot
.61129 .31952 Mdot
.65235 .5406 Mdot
.40309 .42437 Mdot
.52811 .37691 Mdot
.54856 .7207 Mdot
.49962 .3008 Mdot
.56417 .85173 Mdot
.48291 .64354 Mdot
.4392 .61667 Mdot
.59361 .71893 Mdot
.39641 .71178 Mdot
.41548 .42957 Mdot
.55885 .71669 Mdot
.65775 .47636 Mdot
.48437 .29878 Mdot
.63475 .70634 Mdot
.57468 .52425 Mdot
.32698 .19135 Mdot
.51779 .35337 Mdot
.55221 .57579 Mdot
.30136 .48628 Mdot
.38566 .63961 Mdot
.61825 .52595 Mdot
.63923 .47339 Mdot
.47944 .36475 Mdot
.6186 .53678 Mdot
.44682 .58738 Mdot
.63638 .51484 Mdot
.4084 .64847 Mdot
.52729 .66543 Mdot
.25166 .50277 Mdot
.58802 .73055 Mdot
.4888 .3594 Mdot
.21147 .47224 Mdot
.36584 .68079 Mdot
.67953 .57378 Mdot
.29158 .50164 Mdot
.57458 .68829 Mdot
.3696 .69463 Mdot
.55414 .73106 Mdot
.61791 .44863 Mdot
.3693 .7013 Mdot
.54588 .70265 Mdot
.42083 .53333 Mdot
.6631 .49367 Mdot
.65194 .65545 Mdot
.31293 .50608 Mdot
.5291 .32391 Mdot
.63439 .45045 Mdot
.42655 .43278 Mdot
.68433 .47704 Mdot
.51677 .51861 Mdot
.42071 .43947 Mdot
.38877 .44542 Mdot
.45144 .61977 Mdot
.54584 .68553 Mdot
.37701 .40879 Mdot
.42233 .56418 Mdot
.48484 .29118 Mdot
.61757 .45115 Mdot
.42165 .30785 Mdot
.31009 .50887 Mdot
.65491 .47199 Mdot
.40089 .27446 Mdot
.28098 .51012 Mdot
.63783 .4592 Mdot
.29192 .46618 Mdot
.49112 .32391 Mdot
.43982 .50538 Mdot
.51753 .29773 Mdot
.66283 .47501 Mdot
.30546 .4673 Mdot
.36048 .66501 Mdot
.5071 .31942 Mdot
.61925 .49087 Mdot
.61301 .50282 Mdot
.40135 .42737 Mdot
.64705 .50351 Mdot
.43853 .24419 Mdot
.62255 .52981 Mdot
.37519 .72031 Mdot
.64907 .53978 Mdot
.62304 .75113 Mdot
.60172 .72881 Mdot
.46844 .3313 Mdot
.41836 .44093 Mdot
.39193 .70062 Mdot
.43203 .51326 Mdot
.62735 .6355 Mdot
.62625 .49795 Mdot
.40124 .44119 Mdot
.54337 .56991 Mdot
.29878 .45928 Mdot
.58239 .48999 Mdot
.39137 .59336 Mdot
.38717 .69768 Mdot
.40938 .42516 Mdot
.57253 .49109 Mdot
.53024 .35198 Mdot
.66958 .51371 Mdot
.364 .69306 Mdot
.52971 .3182 Mdot
.6769 .5204 Mdot
.19552 .56603 Mdot
.42729 .43154 Mdot
.3144 .47027 Mdot
.51077 .25535 Mdot
.59749 .48739 Mdot
.35238 .67953 Mdot
.4882 .31612 Mdot
.30217 .4737 Mdot
.47751 .33031 Mdot
.63011 .7144 Mdot
.52393 .50899 Mdot
.32314 .55467 Mdot
.54432 .73622 Mdot
.84279 .43806 Mdot
.32376 .53064 Mdot
.59633 .57058 Mdot
.37154 .73364 Mdot
.36138 .2179 Mdot
.37127 .69113 Mdot
.61924 .39522 Mdot
.40066 .69484 Mdot
.6584 .52696 Mdot
.39731 .67437 Mdot
.46368 .20519 Mdot
.61746 .51641 Mdot
.40272 .66431 Mdot
.2991 .56941 Mdot
.61531 .51301 Mdot
.48454 .32573 Mdot
.61437 .19097 Mdot
.76104 .42634 Mdot
.75354 .46232 Mdot
.41173 .67904 Mdot
.66448 .40235 Mdot
.62144 .52246 Mdot
.60911 .42379 Mdot
.5005 .32976 Mdot
.68978 .50354 Mdot
.53226 .70278 Mdot
.5446 .72728 Mdot
.70253 .67034 Mdot
.79615 .45281 Mdot
.73412 .48953 Mdot
.5005 .31886 Mdot
.66914 .77278 Mdot
.38106 .37832 Mdot
.42764 .42974 Mdot
.27034 .49595 Mdot
.35287 .39102 Mdot
.57954 .45673 Mdot
.56529 .35621 Mdot
.44633 .57414 Mdot
.51366 .34837 Mdot
.37239 .54166 Mdot
.29641 .4728 Mdot
.7566 .45114 Mdot
.60817 .29139 Mdot
.64804 .48829 Mdot
.32405 .48389 Mdot
.69855 .50731 Mdot
.43254 .58299 Mdot
.63896 .6669 Mdot
.23989 .63236 Mdot
.66182 .48032 Mdot
.39476 .39694 Mdot
.64792 .45225 Mdot
.62797 .66623 Mdot
.65648 .46953 Mdot
.48024 .33377 Mdot
.64092 .4251 Mdot
.417 .55677 Mdot
.8089 .53194 Mdot
.48169 .63232 Mdot
.5395 .70554 Mdot
.63225 .48454 Mdot
.64823 .47968 Mdot
.55079 .69528 Mdot
.51157 .34684 Mdot
.61952 .45225 Mdot
.19388 .62424 Mdot
.62852 .50283 Mdot
.32841 .47219 Mdot
.47867 .53778 Mdot
.79314 .36847 Mdot
.60234 .51146 Mdot
.52589 .35692 Mdot
.28503 .46597 Mdot
.28765 .50677 Mdot
.69741 .43997 Mdot
.3181 .50181 Mdot
.62658 .53909 Mdot
.47819 .53643 Mdot
.47296 .32523 Mdot
.6735 .54756 Mdot
.50649 .3506 Mdot
.65261 .77933 Mdot
.28336 .51225 Mdot
.4021 .44454 Mdot
.73967 .44186 Mdot
.28348 .48154 Mdot
.55485 .63887 Mdot
.64132 .42559 Mdot
.57943 .52342 Mdot
.50296 .25783 Mdot
.35852 .66452 Mdot
.41106 .44029 Mdot
.30544 .47987 Mdot
.63306 .50015 Mdot
.66286 .50794 Mdot
.32498 .49005 Mdot
.63439 .23756 Mdot
.41375 .73509 Mdot
.66326 .47307 Mdot
.48434 .34277 Mdot
.50569 .31189 Mdot
.66836 .45878 Mdot
.64056 .45013 Mdot
.39072 .65692 Mdot
.40188 .44187 Mdot
.41318 .44213 Mdot
.38953 .4269 Mdot
.4057 .65146 Mdot
.83919 .46026 Mdot
.27166 .47399 Mdot
.75938 .30242 Mdot
.38242 .32372 Mdot
.67061 .42399 Mdot
.35648 .68566 Mdot
.63109 .46819 Mdot
.65858 .52294 Mdot
.309 .47052 Mdot
.81778 .49686 Mdot
.64321 .4287 Mdot
.53036 .33637 Mdot
.32766 .47984 Mdot
.6907 .51665 Mdot
.33489 .50339 Mdot
.58079 .71439 Mdot
.74252 .46681 Mdot
.32186 .49815 Mdot
.47527 .31612 Mdot
.3225 .49725 Mdot
.64795 .48281 Mdot
.57135 .49602 Mdot
.51393 .34931 Mdot
.59051 .69372 Mdot
.59878 .47432 Mdot
.63931 .45782 Mdot
.36883 .78541 Mdot
.38184 .38518 Mdot
.60622 .70385 Mdot
.63873 .53234 Mdot
.5884 .54541 Mdot
.59228 .70526 Mdot
.60503 .46808 Mdot
.64751 .53888 Mdot
.57011 .57437 Mdot
.26806 .51829 Mdot
.54259 .68316 Mdot
.80516 .53182 Mdot
.52047 .35156 Mdot
.42934 .25387 Mdot
.39885 .4237 Mdot
.28611 .4517 Mdot
.43908 .49525 Mdot
.41061 .43259 Mdot
.38261 .30001 Mdot
.19555 .46392 Mdot
.40769 .43984 Mdot
.39759 .63936 Mdot
.58097 .37133 Mdot
.63874 .54271 Mdot
.65707 .46082 Mdot
.54543 .68652 Mdot
.52008 .3136 Mdot
.24969 .36258 Mdot
.25065 .50961 Mdot
.61962 .476 Mdot
.53659 .33564 Mdot
.40823 .23891 Mdot
.40981 .42728 Mdot
.57035 .71895 Mdot
.58461 .68629 Mdot
.64231 .45202 Mdot
.59216 .61915 Mdot
.50276 .31726 Mdot
.61932 .49077 Mdot
.61979 .4592 Mdot
.39403 .70476 Mdot
.48746 .29707 Mdot
.36441 .67128 Mdot
.41068 .44763 Mdot
.3349 .21807 Mdot
.30764 .76614 Mdot
.30643 .5088 Mdot
.3908 .48624 Mdot
.25595 .48627 Mdot
.2158 .59558 Mdot
.40304 .44246 Mdot
.62042 .48675 Mdot
.47832 .35188 Mdot
.61966 .49444 Mdot
.631 .50269 Mdot
.65379 .49101 Mdot
.73439 .48972 Mdot
.65408 .77154 Mdot
.57403 .69934 Mdot
.59728 .51952 Mdot
.41359 .67049 Mdot
.4025 .25386 Mdot
.50017 .20772 Mdot
.63766 .48048 Mdot
.62992 .45783 Mdot
.48289 .36267 Mdot
.62428 .44336 Mdot
.27412 .48976 Mdot
.52364 .34208 Mdot
.66678 .50665 Mdot
.60061 .76207 Mdot
.62149 .45237 Mdot
.38171 .49954 Mdot
.31925 .50587 Mdot
.55742 .47269 Mdot
.58742 .5288 Mdot
.40371 .44312 Mdot
.41116 .43962 Mdot
.42658 .44064 Mdot
.32483 .47072 Mdot
.39313 .70426 Mdot
.37902 .63012 Mdot
.58572 .51898 Mdot
.62689 .5358 Mdot
.57293 .50602 Mdot
.40012 .71535 Mdot
.4106 .56808 Mdot
.51833 .40038 Mdot
.69642 .51976 Mdot
.40249 .65266 Mdot
.5297 .27044 Mdot
.78137 .47376 Mdot
.5273 .33542 Mdot
.37261 .73197 Mdot
.28053 .5006 Mdot
.55026 .72632 Mdot
.68857 .70424 Mdot
.47914 .34467 Mdot
.49815 .36713 Mdot
.3913 .66243 Mdot
.48477 .50702 Mdot
.60317 .89397 Mdot
.376 .6834 Mdot
.44064 .61031 Mdot
.50139 .32612 Mdot
.62128 .43902 Mdot
.53383 .56157 Mdot
.48941 .49146 Mdot
.40514 .67014 Mdot
.61352 .50237 Mdot
.5103 .65936 Mdot
.39144 .65711 Mdot
.58748 .46671 Mdot
.41225 .6766 Mdot
.31946 .47681 Mdot
.376 .67531 Mdot
.53186 .30258 Mdot
.62453 .50593 Mdot
.55621 .90459 Mdot
.45607 .47181 Mdot
.61332 .48887 Mdot
.32569 .49261 Mdot
.25655 .56527 Mdot
.65328 .48185 Mdot
.53439 .70763 Mdot
.41391 .66503 Mdot
.2257 .62009 Mdot
.66029 .52988 Mdot
.39857 .66889 Mdot
.53448 .2999 Mdot
.39253 .72674 Mdot
.59632 .75714 Mdot
.41257 .44116 Mdot
.49102 .32742 Mdot
.39904 .41189 Mdot
.27515 .4734 Mdot
.66479 .44714 Mdot
.61477 .46349 Mdot
.48769 .33787 Mdot
.4246 .5197 Mdot
.71355 .46232 Mdot
.62375 .50156 Mdot
.37972 .65947 Mdot
.41232 .69843 Mdot
.46663 .40893 Mdot
.36485 .68448 Mdot
.58994 .54698 Mdot
.4844 .33462 Mdot
.67012 .50789 Mdot
.48589 .31391 Mdot
.61504 .45289 Mdot
.31426 .43419 Mdot
.52727 .32863 Mdot
.64992 .58635 Mdot
.62799 .50761 Mdot
.46666 .26032 Mdot
.59699 .49139 Mdot
.66157 .48488 Mdot
.41779 .6862 Mdot
.56411 .70189 Mdot
.59031 .47066 Mdot
.21517 .48518 Mdot
.58816 .71116 Mdot
.68346 .25219 Mdot
.36103 .70226 Mdot
.57763 .68546 Mdot
.69362 .65859 Mdot
.41853 .44059 Mdot
.55975 .69287 Mdot
.39145 .45487 Mdot
.31336 .50337 Mdot
.50198 .28346 Mdot
.61661 .5115 Mdot
.365 .20753 Mdot
.42304 .72754 Mdot
.39847 .43134 Mdot
.6304 .45301 Mdot
.63629 .46743 Mdot
.53443 .33973 Mdot
.55364 .85465 Mdot
.41767 .65559 Mdot
.66549 .48824 Mdot
.48508 .35484 Mdot
.49811 .85952 Mdot
.40323 .66301 Mdot
.5768 .69876 Mdot
.28122 .51654 Mdot
.50766 .38135 Mdot
.40581 .44514 Mdot
.28031 .5115 Mdot
.33572 .69825 Mdot
.67021 .73592 Mdot
.66723 .52245 Mdot
.35841 .67895 Mdot
.66612 .72998 Mdot
.68089 .54381 Mdot
.2992 .45351 Mdot
.33742 .43821 Mdot
.51689 .34147 Mdot
.32575 .48802 Mdot
.5401 .69251 Mdot
.48258 .29506 Mdot
.50946 .34973 Mdot
.27321 .49583 Mdot
.27372 .30322 Mdot
.53969 .56489 Mdot
.32817 .46003 Mdot
.51368 .52354 Mdot
.66423 .73011 Mdot
.39432 .44124 Mdot
.56817 .72054 Mdot
.58741 .78243 Mdot
.50312 .31523 Mdot
.35339 .38914 Mdot
.66771 .72994 Mdot
.66221 .49043 Mdot
.54402 .70534 Mdot
.41213 .25601 Mdot
.25754 .47158 Mdot
.27305 .50519 Mdot
.33606 .64064 Mdot
.54124 .71496 Mdot
.63636 .44473 Mdot
.80558 .3908 Mdot
.60639 .50912 Mdot
.28857 .51208 Mdot
.44685 .57998 Mdot
.48552 .2996 Mdot
.2895 .46051 Mdot
.44691 .58893 Mdot
.65481 .52682 Mdot
.61025 .48086 Mdot
.51117 .69517 Mdot
.49441 .2928 Mdot
.399 .44746 Mdot
.61657 .49968 Mdot
.64233 .46191 Mdot
.6669 .4515 Mdot
.78889 .5174 Mdot
.62548 .59575 Mdot
.66654 .49646 Mdot
.37317 .64348 Mdot
.57934 .54436 Mdot
.66612 .46267 Mdot
.53429 .34695 Mdot
.6168 .76708 Mdot
.41 .44816 Mdot
.65623 .46134 Mdot
.66276 .47202 Mdot
.26713 .48933 Mdot
.54069 .56662 Mdot
.48811 .48685 Mdot
.38709 .71641 Mdot
.33965 .64206 Mdot
.63978 .5475 Mdot
.49255 .33486 Mdot
.5321 .69778 Mdot
.61921 .55864 Mdot
.52604 .34342 Mdot
.5902 .51684 Mdot
.4153 .6774 Mdot
.40386 .43932 Mdot
.69974 .52969 Mdot
.55398 .69911 Mdot
.2881 .52492 Mdot
.72493 .27809 Mdot
.36559 .66138 Mdot
.63447 .52623 Mdot
.37713 .62797 Mdot
.38624 .68857 Mdot
.39772 .42916 Mdot
.5679 .49995 Mdot
.49319 .32097 Mdot
.47857 .31065 Mdot
.64688 .76473 Mdot
.40495 .64857 Mdot
.40308 .8041 Mdot
.32097 .4812 Mdot
.59493 .51238 Mdot
.4322 .35478 Mdot
.48221 .30476 Mdot
.62381 .65842 Mdot
.58199 .68733 Mdot
.27425 .5058 Mdot
.3787 .43766 Mdot
.52838 .32925 Mdot
.48589 .30406 Mdot
.63614 .50095 Mdot
.62912 .47834 Mdot
.34007 .72699 Mdot
.63289 .69175 Mdot
.29054 .46697 Mdot
.57976 .70758 Mdot
.36929 .71897 Mdot
.64479 .53386 Mdot
.52127 .33585 Mdot
.79684 .38087 Mdot
.59806 .48637 Mdot
.41355 .67173 Mdot
.51838 .32915 Mdot
.57205 .6916 Mdot
.55318 .68674 Mdot
.6617 .48797 Mdot
.77392 .36258 Mdot
.28199 .48428 Mdot
.48286 .32777 Mdot
.53558 .28269 Mdot
.60551 .52861 Mdot
.63341 .48097 Mdot
.69649 .46612 Mdot
.28649 .45935 Mdot
.69025 .53675 Mdot
.58582 .72152 Mdot
.50149 .30632 Mdot
.61538 .49406 Mdot
.55354 .69569 Mdot
.56475 .35925 Mdot
.40654 .43386 Mdot
.40038 .66175 Mdot
.53539 .71104 Mdot
.55676 .70941 Mdot
.588 .70522 Mdot
.35442 .39196 Mdot
.45675 .33155 Mdot
.79373 .63572 Mdot
.61825 .50571 Mdot
.66352 .73022 Mdot
.64584 .43475 Mdot
.31377 .46365 Mdot
.36891 .65439 Mdot
.64118 .49617 Mdot
.61794 .50593 Mdot
.75263 .32436 Mdot
.58528 .43665 Mdot
.5861 .4344 Mdot
.47844 .30584 Mdot
.48693 .24977 Mdot
.3534 .67918 Mdot
.41415 .836 Mdot
.62919 .18201 Mdot
.65395 .541 Mdot
.48404 .51116 Mdot
.52412 .33932 Mdot
.26671 .49938 Mdot
.51664 .53331 Mdot
.35176 .49978 Mdot
.51152 .30811 Mdot
.65498 .52903 Mdot
.72493 .28254 Mdot
.56591 .73081 Mdot
.64528 .4874 Mdot
.29108 .49643 Mdot
.6454 .48822 Mdot
.32053 .46427 Mdot
.44988 .35763 Mdot
.47743 .48079 Mdot
.62108 .514 Mdot
.66135 .53291 Mdot
.55265 .54462 Mdot
.63488 .47914 Mdot
.24919 .61542 Mdot
.5119 .33392 Mdot
.668 .58119 Mdot
.67884 .47614 Mdot
.7483 .37785 Mdot
.61702 .45847 Mdot
.42943 .48715 Mdot
.60958 .4741 Mdot
.78562 .54013 Mdot
.6424 .44386 Mdot
.60469 .4803 Mdot
.3 .47024 Mdot
.26512 .48824 Mdot
.54095 .3108 Mdot
.39285 .44576 Mdot
.40282 .24587 Mdot
.63478 .45714 Mdot
.41116 .70268 Mdot
.51831 .42873 Mdot
.56183 .70681 Mdot
.50441 .30733 Mdot
.24846 .76199 Mdot
.29282 .46271 Mdot
.39921 .64119 Mdot
.44051 .62618 Mdot
.36248 .64605 Mdot
.35875 .72604 Mdot
.47425 .25284 Mdot
.57033 .72086 Mdot
.62576 .45058 Mdot
.72594 .32503 Mdot
.3937 .39049 Mdot
.60855 .53033 Mdot
.4159 .64074 Mdot
.55252 .42796 Mdot
.65887 .75801 Mdot
.54464 .72968 Mdot
.55613 .72327 Mdot
.30209 .47575 Mdot
.35217 .6957 Mdot
.70136 .50993 Mdot
.57736 .68554 Mdot
.36981 .65526 Mdot
.40227 .41994 Mdot
.51654 .73925 Mdot
.49956 .31584 Mdot
.67514 .40853 Mdot
.44107 .37123 Mdot
.29176 .46401 Mdot
.21662 .4821 Mdot
.47526 .28031 Mdot
.47835 .29275 Mdot
.3884 .44091 Mdot
.40653 .66125 Mdot
.50032 .28183 Mdot
.62716 .50523 Mdot
.57471 .52408 Mdot
.6415 .45144 Mdot
.55027 .68487 Mdot
.62492 .45484 Mdot
.39018 .6544 Mdot
.27926 .47723 Mdot
.39071 .69863 Mdot
.28242 .47785 Mdot
.67658 .22891 Mdot
.66286 .46113 Mdot
.63047 .48243 Mdot
.47807 .53167 Mdot
.49043 .30245 Mdot
.7077 .31233 Mdot
.4132 .66914 Mdot
.40416 .69401 Mdot
.66999 .50597 Mdot
.46778 .33668 Mdot
.56907 .64038 Mdot
.50878 .53587 Mdot
.61294 .46868 Mdot
.51164 .33503 Mdot
.67162 .50327 Mdot
.21589 .57811 Mdot
.46962 .45845 Mdot
.47736 .32737 Mdot
.8097 .53198 Mdot
.64297 .50268 Mdot
.5625 .49996 Mdot
.55085 .49169 Mdot
.76754 .53799 Mdot
.61135 .44324 Mdot
.51815 .35218 Mdot
.6685 .4707 Mdot
.49753 .33695 Mdot
.37989 .69109 Mdot
.27264 .47133 Mdot
.49857 .33391 Mdot
.61016 .50939 Mdot
.63849 .18916 Mdot
.27637 .47907 Mdot
.6379 .49143 Mdot
.3103 .48281 Mdot
.50655 .28757 Mdot
.50391 .29805 Mdot
.37613 .44643 Mdot
.43997 .61348 Mdot
.27564 .48852 Mdot
.62534 .53579 Mdot
.36626 .3805 Mdot
.66986 .50962 Mdot
.3427 .63818 Mdot
.68294 .50795 Mdot
.62009 .54452 Mdot
.84466 .43032 Mdot
.42819 .50961 Mdot
.34223 .8056 Mdot
.2372 .49248 Mdot
.35999 .3755 Mdot
.54743 .31883 Mdot
.54444 .72936 Mdot
.39499 .50174 Mdot
.42275 .43531 Mdot
.36691 .6462 Mdot
.63715 .49871 Mdot
.48819 .22744 Mdot
.32849 .46406 Mdot
.56865 .70217 Mdot
.62346 .51355 Mdot
.34554 .67959 Mdot
.445 .43317 Mdot
.2743 .50752 Mdot
.49995 .31358 Mdot
.50206 .30016 Mdot
.69191 .75343 Mdot
.61486 .49046 Mdot
.62483 .48054 Mdot
.27249 .48275 Mdot
.70874 .48839 Mdot
.58621 .70723 Mdot
.31244 .57119 Mdot
.294 .49717 Mdot
.46788 .46453 Mdot
.48 .3014 Mdot
.63404 .46769 Mdot
.47983 .53909 Mdot
.31556 .37236 Mdot
.561 .26549 Mdot
.54692 .71425 Mdot
.60598 .62637 Mdot
.51789 .35259 Mdot
.29583 .49396 Mdot
.69598 .66719 Mdot
.65185 .43205 Mdot
.63818 .46608 Mdot
.65387 .61572 Mdot
.50955 .53382 Mdot
.43749 .60619 Mdot
.69015 .45842 Mdot
.54858 .58636 Mdot
.66937 .50773 Mdot
.66284 .50867 Mdot
.61113 .54206 Mdot
.68075 .50073 Mdot
.50883 .33801 Mdot
.75803 .41778 Mdot
.38861 .67255 Mdot
.59363 .33566 Mdot
.32351 .68395 Mdot
.61803 .52093 Mdot
.65607 .52719 Mdot
.67237 .37241 Mdot
.51166 .49358 Mdot
.50895 .32734 Mdot
.53003 .27743 Mdot
.27116 .47571 Mdot
.59505 .42907 Mdot
.40852 .65327 Mdot
.5533 .46038 Mdot
.39521 .68541 Mdot
.51161 .33746 Mdot
.3798 .70796 Mdot
.32657 .50369 Mdot
.3586 .67964 Mdot
.39562 .64667 Mdot
.27534 .51162 Mdot
.5056 .29521 Mdot
.60326 .47924 Mdot
.28484 .51502 Mdot
.56328 .64081 Mdot
.55044 .68503 Mdot
.37497 .44724 Mdot
.62601 .43603 Mdot
.56941 .45991 Mdot
.19393 .5692 Mdot
.37082 .7037 Mdot
.49448 .47722 Mdot
.52692 .32697 Mdot
.53514 .69321 Mdot
.50549 .33928 Mdot
.7412 .69503 Mdot
.55049 .70534 Mdot
.37623 .44923 Mdot
.67536 .67275 Mdot
.2616 .53195 Mdot
.68646 .51104 Mdot
.50676 .25719 Mdot
.39343 .68906 Mdot
.32829 .47405 Mdot
.40857 .25661 Mdot
.65245 .50171 Mdot
.41976 .41713 Mdot
.48224 .28483 Mdot
.41765 .44046 Mdot
.29162 .49436 Mdot
.38473 .46326 Mdot
.6139 .48487 Mdot
.25907 .52951 Mdot
.66913 .52914 Mdot
.71888 .42712 Mdot
.32859 .68234 Mdot
.562 .33815 Mdot
.66457 .52259 Mdot
.40282 .66058 Mdot
.66763 .51724 Mdot
.60118 .3838 Mdot
.66083 .69565 Mdot
.64885 .54717 Mdot
.52766 .47076 Mdot
.20509 .60464 Mdot
.51938 .33831 Mdot
.59289 .54711 Mdot
.39455 .43652 Mdot
.64639 .5253 Mdot
.4294 .15037 Mdot
.55891 .69482 Mdot
.60186 .69548 Mdot
.61213 .50909 Mdot
.6194 .49791 Mdot
.76069 .34375 Mdot
.4638 .27739 Mdot
.37859 .43908 Mdot
.64536 .46864 Mdot
.69168 .60077 Mdot
.30343 .47249 Mdot
.67903 .51645 Mdot
.65993 .46153 Mdot
.37311 .77428 Mdot
.30778 .47463 Mdot
.36024 .69703 Mdot
.41969 .4397 Mdot
.39938 .70821 Mdot
.56365 .67268 Mdot
.57092 .59715 Mdot
.63045 .6519 Mdot
.46786 .44431 Mdot
.53647 .70663 Mdot
.61331 .52061 Mdot
.55867 .34462 Mdot
.60863 .49294 Mdot
.55793 .72154 Mdot
.30408 .49379 Mdot
.50743 .33451 Mdot
.66204 .40532 Mdot
.39995 .42561 Mdot
.60158 .51947 Mdot
.54006 .72956 Mdot
.49585 .32871 Mdot
.26288 .3848 Mdot
.52221 .31905 Mdot
.28705 .47652 Mdot
.31243 .45427 Mdot
.55695 .7047 Mdot
.50722 .33984 Mdot
.39689 .70838 Mdot
.23686 .47955 Mdot
.6749 .52936 Mdot
.3283 .50203 Mdot
.50747 .27875 Mdot
.52738 .3498 Mdot
.47236 .34152 Mdot
.67765 .48667 Mdot
.49948 .52046 Mdot
.66575 .43799 Mdot
.27487 .48009 Mdot
.35144 .66242 Mdot
.63988 .69996 Mdot
.74679 .34452 Mdot
.4677 .47561 Mdot
.59247 .46483 Mdot
.62666 .45427 Mdot
.64124 .45206 Mdot
.67189 .48811 Mdot
.31701 .56872 Mdot
.66294 .46144 Mdot
.30227 .46667 Mdot
.38962 .68245 Mdot
.61928 .46476 Mdot
.3972 .43939 Mdot
.41427 .56865 Mdot
.5329 .69293 Mdot
.74458 .45838 Mdot
.45014 .25657 Mdot
.49771 .3295 Mdot
.36287 .68714 Mdot
.38322 .70893 Mdot
.57047 .68502 Mdot
.28794 .5141 Mdot
.51717 .31053 Mdot
.77914 .54833 Mdot
.58138 .72213 Mdot
.65584 .46147 Mdot
.47821 .53478 Mdot
.79436 .50122 Mdot
.59134 .50443 Mdot
.65732 .4872 Mdot
.39997 .44851 Mdot
.39376 .64045 Mdot
.41983 .18519 Mdot
.26579 .32 Mdot
.56212 .70216 Mdot
.58139 .70105 Mdot
.47792 .35591 Mdot
.59415 .51231 Mdot
.28097 .48688 Mdot
.55191 .58076 Mdot
.19782 .55485 Mdot
.4275 .2362 Mdot
.21741 .59816 Mdot
.62004 .45336 Mdot
.73095 .3922 Mdot
.68456 .50638 Mdot
.45861 .33939 Mdot
.47074 .34297 Mdot
.50427 .32219 Mdot
.2976 .47158 Mdot
.67196 .73722 Mdot
.30464 .46603 Mdot
.46066 .24182 Mdot
.50291 .35829 Mdot
.42908 .53795 Mdot
.40775 .69021 Mdot
.60296 .42873 Mdot
.56781 .72206 Mdot
.59128 .64696 Mdot
.58708 .53935 Mdot
.59632 .61943 Mdot
.35656 .68611 Mdot
.52179 .30592 Mdot
.63178 .42871 Mdot
.397 .25074 Mdot
.48227 .50488 Mdot
.21219 .63615 Mdot
.50877 .24042 Mdot
.54999 .69697 Mdot
.60868 .32981 Mdot
.583 .71743 Mdot
.27565 .50695 Mdot
.64736 .50015 Mdot
.59489 .49445 Mdot
.66316 .48118 Mdot
.67856 .49403 Mdot
.30631 .48093 Mdot
.67496 .5318 Mdot
.62367 .75124 Mdot
.41123 .42039 Mdot
.39866 .5573 Mdot
.55549 .68787 Mdot
.32104 .47502 Mdot
.38718 .68631 Mdot
.38678 .44073 Mdot
.54718 .73834 Mdot
.66811 .4557 Mdot
.60791 .50364 Mdot
.40205 .42091 Mdot
.71753 .49995 Mdot
.58118 .45321 Mdot
.39374 .67024 Mdot
.42896 .57525 Mdot
.55681 .68004 Mdot
.55672 .72699 Mdot
.32425 .48826 Mdot
.50557 .33959 Mdot
.56831 .68191 Mdot
.35042 .69351 Mdot
.67451 .52132 Mdot
.65668 .53593 Mdot
.51143 .27885 Mdot
.66786 .73202 Mdot
.53133 .69555 Mdot
.68373 .54135 Mdot
.49246 .30736 Mdot
.48046 .28556 Mdot
.64605 .47015 Mdot
.6756 .54009 Mdot
.49042 .36775 Mdot
.57495 .69048 Mdot
.32271 .48607 Mdot
.44431 .5277 Mdot
.30832 .4645 Mdot
.49021 .3145 Mdot
.57815 .53939 Mdot
.49417 .29152 Mdot
.6497 .50404 Mdot
.3849 .85529 Mdot
.6516 .44943 Mdot
.72587 .54641 Mdot
.48611 .66973 Mdot
.41201 .67414 Mdot
.40968 .66881 Mdot
.40194 .4398 Mdot
.52516 .34336 Mdot
.60473 .55905 Mdot
.57553 .71802 Mdot
.36092 .37581 Mdot
.4696 .27843 Mdot
.39903 .64912 Mdot
.40381 .64444 Mdot
.30511 .49167 Mdot
.61982 .45658 Mdot
.62945 .46724 Mdot
.3583 .68285 Mdot
.2739 .56886 Mdot
.49913 .34263 Mdot
.62483 .4809 Mdot
.67554 .47762 Mdot
.38834 .67537 Mdot
.29394 .44498 Mdot
.48594 .27862 Mdot
.67795 .48368 Mdot
.65188 .68905 Mdot
.31389 .46023 Mdot
.62571 .52775 Mdot
.68463 .50207 Mdot
.56092 .71089 Mdot
.62466 .63604 Mdot
.66429 .72719 Mdot
.26111 .49177 Mdot
.40922 .4439 Mdot
.59508 .48333 Mdot
.41075 .67717 Mdot
.62904 .43346 Mdot
.18563 .40356 Mdot
.41753 .42187 Mdot
.61611 .4814 Mdot
.63241 .54878 Mdot
.48393 .31644 Mdot
.61874 .48836 Mdot
.32022 .43559 Mdot
.3743 .6638 Mdot
.61554 .48092 Mdot
.77373 .36553 Mdot
.30312 .49327 Mdot
.5857 .53588 Mdot
.54392 .72113 Mdot
.44033 .60088 Mdot
.62164 .1963 Mdot
.39173 .71924 Mdot
.54835 .69015 Mdot
.62295 .4565 Mdot
.39385 .71344 Mdot
.27749 .51572 Mdot
.6528 .59373 Mdot
.61371 .52246 Mdot
.30437 .46387 Mdot
.27745 .47994 Mdot
.55833 .70104 Mdot
.32314 .80969 Mdot
.63684 .54762 Mdot
.64113 .48513 Mdot
.17662 .55775 Mdot
.49975 .37123 Mdot
.6406 .49154 Mdot
.61593 .4612 Mdot
.3136 .50553 Mdot
.73723 .67735 Mdot
.60438 .62502 Mdot
.29897 .56893 Mdot
.31759 .46241 Mdot
.42025 .6539 Mdot
.36913 .663 Mdot
.54848 .69148 Mdot
.51906 .32747 Mdot
.54309 .68551 Mdot
.37959 .67201 Mdot
.6613 .48323 Mdot
.30178 .50545 Mdot
.59362 .23488 Mdot
.32447 .49975 Mdot
.34972 .69721 Mdot
.46019 .31464 Mdot
.48997 .21796 Mdot
.16879 .43914 Mdot
.44746 .37734 Mdot
.27111 .46759 Mdot
.56195 .70701 Mdot
.25283 .34626 Mdot
.6175 .46529 Mdot
.68678 .40443 Mdot
.64369 .48681 Mdot
.55132 .28241 Mdot
.36976 .65425 Mdot
.38918 .42509 Mdot
.65287 .50159 Mdot
.60716 .62589 Mdot
.27294 .50887 Mdot
.27945 .49697 Mdot
.66874 .47633 Mdot
.28481 .47829 Mdot
.62516 .47085 Mdot
.38627 .68104 Mdot
.33715 .81122 Mdot
.60558 .48331 Mdot
.57704 .54602 Mdot
.25236 .50478 Mdot
.37413 .44678 Mdot
.40272 .63443 Mdot
.74961 .40008 Mdot
.39593 .24024 Mdot
.28411 .48444 Mdot
.73675 .48546 Mdot
.36871 .69968 Mdot
.38859 .44539 Mdot
.42242 .67885 Mdot
.64403 .47816 Mdot
.61601 .45595 Mdot
.6687 .49233 Mdot
.6234 .45773 Mdot
.65189 .3864 Mdot
.58332 .44746 Mdot
.63535 .30191 Mdot
.61778 .5053 Mdot
.72966 .53835 Mdot
.3089 .46895 Mdot
.56046 .50055 Mdot
.45431 .6094 Mdot
.62748 .44662 Mdot
.49377 .25402 Mdot
.32058 .47628 Mdot
.42151 .33868 Mdot
.3071 .47778 Mdot
.39425 .69759 Mdot
.27033 .4988 Mdot
.64467 .50335 Mdot
.50624 .31313 Mdot
.36798 .67921 Mdot
.51546 .4011 Mdot
.35804 .65507 Mdot
.6134 .48872 Mdot
.30516 .53752 Mdot
.40842 .69423 Mdot
.57205 .44706 Mdot
.50903 .31329 Mdot
.71335 .59883 Mdot
.47095 .36251 Mdot
.62297 .49144 Mdot
.62799 .49387 Mdot
.38636 .4278 Mdot
.27286 .50715 Mdot
.47318 .31224 Mdot
.3919 .78288 Mdot
.5319 .72291 Mdot
.51373 .32769 Mdot
.55281 .50247 Mdot
.48216 .51374 Mdot
.47973 .32237 Mdot
.73554 .57435 Mdot
.28602 .51178 Mdot
.49766 .36172 Mdot
.68619 .47891 Mdot
.59647 .34728 Mdot
.56641 .72831 Mdot
.40752 .70177 Mdot
.53178 .57054 Mdot
.37083 .66275 Mdot
.30824 .52244 Mdot
.41087 .65217 Mdot
.30647 .47084 Mdot
.52618 .43561 Mdot
.44678 .58369 Mdot
.3306 .48377 Mdot
.2544 .51563 Mdot
.38851 .66614 Mdot
.66948 .48157 Mdot
.41714 .55851 Mdot
.61009 .56176 Mdot
.57439 .51444 Mdot
.30183 .46165 Mdot
.51159 .35747 Mdot
.48854 .29097 Mdot
.67224 .5757 Mdot
.49206 .29954 Mdot
.37257 .68556 Mdot
.47085 .42745 Mdot
.73905 .44018 Mdot
.30217 .49739 Mdot
.43751 .618 Mdot
.66395 .52158 Mdot
.39791 .66281 Mdot
.37378 .68986 Mdot
.28136 .47679 Mdot
.58584 .32362 Mdot
.57757 .517 Mdot
.52891 .357 Mdot
.4884 .35675 Mdot
.47935 .3253 Mdot
.46928 .34291 Mdot
.67738 .73699 Mdot
.3283 .47454 Mdot
.52131 .34776 Mdot
.67625 .49831 Mdot
.59844 .48098 Mdot
.41765 .43425 Mdot
.57151 .68954 Mdot
.66017 .43855 Mdot
.60678 .56 Mdot
.64454 .46982 Mdot
.41238 .67658 Mdot
.53501 .49357 Mdot
.41443 .42185 Mdot
.40375 .6465 Mdot
.40718 .65224 Mdot
.4048 .44336 Mdot
.53049 .43654 Mdot
.44253 .19074 Mdot
.66535 .48695 Mdot
.46712 .25324 Mdot
.40823 .67242 Mdot
.5672 .61895 Mdot
.72078 .53513 Mdot
.62526 .53821 Mdot
.38073 .5745 Mdot
.38085 .68411 Mdot
.54767 .33568 Mdot
.63967 .47893 Mdot
.38941 .4383 Mdot
.55441 .72774 Mdot
.55336 .53126 Mdot
.39753 .44837 Mdot
.51058 .34214 Mdot
.34084 .75199 Mdot
.53593 .33716 Mdot
.40582 .69954 Mdot
.59055 .54501 Mdot
.58259 .90087 Mdot
.39217 .69105 Mdot
.34909 .38049 Mdot
.44634 .58631 Mdot
.60755 .48374 Mdot
.36413 .67427 Mdot
.51566 .27754 Mdot
.3125 .45998 Mdot
.49028 .53295 Mdot
.52129 .33493 Mdot
.38659 .43935 Mdot
.41419 .43679 Mdot
.38926 .6731 Mdot
.48191 .34757 Mdot
.67918 .52323 Mdot
.5049 .30199 Mdot
.29242 .50532 Mdot
.64208 .51495 Mdot
.40263 .24533 Mdot
.56806 .50324 Mdot
.50312 .30317 Mdot
.34737 .67865 Mdot
.59173 .69835 Mdot
.61415 .51519 Mdot
.419 .3015 Mdot
.61958 .45754 Mdot
.30937 .48611 Mdot
.51356 .62076 Mdot
.59849 .24024 Mdot
.65763 .46943 Mdot
.66124 .52341 Mdot
.3119 .5144 Mdot
.65715 .47135 Mdot
.61908 .54221 Mdot
.38928 .4623 Mdot
.481 .31911 Mdot
.62357 .46298 Mdot
.37234 .6574 Mdot
.63211 .22636 Mdot
.6477 .49833 Mdot
.28992 .43391 Mdot
.69591 .60271 Mdot
.49183 .59551 Mdot
.59247 .55712 Mdot
.62226 .65728 Mdot
.63159 .49102 Mdot
.61832 .53687 Mdot
.66704 .48348 Mdot
.72665 .39293 Mdot
.38311 .6682 Mdot
.39591 .65155 Mdot
.54663 .72666 Mdot
.67739 .60698 Mdot
.5452 .70873 Mdot
.31234 .51289 Mdot
.43938 .62072 Mdot
.40158 .42207 Mdot
.5032 .3392 Mdot
.64942 .49644 Mdot
.36048 .65464 Mdot
.63636 .46973 Mdot
.64396 .52656 Mdot
.37489 .68053 Mdot
.37758 .68925 Mdot
.39447 .71927 Mdot
.57035 .73005 Mdot
.50456 .32834 Mdot
.6591 .49275 Mdot
.58812 .71179 Mdot
.67458 .4685 Mdot
.45441 .50258 Mdot
.50587 .32693 Mdot
.50122 .30211 Mdot
.50069 .28819 Mdot
.60159 .50062 Mdot
.64372 .50682 Mdot
.30463 .46584 Mdot
.51154 .27915 Mdot
.27466 .4936 Mdot
.36458 .67243 Mdot
.39425 .65989 Mdot
.64463 .47868 Mdot
.69849 .51996 Mdot
.56187 .68838 Mdot
.38309 .70484 Mdot
.42516 .43735 Mdot
.5445 .72388 Mdot
.63634 .45014 Mdot
.36703 .66706 Mdot
.53218 .70412 Mdot
.5398 .24432 Mdot
.38067 .2309 Mdot
.56785 .73244 Mdot
.66913 .47651 Mdot
.74732 .33721 Mdot
.6551 .69923 Mdot
.53039 .7246 Mdot
.3133 .48149 Mdot
.60632 .47198 Mdot
.23756 .53945 Mdot
.57418 .68124 Mdot
.66668 .72413 Mdot
.37345 .6764 Mdot
.59357 .56768 Mdot
.54217 .50002 Mdot
.73402 .43434 Mdot
.58767 .6882 Mdot
.50366 .30493 Mdot
.47811 .3497 Mdot
.65739 .4642 Mdot
.43873 .60972 Mdot
.32521 .50193 Mdot
.38254 .70912 Mdot
.38422 .64594 Mdot
.47548 .32963 Mdot
.4674 .4487 Mdot
.37059 .65929 Mdot
.59592 .51815 Mdot
.53671 .67768 Mdot
.59959 .42663 Mdot
.69336 .74515 Mdot
.60512 .19864 Mdot
.58929 .55535 Mdot
.59245 .70397 Mdot
.27146 .51037 Mdot
.29063 .47117 Mdot
.29369 .47356 Mdot
.39064 .65938 Mdot
.51842 .53982 Mdot
.37574 .64863 Mdot
.26058 .42736 Mdot
.55512 .69385 Mdot
.73458 .60266 Mdot
.68129 .47248 Mdot
.60779 .48507 Mdot
.66671 .52511 Mdot
.66873 .49495 Mdot
.63107 .4896 Mdot
.29107 .46467 Mdot
.38736 .71313 Mdot
.20453 .57277 Mdot
.48547 .34333 Mdot
.25826 .38418 Mdot
.40668 .6922 Mdot
.40628 .44837 Mdot
.5739 .70322 Mdot
.64472 .63529 Mdot
.53451 .67523 Mdot
.38825 .70577 Mdot
.58967 .50505 Mdot
.48634 .36265 Mdot
.79399 .53022 Mdot
.62349 .50167 Mdot
.37775 .70532 Mdot
.42544 .66543 Mdot
.587 .31404 Mdot
.68484 .44159 Mdot
.42973 .61015 Mdot
.48637 .51292 Mdot
.57597 .7306 Mdot
.59283 .4678 Mdot
.58214 .61161 Mdot
.38162 .67211 Mdot
.40188 .68418 Mdot
.53336 .72851 Mdot
.56609 .39399 Mdot
.51011 .35275 Mdot
.39188 .42228 Mdot
.31648 .48272 Mdot
.60606 .49657 Mdot
.38496 .6601 Mdot
.54631 .36236 Mdot
.45889 .52622 Mdot
.30207 .48331 Mdot
.40459 .64584 Mdot
.61496 .4604 Mdot
.65507 .46482 Mdot
.54816 .70279 Mdot
.42507 .73895 Mdot
.60961 .56168 Mdot
.35955 .37673 Mdot
.4847 .47289 Mdot
.44629 .59316 Mdot
.63751 .46586 Mdot
.48624 .29741 Mdot
.40293 .44274 Mdot
.5681 .71976 Mdot
.66131 .4511 Mdot
.42065 .19954 Mdot
.53622 .32616 Mdot
.27656 .48869 Mdot
.39801 .44422 Mdot
.55079 .5733 Mdot
.61957 .45809 Mdot
.64368 .48634 Mdot
.67767 .48729 Mdot
.42354 .19391 Mdot
.37871 .65089 Mdot
.47044 .32116 Mdot
.54217 .70836 Mdot
.50919 .30145 Mdot
.41609 .66774 Mdot
.43445 .59705 Mdot
.66361 .46084 Mdot
.53205 .32131 Mdot
.51321 .30788 Mdot
.30241 .4947 Mdot
.28577 .51534 Mdot
.38157 .72052 Mdot
.62025 .46028 Mdot
.39417 .42401 Mdot
.51457 .35333 Mdot
.37618 .71129 Mdot
.5489 .7031 Mdot
.34311 .48197 Mdot
.61621 .50543 Mdot
.38721 .67141 Mdot
.60154 .55609 Mdot
.48655 .3302 Mdot
.39691 .70125 Mdot
.39269 .44898 Mdot
.5751 .69194 Mdot
.60656 .46413 Mdot
.21509 .61601 Mdot
.39087 .44195 Mdot
.60729 .50916 Mdot
.59473 .19995 Mdot
.4387 .60796 Mdot
.51697 .39429 Mdot
.36058 .66411 Mdot
.39261 .42785 Mdot
.46938 .33206 Mdot
.60998 .35132 Mdot
.40032 .68057 Mdot
.73657 .3016 Mdot
.43545 .54112 Mdot
.66408 .49037 Mdot
.51607 .34036 Mdot
.51445 .68946 Mdot
.36485 .36276 Mdot
.647 .69835 Mdot
.62118 .4766 Mdot
.37177 .66204 Mdot
.55375 .72694 Mdot
.27843 .49747 Mdot
.28088 .43726 Mdot
.72563 .72648 Mdot
.39651 .64463 Mdot
.6526 .49465 Mdot
.50839 .35872 Mdot
.27877 .48439 Mdot
.73141 .28706 Mdot
.3525 .69784 Mdot
.36194 .66602 Mdot
.65681 .53273 Mdot
.54451 .71273 Mdot
.24329 .54079 Mdot
.38934 .65124 Mdot
.3944 .7119 Mdot
.41689 .45826 Mdot
.54907 .72966 Mdot
.67604 .48942 Mdot
.67295 .5755 Mdot
.68113 .50751 Mdot
.29496 .39421 Mdot
.39266 .42684 Mdot
.48751 .34497 Mdot
.64049 .4952 Mdot
.20288 .60125 Mdot
.39449 .68376 Mdot
.48739 .51063 Mdot
.2988 .44643 Mdot
.28552 .51494 Mdot
.37499 .66478 Mdot
.63408 .47417 Mdot
.33383 .45943 Mdot
.55375 .6904 Mdot
.67755 .48239 Mdot
.64731 .50542 Mdot
.50684 .27582 Mdot
.3003 .50491 Mdot
.62895 .22222 Mdot
.2809 .50381 Mdot
.32381 .49275 Mdot
.48257 .28326 Mdot
.65654 .46295 Mdot
.39226 .7015 Mdot
.34427 .6834 Mdot
.64399 .55289 Mdot
.56499 .61918 Mdot
.51312 .34913 Mdot
.33917 .70429 Mdot
.40446 .19917 Mdot
.65156 .54125 Mdot
.42182 .44047 Mdot
.54769 .28181 Mdot
.32083 .45932 Mdot
.65908 .47987 Mdot
.49594 .3372 Mdot
.37314 .71718 Mdot
.37883 .65748 Mdot
.65035 .43127 Mdot
.28185 .47515 Mdot
.53388 .69901 Mdot
.37261 .6917 Mdot
.44487 .51353 Mdot
.61559 .48434 Mdot
.41904 .41493 Mdot
.37242 .69383 Mdot
.65265 .2011 Mdot
.19907 .58859 Mdot
.47757 .33104 Mdot
.63576 .53359 Mdot
.49979 .36592 Mdot
.54088 .70101 Mdot
.42001 .66509 Mdot
.29476 .46689 Mdot
.64426 .40638 Mdot
.34485 .77302 Mdot
.39084 .66246 Mdot
.50966 .33707 Mdot
.65343 .49217 Mdot
.72914 .50425 Mdot
.61058 .4724 Mdot
.74198 .66866 Mdot
.52808 .70255 Mdot
.27785 .5275 Mdot
.27379 .4809 Mdot
.65489 .52698 Mdot
.58687 .7083 Mdot
.34948 .70616 Mdot
.37559 .67933 Mdot
.38287 .82787 Mdot
.39559 .44839 Mdot
.36781 .73274 Mdot
.60262 .50125 Mdot
.36844 .70814 Mdot
.74713 .34622 Mdot
.27211 .48714 Mdot
.67784 .52141 Mdot
.37295 .64024 Mdot
.29912 .37119 Mdot
.48361 .51569 Mdot
.61748 .48081 Mdot
.70746 .49526 Mdot
.31018 .47895 Mdot
.25369 .34466 Mdot
.3592 .66387 Mdot
.67357 .46896 Mdot
.32247 .45008 Mdot
.51203 .42474 Mdot
.39846 .77899 Mdot
.50438 .32787 Mdot
.36259 .64241 Mdot
.32117 .48945 Mdot
.58933 .56354 Mdot
.56404 .68682 Mdot
.35967 .71401 Mdot
.36308 .64736 Mdot
.64073 .52026 Mdot
.65199 .43623 Mdot
.70451 .48024 Mdot
.51251 .34492 Mdot
.313 .50486 Mdot
.65745 .51872 Mdot
.46224 .4941 Mdot
.66707 .49853 Mdot
.31847 .49849 Mdot
.4862 .9139 Mdot
.59129 .4904 Mdot
.61283 .50321 Mdot
.74558 .46828 Mdot
.47497 .30828 Mdot
.48452 .31076 Mdot
.47386 .47803 Mdot
.59801 .4952 Mdot
.42803 .52831 Mdot
.50392 .33078 Mdot
.51826 .33465 Mdot
.42816 .53107 Mdot
.63722 .51592 Mdot
.36197 .47025 Mdot
.27978 .48279 Mdot
.28666 .51523 Mdot
.48468 .31523 Mdot
.61433 .42398 Mdot
.27461 .51426 Mdot
.65233 .38103 Mdot
.39622 .70287 Mdot
.58291 .61128 Mdot
.50703 .30243 Mdot
.48071 .54405 Mdot
.27864 .50918 Mdot
.73607 .26794 Mdot
.78519 .51761 Mdot
.65966 .54243 Mdot
.65877 .46789 Mdot
.5568 .71114 Mdot
.70115 .44334 Mdot
.41151 .44279 Mdot
.28835 .4745 Mdot
.32375 .56928 Mdot
.50434 .32154 Mdot
.60009 .48722 Mdot
.6365 .69637 Mdot
.62673 .20213 Mdot
.66034 .58639 Mdot
.51982 .32764 Mdot
.50607 .31745 Mdot
.35538 .68144 Mdot
.39235 .70582 Mdot
.66557 .46554 Mdot
.29981 .46932 Mdot
.48858 .3587 Mdot
.30795 .50504 Mdot
.37996 .67287 Mdot
.40027 .69785 Mdot
.41998 .42596 Mdot
.57571 .50554 Mdot
.37554 .66791 Mdot
.24585 .45364 Mdot
.46098 .495 Mdot
.50014 .27734 Mdot
.19164 .50255 Mdot
.76221 .30681 Mdot
.69221 .42143 Mdot
.55548 .72797 Mdot
.52262 .43587 Mdot
.26358 .49003 Mdot
.65804 .52477 Mdot
.65036 .48287 Mdot
.41013 .42767 Mdot
.26306 .49602 Mdot
.56982 .70719 Mdot
.27085 .5056 Mdot
.57534 .71459 Mdot
.39917 .65392 Mdot
.64095 .50089 Mdot
.63876 .44643 Mdot
.28042 .49556 Mdot
.36021 .69569 Mdot
.40917 .69315 Mdot
.57555 .7229 Mdot
.64969 .62497 Mdot
.3875 .67389 Mdot
.50764 .30245 Mdot
.65887 .25261 Mdot
.41468 .43512 Mdot
.63887 .47913 Mdot
.62775 .66249 Mdot
.62566 .3472 Mdot
.66428 .49544 Mdot
.39553 .44387 Mdot
.33184 .81887 Mdot
.6443 .50041 Mdot
.50633 .86076 Mdot
.40887 .42216 Mdot
.49247 .29197 Mdot
.3688 .69752 Mdot
.39487 .447 Mdot
.53576 .50399 Mdot
.33159 .69541 Mdot
.60826 .55352 Mdot
.513 .35157 Mdot
.52065 .30229 Mdot
.43192 .58392 Mdot
.29247 .39415 Mdot
.54175 .71053 Mdot
.56667 .69744 Mdot
.39903 .67779 Mdot
.22763 .47433 Mdot
.63924 .42722 Mdot
.56652 .70001 Mdot
.32524 .54318 Mdot
.66243 .52391 Mdot
.4384 .60326 Mdot
.40896 .55595 Mdot
.47803 .30968 Mdot
.55872 .49648 Mdot
.39726 .68116 Mdot
.50964 .3361 Mdot
.42422 .56571 Mdot
.67457 .52258 Mdot
.50558 .32489 Mdot
.3041 .51136 Mdot
.40914 .50871 Mdot
.49936 .29899 Mdot
.48519 .53212 Mdot
.28256 .48873 Mdot
.43692 .60758 Mdot
.72203 .63684 Mdot
.50225 .13355 Mdot
.29308 .47123 Mdot
.36927 .70193 Mdot
.38604 .66151 Mdot
.38815 .67751 Mdot
.52015 .33952 Mdot
.38256 .69121 Mdot
.49559 .35229 Mdot
.25493 .51074 Mdot
.63734 .63344 Mdot
.55403 .7047 Mdot
.54027 .76157 Mdot
.49767 .3098 Mdot
.27788 .41541 Mdot
.16922 .52131 Mdot
.67418 .48817 Mdot
.32998 .48358 Mdot
.58848 .71524 Mdot
.49051 .45819 Mdot
.55977 .71164 Mdot
.36748 .69849 Mdot
.58533 .61003 Mdot
.62474 .47008 Mdot
.47756 .23748 Mdot
.55186 .72574 Mdot
.52094 .33106 Mdot
.61661 .52105 Mdot
.34198 .66506 Mdot
.54514 .69304 Mdot
.56398 .72732 Mdot
.63251 .48787 Mdot
.51624 .30064 Mdot
.39137 .70321 Mdot
.26492 .48372 Mdot
.51752 .70327 Mdot
.71044 .49297 Mdot
.66573 .47688 Mdot
.58859 .49748 Mdot
.48719 .49952 Mdot
.21042 .51736 Mdot
.28558 .48647 Mdot
.65953 .72197 Mdot
.39676 .66103 Mdot
.64946 .70159 Mdot
.38153 .37558 Mdot
.55972 .66436 Mdot
.39502 .42558 Mdot
.39211 .42672 Mdot
.62139 .48491 Mdot
.17917 .43836 Mdot
.69801 .57621 Mdot
.28443 .45427 Mdot
.41176 .43354 Mdot
.40746 .69658 Mdot
.53088 .29754 Mdot
.55562 .44337 Mdot
.67641 .45902 Mdot
.26141 .4941 Mdot
.381 .67706 Mdot
.18618 .3998 Mdot
.55489 .69508 Mdot
.4866 .4595 Mdot
.6233 .45895 Mdot
.62748 .48137 Mdot
.29592 .4892 Mdot
.29981 .46663 Mdot
.43391 .44391 Mdot
.48941 .58133 Mdot
.41033 .23946 Mdot
.28557 .52214 Mdot
.1855 .39971 Mdot
.49277 .23025 Mdot
.48706 .31871 Mdot
.42013 .44039 Mdot
.30237 .51599 Mdot
.64039 .49311 Mdot
.48954 .29253 Mdot
.67016 .58934 Mdot
.54821 .34454 Mdot
.44025 .60268 Mdot
.44444 .52548 Mdot
.62748 .45437 Mdot
.47537 .35686 Mdot
.50946 .33293 Mdot
.47185 .35624 Mdot
.40709 .44145 Mdot
.64164 .46636 Mdot
.6712 .4852 Mdot
.64593 .5005 Mdot
.72938 .48996 Mdot
.61829 .48851 Mdot
.37905 .37236 Mdot
.46093 .48157 Mdot
.45928 .75638 Mdot
.62453 .50542 Mdot
.31706 .50417 Mdot
.63917 .50044 Mdot
.58588 .69944 Mdot
.59979 .47241 Mdot
.44167 .6034 Mdot
.29183 .47852 Mdot
.57696 .37275 Mdot
.36269 .62485 Mdot
.64772 .44931 Mdot
.53588 .70637 Mdot
.19853 .49944 Mdot
.64633 .71721 Mdot
.40692 .46191 Mdot
.50528 .30223 Mdot
.40369 .70853 Mdot
.33286 .47039 Mdot
.39729 .69688 Mdot
.67448 .52894 Mdot
.42454 .43114 Mdot
.84114 .45236 Mdot
.48461 .55363 Mdot
.63935 .49478 Mdot
.57655 .50531 Mdot
.48244 .30337 Mdot
.3926 .68667 Mdot
.45271 .3648 Mdot
.66611 .52357 Mdot
.55719 .68212 Mdot
.58665 .69238 Mdot
.3944 .59522 Mdot
.38621 .51122 Mdot
.76533 .46911 Mdot
.29436 .48794 Mdot
.38642 .6571 Mdot
.5838 .68493 Mdot
.5095 .25835 Mdot
.32536 .5007 Mdot
.32042 .45891 Mdot
.30257 .50395 Mdot
.6109 .48918 Mdot
.4198 .42961 Mdot
.35668 .54497 Mdot
.39039 .4443 Mdot
.67612 .51062 Mdot
.36517 .64613 Mdot
.38872 .44487 Mdot
.54997 .71162 Mdot
.32517 .4839 Mdot
.41121 .68317 Mdot
.62536 .49427 Mdot
.49855 .32804 Mdot
.64985 .75841 Mdot
.20896 .64393 Mdot
.43834 .61109 Mdot
.43831 .61121 Mdot
.51305 .29272 Mdot
.43467 .25774 Mdot
.32086 .51554 Mdot
.59201 .32821 Mdot
.57313 .64082 Mdot
.63742 .55463 Mdot
.41616 .81454 Mdot
.37249 .65024 Mdot
.36822 .68103 Mdot
.61757 .47237 Mdot
.36343 .70766 Mdot
.60531 .47742 Mdot
.35716 .66897 Mdot
.34062 .36799 Mdot
.68132 .46787 Mdot
.37138 .68433 Mdot
.67497 .42967 Mdot
.61342 .51442 Mdot
.48983 .29614 Mdot
.36215 .71466 Mdot
.65903 .54244 Mdot
.84658 .50924 Mdot
.29753 .49712 Mdot
.40829 .44099 Mdot
.44772 .61525 Mdot
.27195 .50226 Mdot
.49872 .35594 Mdot
.59599 .49455 Mdot
.55146 .69338 Mdot
.49123 .3144 Mdot
.34315 .65447 Mdot
.54917 .72257 Mdot
.46935 .42893 Mdot
.48603 .31573 Mdot
.41564 .43026 Mdot
.57761 .6946 Mdot
.60872 .55336 Mdot
.36998 .67958 Mdot
.20256 .61224 Mdot
.39632 .44632 Mdot
.62893 .46842 Mdot
.36376 .64045 Mdot
.2713 .50569 Mdot
.65541 .45704 Mdot
.38337 .65886 Mdot
.40213 .44418 Mdot
.61471 .51051 Mdot
.60165 .5069 Mdot
.57554 .39504 Mdot
.5154 .63525 Mdot
.55169 .70705 Mdot
.47398 .29043 Mdot
.67668 .49987 Mdot
.58549 .71304 Mdot
.22748 .60817 Mdot
.6853 .49288 Mdot
.52952 .34209 Mdot
.60927 .37382 Mdot
.37371 .7085 Mdot
.27269 .4844 Mdot
.34848 .69435 Mdot
.53962 .71905 Mdot
.17525 .64849 Mdot
.41815 .4403 Mdot
.58712 .51807 Mdot
.63123 .54429 Mdot
.42195 .66509 Mdot
.51082 .33069 Mdot
.41835 .23837 Mdot
.60088 .4725 Mdot
.57286 .51605 Mdot
.6366 .48352 Mdot
.2252 .61998 Mdot
.51682 .34263 Mdot
.6387 .48143 Mdot
.71232 .50245 Mdot
.65262 .53853 Mdot
.53753 .69588 Mdot
.74707 .59259 Mdot
.65815 .49908 Mdot
.65319 .86726 Mdot
.41622 .41998 Mdot
.37773 .68166 Mdot
.48582 .52399 Mdot
.45551 .64607 Mdot
.66845 .77592 Mdot
.50407 .35267 Mdot
.48063 .25013 Mdot
.39542 .69972 Mdot
.62937 .77648 Mdot
.43423 .26951 Mdot
.60622 .51469 Mdot
.60896 .46712 Mdot
.36756 .69856 Mdot
.38092 .71132 Mdot
.42435 .42594 Mdot
.64261 .44037 Mdot
.56687 .49186 Mdot
.34888 .67044 Mdot
.61965 .49825 Mdot
.62975 .32591 Mdot
.30737 .45529 Mdot
.48383 .31499 Mdot
.27992 .49874 Mdot
.31012 .45751 Mdot
.64973 .40037 Mdot
.48631 .47515 Mdot
.31596 .47412 Mdot
.28347 .45802 Mdot
.51439 .73562 Mdot
.74043 .44989 Mdot
.53893 .69333 Mdot
.39543 .47682 Mdot
.39499 .67448 Mdot
.64418 .46746 Mdot
.52239 .33806 Mdot
.78712 .63882 Mdot
.35712 .26171 Mdot
.59407 .59947 Mdot
.67399 .49474 Mdot
.39346 .6813 Mdot
.39757 .44555 Mdot
.68478 .48064 Mdot
.6531 .69981 Mdot
.6234 .47864 Mdot
.39113 .70767 Mdot
.73861 .43953 Mdot
.33715 .43882 Mdot
.28856 .52291 Mdot
.54038 .31544 Mdot
.64351 .49887 Mdot
.49477 .34274 Mdot
.31546 .46841 Mdot
.5765 .72576 Mdot
.56206 .70564 Mdot
.64238 .44766 Mdot
.44626 .58335 Mdot
.51425 .6796 Mdot
.60835 .51538 Mdot
.64089 .51828 Mdot
.39638 .42558 Mdot
.64139 .5175 Mdot
.6673 .46097 Mdot
.66023 .51639 Mdot
.67 .45621 Mdot
.31743 .50891 Mdot
.48223 .39081 Mdot
.62936 .44144 Mdot
.62203 .54617 Mdot
.27802 .46737 Mdot
.6866 .5255 Mdot
.30586 .47574 Mdot
.37909 .25428 Mdot
.31598 .47927 Mdot
.56063 .70518 Mdot
.35468 .64632 Mdot
.46642 .26075 Mdot
.48776 .35804 Mdot
.31611 .50685 Mdot
.577 .70053 Mdot
.29257 .47261 Mdot
.38372 .65385 Mdot
.19563 .5352 Mdot
.45602 .32257 Mdot
.44971 .48917 Mdot
.74386 .45863 Mdot
.41888 .41421 Mdot
.3589 .7004 Mdot
.47758 .33503 Mdot
.32202 .43639 Mdot
.6531 .52715 Mdot
.54724 .69824 Mdot
.6222 .4846 Mdot
.32619 .48428 Mdot
.39358 .67848 Mdot
.36752 .46733 Mdot
.55213 .70788 Mdot
.18493 .64234 Mdot
.35823 .65689 Mdot
.60131 .5333 Mdot
.27851 .4674 Mdot
.20124 .52765 Mdot
.31089 .47556 Mdot
.63868 .63396 Mdot
.56046 .33781 Mdot
.76699 .66683 Mdot
.50181 .31376 Mdot
.43246 .42693 Mdot
.51332 .17669 Mdot
.40877 .34162 Mdot
.49103 .32672 Mdot
.3665 .6221 Mdot
.61509 .49137 Mdot
.6682 .50046 Mdot
.58087 .48268 Mdot
.52896 .37564 Mdot
.67753 .48811 Mdot
.41504 .43985 Mdot
.48125 .48142 Mdot
.28768 .5545 Mdot
.39753 .71278 Mdot
.60875 .47268 Mdot
.30077 .46167 Mdot
.32394 .49874 Mdot
.38571 .44159 Mdot
.2877 .5071 Mdot
.62581 .51352 Mdot
.49844 .31073 Mdot
.41838 .55956 Mdot
.54144 .70097 Mdot
.36219 .38688 Mdot
.55588 .64537 Mdot
.52168 .68635 Mdot
.6538 .53918 Mdot
.3993 .69889 Mdot
.36328 .79272 Mdot
.66512 .51659 Mdot
.50517 .33328 Mdot
.62642 .54339 Mdot
.66066 .51041 Mdot
.65643 .49595 Mdot
.38767 .65769 Mdot
.48023 .52241 Mdot
.62052 .49945 Mdot
.31694 .47389 Mdot
.42931 .53354 Mdot
.67103 .45015 Mdot
.33182 .57322 Mdot
.44135 .60207 Mdot
.41622 .41456 Mdot
.50346 .27696 Mdot
.38435 .70216 Mdot
.50367 .31924 Mdot
.51139 .37593 Mdot
.49787 .35594 Mdot
.33565 .55447 Mdot
.59701 .34444 Mdot
.53345 .86123 Mdot
.75067 .35984 Mdot
.74519 .44304 Mdot
.53429 .34682 Mdot
.27031 .60426 Mdot
.49107 .33144 Mdot
.50026 .35493 Mdot
.42428 .88176 Mdot
.52797 .33411 Mdot
.64467 .4775 Mdot
.60088 .46529 Mdot
.49309 .21925 Mdot
.52133 .74076 Mdot
.60499 .50333 Mdot
.67461 .47999 Mdot
.58546 .68797 Mdot
.55707 .39841 Mdot
.42724 .42634 Mdot
.48257 .4577 Mdot
.41816 .44604 Mdot
.63161 .48822 Mdot
.63482 .45208 Mdot
.6367 .43348 Mdot
.55005 .16196 Mdot
.75907 .68718 Mdot
.5079 .292 Mdot
.67289 .54714 Mdot
.37797 .42838 Mdot
.61304 .53648 Mdot
.63644 .54312 Mdot
.64668 .50271 Mdot
.3927 .70142 Mdot
.5271 .29397 Mdot
.60879 .56097 Mdot
.39628 .39585 Mdot
.62633 .45613 Mdot
.54549 .65487 Mdot
.56991 .73532 Mdot
.63536 .47388 Mdot
.5298 .33136 Mdot
.67121 .49708 Mdot
.50117 .3643 Mdot
.48324 .32073 Mdot
.57216 .49244 Mdot
.36527 .53617 Mdot
.53554 .30718 Mdot
.60481 .51354 Mdot
.36037 .69782 Mdot
.3556 .37791 Mdot
.6304 .46926 Mdot
.54797 .71612 Mdot
.65993 .48084 Mdot
.53468 .702 Mdot
.64716 .51136 Mdot
.38826 .44217 Mdot
.5955 .24505 Mdot
.40229 .68141 Mdot
.51617 .69954 Mdot
.36424 .70639 Mdot
.57238 .45072 Mdot
.52912 .34998 Mdot
.35925 .45064 Mdot
.73811 .71731 Mdot
.39809 .42492 Mdot
.66303 .73309 Mdot
.42068 .52747 Mdot
.28107 .46937 Mdot
.46874 .33799 Mdot
.7241 .43052 Mdot
.35125 .57421 Mdot
.4155 .70006 Mdot
.41112 .65712 Mdot
.40709 .78511 Mdot
.33773 .81191 Mdot
.61765 .50145 Mdot
.2364 .54045 Mdot
.63133 .29048 Mdot
.7161 .46557 Mdot
.68939 .45768 Mdot
.35809 .65132 Mdot
.60517 .50418 Mdot
.51771 .55951 Mdot
.38757 .6662 Mdot
.56808 .69369 Mdot
.48903 .34556 Mdot
.58311 .71022 Mdot
.32782 .26309 Mdot
.39795 .46198 Mdot
.38024 .66691 Mdot
.66841 .45256 Mdot
.60451 .49028 Mdot
.46933 .32228 Mdot
.73863 .29952 Mdot
.48149 .31799 Mdot
.54003 .70929 Mdot
.40182 .66975 Mdot
.80576 .53861 Mdot
.65906 .48642 Mdot
.5166 .31157 Mdot
.36378 .62452 Mdot
.65403 .46478 Mdot
.27541 .48098 Mdot
.67393 .49771 Mdot
.51597 .30844 Mdot
.64203 .5172 Mdot
.4979 .31278 Mdot
.35687 .68026 Mdot
.63389 .4466 Mdot
.64002 .45074 Mdot
.66407 .72523 Mdot
.56891 .70892 Mdot
.53191 .34493 Mdot
.51958 .55964 Mdot
.68107 .50738 Mdot
.65295 .69123 Mdot
.64188 .50074 Mdot
.73758 .48021 Mdot
.69168 .49846 Mdot
.41713 .43774 Mdot
.63466 .54405 Mdot
.62921 .47005 Mdot
.7595 .34028 Mdot
.74626 .34081 Mdot
.72296 .44653 Mdot
.28692 .51567 Mdot
.52299 .31329 Mdot
.38307 .66207 Mdot
.37978 .71734 Mdot
.38307 .69486 Mdot
.56047 .74584 Mdot
.68309 .54125 Mdot
.6265 .46603 Mdot
.25154 .51496 Mdot
.56318 .69725 Mdot
.5192 .32064 Mdot
.55797 .70136 Mdot
.48948 .47437 Mdot
.55131 .72005 Mdot
.41324 .4427 Mdot
.19888 .58443 Mdot
.63054 .34026 Mdot
.56399 .71991 Mdot
.48194 .31879 Mdot
.43233 .51347 Mdot
.62859 .55608 Mdot
.27423 .38775 Mdot
.55867 .68187 Mdot
.38395 .78455 Mdot
.61859 .50952 Mdot
.4946 .53339 Mdot
.306 .4797 Mdot
.5829 .70972 Mdot
.30087 .50365 Mdot
.67053 .4986 Mdot
.49702 .3942 Mdot
.50737 .33884 Mdot
.30225 .45648 Mdot
.65626 .53494 Mdot
.58336 .70891 Mdot
.37563 .66993 Mdot
.73938 .44513 Mdot
.27488 .46699 Mdot
.6441 .76112 Mdot
.64747 .69972 Mdot
.4002 .66742 Mdot
.75729 .44578 Mdot
.31095 .49276 Mdot
.64348 .55395 Mdot
.58228 .56508 Mdot
.67077 .51086 Mdot
.41105 .6898 Mdot
.36767 .68271 Mdot
.43014 .37105 Mdot
.63244 .45075 Mdot
.61916 .44546 Mdot
.51432 .28668 Mdot
.40063 .66323 Mdot
.49738 .35676 Mdot
.47133 .32991 Mdot
.36609 .69861 Mdot
.47696 .33001 Mdot
.55419 .72602 Mdot
.52501 .54191 Mdot
.31285 .48983 Mdot
.27832 .47666 Mdot
.3775 .66663 Mdot
.40573 .66111 Mdot
.40168 .69752 Mdot
.65844 .52999 Mdot
.48 .34632 Mdot
.63167 .53305 Mdot
.64769 .49653 Mdot
.53136 .27622 Mdot
.50087 .28247 Mdot
.6359 .53881 Mdot
.40396 .55469 Mdot
.53812 .68799 Mdot
.37372 .68577 Mdot
.3059 .50775 Mdot
.66018 .75809 Mdot
.27737 .4702 Mdot
.68086 .50265 Mdot
.29837 .37451 Mdot
.52014 .3383 Mdot
.55839 .71168 Mdot
.44041 .60921 Mdot
.55383 .7097 Mdot
.30641 .45574 Mdot
.48862 .28402 Mdot
.46822 .43947 Mdot
.63198 .44987 Mdot
.48688 .49606 Mdot
.69744 .66949 Mdot
.3867 .37917 Mdot
.31101 .50716 Mdot
.67488 .48876 Mdot
.40517 .42284 Mdot
.588 .31312 Mdot
.62332 .46769 Mdot
.6758 .52525 Mdot
.45755 .68012 Mdot
.63761 .54514 Mdot
.47996 .29068 Mdot
.43893 .59064 Mdot
.65486 .44574 Mdot
.57463 .44922 Mdot
.37959 .83813 Mdot
.61152 .50972 Mdot
.64152 .44956 Mdot
.6503 .47618 Mdot
.65599 .52749 Mdot
.50371 .36544 Mdot
.42832 .72262 Mdot
.30811 .46228 Mdot
.52546 .54285 Mdot
.308 .49981 Mdot
.36746 .67155 Mdot
.50742 .56898 Mdot
.50091 .36509 Mdot
.55344 .7102 Mdot
.22975 .53999 Mdot
.57989 .60468 Mdot
.35541 .68458 Mdot
.69161 .73315 Mdot
.54785 .68581 Mdot
.6299 .55622 Mdot
.54493 .72604 Mdot
.36211 .6461 Mdot
.28354 .47419 Mdot
.58976 .50453 Mdot
.50998 .35532 Mdot
.49947 .29936 Mdot
.6752 .4994 Mdot
.35722 .39233 Mdot
.26863 .49994 Mdot
.61262 .71083 Mdot
.61086 .48435 Mdot
.67866 .52037 Mdot
.47918 .32074 Mdot
.39199 .68552 Mdot
.42225 .52851 Mdot
.57427 .70673 Mdot
.59365 .51325 Mdot
.66988 .49293 Mdot
.48943 .47694 Mdot
.31783 .50687 Mdot
.40343 .43504 Mdot
.61742 .4664 Mdot
.48033 .46814 Mdot
.67833 .48604 Mdot
.6198 .42798 Mdot
.36721 .70448 Mdot
.57136 .50767 Mdot
.61725 .45634 Mdot
.48956 .38944 Mdot
.30772 .49611 Mdot
.50709 .32926 Mdot
.51888 .26641 Mdot
.38841 .43577 Mdot
.29274 .49763 Mdot
.64052 .53846 Mdot
.32479 .45958 Mdot
.66418 .50544 Mdot
.62339 .49649 Mdot
.30955 .50853 Mdot
.48911 .35386 Mdot
.4104 .25463 Mdot
.48272 .39105 Mdot
.64776 .5254 Mdot
.65956 .47705 Mdot
.51994 .73896 Mdot
.79462 .64582 Mdot
.6193 .45373 Mdot
.47767 .34104 Mdot
.65444 .46383 Mdot
.28613 .46785 Mdot
.54157 .71283 Mdot
.4998 .33188 Mdot
.39345 .65496 Mdot
.35824 .67481 Mdot
.40721 .63047 Mdot
.41614 .44177 Mdot
.64021 .44108 Mdot
.47566 .28808 Mdot
.50374 .28464 Mdot
.51548 .51678 Mdot
.37664 .68202 Mdot
.54279 .71693 Mdot
.60327 .50468 Mdot
.64008 .40446 Mdot
.31497 .45961 Mdot
.67491 .84985 Mdot
.46799 .4448 Mdot
.54377 .73637 Mdot
.4873 .59303 Mdot
.40111 .42546 Mdot
.6097 .50299 Mdot
.58594 .7032 Mdot
.36149 .68075 Mdot
.66901 .49925 Mdot
.70575 .49895 Mdot
.35145 .57892 Mdot
.40912 .66187 Mdot
.31617 .4566 Mdot
.36589 .65801 Mdot
.53527 .69744 Mdot
.41274 .44245 Mdot
.50314 .29664 Mdot
.62851 .47454 Mdot
.56361 .49751 Mdot
.38708 .68062 Mdot
.38758 .42716 Mdot
.65339 .4515 Mdot
.51742 .30495 Mdot
.37874 .68952 Mdot
.63637 .48953 Mdot
.58874 .32322 Mdot
.46875 .25996 Mdot
.39685 .67078 Mdot
.59493 .51189 Mdot
.56891 .42986 Mdot
.40953 .65959 Mdot
.37342 .64123 Mdot
.67595 .48291 Mdot
.58207 .70588 Mdot
.62057 .45597 Mdot
.30541 .47115 Mdot
.47919 .5224 Mdot
.28317 .49602 Mdot
.65582 .70026 Mdot
.6441 .43302 Mdot
.66398 .58899 Mdot
.4783 .35799 Mdot
.54319 .67526 Mdot
.79522 .38457 Mdot
.68285 .50642 Mdot
.42719 .20701 Mdot
.47914 .54163 Mdot
.45682 .46691 Mdot
.38512 .21224 Mdot
.57251 .71481 Mdot
.29414 .47345 Mdot
.65188 .45199 Mdot
.22735 .49079 Mdot
.57288 .71864 Mdot
.65642 .69945 Mdot
.6105 .52966 Mdot
.51851 .33259 Mdot
.61262 .4849 Mdot
.51571 .30596 Mdot
.65264 .46778 Mdot
.56856 .36894 Mdot
.53543 .65945 Mdot
.6396 .63281 Mdot
.6213 .55744 Mdot
.20334 .516 Mdot
.74426 .45626 Mdot
.544 .71129 Mdot
.647 .52224 Mdot
.39963 .4309 Mdot
.27129 .50663 Mdot
.23012 .56217 Mdot
.39774 .69874 Mdot
.31805 .4786 Mdot
.48108 .33275 Mdot
.34866 .65911 Mdot
.3892 .42695 Mdot
.62012 .56882 Mdot
.58404 .70607 Mdot
.29683 .49704 Mdot
.63118 .47168 Mdot
.67205 .5178 Mdot
.22437 .62 Mdot
.81203 .51747 Mdot
.4745 .33573 Mdot
.24723 .72811 Mdot
.47245 .29377 Mdot
.56964 .70185 Mdot
.37154 .70629 Mdot
.64472 .49131 Mdot
.62697 .45978 Mdot
.40944 .66766 Mdot
.47685 .3043 Mdot
.54768 .67053 Mdot
.77331 .66139 Mdot
.30147 .44482 Mdot
.70694 .61272 Mdot
.49851 .33419 Mdot
.70261 .6146 Mdot
.59973 .71173 Mdot
.34933 .51274 Mdot
.7757 .53352 Mdot
.27418 .48887 Mdot
.7117 .6109 Mdot
.52174 .32354 Mdot
.61564 .50215 Mdot
.41451 .4298 Mdot
.41622 .42157 Mdot
.48983 .34071 Mdot
.37199 .70127 Mdot
.56622 .68731 Mdot
.61399 .48114 Mdot
.62504 .57695 Mdot
.72923 .28358 Mdot
.4023 .65947 Mdot
.57709 .5026 Mdot
.27521 .50536 Mdot
.65711 .4687 Mdot
.58897 .69373 Mdot
.28286 .47947 Mdot
.39363 .44852 Mdot
.57411 .60027 Mdot
.59581 .4955 Mdot
.44504 .5927 Mdot
.30336 .48663 Mdot
.79783 .6391 Mdot
.63986 .45117 Mdot
.31063 .49319 Mdot
.56438 .49595 Mdot
.36012 .42863 Mdot
.42309 .55089 Mdot
.40777 .33715 Mdot
.37302 .72353 Mdot
.35911 .6661 Mdot
.84098 .52138 Mdot
.57649 .6401 Mdot
.32122 .48038 Mdot
.40634 .44548 Mdot
.76405 .57403 Mdot
.29651 .50318 Mdot
.59199 .50549 Mdot
.63687 .50306 Mdot
.73855 .43911 Mdot
.65503 .41208 Mdot
.42457 .42375 Mdot
.67529 .55925 Mdot
.62808 .5171 Mdot
.59252 .54949 Mdot
.66116 .46329 Mdot
.51837 .30026 Mdot
.27323 .4943 Mdot
.30954 .20014 Mdot
.33029 .46789 Mdot
.61188 .58736 Mdot
.39498 .67483 Mdot
.35954 .71668 Mdot
.6351 .47499 Mdot
.68587 .58846 Mdot
.17255 .42062 Mdot
.65886 .49095 Mdot
.44062 .60857 Mdot
.64771 .7021 Mdot
.65296 .55221 Mdot
.53664 .33265 Mdot
.56727 .49684 Mdot
.45863 .32531 Mdot
.28178 .47939 Mdot
.57216 .71637 Mdot
.55305 .67919 Mdot
.29969 .47369 Mdot
.63093 .46032 Mdot
.56428 .67749 Mdot
.63031 .48171 Mdot
.60605 .49504 Mdot
.4867 .46435 Mdot
.5815 .72439 Mdot
.40101 .69896 Mdot
.55996 .70694 Mdot
.5082 .35078 Mdot
.43292 .89443 Mdot
.55139 .69962 Mdot
.74042 .44931 Mdot
.50272 .54806 Mdot
.71184 .6137 Mdot
.49468 .29946 Mdot
.53965 .70516 Mdot
.27256 .48873 Mdot
.46309 .42723 Mdot
.75136 .44197 Mdot
.2783 .4697 Mdot
.62159 .46612 Mdot
.49669 .36525 Mdot
.50951 .29007 Mdot
.29313 .52179 Mdot
.48317 .30039 Mdot
.59537 .54029 Mdot
.60135 .51207 Mdot
.31793 .47118 Mdot
.62124 .19649 Mdot
.27187 .48431 Mdot
.66305 .40536 Mdot
.64431 .5055 Mdot
.50265 .33246 Mdot
.73751 .48381 Mdot
.53866 .29318 Mdot
.4213 .42704 Mdot
.60189 .46773 Mdot
.54563 .70394 Mdot
.51859 .54031 Mdot
.39804 .67215 Mdot
.30314 .37106 Mdot
.50568 .30203 Mdot
.32232 .50971 Mdot
.49096 .29607 Mdot
.47213 .31926 Mdot
.29497 .45883 Mdot
.51173 .34182 Mdot
.6269 .45642 Mdot
.27344 .30693 Mdot
.49983 .30322 Mdot
.29654 .48508 Mdot
.54594 .69556 Mdot
.47738 .33276 Mdot
.6001 .74364 Mdot
.60206 .49115 Mdot
.35074 .6846 Mdot
.52037 .71418 Mdot
.47697 .36045 Mdot
.54353 .71417 Mdot
.38259 .68269 Mdot
.57051 .6877 Mdot
.23743 .49307 Mdot
.31242 .52181 Mdot
.60078 .60019 Mdot
.34961 .4376 Mdot
.52039 .34383 Mdot
.362 .72407 Mdot
.59746 .4856 Mdot
.60872 .48774 Mdot
.53269 .6926 Mdot
.51688 .29662 Mdot
.34756 .39807 Mdot
.71989 .55003 Mdot
.36316 .38782 Mdot
.30239 .51494 Mdot
.60586 .76527 Mdot
.46671 .44242 Mdot
.26049 .45075 Mdot
.59767 .46088 Mdot
.40283 .42528 Mdot
.6375 .48336 Mdot
.6458 .71671 Mdot
.54059 .6903 Mdot
.25284 .64982 Mdot
.63848 .42739 Mdot
.40858 .67456 Mdot
.65474 .47438 Mdot
.25803 .55536 Mdot
.58379 .44043 Mdot
.55464 .68148 Mdot
.32874 .45663 Mdot
.48773 .35805 Mdot
.54207 .69475 Mdot
.35767 .67864 Mdot
.72568 .58328 Mdot
.59245 .50229 Mdot
.62363 .51537 Mdot
.4052 .64895 Mdot
.50265 .35657 Mdot
.36754 .67539 Mdot
.31253 .49068 Mdot
.55374 .70088 Mdot
.64885 .53149 Mdot
.57951 .52374 Mdot
.4205 .6615 Mdot
.32795 .47438 Mdot
.4152 .67527 Mdot
.32467 .46057 Mdot
.40734 .42485 Mdot
.65856 .44502 Mdot
.40516 .64547 Mdot
.62123 .43878 Mdot
.72322 .32178 Mdot
.53793 .5538 Mdot
.78007 .40175 Mdot
.40031 .70007 Mdot
.52267 .66007 Mdot
.29571 .47728 Mdot
.30101 .49706 Mdot
.66513 .40253 Mdot
.1774 .43754 Mdot
.42794 .52865 Mdot
.18467 .54315 Mdot
.31326 .48927 Mdot
.29914 .49169 Mdot
.36537 .6887 Mdot
.50062 .35215 Mdot
.50393 .37632 Mdot
.36974 .63839 Mdot
.62825 .6616 Mdot
.51925 .3203 Mdot
.45228 .20412 Mdot
.38075 .64647 Mdot
.59332 .47423 Mdot
.39134 .45878 Mdot
.55624 .68155 Mdot
.63857 .69574 Mdot
.19655 .54223 Mdot
.64504 .48579 Mdot
.48573 .85706 Mdot
.38994 .70023 Mdot
.40642 .47131 Mdot
.2888 .54144 Mdot
.67334 .52212 Mdot
.65147 .47256 Mdot
.63955 .45619 Mdot
.53183 .72599 Mdot
.72176 .29442 Mdot
.64398 .4889 Mdot
.61342 .62943 Mdot
.68202 .46929 Mdot
.21156 .61777 Mdot
.55989 .70663 Mdot
.73764 .67598 Mdot
.3436 .69993 Mdot
.38027 .39984 Mdot
.65909 .53619 Mdot
.31292 .48288 Mdot
.37174 .5679 Mdot
.31797 .50099 Mdot
.32172 .53579 Mdot
.77787 .54918 Mdot
.52358 .30504 Mdot
.67406 .4994 Mdot
.38221 .64437 Mdot
.48858 .3645 Mdot
.38503 .56289 Mdot
.40565 .87865 Mdot
.30285 .51818 Mdot
.24039 .75012 Mdot
.28642 .50075 Mdot
.41821 .42144 Mdot
.48233 .33065 Mdot
.71287 .57776 Mdot
.48726 .49017 Mdot
.49586 .35639 Mdot
.47937 .78808 Mdot
.47032 .36374 Mdot
.68884 .60866 Mdot
.45434 .32106 Mdot
.29168 .4821 Mdot
.32286 .51109 Mdot
.70121 .49634 Mdot
.60893 .46388 Mdot
.48253 .49929 Mdot
.68711 .44878 Mdot
.59687 .49224 Mdot
.38784 .66602 Mdot
.33123 .43266 Mdot
.22533 .49215 Mdot
.49697 .33873 Mdot
.32107 .46591 Mdot
.65345 .47439 Mdot
.64722 .52538 Mdot
.61287 .54227 Mdot
.63549 .7752 Mdot
.44999 .20292 Mdot
.6233 .49899 Mdot
.58155 .44469 Mdot
.35708 .69046 Mdot
.22443 .62202 Mdot
.26132 .73018 Mdot
.77108 .55993 Mdot
.65689 .45329 Mdot
.56716 .70802 Mdot
.58751 .68915 Mdot
.60596 .5442 Mdot
.64943 .59695 Mdot
.58271 .7654 Mdot
.63127 .4714 Mdot
.67029 .60703 Mdot
.42245 .68581 Mdot
.38536 .43283 Mdot
.38651 .68054 Mdot
.48285 .36366 Mdot
.40025 .42341 Mdot
.37599 .66012 Mdot
.59972 .62495 Mdot
.39032 .43922 Mdot
.36212 .42485 Mdot
.53953 .70754 Mdot
.65477 .45671 Mdot
.44315 .33316 Mdot
.3998 .66001 Mdot
.30301 .49131 Mdot
.49406 .31916 Mdot
.27244 .50955 Mdot
.20203 .60362 Mdot
.63273 .67092 Mdot
.41885 .43901 Mdot
.31331 .48001 Mdot
.44433 .57341 Mdot
.56607 .70672 Mdot
.28633 .50487 Mdot
.67275 .58788 Mdot
.66184 .43999 Mdot
.21104 .33821 Mdot
.62196 .51879 Mdot
.42798 .35132 Mdot
.3074 .48962 Mdot
.3939 .45035 Mdot
.627 .47561 Mdot
.35674 .65961 Mdot
.6499 .55731 Mdot
.62935 .48316 Mdot
.37906 .65109 Mdot
.62025 .50146 Mdot
.5879 .71268 Mdot
.45986 .32931 Mdot
.48772 .54837 Mdot
.62934 .75668 Mdot
.55737 .68588 Mdot
.51391 .49045 Mdot
.61692 .45472 Mdot
.44269 .76583 Mdot
.51696 .33243 Mdot
.68201 .50642 Mdot
.67167 .70615 Mdot
.49637 .34795 Mdot
.50414 .31826 Mdot
.63883 .52143 Mdot
.27126 .48231 Mdot
.41145 .68565 Mdot
.56415 .70735 Mdot
.23046 .47243 Mdot
.63747 .49097 Mdot
.67543 .48778 Mdot
.54577 .68747 Mdot
.29411 .49594 Mdot
.64459 .53409 Mdot
.35528 .3299 Mdot
.52268 .52883 Mdot
.3162 .45824 Mdot
.67001 .44889 Mdot
.32289 .2233 Mdot
.4943 .37686 Mdot
.49724 .85932 Mdot
.54422 .65124 Mdot
.36759 .7019 Mdot
.57854 .48492 Mdot
.61674 .88897 Mdot
.54089 .70566 Mdot
.38161 .3905 Mdot
.61482 .49858 Mdot
.64842 .49208 Mdot
.5276 .31506 Mdot
.62829 .53551 Mdot
.52513 .32175 Mdot
.61434 .76875 Mdot
.17075 .45271 Mdot
.48366 .30133 Mdot
.5216 .31412 Mdot
.62151 .41813 Mdot
.63985 .77901 Mdot
.48626 .34249 Mdot
.59271 .50222 Mdot
.46386 .76661 Mdot
.70918 .49282 Mdot
.57469 .7322 Mdot
.56225 .76759 Mdot
.53611 .336 Mdot
.74632 .42271 Mdot
.62283 .41837 Mdot
.58322 .3743 Mdot
.58558 .75208 Mdot
.31816 .49022 Mdot
.65647 .50854 Mdot
.41147 .44467 Mdot
.37481 .69012 Mdot
.57395 .53472 Mdot
.64505 .45279 Mdot
.52508 .3463 Mdot
.53164 .72164 Mdot
.29422 .50535 Mdot
.66921 .46972 Mdot
.42146 .65678 Mdot
.57339 .69788 Mdot
.49306 .30601 Mdot
.71461 .4291 Mdot
.5663 .67904 Mdot
.57717 .51527 Mdot
.61779 .50556 Mdot
.6659 .46283 Mdot
.72083 .48631 Mdot
.30189 .47523 Mdot
.35871 .64576 Mdot
.57906 .49127 Mdot
.4744 .44352 Mdot
.53982 .56637 Mdot
.58992 .5172 Mdot
.47743 .33852 Mdot
.30125 .51434 Mdot
.40228 .44195 Mdot
.73513 .6022 Mdot
.63005 .50853 Mdot
.44128 .20138 Mdot
.71892 .72553 Mdot
.3934 .43833 Mdot
.50825 .36708 Mdot
.55793 .71055 Mdot
.63755 .51376 Mdot
.62115 .63388 Mdot
.59565 .50933 Mdot
.7103 .5132 Mdot
.37717 .70423 Mdot
.3133 .49997 Mdot
.55963 .56014 Mdot
.37248 .68901 Mdot
.50385 .31891 Mdot
.48773 .21396 Mdot
.49482 .37435 Mdot
.47195 .3278 Mdot
.3624 .53385 Mdot
.29255 .46923 Mdot
.63125 .88254 Mdot
.79009 .66057 Mdot
.59499 .47565 Mdot
.301 .46442 Mdot
.48545 .33288 Mdot
.62555 .54086 Mdot
.5228 .33488 Mdot
.5333 .30438 Mdot
.60061 .50094 Mdot
.59904 .49652 Mdot
.64223 .6275 Mdot
.45938 .20727 Mdot
.54784 .69778 Mdot
.49008 .29291 Mdot
.62886 .38621 Mdot
.64117 .49351 Mdot
.62699 .45315 Mdot
.36391 .56966 Mdot
.53992 .69874 Mdot
.61499 .31262 Mdot
.61044 .4898 Mdot
.67082 .72873 Mdot
.59879 .47603 Mdot
.5205 .37298 Mdot
.26071 .51072 Mdot
.62999 .5923 Mdot
.40899 .69473 Mdot
.46757 .33309 Mdot
.53292 .69723 Mdot
.51713 .27882 Mdot
.61676 .35126 Mdot
.28309 .47591 Mdot
.51648 .30899 Mdot
.3445 .67156 Mdot
.28665 .49284 Mdot
.27426 .48036 Mdot
.39056 .56051 Mdot
.34574 .67675 Mdot
.53982 .73213 Mdot
.28972 .51125 Mdot
.5883 .32596 Mdot
.28909 .48406 Mdot
.61219 .34507 Mdot
.63821 .44345 Mdot
.61001 .62786 Mdot
.60139 .57533 Mdot
.70415 .48916 Mdot
.27647 .49884 Mdot
.56901 .6904 Mdot
.65241 .53348 Mdot
.47916 .30655 Mdot
.55677 .6923 Mdot
.39201 .46264 Mdot
.35211 .71117 Mdot
.51534 .29241 Mdot
.3214 .45524 Mdot
.52639 .33412 Mdot
.64447 .69967 Mdot
.53857 .67179 Mdot
.38139 .57453 Mdot
.49006 .50177 Mdot
.59872 .55383 Mdot
.58736 .43332 Mdot
.6607 .53072 Mdot
.63126 .45712 Mdot
.39608 .67096 Mdot
.55894 .74511 Mdot
.47706 .33244 Mdot
.72146 .26879 Mdot
.31034 .47997 Mdot
.44175 .58913 Mdot
.70237 .52633 Mdot
.66606 .5036 Mdot
.48783 .32795 Mdot
.52665 .2923 Mdot
.74779 .34162 Mdot
.41133 .66993 Mdot
.70871 .48479 Mdot
.65052 .54336 Mdot
.53622 .51524 Mdot
.27775 .49606 Mdot
.38836 .3056 Mdot
.39277 .71387 Mdot
.26432 .78219 Mdot
.37246 .68543 Mdot
.45537 .70956 Mdot
.51099 .34298 Mdot
.54963 .72105 Mdot
.61547 .46639 Mdot
.54081 .40153 Mdot
.51305 .36207 Mdot
.34822 .72406 Mdot
.55119 .7117 Mdot
.40703 .27389 Mdot
.31123 .46786 Mdot
.65983 .45149 Mdot
.5963 .48124 Mdot
.63607 .52982 Mdot
.61758 .53717 Mdot
.31841 .46854 Mdot
.5977 .51232 Mdot
.27811 .46388 Mdot
.62584 .34806 Mdot
.67515 .69849 Mdot
.38105 .64131 Mdot
.23313 .63596 Mdot
.47242 .32462 Mdot
.54311 .23985 Mdot
.62452 .32488 Mdot
.53735 .55287 Mdot
.24155 .49764 Mdot
.65134 .44272 Mdot
.3724 .70029 Mdot
.20848 .51837 Mdot
.37829 .64226 Mdot
.2292 .27476 Mdot
.74022 .44209 Mdot
.4226 .30732 Mdot
.62171 .53016 Mdot
.39885 .64088 Mdot
.72689 .40078 Mdot
.577 .51866 Mdot
.5605 .67528 Mdot
.60068 .35078 Mdot
.44262 .36446 Mdot
.54112 .71484 Mdot
.60299 .49603 Mdot
.49946 .28172 Mdot
.62151 .46239 Mdot
.60953 .47421 Mdot
.66038 .49012 Mdot
.25621 .50143 Mdot
.61583 .44982 Mdot
.61974 .45701 Mdot
.81181 .52417 Mdot
.42483 .6051 Mdot
.35426 .67561 Mdot
.77617 .38754 Mdot
.56287 .69697 Mdot
.482 .36255 Mdot
.47956 .53899 Mdot
.30882 .47081 Mdot
.74943 .34437 Mdot
.62494 .52469 Mdot
.37544 .36814 Mdot
.32823 .4979 Mdot
.57916 .70631 Mdot
.39914 .44418 Mdot
.38374 .27427 Mdot
.38438 .70937 Mdot
.42671 .42931 Mdot
.39911 .67314 Mdot
.78663 .42405 Mdot
.52326 .31602 Mdot
.59782 .55311 Mdot
.29528 .50741 Mdot
.35838 .65139 Mdot
.61846 .63071 Mdot
.65026 .45853 Mdot
.40136 .69961 Mdot
.584 .55247 Mdot
.52173 .54983 Mdot
.47746 .53344 Mdot
.35333 .65394 Mdot
.33455 .48359 Mdot
.28147 .49246 Mdot
.54109 .71886 Mdot
.4708 .34964 Mdot
.5093 .35444 Mdot
.28318 .48628 Mdot
.37289 .81919 Mdot
.63863 .48919 Mdot
.63641 .5004 Mdot
.47109 .4388 Mdot
.62967 .54261 Mdot
.5135 .71751 Mdot
.40724 .41818 Mdot
.51215 .35622 Mdot
.6575 .53212 Mdot
.64371 .534 Mdot
.61587 .5078 Mdot
.63483 .66456 Mdot
.3879 .68222 Mdot
.62912 .51649 Mdot
.58498 .704 Mdot
.43306 .44514 Mdot
.59892 .48116 Mdot
.58241 .53584 Mdot
.52589 .32574 Mdot
.39641 .77967 Mdot
.30631 .48758 Mdot
.40418 .66509 Mdot
.39167 .64739 Mdot
.69422 .66251 Mdot
.54407 .3564 Mdot
.42494 .42286 Mdot
.21398 .59248 Mdot
.40698 .44364 Mdot
.55063 .71534 Mdot
.422 .54242 Mdot
.41523 .70971 Mdot
.35769 .66769 Mdot
.34064 .47667 Mdot
.6766 .50827 Mdot
.59604 .48765 Mdot
.37507 .39823 Mdot
.65435 .49405 Mdot
.54463 .70428 Mdot
.26939 .47994 Mdot
.52153 .31613 Mdot
.58788 .69384 Mdot
.29861 .49925 Mdot
.49945 .35749 Mdot
.68556 .51411 Mdot
.59254 .5142 Mdot
.49696 .31702 Mdot
.4921 .30414 Mdot
.64255 .47386 Mdot
.81576 .50085 Mdot
.50445 .36019 Mdot
.48883 .32051 Mdot
.44463 .41375 Mdot
.36666 .70657 Mdot
.71426 .45211 Mdot
.29703 .46569 Mdot
.62639 .45524 Mdot
.3868 .64102 Mdot
.5598 .71978 Mdot
.50469 .31108 Mdot
.65357 .50799 Mdot
.62998 .49324 Mdot
.56577 .70929 Mdot
.58975 .71748 Mdot
.54655 .69104 Mdot
.26384 .50913 Mdot
.60496 .51389 Mdot
.48313 .33967 Mdot
.31197 .46771 Mdot
.57323 .68188 Mdot
.54599 .72769 Mdot
.80061 .508 Mdot
.64442 .48351 Mdot
.57823 .67987 Mdot
.47838 .91193 Mdot
.73573 .58002 Mdot
.39732 .42315 Mdot
.42738 .67512 Mdot
.51699 .67007 Mdot
.52017 .70924 Mdot
.3207 .49202 Mdot
.43952 .60068 Mdot
.53157 .71223 Mdot
.65699 .4981 Mdot
.66207 .47344 Mdot
.59519 .46077 Mdot
.56122 .69323 Mdot
.63768 .67611 Mdot
.49835 .2871 Mdot
.63232 .2706 Mdot
.56265 .69693 Mdot
.35044 .66162 Mdot
.4187 .6564 Mdot
.36891 .68305 Mdot
.66685 .45551 Mdot
.77619 .36102 Mdot
.63173 .37159 Mdot
.61368 .30289 Mdot
.31485 .47358 Mdot
.52692 .29316 Mdot
.36796 .47003 Mdot
.50459 .31774 Mdot
.38611 .69415 Mdot
.57312 .69572 Mdot
.52748 .31351 Mdot
.27525 .47982 Mdot
.27903 .49273 Mdot
.41533 .68459 Mdot
.38113 .68065 Mdot
.37825 .6681 Mdot
.46851 .33953 Mdot
.51151 .34246 Mdot
.6462 .53036 Mdot
.50473 .3072 Mdot
.72375 .7293 Mdot
.51316 .69314 Mdot
.41911 .66933 Mdot
.30225 .48159 Mdot
.48588 .31668 Mdot
.65225 .45439 Mdot
.46546 .67939 Mdot
.36084 .72755 Mdot
.57103 .68501 Mdot
.24091 .36617 Mdot
.15854 .45584 Mdot
.67369 .45726 Mdot
.32666 .47612 Mdot
.65799 .593 Mdot
.64018 .45888 Mdot
.38376 .70586 Mdot
.74947 .68175 Mdot
.393 .4449 Mdot
.61036 .46703 Mdot
.66869 .53485 Mdot
.27121 .48934 Mdot
.4797 .53702 Mdot
.6593 .49672 Mdot
.42368 .56685 Mdot
.31821 .50944 Mdot
.39464 .71275 Mdot
.85253 .53321 Mdot
.40671 .46847 Mdot
.62849 .70662 Mdot
.39027 .42807 Mdot
.65322 .49731 Mdot
.39002 .66648 Mdot
.58198 .69258 Mdot
.38593 .67253 Mdot
.50506 .36932 Mdot
.3743 .70862 Mdot
.66513 .47069 Mdot
.48588 .34507 Mdot
.29495 .49717 Mdot
.45005 .59053 Mdot
.78466 .46964 Mdot
.35616 .6613 Mdot
.38253 .43246 Mdot
.5993 .4939 Mdot
.57495 .28932 Mdot
.69946 .49827 Mdot
.61597 .45733 Mdot
.31263 .50626 Mdot
.49117 .33393 Mdot
.30342 .51443 Mdot
.59357 .55815 Mdot
.51547 .24077 Mdot
.30902 .47726 Mdot
.48286 .39486 Mdot
.54688 .68621 Mdot
.62806 .66369 Mdot
.62068 .47489 Mdot
.29879 .5064 Mdot
.60953 .51413 Mdot
.49183 .29193 Mdot
.56442 .59369 Mdot
.52445 .50247 Mdot
.27419 .50502 Mdot
.4334 .29668 Mdot
.52176 .56147 Mdot
.69181 .43124 Mdot
.30894 .49724 Mdot
.79322 .38273 Mdot
.39955 .43344 Mdot
.57274 .70927 Mdot
.59462 .70694 Mdot
.5715 .72432 Mdot
.65145 .49435 Mdot
.57606 .35401 Mdot
.55725 .73136 Mdot
.27218 .51414 Mdot
.57464 .72693 Mdot
.64831 .76259 Mdot
.35533 .39313 Mdot
.5546 .68524 Mdot
.61959 .48026 Mdot
.57197 .54189 Mdot
.44046 .60293 Mdot
.35284 .70417 Mdot
.40562 .23667 Mdot
.80694 .53084 Mdot
.64585 .49035 Mdot
.57343 .32677 Mdot
.52276 .36438 Mdot
.51362 .63966 Mdot
.5261 .49858 Mdot
.43649 .51658 Mdot
.48764 .3176 Mdot
.48372 .5188 Mdot
.49234 .36298 Mdot
.62293 .55824 Mdot
.62256 .49621 Mdot
.47605 .36262 Mdot
.28941 .37109 Mdot
.77494 .32896 Mdot
.36284 .38195 Mdot
.48186 .35021 Mdot
.30741 .49641 Mdot
.32484 .49108 Mdot
.31173 .50628 Mdot
.39238 .65983 Mdot
.50928 .30148 Mdot
.63089 .5106 Mdot
.35869 .68543 Mdot
.60993 .47868 Mdot
.27875 .48569 Mdot
.52931 .5376 Mdot
.52263 .31767 Mdot
.62932 .47082 Mdot
.70695 .41102 Mdot
.39779 .68004 Mdot
.56766 .70517 Mdot
.25477 .34297 Mdot
.42451 .69013 Mdot
.33184 .46601 Mdot
.54145 .32733 Mdot
.38086 .62678 Mdot
.40175 .74319 Mdot
.59307 .4781 Mdot
.59085 .49157 Mdot
.4384 .61463 Mdot
.73821 .42627 Mdot
.66418 .49289 Mdot
.35788 .67675 Mdot
.35732 .70025 Mdot
.60969 .51256 Mdot
.49756 .29661 Mdot
.54062 .72798 Mdot
.53299 .69159 Mdot
.61432 .55659 Mdot
.48619 .50404 Mdot
.61156 .62839 Mdot
.64062 .53754 Mdot
.59874 .44704 Mdot
.34365 .68092 Mdot
.38924 .42728 Mdot
.48962 .48089 Mdot
.55524 .72673 Mdot
.61203 .49745 Mdot
.73195 .28927 Mdot
.5079 .30383 Mdot
.40754 .69446 Mdot
.3 .46098 Mdot
.56525 .67783 Mdot
.41765 .68456 Mdot
.60967 .51248 Mdot
.64395 .5342 Mdot
.2888 .50687 Mdot
.52628 .36932 Mdot
.56648 .69238 Mdot
.3583 .68716 Mdot
.54809 .72064 Mdot
.51393 .34085 Mdot
.49199 .31057 Mdot
.64333 .54711 Mdot
.70316 .48611 Mdot
.36923 .65053 Mdot
.58192 .494 Mdot
.3638 .67585 Mdot
.22401 .62007 Mdot
.31514 .45999 Mdot
.67411 .52549 Mdot
.54797 .34533 Mdot
.27951 .48644 Mdot
.65107 .48502 Mdot
.43781 .6149 Mdot
.66815 .50963 Mdot
.37322 .63798 Mdot
.77623 .64948 Mdot
.5673 .72241 Mdot
.55302 .46924 Mdot
.75159 .50366 Mdot
.63678 .54188 Mdot
.35338 .69883 Mdot
.59419 .35994 Mdot
.30541 .4739 Mdot
.50483 .34456 Mdot
.37828 .7912 Mdot
.29405 .48496 Mdot
.61558 .4871 Mdot
.5524 .69906 Mdot
.48352 .35584 Mdot
.41773 .42776 Mdot
.47323 .48808 Mdot
.57162 .53413 Mdot
.67135 .54447 Mdot
.66918 .468 Mdot
.18476 .54113 Mdot
.3812 .669 Mdot
.48624 .32937 Mdot
.32559 .47868 Mdot
.29062 .47234 Mdot
.39225 .68567 Mdot
.44195 .37337 Mdot
.32675 .3727 Mdot
.51783 .91186 Mdot
.41946 .67836 Mdot
.57548 .72469 Mdot
.55864 .58702 Mdot
.36813 .68608 Mdot
.39756 .66356 Mdot
.34603 .69945 Mdot
.36613 .39863 Mdot
.48184 .34868 Mdot
.63046 .49464 Mdot
.52769 .28388 Mdot
.6521 .49667 Mdot
.62129 .68745 Mdot
.28152 .48276 Mdot
.50612 .34472 Mdot
.60352 .74257 Mdot
.57802 .44691 Mdot
.64462 .46482 Mdot
.61393 .68734 Mdot
.55075 .52474 Mdot
.72105 .60872 Mdot
.60951 .53938 Mdot
.39009 .67545 Mdot
.48867 .25013 Mdot
.57665 .50616 Mdot
.70244 .4101 Mdot
.28287 .4964 Mdot
.42129 .43706 Mdot
.6065 .56031 Mdot
.60809 .43494 Mdot
.48041 .35373 Mdot
.52946 .3183 Mdot
.55462 .7315 Mdot
.27256 .31292 Mdot
.28636 .49762 Mdot
.40403 .31755 Mdot
.61192 .46011 Mdot
.24948 .52155 Mdot
.76383 .67003 Mdot
.65104 .47936 Mdot
.39816 .55709 Mdot
.74834 .34328 Mdot
.66697 .49858 Mdot
.61768 .2967 Mdot
.29809 .48003 Mdot
.67011 .71563 Mdot
.60504 .52585 Mdot
.39002 .7032 Mdot
.50287 .35065 Mdot
.5145 .29172 Mdot
.5806 .68882 Mdot
.75487 .70287 Mdot
.19756 .45896 Mdot
.50893 .34505 Mdot
.64437 .45558 Mdot
.30522 .48682 Mdot
.42122 .43028 Mdot
.5708 .52226 Mdot
.23527 .52953 Mdot
.51067 .30711 Mdot
.57865 .49072 Mdot
.37059 .36649 Mdot
.48 .52777 Mdot
.46658 .19541 Mdot
.30219 .51053 Mdot
.55188 .72653 Mdot
.71009 .4646 Mdot
.21419 .59755 Mdot
.59226 .51296 Mdot
.62416 .69415 Mdot
.53036 .37713 Mdot
.54212 .71351 Mdot
.63472 .46069 Mdot
.66075 .49764 Mdot
.50119 .51174 Mdot
.59608 .70684 Mdot
.65944 .49741 Mdot
.63733 .42717 Mdot
.51373 .3482 Mdot
.40524 .41822 Mdot
.52089 .31658 Mdot
.62376 .46247 Mdot
.77875 .62813 Mdot
.50976 .29735 Mdot
.40804 .24383 Mdot
.55653 .64689 Mdot
.31 .47192 Mdot
.57389 .48442 Mdot
.63187 .44525 Mdot
.40555 .18455 Mdot
.42036 .42535 Mdot
.29244 .75328 Mdot
.39532 .64024 Mdot
.83705 .39123 Mdot
.42285 .69389 Mdot
.42966 .28831 Mdot
.41749 .59184 Mdot
.5881 .46761 Mdot
.6699 .41249 Mdot
.60626 .29386 Mdot
.25378 .52196 Mdot
.55449 .25148 Mdot
.60872 .46412 Mdot
.61339 .50318 Mdot
.36291 .68725 Mdot
.4347 .37382 Mdot
.63768 .59247 Mdot
.48921 .48313 Mdot
.57805 .70548 Mdot
.51025 .32976 Mdot
.66229 .46934 Mdot
.26841 .36921 Mdot
.35439 .65937 Mdot
.77557 .50212 Mdot
.62728 .47283 Mdot
.61672 .59186 Mdot
.43803 .39231 Mdot
.29846 .49646 Mdot
.35231 .65492 Mdot
.34783 .66966 Mdot
.64955 .49915 Mdot
.31341 .46524 Mdot
.65757 .52383 Mdot
.53078 .57052 Mdot
.57662 .53354 Mdot
.55359 .71773 Mdot
.62974 .45066 Mdot
.76253 .50883 Mdot
.53452 .18174 Mdot
.61961 .42385 Mdot
.47129 .33993 Mdot
.37533 .66643 Mdot
.38454 .68643 Mdot
.50726 .35588 Mdot
.38477 .68707 Mdot
.63519 .27864 Mdot
.55111 .27234 Mdot
.54898 .71556 Mdot
.64176 .34435 Mdot
.57318 .7173 Mdot
.42062 .43818 Mdot
.6448 .48043 Mdot
.30406 .59283 Mdot
.41875 .68497 Mdot
.65942 .75832 Mdot
.28595 .48361 Mdot
.41909 .42324 Mdot
.5989 .50211 Mdot
.60164 .73273 Mdot
.38117 .69839 Mdot
.40376 .50649 Mdot
.63744 .50376 Mdot
.47957 .30138 Mdot
.66592 .50162 Mdot
.68611 .46704 Mdot
.4173 .42049 Mdot
.67511 .47837 Mdot
.29883 .49917 Mdot
.5176 .30569 Mdot
.42177 .32221 Mdot
.39892 .65988 Mdot
.60306 .47932 Mdot
.64308 .456 Mdot
.53333 .34345 Mdot
.59931 .46844 Mdot
.31914 .47718 Mdot
.71815 .81572 Mdot
.54259 .69197 Mdot
.38827 .42839 Mdot
.32774 .26313 Mdot
.67206 .48811 Mdot
.65556 .53067 Mdot
.43108 .48733 Mdot
.73585 .29475 Mdot
.31129 .48464 Mdot
.66069 .54881 Mdot
.35369 .68495 Mdot
.56655 .6913 Mdot
.26973 .50573 Mdot
.60062 .5125 Mdot
.62301 .50304 Mdot
.54271 .71069 Mdot
.61233 .67781 Mdot
.558 .66935 Mdot
.32004 .4866 Mdot
.56156 .30184 Mdot
.46675 .67802 Mdot
.63526 .48465 Mdot
.37956 .44571 Mdot
.49251 .32936 Mdot
.31259 .49343 Mdot
.70904 .28302 Mdot
.6258 .55769 Mdot
.31606 .45605 Mdot
.29255 .49768 Mdot
.60352 .46154 Mdot
.54079 .36139 Mdot
.53193 .2938 Mdot
.49054 .32764 Mdot
.68113 .69069 Mdot
.22922 .68668 Mdot
.38095 .66549 Mdot
.30073 .48504 Mdot
.39182 .64227 Mdot
.53125 .70923 Mdot
.53319 .56012 Mdot
.34926 .67235 Mdot
.47438 .30749 Mdot
.38667 .64347 Mdot
.65978 .52314 Mdot
.27796 .47484 Mdot
.38058 .64726 Mdot
.62615 .54015 Mdot
.62358 .43209 Mdot
.65358 .4117 Mdot
.53674 .72621 Mdot
.48252 .51787 Mdot
.61519 .48064 Mdot
.39827 .44322 Mdot
.63812 .47269 Mdot
.31893 .47361 Mdot
.45106 .59899 Mdot
.62749 .52015 Mdot
.41926 .68323 Mdot
.25804 .71567 Mdot
.36373 .70956 Mdot
.67254 .44125 Mdot
.62093 .46684 Mdot
.63799 .48578 Mdot
.5997 .49939 Mdot
.44098 .35595 Mdot
.32223 .45369 Mdot
.71092 .50814 Mdot
.41453 .66858 Mdot
.50257 .31486 Mdot
.50697 .2941 Mdot
.42962 .50887 Mdot
.42617 .43225 Mdot
.30614 .46346 Mdot
.63789 .48748 Mdot
.4041 .50923 Mdot
.46661 .47259 Mdot
.3642 .37339 Mdot
.39629 .62627 Mdot
.3589 .66433 Mdot
.46974 .32808 Mdot
.37328 .65485 Mdot
.59873 .51035 Mdot
.58089 .48346 Mdot
.42148 .31514 Mdot
.26014 .47479 Mdot
.56935 .69338 Mdot
.61323 .47202 Mdot
.63178 .64993 Mdot
.35712 .69045 Mdot
.34433 .67869 Mdot
.65414 .52569 Mdot
.53412 .35736 Mdot
.57195 .16107 Mdot
.29533 .46444 Mdot
.57595 .29591 Mdot
.45964 .28273 Mdot
.53168 .50585 Mdot
.29819 .47298 Mdot
.4095 .55547 Mdot
.35846 .71356 Mdot
.80175 .60543 Mdot
.49763 .3142 Mdot
.56876 .69427 Mdot
.60208 .53061 Mdot
.47402 .30847 Mdot
.4082 .64782 Mdot
.50051 .36379 Mdot
.59608 .55261 Mdot
.29641 .51711 Mdot
.37678 .68801 Mdot
.33214 .50097 Mdot
.49248 .36691 Mdot
.5715 .71926 Mdot
.66284 .72479 Mdot
.58817 .31729 Mdot
.7471 .34253 Mdot
.62995 .51614 Mdot
.33912 .58062 Mdot
.63367 .50967 Mdot
.49064 .2843 Mdot
.62035 .47559 Mdot
.56867 .45812 Mdot
.36177 .71812 Mdot
.59295 .52424 Mdot
.62597 .45245 Mdot
.68922 .40516 Mdot
.65 .47307 Mdot
.60933 .50884 Mdot
.65551 .54596 Mdot
.50316 .37999 Mdot
.59678 .53025 Mdot
.47778 .30466 Mdot
.38085 .38339 Mdot
.40011 .66493 Mdot
.53206 .70853 Mdot
.53465 .69863 Mdot
.62592 .71241 Mdot
.63157 .65436 Mdot
.43925 .3801 Mdot
.51709 .31866 Mdot
.27664 .49692 Mdot
.6551 .52647 Mdot
.7974 .40064 Mdot
.76578 .63508 Mdot
.3713 .72002 Mdot
.37674 .64537 Mdot
.59626 .52012 Mdot
.17018 .43733 Mdot
.59562 .52554 Mdot
.46816 .44249 Mdot
.64905 .49578 Mdot
.67718 .5226 Mdot
.3467 .66252 Mdot
.64358 .69999 Mdot
.62884 .51644 Mdot
.48138 .35495 Mdot
.57224 .70008 Mdot
.57899 .56417 Mdot
.74886 .66009 Mdot
.66032 .40447 Mdot
.71857 .55465 Mdot
.6196 .52108 Mdot
.36315 .6971 Mdot
.48052 .35012 Mdot
.47553 .45269 Mdot
.31713 .47571 Mdot
.47855 .49838 Mdot
.61816 .34307 Mdot
.30399 .53871 Mdot
.57288 .69719 Mdot
.33603 .68154 Mdot
.66651 .47219 Mdot
.38872 .66045 Mdot
.64955 .55278 Mdot
.45998 .47689 Mdot
.55157 .71883 Mdot
.46598 .34103 Mdot
.30712 .49622 Mdot
.48756 .29019 Mdot
.77974 .39956 Mdot
.77019 .63173 Mdot
.83944 .39462 Mdot
.38904 .71002 Mdot
.62708 .22083 Mdot
.4902 .34213 Mdot
.63929 .50491 Mdot
.5139 .91119 Mdot
.49739 .3329 Mdot
.47711 .30389 Mdot
.44395 .52346 Mdot
.65594 .70155 Mdot
.58022 .50552 Mdot
.50988 .35862 Mdot
.33949 .66527 Mdot
.55434 .70856 Mdot
.62626 .53851 Mdot
.6007 .55721 Mdot
.52797 .31519 Mdot
.38572 .69697 Mdot
.62376 .67769 Mdot
.38601 .67885 Mdot
.48279 .3478 Mdot
.40208 .68173 Mdot
.40743 .25768 Mdot
.35158 .66664 Mdot
.63223 .44786 Mdot
.63692 .48722 Mdot
.30735 .55777 Mdot
.49203 .31056 Mdot
.65569 .53095 Mdot
.6169 .50067 Mdot
.48485 .33943 Mdot
.41393 .71227 Mdot
.68569 .25822 Mdot
.66257 .52615 Mdot
.63473 .49175 Mdot
.53878 .69741 Mdot
.50661 .53759 Mdot
.46126 .44039 Mdot
.63296 .54042 Mdot
.57547 .72233 Mdot
.46783 .33046 Mdot
.6398 .47203 Mdot
.64386 .70266 Mdot
.42362 .68013 Mdot
.61683 .52594 Mdot
.41901 .43334 Mdot
.6618 .49109 Mdot
.55906 .16493 Mdot
.59912 .49086 Mdot
.48215 .32866 Mdot
.49714 .34934 Mdot
.35832 .62395 Mdot
.50263 .32008 Mdot
.40052 .42253 Mdot
.28164 .49108 Mdot
.49516 .21055 Mdot
.40586 .42161 Mdot
.67621 .47467 Mdot
.78792 .66596 Mdot
.59756 .55543 Mdot
.58107 .53591 Mdot
.64304 .77878 Mdot
.39161 .42723 Mdot
.49342 .33804 Mdot
.29024 .36533 Mdot
.58359 .4972 Mdot
.30303 .46286 Mdot
.57897 .52293 Mdot
.61666 .52553 Mdot
.58855 .43082 Mdot
.55162 .27959 Mdot
.27299 .47341 Mdot
.71089 .44782 Mdot
.62673 .53843 Mdot
.73662 .2964 Mdot
.65585 .45976 Mdot
.56346 .68345 Mdot
.52168 .33088 Mdot
.37899 .65445 Mdot
.55382 .71464 Mdot
.66955 .47925 Mdot
.56087 .69472 Mdot
.38689 .66252 Mdot
.29544 .50972 Mdot
.63709 .44758 Mdot
.57463 .73239 Mdot
.5743 .69601 Mdot
.64833 .51859 Mdot
.50611 .34713 Mdot
.69679 .50192 Mdot
.64264 .47273 Mdot
.60221 .50795 Mdot
.51058 .35341 Mdot
.55698 .85387 Mdot
.61417 .50667 Mdot
.40609 .5563 Mdot
.46177 .31087 Mdot
.40566 .41921 Mdot
.36101 .66768 Mdot
.63992 .429 Mdot
.29093 .47096 Mdot
.28307 .48897 Mdot
.40963 .70114 Mdot
.53072 .32786 Mdot
.37983 .68975 Mdot
.60847 .42423 Mdot
.58021 .487 Mdot
.60208 .52992 Mdot
.37612 .79123 Mdot
.37988 .26614 Mdot
.48377 .31277 Mdot
.35846 .70937 Mdot
.48373 .49511 Mdot
.28541 .46905 Mdot
.34195 .67565 Mdot
.50364 .27561 Mdot
.52852 .34097 Mdot
.50443 .3582 Mdot
.58205 .71025 Mdot
.37535 .68283 Mdot
.50423 .27221 Mdot
.53377 .29853 Mdot
.64918 .52501 Mdot
.62579 .53647 Mdot
.48523 .37086 Mdot
.33613 .72466 Mdot
.56553 .71902 Mdot
.3654 .70202 Mdot
.52255 .13853 Mdot
.29669 .46383 Mdot
.69338 .407 Mdot
.62909 .54123 Mdot
.32283 .8389 Mdot
.5984 .53 Mdot
.64779 .45599 Mdot
.48289 .3637 Mdot
.59327 .69287 Mdot
.55638 .70597 Mdot
.49089 .34338 Mdot
.53735 .31922 Mdot
.57805 .69285 Mdot
.43624 .53175 Mdot
.60165 .18245 Mdot
.47655 .46629 Mdot
.47918 .32282 Mdot
.59025 .31394 Mdot
.2745 .50747 Mdot
.46391 .31384 Mdot
.34469 .47596 Mdot
.40195 .66522 Mdot
.35954 .65629 Mdot
.2841 .50647 Mdot
.61258 .50827 Mdot
.39372 .7053 Mdot
.6224 .42044 Mdot
.42179 .28643 Mdot
.24061 .52936 Mdot
.82155 .42087 Mdot
.62376 .44847 Mdot
.64348 .59624 Mdot
.32095 .42204 Mdot
.67739 .48678 Mdot
.73935 .48697 Mdot
.56523 .69284 Mdot
.4614 .31711 Mdot
.26243 .494 Mdot
.42467 .20629 Mdot
.63625 .48539 Mdot
.47736 .3334 Mdot
.28412 .46781 Mdot
.40281 .27541 Mdot
.42349 .56616 Mdot
.66083 .51119 Mdot
.56181 .9042 Mdot
.50284 .36583 Mdot
.37869 .65471 Mdot
.67639 .38646 Mdot
.47597 .29777 Mdot
.44927 .67548 Mdot
.3745 .63429 Mdot
.49639 .46142 Mdot
.51799 .35589 Mdot
.55025 .67015 Mdot
.51452 .33269 Mdot
.58967 .70671 Mdot
.54126 .32924 Mdot
.3951 .68912 Mdot
.63733 .46433 Mdot
.39576 .6844 Mdot
.55902 .68103 Mdot
.39764 .70733 Mdot
.26251 .49385 Mdot
.38913 .43343 Mdot
.27683 .48809 Mdot
.54509 .57157 Mdot
.68802 .28227 Mdot
.31313 .50045 Mdot
.39558 .53243 Mdot
.66305 .48512 Mdot
.5198 .3732 Mdot
.38529 .65468 Mdot
.39754 .71675 Mdot
.48449 .51259 Mdot
.49305 .35546 Mdot
.39307 .69565 Mdot
.59163 .32521 Mdot
.37341 .82456 Mdot
.57757 .4596 Mdot
.21694 .66119 Mdot
.48266 .3355 Mdot
.35392 .71117 Mdot
.47021 .43881 Mdot
.51745 .29755 Mdot
.37478 .64824 Mdot
.30609 .49992 Mdot
.29624 .46971 Mdot
.60087 .46699 Mdot
.29097 .52088 Mdot
.34967 .69308 Mdot
.73516 .2917 Mdot
.52002 .34053 Mdot
.36659 .25938 Mdot
.55536 .68633 Mdot
.3952 .66227 Mdot
.58582 .51529 Mdot
.54983 .34055 Mdot
.3982 .64765 Mdot
.18589 .45749 Mdot
.4614 .15337 Mdot
.39277 .69646 Mdot
.52177 .32962 Mdot
.50644 .31267 Mdot
.60995 .4269 Mdot
.4881 .49502 Mdot
.38476 .69936 Mdot
.30247 .59234 Mdot
.63308 .63591 Mdot
.40771 .42471 Mdot
.80929 .52751 Mdot
.62707 .51625 Mdot
.61931 .52176 Mdot
.32061 .48203 Mdot
.64823 .46618 Mdot
.5346 .30672 Mdot
.60127 .53323 Mdot
.32024 .50454 Mdot
.39945 .70896 Mdot
.64132 .4813 Mdot
.56339 .68938 Mdot
.30631 .5119 Mdot
.32892 .4816 Mdot
.40441 .67469 Mdot
.51928 .34645 Mdot
.27384 .38726 Mdot
.3843 .68017 Mdot
.60643 .51538 Mdot
.39489 .43671 Mdot
.61529 .54356 Mdot
.31941 .55611 Mdot
.49964 .28575 Mdot
.37344 .65514 Mdot
.47471 .36415 Mdot
.29862 .48951 Mdot
.37196 .72293 Mdot
.6673 .46977 Mdot
.35908 .66021 Mdot
.39052 .57055 Mdot
.45157 .7441 Mdot
.53702 .30802 Mdot
.43508 .60749 Mdot
.53227 .32768 Mdot
.40958 .42453 Mdot
.69271 .65601 Mdot
.57108 .71267 Mdot
.35855 .69974 Mdot
.40558 .24506 Mdot
.39444 .65468 Mdot
.65239 .47629 Mdot
.62567 .50447 Mdot
.36236 .68498 Mdot
.57519 .7185 Mdot
.62269 .74963 Mdot
.51412 .70705 Mdot
.51101 .30358 Mdot
.44605 .58151 Mdot
.55019 .14533 Mdot
.41156 .63742 Mdot
.27895 .49987 Mdot
.72799 .53072 Mdot
.66904 .49473 Mdot
.27793 .4706 Mdot
.3202 .46437 Mdot
.57792 .68343 Mdot
.39676 .66029 Mdot
.47539 .2876 Mdot
.2679 .49984 Mdot
.55114 .32329 Mdot
.63331 .69262 Mdot
.65179 .55392 Mdot
.54012 .45105 Mdot
.65478 .44571 Mdot
.47959 .52731 Mdot
.31534 .51058 Mdot
.61879 .4874 Mdot
.70685 .45225 Mdot
.31481 .48584 Mdot
.58487 .68797 Mdot
.5602 .34779 Mdot
.39795 .69421 Mdot
.34665 .83166 Mdot
.63497 .44825 Mdot
.63933 .46752 Mdot
.31431 .4729 Mdot
.7416 .42437 Mdot
.48158 .31138 Mdot
.52125 .34325 Mdot
.3804 .66904 Mdot
.4504 .48624 Mdot
.59833 .46921 Mdot
.65387 .45349 Mdot
.39414 .70272 Mdot
.39887 .44276 Mdot
.83009 .4903 Mdot
.62857 .49202 Mdot
.29843 .477 Mdot
.37238 .56783 Mdot
.30917 .51417 Mdot
.68146 .47323 Mdot
.65441 .48098 Mdot
.66095 .45529 Mdot
.62604 .44398 Mdot
.27295 .50078 Mdot
.66975 .47024 Mdot
.66865 .54787 Mdot
.49237 .33401 Mdot
.62118 .51898 Mdot
.63576 .63441 Mdot
.62991 .48797 Mdot
.56088 .68963 Mdot
.45734 .44998 Mdot
.60149 .48487 Mdot
.61936 .51898 Mdot
.62886 .6367 Mdot
.63428 .45873 Mdot
.28101 .4693 Mdot
.50061 .31159 Mdot
.30035 .48946 Mdot
.28396 .5 Mdot
.39155 .64567 Mdot
.59125 .70992 Mdot
.6199 .43611 Mdot
.58231 .69775 Mdot
.58997 .43539 Mdot
.59121 .55618 Mdot
.52338 .55393 Mdot
.46824 .44494 Mdot
.53015 .71193 Mdot
.66031 .46047 Mdot
.38628 .66689 Mdot
.37044 .6554 Mdot
.43914 .60086 Mdot
.57302 .5166 Mdot
.26552 .50191 Mdot
.29959 .50604 Mdot
.50931 .7059 Mdot
.49123 .67796 Mdot
.57456 .69429 Mdot
.56224 .61071 Mdot
.68074 .52161 Mdot
.6065 .49813 Mdot
.57873 .54481 Mdot
.38762 .6391 Mdot
.38825 .43294 Mdot
.41057 .69504 Mdot
.43641 .40927 Mdot
.27457 .5101 Mdot
.62334 .44896 Mdot
.18653 .39814 Mdot
.5079 .29892 Mdot
.50023 .31095 Mdot
.32121 .50373 Mdot
.36214 .70832 Mdot
.57645 .53099 Mdot
.2618 .74975 Mdot
.52266 .29648 Mdot
.53581 .71525 Mdot
.62399 .45966 Mdot
.40165 .66913 Mdot
.52216 .31095 Mdot
.56363 .73454 Mdot
.63332 .44339 Mdot
.35871 .64123 Mdot
.62337 .48204 Mdot
.63941 .31788 Mdot
.49945 .34141 Mdot
.51562 .51776 Mdot
.49884 .37584 Mdot
.27288 .49447 Mdot
.30873 .4884 Mdot
.65183 .4844 Mdot
.30339 .79157 Mdot
.52059 .26661 Mdot
.30679 .4557 Mdot
.56419 .73319 Mdot
.38921 .43961 Mdot
.57082 .73133 Mdot
.36376 .67762 Mdot
.57365 .70046 Mdot
.39821 .64844 Mdot
.33912 .73054 Mdot
.47542 .27961 Mdot
.5432 .70875 Mdot
.759 .43626 Mdot
.58122 .48154 Mdot
.56753 .68029 Mdot
.60109 .52564 Mdot
.58731 .4341 Mdot
.40191 .69659 Mdot
.58172 .70537 Mdot
.65325 .50862 Mdot
.32994 .25786 Mdot
.29967 .49788 Mdot
.2639 .49704 Mdot
.58123 .4849 Mdot
.34856 .70319 Mdot
.53981 .32036 Mdot
.4962 .55074 Mdot
.39656 .42008 Mdot
.65202 .45254 Mdot
.66142 .44774 Mdot
.50075 .36806 Mdot
.47188 .32612 Mdot
.65362 .48535 Mdot
.57624 .30739 Mdot
.66888 .47553 Mdot
.29998 .46919 Mdot
.50978 .30203 Mdot
.50428 .31049 Mdot
.34885 .68466 Mdot
.52965 .32358 Mdot
.70309 .51075 Mdot
.25197 .51144 Mdot
.605 .54809 Mdot
.29661 .48766 Mdot
.3263 .67719 Mdot
.41115 .67085 Mdot
.40333 .24331 Mdot
.52926 .32515 Mdot
.65823 .53162 Mdot
.50531 .2941 Mdot
.54569 .69249 Mdot
.4944 .30844 Mdot
.50999 .3702 Mdot
.60321 .46986 Mdot
.65688 .49951 Mdot
.39995 .44085 Mdot
.48813 .50408 Mdot
.50519 .34008 Mdot
.67531 .49783 Mdot
.63988 .54326 Mdot
.63013 .50525 Mdot
.51642 .55597 Mdot
.47263 .35639 Mdot
.64943 .40029 Mdot
.33248 .53672 Mdot
.50847 .3426 Mdot
.48846 .16774 Mdot
.40998 .4429 Mdot
.42631 .43405 Mdot
.33589 .47551 Mdot
.63156 .49392 Mdot
.38529 .68924 Mdot
.61732 .52236 Mdot
.56731 .49778 Mdot
.60463 .47823 Mdot
.54152 .71005 Mdot
.59183 .48072 Mdot
.41226 .43092 Mdot
.39005 .67865 Mdot
.67404 .49706 Mdot
.64211 .48664 Mdot
.42395 .43686 Mdot
.48788 .37323 Mdot
.52925 .33755 Mdot
.3704 .44361 Mdot
.57576 .68398 Mdot
.31675 .50303 Mdot
.60843 .51778 Mdot
.38316 .66842 Mdot
.39165 .68483 Mdot
.4831 .29515 Mdot
.38506 .70485 Mdot
.31715 .50504 Mdot
.65399 .46027 Mdot
.27294 .49538 Mdot
.54143 .70968 Mdot
.52161 .33168 Mdot
.59791 .51103 Mdot
.65144 .52185 Mdot
.49718 .34919 Mdot
.66414 .49076 Mdot
.53908 .70818 Mdot
.36984 .64212 Mdot
.49106 .30608 Mdot
.28277 .49118 Mdot
.34878 .6779 Mdot
.65277 .52959 Mdot
.37387 .17412 Mdot
.64946 .46661 Mdot
.651 .44984 Mdot
.44584 .26452 Mdot
.66013 .53679 Mdot
.39777 .65768 Mdot
.51242 .29697 Mdot
.67204 .45403 Mdot
.63028 .63943 Mdot
.58865 .67359 Mdot
.39886 .6325 Mdot
.62766 .45557 Mdot
.45851 .19208 Mdot
.64262 .5404 Mdot
.41772 .24013 Mdot
.52273 .5527 Mdot
.20024 .5456 Mdot
.54051 .45032 Mdot
.30997 .45542 Mdot
.39599 .44127 Mdot
.40561 .66111 Mdot
.73071 .39208 Mdot
.65745 .47584 Mdot
.74695 .33474 Mdot
.59954 .51386 Mdot
.29735 .47228 Mdot
.73486 .48658 Mdot
.36986 .70402 Mdot
.80521 .52587 Mdot
.62053 .51161 Mdot
.49872 .36533 Mdot
.35748 .72168 Mdot
.39825 .44557 Mdot
.65144 .50431 Mdot
.57141 .68711 Mdot
.54163 .66735 Mdot
.70433 .50617 Mdot
.29517 .48992 Mdot
.61179 .49908 Mdot
.63967 .42367 Mdot
.38632 .81891 Mdot
.48846 .32816 Mdot
.29343 .50294 Mdot
.53002 .64597 Mdot
.63068 .50373 Mdot
.52772 .34161 Mdot
.49924 .31451 Mdot
.58547 .69574 Mdot
.24546 .45635 Mdot
.58654 .77276 Mdot
.22147 .32416 Mdot
.77668 .36892 Mdot
.38235 .6382 Mdot
.52404 .39463 Mdot
.63155 .52477 Mdot
.77206 .63109 Mdot
.281 .49764 Mdot
.6365 .46572 Mdot
.75057 .35925 Mdot
.48866 .32119 Mdot
.62332 .48758 Mdot
.56499 .71815 Mdot
.28458 .40882 Mdot
.60583 .35022 Mdot
.3872 .18816 Mdot
.34083 .66171 Mdot
.58157 .51851 Mdot
.68686 .53471 Mdot
.4023 .41993 Mdot
.67829 .46595 Mdot
.38754 .65601 Mdot
.3479 .57411 Mdot
.56013 .72545 Mdot
.51076 .29995 Mdot
.40581 .44498 Mdot
.59971 .51494 Mdot
.63204 .55399 Mdot
.54046 .72119 Mdot
.6429 .50645 Mdot
.66195 .38435 Mdot
.42204 .44497 Mdot
.35214 .66426 Mdot
.49698 .36387 Mdot
.65931 .44875 Mdot
.39126 .44029 Mdot
.5988 .47836 Mdot
.75764 .5205 Mdot
.61665 .46913 Mdot
.47154 .23625 Mdot
.50374 .35069 Mdot
.29067 .49425 Mdot
.59191 .47737 Mdot
.62996 .47977 Mdot
.47238 .68729 Mdot
.57555 .52492 Mdot
.60133 .49647 Mdot
.48264 .29229 Mdot
.50595 .29727 Mdot
.47559 .33207 Mdot
.35029 .68069 Mdot
.48025 .46824 Mdot
.28836 .47904 Mdot
.57755 .54164 Mdot
.26858 .50367 Mdot
.54564 .43808 Mdot
.55258 .72904 Mdot
.39151 .24127 Mdot
.66017 .47013 Mdot
.49659 .3583 Mdot
.63624 .20674 Mdot
.46797 .32689 Mdot
.34993 .49973 Mdot
.28437 .4972 Mdot
.5005 .33432 Mdot
.63433 .45657 Mdot
.49149 .48759 Mdot
.35446 .19799 Mdot
.2827 .47092 Mdot
.58401 .53726 Mdot
.34432 .6499 Mdot
.41366 .69994 Mdot
.51221 .17584 Mdot
.27353 .48122 Mdot
.31421 .42233 Mdot
.66465 .52447 Mdot
.51928 .30386 Mdot
.30918 .50668 Mdot
.29801 .45965 Mdot
.38765 .70542 Mdot
.65894 .51721 Mdot
.62814 .48137 Mdot
.41866 .43562 Mdot
.28177 .50867 Mdot
.54685 .46942 Mdot
.66272 .50688 Mdot
.42629 .29989 Mdot
.49694 .27671 Mdot
.56768 .85038 Mdot
.69438 .4288 Mdot
.74885 .35344 Mdot
.34643 .61966 Mdot
.48902 .305 Mdot
.61309 .50998 Mdot
.57847 .53951 Mdot
.36867 .64029 Mdot
.65095 .46088 Mdot
.36747 .71607 Mdot
.27236 .48928 Mdot
.39605 .22934 Mdot
.40769 .51889 Mdot
.24006 .49224 Mdot
.64844 .46899 Mdot
.59989 .34987 Mdot
.54524 .70898 Mdot
.26459 .47021 Mdot
.47642 .31525 Mdot
.68209 .48645 Mdot
.39438 .63852 Mdot
.3513 .6833 Mdot
.49482 .31991 Mdot
.38714 .39866 Mdot
.40897 .24079 Mdot
.63382 .44036 Mdot
.36165 .67126 Mdot
.40268 .47323 Mdot
.54668 .24363 Mdot
.33273 .47575 Mdot
.55689 .72538 Mdot
.40338 .66093 Mdot
.26866 .5147 Mdot
.58023 .44135 Mdot
.50196 .32686 Mdot
.50972 .36409 Mdot
.44444 .6394 Mdot
.38992 .69544 Mdot
.56318 .71003 Mdot
.43596 .59558 Mdot
.44502 .59214 Mdot
.55466 .71951 Mdot
.37011 .72001 Mdot
.49485 .29907 Mdot
.48029 .33999 Mdot
.50153 .3124 Mdot
.70289 .41029 Mdot
.50734 .28863 Mdot
.68977 .73416 Mdot
.68063 .47688 Mdot
.57377 .2841 Mdot
.67836 .50503 Mdot
.26494 .48619 Mdot
.50016 .34274 Mdot
.51991 .54455 Mdot
.67361 .53123 Mdot
.3707 .19559 Mdot
.6148 .47862 Mdot
.38721 .56209 Mdot
.63317 .49348 Mdot
.65093 .36142 Mdot
.46227 .31177 Mdot
.66601 .46668 Mdot
.25316 .51812 Mdot
.5588 .69257 Mdot
.47634 .27498 Mdot
.60281 .49713 Mdot
.37702 .36454 Mdot
.60198 .52639 Mdot
.43657 .22646 Mdot
.43098 .71994 Mdot
.5379 .68357 Mdot
.63201 .54688 Mdot
.41089 .65533 Mdot
.69849 .57253 Mdot
.58476 .29922 Mdot
.28155 .47206 Mdot
.5958 .34213 Mdot
.37671 .70832 Mdot
.73691 .48127 Mdot
.6894 .50259 Mdot
.56716 .72439 Mdot
.56088 .34066 Mdot
.30397 .46902 Mdot
.6597 .47763 Mdot
.61799 .50942 Mdot
.24296 .54005 Mdot
.59605 .31079 Mdot
.56002 .54277 Mdot
.53807 .72475 Mdot
.60885 .34434 Mdot
.60321 .48616 Mdot
.39625 .63226 Mdot
.52111 .30192 Mdot
.72322 .51154 Mdot
.74289 .44217 Mdot
.67474 .49121 Mdot
.49754 .33065 Mdot
.53058 .32973 Mdot
.67572 .2221 Mdot
.56103 .72883 Mdot
.61558 .47127 Mdot
.44613 .65204 Mdot
.60401 .51441 Mdot
.29153 .47435 Mdot
.68475 .51502 Mdot
.41057 .67683 Mdot
.47174 .42925 Mdot
.35038 .68378 Mdot
.64516 .5002 Mdot
.51687 .33158 Mdot
.31111 .47195 Mdot
.2049 .59001 Mdot
.33007 .44326 Mdot
.6876 .73477 Mdot
.54166 .6656 Mdot
.57165 .69007 Mdot
.58091 .72453 Mdot
.31772 .44709 Mdot
.6324 .45431 Mdot
.47633 .53143 Mdot
.57289 .46411 Mdot
.63111 .4981 Mdot
.61402 .46901 Mdot
.34509 .44801 Mdot
.28561 .49676 Mdot
.39978 .68401 Mdot
.65455 .48504 Mdot
.6756 .49777 Mdot
.51063 .3357 Mdot
.57505 .69652 Mdot
.36362 .64764 Mdot
.56105 .68233 Mdot
.38924 .67414 Mdot
.55545 .16347 Mdot
.62152 .55922 Mdot
.55667 .69367 Mdot
.30445 .51485 Mdot
.48002 .34734 Mdot
.42346 .43208 Mdot
.36474 .67985 Mdot
.37187 .70398 Mdot
.67239 .47461 Mdot
.52461 .33034 Mdot
.52724 .33606 Mdot
.5775 .69279 Mdot
.30381 .50508 Mdot
.64234 .43469 Mdot
.65959 .5015 Mdot
.21301 .61745 Mdot
.36286 .64456 Mdot
.60002 .33507 Mdot
.46462 .24854 Mdot
.63752 .45208 Mdot
.52516 .34447 Mdot
.63898 .47728 Mdot
.38448 .4889 Mdot
.47437 .33339 Mdot
.66815 .53127 Mdot
.5611 .4622 Mdot
.38591 .63933 Mdot
.76269 .2983 Mdot
.61123 .44305 Mdot
.27575 .53143 Mdot
.64072 .52105 Mdot
.8313 .36395 Mdot
.65396 .21677 Mdot
.5935 .50893 Mdot
.62033 .44833 Mdot
.23626 .29778 Mdot
.62667 .54218 Mdot
.41581 .43392 Mdot
.56749 .50083 Mdot
.52661 .34479 Mdot
.41207 .56874 Mdot
.48158 .52056 Mdot
.57182 .72755 Mdot
.38067 .66816 Mdot
.64992 .70102 Mdot
.58946 .69648 Mdot
.48215 .33084 Mdot
.62701 .55568 Mdot
.47006 .24819 Mdot
.41146 .70902 Mdot
.68206 .45923 Mdot
.29371 .47322 Mdot
.48027 .51985 Mdot
.41299 .68715 Mdot
.28161 .49184 Mdot
.64471 .54047 Mdot
.35592 .77065 Mdot
.25847 .53029 Mdot
.68752 .22426 Mdot
.31988 .48291 Mdot
.29853 .49589 Mdot
.4888 .47385 Mdot
.57279 .72704 Mdot
.27956 .56573 Mdot
.69059 .53983 Mdot
.29175 .46583 Mdot
.7369 .59916 Mdot
.35315 .64965 Mdot
.45883 .48297 Mdot
.46417 .31013 Mdot
.6051 .5597 Mdot
.62744 .46309 Mdot
.31223 .49606 Mdot
.50676 .39163 Mdot
.49698 .65799 Mdot
.27646 .48123 Mdot
.69316 .52145 Mdot
.45634 .47175 Mdot
.39167 .43484 Mdot
.41411 .44175 Mdot
.55752 .73385 Mdot
.46955 .78415 Mdot
.50556 .35268 Mdot
.53535 .71096 Mdot
.52319 .51817 Mdot
.61189 .48569 Mdot
.27605 .50689 Mdot
.41822 .4422 Mdot
.28471 .48835 Mdot
.55212 .7039 Mdot
.54578 .72644 Mdot
.4915 .33301 Mdot
.48242 .30825 Mdot
.50704 .23889 Mdot
.67711 .607 Mdot
.6219 .52772 Mdot
.70022 .27835 Mdot
.47265 .32467 Mdot
.73538 .4072 Mdot
.58428 .71022 Mdot
.57793 .70868 Mdot
.60588 .26922 Mdot
.64808 .52979 Mdot
.37555 .56709 Mdot
.60098 .48773 Mdot
.72734 .63092 Mdot
.59911 .51591 Mdot
.38976 .70391 Mdot
.62543 .51387 Mdot
.273 .37279 Mdot
.67243 .50209 Mdot
.61223 .4688 Mdot
.37059 .68323 Mdot
.63425 .43413 Mdot
.40871 .68766 Mdot
.61049 .50608 Mdot
.60026 .7111 Mdot
.3828 .6688 Mdot
.5905 .7311 Mdot
.42059 .54904 Mdot
.40674 .43865 Mdot
.57854 .72508 Mdot
.56681 .68641 Mdot
.62074 .67486 Mdot
.48359 .30094 Mdot
.73462 .45857 Mdot
.62618 .45923 Mdot
.34365 .68019 Mdot
.29757 .51386 Mdot
.67492 .48964 Mdot
.59995 .53343 Mdot
.62858 .43195 Mdot
.49457 .33302 Mdot
.3605 .7166 Mdot
.55711 .69836 Mdot
.36775 .65589 Mdot
.59609 .72161 Mdot
.41019 .66083 Mdot
.59939 .44581 Mdot
.58502 .43867 Mdot
.67593 .54231 Mdot
.72887 .32844 Mdot
.79161 .64883 Mdot
.49889 .32286 Mdot
.39726 .4335 Mdot
.55243 .7294 Mdot
.45 .58286 Mdot
.50642 .35524 Mdot
.37351 .70318 Mdot
.62326 .48181 Mdot
.67735 .5461 Mdot
.61768 .56759 Mdot
.53931 .2938 Mdot
.55346 .74429 Mdot
.37027 .67228 Mdot
.3999 .42476 Mdot
.47433 .46833 Mdot
.44813 .34302 Mdot
.53818 .5643 Mdot
.63444 .47857 Mdot
.57701 .69086 Mdot
.52203 .31072 Mdot
.30919 .56846 Mdot
.3092 .49759 Mdot
.48803 .49928 Mdot
.64717 .46703 Mdot
.37119 .42004 Mdot
.51659 .33036 Mdot
.57042 .71926 Mdot
.31302 .49467 Mdot
.5712 .72601 Mdot
.39397 .4466 Mdot
.37409 .43834 Mdot
.64865 .50678 Mdot
.59919 .49215 Mdot
.27791 .51104 Mdot
.50834 .35092 Mdot
.6019 .6961 Mdot
.23637 .53383 Mdot
.36264 .67981 Mdot
.44212 .50106 Mdot
.51554 .30404 Mdot
.33213 .43294 Mdot
.35767 .66649 Mdot
.27173 .51451 Mdot
.48136 .53096 Mdot
.32388 .49545 Mdot
.60664 .47938 Mdot
.5151 .31425 Mdot
.27483 .47736 Mdot
.22298 .61788 Mdot
.47192 .21037 Mdot
.54483 .29021 Mdot
.65877 .49088 Mdot
.39146 .23746 Mdot
.35048 .38911 Mdot
.5443 .39452 Mdot
.26824 .49816 Mdot
.6489 .47886 Mdot
.6357 .44007 Mdot
.6216 .51197 Mdot
.30274 .49803 Mdot
.21937 .4773 Mdot
.35811 .69463 Mdot
.61848 .49018 Mdot
.55331 .68711 Mdot
.40876 .67872 Mdot
.42006 .68413 Mdot
.40192 .65798 Mdot
.47214 .32296 Mdot
.63488 .55594 Mdot
.60149 .5757 Mdot
.73783 .26883 Mdot
.29476 .49558 Mdot
.40699 .43832 Mdot
.64827 .44716 Mdot
.67019 .7362 Mdot
.47929 .3419 Mdot
.36643 .68732 Mdot
.63736 .46701 Mdot
.44708 .69149 Mdot
.41142 .45138 Mdot
.37795 .6813 Mdot
.47606 .31916 Mdot
.54403 .3965 Mdot
.65281 .46153 Mdot
.63987 .52365 Mdot
.48734 .34737 Mdot
.32515 .40836 Mdot
.4712 .46596 Mdot
.63954 .47978 Mdot
.28669 .49455 Mdot
.3436 .81797 Mdot
.6627 .53184 Mdot
.54047 .36893 Mdot
.38752 .43152 Mdot
.43425 .3349 Mdot
.58514 .32613 Mdot
.57385 .47896 Mdot
.35461 .23053 Mdot
.6503 .75744 Mdot
.41235 .20994 Mdot
.72588 .64486 Mdot
.2284 .51904 Mdot
.60905 .17306 Mdot
.2592 .52183 Mdot
.64471 .34782 Mdot
.17794 .45403 Mdot
.33763 .41899 Mdot
.42741 .73893 Mdot
.23168 .58685 Mdot
.34455 .75506 Mdot
.81817 .51377 Mdot
.41594 .66742 Mdot
.75271 .62633 Mdot
.59676 .49851 Mdot
.32864 .39841 Mdot
.63585 .35994 Mdot
.75055 .70887 Mdot
.39238 .24818 Mdot
.44918 .66341 Mdot
.34469 .19175 Mdot
.39884 .26455 Mdot
.53909 .21301 Mdot
.76338 .47354 Mdot
.5071 .80004 Mdot
.44841 .59272 Mdot
.65524 .7138 Mdot
.59486 .35811 Mdot
.27697 .35212 Mdot
.24897 .51775 Mdot
.64432 .24131 Mdot
.41526 .83171 Mdot
.37639 .65915 Mdot
.52356 .30428 Mdot
.26645 .56655 Mdot
.52171 .21248 Mdot
.32257 .52799 Mdot
.35469 .2302 Mdot
.43415 .27504 Mdot
.64796 .35835 Mdot
.51742 .5176 Mdot
.63964 .30982 Mdot
.60725 .77094 Mdot
.79063 .54432 Mdot
.54629 .32904 Mdot
.24399 .6126 Mdot
.45201 .59158 Mdot
.61533 .70879 Mdot
.67473 .37792 Mdot
.5555 .7359 Mdot
.57794 .73336 Mdot
.47529 .32459 Mdot
.54394 .23718 Mdot
.42775 .44036 Mdot
.52461 .51697 Mdot
.40083 .64025 Mdot
.38842 .49353 Mdot
.29164 .40217 Mdot
.36596 .39076 Mdot
.80065 .36284 Mdot
.40222 .16838 Mdot
.67195 .63459 Mdot
.34013 .56871 Mdot
.33017 .51748 Mdot
.65191 .72849 Mdot
.59054 .57911 Mdot
.70018 .60969 Mdot
.76082 .51302 Mdot
.27699 .2363 Mdot
.39464 .35706 Mdot
.33709 .18894 Mdot
.53958 .34613 Mdot
.71355 .46653 Mdot
.35736 .54908 Mdot
.77925 .38715 Mdot
.61667 .64555 Mdot
.39852 .1758 Mdot
.54229 .67766 Mdot
.46451 .30128 Mdot
.33877 .42001 Mdot
.65369 .38213 Mdot
.59312 .75594 Mdot
.52468 .67007 Mdot
.72359 .50818 Mdot
.27403 .22726 Mdot
.34453 .23599 Mdot
.60264 .19316 Mdot
.42451 .31397 Mdot
.43284 .68401 Mdot
.42148 .67662 Mdot
.29575 .4591 Mdot
.50539 .19314 Mdot
.51367 .31938 Mdot
.74874 .27437 Mdot
.47137 .21905 Mdot
.7028 .57217 Mdot
.25381 .24549 Mdot
.82232 .48169 Mdot
.57289 .28746 Mdot
.75048 .6796 Mdot
.2816 .74004 Mdot
.57889 .57909 Mdot
.30448 .43385 Mdot
.36499 .63137 Mdot
.47144 .23262 Mdot
.4942 .18955 Mdot
.74878 .58375 Mdot
.20284 .37127 Mdot
.52571 .51533 Mdot
.34771 .6274 Mdot
.51529 .26736 Mdot
.41946 .75497 Mdot
.58089 .63247 Mdot
.34517 .18589 Mdot
.61611 .35102 Mdot
.32539 .79327 Mdot
.70473 .65599 Mdot
.73954 .42443 Mdot
.34573 .25427 Mdot
.35385 .7446 Mdot
.6962 .59056 Mdot
.38561 .37324 Mdot
.58809 .5359 Mdot
.57216 .60656 Mdot
.74551 .49064 Mdot
.54804 .7597 Mdot
.48068 .46195 Mdot
.38877 .32441 Mdot
.67435 .6644 Mdot
.20506 .4922 Mdot
.73428 .44353 Mdot
.47643 .35582 Mdot
.68102 .61672 Mdot
.7004 .63938 Mdot
.41697 .33081 Mdot
.53417 .64394 Mdot
.59153 .1876 Mdot
.51107 .65307 Mdot
.57106 .48114 Mdot
.64307 .34151 Mdot
.59607 .36231 Mdot
.72004 .6147 Mdot
.59338 .45998 Mdot
.78255 .33794 Mdot
.42993 .30781 Mdot
.70664 .31308 Mdot
.64867 .66783 Mdot
.72178 .32251 Mdot
.49435 .21101 Mdot
.35698 .54344 Mdot
.28663 .43404 Mdot
.53461 .38837 Mdot
.27803 .22541 Mdot
.40456 .68271 Mdot
.73152 .5958 Mdot
.26156 .52616 Mdot
.21633 .61095 Mdot
.22937 .53788 Mdot
.50138 .65498 Mdot
.5206 .19132 Mdot
.3655 .40247 Mdot
.34973 .72553 Mdot
.26634 .34068 Mdot
.41426 .46713 Mdot
.69397 .27891 Mdot
.68168 .43269 Mdot
.7443 .53561 Mdot
.53886 .7092 Mdot
.74534 .38902 Mdot
.33768 .53959 Mdot
.51955 .75043 Mdot
.57823 .47266 Mdot
.44616 .62662 Mdot
.41016 .42344 Mdot
.47229 .51007 Mdot
.5526 .16135 Mdot
.66702 .42051 Mdot
.81818 .48858 Mdot
.35368 .40025 Mdot
.47253 .52578 Mdot
.61322 .68125 Mdot
.45372 .37881 Mdot
.32291 .19437 Mdot
.53615 .18146 Mdot
.34018 .37413 Mdot
.38718 .23505 Mdot
.8587 .51114 Mdot
.20137 .53479 Mdot
.79868 .40956 Mdot
.26006 .52554 Mdot
.70731 .82146 Mdot
.36197 .65978 Mdot
.78271 .62556 Mdot
.77557 .38681 Mdot
.46182 .68819 Mdot
.51977 .21284 Mdot
.60903 .37322 Mdot
.58338 .64938 Mdot
.49937 .37351 Mdot
.58833 .45986 Mdot
.42299 .17802 Mdot
.29023 .21987 Mdot
.41507 .17852 Mdot
.39441 .4103 Mdot
.42678 .19199 Mdot
.23774 .28541 Mdot
.69275 .73343 Mdot
.26038 .54998 Mdot
.68627 .49817 Mdot
.74022 .57478 Mdot
.82002 .46333 Mdot
.52364 .69647 Mdot
.56749 .56548 Mdot
.54595 .32173 Mdot
.23512 .28025 Mdot
.55408 .15993 Mdot
.63131 .27817 Mdot
.55179 .22168 Mdot
.37634 .58414 Mdot
.71147 .59864 Mdot
.53975 .20291 Mdot
.28838 .32901 Mdot
.42472 .27986 Mdot
.22007 .30927 Mdot
.69505 .64774 Mdot
.23179 .59152 Mdot
.33485 .36423 Mdot
.81313 .44039 Mdot
.34583 .25006 Mdot
.25545 .56454 Mdot
.68541 .59036 Mdot
.48517 .26325 Mdot
.49802 .65958 Mdot
.27347 .34723 Mdot
.36434 .56715 Mdot
.64483 .65329 Mdot
.39469 .70957 Mdot
.74493 .58234 Mdot
.51186 .58191 Mdot
.26005 .55062 Mdot
.63633 .68753 Mdot
.75631 .57953 Mdot
.36326 .34524 Mdot
.42021 .18592 Mdot
.35503 .40142 Mdot
.27749 .74308 Mdot
.36231 .27369 Mdot
.74488 .49821 Mdot
.63213 .43369 Mdot
.50614 .20129 Mdot
.49485 .14957 Mdot
.52322 .1894 Mdot
.41641 .39901 Mdot
.44018 .65427 Mdot
.29181 .52111 Mdot
.64485 .7212 Mdot
.47619 .67045 Mdot
.43474 .24968 Mdot
.47534 .57743 Mdot
.2551 .50181 Mdot
.28324 .41138 Mdot
.5038 .23816 Mdot
.66431 .73627 Mdot
.63172 .24042 Mdot
.54529 .50633 Mdot
.55436 .25225 Mdot
.50392 .36805 Mdot
.38854 .4065 Mdot
.70857 .60657 Mdot
.40512 .67561 Mdot
.21768 .62674 Mdot
.50483 .38844 Mdot
.71019 .45659 Mdot
.34718 .57971 Mdot
.53079 .27271 Mdot
.74592 .34402 Mdot
.35364 .72441 Mdot
.58081 .1666 Mdot
.79656 .36439 Mdot
.54042 .20208 Mdot
.67785 .62421 Mdot
.22994 .62983 Mdot
.47045 .49474 Mdot
.32047 .51882 Mdot
.39261 .25505 Mdot
.44496 .54362 Mdot
.68969 .61902 Mdot
.55555 .26212 Mdot
.28057 .54908 Mdot
.57028 .50397 Mdot
.62685 .20066 Mdot
.68543 .72462 Mdot
.46087 .5065 Mdot
.44255 .30801 Mdot
.51867 .29236 Mdot
.8089 .63368 Mdot
.28398 .36124 Mdot
.6595 .58555 Mdot
.36934 .24088 Mdot
.32925 .46299 Mdot
.47593 .34728 Mdot
.7646 .56882 Mdot
.45624 .74139 Mdot
.53355 .25747 Mdot
.37898 .54364 Mdot
.52875 .21392 Mdot
.41836 .53338 Mdot
.3808 .23343 Mdot
.33292 .22638 Mdot
.35024 .81409 Mdot
.53695 .34939 Mdot
.32215 .56661 Mdot
.31677 .57297 Mdot
.53834 .30169 Mdot
.5489 .32355 Mdot
.60877 .35273 Mdot
.46257 .1744 Mdot
.43288 .57892 Mdot
.28212 .32376 Mdot
.4753 .52955 Mdot
.43407 .73901 Mdot
.29232 .55716 Mdot
.64418 .69485 Mdot
.30169 .26895 Mdot
.59022 .22881 Mdot
.18185 .61897 Mdot
.54214 .51438 Mdot
.78549 .61822 Mdot
.64484 .72212 Mdot
.76163 .48002 Mdot
.6734 .37502 Mdot
.41458 .27944 Mdot
.61265 .51793 Mdot
.41727 .16373 Mdot
.39561 .34525 Mdot
.56836 .61298 Mdot
.34838 .74643 Mdot
.64568 .53606 Mdot
.65661 .54832 Mdot
.53489 .20073 Mdot
.43785 .30021 Mdot
.16628 .53328 Mdot
.71639 .64552 Mdot
.73956 .5272 Mdot
.56575 .27996 Mdot
.81755 .48731 Mdot
.37251 .5312 Mdot
.43216 .21377 Mdot
.5128 .58795 Mdot
.82193 .45187 Mdot
.27905 .30374 Mdot
.26173 .3635 Mdot
.35957 .26554 Mdot
.2476 .27419 Mdot
.72243 .53566 Mdot
.43542 .38528 Mdot
.27925 .57204 Mdot
.64196 .44644 Mdot
.38863 .39793 Mdot
.37025 .24963 Mdot
.4199 .7957 Mdot
.60636 .59003 Mdot
.48788 .14785 Mdot
.55321 .48922 Mdot
.41563 .37835 Mdot
.18549 .48166 Mdot
.17621 .65273 Mdot
.26638 .37135 Mdot
.35121 .18354 Mdot
.25772 .35581 Mdot
.36062 .23868 Mdot
.32925 .45883 Mdot
.44011 .5596 Mdot
.72955 .30561 Mdot
.46956 .17172 Mdot
.47732 .76773 Mdot
.21357 .50315 Mdot
.69216 .25833 Mdot
.46266 .16918 Mdot
.55833 .48275 Mdot
.81036 .61823 Mdot
.42216 .70519 Mdot
.83667 .46658 Mdot
.80431 .39103 Mdot
.44987 .29243 Mdot
.74055 .60026 Mdot
.80955 .6005 Mdot
.7307 .72133 Mdot
.79896 .39028 Mdot
.77087 .51978 Mdot
.43669 .3298 Mdot
.66784 .6274 Mdot
.44652 .23245 Mdot
.8219 .52827 Mdot
.30942 .55966 Mdot
.43695 .42868 Mdot
.37636 .43543 Mdot
.47594 .23347 Mdot
.35867 .32921 Mdot
.35839 .55923 Mdot
.46197 .43593 Mdot
.51637 .22167 Mdot
.39403 .8637 Mdot
.23731 .36121 Mdot
.56518 .33267 Mdot
.30758 .21163 Mdot
.42174 .29373 Mdot
.45482 .5778 Mdot
.68472 .38605 Mdot
.66645 .72422 Mdot
.36801 .73687 Mdot
.60363 .47982 Mdot
.4548 .17256 Mdot
.35907 .73184 Mdot
.36027 .19002 Mdot
.69659 .22898 Mdot
.56956 .23727 Mdot
.66641 .42432 Mdot
.36002 .63175 Mdot
.78828 .52519 Mdot
.77719 .53652 Mdot
.3013 .22504 Mdot
.78819 .60704 Mdot
.44344 .51591 Mdot
.40149 .54579 Mdot
.40182 .52398 Mdot
.69098 .56917 Mdot
.82415 .46647 Mdot
.4427 .36553 Mdot
.65446 .67782 Mdot
.3269 .37222 Mdot
.72532 .60395 Mdot
.58763 .32761 Mdot
.64089 .71339 Mdot
.53288 .62974 Mdot
.5908 .65774 Mdot
.35446 .65081 Mdot
.20321 .34908 Mdot
.39315 .28109 Mdot
.77307 .32294 Mdot
.28011 .7433 Mdot
.38794 .37545 Mdot
.76224 .61826 Mdot
.3183 .53951 Mdot
.596 .59474 Mdot
.49573 .79028 Mdot
.67678 .67892 Mdot
.60056 .34293 Mdot
.42318 .23791 Mdot
.6634 .40707 Mdot
.50395 .18368 Mdot
.64334 .6574 Mdot
.17826 .42992 Mdot
.37039 .58957 Mdot
.74121 .37572 Mdot
.58944 .28974 Mdot
.24952 .7138 Mdot
.46196 .50938 Mdot
.27384 .22841 Mdot
.46676 .32983 Mdot
.39852 .16966 Mdot
.32059 .48738 Mdot
.41704 .81691 Mdot
.42284 .26589 Mdot
.5535 .59948 Mdot
.51922 .56599 Mdot
.65542 .21179 Mdot
.34622 .4086 Mdot
.36029 .38934 Mdot
.50068 .66226 Mdot
.41469 .68914 Mdot
.43507 .48934 Mdot
.28871 .31816 Mdot
.2049 .35231 Mdot
.64715 .43573 Mdot
.3989 .6107 Mdot
.78461 .53679 Mdot
.32654 .51488 Mdot
.43426 .29326 Mdot
.41272 .25174 Mdot
.5715 .3582 Mdot
.7071 .59962 Mdot
.24739 .27035 Mdot
.44058 .252 Mdot
.49329 .64059 Mdot
.74113 .47383 Mdot
.25091 .52942 Mdot
.18721 .55484 Mdot
.32136 .24933 Mdot
.40316 .53358 Mdot
.46893 .47008 Mdot
.67473 .63531 Mdot
.51294 .13082 Mdot
.28354 .22819 Mdot
.21085 .66634 Mdot
.4701 .52876 Mdot
.49328 .37842 Mdot
.66869 .70543 Mdot
.17803 .42625 Mdot
.83974 .46081 Mdot
.35454 .36183 Mdot
.73151 .59943 Mdot
.40563 .78569 Mdot
.79691 .6195 Mdot
.44853 .5296 Mdot
.59081 .2904 Mdot
.76238 .3514 Mdot
.35759 .48865 Mdot
.35296 .73608 Mdot
.4864 .54897 Mdot
.23488 .52217 Mdot
.43685 .33471 Mdot
.34695 .40984 Mdot
.17801 .43082 Mdot
.79413 .5954 Mdot
.73926 .46962 Mdot
.18594 .43331 Mdot
.48305 .27593 Mdot
.31058 .57257 Mdot
.19739 .60069 Mdot
.47238 .53979 Mdot
.37939 .64916 Mdot
.57586 .56078 Mdot
.45122 .47418 Mdot
.26008 .34054 Mdot
.37088 .77996 Mdot
.5804 .68191 Mdot
.5411 .35803 Mdot
.80352 .60002 Mdot
.53815 .33722 Mdot
.54729 .14405 Mdot
.29149 .32617 Mdot
.55938 .26369 Mdot
.26339 .31303 Mdot
.2542 .59832 Mdot
.28549 .75421 Mdot
.54169 .21482 Mdot
.62895 .63852 Mdot
.53717 .35961 Mdot
.52266 .35938 Mdot
.28643 .28914 Mdot
.36211 .45105 Mdot
.54299 .22821 Mdot
.81516 .49821 Mdot
.23252 .63405 Mdot
.53442 .3107 Mdot
.40061 .55085 Mdot
.55874 .35924 Mdot
.56258 .15963 Mdot
.37619 .65217 Mdot
.28588 .21768 Mdot
.6932 .42732 Mdot
.18137 .5561 Mdot
.46495 .23802 Mdot
.47635 .42997 Mdot
.45653 .52221 Mdot
.22978 .61737 Mdot
.57026 .49246 Mdot
.73715 .53023 Mdot
.48024 .3084 Mdot
.22701 .53156 Mdot
.5753 .70035 Mdot
.52168 .66177 Mdot
.28454 .53013 Mdot
.76634 .43286 Mdot
.82362 .4355 Mdot
.51141 .36568 Mdot
.36454 .58632 Mdot
.30963 .58506 Mdot
.5634 .45696 Mdot
.77927 .52325 Mdot
.22245 .31793 Mdot
.54424 .22023 Mdot
.46755 .3369 Mdot
.22274 .68412 Mdot
.51171 .71666 Mdot
.59541 .17324 Mdot
.5671 .39016 Mdot
.78828 .52986 Mdot
.75469 .46624 Mdot
.54623 .19441 Mdot
.58533 .32721 Mdot
.4396 .22129 Mdot
.68764 .61505 Mdot
.48856 .66713 Mdot
.7572 .57663 Mdot
.57217 .35554 Mdot
.41758 .51605 Mdot
.83189 .47986 Mdot
.39648 .78488 Mdot
.64083 .31663 Mdot
.59787 .57842 Mdot
.47992 .24017 Mdot
.81702 .48274 Mdot
.54206 .35957 Mdot
.59856 .69703 Mdot
.65774 .25178 Mdot
.42177 .27166 Mdot
.50237 .19345 Mdot
.41633 .33261 Mdot
.7913 .53136 Mdot
.40448 .51817 Mdot
.71108 .692 Mdot
.67613 .41635 Mdot
.56011 .58654 Mdot
.59519 .53255 Mdot
.73931 .49782 Mdot
.48839 .58864 Mdot
.67365 .22683 Mdot
.71566 .55208 Mdot
.45676 .18113 Mdot
.57789 .17215 Mdot
.40307 .20809 Mdot
.35885 .57369 Mdot
.53413 .32418 Mdot
.31012 .20453 Mdot
.79224 .51144 Mdot
.44659 .23557 Mdot
.80554 .40091 Mdot
.8143 .62677 Mdot
.17532 .44969 Mdot
.40085 .31392 Mdot
.51626 .25985 Mdot
.76082 .29575 Mdot
.39733 .35612 Mdot
.8123 .60648 Mdot
.60351 .34585 Mdot
.44969 .25994 Mdot
.24695 .25484 Mdot
.78423 .42315 Mdot
.36546 .38662 Mdot
.58913 .29594 Mdot
.57056 .31806 Mdot
.8019 .49222 Mdot
.58091 .5505 Mdot
.41148 .65863 Mdot
.447 .70476 Mdot
.73263 .60738 Mdot
.5645 .37646 Mdot
.80792 .50655 Mdot
.77859 .53962 Mdot
.75438 .62973 Mdot
.2323 .62345 Mdot
.17617 .4495 Mdot
.55675 .27259 Mdot
.68212 .54144 Mdot
.54528 .35746 Mdot
.59085 .70885 Mdot
.70237 .66317 Mdot
.669 .50557 Mdot
.49724 .5241 Mdot
.71323 .53086 Mdot
.44027 .16544 Mdot
.44957 .72682 Mdot
.24856 .48969 Mdot
.53293 .31558 Mdot
.47551 .23488 Mdot
.37136 .51549 Mdot
.33568 .41938 Mdot
.80433 .50731 Mdot
.5172 .24312 Mdot
.3736 .22628 Mdot
.37343 .38503 Mdot
.66666 .65149 Mdot
.59818 .7743 Mdot
.26734 .48559 Mdot
.7449 .33597 Mdot
.29011 .2379 Mdot
.39615 .38747 Mdot
.47026 .29133 Mdot
.33474 .35404 Mdot
.41909 .51936 Mdot
.43261 .39229 Mdot
.34783 .40482 Mdot
.32005 .54953 Mdot
.59087 .25221 Mdot
.32646 .23436 Mdot
.34304 .65268 Mdot
.70967 .6405 Mdot
.29771 .35586 Mdot
.80908 .50258 Mdot
.56185 .45722 Mdot
.47766 .19007 Mdot
.55012 .59481 Mdot
.52129 .74172 Mdot
.64914 .51588 Mdot
.77632 .48126 Mdot
.53365 .19923 Mdot
.31942 .36689 Mdot
.67529 .59435 Mdot
.45848 .34373 Mdot
.79641 .35973 Mdot
.39596 .73513 Mdot
.38023 .73726 Mdot
.76836 .65516 Mdot
.47264 .40631 Mdot
.47744 .66607 Mdot
.24895 .44946 Mdot
.56576 .48155 Mdot
.59094 .77636 Mdot
.38802 .54122 Mdot
.73757 .32441 Mdot
.79777 .41562 Mdot
.21329 .33363 Mdot
.37816 .5386 Mdot
.8009 .36037 Mdot
.75438 .33448 Mdot
.45455 .25848 Mdot
.80077 .59408 Mdot
.56495 .56086 Mdot
.59432 .45725 Mdot
.59847 .6968 Mdot
.49475 .27958 Mdot
.23206 .31049 Mdot
.71536 .57155 Mdot
.5563 .755 Mdot
.55005 .61088 Mdot
.35597 .55308 Mdot
.31937 .66908 Mdot
.42976 .31693 Mdot
.76223 .29688 Mdot
.70704 .60727 Mdot
.34288 .47297 Mdot
.26434 .3401 Mdot
.61123 .59621 Mdot
.46598 .1857 Mdot
.49871 .60582 Mdot
.52784 .20574 Mdot
.41541 .40917 Mdot
.74515 .35226 Mdot
.60471 .18561 Mdot
.59631 .62875 Mdot
.548 .57135 Mdot
.4442 .35037 Mdot
.55142 .55567 Mdot
.42407 .43205 Mdot
.46998 .70566 Mdot
.80477 .54186 Mdot
.19369 .39107 Mdot
.217 .4723 Mdot
.55997 .51459 Mdot
.67101 .70072 Mdot
.30692 .25063 Mdot
.45362 .58237 Mdot
.54008 .59824 Mdot
.27699 .57405 Mdot
.35337 .73139 Mdot
.35118 .82571 Mdot
.42672 .16443 Mdot
.64891 .51757 Mdot
.50761 .56718 Mdot
.5093 .68709 Mdot
.36494 .7159 Mdot
.62078 .23404 Mdot
.23212 .30647 Mdot
.27902 .47211 Mdot
.25589 .69396 Mdot
.24891 .45036 Mdot
.66367 .21741 Mdot
.20672 .64284 Mdot
.25463 .484 Mdot
.54514 .14264 Mdot
.34899 .37173 Mdot
.49356 .39503 Mdot
.36256 .83623 Mdot
.6425 .21003 Mdot
.75049 .48142 Mdot
.43604 .69682 Mdot
.43729 .17203 Mdot
.45617 .51995 Mdot
.43878 .64047 Mdot
.78725 .41786 Mdot
.70127 .61072 Mdot
.71366 .64429 Mdot
.2742 .44398 Mdot
.73233 .29174 Mdot
.78802 .68287 Mdot
.25681 .59812 Mdot
.24755 .72867 Mdot
.55531 .23044 Mdot
.35029 .21149 Mdot
.26762 .36815 Mdot
.42711 .79214 Mdot
.49725 .19825 Mdot
.7604 .56069 Mdot
.78105 .46016 Mdot
.46096 .76514 Mdot
.59686 .63283 Mdot
.6708 .71798 Mdot
.43196 .40432 Mdot
.55525 .21639 Mdot
.23855 .62024 Mdot
.65238 .60296 Mdot
.75112 .5794 Mdot
.76462 .36468 Mdot
.55181 .57518 Mdot
.3162 .22194 Mdot
.79542 .50131 Mdot
.68591 .62632 Mdot
.23314 .57119 Mdot
.57892 .73352 Mdot
.24979 .29106 Mdot
.38282 .47457 Mdot
.74933 .47552 Mdot
.1812 .49044 Mdot
.34452 .1868 Mdot
.5648 .56103 Mdot
.68202 .51953 Mdot
.61327 .17442 Mdot
.4072 .60263 Mdot
.79664 .40743 Mdot
.29461 .39441 Mdot
.72527 .63992 Mdot
.70882 .54741 Mdot
.60105 .52195 Mdot
.72731 .69514 Mdot
.48598 .25754 Mdot
.76541 .36107 Mdot
.20887 .63049 Mdot
.68385 .62327 Mdot
.76501 .45223 Mdot
.18136 .61525 Mdot
.57005 .38515 Mdot
.52513 .34929 Mdot
.43789 .16961 Mdot
.62925 .22141 Mdot
.74991 .50109 Mdot
.57057 .26752 Mdot
.49704 .61793 Mdot
.58088 .77568 Mdot
.73416 .4622 Mdot
.47015 .49711 Mdot
.73857 .60416 Mdot
.182 .43623 Mdot
.72013 .29533 Mdot
.27034 .22801 Mdot
.53472 .1847 Mdot
.53803 .32727 Mdot
.78115 .40834 Mdot
.46896 .54179 Mdot
.39449 .21251 Mdot
.22414 .60274 Mdot
.21917 .62053 Mdot
.77048 .69419 Mdot
.52027 .66643 Mdot
.59401 .50281 Mdot
.39713 .40905 Mdot
.5078 .18659 Mdot
.78669 .67259 Mdot
.49982 .18583 Mdot
.73432 .50844 Mdot
.62934 .43396 Mdot
.18185 .67176 Mdot
.36969 .23531 Mdot
.60248 .43366 Mdot
.65557 .57896 Mdot
.67543 .57746 Mdot
.60154 .50303 Mdot
.36119 .44811 Mdot
.65954 .72611 Mdot
.73339 .62825 Mdot
.45813 .17761 Mdot
.52101 .29043 Mdot
.45964 .51924 Mdot
.2592 .48349 Mdot
.503 .53872 Mdot
.54575 .43296 Mdot
.32453 .4601 Mdot
.74739 .61809 Mdot
.36069 .61131 Mdot
.60161 .74609 Mdot
.49569 .24685 Mdot
.46514 .41266 Mdot
.50051 .23393 Mdot
.77743 .60367 Mdot
.33006 .43583 Mdot
.72594 .72628 Mdot
.77914 .54472 Mdot
.71006 .43333 Mdot
.42794 .34531 Mdot
.85337 .52496 Mdot
.45687 .51154 Mdot
.37405 .42297 Mdot
.5559 .4407 Mdot
.63521 .39564 Mdot
.57668 .25487 Mdot
.53371 .67092 Mdot
.40906 .42114 Mdot
.73467 .49253 Mdot
.51813 .21124 Mdot
.32419 .50021 Mdot
.50354 .13728 Mdot
.65285 .42475 Mdot
.62383 .24535 Mdot
.45704 .20347 Mdot
.30834 .56635 Mdot
.59873 .34579 Mdot
.59911 .5384 Mdot
.48389 .63479 Mdot
.36637 .60905 Mdot
.55227 .36131 Mdot
.28341 .5552 Mdot
.35386 .22444 Mdot
.78004 .61891 Mdot
.59797 .23863 Mdot
.61732 .47131 Mdot
.55963 .67446 Mdot
.47821 .50233 Mdot
.43085 .78109 Mdot
.35547 .62299 Mdot
.42734 .2844 Mdot
.772 .60739 Mdot
.71521 .64653 Mdot
.59763 .3148 Mdot
.37638 .18216 Mdot
.61359 .58778 Mdot
.56708 .24006 Mdot
.52828 .6221 Mdot
.36623 .32731 Mdot
.77378 .5297 Mdot
.18844 .42827 Mdot
.73045 .52857 Mdot
.59111 .56893 Mdot
.52648 .15904 Mdot
.54245 .21239 Mdot
.23465 .48746 Mdot
.42466 .23475 Mdot
.80516 .53509 Mdot
.52029 .56772 Mdot
.3724 .8467 Mdot
.22 .60219 Mdot
.53065 .14328 Mdot
.2512 .53797 Mdot
.59632 .41814 Mdot
.45041 .37617 Mdot
.58635 .46135 Mdot
.38227 .68709 Mdot
.38359 .21059 Mdot
.44285 .34288 Mdot
.53544 .53072 Mdot
.65602 .55 Mdot
.42284 .59418 Mdot
.55135 .35207 Mdot
.18885 .40028 Mdot
.41104 .70385 Mdot
.49415 .63597 Mdot
.20274 .4833 Mdot
.36427 .61042 Mdot
.822 .61092 Mdot
.30471 .22156 Mdot
.39511 .25441 Mdot
.39289 .53891 Mdot
.37532 .81087 Mdot
.50663 .38141 Mdot
.54227 .29694 Mdot
.30009 .52659 Mdot
.71442 .69565 Mdot
.41199 .38972 Mdot
.18721 .45708 Mdot
.54457 .18989 Mdot
.56317 .45508 Mdot
.40881 .88125 Mdot
.7652 .56089 Mdot
.47403 .59219 Mdot
.40694 .39604 Mdot
.46805 .17669 Mdot
.35309 .75182 Mdot
.68968 .22593 Mdot
.28041 .35006 Mdot
.56211 .38616 Mdot
.69572 .71869 Mdot
.2248 .68493 Mdot
.39082 .55379 Mdot
.24991 .73143 Mdot
.35385 .25242 Mdot
.65487 .71319 Mdot
.31161 .36741 Mdot
.53347 .35737 Mdot
.7318 .53755 Mdot
.29784 .31812 Mdot
.57413 .56813 Mdot
.50069 .39267 Mdot
.34938 .2336 Mdot
.62278 .76403 Mdot
.21915 .56128 Mdot
.39209 .23098 Mdot
.31876 .52335 Mdot
.44439 .32935 Mdot
.78025 .55993 Mdot
.40303 .60984 Mdot
.38442 .71209 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0Xoooool2o`000:Cooooo000Looooo`03o`00
0?oooooooooo09oooooo0_l00002ooooo`;o0000Y?ooool001cooooo00?o0000ooooooooool0Wooo
ool3o`000:Oooooo000Looooo`03o`000?oooooooooo0:3ooooo0_l00004ooooo`;o0000XOooool0
01cooooo00?o0000ooooooooool0Y_ooool2o`000003ooooool0003o000000;ooooo0ol0002Ioooo
o`007?ooool00ol0003oooooooooo`2Yooooo`;o00000_ooool4o`0009Sooooo000Looooo`03o`00
0?oooooooooo08Sooooo0_l0000Aooooo`Co00004?ooool2o`0009Sooooo000Looooo`;o0000ROoo
ool2o`0000Sooooo0_l00007ooooo`Co0000Z_ooool001cooooo00?o0000ooooooooool0T_ooool2
o`000;Gooooo000Looooo`03o`000?oooooooooo0:Oooooo0_l00007ooooo`;o000000?oooooo`00
0?l00000U?ooool001cooooo00?o0000ooooooooool0Yoooool2o`0000Kooooo0ol000001?oooooo
0000o`000?ooool2o`00097ooooo000Looooo`03o`000?oooooooooo08Cooooo0_l000000ooooooo
0000o`000002ooooo`;o00008_ooool5o`0000;ooooo0_l0002Aooooo`007?ooool00ol0003ooooo
ooooo`1oooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo0_l00006ooooo`;o0000
1_ooool2o`0001Cooooo0ol00005ooooo`;o0000S_ooool001cooooo00?o0000ooooooooool0O_oo
ool3o`0000Wooooo0_l00007ooooo`Co00001?ooool2o`0001_ooooo0ol0002>ooooo`007?ooool0
0ol0003oooooooooo`1fooooo`;o00001_ooool2o`0000[ooooo0_l00004ooooo`;o000000?ooooo
o`000?l000000_l0000Qooooo`;o00001?ooool2o`0000;ooooo0ol00024ooooo`007?ooool00ol0
003oooooooooo`1fooooo`;o00001_ooool2o`0000Kooooo0_l00008ooooo`Ko00003Oooool2o`00
01Wooooo0_l00002ooooo`?o0000Q?ooool001cooooo00?o0000ooooooooool0O_ooool2o`0000?o
oooo0_l000000ooooooo0000o`000009ooooo`;o000000?oooooo`000?l000003Oooool2o`0000Go
oooo0_l0002Mooooo`007?ooool00ol0003oooooooooo`1^ooooo`;o00001oooool2o`0000Oooooo
0_l000000ooooooo0000o`00000<ooooo`;o00003Oooool2o`0000Sooooo0_l0000Dooooo`;o0000
1oooool2o`0007kooooo000Looooo`03o`000?oooooooooo06cooooo1?l00007ooooo`;o00001ooo
ool2o`0000?ooooo0_l0000=ooooo`;o00002Oooool4o`0000Oooooo0_l0000@ooooo`;o00000_oo
ool3o`0000Kooooo0_l0001nooooo`007?ooool00ol0003oooooooooo`1Zooooo`Co00000oooool2
o`0000Oooooo0_l00009ooooo`;o00001Oooool2o`0000Kooooo0_l000000ooooooo0000o`000004
ooooo`Ko00000oooool2o`0000;ooooo0_l000000ooooooo0000o`00000=ooooo`;o00000oooool2
o`0000Wooooo0_l0001kooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?oo
ool5o`0000Kooooo00?o0000ooooooooool0I_ooool2o`0000;ooooo1?l00003ooooo`;o00001ooo
ool2o`0000_ooooo0_l00003ooooo`;o00000oooool2o`0000Cooooo0_l00004ooooo`Go00000ooo
ool3o`0000Gooooo0_l0000Aooooo`;o00000_ooool2o`0000Kooooo0_l0001kooooo`0000Kooooo
ogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Ko
oooo00?o0000ooooooooool0IOooool3o`0000Cooooo0_l00007ooooo`;o00003oooool3o`0000So
oooo0_l000000ooooooo0000o`000009ooooo`?o00000oooool2o`0000Oooooo0_l0000@ooooo`;o
00000_ooool4o`00087ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo
00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`1Uooooo`;o00002?ooool2o`0000Cooooo
0_l00009ooooo`;o00000oooool3o`0000cooooo0_l00008ooooo`;o00002_ooool2o`0000;ooooo
0_l0000=ooooo`;o00000_ooool2o`0000?ooooo0_l00021ooooo`0000?oooooo`000?ooool00_oo
ool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0001Qooooo`;o00003?oo
ool2o`0000oooooo0_l00003ooooo`;o00001Oooool4o`0000kooooo0_l000000ooooooo0000o`00
0007ooooo`Co00003oooool2o`0000;ooooo0_l00005ooooo`;o00001_ooool2o`0007Oooooo0000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool0
0ol0003oooooooooo`1Qooooo`;o0000:Oooool9o`0000cooooo0_l00005ooooo`Ko00006_ooool2
o`0000Kooooo0_l0001gooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0=oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0HOooool2o`00013ooooo0_l0000:oooo
o`;o00001Oooool3o`0000Kooooo1_l0000:ooooo`;o00001oooool2o`00027ooooo0_l0001loooo
o`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_oo
ool00ol0003oooooooooo`1Pooooo`;o00003?ooool2o`0000?ooooo0_l00004ooooo`;o00001?oo
ool2o`000003ooooool0003o000000;ooooo0ol00008ooooo`;o00000oooool2o`0000Gooooo1?l0
0004ooooo`;o00009?ooool4o`0000;ooooo0_l0001fooooo`0000Koooooonk^k_lb<S;o0000oc8b
<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Pooooo`;o
00003?ooool2o`0000Wooooo0_l000000ooooooo0000o`000004ooooo`;o00001Oooool2o`0000_o
oooo0_l00003ooooo`Co00001_ooool5o`000004ooooool0003o0000o`0001oooooo0_l00002oooo
o`;o0000M_ooool001cooooo00?o0000ooooooooool0FOooool2o`0000kooooo0_l00007ooooo`;o
00002?ooool2o`0000_ooooo0_l0000@ooooo`;o00002?ooool5o`000004ooooool0003o0000o`00
00?ooooo0_l0000Nooooo`;o000000?oooooo`000?l00000Loooool001cooooo00?o0000oooooooo
ool0FOooool4o`0000;ooooo0_l00008ooooo`;o00001oooool2o`0001Oooooo0_l00008ooooo`;o
00001?ooool3o`0000oooooo0_l00002ooooo`;o00005Oooool3o`0000Kooooo0_l000000ooooooo
0000o`00001cooooo`007?ooool00ol0003oooooooooo`1Kooooo`;o00000_ooool2o`0000;ooooo
1?l00008ooooo`;o00006_ooool2o`0000Sooooo0_l00005ooooo`;o00001_ooool2o`0000Oooooo
1?l0000Gooooo`?o00003Oooool2o`0000;ooooo0_l0001[ooooo`007?ooool00ol0003ooooooooo
o`1Eooooo`Co00001Oooool2o`0000?ooooo1?l000000ooooooo0000o`000005ooooo`;o00001Ooo
ool2o`0001;ooooo0_l0000?ooooo`;o00001oooool2o`0000Wooooo0_l0000Hooooo`?o00002ooo
ool3o`0000;ooooo0_l0001[ooooo`007?ooool00ol0003oooooooooo`1Dooooo`Ko00001?ooool2
o`0000Sooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l0000;ooooo`;o00003oooool3
o`0000oooooo0_l00002ooooo`;o00002Oooool2o`0000cooooo0_l0000;ooooo`?o00000_ooool4
o`0006Wooooo000Looooo`03o`000?oooooooooo05Cooooo0ol000000ooooooo0000o`00000Doooo
o`?o00001oooool2o`0000;ooooo0ol0000>ooooo`;o00001_ooool4o`0000?ooooo0_l000000ooo
oooo0000o`00000<ooooo`;o00000_ooool2o`0000Wooooo0_l0000Jooooo`;o00001?ooool2o`00
06Wooooo000Looooo`03o`000?oooooooooo05Kooooo0_l0000>ooooo`;o00001?ooool4o`0000Co
oooo0_l00002ooooo`Ko00000_ooool2o`000004ooooool0003o0000ooooo`?o00001?ooool2o`00
00Kooooo1?l00006ooooo`;o00007?ooool2o`0000Oooooo0_l00021ooooo`007?ooool00ol0003o
ooooooooo`1Fooooo`;o00000oooool2o`0000Wooooo0_l00004ooooo`;o00000oooool2o`000003
ooooool0003o000000Cooooo0ol00003ooooo`Wo00001?ooool2o`0000Cooooo1_l00007ooooo`?o
00002_ooool2o`0000Gooooo0ol00006ooooo`?o00001_ooool2o`0000;ooooo0_l0001mooooo`00
7?ooool00ol0003oooooooooo`1Kooooo`;o00005?ooool2o`000003ooooool0003o000000Gooooo
3Ol0000:ooooo`?o00000_ooool3o`0000Kooooo1_l00007ooooo`;o00001Oooool3o`0000Oooooo
0ol00008ooooo`?o00000_ooool2o`0007Wooooo000Looooo`03o`000?oooooooooo04oooooo0_l0
000Sooooo`;o00001Oooool8o`000003ooooool0003o000000Gooooo0_l00005ooooo`;o00001?oo
ool2o`0000Sooooo1?l00006ooooo`Co00003_ooool3o`0000Kooooo1?l00003ooooo`;o0000NOoo
ool001cooooo00?o0000ooooooooool0Coooool2o`0001Cooooo0_l0000Eooooo`;o000000?ooooo
o`000?l000000_l00008ooooo`;o00001_ooool4o`0000Kooooo0_l0000;ooooo`Ko00003_ooool2
o`0000Oooooo0_l00020ooooo`007?ooool2o`00067ooooo0_l00003ooooo`;o00001_ooool2o`00
00Kooooo0_l00005ooooo`?o00000oooool2o`0000Gooooo1?l00006ooooo`Co000000?oooooo`00
0?l000001Ol0000;ooooo`;o00001?ooool2o`0000[ooooo0_l0000Dooooo`;o00001_ooool2o`00
06gooooo000Looooo`03o`000?oooooooooo04gooooo0_l0000Aooooo`;o00002oooool4o`0000Co
oooo1?l00003ooooo`Go000000?oooooo`000?l000001?ooool5o`0000Oooooo2ol00003ooooo`;o
00003?ooool2o`0000Kooooo0_l00002ooooo`;o00005?ooool2o`0000Kooooo0_l0001]ooooo`00
7?ooool00ol0003oooooooooo`1=ooooo`;o00006?ooool2o`0000Cooooo1?l00006ooooo`;o0000
0oooool8o`0000Cooooo0ol00003ooooo`Co00000_ooool4o`0000;ooooo0_l000001?oooooo0000
o`000?ooool4o`0000Kooooo0_l0000<ooooo`;o00006?ooool2o`0000Oooooo1?l0001Zooooo`00
7?ooool00ol0003oooooooooo`1Wooooo`;o00002_ooool2o`0000cooooo0ol00005ooooo`;o0000
0oooool4o`0000;ooooo0ol00003ooooo`;o00001?ooool6o`0000Cooooo0_l0000_ooooo`Co0000
J_ooool001cooooo00?o0000ooooooooool0Ioooool2o`0000Oooooo0_l000000ooooooo0000o`00
0009ooooo`;o00003Oooool3o`0000Cooooo0ol00003ooooo`;o00002?ooool2o`0000_ooooo0ol0
002Eooooo`007?ooool00ol0003oooooooooo`1Wooooo`;o00001oooool3o`0000Gooooo0_l00004
ooooo`;o00001_ooool2o`0000Gooooo0_l0000;ooooo`;o00002?ooool3o`0000[ooooo0ol00002
ooooo`;o0000TOooool001cooooo00?o0000ooooooooool0COooool2o`0000oooooo0_l0000Aoooo
o`;o00001Oooool2o`0000cooooo0_l000000ooooooo0000o`00000Iooooo`?o000000?oooooo`00
0?l000002?ooool2o`0000;ooooo0_l00009ooooo`;o00001oooool2o`0001_ooooo0_l00002oooo
o`?o0000Foooool001cooooo00?o0000ooooooooool0COooool2o`0000oooooo0_l0000Booooo`;o
00003?ooool2o`0000?ooooo0_l00002ooooo`;o00005Oooool2o`0000Kooooo0ol00004ooooo`Co
00003_ooool2o`0000Oooooo0_l0000Kooooo`;o00000_ooool3o`0005_ooooo000Looooo`03o`00
0?oooooooooo04Oooooo0_l00004ooooo`;o00008oooool2o`0000Gooooo0_l00003ooooo`Co0000
0oooool2o`0000;ooooo0_l0000<ooooo`Co00000oooool5o`0000Kooooo0_l00004ooooo`Co0000
??ooool2o`0005Sooooo000Looooo`03o`000?oooooooooo04Oooooo0_l00004ooooo`;o0000:_oo
ool2o`0000?ooooo0ol00002ooooo`;o000000Coooooo`000?l0003ooooo0_l00008ooooo`Wo0000
00?oooooo`000?l000001ol00002ooooo`Go00000_ooool2o`0000?ooooo0_l0000Cooooo`Co0000
3_ooool2o`000003ooooool0003o000000;o00001_ooool2o`0000Cooooo0ol0001Hooooo`007?oo
ool00ol0003oooooooooo`19ooooo`;o0000<Oooool2o`0000Gooooo0_l000000ooooooo0000o`00
000:ooooo`Oo000000Coooooo`000?l0003ooooo2Ol00002ooooo`Go000000Coooooo`000?l0003o
00000oooool2o`0001?ooooo1?l0000>ooooo`Oo000000?oooooo`000?l000000oooool2o`0000Co
oooo0_l0001Iooooo`007?ooool00ol0003oooooooooo`19ooooo`?o0000<?ooool2o`0000Wooooo
0_l00009ooooo`;o00000oooool;o`0000Kooooo1?l00002ooooo`?o00001_ooool2o`0002?ooooo
0_l00005ooooo`;o00000oooool3o`0005kooooo000Looooo`03o`000?oooooooooo04[ooooo0_l0
000=ooooo`;o0000:_ooool5o`0000gooooo3_l00003ooooo`;o00003?ooool3o`00033ooooo0ol0
001Mooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00002_ooool2o`0002[ooooo0_l00000
0ooooooo0000o`000004ooooo`;o00001OoooolDo`0000Cooooo0_l00007ooooo`?o00000oooool2
o`0000Cooooo0_l00005ooooo`;o00007oooool3o`0005cooooo000Looooo`03o`000?oooooooooo
04gooooo0_l0000fooooo`;o00000_ooool2o`0000?ooooo0_l00005oooooa[o00003Oooool2o`00
00?ooooo0ol00005ooooo`;o00006oooool3o`000004ooooool0003o0000o`0005cooooo000Loooo
o`03o`000?oooooooooo04Wooooo0_l0000jooooo`;o00000_ooool2o`0000_ooooo6?l00009oooo
o`;o00000oooool2o`0000?ooooo0_l00002ooooo`;o00007oooool3o`0000;ooooo1?l00004oooo
o`?o0000Doooool001cooooo0_l0001:ooooo`;o0000;_ooool2o`0000Wooooo0_l000000ooooooo
0000o`000003o`0000Oooooo0_l00002oooooa7o000000?oooooo`000?l000000ol00009ooooo`;o
000000?oooooo`000?l000000_l00007ooooo`;o00009?ooool4o`0000Cooooo0ol0001Cooooo`00
7?ooool00ol0003oooooooooo`1Eooooo`Co00008?ooool2o`0000Wooooo0_l000001?oooooo0000
o`000?ooool2o`0000Oooooo0_l00002oooooa7o000000?oooooo`000?l000000_l00006ooooo`;o
00001Oooool2o`0000Sooooo0_l00005ooooo`;o00007_ooool3o`0000Gooooo0_l0001Dooooo`00
7?ooool00ol0003oooooooooo`18ooooo`;o00002oooool4o`00027ooooo0_l00009ooooo`Go0000
3?oooolBo`000004ooooool0003o0000o`0000Oooooo0_l00002ooooo`;o00002oooool2o`0000Go
oooo0_l0000Looooo`;o00002?ooool3o`0005?ooooo000Looooo`03o`000?oooooooooo04Cooooo
0_l00002ooooo`;o00002oooool2o`0002?ooooo0_l00009ooooo`Go00000_ooool2o`0000Cooooo
0ol000000ooooooo0000o`00000@o`0000;ooooo1?l00009ooooo`;o00001Oooool2o`0000cooooo
0_l0000Kooooo`;o00002Oooool2o`0005?ooooo000Looooo`03o`000?oooooooooo04Cooooo0_l0
0002ooooo`;o00002?ooool2o`000003ooooool0003o000002Oooooo0_l00006ooooo`;o00001?oo
ool2o`0000Cooooo0ol000000ooooooo0000o`00000Fo`0000gooooo1Ol00004ooooo`;o00001_oo
ool2o`0001Cooooo0_l0001Uooooo`007?ooool00ol0003oooooooooo`1Booooo`;o000000?ooooo
o`000?l000009oooool2o`0000Gooooo1Ol00008ooooo`?o000000?oooooo`000?l000004ol00000
0ooooooo0000o`00000=ooooo`Go00001?ooool2o`0000Kooooo0_l0000Dooooo`Co0000Hoooool0
01cooooo00?o0000ooooooooool0AOooool2o`0000cooooo0_l00005ooooo`;o000000?oooooo`00
0?l000008Oooool2o`0000?ooooo0_l000000ooooooo0000o`000008ooooo`;o00000_oooolJo`00
00Kooooo0_l00003ooooo`;o000000?oooooo`000?l000000oooool2o`0000Oooooo0_l0000Foooo
o`;o0000Hoooool001cooooo00?o0000ooooooooool0AOooool2o`0000cooooo0_l00005ooooo`;o
000000?oooooo`000?l000008Oooool2o`0000?ooooo0_l00009ooooo`Co000000?oooooo`000?l0
00006Ol00006ooooo`;o00000oooool2o`0000Kooooo0_l00007ooooo`;o00006Oooool2o`0000ko
oooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00004_ooool2o`000003oooo
ool0003o000001_ooooo0_l000000ooooooo0000o`000008ooooo`;o00002Oooool3o`0000;ooooo
3Ol00003ooooo`go00002?ooool4o`0000Wooooo1?l0000Looooo`?o00000_ooool2o`0000?ooooo
0_l00004ooooo`;o0000D?ooool001cooooo00?o0000ooooooooool0A?ooool2o`0000gooooo0_l0
0003ooooo`Go00005?ooool4o`0000?ooooo0_l000000ooooooo0000o`00000@ooooo`;o00000_oo
oolQo`0000Cooooo0_l00002ooooo`Go00002?ooool4o`0001gooooo0ol000000ooooooo0000o`00
0003ooooo`;o00001Oooool2o`0004oooooo000Looooo`03o`000?oooooooooo05?ooooo0_l00005
ooooo`;o00005?ooool5o`0000oooooo0_l00004ooooo`;o000000?oooooo`000?l000000_oooolO
o`0000Kooooo0_l00002ooooo`Go00000oooool2o`0002Gooooo0_l0000=ooooo`;o0000Coooool0
01cooooo00?o0000ooooooooool0@_ooool2o`0002cooooo0_l0000Aooooo`?o00000oooool5o`00
00?ooooo0_l000000ooooooo0000o`00000Go`0000Oooooo0_l00009ooooo`;o000000?oooooo`00
0?l00000:oooool4o`0005Kooooo000Looooo`03o`000?oooooooooo047ooooo0ol0000mooooo`Co
00001?ooool5o`0000Kooooo6Ol000000ooooooo0000o`000002ooooo`Co00001oooool4o`0002go
oooo1Ol00007ooooo`;o0000COooool001cooooo00?o0000ooooooooool0@Oooool2o`0000kooooo
1?l0000/ooooo`;o00000_ooool2o`0000[ooooo0_l000000ooooooo0000o`00000Go`000005oooo
ool0003o0000o`000?ooool00ol00008ooooo`;o00002_ooool2o`0000;ooooo0_l0000Oooooo`?o
00000_ooool3o`0000Cooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`1?ooooo`Ko0000
;?ooool2o`0000;ooooo0_l00005ooooo`Co000000?oooooo`000?l000006Ol00002ooooo`?o0000
00?oooooo`000?l000002_ooool3o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000;o
oooo0_l0000Oooooo`Co000000Coooooo`000?l0003o0000Doooool001cooooo00?o0000oooooooo
ool0C_ooool3o`0000Cooooo0_l0000Kooooo`;o00002Oooool2o`0000Sooooo0_l00003ooooo`Co
000000Goooooo`000?l0003o0000ooooo`0Ko`0000;ooooo0_l0000:ooooo`_o00001?ooool3o`00
01kooooo1?l000000ooooooo0000o`00001Dooooo`007?ooool2o`0003oooooo0_l0000>ooooo`;o
00001Oooool4o`0001Wooooo0_l00009ooooo`;o00002?ooool2o`0000Cooooo0_l00006oooooa_o
00000_ooool2o`0000[ooooo1ol00002ooooo`?o00001?ooool2o`0001oooooo0_l0001Hooooo`00
7?ooool00ol0003oooooooooo`0nooooo`?o00005Oooool3o`00013ooooo0_l0000Looooo`;o0000
1?ooool2o`0000Kooooo0_l000000ooooooo0000o`00000@o`000003ooooool0003o000000;ooooo
0_l00006ooooo`;o00001_ooool;o`0002Cooooo0ol00003ooooo`;o0000Doooool001cooooo00?o
0000ooooooooool0?oooool2o`0000oooooo0_l00004ooooo`;o00001Oooool2o`0000[ooooo0_l0
000Aooooo`?o00002?ooool6o`0000Wooooo5?l00003ooooo`Co00000oooool5o`0000Wooooo1Ol0
000Wooooo`?o00000oooool2o`0005?ooooo000Looooo`03o`000?oooooooooo053ooooo0_l0000;
ooooo`;o00007Oooool3o`0000[ooooo1?l000000ooooooo0000o`000006oooooaWo00000oooool6
o`0000Gooooo0_l0000<ooooo`;o00000_ooool2o`0001oooooo0_l0000=ooooo`;o0000B?ooool0
01cooooo00?o0000ooooooooool0BOooool2o`0000;ooooo0_l0000:ooooo`;o00005?ooool2o`00
00;ooooo0_l0000Iooooo`;o00001Oooool@o`000003ooooool0003o000000;ooooo3_l00005oooo
o`?o00002oooool2o`0000;ooooo0ol0000Nooooo`;o00000oooool2o`000003ooooool0003o0000
00Gooooo0ol00017ooooo`007?ooool00ol0003oooooooooo`19ooooo`Ko00000_ooool2o`0000Ko
oooo1?l0000<ooooo`;o00001?ooool2o`0000;ooooo0_l00002ooooo`;o00004oooool2o`000003
ooooool0003o000000Cooooo4?l000000ooooooo0000o`000004ooooo`Ko00003?ooool2o`00013o
oooo0_l0000Sooooo`;o000000?oooooo`000?l000001Oooool3o`0000Sooooo0_l0000mooooo`00
7?ooool00ol0003oooooooooo`1;ooooo`;o00001?ooool4o`0000Kooooo0_l00004ooooo`;o0000
00?oooooo`000?l000000oooool4o`0000Sooooo1?l0000Cooooo`;o000000?oooooo`000?l00000
1?ooool?o`0000;ooooo0ol00003ooooo`;o00001oooool2o`0003kooooo0_l000000ooooooo0000
o`000004ooooo`?o00002Oooool2o`0003gooooo000Looooo`03o`000?oooooooooo03kooooo0_l0
000:ooooo`;o00001oooool2o`0000Gooooo0_l000000ooooooo0000o`000009o`0000?ooooo0_l0
00000ooooooo0000o`000005ooooo`Co00003oooool2o`0000;ooooo0_l0000<ooooo`[o00000ooo
ool2o`0000?ooooo0_l00007ooooo`;o00000_ooool2o`0000kooooo0_l0000<ooooo`;o00007ooo
ool2o`0000Cooooo0_l00019ooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00002_ooool2
o`0000Oooooo1?l00003ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o000000?ooooo
o`000?l000000oooool2o`000004ooooool0003o0000ooooo`Co00000_ooool5o`0000cooooo0ol0
00000ooooooo0000o`00000<ooooo`Oo000000Coooooo`000?l0003ooooo0_l0000Aooooo`Co0000
1_ooool2o`0000Gooooo0_l0000<ooooo`;o0000L?ooool001cooooo00?o0000ooooooooool0EOoo
ool2o`0000Kooooo0_l00007ooooo`;o00000oooool2o`0000?ooooo1Ol00003ooooo`Co00001ooo
ool2o`0000Cooooo0_l000000ooooooo0000o`000003o`0000[ooooo2Ol000001?oooooo0000o`00
0?ooool3o`0000Wooooo0_l00002ooooo`Co00001_ooool2o`0001?ooooo0_l0000Dooooo`Co0000
F?ooool001cooooo00?o0000ooooooooool0K_ooool7o`0000?ooooo1?l00007ooooo`;o00001_oo
ool2o`000003ooooool0003o000000;o00002_ooool8o`0000Cooooo0ol00009ooooo`;o00006_oo
ool2o`0000Gooooo0_l0000Dooooo`Co00003_ooool2o`0004Sooooo000Looooo`03o`000?oooooo
oooo053ooooo1?l0000Jooooo`;o00000_ooool3o`0000?ooooo1?l0000?ooooo`;o00000_ooool3
o`0000kooooo0ol0000Mooooo`;o00003_ooool5o`0002Wooooo0ol00018ooooo`007?ooool00ol0
003oooooooooo`1@ooooo`Co000000?oooooo`000?l000006oooool3o`000003ooooool0003o0000
00;o00000oooool2o`0000_ooooo0_l0000Wooooo`Co00002Oooool2o`0000Kooooo0_l00006oooo
o`Go00000oooool2o`000003ooooool0003o000001_ooooo0ol00003ooooo`;o0000BOooool001co
oooo00?o0000ooooooooool0EOooool2o`0001Oooooo1ol000000ooooooo0000o`000002o`0000;o
oooo0ol00003ooooo`;o00001_ooool2o`0000gooooo1?l00003ooooo`;o00002?ooool2o`0000Oo
oooo1?l0000Aooooo`;o00001_ooool2o`0000Kooooo0_l000000ooooooo0000o`00000Aooooo`;o
00002?ooool3o`0000Gooooo1?l00015ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5oooo
o`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0>oooool2o`00
037ooooo1ol00003ooooo`;o00000_ooool2o`0000Cooooo0_l00005ooooo`Co00003?ooool4o`00
00;ooooo1?l00007ooooo`;o00002?ooool2o`0003;ooooo1?l00002ooooo`;o00004?ooool4o`00
00Sooooo0_l0000kooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo03_ooooo0_l0000Nooooo`?o00004Oooool3
o`0000[ooooo0ol000000ooooooo0000o`000007ooooo`Co00003?ooool2o`0000;ooooo1_l00000
0ooooooo0000o`000002o`0000Gooooo0_l00005ooooo`;o000000?oooooo`000?l000003?ooool2
o`0000Cooooo0_l0000Kooooo`Co00008?ooool3o`0003[ooooo00000ooooooo410@ooooo`02oooo
o`03oa0@4?oooooooooo00Wooooo1Ol00006ooooo`03o`000?oooooooooo03Wooooo0_l0000Poooo
o`?o00002Oooool2o`0000Cooooo1?l00002ooooo`;o000000?oooooo`000?l000001ol000000ooo
oooo0000o`000002ooooo`;o00004oooool2o`0000;ooooo0ol00004ooooo`Co00001Oooool2o`00
00;ooooo0_l00004ooooo`;o00003?ooool2o`0000Cooooo0_l0000Sooooo`;o00001oooool2o`00
01;ooooo0_l0000jooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04
odA4A?oMgMgoooooo`0000Oooooo0ol0000iooooo`?o00007oooool2o`0000[ooooo0_l00004oooo
o`Go000000Coooooo`000?l0003ooooo1ol00007ooooo`;o00007_ooool3o`0000Gooooo0_l00003
ooooo`;o00007?ooool2o`0000?ooooo0_l0000Booooo`;o00001_ooool2o`0000Oooooo0ol00003
ooooo`;o000000?oooooo`000?l00000AOooool00003ooooool0003ooooo00;ooooo00?o0000oooo
ooooool02Oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo03Wooooo0ol0000O
ooooo`;o00004?ooool2o`000004ooooool0003o0000ooooo`;o00005?ooool2o`0000_ooooo0_l0
000<ooooo`?o00001Oooool2o`0001kooooo1Ol00002ooooo`?o00001Oooool3o`0000[ooooo0_l0
000?ooooo`?o00000oooool2o`000003ooooool0003o000004Gooooo00000ooooooo410@ooooo`02
ooooo`03oa0@4?oooooooooo00[ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0i
ooooo`;o00007_ooool2o`0000_ooooo0_l00005ooooo`;o00002?ooool2o`000004ooooool0003o
0000ooooo`;o00001?ooool2o`0000Cooooo0ol00008ooooo`Co0000=?ooool3o`0000Cooooo0ol0
0002ooooo`;o000000?oooooo`000?l000000_l0000<ooooo`;o00003Oooool2o`0000?ooooo0_l0
0018ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo
00?o0000ooooooooool0F?ooool3o`0000_ooooo0_l00005ooooo`;o00002?ooool2o`000003oooo
ool0003o000000Co00000oooool2o`0000Gooooo0_l00008ooooo`;o0000>oooool2o`000003oooo
ool0003o000000Co00000oooool2o`000003ooooool0003o000000;o00001oooool2o`0000gooooo
0_l00003ooooo`?o0000Aoooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo
0000ooooo`06ooooo`03o`000?oooooooooo05Oooooo0ol0000Cooooo`;o00003Oooool4o`0000?o
oooo0ol00007ooooo`;o00001?ooool2o`0003cooooo0_l00003ooooo`;o00002?ooool4o`0000Oo
oooo0_l0000Booooo`?o0000Aoooool001cooooo00?o0000ooooooooool0Eoooool2o`0002Oooooo
1ol00006ooooo`;o00001?ooool2o`0002Wooooo0_l00006ooooo`?o00003oooool2o`00017ooooo
0_l00005ooooo`;o00002?ooool2o`000003ooooool0003o000004Sooooo000Looooo`03o`000?oo
oooooooo03Cooooo0_l0000cooooo`?o00002Oooool2o`0000Kooooo2_l0000gooooo`;o00001_oo
ool3o`0000cooooo0_l000000ooooooo0000o`000003ooooo`;o00004oooool2o`0000Sooooo0_l0
0009ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0=?ooool2o`0002cooooo0_l00000
0ooooooo0000o`000002ooooo`?o00001_ooool2o`000004ooooool0003o0000o`0000Cooooo3Ol0
000Jooooo`;o00007Oooool6o`0000Cooooo0_l00002ooooo`;o00000oooool3o`0000Gooooo0_l0
000=ooooo`Go00002_ooool3o`0000Wooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0f
ooooo`;o00006Oooool2o`0000oooooo0_l000000ooooooo0000o`00000;ooooo`;o00000_ooool2
o`0000;ooooo4Ol00008ooooo`Co00003?ooool2o`0000_ooooo0_l0000=ooooo`Wo00000oooool4
o`000003ooooool0003o000000?ooooo0ol00005ooooo`;o00001oooool2o`0000Cooooo1Ol00002
ooooo`;o00001_ooool3o`0004_ooooo000Looooo`03o`000?oooooooooo03Kooooo0_l00002oooo
o`;o00005Oooool2o`0001kooooo0_l00004ooooo`;o000000?oooooo`000?l000004?l00007oooo
o`Ko00003?ooool2o`0000Wooooo0_l00003ooooo`;o00001?ooool2o`000003ooooool0003o0000
00Co00000_ooool2o`000003ooooool0003o000000Co00002?ooool2o`0000Cooooo0ol00004oooo
o`Go00000oooool2o`0000Gooooo0_l0000Jooooo`;o0000>?ooool001cooooo00?o0000oooooooo
ool0=_ooool2o`000004ooooool0003o0000o`0001gooooo0ol00003ooooo`;o00001oooool2o`00
00Oooooo0_l00004oooooa;o000000Coooooo`000?l0003ooooo0_l00006ooooo`Co00003?ooool2
o`0000Oooooo0_l00005ooooo`;o00001?ooool2o`000003ooooool0003o000000;o00001Oooool;
o`0000Gooooo0_l000001?oooooo0000o`000?ooool3o`0000?ooooo0ol000000ooooooo0000o`00
000<ooooo`;o00006?ooool2o`0003Sooooo000Looooo`03o`000?oooooooooo03Oooooo1?l0000N
ooooo`?o00000oooool2o`000003ooooool0003o000000Ko00003OoooolBo`0000Cooooo0_l00003
ooooo`;o00004_ooool5o`0000?ooooo0_l0000:ooooo`Co00000_ooool4o`0000;ooooo3?l00008
ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Kooooo0_l00006ooooo`Co00004Oooool2
o`0003oooooo000Looooo`03o`000?oooooooooo03?ooooo1_l0000Hooooo`;o00001Oooool2o`00
00Sooooo1ol000000ooooooo0000o`000002ooooo`;o00001_ooool3o`000003ooooool0003o0000
00co00002_ooool5o`0000oooooo1Ol00002ooooo`;o00002oooool4o`0000Cooooo0_l00002oooo
o`Co000000?oooooo`000?l000001Ol000001?oooooo0000o`000?l00009ooooo`;o00002_ooool3
o`0000Gooooo0_l0000Cooooo`;o00001?ooool2o`0003Wooooo000Looooo`03o`000?oooooooooo
03?ooooo1_l0000Hooooo`;o00001Oooool2o`0000gooooo0_l000000ooooooo0000o`000002oooo
o`;o00001_ooool3o`000003ooooool0003o000000go00002Oooool5o`0001Kooooo0_l00002oooo
o`;o00001_ooool3o`0000Oooooo0_l000000ooooooo0000o`000007o`000004ooooool0003o0000
ooooo`?o000000?oooooo`000?l000000_ooool2o`0000;ooooo0ol0000:ooooo`Ko00004_ooool2
o`0000Sooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`1Eooooo`;o00001Oooool4o`00
00Oooooo0_l0000<oooooaKo00001oooool6o`0001Wooooo0_l00006ooooo`?o00000oooool2o`00
00;ooooo3?l000000ooooooo0000o`000002o`0000?ooooo0_l00002ooooo`;o00000oooool2o`00
00Wooooo2Ol0000@ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0=_ooool2o`0001Go
oooo0_l00006ooooo`;o00001Oooool4o`0000?ooooo0_l00007ooooo`;o00001?ooool2o`000003
ooooool0003o0000013o00000_ooool2o`0000Wooooo1?l0000Nooooo`Ko00000oooool2o`0000Co
oooo4ol00003ooooo`;o00001_ooool2o`0000;ooooo0_l00002ooooo`Co00000oooool2o`0005Go
oooo000Looooo`;o0000=_ooool3o`0001Gooooo0_l00002ooooo`;o00001_ooool2o`0000Sooooo
1?l00005ooooo`;o00000oooool3o`0000;ooooo0_l00004ooooo`So00003Oooool2o`000003oooo
ool0003o000001Kooooo0_l00008ooooo`Ko00000oooool2o`0000?ooooo5?l00003ooooo`;o0000
1Oooool4o`000003ooooool0003o000000Cooooo0_l00003ooooo`;o000000?oooooo`000?l00000
4?ooool2o`0000Cooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`0dooooo`Co00005?oo
ool3o`0000;ooooo0_l00006ooooo`;o00000_ooool2o`000003ooooool0003o000000;o000000?o
ooooo`000?l000002_ooool3o`0000Oooooo0ol00004ooooo`;o00003Oooool2o`0000Cooooo0_l0
000Cooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`;o00001_ooool2o`000003oooo
ool0003o000001?o00002Oooool4o`0000Oooooo0_l00003ooooo`;o000000?oooooo`000?l00000
2?ooool2o`0000Kooooo0_l00004ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0<?oo
ool2o`0000;ooooo1?l000000ooooooo0000o`00000Aooooo`;o00002_ooool3o`0000;ooooo3?l0
000Booooo`;o00001oooool2o`0000oooooo1_l000000ooooooo0000o`00000Eooooo`Co000000Co
ooooo`000?l0003o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000Co`0000?ooooo
0_l00005ooooo`;o00001_ooool2o`000003ooooool0003o000000oooooo0_l00018ooooo`007?oo
ool00ol0003oooooooooo`0`ooooo`;o00001oooool2o`000003ooooool0003o000000kooooo0_l0
000:oooooa?o00004?ooool2o`0000Oooooo0_l0000?ooooo`;o00000_ooool6o`00017ooooo0_l0
00000ooooooo0000o`000002o`000004ooooool0003o0000ooooob?o00001Oooool2o`0000Kooooo
0_l000000ooooooo0000o`00000:ooooo`;o00004Oooool2o`0003[ooooo000Looooo`03o`000?oo
oooooooo03cooooo0_l0000IoooooaCo00003_ooool9o`0001;ooooo0_l00002ooooo`Co000000?o
ooooo`000?l000004Oooool4o`000003ooooool0003o000000?o000000?oooooo`000?l000006_l0
00000ooooooo0000o`000002o`0000Oooooo0ol00005ooooo`;o00001?ooool2o`0000Oooooo0_l0
000;ooooo`;o00001?ooool2o`0003[ooooo000Looooo`03o`000?oooooooooo03cooooo0_l0000F
oooooaKo00002_ooool2o`0000?ooooo2Ol000000ooooooo0000o`00000<ooooo`;o000000?ooooo
o`000?l000001_l0000Fooooo`;o00000_ooool2o`0000?ooooo7Ol000000ooooooo0000o`000002
o`000003ooooool0003o000000?ooooo1?l00004ooooo`Co00000_ooool2o`0001Cooooo0ol00002
ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0D_oooolHo`0000Sooooo1?l0000:oooo
o`;o000000?oooooo`000?l000003?ooool2o`0000;ooooo1Ol0000>ooooo`;o00001?ooool4o`00
00Wooooo9Ol00004ooooo`?o00001Oooool4o`000003ooooool0003o000000;ooooo0_l00004oooo
o`;o00002oooool2o`0000;ooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`11ooooo`Co
00000_ooool2o`0000Oooooo1?l000000ooooooo0000o`00000Co`0000;ooooo0_l00004ooooo`Co
00002Oooool3o`0000gooooo0ol00002ooooo`Wo00002oooool2o`0000Cooooo1Ol00005ooooo`;o
00000_ooool2o`000003ooooool0003o000001So000000?oooooo`000?l000000_l0000>ooooo`Co
00001?ooool3o`0000?ooooo0ol0001<ooooo`007?ooool00ol0003oooooooooo`11ooooo`So0000
1oooool3o`000003ooooool0003o000001So00002oooool2o`0000;ooooo1Ol0000=ooooo`Oo0000
1?ooool5o`0001;ooooo0_l00005ooooo`;o00000ooooolOo`00017ooooo0_l000000ooooooo0000
o`000002ooooo`;o00001?ooool2o`0004gooooo000Looooo`03o`000?oooooooooo04Cooooo1?l0
00000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l000006?l0000;ooooo`;o00000_oo
ool2o`0001?ooooo1_l00002ooooo`Go00006?ooool2o`0000?ooooo8Ol00004ooooo`;o00002Ooo
ool2o`0000;ooooo0_l00002ooooo`;o00005?ooool2o`0003gooooo000Looooo`03o`000?oooooo
oooo03Wooooo0_l00003ooooo`;o00000oooool3o`0000?ooooo0_l00006oooooaSo00000oooool2
o`0002?ooooo0ol00002ooooo`Oo00005Oooool9o`000003ooooool0003o000001co000000?ooooo
o`000?l000001?ooool2o`0000Wooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo0_l0000<
ooooo`?o000000?oooooo`000?l00000?Oooool001cooooo00?o0000ooooooooool0>Oooool2o`00
00?ooooo0_l00002ooooo`?o00002_oooolLo`000003ooooool0003o000000gooooo0_l0000Boooo
o`Go00000oooool6o`0001Gooooo2Ol000000ooooooo0000o`00000Oo`0000Cooooo0ol00002oooo
o`;o00001?ooool2o`0000;ooooo0_l00006ooooo`;o00003?ooool3o`00043ooooo000Looooo`03
o`000?oooooooooo04;ooooo0_l00005ooooo`;o00001?oooolLo`0000Gooooo0_l00007ooooo`Co
00002oooool4o`0000;ooooo0ol00005ooooo`;o00000oooool3o`0001;ooooo0_l00005ooooo`Co
00000ooooolNo`0000Gooooo0ol00002ooooo`;o00000oooool3o`0001Sooooo0_l00011ooooo`00
7?ooool00ol0003oooooooooo`0gooooo`;o00001_ooool2o`0000Cooooo0ol000001Ooooooo0000
o`000?l0003ooooo00;o00000_ooool:o`000003ooooool0003o000000[o00002?ooool2o`0000Oo
oooo0_l0000=ooooo`Co00000_ooool2o`0000Kooooo0_l00003ooooo`?o00001Oooool2o`0000[o
oooo0ol00002ooooo`Oo000000?oooooo`000?l000007?l00007ooooo`?o00001Oooool7o`00017o
oooo0_l00003ooooo`;o00000_ooool2o`0003gooooo000Looooo`03o`000?oooooooooo03Oooooo
0_l00006ooooo`;o00001?ooool3o`000005ooooool0003o0000o`000?ooool00_l00002oooooaOo
00004_ooool2o`0000oooooo0_l00005ooooo`;o000000?oooooo`000?l000000_ooool4o`0000Go
oooo0ol00005ooooo`;o00000oooool2o`0000?ooooo1ol000000ooooooo0000o`00000Oo`0000Go
oooo0ol00004ooooo`Co000000?oooooo`000?l000004Oooool2o`0000Oooooo0_l0000mooooo`00
7?ooool00ol0003oooooooooo`19ooooo`Co00001?oooolHo`00017ooooo0_l0000?ooooo`;o0000
1Oooool2o`000004ooooool0003o0000ooooo`Go00001Oooool2o`0000?ooooo0_l000000ooooooo
0000o`000006ooooo`Ko000000?oooooo`000?l00000:_l00007ooooo`Co00005Oooool3o`00047o
oooo000Looooo`;o0000?_ooool2o`0000cooooo0_l00002oooooa_o00001?ooool3o`0000Oooooo
0_l00003ooooo`;o00003Oooool2o`0000Oooooo0_l000000ooooooo0000o`000003o`0000[ooooo
0_l00003ooooo`;o00001?ooool6o`0000;ooooo0ol000000ooooooo0000o`00000So`0000;ooooo
0_l00005ooooo`Ko00003?ooool3o`0000Cooooo0ol00011ooooo`007?ooool00ol0003ooooooooo
o`0kooooo`Co00000oooool2o`0000[ooooo1?l000000ooooooo0000o`00000Fo`0000?ooooo0ol0
0007ooooo`;o00000oooool2o`0000gooooo0_l00002ooooo`;o00001_ooool5o`0000[ooooo0_l0
00000ooooooo0000o`000002o`0000;ooooo1ol000000ooooooo0000o`000002oooooaSo000000?o
ooooo`000?l000001ol000000ooooooo0000o`000002o`000004ooooool0003o0000o`0000;ooooo
0_l00005ooooo`;o00001_ooool2o`0000Cooooo0ol00002ooooo`Co0000@_ooool001cooooo00?o
0000ooooooooool0>oooool2o`0000Gooooo0_l0000:ooooo`;o00001?oooolGo`0001Cooooo0_l0
000:ooooo`;o00000oooool4o`0000Cooooo1Ol0000:ooooo`Go000000Coooooo`000?l0003ooooo
0_l00003ooooo`Ko000000?oooooo`000?l000008?l000000ooooooo0000o`000002o`000003oooo
ool0003o000000;ooooo0ol00005ooooo`;o00001_ooool2o`0000Kooooo1Ol00014ooooo`007?oo
ool00ol0003oooooooooo`1>oooooaWo00006?ooool4o`0000Cooooo0ol000000ooooooo0000o`00
0005ooooo`;o00000_ooool2o`000003ooooool0003o000000;o00002Oooool2o`000003ooooool0
003o000000;ooooo0_l00007ooooo`Go000000?oooooo`000?l000003_l000000ooooooo0000o`00
000>o`0000;ooooo1_l00002ooooo`?o000000?oooooo`000?l000001oooool2o`0000[ooooo1Ol0
000:ooooo`;o00000_ooool2o`0003Cooooo000Looooo`03o`000?oooooooooo04kooooo6Ol00007
ooooo`;o00002_ooool2o`0000Cooooo0ol00004ooooo`Co00000_ooool2o`0000;ooooo0ol00002
ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00001Oooool2o`0001Gooooo7Ol00000
0ooooooo0000o`000003ooooo`Go00000_ooool2o`0000;ooooo0_l00006ooooo`?o00002?ooool2
o`0000Kooooo0_l00007ooooo`;o00000_ooool2o`0003Cooooo000Looooo`03o`000?oooooooooo
03kooooo0_l0000>ooooo`?o00000oooool8o`000003ooooool0003o000000Go000000Coooooo`00
0?l0003o00001_ooool2o`0000Gooooo0_l00003ooooo`;o00002?ooool2o`0000?ooooo1_l00002
ooooo`;o00001_ooool3o`0000?ooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo1?l0
0004ooooo`;o00000_ooool4o`000003ooooool0003o000001_o000000?oooooo`000?l000001?l0
0004ooooo`;o00000_ooool2o`0000[ooooo0_l00009ooooo`;o00001_ooool2o`00047ooooo000L
ooooo`03o`000?oooooooooo03kooooo1Ol00003ooooo`;o00001Oooool4o`0000;ooooo2?l00002
ooooo`Co000000?oooooo`000?l000001_l0000;ooooo`;o00002Oooool3o`000003ooooool0003o
000000;o00000_ooool4o`0000;ooooo1?l00004ooooo`?o00002Oooool5o`000003ooooool0003o
000000;o00001?ooool2o`0000;ooooo6ol000000ooooooo0000o`00000=o`0001Kooooo0_l00002
ooooo`?o00001_ooool2o`0004?ooooo000Looooo`03o`000?oooooooooo03?ooooo0_l0000;oooo
o`?o00000oooool2o`000003ooooool0003o000000;ooooo1Ol000000ooooooo0000o`000004oooo
o`Co00000_ooool7o`0000;ooooo0_l0000Fooooo`?o000000?oooooo`000?l000000_l00004oooo
o`;o00000_ooool4o`0000Cooooo0ol00003ooooo`;o00001?ooool4o`0000kooooo1ol000000ooo
oooo0000o`00000:o`0000;ooooo4?l000000ooooooo0000o`000002o`00017ooooo0_l00003oooo
o`Oo00001_ooool2o`0000Oooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`0cooooo`;o
00005?ooool2o`0000;ooooo1_l00006ooooo`Co00000oooool6o`0001Wooooo0_l0000;ooooo`?o
00000_ooool2o`0000?ooooo1_l00002ooooo`;o00000oooool2o`0000[ooooo0_l00005ooooo`Co
00000ooooolRo`000003ooooool0003o0000013ooooo0_l00005ooooo`;o000000?oooooo`000?l0
00001?ooool4o`0000Oooooo0_l00002ooooo`;o0000=_ooool001cooooo00?o0000ooooooooool0
?_ooool2o`0000Wooooo0ol00002ooooo`Go00001?ooool2o`000003ooooool0003o000000;ooooo
0_l00005ooooo`;o00006?ooool2o`0000Cooooo1?l00004ooooo`?o000000?oooooo`000?l00000
0_ooool7o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000001oooool2o`0000Kooooo
0ol000000ooooooo0000o`000006o`0000;ooooo5Ol000000ooooooo0000o`000003ooooo`;o0000
1oooool2o`000003ooooool0003o000000kooooo0_l00004ooooo`Co000000?oooooo`000?l00000
2?ooool2o`0003Kooooo000Looooo`03o`000?oooooooooo03kooooo0_l00006ooooo`;o000000Co
ooooo`000?l0003o00000_ooool5o`0000?ooooo1Ol00003ooooo`;o00001Oooool3o`0000gooooo
0_l00006ooooo`;o00001_ooool4o`000004ooooool0003o0000ooooo`?o00001Oooool7o`0000[o
oooo0_l00002ooooo`;o00001?ooool2o`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l0
00001Ol000001?oooooo0000o`000?l00002ooooo`ko00000_ooool2o`0000;ooooo0_l00003oooo
o`;o00000oooool2o`000003ooooool0003o000000Gooooo0_l00003ooooo`;o00000_ooool4o`00
00;ooooo0ol00002ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0<_ooool2o`0000So
oooo1?l00006ooooo`;o000000?oooooo`000?l000001Oooool3o`0000?ooooo0_l000000ooooooo
0000o`00000:ooooo`?o00002_ooool2o`000003ooooool0003o000000Kooooo1?l00003ooooo`So
00002oooool8o`0000?ooooo1?l00004ooooo`;o00001?ooool2o`0000Cooooo1?l00004ooooo`Oo
000000?oooooo`000?l000004Ol00002ooooo`;o00000_ooool2o`0000?ooooo1ol000000ooooooo
0000o`000002o`0000?ooooo0_l00003ooooo`;o00000_ooool4o`0000;ooooo0ol0000<ooooo`;o
0000=_ooool001cooooo00?o0000ooooooooool0<_ooool2o`0000Sooooo1?l00007ooooo`Co0000
0oooool2o`0000oooooo0_l00004ooooo`;o000000?oooooo`000?l000002?ooool3o`0000;ooooo
0_l00006ooooo`;o00000oooool3o`000003ooooool0003o000000gooooo0ol00002ooooo`?o0000
00?oooooo`000?l000001?l00002ooooo`;o00003?ooool7o`0000;ooooo0ol000000ooooooo0000
o`00000Bo`0000Cooooo0ol00008ooooo`Ko00000_ooool2o`0000Kooooo1ol00005ooooo`;o0000
3Oooool2o`0003Kooooo000Looooo`03o`000?oooooooooo03Sooooo0_l0000=ooooo`Ko000000?o
ooooo`000?l000002_ooool3o`0000;ooooo0_l00003ooooo`;o00000_ooool4o`0000Oooooo1_l0
00000ooooooo0000o`000002o`0000[ooooo1?l00009ooooo`Go00001_ooool4o`000003ooooool0
003o000000?o00003?ooool7o`000005ooooool0003o0000o`000?ooool04ol00003ooooo`Oo0000
2_ooool3o`0000[ooooo0_l000000ooooooo0000o`000002o`0000Gooooo0_l00015ooooo`007?oo
ool00ol0003oooooooooo`0hooooo`;o00000_ooool2o`0000Wooooo1_l0000=ooooo`?o00001ooo
ool4o`0000;ooooo0_l00004ooooo`;o00000oooool4o`000003ooooool0003o000000;o00001ooo
ool2o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`Go00002oooool4o`0000Oooooo1?l0
0002ooooo`Co000000?oooooo`000?l000000ol000000ooooooo0000o`00000Ao`0000;ooooo1_l0
00000ooooooo0000o`00000Jooooo`Ko00000oooool2o`0004Gooooo000Looooo`03o`000?oooooo
oooo03Sooooo0_l00002ooooo`?o00009oooool2o`0000Sooooo0_l00005ooooo`;o00001_ooool2
o`0000Cooooo0_l00006ooooo`;o00002Oooool2o`0000Kooooo0_l00003ooooo`Co00001oooool4
o`0000Cooooo0_l000000ooooooo0000o`000002o`0000;ooooo4ol000000ooooooo0000o`000004
o`0000Oooooo0_l00004ooooo`;o00003oooool2o`0000;ooooo0_l0001:ooooo`007?ooool2o`00
03kooooo0_l0000Booooo`;o00001?ooool2o`0000_ooooo0_l0000:ooooo`;o00003?ooool3o`00
00Cooooo0ol0000Booooo`Go000000?oooooo`000?l000001?ooool2o`00013ooooo1ol00002oooo
o`;o00000oooool2o`0000;ooooo4?l00008ooooo`;o00000_ooool4o`0000oooooo0_l0001>oooo
o`007?ooool00ol0003oooooooooo`1Aooooo`;o00001?ooool2o`0000_ooooo0_l0000:ooooo`;o
00002Oooool2o`000003ooooool0003o000000Gooooo0ol0000Booooo`Go00001oooool2o`0000?o
oooo0_l0000<ooooo`?o000000?oooooo`000?l000000_l000000ooooooo0000o`000006ooooo`;o
000000?oooooo`000?l000001_l0000@ooooo`?o00004Oooool2o`0004kooooo000Looooo`03o`00
0?oooooooooo03Oooooo1?l00002ooooo`;o00004Oooool2o`0000Kooooo1Ol00007ooooo`?o0000
0_ooool2o`0000Gooooo0_l00009ooooo`;o000000?oooooo`000?l000000ol000000ooooooo0000
o`00000Dooooo`;o00002?ooool4o`0000?ooooo0_l00002ooooo`;o00002Oooool<o`0000;ooooo
2_l0000Cooooo`?o0000HOooool001cooooo00?o0000ooooooooool0=_ooool5o`0000;ooooo0_l0
000Aooooo`;o00001_ooool5o`0000?ooooo0ol000001?oooooo0000o`000?l00002ooooo`;o0000
1_ooool2o`0000_ooooo1Ol000000ooooooo0000o`000005ooooo`;o00005oooool3o`0000;ooooo
0_l00004ooooo`;o000000?oooooo`000?l000002?ooool7o`000003ooooool0003o000000Oo0000
0_ooool2o`0000Oooooo0_l0000<ooooo`;o00003oooool2o`000003ooooool0003o000004gooooo
000Looooo`03o`000?oooooooooo03Kooooo0_l0000;ooooo`;o00000_ooool2o`0001Oooooo0ol0
000>ooooo`;o00001_ooool4o`0000Oooooo0_l00005ooooo`;o00005oooool4o`000004ooooool0
003o0000o`0000Kooooo1?l000000ooooooo0000o`000003ooooo`?o00000_ooool3o`000003oooo
ool0003o000000;o00003oooool2o`0001Wooooo1_l000000ooooooo0000o`00001=ooooo`007?oo
ool00ol0003oooooooooo`0looooo`;o00001Oooool2o`0000;ooooo0_l00006ooooo`?o000000?o
ooooo`000?l000000_ooool2o`0000Oooooo0_l00003ooooo`;o00004_ooool4o`0000Sooooo0ol0
000Mooooo`?o00000_ooool4o`0000Cooooo2Ol000000ooooooo0000o`000004ooooo`;o0000;ooo
ool4o`0005;ooooo000Looooo`03o`000?oooooooooo03_ooooo0ol0000Aooooo`?o000000?ooooo
o`000?l000001?l00004ooooo`;o000000?oooooo`000?l000001Ol00004ooooo`;o00001Oooool6
o`0000[ooooo1_l0000Iooooo`;o00000_ooool2o`0000Cooooo0ol00007ooooo`Ko000000Cooooo
o`000?l0003o00001_ooool3o`0001Gooooo0_l0000Fooooo`;o0000D_ooool001cooooo00?o0000
ooooooooool0>oooool2o`0000;ooooo0_l00007ooooo`;o00002oooool4o`0000Cooooo0_l00002
ooooo`Ko00001?ooool2o`0000Gooooo1_l00003ooooo`;o00001Oooool3o`000003ooooool0003o
000001Wooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo0ol00007ooooo`;o00000oooool4
o`0000Gooooo0ol0000Eooooo`Go00000oooool2o`0000kooooo0_l0001Booooo`007?ooool00ol0
003oooooooooo`0oooooo`;o00001oooool2o`0000cooooo0ol00008ooooo`Co00000oooool2o`00
00?ooooo0ol000000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l000002oooool2o`00
00?ooooo0_l0000Jooooo`;o00000_ooool5o`0000?ooooo0_l00007ooooo`Co00005Oooool4o`00
00Cooooo0ol00003ooooo`;o00001?ooool4o`0000Gooooo0_l0001Cooooo`007?ooool00ol0003o
ooooooooo`12ooooo`;o00004_ooool2o`0000_ooooo0_l00003ooooo`;o00000oooool3o`000003
ooooool0003o000000Gooooo0_l0000>ooooo`?o00000_ooool2o`000003ooooool0003o000000Go
oooo0_l0000Fooooo`?o00000oooool2o`000003ooooool0003o000000Cooooo1?l00005ooooo`;o
00003_ooool4o`0000Cooooo0_l00003ooooo`;o00001Oooool4o`0000?ooooo1?l0001Cooooo`00
7?ooool00ol0003oooooooooo`12ooooo`;o00009_ooool2o`000004ooooool0003o0000o`0001Wo
oooo0_l00002ooooo`;o000000?oooooo`000?l000001Oooool2o`0000;ooooo0_l00006ooooo`;o
00002oooool2o`0000Kooooo0_l00002ooooo`Co00001oooool2o`0000Sooooo0_l00002ooooo`;o
000000?oooooo`000?l000001Oooool2o`0000?ooooo0_l00005ooooo`;o00000oooool4o`0005Go
oooo000Looooo`03o`000?oooooooooo03gooooo0_l0000Rooooo`;o00001oooool2o`000003oooo
ool0003o000000Sooooo0_l0000@ooooo`;o00000_ooool5o`0000Wooooo0_l00006ooooo`;o0000
2oooool2o`0000Kooooo0_l00002ooooo`;o00004oooool2o`0000;ooooo0_l0000Aooooo`;o0000
00Coooooo`000?l0003ooooo1_l0001Eooooo`007?ooool00ol0003oooooooooo`0mooooo`;o0000
2Oooool2o`0001Oooooo0_l0000@ooooo`;o00000_ooool2o`00013ooooo0_l00002ooooo`Go0000
4Oooool2o`0000Wooooo0_l00002ooooo`;o00003oooool3o`0000Wooooo0_l000001?oooooo0000
o`000?l00002ooooo`;o00003oooool2o`0000Cooooo0ol0001Hooooo`007?ooool00ol0003ooooo
ooooo`0mooooo`Co00001oooool2o`0002Wooooo1?l0000Dooooo`Go00002oooool2o`0000Kooooo
0_l00009ooooo`;o00000_ooool2o`0000gooooo1Ol00009ooooo`;o000000?oooooo`000?l00000
1Ol00002ooooo`;o000000?oooooo`000?l00000JOooool00006ooooooo^k^ko<S8bo`000?lb<S;o
k^k^1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo
03gooooo1?l000000ooooooo0000o`000004ooooo`;o00005Oooool2o`0001Cooooo0_l00004oooo
o`;o00001oooool4o`0000?ooooo1_l00005ooooo`;o00000oooool2o`0001Oooooo0_l0000;oooo
o`;o00000_ooool2o`0000;ooooo1?l00003ooooo`So00000oooool2o`000003ooooool0003o0000
00oooooo0_l0000?ooooo`;o0000Aoooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo04;ooooo0_l0
0004ooooo`;o00005Oooool2o`0001[ooooo0ol00006ooooo`Co000000Goooooo`000?l0003o0000
ooooo`04o`0000Gooooo0_l00003ooooo`?o00004Oooool2o`0000?ooooo1?l00006ooooo`;o0000
0ooooolAo`0000Cooooo0_l0000@ooooo`;o00000oooool2o`0000gooooo1?l00017ooooo`0000?o
oooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`12ooooo`?o00002_ooool3o`0002[ooooo0_l0000;ooooo`?o0000
0oooool2o`0000_ooooo0_l0000>ooooo`;o000000Coooooo`000?l0003o00001?ooool3o`0000Co
oooo1?l00002ooooo`;o00000_ooool2o`0000Cooooo1?l00007ooooo`;o00002?ooool4o`0000Co
oooo1Ol0000?ooooo`;o000000?oooooo`000?l000000_l00014ooooo`0000?oooooo`000?ooool0
0_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0003co
oooo1?l00002ooooo`Go00002?ooool3o`0002oooooo0_l00007ooooo`Co000000?oooooo`000?l0
00006oooool2o`0000;ooooo0_l00005ooooo`;o00001?ooool4o`0000oooooo0_l0000;ooooo`?o
00000_ooool4o`0000Cooooo1Ol0000Booooo`Co0000A?ooool00003ooooool0003ooooo00;ooooo
00?o0000ooooooooool02Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000oooooooo
ool0??ooool5o`0000?ooooo0ol0000=ooooo`;o0000:oooool2o`0000?ooooo0_l00002ooooo`Co
00004?ooool2o`0001Kooooo0_l000000ooooooo0000o`00000Eooooo`;o00002oooool3o`0000;o
oooo0_l00004ooooo`;o000000Coooooo`000?l0003o00002oooool2o`0000Kooooo0_l000000ooo
oooo0000o`000013ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`03
oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0?_ooool3o`0000Gooooo0_l0000<ooooo`;o
00007Oooool2o`00017ooooo0_l00002ooooo`?o00000oooool2o`0000cooooo0_l0000Fooooo`;o
000000?oooooo`000?l000006oooool4o`0000;ooooo0_l00002ooooo`Co00000_ooool8o`0000Wo
oooo1?l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l00000@oooool00006oooo
oomgMgOoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo
03kooooo0_l00003ooooo`;o000000?oooooo`000?l000001?ooool2o`0002?ooooo1?l00009oooo
o`?o00001oooool5o`0000?ooooo0_l0000Mooooo`;o00000_ooool2o`0000Cooooo0ol0000Joooo
o`Co00000_ooool2o`0000;ooooo1Ol000000ooooooo0000o`000002ooooo`;o00002oooool2o`00
00?ooooo0_l00009ooooo`;o0000@?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool0
1?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo03Oooooo0_l00005ooooo`;o00000ooo
ool2o`0000Oooooo0ol0000Rooooo`Co00002Oooool3o`0000Oooooo1Ol000000ooooooo0000o`00
000Oooooo`;o00000_ooool4o`0000;ooooo0ol0000Eooooo`;o00002Oooool2o`0000;ooooo1Ol0
00000ooooooo0000o`00000Oooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0=oooool2
o`0000Sooooo0ol000000ooooooo0000o`000002o`0000Cooooo0_l0000kooooo`?o000000?ooooo
o`000?l000003_ooool2o`00013ooooo0_l00002ooooo`?o00006_ooool2o`0000Kooooo0_l00000
0ooooooo0000o`000002ooooo`;o000000Coooooo`000?l0003ooooo1?l00005ooooo`;o00000ooo
ool2o`0000Cooooo0ol00006ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0=oooool2
o`0000Sooooo2?l000000ooooooo0000o`00000Pooooo`?o00006oooool3o`0000;ooooo0_l0000=
ooooo`;o00000oooool2o`0000_ooooo0_l00002ooooo`;o00001oooool3o`0001Wooooo0_l00000
0ooooooo0000o`00000:ooooo`;o00001Oooool2o`0000?ooooo0_l00004ooooo`?o00000_ooool2
o`0000;ooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0kooooo`;o00001_ooool9o`00
023ooooo0ol000000ooooooo0000o`000003o`0001Kooooo0_l00002ooooo`;o00004_ooool2o`00
00?ooooo0_l0000:ooooo`;o00001oooool6o`0000cooooo0_l00007ooooo`Ko00008Oooool2o`00
04Sooooo000Looooo`03o`000?oooooooooo03_ooooo0_l00006ooooo`;o00000oooool2o`0002?o
oooo0_l000000ooooooo0000o`000003o`0000;ooooo0ol00003ooooo`;o00003?ooool4o`0001Wo
oooo0_l0000Eooooo`Go00002Oooool4o`0000Cooooo0_l000000ooooooo0000o`000003o`0001Co
oooo0_l00006ooooo`?o00002Oooool2o`0004;ooooo000Looooo`03o`000?oooooooooo043ooooo
0_l000000ooooooo0000o`000002ooooo`;o00009?ooool2o`0000Sooooo0ol00003ooooo`;o0000
0_ooool2o`0000Sooooo1?l0000Jooooo`;o00004oooool2o`000003ooooool0003o000000Co0000
1_ooool2o`0000Kooooo0_l00004ooooo`;o00002oooool4o`0000Gooooo0_l00004ooooo`Go0000
2Oooool2o`0004;ooooo000Looooo`03o`000?oooooooooo043ooooo0_l00005ooooo`Go00009Ooo
ool4o`000004ooooool0003o0000o`0000Cooooo0ol000000ooooooo0000o`00000Fooooo`;o0000
3_ooool2o`0000kooooo0_l00003ooooo`;o00000oooool5o`0000?ooooo0ol0000Jooooo`Co0000
1Oooool2o`0000?ooooo0ol0000:ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0@Ooo
ool2o`0000Gooooo1?l0000Uooooo`Co000000?oooooo`000?l000001Oooool4o`000003ooooool0
003o000001Gooooo0_l00002ooooo`;o00001Oooool2o`0001?ooooo0_l00003ooooo`;o00001_oo
ool:o`0000Kooooo0ol0000>ooooo`;o00003?ooool3o`0000Kooooo0_l00003ooooo`;o0000A?oo
ool001cooooo00?o0000ooooooooool0@?ooool3o`0000Gooooo0_l0000Rooooo`;o00001?ooool5
o`000003ooooool0003o000000Oo000000?oooooo`000?l000001oooool4o`0000[ooooo0_l00002
ooooo`;o00001?ooool3o`0000[ooooo0_l00003ooooo`Co00003_ooool6o`000003ooooool0003o
000000Kooooo0ol00007ooooo`;o000000?oooooo`000?l000000_ooool3o`0000_ooooo0_l00005
ooooo`Go0000B?ooool001cooooo00?o0000ooooooooool0>?ooool2o`0000Gooooo0ol0000Woooo
o`Go00000ooooolAo`000003ooooool0003o000000Kooooo1?l0000:ooooo`;o000000?oooooo`00
0?l000001Oooool2o`0000_ooooo0_l000000ooooooo0000o`000004o`00013ooooo0_l0000Eoooo
o`;o000000?oooooo`000?l000000oooool2o`0001;ooooo0_l000000ooooooo0000o`000018oooo
o`007?ooool00ol0003oooooooooo`0hooooo`;o00001Oooool3o`0002Oooooo1?l00002oooooa?o
000000?oooooo`000?l000002oooool2o`0000Oooooo0_l000000ooooooo0000o`00000:ooooo`Co
00001Oooool4o`000003ooooool0003o000000gooooo0_l0000Mooooo`?o000000?oooooo`000?l0
00005?ooool2o`0004Wooooo000Looooo`03o`000?oooooooooo03Gooooo0_l00009ooooo`;o0000
;Oooool6o`000003ooooool0003o000000_o00003Oooool2o`0001Kooooo1?l00005ooooo`;o0000
1oooool4o`0000Oooooo0_l0000Gooooo`;o00001?ooool3o`000003ooooool0003o000000kooooo
0_l00003ooooo`?o0000BOooool001cooooo0_l0000fooooo`?o00005_ooool2o`0001cooooo0_l0
00000ooooooo0000o`000009o`000003ooooool0003o000000Oo00002Oooool2o`0001kooooo0_l0
0002ooooo`;o00001oooool4o`0000_ooooo0_l0000:ooooo`;o00001oooool2o`0001Sooooo0_l0
0003ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0=_ooool2o`0001Kooooo0_l0000L
ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`00000Ao`0000Cooooo1?l0000@
ooooo`;o000000?oooooo`000?l000002Oooool2o`0001Oooooo0_l000000ooooooo0000o`000003
ooooo`Co00000oooool2o`0001oooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`1/oooo
o`;o000000?oooooo`000?l000005_l00004ooooo`;o00004Oooool3o`000003ooooool0003o0000
00Wooooo0_l0000=ooooo`;o00002?ooool5o`0000;ooooo1Ol0000;ooooo`?o000000?oooooo`00
0?l000004oooool2o`00057ooooo000Looooo`03o`000?oooooooooo04?ooooo0_l0000Vooooo`;o
000000?oooooo`000?l000005ol0000=ooooo`;o00002?ooool2o`0000;ooooo0_l00002ooooo`;o
00000_ooool2o`00013ooooo0_l00008ooooo`Co00000oooool2o`0000kooooo0ol000000ooooooo
0000o`00000<ooooo`;o00001_ooool2o`0000Cooooo0_l0001:ooooo`007?ooool00ol0003ooooo
ooooo`13ooooo`;o00009_oooolLo`0000Oooooo0_l00004ooooo`;o00002?ooool3o`000003oooo
ool0003o000000;ooooo0_l00002ooooo`;o00001_ooool2o`0001Cooooo1?l0000;ooooo`;o0000
1Oooool4o`0000gooooo0_l00006ooooo`;o00001?ooool2o`0004[ooooo000Looooo`03o`000?oo
oooooooo047ooooo0_l0000Xoooooago00001_ooool2o`0000Oooooo0_l00002ooooo`;o00000_oo
ool2o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o00001?ooool2o`0001Cooooo1_l0
00000ooooooo0000o`000006ooooo`;o00001Oooool4o`0001?ooooo0_l00005ooooo`;o0000Booo
ool001cooooo00?o0000ooooooooool0@Oooool2o`00027ooooo0_l00005ooooo`[o000000?ooooo
o`000?l000004?l0000?ooooo`;o000000Coooooo`000?l0003o00001oooool?o`0001Gooooo1_l0
00000ooooooo0000o`00000=ooooo`Co00002oooool2o`0000Gooooo0ol00005ooooo`;o0000Booo
ool001cooooo00?o0000ooooooooool0=oooool2o`0002_ooooo0_l00006oooooa[o00004Oooool2
o`000003ooooool0003o000000Sooooo0_l000001?oooooo0000o`000?ooool3o`000003ooooool0
003o000000Go00001_ooool2o`0000gooooo0_l0000<ooooo`;o00001Oooool3o`0000_ooooo0_l0
0005ooooo`;o00001_ooool2o`0004_ooooo000Looooo`03o`000?oooooooooo03Oooooo0_l0000]
ooooo`;o00000ooooolNo`0000Gooooo0_l0000Jooooo`Go00000oooool4o`0000Gooooo0_l00009
ooooo`;o00000oooool2o`0000_ooooo0_l0000Booooo`;o00003_ooool2o`0004_ooooo000Loooo
o`03o`000?oooooooooo06Kooooo0_l00003oooooako00001Oooool2o`000003ooooool0003o0000
00?o00001_ooool2o`0000Gooooo0_l00005ooooo`Go000000?oooooo`000?l000002?l00009oooo
o`;o000000Coooooo`000?l0003o00000_ooool2o`0000Cooooo0_l00005ooooo`;o00004_ooool2
o`0000;ooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`1Wooooo`Co000000?oooooo`00
0?l000006_l00009ooooo`Go00001_ooool2o`0000Gooooo0_l00006ooooo`?o00000_ooool;o`00
00Sooooo0_l00002ooooo`;o00002?ooool2o`0000Gooooo0_l0000Fooooo`;o00002_ooool2o`00
04_ooooo000Looooo`03o`000?oooooooooo04Gooooo1?l0000Looooo`Ko000000?oooooo`000?l0
00006Ol00002ooooo`;o00006oooool2o`0000?ooooo4Ol00007ooooo`;o0000:oooool2o`0000[o
oooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`15ooooo`Co00007?ooool2o`0000;ooooo
0_l00003oooooaWo00000_ooool2o`0000Oooooo0_l00002ooooo`;o00002_ooool3o`000003oooo
ool0003o000000?ooooo4_l00007ooooo`Co000000?oooooo`000?l000000_l00003ooooo`;o0000
8Oooool2o`0005Cooooo000Looooo`03o`000?oooooooooo06oooooo4?l000000ooooooo0000o`00
0003o`000003ooooool0003o000000Gooooo0_l00003ooooo`;o00000_ooool2o`0000[ooooo0ol0
0004oooooaOo00001?ooool4o`000003ooooool0003o000000;o00000oooool2o`0000Oooooo0_l0
0008ooooo`;o00003_ooool2o`0005Cooooo000Looooo`03o`000?oooooooooo04oooooo0_l00004
ooooo`;o00004Oooool2o`0000?ooooo5ol00002ooooo`;o00001Oooool2o`0001?ooooo0ol00004
oooooaWo00001Oooool2o`000003ooooool0003o000000?o000000Coooooo`000?l0003ooooo0_l0
0004ooooo`;o00002?ooool3o`0000;ooooo0_l00003ooooo`;o00001oooool2o`00057ooooo000L
ooooo`03o`000?oooooooooo04oooooo0_l00004ooooo`;o00004Oooool3o`0000;ooooo2_l00000
0ooooooo0000o`00000:o`0000;ooooo0_l00002ooooo`;o00005_ooool3o`000004ooooool0003o
0000oooooaGo000000Coooooo`000?l0003o00001Oooool2o`0000;ooooo1Ol00003ooooo`;o0000
0oooool2o`0000[ooooo0_l00002ooooo`;o00000oooool2o`0000Oooooo0_l0001Aooooo`007?oo
ool2o`0006[ooooo0_l000000ooooooo0000o`000009o`000003ooooool0003o000000_o00001Ooo
ool2o`0001Sooooo1?l000000ooooooo0000o`00000Co`000004ooooool0003o0000o`0000Wooooo
2?l00003ooooo`Co0000Koooool001cooooo00?o0000ooooooooool0J_oooolMo`0000Kooooo0_l0
000Eooooo`;o00000_oooolGo`0000;ooooo0_l00009ooooo`Oo00000oooool2o`0000Cooooo0_l0
000Cooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0J_ooool2o`000003ooooool0003o
000000;o000000?oooooo`000?l000003?l00002ooooo`;o000000?oooooo`000?l000001_ooool2
o`0000Kooooo0_l0000;ooooo`Co00000_oooolHo`000003ooooool0003o000000Gooooo1ol00006
ooooo`?o00001?ooool2o`0001?ooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`1^oooo
oa?o000000Coooooo`000?l0003o00002oooool2o`0000?ooooo0_l0000;ooooo`Go00000_oooolH
o`0000;ooooo0ol00002ooooo`Co00002Oooool3o`0001Sooooo0_l0001Gooooo`007?ooool00ol0
003oooooooooo`1=ooooo`;o00008?oooolBo`000004ooooool0003o0000o`0000_ooooo0_l0000C
ooooo`;o000000?oooooo`000?l000005?l000000ooooooo0000o`000002ooooo`?o00000_ooool3
o`000003ooooool0003o000000?ooooo0_l0000Mooooo`;o0000Eoooool001cooooo00?o0000oooo
ooooool0COooool2o`000003ooooool0003o000001oooooo3ol00003ooooo`;o00007Oooool5o`00
0003ooooool0003o000000[o000000?oooooo`000?l000001ol000000ooooooo0000o`000007oooo
o`?o000000?oooooo`000?l000000_l000000ooooooo0000o`000003ooooo`;o00005?ooool2o`00
05_ooooo000Looooo`03o`000?oooooooooo053ooooo0_l0000Oooooo`oo00002?ooool2o`0001So
oooo0ol00005ooooo`oo000000?oooooo`000?l000000ol0000?ooooo`;o00001_ooool2o`0000Ko
oooo0_l0000<ooooo`;o0000Foooool001cooooo00?o0000ooooooooool0L?ooool:o`0000;ooooo
0_l00009ooooo`?o00007oooool2o`000003ooooool0003o000001;o00003_ooool2o`0000;ooooo
0_l00002ooooo`;o00001_ooool2o`0000[ooooo1?l0001Kooooo`007?ooool00ol0003ooooooooo
o`1Yooooo`;o00000_ooool7o`000003ooooool0003o000000Gooooo0_l00009ooooo`;o00008?oo
oolDo`000003ooooool0003o000000kooooo0_l00002ooooo`Go00001?ooool2o`0000Wooooo2?l0
001Kooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00006_ooool;o`0000Sooooo0_l00008
ooooo`;o00001_ooool2o`0001Wooooo4_l00005ooooo`;o00003_ooool8o`0000?ooooo0_l00009
ooooo`Co0000Goooool001cooooo00?o0000ooooooooool0COooool2o`0000;ooooo0_l0000Goooo
o`?o00000_ooool4o`000004ooooool0003o0000o`0000gooooo1?l00006ooooo`;o00006Oooool2
o`000003ooooool0003o000000_o00000_ooool3o`0000;ooooo0_l0000>ooooo`;o00000_ooool4
o`0000oooooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00000_ooool2o`00
01Oooooo0_l00003ooooo`Co000000Coooooo`000?l0003o00001_ooool2o`0000Cooooo0ol0000M
ooooo`;o00001oooool2o`0000;ooooo2_l000001?oooooo0000o`000?l00002ooooo`;o00004_oo
ool4o`0000Cooooo0ol0001Zooooo`007?ooool00ol0003oooooooooo`1_ooooo`;o00000oooool3
o`000003ooooool0003o000000?ooooo0_l00004ooooo`;o000000?oooooo`000?l000000ol0000H
ooooo`Co00001_ooool3o`000003ooooool0003o000000Co000000?oooooo`000?l000006_ooool6
o`0000;ooooo0ol0001Zooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o00005Oooool2o`00
00?ooooo0_l00002ooooo`;o00003?ooool5o`0000Gooooo0_l0000Booooo`Co00001Oooool3o`00
02Cooooo1_l0001_ooooo`007?ooool00ol0003oooooooooo`1Fooooo`Co00005Oooool2o`0000ko
oooo0_l0000>ooooo`?o00004_ooool4o`0000Sooooo1?l0000;ooooo`?o00006oooool2o`0006[o
oooo000Looooo`03o`000?oooooooooo05Kooooo0ol0000Dooooo`Co00003_ooool2o`0000kooooo
0_l0000Oooooo`Co00002oooool3o`0001_ooooo0_l0001Zooooo`007?ooool2o`0004_ooooo0_l0
0005ooooo`;o00006_ooool2o`0003Kooooo0_l0000;ooooo`;o00003?ooool2o`0000Cooooo0ol0
0020ooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o00001Oooool2o`0000Kooooo1?l0000>
ooooo`;o00000_ooool2o`0003Cooooo0_l0000Cooooo`;o00002_ooool3o`0001Cooooo0_l0001Z
ooooo`007?ooool00ol0003oooooooooo`1Iooooo`Co00003_ooool3o`000003ooooool0003o0000
01Cooooo0_l0000:ooooo`;o00007_ooool2o`0000Oooooo0_l000001?oooooo0000o`000?l00009
ooooo`;o00001?ooool2o`0000cooooo0_l0001Zooooo`007?ooool00ol0003oooooooooo`1/oooo
o`;o00001?ooool2o`00017ooooo0_l0000:ooooo`;o00006oooool2o`000003ooooool0003o0000
00[ooooo1?l00008ooooo`;o00001?ooool2o`000004ooooool0003o0000o`0007Cooooo000Loooo
o`03o`000?oooooooooo04gooooo0_l0000Sooooo`;o0000>?ooool4o`0000oooooo0_l0000<oooo
o`Co000000Coooooo`000?l0003o00001?ooool2o`0006kooooo000Looooo`03o`000?oooooooooo
04gooooo0_l0000Aooooo`;o0000:_ooool2o`0000Cooooo0ol0000Gooooo`;o00003?ooool2o`00
00?ooooo1?l00004ooooo`;o00001?ooool4o`0000Sooooo0_l0001^ooooo`007?ooool00ol0003o
ooooooooo`1Pooooo`;o0000:_ooool2o`0000Cooooo0ol00002ooooo`;o00006_ooool2o`0000Go
oooo0_l00005ooooo`;o000000?oooooo`000?l000000ol00005ooooo`;o0000NOooool001cooooo
00?o0000ooooooooool0L?ooool2o`0002Gooooo0_l0000Jooooo`;o00001_ooool2o`0000Cooooo
0_l000001?oooooo0000o`000?l0000:ooooo`;o00000oooool2o`00077ooooo000Looooo`03o`00
0?oooooooooo06cooooo0_l00002ooooo`;o00000oooool2o`0004;ooooo1?l00002ooooo`Co0000
2?ooool2o`0000Cooooo0_l00002ooooo`?o0000LOooool001cooooo00?o0000ooooooooool0K?oo
ool2o`0000Oooooo0_l00007ooooo`;o0000>Oooool2o`000004ooooool0003o0000ooooo`;o0000
2?ooool6o`0000Kooooo0_l0001booooo`007?ooool00ol0003oooooooooo`1Booooo`;o00008Ooo
ool2o`0000Kooooo0ol00008ooooo`;o0000<_ooool2o`0000_ooooo0_l000001Ooooooo0000o`00
0?l0003ooooo00;o0000Moooool001cooooo00?o0000ooooooooool0D_ooool2o`00027ooooo0_l0
0002ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000Kooooo0_l0000;ooooo`;o0000
9?ooool2o`0001?ooooo0_l0001gooooo`007?ooool00ol0003oooooooooo`1dooooo`;o00000ooo
ool2o`000005ooooool0003o0000o`000?ooool00_l0000Cooooo`;o000000?oooooo`000?l00000
8Oooool2o`0008cooooo000Looooo`03o`000?oooooooooo07Cooooo1Ol00007ooooo`;o00005_oo
ool2o`0000?ooooo0_l0002Zooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q
1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0Goooool2o`0000Go
oooo0_l0000:ooooo`;o00000_ooool3o`0000kooooo0_l0000Dooooo`;o0000Z_ooool00006oooo
oomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06
ooooo`03o`000?oooooooooo05oooooo0_l00005ooooo`;o00002_ooool2o`00017ooooo1?l00030
ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`25ooooo`;o00006_ooool2o`000:Kooooo00000ooo
oooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06
ooooo`?o0000XOooool2o`000:Kooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00Wooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo06_ooooo0_l0000B
ooooo`;o0000b?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol@
413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0IOooool2o`0000Cooooo0_l0000B
ooooo`;o0000b?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooo
oonj^[[o000000Kooooo00?o0000ooooooooool0IOooool2o`0000?ooooo0_l0000:ooooo`;o0000
dOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY
00Kooooo00?o0000ooooooooool0J_ooool2o`0000;ooooo0_l00006ooooo`;o00002oooool2o`00
063ooooo0_l0001Rooooo`007?ooool00ol0003oooooooooo`1Xooooo`;o00000_ooool4o`0000Go
oooo0_l00003ooooo`;o00001oooool3o`0005oooooo0_l0001Rooooo`007?ooool00ol0003ooooo
ooooo`1Xooooo`;o00000_ooool2o`0000Oooooo0_l00003ooooo`;o00002?ooool2o`0005cooooo
0_l0001Uooooo`007?ooool00ol0003oooooooooo`1fooooo`;o0000J_ooool2o`0006Gooooo000L
ooooo`03o`000?oooooooooo06kooooo0_l00006ooooo`;o000000?oooooo`000?l00000c_ooool0
01cooooo00?o0000ooooooooool0K_ooool2o`0000Wooooo0_l0003>ooooo`007?ooool00ol0003o
ooooooooo`1]ooooo`;o00005?ooool2o`000<Cooooo000Looooo`03o`000?oooooooooo06gooooo
0_l00003ooooo`;o00003oooool2o`000<Cooooo000Looooo`03o`000?oooooooooo06Gooooo0_l0
000;ooooo`;o00001?ooool2o`0000Wooooo0_l00034ooooo`007?ooool00ol0003oooooooooo`1U
ooooo`;o00004Oooool2o`000<oooooo000Looooo`03o`000?oooooooooo07Gooooo0_l0003Boooo
o`007?ooool00ol0003oooooooooo`1eooooo`;o00005_ooool2o`0004Sooooo0_l0001`ooooo`00
7?ooool2o`0008kooooo0_l0000Tooooo`Co00008?ooool2o`00073ooooo000Looooo`03o`000?oo
oooooooo07Wooooo0_l0000eooooo`Oo0000T_ooool001cooooo00?o0000ooooooooool0NOooool2
o`0001oooooo0_l0000Dooooo`?o0000U_ooool001cooooo00?o0000ooooooooool0V_ooool2o`00
00;ooooo0_l000000ooooooo0000o`000005ooooo`Co0000WOooool001cooooo00?o0000oooooooo
ool0O?ooool2o`00023ooooo0_l000000ooooooo0000o`000005ooooo`Co0000WOooool001cooooo
00?o0000ooooooooool0O?ooool2o`0005;ooooo0_l0001gooooo`007?ooool00ol0003ooooooooo
o`3@ooooo`;o0000Moooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo083ooooo0_l00037ooooo`00
7?ooool00ol0003oooooooooo`20ooooo`?o00000oooool2o`00047ooooo0_l0001nooooo`007?oo
ool00ol0003oooooooooo`21ooooo`;o00000oooool2o`00047ooooo0_l0001nooooo`007?ooool0
0ol0003oooooooooo`35ooooo`;o0000P_ooool001cooooo00?o0000ooooooooool0aOooool2o`00
08;ooooo000Looooo`03o`000?oooooooooo08Wooooo0_l0000eooooo`;o0000Qoooool001cooooo
00?o0000ooooooooool0ROooool2o`0003Gooooo0_l00027ooooo`007?ooool2o`000;[ooooo0_l0
002>ooooo`007?ooool00ol0003oooooooooo`2aooooo`Co00001?ooool2o`0008kooooo000Loooo
o`03o`000?oooooooooo0:_ooooo0_l00004ooooo`Co0000U?ooool001cooooo00?o0000oooooooo
ool0Xoooool2o`0000Kooooo0_l0002Looooo`007?ooool00ol0003oooooooooo`2Hooooo`Co0000
1oooool3o`000:?ooooo000Looooo`03o`000?oooooooooo09Sooooo1?l00008ooooo`;o0000Xooo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`004_ooool4o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool3o`00
0?ooooooB_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003ooooo
ooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000
ooooooooool0oooooomBooooo`004_ooool00omEEEGoIVIVo`00003ooooooeCooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo002Uooooo`04oa0@4?l0003o0000ooooo`;o000000?o
410@ooooooooool05oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?l@413oc<c<
00?ooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c02@ooooo`00Y_ooool01Ol0003ooooooooooooooooo
000000Wooooo1_l0000<ooooo`03o`000?oooooooooo00;ooooo00GoEEEEogMgMoooooooV9RHob4Q
8@03ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40T?ooool00:Kooooo00Go0000oooooooooooooooo
o`00000Hooooo`Go00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`00002@ooooo`00Y_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l00009oooo
o`04odA4A?oMgMgoooooo`0000Cooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05oc8b<_nH
V9SooooooiRHV?lb<S80T?ooool00:Kooooo00Go0000ohN7QoooooooZJVYo`00000Hooooo`04omgM
gOmEEEGoooooo`0000Cooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05olc<c?l0003o0000
o`000?o<c<`0T?ooool00:Gooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Goooo
o`03ogMgMoo<c<co000000Cooooo00?oEEEEohN7Qoooool01Oooool01Ol@413o^[Zjoooooonj^[[o
410@093ooooo0034ooooo`03onk^k_m4A4Co000000Cooooo00?ogMgMoa0@4?nHV9P01Oooool01Ol0
003o^[Zjoooooonj^[[o0000093ooooo0035ooooo`03ogMgMol0003ooooo00Cooooo00Coc<c<odA4
A?l0003o410@0oooool01OnYZJWo410@o`000?l@413oZJVY093ooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(474) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.54201 .36107 Mdot
.53907 .34568 Mdot
.32755 .65138 Mdot
.65922 .5324 Mdot
.55802 .69857 Mdot
.37071 .66617 Mdot
.30273 .44225 Mdot
.2862 .44301 Mdot
.36254 .67797 Mdot
.62819 .34234 Mdot
.30631 .47089 Mdot
.65007 .5717 Mdot
.30196 .45598 Mdot
.63579 .50564 Mdot
.47412 .40699 Mdot
.61775 .44326 Mdot
.53831 .28921 Mdot
.52351 .73985 Mdot
.64235 .44084 Mdot
.32956 .67675 Mdot
.74809 .57254 Mdot
.63891 .49551 Mdot
.50559 .31164 Mdot
.63514 .5027 Mdot
.61305 .53512 Mdot
.53746 .33068 Mdot
.53697 .36209 Mdot
.6029 .52148 Mdot
.59257 .54464 Mdot
.29722 .46855 Mdot
.37337 .72507 Mdot
.7668 .30164 Mdot
.64582 .46272 Mdot
.73814 .33955 Mdot
.28943 .43984 Mdot
.30223 .51096 Mdot
.3364 .65585 Mdot
.33673 .44216 Mdot
.28118 .44184 Mdot
.28991 .43571 Mdot
.31877 .4389 Mdot
.53739 .32148 Mdot
.28624 .43254 Mdot
.2535 .661 Mdot
.63062 .51938 Mdot
.46718 .36033 Mdot
.1925 .61057 Mdot
.59508 .52682 Mdot
.55225 .31482 Mdot
.33073 .68714 Mdot
.63541 .75309 Mdot
.32323 .4768 Mdot
.43988 .42128 Mdot
.52186 .90835 Mdot
.30882 .46324 Mdot
.64916 .54719 Mdot
.3659 .68766 Mdot
.66203 .50464 Mdot
.67276 .5237 Mdot
.71163 .30156 Mdot
.65069 .48346 Mdot
.53383 .69992 Mdot
.48853 .31292 Mdot
.39822 .64733 Mdot
.36879 .67587 Mdot
.3364 .44592 Mdot
.49147 .32882 Mdot
.28975 .45396 Mdot
.58295 .5303 Mdot
.32402 .67289 Mdot
.59314 .54207 Mdot
.29835 .47115 Mdot
.50016 .34626 Mdot
.62728 .51992 Mdot
.4087 .36153 Mdot
.23243 .43336 Mdot
.31648 .63757 Mdot
.79218 .43445 Mdot
.65013 .78301 Mdot
.44607 .65888 Mdot
.6192 .50487 Mdot
.50583 .86309 Mdot
.4614 .46704 Mdot
.53864 .35117 Mdot
.57777 .35557 Mdot
.44672 .22231 Mdot
.59603 .51985 Mdot
.42553 .59283 Mdot
.67989 .47231 Mdot
.53367 .61815 Mdot
.35186 .68121 Mdot
.52296 .34995 Mdot
.62457 .51558 Mdot
.62445 .47159 Mdot
.57658 .26348 Mdot
.62589 .56168 Mdot
.648 .53459 Mdot
.57939 .30745 Mdot
.314 .47197 Mdot
.56146 .55765 Mdot
.55833 .77268 Mdot
.4156 .40682 Mdot
.63496 .54933 Mdot
.3499 .65229 Mdot
.48787 .30812 Mdot
.64068 .53581 Mdot
.28767 .44717 Mdot
.6243 .50021 Mdot
.25969 .46741 Mdot
.52574 .293 Mdot
.64623 .46659 Mdot
.51144 .72379 Mdot
.55268 .57263 Mdot
.52013 .30502 Mdot
.75271 .45491 Mdot
.64221 .48503 Mdot
.66173 .48891 Mdot
.54393 .34228 Mdot
.32994 .65488 Mdot
.34192 .59057 Mdot
.49912 .3232 Mdot
.28623 .43664 Mdot
.54915 .30007 Mdot
.6892 .5315 Mdot
.32975 .6613 Mdot
.4294 .41338 Mdot
.42164 .40593 Mdot
.59683 .67579 Mdot
.61884 .51373 Mdot
.54116 .55155 Mdot
.35885 .65611 Mdot
.54311 .32648 Mdot
.2929 .46049 Mdot
.66627 .54423 Mdot
.52324 .31187 Mdot
.27328 .45241 Mdot
.55274 .70508 Mdot
.56677 .72052 Mdot
.54375 .30982 Mdot
.69502 .44229 Mdot
.28255 .4919 Mdot
.30064 .43249 Mdot
.63364 .75101 Mdot
.54143 .35039 Mdot
.51742 .70881 Mdot
.27233 .46384 Mdot
.70158 .65062 Mdot
.6807 .49936 Mdot
.60868 .72746 Mdot
.42091 .84268 Mdot
.63464 .75301 Mdot
.76251 .32082 Mdot
.51061 .7189 Mdot
.2699 .45762 Mdot
.59604 .54081 Mdot
.52243 .32399 Mdot
.52943 .31404 Mdot
.61407 .47824 Mdot
.62131 .52724 Mdot
.64033 .51894 Mdot
.67699 .52128 Mdot
.22704 .49524 Mdot
.62216 .51077 Mdot
.2626 .34167 Mdot
.51755 .31743 Mdot
.62403 .53604 Mdot
.3528 .63847 Mdot
.56383 .54946 Mdot
.32659 .43658 Mdot
.67078 .52539 Mdot
.61685 .52851 Mdot
.65925 .55755 Mdot
.27385 .44311 Mdot
.38601 .35139 Mdot
.71397 .74643 Mdot
.26854 .50628 Mdot
.29278 .40194 Mdot
.37148 .6538 Mdot
.63084 .47963 Mdot
.52715 .72329 Mdot
.56212 .55452 Mdot
.6755 .50238 Mdot
.63705 .75705 Mdot
.609 .51335 Mdot
.7839 .37011 Mdot
.65038 .57824 Mdot
.43456 .22621 Mdot
.29035 .30325 Mdot
.6775 .5018 Mdot
.65361 .37806 Mdot
.60196 .71491 Mdot
.32352 .73826 Mdot
.29579 .46518 Mdot
.36253 .63197 Mdot
.33399 .64498 Mdot
.33839 .43939 Mdot
.7128 .55736 Mdot
.64162 .34868 Mdot
.61102 .55949 Mdot
.42396 .41127 Mdot
.52792 .38374 Mdot
.50984 .71026 Mdot
.54587 .3118 Mdot
.53922 .85651 Mdot
.46571 .64068 Mdot
.42668 .61375 Mdot
.54975 .74084 Mdot
.3472 .69648 Mdot
.4274 .42324 Mdot
.51874 .71518 Mdot
.65802 .52514 Mdot
.53534 .29455 Mdot
.60341 .73028 Mdot
.56767 .50395 Mdot
.34967 .17451 Mdot
.5186 .35791 Mdot
.5318 .56879 Mdot
.30406 .46249 Mdot
.38693 .63113 Mdot
.59641 .52007 Mdot
.65242 .50716 Mdot
.4893 .33987 Mdot
.59021 .53162 Mdot
.43763 .5813 Mdot
.61416 .52439 Mdot
.39703 .65403 Mdot
.51606 .66093 Mdot
.25697 .44905 Mdot
.53959 .74631 Mdot
.49782 .33937 Mdot
.22325 .43151 Mdot
.3492 .64673 Mdot
.64487 .60474 Mdot
.28468 .46299 Mdot
.55308 .71035 Mdot
.3406 .65948 Mdot
.50753 .72433 Mdot
.66048 .47068 Mdot
.33543 .66456 Mdot
.5247 .69749 Mdot
.41451 .52032 Mdot
.64619 .53678 Mdot
.62575 .68108 Mdot
.29349 .48307 Mdot
.5488 .35033 Mdot
.66936 .48851 Mdot
.43386 .42957 Mdot
.67937 .53827 Mdot
.51238 .50902 Mdot
.42212 .43388 Mdot
.39751 .42169 Mdot
.43644 .61859 Mdot
.53515 .687 Mdot
.40491 .38481 Mdot
.4147 .55245 Mdot
.53743 .28879 Mdot
.65923 .47244 Mdot
.45416 .2827 Mdot
.28983 .48295 Mdot
.66054 .5205 Mdot
.43046 .25311 Mdot
.27179 .46347 Mdot
.66425 .49841 Mdot
.32004 .44109 Mdot
.52509 .31658 Mdot
.43612 .49333 Mdot
.55821 .32357 Mdot
.66268 .52745 Mdot
.32483 .45242 Mdot
.35654 .63244 Mdot
.53681 .33035 Mdot
.62881 .4968 Mdot
.61412 .49838 Mdot
.42081 .41261 Mdot
.62877 .52667 Mdot
.47508 .23232 Mdot
.59658 .52676 Mdot
.32934 .69058 Mdot
.60887 .55623 Mdot
.58593 .76894 Mdot
.55888 .74973 Mdot
.50314 .30374 Mdot
.41884 .43405 Mdot
.34853 .6827 Mdot
.42738 .50079 Mdot
.60218 .65515 Mdot
.62432 .50596 Mdot
.40909 .42274 Mdot
.52497 .56162 Mdot
.32856 .43911 Mdot
.60148 .4741 Mdot
.38682 .5775 Mdot
.34751 .6764 Mdot
.42738 .41619 Mdot
.58787 .47312 Mdot
.53319 .36677 Mdot
.63734 .55253 Mdot
.33867 .65399 Mdot
.5536 .34697 Mdot
.64129 .56226 Mdot
.18794 .5334 Mdot
.43547 .42868 Mdot
.32562 .46077 Mdot
.55869 .26664 Mdot
.62052 .47895 Mdot
.34011 .63675 Mdot
.52879 .30947 Mdot
.31737 .45516 Mdot
.51183 .30811 Mdot
.59646 .73755 Mdot
.52297 .49797 Mdot
.30448 .53016 Mdot
.49865 .72502 Mdot
.84932 .46628 Mdot
.30102 .50943 Mdot
.56581 .56817 Mdot
.32623 .70712 Mdot
.38807 .20024 Mdot
.34419 .65816 Mdot
.65527 .41927 Mdot
.3579 .68592 Mdot
.62138 .55263 Mdot
.37036 .66955 Mdot
.49897 .20062 Mdot
.60334 .51115 Mdot
.38172 .6666 Mdot
.28028 .53846 Mdot
.60554 .50716 Mdot
.51986 .3114 Mdot
.64189 .20755 Mdot
.77405 .46576 Mdot
.75844 .50759 Mdot
.37667 .68254 Mdot
.6984 .44021 Mdot
.6004 .51896 Mdot
.65124 .44236 Mdot
.5254 .32839 Mdot
.66626 .55811 Mdot
.51192 .68907 Mdot
.50279 .71448 Mdot
.67586 .69828 Mdot
.80214 .48926 Mdot
.72939 .53952 Mdot
.53383 .32357 Mdot
.63811 .7924 Mdot
.4106 .35616 Mdot
.43705 .42721 Mdot
.27997 .44623 Mdot
.38102 .36443 Mdot
.6103 .45253 Mdot
.5835 .3795 Mdot
.43818 .56661 Mdot
.51928 .35111 Mdot
.36401 .52531 Mdot
.31611 .45005 Mdot
.76456 .49499 Mdot
.64004 .3192 Mdot
.64228 .52103 Mdot
.31756 .47718 Mdot
.6765 .5619 Mdot
.42499 .57314 Mdot
.61357 .69182 Mdot
.2239 .60352 Mdot
.65704 .53001 Mdot
.42415 .3783 Mdot
.6742 .50116 Mdot
.60318 .68979 Mdot
.66366 .52003 Mdot
.51122 .31219 Mdot
.68213 .46299 Mdot
.40954 .54411 Mdot
.80022 .56768 Mdot
.46539 .62983 Mdot
.5174 .69435 Mdot
.63947 .50559 Mdot
.65038 .51806 Mdot
.53292 .69728 Mdot
.51903 .34824 Mdot
.66021 .4752 Mdot
.18119 .59518 Mdot
.62079 .51048 Mdot
.33308 .46705 Mdot
.46823 .52787 Mdot
.8091 .39814 Mdot
.6006 .4969 Mdot
.52622 .36678 Mdot
.31642 .43574 Mdot
.27802 .46356 Mdot
.71579 .49191 Mdot
.30007 .48409 Mdot
.59372 .53877 Mdot
.46808 .52649 Mdot
.51168 .30188 Mdot
.63253 .58002 Mdot
.51377 .34607 Mdot
.62029 .79664 Mdot
.27125 .46685 Mdot
.40671 .42614 Mdot
.75187 .48628 Mdot
.30273 .44575 Mdot
.54017 .64235 Mdot
.68237 .46391 Mdot
.57266 .50264 Mdot
.55236 .26618 Mdot
.35488 .63085 Mdot
.41529 .42881 Mdot
.31218 .46175 Mdot
.62507 .51295 Mdot
.63524 .54341 Mdot
.31426 .48165 Mdot
.66222 .25934 Mdot
.36854 .72653 Mdot
.66475 .5265 Mdot
.50669 .32109 Mdot
.5417 .32483 Mdot
.68102 .5187 Mdot
.67226 .49359 Mdot
.38081 .65172 Mdot
.40885 .42374 Mdot
.41498 .43163 Mdot
.41225 .40484 Mdot
.39321 .65665 Mdot
.84306 .49025 Mdot
.3011 .43235 Mdot
.78049 .32833 Mdot
.41186 .29849 Mdot
.70122 .47145 Mdot
.33907 .64366 Mdot
.65422 .49696 Mdot
.62339 .54961 Mdot
.32308 .45786 Mdot
.81651 .53148 Mdot
.6834 .46944 Mdot
.54131 .35853 Mdot
.32487 .47449 Mdot
.66054 .56669 Mdot
.31787 .49426 Mdot
.53702 .73126 Mdot
.74649 .51405 Mdot
.30571 .48466 Mdot
.51965 .29794 Mdot
.30695 .48455 Mdot
.64735 .51898 Mdot
.58327 .4768 Mdot
.51886 .35197 Mdot
.56143 .72125 Mdot
.63001 .47241 Mdot
.66592 .49882 Mdot
.33562 .76845 Mdot
.41105 .36339 Mdot
.57231 .73145 Mdot
.60484 .54089 Mdot
.56714 .53139 Mdot
.55531 .73093 Mdot
.63976 .47326 Mdot
.60809 .55416 Mdot
.54636 .56834 Mdot
.25794 .46859 Mdot
.53387 .68311 Mdot
.79628 .568 Mdot
.52194 .35893 Mdot
.46456 .23938 Mdot
.42158 .40775 Mdot
.32199 .42272 Mdot
.43612 .48358 Mdot
.42183 .42292 Mdot
.41143 .27576 Mdot
.20606 .42766 Mdot
.41381 .42618 Mdot
.39548 .63893 Mdot
.60369 .39166 Mdot
.6005 .55167 Mdot
.67201 .51448 Mdot
.53422 .68735 Mdot
.54913 .33822 Mdot
.2724 .33418 Mdot
.25079 .45742 Mdot
.64368 .49023 Mdot
.54894 .36144 Mdot
.44049 .22334 Mdot
.426 .41835 Mdot
.52528 .72622 Mdot
.56153 .71266 Mdot
.67171 .49668 Mdot
.56876 .62839 Mdot
.5362 .32502 Mdot
.62894 .49682 Mdot
.65668 .48077 Mdot
.34767 .68802 Mdot
.53842 .29627 Mdot
.35548 .63943 Mdot
.40983 .43465 Mdot
.35901 .19953 Mdot
.28024 .74106 Mdot
.2871 .48007 Mdot
.38628 .47354 Mdot
.27547 .43423 Mdot
.20498 .56451 Mdot
.40898 .42502 Mdot
.63337 .49601 Mdot
.49618 .32523 Mdot
.62533 .49871 Mdot
.62196 .51254 Mdot
.64277 .52732 Mdot
.7296 .53965 Mdot
.62125 .78978 Mdot
.54341 .71794 Mdot
.58924 .5027 Mdot
.38477 .67687 Mdot
.43308 .2354 Mdot
.53782 .21064 Mdot
.64523 .50871 Mdot
.66232 .48999 Mdot
.49244 .33938 Mdot
.66716 .47207 Mdot
.28944 .44375 Mdot
.53152 .35601 Mdot
.63923 .54613 Mdot
.5593 .77517 Mdot
.66142 .47728 Mdot
.37642 .48703 Mdot
.2989 .48771 Mdot
.57425 .46005 Mdot
.57552 .50964 Mdot
.40881 .42603 Mdot
.41593 .42837 Mdot
.4274 .43657 Mdot
.33182 .4646 Mdot
.34732 .68681 Mdot
.38335 .61632 Mdot
.5815 .49775 Mdot
.59557 .53543 Mdot
.57828 .48514 Mdot
.3502 .70234 Mdot
.40309 .55453 Mdot
.52094 .40102 Mdot
.66773 .57 Mdot
.39028 .65644 Mdot
.57488 .29353 Mdot
.78388 .51423 Mdot
.53906 .35563 Mdot
.32686 .70531 Mdot
.2813 .45411 Mdot
.50699 .71669 Mdot
.66174 .7319 Mdot
.50199 .31904 Mdot
.49974 .35366 Mdot
.37727 .65693 Mdot
.48192 .49849 Mdot
.58661 .90127 Mdot
.35268 .65679 Mdot
.42867 .60636 Mdot
.52866 .32767 Mdot
.66637 .46526 Mdot
.51772 .55229 Mdot
.49005 .48437 Mdot
.37848 .6723 Mdot
.61477 .49846 Mdot
.4949 .65353 Mdot
.38107 .65243 Mdot
.6204 .46178 Mdot
.37867 .68102 Mdot
.32142 .46917 Mdot
.35913 .65175 Mdot
.56577 .33478 Mdot
.61626 .50907 Mdot
.54019 .90828 Mdot
.45682 .463 Mdot
.62832 .49106 Mdot
.31329 .48358 Mdot
.24131 .52981 Mdot
.65072 .52353 Mdot
.51082 .69327 Mdot
.38941 .67259 Mdot
.21136 .59083 Mdot
.62156 .55656 Mdot
.3756 .66698 Mdot
.56942 .33279 Mdot
.34267 .70918 Mdot
.55309 .76991 Mdot
.41539 .43048 Mdot
.52248 .31819 Mdot
.42711 .39603 Mdot
.30472 .4341 Mdot
.68764 .50415 Mdot
.65063 .47863 Mdot
.51253 .32067 Mdot
.41941 .50674 Mdot
.72018 .51561 Mdot
.61999 .50567 Mdot
.37315 .64503 Mdot
.36604 .69664 Mdot
.47618 .40153 Mdot
.34579 .64844 Mdot
.56752 .53377 Mdot
.51317 .3161 Mdot
.64134 .54956 Mdot
.5289 .30598 Mdot
.65657 .47147 Mdot
.34498 .41137 Mdot
.5436 .35208 Mdot
.61427 .60631 Mdot
.61618 .51287 Mdot
.51118 .25165 Mdot
.6164 .48094 Mdot
.65268 .53192 Mdot
.37896 .69047 Mdot
.53514 .71217 Mdot
.62212 .46545 Mdot
.22374 .44206 Mdot
.54689 .73339 Mdot
.70846 .27481 Mdot
.33008 .66058 Mdot
.55715 .70921 Mdot
.66671 .68633 Mdot
.4192 .43391 Mdot
.54046 .70342 Mdot
.39279 .43461 Mdot
.29539 .48154 Mdot
.55373 .29675 Mdot
.60755 .50703 Mdot
.39182 .19106 Mdot
.37889 .72251 Mdot
.41595 .41361 Mdot
.66587 .48687 Mdot
.65667 .5015 Mdot
.54369 .36288 Mdot
.52904 .85825 Mdot
.39928 .6647 Mdot
.65263 .53636 Mdot
.49838 .33232 Mdot
.47427 .85781 Mdot
.38309 .66597 Mdot
.54583 .71936 Mdot
.26671 .47089 Mdot
.50538 .377 Mdot
.4084 .42922 Mdot
.27027 .4647 Mdot
.31269 .65045 Mdot
.63874 .75947 Mdot
.63074 .55653 Mdot
.34536 .6403 Mdot
.63482 .75371 Mdot
.64197 .58101 Mdot
.33149 .43227 Mdot
.36016 .41753 Mdot
.52593 .34985 Mdot
.31638 .48066 Mdot
.52579 .6874 Mdot
.5344 .28983 Mdot
.51603 .34823 Mdot
.28212 .44727 Mdot
.29773 .28029 Mdot
.52244 .55589 Mdot
.34279 .45322 Mdot
.5077 .51435 Mdot
.63269 .75351 Mdot
.40477 .41877 Mdot
.52273 .72562 Mdot
.54762 .79077 Mdot
.53789 .32423 Mdot
.38178 .3626 Mdot
.63662 .75392 Mdot
.64827 .53469 Mdot
.5212 .69745 Mdot
.44409 .23875 Mdot
.28547 .42455 Mdot
.27207 .45531 Mdot
.33245 .60362 Mdot
.51042 .70179 Mdot
.67349 .48457 Mdot
.81845 .42135 Mdot
.60511 .49766 Mdot
.27398 .46941 Mdot
.4385 .57302 Mdot
.53623 .2964 Mdot
.32246 .43406 Mdot
.43743 .58308 Mdot
.6188 .54948 Mdot
.63516 .48469 Mdot
.48886 .68117 Mdot
.54557 .29957 Mdot
.40248 .42692 Mdot
.61871 .49906 Mdot
.66375 .50418 Mdot
.68604 .5101 Mdot
.78276 .55546 Mdot
.59338 .6093 Mdot
.64651 .54088 Mdot
.37624 .62643 Mdot
.56112 .52893 Mdot
.67611 .52105 Mdot
.53999 .36688 Mdot
.57921 .78199 Mdot
.40905 .43471 Mdot
.67105 .51432 Mdot
.66537 .52553 Mdot
.28434 .43989 Mdot
.52304 .55782 Mdot
.48963 .48003 Mdot
.33865 .69414 Mdot
.33748 .60501 Mdot
.59936 .55773 Mdot
.51752 .32331 Mdot
.51454 .68584 Mdot
.58232 .56021 Mdot
.53299 .35874 Mdot
.58658 .4974 Mdot
.38111 .683 Mdot
.41217 .42315 Mdot
.67029 .57701 Mdot
.53259 .70246 Mdot
.26699 .48454 Mdot
.74885 .30141 Mdot
.36272 .634 Mdot
.60588 .53231 Mdot
.38152 .61292 Mdot
.35357 .66919 Mdot
.41712 .41146 Mdot
.57634 .48022 Mdot
.52834 .31714 Mdot
.52577 .29723 Mdot
.61306 .78279 Mdot
.39466 .6531 Mdot
.37132 .79385 Mdot
.31753 .47384 Mdot
.59411 .49505 Mdot
.45673 .32743 Mdot
.5317 .29684 Mdot
.59959 .68033 Mdot
.55885 .71294 Mdot
.27215 .45642 Mdot
.39571 .41044 Mdot
.54423 .35317 Mdot
.53523 .30011 Mdot
.62566 .51599 Mdot
.64448 .50009 Mdot
.30576 .68858 Mdot
.60479 .71684 Mdot
.31871 .44071 Mdot
.5406 .72646 Mdot
.32618 .68526 Mdot
.60826 .54719 Mdot
.53338 .35074 Mdot
.81136 .41127 Mdot
.62187 .47872 Mdot
.3837 .67786 Mdot
.53586 .34515 Mdot
.54883 .71156 Mdot
.53968 .69345 Mdot
.65002 .53329 Mdot
.7914 .39257 Mdot
.29935 .44618 Mdot
.51733 .31104 Mdot
.57713 .31157 Mdot
.58728 .51571 Mdot
.64331 .50515 Mdot
.70065 .52646 Mdot
.3206 .43079 Mdot
.65512 .57976 Mdot
.53922 .73893 Mdot
.54316 .31713 Mdot
.62387 .4952 Mdot
.53459 .69996 Mdot
.58235 .38159 Mdot
.41848 .42107 Mdot
.3824 .66324 Mdot
.50909 .69612 Mdot
.52445 .70978 Mdot
.55058 .72946 Mdot
.38243 .36552 Mdot
.49046 .30061 Mdot
.77517 .66474 Mdot
.61373 .50424 Mdot
.63186 .75349 Mdot
.68335 .47976 Mdot
.33172 .45347 Mdot
.36855 .63185 Mdot
.63196 .51795 Mdot
.61338 .50416 Mdot
.77397 .35153 Mdot
.62032 .44176 Mdot
.62124 .44043 Mdot
.52768 .29404 Mdot
.53331 .25001 Mdot
.34116 .6372 Mdot
.38719 .82794 Mdot
.65521 .19891 Mdot
.61209 .56105 Mdot
.48005 .50243 Mdot
.53368 .35491 Mdot
.27387 .44752 Mdot
.50811 .52387 Mdot
.34205 .49242 Mdot
.54767 .32771 Mdot
.61785 .55139 Mdot
.74873 .30607 Mdot
.51637 .73219 Mdot
.64185 .51819 Mdot
.28987 .4597 Mdot
.64113 .51859 Mdot
.33477 .45704 Mdot
.47105 .32841 Mdot
.47932 .47357 Mdot
.60721 .51201 Mdot
.62114 .55986 Mdot
.53938 .53125 Mdot
.64553 .50568 Mdot
.23431 .58596 Mdot
.52786 .34125 Mdot
.63256 .60756 Mdot
.67399 .53732 Mdot
.7671 .40975 Mdot
.65541 .47757 Mdot
.42567 .47559 Mdot
.63943 .48035 Mdot
.77391 .57742 Mdot
.67718 .48866 Mdot
.63163 .48001 Mdot
.31997 .45089 Mdot
.28361 .43832 Mdot
.56928 .34451 Mdot
.39991 .42318 Mdot
.43401 .22852 Mdot
.66474 .4942 Mdot
.3639 .69912 Mdot
.52576 .42652 Mdot
.52943 .71268 Mdot
.54412 .32067 Mdot
.22797 .73906 Mdot
.32319 .43861 Mdot
.39597 .64254 Mdot
.42648 .62582 Mdot
.36571 .62009 Mdot
.31786 .69074 Mdot
.51918 .24772 Mdot
.5244 .7276 Mdot
.66479 .48015 Mdot
.74846 .35115 Mdot
.42276 .37104 Mdot
.58805 .5192 Mdot
.40626 .64537 Mdot
.57036 .42866 Mdot
.62564 .77801 Mdot
.50153 .71721 Mdot
.51232 .71778 Mdot
.31522 .45649 Mdot
.32849 .65042 Mdot
.67916 .56378 Mdot
.55691 .70918 Mdot
.3689 .63327 Mdot
.42593 .40634 Mdot
.47726 .72592 Mdot
.5355 .3209 Mdot
.70627 .45009 Mdot
.46044 .34772 Mdot
.32165 .43901 Mdot
.22648 .43885 Mdot
.52697 .27228 Mdot
.53058 .28437 Mdot
.40092 .41635 Mdot
.38671 .66648 Mdot
.55289 .29368 Mdot
.61801 .51071 Mdot
.56781 .50374 Mdot
.67175 .49552 Mdot
.53877 .68987 Mdot
.66198 .48277 Mdot
.38226 .64906 Mdot
.30466 .43967 Mdot
.34906 .68018 Mdot
.30562 .44258 Mdot
.70132 .25022 Mdot
.67532 .5181 Mdot
.64095 .50313 Mdot
.46899 .52171 Mdot
.53948 .30375 Mdot
.73171 .33753 Mdot
.38555 .67562 Mdot
.36121 .68803 Mdot
.64245 .54841 Mdot
.49875 .30759 Mdot
.55299 .64811 Mdot
.49935 .52708 Mdot
.64572 .48002 Mdot
.52685 .34149 Mdot
.6457 .54821 Mdot
.20611 .54549 Mdot
.47406 .45271 Mdot
.51386 .3062 Mdot
.80107 .56763 Mdot
.62718 .52264 Mdot
.56968 .4806 Mdot
.5593 .47517 Mdot
.75466 .57721 Mdot
.65543 .46084 Mdot
.51952 .35743 Mdot
.67049 .52818 Mdot
.51844 .32895 Mdot
.34854 .66535 Mdot
.30348 .43116 Mdot
.52126 .32848 Mdot
.60659 .50072 Mdot
.66437 .20713 Mdot
.30131 .43877 Mdot
.63492 .51317 Mdot
.31097 .46724 Mdot
.55601 .30481 Mdot
.54986 .31345 Mdot
.3878 .42017 Mdot
.4277 .61002 Mdot
.2918 .44392 Mdot
.59468 .53446 Mdot
.39581 .35599 Mdot
.63999 .5503 Mdot
.34158 .60295 Mdot
.65461 .5584 Mdot
.58755 .54188 Mdot
.85187 .45781 Mdot
.42394 .49699 Mdot
.31449 .78778 Mdot
.24717 .44215 Mdot
.39004 .35004 Mdot
.57224 .35179 Mdot
.50155 .71673 Mdot
.38976 .48862 Mdot
.4282 .43073 Mdot
.36973 .62367 Mdot
.62806 .51573 Mdot
.52927 .22785 Mdot
.33988 .45906 Mdot
.53744 .71572 Mdot
.6087 .51341 Mdot
.33363 .63386 Mdot
.45232 .43134 Mdot
.27051 .45814 Mdot
.53729 .32001 Mdot
.54761 .3136 Mdot
.66304 .77648 Mdot
.62737 .49303 Mdot
.641 .4972 Mdot
.29516 .43849 Mdot
.70086 .54531 Mdot
.54721 .72997 Mdot
.29446 .54271 Mdot
.29016 .46243 Mdot
.47119 .45777 Mdot
.53061 .29232 Mdot
.65565 .49951 Mdot
.469 .52927 Mdot
.34407 .34564 Mdot
.59892 .29071 Mdot
.51473 .70469 Mdot
.58185 .64001 Mdot
.51912 .35748 Mdot
.29417 .46222 Mdot
.66922 .69499 Mdot
.68767 .47914 Mdot
.65853 .5026 Mdot
.62415 .63847 Mdot
.50067 .52502 Mdot
.42677 .60067 Mdot
.69973 .51876 Mdot
.52779 .58092 Mdot
.64078 .54885 Mdot
.63471 .54379 Mdot
.58306 .5342 Mdot
.65646 .55302 Mdot
.52306 .34016 Mdot
.77271 .4559 Mdot
.36766 .66119 Mdot
.62102 .3629 Mdot
.30646 .63778 Mdot
.59961 .51505 Mdot
.61954 .55084 Mdot
.70298 .40556 Mdot
.51367 .48535 Mdot
.53154 .33558 Mdot
.57448 .30328 Mdot
.29968 .43319 Mdot
.6334 .43997 Mdot
.39394 .65979 Mdot
.57086 .45133 Mdot
.36052 .67486 Mdot
.52509 .34261 Mdot
.33709 .67918 Mdot
.30727 .49105 Mdot
.34504 .64088 Mdot
.3904 .64565 Mdot
.26744 .46299 Mdot
.5523 .31215 Mdot
.63109 .47838 Mdot
.26986 .47067 Mdot
.54817 .647 Mdot
.53879 .69011 Mdot
.3863 .42133 Mdot
.67057 .46607 Mdot
.59464 .45222 Mdot
.18618 .53691 Mdot
.33459 .66794 Mdot
.49807 .47176 Mdot
.54449 .35089 Mdot
.52027 .68472 Mdot
.52049 .3376 Mdot
.71712 .72111 Mdot
.52508 .70258 Mdot
.38607 .42401 Mdot
.64904 .70004 Mdot
.24754 .48808 Mdot
.65738 .56176 Mdot
.55559 .26716 Mdot
.35698 .6758 Mdot
.33126 .46886 Mdot
.4399 .23871 Mdot
.63322 .53058 Mdot
.43864 .41168 Mdot
.53636 .28129 Mdot
.41881 .43324 Mdot
.29228 .45908 Mdot
.38475 .44556 Mdot
.63273 .48963 Mdot
.24643 .48456 Mdot
.6298 .56304 Mdot
.73764 .4712 Mdot
.31284 .63512 Mdot
.58301 .36667 Mdot
.62831 .55444 Mdot
.38476 .66399 Mdot
.63356 .5532 Mdot
.63047 .40481 Mdot
.63417 .72286 Mdot
.60656 .56356 Mdot
.5361 .46192 Mdot
.19393 .57379 Mdot
.53006 .35036 Mdot
.56945 .53458 Mdot
.40903 .41501 Mdot
.61365 .54113 Mdot
.45579 .14315 Mdot
.53855 .70405 Mdot
.57148 .72423 Mdot
.60778 .502 Mdot
.62167 .50014 Mdot
.78038 .37262 Mdot
.51017 .26414 Mdot
.39474 .41177 Mdot
.65915 .51059 Mdot
.66265 .63096 Mdot
.31906 .45525 Mdot
.64548 .56122 Mdot
.67306 .5168 Mdot
.33749 .757 Mdot
.31844 .45999 Mdot
.33337 .65496 Mdot
.42078 .43382 Mdot
.35054 .69552 Mdot
.55378 .68782 Mdot
.54738 .59693 Mdot
.60555 .67407 Mdot
.47434 .44037 Mdot
.51369 .69346 Mdot
.59757 .51158 Mdot
.57659 .37133 Mdot
.62178 .4897 Mdot
.51446 .7177 Mdot
.2976 .4687 Mdot
.52508 .33724 Mdot
.69672 .44363 Mdot
.42114 .41014 Mdot
.59215 .50429 Mdot
.49851 .71493 Mdot
.52394 .32341 Mdot
.28746 .35473 Mdot
.54651 .34328 Mdot
.30886 .4453 Mdot
.33829 .44005 Mdot
.52891 .70765 Mdot
.52094 .33959 Mdot
.34846 .69371 Mdot
.25319 .4313 Mdot
.63611 .56715 Mdot
.30993 .49089 Mdot
.5586 .29496 Mdot
.53066 .36335 Mdot
.49929 .31314 Mdot
.66409 .54331 Mdot
.49359 .51239 Mdot
.6938 .49186 Mdot
.29939 .43839 Mdot
.34844 .62488 Mdot
.61056 .72459 Mdot
.76734 .37261 Mdot
.46937 .46755 Mdot
.62838 .46297 Mdot
.66323 .48414 Mdot
.67118 .49586 Mdot
.65791 .5406 Mdot
.2993 .54135 Mdot
.6751 .51838 Mdot
.32414 .44946 Mdot
.35998 .66819 Mdot
.65243 .48363 Mdot
.4083 .41867 Mdot
.40674 .55564 Mdot
.5181 .68318 Mdot
.7512 .50453 Mdot
.48973 .2443 Mdot
.52423 .32557 Mdot
.34247 .64889 Mdot
.33873 .68298 Mdot
.55272 .70514 Mdot
.27219 .47121 Mdot
.54944 .33392 Mdot
.76537 .58575 Mdot
.53403 .73675 Mdot
.67071 .51417 Mdot
.46845 .52484 Mdot
.79216 .53892 Mdot
.5985 .48727 Mdot
.64802 .52916 Mdot
.40228 .42842 Mdot
.39257 .63766 Mdot
.44984 .17508 Mdot
.28977 .29563 Mdot
.53387 .7107 Mdot
.54721 .72369 Mdot
.49326 .32916 Mdot
.59358 .49471 Mdot
.29636 .44683 Mdot
.53081 .57469 Mdot
.19121 .52098 Mdot
.46208 .22381 Mdot
.20629 .56733 Mdot
.66007 .47662 Mdot
.75206 .4276 Mdot
.65766 .55814 Mdot
.48803 .30752 Mdot
.49687 .31377 Mdot
.53317 .32881 Mdot
.31774 .45004 Mdot
.64061 .76086 Mdot
.32563 .45052 Mdot
.50087 .23382 Mdot
.50686 .34846 Mdot
.42201 .5259 Mdot
.36655 .68797 Mdot
.64426 .44351 Mdot
.52183 .72652 Mdot
.57206 .66171 Mdot
.56916 .52318 Mdot
.5724 .62976 Mdot
.33881 .64401 Mdot
.55589 .33323 Mdot
.67539 .46178 Mdot
.42703 .23186 Mdot
.47987 .49627 Mdot
.19689 .6075 Mdot
.55292 .2485 Mdot
.53133 .69762 Mdot
.63815 .35851 Mdot
.53778 .73456 Mdot
.27183 .45813 Mdot
.63152 .52516 Mdot
.61145 .48171 Mdot
.65723 .53131 Mdot
.659 .54799 Mdot
.3114 .46306 Mdot
.63547 .5689 Mdot
.58667 .76907 Mdot
.43149 .41216 Mdot
.39136 .54213 Mdot
.5406 .69612 Mdot
.32464 .46783 Mdot
.35577 .6685 Mdot
.3999 .41568 Mdot
.49974 .72888 Mdot
.68348 .51517 Mdot
.61098 .4952 Mdot
.42528 .40718 Mdot
.70578 .5534 Mdot
.61319 .45092 Mdot
.37205 .66403 Mdot
.42145 .56455 Mdot
.54611 .69097 Mdot
.51108 .72187 Mdot
.31471 .48019 Mdot
.52029 .33782 Mdot
.5531 .70078 Mdot
.32866 .64772 Mdot
.63835 .56127 Mdot
.61617 .55865 Mdot
.56138 .29763 Mdot
.63652 .75572 Mdot
.51487 .68409 Mdot
.64571 .58054 Mdot
.53737 .30871 Mdot
.53426 .28044 Mdot
.6581 .51193 Mdot
.63509 .57535 Mdot
.49482 .35016 Mdot
.55164 .71241 Mdot
.31466 .47811 Mdot
.43736 .51604 Mdot
.3285 .45131 Mdot
.53109 .31056 Mdot
.56248 .5225 Mdot
.54568 .29813 Mdot
.6299 .52932 Mdot
.36129 .84511 Mdot
.67822 .50101 Mdot
.70382 .58912 Mdot
.46465 .66464 Mdot
.38035 .67905 Mdot
.38294 .67377 Mdot
.41069 .42215 Mdot
.53218 .35799 Mdot
.57278 .55472 Mdot
.53016 .72976 Mdot
.39095 .35048 Mdot
.51862 .26757 Mdot
.39064 .65055 Mdot
.39664 .64791 Mdot
.30013 .46833 Mdot
.65825 .4789 Mdot
.65447 .49491 Mdot
.34246 .64288 Mdot
.25646 .53472 Mdot
.51493 .3334 Mdot
.64064 .49737 Mdot
.66979 .53682 Mdot
.36518 .66268 Mdot
.32966 .41904 Mdot
.53969 .27848 Mdot
.66681 .54182 Mdot
.62534 .71547 Mdot
.3346 .44907 Mdot
.59971 .52704 Mdot
.66028 .55558 Mdot
.52518 .71391 Mdot
.59976 .65516 Mdot
.63314 .75102 Mdot
.27654 .43964 Mdot
.41134 .43046 Mdot
.62088 .47532 Mdot
.37688 .68071 Mdot
.67316 .4656 Mdot
.20197 .37535 Mdot
.43485 .41705 Mdot
.6372 .48986 Mdot
.59386 .55438 Mdot
.52592 .30558 Mdot
.63116 .49526 Mdot
.34906 .41398 Mdot
.36686 .64314 Mdot
.63746 .48916 Mdot
.791 .39569 Mdot
.29768 .46767 Mdot
.57003 .51841 Mdot
.50669 .70806 Mdot
.42981 .59518 Mdot
.64899 .21379 Mdot
.3421 .70041 Mdot
.53425 .69199 Mdot
.65996 .482 Mdot
.34473 .69611 Mdot
.26529 .46855 Mdot
.61907 .61502 Mdot
.59627 .51365 Mdot
.32739 .44799 Mdot
.30129 .44012 Mdot
.53298 .70707 Mdot
.2976 .79079 Mdot
.59731 .55593 Mdot
.64215 .51359 Mdot
.17085 .52657 Mdot
.49985 .35956 Mdot
.63588 .51551 Mdot
.65298 .47835 Mdot
.2943 .48319 Mdot
.71294 .70453 Mdot
.58022 .63809 Mdot
.2801 .53796 Mdot
.33473 .45364 Mdot
.40228 .66328 Mdot
.36423 .63808 Mdot
.53354 .69294 Mdot
.53761 .34501 Mdot
.53286 .68501 Mdot
.36364 .65295 Mdot
.65394 .53104 Mdot
.28594 .47382 Mdot
.62595 .25535 Mdot
.30706 .4873 Mdot
.32556 .65099 Mdot
.50267 .28887 Mdot
.52926 .21868 Mdot
.17978 .40907 Mdot
.46398 .35615 Mdot
.30394 .42771 Mdot
.52931 .71287 Mdot
.27598 .31938 Mdot
.65103 .48224 Mdot
.71542 .44523 Mdot
.64169 .51653 Mdot
.5892 .31189 Mdot
.36932 .63248 Mdot
.41302 .4032 Mdot
.63356 .5309 Mdot
.58282 .63973 Mdot
.26851 .45904 Mdot
.28489 .45101 Mdot
.66575 .53187 Mdot
.30636 .44475 Mdot
.64995 .49276 Mdot
.35952 .66437 Mdot
.31046 .79354 Mdot
.6302 .48226 Mdot
.55872 .531 Mdot
.25612 .45111 Mdot
.38588 .42081 Mdot
.39969 .63388 Mdot
.76728 .43568 Mdot
.42657 .22256 Mdot
.30009 .44792 Mdot
.73383 .53484 Mdot
.33628 .66268 Mdot
.39742 .4216 Mdot
.38796 .68663 Mdot
.64997 .51358 Mdot
.65601 .47474 Mdot
.65159 .54063 Mdot
.65944 .48336 Mdot
.68634 .4185 Mdot
.6171 .44815 Mdot
.66503 .33013 Mdot
.6139 .50362 Mdot
.70962 .58256 Mdot
.32462 .45636 Mdot
.56686 .48125 Mdot
.44058 .60728 Mdot
.66763 .4782 Mdot
.54209 .25751 Mdot
.32289 .46897 Mdot
.44969 .31105 Mdot
.31495 .46158 Mdot
.35188 .68247 Mdot
.27693 .4485 Mdot
.62754 .52447 Mdot
.5411 .32613 Mdot
.35171 .64734 Mdot
.51802 .40092 Mdot
.35842 .62385 Mdot
.62851 .49105 Mdot
.28113 .50727 Mdot
.36471 .69125 Mdot
.59998 .44447 Mdot
.54252 .32894 Mdot
.68749 .63197 Mdot
.48457 .33499 Mdot
.62951 .50031 Mdot
.62885 .5057 Mdot
.40889 .40407 Mdot
.27006 .45718 Mdot
.51953 .29402 Mdot
.35713 .76992 Mdot
.49651 .70534 Mdot
.53392 .34029 Mdot
.55685 .48449 Mdot
.47742 .50474 Mdot
.51913 .30523 Mdot
.71408 .61176 Mdot
.27298 .46767 Mdot
.5017 .34716 Mdot
.67991 .53996 Mdot
.6229 .37311 Mdot
.51792 .73047 Mdot
.35997 .69615 Mdot
.51428 .56221 Mdot
.36545 .63939 Mdot
.2832 .49318 Mdot
.39635 .65925 Mdot
.32184 .45635 Mdot
.53587 .43269 Mdot
.4382 .5771 Mdot
.32418 .47878 Mdot
.24977 .46487 Mdot
.37292 .65716 Mdot
.66161 .53549 Mdot
.40963 .54591 Mdot
.57599 .5605 Mdot
.57401 .49309 Mdot
.3281 .44379 Mdot
.51251 .35554 Mdot
.5408 .29212 Mdot
.63632 .60392 Mdot
.5419 .30321 Mdot
.34925 .65528 Mdot
.47926 .42357 Mdot
.75181 .48437 Mdot
.29318 .46913 Mdot
.42525 .61512 Mdot
.62825 .55315 Mdot
.38029 .66216 Mdot
.34646 .65935 Mdot
.30605 .441 Mdot
.61437 .352 Mdot
.57547 .49552 Mdot
.53003 .36901 Mdot
.49915 .33633 Mdot
.51681 .3066 Mdot
.49567 .31323 Mdot
.64682 .7614 Mdot
.33081 .46934 Mdot
.52551 .35732 Mdot
.65351 .54901 Mdot
.62583 .47594 Mdot
.4246 .4282 Mdot
.55011 .70964 Mdot
.69008 .49187 Mdot
.57385 .55678 Mdot
.65776 .51037 Mdot
.3788 .68107 Mdot
.53969 .48043 Mdot
.4328 .41559 Mdot
.39525 .6503 Mdot
.39369 .65813 Mdot
.40923 .427 Mdot
.54117 .43353 Mdot
.47469 .18343 Mdot
.65365 .53566 Mdot
.51044 .24558 Mdot
.37874 .6758 Mdot
.54717 .62204 Mdot
.69876 .5807 Mdot
.59327 .53689 Mdot
.37364 .55673 Mdot
.35447 .6615 Mdot
.56404 .36493 Mdot
.64746 .50991 Mdot
.40377 .41411 Mdot
.50915 .72104 Mdot
.54448 .51525 Mdot
.40083 .42749 Mdot
.5214 .34431 Mdot
.30578 .7242 Mdot
.54719 .36206 Mdot
.35908 .69317 Mdot
.56877 .53127 Mdot
.56654 .90663 Mdot
.35486 .67607 Mdot
.37847 .35371 Mdot
.43743 .57999 Mdot
.63084 .484 Mdot
.35302 .64119 Mdot
.56453 .29826 Mdot
.33412 .44805 Mdot
.48075 .52393 Mdot
.53403 .35031 Mdot
.40081 .41425 Mdot
.42011 .42829 Mdot
.3675 .66208 Mdot
.50153 .32339 Mdot
.64271 .56574 Mdot
.54795 .31742 Mdot
.28143 .46602 Mdot
.61745 .5294 Mdot
.43383 .22802 Mdot
.57441 .48304 Mdot
.5462 .31671 Mdot
.33615 .63367 Mdot
.55933 .72554 Mdot
.60296 .50789 Mdot
.45155 .27726 Mdot
.65755 .47938 Mdot
.30732 .46847 Mdot
.49782 .61734 Mdot
.6304 .26162 Mdot
.66445 .52069 Mdot
.62523 .55225 Mdot
.28896 .48868 Mdot
.66239 .52164 Mdot
.58779 .53831 Mdot
.38814 .44476 Mdot
.52226 .3044 Mdot
.65582 .48683 Mdot
.36979 .63702 Mdot
.65985 .24691 Mdot
.6332 .52464 Mdot
.32473 .40509 Mdot
.66752 .63335 Mdot
.4767 .59117 Mdot
.5655 .54844 Mdot
.59822 .67878 Mdot
.63293 .50764 Mdot
.58999 .53157 Mdot
.65804 .53503 Mdot
.74844 .42875 Mdot
.36855 .65376 Mdot
.38728 .65062 Mdot
.50447 .71486 Mdot
.64706 .63411 Mdot
.51891 .70014 Mdot
.28996 .48779 Mdot
.42626 .61872 Mdot
.42437 .40805 Mdot
.51947 .3354 Mdot
.6357 .52538 Mdot
.36128 .62509 Mdot
.65467 .50272 Mdot
.61136 .54015 Mdot
.35442 .65398 Mdot
.34883 .66212 Mdot
.34446 .70226 Mdot
.52049 .7348 Mdot
.52852 .33174 Mdot
.64429 .53285 Mdot
.5465 .73378 Mdot
.67679 .53007 Mdot
.45131 .49105 Mdot
.53028 .33241 Mdot
.54586 .31418 Mdot
.55166 .30078 Mdot
.61064 .48904 Mdot
.62434 .52559 Mdot
.32579 .45031 Mdot
.56141 .29807 Mdot
.28564 .44641 Mdot
.35473 .64031 Mdot
.38064 .65713 Mdot
.64975 .51434 Mdot
.67073 .57044 Mdot
.5448 .70184 Mdot
.34071 .6788 Mdot
.42877 .43324 Mdot
.50493 .7109 Mdot
.67041 .48993 Mdot
.36018 .63887 Mdot
.511 .68991 Mdot
.58065 .26166 Mdot
.40964 .21289 Mdot
.51724 .73498 Mdot
.66588 .53221 Mdot
.76841 .36484 Mdot
.62753 .72554 Mdot
.49422 .70679 Mdot
.31347 .46871 Mdot
.63826 .47653 Mdot
.22771 .49876 Mdot
.55756 .70321 Mdot
.63629 .74878 Mdot
.35692 .65017 Mdot
.56406 .5634 Mdot
.54562 .48476 Mdot
.74897 .47799 Mdot
.56271 .71533 Mdot
.54532 .31838 Mdot
.49757 .32301 Mdot
.66912 .51707 Mdot
.42728 .60524 Mdot
.30649 .48914 Mdot
.33821 .68263 Mdot
.38429 .63725 Mdot
.51077 .30624 Mdot
.47316 .44414 Mdot
.36752 .63686 Mdot
.58954 .50091 Mdot
.52772 .67501 Mdot
.63919 .44005 Mdot
.66471 .76928 Mdot
.6337 .2151 Mdot
.56399 .54522 Mdot
.55635 .73001 Mdot
.26634 .46008 Mdot
.3152 .44421 Mdot
.31429 .44845 Mdot
.3791 .65387 Mdot
.50816 .53031 Mdot
.37686 .6333 Mdot
.28994 .39228 Mdot
.53679 .70017 Mdot
.71119 .63677 Mdot
.67992 .53418 Mdot
.62957 .48485 Mdot
.62909 .55808 Mdot
.64946 .54191 Mdot
.63412 .50661 Mdot
.3208 .4391 Mdot
.33981 .69077 Mdot
.19604 .53999 Mdot
.50692 .32233 Mdot
.28226 .35394 Mdot
.36437 .68866 Mdot
.40644 .43252 Mdot
.53981 .71998 Mdot
.61796 .65846 Mdot
.52491 .67173 Mdot
.34339 .68408 Mdot
.59643 .48721 Mdot
.49455 .34149 Mdot
.78495 .56733 Mdot
.61978 .50553 Mdot
.33731 .67484 Mdot
.39983 .67519 Mdot
.61733 .34296 Mdot
.70511 .49687 Mdot
.42018 .60376 Mdot
.48198 .50429 Mdot
.52521 .73922 Mdot
.62711 .46494 Mdot
.55891 .61685 Mdot
.36462 .65481 Mdot
.36542 .67963 Mdot
.49429 .71174 Mdot
.58519 .40646 Mdot
.51454 .35089 Mdot
.41691 .40224 Mdot
.31353 .47191 Mdot
.61683 .48993 Mdot
.37565 .65 Mdot
.5543 .38073 Mdot
.45166 .5146 Mdot
.3074 .46133 Mdot
.39622 .64978 Mdot
.65296 .47695 Mdot
.66721 .516 Mdot
.52624 .69937 Mdot
.38306 .73241 Mdot
.57566 .5602 Mdot
.38949 .35119 Mdot
.48833 .4671 Mdot
.43613 .58781 Mdot
.65847 .50186 Mdot
.5373 .29533 Mdot
.40868 .42517 Mdot
.52301 .72496 Mdot
.6826 .50822 Mdot
.45198 .18866 Mdot
.55471 .35521 Mdot
.29224 .4446 Mdot
.40455 .42324 Mdot
.53097 .56577 Mdot
.65721 .47976 Mdot
.64213 .51635 Mdot
.66358 .54367 Mdot
.45459 .18376 Mdot
.37826 .63783 Mdot
.51203 .29771 Mdot
.51722 .69769 Mdot
.55072 .3206 Mdot
.38915 .67562 Mdot
.42541 .58923 Mdot
.67607 .51829 Mdot
.55363 .35019 Mdot
.54882 .32899 Mdot
.29594 .46788 Mdot
.27011 .47147 Mdot
.3335 .6949 Mdot
.65617 .48192 Mdot
.41786 .40506 Mdot
.51677 .35519 Mdot
.33335 .67996 Mdot
.52639 .70013 Mdot
.33849 .4794 Mdot
.61308 .50253 Mdot
.36794 .6593 Mdot
.57181 .54946 Mdot
.51781 .31552 Mdot
.35127 .68745 Mdot
.39734 .4271 Mdot
.55054 .71366 Mdot
.64384 .47206 Mdot
.20191 .58604 Mdot
.40176 .41823 Mdot
.6055 .49836 Mdot
.62427 .21589 Mdot
.42749 .60311 Mdot
.51804 .3949 Mdot
.35714 .6319 Mdot
.41424 .40727 Mdot
.50352 .30467 Mdot
.63804 .3782 Mdot
.36672 .67601 Mdot
.75893 .3267 Mdot
.42771 .52973 Mdot
.64969 .53619 Mdot
.52605 .34847 Mdot
.49537 .67663 Mdot
.39574 .33796 Mdot
.61876 .72373 Mdot
.64366 .49199 Mdot
.3665 .63974 Mdot
.50905 .71977 Mdot
.28366 .45084 Mdot
.3161 .40572 Mdot
.70038 .75109 Mdot
.39223 .64424 Mdot
.63896 .52759 Mdot
.50987 .35371 Mdot
.29782 .44375 Mdot
.75466 .31108 Mdot
.32726 .65259 Mdot
.35728 .63412 Mdot
.61758 .55601 Mdot
.51467 .70211 Mdot
.2321 .50003 Mdot
.38395 .64561 Mdot
.34552 .69504 Mdot
.41118 .4474 Mdot
.50462 .71961 Mdot
.66033 .54387 Mdot
.63714 .60399 Mdot
.6527 .5572 Mdot
.32337 .36599 Mdot
.41492 .40649 Mdot
.50686 .32506 Mdot
.63252 .51694 Mdot
.19221 .57025 Mdot
.36135 .67316 Mdot
.48365 .50215 Mdot
.33304 .42299 Mdot
.27029 .4709 Mdot
.36658 .64438 Mdot
.64988 .5027 Mdot
.34688 .45267 Mdot
.53792 .69657 Mdot
.66751 .54086 Mdot
.62749 .52797 Mdot
.55841 .29082 Mdot
.28553 .47223 Mdot
.65684 .24221 Mdot
.27793 .45719 Mdot
.31131 .48271 Mdot
.53671 .28021 Mdot
.66977 .51567 Mdot
.3482 .68367 Mdot
.32985 .63678 Mdot
.60174 .56657 Mdot
.54528 .6218 Mdot
.5185 .35113 Mdot
.3129 .65716 Mdot
.43456 .18632 Mdot
.6102 .55954 Mdot
.4223 .43511 Mdot
.58646 .31116 Mdot
.33894 .45045 Mdot
.65551 .52791 Mdot
.51746 .3276 Mdot
.3292 .68528 Mdot
.3739 .64278 Mdot
.68701 .47718 Mdot
.30765 .44027 Mdot
.51586 .68744 Mdot
.34443 .65971 Mdot
.44005 .50164 Mdot
.63402 .49077 Mdot
.43917 .40843 Mdot
.3427 .66111 Mdot
.67812 .22038 Mdot
.18974 .55712 Mdot
.51133 .30859 Mdot
.60228 .53976 Mdot
.50116 .35312 Mdot
.52166 .69288 Mdot
.39463 .67462 Mdot
.32076 .44391 Mdot
.68303 .43975 Mdot
.312 .75077 Mdot
.377 .65659 Mdot
.5242 .3405 Mdot
.64156 .52741 Mdot
.71815 .55455 Mdot
.64137 .48019 Mdot
.71809 .69638 Mdot
.50727 .68742 Mdot
.25955 .48446 Mdot
.29786 .43816 Mdot
.61877 .54967 Mdot
.54726 .73096 Mdot
.31987 .6608 Mdot
.35573 .65384 Mdot
.35533 .81644 Mdot
.39961 .42705 Mdot
.32342 .70421 Mdot
.6106 .49011 Mdot
.33057 .67107 Mdot
.76752 .37445 Mdot
.29064 .44099 Mdot
.6419 .56361 Mdot
.37674 .62311 Mdot
.3268 .34439 Mdot
.47838 .50676 Mdot
.63834 .49076 Mdot
.6954 .55183 Mdot
.31488 .46468 Mdot
.27693 .31795 Mdot
.35594 .63084 Mdot
.67553 .53006 Mdot
.34632 .43649 Mdot
.51856 .42258 Mdot
.36284 .76702 Mdot
.5288 .33136 Mdot
.36659 .61715 Mdot
.31108 .47924 Mdot
.5615 .55654 Mdot
.54726 .70232 Mdot
.32248 .67381 Mdot
.3659 .62159 Mdot
.61321 .53228 Mdot
.68629 .4854 Mdot
.70067 .53893 Mdot
.52075 .34787 Mdot
.29419 .48227 Mdot
.62477 .54546 Mdot
.46061 .48346 Mdot
.64528 .54228 Mdot
.30274 .48235 Mdot
.47125 .91208 Mdot
.61166 .47752 Mdot
.61367 .49849 Mdot
.74898 .51515 Mdot
.52307 .29285 Mdot
.53024 .30282 Mdot
.47581 .47057 Mdot
.61339 .48382 Mdot
.42185 .51564 Mdot
.52629 .33219 Mdot
.5317 .34752 Mdot
.42172 .51853 Mdot
.6139 .52592 Mdot
.36446 .46012 Mdot
.29992 .44359 Mdot
.27068 .47177 Mdot
.52723 .30558 Mdot
.65774 .44527 Mdot
.26483 .46577 Mdot
.68593 .41263 Mdot
.34999 .68824 Mdot
.55951 .61663 Mdot
.54885 .31952 Mdot
.46887 .53436 Mdot
.27141 .46158 Mdot
.75938 .29086 Mdot
.77884 .55604 Mdot
.61703 .5667 Mdot
.66653 .52039 Mdot
.52286 .71069 Mdot
.71751 .4955 Mdot
.41352 .43106 Mdot
.31117 .44489 Mdot
.30713 .54321 Mdot
.53371 .3286 Mdot
.62295 .48045 Mdot
.60767 .72126 Mdot
.65403 .22033 Mdot
.62524 .60999 Mdot
.53804 .34575 Mdot
.5378 .32838 Mdot
.34121 .64006 Mdot
.34608 .68754 Mdot
.67317 .52272 Mdot
.32077 .45 Mdot
.49811 .33849 Mdot
.29038 .47848 Mdot
.36316 .65379 Mdot
.35567 .68772 Mdot
.43357 .42183 Mdot
.58187 .48451 Mdot
.3646 .64685 Mdot
.2722 .41157 Mdot
.45913 .48415 Mdot
.55339 .28835 Mdot
.19397 .46501 Mdot
.78308 .33296 Mdot
.71726 .46746 Mdot
.50979 .72197 Mdot
.53157 .43283 Mdot
.28043 .43918 Mdot
.62213 .55058 Mdot
.64841 .52121 Mdot
.42587 .41887 Mdot
.27444 .44346 Mdot
.5335 .71921 Mdot
.27038 .45479 Mdot
.53187 .72742 Mdot
.38744 .65538 Mdot
.62774 .51999 Mdot
.67384 .48849 Mdot
.28702 .45078 Mdot
.33437 .65375 Mdot
.3661 .69095 Mdot
.52812 .73322 Mdot
.6215 .64789 Mdot
.36601 .66106 Mdot
.54919 .32005 Mdot
.6853 .27563 Mdot
.42187 .42736 Mdot
.64696 .50927 Mdot
.60309 .68554 Mdot
.65519 .37614 Mdot
.64561 .53852 Mdot
.40324 .42184 Mdot
.30635 .80152 Mdot
.62967 .5226 Mdot
.48266 .85984 Mdot
.42901 .41285 Mdot
.54411 .29683 Mdot
.33796 .66105 Mdot
.4002 .42516 Mdot
.53711 .49015 Mdot
.31009 .64795 Mdot
.57697 .54841 Mdot
.51693 .35265 Mdot
.55745 .32958 Mdot
.42435 .57397 Mdot
.32073 .36572 Mdot
.5149 .69885 Mdot
.54061 .71173 Mdot
.36833 .67317 Mdot
.24281 .42938 Mdot
.6809 .46486 Mdot
.53822 .71303 Mdot
.30505 .52061 Mdot
.62596 .55364 Mdot
.42789 .5974 Mdot
.40164 .54211 Mdot
.52572 .29617 Mdot
.56687 .47797 Mdot
.36472 .67383 Mdot
.52491 .34004 Mdot
.4166 .55427 Mdot
.63788 .56219 Mdot
.53173 .33125 Mdot
.28406 .48029 Mdot
.40429 .49529 Mdot
.54682 .3102 Mdot
.47573 .52281 Mdot
.29508 .44904 Mdot
.42614 .60223 Mdot
.69602 .66707 Mdot
.52757 .13487 Mdot
.31621 .44619 Mdot
.33497 .66515 Mdot
.37521 .65194 Mdot
.36332 .66384 Mdot
.52988 .35167 Mdot
.34977 .66775 Mdot
.50623 .33703 Mdot
.25383 .45829 Mdot
.61108 .65501 Mdot
.52747 .70521 Mdot
.49491 .75696 Mdot
.53862 .31543 Mdot
.30799 .38408 Mdot
.16856 .48925 Mdot
.65981 .54203 Mdot
.32368 .47847 Mdot
.545 .7362 Mdot
.49655 .45411 Mdot
.52389 .71334 Mdot
.33651 .66078 Mdot
.56137 .61574 Mdot
.65047 .49195 Mdot
.5197 .2345 Mdot
.50832 .71722 Mdot
.53644 .34821 Mdot
.59881 .51414 Mdot
.33668 .62185 Mdot
.53001 .69128 Mdot
.51639 .72773 Mdot
.6363 .50717 Mdot
.55563 .32535 Mdot
.34669 .68437 Mdot
.28747 .43507 Mdot
.49376 .6864 Mdot
.70035 .54904 Mdot
.66305 .53035 Mdot
.60234 .48121 Mdot
.48613 .49162 Mdot
.20935 .47646 Mdot
.29859 .4502 Mdot
.62849 .74581 Mdot
.38114 .66009 Mdot
.62085 .72691 Mdot
.41118 .35328 Mdot
.55023 .67501 Mdot
.41755 .40687 Mdot
.41453 .40608 Mdot
.63552 .49607 Mdot
.19141 .40735 Mdot
.66859 .61108 Mdot
.32005 .42433 Mdot
.42162 .42435 Mdot
.36237 .69225 Mdot
.56784 .32931 Mdot
.57581 .4397 Mdot
.68711 .52026 Mdot
.27474 .44146 Mdot
.36027 .65724 Mdot
.20275 .37187 Mdot
.53589 .70077 Mdot
.49229 .45507 Mdot
.6586 .48411 Mdot
.64103 .49996 Mdot
.29917 .45982 Mdot
.32321 .44766 Mdot
.4348 .4409 Mdot
.475 .57556 Mdot
.44284 .22418 Mdot
.2664 .47984 Mdot
.20201 .37184 Mdot
.53462 .23218 Mdot
.52634 .30984 Mdot
.42052 .43458 Mdot
.28062 .48298 Mdot
.63437 .51598 Mdot
.54135 .29444 Mdot
.63665 .61596 Mdot
.56138 .37056 Mdot
.42947 .59723 Mdot
.43778 .51374 Mdot
.66357 .48504 Mdot
.49089 .32924 Mdot
.52734 .33849 Mdot
.48875 .32765 Mdot
.41209 .42702 Mdot
.65959 .506 Mdot
.65986 .53856 Mdot
.63047 .52408 Mdot
.72407 .54103 Mdot
.63084 .49494 Mdot
.40902 .34953 Mdot
.46107 .47183 Mdot
.42274 .75044 Mdot
.61673 .50874 Mdot
.29784 .48486 Mdot
.62737 .51826 Mdot
.55263 .72487 Mdot
.63224 .47196 Mdot
.43051 .59843 Mdot
.3089 .45049 Mdot
.59847 .39231 Mdot
.36564 .6013 Mdot
.67628 .49824 Mdot
.51328 .69304 Mdot
.20175 .46031 Mdot
.61402 .7399 Mdot
.40091 .44721 Mdot
.548 .31792 Mdot
.3548 .69892 Mdot
.33791 .46652 Mdot
.35429 .68455 Mdot
.63575 .5666 Mdot
.43333 .42755 Mdot
.846 .48162 Mdot
.47166 .54467 Mdot
.63245 .51579 Mdot
.58302 .48426 Mdot
.5324 .29611 Mdot
.35823 .67346 Mdot
.47077 .33762 Mdot
.62923 .55645 Mdot
.54515 .69296 Mdot
.5589 .71917 Mdot
.39004 .58004 Mdot
.38023 .49768 Mdot
.76839 .51267 Mdot
.30002 .45792 Mdot
.37845 .64872 Mdot
.56178 .71099 Mdot
.55821 .26982 Mdot
.30734 .48843 Mdot
.339 .44976 Mdot
.28745 .4734 Mdot
.62683 .48934 Mdot
.43048 .42493 Mdot
.34565 .52722 Mdot
.39948 .42078 Mdot
.6455 .5556 Mdot
.36815 .62222 Mdot
.39791 .42101 Mdot
.51888 .70548 Mdot
.31866 .47749 Mdot
.37379 .68528 Mdot
.62751 .50358 Mdot
.52577 .32572 Mdot
.61603 .77733 Mdot
.19336 .61603 Mdot
.42679 .60682 Mdot
.42675 .60695 Mdot
.558 .31525 Mdot
.47098 .24318 Mdot
.29752 .49585 Mdot
.62038 .35619 Mdot
.55648 .64977 Mdot
.59616 .56454 Mdot
.38591 .80614 Mdot
.37338 .63174 Mdot
.35045 .64872 Mdot
.64585 .48632 Mdot
.32803 .66774 Mdot
.63386 .47889 Mdot
.35095 .63297 Mdot
.3705 .3414 Mdot
.68394 .52973 Mdot
.34959 .65347 Mdot
.70263 .48031 Mdot
.60334 .50679 Mdot
.54074 .29787 Mdot
.3237 .67582 Mdot
.61644 .56625 Mdot
.84378 .53916 Mdot
.29159 .46525 Mdot
.41316 .42748 Mdot
.43378 .6132 Mdot
.27441 .45209 Mdot
.50582 .3427 Mdot
.61236 .48232 Mdot
.53454 .69666 Mdot
.53176 .31153 Mdot
.34135 .61456 Mdot
.50872 .71227 Mdot
.47769 .42513 Mdot
.52773 .30716 Mdot
.4269 .42389 Mdot
.55002 .71709 Mdot
.57731 .5484 Mdot
.35257 .6492 Mdot
.19059 .58183 Mdot
.40167 .42472 Mdot
.65329 .49504 Mdot
.36798 .61632 Mdot
.27056 .45507 Mdot
.67433 .51049 Mdot
.37563 .64774 Mdot
.40704 .42585 Mdot
.60762 .50494 Mdot
.60477 .49291 Mdot
.59876 .40891 Mdot
.50049 .6319 Mdot
.52408 .70445 Mdot
.52591 .27943 Mdot
.65281 .5501 Mdot
.54282 .73325 Mdot
.21469 .57838 Mdot
.66753 .55021 Mdot
.53713 .36081 Mdot
.63842 .3978 Mdot
.33325 .67498 Mdot
.29386 .43962 Mdot
.32646 .64789 Mdot
.50564 .70421 Mdot
.16223 .62374 Mdot
.41922 .43345 Mdot
.58328 .49741 Mdot
.59481 .54822 Mdot
.39651 .6748 Mdot
.52986 .33883 Mdot
.45185 .22448 Mdot
.63318 .4728 Mdot
.57133 .49489 Mdot
.64191 .50897 Mdot
.21091 .59069 Mdot
.5251 .35048 Mdot
.6447 .51002 Mdot
.69795 .55679 Mdot
.612 .55774 Mdot
.52125 .68778 Mdot
.72596 .62792 Mdot
.63864 .53459 Mdot
.63466 .87839 Mdot
.43498 .4142 Mdot
.35493 .65718 Mdot
.47839 .51495 Mdot
.43702 .64758 Mdot
.63765 .79514 Mdot
.51106 .34527 Mdot
.52623 .24768 Mdot
.35123 .68502 Mdot
.5943 .79159 Mdot
.47072 .25274 Mdot
.59962 .50195 Mdot
.64379 .47576 Mdot
.3365 .6609 Mdot
.33619 .68368 Mdot
.437 .42295 Mdot
.67918 .48488 Mdot
.57988 .47373 Mdot
.34216 .62858 Mdot
.62143 .5005 Mdot
.6596 .35539 Mdot
.3351 .43906 Mdot
.52686 .30463 Mdot
.28315 .45237 Mdot
.3348 .44348 Mdot
.68655 .43413 Mdot
.4897 .46927 Mdot
.32232 .46512 Mdot
.31863 .42745 Mdot
.47641 .72143 Mdot
.75006 .49546 Mdot
.52411 .68715 Mdot
.39061 .46318 Mdot
.36913 .66771 Mdot
.65968 .50892 Mdot
.53291 .3528 Mdot
.76779 .66779 Mdot
.38278 .24006 Mdot
.56695 .60516 Mdot
.65411 .54564 Mdot
.36274 .67073 Mdot
.40313 .42435 Mdot
.67681 .54153 Mdot
.62523 .72581 Mdot
.64243 .49504 Mdot
.34448 .68827 Mdot
.7516 .48366 Mdot
.35978 .41844 Mdot
.26805 .48213 Mdot
.56607 .34873 Mdot
.63064 .5212 Mdot
.51263 .32945 Mdot
.32804 .45951 Mdot
.52782 .736 Mdot
.53063 .7123 Mdot
.6748 .4926 Mdot
.4378 .57663 Mdot
.49764 .66935 Mdot
.60006 .50384 Mdot
.61455 .53086 Mdot
.41861 .40771 Mdot
.61535 .53069 Mdot
.67837 .5205 Mdot
.62804 .54628 Mdot
.68441 .51617 Mdot
.296 .4885 Mdot
.48657 .3786 Mdot
.67111 .47489 Mdot
.58817 .54512 Mdot
.31065 .43178 Mdot
.65178 .57109 Mdot
.3166 .45929 Mdot
.40684 .2335 Mdot
.31679 .46931 Mdot
.53032 .71092 Mdot
.35709 .61525 Mdot
.51094 .25193 Mdot
.49802 .33729 Mdot
.29572 .48603 Mdot
.54437 .72057 Mdot
.31471 .44684 Mdot
.37926 .64404 Mdot
.19191 .49931 Mdot
.49407 .29351 Mdot
.44797 .4782 Mdot
.75044 .50491 Mdot
.43938 .4074 Mdot
.32999 .65759 Mdot
.50838 .31103 Mdot
.35016 .41516 Mdot
.61737 .54829 Mdot
.52856 .69609 Mdot
.6361 .49665 Mdot
.31936 .47806 Mdot
.36511 .66906 Mdot
.3701 .4548 Mdot
.52353 .70524 Mdot
.17151 .61588 Mdot
.35803 .62531 Mdot
.58189 .51936 Mdot
.31104 .43213 Mdot
.19851 .48986 Mdot
.31865 .46292 Mdot
.61233 .65587 Mdot
.58101 .36651 Mdot
.74493 .69415 Mdot
.53823 .32203 Mdot
.44289 .4259 Mdot
.54625 .181 Mdot
.43706 .31526 Mdot
.523 .31787 Mdot
.36919 .6005 Mdot
.62653 .49365 Mdot
.64466 .54413 Mdot
.60366 .4689 Mdot
.52891 .38312 Mdot
.66277 .54404 Mdot
.41787 .4311 Mdot
.48334 .47455 Mdot
.26742 .52058 Mdot
.3481 .69824 Mdot
.63974 .47886 Mdot
.32764 .44312 Mdot
.30727 .48635 Mdot
.39843 .41635 Mdot
.27775 .46389 Mdot
.60978 .51512 Mdot
.53842 .31678 Mdot
.41084 .54717 Mdot
.52217 .69326 Mdot
.39093 .36156 Mdot
.54282 .65029 Mdot
.50659 .67518 Mdot
.61263 .55923 Mdot
.35431 .68766 Mdot
.33171 .77576 Mdot
.63179 .55068 Mdot
.52494 .33451 Mdot
.59201 .54407 Mdot
.63205 .54287 Mdot
.64013 .53169 Mdot
.37869 .65015 Mdot
.47325 .51284 Mdot
.62061 .50181 Mdot
.32311 .46535 Mdot
.4226 .52124 Mdot
.68985 .50909 Mdot
.31723 .54799 Mdot
.43046 .59682 Mdot
.43749 .40699 Mdot
.55591 .29019 Mdot
.34298 .67747 Mdot
.53515 .32694 Mdot
.50932 .37352 Mdot
.50532 .34198 Mdot
.31998 .53266 Mdot
.62381 .37069 Mdot
.50985 .86279 Mdot
.76972 .38937 Mdot
.75646 .48713 Mdot
.54004 .36681 Mdot
.25473 .57293 Mdot
.5194 .32023 Mdot
.50737 .34332 Mdot
.40445 .87545 Mdot
.5405 .35555 Mdot
.65086 .5139 Mdot
.63786 .46849 Mdot
.53264 .22082 Mdot
.4807 .7275 Mdot
.60986 .49295 Mdot
.66699 .53776 Mdot
.56107 .71459 Mdot
.57291 .40809 Mdot
.439 .42412 Mdot
.48821 .45315 Mdot
.41597 .43786 Mdot
.63565 .50653 Mdot
.66842 .49028 Mdot
.67832 .47156 Mdot
.57898 .17087 Mdot
.73618 .71343 Mdot
.55515 .31068 Mdot
.63175 .57935 Mdot
.40045 .40175 Mdot
.58716 .5285 Mdot
.59879 .55051 Mdot
.62916 .5259 Mdot
.34852 .68399 Mdot
.56685 .32413 Mdot
.57511 .55889 Mdot
.42552 .37746 Mdot
.66189 .48519 Mdot
.53569 .65759 Mdot
.51776 .73881 Mdot
.65058 .50376 Mdot
.54411 .35532 Mdot
.64982 .54483 Mdot
.50268 .35246 Mdot
.52258 .30743 Mdot
.58656 .4741 Mdot
.35606 .52031 Mdot
.56622 .34019 Mdot
.59998 .50009 Mdot
.33285 .65578 Mdot
.38539 .35182 Mdot
.65307 .49688 Mdot
.5136 .70669 Mdot
.65517 .52898 Mdot
.51503 .68967 Mdot
.62306 .53148 Mdot
.39977 .41774 Mdot
.62795 .26714 Mdot
.36736 .67813 Mdot
.49364 .68375 Mdot
.32926 .66667 Mdot
.60007 .44688 Mdot
.53263 .36478 Mdot
.37152 .43092 Mdot
.71379 .74221 Mdot
.42026 .40829 Mdot
.63097 .75589 Mdot
.41484 .51422 Mdot
.31173 .43543 Mdot
.4987 .30896 Mdot
.74134 .47461 Mdot
.34083 .55161 Mdot
.36932 .69962 Mdot
.39321 .66482 Mdot
.37251 .77482 Mdot
.31106 .79435 Mdot
.61748 .50096 Mdot
.22657 .50014 Mdot
.66125 .31777 Mdot
.72117 .51855 Mdot
.69954 .51795 Mdot
.3598 .6211 Mdot
.60915 .49358 Mdot
.50296 .55031 Mdot
.3724 .65641 Mdot
.54464 .71039 Mdot
.50729 .32661 Mdot
.54203 .73008 Mdot
.35176 .24142 Mdot
.39408 .44537 Mdot
.36803 .65041 Mdot
.68627 .51167 Mdot
.62232 .4853 Mdot
.51022 .29771 Mdot
.76092 .32459 Mdot
.52332 .3042 Mdot
.51478 .69697 Mdot
.37667 .66991 Mdot
.79555 .57445 Mdot
.64963 .53048 Mdot
.54829 .33429 Mdot
.36676 .60154 Mdot
.66671 .51523 Mdot
.29897 .43932 Mdot
.65174 .5471 Mdot
.55016 .33146 Mdot
.61593 .531 Mdot
.53669 .31741 Mdot
.34323 .64019 Mdot
.67121 .48426 Mdot
.67159 .49368 Mdot
.63319 .74932 Mdot
.53137 .71936 Mdot
.53816 .3641 Mdot
.50471 .5504 Mdot
.6527 .55709 Mdot
.62625 .7177 Mdot
.62827 .5207 Mdot
.73675 .52926 Mdot
.67195 .55525 Mdot
.42092 .43086 Mdot
.59724 .55033 Mdot
.65198 .49617 Mdot
.77957 .3689 Mdot
.76715 .36858 Mdot
.73545 .49427 Mdot
.27057 .47242 Mdot
.55157 .33977 Mdot
.37323 .6498 Mdot
.33318 .68977 Mdot
.34731 .67079 Mdot
.50934 .74434 Mdot
.64487 .58018 Mdot
.65447 .49144 Mdot
.24792 .46426 Mdot
.53886 .70898 Mdot
.54302 .34206 Mdot
.53251 .70692 Mdot
.4932 .4688 Mdot
.51187 .71162 Mdot
.41458 .43213 Mdot
.18989 .55276 Mdot
.66023 .36985 Mdot
.5197 .72155 Mdot
.52308 .30509 Mdot
.42765 .50101 Mdot
.58921 .56138 Mdot
.30039 .35816 Mdot
.54635 .69392 Mdot
.34974 .77023 Mdot
.61029 .50708 Mdot
.48517 .52456 Mdot
.31256 .46206 Mdot
.54215 .72965 Mdot
.28686 .47182 Mdot
.64804 .54505 Mdot
.49797 .3874 Mdot
.52169 .33915 Mdot
.33194 .4378 Mdot
.61623 .55744 Mdot
.54315 .72945 Mdot
.3631 .64817 Mdot
.75062 .4901 Mdot
.30807 .42945 Mdot
.60992 .77921 Mdot
.61901 .72502 Mdot
.37769 .66713 Mdot
.76663 .48894 Mdot
.302 .47345 Mdot
.60127 .56745 Mdot
.55636 .5572 Mdot
.64009 .55174 Mdot
.36988 .68979 Mdot
.34883 .64939 Mdot
.45223 .34823 Mdot
.66819 .48686 Mdot
.66261 .46915 Mdot
.56136 .30918 Mdot
.38136 .66445 Mdot
.50451 .34231 Mdot
.50698 .30384 Mdot
.33565 .65992 Mdot
.51163 .30752 Mdot
.50976 .71913 Mdot
.51425 .53198 Mdot
.30548 .47327 Mdot
.30457 .43858 Mdot
.36666 .64779 Mdot
.38626 .66597 Mdot
.35696 .68861 Mdot
.62003 .5551 Mdot
.50131 .32101 Mdot
.60008 .5362 Mdot
.63469 .52383 Mdot
.57557 .30193 Mdot
.55314 .29479 Mdot
.60007 .54523 Mdot
.39676 .54016 Mdot
.52634 .68342 Mdot
.34967 .65641 Mdot
.28728 .47883 Mdot
.62704 .77823 Mdot
.30842 .43339 Mdot
.65533 .55421 Mdot
.32605 .34747 Mdot
.5307 .35102 Mdot
.52316 .71224 Mdot
.42866 .605 Mdot
.52269 .70757 Mdot
.33434 .43915 Mdot
.54255 .28607 Mdot
.47539 .43587 Mdot
.66843 .48559 Mdot
.48649 .48842 Mdot
.6707 .69732 Mdot
.41595 .35776 Mdot
.29143 .48239 Mdot
.6599 .5428 Mdot
.42625 .41121 Mdot
.61854 .34204 Mdot
.65194 .48927 Mdot
.63819 .56491 Mdot
.4298 .68191 Mdot
.59882 .55364 Mdot
.53274 .28407 Mdot
.43018 .5832 Mdot
.68262 .49919 Mdot
.60366 .44642 Mdot
.35356 .8268 Mdot
.6069 .50199 Mdot
.67311 .4938 Mdot
.65453 .51855 Mdot
.61933 .55101 Mdot
.50411 .35606 Mdot
.3852 .7194 Mdot
.33027 .44852 Mdot
.51444 .53292 Mdot
.29407 .47513 Mdot
.35722 .64205 Mdot
.49205 .56065 Mdot
.5022 .35307 Mdot
.52202 .70751 Mdot
.22125 .50012 Mdot
.55593 .60792 Mdot
.33901 .64225 Mdot
.66319 .75878 Mdot
.5365 .68871 Mdot
.5902 .56227 Mdot
.50376 .71333 Mdot
.36536 .61985 Mdot
.30923 .44093 Mdot
.59698 .48683 Mdot
.51289 .3526 Mdot
.54668 .31062 Mdot
.65172 .54883 Mdot
.38515 .36619 Mdot
.27462 .44873 Mdot
.57723 .73666 Mdot
.63187 .48692 Mdot
.64322 .56346 Mdot
.51984 .30383 Mdot
.35876 .67218 Mdot
.4163 .51541 Mdot
.53689 .72215 Mdot
.59233 .49537 Mdot
.65206 .54178 Mdot
.49274 .47113 Mdot
.29717 .48732 Mdot
.41572 .41976 Mdot
.65018 .48281 Mdot
.4844 .46248 Mdot
.66521 .54337 Mdot
.66467 .45262 Mdot
.33215 .66625 Mdot
.57534 .48677 Mdot
.65667 .47622 Mdot
.49168 .37919 Mdot
.29729 .47283 Mdot
.52906 .33461 Mdot
.56709 .28466 Mdot
.40502 .41156 Mdot
.28921 .46165 Mdot
.60334 .54835 Mdot
.3411 .45176 Mdot
.63798 .54321 Mdot
.62461 .50279 Mdot
.28959 .48228 Mdot
.50141 .33386 Mdot
.44214 .23731 Mdot
.48695 .3791 Mdot
.6145 .54232 Mdot
.6585 .52673 Mdot
.48014 .7251 Mdot
.77554 .674 Mdot
.65941 .47619 Mdot
.50383 .31517 Mdot
.66779 .51489 Mdot
.3157 .43809 Mdot
.51263 .70036 Mdot
.52341 .32868 Mdot
.38362 .65199 Mdot
.34812 .63749 Mdot
.40312 .62868 Mdot
.41696 .43327 Mdot
.67747 .48389 Mdot
.52828 .2788 Mdot
.55472 .29936 Mdot
.51156 .50735 Mdot
.35411 .65645 Mdot
.50968 .70415 Mdot
.60774 .49255 Mdot
.67915 .43592 Mdot
.33559 .44874 Mdot
.65523 .8628 Mdot
.47439 .4408 Mdot
.49821 .72498 Mdot
.47261 .58871 Mdot
.422 .41084 Mdot
.61244 .49608 Mdot
.54983 .72728 Mdot
.34637 .64355 Mdot
.64627 .54417 Mdot
.69103 .55525 Mdot
.34155 .55575 Mdot
.38811 .66814 Mdot
.3384 .44495 Mdot
.36458 .63193 Mdot
.51814 .68725 Mdot
.41449 .43161 Mdot
.55016 .31148 Mdot
.64779 .49776 Mdot
.57248 .47848 Mdot
.36025 .66482 Mdot
.41036 .40412 Mdot
.67764 .50427 Mdot
.55353 .32972 Mdot
.34919 .66329 Mdot
.63611 .51112 Mdot
.61762 .35161 Mdot
.51382 .25209 Mdot
.37316 .66683 Mdot
.59458 .49461 Mdot
.59467 .43234 Mdot
.3902 .6665 Mdot
.37696 .62446 Mdot
.66573 .54019 Mdot
.54404 .72687 Mdot
.65901 .47919 Mdot
.32114 .4558 Mdot
.47223 .5127 Mdot
.28757 .45315 Mdot
.62816 .72657 Mdot
.68287 .4762 Mdot
.62971 .61374 Mdot
.49218 .33148 Mdot
.5355 .67664 Mdot
.80946 .41537 Mdot
.65544 .55742 Mdot
.45974 .19657 Mdot
.46784 .53178 Mdot
.45832 .4587 Mdot
.4144 .19661 Mdot
.52936 .72531 Mdot
.31458 .44872 Mdot
.67647 .50367 Mdot
.23607 .44357 Mdot
.52759 .72805 Mdot
.62895 .72591 Mdot
.58962 .51947 Mdot
.53341 .3468 Mdot
.63214 .48858 Mdot
.55174 .32934 Mdot
.6632 .5162 Mdot
.58713 .38866 Mdot
.52545 .65875 Mdot
.61308 .65479 Mdot
.58384 .55956 Mdot
.20289 .47659 Mdot
.75157 .5022 Mdot
.5157 .70079 Mdot
.61584 .53916 Mdot
.41705 .41408 Mdot
.26964 .45601 Mdot
.21917 .52673 Mdot
.35336 .68625 Mdot
.31837 .47033 Mdot
.51256 .31225 Mdot
.34662 .62092 Mdot
.41194 .40471 Mdot
.58314 .57434 Mdot
.54579 .72816 Mdot
.2914 .46466 Mdot
.65118 .49881 Mdot
.63749 .55708 Mdot
.21012 .59067 Mdot
.80665 .55299 Mdot
.50543 .30964 Mdot
.22759 .70166 Mdot
.52342 .28086 Mdot
.53834 .71627 Mdot
.33332 .67113 Mdot
.63795 .51908 Mdot
.65966 .48834 Mdot
.3837 .67278 Mdot
.52652 .29167 Mdot
.5397 .67486 Mdot
.7518 .68892 Mdot
.33523 .422 Mdot
.67989 .64377 Mdot
.52102 .32855 Mdot
.67505 .645 Mdot
.56079 .73731 Mdot
.33679 .50235 Mdot
.76456 .57216 Mdot
.29043 .44323 Mdot
.68525 .64261 Mdot
.54262 .34544 Mdot
.61593 .4999 Mdot
.42659 .42294 Mdot
.43414 .41615 Mdot
.5115 .32406 Mdot
.33687 .66655 Mdot
.54838 .70434 Mdot
.63662 .48795 Mdot
.58809 .58672 Mdot
.75276 .30733 Mdot
.38532 .66287 Mdot
.58574 .48206 Mdot
.27315 .45638 Mdot
.6648 .51987 Mdot
.55997 .72096 Mdot
.30448 .44401 Mdot
.39827 .42674 Mdot
.5504 .60138 Mdot
.61124 .48282 Mdot
.43515 .58704 Mdot
.30443 .4642 Mdot
.77939 .66767 Mdot
.67121 .49391 Mdot
.30146 .47345 Mdot
.57438 .47714 Mdot
.3819 .40181 Mdot
.41561 .53897 Mdot
.43651 .31071 Mdot
.32717 .69368 Mdot
.35459 .63229 Mdot
.83608 .55223 Mdot
.55907 .64972 Mdot
.31867 .47322 Mdot
.40847 .42989 Mdot
.74626 .61064 Mdot
.28528 .46797 Mdot
.59809 .4883 Mdot
.62416 .51771 Mdot
.75166 .48317 Mdot
.69186 .45088 Mdot
.43865 .42112 Mdot
.63617 .59049 Mdot
.60768 .51935 Mdot
.56827 .53777 Mdot
.67227 .51874 Mdot
.55724 .32651 Mdot
.28386 .44616 Mdot
.33139 .18248 Mdot
.33807 .46336 Mdot
.57946 .59511 Mdot
.36883 .66792 Mdot
.32125 .67741 Mdot
.64947 .50403 Mdot
.65491 .61923 Mdot
.18643 .39182 Mdot
.64563 .53194 Mdot
.42892 .60428 Mdot
.61879 .72714 Mdot
.60996 .5715 Mdot
.55096 .35958 Mdot
.57755 .47769 Mdot
.49618 .29599 Mdot
.30406 .4431 Mdot
.52815 .72598 Mdot
.54386 .68743 Mdot
.31646 .45325 Mdot
.66076 .49255 Mdot
.55273 .69388 Mdot
.64162 .50266 Mdot
.61833 .48907 Mdot
.49181 .45953 Mdot
.53332 .7384 Mdot
.35552 .6891 Mdot
.52835 .71121 Mdot
.51465 .34779 Mdot
.41496 .8889 Mdot
.53073 .70045 Mdot
.75024 .4948 Mdot
.49036 .53907 Mdot
.68533 .64514 Mdot
.54373 .3059 Mdot
.51781 .69424 Mdot
.28937 .44223 Mdot
.47204 .4236 Mdot
.76224 .4853 Mdot
.30947 .43367 Mdot
.65254 .48667 Mdot
.49954 .35063 Mdot
.55697 .30977 Mdot
.27155 .48297 Mdot
.53391 .29463 Mdot
.57426 .5261 Mdot
.59929 .49705 Mdot
.32658 .46314 Mdot
.64862 .21396 Mdot
.29331 .43907 Mdot
.69747 .44387 Mdot
.62571 .52537 Mdot
.52436 .3317 Mdot
.73527 .53299 Mdot
.5759 .32563 Mdot
.43379 .42308 Mdot
.63717 .47072 Mdot
.52352 .69796 Mdot
.5082 .5308 Mdot
.37261 .66869 Mdot
.33104 .34433 Mdot
.54835 .31809 Mdot
.30061 .49257 Mdot
.54177 .29897 Mdot
.51487 .29759 Mdot
.32679 .43609 Mdot
.52227 .34521 Mdot
.66201 .48599 Mdot
.29756 .28375 Mdot
.54435 .31355 Mdot
.30373 .45814 Mdot
.52914 .69344 Mdot
.50994 .30949 Mdot
.55667 .7602 Mdot
.62005 .48411 Mdot
.33521 .63987 Mdot
.4915 .69552 Mdot
.4898 .33372 Mdot
.5127 .70252 Mdot
.35643 .66214 Mdot
.55088 .70754 Mdot
.24715 .4426 Mdot
.28736 .4953 Mdot
.57273 .6078 Mdot
.36963 .41432 Mdot
.5273 .35429 Mdot
.32026 .68899 Mdot
.62184 .47794 Mdot
.62723 .48696 Mdot
.51805 .68287 Mdot
.55842 .32204 Mdot
.37501 .37113 Mdot
.69586 .5921 Mdot
.39179 .36266 Mdot
.28107 .48204 Mdot
.5661 .77893 Mdot
.47339 .43869 Mdot
.29287 .41116 Mdot
.63654 .46356 Mdot
.42323 .41195 Mdot
.64238 .50969 Mdot
.6135 .73944 Mdot
.52756 .68637 Mdot
.23615 .61976 Mdot
.68036 .46461 Mdot
.37716 .67763 Mdot
.65822 .52183 Mdot
.24255 .51816 Mdot
.61849 .4439 Mdot
.54373 .6905 Mdot
.34557 .44777 Mdot
.49798 .33728 Mdot
.52632 .69009 Mdot
.34497 .63964 Mdot
.70219 .61927 Mdot
.60154 .48598 Mdot
.60709 .5148 Mdot
.39456 .65362 Mdot
.50778 .34688 Mdot
.35437 .64455 Mdot
.30461 .4735 Mdot
.53089 .70313 Mdot
.61221 .54838 Mdot
.57252 .50301 Mdot
.39764 .67121 Mdot
.33068 .46908 Mdot
.38238 .68135 Mdot
.3403 .45317 Mdot
.42634 .41459 Mdot
.68524 .49998 Mdot
.39682 .64951 Mdot
.66636 .46499 Mdot
.74594 .34769 Mdot
.52354 .5436 Mdot
.79368 .43505 Mdot
.35426 .68934 Mdot
.51012 .65555 Mdot
.31148 .45271 Mdot
.29301 .46802 Mdot
.6989 .44057 Mdot
.18955 .40676 Mdot
.42173 .51598 Mdot
.1805 .50964 Mdot
.30617 .47326 Mdot
.29767 .46369 Mdot
.34283 .65177 Mdot
.50934 .34154 Mdot
.50247 .36864 Mdot
.37398 .61874 Mdot
.60358 .6846 Mdot
.54333 .34191 Mdot
.48643 .19766 Mdot
.38175 .63547 Mdot
.62395 .46907 Mdot
.3909 .44005 Mdot
.54481 .69176 Mdot
.61005 .72068 Mdot
.19165 .50706 Mdot
.64325 .51739 Mdot
.46159 .85422 Mdot
.34752 .68069 Mdot
.3996 .45795 Mdot
.26684 .50573 Mdot
.63681 .56098 Mdot
.65831 .5181 Mdot
.66735 .49783 Mdot
.49453 .70858 Mdot
.74526 .31836 Mdot
.63984 .51753 Mdot
.58895 .64519 Mdot
.68343 .53112 Mdot
.19833 .58771 Mdot
.5286 .711 Mdot
.71338 .70324 Mdot
.31886 .65223 Mdot
.40904 .37754 Mdot
.61797 .56081 Mdot
.31193 .46928 Mdot
.36356 .54902 Mdot
.3005 .48346 Mdot
.29928 .513 Mdot
.76387 .58665 Mdot
.55781 .33338 Mdot
.65062 .54803 Mdot
.38344 .63429 Mdot
.49503 .34507 Mdot
.37756 .54603 Mdot
.38543 .87076 Mdot
.27999 .48533 Mdot
.22071 .7264 Mdot
.28358 .45822 Mdot
.43556 .41681 Mdot
.51489 .31217 Mdot
.68696 .61395 Mdot
.48806 .48302 Mdot
.50383 .34083 Mdot
.44483 .78286 Mdot
.48358 .33654 Mdot
.65974 .63762 Mdot
.49253 .2922 Mdot
.3053 .45259 Mdot
.30087 .49392 Mdot
.68636 .55377 Mdot
.64612 .47375 Mdot
.48133 .49107 Mdot
.70298 .5067 Mdot
.61541 .48139 Mdot
.37269 .65652 Mdot
.35703 .41032 Mdot
.2331 .44551 Mdot
.51681 .3293 Mdot
.33363 .459 Mdot
.65758 .52073 Mdot
.61415 .54187 Mdot
.58402 .53531 Mdot
.60102 .79107 Mdot
.48384 .19615 Mdot
.62218 .50383 Mdot
.61469 .44575 Mdot
.33603 .64775 Mdot
.2099 .59278 Mdot
.24041 .70281 Mdot
.75519 .5972 Mdot
.67829 .50815 Mdot
.53119 .71754 Mdot
.56194 .71627 Mdot
.57898 .53465 Mdot
.61641 .61741 Mdot
.53812 .77348 Mdot
.65145 .49876 Mdot
.6394 .6328 Mdot
.38461 .69169 Mdot
.40469 .40785 Mdot
.36004 .66427 Mdot
.49194 .34055 Mdot
.42276 .40845 Mdot
.37043 .64217 Mdot
.57611 .63695 Mdot
.40371 .41525 Mdot
.38514 .39779 Mdot
.51584 .69557 Mdot
.67426 .50985 Mdot
.47388 .30282 Mdot
.38347 .66161 Mdot
.29955 .46652 Mdot
.53009 .31705 Mdot
.26763 .45958 Mdot
.19113 .57276 Mdot
.60749 .69547 Mdot
.42082 .43286 Mdot
.31498 .46778 Mdot
.43645 .56557 Mdot
.53177 .71606 Mdot
.27935 .46104 Mdot
.63938 .61535 Mdot
.69032 .49422 Mdot
.23012 .31333 Mdot
.60318 .51607 Mdot
.45363 .32398 Mdot
.30309 .46895 Mdot
.39711 .42911 Mdot
.64637 .49688 Mdot
.35539 .62633 Mdot
.60717 .57504 Mdot
.63986 .50243 Mdot
.3784 .63829 Mdot
.61862 .5029 Mdot
.54574 .73427 Mdot
.49535 .29936 Mdot
.47501 .53915 Mdot
.59334 .7741 Mdot
.54308 .69612 Mdot
.51694 .48212 Mdot
.65724 .47467 Mdot
.40599 .75898 Mdot
.53233 .34533 Mdot
.65439 .55705 Mdot
.64425 .73343 Mdot
.50964 .33434 Mdot
.53616 .32691 Mdot
.61137 .53168 Mdot
.29458 .43746 Mdot
.37258 .68722 Mdot
.53014 .71482 Mdot
.24707 .42724 Mdot
.63518 .51263 Mdot
.66122 .54258 Mdot
.53391 .68823 Mdot
.29148 .46187 Mdot
.60803 .54726 Mdot
.38466 .30487 Mdot
.51556 .51868 Mdot
.33723 .44731 Mdot
.68996 .5073 Mdot
.34611 .20426 Mdot
.49537 .36413 Mdot
.47337 .85752 Mdot
.53341 .65311 Mdot
.33412 .66398 Mdot
.59941 .46975 Mdot
.59987 .89729 Mdot
.51848 .69537 Mdot
.41063 .3687 Mdot
.61904 .49721 Mdot
.63899 .52275 Mdot
.55404 .34357 Mdot
.59657 .5361 Mdot
.54683 .34669 Mdot
.57645 .78315 Mdot
.17975 .42135 Mdot
.53411 .29581 Mdot
.54988 .33952 Mdot
.66463 .44334 Mdot
.60618 .79497 Mdot
.50806 .32234 Mdot
.60184 .48601 Mdot
.42787 .76053 Mdot
.69886 .54927 Mdot
.52336 .73953 Mdot
.5162 .76955 Mdot
.54812 .36144 Mdot
.76206 .46298 Mdot
.66613 .4443 Mdot
.60665 .39427 Mdot
.53832 .76231 Mdot
.30832 .47753 Mdot
.63074 .53801 Mdot
.41217 .43259 Mdot
.34678 .6604 Mdot
.56139 .51649 Mdot
.67243 .49946 Mdot
.53021 .35956 Mdot
.49718 .70402 Mdot
.28227 .46756 Mdot
.67186 .5279 Mdot
.40158 .66663 Mdot
.54432 .71664 Mdot
.53864 .30851 Mdot
.73353 .47425 Mdot
.55335 .69669 Mdot
.57633 .49374 Mdot
.61366 .5038 Mdot
.67581 .52104 Mdot
.71639 .53937 Mdot
.3157 .45599 Mdot
.36214 .61718 Mdot
.5965 .47409 Mdot
.48142 .43988 Mdot
.52228 .55754 Mdot
.58607 .49765 Mdot
.50561 .31314 Mdot
.28047 .48059 Mdot
.409 .42407 Mdot
.71184 .63637 Mdot
.61623 .51508 Mdot
.47437 .19331 Mdot
.69317 .75045 Mdot
.40669 .41583 Mdot
.5076 .36191 Mdot
.52397 .7113 Mdot
.61559 .52461 Mdot
.5964 .65195 Mdot
.59756 .49267 Mdot
.69043 .56547 Mdot
.33759 .67329 Mdot
.29767 .47933 Mdot
.54074 .5497 Mdot
.34646 .65764 Mdot
.5355 .32695 Mdot
.52632 .21407 Mdot
.49608 .36109 Mdot
.50898 .30285 Mdot
.35264 .51827 Mdot
.31774 .44416 Mdot
.61397 .89194 Mdot
.76996 .68775 Mdot
.62513 .47081 Mdot
.32558 .44628 Mdot
.51513 .31602 Mdot
.59238 .5403 Mdot
.53541 .35156 Mdot
.56588 .33699 Mdot
.60982 .48856 Mdot
.61291 .48519 Mdot
.61494 .6494 Mdot
.49454 .20181 Mdot
.52928 .69631 Mdot
.54175 .2953 Mdot
.6635 .41308 Mdot
.63434 .51681 Mdot
.66403 .48355 Mdot
.35514 .5495 Mdot
.52208 .69094 Mdot
.64561 .34171 Mdot
.62595 .48932 Mdot
.64027 .75333 Mdot
.629 .4734 Mdot
.51807 .37652 Mdot
.25914 .45732 Mdot
.59665 .60662 Mdot
.36495 .69196 Mdot
.50103 .30478 Mdot
.51577 .68586 Mdot
.56536 .30075 Mdot
.64562 .37901 Mdot
.30756 .44178 Mdot
.5501 .33226 Mdot
.33694 .62734 Mdot
.29221 .45432 Mdot
.29872 .43814 Mdot
.38314 .54436 Mdot
.33558 .63164 Mdot
.49716 .71801 Mdot
.27523 .46922 Mdot
.61666 .35412 Mdot
.30239 .45164 Mdot
.64079 .37287 Mdot
.67514 .4849 Mdot
.58567 .64262 Mdot
.56916 .5763 Mdot
.69466 .54734 Mdot
.28087 .451 Mdot
.54785 .70872 Mdot
.61389 .55299 Mdot
.52819 .29515 Mdot
.53884 .70046 Mdot
.38985 .44557 Mdot
.3191 .66774 Mdot
.55959 .31648 Mdot
.34226 .44455 Mdot
.53909 .35423 Mdot
.6157 .72462 Mdot
.5298 .67088 Mdot
.37434 .55687 Mdot
.48863 .49392 Mdot
.5708 .54543 Mdot
.62299 .4401 Mdot
.62154 .55758 Mdot
.66339 .49085 Mdot
.37262 .66635 Mdot
.50785 .74269 Mdot
.50993 .30907 Mdot
.74558 .29157 Mdot
.31388 .4655 Mdot
.43295 .58223 Mdot
.67485 .57506 Mdot
.64068 .54387 Mdot
.52023 .31554 Mdot
.5673 .32199 Mdot
.76852 .36956 Mdot
.38331 .67546 Mdot
.70294 .54188 Mdot
.60872 .56089 Mdot
.53355 .50169 Mdot
.28486 .44956 Mdot
.41767 .28092 Mdot
.34372 .6957 Mdot
.2428 .76077 Mdot
.3493 .65511 Mdot
.42027 .70829 Mdot
.5211 .34523 Mdot
.51015 .71128 Mdot
.64902 .48097 Mdot
.55024 .40743 Mdot
.51233 .36094 Mdot
.31181 .68506 Mdot
.51946 .70647 Mdot
.43759 .25321 Mdot
.32665 .45677 Mdot
.6814 .5081 Mdot
.62346 .47482 Mdot
.60466 .53664 Mdot
.58939 .53151 Mdot
.32954 .46077 Mdot
.59631 .49598 Mdot
.31216 .42907 Mdot
.65538 .37697 Mdot
.64845 .72637 Mdot
.38336 .63023 Mdot
.21683 .60729 Mdot
.51161 .30115 Mdot
.5828 .25684 Mdot
.65448 .35427 Mdot
.52323 .5426 Mdot
.24949 .44576 Mdot
.68262 .49368 Mdot
.3378 .66602 Mdot
.20725 .47804 Mdot
.38114 .6295 Mdot
.24882 .25374 Mdot
.75229 .48649 Mdot
.45532 .28225 Mdot
.59589 .52656 Mdot
.39597 .64196 Mdot
.74813 .43828 Mdot
.57366 .49739 Mdot
.55083 .68886 Mdot
.62746 .37655 Mdot
.46308 .3382 Mdot
.51044 .70164 Mdot
.61573 .48751 Mdot
.55225 .29288 Mdot
.65528 .48443 Mdot
.63932 .48037 Mdot
.64725 .533 Mdot
.26299 .44677 Mdot
.65831 .46974 Mdot
.65797 .47915 Mdot
.80498 .55968 Mdot
.41674 .596 Mdot
.34422 .63542 Mdot
.79154 .41941 Mdot
.53894 .70857 Mdot
.49196 .33866 Mdot
.46878 .52915 Mdot
.32272 .45799 Mdot
.7698 .37261 Mdot
.60111 .52365 Mdot
.40584 .34464 Mdot
.31245 .48815 Mdot
.54106 .72531 Mdot
.40531 .42378 Mdot
.41166 .25203 Mdot
.33924 .68438 Mdot
.43655 .42656 Mdot
.37231 .6702 Mdot
.79689 .45959 Mdot
.54972 .34191 Mdot
.57047 .54418 Mdot
.28107 .46999 Mdot
.36012 .62134 Mdot
.59366 .64779 Mdot
.67031 .50818 Mdot
.35536 .68984 Mdot
.56136 .54024 Mdot
.50901 .54029 Mdot
.46803 .52342 Mdot
.35342 .62012 Mdot
.32843 .47957 Mdot
.29073 .4501 Mdot
.50683 .70478 Mdot
.49215 .32021 Mdot
.51303 .35137 Mdot
.29788 .44822 Mdot
.34454 .80609 Mdot
.63728 .5129 Mdot
.62626 .51592 Mdot
.47844 .43522 Mdot
.59442 .54517 Mdot
.48217 .70047 Mdot
.42992 .40727 Mdot
.51361 .35512 Mdot
.61839 .55607 Mdot
.60746 .54648 Mdot
.61069 .5039 Mdot
.60964 .68877 Mdot
.35934 .66654 Mdot
.60872 .5197 Mdot
.54824 .72736 Mdot
.43345 .44157 Mdot
.62618 .47635 Mdot
.56759 .51804 Mdot
.54447 .34948 Mdot
.36095 .76735 Mdot
.30463 .46697 Mdot
.38203 .66805 Mdot
.38776 .64363 Mdot
.66739 .69027 Mdot
.55148 .3763 Mdot
.4395 .42046 Mdot
.20351 .56113 Mdot
.41025 .42873 Mdot
.51576 .70806 Mdot
.41494 .52999 Mdot
.36825 .70642 Mdot
.35224 .63245 Mdot
.33964 .47412 Mdot
.64737 .55462 Mdot
.6189 .47827 Mdot
.40335 .37485 Mdot
.64045 .52897 Mdot
.52254 .69735 Mdot
.29506 .43487 Mdot
.54829 .3409 Mdot
.55887 .72085 Mdot
.28982 .46726 Mdot
.50528 .3446 Mdot
.65458 .56336 Mdot
.59062 .49582 Mdot
.53321 .31885 Mdot
.53937 .30644 Mdot
.65332 .5104 Mdot
.81375 .5358 Mdot
.50663 .35138 Mdot
.52618 .31253 Mdot
.45826 .40885 Mdot
.33054 .66819 Mdot
.7254 .50303 Mdot
.32283 .44463 Mdot
.66247 .48459 Mdot
.38749 .63356 Mdot
.51664 .71778 Mdot
.54173 .32333 Mdot
.62935 .53507 Mdot
.6302 .50716 Mdot
.52921 .71707 Mdot
.54553 .73824 Mdot
.53234 .69112 Mdot
.26296 .45554 Mdot
.59971 .5005 Mdot
.50843 .31807 Mdot
.32711 .45705 Mdot
.55656 .70354 Mdot
.50347 .71567 Mdot
.79728 .5448 Mdot
.64512 .51601 Mdot
.56101 .70338 Mdot
.46313 .90952 Mdot
.71403 .61668 Mdot
.42079 .40625 Mdot
.39577 .6843 Mdot
.50242 .66265 Mdot
.49405 .69102 Mdot
.30899 .48036 Mdot
.42918 .59473 Mdot
.50446 .69568 Mdot
.63873 .53311 Mdot
.66359 .52603 Mdot
.63331 .46196 Mdot
.54106 .70488 Mdot
.6121 .70144 Mdot
.55012 .29763 Mdot
.66171 .29575 Mdot
.53886 .70838 Mdot
.34771 .62372 Mdot
.39957 .66578 Mdot
.34926 .6506 Mdot
.68277 .51464 Mdot
.79368 .39087 Mdot
.66359 .3996 Mdot
.64477 .33149 Mdot
.32235 .46404 Mdot
.56709 .3231 Mdot
.36952 .45827 Mdot
.53679 .32708 Mdot
.34939 .67294 Mdot
.54605 .71509 Mdot
.55507 .3423 Mdot
.2999 .43848 Mdot
.28938 .44844 Mdot
.37725 .68815 Mdot
.35739 .65955 Mdot
.36598 .64938 Mdot
.49741 .31007 Mdot
.52172 .34539 Mdot
.61087 .5452 Mdot
.54439 .32091 Mdot
.69832 .75378 Mdot
.49224 .67942 Mdot
.39062 .67801 Mdot
.30927 .46042 Mdot
.52698 .30757 Mdot
.67479 .50613 Mdot
.439 .67888 Mdot
.31886 .69371 Mdot
.55309 .70545 Mdot
.26277 .33743 Mdot
.16623 .42618 Mdot
.68634 .51795 Mdot
.32794 .47045 Mdot
.62421 .61586 Mdot
.66541 .50033 Mdot
.34054 .68033 Mdot
.72602 .70849 Mdot
.40071 .42219 Mdot
.64499 .47685 Mdot
.6277 .56698 Mdot
.28771 .44187 Mdot
.46934 .5272 Mdot
.64123 .53466 Mdot
.41608 .55531 Mdot
.2965 .48947 Mdot
.34552 .69604 Mdot
.84662 .56146 Mdot
.3998 .45484 Mdot
.59642 .73079 Mdot
.41217 .40617 Mdot
.6371 .52925 Mdot
.37338 .65865 Mdot
.55489 .71787 Mdot
.3664 .65886 Mdot
.50454 .36161 Mdot
.33351 .6755 Mdot
.6682 .52605 Mdot
.50582 .32391 Mdot
.29054 .4632 Mdot
.43979 .58541 Mdot
.78805 .50933 Mdot
.35399 .62712 Mdot
.4024 .40665 Mdot
.61567 .48383 Mdot
.60903 .31825 Mdot
.68275 .55537 Mdot
.65531 .47574 Mdot
.29316 .48297 Mdot
.51751 .32159 Mdot
.28207 .48238 Mdot
.56587 .55015 Mdot
.55921 .25106 Mdot
.31619 .46266 Mdot
.48748 .38435 Mdot
.53552 .68824 Mdot
.60335 .68694 Mdot
.64502 .49064 Mdot
.2836 .47208 Mdot
.60182 .50369 Mdot
.54357 .29616 Mdot
.5417 .59152 Mdot
.52548 .49134 Mdot
.2729 .45562 Mdot
.46934 .27403 Mdot
.50638 .55225 Mdot
.71438 .48094 Mdot
.29695 .47442 Mdot
.8078 .41348 Mdot
.41492 .41587 Mdot
.53354 .72245 Mdot
.55704 .73265 Mdot
.52402 .73116 Mdot
.63857 .5264 Mdot
.59808 .37792 Mdot
.50954 .72658 Mdot
.26356 .46468 Mdot
.52563 .73552 Mdot
.61453 .78099 Mdot
.38316 .36678 Mdot
.54152 .69341 Mdot
.63962 .49236 Mdot
.55657 .52558 Mdot
.42961 .59757 Mdot
.3234 .65953 Mdot
.43764 .22093 Mdot
.79837 .56685 Mdot
.63935 .51977 Mdot
.59988 .35565 Mdot
.52149 .37053 Mdot
.49885 .63619 Mdot
.52833 .48727 Mdot
.43135 .50434 Mdot
.52746 .30975 Mdot
.47765 .50975 Mdot
.49799 .34549 Mdot
.58499 .56143 Mdot
.62459 .50196 Mdot
.48803 .33609 Mdot
.31634 .34391 Mdot
.79443 .35669 Mdot
.39222 .35683 Mdot
.49959 .3258 Mdot
.29685 .47275 Mdot
.31345 .48222 Mdot
.29245 .48229 Mdot
.37969 .65561 Mdot
.55075 .3207 Mdot
.61471 .51705 Mdot
.34089 .64488 Mdot
.63662 .48319 Mdot
.29653 .44447 Mdot
.51965 .52697 Mdot
.54794 .34262 Mdot
.65134 .49665 Mdot
.73067 .45265 Mdot
.36586 .67355 Mdot
.5341 .71654 Mdot
.27811 .31643 Mdot
.38501 .69539 Mdot
.34057 .46191 Mdot
.56028 .35784 Mdot
.38463 .61326 Mdot
.35677 .73039 Mdot
.62155 .47122 Mdot
.61023 .47802 Mdot
.42636 .61113 Mdot
.75449 .46801 Mdot
.64762 .53736 Mdot
.34645 .63854 Mdot
.32903 .65676 Mdot
.60337 .50266 Mdot
.54685 .30633 Mdot
.49976 .71333 Mdot
.51892 .68243 Mdot
.57961 .55527 Mdot
.48412 .49576 Mdot
.58713 .64359 Mdot
.60379 .54749 Mdot
.63938 .45511 Mdot
.33078 .6345 Mdot
.41178 .40499 Mdot
.49233 .47472 Mdot
.51017 .72056 Mdot
.61889 .49461 Mdot
.75507 .31343 Mdot
.54844 .32133 Mdot
.36376 .69082 Mdot
.32786 .44184 Mdot
.55325 .6948 Mdot
.3797 .68919 Mdot
.60345 .50258 Mdot
.60753 .54685 Mdot
.27842 .46442 Mdot
.52561 .37676 Mdot
.54476 .7084 Mdot
.33937 .64582 Mdot
.50964 .7099 Mdot
.52426 .34673 Mdot
.53487 .31011 Mdot
.60205 .55973 Mdot
.69539 .54483 Mdot
.37042 .62916 Mdot
.5981 .47673 Mdot
.35163 .64197 Mdot
.20976 .59073 Mdot
.33539 .44938 Mdot
.63626 .56394 Mdot
.56076 .37094 Mdot
.29616 .44546 Mdot
.64675 .52265 Mdot
.42587 .61137 Mdot
.63848 .54892 Mdot
.37729 .62097 Mdot
.75538 .67782 Mdot
.52128 .7264 Mdot
.569 .45766 Mdot
.74413 .54934 Mdot
.59948 .54932 Mdot
.32722 .65394 Mdot
.61947 .38376 Mdot
.31834 .45774 Mdot
.51661 .34028 Mdot
.34547 .77645 Mdot
.3031 .45612 Mdot
.63116 .49204 Mdot
.53174 .70103 Mdot
.49682 .33235 Mdot
.43049 .42263 Mdot
.47349 .47954 Mdot
.55979 .51574 Mdot
.62986 .57631 Mdot
.67337 .52665 Mdot
.18088 .50744 Mdot
.36691 .65255 Mdot
.51824 .31482 Mdot
.32435 .47271 Mdot
.3141 .44509 Mdot
.35879 .67251 Mdot
.46071 .35069 Mdot
.35572 .34578 Mdot
.5026 .91249 Mdot
.38488 .68539 Mdot
.52733 .73449 Mdot
.53652 .58271 Mdot
.34645 .65204 Mdot
.37951 .66243 Mdot
.32119 .6522 Mdot
.39361 .37365 Mdot
.50067 .32437 Mdot
.62906 .50816 Mdot
.57123 .31145 Mdot
.63697 .52793 Mdot
.59388 .71302 Mdot
.30067 .44495 Mdot
.51724 .34168 Mdot
.5612 .76004 Mdot
.60907 .44592 Mdot
.66214 .50787 Mdot
.58689 .71392 Mdot
.54447 .50847 Mdot
.6958 .64149 Mdot
.58343 .53014 Mdot
.36595 .66423 Mdot
.53536 .25113 Mdot
.58251 .48499 Mdot
.72715 .45191 Mdot
.28706 .45309 Mdot
.42513 .43187 Mdot
.57362 .5571 Mdot
.65198 .45181 Mdot
.4963 .32828 Mdot
.5533 .34692 Mdot
.50767 .72508 Mdot
.2968 .2893 Mdot
.28693 .4565 Mdot
.43414 .29172 Mdot
.65101 .47403 Mdot
.24269 .47344 Mdot
.74149 .69723 Mdot
.65194 .52054 Mdot
.39086 .54187 Mdot
.76889 .37137 Mdot
.64517 .54222 Mdot
.64868 .32482 Mdot
.30947 .45639 Mdot
.64136 .74187 Mdot
.5889 .51242 Mdot
.34583 .68321 Mdot
.51162 .34264 Mdot
.55939 .31514 Mdot
.55675 .71386 Mdot
.73165 .72821 Mdot
.20939 .42309 Mdot
.51864 .3446 Mdot
.66992 .50128 Mdot
.30495 .46572 Mdot
.43114 .42588 Mdot
.56528 .50185 Mdot
.22833 .48618 Mdot
.54786 .32623 Mdot
.59632 .47363 Mdot
.40122 .34236 Mdot
.47168 .51805 Mdot
.5009 .19178 Mdot
.28315 .4781 Mdot
.50795 .71805 Mdot
.7156 .5196 Mdot
.2033 .56656 Mdot
.59151 .49461 Mdot
.59502 .71947 Mdot
.53098 .38497 Mdot
.51237 .70119 Mdot
.66187 .49646 Mdot
.64138 .53637 Mdot
.49767 .50414 Mdot
.55882 .73291 Mdot
.64076 .53507 Mdot
.67956 .46358 Mdot
.51942 .35107 Mdot
.4286 .40619 Mdot
.54745 .34081 Mdot
.65629 .48673 Mdot
.7594 .65823 Mdot
.55358 .31758 Mdot
.44007 .22763 Mdot
.54382 .65232 Mdot
.32204 .45967 Mdot
.59324 .46863 Mdot
.6708 .48108 Mdot
.4344 .17277 Mdot
.43434 .42139 Mdot
.26702 .72667 Mdot
.39373 .63852 Mdot
.84802 .41765 Mdot
.38096 .69777 Mdot
.46506 .26721 Mdot
.4107 .57966 Mdot
.62079 .46261 Mdot
.70223 .45474 Mdot
.63821 .32192 Mdot
.24562 .47379 Mdot
.59343 .27275 Mdot
.64577 .47373 Mdot
.61395 .49889 Mdot
.34241 .64899 Mdot
.4553 .35172 Mdot
.60392 .6091 Mdot
.49151 .47671 Mdot
.54081 .7241 Mdot
.53029 .33788 Mdot
.66749 .52345 Mdot
.29313 .34096 Mdot
.35295 .62465 Mdot
.77178 .54301 Mdot
.64892 .49577 Mdot
.58464 .60217 Mdot
.456 .37806 Mdot
.29263 .46566 Mdot
.35195 .62019 Mdot
.34153 .62742 Mdot
.63352 .52665 Mdot
.33012 .4552 Mdot
.62222 .54943 Mdot
.51336 .56217 Mdot
.56414 .51505 Mdot
.51513 .71164 Mdot
.66683 .48412 Mdot
.75553 .5518 Mdot
.56731 .19017 Mdot
.66378 .44818 Mdot
.49957 .3114 Mdot
.36556 .64573 Mdot
.35439 .66628 Mdot
.51094 .3506 Mdot
.35401 .66689 Mdot
.66459 .30461 Mdot
.59055 .29894 Mdot
.51466 .70699 Mdot
.67167 .37437 Mdot
.52849 .72738 Mdot
.42333 .4327 Mdot
.64819 .51519 Mdot
.28781 .56193 Mdot
.38071 .68991 Mdot
.62623 .77836 Mdot
.30168 .4489 Mdot
.43501 .41914 Mdot
.60738 .4884 Mdot
.55844 .75252 Mdot
.34376 .67172 Mdot
.39869 .49298 Mdot
.6238 .51856 Mdot
.53017 .29193 Mdot
.64205 .54278 Mdot
.68961 .52846 Mdot
.43546 .41527 Mdot
.6688 .53704 Mdot
.28998 .4674 Mdot
.55313 .33044 Mdot
.45264 .29519 Mdot
.38312 .66083 Mdot
.63087 .47828 Mdot
.66899 .50062 Mdot
.54043 .36438 Mdot
.63424 .46929 Mdot
.32076 .46943 Mdot
.69788 .83205 Mdot
.52846 .68876 Mdot
.41024 .40544 Mdot
.35168 .24145 Mdot
.65805 .54071 Mdot
.61756 .55325 Mdot
.42755 .47581 Mdot
.75849 .3194 Mdot
.30952 .46909 Mdot
.61771 .57326 Mdot
.33741 .64156 Mdot
.54564 .70767 Mdot
.26959 .45445 Mdot
.59835 .49713 Mdot
.61831 .50603 Mdot
.51541 .69957 Mdot
.58812 .70317 Mdot
.54916 .68 Mdot
.31206 .47691 Mdot
.59362 .33353 Mdot
.44085 .67718 Mdot
.64037 .50824 Mdot
.39102 .41951 Mdot
.52176 .32054 Mdot
.30236 .4751 Mdot
.73346 .30631 Mdot
.58707 .56206 Mdot
.33876 .44411 Mdot
.28909 .46152 Mdot
.64291 .46811 Mdot
.54572 .37845 Mdot
.57043 .32543 Mdot
.52204 .31785 Mdot
.65462 .71863 Mdot
.21186 .65946 Mdot
.36952 .65015 Mdot
.30512 .46132 Mdot
.39076 .63855 Mdot
.5064 .69326 Mdot
.51748 .55074 Mdot
.34155 .63007 Mdot
.5227 .29187 Mdot
.38681 .63631 Mdot
.6242 .5508 Mdot
.30589 .43707 Mdot
.38135 .63612 Mdot
.59302 .53977 Mdot
.66868 .45977 Mdot
.69082 .44993 Mdot
.49807 .71011 Mdot
.47669 .50874 Mdot
.63761 .48873 Mdot
.40558 .42244 Mdot
.65264 .5058 Mdot
.32465 .46585 Mdot
.43917 .5953 Mdot
.60536 .52148 Mdot
.38218 .68883 Mdot
.23822 .68718 Mdot
.32709 .67013 Mdot
.69651 .49715 Mdot
.65171 .48643 Mdot
.64026 .51103 Mdot
.61067 .48716 Mdot
.46408 .32755 Mdot
.34386 .44227 Mdot
.69354 .56153 Mdot
.38714 .6757 Mdot
.53786 .32346 Mdot
.55366 .31218 Mdot
.42544 .49632 Mdot
.43392 .429 Mdot
.32846 .4487 Mdot
.6386 .5116 Mdot
.39899 .49556 Mdot
.4686 .46472 Mdot
.39444 .34857 Mdot
.39661 .61936 Mdot
.35537 .63096 Mdot
.50673 .3018 Mdot
.37184 .63599 Mdot
.59907 .49456 Mdot
.60332 .4694 Mdot
.45319 .28898 Mdot
.28767 .42736 Mdot
.54566 .71107 Mdot
.64356 .4822 Mdot
.60673 .67211 Mdot
.33607 .64776 Mdot
.33292 .63282 Mdot
.61883 .54799 Mdot
.53664 .37276 Mdot
.59946 .17257 Mdot
.3231 .44216 Mdot
.60913 .32532 Mdot
.50499 .26672 Mdot
.53213 .49297 Mdot
.31663 .45158 Mdot
.40219 .54172 Mdot
.32192 .67279 Mdot
.78626 .6363 Mdot
.53555 .31795 Mdot
.54457 .71126 Mdot
.58392 .51648 Mdot
.52197 .29224 Mdot
.3973 .65316 Mdot
.50243 .35129 Mdot
.56951 .54302 Mdot
.27581 .47967 Mdot
.34941 .66057 Mdot
.31516 .49182 Mdot
.49638 .35027 Mdot
.5261 .72736 Mdot
.63185 .74874 Mdot
.61803 .34608 Mdot
.76779 .37049 Mdot
.60945 .5201 Mdot
.327 .55534 Mdot
.61679 .51867 Mdot
.54437 .2881 Mdot
.64431 .49069 Mdot
.59368 .45096 Mdot
.32202 .68032 Mdot
.58245 .50592 Mdot
.66387 .48192 Mdot
.71727 .44619 Mdot
.6572 .51697 Mdot
.60674 .49969 Mdot
.61272 .56697 Mdot
.50117 .37239 Mdot
.58082 .51404 Mdot
.52739 .29269 Mdot
.41016 .36141 Mdot
.37969 .66529 Mdot
.50775 .69303 Mdot
.51687 .68762 Mdot
.59219 .73616 Mdot
.6066 .677 Mdot
.45781 .36044 Mdot
.5432 .33923 Mdot
.28316 .44958 Mdot
.61917 .54943 Mdot
.80965 .43272 Mdot
.74462 .66486 Mdot
.32702 .68782 Mdot
.37895 .63132 Mdot
.58799 .50293 Mdot
.18158 .40725 Mdot
.58325 .50834 Mdot
.47493 .43879 Mdot
.63606 .52476 Mdot
.64068 .56398 Mdot
.34327 .62202 Mdot
.61465 .72483 Mdot
.60858 .51943 Mdot
.49609 .33011 Mdot
.5416 .71716 Mdot
.55419 .55555 Mdot
.72557 .68829 Mdot
.6954 .44216 Mdot
.69389 .59568 Mdot
.60028 .51631 Mdot
.33507 .6568 Mdot
.49884 .32484 Mdot
.48138 .44815 Mdot
.32119 .46718 Mdot
.47732 .48979 Mdot
.64735 .37167 Mdot
.28012 .50801 Mdot
.54459 .7159 Mdot
.32169 .63414 Mdot
.66779 .52794 Mdot
.37738 .65333 Mdot
.60673 .56994 Mdot
.46067 .46759 Mdot
.51309 .71096 Mdot
.49405 .31063 Mdot
.29686 .47242 Mdot
.54012 .29052 Mdot
.79363 .43259 Mdot
.74971 .66172 Mdot
.85 .42089 Mdot
.34212 .68889 Mdot
.65508 .24059 Mdot
.5106 .32521 Mdot
.62357 .5207 Mdot
.49855 .9115 Mdot
.52146 .32687 Mdot
.52693 .29161 Mdot
.43759 .51166 Mdot
.62807 .72773 Mdot
.58722 .48463 Mdot
.51081 .35491 Mdot
.33332 .62171 Mdot
.524 .70741 Mdot
.59375 .53786 Mdot
.57087 .55076 Mdot
.55425 .34388 Mdot
.34717 .67462 Mdot
.5983 .70244 Mdot
.36119 .66279 Mdot
.50189 .32416 Mdot
.36699 .67819 Mdot
.43852 .23944 Mdot
.3468 .6278 Mdot
.66967 .48398 Mdot
.6385 .51067 Mdot
.28716 .52876 Mdot
.5349 .31014 Mdot
.61753 .55359 Mdot
.6179 .49989 Mdot
.50965 .31925 Mdot
.36642 .70765 Mdot
.7108 .28108 Mdot
.62505 .55548 Mdot
.63341 .51062 Mdot
.52167 .68945 Mdot
.49667 .52887 Mdot
.46799 .4367 Mdot
.59743 .54479 Mdot
.52827 .73275 Mdot
.50313 .30286 Mdot
.65386 .50707 Mdot
.61436 .7272 Mdot
.38876 .68783 Mdot
.5956 .51913 Mdot
.42653 .42793 Mdot
.6474 .53461 Mdot
.58777 .1753 Mdot
.61857 .48194 Mdot
.51624 .31091 Mdot
.50911 .33607 Mdot
.36059 .59839 Mdot
.53397 .32629 Mdot
.42343 .40781 Mdot
.29225 .44953 Mdot
.5333 .21239 Mdot
.42736 .41035 Mdot
.67282 .53534 Mdot
.76747 .6928 Mdot
.56947 .54736 Mdot
.56652 .51805 Mdot
.60968 .79511 Mdot
.4138 .40622 Mdot
.51553 .32572 Mdot
.31714 .33864 Mdot
.59737 .47949 Mdot
.32764 .44593 Mdot
.57256 .50211 Mdot
.59575 .51861 Mdot
.62438 .43868 Mdot
.59002 .3083 Mdot
.30271 .43275 Mdot
.72411 .49854 Mdot
.59408 .53809 Mdot
.75914 .32119 Mdot
.67224 .51293 Mdot
.54885 .69898 Mdot
.5372 .34875 Mdot
.37608 .6407 Mdot
.51809 .71015 Mdot
.66374 .53416 Mdot
.53973 .70559 Mdot
.37492 .65338 Mdot
.27924 .47188 Mdot
.67233 .48813 Mdot
.52321 .73964 Mdot
.54658 .71603 Mdot
.61893 .53751 Mdot
.51572 .34329 Mdot
.67687 .5581 Mdot
.65438 .50997 Mdot
.60408 .49398 Mdot
.51441 .35178 Mdot
.53229 .85784 Mdot
.61099 .50185 Mdot
.39881 .54206 Mdot
.50599 .28684 Mdot
.42844 .40758 Mdot
.35541 .63459 Mdot
.68131 .46774 Mdot
.31552 .44429 Mdot
.29501 .44956 Mdot
.36234 .69703 Mdot
.54756 .35372 Mdot
.34954 .66437 Mdot
.65053 .44243 Mdot
.60054 .47151 Mdot
.58436 .51569 Mdot
.34344 .77611 Mdot
.40741 .24442 Mdot
.52838 .30327 Mdot
.32407 .66751 Mdot
.48338 .48731 Mdot
.31433 .43849 Mdot
.33182 .62997 Mdot
.55608 .28861 Mdot
.5368 .35943 Mdot
.50783 .34978 Mdot
.54093 .72946 Mdot
.35282 .65586 Mdot
.55634 .28463 Mdot
.56955 .33118 Mdot
.61567 .5432 Mdot
.59454 .5354 Mdot
.49056 .35131 Mdot
.30341 .68538 Mdot
.52134 .72224 Mdot
.33281 .66274 Mdot
.54871 .14262 Mdot
.32421 .4426 Mdot
.72037 .44849 Mdot
.59454 .54307 Mdot
.30026 .8231 Mdot
.58202 .51433 Mdot
.67119 .50427 Mdot
.49194 .34062 Mdot
.56461 .72089 Mdot
.52745 .70779 Mdot
.51003 .32657 Mdot
.56055 .35096 Mdot
.55181 .71603 Mdot
.4293 .51983 Mdot
.62948 .19745 Mdot
.48057 .46044 Mdot
.5184 .30505 Mdot
.62078 .3428 Mdot
.27068 .45818 Mdot
.50782 .28963 Mdot
.34466 .472 Mdot
.3805 .66675 Mdot
.35971 .6257 Mdot
.27674 .46124 Mdot
.60876 .50176 Mdot
.34722 .68824 Mdot
.66615 .44626 Mdot
.45542 .26502 Mdot
.2329 .48507 Mdot
.83048 .45153 Mdot
.66461 .47624 Mdot
.61042 .61494 Mdot
.35019 .3968 Mdot
.66377 .54321 Mdot
.736 .53575 Mdot
.54367 .70777 Mdot
.50335 .29091 Mdot
.2757 .44175 Mdot
.45694 .19555 Mdot
.64001 .50938 Mdot
.50944 .30987 Mdot
.31464 .43655 Mdot
.43269 .25412 Mdot
.41588 .5546 Mdot
.63164 .54348 Mdot
.54582 .90835 Mdot
.50335 .35569 Mdot
.3757 .64064 Mdot
.70729 .42236 Mdot
.52699 .28627 Mdot
.42173 .68016 Mdot
.37899 .61806 Mdot
.50257 .45746 Mdot
.51745 .35979 Mdot
.54204 .676 Mdot
.53045 .34319 Mdot
.55141 .73118 Mdot
.55888 .35906 Mdot
.35792 .67729 Mdot
.65972 .50089 Mdot
.36153 .67468 Mdot
.54709 .69349 Mdot
.34936 .69335 Mdot
.2759 .44167 Mdot
.4074 .4099 Mdot
.29304 .44443 Mdot
.52625 .56357 Mdot
.71331 .30611 Mdot
.29719 .47949 Mdot
.38916 .51755 Mdot
.65355 .53314 Mdot
.51736 .3763 Mdot
.37951 .64583 Mdot
.34757 .7019 Mdot
.48012 .50384 Mdot
.50271 .33793 Mdot
.35242 .68006 Mdot
.62046 .35344 Mdot
.34579 .81188 Mdot
.60702 .45369 Mdot
.20048 .63398 Mdot
.51144 .31518 Mdot
.32026 .66827 Mdot
.47753 .43522 Mdot
.55827 .32334 Mdot
.37618 .63212 Mdot
.29282 .47368 Mdot
.31897 .4475 Mdot
.63672 .46953 Mdot
.27043 .48074 Mdot
.32836 .64705 Mdot
.75798 .31616 Mdot
.52909 .3521 Mdot
.39303 .23795 Mdot
.54141 .69484 Mdot
.37937 .65981 Mdot
.58451 .49438 Mdot
.56511 .36838 Mdot
.39116 .64847 Mdot
.19596 .4236 Mdot
.48983 .14993 Mdot
.35172 .68039 Mdot
.53817 .34826 Mdot
.54155 .32606 Mdot
.65301 .44562 Mdot
.48797 .48755 Mdot
.345 .67555 Mdot
.28607 .56134 Mdot
.60741 .65685 Mdot
.42667 .4147 Mdot
.8016 .56329 Mdot
.60783 .51793 Mdot
.59967 .51672 Mdot
.31633 .47434 Mdot
.66254 .51173 Mdot
.56565 .33954 Mdot
.58191 .51926 Mdot
.3004 .48754 Mdot
.3504 .69625 Mdot
.64589 .51234 Mdot
.54515 .70384 Mdot
.2854 .48243 Mdot
.32422 .47654 Mdot
.37405 .67523 Mdot
.52445 .35487 Mdot
.29992 .35768 Mdot
.35929 .66209 Mdot
.59904 .50271 Mdot
.40911 .41535 Mdot
.58495 .53819 Mdot
.30029 .53046 Mdot
.55145 .29732 Mdot
.3718 .63634 Mdot
.48641 .33778 Mdot
.29973 .46214 Mdot
.32667 .69224 Mdot
.6705 .52674 Mdot
.35765 .62824 Mdot
.38327 .55423 Mdot
.41409 .73887 Mdot
.56707 .34132 Mdot
.4247 .60166 Mdot
.54931 .35443 Mdot
.42796 .41572 Mdot
.66573 .68371 Mdot
.52965 .72296 Mdot
.33022 .65678 Mdot
.43721 .22828 Mdot
.38434 .65247 Mdot
.65537 .52054 Mdot
.61809 .50903 Mdot
.34379 .64702 Mdot
.52963 .72981 Mdot
.58549 .76765 Mdot
.48782 .69004 Mdot
.55043 .32387 Mdot
.43777 .57457 Mdot
.57682 .15322 Mdot
.40479 .64001 Mdot
.28122 .45283 Mdot
.70894 .57668 Mdot
.64988 .54204 Mdot
.30863 .43406 Mdot
.33446 .45708 Mdot
.55864 .70718 Mdot
.38169 .65949 Mdot
.52794 .27824 Mdot
.27422 .44837 Mdot
.57449 .3555 Mdot
.60505 .71767 Mdot
.60884 .57255 Mdot
.5535 .44482 Mdot
.68259 .49913 Mdot
.47141 .51755 Mdot
.29348 .4882 Mdot
.63216 .49487 Mdot
.71857 .5055 Mdot
.30992 .47247 Mdot
.5606 .71443 Mdot
.57795 .37353 Mdot
.35647 .68322 Mdot
.32129 .81668 Mdot
.67087 .48687 Mdot
.6577 .50442 Mdot
.32283 .46312 Mdot
.75774 .46541 Mdot
.52794 .30037 Mdot
.52852 .35467 Mdot
.36645 .65187 Mdot
.44899 .47553 Mdot
.63271 .46909 Mdot
.67638 .5065 Mdot
.34869 .68632 Mdot
.40636 .42238 Mdot
.82991 .52291 Mdot
.63087 .50544 Mdot
.31268 .45462 Mdot
.36423 .54903 Mdot
.28677 .4865 Mdot
.67946 .53487 Mdot
.65204 .52425 Mdot
.67909 .51227 Mdot
.66803 .47432 Mdot
.27657 .45117 Mdot
.67177 .52863 Mdot
.6267 .57749 Mdot
.51808 .32271 Mdot
.60264 .51566 Mdot
.60972 .65575 Mdot
.63531 .50495 Mdot
.54335 .70199 Mdot
.462 .44479 Mdot
.62592 .48011 Mdot
.60179 .51436 Mdot
.60363 .65683 Mdot
.66331 .49487 Mdot
.31174 .43533 Mdot
.53905 .31951 Mdot
.30039 .46349 Mdot
.2835 .45578 Mdot
.38884 .6419 Mdot
.55124 .73394 Mdot
.66531 .4612 Mdot
.55083 .72198 Mdot
.62722 .44268 Mdot
.56499 .54681 Mdot
.50966 .54446 Mdot
.47464 .44093 Mdot
.50328 .69497 Mdot
.67424 .51623 Mdot
.3712 .65573 Mdot
.36935 .63392 Mdot
.42884 .59483 Mdot
.57113 .49546 Mdot
.2706 .44922 Mdot
.28428 .47247 Mdot
.48255 .69006 Mdot
.46876 .6709 Mdot
.54823 .71504 Mdot
.54166 .61127 Mdot
.64506 .56565 Mdot
.61555 .4911 Mdot
.56048 .5295 Mdot
.38839 .63172 Mdot
.40706 .40909 Mdot
.36631 .69316 Mdot
.45309 .40289 Mdot
.26833 .46103 Mdot
.66412 .47625 Mdot
.20319 .37033 Mdot
.55159 .31749 Mdot
.53928 .31874 Mdot
.30169 .48768 Mdot
.32689 .66786 Mdot
.56534 .51191 Mdot
.24003 .72451 Mdot
.56243 .32519 Mdot
.50581 .6997 Mdot
.65845 .48528 Mdot
.3771 .66934 Mdot
.55264 .33752 Mdot
.51284 .73385 Mdot
.67247 .48043 Mdot
.36268 .61355 Mdot
.63903 .49656 Mdot
.66894 .34705 Mdot
.516 .33299 Mdot
.51141 .50831 Mdot
.49855 .36492 Mdot
.28343 .44609 Mdot
.30482 .46929 Mdot
.64769 .52312 Mdot
.27826 .77021 Mdot
.56835 .2856 Mdot
.33454 .43929 Mdot
.51389 .73302 Mdot
.40258 .41521 Mdot
.52034 .73615 Mdot
.3503 .64308 Mdot
.54215 .71834 Mdot
.39064 .64925 Mdot
.30451 .69381 Mdot
.52703 .27177 Mdot
.51758 .69866 Mdot
.77039 .47777 Mdot
.60468 .46828 Mdot
.55353 .69872 Mdot
.58668 .51046 Mdot
.62303 .44066 Mdot
.35774 .68813 Mdot
.54409 .72637 Mdot
.62871 .53518 Mdot
.35387 .23642 Mdot
.29162 .46738 Mdot
.27412 .44456 Mdot
.603 .47043 Mdot
.3209 .6571 Mdot
.56252 .35265 Mdot
.48333 .54172 Mdot
.42185 .40297 Mdot
.67613 .5043 Mdot
.68506 .50416 Mdot
.50112 .35627 Mdot
.51008 .30175 Mdot
.64767 .52511 Mdot
.60727 .33698 Mdot
.66655 .53146 Mdot
.32096 .45003 Mdot
.5507 .32156 Mdot
.5419 .32254 Mdot
.33346 .63922 Mdot
.54959 .35044 Mdot
.68126 .5643 Mdot
.25069 .45961 Mdot
.57689 .53951 Mdot
.30105 .45956 Mdot
.31219 .63085 Mdot
.3824 .67608 Mdot
.43476 .22638 Mdot
.54804 .3512 Mdot
.61916 .55626 Mdot
.55266 .31082 Mdot
.5308 .69136 Mdot
.53772 .3113 Mdot
.50874 .3666 Mdot
.63693 .47298 Mdot
.63752 .53361 Mdot
.40868 .42154 Mdot
.48612 .49594 Mdot
.51975 .33773 Mdot
.65295 .54812 Mdot
.60107 .55308 Mdot
.61925 .51317 Mdot
.50247 .54675 Mdot
.48922 .32801 Mdot
.68629 .43395 Mdot
.31348 .51748 Mdot
.51991 .34258 Mdot
.51974 .16799 Mdot
.41256 .43014 Mdot
.43265 .43063 Mdot
.3361 .47243 Mdot
.63016 .5088 Mdot
.35259 .6688 Mdot
.5982 .51587 Mdot
.577 .47846 Mdot
.63282 .47884 Mdot
.5152 .69837 Mdot
.61867 .47213 Mdot
.42425 .42264 Mdot
.36328 .66616 Mdot
.65231 .54685 Mdot
.64114 .51503 Mdot
.42797 .43246 Mdot
.49158 .35598 Mdot
.53953 .35828 Mdot
.38463 .41698 Mdot
.5569 .70687 Mdot
.29826 .48388 Mdot
.59775 .50607 Mdot
.3684 .65394 Mdot
.3591 .67143 Mdot
.5349 .29038 Mdot
.34189 .6805 Mdot
.29748 .48552 Mdot
.67074 .51213 Mdot
.28244 .44682 Mdot
.51549 .69806 Mdot
.53658 .34905 Mdot
.59775 .49489 Mdot
.61891 .54263 Mdot
.50923 .33598 Mdot
.64939 .53641 Mdot
.51491 .69574 Mdot
.37342 .6224 Mdot
.53742 .30656 Mdot
.29256 .45045 Mdot
.33803 .63362 Mdot
.61593 .54998 Mdot
.39915 .1607 Mdot
.66274 .513 Mdot
.67761 .50099 Mdot
.48497 .25019 Mdot
.6186 .56215 Mdot
.38406 .65787 Mdot
.55539 .31923 Mdot
.6877 .51395 Mdot
.60507 .66016 Mdot
.57051 .69777 Mdot
.39748 .62979 Mdot
.66292 .48613 Mdot
.49188 .18723 Mdot
.60404 .55199 Mdot
.45114 .22597 Mdot
.50932 .54321 Mdot
.19457 .51039 Mdot
.55408 .44426 Mdot
.33623 .44056 Mdot
.40585 .41959 Mdot
.38618 .66591 Mdot
.75187 .42747 Mdot
.65833 .52464 Mdot
.7682 .3622 Mdot
.59621 .498 Mdot
.31698 .45039 Mdot
.73137 .5364 Mdot
.33387 .6676 Mdot
.79772 .56214 Mdot
.6092 .50993 Mdot
.50073 .35186 Mdot
.3182 .68388 Mdot
.40356 .42466 Mdot
.63073 .53105 Mdot
.5519 .70761 Mdot
.53324 .66839 Mdot
.68534 .56089 Mdot
.29815 .45961 Mdot
.61718 .49533 Mdot
.68128 .46032 Mdot
.35734 .80738 Mdot
.52044 .31622 Mdot
.28412 .4653 Mdot
.51714 .6439 Mdot
.62089 .51283 Mdot
.53566 .35912 Mdot
.53625 .31979 Mdot
.55525 .72184 Mdot
.2715 .41353 Mdot
.54445 .78129 Mdot
.24132 .29988 Mdot
.79355 .39922 Mdot
.38476 .6274 Mdot
.52672 .39755 Mdot
.60502 .52878 Mdot
.75181 .66109 Mdot
.28499 .45228 Mdot
.65823 .50083 Mdot
.76966 .38872 Mdot
.52559 .31274 Mdot
.63349 .49895 Mdot
.52136 .72114 Mdot
.3141 .37883 Mdot
.6334 .37669 Mdot
.41487 .1746 Mdot
.33639 .6192 Mdot
.57834 .49683 Mdot
.65051 .57724 Mdot
.42596 .40635 Mdot
.68268 .52777 Mdot
.37978 .64858 Mdot
.33689 .55101 Mdot
.51424 .72303 Mdot
.55262 .32076 Mdot
.40852 .42908 Mdot
.59527 .4991 Mdot
.59195 .56057 Mdot
.50441 .70635 Mdot
.62416 .52466 Mdot
.69501 .41799 Mdot
.41997 .4388 Mdot
.34839 .62656 Mdot
.50029 .3492 Mdot
.68305 .50469 Mdot
.40349 .4166 Mdot
.62767 .47473 Mdot
.74692 .56311 Mdot
.64782 .48363 Mdot
.51268 .23148 Mdot
.5121 .3435 Mdot
.29207 .45826 Mdot
.6205 .47022 Mdot
.64339 .5015 Mdot
.44473 .68423 Mdot
.56805 .50469 Mdot
.61441 .48662 Mdot
.53509 .28767 Mdot
.55144 .31441 Mdot
.50906 .30782 Mdot
.33755 .63647 Mdot
.48431 .46257 Mdot
.30712 .44806 Mdot
.56095 .52539 Mdot
.27091 .45198 Mdot
.56142 .4353 Mdot
.50733 .72119 Mdot
.42149 .22292 Mdot
.66534 .52278 Mdot
.50309 .34311 Mdot
.66309 .22581 Mdot
.50572 .30025 Mdot
.33969 .49272 Mdot
.2867 .45469 Mdot
.52189 .3305 Mdot
.66499 .49338 Mdot
.49303 .48097 Mdot
.37981 .18182 Mdot
.31142 .43784 Mdot
.56806 .52001 Mdot
.34338 .61209 Mdot
.36708 .69853 Mdot
.54501 .17992 Mdot
.29736 .4382 Mdot
.34465 .39664 Mdot
.62753 .55592 Mdot
.55547 .33014 Mdot
.29027 .4806 Mdot
.32796 .43903 Mdot
.34317 .68323 Mdot
.62667 .54571 Mdot
.64125 .50056 Mdot
.42406 .42982 Mdot
.27351 .46232 Mdot
.56057 .4582 Mdot
.63588 .54271 Mdot
.4604 .27621 Mdot
.55066 .28516 Mdot
.54257 .85554 Mdot
.71706 .47722 Mdot
.7685 .38232 Mdot
.34393 .59 Mdot
.53695 .30391 Mdot
.60737 .50335 Mdot
.56267 .52266 Mdot
.37271 .61979 Mdot
.66861 .51041 Mdot
.32625 .68037 Mdot
.28865 .44245 Mdot
.42719 .21307 Mdot
.40229 .50491 Mdot
.25085 .44122 Mdot
.66014 .51357 Mdot
.62662 .37567 Mdot
.51869 .70031 Mdot
.2951 .42635 Mdot
.52119 .29832 Mdot
.66874 .54519 Mdot
.39329 .63544 Mdot
.33662 .63906 Mdot
.53 .31824 Mdot
.41647 .37814 Mdot
.44126 .22513 Mdot
.67423 .47766 Mdot
.35345 .63741 Mdot
.39632 .4595 Mdot
.58627 .26207 Mdot
.33325 .47179 Mdot
.51191 .72041 Mdot
.38484 .66458 Mdot
.26108 .46395 Mdot
.61303 .44318 Mdot
.52837 .32855 Mdot
.50925 .36007 Mdot
.42806 .64219 Mdot
.35065 .67719 Mdot
.52715 .71533 Mdot
.42687 .58798 Mdot
.43523 .58639 Mdot
.51404 .71343 Mdot
.32627 .6871 Mdot
.54401 .30574 Mdot
.50646 .31599 Mdot
.53902 .32093 Mdot
.72749 .45211 Mdot
.55613 .30656 Mdot
.66108 .75971 Mdot
.67524 .53821 Mdot
.60853 .31257 Mdot
.65114 .55397 Mdot
.28542 .43671 Mdot
.51536 .33444 Mdot
.50846 .53499 Mdot
.63406 .56765 Mdot
.39744 .1805 Mdot
.63933 .48735 Mdot
.37978 .54551 Mdot
.63119 .51 Mdot
.68203 .39204 Mdot
.50636 .28762 Mdot
.67243 .52378 Mdot
.24721 .46844 Mdot
.54008 .70241 Mdot
.52714 .26827 Mdot
.61458 .488 Mdot
.40749 .34091 Mdot
.58668 .51165 Mdot
.47169 .2162 Mdot
.38848 .71756 Mdot
.52869 .6805 Mdot
.59433 .55184 Mdot
.39428 .66292 Mdot
.66886 .60814 Mdot
.61735 .32818 Mdot
.30995 .43779 Mdot
.62265 .36861 Mdot
.33508 .67703 Mdot
.73564 .53051 Mdot
.66628 .55742 Mdot
.5203 .72786 Mdot
.58074 .36857 Mdot
.32265 .45294 Mdot
.65804 .52717 Mdot
.61011 .50658 Mdot
.23197 .4991 Mdot
.62717 .33963 Mdot
.54639 .52772 Mdot
.49999 .70899 Mdot
.63714 .37183 Mdot
.62591 .48201 Mdot
.39563 .62786 Mdot
.55803 .32949 Mdot
.70829 .56199 Mdot
.75465 .48634 Mdot
.65766 .5441 Mdot
.52326 .32594 Mdot
.54609 .35479 Mdot
.70036 .24298 Mdot
.51338 .72678 Mdot
.64571 .48382 Mdot
.42642 .6567 Mdot
.59862 .5005 Mdot
.31266 .44731 Mdot
.65302 .56363 Mdot
.37693 .68038 Mdot
.47994 .4254 Mdot
.33548 .63903 Mdot
.6303 .52325 Mdot
.53291 .34487 Mdot
.32245 .4604 Mdot
.19521 .55839 Mdot
.35365 .42562 Mdot
.6586 .76024 Mdot
.53317 .66679 Mdot
.5498 .71016 Mdot
.53262 .73814 Mdot
.34483 .43089 Mdot
.66587 .48982 Mdot
.46738 .52131 Mdot
.59919 .45551 Mdot
.62612 .51027 Mdot
.64624 .48117 Mdot
.36198 .43098 Mdot
.2876 .45547 Mdot
.36404 .67785 Mdot
.6484 .52587 Mdot
.65328 .5483 Mdot
.52577 .34082 Mdot
.54664 .71685 Mdot
.3663 .62223 Mdot
.54782 .69618 Mdot
.36664 .66269 Mdot
.58422 .17327 Mdot
.58397 .56207 Mdot
.53795 .70138 Mdot
.28269 .48355 Mdot
.50056 .32192 Mdot
.43162 .42807 Mdot
.34924 .64527 Mdot
.33494 .66893 Mdot
.66996 .53301 Mdot
.54008 .35091 Mdot
.53858 .35589 Mdot
.55148 .71566 Mdot
.28751 .47521 Mdot
.6814 .47732 Mdot
.6377 .53709 Mdot
.19973 .58746 Mdot
.36641 .61916 Mdot
.62826 .36271 Mdot
.50657 .24073 Mdot
.66955 .49265 Mdot
.53148 .35859 Mdot
.64875 .5086 Mdot
.3802 .47641 Mdot
.50709 .30788 Mdot
.62806 .56389 Mdot
.58199 .45283 Mdot
.38714 .63093 Mdot
.78359 .3239 Mdot
.65533 .46061 Mdot
.25735 .48942 Mdot
.61272 .53292 Mdot
.84471 .38906 Mdot
.67984 .23716 Mdot
.59619 .49158 Mdot
.66248 .47273 Mdot
.25687 .27513 Mdot
.59262 .54268 Mdot
.42366 .42703 Mdot
.57527 .481 Mdot
.53269 .35994 Mdot
.40456 .5554 Mdot
.47505 .51122 Mdot
.52287 .73388 Mdot
.36728 .65157 Mdot
.62147 .72646 Mdot
.55836 .72354 Mdot
.51464 .31211 Mdot
.58802 .56 Mdot
.51306 .24207 Mdot
.36365 .70401 Mdot
.69192 .52035 Mdot
.31461 .44821 Mdot
.47394 .51038 Mdot
.37332 .68901 Mdot
.29143 .44989 Mdot
.60548 .55364 Mdot
.32112 .74968 Mdot
.24579 .48568 Mdot
.71149 .24526 Mdot
.31492 .47457 Mdot
.29323 .46541 Mdot
.49256 .46828 Mdot
.52395 .73422 Mdot
.26131 .5318 Mdot
.65538 .58193 Mdot
.32026 .44067 Mdot
.71403 .63371 Mdot
.3544 .61686 Mdot
.45856 .47292 Mdot
.50943 .28731 Mdot
.57282 .55576 Mdot
.65718 .49069 Mdot
.30002 .47631 Mdot
.50665 .38813 Mdot
.47927 .6527 Mdot
.29948 .4402 Mdot
.66234 .57041 Mdot
.45714 .46295 Mdot
.4083 .41224 Mdot
.4158 .43195 Mdot
.50864 .72927 Mdot
.43475 .77843 Mdot
.51193 .34668 Mdot
.50912 .69604 Mdot
.51929 .50764 Mdot
.63096 .48839 Mdot
.27211 .45823 Mdot
.41792 .43493 Mdot
.29627 .45051 Mdot
.52726 .70322 Mdot
.50405 .71419 Mdot
.5184 .32141 Mdot
.53041 .29932 Mdot
.55085 .24621 Mdot
.64676 .63408 Mdot
.59745 .52426 Mdot
.72497 .30159 Mdot
.51179 .30134 Mdot
.75472 .44539 Mdot
.54322 .73079 Mdot
.53819 .72586 Mdot
.63789 .29466 Mdot
.61248 .54627 Mdot
.3676 .54879 Mdot
.62295 .48137 Mdot
.70188 .66182 Mdot
.5939 .49984 Mdot
.34528 .68361 Mdot
.60929 .51508 Mdot
.29832 .34448 Mdot
.64721 .54822 Mdot
.64512 .47949 Mdot
.35003 .6521 Mdot
.67662 .47045 Mdot
.36895 .68683 Mdot
.60988 .49865 Mdot
.56172 .73691 Mdot
.3679 .65386 Mdot
.5429 .74784 Mdot
.41323 .53673 Mdot
.41435 .42466 Mdot
.53002 .73695 Mdot
.54939 .70402 Mdot
.59589 .69916 Mdot
.53416 .29546 Mdot
.7418 .50621 Mdot
.65978 .48722 Mdot
.33124 .63387 Mdot
.27821 .47729 Mdot
.65916 .54331 Mdot
.58097 .51895 Mdot
.67284 .46344 Mdot
.51997 .32426 Mdot
.32186 .67765 Mdot
.5348 .70473 Mdot
.36697 .63197 Mdot
.55216 .74353 Mdot
.38972 .66775 Mdot
.64039 .45464 Mdot
.62018 .44313 Mdot
.63552 .57725 Mdot
.75117 .35478 Mdot
.77211 .67688 Mdot
.52996 .3238 Mdot
.41343 .41438 Mdot
.50708 .72147 Mdot
.44096 .57662 Mdot
.51084 .34936 Mdot
.33637 .66943 Mdot
.63923 .49637 Mdot
.63738 .58095 Mdot
.58133 .57167 Mdot
.57617 .32647 Mdot
.50313 .73904 Mdot
.35833 .64488 Mdot
.42165 .40938 Mdot
.47779 .46197 Mdot
.4754 .31159 Mdot
.52116 .55523 Mdot
.64592 .50505 Mdot
.55272 .71383 Mdot
.55271 .33727 Mdot
.29064 .5395 Mdot
.29678 .47482 Mdot
.48705 .49147 Mdot
.66133 .51137 Mdot
.39644 .39354 Mdot
.53363 .34409 Mdot
.52518 .7265 Mdot
.3016 .47614 Mdot
.52302 .73224 Mdot
.39995 .42445 Mdot
.39107 .41063 Mdot
.62729 .52997 Mdot
.61733 .48274 Mdot
.26935 .46329 Mdot
.51465 .34802 Mdot
.57119 .72481 Mdot
.22802 .49163 Mdot
.34788 .64371 Mdot
.4389 .48922 Mdot
.55292 .32764 Mdot
.35762 .41066 Mdot
.35294 .63164 Mdot
.26299 .46495 Mdot
.47226 .52134 Mdot
.30952 .48436 Mdot
.63373 .48099 Mdot
.54535 .33494 Mdot
.30161 .43658 Mdot
.2091 .58838 Mdot
.50888 .20702 Mdot
.58196 .32192 Mdot
.64564 .53183 Mdot
.42164 .21961 Mdot
.3789 .36229 Mdot
.55398 .40279 Mdot
.27615 .44715 Mdot
.65143 .51835 Mdot
.67542 .47895 Mdot
.60933 .51096 Mdot
.29285 .46994 Mdot
.23145 .43394 Mdot
.3337 .65179 Mdot
.62922 .49584 Mdot
.53954 .69382 Mdot
.37405 .6808 Mdot
.3826 .68979 Mdot
.38618 .66137 Mdot
.51246 .29993 Mdot
.59405 .56459 Mdot
.56922 .57685 Mdot
.76102 .29185 Mdot
.2921 .46221 Mdot
.41479 .42459 Mdot
.67806 .49647 Mdot
.63868 .75971 Mdot
.50427 .31682 Mdot
.34451 .65161 Mdot
.65743 .50229 Mdot
.41412 .69482 Mdot
.40867 .43854 Mdot
.35533 .65714 Mdot
.51846 .30038 Mdot
.55393 .40421 Mdot
.669 .51216 Mdot
.61065 .5344 Mdot
.50493 .32675 Mdot
.35372 .38158 Mdot
.47467 .45945 Mdot
.64661 .51014 Mdot
.29038 .45523 Mdot
.31701 .80154 Mdot
.62277 .5601 Mdot
.54475 .38328 Mdot
.40745 .40761 Mdot
.4636 .30569 Mdot
.61313 .3543 Mdot
.59553 .4651 Mdot
.38064 .21136 Mdot
.61648 .77649 Mdot
.44406 .19736 Mdot
.70026 .67467 Mdot
.22573 .47416 Mdot
.63576 .18799 Mdot
.24963 .47323 Mdot
.67476 .37797 Mdot
.1874 .42159 Mdot
.364 .39346 Mdot
.38586 .73279 Mdot
.21992 .55507 Mdot
.30897 .72868 Mdot
.81361 .54859 Mdot
.38928 .6753 Mdot
.73036 .65755 Mdot
.60909 .48515 Mdot
.35701 .371 Mdot
.66652 .38916 Mdot
.72705 .73395 Mdot
.42201 .22905 Mdot
.42606 .66805 Mdot
.36886 .17559 Mdot
.42826 .24424 Mdot
.5755 .22531 Mdot
.76523 .51765 Mdot
.47282 .79711 Mdot
.43801 .58769 Mdot
.62497 .73824 Mdot
.62032 .38227 Mdot
.30238 .326 Mdot
.24422 .46826 Mdot
.67146 .26356 Mdot
.38763 .82366 Mdot
.37131 .64183 Mdot
.55828 .33272 Mdot
.24981 .5316 Mdot
.5593 .22082 Mdot
.29913 .50661 Mdot
.38074 .21106 Mdot
.47071 .25716 Mdot
.67875 .38871 Mdot
.51338 .50791 Mdot
.66908 .33848 Mdot
.56833 .78405 Mdot
.77845 .58103 Mdot
.56553 .35997 Mdot
.22959 .58316 Mdot
.44127 .5869 Mdot
.58106 .73451 Mdot
.70542 .41212 Mdot
.50638 .73023 Mdot
.52661 .74266 Mdot
.51422 .30301 Mdot
.58315 .2538 Mdot
.4289 .43666 Mdot
.52111 .5061 Mdot
.39745 .64212 Mdot
.38359 .48086 Mdot
.32064 .37331 Mdot
.3943 .36602 Mdot
.81652 .39152 Mdot
.4292 .15728 Mdot
.64371 .66095 Mdot
.32698 .54534 Mdot
.30929 .50218 Mdot
.61892 .7502 Mdot
.56098 .5785 Mdot
.67238 .64024 Mdot
.75252 .55586 Mdot
.29743 .21656 Mdot
.42359 .33319 Mdot
.36045 .17263 Mdot
.54781 .3687 Mdot
.71814 .52052 Mdot
.3466 .53071 Mdot
.79441 .41886 Mdot
.59308 .66429 Mdot
.42594 .16387 Mdot
.53463 .6783 Mdot
.51195 .2816 Mdot
.36484 .39456 Mdot
.68737 .4141 Mdot
.5488 .76799 Mdot
.51249 .66375 Mdot
.71006 .55906 Mdot
.29425 .20792 Mdot
.36957 .21607 Mdot
.63106 .20898 Mdot
.4568 .28786 Mdot
.39865 .69102 Mdot
.38805 .68473 Mdot
.32711 .43691 Mdot
.54073 .19662 Mdot
.5405 .33655 Mdot
.77107 .29799 Mdot
.50969 .21517 Mdot
.67431 .60849 Mdot
.27365 .22565 Mdot
.82367 .51505 Mdot
.60732 .31637 Mdot
.72712 .70646 Mdot
.25807 .71217 Mdot
.55242 .57588 Mdot
.33754 .4088 Mdot
.36894 .60874 Mdot
.51198 .22802 Mdot
.5291 .19081 Mdot
.72858 .61997 Mdot
.22125 .34441 Mdot
.52275 .50415 Mdot
.34706 .59685 Mdot
.56448 .28432 Mdot
.37956 .74629 Mdot
.56129 .64137 Mdot
.36905 .17019 Mdot
.64492 .37872 Mdot
.298 .77265 Mdot
.67802 .68438 Mdot
.75598 .46568 Mdot
.3706 .23303 Mdot
.3145 .71656 Mdot
.66746 .62283 Mdot
.41511 .35114 Mdot
.57175 .51878 Mdot
.54965 .60845 Mdot
.74139 .5382 Mdot
.50092 .75661 Mdot
.4857 .4569 Mdot
.41828 .29894 Mdot
.64778 .69144 Mdot
.21042 .45134 Mdot
.74656 .4888 Mdot
.49229 .32849 Mdot
.65167 .64396 Mdot
.67311 .66797 Mdot
.44629 .30371 Mdot
.52118 .64284 Mdot
.62038 .20223 Mdot
.49598 .64804 Mdot
.59072 .46615 Mdot
.67285 .37157 Mdot
.62177 .38594 Mdot
.6944 .64679 Mdot
.63088 .46047 Mdot
.80119 .36613 Mdot
.46394 .28266 Mdot
.73073 .33837 Mdot
.62304 .69377 Mdot
.74458 .34843 Mdot
.53256 .21267 Mdot
.34598 .52597 Mdot
.32137 .40424 Mdot
.53899 .39581 Mdot
.29847 .20618 Mdot
.36829 .68068 Mdot
.70825 .63051 Mdot
.24939 .47967 Mdot
.20379 .58081 Mdot
.22137 .49752 Mdot
.48461 .64975 Mdot
.55532 .19783 Mdot
.39254 .37721 Mdot
.31241 .6876 Mdot
.2907 .31487 Mdot
.40713 .4553 Mdot
.71896 .30236 Mdot
.70639 .48444 Mdot
.72807 .57859 Mdot
.51385 .6963 Mdot
.76425 .42294 Mdot
.32091 .52082 Mdot
.47819 .74015 Mdot
.60433 .462 Mdot
.43102 .62646 Mdot
.42905 .41499 Mdot
.46833 .49989 Mdot
.58129 .17057 Mdot
.69949 .46575 Mdot
.81842 .52285 Mdot
.38063 .37378 Mdot
.46495 .51523 Mdot
.58807 .70718 Mdot
.46814 .35815 Mdot
.34545 .17723 Mdot
.5688 .19013 Mdot
.36972 .34711 Mdot
.41691 .2171 Mdot
.8561 .53861 Mdot
.19735 .49791 Mdot
.80974 .44232 Mdot
.24861 .4787 Mdot
.68664 .83719 Mdot
.36071 .62991 Mdot
.76395 .65576 Mdot
.79105 .41865 Mdot
.43247 .68795 Mdot
.55754 .22075 Mdot
.63804 .39724 Mdot
.5664 .66328 Mdot
.49925 .36222 Mdot
.62348 .45793 Mdot
.45253 .16873 Mdot
.31133 .20101 Mdot
.4441 .1682 Mdot
.4234 .39237 Mdot
.4579 .1824 Mdot
.25822 .26361 Mdot
.66445 .759 Mdot
.24452 .5118 Mdot
.66498 .55382 Mdot
.71954 .61209 Mdot
.82416 .49613 Mdot
.50477 .68234 Mdot
.54554 .55648 Mdot
.56901 .35423 Mdot
.25531 .25881 Mdot
.5825 .16924 Mdot
.66106 .30416 Mdot
.58822 .23736 Mdot
.37013 .56531 Mdot
.68533 .63163 Mdot
.57489 .21433 Mdot
.31411 .30502 Mdot
.45907 .25999 Mdot
.23973 .28608 Mdot
.66785 .67571 Mdot
.21985 .56028 Mdot
.36449 .33776 Mdot
.82025 .47317 Mdot
.37075 .2291 Mdot
.24036 .52893 Mdot
.65458 .62077 Mdot
.53522 .26266 Mdot
.4803 .65406 Mdot
.2985 .32134 Mdot
.35545 .54728 Mdot
.61888 .67798 Mdot
.3464 .69303 Mdot
.72437 .61874 Mdot
.49508 .57526 Mdot
.24424 .51257 Mdot
.60923 .71283 Mdot
.73729 .61599 Mdot
.39365 .32012 Mdot
.45031 .17582 Mdot
.38179 .37505 Mdot
.25428 .71598 Mdot
.38853 .25125 Mdot
.73807 .54564 Mdot
.67541 .46826 Mdot
.54265 .20526 Mdot
.52303 .15031 Mdot
.55758 .19631 Mdot
.44133 .38586 Mdot
.4201 .66114 Mdot
.2709 .48145 Mdot
.61166 .74319 Mdot
.45338 .66746 Mdot
.47086 .23655 Mdot
.46264 .57183 Mdot
.26144 .44737 Mdot
.31309 .38109 Mdot
.54756 .24435 Mdot
.63205 .75887 Mdot
.65989 .26245 Mdot
.54666 .49013 Mdot
.59335 .27368 Mdot
.50374 .35917 Mdot
.41784 .38636 Mdot
.68185 .63842 Mdot
.37373 .67634 Mdot
.20295 .59747 Mdot
.50389 .38359 Mdot
.71966 .50986 Mdot
.3366 .55572 Mdot
.57551 .29692 Mdot
.76658 .37201 Mdot
.31513 .68674 Mdot
.6084 .17917 Mdot
.81262 .39354 Mdot
.57541 .21355 Mdot
.64888 .65098 Mdot
.21427 .60105 Mdot
.46933 .48527 Mdot
.29655 .49803 Mdot
.4218 .23517 Mdot
.43644 .53301 Mdot
.66106 .64743 Mdot
.59458 .28617 Mdot
.26077 .5131 Mdot
.57658 .48351 Mdot
.65408 .21878 Mdot
.65702 .75116 Mdot
.45727 .49498 Mdot
.47997 .28266 Mdot
.56178 .31847 Mdot
.79173 .66201 Mdot
.3102 .33462 Mdot
.62413 .60885 Mdot
.39665 .2211 Mdot
.3412 .4579 Mdot
.49777 .31971 Mdot
.74729 .60583 Mdot
.41913 .73624 Mdot
.57722 .27692 Mdot
.37131 .52742 Mdot
.56603 .22404 Mdot
.41206 .52013 Mdot
.40971 .21511 Mdot
.35699 .20712 Mdot
.32271 .79801 Mdot
.54262 .36964 Mdot
.30495 .54053 Mdot
.29954 .54518 Mdot
.57174 .33509 Mdot
.57162 .35575 Mdot
.63662 .37929 Mdot
.49414 .17082 Mdot
.42535 .56906 Mdot
.30726 .29985 Mdot
.4668 .51931 Mdot
.39379 .73367 Mdot
.27207 .52442 Mdot
.6163 .72019 Mdot
.32478 .24741 Mdot
.62267 .24828 Mdot
.17056 .59062 Mdot
.53999 .49941 Mdot
.76757 .64895 Mdot
.61155 .74398 Mdot
.76169 .52467 Mdot
.70408 .40864 Mdot
.44661 .2586 Mdot
.59971 .50883 Mdot
.44492 .1545 Mdot
.42464 .32003 Mdot
.54729 .61524 Mdot
.31076 .71791 Mdot
.60792 .54997 Mdot
.61363 .57004 Mdot
.57012 .21099 Mdot
.47484 .27689 Mdot
.164 .50232 Mdot
.69006 .67494 Mdot
.7239 .57219 Mdot
.60187 .3083 Mdot
.81802 .52161 Mdot
.36431 .51612 Mdot
.46574 .20365 Mdot
.49589 .58199 Mdot
.82747 .48386 Mdot
.30342 .28092 Mdot
.28564 .33543 Mdot
.38543 .24365 Mdot
.26837 .25313 Mdot
.70083 .58099 Mdot
.45464 .36791 Mdot
.26145 .53864 Mdot
.67539 .49104 Mdot
.418 .37777 Mdot
.39732 .22902 Mdot
.38689 .78727 Mdot
.57538 .59675 Mdot
.51572 .14764 Mdot
.56318 .47261 Mdot
.44066 .3583 Mdot
.19131 .44569 Mdot
.1629 .62824 Mdot
.29093 .34278 Mdot
.37548 .16833 Mdot
.28127 .32826 Mdot
.38709 .21889 Mdot
.34431 .45143 Mdot
.43233 .55021 Mdot
.75219 .33064 Mdot
.50103 .16923 Mdot
.4413 .76173 Mdot
.21632 .46024 Mdot
.71702 .28109 Mdot
.49357 .16573 Mdot
.57239 .46715 Mdot
.79449 .64757 Mdot
.37772 .70569 Mdot
.83973 .49726 Mdot
.81723 .42169 Mdot
.49152 .27193 Mdot
.71803 .63477 Mdot
.79514 .63114 Mdot
.70587 .74614 Mdot
.81232 .42133 Mdot
.7624 .56021 Mdot
.46763 .30058 Mdot
.63905 .65308 Mdot
.48332 .22293 Mdot
.81466 .56251 Mdot
.28969 .53113 Mdot
.44597 .42785 Mdot
.39487 .40798 Mdot
.51717 .23011 Mdot
.38809 .30419 Mdot
.34816 .53951 Mdot
.46952 .43229 Mdot
.55591 .22965 Mdot
.37165 .85456 Mdot
.25882 .33302 Mdot
.58863 .36193 Mdot
.3296 .19331 Mdot
.45517 .27097 Mdot
.44518 .57154 Mdot
.71411 .42226 Mdot
.63601 .74883 Mdot
.32388 .71014 Mdot
.63106 .47897 Mdot
.48578 .16786 Mdot
.31755 .69953 Mdot
.38577 .17484 Mdot
.72015 .25022 Mdot
.60529 .25711 Mdot
.69845 .47138 Mdot
.36366 .60615 Mdot
.78021 .56295 Mdot
.76555 .57481 Mdot
.32303 .20596 Mdot
.77137 .63856 Mdot
.43826 .504 Mdot
.39466 .53102 Mdot
.39603 .50946 Mdot
.6587 .60401 Mdot
.8277 .49886 Mdot
.46289 .33968 Mdot
.62881 .70449 Mdot
.35589 .34533 Mdot
.7008 .63749 Mdot
.61563 .35562 Mdot
.60864 .73635 Mdot
.51773 .62784 Mdot
.57289 .67578 Mdot
.35566 .6185 Mdot
.22167 .32383 Mdot
.42198 .25852 Mdot
.79286 .35013 Mdot
.2566 .71603 Mdot
.4172 .35377 Mdot
.7416 .65001 Mdot
.29568 .51487 Mdot
.56769 .5998 Mdot
.46074 .78591 Mdot
.6505 .70644 Mdot
.62798 .36969 Mdot
.45727 .22476 Mdot
.6978 .44615 Mdot
.53801 .18661 Mdot
.6176 .6822 Mdot
.19163 .39981 Mdot
.36484 .56928 Mdot
.7611 .40753 Mdot
.62277 .31792 Mdot
.2304 .68598 Mdot
.45787 .49785 Mdot
.29407 .20901 Mdot
.50246 .302 Mdot
.42533 .15813 Mdot
.31193 .47772 Mdot
.38714 .80866 Mdot
.4567 .24842 Mdot
.5326 .59672 Mdot
.50323 .55708 Mdot
.68107 .23189 Mdot
.37267 .38203 Mdot
.38867 .36367 Mdot
.48309 .65626 Mdot
.374 .69121 Mdot
.43204 .47781 Mdot
.31409 .29481 Mdot
.22346 .32671 Mdot
.68369 .48193 Mdot
.39684 .59891 Mdot
.77357 .57431 Mdot
.30476 .4987 Mdot
.47061 .27144 Mdot
.44499 .23524 Mdot
.59172 .38106 Mdot
.68031 .63206 Mdot
.26801 .2495 Mdot
.47785 .23916 Mdot
.47705 .63704 Mdot
.74273 .52179 Mdot
.24072 .48453 Mdot
.18129 .52204 Mdot
.34467 .22844 Mdot
.39695 .51893 Mdot
.47155 .46281 Mdot
.64651 .66191 Mdot
.53776 .13346 Mdot
.30429 .20886 Mdot
.19459 .63977 Mdot
.46198 .51794 Mdot
.49447 .36574 Mdot
.64123 .73256 Mdot
.19185 .39651 Mdot
.84352 .49073 Mdot
.38542 .33624 Mdot
.70799 .63376 Mdot
.37114 .7752 Mdot
.77985 .64961 Mdot
.44116 .51807 Mdot
.62403 .31857 Mdot
.78128 .38073 Mdot
.35293 .48149 Mdot
.31351 .70412 Mdot
.47369 .53975 Mdot
.23042 .47661 Mdot
.46643 .30514 Mdot
.3732 .38334 Mdot
.19122 .40064 Mdot
.77867 .62756 Mdot
.74234 .51759 Mdot
.19972 .40228 Mdot
.53573 .27355 Mdot
.2926 .54365 Mdot
.18703 .56991 Mdot
.46199 .52943 Mdot
.37973 .63707 Mdot
.5528 .55078 Mdot
.45093 .46498 Mdot
.28391 .3144 Mdot
.33652 .7628 Mdot
.56127 .70665 Mdot
.54658 .3764 Mdot
.78863 .63117 Mdot
.55003 .363 Mdot
.57384 .15151 Mdot
.31732 .30244 Mdot
.59764 .2884 Mdot
.28697 .28913 Mdot
.23967 .5673 Mdot
.26096 .72817 Mdot
.57814 .22786 Mdot
.60381 .65886 Mdot
.54027 .37603 Mdot
.52166 .36624 Mdot
.31037 .26709 Mdot
.37358 .4307 Mdot
.58114 .24317 Mdot
.81367 .53317 Mdot
.21639 .60537 Mdot
.56306 .34328 Mdot
.39354 .53595 Mdot
.57365 .38114 Mdot
.59048 .17001 Mdot
.37558 .63656 Mdot
.30671 .19889 Mdot
.71656 .47536 Mdot
.1756 .52407 Mdot
.50536 .23137 Mdot
.48421 .42612 Mdot
.45007 .51051 Mdot
.21563 .58814 Mdot
.58402 .47405 Mdot
.72035 .5751 Mdot
.52847 .2973 Mdot
.22088 .48993 Mdot
.54337 .71935 Mdot
.50894 .65688 Mdot
.26345 .4901 Mdot
.77756 .47272 Mdot
.83103 .4665 Mdot
.51051 .36313 Mdot
.35799 .56494 Mdot
.29291 .5552 Mdot
.58595 .44951 Mdot
.77099 .56213 Mdot
.24234 .29408 Mdot
.58119 .2344 Mdot
.49838 .30768 Mdot
.20568 .65738 Mdot
.48067 .69999 Mdot
.62294 .1872 Mdot
.58617 .40385 Mdot
.77907 .5674 Mdot
.75841 .51159 Mdot
.5798 .20607 Mdot
.61314 .35527 Mdot
.47457 .2118 Mdot
.65869 .64334 Mdot
.46802 .66186 Mdot
.7385 .61332 Mdot
.59291 .37909 Mdot
.41262 .50276 Mdot
.83324 .51182 Mdot
.36197 .77286 Mdot
.67026 .34571 Mdot
.56644 .57954 Mdot
.52285 .23793 Mdot
.81831 .51692 Mdot
.54784 .37765 Mdot
.56721 .72548 Mdot
.68423 .27477 Mdot
.45539 .25301 Mdot
.53781 .19632 Mdot
.44539 .30554 Mdot
.78187 .56862 Mdot
.39903 .50404 Mdot
.68513 .71906 Mdot
.70619 .46089 Mdot
.53772 .58233 Mdot
.5784 .51621 Mdot
.73191 .54644 Mdot
.47381 .58378 Mdot
.69852 .248 Mdot
.69021 .59361 Mdot
.48888 .17645 Mdot
.60621 .18482 Mdot
.4339 .19449 Mdot
.34966 .55235 Mdot
.55373 .35302 Mdot
.33216 .18663 Mdot
.78769 .5493 Mdot
.4837 .22571 Mdot
.81729 .43229 Mdot
.79813 .65513 Mdot
.18522 .41797 Mdot
.4309 .28842 Mdot
.56411 .27473 Mdot
.7819 .3212 Mdot
.42599 .33206 Mdot
.79761 .63645 Mdot
.63104 .37257 Mdot
.48946 .24705 Mdot
.26692 .23475 Mdot
.79484 .4589 Mdot
.39428 .36188 Mdot
.62203 .32457 Mdot
.59881 .34815 Mdot
.80174 .5287 Mdot
.55985 .53714 Mdot
.39239 .66638 Mdot
.41092 .70574 Mdot
.70872 .64091 Mdot
.58134 .39354 Mdot
.80487 .54248 Mdot
.76643 .57757 Mdot
.73212 .66051 Mdot
.21727 .59454 Mdot
.18619 .4177 Mdot
.59503 .29945 Mdot
.64357 .57986 Mdot
.55321 .37734 Mdot
.55144 .73308 Mdot
.67564 .69128 Mdot
.64185 .54738 Mdot
.49029 .51574 Mdot
.68934 .578 Mdot
.46956 .159 Mdot
.41189 .72367 Mdot
.26325 .43707 Mdot
.55849 .34655 Mdot
.51693 .23134 Mdot
.3638 .50263 Mdot
.36234 .39394 Mdot
.80115 .54366 Mdot
.56136 .25439 Mdot
.40176 .20837 Mdot
.40257 .36177 Mdot
.63966 .67796 Mdot
.55816 .78536 Mdot
.28819 .43745 Mdot
.7662 .36336 Mdot
.31128 .21809 Mdot
.42495 .36816 Mdot
.52081 .27782 Mdot
.36438 .32814 Mdot
.41392 .50606 Mdot
.45232 .37789 Mdot
.37456 .37811 Mdot
.29986 .52464 Mdot
.62413 .27541 Mdot
.35006 .21445 Mdot
.34143 .61329 Mdot
.68288 .66974 Mdot
.32505 .33016 Mdot
.80682 .53833 Mdot
.58363 .44953 Mdot
.51202 .1885 Mdot
.52946 .59086 Mdot
.48043 .72878 Mdot
.62119 .53627 Mdot
.77705 .52274 Mdot
.56878 .2091 Mdot
.34817 .34043 Mdot
.64335 .62194 Mdot
.48542 .31158 Mdot
.81284 .38852 Mdot
.34795 .72007 Mdot
.33353 .71577 Mdot
.74665 .68321 Mdot
.48082 .39834 Mdot
.45585 .66304 Mdot
.27668 .40865 Mdot
.58313 .46612 Mdot
.55021 .78569 Mdot
.38104 .52568 Mdot
.75957 .3509 Mdot
.80813 .44899 Mdot
.23254 .30897 Mdot
.37049 .52281 Mdot
.81694 .38882 Mdot
.7752 .36241 Mdot
.49539 .24674 Mdot
.78604 .62589 Mdot
.5447 .55049 Mdot
.6324 .45923 Mdot
.56725 .72526 Mdot
.54891 .28693 Mdot
.25257 .28697 Mdot
.68983 .609 Mdot
.50717 .75347 Mdot
.53091 .60933 Mdot
.34507 .53398 Mdot
.30629 .6254 Mdot
.46244 .29012 Mdot
.78319 .32239 Mdot
.68011 .63888 Mdot
.34491 .46893 Mdot
.28852 .31422 Mdot
.58089 .60583 Mdot
.49912 .18235 Mdot
.48297 .60196 Mdot
.56413 .21493 Mdot
.43942 .39948 Mdot
.76522 .38088 Mdot
.63254 .20105 Mdot
.57374 .64055 Mdot
.52884 .56338 Mdot
.46869 .32039 Mdot
.53522 .54474 Mdot
.43218 .42822 Mdot
.43758 .70166 Mdot
.79391 .57762 Mdot
.21119 .36339 Mdot
.23 .43033 Mdot
.55887 .49477 Mdot
.64413 .72835 Mdot
.32941 .22984 Mdot
.444 .57656 Mdot
.52072 .59386 Mdot
.25954 .54066 Mdot
.31393 .69719 Mdot
.32487 .81068 Mdot
.45508 .15631 Mdot
.61995 .53728 Mdot
.49235 .55859 Mdot
.48924 .67526 Mdot
.32481 .67888 Mdot
.64982 .25511 Mdot
.25257 .28324 Mdot
.30848 .4359 Mdot
.23741 .66414 Mdot
.27659 .40929 Mdot
.68893 .23796 Mdot
.19136 .61494 Mdot
.27535 .43245 Mdot
.57155 .14975 Mdot
.3791 .34538 Mdot
.4955 .38751 Mdot
.33692 .82303 Mdot
.66901 .2296 Mdot
.74973 .52813 Mdot
.39774 .70083 Mdot
.46713 .16489 Mdot
.45013 .50823 Mdot
.42312 .64431 Mdot
.79821 .45257 Mdot
.67359 .64132 Mdot
.68716 .67362 Mdot
.30998 .40984 Mdot
.75531 .31605 Mdot
.76737 .7083 Mdot
.24206 .56697 Mdot
.22785 .70224 Mdot
.59233 .24779 Mdot
.37569 .19396 Mdot
.29225 .33995 Mdot
.39359 .78438 Mdot
.53341 .2002 Mdot
.74345 .59867 Mdot
.78624 .50027 Mdot
.42481 .75899 Mdot
.57475 .64544 Mdot
.64176 .74403 Mdot
.45128 .39531 Mdot
.59073 .23194 Mdot
.22369 .59126 Mdot
.62059 .62457 Mdot
.73153 .61602 Mdot
.78241 .39487 Mdot
.53155 .56804 Mdot
.3389 .20301 Mdot
.79326 .53884 Mdot
.65735 .65404 Mdot
.22145 .5371 Mdot
.52772 .74343 Mdot
.27129 .26887 Mdot
.38076 .46025 Mdot
.7504 .52222 Mdot
.18521 .45514 Mdot
.36841 .171 Mdot
.54454 .5507 Mdot
.64747 .565 Mdot
.63983 .18975 Mdot
.40243 .59033 Mdot
.80808 .44018 Mdot
.32301 .36615 Mdot
.69955 .67004 Mdot
.68137 .58989 Mdot
.58958 .50653 Mdot
.70244 .72151 Mdot
.53455 .25738 Mdot
.78338 .39101 Mdot
.19434 .60133 Mdot
.65501 .65078 Mdot
.77233 .49478 Mdot
.17044 .58669 Mdot
.58985 .40065 Mdot
.52837 .3613 Mdot
.4675 .16266 Mdot
.65709 .24133 Mdot
.74292 .54734 Mdot
.60689 .29335 Mdot
.48142 .61455 Mdot
.53879 .78265 Mdot
.74008 .51039 Mdot
.4686 .48741 Mdot
.71554 .63822 Mdot
.19492 .4052 Mdot
.7437 .31924 Mdot
.29037 .20864 Mdot
.5679 .19343 Mdot
.55611 .35662 Mdot
.79388 .44243 Mdot
.45849 .53126 Mdot
.42489 .19766 Mdot
.21221 .5725 Mdot
.20513 .59097 Mdot
.74839 .71958 Mdot
.50695 .6603 Mdot
.60247 .48687 Mdot
.42607 .39224 Mdot
.54221 .19031 Mdot
.76601 .69895 Mdot
.53421 .18805 Mdot
.72272 .55713 Mdot
.67336 .46643 Mdot
.16736 .64816 Mdot
.39722 .21616 Mdot
.64451 .4474 Mdot
.61819 .60064 Mdot
.64057 .60663 Mdot
.60838 .49038 Mdot
.37439 .42629 Mdot
.62791 .74933 Mdot
.70861 .65955 Mdot
.48991 .17326 Mdot
.56421 .3175 Mdot
.45366 .50755 Mdot
.28156 .43284 Mdot
.49262 .52999 Mdot
.56122 .4316 Mdot
.34057 .45246 Mdot
.72464 .65044 Mdot
.36009 .58747 Mdot
.55885 .76232 Mdot
.54192 .25072 Mdot
.47491 .40627 Mdot
.54329 .23863 Mdot
.75963 .63617 Mdot
.35564 .41459 Mdot
.70071 .75089 Mdot
.76605 .58234 Mdot
.72854 .48026 Mdot
.45478 .3172 Mdot
.84862 .55329 Mdot
.45236 .49986 Mdot
.3988 .3964 Mdot
.57621 .43787 Mdot
.67245 .42431 Mdot
.6121 .27832 Mdot
.52386 .66778 Mdot
.42969 .41181 Mdot
.72879 .54238 Mdot
.55577 .21864 Mdot
.30646 .48741 Mdot
.52953 .13883 Mdot
.68995 .46861 Mdot
.65297 .26781 Mdot
.49149 .19785 Mdot
.28949 .53731 Mdot
.62564 .37201 Mdot
.57768 .5247 Mdot
.46749 .63204 Mdot
.36554 .58725 Mdot
.56368 .38168 Mdot
.26374 .5206 Mdot
.37983 .20584 Mdot
.76152 .6498 Mdot
.62989 .25976 Mdot
.64657 .48549 Mdot
.55036 .68728 Mdot
.4762 .49337 Mdot
.3958 .77349 Mdot
.35662 .59634 Mdot
.46228 .26389 Mdot
.7533 .63985 Mdot
.68882 .67584 Mdot
.62831 .34367 Mdot
.40262 .16837 Mdot
.581 .59618 Mdot
.60335 .26018 Mdot
.51225 .61941 Mdot
.39566 .3023 Mdot
.76331 .56886 Mdot
.2031 .39761 Mdot
.7125 .57468 Mdot
.56222 .56448 Mdot
.55604 .16429 Mdot
.57852 .2253 Mdot
.24653 .43839 Mdot
.45887 .22212 Mdot
.79559 .57115 Mdot
.50401 .55899 Mdot
.34777 .83503 Mdot
.20838 .57176 Mdot
.55751 .14854 Mdot
.23875 .49624 Mdot
.63308 .43188 Mdot
.46629 .35429 Mdot
.62024 .45801 Mdot
.3528 .66471 Mdot
.4126 .19499 Mdot
.47008 .31225 Mdot
.52754 .51844 Mdot
.61292 .57124 Mdot
.41546 .58303 Mdot
.56384 .37579 Mdot
.20563 .37215 Mdot
.36364 .69993 Mdot
.47812 .63249 Mdot
.21015 .44338 Mdot
.36368 .58786 Mdot
.80774 .6396 Mdot
.32664 .20267 Mdot
.42463 .23484 Mdot
.38613 .52373 Mdot
.34565 .79748 Mdot
.50438 .37641 Mdot
.57739 .33008 Mdot
.27546 .49242 Mdot
.68873 .72243 Mdot
.43793 .3728 Mdot
.19755 .42306 Mdot
.57769 .20078 Mdot
.58581 .44824 Mdot
.38896 .87366 Mdot
.7487 .5985 Mdot
.46054 .58883 Mdot
.43425 .38003 Mdot
.50015 .17391 Mdot
.31506 .72601 Mdot
.71357 .24703 Mdot
.3061 .32431 Mdot
.57868 .40012 Mdot
.66855 .74537 Mdot
.20764 .65804 Mdot
.38353 .53787 Mdot
.2299 .70507 Mdot
.37934 .23138 Mdot
.62466 .73767 Mdot
.33996 .34097 Mdot
.53581 .37235 Mdot
.71243 .58176 Mdot
.32373 .29494 Mdot
.55009 .56046 Mdot
.50053 .38657 Mdot
.37488 .214 Mdot
.58605 .77998 Mdot
.20979 .52639 Mdot
.42264 .21404 Mdot
.29417 .50058 Mdot
.4767 .2992 Mdot
.76507 .59655 Mdot
.40001 .59862 Mdot
.33817 .68731 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`2Xooooo`;o000000?oooooo`000?l00000W?ooool001cooooo00?o0000ooooooooool0Z?oo
ool2o`000003ooooool0003o000009cooooo000Looooo`03o`000?oooooooooo0:Sooooo0_l0002O
ooooo`007?ooool00ol0003oooooooooo`2@ooooo`;o00005_ooool2o`0000Cooooo0_l0002Ioooo
o`007?ooool00ol0003oooooooooo`2@ooooo`;o00004_ooool2o`0000Sooooo0_l0002Iooooo`00
7?ooool00ol0003oooooooooo`2Kooooo`;o00001oooool4o`0000Wooooo0_l00003ooooo`;o0000
TOooool001cooooo0_l0002Looooo`;o00002Oooool2o`0000Wooooo0_l00003ooooo`Co0000Sooo
ool001cooooo00?o0000ooooooooool0SOooool2o`000003ooooool0003o000002Gooooo0ol0002?
ooooo`007?ooool00ol0003oooooooooo`26ooooo`Co00000oooool2o`000003ooooool0003o0000
00?ooooo0_l0002booooo`007?ooool00ol0003oooooooooo`1nooooo`;o00001_ooool4o`0000[o
oooo0ol0002booooo`007?ooool00ol0003oooooooooo`1nooooo`;o00001oooool2o`0000_ooooo
0_l00007ooooo`;o00004_ooool2o`0009Kooooo000Looooo`03o`000?oooooooooo07Kooooo0_l0
0007ooooo`;o00001_ooool2o`0000Cooooo1?l00003ooooo`;o00001?ooool2o`000003ooooool0
003o000000;o00001?ooool2o`0000[ooooo0_l00006ooooo`;o0000S_ooool001cooooo00?o0000
ooooooooool0M?ooool4o`0000Oooooo0_l0000<ooooo`Co00002Oooool2o`000003ooooool0003o
000000;o00001?ooool2o`00017ooooo0ol000000ooooooo0000o`00002;ooooo`007?ooool00ol0
003oooooooooo`1^ooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o00001oooool2
o`0000Cooooo0_l00003ooooo`;o00002oooool6o`0001Oooooo1_l000000ooooooo0000o`000028
ooooo`007?ooool00ol0003oooooooooo`1/ooooo`Co000000Coooooo`000?l0003ooooo0_l00004
ooooo`;o00001oooool2o`0000Cooooo0_l00003ooooo`?o00002_ooool2o`0000;ooooo0_l0000I
ooooo`?o00000_ooool2o`0008Sooooo000Looooo`03o`000?oooooooooo06cooooo0_l00006oooo
o`;o00001oooool2o`00013ooooo0_l0000:ooooo`;o00004?ooool3o`0001;ooooo0_l00025oooo
o`007?ooool00ol0003oooooooooo`1Xooooo`;o00003_ooool2o`0000?ooooo0_l0000Aooooo`?o
00000oooool2o`0000Kooooo0_l0000=ooooo`?o00004_ooool2o`0008Gooooo000Looooo`03o`00
0?oooooooooo06Sooooo0_l0000>ooooo`;o00003oooool2o`0000Gooooo0ol00003ooooo`;o0000
1?ooool4o`0000_ooooo0_l0000Dooooo`;o00001?ooool2o`00083ooooo000Looooo`03o`000?oo
oooooooo06Sooooo0_l0000Oooooo`;o00001?ooool2o`0000_ooooo0_l00005ooooo`;o00001Ooo
ool4o`0000Oooooo0_l0000:ooooo`;o00001?ooool2o`0000;ooooo0ol0001kooooo`0000Kooooo
onk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0
Ioooool2o`0001?ooooo0_l0000Aooooo`;o00001Oooool2o`0000Oooooo0_l00002ooooo`;o0000
0oooool6o`0000Oooooo0_l0000Dooooo`?o0000Noooool00006oooooomgMgOoV9RHoooooonHV9So
MgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo
06Oooooo0_l0000=ooooo`;o00001?ooool2o`0000Cooooo0ol00004ooooo`;o00001_ooool3o`00
00;ooooo0_l000000ooooooo0000o`000004ooooo`;o00001oooool2o`000004ooooool0003o0000
o`0000?ooooo0_l00002ooooo`;o0000T_ooool00003ooooool@413ooooo00;ooooo00?o410@oooo
ooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo063ooooo0_l0000?oooo
o`;o00000oooool2o`0000[ooooo0ol000001?oooooo0000o`000?ooool2o`000003ooooool0003o
000000?ooooo0ol00005ooooo`Go00003Oooool3o`0000?ooooo0_l0000Fooooo`;o00001_ooool2
o`0007Kooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q
8Oo^k^h01_ooool3o`00063ooooo0ol00003ooooo`;o00000_ooool2o`0000Gooooo0_l00007oooo
o`;o00002_ooool2o`0000Cooooo0_l0000<ooooo`Ko00002_ooool2o`0000Gooooo0_l00005oooo
o`;o00003?ooool2o`000004ooooool0003o0000o`0000Gooooo0_l0001fooooo`0000?oooooo`00
0?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000oooo
ooooool0GOooool2o`0000;ooooo0_l00002ooooo`?o00000_ooool2o`000003ooooool0003o0000
00Wooooo1?l0000Hooooo`;o00001oooool3o`0000[ooooo0_l000000ooooooo0000o`000009oooo
o`?o00002oooool2o`0000;ooooo0_l0001mooooo`0000?ooooooa0@4?ooool00_ooool00ol@413o
ooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Foooool6o`0000Co
oooo0_l00006ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Gooooo0_l0000Cooooo`;o
00003?ooool2o`0000Wooooo0_l00006ooooo`;o00000_ooool2o`0000kooooo0_l00002ooooo`;o
00001Oooool2o`0007?ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj
^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo05_ooooo0ol000000ooooooo0000o`00000?
ooooo`;o00001_ooool2o`0000Gooooo0_l0000Eooooo`;o00002_ooool2o`0000Oooooo0_l00008
ooooo`;o00004_ooool2o`0000;ooooo0_l00005ooooo`;o0000Loooool00006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0
K_ooool2o`0000Kooooo1?l00007ooooo`;o00000oooool3o`0000gooooo0_l0000:ooooo`;o0000
0oooool6o`0000Kooooo1_l0000Aooooo`;o00000oooool2o`0007Sooooo000Looooo`03o`000?oo
oooooooo05gooooo0_l00002ooooo`;o00002oooool2o`0000Cooooo1?l00005ooooo`;o00000_oo
ool2o`000003ooooool0003o000000?o00003?ooool2o`0000_ooooo0_l00003ooooo`Co00002?oo
ool2o`0000;ooooo0_l0000>ooooo`;o000000?oooooo`000?l000000oooool2o`0007Sooooo000L
ooooo`03o`000?oooooooooo05gooooo0_l00002ooooo`;o00004Oooool2o`0000Cooooo0_l00000
0ooooooo0000o`000005ooooo`?o00000oooool2o`0000Wooooo0_l0000Aooooo`?o00001_ooool3
o`0001?ooooo0_l00008ooooo`;o00001Oooool2o`0006oooooo000Looooo`03o`000?oooooooooo
07[ooooo0_l000000ooooooo0000o`000006ooooo`Co000000?oooooo`000?l000002?l00005oooo
o`;o00003Oooool3o`0000Kooooo1Ol0000Kooooo`;o00001Oooool2o`0006oooooo000Looooo`03
o`000?oooooooooo05Gooooo0_l0000^ooooo`oo00001Oooool2o`0001Wooooo0_l000001?oooooo
0000o`000?l0000Jooooo`;o0000Loooool001cooooo00?o0000ooooooooool0EOooool2o`00013o
oooo0_l00003ooooo`;o00001oooool2o`0000Kooooo0_l00006ooooo`;o00000_ooool5o`000003
ooooool0003o000000;o00001_ooool2o`0000Sooooo0ol00002ooooo`;o00001oooool2o`0000Co
oooo0ol0000Jooooo`Co0000LOooool001cooooo00?o0000ooooooooool0Ioooool2o`0000?ooooo
0_l00007ooooo`Co00001?ooool2o`000003ooooool0003o000000?ooooo1ol0000;ooooo`;o0000
1_ooool3o`000004ooooool0003o0000o`0000;ooooo1?l00005ooooo`;o00001Oooool2o`0000;o
oooo0_l0000Hooooo`;o000000?oooooo`000?l00000K_ooool001cooooo00?o0000ooooooooool0
Doooool2o`0001[ooooo0_l00004ooooo`Co00001oooool2o`0000?ooooo1_l00002ooooo`;o0000
1_ooool4o`0000Kooooo0ol000000ooooooo0000o`000002o`0000?ooooo0_l0000=ooooo`;o0000
00?oooooo`000?l000006oooool2o`0006kooooo000Looooo`03o`000?oooooooooo05?ooooo0_l0
000Jooooo`;o00002?ooool2o`000003ooooool0003o000000Oooooo0ol000000ooooooo0000o`00
0004o`0000Cooooo1_l0000<ooooo`?o00001Oooool2o`0000[ooooo1?l0000Looooo`;o000000?o
ooooo`000?l00000Joooool001cooooo00?o0000ooooooooool0Koooool2o`0000Sooooo0_l00000
0ooooooo0000o`00000=ooooo`Co00001?ooool2o`0000;ooooo0_l00008ooooo`Co000000?ooooo
o`000?l000001Oooool2o`0000[ooooo1?l0000Dooooo`?o00001Oooool2o`000003ooooool0003o
000000;ooooo0_l0001Wooooo`007?ooool00ol0003oooooooooo`1_ooooo`;o00002?ooool2o`00
00Kooooo0_l00004ooooo`;o00003?ooool2o`0000Cooooo0_l00004ooooo`Co00002Oooool3o`00
00Sooooo0_l0000Fooooo`?o00003?ooool2o`000003ooooool0003o000006Cooooo000Looooo`03
o`000?oooooooooo06Kooooo0_l0000Aooooo`;o00001_ooool2o`0000Cooooo0_l00008ooooo`;o
00000_ooool2o`0000Cooooo1?l00003ooooo`;o000000?oooooo`000?l000000_l00005ooooo`Co
00002oooool2o`0000Oooooo0_l0000;ooooo`;o00002_ooool2o`0000;ooooo0ol0001Sooooo`00
7?ooool2o`0005Cooooo0_l0000Aooooo`;o00004_ooool2o`0000Kooooo0_l0000=ooooo`;o0000
1oooool5o`0000?ooooo3?l00002ooooo`Co00002Oooool2o`0000Oooooo0_l0000;ooooo`;o0000
2_ooool3o`0000;ooooo1?l0001Qooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00001?oo
ool2o`0002Gooooo0_l00006ooooo`;o00001?ooool4o`0000Cooooo0_l00003ooooo`;o00000ooo
ool2o`0000Kooooo0ol00004ooooo`Go00001?ooool3o`0000Gooooo0_l0000<ooooo`;o00001Ooo
ool2o`0000oooooo0_l00004ooooo`;o0000HOooool001cooooo00?o0000ooooooooool0COooool2
o`0000Cooooo0_l0000`ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o00000oooool2
o`0001?ooooo1?l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2
o`0007Sooooo000Looooo`03o`000?oooooooooo04oooooo0_l0000dooooo`;o00001_ooool2o`00
00;ooooo0_l00002ooooo`;o00004oooool4o`0000cooooo0_l00004ooooo`?o00001_ooool2o`00
00Sooooo0_l0001dooooo`007?ooool00ol0003oooooooooo`1?ooooo`?o0000>oooool2o`0000;o
oooo0ol0000>ooooo`;o00001_ooool2o`0000cooooo1Ol00003ooooo`;o00001oooool2o`0000So
oooo0_l000000ooooooo0000o`00001aooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o0000
3oooool2o`0002gooooo1Ol0000;ooooo`Co000000?oooooo`000?l000000oooool2o`0000Cooooo
1?l00004ooooo`Go00002oooool2o`0000Kooooo0_l000001?oooooo0000o`000?ooool2o`00077o
oooo000Looooo`03o`000?oooooooooo05Cooooo0_l0000;ooooo`;o0000;Oooool2o`000003oooo
ool0003o000000_ooooo0_l00003ooooo`Co00001oooool4o`0001Cooooo0_l00006ooooo`;o0000
Moooool001cooooo00?o0000ooooooooool0E?ooool2o`0003[ooooo0_l00003ooooo`;o00001Ooo
ool2o`0000Wooooo0_l000000ooooooo0000o`000006ooooo`;o00002Oooool2o`0008[ooooo000L
ooooo`03o`000?oooooooooo053ooooo0_l0000`ooooo`;o00003?ooool4o`000004ooooool0003o
0000o`0000Cooooo0_l00009ooooo`;o000000?oooooo`000?l000001oooool2o`0000?ooooo0_l0
0003ooooo`;o00002?ooool2o`00017ooooo0ol00005ooooo`;o0000IOooool001cooooo00?o0000
ooooooooool0D?ooool2o`00033ooooo0_l0000;ooooo`;o000000Coooooo`000?l0003ooooo0ol0
000=ooooo`Go00000_ooool2o`0000Gooooo0_l00003ooooo`;o00002Oooool2o`0000;ooooo0_l0
000Aooooo`?o00001Oooool2o`0006Gooooo000Looooo`03o`000?oooooooooo05gooooo1?l0000S
ooooo`;o00002Oooool3o`000003ooooool0003o000000?ooooo0_l00009ooooo`_o00005Oooool2
o`0001kooooo1?l0001Rooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o00000_ooool2o`00
00gooooo1?l0000Sooooo`;o00002_ooool2o`000003ooooool0003o000000?ooooo0_l00009oooo
o`;o000000?oooooo`000?l000001_l000000ooooooo0000o`000002o`000004ooooool0003o0000
o`0000Kooooo0_l0000Tooooo`Co0000H_ooool001cooooo00?o0000ooooooooool0B_ooool2o`00
00;ooooo0_l00009ooooo`;o00000_ooool2o`0002Wooooo0_l00005ooooo`Co00003Oooool4o`00
00?ooooo3?l000001?oooooo0000o`000?l00006ooooo`?o0000ROooool001cooooo00?o0000oooo
ooooool0C_ooool2o`0000Wooooo0_l00002ooooo`;o0000:Oooool3o`0000Cooooo1Ol00008oooo
o`;o00000_ooool4o`0000;ooooo3_l0000:ooooo`?o0000;Oooool2o`0000?ooooo0_l0001Doooo
o`007?ooool00ol0003oooooooooo`1;ooooo`;o00005Oooool2o`000003ooooool0003o000002;o
oooo0_l00004ooooo`;o000000?oooooo`000?l000002?ooool3o`000004ooooool0003o0000o`00
00;ooooo2Ol00002ooooo`Co00000oooool2o`0000Kooooo1?l00008ooooo`;o00008Oooool2o`00
00?ooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o00003Oooool2o`0000Ko
oooo0_l000000ooooooo0000o`00000Kooooo`;o00002oooool2o`0000cooooo0_l00003oooooaCo
000000?oooooo`000?l000002?ooool2o`0000Sooooo0_l00006ooooo`;o00008_ooool2o`00053o
oooo000Looooo`;o0000C?ooool2o`0000gooooo0_l00004ooooo`;o00008?ooool4o`0000kooooo
0_l000000ooooooo0000o`000003ooooo`?o00000_oooolAo`000005ooooool0003o0000o`000?oo
ool00_l00003ooooo`Co00004oooool2o`0000kooooo0_l00003ooooo`;o00001Oooool2o`0000Co
oooo1?l0001@ooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o00003_ooool2o`0000?ooooo
0_l000000ooooooo0000o`00000Eooooo`;o000000?oooooo`000?l000001Oooool2o`0000Oooooo
0_l00005ooooo`Go00000ooooolFo`0000;ooooo0_l000000ooooooo0000o`000003ooooo`Co0000
4oooool3o`0000gooooo0_l000000ooooooo0000o`000002o`0000Gooooo0_l00004ooooo`;o0000
D_ooool001cooooo00?o0000ooooooooool0Foooool2o`0000Gooooo0ol0000Dooooo`?o000000?o
ooooo`000?l000003_ooool2o`0000Cooooo1Ol00003ooooo`;o000000?oooooo`000?l000002_l0
00000ooooooo0000o`000003o`000003ooooool0003o000000Cooooo0ol0000Iooooo`?o00003_oo
ool4o`0000;ooooo0_l00003ooooo`Co0000E_ooool001cooooo00?o0000ooooooooool0B?ooool2
o`0001Sooooo0_l0000Eooooo`;o00003oooool2o`000003ooooool0003o000000Cooooo0ol00005
oooooa[o00000oooool2o`0000;ooooo0_l00002ooooo`;o00008_ooool2o`0000Cooooo0_l00003
ooooo`Co0000E_ooool001cooooo00?o0000ooooooooool0Aoooool3o`00043ooooo0_l00002oooo
o`;o00001Oooool4o`000003ooooool0003o000001Wo000000?oooooo`000?l000000_l000001?oo
oooo0000o`000?l00002ooooo`Co0000;Oooool2o`0005Kooooo000Looooo`03o`000?oooooooooo
04Oooooo0_l0000>ooooo`Ko0000;Oooool2o`0000;ooooo0_l00005ooooo`Co000000?oooooo`00
0?l000006?l00002ooooo`Co000000Coooooo`000?l0003o00000oooool3o`0002gooooo0ol0001E
ooooo`007?ooool00ol0003oooooooooo`1Fooooo`Oo00007oooool2o`0000Sooooo0_l00002oooo
o`;o00001?ooool2o`0000cooooo6?l0000;ooooo`?o00000oooool2o`0000?ooooo0_l00005oooo
o`;o00006Oooool2o`0000;ooooo0ol0001Dooooo`007?ooool00ol0003oooooooooo`1Fooooo`;o
00001Oooool2o`0001gooooo0_l00008ooooo`;o00002?ooool2o`0000;ooooo0_l00006oooooa_o
00000_ooool2o`0000Oooooo0_l00003ooooo`;o00000oooool2o`0000Gooooo0_l0000Iooooo`;o
00000oooool3o`0000Cooooo0ol0001<ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o0000
5oooool5o`0002kooooo0_l00002ooooo`;o00001_oooolOo`0000Oooooo0_l00002ooooo`;o0000
1?ooool2o`000003ooooool0003o000002;ooooo0ol00004ooooo`?o0000C?ooool001cooooo00?o
0000ooooooooool0A?ooool3o`00017ooooo0_l00005ooooo`?o00004Oooool2o`0001_ooooo1ol0
0004oooooako00002Oooool2o`000004ooooool0003o0000o`0000Oooooo0_l0000Rooooo`;o0000
1Oooool3o`0004cooooo000Looooo`03o`000?oooooooooo04Gooooo0_l0000Aooooo`;o00003?oo
ool2o`0000_ooooo0_l0000Booooo`;o00002?ooool6o`0000Cooooo6?l00002ooooo`Go00002ooo
ool2o`0000Oooooo0_l00004ooooo`;o00006oooool4o`0000Gooooo0_l0001=ooooo`007?ooool0
0ol0003oooooooooo`1@ooooo`;o00000oooool2o`0000;ooooo0_l00006ooooo`;o00000oooool2
o`0001kooooo0ol0000Aooooo`Oo000000?oooooo`000?l000005_l00003ooooo`;o00003oooool2
o`0000Cooooo0_l0000Kooooo`;o00002?ooool2o`0004cooooo000Looooo`03o`000?oooooooooo
053ooooo1?l000000ooooooo0000o`000002ooooo`;o00001_ooool4o`0000kooooo0_l00004oooo
o`;o00000_ooool2o`0000Oooooo0_l0000;ooooo`Co00000_oooolBo`000003ooooool0003o0000
00[o00001Oooool2o`0000;ooooo0_l0000Cooooo`;o00004_ooool2o`0000oooooo0_l0001<oooo
o`007?ooool00ol0003oooooooooo`1Booooo`;o00001oooool2o`0000Kooooo0_l00006ooooo`Co
00001?ooool4o`0000;ooooo0_l00002ooooo`;o00000_ooool2o`00013ooooo1?l00002oooooaWo
00000_ooool2o`0000_ooooo0_l00005ooooo`;o00001?ooool2o`0000Kooooo0_l0000Booooo`Co
0000Foooool001cooooo00?o0000ooooooooool0A?ooool2o`0000cooooo0_l00007ooooo`Co0000
1?ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000000_l00006ooooo`;o0000
2?ooool4o`00013ooooo0_l00006oooooa7o000000?oooooo`000?l000002?l0000>ooooo`Go0000
1?ooool2o`0001cooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00005Ooo
ool4o`0000Cooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00002ooooo`;o00000_oo
ool2o`000003ooooool0003o000000Kooooo0ol0000@ooooo`;o00002OoooolJo`0000kooooo1Ol0
000;ooooo`?o00005_ooool2o`0005Wooooo000Looooo`;o0000Ioooool2o`0000Cooooo0_l00002
ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo0ol00003ooooo`;o00003?ooool2
o`000003ooooool0003o000000Wooooo6Ol00009ooooo`;o00001?ooool2o`0000Kooooo0_l00006
ooooo`?o00005_ooool2o`0000?ooooo0_l00009ooooo`;o0000BOooool001cooooo00?o0000oooo
ooooool0F?ooool2o`0001gooooo1ol00003ooooo`Go00002Oooool5o`0000Sooooo7?l00007oooo
o`;o00000oooool4o`0000Gooooo0_l0000Oooooo`?o00000_ooool2o`0000?ooooo0_l00004oooo
o`;o0000BOooool001cooooo00?o0000ooooooooool0F?ooool4o`0001_ooooo2?l00003ooooo`Co
00002_ooool2o`000004ooooool0003o0000o`0000Kooooo0_l000000ooooooo0000o`00000Io`00
00Gooooo0_l00002ooooo`Go00002Oooool3o`0001_ooooo0ol00006ooooo`;o00001?ooool2o`00
04Wooooo000Looooo`03o`000?oooooooooo05[ooooo0_l00002ooooo`;o00007?ooool3o`0000?o
oooo0ol00006ooooo`;o00001_ooool3o`0000Kooooo0_l000000ooooooo0000o`00000Io`0000Go
oooo0_l00002ooooo`Go00001?ooool2o`0000?ooooo0ol0000Looooo`;o00003?ooool2o`0004Wo
oooo000Looooo`03o`000?oooooooooo05kooooo0_l0000Gooooo`?o000000Goooooo`000?l0003o
0000ooooo`06o`0000Kooooo0_l00004ooooo`;o000000?oooooo`000?l000001ooooolDo`000003
ooooool0003o000000;o00001Oooool2o`0000Wooooo1?l00002ooooo`;o0000:?ooool4o`0004oo
oooo000Looooo`03o`000?oooooooooo047ooooo0_l0000Qooooo`?o00004?ooool7o`000003oooo
ool0003o000000?o00003Oooool2o`000003ooooool0003o000000Oooooo2?l000000ooooooo0000
o`000009o`0000;ooooo0_l00006ooooo`;o00002Oooool4o`0002_ooooo1Ol00006ooooo`;o0000
Aoooool001cooooo00?o0000ooooooooool0@Oooool2o`00027ooooo0ol0000Aooooo`Ko00001?oo
ool2o`0000;ooooo0_l00008ooooo`;o00002oooool6o`0000?ooooo2_l00003ooooo`?o00000ooo
ool3o`0000[ooooo0_l0000]ooooo`?o000000?oooooo`000?l000001Oooool2o`0004Oooooo000L
ooooo`03o`000?oooooooooo03kooooo0ol0000_ooooo`;o00001?ooool2o`000003ooooool0003o
000000Oooooo0_l00002ooooo`;o00002?ooool2o`0000gooooo1?l00003ooooo`[o00000_ooool4
o`0000;ooooo1?l0000:ooooo`Co000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00000_oo
ool2o`0001cooooo0ol000000ooooooo0000o`000002o`0004cooooo000Looooo`03o`000?oooooo
oooo03kooooo0ol0000Sooooo`;o00002_ooool2o`0000Cooooo1?l00002ooooo`;o000000?ooooo
o`000?l000001Oooool2o`0000?ooooo0_l0000Booooo`;o000000?oooooo`000?l000000_ooool2
o`0000;ooooo1?l00004ooooo`?o00000oooool2o`0000gooooo2Ol00003ooooo`;o000000Cooooo
o`000?l0003o00007?ooool3o`0000;ooooo0ol0001<ooooo`007?ooool00ol0003oooooooooo`0n
ooooo`;o00009?ooool2o`00013ooooo1?l00002ooooo`;o000000?oooooo`000?l000000_l00000
0ooooooo0000o`000002o`0000?ooooo0_l00002ooooo`?o00002?ooool2o`0000Cooooo2Ol00002
ooooo`Oo000000?oooooo`000?l000000oooool2o`0000Cooooo0_l00007ooooo`Oo00000oooool2
o`0000?ooooo0ol0000Looooo`?o00000_ooool2o`0004gooooo000Looooo`03o`000?oooooooooo
06;ooooo0_l0000;ooooo`;o00001Oooool2o`0000Cooooo0_l00003ooooo`;o000000?oooooo`00
0?l000000_l000000ooooooo0000o`000004ooooo`?o00002?ooool4o`0000;ooooo0_l00002oooo
o`Go00000oooool6o`000003ooooool0003o000000;ooooo2Ol00008ooooo`Go000000Coooooo`00
0?l0003ooooo0_l00004ooooo`;o00007?ooool2o`0000?ooooo0_l0001=ooooo`007?ooool00ol0
003oooooooooo`1Pooooo`Co00002oooool2o`0000Cooooo0_l00009ooooo`;o00001oooool2o`00
00oooooo1?l00002ooooo`;o00001_ooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool2
o`0000;ooooo2?l00006ooooo`?o00000oooool2o`000003ooooool0003o000002Gooooo0ol00002
ooooo`;o0000COooool001cooooo00?o0000ooooooooool0H?ooool2o`0001?ooooo0_l00009oooo
o`;o00000_ooool2o`0000Kooooo0_l0000=ooooo`Oo00001_ooool3o`0000;ooooo0_l0000Foooo
o`?o0000;_ooool2o`00057ooooo000Looooo`03o`000?oooooooooo08Cooooo0_l00006ooooo`;o
00003oooool6o`0000Kooooo0_l0000@ooooo`;o00002Oooool2o`0000gooooo0_l00002ooooo`;o
00006oooool2o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`Co00001oooool2o`0003So
oooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@oooo
ooooool01?ooool00ol0003oooooooooo`0iooooo`;o00007oooool2o`0001Kooooo0ol00008oooo
o`;o00001oooool3o`0001Sooooo0_l0000Fooooo`Co00000_ooool3o`0001?ooooo0_l00002oooo
o`?o00006_ooool2o`0000?ooooo1Ol00004ooooo`Co00001oooool2o`0003Sooooo00001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0>Oooool4o`0001gooooo0_l0000@ooooo`Co00000_ooool3o`0000Sooooo0ol00006
ooooo`?o00001_ooool2o`0001Cooooo0_l00004ooooo`;o00003?ooool2o`0000Cooooo1?l0000G
ooooo`;o00007_ooool2o`000003ooooool0003o000000Gooooo0ol00012ooooo`0000?ooooooa0@
4?ooool00_ooool00ol@413oooooooooo`09ooooo`Go00001_ooool00ol0003oooooooooo`0koooo
o`;o000000?oooooo`000?l00000;?ooool4o`0000?ooooo0_l00004ooooo`;o00000oooool2o`00
00Oooooo0_l00002ooooo`;o00000_ooool2o`0000Oooooo0_l0000;ooooo`Co00000_ooool2o`00
00_ooooo0_l00007ooooo`;o00002?ooool3o`0000Kooooo0_l0000Tooooo`;o000000Coooooo`00
0?l0003o00000oooool2o`0004Cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`0003[ooooo1_l0000Kooooo`;o00006oooool3
o`0000?ooooo0_l00002ooooo`Go00001?ooool2o`0000;ooooo0_l00006ooooo`?o00002oooool4
o`0000Oooooo0_l00006ooooo`;o00000_ooool2o`0000gooooo0ol00006ooooo`;o0000:?ooool2
o`0000?ooooo0_l00014ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09oooo
o`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0>_ooool5o`0001cooooo0_l00006
ooooo`Go00004?ooool2o`0000Cooooo0_l000000ooooooo0000o`000006o`0000Kooooo0_l00006
ooooo`;o00003?ooool2o`0000Wooooo0_l00009ooooo`?o00002oooool2o`0001Kooooo0_l0001V
ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co0000
00Oooooo00?o0000ooooooooool0=oooool2o`000003ooooool0003o000000;o00006?ooool2o`00
00_ooooo1Ol00002ooooo`;o00004Oooool@o`0000Cooooo0_l00003ooooo`?o00005_ooool3o`00
00Cooooo0_l00002ooooo`?o00000_ooool2o`0000Sooooo0_l0000Fooooo`;o00004?ooool2o`00
05Cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l000001oooool0
0ol0003oooooooooo`0gooooo`;o000000?oooooo`000?l000006Oooool3o`0000?ooooo0_l00004
ooooo`;o00001oooool4o`0000;ooooo0_l00009oooooa;o00001?ooool2o`0000?ooooo0_l0000G
ooooo`;o00001Oooool2o`0000;ooooo0_l00003ooooo`;o00008?ooool2o`00013ooooo1?l0000=
ooooo`;o0000@oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000oooo
o`06ooooo`03o`000?oooooooooo05Cooooo0ol00004ooooo`;o00001?ooool2o`0000Wooooo1_l0
0002ooooo`;o00001OoooolBo`0004Oooooo0_l00005ooooo`;o00001?ooool2o`0001;ooooo0_l0
000<ooooo`?o0000@oooool001cooooo00?o0000ooooooooool0>?ooool3o`0001Wooooo0_l0000H
ooooo`Go000000?oooooo`000?l000000oooool2o`0000?ooooo3_l00018ooooo`;o00001Oooool2
o`000003ooooool0003o000001gooooo0_l00004ooooo`;o00002oooool2o`0003Oooooo000Loooo
o`03o`000?oooooooooo03Oooooo1?l0000/ooooo`;o00002?ooool2o`0000Kooooo3Ol000000ooo
oooo0000o`000004o`0004Cooooo0_l00008ooooo`;o000000?oooooo`000?l000007Oooool3o`00
00Cooooo1?l00008ooooo`;o0000=oooool001cooooo00?o0000ooooooooool0=oooool4o`000003
ooooool0003o000000;ooooo0_l0000Gooooo`;o00002Oooool7o`0000oooooo4ol00009ooooo`Co
00002oooool2o`0002[ooooo0_l00004ooooo`;o00002Oooool4o`0000kooooo0_l00007ooooo`?o
00001?ooool4o`0000Sooooo0_l0000gooooo`007?ooool00ol0003oooooooooo`0booooo`;o0000
2?ooool2o`000004ooooool0003o0000o`0000_ooooo0_l0000:ooooo`Go000000?oooooo`000?l0
00000oooool3o`000004ooooool0003o0000o`0000Cooooo0_l00005ooooo`;o00000_ooool2o`00
0003ooooool0003o0000013o00001oooool6o`0000Wooooo1?l0000^ooooo`;o00002Oooool4o`00
00[ooooo0_l00002ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0<_ooool2o`0000_o
oooo0_l00006ooooo`;o00000_ooool4o`0000_ooooo1?l000000ooooooo0000o`000005o`0000Ko
oooo0_l000001?oooooo0000o`000?ooool2o`000004ooooool0003o0000o`0000Gooooo4_l00008
ooooo`Go00002oooool2o`0000cooooo0_l0000hooooo`?o0000Eoooool001cooooo00?o0000oooo
ooooool0AOooool5o`000003ooooool0003o000000;ooooo0_l00005ooooo`Go00000oooool9o`00
0003ooooool0003o000000;ooooo0_l00004ooooo`;o000000Coooooo`000?l0003o00001Oooool?
o`0000?ooooo0_l00004ooooo`;o00004_ooool5o`0000Gooooo1?l00006ooooo`;o00002oooool2
o`0000oooooo0_l0000Booooo`;o00003Oooool2o`0000?ooooo0_l000000ooooooo0000o`000011
ooooo`007?ooool00ol0003oooooooooo`15ooooo`Go00001Oooool2o`000003ooooool0003o0000
00;ooooo5?l00003ooooo`;o00003Oooool2o`0000;ooooo2_l00005ooooo`;o00000oooool6o`00
00oooooo1Ol00005ooooo`;o00002?ooool2o`0000_ooooo0_l0000=ooooo`Co00006?ooool2o`00
00Oooooo0_l00003ooooo`;o000000?oooooo`000?l00000@Oooool001cooooo00?o0000oooooooo
ool0A_ooool2o`0000Cooooo0_l00004ooooo`;o00000_oooolFo`000003ooooool0003o000000co
oooo0ol00003ooooo`Wo00002_ooool7o`0001Sooooo0_l00002ooooo`;o00003_ooool2o`000003
ooooool0003o000000;o00002oooool3o`0000?ooooo0_l0000>ooooo`;o00001?ooool2o`0000Oo
oooo0_l00003ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0@Oooool2o`0000;ooooo
0ol00004ooooo`Co00001OoooolIo`0000gooooo0_l00004ooooo`Ko00000_ooool2o`0000_ooooo
1Ol0000Looooo`;o00002_ooool<o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o0000
0_ooool3o`0000kooooo0_l0000=ooooo`;o00000oooool2o`0004Cooooo000Looooo`03o`000?oo
oooooooo03[ooooo0_l00005ooooo`;o00000_ooool2o`000004ooooool0003o0000o`0000;ooooo
0ol00005oooooaWo00002oooool5o`0000_ooooo0_l00007ooooo`;o00000_ooool2o`0001Sooooo
0_l0000=ooooo`_o00000oooool2o`000003ooooool0003o000000Go00001oooool3o`0000Cooooo
0_l0000:ooooo`;o00002oooool2o`0000?ooooo0_l00014ooooo`007?ooool00ol0003ooooooooo
o`0jooooo`;o00003?ooool3o`0000;ooooo0_l000000ooooooo0000o`00000Mo`0000[ooooo1ol0
0002ooooo`;o00003_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000Eooooo`;o00002?oo
ool3o`0000;ooooo2?l00006ooooo`[o00002?ooool2o`0000Cooooo0ol00009ooooo`;o00004?oo
ool2o`0004Cooooo000Looooo`;o0000@_ooool2o`0000cooooo8?l0000?ooooo`;o00000_ooool2
o`0001Gooooo0_l0000Kooooo`;o00000_ooool7o`000003ooooool0003o000000?o00001oooool4
o`0000;ooooo0_l00007ooooo`;o00000oooool2o`0000;ooooo1Ol0000Dooooo`;o00000_ooool2
o`0000Gooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00001oooool2o`00
00cooooo0_l000000ooooooo0000o`00000Ko`0000Gooooo0_l00008ooooo`;o000000?oooooo`00
0?l000004oooool2o`0000?ooooo1Ol0000Fooooo`;o000000?oooooo`000?l000000_ooool8o`00
00Oooooo0_l00002ooooo`;o00000_ooool2o`0000Oooooo0_l000000ooooooo0000o`000002o`00
00Cooooo1?l00005ooooo`;o00003?ooool2o`0000Wooooo0_l0000mooooo`007?ooool00ol0003o
ooooooooo`0hooooo`;o00005?ooool?o`000003ooooool0003o000000oo00001Oooool2o`0000So
oooo0_l000000ooooooo0000o`00000>ooooo`;o00000_ooool3o`0000;ooooo1ol0000Aooooo`;o
000000?oooooo`000?l000000_ooool2o`0000Cooooo1?l00003ooooo`?o00000oooool2o`0001;o
oooo0_l00008ooooo`;o00001Oooool2o`0000Cooooo0_l0000Hooooo`;o0000=_ooool001cooooo
00?o0000ooooooooool0?_ooool2o`0000?ooooo0_l00009ooooo`Co000000?oooooo`000?l00000
6?l00006ooooo`?o00000_ooool2o`0000?ooooo0ol0000Aooooo`;o00000_ooool9o`000003oooo
ool0003o0000017ooooo0_l000000ooooooo0000o`000002o`0000gooooo1_l00005ooooo`;o0000
00Goooooo`000?l0003o0000ooooo`04o`0000Kooooo0_l0000Cooooo`;o00001Oooool3o`00013o
oooo0_l0000fooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00000oooool2o`0000Sooooo
0ol000000ooooooo0000o`00000Jo`0000Kooooo0_l00003ooooo`;o000000?oooooo`000?l00000
0_l0000Booooo`;o000000?oooooo`000?l000002?l0000<ooooo`;o00002oooool2o`0000Sooooo
0_l00003ooooo`Oo000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000006o`0000Ko
oooo0_l0000@ooooo`;o00002?ooool3o`0004Sooooo000Looooo`03o`000?oooooooooo03_ooooo
0_l0000@ooooo`;o00000_oooolLo`0000kooooo0_l0000Booooo`[o000000Coooooo`000?l0003o
00003Oooool2o`0000[ooooo0_l00002ooooo`Ko000000?oooooo`000?l000000oooool7o`000003
ooooool0003o000000Gooooo1ol00003ooooo`;o00001?ooool2o`0000[ooooo1Ol00002ooooo`;o
00004?ooool2o`0000Cooooo0_l0000gooooo`007?ooool00ol0003oooooooooo`0kooooo`;o0000
3oooool3o`000003ooooool0003o000001co00008Oooool2o`000004ooooool0003o0000ooooo`Co
00000_ooool3o`0001Sooooo0_l00002ooooo`Wo00000oooool3o`000003ooooool0003o000000Co
00000_ooool<o`000003ooooool0003o000000Cooooo0_l0000:ooooo`?o00001?ooool2o`00013o
oooo0_l00004ooooo`;o0000=oooool001cooooo00?o0000ooooooooool0A_ooool2o`0000?ooooo
1?l000000ooooooo0000o`00000Lo`0000cooooo0_l0000Eooooo`?o00000oooool3o`000003oooo
ool0003o000000?o00004oooool2o`0000Cooooo2_l00002oooooa;o000000?oooooo`000?l00000
1?l000001?oooooo0000o`000?l0000:ooooo`;o00002oooool2o`0000cooooo0_l00010ooooo`00
7?ooool00ol0003oooooooooo`0nooooo`Co00001?ooool3o`0000;ooooo1?l00005oooooaCo0000
00?oooooo`000?l000000ol0000:ooooo`Co00002oooool2o`0000Gooooo0_l000001?oooooo0000
o`000?l00004ooooo`?o000000?oooooo`000?l000000_l0000Booooo`?o00000_ooool6o`000003
ooooool0003o000000;o00000ooooolCo`000003ooooool0003o000000;o00000_ooool3o`0000?o
oooo0_l00003ooooo`Go00002_ooool2o`0000cooooo0_l00010ooooo`007?ooool00ol0003ooooo
ooooo`0nooooo`Co00001Oooool2o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l00000
4Ol000000ooooooo0000o`00000<ooooo`;o00003Oooool4o`0000?ooooo0_l00006ooooo`;o0000
00?oooooo`000?l000000ol0000Dooooo`[o00000_ooool3o`000003ooooool0003o000001[o0000
0_ooool2o`0000?ooooo0_l00002ooooo`?o000000?oooooo`000?l000000_l00005ooooo`;o0000
DOooool001cooooo00?o0000ooooooooool0@?ooool2o`0000_ooooo0_l00004oooooaKo000000?o
ooooo`000?l000000oooool2o`0000Sooooo0_l0000>ooooo`;o00000oooool2o`0000Kooooo0_l0
0003ooooo`?o00001_ooool2o`0000Kooooo0_l00006ooooo`So00000_oooolPo`0000;ooooo0_l0
0002ooooo`;o00000oooool2o`0000Cooooo0ol00004ooooo`;o00005oooool2o`0003Sooooo000L
ooooo`03o`000?oooooooooo04Kooooo2?l00003ooooo`Go000000?oooooo`000?l000003?l0000:
ooooo`;o00002?ooool2o`0000oooooo0_l00005ooooo`?o000000?oooooo`000?l000001?ooool3
o`0000Gooooo0ol00006ooooo`?o00000_ooool2o`000003ooooool0003o000000Oo00000ooooolM
o`0000Gooooo1?l0000:ooooo`?o000000?oooooo`000?l000004oooool2o`0000Cooooo0_l0000h
ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00004Oooool9o`000003ooooool0003o0000
00?o00000_ooool=o`0001?ooooo0_l00002ooooo`;o00003Oooool3o`0000Cooooo1_l00002oooo
o`Co00001_ooool2o`0000?ooooo0_l00003ooooo`;o00000_ooool2o`0000Cooooo1_l000000ooo
oooo0000o`00000Mo`0000Gooooo0_l0000;ooooo`So00002_ooool2o`0000Kooooo0_l0000noooo
o`007?ooool00ol0003oooooooooo`0cooooo`;o00002?ooool2o`0000Gooooo1?l00005ooooo`;o
000000?oooooo`000?l000000_l00002ooooo`oo00001_ooool2o`0000[ooooo0_l00002ooooo`;o
00003_ooool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000001?l0000:ooooo`?o
000000Coooooo`000?l0003ooooo0_l00007ooooo`;o00001OoooolLo`0000;ooooo1?l00005oooo
o`;o00002?ooool5o`000003ooooool0003o000000[ooooo0_l0000;ooooo`;o0000>Oooool001co
oooo00?o0000ooooooooool0?Oooool2o`0000Gooooo1?l0000:ooooo`;o00000_ooool6o`0000;o
oooo2?l00005ooooo`;o00004Oooool4o`0000Sooooo0_l00003ooooo`Co00001?ooool6o`0000[o
oooo1_l000000ooooooo0000o`000002ooooo`;o00000_ooool3o`000003ooooool0003o000002Co
00001Oooool2o`0000Cooooo0_l00003ooooo`;o00000oooool4o`0001Gooooo0_l0000iooooo`00
7?ooool00ol0003oooooooooo`0looooo`;o00001_ooool4o`0000;ooooo0_l0000<ooooo`Co0000
00?oooooo`000?l000000_l00003ooooo`;o00001Oooool2o`0000_ooooo0_l00004ooooo`Co0000
1?ooool2o`0000;ooooo0_l00005ooooo`;o00001?ooool6o`0000Wooooo0_l000000ooooooo0000
o`000007ooooo`;o00000_oooolZo`000003ooooool0003o000000;ooooo1?l00002ooooo`;o0000
0oooool2o`0000?ooooo1?l0000?ooooo`;o00000oooool2o`0003[ooooo000Looooo`;o0000??oo
ool3o`0000Kooooo2?l0000@ooooo`Go00005oooool2o`0000cooooo0ol00002ooooo`;o00000_oo
ool4o`000003ooooool0003o000000;ooooo1?l0000:ooooo`;o00000_ooool4o`0000Kooooo0_l0
00000ooooooo0000o`00000To`000004ooooool0003o0000ooooo`;o00001?ooool2o`0001?ooooo
0_l0000:ooooo`?o00000_ooool2o`0003[ooooo000Looooo`03o`000?oooooooooo03;ooooo0_l0
0007ooooo`;o00001oooool6o`0001;ooooo0_l00003ooooo`;o00001oooool2o`0000Kooooo0_l0
000:ooooo`?o000000?oooooo`000?l000000oooool3o`000003ooooool0003o000000;ooooo0_l0
0003ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o00001_ooool2o`0000;ooooo1?l0
0006ooooo`Co00000ooooolSo`0000[ooooo0_l00006ooooo`;o00002_ooool2o`0000_ooooo0_l0
000nooooo`007?ooool00ol0003oooooooooo`0booooo`;o00000oooool2o`0000;ooooo0_l0000F
ooooo`?o000000Coooooo`000?l0003o00000oooool2o`0000;ooooo0_l00007ooooo`;o00001_oo
ool2o`0000[ooooo0ol000000ooooooo0000o`000002o`0000;ooooo0_l000000ooooooo0000o`00
0003ooooo`;o00001Oooool4o`0000?ooooo0_l00002ooooo`Ko00003Oooool3o`000003ooooool0
003o000002?o00000oooool2o`0000?ooooo1?l00003ooooo`;o000000Coooooo`000?l0003ooooo
0_l0001Dooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00000_ooool3o`0001Gooooo0ol0
00001?oooooo0000o`000?l00003ooooo`?o00007Oooool2o`0000Cooooo0ol00008ooooo`Co0000
1?ooool4o`0000Sooooo1_l00005ooooo`;o00002?oooolWo`0000?ooooo0_l00003ooooo`;o0000
1Oooool2o`0000Cooooo0_l00007ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0=ooo
ool2o`0000?ooooo0_l0000>ooooo`;o00000oooool2o`0000[ooooo0ol0000Mooooo`;o00001?oo
ool2o`0000Gooooo0_l00002ooooo`;o00001_ooool3o`0000Cooooo0_l00003ooooo`?o00002?oo
ool2o`0000Gooooo0_l000000ooooooo0000o`00000Uo`0000Sooooo0_l00005ooooo`Co00000_oo
ool2o`000003ooooool0003o000000?ooooo0ol0000=ooooo`;o0000??ooool001cooooo00?o0000
ooooooooool0C?ooool2o`0000?ooooo0_l00009ooooo`?o00005?ooool2o`0000kooooo1?l00003
ooooo`;o00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0ol00002
ooooo`;o00002_ooool2o`0000?ooooo1?l00002ooooobKo00002?ooool2o`0000Oooooo0_l00002
ooooo`;o000000?oooooo`000?l000000oooool2o`0000Wooooo1?l000000ooooooo0000o`00000l
ooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o00003oooool2o`0000Cooooo0_l0000;oooo
o`?o000000?oooooo`000?l000001_ooool4o`0000?ooooo1Ol000000ooooooo0000o`000004o`00
0004ooooool0003o0000ooooo`Go000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l00000
0ooooooo0000o`000002ooooo`;o00000oooool2o`0000?ooooo;ol00004ooooo`?o00001Oooool4
o`0000Cooooo0_l0000?ooooo`Co0000?oooool001cooooo00?o0000ooooooooool0=oooool2o`00
0003ooooool0003o000000oooooo0_l00005ooooo`?o00002_ooool2o`000004ooooool0003o0000
ooooo`;o00002?ooool3o`0000?ooooo0_l00004ooooo`Co00000oooool8o`0000;ooooo0_l00004
ooooo`Oo00002oooool2o`0000;ooooo0_l00009ooooo`Go000000?oooooo`000?l000002Ol00000
0ooooooo0000o`00000Jo`0000Cooooo0ol00005ooooo`;o000000?oooooo`000?l000000oooool2
o`0000;ooooo0_l0000;ooooo`;o00000_ooool2o`0003gooooo000Looooo`03o`000?oooooooooo
03Cooooo1Ol000000ooooooo0000o`000004ooooo`;o00004?ooool5o`0000Oooooo0ol00004oooo
o`;o00001_ooool2o`0000Cooooo1?l000000ooooooo0000o`000002o`0000Wooooo0ol0000<oooo
o`So00000oooool4o`0000kooooo2Ol00004ooooo`Go000000Coooooo`000?l0003ooooo5?l00005
ooooo`;o00000oooool2o`0000Kooooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool2
o`0000_ooooo0_l00002ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0=?ooool3o`00
00Wooooo0_l000000ooooooo0000o`000005ooooo`;o00002Oooool2o`0000?ooooo0_l00002oooo
o`;o00003Oooool2o`0000Cooooo1?l000000ooooooo0000o`000002o`0000Wooooo0_l0000;oooo
o`Go000000?oooooo`000?l000000_l00002ooooo`Go00000_ooool2o`0000Oooooo0_l000001?oo
oooo0000o`000?l00003ooooo`?o000000Coooooo`000?l0003ooooo1Ol000000ooooooo0000o`00
000Co`000003ooooool0003o000000;o00000_ooool2o`0000[ooooo0_l00002ooooo`;o00000_oo
ool2o`0000_ooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00001Oooool5
o`0000;ooooo0_l00007ooooo`;o00000_ooool3o`0000?ooooo0_l00007ooooo`;o00001_ooool2
o`0000Gooooo0_l00005ooooo`;o00000_ooool2o`0000Sooooo1_l00005ooooo`Co000000?ooooo
o`000?l000001?l00004ooooo`;o000000?oooooo`000?l000000_ooool5o`0000?ooooo9?l0000=
ooooo`?o00000_ooool2o`0000oooooo0_l00002ooooo`;o0000@_ooool001cooooo00?o0000oooo
ooooool0>Oooool2o`00013ooooo1?l000001?oooooo0000o`000?l00007ooooo`;o00000_ooool3
o`0000?ooooo0_l00006ooooo`?o00003Oooool2o`0000Gooooo0_l00002ooooo`;o000000?ooooo
o`000?l000001Oooool2o`000004ooooool0003o0000o`0000Gooooo0_l00003ooooo`Co00001_oo
ool2o`0000Gooooo1Ol000000ooooooo0000o`000006o`000003ooooool0003o000000?o000000?o
ooooo`000?l000005Ol0000=ooooo`;o00005oooool3o`0004;ooooo000Looooo`03o`000?oooooo
oooo03Wooooo0_l00009ooooo`;o00002_ooool3o`0000Cooooo0_l000000ooooooo0000o`00000@
ooooo`;o00002oooool2o`000003ooooool0003o000000Cooooo0_l00006ooooo`;o00002Oooool2
o`0000[ooooo1?l0000=ooooo`;o000000Coooooo`000?l0003ooooo8ol0000?ooooo`Go00003ooo
ool2o`0000;ooooo1Ol0000;ooooo`;o0000=Oooool001cooooo00?o0000ooooooooool0>Oooool2
o`000003ooooool0003o000000Kooooo0_l0000;ooooo`;o00001?ooool2o`000005ooooool0003o
0000o`000?ooool00ol0000<ooooo`;o00002_ooool8o`000004ooooool0003o0000o`00017ooooo
1Ol000000ooooooo0000o`000004ooooo`;o00003_ooool5o`000003ooooool0003o0000027o0000
1Oooool3o`0000;ooooo1ol000000ooooooo0000o`00000?ooooo`;o00000_ooool2o`0000[ooooo
0_l00002ooooo`;o0000=Oooool001cooooo00?o0000ooooooooool0??ooool2o`0001?ooooo0_l0
0008ooooo`Oo00002oooool2o`0000[ooooo3?l0000@ooooo`Ko000000?oooooo`000?l000001?oo
ool2o`0000;ooooo0_l00002ooooo`;o00001oooool7o`000003ooooool0003o000000[o00000_oo
ool>o`000004ooooool0003o0000o`0000?ooooo1Ol00002ooooo`Ko00003?ooool2o`0000Gooooo
1_l0000:ooooo`;o0000>Oooool001cooooo00?o0000ooooooooool0?oooool2o`0001[ooooo1ol0
00001?oooooo0000o`000?ooool2o`0000Sooooo0_l00005ooooo`Ko000000?oooooo`000?l00000
1?l0000Aooooo`;o00002?ooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o0000
1oooool5o`0000?ooooo7?l00007ooooo`Co00001oooool7o`0000Oooooo0_l00006ooooo`Go0000
AOooool001cooooo0_l00010ooooo`;o00007Oooool2o`0000?ooooo0_l000000ooooooo0000o`00
0002ooooo`;o00001?ooool6o`000004ooooool0003o0000o`0000Oooooo0ol00005ooooo`;o0000
5?ooool3o`0000;ooooo0_l00006ooooo`?o000000Coooooo`000?l0003ooooo1ol000000ooooooo
0000o`00000Go`000003ooooool0003o000000Oooooo1?l00008ooooo`Ko00003?ooool2o`0000Ko
oooo0_l00013ooooo`007?ooool00ol0003oooooooooo`0jooooo`;o0000;_ooool3o`000003oooo
ool0003o000000Ko00000oooool2o`0000Sooooo0ol00003ooooo`;o00005Oooool3o`000003oooo
ool0003o000000Kooooo0ol000001?oooooo0000o`000?ooool7o`0000?ooooo5_l000001?oooooo
0000o`000?l00004ooooo`;o000000?oooooo`000?l000000ol0000;ooooo`;o00000_ooool2o`00
00Sooooo0_l00004ooooo`Co00001_ooool2o`0000;ooooo0_l0000gooooo`007?ooool00ol0003o
ooooooooo`0jooooo`;o00002?ooool2o`0001Gooooo0_l00009ooooo`;o00000_ooool3o`000003
ooooool0003o000000Kooooo0_l000000ooooooo0000o`000004ooooo`?o000000Coooooo`000?l0
003o00006_ooool3o`000003ooooool0003o000000;o00001?ooool3o`000003ooooool0003o0000
00?o000000?oooooo`000?l000000_l00003oooooa_o00000_ooool9o`000003ooooool0003o0000
00?o00002?ooool3o`0000Gooooo0ol00006ooooo`;o00002?ooool2o`0000;ooooo0_l0000goooo
o`007?ooool00ol0003oooooooooo`0jooooo`Co00001_ooool2o`0001Gooooo0_l00009ooooo`;o
00000_ooool3o`0000Wooooo0_l00007ooooo`?o000000?oooooo`000?l000005oooool2o`0000;o
oooo0_l00004ooooo`;o00001Oooool2o`000003ooooool0003o000000?o000000?oooooo`000?l0
00005Ol000000ooooooo0000o`00000<o`000003ooooool0003o000000;o00000_ooool6o`0000So
oooo0_l000000ooooooo0000o`000003ooooo`?o00001_ooool2o`0004Gooooo000Looooo`03o`00
0?oooooooooo03cooooo1?l00004ooooo`;o00004oooool3o`00043ooooo0_l00002ooooo`;o0000
00Coooooo`000?l0003ooooo1?l00005ooooo`;o00000_ooool2o`0000;ooooo6Ol000001Ooooooo
0000o`000?l0003ooooo00;o000000Coooooo`000?l0003ooooo1?l00003ooooo`?o00002_ooool2
o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo1Ol000000ooooooo0000o`00
0008ooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0?_ooool3o`0001Sooooo0ol0000E
ooooo`;o000000?oooooo`000?l000003oooool2o`0000?ooooo0ol0000?ooooo`;o00001Oooool2
o`0000;ooooo1?l00004ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000;
o`000003ooooool0003o000000[o00001?ooool7o`0000?ooooo0_l0000;ooooo`;o00001_ooool2
o`000003ooooool0003o000000?ooooo1?l00002ooooo`;o00002?ooool2o`0003Sooooo000Loooo
o`03o`000?oooooooooo03kooooo0ol00009ooooo`?o00009?ooool5o`0000oooooo0ol00002oooo
o`?o00006_ooool4o`0000?ooooo0_l00003ooooo`?o00001oooool:o`000003ooooool0003o0000
00So000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000001Kooooo0_l00003oooo
o`Co00000_ooool3o`0004Oooooo000Looooo`03o`000?oooooooooo03Wooooo1?l00002ooooo`Co
00001oooool3o`0002Kooooo0_l0000Aooooo`;o00001Oooool2o`0000Cooooo0_l0000Dooooo`;o
00000oooool4o`0000;ooooo0_l00003ooooo`;o00001Oooool7o`000003ooooool0003o000000?o
00000_ooool3o`000003ooooool0003o000000?o00003oooool2o`0000Kooooo0_l00003ooooo`?o
00000_ooool4o`0000;ooooo0ol00017ooooo`007?ooool00ol0003oooooooooo`0iooooo`Co0000
0oooool3o`0000cooooo0_l0000eooooo`;o00000_ooool5o`0000Cooooo0_l00002ooooo`;o0000
1?ooool2o`0000[ooooo0_l00005ooooo`;o00001oooool3o`0000Gooooo1_l00004ooooo`;o0000
0_ooool3o`000003ooooool0003o000000Co00002oooool5o`0000Kooooo0_l00004ooooo`Co0000
1_ooool2o`0004Sooooo000Looooo`03o`000?oooooooooo03_ooooo0_l00005ooooo`;o00002ooo
ool2o`0002Wooooo0_l0000:ooooo`;o00000_ooool4o`0000Wooooo0_l00004ooooo`;o00002_oo
ool2o`0000Gooooo1?l000000ooooooo0000o`000003ooooo`;o00001Oooool2o`0000;ooooo0_l0
00000ooooooo0000o`000003o`0000;ooooo0ol00004ooooo`?o00000oooool2o`0000Cooooo1_l0
00000ooooooo0000o`000006ooooo`;o00000_ooool5o`0000Cooooo0ol00018ooooo`007?ooool0
0ol0003oooooooooo`0jooooo`;o00000_ooool2o`0000;ooooo0_l0000fooooo`?o00001Oooool2
o`0000Kooooo1?l0000?ooooo`;o00002Oooool2o`0000Kooooo1ol0000Aooooo`_o00000oooool2
o`0000Cooooo0_l000000ooooooo0000o`000005o`0000?ooooo0_l00006ooooo`;o00000_ooool2
o`000004ooooool0003o0000o`0000?ooooo0_l00019ooooo`007?ooool00ol0003oooooooooo`0j
ooooo`;o00000_ooool2o`0000Oooooo0_l0000booooo`;o00001Oooool3o`0000?ooooo1?l0000:
ooooo`;o00001Oooool2o`0000Wooooo0_l000000ooooooo0000o`000007ooooo`;o00004oooool7
o`000003ooooool0003o000000cooooo0ol000001?oooooo0000o`000?l0000?ooooo`;o00000_oo
ool2o`0004kooooo000Looooo`03o`000?oooooooooo03Cooooo0_l00007ooooo`?o00000_ooool2
o`0000?ooooo0ol0000Wooooo`Co00003_ooool2o`0000;ooooo1ol00008ooooo`;o00004oooool2
o`0000kooooo0_l0000Vooooo`;o00003oooool3o`0005;ooooo000Looooo`03o`000?oooooooooo
03Cooooo0_l00007ooooo`Oo000000Coooooo`000?l0003ooooo0_l0000Qooooo`?o00000oooool4
o`0000[ooooo0_l00005ooooo`?o000000?oooooo`000?l000000_l00004ooooo`;o00000_ooool3
o`0000oooooo0_l0000Aooooo`;o00003_ooool2o`0000gooooo0_l00005ooooo`;o00004Oooool3
o`0005;ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0dooooo`;o00002Oooool4o`0000;ooooo
0_l0000Tooooo`?o00004Oooool2o`0000Gooooo0_l0000:ooooo`;o00000_ooool3o`0000cooooo
0_l000000ooooooo0000o`000002ooooo`;o00007Oooool2o`0000gooooo1_l000000ooooooo0000
o`00001Vooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGo
MgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0=oooool2o`0000Oooooo0_l000000ooo
oooo0000o`00000Xooooo`;o000000?oooooo`000?l000004_ooool6o`000003ooooool0003o0000
01Sooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l00007ooooo`Co00008Oooool4o`00
017ooooo0_l00002ooooo`;o0000D_ooool00003ooooool@413ooooo00;ooooo00?o410@oooooooo
ool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0=oooool2o`00
00Gooooo0_l00003ooooo`;o0000:?ooool2o`000005ooooool0003o0000o`000?ooool00_l00007
ooooo`?o00001?ooool2o`000005ooooool0003o0000o`000?ooool00_l0000Looooo`;o00000ooo
ool2o`0000Gooooo1_l0000Sooooo`;o00003_ooool5o`0000;ooooo0_l0001Booooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_oo
ool3o`0003_ooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000009?oo
ool2o`0000Cooooo1Ol00007ooooo`?o00001_ooool4o`0000oooooo0_l0000Dooooo`;o00001?oo
ool2o`0000?ooooo0_l00009ooooo`;o00009oooool3o`0005Sooooo00000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oo
oooooooo03_ooooo0_l00005ooooo`Go00008Oooool5o`0000Gooooo0ol0000@ooooo`Go00003ooo
ool2o`0001Cooooo0_l00003ooooo`;o00000oooool3o`0000;ooooo0_l00004ooooo`?o00001?oo
ool5o`0000;ooooo0_l0000Kooooo`;o0000F?ooool00003ooooool@413ooooo00;ooooo00?o410@
ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo03cooooo0_l00005
ooooo`;o00008oooool4o`0000Kooooo1?l0000?ooooo`Go000000?oooooo`000?l000007?ooool2
o`0000Cooooo1?l000000ooooooo0000o`000002o`000003ooooool0003o000000;ooooo1Ol00002
ooooo`;o000000Coooooo`000?l0003ooooo1_l00002ooooo`;o000000?oooooo`000?l000000_l0
0003ooooo`;o00004Oooool2o`0005Sooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo
00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0kooooo`?o00001Oooool2o`0002Oooooo
0_l00006ooooo`;o00004Oooool2o`0000;ooooo0_l0000Looooo`;o000000Coooooo`000?l0003o
oooo1?l00003ooooo`;o00001Oooool2o`000003ooooool0003o000000Gooooo0_l000000ooooooo
0000o`000009ooooo`Co00000oooool2o`0000Kooooo1?l00007ooooo`;o0000F?ooool00006oooo
ooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooo
oooo03Cooooo0_l00004ooooo`?o0000;_ooool3o`0000;ooooo1?l00004ooooo`?o00002oooool5
o`0000kooooo0_l0000Aooooo`Co00000oooool2o`0000kooooo2?l000000ooooooo0000o`000007
ooooo`;o00001?ooool2o`0000Oooooo1?l00004ooooo`;o000000?oooooo`000?l00000F?ooool0
01cooooo00?o0000ooooooooool0=?ooool2o`0000Cooooo0ol0000^ooooo`;o00000_ooool<o`00
00_ooooo1_l0000=ooooo`;o00000oooool2o`0000[ooooo0_l00002ooooo`;o00000_ooool3o`00
00kooooo2ol0000=ooooo`;o00001oooool2o`000004ooooool0003o0000ooooo`Co0000Foooool0
01cooooo00?o0000ooooooooool0>oooool2o`0000cooooo0_l0000Noooooa;o00000_ooool2o`00
00Sooooo0_l000000ooooooo0000o`00000Booooo`;o00000oooool2o`0000Gooooo0_l000001?oo
oooo0000o`000?l00002ooooo`;o00004?ooool2o`0000Gooooo1?l00002ooooo`;o00003Oooool2
o`0000;ooooo0_l000000ooooooo0000o`000005o`0005_ooooo000Looooo`03o`000?oooooooooo
037ooooo0_l0000Fooooo`;o00007_ooool@o`0000Cooooo0_l0000Tooooo`;o00002?ooool3o`00
01Kooooo0_l00005ooooo`;o00000_ooool2o`0000;ooooo0_l00009ooooo`;o00001oooool2o`00
05kooooo000Looooo`03o`000?oooooooooo037ooooo0_l0000]ooooo`;o00002?oooolAo`0000;o
oooo0_l00008ooooo`?o00006_ooool2o`00023ooooo0_l0000=ooooo`;o00004Oooool2o`0000oo
oooo0_l000000ooooooo0000o`00001;ooooo`007?ooool00ol0003oooooooooo`0aooooo`;o0000
;Oooool4o`0000Cooooo2ol00002ooooo`Oo000000?oooooo`000?l000000_l00006ooooo`?o0000
2Oooool2o`0000oooooo0_l0000?ooooo`?o00006oooool2o`0000gooooo0_l00004ooooo`;o0000
3oooool2o`000003ooooool0003o000000;o0000BOooool001cooooo00?o0000ooooooooool0<Ooo
ool2o`0000[ooooo0_l0000Sooooo`;o000000Coooooo`000?l0003ooooo1Ol000000ooooooo0000
o`00000<o`000003ooooool0003o000000;o00004_ooool3o`0000;ooooo0_l00005ooooo`;o0000
5?ooool3o`0001Cooooo1?l00003ooooo`Co00000_ooool5o`0000Cooooo1?l0000Fooooo`Co0000
BOooool001cooooo00?o0000ooooooooool0?Oooool2o`0002?ooooo0_l000000ooooooo0000o`00
000Io`0001Cooooo0_l000001?oooooo0000o`000?l00004ooooo`?o00005_ooool2o`0001?ooooo
1?l00005ooooo`;o00000_ooool5o`0000Cooooo1Ol0000<ooooo`;o00001oooool2o`000003oooo
ool0003o000004Sooooo000Looooo`03o`000?oooooooooo03cooooo0_l0000Rooooo`Go00000_oo
oolHo`000003ooooool0003o000001Gooooo0_l00005ooooo`;o00005oooool5o`0000_ooooo0_l0
000:ooooo`;o00000_ooool5o`0000Cooooo0_l000000ooooooo0000o`000002o`0000[ooooo1?l0
0002ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo0_l00014ooooo`007?ooool0
0ol0003oooooooooo`0looooo`;o00008_ooool2o`000003ooooool0003o000000Cooooo4?l00000
0ooooooo0000o`000003o`000003ooooool0003o000000Gooooo0_l0000;ooooo`;o00004?ooool2
o`0000Cooooo0_l00005ooooo`;o00000_ooool6o`0000[ooooo0_l00009ooooo`?o00000_ooool6
o`000003ooooool0003o000000Co000000?oooooo`000?l000002_ooool2o`0000Cooooo0_l0000:
ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0JOoooolFo`000003ooooool0003o0000
00Cooooo0ol0000;ooooo`;o00003_ooool4o`0000Cooooo0_l00005ooooo`;o00000_ooool2o`00
0003ooooool0003o000000;o00004_ooool4o`0000?ooooo1_l000000ooooooo0000o`000002oooo
o`;o0000IOooool001cooooo00?o0000ooooooooool0<oooool2o`0002cooooo0_l00003oooooaco
00001?ooool2o`0000;ooooo0_l0000>ooooo`;o000000?oooooo`000?l000001Oooool2o`0000So
oooo1_l00003ooooo`;o00000oooool3o`0000Gooooo1?l00008ooooo`;o000000?oooooo`000?l0
00000_ooool6o`000003ooooool0003o000001Kooooo0_l00002ooooo`;o00000_ooool2o`0004Wo
oooo000Looooo`;o0000=?ooool2o`0002cooooo7ol0000:ooooo`;o00003?ooool4o`000003oooo
ool0003o000000kooooo1ol00009ooooo`?o00001?ooool4o`0000Oooooo1_l00009ooooo`Co0000
1_ooool2o`0000?ooooo0_l00005ooooo`Co00000_ooool2o`0000;ooooo0_l00019ooooo`007?oo
ool00ol0003oooooooooo`1Roooooago00006Oooool2o`0000?ooooo0_l00003ooooo`;o00001_oo
ool2o`000003ooooool0003o000000oooooo1ol00007ooooo`;o000000?oooooo`000?l000000ol0
000<ooooo`;o00001_ooool2o`0000?ooooo0_l00005ooooo`;o00002Oooool2o`0004Sooooo000L
ooooo`03o`000?oooooooooo03oooooo0ol0000Pooooo`;o000000?oooooo`000?l000006?l00008
ooooo`;o00001?ooool2o`0000Wooooo0ol00002ooooo`;o00000oooool2o`0000?ooooo0_l00000
0ooooooo0000o`00000Cooooo`So00001Oooool2o`0000Cooooo0_l0000Eooooo`;o00002?ooool3
o`0000Wooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`0oooooo`Co00003?ooool2o`00
017ooooo7Ol00006ooooo`Co00001?ooool2o`0000Gooooo0_l00003ooooo`;o00001_ooool5o`00
0004ooooool0003o0000ooooo`;o00002_ooool2o`0000Sooooo1?l000000ooooooo0000o`000006
ooooo`?o00004?ooool4o`0000Gooooo0ol00004ooooo`;o000000?oooooo`000?l000002?ooool2
o`0004[ooooo000Looooo`03o`000?oooooooooo047ooooo0_l00006ooooo`;o00001?ooool2o`00
01?ooooo7Ol00004ooooo`;o00002Oooool2o`000004ooooool0003o0000o`0000Wooooo1ol0000>
ooooo`Co00001Oooool2o`0000;ooooo0_l0000:ooooo`?o00004?ooool4o`0000Kooooo0_l00002
ooooo`Co00001_ooool2o`0000?ooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`19oooo
o`;o00006Oooool8o`000003ooooool0003o000001;o00001_ooool2o`0000Oooooo0_l000000ooo
oooo0000o`00000:ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o00002Oooool2
o`0000Oooooo0_l0000Hooooo`;o00001Oooool2o`0000kooooo0_l00006ooooo`Go0000C_ooool0
01cooooo00?o0000ooooooooool0I?ooool8o`000003ooooool0003o000001;o00001_ooool2o`00
00Oooooo0_l00003ooooo`;o00001oooool2o`0000Kooooo1Ol0000/ooooo`;o000000?oooooo`00
0?l000000_ooool3o`0001Gooooo0_l000000ooooooo0000o`00001>ooooo`007?ooool00ol0003o
ooooooooo`1Uoooooa[o00005_ooool2o`0000Oooooo0_l00007ooooo`Co00005_ooool2o`0001Oo
oooo0ol00002ooooo`;o00005oooool2o`0004oooooo000Looooo`03o`000?oooooooooo06Gooooo
6ol0000;ooooo`;o00003_ooool4o`0000;ooooo0_l00004ooooo`Oo000000?oooooo`000?l00000
1Oooool2o`0000Kooooo0_l000000ooooooo0000o`00000Booooo`;o00001?ooool3o`0000;ooooo
0_l0000Eooooo`?o0000Coooool001cooooo00?o0000ooooooooool0IOoooolKo`0000Gooooo0_l0
0004ooooo`;o00003_ooool4o`0000;ooooo0_l00005ooooo`Ko000000?oooooo`000?l000001Ooo
ool2o`0000Kooooo1Ol00002ooooo`;o00001Oooool2o`0000Oooooo0_l00005ooooo`;o00000_oo
ool2o`00013ooooo0_l00003ooooo`;o0000D?ooool001cooooo00?o0000ooooooooool0IOooool3
o`000003ooooool0003o000001;o00002?ooool2o`000004ooooool0003o0000ooooo`;o00003_oo
ool3o`0000;ooooo0_l00003ooooo`Oo00000oooool2o`0000kooooo0_l00004ooooo`Co00000ooo
ool2o`00027ooooo0_l000000ooooooo0000o`00001Eooooo`007?ooool00ol0003oooooooooo`17
ooooo`;o00005_ooool2o`000003ooooool0003o000000oo000000?oooooo`000?l000001_l00000
0ooooooo0000o`000009ooooo`;o00000oooool2o`0000cooooo1?l000001?oooooo0000o`000?oo
ool9o`0001Cooooo0_l00003ooooo`Co00002oooool3o`000003ooooool0003o000001Gooooo0_l0
001Hooooo`007?ooool00ol0003oooooooooo`17ooooo`;o000000?oooooo`000?l000004ooooolP
o`0000[ooooo0_l00002ooooo`;o00003_ooool2o`0000;ooooo4Ol0000>ooooo`Co00004?ooool3
o`000003ooooool0003o000000kooooo0_l00006ooooo`;o00001?ooool2o`00057ooooo000Loooo
o`03o`000?oooooooooo04[ooooo0_l0000Doooooago000000?oooooo`000?l000002Oooool2o`00
00kooooo1_l00002oooooa7o00003_ooool6o`0000Wooooo0_l00004ooooo`;o000000?oooooo`00
0?l000003_ooool2o`0000Kooooo0_l00003ooooo`?o0000DOooool001cooooo00?o0000oooooooo
ool0Goooool2o`0000?ooooo4Ol000000ooooooo0000o`000003o`0000?ooooo0_l00003ooooo`;o
00005?ooool6o`000003ooooool0003o0000013o00004?ooool4o`000003ooooool0003o000000Ko
oooo0_l00004ooooo`Go00005?ooool2o`0000Gooooo0_l0001Booooo`007?ooool00ol0003ooooo
ooooo`1Oooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`00000=o`0000;ooooo
0ol00008ooooo`;o00005oooool2o`0000;ooooo4ol00003ooooo`;o00002_ooool2o`0000?ooooo
0_l0000=ooooo`Co00002oooool2o`0000Kooooo0ol00005ooooo`;o0000D_ooool001cooooo0_l0
0017ooooo`;o00006_ooool3o`0000Kooooo2ol00002ooooo`;o00000oooool2o`0000_ooooo0_l0
000<ooooo`?o00001_oooolBo`0000?ooooo0_l00006ooooo`;o00000oooool2o`0000[ooooo0_l0
0005ooooo`Co00002oooool2o`0000Kooooo0_l00006ooooo`;o0000D_ooool001cooooo00?o0000
ooooooooool0A_ooool3o`000003ooooool0003o000001Kooooo1Ol00004ooooo`Go00000_ooool4
o`0000Oooooo0_l0000;ooooo`;o00003?ooool3o`0000?ooooo5_l00007ooooo`;o000000Cooooo
o`000?l0003o00000_ooool2o`0000?ooooo0_l00005ooooo`;o00004oooool2o`0006?ooooo000L
ooooo`03o`000?oooooooooo04Kooooo0ol000000ooooooo0000o`00000Fooooo`;o000000Cooooo
o`000?l0003o00001?ooool4o`0000;ooooo1?l000000ooooooo0000o`000009ooooo`;o000000?o
ooooo`000?l000005_oooolHo`0000Kooooo0_l00002ooooo`;o00001oooool2o`0000Kooooo0_l0
000Booooo`;o00000_ooool2o`0000_ooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`1U
ooooo`?o00001?ooool2o`0000Gooooo0ol000000ooooooo0000o`000009ooooo`;o000000?ooooo
o`000?l000005_oooolHo`0000Kooooo0_l0000Cooooo`;o00005_ooool2o`0000_ooooo0_l0001B
ooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00004oooool2o`0000Gooooo0_l0000_oooo
oaSo00001_ooool4o`0000?ooooo0_l0000Tooooo`;o000000?oooooo`000?l00000G?ooool001co
oooo00?o0000ooooooooool0Coooool3o`00013ooooo0_l00005ooooo`;o00003oooool2o`00027o
oooo6?l00006ooooo`Co000000?oooooo`000?l000000_l00003ooooo`;o00008_ooool2o`0005co
oooo000Looooo`03o`000?oooooooooo04oooooo0ol0000?ooooo`?o00001Oooool2o`0000;ooooo
0_l0000:ooooo`?o00008_oooolHo`0000Sooooo1Ol000001?oooooo0000o`000?ooool3o`0000Oo
oooo0_l00008ooooo`;o00004_ooool2o`0005Sooooo000Looooo`03o`000?oooooooooo067ooooo
0_l0000:ooooo`;o00002?ooool4o`0000Oooooo0_l0000Cooooo`;o00001OoooolHo`0000Sooooo
0_l000000ooooooo0000o`000003o`0000;ooooo1?l00005ooooo`;o00002?ooool3o`0000;ooooo
0_l00003ooooo`;o00002?ooool2o`0005Sooooo000Looooo`03o`000?oooooooooo04Cooooo0_l0
0004ooooo`;o00001oooool2o`0000_ooooo0_l000000ooooooo0000o`00000?ooooo`Go00002Ooo
ool2o`0001?ooooo0ol00004ooooo`;o000000?oooooo`000?l000005Ol0000:ooooo`[o00000ooo
ool2o`0000_ooooo0_l00002ooooo`;o00000oooool2o`0006;ooooo000Looooo`03o`000?oooooo
oooo04Cooooo0_l00004ooooo`;o00001Oooool4o`0000_ooooo1Ol0000?ooooo`Co00007oooool3
o`0000Cooooo6_l0000:ooooo`Wo00000_ooool4o`0001Wooooo0_l0001Mooooo`007?ooool00ol0
003oooooooooo`1Aooooo`;o00003_ooool2o`0000gooooo0_l00007ooooo`?o00007?ooool2o`00
00Gooooo1?l000000ooooooo0000o`00000>o`0000;ooooo0_l00006ooooo`co00000oooool2o`00
00Cooooo0_l0000Eooooo`;o0000GOooool001cooooo00?o0000ooooooooool0L?ooool2o`0000Oo
oooo1Ol0000Sooooo`Wo000000?oooooo`000?l000001ol00002ooooo`;o000000?oooooo`000?l0
00000oooool4o`0000_ooooo0_l00004ooooo`;o00004oooool2o`0005oooooo000Looooo`03o`00
0?oooooooooo04Kooooo0_l0000Mooooo`;o00005Oooool2o`0000Gooooo0ol0000Jooooo`;o0000
00?oooooo`000?l000003?l000001?oooooo0000o`000?l00003ooooo`?o00000_ooool3o`0000;o
oooo0_l00003ooooo`;o00001?ooool2o`0001Wooooo0_l0001Oooooo`007?ooool00ol0003ooooo
ooooo`16ooooo`;o00003oooool2o`0000cooooo0_l0000Looooo`?o00004_ooool2o`0000Kooooo
0_l00002ooooo`go000000Coooooo`000?l0003o00000oooool2o`0000?ooooo0ol00002ooooo`Co
000000?oooooo`000?l000001?ooool2o`0007[ooooo000Looooo`03o`000?oooooooooo05Oooooo
0_l0000oooooo`;o00001oooool3o`0000;ooooo1?l00005ooooo`?o00004Oooool3o`0000Oooooo
0_l0000Eooooo`;o0000Hoooool001cooooo00?o0000ooooooooool0N?ooool2o`0002Oooooo0ol0
0003ooooo`?o00000_ooool3o`000003ooooool0003o0000017ooooo0_l00003ooooo`;o00000ooo
ool2o`0000Kooooo0_l0000:ooooo`;o000000?oooooo`000?l00000Hoooool001cooooo0_l0001S
ooooo`;o000000?oooooo`000?l000004Oooool2o`0000cooooo0_l0000Tooooo`?o00000oooool2
o`00017ooooo0_l000000ooooooo0000o`000003o`0000Gooooo0_l000000ooooooo0000o`000006
ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0006?ooooo000Looooo`03o`000?oooooo
oooo06;ooooo0_l000000ooooooo0000o`00000Oooooo`;o00006Oooool2o`0000oooooo0_l0000A
ooooo`;o000000?oooooo`000?l000001?l00004ooooo`;o00002Oooool5o`0006Oooooo000Loooo
o`03o`000?oooooooooo06[ooooo0_l0000aooooo`Ko00003oooool2o`0001Gooooo1Ol0000Aoooo
o`;o0000J?ooool001cooooo00?o0000ooooooooool0J_ooool2o`0001Cooooo0_l00004ooooo`?o
00005?ooool4o`00013ooooo1?l0000Dooooo`Go00001?ooool4o`0007?ooooo000Looooo`03o`00
0?oooooooooo04_ooooo0_l0000Mooooo`;o00005?ooool2o`0000Cooooo0ol00003ooooo`;o0000
7Oooool2o`0000Cooooo1?l0000Eooooo`Ko00000_ooool4o`0007?ooooo000Looooo`03o`000?oo
oooooooo04_ooooo0_l0000Mooooo`;o00008?ooool2o`0001gooooo0_l00005ooooo`;o00006?oo
ool4o`0007Wooooo000Looooo`03o`000?oooooooooo06Wooooo0_l00005ooooo`Co0000<?ooool2
o`0000Sooooo1?l00008ooooo`?o00005oooool2o`0007?ooooo000Looooo`03o`000?oooooooooo
05Oooooo0_l00004ooooo`;o00002_ooool2o`0000?ooooo1_l0000`ooooo`;o00002?ooool6o`00
00Kooooo0ol0000Gooooo`;o0000Loooool001cooooo00?o0000ooooooooool0Eoooool2o`0000Co
oooo0_l00009ooooo`;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000006ooooo`;o
0000;?ooool2o`0000Gooooo0_l00009ooooo`;o0000R_ooool001cooooo00?o0000ooooooooool0
J?ooool2o`0000;ooooo0_l00007ooooo`;o00001_ooool2o`0000[ooooo0_l0000Pooooo`;o0000
1Oooool4o`0000Oooooo0_l00005ooooo`;o000000Coooooo`000?l0003o00002_ooool2o`0007?o
oooo000Looooo`03o`000?oooooooooo06cooooo0_l0000Kooooo`;o00008_ooool2o`0000Gooooo
0_l00002ooooo`;o000000?oooooo`000?l000001Oooool4o`000004ooooool0003o0000o`0000[o
oooo0_l0001cooooo`007?ooool00ol0003oooooooooo`1looooo`;o00003oooool2o`0001cooooo
1?l00006ooooo`Go000000?oooooo`000?l000001Oooool4o`0000Wooooo0_l0001hooooo`007?oo
ool00ol0003oooooooooo`1Rooooo`;o00005_ooool4o`0000oooooo0_l00003ooooo`;o00005ooo
ool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool4o`0000[ooooo0_l0000:ooooo`;o0000
N?ooool001cooooo00?o0000ooooooooool0GOooool2o`0000?ooooo0_l0000Fooooo`;o00005_oo
ool2o`0001[ooooo0ol000000ooooooo0000o`00000;ooooo`;o00001Oooool2o`00087ooooo0000
1_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<
c<`01_ooool00ol0003oooooooooo`1Mooooo`;o00000_ooool2o`0001;ooooo0_l0000gooooo`;o
00003Oooool4o`0000Gooooo0_l00003ooooo`;o0000O?ooool00006oooooomgMgOoV9RHoooooonH
V9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooo
oooo067ooooo0_l0000:ooooo`;o00001_ooool2o`0001oooooo0_l0000Uooooo`;o00000_ooool3
o`0000;ooooo0_l00003ooooo`;o0000O?ooool00003ooooool@413ooooo00;ooooo00?o410@oooo
ooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0IOooool2
o`0000Kooooo0_l0000Wooooo`;o0000:Oooool3o`0000;ooooo0_l00003ooooo`;o0000O?ooool0
0003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Olb<S;oV9RHoooooonHV9So
<S8b00Kooooo0ol0001Pooooo`;o000000?oooooo`000?l000000_l0003Rooooo`0000?oooooo`00
0?ooool00_ooool00ol0003oooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool0
0ol0003oooooooooo`1Pooooo`;o000000?oooooo`000?l000001oooool2o`0000cooooo0_l0003=
ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooo
okZj^_l@41001_ooool00ol0003oooooooooo`1/ooooo`;o00000_ooool2o`0000Sooooo0_l0003=
ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`1Vooooo`;o00001Oooool2o`000003ooooool0003o000000Sooooo
0_l0003=ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@
4?nYZJT01_ooool00ol0003oooooooooo`1Vooooo`;o00001Oooool2o`000=[ooooo000Looooo`03
o`000?oooooooooo06Gooooo0_l00009ooooo`;o0000eoooool001cooooo00?o0000ooooooooool0
IOooool2o`0000Wooooo0_l0003Gooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o00002_oo
ool2o`0000kooooo0_l0003=ooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o00002_ooool2
o`0000?ooooo0_l00009ooooo`;o0000cOooool001cooooo00?o0000ooooooooool0Koooool2o`00
00Wooooo0_l0003=ooooo`007?ooool00ol0003oooooooooo`3Oooooo`;o0000J?ooool001cooooo
00?o0000ooooooooool0KOooool2o`0006cooooo0_l00002ooooo`;o0000J?ooool001cooooo00?o
0000ooooooooool0KOooool2o`0006cooooo0_l0001/ooooo`007?ooool00ol0003oooooooooo`25
ooooo`;o0000`_ooool001cooooo00?o0000ooooooooool0L_ooool2o`00017ooooo0_l00032oooo
o`007?ooool00ol0003oooooooooo`1booooo`;o0000eOooool001cooooo0_l0003ooooood_ooooo
000Looooo`03o`000?oooooooooo07Gooooo0_l0000Kooooo`;o00006?ooool2o`0009_ooooo000L
ooooo`03o`000?oooooooooo07Gooooo0_l0000Kooooo`;o00000_ooool2o`00013ooooo1_l0002K
ooooo`007?ooool00ol0003oooooooooo`2Fooooo`;o000000?oooooo`000?l000003Oooool5o`00
09cooooo000Looooo`03o`000?oooooooooo09Wooooo0_l00006ooooo`?o0000;Oooool2o`0007Ko
oooo000Looooo`03o`000?oooooooooo0:7ooooo0ol0000]ooooo`;o0000M_ooool001cooooo00?o
0000ooooooooool0NOooool2o`000<kooooo000Looooo`03o`000?oooooooooo07Wooooo1?l0003<
ooooo`007?ooool00ol0003oooooooooo`1kooooo`;o00000oooool2o`000<Oooooo000Looooo`03
o`000?oooooooooo083ooooo0_l00018ooooo`;o0000OOooool001cooooo00?o0000ooooooooool0
b_ooool2o`0007gooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0Poooool2o`000<Cooooo000Looooo`03o`000?oooooooooo08?ooooo0_l0000ooooo
o`;o0000Poooool001cooooo00?o0000ooooooooool0a?ooool2o`0008?ooooo000Looooo`03o`00
0?oooooooooo0;oooooo0_l00028ooooo`007?ooool2o`000;cooooo0_l00002ooooo`;o0000R?oo
ool001cooooo00?o0000ooooooooool0^oooool2o`0008cooooo000Looooo`03o`000?oooooooooo
0:Kooooo0_l00004ooooo`Co00001?ooool2o`0009?ooooo000Looooo`03o`000?oooooooooo09?o
oooo0_l00009ooooo`;o00001_ooool2o`0000Cooooo1?l00004ooooo`;o0000Toooool001cooooo
00?o0000ooooooooool0Toooool4o`0000Oooooo0ol0002Xooooo`007?ooool00ol0003ooooooooo
o`2Eooooo`;o00002?ooool2o`000:Sooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003o
oooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001;ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB_oo
ool001Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood[ooooo000Doooo
o`03o`000?oooooooooo00Gooooo0ol0003ooooood[ooooo000Dooooo`03o`000?oooooooooo0?oo
ooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003ooooooooo
o`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001;ooooo00?oEEEEofIV
I_l00000oooooomDooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00YOooool0
1?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo01Oooooo0_l000000ol@413ooooooooo
o`03ooooo`03o`000?o^k^kooooo00Gooooo0_l000000ol@413oooooooooo`2>ooooo`00Y_ooool0
1Ol0003ooooooooooooooooo000000Wooooo1_l0000<ooooo`03o`000?oooooooooo00Cooooo00?o
EEEEojVYZOooool01_ooool00ol0003oooooooooo`2?ooooo`00Y_ooool01Ol0003ooooooooooooo
oooo000001Sooooo1Ol00005ooooo`03ojVYZOmEEEGooooo00?ooooo1Ol0002@ooooo`00Y_ooool0
1Ol0003ooooooooooooooooo000000Wooooo1_l00009ooooo`04odA4A?oMgMgoooooo`0000Oooooo
00?o8B4Qooooooooool00_ooool01?m4A4CogMgMooooool0002Aooooo`00Y_ooool01Ol0003oQhN7
oooooonYZJWo000001Sooooo00CogMgMoeEEEOoooooo00001oooool00omEEEGoc<c<ooooo`02oooo
o`04omgMgOmEEEGoooooo`00097ooooo002Uooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHoooo
ooooool05oooool00omgMgOoc<c<o`000007ooooo`03ojVYZOmgMgOooooo00?ooooo00?oMgMgolc<
c?l00000TOooool00<Cooooo00?ok^k^odA4A?l000001?ooool01Ol@413ooooooooooooooooo<S8b
00Cooooo00?ok^k^odA4A?l00000TOooool00<Gooooo00?oMgMgo`000?ooool00oooool5o`0000Go
oooo00?oMgMgo`000?ooool0T?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(480) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.54173 .36646 Mdot
.54722 .3536 Mdot
.32471 .60764 Mdot
.6252 .56326 Mdot
.52978 .7221 Mdot
.33992 .65112 Mdot
.32857 .42265 Mdot
.31866 .41115 Mdot
.32649 .65237 Mdot
.65404 .37478 Mdot
.30018 .4409 Mdot
.60325 .5885 Mdot
.31366 .4295 Mdot
.63975 .52901 Mdot
.4864 .40284 Mdot
.65566 .46782 Mdot
.58593 .31376 Mdot
.47534 .72702 Mdot
.67866 .47697 Mdot
.30926 .62954 Mdot
.72713 .61152 Mdot
.65095 .52766 Mdot
.55289 .30305 Mdot
.64237 .52739 Mdot
.60114 .52789 Mdot
.55666 .3441 Mdot
.53704 .36312 Mdot
.60588 .51085 Mdot
.57881 .52822 Mdot
.29823 .43268 Mdot
.32963 .70701 Mdot
.78703 .32666 Mdot
.67997 .50656 Mdot
.75794 .36671 Mdot
.32338 .41152 Mdot
.28322 .47885 Mdot
.32948 .61647 Mdot
.34775 .43898 Mdot
.31551 .4068 Mdot
.32604 .4087 Mdot
.33952 .42942 Mdot
.56382 .33913 Mdot
.3244 .40352 Mdot
.23849 .62623 Mdot
.62427 .52961 Mdot
.48922 .33834 Mdot
.18116 .58204 Mdot
.59497 .51233 Mdot
.57819 .34668 Mdot
.30242 .64121 Mdot
.60237 .77215 Mdot
.30679 .45805 Mdot
.44711 .42114 Mdot
.50581 .90911 Mdot
.30851 .43828 Mdot
.60995 .56451 Mdot
.32244 .66338 Mdot
.65052 .55112 Mdot
.64146 .5694 Mdot
.73418 .32778 Mdot
.66757 .53011 Mdot
.51089 .7093 Mdot
.53326 .29329 Mdot
.37507 .65306 Mdot
.33145 .65608 Mdot
.34403 .44251 Mdot
.52908 .30536 Mdot
.31064 .41958 Mdot
.58206 .5117 Mdot
.3077 .62411 Mdot
.58128 .52592 Mdot
.29619 .43517 Mdot
.52435 .32262 Mdot
.62221 .52664 Mdot
.4402 .34372 Mdot
.25399 .3917 Mdot
.31671 .59407 Mdot
.80133 .46775 Mdot
.61893 .80093 Mdot
.42391 .65479 Mdot
.63239 .5144 Mdot
.48193 .86168 Mdot
.46368 .45799 Mdot
.5431 .35625 Mdot
.5901 .38376 Mdot
.47985 .21317 Mdot
.60139 .50671 Mdot
.41692 .58519 Mdot
.69356 .53192 Mdot
.51556 .61449 Mdot
.31867 .64641 Mdot
.53505 .34155 Mdot
.62488 .52217 Mdot
.66112 .50093 Mdot
.61576 .29043 Mdot
.58806 .56032 Mdot
.61853 .55402 Mdot
.60779 .34628 Mdot
.30322 .44771 Mdot
.54477 .54084 Mdot
.51475 .77811 Mdot
.44108 .39629 Mdot
.60107 .55472 Mdot
.34071 .62444 Mdot
.53381 .2899 Mdot
.61442 .54822 Mdot
.31638 .41463 Mdot
.6396 .51729 Mdot
.27234 .4147 Mdot
.57662 .30755 Mdot
.67852 .51135 Mdot
.47602 .70481 Mdot
.53229 .56053 Mdot
.56728 .31242 Mdot
.76335 .49654 Mdot
.66241 .52497 Mdot
.66668 .54114 Mdot
.55292 .3562 Mdot
.325 .61146 Mdot
.34403 .56392 Mdot
.54028 .30552 Mdot
.32254 .40676 Mdot
.58683 .33233 Mdot
.65664 .58233 Mdot
.32092 .61575 Mdot
.44437 .40981 Mdot
.44566 .39895 Mdot
.57004 .6944 Mdot
.62359 .51693 Mdot
.52944 .53607 Mdot
.34238 .63471 Mdot
.56309 .34703 Mdot
.30505 .42503 Mdot
.62385 .57728 Mdot
.56439 .31967 Mdot
.30016 .40816 Mdot
.52027 .72475 Mdot
.52623 .74072 Mdot
.57643 .33683 Mdot
.7175 .48843 Mdot
.27155 .4458 Mdot
.33542 .41305 Mdot
.60059 .76997 Mdot
.54571 .35842 Mdot
.49338 .69932 Mdot
.28846 .41447 Mdot
.67168 .67885 Mdot
.66795 .5592 Mdot
.57539 .74584 Mdot
.39574 .83424 Mdot
.60151 .77192 Mdot
.78185 .34701 Mdot
.47945 .70077 Mdot
.29208 .40962 Mdot
.58451 .52572 Mdot
.5552 .32581 Mdot
.56598 .32717 Mdot
.65004 .49791 Mdot
.61265 .52699 Mdot
.62893 .53851 Mdot
.64697 .5708 Mdot
.22623 .45371 Mdot
.62825 .51867 Mdot
.28829 .31477 Mdot
.55746 .31739 Mdot
.6066 .53562 Mdot
.35196 .61766 Mdot
.55127 .53062 Mdot
.34637 .42966 Mdot
.63857 .56895 Mdot
.60894 .52508 Mdot
.61253 .5819 Mdot
.30774 .40304 Mdot
.41901 .32988 Mdot
.68798 .76854 Mdot
.25774 .46363 Mdot
.33079 .37527 Mdot
.35064 .64406 Mdot
.66132 .51267 Mdot
.48681 .7142 Mdot
.54695 .53682 Mdot
.66129 .55843 Mdot
.60388 .77596 Mdot
.61748 .51033 Mdot
.79977 .39939 Mdot
.60425 .59586 Mdot
.46635 .21424 Mdot
.31714 .28076 Mdot
.66324 .55922 Mdot
.67892 .41125 Mdot
.57017 .73484 Mdot
.28949 .71112 Mdot
.30118 .42958 Mdot
.36177 .62047 Mdot
.33402 .60727 Mdot
.35188 .4353 Mdot
.68501 .60176 Mdot
.66752 .38167 Mdot
.57982 .55005 Mdot
.44274 .40497 Mdot
.52707 .38058 Mdot
.48626 .69481 Mdot
.57621 .33988 Mdot
.51415 .8588 Mdot
.44914 .63502 Mdot
.41316 .61077 Mdot
.49877 .74535 Mdot
.30677 .65993 Mdot
.43478 .4167 Mdot
.48853 .70357 Mdot
.6305 .55794 Mdot
.5818 .31747 Mdot
.56883 .74791 Mdot
.58127 .48768 Mdot
.37199 .1601 Mdot
.52694 .34357 Mdot
.51517 .55678 Mdot
.30733 .43425 Mdot
.37718 .63341 Mdot
.60154 .50701 Mdot
.64426 .5441 Mdot
.5197 .31363 Mdot
.58725 .51513 Mdot
.42909 .57393 Mdot
.61087 .52004 Mdot
.36869 .65903 Mdot
.50687 .65958 Mdot
.28272 .40084 Mdot
.48812 .74402 Mdot
.52816 .31572 Mdot
.2423 .39177 Mdot
.34439 .62023 Mdot
.60565 .62316 Mdot
.2982 .42086 Mdot
.51667 .72823 Mdot
.32997 .62177 Mdot
.47272 .70363 Mdot
.68373 .52417 Mdot
.32263 .622 Mdot
.50701 .69985 Mdot
.40981 .50589 Mdot
.61599 .5538 Mdot
.59662 .70289 Mdot
.28354 .44114 Mdot
.5523 .36526 Mdot
.67089 .5455 Mdot
.43707 .42477 Mdot
.64045 .58228 Mdot
.5121 .49944 Mdot
.42377 .42116 Mdot
.41666 .39809 Mdot
.42094 .61636 Mdot
.51992 .69953 Mdot
.43692 .36769 Mdot
.40873 .53964 Mdot
.58553 .31259 Mdot
.68177 .52572 Mdot
.49039 .26589 Mdot
.28164 .43834 Mdot
.63543 .55784 Mdot
.46113 .23753 Mdot
.28833 .41401 Mdot
.658 .54911 Mdot
.33797 .4322 Mdot
.56212 .32435 Mdot
.43391 .48035 Mdot
.57715 .35608 Mdot
.63089 .56362 Mdot
.32887 .44252 Mdot
.35779 .61628 Mdot
.55657 .34332 Mdot
.64518 .5199 Mdot
.63564 .50805 Mdot
.43967 .40416 Mdot
.61694 .53221 Mdot
.51197 .22677 Mdot
.59629 .51275 Mdot
.29933 .64493 Mdot
.58108 .54584 Mdot
.54734 .78023 Mdot
.51076 .75817 Mdot
.55418 .29588 Mdot
.4208 .41934 Mdot
.31586 .64524 Mdot
.42445 .48714 Mdot
.57521 .67094 Mdot
.63397 .51906 Mdot
.42365 .40452 Mdot
.51052 .54922 Mdot
.34507 .43353 Mdot
.63848 .485 Mdot
.38411 .56249 Mdot
.32044 .63921 Mdot
.44067 .41116 Mdot
.62026 .47537 Mdot
.53311 .36481 Mdot
.59969 .55919 Mdot
.33255 .61668 Mdot
.55845 .36757 Mdot
.59802 .57207 Mdot
.18484 .50135 Mdot
.43898 .42507 Mdot
.31995 .44865 Mdot
.60275 .29168 Mdot
.65492 .50372 Mdot
.34386 .60513 Mdot
.56894 .32359 Mdot
.32056 .44049 Mdot
.55989 .30645 Mdot
.55973 .75404 Mdot
.52713 .48821 Mdot
.28911 .50029 Mdot
.46477 .70233 Mdot
.85274 .49402 Mdot
.28187 .47658 Mdot
.54354 .55411 Mdot
.29028 .66791 Mdot
.4147 .18614 Mdot
.3332 .62349 Mdot
.68606 .4545 Mdot
.31848 .6554 Mdot
.59153 .54844 Mdot
.33704 .65306 Mdot
.53385 .20086 Mdot
.61546 .50535 Mdot
.34646 .66039 Mdot
.26707 .50395 Mdot
.62099 .50485 Mdot
.56286 .31606 Mdot
.66926 .22758 Mdot
.78041 .5057 Mdot
.75401 .55279 Mdot
.33222 .66737 Mdot
.72038 .48564 Mdot
.60614 .50781 Mdot
.68598 .48207 Mdot
.55293 .33107 Mdot
.61986 .58764 Mdot
.50078 .68326 Mdot
.47642 .69365 Mdot
.64612 .72262 Mdot
.80324 .5257 Mdot
.71084 .58651 Mdot
.56051 .33682 Mdot
.60632 .80817 Mdot
.44242 .3382 Mdot
.4412 .42486 Mdot
.31154 .40859 Mdot
.41274 .342 Mdot
.64913 .47285 Mdot
.59786 .40113 Mdot
.43097 .5575 Mdot
.5321 .33889 Mdot
.35757 .50684 Mdot
.32576 .43651 Mdot
.76423 .53904 Mdot
.66735 .35174 Mdot
.62781 .54128 Mdot
.30183 .45413 Mdot
.6327 .59673 Mdot
.41884 .56275 Mdot
.58494 .71311 Mdot
.21219 .57397 Mdot
.62616 .55976 Mdot
.45341 .36473 Mdot
.66141 .55692 Mdot
.57489 .71026 Mdot
.6375 .56032 Mdot
.55678 .30835 Mdot
.70153 .5185 Mdot
.40373 .53032 Mdot
.78664 .60334 Mdot
.44962 .62487 Mdot
.50268 .69113 Mdot
.64131 .53226 Mdot
.63345 .54722 Mdot
.51252 .70711 Mdot
.53403 .33663 Mdot
.67998 .52932 Mdot
.17223 .56607 Mdot
.62783 .51742 Mdot
.32195 .45669 Mdot
.46011 .51607 Mdot
.82132 .42768 Mdot
.62502 .4966 Mdot
.5274 .35902 Mdot
.34138 .42508 Mdot
.29367 .41691 Mdot
.71444 .54734 Mdot
.28634 .44678 Mdot
.58437 .52301 Mdot
.46024 .51467 Mdot
.56353 .30231 Mdot
.58858 .58655 Mdot
.53277 .33091 Mdot
.58724 .80974 Mdot
.28422 .41635 Mdot
.41915 .4064 Mdot
.75432 .53199 Mdot
.32504 .42496 Mdot
.52437 .64469 Mdot
.70114 .51991 Mdot
.58817 .48714 Mdot
.59824 .28898 Mdot
.35741 .61339 Mdot
.4221 .41285 Mdot
.31144 .44005 Mdot
.62762 .52179 Mdot
.60595 .54995 Mdot
.29664 .455 Mdot
.68837 .28519 Mdot
.32516 .707 Mdot
.63291 .56491 Mdot
.54787 .30977 Mdot
.56347 .34491 Mdot
.65274 .57174 Mdot
.66739 .55083 Mdot
.35759 .64961 Mdot
.4226 .40522 Mdot
.41977 .41535 Mdot
.43967 .39229 Mdot
.36296 .65998 Mdot
.84365 .51985 Mdot
.33581 .41321 Mdot
.79858 .35496 Mdot
.444 .27841 Mdot
.71106 .52866 Mdot
.3396 .6096 Mdot
.65491 .54111 Mdot
.59511 .54684 Mdot
.32138 .44531 Mdot
.81078 .56602 Mdot
.69814 .52807 Mdot
.54156 .36365 Mdot
.30949 .45755 Mdot
.61343 .59112 Mdot
.29705 .46908 Mdot
.4896 .72838 Mdot
.7394 .56108 Mdot
.28929 .45141 Mdot
.57094 .30667 Mdot
.2901 .45221 Mdot
.63153 .54488 Mdot
.61312 .47527 Mdot
.53124 .33914 Mdot
.5191 .73922 Mdot
.66524 .50628 Mdot
.65856 .5504 Mdot
.30455 .74794 Mdot
.44228 .34608 Mdot
.53002 .74919 Mdot
.59098 .52899 Mdot
.56567 .51151 Mdot
.50692 .74171 Mdot
.67088 .51408 Mdot
.58224 .54342 Mdot
.52803 .55537 Mdot
.26938 .41572 Mdot
.5207 .69448 Mdot
.78234 .60396 Mdot
.52822 .34717 Mdot
.50054 .23126 Mdot
.44425 .40065 Mdot
.35388 .40938 Mdot
.43452 .47094 Mdot
.43123 .41265 Mdot
.44217 .25693 Mdot
.22156 .39156 Mdot
.42342 .40989 Mdot
.3788 .64415 Mdot
.62535 .41472 Mdot
.57914 .5378 Mdot
.64791 .56369 Mdot
.51913 .69927 Mdot
.55912 .35875 Mdot
.29866 .30821 Mdot
.26886 .40659 Mdot
.65801 .52901 Mdot
.54932 .37296 Mdot
.47301 .21286 Mdot
.43791 .41198 Mdot
.48361 .71518 Mdot
.5241 .7338 Mdot
.66415 .5525 Mdot
.54555 .63285 Mdot
.56045 .3399 Mdot
.64523 .52001 Mdot
.6729 .53207 Mdot
.31165 .65018 Mdot
.58269 .32165 Mdot
.35286 .62083 Mdot
.41445 .41628 Mdot
.38315 .18395 Mdot
.25455 .71366 Mdot
.2824 .43363 Mdot
.38426 .46076 Mdot
.31366 .3981 Mdot
.19899 .53345 Mdot
.42153 .40643 Mdot
.64808 .52332 Mdot
.53624 .30506 Mdot
.64162 .51768 Mdot
.62646 .51902 Mdot
.62247 .54496 Mdot
.71107 .58659 Mdot
.58747 .8035 Mdot
.50232 .72512 Mdot
.60832 .49241 Mdot
.3423 .66914 Mdot
.46427 .22212 Mdot
.57517 .21884 Mdot
.64031 .5385 Mdot
.66585 .54225 Mdot
.52322 .31381 Mdot
.68619 .5286 Mdot
.3204 .414 Mdot
.53574 .35335 Mdot
.60559 .55529 Mdot
.51648 .78062 Mdot
.67857 .53194 Mdot
.3718 .47385 Mdot
.28363 .44969 Mdot
.60156 .46044 Mdot
.58796 .49262 Mdot
.42053 .40727 Mdot
.42286 .41283 Mdot
.4272 .42632 Mdot
.3221 .45441 Mdot
.31229 .64865 Mdot
.38171 .6133 Mdot
.60187 .48655 Mdot
.58853 .52049 Mdot
.60419 .47799 Mdot
.30636 .66916 Mdot
.39744 .54011 Mdot
.52394 .39856 Mdot
.62213 .59864 Mdot
.36052 .65853 Mdot
.60948 .33074 Mdot
.77996 .55465 Mdot
.5403 .35922 Mdot
.29107 .66524 Mdot
.30572 .41365 Mdot
.47851 .69721 Mdot
.63252 .7556 Mdot
.54537 .30482 Mdot
.5185 .32983 Mdot
.35107 .65065 Mdot
.48062 .48982 Mdot
.57063 .90725 Mdot
.33873 .62969 Mdot
.41649 .60189 Mdot
.55495 .33391 Mdot
.69076 .51887 Mdot
.50593 .53983 Mdot
.49239 .47775 Mdot
.34027 .66159 Mdot
.636 .50863 Mdot
.4822 .64668 Mdot
.35713 .65031 Mdot
.66009 .48856 Mdot
.33451 .66771 Mdot
.30958 .45163 Mdot
.34598 .63235 Mdot
.57904 .36704 Mdot
.62653 .51338 Mdot
.52434 .91061 Mdot
.45878 .45396 Mdot
.65025 .51699 Mdot
.29508 .45595 Mdot
.23323 .49296 Mdot
.62885 .55024 Mdot
.49771 .68518 Mdot
.34954 .66914 Mdot
.20136 .56106 Mdot
.58839 .55227 Mdot
.34202 .65578 Mdot
.58465 .36711 Mdot
.30033 .67542 Mdot
.50788 .77387 Mdot
.42085 .4144 Mdot
.55974 .32266 Mdot
.45299 .38868 Mdot
.33682 .41719 Mdot
.6718 .56415 Mdot
.67223 .52636 Mdot
.55225 .31459 Mdot
.41599 .49254 Mdot
.70816 .5684 Mdot
.63205 .5153 Mdot
.35891 .63934 Mdot
.3192 .67242 Mdot
.48862 .39594 Mdot
.34131 .61829 Mdot
.5646 .5138 Mdot
.5556 .31244 Mdot
.60385 .5598 Mdot
.57128 .32134 Mdot
.68114 .52308 Mdot
.37303 .39239 Mdot
.54644 .36145 Mdot
.57897 .61392 Mdot
.62274 .51476 Mdot
.55639 .25347 Mdot
.65043 .50159 Mdot
.62271 .5568 Mdot
.33153 .67584 Mdot
.50093 .71535 Mdot
.66096 .49335 Mdot
.24027 .40002 Mdot
.49682 .73735 Mdot
.73147 .30007 Mdot
.32164 .61546 Mdot
.52156 .72959 Mdot
.63655 .71017 Mdot
.42116 .41939 Mdot
.51188 .71615 Mdot
.40259 .41127 Mdot
.28569 .44109 Mdot
.59185 .33103 Mdot
.62261 .5062 Mdot
.4184 .17797 Mdot
.33474 .70624 Mdot
.43591 .40191 Mdot
.67088 .54216 Mdot
.65119 .5453 Mdot
.54326 .36957 Mdot
.50421 .8593 Mdot
.3649 .66767 Mdot
.61915 .55954 Mdot
.53377 .31112 Mdot
.44997 .85331 Mdot
.34795 .66097 Mdot
.5036 .72797 Mdot
.27593 .41927 Mdot
.51122 .36281 Mdot
.4176 .41011 Mdot
.28556 .4144 Mdot
.30744 .60343 Mdot
.6056 .77842 Mdot
.59345 .55792 Mdot
.34613 .61239 Mdot
.60166 .77257 Mdot
.59686 .59369 Mdot
.35352 .42473 Mdot
.3832 .39741 Mdot
.53679 .34421 Mdot
.29887 .45578 Mdot
.51318 .69308 Mdot
.58325 .31151 Mdot
.53237 .33413 Mdot
.31245 .41072 Mdot
.32388 .2597 Mdot
.50971 .54334 Mdot
.34367 .44919 Mdot
.50544 .50484 Mdot
.59927 .77194 Mdot
.42443 .39899 Mdot
.48236 .71287 Mdot
.50717 .79288 Mdot
.56189 .34111 Mdot
.41368 .34029 Mdot
.60366 .77313 Mdot
.61856 .55433 Mdot
.50426 .6965 Mdot
.47664 .22709 Mdot
.32666 .396 Mdot
.29639 .40922 Mdot
.33638 .57293 Mdot
.49285 .69021 Mdot
.67709 .54506 Mdot
.8275 .45162 Mdot
.62883 .50034 Mdot
.28399 .41925 Mdot
.43064 .56477 Mdot
.58134 .32005 Mdot
.34636 .42548 Mdot
.42869 .57592 Mdot
.5927 .54404 Mdot
.65939 .51918 Mdot
.474 .66753 Mdot
.58493 .32992 Mdot
.41581 .40516 Mdot
.6378 .51217 Mdot
.65193 .55214 Mdot
.66477 .56815 Mdot
.77048 .5933 Mdot
.56299 .61299 Mdot
.6129 .55708 Mdot
.37312 .62374 Mdot
.56094 .50895 Mdot
.64626 .57013 Mdot
.53851 .36989 Mdot
.54088 .79094 Mdot
.41392 .41602 Mdot
.64734 .56291 Mdot
.63404 .56487 Mdot
.31938 .40782 Mdot
.50974 .54533 Mdot
.49271 .47384 Mdot
.30286 .65268 Mdot
.34323 .57598 Mdot
.57372 .54389 Mdot
.55354 .32067 Mdot
.50464 .68298 Mdot
.55978 .54385 Mdot
.53477 .35649 Mdot
.60839 .48847 Mdot
.33554 .6711 Mdot
.42514 .40657 Mdot
.62635 .60597 Mdot
.50795 .70931 Mdot
.26488 .43376 Mdot
.7702 .32633 Mdot
.36055 .62246 Mdot
.59898 .52128 Mdot
.38122 .60807 Mdot
.32928 .63851 Mdot
.43848 .40102 Mdot
.60247 .47419 Mdot
.56316 .32792 Mdot
.57496 .31183 Mdot
.57825 .79574 Mdot
.36727 .65739 Mdot
.34098 .78 Mdot
.30399 .45174 Mdot
.61909 .49147 Mdot
.489 .30367 Mdot
.57851 .31672 Mdot
.57219 .69971 Mdot
.52088 .73286 Mdot
.29554 .40987 Mdot
.4225 .38816 Mdot
.54654 .36273 Mdot
.57858 .32264 Mdot
.62503 .52331 Mdot
.6484 .53425 Mdot
.28249 .64199 Mdot
.57295 .73652 Mdot
.33766 .43113 Mdot
.49507 .72789 Mdot
.30066 .63756 Mdot
.58811 .53659 Mdot
.54032 .35135 Mdot
.82198 .44145 Mdot
.65607 .5047 Mdot
.34069 .66908 Mdot
.54557 .35028 Mdot
.51168 .72635 Mdot
.51935 .70917 Mdot
.62046 .55511 Mdot
.80483 .42266 Mdot
.32326 .42282 Mdot
.56155 .3134 Mdot
.60376 .35053 Mdot
.59656 .50058 Mdot
.64309 .53534 Mdot
.67625 .58064 Mdot
.34838 .421 Mdot
.60917 .60051 Mdot
.48734 .73594 Mdot
.57038 .34152 Mdot
.6442 .51513 Mdot
.5113 .70994 Mdot
.59642 .40239 Mdot
.4307 .40909 Mdot
.34913 .65878 Mdot
.4946 .68577 Mdot
.49684 .70531 Mdot
.5026 .73756 Mdot
.41406 .3433 Mdot
.53873 .28601 Mdot
.75325 .69275 Mdot
.62971 .50974 Mdot
.59835 .77175 Mdot
.6897 .54111 Mdot
.33296 .44657 Mdot
.36525 .62417 Mdot
.62618 .53019 Mdot
.62956 .50945 Mdot
.79181 .37954 Mdot
.65814 .46766 Mdot
.65883 .46674 Mdot
.57744 .31034 Mdot
.57897 .26086 Mdot
.34451 .60637 Mdot
.36072 .81705 Mdot
.68124 .21884 Mdot
.57942 .5522 Mdot
.47779 .49327 Mdot
.53769 .35439 Mdot
.30477 .40567 Mdot
.50353 .51348 Mdot
.32718 .47739 Mdot
.56521 .35151 Mdot
.59054 .54536 Mdot
.76981 .3312 Mdot
.47381 .71501 Mdot
.63022 .53955 Mdot
.3045 .42248 Mdot
.62956 .53909 Mdot
.33172 .45046 Mdot
.50479 .30271 Mdot
.48258 .46679 Mdot
.61749 .50845 Mdot
.5857 .55531 Mdot
.53573 .51512 Mdot
.64334 .53747 Mdot
.22434 .55571 Mdot
.54384 .34042 Mdot
.59471 .62166 Mdot
.63473 .57836 Mdot
.78087 .4423 Mdot
.67547 .52857 Mdot
.42295 .46271 Mdot
.66542 .51983 Mdot
.75616 .6142 Mdot
.67505 .55013 Mdot
.66152 .51359 Mdot
.32702 .43918 Mdot
.31961 .40615 Mdot
.58011 .37464 Mdot
.41728 .4004 Mdot
.46564 .21618 Mdot
.66261 .54664 Mdot
.31675 .67351 Mdot
.53339 .42577 Mdot
.49711 .71067 Mdot
.56816 .34452 Mdot
.20858 .71512 Mdot
.34235 .43111 Mdot
.37664 .64789 Mdot
.41032 .62541 Mdot
.36879 .60954 Mdot
.29123 .6434 Mdot
.56409 .25263 Mdot
.48216 .71572 Mdot
.6773 .53645 Mdot
.76721 .37875 Mdot
.45229 .35584 Mdot
.59458 .50366 Mdot
.38427 .65128 Mdot
.58977 .43589 Mdot
.59117 .79314 Mdot
.47314 .69543 Mdot
.48175 .70106 Mdot
.31817 .43964 Mdot
.32608 .60757 Mdot
.63653 .5994 Mdot
.52134 .72947 Mdot
.36453 .62576 Mdot
.4479 .40128 Mdot
.44364 .70571 Mdot
.56338 .33703 Mdot
.72416 .49827 Mdot
.48737 .32402 Mdot
.34104 .43091 Mdot
.24464 .39687 Mdot
.57923 .28415 Mdot
.58204 .30187 Mdot
.4236 .39509 Mdot
.35075 .66362 Mdot
.59298 .3272 Mdot
.62602 .51526 Mdot
.58154 .48752 Mdot
.66527 .55177 Mdot
.52101 .70515 Mdot
.67326 .5369 Mdot
.36077 .64849 Mdot
.33191 .42199 Mdot
.31811 .64342 Mdot
.32946 .4248 Mdot
.7247 .27423 Mdot
.64769 .56798 Mdot
.64421 .53252 Mdot
.4622 .51006 Mdot
.57842 .32901 Mdot
.75204 .36476 Mdot
.34379 .66884 Mdot
.31927 .66001 Mdot
.60526 .55975 Mdot
.54812 .29504 Mdot
.5352 .65488 Mdot
.49301 .51692 Mdot
.66866 .52412 Mdot
.54314 .33958 Mdot
.60723 .56232 Mdot
.20136 .51306 Mdot
.47987 .4477 Mdot
.56254 .30718 Mdot
.78756 .60321 Mdot
.61974 .52814 Mdot
.59258 .47231 Mdot
.57808 .46695 Mdot
.73429 .61507 Mdot
.6871 .50901 Mdot
.52783 .34385 Mdot
.63642 .57035 Mdot
.54934 .3246 Mdot
.32998 .63177 Mdot
.33803 .41341 Mdot
.55104 .32704 Mdot
.62803 .50277 Mdot
.69002 .22804 Mdot
.33129 .41913 Mdot
.63198 .53096 Mdot
.30563 .44225 Mdot
.58817 .34027 Mdot
.57751 .34402 Mdot
.40853 .39484 Mdot
.41486 .60623 Mdot
.3218 .41588 Mdot
.58862 .51927 Mdot
.42831 .33588 Mdot
.60261 .55931 Mdot
.34727 .57594 Mdot
.60864 .57887 Mdot
.57706 .52411 Mdot
.85615 .48482 Mdot
.42129 .48325 Mdot
.28778 .76779 Mdot
.27205 .39619 Mdot
.42319 .32908 Mdot
.58253 .38026 Mdot
.47352 .69505 Mdot
.38635 .47459 Mdot
.43121 .4224 Mdot
.37056 .61655 Mdot
.62642 .52548 Mdot
.5698 .23514 Mdot
.33407 .45427 Mdot
.49913 .71875 Mdot
.61721 .51017 Mdot
.33826 .59874 Mdot
.45849 .42921 Mdot
.29225 .41017 Mdot
.56495 .3382 Mdot
.5759 .3425 Mdot
.63326 .79601 Mdot
.64798 .51711 Mdot
.65005 .53011 Mdot
.32819 .41473 Mdot
.67031 .59298 Mdot
.49901 .73543 Mdot
.28087 .51075 Mdot
.30159 .42419 Mdot
.47588 .45164 Mdot
.57992 .31111 Mdot
.65281 .54352 Mdot
.4606 .51754 Mdot
.3755 .32293 Mdot
.63109 .32492 Mdot
.49466 .69518 Mdot
.55723 .64965 Mdot
.52755 .34358 Mdot
.30371 .42682 Mdot
.63931 .71904 Mdot
.69379 .54049 Mdot
.65076 .54741 Mdot
.59268 .65508 Mdot
.49501 .51505 Mdot
.41621 .59481 Mdot
.67839 .57541 Mdot
.50967 .57088 Mdot
.60412 .55876 Mdot
.60541 .54989 Mdot
.5793 .51553 Mdot
.61205 .57571 Mdot
.54225 .3352 Mdot
.78091 .49457 Mdot
.34251 .64541 Mdot
.6445 .39255 Mdot
.30254 .59362 Mdot
.60897 .50498 Mdot
.59199 .54572 Mdot
.7262 .44287 Mdot
.51917 .47847 Mdot
.54989 .34095 Mdot
.60499 .34199 Mdot
.33436 .41311 Mdot
.67076 .47227 Mdot
.36173 .66255 Mdot
.59499 .45303 Mdot
.3279 .64836 Mdot
.5414 .33863 Mdot
.31242 .63512 Mdot
.2882 .45908 Mdot
.3456 .61251 Mdot
.36966 .64939 Mdot
.28447 .41227 Mdot
.5802 .34474 Mdot
.6624 .512 Mdot
.27899 .41963 Mdot
.53142 .65245 Mdot
.52089 .70541 Mdot
.4063 .39596 Mdot
.69253 .52123 Mdot
.6295 .46348 Mdot
.18284 .50516 Mdot
.31965 .6239 Mdot
.50327 .46756 Mdot
.54788 .36158 Mdot
.51024 .6865 Mdot
.54316 .3313 Mdot
.69063 .74472 Mdot
.50357 .70298 Mdot
.40421 .39881 Mdot
.61969 .72335 Mdot
.2468 .44102 Mdot
.61017 .58413 Mdot
.60058 .29145 Mdot
.32549 .64614 Mdot
.31898 .45717 Mdot
.47181 .22627 Mdot
.61559 .5385 Mdot
.45289 .4109 Mdot
.58678 .30236 Mdot
.42127 .4186 Mdot
.30634 .42389 Mdot
.38989 .42928 Mdot
.65375 .51985 Mdot
.24742 .43667 Mdot
.59023 .56451 Mdot
.74549 .51784 Mdot
.31198 .59209 Mdot
.597 .39197 Mdot
.59372 .55435 Mdot
.35056 .66087 Mdot
.59733 .55689 Mdot
.65835 .43307 Mdot
.60456 .74541 Mdot
.57441 .5528 Mdot
.5482 .45685 Mdot
.1871 .54315 Mdot
.53874 .34824 Mdot
.56596 .51475 Mdot
.43051 .39863 Mdot
.59661 .53343 Mdot
.4817 .1386 Mdot
.51013 .71493 Mdot
.53104 .74411 Mdot
.62788 .50424 Mdot
.63831 .51504 Mdot
.79616 .40197 Mdot
.55878 .26547 Mdot
.42075 .38898 Mdot
.64356 .5516 Mdot
.62917 .65458 Mdot
.32145 .44154 Mdot
.60119 .57428 Mdot
.64676 .56576 Mdot
.30453 .73529 Mdot
.31588 .44382 Mdot
.32782 .61376 Mdot
.42258 .42028 Mdot
.30923 .66072 Mdot
.53256 .70971 Mdot
.52605 .59053 Mdot
.57785 .69313 Mdot
.48206 .43699 Mdot
.50004 .6875 Mdot
.61025 .50172 Mdot
.58755 .39396 Mdot
.64784 .5109 Mdot
.48335 .70233 Mdot
.29825 .43303 Mdot
.5456 .33549 Mdot
.71847 .49024 Mdot
.44199 .40241 Mdot
.61059 .49471 Mdot
.47169 .69295 Mdot
.55633 .32698 Mdot
.3163 .32827 Mdot
.55416 .35915 Mdot
.32802 .42887 Mdot
.35117 .43627 Mdot
.50127 .70824 Mdot
.54172 .33288 Mdot
.30885 .65721 Mdot
.28421 .38914 Mdot
.59287 .57337 Mdot
.29036 .4607 Mdot
.59621 .33071 Mdot
.53166 .35907 Mdot
.54642 .29895 Mdot
.62241 .5748 Mdot
.49013 .50342 Mdot
.689 .5536 Mdot
.33072 .41762 Mdot
.35458 .60215 Mdot
.57806 .74362 Mdot
.78379 .40152 Mdot
.47248 .45978 Mdot
.66685 .49556 Mdot
.67244 .53867 Mdot
.6646 .55166 Mdot
.61911 .56733 Mdot
.28552 .51035 Mdot
.64728 .56801 Mdot
.33154 .44025 Mdot
.33304 .64319 Mdot
.66813 .53142 Mdot
.42682 .40091 Mdot
.40101 .54178 Mdot
.50909 .68367 Mdot
.74745 .55099 Mdot
.5301 .24021 Mdot
.5547 .32843 Mdot
.33909 .61574 Mdot
.31042 .63979 Mdot
.5202 .72477 Mdot
.28053 .42057 Mdot
.56211 .35663 Mdot
.74541 .62214 Mdot
.48451 .73059 Mdot
.64722 .56258 Mdot
.46096 .51307 Mdot
.78409 .57662 Mdot
.62941 .4908 Mdot
.62303 .55078 Mdot
.41444 .40654 Mdot
.37733 .64236 Mdot
.4794 .16861 Mdot
.3162 .2736 Mdot
.50147 .71368 Mdot
.50254 .73163 Mdot
.5308 .30637 Mdot
.61869 .49099 Mdot
.32129 .42094 Mdot
.5133 .56366 Mdot
.18918 .48785 Mdot
.49685 .21732 Mdot
.19988 .53644 Mdot
.67859 .5306 Mdot
.76655 .46446 Mdot
.61102 .58112 Mdot
.53415 .28956 Mdot
.54336 .2979 Mdot
.55605 .33898 Mdot
.3266 .43746 Mdot
.60762 .77999 Mdot
.33148 .44167 Mdot
.54109 .23301 Mdot
.5268 .32825 Mdot
.41643 .51241 Mdot
.32272 .66419 Mdot
.68052 .48098 Mdot
.48115 .71296 Mdot
.55014 .67568 Mdot
.5726 .50403 Mdot
.54865 .63521 Mdot
.33916 .60971 Mdot
.56827 .36084 Mdot
.69809 .51588 Mdot
.4577 .21795 Mdot
.47893 .48752 Mdot
.18549 .57857 Mdot
.59586 .26604 Mdot
.5113 .70601 Mdot
.66354 .39094 Mdot
.48844 .73148 Mdot
.29364 .41068 Mdot
.61953 .53366 Mdot
.64576 .49799 Mdot
.62518 .56071 Mdot
.61619 .57391 Mdot
.30977 .44015 Mdot
.5918 .57488 Mdot
.54822 .78042 Mdot
.44683 .40951 Mdot
.38614 .52578 Mdot
.51802 .71197 Mdot
.313 .45293 Mdot
.33084 .63987 Mdot
.42327 .39405 Mdot
.46343 .70653 Mdot
.65817 .57056 Mdot
.63586 .50405 Mdot
.44685 .40186 Mdot
.67597 .5988 Mdot
.65216 .47302 Mdot
.34237 .65091 Mdot
.41569 .55304 Mdot
.5253 .71056 Mdot
.47728 .70311 Mdot
.29769 .45414 Mdot
.54288 .33125 Mdot
.52389 .72204 Mdot
.3276 .60585 Mdot
.59642 .56875 Mdot
.58359 .55157 Mdot
.59684 .33435 Mdot
.60339 .77469 Mdot
.50582 .68196 Mdot
.60019 .59553 Mdot
.57372 .33092 Mdot
.58536 .29978 Mdot
.64191 .5513 Mdot
.59016 .58209 Mdot
.51737 .32457 Mdot
.51372 .7287 Mdot
.29921 .45256 Mdot
.43223 .50279 Mdot
.33274 .44359 Mdot
.56927 .32652 Mdot
.56585 .5031 Mdot
.58593 .32853 Mdot
.61517 .53495 Mdot
.33788 .83299 Mdot
.66443 .55915 Mdot
.67168 .62512 Mdot
.44467 .6563 Mdot
.337 .66755 Mdot
.34279 .66583 Mdot
.42516 .40495 Mdot
.53479 .35529 Mdot
.55567 .5366 Mdot
.48521 .72185 Mdot
.42405 .32963 Mdot
.56957 .27353 Mdot
.36585 .65374 Mdot
.37323 .6532 Mdot
.29978 .43455 Mdot
.67549 .5315 Mdot
.65712 .54036 Mdot
.34278 .61163 Mdot
.24606 .49832 Mdot
.5439 .32394 Mdot
.64975 .52988 Mdot
.63058 .5751 Mdot
.34008 .64417 Mdot
.3599 .40439 Mdot
.58953 .30072 Mdot
.62543 .57601 Mdot
.59585 .73744 Mdot
.33949 .44502 Mdot
.59872 .5139 Mdot
.61405 .58109 Mdot
.49358 .70769 Mdot
.57311 .67057 Mdot
.60002 .76988 Mdot
.31254 .40241 Mdot
.41842 .41263 Mdot
.65691 .50122 Mdot
.33338 .66608 Mdot
.69436 .52117 Mdot
.22212 .34697 Mdot
.44521 .41596 Mdot
.65566 .52358 Mdot
.57232 .53893 Mdot
.56997 .31825 Mdot
.64777 .5212 Mdot
.37544 .39524 Mdot
.3568 .6334 Mdot
.65644 .52344 Mdot
.80415 .4259 Mdot
.29936 .43243 Mdot
.5764 .49977 Mdot
.48505 .69159 Mdot
.41995 .58871 Mdot
.67603 .23471 Mdot
.30199 .66258 Mdot
.51696 .70404 Mdot
.67309 .53511 Mdot
.30547 .65819 Mdot
.27681 .41676 Mdot
.58462 .62618 Mdot
.60709 .50233 Mdot
.33532 .44089 Mdot
.33006 .42019 Mdot
.50415 .7115 Mdot
.27278 .77022 Mdot
.57363 .54145 Mdot
.6346 .53784 Mdot
.16891 .49613 Mdot
.51462 .33644 Mdot
.6302 .53283 Mdot
.6736 .52768 Mdot
.28388 .44184 Mdot
.68573 .72908 Mdot
.55578 .64702 Mdot
.26688 .50338 Mdot
.33515 .44812 Mdot
.36915 .66734 Mdot
.35872 .6272 Mdot
.51593 .70435 Mdot
.54673 .35187 Mdot
.51923 .69588 Mdot
.34734 .63703 Mdot
.62396 .55745 Mdot
.28767 .42835 Mdot
.65655 .2813 Mdot
.28904 .45502 Mdot
.3231 .60614 Mdot
.55549 .2843 Mdot
.56812 .22527 Mdot
.1942 .37827 Mdot
.48789 .33352 Mdot
.34007 .4097 Mdot
.49687 .71064 Mdot
.30218 .29477 Mdot
.66897 .52947 Mdot
.73284 .49101 Mdot
.63168 .53867 Mdot
.61642 .34926 Mdot
.36529 .62527 Mdot
.44096 .39112 Mdot
.61547 .53898 Mdot
.55802 .64948 Mdot
.28932 .40993 Mdot
.31099 .41458 Mdot
.62992 .56876 Mdot
.32756 .42682 Mdot
.65777 .53549 Mdot
.33597 .64031 Mdot
.28461 .77393 Mdot
.65879 .5138 Mdot
.55711 .5114 Mdot
.28011 .4022 Mdot
.40622 .39543 Mdot
.38501 .63865 Mdot
.77889 .47198 Mdot
.45752 .20959 Mdot
.32174 .42427 Mdot
.71785 .58204 Mdot
.32458 .62121 Mdot
.41666 .39798 Mdot
.34183 .67837 Mdot
.63734 .5448 Mdot
.67822 .52621 Mdot
.61538 .56146 Mdot
.67145 .53582 Mdot
.71232 .45755 Mdot
.65592 .47252 Mdot
.69054 .36223 Mdot
.63044 .50967 Mdot
.67886 .62059 Mdot
.32433 .44506 Mdot
.58836 .47205 Mdot
.42673 .60403 Mdot
.68063 .53608 Mdot
.58879 .27355 Mdot
.31079 .45253 Mdot
.48377 .28952 Mdot
.31278 .44205 Mdot
.31773 .64755 Mdot
.30718 .40792 Mdot
.6183 .52967 Mdot
.56213 .34511 Mdot
.34532 .6229 Mdot
.52128 .39764 Mdot
.36278 .60946 Mdot
.65035 .51714 Mdot
.26639 .46684 Mdot
.32008 .66593 Mdot
.63469 .45957 Mdot
.56093 .34783 Mdot
.65605 .65995 Mdot
.51766 .30883 Mdot
.64212 .52175 Mdot
.63648 .52285 Mdot
.43733 .38952 Mdot
.29265 .40942 Mdot
.57192 .30273 Mdot
.32443 .75269 Mdot
.47556 .68538 Mdot
.54774 .34573 Mdot
.57353 .47321 Mdot
.47465 .49503 Mdot
.56653 .31159 Mdot
.68553 .64496 Mdot
.28494 .41754 Mdot
.5246 .32426 Mdot
.64035 .58365 Mdot
.64605 .40175 Mdot
.47592 .71419 Mdot
.3148 .66753 Mdot
.49998 .5503 Mdot
.35858 .62924 Mdot
.27132 .44766 Mdot
.36455 .66293 Mdot
.3222 .44365 Mdot
.54536 .43231 Mdot
.42998 .56931 Mdot
.30678 .46002 Mdot
.26259 .41315 Mdot
.34856 .64733 Mdot
.62466 .56736 Mdot
.40378 .5322 Mdot
.55476 .54391 Mdot
.59452 .48136 Mdot
.33998 .43848 Mdot
.52488 .3378 Mdot
.58621 .31901 Mdot
.59723 .61878 Mdot
.58019 .33036 Mdot
.33813 .62575 Mdot
.48918 .42135 Mdot
.7549 .52997 Mdot
.29582 .43027 Mdot
.41167 .61249 Mdot
.59474 .55314 Mdot
.34834 .65655 Mdot
.33357 .62606 Mdot
.33122 .42392 Mdot
.63783 .38247 Mdot
.59525 .48324 Mdot
.53015 .36476 Mdot
.53154 .31435 Mdot
.56419 .31022 Mdot
.5422 .29686 Mdot
.61463 .78149 Mdot
.31824 .4573 Mdot
.53141 .34913 Mdot
.61179 .56981 Mdot
.66042 .50587 Mdot
.42936 .41837 Mdot
.51431 .72622 Mdot
.68509 .55357 Mdot
.5553 .53921 Mdot
.64323 .55028 Mdot
.33458 .66785 Mdot
.55123 .47123 Mdot
.44487 .41361 Mdot
.37007 .65509 Mdot
.36244 .66129 Mdot
.41996 .40838 Mdot
.55196 .43378 Mdot
.50646 .1802 Mdot
.62016 .56004 Mdot
.55403 .24723 Mdot
.33807 .66412 Mdot
.52725 .62114 Mdot
.66459 .61758 Mdot
.58554 .5211 Mdot
.36916 .53788 Mdot
.33592 .63416 Mdot
.56843 .38501 Mdot
.63993 .54096 Mdot
.42745 .39493 Mdot
.47651 .70144 Mdot
.54754 .49934 Mdot
.41427 .40491 Mdot
.53823 .33623 Mdot
.27492 .69173 Mdot
.54727 .37196 Mdot
.31546 .66367 Mdot
.56737 .51152 Mdot
.55093 .91109 Mdot
.32427 .64467 Mdot
.41113 .33118 Mdot
.42906 .57241 Mdot
.65768 .51531 Mdot
.35031 .61989 Mdot
.59901 .33554 Mdot
.34011 .44405 Mdot
.47317 .51353 Mdot
.54097 .35162 Mdot
.42507 .39334 Mdot
.42571 .41543 Mdot
.3417 .64581 Mdot
.54234 .30727 Mdot
.5978 .57674 Mdot
.57317 .34542 Mdot
.29324 .42045 Mdot
.60853 .52616 Mdot
.46546 .2157 Mdot
.59905 .47529 Mdot
.57259 .3436 Mdot
.34112 .60003 Mdot
.51427 .7409 Mdot
.61832 .50338 Mdot
.48714 .26099 Mdot
.6747 .53148 Mdot
.30284 .44016 Mdot
.48301 .61151 Mdot
.66028 .28848 Mdot
.63742 .56135 Mdot
.59391 .55039 Mdot
.27726 .44409 Mdot
.63541 .56012 Mdot
.58011 .52059 Mdot
.39292 .42746 Mdot
.56882 .31402 Mdot
.6662 .53599 Mdot
.36259 .62994 Mdot
.68636 .27133 Mdot
.62075 .53494 Mdot
.35844 .38485 Mdot
.63447 .65782 Mdot
.46303 .58499 Mdot
.55336 .52931 Mdot
.57107 .69789 Mdot
.63649 .52709 Mdot
.58712 .51501 Mdot
.62277 .56377 Mdot
.76334 .46627 Mdot
.34914 .64167 Mdot
.36309 .65234 Mdot
.47774 .69465 Mdot
.61354 .65458 Mdot
.50099 .69621 Mdot
.27834 .44352 Mdot
.41167 .61698 Mdot
.44562 .40223 Mdot
.5445 .32909 Mdot
.6212 .53763 Mdot
.36432 .61266 Mdot
.64933 .54411 Mdot
.59599 .53131 Mdot
.3418 .62951 Mdot
.33268 .62983 Mdot
.30273 .66627 Mdot
.47553 .72003 Mdot
.55161 .33593 Mdot
.61839 .54949 Mdot
.49624 .73731 Mdot
.6416 .57569 Mdot
.45004 .47899 Mdot
.55186 .33803 Mdot
.57436 .34157 Mdot
.58792 .33437 Mdot
.63993 .50097 Mdot
.61572 .52791 Mdot
.33182 .44161 Mdot
.59661 .33485 Mdot
.31564 .41274 Mdot
.35187 .62081 Mdot
.35277 .65344 Mdot
.63656 .54494 Mdot
.62592 .60058 Mdot
.5163 .71838 Mdot
.3149 .63657 Mdot
.43039 .42452 Mdot
.48125 .69234 Mdot
.66994 .54722 Mdot
.35589 .62468 Mdot
.49959 .68314 Mdot
.61888 .28844 Mdot
.43871 .1991 Mdot
.47306 .71847 Mdot
.62983 .56908 Mdot
.78562 .39338 Mdot
.59717 .74693 Mdot
.47188 .68605 Mdot
.30555 .44514 Mdot
.66789 .51601 Mdot
.22592 .45783 Mdot
.52615 .72558 Mdot
.60382 .76862 Mdot
.34604 .62941 Mdot
.54407 .54793 Mdot
.5584 .47398 Mdot
.7542 .52348 Mdot
.52391 .73601 Mdot
.57068 .34406 Mdot
.53889 .30444 Mdot
.64358 .56308 Mdot
.41559 .60041 Mdot
.28804 .45651 Mdot
.31038 .63919 Mdot
.3714 .63961 Mdot
.56034 .30434 Mdot
.48014 .4402 Mdot
.36138 .62824 Mdot
.60986 .49166 Mdot
.51898 .68173 Mdot
.67591 .47481 Mdot
.63496 .7898 Mdot
.66198 .23541 Mdot
.55395 .52577 Mdot
.50854 .74182 Mdot
.28602 .40991 Mdot
.33209 .43207 Mdot
.32679 .4344 Mdot
.35471 .65004 Mdot
.5019 .51942 Mdot
.36917 .63113 Mdot
.32552 .36467 Mdot
.51244 .71174 Mdot
.68232 .66712 Mdot
.6429 .58012 Mdot
.65626 .51477 Mdot
.59161 .5584 Mdot
.61343 .5605 Mdot
.63804 .52782 Mdot
.34045 .43062 Mdot
.30555 .64895 Mdot
.19217 .50775 Mdot
.54725 .31072 Mdot
.31058 .32707 Mdot
.32097 .66311 Mdot
.41383 .41257 Mdot
.49795 .72304 Mdot
.58895 .67719 Mdot
.51643 .67613 Mdot
.31219 .64338 Mdot
.62719 .48932 Mdot
.5237 .3162 Mdot
.77022 .60422 Mdot
.63206 .51508 Mdot
.31611 .63117 Mdot
.3599 .67528 Mdot
.64226 .37476 Mdot
.69881 .55646 Mdot
.41038 .59777 Mdot
.47933 .49525 Mdot
.47685 .72728 Mdot
.66533 .49673 Mdot
.53641 .61678 Mdot
.34629 .63897 Mdot
.32678 .656 Mdot
.46896 .68992 Mdot
.60441 .42245 Mdot
.52949 .33502 Mdot
.44428 .39244 Mdot
.303 .44729 Mdot
.64446 .50673 Mdot
.35612 .64474 Mdot
.55546 .39172 Mdot
.44663 .50189 Mdot
.30985 .43619 Mdot
.37139 .65484 Mdot
.67481 .52638 Mdot
.64321 .56101 Mdot
.50695 .70261 Mdot
.34198 .7174 Mdot
.55468 .54352 Mdot
.42254 .33014 Mdot
.49342 .46231 Mdot
.42677 .58114 Mdot
.65144 .54703 Mdot
.58255 .3198 Mdot
.42121 .40643 Mdot
.48299 .71254 Mdot
.66233 .56578 Mdot
.48305 .18193 Mdot
.55698 .37343 Mdot
.32151 .41663 Mdot
.42031 .40275 Mdot
.51508 .5534 Mdot
.67417 .5316 Mdot
.63201 .53899 Mdot
.62184 .57463 Mdot
.48526 .17761 Mdot
.36708 .63665 Mdot
.56445 .29909 Mdot
.50079 .69318 Mdot
.57273 .34951 Mdot
.34733 .67101 Mdot
.41763 .58085 Mdot
.64825 .56855 Mdot
.5573 .36947 Mdot
.56513 .35319 Mdot
.29837 .43137 Mdot
.27843 .42045 Mdot
.29935 .65175 Mdot
.6715 .53263 Mdot
.44365 .39602 Mdot
.52773 .34005 Mdot
.30938 .63429 Mdot
.50646 .70316 Mdot
.32346 .46701 Mdot
.63099 .50864 Mdot
.34422 .64451 Mdot
.55816 .53037 Mdot
.55888 .31652 Mdot
.31387 .65194 Mdot
.41206 .40313 Mdot
.51176 .72865 Mdot
.6739 .51566 Mdot
.19299 .55589 Mdot
.42282 .39704 Mdot
.62871 .50093 Mdot
.65357 .23598 Mdot
.41624 .59786 Mdot
.52039 .39011 Mdot
.35851 .61639 Mdot
.43984 .39582 Mdot
.55434 .29683 Mdot
.66281 .40918 Mdot
.33015 .65443 Mdot
.77814 .35312 Mdot
.42151 .51673 Mdot
.61798 .55667 Mdot
.53781 .34338 Mdot
.4832 .66577 Mdot
.42952 .31753 Mdot
.58758 .74401 Mdot
.65623 .52987 Mdot
.35895 .63029 Mdot
.4775 .70046 Mdot
.31029 .41365 Mdot
.35183 .38486 Mdot
.67353 .7728 Mdot
.37226 .6487 Mdot
.62066 .5417 Mdot
.52458 .33459 Mdot
.32504 .42026 Mdot
.7751 .33654 Mdot
.32382 .60826 Mdot
.35732 .61832 Mdot
.58657 .54965 Mdot
.49635 .69372 Mdot
.22945 .45875 Mdot
.36481 .64671 Mdot
.30648 .65725 Mdot
.40907 .43176 Mdot
.47401 .69838 Mdot
.6191 .57197 Mdot
.59799 .6192 Mdot
.60774 .57623 Mdot
.35481 .34239 Mdot
.44078 .39554 Mdot
.54537 .31241 Mdot
.62737 .53027 Mdot
.18589 .5395 Mdot
.32965 .64781 Mdot
.48169 .49337 Mdot
.36079 .41046 Mdot
.27915 .41993 Mdot
.35572 .63411 Mdot
.64772 .53996 Mdot
.34892 .4483 Mdot
.51606 .71048 Mdot
.62651 .5759 Mdot
.6152 .53208 Mdot
.59803 .3256 Mdot
.28905 .42704 Mdot
.68367 .26605 Mdot
.30026 .4132 Mdot
.29389 .4537 Mdot
.5872 .3012 Mdot
.64528 .56275 Mdot
.31496 .64597 Mdot
.3331 .59878 Mdot
.56976 .55519 Mdot
.52564 .62054 Mdot
.53163 .33822 Mdot
.30501 .60865 Mdot
.46437 .17722 Mdot
.57927 .54975 Mdot
.42318 .42228 Mdot
.61378 .34897 Mdot
.34199 .44689 Mdot
.62718 .5571 Mdot
.54999 .32295 Mdot
.30269 .63857 Mdot
.36112 .63812 Mdot
.69488 .53807 Mdot
.33269 .42434 Mdot
.50495 .6851 Mdot
.33217 .62472 Mdot
.43691 .48866 Mdot
.65333 .52146 Mdot
.4556 .40733 Mdot
.33005 .62441 Mdot
.70306 .2426 Mdot
.18475 .52596 Mdot
.55921 .30629 Mdot
.59008 .52688 Mdot
.51976 .32996 Mdot
.50707 .69373 Mdot
.35393 .67303 Mdot
.33538 .43488 Mdot
.70919 .48441 Mdot
.28161 .72532 Mdot
.35122 .65021 Mdot
.54251 .33647 Mdot
.62189 .54392 Mdot
.6927 .59956 Mdot
.66649 .52111 Mdot
.69108 .72155 Mdot
.49745 .67897 Mdot
.25903 .43346 Mdot
.33 .41638 Mdot
.59252 .54421 Mdot
.49851 .73608 Mdot
.31167 .61211 Mdot
.34258 .63059 Mdot
.32852 .80249 Mdot
.41382 .4039 Mdot
.28923 .66313 Mdot
.63914 .50143 Mdot
.31443 .62452 Mdot
.78376 .40346 Mdot
.32345 .41322 Mdot
.59797 .57393 Mdot
.37545 .62061 Mdot
.35759 .32154 Mdot
.47512 .49706 Mdot
.65534 .52496 Mdot
.66072 .59641 Mdot
.30976 .44374 Mdot
.30318 .29351 Mdot
.35819 .61436 Mdot
.64026 .5749 Mdot
.3612 .42996 Mdot
.5253 .42118 Mdot
.32933 .75043 Mdot
.55204 .33601 Mdot
.36997 .60629 Mdot
.29602 .45062 Mdot
.54538 .53942 Mdot
.51778 .72012 Mdot
.30564 .62471 Mdot
.36853 .61151 Mdot
.60357 .5257 Mdot
.68709 .5471 Mdot
.67158 .58881 Mdot
.53526 .33798 Mdot
.28451 .4409 Mdot
.59925 .54405 Mdot
.46086 .47252 Mdot
.61129 .55713 Mdot
.28898 .44709 Mdot
.45585 .90876 Mdot
.64815 .49544 Mdot
.63523 .50771 Mdot
.74172 .56173 Mdot
.57487 .30491 Mdot
.57405 .32036 Mdot
.47917 .46356 Mdot
.64602 .5007 Mdot
.41739 .50175 Mdot
.55025 .33397 Mdot
.54159 .34781 Mdot
.41693 .50471 Mdot
.60939 .52107 Mdot
.36433 .45285 Mdot
.3261 .42164 Mdot
.27864 .42083 Mdot
.57066 .31947 Mdot
.69104 .4878 Mdot
.27904 .41417 Mdot
.71177 .45054 Mdot
.31269 .65193 Mdot
.53688 .61661 Mdot
.5722 .34745 Mdot
.45964 .52272 Mdot
.28995 .41257 Mdot
.7804 .31507 Mdot
.76598 .59429 Mdot
.58013 .5615 Mdot
.63897 .56291 Mdot
.49508 .70441 Mdot
.71458 .55039 Mdot
.41928 .41417 Mdot
.32948 .43007 Mdot
.29385 .51372 Mdot
.55646 .3394 Mdot
.65578 .50678 Mdot
.57537 .74049 Mdot
.68087 .242 Mdot
.58881 .62197 Mdot
.54648 .35268 Mdot
.55861 .34322 Mdot
.34333 .60856 Mdot
.31114 .64865 Mdot
.64248 .56911 Mdot
.32857 .43899 Mdot
.52904 .31527 Mdot
.28552 .43482 Mdot
.34641 .63711 Mdot
.31614 .65541 Mdot
.44033 .41986 Mdot
.6097 .47937 Mdot
.35272 .63418 Mdot
.31005 .37847 Mdot
.45918 .473 Mdot
.59562 .3206 Mdot
.20093 .42789 Mdot
.80086 .35975 Mdot
.72752 .5187 Mdot
.47623 .70248 Mdot
.54052 .43201 Mdot
.31649 .40454 Mdot
.59364 .54696 Mdot
.62995 .54692 Mdot
.43736 .41231 Mdot
.30813 .40357 Mdot
.49363 .71668 Mdot
.29506 .40817 Mdot
.48774 .72134 Mdot
.35906 .65635 Mdot
.62237 .52712 Mdot
.67317 .5483 Mdot
.31252 .41601 Mdot
.32937 .61361 Mdot
.32116 .66671 Mdot
.48192 .72342 Mdot
.59142 .66563 Mdot
.34183 .64391 Mdot
.57203 .34805 Mdot
.70962 .30197 Mdot
.42776 .41592 Mdot
.64037 .54025 Mdot
.57507 .70567 Mdot
.68049 .40956 Mdot
.61435 .5545 Mdot
.42067 .40089 Mdot
.28147 .78246 Mdot
.62095 .5305 Mdot
.45851 .85617 Mdot
.44456 .4091 Mdot
.58583 .32643 Mdot
.32697 .62112 Mdot
.41582 .40237 Mdot
.54605 .47944 Mdot
.30492 .60132 Mdot
.56326 .52962 Mdot
.52961 .33812 Mdot
.57235 .35944 Mdot
.41822 .56354 Mdot
.35218 .34197 Mdot
.49831 .69194 Mdot
.5047 .71991 Mdot
.33317 .65379 Mdot
.26941 .38776 Mdot
.69955 .52127 Mdot
.502 .71837 Mdot
.2879 .49057 Mdot
.59316 .5521 Mdot
.41785 .59105 Mdot
.39622 .52718 Mdot
.57543 .31079 Mdot
.58876 .46993 Mdot
.33076 .65115 Mdot
.54322 .33685 Mdot
.41063 .54177 Mdot
.59581 .56936 Mdot
.55344 .33885 Mdot
.28051 .43192 Mdot
.40136 .48067 Mdot
.57801 .33937 Mdot
.46852 .51191 Mdot
.3184 .42111 Mdot
.41536 .5966 Mdot
.66598 .6937 Mdot
.55297 .13852 Mdot
.33034 .43407 Mdot
.3219 .62211 Mdot
.35423 .64573 Mdot
.33822 .64327 Mdot
.53775 .34897 Mdot
.32866 .63443 Mdot
.53589 .31949 Mdot
.27231 .40707 Mdot
.58288 .67221 Mdot
.50261 .70606 Mdot
.45278 .74259 Mdot
.56921 .33662 Mdot
.34166 .35934 Mdot
.17148 .45773 Mdot
.61958 .57014 Mdot
.30643 .45949 Mdot
.49351 .73782 Mdot
.50401 .45161 Mdot
.49333 .70644 Mdot
.32615 .61999 Mdot
.53832 .6158 Mdot
.65879 .53551 Mdot
.56143 .23919 Mdot
.47913 .69835 Mdot
.5438 .35253 Mdot
.60906 .504 Mdot
.34424 .59071 Mdot
.51433 .69995 Mdot
.47663 .7108 Mdot
.63846 .53002 Mdot
.57345 .35569 Mdot
.31369 .64565 Mdot
.32432 .4064 Mdot
.47999 .67234 Mdot
.66882 .5954 Mdot
.62905 .56557 Mdot
.63749 .49066 Mdot
.48667 .48387 Mdot
.21449 .43611 Mdot
.31872 .42432 Mdot
.59538 .76444 Mdot
.3505 .65583 Mdot
.58949 .74708 Mdot
.44319 .33514 Mdot
.53421 .69184 Mdot
.44238 .39756 Mdot
.44072 .39491 Mdot
.64899 .52511 Mdot
.20759 .37582 Mdot
.63275 .63697 Mdot
.35204 .41156 Mdot
.42992 .41355 Mdot
.31805 .66514 Mdot
.58434 .36421 Mdot
.60023 .44614 Mdot
.65934 .57494 Mdot
.3097 .40252 Mdot
.34219 .63663 Mdot
.22307 .34382 Mdot
.51137 .7113 Mdot
.49934 .45208 Mdot
.6703 .53586 Mdot
.64733 .5313 Mdot
.30843 .42926 Mdot
.33277 .43864 Mdot
.43241 .43301 Mdot
.46245 .5678 Mdot
.47559 .21409 Mdot
.26772 .4282 Mdot
.22225 .34382 Mdot
.57584 .2415 Mdot
.56741 .32147 Mdot
.42186 .42075 Mdot
.27598 .43405 Mdot
.6291 .53161 Mdot
.58542 .32196 Mdot
.60043 .6327 Mdot
.56421 .38763 Mdot
.4192 .5911 Mdot
.43297 .50049 Mdot
.67167 .53951 Mdot
.52821 .3054 Mdot
.54561 .33836 Mdot
.52669 .30357 Mdot
.42166 .40971 Mdot
.64799 .54987 Mdot
.62158 .56776 Mdot
.62 .53208 Mdot
.70364 .58841 Mdot
.64792 .5208 Mdot
.44148 .33089 Mdot
.46274 .46219 Mdot
.38698 .73891 Mdot
.62716 .51362 Mdot
.2846 .44594 Mdot
.62375 .52588 Mdot
.5073 .73628 Mdot
.66709 .50754 Mdot
.4198 .5927 Mdot
.32226 .43199 Mdot
.61906 .41419 Mdot
.37014 .58577 Mdot
.66553 .55624 Mdot
.49991 .6869 Mdot
.21015 .42164 Mdot
.57961 .75699 Mdot
.40185 .42874 Mdot
.57283 .34578 Mdot
.31035 .66739 Mdot
.32758 .45839 Mdot
.31741 .65125 Mdot
.59284 .57251 Mdot
.43752 .4232 Mdot
.84768 .51045 Mdot
.46083 .53338 Mdot
.6284 .5297 Mdot
.61149 .47985 Mdot
.5793 .31662 Mdot
.32794 .64544 Mdot
.50119 .31112 Mdot
.59261 .5568 Mdot
.52335 .71199 Mdot
.51717 .7368 Mdot
.38719 .56567 Mdot
.37564 .48287 Mdot
.76334 .55601 Mdot
.31083 .429 Mdot
.35877 .64569 Mdot
.52539 .73279 Mdot
.60248 .29604 Mdot
.28887 .45636 Mdot
.34274 .44623 Mdot
.28883 .42911 Mdot
.65093 .51491 Mdot
.43621 .41987 Mdot
.33619 .50604 Mdot
.419 .39809 Mdot
.60333 .56882 Mdot
.36993 .61376 Mdot
.41757 .39764 Mdot
.49728 .69892 Mdot
.30241 .45522 Mdot
.32896 .66742 Mdot
.63789 .52106 Mdot
.55525 .33002 Mdot
.58099 .79105 Mdot
.18156 .58787 Mdot
.41484 .60228 Mdot
.41478 .60243 Mdot
.58255 .35046 Mdot
.50827 .23564 Mdot
.27989 .45814 Mdot
.64431 .38665 Mdot
.53801 .65771 Mdot
.56702 .55127 Mdot
.35665 .79428 Mdot
.36811 .62722 Mdot
.34365 .62266 Mdot
.66273 .52854 Mdot
.31489 .62041 Mdot
.66371 .51461 Mdot
.35352 .61157 Mdot
.40345 .31904 Mdot
.65007 .57951 Mdot
.33967 .6249 Mdot
.70691 .5394 Mdot
.61969 .5031 Mdot
.58316 .32503 Mdot
.30529 .62689 Mdot
.57988 .56064 Mdot
.83786 .56914 Mdot
.29917 .42676 Mdot
.42189 .41061 Mdot
.41951 .61022 Mdot
.30156 .40855 Mdot
.53089 .323 Mdot
.64613 .49904 Mdot
.51398 .70797 Mdot
.56889 .3278 Mdot
.34874 .58701 Mdot
.48363 .69536 Mdot
.48755 .42286 Mdot
.56989 .32102 Mdot
.43396 .41682 Mdot
.50899 .73 Mdot
.56356 .52963 Mdot
.34445 .62489 Mdot
.18281 .55147 Mdot
.41713 .40272 Mdot
.65658 .53941 Mdot
.37112 .60601 Mdot
.29502 .4084 Mdot
.65311 .56289 Mdot
.35803 .64303 Mdot
.41961 .40629 Mdot
.62478 .50529 Mdot
.63176 .49801 Mdot
.62284 .42835 Mdot
.48657 .62656 Mdot
.50137 .70286 Mdot
.57904 .29236 Mdot
.6108 .57011 Mdot
.49322 .73419 Mdot
.20634 .54822 Mdot
.62279 .58258 Mdot
.53735 .36201 Mdot
.66503 .42797 Mdot
.31328 .62937 Mdot
.32661 .41468 Mdot
.32537 .60461 Mdot
.48666 .68862 Mdot
.15193 .59924 Mdot
.42145 .419 Mdot
.60427 .48699 Mdot
.5777 .53254 Mdot
.35604 .67388 Mdot
.54658 .34099 Mdot
.48554 .21618 Mdot
.66733 .50903 Mdot
.59003 .48187 Mdot
.6389 .53574 Mdot
.20094 .56091 Mdot
.53589 .34389 Mdot
.63886 .53859 Mdot
.66398 .60015 Mdot
.58182 .54872 Mdot
.50945 .68962 Mdot
.69903 .66009 Mdot
.61454 .54566 Mdot
.61686 .8882 Mdot
.44776 .41294 Mdot
.33957 .63192 Mdot
.47307 .50477 Mdot
.41614 .6464 Mdot
.60619 .81059 Mdot
.53187 .32841 Mdot
.57137 .25542 Mdot
.31551 .64941 Mdot
.55866 .80146 Mdot
.50886 .24384 Mdot
.62055 .49815 Mdot
.67128 .51919 Mdot
.32606 .62007 Mdot
.30835 .63942 Mdot
.44316 .4219 Mdot
.68099 .54652 Mdot
.60847 .47153 Mdot
.34829 .60026 Mdot
.63783 .51495 Mdot
.68506 .38886 Mdot
.34959 .43473 Mdot
.57108 .31849 Mdot
.30852 .41407 Mdot
.34497 .4401 Mdot
.71221 .47723 Mdot
.49455 .46441 Mdot
.31322 .44961 Mdot
.34973 .41592 Mdot
.44428 .70119 Mdot
.74938 .54196 Mdot
.51204 .6915 Mdot
.38982 .44999 Mdot
.33786 .65078 Mdot
.64533 .55129 Mdot
.53868 .35232 Mdot
.74506 .69555 Mdot
.40932 .22256 Mdot
.54198 .6033 Mdot
.61396 .56762 Mdot
.33226 .64729 Mdot
.41841 .40308 Mdot
.63604 .58284 Mdot
.59463 .74683 Mdot
.65272 .53033 Mdot
.30978 .64856 Mdot
.75493 .52924 Mdot
.38249 .39869 Mdot
.26728 .43102 Mdot
.5743 .37568 Mdot
.62265 .53061 Mdot
.54599 .31963 Mdot
.3234 .44894 Mdot
.48032 .7258 Mdot
.49814 .71153 Mdot
.66983 .55168 Mdot
.42968 .56871 Mdot
.48634 .66079 Mdot
.61956 .49931 Mdot
.60556 .52544 Mdot
.44251 .39897 Mdot
.60619 .52582 Mdot
.64883 .57117 Mdot
.60021 .54705 Mdot
.65859 .57153 Mdot
.28154 .44853 Mdot
.49855 .36286 Mdot
.68577 .53344 Mdot
.57502 .5276 Mdot
.34212 .41824 Mdot
.60484 .58908 Mdot
.31583 .44208 Mdot
.43534 .21731 Mdot
.30679 .44811 Mdot
.49919 .71072 Mdot
.3638 .59864 Mdot
.5562 .25366 Mdot
.52987 .3144 Mdot
.2827 .44562 Mdot
.50164 .72742 Mdot
.32888 .4336 Mdot
.3631 .64271 Mdot
.19288 .4641 Mdot
.54419 .28281 Mdot
.44741 .46677 Mdot
.74655 .55149 Mdot
.45644 .40621 Mdot
.3235 .61329 Mdot
.55541 .30512 Mdot
.37591 .39662 Mdot
.59286 .54217 Mdot
.51064 .70257 Mdot
.64869 .52582 Mdot
.30269 .45617 Mdot
.33472 .64818 Mdot
.37301 .44521 Mdot
.50035 .70271 Mdot
.16122 .58967 Mdot
.36201 .61078 Mdot
.58862 .50181 Mdot
.34207 .41882 Mdot
.20082 .45256 Mdot
.31309 .44559 Mdot
.58399 .67339 Mdot
.59413 .39154 Mdot
.71988 .71969 Mdot
.56379 .34022 Mdot
.44873 .42461 Mdot
.57921 .18902 Mdot
.46988 .29392 Mdot
.56021 .32299 Mdot
.37288 .58615 Mdot
.64699 .51669 Mdot
.60961 .55809 Mdot
.64154 .48259 Mdot
.52783 .38035 Mdot
.62099 .5742 Mdot
.422 .41621 Mdot
.48679 .4682 Mdot
.25582 .48202 Mdot
.30653 .66265 Mdot
.66681 .51893 Mdot
.3404 .43773 Mdot
.28952 .45422 Mdot
.42147 .39401 Mdot
.29311 .41696 Mdot
.61634 .51176 Mdot
.56804 .33731 Mdot
.40493 .53367 Mdot
.50729 .69445 Mdot
.42296 .34071 Mdot
.52786 .65546 Mdot
.49779 .66868 Mdot
.58102 .55049 Mdot
.31539 .65428 Mdot
.30196 .75573 Mdot
.59849 .55347 Mdot
.54776 .33388 Mdot
.57884 .52747 Mdot
.60491 .54707 Mdot
.61761 .54503 Mdot
.3577 .64695 Mdot
.46857 .50208 Mdot
.63612 .51465 Mdot
.3136 .45028 Mdot
.41745 .50756 Mdot
.67041 .5682 Mdot
.3059 .51986 Mdot
.42012 .59077 Mdot
.45521 .4055 Mdot
.5966 .32392 Mdot
.31722 .63679 Mdot
.55844 .33993 Mdot
.51433 .35896 Mdot
.53118 .32217 Mdot
.30658 .50634 Mdot
.64716 .39977 Mdot
.48587 .86176 Mdot
.78433 .4195 Mdot
.75854 .53212 Mdot
.53857 .36986 Mdot
.24453 .54052 Mdot
.55676 .32079 Mdot
.53131 .32449 Mdot
.38438 .86717 Mdot
.54173 .3606 Mdot
.63736 .54573 Mdot
.67242 .50805 Mdot
.5718 .22849 Mdot
.44657 .70655 Mdot
.63648 .50211 Mdot
.62755 .57345 Mdot
.52239 .73488 Mdot
.58804 .42027 Mdot
.44483 .42307 Mdot
.49515 .44982 Mdot
.41674 .42213 Mdot
.6388 .5292 Mdot
.66857 .54623 Mdot
.6932 .53076 Mdot
.60855 .18293 Mdot
.71077 .7377 Mdot
.58337 .34539 Mdot
.58783 .5852 Mdot
.43088 .38273 Mdot
.58697 .51134 Mdot
.57884 .53603 Mdot
.6178 .53201 Mdot
.31489 .64652 Mdot
.58608 .36007 Mdot
.55504 .54187 Mdot
.45446 .3639 Mdot
.67068 .53864 Mdot
.5235 .66269 Mdot
.47174 .72305 Mdot
.64693 .54102 Mdot
.54555 .36404 Mdot
.61174 .56316 Mdot
.52118 .32996 Mdot
.56702 .3163 Mdot
.61825 .47528 Mdot
.34793 .50147 Mdot
.5773 .37055 Mdot
.62226 .49758 Mdot
.32687 .61397 Mdot
.41834 .33022 Mdot
.65461 .54009 Mdot
.49223 .69538 Mdot
.62617 .5574 Mdot
.5031 .68602 Mdot
.60995 .53144 Mdot
.42166 .39566 Mdot
.658 .295 Mdot
.32901 .65651 Mdot
.48037 .67048 Mdot
.31671 .61991 Mdot
.6354 .4617 Mdot
.53301 .36227 Mdot
.38666 .41151 Mdot
.68765 .76458 Mdot
.44304 .40043 Mdot
.59715 .77367 Mdot
.4107 .49971 Mdot
.33924 .42233 Mdot
.54757 .29589 Mdot
.74794 .52101 Mdot
.33346 .52694 Mdot
.32142 .67768 Mdot
.35822 .66563 Mdot
.33966 .76005 Mdot
.28521 .77486 Mdot
.63525 .51175 Mdot
.22457 .45962 Mdot
.68726 .34921 Mdot
.70817 .57067 Mdot
.67857 .57481 Mdot
.36449 .60719 Mdot
.63541 .50181 Mdot
.49136 .53849 Mdot
.34892 .64644 Mdot
.50888 .72268 Mdot
.54461 .3137 Mdot
.49428 .73145 Mdot
.37672 .22317 Mdot
.3973 .42715 Mdot
.35168 .6392 Mdot
.66399 .56923 Mdot
.65162 .50903 Mdot
.56258 .29745 Mdot
.78015 .35094 Mdot
.56951 .31488 Mdot
.49914 .69064 Mdot
.34065 .65857 Mdot
.78037 .61005 Mdot
.6226 .55305 Mdot
.56102 .35587 Mdot
.37107 .58651 Mdot
.64353 .5602 Mdot
.32977 .41808 Mdot
.61166 .56671 Mdot
.56436 .35573 Mdot
.60627 .52645 Mdot
.56672 .3361 Mdot
.34468 .61042 Mdot
.67619 .5436 Mdot
.6669 .55049 Mdot
.60026 .76842 Mdot
.49232 .71509 Mdot
.5376 .36598 Mdot
.49311 .53852 Mdot
.60778 .57613 Mdot
.59662 .73963 Mdot
.62198 .52806 Mdot
.72321 .57681 Mdot
.62696 .58922 Mdot
.42456 .41797 Mdot
.57785 .53539 Mdot
.65497 .53883 Mdot
.79578 .39803 Mdot
.78404 .39727 Mdot
.73485 .54367 Mdot
.27789 .42142 Mdot
.55994 .36183 Mdot
.35497 .64281 Mdot
.30225 .64525 Mdot
.32496 .63473 Mdot
.46401 .72743 Mdot
.59934 .59454 Mdot
.6608 .53824 Mdot
.26082 .41302 Mdot
.50601 .71729 Mdot
.55241 .35522 Mdot
.50401 .71103 Mdot
.49845 .46447 Mdot
.48681 .69696 Mdot
.41917 .41567 Mdot
.18524 .52144 Mdot
.68547 .40367 Mdot
.48355 .70776 Mdot
.56881 .31524 Mdot
.42469 .48737 Mdot
.56406 .54615 Mdot
.33049 .33272 Mdot
.52357 .71348 Mdot
.31761 .75188 Mdot
.62453 .50819 Mdot
.4776 .51446 Mdot
.31128 .4405 Mdot
.49462 .73126 Mdot
.29011 .42768 Mdot
.61057 .56176 Mdot
.5049 .37623 Mdot
.54244 .33333 Mdot
.34857 .43255 Mdot
.5846 .55041 Mdot
.49561 .73193 Mdot
.35088 .63371 Mdot
.7518 .53625 Mdot
.342 .41419 Mdot
.57466 .79196 Mdot
.58768 .74516 Mdot
.3432 .65761 Mdot
.76806 .53241 Mdot
.29587 .43946 Mdot
.56906 .55624 Mdot
.54066 .54085 Mdot
.60178 .56068 Mdot
.32434 .66845 Mdot
.34229 .62164 Mdot
.47982 .32624 Mdot
.67202 .5436 Mdot
.68597 .52299 Mdot
.58954 .3464 Mdot
.34755 .6588 Mdot
.53038 .32193 Mdot
.55822 .29933 Mdot
.32614 .61879 Mdot
.56012 .30591 Mdot
.4786 .70044 Mdot
.50802 .52041 Mdot
.29766 .44188 Mdot
.33287 .42104 Mdot
.35311 .63647 Mdot
.35067 .66303 Mdot
.3164 .6573 Mdot
.58874 .55003 Mdot
.54362 .30555 Mdot
.59144 .52266 Mdot
.62214 .53587 Mdot
.60665 .34046 Mdot
.59256 .32859 Mdot
.58401 .53128 Mdot
.39151 .52451 Mdot
.51555 .69003 Mdot
.33749 .62682 Mdot
.28359 .43281 Mdot
.59269 .79357 Mdot
.33952 .41869 Mdot
.61072 .57575 Mdot
.35687 .32445 Mdot
.53865 .34924 Mdot
.49388 .70536 Mdot
.41678 .60027 Mdot
.49777 .70295 Mdot
.34894 .43479 Mdot
.58968 .31254 Mdot
.48387 .43291 Mdot
.67346 .54284 Mdot
.48774 .48099 Mdot
.64086 .72143 Mdot
.44719 .34045 Mdot
.28293 .43899 Mdot
.61928 .57078 Mdot
.44418 .40612 Mdot
.64374 .37398 Mdot
.66212 .53498 Mdot
.59508 .57249 Mdot
.39831 .67842 Mdot
.57643 .53933 Mdot
.58374 .30325 Mdot
.42264 .5747 Mdot
.67015 .55955 Mdot
.63987 .4632 Mdot
.32802 .81326 Mdot
.62723 .50354 Mdot
.66771 .55146 Mdot
.63461 .55128 Mdot
.59173 .54577 Mdot
.51951 .33441 Mdot
.34108 .70527 Mdot
.33684 .44261 Mdot
.50796 .52128 Mdot
.29047 .43502 Mdot
.35208 .62433 Mdot
.47907 .54968 Mdot
.52044 .33038 Mdot
.49743 .70237 Mdot
.21989 .46031 Mdot
.53342 .60512 Mdot
.34031 .60852 Mdot
.6333 .78054 Mdot
.52012 .70234 Mdot
.56423 .54739 Mdot
.47826 .69331 Mdot
.3686 .60904 Mdot
.33274 .42584 Mdot
.62804 .48953 Mdot
.52723 .33533 Mdot
.5776 .33959 Mdot
.61071 .56812 Mdot
.41675 .34441 Mdot
.30465 .40676 Mdot
.53588 .7535 Mdot
.65573 .51775 Mdot
.59892 .57479 Mdot
.5679 .31139 Mdot
.32922 .64494 Mdot
.41201 .50105 Mdot
.49445 .72178 Mdot
.61673 .49056 Mdot
.61488 .56275 Mdot
.49755 .46645 Mdot
.28285 .44807 Mdot
.43027 .40631 Mdot
.66803 .52929 Mdot
.48983 .45769 Mdot
.62331 .5758 Mdot
.69498 .4999 Mdot
.31921 .62102 Mdot
.59931 .47791 Mdot
.6773 .52809 Mdot
.50188 .36374 Mdot
.29415 .43563 Mdot
.54954 .33798 Mdot
.60632 .31888 Mdot
.43019 .39365 Mdot
.30199 .42311 Mdot
.5838 .53561 Mdot
.34311 .44796 Mdot
.60734 .55188 Mdot
.63721 .51835 Mdot
.28201 .43752 Mdot
.53512 .3141 Mdot
.47444 .22548 Mdot
.4987 .36361 Mdot
.59615 .53501 Mdot
.6294 .55927 Mdot
.44688 .70401 Mdot
.75333 .70118 Mdot
.67869 .5298 Mdot
.54922 .30377 Mdot
.64452 .56086 Mdot
.33868 .42704 Mdot
.49563 .69102 Mdot
.55181 .32928 Mdot
.35921 .65154 Mdot
.34936 .61268 Mdot
.39029 .63198 Mdot
.41995 .41778 Mdot
.68068 .54527 Mdot
.58092 .29331 Mdot
.59094 .33425 Mdot
.51161 .49801 Mdot
.33972 .63075 Mdot
.49066 .6911 Mdot
.63483 .5002 Mdot
.7066 .47903 Mdot
.3406 .445 Mdot
.63622 .87439 Mdot
.48206 .43738 Mdot
.46438 .70228 Mdot
.45938 .58273 Mdot
.44191 .40346 Mdot
.63632 .50567 Mdot
.50307 .73571 Mdot
.34492 .61554 Mdot
.61029 .5595 Mdot
.65371 .59772 Mdot
.3349 .53086 Mdot
.35103 .66551 Mdot
.34671 .44166 Mdot
.36294 .62171 Mdot
.50702 .68675 Mdot
.41949 .41512 Mdot
.57923 .34274 Mdot
.65191 .536 Mdot
.59694 .47177 Mdot
.33594 .64122 Mdot
.43851 .39044 Mdot
.66126 .56084 Mdot
.56844 .35708 Mdot
.33193 .63091 Mdot
.63449 .53129 Mdot
.64161 .38238 Mdot
.55943 .25495 Mdot
.34073 .65364 Mdot
.61993 .49157 Mdot
.62448 .447 Mdot
.35403 .6656 Mdot
.37476 .62216 Mdot
.62514 .57401 Mdot
.49787 .73101 Mdot
.67553 .53222 Mdot
.32231 .44294 Mdot
.46761 .50181 Mdot
.31041 .41761 Mdot
.59774 .74794 Mdot
.69249 .53673 Mdot
.59355 .62793 Mdot
.5282 .30756 Mdot
.5241 .68794 Mdot
.81971 .4459 Mdot
.60961 .57868 Mdot
.49212 .19067 Mdot
.45904 .52 Mdot
.46115 .45063 Mdot
.44342 .18474 Mdot
.48695 .71752 Mdot
.3266 .43475 Mdot
.66089 .55979 Mdot
.2558 .39865 Mdot
.48415 .7184 Mdot
.59868 .74748 Mdot
.59583 .50438 Mdot
.54303 .34891 Mdot
.65442 .51886 Mdot
.56718 .35559 Mdot
.64053 .55788 Mdot
.60385 .40883 Mdot
.51562 .6607 Mdot
.5846 .67226 Mdot
.56134 .54323 Mdot
.20785 .43765 Mdot
.7486 .54861 Mdot
.49797 .69382 Mdot
.5995 .53292 Mdot
.43614 .40296 Mdot
.29322 .40858 Mdot
.21416 .49118 Mdot
.31576 .65219 Mdot
.30693 .45002 Mdot
.55768 .3096 Mdot
.35402 .59687 Mdot
.43949 .39197 Mdot
.55472 .56317 Mdot
.49873 .73321 Mdot
.29973 .42629 Mdot
.652 .53936 Mdot
.59751 .56375 Mdot
.20017 .56087 Mdot
.79646 .58858 Mdot
.55404 .30167 Mdot
.20994 .67362 Mdot
.57696 .29222 Mdot
.49921 .71975 Mdot
.31636 .62588 Mdot
.62779 .53639 Mdot
.66629 .53951 Mdot
.34407 .66571 Mdot
.57753 .3068 Mdot
.5273 .68796 Mdot
.72724 .71485 Mdot
.36257 .40892 Mdot
.64823 .66985 Mdot
.55087 .32684 Mdot
.64314 .67031 Mdot
.51273 .74943 Mdot
.32091 .48359 Mdot
.74658 .60998 Mdot
.3215 .41443 Mdot
.65396 .66951 Mdot
.54994 .35675 Mdot
.63538 .51013 Mdot
.43443 .41593 Mdot
.44543 .41474 Mdot
.5493 .31562 Mdot
.32218 .62436 Mdot
.51698 .72205 Mdot
.65717 .52213 Mdot
.55674 .58153 Mdot
.77356 .33257 Mdot
.35173 .66051 Mdot
.61618 .48008 Mdot
.29657 .41031 Mdot
.63831 .5612 Mdot
.51743 .73847 Mdot
.32755 .42506 Mdot
.4131 .40306 Mdot
.52855 .59628 Mdot
.6448 .4984 Mdot
.42612 .58006 Mdot
.30569 .43542 Mdot
.75775 .69536 Mdot
.66646 .55042 Mdot
.29561 .43906 Mdot
.59988 .47154 Mdot
.41052 .37825 Mdot
.40972 .52569 Mdot
.46957 .28964 Mdot
.29612 .64814 Mdot
.35647 .61433 Mdot
.82774 .58321 Mdot
.53996 .65812 Mdot
.30514 .45221 Mdot
.41712 .4108 Mdot
.72245 .64498 Mdot
.29321 .42415 Mdot
.62826 .49098 Mdot
.62269 .52251 Mdot
.75515 .5287 Mdot
.71315 .50034 Mdot
.4458 .42089 Mdot
.59361 .60232 Mdot
.61106 .51268 Mdot
.56274 .51778 Mdot
.64454 .56631 Mdot
.57424 .35736 Mdot
.31455 .41133 Mdot
.3531 .16709 Mdot
.32915 .45639 Mdot
.55096 .59198 Mdot
.33754 .65066 Mdot
.30211 .62798 Mdot
.64629 .54018 Mdot
.61953 .64136 Mdot
.20378 .3624 Mdot
.61971 .55019 Mdot
.41715 .59945 Mdot
.58709 .74696 Mdot
.57371 .56469 Mdot
.55186 .37325 Mdot
.60453 .47303 Mdot
.54678 .28556 Mdot
.32828 .42413 Mdot
.48571 .71709 Mdot
.52572 .70575 Mdot
.32225 .43873 Mdot
.66233 .54311 Mdot
.52845 .71592 Mdot
.6449 .53289 Mdot
.64614 .5076 Mdot
.49835 .45608 Mdot
.48317 .73157 Mdot
.31529 .65668 Mdot
.4978 .70917 Mdot
.53193 .33278 Mdot
.39663 .88162 Mdot
.50862 .70696 Mdot
.74979 .54124 Mdot
.48039 .52794 Mdot
.6541 .6719 Mdot
.57932 .33381 Mdot
.50309 .69139 Mdot
.32161 .41304 Mdot
.4822 .42178 Mdot
.76478 .52926 Mdot
.33982 .41953 Mdot
.66505 .53367 Mdot
.52055 .3266 Mdot
.58545 .34539 Mdot
.26932 .43263 Mdot
.58091 .31638 Mdot
.57616 .50701 Mdot
.62356 .49576 Mdot
.31834 .45086 Mdot
.67569 .23488 Mdot
.3266 .41385 Mdot
.71897 .49056 Mdot
.61662 .5288 Mdot
.54979 .33181 Mdot
.72019 .58026 Mdot
.59608 .3626 Mdot
.43996 .42073 Mdot
.67095 .50988 Mdot
.50583 .69903 Mdot
.50181 .51987 Mdot
.339 .65438 Mdot
.362 .3216 Mdot
.57294 .34616 Mdot
.28288 .45628 Mdot
.58308 .32678 Mdot
.56724 .30172 Mdot
.34697 .42909 Mdot
.53802 .33766 Mdot
.6699 .53927 Mdot
.3239 .26294 Mdot
.57391 .34 Mdot
.31191 .43184 Mdot
.51257 .70102 Mdot
.5576 .30557 Mdot
.50951 .76608 Mdot
.65115 .50648 Mdot
.33781 .60431 Mdot
.47377 .67788 Mdot
.52424 .30865 Mdot
.49443 .69235 Mdot
.33634 .63626 Mdot
.51666 .72537 Mdot
.27184 .3965 Mdot
.27297 .45192 Mdot
.54673 .6076 Mdot
.39337 .39113 Mdot
.53451 .34852 Mdot
.29406 .64103 Mdot
.65645 .5041 Mdot
.65318 .51401 Mdot
.50921 .6834 Mdot
.57838 .35524 Mdot
.40611 .34802 Mdot
.66187 .62617 Mdot
.42373 .34197 Mdot
.27706 .43306 Mdot
.52521 .78577 Mdot
.48128 .43541 Mdot
.33291 .38528 Mdot
.67306 .50173 Mdot
.44172 .40506 Mdot
.63838 .53644 Mdot
.57908 .75652 Mdot
.51498 .69359 Mdot
.22378 .58856 Mdot
.69937 .52087 Mdot
.33572 .66411 Mdot
.63333 .55637 Mdot
.2354 .47922 Mdot
.6566 .46889 Mdot
.52392 .7089 Mdot
.35157 .44374 Mdot
.52984 .31437 Mdot
.51218 .69574 Mdot
.34617 .61154 Mdot
.67205 .6504 Mdot
.63342 .4924 Mdot
.61477 .50983 Mdot
.36675 .65782 Mdot
.52864 .32748 Mdot
.34878 .62348 Mdot
.29706 .44139 Mdot
.50638 .70817 Mdot
.58965 .53962 Mdot
.58782 .48737 Mdot
.35947 .67176 Mdot
.31821 .45707 Mdot
.33737 .67069 Mdot
.34071 .44942 Mdot
.44138 .40917 Mdot
.67244 .56068 Mdot
.37216 .65474 Mdot
.69094 .51847 Mdot
.76494 .37516 Mdot
.51454 .53066 Mdot
.80262 .46827 Mdot
.31441 .65597 Mdot
.49978 .65186 Mdot
.32068 .435 Mdot
.29689 .42945 Mdot
.7207 .48611 Mdot
.20556 .37542 Mdot
.41724 .50209 Mdot
.1806 .47692 Mdot
.29799 .44239 Mdot
.30364 .43009 Mdot
.33717 .61805 Mdot
.53396 .3246 Mdot
.51157 .34962 Mdot
.37478 .61298 Mdot
.57558 .70467 Mdot
.55273 .35543 Mdot
.52029 .19585 Mdot
.3708 .63656 Mdot
.66155 .49821 Mdot
.39751 .41982 Mdot
.52388 .71069 Mdot
.57817 .74023 Mdot
.19144 .47265 Mdot
.63147 .54046 Mdot
.43703 .84852 Mdot
.31695 .6427 Mdot
.39851 .44271 Mdot
.2566 .46276 Mdot
.59553 .56724 Mdot
.63654 .55453 Mdot
.66039 .55063 Mdot
.47117 .68747 Mdot
.76572 .34395 Mdot
.63001 .53742 Mdot
.56342 .65706 Mdot
.6487 .5801 Mdot
.18934 .55763 Mdot
.49813 .7093 Mdot
.68617 .72788 Mdot
.31479 .60522 Mdot
.4405 .36095 Mdot
.58322 .55472 Mdot
.30431 .44429 Mdot
.35833 .52864 Mdot
.28699 .4465 Mdot
.28099 .48002 Mdot
.74361 .62301 Mdot
.57019 .36208 Mdot
.61043 .5665 Mdot
.37271 .63603 Mdot
.5213 .31963 Mdot
.3724 .52774 Mdot
.36507 .8611 Mdot
.27383 .43679 Mdot
.20231 .70162 Mdot
.30272 .41744 Mdot
.44601 .41596 Mdot
.55925 .31174 Mdot
.65415 .64352 Mdot
.49051 .47629 Mdot
.53119 .32041 Mdot
.41067 .77245 Mdot
.51567 .31003 Mdot
.62671 .66052 Mdot
.5422 .28122 Mdot
.31862 .43038 Mdot
.28274 .45801 Mdot
.64695 .59529 Mdot
.67398 .51888 Mdot
.48161 .48286 Mdot
.68994 .56575 Mdot
.64932 .50102 Mdot
.34898 .64674 Mdot
.38315 .3893 Mdot
.25112 .40074 Mdot
.54827 .32327 Mdot
.32867 .45129 Mdot
.63395 .55519 Mdot
.59631 .53439 Mdot
.57933 .51678 Mdot
.56596 .80182 Mdot
.51742 .19395 Mdot
.63495 .5166 Mdot
.65285 .46868 Mdot
.33441 .61058 Mdot
.19964 .56304 Mdot
.2217 .67348 Mdot
.73296 .63278 Mdot
.65835 .56367 Mdot
.49378 .7141 Mdot
.52245 .7363 Mdot
.57513 .51555 Mdot
.58285 .62837 Mdot
.49248 .77227 Mdot
.65214 .53957 Mdot
.60592 .65164 Mdot
.33757 .68041 Mdot
.4321 .39047 Mdot
.3363 .64069 Mdot
.52188 .31472 Mdot
.44437 .40183 Mdot
.35956 .63516 Mdot
.55238 .64486 Mdot
.42654 .39576 Mdot
.4151 .37512 Mdot
.50073 .69063 Mdot
.65363 .56246 Mdot
.51476 .28334 Mdot
.35098 .65852 Mdot
.30138 .43301 Mdot
.564 .3296 Mdot
.28786 .40999 Mdot
.18451 .54209 Mdot
.57871 .71644 Mdot
.42322 .4195 Mdot
.30709 .44572 Mdot
.42947 .5561 Mdot
.49545 .71397 Mdot
.29724 .41624 Mdot
.60288 .63288 Mdot
.6834 .55573 Mdot
.25177 .28937 Mdot
.61081 .50792 Mdot
.48631 .30083 Mdot
.30048 .43711 Mdot
.41028 .40511 Mdot
.6523 .53441 Mdot
.35967 .60966 Mdot
.57079 .5686 Mdot
.64451 .53133 Mdot
.36686 .63722 Mdot
.63399 .5133 Mdot
.49526 .73707 Mdot
.54548 .28749 Mdot
.46487 .52779 Mdot
.55613 .78549 Mdot
.51965 .71354 Mdot
.52361 .4754 Mdot
.6789 .5269 Mdot
.37051 .74671 Mdot
.54345 .34705 Mdot
.60899 .57748 Mdot
.61432 .75641 Mdot
.54019 .32026 Mdot
.55894 .34089 Mdot
.60297 .52401 Mdot
.32842 .41344 Mdot
.32731 .66816 Mdot
.49561 .71212 Mdot
.27603 .38622 Mdot
.63262 .531 Mdot
.62042 .57179 Mdot
.51854 .69999 Mdot
.30286 .42475 Mdot
.5879 .53654 Mdot
.41652 .28422 Mdot
.51309 .50794 Mdot
.34344 .44387 Mdot
.67207 .56685 Mdot
.36953 .18804 Mdot
.50914 .34144 Mdot
.44905 .85293 Mdot
.52094 .65637 Mdot
.32216 .62067 Mdot
.63626 .48021 Mdot
.58365 .90433 Mdot
.50308 .69271 Mdot
.44169 .3517 Mdot
.63973 .51177 Mdot
.62494 .5392 Mdot
.56024 .36604 Mdot
.58877 .52145 Mdot
.55226 .36138 Mdot
.53787 .79157 Mdot
.19225 .38943 Mdot
.58044 .31776 Mdot
.55885 .36015 Mdot
.69593 .48674 Mdot
.57193 .80616 Mdot
.54811 .31164 Mdot
.63369 .49264 Mdot
.39269 .74907 Mdot
.6665 .59534 Mdot
.47538 .72661 Mdot
.47094 .7618 Mdot
.5484 .37227 Mdot
.77018 .50437 Mdot
.69695 .48834 Mdot
.62924 .41759 Mdot
.48911 .76043 Mdot
.29566 .44719 Mdot
.6082 .54193 Mdot
.41736 .41512 Mdot
.33294 .62701 Mdot
.5678 .49784 Mdot
.66188 .55477 Mdot
.53263 .35479 Mdot
.47716 .68461 Mdot
.29208 .42189 Mdot
.63785 .57117 Mdot
.36667 .66962 Mdot
.50395 .72526 Mdot
.57451 .33189 Mdot
.74057 .52217 Mdot
.52711 .71876 Mdot
.5973 .48242 Mdot
.6301 .50954 Mdot
.64601 .56992 Mdot
.69404 .58817 Mdot
.3189 .43975 Mdot
.36692 .6038 Mdot
.63227 .48146 Mdot
.4896 .43708 Mdot
.50908 .54508 Mdot
.60761 .48836 Mdot
.55193 .30401 Mdot
.27784 .43123 Mdot
.42239 .4056 Mdot
.68304 .66681 Mdot
.62064 .51582 Mdot
.50721 .18968 Mdot
.66578 .77228 Mdot
.42829 .39783 Mdot
.51788 .34266 Mdot
.4952 .70556 Mdot
.61156 .52117 Mdot
.57014 .66628 Mdot
.62471 .49259 Mdot
.65257 .60451 Mdot
.31752 .62997 Mdot
.2886 .44081 Mdot
.52976 .53406 Mdot
.33487 .62493 Mdot
.55858 .34027 Mdot
.56454 .2197 Mdot
.5112 .33741 Mdot
.56053 .30048 Mdot
.34363 .49931 Mdot
.33345 .43348 Mdot
.59739 .9001 Mdot
.74699 .7138 Mdot
.66195 .50079 Mdot
.33577 .43892 Mdot
.55689 .31424 Mdot
.5821 .52397 Mdot
.54089 .35358 Mdot
.57819 .36843 Mdot
.63951 .50006 Mdot
.64464 .501 Mdot
.58591 .66633 Mdot
.52929 .20125 Mdot
.51098 .70338 Mdot
.5852 .32316 Mdot
.69229 .44869 Mdot
.6283 .53195 Mdot
.67344 .53872 Mdot
.34915 .52759 Mdot
.50845 .69268 Mdot
.67168 .37476 Mdot
.65047 .51417 Mdot
.60782 .77336 Mdot
.66407 .50638 Mdot
.51962 .36599 Mdot
.27996 .4066 Mdot
.56514 .61014 Mdot
.31996 .66683 Mdot
.55156 .2949 Mdot
.50568 .6839 Mdot
.59834 .3384 Mdot
.67077 .41114 Mdot
.33112 .42546 Mdot
.56377 .35616 Mdot
.34397 .59541 Mdot
.31145 .42155 Mdot
.33053 .41696 Mdot
.37803 .52687 Mdot
.34119 .59808 Mdot
.46807 .69542 Mdot
.2853 .4195 Mdot
.64025 .38448 Mdot
.3186 .42779 Mdot
.66571 .40464 Mdot
.67781 .54593 Mdot
.56053 .65345 Mdot
.54421 .56533 Mdot
.66032 .59336 Mdot
.30816 .4118 Mdot
.51297 .72428 Mdot
.58684 .54496 Mdot
.57731 .31194 Mdot
.51342 .71352 Mdot
.39388 .4283 Mdot
.30638 .61837 Mdot
.5831 .35213 Mdot
.35084 .44096 Mdot
.54122 .3584 Mdot
.58394 .74434 Mdot
.5202 .67755 Mdot
.36986 .53815 Mdot
.4889 .48622 Mdot
.5599 .52585 Mdot
.66055 .46729 Mdot
.58755 .55323 Mdot
.66547 .5435 Mdot
.34082 .65287 Mdot
.46341 .7249 Mdot
.55786 .30531 Mdot
.76732 .31604 Mdot
.30855 .44346 Mdot
.42507 .57411 Mdot
.63184 .60631 Mdot
.60803 .55459 Mdot
.56032 .31887 Mdot
.58777 .35861 Mdot
.78523 .39834 Mdot
.34197 .6672 Mdot
.67423 .59089 Mdot
.57739 .55053 Mdot
.53864 .48958 Mdot
.31227 .41384 Mdot
.44918 .26192 Mdot
.3051 .65716 Mdot
.2221 .7383 Mdot
.33829 .62568 Mdot
.38305 .70071 Mdot
.53738 .33655 Mdot
.4857 .69561 Mdot
.66931 .52714 Mdot
.55727 .4133 Mdot
.52119 .34336 Mdot
.28936 .63664 Mdot
.49682 .69982 Mdot
.46917 .23854 Mdot
.32543 .44634 Mdot
.66116 .56521 Mdot
.65914 .50296 Mdot
.59443 .52488 Mdot
.58666 .51477 Mdot
.32324 .45058 Mdot
.62102 .49329 Mdot
.34489 .41587 Mdot
.6807 .41039 Mdot
.61906 .74998 Mdot
.37523 .63148 Mdot
.20475 .57785 Mdot
.56362 .30166 Mdot
.6205 .28241 Mdot
.68008 .38762 Mdot
.51452 .52972 Mdot
.27375 .39851 Mdot
.67548 .55515 Mdot
.32319 .62457 Mdot
.21195 .43822 Mdot
.37418 .62992 Mdot
.26978 .23381 Mdot
.75466 .53215 Mdot
.49178 .26567 Mdot
.59586 .51236 Mdot
.37705 .6473 Mdot
.76191 .47765 Mdot
.59195 .48394 Mdot
.52989 .71009 Mdot
.6511 .40564 Mdot
.49295 .31304 Mdot
.49296 .69014 Mdot
.64549 .50461 Mdot
.59295 .32601 Mdot
.6685 .53395 Mdot
.66534 .51976 Mdot
.61952 .55235 Mdot
.29221 .40079 Mdot
.68332 .52192 Mdot
.67511 .53155 Mdot
.79331 .59526 Mdot
.40913 .58779 Mdot
.34746 .60759 Mdot
.80246 .45122 Mdot
.50642 .71719 Mdot
.52325 .31312 Mdot
.4604 .5174 Mdot
.32094 .44522 Mdot
.78611 .40161 Mdot
.60266 .51145 Mdot
.43885 .32533 Mdot
.29304 .45966 Mdot
.4961 .72754 Mdot
.42032 .40359 Mdot
.44076 .23478 Mdot
.30966 .6415 Mdot
.44098 .42425 Mdot
.33768 .65514 Mdot
.8022 .49501 Mdot
.55734 .36133 Mdot
.56044 .52451 Mdot
.28901 .42261 Mdot
.36465 .60766 Mdot
.56761 .66092 Mdot
.65236 .55887 Mdot
.31481 .65734 Mdot
.55447 .52058 Mdot
.50009 .5286 Mdot
.46086 .51162 Mdot
.35994 .60154 Mdot
.31086 .46303 Mdot
.3152 .41839 Mdot
.4875 .68966 Mdot
.53477 .2996 Mdot
.52823 .33441 Mdot
.3205 .42278 Mdot
.31711 .79053 Mdot
.63327 .53307 Mdot
.62538 .52384 Mdot
.4871 .43242 Mdot
.5798 .52934 Mdot
.45915 .68123 Mdot
.44966 .40381 Mdot
.52584 .338 Mdot
.587 .55009 Mdot
.58817 .53553 Mdot
.628 .50724 Mdot
.58117 .70962 Mdot
.3341 .64156 Mdot
.61145 .51352 Mdot
.50148 .73459 Mdot
.4307 .43302 Mdot
.66049 .5065 Mdot
.57391 .49936 Mdot
.54865 .36076 Mdot
.32761 .75049 Mdot
.30308 .43717 Mdot
.34578 .66151 Mdot
.3692 .64673 Mdot
.63735 .71419 Mdot
.55093 .38626 Mdot
.44704 .42052 Mdot
.19792 .52988 Mdot
.41913 .41046 Mdot
.49281 .69773 Mdot
.40947 .51603 Mdot
.32034 .68444 Mdot
.3547 .61231 Mdot
.32693 .46395 Mdot
.60499 .56945 Mdot
.65399 .50187 Mdot
.43475 .35672 Mdot
.62007 .54377 Mdot
.50539 .69767 Mdot
.33026 .41158 Mdot
.55688 .35946 Mdot
.51622 .7378 Mdot
.29619 .42677 Mdot
.52896 .32417 Mdot
.6075 .58347 Mdot
.61437 .48978 Mdot
.56396 .33369 Mdot
.57641 .33103 Mdot
.64153 .54635 Mdot
.80719 .57069 Mdot
.52437 .33067 Mdot
.56553 .32302 Mdot
.47203 .40744 Mdot
.31657 .62186 Mdot
.7201 .55537 Mdot
.33585 .4364 Mdot
.6716 .53856 Mdot
.37607 .63641 Mdot
.48481 .70367 Mdot
.56463 .34409 Mdot
.61001 .53864 Mdot
.63569 .52449 Mdot
.49309 .71233 Mdot
.49362 .73988 Mdot
.51612 .70174 Mdot
.28592 .40608 Mdot
.62168 .49757 Mdot
.551 .30944 Mdot
.32547 .44677 Mdot
.52498 .72536 Mdot
.47617 .69479 Mdot
.78833 .58164 Mdot
.63341 .54152 Mdot
.52939 .72699 Mdot
.4474 .90555 Mdot
.6856 .64925 Mdot
.44492 .39886 Mdot
.35173 .68048 Mdot
.49222 .65643 Mdot
.47903 .67545 Mdot
.29394 .44993 Mdot
.41952 .58808 Mdot
.49002 .68271 Mdot
.61581 .54473 Mdot
.63249 .56364 Mdot
.67106 .49787 Mdot
.51105 .71731 Mdot
.58297 .72277 Mdot
.58897 .3303 Mdot
.68796 .32518 Mdot
.50654 .71704 Mdot
.35426 .60043 Mdot
.36468 .66852 Mdot
.34165 .62281 Mdot
.65768 .56996 Mdot
.8072 .42084 Mdot
.6904 .43403 Mdot
.67125 .36432 Mdot
.31417 .44894 Mdot
.58693 .35938 Mdot
.37084 .44923 Mdot
.55911 .34158 Mdot
.32422 .63796 Mdot
.50651 .72598 Mdot
.56194 .36599 Mdot
.33093 .41803 Mdot
.31622 .41655 Mdot
.33061 .67258 Mdot
.33891 .6355 Mdot
.35145 .6369 Mdot
.54563 .29578 Mdot
.53759 .33726 Mdot
.59149 .53588 Mdot
.56815 .34487 Mdot
.67139 .77533 Mdot
.4789 .66689 Mdot
.34732 .67343 Mdot
.31155 .43713 Mdot
.56923 .32058 Mdot
.65747 .56039 Mdot
.41052 .67388 Mdot
.29043 .64738 Mdot
.52031 .72517 Mdot
.2883 .31088 Mdot
.17686 .39617 Mdot
.65986 .57324 Mdot
.31454 .45666 Mdot
.58914 .62868 Mdot
.65672 .55108 Mdot
.31357 .63789 Mdot
.69986 .73296 Mdot
.41867 .39994 Mdot
.67096 .52092 Mdot
.58734 .56768 Mdot
.32062 .41156 Mdot
.46133 .5155 Mdot
.61559 .54791 Mdot
.41015 .54277 Mdot
.28131 .44995 Mdot
.30597 .65851 Mdot
.83783 .59007 Mdot
.39908 .4389 Mdot
.56067 .74845 Mdot
.43893 .3935 Mdot
.61842 .54097 Mdot
.34753 .64865 Mdot
.51349 .73373 Mdot
.34382 .64292 Mdot
.51626 .34105 Mdot
.31305 .62998 Mdot
.6359 .56742 Mdot
.54535 .31091 Mdot
.30092 .42488 Mdot
.43027 .57906 Mdot
.78539 .54904 Mdot
.35827 .60914 Mdot
.43078 .38814 Mdot
.6479 .50258 Mdot
.63637 .35264 Mdot
.64161 .59494 Mdot
.67702 .52676 Mdot
.28344 .44081 Mdot
.55474 .31972 Mdot
.27746 .43368 Mdot
.55266 .53128 Mdot
.60138 .27101 Mdot
.31224 .44357 Mdot
.49816 .37148 Mdot
.51965 .70113 Mdot
.57523 .7072 Mdot
.65811 .53031 Mdot
.28824 .42563 Mdot
.62136 .50049 Mdot
.58586 .32538 Mdot
.52129 .5836 Mdot
.53175 .48213 Mdot
.29697 .40978 Mdot
.50892 .26136 Mdot
.49441 .54036 Mdot
.71877 .53573 Mdot
.29256 .43657 Mdot
.81837 .44397 Mdot
.43329 .40293 Mdot
.49165 .71896 Mdot
.50853 .74397 Mdot
.47991 .71867 Mdot
.62154 .54073 Mdot
.61731 .40237 Mdot
.47258 .70659 Mdot
.27875 .41301 Mdot
.47895 .72392 Mdot
.57966 .79427 Mdot
.41469 .34468 Mdot
.52057 .71033 Mdot
.65435 .52676 Mdot
.55748 .50652 Mdot
.41924 .59153 Mdot
.31634 .61161 Mdot
.46989 .21011 Mdot
.78483 .60269 Mdot
.62776 .53801 Mdot
.62022 .38484 Mdot
.52289 .35953 Mdot
.48521 .63081 Mdot
.53614 .47826 Mdot
.428 .49083 Mdot
.56805 .32248 Mdot
.47366 .49978 Mdot
.52337 .32099 Mdot
.561 .54562 Mdot
.63803 .51807 Mdot
.5208 .31027 Mdot
.34661 .32066 Mdot
.81061 .38476 Mdot
.4247 .33615 Mdot
.5391 .30754 Mdot
.294 .43526 Mdot
.29575 .45487 Mdot
.28355 .43965 Mdot
.35353 .6517 Mdot
.57269 .34959 Mdot
.6178 .51586 Mdot
.34054 .6117 Mdot
.66144 .51949 Mdot
.32377 .41977 Mdot
.51533 .51518 Mdot
.55561 .36009 Mdot
.65426 .53851 Mdot
.74423 .49764 Mdot
.33155 .65194 Mdot
.49641 .71616 Mdot
.30442 .29217 Mdot
.33773 .6836 Mdot
.33254 .45647 Mdot
.56351 .37875 Mdot
.38321 .60884 Mdot
.31525 .70785 Mdot
.65894 .49825 Mdot
.64667 .49469 Mdot
.4135 .60753 Mdot
.76222 .51128 Mdot
.61615 .55553 Mdot
.34771 .612 Mdot
.32319 .61211 Mdot
.62365 .50112 Mdot
.5809 .3364 Mdot
.47419 .69186 Mdot
.51022 .68371 Mdot
.56087 .53761 Mdot
.4836 .48748 Mdot
.5618 .65485 Mdot
.58482 .53494 Mdot
.67705 .49345 Mdot
.33486 .59761 Mdot
.43924 .39216 Mdot
.4965 .46953 Mdot
.47769 .70165 Mdot
.64196 .51061 Mdot
.77532 .33902 Mdot
.57054 .34827 Mdot
.31958 .66475 Mdot
.34187 .43658 Mdot
.52827 .71697 Mdot
.33251 .67526 Mdot
.62378 .50113 Mdot
.5879 .53593 Mdot
.29308 .41764 Mdot
.52532 .37063 Mdot
.51063 .72188 Mdot
.33862 .61138 Mdot
.48638 .69446 Mdot
.53803 .34056 Mdot
.57142 .32975 Mdot
.57399 .54687 Mdot
.66193 .59189 Mdot
.36805 .62275 Mdot
.63407 .48452 Mdot
.34901 .61917 Mdot
.19981 .56091 Mdot
.33981 .44552 Mdot
.59417 .56997 Mdot
.56326 .38763 Mdot
.32264 .42007 Mdot
.62809 .54614 Mdot
.41305 .6078 Mdot
.60302 .55701 Mdot
.37662 .61833 Mdot
.73118 .70459 Mdot
.48088 .71249 Mdot
.59321 .45703 Mdot
.72648 .59279 Mdot
.58028 .53508 Mdot
.32311 .60911 Mdot
.64259 .41066 Mdot
.3182 .4426 Mdot
.53898 .3294 Mdot
.31447 .75815 Mdot
.31392 .43041 Mdot
.65077 .51975 Mdot
.5087 .70802 Mdot
.5323 .3103 Mdot
.43743 .41838 Mdot
.47535 .47114 Mdot
.56633 .49718 Mdot
.58591 .58007 Mdot
.64004 .57152 Mdot
.18127 .47454 Mdot
.34931 .63957 Mdot
.5596 .31652 Mdot
.30979 .45604 Mdot
.33061 .43205 Mdot
.32897 .6452 Mdot
.48671 .32748 Mdot
.38764 .32293 Mdot
.48716 .91167 Mdot
.33858 .67555 Mdot
.48071 .72407 Mdot
.51712 .57301 Mdot
.33908 .62122 Mdot
.34766 .65611 Mdot
.31777 .60538 Mdot
.42494 .35339 Mdot
.54099 .30732 Mdot
.63417 .5238 Mdot
.59775 .35006 Mdot
.61951 .54013 Mdot
.56167 .73374 Mdot
.32508 .42305 Mdot
.53816 .33078 Mdot
.51524 .76762 Mdot
.64646 .4657 Mdot
.64751 .55281 Mdot
.55362 .73531 Mdot
.55005 .4934 Mdot
.66543 .66984 Mdot
.58261 .51166 Mdot
.33916 .6458 Mdot
.58121 .26297 Mdot
.61046 .47999 Mdot
.74132 .49737 Mdot
.31018 .4172 Mdot
.42775 .42141 Mdot
.55494 .53961 Mdot
.68659 .495 Mdot
.53448 .30717 Mdot
.55817 .36728 Mdot
.47227 .7044 Mdot
.32339 .2681 Mdot
.30644 .41881 Mdot
.46746 .27223 Mdot
.67628 .52233 Mdot
.24962 .42422 Mdot
.71623 .72257 Mdot
.63187 .54986 Mdot
.38566 .52545 Mdot
.78539 .40027 Mdot
.61129 .55699 Mdot
.67527 .35726 Mdot
.31591 .43528 Mdot
.61033 .76362 Mdot
.60082 .49845 Mdot
.31412 .64399 Mdot
.53435 .32695 Mdot
.58384 .35098 Mdot
.51803 .73236 Mdot
.70628 .75149 Mdot
.22641 .38734 Mdot
.53656 .33385 Mdot
.65851 .55445 Mdot
.30444 .43669 Mdot
.43633 .42087 Mdot
.57915 .48609 Mdot
.23019 .44272 Mdot
.56645 .35079 Mdot
.63206 .481 Mdot
.43462 .32254 Mdot
.46574 .50686 Mdot
.53481 .19257 Mdot
.28208 .42946 Mdot
.47811 .69869 Mdot
.70034 .57312 Mdot
.19717 .53561 Mdot
.61624 .48973 Mdot
.56143 .73919 Mdot
.53004 .38354 Mdot
.49494 .6913 Mdot
.65873 .54637 Mdot
.61426 .54923 Mdot
.49663 .49616 Mdot
.51074 .74528 Mdot
.61506 .54778 Mdot
.69955 .51925 Mdot
.53221 .33899 Mdot
.44963 .40221 Mdot
.55632 .35863 Mdot
.6665 .53624 Mdot
.73622 .68684 Mdot
.57721 .34944 Mdot
.47244 .21662 Mdot
.52895 .65833 Mdot
.31837 .44603 Mdot
.62827 .47539 Mdot
.67928 .54068 Mdot
.4628 .16436 Mdot
.44122 .41997 Mdot
.24351 .69773 Mdot
.37768 .64348 Mdot
.85626 .4435 Mdot
.33295 .68334 Mdot
.50323 .25503 Mdot
.40542 .56768 Mdot
.66029 .48962 Mdot
.71964 .50503 Mdot
.66546 .35464 Mdot
.25237 .42387 Mdot
.62859 .30309 Mdot
.67381 .51863 Mdot
.63508 .5081 Mdot
.33897 .61577 Mdot
.48167 .32982 Mdot
.5712 .61476 Mdot
.49528 .47117 Mdot
.49656 .72655 Mdot
.5475 .34092 Mdot
.63711 .5654 Mdot
.32146 .31599 Mdot
.35831 .60581 Mdot
.76067 .58345 Mdot
.65433 .53605 Mdot
.55538 .60232 Mdot
.47673 .36476 Mdot
.29922 .4277 Mdot
.3587 .6004 Mdot
.34814 .59878 Mdot
.61912 .53633 Mdot
.32989 .44697 Mdot
.59464 .54596 Mdot
.4991 .55029 Mdot
.57167 .49667 Mdot
.48923 .69916 Mdot
.6742 .54081 Mdot
.73985 .59347 Mdot
.60026 .20262 Mdot
.69502 .49333 Mdot
.54758 .29802 Mdot
.35411 .63422 Mdot
.33203 .63721 Mdot
.52759 .33242 Mdot
.33135 .63731 Mdot
.69053 .33468 Mdot
.62173 .33536 Mdot
.49284 .69636 Mdot
.69664 .40871 Mdot
.48518 .71854 Mdot
.42561 .42096 Mdot
.63522 .54391 Mdot
.27598 .52919 Mdot
.33338 .67656 Mdot
.59183 .79356 Mdot
.32133 .42595 Mdot
.44345 .41826 Mdot
.63736 .49801 Mdot
.51035 .76017 Mdot
.32237 .6328 Mdot
.39561 .47843 Mdot
.62173 .52251 Mdot
.5798 .3103 Mdot
.60949 .5548 Mdot
.65874 .58056 Mdot
.44726 .41425 Mdot
.62956 .57445 Mdot
.29613 .42697 Mdot
.56756 .35727 Mdot
.48832 .27611 Mdot
.35126 .65777 Mdot
.66234 .51176 Mdot
.65858 .55345 Mdot
.5394 .36793 Mdot
.66954 .50635 Mdot
.30896 .4513 Mdot
.67794 .84693 Mdot
.51445 .69641 Mdot
.43785 .39164 Mdot
.37664 .2232 Mdot
.61914 .56754 Mdot
.58883 .54697 Mdot
.42501 .46306 Mdot
.77813 .34539 Mdot
.30332 .44229 Mdot
.57835 .57019 Mdot
.33912 .60697 Mdot
.51197 .72218 Mdot
.29447 .40766 Mdot
.6225 .49516 Mdot
.63076 .51401 Mdot
.49838 .69283 Mdot
.55791 .7252 Mdot
.53231 .69851 Mdot
.29832 .44963 Mdot
.61562 .36783 Mdot
.41324 .67198 Mdot
.63907 .53411 Mdot
.4122 .39457 Mdot
.55771 .3233 Mdot
.29457 .4409 Mdot
.75509 .33155 Mdot
.56212 .5467 Mdot
.3478 .44086 Mdot
.30208 .42295 Mdot
.67576 .51095 Mdot
.54358 .3844 Mdot
.58955 .36182 Mdot
.55976 .32202 Mdot
.62536 .74252 Mdot
.19749 .63111 Mdot
.35268 .64022 Mdot
.30896 .43446 Mdot
.37535 .643 Mdot
.49344 .68224 Mdot
.5061 .53823 Mdot
.34733 .60101 Mdot
.57487 .30355 Mdot
.37382 .63946 Mdot
.59456 .54842 Mdot
.33486 .42053 Mdot
.37012 .63702 Mdot
.58302 .5237 Mdot
.69528 .51145 Mdot
.71268 .49901 Mdot
.47448 .68909 Mdot
.47297 .49869 Mdot
.6569 .52333 Mdot
.42169 .40253 Mdot
.64565 .5437 Mdot
.31446 .45159 Mdot
.42774 .59041 Mdot
.6076 .51242 Mdot
.33507 .67662 Mdot
.2211 .65663 Mdot
.31232 .62234 Mdot
.688 .5584 Mdot
.66497 .53292 Mdot
.63633 .5351 Mdot
.64128 .50009 Mdot
.49707 .30279 Mdot
.35425 .43849 Mdot
.6571 .60249 Mdot
.34521 .66993 Mdot
.56248 .34066 Mdot
.58113 .34572 Mdot
.42285 .48268 Mdot
.43739 .42444 Mdot
.33537 .44186 Mdot
.63508 .53379 Mdot
.39582 .48082 Mdot
.472 .45716 Mdot
.42767 .32818 Mdot
.38985 .6191 Mdot
.35771 .61393 Mdot
.55846 .29765 Mdot
.36447 .63034 Mdot
.62505 .49447 Mdot
.64111 .48274 Mdot
.4892 .271 Mdot
.32785 .39986 Mdot
.50919 .72377 Mdot
.66569 .52413 Mdot
.57898 .69108 Mdot
.33444 .61061 Mdot
.33778 .59751 Mdot
.59397 .54264 Mdot
.53475 .37333 Mdot
.62766 .18722 Mdot
.33869 .43458 Mdot
.63537 .35913 Mdot
.55348 .26554 Mdot
.53922 .48249 Mdot
.32422 .43778 Mdot
.39677 .52684 Mdot
.30586 .6236 Mdot
.76685 .6664 Mdot
.56575 .33537 Mdot
.50811 .72301 Mdot
.59269 .50011 Mdot
.57422 .30325 Mdot
.36968 .65828 Mdot
.52188 .32865 Mdot
.56036 .5232 Mdot
.27515 .42958 Mdot
.33418 .62927 Mdot
.29471 .46504 Mdot
.5185 .32514 Mdot
.48346 .71673 Mdot
.59882 .76764 Mdot
.6427 .37754 Mdot
.78445 .3993 Mdot
.61159 .5142 Mdot
.31819 .52798 Mdot
.61761 .51796 Mdot
.59007 .3161 Mdot
.65778 .52976 Mdot
.62792 .46196 Mdot
.30086 .63105 Mdot
.59832 .4918 Mdot
.67505 .53734 Mdot
.73416 .49198 Mdot
.63709 .55296 Mdot
.62897 .50245 Mdot
.57705 .55978 Mdot
.50948 .35456 Mdot
.5913 .49712 Mdot
.57778 .30867 Mdot
.44159 .34383 Mdot
.34577 .65806 Mdot
.49497 .68291 Mdot
.50573 .68602 Mdot
.55493 .75303 Mdot
.5787 .69653 Mdot
.48154 .34042 Mdot
.55432 .35383 Mdot
.31109 .41266 Mdot
.59296 .54419 Mdot
.81777 .46454 Mdot
.71964 .69275 Mdot
.29953 .6408 Mdot
.37167 .63056 Mdot
.6067 .49198 Mdot
.1965 .37649 Mdot
.59768 .4937 Mdot
.48295 .43558 Mdot
.62191 .53762 Mdot
.59703 .57339 Mdot
.35077 .59536 Mdot
.5827 .74438 Mdot
.6116 .51329 Mdot
.53308 .30835 Mdot
.50125 .72313 Mdot
.53957 .53903 Mdot
.69897 .71416 Mdot
.7178 .48827 Mdot
.65982 .62878 Mdot
.60842 .50612 Mdot
.32784 .61622 Mdot
.53901 .30643 Mdot
.4885 .44454 Mdot
.31086 .45015 Mdot
.47765 .4811 Mdot
.67251 .40435 Mdot
.26564 .46764 Mdot
.50469 .72514 Mdot
.3243 .59255 Mdot
.63424 .56819 Mdot
.35424 .6483 Mdot
.572 .56135 Mdot
.4628 .45834 Mdot
.48833 .69738 Mdot
.54125 .29427 Mdot
.29431 .43503 Mdot
.58652 .3167 Mdot
.8029 .46555 Mdot
.72535 .68994 Mdot
.85786 .44658 Mdot
.30807 .648 Mdot
.68208 .2642 Mdot
.54792 .31548 Mdot
.61969 .52367 Mdot
.48295 .91034 Mdot
.55244 .32638 Mdot
.57783 .30709 Mdot
.4331 .4984 Mdot
.5975 .74896 Mdot
.61737 .48244 Mdot
.52425 .33622 Mdot
.3401 .58885 Mdot
.49869 .70398 Mdot
.58513 .52218 Mdot
.55654 .53187 Mdot
.56034 .36639 Mdot
.32174 .63758 Mdot
.56857 .72348 Mdot
.33808 .64077 Mdot
.54215 .30804 Mdot
.32874 .65624 Mdot
.4702 .22666 Mdot
.35229 .60342 Mdot
.67572 .54244 Mdot
.63595 .53334 Mdot
.27253 .49447 Mdot
.57142 .32979 Mdot
.58854 .54728 Mdot
.63655 .51176 Mdot
.55116 .31121 Mdot
.31875 .68481 Mdot
.73373 .30652 Mdot
.59119 .55323 Mdot
.63377 .52859 Mdot
.50891 .69123 Mdot
.48955 .51853 Mdot
.4755 .43353 Mdot
.58237 .52998 Mdot
.48227 .7231 Mdot
.55438 .29526 Mdot
.64484 .54532 Mdot
.58198 .74637 Mdot
.34269 .67971 Mdot
.60161 .50601 Mdot
.4312 .41941 Mdot
.61826 .55348 Mdot
.61717 .1889 Mdot
.65148 .50397 Mdot
.56095 .31227 Mdot
.53843 .32093 Mdot
.36557 .58035 Mdot
.55841 .33841 Mdot
.44527 .40155 Mdot
.31656 .41923 Mdot
.57108 .21963 Mdot
.44557 .40589 Mdot
.63443 .57634 Mdot
.74424 .71845 Mdot
.55749 .52795 Mdot
.57271 .49934 Mdot
.57568 .80678 Mdot
.44011 .39457 Mdot
.55062 .32011 Mdot
.34726 .31574 Mdot
.63276 .48599 Mdot
.33752 .4397 Mdot
.5883 .48677 Mdot
.6022 .50565 Mdot
.66166 .46646 Mdot
.61838 .34552 Mdot
.33656 .41465 Mdot
.72065 .55134 Mdot
.5852 .5225 Mdot
.77864 .3473 Mdot
.64939 .56294 Mdot
.52176 .7187 Mdot
.54388 .35355 Mdot
.3639 .63791 Mdot
.49262 .70047 Mdot
.62699 .56845 Mdot
.50952 .7166 Mdot
.35284 .64647 Mdot
.28587 .42293 Mdot
.67277 .54709 Mdot
.47523 .72664 Mdot
.50637 .72685 Mdot
.60262 .5335 Mdot
.53606 .33054 Mdot
.63314 .59409 Mdot
.64233 .5471 Mdot
.63038 .49795 Mdot
.52874 .33564 Mdot
.5074 .85929 Mdot
.63027 .50674 Mdot
.39345 .52673 Mdot
.55944 .28498 Mdot
.44847 .40356 Mdot
.35581 .61697 Mdot
.69785 .52554 Mdot
.33216 .43233 Mdot
.31783 .42132 Mdot
.31625 .67019 Mdot
.54971 .36623 Mdot
.33125 .63192 Mdot
.68543 .48194 Mdot
.63759 .48235 Mdot
.59371 .4996 Mdot
.31259 .75751 Mdot
.43596 .22748 Mdot
.57276 .31897 Mdot
.31154 .61898 Mdot
.48464 .47962 Mdot
.33759 .42668 Mdot
.3373 .59469 Mdot
.5973 .3219 Mdot
.53735 .36043 Mdot
.52634 .32994 Mdot
.49367 .73015 Mdot
.33952 .62925 Mdot
.59886 .31668 Mdot
.58554 .36602 Mdot
.59614 .53645 Mdot
.58774 .52012 Mdot
.51305 .32507 Mdot
.28182 .63846 Mdot
.48402 .70935 Mdot
.32214 .61887 Mdot
.57516 .14917 Mdot
.33889 .43548 Mdot
.73625 .49438 Mdot
.58155 .52737 Mdot
.27779 .80604 Mdot
.59235 .49772 Mdot
.65654 .55711 Mdot
.52184 .31479 Mdot
.52329 .74025 Mdot
.50032 .70705 Mdot
.54659 .31577 Mdot
.56562 .37449 Mdot
.51141 .73078 Mdot
.42399 .50635 Mdot
.65746 .21591 Mdot
.48592 .45533 Mdot
.56621 .31078 Mdot
.64611 .37477 Mdot
.29239 .41025 Mdot
.56103 .28864 Mdot
.33411 .46396 Mdot
.34542 .65959 Mdot
.36305 .61233 Mdot
.2951 .41483 Mdot
.62883 .50492 Mdot
.31127 .65011 Mdot
.6968 .4911 Mdot
.49136 .25138 Mdot
.23488 .4404 Mdot
.83583 .48178 Mdot
.68111 .53261 Mdot
.57747 .62375 Mdot
.38021 .37483 Mdot
.6222 .57446 Mdot
.72019 .58251 Mdot
.51036 .72071 Mdot
.55604 .28633 Mdot
.31055 .40326 Mdot
.48906 .18928 Mdot
.63784 .53424 Mdot
.55699 .30535 Mdot
.33961 .42498 Mdot
.46365 .23868 Mdot
.40994 .54202 Mdot
.60423 .54728 Mdot
.53008 .91115 Mdot
.51931 .33367 Mdot
.36372 .63757 Mdot
.72938 .4628 Mdot
.579 .30113 Mdot
.38824 .67861 Mdot
.37842 .61532 Mdot
.5102 .45465 Mdot
.52494 .34447 Mdot
.52866 .69069 Mdot
.54389 .34404 Mdot
.50247 .73916 Mdot
.56124 .37886 Mdot
.32473 .64801 Mdot
.65294 .54755 Mdot
.32853 .64907 Mdot
.52441 .71341 Mdot
.30956 .65737 Mdot
.3108 .40333 Mdot
.43314 .39374 Mdot
.32211 .41714 Mdot
.51122 .55125 Mdot
.73566 .33245 Mdot
.28821 .44059 Mdot
.38468 .50135 Mdot
.62208 .55833 Mdot
.51918 .36547 Mdot
.36178 .64426 Mdot
.30478 .66722 Mdot
.47754 .4946 Mdot
.53293 .31765 Mdot
.31985 .64583 Mdot
.64465 .38425 Mdot
.31894 .79682 Mdot
.64552 .47196 Mdot
.18749 .60618 Mdot
.55499 .31034 Mdot
.30727 .61898 Mdot
.48617 .43238 Mdot
.57736 .35597 Mdot
.36952 .62948 Mdot
.29115 .43304 Mdot
.33025 .43647 Mdot
.67123 .50835 Mdot
.27015 .42986 Mdot
.32759 .6052 Mdot
.77786 .34196 Mdot
.53702 .34857 Mdot
.42033 .22091 Mdot
.5195 .71149 Mdot
.34968 .65429 Mdot
.6076 .48595 Mdot
.56996 .38777 Mdot
.36802 .65211 Mdot
.21015 .38949 Mdot
.51788 .14933 Mdot
.31925 .64559 Mdot
.54484 .35419 Mdot
.56244 .34548 Mdot
.68755 .48693 Mdot
.48951 .48036 Mdot
.31988 .63669 Mdot
.27417 .52846 Mdot
.57976 .67375 Mdot
.4415 .40947 Mdot
.78899 .59905 Mdot
.61243 .512 Mdot
.60752 .50603 Mdot
.30288 .45116 Mdot
.64416 .55507 Mdot
.57678 .36987 Mdot
.58871 .50173 Mdot
.28459 .45056 Mdot
.30884 .66153 Mdot
.63709 .54064 Mdot
.51486 .7198 Mdot
.27951 .43491 Mdot
.30789 .45852 Mdot
.33528 .65995 Mdot
.53248 .34641 Mdot
.32995 .33222 Mdot
.33775 .6387 Mdot
.6194 .49809 Mdot
.43026 .39892 Mdot
.57785 .51985 Mdot
.28501 .4995 Mdot
.58999 .3307 Mdot
.36421 .63064 Mdot
.51802 .31138 Mdot
.30615 .43083 Mdot
.29664 .64615 Mdot
.63741 .56952 Mdot
.36063 .61353 Mdot
.37842 .53692 Mdot
.37704 .72762 Mdot
.57807 .37165 Mdot
.41433 .59571 Mdot
.55134 .3683 Mdot
.44144 .41116 Mdot
.63549 .70745 Mdot
.48864 .716 Mdot
.32417 .61289 Mdot
.46922 .21661 Mdot
.3593 .65232 Mdot
.63321 .55303 Mdot
.62771 .51477 Mdot
.34122 .61557 Mdot
.48479 .7215 Mdot
.54674 .77907 Mdot
.47057 .67376 Mdot
.57012 .35128 Mdot
.42985 .56639 Mdot
.60419 .16372 Mdot
.386 .64598 Mdot
.30678 .41296 Mdot
.67802 .61597 Mdot
.61354 .56098 Mdot
.33901 .41943 Mdot
.33142 .45035 Mdot
.52447 .72888 Mdot
.35136 .65583 Mdot
.58067 .29237 Mdot
.30453 .40634 Mdot
.58518 .38316 Mdot
.57308 .73724 Mdot
.57264 .56573 Mdot
.56938 .4445 Mdot
.67018 .5595 Mdot
.46559 .50635 Mdot
.28021 .44638 Mdot
.6486 .52184 Mdot
.71089 .55974 Mdot
.30057 .44481 Mdot
.52194 .7346 Mdot
.58963 .39577 Mdot
.31945 .65177 Mdot
.29642 .79996 Mdot
.67334 .54527 Mdot
.64873 .5475 Mdot
.31531 .44867 Mdot
.76582 .50781 Mdot
.57439 .3165 Mdot
.53494 .34985 Mdot
.34965 .63879 Mdot
.44866 .46441 Mdot
.66847 .50502 Mdot
.65834 .56153 Mdot
.31333 .64904 Mdot
.42225 .40285 Mdot
.82591 .55533 Mdot
.63771 .52453 Mdot
.31902 .43682 Mdot
.35904 .52877 Mdot
.27734 .44034 Mdot
.64206 .58026 Mdot
.62877 .55186 Mdot
.65552 .56679 Mdot
.68469 .53174 Mdot
.30449 .40918 Mdot
.63733 .57153 Mdot
.58343 .57986 Mdot
.55429 .32089 Mdot
.61079 .50732 Mdot
.58173 .67284 Mdot
.64023 .52834 Mdot
.5151 .7176 Mdot
.4672 .43981 Mdot
.65789 .50901 Mdot
.61133 .50602 Mdot
.57649 .67312 Mdot
.66118 .54619 Mdot
.33934 .42225 Mdot
.5662 .33952 Mdot
.30494 .43201 Mdot
.30535 .41604 Mdot
.37138 .64561 Mdot
.50106 .7408 Mdot
.69257 .51267 Mdot
.50702 .73332 Mdot
.66535 .47236 Mdot
.55389 .52748 Mdot
.49966 .53249 Mdot
.48232 .43751 Mdot
.48907 .68164 Mdot
.64818 .56624 Mdot
.34886 .64505 Mdot
.36437 .62668 Mdot
.41922 .58814 Mdot
.58949 .4822 Mdot
.29983 .4051 Mdot
.2882 .42634 Mdot
.46316 .67378 Mdot
.4486 .66074 Mdot
.50863 .72761 Mdot
.52185 .60726 Mdot
.59946 .57845 Mdot
.64259 .50615 Mdot
.55992 .5096 Mdot
.37787 .63435 Mdot
.4334 .39289 Mdot
.32046 .66905 Mdot
.46962 .40102 Mdot
.28728 .41116 Mdot
.68087 .53238 Mdot
.22358 .34242 Mdot
.57575 .34804 Mdot
.56692 .33927 Mdot
.28527 .45161 Mdot
.31385 .62009 Mdot
.57464 .49403 Mdot
.21975 .69768 Mdot
.58052 .35931 Mdot
.48949 .68595 Mdot
.66899 .53659 Mdot
.34131 .65855 Mdot
.56227 .36135 Mdot
.47047 .71553 Mdot
.68093 .54056 Mdot
.36809 .5996 Mdot
.64995 .52821 Mdot
.69403 .38001 Mdot
.54481 .32459 Mdot
.51119 .49891 Mdot
.51088 .34307 Mdot
.3143 .411 Mdot
.30094 .43869 Mdot
.62804 .54725 Mdot
.25407 .74724 Mdot
.60698 .32023 Mdot
.34895 .43502 Mdot
.47165 .71496 Mdot
.42571 .39509 Mdot
.47478 .72136 Mdot
.34751 .61875 Mdot
.50097 .72422 Mdot
.36693 .65261 Mdot
.27935 .64905 Mdot
.57918 .28356 Mdot
.50061 .69411 Mdot
.77455 .51978 Mdot
.6428 .48285 Mdot
.52581 .72056 Mdot
.59997 .49629 Mdot
.6607 .46791 Mdot
.31711 .65743 Mdot
.4982 .73073 Mdot
.60962 .53824 Mdot
.37871 .2184 Mdot
.29692 .42808 Mdot
.30706 .40404 Mdot
.64067 .4833 Mdot
.31488 .60921 Mdot
.56803 .37644 Mdot
.4726 .53043 Mdot
.44734 .39578 Mdot
.66009 .56 Mdot
.66871 .56367 Mdot
.51756 .33332 Mdot
.56192 .30069 Mdot
.62633 .54827 Mdot
.63143 .36956 Mdot
.63083 .5692 Mdot
.32867 .4391 Mdot
.57201 .35008 Mdot
.56534 .34379 Mdot
.33622 .60274 Mdot
.55305 .36605 Mdot
.63952 .60064 Mdot
.26729 .4083 Mdot
.56952 .52029 Mdot
.30939 .43053 Mdot
.31148 .58898 Mdot
.34078 .66698 Mdot
.46657 .21443 Mdot
.55118 .36509 Mdot
.58729 .55067 Mdot
.58144 .34397 Mdot
.51487 .70067 Mdot
.57196 .33307 Mdot
.51614 .34911 Mdot
.6694 .51184 Mdot
.61488 .54406 Mdot
.42448 .40335 Mdot
.48574 .48783 Mdot
.5427 .33069 Mdot
.61189 .5686 Mdot
.57842 .53946 Mdot
.62439 .51703 Mdot
.4916 .53497 Mdot
.52704 .30394 Mdot
.71203 .47696 Mdot
.29596 .49012 Mdot
.53879 .33371 Mdot
.55074 .17174 Mdot
.4194 .41285 Mdot
.43542 .42482 Mdot
.32323 .4615 Mdot
.63406 .52499 Mdot
.32913 .63745 Mdot
.60692 .50477 Mdot
.60363 .47331 Mdot
.66312 .51374 Mdot
.49878 .69189 Mdot
.65619 .49672 Mdot
.43306 .41411 Mdot
.33625 .6447 Mdot
.61215 .56701 Mdot
.63287 .53753 Mdot
.43006 .42351 Mdot
.51096 .3305 Mdot
.53981 .36173 Mdot
.40715 .39185 Mdot
.52295 .72786 Mdot
.28546 .44528 Mdot
.61542 .4988 Mdot
.34891 .64165 Mdot
.32998 .6447 Mdot
.58334 .31252 Mdot
.31416 .6389 Mdot
.284 .44636 Mdot
.649 .56146 Mdot
.31302 .41069 Mdot
.49917 .69194 Mdot
.54329 .35314 Mdot
.62338 .49373 Mdot
.5985 .53776 Mdot
.53858 .32097 Mdot
.61767 .55654 Mdot
.49988 .68997 Mdot
.37351 .6175 Mdot
.57532 .32943 Mdot
.31575 .41994 Mdot
.34307 .60118 Mdot
.59059 .54302 Mdot
.42381 .15007 Mdot
.64313 .55587 Mdot
.664 .55878 Mdot
.52548 .24442 Mdot
.58295 .55659 Mdot
.35431 .65641 Mdot
.57753 .35169 Mdot
.66436 .57103 Mdot
.57774 .67721 Mdot
.54201 .72222 Mdot
.38554 .63299 Mdot
.67021 .53989 Mdot
.52486 .18664 Mdot
.58132 .53953 Mdot
.48478 .21739 Mdot
.49963 .53132 Mdot
.19372 .47591 Mdot
.57011 .44417 Mdot
.34897 .43696 Mdot
.42443 .40023 Mdot
.35063 .66295 Mdot
.7664 .46434 Mdot
.63104 .55796 Mdot
.78569 .3906 Mdot
.61955 .49414 Mdot
.32579 .43724 Mdot
.71432 .58369 Mdot
.31941 .62316 Mdot
.78507 .59829 Mdot
.62092 .50874 Mdot
.52041 .32841 Mdot
.29547 .63466 Mdot
.41842 .40357 Mdot
.61406 .53681 Mdot
.51758 .72592 Mdot
.5226 .67594 Mdot
.64514 .59977 Mdot
.30828 .42841 Mdot
.64027 .50942 Mdot
.70246 .51434 Mdot
.32937 .79308 Mdot
.55999 .31947 Mdot
.29542 .42182 Mdot
.50448 .6415 Mdot
.62565 .51819 Mdot
.5365 .35916 Mdot
.56462 .33711 Mdot
.51162 .73634 Mdot
.30952 .37994 Mdot
.5015 .78233 Mdot
.26345 .27677 Mdot
.8063 .42952 Mdot
.37795 .6285 Mdot
.52874 .39638 Mdot
.60139 .51753 Mdot
.7277 .68938 Mdot
.30985 .41529 Mdot
.65236 .54636 Mdot
.78433 .4188 Mdot
.56508 .32256 Mdot
.6453 .52459 Mdot
.48493 .70865 Mdot
.34687 .35465 Mdot
.6577 .40689 Mdot
.44207 .16424 Mdot
.34387 .58827 Mdot
.59836 .48489 Mdot
.60423 .59484 Mdot
.44791 .4013 Mdot
.64951 .57778 Mdot
.35963 .64653 Mdot
.32886 .52573 Mdot
.47863 .70571 Mdot
.57415 .35087 Mdot
.41779 .41002 Mdot
.61778 .49403 Mdot
.56653 .54564 Mdot
.48402 .68923 Mdot
.61646 .52708 Mdot
.71951 .45745 Mdot
.41887 .42447 Mdot
.35398 .60366 Mdot
.52213 .32551 Mdot
.66594 .56353 Mdot
.42539 .39663 Mdot
.66242 .50642 Mdot
.72713 .60377 Mdot
.66618 .52819 Mdot
.55359 .23391 Mdot
.53392 .32789 Mdot
.30715 .42334 Mdot
.65833 .49651 Mdot
.64665 .53391 Mdot
.41627 .67708 Mdot
.58139 .48826 Mdot
.64498 .50302 Mdot
.58446 .3095 Mdot
.5779 .34584 Mdot
.55803 .30376 Mdot
.34154 .60312 Mdot
.48972 .45775 Mdot
.3243 .42941 Mdot
.56269 .50563 Mdot
.298 .40683 Mdot
.57883 .43884 Mdot
.475 .70069 Mdot
.4518 .20912 Mdot
.63621 .56327 Mdot
.52879 .3217 Mdot
.68931 .24818 Mdot
.55768 .29556 Mdot
.32391 .47699 Mdot
.30828 .41774 Mdot
.54966 .32874 Mdot
.66359 .54625 Mdot
.49622 .47509 Mdot
.40487 .1686 Mdot
.33677 .42444 Mdot
.57327 .50112 Mdot
.35056 .58592 Mdot
.31954 .67509 Mdot
.57788 .18767 Mdot
.32968 .41606 Mdot
.37535 .37495 Mdot
.59213 .55518 Mdot
.56997 .35861 Mdot
.28363 .43643 Mdot
.34478 .43324 Mdot
.31272 .6424 Mdot
.6 .54558 Mdot
.64682 .53173 Mdot
.42796 .4192 Mdot
.29114 .41396 Mdot
.58071 .45543 Mdot
.6068 .54983 Mdot
.49784 .2615 Mdot
.59501 .31525 Mdot
.51735 .85823 Mdot
.72322 .53059 Mdot
.78385 .4119 Mdot
.34603 .56411 Mdot
.57695 .32703 Mdot
.6262 .50446 Mdot
.56596 .50325 Mdot
.3737 .61361 Mdot
.64911 .55897 Mdot
.30413 .63212 Mdot
.32093 .41264 Mdot
.45833 .20128 Mdot
.39886 .4896 Mdot
.27791 .39553 Mdot
.64132 .55393 Mdot
.65015 .40468 Mdot
.50071 .69613 Mdot
.33424 .40314 Mdot
.57179 .30851 Mdot
.62586 .57985 Mdot
.37925 .63972 Mdot
.3396 .60456 Mdot
.56304 .33018 Mdot
.44729 .3633 Mdot
.47383 .21463 Mdot
.6849 .53762 Mdot
.35296 .61742 Mdot
.39548 .44506 Mdot
.62331 .28931 Mdot
.32006 .45995 Mdot
.47912 .70251 Mdot
.35026 .66128 Mdot
.27681 .41194 Mdot
.65044 .46518 Mdot
.55411 .33409 Mdot
.51994 .34112 Mdot
.40797 .64357 Mdot
.32134 .6422 Mdot
.49346 .7099 Mdot
.41912 .57963 Mdot
.42633 .57933 Mdot
.48683 .69948 Mdot
.29949 .63969 Mdot
.5796 .33388 Mdot
.5508 .30649 Mdot
.56505 .34031 Mdot
.74157 .49755 Mdot
.58707 .34199 Mdot
.63091 .7813 Mdot
.63569 .57973 Mdot
.63671 .34721 Mdot
.6079 .57203 Mdot
.32182 .40625 Mdot
.54325 .32492 Mdot
.50095 .52374 Mdot
.59135 .57256 Mdot
.4238 .16858 Mdot
.65898 .524 Mdot
.37465 .52754 Mdot
.63338 .52633 Mdot
.70715 .42745 Mdot
.55973 .28589 Mdot
.64109 .56922 Mdot
.25732 .41753 Mdot
.51249 .71539 Mdot
.57829 .27939 Mdot
.64416 .50385 Mdot
.44061 .32147 Mdot
.5991 .49717 Mdot
.50674 .21146 Mdot
.34447 .70461 Mdot
.51846 .6887 Mdot
.57456 .53623 Mdot
.36039 .66475 Mdot
.63242 .63426 Mdot
.64407 .3613 Mdot
.3361 .42357 Mdot
.64598 .39777 Mdot
.3129 .63213 Mdot
.72146 .57807 Mdot
.61994 .58711 Mdot
.47921 .71312 Mdot
.59369 .39291 Mdot
.32671 .44178 Mdot
.62885 .55908 Mdot
.6249 .50785 Mdot
.22958 .45764 Mdot
.6532 .37219 Mdot
.54487 .51033 Mdot
.47746 .68874 Mdot
.66186 .4031 Mdot
.65636 .51012 Mdot
.38524 .63026 Mdot
.57302 .35972 Mdot
.67819 .60499 Mdot
.75703 .53158 Mdot
.61711 .56971 Mdot
.55398 .32767 Mdot
.5478 .36557 Mdot
.72384 .26652 Mdot
.4752 .70833 Mdot
.66503 .52678 Mdot
.40161 .65818 Mdot
.62054 .49683 Mdot
.32742 .43264 Mdot
.60611 .58251 Mdot
.33363 .66587 Mdot
.48962 .42309 Mdot
.33841 .60383 Mdot
.62067 .53146 Mdot
.54409 .34733 Mdot
.31784 .44673 Mdot
.19004 .52715 Mdot
.37411 .41075 Mdot
.62809 .78162 Mdot
.52241 .67383 Mdot
.51362 .72633 Mdot
.4828 .73089 Mdot
.36422 .42161 Mdot
.66779 .54429 Mdot
.46073 .50947 Mdot
.63604 .46879 Mdot
.6307 .52189 Mdot
.66786 .52534 Mdot
.37811 .41589 Mdot
.30792 .41877 Mdot
.32735 .65353 Mdot
.62598 .54933 Mdot
.61202 .56902 Mdot
.54305 .33815 Mdot
.50587 .72732 Mdot
.36865 .61256 Mdot
.52307 .71605 Mdot
.34077 .64544 Mdot
.61368 .18622 Mdot
.55987 .54632 Mdot
.51208 .7132 Mdot
.27696 .43522 Mdot
.54241 .30561 Mdot
.43571 .42256 Mdot
.34546 .61931 Mdot
.31917 .62489 Mdot
.63287 .57289 Mdot
.5443 .35746 Mdot
.53983 .35901 Mdot
.51134 .73035 Mdot
.28708 .43037 Mdot
.69031 .53812 Mdot
.61209 .54669 Mdot
.19071 .55735 Mdot
.36946 .60878 Mdot
.65258 .39344 Mdot
.54854 .24127 Mdot
.6667 .5486 Mdot
.53399 .35514 Mdot
.64162 .54152 Mdot
.37771 .46394 Mdot
.55647 .30206 Mdot
.58876 .56429 Mdot
.61165 .4581 Mdot
.37746 .63321 Mdot
.80165 .35017 Mdot
.68712 .50864 Mdot
.25452 .44077 Mdot
.60276 .5259 Mdot
.85559 .41355 Mdot
.70472 .26068 Mdot
.6239 .49118 Mdot
.6832 .52761 Mdot
.27926 .25388 Mdot
.5804 .52632 Mdot
.42937 .41689 Mdot
.60074 .47431 Mdot
.53404 .35729 Mdot
.39887 .54122 Mdot
.47075 .50079 Mdot
.47772 .72056 Mdot
.35032 .6393 Mdot
.59026 .74679 Mdot
.51424 .73915 Mdot
.55914 .31147 Mdot
.56411 .54431 Mdot
.556 .24468 Mdot
.31608 .67892 Mdot
.66606 .57607 Mdot
.32722 .43444 Mdot
.46987 .49984 Mdot
.32722 .67035 Mdot
.31577 .41881 Mdot
.58097 .54175 Mdot
.28914 .72472 Mdot
.24636 .43827 Mdot
.73423 .26867 Mdot
.30179 .45021 Mdot
.29977 .42796 Mdot
.49784 .46393 Mdot
.47835 .72154 Mdot
.25028 .49498 Mdot
.60993 .60299 Mdot
.33855 .43191 Mdot
.68551 .66459 Mdot
.3614 .59869 Mdot
.4598 .46282 Mdot
.56306 .28787 Mdot
.55509 .53791 Mdot
.66269 .53957 Mdot
.29234 .44011 Mdot
.51105 .37913 Mdot
.46362 .6449 Mdot
.3292 .41907 Mdot
.61573 .59578 Mdot
.45918 .45394 Mdot
.43224 .39611 Mdot
.42005 .416 Mdot
.47016 .70899 Mdot
.40065 .76758 Mdot
.53124 .33003 Mdot
.49467 .68574 Mdot
.52035 .49741 Mdot
.65399 .51781 Mdot
.29383 .41085 Mdot
.41968 .41982 Mdot
.31741 .42274 Mdot
.50424 .7051 Mdot
.47786 .69401 Mdot
.55538 .32049 Mdot
.57638 .31783 Mdot
.59369 .26262 Mdot
.61324 .65448 Mdot
.59902 .51082 Mdot
.74702 .32702 Mdot
.56377 .30199 Mdot
.76663 .48512 Mdot
.49493 .73286 Mdot
.4934 .72541 Mdot
.66622 .32549 Mdot
.59161 .5377 Mdot
.36243 .52902 Mdot
.65507 .50733 Mdot
.67209 .68923 Mdot
.61572 .49354 Mdot
.31353 .64405 Mdot
.61604 .51142 Mdot
.32729 .31972 Mdot
.60814 .56364 Mdot
.66883 .52325 Mdot
.34093 .62444 Mdot
.69294 .52893 Mdot
.32487 .66499 Mdot
.63232 .5046 Mdot
.51406 .74955 Mdot
.34873 .64119 Mdot
.49169 .7476 Mdot
.40755 .52301 Mdot
.42507 .40901 Mdot
.48149 .72813 Mdot
.51809 .72239 Mdot
.56672 .72035 Mdot
.58066 .31746 Mdot
.73711 .55423 Mdot
.66751 .5388 Mdot
.33559 .5974 Mdot
.27929 .4275 Mdot
.61851 .57049 Mdot
.58802 .50117 Mdot
.69564 .51789 Mdot
.55392 .32353 Mdot
.30247 .62835 Mdot
.50727 .71208 Mdot
.36427 .62327 Mdot
.50201 .74935 Mdot
.35279 .66621 Mdot
.67785 .49339 Mdot
.65828 .46903 Mdot
.59068 .58474 Mdot
.76967 .38251 Mdot
.74949 .70384 Mdot
.55861 .33313 Mdot
.43374 .40088 Mdot
.47456 .70083 Mdot
.43239 .56925 Mdot
.5285 .33136 Mdot
.31971 .62618 Mdot
.65022 .5283 Mdot
.59282 .59065 Mdot
.554 .55914 Mdot
.59604 .36328 Mdot
.46128 .71931 Mdot
.35071 .62731 Mdot
.44294 .40209 Mdot
.48264 .45628 Mdot
.5154 .28968 Mdot
.50861 .54272 Mdot
.64409 .53754 Mdot
.51381 .73013 Mdot
.56249 .36124 Mdot
.27679 .50666 Mdot
.29212 .43675 Mdot
.4877 .48383 Mdot
.64385 .55388 Mdot
.42827 .37361 Mdot
.54502 .34757 Mdot
.48338 .71534 Mdot
.29332 .44115 Mdot
.47863 .719 Mdot
.41625 .40157 Mdot
.4174 .3871 Mdot
.61338 .53337 Mdot
.64997 .50339 Mdot
.28609 .41307 Mdot
.53175 .33295 Mdot
.53044 .74444 Mdot
.22818 .44925 Mdot
.34574 .61701 Mdot
.43717 .4765 Mdot
.56941 .35536 Mdot
.38355 .38959 Mdot
.3556 .61227 Mdot
.27792 .41314 Mdot
.46548 .51008 Mdot
.29188 .4539 Mdot
.66192 .51591 Mdot
.5586 .35352 Mdot
.33326 .4175 Mdot
.19952 .55848 Mdot
.54552 .20879 Mdot
.60492 .35961 Mdot
.61981 .55013 Mdot
.45203 .20623 Mdot
.4108 .33957 Mdot
.56058 .41038 Mdot
.30742 .40668 Mdot
.63358 .54832 Mdot
.68435 .53952 Mdot
.62 .50935 Mdot
.29484 .43056 Mdot
.25253 .39228 Mdot
.32992 .61185 Mdot
.64629 .51984 Mdot
.51902 .70939 Mdot
.33143 .66393 Mdot
.33544 .67767 Mdot
.35338 .66013 Mdot
.56468 .30149 Mdot
.56555 .551 Mdot
.54415 .56609 Mdot
.78192 .31611 Mdot
.30277 .42537 Mdot
.42539 .40922 Mdot
.66836 .5561 Mdot
.60552 .77862 Mdot
.54857 .30517 Mdot
.33832 .61928 Mdot
.65066 .54632 Mdot
.37599 .69046 Mdot
.41139 .42021 Mdot
.3398 .63225 Mdot
.56923 .30776 Mdot
.56092 .41159 Mdot
.6478 .56022 Mdot
.6003 .52576 Mdot
.54278 .31203 Mdot
.38465 .35834 Mdot
.47955 .45359 Mdot
.63942 .54032 Mdot
.30959 .42065 Mdot
.29117 .78318 Mdot
.58659 .55655 Mdot
.54364 .38864 Mdot
.43451 .39187 Mdot
.50084 .28493 Mdot
.63614 .38435 Mdot
.63155 .47423 Mdot
.40684 .19587 Mdot
.58143 .79032 Mdot
.47573 .18914 Mdot
.67076 .70122 Mdot
.23188 .42967 Mdot
.66271 .206 Mdot
.25681 .42222 Mdot
.69971 .41251 Mdot
.20073 .38873 Mdot
.39349 .3705 Mdot
.34509 .71843 Mdot
.21325 .52306 Mdot
.27735 .69775 Mdot
.8046 .58333 Mdot
.34767 .67086 Mdot
.7036 .68626 Mdot
.64122 .49782 Mdot
.38821 .34741 Mdot
.69225 .4235 Mdot
.70154 .75688 Mdot
.4522 .21463 Mdot
.3977 .66799 Mdot
.39261 .1621 Mdot
.45858 .22928 Mdot
.61162 .24353 Mdot
.75858 .56137 Mdot
.4384 .78896 Mdot
.42834 .58135 Mdot
.59245 .7574 Mdot
.64337 .40945 Mdot
.33092 .30303 Mdot
.25414 .41813 Mdot
.69682 .28958 Mdot
.36057 .81263 Mdot
.36031 .63549 Mdot
.57115 .36193 Mdot
.24044 .49479 Mdot
.5967 .23511 Mdot
.27996 .47236 Mdot
.40694 .1956 Mdot
.50926 .24765 Mdot
.70393 .42382 Mdot
.51354 .49832 Mdot
.69422 .37093 Mdot
.5287 .791 Mdot
.76059 .61726 Mdot
.57095 .38246 Mdot
.22002 .55319 Mdot
.4312 .58103 Mdot
.54132 .75204 Mdot
.72822 .45049 Mdot
.4679 .70931 Mdot
.47663 .73184 Mdot
.56493 .30556 Mdot
.62066 .27865 Mdot
.42862 .42716 Mdot
.52288 .49569 Mdot
.37818 .64763 Mdot
.38062 .46777 Mdot
.35268 .34959 Mdot
.42598 .34581 Mdot
.82897 .42004 Mdot
.45547 .14915 Mdot
.61253 .68264 Mdot
.31663 .51899 Mdot
.28856 .47226 Mdot
.58405 .76634 Mdot
.53771 .56816 Mdot
.6401 .66527 Mdot
.73538 .59722 Mdot
.31855 .19881 Mdot
.45581 .31299 Mdot
.38338 .15883 Mdot
.54676 .37769 Mdot
.70332 .57319 Mdot
.33769 .50923 Mdot
.8052 .45042 Mdot
.56724 .68053 Mdot
.45282 .1551 Mdot
.5231 .68952 Mdot
.56652 .28458 Mdot
.39416 .37158 Mdot
.71307 .45234 Mdot
.50237 .77047 Mdot
.50344 .66098 Mdot
.68099 .60295 Mdot
.31495 .19043 Mdot
.39493 .19969 Mdot
.65936 .22857 Mdot
.49356 .27047 Mdot
.35518 .68616 Mdot
.3421 .67697 Mdot
.34636 .43024 Mdot
.57607 .20454 Mdot
.55423 .34996 Mdot
.79107 .32263 Mdot
.54771 .21694 Mdot
.63873 .63591 Mdot
.29435 .20734 Mdot
.8209 .54832 Mdot
.63483 .35103 Mdot
.70102 .73107 Mdot
.23685 .68189 Mdot
.53151 .56472 Mdot
.36784 .38981 Mdot
.37323 .5966 Mdot
.55226 .23024 Mdot
.56386 .19629 Mdot
.70219 .65307 Mdot
.24305 .31824 Mdot
.52533 .49364 Mdot
.35149 .57236 Mdot
.60453 .31813 Mdot
.34151 .73081 Mdot
.54085 .64769 Mdot
.39248 .15706 Mdot
.67004 .41076 Mdot
.27176 .74999 Mdot
.6479 .70905 Mdot
.76416 .50839 Mdot
.3962 .21558 Mdot
.28139 .68133 Mdot
.63346 .64784 Mdot
.44698 .33308 Mdot
.57808 .50016 Mdot
.52833 .60487 Mdot
.72597 .58386 Mdot
.45726 .74258 Mdot
.49199 .45288 Mdot
.45067 .27885 Mdot
.61816 .71446 Mdot
.22179 .41129 Mdot
.74822 .53557 Mdot
.53016 .30548 Mdot
.61909 .66563 Mdot
.64218 .6924 Mdot
.48063 .28312 Mdot
.50815 .64115 Mdot
.64934 .22064 Mdot
.483 .64191 Mdot
.62499 .47216 Mdot
.69774 .40581 Mdot
.64536 .41312 Mdot
.66393 .67455 Mdot
.66955 .49465 Mdot
.8164 .39444 Mdot
.5025 .26728 Mdot
.7511 .3657 Mdot
.59432 .71586 Mdot
.76364 .37596 Mdot
.57041 .21974 Mdot
.33643 .50502 Mdot
.35587 .38359 Mdot
.53999 .39858 Mdot
.31934 .18887 Mdot
.32781 .65917 Mdot
.6791 .6612 Mdot
.25255 .4298 Mdot
.19561 .55049 Mdot
.22064 .45726 Mdot
.47001 .64239 Mdot
.59011 .2089 Mdot
.42381 .35679 Mdot
.28851 .63979 Mdot
.31795 .2917 Mdot
.40488 .44026 Mdot
.74118 .32814 Mdot
.70829 .54271 Mdot
.70229 .61796 Mdot
.49872 .68944 Mdot
.77752 .45763 Mdot
.30532 .49562 Mdot
.44076 .72225 Mdot
.64271 .47756 Mdot
.41429 .62551 Mdot
.44278 .41115 Mdot
.46651 .48908 Mdot
.61066 .18292 Mdot
.71264 .52109 Mdot
.81427 .55706 Mdot
.41157 .35135 Mdot
.45985 .50325 Mdot
.55678 .72907 Mdot
.49075 .3352 Mdot
.36767 .16253 Mdot
.60163 .20283 Mdot
.40241 .32436 Mdot
.44676 .20343 Mdot
.85085 .56623 Mdot
.19827 .46164 Mdot
.81666 .4748 Mdot
.25239 .42884 Mdot
.66639 .85142 Mdot
.36192 .61738 Mdot
.74135 .68461 Mdot
.80208 .45041 Mdot
.40052 .68279 Mdot
.5951 .23463 Mdot
.66452 .42734 Mdot
.54594 .67748 Mdot
.51273 .33962 Mdot
.66353 .48692 Mdot
.48164 .16291 Mdot
.3327 .18428 Mdot
.47266 .16126 Mdot
.45152 .38245 Mdot
.48862 .17678 Mdot
.28026 .24317 Mdot
.63471 .78077 Mdot
.23793 .4715 Mdot
.61912 .58334 Mdot
.69192 .64564 Mdot
.82423 .52877 Mdot
.49572 .6738 Mdot
.53156 .54122 Mdot
.57719 .38045 Mdot
.27695 .23862 Mdot
.61162 .18162 Mdot
.6873 .3344 Mdot
.62387 .25933 Mdot
.36681 .54608 Mdot
.65366 .65933 Mdot
.6099 .23091 Mdot
.34249 .28412 Mdot
.49548 .24783 Mdot
.26135 .26394 Mdot
.63728 .69958 Mdot
.21291 .52884 Mdot
.39709 .31547 Mdot
.82327 .50569 Mdot
.3963 .21187 Mdot
.23248 .492 Mdot
.61947 .64281 Mdot
.58417 .27698 Mdot
.46477 .64605 Mdot
.32659 .29842 Mdot
.34925 .52556 Mdot
.59008 .69896 Mdot
.30798 .65519 Mdot
.69745 .65179 Mdot
.48067 .5658 Mdot
.23757 .47243 Mdot
.57855 .73326 Mdot
.71214 .64974 Mdot
.42688 .29943 Mdot
.47997 .16938 Mdot
.41269 .35282 Mdot
.23312 .68671 Mdot
.41592 .23323 Mdot
.71991 .59047 Mdot
.69374 .52556 Mdot
.57905 .21419 Mdot
.55109 .15396 Mdot
.59203 .20769 Mdot
.46523 .37642 Mdot
.39248 .66389 Mdot
.26995 .43073 Mdot
.57657 .75939 Mdot
.43062 .66073 Mdot
.50758 .22981 Mdot
.4516 .56437 Mdot
.28983 .40069 Mdot
.34616 .35687 Mdot
.59048 .25939 Mdot
.59817 .77655 Mdot
.68623 .28868 Mdot
.55857 .47809 Mdot
.62847 .30429 Mdot
.51725 .33775 Mdot
.44856 .37324 Mdot
.65016 .66508 Mdot
.33428 .66046 Mdot
.19226 .56783 Mdot
.50923 .37215 Mdot
.71017 .56339 Mdot
.32925 .52997 Mdot
.60873 .33476 Mdot
.78313 .40086 Mdot
.2912 .63845 Mdot
.63658 .19502 Mdot
.82512 .42256 Mdot
.6103 .23012 Mdot
.61684 .6726 Mdot
.20281 .57157 Mdot
.47001 .47561 Mdot
.27867 .46019 Mdot
.45176 .22013 Mdot
.42957 .52046 Mdot
.6287 .67058 Mdot
.62796 .31985 Mdot
.2509 .47245 Mdot
.60213 .47634 Mdot
.68088 .24033 Mdot
.62671 .77347 Mdot
.4558 .4831 Mdot
.52388 .27022 Mdot
.584 .35441 Mdot
.77143 .68971 Mdot
.33966 .31157 Mdot
.58761 .62019 Mdot
.4243 .20557 Mdot
.33685 .45366 Mdot
.54106 .30238 Mdot
.72376 .64068 Mdot
.38239 .72533 Mdot
.6155 .30869 Mdot
.3656 .50937 Mdot
.60312 .24023 Mdot
.40747 .50548 Mdot
.43876 .20105 Mdot
.38125 .19093 Mdot
.29608 .77976 Mdot
.5406 .37439 Mdot
.29116 .5107 Mdot
.28621 .5142 Mdot
.58672 .36921 Mdot
.58076 .38254 Mdot
.66129 .40992 Mdot
.5253 .17085 Mdot
.41936 .55836 Mdot
.33495 .27878 Mdot
.46065 .50745 Mdot
.35396 .72084 Mdot
.25952 .48716 Mdot
.58532 .74059 Mdot
.34916 .22869 Mdot
.65371 .27315 Mdot
.16266 .56259 Mdot
.54713 .48661 Mdot
.74567 .6784 Mdot
.57634 .76004 Mdot
.75293 .5686 Mdot
.72714 .44641 Mdot
.48028 .24453 Mdot
.61483 .50153 Mdot
.47184 .14824 Mdot
.45723 .29921 Mdot
.52681 .61285 Mdot
.27873 .68314 Mdot
.58556 .53918 Mdot
.57666 .56419 Mdot
.60525 .2263 Mdot
.51624 .26467 Mdot
.16517 .47193 Mdot
.65998 .70076 Mdot
.69757 .613 Mdot
.63055 .34372 Mdot
.81409 .55586 Mdot
.35758 .49878 Mdot
.49922 .19836 Mdot
.48095 .57341 Mdot
.8291 .51563 Mdot
.32991 .26058 Mdot
.3131 .31027 Mdot
.41226 .22601 Mdot
.29053 .23357 Mdot
.66734 .6182 Mdot
.47738 .3509 Mdot
.25031 .50273 Mdot
.67158 .55103 Mdot
.44855 .36316 Mdot
.42497 .2128 Mdot
.35525 .77457 Mdot
.54796 .59364 Mdot
.54342 .15024 Mdot
.58401 .46568 Mdot
.46811 .3403 Mdot
.20129 .40997 Mdot
.15224 .60398 Mdot
.31915 .31748 Mdot
.39926 .15573 Mdot
.30814 .30331 Mdot
.41387 .20309 Mdot
.34711 .44733 Mdot
.42546 .53909 Mdot
.77154 .35715 Mdot
.53212 .17032 Mdot
.40603 .75027 Mdot
.2262 .41817 Mdot
.73972 .30625 Mdot
.5241 .16572 Mdot
.59826 .46448 Mdot
.7752 .67635 Mdot
.32958 .68891 Mdot
.83937 .52766 Mdot
.82629 .45212 Mdot
.53775 .26491 Mdot
.68995 .66585 Mdot
.77686 .66127 Mdot
.67931 .76819 Mdot
.82168 .45213 Mdot
.74642 .59975 Mdot
.50653 .28122 Mdot
.60766 .67372 Mdot
.52009 .21969 Mdot
.80319 .59668 Mdot
.27507 .49758 Mdot
.45171 .42623 Mdot
.42289 .38586 Mdot
.55804 .23386 Mdot
.42001 .28362 Mdot
.34033 .51725 Mdot
.47803 .42973 Mdot
.59501 .24439 Mdot
.34929 .84351 Mdot
.28383 .30679 Mdot
.60525 .38939 Mdot
.35168 .17734 Mdot
.49132 .2563 Mdot
.43657 .56391 Mdot
.73497 .46238 Mdot
.6035 .7686 Mdot
.28818 .67224 Mdot
.66194 .5124 Mdot
.5163 .16669 Mdot
.28683 .65582 Mdot
.4108 .1625 Mdot
.74236 .27367 Mdot
.639 .28369 Mdot
.70854 .52945 Mdot
.36912 .59096 Mdot
.76599 .60052 Mdot
.74723 .61228 Mdot
.34511 .18927 Mdot
.75035 .66888 Mdot
.43484 .49087 Mdot
.38982 .51497 Mdot
.39208 .49379 Mdot
.62006 .62732 Mdot
.82734 .53107 Mdot
.4923 .31457 Mdot
.59995 .72702 Mdot
.38783 .32251 Mdot
.67088 .66679 Mdot
.63891 .38568 Mdot
.57388 .75331 Mdot
.50266 .62385 Mdot
.55013 .69445 Mdot
.36207 .60149 Mdot
.24294 .29929 Mdot
.45224 .24154 Mdot
.80941 .37771 Mdot
.23517 .6865 Mdot
.44863 .33605 Mdot
.71646 .67957 Mdot
.27822 .48084 Mdot
.5422 .59657 Mdot
.42588 .7762 Mdot
.62121 .73001 Mdot
.65187 .39959 Mdot
.49156 .21741 Mdot
.71868 .49365 Mdot
.57207 .19353 Mdot
.5889 .70338 Mdot
.20886 .36917 Mdot
.36245 .54914 Mdot
.77579 .44025 Mdot
.65069 .35125 Mdot
.21382 .65639 Mdot
.45604 .48587 Mdot
.31479 .19147 Mdot
.55377 .29411 Mdot
.45145 .14959 Mdot
.29767 .45013 Mdot
.35817 .797 Mdot
.49181 .23765 Mdot
.5135 .58926 Mdot
.49034 .54543 Mdot
.70588 .25499 Mdot
.40303 .35895 Mdot
.42051 .34245 Mdot
.46807 .64794 Mdot
.32712 .67289 Mdot
.42998 .46527 Mdot
.3419 .27441 Mdot
.24494 .30188 Mdot
.68804 .54339 Mdot
.39336 .58925 Mdot
.75631 .61138 Mdot
.2848 .46587 Mdot
.51035 .25957 Mdot
.47778 .22422 Mdot
.60931 .40389 Mdot
.64819 .65892 Mdot
.28994 .23013 Mdot
.51577 .23329 Mdot
.46185 .63097 Mdot
.73269 .56907 Mdot
.24249 .43792 Mdot
.17963 .48997 Mdot
.36872 .21068 Mdot
.39265 .50309 Mdot
.47555 .45599 Mdot
.61526 .6839 Mdot
.56278 .13835 Mdot
.32552 .1916 Mdot
.18161 .61272 Mdot
.45626 .50563 Mdot
.50777 .34365 Mdot
.61121 .75525 Mdot
.20945 .36624 Mdot
.84404 .52027 Mdot
.41912 .31501 Mdot
.67882 .66413 Mdot
.33838 .76029 Mdot
.75908 .67882 Mdot
.43556 .50495 Mdot
.65188 .35184 Mdot
.79617 .41046 Mdot
.34265 .47083 Mdot
.28257 .66296 Mdot
.46347 .52834 Mdot
.23571 .43108 Mdot
.50451 .28455 Mdot
.40348 .3603 Mdot
.2083 .36993 Mdot
.75878 .6588 Mdot
.73367 .5652 Mdot
.21781 .3709 Mdot
.58668 .29149 Mdot
.2791 .51134 Mdot
.18086 .53916 Mdot
.45381 .5172 Mdot
.36847 .63696 Mdot
.54058 .53348 Mdot
.4514 .4551 Mdot
.31063 .2907 Mdot
.30457 .74171 Mdot
.52755 .72957 Mdot
.54444 .3831 Mdot
.7697 .66164 Mdot
.55033 .37504 Mdot
.60106 .16151 Mdot
.34575 .28183 Mdot
.6303 .32228 Mdot
.31286 .26742 Mdot
.23055 .53552 Mdot
.23817 .70004 Mdot
.61422 .2469 Mdot
.57664 .67551 Mdot
.53696 .37859 Mdot
.52404 .35423 Mdot
.33611 .24761 Mdot
.38866 .41036 Mdot
.61833 .26544 Mdot
.80761 .56809 Mdot
.20446 .57593 Mdot
.57188 .37085 Mdot
.38851 .51983 Mdot
.58373 .39992 Mdot
.61909 .18346 Mdot
.3663 .63348 Mdot
.3278 .18214 Mdot
.72356 .5286 Mdot
.17382 .49288 Mdot
.54566 .23178 Mdot
.4935 .42387 Mdot
.44582 .49778 Mdot
.20591 .5584 Mdot
.61454 .47388 Mdot
.69288 .61536 Mdot
.57645 .31431 Mdot
.2222 .44854 Mdot
.50144 .72585 Mdot
.49883 .65283 Mdot
.25926 .44065 Mdot
.78229 .51302 Mdot
.83473 .49716 Mdot
.51888 .34529 Mdot
.3546 .54315 Mdot
.28056 .52303 Mdot
.61668 .45728 Mdot
.75592 .6006 Mdot
.26437 .27138 Mdot
.61755 .25498 Mdot
.54763 .29485 Mdot
.19154 .62969 Mdot
.45732 .68099 Mdot
.65076 .20444 Mdot
.60515 .42061 Mdot
.76375 .60471 Mdot
.7528 .55672 Mdot
.61344 .22233 Mdot
.63606 .38517 Mdot
.50938 .20762 Mdot
.62607 .66608 Mdot
.4492 .65348 Mdot
.71358 .64739 Mdot
.61076 .40257 Mdot
.40946 .48819 Mdot
.83094 .54358 Mdot
.32935 .7566 Mdot
.69529 .37855 Mdot
.54158 .56973 Mdot
.56532 .24386 Mdot
.8152 .55107 Mdot
.54627 .38506 Mdot
.52474 .74404 Mdot
.70862 .30111 Mdot
.49053 .24129 Mdot
.57322 .20363 Mdot
.47951 .28473 Mdot
.76658 .60563 Mdot
.39548 .48871 Mdot
.65651 .74274 Mdot
.72054 .51276 Mdot
.51821 .57256 Mdot
.5872 .49834 Mdot
.71211 .59182 Mdot
.46083 .57731 Mdot
.72209 .27194 Mdot
.65498 .62631 Mdot
.52052 .17562 Mdot
.63505 .20098 Mdot
.46459 .18494 Mdot
.34344 .52923 Mdot
.5565 .37125 Mdot
.35413 .17104 Mdot
.77719 .58697 Mdot
.52083 .22224 Mdot
.82503 .46346 Mdot
.77877 .68302 Mdot
.19888 .38575 Mdot
.46384 .26916 Mdot
.60633 .30452 Mdot
.80016 .34739 Mdot
.45807 .31162 Mdot
.77931 .66596 Mdot
.65516 .4027 Mdot
.53025 .2426 Mdot
.28792 .21605 Mdot
.80039 .49456 Mdot
.42628 .34161 Mdot
.64932 .35774 Mdot
.61974 .37896 Mdot
.79638 .56531 Mdot
.55484 .51749 Mdot
.35643 .66638 Mdot
.3712 .69864 Mdot
.67954 .67066 Mdot
.59645 .4111 Mdot
.79684 .57847 Mdot
.74776 .61472 Mdot
.70561 .68888 Mdot
.20665 .56497 Mdot
.20001 .3854 Mdot
.6258 .33531 Mdot
.59809 .59329 Mdot
.55335 .3882 Mdot
.50158 .74036 Mdot
.64569 .71571 Mdot
.60578 .55843 Mdot
.48558 .50637 Mdot
.65181 .6135 Mdot
.49834 .15579 Mdot
.37337 .71372 Mdot
.2975 .39497 Mdot
.56432 .37068 Mdot
.558 .23505 Mdot
.35663 .48734 Mdot
.39182 .37107 Mdot
.7927 .58008 Mdot
.60354 .2758 Mdot
.42995 .19448 Mdot
.43435 .34297 Mdot
.60967 .70028 Mdot
.51739 .79005 Mdot
.32382 .40882 Mdot
.78365 .39175 Mdot
.33312 .20057 Mdot
.45418 .35261 Mdot
.57474 .2867 Mdot
.39685 .30636 Mdot
.41053 .49148 Mdot
.47407 .36489 Mdot
.40515 .35508 Mdot
.28369 .49329 Mdot
.65439 .30487 Mdot
.37404 .19761 Mdot
.34868 .58586 Mdot
.65228 .69508 Mdot
.35537 .3081 Mdot
.79969 .57412 Mdot
.61335 .45631 Mdot
.54603 .19117 Mdot
.51074 .58233 Mdot
.44586 .70806 Mdot
.6049 .53395 Mdot
.77067 .56395 Mdot
.60382 .22392 Mdot
.37983 .31795 Mdot
.60806 .64108 Mdot
.52948 .29131 Mdot
.82578 .41721 Mdot
.3051 .69243 Mdot
.29439 .68237 Mdot
.72168 .7095 Mdot
.49237 .39125 Mdot
.43449 .65645 Mdot
.31486 .37715 Mdot
.61412 .46818 Mdot
.50872 .78839 Mdot
.37614 .50858 Mdot
.77797 .37858 Mdot
.81431 .48209 Mdot
.25427 .28529 Mdot
.36462 .50511 Mdot
.82961 .41711 Mdot
.79229 .39106 Mdot
.53712 .24373 Mdot
.76704 .65699 Mdot
.53327 .53428 Mdot
.67103 .4943 Mdot
.52489 .74391 Mdot
.59329 .31682 Mdot
.2751 .26482 Mdot
.65679 .63961 Mdot
.46169 .73925 Mdot
.51254 .60384 Mdot
.33625 .51187 Mdot
.3036 .58459 Mdot
.50052 .27295 Mdot
.80133 .34859 Mdot
.6483 .66524 Mdot
.33541 .46197 Mdot
.31559 .2909 Mdot
.55289 .6064 Mdot
.53184 .18309 Mdot
.46844 .59601 Mdot
.60027 .2295 Mdot
.46051 .39658 Mdot
.78098 .41032 Mdot
.66042 .22 Mdot
.55068 .64891 Mdot
.51372 .5509 Mdot
.5045 .29621 Mdot
.5261 .52977 Mdot
.43615 .42298 Mdot
.40426 .69312 Mdot
.77809 .6131 Mdot
.23247 .33593 Mdot
.25142 .38979 Mdot
.57343 .48077 Mdot
.61458 .75166 Mdot
.35274 .21186 Mdot
.43498 .56956 Mdot
.50309 .58566 Mdot
.24862 .50501 Mdot
.28513 .65265 Mdot
.29918 .79372 Mdot
.48284 .15128 Mdot
.60339 .53394 Mdot
.4796 .54751 Mdot
.47499 .66327 Mdot
.30408 .63018 Mdot
.67732 .28062 Mdot
.27497 .26136 Mdot
.33717 .42099 Mdot
.22234 .63241 Mdot
.3149 .37772 Mdot
.71318 .2614 Mdot
.17978 .58681 Mdot
.31405 .39674 Mdot
.59856 .15935 Mdot
.41237 .32331 Mdot
.50324 .37619 Mdot
.31172 .80794 Mdot
.69477 .25242 Mdot
.7387 .57372 Mdot
.35328 .69294 Mdot
.49655 .1612 Mdot
.4463 .49554 Mdot
.4022 .64695 Mdot
.80439 .48713 Mdot
.64144 .66651 Mdot
.65688 .69924 Mdot
.34735 .38885 Mdot
.77536 .34177 Mdot
.74435 .7326 Mdot
.23274 .53501 Mdot
.21015 .67422 Mdot
.62797 .2721 Mdot
.40098 .17958 Mdot
.32044 .31499 Mdot
.36138 .77206 Mdot
.56948 .2068 Mdot
.71968 .63437 Mdot
.78528 .54047 Mdot
.38954 .74748 Mdot
.55176 .65517 Mdot
.61051 .76555 Mdot
.47014 .39021 Mdot
.6256 .25327 Mdot
.21339 .56173 Mdot
.58756 .63807 Mdot
.70561 .64964 Mdot
.79589 .4252 Mdot
.5151 .55593 Mdot
.36179 .18673 Mdot
.78528 .5764 Mdot
.62539 .67683 Mdot
.21556 .50275 Mdot
.47735 .7334 Mdot
.29453 .24834 Mdot
.38182 .44788 Mdot
.7411 .56819 Mdot
.19326 .42012 Mdot
.39184 .15778 Mdot
.53302 .53455 Mdot
.60133 .57962 Mdot
.66658 .20812 Mdot
.39794 .57887 Mdot
.81537 .47266 Mdot
.35446 .34252 Mdot
.66984 .69681 Mdot
.6434 .62105 Mdot
.60601 .49471 Mdot
.67511 .74496 Mdot
.58213 .27004 Mdot
.79718 .42115 Mdot
.18375 .57204 Mdot
.62287 .67317 Mdot
.77222 .53757 Mdot
.16296 .55842 Mdot
.60936 .419 Mdot
.53065 .35486 Mdot
.49671 .1591 Mdot
.68389 .26506 Mdot
.72547 .59128 Mdot
.63796 .32706 Mdot
.46682 .60894 Mdot
.49598 .78217 Mdot
.73371 .55872 Mdot
.4689 .47745 Mdot
.68711 .66875 Mdot
.21193 .37373 Mdot
.76419 .34486 Mdot
.3109 .19104 Mdot
.60122 .20636 Mdot
.55823 .37544 Mdot
.8018 .47642 Mdot
.45027 .51903 Mdot
.45507 .18683 Mdot
.20474 .54195 Mdot
.19529 .56107 Mdot
.72402 .74336 Mdot
.4973 .65562 Mdot
.6337 .49351 Mdot
.45336 .38309 Mdot
.57664 .19817 Mdot
.74267 .7241 Mdot
.56855 .19435 Mdot
.6981 .60127 Mdot
.69386 .52242 Mdot
.15526 .62459 Mdot
.42495 .20117 Mdot
.68107 .486 Mdot
.58096 .60789 Mdot
.60194 .62364 Mdot
.63692 .49973 Mdot
.392 .40397 Mdot
.5943 .76731 Mdot
.67934 .68753 Mdot
.52121 .17263 Mdot
.58712 .35428 Mdot
.45009 .49503 Mdot
.3202 .40062 Mdot
.48476 .51956 Mdot
.57772 .43588 Mdot
.34178 .4487 Mdot
.69711 .67997 Mdot
.36246 .5676 Mdot
.51279 .7689 Mdot
.58707 .26511 Mdot
.48712 .40193 Mdot
.58543 .25142 Mdot
.73728 .66704 Mdot
.3805 .39483 Mdot
.67389 .77262 Mdot
.74661 .61903 Mdot
.73344 .53053 Mdot
.48871 .29468 Mdot
.84102 .58189 Mdot
.44998 .48751 Mdot
.43048 .37706 Mdot
.60038 .44489 Mdot
.70124 .46334 Mdot
.64385 .30901 Mdot
.51516 .67081 Mdot
.44588 .40837 Mdot
.70926 .5889 Mdot
.59317 .23184 Mdot
.28856 .4547 Mdot
.5556 .14285 Mdot
.70325 .52688 Mdot
.67999 .29482 Mdot
.5256 .19689 Mdot
.27547 .50413 Mdot
.64916 .40125 Mdot
.58064 .50589 Mdot
.45172 .62675 Mdot
.36722 .56886 Mdot
.56903 .39674 Mdot
.2528 .48183 Mdot
.40588 .19076 Mdot
.73892 .67922 Mdot
.65989 .28633 Mdot
.66383 .52853 Mdot
.53035 .70814 Mdot
.47575 .48424 Mdot
.36217 .7609 Mdot
.36154 .57634 Mdot
.49963 .25172 Mdot
.73 .67046 Mdot
.65872 .70153 Mdot
.65407 .37604 Mdot
.42834 .15754 Mdot
.55216 .59369 Mdot
.63733 .28741 Mdot
.4968 .61412 Mdot
.42767 .28191 Mdot
.74576 .60715 Mdot
.22215 .36663 Mdot
.68275 .61469 Mdot
.54214 .54945 Mdot
.58594 .17268 Mdot
.6143 .24401 Mdot
.27262 .39375 Mdot
.4932 .21522 Mdot
.78099 .60698 Mdot
.49073 .54735 Mdot
.32348 .82146 Mdot
.20126 .54112 Mdot
.58478 .15633 Mdot
.23636 .45308 Mdot
.66866 .46279 Mdot
.49049 .33067 Mdot
.66036 .4848 Mdot
.33258 .6348 Mdot
.44133 .1831 Mdot
.50809 .28994 Mdot
.52665 .50571 Mdot
.57579 .56549 Mdot
.40977 .57208 Mdot
.56831 .39238 Mdot
.22624 .34397 Mdot
.31628 .67421 Mdot
.46313 .62663 Mdot
.2233 .4042 Mdot
.36574 .56904 Mdot
.79026 .66806 Mdot
.34882 .18619 Mdot
.45491 .22025 Mdot
.38144 .50711 Mdot
.31714 .78134 Mdot
.51067 .36162 Mdot
.59609 .36616 Mdot
.26653 .44539 Mdot
.66047 .74591 Mdot
.46415 .35885 Mdot
.21212 .38884 Mdot
.61096 .2161 Mdot
.61619 .45623 Mdot
.36893 .86432 Mdot
.72562 .6341 Mdot
.44814 .5837 Mdot
.46092 .36809 Mdot
.53183 .17486 Mdot
.28172 .69462 Mdot
.73618 .27049 Mdot
.33486 .30174 Mdot
.59403 .41552 Mdot
.63946 .76825 Mdot
.19342 .63014 Mdot
.37851 .52055 Mdot
.21183 .67709 Mdot
.40548 .21431 Mdot
.59218 .75686 Mdot
.37125 .3185 Mdot
.53417 .37239 Mdot
.68246 .62018 Mdot
.35201 .27487 Mdot
.53388 .5455 Mdot
.5067 .37553 Mdot
.40062 .198 Mdot
.54841 .79 Mdot
.20582 .49182 Mdot
.45323 .20149 Mdot
.27648 .46215 Mdot
.51913 .28126 Mdot
.74402 .6319 Mdot
.39564 .58912 Mdot
.30689 .64419 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0;?ooooo0_l0002Dooooo`007?ooool0
0ol0003oooooooooo`2Iooooo`;o00005Oooool2o`000003ooooool0003o000009Cooooo000Loooo
o`03o`000?oooooooooo09Wooooo0_l0000Eooooo`?o0000U_ooool001cooooo00?o0000oooooooo
ool0/Oooool2o`0009Kooooo000Looooo`03o`000?oooooooooo08Kooooo0_l00007ooooo`?o0000
1?ooool2o`0000cooooo0_l00007ooooo`;o00002?ooool2o`00093ooooo000Looooo`;o0000Qooo
ool2o`0000Oooooo0ol00004ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Oooooo0_l0
0008ooooo`;o0000T?ooool001cooooo00?o0000ooooooooool0O_ooool2o`0000oooooo0_l00008
ooooo`;o00000oooool2o`0000oooooo0_l00009ooooo`;o0000SOooool001cooooo00?o0000oooo
ooooool0NOooool2o`000003ooooool0003o000000;o00001oooool2o`0000Kooooo0_l0000=oooo
o`;o00003oooool2o`0000Wooooo0_l00003ooooo`;o0000R?ooool001cooooo00?o0000oooooooo
ool0M?ooool3o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`;o00000oooool2o`0000go
oooo0_l000000ooooooo0000o`000003ooooo`;o00007oooool2o`0008Sooooo000Looooo`03o`00
0?oooooooooo07Cooooo0ol00005ooooo`;o00001?ooool2o`0000Sooooo0_l00005ooooo`;o0000
00Coooooo`000?l0003ooooo0_l00003ooooo`;o00001_ooool2o`0001Oooooo0ol00027ooooo`00
7?ooool00ol0003oooooooooo`1_ooooo`;o00003oooool2o`0000Cooooo0_l00004ooooo`;o0000
1Oooool2o`0000?ooooo0_l0000:ooooo`Co00006?ooool2o`0008Oooooo000Looooo`03o`000?oo
oooooooo06oooooo0_l0000?ooooo`;o00001?ooool2o`00013ooooo0_l0000:ooooo`;o000000?o
ooooo`000?l000000_l00004ooooo`;o0000V?ooool001cooooo00?o0000ooooooooool0Koooool2
o`0002Oooooo0_l0000<ooooo`Go00001?ooool2o`0000[ooooo0_l0002<ooooo`007?ooool00ol0
003oooooooooo`1_ooooo`;o00004oooool2o`0000gooooo0_l00005ooooo`?o00002?ooool3o`00
0003ooooool0003o0000013ooooo0_l0002<ooooo`007?ooool00ol0003oooooooooo`1_ooooo`;o
00003_ooool2o`0000?ooooo0_l0000=ooooo`;o00001Oooool3o`0000Cooooo0_l00002ooooo`;o
0000X_ooool001cooooo00?o0000ooooooooool0Ioooool3o`0000oooooo0_l00004ooooo`;o0000
2oooool2o`0000_ooooo0_l00006ooooo`;o00001_ooool2o`0001Oooooo1Ol00022ooooo`007?oo
ool00ol0003oooooooooo`1Wooooo`?o00001?ooool2o`0000;ooooo0_l00005ooooo`;o00002?oo
ool2o`0000Oooooo0_l00002ooooo`;o000000?oooooo`000?l000001?ooool2o`0000cooooo1?l0
000=ooooo`;o00002?ooool5o`000003ooooool0003o000007oooooo000Looooo`03o`000?oooooo
oooo06?ooooo0ol00006ooooo`Co00000_ooool4o`0000[ooooo0_l000000ooooooo0000o`000007
ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`?o00000oooool2
o`0000Cooooo0_l0000?ooooo`;o00002_ooool3o`000003ooooool0003o000007oooooo00001_oo
ooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003ooooooooo
o`1Qooooo`Oo00001?ooool2o`0000Kooooo0_l00002ooooo`;o00001_ooool2o`0001Gooooo0_l0
0002ooooo`?o00000oooool2o`0000Oooooo0_l00002ooooo`;o00001_ooool4o`0000_ooooo0_l0
0022ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Q
onk^k_ooooooA4A400Kooooo00?o0000ooooooooool0HOooool4o`000003ooooool0003o0000013o
oooo0_l00006ooooo`;o00001_ooool2o`0001[ooooo1Ol000000ooooooo0000o`000002ooooo`;o
00000oooool5o`0001?ooooo0_l0001looooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooo
ooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0I?ooool2o`00013ooooo
0_l00005ooooo`Go00001_ooool2o`000003ooooool0003o0000017ooooo0_l00004ooooo`Go0000
2_ooool4o`000003ooooool0003o0000017ooooo0_l0001looooo`0000?oooooo`000?ooool00_oo
ool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0001Tooooo`;o00000_oo
ool2o`0000cooooo0_l00005ooooo`?o00000oooool2o`000003ooooool0003o000000?ooooo0_l0
0002ooooo`Co00002oooool2o`0000Sooooo1?l0000<ooooo`;o00001Oooool3o`0000Sooooo0_l0
001mooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKo
oooo00Gooooo00?o0000ooooooooool0J?ooool2o`0001Wooooo0_l000000ooooooo0000o`000003
ooooo`So00005Oooool4o`0000[ooooo0ol00006ooooo`?o00002?ooool2o`0000Cooooo0_l00000
0ooooooo0000o`00001dooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0=oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0G?ooool2o`0002Sooooo0_l00005oooo
o`Co00004Oooool2o`0000Wooooo0_l00006ooooo`Co00000oooool3o`000003ooooool0003o0000
00kooooo0_l000000ooooooo0000o`000002o`0007;ooooo00001_ooooooMgMgoiRHV?ooooooV9RH
ogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo05cooooo0_l0
000Aooooo`;o00000oooool2o`0000Oooooo0_l0000@ooooo`Co00000_ooool2o`0000[ooooo0ol0
0009ooooo`;o00001_ooool2o`0000Gooooo0ol000000ooooooo0000o`00000Cooooo`;o0000L_oo
ool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Ko
oooo00?o0000ooooooooool0Koooool2o`0000?ooooo0_l00007ooooo`;o000000?oooooo`000?l0
00001?ooool2o`0000Oooooo1?l000000ooooooo0000o`000004o`0000;ooooo0_l00003ooooo`;o
00005Oooool2o`0008oooooo000Looooo`03o`000?oooooooooo05[ooooo0_l0000Kooooo`;o0000
1?ooool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o00000ooooolAo`0000kooooo
0_l00008ooooo`;o00002Oooool2o`0000gooooo0_l0001eooooo`007?ooool00ol0003ooooooooo
o`1Jooooo`;o00006oooool2o`0000Cooooo0_l00006ooooo`;o00000oooool2o`0000?ooooo2Ol0
0002ooooo`Ko00001Oooool2o`0000Oooooo0_l00004ooooo`Go00002_ooool2o`0000[ooooo0_l0
00001?oooooo0000o`000?l00004ooooo`;o0000K_ooool001cooooo00?o0000ooooooooool0Mooo
ool2o`0000Sooooo0_l00002ooooo`;o00002?ooool3o`000003ooooool0003o000000;ooooo0_l0
000<ooooo`;o00003Oooool5o`0000Oooooo0_l000000ooooooo0000o`00000:ooooo`;o00000_oo
ool2o`0000Cooooo0_l0001^ooooo`007?ooool00ol0003oooooooooo`1gooooo`;o00002?ooool3
o`0000Kooooo0_l00007ooooo`Ko00002_ooool4o`0000kooooo0_l00009ooooo`Go00004Oooool2
o`00077ooooo000Looooo`03o`000?oooooooooo05[ooooo0_l0000Booooo`;o00004_ooool2o`00
00Kooooo0_l00005ooooo`;o00000_ooool4o`0000Sooooo1?l0000;ooooo`;o00000oooool3o`00
00Oooooo1Ol0000>ooooo`;o00000_ooool2o`0000Cooooo0_l0001[ooooo`007?ooool00ol0003o
ooooooooo`1Dooooo`;o00001?ooool3o`00017ooooo0_l0000Cooooo`;o00003?ooool2o`0000co
oooo1?l000000ooooooo0000o`000006ooooo`?o000000Coooooo`000?l0003o00000oooool2o`00
00Gooooo1?l000000ooooooo0000o`00000>ooooo`;o00002?ooool2o`0006_ooooo000Looooo`03
o`000?oooooooooo05Cooooo0_l00005ooooo`;o00009_ooool2o`0000Kooooo0_l0000Booooo`Co
000000?oooooo`000?l000001_ooool3o`000004ooooool0003o0000o`0000;ooooo0_l00006oooo
o`?o00000_ooool2o`0000gooooo1?l00003ooooo`;o0000Koooool001cooooo00?o0000oooooooo
ool0E_ooool2o`0003?ooooo0_l00005ooooo`Go00001Oooool2o`0000?ooooo0_l0000>ooooo`Ko
00001oooool2o`00017ooooo1?l00003ooooo`;o0000Koooool001cooooo00?o0000ooooooooool0
E_ooool3o`0003Kooooo0_l000000ooooooo0000o`000003o`0000Gooooo0_l0000:ooooo`;o0000
1?ooool2o`0000?ooooo0_l00002ooooo`;o00001oooool2o`0001Oooooo0_l00006ooooo`;o0000
I_ooool001cooooo00?o0000ooooooooool0Eoooool2o`0003Kooooo0_l00007ooooo`;o00000_oo
ool2o`0000Cooooo0_l00003ooooo`?o000000Coooooo`000?l0003ooooo0_l000001?oooooo0000
o`000?ooool2o`000003ooooool0003o000000Cooooo0_l000001?oooooo0000o`000?ooool3o`00
01?ooooo0_l00006ooooo`;o0000I_ooool001cooooo00?o0000ooooooooool0G?ooool2o`0000_o
oooo0_l0000]ooooo`;o00000oooool2o`0000?ooooo0_l00003ooooo`;o00000_ooool2o`0000?o
oooo0ol000000ooooooo0000o`000007ooooo`;o00001?ooool3o`0001Kooooo0_l0001[ooooo`00
7?ooool2o`0005gooooo0_l0000;ooooo`;o0000<Oooool5o`000003ooooool0003o000000cooooo
0_l00008ooooo`;o00002?ooool2o`0001Kooooo0_l0001[ooooo`007?ooool00ol0003ooooooooo
o`1Gooooo`;o0000@oooool2o`000004ooooool0003o0000o`0000oooooo1?l000000ooooooo0000
o`000002ooooo`;o00002Oooool4o`0001Gooooo0_l000000ooooooo0000o`00001Vooooo`007?oo
ool00ol0003oooooooooo`1Gooooo`;o0000<oooool2o`0000kooooo0_l00002ooooo`;o00003ooo
ool4o`000003ooooool0003o000000gooooo1?l0000Eooooo`;o000000?oooooo`000?l00000I_oo
ool001cooooo00?o0000ooooooooool0E_ooool2o`0000gooooo1?l0000Sooooo`;o00003?ooool6
o`0000;ooooo0_l0000Dooooo`;o00000_ooool2o`0000Wooooo0_l0000Hooooo`;o000000?ooooo
o`000?l00000Hoooool001cooooo00?o0000ooooooooool0DOooool2o`0000?ooooo0_l0000=oooo
o`Co00009Oooool2o`0000[ooooo0_l00002ooooo`;o00000_ooool4o`0001;ooooo0ol000001?oo
oooo0000o`000?l00008ooooo`;o00004Oooool2o`0000Gooooo0_l000000ooooooo0000o`00001S
ooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o00000oooool2o`0000[ooooo0_l000000ooo
oooo0000o`00000Wooooo`;o00003?ooool2o`000003ooooool0003o000000?ooooo0_l00005oooo
o`;o00000oooool4o`0000Gooooo1ol00005ooooo`;o00004oooool2o`0000_ooooo0_l0001Poooo
o`007?ooool00ol0003oooooooooo`1Fooooo`;o00002_ooool2o`000003ooooool0003o000002co
oooo0_l00007ooooo`Go00001Oooool2o`0000?ooooo0_l00003ooooo`Co00001Oooool4o`000003
ooooool0003o000000Gooooo0_l0000Cooooo`;o00002oooool2o`0000;ooooo0_l0001Looooo`00
7?ooool00ol0003oooooooooo`1Booooo`;o00003oooool4o`0002cooooo0ol00005ooooo`Ko0000
1Oooool2o`0000gooooo0_l00002ooooo`Co00000oooool2o`0000Kooooo0_l00007ooooo`;o0000
2?ooool2o`0000[ooooo0_l00002ooooo`Co0000F_ooool001cooooo00?o0000ooooooooool0D_oo
ool2o`0000oooooo0_l00006ooooo`;o00000_ooool2o`0002?ooooo0_l00005ooooo`;o00000_oo
ool2o`0001Cooooo0_l00003ooooo`?o00000oooool2o`0000Kooooo0_l00007ooooo`;o00002?oo
ool2o`0000[ooooo0ol00003ooooo`;o0000F_ooool001cooooo00?o0000ooooooooool0D_ooool2
o`0001Gooooo1?l00002ooooo`;o00006oooool2o`000003ooooool0003o000000[ooooo0_l0000K
ooooo`Co00001?ooool2o`0000Cooooo0_l0000Pooooo`;o0000Goooool001cooooo00?o0000oooo
ooooool0Hoooool2o`0000Cooooo0_l00002ooooo`;o00006?ooool2o`0000?ooooo0_l000000ooo
oooo0000o`000007ooooo`;o00001oooool2o`0000;ooooo0_l00005ooooo`?o00002Oooool2o`00
00cooooo0_l00009ooooo`;o00001Oooool2o`0006oooooo000Looooo`03o`000?oooooooooo04oo
oooo0_l0000Booooo`;o00001oooool3o`0001Gooooo1Ol0000?ooooo`;o00001Oooool8o`0000Co
oooo1Ol000000ooooooo0000o`000003o`0000;ooooo0_l0000<ooooo`;o00001?ooool2o`0000?o
oooo0_l00005ooooo`;o00000_ooool2o`0006_ooooo000Looooo`03o`000?oooooooooo04kooooo
0ol0000Kooooo`;o00005_ooool3o`00017ooooo0_l00005ooooo`?o000000?oooooo`000?l00000
1_ooool5o`000003ooooool0003o000000?o000000Coooooo`000?l0003o00001Oooool2o`0000Co
oooo1?l00002ooooo`?o00001Oooool2o`0000Kooooo0ol0001[ooooo`007?ooool00ol0003ooooo
ooooo`1>ooooo`;o00003oooool7o`0002oooooo0_l00002ooooo`;o00001_ooool2o`000003oooo
ool0003o000000;ooooo1?l000000ooooooo0000o`000002ooooo`Co00000_ooool6o`0000;ooooo
0ol00002ooooo`Go00000_ooool2o`0000Kooooo0_l00006ooooo`;o00000_ooool2o`0006Sooooo
000Looooo`03o`000?oooooooooo05kooooo2?l0000_ooooo`;o00000_ooool4o`0000Cooooo0_l0
00000ooooooo0000o`000002ooooo`[o00001_ooool5o`0000;ooooo0ol00002ooooo`;o00003?oo
ool2o`0000Gooooo0_l00004ooooo`;o0000J?ooool001cooooo00?o0000ooooooooool0G_ooool3
o`0000Gooooo0_l0000]ooooo`;o00001?ooool2o`0000?ooooo0_l00007ooooo`;o000000?ooooo
o`000?l000001ol00004ooooo`;o00001Oooool2o`00013ooooo0_l00005ooooo`;o0000K_ooool0
01cooooo0_l0001<ooooo`;o00006Oooool2o`0001oooooo0_l00008ooooo`;o00001oooool2o`00
00Cooooo0_l00008ooooo`co00000_ooool6o`0000;ooooo0_l0000Pooooo`;o00001_ooool2o`00
05gooooo000Looooo`03o`000?oooooooooo04_ooooo0ol0000Booooo`;o00001_ooool3o`0001co
oooo0_l00008ooooo`;o00001oooool3o`000003ooooool0003o000000;o00001Oooool2o`000003
ooooool0003o000001;o00000oooool2o`0000Gooooo0_l0000Hooooo`?o00001Oooool2o`0005go
oooo000Looooo`03o`000?oooooooooo04cooooo0_l0000:ooooo`;o00001_ooool2o`0000Kooooo
0ol0000Booooo`;o00007?ooool2o`000003ooooool0003o000000;o00001OoooolFo`0000Cooooo
0_l00005ooooo`;o00001oooool2o`00013ooooo0_l00006ooooo`?o0000Foooool001cooooo00?o
0000ooooooooool0F?ooool4o`000003ooooool0003o000000?ooooo0_l0000<ooooo`;o00002ooo
ool2o`0002Gooooo6?l00008ooooo`;o00001oooool2o`0000;ooooo0_l0000Hooooo`?o0000Fooo
ool001cooooo00?o0000ooooooooool0F_ooool2o`000003ooooool0003o000000?ooooo0_l00007
ooooo`;o00000oooool2o`0001kooooo0ol00009ooooo`;o000000?oooooo`000?l000000ooooolJ
o`0000Kooooo0_l00007ooooo`;o0000N_ooool001cooooo00?o0000ooooooooool0F_ooool2o`00
00Sooooo0ol00004ooooo`Co00003_ooool2o`0000Gooooo0_l0000:ooooo`?o00002Oooool2o`00
0003ooooool0003o000000Cooooo1ol000000ooooooo0000o`00000Bo`0003Cooooo0_l00003oooo
o`;o0000COooool001cooooo00?o0000ooooooooool0Boooool2o`0000gooooo0_l00008ooooo`Go
00001?ooool2o`0000Kooooo0_l000000ooooooo0000o`000003ooooo`Co00000oooool2o`0000;o
oooo0_l0000Booooo`;o00002?ooool6o`0000;ooooo5Ol00005ooooo`;o0000:oooool2o`0000?o
oooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o00005oooool2o`000003oooo
ool0003o000000Cooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000Go0000
0oooool2o`0000Oooooo1Ol0000IoooooaOo000000Coooooo`000?l0003ooooo0_l00005ooooo`?o
0000<_ooool2o`0004[ooooo000Looooo`03o`000?oooooooooo06gooooo0_l000000ooooooo0000
o`000002o`0000;ooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000000Gooooo
1?l0000;ooooo`;o000000?oooooo`000?l000001_oooolMo`000003ooooool0003o000000Kooooo
0_l0000:ooooo`;o00001Oooool2o`0001Sooooo0_l00005ooooo`;o0000B_ooool001cooooo00?o
0000ooooooooool0HOooool4o`0000_ooooo0_l0000=ooooo`;o000000?oooooo`000?l000000_oo
ool3o`0000;ooooo0_l0000;ooooo`Go00001_oooolDo`000003ooooool0003o000000Ko00002Ooo
ool4o`0000Sooooo0_l00005ooooo`;o00003Oooool6o`0000Gooooo0_l00004ooooo`;o0000Booo
ool001cooooo00?o0000ooooooooool0HOooool4o`0000;ooooo0_l0000Iooooo`Oo00000oooool2
o`0000_ooooo1Ol00004ooooo`;o000000?oooooo`000?l000006Ol00002ooooo`;o00001oooool2
o`0001kooooo2?l00003ooooo`;o00001?ooool2o`0004_ooooo000Looooo`03o`000?oooooooooo
06Oooooo0ol0000Hooooo`Ko00001?ooool3o`0000[ooooo1Ol00004oooooaoo000000?oooooo`00
0?l000000_ooool3o`0001;ooooo1?l0000<ooooo`;o00001?ooool2o`0000?ooooo0ol0001@oooo
o`007?ooool00ol0003oooooooooo`18ooooo`;o00007_ooool2o`0001cooooo0ol00003ooooo`Co
00002oooool3o`0000Cooooo7ol000000ooooooo0000o`000002ooooo`?o00004_ooool4o`0001So
oooo0ol0001?ooooo`007?ooool00ol0003oooooooooo`18ooooo`;o0000>?ooool3o`000004oooo
ool0003o0000o`0000?ooooo1?l00004ooooo`;o00000oooool4o`0000Gooooo6ol00002ooooo`Co
0000=Oooool2o`0004oooooo000Looooo`03o`000?oooooooooo04Cooooo1?l0000Wooooo`?o0000
4?ooool>o`0000Cooooo0_l00003ooooo`;o00001_oooolLo`0000Cooooo0_l00006ooooo`;o0000
:_ooool2o`000004ooooool0003o0000o`0004kooooo000Looooo`03o`000?oooooooooo04Cooooo
1?l0000Wooooo`?o00002?ooool2o`0000Kooooo3?l0000Cooooo`oo000000?oooooo`000?l00000
2ol00003ooooo`?o000000?oooooo`000?l000000_ooool4o`0002Oooooo0ol000000ooooooo0000
o`000002o`0000Cooooo0_l00017ooooo`007?ooool2o`0004Gooooo0_l0000Yooooo`;o00002Ooo
ool2o`0000Cooooo0_l00005ooooo`;o00000oooool2o`0000Wooooo0_l00009ooooo`Go000000?o
ooooo`000?l000007Ol00004ooooo`;o00003_ooool2o`0001Oooooo0_l00003ooooo`?o00001?oo
ool3o`0004Kooooo000Looooo`03o`000?oooooooooo06oooooo0_l0000?ooooo`Co00000_ooool2
o`0000Cooooo0_l00002ooooo`;o00001Oooool2o`0000Wooooo1?l00003oooooa?o00000_ooool4
o`0000;ooooo0_l00004ooooo`?o00000oooool2o`0000?ooooo0_l00004ooooo`;o00007?ooool3
o`0000Cooooo0ol00016ooooo`007?ooool00ol0003oooooooooo`1]ooooo`;o00004Oooool4o`00
00;ooooo0_l000001?oooooo0000o`000?ooool2o`000004ooooool0003o0000o`00013ooooo0_l0
0002ooooo`;o000000?oooooo`000?l000004_l0000=ooooo`?o00000oooool2o`0000;ooooo0ol0
000Pooooo`Co00001Oooool2o`0004Oooooo000Looooo`03o`000?oooooooooo06_ooooo1?l0000:
ooooo`;o00001?ooool3o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`;o00000_ooool2
o`0000gooooo0ol000000ooooooo0000o`00000Eo`0000Cooooo0_l00008ooooo`;o00000_ooool2
o`0000?ooooo0_l00002ooooo`;o00007Oooool2o`0000Oooooo0_l00017ooooo`007?ooool00ol0
003oooooooooo`0nooooo`;o0000:oooool2o`0000cooooo0_l00004ooooo`;o00002_ooool2o`00
0003ooooool0003o000000?ooooo0_l00009ooooo`;o00000_ooool3o`000003ooooool0003o0000
01So000000?oooooo`000?l000002?ooool6o`0000Oooooo0_l00003ooooo`;o00008Oooool2o`00
04Oooooo000Looooo`03o`000?oooooooooo03kooooo1?l0000Tooooo`;o00005oooool2o`0000[o
oooo0_l000000ooooooo0000o`000002o`0000Cooooo0ol00005ooooo`?o000000Coooooo`000?l0
003ooooo0_l000000ooooooo0000o`00000>o`0000;ooooo1_l0000=ooooo`;o00001oooool2o`00
00Gooooo0_l0000Aooooo`;o0000Eoooool001cooooo00?o0000ooooooooool0@?ooool2o`0000;o
oooo0_l0000Pooooo`;o00008_ooool2o`0000Cooooo1?l00002ooooo`?o00001Oooool3o`0000Co
oooo0_l000000ooooooo0000o`00000;o`0000?ooooo1Ol000000ooooooo0000o`000004ooooo`;o
00004?ooool2o`0001Sooooo1?l0001Eooooo`007?ooool00ol0003oooooooooo`10ooooo`;o0000
00Coooooo`000?l0003o0000=_ooool2o`0000cooooo0_l00006ooooo`;o00002_ooool2o`0000;o
oooo0_l00003ooooo`;o000000?oooooo`000?l000004Ol00007ooooo`;o00000oooool2o`0000Go
oooo0_l0000<ooooo`;o00004_ooool2o`0005Gooooo000Looooo`03o`000?oooooooooo03oooooo
1_l0000Sooooo`;o00003?ooool4o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`0000Gooooo
0_l0000>ooooo`;o000000Coooooo`000?l0003o00000oooool2o`000003ooooool0003o000000oo
00003_ooool2o`0000;ooooo1_l00003ooooo`;o00001_ooool2o`0001Gooooo0_l0001Booooo`00
7?ooool00ol0003oooooooooo`0kooooo`?o000000?oooooo`000?l000000_l0000Nooooo`Co0000
0oooool2o`0000cooooo1?l00008ooooo`?o00000_ooool3o`0000Cooooo0_l00003ooooo`;o0000
2oooool3o`0000Oooooo4Ol0000Booooo`?o000000?oooooo`000?l000000oooool2o`0000Kooooo
0_l0000Dooooo`?o00000_ooool2o`0000Sooooo0_l00014ooooo`007?ooool00ol0003ooooooooo
o`0kooooo`?o00000_ooool2o`0001oooooo1?l0000Mooooo`;o00001?ooool2o`0000Wooooo0_l0
000;ooooo`Co00000oooool3o`000004ooooool0003o0000ooooo`;o00000oooool8o`0000_ooooo
0_l00005ooooo`;o00000_ooool2o`0000;ooooo0_l00007ooooo`;o00005?ooool3o`0000;ooooo
0_l00002ooooo`;o00001?ooool2o`0004Cooooo000Looooo`03o`000?oooooooooo067ooooo0_l0
000<ooooo`Co00005Oooool2o`0000Gooooo0ol0000@ooooo`;o00000oooool3o`0000?ooooo0_l0
0004ooooo`;o000000?oooooo`000?l000001_l00008ooooo`;o00000oooool5o`0000Gooooo0_l0
0007ooooo`;o00005Oooool3o`0000Gooooo0_l00004ooooo`;o0000A?ooool001cooooo00?o0000
ooooooooool0?Oooool2o`0000Oooooo0_l0000<ooooo`Co00004?ooool2o`0000Gooooo1?l0000A
ooooo`Ko00001Oooool3o`0001Kooooo0_l00003ooooo`Co00000_ooool5o`000003ooooool0003o
000000?o00002?ooool2o`0000?ooooo1Ol00009ooooo`;o00006oooool2o`0000_ooooo0_l00014
ooooo`007?ooool00ol0003oooooooooo`0kooooo`Go000000?oooooo`000?l000000oooool2o`00
00Kooooo0_l00004ooooo`Co000000?oooooo`000?l000003Oooool2o`0000?ooooo0_l00005oooo
o`;o00000oooool2o`0000Wooooo2Ol00002ooooo`;o00001?ooool2o`0000kooooo0_l00006oooo
o`Go000000?oooooo`000?l000000_l0000:ooooo`;o00002?ooool5o`0000Cooooo0_l00003oooo
o`Co00007_ooool2o`0004cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46
ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0kooooo`;o000000Cooooo
o`000?l0003ooooo0_l000000ooooooo0000o`000005ooooo`;o000000Coooooo`000?l0003o0000
1?ooool2o`0000;ooooo0_l0000Booooo`;o00001Oooool3o`0000;ooooo0_l000000ooooooo0000
o`000003ooooo`;o00000_ooool<o`0000Cooooo0_l00005ooooo`;o00001oooool2o`0000Kooooo
0_l000001?oooooo0000o`000?l00002ooooo`;o00001?ooool5o`000003ooooool0003o000000_o
oooo1?l00002ooooo`;o00001Oooool2o`0001kooooo0_l000000ooooooo0000o`000019ooooo`00
00KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo03Kooooo0_l0000<ooooo`;o00001Oooool6o`0000Cooooo1?l00004oooo
o`;o00000oooool2o`0000;ooooo0_l0000=ooooo`Go00000_ooool2o`0000;ooooo1?l000000ooo
oooo0000o`000009o`0000;ooooo0_l00007ooooo`?o00002_ooool2o`0000Oooooo0_l00002oooo
o`;o00001?ooool5o`0000kooooo1?l0000Yooooo`;o000000?oooooo`000?l000001Oooool2o`00
04;ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006ooooo`03
o`000?oooooooooo03Kooooo0_l0000Booooo`Co000000?oooooo`000?l000001?ooool4o`0000Co
oooo0_l00003ooooo`;o00000_ooool3o`0000gooooo1Ol00005oooooa3o00000_ooool2o`0000Oo
oooo0_l00009ooooo`Co00000_ooool2o`0000Oooooo0_l00003ooooo`Co00004?ooool4o`0002Wo
oooo0_l00002ooooo`?o00000oooool2o`0004;ooooo00000ooooooo0000ooooo`02ooooo`03o`00
0?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`0004[ooooo0_l00002ooooo`?o
00001?ooool8o`0000?ooooo1_l000000ooooooo0000o`000002o`0000kooooo0_l00005oooooa3o
00001Oooool2o`0000?ooooo0_l0000:ooooo`;o00001?ooool2o`0000cooooo0_l00002ooooo`;o
00000oooool4o`0000Oooooo1ol0000Vooooo`?o000000Coooooo`000?l0003o0000Aoooool00003
ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?oMgMgoEEEEooooool00007oooo
o`03o`000?oooooooooo04Gooooo0_l00007ooooo`;o00001oooool6o`000003ooooool0003o0000
00So000000?oooooo`000?l000001_ooool2o`0000Wooooo0_l00004oooooa7o00000_ooool2o`00
00?ooooo0_l0000Rooooo`;o00000_ooool5o`0000Oooooo2?l000000ooooooo0000o`000002oooo
o`;o00000_ooool2o`0001[ooooo0ol000000ooooooo0000o`000018ooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooooooo
ool0AOooool2o`0000cooooo5Ol00007ooooo`Go00002?ooool2o`0000Cooooo2?l000000ooooooo
0000o`000006o`0000?ooooo0_l0000Xooooo`Co00002Oooool9o`000003ooooool0003o000000;o
oooo0_l000001?oooooo0000o`000?l0000Jooooo`;o0000C?ooool00006oooooomgMgOoV9RHoooo
oonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo03kooooo0_l00004
ooooo`;o00003OoooolGo`000003ooooool0003o000000;ooooo1Ol00002ooooo`;o00000_ooool3
o`0000;ooooo0_l00002ooooo`oo00001?ooool2o`0001[ooooo0_l0000:ooooo`Co00002oooool2
o`0000?ooooo1_l000000ooooooo0000o`000003ooooo`?o00006Oooool3o`0000;ooooo0_l00018
ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o
0000ooooooooool0?_ooool2o`0000Cooooo0_l0000;ooooo`?o000000?oooooo`000?l000005_l0
0002ooooo`Co00000oooool2o`0000;ooooo0ol00002ooooo`;o00000_ooool>o`00023ooooo0ol0
0009ooooo`?o00001Oooool4o`0000Cooooo0ol00003ooooo`;o000000Coooooo`000?l0003ooooo
0_l00004ooooo`;o00006Oooool3o`0000;ooooo0_l0000Aooooo`;o0000=Oooool001cooooo00?o
0000ooooooooool0A_ooool2o`0000Oooooo8Ol00007ooooo`;o00002_ooool=o`00027ooooo0_l0
000:ooooo`;o00001_ooool6o`0000?ooooo0_l0000hooooo`Co00001_ooool2o`0003Gooooo000L
ooooo`03o`000?oooooooooo03_ooooo0_l00004ooooo`;o00000oooool2o`0000Oooooo0ol00002
oooooaco00000oooool2o`0000;ooooo0_l00004ooooo`;o00000oooool=o`0000[ooooo1?l0000:
ooooo`;o00004_ooool2o`0000Cooooo0ol00005ooooo`;o0000<?ooool2o`0000;ooooo0_l00000
0ooooooo0000o`000004ooooo`Co0000?Oooool001cooooo00?o0000ooooooooool0>oooool2o`00
00Cooooo0_l0000:ooooo`Go00001?oooolKo`0000;ooooo0_l00008ooooo`;o00000oooool>o`00
00Wooooo1_l00008ooooo`;o00004_ooool2o`0000Cooooo0ol0000Iooooo`;o00000_ooool2o`00
01Sooooo0_l00002ooooo`;o000000?oooooo`000?l000001?ooool3o`0003kooooo000Looooo`03
o`000?oooooooooo03kooooo0_l0000=ooooo`Go00001Oooool;o`000003ooooool0003o000000co
00002oooool3o`0000Gooooo3Ol0000:ooooo`Co00002_ooool2o`0001Kooooo0_l0000Aooooo`;o
00001oooool2o`0000;ooooo0ol0000Kooooo`Go00000oooool3o`0003oooooo000Looooo`03o`00
0?oooooooooo03kooooo0_l00008ooooo`?o00000oooool2o`0000?ooooo7?l00003ooooo`;o0000
1oooool6o`0000Kooooo0_l00002ooooo`;o00000_ooool4o`0000Gooooo0_l0000?ooooo`;o0000
7?ooool2o`0000_ooooo0_l0000<ooooo`;o00006oooool5o`0000?ooooo0_l00010ooooo`007?oo
ool00ol0003oooooooooo`18ooooo`?o00000ooooolQo`0000?ooooo0_l00007ooooo`?o000000?o
ooooo`000?l000000_l00005ooooo`?o00001_ooool2o`0000Cooooo1Ol0000@ooooo`?o000000?o
ooooo`000?l000005Oooool2o`0000Wooooo0_l00008ooooo`;o00009?ooool2o`0004Gooooo000L
ooooo`03o`000?oooooooooo04;ooooo0_l00009ooooo`;o000000?oooooo`000?l000007ol0000@
ooooo`;o00001Oooool3o`0000cooooo1_l0000?ooooo`?o000000?oooooo`000?l000001_ooool2
o`0000;ooooo0_l0000Dooooo`;o00002?ooool2o`0006_ooooo000Looooo`03o`000?oooooooooo
043ooooo1?l00007ooooo`Co00001_oooolLo`0000gooooo1?l0000Booooo`;o00000_ooool5o`00
01_ooooo0_l00002ooooo`;o0000>_ooool2o`0004oooooo000Looooo`03o`000?oooooooooo043o
oooo0ol00004ooooo`Oo000000?oooooo`000?l000000_l00003oooooa_o00003Oooool4o`0001;o
oooo0_l00002ooooo`?o00007Oooool2o`0002kooooo0_l0000>ooooo`Co00002oooool2o`00043o
oooo000Looooo`03o`000?oooooooooo04Oooooo1?l000001?oooooo0000o`000?oooolQo`0000Go
oooo0_l00006ooooo`?o00006oooool2o`0001Sooooo0_l00008ooooo`;o00009oooool2o`00013o
oooo0_l0000:ooooo`?o00002Oooool2o`0003Gooooo000Looooo`03o`000?oooooooooo04Cooooo
1?l0000;oooooago00001Oooool2o`000003ooooool0003o000000?ooooo0_l0000Iooooo`;o0000
00?oooooo`000?l000006?ooool2o`0000Sooooo0_l00006ooooo`;o00005?ooool2o`0000Wooooo
0_l0000Looooo`;o00002_ooool3o`0003Cooooo000Looooo`;o0000?oooool2o`0000Cooooo1?l0
000<ooooo`?o000000?oooooo`000?l000005_l00005ooooo`;o000000Coooooo`000?l0003ooooo
0_l0000Eooooo`;o00000oooool3o`0000?ooooo1Ol0000Uooooo`;o00005?ooool2o`0000Cooooo
0ol00003ooooo`;o00005_ooool3o`0000?ooooo1?l00008ooooo`;o0000=?ooool001cooooo00?o
0000ooooooooool0?_ooool2o`0000Kooooo0_l000000ooooooo0000o`00000:ooooo`;o000000?o
ooooo`000?l000004_l00007ooooo`;o00001_ooool2o`0001;ooooo1Ol00003ooooo`go00005Ooo
ool2o`0000;ooooo0_l0000Looooo`;o00001_ooool3o`0000?ooooo0_l0000Fooooo`?o00000ooo
ool4o`0003kooooo000Looooo`03o`000?oooooooooo03Cooooo0_l0000>ooooo`Oo00003?oooolE
o`0000Oooooo0_l0000Jooooo`Ko000000?oooooo`000?l000002?l00002ooooo`;o00002_ooool2
o`0000Wooooo0_l00002ooooo`;o00001?ooool4o`0001Cooooo0_l00007ooooo`Co00004Oooool2
o`0004kooooo000Looooo`03o`000?oooooooooo03Cooooo0_l00007ooooo`;o00001Oooool5o`00
00kooooo4ol0000?ooooo`;o00006?ooool2o`000003ooooool0003o000000Go000000?oooooo`00
0?l000003_ooool2o`0000gooooo0_l000001?oooooo0000o`000?ooool4o`0000?ooooo0ol0000G
ooooo`Co00004Oooool2o`0004kooooo000Looooo`03o`000?oooooooooo03_ooooo1?l00005oooo
o`?o00002Oooool2o`0000Cooooo0ol000001?oooooo0000o`000?l00003ooooo`?o000000?ooooo
o`000?l000000_l000000ooooooo0000o`00000<ooooo`Co00002oooool2o`0000Kooooo0_l00002
ooooo`?o000000?oooooo`000?l000000_l00003ooooo`?o00007oooool3o`0000Kooooo1_l00007
ooooo`;o00002Oooool2o`0000Oooooo1?l00008ooooo`;o00003oooool4o`0003oooooo000Loooo
o`03o`000?oooooooooo03_ooooo0_l0000Cooooo`;o000000Coooooo`000?l0003ooooo0_l00000
1?oooooo0000o`000?ooool2o`0000?ooooo0_l00002ooooo`?o000000?oooooo`000?l000003?oo
ool3o`0000cooooo1?l00004ooooo`;o00000_ooool3o`0000?ooooo0ol00002ooooo`Go00005_oo
ool4o`0000?ooooo0_l00007ooooo`?o000000?oooooo`000?l000002Ol00009ooooo`;o00001ooo
ool4o`0000Oooooo0ol00009ooooo`?o00000oooool4o`0003oooooo000Looooo`03o`000?oooooo
oooo05?ooooo0_l00004ooooo`;o000000Coooooo`000?l0003o00001_ooool2o`0000Gooooo0_l0
000:ooooo`;o00003_ooool3o`0000?ooooo0_l00009ooooo`?o00000_ooool4o`0001Kooooo1Ol0
0007ooooo`;o00001Oooool2o`000003ooooool0003o000000Go00007oooool2o`0000[ooooo0ol0
0016ooooo`007?ooool00ol0003oooooooooo`0booooo`;o00001_ooool2o`0000gooooo0ol00002
ooooo`;o00001oooool2o`000004ooooool0003o0000ooooo`;o00003Oooool2o`0000Oooooo0_l0
000Booooo`;o00001_ooool3o`0000?ooooo0_l000000ooooooo0000o`000004o`0000oooooo0_l0
00000ooooooo0000o`000003ooooo`;o00000_ooool;o`000003ooooool0003o000000;ooooo0_l0
00000ooooooo0000o`000008o`00027ooooo0_l00006ooooo`;o00000_ooool2o`0004;ooooo000L
ooooo`03o`000?oooooooooo03;ooooo0_l00003ooooo`;o000000Coooooo`000?l0003o00003?oo
ool3o`0000;ooooo0_l00007ooooo`Go00002Oooool2o`0000kooooo0_l00003ooooo`;o00003_oo
ool2o`0000Gooooo0ol000000ooooooo0000o`000002o`0000?ooooo0ol00007ooooo`;o00001ooo
ool2o`000003ooooool0003o000000?ooooo0_l00002oooooa3o00000oooool5o`000003ooooool0
003o000000Go00002?ooool3o`0001?ooooo0_l00006ooooo`;o00000_ooool2o`0004;ooooo000L
ooooo`03o`000?oooooooooo03Oooooo0_l00002ooooo`;o00003?ooool2o`0000gooooo0_l0000;
ooooo`Co00004Oooool2o`000003ooooool0003o000000[ooooo0ol00002ooooo`;o00001Oooool2
o`0000?ooooo1Ol00006ooooo`?o00000_ooool2o`0000;ooooo0_l00002ooooo`;o00002oooool@
o`0000Wooooo0ol00007ooooo`Co00003_ooool2o`0000_ooooo0_l00002ooooo`;o0000@_ooool0
01cooooo00?o0000ooooooooool0BOooool2o`0000?ooooo0ol00006ooooo`?o00003Oooool2o`00
00gooooo0_l00005ooooo`Co00001?ooool3o`000003ooooool0003o000000?ooooo1?l00003oooo
o`Wo00001oooool2o`0000;ooooo1?l000000ooooooo0000o`000002ooooo`;o00000_ooool2o`00
00Cooooo2ol00003ooooo`Go00002_ooool4o`0000Gooooo0_l0000@ooooo`;o00003oooool2o`00
00Gooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`1>ooooo`?o00001_ooool2o`0000co
oooo0_l0000?ooooo`;o00001Oooool4o`0000Cooooo0ol00008ooooo`;o00001Oooool6o`0000co
oooo1?l00009ooooo`Co00000_ooool5o`000004ooooool0003o0000ooooo`;o00000oooool5o`00
00Cooooo0_l00004ooooo`Co00001_ooool2o`000003ooooool0003o000000gooooo0_l0000>oooo
o`;o00001Oooool2o`0000Cooooo0_l0000eooooo`007?ooool00ol0003oooooooooo`0jooooo`;o
00005Oooool2o`0001;ooooo0_l00009ooooo`;o00002oooool3o`000003ooooool0003o000000?o
oooo0_l00002ooooo`;o00000_ooool4o`0000;ooooo0_l000000ooooooo0000o`000004o`0000[o
oooo0_l00002ooooo`;o000000?oooooo`000?l000002?ooool<o`0000Cooooo1_l00005ooooo`?o
00000oooool2o`000003ooooool0003o000000?o00000_ooool5o`0000gooooo0_l0000:ooooo`;o
00003oooool2o`0003Gooooo000Looooo`03o`000?oooooooooo03Oooooo0_l000000ooooooo0000
o`000003ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Oooooo0_l00007ooooo`Co0000
4_ooool2o`0000_ooooo0ol000000ooooooo0000o`000002o`000005ooooool0003o0000o`000?oo
ool00_l00002ooooo`;o00001?ooool2o`0000;ooooo1?l0000;ooooo`;o00000_ooool2o`000003
ooooool0003o000000Wooooo1?l00002ooooo`ko00001_ooool3o`0000Kooooo1Ol00004ooooo`?o
00000_ooool3o`0001Cooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`0eooooo`Co0000
1_ooool2o`000003ooooool0003o000000Cooooo1?l00002ooooo`;o00001Oooool2o`000003oooo
ool0003o000000Co000000?oooooo`000?l000006oooool2o`0000Cooooo0ol00002ooooo`;o0000
00Coooooo`000?l0003ooooo0ol00006ooooo`Go00002oooool3o`0000Kooooo0_l00006ooooo`;o
00000_ooool2o`000003ooooool0003o000000go000000Coooooo`000?l0003o00000_ooool7o`00
0004ooooool0003o0000ooooo`?o00001Oooool2o`0000;ooooo0ol0000=ooooo`;o00001?ooool3
o`0000kooooo0_l0000fooooo`007?ooool00ol0003oooooooooo`0cooooo`Co00004Oooool8o`00
00Gooooo1Ol00005ooooo`;o00003oooool2o`0000[ooooo0_l0000;ooooo`;o00000_ooool3o`00
00Kooooo1Ol00003ooooo`;o00000_ooool7o`0000Kooooo0_l00003ooooo`Go00000_oooolOo`00
0004ooooool0003o0000ooooo`;o00001_ooool3o`0000;ooooo1Ol00004ooooo`;o00001?ooool2
o`0000Cooooo0ol00008ooooo`;o00001?ooool2o`0003Kooooo000Looooo`;o0000=?ooool2o`00
00?ooooo0_l0000Booooo`;o00002?ooool2o`000004ooooool0003o0000o`00013ooooo0ol00000
0ooooooo0000o`000007ooooo`;o00001oooool4o`0000?ooooo0_l00002ooooo`;o00001Oooool5
o`0000Gooooo0_l00002ooooo`Go00001oooool2o`0000Cooooo1_l000000ooooooo0000o`000004
o`000003ooooool0003o000001Go00001Oooool2o`0000Cooooo0_l000000ooooooo0000o`000004
ooooo`?o00001?ooool2o`0001Gooooo0_l0000looooo`007?ooool00ol0003oooooooooo`0hoooo
o`;o00002?ooool2o`0000Wooooo0ol00003ooooo`;o000000Coooooo`000?l0003ooooo0ol0000@
ooooo`?o00002_ooool2o`000003ooooool0003o000000Cooooo1?l00003ooooo`?o000000?ooooo
o`000?l000000oooool6o`0000?ooooo0_l00003ooooo`Go00002Oooool2o`0000Cooooo1_l00000
0ooooooo0000o`000003o`000003ooooool0003o000001;o00000_ooool2o`0000Gooooo0_l00004
ooooo`;o00004?ooool2o`00057ooooo000Looooo`03o`000?oooooooooo03Sooooo0_l000000ooo
oooo0000o`000005ooooo`;o00002Oooool3o`0000?ooooo0_l000000ooooooo0000o`000008oooo
o`;o00001oooool3o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`;o00000_ooool2o`00
00?ooooo0_l000000ooooooo0000o`000002o`000004ooooool0003o0000o`0000Cooooo2?l00002
ooooo`?o00000oooool2o`000003ooooool0003o000000;ooooo0_l00008ooooo`[o00000_oooolN
o`0000_ooooo0_l0000=ooooo`?o00000_ooool2o`0000cooooo0_l0000oooooo`007?ooool00ol0
003oooooooooo`0hooooo`;o000000?oooooo`000?l000006Oooool7o`0000?ooooo0_l00007oooo
o`?o00001?ooool2o`000004ooooool0003o0000ooooo`Co00001oooool2o`000003ooooool0003o
000000;o00002?ooool6o`0000Cooooo0_l00007ooooo`;o00000_ooool2o`0000Cooooo0_l00002
ooooo`Co00000_ooool4o`0000Cooooo7_l00009ooooo`;o00003?ooool3o`0000?ooooo0_l0000<
ooooo`;o00001_ooool2o`0003Oooooo000Looooo`03o`000?oooooooooo03kooooo0_l0000Goooo
o`Oo00002oooool3o`0000Oooooo0_l000000ooooooo0000o`00000<ooooo`;o00003?ooool6o`00
00Sooooo0_l0000;ooooo`;o00000_ooool6o`0000;ooooo9ol00006ooooo`;o00003?ooool2o`00
00Cooooo0_l0000Dooooo`;o0000=oooool001cooooo00?o0000ooooooooool0?_ooool2o`0001Oo
oooo1?l000000ooooooo0000o`00000;ooooo`Co00003_ooool2o`0000Cooooo0_l000001?oooooo
0000o`000?l00009ooooo`Wo00000oooool3o`000003ooooool0003o000000;ooooo0_l00004oooo
o`;o00001Oooool2o`000003ooooool0003o000002Go00000_ooool5o`0000Cooooo0_l0000<oooo
o`;o00001?ooool2o`0000gooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o
000000?oooooo`000?l000001_ooool2o`0000gooooo0ol00004ooooo`;o00000_ooool2o`0000So
oooo1Ol00003ooooo`;o000000?oooooo`000?l000001ol000000ooooooo0000o`000004ooooo`;o
00001?ooool2o`000003ooooool0003o000000Go000000?oooooo`000?l000000oooool2o`000003
ooooool0003o000001Co00001?ooool5o`0000Oooooo0_l00003ooooo`;o00002?ooool2o`0000oo
oooo0_l00003ooooo`;o0000>Oooool001cooooo00?o0000ooooooooool0>?ooool2o`0000Sooooo
0_l0000Cooooo`;o00001oooool2o`000003ooooool0003o000001;ooooo0_l000000ooooooo0000
o`000005ooooo`;o00001Oooool2o`0000Gooooo1Ol00006ooooo`?o00000_ooool4o`0000gooooo
1ol000000ooooooo0000o`000004o`000003ooooool0003o0000027o00000_ooool2o`0000?ooooo
0_l00002ooooo`Ko00001Oooool2o`0001Cooooo0_l0000iooooo`007?ooool00ol0003ooooooooo
o`0hooooo`;o00002?ooool2o`0001?ooooo0_l0000>ooooo`;o00001Oooool2o`0000Oooooo0_l0
00001?oooooo0000o`000?l00004ooooo`;o00001Oooool2o`0000Sooooo0_l0000;ooooo`Co0000
3Oooool4o`0000Cooooo3Ol000000ooooooo0000o`00000Io`0000?ooooo0_l00007ooooo`Ko0000
3_ooool2o`0004Kooooo000Looooo`03o`000?oooooooooo03Sooooo1?l00005ooooo`;o00004_oo
ool3o`0000cooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000;o000000Go
ooooo`000?l0003o0000ooooo`04o`000003ooooool0003o000000?o00000_ooool2o`00013ooooo
0_l00003ooooo`;o00001Oooool2o`0000oooooo1Ol00002ooooobko00000_ooool2o`0000Sooooo
0_l00002ooooo`;o00002_ooool2o`0000Gooooo0_l00003ooooo`;o0000>_ooool001cooooo00?o
0000ooooooooool0>_ooool2o`000003ooooool0003o000000;ooooo0_l0000Booooo`?o00003?oo
ool2o`000003ooooool0003o000000;o000000?oooooo`000?l000000_l000001Ooooooo0000o`00
0?l0003ooooo00Co00000oooool5o`0001;ooooo0_l000000ooooooo0000o`000002o`0000Gooooo
0_l00002ooooo`;o00000_ooool2o`0000Kooooo1_l00002ooooo`[o000000?oooooo`000?l00000
8Ol00002ooooo`;o000000?oooooo`000?l000001Oooool7o`00013ooooo0ol00002ooooo`;o0000
>_ooool001cooooo00?o0000ooooooooool0??ooool3o`0000Sooooo0ol0000Mooooo`Co00005?oo
ool3o`00013ooooo0_l00002ooooo`;o00001?ooool2o`000003ooooool0003o000000;ooooo0_l0
0002ooooo`Co000000Coooooo`000?l0003ooooo1Ol00004ooooo`Go000000?oooooo`000?l00000
7ol00007ooooo`?o000000?oooooo`000?l000000oooool6o`000003ooooool0003o0000017ooooo
0_l0000nooooo`007?ooool00ol0003oooooooooo`0looooo`?o00002?ooool3o`0002[ooooo0_l0
00000ooooooo0000o`000007ooooo`;o00004?ooool2o`0000Sooooo0_l00003ooooo`;o00001Ooo
ool3o`000003ooooool0003o000000;o000000Coooooo`000?l0003o00000ooooolYo`0000Kooooo
0_l00007ooooo`?o00001Oooool2o`00053ooooo000Looooo`03o`000?oooooooooo03Oooooo1?l0
0002ooooo`Co00002oooool2o`0002Kooooo0_l000000ooooooo0000o`000004ooooo`Oo00000_oo
ool2o`0001Cooooo0ol00002ooooo`;o00001Oooool3o`000003ooooool0003o000000Ko00000_oo
ool;o`000003ooooool0003o000001co00000_ooool2o`0000cooooo0_l00002ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0004cooooo000Looooo`03o`000?oooooooooo03Oooooo1?l00003
ooooo`?o00002oooool2o`00027ooooo0_l0000<ooooo`Oo00000_ooool2o`0001Gooooo0_l00002
ooooo`?o00001Oooool2o`000005ooooool0003o0000o`000?ooool01Ol000000ooooooo0000o`00
0009o`000003ooooool0003o000001co00000_ooool2o`0000Oooooo0_l00003ooooo`;o00000_oo
ool2o`0000Gooooo0_l0000=ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0>?ooool3
o`0003Cooooo0_l00002ooooo`;o00003?ooool2o`0001Gooooo0_l00002ooooo`;o00000oooool3
o`0000Kooooo0_l000001?oooooo0000o`000?ooool6o`000003ooooool0003o000002Go00001?oo
ool4o`0000Gooooo0_l0000Mooooo`;o0000?Oooool001cooooo0_l0000mooooo`;o000000?ooooo
o`000?l00000<Oooool3o`0002?ooooo0_l00002ooooo`Go000000Coooooo`000?l0003o00001Ooo
ool5o`0000?ooooo1?l000000ooooooo0000o`00000To`0000Oooooo0_l00009ooooo`;o00002_oo
ool2o`0000Sooooo1?l00010ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00000_ooool2
o`000003ooooool0003o000000?ooooo0_l0000/ooooo`;o00003oooool2o`0001?ooooo0_l00004
ooooo`?o000000?oooooo`000?l000000_l00006ooooo`?o00001Oooool2o`000003ooooool0003o
0000023o00000_ooool3o`0000Kooooo1?l00004ooooo`;o000000?oooooo`000?l000000_l00008
ooooo`;o00002?ooool4o`00043ooooo000Looooo`03o`000?oooooooooo03Sooooo1Ol00007oooo
o`?o0000??ooool2o`0000?ooooo0_l0000Hooooo`Co00000_ooool2o`0000?ooooo0_l00005oooo
ob[o000000?oooooo`000?l000001Oooool2o`0000Cooooo0_l000000ooooooo0000o`000002o`00
0003ooooool0003o000000Cooooo0_l00009ooooo`;o000000?oooooo`000?l00000?oooool001co
oooo00?o0000ooooooooool0<Oooool2o`0000Oooooo1ol00004ooooo`;o0000?Oooool2o`0000;o
oooo0_l0000Jooooo`;o00000_ooool2o`0000Kooooo0_l00003ooooo`;o000000?oooooo`000?l0
00009?l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000oooool2o`0000Co
oooo0_l000000ooooooo0000o`000004ooooo`;o00002Oooool2o`000003ooooool0003o000003oo
oooo000Looooo`03o`000?oooooooooo037ooooo0_l00007ooooo`Oo000000?oooooo`000?l00000
=Oooool2o`0000Wooooo0_l00002ooooo`;o00007oooool2o`0000Gooooo0_l00004ooooob?o0000
0oooool2o`0000Gooooo0_l00006ooooo`Co00001?ooool2o`0005Cooooo000Looooo`03o`000?oo
oooooooo037ooooo0_l000000ooooooo0000o`000006ooooo`Go000000?oooooo`000?l00000:?oo
ool3o`0000[ooooo0ol00008ooooo`;o00000_ooool4o`0000?ooooo0_l00007ooooo`;o00002Ooo
ool2o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l000001?ooool@o`000003ooooool0
003o0000013o00000oooool2o`0000Gooooo0_l00006ooooo`Co00001?ooool2o`0000;ooooo0_l0
0006ooooo`;o00000oooool2o`0000_ooooo0_l0000fooooo`007?ooool00ol0003oooooooooo`0d
ooooo`;o00001Oooool2o`0000;ooooo0_l0000[ooooo`?o00000oooool4o`0000Cooooo0_l00004
ooooo`;o00000_ooool2o`0000;ooooo1?l00003ooooo`;o000000?oooooo`000?l000001?ooool2
o`0000Wooooo0_l00004ooooo`Ko00001oooool4o`000003ooooool0003o000001co00000oooool2
o`0000Cooooo0_l00006ooooo`Go00000_ooool2o`0000Cooooo0_l00006ooooo`;o00000_ooool3
o`0000Kooooo0_l00003ooooo`;o0000=_ooool001cooooo00?o0000ooooooooool0>?ooool2o`00
0004ooooool0003o0000ooooo`;o0000;_ooool2o`0000;ooooo1?l0000:ooooo`?o00001Oooool4
o`0000Kooooo0_l0000>ooooo`;o000000?oooooo`000?l000001?ooool3o`0000Sooooo1?l00000
0ooooooo0000o`00000Lo`0000Wooooo0_l00006ooooo`;o000000?oooooo`000?l000000_ooool2
o`0000oooooo0ol00007ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0>?ooool2o`00
00Cooooo0_l000000ooooooo0000o`00000Wooooo`;o00000_ooool2o`00017ooooo0_l00003oooo
o`Co00003_ooool2o`0000Sooooo1Ol00005ooooo`;o00002_ooool2o`0000;ooooo6_l00003oooo
o`;o00001Oooool4o`0000Sooooo0_l0000Booooo`Co0000AOooool001cooooo00?o0000oooooooo
ool0>Oooool2o`0000Cooooo1?l0000Wooooo`Go00000oooool2o`0000[ooooo0_l00006ooooo`Co
00002?ooool2o`0000Cooooo0_l0000:ooooo`;o00005_oooolEo`000003ooooool0003o000000?o
00000_ooool2o`0000Gooooo0ol00004ooooo`;o00000oooool2o`0000gooooo0_l00002ooooo`?o
0000Aoooool001cooooo00?o0000ooooooooool0>Oooool2o`0000Cooooo0_l0000[ooooo`?o0000
0oooool3o`0000Wooooo0_l00004ooooo`;o000000Coooooo`000?l0003o00002?ooool2o`0001go
oooo0_l00007ooooo`?o000000?oooooo`000?l000001_l000000ooooooo0000o`000008o`000004
ooooool0003o0000ooooo`;o000000?oooooo`000?l000003?ooool3o`0001;ooooo1_l0000<oooo
o`;o0000>_ooool001cooooo00?o0000ooooooooool0=oooool2o`0002Kooooo0_l0000Booooo`;o
00003oooool2o`000004ooooool0003o0000o`0000Cooooo0_l000000ooooooo0000o`000002o`00
00gooooo0_l00002ooooo`;o00002Oooool2o`0000Oooooo1?l00002ooooo`[o000000?oooooo`00
0?l000001?l000000ooooooo0000o`000004ooooo`;o00002_ooool6o`0000Wooooo0_l00007oooo
o`Co00000_ooool2o`0000Gooooo0_l00002ooooo`;o0000>_ooool001cooooo00?o0000oooooooo
ool0=oooool2o`0002Kooooo0_l0000=ooooo`;o00001?ooool3o`0000[ooooo0_l000001?oooooo
0000o`000?l00007ooooo`;o000000?oooooo`000?l000000_l0000;ooooo`Co00000_ooool2o`00
01?ooooo0ol00003ooooo`?o000000?oooooo`000?l000000_l00002ooooo`?o00001?ooool2o`00
00[ooooo0_l00003ooooo`Oo00002Oooool2o`0000Cooooo0_l00007ooooo`;o00001Oooool2o`00
03kooooo000Looooo`03o`000?oooooooooo037ooooo0_l00004ooooo`;o00003?ooool2o`0001[o
oooo0_l00008ooooo`Go00001?ooool3o`0000Gooooo0ol00002ooooo`;o000000?oooooo`000?l0
00000ol0000Gooooo`;o000000?oooooo`000?l000000_ooool2o`0001;ooooo1?l000000ooooooo
0000o`000003o`000003ooooool0003o000000;o00003?ooool3o`0000Gooooo0_l000000ooooooo
0000o`000002o`000003ooooool0003o0000017ooooo0_l00004ooooo`;o00002oooool2o`0003_o
oooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000
oa0@4?o<c<`01_ooool00ol0003oooooooooo`0aooooo`;o00004_ooool2o`0001Sooooo1_l00000
0ooooooo0000o`000003ooooo`?o00001_ooool2o`0000Kooooo0ol00005ooooo`Go00006_ooool2
o`0000;ooooo0_l00005ooooo`Co00002oooool8o`0000?ooooo1?l00007ooooo`;o000000Cooooo
o`000?l0003o00002?ooool9o`0000?ooooo0_l00006ooooo`?o00001oooool2o`0000_ooooo0_l0
000kooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMg
oooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0Goooool2o`000005ooooool0003o0000o`00
0?ooool00_l000000ooooooo0000o`000006o`0000Gooooo0_l0000;ooooo`Co00003Oooool2o`00
01;ooooo0_l00002ooooo`Ko00003?ooool4o`0000;ooooo0_l00004ooooo`;o000000Coooooo`00
0?l0003o00000oooool5o`0000cooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l00006
ooooo`?o00001_ooool2o`000003ooooool0003o000004Kooooo00000ooooooo410@ooooo`02oooo
o`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo02kooooo0_l0000hoooooa3o00002_ooool4o`0000kooooo0_l0000Booooo`;o00000_ooool2
o`00017ooooo0ol00002ooooo`Co00000_ooool6o`000003ooooool0003o000000Co000000?ooooo
o`000?l000000oooool2o`0000cooooo0_l00002ooooo`;o00002_ooool5o`000003ooooool0003o
000004Kooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oiRH
V?ooooooV9RHob4Q8@06ooooo`?o0000;_ooool2o`0002oooooo0ol00006ooooo`ko00003?ooool4
o`0002Kooooo0_l00003ooooo`;o00002_ooool2o`0000?ooooo0_l00002ooooo`Co000000?ooooo
o`000?l000000ol000000ooooooo0000o`000003o`0000;ooooo2Ol0000>ooooo`;o000000Cooooo
o`000?l0003ooooo0_l00004ooooo`?o0000Boooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool02Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0;_oo
ool2o`0000Wooooo0_l0000Tooooo`?o000000?oooooo`000?l000004_l0000<ooooo`?o000000?o
ooooo`000?l000006_ooool2o`0000?ooooo1_l00002ooooo`?o00002_ooool2o`0000?ooooo0_l0
0004ooooo`?o000000?oooooo`000?l000000_ooool4o`0000Gooooo1?l00002ooooo`;o00001ooo
ool2o`0000Sooooo1_l00002ooooo`Co0000Boooool00003ooooool@413ooooo00;ooooo00?o410@
ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo02kooooo0_l00009
ooooo`;o00009?ooool2o`0000;ooooo5?l000001?oooooo0000o`000?l00007ooooo`?o00000_oo
ool2o`0000_ooooo0_l0000=ooooo`;o000000?oooooo`000?l000001?l00002ooooo`Co00001ooo
ool2o`0000gooooo0ol00005ooooo`;o00001oooool2o`0000gooooo0_l00004ooooo`;o00001?oo
ool4o`0000;ooooo0_l0001=ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgM
gOl@413oV9RH00Sooooo00?o0000ooooooooool0=oooool2o`0002Kooooo0_l000000ooooooo0000
o`00000Bo`0000;ooooo0ol00007ooooo`Go00003Oooool2o`0000?ooooo0_l0000;ooooo`;o0000
1_ooool2o`0000Cooooo0_l00003ooooo`;o0000;Oooool2o`0000Cooooo0ol000000ooooooo0000
o`000006ooooo`;o0000COooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<co
A4A4o`000?l@4106ooooo`03o`000?oooooooooo03Oooooo0_l0000YoooooaSo00002?ooool2o`00
0003ooooool0003o000001;ooooo0_l00003ooooo`;o00001?ooool2o`000003ooooool0003o0000
00;ooooo0_l00006ooooo`Oo00005_ooool2o`0000Sooooo0_l000000ooooooo0000o`000002o`00
00Oooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000001Oooool3o`00
04gooooo000Looooo`03o`000?oooooooooo063ooooo0ol00002oooooaGo00002?ooool2o`000003
ooooool0003o000001Oooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0ol00006oooo
o`;o000000?oooooo`000?l000000_l00004ooooo`;o00004?ooool2o`0000;ooooo0ol000000ooo
oooo0000o`000002o`000003ooooool0003o000000?o00002Oooool2o`0000;ooooo0_l000001?oo
oooo0000o`000?l00004ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0H?oooolDo`00
0003ooooool0003o000000;o00000_ooool2o`0000Gooooo0_l000000ooooooo0000o`00000Poooo
o`Ko00003_ooool5o`0000gooooo0_l00005ooooo`?o000000?oooooo`000?l000000_l00004oooo
o`;o00003Oooool2o`0000;ooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o
0000;ooooolHo`0000?ooooo0_l0000Aooooo`;o00004?ooool2o`0000Gooooo0ol0000>ooooo`;o
000000?oooooo`000?l000001_l0000:ooooo`;o00001oooool2o`000004ooooool0003o0000o`00
01;ooooo0ol0001Hooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00006Oooool2o`0001;o
oooo6_l0000:ooooo`?o00002Oooool3o`0000;ooooo0_l00005ooooo`;o00001?ooool2o`0001Ko
oooo1?l000001?oooooo0000o`000?ooool3o`0000?ooooo0_l00009ooooo`Co000000?oooooo`00
0?l000005_ooool2o`0005Wooooo000Looooo`03o`000?oooooooooo03_ooooo0ol0000<ooooo`;o
00004_ooool8o`0000;ooooo2?l000000ooooooo0000o`000008o`0000Oooooo0ol0000:ooooo`;o
000000Coooooo`000?l0003o00001Oooool2o`0001kooooo1Ol00007ooooo`;o00002Oooool4o`00
07Cooooo000Looooo`03o`000?oooooooooo03_ooooo0ol00007ooooo`;o00005ooooolOo`0001Go
oooo0_l00006ooooo`;o00004Oooool2o`0000_ooooo1?l000001?oooooo0000o`000?l00008oooo
o`;o00001oooool2o`00017ooooo1_l00002ooooo`;o0000FOooool001cooooo00?o0000oooooooo
ool0AOooool2o`0001?ooooo1?l000000ooooooo0000o`00000Lo`00017ooooo0_l0000Mooooo`?o
00003oooool3o`0000Sooooo1?l0000Hooooo`Ko00000_ooool2o`0005Wooooo000Looooo`03o`00
0?oooooooooo05Sooooo8ol0000Cooooo`;o00007_ooool2o`0000_ooooo0_l0000=ooooo`Co0000
1?ooool2o`0007Gooooo000Looooo`03o`000?oooooooooo05Sooooo7?l000000ooooooo0000o`00
0004o`0000Kooooo0_l0000Booooo`;o00000_ooool2o`0000Gooooo0ol0000Hooooo`;o00001Ooo
ool2o`000003ooooool0003o000000[ooooo0ol0000Cooooo`;o0000H?ooool001cooooo00?o0000
ooooooooool0F?ooool2o`000003ooooool0003o000001co000000?oooooo`000?l000001Oooool4
o`0000kooooo1?l00002ooooo`;o00001Oooool3o`0000Cooooo0_l00007ooooo`;o00004?ooool2
o`000003ooooool0003o000000[ooooo0_l00008ooooo`Co00002?ooool2o`00063ooooo000Loooo
o`03o`000?oooooooooo05Oooooo0_l00002oooooako000000?oooooo`000?l000000oooool2o`00
00;ooooo0_l0000>ooooo`?o00000oooool2o`0000cooooo0_l00003ooooo`;o000000?oooooo`00
0?l000000_l0000Gooooo`;o00003oooool4o`0000;ooooo0_l000001?oooooo0000o`000?ooool2
o`00063ooooo000Looooo`;o0000F?oooolTo`0000Cooooo0_l0000Cooooo`;o00002?ooool3o`00
00Sooooo0_l000001?oooooo0000o`000?ooool4o`0000kooooo0_l00007ooooo`;o00002oooool2
o`0000;ooooo0_l00002ooooo`Co000000?oooooo`000?l00000Hoooool001cooooo00?o0000oooo
ooooool0FOooool2o`0000?ooooo3ol000000ooooooo0000o`000008o`000003ooooool0003o0000
00_ooooo0_l00006ooooo`;o00003_ooool3o`0000Oooooo1?l00003ooooo`;o000000Coooooo`00
0?l0003o00002?ooool2o`0000;ooooo1Ol00003ooooo`;o00003?ooool2o`0000Kooooo0ol0001W
ooooo`007?ooool00ol0003oooooooooo`12ooooo`Co00004oooool2o`0000Cooooo6Ol00007oooo
o`;o00001Oooool2o`000003ooooool0003o000000;ooooo0ol0000<ooooo`Co00001Oooool2o`00
0003ooooool0003o000000Co000000Coooooo`000?l0003ooooo0ol00008ooooo`;o00001?ooool3
o`0000?ooooo0ol00003ooooo`;o00003oooool2o`00017ooooo1?l0001Booooo`007?ooool00ol0
003oooooooooo`12ooooo`Co00006OoooolGo`0000Wooooo0_l00007ooooo`?o00000_ooool3o`00
00[ooooo1?l00002ooooo`?o000000Goooooo`000?l0003o0000ooooo`02o`000004ooooool0003o
0000o`0000Gooooo1?l0000Aooooo`Co00000oooool4o`0000Kooooo0_l00004ooooo`;o00004_oo
ool5o`000003ooooool0003o000004kooooo000Looooo`03o`000?oooooooooo05Sooooo1?l00002
oooooaOo00001oooool2o`0000[ooooo0_l00004ooooo`;o00001oooool2o`000003ooooool0003o
000000Cooooo0ol000000ooooooo0000o`000002o`0000gooooo0_l0000Aooooo`;o00001Oooool4
o`0000Kooooo1?l00002ooooo`;o00005Oooool2o`000003ooooool0003o000004kooooo000Loooo
o`03o`000?oooooooooo05Sooooo1Ol000000ooooooo0000o`00000Fo`0000Kooooo0ol0000Goooo
o`Go00002oooool2o`0000gooooo0_l00004ooooo`?o00001oooool2o`000003ooooool0003o0000
00;ooooo1Ol00005ooooo`;o000000?oooooo`000?l000000ol0000>ooooo`;o00001oooool2o`00
00;ooooo0_l00002ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0Foooool2o`0000;o
oooo5ol00007ooooo`;o00005oooool5o`0000?ooooo0_l00004ooooo`;o00003oooool4o`0000;o
oooo0ol00007ooooo`;o000000?oooooo`000?l000000_ooool7o`000003ooooool0003o000000;o
000000?oooooo`000?l000000ol0000;ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?o
oooo0_l00002ooooo`;o00000_ooool2o`0004[ooooo000Looooo`03o`000?oooooooooo043ooooo
0ol000000ooooooo0000o`00000Dooooo`;o00001?ooool2o`000003ooooool0003o0000013o0000
3Oooool2o`0000oooooo1?l000000ooooooo0000o`000003ooooo`?o00001?ooool4o`0000kooooo
1_l00006ooooo`;o000000?oooooo`000?l000000ol00003ooooo`Ko000000?oooooo`000?l00000
0oooool4o`0000cooooo0_l00005ooooo`;o0000Eoooool001cooooo00?o0000ooooooooool0@?oo
ool3o`000003ooooool0003o000001Cooooo0_l00002ooooo`;o00000oooool3o`000003ooooool0
003o000000[o00003oooool3o`0000kooooo1?l000000ooooooo0000o`000003ooooo`;o00001Ooo
ool4o`0000Kooooo0ol00006ooooo`Oo00001?ooool2o`000003ooooool0003o000000;o00002?oo
ool2o`000003ooooool0003o000002;ooooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`11
ooooo`;o00006oooool2o`0000?ooooo1?l000000ooooooo0000o`000004o`000003ooooool0003o
000000;o00001oooool2o`0000;ooooo0_l00003ooooo`;o00004Oooool4o`0000Cooooo0_l00004
ooooo`Co00001_ooool3o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`0000Wooooo0_l0000;
ooooo`Co00001oooool2o`0000Cooooo0_l00005ooooo`Co00000oooool2o`0000?ooooo0_l0001?
ooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00003?ooool3o`0000;ooooo0_l00005oooo
o`Co000000?oooooo`000?l000001?l000000ooooooo0000o`000009ooooo`;o00000_ooool2o`00
017ooooo0_l00003ooooo`;o00000oooool9o`000003ooooool0003o000000gooooo0_l0000=oooo
o`;o00004Oooool2o`0000Oooooo0_l00004ooooo`;o00001Oooool4o`0000?ooooo0_l00004oooo
o`;o0000C_ooool001cooooo00?o0000ooooooooool0B?ooool3o`0000cooooo0ol00002ooooo`;o
00001_ooool2o`0000;ooooo1?l00004ooooo`;o00003?ooool2o`00017ooooo0_l00003ooooo`?o
00000_ooool9o`000003ooooool0003o000001cooooo0ol0000Kooooo`;o00002_ooool2o`0000[o
oooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`18ooooo`?o00006Oooool2o`000003oooo
ool0003o000000Oooooo0_l0000Sooooo`oo000000?oooooo`000?l000000ol0000Jooooo`;o0000
4Oooool4o`0000Kooooo0_l00006ooooo`Ko00002?ooool2o`00053ooooo000Looooo`03o`000?oo
oooooooo05Kooooo0_l00007ooooo`;o00001_ooool2o`0000gooooo0_l0000MoooooaOo00003?oo
ool2o`0001?ooooo0_l00008ooooo`Co00001_ooool2o`0000?ooooo1ol00004ooooo`;o00001?oo
ool2o`00053ooooo000Looooo`03o`000?oooooooooo05Kooooo1?l00005ooooo`;o00003_ooool2
o`0000Gooooo0_l00008ooooo`;o00004_oooolCo`000003ooooool0003o000000;o00000oooool2
o`0000Cooooo0_l000000ooooooo0000o`00000Cooooo`;o000000?oooooo`000?l000000oooool2
o`0000oooooo1?l00004ooooo`;o000000Coooooo`000?l0003o0000EOooool001cooooo00?o0000
ooooooooool0A?ooool2o`0000Gooooo0_l00009ooooo`Co00005Oooool2o`0000Cooooo0_l00009
ooooo`;o00004_oooolCo`0000;ooooo0_l00004ooooo`;o00001?ooool5o`0000;ooooo0_l0000B
ooooo`;o00000oooool3o`0001Kooooo0_l00002ooooo`;o0000EOooool001cooooo0_l0000ooooo
o`;o00001?ooool2o`0000Cooooo0ol00009ooooo`;o00007Oooool2o`0000;ooooo0_l0000Boooo
o`;o00001ooooolAo`0000;ooooo0_l0000;ooooo`Co00000_ooool2o`0000Cooooo0_l00007oooo
o`;o00001Oooool3o`000003ooooool0003o000001Wooooo0_l0001Fooooo`007?ooool00ol0003o
ooooooooo`0nooooo`;o00002_ooool2o`00023ooooo0_l0000;ooooo`;o00004_ooool2o`0000Co
oooo0_l000000ooooooo0000o`00000?o`0000oooooo0ol00003ooooo`Co00000_ooool2o`0000Oo
oooo0_l00005ooooo`?o000000?oooooo`000?l000004_ooool2o`0000Cooooo0ol0001Fooooo`00
7?ooool00ol0003oooooooooo`1Sooooo`;o000000?oooooo`000?l000001_l0000Nooooo`?o0000
1?ooool2o`000003ooooool0003o000001?o00003?ooool2o`0000?ooooo1?l0000;ooooo`;o0000
7Oooool2o`0000Cooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`1Jooooo`;o00001ooo
ool2o`000003ooooool0003o000000Go00007oooool3o`0000Cooooo6?l0000<ooooo`Co00004?oo
ool2o`0000;ooooo0_l0000Fooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0Coooool2
o`0000Wooooo0_l0000Jooooo`;o00007?oooolGo`0000cooooo1Ol00009ooooo`;o00001?ooool2
o`0000;ooooo0_l0000>ooooo`;o00001_ooool2o`0000Kooooo0_l0001Hooooo`007?ooool00ol0
003oooooooooo`10ooooo`;o00003Oooool2o`0001[ooooo0_l00009ooooo`;o00007OoooolEo`00
00kooooo1?l000000ooooooo0000o`000006ooooo`;o00001?ooool2o`000003ooooool0003o0000
00oooooo0_l00007ooooo`;o00001Oooool2o`0005Sooooo000Looooo`03o`000?oooooooooo043o
oooo0_l0000Yooooo`?o00009?ooool2o`000003ooooool0003o000001?o00002_ooool2o`0000;o
oooo0_l00003ooooo`;o00003Oooool4o`0001Kooooo1?l00004ooooo`;o0000FOooool001cooooo
00?o0000ooooooooool0K?ooool2o`000003ooooool0003o000001[ooooo0_l00005ooooo`;o0000
00?oooooo`000?l000004ol00002ooooo`;o00001_ooool3o`0000?ooooo0_l0000:ooooo`;o0000
1?ooool4o`0000gooooo0_l00006ooooo`?o00001_ooool2o`0005Wooooo000Looooo`03o`000?oo
oooooooo05Sooooo1?l0000Cooooo`;o00001oooool2o`00017ooooo0_l00006oooooaOo00000_oo
ool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000[ooooo0_l00004ooooo`Co00003Ooo
ool2o`0000Kooooo0_l00006ooooo`;o0000F_ooool001cooooo00?o0000ooooooooool0F?ooool4
o`0001_ooooo0ol0000Iooooo`;o00000_oooolCo`0000Oooooo0_l0000<ooooo`;o00006_ooool2
o`00013ooooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`1[ooooo`;o00002_ooool2o`00
01[ooooo0_l00002oooooa?o00001oooool2o`0000cooooo0_l00005ooooo`;o00004oooool2o`00
00?ooooo0_l0000<ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0Goooool2o`0000[o
oooo0_l0000Zoooooa;o00001oooool2o`000003ooooool0003o000000;o000000?oooooo`000?l0
00003?ooool2o`0001Sooooo0_l0000<ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0
A?ooool2o`0001Wooooo0_l0000Iooooo`;o00006oooool2o`0000;ooooo3Ol00008ooooo`;o0000
00?oooooo`000?l000001Ol00004ooooo`;o00008oooool2o`0006Cooooo000Looooo`03o`000?oo
oooooooo04Cooooo0_l0000Iooooo`;o00006Oooool2o`0001Kooooo0_l00009ooooo`co00002_oo
ool2o`000003ooooool0003o000000Co00000_ooool2o`0002?ooooo0_l0001Tooooo`007?ooool0
0ol0003oooooooooo`1Oooooo`;o0000;_ooool5o`0000Oooooo4?l00008ooooo`;o00000_ooool6
o`000003ooooool0003o000000Oooooo0_l00008ooooo`;o00001Oooool2o`0000?ooooo0_l00008
ooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0Coooool2o`0000kooooo0_l0000Doooo
o`;o00001?ooool2o`0001;ooooo1?l00008ooooo`Go000000Coooooo`000?l0003o00000oooool4
o`0000[ooooo3_l00004ooooo`;o00002?ooool4o`0000?ooooo0_l00003ooooo`;o00002?ooool2
o`00063ooooo000Looooo`;o0000D?ooool2o`0000Cooooo0_l00008ooooo`;o00001_ooool2o`00
00cooooo0_l00004ooooo`?o00000_ooool2o`0001[ooooo1Ol00002ooooo`;o00000oooool2o`00
00Sooooo0_l000000ooooooo0000o`00000<o`0000;ooooo0_l0000<ooooo`;o0000M?ooool001co
oooo00?o0000ooooooooool0EOooool2o`0000cooooo0_l000001?oooooo0000o`000?l0000Coooo
o`;o00000_ooool2o`0001gooooo0_l00002ooooo`;o00000oooool6o`0000;ooooo1?l00003oooo
o`;o00001Oooool2o`0000Cooooo0ol0000Kooooo`;o0000IOooool001cooooo00?o0000oooooooo
ool0G_ooool2o`0000;ooooo0ol000001?oooooo0000o`000?l00011ooooo`Co00000_ooool4o`00
00?ooooo0ol00003ooooo`;o00001?ooool3o`0000Cooooo0_l0000Dooooo`Co0000IOooool001co
oooo00?o0000ooooooooool0G_ooool2o`0000;ooooo0_l00003ooooo`;o000000Coooooo`000?l0
003o0000;_ooool2o`0000Gooooo0_l0000Cooooo`?o00000oooool2o`0000Cooooo0ol00004oooo
o`;o00005?ooool2o`0006Oooooo000Looooo`03o`000?oooooooooo06;ooooo0_l00006ooooo`?o
00001Oooool2o`00027ooooo0_l00004ooooo`;o00001Oooool2o`0001?ooooo0ol00008ooooo`;o
0000QOooool001cooooo00?o0000ooooooooool0L_ooool2o`00027ooooo0_l0000;ooooo`;o0000
5_ooool2o`0000;ooooo0_l00002ooooo`?o00005oooool2o`0006_ooooo000Looooo`03o`000?oo
oooooooo05[ooooo0_l0000Rooooo`;o00008_ooool4o`0001Cooooo0_l000000ooooooo0000o`00
0003o`000003ooooool0003o000000Oooooo0_l0000;ooooo`;o000000?oooooo`000?l00000Jooo
ool001cooooo00?o0000ooooooooool0EOooool2o`0000?ooooo0_l0000Fooooo`;o00002_ooool2
o`0000;ooooo0_l0000Hooooo`;o000000?oooooo`000?l000000_ooool3o`0001Oooooo1Ol0000:
ooooo`;o00001_ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l00000Joooool0
01cooooo00?o0000ooooooooool0EOooool2o`0000;ooooo0_l0000Eooooo`Co00003_ooool2o`00
01Sooooo0_l000000ooooooo0000o`000002o`0001_ooooo1_l00004ooooo`;o00002_ooool5o`00
073ooooo000Looooo`03o`000?oooooooooo05Wooooo0_l0000Eooooo`;o00005Oooool2o`0001So
oooo1?l00009ooooo`;o00003_ooool6o`0000Cooooo0_l0000<ooooo`;o0000LOooool001cooooo
00?o0000ooooooooool0G?ooool2o`0000Gooooo0_l00006ooooo`;o00006_ooool2o`0001Cooooo
0_l00004ooooo`?o00002?ooool2o`0000oooooo1ol00002ooooo`Co0000OOooool001cooooo00?o
0000ooooooooool0F?ooool2o`000004ooooool0003o0000o`0000Gooooo0_l00006ooooo`;o0000
<?ooool4o`0000?ooooo0_l00008ooooo`;o00004_ooool4o`0000;ooooo1?l0001mooooo`007?oo
ool00ol0003oooooooooo`1Hooooo`;o000000?oooooo`000?l00000@_ooool4o`0000Cooooo0_l0
0008ooooo`;o0000U_ooool001cooooo00?o0000ooooooooool0Hoooool2o`0002Kooooo0_l0000D
ooooo`;o000000Coooooo`000?l0003ooooo0ol00002ooooo`Co000000?oooooo`000?l000001_oo
ool2o`0000oooooo0_l0001mooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q
1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0GOooool2o`0000Co
oooo0_l00002ooooo`;o00001oooool2o`0001Wooooo0_l0000Dooooo`;o000000?oooooo`000?l0
00000_ooool2o`000003ooooool0003o000000?o00001oooool4o`000004ooooool0003o0000o`00
00_ooooo0_l0001mooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool0
1OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0GOooool2o`0000Gooooo0_l0
00000ooooooo0000o`000007ooooo`?o0000;_ooool2o`0000Sooooo0_l0000:ooooo`Co000000Co
ooooo`000?l0003o00002oooool2o`0007gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oo
oooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo05gooooo
0_l00005ooooo`;o00002oooool2o`0004Gooooo0_l0000@ooooo`;o0000OOooool00003ooooool0
003ooooo00;ooooo00?o0000ooooooooool02Oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo
0ol0001Mooooo`;o00002?ooool2o`0004Wooooo1?l00005ooooo`;o00002?ooool2o`0008;ooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Goc<c<o`000?l0003o0000
olc<c006ooooo`03o`000?oooooooooo05Oooooo0_l0000>ooooo`;o0000BOooool7o`0000;ooooo
0_l00008ooooo`;o0000P_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Ooo
ool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0Eoooool2o`0000Wooooo
0_l0001Booooo`?o00000_ooool2o`0000Cooooo0_l00026ooooo`0000KoooooogMgMonHV9Sooooo
oiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`1Roooo
o`;o00003Oooool2o`0004Sooooo0_l00004ooooo`;o0000Q_ooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0Iooo
ool2o`0000Sooooo0_l0001>ooooo`;o0000Q_ooool001cooooo00?o0000ooooooooool0Ioooool2
o`0000Sooooo0_l0003Fooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o00002_ooool2o`00
0=Kooooo000Looooo`03o`000?oooooooooo06Gooooo0_l0003Rooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0J_ooool2o`00017ooooo0_l0003:ooooo`007?ooool00ol0003oooooooooo`1Zoooo
o`;o00004Oooool2o`000<[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0K_ooool2o`000=Wooooo000Looooo`03o`000?oooooooooo06kooooo0_l0
001Xooooo`;o0000Koooool001cooooo00?o0000ooooooooool0R_ooool2o`0004cooooo0_l0001_
ooooo`007?ooool2o`0008_ooooo0_l00002ooooo`;o0000AOooool2o`0007;ooooo000Looooo`03
o`000?oooooooooo08kooooo0_l000000ooooooo0000o`000012ooooo`;o0000L_ooool001cooooo
00?o0000ooooooooool0S_ooool2o`000003ooooool0003o0000013ooooo0ol0002Sooooo`007?oo
ool00ol0003oooooooooo`1cooooo`;o00009?ooool3o`0000Cooooo1_l0002Sooooo`007?ooool0
0ol0003oooooooooo`1cooooo`?o00008oooool3o`0000Cooooo0ol0002Vooooo`007?ooool00ol0
003oooooooooo`1dooooo`;o00000oooool2o`000<kooooo000Looooo`03o`000?oooooooooo07Wo
oooo0_l0003>ooooo`007?ooool00ol0003oooooooooo`3;ooooo`;o0000O?ooool001cooooo00?o
0000ooooooooool0boooool2o`0007cooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0OOooool2o`000<[ooooo000Looooo`03o`000?oooooooooo07go
oooo0_l0003:ooooo`007?ooool00ol0003oooooooooo`35ooooo`;o0000P_ooool001cooooo00?o
0000ooooooooool0aOooool2o`0008;ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000;oooooo0_l00029ooooo`00
7?ooool00ol0003oooooooooo`2jooooo`;o00000_ooool2o`0008Wooooo000Looooo`03o`000?oo
oooooooo08kooooo0_l0000Vooooo`;o00000_ooool2o`0008gooooo000Looooo`03o`000?oooooo
oooo08kooooo1?l00007ooooo`;o00001_ooool2o`0000Cooooo0ol00005ooooo`;o00001Oooool2
o`00097ooooo000Looooo`03o`000?oooooooooo093ooooo0_l00007ooooo`?o00001Oooool2o`00
00Cooooo0ol00005ooooo`;o0000V?ooool001cooooo00?o0000ooooooooool0V_ooool2o`000:go
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001;ooooo1?l000000ol@413o
ooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo0ol0
003ooooood[ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000oooo
ooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`00
0?oooooooooo0?ooooooD_ooool001;ooooo00?oEEEEofIVI_l00000oooooomDooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00YOooool01?l@413o0000o`000?ooool2o`000003
oa0@4?oooooooooo01Oooooo0_l000002Ol@413oooooooooooooooooc<c<ob4Q8Ol0003o8B4Qolc<
c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0T?ooool00:Kooooo00Go0000oooooooooooooooo
o`000009ooooo`Ko00003?ooool00ol0003oooooooooo`02ooooo`05ob4Q8OnHV9SooooooiRHV?lQ
8B400oooool01OmgMgOoV9RHoooooonHV9SoMgMg093ooooo002Vooooo`05o`000?oooooooooooooo
ool000006?ooool5o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05oa0@4?oooooo
ooooooooool@4100T?ooool00:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00002Ooo
ool01?m4A4CogMgMooooool00004ooooo`05oc8b<_nHV9SooooooiRHV?lb<S800oooool01Ol0003o
oooooooooooooooo0000093ooooo002Vooooo`05o`000?n7QhOoooooojVYZOl000006?ooool01?oM
gMgoEEEEooooool00004ooooo`05olc<c?l0003o0000o`000?o<c<`00oooool01Ol0003ooooooooo
oooooooo0000093ooooo002Uooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool05ooo
ool00omgMgOoc<c<o`000004ooooo`05oa0@4?nj^[[ooooookZj^_l@41000oooool01Ol@413ooooo
oooooooooooo410@093ooooo0034ooooo`03onk^k_m4A4Co000000Cooooo00Go0000okZj^_oooooo
^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0T?ooool00<Gooooo00?oMgMgo`000?oo
ool00oooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP2@
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(486) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.54878 .35519 Mdot
.56035 .34807 Mdot
.3345 .57836 Mdot
.5946 .56345 Mdot
.48795 .73613 Mdot
.31208 .62288 Mdot
.34233 .4135 Mdot
.34903 .39984 Mdot
.30456 .61339 Mdot
.67488 .41001 Mdot
.30745 .40073 Mdot
.56551 .57767 Mdot
.32673 .40521 Mdot
.6344 .55723 Mdot
.49986 .40169 Mdot
.68314 .513 Mdot
.61439 .3542 Mdot
.4398 .70076 Mdot
.69789 .52822 Mdot
.31056 .5861 Mdot
.69801 .64705 Mdot
.64101 .56625 Mdot
.60112 .32195 Mdot
.63713 .55885 Mdot
.61327 .52701 Mdot
.57259 .35056 Mdot
.54795 .34847 Mdot
.62906 .51976 Mdot
.59125 .5159 Mdot
.31562 .3955 Mdot
.29066 .67982 Mdot
.80451 .35251 Mdot
.6824 .56736 Mdot
.7739 .39515 Mdot
.35124 .40238 Mdot
.27455 .43859 Mdot
.33397 .5897 Mdot
.34284 .4314 Mdot
.35061 .39442 Mdot
.3556 .40112 Mdot
.34333 .42287 Mdot
.58021 .35468 Mdot
.3585 .39507 Mdot
.22849 .58953 Mdot
.62778 .54436 Mdot
.52052 .3185 Mdot
.17363 .55324 Mdot
.61708 .51342 Mdot
.58488 .37184 Mdot
.29706 .59169 Mdot
.56823 .78606 Mdot
.29609 .41904 Mdot
.4497 .41567 Mdot
.48956 .90854 Mdot
.31446 .40533 Mdot
.58517 .55407 Mdot
.29307 .61986 Mdot
.61743 .57556 Mdot
.59733 .58018 Mdot
.75345 .35604 Mdot
.64803 .57972 Mdot
.47793 .71545 Mdot
.58625 .29618 Mdot
.33787 .64832 Mdot
.30393 .61973 Mdot
.33494 .43219 Mdot
.58118 .30335 Mdot
.33616 .39909 Mdot
.60344 .5063 Mdot
.31186 .58118 Mdot
.59539 .51556 Mdot
.31161 .39529 Mdot
.56867 .31127 Mdot
.62937 .54124 Mdot
.47312 .33042 Mdot
.28517 .35389 Mdot
.32756 .56124 Mdot
.80591 .50064 Mdot
.58749 .81486 Mdot
.40088 .64654 Mdot
.64515 .54506 Mdot
.45746 .8577 Mdot
.46699 .44921 Mdot
.55629 .34683 Mdot
.59521 .40554 Mdot
.51254 .20874 Mdot
.62672 .514 Mdot
.40889 .57743 Mdot
.67365 .59068 Mdot
.49862 .60707 Mdot
.30514 .60397 Mdot
.56332 .33006 Mdot
.6346 .54168 Mdot
.67295 .55701 Mdot
.6485 .32751 Mdot
.57266 .54047 Mdot
.60015 .5529 Mdot
.6217 .38443 Mdot
.30191 .40712 Mdot
.54139 .52114 Mdot
.47042 .77554 Mdot
.46241 .39381 Mdot
.58884 .54278 Mdot
.33462 .60552 Mdot
.58657 .29347 Mdot
.60394 .54712 Mdot
.34431 .40073 Mdot
.64606 .55276 Mdot
.30607 .37146 Mdot
.61214 .34408 Mdot
.67676 .57272 Mdot
.4561 .68401 Mdot
.51935 .54414 Mdot
.6033 .34201 Mdot
.76624 .53844 Mdot
.64994 .57438 Mdot
.6359 .58366 Mdot
.56116 .35434 Mdot
.33318 .58187 Mdot
.34877 .54112 Mdot
.59099 .31257 Mdot
.35524 .39805 Mdot
.60156 .36909 Mdot
.60613 .60402 Mdot
.32824 .58219 Mdot
.45556 .40625 Mdot
.4639 .39884 Mdot
.53997 .70995 Mdot
.63847 .53818 Mdot
.52584 .51985 Mdot
.32698 .61417 Mdot
.57379 .35828 Mdot
.32753 .39718 Mdot
.58203 .57404 Mdot
.59624 .3445 Mdot
.33882 .38459 Mdot
.47589 .73197 Mdot
.4774 .74647 Mdot
.58937 .36461 Mdot
.72534 .53828 Mdot
.28142 .39417 Mdot
.35722 .4086 Mdot
.56646 .78369 Mdot
.556 .35055 Mdot
.4748 .69478 Mdot
.32471 .38014 Mdot
.63802 .70216 Mdot
.62375 .59433 Mdot
.54018 .75773 Mdot
.37054 .8229 Mdot
.56731 .78564 Mdot
.798 .37404 Mdot
.46221 .68386 Mdot
.33118 .37977 Mdot
.59893 .51695 Mdot
.58681 .3397 Mdot
.59092 .35014 Mdot
.66828 .54911 Mdot
.62304 .53381 Mdot
.62109 .55226 Mdot
.60079 .58604 Mdot
.23264 .41286 Mdot
.63937 .54321 Mdot
.31741 .29092 Mdot
.59463 .33699 Mdot
.61101 .53501 Mdot
.34526 .60819 Mdot
.55527 .51198 Mdot
.35059 .42495 Mdot
.59602 .57759 Mdot
.62192 .53024 Mdot
.57332 .57252 Mdot
.34748 .38588 Mdot
.45447 .31339 Mdot
.66069 .78779 Mdot
.25904 .41776 Mdot
.36865 .35839 Mdot
.32298 .62698 Mdot
.66241 .5669 Mdot
.45881 .69639 Mdot
.54632 .51743 Mdot
.61824 .58865 Mdot
.56966 .78984 Mdot
.63965 .52918 Mdot
.81173 .42874 Mdot
.5648 .58949 Mdot
.49782 .20709 Mdot
.34612 .2613 Mdot
.61939 .59071 Mdot
.69864 .4487 Mdot
.53552 .74803 Mdot
.25997 .68002 Mdot
.32055 .39625 Mdot
.34836 .61796 Mdot
.3419 .58538 Mdot
.35174 .43024 Mdot
.64457 .63486 Mdot
.68828 .4179 Mdot
.57394 .53045 Mdot
.45761 .40219 Mdot
.53395 .36923 Mdot
.47198 .68547 Mdot
.5871 .3662 Mdot
.48891 .8586 Mdot
.43375 .62653 Mdot
.39854 .60722 Mdot
.44924 .7305 Mdot
.28532 .61036 Mdot
.44199 .40591 Mdot
.46843 .69265 Mdot
.60174 .56374 Mdot
.60831 .35568 Mdot
.53236 .75857 Mdot
.60847 .48879 Mdot
.39386 .14813 Mdot
.55584 .32634 Mdot
.50346 .54218 Mdot
.31836 .40267 Mdot
.35142 .63449 Mdot
.62671 .5143 Mdot
.62129 .5671 Mdot
.56746 .30246 Mdot
.60745 .51114 Mdot
.42147 .56554 Mdot
.62795 .52877 Mdot
.32722 .6498 Mdot
.49606 .66077 Mdot
.3248 .36805 Mdot
.44184 .72378 Mdot
.57549 .30967 Mdot
.26889 .35443 Mdot
.33963 .60507 Mdot
.56805 .62893 Mdot
.32767 .39034 Mdot
.4707 .73105 Mdot
.33117 .59433 Mdot
.45332 .68166 Mdot
.66914 .58382 Mdot
.32648 .58842 Mdot
.48288 .70736 Mdot
.40715 .49035 Mdot
.59909 .55112 Mdot
.56496 .71999 Mdot
.29658 .39257 Mdot
.55613 .36231 Mdot
.63569 .58871 Mdot
.43791 .41393 Mdot
.59193 .59216 Mdot
.51558 .49103 Mdot
.43118 .40375 Mdot
.44473 .38097 Mdot
.40445 .61246 Mdot
.49157 .71594 Mdot
.46905 .35658 Mdot
.40452 .52593 Mdot
.61491 .35295 Mdot
.66521 .58444 Mdot
.52829 .25746 Mdot
.2978 .38976 Mdot
.6041 .56752 Mdot
.49234 .22731 Mdot
.32492 .37981 Mdot
.62321 .5806 Mdot
.3388 .42399 Mdot
.5913 .34517 Mdot
.4337 .46657 Mdot
.57919 .37704 Mdot
.59702 .56799 Mdot
.32234 .42191 Mdot
.3493 .61116 Mdot
.57316 .35005 Mdot
.64623 .55863 Mdot
.65212 .54491 Mdot
.45571 .40018 Mdot
.62148 .53963 Mdot
.54878 .22721 Mdot
.61827 .51448 Mdot
.29085 .59456 Mdot
.57896 .52777 Mdot
.5082 .78489 Mdot
.46082 .7528 Mdot
.60505 .31612 Mdot
.43065 .40036 Mdot
.3042 .60149 Mdot
.42371 .47266 Mdot
.5466 .68325 Mdot
.64166 .5485 Mdot
.44497 .39008 Mdot
.50054 .53487 Mdot
.34529 .42705 Mdot
.66803 .5283 Mdot
.38289 .54843 Mdot
.31244 .59983 Mdot
.45123 .40533 Mdot
.65551 .50507 Mdot
.54444 .34881 Mdot
.58335 .54468 Mdot
.33584 .59243 Mdot
.55944 .36913 Mdot
.57095 .55475 Mdot
.18606 .46993 Mdot
.43918 .41505 Mdot
.31129 .41964 Mdot
.6382 .32997 Mdot
.66657 .55688 Mdot
.34917 .59031 Mdot
.59535 .35066 Mdot
.31824 .41474 Mdot
.60355 .33108 Mdot
.52119 .76291 Mdot
.53615 .4811 Mdot
.28019 .46603 Mdot
.44451 .67825 Mdot
.85321 .52128 Mdot
.27374 .43524 Mdot
.53306 .53473 Mdot
.26736 .61983 Mdot
.441 .17553 Mdot
.33171 .59837 Mdot
.70644 .49841 Mdot
.29731 .61041 Mdot
.58675 .53403 Mdot
.30915 .62192 Mdot
.56822 .20581 Mdot
.64122 .52464 Mdot
.30813 .63469 Mdot
.26089 .46736 Mdot
.64572 .52957 Mdot
.5983 .34084 Mdot
.69601 .25101 Mdot
.78048 .54529 Mdot
.74081 .59682 Mdot
.29568 .62989 Mdot
.72891 .53441 Mdot
.63094 .5182 Mdot
.70166 .53462 Mdot
.58138 .34029 Mdot
.57629 .58481 Mdot
.48867 .68814 Mdot
.46296 .67775 Mdot
.61388 .74269 Mdot
.79968 .56167 Mdot
.67884 .627 Mdot
.58028 .35033 Mdot
.57421 .8199 Mdot
.47588 .32468 Mdot
.44138 .41586 Mdot
.3467 .39336 Mdot
.44718 .32454 Mdot
.67807 .51762 Mdot
.60981 .42224 Mdot
.42508 .54716 Mdot
.56351 .32638 Mdot
.35295 .48623 Mdot
.32589 .41695 Mdot
.75607 .58252 Mdot
.68937 .38769 Mdot
.61782 .55267 Mdot
.29555 .41234 Mdot
.58452 .6042 Mdot
.4141 .55186 Mdot
.55343 .72952 Mdot
.20498 .54371 Mdot
.59809 .56156 Mdot
.48206 .35466 Mdot
.61932 .5878 Mdot
.54331 .72622 Mdot
.60284 .57071 Mdot
.60059 .32991 Mdot
.69442 .578 Mdot
.39989 .51563 Mdot
.76827 .63845 Mdot
.43489 .61758 Mdot
.48571 .69686 Mdot
.63186 .55975 Mdot
.61368 .56012 Mdot
.48073 .71557 Mdot
.56671 .3264 Mdot
.65925 .5861 Mdot
.16699 .53711 Mdot
.64026 .54229 Mdot
.30798 .4275 Mdot
.45439 .50289 Mdot
.82962 .45675 Mdot
.6536 .52837 Mdot
.5446 .3403 Mdot
.34963 .42068 Mdot
.32752 .38504 Mdot
.69396 .5995 Mdot
.29293 .39855 Mdot
.60042 .51511 Mdot
.45483 .50152 Mdot
.60807 .33026 Mdot
.55686 .57076 Mdot
.57059 .32235 Mdot
.55386 .81839 Mdot
.3193 .37847 Mdot
.44043 .38878 Mdot
.7476 .57721 Mdot
.33784 .41195 Mdot
.50763 .64534 Mdot
.69289 .57958 Mdot
.61713 .49203 Mdot
.63558 .32622 Mdot
.35126 .60816 Mdot
.43692 .3956 Mdot
.31394 .40819 Mdot
.63628 .54398 Mdot
.59736 .54269 Mdot
.29191 .41106 Mdot
.71206 .31477 Mdot
.28698 .67869 Mdot
.59687 .57043 Mdot
.59433 .32284 Mdot
.57564 .35748 Mdot
.60522 .59159 Mdot
.62837 .58889 Mdot
.32274 .6362 Mdot
.44373 .38991 Mdot
.4333 .39625 Mdot
.46421 .38877 Mdot
.32085 .64706 Mdot
.84105 .54905 Mdot
.35734 .40887 Mdot
.81347 .38204 Mdot
.47783 .26425 Mdot
.69909 .58517 Mdot
.34443 .59185 Mdot
.62924 .57432 Mdot
.59154 .53499 Mdot
.3147 .41826 Mdot
.80089 .60034 Mdot
.6827 .58735 Mdot
.55024 .35199 Mdot
.29824 .42006 Mdot
.57146 .58627 Mdot
.28542 .42888 Mdot
.44992 .7079 Mdot
.72148 .60621 Mdot
.29058 .40422 Mdot
.60936 .33972 Mdot
.2904 .40539 Mdot
.61541 .55744 Mdot
.64822 .5 Mdot
.56269 .32597 Mdot
.4682 .74021 Mdot
.67119 .56328 Mdot
.62228 .58172 Mdot
.27599 .7245 Mdot
.47473 .33302 Mdot
.48285 .75488 Mdot
.60302 .52211 Mdot
.58354 .5 Mdot
.45637 .73221 Mdot
.66798 .57205 Mdot
.58235 .52646 Mdot
.51693 .53935 Mdot
.30141 .37136 Mdot
.49553 .71182 Mdot
.76341 .63929 Mdot
.554 .32974 Mdot
.53677 .22911 Mdot
.46169 .40005 Mdot
.37522 .40389 Mdot
.43472 .45744 Mdot
.443 .40079 Mdot
.47383 .24363 Mdot
.242 .35651 Mdot
.4403 .39401 Mdot
.34654 .64337 Mdot
.64554 .44182 Mdot
.58393 .52187 Mdot
.60532 .58112 Mdot
.49119 .71523 Mdot
.56312 .36142 Mdot
.32797 .28542 Mdot
.30437 .36565 Mdot
.64306 .57247 Mdot
.55131 .36857 Mdot
.50511 .20715 Mdot
.44824 .40443 Mdot
.45549 .69458 Mdot
.4754 .74009 Mdot
.62437 .58733 Mdot
.5233 .63244 Mdot
.57779 .35189 Mdot
.64614 .55871 Mdot
.65003 .58391 Mdot
.29727 .60276 Mdot
.60572 .35939 Mdot
.34334 .61181 Mdot
.42845 .39494 Mdot
.4071 .17136 Mdot
.23131 .68462 Mdot
.30296 .38698 Mdot
.38358 .44821 Mdot
.35381 .38369 Mdot
.19746 .50267 Mdot
.44204 .3902 Mdot
.6441 .56234 Mdot
.58794 .30879 Mdot
.64667 .55466 Mdot
.63818 .54174 Mdot
.61161 .55069 Mdot
.67913 .62708 Mdot
.55329 .81245 Mdot
.46063 .71552 Mdot
.64017 .51025 Mdot
.30096 .63928 Mdot
.49541 .21377 Mdot
.61185 .23231 Mdot
.62528 .56149 Mdot
.63424 .58351 Mdot
.57131 .30483 Mdot
.6672 .58747 Mdot
.34704 .40273 Mdot
.55439 .33894 Mdot
.59153 .54562 Mdot
.47303 .77862 Mdot
.65517 .58697 Mdot
.36723 .45912 Mdot
.28858 .40004 Mdot
.63234 .4779 Mdot
.61602 .49587 Mdot
.44068 .39023 Mdot
.43743 .39602 Mdot
.43014 .41079 Mdot
.30932 .42567 Mdot
.29903 .60178 Mdot
.36894 .61505 Mdot
.63393 .50064 Mdot
.60623 .51542 Mdot
.6379 .49585 Mdot
.27872 .62125 Mdot
.39379 .52501 Mdot
.5302 .39366 Mdot
.57631 .60131 Mdot
.3195 .64443 Mdot
.62907 .37271 Mdot
.76985 .5945 Mdot
.55263 .34692 Mdot
.26933 .61611 Mdot
.3386 .39231 Mdot
.4632 .68119 Mdot
.60156 .77483 Mdot
.59501 .31661 Mdot
.55822 .31248 Mdot
.31797 .63167 Mdot
.48095 .48106 Mdot
.55514 .912 Mdot
.32947 .60765 Mdot
.40393 .59731 Mdot
.57997 .34359 Mdot
.68228 .57946 Mdot
.49822 .52623 Mdot
.49608 .47206 Mdot
.30391 .63067 Mdot
.65187 .54555 Mdot
.47154 .63953 Mdot
.32194 .63632 Mdot
.68018 .54249 Mdot
.29672 .63185 Mdot
.30223 .41471 Mdot
.33057 .61552 Mdot
.57823 .38627 Mdot
.6429 .53921 Mdot
.50854 .91165 Mdot
.46123 .44488 Mdot
.65162 .56187 Mdot
.29024 .41141 Mdot
.23183 .45603 Mdot
.6087 .55819 Mdot
.48551 .68746 Mdot
.30602 .64481 Mdot
.19573 .5311 Mdot
.58039 .53465 Mdot
.30929 .62777 Mdot
.58599 .38992 Mdot
.2714 .6294 Mdot
.46196 .76864 Mdot
.4348 .39611 Mdot
.59152 .3421 Mdot
.47575 .38741 Mdot
.35394 .413 Mdot
.62574 .60037 Mdot
.65589 .58065 Mdot
.59404 .33046 Mdot
.41462 .47746 Mdot
.67785 .61431 Mdot
.6442 .54516 Mdot
.33127 .63028 Mdot
.28514 .62888 Mdot
.50314 .39245 Mdot
.33961 .60107 Mdot
.58105 .50137 Mdot
.59724 .33193 Mdot
.58579 .54729 Mdot
.59847 .35129 Mdot
.66741 .58253 Mdot
.40113 .37527 Mdot
.55423 .35368 Mdot
.54778 .61038 Mdot
.63974 .53637 Mdot
.60031 .26532 Mdot
.66564 .55262 Mdot
.59931 .55717 Mdot
.29134 .63941 Mdot
.46703 .70923 Mdot
.67829 .54878 Mdot
.26473 .36061 Mdot
.45049 .7208 Mdot
.75195 .32761 Mdot
.3289 .58252 Mdot
.47471 .73578 Mdot
.60392 .72941 Mdot
.43084 .40061 Mdot
.47301 .71984 Mdot
.4218 .38866 Mdot
.29813 .39352 Mdot
.60763 .37036 Mdot
.6459 .53187 Mdot
.44451 .16818 Mdot
.2948 .68025 Mdot
.45481 .39636 Mdot
.63834 .58709 Mdot
.62336 .5732 Mdot
.54844 .3601 Mdot
.47907 .85784 Mdot
.32037 .65422 Mdot
.59493 .55628 Mdot
.58287 .31101 Mdot
.42501 .84609 Mdot
.30879 .63637 Mdot
.46006 .71874 Mdot
.30833 .37542 Mdot
.53028 .34269 Mdot
.43619 .39082 Mdot
.32195 .37827 Mdot
.31646 .56528 Mdot
.57145 .79246 Mdot
.57945 .54072 Mdot
.34633 .59917 Mdot
.56741 .78625 Mdot
.56057 .58373 Mdot
.36232 .42328 Mdot
.40933 .37804 Mdot
.56226 .33296 Mdot
.29265 .41284 Mdot
.49139 .70636 Mdot
.6139 .35108 Mdot
.56763 .32376 Mdot
.3457 .39563 Mdot
.35171 .24189 Mdot
.50133 .5292 Mdot
.33145 .43611 Mdot
.50657 .49581 Mdot
.56483 .78508 Mdot
.44959 .38627 Mdot
.45631 .69238 Mdot
.46644 .78873 Mdot
.57766 .35391 Mdot
.44824 .32295 Mdot
.5696 .78726 Mdot
.59985 .55308 Mdot
.48367 .70285 Mdot
.50926 .2208 Mdot
.36314 .38564 Mdot
.33511 .38254 Mdot
.34436 .54867 Mdot
.47955 .68777 Mdot
.64203 .59255 Mdot
.8329 .48118 Mdot
.65381 .53443 Mdot
.31705 .3799 Mdot
.42436 .55522 Mdot
.60592 .35756 Mdot
.35438 .42227 Mdot
.42074 .5678 Mdot
.59184 .53208 Mdot
.65421 .57013 Mdot
.46478 .65677 Mdot
.60133 .36642 Mdot
.43879 .38615 Mdot
.64988 .54891 Mdot
.61719 .57724 Mdot
.61733 .59829 Mdot
.75199 .63035 Mdot
.53625 .60768 Mdot
.59413 .55098 Mdot
.35479 .62497 Mdot
.57813 .49715 Mdot
.60056 .58487 Mdot
.54514 .35706 Mdot
.5024 .79384 Mdot
.42823 .39457 Mdot
.6055 .58011 Mdot
.59744 .57128 Mdot
.35241 .3975 Mdot
.50078 .53111 Mdot
.49709 .46867 Mdot
.28806 .60233 Mdot
.35136 .55479 Mdot
.57255 .52458 Mdot
.59018 .33544 Mdot
.49131 .69045 Mdot
.55691 .52222 Mdot
.55138 .34107 Mdot
.64127 .50735 Mdot
.29573 .63628 Mdot
.44425 .39253 Mdot
.58124 .61325 Mdot
.47609 .71296 Mdot
.28344 .38334 Mdot
.78867 .35247 Mdot
.34605 .61884 Mdot
.61672 .52162 Mdot
.37156 .60858 Mdot
.31797 .60583 Mdot
.45721 .3972 Mdot
.63572 .49119 Mdot
.5889 .34805 Mdot
.60802 .34721 Mdot
.54288 .80333 Mdot
.32663 .64793 Mdot
.31223 .76304 Mdot
.29861 .41103 Mdot
.65104 .51892 Mdot
.52756 .2885 Mdot
.60648 .35342 Mdot
.54151 .71552 Mdot
.47225 .73726 Mdot
.33401 .38235 Mdot
.45512 .3757 Mdot
.55354 .35503 Mdot
.60185 .35771 Mdot
.63367 .54231 Mdot
.63301 .56636 Mdot
.27393 .59158 Mdot
.5385 .74973 Mdot
.33967 .42325 Mdot
.45396 .71103 Mdot
.29764 .58835 Mdot
.59381 .52534 Mdot
.55861 .34078 Mdot
.82872 .47101 Mdot
.66642 .55827 Mdot
.29991 .63799 Mdot
.56208 .34431 Mdot
.46741 .72536 Mdot
.48404 .72217 Mdot
.6 .55474 Mdot
.81396 .4525 Mdot
.33927 .40974 Mdot
.59963 .33787 Mdot
.61501 .38674 Mdot
.62471 .50675 Mdot
.62955 .5624 Mdot
.62974 .61493 Mdot
.36013 .41992 Mdot
.56734 .59836 Mdot
.44418 .71407 Mdot
.58191 .36221 Mdot
.65043 .55586 Mdot
.4777 .71612 Mdot
.60817 .4228 Mdot
.44561 .39793 Mdot
.31098 .63571 Mdot
.48309 .68556 Mdot
.47286 .70123 Mdot
.4547 .72518 Mdot
.44838 .32604 Mdot
.59155 .29303 Mdot
.72822 .71917 Mdot
.64747 .54034 Mdot
.56382 .78466 Mdot
.66061 .596 Mdot
.3226 .42726 Mdot
.34799 .62263 Mdot
.62805 .54628 Mdot
.64762 .54006 Mdot
.80596 .40802 Mdot
.68492 .51339 Mdot
.68551 .5123 Mdot
.61069 .3473 Mdot
.62204 .28246 Mdot
.349 .59212 Mdot
.33486 .80344 Mdot
.70684 .24166 Mdot
.57165 .53197 Mdot
.47727 .48381 Mdot
.55478 .34112 Mdot
.34382 .38616 Mdot
.50238 .50317 Mdot
.31125 .45105 Mdot
.57183 .36284 Mdot
.58862 .53172 Mdot
.78791 .35756 Mdot
.44663 .69015 Mdot
.62048 .5538 Mdot
.32989 .39574 Mdot
.62072 .55305 Mdot
.31935 .42896 Mdot
.54854 .28955 Mdot
.48737 .46043 Mdot
.64087 .52819 Mdot
.5751 .53592 Mdot
.54141 .5011 Mdot
.62753 .56349 Mdot
.21935 .52529 Mdot
.56915 .33659 Mdot
.55955 .6243 Mdot
.58872 .58344 Mdot
.78968 .47488 Mdot
.65611 .5835 Mdot
.423 .44861 Mdot
.6579 .57353 Mdot
.73238 .64954 Mdot
.63637 .59391 Mdot
.66165 .56766 Mdot
.32411 .41897 Mdot
.35374 .39601 Mdot
.57924 .39279 Mdot
.44365 .38313 Mdot
.49702 .2087 Mdot
.62808 .5831 Mdot
.28304 .62964 Mdot
.54104 .42571 Mdot
.46859 .70377 Mdot
.5785 .36177 Mdot
.19066 .69063 Mdot
.34469 .42469 Mdot
.3423 .64528 Mdot
.39147 .62348 Mdot
.36157 .60842 Mdot
.283 .59234 Mdot
.60734 .26719 Mdot
.45387 .69407 Mdot
.64955 .58857 Mdot
.78205 .40741 Mdot
.48238 .34426 Mdot
.62107 .50753 Mdot
.35028 .64939 Mdot
.60941 .44982 Mdot
.55601 .80318 Mdot
.45843 .67664 Mdot
.46424 .68568 Mdot
.31786 .41267 Mdot
.33563 .57935 Mdot
.58835 .60958 Mdot
.47455 .73555 Mdot
.3462 .62355 Mdot
.46413 .40202 Mdot
.41612 .68267 Mdot
.58161 .35314 Mdot
.72812 .54852 Mdot
.52257 .30532 Mdot
.34341 .42422 Mdot
.27129 .3579 Mdot
.62366 .31547 Mdot
.61936 .34057 Mdot
.4517 .38243 Mdot
.30929 .6408 Mdot
.61126 .36782 Mdot
.64113 .53963 Mdot
.60882 .48881 Mdot
.6258 .58779 Mdot
.48833 .72064 Mdot
.6453 .58636 Mdot
.32582 .63787 Mdot
.3451 .41504 Mdot
.30727 .60151 Mdot
.3404 .41521 Mdot
.74624 .30068 Mdot
.60276 .58428 Mdot
.63283 .56225 Mdot
.45784 .49718 Mdot
.5968 .36142 Mdot
.76842 .39342 Mdot
.30211 .64016 Mdot
.29385 .61482 Mdot
.58682 .54804 Mdot
.60064 .30996 Mdot
.51595 .66016 Mdot
.48935 .50606 Mdot
.65553 .57766 Mdot
.56948 .33555 Mdot
.58555 .55082 Mdot
.20131 .48113 Mdot
.48684 .44324 Mdot
.60448 .33389 Mdot
.76931 .63827 Mdot
.62683 .53974 Mdot
.62313 .483 Mdot
.6027 .47149 Mdot
.70654 .65015 Mdot
.68707 .56944 Mdot
.55631 .32702 Mdot
.59376 .57697 Mdot
.58499 .33373 Mdot
.32373 .60171 Mdot
.35878 .40967 Mdot
.58381 .33652 Mdot
.65157 .53504 Mdot
.71497 .25179 Mdot
.34791 .41246 Mdot
.62958 .55156 Mdot
.30873 .40537 Mdot
.59852 .3748 Mdot
.58572 .36971 Mdot
.4387 .37545 Mdot
.40137 .60212 Mdot
.34584 .40477 Mdot
.60692 .51464 Mdot
.46291 .32085 Mdot
.5854 .54634 Mdot
.35479 .55637 Mdot
.57289 .56694 Mdot
.59179 .51251 Mdot
.85755 .51133 Mdot
.42092 .46867 Mdot
.26258 .74595 Mdot
.31101 .35993 Mdot
.45867 .31317 Mdot
.58337 .39872 Mdot
.45904 .67666 Mdot
.3846 .45991 Mdot
.43521 .40889 Mdot
.35786 .61712 Mdot
.63243 .54446 Mdot
.60919 .24914 Mdot
.3198 .43332 Mdot
.46319 .70902 Mdot
.63956 .52884 Mdot
.34811 .5794 Mdot
.46235 .42591 Mdot
.33098 .38022 Mdot
.58152 .35526 Mdot
.58522 .36752 Mdot
.60319 .81165 Mdot
.65036 .55994 Mdot
.63802 .56631 Mdot
.35074 .40721 Mdot
.62372 .62198 Mdot
.45291 .72046 Mdot
.2732 .47622 Mdot
.32651 .39428 Mdot
.48188 .44594 Mdot
.61173 .34937 Mdot
.62588 .57369 Mdot
.45453 .50437 Mdot
.40921 .30487 Mdot
.65499 .3647 Mdot
.47806 .69305 Mdot
.53265 .65561 Mdot
.55631 .32667 Mdot
.32487 .39691 Mdot
.60696 .73864 Mdot
.66697 .59637 Mdot
.6211 .57386 Mdot
.56133 .66614 Mdot
.49208 .50451 Mdot
.40569 .58882 Mdot
.63247 .6122 Mdot
.49539 .55755 Mdot
.58703 .54683 Mdot
.59706 .54234 Mdot
.59853 .50769 Mdot
.57706 .56548 Mdot
.57268 .33258 Mdot
.78296 .53297 Mdot
.31805 .62125 Mdot
.66398 .42496 Mdot
.3095 .55597 Mdot
.63528 .51883 Mdot
.58966 .53269 Mdot
.74104 .48264 Mdot
.52754 .47369 Mdot
.57175 .34241 Mdot
.61919 .38105 Mdot
.35643 .40829 Mdot
.69321 .52158 Mdot
.31844 .64821 Mdot
.62207 .46756 Mdot
.3088 .6116 Mdot
.5694 .33355 Mdot
.30975 .59199 Mdot
.28388 .41203 Mdot
.34598 .5989 Mdot
.33363 .64383 Mdot
.32213 .37637 Mdot
.58792 .37209 Mdot
.66386 .56685 Mdot
.31167 .37716 Mdot
.51317 .65647 Mdot
.48803 .72077 Mdot
.43568 .37572 Mdot
.68213 .58156 Mdot
.66271 .49702 Mdot
.18379 .47401 Mdot
.32335 .5875 Mdot
.50998 .46431 Mdot
.55492 .35493 Mdot
.49306 .69757 Mdot
.57637 .33146 Mdot
.66221 .76531 Mdot
.4785 .70613 Mdot
.43192 .37753 Mdot
.58801 .74192 Mdot
.2582 .39374 Mdot
.57103 .57434 Mdot
.63661 .32978 Mdot
.30946 .6083 Mdot
.30551 .42602 Mdot
.50378 .21908 Mdot
.61487 .54243 Mdot
.46267 .41096 Mdot
.62237 .34269 Mdot
.43158 .39998 Mdot
.3294 .39768 Mdot
.39864 .41468 Mdot
.6505 .56602 Mdot
.2609 .38916 Mdot
.57089 .54473 Mdot
.74291 .56462 Mdot
.32169 .55767 Mdot
.60674 .41473 Mdot
.58309 .53868 Mdot
.31063 .63841 Mdot
.58365 .54211 Mdot
.68137 .46935 Mdot
.57322 .76282 Mdot
.56591 .53136 Mdot
.56224 .45647 Mdot
.18463 .51254 Mdot
.56018 .33719 Mdot
.58242 .50235 Mdot
.45373 .38985 Mdot
.60465 .52772 Mdot
.50704 .13667 Mdot
.47291 .71763 Mdot
.48417 .75152 Mdot
.65044 .53571 Mdot
.64756 .55067 Mdot
.80792 .43143 Mdot
.60624 .2805 Mdot
.45339 .37554 Mdot
.61357 .57023 Mdot
.59353 .67098 Mdot
.31788 .41595 Mdot
.57156 .55843 Mdot
.60328 .58173 Mdot
.27469 .71005 Mdot
.31248 .41344 Mdot
.33415 .58606 Mdot
.43106 .40223 Mdot
.28652 .61188 Mdot
.49709 .72832 Mdot
.50846 .57888 Mdot
.54734 .70871 Mdot
.49049 .43435 Mdot
.4859 .69143 Mdot
.63836 .51806 Mdot
.59371 .41239 Mdot
.65624 .5571 Mdot
.46493 .6876 Mdot
.31525 .39567 Mdot
.57412 .33573 Mdot
.72559 .54026 Mdot
.45876 .40018 Mdot
.64189 .51386 Mdot
.45789 .67434 Mdot
.5864 .34135 Mdot
.34837 .30633 Mdot
.55967 .35751 Mdot
.33518 .41567 Mdot
.34994 .43067 Mdot
.47304 .70653 Mdot
.57434 .33095 Mdot
.28912 .6082 Mdot
.32739 .35947 Mdot
.56634 .55465 Mdot
.28429 .41503 Mdot
.61281 .37138 Mdot
.54743 .34198 Mdot
.59842 .31261 Mdot
.58329 .57094 Mdot
.48876 .49437 Mdot
.65195 .60298 Mdot
.3492 .41086 Mdot
.35709 .59485 Mdot
.54353 .75626 Mdot
.79606 .43078 Mdot
.47711 .45232 Mdot
.68082 .55309 Mdot
.64289 .58659 Mdot
.62534 .58722 Mdot
.58788 .56238 Mdot
.27749 .47638 Mdot
.60242 .58395 Mdot
.32634 .42273 Mdot
.31577 .61211 Mdot
.64702 .58062 Mdot
.44979 .3894 Mdot
.3971 .52724 Mdot
.49373 .69373 Mdot
.73392 .59613 Mdot
.57037 .24361 Mdot
.58445 .34061 Mdot
.34037 .59715 Mdot
.30486 .5942 Mdot
.47581 .73193 Mdot
.31269 .37848 Mdot
.56653 .36295 Mdot
.71926 .65647 Mdot
.44492 .70735 Mdot
.6057 .57978 Mdot
.4559 .5 Mdot
.77041 .61394 Mdot
.65955 .52753 Mdot
.60564 .55426 Mdot
.43653 .38664 Mdot
.3457 .64168 Mdot
.50856 .16565 Mdot
.34468 .25441 Mdot
.46872 .70902 Mdot
.45743 .72042 Mdot
.5824 .30534 Mdot
.65088 .51819 Mdot
.34025 .40746 Mdot
.49997 .5495 Mdot
.19159 .45545 Mdot
.53138 .21577 Mdot
.19804 .50579 Mdot
.65658 .58619 Mdot
.77443 .50163 Mdot
.57284 .57074 Mdot
.58693 .29339 Mdot
.5964 .30886 Mdot
.57631 .34723 Mdot
.32554 .41796 Mdot
.57366 .79433 Mdot
.32501 .42337 Mdot
.58077 .239 Mdot
.56785 .31636 Mdot
.4128 .49767 Mdot
.29261 .62083 Mdot
.69796 .53356 Mdot
.45519 .69173 Mdot
.52506 .68884 Mdot
.59523 .49704 Mdot
.52585 .63579 Mdot
.34411 .59163 Mdot
.56995 .37234 Mdot
.69251 .57584 Mdot
.48827 .20877 Mdot
.47972 .47863 Mdot
.1781 .54924 Mdot
.6354 .29356 Mdot
.4808 .71399 Mdot
.684 .42671 Mdot
.44728 .71002 Mdot
.33188 .38151 Mdot
.62197 .5422 Mdot
.66562 .54663 Mdot
.5968 .56149 Mdot
.58076 .56628 Mdot
.31302 .4071 Mdot
.5646 .55605 Mdot
.50921 .78516 Mdot
.45795 .40727 Mdot
.38313 .50844 Mdot
.48096 .72281 Mdot
.30371 .41827 Mdot
.31757 .60807 Mdot
.45222 .38136 Mdot
.44052 .68103 Mdot
.61026 .59503 Mdot
.65533 .54295 Mdot
.46293 .40208 Mdot
.63212 .62944 Mdot
.68012 .51897 Mdot
.31339 .62472 Mdot
.4113 .541 Mdot
.48874 .72675 Mdot
.45853 .68371 Mdot
.29321 .4106 Mdot
.57627 .33118 Mdot
.48115 .73285 Mdot
.33758 .57898 Mdot
.5723 .55079 Mdot
.57643 .53254 Mdot
.61162 .37424 Mdot
.56918 .78858 Mdot
.49256 .69006 Mdot
.56234 .5875 Mdot
.59216 .35891 Mdot
.62278 .33923 Mdot
.61309 .56875 Mdot
.55958 .56487 Mdot
.55978 .30853 Mdot
.46793 .7287 Mdot
.29532 .40961 Mdot
.42916 .48831 Mdot
.32443 .42532 Mdot
.59315 .35263 Mdot
.58642 .49423 Mdot
.60318 .36603 Mdot
.61778 .54009 Mdot
.31481 .819 Mdot
.62047 .5916 Mdot
.63199 .65137 Mdot
.42671 .64469 Mdot
.29827 .63359 Mdot
.3028 .63643 Mdot
.44561 .39138 Mdot
.5523 .34004 Mdot
.55709 .51655 Mdot
.45137 .69993 Mdot
.45946 .31385 Mdot
.61693 .29589 Mdot
.3273 .64467 Mdot
.33559 .64781 Mdot
.31434 .39745 Mdot
.65283 .58518 Mdot
.63108 .57579 Mdot
.34507 .59608 Mdot
.24271 .46112 Mdot
.58283 .32844 Mdot
.63811 .56599 Mdot
.58712 .5766 Mdot
.31804 .61847 Mdot
.38373 .3948 Mdot
.62524 .34141 Mdot
.58382 .57396 Mdot
.56415 .75395 Mdot
.32898 .43089 Mdot
.62023 .51671 Mdot
.57449 .57221 Mdot
.46893 .69925 Mdot
.54482 .68265 Mdot
.56584 .78346 Mdot
.35113 .38818 Mdot
.43465 .39327 Mdot
.66992 .55555 Mdot
.29716 .62943 Mdot
.68423 .58139 Mdot
.24601 .31896 Mdot
.4517 .41095 Mdot
.64757 .56884 Mdot
.57515 .52078 Mdot
.60025 .3483 Mdot
.64617 .56135 Mdot
.40229 .37787 Mdot
.33514 .62448 Mdot
.6481 .56943 Mdot
.81297 .45588 Mdot
.3165 .39619 Mdot
.60088 .49545 Mdot
.4729 .68246 Mdot
.41046 .58182 Mdot
.7022 .259 Mdot
.27973 .61233 Mdot
.48612 .717 Mdot
.64699 .58546 Mdot
.28573 .60827 Mdot
.31101 .37446 Mdot
.55244 .62808 Mdot
.63488 .51578 Mdot
.32854 .42572 Mdot
.34597 .41271 Mdot
.47207 .71057 Mdot
.24921 .74826 Mdot
.57451 .52285 Mdot
.62382 .55661 Mdot
.17079 .46632 Mdot
.54979 .31546 Mdot
.62712 .55084 Mdot
.65554 .58208 Mdot
.29611 .3933 Mdot
.65615 .75034 Mdot
.53152 .65202 Mdot
.26075 .4667 Mdot
.32362 .42982 Mdot
.3253 .65617 Mdot
.34133 .62113 Mdot
.48517 .71646 Mdot
.56144 .3464 Mdot
.49358 .71244 Mdot
.32729 .61972 Mdot
.5992 .55838 Mdot
.31263 .38676 Mdot
.68413 .31253 Mdot
.28741 .40781 Mdot
.33374 .57586 Mdot
.60731 .30286 Mdot
.60621 .23775 Mdot
.21181 .34733 Mdot
.52067 .31399 Mdot
.36381 .40618 Mdot
.46847 .70354 Mdot
.33094 .27314 Mdot
.64977 .58035 Mdot
.73872 .53839 Mdot
.62191 .5546 Mdot
.63257 .38676 Mdot
.34716 .62351 Mdot
.46586 .38782 Mdot
.61432 .54263 Mdot
.53326 .65546 Mdot
.32851 .37809 Mdot
.34124 .39684 Mdot
.59207 .57112 Mdot
.33714 .41455 Mdot
.63629 .57447 Mdot
.31951 .61261 Mdot
.26005 .75266 Mdot
.65955 .56659 Mdot
.57199 .49807 Mdot
.32115 .36751 Mdot
.43586 .37528 Mdot
.35646 .6405 Mdot
.78458 .50811 Mdot
.48825 .20127 Mdot
.3368 .40922 Mdot
.689 .62412 Mdot
.32821 .58943 Mdot
.4448 .38088 Mdot
.29753 .64897 Mdot
.6177 .56199 Mdot
.66117 .58338 Mdot
.59116 .55521 Mdot
.64495 .58469 Mdot
.7278 .50097 Mdot
.68275 .51954 Mdot
.71107 .39744 Mdot
.64792 .54097 Mdot
.63965 .64918 Mdot
.31694 .4201 Mdot
.61745 .4804 Mdot
.41256 .59948 Mdot
.65323 .59025 Mdot
.63061 .30242 Mdot
.30246 .41637 Mdot
.52162 .27663 Mdot
.31262 .41028 Mdot
.30355 .60422 Mdot
.34412 .38976 Mdot
.62464 .53929 Mdot
.57474 .3563 Mdot
.338 .60804 Mdot
.52825 .39204 Mdot
.35736 .60725 Mdot
.65153 .56203 Mdot
.26483 .42131 Mdot
.28976 .62142 Mdot
.66673 .49474 Mdot
.57193 .35663 Mdot
.62067 .6816 Mdot
.56667 .29823 Mdot
.64283 .55664 Mdot
.63905 .55217 Mdot
.46458 .38462 Mdot
.33183 .38004 Mdot
.61246 .33644 Mdot
.29418 .73197 Mdot
.46521 .67184 Mdot
.5668 .34316 Mdot
.59759 .47476 Mdot
.47372 .48493 Mdot
.60351 .34076 Mdot
.65097 .6724 Mdot
.31919 .37954 Mdot
.56806 .31247 Mdot
.59158 .59362 Mdot
.66571 .43393 Mdot
.44932 .6902 Mdot
.28533 .6215 Mdot
.48943 .53653 Mdot
.3396 .62257 Mdot
.27967 .39632 Mdot
.32114 .65028 Mdot
.31656 .41773 Mdot
.55448 .43406 Mdot
.4231 .56032 Mdot
.29497 .42123 Mdot
.29257 .36864 Mdot
.31928 .62743 Mdot
.5907 .56625 Mdot
.39989 .5176 Mdot
.55107 .52284 Mdot
.62592 .49162 Mdot
.33424 .42788 Mdot
.55876 .32124 Mdot
.61077 .35879 Mdot
.56109 .62115 Mdot
.59705 .36355 Mdot
.33235 .60429 Mdot
.49966 .42063 Mdot
.74886 .57513 Mdot
.31669 .3928 Mdot
.39664 .60931 Mdot
.58513 .53849 Mdot
.31206 .63349 Mdot
.32993 .60062 Mdot
.34241 .41589 Mdot
.65686 .41471 Mdot
.62648 .49345 Mdot
.54258 .34786 Mdot
.57934 .31138 Mdot
.60327 .33773 Mdot
.59562 .30676 Mdot
.58159 .79693 Mdot
.30489 .42565 Mdot
.55478 .33297 Mdot
.58163 .55977 Mdot
.66817 .5611 Mdot
.43712 .40436 Mdot
.46965 .72774 Mdot
.64634 .60143 Mdot
.55487 .51872 Mdot
.61468 .56926 Mdot
.29667 .63204 Mdot
.56748 .46842 Mdot
.45319 .40912 Mdot
.33098 .64781 Mdot
.31968 .64769 Mdot
.43937 .39074 Mdot
.56196 .43658 Mdot
.53777 .18092 Mdot
.59496 .55729 Mdot
.59667 .25765 Mdot
.30095 .63112 Mdot
.50817 .61592 Mdot
.62225 .64194 Mdot
.60271 .51437 Mdot
.36726 .51836 Mdot
.32454 .60841 Mdot
.56739 .39422 Mdot
.62264 .56227 Mdot
.45437 .38459 Mdot
.45875 .68229 Mdot
.56149 .48887 Mdot
.43766 .38531 Mdot
.56965 .32961 Mdot
.24927 .6556 Mdot
.55028 .36598 Mdot
.28852 .61724 Mdot
.58577 .50048 Mdot
.53565 .91431 Mdot
.31006 .60639 Mdot
.44642 .31367 Mdot
.42172 .5638 Mdot
.65725 .5671 Mdot
.34278 .6091 Mdot
.61381 .37554 Mdot
.33001 .43076 Mdot
.46819 .50183 Mdot
.55873 .34154 Mdot
.45389 .3818 Mdot
.43714 .39984 Mdot
.31736 .62085 Mdot
.59165 .31573 Mdot
.5677 .56004 Mdot
.58129 .36696 Mdot
.32444 .38657 Mdot
.62063 .53063 Mdot
.49683 .20823 Mdot
.63163 .48974 Mdot
.58198 .36539 Mdot
.3495 .58275 Mdot
.46299 .73759 Mdot
.6448 .52622 Mdot
.52409 .25252 Mdot
.65217 .5847 Mdot
.30959 .40221 Mdot
.46962 .60337 Mdot
.68676 .32053 Mdot
.60194 .57136 Mdot
.58708 .53642 Mdot
.28868 .39267 Mdot
.60206 .56896 Mdot
.59709 .51152 Mdot
.40259 .41094 Mdot
.6029 .34447 Mdot
.64081 .58115 Mdot
.34148 .62571 Mdot
.71092 .2994 Mdot
.6215 .54376 Mdot
.39003 .36927 Mdot
.59889 .67544 Mdot
.45103 .57719 Mdot
.55867 .51081 Mdot
.54061 .71363 Mdot
.63499 .5538 Mdot
.60736 .511 Mdot
.59294 .56207 Mdot
.77129 .5042 Mdot
.32424 .62422 Mdot
.32557 .64196 Mdot
.46382 .67919 Mdot
.57918 .66831 Mdot
.48176 .69966 Mdot
.29023 .39242 Mdot
.39522 .61445 Mdot
.46173 .40184 Mdot
.57887 .33158 Mdot
.61904 .54561 Mdot
.35606 .61118 Mdot
.62361 .57114 Mdot
.60586 .5261 Mdot
.33102 .61011 Mdot
.32656 .60261 Mdot
.27787 .61693 Mdot
.44461 .69442 Mdot
.5767 .34145 Mdot
.60474 .55042 Mdot
.45008 .7204 Mdot
.59459 .58607 Mdot
.45068 .46648 Mdot
.57507 .34274 Mdot
.58457 .36573 Mdot
.60132 .37107 Mdot
.66011 .54483 Mdot
.62445 .53647 Mdot
.32531 .42359 Mdot
.61109 .37455 Mdot
.34586 .39911 Mdot
.34285 .61106 Mdot
.31696 .63493 Mdot
.61725 .56143 Mdot
.57967 .6058 Mdot
.47545 .72491 Mdot
.3106 .59452 Mdot
.43335 .41053 Mdot
.46889 .68011 Mdot
.63342 .58892 Mdot
.34181 .61728 Mdot
.48791 .68711 Mdot
.65135 .32463 Mdot
.4674 .18929 Mdot
.44342 .69254 Mdot
.59176 .5713 Mdot
.79876 .42236 Mdot
.56506 .76283 Mdot
.46052 .67007 Mdot
.30566 .407 Mdot
.66379 .57207 Mdot
.23124 .41748 Mdot
.48195 .73642 Mdot
.57017 .78331 Mdot
.33303 .61353 Mdot
.53673 .52809 Mdot
.5772 .47164 Mdot
.75019 .56877 Mdot
.47448 .74143 Mdot
.58042 .3639 Mdot
.59041 .31055 Mdot
.60347 .57733 Mdot
.40357 .59556 Mdot
.28566 .40902 Mdot
.30529 .59373 Mdot
.3407 .63777 Mdot
.60509 .32964 Mdot
.48802 .43684 Mdot
.34206 .62369 Mdot
.64207 .51099 Mdot
.50072 .69552 Mdot
.69641 .5253 Mdot
.60469 .8062 Mdot
.68942 .2595 Mdot
.56135 .50799 Mdot
.45771 .73366 Mdot
.32523 .37599 Mdot
.3347 .41986 Mdot
.32868 .41688 Mdot
.32063 .63416 Mdot
.4992 .50828 Mdot
.34567 .6299 Mdot
.36305 .34517 Mdot
.477 .71802 Mdot
.64889 .69251 Mdot
.59432 .59164 Mdot
.65697 .56592 Mdot
.57748 .54026 Mdot
.59099 .55331 Mdot
.63489 .55537 Mdot
.34304 .42389 Mdot
.29353 .59945 Mdot
.19273 .47608 Mdot
.59343 .32299 Mdot
.34228 .30454 Mdot
.29243 .61883 Mdot
.43102 .39141 Mdot
.45911 .71025 Mdot
.55823 .69158 Mdot
.50129 .68705 Mdot
.30328 .59787 Mdot
.65831 .52414 Mdot
.57077 .30672 Mdot
.74983 .64019 Mdot
.64439 .54508 Mdot
.31543 .59116 Mdot
.31398 .65768 Mdot
.66213 .40856 Mdot
.66636 .60634 Mdot
.39991 .59225 Mdot
.47836 .48594 Mdot
.4409 .70138 Mdot
.67897 .554 Mdot
.51558 .61116 Mdot
.32518 .62017 Mdot
.30158 .61626 Mdot
.45561 .67115 Mdot
.62346 .44296 Mdot
.56477 .32229 Mdot
.46726 .39044 Mdot
.30218 .40665 Mdot
.65807 .55196 Mdot
.32537 .63175 Mdot
.55516 .394 Mdot
.44368 .48802 Mdot
.31742 .40531 Mdot
.33253 .64832 Mdot
.65804 .58188 Mdot
.60497 .57561 Mdot
.48073 .70872 Mdot
.30418 .69503 Mdot
.55123 .5225 Mdot
.45794 .31414 Mdot
.49979 .45868 Mdot
.41805 .57365 Mdot
.62181 .57423 Mdot
.60709 .35791 Mdot
.44183 .39 Mdot
.45709 .69264 Mdot
.61571 .59464 Mdot
.51369 .17917 Mdot
.55637 .37411 Mdot
.3449 .40508 Mdot
.44423 .38656 Mdot
.50422 .53869 Mdot
.65161 .58444 Mdot
.62171 .55501 Mdot
.58314 .57041 Mdot
.51554 .17528 Mdot
.33932 .6334 Mdot
.61045 .32762 Mdot
.4833 .69697 Mdot
.57864 .36892 Mdot
.30375 .64501 Mdot
.41037 .57241 Mdot
.60291 .58521 Mdot
.55799 .37026 Mdot
.57077 .36378 Mdot
.31713 .39501 Mdot
.31043 .37733 Mdot
.28556 .6009 Mdot
.64825 .58333 Mdot
.46445 .39452 Mdot
.55926 .32435 Mdot
.30775 .58966 Mdot
.48002 .7086 Mdot
.3064 .43841 Mdot
.64903 .54095 Mdot
.31957 .62208 Mdot
.56423 .51151 Mdot
.59598 .3377 Mdot
.29729 .60531 Mdot
.43704 .38304 Mdot
.46632 .72686 Mdot
.6687 .57452 Mdot
.18847 .52565 Mdot
.44986 .3836 Mdot
.65332 .53466 Mdot
.68196 .2601 Mdot
.40485 .59249 Mdot
.52795 .38147 Mdot
.34959 .61179 Mdot
.46186 .39271 Mdot
.60487 .3173 Mdot
.68301 .44456 Mdot
.3047 .61757 Mdot
.79397 .38041 Mdot
.41722 .50273 Mdot
.59721 .55393 Mdot
.56353 .33322 Mdot
.47567 .65867 Mdot
.46543 .3023 Mdot
.55443 .75827 Mdot
.6413 .5713 Mdot
.33894 .62363 Mdot
.46037 .6824 Mdot
.34168 .39583 Mdot
.38448 .37006 Mdot
.64553 .7913 Mdot
.33689 .64434 Mdot
.61431 .54761 Mdot
.56111 .31894 Mdot
.34304 .4097 Mdot
.79248 .36311 Mdot
.33353 .57822 Mdot
.34752 .61275 Mdot
.58109 .53216 Mdot
.47998 .6934 Mdot
.23441 .41789 Mdot
.33031 .63941 Mdot
.28726 .60759 Mdot
.41386 .41405 Mdot
.45785 .67895 Mdot
.58392 .56634 Mdot
.5617 .62188 Mdot
.57423 .56364 Mdot
.38837 .32368 Mdot
.46273 .39286 Mdot
.59131 .32244 Mdot
.62846 .54735 Mdot
.18388 .50881 Mdot
.31015 .61256 Mdot
.4813 .48451 Mdot
.38069 .40307 Mdot
.31165 .3774 Mdot
.33396 .62419 Mdot
.62697 .56802 Mdot
.33867 .43783 Mdot
.48048 .72039 Mdot
.58444 .57457 Mdot
.62035 .53843 Mdot
.61786 .36789 Mdot
.31503 .38692 Mdot
.70868 .29354 Mdot
.33524 .38785 Mdot
.29137 .40853 Mdot
.62334 .34143 Mdot
.60458 .5784 Mdot
.303 .60145 Mdot
.34426 .57609 Mdot
.55924 .53233 Mdot
.50688 .61504 Mdot
.56373 .32566 Mdot
.31307 .56833 Mdot
.49375 .17185 Mdot
.57362 .53011 Mdot
.42993 .40451 Mdot
.62915 .38656 Mdot
.33046 .43369 Mdot
.601 .56064 Mdot
.58665 .33346 Mdot
.2992 .58953 Mdot
.33364 .63103 Mdot
.67047 .59492 Mdot
.34288 .41696 Mdot
.49042 .69283 Mdot
.33028 .59843 Mdot
.43591 .4748 Mdot
.64863 .56619 Mdot
.46757 .40862 Mdot
.32947 .59639 Mdot
.72697 .26752 Mdot
.18411 .49509 Mdot
.60326 .33034 Mdot
.60393 .52036 Mdot
.55958 .31316 Mdot
.48716 .7028 Mdot
.30852 .65175 Mdot
.33435 .42327 Mdot
.7196 .53468 Mdot
.25431 .69727 Mdot
.3184 .6315 Mdot
.57176 .33344 Mdot
.61247 .54971 Mdot
.65434 .63482 Mdot
.65728 .57484 Mdot
.66145 .7435 Mdot
.48822 .68132 Mdot
.27652 .38364 Mdot
.3501 .40947 Mdot
.59152 .53209 Mdot
.45226 .72071 Mdot
.32048 .57374 Mdot
.33049 .61152 Mdot
.30267 .7863 Mdot
.43807 .38432 Mdot
.26893 .61356 Mdot
.65928 .54439 Mdot
.31817 .58502 Mdot
.79578 .43283 Mdot
.34955 .40371 Mdot
.56961 .55678 Mdot
.35902 .62249 Mdot
.39077 .30324 Mdot
.47373 .48692 Mdot
.64597 .56902 Mdot
.61259 .61999 Mdot
.30932 .40916 Mdot
.33194 .27205 Mdot
.35094 .60964 Mdot
.59383 .58419 Mdot
.36722 .42639 Mdot
.53297 .42065 Mdot
.29841 .73002 Mdot
.57685 .34189 Mdot
.36459 .60469 Mdot
.29523 .40642 Mdot
.54291 .51982 Mdot
.47585 .7272 Mdot
.30952 .58059 Mdot
.35999 .61074 Mdot
.61709 .52722 Mdot
.65294 .59873 Mdot
.62471 .61911 Mdot
.56641 .32808 Mdot
.29751 .39283 Mdot
.59808 .53553 Mdot
.46293 .46161 Mdot
.59318 .55004 Mdot
.29429 .39999 Mdot
.43977 .90404 Mdot
.6687 .54546 Mdot
.65215 .54435 Mdot
.72408 .60643 Mdot
.61285 .34039 Mdot
.60082 .35297 Mdot
.48421 .45685 Mdot
.66389 .54922 Mdot
.41485 .48672 Mdot
.57767 .33923 Mdot
.56201 .33924 Mdot
.41405 .48968 Mdot
.62589 .52825 Mdot
.36007 .44404 Mdot
.34211 .41125 Mdot
.31038 .37765 Mdot
.59964 .34965 Mdot
.70324 .54195 Mdot
.3151 .37416 Mdot
.72792 .49262 Mdot
.2965 .60476 Mdot
.51596 .61098 Mdot
.57937 .36722 Mdot
.45253 .50946 Mdot
.3274 .38007 Mdot
.79888 .34025 Mdot
.74668 .63155 Mdot
.56449 .5396 Mdot
.60136 .57363 Mdot
.47256 .69922 Mdot
.69285 .60167 Mdot
.43395 .395 Mdot
.33481 .41721 Mdot
.28577 .48123 Mdot
.57617 .34784 Mdot
.66432 .55976 Mdot
.5408 .75332 Mdot
.70661 .26701 Mdot
.55523 .62335 Mdot
.5607 .34681 Mdot
.57428 .35193 Mdot
.34716 .5935 Mdot
.29823 .6012 Mdot
.59823 .5808 Mdot
.32542 .42004 Mdot
.57657 .31003 Mdot
.30436 .38909 Mdot
.32679 .61904 Mdot
.29578 .6093 Mdot
.44349 .41133 Mdot
.64436 .50126 Mdot
.3323 .62201 Mdot
.35235 .35818 Mdot
.46105 .46176 Mdot
.61844 .3633 Mdot
.21232 .39155 Mdot
.81539 .3869 Mdot
.7232 .57024 Mdot
.45783 .68268 Mdot
.54923 .4329 Mdot
.35265 .39262 Mdot
.59007 .53428 Mdot
.61264 .55728 Mdot
.44755 .40434 Mdot
.34747 .38665 Mdot
.46144 .70339 Mdot
.33473 .38092 Mdot
.45362 .70112 Mdot
.31967 .64186 Mdot
.62904 .5416 Mdot
.6357 .5917 Mdot
.34078 .3987 Mdot
.33534 .5872 Mdot
.28983 .62278 Mdot
.44764 .69955 Mdot
.56046 .67845 Mdot
.31902 .61973 Mdot
.57889 .3674 Mdot
.73109 .33126 Mdot
.43807 .40142 Mdot
.62355 .56229 Mdot
.54383 .72165 Mdot
.70012 .44708 Mdot
.59753 .55044 Mdot
.44584 .38537 Mdot
.25764 .76198 Mdot
.62547 .54186 Mdot
.43369 .84982 Mdot
.45624 .40587 Mdot
.6047 .36437 Mdot
.3298 .59134 Mdot
.44097 .38397 Mdot
.56128 .47437 Mdot
.31327 .56275 Mdot
.57121 .51201 Mdot
.56228 .32432 Mdot
.57388 .37506 Mdot
.41349 .55266 Mdot
.38577 .32315 Mdot
.48227 .69371 Mdot
.46556 .71465 Mdot
.30672 .61943 Mdot
.30769 .35329 Mdot
.68994 .58114 Mdot
.46522 .7115 Mdot
.27843 .45447 Mdot
.58478 .53703 Mdot
.40809 .58443 Mdot
.39284 .51132 Mdot
.60909 .3466 Mdot
.6176 .47887 Mdot
.30779 .61571 Mdot
.57179 .33427 Mdot
.40635 .5284 Mdot
.57137 .55118 Mdot
.57515 .34467 Mdot
.30298 .38506 Mdot
.40077 .46537 Mdot
.58894 .36727 Mdot
.46381 .49976 Mdot
.33851 .40544 Mdot
.40446 .59095 Mdot
.63268 .71589 Mdot
.57845 .14449 Mdot
.33152 .41936 Mdot
.32593 .58791 Mdot
.32352 .63094 Mdot
.31802 .61638 Mdot
.55904 .33694 Mdot
.32098 .60247 Mdot
.58075 .31856 Mdot
.30924 .36701 Mdot
.55314 .68534 Mdot
.47558 .70679 Mdot
.41509 .71987 Mdot
.58499 .35835 Mdot
.37677 .34078 Mdot
.17786 .42682 Mdot
.58571 .56505 Mdot
.29503 .42046 Mdot
.44791 .71938 Mdot
.51248 .45005 Mdot
.4698 .69848 Mdot
.32993 .58979 Mdot
.51713 .61006 Mdot
.63679 .5753 Mdot
.60211 .25123 Mdot
.46324 .68226 Mdot
.55946 .34456 Mdot
.63591 .51835 Mdot
.35363 .57346 Mdot
.4874 .71263 Mdot
.45254 .68811 Mdot
.63293 .55655 Mdot
.57623 .37343 Mdot
.30242 .60043 Mdot
.35663 .39835 Mdot
.47183 .6633 Mdot
.62228 .62333 Mdot
.59442 .56804 Mdot
.66493 .5339 Mdot
.48883 .47653 Mdot
.22529 .39693 Mdot
.33513 .40703 Mdot
.56128 .77759 Mdot
.3138 .63474 Mdot
.55633 .76132 Mdot
.47703 .32146 Mdot
.5078 .7109 Mdot
.46247 .39579 Mdot
.46313 .39216 Mdot
.64269 .56373 Mdot
.22746 .34434 Mdot
.5944 .65261 Mdot
.37186 .4074 Mdot
.44139 .40069 Mdot
.28909 .61979 Mdot
.58584 .38767 Mdot
.62639 .46363 Mdot
.60986 .59952 Mdot
.34909 .38653 Mdot
.3253 .61529 Mdot
.2471 .3162 Mdot
.47664 .7169 Mdot
.50746 .45024 Mdot
.644 .58394 Mdot
.6355 .56444 Mdot
.32447 .40131 Mdot
.32884 .42294 Mdot
.43204 .41994 Mdot
.45212 .55837 Mdot
.50791 .20878 Mdot
.29116 .37924 Mdot
.24618 .31619 Mdot
.61576 .25804 Mdot
.59629 .34813 Mdot
.43022 .40228 Mdot
.29646 .38482 Mdot
.62787 .5494 Mdot
.60779 .36086 Mdot
.56527 .63985 Mdot
.56309 .39409 Mdot
.4092 .58457 Mdot
.43023 .48607 Mdot
.64138 .58646 Mdot
.58029 .30274 Mdot
.57174 .33715 Mdot
.57912 .30028 Mdot
.43933 .39283 Mdot
.61735 .57285 Mdot
.5888 .56445 Mdot
.62365 .54176 Mdot
.6689 .62782 Mdot
.64665 .56134 Mdot
.47601 .31692 Mdot
.46574 .45266 Mdot
.35265 .72226 Mdot
.64306 .53991 Mdot
.2926 .39703 Mdot
.63079 .54228 Mdot
.45894 .72808 Mdot
.67134 .56513 Mdot
.40926 .58648 Mdot
.32844 .41253 Mdot
.63858 .43974 Mdot
.3724 .57631 Mdot
.6232 .59068 Mdot
.48613 .69079 Mdot
.2235 .38403 Mdot
.54389 .76769 Mdot
.40975 .41053 Mdot
.58082 .36686 Mdot
.28249 .62001 Mdot
.31198 .43241 Mdot
.3002 .6067 Mdot
.56689 .55368 Mdot
.43899 .41271 Mdot
.84628 .53883 Mdot
.45239 .52044 Mdot
.62939 .54799 Mdot
.64637 .50307 Mdot
.60711 .35379 Mdot
.31136 .60961 Mdot
.54253 .29497 Mdot
.57982 .53957 Mdot
.4859 .72662 Mdot
.46677 .73674 Mdot
.38573 .55236 Mdot
.37196 .46672 Mdot
.75058 .5984 Mdot
.32594 .40295 Mdot
.32622 .6345 Mdot
.47745 .74028 Mdot
.63673 .33595 Mdot
.28627 .40922 Mdot
.33153 .43372 Mdot
.31285 .38783 Mdot
.65401 .56161 Mdot
.4403 .40916 Mdot
.32864 .48135 Mdot
.44655 .38219 Mdot
.57706 .55373 Mdot
.35943 .61366 Mdot
.44575 .38106 Mdot
.47773 .69823 Mdot
.2952 .41379 Mdot
.29385 .62783 Mdot
.64151 .55273 Mdot
.58339 .34192 Mdot
.54541 .7992 Mdot
.17349 .55938 Mdot
.4024 .59777 Mdot
.40231 .59795 Mdot
.58769 .37722 Mdot
.54584 .23465 Mdot
.27904 .40862 Mdot
.66396 .41956 Mdot
.51788 .66432 Mdot
.55937 .52859 Mdot
.32852 .77922 Mdot
.34787 .6263 Mdot
.33739 .60655 Mdot
.64628 .5759 Mdot
.32094 .58196 Mdot
.66218 .56928 Mdot
.35061 .60366 Mdot
.43871 .3016 Mdot
.60045 .59651 Mdot
.33376 .60497 Mdot
.68687 .59517 Mdot
.64597 .52736 Mdot
.60348 .36204 Mdot
.30817 .58205 Mdot
.56494 .53877 Mdot
.82893 .59903 Mdot
.32251 .39361 Mdot
.43871 .39369 Mdot
.40456 .60613 Mdot
.33957 .3859 Mdot
.57471 .31647 Mdot
.66515 .54789 Mdot
.48103 .71722 Mdot
.59192 .35304 Mdot
.35716 .57128 Mdot
.46934 .6837 Mdot
.49784 .42205 Mdot
.59797 .34996 Mdot
.44134 .40554 Mdot
.46335 .72519 Mdot
.57159 .51209 Mdot
.33599 .60893 Mdot
.17923 .52093 Mdot
.44179 .38487 Mdot
.63173 .57496 Mdot
.36555 .60454 Mdot
.33455 .38104 Mdot
.60948 .58486 Mdot
.32776 .63214 Mdot
.44087 .38893 Mdot
.64784 .53342 Mdot
.65717 .53554 Mdot
.64628 .45486 Mdot
.47371 .61938 Mdot
.47738 .70417 Mdot
.62195 .32738 Mdot
.58078 .55943 Mdot
.44919 .71553 Mdot
.20271 .51798 Mdot
.57939 .5798 Mdot
.54888 .34748 Mdot
.68656 .46474 Mdot
.31427 .58816 Mdot
.34984 .40645 Mdot
.33614 .57617 Mdot
.47602 .6818 Mdot
.14429 .57495 Mdot
.43137 .40044 Mdot
.63677 .50289 Mdot
.5868 .51812 Mdot
.31021 .654 Mdot
.57005 .33932 Mdot
.51886 .21262 Mdot
.67016 .56651 Mdot
.62027 .48925 Mdot
.62752 .55918 Mdot
.19534 .53094 Mdot
.56195 .33214 Mdot
.62464 .56037 Mdot
.61733 .62522 Mdot
.57717 .53001 Mdot
.49097 .70045 Mdot
.66703 .68793 Mdot
.60668 .54581 Mdot
.59983 .89669 Mdot
.45642 .41009 Mdot
.32804 .60992 Mdot
.46997 .49381 Mdot
.39296 .6413 Mdot
.57444 .82211 Mdot
.57205 .32029 Mdot
.61451 .27308 Mdot
.30053 .60426 Mdot
.52304 .80605 Mdot
.54752 .24228 Mdot
.64955 .52529 Mdot
.66305 .57581 Mdot
.32983 .58978 Mdot
.30364 .5927 Mdot
.44497 .41435 Mdot
.64529 .59566 Mdot
.64263 .493 Mdot
.35386 .58787 Mdot
.6474 .55021 Mdot
.70503 .42571 Mdot
.34947 .42918 Mdot
.60065 .34936 Mdot
.34011 .3947 Mdot
.33797 .43125 Mdot
.7243 .52535 Mdot
.50067 .46074 Mdot
.30612 .41566 Mdot
.36607 .41369 Mdot
.41828 .67876 Mdot
.73897 .58754 Mdot
.49162 .70411 Mdot
.39123 .43794 Mdot
.31144 .62102 Mdot
.61469 .57145 Mdot
.55695 .3402 Mdot
.7192 .72151 Mdot
.43624 .20918 Mdot
.52051 .59442 Mdot
.58475 .55925 Mdot
.31188 .61422 Mdot
.44253 .38581 Mdot
.58862 .58961 Mdot
.56219 .7622 Mdot
.6391 .56858 Mdot
.29731 .60053 Mdot
.74913 .57439 Mdot
.40798 .37955 Mdot
.28845 .3813 Mdot
.57271 .38948 Mdot
.62619 .54338 Mdot
.58737 .32808 Mdot
.31354 .4222 Mdot
.44475 .7009 Mdot
.4685 .70507 Mdot
.62999 .59119 Mdot
.42296 .55961 Mdot
.47838 .65503 Mdot
.64817 .5251 Mdot
.61892 .52831 Mdot
.46156 .39737 Mdot
.61908 .52894 Mdot
.60217 .58792 Mdot
.59607 .53777 Mdot
.61027 .59614 Mdot
.28823 .39796 Mdot
.51977 .34489 Mdot
.66206 .59042 Mdot
.58726 .51398 Mdot
.35721 .41549 Mdot
.56641 .5792 Mdot
.31418 .41241 Mdot
.46397 .20566 Mdot
.30351 .40999 Mdot
.4698 .70568 Mdot
.36433 .59367 Mdot
.60018 .26546 Mdot
.57776 .31009 Mdot
.29166 .39588 Mdot
.45881 .71643 Mdot
.33095 .41811 Mdot
.33135 .63564 Mdot
.19829 .42979 Mdot
.59678 .29338 Mdot
.4484 .45467 Mdot
.73273 .59673 Mdot
.46905 .40777 Mdot
.3312 .58222 Mdot
.60175 .32602 Mdot
.40212 .37929 Mdot
.59364 .53107 Mdot
.48301 .71155 Mdot
.64179 .56371 Mdot
.29473 .41495 Mdot
.31223 .61679 Mdot
.37335 .43696 Mdot
.47694 .70322 Mdot
.154 .56345 Mdot
.35584 .60841 Mdot
.61535 .50285 Mdot
.35656 .41606 Mdot
.20788 .41618 Mdot
.30932 .41267 Mdot
.55405 .6868 Mdot
.60258 .4134 Mdot
.69218 .74283 Mdot
.57935 .35523 Mdot
.45042 .4191 Mdot
.61198 .20071 Mdot
.50589 .27959 Mdot
.59148 .34272 Mdot
.37418 .57732 Mdot
.65028 .55891 Mdot
.59123 .54958 Mdot
.67086 .52715 Mdot
.53451 .36905 Mdot
.58305 .56949 Mdot
.43406 .39835 Mdot
.49167 .46254 Mdot
.25307 .44164 Mdot
.2831 .61333 Mdot
.65992 .57357 Mdot
.33537 .42782 Mdot
.28835 .40718 Mdot
.4511 .38026 Mdot
.32703 .38467 Mdot
.63788 .52889 Mdot
.58383 .35768 Mdot
.40095 .51926 Mdot
.48685 .70361 Mdot
.45723 .32487 Mdot
.51072 .65993 Mdot
.48871 .66886 Mdot
.57479 .53108 Mdot
.29627 .60799 Mdot
.27434 .73311 Mdot
.58801 .54067 Mdot
.57653 .33691 Mdot
.59177 .51544 Mdot
.59972 .5404 Mdot
.60902 .54748 Mdot
.32467 .63449 Mdot
.46608 .49056 Mdot
.64682 .54855 Mdot
.30592 .41648 Mdot
.41423 .49265 Mdot
.62315 .6023 Mdot
.29861 .48915 Mdot
.41006 .58423 Mdot
.4682 .40706 Mdot
.61729 .36624 Mdot
.31211 .5961 Mdot
.57674 .34999 Mdot
.53503 .33764 Mdot
.57544 .3162 Mdot
.29725 .47585 Mdot
.6668 .43226 Mdot
.46135 .85821 Mdot
.79452 .44978 Mdot
.75206 .57666 Mdot
.54518 .35705 Mdot
.23993 .50764 Mdot
.59161 .3384 Mdot
.57425 .31769 Mdot
.36394 .85697 Mdot
.55234 .34918 Mdot
.61674 .56244 Mdot
.67476 .56794 Mdot
.61003 .24224 Mdot
.41946 .68271 Mdot
.65715 .54239 Mdot
.58695 .57317 Mdot
.47285 .73959 Mdot
.60203 .43511 Mdot
.44626 .41611 Mdot
.50324 .44777 Mdot
.42548 .40156 Mdot
.63386 .55652 Mdot
.63297 .58745 Mdot
.67408 .58988 Mdot
.63837 .19821 Mdot
.68324 .75948 Mdot
.59106 .37459 Mdot
.55682 .56866 Mdot
.46335 .37397 Mdot
.60901 .50842 Mdot
.58513 .52068 Mdot
.62224 .54012 Mdot
.30251 .60179 Mdot
.58867 .38589 Mdot
.55275 .52103 Mdot
.483 .35369 Mdot
.64139 .58542 Mdot
.50739 .66951 Mdot
.43911 .69605 Mdot
.62555 .56784 Mdot
.55227 .3556 Mdot
.5875 .55416 Mdot
.5611 .31395 Mdot
.60022 .34461 Mdot
.6535 .50358 Mdot
.34115 .47959 Mdot
.57607 .38757 Mdot
.65116 .5265 Mdot
.33337 .58547 Mdot
.45378 .31363 Mdot
.63009 .57363 Mdot
.47626 .69104 Mdot
.60026 .56003 Mdot
.48874 .69246 Mdot
.61705 .53468 Mdot
.45007 .38175 Mdot
.68416 .32824 Mdot
.3023 .61825 Mdot
.47235 .6618 Mdot
.32297 .58256 Mdot
.66763 .49765 Mdot
.546 .34586 Mdot
.40555 .39253 Mdot
.66011 .78404 Mdot
.46094 .39918 Mdot
.56236 .78606 Mdot
.40861 .48419 Mdot
.35025 .41836 Mdot
.60007 .31043 Mdot
.74443 .56741 Mdot
.32909 .50063 Mdot
.28417 .63685 Mdot
.31413 .64823 Mdot
.309 .74155 Mdot
.26063 .75372 Mdot
.64893 .54644 Mdot
.22948 .4197 Mdot
.70848 .38387 Mdot
.67741 .61584 Mdot
.63271 .61186 Mdot
.36021 .60492 Mdot
.65672 .54125 Mdot
.48294 .52527 Mdot
.32018 .62715 Mdot
.46694 .72041 Mdot
.59016 .32268 Mdot
.45138 .71362 Mdot
.40229 .20841 Mdot
.4069 .40897 Mdot
.32756 .6246 Mdot
.6162 .59852 Mdot
.65991 .55913 Mdot
.61012 .32455 Mdot
.79605 .37814 Mdot
.60262 .34569 Mdot
.48356 .69337 Mdot
.30637 .62864 Mdot
.76028 .64494 Mdot
.60308 .55516 Mdot
.56605 .36127 Mdot
.37292 .57752 Mdot
.60579 .5753 Mdot
.3481 .41078 Mdot
.58419 .55689 Mdot
.56879 .36465 Mdot
.61859 .52937 Mdot
.58407 .35578 Mdot
.34687 .5963 Mdot
.64225 .59127 Mdot
.62823 .58835 Mdot
.56625 .78225 Mdot
.46191 .70147 Mdot
.54656 .35191 Mdot
.48481 .52529 Mdot
.57433 .56355 Mdot
.56488 .75609 Mdot
.62805 .54167 Mdot
.69725 .62026 Mdot
.5808 .59138 Mdot
.4343 .40134 Mdot
.58456 .51994 Mdot
.63153 .57345 Mdot
.80805 .42735 Mdot
.7968 .42635 Mdot
.72167 .59203 Mdot
.30907 .3776 Mdot
.56261 .36492 Mdot
.32626 .62957 Mdot
.29364 .59527 Mdot
.31896 .59962 Mdot
.42966 .69989 Mdot
.56198 .5857 Mdot
.63506 .57794 Mdot
.29 .36836 Mdot
.46846 .71476 Mdot
.56165 .35325 Mdot
.47236 .71024 Mdot
.50495 .46136 Mdot
.47113 .68726 Mdot
.43261 .3962 Mdot
.18494 .4905 Mdot
.70497 .44124 Mdot
.46127 .69064 Mdot
.60197 .34535 Mdot
.42393 .4729 Mdot
.56003 .52399 Mdot
.36349 .3122 Mdot
.48525 .72766 Mdot
.28797 .7303 Mdot
.64564 .53473 Mdot
.47254 .50318 Mdot
.31339 .40833 Mdot
.45172 .71365 Mdot
.31532 .38789 Mdot
.58816 .55241 Mdot
.51999 .36232 Mdot
.57432 .33182 Mdot
.35034 .42746 Mdot
.57847 .53202 Mdot
.45203 .71486 Mdot
.33177 .62028 Mdot
.7435 .58175 Mdot
.36116 .41136 Mdot
.53888 .79909 Mdot
.55443 .75928 Mdot
.30848 .63001 Mdot
.76204 .57539 Mdot
.30655 .39728 Mdot
.55778 .53332 Mdot
.53668 .52185 Mdot
.58344 .5467 Mdot
.29058 .62633 Mdot
.33754 .60465 Mdot
.51381 .30852 Mdot
.63822 .58857 Mdot
.67298 .58325 Mdot
.59747 .37939 Mdot
.30991 .63443 Mdot
.57482 .31542 Mdot
.60655 .32322 Mdot
.33054 .58882 Mdot
.60402 .33083 Mdot
.46153 .68311 Mdot
.50606 .5087 Mdot
.30493 .39981 Mdot
.34681 .41487 Mdot
.3306 .62386 Mdot
.30952 .64023 Mdot
.2943 .61111 Mdot
.58274 .53349 Mdot
.59342 .31559 Mdot
.60812 .51833 Mdot
.62124 .54535 Mdot
.6219 .38024 Mdot
.60994 .36875 Mdot
.59431 .52017 Mdot
.38837 .50788 Mdot
.49472 .70452 Mdot
.3312 .60452 Mdot
.30479 .38696 Mdot
.55762 .8039 Mdot
.35445 .41532 Mdot
.57627 .56474 Mdot
.3901 .30603 Mdot
.55933 .33783 Mdot
.47102 .69851 Mdot
.40462 .5954 Mdot
.47532 .70104 Mdot
.34862 .42903 Mdot
.6183 .35436 Mdot
.49291 .43097 Mdot
.64015 .58917 Mdot
.49052 .47412 Mdot
.60857 .74116 Mdot
.47995 .32716 Mdot
.29819 .39075 Mdot
.58501 .56541 Mdot
.45801 .40367 Mdot
.66382 .40806 Mdot
.63915 .57775 Mdot
.56854 .55429 Mdot
.36385 .66872 Mdot
.57951 .52212 Mdot
.61969 .3427 Mdot
.41574 .56586 Mdot
.62581 .59614 Mdot
.67148 .50133 Mdot
.3032 .79768 Mdot
.65054 .53474 Mdot
.62819 .58947 Mdot
.60997 .5631 Mdot
.58936 .53258 Mdot
.55642 .31595 Mdot
.30018 .68102 Mdot
.32831 .42768 Mdot
.50578 .50943 Mdot
.30796 .39176 Mdot
.34016 .61424 Mdot
.46882 .53672 Mdot
.56006 .3138 Mdot
.4756 .70048 Mdot
.22484 .42125 Mdot
.51354 .5964 Mdot
.34542 .5913 Mdot
.60256 .7979 Mdot
.48967 .7181 Mdot
.55929 .52506 Mdot
.46516 .67872 Mdot
.36179 .60778 Mdot
.34124 .41785 Mdot
.65892 .5251 Mdot
.56269 .32107 Mdot
.58844 .36711 Mdot
.58238 .55754 Mdot
.45092 .32758 Mdot
.34301 .38691 Mdot
.49091 .76002 Mdot
.65361 .5669 Mdot
.56971 .55812 Mdot
.60438 .34171 Mdot
.31243 .61025 Mdot
.40974 .48562 Mdot
.45781 .70651 Mdot
.64925 .51613 Mdot
.58966 .55584 Mdot
.50362 .46299 Mdot
.2895 .39811 Mdot
.44768 .39575 Mdot
.64926 .57969 Mdot
.49651 .45384 Mdot
.58294 .5724 Mdot
.70058 .55746 Mdot
.32462 .58501 Mdot
.63204 .49217 Mdot
.65826 .58408 Mdot
.52215 .34538 Mdot
.30983 .39423 Mdot
.574 .34052 Mdot
.63068 .36241 Mdot
.45706 .38503 Mdot
.32783 .39413 Mdot
.59047 .52264 Mdot
.33128 .43502 Mdot
.59622 .54464 Mdot
.64387 .55108 Mdot
.29888 .38936 Mdot
.58262 .31422 Mdot
.5067 .21892 Mdot
.5196 .34585 Mdot
.60289 .52843 Mdot
.60004 .56376 Mdot
.42071 .68048 Mdot
.72824 .72685 Mdot
.65753 .58577 Mdot
.5982 .31925 Mdot
.60574 .57652 Mdot
.34499 .42113 Mdot
.48097 .69066 Mdot
.58233 .33836 Mdot
.32276 .63871 Mdot
.3477 .60172 Mdot
.36705 .6339 Mdot
.4314 .39846 Mdot
.64576 .59484 Mdot
.62275 .32937 Mdot
.60465 .37238 Mdot
.51522 .48988 Mdot
.32907 .60924 Mdot
.4776 .68671 Mdot
.65756 .5398 Mdot
.71921 .52832 Mdot
.32998 .43166 Mdot
.618 .88449 Mdot
.49044 .43468 Mdot
.44405 .67812 Mdot
.44775 .57517 Mdot
.45798 .40082 Mdot
.65435 .54425 Mdot
.45592 .72408 Mdot
.34337 .60116 Mdot
.59021 .55079 Mdot
.60508 .61729 Mdot
.33133 .50471 Mdot
.30859 .64264 Mdot
.33884 .43284 Mdot
.34816 .61967 Mdot
.49088 .69587 Mdot
.4333 .3959 Mdot
.58808 .37018 Mdot
.63289 .56988 Mdot
.62864 .48523 Mdot
.31874 .61319 Mdot
.46472 .38614 Mdot
.6168 .59022 Mdot
.57151 .36966 Mdot
.32533 .60274 Mdot
.63021 .55378 Mdot
.66111 .41525 Mdot
.6036 .26814 Mdot
.31039 .62524 Mdot
.65173 .51974 Mdot
.65379 .47555 Mdot
.31076 .64507 Mdot
.35735 .62384 Mdot
.58531 .57207 Mdot
.45408 .7158 Mdot
.65212 .58555 Mdot
.31721 .41735 Mdot
.46519 .49014 Mdot
.33804 .39797 Mdot
.56562 .76385 Mdot
.66822 .59379 Mdot
.55933 .63221 Mdot
.57928 .30421 Mdot
.50156 .70535 Mdot
.82603 .47591 Mdot
.57355 .56722 Mdot
.52397 .18912 Mdot
.45249 .50672 Mdot
.46416 .44244 Mdot
.47201 .17657 Mdot
.45617 .69818 Mdot
.32821 .41687 Mdot
.61702 .58919 Mdot
.2868 .35858 Mdot
.45332 .69694 Mdot
.56672 .76363 Mdot
.62206 .50876 Mdot
.56187 .34125 Mdot
.65183 .56621 Mdot
.57115 .36739 Mdot
.60637 .5715 Mdot
.61925 .43061 Mdot
.50213 .66461 Mdot
.55461 .68555 Mdot
.55915 .52156 Mdot
.21791 .39971 Mdot
.73598 .59378 Mdot
.48101 .69493 Mdot
.60775 .52901 Mdot
.45414 .39731 Mdot
.33289 .37991 Mdot
.21474 .45613 Mdot
.29832 .60647 Mdot
.30179 .41148 Mdot
.60025 .33166 Mdot
.35856 .58749 Mdot
.46431 .38832 Mdot
.53948 .54272 Mdot
.45371 .71836 Mdot
.32335 .39381 Mdot
.62958 .57124 Mdot
.57731 .54664 Mdot
.1946 .53089 Mdot
.78154 .62387 Mdot
.60259 .32179 Mdot
.19464 .6444 Mdot
.62069 .32627 Mdot
.46241 .70952 Mdot
.31922 .58715 Mdot
.62279 .55037 Mdot
.63726 .58267 Mdot
.3037 .63736 Mdot
.61322 .34384 Mdot
.50391 .70594 Mdot
.69993 .73856 Mdot
.38343 .40014 Mdot
.61331 .69009 Mdot
.58389 .33627 Mdot
.6082 .68977 Mdot
.46205 .745 Mdot
.30618 .45527 Mdot
.72174 .64598 Mdot
.34719 .40365 Mdot
.61918 .69064 Mdot
.55932 .35252 Mdot
.65034 .54576 Mdot
.44239 .40513 Mdot
.45286 .41019 Mdot
.59177 .32847 Mdot
.32487 .58981 Mdot
.47418 .72764 Mdot
.64982 .56963 Mdot
.53515 .56518 Mdot
.79138 .35896 Mdot
.31165 .63907 Mdot
.65133 .50684 Mdot
.33454 .38338 Mdot
.60247 .57194 Mdot
.46636 .73812 Mdot
.33908 .41388 Mdot
.43805 .38338 Mdot
.51016 .58565 Mdot
.66478 .54638 Mdot
.41771 .57235 Mdot
.31625 .40204 Mdot
.73311 .72162 Mdot
.62792 .58798 Mdot
.30684 .39692 Mdot
.63228 .48695 Mdot
.44529 .36129 Mdot
.40566 .51131 Mdot
.50556 .27569 Mdot
.28497 .5972 Mdot
.35008 .60836 Mdot
.81615 .61423 Mdot
.51926 .66512 Mdot
.29885 .4121 Mdot
.43522 .39117 Mdot
.69285 .67583 Mdot
.32101 .38827 Mdot
.65859 .52669 Mdot
.63319 .53986 Mdot
.74954 .57382 Mdot
.71678 .55346 Mdot
.44842 .41485 Mdot
.55741 .59639 Mdot
.63302 .52482 Mdot
.5768 .50368 Mdot
.60144 .58032 Mdot
.57626 .3753 Mdot
.3465 .39748 Mdot
.37457 .15392 Mdot
.31428 .43173 Mdot
.52879 .57955 Mdot
.31139 .62068 Mdot
.30459 .58124 Mdot
.6261 .56696 Mdot
.58297 .65443 Mdot
.22457 .33285 Mdot
.6047 .55166 Mdot
.40517 .59442 Mdot
.55358 .76071 Mdot
.55622 .5421 Mdot
.55294 .37062 Mdot
.63809 .49161 Mdot
.59946 .29816 Mdot
.34051 .41406 Mdot
.45562 .69703 Mdot
.49216 .72355 Mdot
.32113 .41517 Mdot
.63117 .58121 Mdot
.48928 .73169 Mdot
.63277 .56297 Mdot
.65825 .55391 Mdot
.50596 .45382 Mdot
.44337 .70775 Mdot
.29409 .61011 Mdot
.47025 .70376 Mdot
.56844 .32269 Mdot
.37772 .87256 Mdot
.47836 .71236 Mdot
.73966 .5868 Mdot
.47294 .51547 Mdot
.61946 .693 Mdot
.5938 .36499 Mdot
.48584 .69743 Mdot
.3487 .40268 Mdot
.49242 .42111 Mdot
.7595 .57278 Mdot
.35379 .41626 Mdot
.64242 .57942 Mdot
.56246 .31141 Mdot
.59333 .37603 Mdot
.28976 .38264 Mdot
.60847 .35439 Mdot
.59891 .50048 Mdot
.65299 .52638 Mdot
.30876 .42024 Mdot
.70189 .25918 Mdot
.35071 .40576 Mdot
.72595 .54054 Mdot
.62428 .53759 Mdot
.57924 .33774 Mdot
.6925 .62288 Mdot
.60257 .39344 Mdot
.44234 .41182 Mdot
.67205 .5689 Mdot
.48282 .70594 Mdot
.499 .50865 Mdot
.30897 .62438 Mdot
.3953 .30342 Mdot
.58067 .36717 Mdot
.28268 .40648 Mdot
.60205 .36323 Mdot
.6105 .33225 Mdot
.35178 .42475 Mdot
.56834 .33018 Mdot
.64016 .58514 Mdot
.35201 .24498 Mdot
.58527 .36443 Mdot
.32323 .40483 Mdot
.48543 .7121 Mdot
.60275 .32829 Mdot
.46127 .76082 Mdot
.66193 .55694 Mdot
.34582 .58522 Mdot
.46396 .66501 Mdot
.57477 .30208 Mdot
.47944 .6907 Mdot
.32301 .6102 Mdot
.47214 .72935 Mdot
.31068 .36007 Mdot
.27794 .40125 Mdot
.52399 .60004 Mdot
.42295 .3703 Mdot
.55737 .33436 Mdot
.28765 .59065 Mdot
.66721 .55794 Mdot
.65604 .5632 Mdot
.49394 .69347 Mdot
.58067 .37749 Mdot
.44022 .32986 Mdot
.62122 .64949 Mdot
.45783 .32629 Mdot
.29847 .38451 Mdot
.48395 .78604 Mdot
.48984 .43291 Mdot
.37025 .37133 Mdot
.68082 .56169 Mdot
.4567 .40177 Mdot
.62662 .55906 Mdot
.54331 .76721 Mdot
.49225 .70786 Mdot
.21607 .55667 Mdot
.69005 .58079 Mdot
.29972 .62933 Mdot
.60448 .56496 Mdot
.23565 .44019 Mdot
.68369 .51471 Mdot
.48839 .7249 Mdot
.34431 .43566 Mdot
.57775 .31005 Mdot
.48903 .70809 Mdot
.34696 .59843 Mdot
.63661 .6752 Mdot
.66146 .53242 Mdot
.63787 .52645 Mdot
.32581 .64797 Mdot
.57003 .31726 Mdot
.33921 .6111 Mdot
.30511 .39915 Mdot
.47606 .71105 Mdot
.59275 .52791 Mdot
.61666 .492 Mdot
.31384 .65438 Mdot
.30501 .42543 Mdot
.29708 .63721 Mdot
.32817 .4345 Mdot
.45341 .40433 Mdot
.62768 .59847 Mdot
.33346 .64856 Mdot
.68283 .57905 Mdot
.78009 .40379 Mdot
.51065 .51706 Mdot
.80706 .50108 Mdot
.29411 .60911 Mdot
.48912 .6494 Mdot
.32424 .41251 Mdot
.31826 .39316 Mdot
.72904 .53492 Mdot
.22517 .34409 Mdot
.41467 .48705 Mdot
.18465 .44501 Mdot
.30457 .40034 Mdot
.3212 .39822 Mdot
.33774 .59747 Mdot
.5765 .31993 Mdot
.53814 .32715 Mdot
.36368 .61356 Mdot
.5444 .72063 Mdot
.56164 .35364 Mdot
.55363 .19856 Mdot
.34268 .63501 Mdot
.67532 .55436 Mdot
.41137 .39924 Mdot
.48723 .72608 Mdot
.54405 .75348 Mdot
.19569 .43912 Mdot
.62 .55524 Mdot
.41188 .84003 Mdot
.30708 .60031 Mdot
.40181 .42851 Mdot
.2583 .41686 Mdot
.57281 .54899 Mdot
.60764 .56637 Mdot
.62312 .58333 Mdot
.45924 .67057 Mdot
.78288 .37086 Mdot
.62257 .55267 Mdot
.53747 .66572 Mdot
.5991 .59605 Mdot
.18466 .52735 Mdot
.47034 .70411 Mdot
.65655 .74923 Mdot
.32551 .56976 Mdot
.47212 .34925 Mdot
.57327 .53477 Mdot
.30588 .4056 Mdot
.35574 .50708 Mdot
.29361 .3986 Mdot
.27281 .43994 Mdot
.71712 .65721 Mdot
.5712 .37512 Mdot
.58364 .55598 Mdot
.34491 .63533 Mdot
.56679 .30738 Mdot
.36971 .50841 Mdot
.3445 .84961 Mdot
.29162 .38626 Mdot
.18548 .67624 Mdot
.33354 .39207 Mdot
.45249 .41135 Mdot
.59964 .33468 Mdot
.61671 .66491 Mdot
.4943 .47043 Mdot
.57633 .31511 Mdot
.37742 .75704 Mdot
.56352 .29818 Mdot
.59162 .67687 Mdot
.5947 .2904 Mdot
.3282 .40922 Mdot
.28128 .40853 Mdot
.59744 .61069 Mdot
.66549 .57686 Mdot
.48357 .47477 Mdot
.64977 .61036 Mdot
.66548 .55151 Mdot
.31996 .62739 Mdot
.41241 .36997 Mdot
.2797 .36014 Mdot
.58556 .33208 Mdot
.31629 .42745 Mdot
.60587 .56476 Mdot
.60356 .52815 Mdot
.59797 .50856 Mdot
.53081 .80738 Mdot
.5505 .1962 Mdot
.64446 .54835 Mdot
.68109 .51326 Mdot
.34054 .58878 Mdot
.19374 .53308 Mdot
.20565 .64266 Mdot
.70454 .66545 Mdot
.61314 .58986 Mdot
.46367 .70233 Mdot
.47253 .74058 Mdot
.59366 .50595 Mdot
.55128 .63068 Mdot
.44727 .76159 Mdot
.62944 .57145 Mdot
.57216 .66373 Mdot
.29389 .64862 Mdot
.46052 .38298 Mdot
.31934 .61313 Mdot
.56949 .30449 Mdot
.461 .40096 Mdot
.33518 .62781 Mdot
.52889 .64883 Mdot
.45318 .38479 Mdot
.45002 .35931 Mdot
.48467 .69474 Mdot
.6101 .58497 Mdot
.56157 .27867 Mdot
.3124 .63703 Mdot
.31686 .39791 Mdot
.58794 .34973 Mdot
.3271 .37719 Mdot
.18221 .51142 Mdot
.54684 .73232 Mdot
.43212 .4019 Mdot
.30593 .4085 Mdot
.42383 .54554 Mdot
.46484 .70372 Mdot
.3308 .3873 Mdot
.5673 .64064 Mdot
.64304 .60191 Mdot
.27582 .26677 Mdot
.63545 .52199 Mdot
.52445 .28611 Mdot
.3118 .39909 Mdot
.43384 .38406 Mdot
.63469 .56963 Mdot
.35516 .60625 Mdot
.55137 .54676 Mdot
.63416 .56207 Mdot
.33867 .63373 Mdot
.64693 .54602 Mdot
.44948 .71961 Mdot
.59843 .29937 Mdot
.45673 .51473 Mdot
.51854 .79072 Mdot
.48136 .72499 Mdot
.53312 .47098 Mdot
.661 .58412 Mdot
.33694 .72946 Mdot
.56354 .34025 Mdot
.57405 .56563 Mdot
.58262 .77435 Mdot
.58373 .32304 Mdot
.57626 .35098 Mdot
.61807 .52581 Mdot
.35223 .40623 Mdot
.29248 .62763 Mdot
.46649 .70304 Mdot
.31674 .35404 Mdot
.62978 .55211 Mdot
.58476 .56701 Mdot
.49026 .71543 Mdot
.32666 .39545 Mdot
.59365 .52521 Mdot
.4501 .26863 Mdot
.51505 .49799 Mdot
.33344 .43268 Mdot
.62532 .60244 Mdot
.39291 .17466 Mdot
.54063 .319 Mdot
.42406 .84561 Mdot
.50588 .65994 Mdot
.32691 .58705 Mdot
.66788 .52128 Mdot
.56804 .91012 Mdot
.48511 .6986 Mdot
.47368 .33908 Mdot
.6512 .55043 Mdot
.61896 .5493 Mdot
.56128 .36901 Mdot
.60597 .51618 Mdot
.55754 .3582 Mdot
.49917 .79395 Mdot
.20815 .35753 Mdot
.60704 .35529 Mdot
.56235 .36233 Mdot
.70765 .53985 Mdot
.53756 .81252 Mdot
.5935 .32449 Mdot
.66151 .53288 Mdot
.35895 .73256 Mdot
.61938 .62212 Mdot
.44008 .70037 Mdot
.42855 .74421 Mdot
.55094 .36714 Mdot
.77107 .54573 Mdot
.70782 .54183 Mdot
.65016 .44561 Mdot
.44226 .74578 Mdot
.29817 .40305 Mdot
.6069 .53964 Mdot
.43173 .39489 Mdot
.32888 .60078 Mdot
.5897 .4911 Mdot
.62108 .58685 Mdot
.55126 .3384 Mdot
.46737 .67228 Mdot
.32221 .38643 Mdot
.59379 .57867 Mdot
.3221 .65674 Mdot
.46171 .71722 Mdot
.5919 .36014 Mdot
.73626 .56995 Mdot
.4863 .73287 Mdot
.62911 .49427 Mdot
.64784 .5406 Mdot
.60047 .58449 Mdot
.65551 .62631 Mdot
.31812 .41322 Mdot
.36416 .60124 Mdot
.66464 .52015 Mdot
.49866 .43534 Mdot
.50014 .53093 Mdot
.64041 .50663 Mdot
.6 .32191 Mdot
.30094 .38357 Mdot
.44329 .39008 Mdot
.64965 .69231 Mdot
.63777 .5349 Mdot
.53954 .19037 Mdot
.63724 .79061 Mdot
.45286 .3877 Mdot
.54882 .32129 Mdot
.47168 .69983 Mdot
.62745 .52988 Mdot
.5425 .67734 Mdot
.65521 .5249 Mdot
.60552 .62385 Mdot
.31747 .59105 Mdot
.3004 .39461 Mdot
.52708 .51791 Mdot
.33145 .6009 Mdot
.57655 .35032 Mdot
.60205 .23073 Mdot
.54537 .31545 Mdot
.60754 .32631 Mdot
.33579 .4768 Mdot
.33431 .42136 Mdot
.58153 .90699 Mdot
.72141 .73825 Mdot
.67363 .55718 Mdot
.33075 .42518 Mdot
.59666 .33437 Mdot
.59743 .51469 Mdot
.55718 .34297 Mdot
.57716 .38664 Mdot
.66052 .54388 Mdot
.66286 .54853 Mdot
.55583 .67874 Mdot
.56356 .20544 Mdot
.48261 .71226 Mdot
.6067 .36165 Mdot
.71158 .49112 Mdot
.62725 .54886 Mdot
.64375 .58726 Mdot
.34592 .50429 Mdot
.48866 .7029 Mdot
.69258 .41106 Mdot
.6545 .56091 Mdot
.57419 .78845 Mdot
.67026 .5629 Mdot
.53506 .34689 Mdot
.31973 .3703 Mdot
.53788 .60399 Mdot
.28905 .62236 Mdot
.60339 .3128 Mdot
.4915 .69207 Mdot
.6116 .37748 Mdot
.69083 .44772 Mdot
.34061 .41666 Mdot
.5681 .36434 Mdot
.35268 .57903 Mdot
.33447 .40052 Mdot
.34979 .41021 Mdot
.37522 .50838 Mdot
.35013 .58049 Mdot
.45211 .67452 Mdot
.31818 .38081 Mdot
.65954 .41689 Mdot
.33114 .40825 Mdot
.68589 .44052 Mdot
.6422 .59344 Mdot
.53525 .66092 Mdot
.52896 .54727 Mdot
.61151 .61685 Mdot
.34188 .39315 Mdot
.46954 .72533 Mdot
.58547 .52957 Mdot
.60941 .34866 Mdot
.47623 .71979 Mdot
.40308 .41167 Mdot
.31276 .57617 Mdot
.5876 .37868 Mdot
.34496 .43367 Mdot
.55372 .34701 Mdot
.55021 .75785 Mdot
.50313 .6904 Mdot
.36795 .51876 Mdot
.49079 .47898 Mdot
.56917 .50853 Mdot
.68666 .51345 Mdot
.57872 .535 Mdot
.63275 .58378 Mdot
.31105 .62477 Mdot
.43033 .69709 Mdot
.60307 .3283 Mdot
.78647 .34181 Mdot
.30896 .40812 Mdot
.41794 .56542 Mdot
.58599 .61608 Mdot
.59385 .54662 Mdot
.59487 .34047 Mdot
.59127 .38601 Mdot
.79783 .4275 Mdot
.30158 .63706 Mdot
.62848 .62215 Mdot
.57095 .53029 Mdot
.55062 .48178 Mdot
.34278 .39741 Mdot
.48172 .24888 Mdot
.28627 .60712 Mdot
.20266 .71523 Mdot
.33248 .60437 Mdot
.34495 .6862 Mdot
.56889 .32907 Mdot
.47103 .68549 Mdot
.65266 .57949 Mdot
.56217 .418 Mdot
.55132 .32321 Mdot
.28451 .58664 Mdot
.47694 .69848 Mdot
.50122 .22955 Mdot
.31677 .42171 Mdot
.61489 .59331 Mdot
.66996 .55814 Mdot
.6098 .52133 Mdot
.60698 .5106 Mdot
.31234 .42332 Mdot
.652 .52211 Mdot
.36201 .41357 Mdot
.70032 .44795 Mdot
.58777 .76881 Mdot
.35096 .63229 Mdot
.19673 .54792 Mdot
.60851 .32969 Mdot
.65349 .3167 Mdot
.70033 .42439 Mdot
.51093 .51622 Mdot
.31326 .36211 Mdot
.63368 .59703 Mdot
.32537 .59079 Mdot
.22211 .39949 Mdot
.35115 .63064 Mdot
.29183 .21521 Mdot
.74791 .57731 Mdot
.52992 .25758 Mdot
.61801 .51397 Mdot
.34307 .64499 Mdot
.76833 .51738 Mdot
.62231 .49191 Mdot
.49392 .72828 Mdot
.67112 .43878 Mdot
.53141 .29603 Mdot
.47966 .6878 Mdot
.6604 .55163 Mdot
.61197 .36692 Mdot
.64457 .58191 Mdot
.65793 .57345 Mdot
.60236 .55268 Mdot
.33571 .37374 Mdot
.67108 .58213 Mdot
.65245 .58498 Mdot
.77693 .63048 Mdot
.40178 .57987 Mdot
.35012 .59555 Mdot
.80894 .4827 Mdot
.46878 .7151 Mdot
.57165 .30438 Mdot
.45437 .50422 Mdot
.31448 .4179 Mdot
.79828 .43092 Mdot
.62551 .51781 Mdot
.47408 .31097 Mdot
.28654 .41485 Mdot
.45488 .71166 Mdot
.44359 .38724 Mdot
.47041 .22237 Mdot
.30298 .59499 Mdot
.4414 .41524 Mdot
.30773 .62387 Mdot
.80296 .52992 Mdot
.56088 .36214 Mdot
.5706 .50774 Mdot
.31897 .38475 Mdot
.35998 .60551 Mdot
.54069 .67075 Mdot
.61147 .58145 Mdot
.29321 .61051 Mdot
.56455 .50417 Mdot
.49491 .5162 Mdot
.45613 .49858 Mdot
.36075 .59721 Mdot
.29647 .42683 Mdot
.33971 .40182 Mdot
.47607 .68316 Mdot
.58851 .3032 Mdot
.56427 .32111 Mdot
.33779 .40771 Mdot
.29092 .77278 Mdot
.62803 .5535 Mdot
.63337 .54284 Mdot
.49642 .4308 Mdot
.59155 .51702 Mdot
.44385 .66308 Mdot
.46406 .40452 Mdot
.55941 .32189 Mdot
.58109 .53263 Mdot
.59476 .52473 Mdot
.64838 .53747 Mdot
.54971 .72582 Mdot
.31765 .61189 Mdot
.63283 .52561 Mdot
.45521 .72184 Mdot
.43058 .41933 Mdot
.66763 .56164 Mdot
.59769 .4942 Mdot
.55583 .35474 Mdot
.29685 .7299 Mdot
.31302 .40097 Mdot
.30704 .63504 Mdot
.3346 .6418 Mdot
.60486 .73357 Mdot
.55059 .38535 Mdot
.44999 .41515 Mdot
.19675 .49896 Mdot
.437 .39192 Mdot
.47531 .69316 Mdot
.40603 .50098 Mdot
.28163 .64622 Mdot
.35066 .6052 Mdot
.30989 .43712 Mdot
.57764 .55518 Mdot
.66754 .55476 Mdot
.4674 .34384 Mdot
.61173 .54838 Mdot
.48354 .70467 Mdot
.35527 .4054 Mdot
.56121 .35996 Mdot
.46542 .7366 Mdot
.32064 .39152 Mdot
.57229 .31564 Mdot
.56974 .57205 Mdot
.64724 .51343 Mdot
.58459 .35191 Mdot
.59383 .36113 Mdot
.61783 .56599 Mdot
.79627 .60544 Mdot
.56379 .31637 Mdot
.59407 .34739 Mdot
.48531 .40852 Mdot
.32178 .58403 Mdot
.69877 .60439 Mdot
.33323 .4242 Mdot
.64223 .586 Mdot
.34793 .63681 Mdot
.4653 .68951 Mdot
.5769 .35815 Mdot
.61096 .53892 Mdot
.63716 .55213 Mdot
.4647 .70089 Mdot
.44711 .72152 Mdot
.48727 .71495 Mdot
.32706 .37358 Mdot
.65071 .52595 Mdot
.59655 .32549 Mdot
.31652 .42203 Mdot
.48073 .73553 Mdot
.46206 .67826 Mdot
.77411 .61815 Mdot
.61962 .55731 Mdot
.48519 .739 Mdot
.43095 .90011 Mdot
.65145 .67634 Mdot
.46342 .39839 Mdot
.30557 .65749 Mdot
.48301 .65229 Mdot
.4705 .66562 Mdot
.29463 .40483 Mdot
.41028 .58105 Mdot
.48145 .67975 Mdot
.60836 .54613 Mdot
.59775 .56921 Mdot
.6822 .55664 Mdot
.4716 .71957 Mdot
.55095 .73856 Mdot
.60502 .36872 Mdot
.71006 .35813 Mdot
.46898 .71516 Mdot
.35755 .59243 Mdot
.31999 .65476 Mdot
.33634 .60506 Mdot
.61007 .59416 Mdot
.8165 .45054 Mdot
.70967 .47387 Mdot
.69256 .4004 Mdot
.30724 .41581 Mdot
.58997 .38598 Mdot
.36943 .44049 Mdot
.57581 .35152 Mdot
.31583 .60147 Mdot
.46334 .7202 Mdot
.56276 .37064 Mdot
.34888 .41132 Mdot
.34217 .4016 Mdot
.29201 .6348 Mdot
.32478 .61183 Mdot
.3294 .62287 Mdot
.59855 .30862 Mdot
.56843 .32961 Mdot
.59766 .5266 Mdot
.57824 .36196 Mdot
.64339 .79361 Mdot
.47069 .65802 Mdot
.30302 .64746 Mdot
.31721 .40692 Mdot
.59797 .34916 Mdot
.61405 .58674 Mdot
.38048 .66405 Mdot
.27962 .59578 Mdot
.47572 .73224 Mdot
.31709 .28729 Mdot
.19031 .36613 Mdot
.61077 .59849 Mdot
.30254 .42263 Mdot
.55603 .63226 Mdot
.62068 .58055 Mdot
.30859 .5947 Mdot
.67144 .75459 Mdot
.44511 .38346 Mdot
.66093 .57682 Mdot
.56606 .54705 Mdot
.34966 .4011 Mdot
.45571 .50242 Mdot
.60489 .54774 Mdot
.40589 .52938 Mdot
.28687 .39925 Mdot
.28585 .60872 Mdot
.82628 .61893 Mdot
.40358 .42373 Mdot
.52281 .75849 Mdot
.46289 .38974 Mdot
.61388 .54572 Mdot
.3177 .62745 Mdot
.46521 .73165 Mdot
.32073 .62073 Mdot
.5484 .31939 Mdot
.31365 .58851 Mdot
.59608 .57449 Mdot
.59203 .3213 Mdot
.32544 .39407 Mdot
.42153 .57151 Mdot
.777 .58834 Mdot
.35481 .60475 Mdot
.46129 .37996 Mdot
.66339 .55191 Mdot
.65687 .38912 Mdot
.59208 .60705 Mdot
.65951 .58314 Mdot
.29683 .39226 Mdot
.59151 .33601 Mdot
.29837 .38503 Mdot
.55664 .51243 Mdot
.63965 .30111 Mdot
.3108 .41079 Mdot
.51632 .35657 Mdot
.49021 .71695 Mdot
.54388 .7232 Mdot
.64177 .57296 Mdot
.3156 .38573 Mdot
.64882 .52749 Mdot
.60556 .3636 Mdot
.50483 .57107 Mdot
.54268 .47609 Mdot
.33521 .38332 Mdot
.55004 .25833 Mdot
.48579 .52697 Mdot
.70505 .58924 Mdot
.30775 .39376 Mdot
.82495 .474 Mdot
.45234 .39544 Mdot
.45826 .70275 Mdot
.45743 .73593 Mdot
.44965 .69487 Mdot
.61584 .54764 Mdot
.63457 .42858 Mdot
.45122 .68358 Mdot
.31523 .37336 Mdot
.44488 .6987 Mdot
.54422 .80213 Mdot
.4489 .32753 Mdot
.48429 .72376 Mdot
.6436 .56877 Mdot
.57403 .49476 Mdot
.40911 .58508 Mdot
.32581 .57569 Mdot
.50174 .20404 Mdot
.76636 .63799 Mdot
.62118 .55107 Mdot
.63623 .41418 Mdot
.54114 .33968 Mdot
.47282 .62372 Mdot
.54831 .473 Mdot
.42679 .47646 Mdot
.59579 .34927 Mdot
.47167 .48923 Mdot
.56845 .30956 Mdot
.55703 .52368 Mdot
.64453 .55168 Mdot
.57023 .30088 Mdot
.37935 .30185 Mdot
.82329 .41285 Mdot
.4594 .32054 Mdot
.5891 .31306 Mdot
.31016 .39394 Mdot
.2915 .41056 Mdot
.29804 .39146 Mdot
.31871 .63434 Mdot
.57856 .36892 Mdot
.63605 .53231 Mdot
.34377 .59454 Mdot
.65533 .5714 Mdot
.34288 .40857 Mdot
.51586 .50386 Mdot
.56014 .35955 Mdot
.6315 .57275 Mdot
.74775 .54353 Mdot
.30751 .61688 Mdot
.46363 .70553 Mdot
.33319 .27091 Mdot
.29348 .65279 Mdot
.31737 .43391 Mdot
.56083 .38385 Mdot
.37277 .60952 Mdot
.27944 .6779 Mdot
.67355 .55346 Mdot
.66826 .54385 Mdot
.39979 .60361 Mdot
.76188 .55458 Mdot
.59743 .55216 Mdot
.34738 .59994 Mdot
.33151 .581 Mdot
.64988 .53 Mdot
.5935 .36758 Mdot
.46127 .67522 Mdot
.49441 .69432 Mdot
.56278 .51703 Mdot
.48476 .47933 Mdot
.53625 .66282 Mdot
.59202 .52274 Mdot
.68969 .55104 Mdot
.34586 .57596 Mdot
.46403 .38844 Mdot
.50192 .46557 Mdot
.45984 .68318 Mdot
.65338 .5518 Mdot
.79247 .36569 Mdot
.57768 .36612 Mdot
.29035 .61995 Mdot
.33816 .42799 Mdot
.48854 .73228 Mdot
.29216 .63926 Mdot
.64995 .53013 Mdot
.59417 .52484 Mdot
.32652 .38501 Mdot
.53645 .35448 Mdot
.4688 .72166 Mdot
.34288 .59284 Mdot
.47228 .68535 Mdot
.56597 .33168 Mdot
.59172 .35634 Mdot
.57037 .52679 Mdot
.61318 .61642 Mdot
.35125 .6226 Mdot
.66512 .52482 Mdot
.34267 .60746 Mdot
.19425 .53093 Mdot
.329 .43143 Mdot
.56967 .55132 Mdot
.56202 .39345 Mdot
.34195 .40802 Mdot
.61273 .55545 Mdot
.39931 .60394 Mdot
.58799 .54519 Mdot
.36151 .62035 Mdot
.70402 .72922 Mdot
.45532 .69128 Mdot
.62098 .47032 Mdot
.6988 .63237 Mdot
.58749 .52065 Mdot
.33262 .57841 Mdot
.66269 .44186 Mdot
.31493 .41432 Mdot
.57576 .32678 Mdot
.28571 .73698 Mdot
.32583 .40574 Mdot
.64913 .56343 Mdot
.47757 .71296 Mdot
.58197 .30923 Mdot
.44241 .40866 Mdot
.47885 .46296 Mdot
.58778 .49021 Mdot
.55761 .56128 Mdot
.59515 .58083 Mdot
.18561 .44245 Mdot
.32608 .62298 Mdot
.59633 .33835 Mdot
.29936 .41873 Mdot
.33367 .41878 Mdot
.31208 .61024 Mdot
.52102 .30851 Mdot
.42191 .30481 Mdot
.4713 .90951 Mdot
.29608 .64356 Mdot
.44623 .69953 Mdot
.50221 .55938 Mdot
.33633 .60166 Mdot
.312 .63262 Mdot
.32874 .57154 Mdot
.45834 .33843 Mdot
.59065 .31456 Mdot
.63722 .55057 Mdot
.60664 .38542 Mdot
.61544 .54594 Mdot
.52571 .74683 Mdot
.34 .41119 Mdot
.57414 .32675 Mdot
.46774 .76499 Mdot
.67665 .50699 Mdot
.61432 .57402 Mdot
.51563 .74836 Mdot
.56566 .48479 Mdot
.63111 .6927 Mdot
.60408 .50651 Mdot
.31626 .61877 Mdot
.62414 .28591 Mdot
.6452 .5024 Mdot
.745 .54385 Mdot
.33829 .3976 Mdot
.43362 .40617 Mdot
.55416 .51909 Mdot
.69635 .55212 Mdot
.5854 .30883 Mdot
.55936 .36866 Mdot
.45232 .68198 Mdot
.35186 .24985 Mdot
.3346 .39559 Mdot
.50243 .25978 Mdot
.66372 .58014 Mdot
.26946 .37753 Mdot
.6884 .74541 Mdot
.61031 .56025 Mdot
.38266 .50804 Mdot
.79775 .42951 Mdot
.59332 .54995 Mdot
.69675 .39304 Mdot
.32136 .40909 Mdot
.5778 .78028 Mdot
.63008 .50839 Mdot
.30409 .59951 Mdot
.57506 .32149 Mdot
.58896 .37844 Mdot
.46981 .7347 Mdot
.67916 .7723 Mdot
.24867 .35264 Mdot
.57063 .32698 Mdot
.61884 .5839 Mdot
.31422 .40172 Mdot
.43963 .41007 Mdot
.60598 .48662 Mdot
.24 .40029 Mdot
.57318 .36363 Mdot
.6646 .51949 Mdot
.47024 .30783 Mdot
.46216 .49461 Mdot
.56816 .19774 Mdot
.30664 .38429 Mdot
.46199 .6818 Mdot
.66525 .61687 Mdot
.19545 .50492 Mdot
.64903 .51501 Mdot
.5247 .75119 Mdot
.53505 .37401 Mdot
.48035 .69031 Mdot
.62611 .57982 Mdot
.60283 .54757 Mdot
.49761 .48852 Mdot
.45967 .73918 Mdot
.60474 .54731 Mdot
.69147 .57925 Mdot
.56351 .32652 Mdot
.46501 .40325 Mdot
.56117 .35874 Mdot
.64077 .58147 Mdot
.70951 .71328 Mdot
.58237 .37283 Mdot
.50446 .21046 Mdot
.51144 .66402 Mdot
.31223 .41667 Mdot
.66253 .51042 Mdot
.64759 .59173 Mdot
.4907 .15925 Mdot
.44431 .41186 Mdot
.22261 .66715 Mdot
.34558 .64256 Mdot
.86173 .4687 Mdot
.29026 .65002 Mdot
.54244 .25104 Mdot
.40141 .55572 Mdot
.67979 .54391 Mdot
.72074 .55737 Mdot
.68738 .39071 Mdot
.27325 .37674 Mdot
.65693 .34143 Mdot
.66562 .5766 Mdot
.65176 .54442 Mdot
.34028 .59708 Mdot
.51502 .31162 Mdot
.5422 .61072 Mdot
.50031 .4668 Mdot
.45583 .71135 Mdot
.57058 .34015 Mdot
.59843 .57399 Mdot
.35266 .29513 Mdot
.3572 .60163 Mdot
.74234 .62261 Mdot
.63401 .57189 Mdot
.53096 .59335 Mdot
.50083 .35242 Mdot
.32155 .39404 Mdot
.36038 .59527 Mdot
.35425 .5859 Mdot
.61916 .54347 Mdot
.31983 .4253 Mdot
.59192 .53423 Mdot
.48854 .53655 Mdot
.59499 .49149 Mdot
.47181 .69079 Mdot
.64254 .58868 Mdot
.71576 .6327 Mdot
.63302 .21912 Mdot
.70409 .54883 Mdot
.59956 .31269 Mdot
.33301 .62308 Mdot
.32029 .60723 Mdot
.56542 .31944 Mdot
.31991 .60672 Mdot
.71213 .36805 Mdot
.64236 .37563 Mdot
.47612 .69225 Mdot
.71538 .44662 Mdot
.45401 .69765 Mdot
.43255 .40458 Mdot
.61781 .55989 Mdot
.26962 .49531 Mdot
.2923 .64139 Mdot
.55672 .80372 Mdot
.33469 .40958 Mdot
.44808 .41173 Mdot
.66059 .54046 Mdot
.46061 .75469 Mdot
.31911 .5962 Mdot
.39462 .46327 Mdot
.63271 .539 Mdot
.61223 .34857 Mdot
.59451 .54761 Mdot
.60827 .60388 Mdot
.455 .41075 Mdot
.58712 .57535 Mdot
.32038 .39156 Mdot
.57069 .36894 Mdot
.52646 .26578 Mdot
.31305 .63672 Mdot
.66405 .56664 Mdot
.61964 .58337 Mdot
.54663 .3551 Mdot
.67419 .56517 Mdot
.30204 .41397 Mdot
.65848 .86024 Mdot
.49001 .71012 Mdot
.46346 .38718 Mdot
.40221 .20844 Mdot
.58771 .56257 Mdot
.58557 .53177 Mdot
.42503 .44911 Mdot
.79458 .37234 Mdot
.30753 .40376 Mdot
.55692 .5483 Mdot
.34546 .58887 Mdot
.46976 .72314 Mdot
.33458 .38019 Mdot
.65242 .52494 Mdot
.64462 .5434 Mdot
.48184 .69451 Mdot
.52268 .74002 Mdot
.50292 .71812 Mdot
.29743 .40647 Mdot
.62989 .40045 Mdot
.38426 .66215 Mdot
.62918 .55866 Mdot
.44279 .37637 Mdot
.59004 .34065 Mdot
.30414 .39748 Mdot
.77358 .35831 Mdot
.5575 .52454 Mdot
.34096 .43265 Mdot
.32803 .39413 Mdot
.6747 .57189 Mdot
.54422 .37895 Mdot
.5933 .38928 Mdot
.59204 .34177 Mdot
.59405 .76183 Mdot
.1863 .60181 Mdot
.3272 .62606 Mdot
.31891 .4039 Mdot
.34318 .64151 Mdot
.48416 .68174 Mdot
.49888 .52476 Mdot
.35299 .58809 Mdot
.61371 .33895 Mdot
.34321 .63862 Mdot
.58954 .53562 Mdot
.34881 .41534 Mdot
.34169 .63508 Mdot
.59858 .51494 Mdot
.69302 .57143 Mdot
.71694 .55197 Mdot
.46271 .67366 Mdot
.47122 .48809 Mdot
.64844 .56979 Mdot
.44529 .38729 Mdot
.62231 .56802 Mdot
.30563 .41817 Mdot
.41674 .58424 Mdot
.62992 .52197 Mdot
.29336 .64244 Mdot
.20708 .62449 Mdot
.31735 .58217 Mdot
.64837 .6053 Mdot
.64315 .57908 Mdot
.62718 .55685 Mdot
.66159 .54539 Mdot
.53785 .28843 Mdot
.35179 .43307 Mdot
.60989 .62404 Mdot
.30264 .64234 Mdot
.57832 .35422 Mdot
.58845 .3733 Mdot
.42252 .46821 Mdot
.43828 .41377 Mdot
.32776 .42624 Mdot
.628 .55529 Mdot
.39474 .46543 Mdot
.47678 .44999 Mdot
.46312 .31289 Mdot
.37333 .62152 Mdot
.35102 .60889 Mdot
.60742 .32165 Mdot
.34253 .62704 Mdot
.65468 .52674 Mdot
.67052 .52709 Mdot
.52721 .26159 Mdot
.36252 .39142 Mdot
.46664 .72139 Mdot
.65325 .57601 Mdot
.54851 .70651 Mdot
.34054 .58882 Mdot
.34815 .5777 Mdot
.59429 .53193 Mdot
.54143 .36045 Mdot
.6562 .20488 Mdot
.33701 .42544 Mdot
.65513 .39459 Mdot
.6013 .27817 Mdot
.55223 .47647 Mdot
.32352 .41631 Mdot
.39338 .51105 Mdot
.31026 .57987 Mdot
.74363 .69529 Mdot
.58416 .35448 Mdot
.46613 .71985 Mdot
.62047 .50401 Mdot
.61351 .33827 Mdot
.32875 .64977 Mdot
.56265 .31349 Mdot
.57118 .50682 Mdot
.29934 .38164 Mdot
.32771 .60349 Mdot
.2851 .42257 Mdot
.56084 .30944 Mdot
.45414 .69547 Mdot
.56474 .78121 Mdot
.6625 .4111 Mdot
.79696 .42847 Mdot
.63252 .52609 Mdot
.31296 .49885 Mdot
.63435 .53317 Mdot
.61622 .35773 Mdot
.64217 .57252 Mdot
.66105 .49442 Mdot
.30172 .58306 Mdot
.62874 .5018 Mdot
.64651 .58769 Mdot
.73967 .53925 Mdot
.60937 .5659 Mdot
.65235 .53572 Mdot
.56288 .53755 Mdot
.53336 .33266 Mdot
.61936 .50104 Mdot
.6121 .34591 Mdot
.47437 .3306 Mdot
.30949 .63244 Mdot
.48485 .6834 Mdot
.49043 .69427 Mdot
.51555 .76187 Mdot
.54793 .71234 Mdot
.51201 .32253 Mdot
.56368 .35385 Mdot
.3431 .39586 Mdot
.59195 .53231 Mdot
.82186 .49578 Mdot
.69119 .71796 Mdot
.29416 .59094 Mdot
.34836 .63035 Mdot
.63849 .50858 Mdot
.21465 .34557 Mdot
.62764 .50271 Mdot
.49163 .43322 Mdot
.61939 .54611 Mdot
.5693 .55582 Mdot
.35702 .58329 Mdot
.54878 .75766 Mdot
.63309 .52561 Mdot
.58359 .30852 Mdot
.46117 .7132 Mdot
.53635 .52039 Mdot
.66954 .73694 Mdot
.72567 .53803 Mdot
.61958 .65148 Mdot
.63413 .51901 Mdot
.33303 .58813 Mdot
.58956 .31216 Mdot
.49666 .44195 Mdot
.30413 .41439 Mdot
.4797 .47245 Mdot
.69256 .44107 Mdot
.26404 .42239 Mdot
.46232 .71786 Mdot
.33556 .56397 Mdot
.59461 .57378 Mdot
.32159 .63264 Mdot
.55687 .53847 Mdot
.46594 .44936 Mdot
.47212 .68885 Mdot
.59491 .30324 Mdot
.31063 .394 Mdot
.61276 .35694 Mdot
.80767 .49812 Mdot
.69746 .71563 Mdot
.86299 .47163 Mdot
.29646 .59936 Mdot
.7073 .2915 Mdot
.5911 .3271 Mdot
.63065 .53767 Mdot
.46689 .90781 Mdot
.58504 .33748 Mdot
.6132 .34431 Mdot
.43068 .48405 Mdot
.56528 .76471 Mdot
.6519 .50975 Mdot
.5595 .31986 Mdot
.35049 .56896 Mdot
.47502 .70234 Mdot
.6017 .51491 Mdot
.5612 .51265 Mdot
.56123 .36942 Mdot
.31465 .59946 Mdot
.53521 .73816 Mdot
.32005 .61465 Mdot
.59115 .31615 Mdot
.3024 .61787 Mdot
.50199 .21909 Mdot
.35511 .59461 Mdot
.64268 .59042 Mdot
.62876 .55582 Mdot
.2658 .45711 Mdot
.59168 .35637 Mdot
.58502 .53179 Mdot
.64961 .54762 Mdot
.59558 .327 Mdot
.28055 .64637 Mdot
.75396 .33412 Mdot
.58199 .53664 Mdot
.63252 .55211 Mdot
.48979 .70178 Mdot
.485 .50739 Mdot
.48367 .4308 Mdot
.59373 .51861 Mdot
.44815 .69945 Mdot
.60535 .31557 Mdot
.62033 .56813 Mdot
.54773 .75921 Mdot
.29787 .65105 Mdot
.62731 .51374 Mdot
.43745 .40621 Mdot
.60056 .55244 Mdot
.64685 .20579 Mdot
.66428 .55521 Mdot
.60013 .33652 Mdot
.58212 .32182 Mdot
.36941 .56812 Mdot
.57793 .34918 Mdot
.46188 .40123 Mdot
.33955 .40322 Mdot
.60817 .23223 Mdot
.45932 .40422 Mdot
.58912 .58095 Mdot
.71849 .74246 Mdot
.56479 .50969 Mdot
.59613 .49375 Mdot
.54151 .8137 Mdot
.46293 .39151 Mdot
.58923 .3325 Mdot
.37982 .2972 Mdot
.66373 .52551 Mdot
.33126 .42671 Mdot
.61734 .49183 Mdot
.62811 .51396 Mdot
.68755 .51247 Mdot
.63586 .38389 Mdot
.35642 .41048 Mdot
.70096 .60126 Mdot
.60161 .51516 Mdot
.7949 .37433 Mdot
.60678 .58179 Mdot
.48053 .72948 Mdot
.55873 .34539 Mdot
.33572 .63269 Mdot
.47359 .69481 Mdot
.59091 .56875 Mdot
.47118 .71778 Mdot
.32219 .63031 Mdot
.31591 .38294 Mdot
.63615 .5908 Mdot
.43994 .70036 Mdot
.4628 .72065 Mdot
.60977 .53126 Mdot
.5731 .32482 Mdot
.58453 .60117 Mdot
.61742 .56697 Mdot
.65632 .53424 Mdot
.56365 .32222 Mdot
.48225 .85824 Mdot
.65008 .53931 Mdot
.39018 .51046 Mdot
.61048 .30635 Mdot
.46322 .40391 Mdot
.34776 .61036 Mdot
.68453 .5851 Mdot
.3345 .42 Mdot
.33798 .40511 Mdot
.2846 .62523 Mdot
.55404 .36136 Mdot
.3242 .60288 Mdot
.70128 .53447 Mdot
.66826 .52463 Mdot
.62176 .50429 Mdot
.28396 .73609 Mdot
.46484 .2151 Mdot
.60118 .35106 Mdot
.31805 .57913 Mdot
.48742 .47235 Mdot
.34432 .42056 Mdot
.34809 .57418 Mdot
.61937 .36474 Mdot
.55 .34598 Mdot
.5662 .31712 Mdot
.45166 .71206 Mdot
.3302 .608 Mdot
.6241 .36041 Mdot
.58736 .3897 Mdot
.60165 .52932 Mdot
.60558 .51477 Mdot
.55417 .30703 Mdot
.27466 .58858 Mdot
.46047 .6918 Mdot
.32784 .58564 Mdot
.60176 .15815 Mdot
.3363 .42593 Mdot
.74095 .54154 Mdot
.59475 .51661 Mdot
.25584 .78793 Mdot
.62053 .5021 Mdot
.61556 .58383 Mdot
.56941 .3045 Mdot
.47338 .74423 Mdot
.47345 .70515 Mdot
.59018 .32605 Mdot
.56314 .38145 Mdot
.46496 .72789 Mdot
.42061 .49176 Mdot
.68513 .23776 Mdot
.49254 .45101 Mdot
.60392 .33985 Mdot
.6664 .40907 Mdot
.33105 .38037 Mdot
.61129 .31227 Mdot
.31735 .44101 Mdot
.30813 .63324 Mdot
.3554 .61042 Mdot
.33018 .38494 Mdot
.65052 .53696 Mdot
.29706 .60253 Mdot
.70658 .5455 Mdot
.52811 .24494 Mdot
.24572 .39673 Mdot
.8377 .5115 Mdot
.65708 .58849 Mdot
.54699 .62371 Mdot
.41261 .35611 Mdot
.58346 .5705 Mdot
.6921 .62454 Mdot
.46915 .7207 Mdot
.60788 .30585 Mdot
.34931 .38782 Mdot
.52065 .18729 Mdot
.62858 .55772 Mdot
.60253 .32757 Mdot
.34795 .42017 Mdot
.49515 .22879 Mdot
.40568 .52857 Mdot
.59903 .54013 Mdot
.51445 .91267 Mdot
.55671 .31537 Mdot
.33587 .63232 Mdot
.74162 .50557 Mdot
.61777 .33854 Mdot
.35031 .66888 Mdot
.36501 .61702 Mdot
.51897 .45324 Mdot
.55355 .32598 Mdot
.50371 .70935 Mdot
.5662 .33867 Mdot
.45387 .7264 Mdot
.55845 .38227 Mdot
.30742 .60907 Mdot
.62204 .57568 Mdot
.30851 .61256 Mdot
.48614 .72815 Mdot
.28951 .60858 Mdot
.34945 .38805 Mdot
.4589 .38682 Mdot
.3447 .40578 Mdot
.50075 .53684 Mdot
.75462 .36076 Mdot
.30037 .39426 Mdot
.38221 .48403 Mdot
.5975 .55753 Mdot
.53504 .34614 Mdot
.32929 .63577 Mdot
.27875 .61845 Mdot
.47671 .48501 Mdot
.57909 .31472 Mdot
.30642 .60426 Mdot
.66441 .41744 Mdot
.29315 .77965 Mdot
.67566 .51499 Mdot
.17802 .57781 Mdot
.59831 .32981 Mdot
.31353 .57706 Mdot
.49544 .43069 Mdot
.5794 .37714 Mdot
.34729 .62869 Mdot
.31052 .39117 Mdot
.32914 .42025 Mdot
.67361 .56766 Mdot
.29297 .38077 Mdot
.33781 .57838 Mdot
.79462 .36877 Mdot
.55891 .33612 Mdot
.4479 .20818 Mdot
.48256 .72368 Mdot
.31447 .63301 Mdot
.64093 .50478 Mdot
.56955 .39795 Mdot
.33047 .64475 Mdot
.22855 .35588 Mdot
.54557 .15163 Mdot
.30622 .60374 Mdot
.55873 .34663 Mdot
.57463 .3568 Mdot
.70088 .54111 Mdot
.49254 .47387 Mdot
.31417 .59757 Mdot
.26783 .49447 Mdot
.55038 .68687 Mdot
.45328 .40459 Mdot
.77155 .63435 Mdot
.6346 .52559 Mdot
.63329 .51824 Mdot
.29854 .40994 Mdot
.6106 .57262 Mdot
.57554 .38664 Mdot
.61547 .50284 Mdot
.28844 .40131 Mdot
.28561 .61268 Mdot
.62191 .55986 Mdot
.47338 .72444 Mdot
.29924 .38657 Mdot
.29657 .42016 Mdot
.30258 .62549 Mdot
.55766 .33159 Mdot
.36288 .31166 Mdot
.32162 .61301 Mdot
.64866 .52419 Mdot
.45338 .38996 Mdot
.59492 .51001 Mdot
.27649 .46438 Mdot
.60583 .36942 Mdot
.34209 .62714 Mdot
.56633 .30011 Mdot
.32161 .40032 Mdot
.28698 .59544 Mdot
.59496 .57713 Mdot
.35288 .61055 Mdot
.3759 .51888 Mdot
.34147 .71064 Mdot
.57686 .389 Mdot
.40385 .58983 Mdot
.55438 .36485 Mdot
.45194 .4057 Mdot
.60275 .72654 Mdot
.45863 .69881 Mdot
.33189 .58242 Mdot
.50094 .20981 Mdot
.32236 .6393 Mdot
.60763 .56296 Mdot
.64241 .54096 Mdot
.34156 .59855 Mdot
.45132 .69943 Mdot
.50739 .78375 Mdot
.46037 .66034 Mdot
.57567 .36749 Mdot
.42348 .55698 Mdot
.63184 .17676 Mdot
.35477 .64582 Mdot
.33992 .39274 Mdot
.63785 .64484 Mdot
.5906 .55371 Mdot
.35325 .41588 Mdot
.31915 .42867 Mdot
.47836 .73731 Mdot
.31433 .63544 Mdot
.62295 .328 Mdot
.34319 .3865 Mdot
.58783 .40254 Mdot
.53856 .75035 Mdot
.55461 .54329 Mdot
.58577 .4503 Mdot
.62586 .59612 Mdot
.46214 .49411 Mdot
.28926 .3954 Mdot
.64591 .56228 Mdot
.68401 .60847 Mdot
.30341 .40335 Mdot
.47246 .73908 Mdot
.59712 .4148 Mdot
.30107 .60827 Mdot
.2724 .78172 Mdot
.63812 .59029 Mdot
.62001 .57227 Mdot
.30818 .41641 Mdot
.76616 .55024 Mdot
.60407 .35061 Mdot
.5566 .33562 Mdot
.32691 .62272 Mdot
.44975 .45263 Mdot
.67462 .56355 Mdot
.61408 .58828 Mdot
.2994 .60265 Mdot
.44541 .38791 Mdot
.81835 .58751 Mdot
.63792 .55385 Mdot
.3213 .41198 Mdot
.35649 .50734 Mdot
.29213 .38963 Mdot
.59362 .59114 Mdot
.60698 .55897 Mdot
.60953 .58987 Mdot
.66223 .58913 Mdot
.34128 .38858 Mdot
.59323 .57854 Mdot
.55594 .56074 Mdot
.59035 .33624 Mdot
.63575 .52164 Mdot
.55213 .68598 Mdot
.63524 .55737 Mdot
.47482 .72341 Mdot
.47233 .43459 Mdot
.66358 .56251 Mdot
.63699 .52137 Mdot
.54759 .6859 Mdot
.62762 .58173 Mdot
.35043 .41834 Mdot
.58115 .35716 Mdot
.31971 .39999 Mdot
.33636 .39335 Mdot
.33753 .64189 Mdot
.45208 .72678 Mdot
.68943 .57293 Mdot
.46015 .72571 Mdot
.68932 .5211 Mdot
.56037 .50933 Mdot
.49338 .51972 Mdot
.49071 .43483 Mdot
.48083 .67807 Mdot
.60404 .58328 Mdot
.32128 .6262 Mdot
.34535 .62418 Mdot
.41001 .58109 Mdot
.61955 .48919 Mdot
.34052 .38216 Mdot
.31492 .38607 Mdot
.45039 .65838 Mdot
.43141 .64794 Mdot
.46424 .72328 Mdot
.50387 .59856 Mdot
.56773 .56259 Mdot
.65754 .55003 Mdot
.57651 .49736 Mdot
.35137 .63553 Mdot
.45967 .38612 Mdot
.28791 .62522 Mdot
.4848 .40296 Mdot
.32572 .37751 Mdot
.65702 .58826 Mdot
.24767 .31496 Mdot
.58183 .37078 Mdot
.58172 .35771 Mdot
.28796 .40263 Mdot
.32003 .58117 Mdot
.59918 .49064 Mdot
.20143 .66983 Mdot
.58153 .38175 Mdot
.47958 .682 Mdot
.64221 .58339 Mdot
.30674 .62917 Mdot
.56473 .36689 Mdot
.44294 .6895 Mdot
.64947 .59259 Mdot
.36689 .59578 Mdot
.63994 .5656 Mdot
.71376 .41607 Mdot
.58274 .3296 Mdot
.51457 .49063 Mdot
.54148 .32055 Mdot
.34662 .39707 Mdot
.31026 .40014 Mdot
.61154 .55601 Mdot
.23144 .72312 Mdot
.63075 .36365 Mdot
.34841 .42918 Mdot
.44451 .68941 Mdot
.45309 .38371 Mdot
.44301 .69532 Mdot
.34225 .60598 Mdot
.46028 .71362 Mdot
.32907 .64449 Mdot
.26681 .59961 Mdot
.62371 .31457 Mdot
.48266 .69758 Mdot
.77187 .5614 Mdot
.67161 .52815 Mdot
.48392 .73328 Mdot
.62974 .50622 Mdot
.6867 .51432 Mdot
.29467 .61151 Mdot
.45447 .71586 Mdot
.61102 .53844 Mdot
.40406 .20386 Mdot
.31973 .39259 Mdot
.3465 .38647 Mdot
.67004 .52754 Mdot
.32486 .57299 Mdot
.56576 .38528 Mdot
.46439 .51758 Mdot
.46729 .39557 Mdot
.61622 .58868 Mdot
.62269 .59791 Mdot
.55504 .3143 Mdot
.60817 .32752 Mdot
.60975 .55527 Mdot
.64974 .40292 Mdot
.59214 .57211 Mdot
.32539 .42016 Mdot
.57777 .36858 Mdot
.57751 .35867 Mdot
.34534 .58242 Mdot
.55635 .36371 Mdot
.59134 .61265 Mdot
.30148 .3664 Mdot
.58458 .50716 Mdot
.32351 .4025 Mdot
.32061 .5549 Mdot
.30091 .63593 Mdot
.49806 .2073 Mdot
.55544 .36127 Mdot
.58084 .53313 Mdot
.58963 .37244 Mdot
.48722 .71344 Mdot
.58937 .35872 Mdot
.54276 .32684 Mdot
.66911 .56983 Mdot
.60856 .54514 Mdot
.44645 .38975 Mdot
.48702 .47995 Mdot
.57664 .33074 Mdot
.58271 .55873 Mdot
.58167 .52272 Mdot
.63882 .53895 Mdot
.48392 .52203 Mdot
.57951 .30083 Mdot
.72421 .52504 Mdot
.28503 .45575 Mdot
.57209 .32877 Mdot
.58139 .17896 Mdot
.43516 .39397 Mdot
.43669 .41321 Mdot
.30688 .43265 Mdot
.63604 .55093 Mdot
.31878 .60498 Mdot
.63337 .51704 Mdot
.63704 .49123 Mdot
.66264 .56842 Mdot
.48263 .69409 Mdot
.67295 .55076 Mdot
.443 .40298 Mdot
.31593 .61572 Mdot
.58422 .55749 Mdot
.6235 .55506 Mdot
.43373 .40938 Mdot
.54885 .31016 Mdot
.55053 .34867 Mdot
.43855 .37266 Mdot
.47716 .73569 Mdot
.29381 .39685 Mdot
.64491 .52095 Mdot
.32415 .62403 Mdot
.31302 .61067 Mdot
.61324 .35208 Mdot
.30822 .5958 Mdot
.29182 .39713 Mdot
.60753 .58044 Mdot
.34608 .39599 Mdot
.48287 .69448 Mdot
.55875 .3446 Mdot
.65375 .52466 Mdot
.6028 .53136 Mdot
.58221 .32199 Mdot
.59719 .55367 Mdot
.48445 .69345 Mdot
.35953 .61879 Mdot
.59434 .35934 Mdot
.3384 .403 Mdot
.35027 .58535 Mdot
.59073 .53038 Mdot
.44775 .14214 Mdot
.6094 .57229 Mdot
.62031 .59103 Mdot
.56622 .24665 Mdot
.57137 .53614 Mdot
.31611 .63818 Mdot
.58152 .37452 Mdot
.61592 .60015 Mdot
.54842 .69072 Mdot
.50356 .73879 Mdot
.36083 .63517 Mdot
.63975 .58563 Mdot
.55733 .1902 Mdot
.58479 .52371 Mdot
.51807 .21362 Mdot
.49367 .51865 Mdot
.19745 .4423 Mdot
.58661 .45023 Mdot
.3465 .43046 Mdot
.44876 .3873 Mdot
.30953 .64013 Mdot
.7743 .50151 Mdot
.60197 .56417 Mdot
.79911 .41948 Mdot
.65047 .52146 Mdot
.32519 .41727 Mdot
.68391 .62516 Mdot
.32358 .58678 Mdot
.76737 .63394 Mdot
.6431 .5316 Mdot
.56123 .31251 Mdot
.29299 .5856 Mdot
.44217 .3862 Mdot
.61537 .54045 Mdot
.4727 .73046 Mdot
.50513 .68878 Mdot
.59659 .61468 Mdot
.32535 .40086 Mdot
.65356 .54978 Mdot
.69843 .57321 Mdot
.30261 .77632 Mdot
.59423 .34053 Mdot
.32485 .38873 Mdot
.49151 .6382 Mdot
.6385 .54064 Mdot
.55045 .34439 Mdot
.5822 .35436 Mdot
.46241 .73178 Mdot
.35212 .35982 Mdot
.45818 .7758 Mdot
.28762 .25525 Mdot
.81475 .45956 Mdot
.3558 .63031 Mdot
.53379 .39132 Mdot
.62106 .52077 Mdot
.70007 .71522 Mdot
.33986 .39637 Mdot
.62292 .57465 Mdot
.79459 .44903 Mdot
.59422 .34674 Mdot
.64143 .56039 Mdot
.4618 .69215 Mdot
.38129 .33597 Mdot
.67789 .44135 Mdot
.4687 .15708 Mdot
.35339 .57026 Mdot
.62997 .4968 Mdot
.56498 .5879 Mdot
.46412 .40204 Mdot
.60047 .59446 Mdot
.3262 .63574 Mdot
.32395 .49855 Mdot
.45819 .686 Mdot
.57901 .37105 Mdot
.43641 .39086 Mdot
.64898 .51977 Mdot
.56315 .52403 Mdot
.47343 .68016 Mdot
.62569 .53659 Mdot
.7339 .50026 Mdot
.42542 .40465 Mdot
.35605 .59619 Mdot
.56475 .31169 Mdot
.62001 .5958 Mdot
.45178 .38485 Mdot
.66907 .5623 Mdot
.69851 .64088 Mdot
.6491 .57805 Mdot
.59362 .24319 Mdot
.57395 .32164 Mdot
.33039 .39806 Mdot
.67446 .55138 Mdot
.63255 .5648 Mdot
.38729 .66562 Mdot
.60854 .48927 Mdot
.66144 .55019 Mdot
.61623 .34961 Mdot
.58504 .3711 Mdot
.60409 .32711 Mdot
.3486 .58649 Mdot
.49637 .45388 Mdot
.33246 .41308 Mdot
.58152 .49522 Mdot
.33796 .3821 Mdot
.59626 .44845 Mdot
.45762 .68092 Mdot
.48197 .19997 Mdot
.5998 .57179 Mdot
.57344 .31403 Mdot
.71426 .27373 Mdot
.6076 .31864 Mdot
.30783 .44935 Mdot
.33667 .39644 Mdot
.58172 .33611 Mdot
.62903 .58369 Mdot
.50065 .47041 Mdot
.42948 .15835 Mdot
.34588 .4189 Mdot
.59665 .49522 Mdot
.35856 .57085 Mdot
.28402 .6325 Mdot
.61053 .19906 Mdot
.35025 .40904 Mdot
.40771 .35657 Mdot
.58095 .53832 Mdot
.57219 .37225 Mdot
.30125 .38932 Mdot
.34526 .42677 Mdot
.30443 .59749 Mdot
.59734 .53681 Mdot
.63482 .56416 Mdot
.4355 .4043 Mdot
.3275 .38166 Mdot
.60383 .46329 Mdot
.59804 .54313 Mdot
.53676 .25542 Mdot
.62125 .35843 Mdot
.49201 .85841 Mdot
.7131 .58321 Mdot
.79485 .44171 Mdot
.35066 .54197 Mdot
.59735 .35912 Mdot
.64928 .53429 Mdot
.58654 .49436 Mdot
.36242 .61413 Mdot
.60965 .57893 Mdot
.30447 .58524 Mdot
.34873 .40205 Mdot
.48912 .19385 Mdot
.39757 .47358 Mdot
.3191 .3617 Mdot
.61034 .56974 Mdot
.67009 .43764 Mdot
.48161 .69933 Mdot
.36529 .39758 Mdot
.60856 .34205 Mdot
.58202 .57839 Mdot
.34901 .64049 Mdot
.34685 .58672 Mdot
.58699 .3492 Mdot
.4774 .35253 Mdot
.50599 .20893 Mdot
.65699 .59269 Mdot
.34595 .6087 Mdot
.39812 .4319 Mdot
.65488 .32531 Mdot
.30481 .42923 Mdot
.46078 .6846 Mdot
.31019 .63849 Mdot
.31322 .37177 Mdot
.6796 .5077 Mdot
.57943 .34289 Mdot
.55192 .32084 Mdot
.38372 .64088 Mdot
.31045 .60262 Mdot
.46699 .70012 Mdot
.41185 .57115 Mdot
.41802 .57153 Mdot
.46969 .68884 Mdot
.29486 .59 Mdot
.59397 .36523 Mdot
.59799 .32294 Mdot
.57995 .35649 Mdot
.74519 .54399 Mdot
.59655 .37508 Mdot
.59993 .7985 Mdot
.58901 .5857 Mdot
.65781 .38443 Mdot
.57744 .5594 Mdot
.35514 .39721 Mdot
.5817 .32834 Mdot
.49711 .51195 Mdot
.56577 .55327 Mdot
.44964 .15978 Mdot
.64878 .5717 Mdot
.37191 .50855 Mdot
.63451 .55087 Mdot
.72475 .46653 Mdot
.61065 .30775 Mdot
.59719 .57973 Mdot
.28315 .37129 Mdot
.47405 .71998 Mdot
.62354 .30799 Mdot
.66032 .55009 Mdot
.47599 .30701 Mdot
.62852 .50621 Mdot
.54138 .21169 Mdot
.3032 .68131 Mdot
.49731 .70436 Mdot
.58003 .51953 Mdot
.31637 .64907 Mdot
.59353 .64949 Mdot
.66496 .39682 Mdot
.34627 .41808 Mdot
.66553 .43012 Mdot
.31206 .59005 Mdot
.69465 .62126 Mdot
.57645 .58412 Mdot
.45332 .69076 Mdot
.60223 .41428 Mdot
.3214 .41993 Mdot
.59996 .56321 Mdot
.6461 .5349 Mdot
.23484 .41662 Mdot
.67412 .40747 Mdot
.55541 .49694 Mdot
.4664 .67536 Mdot
.68203 .43838 Mdot
.66157 .56265 Mdot
.36224 .63258 Mdot
.57434 .37585 Mdot
.6362 .63549 Mdot
.75062 .57637 Mdot
.58474 .56312 Mdot
.58472 .33956 Mdot
.553 .3591 Mdot
.7457 .29248 Mdot
.45282 .68589 Mdot
.64981 .57676 Mdot
.37175 .65347 Mdot
.65014 .52434 Mdot
.33087 .41667 Mdot
.56936 .5702 Mdot
.29744 .6294 Mdot
.49996 .42227 Mdot
.3464 .58513 Mdot
.62452 .54204 Mdot
.56364 .34097 Mdot
.31134 .41679 Mdot
.18922 .49622 Mdot
.39331 .39741 Mdot
.59682 .79864 Mdot
.50556 .68574 Mdot
.46904 .72716 Mdot
.44346 .70689 Mdot
.3762 .41681 Mdot
.63388 .58591 Mdot
.45651 .49647 Mdot
.66894 .50673 Mdot
.63757 .54676 Mdot
.65355 .57782 Mdot
.39425 .40247 Mdot
.33551 .39668 Mdot
.30402 .61488 Mdot
.60846 .55559 Mdot
.58243 .5592 Mdot
.57064 .33474 Mdot
.46218 .72049 Mdot
.35933 .61201 Mdot
.4833 .72883 Mdot
.31727 .61985 Mdot
.64342 .20245 Mdot
.55525 .52441 Mdot
.47557 .7185 Mdot
.29643 .3859 Mdot
.59252 .31453 Mdot
.43811 .41128 Mdot
.34083 .605 Mdot
.32237 .58797 Mdot
.59002 .57641 Mdot
.55599 .3487 Mdot
.55254 .34637 Mdot
.46511 .72755 Mdot
.31016 .38744 Mdot
.66394 .59431 Mdot
.60427 .54476 Mdot
.18603 .52709 Mdot
.36257 .60761 Mdot
.67259 .42735 Mdot
.58996 .24953 Mdot
.6296 .58724 Mdot
.55189 .33943 Mdot
.62275 .56385 Mdot
.37528 .45121 Mdot
.60404 .32425 Mdot
.56985 .54411 Mdot
.64375 .48152 Mdot
.35184 .63439 Mdot
.81668 .37683 Mdot
.68739 .569 Mdot
.26684 .39117 Mdot
.61625 .52682 Mdot
.86393 .43739 Mdot
.72809 .287 Mdot
.65507 .52294 Mdot
.66473 .5861 Mdot
.30315 .23439 Mdot
.59421 .51541 Mdot
.43833 .40312 Mdot
.6336 .49004 Mdot
.5503 .34142 Mdot
.39512 .52637 Mdot
.46854 .4897 Mdot
.44625 .69544 Mdot
.3268 .62359 Mdot
.55724 .76124 Mdot
.46316 .73589 Mdot
.59978 .33438 Mdot
.56147 .52245 Mdot
.59805 .25553 Mdot
.28032 .63699 Mdot
.61675 .60527 Mdot
.32895 .41722 Mdot
.46787 .48866 Mdot
.29106 .63004 Mdot
.33957 .40244 Mdot
.58248 .52495 Mdot
.26057 .69675 Mdot
.25899 .39104 Mdot
.75535 .29422 Mdot
.29881 .40854 Mdot
.3216 .39454 Mdot
.50436 .46082 Mdot
.44609 .69646 Mdot
.24674 .45718 Mdot
.56824 .60227 Mdot
.33964 .42408 Mdot
.65225 .69055 Mdot
.36272 .59333 Mdot
.46235 .45268 Mdot
.61274 .31255 Mdot
.55549 .51767 Mdot
.63483 .57997 Mdot
.30361 .39577 Mdot
.52365 .36575 Mdot
.4505 .63527 Mdot
.34667 .41134 Mdot
.57196 .59418 Mdot
.46173 .44494 Mdot
.45663 .3886 Mdot
.43294 .39695 Mdot
.44694 .68445 Mdot
.36764 .75188 Mdot
.57024 .32067 Mdot
.48315 .68559 Mdot
.52605 .48892 Mdot
.65269 .56544 Mdot
.33194 .38175 Mdot
.42948 .40011 Mdot
.33621 .40543 Mdot
.47723 .70775 Mdot
.46432 .67889 Mdot
.5912 .33702 Mdot
.60426 .3529 Mdot
.63353 .28859 Mdot
.5789 .66815 Mdot
.62212 .51492 Mdot
.76598 .35414 Mdot
.6084 .33012 Mdot
.77139 .52501 Mdot
.45106 .71529 Mdot
.45447 .70794 Mdot
.68958 .36064 Mdot
.59624 .52776 Mdot
.36 .5082 Mdot
.6634 .55981 Mdot
.63885 .71217 Mdot
.64731 .51753 Mdot
.30364 .59919 Mdot
.63786 .52844 Mdot
.35905 .29931 Mdot
.58486 .55232 Mdot
.65664 .57724 Mdot
.33472 .6057 Mdot
.67536 .58847 Mdot
.2932 .62281 Mdot
.65283 .54002 Mdot
.46342 .74607 Mdot
.32444 .62357 Mdot
.44378 .72985 Mdot
.40377 .50826 Mdot
.44211 .3943 Mdot
.44414 .70361 Mdot
.47504 .72879 Mdot
.53361 .73543 Mdot
.60744 .35515 Mdot
.72076 .60074 Mdot
.63888 .58325 Mdot
.34646 .57618 Mdot
.30575 .38169 Mdot
.58483 .56468 Mdot
.61484 .50206 Mdot
.68836 .57812 Mdot
.58804 .33733 Mdot
.30479 .58169 Mdot
.47346 .7137 Mdot
.34794 .62148 Mdot
.45154 .73724 Mdot
.30963 .64463 Mdot
.69035 .55092 Mdot
.68486 .51531 Mdot
.55884 .56863 Mdot
.78417 .41118 Mdot
.72405 .72919 Mdot
.58239 .34664 Mdot
.45419 .39406 Mdot
.45706 .68078 Mdot
.42519 .56046 Mdot
.5671 .31933 Mdot
.32211 .58928 Mdot
.63999 .56586 Mdot
.55851 .57788 Mdot
.54086 .53826 Mdot
.60249 .39388 Mdot
.43109 .69154 Mdot
.33699 .61565 Mdot
.45972 .40042 Mdot
.48886 .4512 Mdot
.56309 .2836 Mdot
.50032 .52871 Mdot
.62777 .56412 Mdot
.46729 .72966 Mdot
.56495 .36702 Mdot
.26944 .47139 Mdot
.30726 .39362 Mdot
.48995 .47666 Mdot
.61157 .57171 Mdot
.46177 .36176 Mdot
.56393 .34191 Mdot
.45517 .69454 Mdot
.30309 .39701 Mdot
.44823 .69462 Mdot
.44193 .38353 Mdot
.45109 .37223 Mdot
.61788 .53801 Mdot
.66389 .55381 Mdot
.32331 .37786 Mdot
.56818 .32264 Mdot
.48334 .75151 Mdot
.23589 .40766 Mdot
.34267 .60309 Mdot
.4371 .46302 Mdot
.57307 .36942 Mdot
.41275 .37018 Mdot
.35115 .6058 Mdot
.31414 .37298 Mdot
.46114 .49763 Mdot
.29002 .40787 Mdot
.65952 .5694 Mdot
.56614 .35751 Mdot
.35101 .41191 Mdot
.19438 .52844 Mdot
.58156 .21555 Mdot
.6153 .39325 Mdot
.60482 .55169 Mdot
.48225 .19741 Mdot
.44544 .32186 Mdot
.56495 .41615 Mdot
.34512 .38897 Mdot
.61259 .56078 Mdot
.65445 .59362 Mdot
.6421 .53104 Mdot
.31574 .39228 Mdot
.28305 .35431 Mdot
.33665 .58616 Mdot
.64683 .55957 Mdot
.4836 .72205 Mdot
.29754 .62597 Mdot
.29326 .64396 Mdot
.313 .64008 Mdot
.60919 .33024 Mdot
.55804 .52833 Mdot
.52865 .54817 Mdot
.80027 .34131 Mdot
.32599 .39564 Mdot
.44213 .39464 Mdot
.62591 .59271 Mdot
.57136 .79263 Mdot
.59707 .31983 Mdot
.33742 .59946 Mdot
.62212 .57327 Mdot
.33481 .67646 Mdot
.42267 .39868 Mdot
.32787 .61034 Mdot
.60767 .33946 Mdot
.56574 .41753 Mdot
.60789 .57865 Mdot
.61438 .5252 Mdot
.58967 .31971 Mdot
.41829 .3394 Mdot
.48579 .44829 Mdot
.62311 .56156 Mdot
.33451 .39878 Mdot
.26647 .76321 Mdot
.5748 .53711 Mdot
.54466 .38455 Mdot
.46112 .38571 Mdot
.54257 .27574 Mdot
.65492 .41607 Mdot
.66529 .51111 Mdot
.43285 .18398 Mdot
.54582 .79856 Mdot
.50679 .18509 Mdot
.6381 .72363 Mdot
.24605 .38687 Mdot
.68954 .22701 Mdot
.28015 .37479 Mdot
.71816 .45061 Mdot
.21781 .35603 Mdot
.42685 .3515 Mdot
.30734 .69682 Mdot
.21158 .49117 Mdot
.25066 .66324 Mdot
.79123 .61796 Mdot
.30405 .64511 Mdot
.67303 .71163 Mdot
.66303 .5434 Mdot
.4221 .32833 Mdot
.71115 .46236 Mdot
.67441 .77725 Mdot
.48231 .20497 Mdot
.36433 .66109 Mdot
.41589 .1513 Mdot
.48923 .21922 Mdot
.64648 .26778 Mdot
.74388 .60385 Mdot
.40414 .77553 Mdot
.41938 .57401 Mdot
.55867 .77083 Mdot
.66339 .44084 Mdot
.36192 .28394 Mdot
.27841 .37206 Mdot
.71962 .31901 Mdot
.33421 .7988 Mdot
.33535 .62857 Mdot
.57207 .37588 Mdot
.23811 .45738 Mdot
.63313 .2554 Mdot
.27307 .42911 Mdot
.43295 .18373 Mdot
.54849 .24585 Mdot
.72186 .46267 Mdot
.51751 .49005 Mdot
.71422 .40641 Mdot
.48893 .7918 Mdot
.73715 .65217 Mdot
.5698 .3934 Mdot
.21532 .52292 Mdot
.42197 .57384 Mdot
.49839 .76005 Mdot
.7421 .49127 Mdot
.44418 .68407 Mdot
.43815 .70602 Mdot
.60683 .33435 Mdot
.65406 .31186 Mdot
.43073 .41236 Mdot
.52955 .48731 Mdot
.34424 .64556 Mdot
.37861 .45424 Mdot
.38653 .33096 Mdot
.4596 .33064 Mdot
.83779 .44805 Mdot
.48105 .14385 Mdot
.57939 .69932 Mdot
.30974 .48994 Mdot
.27908 .43042 Mdot
.54842 .77656 Mdot
.52214 .55167 Mdot
.60489 .68419 Mdot
.70962 .63577 Mdot
.34008 .1831 Mdot
.491 .29808 Mdot
.40578 .14758 Mdot
.54783 .37236 Mdot
.66976 .61723 Mdot
.33087 .48468 Mdot
.81163 .48167 Mdot
.53889 .6941 Mdot
.479 .14929 Mdot
.50005 .70705 Mdot
.61537 .31003 Mdot
.42748 .35257 Mdot
.7289 .49466 Mdot
.45555 .76272 Mdot
.49354 .66157 Mdot
.6395 .63467 Mdot
.33593 .17484 Mdot
.42025 .18677 Mdot
.68702 .25183 Mdot
.53234 .26205 Mdot
.30935 .66532 Mdot
.29812 .64757 Mdot
.35002 .42532 Mdot
.61099 .21688 Mdot
.56671 .35149 Mdot
.80847 .34799 Mdot
.5851 .22413 Mdot
.59987 .65302 Mdot
.31568 .19064 Mdot
.81427 .58131 Mdot
.65521 .38778 Mdot
.67258 .75286 Mdot
.21848 .64977 Mdot
.51734 .54884 Mdot
.3972 .37344 Mdot
.37127 .59235 Mdot
.59173 .23895 Mdot
.59819 .2059 Mdot
.67027 .68183 Mdot
.26817 .29325 Mdot
.53298 .48547 Mdot
.35765 .55362 Mdot
.62915 .36179 Mdot
.30659 .70979 Mdot
.52007 .65135 Mdot
.41529 .14651 Mdot
.69011 .44724 Mdot
.24728 .72569 Mdot
.61511 .72924 Mdot
.76444 .55115 Mdot
.42214 .2019 Mdot
.256 .6403 Mdot
.59693 .66471 Mdot
.48083 .31929 Mdot
.60297 .49641 Mdot
.50937 .59588 Mdot
.69952 .62556 Mdot
.41881 .7192 Mdot
.49944 .44999 Mdot
.48478 .26496 Mdot
.58619 .73272 Mdot
.23892 .3727 Mdot
.73987 .58164 Mdot
.58218 .30423 Mdot
.5848 .68134 Mdot
.6085 .71184 Mdot
.51784 .27077 Mdot
.49453 .63838 Mdot
.67794 .24281 Mdot
.47171 .63495 Mdot
.65969 .50457 Mdot
.71648 .4435 Mdot
.6657 .44493 Mdot
.62978 .69701 Mdot
.68334 .55236 Mdot
.82813 .42277 Mdot
.54295 .2616 Mdot
.76747 .3945 Mdot
.56288 .73297 Mdot
.7788 .40468 Mdot
.60757 .23219 Mdot
.32872 .48044 Mdot
.38806 .36809 Mdot
.54241 .39596 Mdot
.34044 .17353 Mdot
.29939 .61935 Mdot
.64522 .68651 Mdot
.27042 .38164 Mdot
.19191 .5202 Mdot
.22629 .41779 Mdot
.45781 .6336 Mdot
.62447 .22445 Mdot
.4574 .34186 Mdot
.28193 .58904 Mdot
.34759 .27181 Mdot
.40784 .4251 Mdot
.76021 .35577 Mdot
.68712 .5973 Mdot
.6678 .65115 Mdot
.48392 .69198 Mdot
.78517 .49227 Mdot
.29404 .46411 Mdot
.40817 .69895 Mdot
.67289 .52131 Mdot
.39556 .62276 Mdot
.45315 .40636 Mdot
.46684 .47788 Mdot
.64031 .19844 Mdot
.70546 .57738 Mdot
.80607 .59104 Mdot
.44554 .33394 Mdot
.45709 .49037 Mdot
.52057 .74326 Mdot
.5232 .31504 Mdot
.38954 .15022 Mdot
.63427 .21953 Mdot
.43755 .30652 Mdot
.47639 .19418 Mdot
.84304 .5939 Mdot
.20391 .42627 Mdot
.81946 .5067 Mdot
.27073 .38083 Mdot
.64672 .86401 Mdot
.35081 .61503 Mdot
.71523 .71146 Mdot
.80866 .48186 Mdot
.36627 .67186 Mdot
.6317 .25455 Mdot
.68604 .46397 Mdot
.52137 .69155 Mdot
.54569 .31745 Mdot
.68326 .54104 Mdot
.51032 .16043 Mdot
.35418 .1697 Mdot
.50073 .15755 Mdot
.4778 .37878 Mdot
.51893 .17497 Mdot
.30359 .22436 Mdot
.60412 .79816 Mdot
.23945 .43096 Mdot
.57673 .57834 Mdot
.65824 .67388 Mdot
.82048 .56101 Mdot
.48683 .67383 Mdot
.52612 .52419 Mdot
.57644 .39568 Mdot
.2998 .21994 Mdot
.64105 .19713 Mdot
.70913 .36804 Mdot
.65736 .28779 Mdot
.366 .52678 Mdot
.61814 .68057 Mdot
.64417 .25268 Mdot
.37294 .26687 Mdot
.53262 .24273 Mdot
.28469 .2432 Mdot
.60409 .71865 Mdot
.21088 .4974 Mdot
.4319 .29796 Mdot
.82237 .53766 Mdot
.42209 .19836 Mdot
.23126 .45502 Mdot
.58312 .65607 Mdot
.62752 .30632 Mdot
.45192 .63634 Mdot
.35709 .27912 Mdot
.34576 .50235 Mdot
.55867 .71548 Mdot
.29016 .60598 Mdot
.66489 .68016 Mdot
.46886 .55433 Mdot
.23891 .43208 Mdot
.54525 .7476 Mdot
.68133 .67954 Mdot
.46214 .28402 Mdot
.50924 .16648 Mdot
.44661 .33562 Mdot
.21453 .65582 Mdot
.44388 .2196 Mdot
.69055 .63047 Mdot
.67959 .58538 Mdot
.61487 .22802 Mdot
.57901 .16044 Mdot
.62611 .22347 Mdot
.48896 .37002 Mdot
.35748 .65845 Mdot
.29203 .38138 Mdot
.54028 .76929 Mdot
.40837 .65019 Mdot
.54438 .22917 Mdot
.44269 .55533 Mdot
.33313 .37216 Mdot
.38073 .33832 Mdot
.63077 .28361 Mdot
.56335 .78894 Mdot
.70993 .31877 Mdot
.57793 .47484 Mdot
.65658 .34285 Mdot
.55177 .31726 Mdot
.47718 .3657 Mdot
.61498 .68568 Mdot
.30169 .62515 Mdot
.18596 .53789 Mdot
.52461 .35559 Mdot
.68195 .61095 Mdot
.32513 .50273 Mdot
.62666 .37599 Mdot
.7955 .43008 Mdot
.28578 .58825 Mdot
.66494 .21408 Mdot
.83381 .45106 Mdot
.64445 .25181 Mdot
.58301 .68872 Mdot
.19559 .54171 Mdot
.47246 .46608 Mdot
.27665 .41148 Mdot
.48175 .20984 Mdot
.4245 .50669 Mdot
.59404 .68785 Mdot
.65285 .36019 Mdot
.25061 .4303 Mdot
.63542 .49286 Mdot
.70663 .26519 Mdot
.59525 .7914 Mdot
.45657 .47079 Mdot
.57039 .2705 Mdot
.58765 .38076 Mdot
.74822 .71635 Mdot
.37161 .29276 Mdot
.55421 .62075 Mdot
.45191 .19414 Mdot
.32276 .43474 Mdot
.59308 .31083 Mdot
.6942 .67206 Mdot
.34687 .70877 Mdot
.64358 .35037 Mdot
.362 .48976 Mdot
.63909 .26253 Mdot
.40496 .48975 Mdot
.46753 .19109 Mdot
.40544 .17783 Mdot
.27072 .75973 Mdot
.54482 .364 Mdot
.28289 .47767 Mdot
.27837 .48051 Mdot
.58892 .39272 Mdot
.58124 .39967 Mdot
.68153 .44503 Mdot
.556 .17445 Mdot
.41472 .54718 Mdot
.36469 .26119 Mdot
.45691 .4945 Mdot
.31657 .70107 Mdot
.25558 .44766 Mdot
.55221 .75492 Mdot
.37448 .21292 Mdot
.68221 .30322 Mdot
.15822 .5345 Mdot
.56251 .47985 Mdot
.72008 .70595 Mdot
.54 .76982 Mdot
.73581 .61087 Mdot
.74157 .48664 Mdot
.51429 .23675 Mdot
.64282 .52199 Mdot
.49818 .14487 Mdot
.49257 .28447 Mdot
.50793 .60564 Mdot
.25358 .64332 Mdot
.58919 .52559 Mdot
.55922 .54164 Mdot
.63976 .24663 Mdot
.55948 .26321 Mdot
.16972 .44222 Mdot
.62688 .72219 Mdot
.66163 .64645 Mdot
.65113 .38182 Mdot
.80608 .5899 Mdot
.35207 .47891 Mdot
.53217 .19773 Mdot
.46861 .56269 Mdot
.82702 .54692 Mdot
.35807 .24321 Mdot
.34344 .28881 Mdot
.43951 .21258 Mdot
.31378 .21576 Mdot
.62552 .64348 Mdot
.50512 .33533 Mdot
.24612 .46597 Mdot
.6321 .59208 Mdot
.47842 .35247 Mdot
.45274 .20088 Mdot
.32521 .75815 Mdot
.52625 .58193 Mdot
.57099 .15562 Mdot
.61049 .47306 Mdot
.4992 .32514 Mdot
.21542 .37491 Mdot
.1442 .57988 Mdot
.35033 .29628 Mdot
.42239 .14574 Mdot
.33777 .28174 Mdot
.44061 .19117 Mdot
.33642 .43658 Mdot
.42045 .52693 Mdot
.78737 .38467 Mdot
.56278 .17493 Mdot
.37214 .73365 Mdot
.24266 .37777 Mdot
.75978 .3334 Mdot
.55418 .16908 Mdot
.62904 .4796 Mdot
.75264 .70414 Mdot
.28761 .65606 Mdot
.83574 .55765 Mdot
.83168 .48182 Mdot
.58495 .27058 Mdot
.65713 .69223 Mdot
.75491 .69049 Mdot
.65144 .78713 Mdot
.82722 .48228 Mdot
.72289 .63747 Mdot
.5499 .27428 Mdot
.5747 .68923 Mdot
.55648 .22203 Mdot
.78749 .63077 Mdot
.26789 .461 Mdot
.45399 .42155 Mdot
.45622 .37365 Mdot
.59794 .24441 Mdot
.45364 .2682 Mdot
.33499 .49277 Mdot
.48706 .42784 Mdot
.6327 .26605 Mdot
.32706 .83057 Mdot
.31194 .28328 Mdot
.6175 .41502 Mdot
.37363 .16375 Mdot
.52854 .24926 Mdot
.42955 .55474 Mdot
.74652 .50437 Mdot
.56982 .78322 Mdot
.26387 .62618 Mdot
.66314 .56696 Mdot
.54641 .16897 Mdot
.27089 .60512 Mdot
.43533 .15307 Mdot
.76285 .29909 Mdot
.66876 .31688 Mdot
.69534 .58669 Mdot
.37037 .58354 Mdot
.74563 .6371 Mdot
.72224 .64793 Mdot
.36733 .17501 Mdot
.72526 .69746 Mdot
.43356 .47683 Mdot
.38708 .49789 Mdot
.39012 .47724 Mdot
.5808 .6381 Mdot
.82328 .5629 Mdot
.53033 .29724 Mdot
.56871 .74449 Mdot
.42211 .30441 Mdot
.6367 .69059 Mdot
.65802 .41772 Mdot
.53759 .76369 Mdot
.48802 .61736 Mdot
.52128 .71226 Mdot
.36219 .59744 Mdot
.26686 .27588 Mdot
.48296 .22989 Mdot
.82261 .40535 Mdot
.2164 .6553 Mdot
.48193 .32249 Mdot
.68725 .70607 Mdot
.27072 .44082 Mdot
.52135 .58591 Mdot
.39178 .76109 Mdot
.5897 .74888 Mdot
.67175 .43306 Mdot
.52558 .21492 Mdot
.72455 .54429 Mdot
.60582 .20436 Mdot
.55749 .71997 Mdot
.22973 .33856 Mdot
.36255 .52942 Mdot
.78521 .47311 Mdot
.67273 .3877 Mdot
.20011 .62541 Mdot
.45649 .47342 Mdot
.33582 .17584 Mdot
.60522 .31376 Mdot
.47685 .14389 Mdot
.29662 .40666 Mdot
.33025 .78219 Mdot
.52742 .233 Mdot
.49742 .57779 Mdot
.48056 .53186 Mdot
.72934 .28082 Mdot
.43703 .34076 Mdot
.4547 .32621 Mdot
.45596 .63831 Mdot
.28967 .63301 Mdot
.43008 .45164 Mdot
.37162 .25748 Mdot
.26917 .27827 Mdot
.65676 .59688 Mdot
.38857 .58203 Mdot
.7329 .64708 Mdot
.27841 .42019 Mdot
.55148 .25708 Mdot
.51044 .21851 Mdot
.62521 .42805 Mdot
.61251 .67919 Mdot
.31291 .21246 Mdot
.55375 .23401 Mdot
.44833 .62262 Mdot
.71129 .61362 Mdot
.25489 .39187 Mdot
.18215 .45861 Mdot
.39321 .19607 Mdot
.39037 .48624 Mdot
.48104 .44962 Mdot
.58194 .70084 Mdot
.58798 .14548 Mdot
.34701 .17643 Mdot
.17185 .58516 Mdot
.45286 .49238 Mdot
.53786 .32111 Mdot
.57947 .77286 Mdot
.23072 .33602 Mdot
.8414 .54942 Mdot
.45509 .29889 Mdot
.64503 .68922 Mdot
.30784 .74168 Mdot
.73482 .70657 Mdot
.43208 .49051 Mdot
.67393 .38823 Mdot
.80678 .44016 Mdot
.32785 .45145 Mdot
.26322 .61476 Mdot
.45529 .51526 Mdot
.24993 .38723 Mdot
.54748 .27636 Mdot
.43751 .3422 Mdot
.229 .33924 Mdot
.73467 .68848 Mdot
.71346 .61037 Mdot
.23991 .33977 Mdot
.62706 .32837 Mdot
.27162 .47668 Mdot
.17895 .50848 Mdot
.44806 .50367 Mdot
.34025 .63431 Mdot
.54035 .51516 Mdot
.45236 .44467 Mdot
.33975 .27011 Mdot
.27544 .71745 Mdot
.48163 .73965 Mdot
.54488 .37775 Mdot
.74691 .69097 Mdot
.55125 .37161 Mdot
.62858 .17404 Mdot
.37618 .26486 Mdot
.65472 .3622 Mdot
.34068 .24836 Mdot
.22685 .50352 Mdot
.21768 .67047 Mdot
.64886 .27213 Mdot
.54758 .68869 Mdot
.54093 .36833 Mdot
.54565 .33409 Mdot
.36325 .23102 Mdot
.40833 .39033 Mdot
.65279 .29521 Mdot
.7972 .60284 Mdot
.19667 .54602 Mdot
.57023 .38354 Mdot
.3856 .50269 Mdot
.58999 .41572 Mdot
.64806 .19997 Mdot
.34134 .63048 Mdot
.34896 .16743 Mdot
.71442 .5812 Mdot
.17604 .46235 Mdot
.58531 .23886 Mdot
.50384 .423 Mdot
.44357 .48404 Mdot
.20067 .52842 Mdot
.64965 .49961 Mdot
.65606 .64771 Mdot
.60706 .35022 Mdot
.23008 .40808 Mdot
.45958 .71514 Mdot
.48841 .65026 Mdot
.2723 .39007 Mdot
.78089 .55282 Mdot
.83492 .5273 Mdot
.54787 .32384 Mdot
.35393 .52116 Mdot
.2735 .48916 Mdot
.64905 .4834 Mdot
.73401 .63774 Mdot
.28831 .25024 Mdot
.652 .2822 Mdot
.60029 .30934 Mdot
.18048 .60118 Mdot
.44128 .66276 Mdot
.67856 .22494 Mdot
.62382 .44152 Mdot
.74241 .64095 Mdot
.73838 .60051 Mdot
.64661 .2432 Mdot
.65482 .41678 Mdot
.54374 .20836 Mdot
.59131 .68272 Mdot
.43265 .64207 Mdot
.68286 .67751 Mdot
.62676 .42728 Mdot
.40851 .47283 Mdot
.82521 .57498 Mdot
.29909 .7368 Mdot
.71498 .41445 Mdot
.52525 .55285 Mdot
.60666 .25763 Mdot
.80801 .58499 Mdot
.54653 .38135 Mdot
.47558 .74829 Mdot
.73018 .33043 Mdot
.52621 .2359 Mdot
.6082 .21534 Mdot
.5166 .27206 Mdot
.74549 .64164 Mdot
.39398 .47262 Mdot
.62591 .76252 Mdot
.71818 .56591 Mdot
.50329 .5588 Mdot
.61428 .4996 Mdot
.68002 .63106 Mdot
.44969 .56904 Mdot
.74387 .29836 Mdot
.61385 .64747 Mdot
.55172 .17851 Mdot
.66399 .22055 Mdot
.49476 .17931 Mdot
.34012 .5048 Mdot
.55682 .37156 Mdot
.3759 .15777 Mdot
.7607 .62412 Mdot
.55763 .22458 Mdot
.8291 .49386 Mdot
.75646 .71005 Mdot
.21613 .35356 Mdot
.49821 .2567 Mdot
.63684 .34658 Mdot
.81544 .37402 Mdot
.4933 .2966 Mdot
.75751 .69465 Mdot
.67521 .43674 Mdot
.57105 .246 Mdot
.3097 .19891 Mdot
.80126 .52971 Mdot
.46029 .32637 Mdot
.67088 .39376 Mdot
.63526 .40932 Mdot
.7858 .60179 Mdot
.56633 .50203 Mdot
.31234 .64755 Mdot
.33042 .68272 Mdot
.64602 .69546 Mdot
.6103 .43008 Mdot
.78383 .61423 Mdot
.72259 .65003 Mdot
.67541 .71404 Mdot
.20037 .53506 Mdot
.21747 .35315 Mdot
.64711 .37514 Mdot
.56141 .58341 Mdot
.55289 .38891 Mdot
.45265 .72674 Mdot
.61317 .73575 Mdot
.58848 .54757 Mdot
.48281 .49678 Mdot
.60716 .63291 Mdot
.52666 .15576 Mdot
.33567 .69701 Mdot
.3418 .37155 Mdot
.56307 .37696 Mdot
.5981 .24568 Mdot
.34931 .46868 Mdot
.42505 .35201 Mdot
.77912 .61622 Mdot
.64116 .30776 Mdot
.45773 .18435 Mdot
.46777 .32907 Mdot
.57736 .71791 Mdot
.47636 .78836 Mdot
.35419 .4004 Mdot
.79701 .42063 Mdot
.35537 .18538 Mdot
.48446 .3406 Mdot
.62045 .31732 Mdot
.43141 .28932 Mdot
.40928 .47607 Mdot
.49861 .35304 Mdot
.43911 .33701 Mdot
.27505 .45694 Mdot
.67997 .33982 Mdot
.39814 .18383 Mdot
.35709 .56976 Mdot
.61879 .71564 Mdot
.38801 .29037 Mdot
.78769 .60975 Mdot
.64519 .48061 Mdot
.57946 .198 Mdot
.49535 .57018 Mdot
.4181 .68416 Mdot
.61112 .53296 Mdot
.7574 .60439 Mdot
.63831 .24369 Mdot
.41371 .30012 Mdot
.57279 .65166 Mdot
.58157 .29197 Mdot
.83501 .44543 Mdot
.27094 .65525 Mdot
.26506 .64035 Mdot
.69381 .73338 Mdot
.50705 .38537 Mdot
.41387 .64607 Mdot
.35625 .35783 Mdot
.64853 .49345 Mdot
.46689 .78441 Mdot
.37322 .49016 Mdot
.79255 .40706 Mdot
.81633 .51458 Mdot
.27827 .26302 Mdot
.36066 .48572 Mdot
.8387 .44492 Mdot
.80546 .42006 Mdot
.57866 .24881 Mdot
.74396 .68683 Mdot
.53118 .51736 Mdot
.68465 .55204 Mdot
.47577 .74827 Mdot
.61864 .35937 Mdot
.29937 .24446 Mdot
.61876 .66159 Mdot
.42317 .71432 Mdot
.49598 .59436 Mdot
.32972 .48685 Mdot
.30951 .54899 Mdot
.54105 .26578 Mdot
.81647 .37519 Mdot
.6131 .68554 Mdot
.31899 .44003 Mdot
.34504 .27079 Mdot
.52878 .59867 Mdot
.56405 .18784 Mdot
.45562 .58807 Mdot
.63569 .24955 Mdot
.47784 .39853 Mdot
.79231 .44003 Mdot
.68791 .24237 Mdot
.52757 .65401 Mdot
.50346 .53626 Mdot
.54793 .28485 Mdot
.52438 .51478 Mdot
.43816 .41187 Mdot
.37036 .6799 Mdot
.75734 .64781 Mdot
.25745 .30923 Mdot
.28172 .35257 Mdot
.59877 .48056 Mdot
.58314 .76994 Mdot
.37661 .19672 Mdot
.42737 .56103 Mdot
.48822 .57428 Mdot
.24446 .46858 Mdot
.27103 .60198 Mdot
.27448 .77507 Mdot
.51005 .14924 Mdot
.60999 .53201 Mdot
.46956 .53439 Mdot
.46576 .65349 Mdot
.30539 .58383 Mdot
.70238 .31036 Mdot
.29901 .24123 Mdot
.35004 .41666 Mdot
.21109 .59914 Mdot
.35636 .35854 Mdot
.73592 .28747 Mdot
.17189 .55843 Mdot
.3546 .38216 Mdot
.6259 .17145 Mdot
.4481 .30629 Mdot
.51875 .36253 Mdot
.2873 .7911 Mdot
.71917 .27828 Mdot
.71768 .61686 Mdot
.30881 .67164 Mdot
.52558 .16091 Mdot
.44448 .48195 Mdot
.37577 .64483 Mdot
.80618 .52116 Mdot
.60629 .68567 Mdot
.62367 .72034 Mdot
.38024 .37569 Mdot
.79226 .36855 Mdot
.71919 .75534 Mdot
.22893 .50277 Mdot
.19477 .64502 Mdot
.6605 .30342 Mdot
.42591 .16835 Mdot
.35153 .29407 Mdot
.33078 .75583 Mdot
.60505 .21799 Mdot
.68932 .66625 Mdot
.77852 .58024 Mdot
.35574 .73092 Mdot
.52834 .66234 Mdot
.5778 .78205 Mdot
.48893 .38859 Mdot
.65867 .28048 Mdot
.20769 .53169 Mdot
.55565 .64424 Mdot
.67395 .67903 Mdot
.80489 .45543 Mdot
.5036 .54132 Mdot
.38467 .17313 Mdot
.77177 .61361 Mdot
.59115 .69406 Mdot
.215 .46873 Mdot
.43795 .7079 Mdot
.31915 .22984 Mdot
.38343 .4374 Mdot
.72181 .61197 Mdot
.20516 .38562 Mdot
.41467 .14715 Mdot
.53076 .51767 Mdot
.56815 .56469 Mdot
.69314 .22947 Mdot
.39406 .56849 Mdot
.81851 .50458 Mdot
.38803 .32381 Mdot
.63687 .71929 Mdot
.60069 .63796 Mdot
.63695 .50998 Mdot
.64581 .76499 Mdot
.62566 .29582 Mdot
.80652 .45116 Mdot
.17725 .54236 Mdot
.58862 .68991 Mdot
.76512 .57975 Mdot
.159 .53012 Mdot
.62847 .44143 Mdot
.54988 .33746 Mdot
.52547 .15885 Mdot
.70892 .29242 Mdot
.69772 .63122 Mdot
.66178 .36578 Mdot
.45363 .60131 Mdot
.45294 .77403 Mdot
.71528 .60505 Mdot
.47104 .46756 Mdot
.65408 .6946 Mdot
.23273 .34237 Mdot
.78134 .37185 Mdot
.33173 .17528 Mdot
.63428 .22345 Mdot
.55652 .37695 Mdot
.8052 .50996 Mdot
.4443 .50532 Mdot
.48478 .17978 Mdot
.20205 .51151 Mdot
.18987 .53099 Mdot
.6977 .76508 Mdot
.48748 .65301 Mdot
.66105 .53367 Mdot
.47882 .37984 Mdot
.61077 .21011 Mdot
.71696 .74759 Mdot
.60252 .20466 Mdot
.66153 .63702 Mdot
.68258 .58255 Mdot
.14557 .60102 Mdot
.45252 .19014 Mdot
.69635 .54045 Mdot
.54911 .60212 Mdot
.56523 .6286 Mdot
.65916 .54132 Mdot
.41562 .38232 Mdot
.55976 .77976 Mdot
.64641 .71129 Mdot
.55207 .17561 Mdot
.59149 .38276 Mdot
.44857 .48174 Mdot
.35717 .3899 Mdot
.4792 .50821 Mdot
.59389 .44547 Mdot
.32955 .43471 Mdot
.66547 .70565 Mdot
.3659 .551 Mdot
.46554 .76528 Mdot
.62878 .29036 Mdot
.50066 .40059 Mdot
.62565 .27243 Mdot
.71054 .69561 Mdot
.40756 .37611 Mdot
.6459 .79113 Mdot
.72085 .65377 Mdot
.72509 .58024 Mdot
.52737 .2813 Mdot
.83068 .61068 Mdot
.44977 .47455 Mdot
.46342 .36676 Mdot
.62613 .46251 Mdot
.71802 .50904 Mdot
.66988 .34588 Mdot
.50133 .67908 Mdot
.4579 .40603 Mdot
.67649 .62869 Mdot
.62972 .25094 Mdot
.28737 .40724 Mdot
.58169 .14935 Mdot
.69026 .58561 Mdot
.7039 .32604 Mdot
.55919 .20051 Mdot
.26825 .46845 Mdot
.66895 .4341 Mdot
.60471 .50159 Mdot
.43714 .61912 Mdot
.36988 .55347 Mdot
.57039 .40609 Mdot
.25051 .44164 Mdot
.43167 .17917 Mdot
.71256 .7065 Mdot
.68661 .31808 Mdot
.64703 .57666 Mdot
.49548 .72677 Mdot
.47717 .47502 Mdot
.33042 .74403 Mdot
.36626 .56207 Mdot
.53785 .24716 Mdot
.70235 .69844 Mdot
.62564 .72281 Mdot
.67485 .4112 Mdot
.45337 .14962 Mdot
.52953 .58177 Mdot
.66692 .32152 Mdot
.48239 .60615 Mdot
.46135 .2669 Mdot
.72113 .64362 Mdot
.24537 .33604 Mdot
.64348 .64503 Mdot
.53391 .53004 Mdot
.61596 .1841 Mdot
.64877 .26867 Mdot
.31199 .35844 Mdot
.52722 .21311 Mdot
.76144 .64212 Mdot
.48063 .53377 Mdot
.29971 .80611 Mdot
.19887 .51068 Mdot
.61225 .16668 Mdot
.24286 .41024 Mdot
.69299 .50847 Mdot
.52432 .31078 Mdot
.68216 .5376 Mdot
.3225 .60604 Mdot
.46963 .17482 Mdot
.55277 .2814 Mdot
.53247 .4949 Mdot
.55756 .54298 Mdot
.40488 .56133 Mdot
.56846 .4015 Mdot
.25067 .31634 Mdot
.2824 .63045 Mdot
.44971 .61865 Mdot
.24211 .3665 Mdot
.36874 .55342 Mdot
.76964 .69594 Mdot
.37106 .17218 Mdot
.48517 .21035 Mdot
.37885 .48931 Mdot
.29012 .76283 Mdot
.53045 .34122 Mdot
.60262 .39585 Mdot
.27671 .39422 Mdot
.63031 .76559 Mdot
.49177 .34706 Mdot
.23096 .35516 Mdot
.64389 .23577 Mdot
.64823 .48201 Mdot
.34862 .85316 Mdot
.69614 .66631 Mdot
.43689 .57736 Mdot
.48734 .35893 Mdot
.56308 .17955 Mdot
.25428 .65865 Mdot
.75713 .29606 Mdot
.366 .28311 Mdot
.60832 .43304 Mdot
.60907 .78682 Mdot
.18232 .60138 Mdot
.37568 .50211 Mdot
.19604 .64791 Mdot
.43191 .20118 Mdot
.55842 .77031 Mdot
.40478 .30061 Mdot
.5414 .35898 Mdot
.64395 .64971 Mdot
.38214 .25847 Mdot
.52683 .52784 Mdot
.52157 .36099 Mdot
.42625 .18554 Mdot
.51056 .79398 Mdot
.20699 .45787 Mdot
.48351 .19324 Mdot
.27402 .41446 Mdot
.56729 .27858 Mdot
.71724 .66503 Mdot
.39043 .58167 Mdot
.29881 .59557 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0:7ooooo0_l0002Vooooo`007?ooool0
0ol0003oooooooooo`2Qooooo`;o0000Y_ooool001cooooo00?o0000ooooooooool0S_ooool2o`00
00Oooooo1?l0000Mooooo`;o0000Soooool001cooooo00?o0000ooooooooool0P?ooool2o`000003
ooooool0003o000000;o00001oooool2o`0000Oooooo1?l00003ooooo`;o00006?ooool2o`000003
ooooool0003o000008cooooo000Looooo`03o`000?oooooooooo07_ooooo0ol00002ooooo`;o0000
00?oooooo`000?l000000_l00009ooooo`;o00001_ooool2o`0000Cooooo0_l00002ooooo`;o0000
5Oooool4o`0008cooooo000Looooo`;o0000O?ooool3o`0000Gooooo0_l00005ooooo`;o00001?oo
ool2o`0000Kooooo0_l00008ooooo`;o00002Oooool2o`0000[ooooo0_l0002>ooooo`007?ooool0
0ol0003oooooooooo`1fooooo`;o00002oooool2o`0000Gooooo0_l0000Kooooo`;o00001?ooool2
o`0000Oooooo0_l0002Aooooo`007?ooool00ol0003oooooooooo`1fooooo`;o00004?ooool2o`00
00Cooooo0_l00004ooooo`;o00001_ooool2o`000003ooooool0003o000000Kooooo0_l0000=oooo
o`;o00002?ooool2o`0008Oooooo000Looooo`03o`000?oooooooooo07Kooooo0_l0000@ooooo`;o
00001?ooool2o`0000Cooooo0_l00006ooooo`;o000000Coooooo`000?l0003ooooo0_l00003oooo
o`;o00003oooool2o`0000Kooooo0_l00027ooooo`007?ooool00ol0003oooooooooo`1fooooo`;o
0000:Oooool3o`0000?ooooo0_l0000?ooooo`;o0000Soooool001cooooo00?o0000ooooooooool0
K_ooool2o`0000Kooooo0_l0000?ooooo`;o00001?ooool2o`0001;ooooo0ol0000:ooooo`Co0000
4Oooool2o`0008Cooooo000Looooo`03o`000?oooooooooo06kooooo0ol00004ooooo`;o00002Ooo
ool2o`0000Gooooo0_l00004ooooo`;o00003_ooool2o`0000?ooooo0_l0000:ooooo`Co00004Ooo
ool2o`0000?ooooo0_l0001oooooo`007?ooool00ol0003oooooooooo`1Xooooo`Go00000_ooool2
o`0000?ooooo0ol00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0001?ooooo0_l00006
ooooo`;o00001Oooool3o`0000[ooooo1?l0000Cooooo`;o0000Ooooool001cooooo00?o0000oooo
ooooool0J?ooool7o`0000Gooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`00
00[ooooo0_l00007ooooo`?o00003?ooool3o`0000Wooooo1Ol0000Cooooo`?o0000O_ooool001co
oooo00?o0000ooooooooool0JOooool2o`0000;ooooo0_l0000Aooooo`;o00001_ooool2o`0000;o
oooo0_l00008ooooo`;o00000_ooool2o`000003ooooool0003o000000Cooooo0_l00006ooooo`;o
00000_ooool3o`000003ooooool0003o000000Cooooo0_l0000>ooooo`;o0000O_ooool001cooooo
00?o0000ooooooooool0Joooool2o`00017ooooo0_l00008ooooo`?o00001_ooool2o`0000Oooooo
0_l000000ooooooo0000o`000004ooooo`;o00001_ooool2o`0000;ooooo0_l00002ooooo`;o0000
1?ooool2o`0000Wooooo0_l00023ooooo`007?ooool00ol0003oooooooooo`1[ooooo`;o00000ooo
ool2o`0000cooooo0_l00005ooooo`Ko00001_ooool2o`0000kooooo0_l00002ooooo`;o00007Ooo
ool2o`0008?ooooo000Looooo`03o`000?oooooooooo06?ooooo0_l0000;ooooo`;o00004oooool4
o`0000Kooooo0_l00003ooooo`;o00002oooool2o`0000;ooooo0ol00003ooooo`;o00001?ooool4
o`0009Cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_oo
ool00ol0003oooooooooo`1Sooooo`;o00009_ooool2o`0000;ooooo0_l00003ooooo`;o00000ooo
ool4o`0000Wooooo0_l00003ooooo`;o00001?ooool4o`0009Cooooo00001_ooooooMgMgoiRHV?oo
ooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`1gooooo`;o00000oooool2o`0000gooooo0_l00002ooooo`;o00000oooool2o`000003
ooooool0003o000000Co00004_ooool2o`0009Sooooo00000ooooooo410@ooooo`02ooooo`03oa0@
4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`1Qooooo`;o0000
5?ooool2o`0000?ooooo0_l00007ooooo`;o00002?ooool2o`0000Kooooo1?l0000>ooooo`;o0000
1?ooool3o`0000?ooooo0_l000000ooooooo0000o`000009ooooo`;o00001oooool2o`000003oooo
ool0003o000007Sooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o
V9RHob4Q8Oo^k^h01_ooool3o`00067ooooo0_l0000Rooooo`;o00000_ooool2o`0000Cooooo0_l0
0008ooooo`Co00003?ooool2o`0000Gooooo1?l000001?oooooo0000o`000?ooool2o`0000Wooooo
0_l00007ooooo`Go0000N?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?oo
ool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo083ooooo0_l00003ooooo`;o00000_oo
ool2o`0000Cooooo0_l00002ooooo`;o00001?ooool4o`0000;ooooo0_l0000Aooooo`Go00002?oo
ool6o`0000Sooooo0ol000000ooooooo0000o`00001fooooo`0000?ooooooa0@4?ooool00_ooool0
0ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Ooooool3
o`0000Sooooo0_l00002ooooo`;o00000oooool2o`0000Cooooo1?l000000ooooooo0000o`000005
o`0000Sooooo0_l00004ooooo`Co00002?ooool4o`0000_ooooo0_l000000ooooooo0000o`00001f
ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
1_ooool00ol0003oooooooooo`1oooooo`;o00002Oooool2o`0000;ooooo0_l00009ooooo`Co0000
00?oooooo`000?l000001Ol00007ooooo`?o00005?ooool2o`0008Cooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo
05_ooooo0_l00005ooooo`;o00004_ooool2o`0001?ooooo0_l00006ooooo`;o00001?ooool3o`00
0003ooooool0003o000000?o00000oooool4o`0000?ooooo0_l0000Dooooo`?o00003oooool2o`00
07?ooooo000Looooo`03o`000?oooooooooo05_ooooo0_l00005ooooo`;o00004_ooool2o`0001?o
oooo0_l00006ooooo`;o00002?ooool2o`0000?ooooo0_l000000ooooooo0000o`000004o`0000ko
oooo0_l00006ooooo`Co00003oooool2o`0007?ooooo000Looooo`03o`000?oooooooooo05kooooo
0_l00002ooooo`;o0000:?ooool2o`0000gooooo0_l00002ooooo`Go00001Oooool2o`0000kooooo
0_l00006ooooo`Co00001Oooool2o`0000Sooooo0_l0001cooooo`007?ooool00ol0003ooooooooo
o`1Nooooo`?o0000:oooool2o`0000Oooooo0_l00004ooooo`;o00000_ooool5o`0000gooooo0_l0
0007ooooo`;o00002oooool5o`0000Sooooo0_l0001cooooo`007?ooool00ol0003oooooooooo`1O
ooooo`;o0000=?ooool2o`0000Gooooo0_l0000@ooooo`;o000000?oooooo`000?l000001oooool2
o`0000_ooooo1Ol0000=ooooo`;o000000?oooooo`000?l00000Joooool001cooooo00?o0000oooo
ooooool0I?ooool2o`0003?ooooo0_l000000ooooooo0000o`000003o`0000[ooooo1Ol0000@oooo
o`;o00000_ooool2o`0001?ooooo0_l000001?oooooo0000o`000?l0001Zooooo`007?ooool00ol0
003oooooooooo`1Tooooo`;o00003?ooool2o`0002Gooooo0_l00002ooooo`Co00001oooool2o`00
0003ooooool0003o000000;o00004Oooool6o`0001Oooooo0_l0001Zooooo`007?ooool00ol0003o
ooooooooo`1Oooooo`;o00004Oooool2o`0002oooooo0_l00002ooooo`?o00001?ooool4o`00013o
oooo0ol00008ooooo`;o0000N_ooool001cooooo00?o0000ooooooooool0Goooool2o`0004;ooooo
0_l00002ooooo`;o00001Oooool4o`0000Oooooo1Ol00003ooooo`;o00002_ooool2o`0000cooooo
0_l0001/ooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o00004?ooool2o`0003Sooooo0_l0
0003ooooo`;o00002Oooool5o`0000?ooooo0ol0000Dooooo`;o000000Coooooo`000?l0003o0000
1?ooool2o`0006Gooooo000Looooo`03o`000?oooooooooo05Wooooo0_l00002ooooo`?o00003ooo
ool4o`0002?ooooo0_l0000@ooooo`?o00000oooool2o`0000Kooooo0_l00005ooooo`Co000000?o
ooooo`000?l000002?ooool4o`0000Sooooo0_l00002ooooo`;o00001?ooool2o`0006Gooooo000L
ooooo`03o`000?oooooooooo05Wooooo0_l00003ooooo`;o00002oooool2o`0000;ooooo1?l0000S
ooooo`;o000000?oooooo`000?l000003Oooool2o`000004ooooool0003o0000ooooo`;o00001?oo
ool6o`0000?ooooo1?l000000ooooooo0000o`000008ooooo`Co0000NOooool001cooooo0_l0001K
ooooo`;o00003oooool2o`0000;ooooo0_l0000Xooooo`;o00003Oooool2o`000004ooooool0003o
0000o`0000Kooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo1?l00005ooooo`Oo00002ooo
ool2o`000003ooooool0003o000000Cooooo0_l0001Sooooo`007?ooool00ol0003oooooooooo`1J
ooooo`;o00004?ooool2o`000003ooooool0003o000003Gooooo0_l00003ooooo`?o00003_ooool2
o`0000;ooooo0_l00007ooooo`Oo00002oooool2o`000003ooooool0003o000000Cooooo0_l0001S
ooooo`007?ooool00ol0003oooooooooo`1Jooooo`;o00004?ooool2o`0000Oooooo0_l000000ooo
oooo0000o`00000Tooooo`;o00001_ooool4o`000003ooooool0003o000000;ooooo0_l0000=oooo
o`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`?o000000?oooooo`000?l00000N_ooool0
01cooooo00?o0000ooooooooool0KOooool2o`0000Cooooo1?l000000ooooooo0000o`00000Toooo
o`?o00001_ooool3o`0000?ooooo1?l0000=ooooo`;o000000Coooooo`000?l0003ooooo0_l0000D
ooooo`Co00000_ooool2o`0006Oooooo000Looooo`03o`000?oooooooooo05Oooooo0_l0000Doooo
o`;o00001?ooool2o`0002;ooooo0_l00006ooooo`;o00001_ooool4o`0000;ooooo0_l00003oooo
o`;o00006?ooool2o`0000cooooo1?l00002ooooo`;o0000Ioooool001cooooo00?o0000oooooooo
ool0E_ooool3o`0001cooooo0ol0000Jooooo`;o00000oooool2o`000003ooooool0003o000000_o
oooo1?l000000ooooooo0000o`000004ooooo`;o00002oooool2o`000003ooooool0003o000000Ko
oooo1_l0000Booooo`;o00001?ooool2o`0005oooooo000Looooo`03o`000?oooooooooo05Kooooo
0_l0000Cooooo`?o00001oooool3o`0001Kooooo1_l00006ooooo`;o00002?ooool2o`000003oooo
ool0003o000000?ooooo0_l00008ooooo`;o00000_ooool2o`0000?ooooo1Ol00006ooooo`;o0000
0_ooool3o`00017ooooo0_l00004ooooo`;o0000Goooool001cooooo00?o0000ooooooooool0J?oo
ool7o`0001oooooo1?l0000Booooo`;o00004?ooool2o`0000;ooooo0_l00004ooooo`;o00000_oo
ool2o`000003ooooool0003o000000Kooooo0_l0000Cooooo`;o0000Hoooool001cooooo00?o0000
ooooooooool0Doooool2o`0001?ooooo0ol00002ooooo`;o0000<Oooool2o`0000;ooooo1?l00004
ooooo`Go00004oooool2o`000003ooooool0003o000000Kooooo0_l0000Cooooo`;o0000Hoooool0
01cooooo00?o0000ooooooooool0Doooool3o`0001[ooooo0_l0000^ooooo`?o00000oooool2o`00
00Cooooo1Ol00002ooooo`Co00002Oooool2o`0002Cooooo0_l0001Qooooo`007?ooool00ol0003o
ooooooooo`1Dooooo`;o00005?ooool2o`0000Cooooo0_l000000ooooooo0000o`00000/ooooo`;o
00001Oooool2o`0000Kooooo0_l000000ooooooo0000o`000002o`0000Wooooo0ol00003ooooo`;o
00002?ooool4o`0001;ooooo0_l000000ooooooo0000o`00001Nooooo`007?ooool00ol0003ooooo
ooooo`1Rooooo`;o00000oooool2o`000003ooooool0003o000000Kooooo0ol0000Mooooo`;o0000
2?ooool2o`0000Wooooo0ol00004ooooo`Co000000?oooooo`000?l000003?ooool2o`0000?ooooo
1Ol00005ooooo`Co00005Oooool2o`0005kooooo000Looooo`03o`000?oooooooooo06;ooooo0ol0
0002ooooo`;o00000oooool2o`0000Cooooo0_l0000Dooooo`;o00002?ooool2o`0000Sooooo0_l0
0009ooooo`?o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00004_ooool5o`0000Kooooo
0_l0000Eooooo`Co0000G?ooool001cooooo00?o0000ooooooooool0Hoooool2o`0000Oooooo0_l0
000<ooooo`;o00003?ooool2o`0001kooooo0_l000001?oooooo0000o`000?ooool2o`0000Wooooo
0_l00002ooooo`;o00002Oooool4o`0000Kooooo0_l0000>ooooo`;o00001Oooool4o`0005cooooo
000Looooo`03o`000?oooooooooo05?ooooo0_l0000>ooooo`;o00002Oooool3o`0000Cooooo0_l0
0003ooooo`;o0000<?ooool4o`0000Wooooo1ol00008ooooo`;o000000?oooooo`000?l000000ooo
ool2o`00013ooooo0_l0000:ooooo`;o00000_ooool2o`0005Gooooo000Looooo`03o`000?oooooo
oooo05?ooooo0_l0000Iooooo`?o00001?ooool2o`000003ooooool0003o000000oooooo0_l0000A
ooooo`;o00002oooool2o`000003ooooool0003o000000Gooooo0ol00005ooooo`Ko00001?ooool4
o`0000;ooooo0_l00003ooooo`;o00004?ooool2o`0000[ooooo0_l00002ooooo`;o0000EOooool0
01cooooo0_l0001_ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Kooooo0_l000000ooo
oooo0000o`000004ooooo`Co00000oooool2o`0000[ooooo0_l0000;ooooo`;o00002?ooool4o`00
0004ooooool0003o0000ooooo`;o00000_ooool2o`0000Cooooo1?l00003ooooo`;o00005Oooool2
o`0000Wooooo0ol000000ooooooo0000o`000002o`0005?ooooo000Looooo`03o`000?oooooooooo
06_ooooo0_l00004ooooo`;o00001?ooool2o`0000;ooooo1?l000001?oooooo0000o`000?ooool4
o`0000Cooooo0_l00003ooooo`;o000000?oooooo`000?l000007oooool?o`0000Kooooo0_l00000
0ooooooo0000o`000005ooooo`;o00001Oooool2o`0000Oooooo0_l0000:ooooo`;o00000oooool2
o`0005?ooooo000Looooo`03o`000?oooooooooo06_ooooo1?l00008ooooo`;o00000_ooool4o`00
00;ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`Ko00003Oooool2o`00
00Sooooo0_l00002ooooo`co000000?oooooo`000?l000000_l00003ooooo`?o000000?oooooo`00
0?l000001Oooool2o`0000Gooooo0_l0001]ooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o
00006oooool2o`0000cooooo0_l00004ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o
00001Oooool4o`0000[ooooo1_l00006oooooa;o000000?oooooo`000?l000000_l000001?oooooo
0000o`000?l00002ooooo`;o00004_ooool2o`0006Oooooo000Looooo`03o`000?oooooooooo053o
oooo0_l0000Pooooo`;o00006Oooool2o`000003ooooool0003o000000?o000000?oooooo`000?l0
00002oooool6o`0000Kooooo0_l000000ooooooo0000o`00000Bo`000003ooooool0003o000000So
oooo0_l00007ooooo`;o00001?ooool2o`0006Oooooo000Looooo`03o`000?oooooooooo04cooooo
1?l0000Rooooo`;o00006Oooool2o`000003ooooool0003o000000?o000000Coooooo`000?l0003o
00002oooool4o`0000Gooooo6?l00002ooooo`;o00001oooool3o`0000;ooooo0_l00003ooooo`;o
00001oooool2o`0006Cooooo000Looooo`03o`000?oooooooooo04cooooo1?l00011ooooo`;o0000
1?ooool3o`0000_ooooo0ol00004ooooo`oo000000?oooooo`000?l000001_l00002ooooo`?o0000
1oooool2o`0000?ooooo0_l00004ooooo`;o00001_ooool2o`000003ooooool0003o0000067ooooo
000Looooo`03o`000?oooooooooo04cooooo0_l0000/ooooo`;o00004Oooool3o`000003ooooool0
003o000000;o00000_ooool4o`0000Sooooo1?l00004oooooaWo00000_ooool2o`0000gooooo0_l0
0004ooooo`;o00001_ooool2o`000003ooooool0003o0000067ooooo000Looooo`03o`000?oooooo
oooo07[ooooo0_l0000Aooooo`So00000_ooool4o`0000?ooooo0_l00003ooooo`;o00001_oooolI
o`0000;ooooo0_l00003ooooo`;o00000oooool3o`0000;ooooo0_l00004ooooo`;o00001?ooool2
o`0006Kooooo000Looooo`03o`000?oooooooooo07[ooooo0_l00009ooooo`;o00001oooool8o`00
0004ooooool0003o0000o`0000Cooooo0_l0000;oooooa[o000000?oooooo`000?l000000_l00000
0ooooooo0000o`000002ooooo`Co00001oooool2o`0000Gooooo0_l0000=ooooo`;o0000Eoooool0
01cooooo00?o0000ooooooooool0N_ooool2o`0000Wooooo0_l00004ooooo`;o000000Goooooo`00
0?l0003o0000ooooo`08o`00017ooooo1?l000000ooooooo0000o`00000Co`000003ooooool0003o
000000;o000000Goooooo`000?l0003o0000ooooo`02o`0000Wooooo0_l0000=ooooo`?o00001?oo
ool2o`0005Oooooo000Looooo`03o`000?oooooooooo04Gooooo0_l0000cooooo`;o00003oooool4
o`0000?ooooo0_l00002ooooo`;o00002?ooool2o`0000Oooooo0_l00002ooooo`;o000000?ooooo
o`000?l000004ol00006ooooo`?o00006oooool3o`0000Gooooo1?l0001Dooooo`007?ooool00ol0
003oooooooooo`15ooooo`Co00000oooool2o`0002[ooooo0_l0000Aooooo`Co00000_ooool2o`00
00?ooooo0_l00008ooooo`;o00001oooool3o`000003ooooool0003o000001So00001?ooool2o`00
02Cooooo1?l0001Dooooo`007?ooool00ol0003oooooooooo`17ooooo`;o000000?oooooo`000?l0
00000_l0000Yooooo`?o00002_ooool2o`0000Cooooo1Ol00002ooooo`;o00000oooool2o`0000;o
oooo0_l0000=ooooob3o00000_ooool2o`0000Gooooo0_l00005ooooo`;o00009Oooool2o`0004Oo
oooo000Looooo`03o`000?oooooooooo04Gooooo1ol0000[ooooo`;o00002oooool2o`0000Cooooo
0_l00005ooooo`;o000000?oooooo`000?l000000_l000001?oooooo0000o`000?l0000<ooooo`?o
000000?oooooo`000?l000006ol00008ooooo`?o00001Oooool2o`00027ooooo0_l00002ooooo`;o
0000Aoooool001cooooo00?o0000ooooooooool0@Oooool3o`000003ooooool0003o000000?o0000
:?ooool2o`0001Kooooo0_l00005ooooo`;o000000?oooooo`000?l000000oooool2o`000003oooo
ool0003o000000Oooooo8?l000000ooooooo0000o`000003ooooo`;o00001?ooool2o`0000?ooooo
0_l0000Tooooo`;o0000Boooool001cooooo0_l00012ooooo`?o0000;_ooool2o`0002;ooooo0_l0
0004ooooo`;o00001oooool3o`0000;ooooo2ol000000ooooooo0000o`00000>o`0000Gooooo1?l0
0007ooooo`;o0000:oooool2o`0004Cooooo000Looooo`03o`000?oooooooooo04?ooooo0_l00008
ooooo`;o00002Oooool3o`0000Gooooo0_l000000ooooooo0000o`00000Qooooo`?o00003Oooool5
o`0000?ooooo0ol0000<oooooaWo00001oooool2o`0002gooooo0_l00004ooooo`?o0000A?ooool0
01cooooo00?o0000ooooooooool0@oooool2o`0000;ooooo0_l00002ooooo`Co00001Oooool2o`00
00;ooooo0ol00005ooooo`;o000000?oooooo`000?l000007?ooool3o`0000;ooooo0ol0000<oooo
o`Ko00000oooool3o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o
000001So0000:_ooool6o`0000Gooooo0_l00004ooooo`;o0000AOooool001cooooo00?o0000oooo
ooooool0@?ooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o00001oooool2o`00
0003ooooool0003o000000;o00001_ooool3o`0000?ooooo0_l00006ooooo`?o00000_ooool2o`00
00_ooooo0ol0000:ooooo`;o00001Oooool2o`0000;ooooo1?l00007ooooo`;o000000Coooooo`00
0?l0003ooooo7_l00008ooooo`;o00004Oooool2o`0000cooooo2?l00003ooooo`?o0000B_ooool0
01cooooo00?o0000ooooooooool0@?ooool2o`00013ooooo1?l000000ooooooo0000o`000002o`00
00Kooooo1Ol000000ooooooo0000o`000006ooooo`?o00000_ooool2o`0001Oooooo0ol00002oooo
o`;o00001oooool2o`0000Sooooo0ol00004oooooaoo00001Oooool3o`0000Wooooo0_l00005oooo
o`;o00003?ooool2o`0000Cooooo0_l00003ooooo`Co0000BOooool001cooooo00?o0000oooooooo
ool0>_ooool2o`0001Kooooo0_l0000;ooooo`;o000000?oooooo`000?l000000_l0000Wooooo`;o
00000oooool2o`0000?ooooo0_l0000<ooooo`?o00001?oooolHo`000003ooooool0003o000000Co
00001_ooool4o`0000Oooooo0_l0000Cooooo`;o00002oooool2o`0004Wooooo000Looooo`03o`00
0?oooooooooo03[ooooo0_l0000?ooooo`;o00003Oooool3o`000003ooooool0003o000000?o0000
0_ooool3o`0001;ooooo0ol0000Fooooo`;o00000_ooool2o`0000gooooo0_l00002oooooago0000
0_ooool2o`0000Kooooo1?l0000>ooooo`?o00006?ooool2o`0004Wooooo000Looooo`03o`000?oo
oooooooo04_ooooo0_l0000:ooooo`Ko000000?oooooo`000?l000002_l000000ooooooo0000o`00
0008ooooo`;o00000_ooool4o`0000Gooooo0_l00002ooooo`;o00001oooool2o`0000;ooooo0_l0
0006ooooo`;o00003OoooolEo`000003ooooool0003o000000Go00007?ooool3o`0001Cooooo0_l0
0002ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0@_ooool2o`0000Kooooo0_l0000;
ooooo`?o00001?ooool8o`000003ooooool0003o000000Co00002?ooool2o`0000;ooooo0_l00002
ooooo`Co000000?oooooo`000?l000000_ooool2o`0000;ooooo0ol00002ooooo`?o000000?ooooo
o`000?l000001_ooool2o`0000gooooo0_l00002oooooaSo00000oooool2o`0000;ooooo0ol0000Z
ooooo`;o00000_ooool3o`0000Cooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`12oooo
o`;o00001_ooool3o`0000Oooooo1Ol00007ooooo`_o00003Oooool2o`0000?ooooo1_l00006oooo
o`Go00000_ooool2o`000003ooooool0003o000001Gooooo0_l000000ooooooo0000o`000002oooo
o`Co000000?oooooo`000?l000002Ol00002ooooo`?o00000_ooool3o`0000;ooooo0ol0000^oooo
o`?o00001?ooool2o`0004;ooooo000Looooo`03o`000?oooooooooo04_ooooo0_l00007ooooo`?o
00000oooool3o`000003ooooool0003o000000_o00003Oooool2o`0000Gooooo1?l00006ooooo`_o
00000oooool3o`0000kooooo0_l00003ooooo`?o000000?oooooo`000?l000000_l000000ooooooo
0000o`000008o`0000?ooooo1ol0000dooooo`?o00001?ooool2o`0004;ooooo000Looooo`03o`00
0?oooooooooo04Gooooo0_l0000=ooooo`ko000000?oooooo`000?l000002?l00002ooooo`;o0000
3_ooool6o`0000Cooooo3?l00002ooooo`?o00003_ooool2o`0000?ooooo0ol00002ooooo`Go0000
0_ooool7o`0000Gooooo0ol00003ooooo`;o00000oooool4o`0000kooooo0_l0000Hooooo`Co0000
1?ooool2o`0004?ooooo000Looooo`03o`000?oooooooooo03oooooo0_l00004ooooo`;o00001Ooo
ool3o`0000Oooooo6ol000000ooooooo0000o`00000?ooooo`;o00001?ooool=o`000003ooooool0
003o000000Sooooo0_l0000:ooooo`Co000000?oooooo`000?l000001_l000001?oooooo0000o`00
0?l00003ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000002o`0000?ooooo
1?l00003ooooo`;o00000oooool2o`0000Cooooo0_l0000Hooooo`;o00001_ooool3o`0004;ooooo
000Looooo`03o`000?oooooooooo03oooooo0_l0000;ooooo`?o00000_ooool2o`0000;ooooo0_l0
0004oooooaWo00003Oooool2o`0000;ooooo0_l00003ooooo`co000000?oooooo`000?l000000_oo
ool2o`0000Cooooo0_l0000<ooooo`?o00000_ooool6o`000003ooooool0003o000000;o00000_oo
ool2o`000003ooooool0003o000000?ooooo0ol00005ooooo`?o00000oooool2o`0000;ooooo0ol0
000Wooooo`;o0000@_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo
0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo047ooooo0_l0000<ooooo`So0000
0ooooolJo`0000cooooo0ol00002ooooo`;o000000?oooooo`000?l000003?l00005ooooo`;o0000
0oooool2o`0000Kooooo1?l00004ooooo`[o000000?oooooo`000?l000000_l000000ooooooo0000
o`000002ooooo`;o00003?ooool2o`0000;ooooo0ol00002ooooo`;o00000_ooool2o`0001Gooooo
0_l0001Aooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo047ooooo0_l00002ooooo`;o00001Oooool2o`000005
ooooool0003o0000o`000?ooool00_l000000ooooooo0000o`00000Lo`0000Gooooo0_l00005oooo
o`;o00001Oooool?o`0000[ooooo0_l00006ooooo`Ko00000oooool9o`0000;ooooo0_l00002oooo
o`;o00000_ooool2o`0000_ooooo0_l000000ooooooo0000o`000002o`0000Oooooo0_l0000Doooo
o`Go0000Coooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool5o`0000Ko
oooo00?o0000ooooooooool0@oooool4o`0000Gooooo0_l00008oooooaoo00001?ooool2o`000003
ooooool0003o000000Cooooo0_l00002oooooa3o000000?oooooo`000?l000004oooool2o`0000Oo
oooo1ol00004ooooo`;o00003oooool2o`000003ooooool0003o000000gooooo0_l0000@ooooo`;o
000000?oooooo`000?l00000Coooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
2Oooool01?m4A4CogMgMooooool00007ooooo`?o0000@oooool3o`0000Cooooo0_l0000;oooooa_o
000000?oooooo`000?l000000oooool3o`000003ooooool0003o000000Cooooo0_l00002ooooo`Wo
000000?oooooo`000?l000000ol00002ooooo`;o000000?oooooo`000?l000000oooool2o`0001Co
oooo0_l00002ooooo`Co00003?ooool2o`0000Cooooo0_l0000<ooooo`;o00001?ooool2o`0006Co
oooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`1:ooooo`;o00002oooool2o`000003ooooool0003o000000co
000000?oooooo`000?l000002Ol00002ooooo`Co00000_ooool2o`0000Sooooo3ol00005ooooo`;o
00000oooool2o`0001Cooooo0ol00003ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Co
oooo0_l0000<ooooo`;o00001Oooool2o`0001?ooooo0ol0000;ooooo`;o0000@?ooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00omgMgOoc<c<o`000007ooooo`03o`00
0?oooooooooo04Oooooo1?l0000<oooooago000000Coooooo`000?l0003o00002?ooool2o`0000Co
oooo4Ol00003ooooo`;o00006_ooool2o`0000Kooooo0_l0000;ooooo`;o00001_ooool6o`0000_o
oooo0_l0000Cooooo`?o00000_ooool2o`0000;ooooo0_l00003ooooo`;o0000@?ooool00006oooo
oomgMgOoV9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo
04Oooooo1_l00009oooooako000000?oooooo`000?l000002?ooool4o`0000Gooooo3ol00003oooo
o`;o00008Oooool2o`0000cooooo0_l00006ooooo`Ko00001?ooool2o`0001_ooooo0ol000000ooo
oooo0000o`000002ooooo`;o0000AOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool0
0omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo04Sooooo0_l000000ooooooo0000o`000008
ooooob3o00002Oooool7o`0000?ooooo3Ol0000Xooooo`Ko00000_ooool2o`0000Cooooo0_l00005
ooooo`?o00000_ooool2o`0000Cooooo0_l00005ooooo`;o00005Oooool2o`0000_ooooo0_l0000o
ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00001?ooool5o`0000Gooooo0_l00003oooo
o`;o00000_oooolLo`000003ooooool0003o000000Kooooo0_l00003ooooo`;o00001Oooool6o`00
02?ooooo0ol00006ooooo`Oo00000_ooool2o`0000Cooooo0_l00004ooooo`Go00001_ooool2o`00
00Kooooo0_l0000Rooooo`;o0000?oooool001cooooo00?o0000ooooooooool0@?ooool2o`0000?o
oooo1_l00005ooooo`Co00000oooool2o`0000?ooooo5ol00003ooooo`;o00004?ooool3o`000003
ooooool0003o000000Co00002_ooool2o`000003ooooool0003o000000Sooooo0_l00008ooooo`?o
00001_ooool2o`0001?ooooo1Ol00006ooooo`;o00001_ooool2o`0001Wooooo1Ol00015ooooo`00
7?ooool00ol0003oooooooooo`15ooooo`Co00002Oooool2o`0000?ooooo1?l000000ooooooo0000
o`00000Fo`0000_ooooo0_l00007ooooo`?o00001?ooool3o`0000[ooooo1_l00007ooooo`;o0000
5oooool2o`00013ooooo0_l0000:ooooo`;o00007Oooool5o`0000Gooooo0_l0000nooooo`007?oo
ool00ol0003oooooooooo`0fooooo`;o00001oooool2o`00017ooooo0_l00005ooooo`;o00000_oo
oolDo`000003ooooool0003o000000;o00002Oooool4o`0000oooooo0_l00006ooooo`;o00000_oo
ool4o`0000[ooooo0_l0000Dooooo`;o00001?ooool2o`0000[ooooo0_l000001?oooooo0000o`00
0?ooool2o`0000Cooooo0ol0000Looooo`?o000000?oooooo`000?l000001?ooool2o`0003kooooo
000Looooo`03o`000?oooooooooo03Kooooo0_l00005ooooo`Co00002Oooool2o`0000;ooooo0_l0
0005ooooo`Ko00000_oooolDo`0000?ooooo0_l00009ooooo`Co00003oooool2o`0000Gooooo1_l0
000=ooooo`;o00005?ooool2o`000003ooooool0003o000000Go00002?ooool2o`000004ooooool0
003o0000ooooo`;o00001Oooool2o`0001cooooo0_l00002ooooo`?o0000@oooool001cooooo00?o
0000ooooooooool0?Oooool2o`0000_ooooo0_l00002ooooo`;o00001Oooool6o`0000Cooooo4_l0
000=ooooo`?o00006?ooool6o`00013ooooo0ol0000@ooooo`;o000000?oooooo`000?l000000_l0
00000ooooooo0000o`000008ooooo`Co00009oooool2o`0000;ooooo0ol00013ooooo`007?ooool0
0ol0003oooooooooo`1:ooooo`;o00002Oooool2o`0000Wooooo3_l000000ooooooo0000o`000005
ooooo`;o00001_ooool2o`0001Kooooo0_l00003ooooo`Go00003oooool3o`000003ooooool0003o
000000_ooooo1?l0000@ooooo`Ko00009Oooool2o`0000;ooooo0_l00014ooooo`007?ooool00ol0
003oooooooooo`0looooo`;o00002oooool2o`0000[ooooo0_l00009ooooo`?o000000?oooooo`00
0?l000002?l00008ooooo`;o000000?oooooo`000?l000000_l0000Iooooo`;o00000oooool5o`00
01?ooooo0_l0000;ooooo`;o00002_ooool2o`0000Sooooo1_l0000Rooooo`;o00000_ooool2o`00
017ooooo0_l0000booooo`007?ooool00ol0003oooooooooo`0cooooo`;o00001?ooool2o`000003
ooooool0003o000000_ooooo0_l00003ooooo`;o00001?ooool3o`0000Wooooo0_l000001?oooooo
0000o`000?l00004ooooo`;o00002?ooool2o`0000?ooooo1?l0000Fooooo`;o00001Oooool2o`00
00;ooooo0_l0000Wooooo`?o00000_ooool4o`0000?ooooo3?l00002ooooo`;o00006oooool2o`00
00;ooooo0_l0000Aooooo`;o0000<_ooool001cooooo00?o0000ooooooooool0<oooool2o`0000?o
oooo0ol000000ooooooo0000o`00000@ooooo`;o00001?ooool2o`0000gooooo0_l0000<ooooo`;o
000000?oooooo`000?l000006Oooool2o`000004ooooool0003o0000o`0000Cooooo0ol00002oooo
o`;o00007Oooool2o`0000Sooooo0ol00004ooooo`?o00000_ooool3o`0000;ooooo1ol00002oooo
o`;o00000_ooool2o`0001Oooooo0_l0000;ooooo`Co0000>_ooool001cooooo00?o0000oooooooo
ool0>?ooool2o`0001Gooooo0_l0000?ooooo`;o00003oooool2o`0000Kooooo0_l0000;ooooo`;o
00001oooool2o`000003ooooool0003o000000;o00000oooool3o`0000Cooooo0_l0000Kooooo`?o
00003oooool2o`0000?ooooo0_l00004ooooo`So00000oooool2o`0001Oooooo0_l0000;ooooo`Co
0000>_ooool001cooooo0_l0001@ooooo`;o00003oooool3o`0000Cooooo0_l0000=ooooo`;o0000
00?oooooo`000?l000002oooool4o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l00000
3?l0000Eooooo`?o000000?oooooo`000?l000000_ooool2o`0001Sooooo1_l00003ooooo`;o0000
5oooool2o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`?o0000>oooool001cooooo00?o
0000ooooooooool0>oooool2o`0000[ooooo0_l0000>ooooo`;o00001oooool3o`0000Cooooo0_l0
000=ooooo`?o00003oooool2o`0000Cooooo0_l00002ooooo`Co000000?oooooo`000?l000001ol0
00000ooooooo0000o`000004o`0001?ooooo0ol00005ooooo`;o00002_ooool2o`0001Gooooo0_l0
000Gooooo`;o00000_ooool2o`000003ooooool0003o000000Cooooo0_l0000looooo`007?ooool0
0ol0003oooooooooo`0gooooo`;o00000_ooool2o`0000?ooooo1?l00003ooooo`Oo00001Oooool2
o`000003ooooool0003o000000?o00001Oooool2o`0001Gooooo0_l0000@ooooo`;o00000oooool2
o`0000;ooooo1?l00004ooooo`;o000000?oooooo`000?l000001?l00002ooooo`;o00003?ooool2
o`0001Wooooo0_l0000booooo`Co00001?ooool2o`0003gooooo000Looooo`03o`000?oooooooooo
03Oooooo0_l00007ooooo`Co00001?ooool6o`0000Gooooo0_l000001?oooooo0000o`000?ooool2
o`0001Wooooo0_l00003ooooo`;o00003_ooool2o`0000Oooooo0ol00005ooooo`?o00000_ooool3
o`00017ooooo0_l0001?ooooo`?o00000oooool2o`0003gooooo000Looooo`03o`000?oooooooooo
03Gooooo0_l0000Dooooo`;o00001_ooool2o`000003ooooool0003o000000Cooooo0_l0000Foooo
o`;o00000oooool2o`000003ooooool0003o000000cooooo0_l00006ooooo`?o00000oooool2o`00
0005ooooool0003o0000o`000?ooool01Ol0000Looooo`;o00001_ooool2o`00017ooooo0_l00006
ooooo`;o00000_ooool2o`0001cooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`0doooo
o`?o00005Oooool2o`0000?ooooo0_l00003ooooo`?o00000oooool2o`0001Oooooo0_l00005oooo
o`Co00002Oooool3o`0000?ooooo0_l00004ooooo`Go00000_ooool2o`000003ooooool0003o0000
00?o00007?ooool2o`0000Cooooo1?l0000Aooooo`;o00001_ooool2o`0000;ooooo0ol0001Ooooo
o`007?ooool00ol0003oooooooooo`0dooooo`;o00000oooool2o`0000Oooooo0_l00008ooooo`;o
00000oooool4o`0000;ooooo0_l0000Eooooo`;o00001Oooool2o`0000Gooooo1?l00005ooooo`?o
000000?oooooo`000?l000001?ooool4o`0000;ooooo0ol00005ooooo`Co00002?ooool2o`0000[o
oooo0_l0000?ooooo`;o00004_ooool2o`0000cooooo0_l0000Oooooo`;o00002Oooool2o`0003?o
oooo000Looooo`03o`000?oooooooooo03Sooooo0ol00007ooooo`;o00002?ooool2o`0000Gooooo
0ol0000Hooooo`;o00003?ooool3o`0000;ooooo0_l00002ooooo`?o00002Oooool2o`0000Gooooo
0_l000000ooooooo0000o`000004o`0000Oooooo0ol00003ooooo`;o00001Oooool2o`000003oooo
ool0003o000000Kooooo0_l000001?oooooo0000o`000?ooool2o`0001;ooooo0_l00007ooooo`;o
00005_ooool2o`0000_ooooo0ol00009ooooo`;o0000<oooool001cooooo00?o0000ooooooooool0
>?ooool2o`000003ooooool0003o000001Oooooo1?l00005ooooo`;o00002_ooool2o`00013ooooo
1?l00002ooooo`;o00000oooool6o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`So0000
2Oooool2o`0000?ooooo1Ol000000ooooooo0000o`000003ooooo`;o00001?ooool4o`000003oooo
ool0003o000000cooooo0_l0000@ooooo`;o00005_ooool4o`0000Wooooo0_l0000:ooooo`;o0000
<oooool001cooooo00?o0000ooooooooool0>oooool2o`0001Sooooo1Ol00003ooooo`;o00002_oo
ool4o`0000;ooooo0_l0000:ooooo`;o00001?ooool4o`0000;ooooo1Ol00002ooooo`;o00001?oo
ool2o`000003ooooool0003o000000Go00003oooool2o`000004ooooool0003o0000ooooo`;o0000
0oooool2o`0000Cooooo0_l00005ooooo`;o00000_ooool3o`0000Gooooo0_l0000Zooooo`;o0000
2Oooool2o`0003oooooo000Looooo`03o`000?oooooooooo03kooooo0_l0000Gooooo`Co00003?oo
ool2o`0000;ooooo0_l00002ooooo`;o00004_ooool2o`0000Sooooo0ol00004ooooo`;o00000_oo
ool6o`0000cooooo0_l00003ooooo`;o00000_ooool2o`0000[ooooo0_l00004ooooo`Oo000000?o
ooooo`000?l000000_l0000Looooo`;o00005?ooool3o`0000?ooooo1?l0000looooo`007?ooool0
0ol0003oooooooooo`0nooooo`;o00005oooool4o`0000cooooo0ol00005ooooo`Co00001Oooool2
o`000003ooooool0003o000000Cooooo0_l00005ooooo`;o00000_ooool4o`0000Kooooo1Ol0000>
ooooo`?o00000oooool2o`0000?ooooo0_l00009ooooo`;o00001?ooool5o`0000?ooooo1?l0000L
ooooo`;o00005?ooool3o`0000?ooooo1?l0000looooo`007?ooool00ol0003oooooooooo`1Eoooo
o`;o00001_ooool2o`0000Sooooo0ol00005ooooo`Co00001?ooool3o`000003ooooool0003o0000
00Cooooo1?l00003ooooo`;o00000_ooool2o`0000Kooooo1ol00003ooooo`;o00001oooool4o`00
00Sooooo0ol0000;ooooo`?o000000?oooooo`000?l000001Ol0000Qooooo`;o0000F_ooool001co
oooo00?o0000ooooooooool0>?ooool2o`0000Oooooo0_l0000Booooo`;o00001_ooool2o`0000;o
oooo0_l00004ooooo`;o00002Oooool2o`000003ooooool0003o000000;o00001oooool7o`000005
ooooool0003o0000o`000?ooool00_l000000ooooooo0000o`000007o`0000Kooooo0_l00003oooo
o`?o000000Coooooo`000?l0003o00002Oooool2o`0000Kooooo2Ol000000ooooooo0000o`000006
o`0001Kooooo0_l00004ooooo`;o00000_ooool2o`0000cooooo0_l0001<ooooo`007?ooool00ol0
003oooooooooo`0hooooo`;o00001oooool2o`00013ooooo0ol0000;ooooo`;o00001_ooool2o`00
00Oooooo0_l000000ooooooo0000o`000009ooooo`Oo00000_ooool2o`0000Cooooo2?l00004oooo
o`;o00001_ooool3o`0000?ooooo0_l0000<ooooo`[o00001?ooool<o`0000;ooooo1?l0000<oooo
o`;o00001?ooool2o`0000;ooooo0_l0000<ooooo`;o00003?ooool2o`0003kooooo000Looooo`03
o`000?oooooooooo03Sooooo1?l00005ooooo`;o00004?ooool3o`0000cooooo0_l00002ooooo`;o
000000?oooooo`000?l000003oooool2o`0000Kooooo0_l0000<ooooo`Co000000?oooooo`000?l0
00000_ooool4o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`;o00001_ooool2o`0000?o
oooo1ol000000ooooooo0000o`000002o`0000;ooooo0_l00002ooooo`Wo00000_ooool4o`0000_o
oooo0_l00005ooooo`;o00006?ooool2o`0000;ooooo1?l0000nooooo`007?ooool2o`0003_ooooo
1?l00003ooooo`;o00007oooool2o`0000;ooooo0ol0000Aooooo`;o00001?ooool4o`0000cooooo
1_l00003ooooo`;o00001_ooool2o`000003ooooool0003o000000Kooooo0_l00003ooooo`;o0000
0oooool6o`0000;ooooo1Ol000001Ooooooo0000o`000?l0003ooooo00Go000000Coooooo`000?l0
003o00000_ooool5o`0000[ooooo0_l00005ooooo`Co00002oooool2o`0000Sooooo0ol00002oooo
o`;o0000@?ooool001cooooo00?o0000ooooooooool0??ooool2o`0000Sooooo0ol0000Mooooo`Co
000000?oooooo`000?l000000_l00007ooooo`;o00000_ooool2o`0000Cooooo0_l00002ooooo`;o
00002?ooool4o`000003ooooool0003o000000?o00001?ooool2o`000003ooooool0003o000000?o
oooo0_l00006ooooo`;o00001_ooool2o`0000;ooooo1?l00003ooooo`Co000000?oooooo`000?l0
00003_l00002ooooo`;o00004Oooool4o`0000;ooooo0_l00006ooooo`?o00002?ooool2o`0000;o
oooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0looooo`?o00001oooool3o`000003oooo
ool0003o000001[ooooo1?l000000ooooooo0000o`000002o`000003ooooool0003o000000Cooooo
0_l000001?oooooo0000o`000?l00008ooooo`Co00001Oooool5o`0000Cooooo0_l00002ooooo`Co
000000?oooooo`000?l000000oooool2o`0000gooooo2Ol000000ooooooo0000o`000003o`0000;o
oooo4?l000001?oooooo0000o`000?ooool3o`0001;ooooo1?l00006ooooo`;o00003Oooool2o`00
047ooooo000Looooo`03o`000?oooooooooo03Kooooo1?l00003ooooo`;o00002oooool2o`0002Co
oooo0ol000000ooooooo0000o`000002o`000003ooooool0003o000000?o000000?oooooo`000?l0
00001Oooool2o`0000Gooooo1?l00007ooooo`Go000000Coooooo`000?l0003ooooo0_l0000?oooo
o`Ko00000_ooool2o`000003ooooool0003o000000Go00000_ooool9o`000003ooooool0003o0000
00Go000000Coooooo`000?l0003o00000_ooool2o`0000Kooooo0_l00006ooooo`;o00003?ooool2
o`0000Gooooo0_l00002ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0=_ooool4o`00
00?ooooo0ol0000aooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000003o`00
0004ooooool0003o0000o`0000gooooo0_l00007ooooo`;o00001?ooool2o`000003ooooool0003o
000000kooooo1ol00003ooooo`Go000000Goooooo`000?l0003o0000ooooo`0=o`000004ooooool0
003o0000o`0000?ooooo1_l00006ooooo`;o00005?ooool2o`0000Gooooo0_l00008ooooo`;o0000
1Oooool2o`0003Cooooo000Looooo`03o`000?oooooooooo03Oooooo0ol00004ooooo`;o0000??oo
ool6o`0000kooooo0ol00003ooooo`;o00001Oooool3o`0000;ooooo0_l00003ooooo`;o00000ooo
ool2o`0000?ooooo1ol00003ooooo`So00000_ooool7o`000003ooooool0003o000000;o00001ooo
ool6o`0002Oooooo0_l00005ooooo`;o00001Oooool2o`0003Cooooo000Looooo`03o`000?oooooo
oooo03_ooooo0_l000000ooooooo0000o`00000dooooo`Co00001_ooool3o`0000oooooo1Ol00000
0ooooooo0000o`000005ooooo`;o00000oooool2o`0000?ooooo3_l00004ooooo`_o000000?ooooo
o`000?l000002ol00002ooooo`;o00000_ooool5o`0001Wooooo0_l0000=ooooo`;o0000@_ooool0
01cooooo00?o0000ooooooooool0=oooool2o`0000;ooooo0_l000000ooooooo0000o`000002oooo
o`;o0000:oooool2o`0000?ooooo1?l00006ooooo`?o00003_ooool2o`0000;ooooo0_l00004oooo
o`;o00000_ooool2o`0000Sooooo3_l00002ooooo`So000000?oooooo`000?l000000_l000000ooo
oooo0000o`00000<o`000003ooooool0003o000000Wo00005oooool2o`0000[ooooo0_l0000=oooo
o`;o0000=_ooool001cooooo00?o0000ooooooooool0=oooool2o`000003ooooool0003o000000Ko
oooo1?l0000Yooooo`;o00002oooool3o`000003ooooool0003o000000gooooo0_l00008ooooo`?o
00000_ooool2o`0000Oooooo0_l00002ooooo`?o000000?oooooo`000?l000001?l000000ooooooo
0000o`000007o`000003ooooool0003o000000Ko000000?oooooo`000?l000003_l00003ooooo`Co
00001oooool2o`0000kooooo0_l00009ooooo`;o00003Oooool2o`0003Kooooo000Looooo`03o`00
0?oooooooooo03Sooooo1ol00005ooooo`;o0000;?ooool3o`0000Oooooo0ol000000ooooooo0000
o`000003ooooo`;o00004_ooool3o`0000;ooooo0ol00006ooooo`;o00000_ooool2o`0000Cooooo
1?l000000ooooooo0000o`00000?o`000003ooooool0003o000000ko00001_ooool3o`0000Gooooo
0ol0000>ooooo`;o00004_ooool2o`0003cooooo000Looooo`03o`000?oooooooooo033ooooo0_l0
0006ooooo`Oo000000?oooooo`000?l00000<?ooool3o`0000Sooooo0_l000000ooooooo0000o`00
0003ooooo`;o00004Oooool4o`0000?ooooo0_l00006ooooo`;o000000Coooooo`000?l0003o0000
1?oooolIo`000003ooooool0003o000000_o00001oooool2o`0000Gooooo0_l0000Hooooo`?o0000
2?ooool2o`0003cooooo000Looooo`03o`000?oooooooooo033ooooo0_l00008ooooo`Go000000?o
ooooo`000?l00000Doooool2o`000003ooooool0003o000000Gooooo0_l00008ooooo`?o00001Ooo
oolUo`0000Wooooo0ol00004ooooo`;o000000?oooooo`000?l000004?ooool2o`0000?ooooo0ol0
0016ooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o000000?oooooo`000?l000001?ooool6
o`0005Kooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0ol00007ooooo`;o000000?o
ooooo`000?l000000oooool?o`0000?ooooo4ol00004ooooo`;o00000oooool3o`0000Cooooo1Ol0
00000ooooooo0000o`000007ooooo`;o00001?ooool2o`0000[ooooo0_l00006ooooo`;o0000>?oo
ool001cooooo00?o0000ooooooooool0<oooool2o`0000Cooooo0_l000000ooooooo0000o`00000`
ooooo`;o00004_ooool2o`00017ooooo0_l00004ooooo`;o00000_ooool3o`0000;ooooo0_l00006
ooooo`;o00000oooool<o`000003ooooool0003o000001Go00001Oooool2o`0000;ooooo1_l00004
ooooo`;o00000_ooool3o`0000Kooooo0_l0000@ooooo`;o00001_ooool2o`0003Sooooo000Loooo
o`03o`000?oooooooooo03Kooooo0_l00004ooooo`;o000000?oooooo`000?l00000;Oooool2o`00
01;ooooo0_l0000Looooo`;o00000_ooool3o`0000Cooooo0_l00003ooooo`go000000?oooooo`00
0?l000005ol00002ooooo`?o00000_ooool6o`0000Cooooo0_l00002ooooo`Go0000F?ooool001co
oooo00?o0000ooooooooool0=_ooool2o`0000Cooooo0_l000000ooooooo0000o`000012ooooo`;o
000000?oooooo`000?l000006?ooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`00
00;ooooo1?l000000ooooooo0000o`00000Qo`0000;ooooo0_l00007ooooo`;o00001?ooool2o`00
00Cooooo0ol00006ooooo`;o000000?oooooo`000?l000003Oooool2o`0003kooooo000Looooo`;o
0000=oooool2o`0000Cooooo0_l0000Sooooo`;o00002Oooool2o`0000Gooooo0_l00004ooooo`;o
00002?ooool2o`000003ooooool0003o000001Oooooo0_l00003ooooo`;o00000_ooool2o`0000Go
oooo1?l000000ooooooo0000o`00000Uo`000003ooooool0003o000000?ooooo0ol00005ooooo`;o
00002_ooool4o`000003ooooool0003o000000gooooo0_l00002ooooo`;o0000>_ooool001cooooo
00?o0000ooooooooool0=Oooool3o`0002Wooooo0_l00009ooooo`;o00000_ooool2o`000004oooo
ool0003o0000o`0000?ooooo0ol00007ooooo`;o00006_ooool2o`0000?ooooo1_l00007ooooo`;o
000000?oooooo`000?l00000:_l000000ooooooo0000o`000002ooooo`;o00000_ooool2o`0000[o
oooo0_l00003ooooo`;o00004Oooool2o`0003[ooooo000Looooo`03o`000?oooooooooo03Gooooo
0_l0000;ooooo`;o00007Oooool2o`000003ooooool0003o000000Sooooo1?l00002ooooo`;o0000
1?ooool2o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o0000
1oooool2o`0000oooooo0ol0000;ooooobWo000000?oooooo`000?l000001Oooool3o`0000cooooo
0_l00004ooooo`;o0000COooool001cooooo00?o0000ooooooooool0=?ooool3o`0000_ooooo0_l0
000Mooooo`;o000000Coooooo`000?l0003o00001oooool4o`0000gooooo0_l00005ooooo`Co0000
0_ooool2o`000003ooooool0003o000000Cooooo0_l00006ooooo`Go00004_oooolXo`0000Cooooo
0_l00004ooooo`;o00003?ooool2o`0001Kooooo0_l0000kooooo`007?ooool00ol0003ooooooooo
o`0^ooooo`;o00001?ooool3o`0002_ooooo0_l000000ooooooo0000o`000002o`0000[ooooo0_l0
000;ooooo`;o00001?ooool3o`0000Kooooo0_l00003ooooo`;o00001oooool5o`0000oooooo0_l0
0002ooooob?o000000?oooooo`000?l000001Oooool2o`0001Gooooo0_l00007ooooo`;o00001Ooo
ool3o`0000;ooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o0000<_ooool3
o`0000;ooooo1?l00008ooooo`;o00002oooool2o`000003ooooool0003o000000Co00002oooool2
o`0001Cooooo0_l00005ooooo`?o000000?oooooo`000?l000009?l0000:ooooo`;o00001oooool2
o`0000Oooooo0_l00007ooooo`;o00001Oooool3o`0003oooooo000Looooo`03o`000?oooooooooo
06;ooooo0ol00004ooooo`;o00000oooool2o`0000Cooooo0_l00006ooooo`;o00001Oooool4o`00
00Oooooo0_l0000Jooooo`;o00001Oooool3o`000003ooooool0003o000002;o000000Coooooo`00
0?l0003o00002?ooool2o`0000Oooooo1?l0001Gooooo`007?ooool00ol0003oooooooooo`1Roooo
o`;o00000_ooool3o`0000Gooooo1Ol000000ooooooo0000o`000006ooooo`;o00001?ooool5o`00
00Oooooo0_l0000=ooooo`;o000000?oooooo`000?l000003oooool3o`000003ooooool0003o0000
00;o000000?oooooo`000?l000008ol00008ooooo`;o00000_ooool2o`000003ooooool0003o0000
00;o000000?oooooo`000?l00000E?ooool001cooooo00?o0000ooooooooool0:oooool2o`0003Oo
oooo1ol00002ooooo`Ko00003oooool5o`0000Oooooo0_l0000;ooooo`Co000000?oooooo`000?l0
00003oooool2o`0000;ooooo9Ol00002ooooo`Go00001_ooool2o`0000;ooooo0_l00002ooooo`?o
000000Coooooo`000?l0003o00004_ooool2o`0003oooooo000Looooo`03o`000?oooooooooo02_o
oooo0_l00009ooooo`;o0000:_ooool?o`0000Cooooo0ol00009ooooo`;o000000Coooooo`000?l0
003o00000oooool2o`0000;ooooo0ol0000:ooooo`;o000000Coooooo`000?l0003ooooo0_l0000?
ooooobGo00001Oooool7o`0000cooooo0ol00002ooooo`;o00004_ooool2o`0003oooooo000Loooo
o`03o`000?oooooooooo02_ooooo0_l00009ooooo`;o00009oooool8o`000003ooooool0003o0000
00Oo00001?ooool3o`0000?ooooo0_l00002ooooo`Go00001_ooool2o`0000?ooooo0_l0000=oooo
o`;o000000?oooooo`000?l000001?ooool3o`0000Sooooo1?l00002oooooako00001?ooool6o`00
0004ooooool0003o0000ooooo`;o00000_ooool2o`0000?ooooo1Ol00003ooooo`;o00000_ooool2
o`0000[ooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o0000<OoooolDo`00
00?ooooo0_l00003ooooo`?o00000_ooool7o`00027ooooo0ol00008ooooo`Co000000Goooooo`00
0?l0003o0000ooooo`0No`000003ooooool0003o000000?o00001Oooool2o`0000;ooooo0_l00003
ooooo`?o00000_ooool2o`000003ooooool0003o000000;ooooo0_l00008ooooo`Co0000@_ooool0
01cooooo00?o0000ooooooooool0=?ooool2o`0002?ooooo1?l000000ooooooo0000o`00000Co`00
00;ooooo0_l00003ooooo`;o00001Oooool2o`000003ooooool0003o000000[ooooo0_l0000@oooo
o`;o00000_ooool2o`0000[ooooo1ol00002ooooobKo00000oooool2o`0000Kooooo0_l00004oooo
o`;o00003oooool2o`000003ooooool0003o0000047ooooo000Looooo`03o`000?oooooooooo03Co
oooo0_l0000Aooooo`;o00003OoooolMo`0000cooooo1?l0000=ooooo`;o00004?ooool2o`0000;o
oooo0_l0000;ooooo`Go00000ooooolXo`0000Wooooo0_l0000;ooooo`;o00001oooool2o`0000;o
oooo0_l00011ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^
k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0Aoooool2o`0000cooooo8_l00007
ooooo`Co00009oooool2o`0000Wooooo1?l000000ooooooo0000o`000004o`0000;ooooo6Ol00007
ooooo`;o00001?ooool2o`0000;ooooo0_l0000<ooooo`;o00001oooool2o`0000[ooooo0_l0000i
ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooo
oonHV9So8B4Q00Kooooo00?o0000ooooooooool0EOoooolAo`000003ooooool0003o000000ko0000
1oooool4o`0001_ooooo0_l00003ooooo`Go00000_ooool2o`0000Kooooo0_l00003ooooo`;o0000
00Coooooo`000?l0003ooooo7?l00003ooooo`;o00002_ooool2o`000003ooooool0003o000000?o
00001oooool2o`0001Kooooo0_l0000iooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooo
ooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`11ooooo`;o
00004?ooool2o`0000;ooooo3ol000000ooooooo0000o`00000<o`0000[ooooo1Ol0000Iooooo`;o
000000?oooooo`000?l000002?l00007ooooo`;o00000_ooool2o`0000Sooooo0_l000000ooooooo
0000o`000008o`0000;ooooo2_l00003ooooo`;o000000?oooooo`000?l000002_ooool5o`000003
ooooool0003o000000Cooooo0_l00008ooooo`;o00001oooool2o`0003kooooo00000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o
0000;?ooool2o`0000Wooooo1?l00006ooooo`;o00004?ooool3o`0000?ooooo5_l000000ooooooo
0000o`000003o`0000[ooooo0_l000000ooooooo0000o`00000<ooooo`;o00000oooool2o`0000Wo
oooo0_l00004ooooo`Co00001Oooool2o`0000Cooooo1?l000000ooooooo0000o`000006ooooo`So
00000oooool5o`0000_ooooo1Ol00004ooooo`;o00001?ooool2o`0000;ooooo0_l00009ooooo`;o
00000_ooool3o`0000Oooooo0_l0000nooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooo
ooooo`09ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0/ooooo`;o
00002Oooool4o`0001Wooooo0_l00003oooooaco00002Oooool4o`0000kooooo0_l00003ooooo`;o
00000_ooool2o`0000Kooooo0_l00008ooooo`;o00000_ooool2o`0000Cooooo1ol00005ooooo`?o
000000?oooooo`000?l000000_l00004ooooo`Go00000oooool2o`0000Kooooo1Ol00003ooooo`Co
00000oooool4o`0000;ooooo0_l00007ooooo`;o00000_ooool2o`0004Sooooo00000ooooooo410@
ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003ooooo
ooooo`1Dooooo`;o00000ooooolNo`0000Kooooo1Ol0000Gooooo`;o00000oooool2o`000003oooo
ool0003o000000Oooooo0ol0000<ooooo`Ko00000_ooool3o`000003ooooool0003o000000Sooooo
0_l00004ooooo`;o00000oooool2o`0000?ooooo0_l00004ooooo`Co00001Oooool2o`0000;ooooo
0_l0000;ooooo`;o0000B?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo
410@oiRHV008ooooo`03o`000?oooooooooo05Oooooo7Ol000000ooooooo0000o`000006ooooo`Go
00007?ooool2o`0000Cooooo0_l00004ooooo`Ko00002oooool5o`0000[ooooo0_l00003ooooo`;o
00002Oooool2o`0000Sooooo0_l000000ooooooo0000o`000002ooooo`;o00003oooool2o`0000co
oooo0_l0000mooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co0000
oa0@40Kooooo00?o0000ooooooooool0D_ooool4o`000003ooooool0003o000000;o000000?ooooo
o`000?l000006?l00007ooooo`;o000000?oooooo`000?l000007oooool2o`000003ooooool0003o
000000Kooooo1?l00009ooooo`;o000000?oooooo`000?l000000_l00009ooooo`?o00000oooool2
o`0000Oooooo1?l00007ooooo`?o000000?oooooo`000?l000000_ooool2o`0000Wooooo0ol00002
ooooo`?o00001oooool2o`0000?ooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`1Boooo
o`Co000000?oooooo`000?l000005ol000000ooooooo0000o`000003o`0000Oooooo0_l0000;oooo
o`;o00000_ooool2o`0000_ooooo0_l00004ooooo`;o00005_ooool4o`000004ooooool0003o0000
ooooo`Co00001?ooool2o`0000Wooooo1_l00009ooooo`Co00003oooool9o`0000Kooooo0_l00002
ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0Doooool3o`000003ooooool0003o0000
00Co000000?oooooo`000?l000002_l000000ooooooo0000o`000002o`0000;ooooo1?l000000ooo
oooo0000o`00000Booooo`;o00000_ooool2o`0000Kooooo0_l00003ooooo`;o00001?ooool2o`00
00gooooo1Ol00006ooooo`;o00001?ooool4o`0000;ooooo0_l0000;ooooo`Co00001_ooool3o`00
00Cooooo0_l0000Aooooo`?o00000_ooool2o`0000[ooooo0_l0000nooooo`007?ooool00ol0003o
ooooooooo`10ooooo`;o00004Oooool2o`0000;ooooo7Ol00002ooooo`;o00000oooool4o`0000_o
oooo0_l00002ooooo`;o00001_ooool2o`0001Kooooo1ol0000<ooooo`Wo00004_ooool5o`0000co
oooo0_l00004ooooo`;o00001Oooool2o`0004gooooo000Looooo`03o`000?oooooooooo03gooooo
0_l000000ooooooo0000o`00000@ooooo`;o00001OoooolJo`0000Sooooo1?l0000:ooooo`;o0000
0oooool2o`0000Kooooo0_l0000Fooooo`Ko00003Oooool3o`000003ooooool0003o000000?o0000
1oooool2o`0000;ooooo0_l00002ooooo`So00003?ooool2o`0000Cooooo0_l00005ooooo`;o0000
COooool001cooooo00?o0000ooooooooool0?Oooool2o`0001?ooooo1?l00002oooooa[o00005ooo
ool2o`0002Cooooo0ol00002ooooo`?o00003_ooool2o`0000?ooooo0_l00005ooooo`;o00000_oo
ool2o`000003ooooool0003o000000;o000000?oooooo`000?l000000_l0000?ooooo`;o00001ooo
ool2o`000003ooooool0003o000004_ooooo000Looooo`03o`000?oooooooooo05Cooooo0_l00002
oooooago00007?ooool2o`0001?ooooo0_l00007ooooo`So00002_ooool2o`0000Oooooo0_l0000<
ooooo`?o00000_ooool4o`0000Cooooo0_l00008ooooo`?o00000oooool6o`000003ooooool0003o
000004_ooooo000Looooo`03o`000?oooooooooo05Oooooo7_l0000Jooooo`Co00000_ooool2o`00
00oooooo0ol00008ooooo`?o00003Oooool2o`0000Sooooo1Ol000000ooooooo0000o`000002o`00
00[ooooo0_l00002ooooo`Co00001oooool3o`0000Cooooo1?l0001@ooooo`007?ooool00ol0003o
ooooooooo`1?ooooo`;o000000?oooooo`000?l000000ooooolCo`000003ooooool0003o000000Ko
00007?ooool3o`0000?ooooo0_l00005ooooo`?o00002?ooool2o`0000_ooooo0_l00003ooooo`;o
00001?ooool2o`0000[ooooo1Ol000000ooooooo0000o`000002o`0000kooooo0_l00002ooooo`;o
00000_ooool2o`000003ooooool0003o000000;o00000_ooool4o`00057ooooo000Looooo`03o`00
0?oooooooooo03oooooo0_l0000>ooooo`;o000000?oooooo`000?l000001ooooolGo`0000Oooooo
0_l000000ooooooo0000o`00000;ooooo`;o00001Oooool2o`0000?ooooo0_l00005ooooo`?o0000
5Oooool3o`0000;ooooo0_l00004ooooo`;o00001Oooool3o`0001Kooooo0_l00005ooooo`?o0000
0_ooool7o`0000;ooooo1?l0001Aooooo`007?ooool00ol0003oooooooooo`0looooo`;o000000?o
ooooo`000?l000003_ooool2o`0000Kooooo0ol000001Ooooooo0000o`000?l0003ooooo00Co0000
00?oooooo`000?l000002Ol000000ooooooo0000o`000004ooooo`;o000000Coooooo`000?l0003o
oooo1?l00003ooooo`;o00000_ooool4o`0001Kooooo0_l0000>ooooo`;o00000_ooool2o`0000oo
oooo0ol00002ooooo`Co00001?ooool2o`0000[ooooo0_l00005ooooo`?o00001?ooool3o`0000?o
oooo0ol0001Cooooo`007?ooool00ol0003oooooooooo`0looooo`;o00001Oooool2o`0001;ooooo
0ol00002oooooaKo00001?ooool2o`0000Kooooo0_l00003ooooo`;o00000_ooool3o`00017ooooo
0_l00004ooooo`;o00001Oooool2o`0000Oooooo0_l0000:ooooo`;o00001Oooool4o`0000?ooooo
1?l00002ooooo`Co00002_ooool2o`0000Kooooo0_l000000ooooooo0000o`000006ooooo`?o0000
E?ooool001cooooo0_l0000mooooo`;o00001Oooool2o`0001Kooooo4Ol00002ooooo`;o00004Ooo
ool2o`0000Gooooo0_l0000?ooooo`Co00002?ooool2o`000004ooooool0003o0000o`0000_ooooo
0_l00005ooooo`;o00001Oooool4o`0000;ooooo1Ol00002ooooo`;o00000_ooool2o`0000Sooooo
0_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o0000
EOooool001cooooo00?o0000ooooooooool0@_ooool3o`0000Sooooo0_l00005ooooo`;o00001Ooo
ool4o`000003ooooool0003o000000Oo00003?ooool2o`0000[ooooo0_l0000Aooooo`;o00000_oo
ool5o`0000Sooooo0_l000001?oooooo0000o`000?l0000;ooooo`;o00000_ooool2o`000003oooo
ool0003o000000;o00001?ooool2o`0000?ooooo0_l00009ooooo`;o00002oooool2o`0000;ooooo
0ol00003ooooo`;o0000Foooool001cooooo00?o0000ooooooooool0@_ooool3o`0000Sooooo1?l0
0003ooooo`;o00001?ooool2o`0000Cooooo2?l00008ooooo`;o00000oooool2o`0001Sooooo0_l0
0002ooooo`Oo000000?oooooo`000?l000001_ooool2o`0000?ooooo0ol0000?ooooo`;o00000ooo
ool2o`0002Cooooo0ol0001Qooooo`007?ooool00ol0003oooooooooo`1?ooooo`;o00002Oooool2
o`0000Cooooo1?l000001?oooooo0000o`000?l00008ooooo`;o000000?oooooo`000?l000006_oo
ool2o`000003ooooool0003o000000Go00001?ooool2o`0000;ooooo1Ol00004ooooo`;o00003_oo
ool2o`0000Wooooo0_l0000Nooooo`?o0000HOooool001cooooo00?o0000ooooooooool0C_ooool2
o`0002?ooooo0_l00003ooooo`?o00004Oooool2o`0000Cooooo0ol000000ooooooo0000o`000005
ooooo`[o000000?oooooo`000?l000000_l0000:ooooo`;o00001_ooool2o`0000Gooooo0_l0000N
ooooo`;o0000H_ooool001cooooo00?o0000ooooooooool0AOooool2o`0000Oooooo0_l0000Aoooo
o`;o00005Oooool4o`00013ooooo0_l00005ooooo`Go00001oooool2o`000003ooooool0003o0000
00?o000000?oooooo`000?l000000ol00006ooooo`;o000000?oooooo`000?l000000_l00004oooo
o`;o00001Oooool2o`0001Gooooo1?l000000ooooooo0000o`000002ooooo`;o0000H_ooool001co
oooo00?o0000ooooooooool0?_ooool2o`0000?ooooo1?l0000Jooooo`;o00002oooool2o`0000;o
oooo0_l00006ooooo`;o00005?ooool4o`000003ooooool0003o000000Cooooo0_l00004ooooo`;o
00002?ooool3o`0000Gooooo0_l00003ooooo`;o00000oooool2o`0001gooooo1?l000000ooooooo
0000o`00001Vooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00000oooool2o`0001cooooo
0_l0000;ooooo`;o00000_ooool3o`0001_ooooo1_l00004ooooo`?o00001?ooool2o`0000Wooooo
0_l0000:ooooo`;o00000oooool2o`00017ooooo1?l0000:ooooo`;o0000JOooool001cooooo00?o
0000ooooooooool0>Oooool2o`0002Kooooo0_l00006ooooo`;o00002?ooool2o`0001[ooooo1ol0
0004ooooo`;o00004?ooool2o`0000kooooo0_l000000ooooooo0000o`00000:ooooo`;o00000ooo
ool4o`0000Kooooo0_l000001?oooooo0000o`000?l0001Yooooo`007?ooool00ol0003ooooooooo
o`0iooooo`;o00005_ooool2o`0000Cooooo0_l000000ooooooo0000o`000002o`0000_ooooo0_l0
000:ooooo`;o00003Oooool3o`0000Gooooo3ol00004ooooo`;o00002oooool2o`0000?ooooo0ol0
0008ooooo`;o000000?oooooo`000?l000000_ooool4o`0000Cooooo0_l00003ooooo`;o00000_oo
ool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l00000J_ooool001cooooo00?o
0000ooooooooool0DOooool2o`0000Cooooo0_l000000ooooooo0000o`000005o`0000Oooooo0_l0
000;ooooo`;o00003?ooool4o`0000Cooooo4_l00002ooooo`;o00003?ooool3o`000004ooooool0
003o0000o`0000Kooooo1?l00005ooooo`Go00003?ooool5o`000003ooooool0003o000006gooooo
000Looooo`03o`000?oooooooooo04Oooooo0_l0000Eooooo`?o00001oooool2o`0000;ooooo0_l0
000Eooooo`Co00001?oooolBo`0000?ooooo0_l0000;ooooo`Go00002?ooool4o`0000?ooooo1ol0
0006ooooo`;o00001_ooool2o`00077ooooo000Looooo`03o`000?oooooooooo04Oooooo0_l0000S
ooooo`;o00005_ooool2o`0000Kooooo4Ol00002ooooo`?o00001Oooool2o`0000Gooooo1?l00005
ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`Go00002?ooool2o`0000Gooooo0_l0
000Dooooo`;o000000?oooooo`000?l00000FOooool001cooooo00?o0000ooooooooool0>_ooool2
o`0004cooooo0_l00002oooooa;o000000Coooooo`000?l0003o00001?ooool3o`0000Gooooo1_l0
0003ooooo`;o000000?oooooo`000?l000000ol00003ooooo`Go00000_ooool4o`000003ooooool0
003o000000Co000000?oooooo`000?l000005?ooool2o`000003ooooool0003o000000?o0000E_oo
ool001cooooo00?o0000ooooooooool0>_ooool2o`0002?ooooo0_l0000Wooooo`;o00000_oooolF
o`0000Cooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Oooooo0ol00005
ooooo`Co00000_ooool4o`000003ooooool0003o000000Co00003oooool2o`0000Wooooo1_l00002
ooooo`;o0000DOooool001cooooo00?o0000ooooooooool0Coooool4o`0000cooooo0ol00007oooo
o`;o00005_ooool2o`0000Gooooo0_l000000ooooooo0000o`000006o`0000;ooooo3?l0000:oooo
o`;o00003oooool2o`0000Oooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o0000
00gooooo0_l000000ooooooo0000o`000003ooooo`;o00001?ooool2o`0000;ooooo0_l00002oooo
o`;o0000DOooool001cooooo0_l0001@ooooo`Co00003Oooool2o`000003ooooool0003o000000Co
oooo0_l0000Fooooo`;o00001Oooool2o`000003ooooool0003o0000017o00006_ooool3o`0000ko
oooo0_l0000Eooooo`;o00001_ooool2o`0005oooooo000Looooo`03o`000?oooooooooo06?ooooo
0_l0000Sooooo`;o000000?oooooo`000?l000004ol0000Hooooo`?o00004?ooool2o`0002Cooooo
0_l0001Fooooo`007?ooool00ol0003oooooooooo`2;oooooaOo00003?ooool2o`0001_ooooo0_l0
0007ooooo`;o00001Oooool2o`0000Oooooo1?l00003ooooo`;o00001?ooool2o`0005Kooooo000L
ooooo`03o`000?oooooooooo05Kooooo0_l00008ooooo`;o00002Oooool4o`0001cooooo4ol00000
0ooooooo0000o`000002o`0000Wooooo1?l0000Nooooo`;o00001?ooool2o`0000Gooooo0_l00007
ooooo`Co00000oooool2o`0000Gooooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`1Foooo
o`;o00002?ooool2o`0000Wooooo1?l0000Gooooo`;o00001OoooolBo`000004ooooool0003o0000
o`0000?ooooo0_l00004ooooo`Co00004_ooool2o`0000Sooooo1?l00007ooooo`?o00002Oooool4
o`0000_ooooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00005_ooool2o`00
02kooooo0_l00005oooooa;o00001oooool2o`0000Cooooo1?l00002ooooo`;o00003_ooool2o`00
0003ooooool0003o000000?ooooo1?l00009ooooo`?o00001Oooool3o`000003ooooool0003o0000
00;o00002?ooool2o`0005Sooooo000Looooo`03o`000?oooooooooo03kooooo0_l0000Fooooo`;o
0000:oooool3o`0000Sooooo4?l00002ooooo`;o00002_ooool3o`0000;ooooo1Ol00002ooooo`;o
00001_ooool2o`0000?ooooo1?l000001?oooooo0000o`000?l0000@ooooo`Go00001oooool2o`00
00Cooooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`17ooooo`;o00009_ooool2o`0001;o
oooo0ol00007oooooa7o00000_ooool2o`0000_ooooo0_l00002ooooo`;o000000?oooooo`000?l0
00000_ooool2o`0000Kooooo0_l00005ooooo`?o000000?oooooo`000?l000004?ooool2o`0000Oo
oooo0_l000001?oooooo0000o`000?l0001Mooooo`007?ooool00ol0003oooooooooo`17ooooo`;o
00001?ooool2o`0000Oooooo0_l0000Gooooo`;o00006ooooolCo`0000kooooo1?l0000?ooooo`;o
00001Oooool3o`000003ooooool0003o000001Wooooo0_l00002ooooo`;o0000GOooool001cooooo
00?o0000ooooooooool0COooool2o`0000Oooooo0_l0000Booooo`;o00008?ooool2o`000003oooo
ool0003o000000oo00003Oooool5o`0000kooooo0_l00002ooooo`;o00006oooool2o`0000Cooooo
1?l0001Nooooo`007?ooool00ol0003oooooooooo`1Jooooo`Go00002oooool2o`0000Cooooo0ol0
000IoooooaCo00003_ooool4o`0000Wooooo0_l00003ooooo`;o00000_ooool2o`0001_ooooo0_l0
0004ooooo`Co0000G_ooool001cooooo00?o0000ooooooooool0EOooool2o`0000?ooooo1Ol0000A
ooooo`?o00000_ooool2o`0001Oooooo3ol0000=ooooo`;o00000_ooool2o`0000?ooooo0_l00006
ooooo`;o00001?ooool4o`0001Wooooo0_l0001Yooooo`007?ooool00ol0003oooooooooo`1Eoooo
o`;o00000_ooool2o`0000;ooooo0_l0000Fooooo`;o00006?ooool>o`0000?ooooo0_l00008oooo
o`;o00000oooool2o`0000;ooooo0_l0000<ooooo`Co00004Oooool2o`0000Kooooo1?l00005oooo
o`;o0000H?ooool001cooooo00?o0000ooooooooool0FOooool2o`0000;ooooo0_l000001?oooooo
0000o`000?l0000/ooooo`;o000000?oooooo`000?l000002Ol00003ooooo`;o00001?ooool2o`00
00;ooooo0_l00003ooooo`;o00002_ooool2o`0000Cooooo0ol0000Booooo`;o00002?ooool2o`00
00Gooooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`1Pooooo`?o00001Oooool2o`0001go
oooo0_l00009ooooo`Wo00002_ooool3o`0000gooooo0_l00004ooooo`;o00001Oooool4o`0000go
oooo0_l00008ooooo`;o00001oooool2o`00067ooooo000Looooo`03o`000?oooooooooo04gooooo
0_l00003ooooo`;o00005?ooool2o`0001gooooo0_l00003ooooo`;o00001?ooool3o`000004oooo
ool0003o0000o`0000_ooooo1Ol000001?oooooo0000o`000?ooool2o`0000Kooooo0_l0000=oooo
o`;o00003Oooool2o`0000Oooooo0ol00006ooooo`?o0000HOooool001cooooo0_l0001>ooooo`;o
00000oooool2o`0003Sooooo0_l00005ooooo`;o00000_ooool2o`0000_ooooo0_l000001?oooooo
0000o`000?ooool5o`0000gooooo0_l0000Cooooo`;o00002Oooool2o`0000Oooooo0_l0001Roooo
o`007?ooool00ol0003oooooooooo`1Aooooo`;o00008Oooool2o`0001cooooo0_l00005ooooo`?o
00002oooool2o`0000;ooooo1?l00004ooooo`;o00001oooool2o`0001?ooooo0_l00004ooooo`;o
0000L?ooool001cooooo00?o0000ooooooooool0DOooool2o`0001Gooooo0_l0000:ooooo`;o0000
00?oooooo`000?l000006Oooool2o`0000Gooooo0ol0000@ooooo`?o000000Coooooo`000?l0003o
oooo0ol0000Pooooo`?o00003Oooool2o`00067ooooo000Looooo`03o`000?oooooooooo05Cooooo
0_l0000@ooooo`Co00003Oooool2o`0001Wooooo0_l00005ooooo`;o000000?oooooo`000?l00000
0_l00006ooooo`;o000000Coooooo`000?l0003ooooo1_l00002ooooo`;o00008?ooool2o`0000;o
oooo0_l0000:ooooo`;o0000HOooool001cooooo00?o0000ooooooooool0D?ooool2o`000004oooo
ool0003o0000o`0000Gooooo0_l00005ooooo`;o00000_ooool2o`0001Cooooo0_l0000@ooooo`Ko
00002?ooool4o`0000Cooooo1?l000000ooooooo0000o`00000=o`0000Gooooo0_l00009ooooo`;o
00004?ooool2o`0006gooooo000Looooo`03o`000?oooooooooo053ooooo0_l000000ooooooo0000
o`000006ooooo`;o00001Oooool2o`0001Sooooo0_l0000@ooooo`So00003_ooool4o`0000?ooooo
0_l00003ooooo`So00001Oooool2o`0000Wooooo0ol00003ooooo`;o00000oooool2o`0000[ooooo
0_l0001Xooooo`007?ooool00ol0003oooooooooo`2Booooo`Co00005_ooool3o`0000Gooooo0_l0
0005ooooo`;o00003?ooool2o`0000?ooooo0_l00003ooooo`;o00002_ooool2o`0006Sooooo000L
ooooo`03o`000?oooooooooo05_ooooo0_l0000eooooo`;o00006?ooool3o`0000?ooooo0_l00004
ooooo`Go00007?ooool2o`0006kooooo000Looooo`03o`000?oooooooooo05Gooooo0_l00004oooo
o`;o00008oooool2o`0000gooooo1?l00002ooooo`;o00006oooool2o`0000Cooooo1?l00004oooo
o`;o00005oooool2o`0006kooooo000Looooo`03o`000?oooooooooo05Gooooo0_l00008ooooo`;o
00007oooool2o`0000gooooo1?l00002ooooo`?o00005_ooool2o`0000?ooooo0_l00004ooooo`;o
00001Oooool2o`0001Gooooo0_l0001`ooooo`007?ooool00ol0003oooooooooo`1Eooooo`;o0000
1Oooool2o`000003ooooool0003o000000Kooooo0ol0000/ooooo`;o00005_ooool2o`0000;ooooo
1?l00002ooooo`;o00007Oooool2o`00073ooooo000Looooo`03o`000?oooooooooo05Gooooo0_l0
0005ooooo`;o00002Oooool3o`0002[ooooo0_l0000;ooooo`?o00003_ooool5o`000003ooooool0
003o000001Wooooo0_l0001dooooo`007?ooool00ol0003oooooooooo`1?ooooo`;o00003_ooool2
o`0003?ooooo0_l000000ooooooo0000o`000002o`0000Kooooo0ol0000?ooooo`Co00002oooool2
o`0000cooooo0_l000000ooooooo0000o`00001dooooo`007?ooool00ol0003oooooooooo`1?oooo
o`;o00002Oooool2o`0000?ooooo0_l0000cooooo`;o000000?oooooo`000?l000000_l0000:oooo
o`;o00003?ooool6o`0000Gooooo0_l00002ooooo`;o00001oooool2o`000003ooooool0003o0000
00;o000000?oooooo`000?l00000M?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2
ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo05[ooooo0_l0
000hooooo`;o00001Oooool2o`000005ooooool0003o0000o`000?ooool00_l000000ooooooo0000
o`00000<ooooo`Ko00001Oooool2o`0000_ooooo1Ol0001iooooo`0000KoooooogMgMonHV9Sooooo
oiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000oooo
ooooool0Voooool2o`000005ooooool0003o0000o`000?ooool00_l0000Booooo`Go00004_ooool2
o`0007[ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo05oooooo0_l00008ooooo`;o0000@?ooool5
o`0000Wooooo0_l00003ooooo`Co0000Qoooool00003ooooool0003ooooo00;ooooo00?o0000oooo
ooooool02Oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0001Oooooo`;o00002?ooool2
o`00043ooooo1Ol000000ooooooo0000o`00000;ooooo`Co0000Qoooool00003ooooool0003ooooo
00;ooooo00?o0000ooooooooool02Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000
ooooooooool0G_ooool2o`0000Wooooo0_l0000kooooo`;o00001Oooool2o`0000;ooooo0_l0000>
ooooo`;o0000Q_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol@
413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0G_ooool2o`0004Kooooo0_l00000
0ooooooo0000o`000006ooooo`;o00003_ooool2o`0008Kooooo00001_ooooooMgMgoiRHV?oooooo
V9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0:Wooooo
1?l00003ooooo`;o00003_ooool2o`0008Oooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_o
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo0:_ooooo0ol00002oooo
o`;o00002Oooool2o`0000?ooooo0_l00027ooooo`007?ooool00ol0003oooooooooo`1Sooooo`;o
0000Aoooool2o`0000;ooooo0_l00009ooooo`;o0000S?ooool001cooooo00?o0000ooooooooool0
Hoooool2o`0004_ooooo0_l00005ooooo`;o0000T?ooool001cooooo00?o0000ooooooooool0MOoo
ool2o`00043ooooo0_l0002@ooooo`007?ooool00ol0003oooooooooo`1eooooo`;o0000d_ooool0
01cooooo00?o0000ooooooooool0Ioooool2o`000>3ooooo000Looooo`03o`000?oooooooooo06Oo
oooo0_l0003Pooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo08;ooooo0_l00035ooooo`007?ooool00ol0003oooooooooo`22ooooo`;o0000aOooool0
01cooooo00?o0000ooooooooool0Q_ooool2o`000<7ooooo000Looooo`03o`000?oooooooooo06co
oooo0_l0000Hooooo`;o000000?oooooo`000?l00000__ooool001cooooo0_l0001]ooooo`;o0000
6oooool2o`000;kooooo000Looooo`03o`000?oooooooooo06kooooo0_l0003Iooooo`007?ooool0
0ol0003oooooooooo`1^ooooo`;o00000_ooool2o`0001gooooo0ol00004ooooo`Ko0000Zoooool0
01cooooo00?o0000ooooooooool0L_ooool2o`0001gooooo0ol00004ooooo`Ko0000=?ooool2o`00
07Gooooo000Looooo`03o`000?oooooooooo0<kooooo0_l00002ooooo`;o0000MOooool001cooooo
00?o0000ooooooooool0c_ooool2o`0007Wooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0Moooool2o`000=3ooooo000Looooo`03o`000?oooooooooo
07Oooooo0_l0003@ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0aOooool2o`0008;ooooo000L
ooooo`03o`000?oooooooooo0<Gooooo0_l00022ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
_oooool2o`0008Sooooo000Looooo`;o0000ROooool2o`0003Gooooo0_l00028ooooo`007?ooool0
0ol0003oooooooooo`28ooooo`;o000000?oooooo`000?l00000_?ooool001cooooo00?o0000oooo
ooooool0Roooool2o`0000Oooooo0_l00005ooooo`;o00007?ooool2o`0008kooooo000Looooo`03
o`000?oooooooooo09Cooooo0ol00004ooooo`;o00006?ooool2o`0000;ooooo0_l0002>ooooo`00
7?ooool00ol0003oooooooooo`2Eooooo`;o00002_ooool4o`0000Gooooo0_l00005ooooo`;o0000
0_ooool2o`0009;ooooo000Looooo`03o`000?oooooooooo0:7ooooo1?l00005ooooo`;o00001Ooo
ool2o`0009Kooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001;ooooo1?l0
00000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo
00Gooooo0ol0003ooooood[ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo
00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000D
ooooo`03o`000?oooooooooo0?ooooooD_ooool001;ooooo00?oEEEEofIVI_l00000oooooomDoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00YOooool01?l@413o0000o`000?oo
ool2o`000003oa0@4?oooooooooo01Oooooo0_l000002Ol@413oooooooooooooooooc<c<ob4Q8Ol0
003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0T?ooool00:Kooooo00Go0000oooo
ooooooooooooo`000009ooooo`Ko00003?ooool00ol0003oooooooooo`02ooooo`05ob4Q8OnHV9So
oooooiRHV?lQ8B400oooool01OmEEEGoMgMgoooooonHV9So8B4Q093ooooo002Vooooo`05o`000?oo
ooooooooooooool000006?ooool5o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool00000T?ooool00:Kooooo00Go0000ooooooooooooooooo`000009oooo
o`Ko00002Oooool01?m4A4CogMgMooooool00004ooooo`05oc8b<_nHV9SooooooiRHV?lb<S800ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q093ooooo002Vooooo`05o`000?n7QhOoooooojVYZOl00000
6?ooool01?oMgMgoEEEEooooool00004ooooo`05olc<c?l0003o0000o`000?o<c<`00oooool01Ol0
003oEEEEo`000?l@413oc<c<093ooooo002Uooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHoooo
ooooool05oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?nj^[[ooooookZj^_l@41000oooool0
0omEEEGoQhN7ooooo`2Booooo`00a?ooool00oo^k^koA4A4o`000004ooooo`05o`000?nj^[[ooooo
okZj^_l000000oooool00ooMgMgo410@oiRHV02Booooo`00aOooool00omgMgOo0000ooooo`03oooo
o`05ojVYZOl@413o0000oa0@4?nYZJT01?ooool01?o<c<coA4A4o`000?l@412@ooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(492) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.57603 .34037 Mdot
.59057 .34155 Mdot
.34342 .56579 Mdot
.58648 .55236 Mdot
.438 .73365 Mdot
.29616 .58558 Mdot
.34314 .39732 Mdot
.36089 .39648 Mdot
.30125 .5736 Mdot
.69033 .44778 Mdot
.33402 .36576 Mdot
.54967 .55171 Mdot
.34194 .38209 Mdot
.61834 .58274 Mdot
.51378 .4028 Mdot
.68936 .56935 Mdot
.62066 .3923 Mdot
.42001 .67197 Mdot
.69501 .58398 Mdot
.32375 .5579 Mdot
.66155 .67727 Mdot
.61265 .591 Mdot
.6328 .36157 Mdot
.61803 .58555 Mdot
.63116 .55203 Mdot
.59479 .35343 Mdot
.58056 .33458 Mdot
.64724 .55826 Mdot
.61744 .52705 Mdot
.345 .36991 Mdot
.25888 .64625 Mdot
.81918 .37891 Mdot
.65117 .62027 Mdot
.78582 .42448 Mdot
.35998 .39934 Mdot
.27798 .3949 Mdot
.33632 .57763 Mdot
.33134 .4082 Mdot
.36813 .39271 Mdot
.36541 .39996 Mdot
.33599 .40253 Mdot
.59516 .36245 Mdot
.37479 .39489 Mdot
.22416 .55155 Mdot
.62761 .57281 Mdot
.55989 .30735 Mdot
.16995 .52424 Mdot
.64097 .54432 Mdot
.58645 .37869 Mdot
.30988 .55357 Mdot
.53367 .79476 Mdot
.30614 .36975 Mdot
.45421 .40476 Mdot
.47304 .90668 Mdot
.33452 .37247 Mdot
.5874 .54147 Mdot
.28711 .57166 Mdot
.59027 .57406 Mdot
.57268 .56295 Mdot
.76895 .38584 Mdot
.60442 .60192 Mdot
.43851 .70985 Mdot
.63541 .32279 Mdot
.2957 .62511 Mdot
.29499 .57758 Mdot
.3247 .4026 Mdot
.63058 .32842 Mdot
.35336 .38719 Mdot
.63129 .52802 Mdot
.32661 .55412 Mdot
.62138 .53009 Mdot
.34224 .36669 Mdot
.61916 .32551 Mdot
.63144 .57282 Mdot
.50742 .32203 Mdot
.32613 .32379 Mdot
.3413 .54042 Mdot
.80604 .53291 Mdot
.55609 .82462 Mdot
.37748 .63411 Mdot
.63567 .58757 Mdot
.43243 .8513 Mdot
.47122 .44018 Mdot
.58895 .33768 Mdot
.59607 .42095 Mdot
.54453 .20889 Mdot
.64837 .55152 Mdot
.40143 .5694 Mdot
.6268 .62846 Mdot
.48368 .59584 Mdot
.30888 .56798 Mdot
.60529 .33383 Mdot
.63374 .57739 Mdot
.64615 .61113 Mdot
.67091 .37178 Mdot
.5845 .52683 Mdot
.60019 .55304 Mdot
.62494 .41592 Mdot
.32316 .36486 Mdot
.54999 .50642 Mdot
.42643 .76511 Mdot
.47839 .39427 Mdot
.59991 .54038 Mdot
.32256 .59066 Mdot
.63569 .31916 Mdot
.60828 .55422 Mdot
.35685 .39352 Mdot
.62842 .59136 Mdot
.35193 .34779 Mdot
.62454 .38458 Mdot
.63937 .62079 Mdot
.44583 .67126 Mdot
.51399 .52767 Mdot
.61884 .37692 Mdot
.76184 .57962 Mdot
.61007 .60165 Mdot
.59436 .59317 Mdot
.58568 .34615 Mdot
.34094 .56926 Mdot
.35488 .52161 Mdot
.63289 .3461 Mdot
.36824 .39727 Mdot
.60108 .39141 Mdot
.56373 .59287 Mdot
.33761 .56604 Mdot
.46302 .40035 Mdot
.4753 .3991 Mdot
.50677 .72054 Mdot
.63907 .5788 Mdot
.52932 .50645 Mdot
.31101 .59128 Mdot
.58908 .35852 Mdot
.35054 .37992 Mdot
.56667 .55136 Mdot
.61185 .37222 Mdot
.36981 .38065 Mdot
.42857 .72027 Mdot
.42654 .73593 Mdot
.59373 .37756 Mdot
.71979 .58779 Mdot
.31154 .34896 Mdot
.36088 .40536 Mdot
.53189 .7921 Mdot
.5857 .33994 Mdot
.45214 .69477 Mdot
.36351 .3681 Mdot
.60154 .71981 Mdot
.57936 .59114 Mdot
.50374 .76273 Mdot
.34528 .80878 Mdot
.5327 .79412 Mdot
.81077 .40161 Mdot
.45168 .67662 Mdot
.36812 .37198 Mdot
.62404 .53406 Mdot
.61048 .3613 Mdot
.6042 .37012 Mdot
.64775 .60456 Mdot
.63397 .56381 Mdot
.61662 .57035 Mdot
.57017 .56963 Mdot
.2454 .37369 Mdot
.63463 .58215 Mdot
.3494 .27088 Mdot
.617 .36709 Mdot
.62432 .55526 Mdot
.32599 .59971 Mdot
.57288 .50265 Mdot
.34184 .40919 Mdot
.57416 .56053 Mdot
.63567 .56068 Mdot
.56025 .54705 Mdot
.37445 .38422 Mdot
.4915 .30268 Mdot
.6324 .80397 Mdot
.27125 .37286 Mdot
.40381 .34812 Mdot
.2975 .59693 Mdot
.62605 .60959 Mdot
.44143 .68125 Mdot
.55828 .50437 Mdot
.57998 .58297 Mdot
.53497 .79858 Mdot
.64741 .57328 Mdot
.81971 .45816 Mdot
.54236 .56666 Mdot
.52884 .20445 Mdot
.37675 .24546 Mdot
.57923 .58538 Mdot
.71105 .48966 Mdot
.49902 .7538 Mdot
.23544 .64621 Mdot
.34752 .3741 Mdot
.32027 .60849 Mdot
.34413 .57772 Mdot
.3411 .41356 Mdot
.59724 .65196 Mdot
.70311 .45696 Mdot
.59227 .52261 Mdot
.4668 .39859 Mdot
.55364 .35345 Mdot
.45702 .68573 Mdot
.5914 .37662 Mdot
.46347 .85581 Mdot
.42027 .6159 Mdot
.38205 .60209 Mdot
.41129 .70044 Mdot
.28712 .56118 Mdot
.45383 .39168 Mdot
.45008 .68773 Mdot
.59166 .55797 Mdot
.61381 .38835 Mdot
.49474 .76203 Mdot
.63761 .51345 Mdot
.41525 .1385 Mdot
.60251 .32495 Mdot
.49652 .52721 Mdot
.3398 .37459 Mdot
.31405 .62204 Mdot
.64824 .5518 Mdot
.60114 .57448 Mdot
.61981 .3161 Mdot
.63342 .53538 Mdot
.4151 .55649 Mdot
.64092 .56443 Mdot
.28618 .61972 Mdot
.48079 .66368 Mdot
.36987 .356 Mdot
.40857 .69144 Mdot
.62467 .33049 Mdot
.30328 .32127 Mdot
.32529 .59386 Mdot
.53594 .62358 Mdot
.3575 .37719 Mdot
.4253 .71459 Mdot
.33091 .57945 Mdot
.44389 .66713 Mdot
.62273 .62189 Mdot
.33287 .57102 Mdot
.44742 .70986 Mdot
.40678 .47413 Mdot
.6009 .5516 Mdot
.53138 .73172 Mdot
.33182 .35468 Mdot
.57582 .34926 Mdot
.59025 .59585 Mdot
.44548 .39675 Mdot
.5602 .57284 Mdot
.52173 .4845 Mdot
.44779 .38474 Mdot
.47617 .37425 Mdot
.38713 .60592 Mdot
.44782 .72186 Mdot
.50046 .35047 Mdot
.40219 .51167 Mdot
.62185 .39179 Mdot
.61763 .61938 Mdot
.56641 .25673 Mdot
.33517 .35411 Mdot
.58958 .56117 Mdot
.52325 .2222 Mdot
.36387 .36797 Mdot
.58935 .58093 Mdot
.33188 .39958 Mdot
.60838 .36806 Mdot
.436 .45233 Mdot
.5797 .3781 Mdot
.58402 .55604 Mdot
.323 .3845 Mdot
.32666 .60401 Mdot
.59548 .35366 Mdot
.62275 .59339 Mdot
.63944 .59256 Mdot
.46666 .39597 Mdot
.62845 .56577 Mdot
.58505 .23311 Mdot
.64159 .54611 Mdot
.30208 .55248 Mdot
.59959 .52486 Mdot
.4693 .78305 Mdot
.41364 .73342 Mdot
.63931 .35764 Mdot
.45027 .38164 Mdot
.31003 .56561 Mdot
.42541 .45774 Mdot
.51654 .69188 Mdot
.63048 .58618 Mdot
.46979 .38177 Mdot
.49498 .52072 Mdot
.33536 .40676 Mdot
.66613 .58687 Mdot
.38299 .53543 Mdot
.31644 .57046 Mdot
.46 .39702 Mdot
.67234 .55716 Mdot
.57696 .33362 Mdot
.59345 .5365 Mdot
.33486 .58117 Mdot
.57313 .3575 Mdot
.57216 .53405 Mdot
.1914 .43919 Mdot
.44589 .39846 Mdot
.31754 .37718 Mdot
.6597 .37646 Mdot
.63883 .60805 Mdot
.34448 .58546 Mdot
.60642 .37449 Mdot
.32745 .37853 Mdot
.62751 .37027 Mdot
.48194 .76444 Mdot
.54897 .47759 Mdot
.27898 .42925 Mdot
.43533 .65876 Mdot
.85075 .54806 Mdot
.2783 .39061 Mdot
.53382 .51723 Mdot
.26047 .56797 Mdot
.46685 .16829 Mdot
.32761 .58309 Mdot
.71421 .5467 Mdot
.29828 .56732 Mdot
.60344 .5343 Mdot
.29569 .58273 Mdot
.60198 .21518 Mdot
.65177 .57075 Mdot
.28374 .59192 Mdot
.26191 .43011 Mdot
.65026 .57794 Mdot
.61617 .37219 Mdot
.72147 .27763 Mdot
.77462 .58397 Mdot
.71942 .63803 Mdot
.28045 .58084 Mdot
.72498 .58308 Mdot
.64939 .55818 Mdot
.69555 .5898 Mdot
.60732 .3565 Mdot
.55368 .56035 Mdot
.46524 .69858 Mdot
.45412 .67152 Mdot
.5799 .75791 Mdot
.79168 .59676 Mdot
.63514 .65696 Mdot
.59863 .36033 Mdot
.54207 .82747 Mdot
.51107 .31639 Mdot
.44726 .40049 Mdot
.36625 .39038 Mdot
.48325 .31256 Mdot
.68194 .57603 Mdot
.61933 .44375 Mdot
.42112 .53607 Mdot
.608 .33182 Mdot
.35038 .46368 Mdot
.32977 .3854 Mdot
.74052 .62409 Mdot
.70549 .426 Mdot
.61394 .56771 Mdot
.31227 .36475 Mdot
.55007 .58799 Mdot
.41058 .54066 Mdot
.51979 .73989 Mdot
.20223 .51297 Mdot
.59095 .55437 Mdot
.51132 .34797 Mdot
.58131 .58306 Mdot
.50916 .73575 Mdot
.58554 .56151 Mdot
.62638 .36766 Mdot
.66347 .62807 Mdot
.39822 .50031 Mdot
.74533 .6723 Mdot
.42177 .6081 Mdot
.4572 .70506 Mdot
.61459 .5813 Mdot
.60349 .56643 Mdot
.43988 .71263 Mdot
.60989 .3349 Mdot
.61031 .6155 Mdot
.16547 .50811 Mdot
.63599 .58245 Mdot
.30857 .38218 Mdot
.4511 .48885 Mdot
.83409 .48538 Mdot
.65541 .58278 Mdot
.58257 .32716 Mdot
.34352 .40598 Mdot
.362 .37411 Mdot
.65643 .64135 Mdot
.32288 .35561 Mdot
.62603 .53368 Mdot
.45182 .48755 Mdot
.63141 .37215 Mdot
.54558 .5452 Mdot
.61496 .33621 Mdot
.52016 .82261 Mdot
.36076 .36276 Mdot
.46829 .37796 Mdot
.73226 .6202 Mdot
.34122 .39326 Mdot
.49031 .64384 Mdot
.66043 .629 Mdot
.64563 .5225 Mdot
.6586 .37282 Mdot
.33061 .60277 Mdot
.45967 .38075 Mdot
.33122 .37306 Mdot
.63233 .5798 Mdot
.60692 .54737 Mdot
.30985 .36278 Mdot
.73233 .34768 Mdot
.25611 .6443 Mdot
.58154 .55698 Mdot
.62801 .35783 Mdot
.59064 .35969 Mdot
.56933 .57754 Mdot
.58606 .59044 Mdot
.29015 .60369 Mdot
.46922 .38088 Mdot
.45623 .37946 Mdot
.48404 .39065 Mdot
.28221 .6125 Mdot
.83538 .5778 Mdot
.36078 .40556 Mdot
.82506 .40953 Mdot
.51236 .25632 Mdot
.668 .63286 Mdot
.34015 .58533 Mdot
.5985 .58303 Mdot
.60731 .53886 Mdot
.32132 .378 Mdot
.78702 .63405 Mdot
.64178 .63108 Mdot
.57995 .33826 Mdot
.30712 .37106 Mdot
.54912 .5621 Mdot
.29048 .38091 Mdot
.4263 .68157 Mdot
.69399 .647 Mdot
.31502 .35781 Mdot
.62525 .38006 Mdot
.31366 .35851 Mdot
.60744 .56711 Mdot
.66917 .54848 Mdot
.60779 .33079 Mdot
.42037 .72187 Mdot
.63876 .61358 Mdot
.5879 .58096 Mdot
.25043 .69896 Mdot
.5085 .32472 Mdot
.4337 .7481 Mdot
.62512 .54094 Mdot
.61274 .50893 Mdot
.41554 .70517 Mdot
.62818 .61563 Mdot
.60386 .52681 Mdot
.51255 .52368 Mdot
.34715 .34473 Mdot
.45415 .72146 Mdot
.73975 .6732 Mdot
.59863 .32554 Mdot
.57257 .23239 Mdot
.47205 .39902 Mdot
.38715 .40167 Mdot
.43724 .44334 Mdot
.45872 .38824 Mdot
.50572 .23574 Mdot
.26719 .3233 Mdot
.46344 .38155 Mdot
.30544 .62606 Mdot
.66233 .47411 Mdot
.60814 .52557 Mdot
.57714 .56802 Mdot
.44777 .72114 Mdot
.58083 .35278 Mdot
.35972 .26664 Mdot
.35123 .34173 Mdot
.60787 .59474 Mdot
.56776 .35381 Mdot
.5366 .20595 Mdot
.45871 .39443 Mdot
.44013 .67746 Mdot
.42558 .72735 Mdot
.58486 .58645 Mdot
.50259 .62717 Mdot
.59621 .3588 Mdot
.62262 .59334 Mdot
.60327 .60592 Mdot
.3041 .56181 Mdot
.6093 .38834 Mdot
.32176 .60113 Mdot
.45297 .37659 Mdot
.43079 .16171 Mdot
.21101 .65458 Mdot
.34237 .35641 Mdot
.38309 .43496 Mdot
.38125 .38334 Mdot
.20041 .47213 Mdot
.468 .37998 Mdot
.61801 .59264 Mdot
.6328 .33969 Mdot
.62688 .5925 Mdot
.63551 .58054 Mdot
.61119 .56182 Mdot
.63553 .65711 Mdot
.51892 .81657 Mdot
.42927 .69369 Mdot
.65968 .55645 Mdot
.27596 .59178 Mdot
.5262 .21011 Mdot
.64736 .25087 Mdot
.60935 .57631 Mdot
.59356 .59169 Mdot
.6228 .32174 Mdot
.61888 .62251 Mdot
.35662 .39641 Mdot
.59282 .33149 Mdot
.59978 .54367 Mdot
.42987 .76926 Mdot
.60616 .61246 Mdot
.36217 .44178 Mdot
.31654 .3546 Mdot
.6583 .5138 Mdot
.64449 .52612 Mdot
.46719 .37913 Mdot
.45962 .38135 Mdot
.44137 .39179 Mdot
.31093 .38111 Mdot
.30634 .5622 Mdot
.3438 .61307 Mdot
.65836 .54239 Mdot
.63091 .53829 Mdot
.66243 .53907 Mdot
.27256 .56876 Mdot
.39227 .50949 Mdot
.54158 .38706 Mdot
.54565 .58332 Mdot
.28273 .60878 Mdot
.63553 .41003 Mdot
.75389 .63312 Mdot
.58594 .33547 Mdot
.26478 .56463 Mdot
.36191 .38572 Mdot
.45348 .67523 Mdot
.56955 .78928 Mdot
.63283 .35284 Mdot
.60942 .31697 Mdot
.29117 .59652 Mdot
.48297 .47242 Mdot
.54006 .91553 Mdot
.31823 .58859 Mdot
.39061 .59143 Mdot
.60393 .35676 Mdot
.64378 .62669 Mdot
.49433 .51299 Mdot
.5007 .46713 Mdot
.28497 .5859 Mdot
.63869 .5927 Mdot
.46171 .63211 Mdot
.28963 .6032 Mdot
.66621 .60227 Mdot
.27952 .58294 Mdot
.31567 .36929 Mdot
.31146 .5949 Mdot
.57734 .38848 Mdot
.64027 .58272 Mdot
.49267 .91141 Mdot
.46423 .43495 Mdot
.62266 .59903 Mdot
.30781 .36259 Mdot
.2365 .41971 Mdot
.60199 .56173 Mdot
.46354 .69644 Mdot
.27497 .60069 Mdot
.1946 .50082 Mdot
.59682 .52943 Mdot
.29038 .58714 Mdot
.5832 .39828 Mdot
.2593 .57722 Mdot
.41694 .75436 Mdot
.45755 .38008 Mdot
.611 .36682 Mdot
.49496 .39099 Mdot
.35411 .40555 Mdot
.57753 .59852 Mdot
.61004 .6096 Mdot
.62199 .36299 Mdot
.41559 .46192 Mdot
.63206 .64649 Mdot
.63509 .58688 Mdot
.29934 .60571 Mdot
.27321 .57647 Mdot
.5191 .39138 Mdot
.3289 .59081 Mdot
.60976 .50842 Mdot
.62273 .36657 Mdot
.59373 .53955 Mdot
.60811 .37762 Mdot
.6212 .62004 Mdot
.43166 .36013 Mdot
.58167 .34144 Mdot
.5234 .59755 Mdot
.64134 .57854 Mdot
.64167 .28663 Mdot
.64174 .60534 Mdot
.59578 .55381 Mdot
.26959 .58903 Mdot
.4377 .69553 Mdot
.65915 .60718 Mdot
.29734 .32552 Mdot
.41776 .69121 Mdot
.76948 .35701 Mdot
.33787 .56686 Mdot
.42649 .72272 Mdot
.56945 .74343 Mdot
.45022 .38191 Mdot
.43287 .70753 Mdot
.45048 .3699 Mdot
.33268 .35613 Mdot
.60755 .39718 Mdot
.64839 .57985 Mdot
.47014 .16162 Mdot
.26199 .64741 Mdot
.46987 .39252 Mdot
.59291 .59698 Mdot
.59618 .57775 Mdot
.5717 .3446 Mdot
.45362 .85383 Mdot
.28 .62052 Mdot
.59311 .55006 Mdot
.62876 .33829 Mdot
.39938 .83629 Mdot
.28271 .59384 Mdot
.42651 .69534 Mdot
.35308 .35261 Mdot
.5648 .32617 Mdot
.46348 .37688 Mdot
.36271 .3644 Mdot
.33194 .5398 Mdot
.53677 .80141 Mdot
.59226 .53157 Mdot
.33453 .59326 Mdot
.53277 .79471 Mdot
.5418 .5595 Mdot
.35597 .41562 Mdot
.44035 .36129 Mdot
.60261 .33454 Mdot
.30889 .3642 Mdot
.45441 .71529 Mdot
.62186 .39005 Mdot
.61225 .33422 Mdot
.36311 .39164 Mdot
.38084 .22728 Mdot
.49714 .51571 Mdot
.32044 .40345 Mdot
.51006 .48797 Mdot
.53005 .79294 Mdot
.47589 .38179 Mdot
.44204 .67691 Mdot
.42609 .77854 Mdot
.59452 .35968 Mdot
.48442 .31113 Mdot
.53507 .79619 Mdot
.5998 .55286 Mdot
.45137 .70779 Mdot
.54122 .21946 Mdot
.38782 .38461 Mdot
.36902 .37711 Mdot
.35279 .52996 Mdot
.45965 .69302 Mdot
.59213 .60399 Mdot
.83455 .51018 Mdot
.6502 .58765 Mdot
.35829 .36232 Mdot
.41936 .54506 Mdot
.61047 .38743 Mdot
.34725 .41023 Mdot
.41398 .559 Mdot
.60934 .53754 Mdot
.61666 .60396 Mdot
.45817 .6498 Mdot
.60181 .38929 Mdot
.46898 .37503 Mdot
.63429 .59287 Mdot
.58848 .57449 Mdot
.57285 .59062 Mdot
.72768 .66561 Mdot
.51482 .59491 Mdot
.59712 .5476 Mdot
.32143 .61683 Mdot
.60623 .50311 Mdot
.57092 .56843 Mdot
.5714 .3409 Mdot
.46438 .79081 Mdot
.45305 .37624 Mdot
.5782 .56754 Mdot
.58114 .55778 Mdot
.36622 .39602 Mdot
.49609 .51738 Mdot
.50229 .46432 Mdot
.29493 .55687 Mdot
.35873 .53989 Mdot
.59373 .51864 Mdot
.61578 .36228 Mdot
.46559 .70217 Mdot
.57226 .50943 Mdot
.58881 .33083 Mdot
.66166 .55398 Mdot
.2751 .58679 Mdot
.4671 .38305 Mdot
.5462 .60155 Mdot
.43948 .70662 Mdot
.3204 .34334 Mdot
.80414 .37956 Mdot
.31774 .60782 Mdot
.6369 .55076 Mdot
.35105 .60771 Mdot
.31453 .57883 Mdot
.47077 .39456 Mdot
.66133 .53223 Mdot
.60472 .3672 Mdot
.6187 .38356 Mdot
.50755 .80535 Mdot
.28613 .61734 Mdot
.28541 .74336 Mdot
.31646 .36523 Mdot
.66174 .57198 Mdot
.56894 .28417 Mdot
.61331 .38559 Mdot
.5078 .72589 Mdot
.42424 .72204 Mdot
.36841 .37632 Mdot
.48566 .3737 Mdot
.58 .34217 Mdot
.60643 .38407 Mdot
.63265 .57687 Mdot
.6085 .584 Mdot
.2813 .54527 Mdot
.50234 .75566 Mdot
.33293 .39983 Mdot
.42751 .68626 Mdot
.31168 .55139 Mdot
.61513 .53538 Mdot
.59488 .33583 Mdot
.83157 .50002 Mdot
.63744 .60866 Mdot
.2764 .58998 Mdot
.59464 .34088 Mdot
.42633 .7065 Mdot
.43842 .71999 Mdot
.59845 .55353 Mdot
.81906 .4821 Mdot
.34429 .39352 Mdot
.61942 .37181 Mdot
.61611 .41469 Mdot
.64932 .54309 Mdot
.61073 .58006 Mdot
.5784 .62077 Mdot
.35466 .41279 Mdot
.54061 .57913 Mdot
.41662 .68307 Mdot
.59096 .3689 Mdot
.62777 .59599 Mdot
.43789 .71 Mdot
.61756 .4436 Mdot
.46285 .38776 Mdot
.28443 .59475 Mdot
.46326 .69328 Mdot
.44664 .69702 Mdot
.41825 .69725 Mdot
.48429 .31422 Mdot
.63921 .32133 Mdot
.70042 .74349 Mdot
.64143 .58675 Mdot
.52898 .79228 Mdot
.60796 .62282 Mdot
.31878 .38856 Mdot
.31622 .61176 Mdot
.62595 .57382 Mdot
.64178 .5867 Mdot
.81617 .43672 Mdot
.69075 .56954 Mdot
.69181 .56804 Mdot
.62085 .38577 Mdot
.65994 .31479 Mdot
.34283 .58726 Mdot
.30969 .78729 Mdot
.73145 .26711 Mdot
.5885 .5219 Mdot
.4786 .47432 Mdot
.59172 .33311 Mdot
.37155 .38358 Mdot
.50399 .49379 Mdot
.30285 .41361 Mdot
.58471 .36029 Mdot
.60659 .53465 Mdot
.80291 .38487 Mdot
.43378 .66817 Mdot
.61462 .5703 Mdot
.35329 .38111 Mdot
.61556 .57028 Mdot
.31547 .38865 Mdot
.59623 .29185 Mdot
.49318 .45473 Mdot
.64884 .57338 Mdot
.59027 .5261 Mdot
.55503 .49285 Mdot
.60852 .57866 Mdot
.21942 .49464 Mdot
.60427 .34312 Mdot
.53011 .61665 Mdot
.56388 .56204 Mdot
.79354 .50719 Mdot
.60877 .61133 Mdot
.4262 .43415 Mdot
.61674 .60839 Mdot
.70307 .68222 Mdot
.58729 .60007 Mdot
.62469 .60929 Mdot
.32677 .38466 Mdot
.3691 .39503 Mdot
.57708 .39693 Mdot
.47435 .37563 Mdot
.52797 .20577 Mdot
.59041 .5865 Mdot
.27069 .57708 Mdot
.54929 .42613 Mdot
.44256 .69421 Mdot
.58931 .3653 Mdot
.17452 .66604 Mdot
.33603 .40469 Mdot
.30066 .62517 Mdot
.36915 .61775 Mdot
.33979 .60668 Mdot
.29305 .54779 Mdot
.64764 .29098 Mdot
.43908 .67578 Mdot
.60041 .60829 Mdot
.79284 .43667 Mdot
.51367 .33593 Mdot
.64615 .54147 Mdot
.30892 .63262 Mdot
.62799 .47119 Mdot
.52086 .80792 Mdot
.45009 .66676 Mdot
.45241 .67981 Mdot
.32927 .37747 Mdot
.34367 .56765 Mdot
.55125 .59661 Mdot
.42644 .72236 Mdot
.31411 .61144 Mdot
.47393 .40148 Mdot
.39389 .65882 Mdot
.59705 .36297 Mdot
.71897 .59718 Mdot
.56376 .29729 Mdot
.33519 .40342 Mdot
.30682 .32395 Mdot
.65305 .36113 Mdot
.63435 .38531 Mdot
.48036 .37997 Mdot
.27951 .59827 Mdot
.61237 .39817 Mdot
.63901 .58169 Mdot
.63794 .51369 Mdot
.58538 .58783 Mdot
.44286 .72259 Mdot
.59811 .60288 Mdot
.29063 .60732 Mdot
.34425 .40007 Mdot
.31197 .56784 Mdot
.3399 .39655 Mdot
.76544 .32924 Mdot
.57281 .56903 Mdot
.61257 .58276 Mdot
.45581 .48359 Mdot
.59987 .38194 Mdot
.78065 .42314 Mdot
.27594 .59331 Mdot
.2917 .56858 Mdot
.59395 .54066 Mdot
.6401 .34873 Mdot
.49498 .66405 Mdot
.488 .49533 Mdot
.61178 .60795 Mdot
.6052 .34287 Mdot
.59053 .54061 Mdot
.20572 .44971 Mdot
.49447 .43939 Mdot
.62597 .37293 Mdot
.74652 .6721 Mdot
.63144 .57006 Mdot
.65067 .51543 Mdot
.62841 .49139 Mdot
.67214 .68085 Mdot
.65678 .62227 Mdot
.60242 .32575 Mdot
.57312 .55893 Mdot
.61446 .35654 Mdot
.32097 .58013 Mdot
.36185 .40635 Mdot
.61159 .3569 Mdot
.64847 .58639 Mdot
.73869 .27818 Mdot
.34901 .40105 Mdot
.62163 .57702 Mdot
.33036 .36843 Mdot
.59649 .39343 Mdot
.58834 .37788 Mdot
.47366 .36534 Mdot
.38629 .59693 Mdot
.35383 .39637 Mdot
.63178 .53812 Mdot
.49893 .31119 Mdot
.59412 .53887 Mdot
.36115 .54306 Mdot
.56435 .54262 Mdot
.61894 .52474 Mdot
.85613 .53738 Mdot
.42311 .45373 Mdot
.23934 .72266 Mdot
.35828 .33977 Mdot
.49568 .30303 Mdot
.58102 .40623 Mdot
.4507 .66725 Mdot
.38405 .44452 Mdot
.4469 .3907 Mdot
.32948 .61237 Mdot
.62992 .57673 Mdot
.64672 .26954 Mdot
.31309 .39329 Mdot
.43569 .69183 Mdot
.64763 .57296 Mdot
.35123 .5727 Mdot
.46369 .41865 Mdot
.36771 .37232 Mdot
.59541 .36401 Mdot
.58945 .37584 Mdot
.57309 .82334 Mdot
.62375 .59734 Mdot
.61109 .58837 Mdot
.35581 .40091 Mdot
.5749 .62695 Mdot
.41995 .69219 Mdot
.2723 .44043 Mdot
.35295 .37802 Mdot
.48863 .44058 Mdot
.62063 .38768 Mdot
.59717 .57989 Mdot
.45095 .49031 Mdot
.44461 .29197 Mdot
.6702 .40573 Mdot
.45517 .6964 Mdot
.50837 .6584 Mdot
.60267 .32554 Mdot
.34939 .37776 Mdot
.57284 .75324 Mdot
.61609 .62769 Mdot
.59418 .57622 Mdot
.53031 .6719 Mdot
.49149 .49424 Mdot
.39525 .58216 Mdot
.58036 .61887 Mdot
.48571 .54252 Mdot
.59517 .54041 Mdot
.60699 .54701 Mdot
.62658 .52576 Mdot
.56962 .54327 Mdot
.60908 .34429 Mdot
.77921 .57052 Mdot
.30033 .58911 Mdot
.67887 .46065 Mdot
.32315 .52678 Mdot
.65199 .56169 Mdot
.60697 .53604 Mdot
.74747 .52338 Mdot
.53818 .47105 Mdot
.60101 .34854 Mdot
.62081 .41251 Mdot
.36023 .40496 Mdot
.69409 .57775 Mdot
.2802 .61225 Mdot
.6469 .4964 Mdot
.3049 .57564 Mdot
.60655 .34167 Mdot
.31977 .56236 Mdot
.30074 .36241 Mdot
.33455 .59284 Mdot
.29302 .6181 Mdot
.36394 .36281 Mdot
.58838 .38166 Mdot
.62747 .61065 Mdot
.35562 .35639 Mdot
.49347 .65899 Mdot
.44253 .72244 Mdot
.47099 .36426 Mdot
.64267 .62773 Mdot
.68013 .54842 Mdot
.18885 .44347 Mdot
.33155 .56791 Mdot
.51783 .46238 Mdot
.58111 .34278 Mdot
.46222 .70933 Mdot
.61183 .34723 Mdot
.63225 .7825 Mdot
.44586 .70516 Mdot
.46683 .36435 Mdot
.5547 .75531 Mdot
.28016 .34991 Mdot
.55686 .54831 Mdot
.65815 .37649 Mdot
.30805 .574 Mdot
.3079 .37958 Mdot
.5352 .2167 Mdot
.62144 .56177 Mdot
.46877 .40711 Mdot
.63648 .38776 Mdot
.45144 .3816 Mdot
.35105 .38154 Mdot
.40933 .40259 Mdot
.61808 .59936 Mdot
.28539 .34575 Mdot
.57938 .52828 Mdot
.73053 .60941 Mdot
.33557 .53338 Mdot
.61311 .43532 Mdot
.59705 .53358 Mdot
.28204 .59687 Mdot
.59547 .53564 Mdot
.69561 .5127 Mdot
.5403 .77458 Mdot
.58125 .51856 Mdot
.5769 .46097 Mdot
.18641 .48201 Mdot
.59836 .3351 Mdot
.61106 .51003 Mdot
.47528 .38688 Mdot
.62356 .54593 Mdot
.53184 .1373 Mdot
.43444 .70608 Mdot
.43453 .7455 Mdot
.64727 .586 Mdot
.63129 .5918 Mdot
.81563 .46088 Mdot
.64865 .30858 Mdot
.48451 .37275 Mdot
.59311 .56934 Mdot
.55744 .68029 Mdot
.32595 .37871 Mdot
.56998 .53644 Mdot
.57527 .56727 Mdot
.2484 .68237 Mdot
.32472 .37419 Mdot
.33909 .57445 Mdot
.44899 .38337 Mdot
.28727 .56281 Mdot
.45083 .73369 Mdot
.49581 .56348 Mdot
.51434 .71928 Mdot
.49937 .43244 Mdot
.46112 .70047 Mdot
.65444 .56305 Mdot
.59662 .42708 Mdot
.63008 .6011 Mdot
.45151 .68157 Mdot
.34457 .36968 Mdot
.60746 .34738 Mdot
.71932 .58972 Mdot
.4691 .39772 Mdot
.65909 .56127 Mdot
.45014 .66419 Mdot
.60891 .36169 Mdot
.38272 .28966 Mdot
.58213 .34745 Mdot
.33626 .39253 Mdot
.33879 .41264 Mdot
.44278 .70003 Mdot
.61115 .34497 Mdot
.29229 .56153 Mdot
.37258 .34657 Mdot
.56686 .53194 Mdot
.29869 .3652 Mdot
.61328 .40171 Mdot
.58442 .32951 Mdot
.63727 .3507 Mdot
.57048 .54954 Mdot
.48928 .48536 Mdot
.59776 .62184 Mdot
.35149 .40131 Mdot
.34606 .59307 Mdot
.50767 .76217 Mdot
.80406 .46013 Mdot
.48277 .44509 Mdot
.65898 .6108 Mdot
.5961 .60069 Mdot
.58554 .5871 Mdot
.58226 .54665 Mdot
.27616 .44082 Mdot
.57285 .56857 Mdot
.32467 .38828 Mdot
.30775 .5813 Mdot
.60306 .60141 Mdot
.47323 .38424 Mdot
.39528 .5123 Mdot
.46532 .70621 Mdot
.71137 .63803 Mdot
.60993 .254 Mdot
.60854 .3595 Mdot
.33279 .58816 Mdot
.31491 .56066 Mdot
.42852 .72017 Mdot
.35593 .35815 Mdot
.58156 .35644 Mdot
.68741 .68739 Mdot
.42179 .67854 Mdot
.57864 .56752 Mdot
.45321 .48616 Mdot
.75132 .65021 Mdot
.66008 .58454 Mdot
.60322 .55795 Mdot
.46684 .37406 Mdot
.30503 .62425 Mdot
.53725 .16607 Mdot
.37473 .23864 Mdot
.43873 .69707 Mdot
.42339 .69482 Mdot
.63077 .33168 Mdot
.66218 .57108 Mdot
.34724 .39338 Mdot
.49147 .53421 Mdot
.19815 .42392 Mdot
.56528 .21888 Mdot
.20067 .47533 Mdot
.60784 .61326 Mdot
.776 .53843 Mdot
.56122 .54547 Mdot
.63594 .31925 Mdot
.63799 .3452 Mdot
.59928 .35513 Mdot
.32858 .38547 Mdot
.53919 .80361 Mdot
.32331 .38749 Mdot
.61939 .25133 Mdot
.61675 .32925 Mdot
.41144 .48211 Mdot
.28599 .5721 Mdot
.69208 .58971 Mdot
.44149 .67558 Mdot
.49589 .70048 Mdot
.62522 .51374 Mdot
.50449 .63161 Mdot
.34015 .58499 Mdot
.57746 .36798 Mdot
.66157 .62662 Mdot
.51858 .20421 Mdot
.48209 .46987 Mdot
.17469 .51965 Mdot
.66872 .33113 Mdot
.44113 .71177 Mdot
.69852 .46559 Mdot
.4223 .68162 Mdot
.3675 .37418 Mdot
.62638 .56726 Mdot
.64747 .60187 Mdot
.59 .55334 Mdot
.57244 .54523 Mdot
.3317 .37202 Mdot
.56388 .53201 Mdot
.47042 .78345 Mdot
.46491 .40241 Mdot
.38245 .49043 Mdot
.43551 .7176 Mdot
.31328 .37228 Mdot
.3123 .58002 Mdot
.48133 .3792 Mdot
.42928 .65931 Mdot
.57056 .58381 Mdot
.6431 .59386 Mdot
.47258 .40098 Mdot
.58388 .64057 Mdot
.68297 .57741 Mdot
.29506 .58786 Mdot
.40859 .52849 Mdot
.44164 .72724 Mdot
.4483 .67315 Mdot
.31162 .36283 Mdot
.61199 .34698 Mdot
.43242 .72569 Mdot
.345 .56814 Mdot
.57676 .53236 Mdot
.5939 .52537 Mdot
.61122 .40284 Mdot
.53454 .79731 Mdot
.46678 .70221 Mdot
.54137 .56425 Mdot
.59875 .37619 Mdot
.63893 .38534 Mdot
.59427 .56847 Mdot
.5522 .53894 Mdot
.61165 .3151 Mdot
.42474 .70994 Mdot
.31471 .36295 Mdot
.42855 .4732 Mdot
.32134 .38814 Mdot
.6036 .37349 Mdot
.61566 .50544 Mdot
.60399 .39057 Mdot
.62565 .56309 Mdot
.29219 .80321 Mdot
.57928 .58682 Mdot
.58911 .66599 Mdot
.41154 .63086 Mdot
.27904 .58517 Mdot
.27935 .59008 Mdot
.46896 .3831 Mdot
.59028 .33078 Mdot
.57417 .50605 Mdot
.4333 .67735 Mdot
.49638 .3038 Mdot
.65538 .33362 Mdot
.28764 .61445 Mdot
.29367 .62315 Mdot
.34224 .36965 Mdot
.60502 .60927 Mdot
.59821 .5852 Mdot
.33663 .58978 Mdot
.24592 .42418 Mdot
.61748 .35158 Mdot
.61145 .58836 Mdot
.56851 .55546 Mdot
.30291 .58725 Mdot
.40314 .38748 Mdot
.64047 .38772 Mdot
.56823 .552 Mdot
.53119 .76482 Mdot
.32078 .39642 Mdot
.64227 .5495 Mdot
.56156 .54725 Mdot
.44587 .69208 Mdot
.51506 .69119 Mdot
.53124 .79172 Mdot
.37499 .38718 Mdot
.46006 .37789 Mdot
.64375 .60901 Mdot
.28184 .5812 Mdot
.64607 .62842 Mdot
.27339 .29214 Mdot
.45787 .40181 Mdot
.61373 .59766 Mdot
.59841 .51816 Mdot
.61169 .37758 Mdot
.62006 .59417 Mdot
.43204 .36222 Mdot
.30609 .60446 Mdot
.61348 .59834 Mdot
.81769 .48556 Mdot
.34495 .37086 Mdot
.63065 .51576 Mdot
.45948 .68374 Mdot
.40163 .57456 Mdot
.72684 .2864 Mdot
.27988 .56087 Mdot
.44208 .71834 Mdot
.59994 .60396 Mdot
.2889 .55991 Mdot
.35591 .35367 Mdot
.52466 .62157 Mdot
.6534 .55862 Mdot
.32361 .39196 Mdot
.34706 .39973 Mdot
.43927 .70127 Mdot
.22732 .72523 Mdot
.59697 .51898 Mdot
.61367 .57385 Mdot
.1763 .43704 Mdot
.59908 .31307 Mdot
.62113 .57475 Mdot
.60898 .61003 Mdot
.33082 .35473 Mdot
.62467 .76779 Mdot
.50778 .65351 Mdot
.26185 .42938 Mdot
.31758 .39139 Mdot
.28365 .62569 Mdot
.31242 .60653 Mdot
.4419 .71717 Mdot
.59258 .34147 Mdot
.45167 .721 Mdot
.30596 .59531 Mdot
.59463 .55415 Mdot
.35024 .36345 Mdot
.70718 .34851 Mdot
.30811 .35928 Mdot
.34403 .56221 Mdot
.64722 .3418 Mdot
.64286 .25581 Mdot
.23244 .31691 Mdot
.56054 .30386 Mdot
.37144 .40415 Mdot
.44266 .69397 Mdot
.36179 .25512 Mdot
.60524 .60381 Mdot
.73401 .58513 Mdot
.6147 .57172 Mdot
.64073 .42125 Mdot
.31493 .61196 Mdot
.48608 .39024 Mdot
.62082 .5614 Mdot
.50886 .65821 Mdot
.36726 .36857 Mdot
.35885 .38962 Mdot
.57732 .55407 Mdot
.33839 .39368 Mdot
.60236 .58937 Mdot
.30904 .58452 Mdot
.23722 .73009 Mdot
.62376 .60723 Mdot
.59821 .50049 Mdot
.36707 .35357 Mdot
.47132 .36393 Mdot
.31779 .62838 Mdot
.78466 .54375 Mdot
.51852 .19725 Mdot
.34329 .39144 Mdot
.64844 .65752 Mdot
.33323 .57321 Mdot
.47626 .3742 Mdot
.26753 .60288 Mdot
.60419 .57024 Mdot
.61363 .61567 Mdot
.5911 .54668 Mdot
.59886 .60159 Mdot
.73251 .54603 Mdot
.6852 .5775 Mdot
.72582 .43493 Mdot
.64106 .58745 Mdot
.59601 .6659 Mdot
.32108 .38027 Mdot
.6454 .50933 Mdot
.39865 .59315 Mdot
.6029 .61275 Mdot
.66329 .34354 Mdot
.31417 .37042 Mdot
.56087 .27266 Mdot
.32811 .37293 Mdot
.3077 .567 Mdot
.36817 .38653 Mdot
.63058 .56807 Mdot
.59116 .3583 Mdot
.32188 .59488 Mdot
.54034 .38523 Mdot
.33661 .6045 Mdot
.62246 .599 Mdot
.27551 .37528 Mdot
.28328 .57104 Mdot
.68343 .54588 Mdot
.58949 .35609 Mdot
.58292 .69622 Mdot
.61965 .31127 Mdot
.62294 .58986 Mdot
.62557 .58519 Mdot
.48739 .38676 Mdot
.3684 .37268 Mdot
.63043 .37927 Mdot
.2669 .7085 Mdot
.45743 .6669 Mdot
.59798 .34445 Mdot
.62392 .49231 Mdot
.47478 .47468 Mdot
.61996 .37646 Mdot
.6122 .69247 Mdot
.36006 .3636 Mdot
.61832 .32601 Mdot
.55914 .57452 Mdot
.6805 .47004 Mdot
.4368 .66988 Mdot
.27944 .56925 Mdot
.4826 .52207 Mdot
.31015 .60638 Mdot
.3079 .34979 Mdot
.28143 .61632 Mdot
.32316 .37866 Mdot
.56306 .43682 Mdot
.41748 .55071 Mdot
.3032 .37156 Mdot
.33697 .33773 Mdot
.2953 .59436 Mdot
.58088 .55046 Mdot
.39813 .50239 Mdot
.56357 .50831 Mdot
.65333 .52733 Mdot
.3263 .39848 Mdot
.60832 .32422 Mdot
.61483 .39212 Mdot
.53156 .61232 Mdot
.59906 .38361 Mdot
.32264 .58814 Mdot
.51063 .42085 Mdot
.73427 .61819 Mdot
.34814 .36962 Mdot
.37947 .60429 Mdot
.59913 .53519 Mdot
.28676 .59365 Mdot
.32481 .58364 Mdot
.34108 .3984 Mdot
.67147 .44918 Mdot
.6536 .52979 Mdot
.57577 .33225 Mdot
.6265 .33576 Mdot
.62213 .37462 Mdot
.63839 .34213 Mdot
.54813 .80759 Mdot
.30774 .37895 Mdot
.5971 .32813 Mdot
.57924 .54156 Mdot
.63692 .61097 Mdot
.45197 .38749 Mdot
.42626 .71058 Mdot
.59281 .61601 Mdot
.57037 .50666 Mdot
.59478 .56986 Mdot
.27933 .58308 Mdot
.58636 .47331 Mdot
.45982 .40116 Mdot
.28973 .62011 Mdot
.28118 .61245 Mdot
.46592 .37865 Mdot
.5711 .44132 Mdot
.5686 .18529 Mdot
.59225 .55044 Mdot
.6371 .27624 Mdot
.28285 .58454 Mdot
.49115 .60636 Mdot
.57808 .65188 Mdot
.62826 .53479 Mdot
.36783 .4985 Mdot
.31529 .58554 Mdot
.56854 .39275 Mdot
.607 .57434 Mdot
.48024 .38309 Mdot
.44902 .67221 Mdot
.58282 .48859 Mdot
.46861 .37372 Mdot
.60942 .33963 Mdot
.22967 .61666 Mdot
.56874 .35079 Mdot
.28536 .56747 Mdot
.6151 .51072 Mdot
.52058 .91629 Mdot
.30995 .57322 Mdot
.48336 .30196 Mdot
.41567 .55454 Mdot
.62156 .60548 Mdot
.3236 .59887 Mdot
.61378 .40528 Mdot
.32165 .39722 Mdot
.4654 .48932 Mdot
.59446 .33637 Mdot
.48222 .38063 Mdot
.45593 .38396 Mdot
.30039 .58829 Mdot
.63143 .34987 Mdot
.56453 .5357 Mdot
.58751 .37176 Mdot
.3587 .37264 Mdot
.63451 .55993 Mdot
.52777 .2053 Mdot
.65821 .52828 Mdot
.58893 .37126 Mdot
.35047 .57758 Mdot
.41753 .71514 Mdot
.65249 .57457 Mdot
.56109 .25121 Mdot
.60469 .60839 Mdot
.33418 .36783 Mdot
.45797 .59305 Mdot
.70843 .3571 Mdot
.58428 .56112 Mdot
.60226 .5358 Mdot
.32219 .35067 Mdot
.58673 .56021 Mdot
.62424 .52808 Mdot
.41514 .39682 Mdot
.61672 .37784 Mdot
.59905 .5961 Mdot
.30906 .60995 Mdot
.73269 .33068 Mdot
.62473 .56755 Mdot
.42164 .35657 Mdot
.56236 .68612 Mdot
.44123 .568 Mdot
.5781 .50311 Mdot
.50701 .7241 Mdot
.62201 .58224 Mdot
.63338 .53518 Mdot
.58646 .55052 Mdot
.77263 .5418 Mdot
.30048 .596 Mdot
.28788 .61068 Mdot
.45452 .67378 Mdot
.54504 .67552 Mdot
.45259 .70434 Mdot
.32439 .35117 Mdot
.37641 .60915 Mdot
.47132 .40028 Mdot
.61302 .34967 Mdot
.62167 .56637 Mdot
.33247 .60706 Mdot
.59842 .5774 Mdot
.62552 .54585 Mdot
.31668 .59147 Mdot
.32148 .5828 Mdot
.27455 .56493 Mdot
.42919 .66998 Mdot
.60414 .35267 Mdot
.60597 .55597 Mdot
.41769 .69067 Mdot
.56598 .56701 Mdot
.45344 .45372 Mdot
.60233 .35178 Mdot
.59022 .37395 Mdot
.60013 .3927 Mdot
.64423 .59814 Mdot
.63293 .56649 Mdot
.32331 .38787 Mdot
.61055 .4027 Mdot
.35954 .39382 Mdot
.32204 .6003 Mdot
.28809 .59839 Mdot
.60447 .56972 Mdot
.5465 .59002 Mdot
.43099 .71372 Mdot
.31875 .56499 Mdot
.44421 .39189 Mdot
.45821 .67884 Mdot
.58889 .59427 Mdot
.31612 .60409 Mdot
.46538 .69718 Mdot
.67448 .36803 Mdot
.49565 .18345 Mdot
.42872 .66817 Mdot
.57692 .554 Mdot
.80793 .45151 Mdot
.53175 .773 Mdot
.45389 .66189 Mdot
.32631 .36705 Mdot
.62339 .61264 Mdot
.2428 .37863 Mdot
.43195 .72931 Mdot
.53595 .79271 Mdot
.31451 .59533 Mdot
.54098 .51135 Mdot
.59906 .47988 Mdot
.73752 .61222 Mdot
.42457 .72803 Mdot
.58901 .36869 Mdot
.63351 .34343 Mdot
.57951 .56485 Mdot
.39089 .58957 Mdot
.3051 .35984 Mdot
.31549 .5606 Mdot
.30177 .61819 Mdot
.6297 .37007 Mdot
.49628 .4341 Mdot
.31093 .60886 Mdot
.66065 .55837 Mdot
.47003 .71021 Mdot
.69514 .58115 Mdot
.57435 .8185 Mdot
.7153 .28721 Mdot
.58272 .50241 Mdot
.41576 .7075 Mdot
.36631 .36455 Mdot
.3321 .3938 Mdot
.33142 .38766 Mdot
.29051 .60048 Mdot
.49923 .49789 Mdot
.30999 .61569 Mdot
.4003 .33273 Mdot
.43613 .71039 Mdot
.61203 .71196 Mdot
.5621 .573 Mdot
.62233 .60486 Mdot
.5904 .52987 Mdot
.59263 .54588 Mdot
.62041 .58263 Mdot
.33509 .40293 Mdot
.30259 .55735 Mdot
.19763 .44503 Mdot
.62738 .35728 Mdot
.37646 .28712 Mdot
.28738 .57061 Mdot
.45831 .37491 Mdot
.43216 .68917 Mdot
.52593 .70145 Mdot
.47527 .70132 Mdot
.31168 .56235 Mdot
.66225 .58053 Mdot
.62198 .32312 Mdot
.72407 .67423 Mdot
.63527 .58699 Mdot
.32426 .56569 Mdot
.27486 .62139 Mdot
.67706 .44439 Mdot
.61533 .63477 Mdot
.38857 .58639 Mdot
.4793 .47651 Mdot
.42099 .67281 Mdot
.65599 .61115 Mdot
.49754 .60032 Mdot
.30457 .59397 Mdot
.29678 .57366 Mdot
.44865 .65968 Mdot
.64085 .46915 Mdot
.61161 .33056 Mdot
.48531 .39318 Mdot
.32385 .36477 Mdot
.63616 .60027 Mdot
.29484 .60224 Mdot
.5599 .3877 Mdot
.44323 .47354 Mdot
.33653 .3747 Mdot
.29093 .62163 Mdot
.6113 .61218 Mdot
.58221 .56512 Mdot
.44511 .70873 Mdot
.27146 .66696 Mdot
.56392 .50812 Mdot
.49485 .30388 Mdot
.50674 .45594 Mdot
.41028 .56548 Mdot
.59424 .57688 Mdot
.61142 .38861 Mdot
.46807 .37971 Mdot
.44256 .67772 Mdot
.57416 .58627 Mdot
.54388 .1802 Mdot
.568 .36163 Mdot
.35287 .39579 Mdot
.47246 .3788 Mdot
.49817 .52407 Mdot
.60432 .6077 Mdot
.61414 .57168 Mdot
.57083 .54909 Mdot
.54538 .17664 Mdot
.30272 .61401 Mdot
.63513 .37112 Mdot
.4555 .70368 Mdot
.58465 .37077 Mdot
.27357 .59988 Mdot
.40401 .56363 Mdot
.57218 .56995 Mdot
.57145 .3579 Mdot
.58344 .36024 Mdot
.34643 .37089 Mdot
.35446 .35567 Mdot
.29303 .5547 Mdot
.60222 .60396 Mdot
.4796 .39577 Mdot
.60665 .32664 Mdot
.31961 .55902 Mdot
.44479 .70802 Mdot
.30144 .3942 Mdot
.64164 .58825 Mdot
.30026 .59087 Mdot
.58582 .50586 Mdot
.61723 .36862 Mdot
.30225 .56363 Mdot
.46933 .37154 Mdot
.4248 .70694 Mdot
.62735 .61719 Mdot
.18828 .49524 Mdot
.47833 .37993 Mdot
.64974 .58744 Mdot
.70868 .28813 Mdot
.39321 .58614 Mdot
.54289 .37103 Mdot
.32639 .60462 Mdot
.47886 .39314 Mdot
.63843 .3588 Mdot
.69679 .48407 Mdot
.29747 .57655 Mdot
.80626 .40827 Mdot
.41505 .48767 Mdot
.59695 .55106 Mdot
.60322 .33589 Mdot
.46679 .65588 Mdot
.5031 .29304 Mdot
.5201 .76647 Mdot
.608 .59277 Mdot
.30893 .60666 Mdot
.45056 .67372 Mdot
.36021 .38941 Mdot
.41573 .35868 Mdot
.6167 .8063 Mdot
.29573 .62086 Mdot
.61622 .56309 Mdot
.61098 .3247 Mdot
.34717 .39629 Mdot
.80672 .39045 Mdot
.34288 .56506 Mdot
.324 .6042 Mdot
.59903 .52875 Mdot
.45601 .69831 Mdot
.24596 .37853 Mdot
.29252 .61191 Mdot
.29085 .56019 Mdot
.42532 .39616 Mdot
.44902 .66848 Mdot
.57522 .54664 Mdot
.5319 .61338 Mdot
.56841 .54088 Mdot
.42352 .31009 Mdot
.47949 .39362 Mdot
.62661 .3552 Mdot
.62516 .57458 Mdot
.18617 .47826 Mdot
.3047 .57729 Mdot
.4827 .47571 Mdot
.39414 .39866 Mdot
.35549 .35657 Mdot
.30565 .60339 Mdot
.60354 .57932 Mdot
.32575 .41056 Mdot
.43625 .71529 Mdot
.56821 .55271 Mdot
.62873 .56429 Mdot
.62001 .4028 Mdot
.35189 .3654 Mdot
.73109 .3243 Mdot
.36448 .38123 Mdot
.3117 .36085 Mdot
.63829 .38715 Mdot
.57922 .56612 Mdot
.30928 .56473 Mdot
.35029 .56682 Mdot
.57132 .51617 Mdot
.49015 .60531 Mdot
.60864 .3316 Mdot
.32884 .54145 Mdot
.52257 .16999 Mdot
.59209 .52222 Mdot
.44608 .38513 Mdot
.63588 .42001 Mdot
.32056 .40024 Mdot
.59404 .55631 Mdot
.61554 .35793 Mdot
.31275 .55322 Mdot
.30032 .60803 Mdot
.62126 .62904 Mdot
.34053 .39923 Mdot
.46337 .70403 Mdot
.32689 .58214 Mdot
.43729 .46042 Mdot
.61682 .59778 Mdot
.47548 .40743 Mdot
.32827 .57991 Mdot
.74927 .29486 Mdot
.18771 .46457 Mdot
.62788 .36954 Mdot
.6268 .54047 Mdot
.6107 .31865 Mdot
.45378 .7103 Mdot
.27266 .6108 Mdot
.3292 .39533 Mdot
.71504 .58538 Mdot
.23056 .66748 Mdot
.29152 .59671 Mdot
.60795 .34388 Mdot
.61279 .56222 Mdot
.60746 .65563 Mdot
.61529 .60836 Mdot
.62971 .76167 Mdot
.46923 .69116 Mdot
.31004 .34155 Mdot
.35344 .40137 Mdot
.60905 .53728 Mdot
.41926 .69206 Mdot
.33506 .55152 Mdot
.31512 .59207 Mdot
.27802 .76806 Mdot
.4695 .37318 Mdot
.26565 .5625 Mdot
.64407 .59737 Mdot
.32972 .56191 Mdot
.80349 .46223 Mdot
.35753 .39868 Mdot
.56908 .53465 Mdot
.327 .61688 Mdot
.42564 .28996 Mdot
.47439 .47653 Mdot
.61266 .59628 Mdot
.56618 .61957 Mdot
.32684 .37034 Mdot
.36275 .25418 Mdot
.32921 .60369 Mdot
.56688 .56482 Mdot
.36258 .41832 Mdot
.54177 .42029 Mdot
.27056 .70664 Mdot
.60385 .35302 Mdot
.34547 .60423 Mdot
.3178 .36097 Mdot
.55262 .50565 Mdot
.4302 .71606 Mdot
.32476 .55212 Mdot
.33645 .60821 Mdot
.63402 .55498 Mdot
.59945 .61881 Mdot
.57508 .6236 Mdot
.60858 .33561 Mdot
.33262 .3554 Mdot
.61291 .54476 Mdot
.46659 .45077 Mdot
.59721 .5465 Mdot
.32306 .35703 Mdot
.42294 .89798 Mdot
.65167 .60233 Mdot
.64 .5923 Mdot
.69726 .64706 Mdot
.62789 .38243 Mdot
.6087 .38053 Mdot
.49016 .4508 Mdot
.6433 .60253 Mdot
.41465 .47098 Mdot
.60641 .35251 Mdot
.59819 .33794 Mdot
.4135 .4739 Mdot
.6398 .56244 Mdot
.35045 .42784 Mdot
.34499 .39622 Mdot
.35428 .35588 Mdot
.61019 .37776 Mdot
.6934 .59686 Mdot
.35973 .35618 Mdot
.734 .53641 Mdot
.30192 .56278 Mdot
.49786 .60008 Mdot
.5862 .37013 Mdot
.44811 .49522 Mdot
.36543 .37001 Mdot
.81468 .36613 Mdot
.72132 .66679 Mdot
.57434 .52247 Mdot
.58165 .56168 Mdot
.44786 .69555 Mdot
.65444 .64258 Mdot
.45791 .37882 Mdot
.33465 .39285 Mdot
.28364 .44675 Mdot
.59872 .3553 Mdot
.63389 .60818 Mdot
.50473 .75911 Mdot
.73057 .29509 Mdot
.52706 .61521 Mdot
.59184 .34106 Mdot
.5945 .35562 Mdot
.3404 .58802 Mdot
.30601 .56129 Mdot
.57275 .56385 Mdot
.32649 .38613 Mdot
.62523 .33182 Mdot
.34179 .35848 Mdot
.30637 .59446 Mdot
.2978 .56571 Mdot
.45115 .39739 Mdot
.66604 .54844 Mdot
.30657 .60064 Mdot
.39095 .34911 Mdot
.46451 .45056 Mdot
.62213 .40007 Mdot
.22771 .35643 Mdot
.82655 .4144 Mdot
.70544 .6177 Mdot
.44799 .67175 Mdot
.55782 .43488 Mdot
.37177 .39163 Mdot
.60639 .53723 Mdot
.6057 .56475 Mdot
.45837 .39391 Mdot
.37371 .38489 Mdot
.43863 .68729 Mdot
.36981 .37525 Mdot
.43439 .67972 Mdot
.28436 .60633 Mdot
.63092 .5727 Mdot
.58797 .59766 Mdot
.3566 .3902 Mdot
.33901 .57643 Mdot
.28229 .57207 Mdot
.42981 .67478 Mdot
.52902 .6866 Mdot
.30217 .58885 Mdot
.5858 .36983 Mdot
.74902 .363 Mdot
.45518 .38565 Mdot
.60751 .57508 Mdot
.50991 .73161 Mdot
.71254 .48794 Mdot
.60027 .55013 Mdot
.47443 .37892 Mdot
.23527 .74037 Mdot
.62871 .5699 Mdot
.40821 .84099 Mdot
.46382 .40046 Mdot
.6062 .39069 Mdot
.33273 .57603 Mdot
.47197 .37463 Mdot
.58024 .47679 Mdot
.32872 .5355 Mdot
.59519 .50986 Mdot
.60868 .32942 Mdot
.578 .37311 Mdot
.40993 .54149 Mdot
.42095 .30947 Mdot
.45718 .70024 Mdot
.43287 .69727 Mdot
.29681 .57923 Mdot
.35384 .33135 Mdot
.65522 .62965 Mdot
.43505 .69503 Mdot
.27839 .41507 Mdot
.59967 .53417 Mdot
.39881 .57743 Mdot
.39169 .49478 Mdot
.62 .38414 Mdot
.64536 .50764 Mdot
.30075 .57752 Mdot
.60736 .34437 Mdot
.4039 .51445 Mdot
.57534 .53216 Mdot
.6008 .3528 Mdot
.34357 .35535 Mdot
.40241 .4499 Mdot
.5918 .37905 Mdot
.46127 .48673 Mdot
.34816 .39136 Mdot
.39338 .58451 Mdot
.59694 .73283 Mdot
.60396 .15281 Mdot
.33071 .39097 Mdot
.33289 .57016 Mdot
.29454 .60022 Mdot
.30484 .58584 Mdot
.59771 .33399 Mdot
.31903 .57877 Mdot
.62344 .34335 Mdot
.35597 .34587 Mdot
.52204 .69429 Mdot
.44386 .70268 Mdot
.38353 .69096 Mdot
.59513 .36918 Mdot
.41246 .32778 Mdot
.18753 .39661 Mdot
.57798 .54672 Mdot
.3039 .37084 Mdot
.41655 .68871 Mdot
.52177 .44997 Mdot
.44687 .69246 Mdot
.33397 .57478 Mdot
.4989 .5989 Mdot
.60186 .59009 Mdot
.64083 .2702 Mdot
.45318 .67626 Mdot
.59291 .33871 Mdot
.65267 .56168 Mdot
.35717 .56662 Mdot
.44641 .71672 Mdot
.44083 .67108 Mdot
.61831 .58132 Mdot
.58033 .37295 Mdot
.30962 .56362 Mdot
.36928 .39786 Mdot
.46396 .66001 Mdot
.57403 .62808 Mdot
.582 .5541 Mdot
.65877 .59201 Mdot
.49225 .4697 Mdot
.24112 .35948 Mdot
.34457 .38936 Mdot
.52656 .78502 Mdot
.28667 .59597 Mdot
.52208 .76957 Mdot
.51266 .31318 Mdot
.46946 .72417 Mdot
.4767 .39592 Mdot
.48042 .3932 Mdot
.61593 .59178 Mdot
.25091 .31373 Mdot
.55687 .65835 Mdot
.38108 .40544 Mdot
.45788 .38714 Mdot
.28395 .56953 Mdot
.58338 .39566 Mdot
.64986 .49352 Mdot
.5677 .58839 Mdot
.37499 .38524 Mdot
.30918 .59077 Mdot
.27451 .28974 Mdot
.4368 .70939 Mdot
.51625 .44943 Mdot
.59869 .6003 Mdot
.61171 .58564 Mdot
.34475 .37903 Mdot
.32601 .39052 Mdot
.43765 .40309 Mdot
.44425 .54776 Mdot
.53959 .20802 Mdot
.33285 .34425 Mdot
.27347 .28971 Mdot
.65332 .28161 Mdot
.60903 .37406 Mdot
.44822 .38316 Mdot
.33689 .35066 Mdot
.62289 .57485 Mdot
.61084 .39096 Mdot
.53347 .63846 Mdot
.56551 .39029 Mdot
.39975 .5776 Mdot
.42998 .47105 Mdot
.59514 .59924 Mdot
.63019 .32706 Mdot
.60518 .34589 Mdot
.62988 .32328 Mdot
.46393 .38011 Mdot
.59289 .57307 Mdot
.58109 .54821 Mdot
.62775 .5684 Mdot
.6226 .65429 Mdot
.62033 .59459 Mdot
.51221 .30858 Mdot
.46974 .44307 Mdot
.32065 .70087 Mdot
.63968 .58327 Mdot
.32389 .35465 Mdot
.63118 .57443 Mdot
.4195 .70251 Mdot
.63754 .61452 Mdot
.39925 .57964 Mdot
.33545 .38585 Mdot
.65535 .47013 Mdot
.37 .57111 Mdot
.58165 .58797 Mdot
.46171 .70001 Mdot
.24138 .34798 Mdot
.50759 .77209 Mdot
.42298 .39327 Mdot
.58729 .37123 Mdot
.27771 .56752 Mdot
.30822 .38914 Mdot
.30382 .56626 Mdot
.56819 .53161 Mdot
.44706 .39599 Mdot
.84187 .56677 Mdot
.44672 .50639 Mdot
.625 .57558 Mdot
.66679 .55142 Mdot
.61368 .38631 Mdot
.30791 .57629 Mdot
.58927 .29383 Mdot
.59333 .53134 Mdot
.43883 .7249 Mdot
.42047 .71708 Mdot
.38529 .54021 Mdot
.36908 .44889 Mdot
.73059 .63856 Mdot
.34385 .38074 Mdot
.2933 .60499 Mdot
.42704 .72915 Mdot
.65576 .38272 Mdot
.30558 .36012 Mdot
.32137 .40116 Mdot
.34956 .3642 Mdot
.62437 .60093 Mdot
.45036 .39341 Mdot
.32406 .45322 Mdot
.4769 .37658 Mdot
.57994 .53621 Mdot
.3337 .61034 Mdot
.47686 .37496 Mdot
.45133 .69984 Mdot
.31044 .36559 Mdot
.28093 .57817 Mdot
.62617 .5875 Mdot
.60693 .35913 Mdot
.50971 .80158 Mdot
.16921 .53064 Mdot
.38893 .5921 Mdot
.38877 .59231 Mdot
.58648 .38597 Mdot
.58296 .23967 Mdot
.29831 .35908 Mdot
.6789 .4553 Mdot
.49557 .66969 Mdot
.5733 .51408 Mdot
.30174 .76132 Mdot
.31389 .61442 Mdot
.32292 .59336 Mdot
.60659 .59887 Mdot
.33301 .56073 Mdot
.62383 .61029 Mdot
.3335 .59917 Mdot
.47557 .28974 Mdot
.56347 .58105 Mdot
.32266 .58965 Mdot
.64639 .63705 Mdot
.6522 .57635 Mdot
.60586 .38813 Mdot
.32319 .55266 Mdot
.57544 .52223 Mdot
.81721 .62864 Mdot
.3512 .3746 Mdot
.46269 .38038 Mdot
.38858 .60025 Mdot
.36898 .38197 Mdot
.62108 .33602 Mdot
.64578 .60242 Mdot
.43878 .71385 Mdot
.60258 .37255 Mdot
.36024 .56482 Mdot
.45674 .68246 Mdot
.50867 .42214 Mdot
.60873 .37648 Mdot
.45373 .39095 Mdot
.42406 .70304 Mdot
.59566 .51014 Mdot
.32012 .59412 Mdot
.17986 .49039 Mdot
.47202 .3759 Mdot
.59935 .58547 Mdot
.34662 .60419 Mdot
.36961 .37528 Mdot
.57674 .57355 Mdot
.29589 .60436 Mdot
.46845 .37834 Mdot
.64802 .58243 Mdot
.65103 .59079 Mdot
.66542 .48936 Mdot
.46188 .61025 Mdot
.44676 .70298 Mdot
.64497 .37467 Mdot
.57873 .54098 Mdot
.42028 .68662 Mdot
.20358 .48772 Mdot
.55966 .55509 Mdot
.58213 .33422 Mdot
.69974 .50717 Mdot
.32525 .56222 Mdot
.35562 .39997 Mdot
.34536 .56383 Mdot
.46159 .68517 Mdot
.13933 .55061 Mdot
.45084 .38193 Mdot
.65995 .54648 Mdot
.61239 .52521 Mdot
.27311 .61468 Mdot
.60268 .34543 Mdot
.55148 .21369 Mdot
.63498 .61454 Mdot
.64842 .52121 Mdot
.61297 .57757 Mdot
.19425 .50066 Mdot
.60298 .33376 Mdot
.61016 .5755 Mdot
.57055 .62853 Mdot
.59627 .52466 Mdot
.45851 .71061 Mdot
.63078 .71027 Mdot
.61166 .55605 Mdot
.58356 .90382 Mdot
.46218 .40367 Mdot
.31547 .58916 Mdot
.46907 .48215 Mdot
.36778 .63108 Mdot
.54277 .82962 Mdot
.61722 .3363 Mdot
.65398 .30046 Mdot
.30574 .56486 Mdot
.48767 .80536 Mdot
.58583 .24746 Mdot
.65587 .57726 Mdot
.62011 .61359 Mdot
.33392 .5747 Mdot
.31486 .55865 Mdot
.45091 .40107 Mdot
.59359 .60967 Mdot
.66639 .53765 Mdot
.34944 .58462 Mdot
.63167 .59149 Mdot
.71857 .4652 Mdot
.33875 .41125 Mdot
.61121 .37847 Mdot
.36035 .38789 Mdot
.32746 .40426 Mdot
.72335 .57454 Mdot
.50747 .45793 Mdot
.31771 .37195 Mdot
.36863 .40958 Mdot
.39758 .65582 Mdot
.71948 .63021 Mdot
.45635 .71365 Mdot
.3936 .42633 Mdot
.29759 .5838 Mdot
.59261 .57061 Mdot
.59406 .33414 Mdot
.69059 .7451 Mdot
.4632 .19983 Mdot
.5042 .57983 Mdot
.58258 .54299 Mdot
.304 .57969 Mdot
.47192 .37713 Mdot
.55948 .56866 Mdot
.52864 .77178 Mdot
.60942 .58997 Mdot
.30562 .56025 Mdot
.73477 .6175 Mdot
.43821 .3627 Mdot
.32853 .3441 Mdot
.57298 .38945 Mdot
.62769 .57112 Mdot
.62017 .35556 Mdot
.31684 .38024 Mdot
.42578 .67416 Mdot
.44156 .69479 Mdot
.58526 .59317 Mdot
.41746 .54991 Mdot
.46863 .65231 Mdot
.65526 .57609 Mdot
.63476 .55711 Mdot
.47441 .39681 Mdot
.63452 .55766 Mdot
.56971 .57217 Mdot
.60966 .54422 Mdot
.5699 .58496 Mdot
.31786 .3533 Mdot
.5517 .32961 Mdot
.61145 .62034 Mdot
.61397 .52239 Mdot
.35524 .40887 Mdot
.54942 .55341 Mdot
.32701 .3748 Mdot
.49238 .19829 Mdot
.32152 .36733 Mdot
.44179 .69637 Mdot
.35292 .59364 Mdot
.64159 .28677 Mdot
.62599 .33297 Mdot
.32378 .3536 Mdot
.42734 .69297 Mdot
.33153 .38998 Mdot
.29564 .60973 Mdot
.20785 .39659 Mdot
.64276 .32438 Mdot
.45102 .44207 Mdot
.7098 .63863 Mdot
.47753 .40744 Mdot
.3395 .56822 Mdot
.63012 .36528 Mdot
.43133 .3635 Mdot
.6116 .5385 Mdot
.44432 .71239 Mdot
.6155 .59098 Mdot
.30881 .36628 Mdot
.30183 .58161 Mdot
.37024 .426 Mdot
.44724 .70203 Mdot
.14988 .53728 Mdot
.33436 .60489 Mdot
.64257 .53293 Mdot
.35415 .40868 Mdot
.21921 .38097 Mdot
.32318 .37195 Mdot
.52268 .69596 Mdot
.60754 .43218 Mdot
.66227 .76305 Mdot
.59429 .36192 Mdot
.4533 .40814 Mdot
.64419 .21586 Mdot
.54348 .27313 Mdot
.61047 .36707 Mdot
.37106 .57228 Mdot
.62469 .59692 Mdot
.59608 .54477 Mdot
.66932 .58619 Mdot
.55423 .35315 Mdot
.57157 .54842 Mdot
.45495 .38137 Mdot
.49743 .45765 Mdot
.25862 .40151 Mdot
.28311 .56211 Mdot
.61851 .61012 Mdot
.32717 .3994 Mdot
.30972 .35903 Mdot
.48104 .37732 Mdot
.36194 .37346 Mdot
.64672 .57179 Mdot
.59494 .36763 Mdot
.39905 .50428 Mdot
.45294 .71064 Mdot
.49295 .31438 Mdot
.4912 .6636 Mdot
.4742 .67468 Mdot
.59288 .5235 Mdot
.29929 .56502 Mdot
.24934 .70856 Mdot
.60055 .53871 Mdot
.60772 .35028 Mdot
.61808 .5271 Mdot
.61084 .54849 Mdot
.61204 .55857 Mdot
.29244 .6038 Mdot
.4658 .47847 Mdot
.63304 .59035 Mdot
.31673 .37234 Mdot
.41332 .47695 Mdot
.57539 .59938 Mdot
.2963 .45637 Mdot
.40061 .57725 Mdot
.47678 .40662 Mdot
.61968 .40146 Mdot
.31881 .56736 Mdot
.59725 .35689 Mdot
.573 .32244 Mdot
.62167 .3365 Mdot
.29368 .44197 Mdot
.68154 .46856 Mdot
.4363 .85219 Mdot
.80006 .4799 Mdot
.73746 .61924 Mdot
.57145 .34091 Mdot
.24101 .47476 Mdot
.61411 .36511 Mdot
.62012 .33653 Mdot
.34305 .84483 Mdot
.584 .33697 Mdot
.60309 .56958 Mdot
.63998 .61751 Mdot
.64673 .26181 Mdot
.39849 .65845 Mdot
.64466 .59487 Mdot
.57145 .5528 Mdot
.42392 .72485 Mdot
.61444 .45312 Mdot
.45116 .4034 Mdot
.51189 .44659 Mdot
.4445 .3815 Mdot
.61879 .58209 Mdot
.58979 .59304 Mdot
.6277 .62827 Mdot
.66807 .21654 Mdot
.65397 .77835 Mdot
.59008 .38671 Mdot
.54676 .54304 Mdot
.49204 .37346 Mdot
.63557 .53394 Mdot
.60989 .52577 Mdot
.62846 .56659 Mdot
.30872 .56461 Mdot
.5862 .39607 Mdot
.56662 .50751 Mdot
.51234 .3467 Mdot
.59599 .59874 Mdot
.48672 .67732 Mdot
.42143 .66881 Mdot
.60291 .57812 Mdot
.57851 .34212 Mdot
.58915 .54338 Mdot
.61207 .32064 Mdot
.61452 .37569 Mdot
.67155 .55467 Mdot
.33636 .45458 Mdot
.57563 .38889 Mdot
.6557 .57945 Mdot
.339 .57327 Mdot
.49079 .30283 Mdot
.59965 .58355 Mdot
.45557 .69332 Mdot
.59403 .55553 Mdot
.4624 .70291 Mdot
.62925 .55971 Mdot
.47964 .37834 Mdot
.70487 .36601 Mdot
.29539 .57551 Mdot
.46446 .6584 Mdot
.33402 .56274 Mdot
.68347 .54984 Mdot
.58049 .33182 Mdot
.42896 .37504 Mdot
.63147 .80034 Mdot
.47207 .398 Mdot
.52734 .79318 Mdot
.40882 .46807 Mdot
.34615 .40534 Mdot
.63949 .34904 Mdot
.73144 .61171 Mdot
.32792 .47303 Mdot
.26612 .58497 Mdot
.27767 .60952 Mdot
.28099 .71994 Mdot
.23777 .73129 Mdot
.63625 .59105 Mdot
.24046 .38116 Mdot
.7241 .42085 Mdot
.63158 .64748 Mdot
.58058 .61859 Mdot
.34086 .60353 Mdot
.64549 .59395 Mdot
.47731 .5114 Mdot
.29598 .59485 Mdot
.4294 .7022 Mdot
.6258 .35445 Mdot
.42353 .68639 Mdot
.42818 .19717 Mdot
.42079 .39262 Mdot
.30185 .59884 Mdot
.57205 .59031 Mdot
.63056 .60482 Mdot
.63704 .36828 Mdot
.80848 .40587 Mdot
.61559 .37822 Mdot
.45823 .70084 Mdot
.2881 .58584 Mdot
.73566 .67825 Mdot
.60042 .55611 Mdot
.58257 .35463 Mdot
.36999 .57268 Mdot
.58306 .56557 Mdot
.35059 .40048 Mdot
.58419 .54172 Mdot
.5817 .35964 Mdot
.63388 .55757 Mdot
.59639 .36674 Mdot
.33762 .5908 Mdot
.59288 .60316 Mdot
.58639 .58998 Mdot
.53176 .79071 Mdot
.44023 .68672 Mdot
.57674 .33681 Mdot
.47936 .51148 Mdot
.56858 .54086 Mdot
.53193 .76695 Mdot
.63033 .57192 Mdot
.65972 .65631 Mdot
.55308 .56914 Mdot
.45245 .38379 Mdot
.60964 .52481 Mdot
.60064 .58475 Mdot
.81629 .4567 Mdot
.80544 .4556 Mdot
.69722 .6359 Mdot
.35309 .35489 Mdot
.57789 .35555 Mdot
.29706 .60134 Mdot
.30504 .55434 Mdot
.32044 .57519 Mdot
.40731 .67016 Mdot
.54196 .56192 Mdot
.5986 .58964 Mdot
.33366 .33641 Mdot
.43433 .70006 Mdot
.58687 .34587 Mdot
.43967 .70138 Mdot
.51233 .45915 Mdot
.45531 .68642 Mdot
.45567 .37914 Mdot
.18889 .45997 Mdot
.71745 .48175 Mdot
.44703 .68014 Mdot
.61533 .37751 Mdot
.4256 .45799 Mdot
.57619 .51169 Mdot
.39835 .29712 Mdot
.43789 .72513 Mdot
.26127 .70617 Mdot
.64573 .58173 Mdot
.46971 .49114 Mdot
.33069 .37272 Mdot
.42378 .68663 Mdot
.35133 .36616 Mdot
.59119 .54329 Mdot
.54408 .3481 Mdot
.6105 .34545 Mdot
.34046 .41068 Mdot
.59646 .52662 Mdot
.42318 .6877 Mdot
.30779 .59906 Mdot
.7263 .62467 Mdot
.3636 .40768 Mdot
.50305 .80039 Mdot
.52004 .76735 Mdot
.28797 .58833 Mdot
.74895 .61694 Mdot
.33653 .36373 Mdot
.56872 .51625 Mdot
.54303 .50676 Mdot
.59207 .53737 Mdot
.27992 .57524 Mdot
.3247 .59207 Mdot
.5529 .29934 Mdot
.59168 .59773 Mdot
.62808 .62407 Mdot
.5948 .39662 Mdot
.28491 .5929 Mdot
.62168 .3352 Mdot
.63547 .36534 Mdot
.33504 .57437 Mdot
.62803 .37036 Mdot
.45136 .67537 Mdot
.50741 .49836 Mdot
.33296 .36364 Mdot
.34596 .40127 Mdot
.30408 .60064 Mdot
.28003 .59783 Mdot
.29505 .56623 Mdot
.59985 .53074 Mdot
.63255 .35086 Mdot
.63138 .54208 Mdot
.62317 .56799 Mdot
.62471 .41284 Mdot
.61059 .3978 Mdot
.61851 .53271 Mdot
.38752 .49055 Mdot
.45877 .71539 Mdot
.3219 .5875 Mdot
.34391 .35776 Mdot
.52256 .809 Mdot
.35272 .40692 Mdot
.56948 .54246 Mdot
.42502 .29264 Mdot
.59733 .33476 Mdot
.44751 .69366 Mdot
.39198 .5893 Mdot
.44804 .69926 Mdot
.33787 .41055 Mdot
.62544 .39423 Mdot
.5025 .42988 Mdot
.59238 .59965 Mdot
.49445 .46784 Mdot
.57455 .75595 Mdot
.51467 .31891 Mdot
.33487 .35485 Mdot
.57703 .5466 Mdot
.46651 .39986 Mdot
.67888 .44422 Mdot
.60102 .59316 Mdot
.56969 .5327 Mdot
.32728 .65158 Mdot
.60352 .52224 Mdot
.63334 .38698 Mdot
.41015 .55644 Mdot
.5793 .59386 Mdot
.68506 .55489 Mdot
.2793 .78021 Mdot
.64822 .5854 Mdot
.58552 .59071 Mdot
.59791 .56422 Mdot
.60677 .53573 Mdot
.60692 .31817 Mdot
.2661 .64919 Mdot
.32204 .39312 Mdot
.50691 .49896 Mdot
.34255 .36244 Mdot
.31771 .60082 Mdot
.46139 .52275 Mdot
.6111 .31958 Mdot
.44859 .69922 Mdot
.23543 .38345 Mdot
.49777 .58273 Mdot
.34126 .58512 Mdot
.57148 .81078 Mdot
.44499 .72189 Mdot
.57469 .51202 Mdot
.4557 .67437 Mdot
.34045 .60621 Mdot
.33829 .39837 Mdot
.66182 .58173 Mdot
.61118 .32785 Mdot
.59161 .37847 Mdot
.58206 .54071 Mdot
.48661 .31617 Mdot
.37027 .38391 Mdot
.44434 .75622 Mdot
.61916 .60236 Mdot
.56817 .53546 Mdot
.61988 .37766 Mdot
.30785 .57752 Mdot
.40978 .46955 Mdot
.43392 .686 Mdot
.66257 .56797 Mdot
.58938 .54572 Mdot
.51059 .46035 Mdot
.31927 .35391 Mdot
.46609 .38755 Mdot
.60534 .60304 Mdot
.50377 .45103 Mdot
.56887 .55048 Mdot
.68199 .61225 Mdot
.3338 .56639 Mdot
.65828 .53142 Mdot
.61041 .61356 Mdot
.5542 .32966 Mdot
.3418 .36488 Mdot
.60362 .3497 Mdot
.63961 .40373 Mdot
.48163 .38475 Mdot
.35383 .37893 Mdot
.61368 .53112 Mdot
.32069 .40222 Mdot
.60432 .54712 Mdot
.62899 .58893 Mdot
.33661 .35465 Mdot
.62707 .34136 Mdot
.53839 .21717 Mdot
.55115 .33054 Mdot
.62161 .54491 Mdot
.5904 .55665 Mdot
.40073 .65683 Mdot
.70065 .75049 Mdot
.60891 .61385 Mdot
.63292 .35736 Mdot
.58184 .56606 Mdot
.33869 .40278 Mdot
.45852 .69661 Mdot
.60936 .35645 Mdot
.28828 .60576 Mdot
.33306 .59622 Mdot
.33368 .62684 Mdot
.45261 .38037 Mdot
.59424 .60934 Mdot
.64458 .37674 Mdot
.60361 .39638 Mdot
.52144 .48358 Mdot
.31658 .58943 Mdot
.45925 .69061 Mdot
.64732 .59373 Mdot
.71714 .57881 Mdot
.32118 .398 Mdot
.60055 .89311 Mdot
.49928 .43272 Mdot
.43477 .65847 Mdot
.43828 .5663 Mdot
.46793 .39779 Mdot
.64131 .59381 Mdot
.41981 .69696 Mdot
.33082 .59335 Mdot
.59421 .54438 Mdot
.56117 .61283 Mdot
.33087 .47766 Mdot
.27786 .59976 Mdot
.32753 .4063 Mdot
.31864 .60964 Mdot
.46168 .70692 Mdot
.45655 .37919 Mdot
.58945 .38035 Mdot
.60489 .58487 Mdot
.65559 .52108 Mdot
.30815 .5843 Mdot
.4864 .3883 Mdot
.57789 .58321 Mdot
.58005 .36635 Mdot
.3208 .58205 Mdot
.61975 .57824 Mdot
.67597 .45055 Mdot
.64482 .29117 Mdot
.2932 .586 Mdot
.66156 .57321 Mdot
.67486 .51794 Mdot
.2774 .60373 Mdot
.32466 .61711 Mdot
.57113 .55125 Mdot
.42418 .68962 Mdot
.60421 .60883 Mdot
.32401 .37886 Mdot
.46498 .47792 Mdot
.35564 .38798 Mdot
.5323 .77403 Mdot
.61826 .62685 Mdot
.52947 .62753 Mdot
.62907 .32796 Mdot
.46492 .71869 Mdot
.82839 .50528 Mdot
.56475 .54309 Mdot
.55523 .19161 Mdot
.44851 .49248 Mdot
.46761 .43344 Mdot
.49991 .17195 Mdot
.43835 .68002 Mdot
.33116 .38727 Mdot
.57877 .58254 Mdot
.32915 .32795 Mdot
.43694 .67699 Mdot
.53349 .77408 Mdot
.64659 .54335 Mdot
.59676 .33897 Mdot
.61869 .60058 Mdot
.5813 .36392 Mdot
.58717 .56443 Mdot
.63287 .45526 Mdot
.48409 .67006 Mdot
.52331 .69455 Mdot
.57575 .50988 Mdot
.23249 .36317 Mdot
.71438 .63587 Mdot
.45555 .70037 Mdot
.62544 .54919 Mdot
.4685 .39282 Mdot
.36919 .3732 Mdot
.22049 .4219 Mdot
.30234 .56503 Mdot
.31865 .36722 Mdot
.62478 .36863 Mdot
.35278 .58589 Mdot
.48447 .39025 Mdot
.53866 .52252 Mdot
.42204 .69115 Mdot
.35154 .37536 Mdot
.60172 .58236 Mdot
.58591 .53269 Mdot
.19352 .50059 Mdot
.7622 .65834 Mdot
.63388 .36215 Mdot
.1819 .61437 Mdot
.64447 .37345 Mdot
.43484 .69146 Mdot
.32917 .56466 Mdot
.61943 .57112 Mdot
.5959 .59382 Mdot
.27907 .5914 Mdot
.62574 .38501 Mdot
.46718 .71972 Mdot
.67026 .75948 Mdot
.39938 .39397 Mdot
.57642 .7039 Mdot
.61183 .35685 Mdot
.57148 .70285 Mdot
.415 .72363 Mdot
.29941 .41794 Mdot
.69064 .67874 Mdot
.35585 .39691 Mdot
.58215 .7053 Mdot
.58618 .34352 Mdot
.63766 .59172 Mdot
.45468 .39128 Mdot
.45913 .40183 Mdot
.6223 .35972 Mdot
.33098 .57114 Mdot
.42898 .71482 Mdot
.61431 .59995 Mdot
.52532 .54406 Mdot
.80612 .38621 Mdot
.28206 .59813 Mdot
.66873 .55792 Mdot
.36803 .37757 Mdot
.58408 .56175 Mdot
.41975 .71826 Mdot
.34013 .39499 Mdot
.47 .37239 Mdot
.49643 .57065 Mdot
.6469 .60135 Mdot
.41031 .56398 Mdot
.33909 .37275 Mdot
.70583 .74594 Mdot
.58649 .5895 Mdot
.33709 .36379 Mdot
.65871 .52515 Mdot
.48222 .35252 Mdot
.40378 .49617 Mdot
.54277 .26948 Mdot
.29404 .55188 Mdot
.3295 .60235 Mdot
.80149 .64492 Mdot
.49644 .67075 Mdot
.31562 .366 Mdot
.46234 .37666 Mdot
.6581 .70204 Mdot
.35501 .3709 Mdot
.66016 .58337 Mdot
.63479 .57538 Mdot
.73539 .61693 Mdot
.70374 .60447 Mdot
.45352 .40338 Mdot
.53406 .5772 Mdot
.64677 .56511 Mdot
.60428 .5075 Mdot
.57533 .5652 Mdot
.57917 .37476 Mdot
.36169 .39336 Mdot
.39562 .14303 Mdot
.31021 .38937 Mdot
.51483 .56136 Mdot
.29788 .58354 Mdot
.32001 .54968 Mdot
.60413 .57835 Mdot
.5478 .659 Mdot
.2484 .3039 Mdot
.60482 .55634 Mdot
.39286 .58819 Mdot
.51897 .76835 Mdot
.56164 .52134 Mdot
.56764 .35655 Mdot
.66314 .53397 Mdot
.64377 .33258 Mdot
.34103 .39615 Mdot
.43867 .67893 Mdot
.44621 .72735 Mdot
.32879 .38089 Mdot
.59365 .58786 Mdot
.44081 .73121 Mdot
.61182 .58289 Mdot
.63438 .60134 Mdot
.51425 .45247 Mdot
.41988 .67815 Mdot
.29562 .56541 Mdot
.44344 .69581 Mdot
.61345 .33436 Mdot
.35816 .86179 Mdot
.44106 .70854 Mdot
.72047 .62949 Mdot
.46806 .50224 Mdot
.58258 .70775 Mdot
.59614 .38176 Mdot
.45688 .70558 Mdot
.35781 .39762 Mdot
.50284 .42097 Mdot
.74674 .61483 Mdot
.35131 .40688 Mdot
.6014 .59676 Mdot
.61378 .31977 Mdot
.59167 .39003 Mdot
.32959 .34554 Mdot
.61465 .38777 Mdot
.62835 .51945 Mdot
.65679 .5807 Mdot
.31515 .37631 Mdot
.72655 .28661 Mdot
.35692 .40031 Mdot
.7196 .58992 Mdot
.63185 .56693 Mdot
.60836 .35326 Mdot
.65314 .65741 Mdot
.6013 .41318 Mdot
.45003 .39715 Mdot
.63562 .61664 Mdot
.44848 .70895 Mdot
.49891 .49819 Mdot
.2933 .58438 Mdot
.43028 .29028 Mdot
.587 .37133 Mdot
.30397 .35746 Mdot
.60388 .3877 Mdot
.63181 .37507 Mdot
.34321 .40991 Mdot
.60826 .3387 Mdot
.59551 .59755 Mdot
.38148 .23032 Mdot
.59147 .37367 Mdot
.34041 .37918 Mdot
.44536 .71487 Mdot
.62908 .36773 Mdot
.41493 .74425 Mdot
.63419 .60537 Mdot
.34662 .57902 Mdot
.45808 .65863 Mdot
.62613 .32186 Mdot
.45759 .69553 Mdot
.31292 .58561 Mdot
.42698 .71439 Mdot
.35796 .33975 Mdot
.30238 .35298 Mdot
.50609 .58633 Mdot
.45925 .35587 Mdot
.59819 .33109 Mdot
.29943 .54836 Mdot
.63861 .60891 Mdot
.62416 .60316 Mdot
.46566 .70605 Mdot
.58046 .37949 Mdot
.47626 .31707 Mdot
.5788 .66068 Mdot
.49337 .3159 Mdot
.33932 .35182 Mdot
.4432 .77976 Mdot
.49871 .43104 Mdot
.4017 .3639 Mdot
.65271 .61671 Mdot
.46621 .39775 Mdot
.61262 .5768 Mdot
.50696 .77156 Mdot
.45401 .71684 Mdot
.2133 .52402 Mdot
.65552 .62945 Mdot
.28365 .58239 Mdot
.59237 .56052 Mdot
.24242 .402 Mdot
.68891 .57135 Mdot
.4418 .72565 Mdot
.33137 .41268 Mdot
.626 .33293 Mdot
.45118 .71504 Mdot
.33566 .59285 Mdot
.59792 .69252 Mdot
.65714 .59013 Mdot
.64858 .56988 Mdot
.28549 .61683 Mdot
.61776 .33211 Mdot
.31983 .59794 Mdot
.3337 .36349 Mdot
.4409 .70553 Mdot
.61266 .53599 Mdot
.64521 .52217 Mdot
.27543 .61698 Mdot
.308 .3788 Mdot
.27524 .58817 Mdot
.31845 .39918 Mdot
.46208 .3976 Mdot
.57938 .59763 Mdot
.29166 .62248 Mdot
.64486 .62668 Mdot
.79118 .43305 Mdot
.51104 .50516 Mdot
.80708 .53326 Mdot
.2964 .56471 Mdot
.47641 .64756 Mdot
.33316 .38247 Mdot
.3489 .37105 Mdot
.72494 .58359 Mdot
.24825 .31353 Mdot
.41442 .4713 Mdot
.1924 .41395 Mdot
.33217 .36358 Mdot
.346 .37534 Mdot
.33124 .58657 Mdot
.62004 .34035 Mdot
.58182 .31536 Mdot
.3384 .6113 Mdot
.51055 .73072 Mdot
.58654 .34611 Mdot
.5863 .20552 Mdot
.30489 .61745 Mdot
.65121 .61044 Mdot
.43158 .38014 Mdot
.44026 .72561 Mdot
.50844 .75989 Mdot
.20408 .40663 Mdot
.61281 .57032 Mdot
.3861 .8288 Mdot
.31271 .56686 Mdot
.4073 .41619 Mdot
.27084 .3721 Mdot
.57872 .53158 Mdot
.59309 .56346 Mdot
.5872 .58275 Mdot
.45246 .66153 Mdot
.79655 .39864 Mdot
.61707 .5717 Mdot
.51098 .67118 Mdot
.56284 .58003 Mdot
.18424 .49687 Mdot
.44323 .69608 Mdot
.62499 .76676 Mdot
.33962 .5499 Mdot
.50363 .34185 Mdot
.58876 .52434 Mdot
.32789 .36661 Mdot
.35579 .48471 Mdot
.32358 .35597 Mdot
.27613 .39694 Mdot
.68489 .68784 Mdot
.57645 .37154 Mdot
.58455 .54093 Mdot
.30687 .61911 Mdot
.61839 .32015 Mdot
.36957 .48837 Mdot
.3237 .83633 Mdot
.33024 .34859 Mdot
.17054 .65073 Mdot
.35914 .38218 Mdot
.45836 .40256 Mdot
.62199 .37014 Mdot
.57737 .67741 Mdot
.49904 .46531 Mdot
.62277 .33637 Mdot
.3457 .73686 Mdot
.61673 .30888 Mdot
.55594 .68674 Mdot
.64132 .31901 Mdot
.33864 .38454 Mdot
.30081 .35912 Mdot
.55696 .60016 Mdot
.62199 .61596 Mdot
.48691 .467 Mdot
.59602 .62767 Mdot
.64259 .60466 Mdot
.29567 .59486 Mdot
.44666 .35447 Mdot
.31905 .3271 Mdot
.61607 .35616 Mdot
.31444 .38591 Mdot
.59352 .56152 Mdot
.62236 .5453 Mdot
.62584 .52613 Mdot
.49576 .80769 Mdot
.58288 .20263 Mdot
.63202 .5884 Mdot
.68734 .57008 Mdot
.34056 .5808 Mdot
.19233 .50277 Mdot
.1926 .61078 Mdot
.67055 .69388 Mdot
.57565 .58038 Mdot
.44076 .68877 Mdot
.42339 .72563 Mdot
.6222 .52065 Mdot
.52366 .62508 Mdot
.4044 .74115 Mdot
.60144 .5823 Mdot
.5392 .6695 Mdot
.26544 .60172 Mdot
.48558 .38429 Mdot
.30849 .58473 Mdot
.62124 .31979 Mdot
.47085 .39937 Mdot
.30355 .60686 Mdot
.50602 .64915 Mdot
.47934 .38263 Mdot
.48598 .35132 Mdot
.458 .7027 Mdot
.57708 .5741 Mdot
.60942 .28771 Mdot
.28409 .59689 Mdot
.34357 .37179 Mdot
.60289 .36713 Mdot
.36684 .36682 Mdot
.18416 .48085 Mdot
.51274 .74173 Mdot
.45019 .3834 Mdot
.32496 .36789 Mdot
.42015 .53427 Mdot
.4405 .69058 Mdot
.36232 .37798 Mdot
.535 .63967 Mdot
.59008 .61398 Mdot
.30201 .24594 Mdot
.6502 .56455 Mdot
.56503 .28156 Mdot
.33887 .36833 Mdot
.46599 .37065 Mdot
.60612 .58639 Mdot
.33535 .603 Mdot
.5525 .52486 Mdot
.61341 .58385 Mdot
.30204 .61378 Mdot
.63562 .58937 Mdot
.41772 .68972 Mdot
.64283 .33383 Mdot
.4515 .50069 Mdot
.48108 .7899 Mdot
.43516 .71964 Mdot
.54493 .46906 Mdot
.61308 .61592 Mdot
.30599 .70795 Mdot
.59849 .33992 Mdot
.56656 .54217 Mdot
.54972 .78723 Mdot
.62198 .34909 Mdot
.59621 .35695 Mdot
.6356 .55475 Mdot
.35789 .40156 Mdot
.28016 .57726 Mdot
.44191 .6918 Mdot
.36325 .33583 Mdot
.62119 .57737 Mdot
.57532 .5475 Mdot
.44674 .7206 Mdot
.35182 .37857 Mdot
.61506 .53517 Mdot
.4846 .25847 Mdot
.52013 .48998 Mdot
.32333 .40181 Mdot
.57695 .60109 Mdot
.41618 .16407 Mdot
.5868 .31053 Mdot
.39841 .83571 Mdot
.48773 .6634 Mdot
.33403 .57004 Mdot
.67158 .57927 Mdot
.55295 .91469 Mdot
.45552 .70606 Mdot
.50646 .33079 Mdot
.63353 .59453 Mdot
.61814 .56763 Mdot
.57435 .35867 Mdot
.6304 .53874 Mdot
.5802 .34669 Mdot
.46098 .79043 Mdot
.22718 .32628 Mdot
.61279 .38709 Mdot
.57968 .35303 Mdot
.69955 .59359 Mdot
.50313 .81386 Mdot
.6263 .35847 Mdot
.65676 .59056 Mdot
.32739 .71154 Mdot
.57151 .62516 Mdot
.42058 .67182 Mdot
.39082 .71697 Mdot
.56843 .35217 Mdot
.76516 .58628 Mdot
.69873 .59554 Mdot
.6672 .47948 Mdot
.40112 .71864 Mdot
.32406 .36061 Mdot
.61737 .55409 Mdot
.45611 .37777 Mdot
.32418 .58303 Mdot
.61894 .5044 Mdot
.58317 .58361 Mdot
.59038 .3291 Mdot
.4589 .66869 Mdot
.35729 .37078 Mdot
.5716 .56019 Mdot
.281 .62455 Mdot
.42869 .69566 Mdot
.59783 .37673 Mdot
.7212 .6152 Mdot
.43731 .72993 Mdot
.65568 .53229 Mdot
.64137 .58718 Mdot
.57116 .56803 Mdot
.60626 .64748 Mdot
.32889 .37787 Mdot
.34717 .6014 Mdot
.67004 .57728 Mdot
.50835 .43463 Mdot
.49542 .5172 Mdot
.66135 .55272 Mdot
.6321 .3609 Mdot
.34249 .35298 Mdot
.46883 .38071 Mdot
.6128 .71189 Mdot
.64172 .57615 Mdot
.57129 .19505 Mdot
.60789 .80524 Mdot
.47664 .38473 Mdot
.59726 .31647 Mdot
.44698 .69509 Mdot
.63982 .5648 Mdot
.51375 .68515 Mdot
.65948 .58037 Mdot
.5617 .62251 Mdot
.32568 .56701 Mdot
.3339 .35817 Mdot
.53143 .50487 Mdot
.32527 .58492 Mdot
.59689 .35688 Mdot
.63836 .24698 Mdot
.59342 .31044 Mdot
.63389 .36857 Mdot
.33019 .45037 Mdot
.33058 .39423 Mdot
.56629 .91263 Mdot
.69354 .76058 Mdot
.64685 .61152 Mdot
.3254 .39347 Mdot
.62038 .36745 Mdot
.62354 .53102 Mdot
.59235 .33601 Mdot
.57654 .38834 Mdot
.64544 .59788 Mdot
.64303 .6016 Mdot
.52504 .68683 Mdot
.59721 .21407 Mdot
.44354 .71243 Mdot
.60939 .39057 Mdot
.71962 .53699 Mdot
.6231 .57416 Mdot
.59632 .6019 Mdot
.34549 .48007 Mdot
.45483 .71124 Mdot
.70754 .44999 Mdot
.62534 .60111 Mdot
.54001 .79835 Mdot
.63794 .61292 Mdot
.5683 .32975 Mdot
.36517 .35564 Mdot
.51684 .59005 Mdot
.28202 .57134 Mdot
.64024 .35323 Mdot
.46466 .70384 Mdot
.61095 .40524 Mdot
.70388 .48826 Mdot
.33879 .39735 Mdot
.58149 .35885 Mdot
.35422 .57394 Mdot
.35093 .38655 Mdot
.35256 .40146 Mdot
.37486 .4892 Mdot
.35201 .57493 Mdot
.44433 .66033 Mdot
.35851 .36382 Mdot
.67433 .45181 Mdot
.3412 .38658 Mdot
.69961 .48013 Mdot
.5919 .60491 Mdot
.50983 .66528 Mdot
.52426 .52875 Mdot
.56544 .61459 Mdot
.36314 .38807 Mdot
.42753 .70838 Mdot
.60495 .53093 Mdot
.61887 .38552 Mdot
.43442 .71064 Mdot
.4153 .39746 Mdot
.32823 .54959 Mdot
.58613 .38737 Mdot
.33255 .41151 Mdot
.5868 .33609 Mdot
.51527 .76507 Mdot
.47504 .70548 Mdot
.36848 .49904 Mdot
.49397 .47232 Mdot
.5933 .50645 Mdot
.69228 .56931 Mdot
.59491 .52828 Mdot
.59255 .59069 Mdot
.29395 .58614 Mdot
.40925 .66814 Mdot
.62929 .36792 Mdot
.80279 .36857 Mdot
.32766 .36967 Mdot
.41211 .55611 Mdot
.54896 .60649 Mdot
.60073 .54588 Mdot
.61427 .36905 Mdot
.58856 .39828 Mdot
.80629 .45677 Mdot
.27812 .58991 Mdot
.57883 .62949 Mdot
.58867 .52062 Mdot
.56796 .48034 Mdot
.35928 .39088 Mdot
.51443 .24171 Mdot
.29015 .55938 Mdot
.18487 .69195 Mdot
.32262 .58829 Mdot
.30809 .66439 Mdot
.60935 .33857 Mdot
.45647 .68503 Mdot
.60813 .60612 Mdot
.56665 .42094 Mdot
.5998 .31946 Mdot
.29641 .54433 Mdot
.45072 .69927 Mdot
.53304 .22593 Mdot
.31952 .38138 Mdot
.5745 .58457 Mdot
.64156 .61043 Mdot
.6314 .54553 Mdot
.63317 .53455 Mdot
.31504 .38056 Mdot
.65984 .57593 Mdot
.3629 .40924 Mdot
.71266 .48888 Mdot
.55512 .78264 Mdot
.31441 .62026 Mdot
.19327 .51738 Mdot
.63216 .37192 Mdot
.67861 .35842 Mdot
.71424 .46393 Mdot
.51156 .50448 Mdot
.36037 .34321 Mdot
.58422 .6009 Mdot
.33062 .57239 Mdot
.23713 .36233 Mdot
.31527 .61919 Mdot
.31475 .19813 Mdot
.73259 .62026 Mdot
.56825 .25727 Mdot
.64156 .54547 Mdot
.30151 .62538 Mdot
.7677 .5566 Mdot
.65022 .52552 Mdot
.44701 .73181 Mdot
.68565 .4762 Mdot
.5745 .29124 Mdot
.45969 .69314 Mdot
.63803 .60172 Mdot
.61346 .39811 Mdot
.60058 .59982 Mdot
.61681 .60837 Mdot
.60208 .55473 Mdot
.37454 .36713 Mdot
.62608 .62233 Mdot
.60479 .60881 Mdot
.75607 .66474 Mdot
.39458 .57223 Mdot
.34054 .59122 Mdot
.81107 .51365 Mdot
.43424 .70058 Mdot
.62316 .32159 Mdot
.45082 .49015 Mdot
.32153 .37767 Mdot
.80622 .46028 Mdot
.64572 .55415 Mdot
.51104 .30249 Mdot
.30099 .36509 Mdot
.42784 .68721 Mdot
.47152 .37888 Mdot
.49993 .21456 Mdot
.31311 .55997 Mdot
.44759 .39989 Mdot
.29317 .58314 Mdot
.79921 .56395 Mdot
.579 .35187 Mdot
.59537 .50672 Mdot
.35637 .36719 Mdot
.34023 .60394 Mdot
.51302 .67729 Mdot
.58096 .57255 Mdot
.2945 .56524 Mdot
.58815 .5014 Mdot
.49259 .50426 Mdot
.45377 .4848 Mdot
.34688 .5969 Mdot
.3003 .37808 Mdot
.35266 .39087 Mdot
.46074 .68642 Mdot
.63528 .33336 Mdot
.61213 .32937 Mdot
.34539 .39166 Mdot
.26628 .7531 Mdot
.61899 .57638 Mdot
.63198 .57684 Mdot
.50639 .43017 Mdot
.61731 .52816 Mdot
.43562 .64713 Mdot
.47292 .40316 Mdot
.60852 .32528 Mdot
.59874 .52899 Mdot
.61632 .5358 Mdot
.6446 .58563 Mdot
.51596 .73596 Mdot
.30883 .5826 Mdot
.64614 .56559 Mdot
.42076 .69462 Mdot
.43682 .40227 Mdot
.63583 .61094 Mdot
.62762 .51246 Mdot
.58192 .34311 Mdot
.26916 .70639 Mdot
.33794 .36993 Mdot
.28286 .5915 Mdot
.29458 .61701 Mdot
.57056 .74783 Mdot
.55823 .37524 Mdot
.45468 .40446 Mdot
.20005 .46832 Mdot
.46317 .37811 Mdot
.45355 .69407 Mdot
.4048 .48519 Mdot
.25837 .59683 Mdot
.33238 .60034 Mdot
.30444 .39395 Mdot
.57933 .53728 Mdot
.6417 .6075 Mdot
.50012 .33528 Mdot
.61341 .56116 Mdot
.44991 .70878 Mdot
.36146 .40274 Mdot
.58095 .35034 Mdot
.41955 .71587 Mdot
.35196 .37221 Mdot
.62 .33295 Mdot
.5574 .54585 Mdot
.66279 .56388 Mdot
.5995 .36512 Mdot
.59835 .37913 Mdot
.6001 .5714 Mdot
.78124 .63953 Mdot
.6139 .3252 Mdot
.60819 .37169 Mdot
.49693 .41026 Mdot
.33252 .56342 Mdot
.66299 .64524 Mdot
.32781 .39499 Mdot
.59604 .59976 Mdot
.30938 .62187 Mdot
.45042 .68305 Mdot
.59081 .36122 Mdot
.62139 .5572 Mdot
.62471 .58355 Mdot
.44236 .68898 Mdot
.41452 .69028 Mdot
.44444 .7181 Mdot
.36891 .36302 Mdot
.65594 .57867 Mdot
.62732 .36146 Mdot
.31906 .38151 Mdot
.43118 .72758 Mdot
.45321 .67129 Mdot
.75483 .6537 Mdot
.61036 .57057 Mdot
.43418 .73393 Mdot
.41368 .89327 Mdot
.61322 .69645 Mdot
.47524 .3985 Mdot
.26924 .61756 Mdot
.47203 .65023 Mdot
.46255 .6623 Mdot
.31877 .35981 Mdot
.40169 .57367 Mdot
.46599 .68678 Mdot
.61272 .55756 Mdot
.58338 .55711 Mdot
.65826 .61351 Mdot
.43238 .70605 Mdot
.51699 .74802 Mdot
.60507 .39397 Mdot
.72709 .39378 Mdot
.43431 .7008 Mdot
.34836 .59069 Mdot
.27962 .62096 Mdot
.32378 .59152 Mdot
.57096 .58281 Mdot
.82183 .48005 Mdot
.71959 .51719 Mdot
.708 .43895 Mdot
.3184 .37263 Mdot
.58737 .39721 Mdot
.36373 .42786 Mdot
.59556 .35681 Mdot
.31715 .57417 Mdot
.42746 .69905 Mdot
.57425 .36143 Mdot
.35084 .40127 Mdot
.35451 .39245 Mdot
.27378 .58407 Mdot
.31221 .58804 Mdot
.30428 .59905 Mdot
.63945 .34606 Mdot
.6087 .33845 Mdot
.61787 .53931 Mdot
.58904 .36519 Mdot
.61461 .80838 Mdot
.46294 .65327 Mdot
.27163 .60261 Mdot
.33474 .37505 Mdot
.60936 .37606 Mdot
.57852 .57836 Mdot
.34885 .64889 Mdot
.28792 .54882 Mdot
.42835 .72036 Mdot
.34864 .26734 Mdot
.20635 .33653 Mdot
.56884 .58768 Mdot
.3084 .37499 Mdot
.52705 .62745 Mdot
.58776 .57883 Mdot
.31725 .56368 Mdot
.64118 .7729 Mdot
.4752 .37687 Mdot
.61722 .61231 Mdot
.57167 .52737 Mdot
.35999 .39765 Mdot
.4525 .48849 Mdot
.60849 .55521 Mdot
.40345 .51547 Mdot
.31513 .35357 Mdot
.28873 .56029 Mdot
.81209 .64771 Mdot
.41051 .41101 Mdot
.48366 .76064 Mdot
.48219 .3911 Mdot
.61761 .56209 Mdot
.29455 .59314 Mdot
.42156 .71057 Mdot
.30202 .59087 Mdot
.59701 .31493 Mdot
.32461 .56211 Mdot
.57708 .55853 Mdot
.62785 .35494 Mdot
.35251 .37709 Mdot
.41378 .56324 Mdot
.76307 .62651 Mdot
.33616 .6017 Mdot
.48821 .38155 Mdot
.64021 .60375 Mdot
.67131 .42627 Mdot
.55413 .59338 Mdot
.61205 .61415 Mdot
.33231 .3547 Mdot
.61604 .3638 Mdot
.33889 .35205 Mdot
.57471 .50338 Mdot
.67056 .34116 Mdot
.32624 .37197 Mdot
.54304 .34267 Mdot
.446 .72153 Mdot
.50989 .73303 Mdot
.60671 .59374 Mdot
.35323 .36517 Mdot
.65362 .57854 Mdot
.60742 .39089 Mdot
.49336 .55558 Mdot
.557 .47428 Mdot
.36853 .37789 Mdot
.59105 .26371 Mdot
.48019 .51303 Mdot
.67554 .63551 Mdot
.34058 .36313 Mdot
.82755 .50339 Mdot
.46917 .39029 Mdot
.4369 .68421 Mdot
.41453 .7098 Mdot
.43467 .67308 Mdot
.6174 .56441 Mdot
.64927 .45781 Mdot
.44129 .66693 Mdot
.36014 .35556 Mdot
.42722 .67284 Mdot
.50879 .80435 Mdot
.48468 .31582 Mdot
.43817 .72139 Mdot
.61158 .59406 Mdot
.60037 .49879 Mdot
.39953 .57815 Mdot
.33883 .55712 Mdot
.53303 .20242 Mdot
.74323 .67195 Mdot
.61788 .57006 Mdot
.64868 .4445 Mdot
.57922 .3254 Mdot
.46122 .61496 Mdot
.5637 .47246 Mdot
.42794 .46158 Mdot
.6078 .37419 Mdot
.47181 .47827 Mdot
.61945 .3237 Mdot
.57192 .51035 Mdot
.62872 .5897 Mdot
.62253 .31683 Mdot
.41383 .28809 Mdot
.83247 .44079 Mdot
.49556 .31038 Mdot
.63149 .34524 Mdot
.34231 .36501 Mdot
.30989 .36231 Mdot
.33421 .35509 Mdot
.28942 .59921 Mdot
.5846 .3707 Mdot
.64301 .57303 Mdot
.33724 .58775 Mdot
.61642 .60534 Mdot
.34811 .39571 Mdot
.52024 .49462 Mdot
.58071 .34926 Mdot
.60132 .58451 Mdot
.74197 .58852 Mdot
.29956 .57806 Mdot
.43849 .69039 Mdot
.36398 .25322 Mdot
.26324 .60765 Mdot
.31113 .39305 Mdot
.56573 .37497 Mdot
.35196 .60848 Mdot
.25049 .64283 Mdot
.64979 .60929 Mdot
.65271 .60108 Mdot
.38424 .59862 Mdot
.75389 .59689 Mdot
.59868 .55063 Mdot
.33453 .59449 Mdot
.34033 .56709 Mdot
.65205 .58133 Mdot
.59464 .38333 Mdot
.45326 .66759 Mdot
.46548 .70699 Mdot
.58227 .50865 Mdot
.4874 .4715 Mdot
.51037 .66762 Mdot
.61501 .53242 Mdot
.67183 .60896 Mdot
.35132 .56722 Mdot
.48415 .39028 Mdot
.50829 .46232 Mdot
.44977 .67388 Mdot
.63344 .59679 Mdot
.8064 .39311 Mdot
.58595 .36779 Mdot
.28485 .57029 Mdot
.32916 .40186 Mdot
.43982 .73114 Mdot
.27028 .58906 Mdot
.65197 .58149 Mdot
.61573 .53538 Mdot
.36133 .37327 Mdot
.56527 .33671 Mdot
.42948 .70482 Mdot
.33827 .58577 Mdot
.45726 .68583 Mdot
.60579 .33731 Mdot
.60015 .3742 Mdot
.58982 .51845 Mdot
.56657 .61465 Mdot
.31914 .61344 Mdot
.66674 .58254 Mdot
.32485 .59766 Mdot
.19317 .50063 Mdot
.32054 .39693 Mdot
.5732 .53147 Mdot
.56485 .38883 Mdot
.34793 .3948 Mdot
.60755 .56427 Mdot
.38366 .59901 Mdot
.59733 .54062 Mdot
.33085 .6162 Mdot
.67421 .75104 Mdot
.44184 .67542 Mdot
.64662 .4992 Mdot
.66192 .66566 Mdot
.61213 .52763 Mdot
.34224 .56475 Mdot
.67801 .47788 Mdot
.32559 .37612 Mdot
.61494 .34391 Mdot
.25958 .7135 Mdot
.34091 .38153 Mdot
.61975 .59737 Mdot
.44021 .70809 Mdot
.62901 .33568 Mdot
.45209 .39432 Mdot
.48388 .45492 Mdot
.61655 .50242 Mdot
.55221 .53594 Mdot
.57059 .56242 Mdot
.19364 .41125 Mdot
.30249 .59658 Mdot
.61691 .36926 Mdot
.30939 .3704 Mdot
.33252 .39253 Mdot
.30769 .57725 Mdot
.56158 .29966 Mdot
.45786 .29207 Mdot
.45495 .9061 Mdot
.26986 .59528 Mdot
.42825 .67405 Mdot
.49227 .54388 Mdot
.32685 .58894 Mdot
.28743 .59287 Mdot
.34207 .55403 Mdot
.49262 .32866 Mdot
.63157 .34795 Mdot
.62628 .58308 Mdot
.60521 .40852 Mdot
.6187 .5635 Mdot
.4876 .75164 Mdot
.3434 .39464 Mdot
.61403 .34232 Mdot
.42115 .75215 Mdot
.68659 .56236 Mdot
.58984 .57123 Mdot
.47504 .7521 Mdot
.58788 .48697 Mdot
.59412 .70923 Mdot
.6318 .52868 Mdot
.30182 .58605 Mdot
.66135 .31992 Mdot
.66623 .55012 Mdot
.73905 .58936 Mdot
.35618 .38798 Mdot
.44779 .38764 Mdot
.56924 .50667 Mdot
.67951 .60853 Mdot
.63126 .33787 Mdot
.5734 .35696 Mdot
.44283 .66658 Mdot
.38179 .23502 Mdot
.35609 .3845 Mdot
.53781 .25432 Mdot
.6181 .61605 Mdot
.30152 .3371 Mdot
.65844 .76528 Mdot
.60108 .56368 Mdot
.38201 .48995 Mdot
.80591 .45883 Mdot
.5974 .54659 Mdot
.71239 .4312 Mdot
.33497 .37903 Mdot
.54434 .79173 Mdot
.65316 .54821 Mdot
.31131 .56414 Mdot
.61813 .33994 Mdot
.58738 .38839 Mdot
.42329 .71743 Mdot
.65062 .79028 Mdot
.276 .31997 Mdot
.61182 .33904 Mdot
.58396 .57978 Mdot
.33806 .3711 Mdot
.44925 .39383 Mdot
.63511 .5096 Mdot
.25663 .36 Mdot
.58498 .36205 Mdot
.67048 .57651 Mdot
.50767 .29904 Mdot
.46081 .48158 Mdot
.60085 .20704 Mdot
.34749 .35767 Mdot
.45224 .67468 Mdot
.61534 .64292 Mdot
.19819 .47443 Mdot
.66306 .56659 Mdot
.48616 .75502 Mdot
.55215 .3595 Mdot
.45839 .69588 Mdot
.59177 .5828 Mdot
.607 .55345 Mdot
.50014 .48163 Mdot
.41468 .71474 Mdot
.60875 .55494 Mdot
.65838 .62866 Mdot
.60791 .3319 Mdot
.47446 .4027 Mdot
.58197 .34943 Mdot
.59878 .59622 Mdot
.67964 .73685 Mdot
.5843 .37715 Mdot
.53592 .20889 Mdot
.49085 .66935 Mdot
.32119 .37581 Mdot
.67458 .56534 Mdot
.59717 .60865 Mdot
.51795 .15732 Mdot
.45153 .39838 Mdot
.20478 .63551 Mdot
.30467 .62487 Mdot
.8645 .49342 Mdot
.26241 .60299 Mdot
.58148 .25451 Mdot
.39878 .544 Mdot
.6647 .60342 Mdot
.70689 .60705 Mdot
.70341 .42911 Mdot
.30741 .33675 Mdot
.67591 .38445 Mdot
.6223 .61595 Mdot
.63972 .59206 Mdot
.3328 .58804 Mdot
.55397 .30191 Mdot
.51908 .59837 Mdot
.50624 .46318 Mdot
.42882 .68761 Mdot
.60229 .34634 Mdot
.57922 .55974 Mdot
.38602 .27909 Mdot
.34049 .59992 Mdot
.71726 .65943 Mdot
.60353 .58647 Mdot
.51346 .57733 Mdot
.52915 .3423 Mdot
.3502 .37401 Mdot
.34815 .59472 Mdot
.35117 .58272 Mdot
.62365 .5656 Mdot
.31844 .38544 Mdot
.60811 .53877 Mdot
.48165 .52208 Mdot
.62475 .50802 Mdot
.45326 .68948 Mdot
.59452 .60163 Mdot
.68385 .6676 Mdot
.66504 .23952 Mdot
.69074 .60338 Mdot
.63791 .35139 Mdot
.30604 .6019 Mdot
.31439 .58155 Mdot
.6138 .32935 Mdot
.31467 .58092 Mdot
.72849 .40389 Mdot
.65362 .41438 Mdot
.45464 .6941 Mdot
.72678 .48724 Mdot
.43705 .67795 Mdot
.44824 .38589 Mdot
.60645 .56977 Mdot
.26913 .46093 Mdot
.2688 .59161 Mdot
.52164 .80862 Mdot
.34177 .38987 Mdot
.45461 .40046 Mdot
.64874 .59599 Mdot
.41354 .73589 Mdot
.32312 .57255 Mdot
.39559 .44777 Mdot
.63535 .57455 Mdot
.62163 .38751 Mdot
.60038 .54675 Mdot
.56511 .59347 Mdot
.46064 .40341 Mdot
.56961 .55451 Mdot
.35175 .37202 Mdot
.58004 .36512 Mdot
.56526 .2639 Mdot
.28468 .5971 Mdot
.62785 .6107 Mdot
.58491 .57999 Mdot
.57425 .33961 Mdot
.64125 .61589 Mdot
.31628 .36877 Mdot
.63953 .87191 Mdot
.45039 .71705 Mdot
.48465 .38895 Mdot
.4281 .1972 Mdot
.58196 .54659 Mdot
.60371 .53217 Mdot
.4281 .43472 Mdot
.80766 .3999 Mdot
.33105 .36698 Mdot
.55905 .52575 Mdot
.3434 .58265 Mdot
.429 .70684 Mdot
.37018 .37438 Mdot
.65775 .57909 Mdot
.63707 .58636 Mdot
.45635 .70061 Mdot
.48414 .74606 Mdot
.46073 .72869 Mdot
.31989 .36205 Mdot
.6386 .43112 Mdot
.35396 .64737 Mdot
.61437 .5788 Mdot
.47649 .36829 Mdot
.61139 .36477 Mdot
.33438 .36209 Mdot
.78872 .38622 Mdot
.57227 .51102 Mdot
.32927 .40779 Mdot
.35394 .37908 Mdot
.63701 .61944 Mdot
.55662 .36627 Mdot
.59029 .40312 Mdot
.61156 .36715 Mdot
.56132 .7761 Mdot
.17841 .57167 Mdot
.30043 .59959 Mdot
.3389 .37541 Mdot
.30254 .6226 Mdot
.46638 .69009 Mdot
.4954 .51175 Mdot
.34872 .58453 Mdot
.62973 .38178 Mdot
.30382 .62043 Mdot
.60508 .53748 Mdot
.34739 .40294 Mdot
.30392 .61686 Mdot
.62449 .53214 Mdot
.66451 .62378 Mdot
.70458 .60303 Mdot
.45496 .66712 Mdot
.47159 .47713 Mdot
.61335 .59876 Mdot
.47248 .37998 Mdot
.60081 .57554 Mdot
.31484 .37326 Mdot
.40656 .57741 Mdot
.64651 .56065 Mdot
.2688 .59321 Mdot
.19664 .59109 Mdot
.33054 .55856 Mdot
.59405 .62149 Mdot
.6021 .59729 Mdot
.61521 .57668 Mdot
.64493 .59922 Mdot
.58182 .28679 Mdot
.34035 .4156 Mdot
.56487 .62419 Mdot
.27471 .59611 Mdot
.59457 .36045 Mdot
.58831 .38315 Mdot
.42475 .45336 Mdot
.44586 .39672 Mdot
.32273 .39165 Mdot
.61719 .5769 Mdot
.39564 .44968 Mdot
.48255 .44294 Mdot
.50008 .30332 Mdot
.3458 .61842 Mdot
.32985 .60318 Mdot
.63719 .36436 Mdot
.309 .6116 Mdot
.65746 .58206 Mdot
.6691 .58606 Mdot
.56564 .26029 Mdot
.3825 .39133 Mdot
.42853 .70264 Mdot
.61111 .60524 Mdot
.51569 .71707 Mdot
.34052 .58085 Mdot
.35195 .57041 Mdot
.61168 .53953 Mdot
.56558 .3433 Mdot
.68458 .22555 Mdot
.32973 .39906 Mdot
.66927 .43079 Mdot
.64481 .30379 Mdot
.56919 .4762 Mdot
.32903 .38322 Mdot
.39221 .49456 Mdot
.32557 .55188 Mdot
.71704 .7224 Mdot
.59737 .36609 Mdot
.42935 .7011 Mdot
.64658 .5375 Mdot
.63002 .38117 Mdot
.28743 .62066 Mdot
.61362 .32169 Mdot
.59636 .50644 Mdot
.34174 .35069 Mdot
.32123 .58428 Mdot
.29388 .3731 Mdot
.61255 .31672 Mdot
.43851 .67679 Mdot
.53017 .78933 Mdot
.67745 .44685 Mdot
.80529 .45777 Mdot
.64563 .56575 Mdot
.31162 .46831 Mdot
.64142 .5724 Mdot
.62121 .39549 Mdot
.60734 .59396 Mdot
.67942 .54475 Mdot
.3169 .54953 Mdot
.6539 .54048 Mdot
.59831 .60487 Mdot
.73477 .58581 Mdot
.59469 .56463 Mdot
.64825 .58742 Mdot
.57341 .52064 Mdot
.57331 .31847 Mdot
.64643 .53377 Mdot
.62313 .38579 Mdot
.50859 .32228 Mdot
.28634 .59093 Mdot
.46576 .69208 Mdot
.46242 .70534 Mdot
.47527 .76286 Mdot
.51458 .72298 Mdot
.5492 .31116 Mdot
.58747 .34786 Mdot
.36112 .39034 Mdot
.60931 .53776 Mdot
.82202 .5263 Mdot
.65969 .73974 Mdot
.3071 .55143 Mdot
.31242 .61757 Mdot
.65921 .55365 Mdot
.2359 .31518 Mdot
.65277 .54076 Mdot
.5008 .43167 Mdot
.62145 .56685 Mdot
.56946 .53395 Mdot
.35474 .58098 Mdot
.51364 .76456 Mdot
.64631 .56579 Mdot
.63029 .33618 Mdot
.43137 .69257 Mdot
.54303 .50575 Mdot
.63777 .756 Mdot
.72024 .58748 Mdot
.57776 .6626 Mdot
.65111 .56107 Mdot
.33699 .57557 Mdot
.63224 .34467 Mdot
.50557 .44042 Mdot
.31748 .37013 Mdot
.48321 .46399 Mdot
.70586 .48137 Mdot
.27429 .37679 Mdot
.42859 .69659 Mdot
.34785 .54754 Mdot
.57669 .55723 Mdot
.2922 .60001 Mdot
.56463 .51908 Mdot
.46999 .44009 Mdot
.45477 .68834 Mdot
.63925 .33723 Mdot
.34263 .36539 Mdot
.61774 .39265 Mdot
.80805 .53008 Mdot
.66644 .73806 Mdot
.86544 .4962 Mdot
.30553 .55892 Mdot
.72998 .32213 Mdot
.623 .35828 Mdot
.63545 .57213 Mdot
.4503 .904 Mdot
.61142 .35853 Mdot
.62537 .38533 Mdot
.43075 .46909 Mdot
.53187 .77471 Mdot
.66772 .56163 Mdot
.60943 .32389 Mdot
.35713 .55934 Mdot
.44692 .69968 Mdot
.6272 .53449 Mdot
.58121 .50525 Mdot
.57407 .35907 Mdot
.31807 .57183 Mdot
.49934 .74556 Mdot
.3074 .58629 Mdot
.63089 .3499 Mdot
.29581 .57529 Mdot
.53325 .21634 Mdot
.34485 .59209 Mdot
.59369 .60298 Mdot
.61704 .57768 Mdot
.26734 .41853 Mdot
.60011 .37418 Mdot
.60316 .53173 Mdot
.63543 .59211 Mdot
.6256 .36186 Mdot
.25752 .59701 Mdot
.77114 .36349 Mdot
.59717 .53169 Mdot
.6225 .57963 Mdot
.45655 .71104 Mdot
.48261 .49613 Mdot
.49145 .42808 Mdot
.6187 .53113 Mdot
.4304 .67502 Mdot
.63985 .3572 Mdot
.5995 .57397 Mdot
.51234 .76564 Mdot
.26674 .60589 Mdot
.64892 .55166 Mdot
.45066 .38921 Mdot
.60091 .55321 Mdot
.67631 .22583 Mdot
.63796 .60596 Mdot
.62082 .37152 Mdot
.62198 .34683 Mdot
.37058 .56022 Mdot
.59847 .35759 Mdot
.47172 .39992 Mdot
.3511 .39129 Mdot
.64405 .25 Mdot
.46768 .4009 Mdot
.56618 .55988 Mdot
.69057 .76429 Mdot
.58707 .505 Mdot
.62605 .51101 Mdot
.5072 .81568 Mdot
.48079 .39259 Mdot
.61768 .35981 Mdot
.41408 .28365 Mdot
.6651 .58302 Mdot
.32482 .39503 Mdot
.64582 .5224 Mdot
.64942 .55239 Mdot
.69353 .56792 Mdot
.64511 .41984 Mdot
.35841 .40616 Mdot
.66672 .64342 Mdot
.62703 .53463 Mdot
.80775 .40194 Mdot
.5775 .56941 Mdot
.43298 .7224 Mdot
.59176 .33865 Mdot
.30055 .61081 Mdot
.45146 .69372 Mdot
.57868 .55192 Mdot
.43348 .70453 Mdot
.29436 .59873 Mdot
.35542 .36361 Mdot
.58887 .59744 Mdot
.42041 .67176 Mdot
.42681 .69894 Mdot
.62573 .55212 Mdot
.61476 .34013 Mdot
.55109 .5835 Mdot
.59884 .57134 Mdot
.65172 .58938 Mdot
.61098 .32946 Mdot
.45682 .85464 Mdot
.64374 .58807 Mdot
.38918 .4935 Mdot
.64794 .34753 Mdot
.4722 .40237 Mdot
.32611 .60261 Mdot
.64536 .63055 Mdot
.33185 .3937 Mdot
.34817 .39085 Mdot
.27577 .57267 Mdot
.57506 .3476 Mdot
.32015 .58136 Mdot
.69522 .58976 Mdot
.66929 .58296 Mdot
.64757 .53863 Mdot
.25798 .71238 Mdot
.49376 .20729 Mdot
.61042 .37982 Mdot
.3322 .55591 Mdot
.49142 .46557 Mdot
.33855 .40197 Mdot
.35347 .56562 Mdot
.62299 .40135 Mdot
.58425 .33354 Mdot
.61534 .32825 Mdot
.42485 .6855 Mdot
.31825 .58936 Mdot
.63083 .40015 Mdot
.58449 .39912 Mdot
.61997 .54436 Mdot
.63058 .53725 Mdot
.60567 .30977 Mdot
.28296 .54316 Mdot
.44569 .6801 Mdot
.33545 .56933 Mdot
.62837 .16962 Mdot
.32892 .39881 Mdot
.73546 .58787 Mdot
.62042 .53042 Mdot
.2348 .76893 Mdot
.64711 .53561 Mdot
.58175 .57724 Mdot
.62117 .31974 Mdot
.42333 .7304 Mdot
.44402 .6997 Mdot
.6233 .35682 Mdot
.56812 .37337 Mdot
.4234 .70676 Mdot
.41952 .47645 Mdot
.71192 .26285 Mdot
.49984 .44763 Mdot
.62095 .37633 Mdot
.68164 .44564 Mdot
.36767 .37252 Mdot
.64564 .35552 Mdot
.30841 .40182 Mdot
.28496 .5907 Mdot
.33246 .60622 Mdot
.36394 .37607 Mdot
.64616 .58688 Mdot
.30408 .56153 Mdot
.69544 .59946 Mdot
.56479 .24508 Mdot
.26405 .35549 Mdot
.83608 .54061 Mdot
.60728 .61508 Mdot
.52094 .61548 Mdot
.44833 .34181 Mdot
.57102 .54929 Mdot
.65267 .65859 Mdot
.43033 .70449 Mdot
.64643 .34611 Mdot
.37392 .38645 Mdot
.55165 .18931 Mdot
.61503 .57806 Mdot
.62947 .36705 Mdot
.34231 .40449 Mdot
.52637 .22409 Mdot
.40326 .51458 Mdot
.6105 .54782 Mdot
.49881 .91293 Mdot
.60733 .31797 Mdot
.30088 .61065 Mdot
.74434 .54882 Mdot
.63402 .38316 Mdot
.31048 .64901 Mdot
.33745 .61437 Mdot
.52871 .45336 Mdot
.60084 .32285 Mdot
.46501 .72247 Mdot
.60115 .34153 Mdot
.41691 .6979 Mdot
.56482 .37197 Mdot
.30629 .57299 Mdot
.59294 .57751 Mdot
.30393 .57604 Mdot
.43861 .72624 Mdot
.2924 .56199 Mdot
.37379 .3867 Mdot
.48145 .38706 Mdot
.35206 .39593 Mdot
.49478 .52248 Mdot
.76973 .39056 Mdot
.33419 .358 Mdot
.38178 .4659 Mdot
.59402 .55252 Mdot
.56867 .32914 Mdot
.2942 .60827 Mdot
.27458 .56619 Mdot
.4778 .47534 Mdot
.62468 .33863 Mdot
.30948 .56911 Mdot
.67939 .45333 Mdot
.26874 .76058 Mdot
.68151 .57292 Mdot
.17224 .54885 Mdot
.62504 .36596 Mdot
.32879 .55096 Mdot
.50534 .42996 Mdot
.57976 .37832 Mdot
.31213 .61578 Mdot
.34512 .36411 Mdot
.32848 .38934 Mdot
.6386 .61686 Mdot
.33466 .34616 Mdot
.3454 .56747 Mdot
.80811 .39623 Mdot
.59816 .33341 Mdot
.47544 .19961 Mdot
.43661 .71977 Mdot
.28838 .59499 Mdot
.66239 .55092 Mdot
.56952 .39872 Mdot
.29018 .61678 Mdot
.25087 .32341 Mdot
.57295 .15674 Mdot
.30972 .5686 Mdot
.59079 .33939 Mdot
.5907 .35846 Mdot
.69112 .59667 Mdot
.49664 .46803 Mdot
.3191 .57002 Mdot
.26741 .45996 Mdot
.51944 .696 Mdot
.46184 .39771 Mdot
.74951 .66852 Mdot
.64726 .56685 Mdot
.65097 .5598 Mdot
.31747 .36456 Mdot
.58884 .56797 Mdot
.57539 .38744 Mdot
.64268 .53301 Mdot
.31519 .35533 Mdot
.2859 .5629 Mdot
.60909 .57312 Mdot
.43011 .71133 Mdot
.33893 .35349 Mdot
.30554 .37078 Mdot
.28882 .58104 Mdot
.6003 .32967 Mdot
.3977 .29652 Mdot
.30966 .58642 Mdot
.65627 .57566 Mdot
.47495 .38676 Mdot
.62263 .52508 Mdot
.27585 .4272 Mdot
.60574 .3951 Mdot
.3086 .61139 Mdot
.61923 .31296 Mdot
.34421 .37642 Mdot
.29709 .5515 Mdot
.57383 .55966 Mdot
.33011 .60527 Mdot
.37574 .50041 Mdot
.30847 .68857 Mdot
.57597 .39108 Mdot
.39319 .58335 Mdot
.57262 .35091 Mdot
.46028 .39775 Mdot
.56817 .74037 Mdot
.43975 .68242 Mdot
.33984 .56895 Mdot
.53215 .20757 Mdot
.28762 .60596 Mdot
.59649 .56229 Mdot
.63836 .58339 Mdot
.33216 .59008 Mdot
.43359 .67701 Mdot
.46826 .78186 Mdot
.45453 .65189 Mdot
.58387 .36724 Mdot
.41831 .54701 Mdot
.6596 .19226 Mdot
.31469 .63167 Mdot
.36226 .38682 Mdot
.59319 .66055 Mdot
.59196 .54571 Mdot
.35111 .40634 Mdot
.31554 .3883 Mdot
.42871 .72718 Mdot
.28638 .59694 Mdot
.64555 .37536 Mdot
.37079 .38365 Mdot
.58702 .41353 Mdot
.50237 .75619 Mdot
.55876 .5222 Mdot
.60151 .46227 Mdot
.57934 .59388 Mdot
.46091 .4811 Mdot
.32109 .35236 Mdot
.61903 .59421 Mdot
.64084 .64461 Mdot
.32818 .36405 Mdot
.42381 .72404 Mdot
.60134 .43101 Mdot
.30333 .56787 Mdot
.24956 .76216 Mdot
.59034 .59868 Mdot
.59512 .57489 Mdot
.3185 .37352 Mdot
.75927 .59178 Mdot
.61315 .38202 Mdot
.59675 .3312 Mdot
.30313 .59705 Mdot
.45236 .4403 Mdot
.64301 .61529 Mdot
.57742 .57967 Mdot
.30602 .56303 Mdot
.472 .3805 Mdot
.80747 .61913 Mdot
.62336 .58475 Mdot
.33203 .37994 Mdot
.35657 .48511 Mdot
.32876 .35063 Mdot
.56193 .57214 Mdot
.59997 .56053 Mdot
.57325 .57818 Mdot
.61224 .61973 Mdot
.36741 .38464 Mdot
.57133 .55984 Mdot
.55054 .53567 Mdot
.61521 .36287 Mdot
.65063 .56448 Mdot
.52108 .69501 Mdot
.61861 .58349 Mdot
.43143 .71189 Mdot
.47733 .42881 Mdot
.63078 .60882 Mdot
.65159 .5651 Mdot
.51708 .6949 Mdot
.59119 .58526 Mdot
.34634 .40546 Mdot
.59384 .36474 Mdot
.34339 .37479 Mdot
.35947 .38472 Mdot
.29709 .6192 Mdot
.41534 .69742 Mdot
.65835 .62459 Mdot
.42176 .701 Mdot
.6906 .57801 Mdot
.58095 .50285 Mdot
.49016 .50712 Mdot
.49958 .4329 Mdot
.46658 .68456 Mdot
.57446 .56892 Mdot
.29732 .59505 Mdot
.313 .61138 Mdot
.40144 .57371 Mdot
.64779 .52071 Mdot
.373 .37919 Mdot
.35249 .36485 Mdot
.44292 .64552 Mdot
.4177 .6335 Mdot
.42583 .70217 Mdot
.48904 .58579 Mdot
.56263 .5374 Mdot
.63768 .59893 Mdot
.60422 .50236 Mdot
.31359 .62276 Mdot
.48256 .38684 Mdot
.27879 .57326 Mdot
.49765 .40587 Mdot
.36576 .36637 Mdot
.60733 .6149 Mdot
.27511 .28868 Mdot
.58531 .3751 Mdot
.59376 .36562 Mdot
.31342 .356 Mdot
.33283 .5593 Mdot
.62888 .5097 Mdot
.18543 .64145 Mdot
.58037 .38504 Mdot
.46346 .68777 Mdot
.59806 .59843 Mdot
.28782 .58651 Mdot
.57781 .35896 Mdot
.42952 .66595 Mdot
.59848 .61103 Mdot
.35385 .59603 Mdot
.61273 .58986 Mdot
.72731 .45446 Mdot
.61654 .35217 Mdot
.52053 .48415 Mdot
.58783 .31189 Mdot
.36221 .39314 Mdot
.33673 .36758 Mdot
.60615 .56344 Mdot
.21084 .69825 Mdot
.63944 .40456 Mdot
.3376 .41051 Mdot
.43155 .6666 Mdot
.48019 .38173 Mdot
.42675 .66984 Mdot
.32586 .59632 Mdot
.43046 .69216 Mdot
.28913 .61555 Mdot
.26925 .55138 Mdot
.65353 .35999 Mdot
.45466 .70371 Mdot
.76272 .60185 Mdot
.66914 .58741 Mdot
.43482 .72837 Mdot
.6535 .54574 Mdot
.69186 .57037 Mdot
.29504 .56671 Mdot
.42445 .68989 Mdot
.62182 .55704 Mdot
.42964 .19278 Mdot
.35041 .37197 Mdot
.37317 .38448 Mdot
.66836 .58645 Mdot
.33869 .55337 Mdot
.56867 .37992 Mdot
.45862 .50366 Mdot
.48132 .39799 Mdot
.5786 .58154 Mdot
.57632 .59345 Mdot
.6056 .31585 Mdot
.63348 .36995 Mdot
.6055 .56171 Mdot
.66316 .43721 Mdot
.57644 .55474 Mdot
.32636 .38616 Mdot
.58437 .36978 Mdot
.59078 .36213 Mdot
.34807 .57555 Mdot
.57489 .35061 Mdot
.55284 .60199 Mdot
.34806 .34072 Mdot
.61244 .51516 Mdot
.343 .37865 Mdot
.33385 .52972 Mdot
.27869 .58854 Mdot
.5291 .20469 Mdot
.57617 .34808 Mdot
.59819 .52904 Mdot
.58958 .38354 Mdot
.44562 .7171 Mdot
.59732 .37352 Mdot
.58812 .31665 Mdot
.63107 .61547 Mdot
.61378 .55739 Mdot
.47094 .38247 Mdot
.48973 .47251 Mdot
.61251 .34708 Mdot
.58124 .5415 Mdot
.6055 .52429 Mdot
.63852 .57955 Mdot
.4789 .50856 Mdot
.63007 .32422 Mdot
.72336 .57423 Mdot
.28348 .41686 Mdot
.61144 .34152 Mdot
.6116 .18955 Mdot
.45982 .37866 Mdot
.44502 .39557 Mdot
.30453 .38725 Mdot
.62536 .5822 Mdot
.31571 .57887 Mdot
.65168 .55877 Mdot
.66236 .53296 Mdot
.62499 .61033 Mdot
.45713 .70083 Mdot
.65132 .60741 Mdot
.45681 .38993 Mdot
.30451 .58377 Mdot
.58369 .54195 Mdot
.61512 .57316 Mdot
.44536 .39076 Mdot
.59855 .30876 Mdot
.58278 .3358 Mdot
.47459 .36253 Mdot
.42831 .72473 Mdot
.32539 .35515 Mdot
.65666 .57014 Mdot
.3006 .5958 Mdot
.30777 .57825 Mdot
.62054 .39029 Mdot
.31633 .56428 Mdot
.3229 .35435 Mdot
.57925 .56913 Mdot
.36298 .3921 Mdot
.45701 .70134 Mdot
.59235 .33819 Mdot
.65878 .57951 Mdot
.61971 .5465 Mdot
.62191 .34702 Mdot
.59717 .55095 Mdot
.45876 .70145 Mdot
.32978 .61435 Mdot
.5997 .37841 Mdot
.35063 .39038 Mdot
.34916 .58074 Mdot
.60935 .53569 Mdot
.47106 .13692 Mdot
.58839 .56695 Mdot
.57959 .58626 Mdot
.60629 .25622 Mdot
.58552 .52389 Mdot
.28511 .60051 Mdot
.58267 .37766 Mdot
.5711 .59201 Mdot
.51722 .70041 Mdot
.45813 .74327 Mdot
.32507 .6262 Mdot
.5949 .59745 Mdot
.58917 .19766 Mdot
.60785 .52725 Mdot
.55067 .2145 Mdot
.49069 .50624 Mdot
.20541 .40969 Mdot
.60244 .4625 Mdot
.33513 .4101 Mdot
.4745 .38207 Mdot
.28011 .59773 Mdot
.7759 .53832 Mdot
.59141 .5583 Mdot
.80864 .44858 Mdot
.65945 .57444 Mdot
.32905 .38493 Mdot
.64167 .65697 Mdot
.3321 .56738 Mdot
.74487 .66831 Mdot
.6472 .57761 Mdot
.61242 .31957 Mdot
.30734 .54681 Mdot
.47141 .37719 Mdot
.62357 .56137 Mdot
.42682 .71593 Mdot
.47763 .70353 Mdot
.55598 .60623 Mdot
.34568 .37958 Mdot
.63551 .59602 Mdot
.67155 .62487 Mdot
.27736 .75736 Mdot
.61384 .36851 Mdot
.35714 .37419 Mdot
.47806 .63342 Mdot
.63675 .58027 Mdot
.5858 .33253 Mdot
.59643 .36415 Mdot
.41977 .70849 Mdot
.39068 .35121 Mdot
.41537 .76173 Mdot
.31358 .23574 Mdot
.81909 .48924 Mdot
.32064 .62095 Mdot
.54488 .38328 Mdot
.64084 .55338 Mdot
.66929 .73788 Mdot
.35843 .38851 Mdot
.59448 .57786 Mdot
.80021 .47911 Mdot
.6088 .37151 Mdot
.61856 .58974 Mdot
.44637 .68147 Mdot
.41672 .32266 Mdot
.69204 .48002 Mdot
.4946 .15299 Mdot
.35835 .5621 Mdot
.65602 .53573 Mdot
.54327 .5645 Mdot
.47392 .40148 Mdot
.56457 .57857 Mdot
.2924 .60594 Mdot
.3224 .46982 Mdot
.44703 .67454 Mdot
.58346 .37274 Mdot
.46362 .37703 Mdot
.65989 .57184 Mdot
.58072 .5131 Mdot
.4612 .68203 Mdot
.63355 .56753 Mdot
.73814 .5442 Mdot
.44195 .38469 Mdot
.34418 .59409 Mdot
.61585 .32213 Mdot
.57607 .58994 Mdot
.47843 .38193 Mdot
.63699 .612 Mdot
.66181 .6723 Mdot
.60651 .60226 Mdot
.63218 .25893 Mdot
.6174 .33897 Mdot
.35121 .38245 Mdot
.65254 .60834 Mdot
.60985 .58319 Mdot
.35772 .64977 Mdot
.6377 .51402 Mdot
.64022 .60166 Mdot
.62541 .39023 Mdot
.58703 .37829 Mdot
.63088 .36755 Mdot
.34726 .58133 Mdot
.50362 .45104 Mdot
.33715 .38932 Mdot
.61012 .5034 Mdot
.37127 .37799 Mdot
.6127 .46439 Mdot
.44831 .67006 Mdot
.51164 .19498 Mdot
.58236 .55972 Mdot
.62151 .33267 Mdot
.73731 .30214 Mdot
.63938 .3614 Mdot
.30052 .41019 Mdot
.35641 .38634 Mdot
.61089 .35475 Mdot
.59052 .58765 Mdot
.50615 .46636 Mdot
.45352 .15099 Mdot
.34153 .40237 Mdot
.6266 .51283 Mdot
.36139 .56442 Mdot
.26934 .5802 Mdot
.64263 .21388 Mdot
.35392 .4013 Mdot
.44292 .3423 Mdot
.59517 .53166 Mdot
.5788 .36931 Mdot
.339 .35631 Mdot
.33548 .40654 Mdot
.3127 .56288 Mdot
.61141 .5448 Mdot
.61165 .58498 Mdot
.45083 .3867 Mdot
.36443 .37145 Mdot
.62679 .4831 Mdot
.60708 .54806 Mdot
.57569 .25708 Mdot
.62756 .39791 Mdot
.46651 .85598 Mdot
.68831 .63029 Mdot
.80133 .47144 Mdot
.35659 .5231 Mdot
.60168 .38099 Mdot
.64797 .58413 Mdot
.61582 .50564 Mdot
.33653 .61155 Mdot
.58206 .56988 Mdot
.3189 .55312 Mdot
.35842 .39737 Mdot
.51919 .19042 Mdot
.39844 .45722 Mdot
.3658 .34586 Mdot
.59151 .56671 Mdot
.68468 .47481 Mdot
.45275 .70402 Mdot
.38009 .39744 Mdot
.62289 .38105 Mdot
.56295 .55486 Mdot
.30903 .6251 Mdot
.34603 .58095 Mdot
.6028 .36597 Mdot
.50766 .3458 Mdot
.53755 .20777 Mdot
.6053 .61764 Mdot
.32609 .60045 Mdot
.40289 .42002 Mdot
.67767 .36803 Mdot
.3051 .38248 Mdot
.45009 .67586 Mdot
.28173 .59665 Mdot
.35884 .35278 Mdot
.6887 .56301 Mdot
.60425 .35591 Mdot
.60108 .3183 Mdot
.35551 .63181 Mdot
.31315 .57095 Mdot
.44421 .69073 Mdot
.40559 .56226 Mdot
.41077 .56306 Mdot
.45342 .68639 Mdot
.30823 .55109 Mdot
.59614 .38209 Mdot
.63012 .36042 Mdot
.59366 .36318 Mdot
.73921 .58946 Mdot
.5947 .392 Mdot
.56864 .81113 Mdot
.56237 .56443 Mdot
.67245 .42239 Mdot
.57535 .53957 Mdot
.36908 .39647 Mdot
.61696 .35049 Mdot
.49602 .50083 Mdot
.56714 .53086 Mdot
.47488 .15404 Mdot
.61179 .59968 Mdot
.37169 .48885 Mdot
.62468 .58089 Mdot
.73399 .50776 Mdot
.64746 .34948 Mdot
.573 .56257 Mdot
.32351 .33577 Mdot
.43325 .7086 Mdot
.65626 .35137 Mdot
.63943 .6009 Mdot
.51337 .29858 Mdot
.65253 .54495 Mdot
.57539 .21658 Mdot
.26849 .65009 Mdot
.46127 .71639 Mdot
.60489 .52092 Mdot
.27855 .61192 Mdot
.55583 .65422 Mdot
.68027 .43393 Mdot
.34264 .40229 Mdot
.68033 .4661 Mdot
.3226 .56238 Mdot
.65607 .65657 Mdot
.55426 .55951 Mdot
.44033 .67339 Mdot
.60741 .43286 Mdot
.32426 .38277 Mdot
.59087 .55639 Mdot
.6458 .58219 Mdot
.24673 .37717 Mdot
.68967 .44519 Mdot
.57501 .49259 Mdot
.45746 .6716 Mdot
.69605 .47741 Mdot
.62878 .6074 Mdot
.32769 .62485 Mdot
.57776 .37416 Mdot
.58924 .64935 Mdot
.73591 .61913 Mdot
.57896 .54504 Mdot
.60956 .35925 Mdot
.57613 .34529 Mdot
.76544 .32053 Mdot
.44202 .66984 Mdot
.60803 .60242 Mdot
.33747 .64092 Mdot
.65698 .5769 Mdot
.33285 .38935 Mdot
.55843 .54404 Mdot
.28205 .58131 Mdot
.51079 .42241 Mdot
.34703 .57913 Mdot
.628 .56921 Mdot
.59806 .34043 Mdot
.32043 .37542 Mdot
.19274 .46562 Mdot
.41236 .38571 Mdot
.5652 .81099 Mdot
.47947 .69957 Mdot
.42621 .7095 Mdot
.42054 .67758 Mdot
.38107 .41233 Mdot
.59149 .59283 Mdot
.45463 .48279 Mdot
.68081 .5619 Mdot
.6302 .582 Mdot
.61003 .60623 Mdot
.41057 .391 Mdot
.35547 .38563 Mdot
.29964 .5742 Mdot
.6042 .56073 Mdot
.58055 .54161 Mdot
.6064 .34353 Mdot
.42655 .69831 Mdot
.33484 .60904 Mdot
.43566 .72437 Mdot
.30128 .58755 Mdot
.67299 .22177 Mdot
.56906 .51022 Mdot
.43508 .70923 Mdot
.33628 .35124 Mdot
.63265 .3492 Mdot
.44733 .39416 Mdot
.32595 .59466 Mdot
.33066 .56765 Mdot
.57088 .55661 Mdot
.58729 .33862 Mdot
.58625 .33503 Mdot
.42368 .70658 Mdot
.34786 .36196 Mdot
.61236 .62416 Mdot
.61065 .55369 Mdot
.18564 .49664 Mdot
.34138 .60626 Mdot
.68735 .4647 Mdot
.6297 .26504 Mdot
.58805 .59028 Mdot
.59031 .33015 Mdot
.6054 .57483 Mdot
.37217 .43655 Mdot
.63299 .36501 Mdot
.57848 .52745 Mdot
.66772 .52315 Mdot
.31458 .62215 Mdot
.82858 .40392 Mdot
.65754 .62201 Mdot
.29271 .34648 Mdot
.63361 .5541 Mdot
.86971 .46062 Mdot
.74929 .31585 Mdot
.66113 .57819 Mdot
.61641 .61993 Mdot
.32828 .21696 Mdot
.62034 .52901 Mdot
.45386 .3871 Mdot
.65976 .5297 Mdot
.58765 .33034 Mdot
.39348 .51112 Mdot
.46851 .47813 Mdot
.43059 .67145 Mdot
.30231 .59756 Mdot
.52313 .76973 Mdot
.41834 .71338 Mdot
.62232 .37009 Mdot
.57885 .51143 Mdot
.63794 .27413 Mdot
.26279 .58502 Mdot
.57042 .59962 Mdot
.33124 .388 Mdot
.46805 .47703 Mdot
.2771 .57898 Mdot
.35193 .39101 Mdot
.60492 .52612 Mdot
.23585 .66659 Mdot
.28215 .34759 Mdot
.77442 .32165 Mdot
.31911 .3639 Mdot
.34977 .37426 Mdot
.51171 .45858 Mdot
.42984 .67203 Mdot
.25016 .41958 Mdot
.53993 .58488 Mdot
.33238 .40033 Mdot
.61537 .71058 Mdot
.35168 .59313 Mdot
.46583 .44239 Mdot
.64645 .35632 Mdot
.57155 .50621 Mdot
.59671 .59031 Mdot
.33547 .36099 Mdot
.54593 .35127 Mdot
.44012 .62444 Mdot
.34885 .39967 Mdot
.54547 .57287 Mdot
.46483 .43512 Mdot
.47833 .38744 Mdot
.45528 .37985 Mdot
.43657 .66448 Mdot
.33635 .73164 Mdot
.61589 .33483 Mdot
.46328 .69334 Mdot
.53541 .48304 Mdot
.61992 .60107 Mdot
.36739 .37445 Mdot
.44944 .38108 Mdot
.34681 .38964 Mdot
.44399 .70483 Mdot
.455 .67388 Mdot
.61503 .36404 Mdot
.61166 .38342 Mdot
.66793 .32431 Mdot
.5448 .67531 Mdot
.6445 .54924 Mdot
.78153 .38258 Mdot
.63176 .3722 Mdot
.76935 .56422 Mdot
.42208 .68743 Mdot
.43021 .68455 Mdot
.70698 .39874 Mdot
.61592 .53881 Mdot
.36016 .48665 Mdot
.6329 .60766 Mdot
.60291 .7299 Mdot
.66047 .56848 Mdot
.31119 .56358 Mdot
.64707 .57144 Mdot
.39286 .2839 Mdot
.58868 .54058 Mdot
.61303 .60877 Mdot
.32244 .59086 Mdot
.63001 .62826 Mdot
.28474 .57393 Mdot
.64451 .59046 Mdot
.41582 .72587 Mdot
.30114 .59572 Mdot
.40728 .69839 Mdot
.4022 .49281 Mdot
.46424 .38291 Mdot
.42347 .67561 Mdot
.42899 .71665 Mdot
.49768 .7431 Mdot
.61326 .38734 Mdot
.69408 .6428 Mdot
.59632 .5955 Mdot
.35159 .56774 Mdot
.34819 .35542 Mdot
.57757 .54605 Mdot
.64229 .53178 Mdot
.65406 .62765 Mdot
.6131 .36126 Mdot
.3201 .5502 Mdot
.43764 .7044 Mdot
.317 .61088 Mdot
.40999 .70925 Mdot
.27707 .60255 Mdot
.67275 .60875 Mdot
.68964 .57188 Mdot
.54898 .54269 Mdot
.79465 .44042 Mdot
.69611 .75244 Mdot
.60257 .36046 Mdot
.47167 .39039 Mdot
.4478 .66947 Mdot
.41933 .55093 Mdot
.61487 .33093 Mdot
.32968 .56869 Mdot
.61251 .58997 Mdot
.54317 .55269 Mdot
.5423 .51872 Mdot
.6013 .41354 Mdot
.41241 .66419 Mdot
.31475 .59961 Mdot
.46982 .3984 Mdot
.4958 .44692 Mdot
.61262 .29337 Mdot
.49612 .51525 Mdot
.60801 .57901 Mdot
.42385 .71031 Mdot
.57785 .35925 Mdot
.26915 .43493 Mdot
.34031 .3627 Mdot
.49343 .47004 Mdot
.59036 .56835 Mdot
.49486 .35612 Mdot
.59756 .34123 Mdot
.43989 .67716 Mdot
.33395 .36115 Mdot
.43327 .67204 Mdot
.4729 .37488 Mdot
.48417 .36751 Mdot
.62741 .56217 Mdot
.63891 .60502 Mdot
.36389 .36498 Mdot
.61334 .33407 Mdot
.43357 .74501 Mdot
.25018 .36795 Mdot
.32865 .59445 Mdot
.43957 .44899 Mdot
.5811 .36714 Mdot
.44702 .35466 Mdot
.33232 .601 Mdot
.3593 .35448 Mdot
.45903 .48432 Mdot
.31089 .36 Mdot
.62139 .60818 Mdot
.58573 .35204 Mdot
.35228 .40304 Mdot
.19368 .49816 Mdot
.61677 .227 Mdot
.61759 .42014 Mdot
.60488 .55644 Mdot
.51187 .19264 Mdot
.48175 .30971 Mdot
.56874 .41957 Mdot
.36966 .38626 Mdot
.60207 .56571 Mdot
.60249 .61609 Mdot
.64718 .57647 Mdot
.34794 .36863 Mdot
.32322 .32356 Mdot
.3405 .57628 Mdot
.62215 .5942 Mdot
.43806 .71951 Mdot
.28508 .57867 Mdot
.26774 .59519 Mdot
.28205 .60002 Mdot
.63226 .37275 Mdot
.57148 .51343 Mdot
.52361 .52963 Mdot
.81592 .36716 Mdot
.35127 .37813 Mdot
.46392 .38318 Mdot
.5818 .59138 Mdot
.53666 .80154 Mdot
.63186 .35717 Mdot
.32933 .58798 Mdot
.59539 .57682 Mdot
.29522 .65228 Mdot
.44415 .3784 Mdot
.31501 .58933 Mdot
.62408 .37879 Mdot
.56973 .4215 Mdot
.58119 .56853 Mdot
.63308 .55162 Mdot
.6277 .35184 Mdot
.45441 .3256 Mdot
.49276 .44361 Mdot
.60802 .57454 Mdot
.35275 .38583 Mdot
.24332 .74188 Mdot
.58918 .5265 Mdot
.55438 .37382 Mdot
.48396 .38699 Mdot
.58563 .27744 Mdot
.66943 .45009 Mdot
.67616 .5667 Mdot
.45867 .17559 Mdot
.51008 .80102 Mdot
.53728 .18496 Mdot
.603 .74118 Mdot
.26718 .3468 Mdot
.7157 .25085 Mdot
.31831 .33704 Mdot
.72907 .49128 Mdot
.23836 .32411 Mdot
.46368 .33841 Mdot
.27446 .66951 Mdot
.21475 .45963 Mdot
.22943 .62623 Mdot
.77378 .65193 Mdot
.27367 .60015 Mdot
.63922 .73272 Mdot
.64809 .59881 Mdot
.4581 .31453 Mdot
.72163 .50434 Mdot
.64601 .7947 Mdot
.51211 .19966 Mdot
.32734 .64565 Mdot
.43854 .14316 Mdot
.51958 .21402 Mdot
.67877 .29789 Mdot
.72172 .64373 Mdot
.37058 .75677 Mdot
.41133 .56596 Mdot
.5241 .77836 Mdot
.67858 .4769 Mdot
.39478 .26932 Mdot
.31628 .33488 Mdot
.73901 .35144 Mdot
.30867 .78233 Mdot
.30309 .60754 Mdot
.57647 .37283 Mdot
.24216 .42043 Mdot
.66754 .28162 Mdot
.27999 .38279 Mdot
.45876 .17537 Mdot
.5874 .25115 Mdot
.73158 .50387 Mdot
.52428 .48379 Mdot
.7283 .44414 Mdot
.44972 .78657 Mdot
.70852 .68464 Mdot
.57036 .39293 Mdot
.21558 .49238 Mdot
.41362 .5659 Mdot
.45379 .75846 Mdot
.74721 .53278 Mdot
.43334 .66277 Mdot
.4151 .67522 Mdot
.62736 .3747 Mdot
.68027 .35259 Mdot
.44078 .39364 Mdot
.5401 .48189 Mdot
.30263 .62653 Mdot
.3768 .4395 Mdot
.42181 .31744 Mdot
.49457 .32068 Mdot
.84315 .47578 Mdot
.50597 .14138 Mdot
.5448 .71056 Mdot
.30713 .45866 Mdot
.28483 .38319 Mdot
.51223 .78064 Mdot
.51512 .53417 Mdot
.56811 .69644 Mdot
.67595 .66961 Mdot
.36186 .16947 Mdot
.52828 .28988 Mdot
.42765 .13881 Mdot
.56279 .35771 Mdot
.62138 .64532 Mdot
.32702 .45721 Mdot
.81377 .51237 Mdot
.50795 .70464 Mdot
.50447 .1464 Mdot
.46212 .71966 Mdot
.64949 .35356 Mdot
.46444 .33956 Mdot
.73456 .53861 Mdot
.41076 .74475 Mdot
.47892 .66457 Mdot
.59213 .64973 Mdot
.35705 .16121 Mdot
.4455 .17721 Mdot
.71338 .27863 Mdot
.5715 .26202 Mdot
.27102 .63017 Mdot
.26866 .60112 Mdot
.34104 .40902 Mdot
.64509 .23337 Mdot
.59106 .34888 Mdot
.82317 .37383 Mdot
.62146 .2365 Mdot
.56133 .65985 Mdot
.33746 .17564 Mdot
.80407 .6137 Mdot
.66939 .42501 Mdot
.64226 .77133 Mdot
.20351 .61632 Mdot
.5105 .53208 Mdot
.42788 .35918 Mdot
.36064 .59141 Mdot
.62983 .25376 Mdot
.63179 .21944 Mdot
.63375 .70492 Mdot
.2963 .2701 Mdot
.54469 .48066 Mdot
.36331 .53989 Mdot
.63759 .4028 Mdot
.27579 .68441 Mdot
.4991 .65237 Mdot
.43753 .13853 Mdot
.70324 .48768 Mdot
.22507 .70025 Mdot
.58035 .7444 Mdot
.75732 .59302 Mdot
.44809 .19191 Mdot
.23963 .59489 Mdot
.55995 .67338 Mdot
.51669 .31102 Mdot
.63256 .51812 Mdot
.49421 .5824 Mdot
.66288 .66064 Mdot
.38757 .68928 Mdot
.5075 .44808 Mdot
.51965 .25757 Mdot
.55251 .74561 Mdot
.26119 .33639 Mdot
.7221 .62498 Mdot
.63096 .33021 Mdot
.54988 .69104 Mdot
.57289 .72571 Mdot
.55599 .26664 Mdot
.48041 .63385 Mdot
.70546 .26855 Mdot
.46136 .62712 Mdot
.67543 .55756 Mdot
.72804 .4838 Mdot
.68091 .4819 Mdot
.59305 .71334 Mdot
.66278 .61043 Mdot
.83634 .4507 Mdot
.58358 .26466 Mdot
.77966 .42437 Mdot
.52967 .74434 Mdot
.78982 .434 Mdot
.6435 .24982 Mdot
.32395 .4523 Mdot
.42 .35576 Mdot
.5504 .38951 Mdot
.36165 .16018 Mdot
.29236 .57464 Mdot
.60788 .70545 Mdot
.30173 .33975 Mdot
.19254 .48985 Mdot
.23763 .37968 Mdot
.44775 .62382 Mdot
.65788 .24427 Mdot
.49146 .33217 Mdot
.29255 .54513 Mdot
.37906 .25585 Mdot
.41436 .41143 Mdot
.77565 .38481 Mdot
.64634 .6384 Mdot
.62636 .67546 Mdot
.45943 .69979 Mdot
.78746 .52658 Mdot
.29029 .42814 Mdot
.38045 .67303 Mdot
.67525 .58035 Mdot
.37432 .61648 Mdot
.46089 .39898 Mdot
.46894 .46672 Mdot
.66984 .21701 Mdot
.67978 .6271 Mdot
.79402 .62436 Mdot
.48118 .32213 Mdot
.45663 .47695 Mdot
.4814 .74848 Mdot
.56365 .30476 Mdot
.4109 .14026 Mdot
.66617 .24016 Mdot
.47444 .2943 Mdot
.50544 .18884 Mdot
.8328 .62144 Mdot
.21383 .39201 Mdot
.81831 .53785 Mdot
.30246 .33922 Mdot
.62762 .87493 Mdot
.32477 .60759 Mdot
.68592 .73563 Mdot
.81089 .51278 Mdot
.33062 .65446 Mdot
.6663 .2804 Mdot
.6993 .50624 Mdot
.4917 .7044 Mdot
.59366 .31199 Mdot
.6709 .60082 Mdot
.53851 .16118 Mdot
.37567 .15727 Mdot
.52821 .15697 Mdot
.50109 .38126 Mdot
.5488 .1768 Mdot
.32795 .20747 Mdot
.57319 .81111 Mdot
.24789 .39146 Mdot
.55863 .55313 Mdot
.62 .69529 Mdot
.81309 .59264 Mdot
.47196 .68147 Mdot
.52844 .5098 Mdot
.57468 .39911 Mdot
.32361 .20301 Mdot
.67039 .2156 Mdot
.72561 .40421 Mdot
.68678 .32274 Mdot
.36743 .5077 Mdot
.58042 .69472 Mdot
.67668 .27949 Mdot
.40496 .25384 Mdot
.56959 .2441 Mdot
.3095 .22418 Mdot
.56903 .73233 Mdot
.21367 .46623 Mdot
.46819 .28586 Mdot
.81773 .56893 Mdot
.44789 .1885 Mdot
.23609 .41869 Mdot
.54802 .66109 Mdot
.65984 .34905 Mdot
.44175 .62564 Mdot
.38946 .26412 Mdot
.34505 .4781 Mdot
.52509 .72678 Mdot
.2948 .56048 Mdot
.62781 .70252 Mdot
.46018 .54143 Mdot
.24711 .39275 Mdot
.51017 .75504 Mdot
.64563 .70418 Mdot
.49871 .27456 Mdot
.53803 .167 Mdot
.48212 .32408 Mdot
.19896 .62385 Mdot
.47197 .21031 Mdot
.6509 .66275 Mdot
.63743 .62874 Mdot
.64965 .24661 Mdot
.60681 .16975 Mdot
.65925 .24341 Mdot
.51332 .36644 Mdot
.31825 .64218 Mdot
.33314 .34601 Mdot
.50349 .77281 Mdot
.38706 .63608 Mdot
.58068 .23407 Mdot
.43583 .54532 Mdot
.37373 .36435 Mdot
.4162 .32513 Mdot
.66619 .31731 Mdot
.52824 .79613 Mdot
.72996 .35225 Mdot
.60103 .48325 Mdot
.67524 .38589 Mdot
.60131 .31566 Mdot
.50494 .36236 Mdot
.57776 .69955 Mdot
.28858 .58026 Mdot
.18387 .50757 Mdot
.55203 .33958 Mdot
.63784 .64562 Mdot
.32431 .47436 Mdot
.63174 .41145 Mdot
.80363 .45941 Mdot
.29777 .54594 Mdot
.693 .23618 Mdot
.83888 .47927 Mdot
.67689 .27847 Mdot
.54816 .69911 Mdot
.19287 .51132 Mdot
.47665 .45657 Mdot
.29355 .36187 Mdot
.51158 .20409 Mdot
.42153 .49207 Mdot
.55819 .69907 Mdot
.66823 .40212 Mdot
.2589 .38896 Mdot
.66092 .53413 Mdot
.73067 .29309 Mdot
.56319 .80431 Mdot
.45923 .4584 Mdot
.61622 .28257 Mdot
.58587 .38962 Mdot
.72235 .74148 Mdot
.40533 .2788 Mdot
.52663 .61163 Mdot
.4792 .18669 Mdot
.31456 .39628 Mdot
.63505 .34554 Mdot
.65925 .69874 Mdot
.31362 .68703 Mdot
.65903 .39474 Mdot
.36053 .4688 Mdot
.67268 .29097 Mdot
.40472 .47338 Mdot
.49582 .18512 Mdot
.42948 .16775 Mdot
.24706 .73821 Mdot
.56582 .34761 Mdot
.281 .44259 Mdot
.27688 .4454 Mdot
.58597 .4035 Mdot
.57902 .40597 Mdot
.6954 .48441 Mdot
.58631 .1814 Mdot
.41161 .53552 Mdot
.39597 .24748 Mdot
.45549 .48092 Mdot
.28338 .6757 Mdot
.25983 .40814 Mdot
.51771 .76301 Mdot
.40049 .20024 Mdot
.70666 .33812 Mdot
.1572 .50645 Mdot
.58324 .48205 Mdot
.69114 .73098 Mdot
.50317 .77322 Mdot
.71096 .65008 Mdot
.74742 .52773 Mdot
.54819 .23484 Mdot
.6547 .56962 Mdot
.52395 .14434 Mdot
.52951 .27678 Mdot
.49169 .59386 Mdot
.23652 .59961 Mdot
.6108 .53177 Mdot
.56606 .52142 Mdot
.67274 .27199 Mdot
.60273 .27124 Mdot
.17755 .4131 Mdot
.59154 .73852 Mdot
.6185 .66952 Mdot
.66456 .41986 Mdot
.79422 .62325 Mdot
.3482 .45643 Mdot
.56447 .20138 Mdot
.4593 .55046 Mdot
.8214 .57756 Mdot
.38754 .2292 Mdot
.37599 .27177 Mdot
.46689 .20331 Mdot
.33787 .19994 Mdot
.58133 .65483 Mdot
.53858 .3239 Mdot
.2485 .42931 Mdot
.58578 .59525 Mdot
.50855 .34569 Mdot
.48026 .19302 Mdot
.29715 .7385 Mdot
.51192 .56452 Mdot
.5985 .1637 Mdot
.637 .49711 Mdot
.53463 .31531 Mdot
.23337 .34096 Mdot
.13876 .55572 Mdot
.38374 .27994 Mdot
.44493 .13838 Mdot
.36955 .26421 Mdot
.46711 .18304 Mdot
.32427 .40774 Mdot
.41731 .51405 Mdot
.79961 .41291 Mdot
.59302 .18292 Mdot
.34028 .71223 Mdot
.26496 .33996 Mdot
.7769 .36218 Mdot
.58388 .17561 Mdot
.65565 .51437 Mdot
.72719 .73049 Mdot
.25825 .61162 Mdot
.829 .58709 Mdot
.83328 .51094 Mdot
.62999 .28809 Mdot
.62057 .71297 Mdot
.72959 .71827 Mdot
.6226 .80271 Mdot
.82886 .51178 Mdot
.69246 .67175 Mdot
.5943 .2787 Mdot
.54076 .69931 Mdot
.59227 .22952 Mdot
.76785 .66412 Mdot
.26868 .42309 Mdot
.45542 .41185 Mdot
.48721 .37131 Mdot
.63625 .26137 Mdot
.48819 .25828 Mdot
.33257 .46634 Mdot
.49572 .42613 Mdot
.6676 .29461 Mdot
.30499 .81578 Mdot
.34274 .26311 Mdot
.62647 .44005 Mdot
.39539 .15257 Mdot
.56576 .24919 Mdot
.42409 .54459 Mdot
.74918 .54657 Mdot
.53557 .79254 Mdot
.25348 .57533 Mdot
.62669 .61015 Mdot
.57607 .17447 Mdot
.27251 .55543 Mdot
.45922 .14645 Mdot
.78125 .32622 Mdot
.6925 .35586 Mdot
.66179 .63353 Mdot
.36531 .58099 Mdot
.7195 .67159 Mdot
.69115 .68039 Mdot
.38958 .16314 Mdot
.6966 .72358 Mdot
.43465 .46226 Mdot
.38659 .48006 Mdot
.39018 .46014 Mdot
.54514 .63769 Mdot
.81571 .5941 Mdot
.57326 .29201 Mdot
.53587 .75632 Mdot
.45807 .29169 Mdot
.59959 .70806 Mdot
.67275 .4523 Mdot
.50063 .76746 Mdot
.47451 .6082 Mdot
.48585 .72424 Mdot
.34796 .5975 Mdot
.29318 .25403 Mdot
.51367 .22326 Mdot
.83231 .43292 Mdot
.20075 .62295 Mdot
.51738 .31419 Mdot
.65444 .72869 Mdot
.27416 .39835 Mdot
.5066 .56975 Mdot
.35895 .74072 Mdot
.55662 .7627 Mdot
.68633 .47035 Mdot
.55891 .21705 Mdot
.71659 .59386 Mdot
.63884 .21892 Mdot
.52393 .73112 Mdot
.25404 .30879 Mdot
.36472 .51026 Mdot
.78956 .50584 Mdot
.68882 .42604 Mdot
.18964 .59334 Mdot
.4588 .46086 Mdot
.35699 .16217 Mdot
.64087 .35518 Mdot
.50159 .141 Mdot
.31891 .36177 Mdot
.30358 .76453 Mdot
.5627 .23401 Mdot
.48549 .56334 Mdot
.47384 .51753 Mdot
.75086 .30911 Mdot
.47315 .3283 Mdot
.49037 .31534 Mdot
.44633 .62816 Mdot
.27354 .58163 Mdot
.43284 .4374 Mdot
.40277 .24451 Mdot
.29588 .25635 Mdot
.60358 .62044 Mdot
.38186 .57639 Mdot
.70383 .68013 Mdot
.28952 .3705 Mdot
.59244 .26292 Mdot
.54248 .21758 Mdot
.63888 .45464 Mdot
.57501 .69232 Mdot
.33666 .19672 Mdot
.59121 .24083 Mdot
.43683 .61254 Mdot
.67949 .65279 Mdot
.27663 .34916 Mdot
.18847 .42803 Mdot
.41797 .18463 Mdot
.39026 .4687 Mdot
.48737 .44363 Mdot
.54717 .71227 Mdot
.61324 .15486 Mdot
.36863 .16338 Mdot
.16548 .55708 Mdot
.45183 .47852 Mdot
.58274 .3111 Mdot
.54646 .78525 Mdot
.25536 .30661 Mdot
.83569 .57811 Mdot
.49258 .28863 Mdot
.60789 .7081 Mdot
.27993 .72003 Mdot
.70744 .73229 Mdot
.43111 .47545 Mdot
.69006 .42657 Mdot
.81335 .46974 Mdot
.31566 .41925 Mdot
.25817 .5641 Mdot
.45006 .50117 Mdot
.27188 .34635 Mdot
.59179 .27978 Mdot
.47361 .32989 Mdot
.25315 .30937 Mdot
.7067 .71603 Mdot
.68283 .65038 Mdot
.26595 .30987 Mdot
.64929 .37576 Mdot
.27086 .44086 Mdot
.18128 .47792 Mdot
.44468 .48912 Mdot
.30292 .61534 Mdot
.55021 .50235 Mdot
.4546 .43307 Mdot
.37077 .2532 Mdot
.24955 .69092 Mdot
.43064 .73181 Mdot
.55773 .36469 Mdot
.72061 .71861 Mdot
.56577 .35731 Mdot
.65619 .18897 Mdot
.40812 .25212 Mdot
.67016 .40364 Mdot
.37003 .2324 Mdot
.22852 .47168 Mdot
.20002 .64002 Mdot
.68067 .30335 Mdot
.51672 .69809 Mdot
.55996 .35216 Mdot
.58751 .32309 Mdot
.39143 .21759 Mdot
.43348 .3721 Mdot
.68225 .3323 Mdot
.78266 .63695 Mdot
.1934 .51554 Mdot
.57211 .38039 Mdot
.38499 .4848 Mdot
.59359 .42873 Mdot
.67694 .21941 Mdot
.30601 .61328 Mdot
.37012 .15475 Mdot
.69068 .62853 Mdot
.182 .43239 Mdot
.62373 .25218 Mdot
.51454 .42323 Mdot
.4438 .46975 Mdot
.19992 .49825 Mdot
.6703 .54852 Mdot
.61267 .66921 Mdot
.61587 .38437 Mdot
.24387 .36937 Mdot
.42884 .69265 Mdot
.47589 .6486 Mdot
.30094 .34532 Mdot
.77368 .5916 Mdot
.8316 .55684 Mdot
.59548 .31757 Mdot
.35581 .49927 Mdot
.27248 .45451 Mdot
.67176 .52733 Mdot
.70576 .67218 Mdot
.31388 .23105 Mdot
.68281 .31597 Mdot
.64023 .34786 Mdot
.1726 .57194 Mdot
.43203 .64624 Mdot
.70577 .24849 Mdot
.64081 .46774 Mdot
.7154 .67497 Mdot
.71576 .64136 Mdot
.67843 .26847 Mdot
.66935 .45074 Mdot
.57743 .21367 Mdot
.55568 .69315 Mdot
.41914 .62891 Mdot
.64709 .70248 Mdot
.64044 .45438 Mdot
.4099 .45712 Mdot
.81621 .60585 Mdot
.27159 .7142 Mdot
.72855 .45263 Mdot
.51827 .53473 Mdot
.64562 .27893 Mdot
.79701 .61819 Mdot
.55701 .36962 Mdot
.42508 .73675 Mdot
.7482 .36224 Mdot
.56164 .23641 Mdot
.64237 .23118 Mdot
.55471 .2676 Mdot
.71891 .67555 Mdot
.39452 .4561 Mdot
.59378 .77798 Mdot
.70064 .61517 Mdot
.49346 .54321 Mdot
.6424 .52892 Mdot
.63724 .66064 Mdot
.44087 .55968 Mdot
.76335 .32695 Mdot
.57202 .65613 Mdot
.58247 .18493 Mdot
.69251 .24337 Mdot
.52446 .17743 Mdot
.33965 .47951 Mdot
.56984 .35886 Mdot
.39729 .14685 Mdot
.7387 .65986 Mdot
.59383 .23225 Mdot
.82941 .52361 Mdot
.73151 .73577 Mdot
.23672 .32206 Mdot
.53279 .25097 Mdot
.65201 .39224 Mdot
.82764 .40109 Mdot
.5306 .28846 Mdot
.73257 .72199 Mdot
.68959 .47476 Mdot
.61103 .25662 Mdot
.33206 .18343 Mdot
.79756 .56399 Mdot
.49572 .31637 Mdot
.68673 .43165 Mdot
.64683 .44005 Mdot
.77053 .63753 Mdot
.5909 .50079 Mdot
.27697 .60762 Mdot
.29242 .65787 Mdot
.60926 .7144 Mdot
.62239 .45152 Mdot
.76624 .64926 Mdot
.69149 .68218 Mdot
.64205 .73509 Mdot
.19859 .50477 Mdot
.2383 .32162 Mdot
.65974 .41432 Mdot
.54266 .55899 Mdot
.55905 .38033 Mdot
.4158 .69766 Mdot
.57879 .75085 Mdot
.59567 .54185 Mdot
.48203 .48677 Mdot
.56413 .63562 Mdot
.55459 .1588 Mdot
.30071 .67397 Mdot
.37981 .36618 Mdot
.57061 .36835 Mdot
.63655 .26285 Mdot
.3425 .44586 Mdot
.4618 .33873 Mdot
.7607 .65152 Mdot
.67015 .34975 Mdot
.48514 .17804 Mdot
.50252 .32015 Mdot
.54324 .73016 Mdot
.43583 .78043 Mdot
.36452 .39917 Mdot
.80646 .44975 Mdot
.37785 .17256 Mdot
.51639 .332 Mdot
.64948 .36346 Mdot
.4673 .27762 Mdot
.41034 .46027 Mdot
.52681 .34353 Mdot
.47513 .32456 Mdot
.27527 .41822 Mdot
.69927 .37898 Mdot
.42227 .17306 Mdot
.36084 .56259 Mdot
.58316 .7308 Mdot
.42228 .27748 Mdot
.77122 .6447 Mdot
.66875 .52239 Mdot
.61223 .20888 Mdot
.48429 .55551 Mdot
.3963 .6596 Mdot
.6258 .5542 Mdot
.73764 .64305 Mdot
.67137 .2684 Mdot
.44917 .28748 Mdot
.53953 .65446 Mdot
.63202 .31413 Mdot
.84071 .47341 Mdot
.24685 .61155 Mdot
.24769 .59186 Mdot
.66343 .75423 Mdot
.52438 .38155 Mdot
.39468 .63248 Mdot
.39394 .34856 Mdot
.67061 .54033 Mdot
.42543 .77389 Mdot
.37245 .47068 Mdot
.80331 .43601 Mdot
.81433 .54634 Mdot
.30432 .24253 Mdot
.35863 .46475 Mdot
.8444 .47243 Mdot
.81469 .44918 Mdot
.61899 .26134 Mdot
.71717 .71489 Mdot
.53697 .50406 Mdot
.66471 .61017 Mdot
.42524 .73685 Mdot
.62361 .39761 Mdot
.32509 .22626 Mdot
.57874 .67408 Mdot
.39373 .68344 Mdot
.48249 .5815 Mdot
.32624 .45915 Mdot
.32095 .51953 Mdot
.58207 .26788 Mdot
.82852 .40223 Mdot
.57594 .6991 Mdot
.30977 .40107 Mdot
.37633 .25454 Mdot
.51044 .58424 Mdot
.59562 .19632 Mdot
.44479 .5786 Mdot
.66942 .27499 Mdot
.4907 .40273 Mdot
.79914 .46982 Mdot
.71438 .26801 Mdot
.50456 .65612 Mdot
.49789 .52194 Mdot
.59431 .28752 Mdot
.52868 .50276 Mdot
.44699 .39476 Mdot
.33616 .6614 Mdot
.73206 .68083 Mdot
.28586 .28402 Mdot
.32115 .3219 Mdot
.62675 .49901 Mdot
.55036 .78313 Mdot
.40093 .18446 Mdot
.42123 .5516 Mdot
.47707 .56048 Mdot
.24672 .43226 Mdot
.27413 .55296 Mdot
.25116 .755 Mdot
.53676 .15011 Mdot
.62546 .55274 Mdot
.46231 .5203 Mdot
.45858 .64643 Mdot
.32015 .55249 Mdot
.7239 .3438 Mdot
.32445 .22318 Mdot
.34741 .40441 Mdot
.20412 .56453 Mdot
.39397 .34945 Mdot
.75658 .31586 Mdot
.16775 .52981 Mdot
.38317 .38192 Mdot
.65332 .1859 Mdot
.48557 .29504 Mdot
.5428 .34869 Mdot
.26394 .77268 Mdot
.74159 .30687 Mdot
.68759 .65537 Mdot
.27123 .63864 Mdot
.55415 .16381 Mdot
.44508 .46785 Mdot
.34363 .63481 Mdot
.80357 .55441 Mdot
.56948 .69823 Mdot
.58824 .73624 Mdot
.4092 .36631 Mdot
.80586 .39605 Mdot
.69222 .7761 Mdot
.23056 .4707 Mdot
.18195 .61502 Mdot
.68748 .34146 Mdot
.45047 .1602 Mdot
.38477 .27791 Mdot
.30216 .73611 Mdot
.63972 .23351 Mdot
.65306 .69289 Mdot
.76619 .61878 Mdot
.32418 .70983 Mdot
.50408 .66705 Mdot
.54427 .79334 Mdot
.50718 .3905 Mdot
.68839 .31364 Mdot
.20672 .50121 Mdot
.52628 .64368 Mdot
.63748 .70274 Mdot
.80965 .48536 Mdot
.49687 .52642 Mdot
.40748 .16219 Mdot
.75292 .64979 Mdot
.55558 .70552 Mdot
.21949 .43536 Mdot
.41374 .67671 Mdot
.34487 .21371 Mdot
.38423 .42671 Mdot
.69354 .65152 Mdot
.22066 .35208 Mdot
.43693 .13909 Mdot
.53634 .50432 Mdot
.56145 .53903 Mdot
.71901 .2536 Mdot
.39082 .55921 Mdot
.81765 .53576 Mdot
.42319 .31021 Mdot
.6014 .73675 Mdot
.55994 .64086 Mdot
.65752 .55415 Mdot
.61505 .78117 Mdot
.66134 .33416 Mdot
.81175 .48092 Mdot
.1747 .51259 Mdot
.55322 .7008 Mdot
.75141 .62057 Mdot
.15853 .5018 Mdot
.64566 .46916 Mdot
.5897 .32762 Mdot
.55381 .16176 Mdot
.73138 .32303 Mdot
.66047 .66461 Mdot
.67775 .40628 Mdot
.44224 .59193 Mdot
.41064 .75836 Mdot
.68601 .64632 Mdot
.47494 .45771 Mdot
.61754 .71479 Mdot
.25727 .31204 Mdot
.79496 .3997 Mdot
.35271 .16141 Mdot
.66649 .24463 Mdot
.56644 .36504 Mdot
.80412 .54282 Mdot
.44069 .49049 Mdot
.51391 .17652 Mdot
.20384 .48112 Mdot
.18882 .50063 Mdot
.66979 .78431 Mdot
.47524 .65208 Mdot
.65564 .59111 Mdot
.5015 .38249 Mdot
.64418 .22589 Mdot
.68922 .76891 Mdot
.63576 .21876 Mdot
.61608 .66035 Mdot
.64303 .62844 Mdot
.13815 .57739 Mdot
.47975 .18301 Mdot
.68635 .59724 Mdot
.52613 .58631 Mdot
.53394 .6229 Mdot
.64682 .59574 Mdot
.44633 .3642 Mdot
.52477 .78658 Mdot
.61056 .72997 Mdot
.58252 .18202 Mdot
.58912 .39508 Mdot
.44939 .468 Mdot
.37855 .38972 Mdot
.47589 .49635 Mdot
.60891 .46041 Mdot
.31939 .40042 Mdot
.63042 .72666 Mdot
.36962 .53722 Mdot
.41931 .75162 Mdot
.66436 .32656 Mdot
.51468 .40159 Mdot
.66239 .30167 Mdot
.6799 .72102 Mdot
.43895 .35993 Mdot
.61707 .80616 Mdot
.6893 .68521 Mdot
.7047 .62581 Mdot
.56808 .27807 Mdot
.81776 .63935 Mdot
.45162 .46131 Mdot
.49475 .36316 Mdot
.6493 .49206 Mdot
.72193 .55737 Mdot
.68847 .3867 Mdot
.47935 .69083 Mdot
.4654 .40149 Mdot
.63231 .6576 Mdot
.66443 .2758 Mdot
.30858 .35886 Mdot
.6078 .15829 Mdot
.65426 .63232 Mdot
.72363 .3608 Mdot
.59215 .2084 Mdot
.26831 .4316 Mdot
.68359 .47088 Mdot
.63348 .52445 Mdot
.42429 .60939 Mdot
.37256 .54081 Mdot
.57148 .40916 Mdot
.2562 .40181 Mdot
.45717 .17093 Mdot
.68276 .73094 Mdot
.70864 .3544 Mdot
.60637 .59984 Mdot
.44923 .73171 Mdot
.48009 .46592 Mdot
.30102 .7234 Mdot
.36945 .5519 Mdot
.57591 .24959 Mdot
.67085 .72296 Mdot
.59035 .73901 Mdot
.69026 .44896 Mdot
.47772 .14454 Mdot
.51495 .56375 Mdot
.68991 .36142 Mdot
.46966 .59537 Mdot
.49589 .25758 Mdot
.68999 .67673 Mdot
.27263 .30674 Mdot
.59887 .66264 Mdot
.53663 .5133 Mdot
.64574 .19846 Mdot
.68063 .29911 Mdot
.35919 .3386 Mdot
.56055 .21559 Mdot
.73722 .67575 Mdot
.47367 .5194 Mdot
.27668 .78908 Mdot
.20084 .48034 Mdot
.63972 .17951 Mdot
.25686 .36908 Mdot
.69979 .56198 Mdot
.56552 .30163 Mdot
.67208 .59769 Mdot
.31652 .5824 Mdot
.49722 .17007 Mdot
.59958 .28648 Mdot
.54312 .48759 Mdot
.56299 .52198 Mdot
.40149 .55049 Mdot
.56907 .40268 Mdot
.2786 .29001 Mdot
.26946 .57794 Mdot
.43825 .60881 Mdot
.26615 .33112 Mdot
.3717 .54064 Mdot
.74623 .72284 Mdot
.39327 .1606 Mdot
.51525 .20514 Mdot
.37837 .4706 Mdot
.26495 .74231 Mdot
.56566 .32494 Mdot
.60192 .41546 Mdot
.30499 .34805 Mdot
.59869 .78109 Mdot
.52196 .338 Mdot
.25383 .32272 Mdot
.67574 .25966 Mdot
.67111 .52521 Mdot
.32802 .84022 Mdot
.66091 .69373 Mdot
.42726 .56937 Mdot
.51503 .35226 Mdot
.59381 .18773 Mdot
.23317 .61959 Mdot
.776 .32348 Mdot
.39894 .26894 Mdot
.62103 .45363 Mdot
.57794 .80082 Mdot
.17443 .57187 Mdot
.37525 .48287 Mdot
.18281 .61797 Mdot
.45822 .19187 Mdot
.52385 .77784 Mdot
.43995 .28779 Mdot
.56664 .34188 Mdot
.60047 .66776 Mdot
.4136 .2462 Mdot
.52823 .51264 Mdot
.5462 .34623 Mdot
.45175 .17652 Mdot
.47302 .79205 Mdot
.21286 .4247 Mdot
.51311 .18897 Mdot
.28863 .36513 Mdot
.61559 .29018 Mdot
.6853 .69466 Mdot
.38369 .57573 Mdot
.30972 .55757 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo08gooooo0_l00006ooooo`;o00004_oo
ool2o`0009kooooo000Looooo`03o`000?oooooooooo08;ooooo0ol00002ooooo`;o000000Cooooo
o`000?l0003ooooo0_l00006ooooo`;o00002?ooool4o`0000Kooooo0_l0002Nooooo`007?ooool0
0ol0003oooooooooo`1mooooo`;o00000oooool3o`0000;ooooo0_l000001?oooooo0000o`000?l0
000:ooooo`;o00001_ooool4o`0000?ooooo0_l0002Qooooo`007?ooool00ol0003oooooooooo`1m
ooooo`;o00003?ooool2o`0000Cooooo0_l00004ooooo`;o00001oooool2o`0000Cooooo0_l0002Q
ooooo`007?ooool00ol0003oooooooooo`1mooooo`;o00004_ooool2o`0000gooooo0_l00009oooo
o`;o0000W?ooool001cooooo0_l0001nooooo`;o00004Oooool2o`0000_ooooo0_l0000<ooooo`;o
00004oooool2o`0008Oooooo000Looooo`03o`000?oooooooooo07Cooooo0_l00007ooooo`;o0000
4Oooool2o`0000Gooooo0_l00004ooooo`;o00005oooool2o`0000Sooooo0_l000000ooooooo0000
o`000024ooooo`007?ooool00ol0003oooooooooo`1dooooo`Co00007oooool2o`0000_ooooo0_l0
0002ooooo`;o00001_ooool2o`0000Cooooo0_l0000:ooooo`?o0000Q?ooool001cooooo00?o0000
ooooooooool0Koooool5o`0000;ooooo0_l00004ooooo`;o00000oooool2o`0000Gooooo0_l00005
ooooo`;o00001?ooool2o`0000gooooo0_l00002ooooo`;o000000?oooooo`000?l000000oooool2
o`00013ooooo0_l00025ooooo`007?ooool00ol0003oooooooooo`1_ooooo`Oo00001Oooool3o`00
00?ooooo1?l00003ooooo`;o00001Oooool2o`0000Cooooo0_l0000Dooooo`;o00000oooool2o`00
00gooooo0_l00028ooooo`007?ooool00ol0003oooooooooo`1dooooo`;o00001Oooool2o`0000Ko
oooo0_l00003ooooo`;o00002_ooool2o`0001Gooooo0_l00003ooooo`;o00003Oooool2o`0008So
oooo000Looooo`03o`000?oooooooooo07;ooooo0_l0000Dooooo`;o00001oooool2o`000003oooo
ool0003o000000Sooooo0ol00005ooooo`;o00000oooool2o`0001Cooooo0_l00005ooooo`;o0000
Ooooool001cooooo00?o0000ooooooooool0L_ooool2o`0000?ooooo0_l0000<ooooo`;o00002_oo
ool2o`0000_ooooo0ol00005ooooo`;o00003oooool2o`0000Sooooo0_l00005ooooo`;o0000Oooo
ool001cooooo00?o0000ooooooooool0J_ooool2o`0000_ooooo0_l0000<ooooo`;o00001_ooool6
o`0000Oooooo0_l00007ooooo`;o00000_ooool2o`0000Cooooo0ol00007ooooo`;o000000?ooooo
o`000?l00000SOooool001cooooo00?o0000ooooooooool0J_ooool2o`00027ooooo1_l00007oooo
o`;o00001oooool2o`0000;ooooo0_l00004ooooo`?o00002_ooool3o`0000oooooo0_l0001koooo
o`007?ooool00ol0003oooooooooo`1Xooooo`;o00005?ooool2o`0000Cooooo0_l0000>ooooo`;o
00000_ooool2o`0000?ooooo0_l0000>ooooo`;o00002_ooool6o`0000gooooo0_l0001kooooo`00
7?ooool00ol0003oooooooooo`1Xooooo`;o00005?ooool2o`0000Cooooo0_l0000>ooooo`;o0000
0_ooool2o`0000?ooooo0_l0000<ooooo`;o00002?ooool2o`0000;ooooo0_l00002ooooo`;o0000
4Oooool2o`0007Oooooo000Looooo`03o`000?oooooooooo08kooooo0_l00008ooooo`;o00000ooo
ool2o`000004ooooool0003o0000ooooo`Co00001?ooool2o`0000;ooooo0_l00004ooooo`;o0000
0_ooool2o`0000;ooooo0_l00004ooooo`;o00002oooool3o`0007Kooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`28ooooo`;o
00001?ooool2o`000003ooooool0003o000000Gooooo0_l00006ooooo`;o000000?oooooo`000?l0
00000_l00008ooooo`Co00002_ooool2o`0000Cooooo0_l0000<ooooo`?o0000MOooool00006oooo
oomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006
ooooo`03o`000?oooooooooo06[ooooo0_l0000Looooo`;o00001?ooool2o`000003ooooool0003o
000000Gooooo0_l00008ooooo`?o00003?ooool2o`0000?ooooo0_l00006ooooo`;o00004_ooool2
o`0007Gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q
8Oo^k^h01oooool00ol0003oooooooooo`1Sooooo`;o00001Oooool2o`0001_ooooo0_l0000:oooo
o`;o00000_ooool2o`0000?ooooo0_l00004ooooo`Go00003oooool2o`0000Cooooo1?l0000>oooo
o`;o0000NOooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So
8B4Qonk^kP06ooooo`?o0000Hoooool4o`0000?ooooo0_l0000Booooo`;o00001oooool2o`0000[o
oooo0_l00002ooooo`;o00000oooool2o`0000Gooooo1?l00002ooooo`;o00002Oooool2o`0000Co
oooo1?l0000@ooooo`;o0000NOooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
3?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo06Gooooo0_l0000Gooooo`;o0000
5?ooool2o`0000cooooo1Ol000000ooooooo0000o`000003o`0000Oooooo0_l00004ooooo`?o0000
S?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool03Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo06Oooooo0_l0000[ooooo`;o00001oooool2o`0000?ooooo1Ol0
00000ooooooo0000o`000005o`0000cooooo1_l00002ooooo`;o0000Q?ooool00006oooooomgMgOo
V9RHoooooonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000oooooooo
ool0Ioooool2o`0002gooooo0_l00005ooooo`;o00002?ooool8o`0000kooooo1?l00002ooooo`;o
0000Q?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0K?ooool2o`0002Sooooo0_l00007ooooo`;o00001?ooool4
o`0000Kooooo0_l00007ooooo`;o00001?ooool4o`0000_ooooo0_l0001jooooo`007?ooool00ol0
003oooooooooo`1Wooooo`;o00000oooool2o`0000gooooo0_l0000Rooooo`;o00001?ooool2o`00
00;ooooo1Ol000001?oooooo0000o`000?ooool2o`0000?ooooo0ol00004ooooo`Co00002oooool2
o`0000Kooooo0ol0001aooooo`007?ooool00ol0003oooooooooo`1Wooooo`;o00004_ooool2o`00
02cooooo1Ol00004ooooo`Co000000?oooooo`000?l000004?ooool6o`0000Kooooo1Ol0001_oooo
o`007?ooool00ol0003oooooooooo`1Qooooo`;o00000oooool2o`0003_ooooo0_l000001?oooooo
0000o`000?l00003ooooo`;o00001_ooool2o`0001?ooooo1Ol00009ooooo`?o0000Koooool001co
oooo00?o0000ooooooooool0HOooool2o`0000?ooooo0_l0000@ooooo`;o0000:Oooool2o`000003
ooooool0003o000000?o00006_ooool2o`0000Kooooo0_l00008ooooo`?o000000?oooooo`000?l0
0000K?ooool001cooooo00?o0000ooooooooool0I_ooool2o`00013ooooo1?l0000]ooooo`;o0000
4_ooool2o`0000Kooooo0_l00006ooooo`;o00002Oooool2o`000003ooooool0003o000006cooooo
000Looooo`03o`000?oooooooooo06;ooooo0_l0000@ooooo`;o00000_ooool4o`0003[ooooo0_l0
0002ooooo`;o000000?oooooo`000?l000003Oooool4o`0007Wooooo000Looooo`03o`000?oooooo
oooo06;ooooo0_l0000@ooooo`;o00000_ooool2o`0002Oooooo0_l0000;ooooo`;o00000oooool2
o`000004ooooool0003o0000ooooo`?o000000?oooooo`000?l000001oooool2o`0000Cooooo1?l0
000=ooooo`;o0000J_ooool001cooooo00?o0000ooooooooool0H_ooool2o`0001;ooooo1?l0000W
ooooo`;o00002oooool2o`0000?ooooo0_l00004ooooo`?o00002_ooool2o`0000cooooo0_l00007
ooooo`;o0000J_ooool001cooooo00?o0000ooooooooool0Goooool2o`0001Gooooo0_l0000[oooo
o`;o00005Oooool4o`0001Kooooo0ol0001booooo`007?ooool00ol0003oooooooooo`1Nooooo`?o
00005_ooool2o`0000Kooooo0_l00002ooooo`;o00007_ooool2o`0000oooooo0ol00005ooooo`;o
00005?ooool2o`000003ooooool0003o000000Kooooo0_l0001Zooooo`007?ooool00ol0003ooooo
ooooo`1Nooooo`;o00005oooool2o`0000Cooooo1?l00002ooooo`;o0000;oooool3o`0000Cooooo
0_l0000?ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000006ooooo`;o
00000_ooool2o`0006Kooooo000Looooo`;o0000O_ooool2o`0000;ooooo0_l0000Vooooo`;o0000
1oooool4o`000003ooooool0003o000000;ooooo0_l00008ooooo`Co00000oooool5o`00013ooooo
0_l00002ooooo`;o0000H_ooool001cooooo00?o0000ooooooooool0G?ooool2o`0001Cooooo0_l0
00000ooooooo0000o`000002o`0000Oooooo0ol0000Vooooo`Co00001Oooool2o`0000?ooooo1_l0
0005ooooo`;o000000?oooooo`000?l000001?l00002ooooo`?o00005Oooool3o`00067ooooo000L
ooooo`03o`000?oooooooooo05cooooo0_l0000Dooooo`;o000000?oooooo`000?l000000_l00007
ooooo`;o00006?ooool5o`0000Cooooo1?l00004ooooo`;o00001oooool7o`0000Kooooo1?l00004
ooooo`;o00000_ooool2o`0001Oooooo0_l0001Qooooo`007?ooool00ol0003oooooooooo`1Loooo
o`;o00006Oooool2o`00027ooooo1Ol00004ooooo`Co00003Oooool5o`0000Sooooo1_l00003oooo
o`Go00002Oooool2o`0006oooooo000Looooo`03o`000?oooooooooo06cooooo0_l00006ooooo`;o
00001Oooool2o`0003Oooooo1?l00002ooooo`Go00001_ooool2o`0000?ooooo0ol000000ooooooo
0000o`000008ooooo`;o00002Oooool2o`0006Cooooo000Looooo`03o`000?oooooooooo06cooooo
1?l000001?oooooo0000o`000?ooool2o`0000Gooooo0_l0000cooooo`?o000000?oooooo`000?l0
00000_l00002ooooo`Go00002_ooool4o`000003ooooool0003o000001?ooooo0_l00005ooooo`;o
0000GOooool001cooooo00?o0000ooooooooool0GOooool2o`0000oooooo0_l000000ooooooo0000
o`000009ooooo`Co0000;Oooool2o`000004ooooool0003o0000o`0000Kooooo0_l0000>ooooo`;o
000000?oooooo`000?l000000_l00006ooooo`;o000000?oooooo`000?l000001_ooool2o`000003
ooooool0003o000000Cooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o0000
3oooool2o`0000Kooooo0_l00004ooooo`Co0000;Oooool2o`0000?ooooo0_l00005ooooo`;o0000
1Oooool2o`0000[ooooo1?l00006ooooo`Go00001_ooool2o`000003ooooool0003o000006?ooooo
000Looooo`03o`000?oooooooooo07Kooooo0_l0000Vooooo`;o00002?ooool2o`0000?ooooo0_l0
0003ooooo`;o00003?ooool2o`0000Wooooo0_l00007ooooo`Go0000L?ooool001cooooo00?o0000
ooooooooool0NOooool3o`0000Cooooo0_l00003ooooo`;o00003Oooool2o`0000Sooooo0_l00008
ooooo`;o00002oooool2o`0000?ooooo1Ol0000<ooooo`;o000000?oooooo`000?l000001?ooool6
o`0000[ooooo0_l000000ooooooo0000o`000003ooooo`;o0000Foooool001cooooo00?o0000oooo
ooooool0NOooool3o`0000Cooooo0_l00003ooooo`;o00003Oooool2o`0001kooooo0ol00003oooo
o`Go00001Oooool2o`0000Sooooo1?l00003ooooo`;o000000?oooooo`000?l000002_ooool2o`00
0003ooooool0003o000000?ooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o
00008Oooool2o`0000Gooooo0_l0000?ooooo`;o00007_ooool3o`0000gooooo0_l0000:ooooo`;o
00000oooool2o`0007;ooooo000Looooo`03o`000?oooooooooo05Kooooo0_l000000ooooooo0000
o`00000Looooo`;o00000oooool2o`0000Gooooo0_l00006ooooo`;o000000?oooooo`000?l00000
1?ooool2o`0000Kooooo0_l0000;ooooo`;o00002_ooool2o`0000;ooooo0_l00002ooooo`Co0000
00?oooooo`000?l000001Oooool2o`0000;ooooo0_l0000Cooooo`;o000000Coooooo`000?l0003o
oooo0_l0001Oooooo`007?ooool00ol0003oooooooooo`1Eooooo`Co00007_ooool4o`0000Sooooo
0_l00002ooooo`?o000000?oooooo`000?l000000ol000000ooooooo0000o`000004ooooo`;o0000
0oooool2o`0000[ooooo0ol0000;ooooo`Go00000_ooool4o`000003ooooool0003o000000;o0000
0oooool2o`0000;ooooo1?l00006ooooo`;o00002Oooool2o`000004ooooool0003o0000ooooo`;o
0000Goooool001cooooo00?o0000ooooooooool0EOooool4o`00023ooooo0_l0000;ooooo`Co0000
0oooool2o`0000;ooooo0_l00003ooooo`?o000000?oooooo`000?l000001?ooool2o`0000Kooooo
0_l0000<ooooo`?o00000oooool4o`0000?ooooo0ol00008ooooo`?o00001?ooool4o`00017ooooo
0_l00004ooooo`;o0000Eoooool001cooooo00?o0000ooooooooool0OOooool3o`0000Kooooo0_l0
000>ooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`00000>ooooo`;o00001ooo
ool2o`0000Gooooo0_l0000@ooooo`;o00000_ooool2o`0000oooooo0_l00004ooooo`;o0000Eooo
ool001cooooo0_l0001nooooo`?o00008Oooool4o`0000_ooooo0_l000001?oooooo0000o`000?l0
000Kooooo`Co00001?ooool2o`0006kooooo000Looooo`03o`000?oooooooooo04gooooo0_l0001:
ooooo`;o000000?oooooo`000?l000001_l0000<ooooo`Ko00006?ooool2o`000003ooooool0003o
000000;o00001?ooool2o`00017ooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`1=oooo
o`Co00001?ooool2o`0004;ooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o0000
00cooooo1Ol0000Iooooo`;o00002Oooool2o`00017ooooo0ol0001Jooooo`007?ooool00ol0003o
ooooooooo`1?ooooo`;o00000_ooool4o`0002kooooo0ol0000Aooooo`;o00000_ooool2o`0000Co
oooo0_l0000=ooooo`;o00001oooool8o`0000;ooooo0_l00008ooooo`;o00007?ooool2o`000003
ooooool0003o000005Oooooo000Looooo`03o`000?oooooooooo04gooooo1Ol000000ooooooo0000
o`00000`ooooo`?o00004Oooool3o`000004ooooool0003o0000o`0000?ooooo0ol00009ooooo`;o
00002Oooool9o`0000;ooooo0_l00008ooooo`;o00002oooool2o`0001;ooooo0_l0001Gooooo`00
7?ooool00ol0003oooooooooo`18ooooo`?o00000_ooool5o`0003oooooo0_l00004ooooo`Wo0000
0_ooool4o`0000Cooooo0_l00003ooooo`;o00002?ooool?o`0000;ooooo0_l00007ooooo`;o0000
1Oooool4o`0001;ooooo1?l0001Eooooo`007?ooool00ol0003oooooooooo`18ooooo`?o00002ooo
ool2o`0002gooooo0_l0000:ooooo`;o00001?ooool2o`000003ooooool0003o000000Go000000?o
ooooo`000?l000000_l00004ooooo`;o00002_ooool2o`000003ooooool0003o000000;o000000?o
ooooo`000?l000002?l00002ooooo`Go00001?ooool4o`0000?ooooo0_l0000Dooooo`Co0000EOoo
ool001cooooo00?o0000ooooooooool0BOooool3o`0000?ooooo0_l00005ooooo`;o00001oooool2
o`0000Cooooo0_l0000Mooooo`?o00004_ooool2o`0000;ooooo2?l0000Aooooo`;o00000oooool2
o`000003ooooool0003o000000[o000000?oooooo`000?l000000_l00004ooooo`Co00001?ooool2
o`0000cooooo0ol00009ooooo`;o000000?oooooo`000?l00000Coooool001cooooo00?o0000oooo
ooooool0A_ooool2o`000004ooooool0003o0000o`0000;ooooo0ol00002ooooo`;o00002?ooool5
o`0000?ooooo0ol0000Kooooo`?o00002_ooool2o`0000Gooooo1?l00002ooooo`;o00000_ooool2
o`0000Sooooo0_l00007ooooo`Ko000000?oooooo`000?l000000_ooool@o`0000Kooooo0_l00004
ooooo`;o00003?ooool3o`0000Wooooo0_l000000ooooooo0000o`000002o`0004gooooo000Loooo
o`03o`000?oooooooooo04Kooooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo0_l00008oooo
o`;o000000?oooooo`000?l000000_ooool5o`0001Wooooo0ol0000;ooooo`;o00001?ooool5o`00
0003ooooool0003o000000?ooooo0_l00008ooooo`;o00001oooool3o`000005ooooool0003o0000
o`000?ooool02ol00002ooooo`;o00000_ooool2o`0000Gooooo0ol0000Cooooo`;o00002?ooool3
o`000003ooooool0003o000000;o0000COooool001cooooo00?o0000ooooooooool0Doooool2o`00
00oooooo0_l000000ooooooo0000o`000006ooooo`;o00004Oooool2o`0001;ooooo0_l00004oooo
o`;o00000oooool2o`000003ooooool0003o000000Wooooo0ol00003oooooaKo00002Oooool3o`00
00?ooooo0_l0000>ooooo`;o00002?ooool3o`0005;ooooo000Looooo`03o`000?oooooooooo05?o
oooo0_l0000>ooooo`;o00002_ooool2o`0000gooooo0_l0000Fooooo`;o00001?ooool2o`000003
ooooool0003o000000;o000000?oooooo`000?l000002Oooool3o`0000?ooooo6_l00002ooooo`Ko
00000oooool2o`0000kooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`0oooooo`;o0000
4?ooool2o`0000_ooooo1?l000000ooooooo0000o`000002o`0000;ooooo0ol00005ooooo`?o0000
2_ooool2o`0001?ooooo0_l0000:ooooo`;o00000_ooool2o`000003ooooool0003o000000cooooo
0_l00002oooooaOo00000_ooool4o`0000gooooo0_l0001Uooooo`007?ooool00ol0003ooooooooo
o`0oooooo`;o00001oooool2o`0000Oooooo0ol0000:ooooo`Go000000Coooooo`000?l0003o0000
0_ooool3o`000005ooooool0003o0000o`000?ooool00ol0000Nooooo`?o00003_ooool2o`000003
ooooool0003o000000Sooooo0_l00002oooooa[o00002?ooool2o`0000Cooooo0_l00004ooooo`;o
0000IOooool001cooooo00?o0000ooooooooool0B?ooool2o`0000Sooooo0_l0000:ooooo`Go0000
00Coooooo`000?l0003ooooo0ol00003ooooo`?o000000?oooooo`000?l000006Oooool4o`0000;o
oooo0ol0000;ooooo`;o00001Oooool3o`0000?ooooo0_l000000ooooooo0000o`000002oooooaco
00001?ooool4o`0000Cooooo0_l00009ooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0
Doooool4o`000003ooooool0003o000000?o000000?oooooo`000?l000001?ooool2o`000003oooo
ool0003o000000;o00000_ooool:o`0001Gooooo1?l0000@ooooo`Go00000_ooool3o`0000?ooooo
0ol00004ooooo`Wo000000?oooooo`000?l000004Ol00003ooooo`;o00004Oooool2o`000003oooo
ool0003o000005gooooo000Looooo`;o0000C?ooool2o`0000Kooooo2_l000000ooooooo0000o`00
0003o`0000;ooooo2?l00002ooooo`?o000000?oooooo`000?l000000_l00004ooooo`?o000000?o
ooooo`000?l000007_ooool6o`0000Sooooo0ol00004ooooo`[o000000?oooooo`000?l000001ol0
00000ooooooo0000o`000006o`0000;ooooo0_l000000ooooooo0000o`00000:ooooo`;o00001_oo
ool2o`0005gooooo000Looooo`03o`000?oooooooooo04Cooooo0_l00005ooooo`;o00002Oooool3
o`0000Kooooo3ol000000ooooooo0000o`000002o`000003ooooool0003o000000Gooooo0ol00000
0ooooooo0000o`00000Hooooo`?o00000oooool2o`000003ooooool0003o000000;o00001oooool7
o`000003ooooool0003o000001Oo000000?oooooo`000?l000001?l000001?oooooo0000o`000?oo
ool2o`0000Oooooo0_l00005ooooo`;o000000?oooooo`000?l00000Foooool001cooooo00?o0000
ooooooooool0A?ooool4o`0000[ooooo0_l0000;ooooo`;o000000?oooooo`000?l000004_l00005
ooooo`;o00002?ooool2o`0000Kooooo0_l00002ooooo`;o00001_ooool3o`000003ooooool0003o
000000Gooooo0_l00008ooooo`Ko000000?oooooo`000?l000007?l00006ooooo`;o00000_ooool2
o`0000?ooooo0_l00005ooooo`;o000000?oooooo`000?l000002?ooool2o`00057ooooo000Loooo
o`03o`000?oooooooooo04Kooooo0_l00003ooooo`;o00000oooool4o`0000Wooooo6Ol0000=oooo
o`Oo000000?oooooo`000?l000000_l00002ooooo`;o00002_ooool2o`00017ooooo0_l000000ooo
oooo0000o`000006o`000003ooooool0003o000001Co00001oooool2o`0000;ooooo0_l00003oooo
o`;o00004_ooool2o`00057ooooo000Looooo`03o`000?oooooooooo04Sooooo1Ol00003ooooo`;o
00002_ooool<o`000003ooooool0003o000000Co000000?oooooo`000?l000001?l0000=ooooo`;o
00000_ooool6o`0000Wooooo0_l00005ooooo`;o000000?oooooo`000?l000003_ooool2o`000003
ooooool0003o000001Wo00000_ooool2o`0000Oooooo0_l000000ooooooo0000o`000009ooooo`;o
00001_ooool2o`0000Sooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`18ooooo`?o0000
3ooooolPo`0000Gooooo1?l00005ooooo`Oo00001Oooool4o`0000Gooooo0_l000000ooooooo0000
o`00000?ooooo`;o000000?oooooo`000?l000006?l000001?oooooo0000o`000?l0000:ooooo`;o
00000oooool2o`0000Cooooo0_l00006ooooo`;o00001_ooool4o`0000[ooooo0_l00012ooooo`00
7?ooool00ol0003oooooooooo`1<ooooo`Ko00002?ooool2o`000005ooooool0003o0000o`000?oo
ool06Ol00005ooooo`Co00001Oooool2o`0000?ooooo0_l00005ooooo`Go000000?oooooo`000?l0
00001oooool2o`0000cooooo0_l000000ooooooo0000o`00000Go`0000;ooooo0_l00006ooooo`?o
00001oooool2o`0001Cooooo0_l00008ooooo`;o00000_ooool2o`0004;ooooo000Looooo`03o`00
0?oooooooooo04cooooo1_l00002ooooo`;o00001?ooool2o`0000?ooooo6Ol0000Aooooo`;o0000
1?ooool2o`0000?ooooo1Ol000001?oooooo0000o`000?l00006ooooo`;o00002?ooool2o`0000;o
oooo0_l000000ooooooo0000o`00000Go`0000Wooooo1?l0000Wooooo`;o00000_ooool2o`0004;o
oooo000Looooo`03o`000?oooooooooo04cooooo0_l00006ooooo`Co00000_ooool4o`000003oooo
ool0003o000001Ko00004Oooool3o`0000Cooooo1?l000000ooooooo0000o`000003o`000003oooo
ool0003o000000;o00003oooool2o`000003ooooool0003o000001_o000000?oooooo`000?l00000
0_ooool2o`0000;ooooo0_l0000`ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0Booo
ool3o`0000Kooooo1?l00004ooooo`Ko000000?oooooo`000?l000004_l0000Aooooo`;o00000ooo
oolAo`0001;ooooo7?l00002ooooo`?o000000?oooooo`000?l00000=?ooool2o`0003oooooo000L
ooooo`03o`000?oooooooooo04Cooooo0_l00003ooooo`Go00001oooool2o`0000Cooooo0_l00000
0ooooooo0000o`00000Go`00017ooooo0_l00003oooooa3o00000_ooool2o`0000Kooooo0_l00009
ooooo`;o000000Goooooo`000?l0003o0000ooooo`0Bo`0000?ooooo0ol000000ooooooo0000o`00
000;ooooo`;o00008?ooool2o`0000?ooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`14
ooooo`;o00000oooool3o`0000_ooooo1_l00002oooooago00003?ooool2o`0000;ooooo4Ol00002
ooooo`;o00001_ooool2o`0000Cooooo0_l00003ooooo`;o000000Goooooo`000?l0003o0000oooo
o`0Co`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0001Oooooo1?l00005ooooo`;o00000ooo
ool2o`00047ooooo000Looooo`03o`000?oooooooooo04Wooooo0_l0000<ooooo`Co00001?ooool>
o`000003ooooool0003o000000co00000oooool2o`000003ooooool0003o000000Sooooo4Ol00002
ooooo`;o00002oooool3o`0000?ooooo0_l00003oooooaOo00000oooool2o`0000Gooooo0_l00002
ooooo`;o00006?ooool8o`0000?ooooo0ol00015ooooo`007?ooool00ol0003oooooooooo`1@oooo
o`;o00001Oooool2o`0000Kooooo6_l00006ooooo`;o000000?oooooo`000?l000002OoooolBo`00
00;ooooo0_l00009ooooo`;o000000Coooooo`000?l0003ooooo3?l00002ooooo`Wo000000?ooooo
o`000?l000000_l0000:ooooo`;o00000_ooool2o`0001Sooooo0_l00004ooooo`;o00001?ooool2
o`0004Gooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o
410@ooooooooool01?ooool00ol0003oooooooooo`12ooooo`;o00002Oooool2o`000003ooooool0
003o000000Gooooo0_l00006oooooaco00000oooool2o`0000;ooooo0_l000001?oooooo0000o`00
0?l00003ooooo`So000000Goooooo`000?l0003o0000ooooo`04o`000003ooooool0003o000000;o
oooo0_l00002ooooo`;o00002?ooool2o`0000?ooooo1_l000000ooooooo0000o`00000<o`0000Oo
oooo0_l0000Fooooo`;o00003?ooool2o`0000[ooooo0_l00015ooooo`0000KoooooogMgMonHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
03Wooooo0_l00005ooooo`Co00002Oooool2o`0000Oooooo0ol00005oooooa[o000000?oooooo`00
0?l000000oooool2o`0000?ooooo1Ol00003oooooa7o00002Oooool2o`0000kooooo5?l00007oooo
o`Co00005?ooool2o`0001Sooooo0ol00014ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413o
ooooooooo`09ooooo`Go00001_ooool00ol0003oooooooooo`0iooooo`;o00001Oooool2o`0001?o
oooo1?l00005ooooo`;o00000_oooolHo`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l0
00001Oooool>o`0001[ooooo2_l000000ooooooo0000o`000003o`000003ooooool0003o000000?o
00001oooool2o`0000kooooo0_l0000Jooooo`?o000000Coooooo`000?l0003o0000A?ooool00003
ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?m4A4CogMgMooooool00007oooo
o`?o0000Boooool2o`0000?ooooo0_l00003ooooo`;o00002Oooool3o`000003ooooool0003o0000
013o00000_ooool6o`0000?ooooo1?l00005ooooo`;o000000?oooooo`000?l000003?l000000ooo
oooo0000o`000005ooooo`;o00004?ooool4o`000003ooooool0003o000000;o00001Oooool2o`00
0003ooooool0003o000000Go00002?ooool2o`0000_ooooo0_l0000Jooooo`?o00000_ooool3o`00
00?ooooo0_l0000nooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04
omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0Boooool2o`0000?ooooo0_l0000>oooo
o`?o000000?oooooo`000?l000003_l000001?oooooo0000o`000?ooool4o`0000Gooooo0_l00007
ooooo`;o00000_ooool:o`0000Cooooo1?l00003ooooo`;o00004?ooool2o`000003ooooool0003o
000000Co00001Oooool6o`0000;ooooo0ol00007ooooo`Go00003_ooool3o`0001Sooooo0ol00003
ooooo`;o0000?_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00omg
MgOoc<c<o`000007ooooo`03o`000?oooooooooo03oooooo0_l0000@ooooo`;o00004Oooool@o`00
0004ooooool0003o0000ooooo`;o00005Oooool5o`000003ooooool0003o000000;o00001Oooool2
o`0001Kooooo1ol00004ooooo`Go00001_ooool2o`0000Sooooo1?l0000>ooooo`?o00005oooool3
o`0000Cooooo0_l0000nooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4
A4Co000000Oooooo00?o0000ooooooooool0>oooool2o`0000;ooooo0_l0000@ooooo`;o00002ooo
ool2o`0000Kooooo4?l00002ooooo`;o00002?ooool3o`0000[ooooo0ol00003ooooo`Co00001Ooo
ool2o`0001Kooooo0_l00009ooooo`;o00000oooool2o`000003ooooool0003o000000;o0000=Ooo
ool2o`0000Cooooo0_l0000oooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMg
Mol0003ooooo00Kooooo00?o0000ooooooooool0=_ooool2o`0000?ooooo0_l00002ooooo`;o0000
5_ooool2o`0000Gooooo0ol00005ooooo`co00000_ooool2o`0000;ooooo0_l00008ooooo`?o0000
2oooool2o`0000cooooo0_l0000Kooooo`;o00000oooool2o`0000;ooooo2Ol00004ooooo`Co0000
:oooool2o`0000Kooooo0ol0000nooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00000ooo
ool2o`0000cooooo0_l00008ooooo`;o000000?oooooo`000?l000000_l00004ooooo`?o00001ooo
ool5o`0000;ooooo1Ol0000=ooooo`;o00004?ooool2o`0002Kooooo0_l00003ooooo`;o00000_oo
ool2o`000003ooooool0003o000000Sooooo1?l0000[ooooo`;o00001oooool2o`0003kooooo000L
ooooo`03o`000?oooooooooo04Wooooo1?l000000ooooooo0000o`000003ooooo`;o000000?ooooo
o`000?l000000_l00004ooooo`;o00000oooool2o`0000gooooo0_l0000;ooooo`Co00004?ooool2
o`0000_ooooo1?l00008ooooo`;o00001_ooool3o`0000Oooooo0_l00005ooooo`Co00000_ooool5
o`0000Cooooo0_l0000Aooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0?Oooool2o`00
00;ooooo0_l000000ooooooo0000o`000003ooooo`Oo00001?ooool2o`0000gooooo0_l0000Joooo
o`;o00007oooool5o`0000Oooooo0_l00006ooooo`?o00001oooool2o`0000Gooooo0_l00004oooo
o`Go00001?ooool2o`000003ooooool0003o000000kooooo0_l0000@ooooo`Co0000C?ooool001co
oooo00?o0000ooooooooool0?Oooool2o`0000;ooooo0_l000000ooooooo0000o`000006ooooo`;o
00001_ooool4o`0001Kooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`000003
ooooool0003o000001oooooo0_l00002ooooo`Co00002_ooool2o`0000gooooo0_l0000Fooooo`?o
00000oooool2o`0000?ooooo0_l0000Fooooo`Co0000C?ooool001cooooo00?o0000ooooooooool0
>_ooool2o`00017ooooo0_l00002ooooo`;o00000oooool3o`0000;ooooo0_l0000Aooooo`;o0000
0_ooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`00000Iooooo`;o0000
0oooool7o`0000cooooo0_l0000<ooooo`Go00005?ooool2o`0000Cooooo0_l00003ooooo`;o0000
I_ooool001cooooo00?o0000ooooooooool0=oooool2o`000003ooooool0003o0000013ooooo0ol0
0002ooooo`Co00000_ooool2o`0000;ooooo0_l0000Zooooo`;o00001oooool2o`0000;ooooo0_l0
00000ooooooo0000o`000003ooooo`Oo00006_ooool2o`000003ooooool0003o000000;o00002?oo
ool2o`0000Sooooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l000000ooooooo0000o`00
000Gooooo`;o00003?ooool2o`0003cooooo000Looooo`03o`000?oooooooooo03Kooooo0ol0000;
ooooo`;o00001_ooool2o`0000Gooooo0ol0000Oooooo`;o00000_ooool2o`0000cooooo0_l00007
ooooo`;o000000Coooooo`000?l0003o00001oooool6o`0000kooooo1?l0000=ooooo`?o00001ooo
ool2o`0000Kooooo0_l00003ooooo`Co00001oooool2o`0000;ooooo0_l0000Cooooo`?o000000?o
ooooo`000?l000000_ooool2o`0000Cooooo0_l0000looooo`007?ooool00ol0003oooooooooo`0f
ooooo`;o00000_ooool2o`0000Sooooo0_l0000>ooooo`;o00007oooool6o`0000cooooo1?l00004
ooooo`;o00000_ooool4o`0000Kooooo0_l00002ooooo`;o00003_ooool4o`0000kooooo0_l00003
ooooo`;o00001?ooool2o`0000Cooooo0_l0000<ooooo`;o00001?ooool2o`0001Cooooo0_l00000
0ooooooo0000o`000002ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0>_ooool2o`00
01Sooooo1_l00002ooooo`;o00005?ooool2o`0000?ooooo0_l0000@ooooo`?o00000oooool2o`00
00?ooooo0ol00002ooooo`Ko000000?oooooo`000?l000005?ooool2o`00013ooooo0_l00004oooo
o`;o00004_ooool2o`0001[ooooo0_l0000;ooooo`;o0000??ooool001cooooo00?o0000oooooooo
ool0>_ooool4o`0001Kooooo1_l00002ooooo`;o00003_ooool2o`0000Cooooo0_l00005ooooo`;o
00003oooool2o`0000?ooooo0_l00003ooooo`?o00000_ooool5o`0000;ooooo0_l0000Dooooo`;o
00003Oooool2o`0000Sooooo0_l00007ooooo`Ko00002oooool2o`0001?ooooo0_l0000;ooooo`;o
0000??ooool001cooooo00?o0000ooooooooool0>_ooool4o`0001Sooooo1?l0000Booooo`;o0000
1_ooool2o`0000?ooooo0_l00002ooooo`;o00003?ooool2o`0000cooooo3Ol0000Oooooo`;o0000
2?ooool2o`0000Gooooo2?l0000;ooooo`;o00006?ooool4o`0004;ooooo000Looooo`;o0000@?oo
ool2o`0001Oooooo0_l0000<ooooo`Co00002_ooool2o`0000Oooooo1?l00009ooooo`?o00001_oo
ool3o`0000Gooooo3Ol0000Nooooo`;o00003_ooool4o`0000;ooooo0_l00004ooooo`;o00001Ooo
ool2o`0001Oooooo1Ol00005ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0?oooool2
o`0001Cooooo0_l0000?ooooo`Ko00004Oooool4o`0000Gooooo0_l00002ooooo`;o00001?ooool2
o`000004ooooool0003o0000o`0000?ooooo1Ol00002ooooo`;o000000Coooooo`000?l0003ooooo
1?l0000Jooooo`Co00000_ooool4o`0000Sooooo1Ol00007ooooo`;o00001?ooool3o`0001Oooooo
0ol00007ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0EOooool2o`0000Kooooo0_l0
00000ooooooo0000o`000004ooooo`?o000000Coooooo`000?l0003ooooo0_l0000=ooooo`Co0000
00?oooooo`000?l000000oooool3o`0000Oooooo0ol00004ooooo`Co000000?oooooo`000?l00000
0_l000001?oooooo0000o`000?l00004ooooo`;o00006_ooool4o`0000;ooooo1?l000000ooooooo
0000o`000008ooooo`;o00001_ooool2o`0000Gooooo0_l0000Hooooo`;o000000Coooooo`000?l0
003o0000@Oooool001cooooo00?o0000ooooooooool0>_ooool2o`0000Kooooo0_l0000?ooooo`?o
00001oooool2o`000003ooooool0003o000000Cooooo0ol00004ooooo`;o00003?ooool5o`000004
ooooool0003o0000o`0000;ooooo0ol000000ooooooo0000o`000003ooooo`Co00001?ooool2o`00
00Gooooo0_l000000ooooooo0000o`000002o`0001?ooooo0_l00008ooooo`;o00002oooool2o`00
00Sooooo0_l00006ooooo`;o00007_ooool3o`000004ooooool0003o0000o`0000oooooo0_l0000`
ooooo`007?ooool00ol0003oooooooooo`0iooooo`?o00001_ooool2o`0000oooooo0ol0000@oooo
o`;o00001_ooool2o`000003ooooool0003o000000Sooooo0_l00005ooooo`?o00000_ooool5o`00
00?ooooo1?l00006ooooo`;o00001?ooool7o`0001;ooooo0_l00006ooooo`Go00005?ooool4o`00
00Oooooo0_l0000Kooooo`?o000000?oooooo`000?l000004?ooool2o`00033ooooo000Looooo`03
o`000?oooooooooo03Wooooo1?l00005ooooo`;o00009?ooool2o`0000Cooooo0_l000000ooooooo
0000o`000005ooooo`;o00002Oooool2o`0000Cooooo0_l00002ooooo`?o00001Oooool2o`000003
ooooool0003o000000Wo000000?oooooo`000?l000006_ooool2o`000003ooooool0003o000000Oo
oooo0_l0000;ooooo`Co00000_ooool2o`0000?ooooo1?l0000Iooooo`;o0000A_ooool001cooooo
00?o0000ooooooooool0>oooool4o`0000?ooooo0_l00003ooooo`;o00006Oooool2o`000004oooo
ool0003o0000ooooo`;o00001oooool2o`0000;ooooo1Ol000000ooooooo0000o`000004ooooo`Co
00000oooool2o`0000;ooooo1?l00005ooooo`;o000000?oooooo`000?l000002Ol00008ooooo`Co
00007Oooool4o`000003ooooool0003o000000Kooooo1?l00002ooooo`;o00001Oooool2o`0001So
oooo0_l00002ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0?Oooool2o`0000Sooooo
0_l0000Iooooo`;o000000?oooooo`000?l000000_l00008ooooo`;o00000_ooool4o`0000;ooooo
0_l00003ooooo`Go00000_ooool3o`0000;ooooo0_l0000;ooooo`Ko00003?ooool4o`0000Cooooo
0_l00006ooooo`;o00002oooool2o`0000;ooooo1?l000000ooooooo0000o`000002o`0000Cooooo
1?l0000Sooooo`;o00000_ooool2o`0000Oooooo0ol0000iooooo`007?ooool00ol0003ooooooooo
o`0mooooo`;o00002?ooool2o`0000;ooooo0_l0000Iooooo`?o00005oooool2o`000003ooooool0
003o000000Go00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000009o`0001;ooooo1_l0
0002ooooo`Co00002oooool2o`0000Wooooo0_l00004ooooo`Go00008_ooool2o`0000_ooooo0ol0
000iooooo`007?ooool00ol0003oooooooooo`0gooooo`Co00000_ooool3o`0000_ooooo0_l0000I
ooooo`Co000000Coooooo`000?l0003o00003?ooool2o`0000Oooooo1?l000000ooooooo0000o`00
0005ooooo`co00005?ooool4o`0000;ooooo0_l00002ooooo`;o00001?ooool2o`0001Cooooo0_l0
00000ooooooo0000o`000007o`0001oooooo0_l00005ooooo`;o00001?ooool3o`0003Wooooo000L
ooooo`03o`000?oooooooooo03Oooooo1?l00003ooooo`?o00009oooool2o`000004ooooool0003o
0000o`0000Sooooo0_l00002ooooo`;o00001_ooool2o`0000_ooooo2Ol00007ooooo`;o00002Ooo
ool7o`0000Cooooo0_l00003ooooo`;o00000oooool2o`0000Oooooo0_l0000;ooooo`;o000000Co
ooooo`000?l0003o00000_ooool6o`0000;ooooo0_l0000Iooooo`;o00000_ooool5o`0000Cooooo
0_l0000jooooo`007?ooool00ol0003oooooooooo`0hooooo`?o00001?ooool2o`0002oooooo0_l0
0004ooooo`;o000000?oooooo`000?l000001Oooool4o`0000_ooooo1Ol000000ooooooo0000o`00
0004ooooo`;o00000_ooool2o`0000Cooooo1?l000000ooooooo0000o`000003o`0000_ooooo0_l0
0003ooooo`;o00001oooool2o`0000oooooo0_l00003ooooo`Go00000_ooool2o`0000;ooooo0_l0
000Hooooo`Go00000oooool2o`0003cooooo000Looooo`03o`000?oooooooooo03kooooo0_l0000`
ooooo`?o000000?oooooo`000?l000000_l000000ooooooo0000o`000005ooooo`;o000000?ooooo
o`000?l000002?ooool8o`0000Cooooo1?l00005ooooo`;o000000?oooooo`000?l000000_l00004
ooooo`;o00002oooool3o`0001Oooooo0_l00008ooooo`Go000000?oooooo`000?l000000_ooool3
o`0001Sooooo0_l000000ooooooo0000o`000003ooooo`;o0000??ooool001cooooo00?o0000oooo
ooooool0=oooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o0000;Oooool2o`00
0003ooooool0003o000000Ko00001oooool4o`0000Cooooo1_l000000ooooooo0000o`000003o`00
00;ooooo0_l00007ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Sooooo0_l000001?oo
oooo0000o`000?l0000:ooooo`?o00001Oooool2o`0000?ooooo0_l0000;ooooo`Go00000_ooool3
o`0001_ooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0gooooo`Ko00001Oooool4o`00
03;ooooo1_l000000ooooooo0000o`000004ooooo`;o00001?ooool2o`000004ooooool0003o0000
o`0000Cooooo0_l00004ooooo`?o00000_ooool2o`0000?ooooo0_l0000:ooooo`;o00001?ooool2
o`0000kooooo0ol00005ooooo`;o00004_ooool2o`0000Cooooo0_l0000Zooooo`;o0000<_ooool0
01cooooo00?o0000ooooooooool0>?ooool7o`0000Gooooo0_l0000^ooooo`;o00001Oooool3o`00
0003ooooool0003o000000gooooo0_l00007ooooo`co00000_ooool2o`0000[ooooo0_l0000<oooo
o`;o00002_ooool2o`000004ooooool0003o0000o`0004Cooooo0_l0000booooo`007?ooool2o`00
037ooooo0_l00006ooooo`Wo0000;oooool2o`0000;ooooo1?l00006ooooo`?o00003Oooool3o`00
00Kooooo1?l00002ooooo`?o000000?oooooo`000?l000006?ooool3o`000003ooooool0003o0000
00Oooooo0_l000001?oooooo0000o`000?ooool2o`0003[ooooo0_l00009ooooo`;o0000<_ooool0
01cooooo00?o0000ooooooooool0<?ooool2o`0000Sooooo1ol0000_ooooo`;o00000_ooool4o`00
00Kooooo0_l0000>ooooo`Go000000?oooooo`000?l000001_ooool3o`0000;ooooo0ol00004oooo
o`Go00000_ooool2o`000003ooooool0003o000000;ooooo2?l000000ooooooo0000o`000006o`00
0003ooooool0003o000000Cooooo0_l0000Gooooo`;o000000?oooooo`000?l000007Oooool3o`00
03gooooo000Looooo`03o`000?oooooooooo02oooooo0_l00007ooooo`;o000000?oooooo`000?l0
00000_l0000eooooo`;o00002?ooool2o`0000gooooo0_l00002ooooo`;o000000?oooooo`000?l0
00001Oooool3o`0000Cooooo0_l00004ooooob7o00001Oooool2o`0000oooooo0_l00006ooooo`;o
000000Coooooo`000?l0003o00004?ooool3o`0000Wooooo0_l0000nooooo`007?ooool00ol0003o
ooooooooo`0_ooooo`;o000000?oooooo`000?l000001?ooool2o`0003Wooooo0ol00006ooooo`;o
00003oooool2o`0000Wooooo0_l000001?oooooo0000o`000?l00004ooooo`;o00001?ooool2o`00
00?ooooo1Ol000000ooooooo0000o`00000;o`000003ooooool0003o000000?o000000Goooooo`00
0?l0003o0000ooooo`02o`000003ooooool0003o000000oooooo0_l0000:ooooo`;o00004?ooool3
o`0000Wooooo1?l0000looooo`007?ooool00ol0003oooooooooo`0booooo`;o000000?oooooo`00
0?l000001?ooool2o`000003ooooool0003o000003?ooooo0_l00007ooooo`Go00000oooool2o`00
017ooooo0ol00003ooooo`;o00002Oooool2o`000004ooooool0003o0000o`0000Gooooo2?l00003
ooooo`;o00000_ooool4o`000005ooooool0003o0000o`000?ooool00_l000000ooooooo0000o`00
0002ooooo`;o00002_ooool2o`0002Cooooo0ol00002ooooo`Co0000??ooool001cooooo00?o0000
ooooooooool0=Oooool2o`0000Cooooo0_l000000ooooooo0000o`00000mooooo`Co00000oooool2
o`00017ooooo0ol00003ooooo`?o00002?ooool6o`0000Oooooo1_l00008ooooo`;o00000_ooool6
o`0000?ooooo1?l0000:ooooo`;o00001_ooool2o`0001cooooo0ol00002ooooo`;o0000?_ooool0
01cooooo00?o0000ooooooooool0=Oooool2o`0000Cooooo0_l0000Xooooo`;o00006?ooool2o`00
017ooooo0_l00002ooooo`;o00001Oooool3o`0000[ooooo1?l00006ooooo`Co000000Coooooo`00
0?l0003ooooo1Ol00002ooooo`;o00000oooool4o`0000Cooooo0ol00004ooooo`;o00003Oooool2
o`00067ooooo000Looooo`03o`000?oooooooooo03Gooooo0_l00004ooooo`;o0000:?ooool2o`00
00Wooooo0_l0000Pooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo0ol0000;oooo
o`?o00001?oooolAo`000003ooooool0003o000000Ko00000_ooool5o`0000;ooooo1?l0000Foooo
o`;o0000F?ooool001cooooo00?o0000ooooooooool0=?ooool2o`0000cooooo0_l0000/ooooo`;o
00008?ooool2o`0000Gooooo0_l00002ooooo`?o00000oooool2o`0000Kooooo0_l00003ooooo`Wo
000000?oooooo`000?l000004?l00002ooooo`Ko000000Coooooo`000?l0003o00005oooool2o`00
01Kooooo0_l000000ooooooo0000o`00000mooooo`007?ooool00ol0003oooooooooo`0dooooo`;o
00003?ooool2o`00027ooooo0_l0000Jooooo`;o00006oooool2o`0000?ooooo0_l000001?oooooo
0000o`000?l00007ooooo`Co00000_oooolFo`000003ooooool0003o000000Go00000_ooool2o`00
01Oooooo0_l0000;ooooo`;o00002Oooool2o`000003ooooool0003o000003gooooo000Looooo`03
o`000?oooooooooo03?ooooo0_l0000`ooooo`;o00000_ooool2o`0000Cooooo0_l0000@ooooo`;o
00006oooool2o`0000;ooooo0ol000001?oooooo0000o`000?l0000:oooooaSo00000_ooool2o`00
0003ooooool0003o000000?o000000?oooooo`000?l000005oooool2o`0000_ooooo0_l00005oooo
o`;o0000A?ooool001cooooo00?o0000ooooooooool0<oooool2o`0003;ooooo1?l00004ooooo`;o
00002?ooool2o`0000Oooooo0_l000000ooooooo0000o`00000Eooooo`;o00001?ooool5o`0000So
oooo0_l00002ooooo`Oo000000?oooooo`000?l000004ol000000ooooooo0000o`000003o`0001Wo
oooo0_l0000Aooooo`?o000000?oooooo`000?l00000@Oooool001cooooo00?o0000ooooooooool0
;Oooool2o`0003Sooooo1?l00009ooooo`;o00000oooool2o`0000Oooooo0_l000000ooooooo0000
o`00000Eooooo`;o00001_ooool3o`0000Sooooo0ol000000ooooooo0000o`000006o`0000;ooooo
2Ol000000ooooooo0000o`00000>o`0000oooooo0_l00003ooooo`;o00000_ooool2o`0000Oooooo
0_l00008ooooo`;o00000_ooool2o`0000[ooooo0_l0000eooooo`007?ooool00ol0003ooooooooo
o`0]ooooo`;o0000>?ooool3o`000003ooooool0003o000000Cooooo1_l00002ooooo`;o00001_oo
ool3o`000003ooooool0003o000000_ooooo0_l0000Looooo`;o000000?oooooo`000?l000005_l0
0003ooooo`[o00003_ooool2o`0000?ooooo0_l0000:ooooo`?o00003?ooool2o`0000Cooooo0_l0
0004ooooo`;o0000=Oooool001cooooo00?o0000ooooooooool0F?ooool2o`0000?ooooo0_l00008
ooooo`?o000000?oooooo`000?l000001?ooool3o`000003ooooool0003o000000;ooooo0_l00003
ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0000[ooooo0_l00006ooooo`Go00002?oo
ool2o`0000Gooooo4ol000000ooooooo0000o`000007o`000003ooooool0003o000000Oo000000Co
ooooo`000?l0003ooooo0_l0000Aooooo`;o00002Oooool2o`0000;ooooo0_l00004ooooo`;o0000
2Oooool2o`0003_ooooo000Looooo`03o`000?oooooooooo05Sooooo0_l000000ooooooo0000o`00
0002o`000003ooooool0003o000000_ooooo0_l00003ooooo`;o00002_ooool2o`0000Cooooo1?l0
0002ooooo`;o000000?oooooo`000?l000002oooool5o`0000Sooooo0_l00004ooooo`ko000000?o
ooooo`000?l000001ol000000ooooooo0000o`000003o`000003ooooool0003o000000Oo00001?oo
ool3o`0000Sooooo0_l00004ooooo`Co00000_ooool2o`0000Wooooo0_l00004ooooo`;o00000_oo
ool2o`0000[ooooo0_l0000fooooo`007?ooool2o`0002_ooooo0_l00008ooooo`;o00008_ooool:
o`000005ooooool0003o0000o`000?ooool00_l00002ooooo`Co00004?ooool2o`0000?ooooo0_l0
0004ooooo`;o000000?oooooo`000?l000000_ooool2o`0001[ooooo0_l00002oooooaCo000000?o
ooooo`000?l000002_l000000ooooooo0000o`000003o`000004ooooool0003o0000o`0000Sooooo
0_l00004ooooo`;o00000_ooool4o`0001?ooooo0_l0000:ooooo`;o0000=_ooool001cooooo00?o
0000ooooooooool0:_ooool2o`0000Sooooo0_l0000?ooooo`;o00003Oooool3o`0000?ooooo4ol0
0007ooooo`;o00002Oooool2o`0000?ooooo0ol0000:ooooo`;o00006_ooool[o`000004ooooool0
003o0000o`0001;ooooo0_l0001Iooooo`007?ooool00ol0003oooooooooo`0Yooooo`;o00001ooo
ool2o`00017ooooo0_l0000=ooooo`?o00001?oooolBo`0000Oooooo0_l0000;ooooo`Ko00004ooo
ool2o`000003ooooool0003o000000kooooo1?l000000ooooooo0000o`00000Mo`000003ooooool0
003o000000Go00000_ooool2o`0000[ooooo0_l0000=ooooo`;o00002Oooool2o`0000Oooooo0_l0
000mooooo`007?ooool00ol0003oooooooooo`0Yooooo`;o00001oooool2o`00027ooooo0_l00003
ooooo`Co000000?oooooo`000?l000001_l000000ooooooo0000o`000002o`0000Cooooo0_l00003
ooooo`;o00001?ooool2o`0000Cooooo1?l00006ooooo`;o00003Oooool2o`000003ooooool0003o
000000gooooo0ol000000ooooooo0000o`00000Ko`000003ooooool0003o000000[o000000?ooooo
o`000?l000002_ooool2o`0000gooooo0_l00009ooooo`;o00001oooool2o`0003gooooo000Loooo
o`03o`000?oooooooooo05?ooooo0_l00002oooooaCo000000?oooooo`000?l000000_ooool3o`00
00;ooooo0_l00004ooooo`;o00000oooool5o`0000Kooooo0_l0000:ooooo`;o000000Coooooo`00
0?l0003ooooo0_l00004ooooo`;o00001oooool6o`000003ooooool0003o000002;o000000?ooooo
o`000?l000001?l00002ooooo`;o0000Ioooool001cooooo00?o0000ooooooooool0?oooool2o`00
00oooooo7_l000000ooooooo0000o`000003o`0000_ooooo1_l00006ooooo`;o00002_ooool2o`00
0004ooooool0003o0000ooooo`;o00001?ooool3o`0000Kooooo1Ol00002ooooob_o00000_ooool2
o`0001Cooooo0_l00007ooooo`?o0000Aoooool001cooooo00?o0000ooooooooool0?oooool2o`00
00oooooo1?l000000ooooooo0000o`00000Mo`0000_ooooo0_l000001?oooooo0000o`000?l00002
ooooo`;o00000_ooool3o`0001Gooooo0ol00006ooooo`?o000000?oooooo`000?l000009?l00000
1?oooooo0000o`000?l00002ooooo`?o00005oooool2o`0000Oooooo0ol00004ooooo`;o00001_oo
ool2o`0003Wooooo000Looooo`03o`000?oooooooooo03Cooooo1?l0000Iooooo`;o00000_oooolL
o`0000?ooooo0ol00005ooooo`;o000000?oooooo`000?l000001_ooool2o`0000?ooooo0_l0000?
ooooo`;o00000_ooool2o`0000Wooooo0_l00002ooooobGo00000oooool2o`000003ooooool0003o
000000;o00006_ooool2o`0000_ooooo0_l00006ooooo`;o0000>Oooool001cooooo00?o0000oooo
ooooool0=?ooool4o`0001Oooooo0_l00005oooooa7o000000?oooooo`000?l000000_l000000ooo
oooo0000o`000002o`0000?ooooo0ol00002ooooo`;o000000Coooooo`000?l0003ooooo0_l0000L
ooooo`;o00000_ooool2o`0000[ooooo0_l00003ooooob?o00001Oooool5o`0000Sooooo0_l0000@
ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0:Oooool2o`0002Cooooo1?l000000ooo
oooo0000o`00000@o`0000;ooooo2Ol00007ooooo`?o00000oooool4o`0000_ooooo0_l0000Doooo
o`;o00001Oooool2o`000003ooooool0003o000000?ooooo8ol000000ooooooo0000o`000002oooo
o`Ko00001Oooool4o`0001kooooo0_l00003ooooo`;o0000>oooool001cooooo00?o0000oooooooo
ool0:Oooool2o`0002Kooooo0_l000000ooooooo0000o`00000Lo`000003ooooool0003o000000?o
oooo0_l00004ooooo`Co00002oooool2o`0000[ooooo0_l00005ooooo`;o000000?oooooo`000?l0
00001Oooool4o`0000Gooooo8_l000000ooooooo0000o`000008o`0000Gooooo0_l0000=ooooo`;o
00004Oooool2o`0000?ooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`1Booooob3o0000
00?oooooo`000?l000001oooool4o`0001Wooooo0_l00002ooooo`Oo00002?ooool5o`0000;ooooo
9ol00004ooooo`;o00002?ooool2o`0000[ooooo0_l00002ooooo`;o0000Coooool001cooooo00?o
0000ooooooooool0D_oooolOo`0000Wooooo1Ol0000Looooo`Go000000Coooooo`000?l0003o0000
0oooool2o`0000?ooooo1Ol00004ooooob?o00001_ooool2o`0000Cooooo1_l000000ooooooo0000
o`000008ooooo`;o000000?oooooo`000?l000003oooool2o`0003kooooo000Looooo`03o`000?oo
oooooooo03cooooo0_l0000Foooooago00002Oooool4o`0001gooooo0_l00004ooooo`;o000000Co
ooooo`000?l0003ooooo0_l00005ooooo`?o00001?oooolOo`000004ooooool0003o0000o`0000Go
oooo0ol00004ooooo`Co00000oooool4o`0000Kooooo0_l0000Booooo`;o0000?_ooool00006oooo
ooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006
ooooo`03o`000?oooooooooo03[ooooo1?l0000?ooooo`;o00001OoooolOo`0000Sooooo1Ol0000<
ooooo`;o00000oooool2o`0000Wooooo0_l00006ooooo`;o00002?ooool4o`000003ooooool0003o
000001oo00002Oooool4o`0000Cooooo0ol00004ooooo`?o00000oooool3o`0000?ooooo0_l0000:
ooooo`?o0000@_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go
EEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo03[ooooo0_l0000>ooooo`;o0000
00Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00000Fo`000003ooooool0003o000000Go
00001oooool3o`000003ooooool0003o000000cooooo0_l00003ooooo`;o00000_ooool2o`0000;o
oooo0_l000000ooooooo0000o`000005ooooo`;o00002_ooool3o`000003ooooool0003o000001co
000000?oooooo`000?l000001oooool6o`0000Cooooo0ol00009ooooo`Co00000oooool2o`0000?o
oooo0_l00005ooooo`?o0000@_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool0
2Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0BOooool3o`0000Co
oooo0_l000000ooooooo0000o`00000Lo`0000Sooooo0ol0000Iooooo`;o00000_ooool2o`0000?o
oooo0_l00003ooooo`Go00001oooool4o`0000?ooooo1?l000000ooooooo0000o`00000Do`0000Ko
oooo0_l00002ooooo`Ko00001Oooool2o`0000Wooooo0_l0000:ooooo`;o0000B_ooool00003oooo
ool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Ko
oooo0ol00019ooooo`;o00001oooool@o`000003ooooool0003o000000[o00002Oooool4o`0002;o
oooo0_l00005ooooo`?o00001_ooool5o`0000?ooooo7?l00002ooooo`Go00001?ooool3o`000003
ooooool0003o0000017ooooo0_l0001Cooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooo
ooooo`09ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`1Booooo`Ko
000000?oooooo`000?l000005?l00009ooooo`Co00007oooool3o`00013ooooo1Ol00005oooooa[o
00000_ooool4o`0000Gooooo0_l00002ooooo`;o00004Oooool2o`0000oooooo0_l00012ooooo`00
00?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo
00?o0000ooooooooool0D_ooool3o`000003ooooool0003o000001Wo00001_ooool5o`0000Wooooo
0ol00003ooooo`;o00002Oooool2o`0000?ooooo0ol0000Aooooo`Co00002OoooolHo`0000;ooooo
1Ol00006ooooo`?o00001Oooool2o`0001[ooooo0_l00012ooooo`0000KoooooogMgMonHV9Sooooo
oiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0>oooool2o`0000oo
oooo0_l00002ooooo`Co000000?oooooo`000?l000005_l000001?oooooo0000o`000?l00006oooo
o`;o00003?ooool3o`0000;ooooo0ol00005ooooo`;o00000_ooool2o`0000oooooo1?l0000Boooo
oaoo00001_ooool2o`0000Gooooo1Ol0001Kooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<
ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0=oooool2o`0000;ooooo0_l0
000?ooooo`;o00000_ooool2o`0000?ooooo2?l000000ooooooo0000o`000006o`000003ooooool0
003o000000Go00005oooool2o`0000?ooooo0_l00006ooooo`;o00004Oooool6o`0000Sooooo0ol0
0006ooooo`;o000000?oooooo`000?l000005Ol00004ooooo`;o00001?ooool2o`0000Cooooo0_l0
0002ooooo`Co000000?oooooo`000?l000004?ooool2o`0004Kooooo000Looooo`03o`000?oooooo
oooo03Oooooo0ol00004ooooo`;o00001oooool2o`0000_ooooo6ol00005ooooo`Co00003Oooool2
o`0000_ooooo0_l0000Aooooo`Ko00002?ooool3o`0000?ooooo0_l000000ooooooo0000o`00000A
o`000003ooooool0003o000000;o00003?ooool3o`0000?ooooo0_l00003ooooo`;o00000_ooool2
o`0000Cooooo0_l00008ooooo`Co0000A_ooool001cooooo00?o0000ooooooooool0>?ooool2o`00
00Cooooo0_l00007ooooo`?o00002_oooolFo`0000?ooooo0_l00005ooooo`Co0000;oooool3o`00
00[ooooo0_l00002ooooo`?o00000_ooool=o`000004ooooool0003o0000o`0000;ooooo1?l0000=
ooooo`;o00001oooool4o`000004ooooool0003o0000o`0000?ooooo0_l00008ooooo`;o000000?o
ooooo`000?l000001oooool2o`0003cooooo000Looooo`03o`000?oooooooooo03gooooo0ol00008
ooooo`;o00003?ooool@o`000003ooooool0003o000002;ooooo0_l000000ooooooo0000o`00000F
ooooo`?o000000?oooooo`000?l000001oooool3o`000004ooooool0003o0000o`0000?ooooo3Ol0
00001?oooooo0000o`000?l00002ooooo`So00003oooool8o`000003ooooool0003o000000cooooo
0_l00002ooooo`;o00001oooool2o`0003cooooo000Looooo`03o`000?oooooooooo03gooooo0ol0
0007ooooo`;o00003oooool2o`000003ooooool0003o000000Oo00000_ooool5o`00023ooooo1Ol0
0002ooooo`;o00002oooool2o`0000Gooooo1_l00007ooooo`Ko00001Oooool2o`0000;ooooo1Ol0
00000ooooooo0000o`000003ooooo`?o000000?oooooo`000?l000001Ol000000ooooooo0000o`00
0006ooooo`;o00001?ooool3o`0000?ooooo0_l00005ooooo`;o00002?ooool2o`0004Wooooo000L
ooooo`03o`000?oooooooooo04Oooooo0_l0000;ooooo`;o00000_ooool2o`0000Cooooo0ol00003
ooooo`Co000000?oooooo`000?l000002Oooool2o`0000cooooo1?l00006ooooo`?o00000oooool2
o`0000_ooooo0_l00006ooooo`?o00003?ooool4o`0000Cooooo0_l00004ooooo`co000000?ooooo
o`000?l000000ol00003ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0000?ooooo0_l0
000<ooooo`;o00004?ooool2o`00047ooooo000Looooo`03o`000?oooooooooo05Cooooo0_l0000;
ooooo`Go00002_ooool2o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o00001?ooool4
o`0000cooooo0_l00004ooooo`;o00001_ooool2o`0001Cooooo1?l0000<ooooo`[o000000?ooooo
o`000?l000001?l00005ooooo`?o00001oooool2o`0000Wooooo0_l00009ooooo`;o00002?ooool2
o`00047ooooo000Looooo`03o`000?oooooooooo03oooooo0_l0000Pooooo`?o00002?ooool2o`00
00;ooooo0_l00005ooooo`;o000000?oooooo`000?l000000_l00006ooooo`;o00003?ooool2o`00
00Cooooo0_l00006ooooo`;o00004Oooool2o`0000oooooo0_l00008ooooo`;o000000?oooooo`00
0?l000001?l000000ooooooo0000o`000005ooooo`;o00000oooool2o`0000_ooooo0_l00007oooo
o`Co0000Boooool001cooooo00?o0000ooooooooool0?Oooool4o`0001?ooooo0_l0000Fooooo`;o
00003?ooool2o`0002kooooo0_l000000ooooooo0000o`000004ooooo`;o00003oooool2o`0000So
oooo0_l00008ooooo`;o00001Oooool2o`0000;ooooo1Ol00002ooooo`;o00002_ooool2o`0000;o
oooo0_l0000:ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0>Oooool2o`0000;ooooo
0_l0000?ooooo`;o00001?ooool2o`0000kooooo0_l00004ooooo`;o0000?_ooool2o`000003oooo
ool0003o000000?ooooo0_l00006ooooo`;o00002?ooool2o`0000Sooooo0_l000000ooooooo0000
o`000002ooooo`;o00001oooool2o`0000?ooooo1Ol00002ooooo`Co00002?ooool2o`0000;ooooo
0_l0000:ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0>Oooool2o`0000kooooo0_l0
0003ooooo`Co00004_ooool2o`000004ooooool0003o0000ooooo`;o00007Oooool2o`000003oooo
ool0003o000000?ooooo0_l00009ooooo`;o00002Oooool2o`0000Wooooo0_l00006ooooo`;o0000
2?ooool4o`0000;ooooo1?l00003ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`000003
ooooool0003o000000Gooooo1?l00003ooooo`;o00002Oooool2o`0000Sooooo0_l00016ooooo`00
7?ooool00ol0003oooooooooo`19ooooo`;o00001?ooool6o`0000cooooo0_l00004ooooo`;o0000
1Oooool4o`0001Oooooo1Ol00003ooooo`;o00001?ooool2o`0000?ooooo0_l00003ooooo`;o0000
1?ooool2o`0001?ooooo0ol00002ooooo`;o00000oooool2o`000003ooooool0003o000000?o0000
1_ooool2o`0000Gooooo0_l000001?oooooo0000o`000?l00006ooooo`;o00002?ooool2o`0000;o
oooo1?l00008ooooo`;o000000?oooooo`000?l00000@oooool001cooooo0_l0000eooooo`;o0000
6oooool5o`0000Kooooo0_l00003ooooo`;o00001?ooool2o`0000Gooooo1?l0000Hooooo`;o0000
1?ooool3o`000003ooooool0003o000000?o00001Oooool2o`000003ooooool0003o000001Gooooo
0_l00002ooooo`Co000000?oooooo`000?l000001_ooool2o`0000kooooo0ol000000ooooooo0000
o`000002o`0000;ooooo0_l0000;ooooo`Oo000000?oooooo`000?l000002_ooool2o`0004?ooooo
000Looooo`03o`000?oooooooooo03Cooooo0_l0000;ooooo`;o00004Oooool2o`0000Kooooo0_l0
0009ooooo`?o00004oooool2o`00017ooooo2Ol00005ooooo`;o000000?oooooo`000?l000002?oo
ool2o`0000Cooooo0_l00005ooooo`?o00000oooool2o`0000;ooooo0_l00002ooooo`;o00004Ooo
ool6o`0000Cooooo0_l0000;ooooo`Go00000oooool2o`0004oooooo000Looooo`03o`000?oooooo
oooo047ooooo0_l0000Hooooo`;o00002oooool2o`0001;ooooo1?l00009ooooo`?o00001Oooool5
o`0000Oooooo0_l000000ooooooo0000o`000002o`0000Oooooo0_l000001?oooooo0000o`000?oo
ool2o`0000?ooooo0_l000000ooooooo0000o`000007ooooo`;o00000_ooool2o`0000;ooooo2ol0
0007ooooo`;o00004oooool2o`000003ooooool0003o000005?ooooo000Looooo`03o`000?oooooo
oooo05_ooooo0_l0000<ooooo`;o00004Oooool4o`0000Sooooo1?l000000ooooooo0000o`000006
o`0000Sooooo0_l000000ooooooo0000o`000002o`0000[ooooo0_l000000ooooooo0000o`000002
o`000003ooooool0003o000000;o00000oooool2o`0000Gooooo0_l00004ooooo`co00003oooool2
o`0000Gooooo0_l00006ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0H?ooool2o`00
00Oooooo0_l0000Booooo`;o00000oooool2o`0000Cooooo1?l000000ooooooo0000o`000006o`00
00?ooooo0_l000000ooooooo0000o`000002o`0000oooooo0_l00003ooooo`;o00000oooool2o`00
00?ooooo1?l00003ooooo`;o00001Oooool2o`0000?ooooo0_l000001?oooooo0000o`000?l0000?
ooooo`;o00001Oooool2o`0000Cooooo0_l00002ooooo`;o0000DOooool001cooooo00?o0000oooo
ooooool0=Oooool2o`00013ooooo1?l00009ooooo`;o00002_ooool2o`0001oooooo0ol00004oooo
o`co00001?ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000000_l0000Doooo
o`;o00000_ooool5o`0000oooooo0_l000000ooooooo0000o`000005ooooo`;o00002oooool4o`00
00Oooooo0_l00002ooooo`;o0000DOooool001cooooo00?o0000ooooooooool0=Oooool2o`00013o
oooo1?l00009ooooo`?o0000:_ooool2o`0000;ooooo3_l00006ooooo`;o000000?oooooo`000?l0
00001_l00007ooooo`;o00003oooool5o`0000;ooooo1?l0000<ooooo`;o00000oooool4o`0000_o
oooo1?l00003ooooo`Co0000Eoooool001cooooo00?o0000ooooooooool0EOooool2o`0000Oooooo
0_l0000Hooooo`;o00001oooool2o`0000;ooooo3_l00006ooooo`;o000000?oooooo`000?l00000
0_l00002ooooo`;o00001?ooool2o`000003ooooool0003o000000Gooooo0_l00004ooooo`;o0000
2Oooool4o`0000cooooo0_l00003ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`?o0000
0oooool6o`0005Oooooo000Looooo`03o`000?oooooooooo05Sooooo0_l00004ooooo`;o00006?oo
ool2o`0000Wooooo4?l00003ooooo`;o00000_ooool2o`0000Oooooo0_l00003ooooo`;o00000ooo
ool2o`0000?ooooo0_l00004ooooo`;o00003_ooool2o`0000Wooooo0_l00007ooooo`?o00000_oo
ool2o`0000;ooooo1?l00003ooooo`Go0000F?ooool001cooooo00?o0000ooooooooool0F?ooool2
o`0002Wooooo4?l00003ooooo`;o00000_ooool2o`0000Oooooo0_l00008ooooo`;o00000_ooool2
o`0000Gooooo0_l0000>ooooo`;o00002Oooool2o`0000Oooooo0ol00002ooooo`;o00000_ooool3
o`0000?ooooo0ol0001Kooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o0000;Oooool2o`00
00Kooooo4?l00002ooooo`;o00006Oooool2o`0002Cooooo0_l00004ooooo`;o00000_ooool2o`00
00Oooooo0ol0001Looooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00001oooool2o`0002Co
oooo0_l00006oooooaCo00002oooool2o`0000?ooooo0_l00007ooooo`Co00008_ooool2o`0000?o
oooo0ol00002ooooo`?o00001_ooool2o`0005gooooo000Looooo`03o`000?oooooooooo05Kooooo
0_l00008ooooo`Co00005_ooool2o`0000Sooooo4_l0000=ooooo`;o00000_ooool3o`0000Oooooo
1?l0000Vooooo`?o00001?ooool2o`0006Gooooo000Looooo`03o`000?oooooooooo03Sooooo0_l0
000Cooooo`;o00004Oooool4o`0001Gooooo0ol00005oooooaKo000000?oooooo`000?l000002_oo
ool2o`000003ooooool0003o000000Kooooo0_l00006ooooo`;o00001Oooool2o`0000?ooooo0_l0
000;ooooo`;o00002Oooool2o`0006cooooo000Looooo`03o`000?oooooooooo03Sooooo0_l0000C
ooooo`;o0000:_ooool2o`0000Kooooo5_l000000ooooooo0000o`00000:ooooo`Co00001oooool4
o`0000Cooooo1?l00003ooooo`;o00000oooool2o`000003ooooool0003o000000Sooooo0_l00000
1?oooooo0000o`000?ooool2o`0000?ooooo0_l0001/ooooo`007?ooool00ol0003oooooooooo`11
ooooo`;o00002oooool2o`00037ooooo5?l0000?ooooo`Co00002Oooool3o`000003ooooool0003o
000000;ooooo0ol00007ooooo`;o000000?oooooo`000?l000002_ooool3o`000003ooooool0003o
000000?ooooo0_l0001/ooooo`007?ooool2o`0004;ooooo0_l00002ooooo`;o00001oooool2o`00
01Cooooo0_l0000KoooooaCo00000_ooool3o`0000?ooooo0_l00005ooooo`Go00000oooool8o`00
0003ooooool0003o000000Go00001oooool2o`0000gooooo0_l0001eooooo`007?ooool00ol0003o
ooooooooo`15ooooo`;o00007Oooool2o`0001cooooo5?l000001?oooooo0000o`000?l00002oooo
o`?o00000_ooool2o`000004ooooool0003o0000ooooo`;o00000oooool6o`0000Cooooo1?l0000>
ooooo`Go000000?oooooo`000?l000000_ooool2o`0007Gooooo000Looooo`03o`000?oooooooooo
057ooooo0_l000000ooooooo0000o`00000:ooooo`;o00008OoooolCo`000003ooooool0003o0000
00?ooooo0_l00003ooooo`;o00003_ooool2o`0000?ooooo1Ol00004ooooo`;o000000?oooooo`00
0?l000001?ooool5o`000003ooooool0003o000007Wooooo000Looooo`03o`000?oooooooooo04go
oooo0_l00002ooooo`Go00002_ooool2o`0000Cooooo0_l0000IoooooaSo00005?ooool2o`0000;o
oooo0_l00006ooooo`;o00000_ooool4o`000003ooooool0003o000000;o00000oooool2o`0007ko
oooo000Looooo`03o`000?oooooooooo04gooooo0_l000000ooooooo0000o`000005o`0000oooooo
0ol00002ooooo`;o00005?oooolCo`000003ooooool0003o000001Kooooo0ol0000=ooooo`;o0000
0oooool6o`000003ooooool0003o000007kooooo000Looooo`03o`000?oooooooooo053ooooo0ol0
0002ooooo`;o00004?ooool2o`0000;ooooo0_l0000>ooooo`;o00001_oooolAo`00013ooooo0_l0
0008ooooo`;o00003Oooool2o`0000?ooooo1_l0000Jooooo`;o000000?oooooo`000?l00000H_oo
ool001cooooo00?o0000ooooooooool0Eoooool3o`00027ooooo0_l00002ooooo`;o00000_oooolC
o`0000_ooooo1Ol0000Jooooo`;o00000oooool2o`0001_ooooo0_l000001Ooooooo0000o`000?l0
003ooooo00;o0000G_ooool001cooooo00?o0000ooooooooool0B_ooool2o`0000_ooooo0ol00004
ooooo`;o00007oooool2o`0000;ooooo4ol0000;ooooo`Co00006oooool2o`0001Cooooo0_l00000
0ooooooo0000o`000003ooooo`;o00001Oooool3o`000004ooooool0003o0000o`0000?ooooo0_l0
001Hooooo`007?ooool00ol0003oooooooooo`16ooooo`;o00000_ooool2o`0001;ooooo0_l0000S
ooooo`oo000000?oooooo`000?l000000_l00003ooooo`;o00001Oooool4o`0000;ooooo0_l0000=
ooooo`;o00004Oooool2o`0000_ooooo0_l000000ooooooo0000o`000003ooooo`;o00001Oooool2
o`0000?ooooo0_l00003ooooo`;o0000F?ooool001cooooo00?o0000ooooooooool0A_ooool2o`00
03_ooooo0_l000000ooooooo0000o`000007o`0000?ooooo0_l000000ooooooo0000o`000003oooo
o`;o00001Oooool2o`0000Cooooo0_l0000=ooooo`;o00004Oooool2o`0000Kooooo0_l0001foooo
o`007?ooool00ol0003oooooooooo`19ooooo`?o00007_ooool2o`0001[ooooo2_l00002ooooo`;o
00003_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00001_ooool2o`0000?o
oooo0_l00002ooooo`Co000000?oooooo`000?l000001oooool2o`0000?ooooo0_l00007ooooo`;o
000000?oooooo`000?l000000oooool2o`0000Cooooo0_l0001Oooooo`007?ooool00ol0003ooooo
ooooo`19ooooo`?o00007_ooool2o`0001Oooooo0_l000000ooooooo0000o`000009o`00017ooooo
1_l000000ooooooo0000o`000002ooooo`;o00001_ooool2o`0000?ooooo0_l00002ooooo`Co0000
00?oooooo`000?l000001oooool3o`0000_ooooo1Ol00003ooooo`;o00001?ooool4o`0005gooooo
000Looooo`03o`000?oooooooooo04gooooo0_l0000>ooooo`?o00003Oooool2o`0001Cooooo0_l0
00000ooooooo0000o`000005o`0000;ooooo0_l0000Aooooo`Co00005Oooool3o`0000;ooooo0_l0
000;ooooo`;o00001_ooool3o`000003ooooool0003o000000;o00003Oooool2o`0005gooooo000L
ooooo`03o`000?oooooooooo04Wooooo1_l0000>ooooo`?o00003Oooool2o`0000;ooooo0_l0000=
ooooo`;o00001?ooool2o`0001_ooooo1?l0000>ooooo`;o00001?ooool3o`0000;ooooo0_l0000@
ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000cooooo0_l0001Pooooo`007?ooool0
0ol0003oooooooooo`19ooooo`Co00001Oooool2o`0000Gooooo0_l0000Fooooo`;o00003Oooool5
o`0000Cooooo0_l00006ooooo`;o00002oooool2o`0000?ooooo1?l000000ooooooo0000o`00000;
ooooo`;o00000_ooool2o`0000Gooooo0_l0000@ooooo`;o00002Oooool2o`000003ooooool0003o
000000Gooooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`1Booooo`;o00001Oooool2o`00
02Oooooo0ol00004ooooo`;o00001_ooool2o`0000Oooooo0_l00002ooooo`;o00001?ooool2o`00
00;ooooo0_l00006ooooo`;o00000oooool3o`000003ooooool0003o000002;ooooo0_l000001?oo
oooo0000o`000?l0001Vooooo`007?ooool2o`0008[ooooo0_l0000>ooooo`?o00000_ooool2o`00
00Cooooo0_l0000:ooooo`;o00001?ooool4o`0001gooooo0_l00007ooooo`?o0000I_ooool001co
oooo00?o0000ooooooooool0Doooool2o`0002oooooo0ol0000@ooooo`Ko000000?oooooo`000?l0
00005_ooool4o`0001[ooooo0_l000000ooooooo0000o`000005ooooo`Co0000Ioooool001cooooo
00?o0000ooooooooool0C_ooool2o`0000?ooooo0_l000000ooooooo0000o`00000Mooooo`;o0000
3Oooool3o`0000Kooooo0_l00008ooooo`;o000000Goooooo`000?l0003o0000ooooo`03o`000003
ooooool0003o000000Kooooo0_l00004ooooo`;o00001?ooool3o`0001;ooooo0_l00007ooooo`;o
00002?ooool2o`0006Wooooo000Looooo`03o`000?oooooooooo04kooooo0_l00004ooooo`Co0000
7Oooool2o`0000_ooooo0_l00009ooooo`;o000000?oooooo`000?l000001oooool3o`0000?ooooo
1Ol00006ooooo`;o00001?ooool2o`0000Gooooo1?l0000@ooooo`;o00002Oooool2o`0000Gooooo
0_l0001Zooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00001Oooool2o`0000Sooooo0_l0
000Rooooo`?o00002oooool2o`0000Gooooo1?l00002ooooo`;o000000Goooooo`000?l0003o0000
ooooo`02o`0000_ooooo0_l00006ooooo`;o00003_ooool2o`0000Sooooo0_l000000ooooooo0000
o`000005ooooo`;o0000J_ooool001cooooo00?o0000ooooooooool0COooool2o`0000oooooo0ol0
000Rooooo`;o00000_ooool2o`0000kooooo1?l00002ooooo`;o000000?oooooo`000?l000001Ol0
0002ooooo`;o00001_ooool2o`0001Cooooo1?l00007ooooo`?o00002?ooool2o`0006[ooooo000L
ooooo`03o`000?oooooooooo04Wooooo0_l0000<ooooo`;o00001_ooool2o`0002Kooooo0ol0000?
ooooo`;o00001?ooool2o`0000;ooooo1Ol000000ooooooo0000o`00000Looooo`;o00002Oooool2
o`0000Sooooo0ol0001Zooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00001oooool2o`00
00?ooooo0_l0000_ooooo`;o00005Oooool4o`0000;ooooo1_l0000Looooo`;o00000oooool3o`00
00gooooo0_l0001[ooooo`007?ooool00ol0003oooooooooo`1Booooo`;o0000<_ooool2o`0001So
oooo0ol00005ooooo`Ko00007_ooool3o`0007[ooooo000Looooo`03o`000?oooooooooo08Kooooo
0ol0000Gooooo`;o00001?ooool2o`000003ooooool0003o000000?o00001Oooool2o`0000Sooooo
0_l0000Booooo`;o00002_ooool2o`0006[ooooo000Looooo`03o`000?oooooooooo05Oooooo0_l0
000^ooooo`;o000000?oooooo`000?l000000_l00006ooooo`;o00003Oooool2o`000003ooooool0
003o000000_ooooo0_l00008ooooo`Co00000oooool2o`0000_ooooo0_l0000:ooooo`;o0000J_oo
ool001cooooo00?o0000ooooooooool0Eoooool2o`0000Sooooo0_l0000Wooooo`Co00001_ooool3
o`0000cooooo0_l00002ooooo`;o00001Oooool5o`0000cooooo0_l00003ooooo`;o00001?ooool2
o`0000[ooooo0_l0001aooooo`007?ooool00ol0003oooooooooo`1Qooooo`;o0000:oooool2o`00
00Gooooo0_l0000@ooooo`;o00001Oooool5o`0001Oooooo0_l0000:ooooo`;o0000LOooool001co
oooo00?o0000ooooooooool0E_ooool2o`0000Wooooo0_l0000[ooooo`;o00000_ooool3o`0000Co
oooo0_l0000<ooooo`Co00001?ooool2o`0000Cooooo0_l0000Iooooo`;o0000Moooool00006oooo
ooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006
ooooo`03o`000?oooooooooo05Kooooo0_l0000jooooo`?o000000Coooooo`000?l0003ooooo0_l0
000=ooooo`Co000000?oooooo`000?l000001_ooool2o`0001Wooooo0_l0001gooooo`0000Kooooo
ogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Ko
oooo00?o0000ooooooooool0U_ooool2o`00013ooooo1?l000000ooooooo0000o`00000Oooooo`;o
0000NOooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool0X?ooool2o`0000Kooooo1_l0000Kooooo`;o
00000oooool2o`0007Wooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo
00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000Foooool2o`0004?ooooo1?l00006ooooo`Co
00002_ooool2o`0000cooooo0_l000000ooooooo0000o`00001nooooo`0000?oooooo`000?ooool0
0_ooool00ol0003oooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003o
ooooooooo`1Kooooo`;o0000?_ooool2o`0000Cooooo0ol00007ooooo`;o00001_ooool2o`0000?o
oooo0_l00008ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0007gooooo00000ooooooo
410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go410@okZj^_oooooo^[Zjoa0@4006oooo
o`03o`000?oooooooooo06cooooo0_l0000]ooooo`Co00000_ooool3o`000004ooooool0003o0000
o`0000Kooooo0_l00003ooooo`;o00003Oooool5o`0000?ooooo0_l0001mooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003ooooo
ooooo`1/ooooo`;o0000;oooool2o`0000Kooooo0ol00006ooooo`;o00001?ooool4o`0000cooooo
0_l00023ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@
4?nYZJT01_ooool00ol0003oooooooooo`1Oooooo`;o0000?oooool3o`00017ooooo1?l0002Aoooo
o`007?ooool00ol0003oooooooooo`1Oooooo`;o0000?oooool3o`0000;ooooo0_l0000@ooooo`;o
0000T?ooool001cooooo00?o0000ooooooooool0YOooool2o`00013ooooo0_l0002@ooooo`007?oo
ool00ol0003oooooooooo`2Uooooo`;o00002_ooool2o`0000?ooooo0_l0002Aooooo`007?ooool0
0ol0003oooooooooo`2Uooooo`;o00001Oooool2o`0000?ooooo0_l00003ooooo`;o0000TOooool0
01cooooo00?o0000ooooooooool0N_ooool2o`00033ooooo0ol0002Jooooo`007?ooool00ol0003o
ooooooooo`1jooooo`;o0000<Oooool2o`0009[ooooo000Looooo`03o`000?oooooooooo06Gooooo
0_l0000Gooooo`;o0000bOooool001cooooo00?o0000ooooooooool0IOooool4o`0001Gooooo0_l0
0039ooooo`007?ooool00ol0003oooooooooo`1Wooooo`;o00006?ooool2o`000<Kooooo000Loooo
o`03o`000?oooooooooo06cooooo0_l0000Cooooo`;o0000a_ooool001cooooo00?o0000oooooooo
ool0K?ooool2o`000=_ooooo000Looooo`;o0000R_ooool3o`000;gooooo000Looooo`03o`000?oo
oooooooo08Wooooo0ol00004ooooo`Ko0000/oooool001cooooo00?o0000ooooooooool0T?ooool6
o`000;?ooooo000Looooo`03o`000?oooooooooo077ooooo0_l0003Fooooo`007?ooool00ol0003o
ooooooooo`1aooooo`;o0000e_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0<cooooo0_l0001k
ooooo`007?ooool00ol0003oooooooooo`38ooooo`;o00000_ooool2o`0007_ooooo000Looooo`03
o`000?oooooooooo0<Sooooo0_l0001oooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`2oooooo`;o0000R?ooool001cooooo00?o0000oooooooo
ool0Poooool2o`0003[ooooo0_l00028ooooo`007?ooool00ol0003oooooooooo`23ooooo`;o0000
00?oooooo`000?l00000`Oooool001cooooo0_l00027ooooo`;o0000`Oooool001cooooo00?o0000
ooooooooool0Soooool2o`0002Wooooo0_l0002=ooooo`007?ooool00ol0003oooooooooo`2?oooo
o`?o00001?ooool2o`0002;ooooo0_l0002=ooooo`007?ooool00ol0003oooooooooo`2@ooooo`;o
00001?ooool2o`0000Cooooo0_l0002[ooooo`007?ooool00ol0003oooooooooo`2Looooo`Co0000
4?ooool2o`0000;ooooo0_l0002Cooooo`007?ooool00ol0003oooooooooo`2Nooooo`;o00001Ooo
ool2o`0000Gooooo0_l00002ooooo`;o00000_ooool2o`0009?ooooo000Looooo`03o`000?oooooo
oooo0:Gooooo0_l00005ooooo`;o0000Voooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001;ooooo1?l000000ol@413ooooooooo
o`03ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo0ol0003ooooo
od[ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0
oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooo
oooo0?ooooooD_ooool001;ooooo00?oEEEEofIVI_l00000oooooomDooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00YOooool01?l@413o0000o`000?ooool2o`000003oa0@4?oo
oooooooo01Oooooo0_l000002?l@413ooooooooooooooooo410@o`000?m4A4Coc<c<1?ooool5o`00
093ooooo002Vooooo`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo00?o0000oooo
ooooool01?ooool00onHV9So410@omgMg@03ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0T?ooool0
0:Kooooo00Go0000ooooooooooooooooo`00000Hooooo`Go00001_ooool00on7QhOoEEEEooooo`03
ooooo`03oiRHV?lQ8B7ok^k^097ooooo002Vooooo`05o`000?ooooooooooooooool000002Oooool6
o`0000Wooooo00CoA4A4omgMgOoooooo00001?ooool01Oo<c<co8B4Qo`000?mEEEGo000000Gooooo
00?oV9RHob4Q8Oo^k^h0T?ooool00:Kooooo00Go0000ohN7QoooooooZJVYo`00000Hooooo`04omgM
gOmEEEGoooooo`0000Cooooo00Go8B4QohN7QoooooooV9RHo`000006ooooo`03ogMgMomVIVKooooo
08oooooo002Uooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool05oooool00omgMgOo
c<c<o`000004ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`2>oooo
o`00a?ooool00oo^k^koA4A4o`000004ooooo`05ob4Q8OnHV9SoooooogMgMomEEED00oooool01Ol0
003o^[ZjoooooonHV9So410@093ooooo0035ooooo`03ogMgMol0003ooooo00?ooooo00Goc<c<oa0@
4?l0003o<S8bonk^kP03ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0T?ooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(498) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.62121 .33982 Mdot
.63209 .35235 Mdot
.34142 .56221 Mdot
.59747 .55514 Mdot
.38972 .71321 Mdot
.29479 .54918 Mdot
.34602 .36619 Mdot
.35859 .38183 Mdot
.30831 .54471 Mdot
.69946 .48784 Mdot
.36941 .34754 Mdot
.55703 .53015 Mdot
.35949 .35991 Mdot
.59434 .59843 Mdot
.52743 .40584 Mdot
.67261 .6239 Mdot
.61594 .41328 Mdot
.41262 .64978 Mdot
.6724 .63489 Mdot
.33361 .54581 Mdot
.61926 .69988 Mdot
.58387 .59469 Mdot
.6404 .40311 Mdot
.59164 .59873 Mdot
.6283 .59588 Mdot
.62547 .3629 Mdot
.6277 .33889 Mdot
.63612 .60984 Mdot
.63403 .56687 Mdot
.37295 .35838 Mdot
.2348 .60888 Mdot
.83095 .40567 Mdot
.59826 .64703 Mdot
.79363 .45454 Mdot
.35566 .38244 Mdot
.29243 .35171 Mdot
.32529 .56988 Mdot
.33068 .36707 Mdot
.36961 .38474 Mdot
.36077 .38662 Mdot
.33741 .36429 Mdot
.61851 .36851 Mdot
.37563 .38985 Mdot
.22622 .51304 Mdot
.60916 .60457 Mdot
.60343 .30826 Mdot
.17005 .49488 Mdot
.6411 .59503 Mdot
.60048 .37344 Mdot
.32699 .53383 Mdot
.49877 .79816 Mdot
.33986 .3279 Mdot
.46396 .38899 Mdot
.45617 .90354 Mdot
.36415 .35055 Mdot
.60568 .55148 Mdot
.30023 .53348 Mdot
.58431 .56684 Mdot
.57819 .54719 Mdot
.78038 .41686 Mdot
.57038 .59134 Mdot
.40235 .68995 Mdot
.66874 .36877 Mdot
.26313 .58365 Mdot
.30125 .54307 Mdot
.33025 .35771 Mdot
.66221 .3737 Mdot
.36051 .37163 Mdot
.6433 .57548 Mdot
.33774 .54303 Mdot
.6351 .57215 Mdot
.37418 .35481 Mdot
.65731 .36428 Mdot
.61175 .60783 Mdot
.54289 .31908 Mdot
.37368 .30615 Mdot
.35227 .52891 Mdot
.8019 .56443 Mdot
.52502 .83029 Mdot
.35405 .61733 Mdot
.60096 .61597 Mdot
.40704 .84246 Mdot
.47661 .43082 Mdot
.63372 .34838 Mdot
.5957 .4289 Mdot
.57571 .21324 Mdot
.64208 .60421 Mdot
.39465 .56095 Mdot
.57245 .63417 Mdot
.47212 .58161 Mdot
.31744 .54617 Mdot
.64507 .36092 Mdot
.60911 .61132 Mdot
.59458 .63669 Mdot
.6813 .41775 Mdot
.60927 .5391 Mdot
.60627 .56985 Mdot
.62248 .4395 Mdot
.36212 .33768 Mdot
.56686 .50098 Mdot
.38436 .74726 Mdot
.49016 .39354 Mdot
.61479 .56302 Mdot
.3041 .57076 Mdot
.67078 .36382 Mdot
.61046 .57856 Mdot
.35751 .3772 Mdot
.59283 .61028 Mdot
.39394 .34485 Mdot
.62199 .41047 Mdot
.58478 .63744 Mdot
.43379 .66792 Mdot
.51473 .51383 Mdot
.62073 .39987 Mdot
.75088 .61902 Mdot
.57368 .59611 Mdot
.57173 .57876 Mdot
.62549 .35086 Mdot
.33621 .5653 Mdot
.36181 .50518 Mdot
.65131 .39114 Mdot
.36627 .38704 Mdot
.60179 .39436 Mdot
.5477 .56507 Mdot
.33674 .56126 Mdot
.47378 .38911 Mdot
.48323 .39524 Mdot
.4712 .72442 Mdot
.61132 .61628 Mdot
.53794 .49784 Mdot
.2971 .56317 Mdot
.61831 .36089 Mdot
.3661 .36664 Mdot
.57965 .53698 Mdot
.61969 .39021 Mdot
.37975 .38042 Mdot
.38994 .69077 Mdot
.38186 .70947 Mdot
.60558 .37668 Mdot
.70282 .63399 Mdot
.35724 .31975 Mdot
.35325 .38685 Mdot
.49708 .79519 Mdot
.63032 .34708 Mdot
.42059 .69236 Mdot
.3869 .36877 Mdot
.56326 .73107 Mdot
.56249 .56734 Mdot
.46689 .76126 Mdot
.3201 .79204 Mdot
.49779 .7973 Mdot
.82011 .42975 Mdot
.43409 .67752 Mdot
.38689 .37334 Mdot
.6347 .57729 Mdot
.62678 .38278 Mdot
.61701 .38153 Mdot
.59907 .63427 Mdot
.62131 .60551 Mdot
.60381 .5933 Mdot
.5709 .5491 Mdot
.26344 .337 Mdot
.60528 .61348 Mdot
.38362 .25545 Mdot
.62611 .39226 Mdot
.62083 .59353 Mdot
.29861 .57882 Mdot
.59791 .50927 Mdot
.33651 .37363 Mdot
.58142 .54692 Mdot
.62517 .60496 Mdot
.57384 .53041 Mdot
.38245 .38418 Mdot
.5296 .29817 Mdot
.6034 .81678 Mdot
.29264 .33176 Mdot
.43733 .3421 Mdot
.28474 .5572 Mdot
.57751 .61586 Mdot
.42555 .67429 Mdot
.57875 .50249 Mdot
.56953 .56252 Mdot
.49999 .80212 Mdot
.62267 .61964 Mdot
.82382 .48742 Mdot
.54018 .54109 Mdot
.55925 .20604 Mdot
.40864 .2337 Mdot
.56695 .56356 Mdot
.71487 .53291 Mdot
.46169 .75239 Mdot
.21607 .61096 Mdot
.37024 .36197 Mdot
.28843 .58145 Mdot
.33103 .57364 Mdot
.33444 .37814 Mdot
.55186 .65172 Mdot
.71104 .4981 Mdot
.61798 .54311 Mdot
.47791 .39 Mdot
.5873 .34236 Mdot
.43076 .68911 Mdot
.60499 .37453 Mdot
.43778 .85032 Mdot
.40953 .60357 Mdot
.36364 .59331 Mdot
.38979 .6656 Mdot
.30551 .52575 Mdot
.47443 .37734 Mdot
.42524 .68593 Mdot
.59734 .56288 Mdot
.61171 .4037 Mdot
.4568 .75875 Mdot
.6539 .56031 Mdot
.43622 .13126 Mdot
.64893 .35044 Mdot
.49387 .51332 Mdot
.3655 .35582 Mdot
.27718 .58968 Mdot
.64179 .60442 Mdot
.59102 .57861 Mdot
.66285 .35329 Mdot
.64079 .58376 Mdot
.4103 .54681 Mdot
.62577 .61093 Mdot
.25952 .57257 Mdot
.46065 .66763 Mdot
.40202 .35849 Mdot
.39104 .6582 Mdot
.65717 .37272 Mdot
.34551 .29511 Mdot
.30298 .57461 Mdot
.51132 .60877 Mdot
.37317 .37062 Mdot
.39227 .68329 Mdot
.31999 .56845 Mdot
.43504 .66229 Mdot
.57011 .62349 Mdot
.32924 .56281 Mdot
.40677 .69824 Mdot
.40877 .45768 Mdot
.60773 .56985 Mdot
.4965 .73723 Mdot
.37565 .33923 Mdot
.61552 .34539 Mdot
.56679 .57731 Mdot
.46247 .37932 Mdot
.55824 .54649 Mdot
.52978 .48034 Mdot
.47433 .36984 Mdot
.50389 .37693 Mdot
.36912 .59595 Mdot
.39996 .7078 Mdot
.53145 .34886 Mdot
.40203 .49726 Mdot
.61713 .41385 Mdot
.56653 .6161 Mdot
.60364 .26292 Mdot
.37844 .3412 Mdot
.59365 .56186 Mdot
.55362 .2217 Mdot
.38732 .36877 Mdot
.57848 .5683 Mdot
.33724 .35956 Mdot
.62075 .38443 Mdot
.44113 .43804 Mdot
.59684 .36928 Mdot
.59311 .55401 Mdot
.34483 .34484 Mdot
.29596 .58228 Mdot
.62565 .36368 Mdot
.58757 .60529 Mdot
.59902 .62108 Mdot
.48004 .38799 Mdot
.61565 .60246 Mdot
.62028 .24403 Mdot
.64038 .59689 Mdot
.32124 .52765 Mdot
.62309 .55159 Mdot
.43098 .77496 Mdot
.37443 .70115 Mdot
.64921 .40336 Mdot
.47904 .36867 Mdot
.31997 .54521 Mdot
.42963 .44288 Mdot
.48469 .69619 Mdot
.59884 .61082 Mdot
.49416 .38036 Mdot
.49307 .50763 Mdot
.33405 .36778 Mdot
.63072 .63639 Mdot
.38438 .52346 Mdot
.31975 .55351 Mdot
.47459 .38475 Mdot
.66019 .61419 Mdot
.62399 .33573 Mdot
.61292 .55451 Mdot
.32094 .57193 Mdot
.60697 .34935 Mdot
.59381 .53187 Mdot
.20074 .40915 Mdot
.46149 .38117 Mdot
.34701 .33759 Mdot
.66634 .42208 Mdot
.58861 .6278 Mdot
.32506 .5797 Mdot
.61504 .38623 Mdot
.35375 .34613 Mdot
.63128 .40367 Mdot
.44262 .75876 Mdot
.56374 .47829 Mdot
.2852 .39182 Mdot
.43004 .64749 Mdot
.84539 .57443 Mdot
.29429 .34708 Mdot
.54258 .50571 Mdot
.27099 .52031 Mdot
.49231 .16438 Mdot
.31435 .56926 Mdot
.70881 .5952 Mdot
.31159 .53796 Mdot
.62077 .56244 Mdot
.29711 .54703 Mdot
.63487 .2286 Mdot
.62867 .6206 Mdot
.28203 .54446 Mdot
.2694 .39338 Mdot
.62071 .62373 Mdot
.62217 .3944 Mdot
.74501 .30711 Mdot
.76341 .6211 Mdot
.69065 .67484 Mdot
.28908 .53532 Mdot
.71043 .62893 Mdot
.6379 .61049 Mdot
.67055 .63916 Mdot
.62888 .37696 Mdot
.55816 .53649 Mdot
.42743 .70424 Mdot
.43847 .67273 Mdot
.54464 .76803 Mdot
.77954 .63073 Mdot
.58506 .67166 Mdot
.62191 .3705 Mdot
.51023 .83103 Mdot
.54744 .31396 Mdot
.46112 .38346 Mdot
.3693 .38244 Mdot
.52028 .30675 Mdot
.6587 .63042 Mdot
.62661 .46655 Mdot
.41896 .52462 Mdot
.64765 .36161 Mdot
.35051 .43931 Mdot
.34894 .35034 Mdot
.71825 .66281 Mdot
.7151 .46581 Mdot
.60413 .58973 Mdot
.35097 .32877 Mdot
.53738 .56061 Mdot
.40891 .52928 Mdot
.48486 .74378 Mdot
.20418 .4817 Mdot
.59937 .56066 Mdot
.54182 .34488 Mdot
.57054 .56345 Mdot
.47354 .73821 Mdot
.59052 .55767 Mdot
.63204 .40105 Mdot
.61561 .6608 Mdot
.39879 .48471 Mdot
.71829 .70398 Mdot
.41096 .59683 Mdot
.41665 .70328 Mdot
.59341 .59436 Mdot
.59846 .57864 Mdot
.4009 .69321 Mdot
.64641 .36591 Mdot
.56442 .60723 Mdot
.16766 .47888 Mdot
.6059 .61478 Mdot
.33311 .33603 Mdot
.45051 .47436 Mdot
.83473 .51375 Mdot
.62134 .62911 Mdot
.63174 .33505 Mdot
.33936 .3716 Mdot
.37971 .372 Mdot
.60669 .66729 Mdot
.36735 .33272 Mdot
.63637 .57815 Mdot
.45149 .47317 Mdot
.63352 .40827 Mdot
.55376 .52538 Mdot
.64773 .37133 Mdot
.48631 .82241 Mdot
.38985 .36386 Mdot
.49577 .37611 Mdot
.70915 .65988 Mdot
.34857 .36282 Mdot
.4732 .63992 Mdot
.61123 .66002 Mdot
.65668 .57377 Mdot
.66582 .41932 Mdot
.30001 .58393 Mdot
.48795 .37291 Mdot
.36133 .34774 Mdot
.60597 .61082 Mdot
.61443 .57363 Mdot
.34919 .32617 Mdot
.74822 .38326 Mdot
.23286 .60647 Mdot
.59062 .5518 Mdot
.63939 .39669 Mdot
.61831 .36289 Mdot
.56439 .55298 Mdot
.56825 .57105 Mdot
.27451 .55738 Mdot
.49447 .37934 Mdot
.48604 .36994 Mdot
.49871 .39344 Mdot
.26216 .56274 Mdot
.82672 .60591 Mdot
.35309 .38692 Mdot
.8333 .43701 Mdot
.54678 .25444 Mdot
.62219 .66595 Mdot
.32115 .57777 Mdot
.58282 .57842 Mdot
.62042 .56922 Mdot
.34952 .34088 Mdot
.7695 .66668 Mdot
.58692 .64854 Mdot
.62607 .34103 Mdot
.34013 .32905 Mdot
.55116 .53759 Mdot
.3124 .33419 Mdot
.41579 .66085 Mdot
.65816 .68097 Mdot
.35807 .32746 Mdot
.6243 .40782 Mdot
.35625 .32678 Mdot
.60046 .58298 Mdot
.66255 .60557 Mdot
.64821 .36049 Mdot
.3841 .6881 Mdot
.58624 .63131 Mdot
.57741 .56707 Mdot
.22821 .67187 Mdot
.54352 .32176 Mdot
.38678 .72906 Mdot
.6312 .58361 Mdot
.63707 .54359 Mdot
.39148 .6706 Mdot
.57601 .62214 Mdot
.625 .55673 Mdot
.51361 .51065 Mdot
.39255 .33965 Mdot
.40494 .71254 Mdot
.7118 .70471 Mdot
.64628 .34755 Mdot
.60743 .24062 Mdot
.48106 .39332 Mdot
.38919 .39618 Mdot
.44316 .42918 Mdot
.48135 .37752 Mdot
.53734 .23294 Mdot
.29661 .29297 Mdot
.49005 .37597 Mdot
.26944 .58937 Mdot
.67315 .512 Mdot
.62847 .55894 Mdot
.57885 .55285 Mdot
.40026 .7071 Mdot
.61704 .35106 Mdot
.39337 .25247 Mdot
.39624 .3375 Mdot
.57807 .59106 Mdot
.60385 .34482 Mdot
.56738 .209 Mdot
.47589 .38204 Mdot
.42684 .66958 Mdot
.38425 .6974 Mdot
.57061 .56778 Mdot
.48438 .61693 Mdot
.62192 .36733 Mdot
.58754 .60515 Mdot
.56669 .59347 Mdot
.31904 .53781 Mdot
.60862 .3995 Mdot
.29441 .5769 Mdot
.48481 .36628 Mdot
.45421 .15495 Mdot
.19409 .62413 Mdot
.38186 .34798 Mdot
.38188 .41988 Mdot
.39204 .38399 Mdot
.20767 .44177 Mdot
.49425 .37776 Mdot
.5854 .60033 Mdot
.6559 .38581 Mdot
.59088 .60912 Mdot
.60736 .61381 Mdot
.60679 .58483 Mdot
.58549 .67199 Mdot
.48433 .81598 Mdot
.41035 .67156 Mdot
.64763 .61242 Mdot
.27523 .54164 Mdot
.55649 .21083 Mdot
.68097 .27416 Mdot
.59458 .58782 Mdot
.57248 .57734 Mdot
.66169 .36215 Mdot
.56701 .62103 Mdot
.35529 .37823 Mdot
.6395 .34718 Mdot
.61254 .56464 Mdot
.38843 .75293 Mdot
.56396 .6015 Mdot
.35722 .42012 Mdot
.36103 .3268 Mdot
.66896 .56466 Mdot
.65414 .57762 Mdot
.49423 .37646 Mdot
.48751 .37331 Mdot
.4623 .37397 Mdot
.33663 .33619 Mdot
.32016 .53974 Mdot
.30918 .59862 Mdot
.6562 .59886 Mdot
.6372 .58506 Mdot
.66192 .59546 Mdot
.28719 .52355 Mdot
.39301 .49398 Mdot
.55881 .38067 Mdot
.53546 .55638 Mdot
.26546 .55894 Mdot
.63437 .44027 Mdot
.73253 .66962 Mdot
.6325 .34403 Mdot
.27805 .51878 Mdot
.36831 .37744 Mdot
.43597 .67701 Mdot
.5368 .79886 Mdot
.64641 .39655 Mdot
.65655 .34744 Mdot
.28187 .55244 Mdot
.48647 .46385 Mdot
.52524 .91785 Mdot
.30358 .5665 Mdot
.37721 .58341 Mdot
.62716 .37373 Mdot
.589 .64622 Mdot
.49349 .501 Mdot
.50611 .46282 Mdot
.28795 .54156 Mdot
.59839 .62043 Mdot
.45182 .62431 Mdot
.27467 .55665 Mdot
.62259 .64537 Mdot
.28669 .53614 Mdot
.35171 .33315 Mdot
.2939 .56569 Mdot
.58841 .37912 Mdot
.60848 .61862 Mdot
.4766 .90993 Mdot
.46873 .42417 Mdot
.58303 .60727 Mdot
.34665 .32487 Mdot
.24662 .38452 Mdot
.60098 .57539 Mdot
.42697 .7019 Mdot
.26659 .54864 Mdot
.19791 .47025 Mdot
.61891 .55269 Mdot
.29011 .54607 Mdot
.58726 .39346 Mdot
.26616 .52643 Mdot
.37479 .73145 Mdot
.48673 .37116 Mdot
.62304 .38629 Mdot
.5099 .39663 Mdot
.34767 .38119 Mdot
.55539 .57254 Mdot
.56811 .60194 Mdot
.63203 .39438 Mdot
.41902 .44636 Mdot
.57953 .65867 Mdot
.60121 .61525 Mdot
.2775 .5646 Mdot
.28436 .52906 Mdot
.5359 .39302 Mdot
.30815 .57505 Mdot
.6348 .54119 Mdot
.63021 .39709 Mdot
.61133 .55666 Mdot
.61402 .38999 Mdot
.56907 .6199 Mdot
.4668 .34886 Mdot
.62646 .34463 Mdot
.50824 .57806 Mdot
.61311 .61808 Mdot
.67871 .31657 Mdot
.59257 .6291 Mdot
.60305 .56568 Mdot
.27123 .53751 Mdot
.41334 .68024 Mdot
.61139 .64474 Mdot
.33778 .29692 Mdot
.40201 .66183 Mdot
.78364 .38796 Mdot
.33617 .56205 Mdot
.38721 .69217 Mdot
.53382 .75181 Mdot
.47881 .36884 Mdot
.40165 .68341 Mdot
.48665 .36036 Mdot
.37531 .34084 Mdot
.60421 .40613 Mdot
.61737 .62349 Mdot
.49536 .1583 Mdot
.23707 .6103 Mdot
.48519 .3875 Mdot
.5676 .57991 Mdot
.58539 .57435 Mdot
.61463 .33998 Mdot
.4279 .84718 Mdot
.25519 .57178 Mdot
.60389 .56117 Mdot
.65405 .38243 Mdot
.3733 .82397 Mdot
.2794 .54541 Mdot
.40732 .67037 Mdot
.39166 .35058 Mdot
.61058 .32456 Mdot
.4931 .3722 Mdot
.38981 .36567 Mdot
.34581 .52623 Mdot
.50202 .80529 Mdot
.61452 .55 Mdot
.3106 .58003 Mdot
.49782 .79787 Mdot
.54282 .53523 Mdot
.3463 .39126 Mdot
.47754 .35071 Mdot
.64335 .35889 Mdot
.34714 .32624 Mdot
.40846 .70805 Mdot
.61756 .41237 Mdot
.64794 .36742 Mdot
.36495 .38097 Mdot
.41101 .2162 Mdot
.49627 .50359 Mdot
.32671 .35588 Mdot
.51506 .4819 Mdot
.49507 .79545 Mdot
.49832 .38378 Mdot
.42831 .67078 Mdot
.38701 .76255 Mdot
.62036 .3663 Mdot
.52157 .30548 Mdot
.50016 .79991 Mdot
.60616 .56937 Mdot
.41066 .70038 Mdot
.57243 .22265 Mdot
.40048 .38463 Mdot
.38235 .37776 Mdot
.36072 .51589 Mdot
.42645 .69686 Mdot
.56141 .58432 Mdot
.83255 .5387 Mdot
.61231 .62829 Mdot
.38851 .36272 Mdot
.41639 .53441 Mdot
.60984 .39985 Mdot
.34009 .37878 Mdot
.40875 .54954 Mdot
.62253 .57013 Mdot
.57589 .6039 Mdot
.44848 .64591 Mdot
.60346 .39323 Mdot
.49822 .3738 Mdot
.59535 .61633 Mdot
.58282 .56507 Mdot
.55743 .56414 Mdot
.69824 .69781 Mdot
.50091 .57664 Mdot
.60821 .56406 Mdot
.28517 .58938 Mdot
.63199 .53263 Mdot
.5725 .54894 Mdot
.61566 .33739 Mdot
.42708 .78205 Mdot
.48512 .36606 Mdot
.58024 .55328 Mdot
.58979 .55169 Mdot
.36492 .38513 Mdot
.49482 .5049 Mdot
.50823 .46069 Mdot
.31407 .52706 Mdot
.36446 .52989 Mdot
.62048 .54108 Mdot
.62874 .38841 Mdot
.42601 .70674 Mdot
.5976 .51445 Mdot
.63658 .34305 Mdot
.65132 .61058 Mdot
.27885 .53736 Mdot
.49139 .37953 Mdot
.52708 .57766 Mdot
.40526 .6886 Mdot
.36908 .32193 Mdot
.81639 .40737 Mdot
.28705 .57913 Mdot
.63355 .59887 Mdot
.31968 .59724 Mdot
.31099 .55779 Mdot
.48404 .38944 Mdot
.66458 .58784 Mdot
.61955 .38039 Mdot
.61718 .40439 Mdot
.47226 .80193 Mdot
.26101 .5697 Mdot
.26076 .72134 Mdot
.35549 .33212 Mdot
.63668 .62553 Mdot
.61066 .29012 Mdot
.61261 .40103 Mdot
.47222 .72923 Mdot
.38633 .69027 Mdot
.38265 .3769 Mdot
.51141 .37895 Mdot
.6247 .34375 Mdot
.60933 .39337 Mdot
.60888 .61022 Mdot
.58761 .58882 Mdot
.30133 .50963 Mdot
.4654 .7547 Mdot
.33769 .36036 Mdot
.41405 .6652 Mdot
.32914 .53253 Mdot
.62764 .57287 Mdot
.63848 .35249 Mdot
.83059 .52861 Mdot
.58708 .62676 Mdot
.27729 .54032 Mdot
.63489 .35567 Mdot
.39912 .67736 Mdot
.39521 .69797 Mdot
.60486 .56835 Mdot
.81991 .51138 Mdot
.35001 .36575 Mdot
.62444 .39727 Mdot
.61254 .43282 Mdot
.64849 .59666 Mdot
.59228 .59017 Mdot
.54267 .60111 Mdot
.34568 .3877 Mdot
.53224 .55325 Mdot
.40486 .65577 Mdot
.61104 .36893 Mdot
.58854 .61112 Mdot
.40196 .68952 Mdot
.62468 .46565 Mdot
.48464 .37981 Mdot
.27973 .54689 Mdot
.42903 .69927 Mdot
.41598 .68923 Mdot
.3991 .66593 Mdot
.52112 .30856 Mdot
.67205 .36752 Mdot
.67038 .76514 Mdot
.60561 .62093 Mdot
.494 .79454 Mdot
.55941 .61371 Mdot
.33777 .34436 Mdot
.2837 .58139 Mdot
.60714 .60343 Mdot
.60591 .62121 Mdot
.82276 .46561 Mdot
.67427 .62382 Mdot
.67647 .62228 Mdot
.61806 .40804 Mdot
.68942 .35771 Mdot
.32224 .58028 Mdot
.28534 .76879 Mdot
.7545 .29492 Mdot
.61467 .53915 Mdot
.48154 .46475 Mdot
.63798 .34745 Mdot
.37961 .38276 Mdot
.50725 .48601 Mdot
.30791 .36908 Mdot
.61419 .35853 Mdot
.62258 .56557 Mdot
.81455 .41289 Mdot
.42713 .65571 Mdot
.60258 .5913 Mdot
.36642 .36928 Mdot
.60319 .59223 Mdot
.33464 .34282 Mdot
.64295 .30843 Mdot
.4995 .44987 Mdot
.62375 .62052 Mdot
.61504 .54401 Mdot
.57297 .49219 Mdot
.5922 .58756 Mdot
.22463 .4639 Mdot
.63779 .36618 Mdot
.50851 .60039 Mdot
.56964 .54074 Mdot
.79265 .53907 Mdot
.56623 .6024 Mdot
.43236 .42022 Mdot
.57274 .60666 Mdot
.66904 .71074 Mdot
.56132 .57814 Mdot
.57688 .61442 Mdot
.34752 .34775 Mdot
.36897 .38647 Mdot
.58393 .38962 Mdot
.50163 .37746 Mdot
.55833 .20711 Mdot
.57468 .57203 Mdot
.28091 .52879 Mdot
.55844 .42659 Mdot
.41649 .68389 Mdot
.61303 .3653 Mdot
.16036 .64173 Mdot
.33579 .36613 Mdot
.26631 .58591 Mdot
.34382 .60571 Mdot
.30632 .59219 Mdot
.31426 .51755 Mdot
.6833 .32334 Mdot
.42708 .66707 Mdot
.56331 .59338 Mdot
.79967 .46632 Mdot
.54666 .33243 Mdot
.64699 .59406 Mdot
.27145 .59902 Mdot
.6435 .50113 Mdot
.48571 .80755 Mdot
.43882 .66501 Mdot
.43261 .68153 Mdot
.35602 .34735 Mdot
.34 .56413 Mdot
.53398 .5703 Mdot
.38742 .69174 Mdot
.28245 .57966 Mdot
.48051 .39627 Mdot
.37631 .63487 Mdot
.61907 .37053 Mdot
.69881 .64203 Mdot
.60707 .30087 Mdot
.33624 .36459 Mdot
.35081 .29839 Mdot
.66288 .41011 Mdot
.63203 .41951 Mdot
.50306 .3846 Mdot
.27255 .54788 Mdot
.60814 .41171 Mdot
.60859 .6172 Mdot
.65407 .56071 Mdot
.56988 .56898 Mdot
.3964 .70431 Mdot
.56599 .58724 Mdot
.27148 .56102 Mdot
.34421 .36834 Mdot
.3194 .54836 Mdot
.34486 .36286 Mdot
.78184 .35959 Mdot
.57391 .55052 Mdot
.59095 .59265 Mdot
.45633 .46977 Mdot
.6065 .38501 Mdot
.78859 .45357 Mdot
.27388 .54284 Mdot
.30597 .53431 Mdot
.61074 .55746 Mdot
.65576 .39649 Mdot
.47201 .66668 Mdot
.48865 .48522 Mdot
.57025 .60218 Mdot
.63838 .36693 Mdot
.60846 .55413 Mdot
.21433 .41893 Mdot
.50255 .43626 Mdot
.62849 .4039 Mdot
.71967 .7038 Mdot
.6142 .60675 Mdot
.66295 .56611 Mdot
.64838 .52731 Mdot
.63232 .70516 Mdot
.60591 .6528 Mdot
.6485 .35115 Mdot
.5815 .54538 Mdot
.63214 .38395 Mdot
.3132 .5631 Mdot
.35378 .38829 Mdot
.63052 .38139 Mdot
.61169 .62652 Mdot
.76065 .3069 Mdot
.34641 .37343 Mdot
.60148 .60025 Mdot
.36471 .34545 Mdot
.59791 .39407 Mdot
.60221 .37374 Mdot
.50795 .36552 Mdot
.37055 .58853 Mdot
.35327 .3757 Mdot
.63797 .58546 Mdot
.53588 .30766 Mdot
.61202 .55664 Mdot
.36601 .53406 Mdot
.58119 .53065 Mdot
.63625 .56549 Mdot
.85187 .56304 Mdot
.42778 .43892 Mdot
.21839 .69832 Mdot
.4016 .33674 Mdot
.53379 .29918 Mdot
.5839 .40301 Mdot
.43889 .66587 Mdot
.38415 .42792 Mdot
.46876 .37402 Mdot
.29392 .59057 Mdot
.6072 .60781 Mdot
.68153 .2959 Mdot
.32846 .34536 Mdot
.41529 .6762 Mdot
.62315 .61961 Mdot
.3424 .56984 Mdot
.46794 .40729 Mdot
.3862 .37347 Mdot
.6174 .36965 Mdot
.60448 .37272 Mdot
.54324 .83104 Mdot
.58499 .60766 Mdot
.58527 .59248 Mdot
.35151 .37965 Mdot
.53832 .61038 Mdot
.40375 .66373 Mdot
.2778 .40452 Mdot
.36937 .36773 Mdot
.49599 .4357 Mdot
.61721 .40936 Mdot
.58446 .57607 Mdot
.45009 .47578 Mdot
.48093 .2847 Mdot
.67772 .44573 Mdot
.42089 .69592 Mdot
.48439 .65824 Mdot
.64874 .35116 Mdot
.36762 .36485 Mdot
.53751 .76251 Mdot
.56434 .62567 Mdot
.58523 .57172 Mdot
.50023 .67289 Mdot
.49273 .48481 Mdot
.38457 .57486 Mdot
.54481 .59832 Mdot
.48038 .52722 Mdot
.6117 .55849 Mdot
.61473 .57351 Mdot
.64114 .57098 Mdot
.5876 .5349 Mdot
.63895 .37155 Mdot
.7701 .60681 Mdot
.29371 .55433 Mdot
.68777 .49957 Mdot
.33821 .50563 Mdot
.63712 .61432 Mdot
.62201 .56698 Mdot
.74578 .5639 Mdot
.55029 .47101 Mdot
.6322 .3662 Mdot
.61654 .43341 Mdot
.35285 .38605 Mdot
.67422 .63015 Mdot
.26106 .56175 Mdot
.66245 .5391 Mdot
.30865 .5488 Mdot
.63988 .36753 Mdot
.32825 .54846 Mdot
.33681 .32164 Mdot
.31093 .57978 Mdot
.26474 .57369 Mdot
.39225 .36469 Mdot
.59943 .3772 Mdot
.57763 .61773 Mdot
.39096 .35565 Mdot
.47234 .66048 Mdot
.39627 .70389 Mdot
.50679 .36341 Mdot
.58778 .64624 Mdot
.67355 .60567 Mdot
.19788 .41357 Mdot
.33126 .55967 Mdot
.52623 .462 Mdot
.62501 .34502 Mdot
.4188 .7095 Mdot
.63792 .37595 Mdot
.60109 .79596 Mdot
.40911 .6936 Mdot
.50374 .36205 Mdot
.52036 .76308 Mdot
.31079 .31205 Mdot
.56869 .52933 Mdot
.66437 .42212 Mdot
.31185 .54992 Mdot
.33453 .33411 Mdot
.56594 .21882 Mdot
.61374 .59505 Mdot
.47441 .39841 Mdot
.63391 .42295 Mdot
.48024 .36912 Mdot
.36475 .36765 Mdot
.4199 .39319 Mdot
.58001 .6028 Mdot
.31938 .30912 Mdot
.60374 .53514 Mdot
.70954 .65095 Mdot
.34862 .51792 Mdot
.61691 .4545 Mdot
.61698 .55595 Mdot
.27591 .54758 Mdot
.61478 .55587 Mdot
.69799 .56045 Mdot
.50693 .78088 Mdot
.60843 .53002 Mdot
.5907 .46947 Mdot
.19252 .45162 Mdot
.64086 .35526 Mdot
.63572 .54398 Mdot
.49386 .38686 Mdot
.62671 .58636 Mdot
.55627 .14043 Mdot
.4035 .68379 Mdot
.38707 .72611 Mdot
.61091 .62542 Mdot
.59429 .61318 Mdot
.81938 .49027 Mdot
.68278 .34917 Mdot
.5111 .37746 Mdot
.58971 .56834 Mdot
.52208 .68293 Mdot
.35249 .34493 Mdot
.59044 .5314 Mdot
.57761 .55122 Mdot
.2261 .65309 Mdot
.35554 .34241 Mdot
.33011 .5688 Mdot
.47654 .36937 Mdot
.30499 .5271 Mdot
.40111 .72179 Mdot
.48886 .54659 Mdot
.47912 .72368 Mdot
.50821 .43115 Mdot
.4225 .70306 Mdot
.63798 .61625 Mdot
.59785 .43679 Mdot
.5861 .61541 Mdot
.43082 .68242 Mdot
.37292 .35795 Mdot
.63589 .37186 Mdot
.70162 .63573 Mdot
.48019 .3907 Mdot
.64342 .61637 Mdot
.44025 .66186 Mdot
.62576 .38143 Mdot
.41848 .27886 Mdot
.62209 .34874 Mdot
.34638 .35828 Mdot
.33322 .3759 Mdot
.41187 .68753 Mdot
.63934 .37392 Mdot
.31012 .52931 Mdot
.40929 .34651 Mdot
.58822 .52631 Mdot
.33231 .32255 Mdot
.60864 .41644 Mdot
.6329 .33827 Mdot
.65185 .39696 Mdot
.58528 .53875 Mdot
.49134 .477 Mdot
.55366 .60698 Mdot
.34801 .37593 Mdot
.32154 .58547 Mdot
.47129 .76166 Mdot
.80795 .48946 Mdot
.48942 .43818 Mdot
.61024 .6468 Mdot
.56653 .58434 Mdot
.5706 .56866 Mdot
.59823 .54848 Mdot
.28132 .40494 Mdot
.57429 .5503 Mdot
.34256 .34799 Mdot
.30507 .55468 Mdot
.57002 .58991 Mdot
.4945 .38399 Mdot
.39571 .49739 Mdot
.42372 .7092 Mdot
.68066 .67473 Mdot
.64769 .27049 Mdot
.6272 .37984 Mdot
.31323 .57572 Mdot
.32644 .54408 Mdot
.38999 .69062 Mdot
.39001 .35773 Mdot
.61485 .35387 Mdot
.65089 .71342 Mdot
.41289 .65544 Mdot
.58068 .55354 Mdot
.45317 .47197 Mdot
.72726 .68447 Mdot
.62479 .63264 Mdot
.60453 .57515 Mdot
.49734 .37165 Mdot
.26965 .58697 Mdot
.56546 .16976 Mdot
.40594 .22668 Mdot
.41256 .68209 Mdot
.40528 .66772 Mdot
.66017 .3772 Mdot
.63791 .62496 Mdot
.35178 .3684 Mdot
.48747 .5194 Mdot
.20864 .3932 Mdot
.59825 .22638 Mdot
.20762 .445 Mdot
.56443 .60343 Mdot
.77168 .57444 Mdot
.57582 .53018 Mdot
.67091 .36399 Mdot
.65623 .39274 Mdot
.62631 .3682 Mdot
.34804 .34944 Mdot
.5047 .80796 Mdot
.3423 .34664 Mdot
.65615 .26934 Mdot
.65366 .36645 Mdot
.41243 .46612 Mdot
.29901 .53307 Mdot
.66572 .63948 Mdot
.42873 .66901 Mdot
.46199 .70726 Mdot
.6451 .55628 Mdot
.48542 .62263 Mdot
.32141 .57753 Mdot
.60329 .35918 Mdot
.6128 .65888 Mdot
.5484 .20379 Mdot
.48595 .46124 Mdot
.17526 .48972 Mdot
.69181 .37728 Mdot
.40213 .69375 Mdot
.70598 .50722 Mdot
.41213 .65796 Mdot
.38411 .37486 Mdot
.61294 .60146 Mdot
.60002 .63256 Mdot
.59939 .55924 Mdot
.58998 .53833 Mdot
.36257 .34785 Mdot
.58442 .52416 Mdot
.43218 .77552 Mdot
.47355 .39194 Mdot
.38428 .4721 Mdot
.39528 .69339 Mdot
.34676 .33269 Mdot
.3087 .55703 Mdot
.50439 .38425 Mdot
.4243 .64457 Mdot
.56076 .55746 Mdot
.60093 .62491 Mdot
.47984 .3951 Mdot
.54203 .63271 Mdot
.65927 .6314 Mdot
.29205 .54982 Mdot
.40783 .51588 Mdot
.39372 .70824 Mdot
.43413 .67156 Mdot
.35132 .32743 Mdot
.63817 .37595 Mdot
.38895 .69966 Mdot
.34071 .56474 Mdot
.59957 .53511 Mdot
.61846 .54681 Mdot
.60692 .41607 Mdot
.49953 .8008 Mdot
.42732 .70725 Mdot
.54012 .53914 Mdot
.60947 .37964 Mdot
.63699 .42312 Mdot
.5911 .56931 Mdot
.56557 .52219 Mdot
.65854 .3467 Mdot
.39548 .67881 Mdot
.35501 .32971 Mdot
.43056 .45794 Mdot
.34021 .34574 Mdot
.61415 .38284 Mdot
.63948 .54081 Mdot
.60408 .3964 Mdot
.61581 .59904 Mdot
.27012 .78574 Mdot
.56584 .56447 Mdot
.54722 .66864 Mdot
.39985 .61557 Mdot
.28442 .53743 Mdot
.28014 .54123 Mdot
.49255 .38072 Mdot
.63789 .34431 Mdot
.5997 .51302 Mdot
.42257 .66338 Mdot
.53441 .30005 Mdot
.67875 .38262 Mdot
.26398 .56704 Mdot
.26267 .58025 Mdot
.37155 .35607 Mdot
.56536 .59774 Mdot
.58082 .57877 Mdot
.31498 .57898 Mdot
.25506 .38825 Mdot
.63733 .38381 Mdot
.58548 .59284 Mdot
.57905 .54041 Mdot
.29682 .55503 Mdot
.41912 .38188 Mdot
.63859 .42561 Mdot
.5811 .53837 Mdot
.49736 .76954 Mdot
.3325 .35046 Mdot
.63861 .60023 Mdot
.57547 .53137 Mdot
.41966 .68543 Mdot
.48341 .69556 Mdot
.49642 .79466 Mdot
.38105 .38616 Mdot
.49006 .37096 Mdot
.59291 .63317 Mdot
.28975 .53647 Mdot
.59174 .64949 Mdot
.30373 .26735 Mdot
.46892 .3874 Mdot
.57874 .59756 Mdot
.62471 .54457 Mdot
.61615 .3935 Mdot
.58529 .60281 Mdot
.46691 .35061 Mdot
.28232 .56834 Mdot
.57806 .59757 Mdot
.8182 .51491 Mdot
.37201 .3587 Mdot
.64823 .56101 Mdot
.43378 .689 Mdot
.39331 .56647 Mdot
.7493 .31659 Mdot
.29827 .52132 Mdot
.3984 .6998 Mdot
.56625 .58928 Mdot
.30771 .52586 Mdot
.39294 .35272 Mdot
.50288 .60749 Mdot
.6408 .61221 Mdot
.33846 .34951 Mdot
.34624 .37089 Mdot
.40944 .68503 Mdot
.20745 .70147 Mdot
.6233 .54419 Mdot
.59918 .59149 Mdot
.18541 .40813 Mdot
.64969 .33486 Mdot
.60311 .59914 Mdot
.56721 .60145 Mdot
.37483 .33854 Mdot
.59173 .78102 Mdot
.48481 .6517 Mdot
.26944 .39259 Mdot
.33426 .34553 Mdot
.25528 .58002 Mdot
.28437 .57437 Mdot
.39901 .69866 Mdot
.63335 .3541 Mdot
.40322 .71012 Mdot
.29062 .56209 Mdot
.60209 .56459 Mdot
.38226 .3592 Mdot
.7241 .38824 Mdot
.34888 .32332 Mdot
.34482 .55852 Mdot
.66689 .39183 Mdot
.6774 .27908 Mdot
.25565 .28776 Mdot
.60395 .3056 Mdot
.36608 .39286 Mdot
.41673 .68383 Mdot
.3943 .24128 Mdot
.56939 .59338 Mdot
.72004 .62925 Mdot
.60151 .59183 Mdot
.64356 .45263 Mdot
.2827 .58068 Mdot
.50101 .39405 Mdot
.61358 .59438 Mdot
.48483 .65793 Mdot
.38957 .37021 Mdot
.36209 .37716 Mdot
.58908 .54655 Mdot
.3466 .36047 Mdot
.57964 .58413 Mdot
.30265 .55764 Mdot
.21644 .70658 Mdot
.57781 .61246 Mdot
.62491 .52485 Mdot
.40119 .35517 Mdot
.50722 .36312 Mdot
.27927 .59864 Mdot
.77942 .57849 Mdot
.54817 .1972 Mdot
.35135 .36406 Mdot
.59975 .67793 Mdot
.32745 .56473 Mdot
.50399 .37692 Mdot
.25877 .5486 Mdot
.59606 .58061 Mdot
.56614 .60968 Mdot
.60478 .55759 Mdot
.56748 .58679 Mdot
.72705 .59035 Mdot
.66226 .63126 Mdot
.73419 .47372 Mdot
.60473 .62083 Mdot
.55265 .66988 Mdot
.34731 .34154 Mdot
.66041 .55678 Mdot
.38556 .58459 Mdot
.56182 .59946 Mdot
.68201 .3925 Mdot
.34918 .33252 Mdot
.59984 .27701 Mdot
.35919 .34494 Mdot
.31749 .54456 Mdot
.37411 .38192 Mdot
.61533 .60524 Mdot
.61971 .3625 Mdot
.29985 .57293 Mdot
.5583 .3788 Mdot
.30426 .5888 Mdot
.58293 .60705 Mdot
.29687 .33285 Mdot
.2973 .53064 Mdot
.67829 .60231 Mdot
.62037 .35983 Mdot
.54432 .70374 Mdot
.66433 .34636 Mdot
.59074 .60453 Mdot
.59657 .60598 Mdot
.50466 .39184 Mdot
.38643 .374 Mdot
.6296 .41194 Mdot
.24295 .6829 Mdot
.44296 .66838 Mdot
.63388 .3609 Mdot
.64502 .52699 Mdot
.47756 .46439 Mdot
.6218 .40063 Mdot
.57116 .70442 Mdot
.38852 .36433 Mdot
.65654 .36427 Mdot
.55584 .54787 Mdot
.68875 .50997 Mdot
.42881 .65961 Mdot
.29481 .52707 Mdot
.47904 .50783 Mdot
.28305 .57266 Mdot
.35222 .31798 Mdot
.2588 .56685 Mdot
.3504 .34261 Mdot
.57106 .43991 Mdot
.41367 .54053 Mdot
.33466 .32786 Mdot
.38523 .32649 Mdot
.28609 .55402 Mdot
.59456 .5486 Mdot
.39861 .48693 Mdot
.58629 .5079 Mdot
.66036 .58141 Mdot
.3346 .35538 Mdot
.65238 .35466 Mdot
.61127 .40792 Mdot
.51089 .59453 Mdot
.605 .38573 Mdot
.30648 .56926 Mdot
.52135 .42224 Mdot
.71198 .65811 Mdot
.37504 .3606 Mdot
.35983 .59527 Mdot
.61749 .55904 Mdot
.28215 .5476 Mdot
.31208 .56787 Mdot
.34386 .36467 Mdot
.68096 .48631 Mdot
.6594 .58436 Mdot
.62294 .33404 Mdot
.6545 .37876 Mdot
.62457 .40141 Mdot
.65864 .39035 Mdot
.51463 .81342 Mdot
.33488 .33366 Mdot
.64402 .34841 Mdot
.59909 .54318 Mdot
.58556 .6277 Mdot
.4763 .37345 Mdot
.39593 .68028 Mdot
.5538 .59763 Mdot
.59506 .51089 Mdot
.59038 .57031 Mdot
.2864 .53614 Mdot
.60504 .48669 Mdot
.47088 .38786 Mdot
.26152 .57457 Mdot
.26154 .56232 Mdot
.49366 .37525 Mdot
.57927 .44629 Mdot
.59876 .19322 Mdot
.60304 .56043 Mdot
.67417 .30217 Mdot
.28779 .53927 Mdot
.47726 .59281 Mdot
.53817 .64796 Mdot
.63733 .58044 Mdot
.37092 .47872 Mdot
.30494 .56258 Mdot
.5796 .38369 Mdot
.5947 .58484 Mdot
.50075 .38667 Mdot
.4351 .67092 Mdot
.60635 .50166 Mdot
.49884 .37233 Mdot
.64268 .36897 Mdot
.21653 .57598 Mdot
.60713 .34276 Mdot
.30127 .52943 Mdot
.63878 .54729 Mdot
.50558 .91707 Mdot
.31362 .55075 Mdot
.52132 .29627 Mdot
.41123 .54468 Mdot
.57774 .60947 Mdot
.29752 .57666 Mdot
.60889 .4209 Mdot
.33246 .35153 Mdot
.46505 .47654 Mdot
.63792 .35249 Mdot
.50415 .3856 Mdot
.48268 .37294 Mdot
.29452 .55387 Mdot
.64741 .39339 Mdot
.58394 .52676 Mdot
.60666 .36845 Mdot
.37871 .36924 Mdot
.62492 .60367 Mdot
.55812 .20663 Mdot
.66378 .58304 Mdot
.60793 .36903 Mdot
.33733 .57484 Mdot
.3865 .68026 Mdot
.62576 .62317 Mdot
.5973 .2563 Mdot
.56574 .59668 Mdot
.36788 .34857 Mdot
.44855 .58094 Mdot
.72376 .39709 Mdot
.58986 .5562 Mdot
.61913 .56237 Mdot
.36875 .32888 Mdot
.59227 .55845 Mdot
.63826 .57193 Mdot
.42967 .38563 Mdot
.61892 .39847 Mdot
.57213 .5839 Mdot
.27985 .57483 Mdot
.75072 .36481 Mdot
.61151 .60015 Mdot
.45492 .34662 Mdot
.52601 .68988 Mdot
.43379 .55773 Mdot
.60417 .51331 Mdot
.4714 .72758 Mdot
.59705 .60191 Mdot
.64088 .58355 Mdot
.59873 .55438 Mdot
.76782 .57857 Mdot
.28716 .55868 Mdot
.26706 .56306 Mdot
.43743 .67574 Mdot
.51205 .67684 Mdot
.41348 .69921 Mdot
.37067 .33092 Mdot
.355 .59915 Mdot
.4795 .39385 Mdot
.63661 .37854 Mdot
.61027 .597 Mdot
.29912 .58823 Mdot
.58712 .57661 Mdot
.62823 .58754 Mdot
.29999 .56719 Mdot
.31092 .56515 Mdot
.29096 .52167 Mdot
.42271 .65393 Mdot
.63039 .37167 Mdot
.60772 .57704 Mdot
.40225 .66143 Mdot
.56852 .54488 Mdot
.45847 .44094 Mdot
.63028 .36935 Mdot
.60648 .37183 Mdot
.60049 .39494 Mdot
.59896 .62776 Mdot
.61833 .6062 Mdot
.34196 .34686 Mdot
.60637 .41534 Mdot
.35932 .37963 Mdot
.29523 .57652 Mdot
.27844 .55167 Mdot
.59662 .58076 Mdot
.53287 .56361 Mdot
.39594 .68649 Mdot
.32569 .55036 Mdot
.46508 .37441 Mdot
.43662 .68372 Mdot
.56715 .57539 Mdot
.28846 .57507 Mdot
.42835 .70333 Mdot
.68623 .41396 Mdot
.52341 .18136 Mdot
.42273 .65211 Mdot
.58876 .54614 Mdot
.81299 .48079 Mdot
.49798 .77732 Mdot
.44357 .66052 Mdot
.36279 .34133 Mdot
.57366 .61515 Mdot
.25959 .34198 Mdot
.38721 .70381 Mdot
.50133 .7969 Mdot
.29516 .56807 Mdot
.55344 .50251 Mdot
.61989 .50035 Mdot
.71714 .65284 Mdot
.38334 .69774 Mdot
.61007 .36733 Mdot
.65372 .38931 Mdot
.58352 .55288 Mdot
.37804 .58176 Mdot
.34444 .32212 Mdot
.32683 .54436 Mdot
.27013 .57826 Mdot
.63311 .40552 Mdot
.50466 .43197 Mdot
.2818 .5752 Mdot
.64709 .61433 Mdot
.42723 .71385 Mdot
.67392 .63271 Mdot
.54398 .82659 Mdot
.73877 .3182 Mdot
.60919 .51602 Mdot
.39018 .67261 Mdot
.3926 .36655 Mdot
.34254 .35596 Mdot
.3479 .35251 Mdot
.27774 .55479 Mdot
.50113 .48896 Mdot
.27711 .58072 Mdot
.43644 .32604 Mdot
.40088 .68828 Mdot
.57293 .72471 Mdot
.56032 .54676 Mdot
.57867 .60986 Mdot
.61373 .54695 Mdot
.60636 .55875 Mdot
.59569 .60046 Mdot
.33656 .36413 Mdot
.3201 .53276 Mdot
.2067 .41462 Mdot
.63934 .39579 Mdot
.41217 .27549 Mdot
.3011 .53292 Mdot
.49056 .36766 Mdot
.41526 .67126 Mdot
.49217 .70603 Mdot
.43755 .70897 Mdot
.32332 .54363 Mdot
.63022 .63135 Mdot
.66039 .36329 Mdot
.69356 .70506 Mdot
.60123 .61544 Mdot
.32859 .55392 Mdot
.25138 .57266 Mdot
.68654 .48246 Mdot
.563 .63454 Mdot
.37643 .57914 Mdot
.48189 .467 Mdot
.41366 .65088 Mdot
.60619 .64483 Mdot
.48384 .58519 Mdot
.29119 .56029 Mdot
.3056 .54155 Mdot
.44065 .65561 Mdot
.65445 .50212 Mdot
.65019 .36369 Mdot
.49808 .3958 Mdot
.36272 .33827 Mdot
.59055 .62084 Mdot
.27835 .55898 Mdot
.57511 .37705 Mdot
.44545 .45902 Mdot
.3634 .353 Mdot
.26156 .57704 Mdot
.56713 .60507 Mdot
.58558 .55541 Mdot
.4062 .69531 Mdot
.24475 .63515 Mdot
.58676 .50797 Mdot
.53287 .29989 Mdot
.5142 .45416 Mdot
.40393 .55657 Mdot
.58478 .57199 Mdot
.60985 .40167 Mdot
.49447 .37756 Mdot
.42815 .672 Mdot
.56193 .56128 Mdot
.57352 .18486 Mdot
.59896 .35078 Mdot
.35308 .37458 Mdot
.49811 .37953 Mdot
.49613 .51072 Mdot
.56601 .59581 Mdot
.60119 .59126 Mdot
.58595 .53881 Mdot
.57473 .1815 Mdot
.27323 .57446 Mdot
.6373 .41086 Mdot
.41611 .70105 Mdot
.60573 .36581 Mdot
.26611 .54747 Mdot
.39865 .55452 Mdot
.57263 .5506 Mdot
.60502 .349 Mdot
.61338 .35757 Mdot
.37281 .35985 Mdot
.39062 .35443 Mdot
.31283 .5239 Mdot
.56756 .59108 Mdot
.48999 .39516 Mdot
.65018 .35563 Mdot
.33035 .54499 Mdot
.40653 .69451 Mdot
.31668 .34557 Mdot
.60445 .6216 Mdot
.29198 .55535 Mdot
.61296 .52172 Mdot
.6252 .39335 Mdot
.31665 .53795 Mdot
.50082 .37058 Mdot
.39787 .67652 Mdot
.57482 .62267 Mdot
.19245 .46469 Mdot
.50153 .38366 Mdot
.61203 .62788 Mdot
.73286 .31977 Mdot
.38136 .57868 Mdot
.5668 .36158 Mdot
.29533 .58254 Mdot
.49158 .39296 Mdot
.64756 .40393 Mdot
.70224 .52697 Mdot
.30364 .54411 Mdot
.81504 .4367 Mdot
.41524 .47207 Mdot
.60571 .5656 Mdot
.64268 .36047 Mdot
.45324 .65644 Mdot
.54125 .29034 Mdot
.48525 .76851 Mdot
.57983 .59062 Mdot
.28213 .57203 Mdot
.43512 .67353 Mdot
.3636 .37801 Mdot
.44737 .34948 Mdot
.58725 .81772 Mdot
.26494 .57826 Mdot
.60913 .5904 Mdot
.6535 .35734 Mdot
.34921 .3695 Mdot
.81755 .41845 Mdot
.34161 .56141 Mdot
.29381 .58064 Mdot
.62082 .55421 Mdot
.41972 .69797 Mdot
.263 .34151 Mdot
.26879 .56665 Mdot
.30939 .5273 Mdot
.44163 .3811 Mdot
.43725 .66663 Mdot
.59229 .54153 Mdot
.51086 .59583 Mdot
.58709 .53264 Mdot
.4598 .30201 Mdot
.49175 .3936 Mdot
.64019 .39386 Mdot
.60594 .60294 Mdot
.19269 .44793 Mdot
.30708 .5498 Mdot
.48564 .46692 Mdot
.40173 .39408 Mdot
.39075 .35581 Mdot
.28299 .56725 Mdot
.58887 .58261 Mdot
.32576 .36659 Mdot
.39728 .69216 Mdot
.58061 .53873 Mdot
.61708 .60193 Mdot
.61413 .42288 Mdot
.38146 .36131 Mdot
.74992 .35795 Mdot
.37446 .37709 Mdot
.35261 .32656 Mdot
.63602 .4239 Mdot
.58231 .55322 Mdot
.32021 .54398 Mdot
.3463 .56379 Mdot
.5968 .51927 Mdot
.47653 .5917 Mdot
.64809 .36197 Mdot
.3435 .52761 Mdot
.55079 .17155 Mdot
.61793 .54264 Mdot
.47224 .36961 Mdot
.63728 .44947 Mdot
.32921 .35299 Mdot
.60014 .56485 Mdot
.63169 .38575 Mdot
.32924 .53517 Mdot
.27615 .5673 Mdot
.56802 .63092 Mdot
.34279 .36451 Mdot
.42286 .70667 Mdot
.3148 .56818 Mdot
.44144 .44605 Mdot
.58046 .60081 Mdot
.48058 .40212 Mdot
.31784 .5674 Mdot
.76948 .32438 Mdot
.19547 .43442 Mdot
.632 .40357 Mdot
.63276 .5843 Mdot
.65657 .35044 Mdot
.41091 .7041 Mdot
.25684 .5585 Mdot
.33928 .35512 Mdot
.69788 .63278 Mdot
.21063 .63678 Mdot
.28187 .55281 Mdot
.63878 .37023 Mdot
.60752 .58659 Mdot
.56016 .65988 Mdot
.57196 .60542 Mdot
.59632 .77555 Mdot
.43614 .69971 Mdot
.35699 .31388 Mdot
.34944 .37779 Mdot
.62252 .56969 Mdot
.4031 .66324 Mdot
.34466 .54337 Mdot
.29855 .56649 Mdot
.2548 .74801 Mdot
.49985 .37231 Mdot
.27984 .51744 Mdot
.59933 .62728 Mdot
.33491 .55329 Mdot
.80707 .49159 Mdot
.35436 .38006 Mdot
.58998 .52962 Mdot
.29001 .59285 Mdot
.46149 .28219 Mdot
.47682 .46612 Mdot
.57932 .59607 Mdot
.53508 .59929 Mdot
.3605 .34298 Mdot
.39519 .24047 Mdot
.29823 .58371 Mdot
.57094 .54427 Mdot
.3527 .39809 Mdot
.55169 .42051 Mdot
.2462 .68095 Mdot
.62999 .37157 Mdot
.31357 .59317 Mdot
.35951 .33135 Mdot
.57066 .50126 Mdot
.3938 .68794 Mdot
.3378 .53993 Mdot
.30238 .59144 Mdot
.62832 .59997 Mdot
.55614 .60387 Mdot
.53948 .6053 Mdot
.64532 .36532 Mdot
.37574 .34029 Mdot
.62001 .57811 Mdot
.47203 .44007 Mdot
.60899 .5636 Mdot
.36685 .33374 Mdot
.40533 .89057 Mdot
.60436 .63637 Mdot
.59963 .62151 Mdot
.66232 .68126 Mdot
.62602 .41191 Mdot
.61265 .39271 Mdot
.49679 .44548 Mdot
.59546 .62905 Mdot
.4169 .45505 Mdot
.6315 .37383 Mdot
.63887 .35717 Mdot
.41539 .45789 Mdot
.62669 .60905 Mdot
.341 .40017 Mdot
.34805 .36748 Mdot
.39035 .35459 Mdot
.61516 .39216 Mdot
.66462 .64447 Mdot
.39403 .357 Mdot
.73032 .57991 Mdot
.31702 .53704 Mdot
.48418 .58489 Mdot
.60721 .36638 Mdot
.44648 .48043 Mdot
.3866 .37082 Mdot
.82764 .39254 Mdot
.69066 .69863 Mdot
.60016 .52678 Mdot
.58755 .55366 Mdot
.41775 .68935 Mdot
.60427 .66729 Mdot
.48776 .37043 Mdot
.34506 .3572 Mdot
.28767 .41159 Mdot
.62591 .36775 Mdot
.58422 .62276 Mdot
.46801 .75826 Mdot
.75209 .32592 Mdot
.50639 .59896 Mdot
.63323 .3532 Mdot
.62359 .36393 Mdot
.31945 .57971 Mdot
.32059 .53875 Mdot
.57761 .54771 Mdot
.34591 .34813 Mdot
.65656 .37437 Mdot
.38008 .34926 Mdot
.29164 .56185 Mdot
.31248 .5364 Mdot
.46713 .3811 Mdot
.65945 .60547 Mdot
.28592 .56594 Mdot
.42419 .34633 Mdot
.46992 .43951 Mdot
.616 .42166 Mdot
.24671 .32311 Mdot
.83433 .44186 Mdot
.67593 .6589 Mdot
.43476 .66981 Mdot
.56636 .43682 Mdot
.37444 .3865 Mdot
.62091 .56731 Mdot
.6011 .5803 Mdot
.4761 .38146 Mdot
.3811 .38442 Mdot
.42007 .67604 Mdot
.38505 .37657 Mdot
.4221 .66641 Mdot
.26863 .55705 Mdot
.61151 .60736 Mdot
.56375 .57699 Mdot
.35984 .37565 Mdot
.32822 .57036 Mdot
.29586 .53073 Mdot
.42155 .65828 Mdot
.49708 .68991 Mdot
.29489 .55547 Mdot
.60721 .3659 Mdot
.76274 .39671 Mdot
.48068 .37373 Mdot
.59444 .58558 Mdot
.47441 .73458 Mdot
.71648 .53106 Mdot
.6084 .56848 Mdot
.49942 .38087 Mdot
.21469 .71791 Mdot
.61243 .60446 Mdot
.38229 .82966 Mdot
.47424 .38967 Mdot
.60538 .39856 Mdot
.32446 .5667 Mdot
.50062 .37508 Mdot
.59985 .48781 Mdot
.34362 .51906 Mdot
.6227 .53326 Mdot
.6495 .36003 Mdot
.59953 .364 Mdot
.40825 .53018 Mdot
.45719 .30133 Mdot
.41926 .7002 Mdot
.40981 .67685 Mdot
.30096 .54552 Mdot
.39888 .32461 Mdot
.60397 .65724 Mdot
.41256 .67751 Mdot
.28722 .37495 Mdot
.61841 .55883 Mdot
.38965 .56972 Mdot
.39294 .47794 Mdot
.61792 .40601 Mdot
.66065 .55445 Mdot
.30472 .54713 Mdot
.63815 .36995 Mdot
.4036 .50038 Mdot
.59806 .53365 Mdot
.62882 .36841 Mdot
.38343 .34795 Mdot
.40585 .43448 Mdot
.60327 .37655 Mdot
.46123 .47341 Mdot
.35405 .36846 Mdot
.38197 .57719 Mdot
.5595 .74405 Mdot
.62947 .16336 Mdot
.34426 .35342 Mdot
.33005 .56214 Mdot
.28007 .55725 Mdot
.29919 .55556 Mdot
.64121 .3538 Mdot
.31342 .56087 Mdot
.64679 .38318 Mdot
.39781 .34384 Mdot
.48943 .69852 Mdot
.41016 .69012 Mdot
.35838 .65967 Mdot
.61314 .37244 Mdot
.44867 .3199 Mdot
.20028 .36733 Mdot
.59479 .54419 Mdot
.33611 .32769 Mdot
.402 .65951 Mdot
.53137 .45099 Mdot
.41982 .68652 Mdot
.32645 .56637 Mdot
.48534 .58345 Mdot
.57875 .58385 Mdot
.67669 .29561 Mdot
.43519 .67802 Mdot
.63559 .3527 Mdot
.6377 .61454 Mdot
.35229 .56412 Mdot
.40204 .70237 Mdot
.43087 .66409 Mdot
.5956 .59809 Mdot
.60126 .36508 Mdot
.3212 .54331 Mdot
.36702 .38798 Mdot
.45039 .66173 Mdot
.53747 .61209 Mdot
.59292 .55118 Mdot
.61826 .63585 Mdot
.49664 .46333 Mdot
.26133 .32443 Mdot
.35395 .3645 Mdot
.49191 .7871 Mdot
.27994 .54902 Mdot
.48744 .77178 Mdot
.54951 .31101 Mdot
.42288 .7236 Mdot
.4872 .39382 Mdot
.49303 .39372 Mdot
.58498 .59809 Mdot
.27739 .28477 Mdot
.52248 .65524 Mdot
.3789 .39856 Mdot
.48167 .37626 Mdot
.29877 .53001 Mdot
.5887 .39043 Mdot
.66458 .53562 Mdot
.55453 .56089 Mdot
.38241 .38494 Mdot
.29663 .56158 Mdot
.30486 .26531 Mdot
.40194 .68811 Mdot
.52538 .4501 Mdot
.56844 .58581 Mdot
.58796 .59244 Mdot
.36391 .36146 Mdot
.34146 .35016 Mdot
.45102 .38562 Mdot
.43926 .53641 Mdot
.57052 .21151 Mdot
.38085 .33122 Mdot
.30367 .2652 Mdot
.68738 .31184 Mdot
.61683 .38856 Mdot
.47591 .36892 Mdot
.38208 .3399 Mdot
.60418 .60088 Mdot
.60847 .40313 Mdot
.5067 .62931 Mdot
.57838 .38043 Mdot
.39053 .56984 Mdot
.43238 .45592 Mdot
.56714 .58282 Mdot
.66284 .37207 Mdot
.63606 .36876 Mdot
.66497 .36751 Mdot
.49137 .37518 Mdot
.58676 .56932 Mdot
.59626 .54792 Mdot
.61302 .60308 Mdot
.57248 .66339 Mdot
.58512 .60323 Mdot
.54963 .30661 Mdot
.47536 .43329 Mdot
.29181 .67537 Mdot
.60757 .6183 Mdot
.36872 .33293 Mdot
.61014 .6082 Mdot
.39707 .67002 Mdot
.58475 .63076 Mdot
.38938 .57204 Mdot
.35227 .35521 Mdot
.66709 .50618 Mdot
.36255 .56733 Mdot
.56684 .56665 Mdot
.42329 .70314 Mdot
.26316 .31424 Mdot
.47116 .7704 Mdot
.44046 .37888 Mdot
.60696 .36793 Mdot
.2937 .52495 Mdot
.32698 .34105 Mdot
.31573 .54117 Mdot
.58995 .52716 Mdot
.46456 .37877 Mdot
.83448 .59423 Mdot
.44368 .49175 Mdot
.60496 .60309 Mdot
.65827 .60858 Mdot
.6125 .40192 Mdot
.30973 .55141 Mdot
.63617 .3075 Mdot
.61543 .55084 Mdot
.39282 .70332 Mdot
.38736 .68322 Mdot
.38612 .52901 Mdot
.36724 .42878 Mdot
.70405 .67523 Mdot
.3618 .36122 Mdot
.27503 .56035 Mdot
.38437 .70053 Mdot
.66016 .42653 Mdot
.345 .3225 Mdot
.32908 .35431 Mdot
.38115 .35913 Mdot
.58268 .60984 Mdot
.46979 .37731 Mdot
.32386 .42197 Mdot
.50284 .37984 Mdot
.60168 .5407 Mdot
.29883 .59144 Mdot
.50392 .37805 Mdot
.41583 .69513 Mdot
.34826 .32788 Mdot
.29137 .53389 Mdot
.59484 .60711 Mdot
.62674 .37803 Mdot
.47409 .79836 Mdot
.16869 .50142 Mdot
.37513 .58411 Mdot
.37489 .5843 Mdot
.59575 .38085 Mdot
.61898 .25018 Mdot
.3348 .3189 Mdot
.68805 .49394 Mdot
.47071 .6737 Mdot
.59919 .51913 Mdot
.27653 .74085 Mdot
.28061 .58216 Mdot
.30185 .57269 Mdot
.57395 .59136 Mdot
.33785 .55383 Mdot
.57562 .6142 Mdot
.3051 .58325 Mdot
.51304 .2839 Mdot
.55595 .55357 Mdot
.30509 .57021 Mdot
.593 .65742 Mdot
.6239 .62398 Mdot
.60663 .39613 Mdot
.33649 .5398 Mdot
.60147 .52759 Mdot
.80285 .65758 Mdot
.37184 .36499 Mdot
.49034 .37457 Mdot
.37219 .59124 Mdot
.37806 .38045 Mdot
.65102 .37576 Mdot
.59801 .63133 Mdot
.39951 .69321 Mdot
.61431 .3813 Mdot
.35604 .56256 Mdot
.43311 .68621 Mdot
.51906 .42317 Mdot
.61509 .38982 Mdot
.47498 .37674 Mdot
.40024 .67334 Mdot
.62314 .53393 Mdot
.29942 .57123 Mdot
.18471 .45978 Mdot
.49979 .3764 Mdot
.58126 .57999 Mdot
.31497 .59356 Mdot
.38483 .37653 Mdot
.57426 .55549 Mdot
.27696 .56138 Mdot
.49562 .37656 Mdot
.61464 .62445 Mdot
.61063 .63025 Mdot
.67597 .53162 Mdot
.45164 .59916 Mdot
.41118 .69302 Mdot
.64766 .41766 Mdot
.59884 .54231 Mdot
.40729 .66022 Mdot
.20909 .45739 Mdot
.569 .5344 Mdot
.62936 .33987 Mdot
.70221 .55331 Mdot
.33181 .55118 Mdot
.35197 .37896 Mdot
.3446 .56038 Mdot
.43415 .6914 Mdot
.13689 .52602 Mdot
.47943 .36908 Mdot
.65486 .60317 Mdot
.63152 .56169 Mdot
.25432 .56346 Mdot
.63534 .36604 Mdot
.58323 .21912 Mdot
.58246 .62821 Mdot
.65934 .57302 Mdot
.5957 .59184 Mdot
.19758 .47008 Mdot
.64403 .35863 Mdot
.59571 .58844 Mdot
.53509 .61274 Mdot
.62064 .54841 Mdot
.41453 .70796 Mdot
.5915 .72621 Mdot
.61134 .5829 Mdot
.56789 .90962 Mdot
.47076 .39146 Mdot
.30154 .56494 Mdot
.47028 .47053 Mdot
.34086 .61518 Mdot
.51139 .83322 Mdot
.64876 .3732 Mdot
.68747 .33731 Mdot
.31795 .54149 Mdot
.45252 .7993 Mdot
.62286 .25871 Mdot
.62635 .62651 Mdot
.57109 .61302 Mdot
.3265 .56627 Mdot
.32768 .54204 Mdot
.46384 .38453 Mdot
.55818 .59053 Mdot
.66623 .59399 Mdot
.33079 .58055 Mdot
.59482 .61345 Mdot
.72488 .50661 Mdot
.33366 .37425 Mdot
.61534 .39365 Mdot
.36496 .37741 Mdot
.33085 .36093 Mdot
.7111 .62131 Mdot
.51479 .45613 Mdot
.3517 .33574 Mdot
.36107 .39494 Mdot
.38173 .63298 Mdot
.69183 .66842 Mdot
.41092 .70845 Mdot
.39527 .41406 Mdot
.29723 .54908 Mdot
.58843 .56822 Mdot
.63897 .35043 Mdot
.65969 .76573 Mdot
.49005 .19436 Mdot
.49433 .56209 Mdot
.60103 .54731 Mdot
.30458 .55096 Mdot
.49888 .37756 Mdot
.56023 .5431 Mdot
.49467 .77545 Mdot
.58299 .59124 Mdot
.32106 .53762 Mdot
.71272 .6575 Mdot
.47465 .35156 Mdot
.37684 .32819 Mdot
.58464 .37949 Mdot
.61066 .60405 Mdot
.63593 .38856 Mdot
.34357 .33861 Mdot
.41863 .65478 Mdot
.4156 .68335 Mdot
.56545 .57223 Mdot
.41381 .53966 Mdot
.45524 .65159 Mdot
.62686 .62553 Mdot
.6273 .60198 Mdot
.48462 .39315 Mdot
.6267 .60218 Mdot
.56865 .55021 Mdot
.6183 .57462 Mdot
.55924 .55822 Mdot
.36306 .32707 Mdot
.59241 .32432 Mdot
.56234 .61279 Mdot
.63395 .5599 Mdot
.3473 .3848 Mdot
.5559 .53133 Mdot
.35676 .34456 Mdot
.52041 .19497 Mdot
.35888 .33722 Mdot
.41442 .68449 Mdot
.32917 .58771 Mdot
.67867 .31676 Mdot
.65621 .37593 Mdot
.36909 .33215 Mdot
.40961 .66949 Mdot
.34574 .35357 Mdot
.27225 .56612 Mdot
.22113 .36463 Mdot
.67302 .37175 Mdot
.45641 .42919 Mdot
.67862 .67518 Mdot
.48267 .40314 Mdot
.33602 .56398 Mdot
.63621 .40302 Mdot
.46567 .35163 Mdot
.62334 .57273 Mdot
.40338 .6972 Mdot
.58543 .59747 Mdot
.34572 .3273 Mdot
.30164 .55071 Mdot
.36323 .40825 Mdot
.41214 .69286 Mdot
.14879 .51084 Mdot
.302 .58775 Mdot
.64918 .58444 Mdot
.34647 .38372 Mdot
.23445 .3473 Mdot
.35633 .34035 Mdot
.48974 .70031 Mdot
.61006 .44828 Mdot
.63056 .77989 Mdot
.61848 .36742 Mdot
.46141 .39247 Mdot
.67542 .23426 Mdot
.58108 .27432 Mdot
.62258 .38591 Mdot
.36307 .56831 Mdot
.58589 .60843 Mdot
.60941 .56162 Mdot
.63544 .63673 Mdot
.58819 .34211 Mdot
.58722 .53908 Mdot
.4837 .37063 Mdot
.50362 .4536 Mdot
.2713 .36269 Mdot
.30119 .5241 Mdot
.57255 .60934 Mdot
.3344 .35656 Mdot
.35105 .32428 Mdot
.50543 .38236 Mdot
.38032 .37164 Mdot
.62351 .61846 Mdot
.61428 .37134 Mdot
.39936 .48907 Mdot
.41013 .70361 Mdot
.52949 .30993 Mdot
.46903 .66656 Mdot
.45062 .68251 Mdot
.61826 .54438 Mdot
.3139 .53693 Mdot
.22731 .68256 Mdot
.61628 .56264 Mdot
.63378 .37382 Mdot
.63446 .56733 Mdot
.61615 .57818 Mdot
.60976 .58442 Mdot
.27566 .5588 Mdot
.46764 .46641 Mdot
.59675 .61437 Mdot
.35045 .33512 Mdot
.41483 .46098 Mdot
.55307 .57293 Mdot
.29951 .42246 Mdot
.39148 .56941 Mdot
.48197 .4021 Mdot
.61383 .42123 Mdot
.32381 .55247 Mdot
.62395 .36722 Mdot
.62216 .32561 Mdot
.65099 .37655 Mdot
.29678 .40647 Mdot
.68983 .50848 Mdot
.4109 .84373 Mdot
.80126 .50974 Mdot
.71555 .65884 Mdot
.61572 .33742 Mdot
.24759 .44242 Mdot
.62589 .3884 Mdot
.65008 .37555 Mdot
.32177 .83091 Mdot
.6303 .34343 Mdot
.59586 .57921 Mdot
.58618 .6354 Mdot
.68109 .28678 Mdot
.383 .63484 Mdot
.60154 .62673 Mdot
.58413 .54106 Mdot
.38444 .69331 Mdot
.62494 .47504 Mdot
.46236 .38698 Mdot
.52086 .44679 Mdot
.47301 .36662 Mdot
.5952 .59873 Mdot
.5688 .57525 Mdot
.57323 .63465 Mdot
.69711 .23761 Mdot
.62332 .79391 Mdot
.59761 .38361 Mdot
.55623 .52405 Mdot
.51671 .37944 Mdot
.64324 .58321 Mdot
.62956 .56043 Mdot
.615 .60284 Mdot
.31996 .54347 Mdot
.59024 .39225 Mdot
.59031 .50913 Mdot
.54308 .34337 Mdot
.56808 .5831 Mdot
.46013 .68484 Mdot
.41518 .64814 Mdot
.58943 .58162 Mdot
.62329 .34262 Mdot
.60564 .55411 Mdot
.65643 .35382 Mdot
.61893 .39494 Mdot
.66101 .6118 Mdot
.33502 .4263 Mdot
.58694 .3792 Mdot
.62435 .62758 Mdot
.33114 .56781 Mdot
.52887 .2982 Mdot
.58307 .57975 Mdot
.42374 .69397 Mdot
.60071 .56451 Mdot
.42247 .70538 Mdot
.62118 .59976 Mdot
.50364 .38301 Mdot
.71864 .4069 Mdot
.3032 .54189 Mdot
.45118 .65963 Mdot
.33716 .5565 Mdot
.67647 .60657 Mdot
.62841 .33685 Mdot
.45763 .36099 Mdot
.60203 .8132 Mdot
.48193 .3926 Mdot
.49221 .7949 Mdot
.4114 .45179 Mdot
.3415 .37347 Mdot
.65499 .39651 Mdot
.71005 .65282 Mdot
.33038 .44458 Mdot
.27044 .53342 Mdot
.2614 .55812 Mdot
.25595 .69582 Mdot
.21694 .70789 Mdot
.59826 .6176 Mdot
.25659 .34471 Mdot
.73346 .45921 Mdot
.57928 .65957 Mdot
.54507 .59793 Mdot
.30878 .59052 Mdot
.60293 .6271 Mdot
.47452 .49782 Mdot
.28596 .55482 Mdot
.4042 .67689 Mdot
.64016 .39269 Mdot
.41066 .6622 Mdot
.45438 .18948 Mdot
.43827 .37904 Mdot
.28515 .56146 Mdot
.55699 .56361 Mdot
.58383 .61766 Mdot
.64056 .41039 Mdot
.81743 .43418 Mdot
.61805 .39767 Mdot
.41978 .70136 Mdot
.28988 .54368 Mdot
.70687 .70897 Mdot
.60415 .57155 Mdot
.61689 .35353 Mdot
.36168 .56897 Mdot
.58589 .55644 Mdot
.34786 .37458 Mdot
.60316 .54841 Mdot
.61265 .35588 Mdot
.62628 .60166 Mdot
.61575 .37212 Mdot
.31505 .58017 Mdot
.56254 .58407 Mdot
.56888 .571 Mdot
.49704 .79386 Mdot
.42132 .67714 Mdot
.62288 .33783 Mdot
.47673 .49804 Mdot
.5873 .53276 Mdot
.49813 .77168 Mdot
.61179 .60657 Mdot
.61339 .6813 Mdot
.55203 .54334 Mdot
.47965 .3711 Mdot
.62984 .55931 Mdot
.58262 .58109 Mdot
.82063 .48607 Mdot
.80997 .48489 Mdot
.66276 .6726 Mdot
.39017 .35303 Mdot
.61267 .35075 Mdot
.28034 .55984 Mdot
.32306 .53154 Mdot
.31758 .55948 Mdot
.3952 .64347 Mdot
.54195 .53711 Mdot
.57729 .58061 Mdot
.38237 .32316 Mdot
.40828 .67982 Mdot
.62653 .35163 Mdot
.40951 .68545 Mdot
.52014 .45835 Mdot
.4292 .6886 Mdot
.48577 .3694 Mdot
.19698 .42986 Mdot
.72191 .52442 Mdot
.42937 .67811 Mdot
.61832 .39695 Mdot
.42979 .44312 Mdot
.6026 .51944 Mdot
.43422 .28793 Mdot
.3922 .70287 Mdot
.2379 .68014 Mdot
.61345 .62258 Mdot
.46929 .47891 Mdot
.36125 .34716 Mdot
.41074 .66255 Mdot
.38038 .36129 Mdot
.60712 .55608 Mdot
.57796 .33912 Mdot
.63869 .37361 Mdot
.33499 .37447 Mdot
.61995 .55018 Mdot
.40958 .66284 Mdot
.28803 .56574 Mdot
.70112 .66378 Mdot
.35524 .39049 Mdot
.46734 .79607 Mdot
.48517 .76927 Mdot
.28765 .54514 Mdot
.72951 .65605 Mdot
.37274 .34866 Mdot
.59346 .51732 Mdot
.55685 .4998 Mdot
.61147 .55373 Mdot
.29222 .53137 Mdot
.30416 .57309 Mdot
.59438 .30018 Mdot
.56619 .57949 Mdot
.57427 .63053 Mdot
.5952 .39679 Mdot
.28181 .54586 Mdot
.65196 .37549 Mdot
.64043 .40752 Mdot
.32753 .5666 Mdot
.63162 .40421 Mdot
.43463 .67589 Mdot
.51096 .49005 Mdot
.37032 .34563 Mdot
.34434 .37068 Mdot
.28463 .56421 Mdot
.27342 .54765 Mdot
.31008 .53487 Mdot
.62041 .55652 Mdot
.64759 .39482 Mdot
.63515 .58842 Mdot
.61004 .59895 Mdot
.62129 .43625 Mdot
.6067 .4097 Mdot
.63156 .57278 Mdot
.38913 .47288 Mdot
.41186 .71148 Mdot
.30665 .56836 Mdot
.382 .35018 Mdot
.48748 .80905 Mdot
.34596 .381 Mdot
.58778 .53436 Mdot
.46093 .2848 Mdot
.64052 .35402 Mdot
.41914 .68784 Mdot
.37926 .58148 Mdot
.41475 .69189 Mdot
.33332 .37296 Mdot
.62027 .41901 Mdot
.51176 .42938 Mdot
.56505 .58116 Mdot
.49918 .46213 Mdot
.53932 .76551 Mdot
.55088 .31653 Mdot
.37771 .34151 Mdot
.59402 .54321 Mdot
.47658 .39077 Mdot
.68835 .48256 Mdot
.57571 .58418 Mdot
.59138 .529 Mdot
.29167 .62598 Mdot
.62691 .55233 Mdot
.63058 .41988 Mdot
.40583 .54666 Mdot
.56031 .5692 Mdot
.67564 .61136 Mdot
.25652 .76103 Mdot
.61223 .62592 Mdot
.56764 .57082 Mdot
.59659 .57188 Mdot
.62206 .56656 Mdot
.65462 .34703 Mdot
.24003 .61268 Mdot
.3363 .34923 Mdot
.51031 .49049 Mdot
.3778 .35271 Mdot
.29198 .57385 Mdot
.45694 .50812 Mdot
.65639 .35187 Mdot
.41504 .69235 Mdot
.25087 .34757 Mdot
.48745 .56582 Mdot
.32225 .57816 Mdot
.54022 .81913 Mdot
.39808 .70543 Mdot
.60077 .5185 Mdot
.43779 .67706 Mdot
.3072 .59221 Mdot
.3422 .36252 Mdot
.62886 .63183 Mdot
.65173 .36073 Mdot
.60362 .37601 Mdot
.60202 .54573 Mdot
.52312 .31081 Mdot
.37808 .3821 Mdot
.39864 .74262 Mdot
.57851 .60546 Mdot
.58861 .52935 Mdot
.62099 .40132 Mdot
.30861 .55223 Mdot
.41221 .45331 Mdot
.41833 .67079 Mdot
.64105 .6226 Mdot
.60422 .55539 Mdot
.51805 .45905 Mdot
.36439 .32858 Mdot
.48696 .3818 Mdot
.57003 .59289 Mdot
.51147 .44903 Mdot
.58284 .538 Mdot
.64411 .65504 Mdot
.33403 .55961 Mdot
.66242 .58682 Mdot
.56573 .60559 Mdot
.59563 .32457 Mdot
.37539 .35358 Mdot
.63245 .36946 Mdot
.63832 .43742 Mdot
.50077 .38835 Mdot
.36897 .36879 Mdot
.62926 .56819 Mdot
.3278 .35482 Mdot
.61299 .57091 Mdot
.59536 .61016 Mdot
.37908 .34261 Mdot
.65065 .38396 Mdot
.56933 .21991 Mdot
.59149 .32497 Mdot
.62594 .58438 Mdot
.59738 .56098 Mdot
.38627 .63385 Mdot
.67102 .77159 Mdot
.56467 .60473 Mdot
.64332 .40008 Mdot
.58465 .55534 Mdot
.33879 .36594 Mdot
.42271 .69873 Mdot
.62984 .37895 Mdot
.27154 .5583 Mdot
.30708 .58107 Mdot
.29532 .60481 Mdot
.48216 .36882 Mdot
.55881 .59054 Mdot
.64643 .41902 Mdot
.60106 .40135 Mdot
.52947 .47959 Mdot
.30189 .56587 Mdot
.42819 .69468 Mdot
.60489 .62856 Mdot
.7026 .62666 Mdot
.33147 .35176 Mdot
.58371 .90026 Mdot
.5081 .43139 Mdot
.42952 .64685 Mdot
.431 .55627 Mdot
.47935 .39007 Mdot
.59944 .62326 Mdot
.40078 .66666 Mdot
.30749 .57788 Mdot
.60844 .55959 Mdot
.53427 .58986 Mdot
.33386 .45008 Mdot
.26979 .54867 Mdot
.32943 .36286 Mdot
.28662 .58128 Mdot
.4196 .70758 Mdot
.48645 .36993 Mdot
.60095 .37646 Mdot
.58489 .5854 Mdot
.6648 .57404 Mdot
.3024 .55688 Mdot
.50267 .39276 Mdot
.56755 .56147 Mdot
.60653 .35924 Mdot
.31126 .56421 Mdot
.59922 .59873 Mdot
.68537 .48854 Mdot
.6813 .32318 Mdot
.29275 .54735 Mdot
.63545 .62638 Mdot
.68041 .5702 Mdot
.26599 .55212 Mdot
.28782 .59164 Mdot
.58489 .54007 Mdot
.40931 .66488 Mdot
.56516 .5967 Mdot
.35091 .34335 Mdot
.4669 .46573 Mdot
.3611 .37392 Mdot
.49856 .77842 Mdot
.56602 .62604 Mdot
.50541 .61476 Mdot
.66156 .37246 Mdot
.41656 .71746 Mdot
.82689 .53418 Mdot
.58154 .53118 Mdot
.58585 .19799 Mdot
.44728 .4777 Mdot
.47201 .4235 Mdot
.52715 .17077 Mdot
.42439 .67035 Mdot
.34809 .35216 Mdot
.56885 .56158 Mdot
.37767 .31182 Mdot
.42505 .66626 Mdot
.49981 .77875 Mdot
.64616 .59599 Mdot
.6374 .35649 Mdot
.57948 .60402 Mdot
.60923 .35841 Mdot
.58964 .56036 Mdot
.64395 .48428 Mdot
.46069 .67593 Mdot
.49058 .69876 Mdot
.60192 .5175 Mdot
.25114 .32867 Mdot
.68466 .67303 Mdot
.41798 .69897 Mdot
.62593 .58999 Mdot
.48401 .38685 Mdot
.38663 .37465 Mdot
.23082 .38879 Mdot
.31575 .53915 Mdot
.35633 .33472 Mdot
.63029 .40019 Mdot
.33374 .58209 Mdot
.49942 .39335 Mdot
.54878 .50972 Mdot
.40637 .66442 Mdot
.37127 .36555 Mdot
.58526 .58154 Mdot
.60875 .54458 Mdot
.19686 .47001 Mdot
.73875 .69122 Mdot
.64093 .40425 Mdot
.17201 .58394 Mdot
.64742 .41663 Mdot
.41515 .67518 Mdot
.33254 .55565 Mdot
.60501 .59639 Mdot
.57214 .58028 Mdot
.27861 .54223 Mdot
.62308 .4119 Mdot
.41943 .71933 Mdot
.6387 .77718 Mdot
.41117 .38894 Mdot
.53857 .711 Mdot
.63067 .3816 Mdot
.53398 .70935 Mdot
.37926 .68868 Mdot
.30411 .37543 Mdot
.65417 .70631 Mdot
.35438 .37777 Mdot
.54397 .71313 Mdot
.6279 .34966 Mdot
.59858 .61915 Mdot
.47549 .37746 Mdot
.46984 .38803 Mdot
.63441 .39277 Mdot
.32795 .56192 Mdot
.39411 .68595 Mdot
.57732 .59919 Mdot
.52614 .52566 Mdot
.81752 .41411 Mdot
.27469 .54865 Mdot
.65574 .61491 Mdot
.38104 .37761 Mdot
.58929 .55622 Mdot
.38604 .68408 Mdot
.34639 .36246 Mdot
.50073 .37177 Mdot
.48841 .55357 Mdot
.59965 .63177 Mdot
.40431 .55496 Mdot
.36677 .3546 Mdot
.67643 .76779 Mdot
.56935 .57078 Mdot
.37307 .34915 Mdot
.66559 .57931 Mdot
.517 .351 Mdot
.4042 .48067 Mdot
.57989 .27068 Mdot
.31448 .52196 Mdot
.29936 .58293 Mdot
.78408 .67484 Mdot
.47113 .67489 Mdot
.35409 .33177 Mdot
.49245 .37132 Mdot
.61924 .72236 Mdot
.37793 .36604 Mdot
.62574 .63203 Mdot
.61167 .61151 Mdot
.71358 .65699 Mdot
.67668 .64916 Mdot
.46432 .38743 Mdot
.52598 .55302 Mdot
.62973 .61456 Mdot
.63046 .53672 Mdot
.57919 .55016 Mdot
.59905 .36605 Mdot
.36203 .38084 Mdot
.41647 .13431 Mdot
.32885 .34159 Mdot
.50964 .54191 Mdot
.29764 .54912 Mdot
.3357 .53488 Mdot
.58996 .58295 Mdot
.5155 .65605 Mdot
.27498 .27635 Mdot
.60673 .57605 Mdot
.38048 .58049 Mdot
.48396 .76989 Mdot
.5839 .51613 Mdot
.60187 .34687 Mdot
.66528 .58984 Mdot
.6693 .38172 Mdot
.34588 .36378 Mdot
.42514 .66963 Mdot
.39704 .71204 Mdot
.35253 .34802 Mdot
.57577 .57547 Mdot
.39208 .71216 Mdot
.5904 .59191 Mdot
.58866 .61964 Mdot
.52292 .45262 Mdot
.41073 .65409 Mdot
.31097 .53463 Mdot
.41557 .68567 Mdot
.64839 .36858 Mdot
.33797 .84938 Mdot
.40447 .69136 Mdot
.69318 .66783 Mdot
.46563 .48868 Mdot
.54446 .71573 Mdot
.60421 .38187 Mdot
.4161 .70337 Mdot
.35532 .37982 Mdot
.51251 .42121 Mdot
.72736 .65439 Mdot
.34482 .37966 Mdot
.57291 .58608 Mdot
.65783 .35405 Mdot
.5968 .38808 Mdot
.37747 .33022 Mdot
.61257 .40399 Mdot
.64533 .56474 Mdot
.62439 .62882 Mdot
.34543 .33569 Mdot
.74901 .31684 Mdot
.35272 .38029 Mdot
.7019 .63585 Mdot
.6172 .60564 Mdot
.63179 .37617 Mdot
.60538 .67973 Mdot
.5983 .42114 Mdot
.46636 .38054 Mdot
.5824 .63051 Mdot
.40803 .69858 Mdot
.50074 .48917 Mdot
.29424 .54639 Mdot
.46623 .28268 Mdot
.60671 .3678 Mdot
.3438 .32026 Mdot
.60566 .39389 Mdot
.63255 .41044 Mdot
.33716 .37525 Mdot
.64289 .36726 Mdot
.56877 .58207 Mdot
.41197 .21929 Mdot
.60744 .37246 Mdot
.36149 .35773 Mdot
.40251 .70002 Mdot
.63397 .40355 Mdot
.37306 .71705 Mdot
.586 .62147 Mdot
.33212 .57549 Mdot
.44697 .65789 Mdot
.66355 .36407 Mdot
.42307 .69719 Mdot
.30362 .56098 Mdot
.3934 .68413 Mdot
.40137 .33666 Mdot
.34326 .317 Mdot
.49468 .56868 Mdot
.49833 .35026 Mdot
.64316 .35192 Mdot
.32002 .52177 Mdot
.58799 .62809 Mdot
.581 .61076 Mdot
.42415 .70928 Mdot
.59626 .37092 Mdot
.51316 .31042 Mdot
.53894 .6602 Mdot
.52968 .3115 Mdot
.38298 .34235 Mdot
.40364 .76717 Mdot
.50751 .42975 Mdot
.42961 .3593 Mdot
.60069 .64581 Mdot
.47822 .38904 Mdot
.59613 .59129 Mdot
.47047 .7698 Mdot
.40726 .70883 Mdot
.21567 .49092 Mdot
.60437 .6573 Mdot
.29003 .53844 Mdot
.59592 .56468 Mdot
.25499 .36537 Mdot
.67083 .62574 Mdot
.39441 .70663 Mdot
.32818 .37207 Mdot
.65625 .3759 Mdot
.40629 .70517 Mdot
.31185 .58041 Mdot
.55782 .70196 Mdot
.6177 .63387 Mdot
.62681 .61837 Mdot
.26099 .56884 Mdot
.65215 .36989 Mdot
.2958 .57346 Mdot
.37096 .34619 Mdot
.40671 .68919 Mdot
.62564 .57158 Mdot
.6565 .57327 Mdot
.25437 .56668 Mdot
.33531 .33366 Mdot
.27778 .5385 Mdot
.32837 .35135 Mdot
.47554 .38647 Mdot
.55751 .57223 Mdot
.26167 .57845 Mdot
.59022 .64706 Mdot
.79832 .46281 Mdot
.51464 .49584 Mdot
.80288 .56471 Mdot
.31195 .53462 Mdot
.46195 .64514 Mdot
.35402 .35223 Mdot
.37407 .36177 Mdot
.71024 .62939 Mdot
.27428 .28458 Mdot
.41664 .45536 Mdot
.20378 .38379 Mdot
.36979 .34492 Mdot
.36817 .3612 Mdot
.3135 .57375 Mdot
.64709 .37862 Mdot
.63279 .32475 Mdot
.30329 .59482 Mdot
.4751 .73385 Mdot
.62611 .35152 Mdot
.61831 .21633 Mdot
.27261 .57928 Mdot
.60053 .64063 Mdot
.45835 .3645 Mdot
.39342 .70529 Mdot
.47216 .75983 Mdot
.21627 .37518 Mdot
.60142 .58949 Mdot
.35995 .81501 Mdot
.32061 .54816 Mdot
.41384 .40543 Mdot
.2924 .33118 Mdot
.60193 .53657 Mdot
.59414 .56641 Mdot
.57544 .56741 Mdot
.44284 .65948 Mdot
.80663 .42713 Mdot
.60304 .59419 Mdot
.48381 .67358 Mdot
.55603 .55263 Mdot
.18812 .46623 Mdot
.41526 .68564 Mdot
.59195 .78005 Mdot
.34857 .54212 Mdot
.53591 .33845 Mdot
.61416 .54125 Mdot
.36437 .34258 Mdot
.35867 .46196 Mdot
.36784 .33354 Mdot
.2899 .35448 Mdot
.64798 .71347 Mdot
.59957 .36193 Mdot
.60395 .54841 Mdot
.27309 .58221 Mdot
.6601 .35763 Mdot
.37211 .46801 Mdot
.30274 .82133 Mdot
.37717 .33339 Mdot
.15765 .62544 Mdot
.36916 .37402 Mdot
.46873 .3883 Mdot
.62735 .39856 Mdot
.53863 .68134 Mdot
.50441 .46089 Mdot
.65173 .37715 Mdot
.31609 .7122 Mdot
.66264 .34117 Mdot
.52045 .69023 Mdot
.67456 .36452 Mdot
.35536 .35765 Mdot
.3385 .3198 Mdot
.53713 .57351 Mdot
.57077 .61635 Mdot
.49142 .45964 Mdot
.55092 .61506 Mdot
.59373 .62956 Mdot
.2858 .5546 Mdot
.48541 .34579 Mdot
.36674 .30632 Mdot
.63323 .38525 Mdot
.33605 .34064 Mdot
.59588 .56625 Mdot
.62624 .58513 Mdot
.64043 .57097 Mdot
.46085 .80269 Mdot
.61462 .21284 Mdot
.59781 .61284 Mdot
.66954 .62489 Mdot
.32517 .57473 Mdot
.19533 .47212 Mdot
.18283 .57816 Mdot
.63206 .71669 Mdot
.56789 .55851 Mdot
.42005 .67892 Mdot
.38371 .69398 Mdot
.64052 .56313 Mdot
.50135 .61215 Mdot
.36604 .71124 Mdot
.58515 .58123 Mdot
.50777 .6695 Mdot
.25773 .54733 Mdot
.50463 .38936 Mdot
.30215 .55739 Mdot
.66187 .3589 Mdot
.47997 .3929 Mdot
.2789 .56847 Mdot
.48423 .64598 Mdot
.50035 .38595 Mdot
.51987 .34974 Mdot
.41858 .70238 Mdot
.57414 .55599 Mdot
.65404 .30892 Mdot
.27738 .54845 Mdot
.37032 .35795 Mdot
.6187 .37855 Mdot
.3909 .36862 Mdot
.19037 .45047 Mdot
.47729 .74424 Mdot
.47773 .36986 Mdot
.36107 .34045 Mdot
.41823 .52264 Mdot
.41851 .6798 Mdot
.37601 .37412 Mdot
.50768 .63085 Mdot
.55329 .59395 Mdot
.33001 .22729 Mdot
.63309 .61578 Mdot
.60578 .28655 Mdot
.37058 .35278 Mdot
.49898 .36798 Mdot
.58426 .58703 Mdot
.30394 .58698 Mdot
.56962 .51382 Mdot
.59047 .59373 Mdot
.27292 .5738 Mdot
.59932 .61648 Mdot
.40278 .66083 Mdot
.66776 .38306 Mdot
.44899 .48609 Mdot
.444 .78327 Mdot
.39362 .69476 Mdot
.55788 .47011 Mdot
.56569 .60952 Mdot
.27835 .68281 Mdot
.63757 .35875 Mdot
.58427 .53188 Mdot
.51612 .79486 Mdot
.64155 .38625 Mdot
.62341 .36627 Mdot
.62969 .60092 Mdot
.35264 .38182 Mdot
.29134 .53283 Mdot
.41815 .68181 Mdot
.40543 .33218 Mdot
.60089 .59991 Mdot
.59179 .54198 Mdot
.3999 .70575 Mdot
.36816 .36709 Mdot
.62772 .57264 Mdot
.51927 .25388 Mdot
.52727 .48448 Mdot
.32991 .35612 Mdot
.55306 .57493 Mdot
.4393 .15626 Mdot
.63763 .32333 Mdot
.37232 .82327 Mdot
.46626 .66669 Mdot
.33088 .56263 Mdot
.64291 .63249 Mdot
.53825 .91806 Mdot
.41475 .70264 Mdot
.54043 .32747 Mdot
.59339 .61615 Mdot
.60693 .59394 Mdot
.60731 .35073 Mdot
.63654 .58513 Mdot
.62128 .34676 Mdot
.4236 .78117 Mdot
.24898 .2963 Mdot
.61152 .40172 Mdot
.616 .35037 Mdot
.67455 .64151 Mdot
.46873 .8102 Mdot
.63785 .39554 Mdot
.61697 .63389 Mdot
.29867 .68641 Mdot
.53666 .60765 Mdot
.41339 .64995 Mdot
.36041 .68232 Mdot
.60576 .34375 Mdot
.75315 .62504 Mdot
.67263 .64304 Mdot
.67719 .51914 Mdot
.37008 .68183 Mdot
.36583 .33662 Mdot
.61655 .58782 Mdot
.48693 .36865 Mdot
.31229 .56707 Mdot
.64196 .54117 Mdot
.57159 .56499 Mdot
.6385 .34305 Mdot
.44286 .67137 Mdot
.3796 .36743 Mdot
.57904 .545 Mdot
.25406 .57778 Mdot
.40861 .6723 Mdot
.60855 .37915 Mdot
.69687 .65628 Mdot
.39014 .70818 Mdot
.65987 .5876 Mdot
.60519 .62102 Mdot
.57303 .54888 Mdot
.55781 .64818 Mdot
.3554 .34714 Mdot
.31687 .59177 Mdot
.64238 .6309 Mdot
.51798 .43492 Mdot
.49409 .50469 Mdot
.65193 .6094 Mdot
.64028 .40214 Mdot
.38436 .3453 Mdot
.49431 .37894 Mdot
.57367 .72477 Mdot
.61562 .61734 Mdot
.60233 .20347 Mdot
.57797 .81606 Mdot
.49661 .38612 Mdot
.64797 .33744 Mdot
.41773 .6883 Mdot
.62463 .6104 Mdot
.48339 .68918 Mdot
.62732 .63003 Mdot
.53084 .60413 Mdot
.32839 .55584 Mdot
.37484 .34314 Mdot
.54093 .49678 Mdot
.31113 .56898 Mdot
.62379 .36687 Mdot
.67283 .26803 Mdot
.6445 .32772 Mdot
.63745 .4083 Mdot
.32874 .42016 Mdot
.34119 .3553 Mdot
.55156 .91708 Mdot
.6639 .78031 Mdot
.59518 .63757 Mdot
.33838 .35153 Mdot
.628 .39556 Mdot
.6361 .57424 Mdot
.6369 .35025 Mdot
.5879 .37872 Mdot
.60028 .62877 Mdot
.59567 .62829 Mdot
.49352 .69027 Mdot
.63005 .2268 Mdot
.40289 .6965 Mdot
.60752 .4014 Mdot
.71615 .5832 Mdot
.6049 .60088 Mdot
.56568 .58534 Mdot
.34816 .45526 Mdot
.41115 .70559 Mdot
.71571 .49073 Mdot
.58315 .61087 Mdot
.50543 .80329 Mdot
.58574 .63005 Mdot
.61434 .32845 Mdot
.39852 .35739 Mdot
.50417 .57078 Mdot
.29602 .53007 Mdot
.65303 .4002 Mdot
.42424 .7073 Mdot
.60657 .41864 Mdot
.70834 .53155 Mdot
.34344 .36232 Mdot
.61306 .35526 Mdot
.34426 .57127 Mdot
.35984 .36925 Mdot
.34872 .37703 Mdot
.37711 .4697 Mdot
.34126 .57217 Mdot
.43769 .65471 Mdot
.38724 .36392 Mdot
.68373 .48955 Mdot
.35479 .36057 Mdot
.70533 .52275 Mdot
.56056 .585 Mdot
.48413 .66657 Mdot
.52783 .51435 Mdot
.53665 .5919 Mdot
.36774 .37932 Mdot
.39831 .67964 Mdot
.62361 .56115 Mdot
.6166 .40608 Mdot
.39992 .68697 Mdot
.42955 .38621 Mdot
.34141 .53861 Mdot
.59478 .38223 Mdot
.32951 .37131 Mdot
.6329 .34529 Mdot
.47983 .76606 Mdot
.43563 .71192 Mdot
.37153 .47942 Mdot
.49813 .46607 Mdot
.62074 .52804 Mdot
.67635 .62332 Mdot
.61803 .55004 Mdot
.57265 .576 Mdot
.29305 .54797 Mdot
.39841 .64262 Mdot
.63401 .40385 Mdot
.816 .39613 Mdot
.36167 .34348 Mdot
.40768 .54633 Mdot
.52725 .58354 Mdot
.61162 .56673 Mdot
.62322 .39073 Mdot
.59056 .3959 Mdot
.81065 .48608 Mdot
.27906 .54077 Mdot
.54015 .61446 Mdot
.61523 .53831 Mdot
.58714 .48624 Mdot
.36148 .37805 Mdot
.54673 .24003 Mdot
.30903 .52619 Mdot
.16897 .66878 Mdot
.30633 .56934 Mdot
.27552 .63585 Mdot
.64346 .36818 Mdot
.43097 .68821 Mdot
.56935 .5975 Mdot
.57232 .42127 Mdot
.64941 .34269 Mdot
.31787 .51594 Mdot
.416 .69424 Mdot
.56421 .22725 Mdot
.345 .34085 Mdot
.56357 .56038 Mdot
.59013 .63195 Mdot
.63289 .59111 Mdot
.64109 .58286 Mdot
.34147 .3378 Mdot
.63134 .62761 Mdot
.35407 .39117 Mdot
.71648 .53205 Mdot
.52168 .7911 Mdot
.27807 .58805 Mdot
.19429 .48625 Mdot
.63429 .40879 Mdot
.69301 .4043 Mdot
.72092 .50551 Mdot
.51536 .49532 Mdot
.4023 .34161 Mdot
.55848 .57705 Mdot
.32655 .56272 Mdot
.25642 .32742 Mdot
.2792 .58756 Mdot
.33831 .18271 Mdot
.70953 .65992 Mdot
.60568 .26389 Mdot
.64079 .59628 Mdot
.26684 .58661 Mdot
.7606 .59469 Mdot
.65883 .57863 Mdot
.39719 .71738 Mdot
.69305 .5174 Mdot
.61859 .29875 Mdot
.42639 .69699 Mdot
.59112 .62342 Mdot
.60904 .41261 Mdot
.56993 .58696 Mdot
.5728 .60672 Mdot
.60619 .57255 Mdot
.39768 .37013 Mdot
.57278 .62683 Mdot
.56553 .59714 Mdot
.73119 .69714 Mdot
.38723 .56454 Mdot
.31726 .58196 Mdot
.80904 .54404 Mdot
.40782 .68007 Mdot
.66198 .36218 Mdot
.44999 .47561 Mdot
.34999 .34093 Mdot
.81008 .48962 Mdot
.63809 .60569 Mdot
.54923 .30075 Mdot
.33565 .32326 Mdot
.41372 .66613 Mdot
.4974 .37903 Mdot
.5293 .21121 Mdot
.32582 .54235 Mdot
.46185 .38284 Mdot
.29526 .5455 Mdot
.79115 .59696 Mdot
.6163 .34918 Mdot
.6228 .52993 Mdot
.38258 .36507 Mdot
.30794 .59048 Mdot
.4843 .68071 Mdot
.57884 .55758 Mdot
.31018 .53372 Mdot
.61484 .51889 Mdot
.49277 .49337 Mdot
.45401 .47072 Mdot
.3197 .58844 Mdot
.32649 .33102 Mdot
.35693 .37235 Mdot
.43259 .69202 Mdot
.66215 .38104 Mdot
.65121 .36301 Mdot
.35225 .36603 Mdot
.24343 .73178 Mdot
.60037 .59749 Mdot
.60846 .60963 Mdot
.51606 .43035 Mdot
.63339 .5679 Mdot
.43055 .63533 Mdot
.47901 .39713 Mdot
.65189 .35589 Mdot
.62049 .55412 Mdot
.62818 .57406 Mdot
.609 .62316 Mdot
.48078 .73945 Mdot
.3044 .55628 Mdot
.62878 .61453 Mdot
.40307 .66582 Mdot
.45068 .3848 Mdot
.58459 .62655 Mdot
.64708 .55562 Mdot
.62532 .34589 Mdot
.24494 .68062 Mdot
.3686 .35263 Mdot
.28182 .54367 Mdot
.26635 .57321 Mdot
.53507 .75656 Mdot
.58049 .36271 Mdot
.46455 .38878 Mdot
.20765 .43792 Mdot
.49208 .37303 Mdot
.42194 .693 Mdot
.40588 .469 Mdot
.25369 .54342 Mdot
.30323 .58334 Mdot
.3197 .34527 Mdot
.60068 .54072 Mdot
.59151 .63028 Mdot
.53358 .33178 Mdot
.60874 .58684 Mdot
.4091 .69974 Mdot
.35485 .38554 Mdot
.619 .34963 Mdot
.38757 .68163 Mdot
.37471 .3645 Mdot
.65268 .37236 Mdot
.5705 .52818 Mdot
.64478 .61938 Mdot
.6186 .37409 Mdot
.60713 .3812 Mdot
.59263 .57654 Mdot
.76244 .67249 Mdot
.65476 .3601 Mdot
.618 .38632 Mdot
.50692 .41213 Mdot
.33568 .55633 Mdot
.61618 .67346 Mdot
.33867 .35402 Mdot
.56727 .58372 Mdot
.27363 .58667 Mdot
.42911 .68282 Mdot
.61716 .36397 Mdot
.6172 .59279 Mdot
.59754 .60478 Mdot
.42057 .68046 Mdot
.399 .65936 Mdot
.39999 .70171 Mdot
.39613 .36577 Mdot
.62524 .6273 Mdot
.63659 .39822 Mdot
.34447 .34063 Mdot
.38743 .70108 Mdot
.43807 .67201 Mdot
.73088 .6874 Mdot
.59968 .58713 Mdot
.38716 .71116 Mdot
.39563 .88505 Mdot
.57265 .70883 Mdot
.48373 .3948 Mdot
.24965 .5672 Mdot
.45813 .64883 Mdot
.44839 .66442 Mdot
.36124 .3316 Mdot
.39363 .56551 Mdot
.43645 .69444 Mdot
.61095 .58468 Mdot
.59191 .55375 Mdot
.6087 .64793 Mdot
.4026 .68197 Mdot
.48186 .7509 Mdot
.60293 .40033 Mdot
.73817 .43129 Mdot
.40767 .68026 Mdot
.32572 .58453 Mdot
.25472 .57235 Mdot
.30405 .57212 Mdot
.56189 .55707 Mdot
.82293 .50916 Mdot
.71929 .56186 Mdot
.71685 .47914 Mdot
.35177 .33655 Mdot
.59038 .39412 Mdot
.35506 .40714 Mdot
.62319 .36559 Mdot
.31675 .55655 Mdot
.40539 .67338 Mdot
.60528 .35264 Mdot
.34754 .37529 Mdot
.35677 .37467 Mdot
.27972 .53484 Mdot
.30088 .562 Mdot
.28621 .56328 Mdot
.65693 .39404 Mdot
.64327 .3675 Mdot
.62699 .57787 Mdot
.61296 .36503 Mdot
.58529 .81958 Mdot
.45115 .65213 Mdot
.26234 .5493 Mdot
.36192 .3515 Mdot
.61572 .39017 Mdot
.57201 .55911 Mdot
.31628 .6275 Mdot
.30896 .51579 Mdot
.38978 .6907 Mdot
.38235 .25181 Mdot
.22466 .30789 Mdot
.55612 .56044 Mdot
.33881 .33167 Mdot
.50355 .61491 Mdot
.57901 .56594 Mdot
.32577 .54832 Mdot
.60948 .78748 Mdot
.50138 .37927 Mdot
.57035 .60979 Mdot
.59551 .5275 Mdot
.35688 .38169 Mdot
.452 .47415 Mdot
.60988 .57924 Mdot
.40317 .50147 Mdot
.35982 .32509 Mdot
.3074 .52605 Mdot
.79552 .67599 Mdot
.41882 .40034 Mdot
.44425 .75555 Mdot
.49654 .39297 Mdot
.61083 .59147 Mdot
.28685 .55273 Mdot
.39291 .67752 Mdot
.29286 .5566 Mdot
.64788 .33549 Mdot
.33148 .55072 Mdot
.58574 .54821 Mdot
.64118 .39476 Mdot
.37006 .36702 Mdot
.40766 .55419 Mdot
.74409 .66291 Mdot
.3055 .58653 Mdot
.50872 .38773 Mdot
.59183 .62668 Mdot
.68014 .46406 Mdot
.53831 .56602 Mdot
.56626 .60728 Mdot
.37599 .33959 Mdot
.62784 .38951 Mdot
.38253 .34225 Mdot
.60016 .51112 Mdot
.69007 .38839 Mdot
.35866 .343 Mdot
.57851 .33463 Mdot
.39891 .70595 Mdot
.47437 .73586 Mdot
.5783 .58964 Mdot
.38251 .3621 Mdot
.62313 .62596 Mdot
.60602 .39984 Mdot
.48727 .53927 Mdot
.57258 .47704 Mdot
.38111 .37809 Mdot
.63072 .27651 Mdot
.47744 .4995 Mdot
.63302 .67001 Mdot
.37596 .35165 Mdot
.82624 .53232 Mdot
.48665 .38557 Mdot
.42111 .67231 Mdot
.38752 .67432 Mdot
.42566 .66079 Mdot
.6089 .59206 Mdot
.6602 .49098 Mdot
.43356 .66032 Mdot
.39473 .35643 Mdot
.42024 .6548 Mdot
.47341 .8011 Mdot
.52132 .31021 Mdot
.39426 .69909 Mdot
.58065 .59443 Mdot
.6266 .52415 Mdot
.39013 .57044 Mdot
.34395 .55148 Mdot
.56365 .20498 Mdot
.71591 .70367 Mdot
.60485 .59448 Mdot
.65755 .47695 Mdot
.6288 .33132 Mdot
.45104 .60446 Mdot
.57993 .4772 Mdot
.43174 .4467 Mdot
.61604 .38742 Mdot
.47385 .46732 Mdot
.6586 .36247 Mdot
.59722 .51495 Mdot
.59448 .6101 Mdot
.66407 .35574 Mdot
.44938 .27981 Mdot
.83819 .46861 Mdot
.53263 .30638 Mdot
.65084 .38973 Mdot
.37564 .35404 Mdot
.34952 .32599 Mdot
.37708 .3412 Mdot
.27838 .5531 Mdot
.60575 .36573 Mdot
.61949 .61678 Mdot
.31699 .57793 Mdot
.57472 .60443 Mdot
.35025 .37014 Mdot
.52704 .48814 Mdot
.61964 .34877 Mdot
.5832 .58171 Mdot
.72803 .63113 Mdot
.30359 .54665 Mdot
.41776 .67789 Mdot
.39634 .23968 Mdot
.25138 .55448 Mdot
.32678 .34478 Mdot
.58763 .36255 Mdot
.32082 .59796 Mdot
.22868 .60496 Mdot
.59938 .63876 Mdot
.60608 .63654 Mdot
.36751 .59018 Mdot
.73915 .63716 Mdot
.60707 .56715 Mdot
.30965 .58081 Mdot
.3377 .56322 Mdot
.61922 .6265 Mdot
.60233 .38241 Mdot
.44017 .66741 Mdot
.4235 .70979 Mdot
.60939 .52166 Mdot
.49128 .46394 Mdot
.48407 .66935 Mdot
.62936 .57023 Mdot
.62934 .6513 Mdot
.34686 .56428 Mdot
.49909 .39323 Mdot
.51526 .46025 Mdot
.43457 .67324 Mdot
.59152 .61691 Mdot
.8169 .42118 Mdot
.60899 .3645 Mdot
.29911 .5311 Mdot
.33373 .3598 Mdot
.39138 .71138 Mdot
.27192 .53773 Mdot
.61902 .62652 Mdot
.62804 .5733 Mdot
.38002 .37119 Mdot
.60884 .33185 Mdot
.40216 .6787 Mdot
.31936 .57707 Mdot
.43083 .68935 Mdot
.64284 .36398 Mdot
.61178 .37983 Mdot
.61689 .5375 Mdot
.53744 .59191 Mdot
.28493 .58487 Mdot
.63429 .63399 Mdot
.29945 .57673 Mdot
.1965 .47004 Mdot
.3319 .35064 Mdot
.59589 .53127 Mdot
.57853 .37849 Mdot
.35092 .36959 Mdot
.60263 .58202 Mdot
.36666 .59057 Mdot
.61297 .56067 Mdot
.29385 .5945 Mdot
.64228 .76958 Mdot
.42903 .66916 Mdot
.66229 .54299 Mdot
.61781 .68991 Mdot
.63009 .56383 Mdot
.34135 .56105 Mdot
.68606 .51852 Mdot
.35451 .34378 Mdot
.64184 .3768 Mdot
.23643 .68824 Mdot
.35948 .35883 Mdot
.58252 .60361 Mdot
.40443 .69026 Mdot
.65617 .38014 Mdot
.4706 .37869 Mdot
.48967 .44763 Mdot
.64013 .53734 Mdot
.56645 .52041 Mdot
.57642 .54549 Mdot
.2053 .38097 Mdot
.28763 .56046 Mdot
.62457 .39342 Mdot
.34351 .32975 Mdot
.34398 .3555 Mdot
.30877 .55192 Mdot
.60482 .30244 Mdot
.4946 .28509 Mdot
.43807 .90141 Mdot
.26662 .54249 Mdot
.42066 .6565 Mdot
.48733 .52831 Mdot
.3084 .57254 Mdot
.28323 .54759 Mdot
.34803 .54774 Mdot
.52739 .32438 Mdot
.64891 .39195 Mdot
.59898 .60616 Mdot
.60165 .418 Mdot
.61047 .59307 Mdot
.44842 .74858 Mdot
.34854 .36537 Mdot
.64264 .375 Mdot
.37766 .72962 Mdot
.67329 .61821 Mdot
.58618 .56545 Mdot
.43315 .747 Mdot
.6112 .50278 Mdot
.55555 .71885 Mdot
.64332 .57637 Mdot
.2974 .55351 Mdot
.68916 .36458 Mdot
.65857 .60723 Mdot
.72458 .63235 Mdot
.36147 .37437 Mdot
.4721 .37196 Mdot
.59365 .51014 Mdot
.6411 .65229 Mdot
.65612 .38336 Mdot
.60759 .34913 Mdot
.43471 .66103 Mdot
.41275 .22401 Mdot
.36466 .37281 Mdot
.57267 .25535 Mdot
.56836 .61321 Mdot
.34478 .30649 Mdot
.62675 .7817 Mdot
.59897 .57516 Mdot
.38387 .47153 Mdot
.80998 .48815 Mdot
.60906 .56383 Mdot
.72154 .47098 Mdot
.35843 .35284 Mdot
.51032 .79815 Mdot
.6481 .60275 Mdot
.32187 .54496 Mdot
.64644 .3768 Mdot
.59501 .38405 Mdot
.38894 .68496 Mdot
.62099 .80512 Mdot
.30794 .2906 Mdot
.64417 .37082 Mdot
.57537 .56341 Mdot
.36764 .35315 Mdot
.46841 .3773 Mdot
.65297 .55444 Mdot
.27882 .32311 Mdot
.6131 .35982 Mdot
.6435 .63039 Mdot
.54592 .29696 Mdot
.46186 .46845 Mdot
.63284 .22008 Mdot
.38452 .35261 Mdot
.43556 .67562 Mdot
.56386 .6455 Mdot
.20526 .4441 Mdot
.64275 .62162 Mdot
.44686 .7512 Mdot
.58252 .34769 Mdot
.42327 .69808 Mdot
.57865 .57137 Mdot
.6102 .5769 Mdot
.50384 .47547 Mdot
.38435 .6792 Mdot
.61025 .57939 Mdot
.60835 .65853 Mdot
.64755 .3616 Mdot
.4804 .39759 Mdot
.62044 .34983 Mdot
.57186 .58376 Mdot
.64716 .75698 Mdot
.60039 .37096 Mdot
.56669 .21163 Mdot
.46673 .674 Mdot
.35139 .33995 Mdot
.65687 .62167 Mdot
.56109 .59165 Mdot
.54466 .15849 Mdot
.46661 .3821 Mdot
.19043 .60344 Mdot
.2692 .58753 Mdot
.8645 .51778 Mdot
.25387 .54906 Mdot
.61927 .26471 Mdot
.39789 .53272 Mdot
.62013 .64536 Mdot
.68031 .65083 Mdot
.71295 .46904 Mdot
.35326 .30883 Mdot
.68519 .428 Mdot
.57099 .61661 Mdot
.59966 .62117 Mdot
.31334 .57565 Mdot
.59587 .30262 Mdot
.50397 .57985 Mdot
.51285 .46054 Mdot
.41417 .66725 Mdot
.63447 .36618 Mdot
.58692 .55057 Mdot
.42078 .26843 Mdot
.31056 .5878 Mdot
.6862 .69231 Mdot
.58277 .58447 Mdot
.50434 .55783 Mdot
.56207 .33652 Mdot
.37185 .36397 Mdot
.32273 .58731 Mdot
.33381 .57953 Mdot
.6123 .59846 Mdot
.34027 .34237 Mdot
.62098 .56992 Mdot
.478 .50779 Mdot
.64602 .5486 Mdot
.42556 .6895 Mdot
.56478 .58392 Mdot
.64556 .69615 Mdot
.69569 .26342 Mdot
.65874 .64917 Mdot
.65198 .39779 Mdot
.2845 .56645 Mdot
.30832 .55945 Mdot
.65207 .36428 Mdot
.30908 .55925 Mdot
.73885 .44135 Mdot
.6582 .45034 Mdot
.4225 .6939 Mdot
.73019 .52919 Mdot
.42463 .66723 Mdot
.47395 .37081 Mdot
.59784 .5829 Mdot
.27426 .42678 Mdot
.26837 .53934 Mdot
.48653 .80844 Mdot
.35198 .36214 Mdot
.46742 .38494 Mdot
.60482 .63078 Mdot
.37366 .70469 Mdot
.32175 .55896 Mdot
.39815 .43211 Mdot
.61282 .61169 Mdot
.61816 .41011 Mdot
.61081 .56684 Mdot
.54856 .56573 Mdot
.46983 .39032 Mdot
.58091 .54065 Mdot
.37478 .36427 Mdot
.60748 .35835 Mdot
.60339 .2696 Mdot
.27757 .54889 Mdot
.57784 .61812 Mdot
.57593 .56422 Mdot
.61937 .33817 Mdot
.5879 .63537 Mdot
.35275 .33341 Mdot
.62107 .88203 Mdot
.40451 .70599 Mdot
.50054 .39251 Mdot
.4543 .1895 Mdot
.59805 .54816 Mdot
.62214 .56109 Mdot
.43427 .42071 Mdot
.81729 .42809 Mdot
.36637 .34552 Mdot
.57947 .51747 Mdot
.32597 .57736 Mdot
.40028 .67973 Mdot
.38633 .37591 Mdot
.62667 .62844 Mdot
.603 .61686 Mdot
.41845 .69977 Mdot
.44393 .74336 Mdot
.41159 .72335 Mdot
.36109 .33361 Mdot
.6437 .46124 Mdot
.32267 .62672 Mdot
.59548 .59355 Mdot
.50803 .36993 Mdot
.62472 .38556 Mdot
.37245 .346 Mdot
.80032 .41513 Mdot
.5977 .51577 Mdot
.3296 .36544 Mdot
.36889 .36894 Mdot
.5829 .63412 Mdot
.58416 .35322 Mdot
.59077 .40298 Mdot
.6231 .38702 Mdot
.5277 .78529 Mdot
.17402 .54079 Mdot
.28371 .56095 Mdot
.36419 .35532 Mdot
.26859 .58375 Mdot
.43429 .69788 Mdot
.4949 .50007 Mdot
.33006 .58032 Mdot
.62805 .41306 Mdot
.27037 .58187 Mdot
.61993 .5662 Mdot
.34394 .373 Mdot
.27229 .57807 Mdot
.63615 .57582 Mdot
.61706 .65827 Mdot
.67821 .64802 Mdot
.4414 .66757 Mdot
.47384 .46618 Mdot
.57766 .59763 Mdot
.49733 .38069 Mdot
.59003 .5786 Mdot
.34776 .33409 Mdot
.39734 .56929 Mdot
.63354 .61137 Mdot
.26716 .54058 Mdot
.18998 .55664 Mdot
.33755 .55003 Mdot
.55173 .60535 Mdot
.57286 .5869 Mdot
.5978 .59384 Mdot
.59891 .6289 Mdot
.62593 .29707 Mdot
.33325 .38014 Mdot
.5325 .60637 Mdot
.2703 .54469 Mdot
.61978 .3668 Mdot
.59846 .37874 Mdot
.4295 .43863 Mdot
.46285 .37931 Mdot
.3381 .34877 Mdot
.59882 .59586 Mdot
.39822 .43378 Mdot
.4892 .43614 Mdot
.53818 .30017 Mdot
.31073 .60311 Mdot
.29909 .58375 Mdot
.64276 .40766 Mdot
.27882 .57629 Mdot
.62397 .62987 Mdot
.63521 .63662 Mdot
.60329 .26619 Mdot
.38864 .38927 Mdot
.40338 .67648 Mdot
.57174 .5996 Mdot
.48057 .72165 Mdot
.32509 .57474 Mdot
.34495 .56754 Mdot
.62273 .57356 Mdot
.60763 .33638 Mdot
.71225 .24885 Mdot
.33632 .35789 Mdot
.67812 .46786 Mdot
.68089 .34164 Mdot
.5874 .48274 Mdot
.35052 .34899 Mdot
.39344 .47777 Mdot
.33846 .54004 Mdot
.68762 .74703 Mdot
.61678 .37262 Mdot
.40507 .67613 Mdot
.64974 .59032 Mdot
.62853 .41289 Mdot
.25981 .5743 Mdot
.65663 .35607 Mdot
.62372 .53035 Mdot
.38543 .34295 Mdot
.30935 .56591 Mdot
.32114 .32741 Mdot
.65847 .34939 Mdot
.42616 .66749 Mdot
.49546 .79213 Mdot
.6869 .485 Mdot
.80951 .48708 Mdot
.62822 .61436 Mdot
.31462 .43688 Mdot
.6189 .61543 Mdot
.61575 .41657 Mdot
.57846 .59032 Mdot
.67469 .6019 Mdot
.33354 .53317 Mdot
.65375 .59569 Mdot
.56457 .58897 Mdot
.7207 .62975 Mdot
.59426 .56853 Mdot
.61068 .62673 Mdot
.59955 .52472 Mdot
.62274 .32262 Mdot
.65175 .58649 Mdot
.6202 .41011 Mdot
.54404 .31943 Mdot
.28441 .54563 Mdot
.43216 .69951 Mdot
.42121 .70696 Mdot
.43493 .75626 Mdot
.47936 .72714 Mdot
.59047 .30955 Mdot
.62537 .35333 Mdot
.36384 .37903 Mdot
.62237 .57026 Mdot
.81831 .55621 Mdot
.62574 .75748 Mdot
.32559 .52982 Mdot
.27792 .58413 Mdot
.64926 .60985 Mdot
.25978 .28611 Mdot
.65268 .59558 Mdot
.50982 .43072 Mdot
.60974 .59695 Mdot
.59067 .52953 Mdot
.3389 .57845 Mdot
.47799 .7652 Mdot
.62873 .61474 Mdot
.65668 .38127 Mdot
.41242 .67267 Mdot
.55693 .49911 Mdot
.60417 .77081 Mdot
.70347 .63364 Mdot
.53825 .66252 Mdot
.63693 .61351 Mdot
.32768 .56859 Mdot
.65184 .38965 Mdot
.51465 .43976 Mdot
.35294 .33486 Mdot
.48801 .45593 Mdot
.71106 .52409 Mdot
.29489 .33457 Mdot
.40791 .67277 Mdot
.3553 .5397 Mdot
.58627 .54732 Mdot
.27906 .55548 Mdot
.58812 .51654 Mdot
.47532 .43048 Mdot
.42736 .68969 Mdot
.66258 .38625 Mdot
.37554 .3545 Mdot
.61348 .41103 Mdot
.80422 .56132 Mdot
.63288 .75663 Mdot
.86517 .5204 Mdot
.32164 .53633 Mdot
.74911 .35567 Mdot
.63584 .39253 Mdot
.61508 .61083 Mdot
.43315 .89889 Mdot
.62924 .38214 Mdot
.62262 .41182 Mdot
.43348 .45407 Mdot
.49812 .77896 Mdot
.65187 .6182 Mdot
.65315 .35526 Mdot
.35651 .55625 Mdot
.4139 .69114 Mdot
.63673 .57955 Mdot
.60784 .51758 Mdot
.60678 .35083 Mdot
.31943 .55564 Mdot
.46222 .74528 Mdot
.30008 .55761 Mdot
.64697 .39308 Mdot
.30365 .54203 Mdot
.56389 .21809 Mdot
.32093 .58435 Mdot
.5632 .58438 Mdot
.59805 .59591 Mdot
.27632 .38026 Mdot
.61177 .37978 Mdot
.62203 .56026 Mdot
.59678 .61716 Mdot
.63517 .39692 Mdot
.25257 .54387 Mdot
.78477 .39427 Mdot
.61806 .55471 Mdot
.59974 .60177 Mdot
.41262 .70682 Mdot
.48245 .48511 Mdot
.49883 .4252 Mdot
.63263 .57149 Mdot
.42183 .65896 Mdot
.65005 .40323 Mdot
.59035 .57669 Mdot
.47651 .76583 Mdot
.25581 .55198 Mdot
.64242 .60453 Mdot
.47365 .37415 Mdot
.60659 .57066 Mdot
.70495 .24878 Mdot
.58885 .62569 Mdot
.62561 .39836 Mdot
.64325 .38468 Mdot
.36846 .5552 Mdot
.62398 .36878 Mdot
.48006 .3938 Mdot
.35571 .3711 Mdot
.67804 .27255 Mdot
.47654 .39226 Mdot
.57355 .54114 Mdot
.66095 .7835 Mdot
.61419 .52179 Mdot
.6463 .55306 Mdot
.47286 .81278 Mdot
.49391 .39344 Mdot
.63151 .38877 Mdot
.44944 .27546 Mdot
.6319 .63385 Mdot
.33658 .35213 Mdot
.65686 .57371 Mdot
.6423 .60538 Mdot
.67863 .62181 Mdot
.64858 .4526 Mdot
.35093 .38539 Mdot
.62111 .67335 Mdot
.63653 .57957 Mdot
.81715 .43017 Mdot
.57815 .5538 Mdot
.39088 .6962 Mdot
.63495 .35162 Mdot
.27406 .56996 Mdot
.42109 .69109 Mdot
.5918 .54696 Mdot
.4043 .68193 Mdot
.2814 .55614 Mdot
.38542 .36236 Mdot
.56455 .57744 Mdot
.41318 .64982 Mdot
.40504 .67281 Mdot
.62412 .5923 Mdot
.64467 .37417 Mdot
.54097 .5558 Mdot
.59188 .57516 Mdot
.61242 .63009 Mdot
.6506 .36209 Mdot
.43113 .84836 Mdot
.60617 .62334 Mdot
.39061 .47624 Mdot
.66423 .39744 Mdot
.47879 .39605 Mdot
.29648 .58089 Mdot
.59099 .65077 Mdot
.34248 .35574 Mdot
.3545 .36828 Mdot
.28926 .52751 Mdot
.61606 .34383 Mdot
.31156 .56333 Mdot
.6701 .63917 Mdot
.63738 .63467 Mdot
.64985 .59176 Mdot
.235 .68697 Mdot
.52237 .20367 Mdot
.61406 .39383 Mdot
.34022 .54782 Mdot
.49631 .45938 Mdot
.33934 .36523 Mdot
.34985 .56284 Mdot
.61692 .42361 Mdot
.63159 .34113 Mdot
.65357 .36433 Mdot
.41238 .66255 Mdot
.30285 .56698 Mdot
.62643 .42838 Mdot
.58764 .39505 Mdot
.62511 .58299 Mdot
.63757 .58396 Mdot
.65488 .33547 Mdot
.30311 .5085 Mdot
.42864 .67698 Mdot
.33242 .56279 Mdot
.65476 .18339 Mdot
.33603 .35723 Mdot
.72094 .63152 Mdot
.63424 .5719 Mdot
.21492 .74918 Mdot
.65127 .5886 Mdot
.57566 .56059 Mdot
.66186 .35879 Mdot
.38167 .70028 Mdot
.41264 .68849 Mdot
.637 .39193 Mdot
.59098 .36124 Mdot
.3971 .67538 Mdot
.42092 .46084 Mdot
.73713 .29084 Mdot
.5076 .44506 Mdot
.62264 .40144 Mdot
.69104 .48439 Mdot
.38596 .3736 Mdot
.65732 .40379 Mdot
.31793 .35351 Mdot
.28381 .54453 Mdot
.29956 .58759 Mdot
.37928 .37417 Mdot
.60923 .62487 Mdot
.31922 .53756 Mdot
.66655 .64616 Mdot
.60057 .25124 Mdot
.28851 .31823 Mdot
.83105 .56913 Mdot
.56295 .60473 Mdot
.50124 .6002 Mdot
.48714 .33391 Mdot
.58605 .53906 Mdot
.60505 .68061 Mdot
.40288 .67916 Mdot
.66358 .39594 Mdot
.38027 .3854 Mdot
.58204 .19516 Mdot
.59651 .59404 Mdot
.63466 .40348 Mdot
.33964 .36945 Mdot
.55707 .22419 Mdot
.403 .50049 Mdot
.61639 .57749 Mdot
.48303 .91196 Mdot
.65494 .3471 Mdot
.27436 .57002 Mdot
.73826 .59101 Mdot
.63214 .41771 Mdot
.27443 .61887 Mdot
.3014 .59661 Mdot
.53895 .45462 Mdot
.64895 .34697 Mdot
.41672 .72044 Mdot
.63761 .36223 Mdot
.39739 .66564 Mdot
.5889 .35931 Mdot
.31173 .54793 Mdot
.58346 .57081 Mdot
.30776 .54838 Mdot
.39218 .70472 Mdot
.31002 .52975 Mdot
.37996 .38549 Mdot
.49891 .38986 Mdot
.35248 .3739 Mdot
.49258 .50913 Mdot
.78069 .42149 Mdot
.37515 .34323 Mdot
.38343 .44712 Mdot
.60285 .5632 Mdot
.61497 .32819 Mdot
.27263 .56387 Mdot
.29057 .52256 Mdot
.48054 .46558 Mdot
.65119 .38025 Mdot
.31689 .54746 Mdot
.68861 .49196 Mdot
.24592 .73988 Mdot
.66005 .628 Mdot
.17009 .51923 Mdot
.6322 .39882 Mdot
.34104 .54048 Mdot
.51491 .42996 Mdot
.59671 .36951 Mdot
.27863 .58224 Mdot
.37824 .3557 Mdot
.34426 .35107 Mdot
.58508 .63361 Mdot
.38201 .33432 Mdot
.34163 .56408 Mdot
.81817 .42432 Mdot
.64182 .35377 Mdot
.50274 .19503 Mdot
.39434 .69618 Mdot
.2818 .54953 Mdot
.65422 .60781 Mdot
.57758 .39163 Mdot
.26381 .57079 Mdot
.27664 .29294 Mdot
.60005 .16456 Mdot
.31746 .54727 Mdot
.63387 .35125 Mdot
.61931 .36221 Mdot
.66147 .6445 Mdot
.50148 .46278 Mdot
.32167 .55484 Mdot
.27263 .42575 Mdot
.48665 .70047 Mdot
.47528 .38642 Mdot
.72337 .70062 Mdot
.62852 .61588 Mdot
.63789 .6124 Mdot
.35695 .33267 Mdot
.58801 .56332 Mdot
.58753 .37738 Mdot
.64922 .58455 Mdot
.35922 .32617 Mdot
.30366 .52633 Mdot
.59692 .58666 Mdot
.39733 .68391 Mdot
.38154 .34341 Mdot
.33831 .32824 Mdot
.29449 .5411 Mdot
.64519 .35273 Mdot
.43354 .28728 Mdot
.30113 .55924 Mdot
.6282 .62574 Mdot
.49371 .38661 Mdot
.6387 .56804 Mdot
.28273 .38962 Mdot
.60312 .40211 Mdot
.27867 .57582 Mdot
.66364 .34854 Mdot
.36614 .36011 Mdot
.31734 .52346 Mdot
.58172 .54624 Mdot
.29799 .58545 Mdot
.378 .48193 Mdot
.27924 .66211 Mdot
.58607 .38203 Mdot
.38212 .57611 Mdot
.61112 .34471 Mdot
.47417 .38548 Mdot
.53245 .74845 Mdot
.42389 .67366 Mdot
.33561 .56473 Mdot
.56273 .20964 Mdot
.27096 .55818 Mdot
.59715 .56972 Mdot
.60658 .61716 Mdot
.31114 .57661 Mdot
.42292 .66333 Mdot
.42974 .77363 Mdot
.44563 .64755 Mdot
.60815 .36267 Mdot
.41513 .53651 Mdot
.687 .21001 Mdot
.27644 .60062 Mdot
.36779 .37817 Mdot
.54986 .66257 Mdot
.60603 .558 Mdot
.34492 .37906 Mdot
.33502 .34261 Mdot
.38617 .69893 Mdot
.27882 .54961 Mdot
.64818 .41833 Mdot
.37879 .38232 Mdot
.58773 .41578 Mdot
.46543 .75517 Mdot
.57948 .51504 Mdot
.61572 .48031 Mdot
.56033 .56924 Mdot
.46207 .46801 Mdot
.36695 .32912 Mdot
.58465 .60179 Mdot
.58804 .66152 Mdot
.36662 .34181 Mdot
.38484 .69231 Mdot
.60341 .44378 Mdot
.31419 .54203 Mdot
.22817 .74149 Mdot
.56452 .57924 Mdot
.58684 .57229 Mdot
.35111 .33696 Mdot
.74593 .63141 Mdot
.61447 .39813 Mdot
.64225 .35067 Mdot
.28751 .56119 Mdot
.45761 .42753 Mdot
.58979 .63654 Mdot
.57 .55915 Mdot
.31939 .5402 Mdot
.49662 .38083 Mdot
.79349 .64987 Mdot
.59558 .60379 Mdot
.35568 .3505 Mdot
.35945 .46251 Mdot
.37501 .33398 Mdot
.56072 .54605 Mdot
.60061 .57292 Mdot
.56751 .5558 Mdot
.56303 .6126 Mdot
.37466 .3806 Mdot
.57901 .54462 Mdot
.56404 .51982 Mdot
.62803 .38821 Mdot
.63351 .61593 Mdot
.4884 .69933 Mdot
.59383 .59886 Mdot
.39756 .68538 Mdot
.48142 .42152 Mdot
.58128 .61995 Mdot
.63374 .61678 Mdot
.4846 .69941 Mdot
.57626 .57201 Mdot
.34159 .37376 Mdot
.61601 .36868 Mdot
.3673 .3589 Mdot
.36697 .37537 Mdot
.26657 .57687 Mdot
.39602 .66466 Mdot
.6082 .65556 Mdot
.39991 .67046 Mdot
.66936 .63093 Mdot
.60731 .51513 Mdot
.48957 .49548 Mdot
.50843 .43162 Mdot
.43855 .69235 Mdot
.5756 .55155 Mdot
.28647 .55589 Mdot
.28171 .57884 Mdot
.39338 .56557 Mdot
.65907 .57225 Mdot
.38425 .38068 Mdot
.38237 .36145 Mdot
.43768 .63618 Mdot
.40796 .6184 Mdot
.40209 .67407 Mdot
.47855 .56998 Mdot
.58079 .52655 Mdot
.59266 .62178 Mdot
.63024 .53054 Mdot
.27656 .59014 Mdot
.5001 .39015 Mdot
.29214 .52941 Mdot
.50836 .40887 Mdot
.39042 .368 Mdot
.56309 .60459 Mdot
.30547 .26442 Mdot
.60262 .36975 Mdot
.61525 .36915 Mdot
.35693 .3252 Mdot
.33861 .55211 Mdot
.64856 .55245 Mdot
.17198 .61298 Mdot
.59242 .3764 Mdot
.43357 .69464 Mdot
.5696 .58433 Mdot
.28914 .5439 Mdot
.61013 .35288 Mdot
.42392 .65076 Mdot
.56024 .59481 Mdot
.32882 .58961 Mdot
.58489 .59448 Mdot
.73405 .49418 Mdot
.63641 .38332 Mdot
.52825 .47995 Mdot
.63889 .32542 Mdot
.36277 .38108 Mdot
.36982 .35068 Mdot
.60235 .58026 Mdot
.1926 .67302 Mdot
.63826 .43801 Mdot
.33315 .37277 Mdot
.4256 .6527 Mdot
.50168 .38572 Mdot
.42065 .65213 Mdot
.30129 .57655 Mdot
.41219 .67161 Mdot
.26407 .56894 Mdot
.2861 .51019 Mdot
.6639 .4092 Mdot
.41545 .7004 Mdot
.74775 .64042 Mdot
.63442 .63748 Mdot
.38919 .70456 Mdot
.65004 .60056 Mdot
.67522 .62436 Mdot
.30979 .53523 Mdot
.40935 .66526 Mdot
.61765 .593 Mdot
.45545 .18519 Mdot
.37402 .36329 Mdot
.38077 .384 Mdot
.63395 .63676 Mdot
.34602 .54654 Mdot
.58678 .36801 Mdot
.45553 .48926 Mdot
.48988 .39748 Mdot
.56951 .56091 Mdot
.5582 .56765 Mdot
.65427 .34317 Mdot
.63643 .40876 Mdot
.6032 .57894 Mdot
.67189 .47279 Mdot
.58778 .54604 Mdot
.34579 .34804 Mdot
.60637 .36489 Mdot
.61642 .3645 Mdot
.33681 .57257 Mdot
.61366 .34569 Mdot
.53261 .57669 Mdot
.39393 .33511 Mdot
.63579 .55102 Mdot
.36336 .35985 Mdot
.34705 .51242 Mdot
.28097 .5398 Mdot
.55952 .20633 Mdot
.61669 .34488 Mdot
.62008 .55364 Mdot
.59905 .37988 Mdot
.40132 .70197 Mdot
.61084 .37686 Mdot
.63946 .33051 Mdot
.57868 .62501 Mdot
.61177 .58569 Mdot
.49436 .3815 Mdot
.49361 .46536 Mdot
.63833 .3765 Mdot
.60093 .54528 Mdot
.6273 .55571 Mdot
.61026 .61607 Mdot
.47658 .49538 Mdot
.66454 .3688 Mdot
.71121 .62101 Mdot
.29114 .37637 Mdot
.64211 .37208 Mdot
.64128 .20317 Mdot
.4894 .37142 Mdot
.46296 .37802 Mdot
.32458 .33889 Mdot
.59921 .60508 Mdot
.31157 .55864 Mdot
.63928 .61176 Mdot
.66512 .58869 Mdot
.5763 .61526 Mdot
.41891 .70053 Mdot
.6018 .63895 Mdot
.47843 .37759 Mdot
.301 .55401 Mdot
.60261 .548 Mdot
.60064 .59271 Mdot
.46714 .37371 Mdot
.64915 .32935 Mdot
.62955 .34154 Mdot
.51031 .36233 Mdot
.3871 .69556 Mdot
.36986 .33446 Mdot
.63354 .62243 Mdot
.28742 .55864 Mdot
.30791 .55266 Mdot
.61631 .41142 Mdot
.32476 .54832 Mdot
.36796 .33195 Mdot
.58001 .55473 Mdot
.36445 .3811 Mdot
.41855 .70075 Mdot
.63561 .35184 Mdot
.62734 .62919 Mdot
.62349 .5844 Mdot
.64306 .38476 Mdot
.60591 .56578 Mdot
.41989 .70213 Mdot
.2935 .59237 Mdot
.60843 .38191 Mdot
.35625 .37033 Mdot
.33303 .57766 Mdot
.62371 .56873 Mdot
.49381 .13428 Mdot
.5885 .5625 Mdot
.56655 .5643 Mdot
.64455 .27216 Mdot
.6112 .53794 Mdot
.27455 .55191 Mdot
.59901 .37053 Mdot
.55487 .56503 Mdot
.48393 .7051 Mdot
.41 .73458 Mdot
.28624 .60023 Mdot
.56847 .58159 Mdot
.62033 .20874 Mdot
.62746 .5603 Mdot
.5824 .21975 Mdot
.4903 .4948 Mdot
.21727 .3781 Mdot
.6167 .48098 Mdot
.33189 .37111 Mdot
.49712 .38322 Mdot
.27357 .5476 Mdot
.7716 .57435 Mdot
.59693 .56274 Mdot
.81406 .47782 Mdot
.63228 .62648 Mdot
.34889 .34959 Mdot
.59182 .67445 Mdot
.33209 .55953 Mdot
.71807 .70047 Mdot
.61849 .62166 Mdot
.65715 .35283 Mdot
.32687 .5248 Mdot
.49847 .37732 Mdot
.61563 .5966 Mdot
.39218 .68546 Mdot
.43959 .71093 Mdot
.53318 .58169 Mdot
.36387 .36244 Mdot
.59352 .61859 Mdot
.62733 .66162 Mdot
.25384 .73649 Mdot
.62336 .39001 Mdot
.37603 .36897 Mdot
.46463 .62653 Mdot
.60842 .61481 Mdot
.63332 .34171 Mdot
.61781 .37065 Mdot
.39318 .67478 Mdot
.42311 .34887 Mdot
.37459 .74058 Mdot
.34102 .21859 Mdot
.8192 .51856 Mdot
.28284 .59269 Mdot
.56328 .37501 Mdot
.63476 .60312 Mdot
.63596 .75677 Mdot
.36269 .37636 Mdot
.5842 .57256 Mdot
.8015 .50892 Mdot
.61847 .38681 Mdot
.58825 .60019 Mdot
.42819 .6788 Mdot
.45309 .3146 Mdot
.69844 .52222 Mdot
.5199 .15194 Mdot
.3561 .55977 Mdot
.65824 .59149 Mdot
.54236 .53919 Mdot
.48049 .39627 Mdot
.55896 .55162 Mdot
.27369 .56066 Mdot
.32477 .44003 Mdot
.43259 .67222 Mdot
.60338 .3667 Mdot
.49311 .3724 Mdot
.63494 .62487 Mdot
.60802 .52456 Mdot
.43622 .68821 Mdot
.61786 .60718 Mdot
.73294 .58737 Mdot
.46809 .36819 Mdot
.31877 .58549 Mdot
.65756 .35818 Mdot
.56069 .5648 Mdot
.50015 .38506 Mdot
.58522 .62848 Mdot
.61877 .69559 Mdot
.57129 .59328 Mdot
.6684 .28057 Mdot
.64682 .37546 Mdot
.36392 .3681 Mdot
.6029 .64047 Mdot
.58905 .58999 Mdot
.32773 .62889 Mdot
.6538 .56108 Mdot
.59301 .6256 Mdot
.62117 .41566 Mdot
.60113 .3734 Mdot
.63542 .40506 Mdot
.33064 .57766 Mdot
.51131 .449 Mdot
.34995 .3578 Mdot
.63511 .53516 Mdot
.38349 .37932 Mdot
.62724 .48747 Mdot
.43592 .66807 Mdot
.54077 .19398 Mdot
.5894 .55368 Mdot
.65374 .37304 Mdot
.75775 .33311 Mdot
.64689 .40634 Mdot
.30747 .36451 Mdot
.36313 .37385 Mdot
.6318 .37948 Mdot
.5738 .57273 Mdot
.51245 .46323 Mdot
.47713 .14651 Mdot
.34074 .36722 Mdot
.64628 .55567 Mdot
.35737 .5621 Mdot
.27739 .53072 Mdot
.67377 .23193 Mdot
.34985 .37818 Mdot
.48134 .33391 Mdot
.61663 .55279 Mdot
.60316 .36106 Mdot
.37962 .34561 Mdot
.33425 .36762 Mdot
.32358 .54476 Mdot
.61902 .57669 Mdot
.5885 .59222 Mdot
.47584 .37242 Mdot
.38431 .37162 Mdot
.64541 .51575 Mdot
.61406 .57417 Mdot
.61354 .2657 Mdot
.62228 .42399 Mdot
.44076 .85082 Mdot
.65128 .66803 Mdot
.80359 .50101 Mdot
.36325 .50732 Mdot
.60814 .38605 Mdot
.61303 .62518 Mdot
.63958 .54116 Mdot
.30126 .59399 Mdot
.58193 .55701 Mdot
.33352 .53835 Mdot
.35593 .38023 Mdot
.54866 .19082 Mdot
.40126 .44089 Mdot
.40458 .34551 Mdot
.59068 .56577 Mdot
.69227 .51574 Mdot
.41379 .69913 Mdot
.38064 .39343 Mdot
.62172 .40634 Mdot
.57313 .53635 Mdot
.27234 .59015 Mdot
.32973 .57704 Mdot
.61956 .37781 Mdot
.53889 .34273 Mdot
.56838 .21089 Mdot
.5602 .60593 Mdot
.2981 .57939 Mdot
.40779 .40914 Mdot
.68975 .41345 Mdot
.32893 .33527 Mdot
.4336 .67568 Mdot
.27588 .54729 Mdot
.39556 .35275 Mdot
.67547 .6184 Mdot
.62796 .37358 Mdot
.65064 .34249 Mdot
.32368 .61488 Mdot
.31745 .55148 Mdot
.41999 .68317 Mdot
.40042 .55302 Mdot
.40495 .55396 Mdot
.42814 .6873 Mdot
.32656 .53013 Mdot
.60401 .38218 Mdot
.63915 .40013 Mdot
.61715 .36759 Mdot
.72473 .63242 Mdot
.5976 .3917 Mdot
.5372 .8192 Mdot
.56648 .54103 Mdot
.68121 .46071 Mdot
.59567 .53807 Mdot
.36786 .38716 Mdot
.63787 .38268 Mdot
.49715 .49096 Mdot
.58894 .5259 Mdot
.49958 .15133 Mdot
.57605 .59648 Mdot
.37413 .46885 Mdot
.59999 .60414 Mdot
.73463 .54982 Mdot
.66266 .39922 Mdot
.57878 .5472 Mdot
.37288 .31691 Mdot
.40098 .68451 Mdot
.67097 .40123 Mdot
.59276 .62442 Mdot
.55162 .29706 Mdot
.64979 .5995 Mdot
.60853 .22575 Mdot
.24177 .61395 Mdot
.41368 .71381 Mdot
.62842 .55209 Mdot
.26018 .56097 Mdot
.52192 .64967 Mdot
.68986 .4725 Mdot
.34147 .36807 Mdot
.68885 .50565 Mdot
.33002 .54993 Mdot
.60882 .68016 Mdot
.55939 .53591 Mdot
.42924 .66591 Mdot
.6102 .44901 Mdot
.34741 .34507 Mdot
.5979 .56138 Mdot
.61308 .62283 Mdot
.26413 .34012 Mdot
.69892 .48507 Mdot
.59863 .5012 Mdot
.44041 .6744 Mdot
.70234 .51972 Mdot
.58085 .61729 Mdot
.28895 .60027 Mdot
.59852 .36484 Mdot
.54593 .64621 Mdot
.71373 .65883 Mdot
.59679 .54448 Mdot
.62785 .38071 Mdot
.61877 .34308 Mdot
.78262 .35039 Mdot
.43233 .66381 Mdot
.572 .59475 Mdot
.30111 .61849 Mdot
.62774 .62683 Mdot
.34723 .35428 Mdot
.5727 .52769 Mdot
.2898 .53668 Mdot
.52143 .42375 Mdot
.33241 .57571 Mdot
.61251 .60361 Mdot
.63695 .35863 Mdot
.35112 .33919 Mdot
.20055 .43532 Mdot
.43159 .37582 Mdot
.5335 .81875 Mdot
.44316 .70821 Mdot
.39674 .67938 Mdot
.41172 .65406 Mdot
.37842 .40313 Mdot
.57015 .57637 Mdot
.4553 .46888 Mdot
.66651 .61855 Mdot
.60253 .6095 Mdot
.57041 .59933 Mdot
.42684 .38187 Mdot
.36318 .37281 Mdot
.30689 .54398 Mdot
.60311 .57725 Mdot
.60028 .54459 Mdot
.63838 .3685 Mdot
.40532 .67222 Mdot
.3005 .59111 Mdot
.39134 .70034 Mdot
.29569 .55404 Mdot
.70183 .24392 Mdot
.5936 .51282 Mdot
.4013 .68654 Mdot
.38124 .33991 Mdot
.64887 .39352 Mdot
.46631 .37707 Mdot
.30272 .57556 Mdot
.33094 .55901 Mdot
.58078 .54264 Mdot
.63207 .34757 Mdot
.63292 .34399 Mdot
.39743 .67546 Mdot
.3818 .35647 Mdot
.56211 .61854 Mdot
.61237 .58071 Mdot
.18956 .46602 Mdot
.30816 .59272 Mdot
.69554 .50511 Mdot
.66687 .28716 Mdot
.56984 .57236 Mdot
.63812 .34383 Mdot
.59338 .5833 Mdot
.36822 .41832 Mdot
.63845 .40544 Mdot
.60305 .53373 Mdot
.67345 .57687 Mdot
.27756 .59013 Mdot
.83731 .43104 Mdot
.60698 .65313 Mdot
.33025 .31016 Mdot
.62867 .59905 Mdot
.87299 .48342 Mdot
.76768 .34686 Mdot
.63088 .62949 Mdot
.56555 .61577 Mdot
.35442 .20189 Mdot
.635 .57058 Mdot
.47834 .37407 Mdot
.66441 .58482 Mdot
.63565 .34168 Mdot
.39409 .49592 Mdot
.47048 .46658 Mdot
.42344 .65616 Mdot
.2866 .56094 Mdot
.48861 .77219 Mdot
.38836 .67885 Mdot
.62762 .39882 Mdot
.60577 .52143 Mdot
.67464 .29978 Mdot
.26661 .53257 Mdot
.54893 .57259 Mdot
.34745 .3525 Mdot
.47023 .46544 Mdot
.28732 .53229 Mdot
.35641 .37174 Mdot
.62604 .55694 Mdot
.2152 .63535 Mdot
.31422 .31038 Mdot
.79108 .35067 Mdot
.35905 .33375 Mdot
.37135 .36374 Mdot
.5195 .45769 Mdot
.42264 .65608 Mdot
.2598 .38293 Mdot
.5288 .5595 Mdot
.33695 .36043 Mdot
.5761 .72389 Mdot
.32799 .58709 Mdot
.47123 .43185 Mdot
.65776 .40471 Mdot
.59651 .51131 Mdot
.57562 .57923 Mdot
.374 .3462 Mdot
.57885 .3416 Mdot
.4318 .61313 Mdot
.34739 .37255 Mdot
.54072 .54626 Mdot
.46937 .42448 Mdot
.49585 .38876 Mdot
.48503 .3697 Mdot
.43057 .65429 Mdot
.30739 .70721 Mdot
.64922 .37094 Mdot
.42899 .69934 Mdot
.54742 .48065 Mdot
.57986 .60549 Mdot
.38372 .37503 Mdot
.47855 .36797 Mdot
.35486 .36661 Mdot
.40852 .6916 Mdot
.43765 .6761 Mdot
.62712 .38869 Mdot
.61284 .39783 Mdot
.69329 .36912 Mdot
.51186 .67658 Mdot
.64054 .60074 Mdot
.79343 .41217 Mdot
.6338 .40861 Mdot
.76109 .60213 Mdot
.40865 .66193 Mdot
.41692 .66637 Mdot
.71763 .43858 Mdot
.62598 .57616 Mdot
.36302 .46471 Mdot
.58367 .6214 Mdot
.56509 .74185 Mdot
.63848 .62244 Mdot
.32218 .54438 Mdot
.62412 .61848 Mdot
.42789 .27398 Mdot
.60718 .55231 Mdot
.5704 .60385 Mdot
.30383 .57081 Mdot
.57524 .63654 Mdot
.29696 .53353 Mdot
.60482 .6249 Mdot
.37872 .69156 Mdot
.28777 .55898 Mdot
.38613 .66322 Mdot
.40294 .47699 Mdot
.48959 .3775 Mdot
.41577 .65433 Mdot
.39277 .68764 Mdot
.46031 .74287 Mdot
.61173 .40235 Mdot
.65835 .67772 Mdot
.57099 .58147 Mdot
.3467 .56482 Mdot
.38652 .35092 Mdot
.59488 .54352 Mdot
.64958 .58315 Mdot
.60229 .6549 Mdot
.62807 .3853 Mdot
.33558 .53555 Mdot
.40624 .68548 Mdot
.28474 .58116 Mdot
.38346 .6727 Mdot
.26675 .55091 Mdot
.63074 .65141 Mdot
.67148 .62607 Mdot
.5596 .52402 Mdot
.80112 .46993 Mdot
.66616 .773 Mdot
.62372 .37441 Mdot
.48826 .38719 Mdot
.43597 .66711 Mdot
.41528 .54083 Mdot
.65157 .36665 Mdot
.32939 .55933 Mdot
.58467 .59429 Mdot
.54751 .53038 Mdot
.55471 .50768 Mdot
.59833 .4216 Mdot
.4033 .64115 Mdot
.29135 .57096 Mdot
.4801 .39161 Mdot
.50332 .44344 Mdot
.65824 .31746 Mdot
.49518 .5031 Mdot
.59161 .58712 Mdot
.39462 .67862 Mdot
.60996 .35309 Mdot
.27551 .39848 Mdot
.37609 .35116 Mdot
.49785 .46389 Mdot
.58869 .56507 Mdot
.52597 .35614 Mdot
.63609 .35862 Mdot
.42685 .66909 Mdot
.37284 .34511 Mdot
.42526 .65871 Mdot
.50112 .37585 Mdot
.51396 .37053 Mdot
.61785 .59986 Mdot
.5901 .6261 Mdot
.39019 .36645 Mdot
.64854 .36824 Mdot
.38627 .72505 Mdot
.26992 .33107 Mdot
.30492 .57719 Mdot
.44505 .43497 Mdot
.60652 .36063 Mdot
.48583 .34603 Mdot
.30269 .58375 Mdot
.39481 .35487 Mdot
.45945 .47079 Mdot
.35213 .3256 Mdot
.57566 .61078 Mdot
.62099 .35444 Mdot
.34754 .37774 Mdot
.19741 .46762 Mdot
.65081 .24281 Mdot
.61561 .43977 Mdot
.60669 .57616 Mdot
.54094 .19182 Mdot
.51909 .30369 Mdot
.57377 .41983 Mdot
.37587 .38275 Mdot
.59809 .57688 Mdot
.55953 .60266 Mdot
.61952 .62109 Mdot
.37591 .36003 Mdot
.37056 .3047 Mdot
.32938 .57102 Mdot
.58654 .60494 Mdot
.39533 .69724 Mdot
.29387 .53697 Mdot
.26471 .54178 Mdot
.27288 .55022 Mdot
.63396 .40937 Mdot
.59685 .51716 Mdot
.52677 .51505 Mdot
.82875 .39352 Mdot
.36829 .36648 Mdot
.48918 .37747 Mdot
.56423 .56895 Mdot
.50191 .80539 Mdot
.64257 .39928 Mdot
.31093 .5735 Mdot
.58557 .5732 Mdot
.26222 .61954 Mdot
.47447 .3644 Mdot
.30113 .56473 Mdot
.62386 .40591 Mdot
.57478 .42228 Mdot
.58223 .55575 Mdot
.63004 .59688 Mdot
.64323 .39245 Mdot
.49211 .31764 Mdot
.50046 .4396 Mdot
.59516 .58596 Mdot
.36143 .37061 Mdot
.22204 .71947 Mdot
.61389 .54328 Mdot
.57745 .36168 Mdot
.5013 .39082 Mdot
.62771 .28895 Mdot
.67898 .48684 Mdot
.65774 .62285 Mdot
.48412 .17061 Mdot
.47443 .79787 Mdot
.5672 .18862 Mdot
.56611 .75335 Mdot
.29413 .3109 Mdot
.74066 .27721 Mdot
.36735 .31516 Mdot
.7319 .53317 Mdot
.26199 .29372 Mdot
.5017 .33206 Mdot
.24741 .63833 Mdot
.22257 .42877 Mdot
.21404 .58776 Mdot
.75256 .68463 Mdot
.26597 .54774 Mdot
.60286 .74883 Mdot
.60226 .63153 Mdot
.4954 .30675 Mdot
.72294 .54781 Mdot
.61662 .80903 Mdot
.5414 .19843 Mdot
.29048 .62009 Mdot
.46086 .13763 Mdot
.54958 .21321 Mdot
.70672 .33378 Mdot
.69285 .67952 Mdot
.33833 .73287 Mdot
.40479 .5571 Mdot
.48962 .78021 Mdot
.68661 .51746 Mdot
.42892 .25979 Mdot
.36462 .312 Mdot
.75419 .38628 Mdot
.28408 .76346 Mdot
.27809 .56871 Mdot
.59857 .36311 Mdot
.25198 .38467 Mdot
.69875 .31327 Mdot
.29915 .33867 Mdot
.48421 .1704 Mdot
.62495 .26285 Mdot
.73277 .54606 Mdot
.53312 .48003 Mdot
.73584 .48317 Mdot
.41158 .77538 Mdot
.6755 .7133 Mdot
.5809 .38394 Mdot
.2208 .46189 Mdot
.40693 .55704 Mdot
.40942 .74784 Mdot
.74402 .57377 Mdot
.42791 .65036 Mdot
.40516 .64977 Mdot
.62875 .40625 Mdot
.69634 .39813 Mdot
.46033 .37572 Mdot
.55327 .48047 Mdot
.26734 .58861 Mdot
.3746 .42225 Mdot
.45819 .30934 Mdot
.53019 .31637 Mdot
.84499 .50326 Mdot
.53033 .14166 Mdot
.50915 .71602 Mdot
.30946 .42587 Mdot
.30443 .33768 Mdot
.47627 .77903 Mdot
.51504 .51894 Mdot
.53085 .70219 Mdot
.63585 .69641 Mdot
.38381 .15793 Mdot
.56643 .28916 Mdot
.4491 .1325 Mdot
.5958 .34664 Mdot
.56933 .65153 Mdot
.32713 .42714 Mdot
.81178 .54252 Mdot
.47428 .70957 Mdot
.52937 .14642 Mdot
.41293 .7167 Mdot
.66253 .40323 Mdot
.50243 .33342 Mdot
.73047 .58214 Mdot
.37015 .71709 Mdot
.45886 .66888 Mdot
.54801 .64739 Mdot
.3782 .14947 Mdot
.47052 .17103 Mdot
.73769 .30864 Mdot
.60981 .26939 Mdot
.24568 .58557 Mdot
.26104 .54703 Mdot
.33606 .37298 Mdot
.6778 .25371 Mdot
.6268 .35699 Mdot
.83512 .3999 Mdot
.65641 .25357 Mdot
.52579 .65741 Mdot
.35953 .16238 Mdot
.79054 .64512 Mdot
.67789 .46258 Mdot
.61046 .78606 Mdot
.19233 .58217 Mdot
.50973 .51744 Mdot
.46217 .34825 Mdot
.34019 .58677 Mdot
.66584 .27413 Mdot
.66426 .23664 Mdot
.59388 .72132 Mdot
.32702 .24949 Mdot
.55891 .48028 Mdot
.36809 .52966 Mdot
.63555 .43535 Mdot
.24973 .65588 Mdot
.4782 .65094 Mdot
.4593 .13304 Mdot
.70782 .53093 Mdot
.20551 .67408 Mdot
.54427 .75399 Mdot
.74361 .63294 Mdot
.47411 .18556 Mdot
.2337 .54707 Mdot
.52439 .67453 Mdot
.55395 .30914 Mdot
.6488 .56471 Mdot
.48407 .56584 Mdot
.61817 .6859 Mdot
.36373 .6575 Mdot
.51591 .44716 Mdot
.55434 .25648 Mdot
.51775 .75283 Mdot
.28788 .30321 Mdot
.69598 .66412 Mdot
.66128 .37579 Mdot
.51488 .69489 Mdot
.53611 .7335 Mdot
.59374 .27011 Mdot
.46644 .62712 Mdot
.73119 .29757 Mdot
.45132 .61829 Mdot
.66328 .61459 Mdot
.73182 .52543 Mdot
.68845 .52349 Mdot
.55477 .72294 Mdot
.61574 .64869 Mdot
.84105 .47865 Mdot
.62308 .27541 Mdot
.78749 .4549 Mdot
.49526 .74957 Mdot
.79687 .46388 Mdot
.67754 .27225 Mdot
.32362 .42089 Mdot
.45309 .3461 Mdot
.56604 .38107 Mdot
.38285 .1488 Mdot
.30195 .53915 Mdot
.56839 .71723 Mdot
.34516 .30846 Mdot
.1976 .45943 Mdot
.25386 .34363 Mdot
.43913 .61334 Mdot
.68973 .26814 Mdot
.52598 .32799 Mdot
.31397 .51475 Mdot
.41186 .24437 Mdot
.42336 .39989 Mdot
.78723 .41497 Mdot
.59313 .65864 Mdot
.58107 .68889 Mdot
.42134 .70155 Mdot
.7846 .5602 Mdot
.2948 .38995 Mdot
.35678 .64591 Mdot
.64705 .63359 Mdot
.35113 .60462 Mdot
.4735 .38679 Mdot
.47305 .45571 Mdot
.69873 .23829 Mdot
.63939 .66489 Mdot
.77842 .65663 Mdot
.51741 .31608 Mdot
.45855 .46352 Mdot
.44069 .74498 Mdot
.60798 .3072 Mdot
.43193 .13266 Mdot
.6967 .26426 Mdot
.51195 .28806 Mdot
.53398 .18745 Mdot
.8202 .64855 Mdot
.22768 .35916 Mdot
.81335 .56833 Mdot
.34628 .30836 Mdot
.60904 .88421 Mdot
.29231 .58376 Mdot
.65397 .75655 Mdot
.80894 .54316 Mdot
.29586 .62949 Mdot
.69779 .31166 Mdot
.70191 .55225 Mdot
.45649 .71121 Mdot
.64484 .32962 Mdot
.62989 .64604 Mdot
.56624 .16505 Mdot
.39707 .14699 Mdot
.5552 .15946 Mdot
.52129 .38761 Mdot
.57816 .18213 Mdot
.35312 .1927 Mdot
.54207 .81958 Mdot
.26236 .35391 Mdot
.5687 .53287 Mdot
.57896 .70888 Mdot
.80227 .62346 Mdot
.44517 .69001 Mdot
.53634 .50025 Mdot
.58114 .39227 Mdot
.34816 .18802 Mdot
.69912 .23676 Mdot
.73599 .442 Mdot
.70998 .36353 Mdot
.37107 .48922 Mdot
.54197 .70177 Mdot
.70629 .31113 Mdot
.43799 .24542 Mdot
.60561 .25137 Mdot
.33552 .20716 Mdot
.53284 .74007 Mdot
.22111 .4356 Mdot
.50521 .27973 Mdot
.80947 .59944 Mdot
.47368 .18219 Mdot
.24636 .3835 Mdot
.51551 .65877 Mdot
.67593 .39856 Mdot
.43361 .61455 Mdot
.42316 .25401 Mdot
.34744 .45313 Mdot
.4901 .73173 Mdot
.31276 .53013 Mdot
.58753 .71782 Mdot
.4548 .52774 Mdot
.26132 .35531 Mdot
.47421 .75586 Mdot
.60612 .72252 Mdot
.53569 .27139 Mdot
.56635 .1708 Mdot
.51814 .31823 Mdot
.18675 .59132 Mdot
.50002 .20524 Mdot
.60383 .68378 Mdot
.58202 .64287 Mdot
.68271 .26961 Mdot
.63432 .18173 Mdot
.69087 .26731 Mdot
.53879 .36592 Mdot
.28049 .61368 Mdot
.38066 .33312 Mdot
.46665 .77022 Mdot
.36705 .61863 Mdot
.61599 .24406 Mdot
.43163 .53426 Mdot
.39932 .36749 Mdot
.45253 .31712 Mdot
.69376 .36024 Mdot
.49296 .7979 Mdot
.74534 .38845 Mdot
.62292 .50543 Mdot
.6843 .42926 Mdot
.65125 .33962 Mdot
.5328 .36271 Mdot
.53971 .70662 Mdot
.29497 .54043 Mdot
.1861 .47684 Mdot
.59073 .33151 Mdot
.58506 .66087 Mdot
.32722 .44533 Mdot
.6299 .43929 Mdot
.80762 .48873 Mdot
.319 .51835 Mdot
.72011 .26106 Mdot
.84029 .50735 Mdot
.70651 .3099 Mdot
.51277 .7039 Mdot
.19466 .48042 Mdot
.48191 .44738 Mdot
.32645 .3195 Mdot
.54096 .20256 Mdot
.42091 .47696 Mdot
.52183 .70423 Mdot
.67521 .4425 Mdot
.27442 .34975 Mdot
.66329 .59003 Mdot
.75233 .32374 Mdot
.53095 .81249 Mdot
.46404 .44612 Mdot
.65849 .30481 Mdot
.59341 .38465 Mdot
.69435 .76458 Mdot
.44019 .27007 Mdot
.50696 .59446 Mdot
.50621 .18303 Mdot
.32731 .34804 Mdot
.65345 .3918 Mdot
.62 .71942 Mdot
.28397 .66074 Mdot
.66376 .43584 Mdot
.36145 .44659 Mdot
.70238 .32518 Mdot
.40681 .45678 Mdot
.52364 .18293 Mdot
.45331 .16069 Mdot
.22541 .71548 Mdot
.60591 .33955 Mdot
.28552 .40693 Mdot
.28162 .40997 Mdot
.58764 .4015 Mdot
.58249 .40195 Mdot
.70094 .52729 Mdot
.61594 .19153 Mdot
.41021 .52369 Mdot
.42837 .23823 Mdot
.45657 .46718 Mdot
.25542 .64612 Mdot
.27117 .36957 Mdot
.48261 .76485 Mdot
.42702 .19076 Mdot
.72551 .37709 Mdot
.15958 .4782 Mdot
.60476 .49485 Mdot
.65941 .75279 Mdot
.4663 .77053 Mdot
.6792 .68445 Mdot
.74507 .56845 Mdot
.58131 .23834 Mdot
.63228 .62118 Mdot
.5492 .14651 Mdot
.56681 .2764 Mdot
.47969 .57855 Mdot
.22858 .55324 Mdot
.62698 .56664 Mdot
.59012 .5193 Mdot
.70324 .30194 Mdot
.64379 .28761 Mdot
.18854 .38458 Mdot
.55468 .74923 Mdot
.57233 .68001 Mdot
.6719 .45715 Mdot
.77878 .65556 Mdot
.34686 .43124 Mdot
.59598 .20896 Mdot
.45332 .5373 Mdot
.81236 .60747 Mdot
.41795 .21892 Mdot
.41014 .25984 Mdot
.49409 .198 Mdot
.3626 .1863 Mdot
.54059 .65252 Mdot
.57722 .32014 Mdot
.25685 .39345 Mdot
.56415 .57391 Mdot
.53974 .34255 Mdot
.50753 .18913 Mdot
.27139 .71602 Mdot
.50577 .5454 Mdot
.62571 .17439 Mdot
.65527 .53778 Mdot
.57313 .31281 Mdot
.25478 .30879 Mdot
.13577 .53132 Mdot
.41858 .269 Mdot
.46697 .13353 Mdot
.40294 .25139 Mdot
.49335 .1785 Mdot
.3264 .36249 Mdot
.41624 .50061 Mdot
.80813 .44171 Mdot
.62263 .19402 Mdot
.3112 .68656 Mdot
.29228 .30578 Mdot
.79066 .39227 Mdot
.613 .18522 Mdot
.66688 .56527 Mdot
.6993 .75482 Mdot
.24422 .56074 Mdot
.81923 .61587 Mdot
.83121 .53957 Mdot
.67028 .31601 Mdot
.58142 .72724 Mdot
.70149 .74395 Mdot
.59303 .81471 Mdot
.82672 .54077 Mdot
.65617 .70068 Mdot
.63716 .29316 Mdot
.50602 .70397 Mdot
.62707 .24183 Mdot
.74467 .69601 Mdot
.27677 .38531 Mdot
.46171 .39689 Mdot
.51405 .37601 Mdot
.67213 .28425 Mdot
.52288 .254 Mdot
.3337 .43834 Mdot
.50411 .42466 Mdot
.69817 .32969 Mdot
.2832 .79923 Mdot
.37574 .24701 Mdot
.63299 .46544 Mdot
.41699 .14366 Mdot
.60207 .25544 Mdot
.4208 .53388 Mdot
.74356 .5878 Mdot
.50095 .79663 Mdot
.25899 .52574 Mdot
.5775 .61675 Mdot
.6052 .18309 Mdot
.29047 .51409 Mdot
.4827 .14264 Mdot
.79725 .35472 Mdot
.7081 .39883 Mdot
.61329 .66391 Mdot
.35112 .57831 Mdot
.6883 .70263 Mdot
.65485 .70779 Mdot
.41179 .1537 Mdot
.66492 .74655 Mdot
.43851 .4477 Mdot
.38853 .46181 Mdot
.39221 .44262 Mdot
.51569 .62735 Mdot
.80481 .62454 Mdot
.61731 .29904 Mdot
.50205 .7622 Mdot
.49481 .28474 Mdot
.56068 .71853 Mdot
.68219 .48977 Mdot
.46346 .76486 Mdot
.46273 .59625 Mdot
.44592 .72683 Mdot
.32051 .58924 Mdot
.32155 .2342 Mdot
.54384 .22115 Mdot
.83863 .46045 Mdot
.18858 .59002 Mdot
.55431 .31213 Mdot
.61877 .74666 Mdot
.28752 .35654 Mdot
.49898 .55149 Mdot
.32817 .71532 Mdot
.52252 .77095 Mdot
.69414 .51105 Mdot
.59136 .22364 Mdot
.69693 .63962 Mdot
.67081 .23695 Mdot
.48902 .73589 Mdot
.28137 .28065 Mdot
.36895 .49198 Mdot
.78894 .53822 Mdot
.69857 .46567 Mdot
.18261 .56042 Mdot
.46346 .44843 Mdot
.37822 .1504 Mdot
.65243 .40197 Mdot
.52577 .14086 Mdot
.36025 .33266 Mdot
.27839 .74431 Mdot
.59707 .24018 Mdot
.47822 .54738 Mdot
.47023 .50334 Mdot
.7698 .33952 Mdot
.50994 .32187 Mdot
.52684 .3105 Mdot
.4383 .6178 Mdot
.28146 .53286 Mdot
.43899 .42322 Mdot
.43493 .23592 Mdot
.32474 .23659 Mdot
.55764 .60805 Mdot
.373 .57016 Mdot
.66986 .70899 Mdot
.31663 .32587 Mdot
.63202 .27607 Mdot
.57371 .22112 Mdot
.64973 .48524 Mdot
.53702 .69833 Mdot
.361 .18304 Mdot
.62747 .2532 Mdot
.42755 .6012 Mdot
.63927 .68367 Mdot
.30604 .31177 Mdot
.19853 .3982 Mdot
.44283 .17633 Mdot
.39238 .45076 Mdot
.49456 .43812 Mdot
.51128 .71791 Mdot
.63853 .16643 Mdot
.39029 .15247 Mdot
.16239 .52841 Mdot
.45332 .46454 Mdot
.63311 .32128 Mdot
.51282 .79241 Mdot
.28301 .27882 Mdot
.82701 .60618 Mdot
.53063 .28471 Mdot
.56863 .71999 Mdot
.25498 .6959 Mdot
.67748 .7554 Mdot
.43276 .4602 Mdot
.69984 .4663 Mdot
.81579 .49914 Mdot
.3152 .3768 Mdot
.26883 .51737 Mdot
.44751 .48651 Mdot
.30031 .31013 Mdot
.63486 .29347 Mdot
.51038 .3237 Mdot
.28029 .28112 Mdot
.67562 .7406 Mdot
.64363 .68234 Mdot
.29547 .28207 Mdot
.65296 .41977 Mdot
.27643 .405 Mdot
.18774 .4476 Mdot
.44399 .47401 Mdot
.27259 .57593 Mdot
.56726 .49823 Mdot
.4592 .42042 Mdot
.40322 .24058 Mdot
.22729 .66282 Mdot
.38558 .70619 Mdot
.58622 .35168 Mdot
.69142 .74384 Mdot
.59935 .34694 Mdot
.68346 .20614 Mdot
.44102 .24398 Mdot
.67761 .44398 Mdot
.40047 .21999 Mdot
.23534 .44022 Mdot
.18546 .60925 Mdot
.70772 .34053 Mdot
.48373 .70278 Mdot
.5959 .34169 Mdot
.63763 .3358 Mdot
.42037 .20764 Mdot
.46514 .35825 Mdot
.70379 .37565 Mdot
.76435 .66993 Mdot
.19465 .48447 Mdot
.58934 .36899 Mdot
.38685 .46652 Mdot
.59571 .43779 Mdot
.7052 .24154 Mdot
.27575 .57576 Mdot
.39118 .14413 Mdot
.65466 .66689 Mdot
.1916 .40308 Mdot
.66019 .27112 Mdot
.52541 .42486 Mdot
.44675 .45551 Mdot
.20373 .46776 Mdot
.66364 .60564 Mdot
.56711 .67806 Mdot
.61491 .40243 Mdot
.26265 .33312 Mdot
.41082 .67054 Mdot
.46133 .64659 Mdot
.34328 .31178 Mdot
.76122 .62877 Mdot
.8249 .58575 Mdot
.64627 .33717 Mdot
.36023 .47783 Mdot
.27733 .41983 Mdot
.67517 .58207 Mdot
.67209 .7024 Mdot
.34082 .21412 Mdot
.70774 .356 Mdot
.65643 .39581 Mdot
.16805 .54205 Mdot
.42674 .63319 Mdot
.73176 .27478 Mdot
.65416 .50048 Mdot
.68338 .70532 Mdot
.68577 .67751 Mdot
.70803 .29798 Mdot
.67891 .4875 Mdot
.6103 .22318 Mdot
.51984 .69754 Mdot
.40914 .61466 Mdot
.60741 .72108 Mdot
.6512 .48532 Mdot
.41351 .44149 Mdot
.80414 .63593 Mdot
.24726 .68934 Mdot
.73538 .49211 Mdot
.51879 .51925 Mdot
.6812 .30715 Mdot
.78244 .65039 Mdot
.5827 .35656 Mdot
.38076 .70991 Mdot
.76201 .39605 Mdot
.59617 .24222 Mdot
.67519 .25086 Mdot
.59249 .27077 Mdot
.6875 .70598 Mdot
.39695 .43943 Mdot
.56063 .78887 Mdot
.66995 .6572 Mdot
.48867 .52764 Mdot
.65113 .58012 Mdot
.58811 .67643 Mdot
.43448 .54925 Mdot
.78003 .35739 Mdot
.53387 .65316 Mdot
.61251 .19464 Mdot
.71988 .26915 Mdot
.55353 .17918 Mdot
.34238 .45362 Mdot
.60269 .34921 Mdot
.41854 .13817 Mdot
.71164 .69305 Mdot
.62897 .24493 Mdot
.82605 .55275 Mdot
.70436 .75964 Mdot
.26025 .29202 Mdot
.56686 .2515 Mdot
.65429 .43235 Mdot
.83667 .42822 Mdot
.56879 .28789 Mdot
.70501 .74736 Mdot
.69674 .51623 Mdot
.6491 .27354 Mdot
.35482 .16971 Mdot
.78949 .59727 Mdot
.53192 .31228 Mdot
.69637 .47099 Mdot
.65481 .472 Mdot
.75085 .6719 Mdot
.61764 .5202 Mdot
.26239 .5559 Mdot
.26087 .62593 Mdot
.57042 .72674 Mdot
.63242 .47633 Mdot
.74441 .68284 Mdot
.65535 .70939 Mdot
.60618 .75133 Mdot
.20132 .4741 Mdot
.26212 .29157 Mdot
.66572 .45163 Mdot
.54419 .53491 Mdot
.57819 .36837 Mdot
.39636 .66501 Mdot
.5431 .76062 Mdot
.61108 .55972 Mdot
.48314 .47708 Mdot
.52954 .62356 Mdot
.58213 .16478 Mdot
.27028 .64563 Mdot
.40388 .36923 Mdot
.59701 .35701 Mdot
.67252 .28605 Mdot
.33844 .41796 Mdot
.50001 .33218 Mdot
.73784 .68522 Mdot
.68672 .3975 Mdot
.51205 .1753 Mdot
.53817 .31681 Mdot
.508 .73639 Mdot
.39659 .76649 Mdot
.36042 .38564 Mdot
.81175 .479 Mdot
.40056 .16211 Mdot
.55028 .32863 Mdot
.65767 .41111 Mdot
.50368 .27165 Mdot
.41372 .44445 Mdot
.55915 .338 Mdot
.51173 .31795 Mdot
.2838 .37916 Mdot
.71111 .42055 Mdot
.44629 .16536 Mdot
.35791 .56032 Mdot
.54621 .74 Mdot
.45747 .26985 Mdot
.75063 .67831 Mdot
.6745 .57592 Mdot
.64418 .22339 Mdot
.47775 .53987 Mdot
.37979 .63552 Mdot
.62272 .59382 Mdot
.71196 .67886 Mdot
.7021 .29758 Mdot
.48549 .28047 Mdot
.50949 .65033 Mdot
.67062 .35561 Mdot
.84283 .50121 Mdot
.23394 .56374 Mdot
.24405 .54151 Mdot
.63102 .77154 Mdot
.54415 .38037 Mdot
.37744 .61602 Mdot
.42723 .34497 Mdot
.66869 .59706 Mdot
.38543 .75719 Mdot
.37405 .45041 Mdot
.81016 .46524 Mdot
.80846 .57733 Mdot
.33206 .22426 Mdot
.35889 .44216 Mdot
.84663 .49969 Mdot
.82001 .47843 Mdot
.65707 .28046 Mdot
.68731 .74031 Mdot
.54849 .49681 Mdot
.61861 .64944 Mdot
.38084 .71012 Mdot
.61776 .42052 Mdot
.35205 .21055 Mdot
.53957 .67731 Mdot
.37298 .65202 Mdot
.47294 .56617 Mdot
.32675 .42915 Mdot
.33471 .49593 Mdot
.62202 .27818 Mdot
.83742 .42932 Mdot
.53802 .70594 Mdot
.31955 .35256 Mdot
.40897 .24268 Mdot
.49943 .56571 Mdot
.62656 .20833 Mdot
.4364 .56777 Mdot
.70046 .3053 Mdot
.49981 .40505 Mdot
.80164 .49937 Mdot
.73914 .2966 Mdot
.48177 .65554 Mdot
.49615 .5089 Mdot
.63964 .30275 Mdot
.53752 .49505 Mdot
.46548 .37756 Mdot
.3032 .6369 Mdot
.70269 .71109 Mdot
.31728 .26125 Mdot
.36791 .30218 Mdot
.64774 .53714 Mdot
.51686 .79099 Mdot
.42545 .17506 Mdot
.41686 .54159 Mdot
.47004 .54547 Mdot
.25483 .39678 Mdot
.29253 .51281 Mdot
.22947 .73371 Mdot
.56304 .15376 Mdot
.62348 .59256 Mdot
.45795 .50563 Mdot
.44935 .64143 Mdot
.33467 .53825 Mdot
.74078 .38035 Mdot
.35105 .20752 Mdot
.34299 .37401 Mdot
.2018 .52891 Mdot
.42692 .34597 Mdot
.77459 .34624 Mdot
.16731 .50076 Mdot
.39562 .38292 Mdot
.68043 .20257 Mdot
.52351 .28999 Mdot
.57612 .33989 Mdot
.24185 .75287 Mdot
.76131 .33787 Mdot
.64992 .68686 Mdot
.24426 .59823 Mdot
.5822 .16977 Mdot
.4484 .45383 Mdot
.30786 .61503 Mdot
.79668 .58676 Mdot
.5321 .70427 Mdot
.55136 .74641 Mdot
.43726 .35874 Mdot
.816 .4242 Mdot
.66387 .79451 Mdot
.23739 .43906 Mdot
.17196 .58462 Mdot
.70649 .38472 Mdot
.47467 .1551 Mdot
.41945 .26711 Mdot
.27592 .71337 Mdot
.67299 .25306 Mdot
.61226 .71275 Mdot
.74874 .65557 Mdot
.29552 .68472 Mdot
.4788 .66931 Mdot
.51017 .79967 Mdot
.52396 .39527 Mdot
.71293 .35231 Mdot
.21053 .47054 Mdot
.50046 .63696 Mdot
.59741 .71975 Mdot
.81024 .51503 Mdot
.49436 .51266 Mdot
.43016 .15387 Mdot
.72914 .68405 Mdot
.5193 .71101 Mdot
.22861 .40303 Mdot
.40304 .6501 Mdot
.37147 .20016 Mdot
.38248 .4134 Mdot
.65749 .68445 Mdot
.23935 .32003 Mdot
.45875 .13353 Mdot
.54759 .49691 Mdot
.57867 .52674 Mdot
.74362 .28021 Mdot
.38755 .55065 Mdot
.81294 .56628 Mdot
.45947 .30211 Mdot
.56412 .74869 Mdot
.52585 .6314 Mdot
.64753 .60973 Mdot
.58309 .79323 Mdot
.68396 .38245 Mdot
.81278 .51044 Mdot
.17621 .48249 Mdot
.51728 .70587 Mdot
.73167 .65901 Mdot
.16152 .47328 Mdot
.65862 .50313 Mdot
.63832 .34127 Mdot
.58166 .16766 Mdot
.75031 .35651 Mdot
.61581 .68861 Mdot
.68655 .44676 Mdot
.43308 .58108 Mdot
.37046 .73548 Mdot
.64781 .67971 Mdot
.48007 .44814 Mdot
.57855 .72857 Mdot
.285 .28348 Mdot
.80495 .42827 Mdot
.37375 .14937 Mdot
.6972 .26948 Mdot
.59515 .35319 Mdot
.79874 .57485 Mdot
.43976 .47501 Mdot
.5424 .17681 Mdot
.21017 .45082 Mdot
.19213 .46999 Mdot
.64062 .80078 Mdot
.46007 .65151 Mdot
.61534 .63347 Mdot
.5212 .38867 Mdot
.67638 .24526 Mdot
.65988 .78769 Mdot
.66792 .23639 Mdot
.5682 .66837 Mdot
.58821 .64715 Mdot
.13295 .55363 Mdot
.50665 .17958 Mdot
.65445 .64516 Mdot
.5144 .56473 Mdot
.50993 .60811 Mdot
.60303 .62905 Mdot
.48439 .35466 Mdot
.48989 .78802 Mdot
.57263 .74296 Mdot
.61229 .19166 Mdot
.59255 .3925 Mdot
.45285 .45435 Mdot
.38394 .38828 Mdot
.47507 .48439 Mdot
.62215 .48124 Mdot
.32815 .35269 Mdot
.59279 .74217 Mdot
.37328 .52596 Mdot
.37626 .72839 Mdot
.6895 .37263 Mdot
.52855 .40455 Mdot
.69356 .33913 Mdot
.646 .74253 Mdot
.47596 .34934 Mdot
.58763 .81762 Mdot
.65296 .71176 Mdot
.6736 .66504 Mdot
.60855 .28409 Mdot
.80241 .66754 Mdot
.45605 .44814 Mdot
.52397 .36534 Mdot
.66409 .53351 Mdot
.71419 .60452 Mdot
.69886 .42902 Mdot
.44675 .70046 Mdot
.47452 .39143 Mdot
.58244 .67118 Mdot
.69635 .30585 Mdot
.34965 .32341 Mdot
.63385 .16958 Mdot
.60279 .65867 Mdot
.73803 .39838 Mdot
.62443 .22021 Mdot
.27512 .39484 Mdot
.69157 .51128 Mdot
.64669 .57247 Mdot
.41391 .59795 Mdot
.37536 .53033 Mdot
.57674 .4058 Mdot
.26883 .36336 Mdot
.48233 .16601 Mdot
.65013 .7519 Mdot
.72443 .39423 Mdot
.57304 .5916 Mdot
.39938 .7188 Mdot
.48451 .457 Mdot
.27444 .69961 Mdot
.37027 .54476 Mdot
.61287 .25834 Mdot
.63616 .74324 Mdot
.55356 .74959 Mdot
.69933 .48905 Mdot
.50158 .14228 Mdot
.50926 .5441 Mdot
.70425 .40499 Mdot
.45945 .5824 Mdot
.53053 .254 Mdot
.65332 .70452 Mdot
.30347 .27984 Mdot
.55449 .66642 Mdot
.54696 .50319 Mdot
.67492 .21553 Mdot
.70813 .3352 Mdot
.40232 .33536 Mdot
.59298 .22248 Mdot
.70876 .70685 Mdot
.4699 .50508 Mdot
.25458 .77053 Mdot
.2073 .45004 Mdot
.66686 .19467 Mdot
.27714 .33117 Mdot
.68887 .61499 Mdot
.60993 .30525 Mdot
.63305 .64438 Mdot
.30863 .56146 Mdot
.52418 .16869 Mdot
.6447 .30368 Mdot
.55708 .48535 Mdot
.58583 .51749 Mdot
.39931 .53987 Mdot
.57574 .39685 Mdot
.30957 .26589 Mdot
.27884 .52912 Mdot
.42886 .59763 Mdot
.2947 .29898 Mdot
.3747 .53017 Mdot
.72045 .7482 Mdot
.41538 .15143 Mdot
.54489 .20407 Mdot
.38013 .45128 Mdot
.24189 .72011 Mdot
.61201 .32406 Mdot
.59922 .42435 Mdot
.34888 .31532 Mdot
.56603 .79214 Mdot
.55503 .33365 Mdot
.2802 .29237 Mdot
.70577 .28754 Mdot
.67541 .57949 Mdot
.30717 .82557 Mdot
.62109 .71495 Mdot
.4194 .5603 Mdot
.54429 .34917 Mdot
.62389 .19914 Mdot
.21886 .57855 Mdot
.79245 .35242 Mdot
.4331 .25985 Mdot
.63172 .47818 Mdot
.54637 .81031 Mdot
.16992 .54166 Mdot
.3774 .46317 Mdot
.17238 .58763 Mdot
.4845 .18628 Mdot
.48935 .77967 Mdot
.47604 .28054 Mdot
.60946 .33582 Mdot
.55648 .67321 Mdot
.44596 .23849 Mdot
.53566 .50232 Mdot
.58134 .33715 Mdot
.47696 .1709 Mdot
.43601 .78443 Mdot
.22308 .39258 Mdot
.54217 .18854 Mdot
.31789 .32198 Mdot
.65984 .31439 Mdot
.64903 .71957 Mdot
.37523 .56915 Mdot
.32521 .53789 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0R_ooool2o`000;gooooo000Looooo`03o`00
0?oooooooooo08Cooooo0_l00003ooooo`?o00000_ooool2o`000004ooooool0003o0000ooooo`;o
00001oooool2o`000:[ooooo000Looooo`03o`000?oooooooooo08Cooooo0_l00003ooooo`;o0000
0oooool2o`000003ooooool0003o000000?o00001oooool2o`000:[ooooo000Looooo`03o`000?oo
oooooooo08Cooooo0_l0000<ooooo`;o00004oooool2o`0000Sooooo0_l0002Fooooo`007?ooool0
0ol0003oooooooooo`1kooooo`;o00001oooool2o`0001?ooooo0_l00004ooooo`;o00001_ooool4
o`0000Kooooo0_l0002Fooooo`007?ooool00ol0003oooooooooo`1kooooo`Co00001Oooool2o`00
017ooooo1?l00004ooooo`;o00001oooool3o`0000Cooooo0_l0002Hooooo`007?ooool00ol0003o
ooooooooo`1fooooo`Go00000_ooool2o`0001Sooooo0_l0000?ooooo`;o00001Oooool2o`0009So
oooo000Looooo`;o0000Moooool7o`0000Gooooo0ol0000Jooooo`;o00001?ooool2o`0000cooooo
0_l0002Dooooo`007?ooool00ol0003oooooooooo`1kooooo`;o00001Oooool3o`0000?ooooo0_l0
00000ooooooo0000o`000003ooooo`;o00001?ooool2o`0000Oooooo0_l00004ooooo`;o00003?oo
ool2o`0009Cooooo000Looooo`03o`000?oooooooooo07Wooooo0_l0000=ooooo`;o000000?ooooo
o`000?l000000oooool2o`0000Cooooo0_l00005ooooo`;o00003_ooool2o`0000;ooooo0_l0002F
ooooo`007?ooool00ol0003oooooooooo`1aooooo`;o00001_ooool2o`0000?ooooo0_l0000?oooo
o`;o00003?ooool2o`0000kooooo0_l00002ooooo`;o0000U_ooool001cooooo00?o0000oooooooo
ool0LOooool2o`0000_ooooo0_l0000=ooooo`Co00002?ooool2o`000003ooooool0003o000001Ko
oooo0_l00003ooooo`;o00001?ooool2o`0000Sooooo0_l0001nooooo`007?ooool00ol0003ooooo
ooooo`2=ooooo`;o00002_ooool2o`000003ooooool0003o000000Wooooo0_l0000;ooooo`;o0000
0oooool2o`0000Cooooo0_l00008ooooo`;o000000?oooooo`000?l00000Noooool001cooooo00?o
0000ooooooooool0L?ooool2o`0002?ooooo1?l000000ooooooo0000o`00000;ooooo`;o00001_oo
ool2o`0000?ooooo0_l00003ooooo`;o00003oooool4o`0007_ooooo000Looooo`03o`000?oooooo
oooo073ooooo0_l0000Dooooo`;o00003Oooool4o`000003ooooool0003o000000Oooooo0_l00002
ooooo`;o00001_ooool2o`0000?ooooo0_l00003ooooo`;o00003?ooool2o`000003ooooool0003o
000007gooooo000Looooo`03o`000?oooooooooo08Kooooo0_l00004ooooo`;o00005Oooool2o`00
00Oooooo0_l0000Iooooo`;o0000P?ooool001cooooo00?o0000ooooooooool0S?ooool2o`0000ko
oooo0_l00003ooooo`;o00000oooool2o`0000Cooooo0_l00002ooooo`;o00001Oooool2o`00093o
oooo000Looooo`03o`000?oooooooooo06[ooooo0_l00006ooooo`;o00008_ooool2o`0000Cooooo
0_l00003ooooo`;o00000oooool2o`0000Sooooo0_l00005ooooo`?o00001oooool2o`0000Oooooo
0_l00005ooooo`;o0000M_ooool001cooooo00?o0000ooooooooool0J_ooool2o`0000Kooooo0_l0
000Looooo`;o00001?ooool2o`0000;ooooo0_l00005ooooo`;o00000oooool2o`0000;ooooo0_l0
000;ooooo`?o00001oooool4o`0000Gooooo0_l00005ooooo`;o0000M_ooool001cooooo00?o0000
ooooooooool0KOooool2o`0000?ooooo0_l0000Cooooo`;o00001oooool2o`0000Cooooo0_l00002
ooooo`;o00001Oooool2o`0000Oooooo1?l00006ooooo`;o000000?oooooo`000?l000002_ooool2
o`0008Cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_oo
ool00ol0003oooooooooo`1]ooooo`Co00005_ooool2o`0000Oooooo0_l0000?ooooo`;o00002Ooo
ool4o`0000Cooooo0_l00009ooooo`;o00000_ooool3o`0008?ooooo00001_ooooooMgMgoiRHV?oo
ooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`1_ooooo`;o0000:_ooool2o`0000?ooooo0_l00003ooooo`;o00001Oooool4o`0000Wo
oooo0_l00004ooooo`;o00000_ooool5o`0000gooooo0_l0001booooo`0000?ooooooa0@4?ooool0
0_ooool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0
Voooool4o`000003ooooool0003o000000?ooooo0_l00005ooooo`Co00002Oooool4o`0000Kooooo
0_l000001?oooooo0000o`000?l0000<ooooo`;o0000L_ooool00003ooooool0003ooooo00;ooooo
00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06ooooo`?o0000Koooool2o`0000Cooooo
0_l0000Vooooo`;o00003Oooool4o`0000_ooooo0_l0000:ooooo`;o00004?ooool2o`0006kooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Ooo
ool00ol0003oooooooooo`1_ooooo`;o00001?ooool2o`0002Sooooo0_l00005ooooo`;o00001?oo
ool4o`0000;ooooo0ol0000;ooooo`;o00002oooool2o`0000[ooooo0ol0001]ooooo`0000?ooooo
oa0@4?ooool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0JOooool2o`0000?ooooo0_l0000Eooooo`;o00006?ooool2o`0000Gooooo0_l00005
ooooo`?o00000_ooool5o`0000Oooooo1?l00004ooooo`Co00000oooool2o`0000_ooooo0_l0001]
ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
1_ooool00ol0003oooooooooo`1Yooooo`;o00000oooool3o`0001Cooooo0_l0000Qooooo`;o0000
1oooool7o`0000Kooooo0_l00006ooooo`Co00004Oooool2o`0006cooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo
06_ooooo0_l00002ooooo`;o0000=oooool2o`0000Gooooo2_l0000;ooooo`;o00005Oooool2o`00
06cooooo000Looooo`03o`000?oooooooooo06_ooooo0_l0000Eooooo`;o0000:oooool2o`0000;o
oooo0_l00002ooooo`;o00002oooool3o`00013ooooo0_l0001`ooooo`007?ooool00ol0003ooooo
ooooo`1[ooooo`;o00004Oooool2o`0000;ooooo1?l0000Wooooo`;o00001?ooool9o`0000Wooooo
1?l000000ooooooo0000o`00000;ooooo`;o0000L?ooool001cooooo00?o0000ooooooooool0J?oo
ool2o`000003ooooool0003o0000017ooooo0_l00002ooooo`Co00009oooool2o`000005ooooool0
003o0000o`000?ooool02ol00003ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`;o
0000N_ooool001cooooo00?o0000ooooooooool0Ioooool3o`0001Kooooo1?l0000/ooooo`?o0000
00?oooooo`000?l000000_l00004ooooo`Go000000?oooooo`000?l000001Oooool2o`0000;ooooo
0_l0001jooooo`007?ooool00ol0003oooooooooo`1Wooooo`;o00005oooool2o`0003;ooooo0_l0
0009ooooo`;o000000?oooooo`000?l000001Oooool3o`0007gooooo000Looooo`03o`000?oooooo
oooo087ooooo0_l0000Xooooo`;o00007Oooool2o`0000_ooooo0_l0001`ooooo`007?ooool00ol0
003oooooooooo`1Uooooo`?o00006Oooool2o`0000Oooooo0_l0000Oooooo`;o00009oooool6o`00
00Gooooo0_l0001Xooooo`007?ooool00ol0003oooooooooo`1Uooooo`?o00005Oooool2o`0000So
oooo0_l000001?oooooo0000o`000?ooool2o`0001oooooo0_l00009ooooo`;o00006Oooool6o`00
00Gooooo0_l0001Xooooo`007?ooool00ol0003oooooooooo`1looooo`Oo00001?ooool2o`0000Co
oooo0_l0000Oooooo`;o00002Oooool2o`0000?ooooo0_l00002ooooo`;o00001?ooool2o`0000Ko
oooo0_l0000=ooooo`Co0000I_ooool001cooooo00?o0000ooooooooool0O?ooool8o`0000Oooooo
0ol0000`ooooo`;o00000_ooool9o`0000Gooooo0_l00006ooooo`;o00001_ooool3o`0006Kooooo
000Looooo`03o`000?oooooooooo07Kooooo0_l0000:ooooo`;o00001oooool3o`0003Kooooo1?l0
00000ooooooo0000o`00000=ooooo`;o00001_ooool3o`000003ooooool0003o000006?ooooo000L
ooooo`;o0000J?ooool2o`0000gooooo1?l00005ooooo`;o0000<oooool2o`0000Wooooo1?l00002
ooooo`;o00004Oooool2o`0000Oooooo0_l000000ooooooo0000o`00001Sooooo`007?ooool00ol0
003oooooooooo`1Wooooo`;o00003oooool3o`000004ooooool0003o0000ooooo`;o00001Oooool2
o`0001gooooo0ol000000ooooooo0000o`000003ooooo`;o00001?ooool4o`0000Oooooo1?l00002
ooooo`;o000000?oooooo`000?l000001oooool2o`0000Cooooo0ol0001_ooooo`007?ooool00ol0
003oooooooooo`1iooooo`;o000000?oooooo`000?l000002?ooool2o`0001gooooo0ol000000ooo
oooo0000o`000003ooooo`Co00001?ooool2o`0000Kooooo1?l000000ooooooo0000o`000003oooo
o`;o00001oooool2o`0000Cooooo0ol0001_ooooo`007?ooool00ol0003oooooooooo`1Sooooo`;o
00007?ooool2o`0000Gooooo0ol0000Uooooo`;o00003?ooool2o`0000?ooooo0_l00002ooooo`;o
00007Oooool2o`00067ooooo000Looooo`03o`000?oooooooooo063ooooo0_l000000ooooooo0000
o`00000Looooo`;o00001Oooool3o`0003Gooooo0ol00002ooooo`Co00005Oooool3o`0000Gooooo
0_l0001Qooooo`007?ooool00ol0003oooooooooo`1Oooooo`Co00008_ooool2o`0003Wooooo0ol0
00000ooooooo0000o`000003o`0001Cooooo1?l0001Xooooo`007?ooool00ol0003oooooooooo`1O
ooooo`Co00008Oooool3o`0000Cooooo0_l00004ooooo`;o00009_ooool2o`0000;ooooo0_l00000
0ooooooo0000o`000004o`0000Wooooo1?l00004ooooo`;o000000?oooooo`000?l000001Ol00005
ooooo`;o0000HOooool001cooooo00?o0000ooooooooool0Q?ooool5o`0000;ooooo0_l00004oooo
o`;o00003Oooool2o`0000Sooooo0_l0000=ooooo`;o00000_ooool2o`000003ooooool0003o0000
00;o00002_ooool7o`0000;ooooo1ol000000ooooooo0000o`000005ooooo`;o0000HOooool001co
oooo00?o0000ooooooooool0E_ooool2o`0002[ooooo0_l00003ooooo`;o00001Oooool2o`00013o
oooo0_l00008ooooo`;o00002?ooool2o`0000?ooooo0_l00004ooooo`;o00001_ooool5o`0000;o
oooo0ol00002ooooo`?o00000_ooool3o`0000oooooo0_l0001Mooooo`007?ooool00ol0003ooooo
ooooo`1Fooooo`Co00001Oooool2o`00027ooooo1?l00008ooooo`;o00004?ooool2o`0001;ooooo
0_l00003ooooo`;o00001?ooool2o`0000Gooooo1_l00008ooooo`;o00000_ooool3o`0000oooooo
0_l000000ooooooo0000o`00001Jooooo`007?ooool00ol0003oooooooooo`1Gooooo`?o00000_oo
ool2o`000003ooooool0003o000002?ooooo0_l00008ooooo`;o00000_ooool4o`000004ooooool0
003o0000ooooo`;o00001?ooool2o`0002Cooooo0_l0000:ooooo`;o000000Coooooo`000?l0003o
oooo0_l0000Cooooo`?o0000FOooool001cooooo00?o0000ooooooooool0DOooool2o`0000;ooooo
1_l000000ooooooo0000o`00000dooooo`Co000000?oooooo`000?l000000ol000000ooooooo0000
o`000004ooooo`;o00001?ooool2o`0001Oooooo0_l0000>ooooo`;o000000?oooooo`000?l00000
0_l0000Eooooo`;o0000FOooool001cooooo00?o0000ooooooooool0Coooool4o`0000;ooooo0ol0
00000ooooooo0000o`00000^ooooo`;o00001oooool2o`0000Cooooo0_l00003ooooo`;o00001?oo
ool2o`0000Cooooo0_l00009ooooo`?o00002_ooool3o`0000Cooooo0_l00003ooooo`;o00001_oo
ool6o`0000Kooooo0_l0001Vooooo`007?ooool00ol0003oooooooooo`1?ooooo`Co00001?ooool2
o`0000Oooooo0_l0000Wooooo`;o00006?ooool2o`000003ooooool0003o000000Cooooo0_l00006
ooooo`?o00002_ooool4o`0000?ooooo0_l00003ooooo`;o00001_ooool2o`0000;ooooo0_l00006
ooooo`;o00002Oooool2o`0005_ooooo000Looooo`03o`000?oooooooooo057ooooo0_l00003oooo
o`?o00001?ooool2o`000003ooooool0003o000000_ooooo0_l0000gooooo`;o00001?ooool2o`00
01Gooooo0_l00005ooooo`?o00007oooool2o`0000?ooooo0_l0001Fooooo`007?ooool00ol0003o
ooooooooo`1=ooooo`;o00000_ooool2o`0000?ooooo0_l00005ooooo`;o00002oooool2o`000004
ooooool0003o0000o`0003Kooooo1?l00004ooooo`?o00005oooool5o`0000_ooooo1?l00004oooo
o`Co00001_ooool4o`0000?ooooo0_l0001Fooooo`007?ooool2o`0004kooooo0_l0000=ooooo`;o
00003?ooool2o`0000;ooooo0_l0000Qooooo`;o00004oooool7o`000004ooooool0003o0000o`00
00cooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000gooooo1Ol00004oooo
o`Co00001_ooool4o`0005_ooooo000Looooo`03o`000?oooooooooo05[ooooo1?l0000Fooooo`?o
00006_ooool3o`00017ooooo0_l00002ooooo`Co00000_ooool2o`0000cooooo0ol000000ooooooo
0000o`000002ooooo`;o00001Oooool4o`0000Oooooo0_l00008ooooo`;o0000I_ooool001cooooo
00?o0000ooooooooool0F_ooool3o`0000oooooo0_l00005ooooo`Go00006Oooool3o`0000Wooooo
0_l00006ooooo`?o000000Coooooo`000?l0003o00000oooool2o`0000gooooo1_l00007ooooo`Go
00000_ooool2o`0000?ooooo1?l00003ooooo`Go00002oooool2o`0000?ooooo0_l0001Dooooo`00
7?ooool00ol0003oooooooooo`15ooooo`;o00002?ooool2o`0000[ooooo1Ol00002ooooo`Co0000
0_ooool2o`0000;ooooo1Ol00002ooooo`;o000000?oooooo`000?l000006Oooool2o`0000[ooooo
0_l00004ooooo`Wo00000oooool3o`0000[ooooo0_l00002ooooo`Co00001oooool4o`0000;ooooo
0ol00005ooooo`;o00000oooool6o`0000Sooooo1?l00003ooooo`;o0000E?ooool001cooooo00?o
0000ooooooooool0AOooool2o`0000Sooooo0_l0000;ooooo`[o00000_ooool2o`0000;ooooo1_l0
00000ooooooo0000o`000002ooooo`;o00006?ooool2o`00013ooooo0_l000000ooooooo0000o`00
0003o`0000?ooooo1?l00004ooooo`;o00001?ooool2o`0000;ooooo0_l0000;ooooo`;o00000_oo
ool2o`0000Sooooo0_l00002ooooo`;o000000?oooooo`000?l000002?ooool2o`0005_ooooo000L
ooooo`03o`000?oooooooooo05;ooooo0_l0000<ooooo`?o00002Oooool6o`000003ooooool0003o
000000Co00005_ooool2o`0001?ooooo0_l00002ooooo`Go000000?oooooo`000?l000000_l00004
ooooo`;o00006oooool2o`000004ooooool0003o0000ooooo`Co00000_ooool2o`000003ooooool0
003o000000_ooooo0ol0001Gooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o00001_ooool2
o`0000Kooooo0_l0000:ooooo`;o000000?oooooo`000?l000001ol00002ooooo`?o00005oooool3
o`0000_ooooo0_l00004ooooo`Go000000Coooooo`000?l0003ooooo1_l00007ooooo`;o00006?oo
ool3o`000004ooooool0003o0000ooooo`;o00003oooool4o`000004ooooool0003o0000o`0005Oo
oooo000Looooo`03o`000?oooooooooo04[ooooo1?l00009ooooo`;o000000?oooooo`000?l00000
2?ooool:o`000004ooooool0003o0000o`0000;ooooo0_l00002ooooo`;o00005?ooool3o`0000_o
oooo0_l00004ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Wooooo0_l0000=ooooo`;o
000000?oooooo`000?l000001_ooool2o`0000Kooooo0_l0000>ooooo`Co0000Foooool001cooooo
00?o0000ooooooooool0C?ooool2o`0000?ooooo0_l00004ooooo`;o00002_ooool3o`0000;ooooo
2ol000000ooooooo0000o`000002ooooo`;o00001?ooool2o`0000[ooooo0_l0000Fooooo`;o0000
1?ooool2o`0000?ooooo0_l0000=ooooo`Co00000oooool2o`000005ooooool0003o0000o`000?oo
ool01?l0000<ooooo`;o00001?ooool2o`0000kooooo0ol00003ooooo`;o0000DOooool001cooooo
00?o0000ooooooooool0C_ooool5o`00013ooooo1?l00002ooooo`go000000?oooooo`000?l00000
0_l00003ooooo`;o00002_ooool2o`0001Kooooo0_l00003ooooo`?o00000_ooool2o`000003oooo
ool0003o000000_ooooo1?l00003ooooo`Go00000_ooool7o`0000Wooooo0_l00004ooooo`;o0000
3_ooool3o`0000?ooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`1>ooooo`Co00000_oo
ool4o`0000?ooooo0_l00008ooooo`?o000000?oooooo`000?l000004?l00005ooooo`;o00007Ooo
ool2o`0000Kooooo0_l000000ooooooo0000o`000005o`0000_ooooo0_l00004ooooo`Co00000_oo
ool2o`0000;ooooo1Ol0000>ooooo`;o0000J?ooool001cooooo00?o0000ooooooooool0D_ooool6
o`0000?ooooo1?l00003ooooo`;o00000_oooolDo`0000;ooooo0_l000001?oooooo0000o`000?l0
000Gooooo`?o00000oooool2o`0000Wooooo0_l00002ooooo`;o000000?oooooo`000?l000001Ooo
ool2o`0000;ooooo0_l00004ooooo`;o00000oooool4o`000003ooooool0003o000000Go00003?oo
ool2o`000003ooooool0003o000000kooooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`1B
ooooo`;o00002?ooool5o`000003ooooool0003o000000?ooooo4ol00002ooooo`Go00006?ooool3
o`0000?ooooo0_l00009ooooo`;o00001Oooool4o`0000?ooooo0ol00007ooooo`_o000000?ooooo
o`000?l000000ol00009ooooo`;o00001?ooool2o`0000kooooo0ol0001Dooooo`007?ooool00ol0
003oooooooooo`1Booooo`;o00002Oooool4o`0000Gooooo3ol000000ooooooo0000o`000002o`00
00;ooooo1Ol0000Yooooo`;o00001_ooool3o`0000;ooooo1?l00003ooooo`;o000000?oooooo`00
0?l000003ol000000ooooooo0000o`000004ooooo`;o000000Coooooo`000?l0003o00000oooool2
o`0000oooooo0_l000000ooooooo0000o`00001Aooooo`007?ooool00ol0003oooooooooo`1?oooo
o`Go00002Oooool2o`0000Oooooo3ol000000ooooooo0000o`000003o`000003ooooool0003o0000
00?o00002Oooool2o`0001oooooo1?l00008ooooo`?o000000Coooooo`000?l0003ooooo4?l00000
0ooooooo0000o`000004o`0000Cooooo0_l00002ooooo`;o00000oooool2o`0001;ooooo0_l0001A
ooooo`007?ooool00ol0003oooooooooo`18ooooo`;o00001?ooool5o`0000Wooooo0_l00005oooo
oaSo000000Goooooo`000?l0003o0000ooooo`03o`0000?ooooo0ol000000ooooooo0000o`000003
ooooo`?o00002?ooool2o`0000oooooo1?l0000:ooooo`Co000000?oooooo`000?l000005_l0000P
ooooo`Co0000Coooool001cooooo0_l00019ooooo`;o00001?ooool2o`0000Gooooo0_l00005oooo
o`;o00001Oooool3o`000003ooooool0003o000001Go00000_ooool3o`0000?ooooo0ol00005oooo
o`So000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00001Oooool2o`0000;ooooo0_l00000
1?oooooo0000o`000?l0000:ooooo`;o00000ooooolHo`0000Cooooo0_l0000Jooooo`Ko000000?o
ooooo`000?l00000B_ooool001cooooo00?o0000ooooooooool0D_ooool2o`000003ooooool0003o
000000Cooooo0_l00007ooooo`;o000000?oooooo`000?l000005_l00007ooooo`;o00001_ooool2
o`0000;ooooo1ol00005ooooo`;o00001?ooool3o`0000;ooooo0_l00002ooooo`;o00002oooool3
o`000003ooooool0003o000001Ko00001?ooool2o`0000Sooooo0_l0000Dooooo`;o000000Cooooo
o`000?l0003o0000BOooool001cooooo00?o0000ooooooooool0DOooool3o`0000Kooooo0ol00007
oooooago00004oooool4o`0000;ooooo0_l00008ooooo`;o000000?oooooo`000?l000004Oooool3
o`000004ooooool0003o0000oooooaOo00002_ooool4o`0000[ooooo0_l0000<ooooo`?o0000B?oo
ool001cooooo00?o0000ooooooooool0A_ooool2o`0000Wooooo0_l00007ooooo`;o00002_oooolD
o`000003ooooool0003o000000Co00001oooool4o`0000Oooooo0_l00005ooooo`;o00002oooool2
o`00017ooooo7_l00004ooooo`;o00001?ooool2o`0000cooooo0_l00008ooooo`;o00000oooool2
o`0004Sooooo000Looooo`03o`000?oooooooooo04Kooooo0_l0000<ooooo`;o00004?oooolGo`00
0004ooooool0003o0000o`0000Oooooo1?l00005ooooo`Co00001Oooool2o`0000Cooooo1?l00005
ooooo`;o00002Oooool2o`0000;ooooo1_l000000ooooooo0000o`000008o`000003ooooool0003o
000000Wo00001oooool4o`00013ooooo0_l00008ooooo`;o0000COooool001cooooo00?o0000oooo
ooooool0A?ooool2o`0000Wooooo0_l00003ooooo`;o00002_ooool2o`0000Cooooo6Ol0000Boooo
o`;o00000oooool2o`0000;ooooo0_l00004ooooo`Co00000_ooool2o`000003ooooool0003o0000
00;o00001oooool2o`0000;ooooo1_l000000ooooooo0000o`000008o`000003ooooool0003o0000
00go00000oooool4o`0000?ooooo0_l0000;ooooo`;o0000Eoooool001cooooo00?o0000oooooooo
ool0?Oooool2o`0000Gooooo0_l00009ooooo`;o00000oooool2o`0000[ooooo0_l00004oooooa_o
00004?ooool2o`000003ooooool0003o000000[o000000?oooooo`000?l000000oooool2o`0000?o
oooo0_l0000;ooooo`;o000000?oooooo`000?l000007?l00003ooooo`?o00001?ooool2o`0000_o
oooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00005Oooool2o`0000[ooooo
0_l00004oooooa_o00004ooooolAo`0001?ooooo0_l000000ooooooo0000o`00000Lo`0000Cooooo
0_l0001Zooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00003oooool2o`0000Cooooo0_l0
0003ooooo`;o00001_oooolHo`0001?ooooo4ol0000>ooooo`;o00002OoooolHo`000003ooooool0
003o000000?ooooo0_l0001[ooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00005Oooool3
o`0000;ooooo0_l00002ooooo`;o00000ooooolDo`0000cooooo0_l00008oooooa?o00003_ooool2
o`0000;ooooo0ol000000ooooooo0000o`00000Ho`0000Oooooo0ol00002ooooo`;o00001Oooool2
o`0005oooooo000Looooo`03o`000?oooooooooo03oooooo0_l00002ooooo`;o00004Oooool4o`00
0003ooooool0003o000000Kooooo0_l00004oooooa?o00003?ooool2o`000004ooooool0003o0000
o`0000Cooooo5?l00007ooooo`;o00000oooool4o`000003ooooool0003o000001co000000?ooooo
o`000?l000001Oooool2o`0000;ooooo0_l00005ooooo`;o00000oooool2o`0005[ooooo000Loooo
o`03o`000?oooooooooo03[ooooo0_l00002ooooo`?o00002oooool4o`000003ooooool0003o0000
00?ooooo1?l0000?oooooa;o000000?oooooo`000?l000000_l00004ooooo`;o000000?oooooo`00
0?l000000_ooool3o`000004ooooool0003o0000ooooo`Oo000000?oooooo`000?l000002_l00007
ooooo`;o00000oooool4o`0000;ooooo8?l000001?oooooo0000o`000?l00006ooooo`;o00002Ooo
ool4o`0005Sooooo000Looooo`03o`000?oooooooooo03[ooooo0_l00002ooooo`;o00003?ooool4
o`000003ooooool0003o000000?ooooo0_l0000Eooooo`go00000_ooool4o`0000Cooooo0_l00000
1?oooooo0000o`000?l00005ooooo`;o000000?oooooo`000?l000003ol00003ooooo`;o00004?oo
oolOo`0000;ooooo0ol00006ooooo`;o00002oooool4o`0005Kooooo000Looooo`03o`000?oooooo
oooo04Oooooo0_l00006ooooo`;o00001Oooool4o`0000;ooooo0_l0000?oooooa3o00001Oooool2
o`0000Cooooo0_l00005ooooo`;o000000?oooooo`000?l000003ol00003ooooo`;o00004_ooool3
o`000004ooooool0003o0000ooooo`ko000000?oooooo`000?l000000ol00007ooooo`;o00002Ooo
ool2o`0000Gooooo0_l000000ooooooo0000o`000008ooooo`;o0000C?ooool00006ooooooo^k^ko
<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`00
0?oooooooooo043ooooo0_l00003ooooo`Co00001_ooool3o`0000;ooooo0_l00002ooooo`?o0000
00?oooooo`000?l000003oooool5o`000004ooooool0003o0000ooooo`Oo00000_ooool2o`000004
ooooool0003o0000ooooo`;o00002oooool@o`0000Cooooo0_l00002ooooo`;o00003?oooolLo`00
0003ooooool0003o000000?ooooo1?l00009ooooo`;o00001Oooool2o`0000_ooooo1?l0000:oooo
o`;o0000?_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`10ooooo`;o00000oooool2o`0000Sooooo0ol00002
ooooo`Co000000?oooooo`000?l000004_ooool4o`000004ooooool0003o0000o`0000?ooooo0_l0
00000ooooooo0000o`000002ooooo`;o00001?ooool2o`0000_ooooo0_l000000ooooooo0000o`00
000=o`0000;ooooo0_l00002ooooo`;o00002ooooolPo`0000?ooooo0_l0000;ooooo`?o00002_oo
ool2o`0000Gooooo1?l00006ooooo`;o00000_ooool2o`0003kooooo00000ooooooo410@ooooo`02
ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006ooooo`03o`000?oooooooooo03gooooo0_l0000@
ooooo`;o00001Oooool2o`0001?ooooo0_l00002ooooo`;o000000?oooooo`000?l000000oooool2
o`0000;ooooo0_l00009ooooo`;o00002_ooool2o`0000;ooooo1ol000000ooooooo0000o`000002
ooooo`;o00000_ooool2o`0000oooooo0_l00002oooooa_o00000_ooool2o`000004ooooool0003o
0000ooooo`;o00000_ooool2o`0000?ooooo0ol00002ooooo`;o00001_ooool2o`0000Gooooo0_l0
0008ooooo`;o00001?ooool2o`0003cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`0003_ooooo1?l00008ooooo`;o00003Ooo
ool2o`0001?ooooo0_l00002ooooo`;o00001_ooool2o`0000_ooooo1?l0000>ooooo`Oo00007?oo
ool5o`000003ooooool0003o0000017o000000?oooooo`000?l000001Ol000001?oooooo0000o`00
0?ooool2o`0000;ooooo0_l00008ooooo`;o00007Oooool2o`0003cooooo00000ooooooo0000oooo
o`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003ooooo
ooooo`0kooooo`;o00002_ooool2o`0000gooooo1?l0000Mooooo`;o00002_ooool3o`0001;ooooo
0ol00004ooooo`;o00001oooool2o`0000kooooo1_l000000ooooooo0000o`00000Do`000003oooo
ool0003o000000Gooooo0_l00002ooooo`;o00009oooool2o`0003gooooo00000ooooooo410@oooo
o`02ooooo`03oa0@4?oooooooooo00[ooooo00?oMgMgolc<c?l000001oooool00ol0003ooooooooo
o`0iooooo`;o00000oooool2o`0001Kooooo1Ol00002ooooo`;o00004Oooool4o`0000gooooo1?l0
000?ooooo`;o00002Oooool4o`0000Gooooo0_l0000>ooooo`;o00001_ooool2o`000003ooooool0
003o000000co000000?oooooo`000?l000000_l00007ooooo`;o00000_ooool2o`0000?ooooo0_l0
000Mooooo`;o00000oooool2o`0003gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo
00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0iooooo`;o00000oooool2o`0001Sooooo
1?l000000ooooooo0000o`00000Aooooo`Co00003Oooool2o`00017ooooo0_l0000;ooooo`;o0000
7_ooool>o`0000?ooooo1?l0000@ooooo`;o00005_ooool2o`0000Gooooo0_l00012ooooo`0000Ko
ooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000oooooooo
ool0?Oooool4o`0001Oooooo1?l0000Mooooo`;o00000_ooool2o`0002;ooooo0_l0000Nooooo`go
00001?ooool4o`0000Gooooo0ol0000Nooooo`Ko00000oooool3o`00047ooooo000Looooo`03o`00
0?oooooooooo03gooooo1?l0000Yooooo`;o00002?ooool2o`0000?ooooo0_l00002ooooo`;o0000
??ooool2o`0000?ooooo3?l00003ooooo`;o00002Oooool4o`0001cooooo1?l00002ooooo`;o0000
0oooool3o`00047ooooo000Looooo`03o`000?oooooooooo04;ooooo0_l0000Booooo`;o00003Ooo
ool4o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o00000_ooool2o`0000oooooo0_l0
0006ooooo`;o00001_ooool2o`0000Sooooo0_l0000:ooooo`;o00001Oooool3o`0000;ooooo0_l0
0002ooooo`Wo000000Coooooo`000?l0003o00000_ooool4o`0000;ooooo0_l00004ooooo`;o0000
1oooool2o`0001Gooooo0_l0000:ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0@_oo
ool2o`0001;ooooo0_l00006ooooo`;o00001Oooool4o`0000Oooooo0_l00004ooooo`Co00003ooo
ool4o`0000Cooooo0_l00002ooooo`?o000000?oooooo`000?l000001Oooool2o`000003ooooool0
003o000000Co00001_ooool2o`0000Gooooo0ol00006ooooo`;o000000?oooooo`000?l000001?l0
00000ooooooo0000o`000002o`000003ooooool0003o000000;o00000_ooool3o`0000cooooo0_l0
000Eooooo`;o00002Oooool3o`00047ooooo000Looooo`03o`000?oooooooooo05Gooooo0_l00007
ooooo`;o000000?oooooo`000?l000000_ooool6o`0000_ooooo0_l000000ooooooo0000o`00000@
ooooo`;o00001?ooool2o`0000;ooooo0ol00006ooooo`Co00000oooool4o`0000Wooooo0_l00003
ooooo`;o00001_ooool2o`0000?ooooo1?l00002ooooo`Co00001Oooool4o`0000Cooooo0_l0000U
ooooo`;o000000Coooooo`000?l0003o0000@Oooool001cooooo00?o0000ooooooooool0??ooool2
o`0000Oooooo0_l0000>ooooo`;o00002_ooool2o`0000?ooooo1Ol00009ooooo`;o00000oooool2
o`00017ooooo0_l00003ooooo`;o00001?ooool2o`0000Gooooo0_l000000ooooooo0000o`000003
o`0000cooooo0_l0000:ooooo`;o00002?ooool2o`0000;ooooo0_l00005ooooo`;o00001Oooool3
o`0000;ooooo0_l0000Qooooo`;o00000_ooool3o`0000?ooooo0_l0000kooooo`007?ooool00ol0
003oooooooooo`0looooo`;o00001oooool2o`0001oooooo0_l00005ooooo`;o00001Oooool2o`00
00Sooooo0_l0000<ooooo`;o00000oooool2o`0000;ooooo1?l00007ooooo`Ko00006?ooool2o`00
00?ooooo0ol00002ooooo`;o00001oooool2o`0000Oooooo0_l00003ooooo`;o00002oooool2o`00
01Cooooo0_l00002ooooo`?o00000oooool2o`0003_ooooo000Looooo`03o`000?oooooooooo03co
oooo0ol00005ooooo`;o00007?ooool2o`0000Wooooo0_l0000?ooooo`Co00002oooool2o`0000Ko
oooo1?l00002ooooo`So000000?oooooo`000?l000003_ooool2o`0000Sooooo0_l00003ooooo`Go
00000oooool2o`0000Cooooo0_l000000ooooooo0000o`00000Fooooo`;o00005oooool3o`0000?o
oooo0_l0000looooo`007?ooool00ol0003oooooooooo`0looooo`?o000000?oooooo`000?l00000
0_ooool2o`0000?ooooo0_l0000Gooooo`;o00000_ooool2o`000003ooooool0003o000000?ooooo
0_l0000=ooooo`;o000000?oooooo`000?l000001Oooool3o`0000;ooooo0ol00006ooooo`?o0000
0oooool6o`0000;ooooo0ol0000>ooooo`Co00001_ooool2o`0000Cooooo1?l000000ooooooo0000
o`000003o`0000Kooooo0_l0000?ooooo`;o00007_ooool3o`0000?ooooo0_l0000looooo`007?oo
ool00ol0003oooooooooo`10ooooo`;o00001oooool2o`0000;ooooo0_l0000Gooooo`;o000000?o
ooooo`000?l000000oooool2o`000003ooooool0003o000000Wooooo1Ol00002ooooo`;o00000_oo
ool3o`0000;ooooo0_l00003ooooo`;o00000_ooool3o`0000?ooooo1_l00002ooooo`;o00004Ooo
ool2o`0000Kooooo0_l00004ooooo`Co000000?oooooo`000?l000000ol0000:ooooo`;o00002ooo
ool2o`0000Cooooo0ol0000Eooooo`;o00001_ooool2o`0003cooooo000Looooo`03o`000?oooooo
oooo03oooooo0ol0000;ooooo`;o00006?ooool3o`0000Oooooo0_l00009ooooo`;o000000?ooooo
o`000?l000000_ooool3o`0000;ooooo0_l00002ooooo`;o00000oooool4o`0000Wooooo1Ol0000E
ooooo`;o00001_ooool2o`0001Kooooo0_l0000Aooooo`?o00005Oooool2o`0000Kooooo0_l0000l
ooooo`007?ooool00ol0003oooooooooo`0iooooo`Co00000_ooool3o`0002Gooooo0ol00008oooo
o`;o00001Oooool2o`0000Sooooo0ol00002ooooo`;o000000Coooooo`000?l0003o00000_ooool2
o`000003ooooool0003o000000?ooooo1Ol000000ooooooo0000o`000007o`00017ooooo0_l00006
ooooo`Co00001oooool2o`0000_ooooo0_l000000ooooooo0000o`00001/ooooo`007?ooool2o`00
03[ooooo1?l00003ooooo`?o00009_ooool2o`0000Oooooo0_l00002ooooo`Go000000?oooooo`00
0?l000001?ooool2o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`00
0?l000000oooool5o`000003ooooool0003o000000;ooooo2Ol0000Gooooo`;o00001oooool6o`00
0003ooooool0003o000000;o00001Oooool2o`0006cooooo000Looooo`03o`000?oooooooooo03[o
oooo0ol00003ooooo`?o00009_ooool6o`0000Oooooo1?l00002ooooo`;o00001?ooool4o`0000?o
oooo0_l00002ooooo`Co00001Oooool2o`0000Kooooo1?l000001?oooooo0000o`000?ooool7o`00
01Sooooo0_l00006ooooo`Co000000?oooooo`000?l000000_l0000Vooooo`Co0000BOooool001co
oooo00?o0000ooooooooool0@?ooool2o`0002Wooooo1?l0000Aooooo`Ko00000_ooool3o`0000;o
oooo1?l00005ooooo`;o00000_ooool3o`0000?ooooo0_l000000ooooooo0000o`000002o`0000Co
oooo0_l0000Hooooo`;o00003oooool2o`0002Cooooo1?l00019ooooo`007?ooool00ol0003ooooo
ooooo`0hooooo`;o00000_ooool2o`0000;ooooo0_l0000hooooo`;o00001?ooool7o`000004oooo
ool0003o0000o`0000;ooooo0_l0000;ooooo`Go000000?oooooo`000?l000001Ol0000Vooooo`;o
00001oooool2o`000003ooooool0003o000000oooooo0_l0000Qooooo`;o0000>_ooool001cooooo
00?o0000ooooooooool0>?ooool2o`000004ooooool0003o0000o`0000Kooooo0ol0000Zooooo`?o
00000oooool2o`000003ooooool0003o000000Oooooo1?l00002ooooo`;o00000_ooool2o`000004
ooooool0003o0000o`0000Cooooo4_l0000Tooooo`;o00002Oooool3o`0000oooooo0_l0000Coooo
o`;o00003?ooool2o`0003[ooooo000Looooo`03o`000?oooooooooo03Wooooo1ol00004ooooo`?o
0000:_ooool3o`000003ooooool0003o000000;o000000?oooooo`000?l000001_ooool2o`0000co
oooo5Ol00002ooooo`;o00007_ooool5o`0000cooooo0ol00004ooooo`?o00000_ooool2o`0001Wo
oooo0ol000000ooooooo0000o`000002ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0
>Oooool7o`000003ooooool0003o000003;ooooo1?l000000ooooooo0000o`000004ooooo`Co0000
3?ooool<o`000004ooooool0003o0000o`0000oooooo1?l00009ooooo`;o00002Oooool5o`0000co
oooo0_l00004ooooo`Co00000_ooool2o`000003ooooool0003o000001Oooooo0_l000000ooooooo
0000o`000002ooooo`;o00000oooool2o`0003_ooooo000Looooo`03o`000?oooooooooo037ooooo
0_l00008ooooo`Go000000?oooooo`000?l00000<oooool7o`0000?ooooo0_l000000ooooooo0000
o`000007ooooo`;o000000?oooooo`000?l000000ol000000ooooooo0000o`00000Hooooo`Co0000
2Oooool2o`0001?ooooo0_l00003ooooo`;o00001?ooool4o`0000Cooooo0_l000000ooooooo0000
o`000002ooooo`;o00004oooool2o`0000[ooooo0_l0000kooooo`007?ooool00ol0003ooooooooo
o`0aooooo`;o00001_ooool2o`000003ooooool0003o000000;o0000>Oooool4o`0000;ooooo0_l0
0002ooooo`Co00001?ooool6o`000004ooooool0003o0000o`0000Cooooo0_l000000ooooooo0000
o`000002ooooo`;o00005?ooool2o`000003ooooool0003o000000cooooo0_l000000ooooooo0000
o`000005ooooo`?o00000_ooool2o`0000Cooooo0_l0000=ooooo`;o0000G?ooool001cooooo00?o
0000ooooooooool0<?ooool2o`000003ooooool0003o000000Cooooo0_l0000fooooo`;o00000_oo
ool2o`0000Cooooo0ol000000ooooooo0000o`000004ooooo`;o00001?ooool2o`000004ooooool0
003o0000o`0000;ooooo1?l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Kooooo
0ol00007ooooo`?o000000Coooooo`000?l0003ooooo0_l00009ooooo`;o000000?oooooo`000?l0
00000ol00006ooooo`;o00004Oooool2o`0001gooooo1Ol00004ooooo`;o0000>_ooool001cooooo
00?o0000ooooooooool0<?ooool2o`000004ooooool0003o0000ooooo`;o00001?ooool2o`000003
ooooool0003o0000033ooooo0_l00002ooooo`Co00000oooool2o`0000;ooooo0_l0000;ooooo`?o
00001Oooool2o`0000gooooo0_l00002ooooo`?o00000oooool7o`0000Kooooo0_l00007ooooo`Co
000000?oooooo`000?l000004?ooool3o`0000Oooooo0_l00004ooooo`;o00005oooool5o`0000Co
oooo0_l00009ooooo`;o0000;oooool001cooooo00?o0000ooooooooool0=_ooool2o`0000?ooooo
0ol000000ooooooo0000o`00000fooooo`;o00001Oooool4o`0000_ooooo0ol00007ooooo`Oo0000
0oooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`Go00002?ooool2o`0000Sooooo
0ol00005ooooo`Go00001oooool8o`0000[ooooo0_l0000Fooooo`?o000000?oooooo`000?l00000
3oooool2o`0002oooooo000Looooo`03o`000?oooooooooo03_ooooo0ol0000gooooo`;o00001ooo
ool2o`0000kooooo1?l000000ooooooo0000o`000002ooooo`Oo000000?oooooo`000?l000000_l0
0004ooooo`?o00001oooool2o`0000Sooooo0_l00002ooooo`Co00001Oooool2o`0000?ooooo1Ol0
0007ooooo`So00008_ooool3o`000004ooooool0003o0000o`0003oooooo000Looooo`03o`000?oo
oooooooo03Gooooo0_l0000;ooooo`;o0000<?ooool3o`0000Oooooo0_l0000<ooooo`;o00000_oo
ool2o`000003ooooool0003o000000Wooooo0ol000000ooooooo0000o`000003ooooo`;o00003Ooo
ool2o`0000Oooooo1?l00005ooooo`;o00002Oooool2o`0000Cooooo1Ol000000ooooooo0000o`00
0004ooooo`;o00001?ooool2o`0001Gooooo0ol000000ooooooo0000o`000002o`0003oooooo000L
ooooo`03o`000?oooooooooo03Cooooo0ol0000;ooooo`;o0000<?ooool2o`0000Kooooo0_l0000>
ooooo`;o00002Oooool2o`0000;ooooo1Ol00002ooooo`Co00001Oooool2o`0000Wooooo0_l00009
ooooo`;o00004?ooool2o`0000Gooooo1?l00007ooooo`;o00001?ooool2o`0001Gooooo0ol00000
0ooooooo0000o`000011ooooo`007?ooool00ol0003oooooooooo`0dooooo`;o0000<oooool2o`00
017ooooo1Ol0000Eooooo`?o00000_ooool3o`0000Gooooo0ol00005ooooo`Go00001?ooool2o`00
00_ooooo0_l0000Iooooo`;o00001Oooool2o`0000Kooooo0_l0001Looooo`007?ooool2o`0003Co
oooo0_l0000dooooo`;o00004Oooool5o`0000;ooooo0_l0000Aooooo`?o00001?ooool2o`0000Co
oooo0_l00005ooooo`Ko000000Coooooo`000?l0003ooooo1?l00007ooooo`Co00000oooool2o`00
00Gooooo0_l00002ooooo`;o00002Oooool2o`0000Gooooo0_l0000Looooo`;o00000_ooool2o`00
00Oooooo0ol0000hooooo`007?ooool00ol0003oooooooooo`0cooooo`;o0000B_ooool2o`0000;o
oooo0_l0000@ooooo`Co00001?ooool2o`0000_ooooo0_l00002ooooo`Go000000?oooooo`000?l0
00001?l00005ooooo`Ko000000?oooooo`000?l000001Oooool2o`0000;ooooo0ol00008ooooo`;o
00008oooool2o`0000;ooooo0_l00007ooooo`?o0000>?ooool001cooooo00?o0000ooooooooool0
J_ooool2o`0000Kooooo0_l0000Mooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo
0ol0000;ooooo`So00001_ooool2o`000003ooooool0003o000000Kooooo0_l00002ooooo`;o0000
2?ooool3o`000003ooooool0003o000000Gooooo1?l00002ooooo`;o00000_ooool4o`0002?ooooo
1?l0000hooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o0000:_ooool2o`0000?ooooo0ol0
0009ooooo`;o00001_ooool2o`0001gooooo0_l00002ooooo`;o000000?oooooo`000?l000000_oo
ool3o`0000Cooooo0_l00007ooooo`Ko00002Oooool6o`0000Kooooo0_l0000<ooooo`;o00001Ooo
ool4o`0000;ooooo0_l00002ooooo`Co00005_ooool3o`000004ooooool0003o0000ooooo`;o0000
1?ooool2o`0003[ooooo000Looooo`03o`000?oooooooooo02gooooo0_l0000Gooooo`;o00004Ooo
ool4o`000004ooooool0003o0000o`0000cooooo0_l0000Rooooo`;o00002Oooool3o`0000Cooooo
0_l00009ooooo`;o00001Oooool2o`0000Gooooo1_l0000Eooooo`;o00000oooool4o`00023ooooo
0ol000001?oooooo0000o`000?ooool2o`0000;ooooo0_l0000looooo`007?ooool00ol0003ooooo
ooooo`16ooooo`;o00004oooool2o`0000Cooooo1Ol00007ooooo`;o00000_ooool2o`0000kooooo
0_l0000Jooooo`;o00001?ooool2o`0000;ooooo0ol0000;ooooo`;o000000?oooooo`000?l00000
2_l0000:ooooo`;o00001oooool2o`0000Cooooo1?l0000Rooooo`;o000000Coooooo`000?l0003o
00000_ooool2o`0003cooooo000Looooo`03o`000?oooooooooo03Cooooo0_l0000Nooooo`;o0000
00?oooooo`000?l000002?ooool5o`0000Kooooo1?l000000ooooooo0000o`00000>ooooo`;o0000
6?ooool2o`0000Gooooo2?l00009ooooo`?o00000_ooool?o`0000Oooooo0_l00008ooooo`;o0000
00?oooooo`000?l000001Ol0000Qooooo`;o000000?oooooo`000?l000003Oooool2o`0003;ooooo
000Looooo`03o`000?oooooooooo03Cooooo0_l0000Nooooo`;o000000?oooooo`000?l000000_oo
ool4o`0000?ooooo1?l00006ooooo`Co00002Oooool2o`0000Wooooo0_l0000Eooooo`;o00001Ooo
ool5o`0000cooooo0ol00002ooooo`;o000000?oooooo`000?l000002_l0000Aooooo`;o000000?o
ooooo`000?l000001_l0000Sooooo`;o00003Oooool2o`0003;ooooo000Looooo`03o`000?oooooo
oooo02Wooooo0_l0000Uooooo`;o000000?oooooo`000?l000001Oooool>o`0000Gooooo0_l00007
ooooo`;o000000?oooooo`000?l000001oooool4o`00027ooooo0_l00007ooooo`Ko00000oooool5
o`000003ooooool0003o000000Go000000Coooooo`000?l0003o00004_ooool2o`000003ooooool0
003o000000Co00000_ooool2o`000003ooooool0003o000005gooooo000Looooo`03o`000?oooooo
oooo02Wooooo0_l00006ooooo`;o00002oooool2o`00013ooooo0_l000000ooooooo0000o`000002
ooooo`go000000Coooooo`000?l0003o00001?ooool5o`0000Gooooo0_l00002ooooo`;o00001Ooo
ool5o`0000[ooooo0_l00006ooooo`;o000000?oooooo`000?l000002_ooool2o`0000Oooooo1?l0
00000ooooooo0000o`00000=o`0000;ooooo1?l00004ooooo`?o00003oooool2o`000003ooooool0
003o000000;ooooo1Ol0000Nooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0:?ooool2
o`0000Oooooo0_l0000;ooooo`;o00004oooool2o`000003ooooool0003o000000co000000?ooooo
o`000?l000000_l00003ooooo`;o000000?oooooo`000?l000000_ooool5o`0000;ooooo0_l00002
ooooo`;o000000?oooooo`000?l000003Oooool2o`0000Kooooo0_l000000ooooooo0000o`00000A
ooooo`;o000000?oooooo`000?l000000_ooool?o`0000;ooooo1_l00002ooooo`?o00001oooool2
o`0000Kooooo1?l000000ooooooo0000o`000002ooooo`;o00007_ooool3o`0003gooooo000Loooo
o`03o`000?oooooooooo02Sooooo0_l0000YoooooaSo00002?ooool5o`0000Kooooo0_l000001?oo
oooo0000o`000?ooool3o`000003ooooool0003o000002?ooooo0ol000000ooooooo0000o`000002
ooooo`oo00000_ooool7o`0000Oooooo0_l00002ooooo`;o00002?ooool5o`0000?ooooo0_l0000M
ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0E?oooolIo`0000Kooooo0_l0000>oooo
o`Co000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00006_ooool5o`000004ooooool0003o
0000ooooo`?o000000?oooooo`000?l000001ol000000ooooooo0000o`000009o`000003ooooool0
003o000000;o000000?oooooo`000?l000003_ooool2o`0000Cooooo0_l0000@ooooo`;o00002ooo
ool4o`0003cooooo000Looooo`03o`000?oooooooooo03Cooooo0ol0000Eooooo`;o00001?oooolF
o`000003ooooool0003o000000;o00000oooool2o`0000cooooo0_l00003ooooo`?o00001Oooool2
o`0000?ooooo0_l00005ooooo`;o00000_ooool2o`0000Gooooo0_l00008ooooo`;o000000Cooooo
o`000?l0003ooooo5_l000000ooooooo0000o`00000:o`0002Oooooo1?l00009ooooo`Co0000??oo
ool001cooooo00?o0000ooooooooool0<oooool4o`0001Gooooo1Ol000000ooooooo0000o`00000K
o`000003ooooool0003o000000?ooooo0_l00007ooooo`;o00000_ooool4o`00017ooooo0_l00002
ooooo`;o00001Oooool2o`0000Sooooo0_l00002oooooaWo000000?oooooo`000?l000000ol00004
ooooo`;o0000:Oooool2o`0000?ooooo0ol00003ooooo`?o0000?Oooool001cooooo00?o0000oooo
ooooool0<oooool2o`0001?ooooo0_l00004ooooob7o00001_ooool2o`0000Wooooo1?l0000Aoooo
o`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`?o00002?ooool2o`0000;ooooo1?l00000
0ooooooo0000o`00000Bo`0000;ooooo0ol00005ooooo`;o00004_ooool2o`000003ooooool0003o
000001Oooooo0ol00013ooooo`007?ooool2o`0004Wooooo0_l00005ooooob3o00002oooool2o`00
00Cooooo1?l00005ooooo`;o00002_ooool2o`000004ooooool0003o0000ooooo`;o00001?ooool2
o`0000Wooooo0_l00003ooooo`?o000000?oooooo`000?l000002ol00002ooooo`Co00000oooool5
o`0001Oooooo0_l000001?oooooo0000o`000?l0001Looooo`007?ooool00ol0003oooooooooo`0X
ooooo`;o00007Oooool2o`0000Kooooo7ol0000<ooooo`;o00000_ooool5o`0000Kooooo0_l0000@
ooooo`;o000000?oooooo`000?l000001oooool4o`0000Kooooo6Ol000001?oooooo0000o`000?oo
ool3o`0000oooooo0_l00009ooooo`;o00007?ooool2o`0003kooooo000Looooo`03o`000?oooooo
oooo02Sooooo0_l0000@ooooo`;o00002oooool2o`0000Gooooo0ol000000ooooooo0000o`00000J
o`0000;ooooo0_l00002ooooo`;o00002?ooool5o`0000Gooooo0_l0000Aooooo`;o000000?ooooo
o`000?l000001oooool7o`0000?ooooo6Ol00004ooooo`Co000000?oooooo`000?l000002oooool2
o`0002Cooooo0_l000000ooooooo0000o`00000nooooo`007?ooool00ol0003oooooooooo`0hoooo
o`Co00004_oooolPo`0000;ooooo0ol000000ooooooo0000o`000008ooooo`Co00000_ooool2o`00
00;ooooo0ol0000Eooooo`;o00001_ooool6o`0000?ooooo6ol00002ooooo`Oo00002_ooool2o`00
01[ooooo0_l00009ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0>?ooool2o`0001;o
oooo0_l000000ooooooo0000o`00000Ro`0000Wooooo0_l00006ooooo`;o00000oooool2o`0001;o
oooo0_l000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l000000oooool:o`000003
ooooool0003o0000017o000000?oooooo`000?l000000_l0000<ooooo`;o00001Oooool2o`0001?o
oooo0_l00004ooooo`;o00003_ooool2o`0003Kooooo000Looooo`03o`000?oooooooooo04Sooooo
0_l00002ooooo`;o000000?oooooo`000?l000004ol00002ooooo`co00002?ooool4o`0001Sooooo
0_l000000ooooooo0000o`000005o`0000?ooooo0_l00004ooooo`Co000000?oooooo`000?l00000
8ol000000ooooooo0000o`000002o`0000kooooo0_l00006ooooo`;o00004Oooool2o`000003oooo
ool0003o000000_ooooo0_l0000fooooo`007?ooool00ol0003oooooooooo`18ooooo`;o00000ooo
oolTo`000003ooooool0003o000000;ooooo0_l00002ooooo`Go00002oooool2o`0000[ooooo0_l0
00000ooooooo0000o`000005o`0000?ooooo0_l00004ooooo`Co000000?oooooo`000?l000005Ol0
00000ooooooo0000o`000009o`0000?ooooo1?l0000Fooooo`;o00004Oooool2o`000003ooooool0
003o000000Cooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`1=ooooo`go000000?ooooo
o`000?l000004Ol00004ooooo`;o000000Coooooo`000?l0003o00000oooool4o`0000_ooooo0_l0
000<ooooo`;o00000oooool2o`000003ooooool0003o000000Sooooo0_l00003oooooaKo000000?o
ooooo`000?l000002?l00002ooooo`;o00001Oooool2o`0001?ooooo0_l0000Dooooo`;o00001?oo
ool2o`0003gooooo000Looooo`03o`000?oooooooooo04kooooo5_l000000ooooooo0000o`000007
o`0000Oooooo0_l00002ooooo`Co00006oooool2o`0000Kooooo0_l00008ooooo`?o00000_oooolQ
o`000003ooooool0003o000000?o00000oooool2o`0001?ooooo0_l00007ooooo`;o00001oooool2
o`0000gooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00002Oooool2o`00
00[ooooo7Ol00002ooooo`;o00002?ooool3o`0001gooooo0_l00005ooooo`Co00001?ooool6o`00
00?ooooo7ol00002ooooo`Go000000?oooooo`000?l000005Oooool2o`0000Kooooo1Ol00005oooo
o`;o000000?oooooo`000?l000002_ooool2o`0003Sooooo000Looooo`03o`000?oooooooooo03So
oooo0_l00009ooooo`;o00002_oooolMo`0000;ooooo0_l00007ooooo`?o00003oooool2o`0000?o
oooo0_l00006ooooo`Co00001Oooool4o`0000Cooooo1?l00007oooooago000000?oooooo`000?l0
00001?l000001?oooooo0000o`000?l0000?ooooo`;o00002oooool2o`000003ooooool0003o0000
00Sooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0dooooo`;o00001Oooool2o`0001;o
oooo0_l000000ooooooo0000o`00000Go`0000_ooooo1_l0000=ooooo`;o00000oooool2o`000003
ooooool0003o000000?ooooo0_l00002ooooo`;o00001?ooool2o`0000Kooooo0ol00007oooooa?o
00000_ooool?o`0000;ooooo0_l0000;ooooo`;o00000_ooool2o`0005kooooo000Looooo`03o`00
0?oooooooooo03Cooooo0_l00005ooooo`;o00001Oooool2o`0000Sooooo0_l00004oooooa7o0000
00?oooooo`000?l000001ol00009ooooo`?o000000?oooooo`000?l000005Oooool2o`0000Kooooo
0ol0000<ooooo`;o00002?oooolDo`000003ooooool0003o000000go00000_ooool2o`0000_ooooo
0_l00002ooooo`?o00000_ooool2o`0000oooooo0_l00007ooooo`;o0000?oooool001cooooo00?o
0000ooooooooool0=?ooool2o`0000Cooooo0_l00006ooooo`;o00002?ooool2o`0000Gooooo2?l0
00000ooooooo0000o`000005o`000003ooooool0003o000000?o00000_ooool2o`0000Kooooo1?l0
000Rooooo`;o00003oooool2o`0000Kooooo5?l00002ooooo`Go00000_ooool3o`000004ooooool0
003o0000o`0001;ooooo2?l0000?ooooo`;o00001oooool2o`0003oooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0
003oooooooooo`0iooooo`?o00005ooooolCo`000003ooooool0003o000000Wooooo1Ol0000Poooo
o`;o00004Oooool3o`0000?ooooo7Ol000000ooooooo0000o`000007o`00017ooooo0_l00002oooo
o`;o00007Oooool2o`0003cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44
ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0iooooo`;o00007Ooo
ool>o`0000_ooooo1Ol0000<ooooo`;o00003oooool2o`0000;ooooo0_l00008ooooo`?o00001ooo
ool2o`0000?ooooo6ol000000ooooooo0000o`000009o`0000_ooooo0_l0000?ooooo`;o00002?oo
ool2o`0000cooooo0_l0000looooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`1<ooooo`;o00001_oo
ool2o`000003ooooool0003o000000[o000000?oooooo`000?l000002_ooool3o`000003ooooool0
003o000000cooooo0ol00003ooooo`;o00001Oooool2o`0000;ooooo0_l0000:ooooo`Go00001_oo
ool2o`000004ooooool0003o0000ooooobOo00002oooool2o`0000oooooo0_l00008ooooo`;o0000
1?ooool2o`0004Cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go
0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000>_ooool2o`00013ooooo0_l00006ooooo`So0000
1Oooool2o`000003ooooool0003o000000[ooooo0_l0000?ooooo`Co00000_ooool3o`0000Gooooo
0_l0000>ooooo`Co00001oooool2o`000004ooooool0003o0000oooooako000000?oooooo`000?l0
00000_l00004ooooo`Co00006?ooool2o`0000kooooo0_l00014ooooo`0000?oooooo`000?ooool0
0_ooool00ol0003oooooooooo`09ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003o
ooooooooo`0jooooo`;o00002oooool3o`0000cooooo0_l00004ooooo`;o00000oooool2o`0000Wo
oooo1?l0000Aooooo`;o00001?ooool2o`0000Kooooo0_l0000Hooooobgo000000?oooooo`000?l0
00000_l00009ooooo`;o00003Oooool2o`0001Cooooo0_l0000nooooo`0000?ooooooa0@4?ooool0
0_ooool00ol@413oooooooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0
>Oooool2o`0000cooooo1?l0000Aooooo`;o00003_ooool4o`0001oooooo0_l0000?ooooo`Co0000
1Oooool4o`0000;ooooo6ol000000ooooooo0000o`000009o`000004ooooool0003o0000o`0000[o
oooo0_l0000@ooooo`;o00003?ooool2o`0000?ooooo0_l0000nooooo`0000KoooooogMgMonHV9So
oooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0>Oooool2o`00
00Oooooo0_l00005ooooo`?o0000Doooool5o`0000Kooooo0ol00003oooooako000000?oooooo`00
0?l000001?l00003ooooo`;o00007?ooool2o`0000cooooo0_l00013ooooo`0000Koooooonk^k_lb
<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0=?oo
ool2o`0000cooooo0_l00005ooooo`Co00002_ooool2o`0000Oooooo0_l00003ooooo`;o00001?oo
ool2o`00017ooooo0_l000000ooooooo0000o`000006ooooo`Co00004_ooool3o`0000Sooooo1?l0
00001?oooooo0000o`000?oooolTo`0000;ooooo0_l00002ooooo`;o0000:?ooool2o`00047ooooo
000Looooo`03o`000?oooooooooo03Cooooo0_l0000Eooooo`;o00002?ooool4o`0000Gooooo1?l0
0003ooooo`;o00001?ooool2o`0000;ooooo0_l00002ooooo`;o00000_ooool2o`0000Gooooo0_l0
00000ooooooo0000o`000006ooooo`Co00000_ooool2o`0000Wooooo0_l00004ooooo`;o00002_oo
ool2o`000004ooooool0003o0000ooooobSo00000_ooool2o`0002Sooooo0_l00011ooooo`007?oo
ool00ol0003oooooooooo`1Aooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`00
000?ooooo`;o00000_ooool2o`0000;ooooo0_l00008ooooo`;o00002?ooool2o`0000;ooooo0_l0
0009ooooo`;o00005ooooolQo`000003ooooool0003o000000Co00002?ooool2o`0000_ooooo0_l0
0002ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0>oooool2o`0001Cooooo0_l00008
ooooo`;o0000<_ooool2o`0000Wooooo0_l0000<ooooo`;o00002_oooolLo`0000;ooooo0_l00002
ooooo`Go00002?ooool2o`0000_ooooo0ol000000ooooooo0000o`00000;ooooo`?o0000AOooool0
01cooooo00?o0000ooooooooool0<?ooool2o`0000Wooooo0_l0000Dooooo`;o00002?ooool2o`00
00Kooooo1?l0000Xooooo`;o00000_ooool3o`0000Cooooo0_l00008ooooo`;o00000_ooool2o`00
00[ooooo6_l00004ooooo`?o000000?oooooo`000?l000000_l00006ooooo`;o00003oooool2o`00
00kooooo0ol00015ooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00007oooool2o`0000So
oooo0ol00005ooooo`Ko0000:_ooool3o`0000_ooooo0_l000000ooooooo0000o`00000>oooooa_o
00000oooool3o`000004ooooool0003o0000o`0000Oooooo0_l000001?oooooo0000o`000?ooool2
o`000003ooooool0003o000000Sooooo0_l00004ooooo`;o0000C_ooool001cooooo00?o0000oooo
ooooool0G?ooool2o`0000Wooooo0_l0000?ooooo`Co00002oooool2o`0001Sooooo0_l00004oooo
o`;o00000oooool2o`0000Oooooo5ol000001?oooooo0000o`000?l00002ooooo`?o000000Cooooo
o`000?l0003o00001_ooool6o`000003ooooool0003o000000?o00000oooool2o`0000?ooooo0_l0
0004ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0@Oooool3o`0000Sooooo0_l00008
ooooo`;o00001oooool2o`0001Kooooo1Ol0000;ooooo`Go00004oooool2o`0000Kooooo0_l00003
ooooo`;o00001Oooool2o`000005ooooool0003o0000o`000?ooool02Ol000000ooooooo0000o`00
000:o`0000;ooooo0_l00003ooooo`;o00001_ooool4o`0000?ooooo1?l00002ooooo`Co00004Ooo
ool2o`0004Kooooo000Looooo`03o`000?oooooooooo047ooooo0ol00008ooooo`?o00001oooool2
o`0000Oooooo0_l0000Fooooo`Co00003Oooool4o`0000[ooooo0_l00007ooooo`;o00004_ooool2
o`000005ooooool0003o0000o`000?ooool02Ol00002ooooo`;o00000_ooool4o`0000Oooooo1Ol0
0006ooooo`?o00002_ooool2o`000003ooooool0003o0000013ooooo0_l00016ooooo`007?ooool0
0ol0003oooooooooo`0`ooooo`;o00006oooool2o`0002kooooo1?l0000=ooooo`;o00001_ooool2
o`00027ooooo0_l00003ooooo`Co00002?ooool2o`0000Sooooo1Ol00006ooooo`;o00003_ooool2
o`0005Sooooo000Looooo`03o`000?oooooooooo033ooooo0_l0000Mooooo`;o00000oooool2o`00
01[ooooo0_l0000;ooooo`Co00001Oooool2o`0000Kooooo0_l00002ooooo`;o00001_ooool2o`00
01;ooooo0_l00003ooooo`;o00001?ooool5o`000003ooooool0003o000000Co000000Coooooo`00
0?l0003ooooo0ol00005ooooo`So00001_ooool2o`0001cooooo0_l0001:ooooo`007?ooool00ol0
003oooooooooo`1?ooooo`;o00000oooool2o`0001[ooooo0_l0000>ooooo`Go000000?oooooo`00
0?l000000_l00003ooooo`?o000000Coooooo`000?l0003o00001_ooool2o`0000[ooooo0_l00003
ooooo`;o000000Coooooo`000?l0003ooooo1?l00006ooooo`?o000000?oooooo`000?l000001ol0
00001?oooooo0000o`000?l00005ooooo`Ko000000Coooooo`000?l0003o00008_ooool2o`0000So
oooo0_l00010ooooo`007?ooool2o`0007Kooooo0_l00008ooooo`_o00000oooool7o`0000Cooooo
1?l00006ooooo`;o00000_ooool2o`0000?ooooo2?l00002ooooo`;o00001?ooool3o`000003oooo
ool0003o000000Ko00000_ooool2o`000003ooooool0003o000000Cooooo0_l00004ooooo`?o0000
2?ooool4o`0001?ooooo0_l00002ooooo`;o00001oooool2o`00043ooooo000Looooo`03o`000?oo
oooooooo04Kooooo0_l00005ooooo`;o00009_ooool2o`0000Sooooo3_l00002ooooo`Go00001?oo
ool4o`0000Kooooo0_l00002ooooo`;o00000_ooool4o`000003ooooool0003o000000Cooooo0_l0
0005ooooo`;o00000_ooool4o`0000Gooooo0_l000001?oooooo0000o`000?l0000:ooooo`;o0000
2?ooool4o`000003ooooool0003o000000Gooooo0_l00008ooooo`?o00000_ooool2o`0004Wooooo
000Looooo`03o`000?oooooooooo04Kooooo0_l00005ooooo`;o00008oooool2o`0000Oooooo0_l0
0003oooooa7o00002?ooool3o`0000Sooooo1Ol000000ooooooo0000o`00000<ooooo`;o00000ooo
ool2o`000003ooooool0003o000000Go00001_ooool2o`0000Oooooo1?l00005ooooo`;o00000_oo
ool4o`000003ooooool0003o000000;o00000oooool2o`0000Sooooo0_l00006ooooo`;o0000A_oo
ool001cooooo00?o0000ooooooooool0Eoooool4o`0001Kooooo0ol00007ooooo`;o000000?ooooo
o`000?l000004Ol00005ooooo`;o00000_ooool2o`0000Sooooo0_l000000ooooooo0000o`000002
ooooo`;o00001Oooool2o`0000Cooooo1ol000000ooooooo0000o`000005o`000003ooooool0003o
000000cooooo1?l00005ooooo`;o00000_ooool4o`0000;ooooo0ol0000=ooooo`;o00001_ooool2
o`0004Kooooo000Looooo`03o`000?oooooooooo04Kooooo0_l0000?ooooo`Co00005_ooool2o`00
00Oooooo0_l000000ooooooo0000o`000006o`000003ooooool0003o000000Wo00001Oooool2o`00
01?ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool7o`0000Kooooo0ol00002oooo
o`;o00000_ooool2o`0000Wooooo0_l00005ooooo`Co000000Coooooo`000?l0003ooooo0_l00006
ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0A_ooool2o`0003;ooooo5_l00002oooo
o`Ko00000_ooool2o`0000oooooo0_l00002ooooo`?o00001?ooool2o`0000Wooooo1?l000000ooo
oooo0000o`000004ooooo`;o00000_ooool3o`0000Cooooo0_l00004ooooo`Go00001?ooool2o`00
00Kooooo0_l00006ooooo`;o00002Oooool2o`0004Kooooo000Looooo`03o`000?oooooooooo03?o
oooo0_l00016oooooa?o00000oooool;o`0000Gooooo0_l0000;ooooo`Co00000oooool2o`0000;o
oooo0_l00006ooooo`;o00000oooool2o`0000;ooooo0_l00004ooooo`?o00002_ooool2o`0000_o
oooo0_l00008ooooo`Co00002Oooool2o`0004Kooooo000Looooo`03o`000?oooooooooo03?ooooo
0_l00006ooooo`;o00000_ooool2o`0000Gooooo0_l0000aoooooaGo00000oooool2o`000005oooo
ool0003o0000o`000?ooool00ol00004ooooo`Co00002oooool5o`0000;ooooo0_l00002ooooo`?o
00002?ooool4o`0000;ooooo0_l00007ooooo`;o00001_ooool4o`0000_ooooo0_l00004ooooo`;o
00000_ooool2o`0005?ooooo000Looooo`03o`000?oooooooooo03_ooooo0_l00002ooooo`;o0000
1Oooool2o`0001?ooooo0_l0000LoooooaGo00001?ooool5o`0000;ooooo0_l00004ooooo`;o0000
0_ooool2o`0000;ooooo0_l00003ooooo`;o00000oooool2o`0000Oooooo1?l00006ooooo`Co0000
2oooool2o`0000Cooooo1_l00002ooooo`;o00003Oooool2o`0000;ooooo0_l00005ooooo`;o0000
0_ooool2o`0004Sooooo000Looooo`03o`000?oooooooooo04[ooooo0_l0000?ooooo`;o00007?oo
oolCo`0000Kooooo0_l000000ooooooo0000o`00000<ooooo`;o00000_ooool2o`0000?ooooo0_l0
0006ooooo`Co00000oooool3o`000003ooooool0003o000000?o00002oooool2o`000003ooooool0
003o000000Gooooo1_l00002ooooo`Co00002oooool2o`0000Wooooo0_l00002ooooo`;o0000B?oo
ool001cooooo00?o0000ooooooooool0A_ooool2o`0000;ooooo1?l00009ooooo`;o00006?ooool2
o`000003ooooool0003o000000?ooooo4ol00003ooooo`;o00002Oooool2o`0000[ooooo0_l00003
ooooo`;o00001oooool4o`0000Oooooo1_l00007ooooo`Go000000Coooooo`000?l0003o00002?oo
ool2o`0000Cooooo0_l00009ooooo`Co0000Eoooool001cooooo00?o0000ooooooooool0A_ooool2
o`0000?ooooo0ol00009ooooo`;o00000oooool3o`0000;ooooo0_l0000>ooooo`;o000000?ooooo
o`000?l000001?oooolBo`0000?ooooo0_l000000ooooooo0000o`000006ooooo`;o00002_ooool2
o`0000?ooooo0_l0000Cooooo`Oo00001Oooool3o`0000?ooooo0ol00004ooooo`;o00003Oooool3
o`000003ooooool0003o000000;o000000?oooooo`000?l00000E_ooool001cooooo00?o0000oooo
ooooool0BOooool2o`0000;ooooo0_l0000=ooooo`?o00000_ooool2o`0001Cooooo5Ol00006oooo
o`;o00001Oooool2o`0001kooooo0_l00005ooooo`;o00000_ooool3o`0000Sooooo0_l000000ooo
oooo0000o`000005ooooo`;o00003Oooool6o`0000?ooooo0_l0001Fooooo`007?ooool00ol0003o
ooooooooo`19ooooo`;o00000_ooool2o`0002Sooooo6?l0000:ooooo`;o00000_ooool3o`0000Go
oooo1?l0000@ooooo`;o00002Oooool3o`0000Sooooo0_l0000:ooooo`;o00003Oooool4o`0005_o
oooo000Looooo`03o`000?oooooooooo04oooooo0_l0000VoooooaSo00002_ooool2o`0000;ooooo
0ol00003ooooo`Ko00007?ooool2o`0001Cooooo0_l00006ooooo`;o00001oooool2o`0005_ooooo
000Looooo`03o`000?oooooooooo04?ooooo0_l0000:ooooo`;o0000:?oooolCo`0000gooooo1Ol0
0005ooooo`Co00001?ooool2o`0001Sooooo0_l00004ooooo`;o000000?oooooo`000?l000003Ooo
ool4o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`0005Wooooo000Looooo`;o0000@Oooool2
o`000003ooooool0003o0000013ooooo0_l0000OoooooaKo000000?oooooo`000?l000002oooool4
o`0000Oooooo0_l00004ooooo`?o00000oooool2o`0001;ooooo0_l00004ooooo`;o000000Cooooo
o`000?l0003ooooo0_l0000:ooooo`Co00001?ooool4o`000003ooooool0003o000000;ooooo0_l0
001Iooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00004oooool2o`0001oooooo5_l00000
0ooooooo0000o`00000:ooooo`Co00001?ooool4o`000004ooooool0003o0000ooooo`;o000000Co
ooooo`000?l0003o00000_ooool2o`0000?ooooo0_l0000=ooooo`;o00000oooool2o`0000Cooooo
0ol00004ooooo`;o00000oooool3o`0000Cooooo1_l0001Pooooo`007?ooool00ol0003ooooooooo
o`13ooooo`;o00006oooool2o`0001Cooooo0_l00002ooooo`oo00000oooool2o`0000Cooooo0_l0
0005ooooo`;o000000?oooooo`000?l000000oooool7o`000003ooooool0003o000000Co00001ooo
ool2o`0001;ooooo0_l00004ooooo`?o00001?ooool2o`000003ooooool0003o000000?o00000ooo
ool6o`00067ooooo000Looooo`03o`000?oooooooooo04?ooooo0_l0000Kooooo`;o00004Oooool2
o`0000?ooooo4Ol000000ooooooo0000o`000002o`0000?ooooo0ol00002ooooo`;o00001?ooool2
o`0000Kooooo0ol00003ooooo`Co00002?ooool4o`0001Oooooo0_l00003ooooo`;o00000_ooool4
o`0000;ooooo1?l0001Uooooo`007?ooool00ol0003oooooooooo`1Fooooo`;o00002oooool2o`00
00kooooo0_l00003oooooa7o000000Coooooo`000?l0003o00001?ooool2o`0000?ooooo0_l0000=
ooooo`;o00000oooool5o`0000Oooooo1?l00009ooooo`;o00002_ooool4o`0000?ooooo1?l00006
ooooo`Co0000IOooool001cooooo00?o0000ooooooooool0A_ooool2o`0000cooooo1?l0000;oooo
o`;o00000_ooool2o`0000cooooo0_l00004ooooo`Co000000?oooooo`000?l000001?l000001?oo
oooo0000o`000?ooool2o`0001Kooooo0_l00009ooooo`;o00001_ooool2o`0000cooooo0_l00000
0ooooooo0000o`000002ooooo`;o00000oooool3o`0000Kooooo0_l0001_ooooo`007?ooool00ol0
003oooooooooo`12ooooo`Ko00000oooool2o`0000Oooooo0_l0000Aooooo`;o00003?ooool2o`00
00Kooooo0ol00002ooooo`Go00006oooool2o`0000Wooooo0_l00002ooooo`?o000000?oooooo`00
0?l000001?ooool2o`000003ooooool0003o000000Kooooo0_l00002ooooo`;o00000oooool2o`00
07Sooooo000Looooo`03o`000?oooooooooo04;ooooo1?l00005ooooo`;o00001?ooool2o`0002_o
oooo0ol000000ooooooo0000o`000004o`00013ooooo0_l00008ooooo`;o00003?ooool4o`000003
ooooool0003o000000Cooooo1Ol000001Ooooooo0000o`000?l0003ooooo00?o00001oooool2o`00
07Sooooo000Looooo`03o`000?oooooooooo057ooooo0_l0000Wooooo`;o00000oooool2o`000003
ooooool0003o000000;ooooo0_l0000=ooooo`;o000000?oooooo`000?l000005_ooool2o`0000Co
oooo0ol00003ooooo`?o00000_ooool3o`000003ooooool0003o000008;ooooo000Looooo`03o`00
0?oooooooooo07Kooooo0ol000000ooooooo0000o`00000Aooooo`;o00001_ooool5o`0001cooooo
1Ol000000ooooooo0000o`00002;ooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o00007Ooo
ool2o`0000[ooooo0ol000000ooooooo0000o`00000Aooooo`;o00001_ooool5o`000003ooooool0
003o000001Kooooo0_l00003ooooo`?o0000S_ooool001cooooo00?o0000ooooooooool0Aoooool2
o`0000;ooooo0_l0000Mooooo`;o00002Oooool3o`0000Wooooo0_l0000Cooooo`?o00000_ooool2
o`0000gooooo0_l00007ooooo`;o0000U?ooool001cooooo00?o0000ooooooooool0Aoooool2o`00
00Kooooo0_l0000Tooooo`;o00002_ooool2o`0001?ooooo0ol00002ooooo`;o000000Coooooo`00
0?l0003ooooo0_l00007ooooo`;o0000WOooool001cooooo00?o0000ooooooooool0A_ooool2o`00
00Cooooo0_l000000ooooooo0000o`000005ooooo`;o00007_ooool2o`0001kooooo1?l00004oooo
o`;o000000?oooooo`000?l000001_ooool2o`0000?ooooo0_l00004ooooo`;o00001oooool2o`00
01Wooooo0_l000000ooooooo0000o`00001/ooooo`007?ooool00ol0003oooooooooo`16ooooo`;o
00001?ooool2o`0000Sooooo0ol0000Mooooo`;o00001_ooool2o`0000_ooooo0ol00004ooooo`;o
00000oooool5o`0000gooooo0_l00003ooooo`;o00000_ooool6o`0000Gooooo0_l0000<ooooo`;o
000000?oooooo`000?l000002?ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l0
0000Ioooool001cooooo00?o0000ooooooooool0Coooool2o`0000Kooooo0_l0000Pooooo`;o0000
0oooool2o`000003ooooool0003o000000Kooooo1Ol00004ooooo`;o00000oooool2o`000003oooo
ool0003o000001?ooooo0_l000000ooooooo0000o`000002ooooo`;o00003Oooool2o`0000Cooooo
0_l000000ooooooo0000o`000004ooooo`;o00001_ooool3o`000004ooooool0003o0000o`0000?o
oooo0_l0001Qooooo`007?ooool2o`0004?ooooo0_l0000;ooooo`;o0000:?ooool2o`0000Kooooo
0_l00006ooooo`;o00000_ooool3o`0000Wooooo0_l00002ooooo`;o00002_ooool2o`0000Cooooo
0ol000000ooooooo0000o`00000;ooooo`?o00000_ooool2o`0000gooooo0_l00006ooooo`;o0000
0oooool2o`0000?ooooo0_l0001Qooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00001ooo
ool2o`0002gooooo0_l0000Aooooo`?o00000_ooool2o`0000Gooooo0_l00002ooooo`;o00001Ooo
ool2o`0000?ooooo0ol000001?oooooo0000o`000?ooool2o`000004ooooool0003o0000o`0000[o
oooo0ol0000<ooooo`;o000000?oooooo`000?l00000MOooool001cooooo00?o0000ooooooooool0
Boooool2o`0002cooooo0ol0000>ooooo`;o000000?oooooo`000?l000000oooool3o`000003oooo
ool0003o000000cooooo0_l00004ooooo`;o000000?oooooo`000?l000001Oooool2o`00017ooooo
0_l000001Ooooooo0000o`000?l0003ooooo00Ko00001?ooool2o`0000Gooooo0_l0001Xooooo`00
7?ooool00ol0003oooooooooo`1iooooo`;o00003oooool5o`0000;ooooo1ol0000Booooo`;o0000
00?oooooo`000?l000006?ooool2o`000005ooooool0003o0000o`000?ooool00_l000000ooooooo
0000o`000005ooooo`;o00001Oooool4o`0006Kooooo000Looooo`03o`000?oooooooooo053ooooo
0_l00007ooooo`;o00007oooool2o`00013ooooo0_l00003ooooo`;o000000?oooooo`000?l00000
0_l00007ooooo`;o00001?ooool2o`0000Cooooo1?l0000booooo`;o0000I_ooool001cooooo00?o
0000ooooooooool0D?ooool2o`0000Oooooo0_l0000Oooooo`;o000000?oooooo`000?l000005?oo
ool8o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`0002Gooooo0_l00002ooooo`;o00001_oo
ool2o`0006Wooooo000Looooo`03o`000?oooooooooo05Wooooo0_l0000Rooooo`Co00004_ooool9
o`0000;ooooo0_l0000;ooooo`Co00007_ooool2o`0000?ooooo0_l00002ooooo`Co00001?ooool2
o`0006Wooooo000Looooo`03o`000?oooooooooo04oooooo0_l00008ooooo`;o00009?ooool2o`00
01?ooooo0ol00002ooooo`Co000000?oooooo`000?l000001_ooool2o`0000Gooooo0_l0000Aoooo
o`;o00001oooool2o`0000;ooooo0_l00006ooooo`Go0000Koooool001cooooo00?o0000oooooooo
ool0Coooool2o`00037ooooo0_l00004ooooo`?o00002Oooool3o`0000Cooooo1Ol00006ooooo`;o
00005_ooool4o`0000Oooooo0_l0000:ooooo`?o0000LOooool001cooooo00?o0000ooooooooool0
P_ooool2o`0000Cooooo0ol0000<ooooo`;o00001?ooool4o`0001gooooo0_l0000<ooooo`;o0000
Noooool001cooooo00?o0000ooooooooool0Q_ooool3o`0000kooooo0_l00002ooooo`;o000000?o
ooooo`000?l000000ol0000Iooooo`?o00002Oooool3o`000003ooooool0003o000000Kooooo0_l0
001cooooo`007?ooool00ol0003oooooooooo`26ooooo`?o000000?oooooo`000?l000000_l0000=
ooooo`;o00001?ooool2o`0000Gooooo0_l0000Booooo`?o00002Oooool3o`0000Sooooo0ol0001c
ooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o0000=?ooool4o`0000gooooo0ol0000:oooo
o`;o00006?ooool3o`0000kooooo0_l0001dooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o
0000AOooool3o`0000Kooooo1?l0000:ooooo`;o00003_ooool3o`0000kooooo0_l0001dooooo`00
00Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0I?ooool2o`0003Oooooo0ol00003ooooo`Go00002_ooool4
o`0000Cooooo0_l0000;ooooo`;o00002oooool2o`0007?ooooo00001_ooooooMgMgoiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`1Tooooo`;o0000;_ooool2o`0000Kooooo1Ol00002ooooo`?o00003_ooool2o`0000Cooooo
0_l00003ooooo`;o00001_ooool2o`0000_ooooo0_l0001cooooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`1Hooooo`;o0000=Oooool2o`0000?ooooo1?l00004ooooo`Go000000?oooooo`000?l00000
0_l00005ooooo`;o00004_ooool2o`0008Sooooo00000ooooooo0000ooooo`02ooooo`03o`000?oo
oooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000F?ooool2o`0003Gooooo
0_l000000ooooooo0000o`000002ooooo`;o00001?ooool8o`0000Oooooo0_l0000Oooooo`;o0000
Noooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Oo<c<co0000o`00
0?l0003oc<c<00Kooooo00?o0000ooooooooool0T_ooool2o`0000;ooooo0_l00007ooooo`?o0000
9?ooool2o`0000Cooooo0_l0001kooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`2Jooooo`?o0000
0_ooool3o`0002?ooooo0ol00021ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05
o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`2Eooooo`?o00000_ooool3o`00
00?ooooo0_l00007ooooo`;o00000oooool2o`0001Gooooo0_l00022ooooo`0000Koooooonk^k_lb
<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003ooooooooo
o`1aooooo`;o00008_ooool3o`0000;ooooo0_l00007ooooo`;o00001?ooool2o`0000?ooooo0_l0
0008ooooo`;o00000oooool2o`000003ooooool0003o000008Oooooo000Looooo`03o`000?oooooo
oooo077ooooo0_l0000Wooooo`;o00001oooool2o`0000Gooooo1?l0000:ooooo`;o000000?ooooo
o`000?l000000_l000000ooooooo0000o`000027ooooo`007?ooool00ol0003oooooooooo`1Ooooo
o`;o0000BOooool4o`0000cooooo0ol00003ooooo`;o0000Qoooool001cooooo00?o0000oooooooo
ool0Goooool2o`0001Cooooo0ol0000Rooooo`;o00004?ooool2o`0000cooooo0_l0002=ooooo`00
7?ooool00ol0003oooooooooo`1Pooooo`;o00004oooool3o`0002;ooooo0_l0000Aooooo`;o0000
V_ooool001cooooo00?o0000ooooooooool0H?ooool2o`0000?ooooo0_l0000Aooooo`;o0000:?oo
ool2o`0000?ooooo0_l00004ooooo`;o0000V_ooool001cooooo00?o0000ooooooooool0IOooool2
o`00017ooooo0_l0000Xooooo`;o00000oooool2o`0000Cooooo0_l0002Jooooo`007?ooool00ol0
003oooooooooo`2Rooooo`;o0000YOooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`20ooooo`Co0000aOooool001cooooo00?o0000ooooooooool0P?oo
ool4o`000<Gooooo000Looooo`03o`000?oooooooooo06[ooooo0_l0000Kooooo`?o0000_oooool0
01cooooo0_l0001[ooooo`;o00006oooool6o`000;cooooo000Looooo`03o`000?oooooooooo08[o
oooo0ol0002looooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0a_ooool2o`00
087ooooo000Looooo`03o`000?oooooooooo07gooooo0_l00013ooooo`;o00000_ooool2o`00087o
oooo000Looooo`03o`000?oooooooooo07gooooo0_l00013ooooo`;o0000QOooool001cooooo00?o
0000ooooooooool0P?ooool2o`000<Oooooo000Looooo`03o`000?oooooooooo083ooooo0_l00037
ooooo`007?ooool00ol0003oooooooooo`29ooooo`;o0000__ooool001cooooo0_l0002:ooooo`Co
0000;Oooool2o`0008gooooo000Looooo`03o`000?oooooooooo08_ooooo0_l00003ooooo`;o0000
:?ooool2o`0008gooooo000Looooo`03o`000?oooooooooo093ooooo0_l0002gooooo`007?ooool0
0ol0003oooooooooo`2Gooooo`;o00007?ooool2o`0009;ooooo000Looooo`03o`000?oooooooooo
09Oooooo1?l0000Jooooo`;o0000T_ooool001cooooo00?o0000ooooooooool0VOooool2o`0000Go
oooo0_l0000=ooooo`;o0000V?ooool001cooooo00?o0000ooooooooool0X?ooool2o`0000Gooooo
0_l00002ooooo`;o00000_ooool2o`0009Sooooo000Looooo`03o`000?oooooooooo0:Oooooo0_l0
0002ooooo`;o0000W?ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Booooo`Co
000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003ooooooooo
o`05ooooo`?o0000oooooom:ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Doooo
o`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`00
5?ooool00ol0003oooooooooo`3ooooooe;ooooo000Booooo`03oeEEEOmVIVKo00000?ooooooE?oo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Gooooo00Co410@o`000?l0003o
oooo0_l000000ol@413oooooooooo`0Gooooo`;o000000So410@oooooooooooooooooa0@4?l0003o
A4A4olc<c0Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c02@ooooo`00Y_ooool01Ol0003ooooooooo
oooooooo000000Wooooo1_l0000<ooooo`03o`000?oooooooooo00Cooooo00?oV9RHoa0@4?oMgMd0
0oooool01OlQ8B7oV9RHoooooonHV9So8B4Q093ooooo002Vooooo`05o`000?ooooooooooooooool0
00006?ooool5o`0000Kooooo00?oQhN7oeEEEOooool00_ooool01Ol0003ooooooooooooooooo0000
093ooooo002Vooooo`05o`000?ooooooooooooooool000002Oooool6o`0000Wooooo00CoA4A4omgM
gOoooooo00001?ooool01Oo<c<co8B4Qo`000?mEEEGo000000?ooooo00Go<S8boiRHV?ooooooV9RH
oc8b<P2@ooooo`00Y_ooool01Ol0003oQhN7oooooonYZJWo000001Sooooo00CogMgMoeEEEOoooooo
00001?ooool01OlQ8B7oQhN7oooooonHV9So000000?ooooo00Goc<c<o`000?l0003o0000olc<c02@
ooooo`00YOooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo01Oooooo00?oMgMgolc<
c?l000001?ooool01Ol0003ooooooooooooooooo000000?ooooo00Go410@okZj^_oooooo^[Zjoa0@
402@ooooo`00a?ooool00oo^k^koA4A4o`000004ooooo`05ob4Q8OnHV9SoooooogMgMomEEED00ooo
ool01Ol0003o^[Zjoooooonj^[[o0000093ooooo0035ooooo`03ogMgMol0003ooooo00?ooooo00Go
c<c<oa0@4?l0003o<S8bonk^kP03ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0T?ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(504) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.66787 .36523 Mdot
.66752 .38595 Mdot
.32478 .55576 Mdot
.60541 .58265 Mdot
.35192 .67705 Mdot
.30262 .52071 Mdot
.36607 .32963 Mdot
.36009 .34764 Mdot
.31456 .52738 Mdot
.70141 .52962 Mdot
.39667 .34299 Mdot
.57808 .52518 Mdot
.37944 .33903 Mdot
.57228 .60141 Mdot
.5399 .41053 Mdot
.63747 .66726 Mdot
.61491 .41717 Mdot
.40908 .63712 Mdot
.63443 .67442 Mdot
.33171 .54126 Mdot
.57367 .71318 Mdot
.57061 .58836 Mdot
.63461 .42851 Mdot
.57092 .59853 Mdot
.59481 .63295 Mdot
.65645 .38691 Mdot
.67241 .36956 Mdot
.59384 .6459 Mdot
.62106 .61775 Mdot
.38847 .35032 Mdot
.21828 .56969 Mdot
.83967 .43289 Mdot
.5461 .64224 Mdot
.7973 .48498 Mdot
.35797 .34652 Mdot
.31572 .31239 Mdot
.30276 .55318 Mdot
.35302 .32158 Mdot
.36656 .35961 Mdot
.35846 .35324 Mdot
.36193 .32268 Mdot
.64894 .3837 Mdot
.37022 .36917 Mdot
.23545 .47485 Mdot
.57446 .62024 Mdot
.64693 .3213 Mdot
.17405 .46499 Mdot
.60829 .63975 Mdot
.63313 .37268 Mdot
.33574 .52722 Mdot
.46389 .79636 Mdot
.3885 .30564 Mdot
.48299 .37362 Mdot
.43887 .89908 Mdot
.39065 .34001 Mdot
.61277 .58775 Mdot
.31845 .51349 Mdot
.59105 .57538 Mdot
.59857 .55632 Mdot
.78736 .44888 Mdot
.56618 .57358 Mdot
.37699 .66195 Mdot
.67867 .42077 Mdot
.24954 .53145 Mdot
.31189 .52147 Mdot
.36084 .31529 Mdot
.66874 .42214 Mdot
.36954 .34381 Mdot
.62403 .62785 Mdot
.33743 .54096 Mdot
.61804 .6219 Mdot
.39281 .34971 Mdot
.67142 .41286 Mdot
.57366 .62429 Mdot
.57883 .3225 Mdot
.42024 .30361 Mdot
.35811 .52325 Mdot
.79363 .59519 Mdot
.49425 .832 Mdot
.33074 .59591 Mdot
.56197 .61574 Mdot
.38138 .83097 Mdot
.48379 .42117 Mdot
.67089 .38387 Mdot
.59836 .42909 Mdot
.60586 .22162 Mdot
.60369 .64599 Mdot
.38872 .55208 Mdot
.53529 .61096 Mdot
.46483 .56528 Mdot
.31867 .53467 Mdot
.66668 .40266 Mdot
.56964 .62287 Mdot
.54678 .62657 Mdot
.68098 .46067 Mdot
.62214 .58081 Mdot
.59913 .59949 Mdot
.61847 .45514 Mdot
.39993 .33151 Mdot
.58662 .50653 Mdot
.3455 .72254 Mdot
.50228 .38911 Mdot
.60928 .60321 Mdot
.28742 .53946 Mdot
.68382 .41708 Mdot
.5945 .60815 Mdot
.36307 .34371 Mdot
.56271 .6047 Mdot
.41969 .35164 Mdot
.61973 .41755 Mdot
.54101 .62089 Mdot
.41158 .66801 Mdot
.51959 .50389 Mdot
.62589 .40644 Mdot
.73409 .65586 Mdot
.56432 .57902 Mdot
.57598 .5686 Mdot
.665 .37886 Mdot
.31684 .55586 Mdot
.36983 .49145 Mdot
.64885 .42823 Mdot
.36265 .35826 Mdot
.61869 .38961 Mdot
.55899 .54407 Mdot
.32059 .55331 Mdot
.49229 .37639 Mdot
.49582 .38667 Mdot
.43436 .72056 Mdot
.56791 .62737 Mdot
.54946 .49428 Mdot
.29039 .53004 Mdot
.65446 .37905 Mdot
.37702 .34725 Mdot
.60389 .54986 Mdot
.63235 .39852 Mdot
.37699 .36562 Mdot
.36853 .65452 Mdot
.34848 .6702 Mdot
.63488 .37836 Mdot
.67689 .67446 Mdot
.40627 .31315 Mdot
.35392 .34952 Mdot
.46235 .79301 Mdot
.66985 .37983 Mdot
.38332 .67918 Mdot
.3931 .36479 Mdot
.52403 .73575 Mdot
.57641 .55379 Mdot
.43007 .75336 Mdot
.29531 .77295 Mdot
.46294 .79525 Mdot
.82591 .45821 Mdot
.40315 .67724 Mdot
.39006 .36697 Mdot
.61372 .62515 Mdot
.64086 .40022 Mdot
.63798 .39052 Mdot
.55042 .62761 Mdot
.58235 .63246 Mdot
.58018 .60948 Mdot
.59204 .5499 Mdot
.28581 .30339 Mdot
.56585 .61954 Mdot
.41952 .24537 Mdot
.6334 .40601 Mdot
.59005 .62599 Mdot
.27712 .54105 Mdot
.62037 .53507 Mdot
.35274 .32836 Mdot
.60087 .55984 Mdot
.58602 .63555 Mdot
.59912 .53778 Mdot
.37807 .37003 Mdot
.56763 .3003 Mdot
.57381 .82632 Mdot
.32101 .29607 Mdot
.4708 .33903 Mdot
.28902 .51779 Mdot
.55074 .59403 Mdot
.4008 .66965 Mdot
.60081 .51398 Mdot
.58508 .55731 Mdot
.46506 .80054 Mdot
.57433 .64046 Mdot
.82399 .51651 Mdot
.55325 .52636 Mdot
.58892 .21148 Mdot
.44144 .22653 Mdot
.58232 .5555 Mdot
.70936 .5769 Mdot
.42435 .74413 Mdot
.20192 .57526 Mdot
.38341 .34946 Mdot
.26874 .53721 Mdot
.30609 .55878 Mdot
.34717 .33137 Mdot
.51586 .6362 Mdot
.71124 .54048 Mdot
.62578 .59002 Mdot
.49519 .37916 Mdot
.63126 .34528 Mdot
.39288 .68447 Mdot
.6359 .37658 Mdot
.41176 .84211 Mdot
.40159 .59052 Mdot
.34411 .57926 Mdot
.38282 .63675 Mdot
.32618 .50926 Mdot
.50172 .36871 Mdot
.39068 .6787 Mdot
.59978 .58731 Mdot
.61839 .40407 Mdot
.4191 .74897 Mdot
.64489 .61689 Mdot
.45687 .12633 Mdot
.67741 .39622 Mdot
.49463 .50126 Mdot
.38647 .34311 Mdot
.25566 .54121 Mdot
.60324 .64595 Mdot
.58582 .58866 Mdot
.68429 .40534 Mdot
.61546 .63236 Mdot
.40741 .53675 Mdot
.58269 .63899 Mdot
.25529 .51903 Mdot
.43512 .67036 Mdot
.41839 .36341 Mdot
.38572 .63224 Mdot
.66453 .41937 Mdot
.39309 .27931 Mdot
.28338 .54116 Mdot
.49645 .58733 Mdot
.37823 .35539 Mdot
.37618 .65032 Mdot
.29958 .54889 Mdot
.41708 .66281 Mdot
.54018 .59725 Mdot
.31187 .551 Mdot
.37174 .67123 Mdot
.41308 .44145 Mdot
.59992 .60079 Mdot
.46097 .73634 Mdot
.4085 .34233 Mdot
.66135 .36512 Mdot
.57382 .56304 Mdot
.48797 .36587 Mdot
.57945 .53743 Mdot
.53888 .47873 Mdot
.50739 .36389 Mdot
.52593 .38515 Mdot
.35147 .58159 Mdot
.36106 .67509 Mdot
.56267 .35165 Mdot
.40429 .48317 Mdot
.61519 .41844 Mdot
.54326 .58861 Mdot
.63935 .27517 Mdot
.40892 .34503 Mdot
.59875 .58293 Mdot
.58343 .22557 Mdot
.39357 .36506 Mdot
.58734 .56976 Mdot
.36625 .31983 Mdot
.63726 .39576 Mdot
.44904 .42475 Mdot
.63261 .3677 Mdot
.60366 .57765 Mdot
.38391 .32013 Mdot
.27285 .54228 Mdot
.65591 .38753 Mdot
.56412 .59686 Mdot
.55766 .61656 Mdot
.49835 .37881 Mdot
.58018 .62582 Mdot
.65405 .2595 Mdot
.6063 .64058 Mdot
.33618 .51877 Mdot
.62373 .60039 Mdot
.39369 .76097 Mdot
.34682 .66024 Mdot
.6426 .4358 Mdot
.51243 .36549 Mdot
.32132 .53526 Mdot
.43637 .42877 Mdot
.45102 .69516 Mdot
.56487 .61138 Mdot
.51494 .38286 Mdot
.49408 .49621 Mdot
.35569 .32325 Mdot
.57654 .65818 Mdot
.38718 .51276 Mdot
.31319 .54018 Mdot
.49631 .37352 Mdot
.62282 .65874 Mdot
.6708 .36302 Mdot
.61491 .59654 Mdot
.29755 .55175 Mdot
.65234 .3611 Mdot
.6148 .55952 Mdot
.21384 .37985 Mdot
.48567 .36693 Mdot
.39042 .3184 Mdot
.66202 .46063 Mdot
.54829 .61237 Mdot
.29616 .55954 Mdot
.63329 .39196 Mdot
.3884 .32896 Mdot
.62865 .42036 Mdot
.40375 .74647 Mdot
.5779 .4836 Mdot
.29808 .35526 Mdot
.42223 .64243 Mdot
.83708 .60057 Mdot
.31933 .30797 Mdot
.55594 .50165 Mdot
.29591 .48392 Mdot
.51753 .16373 Mdot
.29511 .54554 Mdot
.69203 .6404 Mdot
.32221 .5247 Mdot
.61339 .60781 Mdot
.30598 .52111 Mdot
.66656 .24568 Mdot
.57995 .64628 Mdot
.29809 .50862 Mdot
.28276 .35818 Mdot
.57038 .64085 Mdot
.6302 .40363 Mdot
.76594 .33902 Mdot
.74724 .6561 Mdot
.65576 .706 Mdot
.30923 .50718 Mdot
.68732 .66978 Mdot
.5954 .64739 Mdot
.6309 .6769 Mdot
.64634 .39844 Mdot
.57972 .53039 Mdot
.38098 .69284 Mdot
.41067 .67456 Mdot
.50871 .77274 Mdot
.76356 .66301 Mdot
.53662 .66958 Mdot
.6489 .38799 Mdot
.47864 .83066 Mdot
.58425 .31821 Mdot
.48376 .36857 Mdot
.36738 .35758 Mdot
.55744 .30721 Mdot
.61537 .66826 Mdot
.63231 .49139 Mdot
.41911 .51315 Mdot
.66738 .40505 Mdot
.35404 .41337 Mdot
.38208 .3262 Mdot
.69041 .69766 Mdot
.71781 .5065 Mdot
.58301 .608 Mdot
.3982 .31622 Mdot
.54538 .53875 Mdot
.40918 .51817 Mdot
.44939 .74111 Mdot
.21098 .45014 Mdot
.60259 .58792 Mdot
.57376 .34654 Mdot
.58548 .55885 Mdot
.43723 .73359 Mdot
.60008 .57731 Mdot
.63051 .41879 Mdot
.56091 .6711 Mdot
.40181 .46934 Mdot
.68783 .73248 Mdot
.40281 .58461 Mdot
.37331 .68334 Mdot
.57501 .59855 Mdot
.5888 .59653 Mdot
.37336 .66313 Mdot
.66299 .40726 Mdot
.54879 .57999 Mdot
.17354 .4493 Mdot
.56537 .62076 Mdot
.37794 .30541 Mdot
.45272 .45994 Mdot
.83164 .54195 Mdot
.56874 .64483 Mdot
.67636 .36811 Mdot
.35681 .32841 Mdot
.3828 .36153 Mdot
.55353 .6734 Mdot
.40692 .33163 Mdot
.61473 .62656 Mdot
.45393 .45884 Mdot
.628 .42658 Mdot
.57339 .5202 Mdot
.65936 .41187 Mdot
.45242 .8178 Mdot
.39941 .36445 Mdot
.51949 .38087 Mdot
.67974 .69503 Mdot
.3708 .33029 Mdot
.45666 .63312 Mdot
.55655 .66744 Mdot
.64 .62937 Mdot
.66096 .45818 Mdot
.27412 .54612 Mdot
.51602 .37356 Mdot
.39158 .33655 Mdot
.56809 .61925 Mdot
.60062 .60877 Mdot
.39763 .31257 Mdot
.75888 .42091 Mdot
.21708 .56698 Mdot
.60365 .57361 Mdot
.63663 .42244 Mdot
.65298 .38023 Mdot
.58433 .54642 Mdot
.57911 .56095 Mdot
.28159 .51156 Mdot
.51592 .3824 Mdot
.51688 .37024 Mdot
.50967 .39379 Mdot
.26651 .50997 Mdot
.8151 .63349 Mdot
.35379 .34951 Mdot
.83817 .46494 Mdot
.58058 .25825 Mdot
.5688 .68043 Mdot
.29365 .5558 Mdot
.5825 .57978 Mdot
.6076 .61132 Mdot
.38979 .32251 Mdot
.74882 .6976 Mdot
.53851 .63752 Mdot
.67048 .37043 Mdot
.38839 .30668 Mdot
.56978 .52746 Mdot
.34823 .29652 Mdot
.40628 .65073 Mdot
.6156 .70582 Mdot
.40442 .32134 Mdot
.62259 .41725 Mdot
.40347 .31939 Mdot
.58638 .60076 Mdot
.63 .65387 Mdot
.66866 .40457 Mdot
.36516 .64995 Mdot
.54493 .61447 Mdot
.58761 .56798 Mdot
.20956 .64376 Mdot
.57914 .32499 Mdot
.34578 .69884 Mdot
.60572 .62711 Mdot
.63912 .59817 Mdot
.38248 .6413 Mdot
.54497 .59851 Mdot
.62135 .60582 Mdot
.51832 .5013 Mdot
.42255 .34705 Mdot
.36159 .68376 Mdot
.68036 .73275 Mdot
.67812 .39177 Mdot
.64088 .25345 Mdot
.49544 .38381 Mdot
.38574 .38304 Mdot
.45199 .41617 Mdot
.50741 .3726 Mdot
.56836 .23483 Mdot
.32945 .26644 Mdot
.51517 .37714 Mdot
.25056 .53941 Mdot
.67507 .55502 Mdot
.62237 .60931 Mdot
.59647 .56102 Mdot
.36166 .6745 Mdot
.65986 .37109 Mdot
.42838 .24358 Mdot
.42752 .34496 Mdot
.5706 .58097 Mdot
.65057 .35538 Mdot
.59726 .21587 Mdot
.49955 .37233 Mdot
.40577 .66628 Mdot
.35842 .65754 Mdot
.58305 .56131 Mdot
.47004 .60235 Mdot
.65142 .38615 Mdot
.56421 .59677 Mdot
.56245 .57102 Mdot
.32702 .52826 Mdot
.61921 .39763 Mdot
.2762 .53692 Mdot
.51878 .36676 Mdot
.47761 .15101 Mdot
.1806 .59379 Mdot
.4053 .3511 Mdot
.38016 .40112 Mdot
.39051 .37598 Mdot
.21926 .41192 Mdot
.51695 .38118 Mdot
.56691 .59242 Mdot
.65503 .42817 Mdot
.56272 .60209 Mdot
.56685 .62195 Mdot
.58794 .6081 Mdot
.53696 .67018 Mdot
.45001 .81064 Mdot
.39639 .65607 Mdot
.60622 .65345 Mdot
.2944 .50212 Mdot
.58608 .21551 Mdot
.71189 .30153 Mdot
.5804 .59679 Mdot
.57742 .56856 Mdot
.67672 .41309 Mdot
.53985 .59332 Mdot
.36093 .343 Mdot
.67475 .38719 Mdot
.60673 .6021 Mdot
.34972 .73008 Mdot
.55337 .57515 Mdot
.35604 .39304 Mdot
.40679 .32304 Mdot
.65777 .62018 Mdot
.63499 .63228 Mdot
.51799 .38018 Mdot
.51536 .3736 Mdot
.4914 .36223 Mdot
.38184 .30826 Mdot
.32629 .53062 Mdot
.27507 .56616 Mdot
.62476 .64785 Mdot
.61074 .63138 Mdot
.63414 .64695 Mdot
.31277 .49545 Mdot
.39618 .479 Mdot
.58247 .37687 Mdot
.54374 .53585 Mdot
.27238 .50868 Mdot
.63021 .46316 Mdot
.7066 .70318 Mdot
.67273 .37871 Mdot
.30411 .48584 Mdot
.36988 .35386 Mdot
.40501 .67757 Mdot
.50377 .8036 Mdot
.64218 .42827 Mdot
.68414 .39691 Mdot
.29158 .51311 Mdot
.49152 .45589 Mdot
.51059 .919 Mdot
.29096 .5365 Mdot
.36353 .57258 Mdot
.64835 .39482 Mdot
.54019 .63527 Mdot
.49501 .49049 Mdot
.51218 .45959 Mdot
.30462 .5111 Mdot
.55773 .61536 Mdot
.44189 .61477 Mdot
.28237 .51113 Mdot
.56658 .65992 Mdot
.30697 .50615 Mdot
.39641 .3199 Mdot
.28612 .52921 Mdot
.61722 .37205 Mdot
.56466 .62551 Mdot
.46026 .90721 Mdot
.47655 .41306 Mdot
.56043 .59309 Mdot
.39581 .30928 Mdot
.26146 .3509 Mdot
.59226 .59754 Mdot
.38147 .69065 Mdot
.281 .50218 Mdot
.20573 .43935 Mdot
.61996 .59954 Mdot
.30267 .51558 Mdot
.60672 .38472 Mdot
.2895 .48667 Mdot
.33735 .70064 Mdot
.51646 .37154 Mdot
.63668 .39908 Mdot
.51977 .4009 Mdot
.35417 .34072 Mdot
.56624 .55157 Mdot
.55617 .57765 Mdot
.63458 .41343 Mdot
.42479 .43136 Mdot
.53262 .6496 Mdot
.56262 .61574 Mdot
.27701 .51822 Mdot
.30849 .49871 Mdot
.55277 .39764 Mdot
.28632 .54503 Mdot
.63867 .59483 Mdot
.63201 .41372 Mdot
.61235 .5964 Mdot
.6298 .39368 Mdot
.54207 .59318 Mdot
.50603 .34444 Mdot
.66897 .37422 Mdot
.50349 .55688 Mdot
.56806 .63017 Mdot
.70929 .35423 Mdot
.54963 .61713 Mdot
.60071 .59418 Mdot
.29253 .49696 Mdot
.39007 .66497 Mdot
.55665 .64998 Mdot
.38463 .27796 Mdot
.39685 .64172 Mdot
.79407 .42005 Mdot
.31932 .55364 Mdot
.36513 .65435 Mdot
.49752 .75436 Mdot
.51211 .36549 Mdot
.38236 .65715 Mdot
.52469 .36273 Mdot
.40695 .34338 Mdot
.61233 .40233 Mdot
.56798 .63751 Mdot
.52026 .15808 Mdot
.21988 .57115 Mdot
.50269 .3817 Mdot
.57262 .5652 Mdot
.58644 .58047 Mdot
.66228 .3598 Mdot
.40187 .8378 Mdot
.25141 .51863 Mdot
.60472 .59234 Mdot
.65542 .42443 Mdot
.34719 .80918 Mdot
.29542 .5073 Mdot
.39567 .65269 Mdot
.41219 .35608 Mdot
.6584 .34125 Mdot
.52056 .37604 Mdot
.39828 .36525 Mdot
.35432 .52028 Mdot
.4673 .80417 Mdot
.61909 .59465 Mdot
.284 .55012 Mdot
.46294 .7958 Mdot
.55739 .52313 Mdot
.34745 .35077 Mdot
.51729 .34903 Mdot
.66756 .39988 Mdot
.39579 .31082 Mdot
.3659 .68124 Mdot
.6163 .41703 Mdot
.66257 .40948 Mdot
.36485 .35239 Mdot
.44187 .209 Mdot
.49791 .49322 Mdot
.3582 .31281 Mdot
.52068 .47781 Mdot
.46027 .79267 Mdot
.51618 .38732 Mdot
.40557 .66813 Mdot
.3501 .74117 Mdot
.65156 .3841 Mdot
.55886 .30613 Mdot
.4652 .79844 Mdot
.59945 .59911 Mdot
.37189 .67602 Mdot
.60287 .23013 Mdot
.40254 .38025 Mdot
.3816 .36615 Mdot
.36791 .50551 Mdot
.38426 .68674 Mdot
.5655 .56176 Mdot
.82691 .56687 Mdot
.56183 .63539 Mdot
.39867 .36308 Mdot
.41532 .52364 Mdot
.61971 .39863 Mdot
.35121 .33373 Mdot
.40535 .53959 Mdot
.60843 .61336 Mdot
.55932 .58469 Mdot
.43547 .64362 Mdot
.62069 .38952 Mdot
.52337 .3803 Mdot
.55928 .61001 Mdot
.59156 .57284 Mdot
.5726 .54797 Mdot
.66444 .72575 Mdot
.49562 .55681 Mdot
.60481 .59791 Mdot
.26116 .5437 Mdot
.64035 .5831 Mdot
.59344 .55141 Mdot
.66378 .35816 Mdot
.39078 .76782 Mdot
.51919 .36674 Mdot
.5972 .56293 Mdot
.60327 .57268 Mdot
.36234 .35533 Mdot
.4962 .49411 Mdot
.51465 .45822 Mdot
.33163 .51532 Mdot
.36814 .52287 Mdot
.62871 .58905 Mdot
.6373 .40588 Mdot
.37892 .69383 Mdot
.62041 .54184 Mdot
.67559 .38077 Mdot
.61197 .65382 Mdot
.29997 .50154 Mdot
.5133 .38059 Mdot
.52611 .55294 Mdot
.37948 .66347 Mdot
.41489 .32274 Mdot
.82545 .43578 Mdot
.26974 .53439 Mdot
.59799 .63798 Mdot
.28535 .57063 Mdot
.30365 .53661 Mdot
.50045 .38248 Mdot
.64149 .64143 Mdot
.63998 .39202 Mdot
.62111 .40807 Mdot
.43731 .79333 Mdot
.25942 .51587 Mdot
.23849 .69738 Mdot
.39954 .32239 Mdot
.587 .65531 Mdot
.65042 .30486 Mdot
.62066 .40162 Mdot
.4356 .7251 Mdot
.36576 .6525 Mdot
.38258 .36591 Mdot
.53174 .38853 Mdot
.66842 .37192 Mdot
.62441 .3929 Mdot
.57024 .62219 Mdot
.57681 .58976 Mdot
.32537 .48736 Mdot
.42845 .74701 Mdot
.36588 .32056 Mdot
.4028 .65354 Mdot
.33819 .52664 Mdot
.61052 .61832 Mdot
.67042 .39119 Mdot
.82588 .55696 Mdot
.54813 .61016 Mdot
.2971 .5026 Mdot
.66635 .39089 Mdot
.3853 .65125 Mdot
.36581 .66328 Mdot
.59957 .59735 Mdot
.81681 .54048 Mdot
.36889 .33255 Mdot
.62924 .40806 Mdot
.60932 .44167 Mdot
.61603 .64395 Mdot
.57772 .59541 Mdot
.53308 .57053 Mdot
.34877 .3461 Mdot
.53999 .53373 Mdot
.40129 .63822 Mdot
.64419 .37755 Mdot
.56013 .60054 Mdot
.37719 .66135 Mdot
.63029 .4895 Mdot
.50806 .37618 Mdot
.29465 .50845 Mdot
.38471 .69021 Mdot
.38327 .67323 Mdot
.39213 .64302 Mdot
.55807 .30914 Mdot
.68281 .42047 Mdot
.63867 .78356 Mdot
.5616 .62378 Mdot
.45922 .79148 Mdot
.53968 .58379 Mdot
.37876 .31353 Mdot
.26576 .53476 Mdot
.57426 .61759 Mdot
.56164 .62429 Mdot
.8254 .49455 Mdot
.63991 .66741 Mdot
.64353 .66661 Mdot
.61924 .41256 Mdot
.70627 .40834 Mdot
.29311 .55821 Mdot
.26203 .74824 Mdot
.7755 .32467 Mdot
.62575 .58425 Mdot
.48633 .45566 Mdot
.67375 .38626 Mdot
.37576 .36694 Mdot
.51161 .47989 Mdot
.32695 .32422 Mdot
.6538 .37386 Mdot
.61221 .61078 Mdot
.82289 .44153 Mdot
.41597 .65212 Mdot
.58111 .60718 Mdot
.37496 .34851 Mdot
.58069 .6083 Mdot
.37659 .31022 Mdot
.68398 .3368 Mdot
.50673 .44557 Mdot
.57488 .6419 Mdot
.62331 .5894 Mdot
.59129 .50052 Mdot
.57963 .59411 Mdot
.23501 .43336 Mdot
.65885 .40016 Mdot
.49656 .57872 Mdot
.59419 .54269 Mdot
.78717 .57051 Mdot
.55435 .57699 Mdot
.44134 .40769 Mdot
.55513 .5842 Mdot
.63115 .73374 Mdot
.56962 .55834 Mdot
.55147 .59255 Mdot
.38332 .32385 Mdot
.36524 .36036 Mdot
.60594 .38077 Mdot
.52351 .38488 Mdot
.58798 .21233 Mdot
.58258 .56777 Mdot
.30576 .49624 Mdot
.56887 .42689 Mdot
.38802 .67021 Mdot
.64812 .37699 Mdot
.14836 .61796 Mdot
.3588 .32293 Mdot
.25042 .53454 Mdot
.31532 .5858 Mdot
.27451 .55797 Mdot
.33469 .50307 Mdot
.71181 .36371 Mdot
.40812 .66418 Mdot
.55987 .56883 Mdot
.80228 .49608 Mdot
.58106 .33477 Mdot
.6158 .64169 Mdot
.24725 .55305 Mdot
.65253 .54026 Mdot
.45081 .80207 Mdot
.41741 .66678 Mdot
.39903 .67983 Mdot
.38877 .33162 Mdot
.32185 .55653 Mdot
.53774 .54589 Mdot
.36566 .65409 Mdot
.26633 .53256 Mdot
.49301 .38598 Mdot
.36345 .6112 Mdot
.64764 .38541 Mdot
.66998 .68085 Mdot
.64905 .31498 Mdot
.36062 .32224 Mdot
.39966 .28512 Mdot
.65682 .44998 Mdot
.62444 .43689 Mdot
.52021 .39003 Mdot
.2876 .5045 Mdot
.61153 .4111 Mdot
.56555 .62487 Mdot
.64484 .61729 Mdot
.58169 .56131 Mdot
.36137 .66958 Mdot
.56655 .56737 Mdot
.27582 .51277 Mdot
.36293 .32951 Mdot
.31782 .53722 Mdot
.36849 .32731 Mdot
.79499 .39139 Mdot
.59389 .55397 Mdot
.57529 .59509 Mdot
.45957 .45594 Mdot
.62931 .38471 Mdot
.7922 .48454 Mdot
.29232 .50207 Mdot
.32179 .51819 Mdot
.6114 .59635 Mdot
.65087 .43548 Mdot
.44667 .66729 Mdot
.49088 .47576 Mdot
.5574 .57923 Mdot
.65847 .40113 Mdot
.61257 .59214 Mdot
.22714 .3891 Mdot
.51061 .43345 Mdot
.62713 .41786 Mdot
.68942 .7324 Mdot
.57613 .62623 Mdot
.65091 .62251 Mdot
.65373 .57639 Mdot
.58885 .72147 Mdot
.55126 .65517 Mdot
.67662 .39667 Mdot
.60163 .55881 Mdot
.64201 .40608 Mdot
.29992 .54107 Mdot
.35348 .35136 Mdot
.64334 .40282 Mdot
.56242 .63367 Mdot
.78028 .33749 Mdot
.35973 .33414 Mdot
.57391 .61012 Mdot
.39572 .33839 Mdot
.61609 .38741 Mdot
.63428 .37411 Mdot
.53713 .37351 Mdot
.35416 .57618 Mdot
.36184 .34002 Mdot
.61126 .63203 Mdot
.57293 .31062 Mdot
.61276 .59701 Mdot
.36825 .52762 Mdot
.60636 .54522 Mdot
.62412 .61788 Mdot
.84476 .58847 Mdot
.43478 .42493 Mdot
.19993 .67326 Mdot
.43323 .34339 Mdot
.57187 .30208 Mdot
.5978 .39479 Mdot
.41677 .66773 Mdot
.38512 .4094 Mdot
.49852 .36429 Mdot
.26627 .54936 Mdot
.57101 .61943 Mdot
.71248 .32748 Mdot
.36776 .30743 Mdot
.39441 .66361 Mdot
.57479 .64087 Mdot
.32163 .56093 Mdot
.47704 .39396 Mdot
.38917 .36657 Mdot
.64751 .38338 Mdot
.63677 .37506 Mdot
.51346 .83491 Mdot
.5611 .59523 Mdot
.57297 .58887 Mdot
.3576 .34176 Mdot
.52239 .58169 Mdot
.39731 .64458 Mdot
.28922 .36953 Mdot
.37799 .3507 Mdot
.50351 .43096 Mdot
.61795 .41354 Mdot
.58484 .58035 Mdot
.45203 .46131 Mdot
.51751 .28332 Mdot
.67904 .48465 Mdot
.38101 .68172 Mdot
.46076 .65504 Mdot
.67675 .39682 Mdot
.37939 .34804 Mdot
.50155 .76618 Mdot
.53483 .59797 Mdot
.58816 .57892 Mdot
.47102 .6695 Mdot
.49539 .47619 Mdot
.37486 .56533 Mdot
.53724 .56754 Mdot
.47893 .51261 Mdot
.61115 .59785 Mdot
.60088 .60895 Mdot
.6249 .62395 Mdot
.6098 .55642 Mdot
.65483 .40444 Mdot
.75602 .64142 Mdot
.29704 .52273 Mdot
.68936 .54131 Mdot
.35233 .4913 Mdot
.59247 .64914 Mdot
.61059 .61121 Mdot
.73651 .60338 Mdot
.56258 .47356 Mdot
.65656 .39509 Mdot
.61226 .44433 Mdot
.3541 .34844 Mdot
.63817 .67153 Mdot
.26629 .5088 Mdot
.6614 .59138 Mdot
.311 .53007 Mdot
.65859 .40282 Mdot
.32488 .54097 Mdot
.38679 .29869 Mdot
.28442 .55017 Mdot
.25916 .52032 Mdot
.40162 .36614 Mdot
.62966 .37457 Mdot
.54936 .59557 Mdot
.40645 .36003 Mdot
.44934 .66042 Mdot
.36162 .66911 Mdot
.5375 .37082 Mdot
.53945 .63464 Mdot
.64516 .65507 Mdot
.21077 .38429 Mdot
.3167 .55002 Mdot
.53483 .46281 Mdot
.66797 .37336 Mdot
.37186 .69071 Mdot
.65078 .40626 Mdot
.56911 .80544 Mdot
.3767 .66998 Mdot
.53601 .36894 Mdot
.48549 .76512 Mdot
.34869 .28191 Mdot
.59328 .53246 Mdot
.65946 .46012 Mdot
.31181 .53291 Mdot
.38028 .30535 Mdot
.59591 .22512 Mdot
.58427 .62035 Mdot
.48657 .38521 Mdot
.62581 .44252 Mdot
.51307 .36643 Mdot
.37538 .34634 Mdot
.42978 .38584 Mdot
.5624 .58799 Mdot
.3614 .28143 Mdot
.62021 .5723 Mdot
.68165 .68779 Mdot
.35841 .50879 Mdot
.61903 .47215 Mdot
.61612 .60102 Mdot
.29093 .50629 Mdot
.61491 .59904 Mdot
.68771 .60873 Mdot
.47332 .7818 Mdot
.62514 .57012 Mdot
.60165 .48145 Mdot
.20295 .42125 Mdot
.66939 .3953 Mdot
.63785 .59843 Mdot
.51008 .38681 Mdot
.5997 .62601 Mdot
.58036 .14594 Mdot
.38295 .65891 Mdot
.34605 .69468 Mdot
.56253 .63224 Mdot
.56117 .60752 Mdot
.81912 .51957 Mdot
.70378 .39963 Mdot
.53231 .38724 Mdot
.59251 .58204 Mdot
.4882 .67933 Mdot
.3886 .32725 Mdot
.61274 .55565 Mdot
.59635 .55849 Mdot
.20799 .62285 Mdot
.39236 .32881 Mdot
.30807 .55523 Mdot
.50973 .36468 Mdot
.32526 .51046 Mdot
.35596 .69322 Mdot
.48738 .53037 Mdot
.44281 .72086 Mdot
.51657 .43026 Mdot
.37734 .68805 Mdot
.59248 .65079 Mdot
.59916 .44094 Mdot
.55574 .60033 Mdot
.39705 .67963 Mdot
.38887 .35011 Mdot
.65329 .40187 Mdot
.67498 .67589 Mdot
.49657 .3811 Mdot
.59901 .65386 Mdot
.4208 .66383 Mdot
.64154 .39839 Mdot
.45476 .27444 Mdot
.66428 .37393 Mdot
.37363 .32679 Mdot
.34792 .32916 Mdot
.38307 .66853 Mdot
.65306 .40625 Mdot
.32778 .51587 Mdot
.43586 .35105 Mdot
.61236 .54776 Mdot
.38096 .29634 Mdot
.60924 .41684 Mdot
.67589 .37285 Mdot
.64701 .43286 Mdot
.60696 .55773 Mdot
.49483 .4689 Mdot
.53988 .57613 Mdot
.35857 .33691 Mdot
.29004 .56168 Mdot
.43485 .75477 Mdot
.8077 .51881 Mdot
.49698 .43169 Mdot
.55543 .65134 Mdot
.56891 .56645 Mdot
.5824 .56181 Mdot
.60995 .57867 Mdot
.29246 .36984 Mdot
.59429 .55421 Mdot
.38001 .31937 Mdot
.30324 .53087 Mdot
.56705 .57255 Mdot
.51267 .38535 Mdot
.39852 .48301 Mdot
.37613 .69423 Mdot
.64314 .70475 Mdot
.68284 .29226 Mdot
.64334 .39869 Mdot
.28913 .54896 Mdot
.32738 .5371 Mdot
.36868 .65444 Mdot
.40356 .36124 Mdot
.65694 .3712 Mdot
.61073 .73299 Mdot
.40688 .6431 Mdot
.59736 .56364 Mdot
.45587 .4578 Mdot
.69903 .71588 Mdot
.57097 .65058 Mdot
.59407 .60084 Mdot
.52435 .37788 Mdot
.25217 .5363 Mdot
.5932 .17656 Mdot
.43813 .21894 Mdot
.38814 .66558 Mdot
.39617 .64899 Mdot
.66408 .42421 Mdot
.58866 .65582 Mdot
.36744 .33504 Mdot
.48717 .50591 Mdot
.22274 .36362 Mdot
.63008 .23771 Mdot
.21897 .41512 Mdot
.55208 .57685 Mdot
.76187 .60944 Mdot
.60128 .53942 Mdot
.68383 .41725 Mdot
.65246 .43315 Mdot
.65254 .39075 Mdot
.38228 .32503 Mdot
.4702 .80739 Mdot
.38095 .31855 Mdot
.69029 .29226 Mdot
.66691 .41259 Mdot
.4158 .45025 Mdot
.31786 .51229 Mdot
.62391 .676 Mdot
.40738 .66678 Mdot
.42407 .70544 Mdot
.63877 .61267 Mdot
.4699 .60905 Mdot
.29403 .55581 Mdot
.64541 .36526 Mdot
.55786 .66715 Mdot
.57764 .20739 Mdot
.49137 .45328 Mdot
.17995 .45918 Mdot
.70109 .42708 Mdot
.37347 .66443 Mdot
.70522 .55027 Mdot
.40527 .64514 Mdot
.38578 .36588 Mdot
.57908 .62273 Mdot
.55183 .62682 Mdot
.60368 .58709 Mdot
.6101 .56231 Mdot
.39223 .33767 Mdot
.60958 .54177 Mdot
.39496 .76171 Mdot
.49007 .37872 Mdot
.38885 .45384 Mdot
.3699 .6597 Mdot
.3928 .31513 Mdot
.30303 .53463 Mdot
.52175 .39043 Mdot
.41969 .63728 Mdot
.57874 .54645 Mdot
.5566 .62153 Mdot
.49327 .38459 Mdot
.51466 .60953 Mdot
.61594 .66904 Mdot
.30038 .51908 Mdot
.40917 .50364 Mdot
.35705 .67229 Mdot
.40863 .67161 Mdot
.39907 .31551 Mdot
.6509 .40649 Mdot
.36026 .66149 Mdot
.3223 .55717 Mdot
.61752 .56857 Mdot
.62376 .5939 Mdot
.60849 .41549 Mdot
.46455 .79912 Mdot
.38006 .69523 Mdot
.55326 .52503 Mdot
.63551 .38304 Mdot
.62861 .44506 Mdot
.59247 .58404 Mdot
.58953 .52447 Mdot
.68593 .39668 Mdot
.38154 .64962 Mdot
.40092 .32047 Mdot
.43513 .44301 Mdot
.38011 .31625 Mdot
.63554 .38895 Mdot
.64244 .59474 Mdot
.61869 .39257 Mdot
.58272 .62436 Mdot
.24879 .76679 Mdot
.58086 .55507 Mdot
.50957 .66035 Mdot
.39217 .60008 Mdot
.30452 .50555 Mdot
.29893 .50519 Mdot
.51337 .38212 Mdot
.67558 .38306 Mdot
.62196 .54162 Mdot
.40878 .65837 Mdot
.57243 .30304 Mdot
.68305 .43334 Mdot
.26455 .51398 Mdot
.25169 .52741 Mdot
.38983 .34824 Mdot
.55779 .57309 Mdot
.58135 .57779 Mdot
.28797 .5524 Mdot
.26936 .35384 Mdot
.64439 .411 Mdot
.57278 .58925 Mdot
.60232 .55234 Mdot
.29819 .52535 Mdot
.43139 .37719 Mdot
.63053 .449 Mdot
.60444 .55279 Mdot
.46334 .76843 Mdot
.3692 .31243 Mdot
.60234 .64169 Mdot
.60085 .54016 Mdot
.38796 .674 Mdot
.44983 .69462 Mdot
.46171 .79231 Mdot
.37601 .37049 Mdot
.51919 .37333 Mdot
.54768 .62158 Mdot
.30916 .50861 Mdot
.54154 .64167 Mdot
.33652 .24555 Mdot
.48902 .3733 Mdot
.56584 .5845 Mdot
.62953 .59428 Mdot
.62819 .39769 Mdot
.56495 .59337 Mdot
.50589 .34594 Mdot
.27674 .52323 Mdot
.56547 .58386 Mdot
.81469 .54403 Mdot
.38756 .34969 Mdot
.63895 .61746 Mdot
.39566 .68588 Mdot
.38605 .55755 Mdot
.76891 .34917 Mdot
.32246 .49988 Mdot
.36617 .66647 Mdot
.56525 .56861 Mdot
.3277 .51062 Mdot
.41155 .3581 Mdot
.48888 .58774 Mdot
.59779 .65005 Mdot
.37584 .31639 Mdot
.36185 .33238 Mdot
.38433 .6648 Mdot
.18983 .67725 Mdot
.62876 .5933 Mdot
.57951 .60357 Mdot
.19797 .37982 Mdot
.68714 .37791 Mdot
.57548 .61146 Mdot
.55594 .57679 Mdot
.40837 .34129 Mdot
.55774 .7897 Mdot
.46302 .64646 Mdot
.28292 .35735 Mdot
.37461 .31129 Mdot
.24534 .52758 Mdot
.2723 .52905 Mdot
.3675 .66597 Mdot
.66685 .38841 Mdot
.36173 .67983 Mdot
.28774 .52479 Mdot
.60104 .59268 Mdot
.39484 .35733 Mdot
.73344 .43049 Mdot
.39823 .30986 Mdot
.33186 .55409 Mdot
.66509 .4375 Mdot
.70896 .30687 Mdot
.28102 .26052 Mdot
.64687 .31876 Mdot
.36071 .36381 Mdot
.38816 .67037 Mdot
.42801 .2321 Mdot
.56409 .57357 Mdot
.69851 .66923 Mdot
.58024 .60628 Mdot
.64374 .48157 Mdot
.26568 .53362 Mdot
.51164 .39525 Mdot
.58467 .61984 Mdot
.46123 .65455 Mdot
.39518 .3672 Mdot
.36591 .34766 Mdot
.60568 .56814 Mdot
.37179 .32777 Mdot
.57682 .57932 Mdot
.29892 .53083 Mdot
.19794 .68242 Mdot
.55358 .59175 Mdot
.63771 .57062 Mdot
.41953 .36095 Mdot
.538 .37052 Mdot
.25267 .55348 Mdot
.76924 .61223 Mdot
.57726 .20105 Mdot
.37122 .33303 Mdot
.5492 .68303 Mdot
.30862 .5512 Mdot
.52603 .38517 Mdot
.27247 .49911 Mdot
.58637 .59494 Mdot
.54805 .58284 Mdot
.60793 .59097 Mdot
.56779 .56858 Mdot
.71253 .63221 Mdot
.62038 .66976 Mdot
.73576 .51325 Mdot
.56112 .62274 Mdot
.51346 .6621 Mdot
.38797 .32084 Mdot
.6529 .61313 Mdot
.37357 .57372 Mdot
.55327 .57272 Mdot
.68433 .44084 Mdot
.39488 .31728 Mdot
.63712 .28859 Mdot
.39266 .3334 Mdot
.32021 .5336 Mdot
.37162 .36169 Mdot
.578 .62668 Mdot
.65403 .38129 Mdot
.28295 .53791 Mdot
.58257 .37526 Mdot
.2741 .55328 Mdot
.56055 .59288 Mdot
.32621 .29642 Mdot
.31794 .50886 Mdot
.65281 .65261 Mdot
.65638 .38031 Mdot
.50598 .70398 Mdot
.69026 .39713 Mdot
.56612 .59994 Mdot
.56753 .60695 Mdot
.51709 .39543 Mdot
.38907 .36698 Mdot
.62395 .42633 Mdot
.22254 .65572 Mdot
.41789 .67135 Mdot
.66168 .39354 Mdot
.65137 .57599 Mdot
.4823 .45447 Mdot
.62591 .40822 Mdot
.52951 .70775 Mdot
.3977 .36381 Mdot
.67082 .41249 Mdot
.57588 .53681 Mdot
.68885 .55295 Mdot
.41495 .65758 Mdot
.3177 .5037 Mdot
.47855 .4943 Mdot
.27312 .52702 Mdot
.40223 .30723 Mdot
.25958 .51307 Mdot
.38907 .32419 Mdot
.57881 .44195 Mdot
.41177 .53015 Mdot
.3826 .30154 Mdot
.42393 .33194 Mdot
.29283 .51705 Mdot
.60768 .57524 Mdot
.40151 .47173 Mdot
.61023 .52483 Mdot
.63984 .63609 Mdot
.36759 .31608 Mdot
.67604 .4022 Mdot
.61552 .40856 Mdot
.50107 .57206 Mdot
.62771 .38428 Mdot
.2902 .54015 Mdot
.53125 .42452 Mdot
.68343 .69366 Mdot
.38769 .35289 Mdot
.33851 .58041 Mdot
.61398 .60342 Mdot
.29586 .51062 Mdot
.29486 .54314 Mdot
.36616 .32729 Mdot
.68406 .52608 Mdot
.63709 .63824 Mdot
.6703 .36026 Mdot
.65797 .42234 Mdot
.62672 .41173 Mdot
.6555 .43332 Mdot
.48107 .81437 Mdot
.38084 .30535 Mdot
.67629 .39122 Mdot
.61337 .57531 Mdot
.54672 .61004 Mdot
.50641 .36716 Mdot
.38101 .65091 Mdot
.54697 .56875 Mdot
.6183 .53509 Mdot
.59146 .58378 Mdot
.30674 .50594 Mdot
.62068 .50864 Mdot
.49057 .37427 Mdot
.25548 .52108 Mdot
.26629 .5094 Mdot
.51853 .37885 Mdot
.58644 .45017 Mdot
.62823 .20439 Mdot
.60482 .59113 Mdot
.70655 .33463 Mdot
.30604 .50937 Mdot
.46788 .57621 Mdot
.50697 .63208 Mdot
.61406 .62855 Mdot
.37667 .45948 Mdot
.2954 .53515 Mdot
.60497 .37492 Mdot
.58268 .5955 Mdot
.51651 .39033 Mdot
.40986 .67143 Mdot
.62577 .52987 Mdot
.52501 .37917 Mdot
.65867 .40609 Mdot
.21008 .5342 Mdot
.6544 .35625 Mdot
.3215 .51047 Mdot
.63834 .60272 Mdot
.49057 .91668 Mdot
.31207 .53459 Mdot
.55915 .29707 Mdot
.40872 .53452 Mdot
.55591 .58962 Mdot
.27826 .53877 Mdot
.60808 .42281 Mdot
.3684 .31289 Mdot
.46716 .46373 Mdot
.67015 .39077 Mdot
.52065 .39117 Mdot
.51198 .37043 Mdot
.29796 .52306 Mdot
.64448 .4267 Mdot
.60904 .54404 Mdot
.64142 .37391 Mdot
.38378 .35951 Mdot
.58666 .63471 Mdot
.58776 .21183 Mdot
.64301 .63762 Mdot
.64193 .37522 Mdot
.3126 .56236 Mdot
.3727 .64514 Mdot
.5757 .64524 Mdot
.63217 .26704 Mdot
.55903 .57254 Mdot
.39474 .34221 Mdot
.4418 .56759 Mdot
.73143 .43918 Mdot
.60067 .57574 Mdot
.61225 .60666 Mdot
.41038 .32904 Mdot
.60041 .57965 Mdot
.6213 .6233 Mdot
.44436 .37736 Mdot
.62593 .40352 Mdot
.57265 .5717 Mdot
.26896 .52727 Mdot
.76418 .40121 Mdot
.57916 .62072 Mdot
.49167 .34104 Mdot
.49078 .68723 Mdot
.42894 .54656 Mdot
.62511 .54518 Mdot
.43466 .72347 Mdot
.57078 .60586 Mdot
.61571 .63226 Mdot
.60664 .58333 Mdot
.75734 .61417 Mdot
.28904 .52037 Mdot
.27042 .51231 Mdot
.4072 .67707 Mdot
.48054 .6728 Mdot
.37429 .67749 Mdot
.41037 .33197 Mdot
.33122 .58271 Mdot
.49384 .38332 Mdot
.64811 .40674 Mdot
.5808 .61792 Mdot
.27095 .54971 Mdot
.58565 .58351 Mdot
.60028 .62773 Mdot
.28818 .53442 Mdot
.29659 .54072 Mdot
.31646 .49584 Mdot
.41409 .64803 Mdot
.6513 .39661 Mdot
.5942 .60482 Mdot
.39722 .64156 Mdot
.59178 .54471 Mdot
.46665 .42886 Mdot
.65318 .39514 Mdot
.6389 .37591 Mdot
.61738 .38939 Mdot
.55383 .62164 Mdot
.57951 .63004 Mdot
.38054 .31834 Mdot
.60857 .41433 Mdot
.36208 .34631 Mdot
.27702 .53718 Mdot
.28973 .51028 Mdot
.58648 .59561 Mdot
.53835 .54104 Mdot
.37648 .65492 Mdot
.32094 .54127 Mdot
.49422 .36334 Mdot
.40122 .68332 Mdot
.57536 .56233 Mdot
.27418 .53187 Mdot
.38216 .69278 Mdot
.68688 .45771 Mdot
.55069 .18288 Mdot
.41508 .64593 Mdot
.60571 .56749 Mdot
.81405 .51015 Mdot
.46421 .77612 Mdot
.42421 .663 Mdot
.39781 .33455 Mdot
.54885 .59136 Mdot
.28074 .30817 Mdot
.35593 .66464 Mdot
.46662 .7959 Mdot
.28459 .53156 Mdot
.56995 .50237 Mdot
.63534 .53411 Mdot
.6905 .6894 Mdot
.35738 .65751 Mdot
.64472 .37578 Mdot
.65171 .42885 Mdot
.5993 .5665 Mdot
.36496 .57129 Mdot
.39448 .30499 Mdot
.32743 .53749 Mdot
.25918 .52622 Mdot
.62878 .42373 Mdot
.51269 .42996 Mdot
.26988 .52847 Mdot
.60464 .65438 Mdot
.37921 .70066 Mdot
.63709 .67318 Mdot
.51372 .83069 Mdot
.75906 .35197 Mdot
.62841 .55221 Mdot
.38027 .64181 Mdot
.40086 .36733 Mdot
.37327 .32261 Mdot
.37959 .32605 Mdot
.28656 .51162 Mdot
.50442 .48136 Mdot
.26187 .53127 Mdot
.47223 .32378 Mdot
.37777 .65967 Mdot
.53271 .73043 Mdot
.58219 .53907 Mdot
.55615 .59054 Mdot
.62065 .59139 Mdot
.60797 .59316 Mdot
.5713 .60376 Mdot
.36133 .32213 Mdot
.33172 .52368 Mdot
.21964 .38504 Mdot
.63713 .42169 Mdot
.44861 .27038 Mdot
.31941 .51362 Mdot
.52217 .37086 Mdot
.39881 .65967 Mdot
.4572 .70474 Mdot
.39183 .70276 Mdot
.32537 .5354 Mdot
.57746 .6542 Mdot
.67469 .41351 Mdot
.65916 .73158 Mdot
.56249 .61583 Mdot
.31998 .54491 Mdot
.24684 .51981 Mdot
.68953 .52257 Mdot
.52907 .60986 Mdot
.36377 .56919 Mdot
.48633 .45785 Mdot
.40953 .63888 Mdot
.55222 .64547 Mdot
.47566 .56737 Mdot
.28982 .52419 Mdot
.31572 .5234 Mdot
.42493 .65626 Mdot
.66076 .54235 Mdot
.66699 .40836 Mdot
.5073 .39507 Mdot
.39993 .33241 Mdot
.55382 .6078 Mdot
.28319 .51451 Mdot
.60312 .36962 Mdot
.45042 .44491 Mdot
.38793 .34031 Mdot
.25336 .52376 Mdot
.55266 .57957 Mdot
.59901 .57051 Mdot
.37399 .66868 Mdot
.22422 .60107 Mdot
.6107 .52524 Mdot
.5709 .30259 Mdot
.52169 .45367 Mdot
.39902 .54702 Mdot
.58777 .57856 Mdot
.61855 .40066 Mdot
.51729 .38117 Mdot
.40438 .66914 Mdot
.5785 .5498 Mdot
.60255 .19296 Mdot
.64357 .35636 Mdot
.36269 .33917 Mdot
.51889 .38457 Mdot
.49729 .49933 Mdot
.56001 .57205 Mdot
.58052 .60566 Mdot
.60736 .55851 Mdot
.60352 .18973 Mdot
.2647 .5242 Mdot
.63011 .43254 Mdot
.37442 .68111 Mdot
.64263 .37153 Mdot
.28125 .50118 Mdot
.39434 .54512 Mdot
.59281 .55269 Mdot
.65055 .35929 Mdot
.65391 .3725 Mdot
.38695 .35082 Mdot
.40733 .35895 Mdot
.33207 .5109 Mdot
.56475 .57073 Mdot
.50104 .39026 Mdot
.67393 .40177 Mdot
.3297 .53942 Mdot
.37482 .66839 Mdot
.35056 .30396 Mdot
.56054 .62296 Mdot
.29504 .52204 Mdot
.63016 .56211 Mdot
.63224 .40589 Mdot
.32531 .52736 Mdot
.52791 .3781 Mdot
.38481 .6498 Mdot
.54384 .5984 Mdot
.20099 .43393 Mdot
.51931 .38878 Mdot
.56188 .63486 Mdot
.75355 .35442 Mdot
.36998 .56871 Mdot
.59963 .35763 Mdot
.27227 .54214 Mdot
.50381 .38953 Mdot
.64082 .43501 Mdot
.69799 .57149 Mdot
.31238 .5238 Mdot
.81994 .46546 Mdot
.41787 .4566 Mdot
.60222 .59653 Mdot
.66588 .4006 Mdot
.43435 .65809 Mdot
.57922 .29444 Mdot
.45033 .76463 Mdot
.57187 .58245 Mdot
.2731 .52608 Mdot
.40758 .6739 Mdot
.36619 .34952 Mdot
.48136 .34349 Mdot
.55729 .82546 Mdot
.25521 .52526 Mdot
.58505 .6134 Mdot
.67448 .40526 Mdot
.36489 .3336 Mdot
.82507 .44698 Mdot
.32558 .5553 Mdot
.27273 .53954 Mdot
.62014 .60173 Mdot
.37876 .68211 Mdot
.2846 .30748 Mdot
.26857 .51586 Mdot
.32829 .51326 Mdot
.46136 .36949 Mdot
.41503 .66799 Mdot
.61009 .56745 Mdot
.50057 .5734 Mdot
.61015 .55353 Mdot
.49652 .29968 Mdot
.50349 .39008 Mdot
.63876 .42099 Mdot
.57401 .61609 Mdot
.20358 .41767 Mdot
.30913 .52957 Mdot
.49022 .45859 Mdot
.40364 .38657 Mdot
.40606 .3601 Mdot
.27822 .52275 Mdot
.58198 .58825 Mdot
.34831 .32001 Mdot
.37225 .65997 Mdot
.60401 .55259 Mdot
.58157 .62692 Mdot
.61129 .42855 Mdot
.39226 .35778 Mdot
.76438 .39399 Mdot
.37493 .35947 Mdot
.40054 .31598 Mdot
.62782 .44522 Mdot
.59844 .56533 Mdot
.32266 .53439 Mdot
.32984 .55811 Mdot
.61967 .54747 Mdot
.46739 .57514 Mdot
.6673 .40563 Mdot
.35188 .52219 Mdot
.5785 .17637 Mdot
.62605 .58953 Mdot
.50554 .36279 Mdot
.63635 .47544 Mdot
.36341 .31215 Mdot
.59977 .59108 Mdot
.64048 .40689 Mdot
.33641 .52951 Mdot
.2734 .51968 Mdot
.53424 .60542 Mdot
.36562 .32639 Mdot
.37611 .69135 Mdot
.29633 .54519 Mdot
.44844 .43253 Mdot
.56417 .58756 Mdot
.48926 .39126 Mdot
.29903 .54676 Mdot
.78703 .35566 Mdot
.20745 .40458 Mdot
.62906 .42096 Mdot
.60675 .62846 Mdot
.68198 .40031 Mdot
.36959 .67936 Mdot
.26388 .50567 Mdot
.37178 .31948 Mdot
.67073 .67383 Mdot
.19475 .60577 Mdot
.29127 .51331 Mdot
.65586 .40347 Mdot
.58701 .60977 Mdot
.51984 .64835 Mdot
.55568 .58276 Mdot
.56176 .78478 Mdot
.39112 .69514 Mdot
.40684 .30604 Mdot
.35785 .33908 Mdot
.60877 .6131 Mdot
.39706 .64369 Mdot
.34386 .54128 Mdot
.28802 .533 Mdot
.23316 .72644 Mdot
.52583 .37956 Mdot
.30589 .48544 Mdot
.55431 .62164 Mdot
.3263 .54696 Mdot
.8065 .52095 Mdot
.35895 .34378 Mdot
.61288 .5532 Mdot
.26245 .54993 Mdot
.49782 .28008 Mdot
.48127 .45597 Mdot
.56731 .58439 Mdot
.52545 .57057 Mdot
.39505 .33359 Mdot
.4288 .23141 Mdot
.27316 .54483 Mdot
.59421 .54661 Mdot
.35009 .36303 Mdot
.56306 .42119 Mdot
.22551 .65354 Mdot
.65123 .39617 Mdot
.28043 .56337 Mdot
.40267 .32512 Mdot
.59119 .50852 Mdot
.37377 .65459 Mdot
.33982 .53821 Mdot
.2717 .55486 Mdot
.59219 .6354 Mdot
.54448 .57424 Mdot
.52684 .57557 Mdot
.66297 .40598 Mdot
.40776 .34324 Mdot
.60052 .616 Mdot
.47976 .42979 Mdot
.60561 .59836 Mdot
.4059 .33223 Mdot
.387 .8818 Mdot
.55226 .63378 Mdot
.55774 .61756 Mdot
.62068 .70696 Mdot
.6213 .42271 Mdot
.6269 .3946 Mdot
.50449 .4406 Mdot
.55124 .61963 Mdot
.4215 .43954 Mdot
.64993 .39898 Mdot
.66688 .39527 Mdot
.41962 .44221 Mdot
.58477 .6388 Mdot
.34168 .36072 Mdot
.36609 .33179 Mdot
.40688 .359 Mdot
.62871 .39602 Mdot
.62196 .67913 Mdot
.40886 .36175 Mdot
.71771 .62154 Mdot
.32627 .52665 Mdot
.47606 .56701 Mdot
.64334 .37299 Mdot
.44759 .46567 Mdot
.39142 .36556 Mdot
.83772 .41941 Mdot
.6555 .72575 Mdot
.62043 .5597 Mdot
.60101 .5716 Mdot
.38397 .67486 Mdot
.55134 .67209 Mdot
.51782 .37158 Mdot
.37381 .32528 Mdot
.29775 .37682 Mdot
.65274 .39012 Mdot
.54929 .60417 Mdot
.43129 .75086 Mdot
.77046 .35906 Mdot
.49491 .57769 Mdot
.66747 .38761 Mdot
.65484 .38574 Mdot
.29091 .556 Mdot
.32738 .52981 Mdot
.59793 .55604 Mdot
.382 .32253 Mdot
.66275 .42036 Mdot
.40256 .35114 Mdot
.28856 .52539 Mdot
.32395 .5238 Mdot
.49178 .36825 Mdot
.62575 .65306 Mdot
.2813 .52362 Mdot
.4537 .34612 Mdot
.4777 .42894 Mdot
.61259 .42786 Mdot
.26884 .29203 Mdot
.8387 .46974 Mdot
.63686 .69173 Mdot
.41059 .67024 Mdot
.57482 .43829 Mdot
.37005 .36537 Mdot
.60948 .61063 Mdot
.58863 .60015 Mdot
.50017 .37206 Mdot
.37654 .36925 Mdot
.39648 .66742 Mdot
.38565 .36735 Mdot
.40603 .66073 Mdot
.27673 .50875 Mdot
.57384 .62385 Mdot
.57202 .55999 Mdot
.36579 .34483 Mdot
.30516 .55518 Mdot
.31682 .50794 Mdot
.41107 .65229 Mdot
.46457 .68844 Mdot
.29663 .52421 Mdot
.6437 .37268 Mdot
.77165 .43199 Mdot
.50985 .36978 Mdot
.58202 .59558 Mdot
.43807 .73039 Mdot
.7113 .5749 Mdot
.60138 .60059 Mdot
.51914 .38607 Mdot
.19609 .69481 Mdot
.57654 .62352 Mdot
.35626 .81585 Mdot
.49228 .37705 Mdot
.61791 .3951 Mdot
.30447 .55066 Mdot
.52436 .38254 Mdot
.61665 .5077 Mdot
.35467 .51051 Mdot
.63371 .5807 Mdot
.66978 .4051 Mdot
.63894 .3658 Mdot
.40842 .51912 Mdot
.49384 .29891 Mdot
.37685 .6832 Mdot
.39167 .65951 Mdot
.30957 .52285 Mdot
.43613 .32928 Mdot
.5496 .65953 Mdot
.39216 .66231 Mdot
.30366 .3364 Mdot
.61471 .60401 Mdot
.38161 .56062 Mdot
.39677 .46132 Mdot
.62046 .41027 Mdot
.65417 .61054 Mdot
.31027 .5264 Mdot
.65583 .40274 Mdot
.40567 .48662 Mdot
.61706 .5656 Mdot
.65338 .39322 Mdot
.40673 .35163 Mdot
.41081 .41921 Mdot
.63321 .3767 Mdot
.46384 .46009 Mdot
.36868 .3369 Mdot
.37117 .56742 Mdot
.5212 .74914 Mdot
.65477 .17603 Mdot
.37655 .32315 Mdot
.3132 .55101 Mdot
.28616 .51442 Mdot
.29902 .52732 Mdot
.67073 .39436 Mdot
.3022 .53997 Mdot
.65035 .41885 Mdot
.42458 .35095 Mdot
.45533 .69731 Mdot
.38013 .66867 Mdot
.33899 .62765 Mdot
.64301 .38142 Mdot
.48559 .31715 Mdot
.21596 .33904 Mdot
.61023 .57207 Mdot
.38437 .3025 Mdot
.39785 .63975 Mdot
.54107 .45334 Mdot
.38713 .67484 Mdot
.30643 .55164 Mdot
.47753 .56539 Mdot
.57653 .57831 Mdot
.70856 .32661 Mdot
.40349 .67819 Mdot
.66891 .38916 Mdot
.59301 .64963 Mdot
.33772 .55899 Mdot
.36602 .67112 Mdot
.41294 .66318 Mdot
.57306 .60267 Mdot
.63967 .36771 Mdot
.32403 .53424 Mdot
.363 .35988 Mdot
.42905 .66463 Mdot
.5205 .58391 Mdot
.60527 .57551 Mdot
.56371 .647 Mdot
.50206 .45767 Mdot
.28522 .29237 Mdot
.37225 .33538 Mdot
.45746 .78376 Mdot
.29311 .50983 Mdot
.45278 .76818 Mdot
.58672 .31566 Mdot
.37399 .70698 Mdot
.49984 .38773 Mdot
.50443 .39089 Mdot
.56847 .591 Mdot
.30634 .25834 Mdot
.4932 .64411 Mdot
.37269 .3792 Mdot
.50863 .372 Mdot
.31937 .50928 Mdot
.61023 .3819 Mdot
.66408 .58646 Mdot
.57019 .54421 Mdot
.37777 .37054 Mdot
.29167 .5288 Mdot
.33759 .24386 Mdot
.37841 .66043 Mdot
.53441 .45167 Mdot
.56906 .56903 Mdot
.57418 .59174 Mdot
.38042 .34354 Mdot
.37748 .3193 Mdot
.47079 .37092 Mdot
.43699 .52453 Mdot
.6005 .21893 Mdot
.41779 .33632 Mdot
.33622 .24361 Mdot
.7164 .34806 Mdot
.63234 .39498 Mdot
.50952 .36407 Mdot
.413 .34532 Mdot
.57468 .61336 Mdot
.61678 .40146 Mdot
.48632 .61335 Mdot
.60528 .37212 Mdot
.38249 .5607 Mdot
.43734 .4412 Mdot
.57035 .56627 Mdot
.67056 .42109 Mdot
.65597 .40015 Mdot
.67588 .41834 Mdot
.51681 .3774 Mdot
.59049 .57934 Mdot
.60907 .57637 Mdot
.57794 .62351 Mdot
.52759 .65511 Mdot
.56456 .59337 Mdot
.58722 .31156 Mdot
.48272 .42343 Mdot
.26693 .64633 Mdot
.56426 .62434 Mdot
.40771 .33261 Mdot
.57241 .62275 Mdot
.38799 .64471 Mdot
.54443 .61279 Mdot
.38081 .56271 Mdot
.3798 .33095 Mdot
.67082 .54799 Mdot
.35037 .56089 Mdot
.58067 .55721 Mdot
.37792 .68875 Mdot
.28823 .28341 Mdot
.43491 .76283 Mdot
.4609 .36803 Mdot
.64202 .3738 Mdot
.31773 .50087 Mdot
.36814 .30437 Mdot
.32209 .52988 Mdot
.61345 .55044 Mdot
.49063 .36602 Mdot
.82416 .62121 Mdot
.44349 .4771 Mdot
.57341 .61508 Mdot
.62265 .65468 Mdot
.62001 .40256 Mdot
.30914 .53227 Mdot
.67848 .33335 Mdot
.61907 .59599 Mdot
.35998 .66674 Mdot
.37174 .64765 Mdot
.38798 .51887 Mdot
.36766 .40579 Mdot
.67204 .70742 Mdot
.3795 .34153 Mdot
.27927 .5139 Mdot
.35618 .6604 Mdot
.65507 .46238 Mdot
.39491 .3058 Mdot
.36229 .31283 Mdot
.39392 .35658 Mdot
.55829 .59396 Mdot
.4972 .36676 Mdot
.32933 .38868 Mdot
.52301 .38702 Mdot
.61635 .57569 Mdot
.26904 .55284 Mdot
.52519 .38604 Mdot
.3786 .67688 Mdot
.39624 .31314 Mdot
.3117 .50759 Mdot
.56596 .60552 Mdot
.64465 .3971 Mdot
.43897 .79018 Mdot
.17195 .47166 Mdot
.36081 .57307 Mdot
.36045 .57321 Mdot
.62386 .37533 Mdot
.65342 .26565 Mdot
.38449 .29527 Mdot
.69018 .53515 Mdot
.44246 .6752 Mdot
.62131 .54937 Mdot
.25313 .71816 Mdot
.26313 .5341 Mdot
.28437 .53915 Mdot
.56817 .57709 Mdot
.32855 .5485 Mdot
.55085 .59168 Mdot
.27794 .54885 Mdot
.55043 .28434 Mdot
.57454 .5405 Mdot
.28852 .53979 Mdot
.54158 .65365 Mdot
.57337 .64402 Mdot
.62055 .3937 Mdot
.3388 .53771 Mdot
.62109 .5618 Mdot
.78605 .68559 Mdot
.38169 .35198 Mdot
.51651 .37629 Mdot
.35599 .57829 Mdot
.37563 .36424 Mdot
.65792 .41748 Mdot
.55141 .62398 Mdot
.37264 .66213 Mdot
.63684 .38806 Mdot
.34357 .55772 Mdot
.39674 .6835 Mdot
.52872 .42522 Mdot
.63049 .3944 Mdot
.50269 .36858 Mdot
.38886 .64929 Mdot
.63374 .58165 Mdot
.28418 .53651 Mdot
.19373 .42923 Mdot
.52263 .38329 Mdot
.58072 .57893 Mdot
.28163 .56459 Mdot
.38543 .36719 Mdot
.59195 .55768 Mdot
.27975 .51556 Mdot
.51901 .38114 Mdot
.56554 .63537 Mdot
.55962 .63505 Mdot
.674 .57943 Mdot
.44325 .58631 Mdot
.37807 .6714 Mdot
.63882 .44698 Mdot
.61368 .57439 Mdot
.40124 .64399 Mdot
.21914 .42738 Mdot
.59356 .53688 Mdot
.67306 .37205 Mdot
.69312 .60005 Mdot
.32544 .54427 Mdot
.35842 .34153 Mdot
.32995 .55543 Mdot
.39452 .68785 Mdot
.13687 .50107 Mdot
.51245 .36598 Mdot
.62063 .65026 Mdot
.6228 .61286 Mdot
.25703 .51026 Mdot
.65794 .39789 Mdot
.61391 .22854 Mdot
.5447 .60834 Mdot
.64331 .62898 Mdot
.57786 .5999 Mdot
.2054 .43919 Mdot
.66811 .40018 Mdot
.5804 .59829 Mdot
.51775 .58534 Mdot
.62417 .59643 Mdot
.36962 .68588 Mdot
.55039 .73505 Mdot
.59177 .61136 Mdot
.55266 .91419 Mdot
.48785 .37729 Mdot
.29119 .53417 Mdot
.47375 .45895 Mdot
.31253 .59259 Mdot
.48028 .83298 Mdot
.65847 .41392 Mdot
.71199 .3827 Mdot
.32327 .53127 Mdot
.41786 .78827 Mdot
.65811 .27534 Mdot
.57495 .64781 Mdot
.54885 .58815 Mdot
.30655 .55161 Mdot
.3301 .53593 Mdot
.48589 .36988 Mdot
.55707 .56483 Mdot
.64046 .64627 Mdot
.30181 .56317 Mdot
.5612 .6082 Mdot
.72341 .54878 Mdot
.3497 .32793 Mdot
.62764 .39718 Mdot
.36761 .3506 Mdot
.35865 .31751 Mdot
.68967 .6633 Mdot
.52213 .45566 Mdot
.3946 .32148 Mdot
.35633 .36285 Mdot
.371 .61065 Mdot
.65755 .70096 Mdot
.3672 .68352 Mdot
.39587 .39992 Mdot
.30415 .5224 Mdot
.592 .58058 Mdot
.67221 .38979 Mdot
.62713 .78289 Mdot
.51687 .19278 Mdot
.49144 .54401 Mdot
.61235 .58036 Mdot
.30658 .5285 Mdot
.52097 .38366 Mdot
.5826 .5365 Mdot
.46062 .77343 Mdot
.5729 .58592 Mdot
.32859 .52884 Mdot
.68443 .69317 Mdot
.51431 .34893 Mdot
.41654 .33189 Mdot
.61281 .3718 Mdot
.5757 .6216 Mdot
.64025 .41302 Mdot
.38728 .31584 Mdot
.41098 .64637 Mdot
.38816 .66906 Mdot
.57633 .55899 Mdot
.41205 .52923 Mdot
.43822 .65112 Mdot
.57587 .64764 Mdot
.58996 .63566 Mdot
.49833 .38575 Mdot
.58927 .63531 Mdot
.58955 .54847 Mdot
.60212 .61257 Mdot
.57685 .54571 Mdot
.40787 .32445 Mdot
.63714 .33246 Mdot
.54267 .58401 Mdot
.6262 .61272 Mdot
.35146 .34391 Mdot
.57649 .52543 Mdot
.39146 .33102 Mdot
.54803 .19555 Mdot
.39813 .32858 Mdot
.38671 .6688 Mdot
.29731 .5676 Mdot
.70923 .35449 Mdot
.66121 .42141 Mdot
.40849 .33213 Mdot
.39753 .65385 Mdot
.37738 .3245 Mdot
.27166 .51701 Mdot
.23781 .33412 Mdot
.68123 .42434 Mdot
.46529 .41673 Mdot
.64054 .70484 Mdot
.49044 .39336 Mdot
.31762 .5549 Mdot
.6318 .4245 Mdot
.50421 .34653 Mdot
.60703 .61541 Mdot
.37104 .66787 Mdot
.56916 .59122 Mdot
.39418 .31035 Mdot
.30513 .52636 Mdot
.35802 .38027 Mdot
.37862 .67214 Mdot
.15068 .48393 Mdot
.27312 .55093 Mdot
.6248 .63591 Mdot
.35168 .34238 Mdot
.25308 .31551 Mdot
.39438 .32836 Mdot
.45529 .69906 Mdot
.61113 .46138 Mdot
.59755 .79292 Mdot
.64974 .38304 Mdot
.47833 .37683 Mdot
.70518 .25549 Mdot
.61756 .28238 Mdot
.6368 .39841 Mdot
.35069 .56157 Mdot
.56096 .59648 Mdot
.60741 .5976 Mdot
.58188 .66181 Mdot
.6325 .34541 Mdot
.60805 .5601 Mdot
.51456 .36942 Mdot
.51059 .45028 Mdot
.28991 .32647 Mdot
.32375 .50482 Mdot
.55278 .58612 Mdot
.3663 .31659 Mdot
.39992 .3126 Mdot
.52393 .38957 Mdot
.38373 .36177 Mdot
.57586 .64062 Mdot
.64451 .38167 Mdot
.40209 .47411 Mdot
.36943 .67828 Mdot
.56619 .31178 Mdot
.44382 .66772 Mdot
.4164 .68577 Mdot
.62517 .59142 Mdot
.32439 .52505 Mdot
.20845 .65551 Mdot
.61041 .60432 Mdot
.65082 .40112 Mdot
.6211 .61826 Mdot
.59811 .61284 Mdot
.5898 .61072 Mdot
.28126 .51306 Mdot
.47183 .45458 Mdot
.56133 .61064 Mdot
.39421 .32001 Mdot
.41868 .44521 Mdot
.56304 .55075 Mdot
.30821 .38844 Mdot
.38357 .56029 Mdot
.49038 .39197 Mdot
.61124 .42606 Mdot
.31729 .54191 Mdot
.65237 .38799 Mdot
.66986 .3495 Mdot
.65735 .41797 Mdot
.3066 .37085 Mdot
.69005 .55133 Mdot
.38522 .83261 Mdot
.79832 .53939 Mdot
.68765 .69433 Mdot
.66382 .35823 Mdot
.25934 .41108 Mdot
.63615 .40312 Mdot
.65755 .41654 Mdot
.30031 .81528 Mdot
.67178 .37634 Mdot
.58733 .59406 Mdot
.5428 .61929 Mdot
.71212 .31648 Mdot
.37311 .61227 Mdot
.55593 .62353 Mdot
.60525 .55845 Mdot
.36183 .65411 Mdot
.63355 .50139 Mdot
.4827 .37168 Mdot
.52965 .44795 Mdot
.50858 .3612 Mdot
.5724 .60249 Mdot
.57654 .56383 Mdot
.53552 .61179 Mdot
.72493 .26115 Mdot
.59164 .80589 Mdot
.62383 .37818 Mdot
.57686 .52043 Mdot
.5369 .38932 Mdot
.61864 .63301 Mdot
.62213 .61097 Mdot
.57945 .62535 Mdot
.32293 .53387 Mdot
.61046 .38385 Mdot
.61415 .52923 Mdot
.57541 .34497 Mdot
.57075 .56732 Mdot
.42668 .68725 Mdot
.41162 .63693 Mdot
.58294 .58839 Mdot
.66803 .36962 Mdot
.61092 .5895 Mdot
.67927 .40359 Mdot
.62843 .40088 Mdot
.62503 .65748 Mdot
.33878 .39531 Mdot
.61554 .37187 Mdot
.57233 .64667 Mdot
.30979 .55511 Mdot
.56689 .30019 Mdot
.58172 .58077 Mdot
.38432 .68273 Mdot
.60034 .59138 Mdot
.37627 .68994 Mdot
.58612 .6297 Mdot
.5218 .38929 Mdot
.72452 .44934 Mdot
.31403 .52199 Mdot
.43101 .66234 Mdot
.32547 .5501 Mdot
.64882 .65577 Mdot
.67365 .36787 Mdot
.49236 .35214 Mdot
.57194 .82266 Mdot
.49663 .38375 Mdot
.45736 .7913 Mdot
.41629 .43584 Mdot
.35659 .33096 Mdot
.65014 .43492 Mdot
.68193 .68931 Mdot
.33671 .41567 Mdot
.29326 .49365 Mdot
.26933 .50638 Mdot
.23412 .66968 Mdot
.19836 .68383 Mdot
.55958 .6136 Mdot
.27703 .31091 Mdot
.73611 .49833 Mdot
.53235 .65091 Mdot
.5378 .56714 Mdot
.27711 .55786 Mdot
.55656 .62524 Mdot
.47444 .48479 Mdot
.292 .51738 Mdot
.38899 .65485 Mdot
.63954 .42008 Mdot
.40245 .64822 Mdot
.4808 .18532 Mdot
.45804 .36889 Mdot
.28521 .52045 Mdot
.57225 .54736 Mdot
.55291 .59986 Mdot
.63277 .43502 Mdot
.82262 .46279 Mdot
.62602 .40211 Mdot
.37638 .68449 Mdot
.30438 .51389 Mdot
.67475 .73615 Mdot
.59667 .59854 Mdot
.65846 .37283 Mdot
.34853 .56211 Mdot
.59858 .5715 Mdot
.35964 .3359 Mdot
.61304 .5831 Mdot
.6544 .37067 Mdot
.58923 .63472 Mdot
.6448 .38337 Mdot
.28711 .55328 Mdot
.56655 .56253 Mdot
.57957 .56151 Mdot
.4624 .79174 Mdot
.39604 .66925 Mdot
.66962 .36452 Mdot
.47678 .48519 Mdot
.61027 .55389 Mdot
.46421 .77067 Mdot
.5746 .62379 Mdot
.56324 .69226 Mdot
.57103 .53175 Mdot
.51108 .36745 Mdot
.62321 .61025 Mdot
.58059 .58096 Mdot
.82099 .51532 Mdot
.8104 .51424 Mdot
.62036 .69991 Mdot
.40826 .3577 Mdot
.65691 .36687 Mdot
.28385 .51611 Mdot
.33465 .5234 Mdot
.30614 .54197 Mdot
.39114 .62285 Mdot
.55605 .52417 Mdot
.57803 .5752 Mdot
.42352 .32779 Mdot
.38848 .66033 Mdot
.66509 .38046 Mdot
.38398 .66514 Mdot
.52792 .45874 Mdot
.39197 .6831 Mdot
.51709 .36968 Mdot
.2092 .40013 Mdot
.71785 .56782 Mdot
.39947 .67529 Mdot
.62667 .40178 Mdot
.43652 .429 Mdot
.62354 .55248 Mdot
.47031 .28474 Mdot
.35992 .66604 Mdot
.21806 .65271 Mdot
.56576 .63304 Mdot
.47114 .46666 Mdot
.39205 .33625 Mdot
.40233 .64861 Mdot
.39125 .35706 Mdot
.61038 .59218 Mdot
.61913 .34085 Mdot
.65301 .40547 Mdot
.35068 .32845 Mdot
.62248 .59779 Mdot
.40147 .64803 Mdot
.28271 .52502 Mdot
.66949 .69788 Mdot
.35348 .35462 Mdot
.4321 .78672 Mdot
.45025 .7653 Mdot
.30168 .51317 Mdot
.70471 .69182 Mdot
.39779 .3459 Mdot
.61729 .54211 Mdot
.57386 .50142 Mdot
.61464 .59467 Mdot
.31372 .506 Mdot
.28544 .54099 Mdot
.63525 .31053 Mdot
.57199 .56363 Mdot
.53841 .6069 Mdot
.61183 .38896 Mdot
.29695 .50934 Mdot
.65866 .4181 Mdot
.63339 .43233 Mdot
.30722 .55241 Mdot
.62851 .42116 Mdot
.40507 .67592 Mdot
.51575 .48394 Mdot
.39908 .34278 Mdot
.36087 .33103 Mdot
.28223 .52167 Mdot
.28857 .50485 Mdot
.32377 .52114 Mdot
.61802 .60349 Mdot
.64398 .42791 Mdot
.60632 .63239 Mdot
.57921 .61865 Mdot
.61648 .45025 Mdot
.61182 .40796 Mdot
.61416 .62054 Mdot
.39342 .45534 Mdot
.36649 .68738 Mdot
.29108 .53971 Mdot
.40333 .35258 Mdot
.45264 .80409 Mdot
.35325 .33945 Mdot
.6101 .55606 Mdot
.49731 .28264 Mdot
.67022 .39405 Mdot
.38579 .6751 Mdot
.36656 .57107 Mdot
.3806 .67383 Mdot
.35052 .32684 Mdot
.61556 .42657 Mdot
.52044 .42965 Mdot
.57013 .56342 Mdot
.50486 .45719 Mdot
.50345 .76955 Mdot
.58774 .32095 Mdot
.40808 .34496 Mdot
.61026 .57052 Mdot
.49353 .3791 Mdot
.69126 .52289 Mdot
.57455 .57542 Mdot
.61399 .55393 Mdot
.26189 .59238 Mdot
.62605 .60287 Mdot
.62322 .43606 Mdot
.4032 .53658 Mdot
.57349 .55296 Mdot
.64595 .65913 Mdot
.23501 .7404 Mdot
.56312 .63384 Mdot
.57886 .56024 Mdot
.59302 .59115 Mdot
.61098 .611 Mdot
.68322 .3958 Mdot
.22192 .57377 Mdot
.3741 .31453 Mdot
.51498 .48421 Mdot
.39752 .35132 Mdot
.2774 .5331 Mdot
.45557 .49364 Mdot
.68078 .40169 Mdot
.38036 .67439 Mdot
.27046 .31403 Mdot
.48329 .54795 Mdot
.29443 .55677 Mdot
.50891 .82308 Mdot
.36152 .67157 Mdot
.62246 .54988 Mdot
.40626 .67851 Mdot
.27521 .5585 Mdot
.36709 .32506 Mdot
.57574 .65347 Mdot
.67046 .40707 Mdot
.63383 .37659 Mdot
.61387 .58003 Mdot
.55979 .31169 Mdot
.37481 .36526 Mdot
.35627 .71981 Mdot
.55952 .58783 Mdot
.61202 .55153 Mdot
.62511 .40805 Mdot
.3077 .53196 Mdot
.41698 .4374 Mdot
.40049 .66164 Mdot
.59336 .65638 Mdot
.6092 .58906 Mdot
.52546 .45906 Mdot
.40771 .3265 Mdot
.5082 .37902 Mdot
.56482 .57396 Mdot
.51934 .44814 Mdot
.60569 .55438 Mdot
.59366 .68055 Mdot
.31944 .55108 Mdot
.63938 .64048 Mdot
.55118 .57925 Mdot
.6411 .33386 Mdot
.39485 .35008 Mdot
.65395 .39723 Mdot
.63316 .46207 Mdot
.51539 .39141 Mdot
.37691 .35073 Mdot
.61568 .61632 Mdot
.36034 .31261 Mdot
.60194 .60602 Mdot
.56388 .60737 Mdot
.40809 .3463 Mdot
.65226 .42265 Mdot
.59948 .22688 Mdot
.63609 .33271 Mdot
.60043 .62426 Mdot
.60126 .58625 Mdot
.37768 .61224 Mdot
.63988 .78963 Mdot
.55113 .57801 Mdot
.63797 .42848 Mdot
.59857 .56941 Mdot
.36148 .32447 Mdot
.38025 .68504 Mdot
.64506 .40061 Mdot
.27823 .51088 Mdot
.28082 .54848 Mdot
.263 .56717 Mdot
.5148 .36726 Mdot
.55775 .56502 Mdot
.63745 .44743 Mdot
.61317 .39522 Mdot
.5385 .47806 Mdot
.29053 .53496 Mdot
.38719 .68649 Mdot
.55691 .62825 Mdot
.67824 .66864 Mdot
.36714 .31241 Mdot
.56737 .90602 Mdot
.51645 .43046 Mdot
.42222 .64146 Mdot
.42625 .5454 Mdot
.49632 .38008 Mdot
.55666 .61868 Mdot
.39334 .64474 Mdot
.28357 .54648 Mdot
.60848 .59555 Mdot
.5297 .56192 Mdot
.3405 .42232 Mdot
.2843 .50357 Mdot
.35546 .31821 Mdot
.2677 .53609 Mdot
.37315 .68955 Mdot
.51721 .37046 Mdot
.63146 .37501 Mdot
.57828 .58531 Mdot
.64884 .62996 Mdot
.29953 .53025 Mdot
.51437 .39512 Mdot
.58383 .55476 Mdot
.64808 .36784 Mdot
.29766 .5404 Mdot
.57406 .60699 Mdot
.68809 .529 Mdot
.71034 .3636 Mdot
.30311 .5182 Mdot
.58524 .65498 Mdot
.66718 .62369 Mdot
.27789 .5043 Mdot
.26166 .54756 Mdot
.60618 .55851 Mdot
.40022 .64966 Mdot
.55853 .57224 Mdot
.38884 .32503 Mdot
.47122 .4538 Mdot
.36797 .3453 Mdot
.46486 .77735 Mdot
.53576 .59871 Mdot
.48908 .59568 Mdot
.66896 .42096 Mdot
.36826 .69701 Mdot
.82156 .56279 Mdot
.60652 .54613 Mdot
.61571 .20781 Mdot
.44886 .46301 Mdot
.47946 .41278 Mdot
.5539 .17295 Mdot
.40374 .66552 Mdot
.38001 .3261 Mdot
.58491 .55607 Mdot
.42263 .31241 Mdot
.40768 .66238 Mdot
.46619 .77801 Mdot
.61355 .64267 Mdot
.6668 .39358 Mdot
.56115 .58805 Mdot
.65051 .36952 Mdot
.5979 .57782 Mdot
.65142 .51859 Mdot
.43051 .67933 Mdot
.45642 .69754 Mdot
.62335 .54939 Mdot
.27323 .29671 Mdot
.64828 .70391 Mdot
.37704 .68127 Mdot
.59657 .62776 Mdot
.50224 .38048 Mdot
.38886 .36743 Mdot
.24528 .35706 Mdot
.32378 .52807 Mdot
.39824 .32476 Mdot
.63016 .41632 Mdot
.30444 .5656 Mdot
.51045 .39407 Mdot
.56471 .50633 Mdot
.3987 .64712 Mdot
.38087 .35166 Mdot
.58133 .58395 Mdot
.61889 .58532 Mdot
.20467 .43911 Mdot
.71188 .72175 Mdot
.63464 .42994 Mdot
.16503 .55338 Mdot
.63853 .44588 Mdot
.39527 .66272 Mdot
.32189 .54768 Mdot
.57846 .61223 Mdot
.5752 .56984 Mdot
.29698 .50475 Mdot
.61938 .41987 Mdot
.37057 .70068 Mdot
.60572 .79117 Mdot
.41837 .38351 Mdot
.50067 .71127 Mdot
.64323 .4031 Mdot
.4965 .70921 Mdot
.35949 .64892 Mdot
.32025 .33226 Mdot
.61358 .72717 Mdot
.36077 .34213 Mdot
.50561 .71398 Mdot
.667 .38002 Mdot
.55864 .61473 Mdot
.50263 .36928 Mdot
.48944 .37409 Mdot
.63673 .41459 Mdot
.31153 .54976 Mdot
.37558 .65335 Mdot
.5638 .58385 Mdot
.53431 .51385 Mdot
.82566 .44259 Mdot
.28902 .50619 Mdot
.61621 .65787 Mdot
.38015 .36518 Mdot
.60037 .57512 Mdot
.36983 .64773 Mdot
.36986 .32834 Mdot
.52696 .37931 Mdot
.48615 .53667 Mdot
.55205 .6258 Mdot
.39979 .5453 Mdot
.38836 .34374 Mdot
.64542 .78663 Mdot
.58004 .56184 Mdot
.39755 .34637 Mdot
.64709 .63457 Mdot
.54962 .35555 Mdot
.40704 .46524 Mdot
.61593 .27854 Mdot
.33382 .50911 Mdot
.27442 .54486 Mdot
.76415 .7035 Mdot
.44238 .67642 Mdot
.39889 .32102 Mdot
.52075 .37495 Mdot
.57769 .73569 Mdot
.38531 .35748 Mdot
.57218 .65098 Mdot
.57115 .62568 Mdot
.68554 .69277 Mdot
.63852 .68477 Mdot
.48441 .37226 Mdot
.53149 .53385 Mdot
.58434 .64398 Mdot
.63774 .58786 Mdot
.59791 .55956 Mdot
.63698 .36688 Mdot
.36292 .3494 Mdot
.43701 .12783 Mdot
.37028 .30571 Mdot
.51194 .52586 Mdot
.30436 .52271 Mdot
.34144 .53153 Mdot
.58217 .58957 Mdot
.48739 .64633 Mdot
.3036 .251 Mdot
.59445 .60337 Mdot
.36835 .57025 Mdot
.44893 .76556 Mdot
.60927 .53259 Mdot
.64795 .35547 Mdot
.64132 .64304 Mdot
.67194 .43075 Mdot
.36829 .32849 Mdot
.40477 .66537 Mdot
.35704 .67857 Mdot
.38617 .32868 Mdot
.58077 .57079 Mdot
.35391 .67645 Mdot
.57562 .59416 Mdot
.55382 .60522 Mdot
.53151 .45372 Mdot
.40603 .64031 Mdot
.3245 .5214 Mdot
.38612 .67057 Mdot
.66187 .41064 Mdot
.31733 .83537 Mdot
.37669 .66458 Mdot
.65927 .7006 Mdot
.46566 .47532 Mdot
.50606 .71679 Mdot
.63034 .38078 Mdot
.37293 .68295 Mdot
.35968 .34415 Mdot
.52123 .4221 Mdot
.70242 .6905 Mdot
.35351 .33752 Mdot
.57154 .57355 Mdot
.68003 .40447 Mdot
.61969 .38172 Mdot
.41578 .3342 Mdot
.61871 .40491 Mdot
.63367 .62045 Mdot
.57187 .64751 Mdot
.39025 .3158 Mdot
.76863 .34946 Mdot
.35783 .34301 Mdot
.67531 .67597 Mdot
.57904 .62872 Mdot
.64809 .4007 Mdot
.55484 .68733 Mdot
.60116 .41784 Mdot
.49135 .36766 Mdot
.54326 .6109 Mdot
.37205 .67252 Mdot
.50395 .48148 Mdot
.30488 .51871 Mdot
.50262 .28076 Mdot
.64193 .37353 Mdot
.39432 .30287 Mdot
.62165 .39127 Mdot
.62662 .42772 Mdot
.35184 .32977 Mdot
.6602 .40523 Mdot
.57188 .56746 Mdot
.44324 .21229 Mdot
.63915 .37702 Mdot
.38252 .34021 Mdot
.36814 .66939 Mdot
.63019 .42283 Mdot
.3386 .68036 Mdot
.55117 .60433 Mdot
.30623 .5605 Mdot
.42848 .66025 Mdot
.67696 .41524 Mdot
.38161 .6843 Mdot
.29619 .53336 Mdot
.37643 .65162 Mdot
.43303 .34334 Mdot
.39425 .29941 Mdot
.49064 .55001 Mdot
.53534 .35392 Mdot
.67318 .394 Mdot
.33769 .51095 Mdot
.54779 .61218 Mdot
.55672 .593 Mdot
.37652 .69462 Mdot
.6309 .36852 Mdot
.55012 .31002 Mdot
.50474 .64915 Mdot
.56618 .31335 Mdot
.41156 .34741 Mdot
.36588 .74878 Mdot
.51575 .42871 Mdot
.45523 .35574 Mdot
.54796 .64242 Mdot
.49612 .37856 Mdot
.57844 .60011 Mdot
.43414 .76211 Mdot
.36478 .68119 Mdot
.22344 .45779 Mdot
.54994 .65984 Mdot
.30818 .51035 Mdot
.59783 .58678 Mdot
.27245 .33082 Mdot
.63441 .66823 Mdot
.35855 .67093 Mdot
.34645 .32501 Mdot
.66127 .4214 Mdot
.36629 .67675 Mdot
.28464 .55127 Mdot
.51781 .70334 Mdot
.5637 .64475 Mdot
.57913 .64353 Mdot
.2602 .51494 Mdot
.66299 .41428 Mdot
.28006 .53545 Mdot
.39897 .34349 Mdot
.37955 .6651 Mdot
.60982 .61627 Mdot
.6401 .62893 Mdot
.25463 .51334 Mdot
.38132 .30568 Mdot
.29847 .50164 Mdot
.36353 .31088 Mdot
.49581 .37519 Mdot
.56898 .5526 Mdot
.25228 .52535 Mdot
.5408 .63726 Mdot
.80129 .49271 Mdot
.51995 .48938 Mdot
.79458 .59536 Mdot
.32508 .52192 Mdot
.44622 .64162 Mdot
.38344 .33163 Mdot
.38591 .35262 Mdot
.68699 .67018 Mdot
.3027 .25803 Mdot
.42119 .43982 Mdot
.21846 .35464 Mdot
.39941 .34207 Mdot
.38297 .34735 Mdot
.29089 .54785 Mdot
.65365 .41599 Mdot
.6781 .35488 Mdot
.27129 .55898 Mdot
.43879 .72983 Mdot
.66493 .37997 Mdot
.64919 .23065 Mdot
.26001 .5281 Mdot
.54842 .6354 Mdot
.49219 .35482 Mdot
.35888 .669 Mdot
.4358 .75329 Mdot
.23191 .34504 Mdot
.58194 .60501 Mdot
.33383 .79872 Mdot
.31894 .53769 Mdot
.41979 .39544 Mdot
.32083 .29564 Mdot
.61844 .57213 Mdot
.59583 .58579 Mdot
.58628 .56607 Mdot
.42435 .6618 Mdot
.81289 .45627 Mdot
.57915 .60909 Mdot
.45576 .67271 Mdot
.57498 .53996 Mdot
.19631 .43544 Mdot
.38603 .67028 Mdot
.55785 .78877 Mdot
.34852 .53986 Mdot
.56885 .34037 Mdot
.62433 .58619 Mdot
.39792 .33662 Mdot
.36455 .43918 Mdot
.40671 .33261 Mdot
.31201 .31547 Mdot
.60748 .73249 Mdot
.64053 .36443 Mdot
.61354 .58384 Mdot
.25796 .53124 Mdot
.67877 .40886 Mdot
.37748 .44778 Mdot
.28177 .80475 Mdot
.41359 .33729 Mdot
.14694 .6007 Mdot
.373 .35309 Mdot
.48818 .37397 Mdot
.62977 .41205 Mdot
.50188 .67717 Mdot
.51056 .4574 Mdot
.65735 .41897 Mdot
.28928 .6835 Mdot
.69226 .39018 Mdot
.48588 .68771 Mdot
.68723 .4178 Mdot
.3793 .33456 Mdot
.38913 .29849 Mdot
.54078 .54786 Mdot
.546 .59086 Mdot
.49718 .45298 Mdot
.53146 .58505 Mdot
.55002 .61862 Mdot
.29211 .51715 Mdot
.52506 .34614 Mdot
.41519 .30151 Mdot
.64149 .40803 Mdot
.37921 .31028 Mdot
.59671 .58754 Mdot
.60012 .62494 Mdot
.62416 .62367 Mdot
.42627 .79254 Mdot
.64522 .22655 Mdot
.56293 .61112 Mdot
.63273 .6675 Mdot
.29933 .55627 Mdot
.20274 .44111 Mdot
.17653 .54536 Mdot
.59044 .73243 Mdot
.58535 .55322 Mdot
.39382 .66971 Mdot
.36061 .65444 Mdot
.62981 .61818 Mdot
.48613 .59342 Mdot
.33496 .67267 Mdot
.58152 .5837 Mdot
.47825 .66449 Mdot
.27189 .49796 Mdot
.5187 .3938 Mdot
.29889 .53036 Mdot
.6793 .41056 Mdot
.49487 .38279 Mdot
.27428 .52178 Mdot
.46416 .63914 Mdot
.5166 .3897 Mdot
.55221 .35383 Mdot
.37504 .68427 Mdot
.59164 .55788 Mdot
.69217 .34042 Mdot
.29156 .50775 Mdot
.38724 .34802 Mdot
.64109 .39005 Mdot
.39769 .3673 Mdot
.20085 .42017 Mdot
.44137 .73999 Mdot
.5104 .36562 Mdot
.39732 .33259 Mdot
.4186 .51101 Mdot
.39242 .66909 Mdot
.37807 .35949 Mdot
.48678 .61511 Mdot
.5492 .56586 Mdot
.35941 .21121 Mdot
.58721 .64716 Mdot
.64479 .29979 Mdot
.3924 .34611 Mdot
.52835 .37476 Mdot
.57675 .58538 Mdot
.27485 .55137 Mdot
.5931 .51957 Mdot
.57425 .59505 Mdot
.2651 .52351 Mdot
.56087 .61423 Mdot
.39792 .64143 Mdot
.66949 .43123 Mdot
.44924 .47153 Mdot
.40763 .77112 Mdot
.36758 .65989 Mdot
.57047 .4739 Mdot
.54785 .58246 Mdot
.25458 .65471 Mdot
.66503 .39532 Mdot
.6084 .54978 Mdot
.48207 .79741 Mdot
.64502 .41649 Mdot
.6529 .38693 Mdot
.59288 .63686 Mdot
.35668 .34429 Mdot
.31224 .50665 Mdot
.39047 .67025 Mdot
.43911 .33704 Mdot
.5739 .60934 Mdot
.60957 .56731 Mdot
.36233 .67285 Mdot
.3778 .34933 Mdot
.61076 .61823 Mdot
.5535 .25468 Mdot
.53574 .48176 Mdot
.36188 .31419 Mdot
.56189 .55209 Mdot
.46247 .15112 Mdot
.68158 .35552 Mdot
.34619 .80836 Mdot
.44106 .66838 Mdot
.31353 .55172 Mdot
.59235 .66345 Mdot
.52383 .92028 Mdot
.37259 .68121 Mdot
.57502 .33002 Mdot
.55855 .60789 Mdot
.58125 .61303 Mdot
.65227 .36238 Mdot
.61001 .63107 Mdot
.66486 .37154 Mdot
.38728 .76646 Mdot
.27307 .26828 Mdot
.61955 .40173 Mdot
.65951 .36959 Mdot
.63636 .67918 Mdot
.43462 .80156 Mdot
.63656 .42005 Mdot
.56303 .64402 Mdot
.27356 .65769 Mdot
.52226 .57901 Mdot
.40965 .63776 Mdot
.33849 .64446 Mdot
.65279 .35597 Mdot
.73574 .66125 Mdot
.6334 .67995 Mdot
.67724 .5635 Mdot
.35112 .64303 Mdot
.40318 .33372 Mdot
.59126 .61886 Mdot
.51858 .36973 Mdot
.29569 .54279 Mdot
.64426 .5951 Mdot
.58555 .56077 Mdot
.67671 .38227 Mdot
.41538 .67456 Mdot
.38599 .35931 Mdot
.60018 .55571 Mdot
.2458 .52511 Mdot
.39495 .6552 Mdot
.63534 .382 Mdot
.66499 .69169 Mdot
.35488 .67067 Mdot
.63583 .64079 Mdot
.5613 .62338 Mdot
.5939 .55192 Mdot
.52069 .63066 Mdot
.38858 .33096 Mdot
.28375 .5641 Mdot
.59217 .66217 Mdot
.52726 .43633 Mdot
.49541 .49381 Mdot
.61341 .65327 Mdot
.63483 .42758 Mdot
.41006 .35 Mdot
.51609 .38204 Mdot
.53341 .73062 Mdot
.57023 .63244 Mdot
.63242 .21533 Mdot
.54756 .82299 Mdot
.51298 .38791 Mdot
.68503 .38085 Mdot
.38478 .67416 Mdot
.58201 .63772 Mdot
.45126 .68859 Mdot
.5746 .65094 Mdot
.51802 .57666 Mdot
.3179 .54617 Mdot
.40447 .3446 Mdot
.55326 .49411 Mdot
.2933 .54318 Mdot
.65258 .38764 Mdot
.70477 .29325 Mdot
.68593 .3654 Mdot
.63092 .43031 Mdot
.33313 .38704 Mdot
.373 .32114 Mdot
.53721 .92039 Mdot
.63296 .79703 Mdot
.54665 .62792 Mdot
.37415 .31718 Mdot
.63197 .41032 Mdot
.61742 .62381 Mdot
.67137 .38808 Mdot
.6169 .37163 Mdot
.55402 .62378 Mdot
.55175 .61909 Mdot
.46106 .689 Mdot
.66172 .24314 Mdot
.37142 .667 Mdot
.61726 .39891 Mdot
.7021 .62742 Mdot
.57504 .61414 Mdot
.56768 .56614 Mdot
.35417 .43035 Mdot
.36883 .68093 Mdot
.71641 .53266 Mdot
.55773 .59495 Mdot
.47083 .80315 Mdot
.54539 .61271 Mdot
.66285 .34764 Mdot
.4143 .36256 Mdot
.50064 .55095 Mdot
.3173 .50745 Mdot
.64707 .43617 Mdot
.3771 .69296 Mdot
.60698 .41832 Mdot
.70313 .57596 Mdot
.36808 .32596 Mdot
.65503 .3706 Mdot
.32333 .56233 Mdot
.37121 .34229 Mdot
.35806 .33811 Mdot
.3821 .4503 Mdot
.3189 .56208 Mdot
.42343 .6541 Mdot
.39657 .36279 Mdot
.68649 .52993 Mdot
.37634 .33492 Mdot
.70185 .56685 Mdot
.56418 .56165 Mdot
.45813 .66488 Mdot
.53661 .50549 Mdot
.5315 .56323 Mdot
.36802 .35418 Mdot
.38319 .65219 Mdot
.61673 .60864 Mdot
.61969 .40958 Mdot
.37844 .65806 Mdot
.44403 .37788 Mdot
.34394 .53636 Mdot
.62198 .37609 Mdot
.34835 .32454 Mdot
.6723 .3803 Mdot
.44431 .761 Mdot
.38931 .70396 Mdot
.37721 .46033 Mdot
.50332 .4605 Mdot
.63404 .57354 Mdot
.64307 .66729 Mdot
.62129 .59674 Mdot
.57846 .568 Mdot
.30271 .51877 Mdot
.39532 .62346 Mdot
.63008 .42314 Mdot
.82629 .42429 Mdot
.3954 .33488 Mdot
.40502 .53624 Mdot
.52396 .5579 Mdot
.60454 .60246 Mdot
.63333 .40214 Mdot
.60824 .38732 Mdot
.81091 .51543 Mdot
.29837 .50413 Mdot
.52184 .58601 Mdot
.62651 .5836 Mdot
.60418 .50004 Mdot
.36476 .34743 Mdot
.57833 .24342 Mdot
.32851 .51177 Mdot
.15511 .64594 Mdot
.29003 .5401 Mdot
.24954 .60226 Mdot
.65969 .40627 Mdot
.39362 .68395 Mdot
.5609 .57545 Mdot
.58151 .41855 Mdot
.68317 .38826 Mdot
.33745 .50213 Mdot
.37933 .67645 Mdot
.59465 .23313 Mdot
.38699 .3184 Mdot
.5805 .55061 Mdot
.54678 .61808 Mdot
.60232 .63279 Mdot
.61643 .6319 Mdot
.38591 .31339 Mdot
.58007 .65262 Mdot
.35253 .35484 Mdot
.71112 .5759 Mdot
.48775 .79456 Mdot
.25725 .53945 Mdot
.19963 .45464 Mdot
.62841 .42781 Mdot
.69585 .44972 Mdot
.71973 .54814 Mdot
.52081 .48906 Mdot
.431 .34812 Mdot
.56745 .55585 Mdot
.30959 .54948 Mdot
.27932 .29528 Mdot
.25832 .53917 Mdot
.36232 .16901 Mdot
.68019 .69507 Mdot
.64153 .27665 Mdot
.60714 .6404 Mdot
.25037 .53549 Mdot
.74753 .63113 Mdot
.63967 .63363 Mdot
.35481 .68546 Mdot
.69148 .5613 Mdot
.66035 .31676 Mdot
.38413 .68677 Mdot
.55231 .61046 Mdot
.61155 .41264 Mdot
.56915 .57104 Mdot
.55512 .58427 Mdot
.5969 .60098 Mdot
.40531 .37073 Mdot
.53971 .60202 Mdot
.55846 .57275 Mdot
.70283 .72692 Mdot
.38038 .55594 Mdot
.28785 .55615 Mdot
.8029 .57388 Mdot
.38808 .6601 Mdot
.67696 .41321 Mdot
.45196 .46114 Mdot
.39004 .32296 Mdot
.80983 .51896 Mdot
.59837 .64469 Mdot
.5873 .30602 Mdot
.38505 .29907 Mdot
.40201 .65411 Mdot
.51862 .38388 Mdot
.55822 .21206 Mdot
.3284 .53539 Mdot
.48496 .36818 Mdot
.3063 .51892 Mdot
.77899 .62887 Mdot
.66028 .36893 Mdot
.63488 .57656 Mdot
.39082 .36019 Mdot
.27642 .55727 Mdot
.4541 .68037 Mdot
.59426 .56419 Mdot
.32476 .52017 Mdot
.63191 .55914 Mdot
.49475 .4837 Mdot
.45699 .45666 Mdot
.28737 .563 Mdot
.37103 .29844 Mdot
.36687 .34087 Mdot
.39263 .68757 Mdot
.66381 .42785 Mdot
.66817 .40854 Mdot
.3699 .33449 Mdot
.22256 .70912 Mdot
.57548 .60775 Mdot
.57039 .62151 Mdot
.52524 .43163 Mdot
.61968 .61813 Mdot
.4246 .62705 Mdot
.49122 .3859 Mdot
.67472 .40302 Mdot
.61997 .60152 Mdot
.61007 .61937 Mdot
.56251 .62886 Mdot
.445 .73616 Mdot
.30127 .53128 Mdot
.58335 .64323 Mdot
.39569 .64576 Mdot
.47081 .37027 Mdot
.54691 .60813 Mdot
.641 .612 Mdot
.66769 .37442 Mdot
.22439 .65319 Mdot
.39132 .34447 Mdot
.29848 .50797 Mdot
.26091 .52015 Mdot
.49892 .75957 Mdot
.6171 .35784 Mdot
.48372 .37345 Mdot
.2195 .4081 Mdot
.5191 .37613 Mdot
.38377 .68067 Mdot
.40938 .45285 Mdot
.26839 .49462 Mdot
.27662 .54765 Mdot
.35523 .30433 Mdot
.6157 .57483 Mdot
.54842 .61737 Mdot
.56741 .33377 Mdot
.58745 .6111 Mdot
.37156 .67423 Mdot
.35559 .34901 Mdot
.66191 .37177 Mdot
.37293 .64662 Mdot
.38396 .35429 Mdot
.66136 .41651 Mdot
.59542 .53297 Mdot
.59936 .65632 Mdot
.64463 .38709 Mdot
.63278 .3824 Mdot
.588 .58933 Mdot
.74039 .70365 Mdot
.67292 .40838 Mdot
.63464 .39451 Mdot
.51488 .41247 Mdot
.3242 .54941 Mdot
.56418 .68523 Mdot
.37228 .31853 Mdot
.56982 .56686 Mdot
.25515 .53669 Mdot
.39545 .67905 Mdot
.65155 .37982 Mdot
.58808 .62237 Mdot
.56884 .60754 Mdot
.39265 .67131 Mdot
.39494 .63769 Mdot
.36549 .66907 Mdot
.40592 .36774 Mdot
.5734 .64731 Mdot
.63437 .42092 Mdot
.38678 .31779 Mdot
.35808 .66212 Mdot
.41102 .67367 Mdot
.70304 .71843 Mdot
.58296 .60196 Mdot
.3512 .67332 Mdot
.37685 .87541 Mdot
.53125 .71293 Mdot
.49651 .38658 Mdot
.2489 .51427 Mdot
.44173 .647 Mdot
.42557 .6675 Mdot
.40362 .32659 Mdot
.38658 .55663 Mdot
.39481 .69132 Mdot
.59024 .61198 Mdot
.60318 .57627 Mdot
.55398 .65136 Mdot
.38408 .65698 Mdot
.44632 .74728 Mdot
.61507 .39528 Mdot
.74277 .47001 Mdot
.38785 .6601 Mdot
.2945 .56342 Mdot
.25047 .51926 Mdot
.28621 .54029 Mdot
.58005 .54711 Mdot
.82013 .53814 Mdot
.70906 .60576 Mdot
.71856 .52045 Mdot
.39411 .32204 Mdot
.60928 .38563 Mdot
.35151 .376 Mdot
.65334 .38634 Mdot
.30844 .53981 Mdot
.39236 .65333 Mdot
.64978 .36212 Mdot
.35883 .33617 Mdot
.36475 .34177 Mdot
.30202 .50026 Mdot
.29365 .53206 Mdot
.28404 .52228 Mdot
.65273 .4346 Mdot
.66017 .40569 Mdot
.60608 .62093 Mdot
.64827 .37677 Mdot
.5555 .82708 Mdot
.43466 .6522 Mdot
.27601 .50092 Mdot
.38849 .33853 Mdot
.63054 .39514 Mdot
.58863 .55769 Mdot
.2854 .59877 Mdot
.33139 .49854 Mdot
.36846 .65438 Mdot
.41775 .24135 Mdot
.24494 .28064 Mdot
.57239 .5449 Mdot
.38601 .30729 Mdot
.48735 .59625 Mdot
.58922 .56912 Mdot
.32295 .53989 Mdot
.57673 .798 Mdot
.52202 .38601 Mdot
.55096 .58509 Mdot
.61713 .55623 Mdot
.35918 .34654 Mdot
.45426 .45985 Mdot
.59367 .608 Mdot
.40523 .4878 Mdot
.40708 .32089 Mdot
.32741 .51066 Mdot
.77673 .70331 Mdot
.42691 .39151 Mdot
.40519 .74373 Mdot
.50796 .39236 Mdot
.58519 .61564 Mdot
.29452 .5169 Mdot
.38025 .64691 Mdot
.29437 .52336 Mdot
.68582 .37809 Mdot
.32556 .54382 Mdot
.60297 .5658 Mdot
.63886 .42254 Mdot
.37898 .35108 Mdot
.40326 .54443 Mdot
.72076 .69678 Mdot
.27616 .55192 Mdot
.52397 .39441 Mdot
.55063 .61411 Mdot
.68317 .50276 Mdot
.54499 .54243 Mdot
.55013 .58091 Mdot
.4085 .34282 Mdot
.63612 .40577 Mdot
.41126 .3472 Mdot
.62219 .53934 Mdot
.69546 .43677 Mdot
.39388 .33194 Mdot
.6199 .33737 Mdot
.36163 .67255 Mdot
.43806 .73157 Mdot
.57183 .58055 Mdot
.39271 .35882 Mdot
.57173 .64449 Mdot
.61737 .39652 Mdot
.48605 .52382 Mdot
.58679 .48468 Mdot
.37987 .36548 Mdot
.66791 .29576 Mdot
.47742 .48657 Mdot
.5824 .68905 Mdot
.39715 .34958 Mdot
.82108 .56097 Mdot
.50521 .3813 Mdot
.40036 .665 Mdot
.37675 .64145 Mdot
.41231 .6575 Mdot
.5837 .61404 Mdot
.66555 .52905 Mdot
.41766 .66027 Mdot
.41016 .36145 Mdot
.41204 .64754 Mdot
.4384 .79272 Mdot
.55808 .31082 Mdot
.36424 .66371 Mdot
.56928 .58497 Mdot
.63906 .57024 Mdot
.38195 .56125 Mdot
.33688 .54849 Mdot
.59343 .21129 Mdot
.68508 .73209 Mdot
.57981 .61113 Mdot
.6623 .51255 Mdot
.67488 .3612 Mdot
.44232 .5921 Mdot
.594 .48712 Mdot
.43813 .43251 Mdot
.63285 .39357 Mdot
.47801 .45657 Mdot
.67389 .41207 Mdot
.62013 .5422 Mdot
.56355 .6064 Mdot
.68343 .40824 Mdot
.48537 .27719 Mdot
.84027 .49657 Mdot
.56981 .30884 Mdot
.64915 .42686 Mdot
.39456 .35046 Mdot
.39799 .31271 Mdot
.4079 .34448 Mdot
.28848 .51105 Mdot
.64271 .37149 Mdot
.57345 .63606 Mdot
.29022 .55308 Mdot
.55822 .58407 Mdot
.36493 .33469 Mdot
.53547 .48471 Mdot
.66278 .37167 Mdot
.58038 .58186 Mdot
.70725 .67011 Mdot
.31005 .52534 Mdot
.39386 .66696 Mdot
.42986 .23077 Mdot
.25937 .50279 Mdot
.36573 .30646 Mdot
.62641 .35896 Mdot
.2864 .57184 Mdot
.2139 .5658 Mdot
.5483 .63218 Mdot
.55327 .63546 Mdot
.3498 .57721 Mdot
.71872 .67437 Mdot
.60173 .59865 Mdot
.28279 .55006 Mdot
.32 .55502 Mdot
.56783 .64105 Mdot
.62855 .37997 Mdot
.41642 .66977 Mdot
.37576 .69458 Mdot
.6277 .56001 Mdot
.49646 .45704 Mdot
.45727 .66798 Mdot
.61417 .61767 Mdot
.57423 .66998 Mdot
.33032 .55854 Mdot
.51022 .39383 Mdot
.52222 .45962 Mdot
.40744 .67339 Mdot
.55714 .60636 Mdot
.82401 .44977 Mdot
.64608 .37312 Mdot
.31903 .51055 Mdot
.3627 .31807 Mdot
.35383 .67515 Mdot
.29314 .4975 Mdot
.56763 .64086 Mdot
.61054 .61883 Mdot
.38372 .36136 Mdot
.65749 .34763 Mdot
.38642 .65446 Mdot
.2926 .55413 Mdot
.3928 .68467 Mdot
.66295 .40312 Mdot
.63666 .38501 Mdot
.62798 .58351 Mdot
.53247 .56305 Mdot
.264 .53879 Mdot
.58121 .65905 Mdot
.27938 .54014 Mdot
.20428 .43913 Mdot
.36842 .31211 Mdot
.61636 .56091 Mdot
.60644 .37052 Mdot
.36583 .33493 Mdot
.58803 .60253 Mdot
.34858 .57744 Mdot
.61016 .6003 Mdot
.26448 .55376 Mdot
.60873 .78429 Mdot
.40743 .66707 Mdot
.66004 .59638 Mdot
.57002 .70273 Mdot
.61991 .61372 Mdot
.32556 .55496 Mdot
.68504 .56258 Mdot
.39072 .32859 Mdot
.65207 .41025 Mdot
.2165 .66167 Mdot
.38042 .33871 Mdot
.56299 .5909 Mdot
.37764 .66384 Mdot
.65817 .42463 Mdot
.49704 .36791 Mdot
.49701 .44094 Mdot
.64452 .59027 Mdot
.59057 .52358 Mdot
.59809 .55316 Mdot
.22023 .35176 Mdot
.28762 .5217 Mdot
.63193 .40532 Mdot
.39129 .31014 Mdot
.37457 .3237 Mdot
.30808 .5319 Mdot
.64706 .31581 Mdot
.53143 .28418 Mdot
.42063 .8954 Mdot
.28493 .49799 Mdot
.41142 .64972 Mdot
.48657 .51397 Mdot
.28852 .54354 Mdot
.29661 .51139 Mdot
.34422 .545 Mdot
.56235 .32588 Mdot
.64646 .42688 Mdot
.56842 .60968 Mdot
.60457 .41493 Mdot
.58382 .61611 Mdot
.40924 .738 Mdot
.36838 .33121 Mdot
.6539 .40977 Mdot
.33941 .69832 Mdot
.64027 .66363 Mdot
.59284 .5767 Mdot
.39157 .73346 Mdot
.62942 .53405 Mdot
.51645 .72145 Mdot
.62345 .62847 Mdot
.29999 .52494 Mdot
.70317 .41565 Mdot
.62369 .65392 Mdot
.70313 .67154 Mdot
.36783 .34585 Mdot
.50357 .36426 Mdot
.61708 .53303 Mdot
.5893 .67715 Mdot
.65629 .42673 Mdot
.65299 .36142 Mdot
.41787 .66138 Mdot
.4446 .21722 Mdot
.37104 .34827 Mdot
.60667 .26223 Mdot
.54679 .58696 Mdot
.39529 .29056 Mdot
.59381 .79428 Mdot
.5916 .59533 Mdot
.38847 .45319 Mdot
.80993 .5175 Mdot
.60546 .59855 Mdot
.72371 .51157 Mdot
.38534 .33591 Mdot
.47593 .79948 Mdot
.6118 .64781 Mdot
.32302 .53585 Mdot
.65461 .41424 Mdot
.62102 .37762 Mdot
.3721 .64968 Mdot
.5906 .81666 Mdot
.34373 .26577 Mdot
.65798 .40847 Mdot
.58901 .56388 Mdot
.39023 .34392 Mdot
.49578 .36625 Mdot
.64708 .61074 Mdot
.30545 .29027 Mdot
.65223 .37373 Mdot
.59383 .6624 Mdot
.58413 .30189 Mdot
.46552 .45547 Mdot
.66375 .23655 Mdot
.4032 .35528 Mdot
.40599 .67607 Mdot
.52536 .62664 Mdot
.21669 .41417 Mdot
.5959 .65666 Mdot
.40769 .74014 Mdot
.62355 .34766 Mdot
.38112 .68504 Mdot
.58532 .57157 Mdot
.59563 .60701 Mdot
.50859 .47009 Mdot
.37085 .64357 Mdot
.59376 .6084 Mdot
.55357 .6638 Mdot
.66734 .40497 Mdot
.49203 .38706 Mdot
.66272 .37326 Mdot
.57259 .57136 Mdot
.61271 .77299 Mdot
.63474 .371 Mdot
.59656 .21829 Mdot
.43813 .67627 Mdot
.39161 .32373 Mdot
.61516 .66235 Mdot
.5592 .56663 Mdot
.57094 .16269 Mdot
.49053 .36877 Mdot
.17957 .57132 Mdot
.25147 .53695 Mdot
.86174 .54206 Mdot
.26587 .49854 Mdot
.65526 .28077 Mdot
.39832 .52199 Mdot
.56423 .65804 Mdot
.64351 .68646 Mdot
.71556 .50987 Mdot
.40429 .29799 Mdot
.68584 .46945 Mdot
.54595 .59119 Mdot
.55794 .61733 Mdot
.28926 .549 Mdot
.63734 .31329 Mdot
.4981 .55935 Mdot
.51959 .45928 Mdot
.40149 .65545 Mdot
.65748 .39717 Mdot
.60238 .56881 Mdot
.45627 .26371 Mdot
.27956 .55647 Mdot
.65011 .71996 Mdot
.57807 .58267 Mdot
.50347 .53952 Mdot
.59861 .33814 Mdot
.38256 .35162 Mdot
.29063 .56387 Mdot
.30581 .5639 Mdot
.58089 .62068 Mdot
.38237 .3147 Mdot
.60743 .61212 Mdot
.47746 .4942 Mdot
.64383 .60411 Mdot
.38858 .68124 Mdot
.56811 .56458 Mdot
.60248 .71619 Mdot
.72427 .29052 Mdot
.61359 .68086 Mdot
.64685 .43358 Mdot
.27996 .52301 Mdot
.3004 .53571 Mdot
.66764 .41003 Mdot
.30107 .53611 Mdot
.74272 .47982 Mdot
.65825 .4843 Mdot
.38353 .6817 Mdot
.72541 .5715 Mdot
.4066 .66299 Mdot
.50628 .36432 Mdot
.58538 .59791 Mdot
.28461 .39344 Mdot
.2886 .49672 Mdot
.45167 .80321 Mdot
.37337 .33293 Mdot
.48932 .37099 Mdot
.55563 .62982 Mdot
.34419 .66427 Mdot
.30937 .54443 Mdot
.40188 .41625 Mdot
.57177 .62696 Mdot
.61799 .41488 Mdot
.60401 .6018 Mdot
.55997 .54474 Mdot
.4878 .37599 Mdot
.60347 .5546 Mdot
.3842 .35424 Mdot
.6493 .368 Mdot
.63981 .28191 Mdot
.2914 .50813 Mdot
.54919 .596 Mdot
.58876 .56491 Mdot
.66684 .36202 Mdot
.54379 .62039 Mdot
.3969 .32093 Mdot
.60305 .8907 Mdot
.36478 .67631 Mdot
.51224 .39403 Mdot
.48073 .18533 Mdot
.61003 .57825 Mdot
.61562 .60777 Mdot
.44344 .40809 Mdot
.82335 .45667 Mdot
.3967 .33974 Mdot
.60528 .5304 Mdot
.29859 .55847 Mdot
.38452 .65369 Mdot
.38764 .36786 Mdot
.57448 .64932 Mdot
.56237 .61846 Mdot
.37669 .6822 Mdot
.40345 .7324 Mdot
.36385 .70064 Mdot
.40212 .32788 Mdot
.64643 .4913 Mdot
.29216 .59923 Mdot
.57648 .60046 Mdot
.5344 .37883 Mdot
.63789 .40015 Mdot
.40014 .34448 Mdot
.8081 .44471 Mdot
.6205 .54369 Mdot
.35334 .3201 Mdot
.37673 .35071 Mdot
.54152 .61555 Mdot
.62435 .35184 Mdot
.60383 .39435 Mdot
.63613 .39961 Mdot
.49355 .78934 Mdot
.17319 .50924 Mdot
.28486 .51911 Mdot
.38622 .34179 Mdot
.25361 .53208 Mdot
.39045 .69269 Mdot
.49664 .48993 Mdot
.30112 .56265 Mdot
.62244 .42594 Mdot
.25633 .53018 Mdot
.60964 .60934 Mdot
.35856 .33222 Mdot
.26084 .52688 Mdot
.61628 .62489 Mdot
.56187 .66922 Mdot
.64083 .6842 Mdot
.41727 .67018 Mdot
.4782 .45549 Mdot
.56521 .58351 Mdot
.5174 .38488 Mdot
.58544 .5876 Mdot
.39289 .31695 Mdot
.38964 .56005 Mdot
.59018 .64513 Mdot
.2866 .49698 Mdot
.18742 .52152 Mdot
.33157 .54573 Mdot
.53936 .57423 Mdot
.57091 .57389 Mdot
.57718 .60319 Mdot
.55318 .62257 Mdot
.66704 .3174 Mdot
.34463 .33319 Mdot
.51856 .5787 Mdot
.28753 .50124 Mdot
.6509 .38386 Mdot
.62779 .37505 Mdot
.43666 .42474 Mdot
.48839 .36595 Mdot
.3761 .31577 Mdot
.57606 .60528 Mdot
.40209 .41776 Mdot
.49661 .42964 Mdot
.5762 .30382 Mdot
.27584 .57173 Mdot
.27365 .54539 Mdot
.63531 .43442 Mdot
.26691 .52806 Mdot
.571 .64781 Mdot
.58163 .66158 Mdot
.63935 .27841 Mdot
.38516 .37765 Mdot
.38884 .6539 Mdot
.56056 .57864 Mdot
.44427 .71909 Mdot
.29925 .55623 Mdot
.32616 .56017 Mdot
.6059 .61546 Mdot
.65625 .35124 Mdot
.73855 .27445 Mdot
.36695 .31839 Mdot
.68135 .5063 Mdot
.70535 .39007 Mdot
.60319 .49606 Mdot
.38418 .32717 Mdot
.39725 .46121 Mdot
.34032 .5384 Mdot
.65595 .76852 Mdot
.64493 .38457 Mdot
.39005 .65503 Mdot
.62166 .64009 Mdot
.62285 .42624 Mdot
.25408 .52083 Mdot
.67758 .40578 Mdot
.63539 .57737 Mdot
.4132 .34841 Mdot
.29494 .5401 Mdot
.36385 .29403 Mdot
.68398 .39982 Mdot
.40722 .66406 Mdot
.46088 .78961 Mdot
.68975 .52534 Mdot
.80962 .51643 Mdot
.58287 .64271 Mdot
.32225 .40492 Mdot
.57384 .63483 Mdot
.61314 .42085 Mdot
.57138 .581 Mdot
.64816 .65239 Mdot
.34093 .52895 Mdot
.62339 .64499 Mdot
.56445 .56687 Mdot
.69918 .6696 Mdot
.59441 .58699 Mdot
.56164 .63283 Mdot
.62047 .55661 Mdot
.67011 .34623 Mdot
.6266 .63807 Mdot
.61906 .41599 Mdot
.58003 .32293 Mdot
.29901 .51109 Mdot
.38739 .69246 Mdot
.37466 .69031 Mdot
.39516 .74278 Mdot
.44316 .72418 Mdot
.63266 .3186 Mdot
.6634 .38064 Mdot
.36555 .35023 Mdot
.6082 .61332 Mdot
.81085 .58557 Mdot
.59002 .77055 Mdot
.33759 .52247 Mdot
.25984 .53503 Mdot
.60961 .65257 Mdot
.28584 .25901 Mdot
.62206 .6446 Mdot
.51832 .43034 Mdot
.58053 .61736 Mdot
.61337 .55381 Mdot
.31244 .56532 Mdot
.44226 .75974 Mdot
.58319 .6433 Mdot
.65783 .4258 Mdot
.39642 .6586 Mdot
.57385 .50083 Mdot
.56922 .78095 Mdot
.67778 .67414 Mdot
.50375 .65238 Mdot
.59266 .64855 Mdot
.30586 .55375 Mdot
.65 .42761 Mdot
.52361 .4403 Mdot
.396 .32198 Mdot
.4942 .4486 Mdot
.70722 .56803 Mdot
.32322 .29796 Mdot
.39423 .65498 Mdot
.35614 .53657 Mdot
.60372 .56572 Mdot
.28704 .51281 Mdot
.61298 .53659 Mdot
.4826 .42059 Mdot
.38985 .68258 Mdot
.66185 .43193 Mdot
.39405 .3506 Mdot
.61492 .41331 Mdot
.79632 .5918 Mdot
.59748 .77069 Mdot
.86216 .54454 Mdot
.33004 .52778 Mdot
.76392 .39167 Mdot
.63753 .41581 Mdot
.57396 .62887 Mdot
.41538 .8924 Mdot
.64226 .40209 Mdot
.6192 .41942 Mdot
.4388 .43953 Mdot
.46441 .77775 Mdot
.60936 .65862 Mdot
.676 .40319 Mdot
.34817 .55223 Mdot
.38081 .67259 Mdot
.61407 .62768 Mdot
.62732 .55357 Mdot
.65173 .36203 Mdot
.31099 .5411 Mdot
.42485 .73774 Mdot
.2975 .52906 Mdot
.64428 .42612 Mdot
.31417 .52239 Mdot
.59375 .22398 Mdot
.28994 .56044 Mdot
.56677 .56331 Mdot
.57571 .60445 Mdot
.29178 .34372 Mdot
.6367 .38497 Mdot
.61622 .60715 Mdot
.55928 .61187 Mdot
.63447 .4185 Mdot
.26665 .4948 Mdot
.79462 .42618 Mdot
.61782 .60083 Mdot
.572 .6088 Mdot
.36905 .68327 Mdot
.48413 .47448 Mdot
.50573 .42166 Mdot
.61618 .62024 Mdot
.41091 .65324 Mdot
.64347 .43633 Mdot
.58695 .58699 Mdot
.44065 .75994 Mdot
.26665 .50084 Mdot
.60391 .64635 Mdot
.5034 .36634 Mdot
.59865 .60024 Mdot
.73216 .27416 Mdot
.54974 .61043 Mdot
.62909 .41014 Mdot
.64716 .41684 Mdot
.36287 .54975 Mdot
.65112 .38892 Mdot
.49433 .3836 Mdot
.36726 .33934 Mdot
.70937 .29926 Mdot
.49248 .38038 Mdot
.59782 .54699 Mdot
.63009 .79971 Mdot
.63101 .56279 Mdot
.64174 .60935 Mdot
.43882 .80509 Mdot
.50536 .39121 Mdot
.63818 .40883 Mdot
.4852 .27293 Mdot
.57854 .65717 Mdot
.37212 .31605 Mdot
.64024 .62933 Mdot
.60331 .64678 Mdot
.64681 .66649 Mdot
.64894 .48332 Mdot
.35327 .3466 Mdot
.5694 .68733 Mdot
.61384 .62759 Mdot
.8229 .45877 Mdot
.59557 .56087 Mdot
.36452 .65948 Mdot
.66943 .38778 Mdot
.26942 .52089 Mdot
.38452 .67879 Mdot
.60701 .57129 Mdot
.38494 .65835 Mdot
.28803 .51477 Mdot
.3956 .36086 Mdot
.57225 .56098 Mdot
.40952 .6375 Mdot
.39257 .65264 Mdot
.59347 .62794 Mdot
.65559 .41099 Mdot
.55192 .5363 Mdot
.58869 .58783 Mdot
.56089 .63664 Mdot
.66858 .40744 Mdot
.40513 .83938 Mdot
.56065 .62602 Mdot
.39467 .45917 Mdot
.66003 .44094 Mdot
.49177 .38484 Mdot
.27419 .54136 Mdot
.54093 .64307 Mdot
.37343 .32246 Mdot
.3691 .33719 Mdot
.31316 .50048 Mdot
.66231 .36429 Mdot
.29868 .54009 Mdot
.63025 .6768 Mdot
.58476 .66164 Mdot
.62085 .6411 Mdot
.21525 .66027 Mdot
.55055 .20412 Mdot
.62681 .3964 Mdot
.33585 .54516 Mdot
.50222 .45384 Mdot
.36257 .32441 Mdot
.33509 .55799 Mdot
.61302 .43107 Mdot
.67378 .37508 Mdot
.66862 .41093 Mdot
.40334 .64983 Mdot
.29008 .53629 Mdot
.61944 .4433 Mdot
.60603 .38629 Mdot
.60074 .62282 Mdot
.61188 .63089 Mdot
.68995 .38058 Mdot
.32671 .48669 Mdot
.40007 .67389 Mdot
.3149 .55257 Mdot
.68075 .19936 Mdot
.36727 .3179 Mdot
.69913 .67113 Mdot
.6174 .62131 Mdot
.19636 .72886 Mdot
.62466 .63938 Mdot
.5908 .56254 Mdot
.67937 .41046 Mdot
.35415 .65954 Mdot
.38254 .66982 Mdot
.63846 .41651 Mdot
.63108 .3593 Mdot
.38487 .6485 Mdot
.42475 .44542 Mdot
.76013 .32124 Mdot
.51573 .44332 Mdot
.6258 .40982 Mdot
.69372 .52514 Mdot
.3888 .36648 Mdot
.65084 .442 Mdot
.34812 .3092 Mdot
.29941 .50998 Mdot
.2716 .54932 Mdot
.38074 .36228 Mdot
.56173 .63019 Mdot
.32734 .52809 Mdot
.62453 .68077 Mdot
.635 .26266 Mdot
.31792 .28579 Mdot
.82265 .59716 Mdot
.54973 .57729 Mdot
.48944 .58004 Mdot
.52649 .33334 Mdot
.60732 .55884 Mdot
.55473 .68819 Mdot
.38653 .65533 Mdot
.65956 .43962 Mdot
.37542 .36932 Mdot
.61176 .2045 Mdot
.57652 .60184 Mdot
.63064 .42343 Mdot
.35895 .32716 Mdot
.58712 .22874 Mdot
.4051 .48672 Mdot
.59879 .61264 Mdot
.46702 .90977 Mdot
.68338 .39597 Mdot
.26957 .52107 Mdot
.72435 .63103 Mdot
.62476 .43497 Mdot
.24756 .58114 Mdot
.26928 .55996 Mdot
.54924 .45739 Mdot
.68 .39269 Mdot
.36809 .7002 Mdot
.66212 .39766 Mdot
.39055 .64167 Mdot
.62901 .35717 Mdot
.31363 .53171 Mdot
.58797 .57651 Mdot
.31087 .52922 Mdot
.35852 .66785 Mdot
.32745 .51627 Mdot
.37512 .36914 Mdot
.51247 .39152 Mdot
.36292 .33835 Mdot
.49344 .49744 Mdot
.78716 .45341 Mdot
.40461 .34481 Mdot
.38738 .42783 Mdot
.60253 .59255 Mdot
.66346 .34778 Mdot
.27406 .51545 Mdot
.31596 .49651 Mdot
.48516 .45622 Mdot
.65495 .42056 Mdot
.31713 .53502 Mdot
.69088 .53304 Mdot
.22485 .71781 Mdot
.61797 .66715 Mdot
.17164 .4889 Mdot
.6319 .41709 Mdot
.34242 .53878 Mdot
.52396 .43103 Mdot
.63232 .36779 Mdot
.26174 .53337 Mdot
.39492 .35301 Mdot
.3786 .32223 Mdot
.54305 .61634 Mdot
.41687 .33988 Mdot
.32381 .55706 Mdot
.82478 .45286 Mdot
.67106 .39478 Mdot
.52986 .19436 Mdot
.36681 .66138 Mdot
.29397 .51145 Mdot
.61738 .653 Mdot
.59826 .38321 Mdot
.26108 .51717 Mdot
.3051 .26517 Mdot
.62667 .17498 Mdot
.31765 .5353 Mdot
.66918 .38658 Mdot
.65403 .38075 Mdot
.61752 .67834 Mdot
.50723 .45838 Mdot
.31326 .54211 Mdot
.28308 .3924 Mdot
.45214 .6992 Mdot
.49563 .37502 Mdot
.69371 .72979 Mdot
.58233 .64371 Mdot
.5943 .6485 Mdot
.40009 .32398 Mdot
.59514 .57758 Mdot
.61729 .37052 Mdot
.62477 .636 Mdot
.40604 .32129 Mdot
.32461 .50877 Mdot
.58221 .59874 Mdot
.37939 .65419 Mdot
.40937 .34773 Mdot
.38668 .30459 Mdot
.30949 .51551 Mdot
.67362 .39604 Mdot
.46961 .28404 Mdot
.29649 .53069 Mdot
.57727 .64893 Mdot
.51013 .38655 Mdot
.62457 .62081 Mdot
.29616 .35308 Mdot
.61401 .39712 Mdot
.26724 .5276 Mdot
.68829 .39975 Mdot
.38286 .34516 Mdot
.33536 .51224 Mdot
.60137 .5597 Mdot
.27185 .54631 Mdot
.3828 .46383 Mdot
.25476 .63217 Mdot
.61293 .37403 Mdot
.37166 .56649 Mdot
.65765 .36084 Mdot
.49538 .37383 Mdot
.49609 .75064 Mdot
.40049 .66807 Mdot
.3166 .55525 Mdot
.59249 .21559 Mdot
.27783 .51055 Mdot
.5948 .59064 Mdot
.56431 .62264 Mdot
.28703 .54813 Mdot
.40902 .65856 Mdot
.39229 .75942 Mdot
.43257 .64587 Mdot
.64687 .37129 Mdot
.4138 .52587 Mdot
.71362 .22972 Mdot
.25018 .55594 Mdot
.36897 .3537 Mdot
.51223 .65208 Mdot
.60834 .59238 Mdot
.35407 .33714 Mdot
.37709 .31043 Mdot
.35883 .65956 Mdot
.29178 .50937 Mdot
.63944 .44793 Mdot
.37529 .36599 Mdot
.59547 .41078 Mdot
.42848 .74745 Mdot
.60497 .52778 Mdot
.62753 .50476 Mdot
.57349 .55299 Mdot
.46583 .45509 Mdot
.40903 .32829 Mdot
.56544 .59225 Mdot
.53802 .65701 Mdot
.40006 .33807 Mdot
.363 .6534 Mdot
.60474 .45248 Mdot
.32042 .52969 Mdot
.2084 .7199 Mdot
.57106 .56191 Mdot
.5885 .58097 Mdot
.39342 .3217 Mdot
.72705 .66824 Mdot
.62371 .39982 Mdot
.67366 .39227 Mdot
.28683 .52203 Mdot
.4665 .41513 Mdot
.54428 .62307 Mdot
.58696 .55567 Mdot
.32537 .53073 Mdot
.51669 .38459 Mdot
.77665 .67936 Mdot
.56876 .60497 Mdot
.3859 .33256 Mdot
.36534 .4399 Mdot
.41156 .33699 Mdot
.58285 .5389 Mdot
.59394 .59588 Mdot
.58611 .55109 Mdot
.54335 .5841 Mdot
.37283 .36139 Mdot
.60033 .5554 Mdot
.58733 .52155 Mdot
.63716 .40505 Mdot
.5876 .64754 Mdot
.45412 .69811 Mdot
.57174 .60102 Mdot
.37847 .65526 Mdot
.488 .41271 Mdot
.5498 .59962 Mdot
.58743 .64817 Mdot
.45019 .6982 Mdot
.58353 .56939 Mdot
.35639 .33119 Mdot
.64745 .38157 Mdot
.38462 .34577 Mdot
.37051 .3516 Mdot
.25773 .52394 Mdot
.38966 .64001 Mdot
.55304 .66013 Mdot
.39038 .64697 Mdot
.63088 .67126 Mdot
.62721 .54979 Mdot
.49106 .48496 Mdot
.51682 .43077 Mdot
.39815 .69077 Mdot
.59472 .55648 Mdot
.29128 .51834 Mdot
.26655 .53149 Mdot
.38631 .5567 Mdot
.64345 .62828 Mdot
.38174 .36895 Mdot
.39304 .35844 Mdot
.42987 .62945 Mdot
.40199 .604 Mdot
.38971 .65121 Mdot
.47322 .55286 Mdot
.60632 .54074 Mdot
.55413 .61048 Mdot
.63981 .57987 Mdot
.25497 .54162 Mdot
.51343 .39228 Mdot
.31461 .50415 Mdot
.51669 .41023 Mdot
.39752 .36671 Mdot
.54997 .57724 Mdot
.33819 .24313 Mdot
.63739 .37179 Mdot
.6467 .38117 Mdot
.40466 .31855 Mdot
.33075 .54759 Mdot
.64412 .60864 Mdot
.16132 .58482 Mdot
.6233 .37088 Mdot
.39187 .68996 Mdot
.57083 .56943 Mdot
.3037 .51349 Mdot
.65395 .36631 Mdot
.41657 .64485 Mdot
.55575 .56865 Mdot
.29652 .56889 Mdot
.57124 .58935 Mdot
.73364 .53457 Mdot
.64433 .4098 Mdot
.53698 .47818 Mdot
.68244 .3592 Mdot
.36326 .3503 Mdot
.39394 .34463 Mdot
.58921 .60139 Mdot
.17694 .64769 Mdot
.63328 .46271 Mdot
.35054 .32665 Mdot
.41661 .64785 Mdot
.51809 .39014 Mdot
.41371 .64481 Mdot
.2807 .5413 Mdot
.39721 .6576 Mdot
.26296 .51556 Mdot
.31134 .48117 Mdot
.65816 .44967 Mdot
.37449 .68005 Mdot
.72779 .6763 Mdot
.5805 .66166 Mdot
.3567 .66628 Mdot
.61561 .64708 Mdot
.64115 .66788 Mdot
.32332 .52127 Mdot
.40003 .65002 Mdot
.58821 .6229 Mdot
.48141 .18097 Mdot
.38451 .35321 Mdot
.37636 .36872 Mdot
.58013 .6608 Mdot
.34297 .54406 Mdot
.62217 .36303 Mdot
.45525 .475 Mdot
.49939 .39201 Mdot
.58578 .5563 Mdot
.57198 .55052 Mdot
.68569 .391 Mdot
.63003 .42979 Mdot
.59058 .60155 Mdot
.67553 .51038 Mdot
.60522 .56639 Mdot
.38199 .32238 Mdot
.6438 .37141 Mdot
.65074 .37948 Mdot
.31326 .5607 Mdot
.65964 .36373 Mdot
.53365 .55111 Mdot
.42674 .34251 Mdot
.63372 .60589 Mdot
.3816 .34254 Mdot
.35818 .50117 Mdot
.30054 .50484 Mdot
.5892 .21181 Mdot
.66248 .36574 Mdot
.62003 .60094 Mdot
.62757 .37613 Mdot
.36597 .67026 Mdot
.63842 .38232 Mdot
.68242 .36695 Mdot
.54459 .60273 Mdot
.58996 .61331 Mdot
.51431 .3837 Mdot
.49868 .45887 Mdot
.65054 .40699 Mdot
.61341 .57867 Mdot
.6239 .60607 Mdot
.56733 .62612 Mdot
.47682 .48277 Mdot
.67459 .41914 Mdot
.68986 .66303 Mdot
.30717 .33714 Mdot
.65593 .4075 Mdot
.67015 .21965 Mdot
.51831 .3733 Mdot
.48937 .3651 Mdot
.36554 .3022 Mdot
.56931 .60951 Mdot
.30319 .53747 Mdot
.59622 .64896 Mdot
.64172 .64213 Mdot
.55045 .5929 Mdot
.37642 .68314 Mdot
.54969 .63439 Mdot
.50505 .37089 Mdot
.30159 .52774 Mdot
.61293 .5823 Mdot
.57919 .60578 Mdot
.49702 .36351 Mdot
.68849 .3695 Mdot
.67237 .3739 Mdot
.54086 .36981 Mdot
.36219 .65718 Mdot
.40748 .33464 Mdot
.58453 .65119 Mdot
.28923 .52054 Mdot
.30686 .53171 Mdot
.61621 .41531 Mdot
.32212 .53948 Mdot
.40784 .3313 Mdot
.59641 .56366 Mdot
.36441 .35198 Mdot
.37605 .68299 Mdot
.66957 .38846 Mdot
.57491 .65038 Mdot
.59844 .62252 Mdot
.64699 .41674 Mdot
.60219 .59682 Mdot
.376 .68518 Mdot
.26503 .5511 Mdot
.63302 .38386 Mdot
.36825 .33947 Mdot
.30602 .56232 Mdot
.61051 .61333 Mdot
.51624 .1342 Mdot
.59592 .57769 Mdot
.58159 .55559 Mdot
.68017 .29361 Mdot
.62395 .58088 Mdot
.28625 .50809 Mdot
.63382 .36981 Mdot
.56903 .54689 Mdot
.44894 .70365 Mdot
.36404 .71365 Mdot
.25706 .55758 Mdot
.57202 .56693 Mdot
.65048 .22312 Mdot
.62051 .60987 Mdot
.61309 .22903 Mdot
.49192 .4845 Mdot
.23267 .34782 Mdot
.62854 .50604 Mdot
.35079 .32497 Mdot
.51547 .38635 Mdot
.28876 .5049 Mdot
.7618 .60936 Mdot
.59968 .58683 Mdot
.81553 .50719 Mdot
.58155 .65267 Mdot
.38269 .32588 Mdot
.54208 .67577 Mdot
.31763 .55025 Mdot
.68758 .72942 Mdot
.56979 .63757 Mdot
.68054 .403 Mdot
.34142 .51715 Mdot
.5208 .38328 Mdot
.58433 .62297 Mdot
.37449 .65182 Mdot
.39444 .70502 Mdot
.53237 .55504 Mdot
.3795 .3438 Mdot
.55678 .60915 Mdot
.57358 .67869 Mdot
.23218 .71402 Mdot
.63393 .40178 Mdot
.38149 .35731 Mdot
.45208 .6169 Mdot
.5669 .62356 Mdot
.67445 .37694 Mdot
.64694 .38434 Mdot
.38191 .64529 Mdot
.45132 .34878 Mdot
.33724 .71289 Mdot
.36968 .20408 Mdot
.81533 .54763 Mdot
.25774 .54664 Mdot
.58977 .3703 Mdot
.59652 .64122 Mdot
.60075 .77125 Mdot
.36695 .34789 Mdot
.58712 .57823 Mdot
.79865 .53853 Mdot
.63446 .39525 Mdot
.56831 .59541 Mdot
.39808 .67525 Mdot
.49009 .31189 Mdot
.6954 .56653 Mdot
.54478 .15386 Mdot
.34532 .55544 Mdot
.6316 .64329 Mdot
.55666 .52567 Mdot
.49299 .38597 Mdot
.57897 .54127 Mdot
.27791 .51352 Mdot
.33131 .40972 Mdot
.40699 .67155 Mdot
.64021 .37032 Mdot
.5204 .37622 Mdot
.58521 .6537 Mdot
.62619 .56294 Mdot
.39835 .68649 Mdot
.57848 .63004 Mdot
.71925 .62836 Mdot
.50222 .36026 Mdot
.28753 .55996 Mdot
.67651 .40811 Mdot
.57583 .55086 Mdot
.51701 .38905 Mdot
.54605 .61062 Mdot
.57227 .70872 Mdot
.56524 .57536 Mdot
.70143 .30726 Mdot
.65579 .41369 Mdot
.37453 .34573 Mdot
.55001 .63715 Mdot
.57652 .59184 Mdot
.2984 .60201 Mdot
.64437 .61765 Mdot
.55187 .61418 Mdot
.61674 .4228 Mdot
.63367 .37312 Mdot
.63052 .42553 Mdot
.30338 .56117 Mdot
.51917 .44806 Mdot
.37618 .32972 Mdot
.64165 .58707 Mdot
.38178 .36772 Mdot
.63848 .51847 Mdot
.41292 .66893 Mdot
.56931 .19675 Mdot
.60194 .57364 Mdot
.66158 .41771 Mdot
.77497 .3662 Mdot
.63957 .43649 Mdot
.3286 .31981 Mdot
.36926 .34724 Mdot
.64536 .40281 Mdot
.58152 .56728 Mdot
.51898 .46149 Mdot
.50053 .14481 Mdot
.36173 .32649 Mdot
.64023 .61205 Mdot
.3456 .55731 Mdot
.30169 .49556 Mdot
.70349 .25279 Mdot
.35776 .33961 Mdot
.52113 .33258 Mdot
.61839 .5984 Mdot
.6442 .36646 Mdot
.40569 .34859 Mdot
.35602 .32322 Mdot
.32453 .53642 Mdot
.60099 .61435 Mdot
.57458 .59223 Mdot
.50679 .36627 Mdot
.38828 .36443 Mdot
.65352 .56039 Mdot
.59997 .60876 Mdot
.64967 .28042 Mdot
.61648 .43453 Mdot
.41468 .84294 Mdot
.60525 .69336 Mdot
.8017 .53044 Mdot
.37092 .49422 Mdot
.62951 .38662 Mdot
.56405 .63419 Mdot
.64236 .59518 Mdot
.27001 .55699 Mdot
.59624 .5674 Mdot
.33741 .53474 Mdot
.35971 .34483 Mdot
.5775 .19494 Mdot
.40583 .42454 Mdot
.43101 .35133 Mdot
.5947 .58174 Mdot
.69107 .55945 Mdot
.37452 .67771 Mdot
.37442 .37602 Mdot
.62225 .41338 Mdot
.59817 .54232 Mdot
.25212 .54085 Mdot
.30274 .5603 Mdot
.64206 .39034 Mdot
.57109 .3446 Mdot
.5983 .21791 Mdot
.54649 .57717 Mdot
.27635 .54115 Mdot
.41171 .39783 Mdot
.69108 .45735 Mdot
.37289 .30228 Mdot
.40452 .67527 Mdot
.29111 .50609 Mdot
.41448 .35858 Mdot
.64332 .66394 Mdot
.64878 .39547 Mdot
.68402 .38872 Mdot
.29099 .58852 Mdot
.31367 .53759 Mdot
.38999 .67278 Mdot
.39646 .54341 Mdot
.40066 .54424 Mdot
.39197 .68154 Mdot
.33804 .52313 Mdot
.62995 .3809 Mdot
.63481 .42486 Mdot
.64888 .38195 Mdot
.7033 .67159 Mdot
.6176 .38522 Mdot
.50572 .82279 Mdot
.59054 .54006 Mdot
.68406 .49952 Mdot
.6138 .5678 Mdot
.36402 .35992 Mdot
.6455 .41072 Mdot
.49977 .48239 Mdot
.61296 .548 Mdot
.52394 .15158 Mdot
.56526 .58148 Mdot
.37935 .44897 Mdot
.57034 .61 Mdot
.72686 .59136 Mdot
.65756 .44177 Mdot
.59898 .557 Mdot
.41858 .31786 Mdot
.3811 .65732 Mdot
.66824 .44565 Mdot
.55246 .61286 Mdot
.58984 .30274 Mdot
.61591 .64631 Mdot
.64043 .2387 Mdot
.22317 .57517 Mdot
.36688 .69121 Mdot
.62734 .60337 Mdot
.26602 .50795 Mdot
.49399 .63679 Mdot
.69308 .51247 Mdot
.36143 .32752 Mdot
.68958 .54813 Mdot
.32502 .54269 Mdot
.55833 .68921 Mdot
.58142 .53073 Mdot
.4104 .66416 Mdot
.61146 .4624 Mdot
.38542 .32264 Mdot
.60123 .58697 Mdot
.56537 .63281 Mdot
.28609 .30613 Mdot
.70115 .52668 Mdot
.61978 .52466 Mdot
.41067 .67699 Mdot
.69951 .56371 Mdot
.5516 .59734 Mdot
.25905 .55875 Mdot
.63735 .36573 Mdot
.51316 .62857 Mdot
.68545 .69428 Mdot
.61127 .57421 Mdot
.64288 .39986 Mdot
.66478 .36603 Mdot
.79679 .38168 Mdot
.41411 .66343 Mdot
.5645 .57674 Mdot
.26876 .58564 Mdot
.57634 .64924 Mdot
.37767 .32609 Mdot
.59796 .53438 Mdot
.30907 .50881 Mdot
.53129 .42599 Mdot
.30644 .56077 Mdot
.57722 .62323 Mdot
.66486 .39473 Mdot
.39195 .32304 Mdot
.21255 .40546 Mdot
.45079 .36864 Mdot
.50173 .82189 Mdot
.3993 .70416 Mdot
.38219 .6509 Mdot
.40672 .64091 Mdot
.37243 .38308 Mdot
.57662 .56575 Mdot
.4587 .455 Mdot
.63033 .66294 Mdot
.5675 .61492 Mdot
.56001 .57739 Mdot
.44198 .37513 Mdot
.37014 .34685 Mdot
.31439 .52594 Mdot
.59181 .60059 Mdot
.61336 .57754 Mdot
.65715 .40207 Mdot
.39317 .65244 Mdot
.27038 .55341 Mdot
.36136 .66323 Mdot
.29848 .524 Mdot
.72932 .26854 Mdot
.61726 .53646 Mdot
.37949 .6589 Mdot
.41229 .3451 Mdot
.64564 .42797 Mdot
.4937 .36543 Mdot
.28244 .54162 Mdot
.31706 .54942 Mdot
.60245 .55595 Mdot
.67049 .38179 Mdot
.67299 .37897 Mdot
.38509 .64877 Mdot
.3971 .35574 Mdot
.53814 .58929 Mdot
.59396 .61106 Mdot
.19782 .43524 Mdot
.27584 .55961 Mdot
.69577 .54789 Mdot
.70043 .31491 Mdot
.57924 .56321 Mdot
.67601 .38275 Mdot
.58328 .59336 Mdot
.36581 .39474 Mdot
.6325 .42869 Mdot
.62029 .57021 Mdot
.65715 .63164 Mdot
.25564 .54185 Mdot
.84287 .45868 Mdot
.55207 .65635 Mdot
.37751 .28602 Mdot
.59309 .63512 Mdot
.87377 .50603 Mdot
.78274 .37968 Mdot
.57885 .65347 Mdot
.54279 .58792 Mdot
.38133 .18939 Mdot
.61914 .62077 Mdot
.50766 .36866 Mdot
.64285 .63906 Mdot
.6758 .37861 Mdot
.39711 .48126 Mdot
.4747 .45525 Mdot
.41336 .65098 Mdot
.28655 .52122 Mdot
.45407 .76887 Mdot
.37545 .645 Mdot
.62973 .41254 Mdot
.62528 .55734 Mdot
.70693 .33158 Mdot
.28881 .49124 Mdot
.55745 .54936 Mdot
.37933 .32564 Mdot
.47465 .45413 Mdot
.30941 .50344 Mdot
.3671 .34018 Mdot
.62199 .60649 Mdot
.19888 .60365 Mdot
.35373 .28127 Mdot
.80499 .38097 Mdot
.40069 .3264 Mdot
.38246 .35109 Mdot
.52723 .45802 Mdot
.4129 .65046 Mdot
.27483 .348 Mdot
.53396 .53842 Mdot
.36518 .32015 Mdot
.53561 .73007 Mdot
.29617 .56655 Mdot
.47885 .42138 Mdot
.65115 .44298 Mdot
.61945 .53677 Mdot
.57802 .57275 Mdot
.40098 .34569 Mdot
.62008 .34281 Mdot
.42487 .6016 Mdot
.36108 .33418 Mdot
.55352 .52996 Mdot
.47712 .41348 Mdot
.51042 .38919 Mdot
.5163 .3695 Mdot
.41898 .65146 Mdot
.28132 .67902 Mdot
.66041 .4129 Mdot
.38463 .69023 Mdot
.56023 .48201 Mdot
.56022 .58909 Mdot
.38521 .3657 Mdot
.51256 .36477 Mdot
.37083 .33691 Mdot
.37818 .66819 Mdot
.40704 .67752 Mdot
.63643 .4045 Mdot
.62302 .39851 Mdot
.70574 .41906 Mdot
.48043 .67251 Mdot
.60406 .64308 Mdot
.8014 .44244 Mdot
.62809 .42717 Mdot
.74709 .63823 Mdot
.40132 .64652 Mdot
.40355 .65681 Mdot
.72115 .47914 Mdot
.60652 .61924 Mdot
.36888 .44285 Mdot
.54999 .60256 Mdot
.52631 .74756 Mdot
.59027 .65473 Mdot
.3238 .53551 Mdot
.5764 .64117 Mdot
.46348 .27009 Mdot
.61308 .5897 Mdot
.55602 .58056 Mdot
.28723 .53931 Mdot
.5358 .61493 Mdot
.31612 .51126 Mdot
.55894 .62562 Mdot
.35715 .65103 Mdot
.28912 .52098 Mdot
.37906 .63311 Mdot
.40611 .46123 Mdot
.51358 .37794 Mdot
.40932 .64389 Mdot
.37323 .65374 Mdot
.42262 .73518 Mdot
.61926 .40257 Mdot
.61546 .70313 Mdot
.57367 .56932 Mdot
.32985 .55884 Mdot
.40671 .35488 Mdot
.61063 .57161 Mdot
.62613 .63514 Mdot
.54832 .65551 Mdot
.63937 .40311 Mdot
.34091 .53233 Mdot
.38264 .66233 Mdot
.26662 .53502 Mdot
.37259 .63875 Mdot
.2795 .50381 Mdot
.57598 .67089 Mdot
.63527 .66853 Mdot
.58162 .52218 Mdot
.80335 .49956 Mdot
.63474 .79044 Mdot
.64645 .39201 Mdot
.50532 .38348 Mdot
.41376 .66801 Mdot
.41323 .53048 Mdot
.66535 .41146 Mdot
.31532 .54889 Mdot
.57129 .58903 Mdot
.56443 .52114 Mdot
.57232 .50685 Mdot
.60109 .41849 Mdot
.40094 .62414 Mdot
.27966 .53066 Mdot
.49587 .38179 Mdot
.51148 .44054 Mdot
.69535 .35346 Mdot
.49673 .49262 Mdot
.57972 .59327 Mdot
.38098 .64886 Mdot
.65373 .36633 Mdot
.28787 .36322 Mdot
.39772 .34944 Mdot
.50325 .45848 Mdot
.59426 .57923 Mdot
.55647 .36062 Mdot
.66451 .39401 Mdot
.40622 .66585 Mdot
.40123 .34434 Mdot
.41315 .65489 Mdot
.52422 .38338 Mdot
.53924 .38017 Mdot
.58356 .6267 Mdot
.5501 .61193 Mdot
.39822 .36585 Mdot
.66224 .41051 Mdot
.34563 .69303 Mdot
.29406 .29768 Mdot
.28248 .54424 Mdot
.45338 .42194 Mdot
.64717 .36873 Mdot
.52541 .34652 Mdot
.27599 .54765 Mdot
.41161 .36024 Mdot
.46255 .45727 Mdot
.40045 .31472 Mdot
.5536 .58911 Mdot
.66035 .37729 Mdot
.35675 .33786 Mdot
.20563 .43683 Mdot
.68316 .26242 Mdot
.61306 .45238 Mdot
.59435 .6034 Mdot
.56943 .19472 Mdot
.55658 .30396 Mdot
.58312 .41659 Mdot
.3727 .36381 Mdot
.58997 .59527 Mdot
.54857 .5743 Mdot
.57085 .63827 Mdot
.38885 .35331 Mdot
.41813 .30071 Mdot
.30584 .55625 Mdot
.56391 .59562 Mdot
.36652 .66274 Mdot
.31184 .51194 Mdot
.28311 .49672 Mdot
.28612 .50614 Mdot
.62799 .42805 Mdot
.61988 .54481 Mdot
.53522 .50592 Mdot
.83871 .42031 Mdot
.3784 .34924 Mdot
.5133 .37765 Mdot
.57717 .55618 Mdot
.46718 .80423 Mdot
.63764 .42723 Mdot
.28938 .54591 Mdot
.5873 .58006 Mdot
.23849 .58139 Mdot
.51171 .36036 Mdot
.29116 .53376 Mdot
.62358 .4151 Mdot
.58345 .41943 Mdot
.59709 .56694 Mdot
.59584 .63464 Mdot
.64182 .42254 Mdot
.53004 .31608 Mdot
.50858 .43604 Mdot
.58203 .59652 Mdot
.37095 .3443 Mdot
.20283 .69625 Mdot
.623 .58805 Mdot
.61343 .35683 Mdot
.51424 .39325 Mdot
.66703 .30873 Mdot
.68217 .52643 Mdot
.61602 .66333 Mdot
.50941 .16901 Mdot
.43929 .78976 Mdot
.59646 .19579 Mdot
.52816 .75991 Mdot
.3257 .28007 Mdot
.76385 .30564 Mdot
.4146 .31327 Mdot
.72654 .57526 Mdot
.28812 .26563 Mdot
.53898 .33251 Mdot
.2264 .60479 Mdot
.23486 .39863 Mdot
.20459 .54856 Mdot
.72821 .71533 Mdot
.28094 .50131 Mdot
.56482 .75933 Mdot
.55367 .62796 Mdot
.53288 .30518 Mdot
.71494 .59111 Mdot
.58654 .82007 Mdot
.57013 .20111 Mdot
.26008 .58504 Mdot
.48285 .13464 Mdot
.57901 .21655 Mdot
.72864 .37476 Mdot
.65828 .71003 Mdot
.30829 .70428 Mdot
.39975 .54755 Mdot
.45529 .77655 Mdot
.68571 .56136 Mdot
.46371 .25573 Mdot
.41297 .30792 Mdot
.76439 .42295 Mdot
.26064 .7425 Mdot
.27347 .52163 Mdot
.63866 .3646 Mdot
.26678 .35048 Mdot
.72522 .34996 Mdot
.32784 .30044 Mdot
.50949 .16882 Mdot
.66062 .28008 Mdot
.72546 .58793 Mdot
.54305 .47897 Mdot
.73648 .5229 Mdot
.37483 .75872 Mdot
.63883 .73687 Mdot
.60624 .37521 Mdot
.23099 .43169 Mdot
.40189 .54743 Mdot
.36701 .72864 Mdot
.73316 .61334 Mdot
.41936 .64562 Mdot
.40273 .63295 Mdot
.62582 .42017 Mdot
.70092 .44438 Mdot
.48792 .36296 Mdot
.56697 .48305 Mdot
.2495 .53817 Mdot
.3733 .40115 Mdot
.4952 .30682 Mdot
.56604 .3182 Mdot
.84337 .53064 Mdot
.55425 .1446 Mdot
.47295 .71534 Mdot
.31714 .39235 Mdot
.33545 .29911 Mdot
.44067 .77198 Mdot
.51981 .5079 Mdot
.49395 .70143 Mdot
.59133 .71406 Mdot
.40588 .14854 Mdot
.60425 .29591 Mdot
.47021 .12861 Mdot
.64091 .35177 Mdot
.52722 .6365 Mdot
.33229 .39524 Mdot
.80574 .57216 Mdot
.43826 .70761 Mdot
.55383 .14921 Mdot
.36557 .69382 Mdot
.65674 .44467 Mdot
.53958 .3341 Mdot
.71749 .62368 Mdot
.33641 .68044 Mdot
.43269 .67186 Mdot
.5143 .6301 Mdot
.39939 .13965 Mdot
.49552 .16818 Mdot
.75914 .34136 Mdot
.64633 .28328 Mdot
.23416 .53572 Mdot
.27595 .49889 Mdot
.35294 .32774 Mdot
.70857 .27742 Mdot
.66165 .38456 Mdot
.84425 .42639 Mdot
.68933 .27474 Mdot
.49535 .64655 Mdot
.38179 .15092 Mdot
.77396 .6752 Mdot
.68077 .50098 Mdot
.57756 .79671 Mdot
.18504 .54763 Mdot
.51328 .50629 Mdot
.50046 .34305 Mdot
.311 .57137 Mdot
.69898 .29926 Mdot
.69512 .25704 Mdot
.55215 .73032 Mdot
.35979 .23211 Mdot
.57312 .48423 Mdot
.37148 .52195 Mdot
.62984 .45803 Mdot
.22859 .62522 Mdot
.45767 .64675 Mdot
.48073 .12999 Mdot
.70273 .57534 Mdot
.18884 .64751 Mdot
.50741 .75785 Mdot
.72429 .66996 Mdot
.50009 .18282 Mdot
.23916 .49965 Mdot
.49131 .66882 Mdot
.59158 .31434 Mdot
.63724 .62084 Mdot
.47961 .54824 Mdot
.56941 .69882 Mdot
.34638 .62599 Mdot
.52423 .44751 Mdot
.58833 .26124 Mdot
.48248 .75407 Mdot
.31833 .27401 Mdot
.66305 .69784 Mdot
.66626 .42346 Mdot
.48026 .69311 Mdot
.49883 .73502 Mdot
.63001 .28026 Mdot
.45347 .61746 Mdot
.75439 .32929 Mdot
.44182 .60776 Mdot
.62712 .65977 Mdot
.72762 .56747 Mdot
.68628 .56832 Mdot
.51587 .72575 Mdot
.55992 .65797 Mdot
.84222 .50653 Mdot
.66034 .29277 Mdot
.79094 .48598 Mdot
.46033 .74847 Mdot
.7997 .49387 Mdot
.70894 .29884 Mdot
.3291 .38735 Mdot
.48946 .34062 Mdot
.59059 .3751 Mdot
.40409 .13939 Mdot
.3156 .51924 Mdot
.52819 .72165 Mdot
.39601 .2927 Mdot
.20711 .42894 Mdot
.27423 .31011 Mdot
.43146 .60224 Mdot
.71925 .29547 Mdot
.56063 .32948 Mdot
.33508 .49915 Mdot
.44559 .23791 Mdot
.43261 .39064 Mdot
.79464 .44605 Mdot
.54155 .65543 Mdot
.53573 .69079 Mdot
.37735 .68593 Mdot
.77685 .59293 Mdot
.30739 .35195 Mdot
.33672 .61749 Mdot
.59788 .66608 Mdot
.32567 .58611 Mdot
.49378 .37447 Mdot
.47912 .44527 Mdot
.7264 .26201 Mdot
.58918 .68702 Mdot
.75963 .68732 Mdot
.55372 .31623 Mdot
.4632 .45027 Mdot
.3999 .73321 Mdot
.65157 .32195 Mdot
.45264 .12738 Mdot
.72515 .29157 Mdot
.54937 .28814 Mdot
.56198 .18971 Mdot
.80533 .67499 Mdot
.24501 .32795 Mdot
.8047 .5981 Mdot
.3972 .2933 Mdot
.59089 .892 Mdot
.26949 .54154 Mdot
.62007 .77352 Mdot
.80289 .57299 Mdot
.26603 .59712 Mdot
.72464 .34796 Mdot
.69301 .59897 Mdot
.41689 .70837 Mdot
.68593 .36845 Mdot
.57461 .66564 Mdot
.5935 .17192 Mdot
.41848 .13883 Mdot
.58178 .1649 Mdot
.53822 .39556 Mdot
.60697 .19082 Mdot
.37891 .18022 Mdot
.5109 .82372 Mdot
.28187 .31905 Mdot
.59324 .53537 Mdot
.53683 .71404 Mdot
.78818 .65317 Mdot
.40675 .69113 Mdot
.54747 .4959 Mdot
.60147 .38358 Mdot
.37326 .17508 Mdot
.72667 .26031 Mdot
.73977 .48081 Mdot
.72465 .40882 Mdot
.37699 .47171 Mdot
.5039 .7017 Mdot
.73172 .34692 Mdot
.47168 .24209 Mdot
.64016 .2639 Mdot
.36247 .19229 Mdot
.49606 .74174 Mdot
.23307 .40561 Mdot
.54216 .27971 Mdot
.7977 .62907 Mdot
.49939 .17941 Mdot
.26133 .3499 Mdot
.48679 .64991 Mdot
.67533 .44505 Mdot
.42657 .60324 Mdot
.4576 .24919 Mdot
.35323 .42791 Mdot
.45435 .7301 Mdot
.32902 .51808 Mdot
.54579 .72554 Mdot
.45284 .51399 Mdot
.28053 .32048 Mdot
.43806 .75013 Mdot
.56429 .73362 Mdot
.57228 .27441 Mdot
.5942 .17774 Mdot
.55421 .31849 Mdot
.17807 .55874 Mdot
.52783 .20422 Mdot
.55433 .69132 Mdot
.53709 .62682 Mdot
.71329 .2964 Mdot
.6614 .19619 Mdot
.72021 .29462 Mdot
.56545 .36877 Mdot
.25176 .57485 Mdot
.41649 .33832 Mdot
.43006 .76168 Mdot
.34872 .59815 Mdot
.64984 .25868 Mdot
.42988 .52278 Mdot
.40931 .36914 Mdot
.48958 .31437 Mdot
.70953 .40991 Mdot
.45797 .79438 Mdot
.75514 .4267 Mdot
.63786 .54255 Mdot
.68491 .47049 Mdot
.68599 .38531 Mdot
.56064 .36683 Mdot
.5018 .70668 Mdot
.31034 .51539 Mdot
.19264 .44582 Mdot
.63576 .3379 Mdot
.53601 .6549 Mdot
.33402 .41607 Mdot
.62556 .45939 Mdot
.80747 .51808 Mdot
.33775 .50587 Mdot
.74562 .28834 Mdot
.83808 .53531 Mdot
.73204 .34542 Mdot
.47727 .70284 Mdot
.20074 .44909 Mdot
.48923 .4389 Mdot
.37287 .29113 Mdot
.56981 .20499 Mdot
.42286 .46196 Mdot
.48561 .70325 Mdot
.67579 .48101 Mdot
.29581 .31387 Mdot
.63872 .64303 Mdot
.77094 .35667 Mdot
.49857 .81578 Mdot
.47166 .43471 Mdot
.69503 .33579 Mdot
.61906 .3776 Mdot
.66479 .78507 Mdot
.47551 .26708 Mdot
.49695 .57292 Mdot
.53289 .18301 Mdot
.36457 .30854 Mdot
.65031 .43036 Mdot
.578 .7329 Mdot
.25899 .63073 Mdot
.66117 .47193 Mdot
.36539 .42336 Mdot
.72647 .36467 Mdot
.41121 .44039 Mdot
.55099 .1844 Mdot
.47718 .15654 Mdot
.20599 .69184 Mdot
.65413 .35285 Mdot
.29615 .37184 Mdot
.29222 .37522 Mdot
.60192 .39284 Mdot
.59711 .39371 Mdot
.69669 .57192 Mdot
.6449 .20464 Mdot
.41101 .51214 Mdot
.4615 .23377 Mdot
.46037 .45349 Mdot
.2332 .61389 Mdot
.28853 .33327 Mdot
.44736 .76061 Mdot
.45401 .18455 Mdot
.73722 .41907 Mdot
.16532 .44971 Mdot
.62304 .51953 Mdot
.62563 .77075 Mdot
.42969 .76189 Mdot
.64151 .71255 Mdot
.73508 .60795 Mdot
.61332 .24668 Mdot
.58362 .6495 Mdot
.57403 .15127 Mdot
.60348 .28282 Mdot
.47284 .56124 Mdot
.23067 .50661 Mdot
.61497 .61405 Mdot
.61461 .54162 Mdot
.73005 .33589 Mdot
.68128 .31113 Mdot
.2026 .35677 Mdot
.51698 .75405 Mdot
.52762 .67799 Mdot
.6741 .49437 Mdot
.76014 .68628 Mdot
.34946 .40348 Mdot
.62642 .22018 Mdot
.45078 .52383 Mdot
.80001 .63655 Mdot
.44909 .2127 Mdot
.44525 .25347 Mdot
.52118 .19663 Mdot
.38785 .17497 Mdot
.50767 .63819 Mdot
.61839 .32579 Mdot
.27045 .35904 Mdot
.5743 .55872 Mdot
.572 .34437 Mdot
.53452 .189 Mdot
.24822 .69116 Mdot
.50691 .52888 Mdot
.65258 .18749 Mdot
.65605 .5905 Mdot
.61305 .31892 Mdot
.27909 .279 Mdot
.13514 .5066 Mdot
.45418 .26408 Mdot
.48867 .13115 Mdot
.43748 .24381 Mdot
.51934 .17753 Mdot
.3524 .31706 Mdot
.41754 .48724 Mdot
.81273 .47094 Mdot
.65151 .20805 Mdot
.28565 .65694 Mdot
.32373 .27614 Mdot
.80084 .42333 Mdot
.6415 .19767 Mdot
.65538 .62118 Mdot
.66952 .77654 Mdot
.24657 .50875 Mdot
.80646 .64393 Mdot
.82547 .56785 Mdot
.70339 .35287 Mdot
.5408 .73452 Mdot
.67113 .76688 Mdot
.56287 .82313 Mdot
.82076 .56941 Mdot
.61526 .7225 Mdot
.67639 .31612 Mdot
.47092 .70288 Mdot
.6604 .25841 Mdot
.71841 .7258 Mdot
.29128 .34905 Mdot
.47626 .38173 Mdot
.53605 .38619 Mdot
.70465 .31228 Mdot
.55709 .25514 Mdot
.33892 .40906 Mdot
.51171 .42278 Mdot
.72221 .3709 Mdot
.26184 .78112 Mdot
.4105 .23547 Mdot
.63762 .49255 Mdot
.43851 .13714 Mdot
.63697 .2672 Mdot
.41953 .52307 Mdot
.73045 .62711 Mdot
.46624 .79553 Mdot
.27978 .48383 Mdot
.55004 .59472 Mdot
.63371 .19464 Mdot
.31601 .48737 Mdot
.50594 .14154 Mdot
.81055 .38443 Mdot
.71408 .44339 Mdot
.55928 .67325 Mdot
.32934 .56812 Mdot
.65287 .72897 Mdot
.61453 .72863 Mdot
.43406 .1466 Mdot
.63097 .76564 Mdot
.44511 .43389 Mdot
.39305 .44351 Mdot
.39619 .42486 Mdot
.49446 .60896 Mdot
.79076 .65392 Mdot
.65913 .31662 Mdot
.46792 .76212 Mdot
.53163 .28385 Mdot
.52119 .72184 Mdot
.68503 .53001 Mdot
.42645 .75596 Mdot
.4538 .58207 Mdot
.40347 .71875 Mdot
.28787 .56415 Mdot
.35152 .21684 Mdot
.5735 .2234 Mdot
.84136 .48812 Mdot
.18003 .55696 Mdot
.59179 .31715 Mdot
.58108 .75924 Mdot
.30875 .31791 Mdot
.49817 .53445 Mdot
.30025 .68535 Mdot
.48791 .77381 Mdot
.69355 .55431 Mdot
.62271 .23405 Mdot
.66795 .67907 Mdot
.70117 .25799 Mdot
.45342 .73408 Mdot
.31112 .25508 Mdot
.37532 .47492 Mdot
.78358 .57013 Mdot
.70183 .5064 Mdot
.17926 .52702 Mdot
.47081 .43686 Mdot
.3995 .14057 Mdot
.64613 .4371 Mdot
.54953 .14341 Mdot
.40224 .32659 Mdot
.25491 .72186 Mdot
.63021 .25103 Mdot
.47567 .53147 Mdot
.46948 .48949 Mdot
.78571 .3717 Mdot
.54637 .32151 Mdot
.5635 .31194 Mdot
.43079 .60712 Mdot
.30444 .49992 Mdot
.44827 .41034 Mdot
.46775 .23211 Mdot
.35526 .2195 Mdot
.54254 .57822 Mdot
.36254 .56219 Mdot
.63192 .73231 Mdot
.35687 .29196 Mdot
.66909 .29557 Mdot
.60411 .22889 Mdot
.65638 .52078 Mdot
.49963 .69753 Mdot
.38582 .17158 Mdot
.66201 .27048 Mdot
.42035 .58917 Mdot
.59306 .70342 Mdot
.34189 .28129 Mdot
.21214 .36921 Mdot
.46795 .17118 Mdot
.39678 .43277 Mdot
.50222 .43291 Mdot
.47482 .71735 Mdot
.66365 .18006 Mdot
.41201 .14367 Mdot
.1626 .49913 Mdot
.45756 .45071 Mdot
.67831 .35029 Mdot
.47872 .79432 Mdot
.31305 .25363 Mdot
.81538 .63371 Mdot
.56849 .28726 Mdot
.52855 .72467 Mdot
.23322 .6698 Mdot
.64557 .77524 Mdot
.43702 .44522 Mdot
.70307 .50706 Mdot
.8142 .52841 Mdot
.33086 .33052 Mdot
.29292 .48058 Mdot
.44773 .47188 Mdot
.33397 .27976 Mdot
.67443 .31588 Mdot
.54668 .3236 Mdot
.30985 .25541 Mdot
.64206 .76139 Mdot
.5981 .70344 Mdot
.32789 .2575 Mdot
.6453 .45225 Mdot
.28787 .37008 Mdot
.19839 .41747 Mdot
.44615 .45905 Mdot
.26292 .52513 Mdot
.58643 .5042 Mdot
.46836 .4077 Mdot
.43671 .23273 Mdot
.20894 .63377 Mdot
.35315 .66683 Mdot
.62748 .35118 Mdot
.65989 .76595 Mdot
.6451 .35391 Mdot
.71 .22528 Mdot
.47455 .24088 Mdot
.67871 .48297 Mdot
.43186 .21142 Mdot
.24712 .40963 Mdot
.17419 .57859 Mdot
.72817 .38285 Mdot
.44892 .70142 Mdot
.64243 .34834 Mdot
.67973 .3731 Mdot
.44996 .20131 Mdot
.50251 .35185 Mdot
.71484 .42278 Mdot
.74277 .70113 Mdot
.20021 .45294 Mdot
.62463 .36431 Mdot
.3914 .44824 Mdot
.59767 .442 Mdot
.73221 .26596 Mdot
.26526 .52637 Mdot
.41219 .13549 Mdot
.60945 .69335 Mdot
.20471 .37443 Mdot
.69394 .2949 Mdot
.53558 .42741 Mdot
.45244 .44178 Mdot
.21228 .43716 Mdot
.63149 .65416 Mdot
.5237 .67449 Mdot
.6211 .40458 Mdot
.28551 .29999 Mdot
.39739 .65566 Mdot
.44516 .64366 Mdot
.39431 .29466 Mdot
.74397 .66368 Mdot
.81491 .61415 Mdot
.68417 .37973 Mdot
.36731 .45722 Mdot
.2876 .38591 Mdot
.65689 .6362 Mdot
.63392 .72684 Mdot
.36888 .19968 Mdot
.72445 .40108 Mdot
.65173 .43549 Mdot
.1668 .51153 Mdot
.42171 .62374 Mdot
.75596 .30335 Mdot
.66055 .5402 Mdot
.6473 .73081 Mdot
.64961 .70766 Mdot
.73439 .33101 Mdot
.68208 .52715 Mdot
.64194 .23639 Mdot
.4844 .69599 Mdot
.40261 .60065 Mdot
.56538 .73238 Mdot
.65761 .52112 Mdot
.41924 .42636 Mdot
.78915 .66496 Mdot
.22628 .66277 Mdot
.73513 .53226 Mdot
.52456 .50843 Mdot
.71188 .3417 Mdot
.76468 .68106 Mdot
.62159 .35384 Mdot
.34743 .67059 Mdot
.77099 .43146 Mdot
.62949 .25289 Mdot
.70611 .27389 Mdot
.6288 .28069 Mdot
.65213 .73181 Mdot
.40102 .42269 Mdot
.52683 .79506 Mdot
.62873 .68938 Mdot
.48809 .51344 Mdot
.62995 .63348 Mdot
.53934 .67703 Mdot
.43074 .53811 Mdot
.79345 .38931 Mdot
.50245 .63989 Mdot
.6418 .20747 Mdot
.7454 .29748 Mdot
.582 .18431 Mdot
.34866 .4276 Mdot
.64814 .35771 Mdot
.43953 .13182 Mdot
.68025 .72268 Mdot
.66257 .26201 Mdot
.81894 .58148 Mdot
.67555 .78117 Mdot
.28619 .26414 Mdot
.60018 .2577 Mdot
.64942 .46485 Mdot
.84257 .45589 Mdot
.60652 .2948 Mdot
.67534 .77019 Mdot
.69498 .56002 Mdot
.68439 .29589 Mdot
.37786 .15779 Mdot
.77724 .62938 Mdot
.56833 .31447 Mdot
.69953 .51169 Mdot
.65919 .50647 Mdot
.72743 .70413 Mdot
.63366 .56213 Mdot
.27176 .50532 Mdot
.2374 .5895 Mdot
.53049 .73222 Mdot
.64013 .50575 Mdot
.71905 .7142 Mdot
.61529 .73016 Mdot
.56863 .76215 Mdot
.20881 .44306 Mdot
.28836 .26376 Mdot
.66668 .4875 Mdot
.55944 .52326 Mdot
.61139 .36217 Mdot
.38985 .6405 Mdot
.5067 .76478 Mdot
.60985 .59803 Mdot
.48607 .46733 Mdot
.50767 .60055 Mdot
.60924 .17357 Mdot
.2458 .61353 Mdot
.41508 .37028 Mdot
.63952 .35953 Mdot
.705 .31449 Mdot
.34059 .3853 Mdot
.53758 .33255 Mdot
.71129 .71649 Mdot
.68914 .44447 Mdot
.53852 .17602 Mdot
.57413 .31977 Mdot
.4722 .73644 Mdot
.35929 .74701 Mdot
.35879 .3521 Mdot
.81303 .50838 Mdot
.42333 .15403 Mdot
.58555 .33152 Mdot
.65056 .44787 Mdot
.53986 .27147 Mdot
.4193 .42911 Mdot
.5948 .33945 Mdot
.54824 .31756 Mdot
.29929 .3415 Mdot
.71484 .46272 Mdot
.47042 .16059 Mdot
.34731 .55586 Mdot
.50858 .74298 Mdot
.49307 .2678 Mdot
.72654 .70984 Mdot
.6587 .63055 Mdot
.67494 .24117 Mdot
.47565 .5245 Mdot
.36855 .61221 Mdot
.59131 .62772 Mdot
.68129 .71076 Mdot
.72943 .33067 Mdot
.52199 .27934 Mdot
.48376 .63991 Mdot
.68912 .40875 Mdot
.84141 .52893 Mdot
.2329 .51451 Mdot
.25536 .49364 Mdot
.59714 .78482 Mdot
.56621 .38231 Mdot
.36276 .59734 Mdot
.45787 .34397 Mdot
.64223 .64868 Mdot
.34786 .73467 Mdot
.37826 .42963 Mdot
.81291 .49472 Mdot
.7988 .60752 Mdot
.36112 .20852 Mdot
.3622 .41815 Mdot
.84548 .52686 Mdot
.82146 .50769 Mdot
.69188 .3052 Mdot
.65499 .76235 Mdot
.56301 .49601 Mdot
.56241 .66093 Mdot
.34737 .67087 Mdot
.6138 .42725 Mdot
.37999 .19759 Mdot
.503 .67192 Mdot
.35988 .62276 Mdot
.46807 .54978 Mdot
.33214 .39752 Mdot
.34897 .47761 Mdot
.65972 .29545 Mdot
.84319 .45693 Mdot
.50029 .70585 Mdot
.35095 .30884 Mdot
.44258 .23576 Mdot
.49639 .54691 Mdot
.6565 .2235 Mdot
.43051 .55609 Mdot
.72744 .34008 Mdot
.50616 .40343 Mdot
.79995 .52881 Mdot
.76156 .32764 Mdot
.45931 .65206 Mdot
.49741 .49777 Mdot
.68035 .32847 Mdot
.54884 .49191 Mdot
.49245 .36552 Mdot
.27393 .60627 Mdot
.67 .73767 Mdot
.35107 .24178 Mdot
.41579 .29665 Mdot
.65047 .5898 Mdot
.48286 .79369 Mdot
.45035 .16861 Mdot
.41458 .5313 Mdot
.46727 .53026 Mdot
.26803 .36264 Mdot
.31785 .48698 Mdot
.2096 .71143 Mdot
.589 .16012 Mdot
.59275 .62762 Mdot
.45662 .4911 Mdot
.43788 .63733 Mdot
.33838 .53513 Mdot
.75198 .41928 Mdot
.37855 .1945 Mdot
.35707 .33227 Mdot
.20445 .49249 Mdot
.45713 .34494 Mdot
.78949 .37825 Mdot
.17061 .47118 Mdot
.39557 .37742 Mdot
.70686 .22122 Mdot
.56131 .2914 Mdot
.61667 .34124 Mdot
.22118 .73192 Mdot
.77778 .37088 Mdot
.60639 .709 Mdot
.22817 .55374 Mdot
.60985 .17869 Mdot
.4545 .44035 Mdot
.27434 .58369 Mdot
.78579 .61816 Mdot
.49499 .7037 Mdot
.51371 .75056 Mdot
.46539 .35256 Mdot
.82266 .45284 Mdot
.63448 .8103 Mdot
.24921 .40832 Mdot
.16489 .55411 Mdot
.71533 .43074 Mdot
.4987 .15296 Mdot
.45489 .26218 Mdot
.25235 .68805 Mdot
.70426 .27611 Mdot
.56893 .72475 Mdot
.72689 .68985 Mdot
.2706 .65605 Mdot
.45229 .66888 Mdot
.47576 .80089 Mdot
.53787 .40154 Mdot
.73027 .39558 Mdot
.21921 .43993 Mdot
.47938 .62442 Mdot
.55538 .7293 Mdot
.80672 .54443 Mdot
.49521 .50075 Mdot
.45288 .1481 Mdot
.70127 .71553 Mdot
.48285 .71031 Mdot
.24192 .37191 Mdot
.40082 .63213 Mdot
.39878 .1895 Mdot
.37898 .39512 Mdot
.61518 .70866 Mdot
.26081 .28987 Mdot
.48022 .13043 Mdot
.56188 .49586 Mdot
.60436 .53892 Mdot
.76639 .30884 Mdot
.38456 .54188 Mdot
.80449 .59608 Mdot
.49618 .29977 Mdot
.52589 .75471 Mdot
.50192 .61172 Mdot
.60741 .65178 Mdot
.55041 .80097 Mdot
.68961 .43258 Mdot
.80976 .53974 Mdot
.18184 .45182 Mdot
.48132 .70491 Mdot
.70685 .69426 Mdot
.1679 .44462 Mdot
.66406 .54391 Mdot
.67757 .38018 Mdot
.60909 .17647 Mdot
.76494 .39237 Mdot
.56759 .70076 Mdot
.68865 .48662 Mdot
.42616 .56921 Mdot
.33413 .70578 Mdot
.60278 .70224 Mdot
.48726 .43921 Mdot
.53819 .73548 Mdot
.31541 .25776 Mdot
.81108 .4575 Mdot
.39483 .13917 Mdot
.72565 .29768 Mdot
.63834 .3559 Mdot
.78924 .60609 Mdot
.44168 .45972 Mdot
.57034 .18053 Mdot
.22094 .42095 Mdot
.19981 .43907 Mdot
.61055 .81419 Mdot
.44214 .65057 Mdot
.5617 .642 Mdot
.53762 .39641 Mdot
.70684 .26773 Mdot
.62937 .80354 Mdot
.69847 .25712 Mdot
.52454 .66129 Mdot
.5395 .63618 Mdot
.12985 .52978 Mdot
.53319 .17971 Mdot
.60758 .67672 Mdot
.51419 .54412 Mdot
.49535 .58691 Mdot
.55552 .6268 Mdot
.52339 .35552 Mdot
.45529 .78406 Mdot
.53361 .74978 Mdot
.64136 .20434 Mdot
.61251 .38443 Mdot
.45907 .44119 Mdot
.37884 .37403 Mdot
.47629 .47263 Mdot
.63304 .50838 Mdot
.36228 .31156 Mdot
.55356 .75157 Mdot
.37695 .51677 Mdot
.3385 .69651 Mdot
.7002 .42327 Mdot
.54143 .40944 Mdot
.71644 .38398 Mdot
.6096 .75927 Mdot
.51586 .34721 Mdot
.55766 .8254 Mdot
.61284 .73187 Mdot
.63375 .69609 Mdot
.64722 .298 Mdot
.78487 .69482 Mdot
.46351 .43564 Mdot
.55124 .37216 Mdot
.6642 .58371 Mdot
.69636 .64794 Mdot
.70127 .47116 Mdot
.40427 .69956 Mdot
.49128 .37867 Mdot
.53467 .66813 Mdot
.72402 .34077 Mdot
.39891 .31061 Mdot
.65966 .18308 Mdot
.54879 .6606 Mdot
.74615 .43789 Mdot
.65557 .23552 Mdot
.28808 .35936 Mdot
.69119 .55449 Mdot
.62989 .62676 Mdot
.40605 .5857 Mdot
.37781 .52145 Mdot
.59031 .3987 Mdot
.28717 .3274 Mdot
.50734 .16435 Mdot
.61536 .76864 Mdot
.73265 .43629 Mdot
.56749 .57631 Mdot
.35559 .68834 Mdot
.49049 .44885 Mdot
.25102 .67312 Mdot
.36895 .53905 Mdot
.64821 .2727 Mdot
.59911 .75847 Mdot
.51594 .75428 Mdot
.70117 .5309 Mdot
.52512 .14279 Mdot
.51129 .52765 Mdot
.70878 .44936 Mdot
.45235 .56771 Mdot
.56462 .25592 Mdot
.61241 .72539 Mdot
.33735 .25652 Mdot
.51499 .65745 Mdot
.5616 .50088 Mdot
.70311 .23502 Mdot
.72958 .37627 Mdot
.43463 .3417 Mdot
.62431 .23317 Mdot
.67687 .73442 Mdot
.46903 .49111 Mdot
.23354 .75067 Mdot
.21814 .4201 Mdot
.69335 .212 Mdot
.30232 .29722 Mdot
.66305 .66118 Mdot
.65316 .32062 Mdot
.57842 .66623 Mdot
.29865 .53704 Mdot
.55065 .17064 Mdot
.68451 .33109 Mdot
.57188 .48835 Mdot
.61106 .53579 Mdot
.39843 .52949 Mdot
.59353 .38904 Mdot
.34302 .24497 Mdot
.30368 .49521 Mdot
.42161 .58565 Mdot
.32703 .27101 Mdot
.37725 .52139 Mdot
.6928 .77148 Mdot
.43754 .14464 Mdot
.57398 .20707 Mdot
.38437 .43154 Mdot
.22115 .69652 Mdot
.65986 .34153 Mdot
.6014 .42267 Mdot
.39958 .30186 Mdot
.53273 .79864 Mdot
.59034 .33588 Mdot
.30938 .26485 Mdot
.73293 .31879 Mdot
.65824 .63378 Mdot
.28624 .80934 Mdot
.5784 .72866 Mdot
.41371 .55043 Mdot
.57557 .35046 Mdot
.65315 .21357 Mdot
.21166 .53638 Mdot
.80612 .38264 Mdot
.46786 .25624 Mdot
.63998 .50786 Mdot
.51456 .81521 Mdot
.1688 .51082 Mdot
.38229 .44342 Mdot
.16485 .55725 Mdot
.51068 .18439 Mdot
.45499 .77598 Mdot
.51242 .27905 Mdot
.6581 .35195 Mdot
.51604 .6668 Mdot
.47883 .23561 Mdot
.54664 .49742 Mdot
.6237 .33983 Mdot
.50209 .16862 Mdot
.39984 .77138 Mdot
.23723 .36174 Mdot
.5706 .19177 Mdot
.35934 .28976 Mdot
.69646 .34925 Mdot
.6095 .73834 Mdot
.36553 .56116 Mdot
.33142 .53073 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
08[ooooo0_l00003ooooo`Co00000_ooool2o`000;;ooooo000Looooo`03o`000?oooooooooo08[o
oooo0ol00002ooooo`Co00000_ooool2o`000004ooooool0003o0000ooooo`;o0000[?ooool001co
oooo00?o0000ooooooooool0Roooool2o`0000_ooooo1Ol00007ooooo`;o0000Xoooool001cooooo
00?o0000ooooooooool0P_ooool2o`0000Oooooo0_l0000<ooooo`;o00002Oooool2o`000:?ooooo
000Looooo`03o`000?oooooooooo07gooooo2Ol00005ooooo`;o0000_?ooool001cooooo00?o0000
ooooooooool0OOooool9o`0001_ooooo0_l00004ooooo`;o00001_ooool3o`0009Oooooo000Loooo
o`03o`000?oooooooooo08;ooooo0_l00005ooooo`?o00004oooool4o`0000Cooooo0_l00006oooo
o`?o00001oooool2o`0008kooooo000Looooo`03o`000?oooooooooo083ooooo0_l00007ooooo`?o
00000oooool2o`0000kooooo0_l0000?ooooo`;o00001oooool2o`0008kooooo000Looooo`;o0000
NOooool2o`0000Kooooo0_l0000=ooooo`;o000000?oooooo`000?l000000oooool2o`0000Gooooo
0_l00006ooooo`;o00002?ooool2o`0000Gooooo0_l0002@ooooo`007?ooool00ol0003ooooooooo
o`1hooooo`;o00003?ooool2o`0000[ooooo0_l00003ooooo`;o00001Oooool2o`0000Kooooo0_l0
0005ooooo`;o00002?ooool2o`00093ooooo000Looooo`03o`000?oooooooooo07Oooooo0_l0000=
ooooo`;o00003oooool2o`0000cooooo0_l00006ooooo`;o0000V_ooool001cooooo00?o0000oooo
ooooool0Moooool2o`0001cooooo0_l0000>ooooo`;o00003oooool2o`0000Cooooo0_l0002;oooo
o`007?ooool00ol0003oooooooooo`2Eooooo`;o00002_ooool2o`000003ooooool0003o0000013o
oooo0_l000001?oooooo0000o`000?ooool2o`0008_ooooo000Looooo`03o`000?oooooooooo07;o
oooo0_l0000Kooooo`;o00003?ooool9o`0001?ooooo0_l0002>ooooo`007?ooool00ol0003ooooo
ooooo`1booooo`;o00001_ooool2o`0001?ooooo0_l00003ooooo`;o00001oooool4o`000003oooo
ool0003o000000_ooooo0_l0000<ooooo`;o0000R_ooool001cooooo00?o0000ooooooooool0M_oo
ool2o`0000;ooooo0_l0000Hooooo`;o00006Oooool3o`0000_ooooo0_l00003ooooo`;o00001?oo
ool2o`0007oooooo000Looooo`03o`000?oooooooooo07Kooooo0_l00002ooooo`;o0000:Oooool2
o`0000Cooooo0_l00003ooooo`;o00001_ooool2o`0000?ooooo0_l00003ooooo`;o00001?ooool2
o`0000Oooooo0_l0001fooooo`007?ooool00ol0003oooooooooo`1gooooo`;o00008?ooool2o`00
00?ooooo0_l00005ooooo`;o00000_ooool4o`0000Sooooo0_l000000ooooooo0000o`000003oooo
o`;o00000oooool2o`0000gooooo0_l000000ooooooo0000o`00001cooooo`007?ooool00ol0003o
ooooooooo`1gooooo`;o00005oooool2o`0000Oooooo0_l00003ooooo`?o000000?oooooo`000?l0
00001Oooool2o`0000Cooooo0_l00004ooooo`;o00000_ooool2o`0000Oooooo0_l0000>ooooo`Co
0000Loooool001cooooo00?o0000ooooooooool0T?ooool2o`0000Kooooo0_l00005ooooo`;o0000
00?oooooo`000?l000001Oooool2o`0000Cooooo0_l00008ooooo`;o00005Oooool4o`0007Gooooo
000Looooo`03o`000?oooooooooo07Sooooo0_l00004ooooo`;o00006?ooool2o`00013ooooo0_l0
0007ooooo`;o00002oooool2o`0000kooooo0_l0001gooooo`0000Koooooonk^k_lb<S;o0000oc8b
<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0L_ooool2o`0000Cooooo
0_l00004ooooo`;o00009?ooool2o`0000Cooooo0_l00007ooooo`;o000000?oooooo`000?l00000
2?ooool3o`0008Kooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1booooo`;o00000oooool2o`00
02_ooooo1_l00004ooooo`;o00001Oooool5o`0000Cooooo1Ol00007ooooo`;o00001oooool2o`00
07Cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^
k^h01oooool00ol0003oooooooooo`1dooooo`;o000000Coooooo`000?l0003o0000;?ooool4o`00
00Cooooo0_l00005ooooo`;o000000?oooooo`000?l000001?ooool2o`0000[ooooo0_l000000ooo
oooo0000o`000004ooooo`;o00001?ooool2o`0006kooooo00000ooooooo0000ooooo`02ooooo`03
o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0007Cooooo0_l00002ooooo`;o
00005?ooool2o`0002Gooooo0_l000000ooooooo0000o`00000Cooooo`;o00002_ooool2o`0006ko
oooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool0
1Oooool00ol0003oooooooooo`1dooooo`;o00006?ooool2o`0001Sooooo0_l00005ooooo`;o0000
1?ooool2o`000003ooooool0003o000000Wooooo0_l00003ooooo`;o00000oooool3o`0007Wooooo
00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`1booooo`Co00005_ooool2o`0001[ooooo0_l00005ooooo`;o00001?oo
ool5o`0000Wooooo0ol00002ooooo`;o00000oooool5o`0007Oooooo00001_ooooooMgMgoiRHV?oo
ooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo077o
oooo0ol0000Eooooo`;o000000?oooooo`000?l000009?ooool2o`0000?ooooo0ol000000ooooooo
0000o`000002o`0000Gooooo0_l00007ooooo`;o000000?oooooo`000?l000002oooool2o`0006[o
oooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006
ooooo`03o`000?oooooooooo077ooooo0_l0000Fooooo`;o000000?oooooo`000?l000000_l0000R
ooooo`;o00001oooool4o`0000_ooooo0_l00004ooooo`;o00002oooool2o`0006[ooooo000Loooo
o`03o`000?oooooooooo06kooooo0_l0000Mooooo`?o0000:?ooool2o`000003ooooool0003o0000
00Co00002Oooool2o`0000Cooooo0_l0001gooooo`007?ooool00ol0003oooooooooo`1^ooooo`Co
00006Oooool4o`0002Wooooo0_l000000ooooooo0000o`000004o`0000Oooooo0_l0000<ooooo`;o
00002_ooool2o`0006Gooooo000Looooo`03o`000?oooooooooo073ooooo0_l0000Iooooo`;o0000
:_ooool2o`0000Cooooo1_l00005ooooo`;o00001_ooool3o`0000?ooooo0_l0000:ooooo`;o0000
IOooool001cooooo00?o0000ooooooooool0S?ooool2o`0002Wooooo0_l000001?oooooo0000o`00
0?ooool6o`0000_ooooo1Ol0000@ooooo`;o0000I?ooool001cooooo00?o0000ooooooooool0R?oo
ool2o`0000;ooooo0_l0000/ooooo`?o000000?oooooo`000?l000000_l000001?oooooo0000o`00
0?l00008ooooo`?o00004_ooool3o`0006?ooooo000Looooo`03o`000?oooooooooo077ooooo0_l0
000Dooooo`Go00001_ooool4o`0002Gooooo1?l000001?oooooo0000o`000?ooool3o`000003oooo
ool0003o000000Kooooo0_l0000Cooooo`;o0000Hoooool001cooooo00?o0000ooooooooool0LOoo
ool2o`0000oooooo0_l00003ooooo`Oo00001?ooool4o`0000;ooooo0_l0000Kooooo`;o00001_oo
ool2o`0000Oooooo0ol00004ooooo`;o00000_ooool2o`000003ooooool0003o000000_ooooo0_l0
001Vooooo`007?ooool00ol0003oooooooooo`22ooooo`;o00002?ooool3o`0000Wooooo0_l0000K
ooooo`;o00003oooool2o`000004ooooool0003o0000ooooo`?o00000_ooool2o`000003ooooool0
003o000000_ooooo0_l0001Vooooo`007?ooool00ol0003oooooooooo`1Zooooo`;o00000_ooool2
o`0001Cooooo0_l00007ooooo`;o00001_ooool3o`00037ooooo0_l000000ooooooo0000o`000005
ooooo`;o00000_ooool2o`00073ooooo000Looooo`03o`000?oooooooooo06Wooooo1ol0000Doooo
o`Go000000?oooooo`000?l000002Oooool3o`00023ooooo0_l0000Iooooo`Ko0000L?ooool001co
oooo00?o0000ooooooooool0JOooool5o`0001Oooooo1?l000000ooooooo0000o`000005ooooo`;o
00009Oooool2o`0000Wooooo0_l0000@ooooo`;o0000L_ooool001cooooo0_l0001Pooooo`;o0000
<?ooool2o`00033ooooo0_l00004ooooo`;o0000O_ooool001cooooo00?o0000ooooooooool0Gooo
ool5o`0002Wooooo0_l0000Qooooo`?o00005_ooool2o`000003ooooool0003o000001?ooooo0_l0
001Vooooo`007?ooool00ol0003oooooooooo`1Oooooo`Ko00000_ooool2o`000003ooooool0003o
0000027ooooo0_l00004ooooo`?o00006_ooool3o`000003ooooool0003o000000?ooooo0_l00004
ooooo`;o00002?ooool2o`000003ooooool0003o000000Gooooo0_l00009ooooo`Go0000I_ooool0
01cooooo00?o0000ooooooooool0F?ooool3o`0000Cooooo0ol000000ooooooo0000o`000002oooo
o`;o000000?oooooo`000?l000009oooool3o`0001kooooo0_l00003ooooo`Co00000_ooool2o`00
00kooooo1_l00009ooooo`Co00001_ooool2o`0005oooooo000Looooo`03o`000?oooooooooo05So
oooo1?l0000dooooo`;o0000:Oooool2o`0000Cooooo0_l00007ooooo`Co000000?oooooo`000?l0
00001?l00005ooooo`;o00003?ooool2o`0005oooooo000Looooo`03o`000?oooooooooo05Wooooo
0ol00003ooooo`Co00001?ooool2o`0000?ooooo0_l0000Rooooo`;o00001Oooool2o`0000?ooooo
0_l0000Sooooo`;o00001oooool4o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`;o0000
1_ooool2o`0000Cooooo1?l0001Mooooo`007?ooool00ol0003oooooooooo`1Eooooo`;o00000ooo
ool2o`0000?ooooo1?l00004ooooo`;o00000oooool2o`00023ooooo0_l00003ooooo`;o00000_oo
ool2o`0000?ooooo0_l0000/ooooo`?o00000oooool2o`000003ooooool0003o000000gooooo0_l0
0005ooooo`?o0000GOooool001cooooo00?o0000ooooooooool0EOooool2o`00013ooooo0_l0000U
ooooo`;o00000oooool2o`0000Gooooo0_l0000@ooooo`;o00008Oooool2o`0000;ooooo0_l0000=
ooooo`;o00001Oooool2o`0005kooooo000Looooo`03o`000?oooooooooo06Cooooo1Ol0000Woooo
o`;o00002?ooool2o`00013ooooo0_l00008ooooo`;o00005?ooool5o`000003ooooool0003o0000
00Sooooo0_l00003ooooo`?o00001_ooool4o`0005_ooooo000Looooo`03o`000?oooooooooo05Oo
oooo0_l0000;ooooo`Co000000?oooooo`000?l000003_ooool2o`000003ooooool0003o000001;o
oooo0_l00008ooooo`;o00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`;o
00002?ooool2o`0000cooooo0_l00006ooooo`?o00000oooool3o`0000Oooooo0_l00003ooooo`?o
00001_ooool4o`0005_ooooo000Looooo`03o`000?oooooooooo04cooooo0_l00009ooooo`;o0000
3Oooool2o`000003ooooool0003o000000;o000000Goooooo`000?l0003o0000ooooo`02o`0000Go
oooo0_l000000ooooooo0000o`00000Looooo`;o00000_ooool4o`000004ooooool0003o0000oooo
o`;o00001?ooool2o`0001;ooooo0_l00002ooooo`?o000000Goooooo`000?l0003o0000ooooo`02
o`000003ooooool0003o000000Co00003Oooool2o`0006Gooooo000Looooo`03o`000?oooooooooo
04cooooo0_l0000<ooooo`;o00002?ooool2o`0000Gooooo0_l000001Ooooooo0000o`000?l0003o
oooo00;o00000oooool2o`0000Gooooo0_l0000Eooooo`;o00001oooool4o`0000;ooooo0_l00003
ooooo`;o00001?ooool2o`0000oooooo0_l00003ooooo`;o000000Goooooo`000?l0003o0000oooo
o`07o`0007Kooooo000Looooo`03o`000?oooooooooo05[ooooo0_l00008ooooo`;o00004Oooool2
o`0000Gooooo0_l0000Eooooo`;o00003Oooool2o`0000?ooooo0_l00004ooooo`;o00001?ooool2
o`0001Cooooo0_l000000ooooooo0000o`00000Nooooo`;o0000FOooool001cooooo00?o0000oooo
ooooool0DOooool2o`000003ooooool0003o000000?ooooo0_l00004ooooo`;o00003oooool3o`00
00;ooooo0_l00006ooooo`;o0000<?ooool2o`0000;ooooo1?l0000Dooooo`;o00003Oooool4o`00
00Wooooo0ol00004ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0DOooool2o`000004
ooooool0003o0000ooooo`Co00001?ooool2o`0000oooooo1?l000000ooooooo0000o`000002oooo
o`;o000000Coooooo`000?l0003o0000=?ooool2o`0000?ooooo0_l00007ooooo`;o00004?ooool2
o`0000Cooooo1ol000000ooooooo0000o`000003ooooo`Co0000Goooool001cooooo00?o0000oooo
ooooool0EOooool4o`0000?ooooo1?l00004ooooo`Co00001Oooool2o`0000?ooooo0_l000001?oo
oooo0000o`000?ooool7o`000004ooooool0003o0000ooooo`;o0000;Oooool2o`0000Cooooo0_l0
0006ooooo`?o00002oooool2o`0000?ooooo1Ol000000ooooooo0000o`000002o`000004ooooool0
003o0000ooooo`;o000000?oooooo`000?l000001?l00004ooooo`;o0000FOooool001cooooo0_l0
001Fooooo`;o00000_ooool2o`000003ooooool0003o000000;o00001?ooool7o`0000;ooooo0_l0
0006ooooo`;o000000?oooooo`000?l000001?l00002ooooo`;o000000Coooooo`000?l0003o0000
5oooool3o`0001;ooooo1Ol00009ooooo`;o00003?ooool2o`0000Gooooo0ol00003ooooo`;o0000
0_ooool2o`000003ooooool0003o000000;o00000_ooool2o`0000Cooooo0_l0001Iooooo`007?oo
ool00ol0003oooooooooo`1Iooooo`;o00003?ooool4o`0000?ooooo1?l000000ooooooo0000o`00
0002o`0000;ooooo1ol00003ooooo`Co00005_ooool3o`00017ooooo0_l000000ooooooo0000o`00
0003o`000003ooooool0003o000000;o00004?ooool2o`0000oooooo0_l000001?oooooo0000o`00
0?l0000=ooooo`;o0000EOooool001cooooo00?o0000ooooooooool0FOooool2o`0001?ooooo1?l0
00000ooooooo0000o`00000=o`0000?ooooo0_l0000Fooooo`;o00002_ooool2o`0000Kooooo0ol0
0002ooooo`?o000000?oooooo`000?l000000_l0000Aooooo`;o00003?ooool2o`000003ooooool0
003o000000;o00003_ooool4o`0005?ooooo000Looooo`03o`000?oooooooooo05Gooooo1_l00009
ooooo`;o00001oooool3o`0000;ooooo4_l0000Iooooo`;o00002_ooool2o`0000Cooooo1Ol00000
1?oooooo0000o`000?l00003ooooo`;o00003_ooool2o`0000;ooooo0_l00004ooooo`;o00001_oo
ool2o`000003ooooool0003o000000;o00004?ooool3o`0005;ooooo000Looooo`03o`000?oooooo
oooo05Gooooo1?l00003ooooo`;o00001Oooool3o`0000Oooooo0ol000000ooooooo0000o`00000B
o`000003ooooool0003o000001?ooooo0_l0000Booooo`;o000000?oooooo`000?l000001?l00003
ooooo`;o00003_ooool2o`0000Sooooo0_l00003ooooo`;o00001Oooool2o`0001;ooooo0_l0001B
ooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o00001?ooool2o`0000Kooooo0_l00004oooo
o`?o00002_oooolCo`000004ooooool0003o0000ooooo`;o00004oooool2o`0000_ooooo0_l00006
ooooo`Oo00001?ooool3o`0000gooooo0_l000001Ooooooo0000o`000?l0003ooooo00?o00000_oo
ool5o`0000Cooooo0ol000000ooooooo0000o`00001Sooooo`007?ooool00ol0003oooooooooo`1>
ooooo`;o00001?ooool2o`0000;ooooo0_l00007ooooo`?o00000oooool2o`0000Cooooo5Ol00002
ooooo`;o00005?ooool3o`0000_ooooo0_l00004ooooo`Co00000_ooool5o`000003ooooool0003o
000000;o00001Oooool2o`0000Gooooo0_l00002ooooo`?o000000?oooooo`000?l000001_l00006
ooooo`?o000000?oooooo`000?l000001?ooool2o`0005gooooo000Looooo`03o`000?oooooooooo
05Oooooo0ol00007ooooo`;o00001?ooool2o`0000Cooooo5Ol000001?oooooo0000o`000?l0000D
ooooo`;o00004_ooool4o`0000;ooooo0_l000000ooooooo0000o`000005o`0000Gooooo0_l00005
ooooo`;o00000_ooool4o`0000?ooooo0_l0000Cooooo`;o00001oooool2o`0005Cooooo000Loooo
o`03o`000?oooooooooo05Oooooo0_l0000=ooooo`;o00001OoooolHo`00017ooooo0_l0000Foooo
o`;o00000oooool2o`0000?ooooo1Ol00008ooooo`;o00001oooool4o`00027ooooo0_l00003oooo
o`;o0000Coooool001cooooo00?o0000ooooooooool0C?ooool2o`0000cooooo0_l0000:ooooo`;o
00001OoooolGo`0000;ooooo0_l00002ooooo`;o00002_ooool2o`0001Kooooo0_l00003ooooo`;o
00000oooool2o`0000_ooooo0_l0000Booooo`;o00001oooool4o`0000_ooooo0_l000000ooooooo
0000o`000002ooooo`;o0000Coooool001cooooo00?o0000ooooooooool0C?ooool2o`0000Oooooo
0_l00003ooooo`;o00002?ooool2o`0000;ooooo0_l00003oooooa_o00000_ooool2o`0002Kooooo
0_l00003ooooo`;o000000?oooooo`000?l000003oooool2o`0000cooooo1?l00005ooooo`Co0000
0oooool4o`0000Cooooo0_l000000ooooooo0000o`00001Cooooo`007?ooool00ol0003ooooooooo
o`1:ooooo`;o00002Oooool2o`0000?ooooo0_l00008ooooo`;o00000_ooool2o`0000;ooooo7?l0
000Nooooo`?o00000_ooool3o`0000Cooooo0_l000000ooooooo0000o`000005o`0000oooooo0ol0
000;ooooo`Co00001Oooool2o`0000Gooooo1?l0001Looooo`007?ooool00ol0003oooooooooo`1:
ooooo`;o00003_ooool2o`0000?ooooo0ol0000:oooooa[o00001Oooool2o`0001Wooooo0ol00002
ooooo`?o00001oooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000Gooooo0_l0
0003ooooo`?o00002oooool3o`0000;ooooo0_l00002ooooo`;o00001Oooool2o`0000oooooo0_l0
001=ooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00006Oooool5o`0000gooooo2?l00000
0ooooooo0000o`000006o`000003ooooool0003o000000?o00000oooool4o`0000Sooooo0_l00004
ooooo`?o00005oooool2o`0000Gooooo1Ol00004ooooo`Co00000_ooool2o`0000Gooooo0ol00005
ooooo`;o000000Coooooo`000?l0003o00000oooool2o`0000;ooooo1?l00008ooooo`Co00000ooo
ool2o`0004gooooo000Looooo`03o`000?oooooooooo04;ooooo0_l0000Gooooo`Co00003oooool9
o`000003ooooool0003o000000Wo000000Coooooo`000?l0003ooooo1?l00006ooooo`;o00000_oo
ool2o`0000;ooooo1Ol000000ooooooo0000o`000002o`0001;ooooo0ol00005ooooo`;o00001_oo
ool4o`0000Wooooo0ol00008ooooo`;o00001?ooool2o`0000;ooooo0ol00009ooooo`Co0000D_oo
ool001cooooo00?o0000ooooooooool0B?ooool2o`00017ooooo0_l0000AoooooaKo00000_ooool5
o`0000Gooooo0ol00006ooooo`;o00001?ooool4o`000004ooooool0003o0000ooooo`;o00003Ooo
ool3o`0000gooooo1_l00006ooooo`Ko00004_ooool2o`0005gooooo000Looooo`;o0000BOooool2
o`0000Oooooo1?l000000ooooooo0000o`000003ooooo`;o00004?oooolGo`0000;ooooo1?l00005
ooooo`Co00003Oooool6o`000003ooooool0003o000000kooooo0_l0000>ooooo`Go000000?ooooo
o`000?l000000oooool6o`000003ooooool0003o000000?ooooo0_l00005ooooo`;o000000?ooooo
o`000?l000000_l0000:ooooo`;o0000DOooool001cooooo00?o0000ooooooooool0A?ooool2o`00
00_ooooo1ol00003ooooo`?o00000_ooool2o`0000_ooooo5ol000000ooooooo0000o`000005o`00
00?ooooo0_l00002ooooo`;o00001oooool2o`000003ooooool0003o000000;ooooo0ol00004oooo
o`;o00001?ooool2o`000003ooooool0003o000000;ooooo0_l0000=ooooo`Co00000_ooool4o`00
0004ooooool0003o0000o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o000000?ooooo
o`000?l000000_ooool2o`000003ooooool0003o000000Wooooo0_l000000ooooooo0000o`00001A
ooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00000oooool3o`0000Kooooo0_l00006oooo
o`;o00001_ooool3o`000003ooooool0003o000000gooooo5Ol000001?oooooo0000o`000?ooool4
o`0000Cooooo0_l000000ooooooo0000o`000007ooooo`;o000000?oooooo`000?l000001Oooool2
o`0000;ooooo0_l00003ooooo`?o000000?oooooo`000?l000003_ooool2o`000003ooooool0003o
000000;o00000_ooool8o`0000Cooooo1?l00002ooooo`;o000000?oooooo`000?l000000_l0000<
ooooo`Co00000_ooool2o`0000?ooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`0noooo
o`;o00000oooool2o`0000Oooooo0_l00006ooooo`;o00000_ooool4o`000003ooooool0003o0000
013ooooo0_l000000ooooooo0000o`00000Ao`0000_ooooo0_l0000:ooooo`;o00002?ooool2o`00
00Oooooo0_l0000>ooooo`;o00000_ooool4o`000005ooooool0003o0000o`000?ooool02_l00002
ooooo`Co00001oooool2o`0000cooooo0_l00003ooooo`?o00000oooool2o`0004_ooooo000Loooo
o`03o`000?oooooooooo04Wooooo0_l00008ooooo`?o00000_ooool4o`0000oooooo0_l000000ooo
oooo0000o`00000Go`0001Cooooo0ol000000ooooooo0000o`000003o`0000?ooooo0_l00008oooo
o`;o00003?ooool2o`0000;ooooo2?l000001?oooooo0000o`000?ooool:o`000003ooooool0003o
000001[ooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00000_ooool2o`00
00Sooooo0_l00005ooooo`;o00003oooool2o`000003ooooool0003o000001Oo00005?ooool:o`00
00;ooooo0_l00008ooooo`;o00004?ooool2o`000004ooooool0003o0000o`0000;ooooo3_l00002
ooooo`;o00001_ooool2o`0000?ooooo0_l0000>ooooo`;o0000Coooool001cooooo00?o0000oooo
ooooool0@Oooool2o`0000;ooooo0_l0000Zooooo`;o000000?oooooo`000?l000003Ol000000ooo
oooo0000o`000009ooooo`Go00001Oooool>o`0000?ooooo0_l00006ooooo`Co00004OoooolFo`00
00Kooooo0_l00003ooooo`;o00003_ooool2o`0004oooooo000Looooo`03o`000?oooooooooo047o
oooo0_l00008ooooo`;o00003Oooool4o`0000;ooooo0_l0000Coooooa3o00002_ooool5o`000003
ooooool0003o000000;ooooo3ol00002ooooo`Co000000Coooooo`000?l0003ooooo1?l00006oooo
o`;o00000_oooolNo`0000Wooooo0_l0000@ooooo`Co0000C?ooool001cooooo00?o0000oooooooo
ool0?oooool2o`0000[ooooo0_l0000=ooooo`Co00000_ooool2o`0001Cooooo0ol00007ooooo`;o
000000?oooooo`000?l000001oooool2o`0000Cooooo0_l000000ooooooo0000o`000002oooooa7o
000000Goooooo`000?l0003o0000ooooo`02o`0000Sooooo0_l000000ooooooo0000o`000002oooo
oa_o000000?oooooo`000?l000002Oooool4o`0000kooooo1?l0001<ooooo`007?ooool00ol0003o
ooooooooo`0oooooo`;o00006_ooool4o`0000oooooo0_l00006ooooo`Wo00002Oooool2o`0000;o
oooo0ol00009ooooo`Oo00000_ooool9o`000003ooooool0003o000000cooooo0_l000000ooooooo
0000o`000003oooooaco00003?ooool2o`0001;ooooo0_l0001:ooooo`007?ooool00ol0003ooooo
ooooo`0mooooo`;o00000oooool2o`0001Wooooo0_l0000?ooooo`;o000000?oooooo`000?l00000
0_ooool3o`000003ooooool0003o000000Ko00001oooool2o`0000;ooooo0ol00008ooooo`?o0000
00?oooooo`000?l000004?l0000<ooooo`;o00001_ooool2o`0000;ooooo6Ol0000;ooooo`;o0000
3oooool2o`000003ooooool0003o000000;o000000?oooooo`000?l00000AOooool001cooooo00?o
0000ooooooooool0?Oooool2o`0000;ooooo0ol0000]ooooo`;o00000_ooool2o`0000?ooooo0_l0
0003ooooo`;o00000oooool2o`00017ooooo0_l00002ooooo`ko000000Coooooo`000?l0003o0000
1oooool2o`0000Wooooo1_l000000ooooooo0000o`00000Fo`0000Gooooo1?l00002ooooo`;o0000
3oooool2o`0000?ooooo0_l000001?oooooo0000o`000?l00014ooooo`007?ooool00ol0003ooooo
ooooo`11ooooo`;o000000?oooooo`000?l000005?ooool2o`0000_ooooo0ol000000ooooooo0000
o`000008ooooo`;o00000oooool2o`0000?ooooo0_l00003ooooo`;o00000_ooool2o`00013ooooo
4_l00008ooooo`;o00002Oooool8o`000003ooooool0003o0000013o000000?oooooo`000?l00000
1_ooool4o`0000;ooooo0_l0000Gooooo`?o0000A?ooool001cooooo00?o0000ooooooooool0A?oo
ool4o`0001;ooooo0_l00004ooooo`;o00001Oooool3o`000003ooooool0003o000001;ooooo0_l0
0007ooooo`?o00003ooooolCo`00013ooooo0_l00002ooooo`Oo000000?oooooo`000?l000002?l0
0002ooooo`Co000000?oooooo`000?l000000ol00002ooooo`;o00006oooool2o`0004Wooooo0000
1_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0
1?ooool00ol0003oooooooooo`16ooooo`;o00004?ooool3o`0000Gooooo0_l000000ooooooo0000
o`000002ooooo`;o00001oooool2o`0001Gooooo1?l0000<ooooo`;o00000_ooool=o`000003oooo
ool0003o000000;o00004?ooool5o`000003ooooool0003o000000go000000?oooooo`000?l00000
2_l00002ooooo`;o00004Oooool3o`0000Oooooo0_l00019ooooo`0000KoooooogMgMonHV9Sooooo
oiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05So
oooo0ol00008ooooo`;o00000oooool4o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o
00003?ooool4o`0000kooooo0_l00002ooooo`go00000oooool2o`00017ooooo1?l000000ooooooo
0000o`00000Io`0000_ooooo0_l00009ooooo`?o00001oooool2o`0004Wooooo00000ooooooo410@
ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006ooooo`03o`000?oooooooooo043ooooo
0_l00007ooooo`;o00007Oooool4o`0000Oooooo0_l00002ooooo`;o00001?ooool2o`0000?ooooo
0_l000000ooooooo0000o`00000Jooooo`Oo00000oooool2o`0000?ooooo0_l0000:ooooo`Ko0000
00?oooooo`000?l000006Ol00003ooooo`;o00001_ooool2o`0005kooooo00000ooooooo0000oooo
o`02ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`00043ooooo
0_l00007ooooo`;o00007Oooool2o`0000cooooo1?l00003ooooo`;o00000oooool2o`00027ooooo
0_l00004ooooo`;o00000oooool2o`0000[ooooo0_l00005oooooa_o00000oooool2o`0000Gooooo
0_l0000:ooooo`;o0000Doooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Ooo
ool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo043ooooo0ol00005ooooo`;o0000
6oooool2o`0000Oooooo0_l00004ooooo`Ko00009oooool2o`0000;ooooo0_l00004ooooo`;o0000
5_oooolIo`0000cooooo0_l0000:ooooo`;o0000Doooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo043ooooo0ol0
00000ooooooo0000o`000002ooooo`;o00000oooool2o`0001Kooooo0_l00003ooooo`;o00000_oo
ool2o`0000Cooooo0_l00003ooooo`;o00004Oooool2o`0000Kooooo0_l0000;ooooo`;o00002Ooo
ool2o`0001Gooooo6ol00004ooooo`;o00001?ooool2o`0005oooooo00001_ooooooMgMgoiRHV?oo
ooooV9RHogMgM`cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`14ooooo`;o0000
1oooool2o`0000;ooooo0_l0000Eooooo`Co00003Oooool2o`00017ooooo1?l00004ooooo`;o0000
3Oooool3o`0000Kooooo0_l0000@ooooo`;o00000oooool8o`000003ooooool0003o0000013o0000
1?ooool3o`0000?ooooo0_l0001Oooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03
ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0@oooool3o`0000Oooooo0_l00002ooooo`;o
00005Oooool4o`0000?ooooo0_l0000Mooooo`;o00001?ooool2o`000005ooooool0003o0000o`00
0?ooool00_l00006ooooo`?o00001_ooool2o`00013ooooo0_l000000ooooooo0000o`00000Ho`00
00Kooooo1?l0001Tooooo`007?ooool00ol0003oooooooooo`0mooooo`?o00000oooool2o`0002Co
oooo0ol00003ooooo`;o000000?oooooo`000?l000002oooool2o`0000kooooo0_l00002ooooo`?o
000000Goooooo`000?l0003o0000ooooo`02o`0001cooooo0ol00003oooooa7o000000?oooooo`00
0?l000002_l00004ooooo`;o0000I_ooool001cooooo00?o0000ooooooooool0?Oooool3o`0000?o
oooo0ol0000Sooooo`;o00001oooool2o`0000_ooooo0_l000000ooooooo0000o`00000;ooooo`;o
00000_ooool2o`0000?ooooo0ol00006ooooo`;o00004?ooool2o`0000Cooooo0ol00003oooooako
00001?ooool2o`0000Wooooo0_l00002ooooo`;o000000?oooooo`000?l000002Oooool2o`0000co
oooo0ol0000jooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00000oooool3o`0002Gooooo
0_l00006ooooo`;o00002?ooool7o`0000Kooooo0_l00002ooooo`Co00001_ooool3o`0000Kooooo
0ol00002ooooo`;o000000?oooooo`000?l000002?ooool2o`0000Gooooo0_l00004oooooaco0000
1?ooool3o`000003ooooool0003o000000Kooooo0_l00002ooooo`;o000000Coooooo`000?l0003o
00002?ooool4o`0000Oooooo0_l000001?oooooo0000o`000?l0000jooooo`007?ooool00ol0003o
ooooooooo`13ooooo`;o00009_ooool2o`000004ooooool0003o0000o`0000;ooooo0_l00005oooo
o`;o000000?oooooo`000?l000000ol00002ooooo`;o00000oooool3o`0000;ooooo1?l00007oooo
o`;o00001oooool2o`0000;ooooo1_l00009ooooo`;o00002OoooolGo`0000;ooooo0_l00005oooo
o`;o00000_ooool2o`0000_ooooo0_l000000ooooooo0000o`000008ooooo`Co00001oooool2o`00
00?ooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`0kooooo`;o00000oooool2o`000003
ooooool0003o000002Wooooo0ol00006ooooo`;o000000?oooooo`000?l000002?ooool2o`0000?o
oooo0ol00008ooooo`;o000000Coooooo`000?l0003o00001?ooool4o`000003ooooool0003o0000
00Oo00002Oooool2o`0000Sooooo0_l00002oooooaGo00002?ooool2o`0000?ooooo0_l00003oooo
o`;o00001Oooool2o`0000_ooooo0_l0000>ooooo`;o0000>Oooool001cooooo00?o0000oooooooo
ool0>oooool2o`000003ooooool0003o000000;o00001Oooool4o`0002Cooooo0_l00006ooooo`Co
00000_ooool2o`0000Gooooo1?l00002ooooo`Ko00001?ooool2o`000004ooooool0003o0000o`00
00Cooooo2ol0000Fooooo`;o00000_ooool2o`0000?ooooo3Ol000000ooooooo0000o`000002oooo
o`Co00001oooool2o`0000?ooooo0_l0000;ooooo`;o00005?ooool2o`0003[ooooo000Looooo`03
o`000?oooooooooo03cooooo1ol00004ooooo`Co0000;_ooool2o`0000;ooooo0_l00004ooooo`;o
000000?oooooo`000?l000000oooool5o`0000?ooooo1?l00007ooooo`Ko00000oooool3o`0001[o
oooo0_l000000ooooooo0000o`00000<o`000003ooooool0003o000000;ooooo1_l0000:ooooo`;o
00002oooool2o`0000oooooo0_l00003ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0
??ooool7o`000003ooooool0003o000002gooooo0_l0000>ooooo`Co00001?ooool2o`0000Kooooo
1?l00004ooooo`;o00001?ooool2o`0000?ooooo1?l0000=ooooo`;o00002oooool2o`000004oooo
ool0003o0000ooooo`co00002?ooool2o`0000[ooooo0_l00003ooooo`;o00005oooool2o`0003oo
oooo000Looooo`03o`000?oooooooooo03gooooo1Ol00002ooooo`;o0000;Oooool3o`0000cooooo
1Ol00003ooooo`?o00000_ooool4o`0000Sooooo0_l000000ooooooo0000o`000008o`0000oooooo
0ol00004ooooo`?o000000Coooooo`000?l0003ooooo1?l00007ooooo`Ko00001?ooool2o`0000So
oooo0_l00004ooooo`;o00000oooool2o`0000oooooo0_l00005ooooo`?o0000?oooool001cooooo
00?o0000ooooooooool0<oooool2o`0000Kooooo0_l000000ooooooo0000o`000002o`0003;ooooo
0_l00002ooooo`;o00000_ooool2o`0000Cooooo1_l00002ooooo`;o00000oooool4o`0000Gooooo
0_l00004ooooo`So00004_ooool2o`0000Cooooo0ol000000ooooooo0000o`000006o`0000;ooooo
0_l00002ooooo`Oo000000?oooooo`000?l000001?l00002ooooo`;o00000_ooool2o`0001Sooooo
1?l000000ooooooo0000o`000002ooooo`?o0000?oooool001cooooo00?o0000ooooooooool0<ooo
ool4o`0000Cooooo0_l000000ooooooo0000o`00000gooooo`?o000000Coooooo`000?l0003o0000
1_ooool4o`0000;ooooo0_l00003ooooo`;o00001oooool2o`0000;ooooo0ol00002ooooo`;o0000
0_ooool5o`0001Wooooo0_l00003ooooo`Ko00000_ooool4o`000004ooooool0003o0000ooooo`;o
00000_ooool2o`0000;ooooo1?l00004ooooo`;o00004_ooool4o`0000?ooooo0_l00003ooooo`;o
0000?oooool001cooooo0_l0000cooooo`;o000000?oooooo`000?l000000_l00005ooooo`;o0000
00?oooooo`000?l00000=?ooool3o`000003ooooool0003o000000Kooooo0_l0000<ooooo`Co0000
1oooool3o`0000?ooooo0_l000000ooooooo0000o`000005o`0000oooooo0_l00004ooooo`Go0000
0oooool;o`0000[ooooo0_l00002ooooo`;o00001?ooool2o`0001;ooooo0_l0000:ooooo`;o0000
?oooool001cooooo00?o0000ooooooooool0<_ooool2o`0000?ooooo0_l00004ooooo`;o00000_oo
ool2o`0003Gooooo1_l00003ooooo`Co00003?ooool@o`000003ooooool0003o000000;ooooo0_l0
00000ooooooo0000o`000003o`0000gooooo0_l00004ooooo`Ko00001oooool2o`0000;ooooo0_l0
000:ooooo`;o00007?ooool2o`0000Wooooo0ol0000oooooo`007?ooool00ol0003oooooooooo`0m
ooooo`;o00001_ooool2o`0002gooooo0_l00004ooooo`Co00000oooool2o`000003ooooool0003o
000000[ooooo5Ol000000ooooooo0000o`000003o`000004ooooool0003o0000ooooo`;o00005?oo
ool2o`0000;ooooo0_l00008ooooo`;o00001_ooool4o`0001gooooo0_l00006ooooo`;o000000Co
ooooo`000?l0003o00001?ooool2o`0003Wooooo000Looooo`03o`000?oooooooooo03Oooooo0_l0
000<ooooo`;o0000;Oooool2o`000003ooooool0003o000000?ooooo0ol000000ooooooo0000o`00
0002ooooo`;o00001_ooool9o`000003ooooool0003o000001;o00001Oooool2o`0001;ooooo0_l0
0002ooooo`Co00001oooool3o`0000Cooooo1_l0000Uooooo`;o000000Coooooo`000?l0003o0000
1?ooool2o`0003Wooooo000Looooo`03o`000?oooooooooo03Oooooo0_l0000nooooo`Co000000Go
ooooo`000?l0003o0000ooooo`02o`0000Cooooo0_l00004ooooo`Ko000000?oooooo`000?l00000
0ol00006ooooo`Co000000?oooooo`000?l000001?l000000ooooooo0000o`00000Gooooo`;o0000
0_ooool5o`0000?ooooo1_l00004ooooo`;o00002Oooool2o`00027ooooo0_l00003ooooo`;o0000
>oooool001cooooo00?o0000ooooooooool0=Oooool2o`0004;ooooo0_l00005ooooo`;o00001?oo
ool2o`0000Kooooo0_l00004ooooo`?o00000oooool2o`0000kooooo0_l0000Gooooo`;o00001?oo
ool3o`0000?ooooo1?l0000Aooooo`;o00008Oooool2o`0000?ooooo0_l0000kooooo`007?ooool0
0ol0003oooooooooo`0eooooo`;o0000B?ooool3o`0000cooooo0_l00005ooooo`;o00000oooool2
o`000003ooooool0003o000000;ooooo0_l0000hooooo`;o00004?ooool2o`0001Gooooo0_l00000
0ooooooo0000o`000004ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0=?ooool2o`00
047ooooo0_l00006ooooo`;o00003Oooool2o`0000Oooooo0_l00004ooooo`;o00000_ooool2o`00
013ooooo0_l000000ooooooo0000o`00000=ooooo`;o00003?ooool2o`0000Kooooo0_l00003oooo
o`;o00002oooool2o`0001Gooooo0_l00007ooooo`;o0000>_ooool001cooooo00?o0000oooooooo
ool0=?ooool2o`0001?ooooo0_l0000[ooooo`?o00001_ooool2o`0000_ooooo1_l00002ooooo`;o
000000Coooooo`000?l0003ooooo1Ol0000Dooooo`;o000000?oooooo`000?l000003Oooool2o`00
00Cooooo0_l00006ooooo`;o00002oooool2o`0006Oooooo000Looooo`03o`000?oooooooooo04Wo
oooo0_l0000Sooooo`;o00001_ooool2o`0000Gooooo0_l0000=ooooo`;o00000_ooool2o`0000;o
oooo0_l00004ooooo`Go00000oooool2o`000003ooooool0003o000000Cooooo1?l0000Looooo`;o
00006Oooool2o`0000Gooooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`1Kooooo`;o0000
1?ooool2o`0000_ooooo0_l0000=ooooo`Go00005Oooool2o`0000Kooooo1Ol000000ooooooo0000
o`000003ooooo`Go00000oooool4o`0000[ooooo0_l0000;ooooo`Co00001oooool3o`0000_ooooo
0_l00004ooooo`?o0000F_ooool001cooooo00?o0000ooooooooool0;Oooool2o`0002Sooooo0_l0
0002ooooo`?o000000?oooooo`000?l000000_l0000Jooooo`Go00005?ooool3o`0000?ooooo1_l0
0002ooooo`;o00001?ooool2o`0000Kooooo2?l000000ooooooo0000o`000003ooooo`;o00002ooo
ool4o`000003ooooool0003o000000Cooooo0ol0000Aooooo`;o00003oooool4o`0004Sooooo000L
ooooo`03o`000?oooooooooo02gooooo0_l00005ooooo`;o00008Oooool2o`000003ooooool0003o
000000;o000000Goooooo`000?l0003o0000ooooo`05o`0001Sooooo0_l00002ooooo`;o00003ooo
ool4o`0000?ooooo0ol00005ooooo`?o00000oooool2o`0000[ooooo1?l000000ooooooo0000o`00
0002o`0000[ooooo0_l00007ooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0
003o000001oooooo1?l0000<ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0=?ooool2
o`0000Wooooo0_l0000Iooooo`;o00001oooool5o`0000Oooooo0_l00003ooooo`;o00002_ooool2
o`0000;ooooo0_l0000;ooooo`;o00000_ooool4o`0000Cooooo0ol00005ooooo`;o00002?ooool2
o`0000Gooooo0_l00005ooooo`;o00002_ooool4o`000003ooooool0003o000000Gooooo0_l00005
ooooo`;o0000;oooool2o`0003[ooooo000Looooo`03o`000?oooooooooo03oooooo0_l0000>oooo
o`;o00000_ooool2o`0000Gooooo1ol000000ooooooo0000o`00000;ooooo`;o00000oooool3o`00
01Wooooo0ol00002ooooo`Go00000oooool3o`0000oooooo0ol0000Hooooo`?o000000?oooooo`00
0?l000001oooool2o`0002Oooooo0_l00002ooooo`;o00000_ooool2o`0003oooooo000Looooo`03
o`000?oooooooooo04oooooo0_l00002ooooo`Co000000?oooooo`000?l000002ol00003ooooo`;o
00002oooool2o`0001Wooooo0_l00005ooooo`?o00000oooool3o`0000kooooo1?l000000ooooooo
0000o`00000;ooooo`;o00005Oooool2o`0001;ooooo0_l0000Cooooo`?o000000?oooooo`000?l0
00000_ooool2o`0000?ooooo0_l0000jooooo`007?ooool2o`0002[ooooo0_l00006ooooo`;o0000
5oooool2o`0000Oooooo5?l000001?oooooo0000o`000?l00006ooooo`;o0000:_ooool3o`0000Go
oooo0_l00007ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00000oooool2o`0000;o
oooo0_l00008ooooo`;o00003Oooool3o`0000oooooo0_l0000Dooooo`;o00002_ooool2o`0003[o
oooo000Looooo`03o`000?oooooooooo02Wooooo0_l00006ooooo`;o00005oooool2o`0000Gooooo
5_l00002ooooo`?o00001Oooool2o`0000kooooo0_l0000Jooooo`?o00001Oooool2o`0000[ooooo
2?l00002ooooo`?o00000_ooool2o`0000Kooooo1?l0000=ooooo`?o00009Oooool2o`0004Kooooo
000Looooo`03o`000?oooooooooo02Sooooo0_l0000Mooooo`;o00002?oooolFo`0000;ooooo0ol0
0008ooooo`;o00002oooool2o`0001Oooooo0_l00007ooooo`Co00000oooool3o`0000Oooooo1?l0
0003ooooo`;o00002?ooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o00001_oo
ool2o`0000Cooooo0ol00002ooooo`;o00007_ooool4o`0000Gooooo0_l00008ooooo`;o0000;ooo
ool001cooooo00?o0000ooooooooool0:?ooool2o`0000Wooooo1?l0000@ooooo`;o00000oooool2
o`0000;ooooo7?l00003ooooo`Co000000?oooooo`000?l000003_ooool2o`0001Cooooo0_l00007
ooooo`Ko000000Coooooo`000?l0003o00001oooool4o`0000?ooooo0ol00007ooooo`Wo00001?oo
ool2o`0000Cooooo1?l00004ooooo`?o00000_ooool2o`0001gooooo1Ol00005ooooo`;o00002?oo
ool2o`0002oooooo000Looooo`03o`000?oooooooooo03;ooooo1Ol0000Eooooo`;o000000?ooooo
o`000?l000006ol00003ooooo`Co00001oooool2o`0000Kooooo1?l00009ooooo`;o00001oooool5
o`0000[ooooo0_l000000ooooooo0000o`00000@ooooo`;o000000?oooooo`000?l000001Oooool2
o`0000;ooooo0_l00007ooooo`;o00000oooool2o`0000?ooooo1?l00004ooooo`Co00000_ooool2
o`0001Kooooo1?l00012ooooo`007?ooool00ol0003oooooooooo`0booooo`;o00005?ooool2o`00
00?ooooo6Ol000000ooooooo0000o`000004o`0000[ooooo0_l000000ooooooo0000o`000006oooo
o`Co00002Oooool2o`0000Oooooo1Ol0000=ooooo`;o00004oooool2o`0001;ooooo0_l00008oooo
o`Co00001_ooool2o`0000;ooooo0_l0000Fooooo`?o000000Coooooo`000?l0003o0000?oooool0
01cooooo00?o0000ooooooooool0B?ooool2o`0000;ooooo8Ol00002ooooo`;o00001_ooool2o`00
0003ooooool0003o000000Gooooo0_l0000cooooo`;o00001Oooool2o`0000Sooooo0_l00003oooo
o`;o00000_ooool2o`00033ooooo2?l0000oooooo`007?ooool00ol0003oooooooooo`0iooooo`;o
00004Oooool7o`000003ooooool0003o000001Ko00000oooool4o`000003ooooool0003o000000?o
000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo
0000o`00000Wooooo`ko00002?ooool2o`0000?ooooo0_l00002ooooo`Co00002?ooool3o`0000Oo
oooo0_l00003ooooo`;o00005Oooool3o`000003ooooool0003o0000047ooooo000Looooo`03o`00
0?oooooooooo03Wooooo0_l0000Aooooob3o00000oooool4o`000003ooooool0003o000000?o0000
1Oooool2o`0000?ooooo1?l000000ooooooo0000o`000002o`0000?ooooo0_l00006ooooo`;o0000
00?oooooo`000?l000001oooool2o`0000_ooooo1_l000000ooooooo0000o`000005o`0000Cooooo
0ol000000ooooooo0000o`000009ooooo`?o00001_ooool6o`0000Kooooo0_l00003ooooo`;o0000
5Oooool2o`0004Gooooo000Looooo`03o`000?oooooooooo03Oooooo0_l0000Cooooo`_o000000?o
ooooo`000?l000002_l000000ooooooo0000o`000006o`0000Oooooo0_l00008ooooo`;o00000_oo
ool3o`0000Gooooo0_l00003ooooo`;o00001_ooool2o`000003ooooool0003o000000Gooooo1?l0
000;ooooo`?o00000_ooool5o`0000;ooooo0_l00003ooooo`Oo00003?ooool2o`0000Cooooo2?l0
000Nooooo`;o00000oooool2o`0000Kooooo1?l0000hooooo`007?ooool00ol0003oooooooooo`0V
ooooo`;o00003oooool2o`0001?ooooo8Ol00007ooooo`;o00002?ooool2o`0000;ooooo0ol0000?
ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Cooooo0ol0000<ooooo`;o00000oooool3
o`000003ooooool0003o000000;ooooo0_l00002ooooo`Go000000?oooooo`000?l000002oooool2
o`0000Cooooo1?l00002ooooo`;o00000oooool2o`0000Cooooo0_l0000Cooooo`?o00000_ooool2
o`0000Kooooo1?l0000hooooo`007?ooool00ol0003oooooooooo`0Vooooo`;o00006Oooool2o`00
00Gooooo0_l00003ooooob3o00005?ooool4o`0000oooooo0_l000000ooooooo0000o`000002oooo
o`;o000000?oooooo`000?l000002Oooool2o`000003ooooool0003o000000;ooooo0_l00004oooo
o`;o000000?oooooo`000?l000000_ooool3o`000003ooooool0003o000000[o00003_ooool4o`00
0003ooooool0003o000000?ooooo0_l00004ooooo`;o00005?ooool2o`0000Wooooo1?l0000ioooo
o`007?ooool00ol0003oooooooooo`11ooooo`;o00001Oooool2o`0000?ooooo5?l000000ooooooo
0000o`00000:o`0000;ooooo0_l0000=ooooo`Co00001Oooool2o`00013ooooo0_l00002ooooo`;o
00002Oooool6o`000003ooooool0003o000000Gooooo1?l00002ooooo`Co00000_ooool5o`000003
ooooool0003o000000;o00003oooool3o`0000cooooo0_l0000Cooooo`;o00001Oooool2o`0000?o
oooo0_l0000kooooo`007?ooool00ol0003oooooooooo`11ooooo`;o00002_oooolRo`000003oooo
ool0003o000000;ooooo0_l00003ooooo`;o00001?ooool4o`0000Gooooo0_l0000@ooooo`;o0000
1?ooool2o`0000Sooooo1Ol000000ooooooo0000o`000005oooooa7o00002?ooool2o`000003oooo
ool0003o000000Oooooo0_l00005ooooo`;o00006_ooool3o`000004ooooool0003o0000ooooo`?o
000000?oooooo`000?l00000?Oooool001cooooo00?o0000ooooooooool0C_ooool5o`000003oooo
ool0003o000001Wo00001Oooool2o`0000?ooooo0_l00002ooooo`Go00006_ooool2o`0000;ooooo
0_l000000ooooooo0000o`000006ooooo`Co00000oooool2o`000003ooooool0003o0000017o0000
0oooool2o`0000?ooooo0_l000001?oooooo0000o`000?l00006ooooo`;o00001Oooool2o`0001[o
oooo0_l000000ooooooo0000o`000004o`0000;ooooo0_l00008ooooo`;o0000<oooool001cooooo
00?o0000ooooooooool0=_ooool4o`0001Kooooo0ol00002ooooo`[o00000_ooool:o`000003oooo
ool0003o000000kooooo1Ol00006ooooo`?o00003oooool2o`000004ooooool0003o0000o`0000Co
oooo0_l00006ooooo`Co00000oooool2o`000003ooooool0003o000001;o00000_ooool2o`0000Ko
oooo1Ol00004ooooo`Co00008_ooool2o`000003ooooool0003o000000gooooo0_l0000cooooo`00
7?ooool2o`0003Oooooo1?l00005ooooo`;o00003ooooolLo`0000Kooooo0_l00008ooooo`Go0000
0_ooool2o`0000;ooooo0ol0000:ooooo`;o00000_ooool3o`000003ooooool0003o000000?o0000
2Oooool4o`0000?ooooo5?l000000ooooooo0000o`000002o`0000cooooo0_l00004ooooo`Co0000
00?oooooo`000?l000000oooool3o`0001cooooo0_l00012ooooo`007?ooool00ol0003ooooooooo
o`0booooo`;o00002oooool2o`0000Gooooo0_l00005ooooo`?o00000_oooolJo`000003ooooool0
003o000000?ooooo0_l00007ooooo`;o00001_ooool2o`0000oooooo1_l00002ooooo`;o000000?o
ooooo`000?l000001_ooool2o`000003ooooool0003o000000Gooooo6Ol0000Booooo`;o00000ooo
ool2o`0000?ooooo0ol0001Pooooo`007?ooool00ol0003oooooooooo`0booooo`;o00000oooool2
o`0000gooooo0_l00005ooooo`?o00000_oooolHo`0000;ooooo0ol00009ooooo`Go00002oooool2
o`0000cooooo0_l00005ooooo`;o000000?oooooo`000?l000001Oooool4o`0000Sooooo5ol0000=
ooooo`;o00000oooool3o`0002Wooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0boooo
o`;o00000_ooool3o`0001Gooooo1?l00002ooooo`Go000000?oooooo`000?l000004ol00009oooo
o`Go00002oooool2o`0001?ooooo1Ol00004ooooo`;o000000?oooooo`000?l000002_oooolFo`00
00Gooooo0_l00005ooooo`;o00001?ooool3o`0002Sooooo0_l0000oooooo`007?ooool00ol0003o
ooooooooo`0fooooo`;o00006?ooool2o`0000;ooooo1Ol000000ooooooo0000o`00000Do`0000;o
oooo0ol00003ooooo`Go00006Oooool2o`0000Kooooo0_l00006ooooo`Go00002?oooolIo`0000Co
oooo0_l00006ooooo`;o000000?oooooo`000?l000000ol0000Wooooo`;o0000@?ooool001cooooo
00?o0000ooooooooool0@_ooool2o`0001;ooooo4Ol00006ooooo`?o00000_ooool9o`0001Sooooo
0_l000001?oooooo0000o`000?l0000?ooooo`?o00001?oooolMo`0000cooooo0_l000000ooooooo
0000o`000004o`0002Kooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`12ooooo`?o0000
3Oooool2o`0000;ooooo3_l00003ooooo`;o00002Oooool6o`0000oooooo0_l00003ooooo`;o0000
00?oooooo`000?l000000_ooool2o`0000;ooooo0_l0000Booooo`;o000000?oooooo`000?l00000
5ol0000Dooooo`;o000000?oooooo`000?l000001?l000000ooooooo0000o`000002ooooo`;o0000
7?ooool4o`0003kooooo000Looooo`03o`000?oooooooooo03Oooooo0_l0000:ooooo`?o00003?oo
ool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool2o`0000Cooooo0_l0
0009ooooo`Go00004?ooool2o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`;o00001_oo
ool2o`0000Kooooo1_l000000ooooooo0000o`00000Io`0000;ooooo0ol0000=ooooo`;o00000_oo
ool5o`000004ooooool0003o0000ooooo`?o00004?ooool3o`0000Cooooo0_l00003ooooo`Co0000
?_ooool001cooooo00?o0000ooooooooool0=oooool2o`0000Gooooo0_l00004ooooo`?o00001ooo
ool2o`0000Kooooo0_l000000ooooooo0000o`000006ooooo`;o00003_ooool7o`0001cooooo0_l0
0008ooooo`?o00001_oooolGo`000003ooooool0003o000000So000000?oooooo`000?l000000_l0
000Aooooo`?o000000?oooooo`000?l000000oooool2o`00017ooooo0ol00003ooooo`?o0000AOoo
ool001cooooo00?o0000ooooooooool0=Oooool2o`0000Oooooo0_l00004ooooo`?o00001oooool2
o`0001kooooo1Ol00003ooooo`;o00007?ooool2o`0000Oooooo1?l00004ooooo`Co00000_oooolK
o`0000Cooooo0ol00003ooooo`?o00003Oooool5o`0000?ooooo0_l0000Gooooo`;o0000A_ooool0
01cooooo00?o0000ooooooooool0=Oooool2o`0001?ooooo0_l000000ooooooo0000o`00000Koooo
o`So00008_ooool2o`0000Gooooo1Ol00005ooooo`?o00001?oooolMo`000003ooooool0003o0000
00;o00000_ooool3o`0000Cooooo0_l00008ooooo`Co00008Oooool2o`00047ooooo000Looooo`03
o`000?oooooooooo037ooooo0_l0000Gooooo`;o000000?oooooo`000?l000000_ooool2o`0000;o
oooo0_l0000Aooooo`So00003oooool2o`0000oooooo0_l00009ooooo`;o00002?ooool3o`000004
ooooool0003o0000ooooob;o00001_ooool2o`000003ooooool0003o000002gooooo0_l00011oooo
o`007?ooool00ol0003oooooooooo`0aooooo`;o00007_ooool2o`000004ooooool0003o0000o`00
00cooooo0_l000000ooooooo0000o`000002o`0001Gooooo0ol00003ooooo`;o00001Oooool2o`00
00;ooooo0_l00009ooooo`Go00001?ooool4o`000004ooooool0003o0000oooooako000000?ooooo
o`000?l000000_l00005ooooo`;o00004_ooool2o`0001[ooooo0_l00013ooooo`007?ooool00ol0
003oooooooooo`19ooooo`;o00002Oooool2o`0000Gooooo0_l00006ooooo`;o000000?oooooo`00
0?l000005oooool3o`0000?ooooo0_l00005ooooo`;o00003Oooool5o`0000Cooooo1?l00003oooo
oaoo000000?oooooo`000?l000001_l000000ooooooo0000o`00000>ooooo`;o00000_ooool2o`00
01[ooooo0_l00009ooooo`;o0000>?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2
ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo03Oooooo0_l0
000@ooooo`;o00001_ooool2o`0000Sooooo0_l00005ooooo`;o00006oooool2o`0000Cooooo0_l0
0005ooooo`;o00003?ooool2o`0000oooooo6_l000000ooooooo0000o`000003o`0000?ooooo1ol0
000?ooooo`;o00000_ooool2o`0000oooooo0_l00004ooooo`;o00003_ooool2o`0003Sooooo0000
1_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B401_ooool00ol0003oooooooooo`0gooooo`;o00006?ooool4o`0000gooooo0_l00004ooooo`;o
00002?ooool2o`0001Sooooo0_l0000<ooooo`?o00003oooool2o`000003ooooool0003o000001[o
000000Coooooo`000?l0003o00001?ooool2o`0001?ooooo0_l0000?ooooo`;o00000oooool3o`00
0003ooooool0003o000000?ooooo0_l00010ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413o
ooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`1Coooo
o`;o00001?ooool4o`0000_ooooo0_l00004ooooo`;o00000_ooool2o`0000Sooooo0_l0000Moooo
o`;o00003OoooolOo`0000;ooooo1?l00004ooooo`;o00002?ooool2o`0001oooooo0_l00002oooo
o`;o00000oooool2o`00043ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wo
oooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000;?ooool2o`0001Oooooo0_l00006oooo
o`;o00002_ooool6o`0000oooooo0_l0000<ooooo`;o000000?oooooo`000?l000001Oooool4o`00
00_ooooo0_l0000:ooooo`;o00001ooooolPo`000004ooooool0003o0000o`0000oooooo0_l0000<
ooooo`;o00005Oooool2o`0000Sooooo0_l0000kooooo`0000?oooooo`000?ooool00_ooool00ol0
003oooooooooo`09ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0/
ooooo`;o00003_ooool3o`0000Kooooo0ol00005ooooo`;o00001_ooool2o`0000Kooooo0_l0000P
ooooo`;o00001Oooool4o`0000_ooooo0_l0000:ooooo`;o00001ooooolUo`0001Cooooo0_l00006
ooooo`;o00004?ooool2o`0000gooooo0_l0000kooooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0??ooool3o`00
00Oooooo0_l0000=ooooo`;o0000:?ooool2o`0000Oooooo0_l00002ooooo`;o00001oooool2o`00
00Kooooo0_l00004ooooo`;o00001OoooolOo`000004ooooool0003o0000ooooo`;o00003Oooool2
o`0000Gooooo0_l00006ooooo`;o00001oooool2o`0000Oooooo0_l000000ooooooo0000o`000017
ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o
0000ooooooooool0L_ooool7o`0000oooooo0_l00002ooooo`;o00001oooool2o`0000Kooooo1?l0
0002ooooo`;o00000ooooolRo`0000;ooooo1?l000000ooooooo0000o`000009ooooo`;o00003Ooo
ool2o`0000Oooooo1?l00008ooooo`;o0000Aoooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^
3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo04Sooooo0_l00002ooooo`;o
00009?ooool7o`0001?ooooo0_l0000<ooooo`;o00000oooool2o`0000Oooooo8_l00002ooooo`Oo
00005oooool2o`0000Kooooo0_l00002ooooo`;o00003Oooool2o`0004;ooooo000Looooo`03o`00
0?oooooooooo02gooooo0_l0000Iooooo`;o00000_ooool2o`0001cooooo0_l0000Pooooo`;o0000
00Coooooo`000?l0003o00002?ooool2o`0000kooooo5?l000000ooooooo0000o`00000:o`000003
ooooool0003o000000Co00006?ooool2o`0000Kooooo0_l00007ooooo`;o00002?ooool2o`0004;o
oooo000Looooo`03o`000?oooooooooo02gooooo0_l0000kooooo`;o00008oooool3o`0001[ooooo
4_l000000ooooooo0000o`00000?o`000004ooooool0003o0000o`00017ooooo0_l0000Dooooo`;o
00002oooool2o`0003oooooo000Looooo`03o`000?oooooooooo043ooooo0_l0000_ooooo`;o0000
2?ooool5o`0000Gooooo0_l0000Aooooo`;o00004_oooolAo`0000;ooooo2_l000001?oooooo0000
o`000?l00003ooooo`Co000000?oooooo`000?l000003_ooool2o`00027ooooo0_l0000oooooo`00
7?ooool00ol0003oooooooooo`10ooooo`;o00001Oooool2o`00027ooooo0_l000000ooooooo0000
o`000002ooooo`;o00002?ooool5o`0000Gooooo0ol0000@ooooo`;o00003Oooool2o`0000;ooooo
6?l000000ooooooo0000o`000005o`0000Gooooo0_l00003ooooo`;o00002Oooool2o`0000?ooooo
0_l00002ooooo`;o0000G_ooool001cooooo00?o0000ooooooooool0Aoooool2o`0000Oooooo0_l0
000Hooooo`;o000000?oooooo`000?l000005oooool4o`0001Wooooo1_l00002ooooo`;o000000?o
ooooo`000?l000005_l000000ooooooo0000o`000002o`000003ooooool0003o000000?o000000?o
ooooo`000?l000003?ooool2o`0000Cooooo1Ol00004ooooo`;o00002?ooool2o`0000Cooooo0_l0
0018ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00003Oooool3o`0002Gooooo0_l00000
0ooooooo0000o`000002ooooo`?o00001oooool2o`0000Oooooo0_l0000>ooooo`Ko00001ooooolA
o`000003ooooool0003o000000oo000000?oooooo`000?l000004?ooool5o`0000Kooooo0_l00008
ooooo`;o00001?ooool2o`0000Cooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`10oooo
o`;o00003Oooool2o`0002Kooooo1Ol00002ooooo`Ko000000?oooooo`000?l000000oooool2o`00
00Gooooo0_l0000:ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o00000_oooolU
o`0000;ooooo0_l0000@ooooo`;o00006_ooool2o`0000?ooooo0_l00012ooooo`007?ooool00ol0
003oooooooooo`1eooooo`;o00000_ooool;o`000003ooooool0003o000000?ooooo0_l00007oooo
o`;o00001?ooool2o`0000;ooooo1_l000001?oooooo0000o`000?ooool2o`0000;ooooo5Ol00000
1?oooooo0000o`000?l00002ooooo`Co000000?oooooo`000?l000000ol00002ooooo`;o00002Ooo
ool2o`00013ooooo0_l0000?ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0K_ooool2
o`0000Gooooo3_l00002ooooo`;o00000oooool2o`000003ooooool0003o000000Cooooo0_l00004
ooooo`;o00001?ooool4o`0000Sooooo1Ol00003ooooo`Wo00000_oooolAo`0000kooooo0_l0000@
ooooo`;o000000?oooooo`000?l00000EOooool001cooooo00?o0000ooooooooool0;oooool2o`00
00oooooo0_l0000Aooooo`;o00005Oooool2o`0000;ooooo0_l00005oooooa;o00000_ooool3o`00
0003ooooool0003o000000Cooooo0_l00006ooooo`Co00003Oooool6o`000003ooooool0003o0000
00ko000000?oooooo`000?l000002Ol0000Sooooo`;o00003_ooool2o`0004Gooooo000Looooo`03
o`000?oooooooooo02oooooo0_l00005ooooo`;o00000_ooool2o`0000Cooooo0_l0000Aooooo`;o
00005Oooool2o`0000Gooooo0_l000000ooooooo0000o`00000@o`0000?ooooo0_l000001?oooooo
0000o`000?l00002ooooo`Co00001_ooool4o`000003ooooool0003o000000?ooooo0_l00002oooo
o`;o00001Oooool2o`000003ooooool0003o000000go000000?oooooo`000?l000001?l000000ooo
oooo0000o`000003o`0000oooooo0_l0000Rooooo`;o0000AOooool001cooooo0_l0000gooooo`;o
00000_ooool2o`0000Oooooo0_l0000[oooooaKo00000oooool5o`0000?ooooo0_l00007ooooo`;o
00001?ooool2o`000003ooooool0003o000000;o00000_ooool2o`0000Gooooo1Ol000000ooooooo
0000o`00000Ao`000004ooooool0003o0000ooooo`Go00003?ooool2o`0006Wooooo000Looooo`03
o`000?oooooooooo043ooooo0_l000000ooooooo0000o`000003o`0000Oooooo0_l0000OoooooaSo
000000?oooooo`000?l000000ol00003ooooo`?o00001_ooool2o`0000Cooooo0_l000000ooooooo
0000o`000003ooooo`_o00000ooooolEo`0000?ooooo1?l0000Iooooo`;o00003oooool3o`0004[o
oooo000Looooo`03o`000?oooooooooo043ooooo0_l00003ooooo`?o00001oooool2o`0000?ooooo
0ol00002ooooo`;o00005OoooolEo`000004ooooool0003o0000ooooo`;o00001oooool2o`00013o
oooo0_l00002ooooo`ko000000?oooooo`000?l000004_l00003ooooo`?o00006_ooool2o`0000;o
oooo0_l0000;ooooo`?o0000B_ooool001cooooo00?o0000ooooooooool0@_ooool3o`0000oooooo
0ol00002ooooo`;o00004_oooolNo`0000?ooooo0_l0000Booooo`Co000000?oooooo`000?l00000
0_ooool2o`000003ooooool0003o000000Ko00000_ooool4o`000003ooooool0003o000000;o0000
00?oooooo`000?l000000_l000001?oooooo0000o`000?l00004ooooo`;o00001?ooool2o`0001Go
oooo0_l00002ooooo`;o0000F?ooool001cooooo00?o0000ooooooooool0@_ooool3o`000003oooo
ool0003o000002Cooooo7_l00004ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Sooooo
0ol00002ooooo`;o00001Oooool4o`000004ooooool0003o0000o`0000?ooooo0ol000000ooooooo
0000o`000005ooooo`;o00000_ooool3o`000003ooooool0003o000000;o00001?ooool2o`0000Ko
oooo0_l0000=ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Oooooo0_l0001:ooooo`00
7?ooool00ol0003oooooooooo`16ooooo`;o00009?ooool2o`000003ooooool0003o000001Wo0000
0_ooool3o`0000;ooooo0_l00005ooooo`;o00002_ooool2o`0000Cooooo0_l00004ooooo`?o0000
1?ooool3o`0000?ooooo0ol00004ooooo`?o00000_ooool7o`0000cooooo0_l0000:ooooo`;o0000
1?ooool2o`0000Cooooo0_l00007ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0B?oo
ool2o`0002?ooooo6ol00002ooooo`Wo00000_ooool2o`0000Gooooo0_l00006ooooo`;o00001?oo
ool3o`0000Cooooo1?l00002ooooo`?o00001?ooool2o`0000Cooooo1?l000000ooooooo0000o`00
0005o`0000Wooooo1?l00002ooooo`;o000000?oooooo`000?l000000oooool3o`0005oooooo000L
ooooo`03o`000?oooooooooo03gooooo0_l00009ooooo`;o00001?ooool2o`0001Wooooo0_l00002
oooooaWo00000oooool5o`000004ooooool0003o0000o`0000?ooooo0_l000000ooooooo0000o`00
0002ooooo`;o00000_ooool2o`0000Wooooo0_l00002ooooo`Ko00000_ooool2o`0000_ooooo1?l0
00000ooooooo0000o`000003o`0000Sooooo1ol00002ooooo`Go00000_ooool3o`00063ooooo000L
ooooo`03o`000?oooooooooo03[ooooo0_l000000ooooooo0000o`00000?ooooo`;o00006Oooool2
o`0000?ooooo3ol000000ooooooo0000o`000005o`0000Cooooo1Ol00002ooooo`;o00001_ooool2
o`0000Gooooo0ol00004ooooo`;o00000oooool3o`000003ooooool0003o000000?o00002?ooool2
o`0000Cooooo0_l00003ooooo`Oo00002?ooool4o`0000Oooooo0_l00003ooooo`;o000000?ooooo
o`000?l000003Oooool2o`0000Sooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`0joooo
o`;o00007?ooool2o`00013ooooo0_l00003oooooaKo00000oooool2o`000004ooooool0003o0000
o`0000;ooooo0_l00009ooooo`;o00000_ooool2o`0000Gooooo1?l000001?oooooo0000o`000?l0
0007ooooo`Co00000oooool3o`0000?ooooo0_l000000ooooooo0000o`000006o`0000Sooooo1Ol0
000?ooooo`;o00003Oooool2o`0000Sooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`0m
ooooo`;o00006Oooool4o`0000kooooo0_l00004oooooa;o00001_ooool2o`0000Kooooo0_l00009
ooooo`;o00002oooool2o`0000Gooooo0_l00004ooooo`Co00001?ooool2o`0000Gooooo1Ol00000
1?oooooo0000o`000?l00008ooooo`?o00007Oooool2o`000003ooooool0003o000004oooooo000L
ooooo`03o`000?oooooooooo03gooooo0_l0000Kooooo`;o00000_ooool2o`00013ooooo4Ol00003
ooooo`;o0000:Oooool2o`0000;ooooo0_l0000?ooooo`;o000000?oooooo`000?l000000oooool3
o`0000Oooooo0_l0000Kooooo`Co00001Oooool2o`0004_ooooo000Looooo`03o`000?oooooooooo
03gooooo0_l0000?ooooo`;o00003_ooool2o`00013ooooo4?l00004ooooo`;o000000?oooooo`00
0?l000001_ooool2o`000004ooooool0003o0000o`0000Gooooo1?l0000Booooo`Oo00000_ooool2
o`000003ooooool0003o000000[ooooo0_l00002ooooo`?o00002oooool4o`0001Gooooo0_l00007
ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0?oooool2o`0000cooooo0ol0000Poooo
o`;o000000?oooooo`000?l000003Ol00005ooooo`;o00001_ooool2o`000004ooooool0003o0000
o`0000Gooooo1?l0000<ooooo`;o00001?ooool7o`0000;ooooo0_l000000ooooooo0000o`00000:
ooooo`;o000000?oooooo`000?l000001oooool2o`0000Cooooo1?l00002ooooo`?o00001Oooool2
o`0000Wooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`0looooo`;o000000?oooooo`00
0?l000003?ooool2o`0001kooooo0_l000001?oooooo0000o`000?ooool?o`0000cooooo0ol00007
ooooo`Co00003_ooool2o`0000Cooooo0_l000000ooooooo0000o`00000<ooooo`?o00001oooool2
o`0000Oooooo0_l00003ooooo`Go00000_ooool4o`0000Cooooo0_l0000Aooooo`;o0000C?ooool0
01cooooo00?o0000ooooooooool0??ooool4o`0000Cooooo0_l00004ooooo`;o00007_ooool5o`00
0004ooooool0003o0000ooooo`Oo000000?oooooo`000?l000004Oooool5o`0000Gooooo1?l00003
ooooo`;o00005?ooool2o`0000[ooooo0ol00006ooooo`;o00002?ooool4o`000003ooooool0003o
000000?o00001?ooool2o`0000;ooooo0_l00007ooooo`;o00002_ooool2o`0004cooooo000Loooo
o`;o0000?oooool2o`0000Cooooo0_l00004ooooo`;o00007_ooool5o`0000?ooooo1ol00007oooo
o`;o00003?ooool5o`0000[ooooo1Ol0000Cooooo`;o00003oooool2o`0000;ooooo0_l00006oooo
o`Ko00001?ooool2o`0000Sooooo0_l00005ooooo`Co0000F?ooool001cooooo00?o0000oooooooo
ool0H?ooool2o`0000Sooooo0_l00006ooooo`Oo00000_ooool7o`0000cooooo1Ol00002ooooo`Oo
000000Coooooo`000?l0003ooooo0ol000000ooooooo0000o`00000?ooooo`;o00001_ooool5o`00
00;ooooo1?l00004ooooo`Go000000?oooooo`000?l000003_ooool2o`0000Cooooo0_l00003oooo
o`;o00001Oooool2o`0000;ooooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o
00001oooool2o`0000_ooooo0_l00003ooooo`Go00001_ooool2o`0000?ooooo0_l000001?oooooo
0000o`000?ooool2o`0000;ooooo1ol000000ooooooo0000o`000004o`000003ooooool0003o0000
00;ooooo0_l0000;ooooo`;o00001_ooool5o`0000;ooooo1?l00004ooooo`Oo00001?ooool2o`00
00Wooooo0_l00004ooooo`;o00000oooool2o`0000Gooooo0_l00002ooooo`;o0000Coooool001co
oooo00?o0000ooooooooool0AOooool2o`0002;ooooo0_l0000;ooooo`;o00003?ooool4o`0000?o
oooo0_l0000<ooooo`;o00000oooool3o`0000Oooooo0_l0000<ooooo`;o00002Oooool2o`000003
ooooool0003o000000;o00001oooool5o`0000?ooooo0_l000000ooooooo0000o`00000<ooooo`;o
0000Goooool001cooooo00?o0000ooooooooool0@?ooool2o`0000?ooooo0_l000000ooooooo0000
o`00000Pooooo`;o00001oooool2o`0000oooooo0_l0000Cooooo`;o00000oooool4o`0000Oooooo
1?l00009ooooo`?o00000oooool2o`0000?ooooo0_l000000ooooooo0000o`000007ooooo`;o0000
0oooool2o`0000Kooooo0_l0000:ooooo`Co0000Goooool001cooooo00?o0000ooooooooool0@?oo
ool2o`0000Kooooo0_l0000Pooooo`;o00001oooool2o`00027ooooo0_l00008ooooo`?o00001_oo
ool4o`0000[ooooo0_l00003ooooo`;o00000_ooool2o`0000_ooooo0_l0000@ooooo`?o000000Co
ooooo`000?l0003ooooo0_l000000ooooooo0000o`00001Nooooo`007?ooool00ol0003ooooooooo
o`10ooooo`;o00000oooool2o`0000Sooooo0_l0000Oooooo`;o00003Oooool2o`0000Sooooo0_l0
0002ooooo`;o00001oooool2o`0000Wooooo0_l0000Mooooo`;o00003Oooool2o`0000kooooo1_l0
0004ooooo`;o0000G_ooool001cooooo00?o0000ooooooooool0@?ooool2o`0000?ooooo0_l00008
ooooo`;o00007?ooool2o`000003ooooool0003o000000gooooo0_l00008ooooo`;o000000Cooooo
o`000?l0003o00005Oooool6o`00017ooooo0_l00007ooooo`;o00002Oooool2o`0000Sooooo0_l0
0006ooooo`Co0000I?ooool001cooooo00?o0000ooooooooool0B?ooool2o`0000Gooooo0_l0000L
ooooo`;o00006_ooool5o`0001Kooooo1_l00004ooooo`;o00001Oooool2o`0000Cooooo0_l00006
ooooo`?o00002oooool2o`000003ooooool0003o000000?ooooo0_l00008ooooo`;o000000?ooooo
o`000?l00000HOooool001cooooo00?o0000ooooooooool0??ooool2o`0000[ooooo0_l0000Yoooo
o`;o00005Oooool4o`0001Kooooo0_l00002ooooo`;o00001?ooool2o`000003ooooool0003o0000
00;ooooo0_l000000ooooooo0000o`000009ooooo`?o00001?ooool2o`0000Cooooo0ol000000ooo
oooo0000o`000006ooooo`Co000000?oooooo`000?l000000oooool2o`00067ooooo000Looooo`03
o`000?oooooooooo03cooooo0_l00006ooooo`;o0000:?ooool2o`0000?ooooo0_l0000:ooooo`;o
00002_ooool2o`0000?ooooo0_l0000Gooooo`?o00001?ooool3o`000003ooooool0003o000000;o
oooo0_l00002ooooo`;o00001?ooool4o`0000?ooooo0ol00002ooooo`Ko00001Oooool7o`000003
ooooool0003o000006Kooooo000Looooo`03o`000?oooooooooo04Cooooo0_l0000Wooooo`?o0000
2oooool2o`000004ooooool0003o0000o`0000Gooooo0_l00002ooooo`?o00000oooool2o`0000co
oooo0_l00006ooooo`;o000000?oooooo`000?l000000ol000001?oooooo0000o`000?l00002oooo
o`;o00000_ooool2o`0000;ooooo0_l00004ooooo`Co00000oooool2o`0000?ooooo1_l00004oooo
o`Ko0000Joooool001cooooo00?o0000ooooooooool0KOooool2o`0000cooooo0_l000001?oooooo
0000o`000?ooool2o`0000?ooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo1?l00002
ooooo`;o00001_ooool2o`0000Kooooo0_l00003ooooo`?o000000?oooooo`000?l000000oooool2
o`0000;ooooo0_l00008ooooo`?o00001?ooool2o`000003ooooool0003o000000Sooooo1?l0001_
ooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00008oooool2o`00017ooooo0_l00003oooo
o`;o00001?ooool4o`0000;ooooo0_l00002ooooo`;o00001Oooool2o`0002?ooooo0_l00008oooo
o`;o00002?ooool3o`00073ooooo000Looooo`03o`000?oooooooooo04Wooooo0_l00006ooooo`;o
00006oooool2o`0000gooooo0_l000001?oooooo0000o`000?l00003ooooo`;o00001?ooool4o`00
00gooooo0_l00002ooooo`;o0000Y_ooool001cooooo00?o0000ooooooooool0DOooool2o`0001ko
oooo0_l0000:ooooo`Go00001?ooool3o`0000Cooooo0_l0000Booooo`;o00001?ooool2o`000:3o
oooo000Looooo`;o0000BOooool2o`0000Oooooo0_l0000Nooooo`Co00002_ooool2o`0000?ooooo
0_l000001Ooooooo0000o`000?l0003ooooo00Co00000oooool2o`0000Wooooo0_l00004ooooo`;o
000000Goooooo`000?l0003o0000ooooo`02o`0009gooooo000Looooo`03o`000?oooooooooo04So
oooo0_l0000Yooooo`;o00003oooool2o`0000;ooooo1Ol00005ooooo`;o00001Oooool2o`0000;o
oooo0ol00003ooooo`Go00000_ooool2o`0000Cooooo0_l0002Gooooo`007?ooool00ol0003ooooo
ooooo`27ooooo`Go00003Oooool2o`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l00000
1oooool2o`0009Oooooo000Looooo`03o`000?oooooooooo07Kooooo0_l00004ooooo`;o00002Ooo
ool2o`000003ooooool0003o000000Co00003_ooool2o`000003ooooool0003o000000Cooooo0ol0
000:ooooo`;o00000oooool2o`0000Cooooo0_l000000ooooooo0000o`000025ooooo`007?ooool0
0ol0003oooooooooo`1fooooo`;o00001?ooool3o`0000Wooooo2?l00004ooooo`;o00002?ooool2
o`000003ooooool0003o000000Gooooo0_l0000:ooooo`?o00000_ooool2o`0000Cooooo0_l00000
0ooooooo0000o`000009ooooo`;o00000_ooool2o`0007Kooooo000Looooo`03o`000?oooooooooo
04gooooo0_l0000[ooooo`Go00002Oooool4o`000003ooooool0003o000000;o00000oooool2o`00
00Cooooo0_l00003ooooo`Co00004_ooool2o`0001;ooooo0_l00002ooooo`;o00000_ooool4o`00
07Cooooo000Looooo`03o`000?oooooooooo04gooooo0_l0000[ooooo`?o00004Oooool4o`000003
ooooool0003o000000Gooooo0_l00003ooooo`Co00008Oooool2o`0000?ooooo0_l00006ooooo`Co
000000?oooooo`000?l00000LOooool001cooooo00?o0000ooooooooool0G?ooool2o`0001gooooo
0_l000001?oooooo0000o`000?ooool2o`0000Sooooo0_l00002ooooo`?o000000?oooooo`000?l0
00002oooool3o`0001Wooooo1Ol00002ooooo`?o000000?oooooo`000?l000002?ooool2o`0000?o
oooo1?l00003ooooo`;o0000J_ooool001cooooo00?o0000ooooooooool0G?ooool2o`00023ooooo
0_l000000ooooooo0000o`000008ooooo`;o00000oooool5o`0000Kooooo0_l00004ooooo`;o0000
6Oooool5o`0000;ooooo0_l000001?oooooo0000o`000?l00005ooooo`;o00002?ooool2o`0000?o
oooo0_l0001Zooooo`007?ooool00ol0003oooooooooo`2@ooooo`Ko00001Oooool2o`0002Wooooo
0_l00006ooooo`;o00001_ooool2o`00077ooooo000Looooo`03o`000?oooooooooo057ooooo0_l0
000mooooo`;o000000?oooooo`000?l000000ol0000Mooooo`;o00007oooool4o`0006oooooo000L
ooooo`03o`000?oooooooooo057ooooo0_l0000mooooo`?o00000oooool2o`0001_ooooo1?l00007
ooooo`;o00000_ooool2o`0000Cooooo0_l00002ooooo`;o00001_ooool2o`0000;ooooo0_l0001_
ooooo`007?ooool00ol0003oooooooooo`24ooooo`;o00000oooool2o`0000Gooooo0ol0000Poooo
o`;o00002Oooool2o`0000;ooooo0_l00004ooooo`;o00000_ooool4o`0000Cooooo0_l0001coooo
o`007?ooool00ol0003oooooooooo`24ooooo`;o00000oooool4o`0000Cooooo0ol00009ooooo`;o
00004_ooool2o`0000kooooo0_l00007ooooo`Ko0000NOooool00006ooooooo^k^ko<S8bo`000?lb
<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooo
oooo08Oooooo0_l000001?oooooo0000o`000?l00004ooooo`?o00001?ooool7o`0001;ooooo0_l0
000:ooooo`?o000000?oooooo`000?l000001oooool4o`0007_ooooo00001_ooooooMgMgoiRHV?oo
ooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003o
ooooooooo`27ooooo`;o000000Coooooo`000?l0003o00001?ooool5o`0000;ooooo1Ol0000:oooo
o`;o00003oooool2o`0000?ooooo0ol0000:ooooo`;o0000OOooool00003ooooool@413ooooo00;o
oooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool0JOooool2o`0002Sooooo0ol000000ooooooo0000o`000002o`0000cooooo1?l0000=oooo
o`;o00003oooool3o`0007gooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wo
oooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000JOooool2o`0001kooooo0_l00004oooo
o`;o00000_ooool6o`0000Oooooo0_l00007ooooo`;o00001?ooool2o`0000Oooooo0_l0000?oooo
o`;o0000O_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Oo<c<co
0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0F?ooool2o`0002oooooo1?l00002oooo
o`;o00000oooool5o`0000Oooooo0_l0000=ooooo`;o00001?ooool2o`0000Gooooo0_l0000;oooo
o`;o0000O_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol@413o
^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0F?ooool3o`0001;ooooo0_l0000Loooo
o`;o00000_ooool2o`0000?ooooo0ol0000Nooooo`;o00001Oooool2o`0008_ooooo00001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oo
oooooooo05Wooooo0_l0000Booooo`;o00007oooool2o`0000Gooooo0_l0000cooooo`;o0000OOoo
ool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Ko
oooo00?o0000ooooooooool0G_ooool2o`00013ooooo0_l0000Looooo`;o00002Oooool2o`0000?o
oooo0_l00003ooooo`;o00007_ooool2o`0000Gooooo0_l0001mooooo`007?ooool00ol0003ooooo
ooooo`1Nooooo`;o00004?ooool2o`0001gooooo0_l00008ooooo`;o00000oooool2o`0000?ooooo
0_l0000Gooooo`;o00001Oooool2o`0008Cooooo000Looooo`03o`000?oooooooooo08oooooo0_l0
000>ooooo`;o00006_ooool3o`0008_ooooo000Looooo`03o`000?oooooooooo09oooooo1Ol0000:
ooooo`;o00000oooool2o`000003ooooool0003o000000?ooooo0_l0002<ooooo`007?ooool00ol0
003oooooooooo`2Qooooo`?o00002_ooool2o`000003ooooool0003o000000;o000000Coooooo`00
0?l0003o0000T?ooool001cooooo00?o0000ooooooooool0N?ooool2o`0001kooooo0_l00009oooo
o`;o00003?ooool2o`0000Cooooo0_l0002@ooooo`007?ooool00ol0003oooooooooo`1hooooo`?o
00007Oooool2o`0000?ooooo0_l00004ooooo`;o0000Y?ooool001cooooo00?o0000ooooooooool0
Hoooool2o`0001Cooooo0_l0000Mooooo`;o00000oooool2o`0000Cooooo0_l0002Tooooo`007?oo
ool00ol0003oooooooooo`1Sooooo`;o00006_ooool3o`00027ooooo0_l0002Tooooo`007?ooool0
0ol0003oooooooooo`1oooooo`Ko0000a?ooool001cooooo00?o0000ooooooooool0P_ooool3o`00
0<Cooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0Moooool2o`000=3ooooo000Looooo`03o`000?oooooooooo07Oooooo0_l0003@ooooo`00
7?ooool00ol0003oooooooooo`1jooooo`;o0000cOooool001cooooo00?o0000ooooooooool0N_oo
ool2o`000<gooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0Poooool2o`0003Oooooo0_l00002ooooo`;o0000Qoooool001cooooo00?o0000oooooooo
ool0Poooool4o`0003Gooooo0_l00002ooooo`;o0000Qoooool001cooooo00?o0000ooooooooool0
QOooool2o`0000Cooooo0_l0002looooo`007?ooool2o`0008cooooo0_l0002looooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo09;ooooo0_l0000Qoooo
o`;o0000T_ooool001cooooo00?o0000ooooooooool0T_ooool4o`0001oooooo0_l0002Booooo`00
7?ooool00ol0003oooooooooo`2Dooooo`;o00006_ooool2o`0009Oooooo000Looooo`03o`000?oo
oooooooo09cooooo0_l0000Booooo`;o0000Uoooool001cooooo00?o0000ooooooooool0W?ooool2
o`0000Cooooo0_l00002ooooo`;o00000oooool2o`0009cooooo000Looooo`03o`000?oooooooooo
0:;ooooo0_l00002ooooo`;o00000oooool2o`0009cooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2
o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooo
oom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool0
01Cooooo00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o0000oooooooo
ool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oo
oooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`004_ooool00omE
EEGoIVIVo`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002U
ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05_ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o000000?o410@oooooooo
ool0S_ooool00:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00003Oooool02OmgMgOo
<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo08oooooo002V
ooooo`05o`000?ooooooooooooooool000007Oooool01?l0003oooooooooool@4103ooooo`04oa0@
4?ooooooooooooooo`Go0000T?ooool00:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko
00003Oooool01OmgMgOo<S8boooooooooooo000000?ooooo00So0000ooooooooooooooooodA4A?oM
gMgoooooo`00097ooooo002Vooooo`05o`000?n7QhOoooooojVYZOl000006Oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`000003ooooo`04omgMgOmEEEGooooo
o`00097ooooo002Uooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool05oooool00ol0
003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41001?ooool00omgMgOoc<c<o`00002A
ooooo`00a?ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool0
0oo^k^koA4A4o`00002Aooooo`00a?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`03ogMgMol0003ooooo093ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(510) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.69778 .41178 Mdot
.68147 .43192 Mdot
.30021 .53504 Mdot
.589 .62092 Mdot
.32925 .63293 Mdot
.31016 .50054 Mdot
.40398 .30453 Mdot
.3838 .30748 Mdot
.31177 .51279 Mdot
.69541 .57233 Mdot
.40939 .33673 Mdot
.60041 .54024 Mdot
.40348 .31979 Mdot
.56094 .59859 Mdot
.55028 .41673 Mdot
.59022 .69555 Mdot
.62909 .41268 Mdot
.4007 .63229 Mdot
.58617 .69939 Mdot
.31608 .53044 Mdot
.52768 .71611 Mdot
.57133 .58965 Mdot
.63292 .43556 Mdot
.563 .59561 Mdot
.5476 .64003 Mdot
.67547 .42336 Mdot
.69743 .41902 Mdot
.54191 .65024 Mdot
.57879 .65265 Mdot
.39866 .33251 Mdot
.20893 .53002 Mdot
.84536 .4604 Mdot
.51545 .6141 Mdot
.79665 .51572 Mdot
.38301 .30557 Mdot
.34529 .27909 Mdot
.28167 .51895 Mdot
.39749 .29017 Mdot
.37838 .3205 Mdot
.37783 .31076 Mdot
.40649 .2979 Mdot
.67508 .41455 Mdot
.37489 .33241 Mdot
.25245 .4381 Mdot
.54535 .61182 Mdot
.68635 .34457 Mdot
.18185 .43461 Mdot
.55667 .65664 Mdot
.67405 .39216 Mdot
.33165 .52302 Mdot
.4294 .78951 Mdot
.43517 .3076 Mdot
.50986 .36384 Mdot
.42105 .89321 Mdot
.40833 .33032 Mdot
.59012 .62992 Mdot
.32714 .50598 Mdot
.58824 .60269 Mdot
.60611 .5945 Mdot
.78962 .48174 Mdot
.58044 .57619 Mdot
.36195 .63523 Mdot
.66767 .46278 Mdot
.25686 .47921 Mdot
.31542 .50779 Mdot
.40926 .29295 Mdot
.65754 .45691 Mdot
.39364 .31255 Mdot
.57808 .66087 Mdot
.32328 .53267 Mdot
.57349 .65255 Mdot
.4017 .33634 Mdot
.66415 .45193 Mdot
.54199 .61392 Mdot
.61438 .33246 Mdot
.45861 .31413 Mdot
.35874 .51991 Mdot
.78145 .62519 Mdot
.46373 .82986 Mdot
.30766 .5688 Mdot
.54538 .59743 Mdot
.35559 .81682 Mdot
.49449 .4121 Mdot
.68516 .43248 Mdot
.60847 .42415 Mdot
.63505 .23352 Mdot
.55032 .65804 Mdot
.38423 .54209 Mdot
.52991 .57959 Mdot
.46236 .54852 Mdot
.30859 .51921 Mdot
.66764 .44158 Mdot
.54174 .60909 Mdot
.5279 .59619 Mdot
.67306 .49852 Mdot
.60221 .63152 Mdot
.57265 .62374 Mdot
.61587 .46333 Mdot
.42212 .33448 Mdot
.60312 .52254 Mdot
.31085 .69188 Mdot
.51879 .38225 Mdot
.57672 .63501 Mdot
.2831 .49968 Mdot
.67454 .46308 Mdot
.56337 .62365 Mdot
.38943 .30743 Mdot
.55527 .59128 Mdot
.42956 .35515 Mdot
.63233 .415 Mdot
.52819 .58889 Mdot
.37795 .66186 Mdot
.52684 .49807 Mdot
.64528 .40986 Mdot
.71224 .68954 Mdot
.57608 .57793 Mdot
.58853 .58252 Mdot
.68617 .4244 Mdot
.29199 .53007 Mdot
.37845 .48056 Mdot
.64085 .44551 Mdot
.37686 .31714 Mdot
.6526 .3935 Mdot
.58366 .54606 Mdot
.29685 .53083 Mdot
.51841 .36828 Mdot
.51459 .37648 Mdot
.39713 .70902 Mdot
.53758 .61076 Mdot
.56195 .49568 Mdot
.2939 .49671 Mdot
.68117 .41636 Mdot
.39495 .32044 Mdot
.61289 .59123 Mdot
.65584 .40922 Mdot
.38078 .33177 Mdot
.36095 .62453 Mdot
.32987 .62653 Mdot
.6722 .39815 Mdot
.64432 .70776 Mdot
.4425 .32423 Mdot
.37682 .30617 Mdot
.42804 .7858 Mdot
.68795 .42841 Mdot
.34904 .65062 Mdot
.39292 .34531 Mdot
.48496 .73357 Mdot
.59773 .57085 Mdot
.39396 .73941 Mdot
.27132 .75183 Mdot
.42851 .78816 Mdot
.82812 .48722 Mdot
.36367 .66384 Mdot
.38974 .34443 Mdot
.5677 .65091 Mdot
.65811 .41758 Mdot
.66512 .40894 Mdot
.52931 .59889 Mdot
.54044 .62855 Mdot
.55619 .61079 Mdot
.60744 .58217 Mdot
.31154 .27338 Mdot
.54338 .60331 Mdot
.45633 .24117 Mdot
.64976 .41498 Mdot
.5488 .6307 Mdot
.27463 .49488 Mdot
.62934 .57937 Mdot
.39302 .29319 Mdot
.60438 .59959 Mdot
.54043 .63431 Mdot
.61667 .57242 Mdot
.37952 .33729 Mdot
.60476 .30899 Mdot
.54385 .83227 Mdot
.35441 .2666 Mdot
.50587 .3388 Mdot
.30435 .48906 Mdot
.55717 .57495 Mdot
.36707 .65733 Mdot
.61705 .53902 Mdot
.6001 .5832 Mdot
.43033 .79394 Mdot
.53127 .62824 Mdot
.82025 .54576 Mdot
.5724 .52623 Mdot
.61775 .22052 Mdot
.47489 .22427 Mdot
.59993 .57864 Mdot
.69443 .6198 Mdot
.38768 .7293 Mdot
.19297 .53972 Mdot
.39654 .32732 Mdot
.27169 .48812 Mdot
.28085 .52531 Mdot
.38362 .292 Mdot
.49469 .60954 Mdot
.7033 .58323 Mdot
.59992 .63987 Mdot
.5193 .37112 Mdot
.67619 .36511 Mdot
.35116 .66212 Mdot
.67388 .39768 Mdot
.3854 .83114 Mdot
.3964 .5776 Mdot
.32352 .5591 Mdot
.38183 .61998 Mdot
.3366 .50478 Mdot
.53319 .36876 Mdot
.35343 .65587 Mdot
.5824 .61826 Mdot
.64276 .40321 Mdot
.38238 .73291 Mdot
.61003 .66461 Mdot
.47748 .12364 Mdot
.67917 .44617 Mdot
.49776 .4911 Mdot
.40341 .32764 Mdot
.25601 .48783 Mdot
.54992 .65768 Mdot
.57553 .60519 Mdot
.68064 .45504 Mdot
.56655 .65706 Mdot
.40631 .52667 Mdot
.53643 .63418 Mdot
.273 .47061 Mdot
.40379 .66791 Mdot
.42236 .36224 Mdot
.38531 .61674 Mdot
.65504 .45127 Mdot
.44124 .2767 Mdot
.27902 .49809 Mdot
.4928 .56454 Mdot
.38894 .3252 Mdot
.36986 .62718 Mdot
.28227 .5138 Mdot
.38677 .6602 Mdot
.5459 .5697 Mdot
.29034 .5235 Mdot
.35046 .63706 Mdot
.41962 .42595 Mdot
.57205 .62511 Mdot
.42558 .72918 Mdot
.42112 .34554 Mdot
.69439 .4081 Mdot
.59137 .57623 Mdot
.52136 .36035 Mdot
.60354 .55635 Mdot
.54816 .47972 Mdot
.54155 .36907 Mdot
.54227 .3939 Mdot
.33422 .56266 Mdot
.33928 .63348 Mdot
.59423 .35943 Mdot
.40887 .46998 Mdot
.62834 .41388 Mdot
.55373 .56651 Mdot
.67271 .29251 Mdot
.41991 .34709 Mdot
.58528 .6149 Mdot
.61254 .23351 Mdot
.39317 .34596 Mdot
.59164 .59504 Mdot
.41161 .30038 Mdot
.66047 .41162 Mdot
.45967 .41308 Mdot
.67559 .38754 Mdot
.5918 .61629 Mdot
.42252 .31639 Mdot
.27023 .49369 Mdot
.67472 .42328 Mdot
.56252 .58786 Mdot
.54291 .59433 Mdot
.52251 .37242 Mdot
.54363 .62143 Mdot
.68582 .27895 Mdot
.5545 .65571 Mdot
.33795 .51709 Mdot
.59124 .64561 Mdot
.35798 .74146 Mdot
.33273 .61866 Mdot
.63406 .44905 Mdot
.54441 .37307 Mdot
.31034 .52133 Mdot
.44526 .41601 Mdot
.41617 .68824 Mdot
.55022 .59734 Mdot
.53349 .3862 Mdot
.49731 .48644 Mdot
.39979 .29298 Mdot
.52491 .64983 Mdot
.39101 .5033 Mdot
.29935 .51804 Mdot
.52464 .3683 Mdot
.57046 .68083 Mdot
.70087 .41047 Mdot
.58575 .63654 Mdot
.27878 .51445 Mdot
.69162 .39727 Mdot
.61108 .60918 Mdot
.2306 .35152 Mdot
.51775 .36025 Mdot
.42772 .32052 Mdot
.65264 .49157 Mdot
.54164 .58425 Mdot
.2727 .51999 Mdot
.66161 .40579 Mdot
.41743 .3243 Mdot
.63522 .42311 Mdot
.36636 .72774 Mdot
.58955 .49222 Mdot
.31698 .32104 Mdot
.40781 .64119 Mdot
.82589 .62647 Mdot
.35081 .27547 Mdot
.57032 .50441 Mdot
.32536 .46282 Mdot
.54265 .16626 Mdot
.28215 .50862 Mdot
.66626 .67989 Mdot
.32018 .51617 Mdot
.57697 .64092 Mdot
.31191 .50322 Mdot
.6966 .26586 Mdot
.53152 .63917 Mdot
.31776 .48992 Mdot
.30106 .32518 Mdot
.52918 .62535 Mdot
.65021 .41095 Mdot
.78372 .37282 Mdot
.72671 .68854 Mdot
.61637 .7304 Mdot
.32622 .49653 Mdot
.65785 .70438 Mdot
.5426 .65282 Mdot
.58171 .69962 Mdot
.6618 .4214 Mdot
.6032 .54776 Mdot
.33903 .66203 Mdot
.37258 .6661 Mdot
.4725 .77208 Mdot
.74411 .69327 Mdot
.49661 .65288 Mdot
.67156 .41729 Mdot
.44738 .82643 Mdot
.62057 .3294 Mdot
.51418 .36076 Mdot
.38045 .31929 Mdot
.59393 .31401 Mdot
.5615 .68407 Mdot
.6354 .5189 Mdot
.42137 .5021 Mdot
.66621 .44364 Mdot
.36172 .38619 Mdot
.4166 .31792 Mdot
.6584 .72761 Mdot
.71348 .54727 Mdot
.55844 .61266 Mdot
.43435 .32376 Mdot
.56532 .53345 Mdot
.41134 .5076 Mdot
.41401 .73213 Mdot
.22268 .41847 Mdot
.58336 .62133 Mdot
.6065 .35394 Mdot
.59929 .58495 Mdot
.40094 .72209 Mdot
.59014 .61299 Mdot
.63733 .42277 Mdot
.51254 .65935 Mdot
.40728 .45464 Mdot
.6548 .75714 Mdot
.39727 .57209 Mdot
.34027 .64718 Mdot
.56408 .59974 Mdot
.57027 .61217 Mdot
.35872 .6332 Mdot
.66183 .44133 Mdot
.56412 .56483 Mdot
.18323 .41931 Mdot
.54215 .60367 Mdot
.42886 .30059 Mdot
.45768 .44627 Mdot
.82484 .57007 Mdot
.52601 .62865 Mdot
.70082 .41901 Mdot
.39765 .29608 Mdot
.38709 .33296 Mdot
.50742 .66068 Mdot
.42787 .33849 Mdot
.56813 .65267 Mdot
.45915 .44531 Mdot
.6307 .42936 Mdot
.59425 .53155 Mdot
.65615 .4413 Mdot
.41909 .80891 Mdot
.39783 .35041 Mdot
.53881 .38785 Mdot
.64576 .72445 Mdot
.40653 .30902 Mdot
.44129 .62278 Mdot
.51024 .65272 Mdot
.59932 .67117 Mdot
.65094 .48835 Mdot
.26766 .49733 Mdot
.54108 .38111 Mdot
.4121 .32985 Mdot
.54433 .60523 Mdot
.56659 .62972 Mdot
.4365 .31984 Mdot
.76345 .45994 Mdot
.20843 .52709 Mdot
.59488 .61343 Mdot
.63809 .43053 Mdot
.67961 .41589 Mdot
.60507 .5712 Mdot
.59522 .57999 Mdot
.30419 .47985 Mdot
.53463 .38657 Mdot
.54439 .37921 Mdot
.522 .39024 Mdot
.2908 .46938 Mdot
.80064 .66041 Mdot
.37671 .30612 Mdot
.8396 .49328 Mdot
.61322 .26727 Mdot
.51764 .67561 Mdot
.27333 .51533 Mdot
.58185 .59679 Mdot
.5699 .63753 Mdot
.42411 .32287 Mdot
.72541 .72623 Mdot
.51351 .60704 Mdot
.6957 .41905 Mdot
.43445 .30854 Mdot
.59245 .53711 Mdot
.39526 .2721 Mdot
.38875 .64613 Mdot
.56845 .71987 Mdot
.43489 .33042 Mdot
.63421 .41648 Mdot
.43578 .32873 Mdot
.56585 .61196 Mdot
.58053 .68177 Mdot
.66735 .44443 Mdot
.36035 .61933 Mdot
.53715 .58448 Mdot
.59314 .59404 Mdot
.19461 .61505 Mdot
.61448 .33478 Mdot
.31327 .65927 Mdot
.55927 .64535 Mdot
.61063 .65036 Mdot
.38003 .62427 Mdot
.54961 .57337 Mdot
.58557 .64668 Mdot
.52515 .49567 Mdot
.43667 .35281 Mdot
.33261 .64162 Mdot
.64628 .75663 Mdot
.68357 .44273 Mdot
.67256 .27023 Mdot
.51617 .37415 Mdot
.38276 .35782 Mdot
.46357 .40513 Mdot
.53485 .37472 Mdot
.59847 .24101 Mdot
.36505 .24455 Mdot
.53759 .38287 Mdot
.25209 .48618 Mdot
.66539 .60133 Mdot
.58466 .64924 Mdot
.60167 .59735 Mdot
.3403 .63336 Mdot
.68963 .41356 Mdot
.46414 .24046 Mdot
.4451 .35198 Mdot
.57742 .5855 Mdot
.69277 .38905 Mdot
.62626 .22644 Mdot
.52855 .36948 Mdot
.37352 .65816 Mdot
.34864 .6209 Mdot
.59657 .58437 Mdot
.46097 .58449 Mdot
.67407 .4184 Mdot
.56263 .5879 Mdot
.58005 .57085 Mdot
.32182 .52033 Mdot
.64817 .39903 Mdot
.278 .49154 Mdot
.54845 .37703 Mdot
.50112 .14989 Mdot
.17076 .56388 Mdot
.4123 .34725 Mdot
.38121 .37748 Mdot
.38773 .35358 Mdot
.23507 .38275 Mdot
.53634 .38649 Mdot
.56695 .58818 Mdot
.6451 .45112 Mdot
.55757 .58967 Mdot
.54161 .60584 Mdot
.56023 .61741 Mdot
.49671 .65374 Mdot
.4161 .80063 Mdot
.37754 .64511 Mdot
.55135 .66602 Mdot
.31955 .48201 Mdot
.61488 .22389 Mdot
.7393 .3322 Mdot
.56708 .60409 Mdot
.58921 .58397 Mdot
.66873 .45611 Mdot
.54776 .56717 Mdot
.38854 .30545 Mdot
.68481 .43735 Mdot
.57555 .63214 Mdot
.31469 .70163 Mdot
.57114 .56525 Mdot
.3617 .36081 Mdot
.43548 .33246 Mdot
.62601 .66794 Mdot
.59134 .67064 Mdot
.53791 .38653 Mdot
.5405 .38072 Mdot
.52793 .3594 Mdot
.42956 .3057 Mdot
.31912 .52154 Mdot
.25448 .51883 Mdot
.57412 .67432 Mdot
.56218 .65253 Mdot
.58726 .67959 Mdot
.3349 .48487 Mdot
.40161 .46512 Mdot
.61207 .37871 Mdot
.56242 .53027 Mdot
.29783 .47178 Mdot
.62581 .47995 Mdot
.67717 .73303 Mdot
.69063 .42885 Mdot
.33155 .4688 Mdot
.38507 .31802 Mdot
.36504 .66522 Mdot
.47063 .80338 Mdot
.63688 .43997 Mdot
.68574 .4487 Mdot
.30987 .48805 Mdot
.49845 .44847 Mdot
.49598 .91899 Mdot
.28802 .50055 Mdot
.35152 .55832 Mdot
.66564 .421 Mdot
.51644 .60406 Mdot
.49847 .48147 Mdot
.51862 .45715 Mdot
.32014 .49642 Mdot
.54394 .59366 Mdot
.43245 .60355 Mdot
.30506 .48013 Mdot
.51843 .64618 Mdot
.32544 .49423 Mdot
.43026 .32577 Mdot
.29219 .49328 Mdot
.65916 .38037 Mdot
.53791 .60635 Mdot
.44358 .90321 Mdot
.4886 .40237 Mdot
.56452 .58211 Mdot
.43742 .31539 Mdot
.28038 .31945 Mdot
.57094 .61609 Mdot
.34038 .65993 Mdot
.30929 .47272 Mdot
.21818 .40852 Mdot
.58808 .64233 Mdot
.31493 .49767 Mdot
.64224 .38498 Mdot
.31974 .4628 Mdot
.3063 .66266 Mdot
.54303 .37994 Mdot
.65737 .41319 Mdot
.52709 .40127 Mdot
.38455 .30009 Mdot
.59037 .5588 Mdot
.57204 .56928 Mdot
.64381 .42091 Mdot
.43255 .41732 Mdot
.50163 .62448 Mdot
.54562 .59801 Mdot
.29571 .48081 Mdot
.33061 .48704 Mdot
.56878 .40542 Mdot
.2772 .50255 Mdot
.61176 .64774 Mdot
.64223 .41941 Mdot
.58381 .63432 Mdot
.65829 .40404 Mdot
.55013 .56838 Mdot
.54641 .34944 Mdot
.692 .42238 Mdot
.5079 .53908 Mdot
.53549 .61325 Mdot
.73139 .39861 Mdot
.53829 .58884 Mdot
.57757 .6227 Mdot
.32072 .47588 Mdot
.3655 .64671 Mdot
.51696 .62803 Mdot
.43356 .2721 Mdot
.38996 .63313 Mdot
.80042 .45302 Mdot
.29542 .5302 Mdot
.35807 .62216 Mdot
.46126 .75099 Mdot
.54415 .37288 Mdot
.36932 .63634 Mdot
.55591 .37452 Mdot
.41891 .34489 Mdot
.6388 .39907 Mdot
.5303 .62002 Mdot
.54509 .16093 Mdot
.21008 .53139 Mdot
.52399 .3766 Mdot
.58929 .57666 Mdot
.58253 .60119 Mdot
.69786 .40208 Mdot
.3756 .8256 Mdot
.26812 .46945 Mdot
.58128 .62561 Mdot
.64679 .44785 Mdot
.32137 .79193 Mdot
.3169 .48695 Mdot
.38053 .64206 Mdot
.41664 .3546 Mdot
.69915 .37417 Mdot
.54307 .38553 Mdot
.39671 .35011 Mdot
.35595 .51748 Mdot
.43261 .79815 Mdot
.59051 .63884 Mdot
.27117 .50531 Mdot
.42847 .7887 Mdot
.57661 .52531 Mdot
.36954 .30587 Mdot
.55546 .35755 Mdot
.67026 .44061 Mdot
.43642 .31696 Mdot
.33758 .64088 Mdot
.63029 .41305 Mdot
.65981 .44243 Mdot
.38304 .31373 Mdot
.47326 .2059 Mdot
.50153 .48451 Mdot
.40717 .28921 Mdot
.52702 .4757 Mdot
.42596 .78489 Mdot
.53164 .38979 Mdot
.3721 .65923 Mdot
.31607 .71503 Mdot
.67582 .41719 Mdot
.59545 .31318 Mdot
.4306 .79191 Mdot
.57311 .62386 Mdot
.34598 .64051 Mdot
.63216 .2414 Mdot
.39933 .36533 Mdot
.38354 .33543 Mdot
.37461 .49839 Mdot
.34416 .65788 Mdot
.58786 .56722 Mdot
.81769 .59488 Mdot
.52894 .61338 Mdot
.39778 .34879 Mdot
.4165 .51322 Mdot
.648 .39996 Mdot
.38736 .29465 Mdot
.40364 .52957 Mdot
.56918 .63935 Mdot
.57012 .57647 Mdot
.41876 .64117 Mdot
.65436 .39476 Mdot
.54279 .38962 Mdot
.54918 .59164 Mdot
.5905 .60151 Mdot
.59649 .56128 Mdot
.62761 .74859 Mdot
.49811 .53909 Mdot
.57722 .62837 Mdot
.25948 .49009 Mdot
.61969 .638 Mdot
.60729 .58516 Mdot
.69942 .40061 Mdot
.35594 .7485 Mdot
.54879 .37719 Mdot
.60042 .59964 Mdot
.59542 .61241 Mdot
.37896 .31456 Mdot
.49966 .48497 Mdot
.52121 .45649 Mdot
.33649 .51215 Mdot
.36961 .51736 Mdot
.60361 .64039 Mdot
.6517 .41806 Mdot
.33727 .66189 Mdot
.6264 .58966 Mdot
.69086 .43213 Mdot
.55782 .67023 Mdot
.32369 .48538 Mdot
.53357 .38368 Mdot
.53919 .53771 Mdot
.36198 .63799 Mdot
.44328 .33494 Mdot
.83104 .4648 Mdot
.27517 .48676 Mdot
.54804 .64684 Mdot
.26018 .52761 Mdot
.29549 .50938 Mdot
.52158 .37577 Mdot
.59852 .67959 Mdot
.66479 .41169 Mdot
.64099 .40817 Mdot
.40306 .78004 Mdot
.27977 .46998 Mdot
.21877 .67189 Mdot
.43014 .32902 Mdot
.53295 .65381 Mdot
.68677 .3267 Mdot
.64657 .40261 Mdot
.39879 .71354 Mdot
.3597 .62137 Mdot
.38442 .33623 Mdot
.54628 .39835 Mdot
.69344 .41964 Mdot
.65505 .39955 Mdot
.54248 .60917 Mdot
.57189 .59666 Mdot
.34628 .47703 Mdot
.39211 .73298 Mdot
.41086 .30042 Mdot
.38362 .64685 Mdot
.33463 .52357 Mdot
.56791 .64398 Mdot
.67869 .43775 Mdot
.81746 .58521 Mdot
.54328 .58275 Mdot
.32112 .48433 Mdot
.67681 .43414 Mdot
.37614 .6346 Mdot
.35304 .62823 Mdot
.57454 .62315 Mdot
.80972 .5694 Mdot
.40336 .30807 Mdot
.64573 .41335 Mdot
.61109 .44176 Mdot
.56379 .66558 Mdot
.56743 .60072 Mdot
.54743 .55074 Mdot
.37428 .30221 Mdot
.55685 .52703 Mdot
.39458 .63174 Mdot
.6779 .40591 Mdot
.55777 .58647 Mdot
.36258 .63504 Mdot
.63335 .51574 Mdot
.5326 .37728 Mdot
.31557 .48724 Mdot
.34274 .66174 Mdot
.35442 .6466 Mdot
.38604 .63153 Mdot
.5944 .31602 Mdot
.67219 .46498 Mdot
.60576 .79831 Mdot
.53827 .60236 Mdot
.42496 .78342 Mdot
.55231 .56141 Mdot
.42401 .30728 Mdot
.27145 .48509 Mdot
.54757 .60996 Mdot
.53784 .60281 Mdot
.82428 .5237 Mdot
.59356 .69677 Mdot
.59862 .69753 Mdot
.63601 .4107 Mdot
.70711 .45935 Mdot
.27128 .5171 Mdot
.24001 .72605 Mdot
.79389 .35579 Mdot
.60346 .63569 Mdot
.49318 .44726 Mdot
.68489 .43609 Mdot
.37932 .33258 Mdot
.5169 .47567 Mdot
.35755 .28611 Mdot
.68486 .41158 Mdot
.57397 .64139 Mdot
.82769 .47079 Mdot
.39509 .65044 Mdot
.55852 .61039 Mdot
.3927 .31909 Mdot
.5574 .61061 Mdot
.42496 .30322 Mdot
.71658 .37422 Mdot
.51471 .44226 Mdot
.53071 .63024 Mdot
.5978 .63822 Mdot
.60552 .51714 Mdot
.56905 .60192 Mdot
.2507 .4035 Mdot
.66536 .43343 Mdot
.49513 .55707 Mdot
.612 .57527 Mdot
.77739 .60129 Mdot
.57093 .56727 Mdot
.45197 .39707 Mdot
.5674 .57243 Mdot
.59038 .75021 Mdot
.59179 .56829 Mdot
.55879 .57459 Mdot
.41931 .31799 Mdot
.377 .32044 Mdot
.64342 .38194 Mdot
.54012 .39241 Mdot
.61679 .22116 Mdot
.59164 .58871 Mdot
.32996 .48268 Mdot
.58072 .42804 Mdot
.35948 .64831 Mdot
.68006 .40909 Mdot
.13859 .59484 Mdot
.40339 .29531 Mdot
.2556 .48183 Mdot
.2867 .55552 Mdot
.25837 .5084 Mdot
.34731 .50013 Mdot
.7305 .41082 Mdot
.37715 .65781 Mdot
.58001 .56688 Mdot
.80081 .5261 Mdot
.61576 .34388 Mdot
.56392 .66379 Mdot
.24027 .50117 Mdot
.64993 .58782 Mdot
.41635 .79167 Mdot
.38477 .66307 Mdot
.35835 .66295 Mdot
.41517 .3256 Mdot
.29659 .53373 Mdot
.55567 .53589 Mdot
.35871 .62232 Mdot
.27394 .48394 Mdot
.51239 .37482 Mdot
.35598 .58863 Mdot
.67318 .41449 Mdot
.6348 .71227 Mdot
.68709 .33787 Mdot
.40564 .29654 Mdot
.44682 .28654 Mdot
.64512 .47677 Mdot
.62228 .43851 Mdot
.5336 .39386 Mdot
.31338 .47919 Mdot
.63094 .40635 Mdot
.53874 .60669 Mdot
.60981 .66488 Mdot
.59603 .58294 Mdot
.34393 .62992 Mdot
.58474 .57228 Mdot
.29871 .47663 Mdot
.40188 .30167 Mdot
.30574 .51984 Mdot
.40755 .30579 Mdot
.80452 .42431 Mdot
.60592 .58832 Mdot
.56703 .5981 Mdot
.46563 .44317 Mdot
.66412 .39785 Mdot
.79127 .51582 Mdot
.31815 .48051 Mdot
.32572 .51104 Mdot
.58311 .6335 Mdot
.63986 .45524 Mdot
.41845 .66433 Mdot
.49524 .46704 Mdot
.57206 .5714 Mdot
.66436 .43369 Mdot
.58689 .63228 Mdot
.24389 .36039 Mdot
.51871 .43119 Mdot
.63622 .4197 Mdot
.65662 .7572 Mdot
.54156 .61781 Mdot
.61621 .66936 Mdot
.63731 .62999 Mdot
.54368 .72833 Mdot
.51133 .6337 Mdot
.67812 .44614 Mdot
.60551 .5991 Mdot
.6535 .42229 Mdot
.28906 .50921 Mdot
.37497 .30754 Mdot
.65685 .42145 Mdot
.5305 .61207 Mdot
.79716 .36949 Mdot
.39555 .30071 Mdot
.5539 .60513 Mdot
.41281 .33401 Mdot
.65146 .39056 Mdot
.67417 .39431 Mdot
.56075 .38761 Mdot
.33811 .55929 Mdot
.39193 .30473 Mdot
.56243 .65341 Mdot
.60927 .32017 Mdot
.58371 .63498 Mdot
.36827 .52181 Mdot
.61688 .5874 Mdot
.58224 .65514 Mdot
.83482 .61391 Mdot
.44384 .41236 Mdot
.18408 .64772 Mdot
.45395 .35012 Mdot
.60884 .31152 Mdot
.62575 .3906 Mdot
.38351 .66352 Mdot
.38842 .38852 Mdot
.5338 .36428 Mdot
.25903 .49666 Mdot
.54505 .60805 Mdot
.73856 .3634 Mdot
.41877 .29358 Mdot
.36893 .64897 Mdot
.53124 .62905 Mdot
.29445 .53656 Mdot
.49315 .38113 Mdot
.38919 .34325 Mdot
.67477 .41304 Mdot
.67529 .39724 Mdot
.4838 .835 Mdot
.56295 .58398 Mdot
.57155 .5923 Mdot
.38698 .30239 Mdot
.52828 .55663 Mdot
.38861 .63636 Mdot
.3059 .33635 Mdot
.39258 .32278 Mdot
.51206 .42652 Mdot
.6343 .41083 Mdot
.58212 .59949 Mdot
.45672 .44753 Mdot
.55358 .2878 Mdot
.67504 .52263 Mdot
.34572 .65094 Mdot
.43748 .64836 Mdot
.67811 .44632 Mdot
.39555 .32295 Mdot
.46543 .7643 Mdot
.53832 .56927 Mdot
.58437 .602 Mdot
.44267 .66215 Mdot
.49997 .46841 Mdot
.36617 .55385 Mdot
.55405 .55033 Mdot
.4808 .49915 Mdot
.58187 .63405 Mdot
.56664 .63006 Mdot
.58063 .65919 Mdot
.61093 .60251 Mdot
.66003 .43255 Mdot
.73746 .67404 Mdot
.3048 .49756 Mdot
.68218 .58496 Mdot
.36441 .48242 Mdot
.53962 .65209 Mdot
.5723 .64018 Mdot
.72029 .64105 Mdot
.57353 .47831 Mdot
.66862 .42847 Mdot
.61276 .4461 Mdot
.37785 .30539 Mdot
.59112 .69901 Mdot
.29121 .4685 Mdot
.63981 .64322 Mdot
.30677 .51149 Mdot
.66299 .43483 Mdot
.30893 .52644 Mdot
.43679 .299 Mdot
.27142 .50557 Mdot
.277 .47272 Mdot
.39951 .35333 Mdot
.67051 .39092 Mdot
.55502 .57486 Mdot
.40751 .3526 Mdot
.42371 .65743 Mdot
.34454 .62973 Mdot
.56262 .38504 Mdot
.51633 .6032 Mdot
.60156 .69007 Mdot
.22734 .35586 Mdot
.29514 .52611 Mdot
.54338 .46502 Mdot
.69213 .42091 Mdot
.3343 .65395 Mdot
.65689 .43013 Mdot
.53644 .81072 Mdot
.35433 .63975 Mdot
.56217 .38307 Mdot
.4506 .76159 Mdot
.39311 .26126 Mdot
.61383 .56071 Mdot
.65005 .48982 Mdot
.30473 .51347 Mdot
.43058 .30223 Mdot
.62501 .23532 Mdot
.54905 .62133 Mdot
.5065 .37262 Mdot
.62204 .44745 Mdot
.54421 .37415 Mdot
.39484 .3186 Mdot
.43719 .3787 Mdot
.56934 .5812 Mdot
.41013 .26578 Mdot
.60595 .62378 Mdot
.64884 .71875 Mdot
.36476 .50397 Mdot
.61944 .48803 Mdot
.58378 .63989 Mdot
.31453 .48292 Mdot
.58406 .63786 Mdot
.66525 .65314 Mdot
.43949 .77744 Mdot
.61163 .6237 Mdot
.60881 .49592 Mdot
.21758 .39122 Mdot
.6749 .43938 Mdot
.60897 .65021 Mdot
.52677 .38539 Mdot
.55486 .63931 Mdot
.60421 .15379 Mdot
.36805 .63788 Mdot
.31486 .65327 Mdot
.53165 .61071 Mdot
.55216 .5917 Mdot
.81485 .54889 Mdot
.70718 .45266 Mdot
.54773 .39755 Mdot
.5834 .6082 Mdot
.45652 .67035 Mdot
.4191 .32383 Mdot
.61284 .60384 Mdot
.60361 .5949 Mdot
.19409 .59221 Mdot
.41978 .32747 Mdot
.28464 .52394 Mdot
.54285 .37095 Mdot
.33497 .50556 Mdot
.32264 .65197 Mdot
.49025 .5164 Mdot
.40628 .71093 Mdot
.52431 .42967 Mdot
.33913 .65441 Mdot
.53901 .65363 Mdot
.6043 .43934 Mdot
.55545 .5828 Mdot
.3571 .66136 Mdot
.39904 .33279 Mdot
.66155 .42963 Mdot
.6417 .70877 Mdot
.5192 .37285 Mdot
.54376 .66134 Mdot
.39007 .66202 Mdot
.65996 .41706 Mdot
.49072 .2766 Mdot
.68974 .41932 Mdot
.41119 .31033 Mdot
.38621 .29095 Mdot
.35882 .6436 Mdot
.65783 .43213 Mdot
.33276 .51123 Mdot
.45421 .35504 Mdot
.6181 .59485 Mdot
.43222 .29245 Mdot
.62452 .41104 Mdot
.69723 .42425 Mdot
.63785 .44886 Mdot
.60868 .6018 Mdot
.50018 .46149 Mdot
.55562 .55691 Mdot
.39209 .30092 Mdot
.26713 .519 Mdot
.39904 .74187 Mdot
.8033 .54809 Mdot
.50604 .42542 Mdot
.5156 .62933 Mdot
.58659 .57393 Mdot
.59597 .58407 Mdot
.59475 .62198 Mdot
.30905 .33648 Mdot
.6059 .5889 Mdot
.4207 .31239 Mdot
.30068 .50616 Mdot
.58157 .57636 Mdot
.52991 .38622 Mdot
.4035 .46966 Mdot
.33535 .66069 Mdot
.6004 .72686 Mdot
.71461 .31834 Mdot
.66041 .41887 Mdot
.2755 .50715 Mdot
.31476 .52584 Mdot
.36113 .62458 Mdot
.40356 .35124 Mdot
.68817 .41156 Mdot
.56798 .745 Mdot
.39621 .63956 Mdot
.59991 .60039 Mdot
.46139 .44447 Mdot
.66762 .74348 Mdot
.52452 .63722 Mdot
.56908 .61951 Mdot
.54528 .38841 Mdot
.25623 .48333 Mdot
.62057 .18633 Mdot
.47093 .21579 Mdot
.364 .64566 Mdot
.38434 .63945 Mdot
.65289 .45511 Mdot
.534 .6555 Mdot
.40024 .30765 Mdot
.48966 .49408 Mdot
.2402 .33527 Mdot
.66038 .25265 Mdot
.23457 .38589 Mdot
.56897 .56532 Mdot
.74702 .64303 Mdot
.61725 .5762 Mdot
.67449 .4632 Mdot
.64167 .45405 Mdot
.67066 .42231 Mdot
.41772 .3176 Mdot
.43584 .80203 Mdot
.42184 .31263 Mdot
.72104 .31917 Mdot
.66065 .44813 Mdot
.42154 .43518 Mdot
.32773 .50478 Mdot
.57265 .69527 Mdot
.37467 .65926 Mdot
.38344 .69357 Mdot
.60353 .66005 Mdot
.45938 .59172 Mdot
.27359 .51555 Mdot
.68562 .39619 Mdot
.51112 .65267 Mdot
.60614 .21451 Mdot
.49868 .44591 Mdot
.18869 .42832 Mdot
.69612 .47429 Mdot
.35773 .63402 Mdot
.69568 .59387 Mdot
.39328 .64096 Mdot
.38689 .3394 Mdot
.54511 .61806 Mdot
.53082 .59886 Mdot
.5846 .62191 Mdot
.60673 .60838 Mdot
.4114 .33082 Mdot
.62042 .58521 Mdot
.35927 .7424 Mdot
.5144 .36895 Mdot
.39626 .43629 Mdot
.359 .6287 Mdot
.43153 .31946 Mdot
.29694 .50791 Mdot
.53488 .39492 Mdot
.40839 .63434 Mdot
.60172 .56574 Mdot
.53817 .59675 Mdot
.51357 .37385 Mdot
.5065 .58024 Mdot
.56224 .68505 Mdot
.3103 .49804 Mdot
.41278 .49225 Mdot
.33765 .6299 Mdot
.37259 .66312 Mdot
.43547 .32363 Mdot
.65674 .43038 Mdot
.34866 .62418 Mdot
.29676 .53443 Mdot
.60659 .61886 Mdot
.59537 .64155 Mdot
.62483 .40965 Mdot
.4299 .7924 Mdot
.33751 .6642 Mdot
.57207 .52505 Mdot
.66934 .40189 Mdot
.62352 .45298 Mdot
.58181 .60928 Mdot
.61038 .54708 Mdot
.68788 .44901 Mdot
.37479 .63068 Mdot
.43282 .32849 Mdot
.44201 .42909 Mdot
.42291 .3103 Mdot
.66516 .40574 Mdot
.6163 .64824 Mdot
.65075 .39546 Mdot
.54583 .62277 Mdot
.22836 .74666 Mdot
.59948 .57668 Mdot
.47897 .64302 Mdot
.3875 .58562 Mdot
.32421 .49208 Mdot
.32074 .48789 Mdot
.53262 .38467 Mdot
.68895 .43421 Mdot
.62751 .58954 Mdot
.38305 .6536 Mdot
.60933 .31258 Mdot
.67142 .47479 Mdot
.28655 .47099 Mdot
.26265 .47579 Mdot
.401 .33285 Mdot
.57594 .56778 Mdot
.58317 .5944 Mdot
.2719 .50927 Mdot
.28807 .32167 Mdot
.65031 .42747 Mdot
.57119 .59233 Mdot
.61052 .59292 Mdot
.30293 .49971 Mdot
.44032 .37302 Mdot
.62419 .45984 Mdot
.61114 .59491 Mdot
.42962 .76174 Mdot
.41819 .29851 Mdot
.55048 .65344 Mdot
.6167 .57692 Mdot
.35592 .65062 Mdot
.41495 .68773 Mdot
.42743 .78493 Mdot
.37806 .33688 Mdot
.54393 .38289 Mdot
.53291 .59175 Mdot
.32509 .49769 Mdot
.51284 .61271 Mdot
.37114 .22747 Mdot
.51707 .3653 Mdot
.57317 .5827 Mdot
.60139 .64453 Mdot
.65436 .40537 Mdot
.56563 .58676 Mdot
.5461 .351 Mdot
.29141 .48357 Mdot
.57359 .58197 Mdot
.80723 .57294 Mdot
.39864 .33137 Mdot
.60182 .66318 Mdot
.35244 .66541 Mdot
.3804 .54731 Mdot
.78508 .38362 Mdot
.33971 .49387 Mdot
.35083 .63045 Mdot
.58323 .5719 Mdot
.33678 .5065 Mdot
.41462 .35516 Mdot
.4841 .56622 Mdot
.5436 .65705 Mdot
.4201 .30666 Mdot
.39869 .30185 Mdot
.36304 .6424 Mdot
.17454 .6528 Mdot
.6011 .64352 Mdot
.56114 .60686 Mdot
.21395 .35203 Mdot
.70204 .4326 Mdot
.55318 .60741 Mdot
.57235 .56852 Mdot
.42163 .34493 Mdot
.52303 .79356 Mdot
.44278 .6376 Mdot
.30134 .32433 Mdot
.42291 .30232 Mdot
.25447 .47593 Mdot
.28246 .48446 Mdot
.35233 .63094 Mdot
.6791 .433 Mdot
.33577 .63768 Mdot
.2973 .49207 Mdot
.57891 .62226 Mdot
.39826 .34202 Mdot
.73417 .47362 Mdot
.43866 .31734 Mdot
.30971 .53798 Mdot
.65117 .46849 Mdot
.73665 .3383 Mdot
.30802 .2358 Mdot
.68581 .3416 Mdot
.37182 .32144 Mdot
.3594 .64852 Mdot
.46261 .22815 Mdot
.57933 .57413 Mdot
.67107 .70399 Mdot
.55902 .60906 Mdot
.64212 .50967 Mdot
.27242 .48431 Mdot
.52268 .39244 Mdot
.54957 .62135 Mdot
.43811 .64766 Mdot
.39366 .34912 Mdot
.38782 .31153 Mdot
.60019 .61033 Mdot
.40925 .309 Mdot
.58056 .59083 Mdot
.29804 .50305 Mdot
.18181 .65784 Mdot
.56106 .57566 Mdot
.62337 .62589 Mdot
.42446 .36089 Mdot
.56329 .38475 Mdot
.24457 .50141 Mdot
.75447 .64471 Mdot
.60567 .20839 Mdot
.40444 .31035 Mdot
.50352 .67352 Mdot
.28755 .52147 Mdot
.54235 .39396 Mdot
.30154 .46483 Mdot
.5706 .60897 Mdot
.56172 .56617 Mdot
.58441 .62775 Mdot
.58459 .57435 Mdot
.69034 .67026 Mdot
.56774 .68814 Mdot
.7305 .55265 Mdot
.53899 .60116 Mdot
.4815 .64464 Mdot
.42449 .32053 Mdot
.62189 .6626 Mdot
.36402 .56049 Mdot
.57246 .56358 Mdot
.67348 .48143 Mdot
.43137 .32275 Mdot
.67179 .30621 Mdot
.41568 .32953 Mdot
.31075 .51979 Mdot
.38006 .32519 Mdot
.54208 .61998 Mdot
.67917 .41755 Mdot
.282 .49569 Mdot
.61254 .37741 Mdot
.26162 .50359 Mdot
.56475 .5821 Mdot
.36151 .26707 Mdot
.33067 .50192 Mdot
.6126 .69057 Mdot
.68097 .41896 Mdot
.46897 .69756 Mdot
.69249 .45053 Mdot
.56054 .59157 Mdot
.5549 .59715 Mdot
.52711 .39563 Mdot
.38897 .34354 Mdot
.62864 .42644 Mdot
.20579 .6274 Mdot
.38248 .66645 Mdot
.67229 .43187 Mdot
.63503 .6301 Mdot
.48928 .44538 Mdot
.64372 .41121 Mdot
.48929 .70292 Mdot
.39678 .34852 Mdot
.6638 .45119 Mdot
.6005 .55247 Mdot
.67903 .5974 Mdot
.38903 .65527 Mdot
.33435 .49709 Mdot
.48067 .48166 Mdot
.28503 .48363 Mdot
.44306 .31611 Mdot
.28132 .46824 Mdot
.42218 .32298 Mdot
.58753 .44276 Mdot
.41195 .51995 Mdot
.43345 .29991 Mdot
.4473 .34287 Mdot
.30741 .49138 Mdot
.59593 .61769 Mdot
.40687 .45726 Mdot
.62513 .55975 Mdot
.59736 .67546 Mdot
.41484 .29938 Mdot
.67399 .44897 Mdot
.63655 .40557 Mdot
.50191 .55112 Mdot
.66321 .39637 Mdot
.28408 .50201 Mdot
.53961 .42799 Mdot
.65036 .7237 Mdot
.39633 .33303 Mdot
.31534 .55834 Mdot
.58036 .63927 Mdot
.31471 .48962 Mdot
.28411 .50698 Mdot
.40596 .3037 Mdot
.67978 .56809 Mdot
.59293 .67554 Mdot
.70218 .40667 Mdot
.64926 .44819 Mdot
.6411 .41456 Mdot
.64385 .45686 Mdot
.4478 .81085 Mdot
.4309 .30259 Mdot
.68249 .44153 Mdot
.59939 .62167 Mdot
.54257 .58157 Mdot
.53823 .37067 Mdot
.37349 .63122 Mdot
.56722 .55634 Mdot
.62814 .57888 Mdot
.58161 .60813 Mdot
.32544 .49391 Mdot
.63053 .53924 Mdot
.5181 .36641 Mdot
.27201 .47199 Mdot
.29087 .46889 Mdot
.53927 .38607 Mdot
.59333 .45238 Mdot
.65668 .21865 Mdot
.58223 .6251 Mdot
.7332 .37234 Mdot
.32248 .49628 Mdot
.46383 .5586 Mdot
.48824 .6072 Mdot
.56659 .65338 Mdot
.38511 .44122 Mdot
.2919 .50291 Mdot
.64322 .37756 Mdot
.56885 .60563 Mdot
.52996 .39192 Mdot
.3739 .66359 Mdot
.63399 .57248 Mdot
.54506 .38957 Mdot
.66034 .43694 Mdot
.21048 .49227 Mdot
.69486 .39264 Mdot
.33201 .50442 Mdot
.60746 .65339 Mdot
.47544 .91511 Mdot
.3034 .51448 Mdot
.59639 .3043 Mdot
.40808 .5244 Mdot
.56445 .57622 Mdot
.27775 .49382 Mdot
.61952 .41707 Mdot
.41726 .29813 Mdot
.47193 .45163 Mdot
.67888 .43726 Mdot
.5333 .39481 Mdot
.54023 .37632 Mdot
.30502 .49839 Mdot
.63905 .4401 Mdot
.61888 .58785 Mdot
.67874 .40045 Mdot
.38913 .33267 Mdot
.54133 .63423 Mdot
.61656 .22063 Mdot
.60141 .67765 Mdot
.67821 .40199 Mdot
.28491 .53228 Mdot
.36957 .62092 Mdot
.52945 .6346 Mdot
.66504 .28266 Mdot
.57711 .56858 Mdot
.4087 .33474 Mdot
.43806 .55371 Mdot
.73059 .48179 Mdot
.59165 .61253 Mdot
.57676 .63933 Mdot
.4336 .33817 Mdot
.58852 .61471 Mdot
.57656 .65604 Mdot
.45842 .37228 Mdot
.64794 .40774 Mdot
.58487 .58137 Mdot
.28106 .4817 Mdot
.7723 .43942 Mdot
.54649 .61668 Mdot
.53225 .34228 Mdot
.45738 .67901 Mdot
.42659 .53535 Mdot
.62752 .59502 Mdot
.39766 .7118 Mdot
.55672 .59964 Mdot
.56685 .65719 Mdot
.58923 .62236 Mdot
.74163 .6482 Mdot
.30216 .49059 Mdot
.29376 .473 Mdot
.36742 .6661 Mdot
.45095 .66402 Mdot
.34594 .64316 Mdot
.43092 .34028 Mdot
.30551 .55787 Mdot
.515 .37313 Mdot
.65539 .42808 Mdot
.54913 .61635 Mdot
.26224 .49887 Mdot
.57975 .60214 Mdot
.55432 .641 Mdot
.28842 .4975 Mdot
.28736 .50675 Mdot
.33719 .48674 Mdot
.3972 .64597 Mdot
.66524 .42474 Mdot
.56586 .62168 Mdot
.3903 .63318 Mdot
.60983 .57581 Mdot
.47745 .41826 Mdot
.6672 .42555 Mdot
.67609 .3998 Mdot
.65148 .39261 Mdot
.53666 .59506 Mdot
.54058 .62401 Mdot
.42173 .31212 Mdot
.62573 .4086 Mdot
.38639 .30796 Mdot
.2784 .49212 Mdot
.31088 .4849 Mdot
.57011 .60942 Mdot
.55595 .53237 Mdot
.36697 .63052 Mdot
.30498 .52403 Mdot
.53041 .36145 Mdot
.35808 .66714 Mdot
.59257 .57724 Mdot
.28135 .48723 Mdot
.33983 .6627 Mdot
.67904 .49709 Mdot
.57749 .18779 Mdot
.39975 .6439 Mdot
.60069 .6098 Mdot
.81101 .53962 Mdot
.43052 .7696 Mdot
.39431 .66215 Mdot
.41785 .33412 Mdot
.55737 .57199 Mdot
.3053 .27772 Mdot
.34157 .62436 Mdot
.43218 .78979 Mdot
.28907 .49345 Mdot
.58575 .5104 Mdot
.63855 .58102 Mdot
.65929 .72077 Mdot
.34733 .62046 Mdot
.67932 .40501 Mdot
.64255 .4488 Mdot
.59837 .60441 Mdot
.35351 .55757 Mdot
.43927 .31022 Mdot
.31449 .52608 Mdot
.27261 .47657 Mdot
.63303 .42681 Mdot
.52056 .4282 Mdot
.28083 .48293 Mdot
.54958 .66573 Mdot
.33511 .67025 Mdot
.58969 .69973 Mdot
.48355 .83087 Mdot
.77539 .38799 Mdot
.62567 .60476 Mdot
.37812 .62338 Mdot
.39839 .35375 Mdot
.41424 .30809 Mdot
.4153 .31557 Mdot
.30768 .48348 Mdot
.50906 .47533 Mdot
.27101 .48105 Mdot
.50831 .32561 Mdot
.36436 .6345 Mdot
.49269 .72889 Mdot
.6055 .56071 Mdot
.56395 .57695 Mdot
.59398 .6381 Mdot
.58284 .62893 Mdot
.55866 .59896 Mdot
.40634 .29712 Mdot
.33004 .5192 Mdot
.23641 .35648 Mdot
.63884 .43008 Mdot
.48492 .27196 Mdot
.32776 .50644 Mdot
.5483 .38207 Mdot
.37509 .64937 Mdot
.42154 .69711 Mdot
.3455 .67937 Mdot
.31413 .52383 Mdot
.52697 .6459 Mdot
.66673 .45489 Mdot
.62194 .75295 Mdot
.54549 .59795 Mdot
.30139 .52535 Mdot
.26125 .46986 Mdot
.68529 .56439 Mdot
.5235 .57771 Mdot
.35213 .55581 Mdot
.49284 .44937 Mdot
.4003 .63472 Mdot
.517 .62041 Mdot
.4737 .54933 Mdot
.29911 .49321 Mdot
.31624 .51168 Mdot
.39973 .65605 Mdot
.65598 .58894 Mdot
.66353 .44543 Mdot
.51936 .39013 Mdot
.42129 .33486 Mdot
.54822 .58591 Mdot
.30306 .48288 Mdot
.64163 .37334 Mdot
.45821 .432 Mdot
.40665 .32799 Mdot
.26748 .4733 Mdot
.56802 .56754 Mdot
.59499 .60744 Mdot
.35412 .63699 Mdot
.20967 .56607 Mdot
.62542 .56063 Mdot
.60784 .31185 Mdot
.52908 .45383 Mdot
.39567 .53708 Mdot
.58454 .60138 Mdot
.64585 .40052 Mdot
.53665 .38669 Mdot
.37037 .65921 Mdot
.60046 .569 Mdot
.63103 .20428 Mdot
.68783 .38526 Mdot
.39329 .30511 Mdot
.53589 .38972 Mdot
.50068 .48984 Mdot
.57805 .56918 Mdot
.55965 .60899 Mdot
.60828 .60287 Mdot
.63175 .20109 Mdot
.27971 .47771 Mdot
.62796 .43712 Mdot
.34274 .646 Mdot
.68073 .3995 Mdot
.30989 .4721 Mdot
.3913 .53532 Mdot
.60628 .58602 Mdot
.69144 .39386 Mdot
.68588 .41039 Mdot
.39743 .33131 Mdot
.40925 .35266 Mdot
.3401 .50821 Mdot
.58154 .57286 Mdot
.51705 .38249 Mdot
.67273 .44707 Mdot
.3153 .52834 Mdot
.35486 .6374 Mdot
.39907 .27839 Mdot
.5386 .6008 Mdot
.30428 .49578 Mdot
.62116 .61642 Mdot
.64926 .41403 Mdot
.32083 .51911 Mdot
.54855 .38988 Mdot
.37698 .6332 Mdot
.54873 .57251 Mdot
.21393 .40319 Mdot
.53355 .39257 Mdot
.52936 .61287 Mdot
.76985 .3915 Mdot
.36003 .55618 Mdot
.63873 .36409 Mdot
.26991 .4933 Mdot
.51982 .38352 Mdot
.63313 .44682 Mdot
.68363 .61566 Mdot
.31359 .5094 Mdot
.82115 .49473 Mdot
.42296 .44192 Mdot
.57663 .62529 Mdot
.66876 .43963 Mdot
.40874 .6576 Mdot
.61632 .30508 Mdot
.41585 .75495 Mdot
.57656 .58761 Mdot
.28586 .48305 Mdot
.37002 .6641 Mdot
.38638 .31274 Mdot
.51913 .34251 Mdot
.52697 .82948 Mdot
.26867 .47476 Mdot
.55443 .61762 Mdot
.67103 .44953 Mdot
.39977 .30493 Mdot
.82899 .47608 Mdot
.30134 .53523 Mdot
.27272 .49161 Mdot
.58684 .64365 Mdot
.34423 .64966 Mdot
.30971 .27702 Mdot
.28994 .47423 Mdot
.33525 .50908 Mdot
.48344 .36247 Mdot
.38152 .66312 Mdot
.60304 .61281 Mdot
.50097 .55224 Mdot
.61316 .5998 Mdot
.53316 .30316 Mdot
.51923 .3838 Mdot
.64013 .4304 Mdot
.54879 .60881 Mdot
.21852 .38783 Mdot
.30593 .50988 Mdot
.49673 .45082 Mdot
.40155 .37167 Mdot
.40703 .35236 Mdot
.29296 .48427 Mdot
.57459 .60106 Mdot
.39177 .28645 Mdot
.36053 .63057 Mdot
.61109 .59437 Mdot
.54362 .62358 Mdot
.61864 .42472 Mdot
.39617 .33994 Mdot
.77366 .43198 Mdot
.38364 .32505 Mdot
.43617 .32477 Mdot
.62298 .45272 Mdot
.59897 .60273 Mdot
.31232 .52175 Mdot
.30559 .53932 Mdot
.6224 .59742 Mdot
.4635 .55763 Mdot
.6657 .44394 Mdot
.35241 .51964 Mdot
.6058 .18426 Mdot
.60051 .63962 Mdot
.54086 .36725 Mdot
.63414 .49911 Mdot
.41296 .29315 Mdot
.5795 .62021 Mdot
.65218 .42143 Mdot
.33073 .52477 Mdot
.29159 .4794 Mdot
.53275 .57483 Mdot
.40632 .30287 Mdot
.33667 .65731 Mdot
.28322 .50922 Mdot
.45803 .42033 Mdot
.57019 .58274 Mdot
.50577 .37868 Mdot
.28362 .51205 Mdot
.80155 .38835 Mdot
.22336 .37532 Mdot
.63506 .42403 Mdot
.55958 .64717 Mdot
.68094 .45075 Mdot
.34151 .64151 Mdot
.28958 .46519 Mdot
.41552 .30507 Mdot
.63636 .70698 Mdot
.18288 .57491 Mdot
.30951 .48796 Mdot
.66125 .43285 Mdot
.55841 .61744 Mdot
.49226 .62462 Mdot
.56873 .57203 Mdot
.52642 .78902 Mdot
.34578 .67111 Mdot
.44704 .31604 Mdot
.38954 .30132 Mdot
.56962 .63952 Mdot
.38903 .63533 Mdot
.33153 .53521 Mdot
.2897 .49662 Mdot
.21324 .70369 Mdot
.54559 .39019 Mdot
.33289 .469 Mdot
.53693 .59535 Mdot
.30637 .53065 Mdot
.80178 .55019 Mdot
.3863 .30435 Mdot
.61464 .6014 Mdot
.2555 .4968 Mdot
.53388 .28374 Mdot
.48798 .44662 Mdot
.57368 .58411 Mdot
.53604 .54951 Mdot
.41691 .33156 Mdot
.46328 .22753 Mdot
.2681 .49582 Mdot
.61024 .58016 Mdot
.36406 .31883 Mdot
.57546 .42339 Mdot
.20865 .62489 Mdot
.66558 .42442 Mdot
.25941 .51671 Mdot
.43015 .33223 Mdot
.60777 .52718 Mdot
.36517 .62831 Mdot
.32826 .53187 Mdot
.25865 .50408 Mdot
.54452 .63963 Mdot
.56216 .55834 Mdot
.53683 .55301 Mdot
.66286 .4405 Mdot
.41982 .34543 Mdot
.56158 .63361 Mdot
.49008 .42057 Mdot
.57745 .62933 Mdot
.4264 .33832 Mdot
.36795 .87158 Mdot
.52527 .60643 Mdot
.5421 .59499 Mdot
.57425 .72258 Mdot
.62953 .42066 Mdot
.65583 .40237 Mdot
.51296 .43676 Mdot
.53703 .59178 Mdot
.42829 .42485 Mdot
.66271 .42493 Mdot
.67358 .43726 Mdot
.42608 .4273 Mdot
.53778 .63589 Mdot
.35821 .31689 Mdot
.40215 .30534 Mdot
.4087 .35237 Mdot
.65594 .40469 Mdot
.57061 .697 Mdot
.40967 .3554 Mdot
.69727 .66004 Mdot
.32236 .51903 Mdot
.47418 .54896 Mdot
.68032 .40143 Mdot
.45146 .45148 Mdot
.39133 .34444 Mdot
.84486 .44664 Mdot
.6172 .74729 Mdot
.61442 .61249 Mdot
.5951 .60983 Mdot
.35325 .64819 Mdot
.50609 .65826 Mdot
.54414 .38079 Mdot
.41252 .30985 Mdot
.31333 .34337 Mdot
.67127 .4221 Mdot
.54858 .57998 Mdot
.39519 .7373 Mdot
.78505 .39402 Mdot
.49346 .55641 Mdot
.68006 .43302 Mdot
.67578 .42118 Mdot
.27124 .51398 Mdot
.32092 .52145 Mdot
.60606 .59373 Mdot
.41958 .31611 Mdot
.65322 .45059 Mdot
.40938 .34519 Mdot
.29724 .49297 Mdot
.3226 .51624 Mdot
.52397 .36321 Mdot
.57483 .67859 Mdot
.2943 .48689 Mdot
.48105 .34696 Mdot
.48825 .41943 Mdot
.62004 .42395 Mdot
.29334 .26366 Mdot
.83956 .49796 Mdot
.59076 .71434 Mdot
.37543 .66307 Mdot
.58435 .43912 Mdot
.37676 .32801 Mdot
.57182 .63888 Mdot
.56725 .61385 Mdot
.52933 .3697 Mdot
.37881 .3356 Mdot
.36634 .6528 Mdot
.38613 .3406 Mdot
.37853 .65426 Mdot
.30215 .47457 Mdot
.54238 .61377 Mdot
.59252 .57214 Mdot
.3903 .30997 Mdot
.28227 .522 Mdot
.33062 .50077 Mdot
.39089 .64922 Mdot
.43174 .68204 Mdot
.30313 .49803 Mdot
.68069 .40149 Mdot
.77522 .46827 Mdot
.53903 .37456 Mdot
.56857 .60503 Mdot
.40171 .71917 Mdot
.69693 .61773 Mdot
.57306 .62641 Mdot
.53515 .39078 Mdot
.17959 .67132 Mdot
.54358 .61616 Mdot
.3304 .79952 Mdot
.51793 .36868 Mdot
.64852 .39664 Mdot
.28465 .51832 Mdot
.54237 .39147 Mdot
.62749 .53665 Mdot
.36067 .50653 Mdot
.61387 .63518 Mdot
.66763 .44568 Mdot
.68125 .3911 Mdot
.41052 .50862 Mdot
.5304 .30227 Mdot
.34231 .64938 Mdot
.37167 .64448 Mdot
.31261 .50682 Mdot
.46436 .3381 Mdot
.50853 .63955 Mdot
.36912 .64661 Mdot
.32641 .30149 Mdot
.58059 .64018 Mdot
.37489 .55015 Mdot
.40315 .44546 Mdot
.63871 .40955 Mdot
.62442 .66057 Mdot
.30972 .50915 Mdot
.66185 .43238 Mdot
.41004 .47381 Mdot
.60824 .61605 Mdot
.66891 .42457 Mdot
.41348 .34857 Mdot
.41723 .4042 Mdot
.67211 .39546 Mdot
.46917 .44769 Mdot
.39936 .30936 Mdot
.36157 .55526 Mdot
.48279 .74794 Mdot
.67974 .19073 Mdot
.41583 .31138 Mdot
.29146 .5244 Mdot
.30518 .48494 Mdot
.30148 .50129 Mdot
.67637 .43995 Mdot
.29146 .51014 Mdot
.64709 .43851 Mdot
.43746 .35547 Mdot
.42048 .69024 Mdot
.35731 .64146 Mdot
.32458 .59544 Mdot
.67445 .40759 Mdot
.52303 .31972 Mdot
.23433 .31196 Mdot
.59978 .61686 Mdot
.43461 .30218 Mdot
.39156 .63155 Mdot
.55024 .45682 Mdot
.35475 .65052 Mdot
.28552 .52031 Mdot
.47602 .54732 Mdot
.58131 .58989 Mdot
.73547 .36223 Mdot
.36328 .66471 Mdot
.67951 .43522 Mdot
.53988 .65297 Mdot
.31594 .54352 Mdot
.34672 .63335 Mdot
.38238 .65907 Mdot
.56006 .60009 Mdot
.68088 .39345 Mdot
.31377 .52248 Mdot
.37586 .31869 Mdot
.39915 .66353 Mdot
.52465 .55796 Mdot
.59434 .61606 Mdot
.52227 .62786 Mdot
.50878 .45262 Mdot
.3118 .26376 Mdot
.40294 .31205 Mdot
.42349 .77533 Mdot
.31352 .48708 Mdot
.41853 .75895 Mdot
.62333 .32742 Mdot
.33083 .67633 Mdot
.51752 .37946 Mdot
.51952 .38504 Mdot
.56854 .58896 Mdot
.33714 .23506 Mdot
.47073 .62617 Mdot
.37353 .34667 Mdot
.5363 .37517 Mdot
.33135 .50277 Mdot
.64837 .38403 Mdot
.64448 .63778 Mdot
.59486 .55539 Mdot
.37917 .33777 Mdot
.29583 .49695 Mdot
.37211 .22609 Mdot
.36415 .63542 Mdot
.54308 .45468 Mdot
.58494 .57592 Mdot
.56951 .59512 Mdot
.39994 .32221 Mdot
.41919 .31006 Mdot
.49564 .36169 Mdot
.43766 .51289 Mdot
.62957 .23004 Mdot
.43639 .34548 Mdot
.37055 .22563 Mdot
.73863 .38948 Mdot
.65878 .40693 Mdot
.54314 .37039 Mdot
.42441 .34945 Mdot
.55133 .60778 Mdot
.64377 .4002 Mdot
.4744 .59237 Mdot
.64416 .37564 Mdot
.37588 .55025 Mdot
.44462 .42757 Mdot
.58744 .5752 Mdot
.65962 .45738 Mdot
.66407 .43093 Mdot
.66572 .45912 Mdot
.5388 .38412 Mdot
.5848 .60464 Mdot
.59592 .61957 Mdot
.54411 .61752 Mdot
.49532 .63264 Mdot
.56552 .58635 Mdot
.62399 .32357 Mdot
.49338 .41442 Mdot
.24682 .6144 Mdot
.53873 .60513 Mdot
.42769 .33953 Mdot
.54274 .6116 Mdot
.38228 .63066 Mdot
.53819 .58285 Mdot
.37357 .55199 Mdot
.41112 .31755 Mdot
.66344 .59414 Mdot
.33417 .54826 Mdot
.59825 .57847 Mdot
.33908 .65552 Mdot
.31579 .25596 Mdot
.3993 .74955 Mdot
.48336 .36143 Mdot
.67913 .40091 Mdot
.33589 .49374 Mdot
.41982 .29134 Mdot
.31554 .51916 Mdot
.61681 .59874 Mdot
.52442 .36139 Mdot
.81095 .64777 Mdot
.44619 .46297 Mdot
.54949 .60762 Mdot
.5705 .67775 Mdot
.64534 .40285 Mdot
.30339 .51121 Mdot
.71289 .36863 Mdot
.5896 .6396 Mdot
.34485 .62735 Mdot
.36743 .6221 Mdot
.39076 .50965 Mdot
.37201 .37997 Mdot
.63608 .73389 Mdot
.40125 .32067 Mdot
.30075 .4797 Mdot
.34448 .62175 Mdot
.64661 .49044 Mdot
.43904 .31128 Mdot
.41159 .29263 Mdot
.39809 .3408 Mdot
.56252 .58078 Mdot
.53067 .36501 Mdot
.34124 .35417 Mdot
.5383 .39344 Mdot
.60107 .624 Mdot
.25834 .50112 Mdot
.54101 .39404 Mdot
.3488 .64564 Mdot
.43518 .31957 Mdot
.32753 .49823 Mdot
.55568 .59477 Mdot
.66229 .41906 Mdot
.40453 .77707 Mdot
.17895 .44134 Mdot
.34771 .55822 Mdot
.34721 .55827 Mdot
.66532 .38711 Mdot
.68567 .28537 Mdot
.43507 .29329 Mdot
.68408 .5782 Mdot
.41069 .67157 Mdot
.62229 .60013 Mdot
.23177 .6937 Mdot
.26975 .48343 Mdot
.28163 .49737 Mdot
.57916 .5805 Mdot
.30802 .53289 Mdot
.55889 .57362 Mdot
.26805 .50138 Mdot
.58681 .29069 Mdot
.59922 .5555 Mdot
.28343 .50063 Mdot
.50597 .62988 Mdot
.52882 .63135 Mdot
.65166 .39733 Mdot
.32742 .5311 Mdot
.61354 .61474 Mdot
.76703 .71225 Mdot
.39359 .32682 Mdot
.53938 .38323 Mdot
.34065 .56119 Mdot
.38079 .32968 Mdot
.65167 .4441 Mdot
.53315 .59577 Mdot
.35909 .6321 Mdot
.66647 .40634 Mdot
.32509 .54474 Mdot
.35442 .66414 Mdot
.53694 .42798 Mdot
.65819 .40506 Mdot
.5341 .36928 Mdot
.37988 .63532 Mdot
.61337 .63599 Mdot
.28408 .4958 Mdot
.20698 .39858 Mdot
.54026 .39098 Mdot
.58203 .59448 Mdot
.2597 .51868 Mdot
.38601 .34021 Mdot
.60257 .59035 Mdot
.29984 .48106 Mdot
.53821 .38771 Mdot
.53063 .61604 Mdot
.52818 .61146 Mdot
.65713 .62813 Mdot
.43747 .57232 Mdot
.35367 .64163 Mdot
.62975 .46175 Mdot
.60024 .62112 Mdot
.39159 .63829 Mdot
.23379 .39777 Mdot
.61379 .56712 Mdot
.69605 .42213 Mdot
.67273 .64414 Mdot
.3071 .52859 Mdot
.38788 .30286 Mdot
.30673 .53778 Mdot
.35073 .66638 Mdot
.13922 .47575 Mdot
.54405 .37344 Mdot
.56844 .6733 Mdot
.58321 .65142 Mdot
.2794 .4655 Mdot
.66684 .43131 Mdot
.64342 .24152 Mdot
.54244 .57917 Mdot
.60404 .67212 Mdot
.56377 .60325 Mdot
.21786 .40835 Mdot
.67036 .44126 Mdot
.56586 .60487 Mdot
.5204 .55921 Mdot
.59422 .64344 Mdot
.33616 .64736 Mdot
.50895 .73646 Mdot
.55935 .62279 Mdot
.53776 .91759 Mdot
.51299 .36741 Mdot
.2904 .49947 Mdot
.47972 .44815 Mdot
.2852 .56142 Mdot
.44949 .82901 Mdot
.65423 .44192 Mdot
.7236 .43361 Mdot
.31552 .52052 Mdot
.38392 .77248 Mdot
.69084 .29651 Mdot
.52789 .6369 Mdot
.55939 .57004 Mdot
.28563 .52037 Mdot
.31874 .52642 Mdot
.5159 .36216 Mdot
.58015 .56149 Mdot
.59625 .6824 Mdot
.2751 .52652 Mdot
.55159 .59215 Mdot
.71409 .59077 Mdot
.38949 .2911 Mdot
.65443 .40462 Mdot
.38636 .31436 Mdot
.40605 .29239 Mdot
.66133 .69908 Mdot
.52942 .45582 Mdot
.42774 .32565 Mdot
.36917 .31901 Mdot
.36557 .59039 Mdot
.61838 .72649 Mdot
.33654 .64368 Mdot
.39662 .3819 Mdot
.30952 .50256 Mdot
.58436 .60688 Mdot
.68084 .43814 Mdot
.59333 .7961 Mdot
.5436 .19499 Mdot
.49452 .52837 Mdot
.59507 .62497 Mdot
.30522 .50746 Mdot
.53843 .39033 Mdot
.60596 .55786 Mdot
.42684 .76606 Mdot
.57398 .59059 Mdot
.32297 .52131 Mdot
.65161 .7234 Mdot
.55309 .35682 Mdot
.43796 .34221 Mdot
.65398 .37794 Mdot
.54469 .61395 Mdot
.64688 .42507 Mdot
.42759 .3159 Mdot
.39629 .6437 Mdot
.36063 .64773 Mdot
.59523 .57557 Mdot
.41241 .51902 Mdot
.41719 .64927 Mdot
.5285 .63741 Mdot
.54277 .6379 Mdot
.51745 .37697 Mdot
.5425 .637 Mdot
.60698 .57835 Mdot
.565 .63315 Mdot
.60036 .56308 Mdot
.43522 .3339 Mdot
.6797 .35398 Mdot
.55549 .56338 Mdot
.5873 .65381 Mdot
.37893 .30128 Mdot
.59891 .53943 Mdot
.41721 .32762 Mdot
.57522 .19984 Mdot
.4236 .33175 Mdot
.36023 .64649 Mdot
.27004 .52889 Mdot
.73127 .39897 Mdot
.65169 .45021 Mdot
.4289 .33955 Mdot
.38035 .64405 Mdot
.41526 .3128 Mdot
.29201 .4767 Mdot
.25744 .30539 Mdot
.66963 .46699 Mdot
.47731 .40598 Mdot
.59713 .72633 Mdot
.50586 .38119 Mdot
.2932 .52992 Mdot
.63413 .42958 Mdot
.54439 .35102 Mdot
.56675 .63921 Mdot
.35321 .63437 Mdot
.56856 .58978 Mdot
.43566 .31556 Mdot
.30634 .50532 Mdot
.36381 .34261 Mdot
.35325 .64249 Mdot
.15555 .45649 Mdot
.26282 .50099 Mdot
.57637 .6664 Mdot
.38049 .30025 Mdot
.27455 .28606 Mdot
.42136 .32891 Mdot
.42016 .69178 Mdot
.61165 .47061 Mdot
.56359 .8018 Mdot
.67596 .41484 Mdot
.50236 .36555 Mdot
.73297 .27915 Mdot
.65214 .29648 Mdot
.658 .41287 Mdot
.33446 .54874 Mdot
.56177 .58461 Mdot
.57926 .63061 Mdot
.52768 .65771 Mdot
.67747 .3659 Mdot
.6074 .60493 Mdot
.54312 .37725 Mdot
.51797 .44782 Mdot
.31312 .29381 Mdot
.33805 .50004 Mdot
.56422 .57165 Mdot
.41361 .29855 Mdot
.43807 .32116 Mdot
.5376 .39554 Mdot
.38751 .33404 Mdot
.53189 .62967 Mdot
.67489 .40915 Mdot
.40728 .45992 Mdot
.3424 .64056 Mdot
.60233 .32004 Mdot
.41519 .66516 Mdot
.37351 .67647 Mdot
.59839 .64062 Mdot
.32189 .51726 Mdot
.19288 .62781 Mdot
.57685 .63655 Mdot
.66123 .427 Mdot
.57858 .65297 Mdot
.56212 .62957 Mdot
.55876 .62058 Mdot
.30284 .48059 Mdot
.47856 .44374 Mdot
.54954 .59376 Mdot
.42878 .3246 Mdot
.42484 .43022 Mdot
.58738 .55521 Mdot
.32228 .35503 Mdot
.37716 .54989 Mdot
.50647 .37967 Mdot
.62009 .42146 Mdot
.30136 .52182 Mdot
.67292 .42042 Mdot
.70597 .39061 Mdot
.65107 .44397 Mdot
.32273 .33632 Mdot
.68059 .59565 Mdot
.35938 .81881 Mdot
.79111 .56903 Mdot
.65536 .72464 Mdot
.69942 .40074 Mdot
.2759 .38122 Mdot
.6536 .41534 Mdot
.652 .44305 Mdot
.27894 .79807 Mdot
.69197 .42603 Mdot
.57168 .60948 Mdot
.53107 .58796 Mdot
.73888 .34999 Mdot
.36867 .59245 Mdot
.536 .59806 Mdot
.60737 .60129 Mdot
.35457 .62023 Mdot
.63838 .53281 Mdot
.51078 .3625 Mdot
.53804 .4502 Mdot
.54456 .36778 Mdot
.56004 .59935 Mdot
.59209 .57955 Mdot
.52954 .58034 Mdot
.7509 .28651 Mdot
.55923 .81402 Mdot
.6641 .38927 Mdot
.59789 .53395 Mdot
.55195 .39985 Mdot
.56966 .66 Mdot
.58344 .6499 Mdot
.5436 .62037 Mdot
.31301 .52166 Mdot
.64749 .38544 Mdot
.62742 .56834 Mdot
.60851 .35253 Mdot
.58693 .57635 Mdot
.38694 .68009 Mdot
.40262 .63246 Mdot
.57477 .60213 Mdot
.6949 .41693 Mdot
.58756 .62946 Mdot
.67575 .45213 Mdot
.65172 .40773 Mdot
.57346 .68127 Mdot
.34861 .36228 Mdot
.65723 .37934 Mdot
.52697 .63354 Mdot
.28616 .52499 Mdot
.60403 .30875 Mdot
.58079 .59657 Mdot
.3466 .65418 Mdot
.57955 .62092 Mdot
.33743 .65577 Mdot
.54423 .62991 Mdot
.53566 .39423 Mdot
.72188 .4917 Mdot
.31638 .50968 Mdot
.40256 .66168 Mdot
.30371 .53198 Mdot
.60664 .6917 Mdot
.69932 .41769 Mdot
.53112 .35178 Mdot
.54143 .82838 Mdot
.51732 .37462 Mdot
.42309 .78272 Mdot
.42319 .4208 Mdot
.39543 .29693 Mdot
.63947 .45396 Mdot
.649 .72 Mdot
.34721 .38656 Mdot
.32215 .47283 Mdot
.29564 .46845 Mdot
.21566 .64202 Mdot
.18214 .65935 Mdot
.54629 .59406 Mdot
.30087 .2803 Mdot
.73192 .53739 Mdot
.50076 .62635 Mdot
.55492 .55031 Mdot
.26027 .5093 Mdot
.53477 .60002 Mdot
.47679 .47228 Mdot
.30659 .49097 Mdot
.37496 .63957 Mdot
.64114 .42999 Mdot
.38855 .64238 Mdot
.5075 .1847 Mdot
.47918 .36286 Mdot
.29962 .4879 Mdot
.59628 .56036 Mdot
.55419 .58017 Mdot
.62804 .44156 Mdot
.82419 .49193 Mdot
.64929 .40677 Mdot
.34103 .65023 Mdot
.31756 .49794 Mdot
.64013 .75899 Mdot
.57219 .6209 Mdot
.68772 .41431 Mdot
.33112 .54863 Mdot
.59403 .60775 Mdot
.39395 .30129 Mdot
.59355 .62735 Mdot
.68739 .40906 Mdot
.54283 .63651 Mdot
.67368 .41057 Mdot
.27063 .50955 Mdot
.58798 .5688 Mdot
.59503 .5809 Mdot
.42816 .78456 Mdot
.36444 .65365 Mdot
.69923 .41175 Mdot
.47922 .47289 Mdot
.61296 .60026 Mdot
.4305 .76416 Mdot
.54268 .61446 Mdot
.51492 .68882 Mdot
.59502 .54266 Mdot
.54181 .3737 Mdot
.58504 .65036 Mdot
.58029 .59554 Mdot
.81738 .54473 Mdot
.80671 .54362 Mdot
.57245 .71571 Mdot
.41115 .35268 Mdot
.69103 .40701 Mdot
.30229 .48434 Mdot
.33316 .52012 Mdot
.29235 .51402 Mdot
.39031 .60897 Mdot
.57525 .5256 Mdot
.58431 .58931 Mdot
.44949 .33928 Mdot
.36934 .64278 Mdot
.68488 .42585 Mdot
.36255 .64233 Mdot
.53564 .46 Mdot
.3513 .66026 Mdot
.54498 .37883 Mdot
.22534 .37108 Mdot
.70529 .61034 Mdot
.36203 .66014 Mdot
.64995 .40702 Mdot
.44539 .41624 Mdot
.62187 .60444 Mdot
.50598 .28753 Mdot
.34524 .62688 Mdot
.20187 .62433 Mdot
.53243 .61393 Mdot
.4756 .45498 Mdot
.41264 .33015 Mdot
.3881 .64264 Mdot
.39591 .33861 Mdot
.58525 .63048 Mdot
.6622 .35535 Mdot
.65845 .4316 Mdot
.39038 .29194 Mdot
.59161 .64324 Mdot
.38812 .64175 Mdot
.29399 .48866 Mdot
.63315 .7256 Mdot
.37243 .31025 Mdot
.39755 .77247 Mdot
.41578 .75558 Mdot
.31645 .49555 Mdot
.67585 .72342 Mdot
.4082 .33902 Mdot
.62438 .58933 Mdot
.5895 .51097 Mdot
.58679 .63533 Mdot
.33005 .4978 Mdot
.28049 .49917 Mdot
.67334 .32914 Mdot
.59006 .57487 Mdot
.53684 .57651 Mdot
.64599 .38953 Mdot
.31645 .48958 Mdot
.65173 .44522 Mdot
.62979 .43887 Mdot
.28563 .52135 Mdot
.63462 .42387 Mdot
.36624 .66415 Mdot
.52138 .48024 Mdot
.4115 .33863 Mdot
.39908 .30047 Mdot
.29661 .48647 Mdot
.31385 .48015 Mdot
.32485 .51424 Mdot
.58381 .64275 Mdot
.63801 .44089 Mdot
.55753 .64957 Mdot
.54802 .61531 Mdot
.61487 .45561 Mdot
.63378 .40364 Mdot
.57017 .64843 Mdot
.40038 .4385 Mdot
.33325 .64743 Mdot
.28502 .50238 Mdot
.40922 .34648 Mdot
.41816 .79423 Mdot
.38467 .29891 Mdot
.61133 .60235 Mdot
.53344 .28627 Mdot
.67633 .43933 Mdot
.35388 .6497 Mdot
.35562 .55763 Mdot
.35262 .64499 Mdot
.39128 .29112 Mdot
.62309 .42269 Mdot
.52829 .43014 Mdot
.58927 .5729 Mdot
.5116 .4529 Mdot
.46738 .76815 Mdot
.62419 .33237 Mdot
.4191 .34644 Mdot
.6009 .61558 Mdot
.5177 .37038 Mdot
.68686 .5648 Mdot
.58299 .58591 Mdot
.61464 .60295 Mdot
.24112 .55345 Mdot
.59232 .64849 Mdot
.62213 .43683 Mdot
.4022 .52655 Mdot
.59616 .56707 Mdot
.6023 .69314 Mdot
.2149 .71867 Mdot
.53068 .61275 Mdot
.59559 .57918 Mdot
.57643 .61362 Mdot
.57277 .64041 Mdot
.68553 .44754 Mdot
.21135 .5341 Mdot
.42029 .30396 Mdot
.52052 .48031 Mdot
.40421 .34136 Mdot
.28277 .48965 Mdot
.45702 .47977 Mdot
.67857 .45151 Mdot
.35199 .64518 Mdot
.29336 .28341 Mdot
.48476 .53151 Mdot
.27321 .51659 Mdot
.47772 .82284 Mdot
.3425 .63131 Mdot
.62279 .60091 Mdot
.36547 .66661 Mdot
.25847 .50921 Mdot
.40843 .30362 Mdot
.52622 .64389 Mdot
.66694 .44745 Mdot
.6726 .3959 Mdot
.59636 .62576 Mdot
.5959 .3188 Mdot
.37971 .33031 Mdot
.31887 .68945 Mdot
.56826 .57836 Mdot
.61541 .59893 Mdot
.6434 .41058 Mdot
.30268 .50999 Mdot
.42378 .4224 Mdot
.37398 .65185 Mdot
.53802 .65959 Mdot
.58667 .62779 Mdot
.53288 .45977 Mdot
.43332 .33526 Mdot
.53048 .37897 Mdot
.57947 .57511 Mdot
.52697 .44807 Mdot
.61057 .59753 Mdot
.53948 .6856 Mdot
.297 .52866 Mdot
.59573 .67811 Mdot
.56684 .56615 Mdot
.68379 .3573 Mdot
.40292 .33842 Mdot
.66573 .42744 Mdot
.62778 .47976 Mdot
.52826 .39195 Mdot
.39195 .32181 Mdot
.57387 .64734 Mdot
.40969 .29082 Mdot
.56945 .62957 Mdot
.55337 .59399 Mdot
.41828 .34706 Mdot
.64566 .44338 Mdot
.62866 .23767 Mdot
.67872 .35383 Mdot
.55642 .63877 Mdot
.58392 .61914 Mdot
.37439 .5939 Mdot
.60768 .80422 Mdot
.56747 .5653 Mdot
.63465 .43758 Mdot
.59568 .60626 Mdot
.40484 .2983 Mdot
.34269 .65324 Mdot
.65943 .42159 Mdot
.30207 .47701 Mdot
.27041 .50238 Mdot
.24569 .51887 Mdot
.54496 .37576 Mdot
.58079 .56226 Mdot
.62882 .46159 Mdot
.64377 .39443 Mdot
.54772 .47905 Mdot
.28925 .49943 Mdot
.34614 .65974 Mdot
.53232 .60306 Mdot
.64666 .7033 Mdot
.41635 .29668 Mdot
.55139 .91052 Mdot
.52421 .42984 Mdot
.40848 .64014 Mdot
.42388 .53456 Mdot
.51972 .37213 Mdot
.54068 .59478 Mdot
.38591 .63399 Mdot
.27406 .50214 Mdot
.58149 .63056 Mdot
.5439 .54429 Mdot
.35094 .3948 Mdot
.3114 .47614 Mdot
.40197 .29027 Mdot
.27187 .48688 Mdot
.33571 .65334 Mdot
.54449 .37954 Mdot
.67169 .3927 Mdot
.57599 .59566 Mdot
.61136 .67426 Mdot
.29895 .50316 Mdot
.52498 .39386 Mdot
.60102 .57952 Mdot
.6858 .40099 Mdot
.2883 .50729 Mdot
.55662 .60347 Mdot
.6831 .57142 Mdot
.72929 .41101 Mdot
.31281 .49949 Mdot
.53178 .6522 Mdot
.63753 .67001 Mdot
.30553 .47221 Mdot
.25668 .4941 Mdot
.60774 .60201 Mdot
.38584 .64235 Mdot
.57697 .56791 Mdot
.42128 .32313 Mdot
.47807 .44291 Mdot
.39129 .3119 Mdot
.43119 .77099 Mdot
.53913 .56992 Mdot
.48224 .57373 Mdot
.65812 .45607 Mdot
.32926 .66046 Mdot
.81254 .59119 Mdot
.61647 .5887 Mdot
.64455 .22105 Mdot
.45317 .44895 Mdot
.49118 .40224 Mdot
.58025 .17835 Mdot
.37251 .65646 Mdot
.41551 .31598 Mdot
.60077 .58189 Mdot
.45729 .3247 Mdot
.37824 .65631 Mdot
.43253 .77198 Mdot
.56125 .66285 Mdot
.67489 .43617 Mdot
.5689 .58001 Mdot
.68617 .40469 Mdot
.58882 .61114 Mdot
.65293 .5587 Mdot
.39348 .67478 Mdot
.42161 .69048 Mdot
.62374 .60038 Mdot
.29797 .26768 Mdot
.60683 .72727 Mdot
.34398 .6478 Mdot
.5517 .63775 Mdot
.52455 .3756 Mdot
.38863 .34375 Mdot
.26339 .32712 Mdot
.31871 .51896 Mdot
.42714 .32973 Mdot
.63907 .42033 Mdot
.27634 .53033 Mdot
.52245 .39088 Mdot
.58105 .51231 Mdot
.38743 .63944 Mdot
.39337 .32588 Mdot
.578 .598 Mdot
.59649 .6328 Mdot
.21709 .40825 Mdot
.6824 .74907 Mdot
.63199 .43709 Mdot
.16113 .52306 Mdot
.62973 .46007 Mdot
.37023 .64902 Mdot
.30137 .52825 Mdot
.55333 .61073 Mdot
.58732 .58263 Mdot
.31972 .48613 Mdot
.63032 .41668 Mdot
.32943 .6665 Mdot
.57172 .80114 Mdot
.42057 .37521 Mdot
.46365 .70505 Mdot
.65656 .42153 Mdot
.45988 .70276 Mdot
.35404 .61578 Mdot
.34629 .29404 Mdot
.57005 .74002 Mdot
.38921 .3049 Mdot
.4681 .70814 Mdot
.68622 .42683 Mdot
.5449 .59399 Mdot
.53351 .36965 Mdot
.51698 .36593 Mdot
.6439 .42328 Mdot
.29087 .52248 Mdot
.36744 .62883 Mdot
.5729 .58032 Mdot
.54636 .50896 Mdot
.83027 .47165 Mdot
.31328 .48148 Mdot
.56242 .67613 Mdot
.38296 .33314 Mdot
.59198 .61186 Mdot
.36565 .62087 Mdot
.40758 .30744 Mdot
.54686 .39042 Mdot
.48868 .52179 Mdot
.53185 .59797 Mdot
.39679 .53537 Mdot
.40383 .32961 Mdot
.6133 .80208 Mdot
.59501 .58163 Mdot
.40766 .33904 Mdot
.60779 .67694 Mdot
.58082 .36524 Mdot
.41233 .45043 Mdot
.65016 .29218 Mdot
.34274 .5067 Mdot
.26902 .49646 Mdot
.74214 .73036 Mdot
.4101 .67258 Mdot
.43091 .32782 Mdot
.54406 .38483 Mdot
.53493 .74121 Mdot
.39161 .33312 Mdot
.52507 .63855 Mdot
.54004 .61256 Mdot
.653 .72318 Mdot
.59223 .70934 Mdot
.51242 .36333 Mdot
.54552 .52451 Mdot
.53542 .64053 Mdot
.61435 .64194 Mdot
.60338 .59716 Mdot
.67935 .39043 Mdot
.38426 .3105 Mdot
.45754 .12344 Mdot
.42167 .29429 Mdot
.51916 .51509 Mdot
.30936 .50288 Mdot
.33506 .52791 Mdot
.57355 .60199 Mdot
.46478 .63051 Mdot
.33373 .22849 Mdot
.56718 .62119 Mdot
.35794 .55722 Mdot
.41436 .75549 Mdot
.6238 .57127 Mdot
.69104 .38729 Mdot
.59799 .68059 Mdot
.65864 .46654 Mdot
.40647 .30607 Mdot
.37341 .65699 Mdot
.33288 .63522 Mdot
.41652 .32229 Mdot
.58871 .58902 Mdot
.3316 .63264 Mdot
.56789 .59792 Mdot
.55031 .5843 Mdot
.53983 .45606 Mdot
.39718 .63593 Mdot
.32525 .51472 Mdot
.35825 .64709 Mdot
.65845 .44261 Mdot
.29649 .81983 Mdot
.35945 .63652 Mdot
.62055 .72646 Mdot
.46862 .46236 Mdot
.46837 .71113 Mdot
.66752 .39608 Mdot
.34037 .64658 Mdot
.38657 .30505 Mdot
.52878 .42271 Mdot
.67329 .72226 Mdot
.38664 .29789 Mdot
.5831 .58154 Mdot
.67601 .45308 Mdot
.65856 .3889 Mdot
.43528 .34361 Mdot
.64223 .4041 Mdot
.59343 .66273 Mdot
.52633 .6342 Mdot
.42945 .31812 Mdot
.78477 .38397 Mdot
.38604 .30324 Mdot
.64212 .70885 Mdot
.54123 .62254 Mdot
.66054 .42434 Mdot
.50781 .68042 Mdot
.6166 .41154 Mdot
.52396 .36268 Mdot
.53883 .58081 Mdot
.34939 .63817 Mdot
.50855 .47533 Mdot
.31344 .50107 Mdot
.53869 .28462 Mdot
.67924 .4006 Mdot
.44046 .3079 Mdot
.654 .39655 Mdot
.6292 .42969 Mdot
.39091 .29325 Mdot
.66187 .4377 Mdot
.58739 .57757 Mdot
.475 .20954 Mdot
.67557 .40089 Mdot
.40397 .32299 Mdot
.34984 .63347 Mdot
.6344 .42678 Mdot
.3142 .63656 Mdot
.54955 .58158 Mdot
.27996 .52675 Mdot
.4006 .66013 Mdot
.66801 .45772 Mdot
.34396 .65356 Mdot
.29406 .50251 Mdot
.36923 .62827 Mdot
.4537 .35013 Mdot
.44214 .304 Mdot
.49312 .53344 Mdot
.56855 .36522 Mdot
.678 .44178 Mdot
.3448 .50892 Mdot
.54149 .58377 Mdot
.56245 .57883 Mdot
.33542 .66138 Mdot
.67386 .38691 Mdot
.58648 .31581 Mdot
.47903 .62941 Mdot
.60219 .32158 Mdot
.42129 .34998 Mdot
.33066 .72511 Mdot
.52344 .42784 Mdot
.47979 .35363 Mdot
.51648 .61478 Mdot
.52065 .37117 Mdot
.56377 .60393 Mdot
.39846 .74869 Mdot
.33685 .64026 Mdot
.23697 .42485 Mdot
.50861 .6401 Mdot
.32307 .49841 Mdot
.58193 .61606 Mdot
.29386 .29903 Mdot
.58607 .69471 Mdot
.34014 .62954 Mdot
.38658 .28813 Mdot
.65174 .45025 Mdot
.34176 .63756 Mdot
.27065 .50661 Mdot
.47939 .69728 Mdot
.52353 .62506 Mdot
.53214 .63559 Mdot
.28115 .46969 Mdot
.65663 .44607 Mdot
.28253 .49247 Mdot
.41092 .33886 Mdot
.36047 .63898 Mdot
.56845 .64221 Mdot
.59958 .67093 Mdot
.27494 .46679 Mdot
.43096 .30319 Mdot
.32261 .48443 Mdot
.41353 .29239 Mdot
.52288 .36906 Mdot
.59275 .5623 Mdot
.26493 .47428 Mdot
.51544 .6067 Mdot
.80014 .52288 Mdot
.52649 .4857 Mdot
.78239 .62529 Mdot
.32531 .51535 Mdot
.42926 .63636 Mdot
.41239 .32099 Mdot
.39547 .33118 Mdot
.65742 .7047 Mdot
.33289 .23452 Mdot
.42795 .42509 Mdot
.23627 .32673 Mdot
.41228 .33858 Mdot
.39804 .32603 Mdot
.27754 .50735 Mdot
.65061 .43923 Mdot
.70917 .40105 Mdot
.25546 .50866 Mdot
.40245 .71878 Mdot
.68521 .42535 Mdot
.67871 .24806 Mdot
.27194 .47813 Mdot
.52177 .60659 Mdot
.53044 .35392 Mdot
.34193 .62839 Mdot
.40001 .74069 Mdot
.25067 .31645 Mdot
.56068 .61 Mdot
.30819 .78008 Mdot
.30628 .52085 Mdot
.42449 .38507 Mdot
.35418 .26628 Mdot
.60485 .62251 Mdot
.58182 .61357 Mdot
.59422 .59128 Mdot
.3951 .66124 Mdot
.81522 .48606 Mdot
.55623 .60958 Mdot
.42639 .66792 Mdot
.59968 .55533 Mdot
.2088 .40449 Mdot
.35849 .64685 Mdot
.52302 .79263 Mdot
.33888 .53477 Mdot
.60192 .3481 Mdot
.60083 .63647 Mdot
.41598 .33506 Mdot
.3738 .41702 Mdot
.42676 .33902 Mdot
.34019 .28193 Mdot
.56446 .74377 Mdot
.68291 .39114 Mdot
.5934 .62819 Mdot
.26702 .47961 Mdot
.67257 .45493 Mdot
.38584 .42813 Mdot
.26105 .78677 Mdot
.43039 .34492 Mdot
.13853 .57664 Mdot
.38766 .31974 Mdot
.51565 .36543 Mdot
.6425 .41669 Mdot
.46872 .66594 Mdot
.51723 .45463 Mdot
.65049 .44475 Mdot
.26601 .65129 Mdot
.69874 .44544 Mdot
.45284 .67988 Mdot
.67874 .4647 Mdot
.40755 .31825 Mdot
.43855 .30006 Mdot
.56014 .53866 Mdot
.55509 .5697 Mdot
.50455 .44681 Mdot
.54042 .55976 Mdot
.53721 .59027 Mdot
.30686 .49091 Mdot
.56182 .35511 Mdot
.45548 .3114 Mdot
.65161 .42303 Mdot
.42662 .30538 Mdot
.58086 .61536 Mdot
.5558 .63896 Mdot
.57985 .65847 Mdot
.39233 .77773 Mdot
.67454 .24331 Mdot
.54975 .59544 Mdot
.58382 .69327 Mdot
.277 .51899 Mdot
.21477 .41007 Mdot
.17376 .51256 Mdot
.54701 .74005 Mdot
.60254 .57953 Mdot
.36283 .65232 Mdot
.35291 .61988 Mdot
.58927 .65925 Mdot
.47955 .57216 Mdot
.31332 .62956 Mdot
.57827 .59805 Mdot
.45081 .65511 Mdot
.30103 .46356 Mdot
.52967 .39545 Mdot
.29848 .50278 Mdot
.67219 .45635 Mdot
.51636 .37321 Mdot
.29069 .48119 Mdot
.44619 .62828 Mdot
.53046 .39157 Mdot
.5836 .36294 Mdot
.34048 .64915 Mdot
.60231 .59025 Mdot
.72182 .38006 Mdot
.31395 .48444 Mdot
.39975 .33031 Mdot
.66683 .41147 Mdot
.39567 .35128 Mdot
.21552 .39011 Mdot
.40557 .72927 Mdot
.54267 .372 Mdot
.41935 .33292 Mdot
.42113 .49985 Mdot
.36269 .6509 Mdot
.38555 .3272 Mdot
.47435 .59413 Mdot
.57075 .55594 Mdot
.38987 .19803 Mdot
.53626 .64601 Mdot
.68069 .31978 Mdot
.40411 .33432 Mdot
.55118 .38736 Mdot
.57551 .59416 Mdot
.2637 .50218 Mdot
.61235 .54272 Mdot
.56678 .59703 Mdot
.28063 .47744 Mdot
.54628 .59554 Mdot
.39085 .6335 Mdot
.6559 .46541 Mdot
.45234 .45742 Mdot
.37235 .75367 Mdot
.35707 .62723 Mdot
.58126 .47981 Mdot
.56173 .5658 Mdot
.23514 .6243 Mdot
.67257 .43572 Mdot
.61496 .59434 Mdot
.44795 .79495 Mdot
.64632 .43188 Mdot
.67401 .42021 Mdot
.54442 .64142 Mdot
.38383 .30351 Mdot
.32859 .49769 Mdot
.36063 .65018 Mdot
.46484 .34416 Mdot
.55456 .60466 Mdot
.60286 .61233 Mdot
.34224 .63254 Mdot
.39361 .32201 Mdot
.56818 .64415 Mdot
.58674 .26056 Mdot
.54469 .48185 Mdot
.41068 .29316 Mdot
.58616 .55537 Mdot
.4858 .14871 Mdot
.7111 .40245 Mdot
.32037 .791 Mdot
.41175 .666 Mdot
.29133 .5251 Mdot
.53699 .66644 Mdot
.50956 .92135 Mdot
.34166 .64489 Mdot
.60951 .33886 Mdot
.55061 .58977 Mdot
.55349 .61386 Mdot
.69093 .39867 Mdot
.56159 .65172 Mdot
.69184 .41716 Mdot
.35252 .74667 Mdot
.29891 .24265 Mdot
.64577 .40192 Mdot
.69052 .41178 Mdot
.58892 .70399 Mdot
.40096 .78822 Mdot
.63964 .42802 Mdot
.52362 .62373 Mdot
.25274 .62592 Mdot
.52896 .55481 Mdot
.40084 .63324 Mdot
.32466 .60741 Mdot
.69399 .39127 Mdot
.71363 .69434 Mdot
.58513 .70325 Mdot
.665 .6102 Mdot
.34322 .60862 Mdot
.42265 .3377 Mdot
.55381 .62682 Mdot
.54613 .37956 Mdot
.28493 .50734 Mdot
.61833 .64856 Mdot
.59798 .58656 Mdot
.69046 .43392 Mdot
.37768 .66785 Mdot
.39067 .33472 Mdot
.60722 .59509 Mdot
.25666 .47393 Mdot
.37767 .64359 Mdot
.66996 .40105 Mdot
.62778 .72015 Mdot
.33652 .6281 Mdot
.59061 .67653 Mdot
.53851 .60178 Mdot
.60723 .58613 Mdot
.50224 .60109 Mdot
.41568 .3252 Mdot
.26144 .51893 Mdot
.53679 .66491 Mdot
.53582 .43857 Mdot
.49881 .48453 Mdot
.55952 .67075 Mdot
.63365 .43473 Mdot
.41808 .3502 Mdot
.53502 .38646 Mdot
.49331 .72919 Mdot
.53476 .61722 Mdot
.66136 .23035 Mdot
.51684 .82602 Mdot
.52849 .3881 Mdot
.69835 .43507 Mdot
.35427 .64833 Mdot
.53681 .63245 Mdot
.41743 .68255 Mdot
.5265 .6402 Mdot
.52345 .55302 Mdot
.29872 .52462 Mdot
.41565 .34356 Mdot
.56625 .49649 Mdot
.28313 .50594 Mdot
.67329 .42038 Mdot
.73347 .32181 Mdot
.70908 .41687 Mdot
.62982 .43521 Mdot
.34465 .35196 Mdot
.41514 .30707 Mdot
.5231 .92256 Mdot
.60112 .81037 Mdot
.52665 .59756 Mdot
.41852 .30569 Mdot
.6452 .41688 Mdot
.57203 .65319 Mdot
.68176 .43625 Mdot
.65886 .37989 Mdot
.5348 .59709 Mdot
.53785 .59162 Mdot
.42798 .6827 Mdot
.69183 .26267 Mdot
.35421 .63412 Mdot
.64574 .39869 Mdot
.67911 .66721 Mdot
.55076 .60859 Mdot
.58617 .57251 Mdot
.3636 .40573 Mdot
.33968 .64236 Mdot
.70939 .57476 Mdot
.56128 .58097 Mdot
.43623 .79804 Mdot
.5391 .58314 Mdot
.702 .3851 Mdot
.41654 .35964 Mdot
.50491 .53441 Mdot
.33136 .50051 Mdot
.63697 .45285 Mdot
.33654 .6598 Mdot
.62149 .4123 Mdot
.68795 .6195 Mdot
.40836 .30487 Mdot
.68773 .40948 Mdot
.29596 .53854 Mdot
.39604 .31341 Mdot
.39058 .30106 Mdot
.39011 .43152 Mdot
.29115 .53581 Mdot
.39999 .65371 Mdot
.39635 .3468 Mdot
.68147 .57242 Mdot
.40567 .31564 Mdot
.68869 .61077 Mdot
.58704 .56586 Mdot
.43123 .65995 Mdot
.5479 .50245 Mdot
.54641 .54558 Mdot
.38363 .31703 Mdot
.37402 .63373 Mdot
.57937 .64423 Mdot
.63882 .40852 Mdot
.36608 .634 Mdot
.45784 .3727 Mdot
.33497 .53179 Mdot
.66334 .38635 Mdot
.3896 .28869 Mdot
.68907 .43015 Mdot
.40925 .75003 Mdot
.34319 .67944 Mdot
.38557 .44225 Mdot
.50969 .45568 Mdot
.61811 .62852 Mdot
.59795 .69786 Mdot
.59115 .64175 Mdot
.59006 .58463 Mdot
.31204 .49953 Mdot
.39417 .61119 Mdot
.63414 .42703 Mdot
.83308 .45304 Mdot
.41592 .33236 Mdot
.40408 .52618 Mdot
.53573 .54078 Mdot
.57375 .63029 Mdot
.65313 .4124 Mdot
.64265 .38724 Mdot
.80707 .54478 Mdot
.32107 .48662 Mdot
.52579 .55951 Mdot
.60461 .63553 Mdot
.61588 .52132 Mdot
.38725 .31057 Mdot
.60902 .25128 Mdot
.33657 .50781 Mdot
.14336 .62354 Mdot
.28403 .50186 Mdot
.23107 .5657 Mdot
.66072 .43792 Mdot
.35194 .66223 Mdot
.57642 .5723 Mdot
.59606 .41581 Mdot
.69123 .44112 Mdot
.34997 .49892 Mdot
.34957 .64586 Mdot
.62391 .24304 Mdot
.42562 .31784 Mdot
.60135 .57191 Mdot
.53539 .58829 Mdot
.55374 .64644 Mdot
.56774 .65753 Mdot
.42847 .31284 Mdot
.5292 .64601 Mdot
.37139 .3103 Mdot
.69653 .6187 Mdot
.45368 .79297 Mdot
.25912 .48612 Mdot
.2098 .42265 Mdot
.63011 .43094 Mdot
.68869 .49146 Mdot
.71049 .5905 Mdot
.52749 .48557 Mdot
.44853 .3538 Mdot
.59101 .56386 Mdot
.28947 .52098 Mdot
.30492 .26633 Mdot
.2605 .48585 Mdot
.3865 .15715 Mdot
.64631 .72453 Mdot
.67496 .29454 Mdot
.55535 .65623 Mdot
.25486 .48263 Mdot
.7292 .66546 Mdot
.59771 .67379 Mdot
.3261 .64225 Mdot
.67953 .60594 Mdot
.69725 .34312 Mdot
.34406 .65782 Mdot
.54527 .58632 Mdot
.62974 .40772 Mdot
.58363 .5774 Mdot
.56734 .57246 Mdot
.57033 .62234 Mdot
.40367 .35946 Mdot
.54222 .57274 Mdot
.57661 .56818 Mdot
.67193 .75332 Mdot
.37452 .54584 Mdot
.26896 .51248 Mdot
.79291 .60319 Mdot
.36937 .64236 Mdot
.66889 .45636 Mdot
.45668 .44736 Mdot
.42384 .32325 Mdot
.80545 .54825 Mdot
.54604 .65286 Mdot
.62417 .31804 Mdot
.43548 .29848 Mdot
.38256 .64688 Mdot
.53609 .38913 Mdot
.58653 .21675 Mdot
.31731 .52538 Mdot
.51595 .36083 Mdot
.31415 .50222 Mdot
.76304 .65948 Mdot
.69136 .41163 Mdot
.61735 .63146 Mdot
.39361 .33992 Mdot
.26021 .50844 Mdot
.42214 .67521 Mdot
.59835 .59811 Mdot
.32657 .51384 Mdot
.62441 .61333 Mdot
.49851 .47524 Mdot
.4628 .44351 Mdot
.26456 .51923 Mdot
.42325 .28785 Mdot
.3946 .30921 Mdot
.3495 .66474 Mdot
.65153 .45824 Mdot
.6643 .44651 Mdot
.40232 .30964 Mdot
.20379 .68542 Mdot
.55636 .60527 Mdot
.5431 .60885 Mdot
.53349 .4334 Mdot
.57704 .65175 Mdot
.41599 .6205 Mdot
.51072 .37417 Mdot
.67252 .44841 Mdot
.58681 .6434 Mdot
.56692 .64418 Mdot
.53435 .60745 Mdot
.4092 .72632 Mdot
.29899 .50492 Mdot
.53501 .63894 Mdot
.38675 .63644 Mdot
.49598 .36119 Mdot
.54413 .58055 Mdot
.60676 .66039 Mdot
.69116 .42179 Mdot
.20764 .62456 Mdot
.4048 .33263 Mdot
.31851 .48975 Mdot
.27903 .47337 Mdot
.46271 .75681 Mdot
.6613 .3695 Mdot
.5108 .36394 Mdot
.23553 .37901 Mdot
.54172 .38473 Mdot
.34799 .6521 Mdot
.41532 .43733 Mdot
.29735 .45913 Mdot
.26812 .49977 Mdot
.40552 .28143 Mdot
.60124 .62286 Mdot
.53725 .5884 Mdot
.60116 .34169 Mdot
.55742 .61859 Mdot
.34748 .63905 Mdot
.37881 .30631 Mdot
.69016 .41562 Mdot
.36903 .62217 Mdot
.39309 .33012 Mdot
.65422 .44635 Mdot
.61534 .56299 Mdot
.54387 .66386 Mdot
.67061 .41284 Mdot
.66805 .39915 Mdot
.57581 .60772 Mdot
.7157 .73232 Mdot
.66803 .45021 Mdot
.66031 .40858 Mdot
.52215 .41069 Mdot
.30276 .53077 Mdot
.51465 .68019 Mdot
.41646 .30492 Mdot
.58678 .57511 Mdot
.25922 .48364 Mdot
.35644 .65975 Mdot
.67936 .41432 Mdot
.54988 .62633 Mdot
.55475 .59876 Mdot
.36079 .65246 Mdot
.39024 .62741 Mdot
.34801 .63174 Mdot
.40469 .35761 Mdot
.52725 .63512 Mdot
.63791 .42749 Mdot
.42592 .31717 Mdot
.34566 .62365 Mdot
.37353 .66566 Mdot
.67223 .7459 Mdot
.56362 .60931 Mdot
.33094 .62952 Mdot
.35737 .86423 Mdot
.49091 .70903 Mdot
.51527 .37672 Mdot
.26671 .46622 Mdot
.4227 .64383 Mdot
.39354 .66557 Mdot
.42962 .33361 Mdot
.38114 .54643 Mdot
.34982 .66984 Mdot
.558 .62169 Mdot
.5926 .61496 Mdot
.51475 .62896 Mdot
.37042 .63749 Mdot
.41104 .73748 Mdot
.64574 .39521 Mdot
.7404 .50903 Mdot
.36926 .64219 Mdot
.26951 .52298 Mdot
.26651 .46973 Mdot
.2816 .4993 Mdot
.60235 .56776 Mdot
.81337 .56705 Mdot
.6895 .64679 Mdot
.71295 .56187 Mdot
.42694 .32565 Mdot
.64498 .3863 Mdot
.36015 .3362 Mdot
.67469 .42023 Mdot
.29586 .51445 Mdot
.3782 .64063 Mdot
.6896 .39638 Mdot
.39299 .3008 Mdot
.39236 .30784 Mdot
.3257 .4853 Mdot
.29384 .50005 Mdot
.29725 .48809 Mdot
.64146 .45587 Mdot
.66146 .43796 Mdot
.5626 .64161 Mdot
.68029 .40906 Mdot
.52539 .83092 Mdot
.41298 .65104 Mdot
.30493 .46837 Mdot
.40859 .32786 Mdot
.65765 .40559 Mdot
.60139 .58722 Mdot
.26052 .56294 Mdot
.34666 .49372 Mdot
.36097 .62439 Mdot
.45412 .23645 Mdot
.26677 .25516 Mdot
.59673 .55804 Mdot
.43264 .3076 Mdot
.48017 .57467 Mdot
.59277 .59651 Mdot
.30794 .52466 Mdot
.54325 .80418 Mdot
.53796 .39231 Mdot
.56325 .56961 Mdot
.61453 .60759 Mdot
.384 .30623 Mdot
.45929 .44629 Mdot
.56302 .6228 Mdot
.4096 .47509 Mdot
.43749 .3311 Mdot
.33651 .50644 Mdot
.75604 .72922 Mdot
.43357 .38284 Mdot
.36751 .72523 Mdot
.5215 .38819 Mdot
.55262 .61908 Mdot
.3086 .49253 Mdot
.37549 .62765 Mdot
.30263 .496 Mdot
.70087 .43259 Mdot
.30753 .52841 Mdot
.60063 .60637 Mdot
.63915 .43204 Mdot
.39281 .32385 Mdot
.40049 .53445 Mdot
.69398 .7273 Mdot
.2642 .50327 Mdot
.53458 .39864 Mdot
.54154 .58717 Mdot
.68033 .54247 Mdot
.56556 .53639 Mdot
.5649 .5664 Mdot
.42082 .34579 Mdot
.65127 .417 Mdot
.42108 .34969 Mdot
.62877 .5862 Mdot
.68771 .4806 Mdot
.41776 .32995 Mdot
.6626 .35242 Mdot
.34185 .632 Mdot
.40175 .72031 Mdot
.57812 .58651 Mdot
.39585 .34092 Mdot
.52774 .63055 Mdot
.64721 .39723 Mdot
.48876 .51043 Mdot
.59745 .49589 Mdot
.3826 .33321 Mdot
.70163 .32014 Mdot
.4798 .47424 Mdot
.53064 .69099 Mdot
.40511 .34021 Mdot
.8122 .58942 Mdot
.52633 .3781 Mdot
.37066 .65399 Mdot
.37492 .62065 Mdot
.38682 .65428 Mdot
.55343 .61674 Mdot
.66305 .57193 Mdot
.38886 .65863 Mdot
.41135 .35611 Mdot
.39605 .64508 Mdot
.40409 .77959 Mdot
.59428 .31768 Mdot
.35125 .62762 Mdot
.57375 .58642 Mdot
.62487 .62562 Mdot
.37515 .55073 Mdot
.31864 .53701 Mdot
.62235 .2212 Mdot
.65164 .75653 Mdot
.55466 .61139 Mdot
.66172 .55181 Mdot
.70435 .40977 Mdot
.43589 .57848 Mdot
.60421 .50113 Mdot
.4467 .4196 Mdot
.66014 .40646 Mdot
.48456 .44659 Mdot
.66667 .4533 Mdot
.62601 .59013 Mdot
.5541 .5931 Mdot
.67803 .45688 Mdot
.52111 .28038 Mdot
.83881 .52461 Mdot
.60624 .31781 Mdot
.64169 .44445 Mdot
.40244 .33833 Mdot
.43666 .32021 Mdot
.4192 .34609 Mdot
.30944 .48449 Mdot
.68079 .39954 Mdot
.53377 .62337 Mdot
.27283 .51105 Mdot
.5698 .57508 Mdot
.39885 .30534 Mdot
.5446 .48434 Mdot
.69068 .41611 Mdot
.57947 .59585 Mdot
.68104 .70451 Mdot
.31058 .50845 Mdot
.36537 .65065 Mdot
.46422 .22702 Mdot
.28509 .46126 Mdot
.41702 .29105 Mdot
.6716 .37572 Mdot
.26061 .52955 Mdot
.20577 .52645 Mdot
.52418 .60291 Mdot
.52453 .60873 Mdot
.33182 .55909 Mdot
.69364 .70771 Mdot
.57475 .62582 Mdot
.2704 .50465 Mdot
.2954 .53157 Mdot
.52782 .62358 Mdot
.66684 .39409 Mdot
.38186 .66485 Mdot
.33496 .66089 Mdot
.62032 .61389 Mdot
.50331 .45057 Mdot
.42942 .66314 Mdot
.57163 .64678 Mdot
.52183 .66389 Mdot
.30605 .53983 Mdot
.5224 .39056 Mdot
.52923 .45958 Mdot
.37025 .66369 Mdot
.55115 .58771 Mdot
.82749 .47892 Mdot
.68168 .40405 Mdot
.33007 .50373 Mdot
.40986 .29623 Mdot
.33241 .6315 Mdot
.32101 .47683 Mdot
.52785 .62325 Mdot
.56765 .64428 Mdot
.38779 .33376 Mdot
.69846 .38263 Mdot
.37404 .63757 Mdot
.27371 .51331 Mdot
.35099 .66223 Mdot
.66515 .4387 Mdot
.66867 .40419 Mdot
.6062 .63595 Mdot
.54784 .54575 Mdot
.26632 .48691 Mdot
.52757 .65383 Mdot
.27722 .49531 Mdot
.21668 .40826 Mdot
.41763 .29761 Mdot
.61099 .6115 Mdot
.64605 .37475 Mdot
.39925 .3062 Mdot
.56502 .61451 Mdot
.33005 .55897 Mdot
.57938 .63438 Mdot
.25418 .50136 Mdot
.57403 .79479 Mdot
.37451 .65948 Mdot
.63649 .64819 Mdot
.52245 .70339 Mdot
.57958 .64956 Mdot
.30149 .53501 Mdot
.67277 .60785 Mdot
.41905 .32606 Mdot
.6542 .43381 Mdot
.19987 .63412 Mdot
.40428 .32059 Mdot
.56712 .58341 Mdot
.36064 .63682 Mdot
.64847 .45045 Mdot
.52963 .36558 Mdot
.50576 .43496 Mdot
.62089 .64444 Mdot
.61107 .54655 Mdot
.60815 .59079 Mdot
.23824 .32382 Mdot
.30007 .4903 Mdot
.64961 .4134 Mdot
.43396 .31366 Mdot
.41423 .30985 Mdot
.30301 .51024 Mdot
.68543 .33824 Mdot
.56753 .28917 Mdot
.40257 .88802 Mdot
.31402 .47179 Mdot
.39358 .64699 Mdot
.48913 .50144 Mdot
.27993 .50286 Mdot
.31461 .4907 Mdot
.33041 .53755 Mdot
.59695 .33337 Mdot
.64001 .44199 Mdot
.55278 .59963 Mdot
.62157 .4088 Mdot
.55169 .61807 Mdot
.37105 .72034 Mdot
.4042 .30716 Mdot
.65536 .43511 Mdot
.30851 .65912 Mdot
.59413 .6942 Mdot
.58777 .60538 Mdot
.35197 .71229 Mdot
.63505 .57966 Mdot
.47782 .71703 Mdot
.57712 .66081 Mdot
.30443 .50081 Mdot
.70096 .46564 Mdot
.57195 .67787 Mdot
.67618 .70592 Mdot
.3907 .31202 Mdot
.53815 .36712 Mdot
.62816 .57534 Mdot
.53428 .67992 Mdot
.6465 .45082 Mdot
.69183 .39809 Mdot
.38838 .65949 Mdot
.47693 .21494 Mdot
.39059 .31571 Mdot
.63923 .27437 Mdot
.55811 .56789 Mdot
.44344 .29248 Mdot
.55999 .80267 Mdot
.57244 .61433 Mdot
.39593 .43551 Mdot
.80577 .54681 Mdot
.57721 .62928 Mdot
.71878 .55223 Mdot
.4094 .32413 Mdot
.44156 .79567 Mdot
.5584 .66544 Mdot
.31144 .5227 Mdot
.6523 .43879 Mdot
.66191 .38682 Mdot
.36678 .62381 Mdot
.55955 .82466 Mdot
.38283 .24674 Mdot
.65811 .43783 Mdot
.59683 .59248 Mdot
.40467 .33141 Mdot
.5297 .36395 Mdot
.61524 .66065 Mdot
.33533 .26186 Mdot
.68427 .41013 Mdot
.53839 .66626 Mdot
.62107 .3134 Mdot
.47187 .44363 Mdot
.69322 .25595 Mdot
.40722 .34775 Mdot
.36694 .66479 Mdot
.50931 .59482 Mdot
.23229 .38488 Mdot
.54043 .66171 Mdot
.36968 .72213 Mdot
.66825 .3635 Mdot
.34318 .65389 Mdot
.58954 .59424 Mdot
.56491 .62413 Mdot
.51429 .46594 Mdot
.36842 .61849 Mdot
.56276 .62309 Mdot
.50941 .64675 Mdot
.66624 .44356 Mdot
.51077 .37538 Mdot
.68946 .41766 Mdot
.58507 .58108 Mdot
.57684 .78438 Mdot
.67592 .39212 Mdot
.62557 .22869 Mdot
.40487 .67256 Mdot
.42401 .32481 Mdot
.56109 .67907 Mdot
.58099 .56474 Mdot
.59681 .16981 Mdot
.52219 .36302 Mdot
.17246 .53959 Mdot
.25495 .48391 Mdot
.85622 .56655 Mdot
.29388 .46102 Mdot
.68855 .30176 Mdot
.40053 .51186 Mdot
.51777 .64254 Mdot
.59908 .71222 Mdot
.71107 .55086 Mdot
.44917 .30557 Mdot
.67978 .50819 Mdot
.55485 .56986 Mdot
.54239 .59501 Mdot
.27556 .50725 Mdot
.67587 .33264 Mdot
.50066 .54107 Mdot
.52632 .4587 Mdot
.38092 .64765 Mdot
.66724 .4305 Mdot
.59799 .60861 Mdot
.49182 .26516 Mdot
.26302 .5089 Mdot
.6104 .74135 Mdot
.57813 .59398 Mdot
.50906 .52529 Mdot
.63686 .34856 Mdot
.39436 .32749 Mdot
.26649 .52165 Mdot
.27816 .52953 Mdot
.54722 .61834 Mdot
.42543 .31114 Mdot
.56923 .6378 Mdot
.47953 .48148 Mdot
.61379 .65561 Mdot
.35026 .65618 Mdot
.58744 .57179 Mdot
.55655 .72628 Mdot
.75017 .32002 Mdot
.56114 .69466 Mdot
.63753 .44956 Mdot
.29396 .48561 Mdot
.29431 .50664 Mdot
.66291 .44704 Mdot
.29434 .50731 Mdot
.73974 .51844 Mdot
.65528 .51751 Mdot
.34703 .65277 Mdot
.71267 .61307 Mdot
.37687 .65622 Mdot
.5403 .36872 Mdot
.56782 .6095 Mdot
.29982 .3616 Mdot
.3175 .473 Mdot
.41719 .79306 Mdot
.40579 .31229 Mdot
.51911 .36397 Mdot
.53031 .60395 Mdot
.32763 .62152 Mdot
.29286 .51769 Mdot
.40704 .39966 Mdot
.53931 .61413 Mdot
.63326 .41196 Mdot
.57385 .62947 Mdot
.58472 .54737 Mdot
.51382 .36657 Mdot
.60945 .5962 Mdot
.39326 .33032 Mdot
.68636 .40215 Mdot
.67374 .29972 Mdot
.31356 .4846 Mdot
.5546 .57498 Mdot
.59595 .59298 Mdot
.69921 .40734 Mdot
.531 .58918 Mdot
.42967 .32668 Mdot
.58547 .89805 Mdot
.3411 .63637 Mdot
.52392 .39185 Mdot
.50743 .18471 Mdot
.5951 .62175 Mdot
.57891 .64284 Mdot
.45436 .39744 Mdot
.82576 .48581 Mdot
.41214 .33536 Mdot
.62185 .5657 Mdot
.27511 .52041 Mdot
.37361 .63571 Mdot
.38751 .343 Mdot
.52704 .63825 Mdot
.54315 .59951 Mdot
.34303 .64839 Mdot
.36409 .7137 Mdot
.32514 .66413 Mdot
.4272 .3337 Mdot
.64678 .52285 Mdot
.26661 .56439 Mdot
.56291 .60221 Mdot
.55482 .39184 Mdot
.65696 .41491 Mdot
.41135 .34024 Mdot
.81198 .47519 Mdot
.62536 .59228 Mdot
.39867 .28968 Mdot
.39187 .32164 Mdot
.53307 .58441 Mdot
.66951 .36787 Mdot
.63343 .39119 Mdot
.65666 .41306 Mdot
.45918 .78823 Mdot
.17597 .47722 Mdot
.30055 .48688 Mdot
.40443 .32693 Mdot
.26122 .47973 Mdot
.34592 .66818 Mdot
.50025 .4813 Mdot
.27475 .52563 Mdot
.62805 .425 Mdot
.26605 .47849 Mdot
.5728 .63836 Mdot
.39617 .29903 Mdot
.27373 .47771 Mdot
.57039 .65291 Mdot
.51331 .65703 Mdot
.59527 .70967 Mdot
.38254 .66542 Mdot
.48494 .4456 Mdot
.57375 .58151 Mdot
.53433 .38902 Mdot
.57627 .60423 Mdot
.4303 .32122 Mdot
.38368 .5497 Mdot
.53932 .64654 Mdot
.31573 .47194 Mdot
.18916 .48608 Mdot
.31309 .53297 Mdot
.55545 .55548 Mdot
.58258 .58113 Mdot
.56078 .60439 Mdot
.53547 .59547 Mdot
.70283 .34552 Mdot
.37893 .29233 Mdot
.52363 .5544 Mdot
.31514 .4765 Mdot
.67575 .41643 Mdot
.66882 .38981 Mdot
.44593 .41234 Mdot
.52182 .36054 Mdot
.4207 .3065 Mdot
.55865 .60445 Mdot
.40749 .40115 Mdot
.50578 .42321 Mdot
.61306 .31404 Mdot
.25321 .52663 Mdot
.26797 .49652 Mdot
.62985 .44248 Mdot
.27847 .48127 Mdot
.52573 .63392 Mdot
.52749 .65725 Mdot
.67297 .29593 Mdot
.38268 .35109 Mdot
.37584 .63884 Mdot
.57435 .57403 Mdot
.4078 .70952 Mdot
.27697 .51891 Mdot
.30008 .53862 Mdot
.56583 .63821 Mdot
.69741 .38698 Mdot
.76293 .3018 Mdot
.41296 .30017 Mdot
.67867 .54616 Mdot
.71334 .44309 Mdot
.61395 .5157 Mdot
.41687 .32007 Mdot
.40359 .44539 Mdot
.32875 .5322 Mdot
.62272 .78634 Mdot
.67277 .41148 Mdot
.37532 .64039 Mdot
.57117 .66689 Mdot
.62809 .42561 Mdot
.27039 .47146 Mdot
.67315 .45222 Mdot
.61744 .63227 Mdot
.42261 .35134 Mdot
.28694 .50526 Mdot
.41602 .27853 Mdot
.68361 .4509 Mdot
.3765 .65729 Mdot
.42674 .78205 Mdot
.68516 .56744 Mdot
.8056 .54575 Mdot
.53488 .638 Mdot
.33437 .37323 Mdot
.53476 .62257 Mdot
.62493 .41553 Mdot
.57762 .58631 Mdot
.60606 .68921 Mdot
.33616 .526 Mdot
.57266 .67143 Mdot
.58394 .5699 Mdot
.67181 .70431 Mdot
.58027 .61281 Mdot
.53079 .61064 Mdot
.61654 .60926 Mdot
.70671 .38573 Mdot
.57826 .66902 Mdot
.63313 .41338 Mdot
.61563 .33304 Mdot
.31645 .49229 Mdot
.34368 .66591 Mdot
.33625 .65514 Mdot
.35729 .72259 Mdot
.40676 .71418 Mdot
.6724 .33713 Mdot
.68387 .42486 Mdot
.38533 .31268 Mdot
.56903 .63913 Mdot
.79985 .61434 Mdot
.55299 .7784 Mdot
.33674 .5206 Mdot
.26588 .48265 Mdot
.55523 .66764 Mdot
.31351 .23459 Mdot
.57096 .67026 Mdot
.5261 .43026 Mdot
.54952 .61576 Mdot
.61444 .60239 Mdot
.28387 .53475 Mdot
.40702 .74834 Mdot
.53487 .63887 Mdot
.64787 .45128 Mdot
.37498 .647 Mdot
.58933 .51033 Mdot
.53342 .78602 Mdot
.6455 .70755 Mdot
.47696 .63381 Mdot
.54 .6517 Mdot
.28369 .5214 Mdot
.64189 .44597 Mdot
.53204 .4416 Mdot
.42816 .32679 Mdot
.50218 .44191 Mdot
.69403 .6115 Mdot
.35729 .26806 Mdot
.37752 .64299 Mdot
.35086 .53157 Mdot
.60104 .60683 Mdot
.30705 .48456 Mdot
.62456 .57924 Mdot
.49344 .4113 Mdot
.35018 .65823 Mdot
.64889 .46067 Mdot
.40197 .33792 Mdot
.63212 .40938 Mdot
.78452 .62162 Mdot
.56066 .77968 Mdot
.8564 .56888 Mdot
.32529 .52119 Mdot
.77358 .42966 Mdot
.64331 .42482 Mdot
.53884 .61773 Mdot
.39699 .88453 Mdot
.65704 .42004 Mdot
.63055 .41623 Mdot
.44643 .42614 Mdot
.43073 .77128 Mdot
.55449 .67247 Mdot
.67335 .44951 Mdot
.33374 .54264 Mdot
.35387 .64436 Mdot
.56698 .65283 Mdot
.624 .60632 Mdot
.69079 .39784 Mdot
.29678 .51695 Mdot
.38788 .7233 Mdot
.29892 .50114 Mdot
.63935 .4394 Mdot
.3161 .51 Mdot
.62283 .2338 Mdot
.26768 .51761 Mdot
.58758 .56958 Mdot
.55928 .60364 Mdot
.31253 .31005 Mdot
.66871 .4042 Mdot
.57985 .64304 Mdot
.54761 .59277 Mdot
.63966 .42513 Mdot
.29528 .45848 Mdot
.80027 .45887 Mdot
.58534 .64122 Mdot
.55452 .60253 Mdot
.33786 .64455 Mdot
.48824 .46441 Mdot
.51408 .41752 Mdot
.5723 .64997 Mdot
.38986 .65001 Mdot
.63448 .45031 Mdot
.57733 .60542 Mdot
.4053 .74813 Mdot
.29445 .46312 Mdot
.5504 .65851 Mdot
.53643 .36836 Mdot
.57181 .62365 Mdot
.75734 .30141 Mdot
.54394 .58421 Mdot
.64381 .41475 Mdot
.64705 .4341 Mdot
.3553 .54154 Mdot
.67165 .41988 Mdot
.51527 .37352 Mdot
.39625 .30895 Mdot
.73725 .3293 Mdot
.51573 .37073 Mdot
.61178 .58346 Mdot
.59839 .81257 Mdot
.62149 .61724 Mdot
.60886 .65877 Mdot
.40513 .79252 Mdot
.52009 .38583 Mdot
.64953 .42064 Mdot
.52073 .27615 Mdot
.5265 .64993 Mdot
.41796 .30323 Mdot
.59966 .67123 Mdot
.5497 .65842 Mdot
.60322 .69856 Mdot
.64708 .51355 Mdot
.37853 .30376 Mdot
.51913 .68452 Mdot
.56678 .65258 Mdot
.82501 .48791 Mdot
.60146 .59647 Mdot
.35459 .6251 Mdot
.68091 .43469 Mdot
.28699 .47785 Mdot
.35 .65125 Mdot
.59851 .61397 Mdot
.36954 .63898 Mdot
.30618 .48651 Mdot
.39662 .34466 Mdot
.592 .57313 Mdot
.40086 .63287 Mdot
.37899 .64021 Mdot
.54966 .63514 Mdot
.65516 .43742 Mdot
.57328 .53452 Mdot
.5773 .60761 Mdot
.52758 .61397 Mdot
.6653 .44616 Mdot
.37884 .82759 Mdot
.53599 .60344 Mdot
.40134 .44288 Mdot
.64663 .46866 Mdot
.51195 .37354 Mdot
.27212 .49367 Mdot
.51148 .61459 Mdot
.41443 .30815 Mdot
.39937 .30983 Mdot
.33291 .49145 Mdot
.6954 .40764 Mdot
.28918 .50781 Mdot
.58087 .69922 Mdot
.53002 .65934 Mdot
.56999 .66701 Mdot
.19881 .63265 Mdot
.5783 .20842 Mdot
.65449 .40349 Mdot
.31882 .53461 Mdot
.50938 .44897 Mdot
.40568 .29926 Mdot
.31264 .5418 Mdot
.61843 .42819 Mdot
.69419 .42573 Mdot
.66307 .44842 Mdot
.3876 .6441 Mdot
.28771 .49982 Mdot
.61768 .44571 Mdot
.64046 .38593 Mdot
.5575 .63809 Mdot
.56349 .65313 Mdot
.70271 .43576 Mdot
.34729 .47619 Mdot
.36349 .65961 Mdot
.29205 .52657 Mdot
.70607 .21733 Mdot
.41349 .30017 Mdot
.67158 .70563 Mdot
.57306 .65165 Mdot
.17921 .7082 Mdot
.57533 .66852 Mdot
.59848 .59333 Mdot
.6723 .45634 Mdot
.34241 .62031 Mdot
.35732 .64395 Mdot
.64325 .4261 Mdot
.67628 .37912 Mdot
.3779 .63218 Mdot
.43103 .43078 Mdot
.78027 .35344 Mdot
.52367 .44259 Mdot
.64224 .41245 Mdot
.68888 .56735 Mdot
.38894 .34282 Mdot
.63874 .46311 Mdot
.39448 .28035 Mdot
.31758 .49182 Mdot
.26303 .49883 Mdot
.38526 .33142 Mdot
.53294 .60814 Mdot
.32228 .52035 Mdot
.574 .69973 Mdot
.66749 .27867 Mdot
.3509 .25857 Mdot
.81095 .62484 Mdot
.56646 .5638 Mdot
.48661 .55914 Mdot
.56414 .33981 Mdot
.60801 .60318 Mdot
.50782 .68151 Mdot
.37323 .6382 Mdot
.6461 .46686 Mdot
.37808 .33514 Mdot
.6405 .21715 Mdot
.56175 .603 Mdot
.63424 .42771 Mdot
.40069 .2973 Mdot
.61634 .23737 Mdot
.4095 .47391 Mdot
.56269 .63009 Mdot
.45072 .90634 Mdot
.68556 .44774 Mdot
.28699 .47805 Mdot
.70363 .66793 Mdot
.62362 .43654 Mdot
.23119 .53942 Mdot
.25341 .50945 Mdot
.55895 .4612 Mdot
.68451 .44418 Mdot
.32799 .66476 Mdot
.66913 .43468 Mdot
.38557 .62919 Mdot
.67448 .37579 Mdot
.30717 .51421 Mdot
.58631 .60029 Mdot
.30747 .51099 Mdot
.34243 .62746 Mdot
.33216 .51146 Mdot
.37796 .33478 Mdot
.52572 .39021 Mdot
.39419 .30501 Mdot
.49659 .48743 Mdot
.78885 .48612 Mdot
.41566 .34376 Mdot
.39403 .40838 Mdot
.57979 .62366 Mdot
.70238 .38556 Mdot
.29531 .47719 Mdot
.33655 .48747 Mdot
.49191 .44758 Mdot
.64826 .44393 Mdot
.30703 .5183 Mdot
.68509 .5759 Mdot
.20568 .69472 Mdot
.56461 .68463 Mdot
.17685 .45797 Mdot
.63936 .42211 Mdot
.33122 .53316 Mdot
.5321 .43246 Mdot
.67532 .38739 Mdot
.2691 .48232 Mdot
.40102 .33988 Mdot
.41776 .31281 Mdot
.53384 .58547 Mdot
.43292 .34746 Mdot
.29849 .53528 Mdot
.82779 .48195 Mdot
.67622 .44047 Mdot
.55673 .19745 Mdot
.35532 .62766 Mdot
.3128 .48877 Mdot
.56417 .67316 Mdot
.63177 .38217 Mdot
.28101 .47152 Mdot
.33573 .24082 Mdot
.65291 .18791 Mdot
.30722 .5188 Mdot
.6818 .43358 Mdot
.67961 .41719 Mdot
.56524 .69413 Mdot
.51382 .45468 Mdot
.2978 .5191 Mdot
.29838 .36055 Mdot
.41679 .69176 Mdot
.52282 .36888 Mdot
.66146 .75523 Mdot
.53411 .63852 Mdot
.54132 .65295 Mdot
.42912 .33029 Mdot
.58793 .60822 Mdot
.65951 .37927 Mdot
.57631 .66643 Mdot
.43629 .33098 Mdot
.33575 .50386 Mdot
.56606 .60685 Mdot
.36974 .63224 Mdot
.41874 .34865 Mdot
.43479 .30558 Mdot
.3193 .50251 Mdot
.67668 .44338 Mdot
.50528 .28683 Mdot
.29678 .50129 Mdot
.52885 .63989 Mdot
.52698 .38525 Mdot
.58149 .65712 Mdot
.31544 .31902 Mdot
.64355 .39607 Mdot
.27918 .48111 Mdot
.68867 .45202 Mdot
.39981 .32506 Mdot
.34189 .51026 Mdot
.60471 .5998 Mdot
.2658 .49637 Mdot
.39048 .44686 Mdot
.23561 .59971 Mdot
.65376 .37961 Mdot
.36226 .55457 Mdot
.69474 .40059 Mdot
.52349 .36806 Mdot
.45982 .74682 Mdot
.36807 .65611 Mdot
.29206 .52948 Mdot
.62143 .22525 Mdot
.30199 .47652 Mdot
.5776 .61511 Mdot
.54018 .60399 Mdot
.27485 .5053 Mdot
.38304 .65385 Mdot
.35649 .73965 Mdot
.41481 .64425 Mdot
.68321 .40319 Mdot
.41469 .51556 Mdot
.739 .25111 Mdot
.2411 .50456 Mdot
.38462 .31728 Mdot
.48421 .63143 Mdot
.58366 .62885 Mdot
.38758 .29795 Mdot
.42514 .30376 Mdot
.34822 .62233 Mdot
.31294 .48577 Mdot
.63016 .46338 Mdot
.37958 .33133 Mdot
.61488 .40482 Mdot
.39215 .7334 Mdot
.62166 .56151 Mdot
.63463 .53572 Mdot
.59615 .5671 Mdot
.47226 .44332 Mdot
.43295 .33709 Mdot
.56668 .58662 Mdot
.50197 .63471 Mdot
.41612 .33736 Mdot
.3563 .62036 Mdot
.60687 .45648 Mdot
.31415 .5181 Mdot
.19033 .69766 Mdot
.59076 .57268 Mdot
.58279 .60358 Mdot
.42682 .32504 Mdot
.70347 .70152 Mdot
.65 .40348 Mdot
.67964 .44103 Mdot
.29927 .48992 Mdot
.47868 .40437 Mdot
.52908 .59182 Mdot
.60192 .5836 Mdot
.31807 .52125 Mdot
.53388 .38841 Mdot
.75722 .70726 Mdot
.55696 .59715 Mdot
.41279 .32349 Mdot
.37456 .41792 Mdot
.42814 .34402 Mdot
.606 .56108 Mdot
.57304 .61691 Mdot
.604 .57806 Mdot
.55618 .56387 Mdot
.38098 .32553 Mdot
.60751 .59487 Mdot
.60793 .54187 Mdot
.65236 .41741 Mdot
.53641 .64669 Mdot
.41906 .69089 Mdot
.56114 .59782 Mdot
.36821 .63224 Mdot
.49853 .40297 Mdot
.5525 .57752 Mdot
.53604 .64716 Mdot
.41483 .69081 Mdot
.5907 .59086 Mdot
.39504 .29688 Mdot
.67624 .4118 Mdot
.4002 .32693 Mdot
.38735 .31704 Mdot
.27266 .47456 Mdot
.38567 .62695 Mdot
.51037 .6413 Mdot
.3825 .63423 Mdot
.5814 .69514 Mdot
.62623 .60146 Mdot
.49447 .47558 Mdot
.52459 .43027 Mdot
.35279 .67154 Mdot
.60448 .59159 Mdot
.30533 .49101 Mdot
.27508 .48336 Mdot
.38084 .5465 Mdot
.60444 .67173 Mdot
.38239 .33828 Mdot
.39632 .34101 Mdot
.41942 .62324 Mdot
.39809 .59116 Mdot
.37884 .63742 Mdot
.47309 .53631 Mdot
.61923 .58148 Mdot
.54619 .58783 Mdot
.62077 .63502 Mdot
.25497 .48825 Mdot
.52603 .39134 Mdot
.3319 .49633 Mdot
.52385 .40914 Mdot
.39569 .35066 Mdot
.56673 .56394 Mdot
.37267 .22551 Mdot
.67741 .39508 Mdot
.67623 .41083 Mdot
.43741 .32853 Mdot
.3111 .5336 Mdot
.61227 .65883 Mdot
.15347 .55722 Mdot
.66611 .38323 Mdot
.34796 .66646 Mdot
.58554 .57794 Mdot
.31746 .4972 Mdot
.68978 .40424 Mdot
.40174 .64298 Mdot
.5771 .563 Mdot
.26904 .52998 Mdot
.57068 .59083 Mdot
.72611 .57477 Mdot
.65128 .42665 Mdot
.54596 .47892 Mdot
.71013 .4081 Mdot
.38372 .31133 Mdot
.40623 .33508 Mdot
.56647 .61505 Mdot
.16394 .62245 Mdot
.62802 .48071 Mdot
.39141 .29104 Mdot
.39933 .64615 Mdot
.53152 .39274 Mdot
.39965 .64253 Mdot
.27704 .49679 Mdot
.37641 .64679 Mdot
.28399 .47126 Mdot
.33683 .46496 Mdot
.64632 .47723 Mdot
.34369 .64517 Mdot
.70362 .70876 Mdot
.52663 .6566 Mdot
.34148 .6257 Mdot
.56281 .66757 Mdot
.59526 .69759 Mdot
.32433 .51416 Mdot
.38539 .64254 Mdot
.54964 .62682 Mdot
.50761 .18018 Mdot
.39423 .33012 Mdot
.37891 .33489 Mdot
.52645 .65525 Mdot
.32902 .53665 Mdot
.66639 .37633 Mdot
.45792 .46108 Mdot
.51462 .38312 Mdot
.60102 .58301 Mdot
.59563 .56319 Mdot
.69162 .44423 Mdot
.62968 .43409 Mdot
.5669 .61648 Mdot
.67339 .55021 Mdot
.60126 .6085 Mdot
.41969 .31602 Mdot
.68145 .40046 Mdot
.6793 .41334 Mdot
.2862 .53132 Mdot
.69426 .40542 Mdot
.55005 .53818 Mdot
.44524 .35038 Mdot
.6001 .65384 Mdot
.40143 .32295 Mdot
.36704 .49495 Mdot
.32205 .48877 Mdot
.61804 .22089 Mdot
.69458 .40942 Mdot
.58724 .64314 Mdot
.6682 .39048 Mdot
.3474 .63277 Mdot
.67154 .40399 Mdot
.70559 .41889 Mdot
.54658 .57549 Mdot
.55685 .62219 Mdot
.53239 .3863 Mdot
.50529 .45288 Mdot
.65618 .43037 Mdot
.59701 .62438 Mdot
.58818 .6487 Mdot
.53835 .60924 Mdot
.47948 .47064 Mdot
.66417 .45878 Mdot
.66158 .69886 Mdot
.33006 .30154 Mdot
.65804 .43543 Mdot
.6979 .23857 Mdot
.54321 .38236 Mdot
.52369 .36034 Mdot
.41754 .2873 Mdot
.55318 .60038 Mdot
.29438 .5095 Mdot
.54269 .65487 Mdot
.5987 .68014 Mdot
.55771 .57406 Mdot
.34213 .64904 Mdot
.52328 .606 Mdot
.53426 .37217 Mdot
.30267 .50338 Mdot
.59405 .62676 Mdot
.55913 .60777 Mdot
.533 .36301 Mdot
.70851 .42231 Mdot
.69425 .42377 Mdot
.56659 .38364 Mdot
.3534 .62238 Mdot
.42555 .34075 Mdot
.53276 .64783 Mdot
.30214 .49082 Mdot
.30233 .50926 Mdot
.63157 .41156 Mdot
.30751 .52392 Mdot
.42907 .33868 Mdot
.59953 .59962 Mdot
.38308 .31318 Mdot
.34205 .64867 Mdot
.68041 .4353 Mdot
.52689 .63977 Mdot
.55612 .63583 Mdot
.64704 .43387 Mdot
.5764 .6254 Mdot
.34031 .65065 Mdot
.25669 .49839 Mdot
.66721 .40031 Mdot
.39678 .30982 Mdot
.279 .52824 Mdot
.57084 .64121 Mdot
.53862 .1367 Mdot
.58815 .60907 Mdot
.59955 .57794 Mdot
.71235 .31955 Mdot
.60384 .6324 Mdot
.30999 .48084 Mdot
.67577 .39033 Mdot
.59346 .55695 Mdot
.41285 .69545 Mdot
.32412 .68246 Mdot
.24569 .5062 Mdot
.58783 .57733 Mdot
.67942 .2404 Mdot
.58238 .64804 Mdot
.64259 .24187 Mdot
.49542 .47535 Mdot
.25126 .31911 Mdot
.63555 .5378 Mdot
.39271 .2904 Mdot
.53166 .38873 Mdot
.31394 .48032 Mdot
.74696 .64297 Mdot
.58272 .6179 Mdot
.81293 .53671 Mdot
.53016 .64716 Mdot
.41722 .31832 Mdot
.49932 .66202 Mdot
.29583 .5269 Mdot
.65439 .75442 Mdot
.5311 .62164 Mdot
.67746 .45233 Mdot
.34431 .51552 Mdot
.53851 .39001 Mdot
.54752 .62326 Mdot
.3675 .62698 Mdot
.34827 .68316 Mdot
.54809 .54044 Mdot
.39924 .32145 Mdot
.54864 .58915 Mdot
.52118 .67521 Mdot
.21257 .69032 Mdot
.65374 .41265 Mdot
.38935 .32922 Mdot
.44116 .60426 Mdot
.54028 .60699 Mdot
.69313 .42795 Mdot
.67376 .41315 Mdot
.37775 .62753 Mdot
.47689 .34955 Mdot
.3046 .67916 Mdot
.39921 .19259 Mdot
.80754 .57647 Mdot
.25378 .49324 Mdot
.6231 .37272 Mdot
.54568 .64832 Mdot
.56412 .78074 Mdot
.38831 .3124 Mdot
.58461 .60052 Mdot
.79153 .56814 Mdot
.65961 .40889 Mdot
.56486 .59126 Mdot
.36105 .65913 Mdot
.52749 .31477 Mdot
.68218 .61096 Mdot
.56947 .1587 Mdot
.32847 .54391 Mdot
.58423 .67565 Mdot
.57641 .52729 Mdot
.51238 .37481 Mdot
.60277 .56038 Mdot
.29998 .47851 Mdot
.34233 .37917 Mdot
.37108 .66223 Mdot
.68002 .39628 Mdot
.5428 .38555 Mdot
.53226 .65088 Mdot
.61714 .61693 Mdot
.35431 .66786 Mdot
.54011 .62304 Mdot
.69823 .66605 Mdot
.54007 .36372 Mdot
.2662 .51593 Mdot
.67101 .4528 Mdot
.5984 .56734 Mdot
.53124 .3914 Mdot
.54158 .5816 Mdot
.52556 .71076 Mdot
.5788 .57644 Mdot
.73038 .33811 Mdot
.65323 .43945 Mdot
.3949 .31759 Mdot
.52139 .60928 Mdot
.57008 .59753 Mdot
.27288 .56827 Mdot
.60904 .66502 Mdot
.54209 .58823 Mdot
.62643 .41851 Mdot
.67425 .39298 Mdot
.63276 .42985 Mdot
.27724 .52554 Mdot
.5268 .44796 Mdot
.41023 .31381 Mdot
.61916 .64159 Mdot
.38293 .33707 Mdot
.64316 .55792 Mdot
.37874 .66299 Mdot
.59732 .20316 Mdot
.59397 .61212 Mdot
.65366 .44745 Mdot
.7883 .40092 Mdot
.63193 .44787 Mdot
.36121 .28276 Mdot
.39039 .31381 Mdot
.65765 .42324 Mdot
.59166 .58726 Mdot
.52552 .4606 Mdot
.52392 .1459 Mdot
.40351 .2994 Mdot
.60572 .66022 Mdot
.32826 .54507 Mdot
.32774 .4799 Mdot
.7313 .27608 Mdot
.38901 .30149 Mdot
.55972 .33859 Mdot
.58744 .6404 Mdot
.6843 .39627 Mdot
.41435 .34634 Mdot
.40017 .29322 Mdot
.31242 .52389 Mdot
.56299 .63309 Mdot
.56921 .5958 Mdot
.53923 .37032 Mdot
.38948 .34059 Mdot
.64357 .61245 Mdot
.56617 .62911 Mdot
.68316 .30025 Mdot
.61882 .43308 Mdot
.38825 .8323 Mdot
.55469 .70374 Mdot
.79555 .55975 Mdot
.37899 .48388 Mdot
.66295 .39927 Mdot
.53083 .61378 Mdot
.61599 .6486 Mdot
.25592 .50601 Mdot
.59647 .60249 Mdot
.32803 .52859 Mdot
.38599 .30542 Mdot
.60578 .20252 Mdot
.41239 .40834 Mdot
.44696 .35602 Mdot
.58449 .61023 Mdot
.67959 .60406 Mdot
.34587 .64347 Mdot
.37545 .3432 Mdot
.63714 .41318 Mdot
.61426 .57782 Mdot
.25265 .48754 Mdot
.27719 .52439 Mdot
.66698 .41255 Mdot
.60382 .35214 Mdot
.62733 .22863 Mdot
.56311 .56146 Mdot
.27395 .49458 Mdot
.41471 .38498 Mdot
.68381 .49746 Mdot
.42486 .29333 Mdot
.36622 .66337 Mdot
.3148 .48291 Mdot
.41771 .35737 Mdot
.59839 .69557 Mdot
.66525 .42179 Mdot
.69171 .44172 Mdot
.26389 .55195 Mdot
.302 .51709 Mdot
.35806 .6514 Mdot
.39382 .5336 Mdot
.39789 .53429 Mdot
.35227 .65898 Mdot
.33677 .52121 Mdot
.66717 .39583 Mdot
.63548 .43188 Mdot
.67651 .41335 Mdot
.67636 .70596 Mdot
.65431 .38996 Mdot
.47441 .82219 Mdot
.611 .569 Mdot
.68112 .53906 Mdot
.60486 .61569 Mdot
.37649 .3193 Mdot
.65102 .42829 Mdot
.50398 .4752 Mdot
.61822 .59556 Mdot
.54821 .15475 Mdot
.57506 .58039 Mdot
.38757 .42969 Mdot
.55303 .60165 Mdot
.71118 .63135 Mdot
.64455 .46782 Mdot
.60577 .59547 Mdot
.45037 .33082 Mdot
.3684 .63552 Mdot
.65556 .47861 Mdot
.54345 .5879 Mdot
.62674 .31508 Mdot
.56327 .66721 Mdot
.67082 .25509 Mdot
.21218 .53554 Mdot
.33099 .65209 Mdot
.59357 .64947 Mdot
.29129 .4678 Mdot
.47415 .61689 Mdot
.68956 .55356 Mdot
.40246 .29954 Mdot
.68088 .59229 Mdot
.30776 .52745 Mdot
.51065 .68363 Mdot
.60467 .54949 Mdot
.37928 .65876 Mdot
.61205 .47214 Mdot
.42153 .31929 Mdot
.58335 .61951 Mdot
.53245 .6134 Mdot
.31155 .27579 Mdot
.69558 .5692 Mdot
.63114 .56308 Mdot
.37095 .66773 Mdot
.68703 .60786 Mdot
.55542 .57754 Mdot
.2466 .50748 Mdot
.68005 .38969 Mdot
.49583 .60096 Mdot
.65272 .72441 Mdot
.59887 .61933 Mdot
.65922 .41918 Mdot
.6956 .41101 Mdot
.80763 .41412 Mdot
.38339 .65966 Mdot
.57756 .57662 Mdot
.24647 .54506 Mdot
.52818 .63955 Mdot
.41417 .3138 Mdot
.61693 .56678 Mdot
.32488 .4978 Mdot
.53971 .42943 Mdot
.28003 .52712 Mdot
.54403 .61661 Mdot
.67296 .43523 Mdot
.42482 .32473 Mdot
.22858 .37626 Mdot
.46944 .36459 Mdot
.47016 .8208 Mdot
.35319 .68461 Mdot
.37438 .63211 Mdot
.3974 .63689 Mdot
.37282 .3519 Mdot
.5908 .58108 Mdot
.46493 .44217 Mdot
.58055 .6885 Mdot
.54792 .60197 Mdot
.57479 .57269 Mdot
.45569 .371 Mdot
.39129 .31432 Mdot
.31297 .51197 Mdot
.56824 .61718 Mdot
.59779 .62346 Mdot
.66297 .43312 Mdot
.37949 .6404 Mdot
.25883 .5021 Mdot
.34864 .62582 Mdot
.30442 .49923 Mdot
.75486 .29497 Mdot
.627 .5807 Mdot
.3661 .6353 Mdot
.42365 .34904 Mdot
.63892 .44231 Mdot
.52823 .36241 Mdot
.27795 .49791 Mdot
.2958 .52598 Mdot
.60802 .59685 Mdot
.6867 .43047 Mdot
.69058 .42924 Mdot
.37787 .63256 Mdot
.40083 .34318 Mdot
.54772 .56407 Mdot
.56087 .62469 Mdot
.21042 .40432 Mdot
.25812 .51059 Mdot
.68692 .59181 Mdot
.72937 .34732 Mdot
.59371 .58186 Mdot
.68952 .4341 Mdot
.57079 .60512 Mdot
.36887 .36555 Mdot
.6317 .43446 Mdot
.60737 .62204 Mdot
.62236 .67633 Mdot
.25547 .48846 Mdot
.84513 .48652 Mdot
.51128 .63558 Mdot
.42926 .27838 Mdot
.54532 .6402 Mdot
.87203 .52873 Mdot
.79393 .41392 Mdot
.5281 .64605 Mdot
.55362 .5658 Mdot
.40896 .17962 Mdot
.57514 .65279 Mdot
.53811 .37242 Mdot
.60086 .67854 Mdot
.69274 .43016 Mdot
.40232 .46767 Mdot
.4814 .4448 Mdot
.39397 .64868 Mdot
.29981 .48928 Mdot
.4199 .75994 Mdot
.37219 .62269 Mdot
.64206 .41705 Mdot
.61997 .61059 Mdot
.73382 .36843 Mdot
.31871 .46744 Mdot
.58158 .54935 Mdot
.4155 .31516 Mdot
.48155 .44374 Mdot
.32878 .49298 Mdot
.39538 .30913 Mdot
.58587 .6475 Mdot
.18687 .57201 Mdot
.39997 .26251 Mdot
.81581 .41227 Mdot
.42739 .33208 Mdot
.39472 .32715 Mdot
.53491 .45918 Mdot
.39408 .64807 Mdot
.29441 .3155 Mdot
.54949 .52877 Mdot
.41068 .29959 Mdot
.49527 .72889 Mdot
.26948 .52717 Mdot
.49001 .41169 Mdot
.63904 .46458 Mdot
.62814 .58178 Mdot
.58627 .58759 Mdot
.41139 .34143 Mdot
.66355 .35745 Mdot
.41876 .58978 Mdot
.39653 .30186 Mdot
.57367 .52961 Mdot
.48907 .40286 Mdot
.52551 .38727 Mdot
.54448 .37832 Mdot
.39817 .65037 Mdot
.25886 .64761 Mdot
.65588 .44289 Mdot
.34268 .6617 Mdot
.57216 .48652 Mdot
.56777 .57966 Mdot
.38654 .33869 Mdot
.54506 .3726 Mdot
.40071 .31125 Mdot
.35678 .63973 Mdot
.36693 .66633 Mdot
.65251 .41645 Mdot
.65052 .40211 Mdot
.7033 .4679 Mdot
.45092 .66371 Mdot
.5516 .65594 Mdot
.8053 .47364 Mdot
.63036 .43005 Mdot
.72805 .67209 Mdot
.38944 .64046 Mdot
.38081 .64985 Mdot
.71739 .51948 Mdot
.56392 .64096 Mdot
.37794 .42165 Mdot
.55025 .57953 Mdot
.48742 .74687 Mdot
.53573 .65565 Mdot
.31247 .523 Mdot
.53185 .63072 Mdot
.49894 .27234 Mdot
.58898 .63132 Mdot
.57027 .571 Mdot
.28313 .49945 Mdot
.52753 .58302 Mdot
.32738 .50322 Mdot
.53559 .60187 Mdot
.34996 .61624 Mdot
.30167 .49098 Mdot
.37926 .61456 Mdot
.41173 .44604 Mdot
.53567 .38226 Mdot
.39725 .64093 Mdot
.36528 .62736 Mdot
.38529 .72036 Mdot
.64479 .40244 Mdot
.56773 .71717 Mdot
.58697 .58071 Mdot
.3053 .53977 Mdot
.41131 .35014 Mdot
.60034 .61675 Mdot
.57834 .66684 Mdot
.50944 .63334 Mdot
.655 .41809 Mdot
.33384 .52833 Mdot
.36464 .6397 Mdot
.27194 .48567 Mdot
.3715 .61571 Mdot
.30722 .47293 Mdot
.52307 .66594 Mdot
.58723 .69538 Mdot
.60301 .53907 Mdot
.8015 .52943 Mdot
.60227 .80432 Mdot
.66728 .41759 Mdot
.52489 .37962 Mdot
.3802 .66266 Mdot
.4133 .52026 Mdot
.66022 .44608 Mdot
.29464 .52449 Mdot
.57095 .5907 Mdot
.58454 .52727 Mdot
.58934 .51621 Mdot
.61616 .41217 Mdot
.39917 .61406 Mdot
.28689 .48957 Mdot
.51802 .37297 Mdot
.51972 .43874 Mdot
.72103 .39928 Mdot
.50027 .48373 Mdot
.56977 .60156 Mdot
.37488 .6297 Mdot
.68965 .40408 Mdot
.30544 .32999 Mdot
.4057 .34062 Mdot
.50986 .45371 Mdot
.5863 .60835 Mdot
.58602 .36943 Mdot
.67335 .4345 Mdot
.37422 .65808 Mdot
.41254 .341 Mdot
.3901 .65224 Mdot
.54172 .3919 Mdot
.55954 .39321 Mdot
.54479 .62529 Mdot
.54296 .58542 Mdot
.39649 .35053 Mdot
.65877 .44283 Mdot
.31512 .65101 Mdot
.32143 .26829 Mdot
.27545 .49989 Mdot
.46468 .41065 Mdot
.68482 .40109 Mdot
.56204 .35561 Mdot
.26766 .49948 Mdot
.41346 .35634 Mdot
.46842 .44487 Mdot
.43703 .32355 Mdot
.56297 .57405 Mdot
.68513 .41979 Mdot
.38962 .30002 Mdot
.21842 .40614 Mdot
.71325 .28531 Mdot
.61237 .45804 Mdot
.56711 .6211 Mdot
.59737 .20119 Mdot
.59334 .31068 Mdot
.59847 .41347 Mdot
.37932 .32778 Mdot
.57179 .61269 Mdot
.56689 .561 Mdot
.53112 .62321 Mdot
.39674 .33435 Mdot
.45805 .31047 Mdot
.28221 .52325 Mdot
.56349 .58696 Mdot
.35406 .62833 Mdot
.32396 .50167 Mdot
.31268 .46937 Mdot
.31128 .47939 Mdot
.62973 .43093 Mdot
.62426 .59379 Mdot
.54626 .50251 Mdot
.84573 .44745 Mdot
.39402 .32252 Mdot
.53565 .38188 Mdot
.5971 .57389 Mdot
.43249 .79818 Mdot
.63533 .4361 Mdot
.27824 .50498 Mdot
.58314 .60183 Mdot
.22388 .5408 Mdot
.54757 .36848 Mdot
.29077 .49923 Mdot
.6365 .41536 Mdot
.59775 .41609 Mdot
.59713 .60298 Mdot
.54763 .64226 Mdot
.64061 .43402 Mdot
.56725 .32068 Mdot
.51684 .43325 Mdot
.56781 .60553 Mdot
.39407 .3139 Mdot
.1858 .67246 Mdot
.59836 .63711 Mdot
.65686 .36708 Mdot
.52607 .39248 Mdot
.70195 .335 Mdot
.67797 .56844 Mdot
.5621 .68037 Mdot
.5347 .17072 Mdot
.40483 .7767 Mdot
.62518 .20638 Mdot
.48977 .76061 Mdot
.36104 .25492 Mdot
.7846 .3356 Mdot
.44931 .32609 Mdot
.71328 .61648 Mdot
.31613 .24041 Mdot
.57474 .33934 Mdot
.21132 .57019 Mdot
.25142 .36971 Mdot
.2011 .50947 Mdot
.70134 .74337 Mdot
.30955 .47198 Mdot
.52567 .76375 Mdot
.53083 .60104 Mdot
.5697 .30985 Mdot
.69802 .63252 Mdot
.55591 .82758 Mdot
.5983 .20746 Mdot
.24014 .54396 Mdot
.50479 .13417 Mdot
.60767 .22355 Mdot
.74241 .41979 Mdot
.61963 .73421 Mdot
.28141 .67164 Mdot
.39631 .53758 Mdot
.42124 .7677 Mdot
.67376 .60649 Mdot
.49865 .25745 Mdot
.45072 .31957 Mdot
.76892 .46089 Mdot
.23863 .71986 Mdot
.29009 .48061 Mdot
.68148 .38974 Mdot
.28585 .31855 Mdot
.74551 .39075 Mdot
.36358 .26998 Mdot
.53477 .17053 Mdot
.69357 .30198 Mdot
.71013 .62839 Mdot
.55294 .48061 Mdot
.73024 .56246 Mdot
.34013 .737 Mdot
.59944 .75452 Mdot
.64493 .37806 Mdot
.24631 .40201 Mdot
.39852 .53743 Mdot
.32843 .70211 Mdot
.71538 .6507 Mdot
.40323 .64425 Mdot
.39787 .62563 Mdot
.63379 .42099 Mdot
.69467 .48775 Mdot
.52315 .35845 Mdot
.57907 .48902 Mdot
.25189 .48504 Mdot
.37565 .37581 Mdot
.53241 .3101 Mdot
.60156 .32631 Mdot
.83826 .55812 Mdot
.57792 .15013 Mdot
.43692 .70858 Mdot
.33033 .35888 Mdot
.375 .26993 Mdot
.40565 .75958 Mdot
.52746 .50142 Mdot
.45814 .69452 Mdot
.54488 .72118 Mdot
.42816 .14127 Mdot
.64061 .30956 Mdot
.49127 .12708 Mdot
.6859 .37807 Mdot
.50483 .60707 Mdot
.34336 .36203 Mdot
.79588 .60128 Mdot
.40089 .69773 Mdot
.57804 .15472 Mdot
.32893 .65505 Mdot
.64417 .4706 Mdot
.57517 .34114 Mdot
.69679 .66201 Mdot
.31194 .63719 Mdot
.40007 .66911 Mdot
.49619 .60245 Mdot
.4206 .13171 Mdot
.52066 .16857 Mdot
.77711 .37621 Mdot
.68018 .30255 Mdot
.23627 .4851 Mdot
.30545 .4667 Mdot
.39372 .29304 Mdot
.73677 .30388 Mdot
.67974 .42628 Mdot
.85048 .45299 Mdot
.71958 .29935 Mdot
.47176 .62863 Mdot
.40415 .14118 Mdot
.75458 .70363 Mdot
.67801 .54035 Mdot
.54393 .80299 Mdot
.18182 .51321 Mdot
.51944 .49897 Mdot
.54126 .34628 Mdot
.28167 .5397 Mdot
.72849 .32827 Mdot
.72391 .2802 Mdot
.51019 .7315 Mdot
.39409 .21875 Mdot
.58531 .49174 Mdot
.37342 .51561 Mdot
.62446 .47244 Mdot
.21242 .59332 Mdot
.43776 .63943 Mdot
.5021 .12938 Mdot
.68766 .61894 Mdot
.17515 .62081 Mdot
.47044 .75584 Mdot
.70026 .70332 Mdot
.52615 .18368 Mdot
.25689 .45597 Mdot
.46133 .65745 Mdot
.62851 .32684 Mdot
.59815 .66462 Mdot
.48049 .53171 Mdot
.52123 .69871 Mdot
.33492 .59539 Mdot
.53225 .44857 Mdot
.62112 .27133 Mdot
.44735 .74941 Mdot
.35158 .2492 Mdot
.62523 .72475 Mdot
.65494 .45616 Mdot
.44655 .68588 Mdot
.46178 .73013 Mdot
.66404 .2961 Mdot
.44231 .60463 Mdot
.77434 .36312 Mdot
.43344 .59541 Mdot
.57617 .68422 Mdot
.71565 .60886 Mdot
.67245 .6137 Mdot
.47735 .72164 Mdot
.51531 .64026 Mdot
.83984 .53446 Mdot
.69447 .31551 Mdot
.78981 .51734 Mdot
.42568 .74131 Mdot
.79839 .52408 Mdot
.7369 .32876 Mdot
.34118 .35257 Mdot
.52979 .34152 Mdot
.62325 .37622 Mdot
.42535 .13193 Mdot
.31993 .50922 Mdot
.48848 .71865 Mdot
.44389 .29569 Mdot
.22101 .39872 Mdot
.29787 .27966 Mdot
.42472 .59004 Mdot
.74574 .32562 Mdot
.59484 .33685 Mdot
.34922 .49478 Mdot
.47994 .23682 Mdot
.44132 .38293 Mdot
.7977 .47792 Mdot
.50511 .63246 Mdot
.4938 .68203 Mdot
.3405 .65224 Mdot
.76454 .62483 Mdot
.32706 .31616 Mdot
.31988 .58734 Mdot
.54233 .67254 Mdot
.29887 .55902 Mdot
.52136 .36777 Mdot
.48759 .43599 Mdot
.75221 .28753 Mdot
.53665 .69112 Mdot
.73806 .71596 Mdot
.58955 .3224 Mdot
.47054 .43842 Mdot
.36047 .71377 Mdot
.6906 .34686 Mdot
.47331 .12432 Mdot
.7509 .32127 Mdot
.58595 .29426 Mdot
.58941 .19542 Mdot
.78829 .70056 Mdot
.26533 .29874 Mdot
.79242 .62718 Mdot
.44473 .29698 Mdot
.57314 .89841 Mdot
.26833 .49146 Mdot
.58472 .78609 Mdot
.79297 .6023 Mdot
.24444 .55941 Mdot
.74546 .38835 Mdot
.6728 .64315 Mdot
.37477 .69451 Mdot
.70721 .42089 Mdot
.52219 .65831 Mdot
.62043 .18163 Mdot
.43988 .13281 Mdot
.60799 .17316 Mdot
.55063 .40463 Mdot
.63518 .20259 Mdot
.40523 .17013 Mdot
.47983 .82369 Mdot
.30522 .2875 Mdot
.6137 .56476 Mdot
.49569 .71093 Mdot
.77107 .68163 Mdot
.36161 .67674 Mdot
.55975 .4967 Mdot
.63597 .38295 Mdot
.39873 .1643 Mdot
.75242 .28563 Mdot
.73662 .51973 Mdot
.72879 .45581 Mdot
.38517 .45568 Mdot
.46727 .69499 Mdot
.75169 .38619 Mdot
.50557 .24404 Mdot
.67267 .2809 Mdot
.39011 .1798 Mdot
.45948 .73715 Mdot
.24942 .3767 Mdot
.57815 .28549 Mdot
.78266 .65781 Mdot
.52518 .18015 Mdot
.28036 .31847 Mdot
.46307 .63512 Mdot
.66359 .4814 Mdot
.42022 .59145 Mdot
.49239 .25007 Mdot
.36253 .40284 Mdot
.41847 .72194 Mdot
.33206 .51364 Mdot
.50413 .72531 Mdot
.45405 .50068 Mdot
.30358 .28887 Mdot
.40233 .73822 Mdot
.52179 .73691 Mdot
.60774 .28329 Mdot
.62167 .18765 Mdot
.58981 .32476 Mdot
.17299 .52636 Mdot
.55543 .20721 Mdot
.50784 .68547 Mdot
.52013 .59377 Mdot
.74065 .32628 Mdot
.68778 .21292 Mdot
.74658 .32467 Mdot
.5934 .37553 Mdot
.23552 .53052 Mdot
.43339 .34643 Mdot
.39417 .74738 Mdot
.33251 .57464 Mdot
.6817 .27731 Mdot
.43083 .51157 Mdot
.40923 .36086 Mdot
.52713 .31717 Mdot
.71065 .46004 Mdot
.42357 .78593 Mdot
.75844 .4662 Mdot
.63722 .59358 Mdot
.67894 .50909 Mdot
.69602 .43936 Mdot
.58855 .37485 Mdot
.46497 .70028 Mdot
.31995 .50305 Mdot
.20346 .41445 Mdot
.67953 .35953 Mdot
.5015 .63176 Mdot
.34495 .38677 Mdot
.62157 .47229 Mdot
.80317 .54737 Mdot
.34806 .50322 Mdot
.76889 .31741 Mdot
.83221 .56311 Mdot
.75224 .38434 Mdot
.44203 .69586 Mdot
.21163 .41748 Mdot
.4983 .43133 Mdot
.42515 .28134 Mdot
.59806 .21114 Mdot
.42734 .44749 Mdot
.45006 .69633 Mdot
.67139 .51801 Mdot
.32152 .28223 Mdot
.59434 .67947 Mdot
.78588 .39143 Mdot
.46629 .8145 Mdot
.48166 .42451 Mdot
.72434 .37372 Mdot
.65997 .38555 Mdot
.63414 .80267 Mdot
.51067 .26991 Mdot
.49686 .55219 Mdot
.55931 .18655 Mdot
.41539 .29166 Mdot
.64101 .44909 Mdot
.53482 .7383 Mdot
.23942 .59799 Mdot
.65501 .50401 Mdot
.37285 .39966 Mdot
.74307 .40861 Mdot
.41787 .42466 Mdot
.57785 .18928 Mdot
.50121 .15532 Mdot
.18889 .66756 Mdot
.69568 .38793 Mdot
.3124 .3383 Mdot
.30816 .34206 Mdot
.63185 .38968 Mdot
.62534 .38978 Mdot
.68217 .61621 Mdot
.67281 .22045 Mdot
.41378 .50123 Mdot
.495 .23441 Mdot
.46698 .441 Mdot
.21679 .58017 Mdot
.31065 .3003 Mdot
.41252 .75041 Mdot
.48145 .1816 Mdot
.74059 .46241 Mdot
.17445 .4209 Mdot
.63325 .55588 Mdot
.5903 .78431 Mdot
.39379 .74751 Mdot
.59934 .73323 Mdot
.71815 .64546 Mdot
.64413 .25939 Mdot
.53276 .64541 Mdot
.59863 .15864 Mdot
.63858 .29551 Mdot
.47158 .54397 Mdot
.24319 .46145 Mdot
.57445 .6455 Mdot
.62313 .58763 Mdot
.7522 .37304 Mdot
.71397 .34043 Mdot
.21954 .32986 Mdot
.4791 .75284 Mdot
.48867 .66466 Mdot
.6715 .53223 Mdot
.73869 .71496 Mdot
.35705 .37371 Mdot
.65568 .23469 Mdot
.4516 .51079 Mdot
.78456 .66473 Mdot
.48067 .21079 Mdot
.48084 .25325 Mdot
.54813 .1991 Mdot
.41351 .16604 Mdot
.48622 .61454 Mdot
.65889 .3409 Mdot
.28853 .32676 Mdot
.59433 .57327 Mdot
.60481 .35192 Mdot
.56121 .19252 Mdot
.22785 .66438 Mdot
.51311 .51698 Mdot
.67881 .20288 Mdot
.63414 .64345 Mdot
.65206 .3335 Mdot
.30563 .25204 Mdot
.13678 .48159 Mdot
.48985 .2654 Mdot
.51029 .13124 Mdot
.47265 .242 Mdot
.54521 .18004 Mdot
.39852 .2874 Mdot
.42119 .47465 Mdot
.81332 .50074 Mdot
.67936 .22473 Mdot
.2644 .62399 Mdot
.35838 .25156 Mdot
.80711 .45524 Mdot
.66913 .21276 Mdot
.62257 .66864 Mdot
.63846 .79523 Mdot
.26558 .46228 Mdot
.7909 .67118 Mdot
.81611 .59595 Mdot
.72717 .39756 Mdot
.5001 .73451 Mdot
.63918 .78652 Mdot
.53229 .82775 Mdot
.81117 .59778 Mdot
.57109 .73594 Mdot
.71029 .34584 Mdot
.43577 .69588 Mdot
.69176 .27873 Mdot
.68993 .75268 Mdot
.31116 .31541 Mdot
.49738 .36932 Mdot
.55269 .39744 Mdot
.7329 .34444 Mdot
.59026 .26137 Mdot
.34872 .37905 Mdot
.51946 .42052 Mdot
.73749 .41707 Mdot
.24113 .7617 Mdot
.44649 .22923 Mdot
.63976 .52211 Mdot
.45998 .1329 Mdot
.66979 .28371 Mdot
.42059 .51256 Mdot
.71082 .66371 Mdot
.43182 .78933 Mdot
.31049 .45485 Mdot
.55613 .57485 Mdot
.66143 .20891 Mdot
.33996 .47519 Mdot
.52913 .14316 Mdot
.82091 .41505 Mdot
.71028 .48696 Mdot
.51128 .66193 Mdot
.30257 .54587 Mdot
.61444 .74972 Mdot
.57129 .74166 Mdot
.45644 .14194 Mdot
.5953 .78026 Mdot
.45416 .42136 Mdot
.40026 .42565 Mdot
.40226 .40696 Mdot
.48415 .58555 Mdot
.77374 .6821 Mdot
.69619 .34262 Mdot
.43408 .75624 Mdot
.56771 .28886 Mdot
.48217 .71798 Mdot
.68009 .57249 Mdot
.39027 .74115 Mdot
.44844 .56641 Mdot
.36115 .70042 Mdot
.26437 .52075 Mdot
.38263 .20239 Mdot
.60252 .2297 Mdot
.84056 .51593 Mdot
.17521 .52413 Mdot
.62871 .32948 Mdot
.542 .76583 Mdot
.33588 .2843 Mdot
.50245 .5207 Mdot
.27616 .65149 Mdot
.45314 .77137 Mdot
.68331 .59861 Mdot
.65265 .24807 Mdot
.63227 .71075 Mdot
.72946 .28162 Mdot
.41776 .7258 Mdot
.34265 .23261 Mdot
.38371 .45956 Mdot
.77377 .60136 Mdot
.69817 .54757 Mdot
.17963 .49336 Mdot
.48051 .42654 Mdot
.42082 .13263 Mdot
.63613 .45328 Mdot
.57305 .14856 Mdot
.42848 .33294 Mdot
.23336 .69764 Mdot
.66169 .26606 Mdot
.47727 .51682 Mdot
.47131 .47631 Mdot
.79807 .40527 Mdot
.58217 .32729 Mdot
.5996 .3197 Mdot
.42374 .59547 Mdot
.32741 .48633 Mdot
.45978 .39956 Mdot
.50085 .23324 Mdot
.38699 .20558 Mdot
.5581 .55972 Mdot
.35156 .55053 Mdot
.59101 .74904 Mdot
.40711 .27279 Mdot
.70268 .32013 Mdot
.63341 .24038 Mdot
.65654 .56168 Mdot
.46389 .69018 Mdot
.41099 .16239 Mdot
.69416 .29192 Mdot
.415 .57686 Mdot
.54438 .71034 Mdot
.38319 .25879 Mdot
.22916 .34121 Mdot
.49343 .16918 Mdot
.40357 .41504 Mdot
.51085 .42815 Mdot
.43862 .71067 Mdot
.68841 .19564 Mdot
.43382 .13698 Mdot
.16616 .46929 Mdot
.46467 .43802 Mdot
.71087 .394 Mdot
.44453 .79116 Mdot
.34485 .23151 Mdot
.80092 .66059 Mdot
.60525 .29599 Mdot
.48885 .72201 Mdot
.21483 .64219 Mdot
.61228 .79134 Mdot
.44367 .43127 Mdot
.69931 .54824 Mdot
.80856 .55756 Mdot
.36077 .28998 Mdot
.32268 .45729 Mdot
.45081 .45771 Mdot
.37189 .2559 Mdot
.70869 .34519 Mdot
.58227 .32961 Mdot
.34117 .23278 Mdot
.60669 .77785 Mdot
.54946 .71185 Mdot
.3625 .23681 Mdot
.63506 .47243 Mdot
.30451 .33699 Mdot
.21314 .38749 Mdot
.45107 .44498 Mdot
.2772 .47751 Mdot
.60227 .51962 Mdot
.48128 .3967 Mdot
.47091 .23012 Mdot
.1945 .60416 Mdot
.33717 .62465 Mdot
.67282 .36906 Mdot
.62671 .78444 Mdot
.68919 .38344 Mdot
.73535 .24611 Mdot
.50826 .24301 Mdot
.67449 .52077 Mdot
.46384 .20707 Mdot
.26361 .38029 Mdot
.16634 .54839 Mdot
.73973 .42895 Mdot
.413 .69347 Mdot
.68713 .37505 Mdot
.69959 .42594 Mdot
.48003 .19883 Mdot
.54206 .35575 Mdot
.71397 .46979 Mdot
.71849 .72988 Mdot
.21062 .42106 Mdot
.66877 .37892 Mdot
.39871 .43048 Mdot
.60308 .44083 Mdot
.75737 .29213 Mdot
.27839 .47939 Mdot
.43315 .12888 Mdot
.55918 .70529 Mdot
.22124 .34659 Mdot
.72422 .3226 Mdot
.54447 .43168 Mdot
.46096 .42925 Mdot
.22543 .40672 Mdot
.58256 .68287 Mdot
.4863 .66004 Mdot
.64412 .40525 Mdot
.31155 .2704 Mdot
.37847 .64538 Mdot
.42749 .63917 Mdot
.44258 .29765 Mdot
.72252 .69581 Mdot
.80172 .6419 Mdot
.69842 .4338 Mdot
.37719 .43794 Mdot
.30276 .35344 Mdot
.62101 .6796 Mdot
.59242 .74443 Mdot
.39774 .18807 Mdot
.73059 .4487 Mdot
.64049 .45601 Mdot
.16893 .4806 Mdot
.4147 .61605 Mdot
.77762 .3337 Mdot
.65637 .58626 Mdot
.60822 .75046 Mdot
.60883 .73069 Mdot
.75656 .3669 Mdot
.67778 .56925 Mdot
.67209 .25295 Mdot
.45004 .68873 Mdot
.39833 .5878 Mdot
.52266 .73572 Mdot
.65743 .56213 Mdot
.42678 .41207 Mdot
.77144 .69271 Mdot
.20879 .63492 Mdot
.72787 .57219 Mdot
.53341 .50267 Mdot
.73631 .3815 Mdot
.74406 .70979 Mdot
.66653 .36823 Mdot
.32847 .62678 Mdot
.77459 .46788 Mdot
.66114 .26782 Mdot
.73451 .29969 Mdot
.6629 .29635 Mdot
.61387 .75213 Mdot
.40705 .4057 Mdot
.49276 .79641 Mdot
.58041 .70924 Mdot
.49078 .50116 Mdot
.58397 .66833 Mdot
.49724 .66356 Mdot
.42964 .52688 Mdot
.80325 .42239 Mdot
.48072 .61825 Mdot
.67003 .22312 Mdot
.76841 .32783 Mdot
.60983 .19262 Mdot
.35855 .40193 Mdot
.69044 .39013 Mdot
.46048 .12765 Mdot
.64573 .74779 Mdot
.69407 .28287 Mdot
.80836 .60979 Mdot
.64565 .79992 Mdot
.31395 .23907 Mdot
.63215 .269 Mdot
.64209 .49084 Mdot
.84518 .48375 Mdot
.64272 .30859 Mdot
.6442 .78993 Mdot
.68337 .60442 Mdot
.71607 .32263 Mdot
.40106 .14768 Mdot
.76113 .66017 Mdot
.60425 .32307 Mdot
.69568 .5531 Mdot
.6589 .54424 Mdot
.70105 .73348 Mdot
.62423 .61679 Mdot
.29873 .46907 Mdot
.22189 .55097 Mdot
.49072 .73056 Mdot
.64384 .54042 Mdot
.69091 .74256 Mdot
.57235 .74332 Mdot
.52992 .76705 Mdot
.22101 .41207 Mdot
.31641 .23879 Mdot
.66367 .52322 Mdot
.57915 .52652 Mdot
.65383 .3704 Mdot
.38559 .62757 Mdot
.47012 .76331 Mdot
.58076 .63299 Mdot
.49116 .45825 Mdot
.50175 .57396 Mdot
.636 .18505 Mdot
.22767 .57909 Mdot
.41696 .36505 Mdot
.68401 .38557 Mdot
.73312 .34714 Mdot
.35062 .34953 Mdot
.57353 .33935 Mdot
.68184 .74447 Mdot
.67991 .48568 Mdot
.56473 .18014 Mdot
.60966 .32919 Mdot
.43661 .73025 Mdot
.32462 .72253 Mdot
.37901 .31007 Mdot
.81022 .53789 Mdot
.44637 .1484 Mdot
.62117 .34149 Mdot
.63899 .4702 Mdot
.57514 .27693 Mdot
.42678 .41465 Mdot
.63212 .34918 Mdot
.58423 .32316 Mdot
.32077 .30703 Mdot
.71059 .50413 Mdot
.49478 .15874 Mdot
.33129 .54464 Mdot
.4711 .73959 Mdot
.52845 .27136 Mdot
.69971 .73857 Mdot
.62474 .67562 Mdot
.70413 .26184 Mdot
.47741 .51038 Mdot
.36292 .59098 Mdot
.54849 .63308 Mdot
.64695 .73772 Mdot
.75237 .36683 Mdot
.55789 .28402 Mdot
.46369 .62364 Mdot
.6851 .45867 Mdot
.83643 .55669 Mdot
.24391 .46684 Mdot
.28093 .45371 Mdot
.5622 .79366 Mdot
.5903 .38787 Mdot
.35169 .57732 Mdot
.48738 .34439 Mdot
.59833 .68467 Mdot
.31359 .70705 Mdot
.38541 .40863 Mdot
.81175 .52448 Mdot
.78555 .63689 Mdot
.39118 .19564 Mdot
.36929 .39322 Mdot
.84091 .55415 Mdot
.8189 .53714 Mdot
.72252 .33459 Mdot
.62091 .78048 Mdot
.57694 .50132 Mdot
.51564 .64555 Mdot
.32824 .62703 Mdot
.62133 .42328 Mdot
.40878 .18765 Mdot
.47056 .65917 Mdot
.35409 .59687 Mdot
.46787 .53384 Mdot
.34311 .36479 Mdot
.36317 .46371 Mdot
.69417 .31831 Mdot
.84567 .48472 Mdot
.46363 .69935 Mdot
.39873 .28169 Mdot
.47681 .23416 Mdot
.50007 .53098 Mdot
.68526 .2415 Mdot
.42729 .54411 Mdot
.74931 .37832 Mdot
.51436 .39737 Mdot
.79401 .55825 Mdot
.78099 .36054 Mdot
.43724 .64524 Mdot
.50086 .48847 Mdot
.7141 .36235 Mdot
.56095 .49338 Mdot
.52684 .36186 Mdot
.25146 .57062 Mdot
.63487 .75977 Mdot
.3867 .22656 Mdot
.4576 .30519 Mdot
.62803 .64356 Mdot
.44873 .79134 Mdot
.47559 .16507 Mdot
.41445 .52107 Mdot
.46838 .51588 Mdot
.28569 .33055 Mdot
.34126 .47511 Mdot
.19163 .68845 Mdot
.6147 .16913 Mdot
.54943 .63428 Mdot
.45805 .47715 Mdot
.42346 .63257 Mdot
.32886 .52923 Mdot
.75639 .45972 Mdot
.40687 .18434 Mdot
.3948 .29785 Mdot
.2125 .45562 Mdot
.48606 .34525 Mdot
.80086 .41154 Mdot
.17761 .44106 Mdot
.39238 .35866 Mdot
.73215 .24157 Mdot
.59834 .29903 Mdot
.65934 .35489 Mdot
.20205 .7101 Mdot
.79034 .40542 Mdot
.55927 .72016 Mdot
.22244 .50799 Mdot
.63705 .19043 Mdot
.46342 .4281 Mdot
.25067 .54297 Mdot
.77112 .6485 Mdot
.45885 .69696 Mdot
.476 .74857 Mdot
.4949 .34916 Mdot
.82566 .48204 Mdot
.60448 .82317 Mdot
.26572 .37889 Mdot
.16089 .52384 Mdot
.71321 .47631 Mdot
.52276 .15376 Mdot
.49047 .26341 Mdot
.23173 .66062 Mdot
.73294 .30205 Mdot
.52502 .72798 Mdot
.70148 .72087 Mdot
.24999 .62444 Mdot
.42394 .66486 Mdot
.44136 .79702 Mdot
.54893 .40938 Mdot
.73841 .44162 Mdot
.23275 .40952 Mdot
.46453 .60643 Mdot
.51303 .73084 Mdot
.79905 .57351 Mdot
.4984 .49075 Mdot
.47574 .14494 Mdot
.67025 .74331 Mdot
.44685 .70358 Mdot
.25913 .34238 Mdot
.39683 .624 Mdot
.42676 .18191 Mdot
.3788 .36983 Mdot
.56858 .72251 Mdot
.28438 .26207 Mdot
.50163 .12977 Mdot
.57573 .50079 Mdot
.61902 .57757 Mdot
.78672 .33895 Mdot
.38214 .5325 Mdot
.7924 .62521 Mdot
.53283 .30324 Mdot
.48735 .75469 Mdot
.4912 .58631 Mdot
.55283 .66547 Mdot
.51711 .80418 Mdot
.67991 .47617 Mdot
.8026 .5688 Mdot
.19155 .42097 Mdot
.44576 .69799 Mdot
.67811 .72547 Mdot
.17777 .41558 Mdot
.65844 .59031 Mdot
.69281 .43232 Mdot
.63613 .18806 Mdot
.77447 .43019 Mdot
.51996 .70051 Mdot
.68477 .52595 Mdot
.42164 .55691 Mdot
.30279 .67002 Mdot
.55403 .71207 Mdot
.49635 .43132 Mdot
.49776 .7352 Mdot
.34779 .23535 Mdot
.8132 .48741 Mdot
.41591 .13079 Mdot
.75113 .32838 Mdot
.68346 .38089 Mdot
.77588 .63634 Mdot
.44634 .4453 Mdot
.59771 .18743 Mdot
.23621 .39165 Mdot
.21195 .40802 Mdot
.57982 .82436 Mdot
.42129 .64785 Mdot
.52422 .62045 Mdot
.54957 .40526 Mdot
.73497 .29282 Mdot
.59814 .81615 Mdot
.72697 .28049 Mdot
.49053 .64174 Mdot
.51528 .60519 Mdot
.12877 .50593 Mdot
.55948 .18334 Mdot
.55346 .68773 Mdot
.52273 .52958 Mdot
.49166 .56435 Mdot
.53286 .60083 Mdot
.55879 .36638 Mdot
.42121 .77499 Mdot
.49431 .7502 Mdot
.66941 .21977 Mdot
.64945 .38677 Mdot
.46807 .42936 Mdot
.37874 .34255 Mdot
.4802 .46124 Mdot
.63899 .54235 Mdot
.41201 .29177 Mdot
.51357 .75442 Mdot
.38033 .50874 Mdot
.30827 .65676 Mdot
.6955 .47144 Mdot
.5523 .41579 Mdot
.72758 .43365 Mdot
.57137 .77055 Mdot
.55452 .35508 Mdot
.52734 .82945 Mdot
.57004 .7444 Mdot
.58748 .71692 Mdot
.68276 .31841 Mdot
.76531 .72085 Mdot
.47335 .42455 Mdot
.57661 .38337 Mdot
.64555 .63502 Mdot
.67067 .68584 Mdot
.69626 .51197 Mdot
.35855 .68261 Mdot
.5157 .36932 Mdot
.49566 .6508 Mdot
.74631 .37945 Mdot
.43866 .31848 Mdot
.685 .19865 Mdot
.50759 .64098 Mdot
.74698 .47839 Mdot
.68533 .25396 Mdot
.30623 .32607 Mdot
.68094 .59891 Mdot
.58601 .66427 Mdot
.40063 .5732 Mdot
.38014 .51356 Mdot
.61455 .39471 Mdot
.30999 .29486 Mdot
.53236 .16589 Mdot
.57901 .78061 Mdot
.73238 .47901 Mdot
.57933 .5793 Mdot
.32498 .64572 Mdot
.49842 .44146 Mdot
.23111 .64451 Mdot
.36552 .53214 Mdot
.68113 .2918 Mdot
.56034 .76795 Mdot
.47816 .75297 Mdot
.69501 .5737 Mdot
.54855 .14605 Mdot
.51845 .51646 Mdot
.70386 .49221 Mdot
.44895 .55244 Mdot
.5976 .26298 Mdot
.56852 .73801 Mdot
.37354 .23752 Mdot
.48442 .63803 Mdot
.57638 .50568 Mdot
.72983 .25658 Mdot
.74289 .42126 Mdot
.45667 .34865 Mdot
.65421 .24739 Mdot
.64243 .75771 Mdot
.47078 .47784 Mdot
.2137 .7298 Mdot
.23337 .39073 Mdot
.71891 .23124 Mdot
.33109 .2677 Mdot
.62665 .69757 Mdot
.69175 .34576 Mdot
.52492 .66116 Mdot
.29203 .50615 Mdot
.57675 .1758 Mdot
.71716 .3663 Mdot
.58483 .49594 Mdot
.62385 .57713 Mdot
.39916 .51955 Mdot
.62265 .38654 Mdot
.37834 .22808 Mdot
.32915 .48046 Mdot
.41633 .5733 Mdot
.36234 .24791 Mdot
.37958 .51363 Mdot
.66391 .79218 Mdot
.45975 .1403 Mdot
.60238 .21367 Mdot
.3915 .41172 Mdot
.20281 .67189 Mdot
.70018 .37516 Mdot
.61407 .4164 Mdot
.44437 .30907 Mdot
.49912 .80043 Mdot
.62665 .34578 Mdot
.34077 .24085 Mdot
.7564 .35267 Mdot
.62341 .67794 Mdot
.26549 .79169 Mdot
.53458 .73384 Mdot
.41025 .54004 Mdot
.60818 .35751 Mdot
.68131 .23072 Mdot
.21154 .49399 Mdot
.81673 .41383 Mdot
.50271 .25836 Mdot
.64396 .54323 Mdot
.48264 .81566 Mdot
.17113 .47954 Mdot
.39021 .42404 Mdot
.16038 .52713 Mdot
.53686 .18614 Mdot
.42092 .76706 Mdot
.54836 .28333 Mdot
.69836 .38905 Mdot
.48211 .65049 Mdot
.51186 .23779 Mdot
.55892 .49788 Mdot
.66732 .35616 Mdot
.52729 .16964 Mdot
.36488 .75319 Mdot
.25494 .3325 Mdot
.59846 .19846 Mdot
.40991 .27223 Mdot
.723 .39305 Mdot
.56761 .74998 Mdot
.35576 .55006 Mdot
.32444 .52362 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`2Aooooo`;o00000oooool3o`000;3ooooo000Loooo
o`03o`000?oooooooooo08Wooooo0_l00006ooooo`?o00000_ooool3o`0000?ooooo0_l0002[oooo
o`007?ooool00ol0003oooooooooo`23ooooo`Go000000?oooooo`000?l000001oooool2o`0000So
oooo0_l000001?oooooo0000o`000?ooool2o`000:Gooooo000Looooo`03o`000?oooooooooo08?o
oooo1Ol00003ooooo`;o00001Oooool2o`0000_ooooo1Ol0002Uooooo`007?ooool00ol0003ooooo
ooooo`25ooooo`;o00000_ooool4o`0000Gooooo0_l0000<ooooo`;o00002Oooool2o`0009cooooo
000Looooo`03o`000?oooooooooo083ooooo0_l00005ooooo`Co00001oooool2o`0001Oooooo0_l0
002Looooo`007?ooool00ol0003oooooooooo`20ooooo`;o00001Oooool2o`0000Sooooo0ol0000D
ooooo`;o0000Woooool001cooooo00?o0000ooooooooool0Ooooool2o`00013ooooo0_l00004oooo
o`;o00003Oooool4o`0000Cooooo0_l0002Iooooo`007?ooool00ol0003oooooooooo`1oooooo`;o
00003?ooool2o`0000Sooooo0_l000000ooooooo0000o`000003ooooo`;o00001Oooool2o`0000Ko
oooo0_l00006ooooo`Co0000Soooool001cooooo0_l0002>ooooo`;o00002oooool2o`0000?ooooo
0_l00005ooooo`;o00003_ooool4o`0000Kooooo0_l00027ooooo`007?ooool00ol0003ooooooooo
o`2Oooooo`;o00001Oooool2o`0000Kooooo0_l00008ooooo`;o00001_ooool2o`0008Oooooo000L
ooooo`03o`000?oooooooooo07[ooooo0_l0000Qooooo`Co00003Oooool2o`0000Gooooo0_l00000
0ooooooo0000o`000005ooooo`;o0000R?ooool001cooooo00?o0000ooooooooool0N_ooool2o`00
00Kooooo0_l0000Iooooo`;o00003_ooool2o`0000Kooooo0_l00008ooooo`;o0000R?ooool001co
oooo00?o0000ooooooooool0O_ooool2o`0000;ooooo0ol0000Booooo`;o00004?ooool2o`0000;o
oooo0_l0002Jooooo`007?ooool00ol0003oooooooooo`1nooooo`;o00000oooool2o`0001;ooooo
0_l00004ooooo`;o00001_ooool2o`0000;ooooo0_l00002ooooo`;o00005Oooool2o`0008?ooooo
000Looooo`03o`000?oooooooooo083ooooo0_l0000Kooooo`;o00001_ooool2o`000003ooooool0
003o000000;o000000?oooooo`000?l000003oooool2o`0000Cooooo0_l00023ooooo`007?ooool0
0ol0003oooooooooo`20ooooo`;o00009_ooool4o`0001;ooooo0_l00002ooooo`;o0000QOooool0
01cooooo00?o0000ooooooooool0^?ooool3o`0000Oooooo0_l00025ooooo`007?ooool00ol0003o
ooooooooo`1kooooo`;o00001?ooool2o`0001kooooo0_l00004ooooo`;o00001?ooool2o`0000Go
oooo0_l00002ooooo`?o0000S_ooool001cooooo00?o0000ooooooooool0Noooool2o`0000?ooooo
0ol00004ooooo`;o00004?ooool2o`0000Kooooo0_l00004ooooo`;o00001?ooool2o`0000?ooooo
1?l0000;ooooo`;o00000oooool2o`00087ooooo000Looooo`03o`000?oooooooooo083ooooo0ol0
0004ooooo`;o00004?ooool2o`0000Kooooo0_l00004ooooo`;o00000_ooool2o`0000Gooooo0_l0
000:ooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo0_l0001looooo`007?ooool0
0ol0003oooooooooo`1mooooo`;o00000_ooool2o`0001kooooo0_l00008ooooo`;o00001Oooool2
o`0000Cooooo0_l00004ooooo`;o00001_ooool2o`0000?ooooo0_l00003ooooo`;o00001oooool2
o`0006kooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_oo
ool00ol0003oooooooooo`1mooooo`?o0000<oooool2o`0000?ooooo0_l00008ooooo`;o00001ooo
ool2o`0000?ooooo0_l00007ooooo`;o0000K_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo07_o
oooo0_l000000ooooooo0000o`00000]ooooo`;o00001?ooool2o`0000Oooooo0_l00004ooooo`;o
00006?ooool2o`0006_ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo
00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`1kooooo`;o00006oooool2o`0001?ooooo
0ol000000ooooooo0000o`000004ooooo`;o00000oooool2o`000003ooooool0003o000001[ooooo
0ol0001[ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ
8B7ok^k^00Kooooo0ol0001iooooo`Co00006oooool2o`0001Cooooo0_l000000ooooooo0000o`00
0004ooooo`;o00001Oooool5o`0000Kooooo1?l0000<ooooo`Co0000K?ooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooo
oooo07Wooooo0ol0000Jooooo`;o00009_ooool2o`000003ooooool0003o000000Kooooo1?l0000<
ooooo`;o0000K_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool03Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo07[ooooo0_l0000Gooooo`;o000000?oooooo`00
0?l000006Oooool2o`0000Gooooo0_l00004ooooo`Go00001?ooool4o`0000Sooooo0_l0001doooo
o`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_oo
ool00ol0003oooooooooo`2Cooooo`;o00000_ooool3o`0001Oooooo0_l00005ooooo`;o00001?oo
ool5o`0000Cooooo0_l0000:ooooo`;o0000M?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^
2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0Uoooool3o`0002Co
oooo1Ol0000Cooooo`;o00001?ooool2o`0006_ooooo000Looooo`03o`000?oooooooooo09Gooooo
1?l0000Rooooo`;o00000oooool3o`0000Wooooo0_l00008ooooo`;o00001?ooool2o`0000Cooooo
0_l0001Uooooo`007?ooool00ol0003oooooooooo`1looooo`;o00005oooool2o`0002Cooooo0_l0
0007ooooo`Co00001?ooool4o`0000;ooooo0_l00002ooooo`?o00002Oooool2o`0006Gooooo000L
ooooo`03o`000?oooooooooo07cooooo0_l0000Iooooo`;o0000:Oooool6o`0000Kooooo0_l00002
ooooo`;o00000_ooool3o`00073ooooo000Looooo`03o`000?oooooooooo07Gooooo0_l00003oooo
o`;o00005oooool2o`0000;ooooo0_l0000Yooooo`So00003?ooool2o`000003ooooool0003o0000
06kooooo000Looooo`03o`000?oooooooooo06Wooooo0_l0000:ooooo`Co000000?oooooo`000?l0
00004Oooool2o`0000Cooooo1?l0000Yooooo`;o00001?ooool5o`0000Sooooo0_l00004ooooo`?o
0000KOooool001cooooo00?o0000ooooooooool0JOooool5o`0000Wooooo0_l0000Dooooo`;o0000
1?ooool4o`0000Sooooo0_l0000Oooooo`;o000000?oooooo`000?l000000_ooool5o`0000Oooooo
0_l00005ooooo`;o00002_ooool2o`00067ooooo000Looooo`03o`000?oooooooooo063ooooo1?l0
0004ooooo`Oo00000oooool2o`0001cooooo0_l00005ooooo`?o00000oooool4o`0002;ooooo0_l0
0002ooooo`;o000000?oooooo`000?l000001Oooool2o`0001?ooooo0_l0001Qooooo`007?ooool0
0ol0003oooooooooo`1Pooooo`Go00000oooool4o`000003ooooool0003o000000?ooooo0_l00002
ooooo`;o00006?ooool2o`0000Gooooo0ol00003ooooo`;o00001?ooool2o`0001oooooo0_l00000
1?oooooo0000o`000?l00007ooooo`;o00003?ooool2o`0006Sooooo000Looooo`03o`000?oooooo
oooo05gooooo0_l00003ooooo`?o00001?ooool4o`0000Wooooo0_l0000Hooooo`;o000000Cooooo
o`000?l0003ooooo0_l00009ooooo`Co00006_ooool2o`0000?ooooo0_l000000ooooooo0000o`00
0003o`000003ooooool0003o000000[ooooo1?l00002ooooo`;o00002Oooool2o`0005gooooo000L
ooooo`03o`000?oooooooooo05gooooo0_l00004ooooo`;o00001?ooool4o`0000Kooooo0_l0000K
ooooo`;o000000Coooooo`000?l0003ooooo0_l00008ooooo`?o00007?ooool2o`0000Kooooo0_l0
00001?oooooo0000o`000?ooool2o`0000Sooooo1_l0000=ooooo`?o0000G?ooool001cooooo00?o
0000ooooooooool0K_ooool2o`0000;ooooo0ol00004ooooo`;o00009Oooool2o`0002kooooo0ol0
0004ooooo`Co00004?ooool2o`0005cooooo000Looooo`;o0000HOooool2o`0000cooooo0_l00000
1?oooooo0000o`000?l00005ooooo`;o00008Oooool2o`0002Cooooo0_l0000<ooooo`?o00001_oo
ool2o`00017ooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00002oooool2
o`0000oooooo0ol0000Tooooo`;o00000_ooool2o`0002Cooooo0_l0000?ooooo`;o000000Cooooo
o`000?l0003o00000_ooool2o`0000oooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`1C
ooooo`;o00003_ooool2o`0000Wooooo0_l00002ooooo`;o000000?oooooo`000?l000008Oooool2
o`0000Cooooo1?l0000aooooo`;o000000Coooooo`000?l0003o00000_ooool4o`0000[ooooo0_l0
001Nooooo`007?ooool00ol0003oooooooooo`1Sooooo`;o00002Oooool2o`0000Gooooo0_l00002
ooooo`;o000000?oooooo`000?l000008?ooool4o`0001Wooooo0ol0000?ooooo`;o00003_ooool2
o`0000[ooooo0_l0001Nooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o000000?oooooo`00
0?l000001?ooool2o`0000Gooooo0_l0000>ooooo`;o000000?oooooo`000?l000000_l0000Loooo
o`;o00007Oooool5o`0000gooooo0_l0000>ooooo`;o00000_ooool2o`0006Kooooo000Looooo`03
o`000?oooooooooo05Wooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000Co
oooo0ol00004ooooo`;o000000?oooooo`000?l000002_ooool2o`000003ooooool0003o000001So
oooo0ol0000Pooooo`;o00000oooool2o`0000kooooo0_l00008ooooo`?o000000?oooooo`000?l0
0000I_ooool001cooooo00?o0000ooooooooool0GOooool6o`0000;ooooo0_l000000ooooooo0000
o`000005ooooo`Go00000_ooool2o`0000Wooooo0_l0000Hooooo`?o00001?ooool2o`0001oooooo
0_l00005ooooo`;o00001oooool2o`0000;ooooo0_l00005ooooo`;o0000JOooool001cooooo00?o
0000ooooooooool0HOooool2o`0000;ooooo0_l00009ooooo`Co00000_ooool2o`0000Gooooo0_l0
0002ooooo`;o00001_ooool2o`0000oooooo0_l00002ooooo`;o00000_ooool2o`0000Cooooo0_l0
000Looooo`;o00000_ooool2o`0000Oooooo0_l00002ooooo`;o0000L?ooool001cooooo00?o0000
ooooooooool0HOooool2o`0000_ooooo0_l0000=ooooo`;o00000_ooool2o`0000Kooooo0_l00000
0ooooooo0000o`00000<ooooo`Ko00001Oooool2o`000003ooooool0003o000000gooooo0_l0000=
ooooo`;o00001?ooool2o`0001cooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1Moooo
o`Ko00002Oooool4o`0000kooooo0_l00003ooooo`;o00000oooool2o`0000;ooooo0_l0000>oooo
o`;o00001oooool2o`00013ooooo0_l0000Cooooo`;o00001oooool2o`0000?ooooo1Ol0000;oooo
o`;o0000GOooool001cooooo00?o0000ooooooooool0GOooool4o`0000Cooooo0_l00004ooooo`?o
00001?ooool2o`0000Sooooo1_l000001?oooooo0000o`000?ooool4o`0001cooooo0_l0000/oooo
o`Go000000?oooooo`000?l000001?l00007ooooo`Go0000GOooool001cooooo00?o0000oooooooo
ool0EOooool2o`0000Gooooo1?l00005ooooo`;o00000_ooool4o`0000?ooooo1?l00008ooooo`Ko
00001?ooool2o`0001kooooo0_l00002ooooo`?o000000Coooooo`000?l0003ooooo0_l00005oooo
o`;o00002?ooool2o`00013ooooo1Ol00002ooooo`;o000000?oooooo`000?l000001?ooool2o`00
0003ooooool0003o000000;o00001_ooool2o`0005Kooooo000Looooo`03o`000?oooooooooo05Go
oooo0_l00005ooooo`;o000000?oooooo`000?l000002?ooool2o`0000Gooooo0_l00008ooooo`Ko
000000Coooooo`000?l0003ooooo1?l00005ooooo`;o00004Oooool3o`0000Oooooo0ol000000ooo
oooo0000o`000003o`0000;ooooo0_l000000ooooooo0000o`000008ooooo`;o00004_ooool2o`00
00?ooooo0_l00007ooooo`;o00002_ooool3o`0005Kooooo000Looooo`03o`000?oooooooooo05oo
oooo0_l0000@ooooo`;o00001?oooolAo`000003ooooool0003o000000;ooooo0_l0000Aooooo`?o
00003Oooool2o`0000?ooooo0_l00004ooooo`;o00004_ooool2o`0000Sooooo0_l00003ooooo`;o
00004?ooool4o`0005Gooooo000Looooo`03o`000?oooooooooo067ooooo0ol00009ooooo`;o0000
0_ooool2o`0000Cooooo4Ol000000ooooooo0000o`000003o`0002gooooo0_l0000?ooooo`;o0000
00?oooooo`000?l000001_ooool4o`0000?ooooo0_l0000;ooooo`;o00001?ooool3o`0005Gooooo
000Looooo`03o`000?oooooooooo067ooooo0ol00009ooooo`;o00002oooool>o`0000;ooooo1Ol0
000/ooooo`;o00001?ooool2o`0000Wooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0
003o000000Cooooo0_l0000<ooooo`;o00001?ooool2o`0005Kooooo000Looooo`;o0000Doooool2
o`0000Sooooo0_l00003ooooo`;o00000oooool3o`0000kooooo3ol00002ooooo`Oo0000<?ooool4
o`0000gooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00
0007ooooo`;o00000oooool2o`0000Gooooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`1B
ooooo`;o00002?ooool2o`0000?ooooo0_l00003ooooo`?o00003OoooolHo`0001_ooooo0_l0000C
ooooo`?o00005_ooool8o`0000Oooooo0_l00002ooooo`Co00001?ooool4o`0005?ooooo000Loooo
o`03o`000?oooooooooo053ooooo0_l0000Booooo`;o00003_oooolLo`000003ooooool0003o0000
01Kooooo0_l0000Cooooo`;o00001?ooool2o`00013ooooo0_l000001?oooooo0000o`000?ooool3
o`0000_ooooo1?l00006ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0D?ooool2o`00
013ooooo1?l0000>oooooaco000000?oooooo`000?l000005_ooool2o`0000[ooooo0_l00006oooo
o`;o000000Goooooo`000?l0003o0000ooooo`02o`0000Kooooo0ol00007ooooo`;o0000LOooool0
01cooooo00?o0000ooooooooool0B?ooool2o`0001Sooooo0_l0000Aoooooa[o000000Coooooo`00
0?l0003o00005_ooool2o`0000[ooooo0_l00006ooooo`Oo00000_ooool2o`0000Cooooo0ol0001j
ooooo`007?ooool00ol0003oooooooooo`18ooooo`;o00001?ooool2o`0000cooooo0_l00003oooo
o`;o00001?ooool2o`0000Sooooo0_l00004oooooaSo000000Coooooo`000?l0003o00005Oooool2
o`00017ooooo1Ol00002ooooo`?o000000?oooooo`000?l000000_l0000Dooooo`;o0000JOooool0
01cooooo00?o0000ooooooooool0C_ooool2o`0000Oooooo1?l000000ooooooo0000o`000003oooo
o`Co00000_ooool2o`0000Sooooo8_l0000Cooooo`Co00004Oooool:o`0000;ooooo0ol0000?oooo
o`?o00000_ooool4o`0000;ooooo1?l00008ooooo`;o00001?ooool2o`00057ooooo000Looooo`03
o`000?oooooooooo04kooooo0_l00007ooooo`Go00001oooool2o`0000kooooo6_l00002ooooo`;o
00005Oooool3o`0000_ooooo0_l00004ooooo`[o00000oooool2o`00013ooooo0ol00002ooooo`Co
00000_ooool5o`000003ooooool0003o000000Cooooo0_l00004ooooo`;o0000DOooool001cooooo
00?o0000ooooooooool0B_ooool2o`0000kooooo0_l00002ooooo`Co000000?oooooo`000?l00000
4?oooolKo`000003ooooool0003o000000kooooo0_l0000Aooooo`;o00001?ooool4o`0000;ooooo
0_l00005ooooo`;o00007?ooool4o`000004ooooool0003o0000ooooo`Go0000Eoooool001cooooo
00?o0000ooooooooool0BOooool3o`0000Kooooo0_l00006ooooo`;o00000_ooool4o`0001Gooooo
6Ol000000ooooooo0000o`00000>ooooo`;o00005_ooool2o`000003ooooool0003o000000;ooooo
1?l00002ooooo`Co00003Oooool2o`0000;ooooo0_l0000<ooooo`;o000000?oooooo`000?l00000
1?l00004ooooo`;o0000DOooool001cooooo00?o0000ooooooooool0A?ooool2o`0000?ooooo0_l0
0004ooooo`;o000000?oooooo`000?l000001Oooool3o`0000?ooooo0_l0000EoooooaKo00000ooo
ool2o`0002Sooooo0_l00007ooooo`So00003Oooool2o`0000;ooooo0_l0000<ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0000Cooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`14
ooooo`;o00001?ooool2o`0000?ooooo0_l00008ooooo`;o00001?ooool2o`0001Gooooo6?l00000
0ooooooo0000o`00000Xooooo`;o00000oooool2o`0000Cooooo0_l000001?oooooo0000o`000?l0
0006ooooo`;o00001_ooool2o`0000Kooooo0_l00005ooooo`;o00000oooool2o`0000_ooooo0_l0
001>ooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o00004oooool5o`000003ooooool0003o
000000[ooooo0_l00004oooooaOo00001Oooool2o`0001gooooo0_l00009ooooo`?o00001?ooool2
o`0000[ooooo0_l00005ooooo`?o000000?oooooo`000?l000000oooool2o`0000Gooooo1_l0000<
ooooo`Co0000C?ooool001cooooo00?o0000ooooooooool0Aoooool2o`0001Kooooo1Ol000000ooo
oooo0000o`00000:ooooo`;o00001?ooool>o`000003ooooool0003o000000?o00000oooool2o`00
00?ooooo0_l0000<ooooo`;o00001Oooool2o`0000Sooooo0ol00002ooooo`;o00001?ooool4o`00
0003ooooool0003o000000;ooooo0_l0000:ooooo`;o00000oooool2o`0000;ooooo0_l00007oooo
o`;o00000oooool4o`0000kooooo0ol0001;ooooo`007?ooool00ol0003oooooooooo`17ooooo`;o
00001oooool2o`0000kooooo1?l0000>ooooo`;o00000_ooool3o`000003ooooool0003o000000Wo
000000?oooooo`000?l000001Ol000000ooooooo0000o`000003ooooo`;o00001_ooool2o`0000Co
oooo0_l00002ooooo`;o000000Coooooo`000?l0003o00002?ooool2o`0000;ooooo0_l00006oooo
o`;o000000?oooooo`000?l000001?l0000:ooooo`;o00001oooool2o`000004ooooool0003o0000
o`0000?ooooo0_l00004ooooo`;o00004?ooool2o`0004_ooooo000Looooo`03o`000?oooooooooo
04Cooooo0_l0000:ooooo`;o00003_ooool4o`0000kooooo0_l00002ooooo`?o000000?oooooo`00
0?l000001?l000000ooooooo0000o`00000:o`000003ooooool0003o000000?ooooo0_l00004oooo
o`Co00002?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000Fooooo`;o00000_ooool2o`00
017ooooo2_l00004ooooo`?o0000GOooool001cooooo0_l00015ooooo`;o0000:?ooool2o`0000Ko
oooo0_l00004ooooo`?o00000_ooool;o`000004ooooool0003o0000ooooo`?o00001?ooool5o`00
0003ooooool0003o000000gooooo1?l0000@ooooo`;o00001_ooool5o`00013ooooo0_l00002oooo
o`Co00001?ooool5o`0005_ooooo000Looooo`03o`000?oooooooooo04;ooooo0_l00003ooooo`;o
00005_ooool2o`0000[ooooo1Ol00005ooooo`;o00000_ooool?o`0000;ooooo0_l000000ooooooo
0000o`000004o`0000Cooooo0ol00003ooooo`;o00002_ooool2o`0000;ooooo0ol0000@ooooo`Co
00001_ooool3o`0000Kooooo0_l00004ooooo`;o00004Oooool2o`0000Cooooo0_l00006ooooo`;o
0000COooool001cooooo00?o0000ooooooooool0@_ooool2o`0000;ooooo1Ol0000Dooooo`;o0000
1?ooool2o`0000Cooooo0ol00007ooooo`;o00000_ooool3o`000003ooooool0003o000000go0000
00?oooooo`000?l000000ol00006ooooo`;o00003oooool2o`000003ooooool0003o000000Co0000
00?oooooo`000?l000002oooool4o`0000kooooo1Ol00002ooooo`;o00005oooool2o`0000Kooooo
0_l00002ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0A_ooool2o`000003ooooool0
003o000001[ooooo0_l000001?oooooo0000o`000?ooool2o`0000cooooo0_l000001?oooooo0000
o`000?ooool7o`0000;ooooo1?l000001?oooooo0000o`000?ooool2o`0001Cooooo1?l00002oooo
o`;o00000_ooool5o`0000Sooooo0_l00003ooooo`;o00003_ooool5o`0000;ooooo0ol0000Roooo
o`;o0000BOooool001cooooo00?o0000ooooooooool0C?ooool2o`0000oooooo0ol00008ooooo`;o
00000_ooool4o`0000;ooooo0_l00005ooooo`;o000000Coooooo`000?l0003ooooo1?l000000ooo
oooo0000o`000002o`00013ooooo0ol00002ooooo`;o00000oooool9o`0000Kooooo0_l00007oooo
o`;o000000?oooooo`000?l000000oooool2o`00013ooooo0_l00003ooooo`?o00002?ooool2o`00
00Gooooo0_l0000;ooooo`Co0000COooool001cooooo00?o0000ooooooooool0C?ooool2o`0000oo
oooo0ol0000<ooooo`Co00000_ooool4o`0000Sooooo0_l000001?oooooo0000o`000?ooool4o`00
00gooooo0_l000001?oooooo0000o`000?l00002ooooo`Co000000?oooooo`000?l000002_l00004
ooooo`;o000000?oooooo`000?l000000_ooool3o`00013ooooo0_l00007ooooo`;o000000?ooooo
o`000?l000002_ooool3o`0000Cooooo0ol0000:ooooo`Co0000COooool001cooooo00?o0000oooo
ooooool0K?ooool2o`0000Kooooo0_l00008ooooo`;o00001?ooool2o`0000oooooo0_l00007oooo
o`?o000000?oooooo`000?l000003?l00002ooooo`;o000000?oooooo`000?l000000_ooool4o`00
00oooooo0_l00004ooooo`;o000000?oooooo`000?l000000ol0000:ooooo`?o00001?ooool3o`00
00?ooooo0ol0001Eooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00001oooool2o`0002Oo
oooo0_l00006ooooo`;o00003oooool3o`0000_ooooo0_l00003ooooo`go00002oooool2o`0001Co
oooo2?l0000;ooooo`;o00001?ooool3o`0000Cooooo0ol0000;ooooo`;o0000B?ooool001cooooo
00?o0000ooooooooool0AOooool2o`0000Oooooo0_l0000Iooooo`;o00001Oooool2o`0000Gooooo
0_l00006ooooo`;o00001?ooool2o`0000Cooooo0_l00003ooooo`?o00003_ooool>o`0000;ooooo
0_l00008ooooo`Co00002?ooool2o`0000Cooooo0ol000000ooooooo0000o`000002o`0000Kooooo
0_l00002ooooo`?o00000oooool4o`000003ooooool0003o000000Gooooo0_l00008ooooo`;o0000
0_ooool2o`0004Sooooo000Looooo`03o`000?oooooooooo04Gooooo1?l00004ooooo`;o00006_oo
ool2o`0000Gooooo0_l00004ooooo`Co00002oooool2o`0000?ooooo0ol00004ooooo`;o00003_oo
ool?o`000003ooooool0003o000000Sooooo1?l00004ooooo`;o00000_ooool2o`0000Cooooo0ol0
00000ooooooo0000o`000002ooooo`Co00000_ooool2o`0000;ooooo0ol00003ooooo`Co00001ooo
ool3o`0000Kooooo1?l0001<ooooo`007?ooool00ol0003oooooooooo`17ooooo`Co00000_ooool2
o`0000?ooooo0ol000000ooooooo0000o`00000Cooooo`;o000000?oooooo`000?l000001Oooool5
o`00013ooooo0_l0000@ooooo`;o00000oooool:o`000003ooooool0003o000000;o00004oooool2
o`0000;ooooo0_l00004ooooo`?o000000Goooooo`000?l0003o0000ooooo`08o`0000[ooooo0_l0
0002ooooo`;o00000_ooool3o`0000Oooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`19
ooooo`;o00001oooool3o`000003ooooool0003o000001?ooooo0_l000000ooooooo0000o`000005
ooooo`;o00001_ooool2o`0000[ooooo0_l000000ooooooo0000o`00000>ooooo`;o00000oooool?
o`0000?ooooo0ol00002ooooo`;o00003oooool;o`000004ooooool0003o0000ooooo`Ko000000?o
ooooo`000?l000001_ooool2o`0000;ooooo0_l00002ooooo`Co00002?ooool2o`0004cooooo000L
ooooo`03o`000?oooooooooo04;ooooo0ol00003ooooo`?o00008Oooool3o`0000?ooooo0_l00009
ooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000005Ooo
ool>o`000003ooooool0003o000000;o00000_ooool2o`0000;ooooo0_l00008ooooo`;o000000?o
ooooo`000?l000001_l00002oooooa7o00003?ooool3o`0000Sooooo0_l0001<ooooo`007?ooool0
0ol0003oooooooooo`12ooooo`?o00000oooool2o`0002;ooooo0ol00003ooooo`;o00001_ooool2
o`0000Oooooo0_l000000ooooooo0000o`00000Mooooo`co000000Coooooo`000?l0003o00001ooo
ool2o`0000Sooooo1Ol000000ooooooo0000o`00000Fo`0000Sooooo1_l00006ooooo`;o00001ooo
ool2o`0004Kooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o0000
00?o410@ooooooooool01?ooool00ol0003oooooooooo`12ooooo`?o00000oooool3o`0002Wooooo
0_l00004ooooo`;o0000:Oooool?o`0001?ooooo1Ol00002oooooa?o000000Coooooo`000?l0003o
00000_ooool2o`0000?ooooo1?l00006ooooo`Co000000?oooooo`000?l000001?ooool2o`0004Ko
oooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0@oooool2o`0000Cooooo0_l0000Sooooo`;o00001?ooool2o`00
01Wooooo0_l00008ooooo`;o00002oooool8o`0000;ooooo1?l0000@ooooo`;o00001?ooool2o`00
0003ooooool0003o000000Co000000?oooooo`000?l000002_l00003ooooo`;o00000_ooool2o`00
00gooooo0_l00003ooooo`;o0000C?ooool00003ooooool@413ooooo00;ooooo00?o410@oooooooo
ool02Oooool5o`0000Kooooo00?o0000ooooooooool0@?ooool2o`0000;ooooo0_l00002ooooo`;o
00009?ooool2o`0000Gooooo0_l00009ooooo`;o00003Oooool5o`0000Gooooo0_l00008ooooo`;o
00000_ooool6o`000003ooooool0003o000000;o00004_ooool2o`0000Kooooo1ol000000ooooooo
0000o`000009o`0000Oooooo1_l0001Mooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooo
ooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol00010ooooo`Ko00000_ooool2o`0000;o
oooo0_l0000Sooooo`?o000000?oooooo`000?l000002Oooool3o`0000gooooo1?l00007ooooo`Go
00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`Co00006_ooool7o`000003
ooooool0003o000000_o00000_ooool2o`000003ooooool0003o000000Co00004?ooool2o`0004_o
oooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`10ooooo`Go00001oooool4o`00027ooooo0ol0000<ooooo`?o
000000?oooooo`000?l000003Oooool2o`0000;ooooo0ol000000ooooooo0000o`000003o`0000Oo
oooo0_l00006ooooo`;o00001?ooool2o`0000gooooo0_l00003oooooaSo00000_ooool2o`0001Oo
oooo1Ol00018ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03ogMg
Moo<c<co000000Oooooo00?o0000ooooooooool0@?ooool5o`000003ooooool0003o000000Kooooo
0_l0000Rooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`Oo00003Oooool2o`0000;o
oooo0ol0000<ooooo`;o00001oooool2o`0000Cooooo0_l0000=oooooako000000?oooooo`000?l0
00002Oooool2o`0000gooooo1?l00018ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<oooo
o`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0@Oooool9o`0002oooooo1Ol000001?oo
oooo0000o`000?ooool2o`0000?ooooo0_l00003ooooo`?o00001?ooool2o`0000Kooooo1?l00007
ooooo`;o00001oooool2o`0001?ooooo8Ol00004ooooo`;o00000oooool2o`00013ooooo0_l00003
ooooo`;o0000@_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000oooo
o`06ooooo`03o`000?oooooooooo03Kooooo0_l00006ooooo`;o00000_ooool4o`0000;ooooo0_l0
000aooooo`;o00000_ooool2o`0000Kooooo0_l00003ooooo`?o00000oooool3o`0000Kooooo1?l0
0007ooooo`;o00005oooool2o`0000?ooooo7ol00006ooooo`;o00004oooool4o`000003ooooool0
003o000000Co0000@?ooool001cooooo00?o0000ooooooooool0=_ooool2o`0000Kooooo0_l00000
0ooooooo0000o`000002ooooo`;o0000;oooool2o`0000Oooooo0_l00006ooooo`Co00000_ooool2
o`0000?ooooo0_l00003ooooo`;o00001?ooool2o`0000Cooooo0_l0000:ooooo`?o00003?ooool3
o`0000?ooooo5ol000000ooooooo0000o`000003o`0000;ooooo0_l00007ooooo`;o00004?ooool2
o`0000?ooooo1_l00010ooooo`007?ooool00ol0003oooooooooo`0eooooo`;o000000Coooooo`00
0?l0003ooooo0_l00004ooooo`;o00000_ooool2o`0002oooooo0ol0000=ooooo`;o000000?ooooo
o`000?l000000_ooool2o`000004ooooool0003o0000o`0000Cooooo0_l00002ooooo`;o00001_oo
ool4o`0000Sooooo0ol0000<ooooo`;o00001?oooolQo`0000Oooooo1?l0001Iooooo`007?ooool0
0ol0003oooooooooo`0eooooo`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`?o00001_oo
ool2o`0002cooooo0_l00002ooooo`;o00001oooool5o`0000Cooooo0_l000001?oooooo0000o`00
0?l00003ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o00000_ooool2o`000003oooo
ool0003o000000gooooo0_l00009ooooo`;o000000?oooooo`000?l000007Ol00009ooooo`?o0000
4Oooool3o`0004Gooooo000Looooo`03o`000?oooooooooo043ooooo0_l00007ooooo`;o0000<?oo
ool2o`000003ooooool0003o000000Cooooo1Ol00004ooooo`;o00001oooool5o`0000Kooooo1?l0
00000ooooooo0000o`000002o`000004ooooool0003o0000o`0000Wooooo0_l00009ooooo`;o0000
00?oooooo`000?l000006_l000000ooooooo0000o`00000Mooooo`?o0000AOooool001cooooo00?o
0000ooooooooool0>_ooool2o`0003kooooo0_l00002ooooo`;o00001Oooool5o`0000;ooooo0ol0
0003ooooo`Co00000_ooool2o`0000Oooooo2Ol000001?oooooo0000o`000?l0000;ooooo`;o0000
2_ooool2o`000003ooooool0003o000000go00000_ooool8o`0000_ooooo0_l00009ooooo`?o0000
Coooool001cooooo00?o0000ooooooooool0>_ooool2o`0003kooooo0ol000000ooooooo0000o`00
0006ooooo`Co00000_ooool2o`0000?ooooo1Ol00007ooooo`?o00000_ooool=o`0000[ooooo0_l0
000:ooooo`;o00000_oooolIo`0000Gooooo1?l000000ooooooo0000o`000009ooooo`?o0000Cooo
ool001cooooo00?o0000ooooooooool0=oooool2o`0004;ooooo1?l00006ooooo`;o00001Oooool2
o`0000?ooooo0_l00008ooooo`Go000000?oooooo`000?l000001?l00002ooooo`?o000000?ooooo
o`000?l000005_ooool;o`000003ooooool0003o000000oo00001Oooool4o`0000cooooo0_l0001@
ooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00005Oooool2o`0002Oooooo0_l00004oooo
o`?o00000oooool4o`0000cooooo1?l00004ooooo`;o00001?ooool6o`0000?ooooo0_l0000>oooo
o`;o00001Oooool2o`0000?ooooo7?l0000Eooooo`;o0000D?ooool001cooooo00?o0000oooooooo
ool0=_ooool2o`0001Kooooo0_l0000Wooooo`Go00000_ooool3o`0000;ooooo0_l000000ooooooo
0000o`00000;ooooo`Oo00001?ooool3o`0000;ooooo1Ol000001?oooooo0000o`000?l0000>oooo
o`?o00000oooool5o`000003ooooool0003o000001So00001?ooool2o`0000Kooooo0_l00009oooo
o`;o0000D?ooool001cooooo00?o0000ooooooooool0=_ooool2o`00047ooooo0ol00003ooooo`;o
000000?oooooo`000?l000000_ooool2o`0000Gooooo4?l000001?oooooo0000o`000?l00002oooo
o`;o000000Coooooo`000?l0003ooooo0_l0000@ooooo`;o00000oooool2o`000003ooooool0003o
000000;o000000?oooooo`000?l000005ol00003ooooo`;o00001_ooool2o`0005_ooooo000Loooo
o`03o`000?oooooooooo07_ooooo0_l00002ooooo`;o000000?oooooo`000?l000000oooool2o`00
00Cooooo6Ol000000ooooooo0000o`000002o`0001Sooooo1Ol000000ooooooo0000o`00000Fo`00
00Wooooo0_l0000Sooooo`;o0000>?ooool001cooooo0_l0001looooo`;o00001Oooool2o`0000?o
oooo0_l00006ooooo`Co00000_oooolAo`000003ooooool0003o000000Co00004?ooool2o`0000Oo
oooo0_l000000ooooooo0000o`00000Do`0000_ooooo0_l0000Sooooo`;o0000>?ooool001cooooo
00?o0000ooooooooool0@Oooool2o`0001Gooooo0_l00007ooooo`;o00005_ooool2o`0000Kooooo
0ol0000;ooooo`;o00001Oooool3o`0000Gooooo2?l00002ooooo`;o000000?oooooo`000?l00000
0_l0000>ooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`Wo000000?oooooo`000?l0
00002Ol00003ooooo`;o00007?ooool4o`0000Oooooo0_l00003ooooo`;o0000=oooool001cooooo
00?o0000ooooooooool0;oooool2o`0000Gooooo0_l00009ooooo`;o00003Oooool2o`0000Kooooo
0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l0000Booooo`;o00001Oooool3o`0000cooooo
0_l00006ooooo`;o00000oooool2o`0000;ooooo2_l00002ooooo`Go00004?ooool5o`000003oooo
ool0003o000000;ooooo1?l000000ooooooo0000o`00000;o`0000Gooooo0_l00005ooooo`;o0000
5Oooool4o`0000Oooooo0_l00003ooooo`;o0000=oooool001cooooo00?o0000ooooooooool0;ooo
ool2o`0000Gooooo0_l0000Cooooo`;o00000oooool2o`0000Oooooo0_l000001?oooooo0000o`00
0?l00006ooooo`;o00004_ooool2o`0000Gooooo0ol0000<ooooo`Co00001Oooool2o`0000;ooooo
0_l000000ooooooo0000o`000004ooooo`Wo000000Coooooo`000?l0003ooooo0_l0000=ooooo`Co
00000_ooool4o`000003ooooool0003o000000co000000?oooooo`000?l000001Oooool3o`0000Co
oooo0_l00007ooooo`Ko00002?ooool2o`0000gooooo0_l0000hooooo`007?ooool00ol0003ooooo
ooooo`1;ooooo`;o00001_ooool2o`0000Cooooo0_l000000ooooooo0000o`000002o`0000Cooooo
1?l00002ooooo`;o00001_ooool2o`0000Gooooo0_l00006ooooo`;o00002_ooool2o`0000;ooooo
0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Kooooo
1Ol00006ooooo`;o00004?ooool2o`000003ooooool0003o000000;o000000Coooooo`000?l0003o
oooo0_l00003ooooo`Oo00001oooool3o`0000Sooooo0_l00003ooooo`Ko00002?ooool2o`0000So
oooo0_l00003ooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0C?ooool2o`0000Gooooo
0_l000001Ooooooo0000o`000?l0003ooooo00Oo00000oooool4o`0000;ooooo0_l00006ooooo`;o
00002oooool2o`0000cooooo0_l00005ooooo`;o00001Oooool4o`0000Cooooo0_l00008ooooo`;o
00005Oooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`000005ooooool0003o0000o`00
0?ooool01_l00005ooooo`?o00002_ooool2o`0000Cooooo0_l00003ooooo`;o00004?ooool2o`00
03gooooo000Looooo`03o`000?oooooooooo03;ooooo0_l0000Hooooo`;o00000oooool@o`000003
ooooool0003o000000;o00000_ooool2o`0001Gooooo1?l0000Eooooo`;o00000oooool4o`0000;o
oooo0_l00008ooooo`;o00005?ooool2o`0000Oooooo2?l00002ooooo`?o00001oooool3o`000003
ooooool0003o000000gooooo0_l00003ooooo`;o00003oooool2o`0003kooooo000Looooo`03o`00
0?oooooooooo03;ooooo0_l0000LoooooaOo000000?oooooo`000?l000005Oooool4o`0001Cooooo
0ol00005ooooo`;o00008_ooool2o`000004ooooool0003o0000o`0000;ooooo1ol0000<ooooo`;o
00001?ooool2o`0000Gooooo0_l0000;ooooo`;o00002?ooool2o`0000Gooooo0ol0000mooooo`00
7?ooool00ol0003oooooooooo`0Zooooo`;o00002Oooool2o`0001Sooooo6?l00004ooooo`Co0000
4_ooool2o`0000;ooooo0_l0000:ooooo`;o00000_ooool5o`0000?ooooo2Ol000000ooooooo0000
o`00000Jooooo`;o000000Coooooo`000?l0003o00000_ooool2o`000003ooooool0003o000000Ko
oooo0_l000000ooooooo0000o`000003ooooo`;o00001?ooool2o`0000Gooooo0_l0000Eooooo`Co
00000oooool3o`0003gooooo000Looooo`03o`000?oooooooooo02[ooooo0_l00008ooooo`?o0000
6?ooool:o`000003ooooool0003o000000go00000_ooool4o`0001;ooooo0_l00002ooooo`;o0000
2_ooool2o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`co00001Oooool2o`0000Oooooo
1?l0000<ooooo`?o00001?ooool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000
o`000003ooooo`;o00001?ooool2o`0000Cooooo0_l00003ooooo`;o00003_ooool2o`0000?ooooo
0_l00003ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0:Oooool2o`0000Sooooo0ol0
000IoooooaOo000000?oooooo`000?l000002_ooool2o`0000;ooooo0_l0000Hooooo`;o00000_oo
ool2o`000003ooooool0003o000000Cooooo0ol00004ooooo`?o00001Oooool5o`0000Gooooo1?l0
000<ooooo`?o00001oooool2o`000004ooooool0003o0000ooooo`;o00000oooool2o`0000cooooo
0_l00003ooooo`;o00003?ooool4o`0000Oooooo0ol0000nooooo`007?ooool00ol0003ooooooooo
o`0Yooooo`;o00002?ooool2o`0000Gooooo0_l0000=ooooo`;o00000ooooolMo`0000Sooooo0_l0
0002ooooo`;o00007oooool2o`0000Cooooo0ol00006ooooo`?o00000oooool2o`000003ooooool0
003o000000Cooooo0_l0000@ooooo`;o00002_ooool2o`000003ooooool0003o000000;o000000?o
ooooo`000?l000003?ooool2o`00013ooooo0ol00006ooooo`;o000000Coooooo`000?l0003o0000
1?ooool2o`0003Sooooo000Looooo`03o`000?oooooooooo03[ooooo0_l0000=ooooo`;o00000ooo
oolNo`0000_ooooo0_l0000Uooooo`?o00001_ooool3o`0000?ooooo0_l00007ooooo`Co00002ooo
ool2o`0000Wooooo0_l00007ooooo`;o00000oooool2o`0000?ooooo0_l0000Gooooo`;o00001_oo
ool3o`000004ooooool0003o0000o`0000Cooooo0_l0000hooooo`007?ooool00ol0003ooooooooo
o`11ooooo`;o00002oooool=o`000003ooooool0003o000000ko00005_ooool2o`0001[ooooo0ol0
000Gooooo`Ko00001oooool2o`0000Kooooo1Ol0000:ooooo`Co000000?oooooo`000?l000000_l0
0002ooooo`;o00006oooool2o`0000;ooooo0ol0000nooooo`007?ooool00ol0003oooooooooo`0g
ooooo`;o00002?ooool2o`0000cooooo8Ol00003ooooo`;o00003Oooool2o`0001Oooooo0_l00000
1?oooooo0000o`000?l00006ooooo`;o00002Oooool3o`0000Gooooo1?l0000?ooooo`Go00002_oo
ool2o`0000?ooooo0_l00004ooooo`;o00007_ooool3o`0000?ooooo0_l0000jooooo`007?ooool0
0ol0003oooooooooo`0gooooo`;o00002?ooool2o`0000cooooo8Ol00003ooooo`;o000000?ooooo
o`000?l000008oooool2o`0000[ooooo0_l00009ooooo`Co00001?ooool2o`0000;ooooo0_l00002
ooooo`;o00004oooool5o`0002_ooooo0_l00004ooooo`;o0000>_ooool001cooooo0_l0001;oooo
o`Co000000?oooooo`000?l000006ol000001?oooooo0000o`000?l00006ooooo`;o00002oooool4
o`0000Wooooo0_l00006ooooo`;o000000Coooooo`000?l0003o00001oooool5o`0000Sooooo1?l0
00000ooooooo0000o`000003o`0000;ooooo1_l00006ooooo`;o00002oooool5o`0002Sooooo0_l0
0007ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0B_ooool4o`000003ooooool0003o
000001_o000000Coooooo`000?l0003o00000oooool2o`0000Kooooo0_l00006ooooo`Co00002Ooo
ool2o`0000Kooooo0_l000001?oooooo0000o`000?l00007ooooo`;o000000?oooooo`000?l00000
0_l00002ooooo`;o00001Oooool5o`0000Kooooo0_l00008ooooo`;o00001Oooool2o`00013ooooo
0_l0000Oooooo`;o0000@oooool001cooooo00?o0000ooooooooool09_ooool2o`0001gooooo0_l0
0004ooooo`?o000000?oooooo`000?l000005Ol000000ooooooo0000o`000006o`0000;ooooo1?l0
0006ooooo`;o00001Oooool2o`000003ooooool0003o000002?ooooo0_l00002ooooo`;o00001Ooo
ool4o`0001Sooooo0_l0000@ooooo`;o0000I?ooool001cooooo00?o0000ooooooooool09_ooool2
o`0001Kooooo0_l00005ooooo`;o00001Oooool2o`000003ooooool0003o000001go00000oooool2
o`0000Gooooo0_l000000ooooooo0000o`000005ooooo`;o00002oooool2o`0000Kooooo0_l00002
ooooo`;o00004Oooool2o`0000Oooooo0_l000000ooooooo0000o`000002o`0000oooooo0_l0000:
ooooo`;o00004_ooool2o`0005[ooooo000Looooo`03o`000?oooooooooo03Gooooo1?l00005oooo
o`;o00003oooool8o`000003ooooool0003o000001Co00002_ooool2o`000004ooooool0003o0000
ooooo`;o00000_ooool5o`000003ooooool0003o000000;o00000oooool2o`0000Kooooo0_l00002
ooooo`;o00004Oooool2o`0000Wooooo1Ol0000?ooooo`?o00002Oooool2o`0000?ooooo0_l0000=
ooooo`;o0000F_ooool001cooooo00?o0000ooooooooool0=Oooool4o`0001Sooooo2Ol000000ooo
oooo0000o`00000Ao`0000Sooooo1?l00004ooooo`;o00000oooool4o`000003ooooool0003o0000
00;o00002?ooool2o`000003ooooool0003o000000;ooooo0_l00006ooooo`Co00004_ooool2o`00
0003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000004ooooo`;o00000_ooool2o`00
00kooooo0_l0000Mooooo`Co00003?ooool2o`0003[ooooo000Looooo`03o`000?oooooooooo04co
oooo0_l000000ooooooo0000o`00000Mo`000003ooooool0003o000000;o000000?oooooo`000?l0
00000_l00006ooooo`;o00000_ooool3o`0000oooooo0_l000000ooooooo0000o`000002ooooo`;o
00001_ooool4o`0001Gooooo0_l00002ooooo`?o000000?oooooo`000?l000001?ooool3o`0000Co
oooo0_l00003ooooo`;o00003Oooool2o`0000Cooooo0ol0000?ooooo`Co00003?ooool2o`0003[o
oooo000Looooo`03o`000?oooooooooo037ooooo0_l0000Iooooo`;o000000?oooooo`000?l00000
6ol00003ooooo`Co000000?oooooo`000?l000002?ooool2o`0000;ooooo0ol0000Fooooo`;o0000
0_ooool2o`0001oooooo0_l00002ooooo`;o00001Oooool5o`000004ooooool0003o0000ooooo`Go
00003?ooool2o`0000Cooooo0ol0000?ooooo`;o000000?oooooo`000?l00000Aoooool001cooooo
00?o0000ooooooooool0<Oooool2o`000004ooooool0003o0000o`0000Sooooo0_l0000Aoooooa[o
00002?ooool2o`0000Wooooo1_l0000Fooooo`;o00000_ooool2o`000003ooooool0003o000000Wo
oooo0_l00007ooooo`Co00001_ooool2o`0000;ooooo0_l00006ooooo`Co00001?ooool2o`000003
ooooool0003o000000;ooooo0_l0000Sooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o
0000>_ooool001cooooo00?o0000ooooooooool0<?ooool3o`000004ooooool0003o0000o`0000So
oooo0ol0000=ooooo`Co000000?oooooo`000?l000005Ol0000Dooooo`Co00001Oooool2o`0001?o
oooo0_l00003ooooo`;o00000_ooool2o`0000Gooooo1_l00003ooooo`Ko00001_ooool2o`0001Oo
oooo0_l0000Sooooo`?o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l00008ooooo`;o
0000<?ooool001cooooo00?o0000ooooooooool0<?ooool2o`0000kooooo0ol00006ooooo`;o0000
1?ooool4o`000003ooooool0003o000000co000000?oooooo`000?l000001_l00003ooooo`;o0000
0oooool2o`0000?ooooo0_l00005ooooo`?o00001_ooool2o`0000kooooo1?l000000ooooooo0000
o`000002o`0000Gooooo0_l00007ooooo`Ko00000_ooool2o`000004ooooool0003o0000ooooo`;o
00000oooool2o`0001;ooooo0_l0000Yooooo`;o00005?ooool2o`00033ooooo000Looooo`03o`00
0?oooooooooo043ooooo0ol00006ooooo`;o00002OoooolHo`0000;ooooo0_l00003ooooo`;o0000
0oooool2o`000003ooooool0003o000000?o00001_ooool3o`0000_ooooo0_l00002ooooo`Ko0000
00Coooooo`000?l0003o00003oooool7o`0000Gooooo0ol0000:ooooo`Co00002?ooool2o`0003Go
oooo0_l0000jooooo`007?ooool00ol0003oooooooooo`11ooooo`;o00005Oooool2o`000003oooo
ool0003o000000Wo000000?oooooo`000?l000000ol0000?ooooo`Go00001_ooool3o`0000_ooooo
1?l00004ooooo`;o00000_ooool2o`0000Wooooo0_l00002ooooo`Wo00001Oooool3o`0000Sooooo
1_l0000Looooo`;o00005oooool5o`0000Gooooo0_l0000jooooo`007?ooool00ol0003ooooooooo
o`0dooooo`;o00001Oooool2o`0000Sooooo1?l0000?ooooo`;o00000_ooool:o`000004ooooool0
003o0000o`0000Kooooo0_l0000;ooooo`?o00000_ooool2o`0001;ooooo0_l00006ooooo`Go0000
1oooool3o`000003ooooool0003o000000Ko00001oooool7o`000004ooooool0003o0000ooooo`Oo
00002Oooool3o`0000oooooo0_l0000Gooooo`Go0000@Oooool001cooooo00?o0000ooooooooool0
=?ooool2o`0000Gooooo0_l00008ooooo`Co000000?oooooo`000?l000000_ooool2o`0000Sooooo
0_l00005ooooo`Ko000000?oooooo`000?l000000ol00005ooooo`;o00001oooool2o`0000Oooooo
0_l00003ooooo`;o00003?ooool2o`0000Oooooo1Ol00007ooooo`;o000000Coooooo`000?l0003o
00003_ooool9o`0000;ooooo0_l000001?oooooo0000o`000?l00003ooooo`;o00001?ooool3o`00
02Oooooo1_l00011ooooo`007?ooool00ol0003oooooooooo`1:ooooo`Ko00003oooool2o`0000;o
oooo0_l000000ooooooo0000o`000003o`0000_ooooo1Ol0000<ooooo`;o00003?ooool4o`0001Co
oooo0ol0000:ooooo`;o00000_ooool7o`0000Oooooo0ol00003ooooo`;o00001Oooool2o`0000Co
oooo0_l00003ooooo`;o00006oooool3o`0000;ooooo0ol00010ooooo`007?ooool2o`0003?ooooo
0_l0000@ooooo`;o00001_ooool2o`00017ooooo0_l00006ooooo`Co00000oooool4o`0000Cooooo
1Ol0000Gooooo`;o00000_ooool3o`0000Kooooo0_l00009ooooo`;o00000_ooool4o`0000Oooooo
0ol00004ooooo`Go00004_ooool4o`0000Cooooo0_l00002ooooo`?o00006oooool3o`000003oooo
ool0003o000000;o0000@?ooool001cooooo00?o0000ooooooooool0<_ooool2o`00013ooooo0_l0
0005ooooo`;o00001Oooool2o`0001Cooooo0ol00003ooooo`Co000000Coooooo`000?l0003ooooo
1Ol0000@ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00006ooooo`?o0000
1Oooool2o`0000;ooooo0ol000000ooooooo0000o`000002o`0000Oooooo0_l00004ooooo`Co0000
4?ooool2o`0000;ooooo0_l00003ooooo`Go00000_ooool2o`000004ooooool0003o0000ooooo`;o
00005_ooool3o`000003ooooool0003o000000Kooooo0_l0000jooooo`007?ooool00ol0003ooooo
ooooo`0^ooooo`;o00006oooool2o`0000Gooooo0_l00005ooooo`;o00005?ooool6o`000003oooo
ool0003o000000gooooo0_l00004ooooo`;o000000?oooooo`000?l000003Oooool4o`0000Gooooo
1?l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000000_l00003ooooo`Oo0000
2?ooool2o`0000Oooooo0_l00007ooooo`Co00001_ooool2o`000003ooooool0003o0000027ooooo
0ol0000jooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00007?ooool2o`0000_ooooo0_l0
0002ooooo`;o000000Coooooo`000?l0003ooooo2Ol000000ooooooo0000o`000005o`00017ooooo
0_l0000<ooooo`;o00001Oooool2o`000003ooooool0003o000000Kooooo1Ol00002ooooo`;o0000
0oooool7o`0000?ooooo2?l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo
0000o`00000/ooooo`?o00000_ooool2o`0000Oooooo0_l0000kooooo`007?ooool00ol0003ooooo
ooooo`1<ooooo`;o00000oooool2o`0000Kooooo0_l00002ooooo`;o000000Coooooo`000?l0003o
oooo3ol000000ooooooo0000o`00000Nooooo`;o00001Oooool2o`0000Wooooo1?l00003ooooo`;o
00000_ooool6o`0000;ooooo0ol000000ooooooo0000o`000005o`000003ooooool0003o000000Go
00000_ooool2o`000003ooooool0003o000000;o00004?ooool2o`0000?ooooo0_l0000Cooooo`?o
00000_ooool2o`0000Kooooo0ol0000kooooo`007?ooool00ol0003oooooooooo`0dooooo`;o0000
2_ooool2o`0000Gooooo0_l00008ooooo`Co00001?ooool2o`0000kooooo1?l00006ooooo`;o0000
6Oooool2o`0000Wooooo0_l000000ooooooo0000o`00000@oooooaGo000000?oooooo`000?l00000
1Ol00006ooooo`?o00001oooool2o`0000Oooooo0_l00003ooooo`;o00008?ooool2o`0000Gooooo
0_l0000eooooo`007?ooool00ol0003oooooooooo`0dooooo`;o00002_ooool2o`0000Gooooo0_l0
000:ooooo`Co00002Oooool2o`0002cooooo0_l00009ooooo`;o000000?oooooo`000?l000003Ooo
ool2o`000003ooooool0003o000001;o000000?oooooo`000?l000001Ol0000>ooooo`So00007Ooo
ool2o`0000;ooooo1Ol0000<ooooo`;o0000=Oooool001cooooo00?o0000ooooooooool0>Oooool2
o`0000Kooooo0_l0000;ooooo`;o00001Oooool2o`0000Wooooo0_l0000Kooooo`;o00002oooool2
o`0000cooooo0_l0000Aooooob7o00002?ooool2o`0000;ooooo2?l00009ooooo`;o00004_ooool2
o`0000;ooooo1Ol00002ooooo`;o00002?ooool2o`0003Gooooo000Looooo`03o`000?oooooooooo
03Sooooo0ol00006ooooo`;o00002oooool2o`0001Sooooo0_l0000Cooooo`?o00000oooool2o`00
00Gooooo0_l0000<ooooo`?o00001?ooool2o`0000Sooooo8ol00008ooooo`;o00000oooool3o`00
00;ooooo0_l00003ooooo`;o00000oooool3o`0001Gooooo1?l00004ooooo`;o0000?oooool001co
oooo00?o0000ooooooooool0:Oooool2o`0000gooooo0_l0000^ooooo`;o00001Oooool2o`0000co
oooo0ol00003ooooo`;o00001Oooool2o`0000cooooo0ol00004ooooo`;o00001Oooool2o`000003
ooooool0003o000000;o000000?oooooo`000?l000006_l0000@ooooo`?o000000?oooooo`000?l0
00000oooool2o`0000?ooooo0_l0000Fooooo`Co0000AOooool001cooooo00?o0000ooooooooool0
:Oooool2o`0001Sooooo0_l000000ooooooo0000o`00000Wooooo`;o00003?ooool2o`0000Cooooo
0_l00005ooooo`;o00005Oooool2o`0000?ooooo1?l000000ooooooo0000o`00000Qo`0000cooooo
0ol0000Uooooo`;o0000AOooool001cooooo00?o0000ooooooooool0@oooool2o`000003ooooool0
003o000004[ooooo0_l0000=ooooo`;o00001OoooolVo`0000cooooo0_l00005ooooo`;o0000I_oo
ool001cooooo00?o0000ooooooooool0I?ooool2o`0001Cooooo0_l00002ooooo`;o00004_ooool2
o`0000Kooooo1?l0000:ooooob;o00001Oooool4o`0000Oooooo0_l00005ooooo`;o00008oooool2
o`00047ooooo000Looooo`03o`000?oooooooooo06Cooooo0_l0000:ooooo`Go00001Oooool2o`00
00;ooooo0_l00004ooooo`Co00004_ooool4o`0000[ooooo8_l00005ooooo`Go00003oooool3o`00
01kooooo1?l00011ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool0
1Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0>oooool2o`0000Cooooo0_l0
000]ooooo`So00001_ooool2o`0000Cooooo1?l00009ooooo`;o00000oooool2o`0000gooooo0_l0
00000ooooooo0000o`00000Lo`000005ooooool0003o0000o`000?ooool00_l00004ooooo`Go0000
0oooool4o`000003ooooool0003o000000?ooooo0ol0000Nooooo`;o0000@oooool00006oooooomg
MgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06oooo
o`03o`000?oooooooooo02Wooooo0_l0000@ooooo`;o00001?ooool2o`0002?ooooo0_l000000ooo
oooo0000o`000004ooooo`;o00000oooool4o`0000gooooo0ol000000ooooooo0000o`000006oooo
o`;o00000oooool2o`0000[ooooo0_l000001?oooooo0000o`000?oooolRo`000003ooooool0003o
000000Oooooo0_l00003ooooo`Co000000?oooooo`000?l000009Oooool3o`00047ooooo00000ooo
oooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo02Wooooo0_l0000Nooooo`?o00006_ooool2o`000003ooooool0003o
000000Cooooo0_l0000Eooooo`;o000000?oooooo`000?l000005oooool2o`0000?ooooo8ol0000?
ooooo`?o0000:?ooool4o`00047ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000BOooool3o`0003gooooo0_l0000B
ooooo`Co00000oooool2o`000003ooooool0003o0000027o00002_ooool2o`0000?ooooo0ol0000L
ooooo`?o00000oooool3o`0000?ooooo0_l00013ooooo`0000?oooooo`000?ooool00_ooool00ol0
003oooooooooo`09ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0k
ooooo`;o0000C?ooool2o`000003ooooool0003o000000Gooooo0_l00008ooooo`Co00000ooooolM
o`000003ooooool0003o000000Ko00002_ooool2o`000003ooooool0003o000000?o00007?ooool3
o`0000?ooooo0ol00018ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09oooo
o`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0>oooool2o`0002Wooooo0_l00004oooo
o`;o00003Oooool2o`0000oooooo0_l00005ooooo`;o00001_ooool4o`000004ooooool0003o0000
ooooobKo00003_ooool6o`0000Sooooo0_l0001Rooooo`0000KoooooogMgMonHV9SooooooiRHV?mg
MgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0I_ooool2o`0000Cooooo0_l0
000=ooooo`?o00007Oooool4o`000004ooooool0003o0000ooooobGo00001Oooool2o`0000Gooooo
0_l000001?oooooo0000o`000?ooool6o`000003ooooool0003o000000;ooooo0_l0000Looooo`;o
0000A?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106
ooooo`03o`000?oooooooooo03cooooo0_l0000>ooooo`;o00008Oooool2o`0000Cooooo1?l00003
ooooo`Co00006_ooool2o`0000Kooooo1?l00002ooooob7o00001?ooool2o`0000Gooooo0_l00000
1?oooooo0000o`000?ooool6o`000004ooooool0003o0000ooooo`;o00006_ooool2o`000003oooo
ool0003o000000Kooooo0_l0000looooo`007?ooool00ol0003oooooooooo`0looooo`;o00003_oo
ool2o`0001[ooooo0_l00004ooooo`?o00000oooool7o`0000?ooooo0_l00003ooooo`;o00004Ooo
ool6o`0000Kooooo1?l00002ooooob7o00003_ooool2o`000003ooooool0003o000000Go00000ooo
ool2o`0001[ooooo0_l00009ooooo`;o0000??ooool001cooooo00?o0000ooooooooool0=Oooool2
o`00033ooooo0ol000000ooooooo0000o`00000>o`0000Sooooo0_l0000Aooooo`Co00002_ooool2
o`000003ooooool0003o000001_o000000?oooooo`000?l000000_l0000Aooooo`Oo00000oooool2
o`0001Gooooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o00001Oooool2o`00
0003ooooool0003o000000Oooooo1?l00007ooooo`;o00000_ooool2o`0000?ooooo0_l0000Coooo
o`;o000000?oooooo`000?l000003_l00003ooooo`;o00001?ooool3o`0000Kooooo0_l00005oooo
o`;o00001oooool2o`000003ooooool0003o000000?ooooo8Ol0000Gooooo`Co00005Oooool2o`00
00Cooooo0_l00007ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0:oooool2o`0000Go
oooo0_l00007ooooo`;o000000?oooooo`000?l000000_l00007ooooo`;o00000_ooool3o`0000;o
oooo0_l0000Cooooo`;o000000?oooooo`000?l000005?l00004ooooo`;o00001_ooool2o`0000Go
oooo1?l00005ooooo`;o000000?oooooo`000?l000000ooooolQo`0000;ooooo0_l00009ooooo`;o
00008Oooool2o`0000?ooooo0_l00002ooooo`;o00001?ooool2o`0000;ooooo0_l0000oooooo`00
7?ooool00ol0003oooooooooo`0kooooo`;o00000_ooool2o`0000gooooo0_l0000Booooo`;o0000
0ooooolFo`000003ooooool0003o000000gooooo0_l00004ooooo`Co000000?oooooo`000?l00000
1Oooool<o`000003ooooool0003o000000Co000000?oooooo`000?l000002ol00005ooooo`Co0000
00Coooooo`000?l0003o00001Oooool2o`0000oooooo0_l0000Eooooo`;o00000_ooool2o`0000So
oooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00008oooool2o`0000?ooooo
7?l00003ooooo`;o00001Oooool2o`0000Cooooo2Ol000000ooooooo0000o`000007o`000003oooo
ool0003o000000So00000_ooool?o`0000?ooooo0_l00003ooooo`?o00004_ooool2o`0000;ooooo
0_l0001Tooooo`007?ooool00ol0003oooooooooo`0mooooo`;o000000?oooooo`000?l000008?oo
ool2o`0000?ooooo7?l00003ooooo`Co00002Oooool2o`0000;ooooo0_l000001?oooooo0000o`00
0?ooool7o`0000?ooooo3ol000000ooooooo0000o`00000?o`0000Kooooo0_l0000?ooooo`;o0000
0_ooool2o`0001?ooooo0_l000000ooooooo0000o`00001<ooooo`007?ooool00ol0003ooooooooo
o`10ooooo`;o00008?ooool2o`0000Cooooo6?l000000ooooooo0000o`000004ooooo`Oo00001Ooo
ool2o`0000Gooooo0_l00003ooooo`Oo000000?oooooo`000?l000002_l000000ooooooo0000o`00
000Bo`0000Kooooo0_l0000Xooooo`;o000000?oooooo`000?l00000C?ooool001cooooo00?o0000
ooooooooool0@_ooool2o`0002;ooooo7Ol000001?oooooo0000o`000?ooool2o`000003ooooool0
003o000000;o00002_ooool6o`0000?ooooo1Ol000000ooooooo0000o`000003o`000003ooooool0
003o000001?o00000_ooool<o`0000Oooooo0_l0000=ooooo`;o00001oooool2o`00013ooooo0_l0
0016ooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00000oooool2o`0001gooooo8_l00002
ooooo`;o00003?ooool3o`000003ooooool0003o000000?ooooo8Ol00002ooooo`[o00002Oooool2
o`0000cooooo0ol00007ooooo`Co00003_ooool2o`0004Kooooo000Looooo`03o`000?oooooooooo
03Sooooo0_l0000=ooooo`;o00001oooool2o`0001Cooooo0_l000000ooooooo0000o`00000Fo`00
00;ooooo1Ol00002ooooo`?o00003?ooool2o`0000Oooooo7Ol000001?oooooo0000o`000?ooool5
o`0000?ooooo0_l0000:ooooo`;o00000oooool2o`0000Oooooo0_l00006ooooo`;o00000_ooool2
o`0000Cooooo0_l0000;ooooo`;o0000@oooool001cooooo0_l0000fooooo`;o000000?oooooo`00
0?l000005_ooool2o`000004ooooool0003o0000ooooo`;o00002oooool4o`000003ooooool0003o
000001Ko00000_ooool5o`0000?ooooo0ol0000<ooooo`;o00000_ooool2o`0000?ooooo0_l00003
ooooo`Wo000000?oooooo`000?l000003?l00003ooooo`Go00001?ooool2o`0000oooooo0_l00007
ooooo`;o00001_ooool2o`0000Sooooo0_l0000;ooooo`;o0000@oooool001cooooo00?o0000oooo
ooooool0=Oooool2o`0001cooooo0_l000000ooooooo0000o`00000;oooooago00000_ooool2o`00
00_ooooo0_l00008ooooo`;o00000_ooool3o`0000;ooooo0_l00003ooooo`_o000000?oooooo`00
0?l000002?l00002ooooo`;o000000?oooooo`000?l000000_l0000>ooooo`;o00003oooool2o`00
06;ooooo000Looooo`03o`000?oooooooooo03Oooooo0_l0000Wooooo`;o000000?oooooo`000?l0
00000_ooool:o`0000;ooooo2_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l00007oooo
o`;o000000?oooooo`000?l000002_ooool2o`000003ooooool0003o000000;o000000?oooooo`00
0?l000005Ol00002ooooo`;o000000?oooooo`000?l000000_l0000>ooooo`;o00009?ooool2o`00
04gooooo000Looooo`03o`000?oooooooooo03Oooooo0_l0000?ooooo`;o00005_ooool4o`0000?o
oooo7?l00003ooooo`Co00002?ooool2o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o
000000?oooooo`000?l000000_l000000ooooooo0000o`000002o`000003ooooool0003o000000Ko
000000Goooooo`000?l0003o0000ooooo`03o`000003ooooool0003o000000;ooooo1_l000000ooo
oooo0000o`00000Fooooo`;o00004_ooool3o`0000Cooooo0_l00004ooooo`;o0000Aoooool001co
oooo00?o0000ooooooooool0=oooool2o`0000gooooo1?l0000Fooooo`Co00000_oooolKo`0000;o
oooo1ol00002ooooo`;o000000?oooooo`000?l000001?ooool2o`0000?ooooo0ol000001?oooooo
0000o`000?ooool4o`000003ooooool0003o000000;o000000?oooooo`000?l000000_l00004oooo
o`Co000000?oooooo`000?l000003ol0000Fooooo`;o00000_ooool2o`0000kooooo0ol00005oooo
o`;o00000oooool2o`0004Oooooo000Looooo`03o`000?oooooooooo03[ooooo0_l0000:ooooo`;o
00006?ooool2o`0000Cooooo0ol000000ooooooo0000o`00000?o`000003ooooool0003o000000?o
000000?oooooo`000?l000001_l00002ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Co
oooo0_l000000ooooooo0000o`000006ooooo`;o00000oooool?o`000003ooooool0003o000000Oo
00000_ooool4o`0000oooooo0_l00004ooooo`Ko00001?ooool2o`00013ooooo0_l0001<ooooo`00
7?ooool00ol0003oooooooooo`0gooooo`;o000000?oooooo`000?l000008oooool2o`0000Kooooo
1?l000000ooooooo0000o`00000=o`000003ooooool0003o000000?o000000?oooooo`000?l00000
0oooool2o`0000Sooooo0_l00002ooooo`;o00003oooool2o`0000?ooooo0_l00002ooooo`oo0000
00?oooooo`000?l000000oooool6o`000003ooooool0003o000000cooooo0_l000001?oooooo0000
o`000?ooool4o`0000Kooooo0_l0000Booooo`;o0000B_ooool001cooooo00?o0000ooooooooool0
=oooool4o`0000?ooooo0_l00003ooooo`;o00004oooool2o`0000Gooooo0_l00008ooooo`;o0000
0_ooool4o`0000gooooo1_l0000=ooooo`;o00003Oooool2o`0000[ooooo0_l00002oooooaSo0000
0oooool2o`0000oooooo0_l0000;ooooo`;o000000?oooooo`000?l000003oooool2o`0004[ooooo
000Looooo`03o`000?oooooooooo03Wooooo0_l00003ooooo`;o00000oooool2o`0001?ooooo0_l0
000>ooooo`;o00001Oooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o00000_oo
ool4o`000003ooooool0003o000001Wooooo0_l00002ooooo`Co00001?ooool2o`0000;ooooo0_l0
00000ooooooo0000o`000004o`000003ooooool0003o000000Wo000000Coooooo`000?l0003o0000
8?ooool2o`000003ooooool0003o000005_ooooo000Looooo`03o`000?oooooooooo05oooooo0_l0
0007ooooo`;o00000_ooool3o`0000?ooooo0_l00002ooooo`;o00000_ooool4o`0000Oooooo0_l0
0008ooooo`Co00003_ooool7o`0000;ooooo0_l00006ooooo`?o000000Goooooo`000?l0003o0000
ooooo`0:o`0000;ooooo0ol0000<ooooo`;o0000L_ooool001cooooo00?o0000ooooooooool0Gooo
ool2o`0000Gooooo0_l00004ooooo`?o00000_ooool2o`0000Oooooo0_l00008ooooo`;o000000Co
ooooo`000?l0003o00001Oooool4o`0000[ooooo0_l00002ooooo`Co00001Oooool2o`0000Kooooo
0ol000000ooooooo0000o`00000:o`0000Cooooo0ol0000<ooooo`;o00008?ooool3o`0004oooooo
000Looooo`03o`000?oooooooooo03kooooo0_l0000Vooooo`;o00001Oooool6o`00017ooooo0_l0
00001?oooooo0000o`000?l00003ooooo`;o00003_ooool2o`0000;ooooo0ol000000ooooooo0000
o`000004ooooo`;o00001_ooool8o`0000?ooooo0ol0000Eooooo`;o00007oooool3o`0004oooooo
000Looooo`03o`000?oooooooooo03_ooooo0_l000000ooooooo0000o`00000Tooooo`;o00002Ooo
ool2o`0001;ooooo0_l00008ooooo`?o00004Oooool6o`0000Cooooo0_l00003ooooo`;o000000?o
ooooo`000?l000001_l00004ooooo`Co00004oooool2o`0000cooooo0_l00002ooooo`;o0000Gooo
ool001cooooo00?o0000ooooooooool0>oooool2o`0000Cooooo0_l0000Nooooo`;o000000?ooooo
o`000?l000007Oooool4o`0000Oooooo0_l00003ooooo`;o00003_ooool2o`0000Cooooo1?l00003
ooooo`;o00000oooool2o`0000;ooooo0_l00005ooooo`Go00007oooool2o`0000;ooooo0_l0000=
ooooo`;o0000D?ooool001cooooo00?o0000ooooooooool0?oooool4o`0000Gooooo0_l0000Goooo
o`;o00004oooool2o`000003ooooool0003o000000Oooooo1Ol00003ooooo`Co00000oooool5o`00
01?ooooo1?l00006ooooo`Go000000?oooooo`000?l000002_l0000Oooooo`;o000000?oooooo`00
0?l000001Oooool2o`0000Oooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`0jooooo`;o
00000oooool2o`0000Oooooo0_l0000/ooooo`;o000000?oooooo`000?l000000oooool2o`0000;o
oooo0_l000000ooooooo0000o`000003ooooo`Ko000000Coooooo`000?l0003ooooo0ol000000ooo
oooo0000o`00000<ooooo`;o00002oooool5o`000003ooooool0003o000000Oo00001_ooool2o`00
00Wooooo0_l0000?ooooo`;o000000?oooooo`000?l000001Oooool2o`0005Wooooo000Looooo`;o
0000>oooool2o`0000cooooo0_l0000Hooooo`;o00000oooool2o`0000Wooooo0_l0000:ooooo`;o
00001Oooool2o`0000Kooooo0ol000000ooooooo0000o`000004o`000003ooooool0003o000000_o
oooo0ol0000>ooooo`co00001_ooool2o`0000Wooooo0_l0000<ooooo`;o00006Oooool2o`0004_o
oooo000Looooo`03o`000?oooooooooo04;ooooo0_l0000Nooooo`;o00000oooool2o`0000Wooooo
0_l0000Iooooo`;o00000oooool3o`0000Kooooo0_l00008ooooo`?o00002?ooool2o`0000Gooooo
1ol0000@ooooo`;o00000_ooool3o`000004ooooool0003o0000ooooo`;o00001Oooool3o`0000ko
oooo0_l00009ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0=oooool2o`0000Wooooo
0_l0000Nooooo`;o0000:Oooool2o`0000?ooooo1?l00005ooooo`;o00002Oooool2o`0000Sooooo
1?l00006ooooo`Co00003Oooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`Go0000
0oooool4o`0000oooooo0ol0001Eooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00001Ooo
ool2o`0002;ooooo0_l0000Iooooo`;o000000Coooooo`000?l0003o00001oooool3o`0000Oooooo
0_l00006ooooo`?o00002?ooool2o`0000Cooooo0_l00003ooooo`;o00001Oooool2o`0000;ooooo
0ol0000:ooooo`Ko00001_ooool4o`0000Cooooo0_l000000ooooooo0000o`00000;ooooo`;o0000
0_ooool2o`0005Gooooo000Looooo`03o`000?oooooooooo03kooooo0_l0000_ooooo`Ko00002?oo
ool6o`0000Oooooo0ol00007ooooo`;o00001_ooool3o`0000Sooooo0_l00004ooooo`Go00001ooo
ool2o`000003ooooool0003o000000?o00002Oooool2o`000003ooooool0003o000001;ooooo0_l0
000;ooooo`;o00001Oooool2o`0005;ooooo000Looooo`03o`000?oooooooooo06?ooooo0_l0000:
ooooo`Ko00002?ooool5o`0001Gooooo0_l0000?ooooo`;o00001Oooool3o`0000?ooooo0ol00003
ooooo`?o000000?oooooo`000?l000002Oooool2o`00023ooooo0_l00007ooooo`;o0000D_ooool0
01cooooo00?o0000ooooooooool0@_ooool2o`0000Kooooo0_l0000Gooooo`;o00004?ooool2o`00
00;ooooo0_l00004ooooo`;o00005_ooool6o`0000_ooooo0_l00008ooooo`;o000000Coooooo`00
0?l0003o00000oooool2o`0000_ooooo0_l00005ooooo`;o00006oooool2o`0005_ooooo000Loooo
o`03o`000?oooooooooo04;ooooo0_l00006ooooo`;o00006_ooool2o`0000Sooooo0_l00002oooo
o`?o00000_ooool3o`0000;ooooo0ol00003ooooo`;o00004Oooool6o`00013ooooo0_l00003oooo
o`;o000000?oooooo`000?l000000_l0000?ooooo`;o00001Oooool5o`0000?ooooo0ol00006oooo
o`;o00004oooool2o`0005;ooooo000Looooo`03o`000?oooooooooo04[ooooo0_l0000Jooooo`Co
00001_ooool2o`0000;ooooo0_l00004ooooo`;o00000_ooool2o`000004ooooool0003o0000oooo
o`;o00004Oooool2o`0000;ooooo0_l00003ooooo`;o00002oooool2o`0000;ooooo0_l00002oooo
o`Co00001Oooool2o`0000Gooooo1?l000000ooooooo0000o`000002ooooo`Ko00000oooool3o`00
00Kooooo0_l00006ooooo`;o00002oooool2o`0005;ooooo000Looooo`03o`000?oooooooooo04;o
oooo0_l00006ooooo`;o00007?ooool2o`0000Wooooo0ol00004ooooo`;o00001?ooool3o`000003
ooooool0003o000000;o00005?ooool3o`000003ooooool0003o000000Gooooo0_l00004ooooo`;o
00000_ooool2o`0000_ooooo1Ol00002ooooo`Co000000?oooooo`000?l000000_ooool6o`0000Co
oooo0_l00004ooooo`;o00001_ooool4o`0000Sooooo0_l0001Eooooo`007?ooool00ol0003ooooo
ooooo`12ooooo`;o0000;oooool2o`0000?ooooo1?l00004ooooo`;o000000Coooooo`000?l0003o
oooo0_l00002ooooo`;o00001_ooool2o`0000Sooooo0ol00003ooooo`?o00000_ooool2o`0000Co
oooo0_l0000@ooooo`Oo00003?ooool2o`0000[ooooo0_l00005ooooo`?o00001Oooool2o`0000?o
oooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`1hooooo`;o00000_ooool2o`0000Gooooo
0_l00005ooooo`;o00001_ooool2o`0000Kooooo1ol000001Ooooooo0000o`000?l0003ooooo00;o
00000_ooool2o`0000[ooooo0_l00007ooooo`;o000000?oooooo`000?l000000ol00004ooooo`;o
00002oooool2o`0000Kooooo0_l00003ooooo`;o00001_ooool2o`0005[ooooo000Looooo`03o`00
0?oooooooooo06_ooooo0_l0000?ooooo`Go000000?oooooo`000?l000003_ooool2o`0000Kooooo
0_l00002ooooo`?o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00009ooooo`?o0000
1oooool2o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l000002?ooool2o`0000Gooooo
0ol0001Wooooo`007?ooool00ol0003oooooooooo`1[ooooo`;o00000oooool3o`0000Sooooo1_l0
00000ooooooo0000o`000003ooooo`;o00002Oooool2o`000003ooooool0003o000000_ooooo0_l0
0002ooooo`;o00000_ooool2o`0000;ooooo0_l00005ooooo`?o00002_ooool2o`0000[ooooo0_l0
000?ooooo`;o0000J?ooool001cooooo00?o0000ooooooooool0L?ooool3o`0000Sooooo1Ol00007
ooooo`;o00003?ooool2o`0001?ooooo0_l00002ooooo`;o00001?ooool4o`0000Gooooo0_l00003
ooooo`;o00004Oooool3o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0006Oooooo000L
ooooo`03o`000?oooooooooo04Kooooo0_l0000Wooooo`Co00002Oooool2o`0000;ooooo0_l0000@
ooooo`;o00001Oooool4o`0001Oooooo1?l00005ooooo`;o00001_ooool2o`0000Oooooo0_l00005
ooooo`Co000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00001Wooooo`007?ooool2
o`0004Oooooo0_l0000Wooooo`?o00002_ooool8o`0000[ooooo0_l00002ooooo`;o00000oooool8
o`0001Kooooo0_l00005ooooo`;o00001?ooool5o`000003ooooool0003o000000Cooooo0_l00007
ooooo`;o000000?oooooo`000?l00000KOooool001cooooo00?o0000ooooooooool0E?ooool2o`00
01[ooooo0_l000000ooooooo0000o`000002o`0000Oooooo0_l000001?oooooo0000o`000?l0000:
ooooo`;o00000_ooool2o`0000?ooooo0ol00003ooooo`;o00001?ooool2o`00013ooooo0_l00005
ooooo`;o000000Coooooo`000?l0003ooooo2?l00007ooooo`;o00000oooool2o`0000;ooooo1?l0
001[ooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o00007Oooool4o`0000cooooo0_l00004
ooooo`;o00002?ooool4o`000004ooooool0003o0000ooooo`;o00001_ooool2o`0001[ooooo0_l0
0003ooooo`Co00001_ooool7o`000003ooooool0003o000000Cooooo0_l0001[ooooo`007?ooool0
0ol0003oooooooooo`20ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00002?ooool4
o`0000Cooooo0_l0000]ooooo`_o0000M?ooool001cooooo00?o0000ooooooooool0Boooool2o`00
03?ooooo0_l00002ooooo`?o000000?oooooo`000?l000001Oooool2o`0000Cooooo0_l00004oooo
o`;o00002_ooool2o`00027ooooo1Ol0001jooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o
0000>_ooool3o`0000Gooooo0_l00002ooooo`Co00004?ooool2o`0000?ooooo0_l0002Kooooo`00
7?ooool00ol0003oooooooooo`25ooooo`Go00002Oooool3o`0001;ooooo0_l00002ooooo`;o0000
1?ooool2o`0009Gooooo000Looooo`03o`000?oooooooooo07Wooooo0_l00002ooooo`;o00001_oo
ool2o`000004ooooool0003o0000o`0000Cooooo0_l00003ooooo`Co00004?ooool2o`0000Sooooo
0_l00002ooooo`;o0000TOooool001cooooo00?o0000ooooooooool0NOooool2o`0000;ooooo0_l0
0006ooooo`Ko00001?ooool2o`0000Gooooo0_l0000Nooooo`;o0000TOooool001cooooo00?o0000
ooooooooool0O?ooool2o`0000;ooooo0_l00003ooooo`?o00000oooool2o`0002?ooooo0_l0000?
ooooo`;o0000Q_ooool001cooooo00?o0000ooooooooool0H?ooool2o`0001[ooooo0_l000001?oo
oooo0000o`000?l00005ooooo`;o00000_ooool2o`0002?ooooo1Ol00003ooooo`;o00001?ooool2
o`000003ooooool0003o000000?ooooo0_l00021ooooo`007?ooool00ol0003oooooooooo`1Poooo
o`;o00007Oooool3o`0000Cooooo0ol0000Yooooo`?o00000oooool2o`0000;ooooo1?l00006oooo
o`Co0000Ooooool001cooooo00?o0000ooooooooool0DOooool2o`0002cooooo0_l00005ooooo`?o
00002?ooool2o`0001Oooooo0_l0000<ooooo`Ko00002?ooool4o`0000;ooooo0_l0001kooooo`00
7?ooool00ol0003oooooooooo`1Aooooo`;o00004Oooool2o`0001Wooooo0_l00005ooooo`Go0000
0_ooool3o`000003ooooool0003o000001Cooooo0_l000000ooooooo0000o`00000>ooooo`;o0000
1oooool2o`000003ooooool0003o000000Cooooo0ol0001jooooo`0000Koooooonk^k_lb<S;o0000
oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000oooo
ooooool0Doooool2o`0000oooooo0ol0000Iooooo`;o00000_ooool2o`000003ooooool0003o0000
00;o00000_ooool5o`0001Cooooo0ol0000:ooooo`;o00003_ooool2o`0000Sooooo0_l00005oooo
o`;o0000Loooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4Q
oiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo05?ooooo0_l0000@ooooo`;o00006Ooo
ool2o`0000;ooooo0_l00002ooooo`;o00000_ooool6o`0000[ooooo0_l00008ooooo`;o00002ooo
ool2o`0000;ooooo0_l00004ooooo`;o00003Oooool2o`0000Kooooo0_l0001cooooo`0000?ooooo
oa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`1Gooooo`;o00003oooool2o`0001Wooooo0_l00004ooooo`Oo00003?oo
ool4o`0001Oooooo0_l00004ooooo`;o00000_ooool2o`0000Wooooo1?l0001iooooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_oo
ool3o`0005Oooooo0_l0000?ooooo`;o00006Oooool2o`0000Cooooo0ol00009ooooo`;o00001ooo
ool2o`0000gooooo0_l00003ooooo`?o000000?oooooo`000?l000002Oooool4o`0000Gooooo0_l0
0002ooooo`;o0000NOooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0R_ooool2o`0000Wooooo0_l0
000=ooooo`;o00001oooool2o`0000?ooooo0ol000000ooooooo0000o`000008ooooo`Go00001Ooo
ool2o`0007gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go410@
okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo08Cooooo0_l0000Nooooo`;o00001ooo
ool2o`00017ooooo1?l00025ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`00
0?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`24ooooo`;o00002?ooool2o`0001[o
oooo0_l0000Cooooo`;o0000R?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnY
ZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0S_ooool2o`0000Cooooo0_l00003
ooooo`;o00003oooool2o`0000Kooooo0_l0000;ooooo`;o0000R?ooool001cooooo00?o0000oooo
ooooool0L?ooool3o`00027ooooo0_l00003ooooo`;o00005oooool2o`0000_ooooo0_l00028oooo
o`007?ooool00ol0003oooooooooo`1Mooooo`;o00004Oooool3o`0002;ooooo0ol0000Wooooo`;o
0000R?ooool001cooooo00?o0000ooooooooool0GOooool2o`0003Kooooo1Ol0000Hooooo`;o0000
1Oooool2o`0000Kooooo0_l00026ooooo`007?ooool00ol0003oooooooooo`1fooooo`?o00005Ooo
ool2o`0000Oooooo0ol0000:ooooo`;o00000oooool2o`000003ooooool0003o000000?ooooo0ol0
0005ooooo`;o00001_ooool2o`0008Kooooo000Looooo`03o`000?oooooooooo07Kooooo1Ol0000C
ooooo`;o00000oooool2o`0000Cooooo0_l00009ooooo`;o000000?oooooo`000?l000000_l00000
0ooooooo0000o`000003ooooo`;o0000U_ooool001cooooo00?o0000ooooooooool0NOooool3o`00
01;ooooo0_l00003ooooo`;o00001?ooool2o`0000cooooo0ol00003ooooo`;o0000V_ooool001co
oooo00?o0000ooooooooool0N_ooool2o`0001gooooo0_l0000Booooo`;o0000V_ooool001cooooo
00?o0000ooooooooool0VOooool2o`000:kooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`1`ooooo`;o0000eoooool001cooooo00?o0000oooooooo
ool0L?ooool2o`000=Oooooo000Looooo`03o`000?oooooooooo07Cooooo0_l0003Cooooo`007?oo
ool00ol0003oooooooooo`1dooooo`;o0000doooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0OOooool2o`000<[ooooo000Looooo`03o`000?oo
oooooooo07gooooo1?l00038ooooo`007?ooool00ol0003oooooooooo`1oooooo`;o0000b?ooool0
01cooooo00?o0000ooooooooool0QOooool2o`000<;ooooo000Looooo`03o`000?oooooooooo08Go
oooo0_l0000_ooooo`;o00000_ooool2o`0008gooooo000Looooo`;o0000]oooool2o`0000;ooooo
0_l0002=ooooo`007?ooool00ol0003oooooooooo`2<ooooo`;o0000^oooool001cooooo00?o0000
ooooooooool0S?ooool2o`000003ooooool0003o00000;Sooooo000Looooo`03o`000?oooooooooo
08oooooo0_l0000Nooooo`;o0000V?ooool001cooooo00?o0000ooooooooool0[oooool2o`0009So
oooo000Looooo`03o`000?oooooooooo09Oooooo0_l0000Booooo`;o0000W?ooool001cooooo00?o
0000ooooooooool0Uoooool2o`0000Cooooo0_l0000<ooooo`;o0000W?ooool001cooooo00?o0000
ooooooooool0WOooool2o`0000?ooooo0_l00002ooooo`;o0000XOooool001cooooo00?o0000oooo
ooooool0X_ooool2o`0000;ooooo0_l0002Qooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Booooo`Co000000?o410@ooooooooool0
0oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`?o0000oooooom:
ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?oo
ooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003ooooooooo
o`3ooooooe;ooooo000Booooo`03oeEEEOmVIVKo00000?ooooooE?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00:Gooooo00Co410@o`000?l0003ooooo0_l000000ol@413ooooo
ooooo`0Fooooo`05odA4A?l0003o0000oc8b<_oMgMd00oooool4o`000008oa0@4?ooooooooooonk^
k_lb<S;o0000oc8b<_o^k^j@ooooo`00Y_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l0
000=ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg093ooooo002Vooooo`05o`000?ooooooooooooooool000007Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@402@ooooo`00
Y_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l0000=ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000093ooooo002Vooooo`05
o`000?n7QhOoooooojVYZOl000006Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo0000093ooooo002Uooooo`03oa0@4?l0003o
MgMg00;o000000?oV9RHooooooooool05oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@402@ooooo`00a?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`2@ooooo`00a?ooool4
o`0000Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^093ooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(516) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.70087 .46604 Mdot
.67367 .4712 Mdot
.28003 .49581 Mdot
.55062 .64166 Mdot
.32162 .59125 Mdot
.31308 .48255 Mdot
.44587 .30099 Mdot
.42864 .28214 Mdot
.30356 .48958 Mdot
.68134 .61454 Mdot
.42095 .31776 Mdot
.61228 .57269 Mdot
.432 .30509 Mdot
.55817 .60305 Mdot
.55748 .42298 Mdot
.53744 .70611 Mdot
.66011 .41709 Mdot
.38428 .6288 Mdot
.5335 .70753 Mdot
.29615 .50307 Mdot
.48371 .70835 Mdot
.57009 .60749 Mdot
.64648 .4349 Mdot
.5617 .60331 Mdot
.51636 .61976 Mdot
.67762 .46048 Mdot
.69488 .47206 Mdot
.50542 .62732 Mdot
.5269 .65573 Mdot
.4184 .30593 Mdot
.20624 .49075 Mdot
.84789 .48823 Mdot
.5151 .58293 Mdot
.79152 .54676 Mdot
.42916 .28053 Mdot
.37922 .25256 Mdot
.27639 .47181 Mdot
.44931 .28465 Mdot
.41427 .28475 Mdot
.42022 .27934 Mdot
.45148 .29873 Mdot
.68539 .45401 Mdot
.40169 .2917 Mdot
.27781 .40464 Mdot
.5399 .59526 Mdot
.71925 .37537 Mdot
.19351 .40396 Mdot
.51131 .64186 Mdot
.70391 .43448 Mdot
.3165 .50932 Mdot
.39542 .77789 Mdot
.46443 .32337 Mdot
.54385 .36185 Mdot
.4027 .88591 Mdot
.42527 .31364 Mdot
.5458 .64896 Mdot
.32195 .49689 Mdot
.56459 .62929 Mdot
.5808 .63851 Mdot
.78684 .5153 Mdot
.58589 .60717 Mdot
.35021 .61489 Mdot
.65003 .4863 Mdot
.28353 .43512 Mdot
.31023 .49002 Mdot
.45596 .29661 Mdot
.64568 .47171 Mdot
.43284 .29333 Mdot
.52415 .66273 Mdot
.30301 .50995 Mdot
.52388 .6509 Mdot
.41689 .3107 Mdot
.65172 .47136 Mdot
.5363 .59435 Mdot
.64837 .34888 Mdot
.48663 .32981 Mdot
.3552 .51389 Mdot
.76568 .65423 Mdot
.43348 .82389 Mdot
.28672 .53444 Mdot
.55292 .58818 Mdot
.32985 .80003 Mdot
.5087 .40421 Mdot
.67608 .47431 Mdot
.62931 .4212 Mdot
.66298 .24872 Mdot
.50628 .63989 Mdot
.38111 .53168 Mdot
.55046 .56534 Mdot
.46474 .53283 Mdot
.29599 .49025 Mdot
.65995 .46526 Mdot
.54082 .59087 Mdot
.54097 .57448 Mdot
.66118 .53197 Mdot
.5542 .66137 Mdot
.5415 .62744 Mdot
.6178 .46421 Mdot
.43163 .32823 Mdot
.61213 .54733 Mdot
.28139 .65655 Mdot
.54187 .37665 Mdot
.53518 .63897 Mdot
.29537 .46202 Mdot
.65565 .4916 Mdot
.53712 .61839 Mdot
.43342 .2873 Mdot
.56279 .59401 Mdot
.4308 .34748 Mdot
.66236 .42023 Mdot
.54525 .57015 Mdot
.33891 .63996 Mdot
.53535 .49576 Mdot
.67588 .4262 Mdot
.68622 .71966 Mdot
.58269 .6049 Mdot
.58307 .61793 Mdot
.68286 .46895 Mdot
.27608 .48632 Mdot
.38743 .47258 Mdot
.6443 .44735 Mdot
.41494 .28204 Mdot
.6905 .41931 Mdot
.60137 .57365 Mdot
.27925 .48987 Mdot
.55076 .36846 Mdot
.54122 .37135 Mdot
.36065 .69018 Mdot
.53665 .58957 Mdot
.57289 .5009 Mdot
.30607 .46838 Mdot
.68669 .45967 Mdot
.42703 .29721 Mdot
.5887 .64018 Mdot
.68226 .43445 Mdot
.40761 .29322 Mdot
.3578 .60805 Mdot
.32471 .58769 Mdot
.69858 .439 Mdot
.60731 .73323 Mdot
.46047 .33665 Mdot
.42182 .27623 Mdot
.39424 .77377 Mdot
.68123 .47303 Mdot
.32769 .61307 Mdot
.40467 .31066 Mdot
.44705 .72455 Mdot
.59756 .61628 Mdot
.3591 .71984 Mdot
.24861 .72902 Mdot
.39458 .77627 Mdot
.82659 .5168 Mdot
.32601 .63201 Mdot
.40332 .30832 Mdot
.52135 .64443 Mdot
.67623 .44171 Mdot
.68642 .44195 Mdot
.54072 .57689 Mdot
.52203 .60497 Mdot
.54527 .60466 Mdot
.59296 .63076 Mdot
.33952 .24745 Mdot
.54694 .58921 Mdot
.49324 .2435 Mdot
.6746 .43319 Mdot
.52438 .61242 Mdot
.29281 .45392 Mdot
.61334 .63335 Mdot
.44426 .28274 Mdot
.57523 .64072 Mdot
.5171 .61029 Mdot
.60765 .62477 Mdot
.40202 .29726 Mdot
.64007 .32377 Mdot
.51353 .83469 Mdot
.39111 .24376 Mdot
.54373 .34317 Mdot
.3198 .47255 Mdot
.57643 .5853 Mdot
.33323 .6295 Mdot
.62249 .57598 Mdot
.58723 .62748 Mdot
.3963 .78261 Mdot
.51732 .59976 Mdot
.81252 .57517 Mdot
.58904 .53986 Mdot
.64578 .23293 Mdot
.50857 .22733 Mdot
.59147 .62434 Mdot
.67071 .65983 Mdot
.35243 .70833 Mdot
.18886 .50475 Mdot
.42174 .30153 Mdot
.29535 .44858 Mdot
.27088 .47704 Mdot
.43504 .27342 Mdot
.49199 .58046 Mdot
.68729 .62509 Mdot
.54914 .6656 Mdot
.54974 .37056 Mdot
.7129 .39994 Mdot
.31908 .62301 Mdot
.69974 .43986 Mdot
.35881 .81743 Mdot
.39263 .56531 Mdot
.30288 .53095 Mdot
.37664 .61436 Mdot
.33319 .50085 Mdot
.56376 .37859 Mdot
.32575 .61951 Mdot
.54971 .63351 Mdot
.67816 .41957 Mdot
.34728 .71096 Mdot
.55916 .6913 Mdot
.49826 .1232 Mdot
.66411 .47952 Mdot
.50286 .48286 Mdot
.42497 .30785 Mdot
.27783 .44028 Mdot
.50619 .63928 Mdot
.55754 .61926 Mdot
.66204 .48825 Mdot
.51736 .64924 Mdot
.40695 .51691 Mdot
.51499 .60825 Mdot
.30564 .43805 Mdot
.36677 .65654 Mdot
.42099 .34809 Mdot
.38041 .61052 Mdot
.64709 .46343 Mdot
.48418 .28775 Mdot
.29367 .45837 Mdot
.4993 .54625 Mdot
.4191 .29448 Mdot
.36296 .61508 Mdot
.28155 .4684 Mdot
.34859 .64431 Mdot
.56906 .57043 Mdot
.27921 .47982 Mdot
.34054 .60671 Mdot
.42844 .41154 Mdot
.54022 .62777 Mdot
.39103 .71614 Mdot
.42352 .33334 Mdot
.70156 .46141 Mdot
.59007 .61597 Mdot
.55907 .36554 Mdot
.61071 .59922 Mdot
.55711 .48268 Mdot
.57037 .38342 Mdot
.55382 .40012 Mdot
.31787 .53832 Mdot
.33338 .59715 Mdot
.62555 .37235 Mdot
.41566 .45835 Mdot
.65867 .41751 Mdot
.57666 .57461 Mdot
.70316 .31416 Mdot
.42167 .33338 Mdot
.55349 .63412 Mdot
.64059 .24497 Mdot
.40439 .31142 Mdot
.5726 .62785 Mdot
.45341 .30542 Mdot
.68231 .43995 Mdot
.47219 .40369 Mdot
.70759 .43 Mdot
.55539 .64114 Mdot
.44604 .32119 Mdot
.2895 .45058 Mdot
.67741 .45975 Mdot
.56866 .59865 Mdot
.55453 .58444 Mdot
.55188 .37334 Mdot
.52998 .601 Mdot
.71505 .30155 Mdot
.51035 .63965 Mdot
.32787 .50883 Mdot
.53933 .66195 Mdot
.32451 .71694 Mdot
.32991 .58397 Mdot
.63709 .44919 Mdot
.57006 .38781 Mdot
.29575 .4928 Mdot
.45579 .40496 Mdot
.38035 .67463 Mdot
.55506 .5925 Mdot
.55167 .38955 Mdot
.5023 .47831 Mdot
.44949 .28875 Mdot
.49476 .62123 Mdot
.39588 .49502 Mdot
.29028 .48283 Mdot
.55661 .37243 Mdot
.51576 .67815 Mdot
.70511 .46503 Mdot
.53945 .64939 Mdot
.2782 .4674 Mdot
.70946 .44912 Mdot
.57351 .65164 Mdot
.2508 .32436 Mdot
.55548 .36344 Mdot
.44703 .32689 Mdot
.64233 .51681 Mdot
.56103 .5778 Mdot
.26842 .46936 Mdot
.68762 .4368 Mdot
.43582 .31995 Mdot
.65908 .42736 Mdot
.33133 .70307 Mdot
.59719 .50279 Mdot
.34074 .29035 Mdot
.38546 .6379 Mdot
.81187 .65216 Mdot
.38642 .25003 Mdot
.58254 .51275 Mdot
.35019 .45522 Mdot
.56779 .17192 Mdot
.28631 .46559 Mdot
.63388 .71216 Mdot
.30792 .49795 Mdot
.53202 .64389 Mdot
.3118 .48514 Mdot
.72453 .28872 Mdot
.5077 .61142 Mdot
.32792 .4819 Mdot
.32353 .29511 Mdot
.51875 .59581 Mdot
.67799 .43093 Mdot
.7978 .40791 Mdot
.70246 .7181 Mdot
.57436 .74713 Mdot
.32909 .49027 Mdot
.62379 .73216 Mdot
.50411 .63044 Mdot
.52887 .7052 Mdot
.67434 .44712 Mdot
.61338 .58565 Mdot
.31106 .61762 Mdot
.33211 .63972 Mdot
.43655 .76609 Mdot
.72167 .72129 Mdot
.46999 .62601 Mdot
.6815 .4531 Mdot
.41645 .81836 Mdot
.65499 .3471 Mdot
.55128 .36186 Mdot
.41721 .28546 Mdot
.6291 .32675 Mdot
.50828 .67685 Mdot
.63437 .5498 Mdot
.42588 .49192 Mdot
.65785 .46557 Mdot
.37398 .35838 Mdot
.44071 .31688 Mdot
.62367 .7519 Mdot
.70226 .58723 Mdot
.54448 .60765 Mdot
.45099 .33265 Mdot
.58467 .54536 Mdot
.41543 .49797 Mdot
.37943 .71711 Mdot
.23934 .38709 Mdot
.54783 .63647 Mdot
.63943 .36786 Mdot
.58523 .62792 Mdot
.36566 .70418 Mdot
.55717 .63741 Mdot
.66098 .42847 Mdot
.47951 .63256 Mdot
.4151 .4413 Mdot
.62022 .77725 Mdot
.3934 .5599 Mdot
.32422 .60577 Mdot
.55824 .60642 Mdot
.54961 .61815 Mdot
.34962 .61134 Mdot
.65752 .45992 Mdot
.58511 .58287 Mdot
.19656 .38927 Mdot
.54611 .58827 Mdot
.46485 .31533 Mdot
.46507 .43361 Mdot
.81441 .59841 Mdot
.51341 .59831 Mdot
.69826 .47305 Mdot
.44625 .28905 Mdot
.41111 .29776 Mdot
.47499 .63446 Mdot
.43334 .33501 Mdot
.52066 .64642 Mdot
.46681 .43291 Mdot
.6498 .42936 Mdot
.60732 .55741 Mdot
.65506 .45552 Mdot
.38601 .79594 Mdot
.40472 .31828 Mdot
.55491 .39424 Mdot
.60892 .74734 Mdot
.44317 .30476 Mdot
.42812 .60851 Mdot
.48167 .62396 Mdot
.54607 .68988 Mdot
.64023 .51173 Mdot
.28406 .45111 Mdot
.56159 .39171 Mdot
.42781 .31705 Mdot
.5456 .59095 Mdot
.53429 .62571 Mdot
.45635 .33168 Mdot
.76103 .49955 Mdot
.20646 .48764 Mdot
.55906 .64198 Mdot
.65468 .43407 Mdot
.68626 .45829 Mdot
.60143 .61925 Mdot
.58814 .62174 Mdot
.32704 .46617 Mdot
.55234 .3906 Mdot
.5658 .3923 Mdot
.53974 .3853 Mdot
.32292 .44851 Mdot
.78353 .6866 Mdot
.42169 .27613 Mdot
.83746 .52207 Mdot
.64433 .28085 Mdot
.47712 .65496 Mdot
.27294 .4659 Mdot
.56708 .62047 Mdot
.53023 .6344 Mdot
.4421 .32525 Mdot
.69983 .75211 Mdot
.51765 .57681 Mdot
.69359 .47105 Mdot
.463 .32386 Mdot
.6069 .56478 Mdot
.44769 .26458 Mdot
.36088 .63712 Mdot
.51951 .72197 Mdot
.44611 .33659 Mdot
.6634 .42228 Mdot
.44855 .33614 Mdot
.54809 .61405 Mdot
.52554 .68588 Mdot
.65796 .46727 Mdot
.35996 .60321 Mdot
.55693 .57397 Mdot
.57416 .62852 Mdot
.18335 .58597 Mdot
.6484 .35109 Mdot
.29085 .61337 Mdot
.51939 .63247 Mdot
.56042 .68072 Mdot
.3729 .61829 Mdot
.5711 .57674 Mdot
.53431 .65726 Mdot
.53322 .49324 Mdot
.43961 .35069 Mdot
.32099 .59835 Mdot
.61062 .77563 Mdot
.66892 .48061 Mdot
.70202 .29048 Mdot
.54449 .37053 Mdot
.39195 .32229 Mdot
.47706 .39655 Mdot
.56103 .38367 Mdot
.62747 .251 Mdot
.40256 .22793 Mdot
.55741 .39044 Mdot
.27354 .43813 Mdot
.6425 .64638 Mdot
.53237 .65845 Mdot
.57545 .63729 Mdot
.33459 .59763 Mdot
.69392 .4632 Mdot
.50002 .24362 Mdot
.45254 .35337 Mdot
.57603 .61069 Mdot
.71625 .43906 Mdot
.6542 .24021 Mdot
.55927 .37581 Mdot
.3375 .63449 Mdot
.3489 .59554 Mdot
.58458 .62544 Mdot
.45833 .56525 Mdot
.68144 .45599 Mdot
.56867 .59876 Mdot
.58996 .60234 Mdot
.30673 .5013 Mdot
.6847 .4207 Mdot
.29856 .45453 Mdot
.57098 .39249 Mdot
.52491 .15162 Mdot
.16449 .53452 Mdot
.41614 .32736 Mdot
.38875 .34954 Mdot
.39687 .31832 Mdot
.25507 .35471 Mdot
.55379 .39175 Mdot
.56995 .60279 Mdot
.64226 .4558 Mdot
.5652 .59522 Mdot
.5439 .58885 Mdot
.54093 .61171 Mdot
.46964 .62709 Mdot
.38272 .78637 Mdot
.35173 .6303 Mdot
.50342 .64965 Mdot
.33586 .47714 Mdot
.64288 .23578 Mdot
.76251 .36531 Mdot
.5555 .61121 Mdot
.58195 .61935 Mdot
.65252 .4795 Mdot
.57144 .56991 Mdot
.43402 .28558 Mdot
.6727 .47757 Mdot
.53665 .63588 Mdot
.28429 .66878 Mdot
.58926 .58947 Mdot
.37588 .32565 Mdot
.44505 .33805 Mdot
.58052 .70049 Mdot
.53663 .68326 Mdot
.55507 .39285 Mdot
.56136 .39113 Mdot
.56549 .36872 Mdot
.46119 .3193 Mdot
.30341 .49987 Mdot
.25353 .46568 Mdot
.51934 .67354 Mdot
.51707 .64155 Mdot
.53248 .68849 Mdot
.34585 .48472 Mdot
.40922 .45289 Mdot
.64627 .3887 Mdot
.5811 .53981 Mdot
.32784 .45519 Mdot
.62201 .49102 Mdot
.64527 .75823 Mdot
.68313 .47497 Mdot
.35212 .4643 Mdot
.42214 .28821 Mdot
.32623 .63412 Mdot
.43767 .79826 Mdot
.64594 .43981 Mdot
.66855 .48683 Mdot
.32422 .47606 Mdot
.50713 .44238 Mdot
.48128 .91779 Mdot
.2982 .46593 Mdot
.34147 .54095 Mdot
.67609 .45023 Mdot
.52341 .57447 Mdot
.50365 .47386 Mdot
.52552 .45551 Mdot
.32383 .48727 Mdot
.5556 .58502 Mdot
.4246 .58957 Mdot
.32739 .46696 Mdot
.49285 .6158 Mdot
.33043 .48834 Mdot
.44516 .33125 Mdot
.30794 .4655 Mdot
.69946 .41073 Mdot
.541 .5868 Mdot
.42648 .89785 Mdot
.50427 .39403 Mdot
.57464 .59723 Mdot
.46069 .32957 Mdot
.30265 .29049 Mdot
.5465 .62083 Mdot
.31356 .61568 Mdot
.33509 .46231 Mdot
.2352 .37787 Mdot
.53816 .65626 Mdot
.31881 .48481 Mdot
.68414 .40395 Mdot
.34651 .45438 Mdot
.28317 .61919 Mdot
.5641 .39211 Mdot
.67967 .43836 Mdot
.53732 .39776 Mdot
.43369 .27912 Mdot
.60269 .59711 Mdot
.58741 .5942 Mdot
.66652 .4321 Mdot
.44171 .40466 Mdot
.49275 .59265 Mdot
.55251 .58868 Mdot
.32075 .46112 Mdot
.34068 .48578 Mdot
.58325 .41583 Mdot
.28808 .45933 Mdot
.56205 .67945 Mdot
.66699 .42995 Mdot
.53948 .64575 Mdot
.68748 .43276 Mdot
.57308 .573 Mdot
.5834 .36394 Mdot
.68857 .47113 Mdot
.51857 .52809 Mdot
.53307 .59009 Mdot
.74252 .44803 Mdot
.55596 .57755 Mdot
.54441 .63163 Mdot
.3407 .47101 Mdot
.34174 .62271 Mdot
.50612 .59601 Mdot
.47877 .28078 Mdot
.37371 .62832 Mdot
.8024 .48673 Mdot
.27854 .48841 Mdot
.35665 .60386 Mdot
.42577 .74173 Mdot
.56997 .38755 Mdot
.3543 .62058 Mdot
.57993 .39238 Mdot
.42176 .33084 Mdot
.6773 .41365 Mdot
.52407 .59183 Mdot
.56993 .16675 Mdot
.20702 .492 Mdot
.5504 .37664 Mdot
.58886 .61462 Mdot
.56348 .62339 Mdot
.70971 .45609 Mdot
.34917 .81062 Mdot
.30046 .43434 Mdot
.54386 .63724 Mdot
.64553 .4541 Mdot
.2962 .77233 Mdot
.3299 .47957 Mdot
.35692 .6306 Mdot
.41686 .33728 Mdot
.72706 .41872 Mdot
.56034 .39549 Mdot
.40414 .3174 Mdot
.35224 .51199 Mdot
.39854 .7874 Mdot
.54153 .65594 Mdot
.28023 .45785 Mdot
.39453 .77682 Mdot
.59236 .54065 Mdot
.4114 .27236 Mdot
.58822 .3745 Mdot
.66189 .46698 Mdot
.45844 .33002 Mdot
.32664 .60058 Mdot
.66124 .4179 Mdot
.6558 .45927 Mdot
.42358 .2846 Mdot
.50508 .20721 Mdot
.50672 .47757 Mdot
.45636 .29143 Mdot
.53379 .47528 Mdot
.39225 .77227 Mdot
.54767 .3906 Mdot
.33542 .63413 Mdot
.2858 .68487 Mdot
.68327 .45651 Mdot
.63065 .32619 Mdot
.39658 .78063 Mdot
.54161 .62798 Mdot
.33455 .60522 Mdot
.66028 .25618 Mdot
.40092 .33733 Mdot
.4065 .2975 Mdot
.37997 .49255 Mdot
.31787 .61545 Mdot
.59608 .60521 Mdot
.80503 .62262 Mdot
.52868 .58635 Mdot
.40554 .31656 Mdot
.41955 .50348 Mdot
.68406 .42131 Mdot
.43852 .27849 Mdot
.40371 .51973 Mdot
.52868 .63516 Mdot
.5816 .59873 Mdot
.39781 .63641 Mdot
.69121 .42187 Mdot
.55728 .39778 Mdot
.55981 .58867 Mdot
.56654 .63056 Mdot
.60432 .60393 Mdot
.58896 .76547 Mdot
.50635 .52643 Mdot
.5401 .63503 Mdot
.28068 .443 Mdot
.57314 .67654 Mdot
.59003 .63292 Mdot
.71217 .45478 Mdot
.32316 .72452 Mdot
.57119 .39273 Mdot
.5728 .63777 Mdot
.56014 .64177 Mdot
.41899 .28206 Mdot
.50476 .4775 Mdot
.52822 .45555 Mdot
.32894 .50516 Mdot
.36939 .51076 Mdot
.55309 .66888 Mdot
.67299 .43668 Mdot
.30986 .61707 Mdot
.60249 .6432 Mdot
.6812 .47754 Mdot
.50704 .65794 Mdot
.33641 .48152 Mdot
.55354 .38804 Mdot
.55829 .53593 Mdot
.34778 .61619 Mdot
.45425 .34291 Mdot
.83296 .49443 Mdot
.29975 .45015 Mdot
.5116 .62668 Mdot
.25312 .47534 Mdot
.29525 .47555 Mdot
.54878 .37453 Mdot
.54551 .69669 Mdot
.68393 .44359 Mdot
.67391 .42162 Mdot
.36984 .76203 Mdot
.31261 .44174 Mdot
.20171 .6453 Mdot
.44242 .3328 Mdot
.49723 .62812 Mdot
.71841 .35384 Mdot
.68133 .42215 Mdot
.36286 .6951 Mdot
.35846 .60459 Mdot
.40642 .29859 Mdot
.5559 .40572 Mdot
.69155 .47009 Mdot
.68912 .42663 Mdot
.54113 .59143 Mdot
.56374 .61166 Mdot
.36002 .47485 Mdot
.35706 .71299 Mdot
.45295 .30487 Mdot
.35513 .63504 Mdot
.3202 .51116 Mdot
.52529 .63819 Mdot
.66832 .47275 Mdot
.80546 .61328 Mdot
.56304 .57828 Mdot
.33525 .47976 Mdot
.66964 .46858 Mdot
.36088 .62337 Mdot
.34888 .60394 Mdot
.54276 .62891 Mdot
.79871 .59811 Mdot
.44242 .30147 Mdot
.67367 .42889 Mdot
.62269 .43741 Mdot
.51239 .65613 Mdot
.55857 .60982 Mdot
.57086 .55355 Mdot
.41987 .27257 Mdot
.57479 .53315 Mdot
.37914 .62772 Mdot
.69452 .4496 Mdot
.56821 .59362 Mdot
.35082 .61528 Mdot
.63258 .54498 Mdot
.55736 .38346 Mdot
.32873 .47905 Mdot
.31384 .61853 Mdot
.33491 .61443 Mdot
.37156 .62594 Mdot
.62943 .32884 Mdot
.65363 .49212 Mdot
.57221 .80912 Mdot
.54503 .5846 Mdot
.39134 .77052 Mdot
.57713 .56878 Mdot
.45548 .31724 Mdot
.29707 .4467 Mdot
.54255 .59617 Mdot
.5443 .58456 Mdot
.81902 .55325 Mdot
.54128 .70931 Mdot
.54716 .71293 Mdot
.66828 .41967 Mdot
.69285 .50412 Mdot
.26972 .46645 Mdot
.21959 .70268 Mdot
.80923 .38775 Mdot
.55405 .66537 Mdot
.50204 .44019 Mdot
.67357 .47673 Mdot
.40579 .29302 Mdot
.52295 .47312 Mdot
.3957 .25827 Mdot
.69302 .45852 Mdot
.53013 .64146 Mdot
.8287 .5007 Mdot
.36501 .64224 Mdot
.54656 .60657 Mdot
.42682 .29474 Mdot
.54591 .60567 Mdot
.45969 .31527 Mdot
.7392 .41838 Mdot
.5235 .4402 Mdot
.5151 .60169 Mdot
.54759 .66252 Mdot
.61294 .54035 Mdot
.5581 .61184 Mdot
.27153 .37509 Mdot
.66533 .45762 Mdot
.50252 .54058 Mdot
.60227 .62611 Mdot
.76347 .63133 Mdot
.58809 .59135 Mdot
.46339 .38889 Mdot
.58324 .59301 Mdot
.54791 .75948 Mdot
.59709 .60962 Mdot
.57756 .58658 Mdot
.44231 .31934 Mdot
.41283 .28398 Mdot
.68557 .40195 Mdot
.55282 .39788 Mdot
.64481 .2334 Mdot
.57842 .62419 Mdot
.34335 .48195 Mdot
.59376 .43167 Mdot
.33636 .61901 Mdot
.69266 .45352 Mdot
.1311 .57237 Mdot
.45071 .29377 Mdot
.28055 .43636 Mdot
.2655 .51451 Mdot
.26567 .4548 Mdot
.34844 .49893 Mdot
.7364 .46175 Mdot
.34092 .63686 Mdot
.59271 .5985 Mdot
.79507 .55631 Mdot
.64976 .35979 Mdot
.51297 .65423 Mdot
.24975 .44957 Mdot
.63016 .63774 Mdot
.38278 .77681 Mdot
.34495 .64506 Mdot
.32304 .62795 Mdot
.43319 .31833 Mdot
.27753 .49223 Mdot
.57615 .54269 Mdot
.35713 .60453 Mdot
.30035 .44768 Mdot
.53981 .36954 Mdot
.35359 .56882 Mdot
.68467 .45248 Mdot
.59538 .73534 Mdot
.71943 .3671 Mdot
.4516 .29678 Mdot
.48629 .30121 Mdot
.6342 .4922 Mdot
.63528 .43484 Mdot
.54636 .39466 Mdot
.33347 .47105 Mdot
.66562 .41375 Mdot
.54129 .58749 Mdot
.55889 .69138 Mdot
.5857 .62415 Mdot
.34041 .5979 Mdot
.59089 .60746 Mdot
.32572 .45997 Mdot
.44634 .29726 Mdot
.29335 .48841 Mdot
.44659 .30458 Mdot
.81004 .45814 Mdot
.58613 .63429 Mdot
.56076 .60816 Mdot
.4741 .4319 Mdot
.69499 .43248 Mdot
.78564 .54726 Mdot
.3359 .47496 Mdot
.31696 .49914 Mdot
.53953 .64444 Mdot
.6365 .45779 Mdot
.387 .65579 Mdot
.50136 .45925 Mdot
.58607 .59618 Mdot
.66474 .45687 Mdot
.54244 .64745 Mdot
.2644 .33312 Mdot
.52806 .4294 Mdot
.66294 .42569 Mdot
.62227 .77754 Mdot
.53241 .59686 Mdot
.56719 .69826 Mdot
.59852 .67438 Mdot
.49844 .72507 Mdot
.49646 .60137 Mdot
.66347 .47855 Mdot
.5764 .64118 Mdot
.67018 .44061 Mdot
.2908 .47085 Mdot
.41864 .27578 Mdot
.67237 .44291 Mdot
.53081 .58635 Mdot
.81082 .40237 Mdot
.44231 .29007 Mdot
.54951 .59966 Mdot
.4251 .31952 Mdot
.69078 .41568 Mdot
.70254 .43692 Mdot
.57834 .40294 Mdot
.32283 .53716 Mdot
.4372 .28851 Mdot
.51675 .6426 Mdot
.64396 .33594 Mdot
.53905 .64612 Mdot
.36659 .51464 Mdot
.59528 .63899 Mdot
.52861 .66116 Mdot
.82204 .63925 Mdot
.45433 .40143 Mdot
.17094 .62192 Mdot
.46678 .35452 Mdot
.64403 .32717 Mdot
.6644 .40018 Mdot
.34347 .64464 Mdot
.39568 .36522 Mdot
.56718 .37563 Mdot
.27563 .4468 Mdot
.54331 .59294 Mdot
.75871 .40242 Mdot
.4625 .30422 Mdot
.34189 .62627 Mdot
.51655 .60062 Mdot
.27469 .49395 Mdot
.51417 .37245 Mdot
.40384 .30689 Mdot
.68665 .45267 Mdot
.70077 .44046 Mdot
.45421 .8314 Mdot
.57237 .59687 Mdot
.56767 .60911 Mdot
.43449 .2826 Mdot
.54858 .54732 Mdot
.3695 .63048 Mdot
.32706 .30575 Mdot
.42358 .29616 Mdot
.52273 .42273 Mdot
.66662 .41863 Mdot
.56478 .62213 Mdot
.46382 .4347 Mdot
.5885 .29779 Mdot
.66627 .5604 Mdot
.32511 .61128 Mdot
.41482 .63859 Mdot
.66337 .47868 Mdot
.4251 .29872 Mdot
.42967 .75697 Mdot
.56225 .56388 Mdot
.56353 .62547 Mdot
.41548 .65121 Mdot
.5061 .46167 Mdot
.36001 .54049 Mdot
.57773 .55795 Mdot
.48539 .48748 Mdot
.53851 .64354 Mdot
.53406 .62601 Mdot
.52653 .66339 Mdot
.57781 .64698 Mdot
.66404 .4522 Mdot
.71507 .7043 Mdot
.31238 .47702 Mdot
.66549 .62832 Mdot
.37437 .47804 Mdot
.50271 .62841 Mdot
.52984 .6388 Mdot
.69804 .67623 Mdot
.58289 .48425 Mdot
.67073 .45747 Mdot
.62227 .44228 Mdot
.42356 .27647 Mdot
.53888 .71006 Mdot
.32356 .44793 Mdot
.60029 .68413 Mdot
.30111 .48498 Mdot
.66326 .45633 Mdot
.29142 .49498 Mdot
.47241 .3159 Mdot
.2802 .45813 Mdot
.30894 .44215 Mdot
.40437 .3223 Mdot
.70286 .43059 Mdot
.57497 .58312 Mdot
.41047 .32831 Mdot
.39624 .65001 Mdot
.34102 .59824 Mdot
.58216 .4011 Mdot
.52373 .57387 Mdot
.54983 .70791 Mdot
.24742 .3285 Mdot
.28084 .48494 Mdot
.55142 .46826 Mdot
.68971 .47017 Mdot
.31349 .60844 Mdot
.66487 .44801 Mdot
.50326 .81162 Mdot
.34113 .61107 Mdot
.58259 .39959 Mdot
.41629 .75259 Mdot
.44222 .25217 Mdot
.61418 .60938 Mdot
.63989 .51343 Mdot
.298 .48435 Mdot
.46485 .31727 Mdot
.65296 .24889 Mdot
.53254 .6048 Mdot
.53406 .36653 Mdot
.62961 .44434 Mdot
.56915 .38857 Mdot
.42856 .29649 Mdot
.44229 .37063 Mdot
.57722 .60106 Mdot
.46004 .26499 Mdot
.56101 .6585 Mdot
.61264 .743 Mdot
.36754 .50033 Mdot
.61828 .50175 Mdot
.53649 .6499 Mdot
.3316 .47525 Mdot
.53772 .64863 Mdot
.63282 .69036 Mdot
.40584 .76805 Mdot
.56664 .66221 Mdot
.61187 .51144 Mdot
.23638 .36168 Mdot
.66517 .47042 Mdot
.55838 .67962 Mdot
.54679 .38414 Mdot
.52103 .62395 Mdot
.62797 .16405 Mdot
.35195 .6205 Mdot
.295 .60658 Mdot
.53275 .58608 Mdot
.56107 .59139 Mdot
.80653 .57816 Mdot
.6934 .49919 Mdot
.55774 .40599 Mdot
.55802 .62814 Mdot
.4274 .65693 Mdot
.43743 .32129 Mdot
.57859 .64899 Mdot
.57878 .63711 Mdot
.18436 .56155 Mdot
.43512 .32332 Mdot
.27472 .47725 Mdot
.5702 .3855 Mdot
.33088 .50052 Mdot
.30394 .6048 Mdot
.4962 .50537 Mdot
.37045 .69422 Mdot
.53299 .42936 Mdot
.31713 .61022 Mdot
.50126 .62991 Mdot
.61676 .43644 Mdot
.57064 .58949 Mdot
.32339 .62583 Mdot
.41836 .3064 Mdot
.66712 .45181 Mdot
.60403 .73365 Mdot
.54846 .37146 Mdot
.49999 .6407 Mdot
.35121 .6472 Mdot
.67743 .44296 Mdot
.52552 .28493 Mdot
.68917 .46757 Mdot
.44451 .30946 Mdot
.43837 .27505 Mdot
.34051 .61629 Mdot
.66353 .45003 Mdot
.32503 .5028 Mdot
.46607 .35744 Mdot
.59004 .64539 Mdot
.47269 .30808 Mdot
.65571 .41407 Mdot
.6914 .47557 Mdot
.63977 .44989 Mdot
.5765 .64511 Mdot
.50696 .45511 Mdot
.58031 .56674 Mdot
.43958 .2867 Mdot
.26472 .46637 Mdot
.3643 .72338 Mdot
.79476 .57733 Mdot
.51746 .42042 Mdot
.50375 .59723 Mdot
.59021 .6103 Mdot
.58461 .62477 Mdot
.55332 .64774 Mdot
.33025 .30572 Mdot
.58559 .63469 Mdot
.4484 .31794 Mdot
.30189 .47777 Mdot
.58617 .6082 Mdot
.54879 .38699 Mdot
.41071 .45801 Mdot
.30926 .61528 Mdot
.55457 .74006 Mdot
.74229 .34766 Mdot
.67604 .44441 Mdot
.28226 .46098 Mdot
.29694 .49899 Mdot
.35791 .6082 Mdot
.40822 .32361 Mdot
.69483 .46073 Mdot
.52367 .74887 Mdot
.37414 .63531 Mdot
.57191 .63782 Mdot
.46934 .43247 Mdot
.63422 .76661 Mdot
.50469 .60705 Mdot
.54297 .62113 Mdot
.56036 .39861 Mdot
.28065 .43752 Mdot
.64737 .19887 Mdot
.50409 .21757 Mdot
.34177 .62114 Mdot
.36266 .63092 Mdot
.64384 .4659 Mdot
.49677 .6304 Mdot
.44103 .29827 Mdot
.4945 .48413 Mdot
.26078 .30849 Mdot
.6889 .27075 Mdot
.25443 .35773 Mdot
.58805 .58771 Mdot
.72774 .67489 Mdot
.60501 .62893 Mdot
.65561 .4917 Mdot
.63837 .45693 Mdot
.67677 .45549 Mdot
.4417 .31777 Mdot
.4018 .79203 Mdot
.44901 .31884 Mdot
.74781 .3491 Mdot
.652 .46482 Mdot
.42973 .42117 Mdot
.32343 .49645 Mdot
.5194 .69558 Mdot
.33766 .63597 Mdot
.34263 .67142 Mdot
.55096 .68359 Mdot
.45525 .57229 Mdot
.27296 .46617 Mdot
.70688 .44531 Mdot
.48241 .62386 Mdot
.63392 .22513 Mdot
.50771 .44001 Mdot
.20146 .39723 Mdot
.68005 .51353 Mdot
.34819 .61094 Mdot
.6774 .6361 Mdot
.36986 .63562 Mdot
.40541 .30234 Mdot
.53386 .59948 Mdot
.54224 .57769 Mdot
.54794 .63808 Mdot
.57032 .64827 Mdot
.42662 .31679 Mdot
.60007 .63831 Mdot
.32575 .71806 Mdot
.546 .36669 Mdot
.40622 .41992 Mdot
.35338 .60916 Mdot
.45146 .32881 Mdot
.29766 .47586 Mdot
.54663 .39618 Mdot
.39068 .63068 Mdot
.60388 .61173 Mdot
.54994 .58157 Mdot
.54177 .36938 Mdot
.51705 .55814 Mdot
.50897 .6784 Mdot
.31547 .48145 Mdot
.41827 .48207 Mdot
.33349 .59408 Mdot
.3334 .6372 Mdot
.45231 .3332 Mdot
.66459 .44803 Mdot
.3476 .5979 Mdot
.27741 .49303 Mdot
.5639 .65541 Mdot
.54426 .66278 Mdot
.65679 .41326 Mdot
.39589 .78095 Mdot
.30849 .61983 Mdot
.58846 .53819 Mdot
.69422 .44005 Mdot
.62755 .45126 Mdot
.55648 .62728 Mdot
.61758 .58701 Mdot
.67063 .4885 Mdot
.36359 .62012 Mdot
.44548 .33432 Mdot
.45125 .41667 Mdot
.45192 .31835 Mdot
.68915 .43965 Mdot
.56782 .68227 Mdot
.68833 .41966 Mdot
.52975 .60358 Mdot
.20907 .72569 Mdot
.5931 .62252 Mdot
.45805 .61908 Mdot
.38453 .57295 Mdot
.33125 .4863 Mdot
.33199 .48197 Mdot
.55206 .38795 Mdot
.67821 .47801 Mdot
.60379 .64319 Mdot
.34942 .63835 Mdot
.64448 .32835 Mdot
.65356 .50324 Mdot
.31842 .44709 Mdot
.29212 .43571 Mdot
.41936 .30819 Mdot
.59022 .59604 Mdot
.56972 .62037 Mdot
.27723 .4609 Mdot
.31044 .29221 Mdot
.66418 .44105 Mdot
.56752 .6088 Mdot
.5854 .64008 Mdot
.30922 .47659 Mdot
.44549 .36691 Mdot
.6245 .4597 Mdot
.58413 .64182 Mdot
.3968 .74961 Mdot
.4589 .30852 Mdot
.5089 .63491 Mdot
.60405 .62945 Mdot
.33204 .61776 Mdot
.37895 .67399 Mdot
.39368 .77272 Mdot
.40118 .29637 Mdot
.5629 .39444 Mdot
.54905 .57498 Mdot
.32705 .49049 Mdot
.51294 .58163 Mdot
.40694 .21367 Mdot
.55139 .36602 Mdot
.57723 .60536 Mdot
.54994 .67022 Mdot
.68451 .43052 Mdot
.57078 .60081 Mdot
.58286 .36577 Mdot
.31556 .4598 Mdot
.57806 .60534 Mdot
.79578 .60161 Mdot
.41936 .30533 Mdot
.54892 .68495 Mdot
.31754 .62681 Mdot
.37632 .53625 Mdot
.79735 .41942 Mdot
.34402 .49336 Mdot
.34567 .60351 Mdot
.59055 .60589 Mdot
.33246 .50195 Mdot
.41504 .33634 Mdot
.48826 .54739 Mdot
.50216 .6356 Mdot
.45316 .31459 Mdot
.44394 .29396 Mdot
.34432 .61896 Mdot
.1616 .62834 Mdot
.54975 .66925 Mdot
.55077 .60721 Mdot
.23319 .32498 Mdot
.69174 .48366 Mdot
.54714 .60013 Mdot
.58803 .59374 Mdot
.42429 .33337 Mdot
.48786 .79233 Mdot
.42433 .62504 Mdot
.32393 .29429 Mdot
.45896 .31361 Mdot
.28132 .43225 Mdot
.30784 .45399 Mdot
.34647 .60495 Mdot
.67154 .4699 Mdot
.32676 .59769 Mdot
.31256 .46872 Mdot
.54529 .63268 Mdot
.41041 .3111 Mdot
.72569 .51581 Mdot
.4606 .33129 Mdot
.28735 .50449 Mdot
.63827 .48278 Mdot
.75973 .37243 Mdot
.33597 .21398 Mdot
.71863 .37147 Mdot
.40603 .28247 Mdot
.33611 .61905 Mdot
.49758 .22981 Mdot
.58714 .60461 Mdot
.63925 .73286 Mdot
.54796 .60635 Mdot
.6379 .53846 Mdot
.29858 .44688 Mdot
.53899 .38766 Mdot
.53275 .60521 Mdot
.41574 .6377 Mdot
.40268 .31489 Mdot
.42933 .2875 Mdot
.56424 .64455 Mdot
.44464 .30726 Mdot
.57207 .61626 Mdot
.30302 .47434 Mdot
.16813 .63305 Mdot
.5782 .58968 Mdot
.58008 .66918 Mdot
.42361 .34829 Mdot
.58317 .40087 Mdot
.25478 .44934 Mdot
.73566 .67557 Mdot
.63332 .21905 Mdot
.44092 .30316 Mdot
.46729 .65248 Mdot
.27869 .47658 Mdot
.55386 .40021 Mdot
.33302 .44984 Mdot
.55252 .61681 Mdot
.583 .58196 Mdot
.54374 .64177 Mdot
.58906 .60902 Mdot
.6619 .70343 Mdot
.51403 .68482 Mdot
.71866 .59112 Mdot
.54663 .58447 Mdot
.45982 .62016 Mdot
.44424 .32452 Mdot
.57472 .69537 Mdot
.35758 .5458 Mdot
.59085 .58888 Mdot
.65702 .51211 Mdot
.4487 .33039 Mdot
.70301 .32882 Mdot
.43049 .32037 Mdot
.29719 .49224 Mdot
.41232 .28848 Mdot
.5306 .59884 Mdot
.68451 .45922 Mdot
.29811 .45936 Mdot
.64691 .38779 Mdot
.273 .45234 Mdot
.57473 .59743 Mdot
.4008 .24549 Mdot
.32856 .49616 Mdot
.56388 .71345 Mdot
.68421 .46149 Mdot
.43441 .6849 Mdot
.67525 .49231 Mdot
.56456 .59893 Mdot
.55717 .59669 Mdot
.54044 .39263 Mdot
.40349 .30709 Mdot
.65044 .42628 Mdot
.19277 .5983 Mdot
.34132 .64625 Mdot
.6693 .46299 Mdot
.59525 .67435 Mdot
.49832 .43773 Mdot
.67394 .42586 Mdot
.45213 .69064 Mdot
.40504 .31574 Mdot
.65189 .47032 Mdot
.61068 .59229 Mdot
.65884 .64078 Mdot
.35458 .64264 Mdot
.33612 .49471 Mdot
.48516 .4702 Mdot
.31057 .45533 Mdot
.46657 .33168 Mdot
.3146 .44126 Mdot
.44048 .32366 Mdot
.59816 .4438 Mdot
.41386 .51031 Mdot
.46896 .31624 Mdot
.45801 .34893 Mdot
.31969 .47609 Mdot
.5567 .64581 Mdot
.41455 .4442 Mdot
.62234 .60885 Mdot
.5439 .6922 Mdot
.45611 .30696 Mdot
.6593 .4772 Mdot
.67162 .41666 Mdot
.5114 .5368 Mdot
.69558 .43043 Mdot
.29391 .46382 Mdot
.54682 .43175 Mdot
.61436 .74743 Mdot
.41668 .30428 Mdot
.29287 .52665 Mdot
.53478 .64593 Mdot
.32601 .48008 Mdot
.28928 .46619 Mdot
.44759 .30243 Mdot
.66704 .61098 Mdot
.53874 .68895 Mdot
.70969 .46121 Mdot
.64647 .45627 Mdot
.67004 .42594 Mdot
.63777 .46124 Mdot
.41497 .80296 Mdot
.46482 .3177 Mdot
.66866 .47883 Mdot
.55655 .65175 Mdot
.56284 .57682 Mdot
.56662 .38311 Mdot
.36217 .61982 Mdot
.58959 .57612 Mdot
.61251 .63291 Mdot
.55734 .62644 Mdot
.33071 .48812 Mdot
.63136 .57795 Mdot
.55173 .36722 Mdot
.30408 .43846 Mdot
.32313 .44809 Mdot
.55656 .39347 Mdot
.60193 .45315 Mdot
.68403 .2356 Mdot
.54464 .63785 Mdot
.75267 .41406 Mdot
.32602 .48827 Mdot
.46533 .54171 Mdot
.48473 .57984 Mdot
.51935 .64582 Mdot
.39631 .42475 Mdot
.29881 .46982 Mdot
.68563 .3978 Mdot
.55479 .61355 Mdot
.5449 .39105 Mdot
.33434 .63848 Mdot
.62221 .62467 Mdot
.55937 .39918 Mdot
.66048 .4553 Mdot
.21763 .45101 Mdot
.71509 .44444 Mdot
.3282 .4984 Mdot
.55621 .68107 Mdot
.46008 .91234 Mdot
.29624 .48387 Mdot
.63181 .3175 Mdot
.40917 .51471 Mdot
.57941 .59334 Mdot
.29645 .45548 Mdot
.64693 .41621 Mdot
.45857 .30763 Mdot
.47914 .44071 Mdot
.66873 .47259 Mdot
.54549 .39515 Mdot
.56424 .38832 Mdot
.31177 .47758 Mdot
.64739 .44103 Mdot
.59656 .64006 Mdot
.6998 .44585 Mdot
.41268 .29891 Mdot
.51763 .61072 Mdot
.64459 .23284 Mdot
.54882 .69691 Mdot
.69819 .44672 Mdot
.26961 .48544 Mdot
.36634 .60916 Mdot
.51038 .60585 Mdot
.69546 .30248 Mdot
.59026 .59781 Mdot
.42196 .31606 Mdot
.43739 .54009 Mdot
.72104 .52324 Mdot
.55824 .63847 Mdot
.53274 .64234 Mdot
.43881 .33975 Mdot
.55506 .63705 Mdot
.52386 .65668 Mdot
.47106 .36961 Mdot
.67899 .4269 Mdot
.58275 .61428 Mdot
.30852 .45134 Mdot
.77424 .47874 Mdot
.53579 .59948 Mdot
.57221 .35265 Mdot
.42637 .66599 Mdot
.42682 .52436 Mdot
.59974 .64799 Mdot
.36152 .69308 Mdot
.55559 .59964 Mdot
.51747 .64961 Mdot
.54981 .64285 Mdot
.72138 .68029 Mdot
.31704 .47167 Mdot
.32399 .45374 Mdot
.32775 .63643 Mdot
.42346 .65139 Mdot
.33222 .60667 Mdot
.4352 .33863 Mdot
.2823 .52241 Mdot
.54387 .36945 Mdot
.66603 .44552 Mdot
.53724 .60133 Mdot
.27736 .44958 Mdot
.56166 .62144 Mdot
.51946 .625 Mdot
.30137 .46478 Mdot
.29187 .46841 Mdot
.3466 .4866 Mdot
.37043 .64017 Mdot
.67269 .45214 Mdot
.53982 .61944 Mdot
.37398 .62843 Mdot
.60038 .62589 Mdot
.49099 .40987 Mdot
.67271 .45438 Mdot
.69911 .44342 Mdot
.69002 .41762 Mdot
.55036 .5795 Mdot
.52613 .60113 Mdot
.44939 .3185 Mdot
.65841 .41292 Mdot
.4306 .2847 Mdot
.29844 .4551 Mdot
.32756 .47459 Mdot
.55195 .61659 Mdot
.57543 .53879 Mdot
.35816 .61602 Mdot
.28973 .49043 Mdot
.56623 .3716 Mdot
.32028 .63181 Mdot
.58962 .61764 Mdot
.30493 .45475 Mdot
.31117 .61857 Mdot
.66646 .53194 Mdot
.60382 .19599 Mdot
.37461 .63955 Mdot
.56493 .64461 Mdot
.8039 .56915 Mdot
.39761 .75784 Mdot
.35617 .6492 Mdot
.42845 .32429 Mdot
.57774 .58294 Mdot
.33228 .25106 Mdot
.34086 .59283 Mdot
.3982 .7789 Mdot
.30551 .46332 Mdot
.59665 .52489 Mdot
.62139 .6337 Mdot
.62489 .74622 Mdot
.34775 .59426 Mdot
.696 .4499 Mdot
.6427 .45174 Mdot
.56792 .63908 Mdot
.34405 .54085 Mdot
.4664 .3266 Mdot
.29657 .49893 Mdot
.30292 .4421 Mdot
.65402 .42864 Mdot
.5298 .42668 Mdot
.30755 .45193 Mdot
.50223 .64846 Mdot
.30338 .6271 Mdot
.53739 .70994 Mdot
.45345 .82722 Mdot
.78713 .42562 Mdot
.5915 .65528 Mdot
.37197 .61638 Mdot
.40345 .32222 Mdot
.4482 .31105 Mdot
.44208 .31493 Mdot
.3266 .47139 Mdot
.5149 .47074 Mdot
.29919 .44406 Mdot
.54557 .33186 Mdot
.3526 .61636 Mdot
.45403 .72005 Mdot
.60952 .60639 Mdot
.57867 .59341 Mdot
.54447 .6588 Mdot
.54218 .64098 Mdot
.55697 .6011 Mdot
.45178 .29791 Mdot
.31665 .50617 Mdot
.25679 .32922 Mdot
.65557 .43427 Mdot
.52014 .28007 Mdot
.32228 .49749 Mdot
.56751 .396 Mdot
.34601 .63075 Mdot
.38613 .68361 Mdot
.30748 .64168 Mdot
.29741 .49723 Mdot
.4992 .61714 Mdot
.65179 .47654 Mdot
.58308 .76845 Mdot
.55251 .58853 Mdot
.28612 .48877 Mdot
.29186 .431 Mdot
.67305 .6067 Mdot
.5424 .56056 Mdot
.34208 .53912 Mdot
.50137 .44211 Mdot
.38208 .63128 Mdot
.51218 .58863 Mdot
.47748 .53318 Mdot
.31273 .47065 Mdot
.30777 .49257 Mdot
.36675 .64743 Mdot
.63649 .63709 Mdot
.6553 .46476 Mdot
.53761 .38374 Mdot
.43062 .32767 Mdot
.56463 .5848 Mdot
.32409 .46777 Mdot
.68367 .39284 Mdot
.46843 .42084 Mdot
.42633 .31105 Mdot
.29858 .43673 Mdot
.58637 .58905 Mdot
.56386 .63809 Mdot
.34319 .60954 Mdot
.20087 .531 Mdot
.62208 .61006 Mdot
.64302 .32731 Mdot
.53643 .45502 Mdot
.39401 .52708 Mdot
.56411 .62528 Mdot
.68205 .42005 Mdot
.55389 .39209 Mdot
.3341 .63291 Mdot
.60058 .61523 Mdot
.65861 .2185 Mdot
.71566 .43234 Mdot
.43799 .29003 Mdot
.55112 .39344 Mdot
.50594 .48238 Mdot
.59029 .59915 Mdot
.54827 .60689 Mdot
.57531 .6456 Mdot
.65918 .2153 Mdot
.30952 .44771 Mdot
.64109 .43479 Mdot
.32726 .6064 Mdot
.70158 .44641 Mdot
.3359 .46199 Mdot
.38977 .52541 Mdot
.58854 .63294 Mdot
.71208 .44488 Mdot
.69461 .45829 Mdot
.41876 .30426 Mdot
.4117 .32978 Mdot
.33543 .50454 Mdot
.58908 .60534 Mdot
.54002 .37601 Mdot
.65954 .47445 Mdot
.29629 .50105 Mdot
.34338 .61033 Mdot
.45257 .27437 Mdot
.54668 .584 Mdot
.31368 .47578 Mdot
.58035 .66179 Mdot
.6751 .43218 Mdot
.30658 .49991 Mdot
.56238 .40143 Mdot
.36281 .6229 Mdot
.57063 .57522 Mdot
.23125 .37268 Mdot
.54723 .39374 Mdot
.52938 .58624 Mdot
.78105 .43037 Mdot
.35258 .54132 Mdot
.67909 .3828 Mdot
.28949 .45019 Mdot
.54205 .37805 Mdot
.638 .44635 Mdot
.65913 .65682 Mdot
.30764 .48936 Mdot
.81833 .52455 Mdot
.43052 .42817 Mdot
.54211 .63239 Mdot
.66184 .46487 Mdot
.37742 .65031 Mdot
.6513 .32175 Mdot
.38237 .73997 Mdot
.57375 .61105 Mdot
.31166 .45557 Mdot
.33081 .63637 Mdot
.42721 .28681 Mdot
.55937 .34898 Mdot
.49632 .82967 Mdot
.2994 .43843 Mdot
.53832 .60667 Mdot
.65708 .475 Mdot
.44275 .2967 Mdot
.82922 .50584 Mdot
.28093 .49672 Mdot
.29356 .45104 Mdot
.53669 .65607 Mdot
.32519 .60957 Mdot
.33724 .25059 Mdot
.32006 .45212 Mdot
.32923 .50273 Mdot
.50692 .35983 Mdot
.34166 .64316 Mdot
.56444 .64851 Mdot
.51016 .53754 Mdot
.58171 .64643 Mdot
.5693 .31228 Mdot
.54131 .37799 Mdot
.65609 .43538 Mdot
.54411 .59673 Mdot
.23766 .35853 Mdot
.30197 .48357 Mdot
.50508 .44423 Mdot
.40311 .34718 Mdot
.41023 .32769 Mdot
.31614 .46133 Mdot
.56079 .61628 Mdot
.44557 .27678 Mdot
.3532 .6115 Mdot
.58456 .64141 Mdot
.52798 .60274 Mdot
.64166 .42171 Mdot
.41078 .30815 Mdot
.77699 .47126 Mdot
.41532 .29079 Mdot
.45219 .33418 Mdot
.62733 .45083 Mdot
.56957 .6385 Mdot
.29702 .49459 Mdot
.28307 .50308 Mdot
.59224 .64919 Mdot
.46505 .54088 Mdot
.6574 .46537 Mdot
.34635 .51356 Mdot
.63248 .19513 Mdot
.54983 .66591 Mdot
.57097 .38155 Mdot
.63025 .52183 Mdot
.45851 .29971 Mdot
.54703 .63194 Mdot
.67032 .43905 Mdot
.31466 .50987 Mdot
.31878 .45729 Mdot
.55475 .56392 Mdot
.44849 .30236 Mdot
.31285 .61207 Mdot
.28654 .46667 Mdot
.46991 .41027 Mdot
.57612 .60269 Mdot
.52993 .37041 Mdot
.28419 .46838 Mdot
.81263 .42195 Mdot
.24318 .34693 Mdot
.65813 .42788 Mdot
.51845 .6344 Mdot
.66343 .48481 Mdot
.32995 .60305 Mdot
.32308 .44366 Mdot
.45167 .31055 Mdot
.59718 .73138 Mdot
.17512 .5444 Mdot
.32407 .47576 Mdot
.66425 .4535 Mdot
.54014 .6101 Mdot
.48167 .595 Mdot
.58411 .59383 Mdot
.49057 .78799 Mdot
.31006 .63048 Mdot
.47143 .33195 Mdot
.43728 .28446 Mdot
.52879 .63572 Mdot
.37085 .62981 Mdot
.31293 .51688 Mdot
.30313 .46527 Mdot
.19519 .6802 Mdot
.55943 .39988 Mdot
.35295 .46468 Mdot
.55029 .57986 Mdot
.28717 .49625 Mdot
.79288 .57939 Mdot
.43282 .28296 Mdot
.58194 .64829 Mdot
.27135 .44579 Mdot
.56902 .29291 Mdot
.49676 .43868 Mdot
.57607 .60659 Mdot
.55722 .54514 Mdot
.42977 .32236 Mdot
.49814 .22923 Mdot
.28573 .45052 Mdot
.59675 .63029 Mdot
.39725 .27996 Mdot
.58829 .42877 Mdot
.1957 .59538 Mdot
.6731 .45225 Mdot
.2598 .46267 Mdot
.43994 .33425 Mdot
.61601 .55538 Mdot
.35858 .61347 Mdot
.30934 .51278 Mdot
.26957 .45152 Mdot
.51495 .61767 Mdot
.58562 .57427 Mdot
.55897 .54868 Mdot
.65861 .46011 Mdot
.42231 .33208 Mdot
.52891 .62436 Mdot
.50339 .41306 Mdot
.5395 .63589 Mdot
.43224 .33367 Mdot
.34824 .85987 Mdot
.53141 .57951 Mdot
.55358 .58406 Mdot
.52551 .72693 Mdot
.65639 .42241 Mdot
.68745 .42946 Mdot
.52246 .43396 Mdot
.55305 .5781 Mdot
.43721 .41133 Mdot
.6716 .45002 Mdot
.66587 .46772 Mdot
.43485 .41352 Mdot
.51428 .6106 Mdot
.39014 .27861 Mdot
.44406 .29939 Mdot
.41143 .32906 Mdot
.68584 .43132 Mdot
.51768 .69644 Mdot
.41109 .33286 Mdot
.67021 .69433 Mdot
.30815 .50104 Mdot
.47806 .53284 Mdot
.69969 .44777 Mdot
.45779 .4383 Mdot
.4043 .30905 Mdot
.8489 .47426 Mdot
.5771 .76244 Mdot
.57487 .65581 Mdot
.56202 .63977 Mdot
.33268 .61447 Mdot
.47524 .63133 Mdot
.56451 .39319 Mdot
.44566 .3104 Mdot
.33369 .31219 Mdot
.67716 .45591 Mdot
.56837 .5812 Mdot
.36029 .71801 Mdot
.79547 .43043 Mdot
.50049 .53996 Mdot
.67201 .47077 Mdot
.67959 .45938 Mdot
.27244 .46404 Mdot
.30518 .50122 Mdot
.58144 .63797 Mdot
.4442 .3188 Mdot
.64656 .46135 Mdot
.41527 .32323 Mdot
.31173 .46912 Mdot
.31024 .4998 Mdot
.55944 .36889 Mdot
.51959 .67858 Mdot
.31494 .46379 Mdot
.50738 .34959 Mdot
.50172 .41174 Mdot
.64389 .42122 Mdot
.31962 .23829 Mdot
.83682 .52662 Mdot
.54089 .72497 Mdot
.33599 .63913 Mdot
.59548 .44067 Mdot
.40696 .28855 Mdot
.53032 .63725 Mdot
.54698 .61628 Mdot
.55981 .3765 Mdot
.40283 .29547 Mdot
.33661 .62635 Mdot
.40394 .30306 Mdot
.34462 .63575 Mdot
.32931 .46026 Mdot
.53666 .59449 Mdot
.59415 .61364 Mdot
.43236 .28919 Mdot
.27438 .47456 Mdot
.32945 .4954 Mdot
.36102 .63986 Mdot
.39876 .67064 Mdot
.31089 .47596 Mdot
.69983 .44806 Mdot
.7728 .5051 Mdot
.56453 .38642 Mdot
.55522 .613 Mdot
.36628 .70144 Mdot
.674 .6579 Mdot
.53971 .62963 Mdot
.54975 .39362 Mdot
.16521 .64768 Mdot
.53497 .59698 Mdot
.30502 .78076 Mdot
.54999 .36842 Mdot
.68618 .41899 Mdot
.27919 .47269 Mdot
.55561 .39867 Mdot
.62954 .57377 Mdot
.36219 .50326 Mdot
.56618 .67162 Mdot
.65732 .46857 Mdot
.70836 .43731 Mdot
.41445 .49901 Mdot
.56649 .31121 Mdot
.32395 .60835 Mdot
.34808 .62608 Mdot
.30912 .48736 Mdot
.48547 .3466 Mdot
.4894 .60799 Mdot
.34427 .62527 Mdot
.35389 .27158 Mdot
.53442 .64688 Mdot
.36988 .53823 Mdot
.41195 .4308 Mdot
.67128 .42083 Mdot
.57819 .69454 Mdot
.30516 .4862 Mdot
.66487 .45375 Mdot
.4166 .4625 Mdot
.56695 .65455 Mdot
.67418 .45531 Mdot
.41638 .32944 Mdot
.42512 .38941 Mdot
.70065 .43647 Mdot
.47695 .43662 Mdot
.43908 .29794 Mdot
.35454 .54091 Mdot
.44506 .74043 Mdot
.70417 .20729 Mdot
.4462 .31373 Mdot
.27935 .48119 Mdot
.32382 .47071 Mdot
.30685 .4762 Mdot
.66561 .47216 Mdot
.29166 .47302 Mdot
.65296 .446 Mdot
.44007 .35277 Mdot
.38521 .67708 Mdot
.34153 .61418 Mdot
.3145 .56282 Mdot
.69147 .44838 Mdot
.56069 .32786 Mdot
.25514 .28633 Mdot
.55966 .64864 Mdot
.46817 .3185 Mdot
.37657 .62728 Mdot
.55875 .46142 Mdot
.3314 .61688 Mdot
.27813 .47459 Mdot
.48025 .53135 Mdot
.57323 .61641 Mdot
.75631 .40118 Mdot
.32522 .63255 Mdot
.67035 .47176 Mdot
.50227 .62948 Mdot
.29212 .51302 Mdot
.34038 .60189 Mdot
.34495 .64104 Mdot
.55642 .60298 Mdot
.70648 .43997 Mdot
.29787 .49615 Mdot
.41274 .28238 Mdot
.3617 .65207 Mdot
.5438 .54685 Mdot
.55688 .64328 Mdot
.51117 .59652 Mdot
.51651 .44874 Mdot
.34029 .23898 Mdot
.43864 .30224 Mdot
.39034 .76197 Mdot
.32746 .47778 Mdot
.38538 .74449 Mdot
.6579 .34566 Mdot
.2982 .635 Mdot
.5424 .3743 Mdot
.5408 .37913 Mdot
.56979 .60464 Mdot
.36894 .21537 Mdot
.45706 .60303 Mdot
.3906 .30589 Mdot
.56189 .38498 Mdot
.32862 .49704 Mdot
.68993 .40713 Mdot
.60731 .68009 Mdot
.60665 .59452 Mdot
.40136 .29757 Mdot
.30718 .46992 Mdot
.40777 .21256 Mdot
.35159 .61664 Mdot
.55102 .4585 Mdot
.58784 .61057 Mdot
.56435 .60879 Mdot
.42806 .30248 Mdot
.44951 .3157 Mdot
.52448 .35754 Mdot
.44096 .50198 Mdot
.65748 .24435 Mdot
.44065 .34611 Mdot
.406 .2118 Mdot
.75245 .43487 Mdot
.68544 .43528 Mdot
.57081 .38514 Mdot
.42591 .33928 Mdot
.54607 .59858 Mdot
.6807 .41818 Mdot
.47226 .56995 Mdot
.68658 .39642 Mdot
.371 .53843 Mdot
.4543 .41553 Mdot
.58945 .61204 Mdot
.64663 .47383 Mdot
.66693 .45487 Mdot
.64945 .48045 Mdot
.55754 .39199 Mdot
.56154 .62734 Mdot
.5555 .6471 Mdot
.53393 .59836 Mdot
.48041 .6026 Mdot
.57112 .6005 Mdot
.65862 .34198 Mdot
.50736 .40669 Mdot
.23198 .58024 Mdot
.54277 .58649 Mdot
.4324 .33532 Mdot
.53891 .59323 Mdot
.36914 .62389 Mdot
.55853 .57379 Mdot
.36836 .53972 Mdot
.43792 .31172 Mdot
.64284 .64011 Mdot
.31573 .52713 Mdot
.5908 .62311 Mdot
.31619 .61115 Mdot
.34495 .23225 Mdot
.36481 .731 Mdot
.50707 .35909 Mdot
.69958 .44651 Mdot
.3402 .49296 Mdot
.46438 .30242 Mdot
.30166 .49577 Mdot
.58581 .64765 Mdot
.56107 .368 Mdot
.79508 .67382 Mdot
.45125 .45002 Mdot
.54549 .5968 Mdot
.51585 .67467 Mdot
.68027 .42136 Mdot
.29911 .48221 Mdot
.73775 .41074 Mdot
.54051 .6556 Mdot
.34269 .59708 Mdot
.36413 .60926 Mdot
.39439 .50121 Mdot
.38203 .35151 Mdot
.59765 .75386 Mdot
.4301 .30321 Mdot
.32498 .46381 Mdot
.34453 .59314 Mdot
.63741 .513 Mdot
.4654 .32736 Mdot
.45777 .29818 Mdot
.41124 .31011 Mdot
.57512 .5947 Mdot
.56412 .37433 Mdot
.35983 .32008 Mdot
.55047 .39738 Mdot
.55671 .65484 Mdot
.27149 .4494 Mdot
.55251 .39945 Mdot
.33211 .60996 Mdot
.4551 .3309 Mdot
.32876 .49208 Mdot
.55971 .5962 Mdot
.67656 .44614 Mdot
.3712 .75926 Mdot
.18971 .41068 Mdot
.33639 .53989 Mdot
.33571 .53976 Mdot
.70152 .42256 Mdot
.71513 .30845 Mdot
.47448 .30948 Mdot
.66901 .62125 Mdot
.37547 .66068 Mdot
.59029 .65104 Mdot
.21269 .66799 Mdot
.29636 .44465 Mdot
.29632 .45988 Mdot
.58145 .60918 Mdot
.28769 .49918 Mdot
.57812 .58586 Mdot
.28097 .45383 Mdot
.62178 .30268 Mdot
.60886 .59655 Mdot
.29473 .4627 Mdot
.49397 .59752 Mdot
.5129 .60213 Mdot
.6881 .42203 Mdot
.30847 .51175 Mdot
.57273 .65695 Mdot
.74604 .73737 Mdot
.42055 .29886 Mdot
.55866 .39185 Mdot
.32684 .53967 Mdot
.40926 .29184 Mdot
.65079 .45452 Mdot
.54667 .57737 Mdot
.35083 .61109 Mdot
.68918 .44116 Mdot
.30316 .51968 Mdot
.31968 .62671 Mdot
.54414 .43113 Mdot
.68663 .43343 Mdot
.56418 .3796 Mdot
.36292 .62589 Mdot
.56543 .67192 Mdot
.2996 .46088 Mdot
.2243 .36817 Mdot
.55396 .39708 Mdot
.56923 .61943 Mdot
.25853 .46476 Mdot
.40417 .30262 Mdot
.58213 .6335 Mdot
.32341 .46425 Mdot
.55449 .39376 Mdot
.52758 .5892 Mdot
.52971 .58458 Mdot
.62538 .6711 Mdot
.43478 .5576 Mdot
.33899 .61144 Mdot
.6275 .46418 Mdot
.55746 .65207 Mdot
.37061 .63295 Mdot
.25295 .36911 Mdot
.60979 .61759 Mdot
.69177 .4734 Mdot
.64234 .68239 Mdot
.28873 .49516 Mdot
.435 .28368 Mdot
.28467 .50243 Mdot
.31584 .62693 Mdot
.14395 .45017 Mdot
.5695 .38797 Mdot
.51481 .66824 Mdot
.53033 .65886 Mdot
.31368 .43774 Mdot
.66767 .45764 Mdot
.67154 .25773 Mdot
.56346 .57495 Mdot
.55177 .69388 Mdot
.55502 .60786 Mdot
.23487 .3777 Mdot
.66154 .46757 Mdot
.55437 .61051 Mdot
.53765 .54637 Mdot
.54268 .66311 Mdot
.32027 .60388 Mdot
.46835 .73017 Mdot
.53587 .61418 Mdot
.52306 .91989 Mdot
.54538 .3652 Mdot
.30097 .46712 Mdot
.48794 .43869 Mdot
.26469 .52152 Mdot
.41902 .8213 Mdot
.65369 .45459 Mdot
.71954 .48466 Mdot
.30072 .49646 Mdot
.35114 .75221 Mdot
.72033 .32124 Mdot
.50731 .60778 Mdot
.57993 .58321 Mdot
.27817 .47469 Mdot
.3005 .50248 Mdot
.55227 .36358 Mdot
.59604 .59285 Mdot
.54305 .69769 Mdot
.26559 .47641 Mdot
.56041 .59111 Mdot
.69736 .63125 Mdot
.44195 .27816 Mdot
.68509 .43002 Mdot
.42597 .28754 Mdot
.45403 .29353 Mdot
.62807 .72802 Mdot
.53663 .45701 Mdot
.44298 .32937 Mdot
.40405 .28042 Mdot
.36446 .57377 Mdot
.57634 .74415 Mdot
.32339 .60177 Mdot
.40097 .35883 Mdot
.31083 .48299 Mdot
.55951 .62825 Mdot
.66931 .47496 Mdot
.55882 .8051 Mdot
.57024 .20083 Mdot
.50179 .51676 Mdot
.55185 .65018 Mdot
.30364 .48189 Mdot
.55281 .39552 Mdot
.61128 .60235 Mdot
.3941 .75344 Mdot
.57009 .61035 Mdot
.30732 .50269 Mdot
.61584 .74737 Mdot
.58652 .37356 Mdot
.4436 .34493 Mdot
.69574 .40459 Mdot
.53758 .59622 Mdot
.6645 .43696 Mdot
.45071 .3244 Mdot
.37088 .63843 Mdot
.33763 .61957 Mdot
.59222 .61858 Mdot
.41448 .50937 Mdot
.39227 .64379 Mdot
.50727 .60852 Mdot
.51538 .61508 Mdot
.54395 .37279 Mdot
.51597 .61406 Mdot
.59618 .62739 Mdot
.53101 .62683 Mdot
.60513 .60792 Mdot
.44347 .33871 Mdot
.71491 .38593 Mdot
.57912 .57338 Mdot
.53349 .66477 Mdot
.4268 .27501 Mdot
.61134 .57091 Mdot
.43307 .32105 Mdot
.60201 .2077 Mdot
.43496 .32838 Mdot
.33858 .61869 Mdot
.26018 .47732 Mdot
.74226 .4485 Mdot
.64609 .45987 Mdot
.43347 .33639 Mdot
.35486 .63163 Mdot
.44457 .31389 Mdot
.32065 .45555 Mdot
.27961 .27871 Mdot
.65153 .49279 Mdot
.49216 .39777 Mdot
.55061 .73863 Mdot
.52877 .37209 Mdot
.27706 .48685 Mdot
.65252 .43115 Mdot
.58156 .3655 Mdot
.52751 .63292 Mdot
.34461 .60751 Mdot
.56903 .60509 Mdot
.4587 .32885 Mdot
.30629 .48179 Mdot
.38422 .30168 Mdot
.33792 .61151 Mdot
.1633 .42853 Mdot
.27627 .45118 Mdot
.52218 .66695 Mdot
.42927 .27562 Mdot
.29826 .25923 Mdot
.43528 .32528 Mdot
.3848 .67846 Mdot
.61326 .47505 Mdot
.52895 .8063 Mdot
.68551 .45488 Mdot
.53256 .36096 Mdot
.75837 .30464 Mdot
.68407 .31568 Mdot
.68021 .43869 Mdot
.31617 .52762 Mdot
.57137 .59617 Mdot
.53933 .63852 Mdot
.49124 .63152 Mdot
.71383 .4015 Mdot
.57309 .64645 Mdot
.56604 .39037 Mdot
.52596 .44638 Mdot
.3397 .26551 Mdot
.33737 .49873 Mdot
.58216 .58944 Mdot
.45592 .3054 Mdot
.45717 .33311 Mdot
.54837 .39829 Mdot
.41047 .29875 Mdot
.51637 .60155 Mdot
.69025 .44987 Mdot
.41474 .44718 Mdot
.33157 .603 Mdot
.63698 .33437 Mdot
.38254 .65626 Mdot
.33036 .6502 Mdot
.54744 .6648 Mdot
.30886 .4998 Mdot
.18066 .59971 Mdot
.53434 .64024 Mdot
.66926 .44994 Mdot
.5266 .6558 Mdot
.53215 .62165 Mdot
.53747 .61215 Mdot
.32565 .46588 Mdot
.48759 .4344 Mdot
.55803 .59008 Mdot
.44475 .32963 Mdot
.43341 .41632 Mdot
.60276 .59006 Mdot
.34135 .32335 Mdot
.37246 .53825 Mdot
.53023 .37116 Mdot
.64565 .41918 Mdot
.28861 .48642 Mdot
.67921 .45633 Mdot
.72426 .44293 Mdot
.6506 .45395 Mdot
.34441 .30439 Mdot
.661 .63896 Mdot
.33355 .8023 Mdot
.7799 .59826 Mdot
.6202 .74895 Mdot
.71206 .45491 Mdot
.29675 .35342 Mdot
.67616 .43658 Mdot
.65178 .45386 Mdot
.25795 .77944 Mdot
.68608 .47372 Mdot
.55247 .61804 Mdot
.54899 .57145 Mdot
.76057 .38628 Mdot
.36792 .57675 Mdot
.54725 .58061 Mdot
.57591 .64393 Mdot
.3546 .59955 Mdot
.63695 .56973 Mdot
.54598 .36134 Mdot
.54577 .4536 Mdot
.57368 .3834 Mdot
.55712 .60259 Mdot
.58729 .6189 Mdot
.54983 .5656 Mdot
.77449 .31322 Mdot
.52622 .81815 Mdot
.69988 .424 Mdot
.61024 .56225 Mdot
.56187 .41001 Mdot
.51794 .65463 Mdot
.53121 .65779 Mdot
.53096 .60014 Mdot
.2977 .49508 Mdot
.6889 .40789 Mdot
.61905 .62041 Mdot
.64168 .36675 Mdot
.58821 .61249 Mdot
.34433 .65979 Mdot
.38602 .62904 Mdot
.55993 .61699 Mdot
.69447 .46909 Mdot
.54447 .64611 Mdot
.65897 .48155 Mdot
.68127 .42999 Mdot
.51861 .68063 Mdot
.36491 .32872 Mdot
.69818 .40826 Mdot
.50962 .60389 Mdot
.27509 .47882 Mdot
.63935 .32338 Mdot
.56689 .61943 Mdot
.32286 .61403 Mdot
.54653 .63245 Mdot
.31468 .61085 Mdot
.52274 .6086 Mdot
.54772 .3962 Mdot
.71101 .53237 Mdot
.30943 .4917 Mdot
.36689 .65192 Mdot
.28429 .49547 Mdot
.55629 .71186 Mdot
.69758 .47175 Mdot
.57072 .36267 Mdot
.51056 .8304 Mdot
.54538 .37135 Mdot
.38954 .76931 Mdot
.43215 .4068 Mdot
.44416 .28749 Mdot
.63715 .45622 Mdot
.6128 .74408 Mdot
.36196 .35791 Mdot
.34355 .4679 Mdot
.32739 .45063 Mdot
.20064 .61317 Mdot
.16834 .63464 Mdot
.55631 .58732 Mdot
.32719 .25322 Mdot
.72111 .57554 Mdot
.49062 .59469 Mdot
.57861 .55859 Mdot
.26694 .45582 Mdot
.5446 .58085 Mdot
.48144 .46071 Mdot
.31954 .47526 Mdot
.35522 .62582 Mdot
.657 .43587 Mdot
.36381 .63476 Mdot
.53457 .18774 Mdot
.50087 .36089 Mdot
.31774 .46834 Mdot
.60477 .60253 Mdot
.57209 .58668 Mdot
.63793 .43892 Mdot
.82186 .52163 Mdot
.68051 .42731 Mdot
.32219 .60822 Mdot
.32032 .48686 Mdot
.60403 .77689 Mdot
.54337 .6251 Mdot
.6922 .46249 Mdot
.31146 .52595 Mdot
.56314 .63746 Mdot
.44078 .28875 Mdot
.54953 .65046 Mdot
.69657 .45829 Mdot
.51655 .61377 Mdot
.68845 .45 Mdot
.27589 .46056 Mdot
.595 .60692 Mdot
.58722 .62213 Mdot
.39442 .77254 Mdot
.33458 .62548 Mdot
.7023 .4662 Mdot
.48398 .46163 Mdot
.58118 .64663 Mdot
.39769 .75225 Mdot
.53614 .59518 Mdot
.47323 .67285 Mdot
.60885 .57448 Mdot
.56742 .38725 Mdot
.53218 .65973 Mdot
.56764 .61846 Mdot
.80971 .57415 Mdot
.79893 .57299 Mdot
.52253 .7188 Mdot
.41307 .3313 Mdot
.70033 .45899 Mdot
.32246 .46824 Mdot
.31993 .50832 Mdot
.28878 .47569 Mdot
.38672 .60053 Mdot
.59129 .54039 Mdot
.57491 .61863 Mdot
.46223 .34769 Mdot
.34813 .62369 Mdot
.68085 .4692 Mdot
.34407 .61856 Mdot
.5429 .46249 Mdot
.32059 .62142 Mdot
.56657 .39235 Mdot
.24529 .34296 Mdot
.6848 .65078 Mdot
.32746 .62794 Mdot
.68076 .42802 Mdot
.45593 .40519 Mdot
.58724 .65383 Mdot
.5407 .29593 Mdot
.34329 .59709 Mdot
.1894 .59529 Mdot
.53054 .58875 Mdot
.48239 .44435 Mdot
.42793 .31769 Mdot
.36313 .63474 Mdot
.41174 .30716 Mdot
.54251 .64451 Mdot
.701 .38187 Mdot
.66424 .45024 Mdot
.44261 .27953 Mdot
.54039 .66049 Mdot
.36396 .63418 Mdot
.31327 .46452 Mdot
.59391 .74615 Mdot
.41366 .276 Mdot
.36417 .75357 Mdot
.38232 .74056 Mdot
.32179 .48473 Mdot
.64403 .7499 Mdot
.41856 .31799 Mdot
.60057 .64272 Mdot
.59982 .52699 Mdot
.5407 .64955 Mdot
.33148 .49305 Mdot
.29384 .45992 Mdot
.7069 .35424 Mdot
.59078 .61393 Mdot
.55885 .56814 Mdot
.68674 .41071 Mdot
.32728 .481 Mdot
.64993 .45554 Mdot
.64127 .43674 Mdot
.27738 .47548 Mdot
.65794 .4275 Mdot
.32761 .63386 Mdot
.52764 .47852 Mdot
.42088 .32064 Mdot
.44505 .29356 Mdot
.31691 .46526 Mdot
.33315 .4723 Mdot
.31392 .50032 Mdot
.53512 .65227 Mdot
.64604 .44128 Mdot
.51573 .6352 Mdot
.53774 .59973 Mdot
.61966 .45383 Mdot
.67005 .41357 Mdot
.52418 .64428 Mdot
.40984 .42281 Mdot
.31751 .60258 Mdot
.29427 .46466 Mdot
.41448 .32416 Mdot
.38453 .77995 Mdot
.43435 .27855 Mdot
.57826 .64711 Mdot
.56868 .29541 Mdot
.66599 .4717 Mdot
.33164 .61578 Mdot
.34682 .54141 Mdot
.33524 .61228 Mdot
.44387 .27982 Mdot
.64813 .42117 Mdot
.53648 .43102 Mdot
.59217 .61162 Mdot
.5192 .44968 Mdot
.4316 .76137 Mdot
.65881 .35057 Mdot
.42121 .33215 Mdot
.56124 .64867 Mdot
.54859 .36925 Mdot
.67447 .60707 Mdot
.57766 .61561 Mdot
.58086 .64935 Mdot
.23014 .512 Mdot
.53968 .66519 Mdot
.63628 .43332 Mdot
.4028 .51682 Mdot
.59998 .6112 Mdot
.551 .71099 Mdot
.19636 .69621 Mdot
.53037 .58692 Mdot
.58905 .62146 Mdot
.55079 .62468 Mdot
.52998 .63945 Mdot
.66864 .48578 Mdot
.2076 .49473 Mdot
.45566 .31322 Mdot
.52671 .47843 Mdot
.41441 .31587 Mdot
.30405 .45699 Mdot
.46107 .46691 Mdot
.66127 .48343 Mdot
.33466 .61193 Mdot
.31875 .256 Mdot
.49077 .51825 Mdot
.27173 .46681 Mdot
.44664 .81847 Mdot
.33823 .59772 Mdot
.59033 .65177 Mdot
.326 .63572 Mdot
.26509 .45549 Mdot
.44894 .30439 Mdot
.5003 .61464 Mdot
.65585 .4695 Mdot
.70054 .43724 Mdot
.55231 .65195 Mdot
.63068 .3319 Mdot
.40787 .29162 Mdot
.2877 .65306 Mdot
.57934 .59838 Mdot
.58438 .64704 Mdot
.67416 .42518 Mdot
.29972 .48107 Mdot
.43273 .40844 Mdot
.34298 .63126 Mdot
.49695 .63649 Mdot
.54493 .64406 Mdot
.53998 .46165 Mdot
.44033 .33819 Mdot
.55441 .38277 Mdot
.58641 .60552 Mdot
.53476 .44895 Mdot
.58146 .64335 Mdot
.49142 .67111 Mdot
.2807 .48825 Mdot
.54214 .69339 Mdot
.58644 .58668 Mdot
.71805 .3915 Mdot
.41591 .31294 Mdot
.67054 .45423 Mdot
.62326 .49131 Mdot
.54357 .39008 Mdot
.42402 .29522 Mdot
.5269 .6466 Mdot
.45729 .29485 Mdot
.53575 .62825 Mdot
.55947 .59368 Mdot
.42034 .33195 Mdot
.64841 .4492 Mdot
.65665 .25187 Mdot
.71415 .38543 Mdot
.52231 .62461 Mdot
.54968 .63558 Mdot
.37347 .58 Mdot
.57495 .81511 Mdot
.58723 .58639 Mdot
.64619 .4371 Mdot
.56515 .63794 Mdot
.45015 .29758 Mdot
.32088 .61115 Mdot
.67329 .44519 Mdot
.3276 .46237 Mdot
.28223 .45557 Mdot
.24543 .46686 Mdot
.56869 .39011 Mdot
.59594 .59421 Mdot
.62697 .46368 Mdot
.68333 .41345 Mdot
.55657 .48199 Mdot
.30017 .46628 Mdot
.31762 .61794 Mdot
.53989 .58132 Mdot
.61026 .72994 Mdot
.45896 .30574 Mdot
.53567 .91387 Mdot
.5329 .42952 Mdot
.38691 .6369 Mdot
.42398 .52387 Mdot
.54948 .37135 Mdot
.5531 .5827 Mdot
.36921 .62772 Mdot
.28575 .45728 Mdot
.54042 .64071 Mdot
.56562 .54484 Mdot
.36534 .36785 Mdot
.33416 .46687 Mdot
.45235 .28838 Mdot
.29637 .448 Mdot
.31519 .60826 Mdot
.56565 .39258 Mdot
.70233 .43334 Mdot
.56607 .61474 Mdot
.561 .69974 Mdot
.30353 .47508 Mdot
.53992 .39007 Mdot
.59128 .62558 Mdot
.70289 .4506 Mdot
.29204 .46936 Mdot
.55208 .6014 Mdot
.66954 .61426 Mdot
.735 .46232 Mdot
.31576 .48408 Mdot
.49759 .62591 Mdot
.59658 .7038 Mdot
.33305 .45993 Mdot
.27464 .4444 Mdot
.5756 .64467 Mdot
.36124 .63353 Mdot
.59062 .59703 Mdot
.43965 .32295 Mdot
.48725 .43356 Mdot
.43164 .29087 Mdot
.39816 .75942 Mdot
.56289 .565 Mdot
.48495 .55348 Mdot
.64634 .47112 Mdot
.30463 .61396 Mdot
.79989 .61926 Mdot
.5938 .63996 Mdot
.67225 .23714 Mdot
.45991 .43585 Mdot
.5069 .39376 Mdot
.60624 .18689 Mdot
.33807 .63282 Mdot
.44182 .31525 Mdot
.58886 .62707 Mdot
.4803 .338 Mdot
.34293 .63673 Mdot
.39938 .76072 Mdot
.51141 .65138 Mdot
.66728 .46819 Mdot
.57816 .6 Mdot
.69978 .45416 Mdot
.55803 .635 Mdot
.64454 .60363 Mdot
.35245 .65816 Mdot
.38646 .67745 Mdot
.59173 .65173 Mdot
.32466 .24189 Mdot
.56242 .74213 Mdot
.32669 .60822 Mdot
.52046 .62049 Mdot
.55158 .3765 Mdot
.40312 .30719 Mdot
.28468 .29928 Mdot
.30471 .49818 Mdot
.43937 .33064 Mdot
.66437 .42806 Mdot
.26425 .48086 Mdot
.53973 .38613 Mdot
.59315 .52565 Mdot
.36549 .63229 Mdot
.42127 .29823 Mdot
.56466 .61771 Mdot
.54885 .65723 Mdot
.23404 .37755 Mdot
.65124 .77259 Mdot
.64446 .43578 Mdot
.16044 .49313 Mdot
.62792 .4616 Mdot
.34277 .62721 Mdot
.28428 .49089 Mdot
.54416 .60196 Mdot
.58249 .61702 Mdot
.33269 .48037 Mdot
.65937 .42027 Mdot
.30118 .62143 Mdot
.53707 .80682 Mdot
.42116 .36055 Mdot
.42836 .69279 Mdot
.67218 .44271 Mdot
.42494 .69038 Mdot
.35535 .59519 Mdot
.37914 .26356 Mdot
.52475 .74422 Mdot
.43494 .28597 Mdot
.43237 .69608 Mdot
.6811 .47077 Mdot
.55574 .58603 Mdot
.56342 .37942 Mdot
.55086 .36633 Mdot
.66449 .43359 Mdot
.28039 .47946 Mdot
.35987 .61505 Mdot
.57934 .60381 Mdot
.55918 .5105 Mdot
.83119 .50135 Mdot
.33181 .47323 Mdot
.50965 .66768 Mdot
.40807 .29548 Mdot
.55892 .63834 Mdot
.36332 .60717 Mdot
.44514 .30524 Mdot
.56043 .4008 Mdot
.49489 .5101 Mdot
.5439 .57771 Mdot
.3955 .52544 Mdot
.42349 .3091 Mdot
.58062 .81384 Mdot
.58652 .62255 Mdot
.41821 .31752 Mdot
.5566 .70009 Mdot
.61024 .3795 Mdot
.41996 .43693 Mdot
.68195 .31083 Mdot
.33958 .50396 Mdot
.28612 .45137 Mdot
.71834 .75505 Mdot
.37456 .66136 Mdot
.44411 .33273 Mdot
.56169 .39569 Mdot
.49195 .73836 Mdot
.41385 .30081 Mdot
.50395 .6086 Mdot
.53656 .59218 Mdot
.61746 .74737 Mdot
.54163 .72081 Mdot
.54744 .36256 Mdot
.56203 .52572 Mdot
.5089 .61437 Mdot
.56585 .6767 Mdot
.57665 .6384 Mdot
.70777 .43558 Mdot
.42703 .28404 Mdot
.47826 .12116 Mdot
.46413 .30661 Mdot
.5291 .50974 Mdot
.31044 .48301 Mdot
.31941 .51407 Mdot
.55962 .61584 Mdot
.4491 .60963 Mdot
.36467 .20924 Mdot
.54083 .6204 Mdot
.34985 .54165 Mdot
.3808 .74014 Mdot
.61401 .62457 Mdot
.71632 .43616 Mdot
.54495 .69723 Mdot
.64342 .48497 Mdot
.44578 .3038 Mdot
.33836 .63374 Mdot
.32507 .5946 Mdot
.43678 .31835 Mdot
.57692 .62206 Mdot
.32469 .59236 Mdot
.56122 .60882 Mdot
.56704 .58577 Mdot
.54748 .45945 Mdot
.37819 .6321 Mdot
.31405 .50083 Mdot
.33677 .6175 Mdot
.65507 .4584 Mdot
.27568 .80281 Mdot
.34733 .61354 Mdot
.57895 .74457 Mdot
.47381 .45048 Mdot
.43245 .69921 Mdot
.69793 .43357 Mdot
.32477 .60545 Mdot
.43265 .28355 Mdot
.53673 .42313 Mdot
.64111 .74877 Mdot
.43655 .27979 Mdot
.58191 .61298 Mdot
.65868 .48261 Mdot
.69641 .41939 Mdot
.43962 .34423 Mdot
.67722 .41979 Mdot
.53915 .678 Mdot
.50861 .60438 Mdot
.45056 .3268 Mdot
.79699 .41984 Mdot
.43322 .28215 Mdot
.60455 .73378 Mdot
.52779 .60034 Mdot
.67132 .44775 Mdot
.46902 .6616 Mdot
.64562 .41193 Mdot
.55978 .36854 Mdot
.55979 .57294 Mdot
.33893 .60643 Mdot
.51438 .4706 Mdot
.31474 .48532 Mdot
.57381 .29399 Mdot
.69991 .44633 Mdot
.46931 .32485 Mdot
.69012 .4232 Mdot
.6482 .42896 Mdot
.44246 .28084 Mdot
.66047 .45718 Mdot
.58728 .61376 Mdot
.50715 .21138 Mdot
.69792 .44395 Mdot
.42937 .3066 Mdot
.34268 .60436 Mdot
.65519 .42936 Mdot
.30107 .59184 Mdot
.5685 .58332 Mdot
.26921 .47809 Mdot
.36511 .65031 Mdot
.65142 .48067 Mdot
.32155 .61203 Mdot
.30075 .47117 Mdot
.36164 .61557 Mdot
.46639 .35451 Mdot
.47377 .32139 Mdot
.50032 .52093 Mdot
.59749 .38189 Mdot
.66556 .47503 Mdot
.34112 .50558 Mdot
.56112 .57735 Mdot
.57669 .59338 Mdot
.30883 .61606 Mdot
.70701 .42826 Mdot
.62163 .3275 Mdot
.46457 .60385 Mdot
.63668 .33587 Mdot
.42215 .3369 Mdot
.29887 .69691 Mdot
.53227 .42712 Mdot
.50396 .35436 Mdot
.51583 .58356 Mdot
.55103 .3714 Mdot
.55441 .60819 Mdot
.36393 .72999 Mdot
.32631 .59983 Mdot
.25633 .39301 Mdot
.48908 .60859 Mdot
.32456 .48996 Mdot
.55118 .63162 Mdot
.31845 .27045 Mdot
.53277 .70266 Mdot
.33684 .59523 Mdot
.43924 .27337 Mdot
.64608 .45994 Mdot
.33314 .6009 Mdot
.27856 .4585 Mdot
.44399 .68426 Mdot
.51482 .59379 Mdot
.5112 .60794 Mdot
.31397 .44239 Mdot
.65154 .45996 Mdot
.3014 .45821 Mdot
.42035 .32027 Mdot
.34588 .61548 Mdot
.52661 .63705 Mdot
.54638 .68986 Mdot
.30896 .43622 Mdot
.46439 .31822 Mdot
.33633 .48043 Mdot
.45929 .29934 Mdot
.5545 .37169 Mdot
.60178 .60332 Mdot
.29535 .43598 Mdot
.52046 .57651 Mdot
.79468 .5533 Mdot
.5337 .48445 Mdot
.76665 .65425 Mdot
.31371 .5012 Mdot
.41113 .62797 Mdot
.4355 .31402 Mdot
.41778 .3026 Mdot
.62326 .73238 Mdot
.36404 .21449 Mdot
.43684 .41153 Mdot
.25693 .30029 Mdot
.42139 .32126 Mdot
.42367 .30224 Mdot
.2838 .46212 Mdot
.6541 .44942 Mdot
.72012 .45609 Mdot
.26223 .45491 Mdot
.36701 .70122 Mdot
.68147 .46904 Mdot
.70651 .26814 Mdot
.30157 .44274 Mdot
.52836 .57765 Mdot
.5697 .36465 Mdot
.33957 .5956 Mdot
.36526 .72243 Mdot
.27213 .28972 Mdot
.54777 .60834 Mdot
.28344 .7592 Mdot
.29301 .48942 Mdot
.42877 .37203 Mdot
.3908 .24347 Mdot
.56063 .65673 Mdot
.55307 .62993 Mdot
.57717 .62775 Mdot
.35761 .64892 Mdot
.81348 .51655 Mdot
.54638 .60407 Mdot
.39576 .65861 Mdot
.60918 .59647 Mdot
.2256 .37368 Mdot
.33715 .61755 Mdot
.48772 .79137 Mdot
.3237 .52022 Mdot
.63452 .36192 Mdot
.55106 .66393 Mdot
.42639 .32296 Mdot
.38619 .39578 Mdot
.432 .33428 Mdot
.3725 .25472 Mdot
.51998 .74673 Mdot
.70921 .4381 Mdot
.54895 .65092 Mdot
.29557 .44067 Mdot
.65548 .48144 Mdot
.3972 .40972 Mdot
.24087 .76758 Mdot
.43374 .34117 Mdot
.13246 .55331 Mdot
.42278 .29096 Mdot
.54976 .36534 Mdot
.66933 .42844 Mdot
.44007 .64952 Mdot
.52444 .45273 Mdot
.64971 .45418 Mdot
.2471 .61621 Mdot
.68377 .49142 Mdot
.42161 .66742 Mdot
.65971 .49636 Mdot
.43542 .30854 Mdot
.47318 .31722 Mdot
.58132 .54878 Mdot
.57671 .5787 Mdot
.51322 .44221 Mdot
.56493 .55739 Mdot
.55417 .57744 Mdot
.31977 .47544 Mdot
.59461 .37128 Mdot
.48408 .32797 Mdot
.66866 .4395 Mdot
.4591 .31755 Mdot
.55127 .63013 Mdot
.52182 .62433 Mdot
.52594 .66198 Mdot
.35949 .75846 Mdot
.7022 .26277 Mdot
.55659 .59112 Mdot
.53023 .69979 Mdot
.27271 .47015 Mdot
.23133 .37909 Mdot
.17468 .48007 Mdot
.5028 .739 Mdot
.59221 .6264 Mdot
.33472 .62358 Mdot
.35333 .59799 Mdot
.53479 .6713 Mdot
.48179 .55226 Mdot
.30152 .58659 Mdot
.5647 .61797 Mdot
.42618 .64195 Mdot
.33291 .44809 Mdot
.54236 .39362 Mdot
.30357 .47455 Mdot
.65465 .48257 Mdot
.54531 .37005 Mdot
.31685 .45785 Mdot
.43114 .61319 Mdot
.54552 .39109 Mdot
.61374 .37675 Mdot
.32269 .6072 Mdot
.58206 .63326 Mdot
.74153 .42596 Mdot
.32999 .47615 Mdot
.42084 .30577 Mdot
.68492 .44513 Mdot
.40289 .31825 Mdot
.23432 .36052 Mdot
.37068 .71244 Mdot
.56933 .38628 Mdot
.43054 .32515 Mdot
.42582 .48959 Mdot
.33592 .6227 Mdot
.41496 .29324 Mdot
.47182 .5715 Mdot
.59219 .57847 Mdot
.42109 .18814 Mdot
.505 .62053 Mdot
.71239 .34493 Mdot
.41979 .31178 Mdot
.56684 .40085 Mdot
.56727 .61356 Mdot
.27618 .45235 Mdot
.61925 .58059 Mdot
.56165 .6074 Mdot
.31048 .44816 Mdot
.55498 .58804 Mdot
.37422 .62882 Mdot
.64183 .48163 Mdot
.4579 .44433 Mdot
.33872 .73137 Mdot
.35284 .60664 Mdot
.58963 .48641 Mdot
.58312 .58161 Mdot
.22038 .5921 Mdot
.66649 .46575 Mdot
.58768 .64351 Mdot
.4141 .78745 Mdot
.65822 .44083 Mdot
.67978 .45718 Mdot
.51346 .61935 Mdot
.43107 .28024 Mdot
.33023 .49224 Mdot
.33531 .62084 Mdot
.48469 .35046 Mdot
.5502 .60005 Mdot
.56463 .64804 Mdot
.33717 .59829 Mdot
.42486 .29669 Mdot
.52536 .63858 Mdot
.61849 .27114 Mdot
.55346 .48413 Mdot
.45687 .29796 Mdot
.60206 .58946 Mdot
.50944 .14902 Mdot
.72086 .45767 Mdot
.29523 .7713 Mdot
.37782 .65662 Mdot
.27874 .48164 Mdot
.49312 .6448 Mdot
.49528 .92129 Mdot
.32725 .60515 Mdot
.64297 .35407 Mdot
.56218 .58898 Mdot
.54136 .60374 Mdot
.70786 .45043 Mdot
.51714 .64031 Mdot
.69226 .46734 Mdot
.31994 .72228 Mdot
.3259 .21972 Mdot
.68114 .42102 Mdot
.69593 .46247 Mdot
.5372 .71385 Mdot
.36818 .77029 Mdot
.65785 .4335 Mdot
.51609 .59247 Mdot
.23689 .59171 Mdot
.54914 .54616 Mdot
.38372 .6298 Mdot
.31743 .57219 Mdot
.7155 .44237 Mdot
.68762 .7239 Mdot
.533 .71101 Mdot
.63926 .65434 Mdot
.3438 .58173 Mdot
.42957 .3301 Mdot
.53 .61284 Mdot
.56712 .39337 Mdot
.28955 .46696 Mdot
.57042 .68354 Mdot
.58316 .62785 Mdot
.67976 .47866 Mdot
.33612 .6445 Mdot
.41188 .30124 Mdot
.58105 .63961 Mdot
.28486 .43163 Mdot
.35327 .62963 Mdot
.6952 .43984 Mdot
.58713 .74055 Mdot
.33287 .59233 Mdot
.5361 .68809 Mdot
.54572 .58446 Mdot
.58909 .63353 Mdot
.50526 .57234 Mdot
.43386 .31866 Mdot
.25993 .46488 Mdot
.49355 .64275 Mdot
.54392 .44206 Mdot
.50388 .47687 Mdot
.50825 .65953 Mdot
.64775 .4346 Mdot
.4191 .33441 Mdot
.55273 .39081 Mdot
.45458 .72045 Mdot
.52911 .59245 Mdot
.68891 .24816 Mdot
.48582 .82511 Mdot
.54634 .3873 Mdot
.6867 .48382 Mdot
.33317 .61528 Mdot
.51671 .60665 Mdot
.38224 .67004 Mdot
.50353 .61077 Mdot
.54112 .54265 Mdot
.28459 .48638 Mdot
.42019 .32717 Mdot
.5772 .5028 Mdot
.28953 .465 Mdot
.67938 .45664 Mdot
.75832 .35291 Mdot
.70933 .47142 Mdot
.64417 .43355 Mdot
.36347 .31694 Mdot
.44966 .31129 Mdot
.50909 .92365 Mdot
.56878 .82012 Mdot
.53885 .57465 Mdot
.45299 .31296 Mdot
.67069 .43072 Mdot
.52269 .65023 Mdot
.67111 .47443 Mdot
.69935 .40999 Mdot
.54719 .5792 Mdot
.55387 .57869 Mdot
.39446 .67119 Mdot
.7199 .28486 Mdot
.34555 .60818 Mdot
.68304 .41855 Mdot
.64899 .70121 Mdot
.5451 .59845 Mdot
.59126 .60879 Mdot
.37667 .38185 Mdot
.32756 .60254 Mdot
.69482 .61603 Mdot
.57453 .59369 Mdot
.40221 .78813 Mdot
.55928 .57477 Mdot
.7246 .43519 Mdot
.41591 .34195 Mdot
.51444 .52368 Mdot
.33038 .49561 Mdot
.63637 .45435 Mdot
.3108 .61459 Mdot
.65152 .41371 Mdot
.66325 .65991 Mdot
.44781 .30486 Mdot
.69639 .45883 Mdot
.27508 .49674 Mdot
.43368 .29592 Mdot
.43826 .28531 Mdot
.40093 .41395 Mdot
.27237 .49156 Mdot
.36861 .64605 Mdot
.40577 .31382 Mdot
.66775 .61543 Mdot
.4368 .30593 Mdot
.666 .65221 Mdot
.59666 .60313 Mdot
.4037 .65112 Mdot
.55944 .50442 Mdot
.5687 .54763 Mdot
.42175 .28663 Mdot
.36018 .62171 Mdot
.53168 .64907 Mdot
.67196 .42022 Mdot
.35432 .61735 Mdot
.47025 .36992 Mdot
.31837 .51649 Mdot
.70054 .42025 Mdot
.44265 .27652 Mdot
.68095 .475 Mdot
.37515 .73367 Mdot
.30584 .64126 Mdot
.39667 .42598 Mdot
.51699 .45189 Mdot
.57272 .66908 Mdot
.54642 .71286 Mdot
.54068 .65884 Mdot
.58166 .62042 Mdot
.31522 .48351 Mdot
.38908 .60355 Mdot
.65475 .42939 Mdot
.83648 .48238 Mdot
.42844 .32176 Mdot
.40478 .51645 Mdot
.5549 .53727 Mdot
.5372 .63288 Mdot
.67836 .4343 Mdot
.68419 .40625 Mdot
.79913 .57412 Mdot
.33332 .48127 Mdot
.54572 .54856 Mdot
.55533 .66608 Mdot
.62093 .54922 Mdot
.42958 .2866 Mdot
.63836 .26328 Mdot
.33148 .50262 Mdot
.13369 .60159 Mdot
.29402 .46371 Mdot
.21997 .52783 Mdot
.65982 .45635 Mdot
.3195 .62354 Mdot
.58732 .60062 Mdot
.61641 .41718 Mdot
.67656 .48463 Mdot
.35239 .49765 Mdot
.33244 .61059 Mdot
.65215 .25662 Mdot
.44737 .32406 Mdot
.59862 .61879 Mdot
.55348 .57486 Mdot
.51536 .62962 Mdot
.51783 .65065 Mdot
.45407 .32326 Mdot
.50055 .61804 Mdot
.41218 .27559 Mdot
.67335 .65876 Mdot
.41975 .78624 Mdot
.28279 .44037 Mdot
.22453 .39062 Mdot
.64796 .43027 Mdot
.67481 .52832 Mdot
.69363 .63146 Mdot
.5348 .48452 Mdot
.45749 .35554 Mdot
.5999 .60417 Mdot
.28049 .47744 Mdot
.3325 .24095 Mdot
.28463 .44079 Mdot
.4107 .14712 Mdot
.60957 .7475 Mdot
.70535 .31669 Mdot
.51065 .64069 Mdot
.27913 .43663 Mdot
.70635 .69721 Mdot
.54425 .69099 Mdot
.31349 .59659 Mdot
.65698 .64855 Mdot
.72764 .37561 Mdot
.31786 .61535 Mdot
.56284 .58241 Mdot
.66353 .41408 Mdot
.58599 .61059 Mdot
.58319 .59298 Mdot
.54148 .62423 Mdot
.40511 .3325 Mdot
.56494 .56975 Mdot
.59028 .597 Mdot
.63942 .77567 Mdot
.36976 .53445 Mdot
.27187 .46199 Mdot
.77918 .63191 Mdot
.34856 .62352 Mdot
.65252 .4799 Mdot
.46381 .43453 Mdot
.4416 .32517 Mdot
.79696 .57747 Mdot
.50635 .63208 Mdot
.65889 .3365 Mdot
.47168 .31519 Mdot
.35416 .63444 Mdot
.5517 .39321 Mdot
.61411 .22515 Mdot
.29963 .5007 Mdot
.55324 .36283 Mdot
.31416 .48641 Mdot
.74369 .68857 Mdot
.69653 .46291 Mdot
.57106 .67084 Mdot
.40925 .3065 Mdot
.26762 .45513 Mdot
.38921 .66466 Mdot
.57308 .63514 Mdot
.3161 .50117 Mdot
.58561 .66084 Mdot
.50414 .46788 Mdot
.47103 .43179 Mdot
.26241 .46554 Mdot
.46826 .29973 Mdot
.43607 .29305 Mdot
.31604 .62454 Mdot
.64172 .46871 Mdot
.65499 .46636 Mdot
.44049 .30093 Mdot
.18718 .66108 Mdot
.55034 .60204 Mdot
.54174 .59166 Mdot
.54133 .43602 Mdot
.52634 .65333 Mdot
.40502 .61288 Mdot
.53827 .36862 Mdot
.65862 .47537 Mdot
.53678 .65585 Mdot
.52459 .63753 Mdot
.5375 .58544 Mdot
.37427 .71033 Mdot
.30192 .4759 Mdot
.51003 .61256 Mdot
.36771 .62983 Mdot
.52511 .35718 Mdot
.56452 .57749 Mdot
.55499 .68599 Mdot
.68838 .4702 Mdot
.19478 .5951 Mdot
.42152 .31151 Mdot
.32865 .48216 Mdot
.31061 .44396 Mdot
.42713 .74836 Mdot
.70175 .39886 Mdot
.54502 .36225 Mdot
.25566 .35109 Mdot
.55967 .3942 Mdot
.32565 .61336 Mdot
.42358 .42304 Mdot
.33066 .44101 Mdot
.28251 .45282 Mdot
.45863 .28261 Mdot
.55742 .65414 Mdot
.55523 .57643 Mdot
.63402 .35556 Mdot
.53869 .60983 Mdot
.33687 .60547 Mdot
.42432 .27759 Mdot
.69249 .46509 Mdot
.36535 .61016 Mdot
.41732 .30017 Mdot
.65021 .4584 Mdot
.61357 .61291 Mdot
.49891 .64379 Mdot
.68516 .44923 Mdot
.69586 .43674 Mdot
.55545 .62083 Mdot
.68891 .75798 Mdot
.65489 .47296 Mdot
.68479 .43773 Mdot
.53234 .40682 Mdot
.28397 .49379 Mdot
.47413 .66126 Mdot
.45238 .31112 Mdot
.58927 .61141 Mdot
.28439 .43885 Mdot
.32424 .62413 Mdot
.68757 .45695 Mdot
.5285 .60941 Mdot
.55563 .59736 Mdot
.33332 .62222 Mdot
.3788 .62318 Mdot
.34253 .60202 Mdot
.40656 .33127 Mdot
.50843 .60566 Mdot
.6572 .43197 Mdot
.44819 .32394 Mdot
.3451 .5953 Mdot
.33308 .63993 Mdot
.63954 .76912 Mdot
.54956 .61069 Mdot
.32503 .59011 Mdot
.33726 .85151 Mdot
.45318 .69766 Mdot
.54182 .37174 Mdot
.29943 .43122 Mdot
.40082 .63809 Mdot
.35391 .65126 Mdot
.43849 .33439 Mdot
.37724 .53553 Mdot
.31333 .6305 Mdot
.53617 .61226 Mdot
.55679 .64095 Mdot
.50325 .59674 Mdot
.35396 .62186 Mdot
.37657 .72179 Mdot
.68465 .41563 Mdot
.73094 .54737 Mdot
.34865 .62337 Mdot
.26355 .47089 Mdot
.29845 .43366 Mdot
.29457 .46077 Mdot
.60267 .61437 Mdot
.80275 .59576 Mdot
.6618 .68334 Mdot
.7002 .60243 Mdot
.4423 .32874 Mdot
.68658 .40698 Mdot
.38392 .29508 Mdot
.68001 .45778 Mdot
.29094 .47846 Mdot
.35657 .62839 Mdot
.70898 .44729 Mdot
.44034 .28752 Mdot
.43545 .2903 Mdot
.33806 .48236 Mdot
.30293 .46987 Mdot
.31599 .46664 Mdot
.63698 .45896 Mdot
.6601 .457 Mdot
.52372 .63162 Mdot
.69281 .45365 Mdot
.49495 .83095 Mdot
.38637 .64548 Mdot
.33457 .45565 Mdot
.42747 .31286 Mdot
.68596 .43337 Mdot
.58429 .63075 Mdot
.24496 .52222 Mdot
.3518 .49274 Mdot
.35791 .60795 Mdot
.49079 .23786 Mdot
.28973 .23176 Mdot
.60626 .59934 Mdot
.46215 .32229 Mdot
.48215 .5543 Mdot
.5718 .62961 Mdot
.29158 .49302 Mdot
.50915 .8058 Mdot
.55098 .39645 Mdot
.58269 .58671 Mdot
.57778 .6525 Mdot
.42964 .28175 Mdot
.46677 .43383 Mdot
.5376 .61748 Mdot
.41613 .4639 Mdot
.44867 .33833 Mdot
.33217 .50178 Mdot
.73374 .75338 Mdot
.43879 .37295 Mdot
.33221 .70058 Mdot
.54058 .38316 Mdot
.53621 .60605 Mdot
.31942 .47756 Mdot
.36681 .61843 Mdot
.31244 .47463 Mdot
.69039 .48325 Mdot
.28919 .49535 Mdot
.56751 .64226 Mdot
.6541 .43574 Mdot
.42277 .29682 Mdot
.39956 .52452 Mdot
.66463 .75377 Mdot
.27569 .45332 Mdot
.54386 .39862 Mdot
.55954 .57951 Mdot
.6712 .583 Mdot
.58568 .54928 Mdot
.58514 .58519 Mdot
.42312 .33325 Mdot
.67368 .43569 Mdot
.42197 .33649 Mdot
.60772 .64009 Mdot
.67146 .51692 Mdot
.43165 .32248 Mdot
.70087 .37855 Mdot
.33712 .59772 Mdot
.36639 .70259 Mdot
.57531 .61184 Mdot
.40979 .30861 Mdot
.51288 .60091 Mdot
.68493 .41846 Mdot
.49415 .49967 Mdot
.60388 .50931 Mdot
.40775 .29533 Mdot
.73107 .34842 Mdot
.48454 .46301 Mdot
.48488 .67696 Mdot
.41576 .31592 Mdot
.79966 .61755 Mdot
.55147 .3791 Mdot
.33862 .63009 Mdot
.37071 .61171 Mdot
.35286 .64094 Mdot
.53869 .60527 Mdot
.65001 .61709 Mdot
.35204 .64451 Mdot
.41215 .33484 Mdot
.3697 .63925 Mdot
.37083 .76173 Mdot
.62917 .33048 Mdot
.34778 .60213 Mdot
.57394 .60791 Mdot
.58211 .66949 Mdot
.37016 .53878 Mdot
.2965 .50961 Mdot
.65036 .23436 Mdot
.61661 .77628 Mdot
.5441 .60355 Mdot
.65344 .5941 Mdot
.70931 .46443 Mdot
.43232 .56375 Mdot
.60941 .51777 Mdot
.45727 .40843 Mdot
.68645 .43608 Mdot
.49322 .43807 Mdot
.65254 .47488 Mdot
.6017 .6436 Mdot
.56061 .59389 Mdot
.65935 .48783 Mdot
.556 .28912 Mdot
.83368 .55278 Mdot
.64109 .33299 Mdot
.64554 .44704 Mdot
.41571 .31246 Mdot
.45625 .33195 Mdot
.42146 .33199 Mdot
.32693 .47335 Mdot
.70158 .44648 Mdot
.5231 .59654 Mdot
.27642 .46258 Mdot
.58249 .59734 Mdot
.44181 .29591 Mdot
.55362 .48646 Mdot
.6924 .46579 Mdot
.56708 .6179 Mdot
.6507 .73363 Mdot
.30634 .48654 Mdot
.33791 .62452 Mdot
.49896 .2288 Mdot
.31977 .43702 Mdot
.46244 .30028 Mdot
.70919 .41257 Mdot
.25248 .47783 Mdot
.20401 .4876 Mdot
.53302 .5766 Mdot
.52906 .58065 Mdot
.31378 .53448 Mdot
.66488 .73646 Mdot
.54089 .6309 Mdot
.28016 .45705 Mdot
.27771 .48954 Mdot
.51945 .59353 Mdot
.69889 .4311 Mdot
.34123 .64464 Mdot
.30882 .61543 Mdot
.58047 .6597 Mdot
.51151 .4455 Mdot
.40053 .65423 Mdot
.52593 .64406 Mdot
.48396 .6389 Mdot
.2833 .50382 Mdot
.53988 .38581 Mdot
.53617 .46056 Mdot
.33118 .63616 Mdot
.56431 .58837 Mdot
.82725 .50873 Mdot
.69804 .45072 Mdot
.32661 .49699 Mdot
.45475 .30027 Mdot
.32614 .59211 Mdot
.3403 .47219 Mdot
.51978 .59321 Mdot
.52496 .63824 Mdot
.41089 .29875 Mdot
.72357 .43136 Mdot
.35647 .62413 Mdot
.2751 .46457 Mdot
.31889 .62302 Mdot
.66097 .46088 Mdot
.69195 .44128 Mdot
.55698 .6675 Mdot
.5703 .5487 Mdot
.29049 .44458 Mdot
.49369 .62668 Mdot
.29468 .45583 Mdot
.2336 .37753 Mdot
.45919 .30742 Mdot
.57196 .65323 Mdot
.68843 .39656 Mdot
.44149 .29672 Mdot
.5455 .61459 Mdot
.31137 .53365 Mdot
.53694 .64123 Mdot
.26642 .44873 Mdot
.53858 .80082 Mdot
.33735 .63599 Mdot
.59532 .68761 Mdot
.47879 .69218 Mdot
.529 .65382 Mdot
.28114 .49662 Mdot
.64889 .65102 Mdot
.43566 .3221 Mdot
.66041 .44819 Mdot
.1866 .60595 Mdot
.43168 .30612 Mdot
.57439 .60029 Mdot
.34789 .6146 Mdot
.64439 .45769 Mdot
.56284 .37404 Mdot
.51596 .43047 Mdot
.57414 .68161 Mdot
.61804 .58639 Mdot
.58552 .63727 Mdot
.25904 .29741 Mdot
.31594 .46993 Mdot
.67578 .43206 Mdot
.45845 .32686 Mdot
.44662 .3118 Mdot
.2997 .48144 Mdot
.71811 .36722 Mdot
.60231 .2997 Mdot
.3839 .87921 Mdot
.33875 .46358 Mdot
.36562 .63959 Mdot
.49409 .4912 Mdot
.29003 .46126 Mdot
.32497 .48067 Mdot
.31103 .51774 Mdot
.63029 .34675 Mdot
.64656 .44341 Mdot
.55405 .59597 Mdot
.65327 .41149 Mdot
.53674 .60461 Mdot
.33514 .69603 Mdot
.44366 .30199 Mdot
.65981 .45003 Mdot
.28643 .61433 Mdot
.54163 .70723 Mdot
.56219 .63044 Mdot
.31612 .68425 Mdot
.61877 .63286 Mdot
.44104 .70584 Mdot
.52339 .66184 Mdot
.30916 .47825 Mdot
.6852 .50764 Mdot
.51705 .67581 Mdot
.64506 .73473 Mdot
.43111 .29036 Mdot
.56885 .3802 Mdot
.61501 .62913 Mdot
.48813 .66257 Mdot
.64316 .45657 Mdot
.7089 .4501 Mdot
.35088 .64475 Mdot
.5096 .21749 Mdot
.42818 .29163 Mdot
.67001 .29097 Mdot
.57968 .57998 Mdot
.48164 .30899 Mdot
.52547 .80665 Mdot
.54858 .62125 Mdot
.40596 .41901 Mdot
.7975 .57608 Mdot
.53943 .63562 Mdot
.70703 .59193 Mdot
.4311 .31223 Mdot
.40762 .78697 Mdot
.50858 .65255 Mdot
.29566 .49444 Mdot
.65527 .4504 Mdot
.69943 .41971 Mdot
.36273 .61054 Mdot
.52813 .82897 Mdot
.42439 .23456 Mdot
.65875 .45423 Mdot
.57727 .63051 Mdot
.42244 .31076 Mdot
.564 .37298 Mdot
.56581 .69101 Mdot
.36724 .2382 Mdot
.69398 .45701 Mdot
.49413 .64491 Mdot
.65593 .33128 Mdot
.48062 .43325 Mdot
.72082 .27783 Mdot
.41249 .32354 Mdot
.32791 .63492 Mdot
.51746 .56792 Mdot
.25212 .35661 Mdot
.4975 .63987 Mdot
.33399 .69765 Mdot
.70685 .39458 Mdot
.32069 .61186 Mdot
.57238 .62567 Mdot
.53755 .62019 Mdot
.52056 .46293 Mdot
.36638 .606 Mdot
.53725 .61743 Mdot
.48498 .61646 Mdot
.65792 .46554 Mdot
.53759 .3694 Mdot
.69039 .46615 Mdot
.58311 .61426 Mdot
.53996 .79092 Mdot
.70491 .43556 Mdot
.65349 .24233 Mdot
.36769 .66024 Mdot
.44057 .32592 Mdot
.50815 .67044 Mdot
.5945 .59703 Mdot
.62236 .17975 Mdot
.55801 .36768 Mdot
.16902 .50843 Mdot
.27863 .43746 Mdot
.84787 .59129 Mdot
.32762 .44157 Mdot
.71842 .32656 Mdot
.40403 .50249 Mdot
.49518 .61146 Mdot
.54998 .72645 Mdot
.69959 .59115 Mdot
.48006 .3229 Mdot
.66899 .54464 Mdot
.57647 .57861 Mdot
.55369 .58432 Mdot
.28222 .46107 Mdot
.70957 .3587 Mdot
.50961 .52852 Mdot
.53323 .45897 Mdot
.35207 .6338 Mdot
.6685 .45748 Mdot
.56441 .64147 Mdot
.52657 .27276 Mdot
.26977 .45671 Mdot
.5687 .75566 Mdot
.56833 .61576 Mdot
.51864 .51683 Mdot
.67424 .36792 Mdot
.42038 .29983 Mdot
.26213 .46853 Mdot
.2661 .48046 Mdot
.53455 .60122 Mdot
.4531 .32036 Mdot
.52973 .634 Mdot
.48398 .46979 Mdot
.56408 .6864 Mdot
.32346 .61769 Mdot
.59238 .6092 Mdot
.5096 .72553 Mdot
.77275 .35129 Mdot
.50899 .68937 Mdot
.63904 .45064 Mdot
.31578 .46283 Mdot
.29698 .47334 Mdot
.65391 .46566 Mdot
.29637 .47368 Mdot
.72991 .55631 Mdot
.64927 .55152 Mdot
.3244 .61324 Mdot
.69264 .65248 Mdot
.34174 .63572 Mdot
.56959 .38267 Mdot
.55102 .61459 Mdot
.31921 .33176 Mdot
.34029 .46641 Mdot
.3836 .77849 Mdot
.43988 .30504 Mdot
.55438 .36641 Mdot
.53752 .58074 Mdot
.32234 .58326 Mdot
.28583 .47799 Mdot
.41443 .38234 Mdot
.53464 .59287 Mdot
.66494 .41876 Mdot
.53784 .63244 Mdot
.6021 .57632 Mdot
.54692 .36507 Mdot
.58169 .64176 Mdot
.41724 .30041 Mdot
.70215 .45202 Mdot
.70442 .32208 Mdot
.32959 .47604 Mdot
.57461 .58282 Mdot
.5764 .63012 Mdot
.70628 .46169 Mdot
.54835 .57214 Mdot
.44388 .33129 Mdot
.56838 .90422 Mdot
.33331 .59983 Mdot
.54031 .38776 Mdot
.5345 .18775 Mdot
.55368 .64789 Mdot
.53212 .64743 Mdot
.46629 .38943 Mdot
.8244 .51556 Mdot
.42366 .31952 Mdot
.61623 .6176 Mdot
.27001 .47061 Mdot
.35799 .62275 Mdot
.40298 .30601 Mdot
.50556 .60891 Mdot
.55017 .58719 Mdot
.3254 .60808 Mdot
.32746 .68781 Mdot
.29916 .61803 Mdot
.43643 .33236 Mdot
.64306 .55716 Mdot
.24988 .52386 Mdot
.55562 .60658 Mdot
.56848 .40516 Mdot
.67803 .43911 Mdot
.4196 .3214 Mdot
.8117 .50639 Mdot
.59927 .64548 Mdot
.45039 .28521 Mdot
.42411 .29508 Mdot
.55271 .5707 Mdot
.70807 .40095 Mdot
.67404 .40395 Mdot
.67947 .43769 Mdot
.42488 .78215 Mdot
.18241 .44497 Mdot
.31921 .46845 Mdot
.42611 .30853 Mdot
.28883 .43745 Mdot
.3117 .62694 Mdot
.50548 .47416 Mdot
.2659 .4754 Mdot
.65113 .42493 Mdot
.29492 .43937 Mdot
.53113 .63774 Mdot
.44367 .28965 Mdot
.30362 .44363 Mdot
.52188 .64858 Mdot
.48142 .62948 Mdot
.54508 .72252 Mdot
.34173 .64548 Mdot
.4938 .43721 Mdot
.57854 .60523 Mdot
.55034 .39194 Mdot
.55864 .61942 Mdot
.44888 .32893 Mdot
.37971 .53867 Mdot
.50648 .62222 Mdot
.33978 .46451 Mdot
.19535 .4507 Mdot
.29228 .50274 Mdot
.58005 .56492 Mdot
.58211 .61231 Mdot
.55285 .60568 Mdot
.549 .57883 Mdot
.73198 .37939 Mdot
.42886 .26979 Mdot
.54162 .54376 Mdot
.33641 .46916 Mdot
.68395 .4559 Mdot
.70266 .42821 Mdot
.4567 .40165 Mdot
.55934 .36592 Mdot
.45373 .31488 Mdot
.55197 .60376 Mdot
.41515 .38405 Mdot
.5175 .418 Mdot
.6481 .33057 Mdot
.24786 .47519 Mdot
.28504 .45082 Mdot
.63869 .44042 Mdot
.30644 .44923 Mdot
.50843 .60389 Mdot
.4914 .63091 Mdot
.70353 .31788 Mdot
.39472 .31326 Mdot
.35656 .62593 Mdot
.58517 .60039 Mdot
.37191 .69313 Mdot
.27274 .47008 Mdot
.27843 .49903 Mdot
.52775 .6314 Mdot
.72043 .4374 Mdot
.7848 .33031 Mdot
.45436 .30624 Mdot
.66949 .58711 Mdot
.70321 .49251 Mdot
.61875 .54059 Mdot
.43892 .31786 Mdot
.41236 .43075 Mdot
.30988 .51331 Mdot
.58855 .8001 Mdot
.68725 .44997 Mdot
.3547 .62649 Mdot
.51796 .66335 Mdot
.65064 .42541 Mdot
.30249 .4371 Mdot
.6571 .47934 Mdot
.57105 .67146 Mdot
.42341 .33917 Mdot
.29298 .4674 Mdot
.46648 .28498 Mdot
.66584 .48703 Mdot
.34069 .63609 Mdot
.39317 .76961 Mdot
.67233 .60993 Mdot
.79748 .57505 Mdot
.51077 .61153 Mdot
.35124 .34235 Mdot
.52435 .59649 Mdot
.65397 .41714 Mdot
.57533 .61129 Mdot
.55531 .70951 Mdot
.32148 .51342 Mdot
.51853 .66939 Mdot
.59234 .6046 Mdot
.64008 .73316 Mdot
.55301 .62795 Mdot
.53223 .58553 Mdot
.57891 .65462 Mdot
.72761 .43595 Mdot
.52345 .67114 Mdot
.66403 .41963 Mdot
.64968 .34966 Mdot
.32482 .48271 Mdot
.31152 .62342 Mdot
.31421 .60998 Mdot
.32241 .69636 Mdot
.37115 .69759 Mdot
.70714 .36318 Mdot
.68087 .46783 Mdot
.42635 .28596 Mdot
.52874 .63484 Mdot
.78536 .64254 Mdot
.51513 .78067 Mdot
.32424 .51036 Mdot
.29267 .44186 Mdot
.50571 .65345 Mdot
.34213 .21314 Mdot
.51731 .66683 Mdot
.53455 .43052 Mdot
.53795 .60127 Mdot
.58106 .64886 Mdot
.2675 .48771 Mdot
.37275 .73152 Mdot
.51 .61243 Mdot
.64349 .458 Mdot
.34806 .6295 Mdot
.59957 .52607 Mdot
.49701 .78571 Mdot
.60878 .73323 Mdot
.46032 .60928 Mdot
.50321 .62811 Mdot
.27592 .47463 Mdot
.64449 .4486 Mdot
.54014 .4441 Mdot
.44244 .33023 Mdot
.51164 .43693 Mdot
.67189 .65259 Mdot
.39506 .24539 Mdot
.35376 .62923 Mdot
.34147 .52172 Mdot
.56739 .64291 Mdot
.32532 .47177 Mdot
.60878 .63335 Mdot
.50781 .40332 Mdot
.32156 .61913 Mdot
.6393 .46994 Mdot
.41577 .31181 Mdot
.66519 .41641 Mdot
.76915 .65052 Mdot
.52294 .78329 Mdot
.84786 .59348 Mdot
.30989 .50429 Mdot
.77731 .469 Mdot
.66278 .43414 Mdot
.53102 .59517 Mdot
.37798 .87519 Mdot
.67368 .44227 Mdot
.65984 .4201 Mdot
.45648 .4144 Mdot
.3977 .75961 Mdot
.50415 .65904 Mdot
.6586 .47709 Mdot
.31499 .52287 Mdot
.33662 .61289 Mdot
.51988 .64563 Mdot
.58869 .65585 Mdot
.70847 .44947 Mdot
.28933 .48041 Mdot
.35231 .70232 Mdot
.30537 .47417 Mdot
.64815 .44056 Mdot
.30897 .49164 Mdot
.65076 .24698 Mdot
.26631 .46541 Mdot
.59425 .60737 Mdot
.55294 .60394 Mdot
.33741 .28028 Mdot
.69196 .44132 Mdot
.53255 .64851 Mdot
.55806 .58784 Mdot
.66041 .43164 Mdot
.32905 .43925 Mdot
.8015 .49228 Mdot
.53684 .65259 Mdot
.55211 .59899 Mdot
.324 .60296 Mdot
.49418 .45539 Mdot
.52533 .41274 Mdot
.52459 .64754 Mdot
.35928 .6399 Mdot
.6365 .45078 Mdot
.55798 .62099 Mdot
.37094 .73092 Mdot
.32773 .44424 Mdot
.50608 .64045 Mdot
.56668 .38027 Mdot
.54119 .62656 Mdot
.77989 .32999 Mdot
.56297 .57986 Mdot
.67151 .42827 Mdot
.65668 .4428 Mdot
.34631 .52905 Mdot
.67923 .45487 Mdot
.54392 .36979 Mdot
.43737 .29463 Mdot
.76101 .36183 Mdot
.54629 .36835 Mdot
.59483 .63379 Mdot
.5662 .82188 Mdot
.58041 .66249 Mdot
.55767 .686 Mdot
.37226 .77546 Mdot
.54083 .38016 Mdot
.66973 .43645 Mdot
.55545 .28493 Mdot
.49578 .62167 Mdot
.4548 .31126 Mdot
.54648 .69019 Mdot
.50565 .63999 Mdot
.5528 .71615 Mdot
.6424 .54481 Mdot
.42519 .27604 Mdot
.47673 .66733 Mdot
.5199 .64523 Mdot
.8233 .51766 Mdot
.57611 .63657 Mdot
.35211 .60319 Mdot
.67153 .47264 Mdot
.31578 .45291 Mdot
.32774 .6141 Mdot
.56072 .64553 Mdot
.35194 .62204 Mdot
.32318 .47248 Mdot
.40743 .31205 Mdot
.59308 .61407 Mdot
.38401 .62941 Mdot
.35756 .6286 Mdot
.52133 .61687 Mdot
.65774 .45159 Mdot
.59183 .55121 Mdot
.55608 .62212 Mdot
.52728 .58598 Mdot
.65576 .46692 Mdot
.35237 .81304 Mdot
.54239 .58372 Mdot
.41048 .42777 Mdot
.63544 .48044 Mdot
.54011 .3686 Mdot
.29136 .45171 Mdot
.51005 .58322 Mdot
.44827 .31123 Mdot
.43871 .29811 Mdot
.33927 .48998 Mdot
.70278 .46123 Mdot
.29219 .47024 Mdot
.52794 .70429 Mdot
.49174 .63413 Mdot
.517 .66252 Mdot
.18575 .60446 Mdot
.60549 .21637 Mdot
.68594 .42921 Mdot
.29743 .50802 Mdot
.51757 .44539 Mdot
.45027 .29918 Mdot
.28907 .50957 Mdot
.6388 .42483 Mdot
.68803 .47483 Mdot
.65309 .46704 Mdot
.36135 .63541 Mdot
.29866 .46537 Mdot
.6271 .44149 Mdot
.68224 .40365 Mdot
.52341 .62482 Mdot
.51757 .64314 Mdot
.69121 .48615 Mdot
.36117 .4736 Mdot
.32887 .62851 Mdot
.27822 .48323 Mdot
.73043 .23701 Mdot
.45468 .30659 Mdot
.63978 .7343 Mdot
.52412 .64971 Mdot
.16349 .68745 Mdot
.52108 .66836 Mdot
.57728 .6323 Mdot
.65473 .48265 Mdot
.34278 .59068 Mdot
.33924 .61531 Mdot
.6616 .43491 Mdot
.71141 .41941 Mdot
.36442 .62271 Mdot
.4395 .41733 Mdot
.79696 .38681 Mdot
.532 .44284 Mdot
.67218 .42548 Mdot
.67592 .60966 Mdot
.40401 .30637 Mdot
.6326 .4688 Mdot
.44841 .27325 Mdot
.32607 .48304 Mdot
.27819 .44992 Mdot
.41122 .29556 Mdot
.53588 .58508 Mdot
.30718 .50166 Mdot
.52127 .70121 Mdot
.69761 .29863 Mdot
.38634 .23688 Mdot
.79617 .65201 Mdot
.58709 .58393 Mdot
.49199 .54175 Mdot
.59932 .35273 Mdot
.57484 .64565 Mdot
.46883 .66308 Mdot
.35529 .62398 Mdot
.63572 .47745 Mdot
.4026 .2948 Mdot
.66824 .2328 Mdot
.55446 .60591 Mdot
.65423 .42992 Mdot
.44785 .29292 Mdot
.64441 .24953 Mdot
.41609 .46262 Mdot
.53207 .62254 Mdot
.43405 .90161 Mdot
.66863 .48595 Mdot
.31569 .45306 Mdot
.67722 .70092 Mdot
.63779 .43337 Mdot
.22452 .49658 Mdot
.25938 .45595 Mdot
.56807 .46608 Mdot
.66901 .48243 Mdot
.30105 .61909 Mdot
.66576 .46187 Mdot
.37325 .62396 Mdot
.71112 .41407 Mdot
.29908 .4866 Mdot
.56574 .62622 Mdot
.30203 .4853 Mdot
.34057 .59539 Mdot
.32418 .50264 Mdot
.4028 .29443 Mdot
.54272 .38723 Mdot
.4387 .2909 Mdot
.50156 .47909 Mdot
.78552 .51951 Mdot
.42009 .32733 Mdot
.4036 .389 Mdot
.54465 .63449 Mdot
.72461 .43586 Mdot
.32304 .45823 Mdot
.34551 .48725 Mdot
.50068 .44027 Mdot
.64927 .45173 Mdot
.29554 .48857 Mdot
.67051 .61878 Mdot
.1885 .67097 Mdot
.51093 .67906 Mdot
.1858 .42664 Mdot
.66293 .42945 Mdot
.31287 .51538 Mdot
.53999 .43461 Mdot
.70753 .42966 Mdot
.29638 .4436 Mdot
.41367 .31202 Mdot
.44609 .31589 Mdot
.55309 .57194 Mdot
.43619 .3448 Mdot
.27849 .49493 Mdot
.82707 .51168 Mdot
.66522 .47242 Mdot
.58339 .20418 Mdot
.35112 .60546 Mdot
.32549 .47843 Mdot
.51148 .66521 Mdot
.67239 .39607 Mdot
.31323 .44384 Mdot
.36754 .22026 Mdot
.67858 .20315 Mdot
.29529 .48898 Mdot
.67283 .47261 Mdot
.68506 .45926 Mdot
.51245 .69049 Mdot
.52112 .45192 Mdot
.28824 .48231 Mdot
.31786 .33074 Mdot
.381 .67791 Mdot
.55457 .37156 Mdot
.62761 .77638 Mdot
.50984 .61178 Mdot
.5032 .63004 Mdot
.44055 .33257 Mdot
.55997 .63233 Mdot
.69995 .4097 Mdot
.52213 .66695 Mdot
.44728 .33766 Mdot
.33272 .49989 Mdot
.55269 .61168 Mdot
.35862 .61859 Mdot
.4201 .3336 Mdot
.46569 .32154 Mdot
.31734 .49051 Mdot
.66395 .47509 Mdot
.53996 .29523 Mdot
.30381 .47261 Mdot
.50533 .61126 Mdot
.54707 .38418 Mdot
.52759 .66224 Mdot
.33938 .28855 Mdot
.68254 .41469 Mdot
.30719 .44963 Mdot
.67065 .4913 Mdot
.42544 .30339 Mdot
.33664 .50633 Mdot
.57528 .64109 Mdot
.28297 .44967 Mdot
.40064 .43158 Mdot
.2222 .56558 Mdot
.6954 .40626 Mdot
.3554 .54047 Mdot
.70868 .45378 Mdot
.55574 .37152 Mdot
.42441 .73698 Mdot
.33492 .62942 Mdot
.27647 .48581 Mdot
.6494 .23822 Mdot
.32788 .46189 Mdot
.55011 .62675 Mdot
.54486 .5868 Mdot
.28345 .45952 Mdot
.34924 .63849 Mdot
.32302 .71482 Mdot
.39191 .6399 Mdot
.6996 .45102 Mdot
.41736 .50587 Mdot
.76275 .27379 Mdot
.24891 .45256 Mdot
.42237 .28752 Mdot
.46916 .60439 Mdot
.54265 .64176 Mdot
.43733 .28071 Mdot
.45937 .31571 Mdot
.34804 .59627 Mdot
.3282 .47653 Mdot
.6273 .4668 Mdot
.40696 .29224 Mdot
.64621 .40723 Mdot
.35711 .71343 Mdot
.61874 .61174 Mdot
.63434 .57333 Mdot
.59996 .61123 Mdot
.4811 .43302 Mdot
.43867 .33868 Mdot
.57129 .60168 Mdot
.48634 .6034 Mdot
.42472 .32408 Mdot
.35604 .601 Mdot
.61258 .45587 Mdot
.30126 .49413 Mdot
.17403 .6751 Mdot
.59296 .61265 Mdot
.56159 .62495 Mdot
.44267 .32837 Mdot
.67607 .73072 Mdot
.68328 .42554 Mdot
.66693 .47596 Mdot
.31575 .46913 Mdot
.49375 .39623 Mdot
.54482 .57246 Mdot
.58797 .62885 Mdot
.30263 .49887 Mdot
.55042 .39123 Mdot
.73551 .73332 Mdot
.558 .59859 Mdot
.4335 .31526 Mdot
.38692 .39689 Mdot
.43132 .33865 Mdot
.60957 .60708 Mdot
.54677 .62337 Mdot
.59456 .62584 Mdot
.57951 .57446 Mdot
.41286 .28925 Mdot
.58145 .63965 Mdot
.61669 .57775 Mdot
.67386 .43683 Mdot
.50456 .62132 Mdot
.38358 .67747 Mdot
.55898 .60284 Mdot
.35753 .61777 Mdot
.51379 .39419 Mdot
.57213 .58292 Mdot
.50398 .62169 Mdot
.37877 .67669 Mdot
.576 .62475 Mdot
.44389 .28707 Mdot
.6884 .45286 Mdot
.42399 .30454 Mdot
.42471 .28952 Mdot
.30382 .44073 Mdot
.37528 .62221 Mdot
.48978 .60991 Mdot
.36604 .62647 Mdot
.52793 .70026 Mdot
.594 .65303 Mdot
.49993 .46729 Mdot
.53323 .43009 Mdot
.31462 .6338 Mdot
.58225 .63556 Mdot
.31869 .4743 Mdot
.30186 .44812 Mdot
.3769 .53556 Mdot
.55225 .6938 Mdot
.40328 .29936 Mdot
.41001 .309 Mdot
.40718 .61546 Mdot
.39429 .57958 Mdot
.36014 .62667 Mdot
.47751 .52168 Mdot
.60218 .63469 Mdot
.56193 .58402 Mdot
.57499 .67481 Mdot
.27626 .4402 Mdot
.54225 .38836 Mdot
.33444 .49295 Mdot
.53382 .40562 Mdot
.40321 .31755 Mdot
.58724 .58432 Mdot
.40829 .21212 Mdot
.70351 .43975 Mdot
.68928 .45213 Mdot
.45069 .33685 Mdot
.29015 .50182 Mdot
.56199 .68802 Mdot
.14856 .5303 Mdot
.70344 .41877 Mdot
.31398 .62572 Mdot
.58623 .61252 Mdot
.32095 .48635 Mdot
.70214 .4558 Mdot
.37742 .63914 Mdot
.59363 .59206 Mdot
.25883 .47842 Mdot
.56876 .60755 Mdot
.71178 .61387 Mdot
.66538 .44132 Mdot
.5546 .48158 Mdot
.71628 .46322 Mdot
.42598 .28401 Mdot
.42035 .31408 Mdot
.5456 .61618 Mdot
.1536 .59739 Mdot
.62347 .49284 Mdot
.44404 .27989 Mdot
.37273 .64091 Mdot
.54554 .39259 Mdot
.37538 .63859 Mdot
.29319 .45641 Mdot
.34931 .63036 Mdot
.31602 .44563 Mdot
.35745 .45917 Mdot
.63505 .49339 Mdot
.32874 .60645 Mdot
.67603 .73722 Mdot
.49122 .62993 Mdot
.34032 .59365 Mdot
.51132 .65781 Mdot
.54329 .71109 Mdot
.3134 .49994 Mdot
.36065 .63342 Mdot
.52797 .60966 Mdot
.53419 .1829 Mdot
.41799 .30102 Mdot
.40351 .29487 Mdot
.49198 .62821 Mdot
.30924 .51634 Mdot
.70548 .41059 Mdot
.46289 .4481 Mdot
.53718 .37553 Mdot
.58796 .62793 Mdot
.60258 .60604 Mdot
.67576 .48718 Mdot
.64496 .43262 Mdot
.54451 .61731 Mdot
.66422 .59172 Mdot
.56622 .64421 Mdot
.44436 .31885 Mdot
.70112 .4477 Mdot
.68844 .45619 Mdot
.27109 .48491 Mdot
.70396 .4587 Mdot
.57097 .54206 Mdot
.45312 .35248 Mdot
.54731 .67623 Mdot
.42814 .30415 Mdot
.37299 .49079 Mdot
.33229 .48311 Mdot
.64607 .23335 Mdot
.70048 .4628 Mdot
.5372 .65608 Mdot
.7019 .42847 Mdot
.34132 .60211 Mdot
.69337 .44338 Mdot
.70399 .47307 Mdot
.56792 .57573 Mdot
.53525 .61164 Mdot
.55072 .38882 Mdot
.5131 .44816 Mdot
.66436 .44755 Mdot
.5535 .65155 Mdot
.53551 .66144 Mdot
.53858 .58897 Mdot
.48434 .45955 Mdot
.64868 .47891 Mdot
.62837 .72785 Mdot
.35811 .27127 Mdot
.66075 .45238 Mdot
.72421 .25965 Mdot
.56262 .39371 Mdot
.56113 .36688 Mdot
.46444 .29628 Mdot
.55353 .59671 Mdot
.29434 .4748 Mdot
.50289 .63275 Mdot
.54576 .69731 Mdot
.5772 .58509 Mdot
.3241 .60802 Mdot
.53009 .5781 Mdot
.56235 .38163 Mdot
.3057 .47806 Mdot
.5502 .65049 Mdot
.54916 .60582 Mdot
.56734 .37418 Mdot
.70528 .47615 Mdot
.68935 .47348 Mdot
.58779 .39958 Mdot
.35253 .60026 Mdot
.42987 .33415 Mdot
.50142 .62127 Mdot
.31682 .47177 Mdot
.30013 .48045 Mdot
.66342 .41757 Mdot
.29173 .49221 Mdot
.43421 .33611 Mdot
.57235 .63701 Mdot
.42403 .28438 Mdot
.32437 .60773 Mdot
.67083 .47262 Mdot
.50415 .61046 Mdot
.52434 .62197 Mdot
.65688 .44265 Mdot
.54192 .63224 Mdot
.32127 .60812 Mdot
.27166 .44713 Mdot
.69456 .43706 Mdot
.43707 .29549 Mdot
.26752 .47932 Mdot
.52849 .63834 Mdot
.56124 .14176 Mdot
.55938 .63306 Mdot
.59194 .62358 Mdot
.74033 .34884 Mdot
.55541 .66326 Mdot
.33007 .47066 Mdot
.70596 .43339 Mdot
.6052 .5962 Mdot
.37662 .68065 Mdot
.29227 .64344 Mdot
.25315 .4536 Mdot
.58768 .61393 Mdot
.70675 .26024 Mdot
.5315 .6552 Mdot
.67073 .25799 Mdot
.50095 .46726 Mdot
.27263 .29223 Mdot
.63479 .57642 Mdot
.44554 .28065 Mdot
.54842 .38989 Mdot
.33309 .47252 Mdot
.72768 .67484 Mdot
.55012 .6336 Mdot
.80624 .56634 Mdot
.50026 .61965 Mdot
.44073 .31758 Mdot
.46793 .63742 Mdot
.28089 .48606 Mdot
.61956 .77474 Mdot
.52313 .59356 Mdot
.66009 .48319 Mdot
.33707 .51029 Mdot
.55311 .39537 Mdot
.53008 .60519 Mdot
.36129 .61364 Mdot
.30901 .64765 Mdot
.56949 .54343 Mdot
.42839 .30156 Mdot
.56186 .58689 Mdot
.47971 .65454 Mdot
.19512 .6658 Mdot
.67845 .43497 Mdot
.41585 .29693 Mdot
.43306 .5886 Mdot
.54205 .58856 Mdot
.68582 .47578 Mdot
.68612 .45198 Mdot
.36854 .6195 Mdot
.50084 .35207 Mdot
.27771 .6407 Mdot
.42956 .18428 Mdot
.79579 .60505 Mdot
.27152 .44309 Mdot
.66078 .38586 Mdot
.50911 .62705 Mdot
.52654 .78498 Mdot
.42906 .28829 Mdot
.56486 .62486 Mdot
.78041 .59737 Mdot
.68423 .43737 Mdot
.56638 .60261 Mdot
.32766 .6266 Mdot
.56457 .32346 Mdot
.65861 .65279 Mdot
.59408 .16638 Mdot
.30765 .52098 Mdot
.52885 .6824 Mdot
.59267 .54315 Mdot
.53982 .36953 Mdot
.60823 .60498 Mdot
.32529 .46234 Mdot
.35786 .3491 Mdot
.33263 .63554 Mdot
.70382 .44264 Mdot
.56008 .39534 Mdot
.49883 .62454 Mdot
.57546 .66037 Mdot
.31738 .63043 Mdot
.52679 .60001 Mdot
.6711 .6995 Mdot
.57249 .37803 Mdot
.2665 .46345 Mdot
.65545 .47805 Mdot
.60087 .61254 Mdot
.54625 .39147 Mdot
.56197 .57595 Mdot
.48162 .7016 Mdot
.58504 .60603 Mdot
.7545 .37201 Mdot
.65517 .45167 Mdot
.42946 .2962 Mdot
.52607 .5793 Mdot
.56233 .61052 Mdot
.25512 .52866 Mdot
.55792 .69107 Mdot
.55936 .58061 Mdot
.65424 .41963 Mdot
.7035 .43554 Mdot
.65116 .43063 Mdot
.26793 .47613 Mdot
.53459 .4488 Mdot
.44083 .3097 Mdot
.57206 .67889 Mdot
.40467 .29851 Mdot
.63632 .60433 Mdot
.33904 .64131 Mdot
.62466 .21284 Mdot
.55966 .64029 Mdot
.64911 .45893 Mdot
.79743 .43699 Mdot
.63643 .44729 Mdot
.4014 .25665 Mdot
.42956 .29076 Mdot
.67117 .44461 Mdot
.57981 .62331 Mdot
.53228 .46059 Mdot
.54747 .14974 Mdot
.44871 .29728 Mdot
.55367 .68518 Mdot
.30738 .52174 Mdot
.34347 .47846 Mdot
.75678 .30121 Mdot
.43675 .28404 Mdot
.59564 .35134 Mdot
.5386 .65406 Mdot
.70609 .44477 Mdot
.41794 .32827 Mdot
.44962 .28926 Mdot
.29584 .49594 Mdot
.53002 .62511 Mdot
.56362 .60888 Mdot
.56765 .3834 Mdot
.40612 .30471 Mdot
.61177 .66108 Mdot
.53453 .62488 Mdot
.71329 .32413 Mdot
.63577 .4293 Mdot
.36158 .81892 Mdot
.50466 .69828 Mdot
.78529 .58895 Mdot
.38741 .47638 Mdot
.69344 .43281 Mdot
.52963 .58771 Mdot
.56739 .68237 Mdot
.26492 .45255 Mdot
.56852 .63625 Mdot
.30998 .51056 Mdot
.43194 .28318 Mdot
.63331 .2133 Mdot
.42086 .39263 Mdot
.45454 .35632 Mdot
.55685 .6304 Mdot
.65756 .64687 Mdot
.3319 .6068 Mdot
.39435 .30217 Mdot
.66793 .42205 Mdot
.6016 .62947 Mdot
.27354 .43914 Mdot
.26867 .47499 Mdot
.68404 .446 Mdot
.63645 .36594 Mdot
.65524 .24257 Mdot
.58552 .57854 Mdot
.29241 .45333 Mdot
.41819 .36862 Mdot
.67102 .53356 Mdot
.46693 .307 Mdot
.32807 .6332 Mdot
.33179 .47539 Mdot
.41732 .34061 Mdot
.54665 .71101 Mdot
.67526 .45037 Mdot
.67678 .48534 Mdot
.24833 .50806 Mdot
.29301 .48422 Mdot
.33262 .61969 Mdot
.39274 .52375 Mdot
.39687 .52439 Mdot
.32228 .62098 Mdot
.32398 .51074 Mdot
.69792 .43307 Mdot
.65161 .43344 Mdot
.6871 .45422 Mdot
.64527 .73477 Mdot
.69307 .41723 Mdot
.44323 .81741 Mdot
.60673 .61883 Mdot
.67204 .57925 Mdot
.56416 .65193 Mdot
.41305 .28306 Mdot
.66382 .44207 Mdot
.50971 .46926 Mdot
.58958 .64597 Mdot
.57257 .16077 Mdot
.58008 .60575 Mdot
.39872 .41165 Mdot
.55232 .59719 Mdot
.68851 .66864 Mdot
.63452 .47814 Mdot
.5797 .63893 Mdot
.46717 .34252 Mdot
.35447 .61958 Mdot
.64174 .50009 Mdot
.56052 .58164 Mdot
.66141 .33382 Mdot
.51173 .65768 Mdot
.69929 .2745 Mdot
.20806 .49618 Mdot
.31202 .60593 Mdot
.54073 .66713 Mdot
.32384 .44729 Mdot
.4646 .59252 Mdot
.67882 .5949 Mdot
.44793 .29638 Mdot
.66223 .63571 Mdot
.28989 .49484 Mdot
.4706 .66594 Mdot
.61389 .58892 Mdot
.34215 .63887 Mdot
.61327 .47726 Mdot
.44279 .32171 Mdot
.54917 .63527 Mdot
.53101 .58839 Mdot
.33938 .24957 Mdot
.68207 .61128 Mdot
.6251 .61283 Mdot
.33012 .6402 Mdot
.66483 .64971 Mdot
.57406 .58575 Mdot
.25333 .45475 Mdot
.70862 .43503 Mdot
.49682 .5731 Mdot
.61712 .74838 Mdot
.55753 .6496 Mdot
.6753 .44359 Mdot
.69974 .46475 Mdot
.8147 .44749 Mdot
.3455 .642 Mdot
.58439 .60515 Mdot
.23622 .50074 Mdot
.50519 .61067 Mdot
.44301 .31332 Mdot
.61193 .61829 Mdot
.32675 .49046 Mdot
.54706 .43328 Mdot
.26901 .47847 Mdot
.53476 .59764 Mdot
.66702 .46578 Mdot
.44127 .32659 Mdot
.24856 .34806 Mdot
.48699 .36363 Mdot
.43882 .81549 Mdot
.31268 .65105 Mdot
.36197 .62085 Mdot
.37762 .63306 Mdot
.38738 .31246 Mdot
.58534 .61885 Mdot
.47356 .43088 Mdot
.52631 .69289 Mdot
.54999 .59267 Mdot
.58634 .5996 Mdot
.46726 .36858 Mdot
.42978 .29178 Mdot
.30511 .49013 Mdot
.54444 .6189 Mdot
.55452 .6516 Mdot
.66468 .45524 Mdot
.35774 .62901 Mdot
.2713 .45022 Mdot
.34673 .59899 Mdot
.3106 .47752 Mdot
.77788 .32273 Mdot
.61004 .63486 Mdot
.35308 .61797 Mdot
.42511 .33831 Mdot
.64556 .44315 Mdot
.56377 .37103 Mdot
.29295 .45755 Mdot
.28144 .48531 Mdot
.5801 .64129 Mdot
.67873 .47382 Mdot
.68284 .47522 Mdot
.36405 .62295 Mdot
.41105 .31406 Mdot
.57237 .56725 Mdot
.53511 .61691 Mdot
.22735 .37358 Mdot
.26354 .45675 Mdot
.66865 .63473 Mdot
.75293 .38312 Mdot
.58578 .62166 Mdot
.67879 .47827 Mdot
.55593 .61501 Mdot
.38031 .33183 Mdot
.64637 .43361 Mdot
.56313 .65825 Mdot
.57572 .70588 Mdot
.27677 .4405 Mdot
.84409 .51474 Mdot
.495 .60342 Mdot
.47552 .28862 Mdot
.51494 .61865 Mdot
.86773 .55179 Mdot
.80076 .44924 Mdot
.49981 .6177 Mdot
.57679 .57387 Mdot
.43715 .17275 Mdot
.5247 .65254 Mdot
.56532 .38436 Mdot
.54822 .69733 Mdot
.6841 .47715 Mdot
.40972 .45578 Mdot
.4903 .43587 Mdot
.36491 .64076 Mdot
.31666 .4692 Mdot
.38687 .74578 Mdot
.3676 .61236 Mdot
.6688 .42832 Mdot
.58172 .65727 Mdot
.75396 .40905 Mdot
.34442 .46042 Mdot
.60004 .57722 Mdot
.44257 .31497 Mdot
.49066 .43489 Mdot
.33441 .48909 Mdot
.43665 .29381 Mdot
.5341 .65822 Mdot
.17916 .54073 Mdot
.45022 .25659 Mdot
.8233 .44448 Mdot
.4378 .33184 Mdot
.42089 .29995 Mdot
.54212 .46158 Mdot
.36545 .64042 Mdot
.31766 .28605 Mdot
.56767 .53169 Mdot
.45342 .30408 Mdot
.4563 .7203 Mdot
.26074 .47521 Mdot
.50443 .4037 Mdot
.63232 .47114 Mdot
.61035 .63594 Mdot
.57733 .61925 Mdot
.41882 .3222 Mdot
.70247 .38487 Mdot
.41359 .57714 Mdot
.44236 .29173 Mdot
.59096 .54487 Mdot
.50467 .39451 Mdot
.54447 .38473 Mdot
.56648 .39176 Mdot
.36866 .64329 Mdot
.24067 .61354 Mdot
.6537 .45669 Mdot
.31382 .61847 Mdot
.58216 .49319 Mdot
.57805 .59876 Mdot
.40576 .30159 Mdot
.57094 .38768 Mdot
.43824 .29986 Mdot
.34276 .61298 Mdot
.32725 .63635 Mdot
.67474 .43636 Mdot
.68451 .42496 Mdot
.68832 .51016 Mdot
.42351 .65108 Mdot
.50827 .63823 Mdot
.80479 .50558 Mdot
.64892 .42972 Mdot
.70469 .70326 Mdot
.36645 .63387 Mdot
.35013 .6349 Mdot
.70673 .55865 Mdot
.52486 .63212 Mdot
.39005 .4015 Mdot
.56983 .58243 Mdot
.44917 .73971 Mdot
.49782 .6311 Mdot
.29639 .49543 Mdot
.51538 .60266 Mdot
.53346 .28049 Mdot
.54428 .64885 Mdot
.58548 .59426 Mdot
.2956 .46193 Mdot
.54656 .56608 Mdot
.32428 .4953 Mdot
.54353 .58249 Mdot
.35105 .59262 Mdot
.31638 .4715 Mdot
.37631 .6067 Mdot
.4197 .4321 Mdot
.55626 .38873 Mdot
.37404 .63673 Mdot
.35934 .61278 Mdot
.34942 .6988 Mdot
.6801 .42062 Mdot
.51836 .7187 Mdot
.58419 .61554 Mdot
.28264 .50331 Mdot
.41419 .32909 Mdot
.56013 .64903 Mdot
.52377 .66901 Mdot
.49491 .60104 Mdot
.67446 .43942 Mdot
.3176 .51376 Mdot
.34795 .61896 Mdot
.29722 .44735 Mdot
.36976 .60436 Mdot
.33363 .46146 Mdot
.48393 .64187 Mdot
.53411 .70407 Mdot
.61384 .57166 Mdot
.79543 .55944 Mdot
.56926 .81443 Mdot
.67968 .44955 Mdot
.54918 .37885 Mdot
.34053 .64201 Mdot
.41516 .5106 Mdot
.65319 .46266 Mdot
.28166 .48347 Mdot
.56897 .60773 Mdot
.5991 .54697 Mdot
.60062 .53395 Mdot
.64474 .41232 Mdot
.39219 .60746 Mdot
.30728 .45985 Mdot
.54718 .37086 Mdot
.52854 .43788 Mdot
.7322 .45184 Mdot
.50542 .47649 Mdot
.55866 .61229 Mdot
.36455 .61953 Mdot
.70221 .45558 Mdot
.32743 .2996 Mdot
.41585 .31673 Mdot
.51741 .45005 Mdot
.55915 .63091 Mdot
.61512 .3828 Mdot
.66773 .46565 Mdot
.33813 .63494 Mdot
.4198 .32288 Mdot
.35797 .64134 Mdot
.5547 .39854 Mdot
.57404 .40689 Mdot
.52701 .60492 Mdot
.5616 .57974 Mdot
.40379 .31778 Mdot
.65504 .45883 Mdot
.29632 .60426 Mdot
.35097 .2433 Mdot
.28905 .4569 Mdot
.47793 .40175 Mdot
.70229 .45018 Mdot
.59465 .37184 Mdot
.2823 .45242 Mdot
.41386 .33664 Mdot
.47671 .43388 Mdot
.45416 .33391 Mdot
.5801 .59024 Mdot
.68594 .46488 Mdot
.43808 .28385 Mdot
.23571 .37571 Mdot
.74057 .31076 Mdot
.6165 .45713 Mdot
.54086 .62026 Mdot
.62468 .21094 Mdot
.62867 .32334 Mdot
.62027 .41481 Mdot
.40953 .28972 Mdot
.54972 .61979 Mdot
.58831 .58137 Mdot
.52181 .59479 Mdot
.41579 .30532 Mdot
.48752 .32665 Mdot
.27338 .47564 Mdot
.56983 .59901 Mdot
.34965 .60484 Mdot
.32233 .49257 Mdot
.33943 .46039 Mdot
.33193 .47008 Mdot
.64762 .43013 Mdot
.59695 .64658 Mdot
.55764 .50408 Mdot
.84968 .47495 Mdot
.42464 .29725 Mdot
.55651 .38849 Mdot
.59452 .61882 Mdot
.39842 .7874 Mdot
.64794 .43632 Mdot
.28666 .46121 Mdot
.56319 .62429 Mdot
.21781 .49973 Mdot
.57579 .38494 Mdot
.30148 .46727 Mdot
.66615 .42296 Mdot
.61853 .41694 Mdot
.56846 .63711 Mdot
.51467 .62192 Mdot
.6533 .43803 Mdot
.60288 .33141 Mdot
.52628 .43113 Mdot
.55451 .61257 Mdot
.43202 .2942 Mdot
.17097 .64838 Mdot
.54848 .66223 Mdot
.69782 .39361 Mdot
.54157 .38938 Mdot
.7314 .36599 Mdot
.66525 .6115 Mdot
.50878 .67257 Mdot
.5601 .17571 Mdot
.37148 .75893 Mdot
.65298 .2199 Mdot
.45176 .75525 Mdot
.39885 .23578 Mdot
.80249 .36654 Mdot
.46842 .33919 Mdot
.69284 .65546 Mdot
.34533 .21842 Mdot
.60873 .35196 Mdot
.20196 .53539 Mdot
.272 .34234 Mdot
.20342 .47084 Mdot
.6727 .76806 Mdot
.33576 .4617 Mdot
.48613 .76158 Mdot
.54044 .57911 Mdot
.60518 .32029 Mdot
.67301 .67056 Mdot
.52494 .83146 Mdot
.62574 .21714 Mdot
.23121 .50034 Mdot
.52694 .13624 Mdot
.63563 .23431 Mdot
.74604 .4673 Mdot
.57858 .75116 Mdot
.25879 .63572 Mdot
.39459 .52756 Mdot
.38836 .75377 Mdot
.6504 .64967 Mdot
.53306 .265 Mdot
.47399 .3347 Mdot
.76693 .49944 Mdot
.21833 .69602 Mdot
.3168 .45706 Mdot
.70937 .43573 Mdot
.30843 .28932 Mdot
.75829 .43477 Mdot
.40409 .24815 Mdot
.56016 .17554 Mdot
.72311 .32751 Mdot
.68764 .66617 Mdot
.56248 .48431 Mdot
.71742 .60101 Mdot
.30811 .71071 Mdot
.55845 .76559 Mdot
.68741 .39925 Mdot
.26661 .37362 Mdot
.39693 .52742 Mdot
.29528 .66968 Mdot
.69159 .68514 Mdot
.37839 .6402 Mdot
.38651 .62169 Mdot
.65987 .42503 Mdot
.6806 .52589 Mdot
.56163 .36513 Mdot
.58843 .49709 Mdot
.2739 .43735 Mdot
.38473 .34623 Mdot
.56908 .3192 Mdot
.63559 .34044 Mdot
.82973 .58565 Mdot
.60157 .15825 Mdot
.40169 .6958 Mdot
.34874 .32667 Mdot
.42099 .25179 Mdot
.37175 .74211 Mdot
.5364 .49893 Mdot
.42439 .68197 Mdot
.49871 .71713 Mdot
.45065 .13608 Mdot
.67429 .32927 Mdot
.51252 .1279 Mdot
.71765 .42156 Mdot
.5062 .57684 Mdot
.36029 .32892 Mdot
.78229 .62988 Mdot
.36339 .68017 Mdot
.60222 .16295 Mdot
.30803 .60825 Mdot
.63355 .48223 Mdot
.60889 .35401 Mdot
.66957 .69605 Mdot
.29803 .59235 Mdot
.36162 .6563 Mdot
.49679 .57421 Mdot
.44194 .12568 Mdot
.54606 .17223 Mdot
.79102 .41256 Mdot
.71063 .32615 Mdot
.25168 .4373 Mdot
.33548 .45396 Mdot
.4449 .28329 Mdot
.76177 .33238 Mdot
.67688 .46612 Mdot
.85377 .47992 Mdot
.74659 .32653 Mdot
.45711 .60533 Mdot
.42654 .13322 Mdot
.73276 .73013 Mdot
.66922 .58063 Mdot
.50967 .80466 Mdot
.18271 .47914 Mdot
.52714 .49512 Mdot
.57968 .35931 Mdot
.26366 .49297 Mdot
.75367 .36019 Mdot
.75016 .30552 Mdot
.46938 .72467 Mdot
.42966 .21003 Mdot
.59368 .50138 Mdot
.37431 .50869 Mdot
.62153 .47898 Mdot
.20128 .56078 Mdot
.41855 .6288 Mdot
.52368 .13118 Mdot
.66303 .65944 Mdot
.16445 .59415 Mdot
.43409 .748 Mdot
.67243 .73244 Mdot
.55246 .18814 Mdot
.28655 .4193 Mdot
.43579 .64166 Mdot
.66326 .34594 Mdot
.54454 .68345 Mdot
.4859 .51789 Mdot
.47779 .68606 Mdot
.32917 .56658 Mdot
.53994 .45081 Mdot
.65237 .286 Mdot
.41304 .73895 Mdot
.38673 .22924 Mdot
.58441 .74398 Mdot
.64452 .46878 Mdot
.41406 .67387 Mdot
.42576 .71893 Mdot
.69515 .31672 Mdot
.43414 .58873 Mdot
.79042 .39834 Mdot
.42716 .58098 Mdot
.52148 .68556 Mdot
.69653 .64823 Mdot
.6469 .65625 Mdot
.44036 .71072 Mdot
.49489 .60875 Mdot
.83394 .56248 Mdot
.72457 .34234 Mdot
.78391 .54878 Mdot
.39194 .72843 Mdot
.79266 .55455 Mdot
.76075 .36118 Mdot
.36008 .31826 Mdot
.56998 .35117 Mdot
.66129 .38868 Mdot
.44676 .12642 Mdot
.31247 .49428 Mdot
.45063 .70826 Mdot
.48057 .31271 Mdot
.23927 .36901 Mdot
.3239 .25259 Mdot
.41932 .57684 Mdot
.76853 .35773 Mdot
.62789 .35001 Mdot
.35399 .49362 Mdot
.51425 .24151 Mdot
.44859 .37502 Mdot
.79607 .51049 Mdot
.49118 .60046 Mdot
.45787 .66473 Mdot
.32006 .60932 Mdot
.74811 .65547 Mdot
.35245 .28457 Mdot
.30607 .55489 Mdot
.49501 .6543 Mdot
.27608 .52146 Mdot
.55397 .36996 Mdot
.4983 .4283 Mdot
.77565 .31437 Mdot
.48938 .67792 Mdot
.7141 .74217 Mdot
.62409 .33462 Mdot
.48029 .42825 Mdot
.32408 .68726 Mdot
.72261 .37926 Mdot
.49415 .1235 Mdot
.77329 .35274 Mdot
.62116 .3062 Mdot
.61636 .20451 Mdot
.76929 .72506 Mdot
.28812 .27185 Mdot
.77685 .65544 Mdot
.48066 .31411 Mdot
.5558 .90352 Mdot
.28934 .44828 Mdot
.54832 .79395 Mdot
.7793 .63103 Mdot
.23211 .51891 Mdot
.75893 .43189 Mdot
.6425 .68156 Mdot
.33365 .66973 Mdot
.70456 .47491 Mdot
.48712 .6315 Mdot
.64686 .19404 Mdot
.46146 .12885 Mdot
.63384 .18417 Mdot
.55963 .41317 Mdot
.66257 .21723 Mdot
.43197 .16253 Mdot
.44886 .81958 Mdot
.33151 .25981 Mdot
.61144 .61466 Mdot
.45715 .69995 Mdot
.75122 .70865 Mdot
.32011 .6445 Mdot
.57086 .50143 Mdot
.67734 .39866 Mdot
.42452 .15568 Mdot
.77585 .31224 Mdot
.7266 .55777 Mdot
.72123 .50147 Mdot
.39565 .44205 Mdot
.43315 .68218 Mdot
.76512 .42804 Mdot
.53909 .25135 Mdot
.7027 .30174 Mdot
.41812 .16983 Mdot
.42384 .72642 Mdot
.26995 .34926 Mdot
.61261 .29658 Mdot
.76459 .68545 Mdot
.55125 .18441 Mdot
.30272 .28956 Mdot
.44554 .61534 Mdot
.64824 .50767 Mdot
.41473 .57881 Mdot
.5268 .2568 Mdot
.37554 .37837 Mdot
.38346 .70773 Mdot
.32271 .50389 Mdot
.46407 .7171 Mdot
.45806 .48841 Mdot
.32959 .26102 Mdot
.36758 .72053 Mdot
.47981 .73195 Mdot
.6414 .29734 Mdot
.64855 .20035 Mdot
.62412 .33709 Mdot
.17162 .49441 Mdot
.58277 .2141 Mdot
.46825 .66834 Mdot
.53304 .56906 Mdot
.76412 .35843 Mdot
.71318 .23168 Mdot
.76933 .35664 Mdot
.62257 .38699 Mdot
.23103 .48423 Mdot
.43693 .34451 Mdot
.35956 .72784 Mdot
.31881 .54783 Mdot
.71112 .29924 Mdot
.43421 .50107 Mdot
.40949 .33828 Mdot
.5645 .32582 Mdot
.69741 .50506 Mdot
.38985 .77269 Mdot
.75439 .50604 Mdot
.6122 .64646 Mdot
.66838 .54549 Mdot
.68233 .48576 Mdot
.61696 .38724 Mdot
.43021 .68786 Mdot
.31736 .49123 Mdot
.21868 .3831 Mdot
.71511 .39341 Mdot
.48781 .6003 Mdot
.36004 .3581 Mdot
.61986 .47791 Mdot
.79473 .57663 Mdot
.34792 .50128 Mdot
.78941 .3477 Mdot
.82286 .59106 Mdot
.7661 .42577 Mdot
.40798 .68355 Mdot
.22707 .38585 Mdot
.50959 .42518 Mdot
.47193 .29172 Mdot
.62556 .22069 Mdot
.43425 .43393 Mdot
.4161 .68396 Mdot
.66268 .55458 Mdot
.35027 .25535 Mdot
.54063 .69361 Mdot
.79677 .42759 Mdot
.43432 .80881 Mdot
.49445 .41636 Mdot
.74526 .41685 Mdot
.69854 .41692 Mdot
.60301 .81698 Mdot
.54507 .27836 Mdot
.50483 .53697 Mdot
.58554 .19352 Mdot
.46099 .29993 Mdot
.64165 .45101 Mdot
.49158 .73505 Mdot
.22576 .56338 Mdot
.64696 .53404 Mdot
.38405 .37575 Mdot
.75036 .45571 Mdot
.42673 .41003 Mdot
.60425 .19748 Mdot
.52553 .15705 Mdot
.17416 .64291 Mdot
.71874 .43838 Mdot
.33343 .30728 Mdot
.32862 .31122 Mdot
.67221 .402 Mdot
.66387 .39944 Mdot
.65736 .65741 Mdot
.69953 .23873 Mdot
.41857 .49136 Mdot
.52847 .24046 Mdot
.47597 .43011 Mdot
.20606 .54589 Mdot
.33641 .27133 Mdot
.37865 .73478 Mdot
.50937 .1821 Mdot
.73451 .50542 Mdot
.18698 .39185 Mdot
.62965 .60244 Mdot
.55389 .79314 Mdot
.35919 .7279 Mdot
.55459 .74555 Mdot
.6952 .68032 Mdot
.67327 .27586 Mdot
.50331 .6186 Mdot
.62305 .1686 Mdot
.67147 .31355 Mdot
.47548 .52852 Mdot
.26675 .42074 Mdot
.52822 .64552 Mdot
.60069 .64101 Mdot
.76874 .41253 Mdot
.74091 .37393 Mdot
.23924 .30395 Mdot
.44184 .74553 Mdot
.45796 .64322 Mdot
.66352 .57122 Mdot
.71484 .74124 Mdot
.37059 .34245 Mdot
.6835 .25212 Mdot
.45536 .49868 Mdot
.76628 .69185 Mdot
.5126 .21347 Mdot
.51602 .25935 Mdot
.57498 .20532 Mdot
.43961 .15964 Mdot
.47921 .58694 Mdot
.69555 .36457 Mdot
.31041 .29712 Mdot
.59392 .61612 Mdot
.63756 .36584 Mdot
.58765 .19956 Mdot
.21047 .63616 Mdot
.52231 .51019 Mdot
.70423 .22035 Mdot
.59235 .68401 Mdot
.68775 .35561 Mdot
.33363 .2283 Mdot
.14072 .45637 Mdot
.5247 .27295 Mdot
.53211 .13379 Mdot
.50776 .24635 Mdot
.57111 .18601 Mdot
.45143 .28327 Mdot
.42704 .46313 Mdot
.80976 .53104 Mdot
.70595 .24378 Mdot
.24837 .58829 Mdot
.39522 .23245 Mdot
.80928 .48792 Mdot
.69569 .23029 Mdot
.57576 .70013 Mdot
.60669 .81051 Mdot
.29829 .42761 Mdot
.77274 .69747 Mdot
.8033 .62373 Mdot
.73899 .44798 Mdot
.46049 .7271 Mdot
.60631 .80248 Mdot
.50138 .82858 Mdot
.79802 .62575 Mdot
.52498 .74023 Mdot
.73778 .38048 Mdot
.40141 .68346 Mdot
.72058 .30207 Mdot
.65991 .77606 Mdot
.3353 .28539 Mdot
.52388 .36304 Mdot
.5634 .40853 Mdot
.75607 .37969 Mdot
.62192 .27226 Mdot
.36336 .34898 Mdot
.52931 .4179 Mdot
.74158 .46597 Mdot
.22136 .74128 Mdot
.48308 .22887 Mdot
.63764 .5551 Mdot
.48164 .13092 Mdot
.70007 .30429 Mdot
.42374 .50265 Mdot
.68561 .69687 Mdot
.39784 .77834 Mdot
.34069 .44038 Mdot
.57584 .58422 Mdot
.68819 .2257 Mdot
.3555 .47318 Mdot
.55245 .14748 Mdot
.82804 .44647 Mdot
.69773 .52764 Mdot
.47728 .63606 Mdot
.27887 .50803 Mdot
.57428 .76413 Mdot
.52632 .74624 Mdot
.479 .13968 Mdot
.55857 .79001 Mdot
.46553 .41085 Mdot
.41019 .40868 Mdot
.41109 .3891 Mdot
.48543 .56277 Mdot
.75406 .70891 Mdot
.72681 .37481 Mdot
.40085 .74468 Mdot
.60247 .2994 Mdot
.44499 .70711 Mdot
.66641 .61561 Mdot
.35542 .72079 Mdot
.44734 .55054 Mdot
.32215 .6726 Mdot
.26107 .46694 Mdot
.41451 .19121 Mdot
.63065 .23968 Mdot
.83612 .54402 Mdot
.17418 .49169 Mdot
.66352 .34855 Mdot
.50216 .76583 Mdot
.36698 .25671 Mdot
.51037 .51141 Mdot
.25687 .61434 Mdot
.41868 .76361 Mdot
.6631 .64153 Mdot
.68099 .26525 Mdot
.59211 .7337 Mdot
.75522 .30725 Mdot
.38295 .71151 Mdot
.37518 .2138 Mdot
.39417 .44679 Mdot
.7597 .6318 Mdot
.68751 .58834 Mdot
.18383 .45977 Mdot
.49297 .41824 Mdot
.44228 .12662 Mdot
.63554 .45466 Mdot
.59656 .15631 Mdot
.43805 .33314 Mdot
.21402 .67217 Mdot
.69113 .2847 Mdot
.48218 .50398 Mdot
.47569 .46419 Mdot
.80645 .43987 Mdot
.61661 .33904 Mdot
.63427 .33349 Mdot
.41745 .58267 Mdot
.33862 .48384 Mdot
.47278 .39152 Mdot
.5339 .23964 Mdot
.41956 .19524 Mdot
.58234 .57226 Mdot
.34097 .53493 Mdot
.54836 .75851 Mdot
.45865 .27252 Mdot
.73197 .34853 Mdot
.66148 .25534 Mdot
.64691 .60664 Mdot
.43063 .67722 Mdot
.43655 .15556 Mdot
.72326 .3167 Mdot
.41112 .56424 Mdot
.49702 .70382 Mdot
.429 .24557 Mdot
.24931 .31446 Mdot
.51932 .1704 Mdot
.41303 .39794 Mdot
.52148 .42424 Mdot
.40337 .69799 Mdot
.71257 .21296 Mdot
.45583 .1324 Mdot
.17306 .43908 Mdot
.47412 .42707 Mdot
.72603 .44734 Mdot
.41059 .78314 Mdot
.37765 .21308 Mdot
.78383 .68675 Mdot
.64042 .31046 Mdot
.45082 .71201 Mdot
.19983 .61344 Mdot
.57819 .80336 Mdot
.45276 .41884 Mdot
.68852 .58904 Mdot
.79884 .58655 Mdot
.4003 .26107 Mdot
.34891 .4468 Mdot
.45635 .44462 Mdot
.41301 .23931 Mdot
.73656 .37951 Mdot
.61653 .3415 Mdot
.37347 .21378 Mdot
.57027 .78953 Mdot
.50142 .70682 Mdot
.39857 .2205 Mdot
.62779 .48209 Mdot
.32556 .30644 Mdot
.23199 .35797 Mdot
.45839 .43197 Mdot
.3072 .44583 Mdot
.61104 .54294 Mdot
.49741 .38889 Mdot
.5053 .23314 Mdot
.18404 .57436 Mdot
.33507 .5905 Mdot
.71061 .4041 Mdot
.59258 .79887 Mdot
.71749 .4303 Mdot
.75917 .26829 Mdot
.54158 .25043 Mdot
.66567 .5582 Mdot
.49627 .20719 Mdot
.28443 .35277 Mdot
.16189 .5188 Mdot
.7404 .47654 Mdot
.37674 .67883 Mdot
.71922 .41755 Mdot
.69256 .47804 Mdot
.51056 .2004 Mdot
.57835 .37055 Mdot
.70162 .51297 Mdot
.69206 .7557 Mdot
.22557 .38915 Mdot
.70657 .41522 Mdot
.40868 .41374 Mdot
.61488 .43812 Mdot
.78015 .31953 Mdot
.30745 .44797 Mdot
.45428 .12421 Mdot
.50865 .70147 Mdot
.24096 .3197 Mdot
.75038 .35329 Mdot
.55226 .43635 Mdot
.47193 .41869 Mdot
.24326 .37679 Mdot
.5278 .68846 Mdot
.45754 .63781 Mdot
.67796 .42209 Mdot
.33969 .24482 Mdot
.35217 .63106 Mdot
.40805 .63175 Mdot
.47836 .31491 Mdot
.6975 .72485 Mdot
.78561 .66901 Mdot
.68732 .48294 Mdot
.38959 .42041 Mdot
.32235 .32309 Mdot
.57405 .70797 Mdot
.54898 .7544 Mdot
.42726 .1794 Mdot
.72458 .49542 Mdot
.63634 .45885 Mdot
.17448 .44942 Mdot
.40504 .60766 Mdot
.79629 .36519 Mdot
.63804 .63432 Mdot
.56744 .76356 Mdot
.56539 .74565 Mdot
.77378 .40484 Mdot
.66489 .61238 Mdot
.70039 .27245 Mdot
.41714 .67648 Mdot
.39457 .57583 Mdot
.48052 .73068 Mdot
.64758 .60701 Mdot
.43583 .39883 Mdot
.75129 .71898 Mdot
.19483 .60613 Mdot
.71389 .61106 Mdot
.54338 .5013 Mdot
.75291 .42532 Mdot
.72097 .73629 Mdot
.70584 .40007 Mdot
.32272 .5871 Mdot
.77215 .50486 Mdot
.69072 .28646 Mdot
.75984 .3275 Mdot
.69409 .31683 Mdot
.57395 .76623 Mdot
.41547 .38878 Mdot
.4587 .79278 Mdot
.5291 .71501 Mdot
.49579 .49121 Mdot
.52882 .6752 Mdot
.46556 .63994 Mdot
.43111 .51624 Mdot
.809 .45641 Mdot
.47145 .59196 Mdot
.69699 .24132 Mdot
.78832 .35949 Mdot
.6371 .204 Mdot
.37209 .3769 Mdot
.71413 .43975 Mdot
.48163 .12567 Mdot
.60932 .76762 Mdot
.72287 .30683 Mdot
.79435 .63762 Mdot
.61518 .81559 Mdot
.34283 .21711 Mdot
.66258 .28466 Mdot
.63415 .51207 Mdot
.84453 .51198 Mdot
.67619 .32836 Mdot
.61223 .80623 Mdot
.66162 .64689 Mdot
.74343 .35276 Mdot
.42436 .13934 Mdot
.7416 .68938 Mdot
.63862 .33776 Mdot
.68465 .59426 Mdot
.65212 .58524 Mdot
.67243 .75929 Mdot
.58394 .66319 Mdot
.32966 .45308 Mdot
.21394 .51187 Mdot
.45225 .72173 Mdot
.64049 .58058 Mdot
.66086 .76716 Mdot
.52771 .74822 Mdot
.49072 .7655 Mdot
.23797 .38128 Mdot
.3456 .21699 Mdot
.65632 .55987 Mdot
.59469 .54341 Mdot
.69543 .39594 Mdot
.37468 .62268 Mdot
.43389 .75631 Mdot
.53852 .64164 Mdot
.49819 .45015 Mdot
.51061 .55364 Mdot
.66223 .19907 Mdot
.21595 .54353 Mdot
.41594 .34787 Mdot
.71331 .43138 Mdot
.75603 .38293 Mdot
.36962 .31272 Mdot
.60763 .35199 Mdot
.65054 .7685 Mdot
.66465 .5196 Mdot
.59071 .18755 Mdot
.64364 .34484 Mdot
.40187 .7181 Mdot
.29344 .69374 Mdot
.42207 .27974 Mdot
.80332 .56747 Mdot
.46975 .14525 Mdot
.65575 .35855 Mdot
.63058 .47977 Mdot
.60903 .28766 Mdot
.43582 .40132 Mdot
.66895 .36758 Mdot
.61889 .33487 Mdot
.34678 .277 Mdot
.69905 .54377 Mdot
.51946 .15987 Mdot
.31152 .52305 Mdot
.43456 .7299 Mdot
.56301 .28036 Mdot
.67083 .76381 Mdot
.57901 .70591 Mdot
.73132 .28483 Mdot
.48217 .49801 Mdot
.36205 .57371 Mdot
.52232 .61427 Mdot
.61032 .75894 Mdot
.77007 .40523 Mdot
.59256 .29411 Mdot
.45061 .60256 Mdot
.66603 .49467 Mdot
.82797 .58447 Mdot
.26735 .42439 Mdot
.31512 .42694 Mdot
.52646 .7978 Mdot
.61625 .39743 Mdot
.345 .55682 Mdot
.51686 .34692 Mdot
.54564 .70117 Mdot
.28347 .6754 Mdot
.39591 .3879 Mdot
.80636 .55448 Mdot
.76899 .66529 Mdot
.42198 .18594 Mdot
.38056 .36768 Mdot
.83294 .58157 Mdot
.81227 .56679 Mdot
.74823 .36736 Mdot
.58583 .79424 Mdot
.58798 .5111 Mdot
.49107 .61491 Mdot
.32236 .58713 Mdot
.6458 .42099 Mdot
.4383 .18091 Mdot
.44376 .64108 Mdot
.35405 .5762 Mdot
.47187 .51955 Mdot
.35967 .33217 Mdot
.37724 .4542 Mdot
.72444 .34541 Mdot
.84489 .51288 Mdot
.42905 .68688 Mdot
.45274 .27797 Mdot
.51109 .23827 Mdot
.50835 .51992 Mdot
.7124 .26188 Mdot
.42654 .53238 Mdot
.76498 .41917 Mdot
.52962 .38901 Mdot
.78391 .58753 Mdot
.79685 .39463 Mdot
.41574 .63542 Mdot
.50609 .48114 Mdot
.73954 .40213 Mdot
.57175 .49831 Mdot
.56289 .3698 Mdot
.23715 .53182 Mdot
.5983 .7768 Mdot
.42363 .21629 Mdot
.48926 .32151 Mdot
.58391 .68304 Mdot
.41478 .78404 Mdot
.50124 .16453 Mdot
.41616 .5114 Mdot
.47274 .50299 Mdot
.30713 .301 Mdot
.35661 .47288 Mdot
.17562 .66509 Mdot
.64004 .18066 Mdot
.52187 .61596 Mdot
.4621 .46425 Mdot
.40693 .62532 Mdot
.31082 .51149 Mdot
.75308 .50056 Mdot
.4358 .1772 Mdot
.44322 .28749 Mdot
.22582 .41893 Mdot
.51481 .34767 Mdot
.8082 .44582 Mdot
.1883 .41058 Mdot
.39774 .32639 Mdot
.756 .26331 Mdot
.6338 .31254 Mdot
.69845 .38034 Mdot
.18457 .68779 Mdot
.79865 .44123 Mdot
.51113 .71935 Mdot
.22628 .46251 Mdot
.66368 .20479 Mdot
.47478 .41792 Mdot
.23993 .49746 Mdot
.75308 .67752 Mdot
.42474 .68445 Mdot
.43901 .74041 Mdot
.52631 .34934 Mdot
.82489 .51189 Mdot
.57422 .83297 Mdot
.28653 .35132 Mdot
.16008 .49397 Mdot
.70071 .5184 Mdot
.54706 .15749 Mdot
.52528 .27084 Mdot
.2143 .63161 Mdot
.75843 .33013 Mdot
.48218 .72211 Mdot
.67326 .74808 Mdot
.23436 .59049 Mdot
.39366 .65619 Mdot
.40742 .78826 Mdot
.55703 .41635 Mdot
.73553 .48807 Mdot
.25128 .37979 Mdot
.45731 .585 Mdot
.47187 .7242 Mdot
.78745 .60238 Mdot
.50353 .48267 Mdot
.49885 .14437 Mdot
.63723 .76668 Mdot
.41198 .69105 Mdot
.27977 .3148 Mdot
.38677 .61996 Mdot
.45535 .17761 Mdot
.38699 .33831 Mdot
.52009 .72491 Mdot
.30954 .237 Mdot
.52325 .13153 Mdot
.58683 .51015 Mdot
.60519 .63089 Mdot
.80416 .37001 Mdot
.38069 .52285 Mdot
.77697 .65353 Mdot
.56898 .31233 Mdot
.44934 .74843 Mdot
.49446 .56267 Mdot
.50466 .64968 Mdot
.4834 .80274 Mdot
.66223 .50918 Mdot
.79146 .59763 Mdot
.20528 .38993 Mdot
.41154 .68561 Mdot
.64658 .75178 Mdot
.19106 .38641 Mdot
.63869 .63773 Mdot
.68285 .47879 Mdot
.66261 .20223 Mdot
.77816 .46932 Mdot
.4768 .6883 Mdot
.67519 .565 Mdot
.41937 .54479 Mdot
.27803 .62923 Mdot
.50531 .70822 Mdot
.50777 .42485 Mdot
.45841 .72765 Mdot
.38137 .21683 Mdot
.81119 .51803 Mdot
.43706 .12424 Mdot
.77298 .36092 Mdot
.71527 .42479 Mdot
.75899 .66549 Mdot
.45343 .43206 Mdot
.62449 .19743 Mdot
.25586 .36339 Mdot
.22853 .37707 Mdot
.54878 .83104 Mdot
.39759 .64202 Mdot
.51954 .58937 Mdot
.55837 .4132 Mdot
.76025 .31981 Mdot
.56643 .82532 Mdot
.75294 .30593 Mdot
.47026 .61391 Mdot
.52121 .57529 Mdot
.12972 .48217 Mdot
.58558 .19035 Mdot
.50212 .67804 Mdot
.53588 .52337 Mdot
.49788 .54607 Mdot
.54233 .58016 Mdot
.58717 .3847 Mdot
.38806 .76105 Mdot
.45551 .7441 Mdot
.69627 .23775 Mdot
.69029 .41055 Mdot
.47953 .4196 Mdot
.39746 .30211 Mdot
.48609 .45089 Mdot
.6366 .5832 Mdot
.45849 .2976 Mdot
.47362 .75041 Mdot
.38367 .50147 Mdot
.28708 .61167 Mdot
.67892 .51081 Mdot
.5597 .42271 Mdot
.72439 .48377 Mdot
.53208 .77593 Mdot
.58835 .37156 Mdot
.49668 .8297 Mdot
.5256 .74875 Mdot
.53778 .72613 Mdot
.71414 .34375 Mdot
.744 .74533 Mdot
.486 .41566 Mdot
.60025 .39715 Mdot
.60916 .67796 Mdot
.63908 .71721 Mdot
.68514 .55076 Mdot
.3169 .65034 Mdot
.54719 .36756 Mdot
.47023 .62361 Mdot
.76208 .421 Mdot
.45977 .33192 Mdot
.70966 .21609 Mdot
.48749 .60969 Mdot
.73992 .51873 Mdot
.71321 .27499 Mdot
.32878 .29579 Mdot
.66047 .64201 Mdot
.53111 .67304 Mdot
.3968 .56114 Mdot
.38244 .50584 Mdot
.64859 .40033 Mdot
.33615 .26646 Mdot
.55751 .17062 Mdot
.54164 .78756 Mdot
.72322 .52066 Mdot
.58265 .60851 Mdot
.31015 .59931 Mdot
.50813 .43562 Mdot
.21495 .61428 Mdot
.36141 .52303 Mdot
.71108 .31472 Mdot
.52048 .77112 Mdot
.441 .74557 Mdot
.68069 .61597 Mdot
.57203 .152 Mdot
.52847 .51085 Mdot
.69102 .53192 Mdot
.44949 .53766 Mdot
.62905 .27462 Mdot
.52285 .74172 Mdot
.41135 .22352 Mdot
.46605 .61154 Mdot
.58819 .51608 Mdot
.75471 .27976 Mdot
.74612 .46858 Mdot
.47132 .35369 Mdot
.68251 .26474 Mdot
.60644 .77606 Mdot
.4751 .46564 Mdot
.19522 .7083 Mdot
.25292 .36234 Mdot
.74321 .25206 Mdot
.36213 .24299 Mdot
.58366 .72258 Mdot
.72345 .37807 Mdot
.48731 .63559 Mdot
.29581 .47147 Mdot
.60257 .18409 Mdot
.74129 .40741 Mdot
.59372 .50652 Mdot
.60972 .63114 Mdot
.40115 .51004 Mdot
.66034 .39619 Mdot
.4149 .21583 Mdot
.34422 .47957 Mdot
.41273 .56066 Mdot
.39971 .23022 Mdot
.38184 .50596 Mdot
.63439 .81001 Mdot
.48214 .13834 Mdot
.63003 .22375 Mdot
.40165 .39226 Mdot
.18694 .64661 Mdot
.72746 .4203 Mdot
.64014 .41516 Mdot
.47272 .32614 Mdot
.46539 .79735 Mdot
.66222 .3635 Mdot
.37342 .22078 Mdot
.77549 .38843 Mdot
.57728 .70733 Mdot
.2452 .7728 Mdot
.49098 .72992 Mdot
.40876 .52966 Mdot
.64134 .37117 Mdot
.70809 .25025 Mdot
.21841 .45228 Mdot
.82401 .44592 Mdot
.53699 .2662 Mdot
.64023 .58442 Mdot
.45084 .81172 Mdot
.17696 .44802 Mdot
.40105 .40561 Mdot
.15907 .49748 Mdot
.5631 .19148 Mdot
.38804 .75305 Mdot
.58321 .29307 Mdot
.71977 .4404 Mdot
.45771 .62703 Mdot
.54465 .24513 Mdot
.57018 .50244 Mdot
.70544 .38473 Mdot
.55269 .17393 Mdot
.33168 .73027 Mdot
.27585 .30518 Mdot
.62574 .2084 Mdot
.46089 .27332 Mdot
.73721 .44338 Mdot
.52427 .75395 Mdot
.34665 .53541 Mdot
.3077 .50509 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0V?oo
ool2o`000:oooooo000Looooo`03o`000?oooooooooo08[ooooo1?l00002ooooo`;o00001_ooool3
o`0000;ooooo0ol0002Yooooo`007?ooool00ol0003oooooooooo`2:ooooo`Go000000?oooooo`00
0?l000000_l00005ooooo`;o00000_ooool3o`0000?ooooo0_l0002Tooooo`007?ooool00ol0003o
ooooooooo`2<ooooo`?o00000oooool2o`0000Gooooo0_l00008ooooo`;o000000?oooooo`000?l0
0000XOooool001cooooo00?o0000ooooooooool0Qoooool2o`0000Oooooo0_l00007ooooo`;o0000
2oooool2o`000003ooooool0003o000009kooooo000Looooo`03o`000?oooooooooo08Oooooo0_l0
0006ooooo`?o00001oooool2o`0000cooooo1?l0002Nooooo`007?ooool00ol0003oooooooooo`26
ooooo`;o00001oooool2o`0000Oooooo0ol0000<ooooo`;o0000X?ooool001cooooo00?o0000oooo
ooooool0Q_ooool2o`00013ooooo0_l00004ooooo`;o00004oooool2o`0009Cooooo000Looooo`03
o`000?oooooooooo08;ooooo0_l0000Aooooo`;o00001oooool2o`00013ooooo0_l000000ooooooo
0000o`00002Dooooo`007?ooool00ol0003oooooooooo`22ooooo`;o00004Oooool2o`0000_ooooo
0_l0000:ooooo`Co0000Uoooool001cooooo0_l0002Sooooo`;o00000oooool2o`0000Gooooo0_l0
0006ooooo`;o0000TOooool001cooooo00?o0000ooooooooool0Q_ooool2o`0000;ooooo0_l0000K
ooooo`;o00003Oooool2o`0000Kooooo0_l00029ooooo`007?ooool00ol0003oooooooooo`26oooo
o`;o00000_ooool3o`0001Sooooo1?l00005ooooo`;o00003_ooool4o`0008Oooooo000Looooo`03
o`000?oooooooooo08Wooooo1?l0000Hooooo`Co00001Oooool2o`0000Kooooo0_l00008ooooo`;o
0000Qoooool001cooooo00?o0000ooooooooool0ROooool2o`0001Cooooo0_l0000Eooooo`;o0000
2?ooool2o`0000Kooooo0_l0001oooooo`007?ooool00ol0003oooooooooo`2Oooooo`;o00005?oo
ool2o`0000Kooooo0_l00008ooooo`?o0000Ooooool001cooooo00?o0000ooooooooool0Q?ooool2
o`0001oooooo0_l00007ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Kooooo0_l00008
ooooo`;o0000P?ooool001cooooo00?o0000ooooooooool0Q?ooool2o`0000Cooooo0_l0000Ioooo
o`;o00001oooool5o`0000;ooooo0_l0002Booooo`007?ooool00ol0003oooooooooo`2:ooooo`;o
00001?ooool2o`0001kooooo1?l0002Eooooo`007?ooool00ol0003oooooooooo`27ooooo`;o0000
00Coooooo`000?l0003o00000oooool2o`00023ooooo0_l0000Booooo`;o00001?ooool2o`0007_o
oooo000Looooo`03o`000?oooooooooo08Oooooo0ol000000ooooooo0000o`00000Eooooo`;o0000
1_ooool2o`0000?ooooo0_l0000?ooooo`;o00001?ooool2o`0000;ooooo1?l0001kooooo`007?oo
ool00ol0003oooooooooo`25ooooo`;o000000?oooooo`000?l000006?ooool2o`0000Kooooo0_l0
0003ooooo`;o00001Oooool2o`0000Cooooo0_l00002ooooo`?o00001oooool2o`0007gooooo000L
ooooo`03o`000?oooooooooo08Gooooo0_l0000Sooooo`;o00001?ooool2o`0000Cooooo0_l00002
ooooo`Co00000oooool2o`0008Kooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ
8B44ooooo`Go00001_ooool00ol0003oooooooooo`23ooooo`Co00008oooool2o`0000Cooooo0_l0
00000ooooooo0000o`000005ooooo`;o0000SOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo08?o
oooo1?l0000/ooooo`;o00001Oooool2o`0000Cooooo0_l00008ooooo`;o00000_ooool2o`0007Wo
oooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h0
1oooool00ol0003oooooooooo`25ooooo`;o0000=?ooool2o`0000?ooooo0_l00005ooooo`;o0000
00?oooooo`000?l000000_ooool2o`0000?ooooo0_l0001dooooo`0000?oooooo`000?ooool00_oo
ool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0002Rooooo`;o00004Ooo
ool2o`0000Cooooo0_l00003ooooo`;o00001Oooool2o`0000Gooooo0ol00002ooooo`;o0000M?oo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`05
ooooo`03o`000?oooooooooo0:;ooooo0_l0000Aooooo`Co000000?oooooo`000?l000002?ooool2
o`0000Gooooo0_l00002ooooo`;o00000_ooool3o`0000?ooooo0_l0001^ooooo`0000?ooooooa0@
4?ooool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0Loooool2o`0002Sooooo0_l000000ooooooo0000o`00000Eooooo`;o000000?oooooo`00
0?l000001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00001oooool2o`00
00?ooooo0_l00006ooooo`;o0000I_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool0
1Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0Loooool2o`0000_ooooo0ol0
0005ooooo`;o00004oooool2o`000004ooooool0003o0000o`0001gooooo0_l00005ooooo`;o0000
6?ooool2o`0006Kooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c006ooooo`03o`000?oooooooooo06Wooooo1?l00006ooooo`Ko00001oooool3o`00
00Gooooo0_l0000Gooooo`Co00005Oooool2o`0000_ooooo0_l000000ooooooo0000o`000006oooo
o`;o00004?ooool2o`0006?ooooo000Looooo`03o`000?oooooooooo06Wooooo1_l00004ooooo`Oo
00001_ooool5o`000003ooooool0003o000001Sooooo1Ol0000Eooooo`;o00001Oooool2o`0000Co
oooo0_l000000ooooooo0000o`000006ooooo`?o00003_ooool3o`0006?ooooo000Looooo`03o`00
0?oooooooooo06Kooooo0_l00004ooooo`?o00001Oooool6o`0000Cooooo0_l00003ooooo`;o0000
00?oooooo`000?l000006?ooool4o`0001gooooo0_l00004ooooo`;o000000?oooooo`000?l00000
1?ooool5o`0000cooooo1?l0001Tooooo`007?ooool00ol0003oooooooooo`1Vooooo`;o00003?oo
ool4o`0000Kooooo0_l00002ooooo`;o0000@oooool5o`0000Cooooo0_l0000?ooooo`;o0000I_oo
ool001cooooo00?o0000ooooooooool0P_ooool2o`0001gooooo0_l0000Qooooo`;o00000oooool3
o`00013ooooo0_l0001[ooooo`007?ooool00ol0003oooooooooo`1Yooooo`;o00003oooool2o`00
00;ooooo0ol0000Hooooo`;o00000oooool2o`000003ooooool0003o0000027ooooo0_l00004oooo
o`;o00004?ooool4o`0006Wooooo000Looooo`03o`000?oooooooooo05[ooooo0_l0000=ooooo`;o
000000?oooooo`000?l000003?ooool2o`000003ooooool0003o000000;o00006?ooool2o`0000?o
oooo1?l0000/ooooo`;o00001Oooool2o`0000Oooooo0_l00004ooooo`;o0000Hoooool001cooooo
00?o0000ooooooooool0F_ooool2o`0000Gooooo0_l00009ooooo`;o00003?ooool2o`000004oooo
ool0003o0000o`0000Kooooo0_l0000Hooooo`;o0000:Oooool6o`0000Cooooo0_l00003ooooo`;o
00002?ooool2o`0000?ooooo0_l0001Nooooo`007?ooool00ol0003oooooooooo`1Qooooo`;o0000
00?oooooo`000?l000001Oooool2o`0000Oooooo0_l00004ooooo`;o00000_ooool2o`0000;ooooo
0_l00002ooooo`;o00005?ooool2o`0000Cooooo0_l00006ooooo`;o00007Oooool8o`0000Kooooo
0_l000000ooooooo0000o`000002ooooo`?o00002?ooool2o`0005kooooo000Looooo`03o`000?oo
oooooooo06Cooooo1_l000000ooooooo0000o`000005ooooo`Co00003?ooool2o`0001Sooooo0_l0
0004ooooo`?o00000oooool4o`0001gooooo0_l00004ooooo`Co00001?ooool2o`0000Gooooo0ol0
001Xooooo`007?ooool00ol0003oooooooooo`1Vooooo`Co000000Coooooo`000?l0003ooooo0_l0
0002ooooo`;o00001oooool5o`0000Sooooo0_l0000Booooo`;o000000?oooooo`000?l000000_oo
ool2o`0000?ooooo0_l00003ooooo`;o00007Oooool2o`0000;ooooo1?l0000;ooooo`;o000000?o
ooooo`000?l00000IOooool001cooooo00?o0000ooooooooool0Joooool2o`000003ooooool0003o
000000_ooooo1ol00006ooooo`;o00004_ooool2o`000003ooooool0003o000000;o00002_ooool2
o`0001gooooo0_l00002ooooo`Ko00001_ooool2o`0000Cooooo0_l0001Uooooo`007?ooool2o`00
06Wooooo1Ol0000=ooooo`;o00001?ooool2o`0000?ooooo0_l00005ooooo`;o00004oooool2o`00
00Sooooo0ol0000Jooooo`;o00001?ooool8o`0000Cooooo1?l00004ooooo`;o00002_ooool2o`00
05Wooooo000Looooo`03o`000?oooooooooo06Gooooo2?l000000ooooooo0000o`000005ooooo`Co
000000?oooooo`000?l000002Oooool2o`0000Gooooo0_l0000Mooooo`?o00006_ooool2o`0000Co
oooo0_l00002ooooo`?o00001Oooool2o`0000Kooooo0_l0000:ooooo`;o0000FOooool001cooooo
00?o0000ooooooooool0I?ooool5o`0000Gooooo0_l00003ooooo`Ko00001?ooool4o`0000gooooo
0_l0000Gooooo`;o00009oooool2o`000004ooooool0003o0000ooooo`;o0000LOooool001cooooo
00?o0000ooooooooool0GOooool2o`0000Gooooo0_l000001?oooooo0000o`000?l00009ooooo`;o
00002?ooool4o`0000gooooo0_l0000Dooooo`;o000000?oooooo`000?l000009oooool2o`000004
ooooool0003o0000ooooo`;o00002_ooool2o`0000?ooooo0_l0001Pooooo`007?ooool00ol0003o
ooooooooo`1Mooooo`;o00002?ooool3o`0000gooooo0_l00005ooooo`;o00003_ooool2o`0001Co
oooo0_l0000Vooooo`;o00004_ooool6o`000003ooooool0003o000000Wooooo0_l0001Eooooo`00
7?ooool00ol0003oooooooooo`1Yooooo`Co00002_ooool2o`0001Gooooo0_l00002ooooo`;o0000
5Oooool4o`0001oooooo0_l0000;ooooo`?o00001?ooool2o`0000;ooooo0_l0000<ooooo`;o0000
EOooool001cooooo00?o0000ooooooooool0I?ooool2o`0000?ooooo1?l0000Kooooo`;o00002?oo
ool2o`0001?ooooo1_l0000/ooooo`Go00001?ooool2o`0000oooooo0_l0001Dooooo`007?ooool0
0ol0003oooooooooo`1Jooooo`;o00002?ooool2o`0000Cooooo0_l00003ooooo`Co00003oooool2
o`000004ooooool0003o0000ooooo`Go000000Coooooo`000?l0003ooooo0ol0000Cooooo`;o0000
7?ooool3o`0001Cooooo0_l00002ooooo`Co00003oooool3o`0005?ooooo000Looooo`03o`000?oo
oooooooo05[ooooo0_l0000>ooooo`;o000000?oooooo`000?l000001?l0000?oooooa;o00004ooo
ool2o`0001cooooo0ol000000ooooooo0000o`00000<ooooo`;o00001_ooool3o`0000;ooooo0_l0
000>ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0Eoooool2o`0001Cooooo0_l0000<
ooooo`Co00000oooool?o`0001Cooooo0_l00006ooooo`;o00006_ooool2o`0000cooooo0_l00006
ooooo`;o00000oooool4o`0000Wooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`1Goooo
o`;o00004Oooool2o`0000oooooo1?l000000ooooooo0000o`00000Ao`0000Gooooo0_l0000;oooo
o`;o00000oooool2o`000003ooooool0003o000000Cooooo0_l0000Iooooo`;o00005_ooool2o`00
00Wooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`1Sooooo`;o00001?ooool3o`0000?o
oooo0_l0000?oooooa?o000000?oooooo`000?l000000_ooool2o`0000gooooo0_l000000ooooooo
0000o`000005ooooo`Co00006Oooool4o`000003ooooool0003o000000Sooooo0_l00007ooooo`;o
00000_ooool2o`0005gooooo000Looooo`03o`000?oooooooooo04oooooo0_l0000?ooooo`;o0000
00?oooooo`000?l000001?ooool4o`0000;ooooo0_l0000?oooooa7o00000oooool2o`000004oooo
ool0003o0000ooooo`;o00002oooool2o`0000Sooooo0_l0000?ooooo`;o00003?ooool2o`000003
ooooool0003o000000Sooooo0_l00007ooooo`Ko0000GOooool001cooooo00?o0000ooooooooool0
Coooool2o`0000Cooooo0_l00008ooooo`Co00002?ooool2o`0001;ooooo4ol00004ooooo`?o0000
00?oooooo`000?l000005Oooool2o`0000oooooo0_l0000Booooo`;o00001Oooool2o`000003oooo
ool0003o000000Kooooo0_l0001Oooooo`007?ooool00ol0003oooooooooo`1Eooooo`;o00002?oo
ool4o`0000;ooooo0_l00004ooooo`;o00003?ooool2o`0000Cooooo5?l00003ooooo`;o00005?oo
ool2o`0000Oooooo1?l000001?oooooo0000o`000?ooool2o`0001Oooooo0_l00008ooooo`;o0000
Ioooool001cooooo00?o0000ooooooooool0D?ooool2o`0000oooooo0_l00002ooooo`Co00004?oo
ool2o`0000Cooooo5_l0000Gooooo`;o00001oooool4o`000003ooooool0003o000000?o00001?oo
ool2o`0000Sooooo0_l0001jooooo`007?ooool2o`00057ooooo0_l00007ooooo`;o00001Oooool3
o`0000Cooooo0_l0000@ooooo`;o00001?oooolGo`0000Cooooo0_l0000@ooooo`;o00003Oooool2
o`0000?ooooo0_l000000ooooooo0000o`000008ooooo`;o00004?ooool2o`0000;ooooo0ol0000<
ooooo`;o0000EOooool001cooooo00?o0000ooooooooool0B_ooool2o`0000Cooooo0_l00007oooo
o`;o00001Oooool2o`0000Gooooo0_l00003ooooo`;o00002oooool2o`000003ooooool0003o0000
00co000000?oooooo`000?l000002Ol00004ooooo`;o00009?ooool2o`0000Cooooo0_l0000Foooo
o`Co000000?oooooo`000?l000000ol0000:ooooo`?o0000E?ooool001cooooo00?o0000oooooooo
ool0B_ooool2o`0000[ooooo0_l0000>ooooo`Go000000?oooooo`000?l000003OoooolKo`00033o
oooo0_l0000Fooooo`Co00001?ooool3o`0000Oooooo1Ol0001Dooooo`007?ooool00ol0003ooooo
ooooo`1Aooooo`;o00000oooool2o`0000kooooo1Ol0000@ooooo`;o00000_oooolIo`000003oooo
ool0003o000002_ooooo0_l00004ooooo`;o00003?ooool2o`0000Sooooo0_l000000ooooooo0000
o`000004ooooo`;o000000?oooooo`000?l000000_l0001Eooooo`007?ooool00ol0003ooooooooo
o`1Aooooo`;o00005?ooool4o`0000Wooooo0_l00004ooooo`Co000000?oooooo`000?l000004_l0
0003ooooo`Go00006Oooool3o`0001?ooooo1?l00008ooooo`;o00000_ooool2o`0000Sooooo0_l0
0007ooooo`;o00002Oooool2o`0004oooooo000Looooo`03o`000?oooooooooo04gooooo0_l00008
ooooo`;o00003_ooool4o`0000Oooooo1?l00004ooooo`Co000000?oooooo`000?l000006Ol0000J
ooooo`?o00004oooool2o`0000[ooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o
000000;o00000_ooool2o`0000oooooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`1;oooo
o`Co00002?ooool2o`0001Sooooo0ol00009oooooago00006oooool2o`0001;ooooo0_l0000?oooo
o`;o00000_ooool2o`000003ooooool0003o000000;o00000_ooool2o`0000[ooooo0_l00003oooo
o`Co0000COooool001cooooo00?o0000ooooooooool0Boooool2o`0001Sooooo0_l0000:ooooo`;o
00002Oooool6o`000003ooooool0003o000001Go000000?oooooo`000?l000006?ooool2o`0000[o
oooo0_l00006ooooo`;o00001Oooool2o`0000oooooo0_l00003ooooo`;o00002oooool2o`0000Co
oooo0ol0001=ooooo`007?ooool00ol0003oooooooooo`18ooooo`;o00001?ooool2o`0001Gooooo
0_l00004ooooo`;o00002Oooool2o`0000Cooooo0_l000000ooooooo0000o`00000Io`000003oooo
ool0003o000001Oooooo0_l0000;ooooo`;o00001Oooool3o`000003ooooool0003o000000;ooooo
0_l0000?ooooo`Oo00004Oooool2o`0004kooooo000Looooo`03o`000?oooooooooo04Sooooo0_l0
0003ooooo`Go00006Oooool2o`000004ooooool0003o0000ooooo`Co000000?oooooo`000?l00000
1Oooool2o`0000;ooooo5ol000000ooooooo0000o`000002o`0001Gooooo1?l0000@ooooo`Go0000
00?oooooo`000?l000000_l00007ooooo`?o00001oooool8o`0000Kooooo0_l00002ooooo`;o0000
E?ooool001cooooo00?o0000ooooooooool0COooool2o`000003ooooool0003o000001;ooooo0_l0
0008ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o00000oooool2o`000003ooooool0
003o000000Go000000?oooooo`000?l000003Ol00002ooooo`Co00004?ooool2o`0000?ooooo0_l0
000<ooooo`;o00001?ooool2o`000003ooooool0003o000000;ooooo1_l00004ooooo`?o00001ooo
ool2o`0000?ooooo0ol00006ooooo`;o00000_ooool3o`0000Cooooo0ol0001<ooooo`007?ooool0
0ol0003oooooooooo`1Booooo`;o00004?ooool2o`0000_ooooo0_l00005ooooo`;o00001_oooolH
o`0000;ooooo0_l0000Aooooo`;o00004Oooool2o`0000?ooooo2Ol000000ooooooo0000o`000004
o`0001kooooo0ol00004ooooo`?o0000C?ooool001cooooo00?o0000ooooooooool0D_ooool2o`00
02Kooooo0_l00002ooooo`;o000000?oooooo`000?l000004Ol00002ooooo`Co0000:oooool4o`00
0003ooooool0003o000000?o00000oooool3o`0007Cooooo000Looooo`03o`000?oooooooooo07[o
oooo0_l00002ooooo`;o000000?oooooo`000?l000003_l000000ooooooo0000o`000002o`0000;o
oooo0_l0000Zooooo`Go00000_ooool4o`0000?ooooo0_l0001eooooo`007?ooool00ol0003ooooo
ooooo`1<ooooo`;o00001oooool2o`0001Oooooo0_l00005ooooo`;o00003?ooool;o`0000;ooooo
0_l00002ooooo`;o00005oooool2o`0001Gooooo0ol00004ooooo`;o00001Oooool2o`00013ooooo
0_l00002ooooo`;o0000Goooool001cooooo00?o0000ooooooooool0Boooool3o`0000Oooooo0_l0
000Gooooo`;o00001Oooool2o`0000;ooooo0_l00004ooooo`;o00000_ooool2o`0000?ooooo1_l0
0002ooooo`Ko00001?ooool2o`0000Oooooo0ol00007ooooo`;o00006_ooool2o`0000;ooooo0_l0
0002ooooo`Go00003_ooool2o`0000;ooooo0_l00003ooooo`;o00003_ooool2o`0004[ooooo000L
ooooo`;o0000C?ooool4o`0000Gooooo0_l0000Kooooo`?o00001Oooool4o`0000;ooooo0_l00002
ooooo`Oo000000Coooooo`000?l0003o00000oooool3o`0000Kooooo0_l00005ooooo`Go000000?o
ooooo`000?l000002Oooool2o`0001Cooooo0ol00002ooooo`Wo00003_ooool2o`0000;ooooo1?l0
00000ooooooo0000o`000002o`0000cooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`1=
ooooo`Co00000oooool2o`0000?ooooo0_l00002ooooo`;o00004_ooool3o`0000Cooooo0_l00000
0ooooooo0000o`000008ooooo`?o00000oooool2o`0000;ooooo1?l00002ooooo`;o00000oooool2
o`0000?ooooo1?l00004ooooo`;o00002Oooool2o`000004ooooool0003o0000o`0000Kooooo0ol0
00000ooooooo0000o`000004ooooo`;o00000oooool4o`000003ooooool0003o000000;o00004?oo
ool2o`0000;ooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000;ooooo0_l0
001@ooooo`007?ooool00ol0003oooooooooo`1>ooooo`?o00002?ooool2o`0000;ooooo0_l0000I
ooooo`;o00004Oooool2o`0000;ooooo1?l000001?oooooo0000o`000?l00008ooooo`?o00004ooo
ool3o`0000Kooooo0ol000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l000000_l0
000;ooooo`;o00001?ooool2o`0000;ooooo0_l00006ooooo`Co000000Coooooo`000?l0003ooooo
0ol0001@ooooo`007?ooool00ol0003oooooooooo`18ooooo`?o00000oooool3o`00023ooooo0ol0
0002ooooo`;o00001oooool2o`0000oooooo0ol000000ooooooo0000o`00000:ooooo`?o00001?oo
ool2o`00013ooooo0_l0000?ooooo`;o00000oooool4o`0000Wooooo0_l00004ooooo`?o00003?oo
ool2o`000003ooooool0003o000000;o00001?ooool2o`0004_ooooo000Looooo`03o`000?oooooo
oooo04Sooooo0ol00003ooooo`?o00008?ooool3o`0000;ooooo0_l00007ooooo`;o00001?ooool2
o`0000gooooo0_l00009ooooo`Co00000oooool5o`0000;ooooo1Ol00004ooooo`;o000000?ooooo
o`000?l000003oooool2o`0000?ooooo1?l0000?ooooo`?o00003?ooool8o`0000?ooooo0_l0001;
ooooo`007?ooool00ol0003oooooooooo`18ooooo`?o00000oooool3o`0002cooooo0_l00006oooo
o`;o00004oooool2o`0000?ooooo0_l00005ooooo`;o000000?oooooo`000?l000000_ooool;o`00
0004ooooool0003o0000o`0000kooooo0ol00006ooooo`;o00002Oooool2o`0000;ooooo0_l00006
ooooo`;o00001oooool3o`000003ooooool0003o000000Kooooo0_l00018ooooo`007?ooool00ol0
003oooooooooo`15ooooo`;o00000oooool2o`0000;ooooo0ol0000Rooooo`;o00000oooool2o`00
00?ooooo0_l00005ooooo`;o00001oooool2o`0000Gooooo0_l00004ooooo`;o00003_ooool=o`00
00;ooooo0ol0000?ooooo`Co00001?ooool2o`000004ooooool0003o0000o`0000Gooooo0_l00005
ooooo`?o00000_ooool2o`0000?ooooo0_l00003ooooo`;o00002Oooool4o`0004Kooooo000Loooo
o`03o`000?oooooooooo04Gooooo0_l00003ooooo`;o00000_ooool2o`0002?ooooo0_l00003oooo
o`;o00002_ooool2o`0000;ooooo0_l00002ooooo`?o00001Oooool3o`0000cooooo0_l00003oooo
o`ko00000_ooool2o`000003ooooool0003o000000;o00002?ooool2o`0000?ooooo0ol00007oooo
o`?o00003?ooool3o`0000Oooooo1_l0000<ooooo`;o0000A_ooool001cooooo00?o0000oooooooo
ool0A_ooool3o`0000[ooooo0ol0000booooo`;o000000?oooooo`000?l000000ol00005ooooo`;o
00003?ooool2o`0000?ooooo0_l000000ooooooo0000o`00000:o`000004ooooool0003o0000oooo
o`Co00002?ooool2o`0000Cooooo0_l0000Gooooo`Go00000_ooool2o`0000;ooooo1?l0000<oooo
o`;o0000A_ooool001cooooo00?o0000ooooooooool0A_ooool7o`0000Kooooo0ol0000Oooooo`?o
000000?oooooo`000?l000004?ooool2o`000003ooooool0003o000001_ooooo1_l000000ooooooo
0000o`000004o`0000?ooooo0_l00007ooooo`;o00006_ooool2o`0000Cooooo1Ol00002ooooo`;o
0000F_ooool001cooooo00?o0000ooooooooool0Aoooool6o`000003ooooool0003o000002Gooooo
0ol000000ooooooo0000o`00000aooooo`;o000000Coooooo`000?l0003ooooo1_l0000:ooooo`Co
00006Oooool3o`0000Gooooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l0001Eooooo`00
7?ooool00ol0003oooooooooo`13ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo
0_l0000Wooooo`;o00002_ooool2o`0002Kooooo3_l00002ooooo`;o000000?oooooo`000?l00000
0_ooool4o`0001?ooooo0_l00004ooooo`Co00001?ooool2o`000003ooooool0003o000000;o0000
0oooool3o`0005Gooooo000Looooo`03o`000?oooooooooo03[ooooo0_l00007ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0002_ooooo0_l00004ooooo`;o00001?ooool2o`0002Kooooo3_l0
0002ooooo`;o000000?oooooo`000?l000001?ooool4o`0000Kooooo0_l00003ooooo`;o00001?oo
ool2o`0000Gooooo0ol000000ooooooo0000o`00000;ooooo`Co00002_ooool2o`0000;ooooo0_l0
0014ooooo`007?ooool00ol0003oooooooooo`0jooooo`Co000000?oooooo`000?l000001?ooool3
o`0000;ooooo0_l0000aooooo`Co000000Goooooo`000?l0003o0000ooooo`02o`0000_ooooo0ol0
0008ooooo`;o00002?ooool2o`000003ooooool0003o000000co00003?ooool3o`0000Kooooo0_l0
0003ooooo`;o00003oooool2o`0000gooooo0_l00003ooooo`;o00001Oooool2o`0000;ooooo0_l0
0014ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool2o`000003oa0@
4?oooooooooo00Cooooo00?o0000ooooooooool0>Oooool2o`000004ooooool0003o0000ooooo`;o
00001?ooool3o`0000Sooooo0_l0000]ooooo`;o000000?oooooo`000?l000001?l0000;ooooo`Go
00001_ooool5o`0000Gooooo0_l00002ooooo`co000000?oooooo`000?l000004oooool2o`0000?o
oooo0_l00005ooooo`;o00000oooool2o`0000?ooooo0ol0000Aooooo`;o0000Coooool00006oooo
oomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0iooooo`;o00005Oooool2o`0002Sooooo0_l00003ooooo`;o00001?ooool2o`00
00oooooo0ol00004ooooo`;o000000?oooooo`000?l000000ol00007ooooo`co000000?oooooo`00
0?l000001?ooool2o`0001;ooooo0_l00002ooooo`;o000000?oooooo`000?l000001Ol000000ooo
oooo0000o`000003o`0001Sooooo0_l00018ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413o
ooooooooo`09ooooo`Go00001_ooool00ol0003oooooooooo`0nooooo`;o0000>_ooool2o`0000Ko
oooo0_l00006ooooo`;o00002oooool2o`0000?ooooo0ol000001?oooooo0000o`000?ooool2o`00
00Kooooo3?l00002ooooo`Co00000_ooool2o`0000?ooooo0_l0000=ooooo`?o000000Goooooo`00
0?l0003o0000ooooo`0;o`0001Oooooo1?l00018ooooo`0000?oooooo`000?ooool00_ooool00ol0
003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0000nooooo`;o0000>oooool2
o`0000Gooooo0_l00006ooooo`;o00001?ooool3o`0000Cooooo0_l00003ooooo`;o00000oooool2
o`0000Sooooo2ol00002ooooo`Go00001oooool2o`0000Wooooo0_l00003ooooo`;o000000Gooooo
o`000?l0003o0000ooooo`02o`0000?ooooo1_l00006ooooo`;o00001?ooool3o`0000Sooooo0_l0
0005ooooo`;o0000@oooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool0
1?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo03_ooooo0_l0000Jooooo`;o00008_oo
ool2o`0000;ooooo0_l00009ooooo`Co00000_ooool3o`0000?ooooo0ol00007ooooo`?o00001ooo
ool2o`0000Gooooo1_l000000ooooooo0000o`000002o`0001?ooooo0_l00006ooooo`;o000000Go
ooooo`000?l0003o0000ooooo`02o`0000;ooooo1?l00006ooooo`;o00001?ooool3o`000003oooo
ool0003o000000;o00002_ooool2o`0004?ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oo
oooooooo00[ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0kooooo`;o00006_oo
ool2o`0002Kooooo0_l000000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l000000_oo
ool3o`0000?ooooo0_l00008ooooo`?o00001_ooool3o`0000Gooooo2?l0000Eooooo`;o00001ooo
ool2o`000003ooooool0003o000000Go00000_ooool2o`0000Sooooo0_l00002ooooo`;o00000ooo
ool4o`0000Gooooo0_l00018ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<ooooo`03onk^
k_m4A4Co000000Oooooo00?o0000ooooooooool0>Oooool3o`00047ooooo0ol00002ooooo`;o0000
0oooool5o`0000Gooooo1_l00005ooooo`;o000000?oooooo`000?l000000_l00006ooooo`;o0000
2?ooool2o`0000;ooooo0_l0000Eooooo`Co00002Oooool3o`000003ooooool0003o000000Co0000
1oooool3o`0000;ooooo0_l00003ooooo`;o00001Oooool4o`0004Sooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`0iooooo`?o
0000@Oooool3o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000004ooooo`Oo
00000oooool4o`000004ooooool0003o0000o`0000Gooooo0_l00009ooooo`?o00004Oooool2o`00
00Cooooo4_l000000ooooooo0000o`000004o`0000Oooooo0_l00003ooooo`;o00000oooool2o`00
00Gooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`1nooooo`;o000000?oooooo`000?l0
00001_ooool4o`0000;ooooo1?l00003ooooo`;o00000_ooool5o`000003ooooool0003o000000;o
oooo0_l000001?oooooo0000o`000?l00007ooooo`?o00001_ooool2o`0000Sooooo1?l00004oooo
oaGo000000Goooooo`000?l0003o0000ooooo`04o`0000;ooooo1?l000000ooooooo0000o`00001F
ooooo`007?ooool00ol0003oooooooooo`16ooooo`;o00002oooool2o`0000Cooooo0_l0000Poooo
o`;o00000oooool2o`0000Kooooo1Ol00002ooooo`;o00000oooool6o`0000;ooooo0ol00005oooo
o`;o00000_ooool2o`0000Oooooo0_l00007ooooo`;o00002?ooool3o`0000;ooooo0_l00002oooo
oago00000_ooool4o`0000Cooooo0ol00008ooooo`;o0000B?ooool001cooooo00?o0000oooooooo
ool0A_ooool2o`0000_ooooo0_l00004ooooo`;o00008?ooool4o`000004ooooool0003o0000o`00
00?ooooo1?l00005ooooo`;o00000oooool2o`0000;ooooo0_l00007ooooo`;o000000?oooooo`00
0?l000000_l00003ooooo`;o00001?ooool3o`0001Gooooo0_l000000ooooooo0000o`00000Io`00
0003ooooool0003o000000[ooooo0ol00008ooooo`;o00000oooool2o`0004?ooooo000Looooo`03
o`000?oooooooooo03Wooooo0_l0000Hooooo`;o00002?ooool2o`0000Cooooo0_l0000Hooooo`;o
00000_ooool3o`0000;ooooo0_l0000>ooooo`;o00002Oooool3o`0000;ooooo1ol00004ooooo`?o
00006?ooool2o`000003ooooool0003o000000ko000000?oooooo`000?l000000oooool2o`0000Ko
oooo0_l00002ooooo`;o00000_ooool2o`0000Gooooo0_l000000ooooooo0000o`000003ooooo`;o
0000@oooool001cooooo00?o0000ooooooooool0<Oooool2o`0000Kooooo0_l0000Pooooo`Co0000
1?ooool2o`0001Sooooo0_l00003ooooo`;o00001?ooool2o`0000cooooo1?l00004ooooo`;o0000
0_ooool4o`0000;ooooo1?l0000?ooooo`;o00003_ooool2o`0000;ooooo5Ol000000ooooooo0000
o`000006ooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`Co000000?oooooo`000?l00000
B?ooool001cooooo00?o0000ooooooooool0<Oooool2o`0002Gooooo2?l0000Nooooo`;o00000_oo
ool2o`000004ooooool0003o0000ooooo`?o00001Oooool=o`000003ooooool0003o000000Cooooo
2?l000001?oooooo0000o`000?l0000;ooooo`Co00003?oooolNo`0000[ooooo1?l00003ooooo`;o
00000oooool2o`0004Sooooo000Looooo`03o`000?oooooooooo05Oooooo3?l000000ooooooo0000
o`00000Hooooo`;o00001Oooool2o`0000;ooooo0_l00005ooooo`oo00000_ooool3o`0000;ooooo
0ol00003ooooo`Ko00002oooool2o`0000Kooooo0_l00004ooooob3o00001_ooool4o`0000[ooooo
0_l00018ooooo`007?ooool00ol0003oooooooooo`0eooooo`;o00005oooool2o`0000Gooooo4Ol0
00000ooooooo0000o`00000Looooo`;o00002_ooool4o`0000;ooooo0_l00002ooooo`Wo00000_oo
ool4o`0000;ooooo0_l00002ooooo`;o00004_ooool4o`0000?ooooo8?l00006ooooo`Co00002_oo
ool2o`000003ooooool0003o000004Gooooo000Looooo`03o`000?oooooooooo03Gooooo0_l0000G
ooooo`;o00001?ooool@o`0000?ooooo0ol000000ooooooo0000o`00000@ooooo`;o00001?ooool2
o`0000cooooo0_l00005ooooo`;o000000?oooooo`000?l000002?l000000ooooooo0000o`000003
o`0000;ooooo0_l0000?ooooo`;o00001?ooool6o`000003ooooool0003o000001co00000oooool2
o`0001;ooooo1?l00015ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00006_oooolFo`00
0003ooooool0003o0000013ooooo0_l00004ooooo`;o00002oooool3o`0000Gooooo0ol00004oooo
o`Oo000000?oooooo`000?l000000_l000001?oooooo0000o`000?l0000?ooooo`?o00001OoooolS
o`0000?ooooo0_l0000Booooo`;o000000?oooooo`000?l000000oooool3o`0003kooooo000Loooo
o`03o`000?oooooooooo03Gooooo1Ol0000Eooooo`;o00000_ooool5o`0000;ooooo4?l00004oooo
o`;o00003?ooool2o`0000Gooooo0_l0000;ooooo`Go00001?ooool2o`0000Gooooo1_l000001?oo
oooo0000o`000?ooool4o`00017ooooo0_l00008ooooo`Co000000?oooooo`000?l000005_l00002
ooooo`;o00000_ooool3o`00017ooooo0_l000000ooooooo0000o`000002o`000004ooooool0003o
0000o`0003kooooo000Looooo`;o0000;?ooool2o`0000Sooooo0ol00004ooooo`;o00001Oooool2
o`0000Sooooo1?l000000ooooooo0000o`00000?o`000003ooooool0003o000000Co00001?ooool2
o`0000cooooo0_l00005ooooo`;o00002_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002
ooooo`;o00000_ooool2o`0000?ooooo1Ol00002ooooo`Co00006_ooool2o`000003ooooool0003o
000001So00000oooool7o`00017ooooo0_l00003ooooo`;o0000@_ooool001cooooo00?o0000oooo
ooooool0:oooool2o`0000oooooo0_l00005ooooo`;o00002?oooolNo`0000;ooooo0ol00007oooo
o`;o00002?ooool2o`0000cooooo0_l00005ooooo`;o00000_ooool2o`000005ooooool0003o0000
o`000?ooool00_l000000ooooooo0000o`00000:o`00013ooooo0_l00004ooooo`Co000000?ooooo
o`000?l000006Ol00004ooooo`;o00001?ooool2o`0005Oooooo000Looooo`03o`000?oooooooooo
02[ooooo0_l0000Soooooaco00000_ooool3o`0000Oooooo0_l00008ooooo`Co00006?ooool2o`00
00;ooooo0_l00004ooooo`Ko000000Coooooo`000?l0003o00003oooool2o`000003ooooool0003o
000000?o00000ooooolMo`0000Sooooo0_l0000Aooooo`;o0000A?ooool001cooooo00?o0000oooo
ooooool0:_ooool2o`0000cooooo0_l0000Goooooa7o000000?oooooo`000?l000002Ol00002oooo
o`;o00003oooool4o`0001Cooooo0ol00003ooooo`Co00001_ooool8o`000003ooooool0003o0000
00oooooo0ol000001Ooooooo0000o`000?l0003ooooo01[o000000?oooooo`000?l000000oooool2
o`0001Kooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00003?ooool2o`00
00Sooooo7_l000001?oooooo0000o`000?l0000Aooooo`?o000000?oooooo`000?l000002Oooool2
o`0000?ooooo1Ol00003ooooo`Co00000_ooool2o`0000;ooooo1ol00002ooooo`;o00004Oooool5
o`000004ooooool0003o0000oooooaWo00001?ooool2o`0005cooooo000Looooo`03o`000?oooooo
oooo04Kooooo0_l00004ooooo`;o000000?oooooo`000?l000007Ol000000ooooooo0000o`00000B
ooooo`?o000000?oooooo`000?l000002Oooool2o`0000?ooooo0_l000000ooooooo0000o`000003
ooooo`?o00000oooool2o`0000Kooooo0_l00006ooooo`;o00003_ooool2o`000003ooooool0003o
000000?ooooo6_l00004ooooo`Ko0000F?ooool001cooooo00?o0000ooooooooool0?_ooool2o`00
00cooooo0_l000000ooooooo0000o`00000Mo`0002Cooooo0_l00003ooooo`Go00000oooool6o`00
00[ooooo0_l00004ooooo`;o00004OoooolKo`0000[ooooo1?l00008ooooo`;o0000C_ooool001co
oooo00?o0000ooooooooool0?_ooool2o`00017ooooo7?l00003ooooo`Co00001_ooool2o`0001go
oooo0ol00004ooooo`Go000000?oooooo`000?l000001oooool2o`0001Wooooo6ol0000:ooooo`;o
00002?ooool2o`0004kooooo000Looooo`03o`000?oooooooooo04gooooo3?l000000ooooooo0000
o`00000Ao`0000?ooooo1?l00006ooooo`;o00009?ooool2o`0000Cooooo0_l00002ooooo`;o0000
5oooool2o`0000Gooooo0_l00002oooooaOo00002?ooool2o`0000[ooooo0_l0000Eooooo`;o0000
=oooool001cooooo00?o0000ooooooooool0=Oooool2o`000003ooooool0003o000001?ooooo7_l0
00000ooooooo0000o`000003ooooo`;o00000oooool2o`0000;ooooo0_l0000Sooooo`Co00001?oo
ool5o`0001Oooooo0_l000001?oooooo0000o`000?ooool4o`0000;ooooo4?l00002ooooo`;o0000
2_ooool2o`0000Wooooo0_l0000Fooooo`Co0000=Oooool001cooooo00?o0000ooooooooool09_oo
ool2o`0000gooooo0_l000000ooooooo0000o`00000Dooooob3o00002?ooool2o`0000cooooo0_l0
000Iooooo`Co00001?ooool3o`0000Kooooo0ol0000CoooooaWo00006Oooool2o`0001;ooooo0_l0
0004ooooo`;o0000=Oooool001cooooo00?o0000ooooooooool09_ooool2o`0001oooooo0_l00009
oooooago00005Oooool2o`0001Oooooo0_l000001?oooooo0000o`000?l00007ooooo`;o00001?oo
ool5o`0000Gooooo1?l0000:oooooaOo00001oooool3o`0002?ooooo0_l0000kooooo`007?ooool0
0ol0003oooooooooo`0oooooo`;o00001_ooool2o`0000[ooooo7?l0000Hooooo`;o00002?ooool2
o`0000Oooooo0_l000000ooooooo0000o`00000;ooooo`;o00001?ooool2o`000003ooooool0003o
000000Gooooo1?l0000?ooooo`Co000000?oooooo`000?l000002ol00007ooooo`?o00000_ooool2
o`0001Cooooo1?l0000;ooooo`;o0000=oooool001cooooo00?o0000ooooooooool0=Oooool2o`00
00Sooooo0ol0000AoooooaWo000000?oooooo`000?l000001_ooool2o`000003ooooool0003o0000
00[ooooo0_l000000ooooooo0000o`000008ooooo`;o00001oooool2o`000003ooooool0003o0000
02Oooooo0ol000000ooooooo0000o`000005ooooo`_o00001Oooool2o`0000Sooooo0_l0000Doooo
o`Co00002oooool2o`0003Oooooo000Looooo`03o`000?oooooooooo033ooooo0_l00002ooooo`?o
00002?ooool3o`00013ooooo0_l000000ooooooo0000o`00000Go`000003ooooool0003o000000Co
oooo0_l000000ooooooo0000o`000003ooooo`;o00001Oooool2o`000003ooooool0003o000001Co
oooo0_l00008ooooo`Go00003Oooool2o`0000_ooooo0ol000000ooooooo0000o`000004ooooo`?o
00000_ooool7o`0000Gooooo0_l00005ooooo`;o00005oooool2o`0000Sooooo0_l0000looooo`00
7?ooool00ol0003oooooooooo`0`ooooo`;o00000_ooool2o`0000[ooooo0_l00003ooooo`;o0000
0oooool2o`0000Kooooo0_l00002ooooo`ko000000?oooooo`000?l000001ol000000ooooooo0000
o`00000<ooooo`;o00001?ooool2o`0000_ooooo0_l00007ooooo`;o00003?ooool5o`0000[ooooo
0_l000000ooooooo0000o`000002o`0000[ooooo0_l000000ooooooo0000o`000004ooooo`;o0000
00?oooooo`000?l000000_l0000Aooooo`;o00008Oooool2o`0003cooooo000Looooo`;o0000<Ooo
ool2o`0000kooooo0_l000000ooooooo0000o`000007o`0000[ooooo5_l000000ooooooo0000o`00
0002o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Cooooo0_l0
0005ooooo`;o00001oooool2o`0000;ooooo0_l0000;ooooo`;o000000?oooooo`000?l000001ooo
ool2o`0000?ooooo1?l00006ooooo`;o00001_ooool2o`0000Cooooo0_l00008ooooo`;o00001ooo
ool2o`0000Wooooo1_l0000Booooo`?o0000?Oooool001cooooo00?o0000ooooooooool0>_ooool2
o`0000Oooooo0_l00002ooooo`Co00003?oooolHo`0000?ooooo1?l00003ooooo`;o000000?ooooo
o`000?l000000_ooool2o`000003ooooool0003o000000?o000000?oooooo`000?l000000_l00009
ooooo`;o000000?oooooo`000?l000000_ooool2o`0000_ooooo0_l000000ooooooo0000o`000002
ooooo`?o000000?oooooo`000?l000000ol00003ooooo`?o00001Oooool2o`0000Kooooo0_l00002
ooooo`;o00002_ooool2o`0000Oooooo0_l00009ooooo`So00004?ooool3o`0003gooooo000Loooo
o`03o`000?oooooooooo03[ooooo0_l0000Aooooo`;o00002?oooolFo`0000Gooooo0_l00004oooo
o`;o00001_ooool2o`0000;ooooo1?l00003ooooo`;o00002Oooool2o`000003ooooool0003o0000
00;ooooo0_l0000Booooo`?o000000Coooooo`000?l0003ooooo0_l00003ooooo`?o00003oooool4
o`0000Sooooo1_l0000:ooooo`;o00001?ooool2o`0000Cooooo0_l00009ooooo`Co00001?ooool2
o`0003gooooo000Looooo`03o`000?oooooooooo03?ooooo0_l0000Hooooo`;o00002?ooool2o`00
0004ooooool0003o0000ooooo`co000000Coooooo`000?l0003o00001oooool6o`0000Gooooo0_l0
0002ooooo`?o00005oooool2o`0000Oooooo1?l00008ooooo`;o00001oooool4o`000003ooooool0
003o000000gooooo0_l00002ooooo`;o00001?ooool5o`000003ooooool0003o000000[ooooo0_l0
0004ooooo`;o00001?ooool2o`0000Kooooo0_l000000ooooooo0000o`000002o`0000?ooooo0ol0
000mooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00003Oooool2o`0000?ooooo0_l0000A
ooooo`oo000000Coooooo`000?l0003ooooo1Ol00002ooooo`Co00001oooool2o`0000;ooooo0_l0
000Hooooo`;o00000oooool2o`0000;ooooo1?l00008ooooo`;o00001Oooool4o`0000?ooooo0_l0
00000ooooooo0000o`000005ooooo`Co00001?ooool3o`0000Cooooo0_l000000ooooooo0000o`00
0002ooooo`;o00007Oooool2o`0000Oooooo0ol00004ooooo`;o0000>?ooool001cooooo00?o0000
ooooooooool0@_ooool2o`0000?ooooo0_l0000:ooooo`;o00001_ooool2o`0000?ooooo1ol00006
ooooo`Go000000?oooooo`000?l000002_ooool6o`0000?ooooo0_l0000Eooooo`;o000000Cooooo
o`000?l0003ooooo0_l0000Booooo`Co00001_ooool2o`0000Gooooo1Ol00003ooooo`;o00000_oo
ool2o`000003ooooool0003o000000Gooooo0_l00006ooooo`;o00004_ooool2o`0000Kooooo0_l0
0002ooooo`?o00000oooool3o`0003Sooooo000Looooo`03o`000?oooooooooo037ooooo0_l0000E
ooooo`;o00002Oooool2o`0000[ooooo2?l0000<ooooo`;o00002_ooool4o`0000Gooooo0_l0000<
ooooo`;o00000_ooool4o`000003ooooool0003o000000;o00000_ooool2o`0001Cooooo0_l00005
ooooo`;o00002Oooool2o`0000Gooooo1?l00008ooooo`;o00001_ooool2o`0000?ooooo0_l0000<
ooooo`?o00001_ooool2o`0000;ooooo0ol00003ooooo`;o0000>Oooool001cooooo00?o0000oooo
ooooool0<Oooool2o`0001Gooooo0_l00002ooooo`;o00001?ooool2o`0000;ooooo1?l00005oooo
o`So00001?ooool2o`0000Gooooo0_l00004ooooo`;o00001Oooool2o`0001Gooooo0ol000000ooo
oooo0000o`000002o`000003ooooool0003o000000;o00001oooool2o`0001Kooooo0_l00005oooo
o`;o00002Oooool2o`0000[ooooo0_l00004ooooo`?o00001?ooool2o`0000cooooo0_l00007oooo
o`;o000000Coooooo`000?l0003o00000_ooool2o`0003_ooooo000Looooo`03o`000?oooooooooo
04cooooo0ol00003ooooo`;o00000_ooool4o`0000Kooooo1Ol00006ooooo`;o00001Oooool2o`00
00Cooooo0_l000000ooooooo0000o`000003o`0000Kooooo0ol0000>ooooo`;o00001_ooool6o`00
00Gooooo0_l00007ooooo`;o00002?ooool4o`0000Sooooo0_l0000>ooooo`;o00002oooool3o`00
01gooooo0ol00003ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0A?ooool2o`0000Oo
oooo1?l0000:ooooo`;o00001?ooool4o`0000Sooooo0_l0000<ooooo`Go00001_ooool3o`0000ko
oooo0_l00008ooooo`Ko00003?ooool2o`0000Sooooo1?l0000Fooooo`Co00001?ooool2o`0002Go
oooo0_l00004ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0;Oooool2o`0000oooooo
0_l00004ooooo`;o00000oooool2o`0000Cooooo0_l0000:ooooo`;o00000_ooool2o`0000;ooooo
0_l00008ooooo`;o00002Oooool2o`0000;ooooo0ol00002ooooo`;o00001?ooool2o`0000kooooo
0ol00008ooooo`;o000000?oooooo`000?l000003_ooool2o`0000Sooooo0_l0000Booooo`Ko0000
1?ooool4o`0000;ooooo0_l0000Nooooo`;o00001oooool2o`0003_ooooo000Looooo`03o`000?oo
oooooooo02gooooo0_l00003ooooo`;o00002_ooool2o`0000Wooooo0_l0000>ooooo`;o00001?oo
ool5o`0000Oooooo1?l00005ooooo`;o000000Coooooo`000?l0003o00001oooool2o`0000Cooooo
0_l0000:ooooo`;o00000_ooool3o`0001_ooooo1?l00006ooooo`;o00003Oooool2o`0000?ooooo
1Ol00005ooooo`;o00001?ooool2o`0001kooooo0_l00014ooooo`007?ooool00ol0003ooooooooo
o`0booooo`;o00002_ooool2o`0001Wooooo0_l00006ooooo`Ko00001?ooool4o`0000Gooooo1_l0
000Dooooo`;o00000oooool2o`0000;ooooo0ol00006ooooo`Co00003?ooool4o`0000?ooooo0_l0
0002ooooo`;o00000_ooool2o`0000[ooooo0_l000000ooooooo0000o`000006ooooo`;o0000LOoo
ool001cooooo00?o0000ooooooooool0=oooool2o`0002_ooooo1?l000000ooooooo0000o`000008
o`000003ooooool0003o000000Co00004?ooool2o`0000;ooooo0_l00003ooooo`;o00001oooool2
o`000003ooooool0003o000000?o00003?ooool4o`0000?ooooo2?l00004ooooo`Co00001?ooool2
o`0007cooooo000Looooo`03o`000?oooooooooo03Gooooo1?l00009ooooo`;o00008_ooool2o`00
0003ooooool0003o000000So000000?oooooo`000?l000003_ooool2o`0000Cooooo0_l00007oooo
o`;o00001oooool2o`000003ooooool0003o000000_ooooo0_l00006ooooo`Oo000000Coooooo`00
0?l0003o00001?ooool4o`0000?ooooo0_l000000ooooooo0000o`000007ooooo`;o00001oooool2
o`0002_ooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0eooooo`;o00002?ooool2o`00
0003ooooool0003o0000023ooooo0_l0000:ooooo`;o00004_ooool2o`0001Gooooo0_l000000ooo
oooo0000o`00000;ooooo`So000000?oooooo`000?l000000ol000000ooooooo0000o`000005o`00
00;ooooo0_l00005ooooo`;o000000?oooooo`000?l000001_ooool3o`0000Oooooo0_l00009oooo
o`;o00003oooool4o`0000gooooo0_l0000kooooo`007?ooool2o`00043ooooo0_l0000Sooooo`;o
00002_ooool2o`0001cooooo0_l0000;ooooo`;o000000?oooooo`000?l000002oooool9o`000003
ooooool0003o000000;ooooo1Ol000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l0
00000_ooool2o`0000Wooooo0_l00004ooooo`;o00003Oooool2o`0000oooooo1?l0001:ooooo`00
7?ooool00ol0003oooooooooo`0Wooooo`;o0000IOooool2o`0000Wooooo0ol00006ooooo`;o0000
2Oooool2o`0000?ooooo0_l000001Ooooooo0000o`000?l0003ooooo00Go00002?ooool2o`0000;o
oooo0_l00003ooooo`;o00002_ooool2o`0001kooooo0_l000000ooooooo0000o`000006ooooo`;o
00000oooool2o`0000Wooooo0_l0000aooooo`007?ooool00ol0003oooooooooo`0Wooooo`;o0000
=oooool2o`0000[ooooo0_l0000[ooooo`?o00001_ooool2o`0001;ooooo0_l0000<ooooo`;o0000
1Oooool6o`0000;ooooo0_l0000Dooooo`;o00004oooool2o`0000;ooooo0_l00002ooooo`;o0000
0oooool2o`0000Wooooo0_l0000aooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o00002_oo
ool2o`0000kooooo0_l0000;ooooo`;o00003_ooool2o`0000Wooooo0_l0000>ooooo`;o00000_oo
ool2o`0000Oooooo0_l000000ooooooo0000o`000005ooooo`Co00000_ooool6o`0000_ooooo0_l0
0004ooooo`?o00004oooool3o`000003ooooool0003o000004Gooooo000Looooo`03o`000?oooooo
oooo03Sooooo0_l00004ooooo`;o00001_ooool2o`0001[ooooo0_l0000Hooooo`?o00000oooool2
o`0000Gooooo0_l0000?ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Kooooo0_l00006
ooooo`;o00000_ooool2o`0000Oooooo0ol0000=ooooo`;o000000Coooooo`000?l0003o00002ooo
ool2o`0000Cooooo0_l0000Eooooo`;o00002_ooool2o`0003cooooo000Looooo`03o`000?oooooo
oooo03Sooooo0_l00004ooooo`;o00001?ooool4o`0001[ooooo0_l00003ooooo`;o00004oooool3
o`0000?ooooo0_l00005ooooo`;o00001_ooool2o`0000Oooooo0_l000000ooooooo0000o`00000=
ooooo`Ko000000?oooooo`000?l000001?ooool2o`0000Kooooo0ol0000Dooooo`;o0000:?ooool2
o`0000Oooooo0_l0000looooo`007?ooool00ol0003oooooooooo`14ooooo`;o00008Oooool2o`00
00Kooooo0_l0000;ooooo`;o00001?ooool2o`0000Gooooo0_l00006ooooo`;o00004Oooool2o`00
00?ooooo0_l00003ooooo`Oo000000?oooooo`000?l000000ol00006ooooo`;o00005Oooool2o`00
02Oooooo1Ol00013ooooo`007?ooool00ol0003oooooooooo`0Wooooo`;o0000>_ooool2o`0000[o
oooo0_l0000Oooooo`;o00001?ooool2o`0000Sooooo0_l00002ooooo`;o00000oooool2o`0000;o
oooo3_l00008ooooo`?o00001Oooool2o`0000Oooooo0_l0000[ooooo`;o000000?oooooo`000?l0
0000@oooool001cooooo00?o0000ooooooooool09oooool2o`0000oooooo0_l0000Yooooo`;o0000
3Oooool3o`0000Cooooo0_l000000ooooooo0000o`00000Booooo`;o00001?ooool2o`0000Kooooo
1?l00004ooooo`;o00000ooooolAo`0000Cooooo1_l00003ooooo`Co00001oooool2o`00013ooooo
0_l0000Gooooo`?o000000Coooooo`000?l0003o0000@oooool001cooooo00?o0000ooooooooool0
>?ooool2o`0003Gooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l000000ooooooo0000
o`000005ooooo`?o00006?ooool2o`000004ooooool0003o0000ooooob3o000000Goooooo`000?l0
003o0000ooooo`03o`0001[ooooo0_l0000Fooooo`So0000@oooool001cooooo00?o0000oooooooo
ool0B?ooool2o`0002;ooooo0_l000000ooooooo0000o`000003ooooo`Co00001?ooool2o`0000Go
oooo0ol000000ooooooo0000o`00000Aooooo`Co00000ooooolQo`0000?ooooo0ol000000ooooooo
0000o`000003o`0000Sooooo0ol0000Uooooo`?o000000?oooooo`000?l000001oooool2o`0003co
oooo000Looooo`03o`000?oooooooooo04Sooooo0_l0000Kooooo`Co00000oooool2o`0000Sooooo
0_l00004ooooo`;o00001_ooool2o`000003ooooool0003o000000Sooooo0_l00007ooooo`Co0000
1?ooool4o`000003ooooool0003o000001Co00002?ooool2o`0000Cooooo0ol00008ooooo`?o0000
9Oooool2o`0000Wooooo1?l0000looooo`007?ooool00ol0003oooooooooo`0hooooo`;o00009?oo
ool2o`0000Gooooo1?l0000Kooooo`;o00002oooool2o`0000Gooooo0_l00008ooooo`Co00000_oo
oolEo`0000Kooooo1?l00004ooooo`?o00000_ooool2o`0000Cooooo0_l00008ooooo`;o00006Ooo
ool2o`0000?ooooo0_l00007ooooo`?o0000?Oooool001cooooo00?o0000ooooooooool0>?ooool2
o`0000kooooo0_l00003ooooo`;o00003oooool2o`0000Gooooo0ol000001?oooooo0000o`000?oo
ool2o`0001Sooooo0_l000000ooooooo0000o`00000=ooooo`;o00002Oooool4o`000003ooooool0
003o000001Co00000_ooool2o`000003ooooool0003o000000;o00002Oooool2o`0000Cooooo0_l0
0004ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`0001?ooooo0_l00003ooooo`;o0000
1Oooool2o`000003ooooool0003o000003gooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGo
oooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0boooo
o`;o00004?ooool2o`0000;ooooo0ol00002ooooo`;o00003_ooool3o`0000Gooooo2ol0000Foooo
o`;o000000?oooooo`000?l000002?ooool4o`0000Gooooo0_l00005oooooaoo000000Coooooo`00
0?l0003o00002_ooool2o`0000;ooooo0_l00005ooooo`?o000000Coooooo`000?l0003ooooo0_l0
0002ooooo`;o00004oooool2o`0000[ooooo0_l00007ooooo`;o0000=oooool00006oooooomgMgOo
V9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03
o`000?oooooooooo02kooooo0_l00002ooooo`;o00001_ooool4o`0000Kooooo0_l00003ooooo`;o
00004_ooool3o`0000;ooooo0_l00002ooooo`co00008Oooool4o`0000;ooooo0_l000000ooooooo
0000o`000002ooooobGo00002oooool2o`0000;ooooo0_l00003ooooo`Co00001Oooool2o`0001Ko
oooo0_l00005ooooo`;o00003Oooool2o`0003Oooooo00000ooooooo410@ooooo`02ooooo`03oa0@
4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo02ko
oooo0_l00007ooooo`;o000000?oooooo`000?l000000_l0000Sooooo`?o000000Goooooo`000?l0
003o0000ooooo`09o`0002Oooooo1_l000000ooooooo0000o`00000Mo`000003ooooool0003o0000
00?o00005?ooool2o`0001oooooo0_l000001?oooooo0000o`000?ooool3o`0000;ooooo0_l00012
ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9Sooooo
oiRHV?lQ8B401_ooool3o`0002Sooooo0_l0000=ooooo`;o00000_ooool2o`0002Cooooo4_l00007
ooooo`?o00004_ooool4o`0000Gooooo2?l00003ooooo`?o000000?oooooo`000?l000007?l00004
ooooo`;o00005Oooool2o`0000?ooooo0_l0000Cooooo`So00000oooool2o`0004;ooooo00000ooo
oooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006
ooooo`03o`000?oooooooooo02Sooooo0_l0000?ooooo`;o000000?oooooo`000?l000007_ooool5
o`000003ooooool0003o000001;o00001?ooool3o`0001;ooooo2?l000000ooooooo0000o`000002
o`000005ooooool0003o0000o`000?ooool09?l00004ooooo`Co000000?oooooo`000?l000004?oo
ool2o`0000?ooooo0_l0000Eooooo`;o000000?oooooo`000?l00000B?ooool00003ooooool@413o
oooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooo
oooo03Wooooo0_l000000ooooooo0000o`00000Noooooa[o000000?oooooo`000?l000000oooool2
o`0000;ooooo0_l00005ooooo`;o00001Oooool2o`000003ooooool0003o000000Co00001?ooool4
o`000003ooooool0003o000002Ko00000oooool2o`000004ooooool0003o0000o`0000Kooooo0ol0
000Uooooo`;o0000B?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@
oiRHV008ooooo`03o`000?oooooooooo05[ooooo0_l00004oooooa[o00000_ooool2o`0000;ooooo
0_l00005ooooo`;o00001Oooool2o`0000;ooooo1?l00005ooooo`Co000000?oooooo`000?l00000
9_l00007ooooo`;o00000oooool8o`0000Sooooo0_l0001Sooooo`0000Koooooonk^k_lb<S;o0000
oc8b<_o^k^h<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0?Oooool2o`00
00?ooooo0_l00006ooooo`;o00001?ooool2o`0000Oooooo1?l00002oooooa_o00001_ooool3o`00
00Gooooo0_l00003ooooo`;o00001Oooool3o`0000Cooooo9ol000000ooooooo0000o`000004o`00
00_ooooo1Ol000000ooooooo0000o`000007ooooo`?o00007?ooool2o`0004Gooooo000Looooo`03
o`000?oooooooooo03gooooo0_l00003ooooo`;o00001_ooool2o`000004ooooool0003o0000oooo
o`;o00001ooooolPo`0000Oooooo0ol00005ooooo`;o00000oooool2o`0000Kooooo0_l00003oooo
obco000000?oooooo`000?l000001_ooool2o`0000Cooooo0ol000001?oooooo0000o`000?l00002
ooooo`;o00000oooool2o`0001_ooooo1?l00015ooooo`007?ooool00ol0003oooooooooo`0doooo
o`;o00005oooool2o`0000Wooooo0_l00003oooooa[o00000oooool2o`0001Gooooo0ol00006oooo
o`;o000000?oooooo`000?l000000ol000000ooooooo0000o`00000Ro`0000Sooooo0_l00005oooo
o`;o000000?oooooo`000?l000000oooool2o`00023ooooo0_l00017ooooo`007?ooool00ol0003o
ooooooooo`0dooooo`;o00008_ooool2o`0000Cooooo6ol000000ooooooo0000o`00000:ooooo`;o
00002Oooool3o`000003ooooool0003o000000;ooooo0_l00002ooooob;o000000?oooooo`000?l0
00001_l0000>ooooo`;o00000oooool2o`0002?ooooo1?l00015ooooo`007?ooool00ol0003ooooo
ooooo`1Ooooooa[o00001oooool4o`0000;ooooo0_l00009ooooo`;o00000_ooool2o`0000;ooooo
0_l000000ooooooo0000o`000006o`000003ooooool0003o0000027o00004oooool2o`0002;ooooo
1Ol00015ooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00009?ooool2o`0000Kooooo7_l0
0003ooooo`Ko00002oooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000002?l0
0003oooooago00003_ooool2o`0000Wooooo0_l0000Hooooo`?o00000oooool2o`0004Sooooo000L
ooooo`03o`000?oooooooooo037ooooo1?l0000=ooooo`;o00004oooool2o`0000Sooooo7?l00004
ooooo`;o000000?oooooo`000?l000004Oooool<o`000003ooooool0003o000002;o00000oooool2
o`0000Oooooo0_l00008ooooo`?o00004_ooool3o`0000?ooooo0ol0001=ooooo`007?ooool00ol0
003oooooooooo`0cooooo`;o00003?ooool3o`0000cooooo0_l0000;ooooo`;o00000ooooolGo`00
0004ooooool0003o0000ooooo`;o00000_ooool4o`0000oooooo0_l000000ooooooo0000o`00000A
o`000003ooooool0003o000001;o000000?oooooo`000?l000001_l00003ooooo`;o00001_ooool4
o`000003ooooool0003o000000Cooooo0_l0000Cooooo`?o00000oooool2o`0004kooooo000Loooo
o`03o`000?oooooooooo03?ooooo0_l0000<ooooo`;o00003Oooool2o`0000_ooooo0_l00007oooo
oa[o00000oooool2o`0000cooooo1Ol000000ooooooo0000o`000004o`000003ooooool0003o0000
02Co00001Oooool6o`0000Cooooo1?l000000ooooooo0000o`00000Tooooo`;o00001oooool2o`00
043ooooo000Looooo`03o`000?oooooooooo03Gooooo0_l0000Oooooo`;o00000oooool2o`0000?o
oooo0_l00006oooooa?o000000?oooooo`000?l000000_l00003ooooo`;o00000_ooool2o`000003
ooooool0003o000000;o00000oooool4o`0000Cooooo0_l00002ooooo`Wo000000?oooooo`000?l0
00006ol00005ooooo`;o000000Coooooo`000?l0003o00000oooool4o`0002Gooooo0_l000000ooo
oooo0000o`000007ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0=Oooool2o`0000;o
oooo0_l00003ooooo`;o00005_ooool2o`0000?ooooo0_l00003ooooo`;o00000_ooool2o`0000?o
oooo3_l00003ooooo`Go00002?ooool2o`000003ooooool0003o000000;o00000oooool2o`0000Ko
oooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000001ko000000?oooooo`000?l0
00002?ooool2o`0000?ooooo1?l0000Uooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0
<_ooool4o`0000?ooooo0_l00003ooooo`;o00008Oooool2o`000003ooooool0003o000000?ooooo
2Ol000001?oooooo0000o`000?l00004ooooo`Co00003Oooool2o`0000oooooo1_l00002oooooago
00000_ooool2o`0000Sooooo1?l000000ooooooo0000o`000002o`0000Sooooo0_l0001Yooooo`00
7?ooool2o`0003?ooooo1?l0000[ooooo`Co00000oooool2o`0000Cooooo1ol00002ooooo`;o0000
1?ooool4o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o00001oooool2o`0000Wooooo
8_l0000>ooooo`;o000000?oooooo`000?l000001?l00003ooooo`Go00005_ooool2o`0000Oooooo
0_l00003ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0F_ooool2o`0000Kooooo0ol0
0003ooooo`;o00001Oooool2o`000004ooooool0003o0000o`0000;ooooo0_l000001?oooooo0000
o`000?ooool4o`0000;ooooo0_l000000ooooooo0000o`00000<ooooo`;o000000Coooooo`000?l0
003o00000oooool2o`0000;ooooo3Ol000000ooooooo0000o`000009o`000003ooooool0003o0000
00;o00003Oooool2o`000004ooooool0003o0000ooooo`;o000000Coooooo`000?l0003o00000ooo
ool4o`00013ooooo0_l00004ooooo`?o000000?oooooo`000?l000001?ooool2o`0000?ooooo0_l0
0013ooooo`007?ooool00ol0003oooooooooo`1Hooooo`Co00004oooool2o`000004ooooool0003o
0000o`0000;ooooo2Ol00007ooooo`;o00003_ooool3o`0000?ooooo0_l00002oooooako00003Ooo
ool4o`0000;ooooo0_l00003ooooo`;o00001?ooool2o`00013ooooo0_l00004ooooo`;o00000_oo
ool2o`0004kooooo000Looooo`03o`000?oooooooooo03Wooooo0_l0000Mooooo`;o00004_ooool2
o`000004ooooool0003o0000ooooo`Wo000000Coooooo`000?l0003o00002?ooool2o`0000cooooo
0ol00008ooooo`Go000000?oooooo`000?l000003Ol000000ooooooo0000o`000004o`0000Oooooo
0_l00009ooooo`;o00000_ooool7o`00073ooooo000Looooo`03o`000?oooooooooo03Gooooo0_l0
0002ooooo`;o0000<Oooool2o`0000Kooooo1?l00003ooooo`;o00005?ooool2o`0000;ooooo0ol0
0003ooooo`;o00000oooool3o`000003ooooool0003o000000go000000Coooooo`000?l0003ooooo
1Ol00007ooooo`;o00003oooool4o`00077ooooo000Looooo`03o`000?oooooooooo03Gooooo0_l0
0005ooooo`;o00000oooool2o`0003Sooooo0_l00008ooooo`Co00002?ooool2o`0000;ooooo1?l0
0002ooooo`;o00001OoooolAo`000003ooooool0003o000000?ooooo0ol0000Pooooo`;o00005Ooo
ool2o`000003ooooool0003o0000057ooooo000Looooo`03o`000?oooooooooo03[ooooo1?l00003
ooooo`;o00005_ooool2o`000003ooooool0003o000000_ooooo0_l0000=ooooo`;o00000_ooool4
o`0000Gooooo1?l0000;ooooo`Go00000oooool2o`0000?ooooo1ol00002ooooo`Co000000?ooooo
o`000?l000000_l00003ooooo`;o000000?oooooo`000?l000003?ooool2o`0000kooooo0_l00003
ooooo`;o00005Oooool2o`000003ooooool0003o000000?ooooo0_l0001<ooooo`007?ooool00ol0
003oooooooooo`0jooooo`;o00001_ooool2o`0001Gooooo0_l000000ooooooo0000o`000007oooo
o`;o00000_ooool2o`000003ooooool0003o000000Wooooo0ol00002ooooo`Co00000oooool2o`00
00oooooo1?l00004ooooo`;o00000oooool3o`000005ooooool0003o0000o`000?ooool00ol00003
ooooo`?o00000_ooool4o`000003ooooool0003o000000?ooooo0ol00006ooooo`;o00003_ooool2
o`0000?ooooo0_l0000Mooooo`;o000000?oooooo`000?l00000BOooool001cooooo00?o0000oooo
ooooool0=Oooool2o`0000_ooooo0_l0000Dooooo`;o00002oooool2o`0000Gooooo0_l00009oooo
o`Go00001oooool3o`0000;ooooo0_l0000<ooooo`;o00000_ooool2o`0000Gooooo1_l000001?oo
oooo0000o`000?l00003ooooo`;o00001?ooool5o`0000Gooooo0ol0000Nooooo`;o00002?ooool4
o`00017ooooo0_l00019ooooo`007?ooool00ol0003oooooooooo`0eooooo`;o00001Oooool2o`00
01[ooooo0_l0000Hooooo`;o00000oooool5o`0000Sooooo0_l00002ooooo`;o00004?ooool3o`00
00;ooooo2?l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000;ooooo1ol00008
ooooo`?o00006_ooool3o`0000Kooooo1_l00004ooooo`;o0000E_ooool001cooooo00?o0000oooo
ooooool0??ooool2o`0003Cooooo0_l00003ooooo`Go00000oooool4o`0000?ooooo0_l000000ooo
oooo0000o`00000@ooooo`;o00000_ooool2o`000003ooooool0003o000000?o000000Coooooo`00
0?l0003ooooo3_l000000ooooooo0000o`000005ooooo`?o00002Oooool2o`0000Cooooo0_l00009
ooooo`;o00001oooool2o`0000Sooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`1Ioooo
o`;o00002?ooool2o`0001;ooooo0_l000000ooooooo0000o`000003ooooo`Ko000000Coooooo`00
0?l0003ooooo0_l000000ooooooo0000o`000009ooooo`;o00002_ooool7o`000003ooooool0003o
000000co000000Coooooo`000?l0003ooooo1?l0000<ooooo`;o00001?ooool2o`0000Sooooo0_l0
000Fooooo`;o00001?ooool2o`0004cooooo000Looooo`03o`000?oooooooooo037ooooo0_l00005
ooooo`;o00007oooool2o`0000Sooooo0_l000001?oooooo0000o`000?l0000Iooooo`?o000000?o
ooooo`000?l000000ol000000ooooooo0000o`000009ooooo`;o00002Oooool3o`000003ooooool0
003o000000Go00000_ooool6o`0000Sooooo1?l0000Looooo`;o00003_ooool3o`0000Gooooo0_l0
0004ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0<Oooool2o`0000Gooooo0_l0000/
ooooo`?o00002?ooool2o`0000oooooo0_l00002ooooo`Co00001Oooool2o`0000Kooooo0ol00008
ooooo`?o00000_ooool9o`000003ooooool0003o000000?o00002?ooool2o`0000[ooooo0_l0000Q
ooooo`?o00001Oooool2o`0005;ooooo000Looooo`03o`000?oooooooooo05cooooo0_l0000Coooo
o`?o000000?oooooo`000?l000002?ooool2o`000003ooooool0003o000000;ooooo0ol00006oooo
o`;o00001oooool2o`0000Wooooo1_l00003ooooo`[o000000Coooooo`000?l0003o00004?ooool2
o`0000[ooooo0_l0000Mooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0??ooool2o`00
00Gooooo0_l0000Gooooo`?o00001_ooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`00
0003ooooool0003o000000Sooooo0_l00008ooooo`;o00001?ooool2o`0000oooooo0_l00002oooo
o`?o00001Oooool6o`0000;ooooo0_l000001?oooooo0000o`000?l0000Looooo`;o00000oooool2
o`0000Gooooo0_l0000Cooooo`;o0000D?ooool001cooooo0_l0000mooooo`;o00001Oooool2o`00
01Sooooo0_l00006ooooo`;o000000Coooooo`000?l0003o00000oooool2o`0000?ooooo1?l00008
ooooo`;o00002?ooool2o`0000Cooooo1?l00006ooooo`;o00001Oooool3o`000003ooooool0003o
000000Co00000oooool9o`000003ooooool0003o000000;o00005?ooool2o`0000Gooooo1?l00000
0ooooooo0000o`000005ooooo`;o00004oooool2o`00053ooooo000Looooo`03o`000?oooooooooo
04Cooooo0_l0000Rooooo`;o00001Oooool2o`0000;ooooo0_l0000Dooooo`;o00001_ooool2o`00
00Kooooo0_l00003ooooo`;o000000?oooooo`000?l000000oooool6o`000003ooooool0003o0000
00;ooooo0ol00003ooooo`Co00000oooool2o`0000oooooo0_l00002ooooo`;o000000?oooooo`00
0?l000000_l00007ooooo`;o000000?oooooo`000?l00000Hoooool001cooooo00?o0000oooooooo
ool0??ooool2o`0000Kooooo0_l0000Rooooo`;o00001Oooool2o`0000;ooooo0_l00004ooooo`;o
00004Oooool5o`0000gooooo1?l00006ooooo`Ko000000?oooooo`000?l000001_ooool3o`0000Co
oooo0_l0000Cooooo`;o00003?ooool2o`000003ooooool0003o000006?ooooo000Looooo`03o`00
0?oooooooooo03cooooo0_l0000Rooooo`;o00002oooool4o`0000Gooooo0_l000000ooooooo0000
o`00000@ooooo`Ko00002?ooool2o`0000Cooooo0ol00007ooooo`[o00001?ooool3o`0003Kooooo
0ol0001Fooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o00002oooool5o`0000?ooooo0ol0
00000ooooooo0000o`00000@ooooo`;o00000_ooool2o`0000Sooooo0_l0000>ooooo`co00005Ooo
ool2o`0002Cooooo0ol0001Fooooo`007?ooool00ol0003oooooooooo`1Uooooo`?o00002?ooool2
o`0000?ooooo0_l000000ooooooo0000o`000003o`0001;ooooo0_l00002ooooo`;o00002Oooool2
o`0000Sooooo0_l000001?oooooo0000o`000?ooool7o`0001Gooooo1?l0001kooooo`007?ooool0
0ol0003oooooooooo`1Uooooo`?o00002Oooool2o`000003ooooool0003o000000;ooooo0_l00000
0ooooooo0000o`000002ooooo`;o00001_ooool2o`0000Oooooo0_l000000ooooooo0000o`000009
ooooo`;o00000_ooool2o`000003ooooool0003o000000?o00001_ooool2o`0001[ooooo0_l0000=
ooooo`;o00000oooool2o`0000kooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`1Toooo
o`Co00002?ooool6o`000003ooooool0003o000000Kooooo0_l00006ooooo`;o00001_ooool3o`00
00Oooooo0_l00007ooooo`;o000000Coooooo`000?l0003o00001?ooool3o`0000_ooooo0_l0000O
ooooo`;o00000oooool2o`0000Gooooo0_l00007ooooo`;o0000Eoooool001cooooo00?o0000oooo
ooooool0@?ooool2o`0002;ooooo0ol00009ooooo`;o000000?oooooo`000?l000000_ooool2o`00
00gooooo0_l00005ooooo`Co00001?ooool3o`000003ooooool0003o000000?ooooo0_l00002oooo
o`;o000000?oooooo`000?l000001?ooool6o`0000Wooooo0_l0000Pooooo`;o000000?oooooo`00
0?l000001_ooool2o`0000gooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`10ooooo`;o
00002oooool2o`0001Kooooo0_l0000:ooooo`;o00002Oooool2o`0000Sooooo0_l00005ooooo`;o
00000_ooool3o`000004ooooool0003o0000o`0000Kooooo0_l00002ooooo`;o000000?oooooo`00
0?l000000_l00002ooooo`?o000000?oooooo`000?l000005oooool2o`0001;ooooo0_l000000ooo
oooo0000o`00000Eooooo`;o0000DOooool001cooooo00?o0000ooooooooool0COooool2o`0001Wo
oooo1?l00005ooooo`Ko00001Oooool2o`0000_ooooo0_l00006ooooo`Go00000_ooool2o`0000;o
oooo0_l00009ooooo`;o00005Oooool2o`0000;ooooo0_l00003ooooo`?o00000_ooool2o`0000Wo
oooo0ol0000@ooooo`;o0000GOooool001cooooo00?o0000ooooooooool0J?ooool4o`0000Kooooo
1ol0000@ooooo`;o00002Oooool2o`0000;ooooo0_l00002ooooo`;o00007oooool7o`0000?ooooo
0_l00003ooooo`Ko00001Oooool3o`00013ooooo0ol0001Looooo`007?ooool00ol0003ooooooooo
o`1fooooo`?o00002Oooool2o`0000;ooooo0_l0000Dooooo`;o00000_ooool2o`0000gooooo0_l0
000<ooooo`Oo00002?ooool6o`0000;ooooo0_l00002ooooo`;o00003?ooool2o`0000?ooooo0_l0
0002ooooo`;o0000F?ooool001cooooo00?o0000ooooooooool0A?ooool2o`0002oooooo0_l00000
0ooooooo0000o`000008ooooo`;o00000_ooool3o`0000;ooooo1Ol0000<ooooo`;o00000_ooool2
o`0000Cooooo0ol00006ooooo`?o000000?oooooo`000?l000001_ooool2o`0001Oooooo0_l00002
ooooo`;o00002_ooool4o`0000Oooooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`14oooo
o`;o0000;oooool2o`000004ooooool0003o0000o`0000?ooooo0_l00007ooooo`;o00000_ooool7
o`0001Cooooo0ol00007ooooo`;o000000?oooooo`000?l000000_ooool6o`0000Kooooo0_l0000O
ooooo`;o0000Hoooool001cooooo00?o0000ooooooooool0NOooool3o`0000;ooooo0_l00007oooo
o`Co000000?oooooo`000?l000000_ooool2o`0001?ooooo1Ol00006ooooo`;o00000_ooool2o`00
0003ooooool0003o000000?o000000?oooooo`000?l000000oooool7o`0000kooooo0_l0000Eoooo
o`;o0000FOooool001cooooo0_l0001kooooo`;o000000?oooooo`000?l000002?ooool4o`000003
ooooool0003o000000;o00001_ooool2o`0000gooooo1Ol00006ooooo`;o00000_ooool2o`000004
ooooool0003o0000o`0000?ooooo0_l00003ooooo`Oo00000oooool3o`0000Sooooo0_l0000Eoooo
o`;o0000FOooool001cooooo00?o0000ooooooooool0K_ooool2o`0000?ooooo0_l00005ooooo`Go
00001?ooool2o`0000Wooooo0_l00006ooooo`;o00003_ooool3o`0000Kooooo0_l00007ooooo`;o
00001?ooool2o`0000Gooooo1?l00003ooooo`Co00001?ooool2o`0000[ooooo0_l00009ooooo`;o
0000G?ooool001cooooo00?o0000ooooooooool0K_ooool2o`0000?ooooo0_l00005ooooo`Go0000
1?ooool2o`0000?ooooo0ol00004ooooo`;o00005_ooool2o`0000Kooooo0_l00004ooooo`;o0000
1oooool2o`0000Oooooo0_l00005ooooo`;o00001?ooool2o`0000Oooooo0_l000000ooooooo0000
o`000004ooooo`;o00000oooool2o`0005cooooo000Looooo`03o`000?oooooooooo05Sooooo0_l0
000Gooooo`;o00000_ooool2o`0000Kooooo0ol00008ooooo`?o00001?ooool2o`0001gooooo0_l0
0005ooooo`;o00002oooool2o`0000[ooooo0_l00007ooooo`;o00000oooool3o`0000Oooooo0_l0
001Qooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o00005oooool2o`000004ooooool0003o
0000o`0000?ooooo1_l00004ooooo`;o00000_ooool2o`00013ooooo0_l0000Booooo`;o00001Ooo
ool2o`000003ooooool0003o000000Sooooo0_l0000:ooooo`;o00001oooool2o`0000?ooooo0_l0
001[ooooo`007?ooool00ol0003oooooooooo`1dooooo`?o00000oooool3o`000003ooooool0003o
000000Cooooo0_l00002ooooo`Co00003_ooool4o`000003ooooool0003o0000017ooooo0_l00000
0ooooooo0000o`000003o`0000;ooooo0_l0000<ooooo`?o00002Oooool2o`00077ooooo000Loooo
o`03o`000?oooooooooo04_ooooo0_l0000^ooooo`?o00000_ooool2o`0000Sooooo0_l0000@oooo
o`;o000000?oooooo`000?l000004Oooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`00
00Cooooo0_l00006ooooo`Co00000_ooool2o`000004ooooool0003o0000ooooo`?o0000L?ooool0
01cooooo00?o0000ooooooooool0Boooool3o`0000kooooo0_l0000Fooooo`;o00001Oooool3o`00
00;ooooo0_l0000Sooooo`;o00004oooool2o`0000Kooooo0_l00008ooooo`;o00000_ooool2o`00
0003ooooool0003o000000;ooooo0_l0001`ooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o
00003_ooool2o`0001Kooooo0ol00004ooooo`?o00009oooool2o`0000;ooooo0_l0000Fooooo`Ko
00001Oooool2o`0000;ooooo0_l000000ooooooo0000o`00001dooooo`007?ooool00ol0003ooooo
ooooo`1eooooo`;o00000_ooool2o`000003ooooool0003o000000;o0000:Oooool2o`0001Cooooo
2ol00002ooooo`;o00001Oooool2o`0007Cooooo000Looooo`03o`000?oooooooooo053ooooo0_l0
000=ooooo`;o00006?ooool2o`000003ooooool0003o000000;o00001_ooool2o`0001cooooo0_l0
000Iooooo`?o00000oooool5o`0007oooooo000Looooo`03o`000?oooooooooo053ooooo0_l0000=
ooooo`;o00006?ooool2o`0000;ooooo0_l00003ooooo`?o000000?oooooo`000?l000007?ooool5
o`000:3ooooo000Looooo`03o`000?oooooooooo07Wooooo0_l00002ooooo`[o00005Oooool4o`00
00Kooooo0ol00003ooooo`;o0000Voooool001cooooo00?o0000ooooooooool0NOooool2o`0000?o
oooo2Ol0000Dooooo`Go00003?ooool2o`0000Cooooo0_l000000ooooooo0000o`00002Booooo`00
00Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0Ooooool2o`00013ooooo0_l00008ooooo`;o00003oooool8
o`000003ooooool0003o000000Cooooo0_l0002<ooooo`0000KoooooogMgMonHV9SooooooiRHV?mg
MgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0
N_ooool2o`0000?ooooo0_l0000@ooooo`Co00001_ooool2o`00017ooooo1?l00009ooooo`;o0000
S?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool0Ioooool2o`00017ooooo0_l0000>ooooo`;o0000
1oooool2o`0001;ooooo0_l0000Booooo`Co0000R_ooool00003ooooool0003ooooo00;ooooo00?o
0000ooooooooool02Oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0001Fooooo`;o0000
3oooool4o`0001Sooooo0_l00005ooooo`;o00003Oooool2o`0000cooooo0_l00002ooooo`;o0000
2oooool2o`000003ooooool0003o000000;o00000_ooool2o`0008Kooooo00000ooooooo0000oooo
o`02ooooo`03o`000?oooooooooo00Wooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`00
0?oooooooooo05Kooooo0_l0000Aooooo`;o00006?ooool2o`0001Cooooo0_l00007ooooo`;o0000
0oooool3o`000003ooooool0003o000000Gooooo0_l00004ooooo`;o00001oooool4o`0008Cooooo
00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go410@okZj^_oooooo^[Zj
oa0@4006ooooo`03o`000?oooooooooo08Wooooo0_l0000Gooooo`;o00000oooool3o`000003oooo
ool0003o000000Gooooo0_l00002ooooo`;o00002oooool2o`0008Cooooo00001_ooooooMgMgoiRH
V?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo
06kooooo0ol0000Hooooo`;o00001?ooool2o`0000oooooo0_l0000Dooooo`;o00002Oooool2o`00
00Oooooo0_l0001mooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o
0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`1^ooooo`?o00006_ooool2o`0000;ooooo0_l0
000?ooooo`;o00004oooool6o`0000Kooooo0_l000000ooooooo0000o`000004ooooo`;o0000OOoo
ool001cooooo00?o0000ooooooooool0LOooool3o`00013ooooo0_l00005ooooo`Co00006?ooool2
o`0000cooooo1_l00005ooooo`;o00000_ooool2o`0008?ooooo000Looooo`03o`000?oooooooooo
077ooooo0ol0000@ooooo`;o00001_ooool4o`0001Oooooo0_l0000;ooooo`?o00002Oooool2o`00
08Oooooo000Looooo`03o`000?oooooooooo08Cooooo0_l00003ooooo`;o00000oooool2o`0000[o
oooo0_l0000Hooooo`?o0000T_ooool001cooooo00?o0000ooooooooool0ROooool2o`0000Gooooo
0_l00008ooooo`;o00006?ooool2o`0009?ooooo000Looooo`03o`000?oooooooooo093ooooo0_l0
000;ooooo`Co000000?oooooo`000?l000000oooool3o`0000Cooooo0_l0002Iooooo`007?ooool0
0ol0003oooooooooo`2@ooooo`;o00002oooool4o`000003ooooool0003o000000?ooooo0ol00004
ooooo`;o00001oooool2o`00093ooooo000Looooo`03o`000?oooooooooo0:?ooooo0_l0000Boooo
o`;o0000T?ooool001cooooo00?o0000ooooooooool0Xoooool2o`000:Cooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000Joooool2o`000=gooooo000Looooo`03
o`000?oooooooooo06[ooooo0_l0003Mooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo06gooooo0_l0003Jooooo`007?ooool00ol0003oooooooooo`1]
ooooo`;o0000f_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0Moooool2o`000=3ooooo000Looooo`03o`000?oooooooooo07Oooooo1?l0003>
ooooo`007?ooool00ol0003oooooooooo`1iooooo`;o0000c_ooool001cooooo00?o0000oooooooo
ool0Ooooool2o`000<Sooooo000Looooo`03o`000?oooooooooo07oooooo0_l00038ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0Qoooool2o`000<3ooooo000Looooo`;o0000R?ooool4o`000;ko
oooo000Looooo`03o`000?oooooooooo08Wooooo0_l0000Vooooo`;o00000_ooool2o`0009;ooooo
000Looooo`03o`000?oooooooooo0;7ooooo0_l00002ooooo`;o0000T_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Booooo`;o00005_ooool2o`00
09gooooo000Looooo`03o`000?oooooooooo09;ooooo0_l0000Fooooo`;o0000WOooool001cooooo
00?o0000ooooooooool0VOooool2o`0000_ooooo0_l0002Qooooo`007?ooool00ol0003ooooooooo
o`2Iooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o0000XOooool001cooooo00?o0000
ooooooooool0WOooool2o`0000?ooooo0_l0002Uooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Booooo`Co000000?o410@oooooooo
ool00oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`?o0000oooo
oom:ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo
0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003ooooo
ooooo`3ooooooe;ooooo000Booooo`03oeEEEOmVIVKo00000?ooooooE?ooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00:Gooooo00Co410@o`000?l0003ooooo0_l000000ol@413o
ooooooooo`0Fooooo`05odA4A?l0003o0000oc8b<_oMgMd00oooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oa0@4?o<c<b@ooooo`00Y_ooool01Ol0003ooooooooooooooooo000000Wooooo
1_l0000=ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool00_ooool01OmEEEGoMgMg
oooooonHV9So8B4Q093ooooo002Vooooo`05o`000?ooooooooooooooool000007Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00002@oooo
o`00Y_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l0000=ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool00_ooool01Ol0003oV9RHoooooonHV9So8B4Q093ooooo002Voooo
o`05o`000?n7QhOoooooojVYZOl000006Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool00_ooool01Ol0003oEEEEo`000?l@413oc<c<093ooooo002Uooooo`03oa0@4?l0
003oMgMg00;o000000?oV9RHooooooooool05oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00;ooooo00?oEEEEohN7Qoooool0T_ooool00<Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`02ooooo`03omgMgOl@413oV9RH09;ooooo0034ooooo`Co00001?ooool00omE
EEGoIVIVo`000005ooooo`04olc<c?m4A4Co0000oa0@493ooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(522) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.68112 .50857 Mdot
.66058 .49119 Mdot
.27817 .44428 Mdot
.51406 .63491 Mdot
.32466 .55914 Mdot
.31363 .4592 Mdot
.47442 .30966 Mdot
.47908 .28422 Mdot
.30113 .45429 Mdot
.65929 .6544 Mdot
.44625 .29283 Mdot
.6065 .61794 Mdot
.4632 .29852 Mdot
.55209 .61925 Mdot
.56278 .42853 Mdot
.48617 .69884 Mdot
.69649 .44212 Mdot
.36074 .62131 Mdot
.48303 .69866 Mdot
.28628 .45907 Mdot
.44413 .69059 Mdot
.55278 .63216 Mdot
.67629 .44544 Mdot
.55318 .62265 Mdot
.51523 .5967 Mdot
.6708 .48651 Mdot
.67314 .50921 Mdot
.49893 .59706 Mdot
.49132 .6302 Mdot
.45479 .28576 Mdot
.20981 .45236 Mdot
.84713 .51656 Mdot
.53612 .57073 Mdot
.78159 .57779 Mdot
.48016 .28336 Mdot
.41555 .23265 Mdot
.2946 .42612 Mdot
.48939 .30145 Mdot
.4652 .27175 Mdot
.4726 .27324 Mdot
.48032 .31321 Mdot
.67989 .48861 Mdot
.44729 .26582 Mdot
.31035 .37667 Mdot
.55115 .59788 Mdot
.74464 .41096 Mdot
.20884 .37333 Mdot
.49193 .61049 Mdot
.70873 .48631 Mdot
.30065 .4783 Mdot
.36257 .76163 Mdot
.47625 .33373 Mdot
.58137 .3704 Mdot
.3838 .87712 Mdot
.45234 .29502 Mdot
.50611 .63714 Mdot
.3106 .47404 Mdot
.53092 .63816 Mdot
.53178 .65805 Mdot
.77874 .54926 Mdot
.56034 .64567 Mdot
.33566 .59693 Mdot
.63978 .49341 Mdot
.32134 .40793 Mdot
.30588 .4603 Mdot
.48563 .31494 Mdot
.64651 .47335 Mdot
.47296 .29426 Mdot
.48467 .63658 Mdot
.28859 .46941 Mdot
.49353 .62381 Mdot
.44974 .28641 Mdot
.65011 .47629 Mdot
.54974 .59406 Mdot
.67962 .37122 Mdot
.50641 .34343 Mdot
.34948 .50351 Mdot
.74666 .68191 Mdot
.40345 .81417 Mdot
.27286 .49205 Mdot
.56258 .60661 Mdot
.30442 .78072 Mdot
.52581 .39896 Mdot
.65957 .4961 Mdot
.66015 .4292 Mdot
.68938 .26668 Mdot
.48907 .60737 Mdot
.37944 .52107 Mdot
.57245 .5819 Mdot
.47143 .51953 Mdot
.29493 .44953 Mdot
.6599 .47533 Mdot
.55477 .59635 Mdot
.56434 .58419 Mdot
.64699 .56331 Mdot
.50268 .65494 Mdot
.52393 .61798 Mdot
.62762 .46197 Mdot
.4438 .30764 Mdot
.61194 .57997 Mdot
.25829 .61758 Mdot
.57274 .37884 Mdot
.51021 .62139 Mdot
.318 .43559 Mdot
.64036 .50393 Mdot
.52994 .60905 Mdot
.47791 .29145 Mdot
.56183 .6191 Mdot
.43433 .32579 Mdot
.69689 .44662 Mdot
.56811 .58338 Mdot
.30715 .60097 Mdot
.54394 .49659 Mdot
.70065 .46251 Mdot
.65692 .74589 Mdot
.56068 .64212 Mdot
.54911 .64855 Mdot
.66667 .49746 Mdot
.28201 .43504 Mdot
.39613 .46677 Mdot
.66531 .45255 Mdot
.46666 .27049 Mdot
.71323 .46569 Mdot
.59821 .62026 Mdot
.28206 .4387 Mdot
.58527 .37958 Mdot
.57436 .37516 Mdot
.32616 .66441 Mdot
.55342 .59168 Mdot
.58144 .50838 Mdot
.32051 .44734 Mdot
.67566 .49351 Mdot
.46683 .29054 Mdot
.53652 .66592 Mdot
.69676 .47367 Mdot
.45393 .27084 Mdot
.34769 .59831 Mdot
.32834 .55845 Mdot
.7003 .4884 Mdot
.56759 .75047 Mdot
.46402 .33833 Mdot
.47441 .27183 Mdot
.36163 .75708 Mdot
.663 .49952 Mdot
.32029 .57733 Mdot
.43931 .27842 Mdot
.41127 .70877 Mdot
.5606 .65852 Mdot
.32628 .69517 Mdot
.22759 .7049 Mdot
.36184 .75976 Mdot
.82109 .54699 Mdot
.30312 .58763 Mdot
.43982 .27623 Mdot
.49757 .61666 Mdot
.6875 .47361 Mdot
.69159 .48175 Mdot
.5635 .58646 Mdot
.53171 .58987 Mdot
.54601 .60784 Mdot
.54546 .66362 Mdot
.36898 .22576 Mdot
.55904 .60137 Mdot
.52934 .25311 Mdot
.69454 .46669 Mdot
.52796 .59615 Mdot
.32173 .4291 Mdot
.56842 .67585 Mdot
.48751 .29693 Mdot
.52726 .6547 Mdot
.52364 .59035 Mdot
.56509 .66887 Mdot
.44525 .26912 Mdot
.67277 .34391 Mdot
.48291 .83348 Mdot
.42999 .22778 Mdot
.58263 .35398 Mdot
.327 .46006 Mdot
.57515 .62581 Mdot
.31046 .58983 Mdot
.61265 .6215 Mdot
.5438 .65707 Mdot
.36316 .76671 Mdot
.53121 .58346 Mdot
.80077 .60444 Mdot
.59716 .56387 Mdot
.67265 .24826 Mdot
.54206 .23602 Mdot
.54913 .65884 Mdot
.63965 .69491 Mdot
.31966 .68188 Mdot
.18953 .47054 Mdot
.46048 .28717 Mdot
.3272 .42775 Mdot
.28459 .42658 Mdot
.48627 .28078 Mdot
.50604 .56051 Mdot
.66382 .66397 Mdot
.49805 .65601 Mdot
.58337 .3804 Mdot
.73649 .44485 Mdot
.30456 .57775 Mdot
.70035 .48958 Mdot
.33221 .80105 Mdot
.3897 .5535 Mdot
.2864 .49268 Mdot
.3609 .60885 Mdot
.32074 .48491 Mdot
.58903 .39534 Mdot
.31336 .57911 Mdot
.52127 .62852 Mdot
.70659 .4584 Mdot
.31479 .68367 Mdot
.50411 .69467 Mdot
.51942 .12505 Mdot
.65056 .49219 Mdot
.50934 .47663 Mdot
.45714 .29265 Mdot
.31451 .40833 Mdot
.4895 .60686 Mdot
.53754 .62625 Mdot
.6449 .50232 Mdot
.49063 .61922 Mdot
.40912 .5077 Mdot
.5231 .58789 Mdot
.33973 .42502 Mdot
.32807 .63298 Mdot
.4272 .32041 Mdot
.36714 .60558 Mdot
.6543 .46649 Mdot
.51788 .30863 Mdot
.31941 .43235 Mdot
.51257 .53598 Mdot
.46434 .28162 Mdot
.34637 .60527 Mdot
.30193 .42786 Mdot
.31228 .61062 Mdot
.58166 .60435 Mdot
.29049 .43194 Mdot
.33499 .5859 Mdot
.43928 .39847 Mdot
.5231 .61722 Mdot
.35817 .69757 Mdot
.43566 .30586 Mdot
.68391 .50569 Mdot
.55512 .65322 Mdot
.59359 .382 Mdot
.58829 .65089 Mdot
.56537 .48749 Mdot
.59092 .40218 Mdot
.56536 .40228 Mdot
.30387 .50737 Mdot
.33505 .57354 Mdot
.65609 .39109 Mdot
.42421 .4486 Mdot
.69512 .44142 Mdot
.58326 .61452 Mdot
.73014 .33914 Mdot
.43449 .3045 Mdot
.52208 .63198 Mdot
.66745 .25962 Mdot
.43842 .27878 Mdot
.53574 .64433 Mdot
.47612 .31774 Mdot
.69172 .47728 Mdot
.48611 .39724 Mdot
.71538 .48343 Mdot
.51658 .63839 Mdot
.45771 .31764 Mdot
.32113 .4244 Mdot
.67134 .48583 Mdot
.56018 .62688 Mdot
.56612 .60563 Mdot
.58391 .38399 Mdot
.54051 .59292 Mdot
.7413 .3268 Mdot
.49296 .60833 Mdot
.31231 .4869 Mdot
.49357 .64465 Mdot
.29407 .68801 Mdot
.33411 .55882 Mdot
.6572 .45055 Mdot
.58733 .40524 Mdot
.29277 .45096 Mdot
.4675 .39608 Mdot
.34499 .65436 Mdot
.56 .61126 Mdot
.57147 .39381 Mdot
.50887 .47195 Mdot
.48667 .30514 Mdot
.49201 .59021 Mdot
.40147 .48731 Mdot
.2966 .44132 Mdot
.58808 .38655 Mdot
.47252 .65363 Mdot
.68573 .51023 Mdot
.50273 .63269 Mdot
.29977 .42495 Mdot
.70081 .50028 Mdot
.51972 .66152 Mdot
.2741 .29873 Mdot
.59154 .37824 Mdot
.45568 .32182 Mdot
.63159 .53874 Mdot
.57378 .60618 Mdot
.28813 .42076 Mdot
.69689 .47936 Mdot
.45261 .30709 Mdot
.69053 .44951 Mdot
.29985 .67318 Mdot
.60153 .51326 Mdot
.36803 .26404 Mdot
.35748 .62771 Mdot
.79516 .67746 Mdot
.42471 .23184 Mdot
.59019 .52399 Mdot
.36542 .45618 Mdot
.59312 .1808 Mdot
.30806 .43003 Mdot
.59689 .73661 Mdot
.29864 .46261 Mdot
.50409 .62296 Mdot
.31067 .45928 Mdot
.74987 .31356 Mdot
.51343 .58691 Mdot
.32588 .47045 Mdot
.34916 .26854 Mdot
.53505 .58177 Mdot
.69797 .46782 Mdot
.8078 .44367 Mdot
.67528 .74447 Mdot
.53105 .75555 Mdot
.3214 .47587 Mdot
.58677 .7527 Mdot
.49491 .5992 Mdot
.47932 .69355 Mdot
.68166 .47541 Mdot
.6005 .6354 Mdot
.30059 .57034 Mdot
.30223 .59718 Mdot
.40125 .75493 Mdot
.69689 .74679 Mdot
.45916 .5953 Mdot
.67885 .48498 Mdot
.38606 .80672 Mdot
.68634 .37077 Mdot
.58857 .37456 Mdot
.46806 .27508 Mdot
.66197 .34507 Mdot
.46787 .65029 Mdot
.6273 .58472 Mdot
.43211 .48298 Mdot
.65849 .47447 Mdot
.39136 .33043 Mdot
.45788 .31076 Mdot
.5872 .77005 Mdot
.68449 .62542 Mdot
.54309 .60853 Mdot
.45633 .32884 Mdot
.59456 .57088 Mdot
.42093 .48938 Mdot
.34656 .69678 Mdot
.26072 .35666 Mdot
.51775 .62899 Mdot
.67079 .38819 Mdot
.54218 .65562 Mdot
.3323 .68045 Mdot
.52031 .63711 Mdot
.691 .45189 Mdot
.46652 .59982 Mdot
.42498 .42991 Mdot
.58476 .79243 Mdot
.39067 .54814 Mdot
.32251 .57101 Mdot
.54917 .62085 Mdot
.53564 .61865 Mdot
.33834 .59495 Mdot
.66377 .46949 Mdot
.5821 .62724 Mdot
.21348 .35935 Mdot
.55932 .60001 Mdot
.48082 .33016 Mdot
.47465 .42337 Mdot
.80022 .62651 Mdot
.52812 .58036 Mdot
.67578 .51225 Mdot
.48429 .30331 Mdot
.4553 .27589 Mdot
.46009 .60263 Mdot
.44061 .31431 Mdot
.49539 .61802 Mdot
.47662 .42292 Mdot
.68208 .44387 Mdot
.60758 .59487 Mdot
.66652 .46468 Mdot
.35384 .77905 Mdot
.43317 .28351 Mdot
.56997 .3988 Mdot
.5703 .76318 Mdot
.46951 .30884 Mdot
.41792 .59107 Mdot
.47475 .59138 Mdot
.49319 .68393 Mdot
.62978 .53076 Mdot
.31605 .42038 Mdot
.57698 .4022 Mdot
.45081 .29862 Mdot
.5571 .60104 Mdot
.52208 .6116 Mdot
.46159 .33276 Mdot
.75076 .53889 Mdot
.21076 .4491 Mdot
.51784 .64204 Mdot
.68336 .45077 Mdot
.67661 .49221 Mdot
.56165 .66273 Mdot
.54894 .65474 Mdot
.33812 .46149 Mdot
.5711 .3949 Mdot
.58025 .40557 Mdot
.56541 .38309 Mdot
.34766 .44466 Mdot
.76408 .71177 Mdot
.4743 .27162 Mdot
.83167 .55136 Mdot
.67347 .29839 Mdot
.45153 .62483 Mdot
.29569 .42093 Mdot
.54004 .63545 Mdot
.5121 .61476 Mdot
.45249 .31583 Mdot
.6726 .77499 Mdot
.53978 .56765 Mdot
.67258 .50751 Mdot
.47414 .33306 Mdot
.6056 .60653 Mdot
.4963 .27613 Mdot
.32729 .61485 Mdot
.47219 .7115 Mdot
.45014 .32692 Mdot
.69628 .4491 Mdot
.45252 .32883 Mdot
.53872 .61507 Mdot
.4777 .66749 Mdot
.65696 .47602 Mdot
.35316 .5967 Mdot
.57368 .59836 Mdot
.53593 .6461 Mdot
.17588 .55665 Mdot
.67962 .37344 Mdot
.27957 .5657 Mdot
.50661 .60713 Mdot
.50464 .68286 Mdot
.35406 .61158 Mdot
.57923 .61399 Mdot
.49402 .6364 Mdot
.54147 .49372 Mdot
.44032 .33438 Mdot
.32261 .56388 Mdot
.57408 .78928 Mdot
.65224 .49689 Mdot
.72885 .3135 Mdot
.57815 .37675 Mdot
.41787 .2848 Mdot
.49147 .39145 Mdot
.58286 .39719 Mdot
.65513 .26454 Mdot
.44124 .21706 Mdot
.57479 .39844 Mdot
.30983 .40396 Mdot
.60713 .6844 Mdot
.49216 .63644 Mdot
.52978 .65256 Mdot
.336 .57501 Mdot
.67741 .50165 Mdot
.53515 .25367 Mdot
.45489 .34654 Mdot
.55236 .63895 Mdot
.71507 .49459 Mdot
.68087 .25691 Mdot
.58775 .39087 Mdot
.30984 .596 Mdot
.34806 .58242 Mdot
.54376 .65371 Mdot
.46266 .5472 Mdot
.6762 .48679 Mdot
.56008 .62694 Mdot
.56745 .64601 Mdot
.2956 .46407 Mdot
.70919 .46387 Mdot
.32592 .43412 Mdot
.58525 .40884 Mdot
.54916 .1562 Mdot
.16184 .50569 Mdot
.43517 .29558 Mdot
.40437 .3183 Mdot
.42554 .28089 Mdot
.27891 .32828 Mdot
.57119 .39658 Mdot
.55697 .63 Mdot
.65711 .45764 Mdot
.56178 .62194 Mdot
.55778 .59817 Mdot
.53801 .60763 Mdot
.45815 .59645 Mdot
.3504 .76785 Mdot
.32385 .6042 Mdot
.47894 .61563 Mdot
.33671 .47359 Mdot
.66972 .25064 Mdot
.78105 .39992 Mdot
.54394 .62055 Mdot
.54732 .64826 Mdot
.64466 .4853 Mdot
.58312 .60521 Mdot
.47954 .29097 Mdot
.65586 .49643 Mdot
.51385 .62018 Mdot
.25947 .63234 Mdot
.57911 .6356 Mdot
.40004 .29109 Mdot
.44847 .32692 Mdot
.52819 .71524 Mdot
.4861 .66979 Mdot
.5712 .39812 Mdot
.5772 .40171 Mdot
.59698 .38783 Mdot
.47397 .32966 Mdot
.29384 .46075 Mdot
.27211 .41502 Mdot
.47649 .64847 Mdot
.49696 .61233 Mdot
.48262 .67428 Mdot
.34377 .482 Mdot
.41871 .44287 Mdot
.68184 .40899 Mdot
.59206 .5611 Mdot
.34681 .45302 Mdot
.62037 .4961 Mdot
.61168 .77854 Mdot
.66279 .50285 Mdot
.36281 .4661 Mdot
.47109 .28164 Mdot
.30165 .58939 Mdot
.40503 .78841 Mdot
.67276 .44846 Mdot
.64916 .50443 Mdot
.32766 .4648 Mdot
.51723 .43781 Mdot
.46631 .91541 Mdot
.3169 .4397 Mdot
.33428 .52081 Mdot
.67942 .47875 Mdot
.54675 .56952 Mdot
.51034 .46784 Mdot
.53306 .45499 Mdot
.31824 .47029 Mdot
.56613 .60697 Mdot
.41903 .57355 Mdot
.33777 .46214 Mdot
.49353 .58574 Mdot
.32392 .47577 Mdot
.45192 .3226 Mdot
.32426 .44759 Mdot
.72355 .45863 Mdot
.55784 .59417 Mdot
.40884 .89102 Mdot
.52264 .3897 Mdot
.56401 .63153 Mdot
.46812 .33459 Mdot
.32756 .26454 Mdot
.53207 .61759 Mdot
.30455 .57045 Mdot
.34781 .46241 Mdot
.25656 .34805 Mdot
.49679 .63807 Mdot
.31602 .46508 Mdot
.71726 .44252 Mdot
.36267 .4553 Mdot
.26934 .57264 Mdot
.57885 .40423 Mdot
.69206 .47421 Mdot
.55505 .39269 Mdot
.48375 .28623 Mdot
.58197 .64812 Mdot
.57363 .63904 Mdot
.69147 .45919 Mdot
.45252 .39344 Mdot
.50499 .56905 Mdot
.56203 .60654 Mdot
.33716 .45439 Mdot
.33653 .48149 Mdot
.59398 .42742 Mdot
.3142 .42831 Mdot
.50597 .68254 Mdot
.69329 .45802 Mdot
.50587 .62961 Mdot
.70053 .47655 Mdot
.58243 .61052 Mdot
.6146 .38603 Mdot
.66858 .50389 Mdot
.53202 .52491 Mdot
.55072 .58881 Mdot
.74038 .49904 Mdot
.57135 .60139 Mdot
.5211 .62303 Mdot
.34665 .47066 Mdot
.32225 .59277 Mdot
.521 .57561 Mdot
.51501 .30161 Mdot
.34781 .61813 Mdot
.79958 .52104 Mdot
.28256 .4373 Mdot
.34989 .59492 Mdot
.39166 .72682 Mdot
.58742 .40502 Mdot
.33397 .60224 Mdot
.5964 .41148 Mdot
.43627 .30237 Mdot
.7096 .4513 Mdot
.54247 .58286 Mdot
.59492 .17566 Mdot
.21032 .45347 Mdot
.58074 .38513 Mdot
.55547 .65162 Mdot
.53597 .63379 Mdot
.69556 .50595 Mdot
.3228 .79298 Mdot
.3371 .41816 Mdot
.51553 .62642 Mdot
.66101 .45805 Mdot
.27205 .75059 Mdot
.32949 .47064 Mdot
.32804 .6085 Mdot
.42895 .30525 Mdot
.73956 .47006 Mdot
.57327 .40352 Mdot
.43334 .28265 Mdot
.34531 .50146 Mdot
.36524 .77219 Mdot
.49883 .64022 Mdot
.30852 .42129 Mdot
.36177 .7603 Mdot
.59925 .56624 Mdot
.46389 .26016 Mdot
.61525 .39673 Mdot
.65916 .47798 Mdot
.46495 .33336 Mdot
.32732 .57007 Mdot
.6971 .44372 Mdot
.66345 .46785 Mdot
.47436 .28101 Mdot
.53715 .21316 Mdot
.51328 .47231 Mdot
.48987 .31111 Mdot
.54057 .47637 Mdot
.3598 .75506 Mdot
.56776 .39181 Mdot
.30855 .59443 Mdot
.26005 .65148 Mdot
.67661 .48861 Mdot
.66352 .34476 Mdot
.36352 .76472 Mdot
.52348 .61842 Mdot
.33149 .57979 Mdot
.68675 .27393 Mdot
.41763 .30187 Mdot
.45049 .27218 Mdot
.38453 .48698 Mdot
.30935 .57252 Mdot
.56921 .6513 Mdot
.78894 .64993 Mdot
.55028 .58293 Mdot
.4353 .28272 Mdot
.42445 .49475 Mdot
.70842 .46405 Mdot
.487 .28954 Mdot
.40517 .51037 Mdot
.51053 .61431 Mdot
.56583 .63829 Mdot
.37399 .6267 Mdot
.71172 .46883 Mdot
.56919 .40272 Mdot
.56506 .61317 Mdot
.53054 .64059 Mdot
.5776 .65407 Mdot
.54959 .77586 Mdot
.51807 .52008 Mdot
.51619 .62203 Mdot
.31684 .41235 Mdot
.51575 .68713 Mdot
.54162 .66252 Mdot
.69927 .50559 Mdot
.29308 .69644 Mdot
.58535 .4091 Mdot
.52805 .65057 Mdot
.51853 .64275 Mdot
.47085 .27434 Mdot
.51134 .47175 Mdot
.53567 .45574 Mdot
.31428 .48488 Mdot
.36824 .50263 Mdot
.5004 .66309 Mdot
.6908 .46775 Mdot
.29967 .56939 Mdot
.54996 .678 Mdot
.66035 .50365 Mdot
.47626 .62524 Mdot
.3338 .47642 Mdot
.57399 .39425 Mdot
.57446 .54649 Mdot
.33252 .59552 Mdot
.45575 .33846 Mdot
.83118 .52473 Mdot
.32971 .43224 Mdot
.50502 .59925 Mdot
.26564 .42279 Mdot
.30658 .44137 Mdot
.5806 .38247 Mdot
.49271 .692 Mdot
.68896 .48083 Mdot
.70296 .45718 Mdot
.33828 .73998 Mdot
.34387 .43337 Mdot
.18748 .61809 Mdot
.44876 .32086 Mdot
.48956 .59606 Mdot
.74472 .38451 Mdot
.70643 .46312 Mdot
.32891 .67022 Mdot
.35092 .59664 Mdot
.44983 .27266 Mdot
.56499 .4094 Mdot
.67141 .50529 Mdot
.70668 .47228 Mdot
.55452 .59696 Mdot
.54662 .62816 Mdot
.36606 .47532 Mdot
.3242 .68768 Mdot
.47623 .31713 Mdot
.32336 .60928 Mdot
.30385 .48297 Mdot
.50573 .61436 Mdot
.65698 .48784 Mdot
.78987 .641 Mdot
.57437 .60833 Mdot
.33402 .47461 Mdot
.66083 .48543 Mdot
.33723 .60828 Mdot
.34348 .58992 Mdot
.52305 .61994 Mdot
.78382 .62647 Mdot
.47181 .30697 Mdot
.69749 .46279 Mdot
.64596 .4393 Mdot
.48153 .62474 Mdot
.5463 .62271 Mdot
.58633 .5784 Mdot
.4731 .26678 Mdot
.58696 .5493 Mdot
.35491 .6199 Mdot
.68848 .49268 Mdot
.56445 .62376 Mdot
.33581 .59753 Mdot
.62619 .57802 Mdot
.58039 .39444 Mdot
.32893 .46952 Mdot
.30294 .57228 Mdot
.32444 .58402 Mdot
.34672 .61586 Mdot
.66217 .34725 Mdot
.63907 .50369 Mdot
.53835 .81569 Mdot
.56146 .59677 Mdot
.35903 .75303 Mdot
.58659 .60654 Mdot
.46838 .32454 Mdot
.32957 .42765 Mdot
.55181 .60094 Mdot
.56111 .59604 Mdot
.80979 .58299 Mdot
.48951 .7047 Mdot
.4949 .71197 Mdot
.70099 .45094 Mdot
.66988 .53871 Mdot
.29179 .41958 Mdot
.20107 .67854 Mdot
.82116 .42011 Mdot
.50171 .65958 Mdot
.51256 .43473 Mdot
.65679 .49627 Mdot
.45184 .26936 Mdot
.5296 .47178 Mdot
.43876 .24081 Mdot
.68023 .49751 Mdot
.50538 .61982 Mdot
.8259 .53128 Mdot
.32902 .62074 Mdot
.54479 .60999 Mdot
.46862 .28919 Mdot
.54535 .60894 Mdot
.47444 .32678 Mdot
.7502 .46704 Mdot
.5333 .43942 Mdot
.52773 .58351 Mdot
.49813 .65124 Mdot
.61282 .56976 Mdot
.54434 .6232 Mdot
.29728 .34875 Mdot
.66895 .47428 Mdot
.51573 .53196 Mdot
.5577 .66718 Mdot
.74582 .66008 Mdot
.5767 .63694 Mdot
.47485 .38261 Mdot
.57215 .63591 Mdot
.50505 .76121 Mdot
.56595 .65448 Mdot
.57465 .6277 Mdot
.45679 .31313 Mdot
.46387 .26993 Mdot
.7187 .44043 Mdot
.56575 .39966 Mdot
.67167 .24857 Mdot
.54156 .6476 Mdot
.34163 .47978 Mdot
.60724 .4388 Mdot
.3216 .58695 Mdot
.68416 .49383 Mdot
.12589 .55042 Mdot
.48373 .30981 Mdot
.31809 .40696 Mdot
.25843 .46617 Mdot
.29426 .41074 Mdot
.34147 .49172 Mdot
.72701 .51182 Mdot
.31064 .59974 Mdot
.57301 .64516 Mdot
.78475 .58657 Mdot
.68124 .38238 Mdot
.48337 .6228 Mdot
.27378 .40381 Mdot
.59192 .67961 Mdot
.35055 .75761 Mdot
.30906 .60907 Mdot
.30394 .58304 Mdot
.45261 .30406 Mdot
.27872 .44071 Mdot
.58914 .56364 Mdot
.34984 .59571 Mdot
.33163 .43086 Mdot
.57362 .37318 Mdot
.35417 .55331 Mdot
.68094 .48705 Mdot
.55356 .74966 Mdot
.74527 .40055 Mdot
.482 .31227 Mdot
.51559 .32188 Mdot
.62765 .49884 Mdot
.66404 .43954 Mdot
.56377 .39389 Mdot
.33956 .46848 Mdot
.70184 .4431 Mdot
.55747 .59486 Mdot
.50387 .69459 Mdot
.54547 .65398 Mdot
.34078 .58018 Mdot
.56333 .64931 Mdot
.34188 .45666 Mdot
.47788 .30838 Mdot
.29434 .44661 Mdot
.47184 .31174 Mdot
.81123 .49279 Mdot
.538 .66006 Mdot
.54857 .62393 Mdot
.48459 .42289 Mdot
.7045 .48095 Mdot
.77512 .57849 Mdot
.33852 .47238 Mdot
.30512 .47105 Mdot
.50706 .62859 Mdot
.65066 .45658 Mdot
.35395 .64065 Mdot
.50899 .45291 Mdot
.57089 .63973 Mdot
.66941 .47329 Mdot
.50571 .63327 Mdot
.28829 .30769 Mdot
.53906 .42861 Mdot
.69396 .45142 Mdot
.58706 .79303 Mdot
.5453 .59222 Mdot
.51269 .7071 Mdot
.54462 .69931 Mdot
.45524 .71186 Mdot
.50706 .57576 Mdot
.65083 .49059 Mdot
.52757 .65605 Mdot
.68609 .46793 Mdot
.30728 .43589 Mdot
.47137 .26861 Mdot
.68483 .4712 Mdot
.5519 .58467 Mdot
.82094 .43572 Mdot
.48097 .3008 Mdot
.5519 .60956 Mdot
.4471 .29719 Mdot
.71573 .46141 Mdot
.7054 .48799 Mdot
.59014 .41824 Mdot
.30933 .50868 Mdot
.4791 .29554 Mdot
.4958 .61306 Mdot
.67585 .35726 Mdot
.50534 .62962 Mdot
.36441 .50567 Mdot
.54319 .67035 Mdot
.48826 .63706 Mdot
.80654 .66445 Mdot
.46573 .39256 Mdot
.16043 .59615 Mdot
.47362 .35472 Mdot
.67642 .34819 Mdot
.70315 .42764 Mdot
.30811 .60787 Mdot
.40834 .33958 Mdot
.59396 .39468 Mdot
.31004 .41138 Mdot
.55452 .59992 Mdot
.77223 .4435 Mdot
.48569 .32299 Mdot
.31928 .59428 Mdot
.52988 .58358 Mdot
.27498 .44194 Mdot
.5386 .37048 Mdot
.44149 .2756 Mdot
.68174 .48869 Mdot
.70062 .49043 Mdot
.42467 .8241 Mdot
.56336 .6293 Mdot
.55038 .63063 Mdot
.48202 .28959 Mdot
.56922 .55666 Mdot
.34125 .61715 Mdot
.35181 .27852 Mdot
.4657 .2867 Mdot
.53539 .4203 Mdot
.70049 .44864 Mdot
.53765 .63426 Mdot
.47316 .42424 Mdot
.62172 .31288 Mdot
.65198 .59849 Mdot
.31972 .57441 Mdot
.39315 .62537 Mdot
.65071 .49067 Mdot
.46457 .28932 Mdot
.39495 .74434 Mdot
.58012 .58939 Mdot
.53406 .63501 Mdot
.38982 .63677 Mdot
.51329 .45629 Mdot
.35619 .52644 Mdot
.59005 .58909 Mdot
.4919 .47794 Mdot
.50743 .62713 Mdot
.52171 .61163 Mdot
.4857 .63865 Mdot
.5249 .66152 Mdot
.67333 .46983 Mdot
.68962 .73182 Mdot
.31767 .45628 Mdot
.63954 .66809 Mdot
.38149 .47505 Mdot
.49522 .59726 Mdot
.50775 .61766 Mdot
.67098 .70802 Mdot
.59031 .49004 Mdot
.67097 .47873 Mdot
.64346 .44281 Mdot
.47596 .27368 Mdot
.48751 .70436 Mdot
.34849 .44426 Mdot
.5491 .708 Mdot
.30295 .45003 Mdot
.66938 .47172 Mdot
.28778 .44959 Mdot
.4908 .33336 Mdot
.30831 .42143 Mdot
.34086 .4316 Mdot
.42973 .28649 Mdot
.71144 .48233 Mdot
.57625 .62296 Mdot
.43025 .29385 Mdot
.36699 .63721 Mdot
.34102 .58078 Mdot
.59612 .41749 Mdot
.54717 .56924 Mdot
.49703 .70772 Mdot
.27069 .30255 Mdot
.28755 .43584 Mdot
.55902 .47285 Mdot
.66997 .50398 Mdot
.30898 .5661 Mdot
.67733 .46797 Mdot
.46974 .80802 Mdot
.33192 .58819 Mdot
.59717 .41657 Mdot
.38306 .73826 Mdot
.49146 .25702 Mdot
.58437 .65952 Mdot
.62969 .53329 Mdot
.30115 .44741 Mdot
.47972 .33107 Mdot
.67951 .2655 Mdot
.53946 .59712 Mdot
.56788 .36857 Mdot
.65189 .44499 Mdot
.58588 .40529 Mdot
.4682 .29166 Mdot
.44695 .35871 Mdot
.56164 .63569 Mdot
.50453 .28073 Mdot
.50802 .65724 Mdot
.57439 .7601 Mdot
.36749 .49464 Mdot
.61608 .51244 Mdot
.50089 .63103 Mdot
.33456 .46951 Mdot
.50255 .63082 Mdot
.59313 .71831 Mdot
.37311 .75381 Mdot
.5116 .66617 Mdot
.61138 .52651 Mdot
.25912 .33316 Mdot
.65742 .48317 Mdot
.50289 .68003 Mdot
.57218 .38708 Mdot
.51549 .60199 Mdot
.65155 .17655 Mdot
.33209 .6004 Mdot
.28705 .56011 Mdot
.55346 .58616 Mdot
.56334 .61601 Mdot
.79412 .60735 Mdot
.66944 .53373 Mdot
.56644 .41077 Mdot
.52944 .6319 Mdot
.40157 .64003 Mdot
.45236 .30915 Mdot
.5246 .66385 Mdot
.53165 .65537 Mdot
.17888 .5309 Mdot
.44949 .30787 Mdot
.28835 .42823 Mdot
.58917 .40364 Mdot
.3181 .48311 Mdot
.29891 .55906 Mdot
.50406 .49763 Mdot
.3363 .67119 Mdot
.54338 .42959 Mdot
.31203 .56913 Mdot
.49244 .59817 Mdot
.63791 .43893 Mdot
.56906 .62343 Mdot
.30596 .58173 Mdot
.45438 .28591 Mdot
.6748 .47217 Mdot
.56371 .75012 Mdot
.58172 .38013 Mdot
.48242 .60675 Mdot
.31349 .61494 Mdot
.68679 .47536 Mdot
.55836 .29864 Mdot
.67137 .50147 Mdot
.46634 .31178 Mdot
.48837 .28548 Mdot
.32696 .58947 Mdot
.67504 .46807 Mdot
.31079 .48021 Mdot
.47271 .35652 Mdot
.53585 .67074 Mdot
.49554 .32824 Mdot
.69347 .43624 Mdot
.6689 .50975 Mdot
.65934 .45215 Mdot
.52508 .65896 Mdot
.5151 .45011 Mdot
.58902 .60452 Mdot
.48184 .29639 Mdot
.28609 .41742 Mdot
.33144 .69981 Mdot
.782 .60629 Mdot
.53127 .41698 Mdot
.51769 .57554 Mdot
.56023 .65037 Mdot
.5443 .65339 Mdot
.51085 .64198 Mdot
.35515 .27843 Mdot
.53739 .65984 Mdot
.46142 .31853 Mdot
.30952 .44768 Mdot
.55958 .64637 Mdot
.57143 .39023 Mdot
.41965 .44843 Mdot
.30011 .568 Mdot
.50791 .74354 Mdot
.76545 .3791 Mdot
.68484 .47514 Mdot
.30816 .42461 Mdot
.28931 .45609 Mdot
.34766 .59846 Mdot
.432 .28897 Mdot
.67975 .50044 Mdot
.47914 .74422 Mdot
.34421 .62221 Mdot
.52754 .64984 Mdot
.47939 .42281 Mdot
.59953 .78474 Mdot
.5133 .58261 Mdot
.53036 .61498 Mdot
.5716 .40572 Mdot
.31809 .40802 Mdot
.67353 .21398 Mdot
.53743 .22454 Mdot
.32366 .59223 Mdot
.33318 .61304 Mdot
.65014 .46693 Mdot
.48722 .59783 Mdot
.47364 .30446 Mdot
.501 .476 Mdot
.28414 .28353 Mdot
.71534 .29156 Mdot
.2782 .33117 Mdot
.57987 .63335 Mdot
.7048 .70443 Mdot
.55921 .67024 Mdot
.64031 .50406 Mdot
.65304 .45659 Mdot
.67486 .48254 Mdot
.45772 .31201 Mdot
.36855 .77769 Mdot
.46124 .31948 Mdot
.77015 .38092 Mdot
.65597 .47054 Mdot
.43982 .40867 Mdot
.31216 .475 Mdot
.47231 .67759 Mdot
.3089 .59716 Mdot
.30574 .63899 Mdot
.49706 .67953 Mdot
.45827 .55334 Mdot
.2955 .42109 Mdot
.70149 .49644 Mdot
.47572 .59118 Mdot
.66074 .23882 Mdot
.51824 .43562 Mdot
.21814 .36631 Mdot
.6597 .54489 Mdot
.33754 .5938 Mdot
.6511 .67465 Mdot
.33858 .62011 Mdot
.44632 .27396 Mdot
.54441 .59488 Mdot
.56413 .58877 Mdot
.51626 .63015 Mdot
.51956 .65606 Mdot
.45038 .29742 Mdot
.54854 .67337 Mdot
.2952 .68931 Mdot
.58137 .37513 Mdot
.41871 .40537 Mdot
.34317 .59612 Mdot
.45855 .32706 Mdot
.30808 .4434 Mdot
.56287 .39517 Mdot
.36783 .62276 Mdot
.57037 .65943 Mdot
.56591 .59936 Mdot
.57582 .37425 Mdot
.53777 .55218 Mdot
.46782 .65255 Mdot
.31625 .46075 Mdot
.42541 .47334 Mdot
.33614 .57109 Mdot
.3049 .59576 Mdot
.45722 .33029 Mdot
.6772 .46775 Mdot
.34592 .58396 Mdot
.278 .44142 Mdot
.51117 .65642 Mdot
.49598 .64911 Mdot
.69462 .43623 Mdot
.36284 .76489 Mdot
.29656 .57102 Mdot
.59671 .56117 Mdot
.69675 .48662 Mdot
.64491 .45013 Mdot
.52968 .63008 Mdot
.60318 .63657 Mdot
.65005 .50802 Mdot
.34264 .60842 Mdot
.4507 .32485 Mdot
.46177 .40615 Mdot
.46408 .32203 Mdot
.69491 .48243 Mdot
.51127 .68994 Mdot
.71182 .46489 Mdot
.53842 .59439 Mdot
.19116 .7042 Mdot
.5518 .65908 Mdot
.44848 .59211 Mdot
.38132 .56217 Mdot
.32593 .47525 Mdot
.32942 .47344 Mdot
.57302 .39314 Mdot
.65832 .50153 Mdot
.55166 .67862 Mdot
.31624 .60666 Mdot
.67679 .34951 Mdot
.63795 .52127 Mdot
.34549 .4417 Mdot
.32974 .41442 Mdot
.45357 .2875 Mdot
.57369 .64196 Mdot
.54117 .63778 Mdot
.30371 .42081 Mdot
.33562 .26593 Mdot
.68309 .46315 Mdot
.55059 .63036 Mdot
.53381 .66306 Mdot
.31576 .45342 Mdot
.44936 .35606 Mdot
.6369 .45714 Mdot
.53198 .66319 Mdot
.36516 .73244 Mdot
.47847 .32325 Mdot
.49569 .60413 Mdot
.55773 .67005 Mdot
.31959 .58285 Mdot
.34336 .65335 Mdot
.36116 .75586 Mdot
.44462 .26813 Mdot
.57632 .40475 Mdot
.56906 .59244 Mdot
.31918 .47448 Mdot
.5336 .56866 Mdot
.44336 .20452 Mdot
.58691 .37806 Mdot
.5577 .63764 Mdot
.49785 .66228 Mdot
.7012 .47258 Mdot
.55912 .62984 Mdot
.61341 .38814 Mdot
.33424 .45001 Mdot
.55809 .63835 Mdot
.78056 .62982 Mdot
.45593 .28642 Mdot
.49544 .67975 Mdot
.30009 .57976 Mdot
.37388 .52489 Mdot
.80533 .45598 Mdot
.33763 .4872 Mdot
.3413 .58766 Mdot
.56455 .64828 Mdot
.3194 .48512 Mdot
.42827 .30355 Mdot
.49928 .5344 Mdot
.48867 .60297 Mdot
.46784 .32151 Mdot
.47898 .30458 Mdot
.32744 .59361 Mdot
.15106 .60402 Mdot
.49787 .66094 Mdot
.54574 .61426 Mdot
.25543 .29895 Mdot
.66742 .51748 Mdot
.55065 .60752 Mdot
.57446 .63905 Mdot
.43611 .30646 Mdot
.45244 .78593 Mdot
.4085 .60924 Mdot
.34965 .26778 Mdot
.47473 .32552 Mdot
.31926 .4039 Mdot
.33305 .44061 Mdot
.34091 .58915 Mdot
.66062 .48819 Mdot
.32841 .56811 Mdot
.32486 .45285 Mdot
.52044 .62443 Mdot
.4443 .2819 Mdot
.70831 .5552 Mdot
.46709 .33546 Mdot
.27841 .45524 Mdot
.63441 .48458 Mdot
.77769 .40836 Mdot
.36442 .19533 Mdot
.74446 .40587 Mdot
.45591 .26345 Mdot
.32138 .58676 Mdot
.53239 .23756 Mdot
.56348 .64534 Mdot
.60442 .75551 Mdot
.54548 .61121 Mdot
.63004 .56928 Mdot
.33066 .42892 Mdot
.56293 .38466 Mdot
.53927 .59753 Mdot
.39452 .62429 Mdot
.43397 .28031 Mdot
.47552 .28794 Mdot
.5188 .64827 Mdot
.46831 .31107 Mdot
.54578 .63789 Mdot
.31323 .44726 Mdot
.15689 .60829 Mdot
.57229 .63041 Mdot
.52182 .68437 Mdot
.42906 .3224 Mdot
.59763 .41744 Mdot
.28136 .40397 Mdot
.71346 .70437 Mdot
.66011 .23276 Mdot
.46949 .30627 Mdot
.44319 .62466 Mdot
.29274 .42995 Mdot
.56537 .40241 Mdot
.3542 .44873 Mdot
.53788 .62051 Mdot
.58157 .62549 Mdot
.5112 .62961 Mdot
.56065 .64889 Mdot
.6286 .73106 Mdot
.46973 .66237 Mdot
.70073 .62769 Mdot
.56233 .59823 Mdot
.45008 .59258 Mdot
.45448 .31763 Mdot
.52037 .70792 Mdot
.35395 .53057 Mdot
.58064 .63565 Mdot
.64114 .53564 Mdot
.45542 .32546 Mdot
.73008 .35522 Mdot
.44939 .3023 Mdot
.29429 .45153 Mdot
.46165 .27223 Mdot
.54257 .59199 Mdot
.6749 .49144 Mdot
.32214 .43652 Mdot
.68244 .40833 Mdot
.30438 .41312 Mdot
.56387 .63172 Mdot
.44278 .23218 Mdot
.31769 .47887 Mdot
.51183 .72069 Mdot
.67289 .49282 Mdot
.40298 .66707 Mdot
.65277 .51606 Mdot
.55822 .62333 Mdot
.55726 .61543 Mdot
.56074 .38948 Mdot
.44095 .27553 Mdot
.68397 .44217 Mdot
.18345 .56865 Mdot
.30583 .60838 Mdot
.66554 .48118 Mdot
.54029 .69786 Mdot
.50931 .43176 Mdot
.69992 .46067 Mdot
.41919 .67182 Mdot
.4355 .28195 Mdot
.65107 .47544 Mdot
.5936 .64375 Mdot
.62899 .6793 Mdot
.31822 .61347 Mdot
.32723 .48336 Mdot
.49164 .46073 Mdot
.33395 .4434 Mdot
.4751 .33931 Mdot
.34553 .43385 Mdot
.45237 .31329 Mdot
.61095 .44766 Mdot
.41751 .5014 Mdot
.48579 .33257 Mdot
.46063 .34623 Mdot
.3239 .46172 Mdot
.51392 .64307 Mdot
.42423 .43315 Mdot
.59459 .65896 Mdot
.49145 .6854 Mdot
.47707 .32053 Mdot
.64958 .48636 Mdot
.70479 .45072 Mdot
.52567 .53104 Mdot
.70674 .47934 Mdot
.31547 .43524 Mdot
.55461 .43562 Mdot
.57652 .76434 Mdot
.45499 .28356 Mdot
.27757 .4839 Mdot
.50354 .62649 Mdot
.32573 .46813 Mdot
.30995 .43263 Mdot
.47436 .31169 Mdot
.64514 .65187 Mdot
.48737 .67821 Mdot
.69243 .5096 Mdot
.6601 .46009 Mdot
.69781 .45752 Mdot
.64963 .45949 Mdot
.38257 .79078 Mdot
.47946 .33124 Mdot
.65316 .49461 Mdot
.50967 .64777 Mdot
.57527 .60678 Mdot
.58778 .40009 Mdot
.34152 .60739 Mdot
.58948 .62076 Mdot
.56741 .67537 Mdot
.5308 .63028 Mdot
.32433 .47586 Mdot
.6194 .62265 Mdot
.58669 .37923 Mdot
.33844 .4246 Mdot
.34809 .44431 Mdot
.57174 .39954 Mdot
.61343 .45488 Mdot
.70996 .25501 Mdot
.51525 .62744 Mdot
.76378 .45838 Mdot
.31958 .47247 Mdot
.472 .52732 Mdot
.49596 .55906 Mdot
.49501 .61687 Mdot
.40973 .41038 Mdot
.31407 .44187 Mdot
.71957 .43464 Mdot
.54161 .62101 Mdot
.56534 .39049 Mdot
.30471 .5973 Mdot
.5854 .67114 Mdot
.57041 .40545 Mdot
.66929 .46874 Mdot
.23122 .41112 Mdot
.71002 .49842 Mdot
.31617 .4799 Mdot
.50119 .68021 Mdot
.44433 .90829 Mdot
.30022 .44597 Mdot
.66497 .33605 Mdot
.41185 .5056 Mdot
.56962 .63372 Mdot
.32364 .43301 Mdot
.68409 .43264 Mdot
.47883 .32263 Mdot
.48838 .43155 Mdot
.65729 .48802 Mdot
.56279 .39385 Mdot
.58163 .40215 Mdot
.31675 .45599 Mdot
.67294 .4502 Mdot
.54404 .67198 Mdot
.69465 .49413 Mdot
.45611 .2777 Mdot
.52383 .59091 Mdot
.67146 .24797 Mdot
.49545 .69445 Mdot
.6929 .49362 Mdot
.27659 .43309 Mdot
.35452 .60311 Mdot
.52008 .58417 Mdot
.72301 .3256 Mdot
.57203 .64328 Mdot
.44835 .29303 Mdot
.43996 .52732 Mdot
.70335 .56177 Mdot
.51992 .63873 Mdot
.50585 .62224 Mdot
.44214 .32232 Mdot
.51985 .63517 Mdot
.48884 .62965 Mdot
.48135 .36802 Mdot
.70168 .46556 Mdot
.55212 .64657 Mdot
.33551 .4393 Mdot
.76927 .51863 Mdot
.54569 .59645 Mdot
.60829 .37196 Mdot
.39832 .64899 Mdot
.42928 .51421 Mdot
.54554 .6796 Mdot
.32738 .66774 Mdot
.55413 .61531 Mdot
.49041 .61962 Mdot
.51274 .63522 Mdot
.69746 .70988 Mdot
.32561 .4577 Mdot
.34492 .45006 Mdot
.3011 .59211 Mdot
.39876 .63549 Mdot
.32862 .57841 Mdot
.44018 .31889 Mdot
.2693 .47662 Mdot
.57801 .37563 Mdot
.67997 .46744 Mdot
.54525 .59867 Mdot
.31061 .41433 Mdot
.53708 .63109 Mdot
.51326 .60194 Mdot
.32014 .44181 Mdot
.31017 .43567 Mdot
.34402 .48335 Mdot
.3365 .6229 Mdot
.67648 .47706 Mdot
.53043 .6116 Mdot
.34807 .61831 Mdot
.55566 .66603 Mdot
.50625 .40456 Mdot
.67446 .47845 Mdot
.6964 .49211 Mdot
.71409 .46342 Mdot
.56746 .59817 Mdot
.53752 .59029 Mdot
.46175 .31971 Mdot
.69617 .43701 Mdot
.47832 .28748 Mdot
.32544 .43437 Mdot
.33169 .46635 Mdot
.53786 .61989 Mdot
.58815 .55757 Mdot
.34125 .60271 Mdot
.28997 .44542 Mdot
.59588 .39078 Mdot
.29872 .58481 Mdot
.55331 .6538 Mdot
.33044 .43904 Mdot
.30011 .57097 Mdot
.65117 .56411 Mdot
.62984 .20745 Mdot
.34227 .62476 Mdot
.51913 .64889 Mdot
.7926 .59872 Mdot
.36573 .74126 Mdot
.31784 .62022 Mdot
.44498 .30253 Mdot
.57779 .62459 Mdot
.36086 .22842 Mdot
.34346 .57581 Mdot
.36517 .76332 Mdot
.3243 .44453 Mdot
.60171 .54401 Mdot
.58022 .67708 Mdot
.58846 .76526 Mdot
.34788 .58059 Mdot
.68903 .49398 Mdot
.66048 .45494 Mdot
.5245 .64727 Mdot
.33742 .52177 Mdot
.47732 .33661 Mdot
.28905 .45582 Mdot
.33626 .42771 Mdot
.68606 .44643 Mdot
.54098 .42589 Mdot
.3344 .43906 Mdot
.47875 .61421 Mdot
.28685 .57756 Mdot
.48627 .70348 Mdot
.42337 .8197 Mdot
.79382 .46421 Mdot
.53453 .67951 Mdot
.35457 .60988 Mdot
.42898 .28613 Mdot
.46726 .31576 Mdot
.46032 .3114 Mdot
.33353 .464 Mdot
.52157 .46742 Mdot
.33257 .42705 Mdot
.58321 .34373 Mdot
.33629 .59924 Mdot
.41781 .70411 Mdot
.58121 .65683 Mdot
.56922 .63311 Mdot
.49838 .64505 Mdot
.51132 .62784 Mdot
.55335 .61727 Mdot
.48122 .31304 Mdot
.30164 .47577 Mdot
.28042 .30364 Mdot
.68386 .4516 Mdot
.55323 .29387 Mdot
.31053 .47465 Mdot
.5798 .40903 Mdot
.31891 .59976 Mdot
.35165 .66417 Mdot
.28262 .59442 Mdot
.29092 .45512 Mdot
.50035 .58773 Mdot
.64606 .48119 Mdot
.54362 .77759 Mdot
.56214 .60645 Mdot
.2885 .44187 Mdot
.33005 .40943 Mdot
.65229 .64729 Mdot
.56679 .56979 Mdot
.33461 .51946 Mdot
.51153 .43642 Mdot
.35667 .6228 Mdot
.53113 .57316 Mdot
.48581 .52033 Mdot
.32335 .45388 Mdot
.30221 .45949 Mdot
.32936 .62555 Mdot
.6012 .67838 Mdot
.65788 .47233 Mdot
.56447 .38078 Mdot
.44363 .30646 Mdot
.5702 .61477 Mdot
.33444 .46041 Mdot
.71868 .42705 Mdot
.48016 .41215 Mdot
.45516 .29504 Mdot
.33491 .41955 Mdot
.57767 .63401 Mdot
.52308 .64316 Mdot
.33478 .58938 Mdot
.19768 .49623 Mdot
.59355 .6601 Mdot
.67545 .34815 Mdot
.5437 .45736 Mdot
.39361 .51712 Mdot
.53447 .6354 Mdot
.70828 .46151 Mdot
.57099 .39685 Mdot
.30839 .5927 Mdot
.56403 .65991 Mdot
.68528 .23541 Mdot
.71969 .48837 Mdot
.47839 .29714 Mdot
.56801 .39582 Mdot
.51241 .47693 Mdot
.57076 .64422 Mdot
.54512 .61176 Mdot
.52412 .6583 Mdot
.68575 .23216 Mdot
.33864 .43729 Mdot
.67103 .44207 Mdot
.32483 .57396 Mdot
.69563 .49533 Mdot
.34875 .46234 Mdot
.38931 .51545 Mdot
.54059 .66128 Mdot
.70678 .4978 Mdot
.6814 .49853 Mdot
.45642 .28546 Mdot
.43012 .29568 Mdot
.32238 .48889 Mdot
.56405 .64703 Mdot
.57107 .37721 Mdot
.6516 .48343 Mdot
.2875 .45735 Mdot
.33427 .58986 Mdot
.49736 .29199 Mdot
.56269 .59796 Mdot
.31966 .45688 Mdot
.52252 .67717 Mdot
.69561 .46639 Mdot
.2963 .46291 Mdot
.57262 .40957 Mdot
.33949 .60935 Mdot
.57996 .61185 Mdot
.25272 .34294 Mdot
.56506 .39371 Mdot
.5509 .58342 Mdot
.78656 .4703 Mdot
.34764 .52489 Mdot
.71412 .413 Mdot
.32135 .42413 Mdot
.57233 .37981 Mdot
.66031 .44878 Mdot
.62609 .69223 Mdot
.30437 .4577 Mdot
.8114 .55501 Mdot
.44001 .41606 Mdot
.51949 .62176 Mdot
.66113 .47621 Mdot
.34215 .63324 Mdot
.68345 .34362 Mdot
.35053 .72008 Mdot
.5511 .63705 Mdot
.33454 .44431 Mdot
.30351 .59359 Mdot
.47491 .28566 Mdot
.59844 .36477 Mdot
.46536 .82605 Mdot
.33497 .42182 Mdot
.54141 .60249 Mdot
.64993 .48262 Mdot
.476 .30513 Mdot
.8256 .53623 Mdot
.27823 .44532 Mdot
.32426 .42799 Mdot
.49614 .63681 Mdot
.32094 .57366 Mdot
.36637 .22839 Mdot
.34319 .44696 Mdot
.31533 .48338 Mdot
.53122 .36213 Mdot
.30743 .60545 Mdot
.51613 .65141 Mdot
.52434 .53136 Mdot
.52811 .66455 Mdot
.60389 .32675 Mdot
.57159 .37925 Mdot
.68342 .45278 Mdot
.55218 .60276 Mdot
.26061 .33033 Mdot
.30473 .45016 Mdot
.51488 .43919 Mdot
.41526 .31517 Mdot
.43052 .2932 Mdot
.3335 .45144 Mdot
.54144 .62764 Mdot
.49195 .29179 Mdot
.34105 .59727 Mdot
.53251 .66327 Mdot
.53776 .59261 Mdot
.67637 .43376 Mdot
.44711 .28045 Mdot
.77369 .51132 Mdot
.46368 .27631 Mdot
.45666 .33077 Mdot
.6449 .44977 Mdot
.5258 .64827 Mdot
.29248 .45302 Mdot
.27587 .45241 Mdot
.53691 .67525 Mdot
.47169 .52659 Mdot
.65844 .47404 Mdot
.33685 .50112 Mdot
.65865 .20875 Mdot
.49849 .65692 Mdot
.59291 .40104 Mdot
.624 .5445 Mdot
.48538 .31837 Mdot
.52178 .62532 Mdot
.68756 .46706 Mdot
.29875 .47722 Mdot
.33845 .45022 Mdot
.57559 .58348 Mdot
.47502 .31244 Mdot
.30598 .56797 Mdot
.30739 .43072 Mdot
.48294 .40287 Mdot
.55968 .63545 Mdot
.56065 .36988 Mdot
.3041 .42974 Mdot
.81998 .45626 Mdot
.2666 .3198 Mdot
.68956 .44913 Mdot
.50417 .60799 Mdot
.64733 .49854 Mdot
.32911 .57446 Mdot
.35083 .4398 Mdot
.47014 .31858 Mdot
.55524 .74664 Mdot
.17136 .5143 Mdot
.3278 .46454 Mdot
.67225 .47079 Mdot
.53914 .60601 Mdot
.48878 .56928 Mdot
.57192 .63699 Mdot
.45447 .78159 Mdot
.29096 .58144 Mdot
.48192 .34221 Mdot
.48219 .29302 Mdot
.51008 .61477 Mdot
.34334 .61753 Mdot
.29588 .4826 Mdot
.32099 .44349 Mdot
.17913 .65634 Mdot
.57018 .40609 Mdot
.36343 .46641 Mdot
.56721 .59842 Mdot
.28348 .44762 Mdot
.77982 .60822 Mdot
.48084 .28837 Mdot
.52757 .66623 Mdot
.30529 .40804 Mdot
.60272 .30707 Mdot
.50753 .43238 Mdot
.55609 .63717 Mdot
.57586 .55821 Mdot
.44731 .30255 Mdot
.53285 .23696 Mdot
.31787 .42132 Mdot
.54921 .6662 Mdot
.44399 .25667 Mdot
.60018 .43713 Mdot
.18661 .56524 Mdot
.67653 .47746 Mdot
.28248 .41352 Mdot
.44581 .3193 Mdot
.61372 .59217 Mdot
.3438 .60167 Mdot
.29321 .47608 Mdot
.30061 .4107 Mdot
.51569 .59455 Mdot
.58836 .61708 Mdot
.57801 .56396 Mdot
.66415 .47038 Mdot
.43575 .30384 Mdot
.5205 .60688 Mdot
.51879 .40824 Mdot
.51512 .6222 Mdot
.4407 .3124 Mdot
.32795 .84667 Mdot
.55499 .58001 Mdot
.56594 .60448 Mdot
.4775 .71944 Mdot
.6911 .44366 Mdot
.70343 .47378 Mdot
.53336 .43244 Mdot
.56959 .59931 Mdot
.44767 .39936 Mdot
.67803 .47486 Mdot
.66 .48149 Mdot
.44517 .40128 Mdot
.52063 .58924 Mdot
.43274 .25337 Mdot
.47459 .30754 Mdot
.43044 .2949 Mdot
.70109 .47419 Mdot
.47099 .67827 Mdot
.42765 .29855 Mdot
.63788 .72352 Mdot
.29685 .46486 Mdot
.48646 .5201 Mdot
.69289 .49532 Mdot
.46629 .42697 Mdot
.44024 .2772 Mdot
.84979 .50239 Mdot
.53635 .7707 Mdot
.51938 .66662 Mdot
.5209 .64279 Mdot
.32277 .58212 Mdot
.46226 .59947 Mdot
.57855 .40517 Mdot
.46623 .31318 Mdot
.35804 .2844 Mdot
.67462 .48314 Mdot
.57468 .6155 Mdot
.3274 .69351 Mdot
.80117 .46764 Mdot
.51321 .53081 Mdot
.66015 .48933 Mdot
.67249 .48743 Mdot
.29657 .41961 Mdot
.29444 .46296 Mdot
.53255 .65827 Mdot
.45833 .31478 Mdot
.65586 .46427 Mdot
.43782 .29202 Mdot
.32393 .45237 Mdot
.2992 .46559 Mdot
.59225 .38526 Mdot
.47495 .65534 Mdot
.33069 .45207 Mdot
.53327 .35514 Mdot
.51729 .40684 Mdot
.6791 .43464 Mdot
.34699 .21609 Mdot
.83042 .55573 Mdot
.49055 .72277 Mdot
.3055 .59869 Mdot
.60816 .44546 Mdot
.45526 .26782 Mdot
.50949 .61684 Mdot
.53633 .61533 Mdot
.58763 .39171 Mdot
.44713 .26861 Mdot
.31542 .59023 Mdot
.44419 .2735 Mdot
.31421 .60153 Mdot
.3445 .45873 Mdot
.54985 .59445 Mdot
.56015 .65483 Mdot
.47589 .2916 Mdot
.29029 .42652 Mdot
.3191 .47907 Mdot
.32583 .61644 Mdot
.3664 .65421 Mdot
.3175 .45458 Mdot
.69275 .49558 Mdot
.76382 .54208 Mdot
.58338 .40113 Mdot
.54225 .62114 Mdot
.33276 .67775 Mdot
.64385 .69339 Mdot
.52116 .61806 Mdot
.56693 .39507 Mdot
.15295 .6241 Mdot
.54696 .59438 Mdot
.28047 .75976 Mdot
.58456 .37901 Mdot
.71113 .46285 Mdot
.29642 .42834 Mdot
.56737 .40217 Mdot
.61925 .61749 Mdot
.36019 .49707 Mdot
.50961 .67656 Mdot
.65545 .47681 Mdot
.70977 .4904 Mdot
.41982 .49045 Mdot
.60109 .32541 Mdot
.32067 .57205 Mdot
.32423 .59936 Mdot
.30699 .45802 Mdot
.50175 .3541 Mdot
.49407 .57939 Mdot
.32193 .59584 Mdot
.38445 .24744 Mdot
.50253 .62703 Mdot
.36688 .52597 Mdot
.42303 .41803 Mdot
.70206 .45437 Mdot
.52409 .70877 Mdot
.3049 .45405 Mdot
.67225 .47146 Mdot
.4248 .45305 Mdot
.51362 .65821 Mdot
.67412 .48026 Mdot
.43377 .29744 Mdot
.43522 .37465 Mdot
.70434 .48698 Mdot
.48679 .42755 Mdot
.47279 .30252 Mdot
.34987 .52512 Mdot
.40878 .72673 Mdot
.72779 .2255 Mdot
.46371 .31492 Mdot
.28947 .43278 Mdot
.33181 .46177 Mdot
.31439 .45124 Mdot
.65622 .48515 Mdot
.30607 .43751 Mdot
.67292 .45722 Mdot
.44077 .33705 Mdot
.35053 .6579 Mdot
.32956 .58962 Mdot
.30894 .53012 Mdot
.68801 .48964 Mdot
.59756 .34203 Mdot
.27808 .26239 Mdot
.51344 .64766 Mdot
.48347 .33355 Mdot
.35196 .6187 Mdot
.56663 .46722 Mdot
.31985 .58197 Mdot
.29389 .42861 Mdot
.48891 .51912 Mdot
.5461 .63901 Mdot
.77036 .4424 Mdot
.3021 .58765 Mdot
.65862 .48865 Mdot
.49385 .59802 Mdot
.27874 .46705 Mdot
.33834 .58316 Mdot
.31104 .6055 Mdot
.55151 .6176 Mdot
.70591 .49199 Mdot
.29205 .45464 Mdot
.46412 .26874 Mdot
.32295 .62629 Mdot
.56462 .55363 Mdot
.51583 .64126 Mdot
.52667 .57807 Mdot
.52544 .44603 Mdot
.36997 .21825 Mdot
.46899 .3039 Mdot
.35851 .74398 Mdot
.32893 .46795 Mdot
.35377 .72518 Mdot
.68921 .36981 Mdot
.2778 .5869 Mdot
.57432 .37776 Mdot
.57057 .37958 Mdot
.55522 .63066 Mdot
.40111 .19956 Mdot
.4538 .57817 Mdot
.4257 .2704 Mdot
.58246 .39854 Mdot
.31731 .47943 Mdot
.71976 .44972 Mdot
.55768 .70663 Mdot
.58798 .64615 Mdot
.44427 .2689 Mdot
.31999 .44893 Mdot
.44404 .20362 Mdot
.33521 .59862 Mdot
.55849 .46355 Mdot
.55846 .64878 Mdot
.54937 .62746 Mdot
.46325 .29376 Mdot
.46401 .31874 Mdot
.55703 .36062 Mdot
.44671 .49243 Mdot
.684 .26158 Mdot
.44163 .33 Mdot
.44198 .20247 Mdot
.75622 .48262 Mdot
.69736 .47667 Mdot
.59005 .40365 Mdot
.43363 .31314 Mdot
.55154 .60569 Mdot
.7088 .45861 Mdot
.47977 .5507 Mdot
.72041 .4331 Mdot
.36807 .52628 Mdot
.46512 .40546 Mdot
.55813 .65071 Mdot
.64539 .47583 Mdot
.67199 .47389 Mdot
.6425 .48476 Mdot
.57363 .39941 Mdot
.53154 .63439 Mdot
.5124 .64315 Mdot
.54526 .5943 Mdot
.48468 .57439 Mdot
.55955 .62999 Mdot
.68993 .36619 Mdot
.52398 .40166 Mdot
.22288 .54448 Mdot
.55893 .59571 Mdot
.43988 .31395 Mdot
.55207 .59583 Mdot
.34541 .61353 Mdot
.5746 .59956 Mdot
.36521 .52714 Mdot
.46068 .30636 Mdot
.60909 .67981 Mdot
.29865 .49494 Mdot
.54961 .65764 Mdot
.31033 .56918 Mdot
.37512 .21257 Mdot
.33216 .70762 Mdot
.53154 .3616 Mdot
.69388 .49444 Mdot
.33284 .48512 Mdot
.48925 .32238 Mdot
.2953 .45678 Mdot
.53105 .66902 Mdot
.59397 .38527 Mdot
.77674 .69909 Mdot
.45858 .43854 Mdot
.55271 .60417 Mdot
.47379 .64884 Mdot
.70645 .46168 Mdot
.30377 .4472 Mdot
.75174 .4576 Mdot
.49852 .63914 Mdot
.34279 .5806 Mdot
.3523 .60243 Mdot
.39888 .49322 Mdot
.39869 .3214 Mdot
.5579 .76674 Mdot
.46375 .29602 Mdot
.33834 .45884 Mdot
.34612 .57794 Mdot
.62807 .53229 Mdot
.47561 .33637 Mdot
.48595 .31696 Mdot
.44586 .28184 Mdot
.56651 .63065 Mdot
.59242 .39222 Mdot
.38483 .28904 Mdot
.56459 .39801 Mdot
.50762 .65049 Mdot
.30403 .41043 Mdot
.56461 .40072 Mdot
.32603 .57981 Mdot
.46074 .33134 Mdot
.32001 .47665 Mdot
.55866 .61755 Mdot
.68341 .47664 Mdot
.33957 .73735 Mdot
.20412 .37995 Mdot
.32748 .5175 Mdot
.32656 .51708 Mdot
.71723 .47396 Mdot
.74132 .3343 Mdot
.49706 .32954 Mdot
.64493 .66141 Mdot
.33851 .64034 Mdot
.53434 .67524 Mdot
.19614 .64153 Mdot
.33009 .42554 Mdot
.32039 .43534 Mdot
.55608 .64309 Mdot
.28172 .45018 Mdot
.57554 .62746 Mdot
.31175 .41958 Mdot
.65437 .31962 Mdot
.58847 .64831 Mdot
.31697 .43538 Mdot
.50521 .57259 Mdot
.52518 .5827 Mdot
.70995 .46721 Mdot
.29261 .47447 Mdot
.51745 .66586 Mdot
.72348 .76071 Mdot
.46189 .28491 Mdot
.57456 .40015 Mdot
.31501 .51287 Mdot
.45655 .27142 Mdot
.6647 .46119 Mdot
.56673 .59272 Mdot
.3395 .59557 Mdot
.69352 .4834 Mdot
.28649 .47979 Mdot
.3021 .58056 Mdot
.55238 .43427 Mdot
.69957 .47636 Mdot
.58858 .3963 Mdot
.33716 .61085 Mdot
.50899 .67634 Mdot
.32204 .4385 Mdot
.24556 .3384 Mdot
.5671 .39985 Mdot
.54183 .63685 Mdot
.27943 .41477 Mdot
.44474 .27339 Mdot
.53613 .65609 Mdot
.33675 .45804 Mdot
.57007 .39824 Mdot
.54733 .58381 Mdot
.55218 .58259 Mdot
.58161 .70278 Mdot
.43555 .54299 Mdot
.33 .58644 Mdot
.63731 .46163 Mdot
.50992 .64874 Mdot
.34114 .61907 Mdot
.27647 .34186 Mdot
.5726 .66519 Mdot
.66998 .50814 Mdot
.60424 .71242 Mdot
.28552 .4479 Mdot
.4815 .29068 Mdot
.27742 .45202 Mdot
.29846 .57914 Mdot
.15109 .42443 Mdot
.58666 .40506 Mdot
.47582 .63989 Mdot
.49078 .63557 Mdot
.34585 .429 Mdot
.66975 .47626 Mdot
.69795 .27673 Mdot
.57658 .60526 Mdot
.49789 .69273 Mdot
.54672 .61853 Mdot
.25621 .34786 Mdot
.65846 .47826 Mdot
.54414 .61917 Mdot
.55823 .54996 Mdot
.4949 .64835 Mdot
.31951 .56691 Mdot
.42969 .71631 Mdot
.53307 .6055 Mdot
.50853 .92112 Mdot
.58141 .37369 Mdot
.3179 .4425 Mdot
.49821 .43104 Mdot
.25619 .47554 Mdot
.38897 .80999 Mdot
.66655 .46311 Mdot
.69984 .52893 Mdot
.29408 .45664 Mdot
.32011 .72798 Mdot
.746 .34866 Mdot
.51556 .58421 Mdot
.57875 .6258 Mdot
.29384 .42868 Mdot
.29006 .46109 Mdot
.58873 .37656 Mdot
.58062 .64171 Mdot
.49071 .69171 Mdot
.27941 .42488 Mdot
.56332 .61525 Mdot
.67402 .66874 Mdot
.48914 .29143 Mdot
.70189 .47259 Mdot
.47369 .28488 Mdot
.48641 .31168 Mdot
.59146 .74975 Mdot
.54368 .45936 Mdot
.45096 .31923 Mdot
.45379 .26073 Mdot
.36401 .56222 Mdot
.53279 .75324 Mdot
.32366 .56803 Mdot
.41222 .33149 Mdot
.31163 .45748 Mdot
.52991 .63321 Mdot
.65591 .49088 Mdot
.52398 .80964 Mdot
.59686 .21041 Mdot
.5116 .50975 Mdot
.50838 .64285 Mdot
.30731 .45086 Mdot
.56755 .39816 Mdot
.58643 .65369 Mdot
.36246 .73592 Mdot
.55025 .63339 Mdot
.29526 .46553 Mdot
.57821 .76457 Mdot
.61384 .396 Mdot
.44473 .33145 Mdot
.72418 .44859 Mdot
.54915 .59623 Mdot
.68667 .46083 Mdot
.46 .32398 Mdot
.33818 .6222 Mdot
.32203 .58822 Mdot
.55436 .65619 Mdot
.4183 .5005 Mdot
.36369 .63239 Mdot
.51502 .58471 Mdot
.51823 .59292 Mdot
.57661 .37786 Mdot
.51961 .59247 Mdot
.55051 .66419 Mdot
.51949 .60997 Mdot
.57501 .65719 Mdot
.44674 .32591 Mdot
.7405 .42486 Mdot
.58526 .61383 Mdot
.48889 .64434 Mdot
.47901 .27517 Mdot
.60653 .61547 Mdot
.45023 .30492 Mdot
.62826 .21896 Mdot
.44572 .31059 Mdot
.32348 .58869 Mdot
.27279 .4244 Mdot
.73989 .49954 Mdot
.65693 .46262 Mdot
.43997 .31563 Mdot
.32551 .60734 Mdot
.46263 .31343 Mdot
.34115 .45003 Mdot
.30382 .25438 Mdot
.63771 .5037 Mdot
.50872 .3934 Mdot
.50337 .74095 Mdot
.55839 .37076 Mdot
.28248 .43568 Mdot
.68346 .44709 Mdot
.61228 .38791 Mdot
.51191 .61201 Mdot
.33758 .58958 Mdot
.5545 .63017 Mdot
.46592 .33291 Mdot
.30931 .45308 Mdot
.41883 .26763 Mdot
.32913 .58553 Mdot
.174 .40034 Mdot
.30866 .41452 Mdot
.48117 .64097 Mdot
.48104 .27813 Mdot
.32361 .23528 Mdot
.44811 .30905 Mdot
.35009 .65907 Mdot
.61842 .47505 Mdot
.49403 .80624 Mdot
.67916 .48929 Mdot
.56824 .36459 Mdot
.78093 .33137 Mdot
.71276 .33911 Mdot
.69199 .47484 Mdot
.29924 .49571 Mdot
.56356 .62804 Mdot
.51252 .62397 Mdot
.4804 .59783 Mdot
.73666 .44725 Mdot
.52235 .65703 Mdot
.58167 .40461 Mdot
.53474 .44614 Mdot
.36853 .24181 Mdot
.32683 .48645 Mdot
.57475 .63249 Mdot
.47826 .31966 Mdot
.46172 .33416 Mdot
.56256 .3976 Mdot
.45401 .27585 Mdot
.52909 .58409 Mdot
.68607 .48965 Mdot
.42417 .43645 Mdot
.3306 .5759 Mdot
.66914 .35427 Mdot
.34809 .63972 Mdot
.29645 .60843 Mdot
.49719 .65378 Mdot
.29813 .4645 Mdot
.17171 .57137 Mdot
.50858 .62175 Mdot
.67725 .47284 Mdot
.4911 .63011 Mdot
.5245 .60749 Mdot
.53578 .60538 Mdot
.33722 .46042 Mdot
.49866 .4271 Mdot
.56317 .61249 Mdot
.45237 .32119 Mdot
.44357 .40398 Mdot
.58808 .64107 Mdot
.36477 .29452 Mdot
.36965 .52629 Mdot
.56077 .37041 Mdot
.68183 .43423 Mdot
.29232 .44216 Mdot
.67499 .48514 Mdot
.72113 .49799 Mdot
.66501 .4607 Mdot
.37056 .27647 Mdot
.63197 .67768 Mdot
.30797 .78327 Mdot
.76454 .62681 Mdot
.58322 .76681 Mdot
.69907 .50567 Mdot
.32138 .32813 Mdot
.69222 .47026 Mdot
.66591 .46137 Mdot
.23761 .75958 Mdot
.66542 .50411 Mdot
.53678 .6211 Mdot
.57028 .58832 Mdot
.7766 .42445 Mdot
.36697 .56613 Mdot
.5653 .59621 Mdot
.52552 .6576 Mdot
.3506 .58976 Mdot
.62634 .61134 Mdot
.58378 .37124 Mdot
.55317 .45779 Mdot
.59425 .40346 Mdot
.55211 .61807 Mdot
.55072 .65259 Mdot
.57197 .58171 Mdot
.7953 .34071 Mdot
.4929 .81817 Mdot
.71501 .47496 Mdot
.60851 .60247 Mdot
.56903 .41692 Mdot
.48671 .62488 Mdot
.49199 .635 Mdot
.54188 .59307 Mdot
.29267 .45379 Mdot
.71884 .4503 Mdot
.58311 .66817 Mdot
.67313 .38755 Mdot
.55691 .65004 Mdot
.30592 .62539 Mdot
.3628 .62156 Mdot
.54048 .62721 Mdot
.67428 .5066 Mdot
.50772 .63369 Mdot
.6469 .49171 Mdot
.70022 .46971 Mdot
.47378 .65778 Mdot
.38814 .29684 Mdot
.72399 .45468 Mdot
.52058 .58248 Mdot
.28739 .42933 Mdot
.67209 .34337 Mdot
.54092 .63473 Mdot
.31557 .57437 Mdot
.52111 .62527 Mdot
.30882 .56819 Mdot
.52966 .59265 Mdot
.5636 .39573 Mdot
.69299 .56996 Mdot
.30409 .46047 Mdot
.32867 .62917 Mdot
.28178 .44505 Mdot
.5036 .71549 Mdot
.67557 .51076 Mdot
.60405 .3836 Mdot
.47936 .82863 Mdot
.57868 .37791 Mdot
.35735 .75134 Mdot
.44289 .39406 Mdot
.48407 .30058 Mdot
.65235 .45564 Mdot
.57462 .76108 Mdot
.38113 .33022 Mdot
.35199 .46836 Mdot
.3495 .44822 Mdot
.18924 .58361 Mdot
.15696 .60996 Mdot
.56467 .60916 Mdot
.35519 .22999 Mdot
.70406 .61194 Mdot
.50143 .57011 Mdot
.5904 .59051 Mdot
.29544 .41194 Mdot
.56389 .59395 Mdot
.48823 .45088 Mdot
.32449 .46121 Mdot
.33026 .60503 Mdot
.68363 .45385 Mdot
.33181 .61576 Mdot
.56203 .19447 Mdot
.5226 .36334 Mdot
.32896 .45654 Mdot
.5793 .6531 Mdot
.57203 .62282 Mdot
.66585 .44316 Mdot
.81545 .55195 Mdot
.70213 .46712 Mdot
.3191 .57071 Mdot
.31563 .46732 Mdot
.56715 .78933 Mdot
.52688 .61787 Mdot
.67679 .49986 Mdot
.29405 .49113 Mdot
.52317 .64211 Mdot
.48101 .2987 Mdot
.50697 .64129 Mdot
.68267 .49995 Mdot
.52041 .59253 Mdot
.68505 .48837 Mdot
.30261 .41975 Mdot
.56677 .65168 Mdot
.54805 .65418 Mdot
.36188 .75586 Mdot
.31473 .58827 Mdot
.6824 .50955 Mdot
.4908 .45216 Mdot
.5276 .66425 Mdot
.36599 .73537 Mdot
.54903 .59438 Mdot
.44132 .6475 Mdot
.60322 .62079 Mdot
.58519 .40346 Mdot
.49117 .63769 Mdot
.54208 .63492 Mdot
.79797 .60352 Mdot
.78689 .60227 Mdot
.47453 .7084 Mdot
.43009 .29768 Mdot
.68464 .50313 Mdot
.33274 .45959 Mdot
.30417 .48032 Mdot
.30157 .43662 Mdot
.3783 .59427 Mdot
.5986 .56547 Mdot
.5448 .6416 Mdot
.46669 .34756 Mdot
.32626 .59845 Mdot
.66543 .49593 Mdot
.3276 .59326 Mdot
.55001 .46587 Mdot
.30726 .57742 Mdot
.58091 .40614 Mdot
.2688 .31617 Mdot
.65749 .6873 Mdot
.30745 .58534 Mdot
.70169 .46788 Mdot
.46765 .39631 Mdot
.53034 .6752 Mdot
.57391 .30913 Mdot
.3432 .58092 Mdot
.18059 .56582 Mdot
.54991 .58591 Mdot
.49123 .43538 Mdot
.45031 .29897 Mdot
.33113 .61526 Mdot
.44872 .28072 Mdot
.50825 .63088 Mdot
.73108 .41697 Mdot
.67512 .4688 Mdot
.4887 .29322 Mdot
.49503 .64379 Mdot
.33235 .61558 Mdot
.32887 .45125 Mdot
.55295 .75898 Mdot
.46605 .26468 Mdot
.33246 .73048 Mdot
.3505 .72066 Mdot
.31835 .46745 Mdot
.61018 .77107 Mdot
.44456 .29103 Mdot
.54778 .67652 Mdot
.60394 .54774 Mdot
.5032 .63375 Mdot
.32262 .47918 Mdot
.31844 .43333 Mdot
.73482 .38388 Mdot
.55741 .65266 Mdot
.57702 .59268 Mdot
.71627 .45297 Mdot
.32604 .46951 Mdot
.66331 .46135 Mdot
.6704 .44347 Mdot
.29245 .4286 Mdot
.68963 .44869 Mdot
.3029 .58989 Mdot
.53429 .47819 Mdot
.4437 .29422 Mdot
.48001 .30526 Mdot
.33092 .45433 Mdot
.33829 .46896 Mdot
.30189 .46913 Mdot
.49828 .63215 Mdot
.67164 .44951 Mdot
.50128 .60718 Mdot
.54672 .59826 Mdot
.63431 .45248 Mdot
.70528 .44629 Mdot
.49947 .61819 Mdot
.42173 .40888 Mdot
.31676 .56461 Mdot
.31508 .43593 Mdot
.43645 .29227 Mdot
.35209 .76125 Mdot
.48439 .28617 Mdot
.52517 .66203 Mdot
.60249 .30956 Mdot
.65675 .48498 Mdot
.32093 .58174 Mdot
.34086 .5232 Mdot
.32648 .58348 Mdot
.48924 .29415 Mdot
.68376 .43708 Mdot
.54611 .43231 Mdot
.56041 .65242 Mdot
.52786 .44761 Mdot
.39665 .74944 Mdot
.69017 .37495 Mdot
.43505 .30309 Mdot
.51427 .64896 Mdot
.58285 .37866 Mdot
.65368 .64755 Mdot
.54861 .64264 Mdot
.52626 .66616 Mdot
.22813 .47015 Mdot
.4922 .64871 Mdot
.66589 .43879 Mdot
.40481 .50761 Mdot
.56698 .65715 Mdot
.4984 .7118 Mdot
.17959 .67344 Mdot
.55116 .58465 Mdot
.54973 .65535 Mdot
.53004 .62365 Mdot
.5072 .61822 Mdot
.64956 .50313 Mdot
.21028 .4562 Mdot
.47138 .32293 Mdot
.53335 .4779 Mdot
.44344 .2871 Mdot
.32815 .43979 Mdot
.46735 .45574 Mdot
.64704 .4955 Mdot
.32634 .58284 Mdot
.34589 .23204 Mdot
.49974 .50888 Mdot
.29373 .42076 Mdot
.41577 .80998 Mdot
.33923 .5784 Mdot
.53417 .67585 Mdot
.30029 .59063 Mdot
.29322 .41089 Mdot
.4736 .31368 Mdot
.50353 .58606 Mdot
.65386 .47685 Mdot
.70349 .48763 Mdot
.50737 .64469 Mdot
.66318 .35059 Mdot
.455 .27021 Mdot
.26395 .6122 Mdot
.56502 .63629 Mdot
.53007 .66734 Mdot
.70055 .46032 Mdot
.30518 .44719 Mdot
.44343 .39582 Mdot
.31612 .59754 Mdot
.48263 .60283 Mdot
.50966 .63235 Mdot
.54694 .46455 Mdot
.44418 .32249 Mdot
.57887 .39187 Mdot
.56219 .64525 Mdot
.54276 .45096 Mdot
.52925 .66198 Mdot
.45721 .64235 Mdot
.28467 .43786 Mdot
.49002 .6858 Mdot
.57977 .63169 Mdot
.7418 .43304 Mdot
.44712 .28656 Mdot
.67383 .47654 Mdot
.62108 .49662 Mdot
.56503 .38901 Mdot
.46671 .28672 Mdot
.49898 .62172 Mdot
.48812 .31433 Mdot
.52056 .6143 Mdot
.56074 .61593 Mdot
.43466 .30223 Mdot
.66713 .45622 Mdot
.68311 .26906 Mdot
.74003 .42406 Mdot
.51589 .60313 Mdot
.51928 .62987 Mdot
.37153 .57025 Mdot
.54197 .82202 Mdot
.58049 .63171 Mdot
.67481 .44677 Mdot
.52387 .64413 Mdot
.48028 .31157 Mdot
.31559 .57161 Mdot
.68305 .47336 Mdot
.34157 .45967 Mdot
.31171 .42156 Mdot
.26076 .41703 Mdot
.58435 .40608 Mdot
.57932 .64293 Mdot
.63712 .46105 Mdot
.71305 .45472 Mdot
.56478 .48674 Mdot
.31802 .44148 Mdot
.30718 .57386 Mdot
.5613 .58978 Mdot
.57082 .74824 Mdot
.48075 .32204 Mdot
.52022 .91612 Mdot
.54329 .42975 Mdot
.3599 .62715 Mdot
.42616 .51396 Mdot
.58277 .38079 Mdot
.56663 .60306 Mdot
.34276 .61555 Mdot
.31363 .42533 Mdot
.51087 .62635 Mdot
.58207 .56201 Mdot
.38371 .34198 Mdot
.34351 .46579 Mdot
.48891 .30663 Mdot
.32831 .4281 Mdot
.3111 .56691 Mdot
.57995 .40563 Mdot
.70859 .48473 Mdot
.54479 .63167 Mdot
.50665 .70525 Mdot
.31297 .44798 Mdot
.56207 .38708 Mdot
.54799 .65936 Mdot
.69315 .49892 Mdot
.30949 .43621 Mdot
.55131 .6128 Mdot
.64702 .65482 Mdot
.72493 .51247 Mdot
.31438 .46216 Mdot
.49171 .59434 Mdot
.54908 .72332 Mdot
.34777 .45987 Mdot
.30968 .4091 Mdot
.52488 .65787 Mdot
.32998 .61327 Mdot
.57301 .64293 Mdot
.45236 .3121 Mdot
.49846 .42628 Mdot
.47422 .29185 Mdot
.36622 .74305 Mdot
.5802 .59158 Mdot
.49559 .53886 Mdot
.64735 .47317 Mdot
.29563 .56587 Mdot
.78374 .64681 Mdot
.54128 .66983 Mdot
.69861 .25584 Mdot
.46884 .42486 Mdot
.52563 .38921 Mdot
.63189 .19846 Mdot
.3114 .59512 Mdot
.4599 .31127 Mdot
.54522 .65819 Mdot
.49448 .34804 Mdot
.31226 .601 Mdot
.36736 .74469 Mdot
.48433 .61943 Mdot
.66016 .48304 Mdot
.56302 .63605 Mdot
.68782 .49947 Mdot
.52292 .63623 Mdot
.62281 .64844 Mdot
.31314 .62699 Mdot
.35193 .65852 Mdot
.53567 .67683 Mdot
.35261 .21963 Mdot
.51689 .74775 Mdot
.32313 .57432 Mdot
.5182 .59917 Mdot
.58174 .38594 Mdot
.44047 .2754 Mdot
.3086 .27393 Mdot
.29598 .46042 Mdot
.44718 .31626 Mdot
.69319 .45443 Mdot
.2746 .42813 Mdot
.56478 .38368 Mdot
.59928 .54418 Mdot
.33527 .61567 Mdot
.46278 .28534 Mdot
.54162 .63183 Mdot
.50181 .64678 Mdot
.25532 .34765 Mdot
.61897 .7919 Mdot
.67394 .4448 Mdot
.16298 .46371 Mdot
.63948 .45872 Mdot
.31918 .59542 Mdot
.2854 .44198 Mdot
.54799 .60551 Mdot
.54959 .64761 Mdot
.33125 .47309 Mdot
.69462 .44428 Mdot
.2879 .57198 Mdot
.50214 .80804 Mdot
.42663 .33786 Mdot
.39574 .67512 Mdot
.68494 .47092 Mdot
.39255 .67278 Mdot
.35316 .58566 Mdot
.41612 .24123 Mdot
.47928 .73936 Mdot
.47976 .29201 Mdot
.3994 .67838 Mdot
.66449 .49748 Mdot
.56542 .60779 Mdot
.58812 .39578 Mdot
.5863 .378 Mdot
.68931 .45854 Mdot
.29181 .4325 Mdot
.34353 .60337 Mdot
.56005 .63881 Mdot
.56995 .51677 Mdot
.82835 .53169 Mdot
.3364 .46856 Mdot
.47251 .63804 Mdot
.45334 .27236 Mdot
.52036 .63919 Mdot
.35322 .60081 Mdot
.47033 .31075 Mdot
.57085 .40766 Mdot
.50324 .50189 Mdot
.56506 .59046 Mdot
.39543 .51563 Mdot
.45523 .29173 Mdot
.54768 .82167 Mdot
.54727 .65382 Mdot
.44473 .29053 Mdot
.50248 .70306 Mdot
.63863 .39812 Mdot
.42975 .42515 Mdot
.71074 .33356 Mdot
.32781 .49115 Mdot
.31771 .42218 Mdot
.69318 .77737 Mdot
.33735 .64052 Mdot
.45028 .32251 Mdot
.57443 .40465 Mdot
.45013 .72701 Mdot
.45571 .27955 Mdot
.51152 .58336 Mdot
.55146 .59308 Mdot
.58007 .76489 Mdot
.49044 .71843 Mdot
.58475 .37301 Mdot
.57531 .53522 Mdot
.51251 .58947 Mdot
.50908 .6821 Mdot
.52961 .65435 Mdot
.71073 .48873 Mdot
.4769 .28398 Mdot
.49932 .12105 Mdot
.48581 .32503 Mdot
.53969 .50941 Mdot
.31133 .45715 Mdot
.30267 .48492 Mdot
.54139 .62638 Mdot
.44157 .58595 Mdot
.39584 .19358 Mdot
.53005 .61293 Mdot
.34449 .52434 Mdot
.34892 .71995 Mdot
.57376 .67048 Mdot
.71732 .49218 Mdot
.49226 .69231 Mdot
.63678 .48858 Mdot
.47197 .31073 Mdot
.31097 .59597 Mdot
.32744 .56432 Mdot
.45448 .30748 Mdot
.54266 .64512 Mdot
.32757 .56228 Mdot
.54817 .62464 Mdot
.57051 .61763 Mdot
.55479 .46381 Mdot
.35125 .62218 Mdot
.30173 .4696 Mdot
.3232 .58676 Mdot
.66388 .46671 Mdot
.25512 .78446 Mdot
.33457 .59423 Mdot
.5358 .75426 Mdot
.48133 .44007 Mdot
.39913 .68154 Mdot
.70523 .48332 Mdot
.32317 .57131 Mdot
.4803 .28859 Mdot
.54695 .42324 Mdot
.60686 .76978 Mdot
.48514 .28922 Mdot
.55284 .64525 Mdot
.6462 .49299 Mdot
.71654 .46862 Mdot
.44114 .32721 Mdot
.70596 .45795 Mdot
.48866 .6645 Mdot
.5192 .58239 Mdot
.45873 .32514 Mdot
.80489 .45648 Mdot
.48166 .28822 Mdot
.56434 .75035 Mdot
.53936 .59095 Mdot
.67998 .47325 Mdot
.44119 .63483 Mdot
.68315 .42852 Mdot
.5927 .38514 Mdot
.57565 .59966 Mdot
.33394 .5843 Mdot
.52105 .46716 Mdot
.31269 .46187 Mdot
.60747 .30836 Mdot
.69429 .4945 Mdot
.48209 .33743 Mdot
.71006 .46956 Mdot
.68061 .44256 Mdot
.48775 .29427 Mdot
.66762 .46991 Mdot
.55515 .65 Mdot
.53954 .21804 Mdot
.69513 .49176 Mdot
.46056 .29645 Mdot
.33845 .58643 Mdot
.6866 .44784 Mdot
.2975 .54949 Mdot
.57306 .61714 Mdot
.28195 .42693 Mdot
.32688 .62682 Mdot
.64344 .48625 Mdot
.31568 .57248 Mdot
.31431 .44405 Mdot
.34469 .60477 Mdot
.47306 .35455 Mdot
.49014 .33689 Mdot
.51057 .5134 Mdot
.62308 .40215 Mdot
.65411 .48804 Mdot
.32962 .49318 Mdot
.57409 .60581 Mdot
.56836 .63129 Mdot
.29918 .5683 Mdot
.71637 .48149 Mdot
.6546 .34469 Mdot
.46305 .5773 Mdot
.66873 .35574 Mdot
.43264 .30816 Mdot
.27121 .66486 Mdot
.54303 .42687 Mdot
.52782 .35862 Mdot
.53693 .57161 Mdot
.58419 .38195 Mdot
.5462 .61812 Mdot
.33126 .70643 Mdot
.32731 .56929 Mdot
.28154 .36311 Mdot
.4933 .57979 Mdot
.31708 .47228 Mdot
.52361 .62846 Mdot
.34526 .24538 Mdot
.48245 .69224 Mdot
.33908 .57515 Mdot
.48946 .28402 Mdot
.65686 .46267 Mdot
.33318 .57605 Mdot
.30657 .42041 Mdot
.41261 .66573 Mdot
.5322 .5781 Mdot
.51947 .586 Mdot
.3447 .43492 Mdot
.66029 .46587 Mdot
.3254 .43851 Mdot
.44371 .29358 Mdot
.33169 .59373 Mdot
.50755 .61438 Mdot
.49343 .68411 Mdot
.34276 .42476 Mdot
.47865 .3312 Mdot
.33445 .47577 Mdot
.48638 .31853 Mdot
.58694 .38462 Mdot
.57562 .65293 Mdot
.33257 .41686 Mdot
.54323 .56914 Mdot
.78458 .58377 Mdot
.541 .48525 Mdot
.74767 .68188 Mdot
.30125 .46955 Mdot
.39295 .61628 Mdot
.45746 .3048 Mdot
.45706 .28389 Mdot
.58617 .7528 Mdot
.39555 .19826 Mdot
.44728 .39951 Mdot
.28012 .27558 Mdot
.44346 .29502 Mdot
.46101 .28935 Mdot
.3086 .42636 Mdot
.67095 .46015 Mdot
.70774 .50856 Mdot
.28974 .40936 Mdot
.33346 .6777 Mdot
.66586 .49634 Mdot
.73221 .29042 Mdot
.33496 .42745 Mdot
.55193 .57577 Mdot
.60238 .3854 Mdot
.34135 .57773 Mdot
.33236 .69904 Mdot
.2959 .26516 Mdot
.54367 .61198 Mdot
.25997 .73635 Mdot
.29329 .44701 Mdot
.43488 .35554 Mdot
.42956 .22746 Mdot
.50848 .65511 Mdot
.52591 .62891 Mdot
.53802 .64839 Mdot
.31931 .62093 Mdot
.80734 .54765 Mdot
.54692 .60863 Mdot
.36454 .64399 Mdot
.58885 .64826 Mdot
.24647 .34352 Mdot
.32343 .58709 Mdot
.45218 .78489 Mdot
.30671 .49345 Mdot
.66533 .38159 Mdot
.49986 .65549 Mdot
.44489 .30002 Mdot
.40178 .37602 Mdot
.44021 .31277 Mdot
.40719 .23373 Mdot
.47538 .74096 Mdot
.70981 .49136 Mdot
.50633 .64125 Mdot
.33123 .42154 Mdot
.64518 .48968 Mdot
.41125 .39298 Mdot
.2215 .74741 Mdot
.4381 .32041 Mdot
.12879 .53056 Mdot
.46933 .28357 Mdot
.58573 .37654 Mdot
.69563 .45885 Mdot
.41692 .62953 Mdot
.53242 .45197 Mdot
.6642 .46031 Mdot
.23332 .57902 Mdot
.65956 .52061 Mdot
.39292 .65091 Mdot
.64197 .5131 Mdot
.46204 .30293 Mdot
.4912 .33433 Mdot
.5926 .57516 Mdot
.58052 .61952 Mdot
.5233 .43888 Mdot
.58264 .58123 Mdot
.57052 .59966 Mdot
.32452 .46145 Mdot
.62314 .39265 Mdot
.50311 .34225 Mdot
.68646 .46595 Mdot
.47233 .32741 Mdot
.52506 .62756 Mdot
.51577 .60267 Mdot
.48619 .63661 Mdot
.32824 .73511 Mdot
.72789 .28446 Mdot
.56173 .61183 Mdot
.4805 .68739 Mdot
.29216 .42319 Mdot
.2522 .34884 Mdot
.17934 .44798 Mdot
.45945 .72885 Mdot
.54808 .66054 Mdot
.31645 .58745 Mdot
.35025 .58735 Mdot
.48703 .6533 Mdot
.49156 .53735 Mdot
.29815 .54568 Mdot
.5414 .63201 Mdot
.40458 .62571 Mdot
.35515 .44675 Mdot
.56157 .39124 Mdot
.31344 .4478 Mdot
.64417 .49077 Mdot
.57918 .377 Mdot
.33661 .4494 Mdot
.41981 .59484 Mdot
.56578 .39087 Mdot
.64296 .39527 Mdot
.32033 .57049 Mdot
.53628 .65589 Mdot
.74912 .47569 Mdot
.33244 .46887 Mdot
.45649 .28797 Mdot
.68793 .48257 Mdot
.43152 .28271 Mdot
.25697 .33192 Mdot
.33752 .6901 Mdot
.58772 .40382 Mdot
.44548 .30477 Mdot
.43227 .48065 Mdot
.31806 .58798 Mdot
.46186 .27719 Mdot
.47912 .55191 Mdot
.58958 .62476 Mdot
.45279 .18164 Mdot
.50409 .59189 Mdot
.73916 .37388 Mdot
.45079 .2893 Mdot
.57723 .41201 Mdot
.54631 .63222 Mdot
.308 .41515 Mdot
.60811 .62821 Mdot
.54957 .6244 Mdot
.3391 .43826 Mdot
.56355 .60843 Mdot
.34814 .61863 Mdot
.63747 .48298 Mdot
.46566 .43278 Mdot
.30745 .70472 Mdot
.34474 .59429 Mdot
.59611 .49222 Mdot
.58193 .62516 Mdot
.21043 .5585 Mdot
.66202 .48069 Mdot
.5342 .66746 Mdot
.38064 .77522 Mdot
.68037 .45806 Mdot
.67447 .48617 Mdot
.5129 .59503 Mdot
.48162 .28497 Mdot
.32159 .47782 Mdot
.31925 .58676 Mdot
.5002 .35643 Mdot
.55181 .6104 Mdot
.51656 .65121 Mdot
.33805 .57789 Mdot
.46602 .28819 Mdot
.50541 .61466 Mdot
.64848 .28581 Mdot
.56167 .48847 Mdot
.48533 .31634 Mdot
.58796 .64031 Mdot
.53354 .1521 Mdot
.70792 .50983 Mdot
.27113 .74947 Mdot
.34188 .6382 Mdot
.28853 .43273 Mdot
.47266 .61045 Mdot
.48089 .92009 Mdot
.32553 .57328 Mdot
.67401 .37529 Mdot
.56581 .61548 Mdot
.54544 .60365 Mdot
.69803 .50087 Mdot
.49807 .6114 Mdot
.67354 .50363 Mdot
.29015 .69382 Mdot
.35346 .19987 Mdot
.70714 .4619 Mdot
.67928 .50253 Mdot
.48625 .70813 Mdot
.33683 .7484 Mdot
.6858 .45292 Mdot
.53428 .57791 Mdot
.22657 .55562 Mdot
.56938 .55548 Mdot
.35952 .62197 Mdot
.31631 .54015 Mdot
.71188 .497 Mdot
.65858 .74969 Mdot
.48275 .70275 Mdot
.60122 .69048 Mdot
.34737 .56494 Mdot
.44134 .30752 Mdot
.53107 .60036 Mdot
.58081 .40713 Mdot
.30954 .43319 Mdot
.51394 .6931 Mdot
.54106 .65377 Mdot
.65888 .50352 Mdot
.30271 .60404 Mdot
.45366 .27813 Mdot
.53116 .65896 Mdot
.32301 .40564 Mdot
.32563 .60513 Mdot
.69736 .48725 Mdot
.54457 .75242 Mdot
.33601 .56903 Mdot
.48538 .67566 Mdot
.56191 .59736 Mdot
.54054 .6621 Mdot
.52415 .55877 Mdot
.45268 .30481 Mdot
.2812 .41512 Mdot
.47452 .60833 Mdot
.55193 .44605 Mdot
.51048 .4709 Mdot
.47608 .62731 Mdot
.67758 .4461 Mdot
.43223 .30354 Mdot
.5712 .39529 Mdot
.41826 .70458 Mdot
.54611 .58699 Mdot
.71478 .26837 Mdot
.45452 .82014 Mdot
.56932 .38878 Mdot
.66293 .51432 Mdot
.32246 .58286 Mdot
.52592 .58767 Mdot
.34695 .65075 Mdot
.50966 .58465 Mdot
.56054 .54736 Mdot
.28927 .43935 Mdot
.43801 .29814 Mdot
.58538 .51117 Mdot
.31109 .43227 Mdot
.67478 .48548 Mdot
.77893 .38554 Mdot
.68823 .51669 Mdot
.67471 .44311 Mdot
.38941 .28525 Mdot
.46803 .31715 Mdot
.49511 .92368 Mdot
.53631 .826 Mdot
.56248 .58225 Mdot
.46901 .32071 Mdot
.69461 .46169 Mdot
.49338 .62256 Mdot
.65711 .49186 Mdot
.72386 .45757 Mdot
.5661 .59499 Mdot
.56967 .60062 Mdot
.36129 .65418 Mdot
.74551 .3092 Mdot
.33778 .59059 Mdot
.70976 .46047 Mdot
.61356 .72841 Mdot
.55127 .60466 Mdot
.56236 .65027 Mdot
.39328 .35899 Mdot
.32723 .57207 Mdot
.67324 .65477 Mdot
.56714 .62951 Mdot
.36882 .77374 Mdot
.57454 .60141 Mdot
.72691 .4902 Mdot
.42575 .31018 Mdot
.52663 .51964 Mdot
.32007 .47986 Mdot
.65283 .45404 Mdot
.3022 .56838 Mdot
.68946 .43325 Mdot
.63063 .69481 Mdot
.47242 .3129 Mdot
.68214 .5002 Mdot
.27339 .44476 Mdot
.47139 .29636 Mdot
.48212 .29439 Mdot
.41437 .39814 Mdot
.27469 .43935 Mdot
.3319 .62563 Mdot
.4378 .28103 Mdot
.64489 .65604 Mdot
.46496 .3034 Mdot
.63514 .68863 Mdot
.57155 .65041 Mdot
.37607 .63814 Mdot
.56932 .51013 Mdot
.58461 .56774 Mdot
.47184 .2804 Mdot
.338 .60703 Mdot
.49926 .627 Mdot
.70289 .45442 Mdot
.33684 .60088 Mdot
.48034 .36803 Mdot
.30137 .48633 Mdot
.71837 .4712 Mdot
.49035 .29002 Mdot
.66157 .50104 Mdot
.34283 .7124 Mdot
.2815 .59391 Mdot
.40995 .41184 Mdot
.5254 .44921 Mdot
.51517 .67881 Mdot
.49421 .71151 Mdot
.49631 .64237 Mdot
.54626 .64854 Mdot
.31443 .46144 Mdot
.37953 .59716 Mdot
.68623 .44752 Mdot
.83625 .51235 Mdot
.44707 .30113 Mdot
.40694 .50726 Mdot
.5719 .5468 Mdot
.517 .61842 Mdot
.69519 .47049 Mdot
.71664 .4457 Mdot
.78695 .60335 Mdot
.33113 .47403 Mdot
.56699 .55671 Mdot
.50252 .66144 Mdot
.61771 .58355 Mdot
.47634 .28767 Mdot
.66613 .27879 Mdot
.31798 .48492 Mdot
.12609 .58012 Mdot
.31563 .43528 Mdot
.21596 .48977 Mdot
.66813 .46884 Mdot
.30451 .57829 Mdot
.56743 .6433 Mdot
.64197 .42583 Mdot
.65495 .50746 Mdot
.34769 .49165 Mdot
.3258 .58039 Mdot
.67882 .27334 Mdot
.45733 .32057 Mdot
.55941 .66069 Mdot
.57146 .5963 Mdot
.50568 .60319 Mdot
.48982 .62077 Mdot
.46361 .3264 Mdot
.50129 .58863 Mdot
.46438 .26319 Mdot
.64297 .69408 Mdot
.38623 .77488 Mdot
.31982 .41196 Mdot
.24389 .359 Mdot
.67985 .44329 Mdot
.65766 .56114 Mdot
.66988 .6693 Mdot
.54214 .48554 Mdot
.4606 .35129 Mdot
.57315 .65285 Mdot
.29357 .43158 Mdot
.36132 .21937 Mdot
.32155 .4137 Mdot
.43469 .13898 Mdot
.57106 .76345 Mdot
.73215 .34216 Mdot
.49236 .60928 Mdot
.31648 .40624 Mdot
.67988 .72593 Mdot
.49174 .68411 Mdot
.31358 .55838 Mdot
.62497 .68561 Mdot
.75104 .41191 Mdot
.30942 .57245 Mdot
.57124 .61146 Mdot
.70012 .44184 Mdot
.55726 .64743 Mdot
.57214 .63586 Mdot
.52688 .61586 Mdot
.4234 .29664 Mdot
.57973 .60004 Mdot
.57282 .64271 Mdot
.60592 .79357 Mdot
.36681 .52249 Mdot
.29737 .41812 Mdot
.76197 .65969 Mdot
.32675 .59875 Mdot
.64443 .48584 Mdot
.47318 .42408 Mdot
.45216 .31525 Mdot
.78427 .60649 Mdot
.49571 .60112 Mdot
.69027 .36055 Mdot
.49015 .33274 Mdot
.32297 .60822 Mdot
.56859 .39603 Mdot
.64089 .23704 Mdot
.29037 .45906 Mdot
.5899 .37647 Mdot
.31144 .46188 Mdot
.72155 .71574 Mdot
.67937 .50328 Mdot
.51358 .67944 Mdot
.44716 .27853 Mdot
.29662 .41183 Mdot
.35544 .64793 Mdot
.5301 .64908 Mdot
.30325 .4716 Mdot
.5274 .6802 Mdot
.51101 .462 Mdot
.4813 .4224 Mdot
.28389 .41616 Mdot
.49563 .32133 Mdot
.47496 .29706 Mdot
.30049 .57749 Mdot
.64653 .46838 Mdot
.65622 .47358 Mdot
.4711 .30508 Mdot
.17282 .63645 Mdot
.55013 .61145 Mdot
.55465 .59769 Mdot
.54988 .4392 Mdot
.49293 .62752 Mdot
.39202 .60265 Mdot
.57224 .37178 Mdot
.65046 .48389 Mdot
.49635 .63667 Mdot
.50586 .6135 Mdot
.55696 .59004 Mdot
.34104 .68875 Mdot
.31111 .44696 Mdot
.51494 .58872 Mdot
.33954 .61579 Mdot
.55802 .36047 Mdot
.57559 .60889 Mdot
.50037 .68533 Mdot
.66909 .50298 Mdot
.18576 .56504 Mdot
.45206 .29074 Mdot
.32631 .47111 Mdot
.34142 .43451 Mdot
.39276 .7344 Mdot
.72961 .44155 Mdot
.58238 .37135 Mdot
.27955 .3248 Mdot
.57354 .40224 Mdot
.31851 .57586 Mdot
.43409 .41018 Mdot
.35718 .43804 Mdot
.31368 .42019 Mdot
.49734 .3036 Mdot
.50847 .65043 Mdot
.5716 .59959 Mdot
.66484 .37519 Mdot
.53861 .60479 Mdot
.33308 .58197 Mdot
.47652 .27553 Mdot
.67513 .50205 Mdot
.35277 .60346 Mdot
.45868 .28247 Mdot
.66095 .46375 Mdot
.58094 .66228 Mdot
.47904 .60933 Mdot
.68416 .48534 Mdot
.7008 .48516 Mdot
.53533 .62529 Mdot
.66058 .78035 Mdot
.65041 .47942 Mdot
.69483 .47776 Mdot
.54727 .4013 Mdot
.28285 .44368 Mdot
.44598 .63317 Mdot
.47018 .31942 Mdot
.55859 .65025 Mdot
.32173 .41188 Mdot
.30812 .58106 Mdot
.67846 .49232 Mdot
.53306 .59715 Mdot
.55612 .61429 Mdot
.31664 .58576 Mdot
.35715 .61674 Mdot
.3399 .58469 Mdot
.42523 .29551 Mdot
.51816 .58322 Mdot
.68639 .45131 Mdot
.45808 .32131 Mdot
.34543 .58022 Mdot
.30284 .5979 Mdot
.60562 .78766 Mdot
.54223 .6148 Mdot
.32836 .56073 Mdot
.31664 .83727 Mdot
.41923 .67944 Mdot
.57482 .37579 Mdot
.33679 .41409 Mdot
.37695 .62776 Mdot
.31523 .62066 Mdot
.44454 .31795 Mdot
.37492 .52431 Mdot
.29379 .5819 Mdot
.53499 .60449 Mdot
.51742 .63939 Mdot
.51729 .57502 Mdot
.33255 .60249 Mdot
.34384 .70089 Mdot
.71247 .45807 Mdot
.71463 .58403 Mdot
.32695 .59877 Mdot
.28132 .42035 Mdot
.3356 .41625 Mdot
.31835 .43434 Mdot
.56687 .66048 Mdot
.78817 .62425 Mdot
.6276 .71399 Mdot
.6807 .64088 Mdot
.45069 .31813 Mdot
.7179 .44791 Mdot
.42037 .26312 Mdot
.67402 .48676 Mdot
.30082 .4395 Mdot
.32938 .6072 Mdot
.70187 .49868 Mdot
.48167 .29756 Mdot
.47675 .29496 Mdot
.33498 .47807 Mdot
.31698 .44533 Mdot
.3291 .4544 Mdot
.65038 .45756 Mdot
.66765 .46948 Mdot
.51063 .60886 Mdot
.68415 .49403 Mdot
.4642 .82723 Mdot
.35535 .63301 Mdot
.35183 .45555 Mdot
.45423 .29674 Mdot
.69934 .4758 Mdot
.53951 .6564 Mdot
.23952 .47932 Mdot
.34873 .4883 Mdot
.34785 .59832 Mdot
.52702 .24611 Mdot
.31341 .21067 Mdot
.5836 .65066 Mdot
.47376 .33174 Mdot
.49212 .53907 Mdot
.53386 .64459 Mdot
.28941 .44838 Mdot
.4747 .80269 Mdot
.56562 .39765 Mdot
.57747 .63029 Mdot
.52266 .66614 Mdot
.47994 .28487 Mdot
.47642 .42377 Mdot
.531 .60883 Mdot
.42427 .45457 Mdot
.45157 .33033 Mdot
.3191 .48481 Mdot
.71017 .77558 Mdot
.44391 .35986 Mdot
.30052 .67053 Mdot
.56781 .38208 Mdot
.54086 .6005 Mdot
.32241 .46223 Mdot
.34738 .60921 Mdot
.31975 .45535 Mdot
.66625 .51622 Mdot
.28575 .44835 Mdot
.5221 .64925 Mdot
.68182 .45148 Mdot
.46472 .28619 Mdot
.3999 .51489 Mdot
.63344 .776 Mdot
.30698 .4154 Mdot
.55936 .39604 Mdot
.57196 .60643 Mdot
.65469 .62326 Mdot
.59511 .57747 Mdot
.58022 .62966 Mdot
.43548 .30547 Mdot
.69199 .46765 Mdot
.43279 .30765 Mdot
.55787 .67825 Mdot
.65297 .54632 Mdot
.44825 .30429 Mdot
.73099 .41247 Mdot
.3383 .57742 Mdot
.33293 .67898 Mdot
.55103 .63881 Mdot
.44585 .28008 Mdot
.52596 .58185 Mdot
.7108 .46153 Mdot
.5015 .49162 Mdot
.60598 .52266 Mdot
.45307 .27204 Mdot
.75567 .37933 Mdot
.49126 .45358 Mdot
.45001 .6506 Mdot
.44442 .28799 Mdot
.78359 .64516 Mdot
.57978 .38752 Mdot
.31377 .59367 Mdot
.35688 .60603 Mdot
.31761 .61097 Mdot
.54294 .60199 Mdot
.62487 .65986 Mdot
.31504 .61303 Mdot
.42717 .30097 Mdot
.33617 .62197 Mdot
.33924 .73983 Mdot
.66181 .34889 Mdot
.34378 .58784 Mdot
.554 .63585 Mdot
.52398 .68604 Mdot
.36716 .5265 Mdot
.28351 .46564 Mdot
.67718 .25042 Mdot
.5807 .79092 Mdot
.54657 .6062 Mdot
.6352 .6369 Mdot
.69063 .51169 Mdot
.43222 .54874 Mdot
.60994 .53553 Mdot
.469 .39946 Mdot
.69706 .47798 Mdot
.50398 .43127 Mdot
.64767 .47991 Mdot
.54889 .67779 Mdot
.56103 .61707 Mdot
.64368 .50032 Mdot
.58951 .30282 Mdot
.82491 .58125 Mdot
.67326 .35366 Mdot
.66658 .45307 Mdot
.44738 .28619 Mdot
.46133 .33283 Mdot
.43531 .30313 Mdot
.3322 .46526 Mdot
.69557 .49538 Mdot
.53828 .58526 Mdot
.30173 .4212 Mdot
.56764 .63816 Mdot
.47605 .30393 Mdot
.56199 .49079 Mdot
.67459 .50251 Mdot
.54237 .63413 Mdot
.61743 .75724 Mdot
.30553 .45524 Mdot
.31788 .59031 Mdot
.53354 .23657 Mdot
.35037 .43025 Mdot
.48886 .3203 Mdot
.72884 .46289 Mdot
.26336 .42509 Mdot
.20825 .44961 Mdot
.55673 .57871 Mdot
.55247 .57893 Mdot
.29814 .50139 Mdot
.63345 .76057 Mdot
.52043 .61981 Mdot
.30897 .42079 Mdot
.28093 .43822 Mdot
.53723 .58076 Mdot
.70818 .48144 Mdot
.30639 .60664 Mdot
.29954 .56787 Mdot
.52297 .67516 Mdot
.52109 .44173 Mdot
.37148 .64078 Mdot
.50074 .61909 Mdot
.46729 .60537 Mdot
.27567 .45331 Mdot
.56515 .38354 Mdot
.54301 .46272 Mdot
.30394 .59363 Mdot
.56723 .61699 Mdot
.82309 .53917 Mdot
.68951 .49599 Mdot
.31516 .47786 Mdot
.48159 .31644 Mdot
.32911 .56321 Mdot
.34528 .47161 Mdot
.53776 .58077 Mdot
.50546 .6142 Mdot
.45443 .27618 Mdot
.7285 .48613 Mdot
.33274 .60532 Mdot
.29892 .42145 Mdot
.30437 .57766 Mdot
.66446 .47277 Mdot
.69462 .48563 Mdot
.50348 .66447 Mdot
.58577 .57026 Mdot
.32537 .4211 Mdot
.48674 .59432 Mdot
.32198 .43175 Mdot
.25484 .34759 Mdot
.47962 .32298 Mdot
.51796 .66154 Mdot
.72163 .43401 Mdot
.47518 .30409 Mdot
.53728 .61308 Mdot
.2953 .4993 Mdot
.50887 .62426 Mdot
.29791 .40737 Mdot
.50285 .80215 Mdot
.30865 .59699 Mdot
.54343 .70924 Mdot
.44182 .67076 Mdot
.49393 .62957 Mdot
.27847 .44525 Mdot
.6145 .6876 Mdot
.45075 .30781 Mdot
.67538 .46433 Mdot
.17664 .57738 Mdot
.46218 .29854 Mdot
.56113 .63282 Mdot
.33405 .59505 Mdot
.65745 .46003 Mdot
.59164 .39135 Mdot
.52808 .42744 Mdot
.51737 .69335 Mdot
.60394 .63573 Mdot
.53557 .66137 Mdot
.2823 .2728 Mdot
.32627 .45604 Mdot
.69603 .46687 Mdot
.46666 .33167 Mdot
.46561 .3146 Mdot
.30486 .44734 Mdot
.74422 .40056 Mdot
.63511 .31539 Mdot
.36463 .86889 Mdot
.3502 .46419 Mdot
.33104 .61958 Mdot
.50092 .48306 Mdot
.31439 .43088 Mdot
.32435 .46769 Mdot
.29393 .4822 Mdot
.66159 .36579 Mdot
.67033 .45124 Mdot
.55672 .61209 Mdot
.69164 .43234 Mdot
.54241 .60005 Mdot
.30279 .66584 Mdot
.47213 .30824 Mdot
.67358 .46494 Mdot
.27429 .56723 Mdot
.48972 .70241 Mdot
.52889 .63681 Mdot
.28554 .65057 Mdot
.57661 .67641 Mdot
.40694 .68839 Mdot
.48478 .6351 Mdot
.31432 .45405 Mdot
.66311 .53983 Mdot
.47417 .65073 Mdot
.61109 .75778 Mdot
.47432 .2911 Mdot
.59202 .39909 Mdot
.57278 .67354 Mdot
.4579 .63178 Mdot
.65729 .45863 Mdot
.6994 .50091 Mdot
.31394 .61243 Mdot
.5424 .22516 Mdot
.47174 .28899 Mdot
.69853 .31128 Mdot
.58118 .62229 Mdot
.50677 .32948 Mdot
.49066 .80606 Mdot
.53246 .6196 Mdot
.41852 .40433 Mdot
.785 .60517 Mdot
.51534 .62197 Mdot
.68884 .62971 Mdot
.45669 .29997 Mdot
.37416 .77365 Mdot
.4812 .61984 Mdot
.29149 .45202 Mdot
.67091 .4616 Mdot
.7181 .47022 Mdot
.34993 .60259 Mdot
.49647 .82954 Mdot
.46789 .23038 Mdot
.66955 .46663 Mdot
.53582 .65002 Mdot
.45322 .29134 Mdot
.59323 .39105 Mdot
.51023 .69874 Mdot
.40035 .21952 Mdot
.68206 .49718 Mdot
.47357 .6105 Mdot
.68761 .35458 Mdot
.49138 .42504 Mdot
.74614 .3017 Mdot
.43546 .29081 Mdot
.30233 .5909 Mdot
.54019 .56079 Mdot
.2758 .32987 Mdot
.48055 .60571 Mdot
.3019 .6675 Mdot
.7338 .43605 Mdot
.31489 .5719 Mdot
.53752 .64295 Mdot
.52858 .61045 Mdot
.52738 .46098 Mdot
.35701 .60079 Mdot
.53086 .60855 Mdot
.48347 .58501 Mdot
.65856 .47447 Mdot
.57108 .37192 Mdot
.67303 .50127 Mdot
.55231 .64687 Mdot
.50273 .79223 Mdot
.70851 .48765 Mdot
.68013 .25895 Mdot
.3289 .63653 Mdot
.45093 .31461 Mdot
.47026 .64146 Mdot
.57567 .64485 Mdot
.64756 .19234 Mdot
.59181 .38342 Mdot
.16933 .47795 Mdot
.31585 .40662 Mdot
.83671 .61647 Mdot
.35484 .43822 Mdot
.74424 .35426 Mdot
.40879 .49403 Mdot
.49938 .58279 Mdot
.49991 .72805 Mdot
.68146 .6296 Mdot
.4989 .33879 Mdot
.65418 .57999 Mdot
.58046 .61929 Mdot
.56581 .60477 Mdot
.30806 .42462 Mdot
.7373 .38933 Mdot
.52215 .52286 Mdot
.54011 .46045 Mdot
.32162 .60623 Mdot
.67018 .47686 Mdot
.52099 .64608 Mdot
.55975 .28615 Mdot
.29847 .41391 Mdot
.52628 .76228 Mdot
.54476 .63423 Mdot
.52996 .51399 Mdot
.70731 .39531 Mdot
.46104 .28517 Mdot
.28139 .41827 Mdot
.27682 .42817 Mdot
.54359 .59642 Mdot
.4641 .32406 Mdot
.51221 .61415 Mdot
.49042 .46014 Mdot
.50825 .69219 Mdot
.31296 .57674 Mdot
.56278 .65123 Mdot
.46432 .7139 Mdot
.79159 .38364 Mdot
.46539 .6674 Mdot
.65809 .45238 Mdot
.33206 .45212 Mdot
.30974 .44183 Mdot
.65627 .47236 Mdot
.309 .44148 Mdot
.7135 .59255 Mdot
.63833 .58737 Mdot
.31759 .57492 Mdot
.66641 .68823 Mdot
.31206 .5995 Mdot
.59078 .40125 Mdot
.53931 .61805 Mdot
.34226 .30462 Mdot
.34965 .46679 Mdot
.35128 .75954 Mdot
.46732 .30599 Mdot
.58936 .3802 Mdot
.56004 .58694 Mdot
.32576 .55302 Mdot
.29731 .43566 Mdot
.42476 .36398 Mdot
.54974 .59177 Mdot
.69935 .44741 Mdot
.5177 .61856 Mdot
.59734 .62411 Mdot
.58306 .37455 Mdot
.53023 .66102 Mdot
.45843 .2825 Mdot
.69131 .49953 Mdot
.73128 .34796 Mdot
.3322 .46854 Mdot
.57634 .62243 Mdot
.5357 .64901 Mdot
.6884 .50847 Mdot
.56969 .58858 Mdot
.45079 .32136 Mdot
.5518 .90923 Mdot
.33389 .57553 Mdot
.56408 .38532 Mdot
.56197 .19447 Mdot
.51093 .64238 Mdot
.50093 .62592 Mdot
.47831 .38364 Mdot
.819 .54593 Mdot
.44627 .29593 Mdot
.58107 .66594 Mdot
.28891 .42218 Mdot
.3352 .60593 Mdot
.44115 .27461 Mdot
.513 .58425 Mdot
.5621 .60337 Mdot
.3221 .57316 Mdot
.29536 .65568 Mdot
.28735 .5691 Mdot
.44413 .31459 Mdot
.63307 .59454 Mdot
.24342 .48056 Mdot
.54806 .61849 Mdot
.57748 .41623 Mdot
.69069 .4734 Mdot
.44229 .29371 Mdot
.80697 .53821 Mdot
.54551 .67754 Mdot
.48974 .30264 Mdot
.46687 .28675 Mdot
.57273 .59073 Mdot
.73305 .44575 Mdot
.71049 .43736 Mdot
.6926 .47361 Mdot
.39108 .77131 Mdot
.19269 .41273 Mdot
.32998 .4576 Mdot
.45719 .29397 Mdot
.32648 .41393 Mdot
.29477 .57808 Mdot
.51215 .46859 Mdot
.28056 .42418 Mdot
.68522 .44171 Mdot
.33123 .41991 Mdot
.50942 .61775 Mdot
.48216 .30165 Mdot
.33617 .42967 Mdot
.49429 .62058 Mdot
.4708 .59651 Mdot
.49407 .7218 Mdot
.30642 .60777 Mdot
.50474 .43056 Mdot
.55839 .63874 Mdot
.56864 .39437 Mdot
.5378 .62731 Mdot
.45628 .32477 Mdot
.37736 .52756 Mdot
.50414 .59373 Mdot
.35051 .46514 Mdot
.20599 .41583 Mdot
.28329 .45635 Mdot
.58949 .60155 Mdot
.55353 .64512 Mdot
.54784 .61549 Mdot
.56719 .59634 Mdot
.75395 .41704 Mdot
.48154 .27135 Mdot
.56143 .54888 Mdot
.34374 .46831 Mdot
.67748 .48874 Mdot
.71332 .47996 Mdot
.4684 .39317 Mdot
.59366 .38251 Mdot
.46816 .32209 Mdot
.54921 .61378 Mdot
.42559 .36617 Mdot
.53179 .4142 Mdot
.68018 .35252 Mdot
.2595 .42389 Mdot
.31709 .42097 Mdot
.66582 .44457 Mdot
.33538 .43636 Mdot
.51932 .58198 Mdot
.48104 .59735 Mdot
.73045 .34325 Mdot
.42665 .27637 Mdot
.3313 .60614 Mdot
.56633 .64175 Mdot
.33765 .67041 Mdot
.29226 .42316 Mdot
.27468 .44745 Mdot
.51349 .61107 Mdot
.72062 .49328 Mdot
.80376 .35936 Mdot
.47617 .31887 Mdot
.65248 .62772 Mdot
.67933 .53124 Mdot
.61669 .57096 Mdot
.45606 .30937 Mdot
.4234 .418 Mdot
.29361 .47698 Mdot
.55409 .80946 Mdot
.68449 .48742 Mdot
.32928 .60489 Mdot
.48043 .63463 Mdot
.68453 .44171 Mdot
.33771 .42223 Mdot
.64716 .4878 Mdot
.51354 .68009 Mdot
.43209 .31126 Mdot
.31185 .4361 Mdot
.50261 .30741 Mdot
.64748 .50291 Mdot
.31102 .59905 Mdot
.36085 .75253 Mdot
.65086 .65048 Mdot
.78511 .60419 Mdot
.51643 .58833 Mdot
.37262 .31322 Mdot
.53933 .5861 Mdot
.69111 .43774 Mdot
.55153 .63859 Mdot
.50235 .71246 Mdot
.30486 .48594 Mdot
.47771 .64267 Mdot
.56696 .64878 Mdot
.60538 .75588 Mdot
.52776 .6276 Mdot
.5535 .58538 Mdot
.52288 .66904 Mdot
.72968 .49047 Mdot
.48005 .64701 Mdot
.69829 .44744 Mdot
.68094 .37227 Mdot
.32255 .46863 Mdot
.29712 .57479 Mdot
.30886 .56742 Mdot
.29156 .66489 Mdot
.33727 .67489 Mdot
.73541 .39439 Mdot
.66646 .49484 Mdot
.4751 .28442 Mdot
.51087 .61412 Mdot
.76771 .66981 Mdot
.47684 .77721 Mdot
.30811 .48543 Mdot
.3284 .42051 Mdot
.47824 .62004 Mdot
.3712 .19503 Mdot
.47814 .63887 Mdot
.54456 .43127 Mdot
.54573 .59925 Mdot
.52662 .66593 Mdot
.27292 .43479 Mdot
.34026 .70976 Mdot
.515 .58862 Mdot
.65653 .45979 Mdot
.32149 .60084 Mdot
.60374 .54633 Mdot
.46031 .77992 Mdot
.56934 .75077 Mdot
.4554 .58273 Mdot
.49601 .59712 Mdot
.29176 .42735 Mdot
.66451 .4535 Mdot
.5483 .44734 Mdot
.45007 .31922 Mdot
.52274 .43327 Mdot
.64205 .68899 Mdot
.4353 .23024 Mdot
.32633 .60534 Mdot
.3304 .50487 Mdot
.5216 .64965 Mdot
.33217 .46333 Mdot
.56196 .67446 Mdot
.52503 .39811 Mdot
.31002 .57652 Mdot
.64387 .46856 Mdot
.448 .28596 Mdot
.70063 .44544 Mdot
.75052 .67817 Mdot
.4848 .78129 Mdot
.83652 .61853 Mdot
.2965 .46863 Mdot
.77447 .50917 Mdot
.68805 .45748 Mdot
.54554 .59012 Mdot
.35838 .86433 Mdot
.68595 .47188 Mdot
.6951 .4445 Mdot
.46758 .40472 Mdot
.36577 .74315 Mdot
.47324 .62626 Mdot
.64929 .48584 Mdot
.29747 .49 Mdot
.327 .58492 Mdot
.49558 .61692 Mdot
.53134 .67803 Mdot
.69951 .50026 Mdot
.29792 .43935 Mdot
.31931 .6755 Mdot
.31506 .44916 Mdot
.67394 .45038 Mdot
.30378 .46005 Mdot
.67737 .26322 Mdot
.28869 .41743 Mdot
.5658 .65145 Mdot
.5494 .61477 Mdot
.36519 .25495 Mdot
.69458 .48566 Mdot
.50018 .62711 Mdot
.56501 .61109 Mdot
.68863 .45372 Mdot
.35641 .43528 Mdot
.7979 .52624 Mdot
.49886 .63368 Mdot
.55343 .61172 Mdot
.32372 .56926 Mdot
.50229 .44776 Mdot
.5398 .40849 Mdot
.49682 .62111 Mdot
.32399 .61516 Mdot
.65543 .45151 Mdot
.53611 .6276 Mdot
.33838 .70878 Mdot
.35371 .44146 Mdot
.48844 .60778 Mdot
.59008 .39813 Mdot
.52462 .61717 Mdot
.79938 .35925 Mdot
.57322 .60967 Mdot
.69687 .46053 Mdot
.67787 .45805 Mdot
.33796 .51253 Mdot
.67627 .48422 Mdot
.57791 .37588 Mdot
.47446 .29915 Mdot
.78022 .39588 Mdot
.58093 .37648 Mdot
.54534 .66675 Mdot
.53392 .82735 Mdot
.52247 .67792 Mdot
.50258 .68725 Mdot
.34075 .75449 Mdot
.57016 .3802 Mdot
.68959 .46488 Mdot
.58882 .29868 Mdot
.49288 .59072 Mdot
.47212 .32144 Mdot
.49352 .68457 Mdot
.48841 .60728 Mdot
.50064 .71839 Mdot
.63321 .57821 Mdot
.47748 .27478 Mdot
.44614 .63994 Mdot
.49593 .61658 Mdot
.81753 .54802 Mdot
.53063 .65267 Mdot
.34655 .59141 Mdot
.65853 .4905 Mdot
.33949 .44507 Mdot
.31948 .57779 Mdot
.51621 .64613 Mdot
.33075 .60096 Mdot
.32982 .46225 Mdot
.4408 .28077 Mdot
.55893 .65437 Mdot
.36008 .62172 Mdot
.33004 .60808 Mdot
.52226 .59697 Mdot
.67131 .46421 Mdot
.59857 .58268 Mdot
.53437 .62661 Mdot
.54924 .58153 Mdot
.65613 .4745 Mdot
.32593 .79583 Mdot
.56077 .59369 Mdot
.42196 .41453 Mdot
.63347 .48083 Mdot
.57437 .37276 Mdot
.32198 .4266 Mdot
.52973 .56841 Mdot
.46715 .31588 Mdot
.47245 .30225 Mdot
.33304 .4829 Mdot
.68509 .5063 Mdot
.30885 .43672 Mdot
.4786 .69197 Mdot
.479 .60018 Mdot
.48031 .6333 Mdot
.176 .57587 Mdot
.63199 .22778 Mdot
.70296 .47254 Mdot
.28484 .46447 Mdot
.52697 .44301 Mdot
.47903 .31248 Mdot
.27753 .46176 Mdot
.67187 .43441 Mdot
.66644 .50662 Mdot
.65457 .47314 Mdot
.32885 .61431 Mdot
.3177 .43984 Mdot
.65052 .44243 Mdot
.71617 .44122 Mdot
.51656 .60387 Mdot
.49599 .61381 Mdot
.66667 .51958 Mdot
.36796 .4738 Mdot
.30807 .58651 Mdot
.28667 .43347 Mdot
.7535 .2581 Mdot
.47612 .31929 Mdot
.60507 .75685 Mdot
.49467 .62284 Mdot
.14926 .66689 Mdot
.47982 .64231 Mdot
.53444 .65108 Mdot
.64417 .49093 Mdot
.34559 .57457 Mdot
.32688 .58805 Mdot
.68688 .45701 Mdot
.72632 .47245 Mdot
.34129 .61025 Mdot
.44951 .4056 Mdot
.80983 .42083 Mdot
.54089 .44423 Mdot
.69929 .45891 Mdot
.65463 .64999 Mdot
.44204 .2754 Mdot
.63884 .46693 Mdot
.49515 .28877 Mdot
.32338 .4697 Mdot
.31134 .41514 Mdot
.45673 .27491 Mdot
.55625 .58834 Mdot
.29574 .46465 Mdot
.47349 .68537 Mdot
.72495 .32169 Mdot
.42321 .22086 Mdot
.7785 .67843 Mdot
.58244 .62911 Mdot
.50333 .53026 Mdot
.63179 .37154 Mdot
.52384 .65794 Mdot
.4405 .63664 Mdot
.33185 .60436 Mdot
.63542 .477 Mdot
.44711 .2681 Mdot
.6947 .25102 Mdot
.54822 .6171 Mdot
.68554 .4475 Mdot
.48239 .30706 Mdot
.67118 .26487 Mdot
.42431 .45319 Mdot
.52369 .60799 Mdot
.41686 .89545 Mdot
.64949 .50333 Mdot
.3393 .44513 Mdot
.64628 .72939 Mdot
.66768 .43952 Mdot
.22678 .45421 Mdot
.28549 .40892 Mdot
.57628 .47169 Mdot
.65131 .49918 Mdot
.28897 .56991 Mdot
.66527 .47747 Mdot
.35009 .61549 Mdot
.72936 .46522 Mdot
.30014 .44938 Mdot
.53425 .63735 Mdot
.30335 .45095 Mdot
.3422 .57808 Mdot
.30997 .4794 Mdot
.44752 .26802 Mdot
.56648 .38645 Mdot
.47813 .29832 Mdot
.50811 .47254 Mdot
.7769 .55324 Mdot
.43783 .29818 Mdot
.41634 .37003 Mdot
.51847 .62514 Mdot
.72646 .49089 Mdot
.34101 .45354 Mdot
.34228 .48359 Mdot
.51119 .43455 Mdot
.66578 .45843 Mdot
.29589 .4482 Mdot
.64706 .65903 Mdot
.17341 .64694 Mdot
.46893 .6539 Mdot
.19849 .39521 Mdot
.69147 .45425 Mdot
.29601 .48108 Mdot
.54879 .43729 Mdot
.71561 .48307 Mdot
.33057 .42465 Mdot
.44618 .2845 Mdot
.46182 .31559 Mdot
.57247 .59256 Mdot
.43864 .32583 Mdot
.27751 .44332 Mdot
.82242 .54203 Mdot
.65585 .48511 Mdot
.60984 .21454 Mdot
.34422 .59241 Mdot
.32671 .4669 Mdot
.47501 .6351 Mdot
.71012 .42671 Mdot
.34353 .43605 Mdot
.39988 .20379 Mdot
.70349 .22053 Mdot
.29538 .44828 Mdot
.65918 .49167 Mdot
.67515 .49192 Mdot
.46773 .66954 Mdot
.52935 .45031 Mdot
.29547 .43961 Mdot
.34096 .30364 Mdot
.34588 .65758 Mdot
.58707 .38456 Mdot
.59285 .79276 Mdot
.51532 .5881 Mdot
.49433 .59867 Mdot
.44721 .31878 Mdot
.52621 .63613 Mdot
.72437 .45733 Mdot
.48114 .64093 Mdot
.45066 .32868 Mdot
.32061 .48399 Mdot
.54249 .61818 Mdot
.33938 .60434 Mdot
.4334 .3035 Mdot
.47873 .33365 Mdot
.31087 .46661 Mdot
.65331 .48694 Mdot
.57312 .30844 Mdot
.31527 .4472 Mdot
.51115 .58576 Mdot
.57236 .38729 Mdot
.48698 .63779 Mdot
.36669 .26246 Mdot
.71197 .45582 Mdot
.33569 .43717 Mdot
.64957 .5118 Mdot
.46106 .29154 Mdot
.32361 .49092 Mdot
.52704 .65501 Mdot
.31594 .41862 Mdot
.41297 .41853 Mdot
.21463 .53042 Mdot
.72327 .4509 Mdot
.35082 .52499 Mdot
.69609 .50384 Mdot
.58798 .38528 Mdot
.39051 .72143 Mdot
.31173 .59089 Mdot
.2828 .43467 Mdot
.67617 .25415 Mdot
.34216 .45946 Mdot
.52784 .62441 Mdot
.55976 .59792 Mdot
.31023 .42477 Mdot
.31599 .6066 Mdot
.29271 .68559 Mdot
.36484 .62957 Mdot
.69017 .49731 Mdot
.42184 .49713 Mdot
.78454 .29737 Mdot
.27157 .40585 Mdot
.47174 .28152 Mdot
.46897 .57707 Mdot
.51078 .62879 Mdot
.48496 .29052 Mdot
.47379 .32675 Mdot
.34704 .58264 Mdot
.33061 .46782 Mdot
.63535 .46466 Mdot
.45363 .26983 Mdot
.6841 .42491 Mdot
.32426 .68814 Mdot
.58827 .6616 Mdot
.62334 .61629 Mdot
.56692 .65715 Mdot
.49194 .4249 Mdot
.44258 .32138 Mdot
.55854 .63069 Mdot
.49245 .57566 Mdot
.44303 .29941 Mdot
.35106 .59212 Mdot
.62511 .455 Mdot
.29614 .45542 Mdot
.15958 .65255 Mdot
.56009 .65352 Mdot
.5338 .63303 Mdot
.4512 .31829 Mdot
.64577 .75567 Mdot
.7048 .46754 Mdot
.65412 .49007 Mdot
.32681 .4555 Mdot
.51061 .39205 Mdot
.56737 .58567 Mdot
.54327 .65847 Mdot
.29388 .45951 Mdot
.56925 .39397 Mdot
.712 .75731 Mdot
.55592 .61711 Mdot
.45537 .30329 Mdot
.40241 .37735 Mdot
.43751 .31629 Mdot
.58071 .65735 Mdot
.52982 .61945 Mdot
.55032 .66205 Mdot
.58487 .61546 Mdot
.46189 .27314 Mdot
.53137 .65934 Mdot
.6075 .62463 Mdot
.69103 .46855 Mdot
.50306 .59223 Mdot
.34872 .65787 Mdot
.55257 .61991 Mdot
.33917 .60318 Mdot
.53319 .38878 Mdot
.57506 .62018 Mdot
.50219 .59227 Mdot
.34336 .65581 Mdot
.53998 .6457 Mdot
.48421 .30007 Mdot
.68244 .49016 Mdot
.45932 .29053 Mdot
.47151 .28469 Mdot
.33748 .4269 Mdot
.35373 .61514 Mdot
.49345 .58086 Mdot
.34005 .61309 Mdot
.47868 .68686 Mdot
.53772 .67947 Mdot
.50687 .46043 Mdot
.5435 .43049 Mdot
.29265 .58549 Mdot
.53472 .65746 Mdot
.32464 .46015 Mdot
.33252 .43226 Mdot
.37455 .52431 Mdot
.4983 .69296 Mdot
.4457 .27103 Mdot
.44572 .28044 Mdot
.39336 .60471 Mdot
.39001 .5684 Mdot
.33384 .60925 Mdot
.48556 .51001 Mdot
.55274 .67234 Mdot
.56964 .61187 Mdot
.51735 .68657 Mdot
.31278 .40722 Mdot
.56524 .38696 Mdot
.32609 .48122 Mdot
.5488 .39994 Mdot
.43237 .28234 Mdot
.58221 .62956 Mdot
.4445 .20331 Mdot
.70361 .49074 Mdot
.68354 .49036 Mdot
.45407 .33111 Mdot
.28204 .4541 Mdot
.50647 .69269 Mdot
.14666 .50396 Mdot
.7213 .47042 Mdot
.2977 .57755 Mdot
.55565 .64856 Mdot
.31648 .4676 Mdot
.68835 .50212 Mdot
.34619 .62591 Mdot
.57968 .63994 Mdot
.27047 .4251 Mdot
.55219 .63097 Mdot
.69137 .65069 Mdot
.68342 .46432 Mdot
.56271 .48611 Mdot
.6997 .51285 Mdot
.47636 .28305 Mdot
.44914 .29076 Mdot
.53588 .6141 Mdot
.1459 .5725 Mdot
.62074 .4989 Mdot
.4893 .2943 Mdot
.33907 .62457 Mdot
.56468 .39196 Mdot
.34386 .62463 Mdot
.32038 .43086 Mdot
.32182 .60226 Mdot
.34478 .43934 Mdot
.37026 .46016 Mdot
.62772 .50074 Mdot
.32609 .57528 Mdot
.64589 .76152 Mdot
.48157 .59651 Mdot
.34274 .57633 Mdot
.47951 .62626 Mdot
.49132 .70783 Mdot
.30167 .46842 Mdot
.32945 .61278 Mdot
.53251 .59693 Mdot
.56125 .18922 Mdot
.45846 .28344 Mdot
.44826 .26868 Mdot
.48371 .59525 Mdot
.29244 .47961 Mdot
.72737 .45954 Mdot
.47039 .4369 Mdot
.56794 .37542 Mdot
.54396 .65793 Mdot
.57394 .65516 Mdot
.65388 .50994 Mdot
.67589 .44296 Mdot
.53443 .61389 Mdot
.64653 .63302 Mdot
.52011 .64967 Mdot
.45837 .31495 Mdot
.69412 .49602 Mdot
.67959 .49245 Mdot
.27843 .4329 Mdot
.68788 .50517 Mdot
.58546 .56053 Mdot
.45545 .34612 Mdot
.49491 .66773 Mdot
.46192 .29444 Mdot
.37667 .48649 Mdot
.32892 .47427 Mdot
.67293 .24872 Mdot
.68219 .50597 Mdot
.49641 .63719 Mdot
.71257 .47997 Mdot
.33894 .58401 Mdot
.69336 .488 Mdot
.68165 .51556 Mdot
.57836 .61011 Mdot
.53506 .60342 Mdot
.57137 .3927 Mdot
.52224 .44466 Mdot
.67753 .46727 Mdot
.50826 .64528 Mdot
.49182 .64166 Mdot
.55498 .59312 Mdot
.4914 .45022 Mdot
.64291 .48218 Mdot
.59179 .74965 Mdot
.38947 .24711 Mdot
.67194 .46716 Mdot
.74865 .28239 Mdot
.57653 .4041 Mdot
.59461 .38427 Mdot
.49395 .31772 Mdot
.5559 .61197 Mdot
.30654 .44035 Mdot
.49174 .6008 Mdot
.49292 .69292 Mdot
.5757 .62619 Mdot
.32101 .57203 Mdot
.5537 .57758 Mdot
.58552 .39667 Mdot
.31198 .45102 Mdot
.5073 .64183 Mdot
.54638 .6121 Mdot
.59509 .39353 Mdot
.68232 .51855 Mdot
.66801 .50643 Mdot
.60459 .41701 Mdot
.34858 .58915 Mdot
.43898 .31115 Mdot
.49977 .59131 Mdot
.32536 .45759 Mdot
.30601 .44728 Mdot
.69887 .44512 Mdot
.29015 .44794 Mdot
.4406 .31589 Mdot
.52835 .64968 Mdot
.47483 .28133 Mdot
.32144 .57212 Mdot
.65822 .48987 Mdot
.51051 .5847 Mdot
.51983 .60234 Mdot
.67812 .4581 Mdot
.51956 .62151 Mdot
.31821 .57008 Mdot
.30528 .40911 Mdot
.69973 .48472 Mdot
.47362 .29932 Mdot
.27917 .42754 Mdot
.50744 .61645 Mdot
.58418 .14936 Mdot
.52529 .6361 Mdot
.55007 .65879 Mdot
.76369 .38036 Mdot
.50307 .65811 Mdot
.33701 .46595 Mdot
.71126 .48608 Mdot
.58516 .6477 Mdot
.34131 .65895 Mdot
.26975 .5989 Mdot
.2774 .40662 Mdot
.55527 .65039 Mdot
.73217 .28216 Mdot
.49411 .63255 Mdot
.69715 .27692 Mdot
.50787 .46064 Mdot
.29639 .26757 Mdot
.6228 .62015 Mdot
.48968 .29574 Mdot
.56886 .39184 Mdot
.33806 .46905 Mdot
.70474 .70439 Mdot
.52134 .6289 Mdot
.79541 .59605 Mdot
.49972 .58982 Mdot
.45732 .31101 Mdot
.4508 .60755 Mdot
.28666 .43654 Mdot
.58378 .78998 Mdot
.5404 .58335 Mdot
.64659 .49449 Mdot
.32385 .49406 Mdot
.56787 .39826 Mdot
.53743 .59563 Mdot
.346 .60351 Mdot
.28175 .60243 Mdot
.58462 .56184 Mdot
.46416 .29372 Mdot
.56735 .61379 Mdot
.45418 .62362 Mdot
.17994 .64084 Mdot
.69465 .47102 Mdot
.4601 .27968 Mdot
.42894 .57089 Mdot
.55705 .59623 Mdot
.66437 .50577 Mdot
.68211 .48784 Mdot
.34831 .61074 Mdot
.52374 .35732 Mdot
.25785 .59875 Mdot
.46046 .17942 Mdot
.78034 .63314 Mdot
.30631 .40631 Mdot
.69748 .41074 Mdot
.50256 .59827 Mdot
.48857 .78368 Mdot
.47478 .28814 Mdot
.53515 .63581 Mdot
.76513 .62591 Mdot
.69492 .47709 Mdot
.55565 .62668 Mdot
.30871 .58452 Mdot
.60053 .33792 Mdot
.62613 .689 Mdot
.61861 .17689 Mdot
.29042 .48359 Mdot
.48057 .6645 Mdot
.59941 .57023 Mdot
.57363 .37318 Mdot
.5809 .65557 Mdot
.33977 .45814 Mdot
.37814 .3202 Mdot
.30548 .59397 Mdot
.70116 .49324 Mdot
.57312 .40323 Mdot
.49419 .59345 Mdot
.5188 .67171 Mdot
.29727 .58265 Mdot
.53884 .59004 Mdot
.6391 .72799 Mdot
.59695 .39881 Mdot
.2903 .41626 Mdot
.64705 .48518 Mdot
.56667 .65842 Mdot
.56604 .39155 Mdot
.57528 .60504 Mdot
.44303 .6823 Mdot
.56091 .64448 Mdot
.77329 .40801 Mdot
.66986 .46229 Mdot
.4689 .29238 Mdot
.54943 .5754 Mdot
.54709 .62638 Mdot
.24719 .48563 Mdot
.50301 .69355 Mdot
.57106 .60712 Mdot
.69047 .43996 Mdot
.70744 .4871 Mdot
.68261 .44573 Mdot
.28218 .42517 Mdot
.54263 .45077 Mdot
.46396 .30846 Mdot
.51498 .68897 Mdot
.44784 .2714 Mdot
.61344 .65131 Mdot
.30651 .60229 Mdot
.65123 .22568 Mdot
.5193 .64121 Mdot
.65975 .46355 Mdot
.80178 .47389 Mdot
.6579 .44891 Mdot
.44658 .24161 Mdot
.47316 .28986 Mdot
.68278 .47123 Mdot
.54293 .64839 Mdot
.53911 .46177 Mdot
.57144 .15637 Mdot
.47948 .3103 Mdot
.49927 .68342 Mdot
.29013 .48428 Mdot
.34396 .47723 Mdot
.77954 .32763 Mdot
.48221 .29232 Mdot
.62862 .37018 Mdot
.49861 .63629 Mdot
.70124 .49575 Mdot
.43573 .29741 Mdot
.48639 .30565 Mdot
.29056 .45318 Mdot
.52045 .60816 Mdot
.54901 .62684 Mdot
.58843 .40087 Mdot
.44546 .27567 Mdot
.56129 .69351 Mdot
.52292 .61125 Mdot
.7395 .35114 Mdot
.66655 .43602 Mdot
.33489 .80288 Mdot
.46122 .67838 Mdot
.77094 .61751 Mdot
.39547 .4707 Mdot
.70331 .48045 Mdot
.54999 .58453 Mdot
.51089 .68976 Mdot
.29426 .40906 Mdot
.52687 .64584 Mdot
.29421 .47429 Mdot
.48019 .28777 Mdot
.66004 .22707 Mdot
.43165 .37724 Mdot
.45741 .35032 Mdot
.52687 .63233 Mdot
.62605 .68426 Mdot
.32827 .57819 Mdot
.43256 .26866 Mdot
.69926 .45267 Mdot
.55479 .6688 Mdot
.30976 .40474 Mdot
.28393 .42447 Mdot
.68671 .48243 Mdot
.66748 .38586 Mdot
.68185 .25946 Mdot
.58556 .62245 Mdot
.32179 .42842 Mdot
.42554 .34765 Mdot
.65511 .56682 Mdot
.48893 .3262 Mdot
.30374 .58959 Mdot
.33461 .46972 Mdot
.42731 .309 Mdot
.4943 .7095 Mdot
.679 .47814 Mdot
.65493 .50848 Mdot
.24573 .46146 Mdot
.2975 .44396 Mdot
.31833 .58406 Mdot
.39273 .51399 Mdot
.39704 .5147 Mdot
.30914 .57801 Mdot
.3078 .48556 Mdot
.70572 .48286 Mdot
.68145 .44801 Mdot
.68056 .49006 Mdot
.61133 .75783 Mdot
.71605 .46449 Mdot
.41235 .80854 Mdot
.56788 .66498 Mdot
.65593 .61922 Mdot
.51359 .6538 Mdot
.46432 .2695 Mdot
.68204 .46349 Mdot
.51648 .4647 Mdot
.53521 .67081 Mdot
.59713 .1697 Mdot
.55858 .64033 Mdot
.41252 .39531 Mdot
.55504 .61105 Mdot
.66022 .70207 Mdot
.63406 .47777 Mdot
.53085 .65736 Mdot
.47385 .34643 Mdot
.33499 .60196 Mdot
.63088 .5125 Mdot
.57077 .60887 Mdot
.69265 .35797 Mdot
.4799 .62623 Mdot
.72556 .29642 Mdot
.21041 .45763 Mdot
.30842 .56375 Mdot
.49208 .65178 Mdot
.3491 .4437 Mdot
.46659 .56842 Mdot
.66041 .63501 Mdot
.47967 .3092 Mdot
.63418 .67482 Mdot
.28668 .44846 Mdot
.44115 .63966 Mdot
.59881 .63938 Mdot
.31027 .60203 Mdot
.61764 .47755 Mdot
.45524 .31461 Mdot
.5194 .62925 Mdot
.55054 .58606 Mdot
.36877 .22765 Mdot
.66065 .65119 Mdot
.59575 .66195 Mdot
.30045 .59669 Mdot
.6342 .68657 Mdot
.57369 .62397 Mdot
.27722 .40738 Mdot
.71187 .48856 Mdot
.51263 .55654 Mdot
.5797 .76572 Mdot
.51167 .64677 Mdot
.68533 .47403 Mdot
.68066 .50688 Mdot
.81782 .4817 Mdot
.31094 .60665 Mdot
.56137 .64356 Mdot
.23694 .45582 Mdot
.51143 .58529 Mdot
.4622 .31174 Mdot
.57486 .66601 Mdot
.3189 .47424 Mdot
.55484 .43739 Mdot
.28143 .42718 Mdot
.54633 .59457 Mdot
.6622 .48115 Mdot
.45106 .31575 Mdot
.27219 .3213 Mdot
.50288 .3656 Mdot
.40784 .8061 Mdot
.28358 .60711 Mdot
.34044 .60778 Mdot
.34997 .62254 Mdot
.4183 .27598 Mdot
.54961 .65094 Mdot
.48419 .42189 Mdot
.47766 .67684 Mdot
.55784 .60637 Mdot
.5678 .64208 Mdot
.47616 .36602 Mdot
.4725 .29057 Mdot
.30189 .45589 Mdot
.53297 .61478 Mdot
.50875 .6461 Mdot
.67086 .47223 Mdot
.32989 .60841 Mdot
.30339 .41081 Mdot
.34474 .58451 Mdot
.31597 .45497 Mdot
.79794 .35122 Mdot
.56308 .67581 Mdot
.33526 .60025 Mdot
.43368 .31164 Mdot
.66975 .45043 Mdot
.59427 .38926 Mdot
.31939 .4313 Mdot
.28771 .43649 Mdot
.5295 .65933 Mdot
.6612 .49802 Mdot
.66248 .50284 Mdot
.3407 .61014 Mdot
.4423 .28403 Mdot
.58459 .60172 Mdot
.53021 .60666 Mdot
.24839 .34351 Mdot
.29067 .41097 Mdot
.64162 .6737 Mdot
.77045 .42133 Mdot
.54751 .65273 Mdot
.65845 .50228 Mdot
.54074 .62272 Mdot
.40226 .29704 Mdot
.67682 .4445 Mdot
.50969 .65876 Mdot
.52382 .71828 Mdot
.31327 .40777 Mdot
.8396 .54372 Mdot
.50416 .57681 Mdot
.50921 .31128 Mdot
.51485 .59524 Mdot
.86083 .57546 Mdot
.80284 .48547 Mdot
.50068 .58824 Mdot
.58376 .61358 Mdot
.46601 .16896 Mdot
.49264 .62583 Mdot
.58567 .40026 Mdot
.49495 .69457 Mdot
.66254 .50568 Mdot
.41893 .44603 Mdot
.50129 .42882 Mdot
.32962 .61977 Mdot
.32742 .4562 Mdot
.35532 .72674 Mdot
.35322 .60569 Mdot
.69544 .45832 Mdot
.52466 .67388 Mdot
.76637 .45216 Mdot
.35763 .46208 Mdot
.5953 .6255 Mdot
.46057 .31188 Mdot
.50188 .42799 Mdot
.32786 .47907 Mdot
.4747 .29802 Mdot
.49324 .63728 Mdot
.1757 .50985 Mdot
.4984 .26537 Mdot
.82722 .47732 Mdot
.44536 .31549 Mdot
.46125 .28571 Mdot
.54919 .46486 Mdot
.33039 .61993 Mdot
.34369 .25999 Mdot
.58121 .54468 Mdot
.47727 .31714 Mdot
.4198 .70448 Mdot
.27492 .42292 Mdot
.52142 .39863 Mdot
.63695 .46965 Mdot
.56306 .67658 Mdot
.54527 .64407 Mdot
.44112 .29366 Mdot
.73202 .42138 Mdot
.40971 .56347 Mdot
.47973 .30191 Mdot
.59834 .57232 Mdot
.52302 .39012 Mdot
.56988 .38584 Mdot
.58119 .40574 Mdot
.33286 .62377 Mdot
.22744 .57753 Mdot
.66469 .46456 Mdot
.30297 .57224 Mdot
.58931 .50022 Mdot
.5641 .63533 Mdot
.44725 .27374 Mdot
.58834 .40553 Mdot
.47076 .30266 Mdot
.33152 .59027 Mdot
.30077 .59177 Mdot
.69182 .46896 Mdot
.70586 .46781 Mdot
.66667 .5437 Mdot
.3989 .63519 Mdot
.4923 .60657 Mdot
.79964 .53808 Mdot
.68104 .44354 Mdot
.67791 .73133 Mdot
.3354 .6171 Mdot
.31923 .60527 Mdot
.68975 .59593 Mdot
.51095 .60987 Mdot
.40515 .38294 Mdot
.57437 .61769 Mdot
.41242 .7262 Mdot
.48779 .59855 Mdot
.29136 .45318 Mdot
.52737 .5843 Mdot
.56639 .29395 Mdot
.50543 .63588 Mdot
.57236 .63804 Mdot
.31824 .43573 Mdot
.56949 .57962 Mdot
.31361 .47504 Mdot
.56225 .59404 Mdot
.35111 .5807 Mdot
.32526 .45713 Mdot
.36559 .60175 Mdot
.42989 .41984 Mdot
.57535 .39663 Mdot
.34324 .62292 Mdot
.34502 .60182 Mdot
.31624 .67111 Mdot
.70688 .46084 Mdot
.4712 .70702 Mdot
.55177 .64838 Mdot
.27544 .45258 Mdot
.43247 .29606 Mdot
.51341 .64834 Mdot
.48116 .64434 Mdot
.50517 .57516 Mdot
.68894 .47073 Mdot
.3009 .48319 Mdot
.33022 .59665 Mdot
.32933 .42826 Mdot
.3612 .59949 Mdot
.34718 .46137 Mdot
.46533 .60842 Mdot
.48348 .69464 Mdot
.60802 .61636 Mdot
.78483 .58948 Mdot
.536 .82043 Mdot
.68141 .48127 Mdot
.57825 .38561 Mdot
.30722 .60377 Mdot
.41879 .50168 Mdot
.65867 .46927 Mdot
.28942 .4356 Mdot
.55212 .63124 Mdot
.6033 .5779 Mdot
.6046 .55825 Mdot
.68207 .42838 Mdot
.38093 .60056 Mdot
.32826 .444 Mdot
.5807 .37881 Mdot
.5383 .4382 Mdot
.72573 .50444 Mdot
.51202 .4709 Mdot
.54416 .6239 Mdot
.34413 .60865 Mdot
.68858 .50201 Mdot
.35283 .27274 Mdot
.44377 .28849 Mdot
.5261 .44752 Mdot
.52725 .63456 Mdot
.6439 .40043 Mdot
.66257 .48166 Mdot
.30998 .59671 Mdot
.44118 .29478 Mdot
.32201 .61511 Mdot
.5667 .40139 Mdot
.58291 .41993 Mdot
.53544 .59331 Mdot
.5727 .60839 Mdot
.43273 .28275 Mdot
.66345 .46702 Mdot
.28946 .55835 Mdot
.38185 .22296 Mdot
.31666 .42777 Mdot
.49264 .39607 Mdot
.69299 .49832 Mdot
.62301 .39321 Mdot
.31372 .41978 Mdot
.42726 .30345 Mdot
.48705 .42504 Mdot
.45852 .33224 Mdot
.57279 .63207 Mdot
.67133 .49681 Mdot
.4831 .29327 Mdot
.2573 .34611 Mdot
.76463 .33807 Mdot
.62924 .45546 Mdot
.53018 .61287 Mdot
.65122 .2238 Mdot
.66169 .34153 Mdot
.64798 .42416 Mdot
.45788 .27053 Mdot
.53423 .61966 Mdot
.5852 .62679 Mdot
.53839 .58323 Mdot
.4535 .28319 Mdot
.50866 .34129 Mdot
.28837 .42668 Mdot
.56035 .62811 Mdot
.34349 .59105 Mdot
.31348 .47193 Mdot
.35302 .46162 Mdot
.33904 .46689 Mdot
.67957 .44298 Mdot
.54255 .67678 Mdot
.56757 .50946 Mdot
.8505 .50296 Mdot
.46545 .28821 Mdot
.57572 .39668 Mdot
.55593 .65797 Mdot
.36512 .77217 Mdot
.67677 .44739 Mdot
.31164 .42815 Mdot
.53503 .63403 Mdot
.21933 .45932 Mdot
.59553 .40527 Mdot
.31813 .44299 Mdot
.69757 .45194 Mdot
.64514 .42555 Mdot
.52621 .64638 Mdot
.51183 .59742 Mdot
.67964 .4524 Mdot
.63643 .34768 Mdot
.53722 .43018 Mdot
.54237 .62028 Mdot
.47184 .29391 Mdot
.15837 .6243 Mdot
.4988 .65157 Mdot
.7282 .43282 Mdot
.56394 .38732 Mdot
.75493 .40011 Mdot
.64313 .65252 Mdot
.46979 .6445 Mdot
.58573 .18402 Mdot
.33985 .73707 Mdot
.6798 .23619 Mdot
.4148 .74383 Mdot
.43836 .223 Mdot
.81711 .39795 Mdot
.47564 .3448 Mdot
.66637 .69078 Mdot
.37506 .20006 Mdot
.64062 .37016 Mdot
.19821 .5008 Mdot
.29622 .31699 Mdot
.21133 .433 Mdot
.64287 .7891 Mdot
.34884 .46207 Mdot
.44693 .75267 Mdot
.56261 .5884 Mdot
.63859 .33635 Mdot
.64143 .70368 Mdot
.49368 .83168 Mdot
.65239 .23003 Mdot
.2322 .45667 Mdot
.54959 .14086 Mdot
.66248 .2481 Mdot
.73797 .51462 Mdot
.53637 .76028 Mdot
.24143 .59746 Mdot
.39416 .51759 Mdot
.35681 .73512 Mdot
.61666 .68653 Mdot
.56611 .2781 Mdot
.48509 .34473 Mdot
.75774 .538 Mdot
.20007 .67142 Mdot
.33715 .44878 Mdot
.71189 .48942 Mdot
.3337 .26324 Mdot
.76216 .48069 Mdot
.44784 .23568 Mdot
.58578 .18384 Mdot
.74856 .35563 Mdot
.65938 .70006 Mdot
.57082 .48953 Mdot
.69862 .63752 Mdot
.27951 .68057 Mdot
.51708 .76983 Mdot
.72047 .43745 Mdot
.29171 .34707 Mdot
.39667 .51753 Mdot
.26837 .63268 Mdot
.66309 .71589 Mdot
.34682 .62697 Mdot
.36722 .61608 Mdot
.6924 .44837 Mdot
.66235 .55948 Mdot
.59582 .38284 Mdot
.59446 .50512 Mdot
.31033 .40356 Mdot
.40174 .31422 Mdot
.60425 .33394 Mdot
.66728 .36017 Mdot
.81778 .61344 Mdot
.62525 .16899 Mdot
.36823 .67769 Mdot
.37205 .29708 Mdot
.47048 .24679 Mdot
.33961 .72009 Mdot
.54535 .49989 Mdot
.3932 .66464 Mdot
.45565 .70192 Mdot
.47351 .13303 Mdot
.70433 .35396 Mdot
.5342 .13108 Mdot
.72979 .47513 Mdot
.52522 .56232 Mdot
.38349 .29788 Mdot
.76522 .65757 Mdot
.32737 .65452 Mdot
.62629 .17385 Mdot
.30252 .5631 Mdot
.63133 .48353 Mdot
.64058 .37241 Mdot
.63719 .72497 Mdot
.29361 .54967 Mdot
.32243 .63006 Mdot
.51261 .55733 Mdot
.46345 .12141 Mdot
.57184 .17909 Mdot
.80046 .44973 Mdot
.73705 .35306 Mdot
.27931 .39581 Mdot
.35362 .45387 Mdot
.48752 .29775 Mdot
.78324 .36216 Mdot
.66597 .48998 Mdot
.85404 .50731 Mdot
.76987 .35548 Mdot
.45301 .58012 Mdot
.44884 .12703 Mdot
.70903 .75446 Mdot
.6531 .62089 Mdot
.47506 .80158 Mdot
.18778 .44552 Mdot
.53542 .49427 Mdot
.61286 .38069 Mdot
.26602 .43947 Mdot
.77415 .39392 Mdot
.77343 .33235 Mdot
.43091 .71002 Mdot
.46617 .20641 Mdot
.59876 .51105 Mdot
.37457 .5009 Mdot
.6239 .47852 Mdot
.19502 .52794 Mdot
.40087 .61487 Mdot
.54572 .13541 Mdot
.63043 .69443 Mdot
.15678 .56744 Mdot
.39893 .73451 Mdot
.64175 .75714 Mdot
.57894 .19619 Mdot
.32425 .39423 Mdot
.41497 .62268 Mdot
.69441 .37089 Mdot
.49206 .67489 Mdot
.49444 .50776 Mdot
.44199 .66323 Mdot
.32843 .54038 Mdot
.54756 .45393 Mdot
.68154 .30463 Mdot
.38017 .72295 Mdot
.42291 .21437 Mdot
.5419 .75495 Mdot
.64817 .47 Mdot
.38339 .65732 Mdot
.3918 .70182 Mdot
.72275 .34109 Mdot
.43013 .5708 Mdot
.80227 .43433 Mdot
.42375 .56505 Mdot
.47484 .66542 Mdot
.67131 .68414 Mdot
.61103 .69169 Mdot
.4059 .69349 Mdot
.50077 .58071 Mdot
.82447 .5907 Mdot
.74996 .37199 Mdot
.77311 .57997 Mdot
.35975 .71009 Mdot
.78231 .58495 Mdot
.78008 .39513 Mdot
.38548 .28725 Mdot
.60672 .36983 Mdot
.69862 .41386 Mdot
.4684 .12278 Mdot
.30466 .46446 Mdot
.41575 .69106 Mdot
.50372 .33239 Mdot
.26171 .34028 Mdot
.3516 .22921 Mdot
.41577 .56246 Mdot
.78724 .39106 Mdot
.65904 .36887 Mdot
.35147 .48929 Mdot
.54791 .25223 Mdot
.45505 .36577 Mdot
.78941 .54368 Mdot
.50035 .57416 Mdot
.42985 .64127 Mdot
.31602 .57009 Mdot
.72809 .68435 Mdot
.38192 .25845 Mdot
.29566 .51905 Mdot
.46836 .62091 Mdot
.2648 .47535 Mdot
.58748 .3829 Mdot
.51108 .4229 Mdot
.7963 .34198 Mdot
.45335 .6514 Mdot
.68832 .76576 Mdot
.65658 .35236 Mdot
.49197 .42047 Mdot
.29244 .65471 Mdot
.7468 .41637 Mdot
.51536 .12496 Mdot
.79194 .38527 Mdot
.65404 .32317 Mdot
.64266 .21669 Mdot
.74864 .74827 Mdot
.3128 .24754 Mdot
.75821 .68261 Mdot
.50326 .33338 Mdot
.53885 .90745 Mdot
.32234 .42276 Mdot
.5116 .7968 Mdot
.76213 .65882 Mdot
.22848 .47768 Mdot
.76378 .47737 Mdot
.60438 .71176 Mdot
.29818 .63491 Mdot
.68182 .51725 Mdot
.47592 .59779 Mdot
.67274 .20895 Mdot
.4834 .12704 Mdot
.65925 .19771 Mdot
.5655 .41894 Mdot
.68904 .23444 Mdot
.45916 .15747 Mdot
.41803 .81135 Mdot
.35974 .23622 Mdot
.57693 .66334 Mdot
.42254 .68178 Mdot
.72917 .73393 Mdot
.29104 .59853 Mdot
.5796 .50866 Mdot
.71378 .43221 Mdot
.45046 .14928 Mdot
.79656 .3396 Mdot
.71002 .59416 Mdot
.70249 .54254 Mdot
.4076 .43094 Mdot
.40216 .66439 Mdot
.77125 .47153 Mdot
.57171 .26397 Mdot
.72978 .32561 Mdot
.44643 .16244 Mdot
.39004 .70979 Mdot
.29429 .32379 Mdot
.64495 .31268 Mdot
.74397 .71167 Mdot
.57759 .19222 Mdot
.32768 .26365 Mdot
.43527 .59235 Mdot
.63469 .52639 Mdot
.41064 .56492 Mdot
.56015 .26928 Mdot
.39226 .35477 Mdot
.35008 .68799 Mdot
.30809 .47913 Mdot
.42692 .70111 Mdot
.46438 .4777 Mdot
.3576 .23719 Mdot
.33464 .69762 Mdot
.43959 .71888 Mdot
.67278 .31594 Mdot
.67476 .21563 Mdot
.65641 .35492 Mdot
.17399 .46306 Mdot
.60963 .2247 Mdot
.43828 .64308 Mdot
.55748 .57163 Mdot
.78333 .39192 Mdot
.73732 .25219 Mdot
.78806 .3898 Mdot
.65257 .40394 Mdot
.23724 .43864 Mdot
.43921 .32594 Mdot
.32691 .70345 Mdot
.30824 .51712 Mdot
.73764 .32388 Mdot
.43981 .49191 Mdot
.42323 .30423 Mdot
.60076 .34037 Mdot
.67488 .54119 Mdot
.35746 .7549 Mdot
.74214 .54523 Mdot
.56285 .68374 Mdot
.65369 .58097 Mdot
.65903 .51326 Mdot
.64572 .40415 Mdot
.39827 .67021 Mdot
.31042 .46701 Mdot
.23806 .35209 Mdot
.73946 .43553 Mdot
.49576 .57364 Mdot
.37945 .33049 Mdot
.6231 .47731 Mdot
.78205 .60562 Mdot
.33983 .49314 Mdot
.80678 .37861 Mdot
.80989 .6191 Mdot
.7729 .46882 Mdot
.37551 .66622 Mdot
.24697 .35475 Mdot
.52298 .42113 Mdot
.50433 .31476 Mdot
.65226 .23352 Mdot
.44305 .42222 Mdot
.38415 .66663 Mdot
.64908 .59161 Mdot
.38089 .23347 Mdot
.4888 .68516 Mdot
.80309 .46453 Mdot
.40272 .79877 Mdot
.50906 .41106 Mdot
.75626 .46353 Mdot
.71946 .46653 Mdot
.57172 .82784 Mdot
.57812 .292 Mdot
.51795 .52931 Mdot
.61159 .20382 Mdot
.48761 .31959 Mdot
.66014 .45391 Mdot
.44971 .72314 Mdot
.21821 .52768 Mdot
.63638 .56399 Mdot
.3993 .35207 Mdot
.74653 .50386 Mdot
.43776 .39667 Mdot
.63031 .20897 Mdot
.55032 .16174 Mdot
.16181 .61821 Mdot
.718 .49451 Mdot
.35831 .2798 Mdot
.35286 .28367 Mdot
.70946 .43393 Mdot
.7027 .42653 Mdot
.62383 .69268 Mdot
.72478 .25911 Mdot
.42485 .48269 Mdot
.56124 .25193 Mdot
.48694 .42153 Mdot
.20093 .51154 Mdot
.36458 .24686 Mdot
.34649 .71422 Mdot
.53769 .18626 Mdot
.71858 .54612 Mdot
.20275 .36281 Mdot
.60673 .65132 Mdot
.51715 .79692 Mdot
.32656 .70345 Mdot
.50909 .74898 Mdot
.66746 .71164 Mdot
.70042 .2955 Mdot
.50389 .58983 Mdot
.64725 .18097 Mdot
.70141 .33602 Mdot
.48348 .51604 Mdot
.30046 .38756 Mdot
.50064 .62174 Mdot
.54836 .67547 Mdot
.77906 .45343 Mdot
.76174 .41037 Mdot
.26146 .27926 Mdot
.40581 .7323 Mdot
.43764 .61711 Mdot
.6488 .61098 Mdot
.68914 .7649 Mdot
.39049 .31129 Mdot
.70959 .27206 Mdot
.46164 .48802 Mdot
.74558 .71757 Mdot
.54473 .22103 Mdot
.54988 .27173 Mdot
.60171 .21532 Mdot
.46628 .15579 Mdot
.4872 .56341 Mdot
.7259 .39462 Mdot
.33523 .27059 Mdot
.55776 .65607 Mdot
.66865 .38593 Mdot
.61386 .21006 Mdot
.19632 .60703 Mdot
.53268 .50823 Mdot
.72859 .23961 Mdot
.53873 .70499 Mdot
.71807 .38367 Mdot
.36252 .20807 Mdot
.14702 .43108 Mdot
.55793 .28636 Mdot
.5544 .13884 Mdot
.54213 .25719 Mdot
.59704 .19535 Mdot
.4917 .30144 Mdot
.43473 .45336 Mdot
.80191 .56184 Mdot
.73096 .2648 Mdot
.23832 .55045 Mdot
.43343 .21908 Mdot
.80693 .52124 Mdot
.72096 .24995 Mdot
.52255 .71293 Mdot
.57466 .82215 Mdot
.33599 .40925 Mdot
.75235 .72252 Mdot
.78709 .65104 Mdot
.73629 .49987 Mdot
.42299 .71238 Mdot
.57307 .81441 Mdot
.47013 .8255 Mdot
.7815 .6531 Mdot
.47884 .73493 Mdot
.75838 .41854 Mdot
.36838 .66587 Mdot
.7464 .32784 Mdot
.62896 .79565 Mdot
.36251 .25959 Mdot
.55473 .36421 Mdot
.57114 .41636 Mdot
.77359 .41709 Mdot
.65175 .28726 Mdot
.38308 .31969 Mdot
.54204 .4154 Mdot
.73266 .51432 Mdot
.20277 .72016 Mdot
.5197 .23493 Mdot
.62925 .59188 Mdot
.5037 .13125 Mdot
.72732 .32805 Mdot
.42888 .4938 Mdot
.65598 .72605 Mdot
.36485 .76266 Mdot
.36448 .43784 Mdot
.57574 .6245 Mdot
.71372 .24474 Mdot
.36177 .47438 Mdot
.57615 .15449 Mdot
.8318 .47847 Mdot
.6789 .56417 Mdot
.46174 .60375 Mdot
.27049 .45798 Mdot
.53355 .77175 Mdot
.48109 .74199 Mdot
.50199 .13984 Mdot
.52142 .79455 Mdot
.47799 .40279 Mdot
.42267 .39307 Mdot
.42272 .37134 Mdot
.49687 .54638 Mdot
.73222 .73404 Mdot
.75049 .41081 Mdot
.36904 .72794 Mdot
.63526 .31508 Mdot
.4106 .68978 Mdot
.64343 .65631 Mdot
.32275 .69549 Mdot
.4507 .53569 Mdot
.28949 .63671 Mdot
.28123 .41688 Mdot
.44678 .18344 Mdot
.65766 .25299 Mdot
.828 .57246 Mdot
.177 .45982 Mdot
.69473 .37362 Mdot
.46222 .75912 Mdot
.40052 .23514 Mdot
.52021 .50659 Mdot
.24336 .57481 Mdot
.38503 .75088 Mdot
.63386 .67978 Mdot
.70744 .28521 Mdot
.54949 .74746 Mdot
.77802 .33424 Mdot
.34981 .69177 Mdot
.40802 .19887 Mdot
.40583 .43665 Mdot
.74181 .66088 Mdot
.66984 .62768 Mdot
.19211 .42644 Mdot
.50724 .41277 Mdot
.46392 .1224 Mdot
.65175 .45404 Mdot
.62019 .16669 Mdot
.44482 .31663 Mdot
.19714 .64594 Mdot
.7182 .30632 Mdot
.48962 .49403 Mdot
.482 .45354 Mdot
.81056 .47541 Mdot
.64905 .35614 Mdot
.66656 .35285 Mdot
.41284 .56823 Mdot
.33492 .47923 Mdot
.48615 .38658 Mdot
.56631 .25132 Mdot
.45267 .1887 Mdot
.58762 .61326 Mdot
.33222 .51534 Mdot
.50532 .76031 Mdot
.50208 .29139 Mdot
.75645 .37951 Mdot
.68793 .27321 Mdot
.62447 .65076 Mdot
.40051 .65958 Mdot
.46256 .15109 Mdot
.74872 .34391 Mdot
.40885 .55135 Mdot
.45502 .68492 Mdot
.47661 .24368 Mdot
.27234 .28919 Mdot
.5457 .17487 Mdot
.42494 .3816 Mdot
.53408 .42174 Mdot
.36993 .67996 Mdot
.73587 .23183 Mdot
.47821 .12995 Mdot
.18334 .4087 Mdot
.48549 .41853 Mdot
.72054 .50156 Mdot
.3771 .7703 Mdot
.41074 .19855 Mdot
.7644 .7119 Mdot
.67304 .32988 Mdot
.41557 .69514 Mdot
.18844 .58398 Mdot
.54378 .811 Mdot
.46319 .40829 Mdot
.67074 .62833 Mdot
.78514 .61528 Mdot
.44627 .24473 Mdot
.36815 .44551 Mdot
.46405 .433 Mdot
.45641 .23105 Mdot
.75753 .41731 Mdot
.64878 .35878 Mdot
.40609 .19865 Mdot
.53347 .79604 Mdot
.45819 .689 Mdot
.43545 .20909 Mdot
.62729 .48309 Mdot
.35018 .2792 Mdot
.25456 .32941 Mdot
.46776 .42102 Mdot
.33787 .43407 Mdot
.61144 .57333 Mdot
.51542 .38547 Mdot
.53947 .24216 Mdot
.1776 .54438 Mdot
.33876 .56934 Mdot
.73359 .45081 Mdot
.55812 .80888 Mdot
.72304 .48593 Mdot
.78114 .29143 Mdot
.57403 .26308 Mdot
.65152 .59592 Mdot
.52905 .21211 Mdot
.30913 .32754 Mdot
.16096 .48986 Mdot
.7285 .52268 Mdot
.34129 .65722 Mdot
.73358 .46979 Mdot
.66918 .51273 Mdot
.54138 .20622 Mdot
.60697 .39333 Mdot
.68097 .55008 Mdot
.66403 .77829 Mdot
.24512 .35769 Mdot
.72562 .46629 Mdot
.42118 .39857 Mdot
.63488 .44029 Mdot
.80013 .34759 Mdot
.33691 .43607 Mdot
.47567 .12149 Mdot
.46397 .68299 Mdot
.26365 .29404 Mdot
.77207 .38579 Mdot
.55953 .44196 Mdot
.48426 .4107 Mdot
.26556 .34788 Mdot
.47909 .67188 Mdot
.4395 .61133 Mdot
.70475 .46066 Mdot
.36923 .22343 Mdot
.32364 .6049 Mdot
.38798 .62068 Mdot
.49967 .33368 Mdot
.66971 .75052 Mdot
.7668 .69514 Mdot
.66356 .51384 Mdot
.40429 .40521 Mdot
.34552 .29552 Mdot
.52235 .71957 Mdot
.50508 .75634 Mdot
.45731 .1739 Mdot
.70652 .53784 Mdot
.64982 .4573 Mdot
.18351 .41825 Mdot
.39398 .59709 Mdot
.81151 .39733 Mdot
.60422 .67615 Mdot
.52619 .76977 Mdot
.52085 .75192 Mdot
.78541 .44393 Mdot
.64255 .65339 Mdot
.72653 .29438 Mdot
.38638 .65964 Mdot
.39066 .56442 Mdot
.44021 .71746 Mdot
.62511 .65097 Mdot
.44608 .38658 Mdot
.72916 .74351 Mdot
.1845 .57674 Mdot
.69389 .64771 Mdot
.55282 .50369 Mdot
.7602 .4716 Mdot
.69597 .76031 Mdot
.73188 .44407 Mdot
.32637 .55658 Mdot
.76311 .54196 Mdot
.7179 .30813 Mdot
.78167 .35666 Mdot
.7218 .34112 Mdot
.53352 .77373 Mdot
.42644 .37179 Mdot
.42484 .78419 Mdot
.47971 .70604 Mdot
.50266 .48338 Mdot
.482 .65499 Mdot
.44704 .61098 Mdot
.43501 .50642 Mdot
.81038 .49126 Mdot
.4758 .56732 Mdot
.72242 .26172 Mdot
.80475 .39195 Mdot
.66361 .21815 Mdot
.38936 .3529 Mdot
.71267 .49446 Mdot
.50315 .12595 Mdot
.57191 .7816 Mdot
.74846 .33314 Mdot
.77716 .66471 Mdot
.58463 .82793 Mdot
.37223 .19868 Mdot
.69094 .30399 Mdot
.62592 .5304 Mdot
.84046 .54092 Mdot
.70601 .35304 Mdot
.57998 .81876 Mdot
.63093 .68424 Mdot
.76615 .38494 Mdot
.44755 .13287 Mdot
.71925 .71662 Mdot
.67048 .35804 Mdot
.66627 .63393 Mdot
.6361 .62775 Mdot
.64224 .78123 Mdot
.52563 .68123 Mdot
.3496 .45145 Mdot
.2128 .47322 Mdot
.4161 .70591 Mdot
.62648 .62436 Mdot
.62956 .78776 Mdot
.48275 .7445 Mdot
.45165 .75739 Mdot
.25937 .35141 Mdot
.37528 .1988 Mdot
.64362 .59791 Mdot
.60063 .57133 Mdot
.72627 .43556 Mdot
.35268 .61526 Mdot
.39872 .74388 Mdot
.50918 .62568 Mdot
.50713 .44349 Mdot
.52825 .54569 Mdot
.68786 .21543 Mdot
.21048 .50769 Mdot
.42378 .31806 Mdot
.7185 .48694 Mdot
.77311 .42091 Mdot
.39736 .27978 Mdot
.6396 .37024 Mdot
.61796 .78817 Mdot
.64797 .54794 Mdot
.61648 .19817 Mdot
.67498 .36618 Mdot
.36893 .70043 Mdot
.26652 .66141 Mdot
.4743 .27543 Mdot
.79222 .59712 Mdot
.4936 .14461 Mdot
.68741 .38238 Mdot
.63022 .47966 Mdot
.64091 .30313 Mdot
.44629 .38909 Mdot
.70206 .39399 Mdot
.65154 .35193 Mdot
.37595 .25207 Mdot
.68155 .58087 Mdot
.54461 .16403 Mdot
.294 .48804 Mdot
.39981 .71406 Mdot
.59622 .29433 Mdot
.6406 .78524 Mdot
.52772 .7196 Mdot
.75603 .30961 Mdot
.48925 .48805 Mdot
.36196 .56197 Mdot
.52517 .59588 Mdot
.57245 .77387 Mdot
.78191 .44494 Mdot
.62548 .30923 Mdot
.44596 .57928 Mdot
.64611 .5138 Mdot
.81602 .61252 Mdot
.30188 .39064 Mdot
.34928 .41534 Mdot
.49042 .79698 Mdot
.64398 .41211 Mdot
.34283 .53739 Mdot
.54684 .35271 Mdot
.49285 .69756 Mdot
.25844 .64039 Mdot
.40976 .36759 Mdot
.79693 .58469 Mdot
.74948 .69234 Mdot
.45325 .17955 Mdot
.39636 .34199 Mdot
.82161 .60923 Mdot
.80157 .59638 Mdot
.76863 .40243 Mdot
.55045 .80326 Mdot
.59432 .52285 Mdot
.49191 .5848 Mdot
.326 .55637 Mdot
.68128 .43561 Mdot
.46849 .17765 Mdot
.42362 .61952 Mdot
.35543 .56256 Mdot
.47935 .5077 Mdot
.38224 .30141 Mdot
.39004 .44851 Mdot
.74986 .37543 Mdot
.84071 .54175 Mdot
.39724 .66927 Mdot
.49581 .29644 Mdot
.5449 .24843 Mdot
.51935 .51445 Mdot
.73762 .28427 Mdot
.42825 .52137 Mdot
.77376 .4617 Mdot
.5523 .38318 Mdot
.76964 .61616 Mdot
.80881 .42938 Mdot
.39536 .62212 Mdot
.51256 .47572 Mdot
.75585 .44619 Mdot
.58017 .50524 Mdot
.59435 .38776 Mdot
.23109 .49168 Mdot
.56102 .78823 Mdot
.46154 .21142 Mdot
.51264 .33766 Mdot
.52812 .70046 Mdot
.38123 .7719 Mdot
.52736 .16714 Mdot
.41969 .50244 Mdot
.47984 .49216 Mdot
.33156 .27442 Mdot
.36315 .47399 Mdot
.16163 .64168 Mdot
.66504 .19457 Mdot
.52348 .59667 Mdot
.46845 .45308 Mdot
.38924 .61496 Mdot
.29481 .47581 Mdot
.7411 .54072 Mdot
.46541 .17334 Mdot
.48348 .29982 Mdot
.24465 .38324 Mdot
.54388 .35327 Mdot
.8113 .48101 Mdot
.2026 .38002 Mdot
.42115 .28877 Mdot
.7781 .28606 Mdot
.66684 .3312 Mdot
.72921 .41441 Mdot
.16884 .66534 Mdot
.80217 .4779 Mdot
.46546 .70638 Mdot
.23883 .41869 Mdot
.68956 .22152 Mdot
.4875 .41038 Mdot
.24167 .45093 Mdot
.7321 .70489 Mdot
.39317 .66703 Mdot
.40345 .72626 Mdot
.5602 .35497 Mdot
.82012 .54238 Mdot
.54393 .83953 Mdot
.31117 .32608 Mdot
.16249 .46463 Mdot
.68078 .55526 Mdot
.57182 .16418 Mdot
.55854 .28415 Mdot
.20029 .60152 Mdot
.78035 .35959 Mdot
.44193 .70743 Mdot
.64297 .7712 Mdot
.22421 .55473 Mdot
.36239 .64187 Mdot
.37399 .77492 Mdot
.5621 .42126 Mdot
.72066 .53199 Mdot
.27454 .35145 Mdot
.45889 .56335 Mdot
.43309 .70957 Mdot
.77197 .63057 Mdot
.51001 .47661 Mdot
.52242 .14644 Mdot
.6029 .78519 Mdot
.37908 .67333 Mdot
.30345 .28954 Mdot
.36855 .6145 Mdot
.48475 .17688 Mdot
.40592 .30378 Mdot
.47282 .71532 Mdot
.33567 .21484 Mdot
.54534 .13573 Mdot
.59339 .52143 Mdot
.55833 .67148 Mdot
.81832 .4015 Mdot
.37996 .5129 Mdot
.75845 .68076 Mdot
.60358 .32678 Mdot
.41241 .73614 Mdot
.50868 .54801 Mdot
.48001 .6159 Mdot
.44945 .79655 Mdot
.64428 .53312 Mdot
.77643 .62594 Mdot
.22293 .35913 Mdot
.37911 .66815 Mdot
.61308 .77296 Mdot
.20769 .3573 Mdot
.60408 .67855 Mdot
.66094 .50622 Mdot
.68841 .21877 Mdot
.77538 .50926 Mdot
.44077 .66617 Mdot
.65981 .60358 Mdot
.41921 .53285 Mdot
.26106 .58511 Mdot
.46108 .69121 Mdot
.52123 .4206 Mdot
.42112 .7129 Mdot
.41533 .20242 Mdot
.80473 .54922 Mdot
.45829 .11933 Mdot
.79076 .39458 Mdot
.72542 .47934 Mdot
.73899 .69306 Mdot
.46252 .42071 Mdot
.65074 .21036 Mdot
.27966 .33675 Mdot
.24934 .3468 Mdot
.5176 .83418 Mdot
.37124 .63118 Mdot
.5396 .57802 Mdot
.5643 .41842 Mdot
.78225 .34804 Mdot
.53468 .83083 Mdot
.77597 .3328 Mdot
.46593 .58471 Mdot
.5442 .56867 Mdot
.13281 .45853 Mdot
.61152 .20065 Mdot
.46304 .65126 Mdot
.54958 .5251 Mdot
.51082 .53542 Mdot
.56323 .59127 Mdot
.60953 .40607 Mdot
.35631 .74252 Mdot
.41789 .73165 Mdot
.72167 .2579 Mdot
.71834 .45455 Mdot
.49253 .41251 Mdot
.43677 .26972 Mdot
.49431 .44216 Mdot
.62218 .62822 Mdot
.48704 .31695 Mdot
.43441 .73961 Mdot
.38688 .49435 Mdot
.27581 .56472 Mdot
.65806 .54124 Mdot
.56494 .42884 Mdot
.70645 .52876 Mdot
.49246 .7752 Mdot
.61656 .39376 Mdot
.46572 .82611 Mdot
.48089 .74455 Mdot
.48794 .72287 Mdot
.74068 .37272 Mdot
.72134 .76803 Mdot
.50007 .40961 Mdot
.6225 .41386 Mdot
.55983 .7054 Mdot
.60343 .74158 Mdot
.66869 .58796 Mdot
.28679 .60614 Mdot
.5822 .37651 Mdot
.46077 .59306 Mdot
.77043 .46442 Mdot
.46563 .33529 Mdot
.73338 .23516 Mdot
.49062 .58038 Mdot
.72463 .55749 Mdot
.73887 .29817 Mdot
.35463 .26918 Mdot
.63066 .68025 Mdot
.48417 .65346 Mdot
.39405 .54927 Mdot
.38472 .49818 Mdot
.68674 .42014 Mdot
.36454 .24248 Mdot
.58293 .17855 Mdot
.50387 .78908 Mdot
.70567 .55948 Mdot
.5573 .64377 Mdot
.30869 .55853 Mdot
.51952 .43136 Mdot
.20273 .58285 Mdot
.35745 .51174 Mdot
.73749 .34068 Mdot
.48021 .76782 Mdot
.40506 .73229 Mdot
.65834 .6558 Mdot
.59585 .16063 Mdot
.53924 .5104 Mdot
.67274 .56786 Mdot
.45396 .52427 Mdot
.65857 .29035 Mdot
.47714 .73604 Mdot
.45019 .21541 Mdot
.4616 .5834 Mdot
.59483 .52948 Mdot
.77738 .3041 Mdot
.73774 .51563 Mdot
.48006 .35605 Mdot
.7089 .28481 Mdot
.56963 .78896 Mdot
.48135 .45492 Mdot
.1783 .68652 Mdot
.27654 .33548 Mdot
.76593 .27415 Mdot
.39457 .22335 Mdot
.53725 .73576 Mdot
.74756 .41485 Mdot
.4732 .6017 Mdot
.31048 .44011 Mdot
.62808 .19539 Mdot
.75584 .45261 Mdot
.59878 .51781 Mdot
.56428 .67341 Mdot
.40445 .5012 Mdot
.69907 .42134 Mdot
.4523 .20868 Mdot
.34398 .47828 Mdot
.41088 .54785 Mdot
.43837 .21833 Mdot
.38403 .49831 Mdot
.60474 .8246 Mdot
.50497 .1388 Mdot
.6568 .237 Mdot
.41487 .37352 Mdot
.17364 .62102 Mdot
.73911 .47199 Mdot
.67615 .42832 Mdot
.48649 .33934 Mdot
.4317 .78944 Mdot
.69462 .38853 Mdot
.40659 .20488 Mdot
.78966 .42535 Mdot
.526 .72025 Mdot
.22566 .75287 Mdot
.44907 .71713 Mdot
.40904 .5196 Mdot
.67318 .39173 Mdot
.73316 .27175 Mdot
.2319 .41202 Mdot
.82772 .47862 Mdot
.56993 .27946 Mdot
.62505 .62892 Mdot
.41924 .80337 Mdot
.18637 .41651 Mdot
.41468 .38866 Mdot
.16097 .46837 Mdot
.58936 .20034 Mdot
.3565 .73433 Mdot
.61649 .3078 Mdot
.71753 .49642 Mdot
.44449 .59996 Mdot
.57661 .2575 Mdot
.57906 .50971 Mdot
.73407 .42169 Mdot
.5784 .18147 Mdot
.30099 .70318 Mdot
.2995 .28011 Mdot
.65225 .22138 Mdot
.50336 .29286 Mdot
.73632 .4961 Mdot
.48063 .74994 Mdot
.33953 .51794 Mdot
.29435 .46776 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo097ooooo0_l0002fooooo`007?ooool00ol0003ooooooooo
o`2Aooooo`Go000000?oooooo`000?l000001Oooool2o`000:Wooooo000Looooo`03o`000?oooooo
oooo09?ooooo0ol000000ooooooo0000o`000005ooooo`Co00000_ooool3o`000:;ooooo000Loooo
o`03o`000?oooooooooo08kooooo0_l00009ooooo`;o00001Oooool2o`0000;ooooo0ol0002Roooo
o`007?ooool00ol0003oooooooooo`2>ooooo`;o00002?ooool3o`0000Gooooo0_l00008ooooo`;o
0000WOooool001cooooo00?o0000ooooooooool0S_ooool2o`0000Kooooo1?l00006ooooo`;o0000
2?ooool2o`0009gooooo000Looooo`03o`000?oooooooooo08kooooo0_l00006ooooo`;o00005Ooo
ool2o`0009[ooooo000Looooo`03o`000?oooooooooo08Wooooo0_l0000Dooooo`?o00002oooool5
o`0009Oooooo000Looooo`03o`000?oooooooooo08Wooooo0_l0000Dooooo`?o00003Oooool3o`00
09Oooooo000Looooo`03o`000?oooooooooo09gooooo0_l00007ooooo`;o0000XOooool001cooooo
00?o0000ooooooooool0Soooool2o`0000cooooo0_l00007ooooo`;o00004_ooool2o`0008gooooo
000Looooo`;o0000T?ooool2o`0000;ooooo0_l0000Eooooo`;o00003_ooool2o`0008gooooo000L
ooooo`03o`000?oooooooooo09?ooooo0ol0000Dooooo`;o00000oooool2o`0000Gooooo0ol0002@
ooooo`007?ooool00ol0003oooooooooo`2Aooooo`;o000000?oooooo`000?l000006Oooool2o`00
00Gooooo0ol0002@ooooo`007?ooool00ol0003oooooooooo`2=ooooo`;o00000_ooool2o`0001co
oooo0_l0000=ooooo`;o0000ROooool001cooooo00?o0000ooooooooool0SOooool2o`0001kooooo
1?l00005ooooo`;o00001_ooool2o`0008Wooooo000Looooo`03o`000?oooooooooo09Cooooo0_l0
000Booooo`;o00000oooool2o`0000Oooooo0_l0000>ooooo`?o0000P?ooool001cooooo00?o0000
ooooooooool0U?ooool2o`0001;ooooo0_l0000Dooooo`;o00001_ooool3o`00083ooooo000Loooo
o`03o`000?oooooooooo097ooooo1?l0000Hooooo`;o00003oooool2o`0000Sooooo0_l0001ooooo
o`007?ooool00ol0003oooooooooo`2Aooooo`Go00001?ooool2o`00017ooooo0_l0000>ooooo`;o
00001_ooool2o`000003ooooool0003o000000Kooooo0_l0001gooooo`007?ooool00ol0003ooooo
ooooo`2?ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o00006_ooool6o`000003oooo
ool0003o000000Kooooo0_l00007ooooo`Co0000Moooool001cooooo00?o0000ooooooooool0SOoo
ool4o`000003ooooool0003o000002;ooooo2Ol0000?ooooo`;o0000NOooool001cooooo00?o0000
ooooooooool0SOooool4o`0001[ooooo0_l0000=ooooo`?o0000S?ooool001cooooo00?o0000oooo
ooooool0Soooool2o`0001[ooooo0_l00006ooooo`;o0000U?ooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo07gooooo0_l0000@
ooooo`;o00008_ooool2o`0000?ooooo0_l0000Eooooo`;o0000N?ooool00006oooooomgMgOoV9RH
oooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`00
0?oooooooooo07?ooooo1?l00006ooooo`;o0000=?ooool2o`0000?ooooo0_l00004ooooo`;o0000
2?ooool2o`0000Gooooo0_l00003ooooo`;o0000Loooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo06oooooo0_l0
0002ooooo`Go00001Oooool7o`0002oooooo0_l00003ooooo`;o00001?ooool2o`0000Cooooo0_l0
0002ooooo`?o00001oooool4o`0007?ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0006oooooo0_l00004ooooo`?o00001Oooool8
o`0000Oooooo0_l0000^ooooo`;o00001Oooool3o`0000?ooooo0_l00007ooooo`;o0000MOooool0
0003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`05oooo
o`03o`000?oooooooooo07Kooooo0_l00006ooooo`Co000000?oooooo`000?l000001oooool3o`00
02gooooo0_l00005ooooo`;o0000Q?ooool00003ooooool@413ooooo00;ooooo00?o410@oooooooo
ool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07;ooooo0_l0000:ooooo`Co
00002?ooool7o`0000?ooooo0_l0000Fooooo`;o00005Oooool2o`0000Cooooo0_l00007ooooo`;o
00000oooool2o`00073ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj
^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo06;ooooo0_l0000>ooooo`;o00005_ooool2
o`0000?ooooo0_l000000ooooooo0000o`000002o`0001;ooooo0_l00002ooooo`;o00004?ooool2
o`0000Cooooo0_l00003ooooo`;o00001Oooool4o`0000?ooooo0_l0001`ooooo`0000Koooooonk^
k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`1Rooooo`;o00001Oooool2o`0000_ooooo0_l0000>ooooo`;o00001_ooool2o`0000;ooooo
0_l0000Dooooo`;o000000?oooooo`000?l000004Oooool8o`0000[ooooo0_l00005ooooo`;o0000
0oooool2o`0006_ooooo000Looooo`03o`000?oooooooooo06Wooooo0_l00002ooooo`;o00001Ooo
ool4o`0000kooooo0_l00003ooooo`Go00006oooool2o`0001?ooooo1?l00009ooooo`;o00001Ooo
ool2o`000003ooooool0003o000000?ooooo0_l0001[ooooo`007?ooool00ol0003oooooooooo`1]
ooooo`Co000000?oooooo`000?l000000_l00008ooooo`;o00001_ooool2o`000003ooooool0003o
000000?o00007Oooool4o`0001Wooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2
o`000003ooooool0003o000000?ooooo0_l00003ooooo`;o0000I_ooool001cooooo00?o0000oooo
ooooool0Koooool2o`000003ooooool0003o000000;o00000_ooool2o`0000;ooooo1?l00006oooo
o`;o000000?oooooo`000?l000000_l0000Nooooo`Co00006Oooool2o`0000Kooooo0_l0000:oooo
o`;o00000oooool2o`0006Kooooo000Looooo`03o`000?oooooooooo07Cooooo0_l00002ooooo`;o
00000_ooool2o`0000[ooooo0_l000000ooooooo0000o`00000Nooooo`?o00005?ooool2o`0000co
oooo0_l000000ooooooo0000o`00000Dooooo`;o0000G_ooool001cooooo00?o0000ooooooooool0
K_ooool8o`0001;ooooo1?l00008ooooo`;o00005_ooool2o`0001Cooooo0_l00006ooooo`;o0000
1?ooool2o`000003ooooool0003o000001Cooooo0_l0001Nooooo`007?ooool00ol0003ooooooooo
o`1]ooooo`So00000oooool2o`0000Oooooo1?l000000ooooooo0000o`000006o`0000?ooooo0_l0
00000ooooooo0000o`00000dooooo`;o00001?ooool2o`000003ooooool0003o000000Kooooo0_l0
000>ooooo`;o0000G?ooool001cooooo00?o0000ooooooooool0IOooool2o`0000Kooooo0_l00002
ooooo`;o00001Oooool2o`0000Cooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o
000000Cooooo1?l000000ooooooo0000o`00000Booooo`;o00000_ooool5o`0002;ooooo1Ol00004
ooooo`Go00003?ooool3o`0005cooooo000Looooo`03o`000?oooooooooo06Gooooo0_l00009oooo
o`?o00002oooool2o`0000kooooo0_l0000Eooooo`;o00000_ooool5o`0001kooooo0_l00004oooo
o`?o00001?ooool5o`0000_ooooo0ol0001Mooooo`007?ooool00ol0003oooooooooo`1`ooooo`;o
000000Coooooo`000?l0003o00003Oooool2o`0000Kooooo1?l0000Jooooo`Co00007oooool2o`00
00Gooooo0_l0000Dooooo`;o0000G_ooool001cooooo00?o0000ooooooooool0K?ooool2o`0000Go
oooo0ol0000=ooooo`;o00001_ooool4o`0000Sooooo0_l0000>ooooo`;o00000_ooool2o`0003Oo
oooo0_l0001Sooooo`007?ooool00ol0003oooooooooo`1Rooooo`;o00002?ooool2o`0000Gooooo
0_l00004ooooo`Co00004?ooool2o`0000Kooooo1?l0000>ooooo`;o00001?ooool2o`0002Cooooo
0_l000001?oooooo0000o`000?l0000;ooooo`;o0000Hoooool001cooooo0_l0001Sooooo`;o0000
3oooool2o`000004ooooool0003o0000ooooo`Co00006?ooool2o`0001Kooooo0ol00003ooooo`?o
00007Oooool2o`000003ooooool0003o000000;o00001?ooool2o`0000Kooooo0_l00004ooooo`;o
0000Foooool001cooooo00?o0000ooooooooool0Goooool2o`0001;ooooo0_l000000ooooooo0000
o`00000Aooooo`;o00007Oooool4o`0000;ooooo0_l00003ooooo`?o00007?ooool2o`0000;ooooo
1?l00004ooooo`;o00000oooool2o`000003ooooool0003o000000Cooooo0_l0001Kooooo`007?oo
ool00ol0003oooooooooo`1Oooooo`;o00004_ooool2o`0000?ooooo0_l0000?ooooo`;o000000?o
ooooo`000?l000003_ooool2o`0000[ooooo1_l0000:ooooo`;o00006?ooool2o`0000Cooooo0ol0
0004ooooo`;o00000_ooool2o`0000;ooooo0_l00008ooooo`;o0000E_ooool001cooooo00?o0000
ooooooooool0K?ooool2o`0000Cooooo0_l00004ooooo`;o00004_ooool2o`0000;ooooo0_l00000
0ooooooo0000o`000007ooooo`;o00003_ooool2o`0000[ooooo0_l0000Kooooo`;o00000_ooool3
o`0000?ooooo0_l00006ooooo`?o00001oooool2o`0005Kooooo000Looooo`03o`000?oooooooooo
05Oooooo0_l0000>ooooo`Co000000?oooooo`000?l000001?ooool4o`0000oooooo0_l00009oooo
o`;o000000Coooooo`000?l0003o00008?ooool3o`0001Sooooo0_l00002ooooo`;o000000?ooooo
o`000?l000000_l0000;ooooo`?o0000Goooool001cooooo00?o0000ooooooooool0Eoooool2o`00
00?ooooo0ol00008ooooo`Co00000oooool2o`0000?ooooo0ol0000>ooooo`?o00001oooool4o`00
0003ooooool0003o000000?o00001_ooool2o`0001Kooooo0ol0000Hooooo`;o00000oooool5o`00
0003ooooool0003o000000Wooooo0_l000000ooooooo0000o`00001Mooooo`007?ooool00ol0003o
ooooooooo`1Looooo`?o00002_ooool2o`0000?ooooo0ol0000Cooooo`;o000000?oooooo`000?l0
00000ol000000ooooooo0000o`000009o`0000Kooooo0_l0000Booooo`;o00008_ooool2o`000003
ooooool0003o000000?o00001_ooool2o`0000Cooooo0_l0001Mooooo`007?ooool00ol0003ooooo
ooooo`1Hooooo`;o00001oooool2o`0000Kooooo0_l00003ooooo`?o00005_ooool5o`000003oooo
ool0003o000000co00005?ooool2o`000003ooooool0003o000002Gooooo1Ol00005ooooo`?o0000
1?ooool2o`0005gooooo000Looooo`03o`000?oooooooooo05Oooooo0ol00007ooooo`;o00001Ooo
ool2o`0000Gooooo0_l00004ooooo`;o00003Oooool2o`000003ooooool0003o000000;ooooo4?l0
0002ooooo`;o00004?ooool2o`0002Sooooo1Ol000000ooooooo0000o`000002ooooo`;o00001Ooo
ool2o`0000Wooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`1Aooooo`;o00001?ooool2
o`0000Gooooo0_l00008ooooo`;o00001?ooool5o`0000;ooooo0_l00006ooooo`;o00001Oooool2
o`000003ooooool0003o000000;ooooo4?l00002ooooo`;o00005Oooool3o`0001kooooo0_l00008
ooooo`;o00005?ooool2o`0005;ooooo000Looooo`03o`000?oooooooooo057ooooo0_l0000;oooo
o`;o00003_ooool5o`0000[ooooo0_l00007oooooaKo00001?ooool2o`0001;ooooo0ol0000Noooo
o`;o00004oooool2o`0000?ooooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o
00005?ooool4o`0000Sooooo0_l00007oooooaWo00000oooool2o`00013ooooo0_l0000Kooooo`;o
00004Oooool2o`0000Gooooo1Ol000000ooooooo0000o`000008ooooo`;o0000C_ooool001cooooo
00?o0000ooooooooool0EOooool2o`0000;ooooo0_l0000Dooooo`Co00001_ooool4o`0000Oooooo
0ol000001Ooooooo0000o`000?l0003ooooo01?o00004_ooool3o`0001_ooooo0ol0000@ooooo`;o
00001Oooool2o`000003ooooool0003o000000_ooooo0_l0001>ooooo`007?ooool00ol0003ooooo
ooooo`1Eooooo`;o00002?ooool2o`0001Sooooo0_l00003ooooo`;o00001Oooool2o`000003oooo
ool0003o000001Oo00004?ooool2o`0000Gooooo0_l0000Fooooo`Co00004Oooool2o`0000?ooooo
0_l0000>ooooo`;o0000COooool001cooooo00?o0000ooooooooool0D_ooool2o`0000_ooooo0_l0
000<ooooo`;o00001?ooool2o`0000Wooooo0_l00006oooooaco00003_ooool2o`0000;ooooo0_l0
0002ooooo`;o00001?ooool2o`0001;ooooo0_l0000<ooooo`;o00000oooool2o`000003ooooool0
003o000000;o00003_ooool2o`0004gooooo000Looooo`03o`000?oooooooooo05;ooooo0_l0000I
ooooo`;o00001?ooool4o`0000;ooooo0ol00003ooooo`;o00001OoooolIo`000003ooooool0003o
000000kooooo0_l00002ooooo`;o00002?ooool2o`0001Oooooo0_l00007ooooo`;o00001_ooool2
o`0000;ooooo0_l0000=ooooo`;o0000C?ooool001cooooo0_l0001@ooooo`;o00001?ooool2o`00
01kooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l00005oooooaWo00001Oooool2o`00
00cooooo0_l00007ooooo`;o00006_ooool2o`0000oooooo0_l00002ooooo`;o000000?oooooo`00
0?l000002_ooool2o`0004cooooo000Looooo`03o`000?oooooooooo04oooooo0_l00003ooooo`Go
00004_ooool2o`0000_ooooo0_l00006ooooo`;o00000_oooolLo`0000Cooooo0_l0000<ooooo`;o
00001oooool3o`0000kooooo0_l0000<ooooo`;o000000?oooooo`000?l000004?ooool2o`0000So
oooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o000000Coooooo`000?l0003o
oooo0_l0000?ooooo`;o00004oooool2o`0000;ooooo6Ol000000ooooooo0000o`000002o`0001[o
oooo0_l00002ooooo`;o00000_ooool2o`0000Kooooo0_l0000<ooooo`;o000000?oooooo`000?l0
00001_ooool2o`0001;ooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`1Jooooo`;o0000
:ooooolFo`0000?ooooo0_l00002ooooo`;o00004?ooool3o`0000Oooooo1_l000000ooooooo0000
o`00000Looooo`;o00001oooool2o`0000;ooooo0_l0001Eooooo`007?ooool00ol0003ooooooooo
o`1eooooo`;o00001?ooool2o`0000[ooooo5_l00005ooooo`Co00004?ooool3o`0000Oooooo1?l0
0002ooooo`?o00001Oooool2o`0000oooooo0_l00004ooooo`;o00000_ooool2o`0000?ooooo1_l0
001Eooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o00001oooool2o`0001Kooooo0_l00004
ooooo`;o00000_ooool2o`0000;ooooo0_l00004oooooaCo00000oooool4o`0002;ooooo0_l00003
ooooo`;o000000?oooooo`000?l000001oooool2o`0000Kooooo0_l00008ooooo`;o00001Oooool2
o`0005Oooooo000Looooo`03o`000?oooooooooo05?ooooo0ol00007ooooo`;o00006_ooool2o`00
00Cooooo0ol000001?oooooo0000o`000?ooool2o`0000;ooooo5Ol000000ooooooo0000o`00000Y
ooooo`;o00001?ooool2o`0000Cooooo0_l0001`ooooo`007?ooool00ol0003oooooooooo`1Coooo
o`Co00008?ooool4o`0000?ooooo1?l00004ooooo`Co000000?oooooo`000?l000004_l00005oooo
o`;o0000:oooool2o`0001Gooooo0_l0001Oooooo`007?ooool00ol0003oooooooooo`1Eooooo`Co
00000oooool2o`0000?ooooo0_l0000Dooooo`;o00001Oooool2o`0000Oooooo6?l00005ooooo`;o
00006Oooool2o`00013ooooo0_l0000Dooooo`Co000000?oooooo`000?l00000Foooool001cooooo
00?o0000ooooooooool0Coooool2o`0000Kooooo0_l00003ooooo`;o00000oooool2o`0000;ooooo
0_l0000Rooooo`oo00000_ooool5o`00023ooooo0ol0000Uooooo`Co000000?oooooo`000?l00000
0ol00008ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0Coooool4o`0000?ooooo0ol0
0008ooooo`;o00000_ooool2o`00017ooooo0_l000000ooooooo0000o`000005ooooo`;o00002?oo
ool>o`0000?ooooo1_l0000Mooooo`;o00004oooool4o`0000oooooo0_l00003ooooo`Co00001_oo
ool5o`0004gooooo000Looooo`03o`000?oooooooooo053ooooo0ol00003ooooo`?o00007oooool2
o`000003ooooool0003o000000Gooooo0_l00007oooooaSo00007Oooool2o`0001?ooooo1?l0000:
ooooo`;o00002?ooool4o`0000Kooooo1Ol0001=ooooo`007?ooool00ol0003oooooooooo`1<oooo
o`;o00000_ooool2o`0000Cooooo0ol0000^ooooo`;o00000_ooool2o`0000?ooooo3_l000001Ooo
oooo0000o`000?l0003ooooo00;o00006_ooool3o`0000[ooooo0_l00006ooooo`;o00002_ooool2
o`000003ooooool0003o000000Sooooo1?l00004ooooo`;o000000Coooooo`000?l0003o0000C_oo
ool001cooooo00?o0000ooooooooool0C?ooool2o`0000?ooooo0_l00004ooooo`;o0000:?ooool2
o`0000Cooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo1_l00000
1?oooooo0000o`000?ooool4o`0001[ooooo0_l0000;ooooo`;o00001Oooool3o`0000[ooooo0_l0
0002ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000007ooooo`;o00002?oo
ool2o`0004Sooooo000Looooo`03o`000?oooooooooo04cooooo1?l000000ooooooo0000o`000003
ooooo`;o00008Oooool2o`0000;ooooo0_l00002ooooo`;o00005?ooool5o`0000;ooooo1Ol0000G
ooooo`;o00000_ooool3o`00013ooooo1Ol000001?oooooo0000o`000?ooool2o`0000Sooooo0_l0
00000ooooooo0000o`000005o`000003ooooool0003o000000kooooo0_l00018ooooo`007?ooool0
0ol0003oooooooooo`1<ooooo`Ko000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00007?oo
ool2o`0000;ooooo0_l00007ooooo`;o00002?ooool<o`0000Cooooo0ol0000Gooooo`;o00000_oo
ool2o`0000_ooooo0_l00004ooooo`Go000000Coooooo`000?l0003ooooo0_l0000=ooooo`?o0000
0oooool2o`0000kooooo0ol00017ooooo`007?ooool2o`0004kooooo1Ol000000ooooooo0000o`00
0006ooooo`Co00009oooool2o`0000Sooooo2?l00005ooooo`;o0000;?ooool2o`0000Kooooo0ol0
0002ooooo`;o00004?ooool2o`0000?ooooo0_l00009ooooo`;o00001?ooool2o`0004Oooooo000L
ooooo`03o`000?oooooooooo04[ooooo0_l00002ooooo`Go00000_ooool2o`0000Kooooo0_l0000L
ooooo`;o000000?oooooo`000?l000004Oooool3o`0000Wooooo0_l0000>ooooo`?o00002Oooool2
o`0001Gooooo2ol00006ooooo`?o00001_ooool4o`000003ooooool0003o000000Wooooo0_l00003
ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0B_ooool2o`000003ooooool0003o0000
00;ooooo0_l00002ooooo`;o00009?ooool5o`0000[ooooo0_l00002ooooo`;o00000_ooool2o`00
00;ooooo1?l00005ooooo`;o00002?ooool2o`0000;ooooo0ol00002ooooo`;o00001Oooool2o`00
01Cooooo1?l00002ooooo`Ko000000?oooooo`000?l000000oooool3o`0000Gooooo0_l000000ooo
oooo0000o`000003o`0000Gooooo0_l00002ooooo`;o00000oooool2o`0004Sooooo000Looooo`03
o`000?oooooooooo043ooooo1?l000000ooooooo0000o`000005ooooo`?o00000_ooool2o`0002Wo
oooo0_l0000<ooooo`Ko00001_ooool4o`0000Gooooo0_l00005ooooo`Go00001oooool2o`0001_o
oooo1?l00002ooooo`Go00000_ooool3o`0000[ooooo0_l00003ooooo`?o00001Oooool2o`0000;o
oooo0_l00004ooooo`?o0000A_ooool001cooooo00?o0000ooooooooool0?_ooool6o`000003oooo
ool0003o000000Gooooo0_l0000:ooooo`;o00008_ooool2o`0000kooooo0ol0000Gooooo`Go0000
1_ooool2o`0001cooooo0_l00004ooooo`Go00000_ooool3o`0001_ooooo0ol00003ooooo`?o0000
A_ooool001cooooo00?o0000ooooooooool0?_ooool2o`0000?ooooo0_l0000Cooooo`;o0000;?oo
ool3o`0000Oooooo0_l00005ooooo`;o00001oooool2o`0000Cooooo0_l000000ooooooo0000o`00
0005ooooo`?o00000_ooool2o`0000Sooooo0_l0000Booooo`;o00000_ooool2o`0000?ooooo0_l0
000Mooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0@oooool2o`0003cooooo0_l00003
ooooo`?o00001oooool2o`0000Gooooo1?l00005ooooo`;o00001?ooool2o`0000Sooooo0_l00003
ooooo`;o00002?ooool2o`00017ooooo0ol00002ooooo`;o00000oooool2o`0006_ooooo000Loooo
o`03o`000?oooooooooo087ooooo1?l000001?oooooo0000o`000?l0000?ooooo`?o00004?ooool2
o`0000Gooooo0_l000001Ooooooo0000o`000?l0003ooooo00?o00001Oooool3o`0000Cooooo0ol0
00000ooooooo0000o`000004ooooo`;o00001Oooool7o`00013ooooo0_l0001Gooooo`007?ooool0
0ol0003oooooooooo`10ooooo`;o0000@Oooool2o`000005ooooool0003o0000o`000?ooool00_l0
000Oooooo`;o00001Oooool2o`000003ooooool0003o000000Ko00001?ooool3o`0000Cooooo0ol0
00000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l000001ol0000<ooooo`?o000000?o
ooooo`000?l00000Eoooool001cooooo00?o0000ooooooooool0@?ooool2o`0001oooooo0_l0000L
ooooo`;o00000_ooool2o`0000?ooooo1?l0000Yooooo`Wo00005_ooool2o`000003ooooool0003o
000000;o000000?oooooo`000?l000000_l0000<ooooo`?o000000?oooooo`000?l000004?ooool2
o`0004Gooooo000Looooo`03o`000?oooooooooo03kooooo0ol0000Pooooo`;o00007?ooool2o`00
00Gooooo1?l0000Zooooo`[o00001Oooool2o`0000oooooo0_l0000Looooo`Ko00002_ooool2o`00
04Gooooo000Looooo`03o`000?oooooooooo03kooooo0ol0000;ooooo`;o0000<_ooool2o`0000Co
oooo0_l0000>ooooo`Co00005_ooool2o`000003ooooool0003o000000?o000000?oooooo`000?l0
00001ol000000ooooooo0000o`00000?ooooo`;o00000oooool4o`0000Sooooo0_l00004ooooo`;o
000000?oooooo`000?l000000_ooool6o`0000Gooooo0_l0001:ooooo`007?ooool00ol0003ooooo
ooooo`1<ooooo`;o00004?ooool2o`00023ooooo0_l0000;ooooo`;o00001oooool6o`0000Sooooo
0_l0000:ooooo`;o000000?oooooo`000?l000003Ol000001?oooooo0000o`000?l0000?ooooo`So
00002?ooool2o`0000Cooooo0_l000000ooooooo0000o`000005ooooo`Ko00000_ooool2o`0004[o
oooo000Looooo`03o`000?oooooooooo05kooooo0_l0000Sooooo`;o00002?ooool2o`0000_ooooo
0_l00008ooooo`Oo00001oooool@o`000004ooooool0003o0000o`0000oooooo1?l00005ooooo`;o
00003?ooool2o`0000Oooooo1_l000001?oooooo0000o`000?l0001:ooooo`0000Koooooonk^k_lb
<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000
ooooooooool0G_ooool2o`0002;ooooo0ol000000ooooooo0000o`000004ooooo`Go00000oooool2
o`0000Kooooo0_l00003ooooo`?o00000_ooool5o`0000Kooooo2Ol000000ooooooo0000o`000003
o`000003ooooool0003o000000?o000000?oooooo`000?l000002?ooool2o`0000?ooooo0ol00005
ooooo`Co00002_ooool2o`0000[ooooo0_l000001?oooooo0000o`000?l00004ooooo`;o0000AOoo
ool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0mooooo`;o00006?ooool2o`0000gooooo0_l0000Jooooo`;o0000
0_ooool2o`0000;ooooo1?l000000ooooooo0000o`000003ooooo`;o00001_ooool2o`0000?ooooo
0ol0000=ooooo`oo000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000004ooooo`;o
00000_ooool2o`0000Cooooo0_l00007ooooo`Co00001?ooool2o`000003ooooool0003o000000_o
oooo1ol00003ooooo`;o0000AOooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool0
2Oooool5o`0000Kooooo00?o0000ooooooooool0?Oooool2o`0001Sooooo0_l0000=ooooo`;o0000
6_ooool5o`0000?ooooo1_l00004ooooo`?o00000oooool4o`0000Sooooo0ol00005ooooo`;o0000
0_ooool>o`0000Cooooo0_l00006ooooo`?o00004oooool2o`0000Cooooo0_l000000ooooooo0000
o`000004ooooo`;o00001oooool2o`000003ooooool0003o000000Gooooo1?l00011ooooo`0000?o
ooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oooooo
0ol0000eooooo`;o0000C?ooool4o`0000Cooooo1Ol00005ooooo`;o000000?oooooo`000?l00000
0_l0000:ooooo`?o00001Oooool2o`0000?ooooo3Ol00007ooooo`;o00000oooool3o`0001oooooo
0_l000000ooooooo0000o`000003ooooo`;o00000_ooool2o`0000Sooooo1?l00011ooooo`0000?o
ooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo
00?o0000ooooooooool0=Oooool2o`0001kooooo0_l000000ooooooo0000o`000006ooooo`Oo0000
6Oooool2o`0000;ooooo0_l00006ooooo`Co00000_ooool4o`0000;ooooo0ol00006ooooo`;o0000
0oooool2o`0000Kooooo0_l00004ooooo`co00000_ooool2o`0000?ooooo0_l00004ooooo`Go0000
7?ooool2o`0000Kooooo0_l0000>ooooo`;o0000@Oooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo03Sooooo0_l0
000KoooooaKo00005Oooool2o`0000;ooooo0ol00004ooooo`Go00000_ooool4o`0000_ooooo0_l0
00001?oooooo0000o`000?l00005ooooo`;o00001_ooool<o`0000;ooooo0_l0000:ooooo`Co0000
2?ooool2o`0001;ooooo0_l00007ooooo`Co0000C_ooool00006oooooomgMgOoV9RHoooooonHV9So
MgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo03Sooooo0_l0000=ooooo`?o
00003?ooool2o`000003ooooool0003o0000013o00005_ooool2o`0000;ooooo0_l00002ooooo`Co
00001_ooool2o`0000?ooooo1_l000001?oooooo0000o`000?ooool5o`0000Gooooo0_l00006oooo
o`So00000_ooool2o`0000gooooo0_l0000;ooooo`;o00000oooool2o`0000Wooooo0_l00002oooo
o`Co00000_ooool2o`000003ooooool0003o000000;o0000C_ooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo03_ooooo0_l0000:
ooooo`?o00002oooool5o`000003ooooool0003o000000co000000?oooooo`000?l000000_ooool2
o`00017ooooo0_l00002ooooo`;o00000_ooool2o`0000gooooo1_l000000ooooooo0000o`000003
o`0000Gooooo0_l000000ooooooo0000o`000006ooooo`Ko00001?ooool2o`0000Kooooo0_l00005
ooooo`;o00004?ooool2o`0000?ooooo0_l00003ooooo`?o00000_ooool4o`0000;ooooo0_l0001C
ooooo`007?ooool00ol0003oooooooooo`0hooooo`Go00000_ooool2o`0000Wooooo0_l00005oooo
o`;o00000_oooolGo`0000;ooooo0_l0000Booooo`;o000000Coooooo`000?l0003o00000oooool2
o`0000gooooo0_l00005ooooo`;o00001_ooool2o`000003ooooool0003o000000Kooooo1_l00002
ooooo`Co000000?oooooo`000?l000000oooool2o`0001Oooooo0_l00003ooooo`;o00000oooool3
o`0000?ooooo1_l00002ooooo`;o0000D?ooool001cooooo00?o0000ooooooooool0>?ooool3o`00
00Cooooo0_l00009ooooo`;o00001Oooool2o`0000Gooooo5?l0000Fooooo`;o00000_ooool4o`00
0003ooooool0003o000000Gooooo1?l00004ooooo`Co00002?ooool2o`000004ooooool0003o0000
o`0000Oooooo3Ol000000ooooooo0000o`00000Hooooo`;o00000_ooool2o`0000Wooooo0ol00002
ooooo`Ko000000Coooooo`000?l0003o00002_ooool2o`0000;ooooo0_l00010ooooo`007?ooool0
0ol0003oooooooooo`0]ooooo`;o00008_oooolMo`0001[ooooo0_l00002ooooo`;o00001?ooool<
o`0000Cooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`?o00001?ooool2
o`0001?ooooo0_l00009ooooo`?o00000_ooool2o`0000Wooooo1Ol00007ooooo`Co00002Oooool2
o`0000;ooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o00003?ooool2o`00
01Cooooo7Ol0000Jooooo`;o00000_ooool2o`0000Kooooo3Ol000000ooooooo0000o`000004oooo
o`;o00000_ooool4o`0000gooooo0_l0000>ooooo`Co00002Oooool2o`0000Cooooo1Ol000000ooo
oooo0000o`000005ooooo`;o00002Oooool2o`0000?ooooo0_l0001:ooooo`007?ooool00ol0003o
ooooooooo`0/ooooo`;o00003Oooool2o`0001Gooooo7_l0000Aooooo`;o00000oooool4o`0000[o
oooo0_l00004ooooo`So00001_ooool2o`000003ooooool0003o000000;o00001?ooool3o`0000Oo
oooo0_l0000>ooooo`?o00000oooool2o`0000?ooooo1?l00004ooooo`Go000000?oooooo`000?l0
00005Oooool2o`0000Cooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o0000
4oooool2o`0001;ooooo6ol0000Aooooo`;o00000oooool2o`0000_ooooo0ol00005ooooo`;o0000
00?oooooo`000?l000001?l000001Ooooooo0000o`000?l0003ooooo00Oo00000oooool3o`0001go
oooo0_l00003ooooo`Oo00001?ooool8o`0000;ooooo0_l0000Dooooo`;o0000A?ooool001cooooo
00?o0000ooooooooool0@Oooool2o`0001;ooooo6_l000000ooooooo0000o`00000>ooooo`;o0000
1?ooool2o`0000_ooooo1?l00004ooooo`?o00000_ooool8o`000003ooooool0003o000000;ooooo
1Ol0000=ooooo`;o00005?ooool;o`0000?ooooo3?l0000Booooo`;o00001?ooool2o`00043ooooo
000Looooo`03o`000?oooooooooo04Wooooo0_l00008oooooaoo000000?oooooo`000?l000002ooo
ool2o`0000Cooooo0_l00009ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`00
0004ooooo`Ko000000?oooooo`000?l000000_l000000ooooooo0000o`000002o`0000gooooo1?l0
0007ooooo`?o000000?oooooo`000?l000001?ooool4o`000003ooooool0003o000000Go00000ooo
ool2o`000003ooooool0003o000000;o000000Coooooo`000?l0003o00004oooool2o`0000Cooooo
0_l00010ooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00002?ooool2o`000003ooooool0
003o000001[o000000?oooooo`000?l000003oooool2o`0000_ooooo0_l00006ooooo`;o00000_oo
ool2o`0000Cooooo2_l000000ooooooo0000o`000004o`0000gooooo0_l00007ooooo`So00000_oo
ool>o`000003ooooool0003o000000?o000000?oooooo`000?l000002oooool2o`00057ooooo000L
ooooo`03o`000?oooooooooo03Wooooo0_l0000Joooooaco00000oooool2o`0000kooooo0_l0000G
ooooo`;o00000_ooool2o`0000?ooooo0ol000000ooooooo0000o`000002o`0000;ooooo1?l0000>
ooooo`;o00002Oooool2o`000003ooooool0003o000000;ooooo3ol00002ooooo`?o000000?ooooo
o`000?l000000_l00005ooooo`;o00000_ooool3o`000004ooooool0003o0000o`0000Kooooo0_l0
0014ooooo`007?ooool00ol0003oooooooooo`0gooooo`Co00001_ooool2o`0001;ooooo7Ol00002
ooooo`;o00001Oooool2o`0000Oooooo1?l0000Gooooo`Co00000oooool<o`00013ooooo0ol0000;
oooooa?o00000_ooool4o`000004ooooool0003o0000o`0000Gooooo0_l00003ooooo`;o000000Co
ooooo`000?l0003o00001_ooool2o`0004Cooooo000Looooo`;o0000>?ooool2o`0000Oooooo0ol0
0008ooooo`;o00002OoooolLo`0000Wooooo0_l00008ooooo`?o00004oooool3o`000003ooooool0
003o000000?ooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000;o00004ooo
ool2o`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l000005_l000001?oooooo0000o`00
0?l00005ooooo`;o000000?oooooo`000?l000002Oooool2o`0004Oooooo000Looooo`03o`000?oo
oooooooo043ooooo0ol00003ooooo`;o00000oooool2o`0000Wooooo6ol000000ooooooo0000o`00
000Booooo`;o000000?oooooo`000?l000002Oooool2o`0000?ooooo1Ol00004ooooo`Co00000_oo
ool3o`000003ooooool0003o000000;o00004oooool2o`0000;ooooo1Ol00002oooooa_o000000?o
ooooo`000?l000001_ooool2o`000003ooooool0003o000000;ooooo0_l00005ooooo`;o0000Aooo
ool001cooooo00?o0000ooooooooool09oooool2o`0001Sooooo0_l00003ooooo`Go00002OoooolM
o`000004ooooool0003o0000o`00017ooooo0_l000000ooooooo0000o`000009ooooo`;o00000ooo
ool2o`000003ooooool0003o000000Cooooo0ol00004ooooo`?o000000?oooooo`000?l000000ol0
000Aooooo`;o00000_ooool7o`000003ooooool0003o000001So00001oooool2o`0000;ooooo0_l0
0003ooooo`;o00001oooool2o`0000?ooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0W
ooooo`;o00003Oooool2o`0000Wooooo0_l000000ooooooo0000o`000002ooooo`?o000000?ooooo
o`000?l000001_oooolMo`0000;ooooo1?l0000Mooooo`;o00001_ooool2o`0000?ooooo1?l00003
ooooo`Oo000000?oooooo`000?l000006Oooool3o`000003ooooool0003o000001Wo00001_ooool2
o`0000;ooooo0_l00002ooooo`;o00002?ooool2o`0000?ooooo0_l00010ooooo`007?ooool00ol0
003oooooooooo`0aooooo`;o00000_ooool3o`0000cooooo0_l00006ooooo`;o00002?ooool2o`00
0003ooooool0003o000001Oo00000oooool2o`0002Gooooo0_l00003ooooo`Go00000_ooool2o`00
0003ooooool0003o000000Oo00005?ooool2o`000003ooooool0003o000000;ooooo6?l000001?oo
oooo0000o`000?l00007ooooo`;o00000_ooool4o`0000Cooooo0_l000000ooooooo0000o`000016
ooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00000_ooool2o`0001Wooooo0_l00005oooo
o`Co000000?oooooo`000?l000005_l00009ooooo`;o00008oooool6o`0000Gooooo2Ol0000Boooo
o`;o000000Goooooo`000?l0003o0000ooooo`0Lo`0000Gooooo1?l00002ooooo`;o00001_ooool5
o`0004Kooooo000Looooo`03o`000?oooooooooo037ooooo0_l00007ooooo`;o00002_ooool2o`00
00Sooooo0_l00005oooooa[o000000?oooooo`000?l000002Oooool2o`0002?ooooo1_l00007oooo
o`;o00000oooool2o`0001Gooooo8ol00002ooooo`;o00001Oooool2o`0000?ooooo0_l00002oooo
o`;o0000Aoooool001cooooo00?o0000ooooooooool0<Oooool2o`0000Oooooo0_l00005ooooo`;o
00000oooool2o`0001;ooooo0_l000000ooooooo0000o`00000Bo`000003ooooool0003o000000;o
00001oooool2o`0000Oooooo0_l0000Iooooo`Co00000oooool2o`0000Sooooo0_l00003ooooo`;o
00004_oooolSo`0000Gooooo0_l00002ooooo`;o00000oooool2o`0000?ooooo0_l00016ooooo`00
7?ooool00ol0003oooooooooo`11ooooo`;o00003Oooool6o`0000Gooooo4ol00004ooooo`Co0000
0_ooool2o`0000cooooo0_l0000Gooooo`Ko00000oooool2o`0000;ooooo0_l00004ooooo`;o0000
0oooool2o`0000cooooo0_l00004ooooo`;o000000?oooooo`000?l000006ol000000ooooooo0000
o`000002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Sooooo1?l00014ooooo`007?oo
ool00ol0003oooooooooo`0cooooo`;o00004_ooool2o`000003ooooool0003o000000Cooooo1_l0
0003oooooaGo00001?ooool3o`0000?ooooo0_l0000Iooooo`;o00001oooool2o`000004ooooool0
003o0000ooooo`?o00001?ooool5o`0001Oooooo2?l000000ooooooo0000o`00000Fo`0000;ooooo
0ol00005ooooo`;o00000_ooool2o`0000_ooooo1?l00004ooooo`?o0000?Oooool001cooooo00?o
0000ooooooooool0<oooool2o`0001;ooooo0_l000001?oooooo0000o`000?l0000<oooooaGo0000
6?ooool2o`000003ooooool0003o000000Sooooo0_l00007ooooo`;o000000Coooooo`000?l0003o
00001oooool3o`0001Wooooo8_l000000ooooooo0000o`000008ooooo`Co00002oooool2o`000003
ooooool0003o000000;o000000Coooooo`000?l0003o0000?Oooool001cooooo00?o0000oooooooo
ool0Boooool4o`0000Oooooo0_l00003oooooa?o00002Oooool2o`0000gooooo0_l000000ooooooo
0000o`00000Dooooo`?o00002_ooool2o`0000Gooooo0_l0000Cooooob?o00001oooool4o`0000_o
oooo0_l000000ooooooo0000o`000002o`00047ooooo000Looooo`03o`000?oooooooooo04gooooo
0_l00007ooooo`;o00000ooooolBo`000003ooooool0003o000000Oooooo1?l00004ooooo`;o0000
1?ooool2o`0000_ooooo0_l00007ooooo`;o00003oooool2o`0000Gooooo1Ol0000Aooooo`co0000
00?oooooo`000?l000003Ol000000ooooooo0000o`000003o`0001Kooooo0_l00016ooooo`007?oo
ool00ol0003oooooooooo`0aooooo`;o00003oooool2o`0000?ooooo0_l0000<ooooo`;o00000_oo
ool2o`000004ooooool0003o0000o`0000?ooooo0_l000000ooooooo0000o`000002o`000003oooo
ool0003o000000Co00002Oooool2o`0000Cooooo0_l00004ooooo`;o00001?ooool4o`0000?ooooo
0_l00004ooooo`;o000000?oooooo`000?l000000_ooool2o`0001;ooooo1Ol00004ooooo`Co0000
2ooooolPo`0001Sooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00003ooo
ool2o`0000?ooooo0_l0000<ooooo`;o00000_ooool2o`000005ooooool0003o0000o`000?ooool0
0_l00003ooooo`Co00000_ooool4o`0000Gooooo0_l00004ooooo`;o00000_ooool2o`000003oooo
ool0003o000000;ooooo1Ol000000ooooooo0000o`000002o`0000Wooooo0_l000000ooooooo0000
o`000002ooooo`;o00002Oooool4o`0000Gooooo0_l00007ooooo`Co00003?oooolOo`0001Sooooo
0ol00013ooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00007_ooool2o`000003ooooool0
003o000000?ooooo1?l00002ooooo`;o00001?ooool2o`000003ooooool0003o000000?ooooo0ol0
0002ooooo`;o000000?oooooo`000?l000000_ooool5o`00017ooooo0_l00003ooooo`;o00002?oo
ool5o`0001Oooooo1?l00002oooooaco00000oooool2o`0001Oooooo0_l00013ooooo`007?ooool2
o`0003kooooo0_l0000Mooooo`?o00002oooool4o`0000?ooooo0_l00003ooooo`;o000000?ooooo
o`000?l000001Oooool2o`0000;ooooo0ol0000Iooooo`;o00002oooool2o`0000gooooo0_l00008
ooooo`Co00000ooooolKo`0000?ooooo1?l0001Jooooo`007?ooool00ol0003oooooooooo`0/oooo
o`;o00003oooool2o`0001gooooo0ol00009ooooo`So00001?ooool4o`0000Sooooo0_l00002oooo
o`?o00006Oooool2o`0000_ooooo0_l000000ooooooo0000o`00000:ooooo`;o00002?ooool4o`00
0003ooooool0003o000001Go00001?ooool4o`000003ooooool0003o000000Co00007oooool2o`00
03Oooooo000Looooo`03o`000?oooooooooo02cooooo0_l00003ooooo`;o00003_ooool2o`0001co
oooo0_l00007ooooo`;o00001?ooool2o`0000?ooooo0ol0000:ooooo`Co000000?oooooo`000?l0
00000oooool2o`0000cooooo0_l00003ooooo`;o00001_ooool2o`0000Wooooo0_l00007ooooo`;o
00000_ooool2o`0000cooooo5_l00007ooooo`;o00001Oooool2o`0001oooooo1?l0000eooooo`00
7?ooool00ol0003oooooooooo`0aooooo`;o00000_ooool2o`0000[ooooo0_l0000Looooo`Co0000
4?ooool2o`0000_ooooo1?l00006ooooo`;o00003?ooool4o`000003ooooool0003o000000;o0000
00Coooooo`000?l0003ooooo0_l00002ooooo`Go00001oooool2o`000003ooooool0003o000000;o
000000?oooooo`000?l000000_l0000>oooooa;o000000?oooooo`000?l000005?ooool2o`0001So
oooo0_l0000eooooo`007?ooool00ol0003oooooooooo`0eooooo`;o00001oooool2o`00027ooooo
1?l00005ooooo`;o00001?ooool2o`0000Kooooo0_l00002ooooo`;o00000_ooool2o`0000Gooooo
0ol0000@ooooo`;o00000oooool2o`000003ooooool0003o000000Cooooo1_l00007ooooo`;o0000
00?oooooo`000?l000000_l00003ooooo`?o00000_ooool2o`0000?ooooo0_l00002oooooaCo0000
00?oooooo`000?l000001?ooool2o`0000kooooo0_l0000Booooo`;o0000>oooool001cooooo00?o
0000ooooooooool0=?ooool2o`0000Sooooo0_l0000Pooooo`;o000000Coooooo`000?l0003ooooo
1_l00004ooooo`;o00001_ooool2o`000003ooooool0003o000000?o00001oooool3o`0000oooooo
0_l00007ooooo`;o000000Coooooo`000?l0003ooooo0_l0000;ooooo`;o00002Oooool2o`0000;o
oooo0_l00003ooooo`;o00000_oooolDo`0000Oooooo1_l0000:ooooo`;o00004_ooool2o`000003
ooooool0003o000003Sooooo000Looooo`03o`000?oooooooooo03Cooooo0_l0000Vooooo`;o0000
0_ooool2o`0000Cooooo1ol0000>ooooo`Go000000?oooooo`000?l000004_ooool2o`0000;ooooo
1?l00008ooooo`Co00003?ooool2o`0000Sooooo0_l0000?ooooo`;o00000_ooool3o`0000?ooooo
1?l0000<ooooo`Co00002?ooool2o`0001Oooooo0_l0000hooooo`007?ooool00ol0003ooooooooo
o`1Looooo`;o00002Oooool6o`0000Kooooo0_l00003ooooo`;o00000_ooool3o`0000;ooooo0_l0
0004ooooo`;o00003?ooool2o`0000?ooooo0ol00008ooooo`Co00005?ooool6o`0000Sooooo0_l0
0005ooooo`;o000000?oooooo`000?l000000oooool2o`0000gooooo0_l0000;ooooo`;o00002?oo
ool4o`0004Gooooo000Looooo`03o`000?oooooooooo06Wooooo2Ol000000ooooooo0000o`000005
o`0000gooooo0_l00007ooooo`;o00005?ooool2o`000003ooooool0003o000000Cooooo0_l0000;
ooooo`?o00000_ooool4o`0000Gooooo0ol00005ooooo`;o00005Oooool2o`0001Cooooo1Ol00006
ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0??ooool2o`0000Gooooo0_l0000Woooo
o`Ko000000?oooooo`000?l000001?l0000Booooo`;o00000oooool2o`0000?ooooo0ol0000<oooo
o`;o00000oooool2o`0000Cooooo0_l0000;ooooo`?o00001?ooool2o`0000Gooooo0_l0000Doooo
o`Co00006oooool2o`0000Wooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0Vooooo`;o
00003_ooool2o`0000Cooooo0_l00004ooooo`?o00007?ooool2o`0000cooooo0_l00002ooooo`;o
00000_ooool2o`0001;ooooo0_l00008ooooo`?o00002?ooool2o`000005ooooool0003o0000o`00
0?ooool00_l0000Dooooo`;o00002Oooool3o`0000kooooo0_l00005ooooo`Co00000_ooool2o`00
023ooooo0ol0000nooooo`007?ooool00ol0003oooooooooo`0Vooooo`;o00003_ooool2o`0000[o
oooo0_l0000Mooooo`;o00003?ooool2o`0001?ooooo0_l00009ooooo`;o00003Oooool8o`000003
ooooool0003o000000kooooo0_l00009ooooo`;o00001?ooool3o`000004ooooool0003o0000o`00
00Oooooo0_l000000ooooooo0000o`00000;ooooo`;o00008?ooool3o`0003kooooo000Looooo`03
o`000?oooooooooo06cooooo0_l0000Fooooo`;o00002Oooool2o`0000_ooooo1?l00002ooooo`?o
00004_ooool2o`0000Wooooo0_l00005ooooo`;o000000Coooooo`000?l0003o00001oooool2o`00
00[ooooo0_l0000<ooooo`Co00003?ooool4o`0000Cooooo0_l0000oooooo`007?ooool00ol0003o
ooooooooo`1Sooooo`;o00000_ooool2o`0000?ooooo0_l0000^ooooo`?o00001?ooool2o`0002Co
oooo0_l00007ooooo`Oo00002Oooool2o`0000Wooooo0_l000000ooooooo0000o`000004o`0000[o
oooo1?l00004ooooo`;o00000oooool2o`0003[ooooo000Looooo`03o`000?oooooooooo03Kooooo
0_l0000=ooooo`;o00007?ooool2o`0000;ooooo0_l0000Qooooo`;o00004?ooool2o`0001_ooooo
0_l00004ooooo`?o00001Oooool2o`0000Wooooo1ol00007ooooo`;o00002oooool2o`0000Gooooo
0_l00007ooooo`;o00002?ooool3o`0000?ooooo0_l0000jooooo`007?ooool00ol0003ooooooooo
o`0fooooo`;o00003Oooool2o`0001Kooooo0_l0000Sooooo`;o00001_ooool2o`0000Oooooo0_l0
0009ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Sooooo0_l00002ooooo`Go00001?oo
ool3o`0000Gooooo0_l00006ooooo`Go000000?oooooo`000?l000002Oooool2o`0000Cooooo0_l0
0005ooooo`;o00001Oooool2o`0000Oooooo0_l00003ooooo`;o00000_ooool3o`0000Cooooo0_l0
000jooooo`007?ooool2o`0002Kooooo0_l0000Sooooo`;o00004?ooool3o`0001cooooo0ol00004
ooooo`;o00001Oooool2o`0000Sooooo0_l00003ooooo`;o00001?ooool2o`000003ooooool0003o
000000Gooooo0_l00008ooooo`?o000000Coooooo`000?l0003o00000_ooool2o`0000?ooooo0_l0
000=ooooo`?o00001oooool2o`0000_ooooo0_l00005ooooo`;o00002_ooool2o`0000Oooooo0_l0
0002ooooo`?o0000@?ooool001cooooo00?o0000ooooooooool09Oooool2o`0002?ooooo0_l0000@
ooooo`?o00001oooool2o`0000Oooooo0_l0000:ooooo`?o00000oooool2o`0000Kooooo0_l00006
ooooo`;o00001Oooool2o`00017ooooo0_l00005ooooo`Co00001Oooool2o`0001cooooo0_l0000N
ooooo`;o00001oooool2o`000003ooooool0003o000000?ooooo0_l0000mooooo`007?ooool00ol0
003oooooooooo`0eooooo`;o00003_ooool3o`0001kooooo0_l00007ooooo`;o00002_ooool2o`00
00Cooooo0_l0000>ooooo`;o00001Oooool2o`0000Wooooo0_l00006ooooo`;o00001oooool3o`00
02;ooooo0_l00007ooooo`;o00005Oooool2o`0000Wooooo0ol00003ooooo`;o0000?Oooool001co
oooo00?o0000ooooooooool0=Oooool2o`0000[ooooo0_l00002ooooo`?o00004_ooool2o`000003
ooooool0003o000000;ooooo0ol00002ooooo`Go0000<_ooool2o`0000Cooooo0_l000000ooooooo
0000o`00000<ooooo`Go00000_ooool2o`0000Cooooo0_l0000@ooooo`;o00001?ooool2o`0000Ko
oooo0ol00004ooooo`;o00006_ooool2o`0000Cooooo0_l0000mooooo`007?ooool00ol0003ooooo
ooooo`11ooooo`;o00005oooool2o`000003ooooool0003o000000Go00000_ooool5o`0000Gooooo
1Ol00003ooooo`;o00001oooool4o`0000cooooo0_l00008ooooo`Co00000_ooool2o`0000?ooooo
0ol00003ooooo`;o00002Oooool9o`000003ooooool0003o000000_ooooo0_l00002ooooo`?o0000
3?ooool2o`0000Gooooo0_l0000Gooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0=ooo
ool4o`0001_ooooo0ol00003ooooo`;o000000?oooooo`000?l000002?l00004ooooo`;o000000?o
ooooo`000?l000000ol00003ooooo`;o000000?oooooo`000?l000001?ooool4o`000003ooooool0
003o000000Wooooo0_l00008ooooo`;o00001?ooool2o`0000Cooooo0_l00003ooooo`;o00002_oo
ool9o`0000[ooooo0_l000000ooooooo0000o`000004o`0000Gooooo0_l00006ooooo`;o00007_oo
ool2o`0004Kooooo000Looooo`03o`000?oooooooooo02oooooo0_l00006ooooo`Co00006_ooool4
o`000003ooooool0003o0000013o000000?oooooo`000?l000001?ooool2o`0000Kooooo0_l00005
ooooo`;o00000_ooool2o`0000cooooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool2
o`0000Kooooo2?l00008ooooo`Wo00002?ooool4o`0000?ooooo0ol00004ooooo`Co0000K_ooool0
01cooooo00?o0000ooooooooool0;?ooool2o`000003ooooool0003o000000?ooooo0_l00002oooo
o`;o00006_ooool3o`0000?ooooo0_l000000ooooooo0000o`00000=o`0000Wooooo0_l00004oooo
o`;o00001Oooool2o`0000Cooooo0_l0000:ooooo`;o000000?oooooo`000?l000000_ooool2o`00
00;ooooo0ol00006ooooo`So000000Coooooo`000?l0003ooooo0_l00004ooooo`;o000000?ooooo
o`000?l000000_l00002ooooo`Co00000_ooool2o`0000Kooooo0_l00004ooooo`;o00001?ooool2
o`0002[ooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00001_ooool2o`00
01Gooooo0_l00007ooooo`;o00001?ooool2o`000003ooooool0003o0000013o00001_ooool2o`00
00gooooo0_l00002ooooo`;o00004?ooool9o`000004ooooool0003o0000o`0000;ooooo1?l00002
ooooo`Co000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000;o00000_ooool4
o`0001Kooooo0_l0000Zooooo`;o00002Oooool2o`0003?ooooo000Looooo`03o`000?oooooooooo
03Gooooo1Ol0000<ooooo`;o00000oooool2o`0000cooooo0_l000000ooooooo0000o`00000Ao`00
01Gooooo0_l0000:ooooo`;o000000?oooooo`000?l000000_l00003ooooo`Wo000000?oooooo`00
0?l000002?l000000ooooooo0000o`000002o`0000Sooooo1ol000000ooooooo0000o`000003oooo
o`Co0000;?ooool4o`0001Sooooo0_l0000cooooo`007?ooool00ol0003oooooooooo`0Uooooo`;o
00003_ooool5o`0000cooooo1?l0000?oooooaOo00007Oooool5o`000003ooooool0003o000000;o
00001Oooool6o`0000?ooooo2Ol000000ooooooo0000o`000002o`0000;ooooo0ol000000ooooooo
0000o`000002o`000003ooooool0003o000000;o000000?oooooo`000?l000000oooool4o`0000Go
oooo0_l00007ooooo`;o00006oooool5o`0000cooooo0_l0000oooooo`007?ooool00ol0003ooooo
ooooo`0Uooooo`;o00004oooool2o`0000;ooooo0_l00008ooooo`;o00004OoooolEo`0001gooooo
2Ol00003ooooo`;o000000?oooooo`000?l000000ol000000ooooooo0000o`00000Go`0000Cooooo
0_l00002ooooo`Co000000?oooooo`000?l000001oooool2o`0000Oooooo0_l00008ooooo`;o0000
4Oooool2o`000004ooooool0003o0000o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0003oo
oooo000Looooo`03o`000?oooooooooo03[ooooo0_l00002ooooo`;o00004Oooool2o`0000Cooooo
0_l00002oooooaKo00006oooool2o`0000;ooooo1_l00003ooooo`;o000000?oooooo`000?l00000
6ol00006ooooo`;o00001?ooool2o`000003ooooool0003o000000;ooooo0_l00007ooooo`;o0000
3Oooool2o`0001Cooooo0ol00002ooooo`;o00000_ooool2o`0004Cooooo000Looooo`03o`000?oo
oooooooo057ooooo0_l00004ooooo`;o00000_ooool2o`000003ooooool0003o0000017o00004ooo
ool2o`0000Kooooo0_l00009ooooo`;o00000ooooolLo`000004ooooool0003o0000ooooo`;o0000
3_ooool2o`0000Oooooo0_l0000Tooooo`;o00002oooool2o`0003oooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0
003oooooooooo`1Hooooo`;o00001?oooolBo`0000Oooooo0_l0000;ooooo`;o00001?ooool2o`00
00;ooooo0_l00002ooooo`;o00000_ooool3o`000003ooooool0003o000000Ko000000?oooooo`00
0?l000005_l000000ooooooo0000o`000006ooooo`;o00000oooool2o`0000Cooooo0_l0000Boooo
o`?o00005Oooool2o`0000_ooooo0_l0000oooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5
ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0<?oo
ool2o`0002Kooooo0_l00004oooooa?o00001_ooool3o`0000;ooooo0_l00007ooooo`;o00000ooo
ool2o`0000;ooooo0_l000001Ooooooo0000o`000?l0003ooooo00?o000000?oooooo`000?l00000
8?l00007ooooo`Co00000oooool3o`0000?ooooo0ol0000:ooooo`;o00001Oooool3o`0001Sooooo
1Ol00016ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`0`ooooo`;o00006Oooool2o`0000?ooooo
0_l00002ooooo`;o00000_ooool2o`000004ooooool0003o0000oooooa?o000000?oooooo`000?l0
00001?ooool2o`0000;ooooo0_l00007ooooo`;o00001_ooool2o`0000;ooooo:_l00007ooooo`;o
00001_ooool2o`000004ooooool0003o0000ooooo`;o00002_ooool2o`00023ooooo1Ol00016oooo
o`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9SooooooiRH
V?lQ8B401_ooool3o`0003gooooo0_l0000<ooooo`;o00000oooool2o`0000;ooooo0_l00002oooo
o`;o000000?oooooo`000?l000000_oooolFo`0000?ooooo0_l00002ooooo`;o00003oooool2o`00
00?ooooo4?l000000ooooooo0000o`000002o`0000;ooooo5Ol00004ooooo`;o00002Oooool2o`00
0004ooooool0003o0000ooooo`;o00009oooool5o`0004Sooooo00000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooo
oooo02gooooo0_l0000>ooooo`;o00006Oooool3o`0000Cooooo4ol000001?oooooo0000o`000?l0
0002ooooo`;o00000_ooool2o`0001Cooooo3Ol000001?oooooo0000o`000?ooool4o`000003oooo
ool0003o000001Co00000oooool3o`0000oooooo0_l0000Uooooo`Co000000Coooooo`000?l0003o
0000Aoooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7
ooooo`08ooooo`03o`000?oooooooooo02gooooo1?l0000;ooooo`;o00006_ooool3o`0000;ooooo
5_l000000ooooooo0000o`000006ooooo`;o00000oooool2o`0000cooooo0_l000000ooooooo0000
o`00000Zo`0000?ooooo0_l0000fooooo`Co000000?oooooo`000?l000000_l00005ooooo`;o0000
@?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03
o`000?oooooooooo02oooooo0_l0000;ooooo`;o00005?ooool2o`0000Cooooo0_l00003ooooo`;o
000000?oooooo`000?l000004Ol0000>ooooo`;o00002?ooool6o`0000;ooooo0_l000000ooooooo
0000o`00000So`0000gooooo0_l00005ooooo`;o00004?ooool2o`0001Kooooo0_l00003ooooo`;o
00001Oooool4o`00043ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4
A?l0003o410@1_ooool00ol0003oooooooooo`0_ooooo`;o00008Oooool2o`0000kooooo3ol00003
ooooo`;o00001Oooool2o`000003ooooool0003o000000_ooooo1?l00007ooooo`Co00000_oooolQ
o`0000Cooooo0_l00005ooooo`;o00001Oooool2o`00013ooooo0_l0000Hooooo`;o00002?ooool3
o`00047ooooo000Looooo`03o`000?oooooooooo037ooooo0_l00006ooooo`;o00005Oooool2o`00
013ooooo4?l00002ooooo`;o00001Oooool5o`0000[ooooo0_l0000<ooooo`;o00000ooooolPo`00
00Cooooo0ol000000ooooooo0000o`000002o`0002gooooo0ol00002ooooo`;o00002Oooool2o`00
00Cooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00000_ooool2o`0000;o
oooo0_l0000Eooooo`;o00004OoooolCo`0000Cooooo1?l00008ooooo`;o00000_ooool2o`0000So
oooo0_l00002ooooobKo000000?oooooo`000?l000002?l00007ooooo`?o00008oooool3o`0000[o
oooo0_l00007ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0;_ooool4o`0000?ooooo
0_l0000/ooooo`?o000000?oooooo`000?l000003Ol00004ooooo`Go00001?ooool2o`000003oooo
ool0003o000000Cooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00000_oooolbo`0000Ko
oooo0ol0000Yooooo`;o00001Oooool2o`0004Cooooo000Looooo`03o`000?oooooooooo02kooooo
1?l0000^ooooo`Co000000?oooooo`000?l000003?l000000ooooooo0000o`000003o`0000?ooooo
0ol000001?oooooo0000o`000?ooool2o`0000Oooooo0_l000001?oooooo0000o`000?l00004oooo
ob[o00000_ooool2o`000003ooooool0003o000000?o000000?oooooo`000?l000000oooool3o`00
00?ooooo0_l00003ooooo`;o00000oooool2o`0001?ooooo0_l000001?oooooo0000o`000?ooool3
o`0000;ooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`1Pooooo`Co000000?oooooo`00
0?l000000ol00003ooooo`;o000000?oooooo`000?l000001ol00003ooooo`;o00000_ooool2o`00
00;ooooo0_l0000@ooooo`Co000000?oooooo`000?l000007ol00002ooooo`;o00000_ooool2o`00
00;ooooo0ol00002ooooo`;o00000oooool2o`0000Cooooo0_l00002ooooo`Co00000_ooool2o`00
01?ooooo2?l00003ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0DOooool4o`00013o
oooo1?l00002ooooo`;o00000oooool7o`0000gooooo0_l00007ooooo`;o00000_ooool2o`0000Go
oooo0_l000000ooooooo0000o`00000No`0000cooooo0_l00005ooooo`;o00001Oooool3o`0000;o
oooo1?l0000Iooooo`;o000000?oooooo`000?l00000COooool001cooooo00?o0000ooooooooool0
=?ooool2o`0001_ooooo1?l00005ooooo`;o000000?oooooo`000?l000002?ooool2o`0000;ooooo
0_l00003ooooo`Go00001_ooool2o`000003ooooool0003o000000_ooooo1?l00002ooooo`;o0000
1?oooolTo`0000Cooooo0ol00009ooooo`;o000000?oooooo`000?l000000oooool4o`0002?ooooo
0_l0001=ooooo`007?ooool00ol0003oooooooooo`0dooooo`;o00006_ooool2o`0000Sooooo0_l0
00001?oooooo0000o`000?ooool2o`0000Gooooo0_l000000ooooooo0000o`000003o`0000Cooooo
0_l000000ooooooo0000o`000003ooooo`;o000000Coooooo`000?l0003o00002_ooool4o`0000Oo
oooo9ol00002ooooo`?o00002Oooool2o`0000Kooooo0_l0000:ooooo`;o0000J?ooool001cooooo
00?o0000ooooooooool0<Oooool2o`0000Cooooo0_l00003ooooo`;o00004_ooool2o`0000kooooo
0_l00008ooooo`Oo000000Coooooo`000?l0003ooooo0ol00007ooooo`;o00001oooool2o`000003
ooooool0003o000000;o00000_ooool2o`0000;ooooo2ol000000ooooooo0000o`000005o`000003
ooooool0003o000001;o00000_ooool2o`0001Sooooo0_l00004ooooo`;o00007?ooool2o`0004[o
oooo000Looooo`03o`000?oooooooooo037ooooo0_l00004ooooo`;o00000oooool2o`00037ooooo
0_l000000ooooooo0000o`000003o`00017ooooo0_l000000ooooooo0000o`000004ooooo`;o0000
0_ooool;o`000003ooooool0003o000001co00006_ooool2o`00023ooooo1?l0001:ooooo`007?oo
ool00ol0003oooooooooo`0eooooo`;o00001Oooool2o`0003;ooooo0_l000000ooooooo0000o`00
0009ooooo`;o00003?ooool2o`0000Oooooo:_l00008ooooo`;o00001oooool3o`0000_ooooo0_l0
000Kooooo`;o0000C?ooool001cooooo0_l0000aooooo`;o00000oooool2o`0001[ooooo0_l00006
ooooo`;o00004_ooool2o`000003ooooool0003o000000[ooooo1?l0000<ooooo`Ko000000?ooooo
o`000?l000001Ol00002oooooaco000000?oooooo`000?l000000_l00004ooooo`Co00000_ooool2
o`0000Cooooo2?l00008ooooo`?o00006oooool3o`0004_ooooo000Looooo`03o`000?oooooooooo
033ooooo0_l0000Oooooo`;o00001_ooool5o`0000Wooooo0_l00003ooooo`?o00000oooool3o`00
00Oooooo0_l0000@ooooo`Co000000?oooooo`000?l000004Ol000000ooooooo0000o`00000Do`00
00Cooooo1?l00002ooooo`;o00001?ooool8o`0000;ooooo0_l00004ooooo`;o00006oooool4o`00
04_ooooo000Looooo`03o`000?oooooooooo03Kooooo0_l0000Sooooo`?o00002Oooool2o`0000;o
oooo1_l000001?oooooo0000o`000?l00004ooooo`;o00006_ooool7o`0000;ooooo6?l000000ooo
oooo0000o`000006o`0000kooooo0ol00002ooooo`;o00000oooool2o`0001_ooooo0ol00003oooo
o`;o0000COooool001cooooo00?o0000ooooooooool0=_ooool2o`0001_ooooo0_l0000Fooooo`Ko
00002?ooool3o`0000;ooooo0_l0000Fooooo`;o00001_oooolRo`0000Oooooo0_l00004ooooo`?o
00007Oooool3o`0000Cooooo0ol0001Booooo`007?ooool00ol0003oooooooooo`1Cooooo`?o0000
1Oooool2o`0000Wooooo0_l00006ooooo`;o00002_ooool7o`0000_ooooo0_l00007ooooo`;o0000
00Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000002o`0000;ooooo3Ol000000ooooooo
0000o`00000<o`0000Oooooo0_l00005ooooo`;o00001?ooool2o`0001Oooooo0ol00004ooooo`;o
00000oooool2o`0000Oooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o0000
1?ooool2o`0001oooooo0_l00005ooooo`;o000000Coooooo`000?l0003o00001Oooool3o`0000Go
oooo0_l00004ooooo`Oo000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000007oooo
o`?o00001Oooool7o`000003ooooool0003o000001oo00004?ooool2o`0000Kooooo0_l0000Soooo
o`;o00001oooool2o`0004Gooooo000Looooo`03o`000?oooooooooo02gooooo0_l00004ooooo`;o
0000:Oooool3o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000002?ooool7o`000003
ooooool0003o000000?o000000?oooooo`000?l000001oooool3o`0000Gooooo1_l000001?oooooo
0000o`000?ooool2o`0000?ooooo5?l000000ooooooo0000o`000003o`00013ooooo0_l00008oooo
o`?o00007Oooool2o`00057ooooo000Looooo`03o`000?oooooooooo03Oooooo0_l00004ooooo`;o
00007oooool2o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000002oooool2o`0000?o
oooo1?l00004ooooo`;o00001_ooool2o`0000Kooooo0_l00002ooooo`Co00002OoooolDo`000003
ooooool0003o0000017ooooo0_l00007ooooo`?o00007Oooool2o`00057ooooo000Looooo`03o`00
0?oooooooooo03Oooooo0_l00004ooooo`;o00007oooool2o`0000Cooooo0_l00004ooooo`;o0000
2oooool2o`0000?ooooo0ol00005ooooo`;o00004Oooool7o`0000Cooooo0_l000000ooooooo0000
o`00000Do`0000Gooooo0_l00008ooooo`;o000000Coooooo`000?l0003ooooo0_l0000/ooooo`;o
0000BOooool001cooooo00?o0000ooooooooool0?_ooool2o`0001Oooooo0_l0000;ooooo`;o0000
0_ooool4o`0000Sooooo0_l00007ooooo`?o00001?ooool2o`0000cooooo0_l000000ooooooo0000
o`000002o`000003ooooool0003o000001_o000000Goooooo`000?l0003o0000ooooo`02o`0000;o
oooo1?l00005ooooo`?o00001?ooool2o`0001kooooo0_l00007ooooo`;o00000oooool2o`0004Wo
oooo000Looooo`03o`000?oooooooooo03kooooo0_l0000Gooooo`;o00002_ooool3o`0000;ooooo
0ol00009ooooo`;o00002?ooool2o`0000Cooooo1?l00004ooooo`;o00001?ooool6o`0000?ooooo
6?l00009ooooo`;o00000_ooool4o`0000Gooooo0ol0000Sooooo`Ko00001?ooool2o`0004kooooo
000Looooo`03o`000?oooooooooo03Kooooo0_l0000Sooooo`;o00001_ooool3o`0001Sooooo0_l0
0006ooooo`;o00001?ooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo
3_l0000:ooooo`;o00003?ooool2o`0000;ooooo1ol0000:ooooo`;o00004Oooool2o`0000Cooooo
0_l000001?oooooo0000o`000?l0001Dooooo`007?ooool00ol0003oooooooooo`0fooooo`;o0000
8oooool3o`0000Sooooo0_l00003ooooo`;o000000?oooooo`000?l000004?ooool4o`0000cooooo
0ol00003ooooo`Co000000?oooooo`000?l000001?l000000ooooooo0000o`000004o`0000_ooooo
0_l0000<ooooo`;o000000?oooooo`000?l000002Ol00003ooooo`;o000000Coooooo`000?l0003o
00004Oooool2o`0005kooooo000Looooo`03o`000?oooooooooo05cooooo0_l00008ooooo`;o0000
0_ooool3o`000003ooooool0003o0000013ooooo1Ol00008ooooo`;o00000_ooool3o`0000Cooooo
0ol000000ooooooo0000o`000008o`0001[ooooo0_l000001Ooooooo0000o`000?l0003ooooo00?o
000000?oooooo`000?l000000_l00003ooooo`;o000000?oooooo`000?l000006Oooool2o`0005Oo
oooo000Looooo`03o`000?oooooooooo05_ooooo0_l00008ooooo`Co000000?oooooo`000?l00000
0_ooool2o`00013ooooo0_l000000ooooooo0000o`000008ooooo`;o00000oooool2o`0000Cooooo
0ol000000ooooooo0000o`000008o`0000gooooo0_l0000;ooooo`;o000000?oooooo`000?l00000
0_ooool4o`000004ooooool0003o0000o`0000Kooooo0_l0000Eooooo`;o00000_ooool2o`0000?o
oooo0_l0001Booooo`007?ooool00ol0003oooooooooo`1Kooooo`;o00002?ooool6o`0000;ooooo
0_l00002ooooo`;o00003Oooool2o`000003ooooool0003o000001?ooooo3_l00006ooooo`;o0000
1Oooool2o`0001Cooooo0_l000001?oooooo0000o`000?l0000Mooooo`;o00001oooool2o`0005;o
oooo000Looooo`;o0000G?ooool2o`0000_ooooo0ol000001?oooooo0000o`000?l00002ooooo`;o
000000?oooooo`000?l000001_ooool2o`0000Wooooo0_l00007ooooo`;o00001oooool5o`0000Co
oooo0_l00004ooooo`;o00000_ooool3o`0002?ooooo0ol0000Sooooo`;o0000Coooool001cooooo
00?o0000ooooooooool0>_ooool2o`0000[ooooo0_l0000Fooooo`Co00001?ooool4o`0000;ooooo
0_l00006ooooo`;o00001_ooool2o`0000Kooooo1Ol00007ooooo`;o00001oooool4o`0000;ooooo
0_l00007ooooo`;o000000?oooooo`000?l000000_l0000:ooooo`;o00004_ooool2o`0000?ooooo
0ol0000<ooooo`;o000000?oooooo`000?l000001?ooool2o`0000cooooo0_l0001?ooooo`007?oo
ool00ol0003oooooooooo`0jooooo`;o00002_ooool2o`0001Kooooo1?l00004ooooo`Co00006Ooo
ool4o`0000Gooooo0_l00005ooooo`Co000000?oooooo`000?l000003Ol00004ooooo`;o00000_oo
ool5o`0000Gooooo0_l0000Booooo`;o00001oooool2o`0000Wooooo0_l000000ooooooo0000o`00
0004ooooo`;o0000GOooool001cooooo00?o0000ooooooooool0J?ooool5o`0000Cooooo0_l00008
ooooo`;o00001Oooool3o`0000?ooooo0ol000000ooooooo0000o`000005ooooo`go000000?ooooo
o`000?l000001Ol00005ooooo`Oo00008_ooool2o`0000Oooooo0_l0001Xooooo`007?ooool00ol0
003oooooooooo`1Zooooo`Go00000_ooool2o`0000Sooooo0_l000000ooooooo0000o`000002oooo
o`;o000000?oooooo`000?l000001?l00005ooooo`;o000000Coooooo`000?l0003ooooo0_l00005
ooooo`Co00001Oooool2o`0000Gooooo0_l0000Aooooo`?o00001Oooool2o`0000_ooooo0_l00008
ooooo`;o00003Oooool2o`0000Cooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`1/oooo
o`?o00003oooool2o`0000Gooooo1Ol000001?oooooo0000o`000?ooool4o`000004ooooool0003o
0000ooooo`;o00001Oooool5o`0000Cooooo1?l0000Fooooo`?o00001Oooool2o`0000[ooooo0ol0
000?ooooo`?o00001Oooool2o`0000Cooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`0n
ooooo`;o0000:oooool2o`000003ooooool0003o000001Sooooo0_l000001?oooooo0000o`000?oo
ool2o`0000Kooooo0ol00003ooooo`;o000000Coooooo`000?l0003o00001?ooool4o`0001?ooooo
0_l0000Eooooo`;o00004?ooool3o`0000Gooooo0_l0001Iooooo`007?ooool00ol0003ooooooooo
o`0nooooo`;o0000:oooool2o`000003ooooool0003o000000Sooooo0_l000000ooooooo0000o`00
000>ooooo`;o000000?oooooo`000?l000001oooool2o`0000;ooooo1_l000000ooooooo0000o`00
0002ooooo`Co00001Oooool2o`0000cooooo0_l0000<ooooo`;o00008Oooool2o`000003ooooool0
003o000005Kooooo000Looooo`03o`000?oooooooooo06kooooo1?l00006ooooo`;o000000?ooooo
o`000?l000000_ooool5o`0000[ooooo0_l0000;ooooo`Co00000oooool2o`0000_ooooo0_l0000J
ooooo`;o00001?ooool2o`0000Kooooo0_l0000Fooooo`;o0000E_ooool001cooooo00?o0000oooo
ooooool0I?ooool2o`0000Wooooo0ol00002ooooo`;o00001Oooool2o`0000;ooooo1Ol0000:oooo
o`;o000000?oooooo`000?l000003?ooool2o`0002?ooooo0_l00005ooooo`Go000000?oooooo`00
0?l000001_ooool2o`0006kooooo000Looooo`03o`000?oooooooooo06Cooooo0_l00002ooooo`;o
00002Oooool3o`0000Gooooo0_l00003ooooo`;o00000_ooool2o`0000Sooooo0_l000000ooooooo
0000o`00000<ooooo`;o00008oooool2o`0000;ooooo0_l00002ooooo`Co00002?ooool2o`0000;o
oooo0_l0001[ooooo`007?ooool00ol0003oooooooooo`1Wooooo`?o00001_ooool5o`0000Oooooo
1_l00002ooooo`;o00004Oooool3o`00017ooooo0_l0000Kooooo`;o00003_ooool2o`0000;ooooo
0_l0000;ooooo`?o0000GOooool001cooooo00?o0000ooooooooool0DOooool2o`0001Cooooo0_l0
0002ooooo`;o00000oooool5o`0000Cooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l0
000Cooooo`?o00004Oooool2o`00017ooooo0_l0000Yooooo`?o0000GOooool001cooooo00?o0000
ooooooooool0DOooool2o`0001Oooooo0ol00006ooooo`;o00001?ooool2o`0000Oooooo0_l00005
ooooo`;o00003?ooool4o`0000Gooooo0_l0000Looooo`Co0000Qoooool001cooooo00?o0000oooo
ooooool0J_ooool2o`0000Cooooo1_l00007ooooo`?o00000oooool2o`0000Cooooo0_l0000<oooo
o`Co00001Oooool3o`0001gooooo0_l0000Fooooo`;o00003oooool2o`0005kooooo000Looooo`03
o`000?oooooooooo04Cooooo0_l0000Zooooo`Ko00001oooool3o`0000?ooooo0_l0000Cooooo`?o
00001_ooool2o`000003ooooool0003o000000Wooooo1?l00003ooooo`;o00006_ooool2o`0000Co
oooo0_l00005ooooo`;o00002?ooool2o`0000Cooooo0_l0001Hooooo`007?ooool2o`0004Gooooo
0_l0000>ooooo`?o00004oooool2o`0000Cooooo0_l00007ooooo`;o00000_ooool2o`0001Wooooo
0_l00008ooooo`Co00002Oooool9o`0000Cooooo0_l0000Dooooo`;o00000_ooool2o`0000Oooooo
0_l0000>ooooo`;o0000F?ooool001cooooo00?o0000ooooooooool0A_ooool2o`0000cooooo0ol0
000Cooooo`?o00000oooool3o`0000;ooooo0_l00002ooooo`;o00000_ooool2o`0000kooooo0_l0
0009ooooo`;o00002?ooool2o`000003ooooool0003o000000;ooooo0ol000001?oooooo0000o`00
0?ooool2o`000003ooooool0003o000000;o00001?ooool3o`0001Cooooo0_l00002ooooo`;o0000
2oooool2o`0006Cooooo000Looooo`03o`000?oooooooooo04Kooooo0_l0000Sooooo`;o00000ooo
ool4o`000003ooooool0003o000000Sooooo0_l0000<ooooo`Co00003oooool2o`0000?ooooo0_l0
0002ooooo`Ko00003?ooool2o`0000Cooooo0_l00002ooooo`;o00001_ooool3o`0001?ooooo0_l0
001Tooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00003?ooool2o`0001Gooooo1_l0000;
ooooo`;o00003_ooool2o`000003ooooool0003o000000cooooo0_l00007ooooo`Go00000_ooool2
o`0000Gooooo0_l00008ooooo`Ko00000oooool2o`000004ooooool0003o0000o`0000kooooo0_l0
0003ooooo`;o0000I?ooool001cooooo00?o0000ooooooooool0BOooool2o`0000cooooo0_l0000E
ooooo`?o000000Coooooo`000?l0003o00007Oooool2o`0000cooooo0_l00005ooooo`;o000000?o
ooooo`000?l000001?ooool2o`0000?ooooo1?l0000:ooooo`;o00001Oooool2o`0000;ooooo0_l0
000>ooooo`;o00001oooool2o`00063ooooo000Looooo`03o`000?oooooooooo06oooooo0_l00000
1?oooooo0000o`000?l0000[ooooo`;o00001Oooool2o`0000Sooooo0_l00002ooooo`So00004Ooo
ool2o`0000cooooo0_l00009ooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0K_ooool2
o`0000;ooooo0_l0000Tooooo`;o00002_ooool2o`000003ooooool0003o000000Sooooo0_l00004
ooooo`Ko00001?ooool2o`0001Wooooo0_l00009ooooo`;o0000H?ooool001cooooo00?o0000oooo
ooooool0K_ooool2o`0000?ooooo0_l00002ooooo`?o000000?oooooo`000?l000006oooool2o`00
00[ooooo0_l000001?oooooo0000o`000?ooool2o`0000oooooo0_l00004ooooo`Co00002?ooool2
o`0001Sooooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`1cooooo`[o00007oooool2o`00
00cooooo0_l00003ooooo`;o00001Oooool2o`0000?ooooo0_l00005ooooo`?o00001Oooool2o`00
0003ooooool0003o000000Sooooo0_l0000:ooooo`;o0000I?ooool001cooooo00?o0000oooooooo
ool0Koooool2o`0000?ooooo2?l0000Kooooo`;o00000oooool2o`0000cooooo0_l000000ooooooo
0000o`000002o`0000Gooooo0_l0000;ooooo`;o00001Oooool2o`0000Sooooo0_l000000ooooooo
0000o`000004ooooo`;o00001?ooool2o`0006Cooooo000Looooo`03o`000?oooooooooo05oooooo
0_l0000>ooooo`;o00000oooool2o`0001[ooooo1?l00003ooooo`;o000000?oooooo`000?l00000
4Oooool2o`0000Oooooo0_l0000;ooooo`;o00002?ooool2o`0000Cooooo0ol00007ooooo`;o0000
J_ooool001cooooo00?o0000ooooooooool0Coooool2o`0000kooooo0ol0000Tooooo`;o00001ooo
ool5o`0000Kooooo0ol0000Iooooo`;o00001oooool3o`0000[ooooo0ol00004ooooo`;o0000M?oo
ool001cooooo00?o0000ooooooooool0Coooool2o`0000oooooo0_l0000Nooooo`;o00001?ooool2
o`0000Oooooo0_l0000:ooooo`;o00005Oooool2o`0000_ooooo1?l00002ooooo`;o00000_ooool2
o`000003ooooool0003o000007_ooooo000Looooo`03o`000?oooooooooo07Wooooo0_l00005oooo
o`;o00001_ooool2o`0000Gooooo0_l0000?ooooo`;o00004?ooool:o`0000Gooooo0_l00002oooo
o`;o00000_ooool2o`0000;ooooo0_l0001jooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5
ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0IOoo
ool2o`0001;ooooo0_l0000=ooooo`;o00005_ooool2o`0000Cooooo0_l0000<ooooo`_o00000_oo
ool2o`0000;ooooo0_l00006ooooo`;o0000N_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo06Go
oooo0ol0000Vooooo`;o00003?ooool2o`0000;ooooo2?l00002ooooo`;o00003_ooool5o`0000;o
oooo0_l00002ooooo`;o00000_ooool2o`0007kooooo00000ooooooo410@ooooo`02ooooo`03oa0@
4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo06Ko
oooo0_l0000Gooooo`;o00003Oooool2o`0000cooooo0_l00004ooooo`Co00001?ooool2o`0001go
oooo0_l0001nooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05oc8b
<_nHV9SooooooiRHV?lb<S801_ooool3o`0006Sooooo0ol0000Dooooo`;o00000oooool2o`00013o
oooo0ol00007ooooo`;o00003Oooool2o`0009Sooooo00000ooooooo0000ooooo`02ooooo`03o`00
0?oooooooooo00Wooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo06So
oooo0ol0000?ooooo`;o00001Oooool2o`000003ooooool0003o0000013ooooo0ol00003ooooo`?o
000000?oooooo`000?l000003Oooool2o`0009Sooooo00000ooooooo410@ooooo`02ooooo`03oa0@
4?oooooooooo00Wooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo07[o
oooo0_l00005ooooo`?o00004Oooool2o`0000Gooooo1Ol00005ooooo`;o00002?ooool4o`0009Go
oooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zjo`000006
ooooo`03o`000?oooooooooo07_ooooo0_l00005ooooo`Co00003oooool2o`0000Sooooo0_l00005
ooooo`;o00001Oooool2o`000003ooooool0003o000000;o0000UOooool00006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0
Noooool2o`0000;ooooo0_l00002ooooo`?o00009Oooool4o`0000Oooooo0_l0002Aooooo`007?oo
ool00ol0003oooooooooo`1oooooo`;o00006oooool2o`0000gooooo0_l00009ooooo`;o000000?o
ooooo`000?l00000S_ooool001cooooo00?o0000ooooooooool0Q_ooool2o`0000Sooooo0_l0000:
ooooo`;o00003?ooool6o`0000Oooooo1?l0002>ooooo`007?ooool00ol0003oooooooooo`26oooo
o`;o00002?ooool2o`0001Sooooo1_l00007ooooo`;o00002?ooool2o`0008Kooooo000Looooo`03
o`000?oooooooooo08Kooooo0_l0000;ooooo`Co00004oooool2o`0000[ooooo0_l00002ooooo`;o
00001Oooool2o`0008Kooooo000Looooo`03o`000?oooooooooo09?ooooo1?l000000ooooooo0000
o`000004ooooo`;o00002_ooool2o`0000[ooooo0_l00002ooooo`;o0000SOooool001cooooo00?o
0000ooooooooool0V?ooool3o`0000;ooooo0ol00004ooooo`;o00001?ooool2o`0009gooooo000L
ooooo`03o`000?oooooooooo06?ooooo0_l0000dooooo`;o00000_ooool2o`0000Gooooo0_l0002S
ooooo`007?ooool00ol0003oooooooooo`1Sooooo`;o0000B?ooool2o`0009[ooooo000Looooo`03
o`000?oooooooooo0:gooooo0_l0002Jooooo`007?ooool00ol0003oooooooooo`1Wooooo`;o0000
h?ooool001cooooo00?o0000ooooooooool0Ioooool2o`000>3ooooo000Looooo`;o0000oooooom;
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`1aooooo`;o0000e_ooool001cooooo00?o0000ooooooooool0LOooool2o`000=Kooooo000Loooo
o`03o`000?oooooooooo07?ooooo0_l0003Dooooo`007?ooool00ol0003oooooooooo`1cooooo`;o
0000e?ooool001cooooo00?o0000ooooooooool0NOooool2o`000<kooooo000Looooo`03o`000?oo
oooooooo07Wooooo0_l0003>ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`21ooooo`;o0000a_ooool001cooooo00?o0000ooooooooool0POoo
ool2o`000003ooooool0003o00000<?ooooo000Looooo`03o`000?oooooooooo08Cooooo0_l00033
ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`2=ooooo`;o00007?ooool2o`0009cooooo000Looooo`03o`000?oo
oooooooo08gooooo0_l0000Looooo`;o00000_ooool2o`0009Sooooo000Looooo`03o`000?oooooo
oooo0:oooooo0_l0002Hooooo`007?ooool00ol0003oooooooooo`2Dooooo`;o00003oooool2o`00
0:;ooooo000Looooo`03o`000?oooooooooo09Cooooo0_l00002ooooo`;o00002oooool2o`000:;o
oooo000Looooo`03o`000?oooooooooo09Sooooo0_l00003ooooo`;o00000_ooool2o`000:Kooooo
000Looooo`03o`000?oooooooooo09gooooo0_l00002ooooo`;o0000Y_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`004_ooool4o`00
0003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool0
1Oooool3o`000?ooooooB_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool0
0ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Co
oooo00?o0000ooooooooool0oooooomBooooo`004_ooool00omEEEGoIVIVo`00003ooooooeCooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo002Uooooo`04oa0@4?l0003o0000oooo
o`;o000000?o410@ooooooooool05_ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo1Ol00003
ooooo`Go0000T?ooool00:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00003Oooool0
2OmgMgOo<S8booooooooooooV9RHob4Q8Oo^k^koooooodA4A003ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@0T?ooool00:Kooooo00Go0000ooooooooooooooooo`00000Mooooo`07o`000?oooooooooo
oooooonHV9So8B4Qonk^kP05ooooo`03oiRHV?lQ8B7ok^k^097ooooo002Vooooo`05o`000?oooooo
ooooooooool000002Oooool6o`0000gooooo00?oMgMgoc8b<_ooool00oooool00onHV9So8B4Qonk^
kP05ooooo`03oiRHV?lQ8B7ok^k^093ooooo002Vooooo`05o`000?n7QhOoooooojVYZOl000006Ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?oMgMgofIVI_ooool01Oooool00omgMgOoIVIV
ooooo`2?ooooo`00YOooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo01Oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08kooooo0034
ooooo`03o`000?oooooooooo00Cooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05o`000?nj
^[[ooooooiRHV?l@4100T?ooool00<Cooooo1?l00003ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01OnHV9So410@o`000?lQ8B7oc<c<093ooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(528) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.65587 .52935 Mdot
.65911 .49838 Mdot
.30036 .39502 Mdot
.49908 .61587 Mdot
.33091 .53918 Mdot
.31951 .42866 Mdot
.49026 .31434 Mdot
.51401 .30588 Mdot
.31427 .41517 Mdot
.6302 .6897 Mdot
.4872 .28039 Mdot
.57788 .66424 Mdot
.49287 .2989 Mdot
.53172 .64009 Mdot
.57109 .43302 Mdot
.44232 .67555 Mdot
.71924 .48713 Mdot
.33175 .60567 Mdot
.4402 .67441 Mdot
.29789 .40916 Mdot
.41115 .66444 Mdot
.5204 .6471 Mdot
.70536 .47792 Mdot
.529 .64276 Mdot
.53016 .59606 Mdot
.66809 .50258 Mdot
.65083 .52469 Mdot
.51548 .58414 Mdot
.48574 .59887 Mdot
.49805 .28599 Mdot
.21921 .41507 Mdot
.84304 .5455 Mdot
.5564 .5872 Mdot
.76698 .60855 Mdot
.51541 .30593 Mdot
.45313 .21921 Mdot
.32937 .39559 Mdot
.50884 .3229 Mdot
.51318 .28568 Mdot
.51735 .29249 Mdot
.49163 .3213 Mdot
.66975 .51112 Mdot
.50033 .26431 Mdot
.34712 .35619 Mdot
.55101 .62674 Mdot
.76237 .44924 Mdot
.2277 .34317 Mdot
.50104 .58803 Mdot
.68889 .53101 Mdot
.29745 .43155 Mdot
.3311 .7412 Mdot
.47969 .33045 Mdot
.61701 .39023 Mdot
.36427 .8667 Mdot
.48929 .28695 Mdot
.49157 .61162 Mdot
.30734 .4352 Mdot
.50563 .63082 Mdot
.48874 .64305 Mdot
.76499 .5832 Mdot
.51166 .66093 Mdot
.31749 .57428 Mdot
.64276 .49192 Mdot
.35864 .39974 Mdot
.3132 .42238 Mdot
.49628 .32698 Mdot
.66431 .47795 Mdot
.50196 .30701 Mdot
.47412 .6009 Mdot
.29325 .41917 Mdot
.49315 .59649 Mdot
.49446 .28135 Mdot
.66597 .48152 Mdot
.55363 .62249 Mdot
.70655 .39862 Mdot
.52067 .35483 Mdot
.34359 .48853 Mdot
.72476 .70771 Mdot
.37379 .80086 Mdot
.27107 .44435 Mdot
.54657 .64222 Mdot
.27971 .75912 Mdot
.54509 .39796 Mdot
.65385 .50219 Mdot
.69448 .45239 Mdot
.714 .28701 Mdot
.49975 .58449 Mdot
.37863 .51077 Mdot
.5727 .62203 Mdot
.48152 .50937 Mdot
.31286 .40777 Mdot
.6739 .48713 Mdot
.55356 .62901 Mdot
.56729 .62129 Mdot
.63005 .59442 Mdot
.47386 .62301 Mdot
.52073 .61567 Mdot
.64696 .46554 Mdot
.47352 .28474 Mdot
.60018 .61932 Mdot
.24229 .57605 Mdot
.60626 .39249 Mdot
.50866 .6066 Mdot
.33988 .421 Mdot
.63575 .50458 Mdot
.53169 .61543 Mdot
.5074 .30975 Mdot
.53501 .64872 Mdot
.45286 .29389 Mdot
.71615 .49236 Mdot
.56963 .62201 Mdot
.29272 .55294 Mdot
.55205 .50003 Mdot
.70394 .50941 Mdot
.62547 .76802 Mdot
.51478 .65947 Mdot
.50449 .65202 Mdot
.65636 .50749 Mdot
.31087 .3913 Mdot
.40429 .46234 Mdot
.69416 .47589 Mdot
.51467 .28547 Mdot
.70977 .51787 Mdot
.56612 .6669 Mdot
.30861 .39335 Mdot
.61496 .40083 Mdot
.6096 .39058 Mdot
.29558 .63235 Mdot
.55707 .62394 Mdot
.58685 .5162 Mdot
.33295 .42936 Mdot
.66366 .51115 Mdot
.50133 .29955 Mdot
.48535 .65391 Mdot
.691 .51498 Mdot
.50454 .27465 Mdot
.32727 .58492 Mdot
.33375 .54069 Mdot
.6803 .52691 Mdot
.52625 .75939 Mdot
.4683 .32411 Mdot
.51923 .29201 Mdot
.33058 .73621 Mdot
.65283 .50748 Mdot
.32084 .5518 Mdot
.48872 .26612 Mdot
.37841 .6869 Mdot
.50374 .6689 Mdot
.2965 .66614 Mdot
.20856 .67984 Mdot
.33056 .73908 Mdot
.81152 .57783 Mdot
.29876 .54158 Mdot
.48987 .2651 Mdot
.50264 .59501 Mdot
.68709 .50773 Mdot
.68118 .51596 Mdot
.56534 .62385 Mdot
.54676 .60357 Mdot
.54043 .62834 Mdot
.4916 .65904 Mdot
.39919 .20839 Mdot
.55017 .63626 Mdot
.56352 .2699 Mdot
.69652 .50891 Mdot
.54073 .60556 Mdot
.34708 .42007 Mdot
.50641 .6892 Mdot
.51067 .31901 Mdot
.48919 .63729 Mdot
.54017 .59775 Mdot
.50301 .68069 Mdot
.49744 .26507 Mdot
.70196 .36863 Mdot
.45205 .82861 Mdot
.46992 .21869 Mdot
.62047 .37312 Mdot
.32832 .4411 Mdot
.53688 .66301 Mdot
.30373 .5486 Mdot
.58371 .66617 Mdot
.49487 .6519 Mdot
.33136 .74671 Mdot
.54919 .59782 Mdot
.785 .63358 Mdot
.59464 .5961 Mdot
.69814 .26625 Mdot
.57485 .25054 Mdot
.49625 .65815 Mdot
.60313 .72317 Mdot
.29047 .65074 Mdot
.19492 .43713 Mdot
.50031 .29207 Mdot
.35174 .42268 Mdot
.31869 .38833 Mdot
.52195 .3066 Mdot
.52809 .55819 Mdot
.63413 .69808 Mdot
.46985 .62257 Mdot
.61296 .40045 Mdot
.74517 .49576 Mdot
.30605 .53737 Mdot
.67947 .52771 Mdot
.30594 .78229 Mdot
.38693 .54198 Mdot
.28203 .44465 Mdot
.33687 .59786 Mdot
.30979 .45234 Mdot
.6063 .41432 Mdot
.31354 .54622 Mdot
.50971 .61859 Mdot
.7116 .50869 Mdot
.28606 .65204 Mdot
.45536 .67621 Mdot
.54116 .12914 Mdot
.65156 .49506 Mdot
.5169 .47233 Mdot
.49402 .29079 Mdot
.35355 .39646 Mdot
.50055 .58442 Mdot
.51993 .63088 Mdot
.64004 .50277 Mdot
.49378 .59224 Mdot
.41264 .49907 Mdot
.5409 .59545 Mdot
.36288 .42679 Mdot
.29439 .59555 Mdot
.45006 .28723 Mdot
.34676 .59641 Mdot
.67636 .47786 Mdot
.54257 .33158 Mdot
.3432 .4204 Mdot
.52835 .53501 Mdot
.5069 .29333 Mdot
.32114 .58752 Mdot
.33413 .40272 Mdot
.29051 .56384 Mdot
.56023 .65156 Mdot
.32178 .39552 Mdot
.32545 .56877 Mdot
.45185 .38726 Mdot
.52087 .61461 Mdot
.3279 .67414 Mdot
.4686 .27777 Mdot
.65897 .52831 Mdot
.50323 .66007 Mdot
.61997 .40702 Mdot
.53661 .6851 Mdot
.57257 .49331 Mdot
.60381 .41988 Mdot
.58345 .40349 Mdot
.29512 .46784 Mdot
.33367 .56058 Mdot
.68433 .41555 Mdot
.4339 .44116 Mdot
.71888 .48561 Mdot
.55302 .66026 Mdot
.75341 .36662 Mdot
.46862 .27626 Mdot
.50681 .62084 Mdot
.6928 .2771 Mdot
.48765 .2656 Mdot
.50237 .6379 Mdot
.48498 .31927 Mdot
.68541 .51328 Mdot
.50023 .3939 Mdot
.69754 .53229 Mdot
.49734 .61951 Mdot
.47454 .30138 Mdot
.34989 .41622 Mdot
.66895 .50257 Mdot
.5277 .65129 Mdot
.54912 .64414 Mdot
.61069 .40348 Mdot
.55036 .61327 Mdot
.76418 .35388 Mdot
.50355 .58733 Mdot
.30274 .44796 Mdot
.47511 .61021 Mdot
.26751 .65547 Mdot
.33818 .54503 Mdot
.6886 .46857 Mdot
.59878 .41975 Mdot
.30986 .40701 Mdot
.47951 .38924 Mdot
.31158 .62697 Mdot
.54132 .64282 Mdot
.59402 .40086 Mdot
.51653 .46737 Mdot
.50326 .32331 Mdot
.51087 .57481 Mdot
.40746 .4805 Mdot
.3205 .4051 Mdot
.61196 .40782 Mdot
.45029 .61731 Mdot
.65836 .53453 Mdot
.49324 .60698 Mdot
.3344 .39917 Mdot
.67357 .53564 Mdot
.47973 .63774 Mdot
.3002 .27501 Mdot
.62073 .40287 Mdot
.47006 .30184 Mdot
.62013 .55902 Mdot
.55291 .64938 Mdot
.32537 .38729 Mdot
.68585 .51858 Mdot
.47978 .29181 Mdot
.71053 .49175 Mdot
.2729 .63879 Mdot
.60275 .52174 Mdot
.39769 .24276 Mdot
.32586 .60842 Mdot
.7759 .70207 Mdot
.46441 .22068 Mdot
.59299 .53591 Mdot
.37076 .45795 Mdot
.61864 .19276 Mdot
.33712 .40928 Mdot
.55702 .75308 Mdot
.30609 .41746 Mdot
.50312 .60262 Mdot
.31738 .42611 Mdot
.7723 .33985 Mdot
.53333 .58746 Mdot
.32068 .44561 Mdot
.37699 .24606 Mdot
.55271 .59912 Mdot
.69695 .51223 Mdot
.81336 .47974 Mdot
.64613 .76734 Mdot
.48776 .75525 Mdot
.31424 .44542 Mdot
.54792 .76596 Mdot
.51057 .58283 Mdot
.43912 .66677 Mdot
.68304 .50426 Mdot
.56088 .67818 Mdot
.30489 .5297 Mdot
.29102 .54817 Mdot
.3673 .73885 Mdot
.67047 .76943 Mdot
.46406 .56834 Mdot
.67272 .50796 Mdot
.35627 .79155 Mdot
.71294 .39926 Mdot
.62046 .39793 Mdot
.51347 .29126 Mdot
.69164 .36816 Mdot
.44772 .61399 Mdot
.61136 .62329 Mdot
.43995 .4756 Mdot
.67383 .48553 Mdot
.41435 .30355 Mdot
.47998 .2983 Mdot
.54968 .78196 Mdot
.66072 .66061 Mdot
.53892 .62611 Mdot
.46601 .30783 Mdot
.59114 .60687 Mdot
.42787 .48195 Mdot
.31629 .67172 Mdot
.28648 .3279 Mdot
.50703 .61605 Mdot
.69859 .41487 Mdot
.49541 .6497 Mdot
.302 .65173 Mdot
.50083 .62178 Mdot
.70882 .4944 Mdot
.47343 .57208 Mdot
.43622 .42088 Mdot
.549 .80251 Mdot
.38855 .53662 Mdot
.32563 .54895 Mdot
.52937 .63829 Mdot
.52623 .62556 Mdot
.32108 .57585 Mdot
.68085 .48648 Mdot
.54192 .6682 Mdot
.23372 .33008 Mdot
.55158 .63562 Mdot
.48548 .33183 Mdot
.48536 .41517 Mdot
.78246 .6543 Mdot
.54823 .593 Mdot
.65117 .5303 Mdot
.50256 .32059 Mdot
.50404 .28043 Mdot
.46291 .57336 Mdot
.46583 .28626 Mdot
.49945 .59442 Mdot
.48754 .41506 Mdot
.70973 .48037 Mdot
.59065 .63991 Mdot
.68643 .4855 Mdot
.32295 .75871 Mdot
.47995 .26422 Mdot
.58928 .40301 Mdot
.53071 .77189 Mdot
.48809 .30915 Mdot
.41181 .57184 Mdot
.48796 .56776 Mdot
.45213 .65704 Mdot
.61961 .54664 Mdot
.34879 .40916 Mdot
.59206 .41049 Mdot
.48551 .28679 Mdot
.54992 .63429 Mdot
.52487 .61075 Mdot
.46787 .31618 Mdot
.73211 .57679 Mdot
.22092 .41174 Mdot
.49465 .62237 Mdot
.70613 .48824 Mdot
.66517 .51096 Mdot
.50259 .67305 Mdot
.49901 .65514 Mdot
.33587 .45207 Mdot
.59297 .40124 Mdot
.59243 .4153 Mdot
.59669 .39046 Mdot
.35723 .44602 Mdot
.74261 .73555 Mdot
.51925 .2917 Mdot
.82213 .58117 Mdot
.70015 .31923 Mdot
.44251 .59271 Mdot
.33304 .39326 Mdot
.51252 .63722 Mdot
.5154 .60476 Mdot
.47263 .29587 Mdot
.64437 .79474 Mdot
.55944 .58529 Mdot
.65142 .52227 Mdot
.47821 .32822 Mdot
.5829 .65357 Mdot
.53258 .30338 Mdot
.29951 .57675 Mdot
.4298 .68968 Mdot
.46306 .30226 Mdot
.71381 .49465 Mdot
.46353 .30549 Mdot
.53105 .62616 Mdot
.44757 .6334 Mdot
.67158 .48542 Mdot
.33435 .58706 Mdot
.56025 .64254 Mdot
.50088 .63904 Mdot
.1721 .52709 Mdot
.70649 .40095 Mdot
.27881 .5191 Mdot
.51705 .59648 Mdot
.45952 .65937 Mdot
.3267 .59629 Mdot
.54996 .6579 Mdot
.48268 .60421 Mdot
.54948 .49673 Mdot
.45315 .30612 Mdot
.32834 .54284 Mdot
.53731 .79751 Mdot
.64866 .4998 Mdot
.75275 .33865 Mdot
.61161 .39432 Mdot
.45871 .25798 Mdot
.50582 .38964 Mdot
.59997 .41125 Mdot
.68111 .28109 Mdot
.48046 .21216 Mdot
.59298 .40606 Mdot
.35052 .38858 Mdot
.5621 .71098 Mdot
.48109 .60316 Mdot
.49223 .63777 Mdot
.33342 .56244 Mdot
.65778 .51934 Mdot
.56849 .27043 Mdot
.4599 .32808 Mdot
.51424 .65005 Mdot
.69098 .53962 Mdot
.70594 .2761 Mdot
.60842 .41064 Mdot
.29859 .55089 Mdot
.33879 .57541 Mdot
.49774 .64999 Mdot
.47328 .5331 Mdot
.66997 .50702 Mdot
.52761 .65123 Mdot
.51628 .66768 Mdot
.30245 .41687 Mdot
.70843 .51454 Mdot
.34626 .4264 Mdot
.59475 .42099 Mdot
.57395 .16365 Mdot
.16282 .47723 Mdot
.47567 .27202 Mdot
.42929 .28763 Mdot
.47108 .25797 Mdot
.30622 .30409 Mdot
.5918 .40229 Mdot
.52383 .64989 Mdot
.68526 .47386 Mdot
.53257 .65019 Mdot
.55281 .63308 Mdot
.53762 .62115 Mdot
.4623 .56914 Mdot
.3197 .74559 Mdot
.30337 .56674 Mdot
.48315 .58423 Mdot
.32911 .45777 Mdot
.69517 .26825 Mdot
.79479 .43519 Mdot
.52788 .63354 Mdot
.50399 .65025 Mdot
.65332 .48657 Mdot
.56079 .65267 Mdot
.50892 .31061 Mdot
.6513 .50093 Mdot
.51219 .60885 Mdot
.24101 .59322 Mdot
.53309 .67153 Mdot
.43279 .26318 Mdot
.46203 .30144 Mdot
.47544 .71202 Mdot
.45319 .63665 Mdot
.59067 .40329 Mdot
.59256 .41026 Mdot
.61926 .41283 Mdot
.47912 .32541 Mdot
.30332 .4135 Mdot
.30681 .37447 Mdot
.4572 .61121 Mdot
.50509 .59223 Mdot
.44862 .64217 Mdot
.33424 .46867 Mdot
.42914 .43535 Mdot
.71302 .43948 Mdot
.59218 .5912 Mdot
.35088 .45147 Mdot
.62326 .49613 Mdot
.57716 .79382 Mdot
.65016 .51134 Mdot
.36415 .46569 Mdot
.51082 .29869 Mdot
.29603 .54223 Mdot
.37316 .77411 Mdot
.70148 .47808 Mdot
.64118 .50741 Mdot
.3256 .44409 Mdot
.52883 .43528 Mdot
.45094 .9118 Mdot
.33615 .42233 Mdot
.33065 .4984 Mdot
.6789 .50452 Mdot
.5642 .59197 Mdot
.51803 .46341 Mdot
.54108 .45604 Mdot
.31511 .43895 Mdot
.54783 .64506 Mdot
.41672 .55651 Mdot
.3352 .4521 Mdot
.51361 .57248 Mdot
.31621 .44741 Mdot
.46705 .29957 Mdot
.3353 .4328 Mdot
.72469 .51322 Mdot
.5566 .62984 Mdot
.39055 .88267 Mdot
.54248 .39034 Mdot
.52537 .65719 Mdot
.47284 .3243 Mdot
.35439 .24191 Mdot
.52553 .62198 Mdot
.30911 .53303 Mdot
.346 .45839 Mdot
.28193 .31968 Mdot
.48346 .60676 Mdot
.31688 .43383 Mdot
.73178 .49361 Mdot
.36772 .4574 Mdot
.26539 .52611 Mdot
.59216 .41333 Mdot
.68841 .51167 Mdot
.57978 .39222 Mdot
.51595 .3097 Mdot
.52917 .68041 Mdot
.52584 .66929 Mdot
.7024 .50132 Mdot
.46417 .38375 Mdot
.52738 .56569 Mdot
.54641 .64175 Mdot
.34 .44764 Mdot
.32622 .46267 Mdot
.60086 .43964 Mdot
.3426 .41362 Mdot
.4604 .65944 Mdot
.70434 .50148 Mdot
.4985 .60726 Mdot
.6902 .5196 Mdot
.55562 .6568 Mdot
.64003 .41269 Mdot
.65221 .51579 Mdot
.54472 .52912 Mdot
.55806 .61876 Mdot
.72325 .54679 Mdot
.55605 .64418 Mdot
.51471 .61595 Mdot
.34172 .46307 Mdot
.31102 .56037 Mdot
.54335 .58294 Mdot
.54084 .32647 Mdot
.31625 .59597 Mdot
.79169 .55573 Mdot
.31007 .3929 Mdot
.33203 .58444 Mdot
.35965 .70677 Mdot
.59899 .41965 Mdot
.31224 .57502 Mdot
.60596 .42858 Mdot
.47195 .27623 Mdot
.71967 .50326 Mdot
.55734 .60584 Mdot
.62017 .18754 Mdot
.21952 .41607 Mdot
.60749 .4023 Mdot
.50452 .65947 Mdot
.51219 .63306 Mdot
.66743 .53691 Mdot
.29691 .77289 Mdot
.36475 .41867 Mdot
.50792 .61314 Mdot
.68798 .47693 Mdot
.24929 .72706 Mdot
.32363 .4492 Mdot
.3036 .57292 Mdot
.46224 .27459 Mdot
.73399 .52318 Mdot
.58844 .40908 Mdot
.48048 .26386 Mdot
.33773 .48513 Mdot
.33312 .75292 Mdot
.48317 .60915 Mdot
.34306 .40405 Mdot
.33044 .73964 Mdot
.5953 .59995 Mdot
.51531 .2716 Mdot
.6371 .42153 Mdot
.67118 .48821 Mdot
.47055 .32019 Mdot
.32977 .55182 Mdot
.7185 .48928 Mdot
.68204 .48519 Mdot
.51335 .3005 Mdot
.56925 .22402 Mdot
.52078 .46869 Mdot
.50288 .32869 Mdot
.54742 .47902 Mdot
.32903 .73369 Mdot
.59249 .3973 Mdot
.2987 .54908 Mdot
.23949 .61556 Mdot
.66842 .5085 Mdot
.69314 .36807 Mdot
.33179 .74468 Mdot
.52011 .61554 Mdot
.3272 .56222 Mdot
.71134 .29419 Mdot
.45108 .26978 Mdot
.50103 .27234 Mdot
.38808 .48101 Mdot
.31316 .5386 Mdot
.51449 .6721 Mdot
.76957 .6765 Mdot
.5617 .6121 Mdot
.4827 .26543 Mdot
.43086 .48706 Mdot
.70773 .51432 Mdot
.51606 .31365 Mdot
.40799 .50145 Mdot
.51465 .60332 Mdot
.52058 .66235 Mdot
.34838 .61161 Mdot
.7059 .51965 Mdot
.58602 .40598 Mdot
.54166 .64803 Mdot
.50315 .63162 Mdot
.52113 .68062 Mdot
.50986 .77952 Mdot
.53049 .51968 Mdot
.51224 .61159 Mdot
.3535 .40192 Mdot
.46435 .67058 Mdot
.49008 .65458 Mdot
.67046 .53908 Mdot
.2665 .66499 Mdot
.59468 .42124 Mdot
.49303 .63511 Mdot
.49442 .62326 Mdot
.51562 .29248 Mdot
.51891 .46769 Mdot
.54344 .45745 Mdot
.30483 .44738 Mdot
.36705 .49284 Mdot
.46681 .63085 Mdot
.69398 .50668 Mdot
.30418 .52847 Mdot
.48792 .6777 Mdot
.64822 .51116 Mdot
.47332 .5908 Mdot
.32505 .45693 Mdot
.59558 .40288 Mdot
.58219 .56579 Mdot
.31625 .57084 Mdot
.4617 .31787 Mdot
.82548 .55566 Mdot
.35031 .42762 Mdot
.52 .59023 Mdot
.29485 .37803 Mdot
.32799 .4139 Mdot
.60937 .40033 Mdot
.44885 .66819 Mdot
.68084 .51333 Mdot
.71048 .5058 Mdot
.30894 .71421 Mdot
.36091 .43549 Mdot
.17623 .5906 Mdot
.46619 .29615 Mdot
.50609 .5774 Mdot
.76509 .41736 Mdot
.70722 .51262 Mdot
.29845 .63963 Mdot
.33191 .58597 Mdot
.50025 .27207 Mdot
.57871 .41116 Mdot
.65244 .51907 Mdot
.69875 .52017 Mdot
.55292 .6292 Mdot
.52181 .63959 Mdot
.36619 .47214 Mdot
.2946 .65782 Mdot
.48538 .31908 Mdot
.2996 .56944 Mdot
.29771 .43781 Mdot
.51115 .5997 Mdot
.66005 .49402 Mdot
.77079 .66803 Mdot
.55139 .65118 Mdot
.3259 .45596 Mdot
.66487 .49424 Mdot
.31102 .58121 Mdot
.32919 .578 Mdot
.51862 .61599 Mdot
.76515 .65408 Mdot
.49092 .31076 Mdot
.70174 .50807 Mdot
.67717 .45483 Mdot
.48033 .59081 Mdot
.52671 .63666 Mdot
.58284 .61885 Mdot
.52036 .28523 Mdot
.59035 .57203 Mdot
.3245 .60173 Mdot
.67003 .52072 Mdot
.53219 .65349 Mdot
.31713 .57468 Mdot
.61209 .61501 Mdot
.60003 .40778 Mdot
.32376 .44798 Mdot
.30677 .53282 Mdot
.31948 .55889 Mdot
.31601 .59379 Mdot
.69167 .37048 Mdot
.63489 .50434 Mdot
.50446 .81776 Mdot
.55566 .63446 Mdot
.32847 .73139 Mdot
.56302 .65444 Mdot
.47634 .31598 Mdot
.35348 .42405 Mdot
.54843 .62939 Mdot
.55621 .63363 Mdot
.79637 .61289 Mdot
.44339 .68461 Mdot
.44651 .69597 Mdot
.71488 .49888 Mdot
.64603 .56478 Mdot
.32969 .38924 Mdot
.18469 .65401 Mdot
.82944 .4525 Mdot
.46991 .62736 Mdot
.52467 .43161 Mdot
.65201 .50119 Mdot
.50321 .27134 Mdot
.53668 .47208 Mdot
.48486 .23413 Mdot
.66225 .51792 Mdot
.50659 .60212 Mdot
.8191 .56255 Mdot
.29801 .58287 Mdot
.53814 .6285 Mdot
.50348 .3007 Mdot
.53925 .62839 Mdot
.4804 .32364 Mdot
.74769 .51732 Mdot
.54397 .4403 Mdot
.54655 .59535 Mdot
.47339 .61781 Mdot
.60395 .60484 Mdot
.52555 .63519 Mdot
.32724 .32553 Mdot
.67903 .49354 Mdot
.53065 .53178 Mdot
.4977 .67331 Mdot
.72473 .68699 Mdot
.52998 .67057 Mdot
.48599 .37796 Mdot
.52677 .66652 Mdot
.46287 .75517 Mdot
.50982 .67106 Mdot
.53499 .66382 Mdot
.47745 .29834 Mdot
.51288 .2827 Mdot
.73421 .49086 Mdot
.58552 .40114 Mdot
.69716 .26643 Mdot
.50216 .64474 Mdot
.33226 .46571 Mdot
.61982 .44963 Mdot
.31515 .55752 Mdot
.66703 .51814 Mdot
.12293 .52876 Mdot
.49727 .32291 Mdot
.35657 .39692 Mdot
.26675 .41654 Mdot
.33481 .38433 Mdot
.33142 .47479 Mdot
.7024 .55513 Mdot
.29644 .55382 Mdot
.5215 .672 Mdot
.76988 .61653 Mdot
.70823 .41067 Mdot
.48388 .59003 Mdot
.3102 .36768 Mdot
.53922 .70431 Mdot
.32016 .73447 Mdot
.28897 .56101 Mdot
.30259 .53956 Mdot
.48225 .29057 Mdot
.30353 .39279 Mdot
.58978 .59492 Mdot
.33141 .58485 Mdot
.35269 .42777 Mdot
.60983 .3884 Mdot
.35398 .54309 Mdot
.67161 .51092 Mdot
.51046 .75513 Mdot
.76432 .43626 Mdot
.49395 .32243 Mdot
.53667 .3414 Mdot
.6283 .4985 Mdot
.69823 .46399 Mdot
.58763 .39635 Mdot
.33386 .45732 Mdot
.72163 .4908 Mdot
.55583 .63021 Mdot
.45521 .67599 Mdot
.49823 .65164 Mdot
.33382 .57057 Mdot
.51102 .66566 Mdot
.34301 .45161 Mdot
.49359 .31711 Mdot
.31455 .40586 Mdot
.48705 .31259 Mdot
.80784 .52802 Mdot
.49 .64915 Mdot
.52637 .63927 Mdot
.49633 .41649 Mdot
.68905 .52511 Mdot
.75957 .60927 Mdot
.33144 .45866 Mdot
.30513 .42827 Mdot
.50031 .60754 Mdot
.67948 .46912 Mdot
.32026 .61702 Mdot
.51803 .44821 Mdot
.52311 .66742 Mdot
.68016 .49328 Mdot
.49496 .60917 Mdot
.31515 .28463 Mdot
.55157 .42953 Mdot
.71069 .49572 Mdot
.55153 .80349 Mdot
.55306 .61689 Mdot
.46034 .69659 Mdot
.48639 .70038 Mdot
.41647 .68935 Mdot
.52925 .57314 Mdot
.65316 .4938 Mdot
.48826 .63851 Mdot
.69195 .50308 Mdot
.33244 .41178 Mdot
.51856 .28649 Mdot
.68834 .50415 Mdot
.56138 .61525 Mdot
.82727 .46916 Mdot
.50191 .31691 Mdot
.54055 .63463 Mdot
.48425 .28289 Mdot
.71517 .51561 Mdot
.68468 .5301 Mdot
.59684 .43082 Mdot
.30035 .47198 Mdot
.50485 .31287 Mdot
.50344 .59188 Mdot
.70388 .38337 Mdot
.49811 .60691 Mdot
.3625 .49496 Mdot
.48685 .66438 Mdot
.47712 .60211 Mdot
.78838 .68927 Mdot
.47742 .38547 Mdot
.15265 .57046 Mdot
.47762 .34915 Mdot
.70511 .37379 Mdot
.72983 .46985 Mdot
.28892 .55951 Mdot
.42766 .31259 Mdot
.61153 .41648 Mdot
.34908 .39668 Mdot
.55021 .63125 Mdot
.77863 .48583 Mdot
.49354 .33154 Mdot
.30755 .55836 Mdot
.54816 .59697 Mdot
.29818 .39237 Mdot
.56503 .37482 Mdot
.49165 .26619 Mdot
.67044 .51264 Mdot
.67907 .52844 Mdot
.39508 .81312 Mdot
.52696 .65542 Mdot
.52091 .64415 Mdot
.51192 .31124 Mdot
.57869 .58001 Mdot
.30989 .59015 Mdot
.37913 .25536 Mdot
.50373 .29689 Mdot
.55014 .41994 Mdot
.71651 .4963 Mdot
.51254 .63467 Mdot
.48365 .41577 Mdot
.65265 .33245 Mdot
.63098 .63615 Mdot
.32191 .54939 Mdot
.37299 .6088 Mdot
.653 .49382 Mdot
.50098 .29684 Mdot
.36174 .72683 Mdot
.57144 .63575 Mdot
.51014 .63201 Mdot
.36617 .61886 Mdot
.5219 .45238 Mdot
.35456 .51232 Mdot
.57917 .63514 Mdot
.50001 .4704 Mdot
.50185 .60714 Mdot
.52463 .61048 Mdot
.47336 .60285 Mdot
.48257 .64102 Mdot
.68512 .4942 Mdot
.66207 .75613 Mdot
.32447 .4309 Mdot
.60557 .70117 Mdot
.38633 .47154 Mdot
.51176 .5817 Mdot
.50995 .60287 Mdot
.64042 .7356 Mdot
.59675 .49525 Mdot
.67559 .49789 Mdot
.67323 .45634 Mdot
.51929 .29497 Mdot
.44205 .68349 Mdot
.3583 .44611 Mdot
.49374 .71206 Mdot
.31882 .41475 Mdot
.68163 .49226 Mdot
.30627 .40315 Mdot
.49675 .34182 Mdot
.34283 .40398 Mdot
.35948 .43288 Mdot
.47436 .26364 Mdot
.6942 .52986 Mdot
.54018 .66192 Mdot
.47112 .26805 Mdot
.33702 .61879 Mdot
.33363 .57118 Mdot
.60414 .43269 Mdot
.56451 .59178 Mdot
.4483 .69123 Mdot
.29682 .27844 Mdot
.31625 .39539 Mdot
.56605 .4785 Mdot
.65279 .51672 Mdot
.31531 .53393 Mdot
.68849 .49621 Mdot
.43623 .79982 Mdot
.32151 .56716 Mdot
.60579 .43237 Mdot
.35149 .71923 Mdot
.53444 .27641 Mdot
.52833 .68834 Mdot
.61931 .55057 Mdot
.31947 .41191 Mdot
.48385 .33149 Mdot
.70433 .28469 Mdot
.54703 .61562 Mdot
.60532 .38111 Mdot
.68409 .46138 Mdot
.59749 .41885 Mdot
.50124 .30135 Mdot
.45517 .34204 Mdot
.52075 .65711 Mdot
.53766 .30809 Mdot
.47573 .6275 Mdot
.53496 .76996 Mdot
.36627 .48655 Mdot
.61394 .51886 Mdot
.49331 .60492 Mdot
.32866 .45331 Mdot
.49483 .60581 Mdot
.54889 .73575 Mdot
.34159 .735 Mdot
.47188 .63872 Mdot
.60796 .53981 Mdot
.28531 .30625 Mdot
.66507 .49055 Mdot
.45966 .65448 Mdot
.59956 .39741 Mdot
.52783 .60009 Mdot
.67501 .1913 Mdot
.31218 .57244 Mdot
.28929 .51681 Mdot
.56113 .61807 Mdot
.53836 .64827 Mdot
.77764 .63618 Mdot
.64512 .55781 Mdot
.57891 .41317 Mdot
.51084 .62677 Mdot
.37916 .62013 Mdot
.47793 .29249 Mdot
.4807 .64314 Mdot
.49084 .64113 Mdot
.17759 .50025 Mdot
.47715 .28947 Mdot
.32187 .39194 Mdot
.6013 .41983 Mdot
.30841 .44868 Mdot
.30475 .52048 Mdot
.5132 .49301 Mdot
.30519 .64258 Mdot
.55507 .43121 Mdot
.31728 .53878 Mdot
.50844 .58054 Mdot
.6659 .452 Mdot
.53494 .65707 Mdot
.30525 .54073 Mdot
.49769 .28564 Mdot
.68352 .49683 Mdot
.52182 .75811 Mdot
.61197 .39926 Mdot
.49242 .58051 Mdot
.28902 .5686 Mdot
.68513 .50825 Mdot
.58884 .31654 Mdot
.6553 .51486 Mdot
.48398 .30708 Mdot
.52024 .31119 Mdot
.31704 .56341 Mdot
.68747 .49446 Mdot
.30407 .44015 Mdot
.47711 .35057 Mdot
.48235 .65919 Mdot
.50453 .34174 Mdot
.72062 .4783 Mdot
.64815 .5228 Mdot
.68989 .47123 Mdot
.48464 .63902 Mdot
.52462 .44672 Mdot
.56712 .65292 Mdot
.50618 .31531 Mdot
.32412 .38364 Mdot
.30148 .67198 Mdot
.76499 .63472 Mdot
.54701 .41625 Mdot
.54007 .58033 Mdot
.50823 .66334 Mdot
.49825 .65028 Mdot
.49025 .61753 Mdot
.38266 .25536 Mdot
.4899 .64849 Mdot
.47606 .3054 Mdot
.32533 .41956 Mdot
.5107 .66058 Mdot
.59662 .39876 Mdot
.42957 .44118 Mdot
.30513 .5279 Mdot
.46225 .73717 Mdot
.78375 .41174 Mdot
.68455 .50659 Mdot
.3408 .40608 Mdot
.30277 .40815 Mdot
.32712 .58498 Mdot
.47599 .26641 Mdot
.6597 .52001 Mdot
.43604 .73114 Mdot
.31079 .59597 Mdot
.49338 .63426 Mdot
.49059 .41545 Mdot
.56426 .79783 Mdot
.53518 .58408 Mdot
.52683 .61915 Mdot
.58573 .41007 Mdot
.3563 .39815 Mdot
.69884 .23147 Mdot
.57028 .23707 Mdot
.31248 .56143 Mdot
.30517 .58051 Mdot
.67213 .47568 Mdot
.5026 .57732 Mdot
.49406 .31159 Mdot
.50888 .46987 Mdot
.30988 .26074 Mdot
.73938 .31451 Mdot
.30552 .30684 Mdot
.53534 .67066 Mdot
.67908 .73095 Mdot
.49722 .67713 Mdot
.63563 .50477 Mdot
.68197 .47051 Mdot
.67348 .50327 Mdot
.47891 .29871 Mdot
.33641 .75934 Mdot
.47522 .30566 Mdot
.78773 .41382 Mdot
.67494 .4814 Mdot
.45183 .39819 Mdot
.30797 .43726 Mdot
.4391 .64603 Mdot
.29695 .55103 Mdot
.27748 .59743 Mdot
.45642 .65189 Mdot
.46811 .53771 Mdot
.33279 .3932 Mdot
.6761 .53323 Mdot
.48939 .56792 Mdot
.68634 .25529 Mdot
.53027 .43341 Mdot
.23848 .33608 Mdot
.63917 .57092 Mdot
.32135 .57461 Mdot
.61821 .70723 Mdot
.30617 .58994 Mdot
.4967 .26966 Mdot
.55075 .6183 Mdot
.56398 .62715 Mdot
.50497 .61541 Mdot
.48381 .63307 Mdot
.48619 .28594 Mdot
.48859 .67167 Mdot
.26848 .65695 Mdot
.61488 .39479 Mdot
.43318 .39308 Mdot
.3244 .58057 Mdot
.4685 .30809 Mdot
.32754 .41623 Mdot
.58602 .39672 Mdot
.34107 .60832 Mdot
.51119 .678 Mdot
.55518 .63939 Mdot
.61116 .39072 Mdot
.55644 .56335 Mdot
.4464 .61658 Mdot
.32017 .4317 Mdot
.43368 .46622 Mdot
.33597 .55957 Mdot
.29452 .54804 Mdot
.46587 .30984 Mdot
.68864 .49597 Mdot
.33578 .57603 Mdot
.30218 .39298 Mdot
.47833 .62846 Mdot
.4734 .61506 Mdot
.72133 .47888 Mdot
.33115 .74471 Mdot
.29973 .52809 Mdot
.59502 .59188 Mdot
.67949 .52308 Mdot
.67418 .46185 Mdot
.51271 .62613 Mdot
.5642 .67907 Mdot
.63925 .51244 Mdot
.31555 .58616 Mdot
.46473 .30069 Mdot
.47369 .39796 Mdot
.47499 .30988 Mdot
.6822 .51897 Mdot
.46097 .67261 Mdot
.70939 .5166 Mdot
.54838 .61265 Mdot
.17479 .68251 Mdot
.49781 .66101 Mdot
.45051 .56697 Mdot
.37721 .5519 Mdot
.31808 .44876 Mdot
.32208 .45087 Mdot
.59571 .40153 Mdot
.64868 .50774 Mdot
.48942 .67957 Mdot
.29591 .56239 Mdot
.70536 .37526 Mdot
.62623 .53156 Mdot
.35696 .443 Mdot
.36111 .41091 Mdot
.49597 .28544 Mdot
.52397 .67087 Mdot
.51084 .63925 Mdot
.33982 .39974 Mdot
.36282 .24317 Mdot
.69528 .49761 Mdot
.52122 .64422 Mdot
.48589 .64877 Mdot
.32532 .42791 Mdot
.45657 .33915 Mdot
.66198 .4636 Mdot
.48493 .64761 Mdot
.3356 .7108 Mdot
.48522 .32514 Mdot
.50886 .58655 Mdot
.49631 .67581 Mdot
.31663 .55397 Mdot
.30983 .62531 Mdot
.33024 .73483 Mdot
.49722 .26378 Mdot
.58985 .41203 Mdot
.5632 .63389 Mdot
.31334 .4426 Mdot
.55449 .58298 Mdot
.47999 .20033 Mdot
.61718 .40037 Mdot
.51744 .6544 Mdot
.46553 .62936 Mdot
.69434 .51749 Mdot
.52474 .65181 Mdot
.63788 .41462 Mdot
.34077 .44288 Mdot
.51696 .65512 Mdot
.76158 .65718 Mdot
.4982 .28734 Mdot
.45533 .65172 Mdot
.30066 .53509 Mdot
.37259 .51372 Mdot
.80872 .493 Mdot
.32673 .46809 Mdot
.32893 .57529 Mdot
.51257 .66625 Mdot
.3087 .45155 Mdot
.46263 .2732 Mdot
.51403 .52877 Mdot
.5018 .58149 Mdot
.4775 .31323 Mdot
.49746 .31663 Mdot
.31411 .56543 Mdot
.14286 .57998 Mdot
.46636 .6278 Mdot
.53446 .6318 Mdot
.28033 .27428 Mdot
.64451 .53302 Mdot
.54206 .63232 Mdot
.52658 .66992 Mdot
.46852 .2784 Mdot
.4173 .77446 Mdot
.39607 .59085 Mdot
.37755 .24537 Mdot
.48103 .32296 Mdot
.35797 .39377 Mdot
.34663 .43617 Mdot
.3275 .57562 Mdot
.66212 .49594 Mdot
.33143 .55096 Mdot
.33189 .43583 Mdot
.51303 .61607 Mdot
.49218 .27318 Mdot
.68374 .59007 Mdot
.47172 .32416 Mdot
.29305 .40312 Mdot
.64427 .48294 Mdot
.79041 .44524 Mdot
.39284 .17993 Mdot
.76297 .44285 Mdot
.50854 .26965 Mdot
.31514 .55725 Mdot
.56633 .25168 Mdot
.51387 .66372 Mdot
.56769 .77192 Mdot
.53723 .62984 Mdot
.61678 .60319 Mdot
.35336 .4257 Mdot
.59319 .38997 Mdot
.54664 .61575 Mdot
.37496 .60762 Mdot
.48212 .26298 Mdot
.5087 .30592 Mdot
.48973 .62693 Mdot
.48563 .30877 Mdot
.51264 .64345 Mdot
.32817 .42279 Mdot
.14811 .58376 Mdot
.53105 .66379 Mdot
.46856 .66947 Mdot
.45051 .28949 Mdot
.60631 .43312 Mdot
.32076 .37114 Mdot
.68863 .73039 Mdot
.68577 .24919 Mdot
.49016 .30817 Mdot
.43239 .59479 Mdot
.32524 .39621 Mdot
.58337 .40362 Mdot
.36144 .45164 Mdot
.52544 .62838 Mdot
.5426 .66688 Mdot
.50215 .61121 Mdot
.50951 .66292 Mdot
.59194 .75261 Mdot
.44301 .62778 Mdot
.67736 .66137 Mdot
.55462 .6362 Mdot
.45255 .56716 Mdot
.47252 .29851 Mdot
.46688 .70054 Mdot
.35286 .51603 Mdot
.53465 .67246 Mdot
.62643 .55487 Mdot
.46742 .30428 Mdot
.75261 .38441 Mdot
.48164 .28697 Mdot
.31078 .40833 Mdot
.51054 .2833 Mdot
.55194 .61431 Mdot
.66516 .50907 Mdot
.34195 .42502 Mdot
.71342 .43891 Mdot
.34372 .39408 Mdot
.52514 .65716 Mdot
.48677 .22754 Mdot
.30994 .4447 Mdot
.46139 .71248 Mdot
.6631 .50842 Mdot
.37538 .64503 Mdot
.63633 .52492 Mdot
.53008 .64767 Mdot
.53672 .64269 Mdot
.58778 .39187 Mdot
.49116 .26565 Mdot
.71181 .47985 Mdot
.17794 .5386 Mdot
.2868 .55927 Mdot
.67096 .4952 Mdot
.48201 .69672 Mdot
.5218 .42839 Mdot
.70527 .50756 Mdot
.39152 .64798 Mdot
.48324 .26514 Mdot
.66742 .48146 Mdot
.54713 .68272 Mdot
.59131 .70956 Mdot
.29328 .56917 Mdot
.31583 .45601 Mdot
.49972 .45282 Mdot
.34524 .43865 Mdot
.47709 .33398 Mdot
.36206 .4365 Mdot
.47458 .29448 Mdot
.6248 .45596 Mdot
.42256 .49344 Mdot
.49065 .33754 Mdot
.46404 .3304 Mdot
.32487 .43904 Mdot
.49122 .62027 Mdot
.43525 .42446 Mdot
.54422 .69214 Mdot
.45041 .65864 Mdot
.48472 .32193 Mdot
.65616 .48958 Mdot
.7173 .50031 Mdot
.54 .5341 Mdot
.69222 .52541 Mdot
.33846 .41865 Mdot
.56354 .44028 Mdot
.53761 .77439 Mdot
.49988 .28535 Mdot
.27722 .43344 Mdot
.49962 .60403 Mdot
.322 .44412 Mdot
.33663 .4124 Mdot
.48854 .31507 Mdot
.61477 .68754 Mdot
.45055 .64786 Mdot
.66369 .53838 Mdot
.68594 .47769 Mdot
.70713 .50365 Mdot
.67684 .47059 Mdot
.35114 .77477 Mdot
.48349 .33138 Mdot
.65118 .49823 Mdot
.48426 .62073 Mdot
.55333 .65066 Mdot
.60209 .4166 Mdot
.31513 .58463 Mdot
.55484 .66654 Mdot
.50525 .68805 Mdot
.51306 .62714 Mdot
.31648 .44781 Mdot
.59148 .66578 Mdot
.61625 .40129 Mdot
.36216 .42591 Mdot
.35788 .44597 Mdot
.59004 .40473 Mdot
.62793 .46088 Mdot
.73421 .27641 Mdot
.50681 .61339 Mdot
.76578 .50432 Mdot
.31476 .44151 Mdot
.48267 .51656 Mdot
.51605 .55154 Mdot
.49989 .59355 Mdot
.42488 .39882 Mdot
.3327 .42094 Mdot
.73781 .48267 Mdot
.52655 .63176 Mdot
.59131 .39508 Mdot
.29322 .54912 Mdot
.52899 .69629 Mdot
.58506 .40919 Mdot
.68431 .4903 Mdot
.25082 .37329 Mdot
.68356 .53978 Mdot
.30827 .44429 Mdot
.45859 .65414 Mdot
.42802 .90291 Mdot
.31988 .4104 Mdot
.69487 .35914 Mdot
.41587 .49722 Mdot
.52659 .66333 Mdot
.34552 .42399 Mdot
.71593 .46867 Mdot
.48581 .32508 Mdot
.49911 .42494 Mdot
.66008 .49431 Mdot
.5868 .39583 Mdot
.59584 .41373 Mdot
.32408 .42994 Mdot
.70057 .47973 Mdot
.48654 .66686 Mdot
.67244 .52652 Mdot
.50412 .28287 Mdot
.54006 .59833 Mdot
.69696 .26581 Mdot
.44984 .67251 Mdot
.67163 .52481 Mdot
.3056 .3872 Mdot
.33161 .5917 Mdot
.54023 .59027 Mdot
.74731 .35127 Mdot
.52175 .67021 Mdot
.48841 .28241 Mdot
.44569 .51602 Mdot
.67924 .59621 Mdot
.49905 .62222 Mdot
.50493 .60364 Mdot
.46077 .29358 Mdot
.50243 .62054 Mdot
.48399 .59707 Mdot
.48955 .36581 Mdot
.70163 .51236 Mdot
.50746 .65375 Mdot
.34955 .43668 Mdot
.7568 .55824 Mdot
.55008 .62066 Mdot
.63858 .39874 Mdot
.37353 .62865 Mdot
.43413 .50492 Mdot
.48445 .6767 Mdot
.29693 .63645 Mdot
.53591 .63985 Mdot
.49329 .59233 Mdot
.49795 .61504 Mdot
.67079 .73626 Mdot
.32898 .43874 Mdot
.35093 .44853 Mdot
.29358 .54404 Mdot
.37701 .61657 Mdot
.32609 .55893 Mdot
.46193 .28948 Mdot
.27264 .42621 Mdot
.61215 .39326 Mdot
.69002 .49796 Mdot
.54815 .62189 Mdot
.34827 .39982 Mdot
.51523 .63276 Mdot
.52594 .59837 Mdot
.33676 .42628 Mdot
.33459 .41422 Mdot
.33436 .46979 Mdot
.30341 .59061 Mdot
.67943 .50118 Mdot
.52976 .6173 Mdot
.3165 .59627 Mdot
.49692 .6706 Mdot
.52277 .40286 Mdot
.67727 .50044 Mdot
.67497 .52644 Mdot
.71231 .51648 Mdot
.55714 .63907 Mdot
.55035 .60856 Mdot
.47533 .30628 Mdot
.72189 .48061 Mdot
.51093 .30756 Mdot
.34575 .42623 Mdot
.32784 .44874 Mdot
.52602 .62806 Mdot
.59042 .58511 Mdot
.31786 .58199 Mdot
.31149 .40215 Mdot
.61614 .41459 Mdot
.29592 .53813 Mdot
.50182 .65867 Mdot
.34583 .43321 Mdot
.30416 .52971 Mdot
.63322 .59554 Mdot
.65529 .22191 Mdot
.30822 .59655 Mdot
.4894 .62756 Mdot
.77704 .62801 Mdot
.33576 .72025 Mdot
.28966 .5757 Mdot
.47855 .28324 Mdot
.53996 .66397 Mdot
.39033 .20983 Mdot
.33875 .56785 Mdot
.33342 .74354 Mdot
.33757 .43134 Mdot
.60027 .56582 Mdot
.52181 .69781 Mdot
.55074 .77784 Mdot
.33975 .57361 Mdot
.66919 .52205 Mdot
.68945 .4742 Mdot
.49391 .63036 Mdot
.33424 .50097 Mdot
.47966 .33347 Mdot
.30274 .40784 Mdot
.35839 .42761 Mdot
.71044 .48573 Mdot
.5538 .42665 Mdot
.34883 .43581 Mdot
.48374 .58332 Mdot
.28507 .52924 Mdot
.44135 .68191 Mdot
.39336 .80841 Mdot
.79508 .50335 Mdot
.47732 .6696 Mdot
.32813 .59559 Mdot
.47358 .26299 Mdot
.48138 .30972 Mdot
.48091 .30098 Mdot
.33071 .44915 Mdot
.52895 .46563 Mdot
.35608 .42523 Mdot
.61964 .36191 Mdot
.31618 .57586 Mdot
.38493 .68181 Mdot
.52463 .68476 Mdot
.52683 .66266 Mdot
.47855 .61227 Mdot
.50382 .61049 Mdot
.5339 .64019 Mdot
.49266 .32206 Mdot
.29964 .42942 Mdot
.30697 .28018 Mdot
.70569 .48934 Mdot
.58367 .31219 Mdot
.30696 .43561 Mdot
.58972 .41767 Mdot
.30292 .56032 Mdot
.31942 .63899 Mdot
.27287 .54316 Mdot
.30497 .40828 Mdot
.52085 .57859 Mdot
.65836 .48351 Mdot
.50388 .78008 Mdot
.54654 .64178 Mdot
.31278 .39925 Mdot
.36361 .40511 Mdot
.62361 .68342 Mdot
.57539 .60059 Mdot
.33055 .49712 Mdot
.52327 .43299 Mdot
.32587 .60458 Mdot
.55219 .58707 Mdot
.49709 .51208 Mdot
.33009 .43493 Mdot
.31114 .41866 Mdot
.2966 .58784 Mdot
.55333 .70587 Mdot
.67511 .48378 Mdot
.59752 .38837 Mdot
.47436 .28401 Mdot
.54303 .65275 Mdot
.3337 .44812 Mdot
.74013 .47144 Mdot
.49281 .40616 Mdot
.49098 .28968 Mdot
.36253 .41969 Mdot
.5328 .66961 Mdot
.49672 .62688 Mdot
.32266 .57021 Mdot
.19982 .46198 Mdot
.54233 .69249 Mdot
.70421 .37361 Mdot
.55093 .46086 Mdot
.39442 .50755 Mdot
.50996 .63253 Mdot
.70995 .51215 Mdot
.59146 .40232 Mdot
.29986 .54803 Mdot
.50564 .67297 Mdot
.71065 .25459 Mdot
.69961 .53724 Mdot
.50304 .31314 Mdot
.5899 .39986 Mdot
.51983 .47331 Mdot
.52011 .66963 Mdot
.53661 .62983 Mdot
.48463 .63784 Mdot
.71107 .25126 Mdot
.35364 .43668 Mdot
.70331 .47096 Mdot
.32593 .55288 Mdot
.67233 .52813 Mdot
.34718 .45879 Mdot
.38996 .50588 Mdot
.49034 .65244 Mdot
.68035 .53756 Mdot
.66196 .51967 Mdot
.49924 .28747 Mdot
.46993 .26895 Mdot
.31055 .45752 Mdot
.51305 .66511 Mdot
.6059 .39014 Mdot
.66057 .48787 Mdot
.30021 .40835 Mdot
.32192 .56998 Mdot
.52429 .31963 Mdot
.55505 .6362 Mdot
.32536 .43295 Mdot
.47177 .65916 Mdot
.69725 .50956 Mdot
.30387 .41633 Mdot
.58387 .41416 Mdot
.31226 .58388 Mdot
.55226 .65691 Mdot
.27793 .3146 Mdot
.58888 .39689 Mdot
.56171 .61311 Mdot
.78586 .5109 Mdot
.34567 .50814 Mdot
.73927 .45089 Mdot
.3502 .41614 Mdot
.60526 .39293 Mdot
.69212 .46922 Mdot
.58675 .71939 Mdot
.31405 .41973 Mdot
.80009 .58589 Mdot
.45127 .40594 Mdot
.51475 .61407 Mdot
.67371 .48865 Mdot
.30725 .60424 Mdot
.71176 .36964 Mdot
.32102 .69581 Mdot
.51545 .64793 Mdot
.34506 .43962 Mdot
.29485 .54594 Mdot
.51012 .30408 Mdot
.63205 .38977 Mdot
.43413 .81849 Mdot
.36136 .42212 Mdot
.54345 .62096 Mdot
.66009 .48644 Mdot
.49496 .31411 Mdot
.81804 .56731 Mdot
.29971 .39575 Mdot
.34956 .42097 Mdot
.48406 .60565 Mdot
.32321 .54978 Mdot
.39634 .21046 Mdot
.35128 .4456 Mdot
.30618 .44676 Mdot
.55577 .36909 Mdot
.2899 .557 Mdot
.48543 .62745 Mdot
.5388 .53402 Mdot
.48205 .64625 Mdot
.6364 .34616 Mdot
.60505 .39202 Mdot
.70455 .49008 Mdot
.54686 .63085 Mdot
.28698 .30377 Mdot
.32003 .4164 Mdot
.52621 .43612 Mdot
.44168 .28202 Mdot
.4718 .26786 Mdot
.33922 .44297 Mdot
.5203 .63482 Mdot
.51889 .31764 Mdot
.32163 .5793 Mdot
.48512 .64807 Mdot
.54912 .61066 Mdot
.71012 .4657 Mdot
.49526 .27526 Mdot
.76304 .55134 Mdot
.51005 .28898 Mdot
.46525 .30992 Mdot
.67422 .46161 Mdot
.49377 .63196 Mdot
.30801 .40795 Mdot
.29221 .40042 Mdot
.48071 .66558 Mdot
.48227 .51587 Mdot
.67416 .48523 Mdot
.32736 .47989 Mdot
.6841 .22493 Mdot
.46954 .62364 Mdot
.60648 .42019 Mdot
.61477 .56736 Mdot
.49456 .32854 Mdot
.51306 .61755 Mdot
.69335 .50368 Mdot
.29666 .42996 Mdot
.34428 .4457 Mdot
.5732 .62585 Mdot
.48834 .316 Mdot
.31145 .53263 Mdot
.33617 .40909 Mdot
.49702 .39843 Mdot
.5201 .65515 Mdot
.5963 .37839 Mdot
.33449 .40569 Mdot
.82339 .49086 Mdot
.29329 .29449 Mdot
.71037 .49075 Mdot
.5144 .5951 Mdot
.64423 .49921 Mdot
.32884 .55656 Mdot
.36327 .4435 Mdot
.48074 .31374 Mdot
.51173 .75269 Mdot
.17156 .48449 Mdot
.32588 .44408 Mdot
.68376 .49394 Mdot
.53964 .62112 Mdot
.50884 .55728 Mdot
.52581 .66689 Mdot
.4187 .76992 Mdot
.28863 .53334 Mdot
.48451 .34189 Mdot
.50927 .3135 Mdot
.51394 .60321 Mdot
.31176 .59215 Mdot
.29196 .43491 Mdot
.33609 .42789 Mdot
.16524 .63246 Mdot
.58446 .4097 Mdot
.3649 .46589 Mdot
.55677 .63919 Mdot
.30354 .39964 Mdot
.7625 .63647 Mdot
.51199 .30975 Mdot
.48062 .64775 Mdot
.34599 .39006 Mdot
.6344 .32569 Mdot
.51976 .42868 Mdot
.51723 .65265 Mdot
.58264 .58422 Mdot
.48008 .28526 Mdot
.56673 .25101 Mdot
.34949 .41131 Mdot
.49262 .66495 Mdot
.49593 .25258 Mdot
.60952 .44793 Mdot
.18152 .53462 Mdot
.67905 .50146 Mdot
.32093 .37862 Mdot
.46542 .29308 Mdot
.59734 .63511 Mdot
.32093 .58368 Mdot
.29307 .4272 Mdot
.34104 .389 Mdot
.53159 .59482 Mdot
.55648 .66341 Mdot
.5829 .5942 Mdot
.6803 .48734 Mdot
.47034 .27666 Mdot
.52782 .60687 Mdot
.53586 .40703 Mdot
.51135 .61083 Mdot
.46741 .28513 Mdot
.30731 .83204 Mdot
.56567 .61145 Mdot
.55014 .64324 Mdot
.43325 .7007 Mdot
.71508 .48589 Mdot
.6948 .51965 Mdot
.54556 .43294 Mdot
.55711 .64135 Mdot
.45968 .38923 Mdot
.68218 .50106 Mdot
.66826 .49111 Mdot
.45733 .39095 Mdot
.53826 .59457 Mdot
.48043 .24218 Mdot
.49212 .31369 Mdot
.47074 .26872 Mdot
.69275 .51848 Mdot
.43777 .64685 Mdot
.46516 .2696 Mdot
.60188 .74693 Mdot
.30293 .41806 Mdot
.49776 .51197 Mdot
.67054 .52606 Mdot
.47622 .41782 Mdot
.48999 .26613 Mdot
.84751 .53115 Mdot
.49552 .77179 Mdot
.47599 .64304 Mdot
.4958 .62502 Mdot
.31973 .55658 Mdot
.46724 .57138 Mdot
.59128 .41384 Mdot
.48281 .30755 Mdot
.3853 .26085 Mdot
.67281 .50346 Mdot
.54531 .6562 Mdot
.29757 .6646 Mdot
.80196 .50539 Mdot
.52791 .52971 Mdot
.6607 .49661 Mdot
.66789 .50449 Mdot
.33441 .39306 Mdot
.30225 .4155 Mdot
.48892 .64379 Mdot
.47712 .30059 Mdot
.67934 .47747 Mdot
.48061 .27245 Mdot
.33159 .43476 Mdot
.30439 .41979 Mdot
.61648 .40896 Mdot
.45155 .61907 Mdot
.33668 .44073 Mdot
.55904 .36415 Mdot
.53449 .40563 Mdot
.71196 .46827 Mdot
.37488 .19735 Mdot
.82019 .58541 Mdot
.44343 .70811 Mdot
.29292 .55048 Mdot
.62095 .45441 Mdot
.50665 .27319 Mdot
.51184 .6038 Mdot
.52968 .62427 Mdot
.60771 .41111 Mdot
.49924 .26636 Mdot
.30762 .55327 Mdot
.49494 .26726 Mdot
.29793 .55743 Mdot
.34432 .4543 Mdot
.55336 .62291 Mdot
.5054 .66597 Mdot
.50597 .30824 Mdot
.32494 .39242 Mdot
.31084 .44595 Mdot
.29746 .57669 Mdot
.33514 .63282 Mdot
.32561 .42999 Mdot
.67027 .52615 Mdot
.74787 .57848 Mdot
.59789 .41425 Mdot
.52669 .63237 Mdot
.30231 .64889 Mdot
.60828 .72236 Mdot
.51901 .61353 Mdot
.58952 .39879 Mdot
.14287 .60083 Mdot
.55223 .62021 Mdot
.25712 .73683 Mdot
.6148 .39996 Mdot
.71069 .51463 Mdot
.32951 .39832 Mdot
.58503 .40448 Mdot
.5933 .66111 Mdot
.35707 .48748 Mdot
.4651 .65205 Mdot
.66988 .48493 Mdot
.68733 .53421 Mdot
.42658 .48298 Mdot
.63373 .34454 Mdot
.32377 .5484 Mdot
.30726 .56475 Mdot
.3157 .42222 Mdot
.51401 .36082 Mdot
.51495 .56788 Mdot
.30833 .56129 Mdot
.41679 .22898 Mdot
.49833 .60367 Mdot
.36532 .51394 Mdot
.43569 .40763 Mdot
.71251 .50274 Mdot
.47031 .70294 Mdot
.31721 .41845 Mdot
.68312 .49437 Mdot
.4342 .44574 Mdot
.47854 .63133 Mdot
.67539 .50129 Mdot
.47291 .27208 Mdot
.44769 .35967 Mdot
.68443 .52879 Mdot
.49803 .42108 Mdot
.49514 .31003 Mdot
.34801 .50906 Mdot
.37476 .70725 Mdot
.75035 .24513 Mdot
.4801 .30593 Mdot
.32021 .39521 Mdot
.33076 .44637 Mdot
.32601 .42568 Mdot
.66225 .49138 Mdot
.33042 .41153 Mdot
.69602 .48542 Mdot
.45242 .30976 Mdot
.3177 .6324 Mdot
.31874 .56577 Mdot
.3079 .49665 Mdot
.6724 .51823 Mdot
.63198 .3623 Mdot
.30281 .24039 Mdot
.48684 .62304 Mdot
.48752 .33631 Mdot
.32123 .59918 Mdot
.57384 .47356 Mdot
.31749 .55383 Mdot
.32719 .3964 Mdot
.50029 .51143 Mdot
.51175 .64431 Mdot
.77717 .48501 Mdot
.29772 .54115 Mdot
.66036 .49542 Mdot
.51001 .58133 Mdot
.28612 .41369 Mdot
.32992 .57036 Mdot
.29274 .55862 Mdot
.53305 .63871 Mdot
.68249 .53301 Mdot
.30636 .40863 Mdot
.51338 .28156 Mdot
.29141 .58492 Mdot
.57587 .57407 Mdot
.49412 .62051 Mdot
.54776 .58966 Mdot
.53531 .44512 Mdot
.40016 .20161 Mdot
.49181 .30677 Mdot
.32868 .72178 Mdot
.32465 .44705 Mdot
.32438 .7015 Mdot
.71568 .39869 Mdot
.27081 .53702 Mdot
.60818 .39271 Mdot
.60395 .39155 Mdot
.52262 .64862 Mdot
.43315 .18779 Mdot
.46091 .55644 Mdot
.47267 .25143 Mdot
.59875 .41182 Mdot
.30937 .44483 Mdot
.72824 .50304 Mdot
.50244 .71422 Mdot
.53807 .68222 Mdot
.49662 .26402 Mdot
.33143 .42965 Mdot
.48049 .19961 Mdot
.31584 .57459 Mdot
.56551 .46959 Mdot
.50828 .66079 Mdot
.52342 .6417 Mdot
.49668 .29725 Mdot
.47734 .30802 Mdot
.59239 .37053 Mdot
.45445 .48428 Mdot
.70885 .28121 Mdot
.45597 .30143 Mdot
.47816 .1979 Mdot
.74841 .53042 Mdot
.68853 .51728 Mdot
.60212 .42036 Mdot
.46095 .28223 Mdot
.54399 .63202 Mdot
.71285 .50993 Mdot
.49444 .53847 Mdot
.73907 .48045 Mdot
.36656 .51439 Mdot
.47731 .39782 Mdot
.50672 .66154 Mdot
.66161 .47923 Mdot
.6807 .49568 Mdot
.65206 .48518 Mdot
.59148 .40596 Mdot
.5095 .62963 Mdot
.49016 .6193 Mdot
.55154 .6186 Mdot
.50361 .55948 Mdot
.52477 .65229 Mdot
.71649 .39493 Mdot
.54271 .40044 Mdot
.21978 .50763 Mdot
.55559 .632 Mdot
.46557 .28553 Mdot
.55313 .6261 Mdot
.31561 .59136 Mdot
.55966 .64419 Mdot
.36362 .51491 Mdot
.48511 .29916 Mdot
.56475 .70794 Mdot
.29062 .45057 Mdot
.49722 .65768 Mdot
.31558 .53727 Mdot
.40563 .19696 Mdot
.30232 .68018 Mdot
.55624 .36871 Mdot
.67173 .52617 Mdot
.3215 .46241 Mdot
.49784 .3342 Mdot
.30762 .41183 Mdot
.48065 .65356 Mdot
.61804 .40972 Mdot
.75615 .72324 Mdot
.46742 .42918 Mdot
.54573 .63217 Mdot
.45436 .6118 Mdot
.70857 .51142 Mdot
.32157 .41413 Mdot
.75372 .50692 Mdot
.4839 .60833 Mdot
.33526 .57204 Mdot
.32944 .59006 Mdot
.40379 .48584 Mdot
.42291 .29218 Mdot
.51759 .77246 Mdot
.49517 .29857 Mdot
.33781 .45093 Mdot
.33972 .5705 Mdot
.61838 .54893 Mdot
.47838 .33201 Mdot
.49573 .3283 Mdot
.49359 .2748 Mdot
.52741 .65893 Mdot
.61162 .41411 Mdot
.41499 .26356 Mdot
.58567 .39939 Mdot
.48065 .62155 Mdot
.34422 .39137 Mdot
.58393 .40149 Mdot
.32347 .55784 Mdot
.46785 .31399 Mdot
.31281 .44488 Mdot
.53527 .64507 Mdot
.68254 .50638 Mdot
.31015 .71162 Mdot
.22204 .34963 Mdot
.32202 .49137 Mdot
.32081 .49041 Mdot
.70618 .52616 Mdot
.76391 .36206 Mdot
.50665 .34314 Mdot
.61291 .69572 Mdot
.30362 .60932 Mdot
.47928 .66388 Mdot
.18235 .61465 Mdot
.35532 .42273 Mdot
.34165 .4229 Mdot
.51207 .65563 Mdot
.29992 .40071 Mdot
.53581 .66432 Mdot
.34633 .40529 Mdot
.68418 .34088 Mdot
.53784 .68367 Mdot
.33935 .42001 Mdot
.52746 .56904 Mdot
.54495 .59288 Mdot
.70597 .51756 Mdot
.29352 .42542 Mdot
.4754 .64102 Mdot
.69985 .78198 Mdot
.50291 .2925 Mdot
.59163 .40717 Mdot
.30721 .47989 Mdot
.50661 .27773 Mdot
.68805 .48184 Mdot
.56184 .633 Mdot
.32155 .57719 Mdot
.68065 .51852 Mdot
.28606 .42909 Mdot
.30233 .53672 Mdot
.56193 .43821 Mdot
.68985 .51877 Mdot
.60523 .41467 Mdot
.30954 .58265 Mdot
.46487 .65146 Mdot
.34044 .42608 Mdot
.27029 .30985 Mdot
.58641 .40208 Mdot
.51197 .63939 Mdot
.31682 .37769 Mdot
.49547 .26771 Mdot
.49236 .645 Mdot
.33714 .44909 Mdot
.58976 .40265 Mdot
.55962 .61078 Mdot
.56282 .61298 Mdot
.53013 .71943 Mdot
.44009 .5294 Mdot
.32147 .56467 Mdot
.66076 .46672 Mdot
.48363 .62161 Mdot
.30892 .5913 Mdot
.30387 .31691 Mdot
.51199 .68377 Mdot
.64965 .52142 Mdot
.56112 .73274 Mdot
.30536 .40079 Mdot
.51063 .31163 Mdot
.29418 .40044 Mdot
.299 .53421 Mdot
.16071 .3986 Mdot
.59831 .4192 Mdot
.46231 .6029 Mdot
.48067 .60184 Mdot
.36538 .43178 Mdot
.67747 .4954 Mdot
.72235 .29806 Mdot
.55563 .65012 Mdot
.45195 .67095 Mdot
.53073 .63495 Mdot
.28155 .31946 Mdot
.67052 .48789 Mdot
.52925 .63302 Mdot
.57154 .56702 Mdot
.47317 .614 Mdot
.32502 .54349 Mdot
.39404 .69545 Mdot
.53666 .61581 Mdot
.49406 .92126 Mdot
.61562 .39345 Mdot
.33475 .42466 Mdot
.50992 .42603 Mdot
.26094 .42779 Mdot
.35946 .79523 Mdot
.68775 .48449 Mdot
.67051 .56227 Mdot
.30664 .41097 Mdot
.29141 .70027 Mdot
.76751 .37788 Mdot
.53642 .58697 Mdot
.53977 .66537 Mdot
.32709 .3964 Mdot
.29983 .41226 Mdot
.61949 .39998 Mdot
.53087 .67601 Mdot
.44765 .66713 Mdot
.31338 .38394 Mdot
.53901 .64783 Mdot
.64524 .7018 Mdot
.51649 .31612 Mdot
.69481 .51791 Mdot
.50995 .30275 Mdot
.49879 .32615 Mdot
.55276 .76424 Mdot
.55076 .46286 Mdot
.46891 .29658 Mdot
.50757 .26532 Mdot
.36105 .55456 Mdot
.4891 .75337 Mdot
.3278 .54738 Mdot
.43267 .30158 Mdot
.31942 .42608 Mdot
.50982 .62775 Mdot
.65636 .49618 Mdot
.48903 .80943 Mdot
.62321 .22356 Mdot
.52246 .50717 Mdot
.48776 .61649 Mdot
.32136 .41905 Mdot
.58795 .40099 Mdot
.53285 .68596 Mdot
.33293 .71405 Mdot
.51838 .64537 Mdot
.30116 .418 Mdot
.53947 .77498 Mdot
.6355 .42104 Mdot
.45728 .30465 Mdot
.73281 .50131 Mdot
.55165 .62367 Mdot
.6989 .49893 Mdot
.47129 .3071 Mdot
.30508 .59132 Mdot
.31446 .5584 Mdot
.50096 .66131 Mdot
.42355 .4926 Mdot
.33331 .61438 Mdot
.53572 .58695 Mdot
.53452 .59552 Mdot
.60983 .3943 Mdot
.53588 .59623 Mdot
.49454 .66429 Mdot
.52462 .60786 Mdot
.51694 .68043 Mdot
.46152 .29954 Mdot
.75636 .4679 Mdot
.55567 .66024 Mdot
.4715 .60866 Mdot
.52044 .29809 Mdot
.57924 .66202 Mdot
.48004 .2888 Mdot
.65387 .23342 Mdot
.47241 .28777 Mdot
.31517 .55993 Mdot
.30476 .38059 Mdot
.72242 .54719 Mdot
.68149 .47712 Mdot
.46433 .28687 Mdot
.30248 .57002 Mdot
.48066 .30418 Mdot
.34707 .44683 Mdot
.32957 .23269 Mdot
.6338 .5045 Mdot
.52599 .39318 Mdot
.45741 .73317 Mdot
.59326 .37804 Mdot
.31102 .39195 Mdot
.70859 .48464 Mdot
.63665 .41449 Mdot
.51755 .6032 Mdot
.32459 .57279 Mdot
.5228 .64771 Mdot
.47151 .32071 Mdot
.32111 .42191 Mdot
.46231 .24689 Mdot
.32154 .56348 Mdot
.18757 .37207 Mdot
.34681 .39867 Mdot
.46708 .60426 Mdot
.51994 .302 Mdot
.35003 .21446 Mdot
.4753 .28885 Mdot
.31736 .63344 Mdot
.62978 .47573 Mdot
.45917 .80143 Mdot
.66884 .51099 Mdot
.6061 .37801 Mdot
.80047 .35885 Mdot
.73775 .3657 Mdot
.68779 .512 Mdot
.29091 .45166 Mdot
.52813 .65495 Mdot
.50805 .60963 Mdot
.4939 .57401 Mdot
.74397 .49879 Mdot
.48464 .6356 Mdot
.59431 .41555 Mdot
.54417 .44747 Mdot
.39868 .22283 Mdot
.31497 .45853 Mdot
.53139 .6667 Mdot
.48615 .32259 Mdot
.46757 .31773 Mdot
.58425 .39813 Mdot
.5029 .27898 Mdot
.54734 .59683 Mdot
.67148 .5167 Mdot
.43488 .42809 Mdot
.32903 .55873 Mdot
.69775 .37903 Mdot
.31333 .61347 Mdot
.2789 .55746 Mdot
.4708 .62005 Mdot
.30428 .41844 Mdot
.16614 .54283 Mdot
.50723 .60551 Mdot
.68384 .49921 Mdot
.48561 .59868 Mdot
.52977 .61026 Mdot
.53837 .61794 Mdot
.33584 .45068 Mdot
.51112 .42262 Mdot
.5414 .64617 Mdot
.46838 .29892 Mdot
.45572 .39361 Mdot
.54057 .67933 Mdot
.39182 .26995 Mdot
.36819 .51459 Mdot
.5964 .37883 Mdot
.71397 .46937 Mdot
.31613 .40214 Mdot
.67105 .50501 Mdot
.69708 .54423 Mdot
.68863 .48175 Mdot
.3998 .25373 Mdot
.59519 .70854 Mdot
.28303 .76191 Mdot
.74525 .65412 Mdot
.5451 .77815 Mdot
.67027 .53901 Mdot
.34916 .30591 Mdot
.69221 .50934 Mdot
.68868 .48287 Mdot
.21817 .73875 Mdot
.65051 .51423 Mdot
.5244 .62775 Mdot
.56719 .62968 Mdot
.78672 .46372 Mdot
.36293 .55879 Mdot
.55797 .63599 Mdot
.48593 .63827 Mdot
.33633 .58164 Mdot
.60312 .65355 Mdot
.61848 .3922 Mdot
.56022 .46325 Mdot
.60663 .42241 Mdot
.5328 .6395 Mdot
.50163 .6556 Mdot
.57258 .62152 Mdot
.81312 .36855 Mdot
.45953 .81392 Mdot
.70339 .52598 Mdot
.58805 .64863 Mdot
.57713 .42073 Mdot
.48573 .59307 Mdot
.48219 .6022 Mdot
.5509 .6146 Mdot
.30759 .4085 Mdot
.72704 .50377 Mdot
.52578 .69305 Mdot
.70081 .41462 Mdot
.50647 .65999 Mdot
.27945 .57894 Mdot
.33447 .60661 Mdot
.5203 .6338 Mdot
.65288 .52231 Mdot
.496 .61073 Mdot
.64941 .49313 Mdot
.69642 .51495 Mdot
.44904 .62205 Mdot
.4175 .26986 Mdot
.72811 .50882 Mdot
.54143 .58934 Mdot
.32017 .39183 Mdot
.70135 .36795 Mdot
.51355 .63765 Mdot
.31814 .54551 Mdot
.51269 .61699 Mdot
.3145 .53527 Mdot
.54393 .60421 Mdot
.5863 .39746 Mdot
.66963 .60404 Mdot
.31178 .42087 Mdot
.29521 .59137 Mdot
.30372 .39712 Mdot
.4536 .70327 Mdot
.65162 .52823 Mdot
.6294 .41069 Mdot
.44791 .82307 Mdot
.61131 .39564 Mdot
.32701 .72927 Mdot
.45529 .38302 Mdot
.50457 .31908 Mdot
.6817 .46941 Mdot
.53528 .77093 Mdot
.40494 .30443 Mdot
.34942 .46405 Mdot
.35684 .44935 Mdot
.18137 .55347 Mdot
.14802 .5855 Mdot
.54507 .64541 Mdot
.38416 .21064 Mdot
.68141 .64571 Mdot
.52356 .56452 Mdot
.57854 .63709 Mdot
.33566 .38616 Mdot
.55943 .63291 Mdot
.49665 .44289 Mdot
.32567 .43934 Mdot
.30753 .57294 Mdot
.70378 .49118 Mdot
.30266 .58122 Mdot
.58981 .20486 Mdot
.54396 .36996 Mdot
.33228 .44126 Mdot
.52351 .6813 Mdot
.5373 .65894 Mdot
.69865 .46836 Mdot
.80478 .5828 Mdot
.70039 .51382 Mdot
.3232 .54626 Mdot
.3151 .43486 Mdot
.53004 .79622 Mdot
.52247 .61794 Mdot
.65889 .5172 Mdot
.28802 .44467 Mdot
.49773 .62639 Mdot
.50365 .31593 Mdot
.48823 .61461 Mdot
.66139 .5218 Mdot
.53651 .5969 Mdot
.67217 .51504 Mdot
.33963 .39811 Mdot
.51215 .67017 Mdot
.49912 .65403 Mdot
.33092 .73498 Mdot
.3085 .5518 Mdot
.65627 .53137 Mdot
.49926 .44439 Mdot
.482 .64559 Mdot
.33628 .71401 Mdot
.55308 .6221 Mdot
.42087 .61733 Mdot
.57217 .66721 Mdot
.59802 .41713 Mdot
.47915 .60355 Mdot
.51386 .63874 Mdot
.78214 .63265 Mdot
.77059 .63113 Mdot
.43204 .68583 Mdot
.46865 .26999 Mdot
.66069 .52631 Mdot
.33297 .44615 Mdot
.29898 .43505 Mdot
.32784 .40708 Mdot
.36536 .58518 Mdot
.59511 .5987 Mdot
.50891 .64447 Mdot
.46954 .33679 Mdot
.30945 .56622 Mdot
.65711 .50519 Mdot
.3145 .56544 Mdot
.55698 .47045 Mdot
.30874 .53959 Mdot
.59264 .41618 Mdot
.29546 .29126 Mdot
.62488 .71809 Mdot
.30423 .5438 Mdot
.69931 .51424 Mdot
.47968 .38949 Mdot
.47705 .66112 Mdot
.60541 .32653 Mdot
.33542 .5725 Mdot
.17556 .536 Mdot
.55967 .61515 Mdot
.50155 .42878 Mdot
.48492 .28646 Mdot
.30235 .58026 Mdot
.49659 .27714 Mdot
.49902 .60958 Mdot
.75113 .45717 Mdot
.68683 .49498 Mdot
.5147 .31719 Mdot
.47702 .60996 Mdot
.30319 .58156 Mdot
.33589 .43871 Mdot
.51139 .76388 Mdot
.51579 .27825 Mdot
.30318 .70383 Mdot
.321 .69639 Mdot
.31696 .43721 Mdot
.57508 .78684 Mdot
.48734 .27809 Mdot
.4866 .67455 Mdot
.60148 .57166 Mdot
.49262 .60786 Mdot
.31342 .44881 Mdot
.34185 .42013 Mdot
.75654 .41642 Mdot
.50494 .66196 Mdot
.56709 .63829 Mdot
.72277 .50698 Mdot
.32139 .44522 Mdot
.687 .48091 Mdot
.70226 .47181 Mdot
.32585 .39525 Mdot
.71076 .49036 Mdot
.29694 .54306 Mdot
.54114 .47963 Mdot
.48434 .27862 Mdot
.49763 .31782 Mdot
.33529 .44201 Mdot
.3324 .45645 Mdot
.30403 .42407 Mdot
.49007 .60408 Mdot
.70014 .47813 Mdot
.5124 .59243 Mdot
.54906 .62294 Mdot
.65893 .46009 Mdot
.72118 .49579 Mdot
.50333 .59701 Mdot
.43552 .39726 Mdot
.32362 .53954 Mdot
.3377 .41867 Mdot
.47905 .27146 Mdot
.32143 .73868 Mdot
.51649 .30995 Mdot
.48233 .6417 Mdot
.63428 .32822 Mdot
.66279 .49153 Mdot
.31856 .55474 Mdot
.33816 .50411 Mdot
.32122 .56024 Mdot
.51448 .31812 Mdot
.71426 .47392 Mdot
.55687 .43477 Mdot
.50703 .66472 Mdot
.53736 .4473 Mdot
.36313 .73263 Mdot
.71648 .40432 Mdot
.47023 .27582 Mdot
.48628 .6245 Mdot
.61379 .39873 Mdot
.62509 .68362 Mdot
.50951 .6485 Mdot
.47998 .64674 Mdot
.23425 .42918 Mdot
.47075 .61366 Mdot
.70008 .46449 Mdot
.40799 .4989 Mdot
.50927 .67368 Mdot
.44915 .69693 Mdot
.16473 .65066 Mdot
.56106 .61469 Mdot
.49885 .6562 Mdot
.51902 .62343 Mdot
.50912 .60272 Mdot
.64233 .50591 Mdot
.21888 .41878 Mdot
.47914 .31775 Mdot
.54022 .47912 Mdot
.48888 .27519 Mdot
.34364 .43203 Mdot
.47542 .44671 Mdot
.6464 .49647 Mdot
.32158 .55978 Mdot
.37407 .21181 Mdot
.51022 .50349 Mdot
.33119 .39155 Mdot
.38518 .79757 Mdot
.33368 .56783 Mdot
.47888 .66456 Mdot
.29376 .5427 Mdot
.3337 .38373 Mdot
.48649 .31508 Mdot
.52462 .57968 Mdot
.66868 .48398 Mdot
.6833 .52863 Mdot
.4854 .6171 Mdot
.69238 .37414 Mdot
.50567 .27512 Mdot
.24861 .56831 Mdot
.5218 .66058 Mdot
.48118 .65078 Mdot
.70601 .50755 Mdot
.32262 .41537 Mdot
.45576 .38496 Mdot
.30247 .55704 Mdot
.49469 .57823 Mdot
.49861 .61135 Mdot
.55394 .46858 Mdot
.46198 .2948 Mdot
.60091 .40516 Mdot
.5131 .66246 Mdot
.55093 .45411 Mdot
.48448 .64444 Mdot
.44064 .60775 Mdot
.31192 .3945 Mdot
.44932 .65878 Mdot
.53632 .66961 Mdot
.75486 .47895 Mdot
.49233 .27872 Mdot
.67889 .49878 Mdot
.62366 .49663 Mdot
.59206 .39399 Mdot
.50431 .29784 Mdot
.49998 .5986 Mdot
.49928 .32892 Mdot
.52176 .61107 Mdot
.53739 .64604 Mdot
.47046 .27514 Mdot
.69318 .48014 Mdot
.7078 .28877 Mdot
.75621 .46684 Mdot
.52752 .60118 Mdot
.50718 .61764 Mdot
.36606 .56251 Mdot
.50903 .82475 Mdot
.53705 .67003 Mdot
.70378 .47814 Mdot
.49629 .62802 Mdot
.49274 .32059 Mdot
.31964 .54383 Mdot
.68557 .50409 Mdot
.34038 .4535 Mdot
.34519 .40688 Mdot
.28908 .37373 Mdot
.59568 .41842 Mdot
.52883 .67576 Mdot
.66086 .46627 Mdot
.71889 .50842 Mdot
.57198 .49253 Mdot
.33559 .42424 Mdot
.31042 .53746 Mdot
.56193 .62699 Mdot
.52951 .75809 Mdot
.4881 .32649 Mdot
.50496 .91725 Mdot
.55495 .43138 Mdot
.32913 .60924 Mdot
.43063 .50474 Mdot
.61223 .40038 Mdot
.5519 .64269 Mdot
.31206 .59041 Mdot
.34421 .41122 Mdot
.50486 .60945 Mdot
.58583 .59143 Mdot
.40622 .3176 Mdot
.33941 .45849 Mdot
.50454 .32559 Mdot
.35227 .42362 Mdot
.31733 .5364 Mdot
.59212 .41514 Mdot
.6898 .52992 Mdot
.51793 .63961 Mdot
.45558 .6918 Mdot
.32746 .42288 Mdot
.5907 .391 Mdot
.49527 .65743 Mdot
.66853 .52903 Mdot
.33374 .4139 Mdot
.53741 .63596 Mdot
.61637 .69008 Mdot
.69948 .55522 Mdot
.31784 .43084 Mdot
.50923 .5775 Mdot
.49892 .72817 Mdot
.34713 .45669 Mdot
.34945 .39413 Mdot
.48537 .63804 Mdot
.30247 .57785 Mdot
.52282 .67083 Mdot
.47553 .29388 Mdot
.51105 .42187 Mdot
.50468 .30708 Mdot
.3361 .72224 Mdot
.56983 .63842 Mdot
.51091 .532 Mdot
.66525 .47823 Mdot
.29991 .5241 Mdot
.76417 .67351 Mdot
.48595 .66224 Mdot
.72328 .27679 Mdot
.47908 .41597 Mdot
.54609 .38981 Mdot
.65713 .21292 Mdot
.30055 .55174 Mdot
.48078 .3005 Mdot
.4946 .65386 Mdot
.50278 .35459 Mdot
.29679 .55572 Mdot
.337 .72419 Mdot
.48711 .58872 Mdot
.66684 .49222 Mdot
.52108 .65859 Mdot
.66464 .52539 Mdot
.50319 .62346 Mdot
.58799 .68576 Mdot
.28423 .58258 Mdot
.31924 .6334 Mdot
.47924 .66681 Mdot
.38121 .20096 Mdot
.47182 .74377 Mdot
.32447 .55185 Mdot
.53154 .60015 Mdot
.60761 .40353 Mdot
.49075 .26513 Mdot
.33465 .25143 Mdot
.30543 .41441 Mdot
.46881 .29207 Mdot
.70766 .49817 Mdot
.30564 .38347 Mdot
.59567 .39045 Mdot
.59867 .56597 Mdot
.30554 .58412 Mdot
.5031 .29352 Mdot
.51653 .63693 Mdot
.47967 .61536 Mdot
.28057 .31917 Mdot
.58621 .80689 Mdot
.70416 .47563 Mdot
.16876 .43476 Mdot
.66515 .46531 Mdot
.30656 .55873 Mdot
.30966 .39725 Mdot
.54312 .62872 Mdot
.50551 .65196 Mdot
.32395 .4524 Mdot
.71671 .48863 Mdot
.28812 .52575 Mdot
.46721 .80459 Mdot
.44225 .3089 Mdot
.3664 .65278 Mdot
.68865 .50406 Mdot
.36328 .65058 Mdot
.34146 .57912 Mdot
.45524 .22658 Mdot
.43564 .72544 Mdot
.50821 .31139 Mdot
.36985 .65584 Mdot
.65528 .50613 Mdot
.54669 .6451 Mdot
.60518 .41406 Mdot
.61677 .39998 Mdot
.70208 .49927 Mdot
.32264 .39683 Mdot
.3195 .5843 Mdot
.51735 .6572 Mdot
.57676 .52534 Mdot
.82158 .5627 Mdot
.3308 .45446 Mdot
.4601 .60102 Mdot
.5035 .27534 Mdot
.49886 .62277 Mdot
.33156 .58967 Mdot
.48701 .3107 Mdot
.58389 .41153 Mdot
.5128 .49724 Mdot
.56302 .62957 Mdot
.39661 .50621 Mdot
.49363 .28858 Mdot
.51477 .82534 Mdot
.49912 .65315 Mdot
.48783 .27804 Mdot
.45272 .6872 Mdot
.66574 .42127 Mdot
.44096 .41559 Mdot
.73605 .35942 Mdot
.31565 .46383 Mdot
.3489 .41194 Mdot
.66723 .79711 Mdot
.30257 .60896 Mdot
.46603 .29845 Mdot
.58852 .41077 Mdot
.41082 .70782 Mdot
.50301 .28399 Mdot
.5333 .58338 Mdot
.55513 .6233 Mdot
.54152 .7757 Mdot
.44323 .70266 Mdot
.61837 .39443 Mdot
.58219 .54971 Mdot
.53129 .5887 Mdot
.46232 .6601 Mdot
.49067 .63884 Mdot
.68932 .53364 Mdot
.51274 .30428 Mdot
.52094 .12309 Mdot
.49306 .33288 Mdot
.54938 .51337 Mdot
.31945 .42565 Mdot
.29612 .43954 Mdot
.52144 .63419 Mdot
.44275 .56295 Mdot
.42678 .18162 Mdot
.52841 .61775 Mdot
.34225 .5066 Mdot
.31937 .69541 Mdot
.51295 .68858 Mdot
.69477 .53898 Mdot
.44845 .66847 Mdot
.64359 .48702 Mdot
.48795 .31233 Mdot
.29954 .55174 Mdot
.33194 .54662 Mdot
.48059 .29367 Mdot
.50484 .64442 Mdot
.33251 .54454 Mdot
.52558 .63926 Mdot
.54072 .65473 Mdot
.56177 .46936 Mdot
.31906 .60093 Mdot
.30359 .42424 Mdot
.31649 .55892 Mdot
.68326 .48477 Mdot
.23508 .76498 Mdot
.31876 .57215 Mdot
.49242 .75513 Mdot
.49018 .43175 Mdot
.36917 .65889 Mdot
.68772 .52707 Mdot
.32601 .54967 Mdot
.51141 .30958 Mdot
.55944 .4241 Mdot
.57132 .78522 Mdot
.51475 .31254 Mdot
.50891 .65374 Mdot
.64785 .49396 Mdot
.70994 .52165 Mdot
.4571 .29801 Mdot
.71162 .50797 Mdot
.45765 .6303 Mdot
.54034 .58824 Mdot
.46977 .30673 Mdot
.80818 .49358 Mdot
.51273 .31013 Mdot
.52258 .75848 Mdot
.551 .61065 Mdot
.68449 .50162 Mdot
.42579 .60487 Mdot
.71585 .4631 Mdot
.61697 .40907 Mdot
.56018 .64483 Mdot
.32585 .56701 Mdot
.52846 .46522 Mdot
.31688 .42922 Mdot
.63901 .3272 Mdot
.67196 .52652 Mdot
.4845 .33781 Mdot
.70395 .51949 Mdot
.70957 .47801 Mdot
.51303 .31737 Mdot
.68246 .48973 Mdot
.50564 .6583 Mdot
.57176 .22979 Mdot
.6744 .52525 Mdot
.49301 .29552 Mdot
.32762 .57214 Mdot
.70989 .48758 Mdot
.30206 .51144 Mdot
.54283 .65614 Mdot
.31546 .38677 Mdot
.29431 .58764 Mdot
.65151 .4869 Mdot
.31925 .54446 Mdot
.33125 .42224 Mdot
.31973 .58592 Mdot
.47705 .34867 Mdot
.4955 .34364 Mdot
.522 .51068 Mdot
.64614 .42509 Mdot
.65785 .49297 Mdot
.31764 .4672 Mdot
.55343 .64932 Mdot
.52789 .66091 Mdot
.30397 .52749 Mdot
.69984 .53132 Mdot
.6846 .36677 Mdot
.47384 .55642 Mdot
.69723 .3805 Mdot
.46387 .27797 Mdot
.24834 .62988 Mdot
.55534 .42801 Mdot
.55135 .36659 Mdot
.55693 .58885 Mdot
.6124 .40212 Mdot
.53095 .63429 Mdot
.30141 .6788 Mdot
.33008 .55115 Mdot
.31198 .33655 Mdot
.51404 .56778 Mdot
.31311 .43937 Mdot
.51112 .62044 Mdot
.37352 .2242 Mdot
.4418 .66563 Mdot
.33561 .56515 Mdot
.52219 .31046 Mdot
.68139 .47711 Mdot
.33073 .56089 Mdot
.34215 .40181 Mdot
.38583 .64275 Mdot
.55204 .59355 Mdot
.53885 .59122 Mdot
.36061 .43717 Mdot
.68162 .48155 Mdot
.3427 .42893 Mdot
.48482 .27836 Mdot
.31705 .56937 Mdot
.51244 .60108 Mdot
.45222 .65736 Mdot
.36545 .42707 Mdot
.48263 .33064 Mdot
.32596 .4571 Mdot
.49564 .32954 Mdot
.6125 .40574 Mdot
.51956 .67842 Mdot
.362 .4152 Mdot
.56189 .58946 Mdot
.76992 .61398 Mdot
.54834 .48805 Mdot
.72581 .70766 Mdot
.30327 .42384 Mdot
.37561 .60099 Mdot
.48454 .29535 Mdot
.50086 .28751 Mdot
.54728 .76592 Mdot
.42692 .18593 Mdot
.45932 .38934 Mdot
.30548 .25294 Mdot
.48357 .27872 Mdot
.49889 .29341 Mdot
.33997 .40756 Mdot
.69266 .48598 Mdot
.67817 .54634 Mdot
.33026 .38013 Mdot
.30295 .64901 Mdot
.65695 .50587 Mdot
.75551 .31442 Mdot
.35757 .42682 Mdot
.56602 .6039 Mdot
.62656 .41217 Mdot
.33578 .56882 Mdot
.30238 .67136 Mdot
.32156 .2431 Mdot
.53598 .62865 Mdot
.23815 .71188 Mdot
.31332 .40528 Mdot
.44625 .33443 Mdot
.46933 .21826 Mdot
.4776 .6258 Mdot
.51192 .6225 Mdot
.49985 .64209 Mdot
.29048 .5771 Mdot
.79674 .57918 Mdot
.53998 .62962 Mdot
.33313 .62368 Mdot
.5384 .6838 Mdot
.27104 .31456 Mdot
.31638 .55926 Mdot
.41695 .77331 Mdot
.29692 .45155 Mdot
.69283 .40705 Mdot
.47152 .62257 Mdot
.48053 .28208 Mdot
.42029 .35803 Mdot
.46677 .28499 Mdot
.44302 .21889 Mdot
.43249 .72662 Mdot
.68679 .53487 Mdot
.48782 .61418 Mdot
.3588 .41996 Mdot
.64988 .49064 Mdot
.42765 .37852 Mdot
.20318 .72651 Mdot
.45926 .28973 Mdot
.12757 .50812 Mdot
.5083 .29837 Mdot
.61723 .39834 Mdot
.7047 .50364 Mdot
.39955 .60707 Mdot
.54098 .45283 Mdot
.68841 .48089 Mdot
.22547 .54036 Mdot
.63917 .5346 Mdot
.367 .63076 Mdot
.63131 .51819 Mdot
.48866 .29924 Mdot
.49717 .34272 Mdot
.58832 .61357 Mdot
.54636 .66244 Mdot
.53451 .43754 Mdot
.57888 .62372 Mdot
.55727 .64219 Mdot
.32551 .43948 Mdot
.64815 .41761 Mdot
.51556 .35318 Mdot
.69397 .50209 Mdot
.4785 .32216 Mdot
.51278 .62119 Mdot
.52769 .60078 Mdot
.47556 .60124 Mdot
.29928 .70833 Mdot
.7513 .30792 Mdot
.54139 .64463 Mdot
.44205 .65882 Mdot
.32852 .39187 Mdot
.27707 .31992 Mdot
.18783 .41638 Mdot
.41858 .71028 Mdot
.49471 .65856 Mdot
.31058 .55305 Mdot
.33758 .57988 Mdot
.46328 .61732 Mdot
.50613 .52936 Mdot
.30206 .50818 Mdot
.51628 .63682 Mdot
.38643 .60671 Mdot
.36365 .45006 Mdot
.5874 .39347 Mdot
.32792 .42323 Mdot
.64821 .49118 Mdot
.61222 .39517 Mdot
.34319 .44413 Mdot
.41311 .57473 Mdot
.59144 .39557 Mdot
.67063 .41885 Mdot
.32423 .54698 Mdot
.49259 .64497 Mdot
.74257 .52606 Mdot
.32711 .45093 Mdot
.49732 .28847 Mdot
.67873 .51361 Mdot
.47825 .2626 Mdot
.28305 .30485 Mdot
.30717 .66309 Mdot
.59996 .41903 Mdot
.47705 .28469 Mdot
.44024 .47329 Mdot
.31155 .55475 Mdot
.50844 .28816 Mdot
.49383 .53933 Mdot
.55214 .6695 Mdot
.48491 .17876 Mdot
.52267 .58434 Mdot
.76051 .4052 Mdot
.49284 .28341 Mdot
.58557 .4186 Mdot
.51799 .64122 Mdot
.34602 .39875 Mdot
.57486 .67247 Mdot
.52627 .6404 Mdot
.35333 .43771 Mdot
.54526 .6441 Mdot
.31646 .59652 Mdot
.64901 .48178 Mdot
.475 .42357 Mdot
.27923 .67441 Mdot
.32722 .58094 Mdot
.602 .49697 Mdot
.54319 .66687 Mdot
.20564 .52392 Mdot
.66992 .49215 Mdot
.48322 .65396 Mdot
.34829 .75872 Mdot
.69881 .49197 Mdot
.66987 .50524 Mdot
.52896 .5931 Mdot
.51527 .3078 Mdot
.31333 .44698 Mdot
.31349 .55533 Mdot
.5119 .36214 Mdot
.53975 .63503 Mdot
.48587 .62757 Mdot
.33311 .56637 Mdot
.50273 .29781 Mdot
.51067 .59961 Mdot
.67626 .30408 Mdot
.5689 .49409 Mdot
.49533 .32742 Mdot
.54077 .67884 Mdot
.55823 .15801 Mdot
.67818 .54745 Mdot
.24844 .72586 Mdot
.30686 .60888 Mdot
.31929 .39448 Mdot
.47745 .57998 Mdot
.46623 .91775 Mdot
.32682 .55292 Mdot
.70106 .40187 Mdot
.53996 .64995 Mdot
.54396 .62527 Mdot
.67111 .53416 Mdot
.5068 .59246 Mdot
.65465 .51861 Mdot
.26397 .66208 Mdot
.38114 .18311 Mdot
.70883 .51193 Mdot
.65792 .52157 Mdot
.44054 .68816 Mdot
.30755 .72293 Mdot
.70551 .49191 Mdot
.55363 .59476 Mdot
.22215 .5182 Mdot
.57882 .57821 Mdot
.32986 .60559 Mdot
.32024 .51202 Mdot
.68622 .53974 Mdot
.62754 .7715 Mdot
.43903 .6799 Mdot
.55417 .71449 Mdot
.34736 .55674 Mdot
.47189 .28269 Mdot
.54008 .61104 Mdot
.59189 .41686 Mdot
.33594 .41234 Mdot
.46208 .67828 Mdot
.49652 .64769 Mdot
.6475 .51041 Mdot
.28686 .55418 Mdot
.50182 .28049 Mdot
.48771 .64325 Mdot
.36041 .39765 Mdot
.30404 .56881 Mdot
.67932 .52396 Mdot
.50131 .75552 Mdot
.33705 .55782 Mdot
.45015 .64423 Mdot
.55528 .63521 Mdot
.48979 .6532 Mdot
.54599 .56577 Mdot
.48168 .29093 Mdot
.31893 .37892 Mdot
.48124 .57872 Mdot
.56009 .45095 Mdot
.5181 .46662 Mdot
.47166 .59239 Mdot
.70585 .47951 Mdot
.46703 .27446 Mdot
.59276 .40154 Mdot
.38529 .68233 Mdot
.55697 .61289 Mdot
.7387 .29052 Mdot
.4231 .81114 Mdot
.59595 .39649 Mdot
.64274 .52606 Mdot
.31896 .55665 Mdot
.54328 .59742 Mdot
.3131 .62391 Mdot
.53112 .58307 Mdot
.57284 .56389 Mdot
.31538 .39843 Mdot
.47668 .27543 Mdot
.58991 .5194 Mdot
.33768 .41322 Mdot
.67064 .50506 Mdot
.79494 .41892 Mdot
.65838 .54347 Mdot
.7055 .47453 Mdot
.42098 .25988 Mdot
.48072 .31109 Mdot
.48103 .92263 Mdot
.50388 .82786 Mdot
.56771 .61788 Mdot
.47866 .31383 Mdot
.70139 .50544 Mdot
.49397 .59572 Mdot
.65623 .49752 Mdot
.72582 .51202 Mdot
.55951 .63518 Mdot
.55587 .64262 Mdot
.32922 .63181 Mdot
.76826 .33501 Mdot
.32397 .57342 Mdot
.71187 .51199 Mdot
.57461 .74833 Mdot
.54485 .63116 Mdot
.50973 .6653 Mdot
.41359 .33737 Mdot
.32874 .55333 Mdot
.64559 .68942 Mdot
.52871 .65888 Mdot
.33657 .75521 Mdot
.55789 .64585 Mdot
.70794 .54027 Mdot
.45534 .27777 Mdot
.53853 .52162 Mdot
.3111 .44728 Mdot
.68283 .46852 Mdot
.30724 .52978 Mdot
.7193 .47233 Mdot
.59217 .72203 Mdot
.48644 .31362 Mdot
.66096 .52163 Mdot
.29435 .39406 Mdot
.49933 .30632 Mdot
.50809 .31429 Mdot
.42995 .38459 Mdot
.29942 .39057 Mdot
.29869 .58972 Mdot
.48619 .26647 Mdot
.61374 .69112 Mdot
.48992 .30244 Mdot
.59804 .7176 Mdot
.51714 .6736 Mdot
.34881 .62045 Mdot
.57618 .51771 Mdot
.58599 .60114 Mdot
.51223 .29848 Mdot
.31235 .58121 Mdot
.49558 .60168 Mdot
.71296 .50315 Mdot
.31546 .5771 Mdot
.48829 .36546 Mdot
.29467 .44071 Mdot
.70934 .52453 Mdot
.51869 .31558 Mdot
.65087 .50858 Mdot
.31302 .68685 Mdot
.27193 .54291 Mdot
.4249 .40052 Mdot
.53474 .4483 Mdot
.46705 .65787 Mdot
.44602 .69515 Mdot
.47926 .60928 Mdot
.50331 .64945 Mdot
.3184 .4305 Mdot
.36576 .58752 Mdot
.70987 .48701 Mdot
.83226 .54298 Mdot
.48107 .28446 Mdot
.41034 .49862 Mdot
.58048 .56568 Mdot
.51582 .61043 Mdot
.69325 .51179 Mdot
.72899 .49782 Mdot
.77053 .63214 Mdot
.3234 .45289 Mdot
.57734 .57947 Mdot
.46923 .62969 Mdot
.60367 .62331 Mdot
.50945 .30633 Mdot
.69192 .29736 Mdot
.30769 .45029 Mdot
.12047 .55907 Mdot
.33854 .41881 Mdot
.2185 .4522 Mdot
.68367 .48945 Mdot
.30574 .53763 Mdot
.51804 .66626 Mdot
.67119 .44368 Mdot
.6424 .51374 Mdot
.33946 .47819 Mdot
.32293 .558 Mdot
.70361 .29274 Mdot
.47204 .30249 Mdot
.50179 .66942 Mdot
.56097 .63926 Mdot
.51858 .59336 Mdot
.49187 .59262 Mdot
.4722 .31264 Mdot
.52156 .57996 Mdot
.51494 .27541 Mdot
.60719 .72284 Mdot
.35378 .75905 Mdot
.35567 .40327 Mdot
.2674 .32857 Mdot
.70871 .47828 Mdot
.63832 .59201 Mdot
.64051 .70251 Mdot
.5495 .48853 Mdot
.46436 .33713 Mdot
.51728 .6763 Mdot
.32487 .39774 Mdot
.39077 .20161 Mdot
.35592 .40601 Mdot
.4583 .13276 Mdot
.53155 .77232 Mdot
.75509 .37008 Mdot
.50231 .58754 Mdot
.3555 .39515 Mdot
.65095 .75104 Mdot
.45109 .65692 Mdot
.32136 .53103 Mdot
.58576 .71407 Mdot
.76727 .45042 Mdot
.31325 .53861 Mdot
.54656 .65137 Mdot
.72157 .48865 Mdot
.50875 .65896 Mdot
.5268 .66649 Mdot
.52413 .61685 Mdot
.46103 .26708 Mdot
.56234 .64731 Mdot
.52278 .67056 Mdot
.57197 .80693 Mdot
.36522 .51057 Mdot
.33566 .39256 Mdot
.74151 .68601 Mdot
.30957 .56678 Mdot
.65266 .48695 Mdot
.48369 .41563 Mdot
.47287 .2953 Mdot
.76735 .635 Mdot
.51043 .58463 Mdot
.71706 .38895 Mdot
.49601 .34097 Mdot
.29999 .56842 Mdot
.59021 .40033 Mdot
.66658 .25203 Mdot
.30153 .41078 Mdot
.62047 .40043 Mdot
.31598 .42813 Mdot
.69725 .74046 Mdot
.65751 .52238 Mdot
.46591 .65807 Mdot
.49593 .27392 Mdot
.33683 .38694 Mdot
.32227 .62426 Mdot
.49534 .63577 Mdot
.30341 .427 Mdot
.47305 .66628 Mdot
.51888 .45753 Mdot
.49276 .41543 Mdot
.32188 .38131 Mdot
.5066 .33768 Mdot
.5009 .31003 Mdot
.30232 .53385 Mdot
.66746 .47477 Mdot
.67298 .48339 Mdot
.49205 .30934 Mdot
.16078 .6118 Mdot
.53832 .63413 Mdot
.5523 .62982 Mdot
.55891 .44347 Mdot
.48945 .59826 Mdot
.37885 .58918 Mdot
.60911 .38632 Mdot
.65923 .48779 Mdot
.48437 .60568 Mdot
.51194 .59936 Mdot
.55981 .62491 Mdot
.3105 .6624 Mdot
.32696 .42069 Mdot
.53375 .58992 Mdot
.309 .58785 Mdot
.59373 .37074 Mdot
.5517 .65229 Mdot
.45607 .66131 Mdot
.65313 .51505 Mdot
.18073 .53453 Mdot
.49249 .28516 Mdot
.32067 .44644 Mdot
.35799 .43556 Mdot
.36024 .71543 Mdot
.74148 .49222 Mdot
.61742 .39168 Mdot
.30682 .30074 Mdot
.58952 .4082 Mdot
.32013 .5493 Mdot
.44638 .39939 Mdot
.37057 .4422 Mdot
.34731 .40726 Mdot
.51696 .32767 Mdot
.48127 .62202 Mdot
.55793 .64268 Mdot
.69231 .40027 Mdot
.54042 .61992 Mdot
.32686 .56494 Mdot
.51858 .29719 Mdot
.65651 .51808 Mdot
.32933 .5909 Mdot
.50294 .28848 Mdot
.68367 .48069 Mdot
.5231 .68791 Mdot
.48694 .58041 Mdot
.67453 .51238 Mdot
.68293 .52522 Mdot
.51985 .62858 Mdot
.63139 .79935 Mdot
.66375 .48386 Mdot
.68636 .516 Mdot
.56762 .39784 Mdot
.30583 .39673 Mdot
.43207 .6019 Mdot
.48012 .31417 Mdot
.50731 .66172 Mdot
.35696 .40417 Mdot
.30761 .54236 Mdot
.66585 .51252 Mdot
.54359 .61032 Mdot
.53742 .64105 Mdot
.312 .55251 Mdot
.32872 .6011 Mdot
.33 .57263 Mdot
.46394 .26692 Mdot
.53909 .58811 Mdot
.70708 .49082 Mdot
.47196 .30358 Mdot
.33783 .57278 Mdot
.29108 .54892 Mdot
.57111 .80142 Mdot
.53282 .629 Mdot
.33344 .54338 Mdot
.29572 .82159 Mdot
.39015 .65571 Mdot
.60966 .39142 Mdot
.36624 .41323 Mdot
.35208 .61249 Mdot
.2876 .57527 Mdot
.46563 .29133 Mdot
.37369 .51329 Mdot
.2918 .53458 Mdot
.53871 .61675 Mdot
.49689 .62062 Mdot
.53968 .5795 Mdot
.311 .57382 Mdot
.31375 .67546 Mdot
.71573 .51118 Mdot
.69215 .61806 Mdot
.3097 .56697 Mdot
.31765 .38244 Mdot
.36449 .41576 Mdot
.34104 .42061 Mdot
.50761 .67582 Mdot
.76981 .65208 Mdot
.58897 .73756 Mdot
.65522 .67583 Mdot
.46961 .29574 Mdot
.72818 .50067 Mdot
.4644 .24421 Mdot
.66914 .50527 Mdot
.32521 .40783 Mdot
.30543 .57333 Mdot
.67519 .53512 Mdot
.5051 .31583 Mdot
.50376 .31072 Mdot
.32573 .45906 Mdot
.33207 .42526 Mdot
.33388 .44039 Mdot
.6787 .46966 Mdot
.68287 .48948 Mdot
.51923 .60059 Mdot
.66685 .51827 Mdot
.43319 .81961 Mdot
.32241 .61137 Mdot
.35462 .45563 Mdot
.48909 .28937 Mdot
.69025 .51825 Mdot
.49357 .64785 Mdot
.24349 .43644 Mdot
.34058 .47599 Mdot
.32742 .58504 Mdot
.56177 .26159 Mdot
.33745 .19204 Mdot
.52993 .68284 Mdot
.47831 .32686 Mdot
.50708 .53116 Mdot
.50122 .63644 Mdot
.30874 .40336 Mdot
.4403 .79478 Mdot
.58675 .39968 Mdot
.53531 .66727 Mdot
.47809 .6445 Mdot
.51408 .30691 Mdot
.48722 .4158 Mdot
.5325 .61615 Mdot
.4336 .44734 Mdot
.46213 .30657 Mdot
.30856 .45102 Mdot
.68583 .79558 Mdot
.45306 .34273 Mdot
.27352 .63582 Mdot
.59962 .39135 Mdot
.54493 .6192 Mdot
.32342 .43791 Mdot
.31999 .59043 Mdot
.32654 .43235 Mdot
.64412 .53054 Mdot
.30524 .4012 Mdot
.49085 .62989 Mdot
.70488 .48775 Mdot
.50356 .29573 Mdot
.4016 .50561 Mdot
.60113 .79375 Mdot
.34507 .39814 Mdot
.58236 .3958 Mdot
.55156 .64845 Mdot
.6303 .66102 Mdot
.5889 .61717 Mdot
.53827 .66862 Mdot
.46875 .27742 Mdot
.69455 .50754 Mdot
.46442 .27765 Mdot
.49532 .68388 Mdot
.6345 .57187 Mdot
.47929 .28682 Mdot
.75175 .45109 Mdot
.33359 .56622 Mdot
.30252 .65028 Mdot
.51386 .64874 Mdot
.49429 .27367 Mdot
.54594 .59274 Mdot
.71164 .51337 Mdot
.51011 .4862 Mdot
.6047 .53441 Mdot
.50338 .2748 Mdot
.77503 .41179 Mdot
.49968 .44582 Mdot
.42893 .6182 Mdot
.48919 .27661 Mdot
.76407 .67194 Mdot
.60498 .40324 Mdot
.30364 .55325 Mdot
.33292 .59451 Mdot
.29429 .56669 Mdot
.54445 .62199 Mdot
.58868 .69434 Mdot
.29122 .56736 Mdot
.46309 .27107 Mdot
.30345 .58955 Mdot
.30985 .71413 Mdot
.69121 .37213 Mdot
.331 .57717 Mdot
.51759 .65003 Mdot
.46948 .67298 Mdot
.36562 .51451 Mdot
.29119 .4137 Mdot
.70256 .26906 Mdot
.5445 .80033 Mdot
.54207 .62785 Mdot
.60621 .67549 Mdot
.66159 .5394 Mdot
.43585 .53443 Mdot
.60614 .55318 Mdot
.48137 .39278 Mdot
.68719 .51785 Mdot
.51612 .42712 Mdot
.661 .48306 Mdot
.48711 .67675 Mdot
.5365 .64691 Mdot
.64062 .49953 Mdot
.62115 .32098 Mdot
.81226 .61004 Mdot
.70171 .37911 Mdot
.69474 .47726 Mdot
.49276 .27882 Mdot
.46765 .31599 Mdot
.47046 .276 Mdot
.32889 .4486 Mdot
.67225 .52812 Mdot
.55349 .60477 Mdot
.33812 .39839 Mdot
.52186 .66388 Mdot
.49599 .31369 Mdot
.56923 .49645 Mdot
.65593 .51818 Mdot
.51472 .63863 Mdot
.58223 .77519 Mdot
.31676 .41959 Mdot
.30957 .55553 Mdot
.56733 .25061 Mdot
.36853 .43362 Mdot
.4979 .33268 Mdot
.72679 .51731 Mdot
.29064 .37925 Mdot
.2181 .41269 Mdot
.56718 .61054 Mdot
.56501 .6086 Mdot
.28989 .45877 Mdot
.60022 .77975 Mdot
.51707 .61386 Mdot
.34368 .40406 Mdot
.30769 .39237 Mdot
.55469 .59977 Mdot
.69174 .52763 Mdot
.2883 .55776 Mdot
.3045 .52743 Mdot
.47294 .65645 Mdot
.53183 .43982 Mdot
.34237 .62214 Mdot
.5038 .5983 Mdot
.47235 .57592 Mdot
.29138 .40108 Mdot
.59613 .39059 Mdot
.55004 .46602 Mdot
.29522 .54615 Mdot
.53942 .6519 Mdot
.8149 .5703 Mdot
.66796 .52396 Mdot
.30859 .44189 Mdot
.49114 .32401 Mdot
.33353 .54667 Mdot
.33959 .46304 Mdot
.55505 .60017 Mdot
.51108 .59942 Mdot
.50316 .27972 Mdot
.7119 .5376 Mdot
.30924 .57539 Mdot
.33566 .39621 Mdot
.30592 .53716 Mdot
.67836 .48909 Mdot
.67922 .52079 Mdot
.46795 .63345 Mdot
.58599 .6054 Mdot
.35476 .41596 Mdot
.50323 .57471 Mdot
.34533 .42195 Mdot
.28004 .31907 Mdot
.48654 .32605 Mdot
.47868 .63673 Mdot
.73951 .48177 Mdot
.4953 .31293 Mdot
.53224 .62378 Mdot
.2877 .45541 Mdot
.50533 .60692 Mdot
.33914 .38399 Mdot
.46716 .79854 Mdot
.29687 .55077 Mdot
.4884 .71109 Mdot
.41378 .64231 Mdot
.48857 .60005 Mdot
.30002 .3958 Mdot
.57211 .71433 Mdot
.47801 .29052 Mdot
.69103 .4923 Mdot
.17007 .54853 Mdot
.49227 .29787 Mdot
.52299 .65518 Mdot
.31773 .57204 Mdot
.68393 .47578 Mdot
.61152 .4131 Mdot
.5416 .42694 Mdot
.46436 .68016 Mdot
.56569 .67845 Mdot
.48796 .6485 Mdot
.30764 .25032 Mdot
.33064 .43858 Mdot
.69698 .51017 Mdot
.4725 .32031 Mdot
.48138 .30761 Mdot
.32227 .41516 Mdot
.76346 .43626 Mdot
.66539 .33551 Mdot
.3448 .85704 Mdot
.34842 .46062 Mdot
.30013 .58342 Mdot
.50885 .47717 Mdot
.34091 .4153 Mdot
.32119 .44256 Mdot
.29067 .43393 Mdot
.68963 .38986 Mdot
.6983 .47859 Mdot
.5396 .64036 Mdot
.721 .47224 Mdot
.5459 .6203 Mdot
.27549 .63058 Mdot
.49007 .31155 Mdot
.68969 .49126 Mdot
.27235 .52089 Mdot
.44397 .68158 Mdot
.50587 .62854 Mdot
.26132 .61236 Mdot
.51686 .69518 Mdot
.37637 .66552 Mdot
.47547 .59969 Mdot
.32389 .42687 Mdot
.6412 .56474 Mdot
.45356 .61382 Mdot
.57525 .77493 Mdot
.50537 .30675 Mdot
.60668 .41846 Mdot
.51169 .69029 Mdot
.44701 .59744 Mdot
.68481 .47469 Mdot
.67218 .53518 Mdot
.29075 .5663 Mdot
.5747 .23818 Mdot
.50551 .30348 Mdot
.72428 .33456 Mdot
.54464 .66466 Mdot
.52211 .346 Mdot
.4559 .80071 Mdot
.5239 .62342 Mdot
.43311 .39187 Mdot
.76827 .63378 Mdot
.51171 .61089 Mdot
.66487 .66442 Mdot
.48799 .2929 Mdot
.34183 .75606 Mdot
.48342 .58738 Mdot
.3079 .40676 Mdot
.69136 .48691 Mdot
.7099 .52362 Mdot
.32665 .58869 Mdot
.46467 .82622 Mdot
.51219 .23541 Mdot
.68634 .48916 Mdot
.49737 .64112 Mdot
.49274 .28649 Mdot
.61327 .41364 Mdot
.45886 .68454 Mdot
.43382 .20581 Mdot
.66334 .51908 Mdot
.47872 .58011 Mdot
.71495 .38215 Mdot
.50348 .41964 Mdot
.76877 .32698 Mdot
.47886 .26993 Mdot
.29566 .54355 Mdot
.55953 .57603 Mdot
.30297 .30529 Mdot
.49078 .57893 Mdot
.27473 .63244 Mdot
.74736 .48428 Mdot
.3188 .54334 Mdot
.50448 .6387 Mdot
.52968 .61516 Mdot
.53476 .46056 Mdot
.33608 .59137 Mdot
.53267 .61587 Mdot
.50121 .56678 Mdot
.67386 .48559 Mdot
.60798 .38574 Mdot
.65618 .51581 Mdot
.50727 .65408 Mdot
.46566 .78803 Mdot
.68779 .53174 Mdot
.70514 .27808 Mdot
.295 .6002 Mdot
.4726 .29395 Mdot
.45551 .60441 Mdot
.52417 .67397 Mdot
.67236 .20751 Mdot
.61739 .40733 Mdot
.17338 .44805 Mdot
.35494 .39525 Mdot
.82267 .64195 Mdot
.36811 .4424 Mdot
.76564 .3839 Mdot
.41432 .48648 Mdot
.5207 .57401 Mdot
.45177 .71721 Mdot
.65722 .66495 Mdot
.5088 .34971 Mdot
.63484 .6152 Mdot
.5465 .66225 Mdot
.5498 .64335 Mdot
.34072 .406 Mdot
.75854 .42275 Mdot
.53492 .52387 Mdot
.54719 .4632 Mdot
.30026 .56599 Mdot
.67709 .49611 Mdot
.49293 .62703 Mdot
.59058 .30427 Mdot
.33804 .39006 Mdot
.48409 .76095 Mdot
.5156 .64076 Mdot
.54089 .51634 Mdot
.73323 .42839 Mdot
.50221 .29181 Mdot
.31833 .38113 Mdot
.30857 .38448 Mdot
.54924 .61875 Mdot
.47377 .31132 Mdot
.51599 .60453 Mdot
.4985 .45214 Mdot
.45856 .67447 Mdot
.31447 .54447 Mdot
.50941 .66624 Mdot
.42343 .69204 Mdot
.80639 .4164 Mdot
.43699 .63407 Mdot
.68866 .47057 Mdot
.33767 .44199 Mdot
.32984 .41699 Mdot
.67394 .48267 Mdot
.32958 .41614 Mdot
.69119 .62628 Mdot
.62027 .62513 Mdot
.31981 .54784 Mdot
.63541 .71894 Mdot
.29774 .55456 Mdot
.60418 .41919 Mdot
.52843 .6283 Mdot
.36834 .28081 Mdot
.3469 .462 Mdot
.32074 .73666 Mdot
.48916 .30584 Mdot
.61769 .40366 Mdot
.56343 .62287 Mdot
.33184 .53258 Mdot
.32523 .40289 Mdot
.43901 .34472 Mdot
.55538 .62054 Mdot
.71685 .49444 Mdot
.51619 .61106 Mdot
.56265 .66974 Mdot
.61641 .39513 Mdot
.48568 .64426 Mdot
.50277 .28826 Mdot
.66688 .52812 Mdot
.75401 .37642 Mdot
.32707 .4505 Mdot
.54069 .66164 Mdot
.4982 .64045 Mdot
.66095 .53451 Mdot
.56671 .62969 Mdot
.4672 .29789 Mdot
.53576 .91312 Mdot
.33158 .56109 Mdot
.5938 .39109 Mdot
.58976 .20486 Mdot
.48991 .61783 Mdot
.498 .60207 Mdot
.49001 .37981 Mdot
.80945 .57694 Mdot
.4847 .28166 Mdot
.52304 .6904 Mdot
.32559 .38874 Mdot
.31083 .57803 Mdot
.49167 .26521 Mdot
.53422 .58514 Mdot
.54945 .63984 Mdot
.32433 .55028 Mdot
.26923 .61839 Mdot
.28818 .52351 Mdot
.46806 .28895 Mdot
.61415 .63406 Mdot
.24696 .43682 Mdot
.53118 .63611 Mdot
.58332 .42253 Mdot
.68861 .51011 Mdot
.48363 .27709 Mdot
.79765 .5704 Mdot
.48476 .67418 Mdot
.50835 .32377 Mdot
.50438 .298 Mdot
.56644 .63379 Mdot
.74174 .49746 Mdot
.73053 .4856 Mdot
.6892 .51173 Mdot
.3583 .75583 Mdot
.20671 .38093 Mdot
.3323 .44269 Mdot
.49301 .29131 Mdot
.35909 .4087 Mdot
.29494 .53226 Mdot
.51978 .46458 Mdot
.31508 .38424 Mdot
.71281 .48012 Mdot
.35963 .41816 Mdot
.51107 .6042 Mdot
.50215 .31822 Mdot
.35698 .42921 Mdot
.49643 .59517 Mdot
.4808 .57034 Mdot
.44619 .70793 Mdot
.28763 .55886 Mdot
.51708 .42661 Mdot
.51675 .6556 Mdot
.59141 .39937 Mdot
.51906 .6316 Mdot
.46843 .30437 Mdot
.37605 .51672 Mdot
.52182 .58568 Mdot
.34851 .46135 Mdot
.22113 .38175 Mdot
.29705 .40585 Mdot
.56986 .65022 Mdot
.5093 .65431 Mdot
.53392 .63433 Mdot
.55877 .63709 Mdot
.76862 .45684 Mdot
.52417 .29487 Mdot
.57358 .56626 Mdot
.33879 .46021 Mdot
.66866 .50929 Mdot
.69779 .52905 Mdot
.48023 .38661 Mdot
.61967 .40744 Mdot
.47737 .31394 Mdot
.53591 .63463 Mdot
.43971 .34766 Mdot
.54817 .41329 Mdot
.70829 .379 Mdot
.28539 .37822 Mdot
.34916 .41043 Mdot
.69813 .46957 Mdot
.3516 .43425 Mdot
.54063 .58801 Mdot
.49487 .574 Mdot
.75348 .37118 Mdot
.47351 .25585 Mdot
.3076 .57452 Mdot
.5183 .6645 Mdot
.30637 .64208 Mdot
.32863 .39193 Mdot
.29413 .39632 Mdot
.51948 .60392 Mdot
.69831 .54089 Mdot
.81947 .38848 Mdot
.4845 .31995 Mdot
.62731 .6655 Mdot
.65218 .55766 Mdot
.60651 .60636 Mdot
.48 .29593 Mdot
.43602 .40759 Mdot
.2929 .42824 Mdot
.51952 .8141 Mdot
.67279 .51399 Mdot
.3069 .57196 Mdot
.47132 .59866 Mdot
.7124 .47969 Mdot
.36314 .42357 Mdot
.65301 .48982 Mdot
.46559 .65906 Mdot
.46093 .2802 Mdot
.33542 .41594 Mdot
.52228 .33157 Mdot
.64122 .50469 Mdot
.29726 .55358 Mdot
.33024 .73125 Mdot
.62144 .68628 Mdot
.76849 .63286 Mdot
.53521 .59073 Mdot
.39844 .28732 Mdot
.55372 .60637 Mdot
.71845 .4789 Mdot
.51425 .6491 Mdot
.45233 .69913 Mdot
.29732 .44164 Mdot
.46233 .60556 Mdot
.51406 .66872 Mdot
.56878 .77241 Mdot
.51414 .62341 Mdot
.56165 .61717 Mdot
.47634 .64815 Mdot
.71153 .54076 Mdot
.46158 .60982 Mdot
.71625 .49393 Mdot
.70778 .39996 Mdot
.31922 .44145 Mdot
.29921 .53085 Mdot
.31479 .53476 Mdot
.26593 .6292 Mdot
.3063 .64686 Mdot
.75674 .42865 Mdot
.65858 .50487 Mdot
.51122 .30338 Mdot
.51505 .60349 Mdot
.74707 .69576 Mdot
.43884 .76777 Mdot
.29986 .44299 Mdot
.35724 .41725 Mdot
.47943 .58711 Mdot
.40022 .18032 Mdot
.46554 .60212 Mdot
.55574 .43332 Mdot
.54784 .62273 Mdot
.48032 .64673 Mdot
.29974 .38718 Mdot
.31037 .68375 Mdot
.53385 .58989 Mdot
.68336 .47499 Mdot
.3041 .56305 Mdot
.60145 .56949 Mdot
.42389 .76865 Mdot
.52828 .76009 Mdot
.46225 .55961 Mdot
.51264 .58213 Mdot
.32592 .39402 Mdot
.69305 .47606 Mdot
.55657 .45153 Mdot
.46832 .29589 Mdot
.53512 .43195 Mdot
.60637 .7186 Mdot
.47703 .22272 Mdot
.30442 .56956 Mdot
.32056 .47946 Mdot
.49023 .62981 Mdot
.33003 .44752 Mdot
.4992 .68311 Mdot
.54432 .3973 Mdot
.31179 .54159 Mdot
.66448 .47368 Mdot
.49341 .27935 Mdot
.71916 .49292 Mdot
.72893 .70406 Mdot
.44701 .77345 Mdot
.82233 .64388 Mdot
.30011 .42116 Mdot
.76427 .54936 Mdot
.70253 .49749 Mdot
.55463 .61528 Mdot
.33826 .8519 Mdot
.68812 .50545 Mdot
.7168 .48914 Mdot
.47997 .39751 Mdot
.33568 .72228 Mdot
.46888 .59133 Mdot
.65643 .48901 Mdot
.29079 .44413 Mdot
.32054 .56141 Mdot
.50043 .59392 Mdot
.47624 .66562 Mdot
.67249 .53472 Mdot
.32306 .40525 Mdot
.29005 .64355 Mdot
.32799 .42534 Mdot
.7011 .48067 Mdot
.31187 .42035 Mdot
.70232 .28209 Mdot
.32715 .38541 Mdot
.51149 .66916 Mdot
.53504 .63533 Mdot
.39482 .23442 Mdot
.67917 .52078 Mdot
.49629 .60228 Mdot
.54351 .64678 Mdot
.70615 .49465 Mdot
.37127 .43928 Mdot
.78913 .56059 Mdot
.48918 .60529 Mdot
.53899 .63723 Mdot
.32733 .54844 Mdot
.51167 .44188 Mdot
.55761 .40652 Mdot
.49847 .59699 Mdot
.29667 .57423 Mdot
.68657 .46817 Mdot
.51806 .63033 Mdot
.30848 .68244 Mdot
.36519 .44531 Mdot
.49878 .5844 Mdot
.6054 .41674 Mdot
.52178 .61577 Mdot
.81548 .38869 Mdot
.54944 .65141 Mdot
.70369 .50583 Mdot
.69771 .48996 Mdot
.332 .49175 Mdot
.67243 .50544 Mdot
.61193 .39342 Mdot
.49889 .31038 Mdot
.79468 .43058 Mdot
.61378 .39575 Mdot
.48995 .66222 Mdot
.50166 .82886 Mdot
.47139 .66024 Mdot
.45668 .66498 Mdot
.31111 .72965 Mdot
.60314 .39168 Mdot
.69621 .50387 Mdot
.62028 .31689 Mdot
.51176 .5757 Mdot
.48029 .31738 Mdot
.45209 .65805 Mdot
.49905 .58408 Mdot
.45133 .70576 Mdot
.61773 .61454 Mdot
.51967 .29692 Mdot
.42928 .60832 Mdot
.50104 .59395 Mdot
.80756 .57899 Mdot
.49257 .63852 Mdot
.33109 .5807 Mdot
.65847 .49695 Mdot
.34893 .44278 Mdot
.31989 .55137 Mdot
.48995 .62377 Mdot
.31078 .57143 Mdot
.32892 .44477 Mdot
.48939 .26902 Mdot
.50488 .66451 Mdot
.3307 .60568 Mdot
.30542 .57447 Mdot
.53586 .60169 Mdot
.6893 .48897 Mdot
.5888 .62505 Mdot
.5182 .6284 Mdot
.56194 .60975 Mdot
.67221 .48391 Mdot
.29989 .77619 Mdot
.55827 .63105 Mdot
.43512 .40365 Mdot
.64605 .47933 Mdot
.61062 .38849 Mdot
.34902 .41849 Mdot
.55118 .58034 Mdot
.48122 .30967 Mdot
.49516 .3096 Mdot
.3221 .46075 Mdot
.65953 .52986 Mdot
.33295 .41361 Mdot
.43909 .6646 Mdot
.49127 .57485 Mdot
.47227 .5975 Mdot
.16967 .54703 Mdot
.65765 .24239 Mdot
.69564 .5185 Mdot
.29307 .41316 Mdot
.53729 .44247 Mdot
.49103 .3198 Mdot
.28798 .40849 Mdot
.70621 .46379 Mdot
.64908 .51769 Mdot
.672 .48207 Mdot
.30103 .57766 Mdot
.33658 .4231 Mdot
.68276 .45889 Mdot
.73191 .4918 Mdot
.5276 .60217 Mdot
.50309 .59242 Mdot
.64356 .53585 Mdot
.36911 .47106 Mdot
.30401 .54491 Mdot
.3169 .39352 Mdot
.77502 .2803 Mdot
.4843 .32015 Mdot
.56851 .77325 Mdot
.495 .59665 Mdot
.13657 .64679 Mdot
.46474 .60534 Mdot
.49579 .64053 Mdot
.64808 .49132 Mdot
.34122 .56688 Mdot
.31809 .56276 Mdot
.70248 .49625 Mdot
.71704 .52682 Mdot
.31331 .58598 Mdot
.46124 .39584 Mdot
.81851 .4551 Mdot
.55015 .44684 Mdot
.70663 .50567 Mdot
.62572 .68579 Mdot
.49224 .26657 Mdot
.65961 .47086 Mdot
.52411 .31647 Mdot
.31918 .44285 Mdot
.34833 .40102 Mdot
.50562 .28108 Mdot
.56077 .62245 Mdot
.30216 .41742 Mdot
.43735 .65561 Mdot
.74916 .34716 Mdot
.46059 .21057 Mdot
.75809 .70379 Mdot
.54095 .6695 Mdot
.5175 .52592 Mdot
.66105 .39567 Mdot
.48476 .63736 Mdot
.42425 .60681 Mdot
.30914 .57404 Mdot
.65015 .47692 Mdot
.4994 .26595 Mdot
.71957 .27152 Mdot
.53252 .63554 Mdot
.7095 .48651 Mdot
.49809 .32063 Mdot
.69633 .283 Mdot
.43372 .44591 Mdot
.52886 .60993 Mdot
.39903 .88779 Mdot
.64214 .50615 Mdot
.34872 .44273 Mdot
.61224 .75281 Mdot
.70162 .46629 Mdot
.237 .41336 Mdot
.32551 .37719 Mdot
.58381 .47822 Mdot
.64624 .50172 Mdot
.29012 .52465 Mdot
.67441 .49265 Mdot
.32009 .59603 Mdot
.72574 .51952 Mdot
.31724 .41195 Mdot
.50802 .63322 Mdot
.31842 .41555 Mdot
.33628 .56952 Mdot
.30383 .43876 Mdot
.49979 .26625 Mdot
.59523 .39323 Mdot
.50192 .3134 Mdot
.51578 .46781 Mdot
.76262 .58686 Mdot
.47648 .27531 Mdot
.43243 .35145 Mdot
.51105 .61485 Mdot
.70701 .54067 Mdot
.34439 .44912 Mdot
.33224 .46881 Mdot
.52326 .43122 Mdot
.69081 .48076 Mdot
.31472 .40782 Mdot
.61573 .69371 Mdot
.1605 .62292 Mdot
.44674 .61799 Mdot
.21479 .36412 Mdot
.70701 .49696 Mdot
.29268 .43324 Mdot
.5582 .44114 Mdot
.69801 .53213 Mdot
.35628 .42227 Mdot
.49265 .27669 Mdot
.47853 .30439 Mdot
.56479 .63582 Mdot
.45611 .29515 Mdot
.30026 .39412 Mdot
.81373 .57305 Mdot
.66203 .49117 Mdot
.63581 .22832 Mdot
.32809 .57968 Mdot
.32353 .44435 Mdot
.46484 .59874 Mdot
.7346 .4699 Mdot
.35882 .43767 Mdot
.4322 .19156 Mdot
.72743 .23975 Mdot
.31421 .40747 Mdot
.65776 .4982 Mdot
.66483 .5096 Mdot
.4382 .63645 Mdot
.53834 .45038 Mdot
.32082 .40335 Mdot
.36706 .27987 Mdot
.31288 .63065 Mdot
.61265 .40576 Mdot
.55773 .8042 Mdot
.53437 .58973 Mdot
.51022 .58208 Mdot
.46678 .29369 Mdot
.5051 .62606 Mdot
.72648 .51173 Mdot
.46707 .60422 Mdot
.46244 .30438 Mdot
.30996 .45138 Mdot
.5296 .63109 Mdot
.31515 .58114 Mdot
.46827 .27507 Mdot
.48185 .33241 Mdot
.31223 .43036 Mdot
.65834 .49168 Mdot
.60453 .32586 Mdot
.32956 .42462 Mdot
.53189 .58496 Mdot
.59954 .39766 Mdot
.47531 .60238 Mdot
.39626 .24128 Mdot
.71727 .50895 Mdot
.35126 .43508 Mdot
.63654 .51749 Mdot
.49719 .29429 Mdot
.31161 .46053 Mdot
.48882 .63736 Mdot
.34964 .40744 Mdot
.42674 .40822 Mdot
.21297 .49467 Mdot
.73037 .50428 Mdot
.34896 .50922 Mdot
.66859 .53536 Mdot
.61284 .40681 Mdot
.35887 .70067 Mdot
.304 .55021 Mdot
.31198 .39159 Mdot
.70143 .27269 Mdot
.34119 .45364 Mdot
.51726 .62199 Mdot
.55378 .63439 Mdot
.34217 .40793 Mdot
.29576 .56219 Mdot
.26637 .65275 Mdot
.33532 .61269 Mdot
.66751 .52549 Mdot
.4278 .48937 Mdot
.8041 .32146 Mdot
.30703 .36833 Mdot
.5113 .29914 Mdot
.48222 .55694 Mdot
.50261 .61051 Mdot
.51358 .31336 Mdot
.47989 .32302 Mdot
.33773 .57543 Mdot
.32609 .44855 Mdot
.65637 .46842 Mdot
.50462 .27348 Mdot
.71672 .45907 Mdot
.29465 .65832 Mdot
.53387 .69146 Mdot
.59832 .65906 Mdot
.50923 .67364 Mdot
.50412 .41962 Mdot
.46173 .29296 Mdot
.52379 .6517 Mdot
.51309 .56401 Mdot
.47975 .28018 Mdot
.33522 .5833 Mdot
.64507 .46074 Mdot
.3094 .41163 Mdot
.14703 .63029 Mdot
.50615 .66509 Mdot
.51189 .6309 Mdot
.46982 .29621 Mdot
.61359 .77618 Mdot
.70186 .51543 Mdot
.65591 .49473 Mdot
.33142 .43882 Mdot
.5282 .39214 Mdot
.5677 .62473 Mdot
.49348 .65228 Mdot
.30428 .41267 Mdot
.59218 .39949 Mdot
.68728 .77892 Mdot
.53481 .6424 Mdot
.48456 .29279 Mdot
.42079 .35966 Mdot
.4619 .28616 Mdot
.52379 .68473 Mdot
.52277 .62115 Mdot
.49541 .66215 Mdot
.55387 .66144 Mdot
.51037 .28442 Mdot
.48751 .64368 Mdot
.57574 .66973 Mdot
.69332 .50735 Mdot
.52156 .58381 Mdot
.3158 .63182 Mdot
.53126 .64086 Mdot
.31573 .58037 Mdot
.55518 .38884 Mdot
.54162 .6594 Mdot
.52073 .58321 Mdot
.31017 .62795 Mdot
.50316 .64232 Mdot
.50511 .31889 Mdot
.6694 .51416 Mdot
.49698 .2922 Mdot
.50874 .30086 Mdot
.3599 .42745 Mdot
.32486 .59822 Mdot
.51413 .5687 Mdot
.31074 .58658 Mdot
.44086 .65794 Mdot
.47919 .67148 Mdot
.51498 .45511 Mdot
.55498 .43226 Mdot
.28847 .5368 Mdot
.49059 .64487 Mdot
.32651 .43897 Mdot
.35236 .42937 Mdot
.37331 .51324 Mdot
.45214 .67143 Mdot
.49718 .26691 Mdot
.49403 .27375 Mdot
.37979 .59069 Mdot
.38522 .5568 Mdot
.30774 .57863 Mdot
.49576 .50208 Mdot
.4918 .67384 Mdot
.54526 .65055 Mdot
.46541 .67051 Mdot
.35246 .39421 Mdot
.59372 .39282 Mdot
.31539 .45327 Mdot
.56971 .3968 Mdot
.47943 .26297 Mdot
.54039 .66965 Mdot
.4809 .19942 Mdot
.6812 .5307 Mdot
.66972 .51518 Mdot
.46336 .30869 Mdot
.29746 .40365 Mdot
.45734 .6744 Mdot
.1478 .47795 Mdot
.71283 .52476 Mdot
.29887 .5329 Mdot
.5071 .65803 Mdot
.31554 .43575 Mdot
.6636 .52819 Mdot
.31217 .60031 Mdot
.53081 .67442 Mdot
.30108 .38042 Mdot
.52125 .64598 Mdot
.66573 .68402 Mdot
.69431 .49865 Mdot
.56991 .49178 Mdot
.66896 .54589 Mdot
.51311 .30326 Mdot
.49067 .28234 Mdot
.53059 .62319 Mdot
.14078 .54786 Mdot
.62246 .49906 Mdot
.51441 .31825 Mdot
.30508 .59399 Mdot
.58973 .3956 Mdot
.30989 .5976 Mdot
.34492 .42021 Mdot
.30329 .56405 Mdot
.35774 .441 Mdot
.37535 .461 Mdot
.62743 .5009 Mdot
.32615 .55479 Mdot
.61408 .78148 Mdot
.4958 .57372 Mdot
.33783 .56815 Mdot
.47674 .59174 Mdot
.4442 .68942 Mdot
.30434 .4234 Mdot
.30231 .57704 Mdot
.54337 .60971 Mdot
.58871 .19917 Mdot
.50205 .28867 Mdot
.50021 .26745 Mdot
.49896 .57389 Mdot
.29064 .43062 Mdot
.72774 .51394 Mdot
.47931 .42784 Mdot
.60383 .38668 Mdot
.49422 .65255 Mdot
.51685 .67832 Mdot
.64009 .51646 Mdot
.70634 .4752 Mdot
.53003 .62186 Mdot
.62 .67096 Mdot
.48934 .62876 Mdot
.47701 .30071 Mdot
.67088 .5275 Mdot
.66621 .51352 Mdot
.30797 .38802 Mdot
.66191 .53078 Mdot
.58823 .58943 Mdot
.46029 .32771 Mdot
.46046 .63542 Mdot
.49538 .29618 Mdot
.37861 .48081 Mdot
.32122 .45093 Mdot
.6984 .26676 Mdot
.65775 .52729 Mdot
.48394 .60602 Mdot
.69703 .52876 Mdot
.32977 .57138 Mdot
.67647 .52138 Mdot
.65382 .53819 Mdot
.55253 .65475 Mdot
.53974 .61614 Mdot
.59475 .40017 Mdot
.53245 .443 Mdot
.68923 .49592 Mdot
.48549 .61808 Mdot
.47623 .60703 Mdot
.55651 .62666 Mdot
.49999 .44255 Mdot
.65475 .48305 Mdot
.55312 .76421 Mdot
.42267 .22893 Mdot
.68696 .4914 Mdot
.77092 .30639 Mdot
.59044 .41166 Mdot
.6193 .40924 Mdot
.50527 .3348 Mdot
.53948 .63957 Mdot
.32871 .41338 Mdot
.50643 .58186 Mdot
.44867 .66954 Mdot
.53699 .66362 Mdot
.32404 .54863 Mdot
.56631 .60743 Mdot
.60241 .41288 Mdot
.32454 .42337 Mdot
.48796 .61515 Mdot
.53667 .63115 Mdot
.6135 .41617 Mdot
.65356 .54239 Mdot
.64997 .51835 Mdot
.61677 .43436 Mdot
.3347 .58046 Mdot
.4671 .28315 Mdot
.519 .58076 Mdot
.32888 .43846 Mdot
.32316 .41615 Mdot
.7184 .49172 Mdot
.30975 .40361 Mdot
.46457 .28744 Mdot
.49394 .63479 Mdot
.51341 .30102 Mdot
.32432 .54902 Mdot
.65888 .49629 Mdot
.53184 .58371 Mdot
.53113 .60366 Mdot
.69777 .4902 Mdot
.51502 .61401 Mdot
.32276 .54511 Mdot
.34572 .39109 Mdot
.68267 .52413 Mdot
.49824 .30963 Mdot
.31186 .38537 Mdot
.5107 .60204 Mdot
.60763 .15951 Mdot
.50464 .62531 Mdot
.49688 .65906 Mdot
.78207 .41312 Mdot
.47185 .62634 Mdot
.33256 .45351 Mdot
.69154 .53222 Mdot
.53352 .68185 Mdot
.30863 .63062 Mdot
.2578 .55127 Mdot
.31534 .37118 Mdot
.50535 .6586 Mdot
.75537 .30574 Mdot
.48613 .60195 Mdot
.72157 .29819 Mdot
.51594 .45553 Mdot
.32209 .24542 Mdot
.5964 .66283 Mdot
.51364 .31944 Mdot
.59338 .398 Mdot
.33215 .45629 Mdot
.679 .73092 Mdot
.50939 .61882 Mdot
.78029 .62557 Mdot
.51957 .57967 Mdot
.47944 .29785 Mdot
.44866 .57846 Mdot
.31486 .39515 Mdot
.5477 .8 Mdot
.55577 .60466 Mdot
.64691 .49541 Mdot
.31179 .46394 Mdot
.58812 .40126 Mdot
.54706 .61276 Mdot
.32187 .58633 Mdot
.26842 .55182 Mdot
.58744 .59147 Mdot
.49724 .29813 Mdot
.54224 .65013 Mdot
.44639 .59103 Mdot
.16716 .6158 Mdot
.69252 .5117 Mdot
.50589 .28854 Mdot
.42948 .55293 Mdot
.55439 .63103 Mdot
.6487 .51563 Mdot
.67137 .51237 Mdot
.32019 .592 Mdot
.54573 .36561 Mdot
.2461 .55458 Mdot
.49203 .17814 Mdot
.76117 .66035 Mdot
.34721 .389 Mdot
.72669 .44551 Mdot
.51823 .58769 Mdot
.45095 .77662 Mdot
.50806 .30547 Mdot
.5099 .63329 Mdot
.7459 .65324 Mdot
.68702 .51565 Mdot
.52628 .64702 Mdot
.30589 .54456 Mdot
.63416 .358 Mdot
.58698 .71685 Mdot
.6432 .19019 Mdot
.28752 .43454 Mdot
.45138 .62969 Mdot
.59431 .60609 Mdot
.60983 .3884 Mdot
.52462 .68384 Mdot
.33959 .45163 Mdot
.40316 .29386 Mdot
.29638 .54705 Mdot
.67757 .53071 Mdot
.58853 .40875 Mdot
.51236 .57842 Mdot
.47256 .64925 Mdot
.29553 .53623 Mdot
.55126 .60945 Mdot
.60374 .75095 Mdot
.61233 .42048 Mdot
.32914 .38573 Mdot
.65532 .48748 Mdot
.50841 .67425 Mdot
.59119 .39614 Mdot
.55493 .64933 Mdot
.412 .65499 Mdot
.51293 .66087 Mdot
.78661 .44512 Mdot
.69023 .48654 Mdot
.50108 .30233 Mdot
.56468 .60199 Mdot
.52362 .63915 Mdot
.24942 .44159 Mdot
.45494 .67415 Mdot
.55039 .64838 Mdot
.71698 .4813 Mdot
.68713 .53079 Mdot
.70895 .48265 Mdot
.31653 .38589 Mdot
.55082 .45389 Mdot
.4853 .30335 Mdot
.46343 .67289 Mdot
.49891 .26919 Mdot
.57448 .68871 Mdot
.29126 .55384 Mdot
.67685 .24133 Mdot
.49631 .62298 Mdot
.68299 .47969 Mdot
.8012 .5114 Mdot
.68981 .46775 Mdot
.49461 .23883 Mdot
.50566 .30516 Mdot
.68752 .50256 Mdot
.50204 .64639 Mdot
.54618 .4643 Mdot
.59595 .1658 Mdot
.49316 .31935 Mdot
.45616 .65816 Mdot
.28708 .43529 Mdot
.33593 .46579 Mdot
.79932 .35481 Mdot
.50986 .31308 Mdot
.65819 .39451 Mdot
.48659 .60669 Mdot
.67627 .53256 Mdot
.47504 .27333 Mdot
.50261 .32336 Mdot
.30614 .40692 Mdot
.52673 .60756 Mdot
.52386 .64108 Mdot
.60223 .41753 Mdot
.49532 .27005 Mdot
.5017 .70226 Mdot
.52567 .6112 Mdot
.76139 .38032 Mdot
.70107 .46227 Mdot
.3085 .78445 Mdot
.42943 .64749 Mdot
.75244 .64511 Mdot
.40309 .46598 Mdot
.6886 .52399 Mdot
.56059 .61372 Mdot
.46078 .67218 Mdot
.33515 .38292 Mdot
.49646 .6313 Mdot
.29486 .42575 Mdot
.51199 .30898 Mdot
.68572 .24351 Mdot
.44495 .36219 Mdot
.46167 .33403 Mdot
.50911 .62486 Mdot
.58721 .71313 Mdot
.326 .55851 Mdot
.48277 .25438 Mdot
.71243 .49981 Mdot
.49497 .6723 Mdot
.35034 .38942 Mdot
.31889 .38664 Mdot
.67834 .51256 Mdot
.69518 .41185 Mdot
.70681 .2788 Mdot
.54902 .66672 Mdot
.34761 .41964 Mdot
.43983 .32272 Mdot
.63623 .59908 Mdot
.49639 .33616 Mdot
.29798 .54321 Mdot
.32861 .45348 Mdot
.45781 .27704 Mdot
.44618 .69261 Mdot
.67934 .50382 Mdot
.64167 .51503 Mdot
.25509 .41549 Mdot
.31926 .4071 Mdot
.31466 .55334 Mdot
.39389 .5046 Mdot
.39851 .50537 Mdot
.31022 .54164 Mdot
.29958 .44291 Mdot
.68848 .5271 Mdot
.70693 .48418 Mdot
.66871 .51262 Mdot
.57553 .77501 Mdot
.71289 .51822 Mdot
.38179 .79574 Mdot
.50666 .67993 Mdot
.63216 .65699 Mdot
.48191 .62769 Mdot
.51334 .28257 Mdot
.69454 .49701 Mdot
.52408 .46151 Mdot
.48196 .65881 Mdot
.62194 .1815 Mdot
.51544 .65658 Mdot
.42856 .38126 Mdot
.54007 .63829 Mdot
.62775 .7305 Mdot
.64816 .47725 Mdot
.48884 .64187 Mdot
.4762 .34048 Mdot
.31324 .57585 Mdot
.62431 .51779 Mdot
.54862 .6494 Mdot
.71936 .38642 Mdot
.47725 .59174 Mdot
.74926 .3203 Mdot
.21871 .42016 Mdot
.31512 .53155 Mdot
.46835 .61675 Mdot
.35925 .44599 Mdot
.47931 .55032 Mdot
.63455 .67173 Mdot
.49419 .31908 Mdot
.59819 .70641 Mdot
.30606 .40181 Mdot
.42376 .60949 Mdot
.55661 .68086 Mdot
.29449 .55532 Mdot
.62812 .47774 Mdot
.47534 .29761 Mdot
.50785 .61745 Mdot
.55986 .61582 Mdot
.39897 .21008 Mdot
.63219 .68678 Mdot
.54568 .69428 Mdot
.28967 .54726 Mdot
.59707 .71585 Mdot
.53742 .66085 Mdot
.31502 .37162 Mdot
.6906 .53414 Mdot
.53401 .55727 Mdot
.54118 .77638 Mdot
.48646 .62124 Mdot
.68581 .5063 Mdot
.65629 .52708 Mdot
.81672 .51652 Mdot
.2919 .55957 Mdot
.51391 .66085 Mdot
.2475 .41248 Mdot
.53235 .58481 Mdot
.48172 .30299 Mdot
.51473 .68612 Mdot
.31326 .44219 Mdot
.56348 .44243 Mdot
.31474 .38657 Mdot
.55182 .6198 Mdot
.66955 .49258 Mdot
.47178 .29469 Mdot
.29913 .29654 Mdot
.5169 .3698 Mdot
.37726 .79276 Mdot
.26822 .55692 Mdot
.31396 .58388 Mdot
.31735 .60033 Mdot
.46104 .25235 Mdot
.5026 .65373 Mdot
.49603 .41553 Mdot
.44374 .64515 Mdot
.54517 .6381 Mdot
.51917 .66596 Mdot
.48275 .36187 Mdot
.50469 .30496 Mdot
.31361 .41663 Mdot
.52845 .62117 Mdot
.4851 .61897 Mdot
.6818 .49374 Mdot
.3051 .57453 Mdot
.34353 .39123 Mdot
.3343 .57587 Mdot
.32431 .42879 Mdot
.81473 .37994 Mdot
.50044 .68524 Mdot
.31463 .57532 Mdot
.46213 .28105 Mdot
.69838 .47747 Mdot
.61556 .41282 Mdot
.34396 .41975 Mdot
.31593 .39585 Mdot
.48663 .64234 Mdot
.65308 .50491 Mdot
.65 .51119 Mdot
.31285 .5854 Mdot
.48944 .27244 Mdot
.56511 .64993 Mdot
.53393 .61424 Mdot
.27316 .31469 Mdot
.33092 .38201 Mdot
.60722 .70599 Mdot
.78179 .46086 Mdot
.50016 .65278 Mdot
.6482 .50873 Mdot
.52459 .63186 Mdot
.43394 .26765 Mdot
.70617 .47737 Mdot
.47566 .62971 Mdot
.47202 .71394 Mdot
.35273 .39514 Mdot
.8316 .57323 Mdot
.52615 .57217 Mdot
.53015 .3344 Mdot
.53054 .59471 Mdot
.85127 .59986 Mdot
.80002 .52232 Mdot
.52107 .57922 Mdot
.55433 .65964 Mdot
.49557 .16828 Mdot
.49065 .5971 Mdot
.60026 .41526 Mdot
.44948 .67251 Mdot
.64783 .51462 Mdot
.42906 .43871 Mdot
.51367 .42454 Mdot
.2989 .58246 Mdot
.33138 .4397 Mdot
.32597 .70336 Mdot
.32857 .59241 Mdot
.70512 .50305 Mdot
.47449 .65567 Mdot
.77051 .49686 Mdot
.35843 .46271 Mdot
.55913 .67068 Mdot
.48068 .30145 Mdot
.51445 .42388 Mdot
.31789 .45315 Mdot
.49994 .31018 Mdot
.48124 .6043 Mdot
.17638 .4793 Mdot
.53794 .28884 Mdot
.82735 .5107 Mdot
.46819 .29036 Mdot
.50191 .29222 Mdot
.55618 .46931 Mdot
.29944 .5832 Mdot
.37162 .23784 Mdot
.58669 .56421 Mdot
.48633 .32018 Mdot
.38672 .68221 Mdot
.30839 .38047 Mdot
.54023 .39786 Mdot
.65573 .47222 Mdot
.50049 .68599 Mdot
.50688 .64621 Mdot
.48269 .27597 Mdot
.75096 .46334 Mdot
.40764 .54904 Mdot
.50011 .31626 Mdot
.59293 .60924 Mdot
.54289 .39068 Mdot
.59861 .39506 Mdot
.59316 .41606 Mdot
.30005 .58862 Mdot
.2197 .54018 Mdot
.68548 .48401 Mdot
.30681 .53281 Mdot
.59459 .50635 Mdot
.52218 .65923 Mdot
.49759 .27041 Mdot
.59949 .42057 Mdot
.49382 .3081 Mdot
.31962 .56775 Mdot
.29348 .5437 Mdot
.69327 .50822 Mdot
.70237 .51614 Mdot
.64419 .57064 Mdot
.37725 .61628 Mdot
.50388 .58585 Mdot
.78956 .57097 Mdot
.70929 .47933 Mdot
.64877 .75576 Mdot
.30495 .58523 Mdot
.29912 .56349 Mdot
.66719 .63073 Mdot
.51863 .60136 Mdot
.42296 .36644 Mdot
.54323 .65737 Mdot
.37797 .70673 Mdot
.50305 .57809 Mdot
.30687 .40738 Mdot
.54593 .59575 Mdot
.5972 .31194 Mdot
.49229 .61048 Mdot
.52544 .66778 Mdot
.33993 .42128 Mdot
.57265 .61727 Mdot
.30902 .4385 Mdot
.5586 .63215 Mdot
.34255 .57432 Mdot
.32913 .43816 Mdot
.34647 .59365 Mdot
.44161 .40973 Mdot
.59472 .4053 Mdot
.30958 .59576 Mdot
.32203 .58472 Mdot
.28724 .63815 Mdot
.70963 .51093 Mdot
.42975 .68366 Mdot
.50573 .65435 Mdot
.29161 .40047 Mdot
.47236 .27057 Mdot
.48625 .62351 Mdot
.46453 .60737 Mdot
.52729 .57134 Mdot
.69041 .50708 Mdot
.29547 .43694 Mdot
.31371 .56916 Mdot
.35288 .42437 Mdot
.34202 .59141 Mdot
.34567 .4574 Mdot
.46803 .57783 Mdot
.44174 .66911 Mdot
.58055 .66253 Mdot
.76973 .61919 Mdot
.50275 .82215 Mdot
.67723 .50764 Mdot
.60531 .40089 Mdot
.29084 .55539 Mdot
.4239 .49371 Mdot
.67795 .48248 Mdot
.31821 .39664 Mdot
.52098 .64605 Mdot
.59419 .61741 Mdot
.60073 .58785 Mdot
.71504 .46242 Mdot
.36624 .59026 Mdot
.34064 .43464 Mdot
.61216 .3976 Mdot
.54879 .44007 Mdot
.70169 .54973 Mdot
.51959 .46696 Mdot
.52483 .63538 Mdot
.31683 .58754 Mdot
.66381 .52826 Mdot
.38061 .25008 Mdot
.48834 .27618 Mdot
.53569 .44678 Mdot
.50716 .62619 Mdot
.67172 .42355 Mdot
.66923 .4932 Mdot
.29818 .55141 Mdot
.48196 .27655 Mdot
.29518 .57284 Mdot
.58507 .40334 Mdot
.58848 .42896 Mdot
.54738 .6093 Mdot
.55027 .65022 Mdot
.47971 .26346 Mdot
.68275 .48465 Mdot
.29249 .51624 Mdot
.4133 .20723 Mdot
.34466 .41534 Mdot
.50758 .3939 Mdot
.66875 .52842 Mdot
.64787 .41809 Mdot
.34756 .40695 Mdot
.46156 .27284 Mdot
.49872 .41887 Mdot
.46581 .31272 Mdot
.53016 .66503 Mdot
.65899 .51021 Mdot
.5098 .31421 Mdot
.28282 .31802 Mdot
.78515 .36656 Mdot
.65113 .46132 Mdot
.52853 .61782 Mdot
.67683 .23945 Mdot
.6916 .36442 Mdot
.67904 .44388 Mdot
.50804 .27823 Mdot
.52464 .62492 Mdot
.54561 .66933 Mdot
.55444 .60298 Mdot
.49929 .28377 Mdot
.52412 .35389 Mdot
.32282 .39109 Mdot
.5267 .65208 Mdot
.32838 .57851 Mdot
.31069 .43611 Mdot
.35275 .46032 Mdot
.33399 .45594 Mdot
.7087 .47776 Mdot
.48323 .67122 Mdot
.57463 .51684 Mdot
.84816 .53158 Mdot
.50237 .29726 Mdot
.59495 .40561 Mdot
.50095 .66413 Mdot
.33302 .75288 Mdot
.70462 .48015 Mdot
.34094 .4113 Mdot
.51152 .63238 Mdot
.22775 .42007 Mdot
.60731 .42413 Mdot
.33455 .42512 Mdot
.71214 .4982 Mdot
.67546 .44424 Mdot
.49564 .63111 Mdot
.52689 .59405 Mdot
.70316 .48697 Mdot
.66707 .369 Mdot
.5496 .43104 Mdot
.52754 .63205 Mdot
.50158 .30578 Mdot
.14806 .60044 Mdot
.47364 .61834 Mdot
.7446 .47997 Mdot
.59225 .39229 Mdot
.77234 .43585 Mdot
.61233 .68812 Mdot
.45312 .60755 Mdot
.6116 .19555 Mdot
.31042 .71136 Mdot
.70542 .25494 Mdot
.37943 .72688 Mdot
.47856 .21705 Mdot
.8283 .42951 Mdot
.47763 .33996 Mdot
.63528 .7211 Mdot
.40488 .18536 Mdot
.66959 .3935 Mdot
.1998 .46663 Mdot
.32363 .29428 Mdot
.22471 .39649 Mdot
.61235 .80639 Mdot
.34738 .45866 Mdot
.40883 .73717 Mdot
.56354 .6259 Mdot
.66923 .35726 Mdot
.60519 .73053 Mdot
.46228 .8281 Mdot
.678 .24577 Mdot
.24214 .41461 Mdot
.57284 .14806 Mdot
.68799 .26473 Mdot
.71713 .55819 Mdot
.49412 .76127 Mdot
.23021 .55764 Mdot
.39495 .50801 Mdot
.32741 .71223 Mdot
.57497 .71379 Mdot
.59718 .29615 Mdot
.48942 .34648 Mdot
.74073 .57557 Mdot
.18408 .64645 Mdot
.34412 .44404 Mdot
.69014 .5347 Mdot
.36091 .24064 Mdot
.75606 .52707 Mdot
.49387 .23331 Mdot
.61164 .19537 Mdot
.76958 .38553 Mdot
.62675 .7288 Mdot
.57795 .49566 Mdot
.67454 .67099 Mdot
.25496 .64729 Mdot
.47609 .76685 Mdot
.73711 .48678 Mdot
.32102 .32336 Mdot
.39768 .50802 Mdot
.24867 .59215 Mdot
.63118 .74217 Mdot
.31267 .60158 Mdot
.34273 .60369 Mdot
.7124 .49171 Mdot
.64196 .59025 Mdot
.6214 .4086 Mdot
.59844 .51203 Mdot
.35097 .38841 Mdot
.42796 .28392 Mdot
.63716 .35392 Mdot
.69547 .3849 Mdot
.80234 .64115 Mdot
.64902 .18227 Mdot
.33721 .65471 Mdot
.39954 .27185 Mdot
.51886 .25696 Mdot
.30994 .69406 Mdot
.55364 .50374 Mdot
.36507 .64306 Mdot
.41849 .67686 Mdot
.49682 .13207 Mdot
.72988 .38254 Mdot
.5565 .13663 Mdot
.71945 .52887 Mdot
.54716 .57052 Mdot
.41209 .2714 Mdot
.74489 .68391 Mdot
.29533 .62119 Mdot
.65043 .18739 Mdot
.30853 .52621 Mdot
.64159 .48191 Mdot
.66937 .39596 Mdot
.60122 .74813 Mdot
.29714 .51029 Mdot
.2903 .58934 Mdot
.53422 .55812 Mdot
.48511 .11888 Mdot
.59807 .18923 Mdot
.80508 .48731 Mdot
.75906 .38231 Mdot
.31706 .36375 Mdot
.35767 .45529 Mdot
.51002 .31954 Mdot
.80074 .39258 Mdot
.66286 .50101 Mdot
.85128 .53526 Mdot
.78908 .38545 Mdot
.45955 .55788 Mdot
.47101 .12252 Mdot
.68397 .77632 Mdot
.62901 .65892 Mdot
.4405 .79364 Mdot
.19699 .41244 Mdot
.5437 .49625 Mdot
.64012 .40792 Mdot
.28804 .38937 Mdot
.78965 .4285 Mdot
.79352 .36014 Mdot
.39595 .68819 Mdot
.5035 .20836 Mdot
.60105 .51924 Mdot
.37479 .49207 Mdot
.63546 .47798 Mdot
.19368 .49491 Mdot
.38544 .59789 Mdot
.56843 .14213 Mdot
.59195 .7217 Mdot
.15202 .54079 Mdot
.36567 .71581 Mdot
.60921 .77725 Mdot
.60554 .20787 Mdot
.3618 .38229 Mdot
.39943 .60133 Mdot
.7205 .40056 Mdot
.45519 .64433 Mdot
.50466 .50129 Mdot
.41607 .63393 Mdot
.3317 .51823 Mdot
.5551 .45816 Mdot
.70817 .32648 Mdot
.34948 .70196 Mdot
.45935 .20459 Mdot
.49896 .75733 Mdot
.66813 .47659 Mdot
.35506 .63659 Mdot
.36058 .67938 Mdot
.74658 .36831 Mdot
.431 .5527 Mdot
.80949 .47071 Mdot
.42392 .54873 Mdot
.44605 .63108 Mdot
.64127 .71528 Mdot
.56752 .71692 Mdot
.37478 .67071 Mdot
.52243 .57326 Mdot
.81127 .61917 Mdot
.77028 .40346 Mdot
.75722 .6106 Mdot
.33004 .68706 Mdot
.76732 .61503 Mdot
.79467 .42973 Mdot
.41601 .26198 Mdot
.63777 .3962 Mdot
.72779 .44973 Mdot
.49032 .12099 Mdot
.30929 .42362 Mdot
.38477 .66794 Mdot
.51681 .34692 Mdot
.28783 .31327 Mdot
.38024 .20962 Mdot
.41479 .54743 Mdot
.80158 .42487 Mdot
.68703 .39278 Mdot
.34453 .47792 Mdot
.5802 .26886 Mdot
.46255 .35349 Mdot
.77757 .57717 Mdot
.52217 .56733 Mdot
.41047 .61443 Mdot
.32083 .54325 Mdot
.70499 .7109 Mdot
.41382 .23828 Mdot
.29069 .47951 Mdot
.46585 .58693 Mdot
.26911 .42559 Mdot
.61421 .40472 Mdot
.52537 .42054 Mdot
.81393 .36988 Mdot
.43211 .61822 Mdot
.66137 .78652 Mdot
.68595 .37499 Mdot
.50484 .41569 Mdot
.26684 .61721 Mdot
.76306 .45618 Mdot
.53716 .12867 Mdot
.8065 .4182 Mdot
.68406 .34456 Mdot
.66822 .23178 Mdot
.72671 .76991 Mdot
.33884 .22609 Mdot
.73681 .70817 Mdot
.51596 .34741 Mdot
.52229 .91019 Mdot
.35172 .41563 Mdot
.47493 .79437 Mdot
.74171 .68517 Mdot
.23285 .43699 Mdot
.75902 .5235 Mdot
.56118 .7322 Mdot
.2722 .59156 Mdot
.65353 .54046 Mdot
.4878 .57224 Mdot
.69785 .22619 Mdot
.50587 .12732 Mdot
.68416 .21368 Mdot
.57414 .42212 Mdot
.71423 .25386 Mdot
.48675 .155 Mdot
.38748 .79921 Mdot
.38908 .21682 Mdot
.51759 .68585 Mdot
.39299 .65778 Mdot
.70542 .75708 Mdot
.27919 .54672 Mdot
.58527 .51655 Mdot
.73505 .47857 Mdot
.47636 .14515 Mdot
.81434 .36726 Mdot
.6876 .628 Mdot
.67583 .57677 Mdot
.42048 .42303 Mdot
.37494 .64256 Mdot
.76913 .51583 Mdot
.60268 .28155 Mdot
.75358 .35178 Mdot
.47474 .15779 Mdot
.35878 .68785 Mdot
.32198 .30093 Mdot
.67467 .33307 Mdot
.7212 .73598 Mdot
.60409 .20356 Mdot
.35454 .24106 Mdot
.43305 .56911 Mdot
.62325 .5399 Mdot
.4085 .55022 Mdot
.59154 .28703 Mdot
.41289 .33233 Mdot
.31936 .66322 Mdot
.30251 .4369 Mdot
.39376 .67829 Mdot
.47259 .46907 Mdot
.38676 .21749 Mdot
.30456 .67033 Mdot
.40242 .69827 Mdot
.70121 .3383 Mdot
.7001 .23327 Mdot
.68559 .37767 Mdot
.18011 .43236 Mdot
.63593 .23894 Mdot
.41921 .61371 Mdot
.57015 .60029 Mdot
.79802 .42595 Mdot
.7599 .27411 Mdot
.80247 .42344 Mdot
.68176 .42748 Mdot
.2527 .39565 Mdot
.45646 .29555 Mdot
.29713 .67497 Mdot
.30209 .48146 Mdot
.76089 .35048 Mdot
.44724 .4841 Mdot
.45642 .27249 Mdot
.63458 .36074 Mdot
.65026 .5692 Mdot
.32684 .73303 Mdot
.72144 .58239 Mdot
.50141 .69318 Mdot
.63434 .61637 Mdot
.64091 .5228 Mdot
.67401 .42687 Mdot
.36979 .64814 Mdot
.31163 .43022 Mdot
.26129 .32204 Mdot
.75203 .48278 Mdot
.51704 .56418 Mdot
.40336 .30489 Mdot
.63489 .47711 Mdot
.76511 .63409 Mdot
.3296 .47487 Mdot
.82078 .40952 Mdot
.79334 .64703 Mdot
.77174 .51267 Mdot
.34526 .64417 Mdot
.27101 .32485 Mdot
.53788 .41999 Mdot
.52188 .33649 Mdot
.67785 .24923 Mdot
.45358 .4124 Mdot
.35484 .64487 Mdot
.62914 .6289 Mdot
.41246 .21658 Mdot
.44876 .65755 Mdot
.80464 .50198 Mdot
.37173 .78466 Mdot
.52493 .40921 Mdot
.75594 .51187 Mdot
.71405 .52121 Mdot
.54052 .83503 Mdot
.60921 .31014 Mdot
.53226 .52964 Mdot
.63731 .21743 Mdot
.49667 .33121 Mdot
.68975 .47315 Mdot
.41069 .70321 Mdot
.21682 .49139 Mdot
.62213 .59559 Mdot
.41897 .32881 Mdot
.73049 .54987 Mdot
.45051 .38513 Mdot
.65578 .22346 Mdot
.57569 .16948 Mdot
.15194 .59364 Mdot
.69448 .5408 Mdot
.38596 .25666 Mdot
.37988 .26016 Mdot
.73152 .48038 Mdot
.72985 .46815 Mdot
.58391 .71944 Mdot
.74824 .28123 Mdot
.43262 .47544 Mdot
.59271 .26873 Mdot
.49912 .41572 Mdot
.20124 .4773 Mdot
.39428 .22702 Mdot
.31677 .68928 Mdot
.5665 .19423 Mdot
.69385 .58243 Mdot
.22163 .33413 Mdot
.56471 .68896 Mdot
.4804 .79542 Mdot
.29678 .6749 Mdot
.46443 .74319 Mdot
.63628 .73866 Mdot
.72518 .31772 Mdot
.52349 .58273 Mdot
.67123 .19572 Mdot
.72778 .36201 Mdot
.49417 .50756 Mdot
.34042 .36504 Mdot
.50147 .5996 Mdot
.48745 .6738 Mdot
.78262 .49515 Mdot
.77639 .44832 Mdot
.28582 .25609 Mdot
.37182 .71355 Mdot
.42844 .58963 Mdot
.6261 .64956 Mdot
.66225 .78575 Mdot
.41706 .2831 Mdot
.73368 .29406 Mdot
.46994 .47945 Mdot
.72288 .74149 Mdot
.57652 .23364 Mdot
.58149 .28985 Mdot
.62802 .22886 Mdot
.49345 .15451 Mdot
.50627 .55176 Mdot
.74883 .42864 Mdot
.36221 .24758 Mdot
.5031 .66449 Mdot
.69633 .41212 Mdot
.63962 .22388 Mdot
.18552 .57731 Mdot
.54271 .51067 Mdot
.75161 .26039 Mdot
.48252 .7043 Mdot
.74205 .41582 Mdot
.39176 .1914 Mdot
.15577 .4057 Mdot
.58874 .30453 Mdot
.57735 .14643 Mdot
.57469 .27432 Mdot
.62292 .20806 Mdot
.51139 .32408 Mdot
.44378 .44561 Mdot
.7895 .59295 Mdot
.7541 .28744 Mdot
.23487 .51123 Mdot
.47215 .21164 Mdot
.79987 .55499 Mdot
.74464 .27136 Mdot
.46976 .70723 Mdot
.54262 .82992 Mdot
.36765 .40665 Mdot
.73012 .74594 Mdot
.76758 .67755 Mdot
.71729 .54761 Mdot
.38858 .69101 Mdot
.53967 .82218 Mdot
.43861 .81853 Mdot
.76167 .67953 Mdot
.43482 .72006 Mdot
.77199 .45849 Mdot
.33731 .64344 Mdot
.76882 .35523 Mdot
.5976 .81129 Mdot
.39177 .23848 Mdot
.58886 .37233 Mdot
.57876 .42069 Mdot
.7853 .45568 Mdot
.67935 .30579 Mdot
.40804 .29275 Mdot
.55741 .41459 Mdot
.7099 .55769 Mdot
.18556 .69863 Mdot
.55554 .2478 Mdot
.61131 .63159 Mdot
.5264 .13391 Mdot
.75125 .35426 Mdot
.43563 .48612 Mdot
.62327 .75055 Mdot
.33317 .74278 Mdot
.37827 .44112 Mdot
.53848 .66256 Mdot
.73779 .26565 Mdot
.36065 .47146 Mdot
.60039 .16425 Mdot
.83198 .51102 Mdot
.65609 .59705 Mdot
.46485 .57423 Mdot
.28286 .40512 Mdot
.4928 .77227 Mdot
.43747 .72892 Mdot
.5257 .14249 Mdot
.48425 .79365 Mdot
.49145 .39751 Mdot
.43743 .37947 Mdot
.43753 .35384 Mdot
.5139 .53974 Mdot
.70869 .75713 Mdot
.76702 .44905 Mdot
.33925 .70646 Mdot
.66552 .33519 Mdot
.37986 .66681 Mdot
.61201 .69134 Mdot
.2932 .6659 Mdot
.45848 .52291 Mdot
.26545 .59454 Mdot
.3185 .38011 Mdot
.47923 .17933 Mdot
.68323 .26916 Mdot
.81607 .60138 Mdot
.18367 .4286 Mdot
.72078 .40354 Mdot
.42308 .74569 Mdot
.43512 .21944 Mdot
.53049 .50591 Mdot
.23654 .53394 Mdot
.3527 .73362 Mdot
.59722 .71038 Mdot
.73164 .3074 Mdot
.50562 .75198 Mdot
.79766 .36206 Mdot
.31928 .66707 Mdot
.44069 .188 Mdot
.41809 .42976 Mdot
.72045 .68799 Mdot
.6454 .66399 Mdot
.20438 .39367 Mdot
.52271 .41065 Mdot
.48573 .11995 Mdot
.68167 .4679 Mdot
.64393 .17964 Mdot
.46689 .29069 Mdot
.18294 .61929 Mdot
.74253 .33026 Mdot
.49858 .48669 Mdot
.49009 .44491 Mdot
.81016 .51154 Mdot
.67856 .37836 Mdot
.69541 .37709 Mdot
.4105 .55284 Mdot
.32521 .45975 Mdot
.49924 .38426 Mdot
.59744 .2681 Mdot
.4862 .18618 Mdot
.55871 .6602 Mdot
.32652 .49159 Mdot
.46296 .75426 Mdot
.52979 .31933 Mdot
.77571 .41202 Mdot
.7125 .29356 Mdot
.58974 .6874 Mdot
.37398 .63817 Mdot
.48893 .14899 Mdot
.77025 .37282 Mdot
.40815 .5383 Mdot
.42202 .65609 Mdot
.52296 .25492 Mdot
.29789 .26576 Mdot
.57264 .1827 Mdot
.43958 .36651 Mdot
.54859 .42146 Mdot
.33898 .65701 Mdot
.75805 .25199 Mdot
.50109 .1296 Mdot
.19695 .37852 Mdot
.49791 .41278 Mdot
.69505 .54648 Mdot
.34469 .75311 Mdot
.44364 .18803 Mdot
.74295 .73566 Mdot
.70236 .35349 Mdot
.384 .67221 Mdot
.18053 .55397 Mdot
.5093 .81392 Mdot
.475 .40015 Mdot
.64626 .66455 Mdot
.76735 .64341 Mdot
.49523 .24183 Mdot
.379 .44793 Mdot
.47336 .42372 Mdot
.50143 .23212 Mdot
.77153 .45701 Mdot
.67811 .38119 Mdot
.43853 .18755 Mdot
.49661 .79717 Mdot
.42371 .66056 Mdot
.47256 .20265 Mdot
.63724 .48181 Mdot
.37737 .25595 Mdot
.28053 .30231 Mdot
.47839 .41232 Mdot
.35529 .43364 Mdot
.60195 .61003 Mdot
.53416 .38675 Mdot
.57253 .25736 Mdot
.17515 .51424 Mdot
.3389 .56024 Mdot
.73917 .50373 Mdot
.5235 .81419 Mdot
.70494 .53661 Mdot
.80097 .31515 Mdot
.60488 .28062 Mdot
.63086 .63343 Mdot
.56189 .22209 Mdot
.33714 .30521 Mdot
.16358 .46138 Mdot
.70396 .5635 Mdot
.30837 .62876 Mdot
.72737 .52351 Mdot
.647 .52698 Mdot
.57227 .21653 Mdot
.62784 .41891 Mdot
.65658 .58116 Mdot
.63508 .79759 Mdot
.26883 .32742 Mdot
.72093 .52089 Mdot
.43582 .38553 Mdot
.66126 .45231 Mdot
.817 .37582 Mdot
.35306 .43483 Mdot
.49745 .1207 Mdot
.43034 .6527 Mdot
.28893 .26998 Mdot
.78887 .41929 Mdot
.5672 .44796 Mdot
.49755 .4056 Mdot
.29195 .32079 Mdot
.44686 .6389 Mdot
.43273 .58404 Mdot
.70839 .50976 Mdot
.39943 .20629 Mdot
.30271 .56694 Mdot
.36809 .60577 Mdot
.51024 .34661 Mdot
.64007 .77263 Mdot
.74559 .71989 Mdot
.64329 .52564 Mdot
.4208 .39299 Mdot
.37171 .27159 Mdot
.4709 .71492 Mdot
.46197 .75003 Mdot
.48794 .17169 Mdot
.67933 .57286 Mdot
.6782 .46917 Mdot
.19607 .38737 Mdot
.3827 .58353 Mdot
.8231 .42965 Mdot
.55782 .70481 Mdot
.48511 .76869 Mdot
.47661 .74904 Mdot
.79135 .48378 Mdot
.61149 .68887 Mdot
.75015 .31823 Mdot
.35816 .63863 Mdot
.38661 .55269 Mdot
.40311 .69656 Mdot
.59054 .6875 Mdot
.45813 .37553 Mdot
.70555 .76598 Mdot
.17773 .54692 Mdot
.66871 .68098 Mdot
.56094 .50919 Mdot
.75706 .51885 Mdot
.66971 .78162 Mdot
.7418 .49539 Mdot
.33246 .53723 Mdot
.74701 .57844 Mdot
.7423 .33217 Mdot
.79963 .38648 Mdot
.74572 .36829 Mdot
.49303 .77427 Mdot
.44052 .35488 Mdot
.39165 .77069 Mdot
.43621 .68358 Mdot
.51052 .47789 Mdot
.45803 .61845 Mdot
.44241 .58194 Mdot
.44105 .49806 Mdot
.80714 .5267 Mdot
.49159 .55114 Mdot
.74602 .2839 Mdot
.81746 .42453 Mdot
.68921 .23487 Mdot
.41052 .33021 Mdot
.68832 .5384 Mdot
.52527 .12846 Mdot
.53411 .78965 Mdot
.77051 .36108 Mdot
.75692 .69071 Mdot
.55417 .83677 Mdot
.40168 .18378 Mdot
.71679 .32629 Mdot
.61723 .5459 Mdot
.83288 .57049 Mdot
.73137 .3815 Mdot
.54763 .82739 Mdot
.59329 .71366 Mdot
.78378 .41831 Mdot
.47059 .12821 Mdot
.69473 .74136 Mdot
.6987 .38323 Mdot
.64089 .67028 Mdot
.60945 .66742 Mdot
.61112 .79918 Mdot
.4717 .66683 Mdot
.35489 .45168 Mdot
.218 .43546 Mdot
.38313 .68378 Mdot
.59924 .66594 Mdot
.59759 .80415 Mdot
.43923 .7322 Mdot
.41353 .74275 Mdot
.28497 .32305 Mdot
.40499 .18421 Mdot
.6232 .63639 Mdot
.59471 .60777 Mdot
.74205 .48402 Mdot
.32348 .59761 Mdot
.36509 .72646 Mdot
.5043 .60783 Mdot
.5173 .43866 Mdot
.5462 .55193 Mdot
.71259 .23387 Mdot
.21107 .47196 Mdot
.44835 .28469 Mdot
.69897 .53584 Mdot
.78421 .46012 Mdot
.43159 .25466 Mdot
.66862 .39362 Mdot
.58479 .80336 Mdot
.63099 .57351 Mdot
.64198 .2119 Mdot
.7024 .39253 Mdot
.33857 .6778 Mdot
.24444 .62632 Mdot
.51721 .29577 Mdot
.77682 .62649 Mdot
.51817 .14654 Mdot
.71415 .41177 Mdot
.6427 .47835 Mdot
.67037 .3227 Mdot
.45843 .37826 Mdot
.7286 .4264 Mdot
.68121 .37406 Mdot
.40688 .23258 Mdot
.65913 .61545 Mdot
.57038 .17135 Mdot
.28876 .44085 Mdot
.36763 .6926 Mdot
.62754 .31271 Mdot
.60956 .80272 Mdot
.47605 .71689 Mdot
.77797 .33567 Mdot
.49778 .48054 Mdot
.35919 .55457 Mdot
.53878 .60317 Mdot
.53388 .78235 Mdot
.78766 .4855 Mdot
.6561 .32873 Mdot
.45013 .55768 Mdot
.63337 .51964 Mdot
.80052 .64045 Mdot
.34256 .36899 Mdot
.37487 .41594 Mdot
.4545 .79102 Mdot
.67258 .43338 Mdot
.34369 .52093 Mdot
.57804 .36306 Mdot
.44722 .67596 Mdot
.23915 .60288 Mdot
.42711 .34799 Mdot
.7829 .61487 Mdot
.72738 .71758 Mdot
.48497 .17668 Mdot
.41725 .31667 Mdot
.80682 .63691 Mdot
.78672 .62601 Mdot
.78354 .43861 Mdot
.51497 .80719 Mdot
.59619 .53462 Mdot
.51187 .57083 Mdot
.33215 .53675 Mdot
.71319 .47071 Mdot
.49954 .17797 Mdot
.41066 .59591 Mdot
.35396 .55482 Mdot
.48914 .49896 Mdot
.41015 .27475 Mdot
.40116 .44561 Mdot
.77005 .40726 Mdot
.83303 .57126 Mdot
.36881 .64728 Mdot
.5196 .32258 Mdot
.57745 .26462 Mdot
.53085 .51404 Mdot
.76058 .3082 Mdot
.43235 .51123 Mdot
.77486 .50517 Mdot
.58178 .38465 Mdot
.75118 .64381 Mdot
.81645 .46441 Mdot
.37662 .60558 Mdot
.52 .47208 Mdot
.76231 .49273 Mdot
.58599 .51264 Mdot
.61666 .41176 Mdot
.23289 .45152 Mdot
.52356 .79399 Mdot
.50029 .21261 Mdot
.53029 .35194 Mdot
.47226 .69464 Mdot
.34877 .75542 Mdot
.55409 .1731 Mdot
.42476 .49443 Mdot
.48869 .48363 Mdot
.35823 .25127 Mdot
.36261 .47119 Mdot
.14972 .61845 Mdot
.68955 .21076 Mdot
.53701 .60242 Mdot
.47651 .444 Mdot
.37153 .60067 Mdot
.29445 .42742 Mdot
.72013 .57861 Mdot
.49576 .17277 Mdot
.50469 .31829 Mdot
.26851 .34945 Mdot
.57387 .36323 Mdot
.80989 .51682 Mdot
.22037 .34985 Mdot
.46185 .26123 Mdot
.79817 .30946 Mdot
.6966 .35422 Mdot
.75019 .45362 Mdot
.15497 .64304 Mdot
.80077 .5152 Mdot
.42548 .68233 Mdot
.259 .378 Mdot
.71443 .24036 Mdot
.50119 .40589 Mdot
.25417 .40605 Mdot
.70875 .73 Mdot
.3647 .64525 Mdot
.37012 .70653 Mdot
.59659 .36712 Mdot
.81121 .57351 Mdot
.51364 .84268 Mdot
.33907 .30376 Mdot
.16814 .43575 Mdot
.65708 .58713 Mdot
.59698 .17384 Mdot
.58944 .30228 Mdot
.1899 .57078 Mdot
.79829 .38977 Mdot
.40601 .68462 Mdot
.61137 .79009 Mdot
.21983 .51772 Mdot
.33056 .62133 Mdot
.34168 .75734 Mdot
.57145 .42402 Mdot
.69463 .5701 Mdot
.30229 .32529 Mdot
.46908 .5456 Mdot
.39794 .68759 Mdot
.75272 .65769 Mdot
.51753 .47245 Mdot
.54666 .15124 Mdot
.56797 .79876 Mdot
.34878 .65091 Mdot
.32966 .26696 Mdot
.34514 .60269 Mdot
.51504 .17979 Mdot
.43614 .27268 Mdot
.42984 .69473 Mdot
.36224 .19573 Mdot
.5681 .14242 Mdot
.59557 .53266 Mdot
.49602 .67753 Mdot
.82901 .43312 Mdot
.38004 .50327 Mdot
.73711 .7064 Mdot
.63611 .34617 Mdot
.37746 .71813 Mdot
.52736 .54625 Mdot
.48442 .58465 Mdot
.41562 .78567 Mdot
.62851 .55133 Mdot
.75758 .65333 Mdot
.24419 .32917 Mdot
.34915 .64611 Mdot
.5784 .7889 Mdot
.22739 .3287 Mdot
.55758 .70641 Mdot
.64659 .51456 Mdot
.71324 .23741 Mdot
.76533 .54927 Mdot
.41401 .63747 Mdot
.63786 .6408 Mdot
.42117 .5215 Mdot
.25302 .53952 Mdot
.42556 .66301 Mdot
.53624 .41931 Mdot
.38685 .69159 Mdot
.44924 .19233 Mdot
.79372 .58082 Mdot
.4795 .11609 Mdot
.80423 .42866 Mdot
.71152 .53237 Mdot
.71633 .71855 Mdot
.47298 .41155 Mdot
.67626 .226 Mdot
.30717 .31243 Mdot
.27403 .31779 Mdot
.48636 .83354 Mdot
.3437 .61472 Mdot
.55741 .59863 Mdot
.57342 .42118 Mdot
.8007 .377 Mdot
.50294 .83251 Mdot
.79583 .36055 Mdot
.47683 .56184 Mdot
.56259 .58933 Mdot
.13816 .43492 Mdot
.63719 .21419 Mdot
.44232 .61586 Mdot
.56044 .53309 Mdot
.52646 .53379 Mdot
.5615 .62958 Mdot
.62657 .42807 Mdot
.32662 .71982 Mdot
.38243 .71315 Mdot
.74531 .27984 Mdot
.72308 .50902 Mdot
.50651 .40862 Mdot
.4885 .25825 Mdot
.50374 .43523 Mdot
.59289 .66999 Mdot
.49696 .32928 Mdot
.39697 .72235 Mdot
.38991 .48709 Mdot
.27455 .51872 Mdot
.63781 .56567 Mdot
.57271 .43382 Mdot
.6776 .56408 Mdot
.45326 .76802 Mdot
.63975 .41911 Mdot
.43448 .8186 Mdot
.43761 .73187 Mdot
.44134 .7075 Mdot
.76189 .40396 Mdot
.69776 .7887 Mdot
.51525 .40695 Mdot
.64381 .43344 Mdot
.50438 .71385 Mdot
.56508 .75889 Mdot
.64716 .62357 Mdot
.27155 .55515 Mdot
.61468 .39651 Mdot
.46706 .56693 Mdot
.77055 .50888 Mdot
.47055 .32266 Mdot
.75589 .2556 Mdot
.51082 .56677 Mdot
.70158 .59314 Mdot
.76194 .32298 Mdot
.38275 .24688 Mdot
.5933 .71047 Mdot
.46081 .61705 Mdot
.392 .53748 Mdot
.38699 .49032 Mdot
.7188 .45424 Mdot
.39428 .22303 Mdot
.6087 .1896 Mdot
.46632 .78488 Mdot
.68141 .59407 Mdot
.51196 .65712 Mdot
.31575 .52713 Mdot
.53236 .42956 Mdot
.19469 .55074 Mdot
.35465 .49869 Mdot
.76007 .3688 Mdot
.44046 .7579 Mdot
.37117 .7135 Mdot
.62894 .69095 Mdot
.62002 .17201 Mdot
.54908 .51438 Mdot
.65086 .60094 Mdot
.46215 .51304 Mdot
.6858 .30952 Mdot
.43352 .72107 Mdot
.48971 .21343 Mdot
.47082 .56047 Mdot
.59613 .54363 Mdot
.79758 .32918 Mdot
.7167 .55893 Mdot
.48485 .35381 Mdot
.73305 .30709 Mdot
.53258 .79634 Mdot
.48938 .44622 Mdot
.16306 .66477 Mdot
.30381 .31082 Mdot
.78682 .29712 Mdot
.42748 .20871 Mdot
.49005 .73706 Mdot
.76396 .45419 Mdot
.48252 .57407 Mdot
.33161 .41682 Mdot
.6533 .20961 Mdot
.75996 .50008 Mdot
.60007 .52804 Mdot
.50176 .68395 Mdot
.40858 .49301 Mdot
.72805 .45994 Mdot
.49021 .20709 Mdot
.33559 .46645 Mdot
.41084 .53504 Mdot
.47755 .21248 Mdot
.38618 .49043 Mdot
.57523 .83591 Mdot
.52849 .14172 Mdot
.6824 .25308 Mdot
.43121 .3556 Mdot
.16294 .59535 Mdot
.73243 .52503 Mdot
.71022 .45941 Mdot
.49042 .34275 Mdot
.39848 .77673 Mdot
.72145 .41952 Mdot
.43977 .19339 Mdot
.79878 .46293 Mdot
.47453 .717 Mdot
.20707 .73216 Mdot
.41069 .69595 Mdot
.41091 .50997 Mdot
.70129 .41904 Mdot
.75624 .29483 Mdot
.25153 .37392 Mdot
.82768 .51189 Mdot
.60094 .29755 Mdot
.59616 .6701 Mdot
.38795 .79089 Mdot
.19937 .38532 Mdot
.4308 .37367 Mdot
.16612 .43973 Mdot
.61566 .21282 Mdot
.32711 .71135 Mdot
.64758 .32695 Mdot
.69312 .54187 Mdot
.44289 .57341 Mdot
.60722 .27471 Mdot
.58474 .51774 Mdot
.75237 .46376 Mdot
.60444 .19229 Mdot
.27344 .67249 Mdot
.32543 .25767 Mdot
.67788 .23713 Mdot
.53047 .32056 Mdot
.7185 .54486 Mdot
.4381 .73799 Mdot
.33535 .49804 Mdot
.29893 .41962 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Hooooo`;o
0000[oooool001cooooo00?o0000ooooooooool0V?ooool4o`000:gooooo000Looooo`03o`000?oo
oooooooo09Gooooo0_l00003ooooo`Ko0000ZOooool001cooooo00?o0000ooooooooool0UOooool2
o`0000Gooooo1?l00005ooooo`;o0000X_ooool001cooooo00?o0000ooooooooool0UOooool2o`00
00[ooooo0_l00002ooooo`Co00000_ooool3o`0009_ooooo000Looooo`03o`000?oooooooooo09Go
oooo0_l00007ooooo`Go00001?ooool2o`0000;ooooo0ol0002Kooooo`007?ooool00ol0003ooooo
ooooo`2Aooooo`;o00002oooool3o`0000Kooooo0_l0002Pooooo`007?ooool00ol0003ooooooooo
o`2Aooooo`;o00005?ooool2o`0000Sooooo0_l0002Fooooo`007?ooool00ol0003oooooooooo`2a
ooooo`;o0000U_ooool001cooooo00?o0000ooooooooool0Yoooool3o`0000_ooooo0_l0002Boooo
o`007?ooool00ol0003oooooooooo`2Gooooo`;o00003?ooool5o`0000_ooooo0_l000000ooooooo
0000o`00002?ooooo`007?ooool00ol0003oooooooooo`2Gooooo`;o00000_ooool2o`0000Sooooo
0_l0000?ooooo`Co0000Soooool001cooooo0_l0002Looooo`;o00004Oooool2o`0000Kooooo0_l0
002Aooooo`007?ooool00ol0003oooooooooo`2Jooooo`;o000000?oooooo`000?l000003oooool2
o`0009Wooooo000Looooo`03o`000?oooooooooo09Kooooo0_l00002ooooo`;o000000?oooooo`00
0?l000004oooool2o`0000kooooo0_l00025ooooo`007?ooool00ol0003oooooooooo`2Fooooo`;o
00006_ooool2o`0000kooooo0_l00025ooooo`007?ooool00ol0003oooooooooo`2gooooo`;o0000
1Oooool3o`0008Sooooo000Looooo`03o`000?oooooooooo09gooooo0_l0000Hooooo`;o00001Ooo
ool3o`0008Sooooo000Looooo`03o`000?oooooooooo09_ooooo1?l0000Gooooo`?o00003Oooool2
o`00087ooooo000Looooo`03o`000?oooooooooo09_ooooo1?l0000Aooooo`;o00001?ooool3o`00
00Gooooo0_l00006ooooo`;o0000POooool001cooooo00?o0000ooooooooool0V_ooool7o`0000oo
oooo0_l0000<ooooo`;o0000ROooool001cooooo00?o0000ooooooooool0O?ooool4o`0001Sooooo
1_l000000ooooooo0000o`000003ooooo`;o00008?ooool2o`0000Gooooo0_l0001jooooo`007?oo
ool00ol0003oooooooooo`1hooooo`;o00000_ooool6o`0000Gooooo0_l0000?ooooo`Co00002?oo
ool2o`00013ooooo0_l0000>ooooo`;o00001Oooool4o`0007Sooooo000Looooo`03o`000?oooooo
oooo07Sooooo0_l00005ooooo`?o00001Oooool2o`0000;ooooo0_l0000=ooooo`;o00006_ooool2
o`0000kooooo0_l00007ooooo`;o0000N?ooool001cooooo00?o0000ooooooooool0P?ooool2o`00
00Gooooo1ol0000<ooooo`;o00008_ooool2o`0000;ooooo0_l00002ooooo`;o00001Oooool4o`00
07Sooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool0
0ol0003oooooooooo`1Zooooo`;o00004?ooool2o`0000_ooooo1ol0000^ooooo`;o000000Gooooo
o`000?l0003o0000ooooo`02o`0000Kooooo0_l00008ooooo`;o0000L?ooool00006oooooomgMgOo
V9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03
o`000?oooooooooo06[ooooo0_l00006ooooo`;o00002?ooool2o`0000;ooooo0_l00007ooooo`Co
000000?oooooo`000?l000009?ooool2o`0000_ooooo1_l0000?ooooo`?o0000L?ooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`00
0?oooooooooo07;ooooo0_l00002ooooo`;o00002?ooool2o`0001Kooooo0_l0000Jooooo`;o0000
1Oooool2o`0000Kooooo0_l0000Aooooo`;o0000LOooool00003ooooool0003ooooo00;ooooo00?o
0000ooooooooool02oooool00onHV9So8B4Qonk^kP06ooooo`?o0000M_ooool4o`000004ooooool0
003o0000ooooo`;o00005_ooool4o`00027ooooo0_l0002<ooooo`0000?oooooo`000?ooool00_oo
ool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0N?oo
ool2o`000004ooooool0003o0000ooooo`;o00002Oooool2o`0000Kooooo0_l00003ooooo`Co0000
8_ooool2o`0000;ooooo0_l00027ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0O_ooool2o`0000?ooooo0_l0
0002ooooo`Co00001_ooool2o`0000Sooooo0_l00003ooooo`;o00006_ooool2o`0000;ooooo0ol0
0004ooooo`;o00003_ooool2o`00073ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo
00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo07Kooooo2_l00003ooooo`;o
00000_ooool2o`0000Wooooo0_l00002ooooo`Co000000?oooooo`000?l000000oooool2o`0001oo
oooo0_l00004ooooo`;o00001?ooool2o`000003ooooool0003o000000Gooooo0_l00003ooooo`;o
0000Joooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0K_ooool2o`0000Kooooo2_l0000Booooo`;o00000_ooool4
o`000003ooooool0003o000000;ooooo0_l0000Sooooo`;o00001Oooool4o`000003ooooool0003o
000000;o00001_ooool4o`0006_ooooo000Looooo`03o`000?oooooooooo06kooooo0_l0000:oooo
o`?o00001Oooool2o`00017ooooo1Ol000000ooooooo0000o`000002ooooo`;o00005Oooool2o`00
00cooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l0001]ooooo`007?ooool00ol0003o
ooooooooo`1jooooo`?o00001Oooool2o`0000Kooooo1?l000000ooooooo0000o`000002ooooo`Co
000000?oooooo`000?l000007?ooool2o`0001?ooooo0_l0001looooo`007?ooool00ol0003ooooo
ooooo`1fooooo`;o00001?ooool4o`0000[ooooo1?l000000ooooooo0000o`000002ooooo`Ko0000
6_ooool4o`00013ooooo0_l00003ooooo`;o00000oooool2o`0007Kooooo000Looooo`03o`000?oo
oooooooo06[ooooo0_l0000:ooooo`;o00001?ooool4o`00013ooooo0_l00005ooooo`;o000000?o
ooooo`000?l000005oooool4o`00013ooooo0_l00003ooooo`;o00000oooool2o`0000Gooooo1?l0
0003ooooo`;o0000J?ooool001cooooo00?o0000ooooooooool0J_ooool2o`00013ooooo0_l00006
ooooo`Co00002?ooool2o`0000Sooooo0_l0000Jooooo`;o00004?ooool2o`000003ooooool0003o
000000_ooooo1?l00003ooooo`;o0000J?ooool001cooooo00?o0000ooooooooool0Ioooool2o`00
01Oooooo0_l00002ooooo`Co00005Oooool4o`0001Gooooo0ol0000?ooooo`;o000000?oooooo`00
0?l000001?ooool2o`0000;ooooo0_l00008ooooo`?o00000_ooool2o`0006?ooooo000Looooo`03
o`000?oooooooooo06Oooooo0_l0000Dooooo`;o000000?oooooo`000?l000006?ooool2o`000003
ooooool0003o000000;o00000_ooool2o`0001;ooooo0_l0000Hooooo`;o00000_ooool2o`0000Go
oooo0_l000001?oooooo0000o`000?l00002ooooo`;o0000Hoooool001cooooo00?o0000oooooooo
ool0MOooool2o`0000Gooooo0ol00004ooooo`;o00005Oooool2o`000003ooooool0003o000000Co
oooo0_l0000@ooooo`Co00004_ooool2o`0000_ooooo0_l00002ooooo`;o00001_ooool2o`0000;o
oooo0_l0001Oooooo`007?ooool00ol0003oooooooooo`1Oooooo`;o00001?ooool2o`0000Sooooo
0_l000001?oooooo0000o`000?ooool2o`0000Gooooo0ol00004ooooo`;o00004oooool2o`0000?o
oooo0_l0000Fooooo`Co00004_ooool2o`0000Gooooo0_l00004ooooo`;o00002_ooool2o`0000;o
oooo0_l0001Oooooo`007?ooool00ol0003oooooooooo`1Oooooo`;o00001?ooool2o`0000Sooooo
0_l000000ooooooo0000o`000003ooooo`;o00001?ooool2o`0001Cooooo0_l00003ooooo`;o0000
0oooool2o`0003?ooooo0_l00004ooooo`;o000000?oooooo`000?l000001oooool2o`0000[ooooo
0_l0001Gooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o00002oooool2o`0000?ooooo1?l0
000Gooooo`?o00007?ooool2o`0002Gooooo0_l000000ooooooo0000o`00000Cooooo`;o0000Eooo
ool001cooooo0_l0001Qooooo`;o00001oooool2o`0000Kooooo0ol00004ooooo`?o00005oooool2
o`0000;ooooo0_l0000Iooooo`;o000000?oooooo`000?l000000ol0000Looooo`;o000000Cooooo
o`000?l0003ooooo0_l00006ooooo`;o00003Oooool2o`0005Gooooo000Looooo`03o`000?oooooo
oooo063ooooo0_l00007ooooo`;o00001_ooool2o`0000Cooooo1?l00003ooooo`;o00002?ooool2
o`0000Sooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Oooooo0_l0000<
ooooo`Go00007?ooool2o`0000?ooooo0ol00004ooooo`Go00003?ooool2o`0005Gooooo000Loooo
o`03o`000?oooooooooo05Wooooo0_l00005ooooo`;o00001?ooool2o`0000oooooo1Ol00002oooo
o`;o00002?ooool2o`0000Oooooo0_l00002ooooo`?o000000?oooooo`000?l000001?l00006oooo
o`?o00003_ooool2o`0002;ooooo0ol00004ooooo`Go00003?ooool2o`0005Gooooo000Looooo`03
o`000?oooooooooo05Wooooo0_l00006ooooo`;o00000oooool2o`0000oooooo1Ol00009ooooo`;o
00002_ooool3o`000004ooooool0003o0000o`0000?ooooo0_l00008ooooo`;o00003?ooool2o`00
0003ooooool0003o000003Sooooo1?l0001Eooooo`007?ooool00ol0003oooooooooo`1Qooooo`;o
00005Oooool3o`0000Sooooo1?l00002ooooo`;o00001oooool2o`0000;ooooo1Ol00003ooooo`?o
00004_ooool2o`0000?ooooo0_l0000Rooooo`;o00004_ooool2o`0005Oooooo000Looooo`03o`00
0?oooooooooo05gooooo0_l00008ooooo`;o00006_ooool2o`0000Cooooo0_l00007ooooo`?o0000
00?oooooo`000?l000002ol0000Eooooo`;o00008_ooool2o`000003ooooool0003o000000_ooooo
0_l0001Kooooo`007?ooool00ol0003oooooooooo`1Jooooo`;o000000?oooooo`000?l000002?oo
ool2o`0001?ooooo0_l00006ooooo`;o00000oooool2o`0000Cooooo0_l000000ooooooo0000o`00
000?o`00013ooooo1?l00002ooooo`;o00000_ooool3o`0001[ooooo0_l00002ooooo`Co00002_oo
ool2o`0005_ooooo000Looooo`03o`000?oooooooooo05[ooooo0_l0000Iooooo`;o00001Oooool4
o`0000;ooooo1?l00004ooooo`;o00000oooool;o`000003ooooool0003o000000Ko000000?ooooo
o`000?l000003Oooool4o`0000;ooooo0_l00002ooooo`?o00006_ooool2o`0000;ooooo1?l00004
ooooo`;o00001_ooool2o`0005Wooooo000Looooo`03o`000?oooooooooo05Oooooo0_l00005oooo
o`;o00005Oooool2o`0000Oooooo0_l000001?oooooo0000o`000?l00006ooooo`;o00001OoooolB
o`000003ooooool0003o000000Cooooo0_l0000;ooooo`;o00002?ooool2o`0001gooooo1?l00002
ooooo`?o00000_ooool2o`000003ooooool0003o000000?ooooo0_l0001Dooooo`007?ooool00ol0
003oooooooooo`1Gooooo`;o00001?ooool3o`0001?ooooo0_l0000<ooooo`;o00003OoooolCo`00
0003ooooool0003o000000Cooooo0_l0000;ooooo`;o00002?ooool2o`0001[ooooo0_l00002oooo
o`?o00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o0000E?ooool001co
oooo00?o0000ooooooooool0GOooool2o`000003ooooool0003o0000017ooooo0ol0000>ooooo`;o
00001_ooool2o`0000;ooooo5_l0000Jooooo`?o00005_ooool2o`0000;ooooo1ol0000:ooooo`?o
00001oooool2o`0004oooooo000Looooo`03o`000?oooooooooo063ooooo0_l000000ooooooo0000
o`00000?ooooo`;o00003_ooool2o`000003ooooool0003o000000?ooooo1?l00002oooooaGo0000
6Oooool3o`0001Kooooo0_l00003ooooo`Ko00002oooool2o`0000Oooooo0_l0001?ooooo`007?oo
ool00ol0003oooooooooo`1Sooooo`;o00006Oooool2o`0000Oooooo0ol00004ooooo`;o00000_oo
oolEo`0000Cooooo0_l0000?ooooo`;o00008oooool5o`0000Wooooo1?l0001Fooooo`007?ooool0
0ol0003oooooooooo`1Looooo`;o00008?ooool2o`0000Kooooo1?l00004oooooaWo00001?ooool2
o`0000cooooo0_l000000ooooooo0000o`00000Tooooo`Co00001_ooool2o`0000?ooooo0_l0001F
ooooo`007?ooool00ol0003oooooooooo`1Looooo`;o00001oooool2o`0001Sooooo1?l00003oooo
o`;o00001ooooolJo`00013ooooo0_l0000Vooooo`Go00001Oooool3o`0000Cooooo0_l0001Eoooo
o`007?ooool00ol0003oooooooooo`1Looooo`?o00001_ooool2o`0001Sooooo1?l0000<oooooa[o
00005Oooool3o`0001cooooo0_l00002ooooo`Go000000?oooooo`000?l000000_ooool2o`0000Go
oooo0_l00008ooooo`;o0000Boooool001cooooo0_l0001Nooooo`;o000000?oooooo`000?l00000
0oooool2o`0002;ooooo0_l00005oooooaOo00005oooool3o`0001cooooo0_l00008ooooo`;o0000
4oooool2o`0004_ooooo000Looooo`03o`000?oooooooooo05Oooooo0_l000000ooooooo0000o`00
0004ooooo`;o00000oooool2o`0000?ooooo0_l0000Dooooo`;o000000?oooooo`000?l000001?oo
ool2o`0000Gooooo3_l000000ooooooo0000o`000006o`0000;ooooo0_l0000@ooooo`?o00006_oo
ool2o`0006oooooo000Looooo`03o`000?oooooooooo05Oooooo1Ol00003ooooo`?o00002?ooool2
o`0000;ooooo0_l0000?ooooo`?o000000?oooooo`000?l000002_oooolIo`000003ooooool0003o
0000013ooooo0ol0000Jooooo`?o00003oooool2o`0000Kooooo0_l00003ooooo`;o0000D?ooool0
01cooooo00?o0000ooooooooool0E?ooool2o`0000;ooooo0ol00004ooooo`?o00002?ooool2o`00
00;ooooo0_l0000?ooooo`;o00002oooool2o`000004ooooool0003o0000oooooaKo00000oooool2
o`0001Gooooo0_l0000Eooooo`Co00003Oooool2o`0000Cooooo1Ol00002ooooo`;o00001_ooool2
o`0004Sooooo000Looooo`03o`000?oooooooooo05Cooooo0_l00004ooooo`;o00000oooool3o`00
02Gooooo0_l00003ooooo`;o000000?oooooo`000?l000000_oooolEo`0000?ooooo0_l0000=oooo
o`;o00000_ooool2o`0000;ooooo0_l00004ooooo`;o00004Oooool2o`0001?ooooo0_l000000ooo
oooo0000o`00000:ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0E?ooool5o`000003
ooooool0003o000000?ooooo0ol0000Rooooo`;o000000?oooooo`000?l000002ooooolDo`0001;o
oooo0ol000000ooooooo0000o`000006ooooo`Co00008_ooool2o`0000Cooooo0_l0000<ooooo`;o
0000Aoooool001cooooo00?o0000ooooooooool0E?ooool6o`0000Gooooo0_l0000Oooooo`;o0000
0_ooool2o`0000cooooo1?l000000ooooooo0000o`00000Ao`00017ooooo0_l00009ooooo`;o0000
6?ooool2o`0000Kooooo0_l00002ooooo`;o00000_ooool4o`0000cooooo0_l00017ooooo`007?oo
ool00ol0003oooooooooo`1Aooooo`;o00000_ooool8o`0002?ooooo0_l00009ooooo`;o00001Ooo
oolIo`0001_ooooo0_l0000>ooooo`;o00002?ooool2o`0000Kooooo0_l00006ooooo`;o00000_oo
ool2o`0000_ooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o000000?ooooo
o`000?l000000oooool4o`000003ooooool0003o000000Gooooo1?l0000Rooooo`;o00001oooool@
o`000003ooooool0003o000000;ooooo0_l0000Fooooo`;o00000oooool2o`0000;ooooo0_l0000:
ooooo`;o00003Oooool2o`0000Wooooo0_l00002ooooo`;o00002oooool2o`0004Kooooo000Loooo
o`03o`000?oooooooooo04Kooooo0_l00004ooooo`;o00001Oooool3o`0000?ooooo0_l00003oooo
o`;o00001Oooool4o`0001_ooooo0_l0000<oooooaCo00001_ooool2o`0001?ooooo0_l00007oooo
o`Co000000?oooooo`000?l000000_l0000?ooooo`;o000000?oooooo`000?l000003oooool2o`00
00Oooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`16ooooo`Co00000_ooool2o`0000Go
oooo0ol00003ooooo`;o00009oooool4o`0000cooooo0ol00003ooooo`[o00000_ooool4o`0000Co
oooo0_l0000Cooooo`;o00001oooool4o`000003ooooool0003o000000;o00003oooool2o`0000Wo
oooo0_l00007ooooo`;o00001oooool2o`0004Sooooo000Looooo`03o`000?oooooooooo04Cooooo
0_l00002ooooo`;o0000>?ooool2o`0000Wooooo0_l00003ooooo`?o00000_ooool;o`0000Cooooo
1?l00002ooooo`;o00008_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000>ooooo`;o0000
1?ooool2o`0000Oooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00001?oo
ool2o`0001Kooooo0_l0000Oooooo`;o00002?ooool2o`0000?ooooo4Ol00003ooooo`Co0000:_oo
ool2o`000003ooooool0003o000000Oooooo0_l00005ooooo`;o00002?ooool2o`0000?ooooo0_l0
00000ooooooo0000o`00001>ooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o00005_ooool2
o`0001oooooo0_l0000<ooooo`So000000?oooooo`000?l000000ol000001?oooooo0000o`000?l0
0003ooooo`;o00000oooool2o`0002gooooo0_l00004ooooo`;o00003oooool2o`0000Cooooo1?l0
001>ooooo`007?ooool00ol0003oooooooooo`16ooooo`;o0000@oooool2o`0000;ooooo1?l00004
ooooo`;o000000?oooooo`000?l000001ol00008ooooo`;o00007Oooool2o`0000kooooo0_l0000K
ooooo`;o0000D?ooool001cooooo00?o0000ooooooooool0A_ooool2o`0004?ooooo0_l00002oooo
o`?o00002?ooool6o`000003ooooool0003o000000Go00008_ooool3o`0000gooooo0_l0000Doooo
o`;o0000Eoooool001cooooo0_l00015ooooo`;o00003_ooool2o`00037ooooo0_l00002ooooo`;o
00002_ooool2o`0000;ooooo0_l00005ooooo`Ko00008oooool2o`0002?ooooo0_l000000ooooooo
0000o`00001Dooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00003_ooool2o`00037ooooo
1Ol00006ooooo`;o00000oooool2o`000003ooooool0003o000000Kooooo2?l0000Qooooo`;o0000
4oooool2o`0000gooooo1ol0001Cooooo`007?ooool00ol0003oooooooooo`1]ooooo`;o00006Ooo
ool5o`0000Gooooo0_l00006ooooo`;o00001?ooool2o`0000;ooooo1_l0000Qooooo`;o00004Ooo
ool4o`0000gooooo1?l000000ooooooo0000o`000002o`0000Sooooo0_l00017ooooo`007?ooool0
0ol0003oooooooooo`1]ooooo`;o00005_ooool2o`000004ooooool0003o0000ooooo`;o000000?o
ooooo`000?l000004?ooool2o`0000?ooooo0_l0000Sooooo`;o00002_ooool2o`0000Kooooo0_l0
000;ooooo`;o00000oooool2o`0000Cooooo0_l00006ooooo`Co0000Aoooool001cooooo00?o0000
ooooooooool0QOooool2o`0000Kooooo0ol00009ooooo`;o00002?ooool2o`0001;ooooo0ol0000;
ooooo`;o00000oooool2o`0000[ooooo0_l00006ooooo`;o00002Oooool4o`0000Oooooo1?l00006
ooooo`Co0000Aoooool001cooooo00?o0000ooooooooool0@_ooool2o`0001oooooo0_l00006oooo
o`;o00008?ooool2o`0000[ooooo1?l00006ooooo`;o00002Oooool2o`0000;ooooo0_l00003oooo
o`?o00002oooool2o`0000?ooooo0_l0000Aooooo`;o00002_ooool2o`000003ooooool0003o0000
00Kooooo1?l00007ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0@_ooool2o`0001co
oooo1Ol00006ooooo`?o00006?ooool2o`0000?ooooo0_l0000>ooooo`;o00004Oooool6o`0000[o
oooo0_l0000Eooooo`;o00001?ooool4o`000003ooooool0003o000000[ooooo2Ol00006ooooo`;o
00001oooool3o`0004;ooooo000Looooo`03o`000?oooooooooo03Wooooo0_l0000Uooooo`Ko0000
1_ooool2o`0001Sooooo0_l00003ooooo`;o00005oooool2o`0000Oooooo1_l00009ooooo`Co0000
5Oooool2o`0000Cooooo1?l000001?oooooo0000o`000?ooool2o`0000Wooooo1ol00006ooooo`;o
00001oooool3o`0004;ooooo000Looooo`03o`000?oooooooooo03Wooooo0_l0000Cooooo`;o0000
2_ooool2o`0000Cooooo0_l000001?oooooo0000o`000?l0000Rooooo`;o00001oooool2o`00017o
oooo0_l00007ooooo`;o00001Oooool2o`0000Kooooo0ol00007ooooo`;o00004Oooool6o`0000;o
oooo1?l0000<ooooo`;o00000oooool2o`0000gooooo0_l00012ooooo`007?ooool00ol0003ooooo
ooooo`0looooo`;o00004?ooool4o`0000Oooooo1Ol00002ooooo`;o000000?oooooo`000?l00000
0ol0000Oooooo`?o00001oooool2o`0000Oooooo0_l0000Hooooo`;o00001oooool3o`000003oooo
ool0003o000000?ooooo0_l0000Aooooo`Oo000000?oooooo`000?l000003_ooool2o`0000;ooooo
0ol00008ooooo`;o00001?ooool2o`00047ooooo000Looooo`03o`000?oooooooooo03cooooo0_l0
00000ooooooo0000o`000003ooooo`;o00002_ooool2o`0000Oooooo2Ol000000ooooooo0000o`00
0005o`0001gooooo0_l000000ooooooo0000o`000005ooooo`;o00001oooool3o`00023ooooo0ol0
00000ooooooo0000o`00000Eooooo`Go000000?oooooo`000?l000001?l00006ooooo`;o00001Ooo
ool2o`000004ooooool0003o0000o`0000Wooooo0_l00003ooooo`?o0000@Oooool001cooooo00?o
0000ooooooooool0?oooool2o`0000?ooooo0_l0000Eooooo`;o000000?oooooo`000?l000003?l0
0006ooooo`;o00004oooool5o`0000Cooooo0_l000000ooooooo0000o`000006ooooo`;o000000?o
ooooo`000?l000006Oooool2o`0000?ooooo0_l000000ooooooo0000o`00000Eooooo`;o00001Ooo
ool7o`0000?ooooo0ol00005ooooo`Ko00003_ooool2o`0004;ooooo000Looooo`03o`000?oooooo
oooo03cooooo0ol0000Oooooo`ko00001_ooool2o`0001Cooooo1?l00003ooooo`?o000000?ooooo
o`000?l000000_ooool3o`0000Cooooo0_l0000:ooooo`;o00003Oooool2o`0000Gooooo1?l0000J
ooooo`Go000000?oooooo`000?l000000_l000000ooooooo0000o`000006ooooo`Oo00001Oooool2
o`000003ooooool0003o000004Oooooo000Looooo`03o`000?oooooooooo03cooooo0ol0000Koooo
o`;o00000_oooolBo`0001[ooooo0_l00003ooooo`Go00000oooool3o`0000Oooooo0_l00007oooo
o`Ko000000?oooooo`000?l000002Oooool;o`0000?ooooo0_l0000@ooooo`Co00001Oooool3o`00
00kooooo0_l00005ooooo`Go00000oooool3o`00047ooooo00001_ooooook^k^oc8b<_l0003o<S8b
onk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0o
ooooo`;o00006OoooolFo`000003ooooool0003o000001;ooooo0_l00002ooooo`;o00001Oooool4
o`0000Cooooo0ol00004ooooo`Co00001?ooool3o`0000;ooooo1?l000000ooooooo0000o`000006
ooooo`ko00000oooool2o`0000Wooooo0ol00003ooooo`?o00000_ooool2o`0000?ooooo0_l0000H
ooooo`?o00000oooool3o`00047ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ
8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0?oooool2o`0000Cooooo0_l0
0007ooooo`;o00003?ooool?o`000003ooooool0003o000000Go00004_ooool2o`0000;ooooo0_l0
0005ooooo`Co00001Oooool2o`0000Cooooo1?l00004ooooo`?o00002oooool2o`0000;ooooo3_l0
0004ooooo`;o00001Oooool6o`0000?ooooo0_l00003ooooo`;o00000oooool2o`0001Wooooo0_l0
0017ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`Go00001_ooool0
0ol0003oooooooooo`0aooooo`;o00004_ooool2o`0000Oooooo0_l0000<oooooaOo00004oooool2
o`0000;ooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000;ooooo1?l00002
ooooo`Co00003?ooool3o`0000Kooooo0_l00002ooooo`So000000?oooooo`000?l000001?l00003
ooooo`?o00001?ooool3o`000003ooooool0003o000000Gooooo0_l00003ooooo`Go0000H_ooool0
0003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?m4A4CogMgMooooool00007
ooooo`?o0000<Oooool2o`0002Sooooo6?l0000Cooooo`;o00000_ooool2o`000003ooooool0003o
000000;o00001Oooool4o`0000;ooooo1?l00006ooooo`;o00001?ooool3o`0000Kooooo0_l00003
ooooo`ko00001?ooool2o`0000oooooo0_l000000ooooooo0000o`000006o`00067ooooo00000ooo
oooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo00001oooool0
0ol0003oooooooooo`0_ooooo`;o00007_ooool2o`0000Oooooo0_l000000ooooooo0000o`00000;
o`000003ooooool0003o000000Wo00004_ooool2o`0000;ooooo0_l00003ooooo`;o00002oooool5
o`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l000002oooool>o`0001Sooooo1?l00000
1?oooooo0000o`000?l0000;ooooo`Go0000DOooool00003ooooool@413ooooo00;ooooo00?o410@
ooooooooool02_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo02oooooo0_l0000N
ooooo`;o00001oooool4o`000003ooooool0003o000001Oo00004Oooool2o`000003ooooool0003o
000000?ooooo0_l0000;ooooo`Oo000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00
0005ooooo`;o00001oooool7o`000003ooooool0003o000000Co00001?ooool2o`0000oooooo0_l0
0006ooooo`?o00002oooool5o`00057ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo
00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0looooo`;o00001_ooool2o`0000Oooooo
0_l0000;ooooo`;o000000?oooooo`000?l000004Ol000000ooooooo0000o`000003o`00017ooooo
0_l000000ooooooo0000o`000002o`0000;ooooo0_l00004ooooo`Co00001oooool2o`000003oooo
ool0003o000000?o000000?oooooo`000?l000001Oooool2o`0000Gooooo2Ol000000ooooooo0000
o`000007o`000003ooooool0003o000000oooooo0ol00002ooooo`Co00004?ooool4o`000003oooo
ool0003o000000[ooooo0_l00010ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03
ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0??ooool2o`0000Gooooo0ol00003ooooo`So
00002?ooool4o`000003ooooool0003o0000017o000000Coooooo`000?l0003o00005_ooool3o`00
00;ooooo0_l00004ooooo`[o00001_ooool2o`0000Kooooo0_l000000ooooooo0000o`000005oooo
o`oo000000?oooooo`000?l000001?l0000<ooooo`;o00000_ooool8o`0001;ooooo1_l00009oooo
o`;o0000@?ooool001cooooo00?o0000ooooooooool0>Oooool2o`0000Sooooo0ol00003ooooo`Co
00000_ooool2o`0000;ooooo0_l00004ooooo`Co000000?oooooo`000?l000005Ol000000ooooooo
0000o`00000Cooooo`;o00002_ooool;o`0000cooooo0_l000000ooooooo0000o`000005ooooo`oo
00001?ooool3o`000003ooooool0003o000000Wooooo0_l00003ooooo`?o00002oooool2o`0000?o
oooo0_l000000ooooooo0000o`000003ooooo`Co00001?ooool2o`0004Gooooo000Looooo`03o`00
0?oooooooooo03Wooooo0_l00008ooooo`Go00002oooool2o`0000Oooooo6Ol000000ooooooo0000
o`00000Booooo`;o00002oooool;o`0000Gooooo0_l000001Ooooooo0000o`000?l0003ooooo00?o
00001Oooool@o`0000;ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00000oooool4o`00
00Sooooo0_l00005ooooo`;o00001?ooool2o`0000?ooooo0_l000000ooooooo0000o`000004oooo
o`Go00000_ooool2o`0004Gooooo000Looooo`03o`000?oooooooooo04?ooooo0_l000000ooooooo
0000o`00000DoooooaSo00004Oooool2o`0000?ooooo0_l0000:ooooo`?o00001Oooool7o`0000;o
oooo0_l000001Ooooooo0000o`000?l0003ooooo00?o000000?oooooo`000?l000000_ooool6o`00
0003ooooool0003o000000Ko00000oooool2o`000004ooooool0003o0000o`0000Kooooo1?l00008
ooooo`;o00001Oooool2o`0000[ooooo0_l00007ooooo`Co000000?oooooo`000?l000000oooool2
o`00047ooooo000Looooo`03o`000?oooooooooo057ooooo0_l000001?oooooo0000o`000?l00004
ooooo`?o000000?oooooo`000?l000005?l0000@ooooo`;o00000oooool2o`0000[ooooo1?l00004
ooooo`;o00000_ooool4o`0000Kooooo0_l00002ooooo`Co00000_ooool3o`000003ooooool0003o
000000Gooooo0_l0000;ooooo`;o00001_ooool3o`000003ooooool0003o000000gooooo0_l00008
ooooo`;o00002_ooool4o`0000?ooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0hoooo
o`;o00003_ooool2o`0000Oooooo0_l000001?oooooo0000o`000?l00002ooooo`So000000?ooooo
o`000?l000004Ol0000?ooooo`;o00001?ooool2o`0000Sooooo0_l00002ooooo`;o00001?ooool3
o`000003ooooool0003o000000Co000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00
0002o`0000Sooooo0_l000001?oooooo0000o`000?ooool2o`0000Gooooo0_l00004ooooo`;o0000
1oooool2o`000003ooooool0003o000000gooooo0ol00003ooooo`;o000000?oooooo`000?l00000
2Oooool6o`0000Gooooo0ol0000nooooo`007?ooool00ol0003oooooooooo`0gooooo`?o00003_oo
ool2o`0000cooooo0_l000000ooooooo0000o`000006o`000003ooooool0003o000001;o00003_oo
ool2o`0000Cooooo0_l00008ooooo`;o00001Oooool2o`0000;ooooo0_l00004ooooo`Oo000000?o
ooooo`000?l000001?l00003ooooo`;o00000oooool2o`000003ooooool0003o000000?o00001Ooo
ool2o`0000?ooooo0_l00008ooooo`;o00004Oooool2o`0000?ooooo0_l000000ooooooo0000o`00
0009ooooo`?o000000?oooooo`000?l000001Oooool3o`0003kooooo000Looooo`03o`000?oooooo
oooo02Wooooo0_l00008ooooo`;o00000_ooool2o`0000?ooooo0_l00005ooooo`;o00000oooool2
o`000003ooooool0003o000000;o00001oooool2o`0000;ooooo7?l0000Booooo`;o00004Oooool2
o`0000?ooooo0_l00004ooooo`Ko000000Coooooo`000?l0003ooooo0ol00003ooooo`;o00002?oo
ool3o`0000;ooooo0_l00006ooooo`;o00002?ooool2o`0001_ooooo0_l000000ooooooo0000o`00
0005ooooo`;o00002Oooool2o`0003kooooo000Looooo`03o`000?oooooooooo02Wooooo0_l00007
ooooo`?o00001oooool2o`0000Gooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l0000;
oooooa[o000000?oooooo`000?l000004Oooool2o`0001Kooooo0_l00002ooooo`;o000000?ooooo
o`000?l000000ol000001Ooooooo0000o`000?l0003ooooo00Co00002_ooool2o`0000Cooooo0_l0
000Mooooo`;o00003_ooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`00
0019ooooo`007?ooool00ol0003oooooooooo`0booooo`;o00006Oooool2o`0000_ooooo6Ol00000
0ooooooo0000o`000003o`0000oooooo0ol0000Cooooo`?o000000?oooooo`000?l000000_l00003
ooooo`Oo00000_ooool3o`0000[ooooo0_l0000Sooooo`;o00003_ooool2o`0000Gooooo0_l0001<
ooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00001Oooool2o`0000;ooooo8Ol00006oooo
o`;o00001oooool3o`000003ooooool0003o000000Wooooo0_l00002ooooo`;o000000Goooooo`00
0?l0003o0000ooooo`02o`0000Gooooo1?l00005ooooo`?o00008Oooool5o`0000gooooo0_l0000:
ooooo`;o00001_ooool3o`0004[ooooo000Looooo`03o`000?oooooooooo03Gooooo0_l0000Moooo
o`;o00000_ooool5o`0000;ooooo5_l00002ooooo`;o00001_ooool2o`0000Sooooo0_l000000ooo
oooo0000o`000009ooooo`;o00000_ooool2o`000004ooooool0003o0000o`0000Cooooo1?l00000
0ooooooo0000o`000005o`000003ooooool0003o000000;o00003?ooool2o`0001;ooooo1Ol0000=
ooooo`;o00002_ooool3o`000003ooooool0003o000000;ooooo0ol0001:ooooo`007?ooool2o`00
03Kooooo0_l0000<ooooo`;o00000oooool2o`00017ooooo6Ol00003ooooo`;o00004?ooool2o`00
00cooooo0_l00005ooooo`;o00001Oooool4o`000003ooooool0003o000000[o00003?ooool2o`00
00;ooooo0_l0000;ooooo`Co00001oooool2o`0000Wooooo0_l000000ooooooo0000o`000002oooo
o`;o00000_ooool3o`000003ooooool0003o0000013ooooo0_l0000mooooo`007?ooool00ol0003o
ooooooooo`13ooooo`;o00000oooool2o`00013ooooo1Ol000000ooooooo0000o`00000Bo`0002[o
oooo0ol00003ooooo`Co00000oooool3o`000003ooooool0003o000000?o00004_ooool2o`0000_o
oooo1?l000000ooooooo0000o`000004ooooo`;o00001_ooool2o`000004ooooool0003o0000oooo
o`;o00000_ooool2o`0000;ooooo0ol00004ooooo`;o00002Oooool2o`0000;ooooo0_l0000moooo
o`007?ooool00ol0003oooooooooo`1Jooooo`;o00001OoooolAo`0000;ooooo0ol0000Xooooo`;o
00000oooool3o`0000Gooooo1ol0000Cooooo`?o00003_ooool3o`0000cooooo0_l00008ooooo`;o
00000_ooool5o`0000;ooooo0_l00009ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0
<Oooool2o`0002Oooooo0_l00005oooooa3o00000oooool4o`0002gooooo0ol00002ooooo`Wo0000
5?ooool3o`0000Cooooo1_l00003ooooo`;o000000?oooooo`000?l000001oooool4o`0000;ooooo
0_l00005ooooo`;o00000_ooool5o`000004ooooool0003o0000o`0004cooooo000Looooo`03o`00
0?oooooooooo037ooooo0_l0000:ooooo`;o00008_ooool7o`0000;ooooo2Ol00003ooooo`;o0000
2?ooool2o`0002?ooooo0ol00002ooooo`;o00000_ooool3o`000003ooooool0003o000001Cooooo
0_l00004ooooo`Oo00000_ooool2o`000003ooooool0003o000000?ooooo2?l00002ooooo`;o0000
1Oooool3o`0000Oooooo1?l00002ooooo`;o00000oooool2o`0004;ooooo000Looooo`03o`000?oo
oooooooo03gooooo0_l0000Mooooo`;o00001?ooool>o`000003ooooool0003o000000;o00002_oo
ool3o`0000Oooooo0_l0000Iooooo`?o000000?oooooo`000?l000001?ooool3o`000003ooooool0
003o000001[ooooo0_l00003ooooo`?o00001?ooool4o`000003ooooool0003o000000Ko00002Ooo
ool4o`0000Sooooo0_l00002ooooo`;o00000oooool2o`0004;ooooo000Looooo`03o`000?oooooo
oooo03gooooo0_l0000Mooooo`;o00001Oooool2o`000003ooooool0003o000000?o00002?ooool3
o`0000Wooooo0_l00008ooooo`;o00002oooool2o`0000Oooooo0_l000000ooooooo0000o`000003
o`000003ooooool0003o000000Gooooo1ol0000Hooooo`;o000000?oooooo`000?l000000ol00002
ooooo`oo00000_ooool4o`0000Gooooo0_l0000?ooooo`;o00001?ooool2o`0003kooooo000Loooo
o`03o`000?oooooooooo047ooooo0_l0000Kooooo`;o00001_ooool5o`0000Kooooo1Ol00004oooo
o`;o00003oooool2o`0000Wooooo0_l00007ooooo`;o000000?oooooo`000?l000000ol00004oooo
o`;o00000oooool6o`000003ooooool0003o000001Sooooo1Ol00002oooooa3o000000?oooooo`00
0?l000001?l0000Dooooo`;o00001?ooool2o`0003kooooo000Looooo`03o`000?oooooooooo037o
oooo0_l0000>ooooo`;o00006oooool2o`0000Oooooo0ol000000ooooooo0000o`000004ooooo`Co
00001Oooool2o`0000gooooo1?l0000Eooooo`Go00001?ooool2o`0000[ooooo0_l0000@ooooo`?o
00000oooool4o`000003ooooool0003o000000?o000000?oooooo`000?l000003?l00005ooooo`;o
0000F_ooool001cooooo00?o0000ooooooooool0;?ooool2o`0000?ooooo0_l00003ooooo`;o0000
1_ooool2o`0001_ooooo0_l00003ooooo`;o00000_ooool2o`000005ooooool0003o0000o`000?oo
ool00ol0000Kooooo`Co00002?ooool2o`0000_ooooo0_l00008ooooo`Co00001?ooool2o`0000Co
oooo0_l0000<ooooo`Wo00000_oooolFo`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`00
017ooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00002?ooool2o`0000Ko
oooo0_l0000Kooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o000000?oooooo`000?l0
00000_ooool3o`0000Wooooo0_l000000ooooooo0000o`000005ooooo`;o00001?ooool2o`0000co
oooo0_l00007ooooo`;o00000_ooool2o`0000Sooooo1?l00004ooooo`;o00001?ooool2o`0000co
oooo0_l000000ooooooo0000o`00000Lo`000003ooooool0003o000000Oo00004Oooool2o`0004?o
oooo000Looooo`03o`000?oooooooooo03Cooooo0_l0000Xooooo`;o00002_ooool2o`0000_ooooo
0_l000000ooooooo0000o`000003ooooo`Ko00000_ooool2o`000003ooooool0003o000000;ooooo
1?l00009ooooo`;o000000?oooooo`000?l000000_ooool2o`0002Oooooo9ol00007ooooo`;o0000
00Coooooo`000?l0003o0000B_ooool001cooooo00?o0000ooooooooool0=?ooool2o`0003Cooooo
1?l00002ooooo`;o000000?oooooo`000?l000001_ooool2o`0000;ooooo0_l00002ooooo`;o0000
0_ooool5o`0000;ooooo1?l00009ooooo`;o000000?oooooo`000?l000000_ooool2o`0000[ooooo
0ol0000Looooo`;o000000?oooooo`000?l000003_l000000ooooooo0000o`000008o`000003oooo
ool0003o000000?o00002?ooool2o`000004ooooool0003o0000o`0000?ooooo0_l00015ooooo`00
7?ooool00ol0003oooooooooo`13ooooo`;o00007oooool6o`0000;ooooo0_l00002ooooo`;o0000
00Coooooo`000?l0003ooooo0_l00002ooooo`?o00002Oooool4o`0001Cooooo0_l0000>ooooo`?o
00001?ooool3o`0001Gooooo7?l000000ooooooo0000o`000003o`0001?ooooo0_l00004ooooo`;o
0000?oooool001cooooo00?o0000ooooooooool0>oooool2o`0000Cooooo1?l0000Oooooo`Ko0000
2?ooool3o`000003ooooool0003o000000;ooooo0_l00005ooooo`;o00000oooool2o`0001_ooooo
0_l0000@ooooo`Go00001?ooool2o`0000gooooo7?l000000ooooooo0000o`000004o`0000Cooooo
0_l00004ooooo`;o00001oooool2o`0000?ooooo0_l0000oooooo`007?ooool00ol0003ooooooooo
o`0kooooo`;o00001?ooool2o`0001gooooo0_l00006ooooo`?o00001?ooool2o`000004ooooool0
003o0000o`0000cooooo1?l000000ooooooo0000o`000004ooooo`;o00005Oooool2o`0000Sooooo
1?l00004ooooo`Go00001?ooool4o`0000Gooooo0ol00004oooooa[o000000Goooooo`000?l0003o
0000ooooo`03o`0000Cooooo1?l00002ooooo`;o00001oooool2o`0004Cooooo000Looooo`;o0000
=oooool2o`0002Sooooo0_l00006ooooo`?o00001?ooool2o`00013ooooo1?l00007ooooo`;o0000
3Oooool2o`0000?ooooo0_l000000ooooooo0000o`000008ooooo`Go00000oooool2o`0000Wooooo
0_l00004ooooo`Co00000_ooool:o`0000;ooooo4?l000001Ooooooo0000o`000?l0003ooooo00?o
00000oooool2o`000003ooooool0003o0000057ooooo000Looooo`03o`000?oooooooooo03Kooooo
0_l0000aooooo`?o00003?ooool2o`0000;ooooo0_l00003ooooo`?o00001?ooool3o`00013ooooo
1?l000000ooooooo0000o`000002o`0000cooooo0_l0000DooooobSo00001Oooool4o`0000Oooooo
0_l00002ooooo`;o0000AOooool001cooooo00?o0000ooooooooool0A?ooool2o`0002Cooooo0ol0
000;ooooo`;o000000?oooooo`000?l000001?l00007ooooo`?o00004_ooool2o`0000?ooooo0_l0
0002ooooo`;o000000?oooooo`000?l000001Oooool2o`0000_ooooo0_l0000;ooooo`[o000000?o
ooooo`000?l000005?l000000ooooooo0000o`000003ooooo`;o00000_ooool2o`000003ooooool0
003o000000Cooooo0_l000001?oooooo0000o`000?l00015ooooo`007?ooool00ol0003ooooooooo
o`0Vooooo`;o00007?ooool2o`0001Oooooo0ol0000;ooooo`Go00000oooool2o`0000;ooooo0_l0
0002ooooo`Ko000000?oooooo`000?l000005Oooool2o`0000;ooooo0_l00007ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0000?ooooo0_l00009ooooo`;o00003OoooolOo`0000Kooooo0_l0
0003ooooo`Co000000?oooooo`000?l000001?ooool2o`0000Kooooo0ol0000mooooo`007?ooool0
0ol0003oooooooooo`0Vooooo`;o00003Oooool2o`0001;ooooo0_l0000Booooo`?o00001?ooool2
o`0000Oooooo1?l00002ooooo`Ko00002Oooool2o`0000Gooooo0_l00007ooooo`;o00001Oooool2
o`0000?ooooo0ol00005ooooo`;o000000?oooooo`000?l000000_ooool4o`000003ooooool0003o
000000Oooooo0_l00002ooooo`;o00002ooooolOo`0000Oooooo0_l00002ooooo`?o00000_ooool2
o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`?o0000?Oooool001cooooo00?o0000oooo
ooooool0=Oooool2o`0001;ooooo0_l0000?ooooo`?o000000?oooooo`000?l000001?ooool2o`00
00Wooooo0_l000000ooooooo0000o`000004o`00017ooooo0_l00002ooooo`;o00000oooool2o`00
00Gooooo0_l00003ooooo`?o00002?ooool2o`000004ooooool0003o0000ooooo`;o00001_ooool2
o`000004ooooool0003o0000o`0000;ooooo0_l0000;oooooa_o000000Coooooo`000?l0003o0000
1?ooool2o`000003ooooool0003o000000;ooooo0ol00007ooooo`;o000000?oooooo`000?l00000
0_l00002ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0A?ooool2o`0000oooooo1?l0
00001?oooooo0000o`000?l0000;ooooo`;o00001Oooool2o`000003ooooool0003o000000Co0000
5Oooool2o`0000[ooooo0_l0000>ooooo`;o000000Coooooo`000?l0003ooooo0_l00006ooooo`;o
000000?oooooo`000?l000000_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l0
00007_l000000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l000000_ooool2o`0000So
oooo0_l000000ooooooo0000o`000002o`0004;ooooo000Looooo`03o`000?oooooooooo04Cooooo
0_l0000?ooooo`Co00001_ooool2o`0000Oooooo0_l00002ooooo`;o00005oooool2o`0000[ooooo
0_l0000Fooooo`Co00002_ooool2o`000003ooooool0003o000000;o000000Coooooo`000?l0003o
00000_ooool2o`000003ooooool0003o000000Go000000?oooooo`000?l000006Ol000000ooooooo
0000o`000005ooooo`;o00003?ooool2o`0004Oooooo000Looooo`03o`000?oooooooooo03oooooo
0_l0000Aooooo`;o000000?oooooo`000?l000000oooool3o`000003ooooool0003o000000;o0000
2_ooool2o`0001Oooooo0_l0000:ooooo`;o00004Oooool2o`0000Cooooo0ol0000;ooooo`;o0000
1_ooool2o`0000Wooooo5?l00002ooooo`ko00001?ooool2o`0000_ooooo0_l00017ooooo`007?oo
ool00ol0003oooooooooo`0Tooooo`;o00003_ooool2o`0000Wooooo0_l0000Aooooo`;o00001Ooo
ool4o`000003ooooool0003o000000;o000000?oooooo`000?l000009_ooool2o`0001Cooooo1Ol0
0003ooooo`?o000000?oooooo`000?l000002Oooool2o`0000Gooooo0_l0000:ooooob7o000000?o
ooooo`000?l000000oooool3o`0000gooooo0ol00014ooooo`007?ooool00ol0003oooooooooo`0T
ooooo`;o00003_ooool2o`0002?ooooo0_l000000ooooooo0000o`000009o`000003ooooool0003o
0000027ooooo0_l0000Dooooo`Co00000oooool3o`0000;ooooo0_l0000?ooooo`?o00001oooool2
o`0000?ooooo5Ol000000ooooooo0000o`000003o`0000Oooooo0_l000000ooooooo0000o`00000>
ooooo`?o00002_ooool3o`0003Oooooo000Looooo`03o`000?oooooooooo03Oooooo0_l0000@oooo
o`;o00003oooool=o`000003ooooool0003o000001Sooooo0_l00006ooooo`;o00002_ooool2o`00
00Wooooo0ol00003ooooo`Oo00001?ooool2o`0000[ooooo0_l000000ooooooo0000o`000005oooo
o`;o00000_oooolFo`000003ooooool0003o000000[ooooo0_l0000Nooooo`Co0000=_ooool001co
oooo00?o0000ooooooooool0=Oooool4o`00013ooooo0_l00009ooooo`;o00001?ooool;o`0000?o
oooo0_l0000@ooooo`Co00000oooool3o`0000Kooooo0_l00008ooooo`Co00001Oooool2o`0000So
oooo0ol000001?oooooo0000o`000?l00004ooooo`;o00002Oooool3o`000003ooooool0003o0000
00Wooooo1?l000000ooooooo0000o`00000Bo`0002cooooo0_l0000fooooo`007?ooool00ol0003o
ooooooooo`0^ooooo`;o00001Oooool3o`0000cooooo1?l00006ooooo`;o00001?ooool2o`0000Co
oooo3Ol000001?oooooo0000o`000?l0000?ooooo`Co00000oooool2o`00017ooooo0_l00007oooo
o`;o00001?ooool2o`0001Sooooo0_l00003ooooo`;o00000oooool2o`0000Cooooo0_l000000ooo
oooo0000o`000006o`000003ooooool0003o000000[o0000I?ooool001cooooo00?o0000oooooooo
ool0;_ooool2o`0000;ooooo0_l0000@ooooo`Co00001_ooool2o`0000Gooooo0_l00005oooooa3o
00000oooool2o`0000Wooooo0_l0000Qooooo`;o00001?ooool2o`0001Wooooo0_l00002ooooo`;o
00000oooool2o`0000Oooooo1Ol000000ooooooo0000o`000002ooooo`Oo000000Goooooo`000?l0
003o0000ooooo`02o`0002?ooooo0_l0000looooo`007?ooool00ol0003oooooooooo`0Zooooo`;o
00001_ooool3o`000003ooooool0003o000001gooooo1?l000000ooooooo0000o`00000@o`0000?o
oooo0_l00009ooooo`;o00001oooool2o`00013ooooo0_l0000Aooooo`;o00005?ooool2o`0000Go
oooo0_l0000:ooooo`?o00000_ooool4o`0000Cooooo0ol00004ooooo`Co00008_ooool2o`000003
ooooool0003o000003Wooooo000Looooo`;o0000:oooool2o`0000Oooooo1Ol00004ooooo`;o0000
6Oooool2o`000003ooooool0003o000000Go000000?oooooo`000?l000001ol0000Fooooo`Co0000
00?oooooo`000?l000003Oooool2o`000003ooooool0003o000000;ooooo0_l0000:ooooo`;o0000
3oooool2o`0000[ooooo0_l0000?ooooo`Co00001?ooool4o`0000?ooooo1_l00009ooooo`?o0000
5oooool2o`0003Wooooo000Looooo`03o`000?oooooooooo03Cooooo0_l000000ooooooo0000o`00
0003ooooo`;o00004_ooool2o`000003ooooool0003o000000Cooooo4Ol0000=ooooo`;o000000?o
ooooo`000?l000001Oooool3o`0000;ooooo1?l0000>ooooo`;o00000_ooool2o`0000?ooooo0_l0
00000ooooooo0000o`000008ooooo`;o00002Oooool2o`0000Kooooo0_l00002ooooo`;o000000?o
ooooo`000?l000005_ooool2o`0000Oooooo0_l00009ooooo`?o0000D_ooool001cooooo00?o0000
ooooooooool0=oooool2o`0001?ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00000ooo
ool@o`0000Cooooo1ol00003ooooo`Go00001_ooool4o`0000;ooooo0_l00008ooooo`;o00000_oo
ool2o`000003ooooool0003o000000Kooooo1Ol00004ooooo`;o00000_ooool2o`00017ooooo0_l0
0005ooooo`;o00005Oooool3o`0001;ooooo0_l00007ooooo`;o000000?oooooo`000?l000001_oo
ool2o`0003oooooo000Looooo`03o`000?oooooooooo02?ooooo0_l0000Rooooo`;o00000oooool2
o`0000Gooooo0ol000000ooooooo0000o`00000Co`000003ooooool0003o000000Go00001Oooool2
o`0000Wooooo0_l00008ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000005
ooooo`Co00001?ooool4o`0001[ooooo1?l00004ooooo`Co00003Oooool3o`000003ooooool0003o
000000;o00002oooool2o`0000Wooooo0_l000000ooooooo0000o`000006ooooo`;o0000?oooool0
01cooooo00?o0000ooooooooool08oooool2o`0002;ooooo0_l0000>oooooaGo00001_ooool3o`00
01Oooooo1?l00002ooooo`;o000000?oooooo`000?l000000_l00007ooooo`;o00001_ooool4o`00
00Gooooo0_l0000Cooooo`;o00001_ooool4o`0000Cooooo0_l00009ooooo`Ko00002oooool2o`00
00Wooooo0_l00007ooooo`?o0000@?ooool001cooooo00?o0000ooooooooool0F_oooolAo`0000So
oooo0_l0000Gooooo`;o00001oooool4o`0000[ooooo1ol00004ooooo`;o000000?oooooo`000?l0
00000oooool7o`0000;ooooo0_l0000:ooooo`Go00001_ooool4o`0000Oooooo0_l0000Jooooo`;o
00001oooool3o`00043ooooo000Looooo`03o`000?oooooooooo04gooooo0_l0000;oooooa?o0000
7?ooool2o`0000Cooooo0_l000000ooooooo0000o`000002o`0000Gooooo0_l00002ooooo`;o0000
00?oooooo`000?l000001_l00004ooooo`;o00001_ooool7o`0000;ooooo0ol00002ooooo`;o0000
1Oooool6o`0000Oooooo0_l0000/ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0;_oo
ool2o`0000[ooooo0_l0000Aooooo`;o00002ooooolCo`0001Gooooo0_l00005ooooo`;o00001?oo
ool2o`000003ooooool0003o000000Ko000000?oooooo`000?l000000_ooool2o`000003ooooool0
003o000000Ko00001?ooool2o`0000Kooooo0_l00004ooooo`;o00000_ooool2o`0000;ooooo0_l0
0004ooooo`Oo00003Oooool2o`0001gooooo1?l00004ooooo`?o00000oooool2o`0003cooooo000L
ooooo`03o`000?oooooooooo02kooooo0_l0000:ooooo`;o00007_oooolDo`0001Cooooo0_l00008
ooooo`;o00001OoooolGo`0000Cooooo0_l00007ooooo`;o00000oooool2o`0000;ooooo0_l00007
ooooo`Ko00002_ooool2o`0000?ooooo0_l0000=ooooo`;o00003_ooool4o`0000?ooooo0ol00003
ooooo`?o0000??ooool001cooooo00?o0000ooooooooool0>Oooool2o`00013ooooo0_l0000:oooo
o`;o000000?oooooo`000?l000004_l0000Dooooo`;o00002?ooool4o`0000?ooooo1Ol000001?oo
oooo0000o`000?ooool>o`0000Sooooo0_l00003ooooo`?o00003oooool2o`0000gooooo0ol0000;
ooooo`;o00000_ooool2o`000003ooooool0003o000000;o00002?ooool2o`0000Sooooo1?l00003
ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0:oooool2o`0000cooooo0_l0000@oooo
o`;o00002_ooool2o`0000;ooooo4_l0000Oooooo`Co00001?oooolEo`0000?ooooo0_l000001?oo
oooo0000o`000?ooool2o`0000Cooooo0_l0000Gooooo`;o00001Oooool2o`0000cooooo0_l00002
ooooo`;o00000oooool2o`0000Sooooo0_l00003ooooo`?o000000?oooooo`000?l000000_l00000
0ooooooo0000o`000010ooooo`007?ooool00ol0003oooooooooo`0[ooooo`?o0000:ooooolDo`00
00cooooo0_l0000>ooooo`;o000000?oooooo`000?l000002OoooolKo`0000Kooooo0ol0000Foooo
o`;o00002oooool2o`0000Oooooo0_l0000<ooooo`;o00001oooool3o`000003ooooool0003o0000
00?ooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o0000:ooooolBo`0000So
oooo0_l00004ooooo`;o00003_ooool2o`0000Wooooo0_l00002ooooo`Co00000_ooool:o`000003
ooooool0003o000000Co000000?oooooo`000?l000000_l00005ooooo`;o000000Coooooo`000?l0
003ooooo0_l0000Aooooo`;o00002_ooool2o`0000Oooooo0_l0000;ooooo`?o00002Oooool4o`00
00?ooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00002?ooool2o`0002?o
oooo4?l00008ooooo`;o00000_ooool3o`0000?ooooo0_l00008ooooo`;o00001?ooool2o`0000Go
oooo2?l00003ooooo`Go000000Goooooo`000?l0003o0000ooooo`0<o`0000Kooooo1_l0000<oooo
o`;o00000oooool2o`0000Kooooo0_l0000Hooooo`;o00002_ooool2o`0000Gooooo0_l00010oooo
o`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0;_ooool2o`0000Kooooo0_l0000Cooooo`Co00001_oo
ool2o`0000Cooooo5?l00004ooooo`;o00000_ooool3o`0000?ooooo0_l00008ooooo`;o00000ooo
ool3o`0000Kooooo8Ol00004ooooo`Ko00003?ooool3o`0000_ooooo0_l00004ooooo`;o00006ooo
ool2o`0004[ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEE
EOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0^ooooo`;o000000?oooooo`000?l0
00006?ooool4o`0000Cooooo1?l00005ooooo`;o000000?oooooo`000?l000003_l0000Cooooo`;o
00001Oooool2o`000003ooooool0003o000000Oooooo7Ol000001?oooooo0000o`000?l00004oooo
o`Ko00001_ooool2o`000003ooooool0003o000000?o00000oooool2o`0000Kooooo0ol00004oooo
o`;o00006oooool2o`0004[ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wo
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo02cooooo0_l00003oooo
o`;o00008?ooool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`co000000?oooooo`00
0?l000002_ooool2o`0000Oooooo0_l00005ooooo`;o00000_ooool2o`0000Cooooo4ol000000ooo
oooo0000o`00000:o`0000;ooooo0_l00005ooooo`Co00001_ooool2o`000003ooooool0003o0000
00;o00001?ooool2o`0000Kooooo0_l0000fooooo`;o0000=_ooool00003ooooool0003ooooo00;o
oooo00?o0000ooooooooool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0000[oooo
o`?o00007?ooool2o`0000[ooooo0_l00004ooooo`;o00000oooool8o`000003ooooool0003o0000
00;o00001oooool3o`000003ooooool0003o000000?ooooo0_l00009ooooo`;o00000_ooool2o`00
00?ooooo8Ol000000ooooooo0000o`000003o`0000;ooooo0_l000000ooooooo0000o`000005oooo
o`;o00001?ooool2o`0000?ooooo0_l0000cooooo`;o00002_ooool2o`0003Kooooo00000ooooooo
0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006oooo
o`03o`000?oooooooooo02_ooooo0_l0000Mooooo`;o00005?ooool;o`000003ooooool0003o0000
00Kooooo1Ol00005ooooo`;o00001oooool4o`0000Gooooo5ol000000ooooooo0000o`000009o`00
0004ooooool0003o0000ooooo`;o00000_ooool4o`000004ooooool0003o0000o`0000;ooooo0_l0
0009ooooo`;o00001?ooool2o`0002gooooo0_l00012ooooo`0000?ooooooa0@4?ooool00_ooool0
0ol@413oooooooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0Goooool3
o`0000Cooooo2?l00006ooooo`Go000000?oooooo`000?l000000_ooool2o`0000Kooooo1?l00000
0ooooooo0000o`000002oooooaco000000?oooooo`000?l000001Ol000000ooooooo0000o`000005
ooooo`Co000000Coooooo`000?l0003o00004oooool2o`0001_ooooo1?l0001Booooo`0000Kooooo
ogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0
<Oooool2o`0001kooooo0_l0000<ooooo`?o00000oooool<o`0000Cooooo0ol00002ooooo`;o0000
0_ooool2o`0000Kooooo1?l000000ooooooo0000o`000002oooooa_o00000_ooool5o`000003oooo
ool0003o000000;o00001_ooool3o`000003ooooool0003o0000033ooooo1Ol0000=ooooo`;o0000
@oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106oooo
o`03o`000?oooooooooo037ooooo1?l00003ooooo`;o00004?ooool2o`0000Gooooo0_l0000?oooo
o`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000?o00004Oooool4o`00
00Kooooo2?l000000ooooooo0000o`000003o`000003ooooool0003o000001Wo00001Oooool2o`00
00?ooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l00006ooooo`;o00007_ooool2o`00
0004ooooool0003o0000o`0000;ooooo0_l00003ooooo`;o00000oooool2o`0004?ooooo000Loooo
o`03o`000?oooooooooo02gooooo0_l00004ooooo`;o00000oooool2o`00013ooooo0_l00007oooo
o`?o00003?ooool4o`0000?ooooo1Ol00005ooooo`;o00000_ooool2o`0000Wooooo1Ol000001Ooo
oooo0000o`000?l0003ooooo017o000000?oooooo`000?l000006?l00002ooooo`Go00001?ooool4
o`0000?ooooo0_l00006ooooo`;o00002Oooool2o`0001Kooooo0ol00002ooooo`;o00000oooool2
o`0004Sooooo000Looooo`03o`000?oooooooooo02gooooo0_l00009ooooo`;o00006Oooool3o`00
00Kooooo0_l00006ooooo`;o00000_ooool4o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`00
00cooooo0_l000001?oooooo0000o`000?l00002ooooob_o00000_ooool7o`0000Wooooo0_l0000A
ooooo`;o00005oooool2o`0000cooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`0`oooo
o`;o00001_ooool2o`0002;ooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l00000
1?oooooo0000o`000?ooool2o`0000Oooooo0_l0000Eooooo`?o00001?oooolUo`000003ooooool0
003o000000;ooooo0ol000001?oooooo0000o`000?ooool2o`0000Kooooo0_l0000Vooooo`;o0000
3?ooool2o`0004?ooooo000Looooo`03o`000?oooooooooo033ooooo0_l0000Jooooo`;o00004ooo
ool3o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000007oooool2o`0000Kooooo
9_l000000ooooooo0000o`000003ooooo`;o000000Coooooo`000?l0003ooooo0_l00006ooooo`;o
00003?ooool3o`0001[ooooo1Ol0001;ooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o0000
7_ooool3o`0000Cooooo0_l000000ooooooo0000o`000008ooooo`Co00003oooool2o`000003oooo
ool0003o000001Cooooo;?l0000Aooooo`;o00002_ooool2o`0000Gooooo0ol0000Gooooo`;o0000
00?oooooo`000?l000000ol0001;ooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00001?oo
ool2o`0001Wooooo0_l00004ooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo1_l0
00000ooooooo0000o`000002o`0000Sooooo0_l000000ooooooo0000o`00000;ooooo`;o00001Ooo
ool2o`000003ooooool0003o000002Oo00003Oooool3o`0000?ooooo0_l0000:ooooo`;o00007_oo
ool3o`0000;ooooo0ol0001<ooooo`007?ooool00ol0003oooooooooo`0booooo`;o00008Oooool3
o`0000Cooooo0ol00004ooooo`?o000000?oooooo`000?l000000_l00005ooooo`;o00004Oooool2
o`0000Gooooo0ol000001Ooooooo0000o`000?l0003ooooo00Co00000_oooolRo`0000Cooooo0_l0
0003ooooo`?o000000?oooooo`000?l000000_l0000Yooooo`Co000000?oooooo`000?l000000_l0
0005ooooo`;o0000AOooool001cooooo00?o0000ooooooooool0EOooool2o`0000?ooooo0_l00000
0ooooooo0000o`000005ooooo`;o00002_ooool3o`0000?ooooo0_l0000;ooooo`;o00001_ooool6
o`000003ooooool0003o000000;ooooo9?l00002ooooo`Co00001oooool4o`0002Wooooo0ol00002
ooooo`;o00001Oooool4o`0004Gooooo000Looooo`03o`000?oooooooooo02oooooo0_l0000Toooo
o`;o00000oooool2o`000003ooooool0003o000000?o00000_ooool2o`0000Cooooo0_l00005oooo
o`Co000000?oooooo`000?l000000_ooool2o`0000Oooooo0_l00008ooooo`?o00001_oooolQo`00
00Gooooo0_l0000=ooooo`;o0000:?ooool2o`0000Wooooo0ol00004ooooo`;o0000@?ooool001co
oooo00?o0000ooooooooool0;oooool2o`0000Oooooo0_l0000Pooooo`;o00000oooool3o`0000So
oooo2?l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00007ooooo`;o00001_ooool7o`00
00Gooooo7Ol0000Gooooo`;o00003Oooool2o`0001Cooooo0ol00002ooooo`;o00002_ooool2o`00
00Cooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0Yooooo`;o00003Oooool2o`0001Go
oooo0_l0000=ooooo`Co00002_ooool6o`000003ooooool0003o000000?o00000oooool2o`0000_o
oooo2_l00004oooooaoo00001_ooool2o`0000_ooooo0_l0000@ooooo`;o00005?ooool3o`0000_o
oooo0_l00007ooooo`;o0000@?ooool001cooooo0_l0000Zooooo`;o00001oooool2o`0001_ooooo
0_l00002ooooo`;o00001?ooool4o`000003ooooool0003o000000;o00003?ooool2o`0000;ooooo
1?l00005ooooo`;o00002oooool4o`0000?ooooo1_l000000ooooooo0000o`00000Oo`0000Cooooo
0_l0000;ooooo`;o0000;?ooool2o`0000Kooooo0_l00019ooooo`007?ooool00ol0003ooooooooo
o`0booooo`;o00001?ooool2o`0001Wooooo0_l00004ooooo`Co000000Coooooo`000?l0003o0000
2Oooool2o`0000;ooooo0_l00002ooooo`Co00001Oooool2o`0000Gooooo0_l00004ooooo`Co0000
1?ooool5o`000003ooooool0003o000001oo00000oooool2o`0000Cooooo0_l0000/ooooo`;o0000
0_ooool2o`000004ooooool0003o0000o`0000;ooooo0_l0001=ooooo`007?ooool00ol0003ooooo
ooooo`0hooooo`;o00006Oooool2o`0000Oooooo0_l0000<ooooo`;o00002?ooool2o`0000Gooooo
0ol00004ooooo`;o000000?oooooo`000?l000000oooool/o`0000Cooooo0_l00004ooooo`;o0000
1oooool3o`0002;ooooo0_l000000ooooooo0000o`000004o`0000?ooooo0_l0001=ooooo`007?oo
ool00ol0003oooooooooo`1Booooo`?o00001oooool2o`0000cooooo0_l00008ooooo`;o00001_oo
ool2o`0000Oooooo0ol00003oooooa3o000000?oooooo`000?l000005_l00004ooooo`;o00000ooo
ool4o`0000Sooooo0ol00007ooooo`;o00000oooool2o`0001Oooooo1Ol0001Cooooo`007?ooool0
0ol0003oooooooooo`0aooooo`;o00007oooool3o`0000Sooooo0_l000001Ooooooo0000o`000?l0
003ooooo00;o00007?ooool2o`0000;ooooo0_l00003ooooo`;o00000ooooolTo`0000Cooooo0ol0
0002ooooo`Co00002?ooool2o`0000?ooooo0_l00002ooooo`Co00000_ooool2o`0001Wooooo0_l0
001Dooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00008?ooool2o`0000Oooooo0ol00000
1Ooooooo0000o`000?l0003ooooo00;o00004Oooool4o`0000Oooooo0_l00002ooooo`;o00000ooo
ool5o`000003ooooool0003o000000;ooooo7_l000000ooooooo0000o`00000;o`000003ooooool0
003o000000Cooooo0_l00004ooooo`;o00000_ooool4o`00027ooooo0_l0001@ooooo`007?ooool0
0ol0003oooooooooo`1Looooo`Go00000oooool2o`00013ooooo1Ol0000@ooooo`Ko00000_ooool9
o`0000;ooooo6ol000000ooooooo0000o`000005o`000003ooooool0003o000000;ooooo1?l00002
ooooo`;o00002Oooool2o`0001kooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`1Eoooo
o`Co00001Oooool3o`0000;ooooo0_l00002ooooo`;o00003Oooool2o`000003ooooool0003o0000
013ooooo9?l000000ooooooo0000o`000003o`0000;ooooo0_l00004ooooo`?o00001_ooool2o`00
00;ooooo1?l00009ooooo`;o00006oooool2o`0005?ooooo000Looooo`03o`000?oooooooooo05Go
oooo1?l00004ooooo`Co000000Coooooo`000?l0003o00000_ooool2o`00013ooooo0_l00009oooo
o`;o00001Oooool<o`000003ooooool0003o000001;o00002oooool2o`0000Sooooo0_l00007oooo
o`;o00001Oooool2o`00027ooooo1?l0001Aooooo`007?ooool00ol0003oooooooooo`10ooooo`;o
00006oooool3o`0000;ooooo0_l00006ooooo`;o00001Oooool2o`0000Wooooo0_l00006ooooo`;o
00001Oooool:o`0000Gooooo1_l000000ooooooo0000o`000004o`000005ooooool0003o0000o`00
0?ooool00_l00004ooooo`Co00002oooool2o`0000kooooo0_l0000Qooooo`Co0000DOooool001co
oooo00?o0000ooooooooool0=Oooool2o`0000Wooooo0_l0000Looooo`Co00002?ooool2o`0000Go
oooo0_l00006ooooo`Go00002?ooool8o`0000Cooooo0ol00006oooooaGo000000?oooooo`000?l0
00000ol0000Aooooo`;o00003?ooool2o`0001gooooo1?l0001Aooooo`007?ooool00ol0003ooooo
ooooo`0eooooo`;o0000:Oooool3o`0001Kooooo0ol00004ooooo`;o00001?ooool8o`0000?ooooo
0_l0000:ooooo`Go000000?oooooo`000?l000002?l000001?oooooo0000o`000?ooool2o`0000So
oooo0_l00009ooooo`?o00002oooool3o`0001Kooooo0ol0001Iooooo`007?ooool00ol0003ooooo
ooooo`1Qooooo`Co00000_ooool2o`0000Sooooo0_l00004ooooo`Co00000_ooool5o`0000;ooooo
0_l00002ooooo`_o00002_ooool@o`0000Oooooo0_l000000ooooooo0000o`000002ooooo`?o0000
1Oooool9o`0000;ooooo0_l00004ooooo`;o00004?ooool4o`0000?ooooo0ol0000<ooooo`;o0000
Boooool001cooooo00?o0000ooooooooool0H_ooool3o`0000;ooooo0_l00008ooooo`;o000000Co
ooooo`000?l0003ooooo0_l000001?oooooo0000o`000?ooool3o`0000Cooooo1_l000000ooooooo
0000o`000005o`0000kooooo1Ol000000ooooooo0000o`000007o`0000Gooooo0_l000000ooooooo
0000o`000003ooooo`;o00001Oooool3o`0000?ooooo0ol00002ooooo`;o00005_ooool4o`0000So
oooo0_l00008ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0HOooool2o`000004oooo
ool0003o0000o`0000gooooo0_l00004ooooo`Co00001?ooool2o`0000;ooooo1?l00003ooooo`Go
00001?ooool2o`0000Oooooo0_l000000ooooooo0000o`000005o`000003ooooool0003o000000?o
00003?ooool2o`0000Kooooo0ol00003ooooo`;o00009?ooool2o`000003ooooool0003o000005Go
oooo000Looooo`03o`000?oooooooooo03Wooooo0_l0000Vooooo`;o000000Coooooo`000?l0003o
00005Oooool2o`000004ooooool0003o0000ooooo`;o00001?ooool2o`0000?ooooo0ol00002oooo
o`;o00000_ooool2o`000003ooooool0003o000000Cooooo0_l00003ooooo`Ko00000oooool2o`00
00cooooo0_l00006ooooo`?o00001?ooool2o`0002?ooooo0_l0001Hooooo`007?ooool2o`0003[o
oooo0_l0000Pooooo`;o00002?ooool3o`0000Kooooo0_l000000ooooooo0000o`00000<ooooo`;o
00002?ooool2o`0000?ooooo0ol000000ooooooo0000o`000002o`0000?ooooo0ol0000:ooooo`Co
00005oooool2o`0000Oooooo0_l00002ooooo`;o0000:?ooool2o`0004oooooo000Looooo`03o`00
0?oooooooooo05_ooooo0_l00002ooooo`;o00001Oooool2o`0000Kooooo0_l000000ooooooo0000
o`00000?ooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`?o00000_ooool3o`0000;o
oooo0ol00003ooooo`;o00002_ooool2o`0000Cooooo0_l0000>ooooo`;o00002Oooool4o`0001Wo
oooo0_l00007ooooo`;o00001?ooool2o`0004oooooo000Looooo`03o`000?oooooooooo05oooooo
0_l00005ooooo`;o00000_ooool2o`0000Gooooo0_l000000ooooooo0000o`000003o`0000Wooooo
0_l00008ooooo`Ko00000oooool2o`0000;ooooo0_l00004ooooo`;o00002_ooool2o`0000?ooooo
0ol000000ooooooo0000o`000009ooooo`Co00000_ooool2o`0000Gooooo0_l0000Jooooo`?o0000
00?oooooo`000?l000001?ooool2o`0005Gooooo000Looooo`03o`000?oooooooooo05gooooo0_l0
0002ooooo`;o00001?ooool5o`0000Gooooo0_l000000ooooooo0000o`000003o`0000Wooooo1?l0
0006ooooo`Go00001?ooool2o`0000Cooooo0_l0000Cooooo`Ko00001_ooool7o`0000;ooooo0_l0
000Jooooo`;o00001Oooool2o`0000;ooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`1:
ooooo`;o00004Oooool2o`0000;ooooo0_l00004ooooo`Go00002Oooool2o`000003ooooool0003o
000000[ooooo0_l0000<ooooo`;o00000_ooool3o`0000;ooooo1ol0000Aooooo`;o000000Gooooo
o`000?l0003o0000ooooo`06o`00027ooooo0_l0001Vooooo`007?ooool00ol0003oooooooooo`1:
ooooo`;o00005Oooool2o`0000Cooooo1Ol00005ooooo`Ko000000?oooooo`000?l000005Oooool2
o`000004ooooool0003o0000ooooo`Co00001?ooool5o`0000kooooo0_l00003ooooo`Co000000?o
ooooo`000?l000001?l0000=ooooo`;o0000N_ooool001cooooo00?o0000ooooooooool0I_ooool2
o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l0000@
ooooo`;o00001?ooool2o`0000Cooooo1?l0000?ooooo`;o00001_ooool2o`0000?ooooo0_l00003
ooooo`?o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o00000_ooool4o`0001Kooooo0_l0
00000ooooooo0000o`000004ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0H?ooool2
o`0000Cooooo1Ol00003ooooo`;o00001oooool2o`0000Cooooo0_l0000:ooooo`;o00007Oooool2
o`00013ooooo2_l00003ooooo`;o00000_ooool2o`0001Sooooo0_l000000ooooooo0000o`000004
ooooo`;o00000_ooool2o`0005Gooooo000Looooo`03o`000?oooooooooo03kooooo0_l0000=oooo
o`;o00004Oooool2o`0000Gooooo1Ol00007ooooo`;o00002?ooool2o`0000[ooooo0ol0000aoooo
o`;o000000?oooooo`000?l000000_l00007ooooo`;o00009Oooool2o`0005Gooooo000Looooo`03
o`000?oooooooooo03kooooo0_l0000=ooooo`;o00004_ooool2o`0000?ooooo0_l00002ooooo`;o
00001_ooool3o`0000?ooooo0_l0000?ooooo`?o00004_ooool2o`0002Sooooo0_l0001oooooo`00
7?ooool00ol0003oooooooooo`10ooooo`;o00002oooool2o`0001;ooooo0_l00003ooooo`Co0000
2?ooool2o`0000Cooooo0_l0000@ooooo`?o00004Oooool2o`0001;ooooo0ol0000<ooooo`;o0000
1Oooool2o`0000oooooo0_l000000ooooooo0000o`000004ooooo`;o0000IOooool001cooooo00?o
0000ooooooooool0@?ooool2o`0002;ooooo1_l000000ooooooo0000o`000002ooooo`;o000000?o
ooooo`000?l000005_ooool3o`0000Cooooo0_l0000Looooo`;o000000Coooooo`000?l0003o0000
3?ooool2o`0000Gooooo0_l00002ooooo`;o00002oooool2o`000003ooooool0003o000000Cooooo
0_l00002ooooo`;o00001Oooool3o`0005Wooooo000Looooo`03o`000?oooooooooo04?ooooo0_l0
000;ooooo`;o00004_ooool6o`000003ooooool0003o000000;ooooo0_l00003ooooo`;o00002ooo
ool2o`0000Sooooo0_l00004ooooo`?o00001oooool2o`0001;ooooo0_l0000;ooooo`;o00003Ooo
ool3o`0000Sooooo0_l0000>ooooo`;o00001Oooool3o`0005Wooooo000Looooo`03o`000?oooooo
oooo04?ooooo0_l0000;ooooo`;o00004_ooool3o`000003ooooool0003o000000[ooooo0_l0000;
ooooo`;o00002?ooool2o`0000Gooooo0_l00007ooooo`;o00007oooool2o`0000_ooooo1?l00009
ooooo`;o00001_ooool3o`0000Kooooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`1Xoooo
o`?o00006?ooool2o`0000kooooo0_l000000ooooooo0000o`00000aooooo`;o00004oooool3o`00
00Kooooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`1Tooooo`;o00000_ooool3o`0001So
oooo0_l000000ooooooo0000o`00000;ooooo`;o000000?oooooo`000?l000007oooool2o`0000Oo
oooo0_l0000Wooooo`;o0000G_ooool001cooooo0_l0001Uooooo`;o00000_ooool2o`0001cooooo
0_l0000:ooooo`;o00000oooool2o`0001kooooo0_l00007ooooo`;o00001Oooool2o`0000Oooooo
0_l0000Gooooo`;o0000G_ooool001cooooo00?o0000ooooooooool0J?ooool2o`0000;ooooo0_l0
000Tooooo`?o00000_ooool2o`0000;ooooo0_l00003ooooo`Co00003Oooool2o`0000[ooooo0_l0
00001?oooooo0000o`000?ooool2o`0000;ooooo0_l00007ooooo`;o0000Moooool001cooooo00?o
0000ooooooooool0J?ooool8o`000003ooooool0003o0000023ooooo0_l00006ooooo`Wo00003Ooo
ool2o`0000[ooooo0_l00004ooooo`;o00002_ooool2o`0000;ooooo0_l0000<ooooo`?o0000IOoo
ool001cooooo00?o0000ooooooooool0Eoooool2o`0000cooooo0_l00003ooooo`Wo00006?ooool2
o`0000Kooooo0_l00006ooooo`Ko000000?oooooo`000?l000000_ooool4o`0000[ooooo0_l0000I
ooooo`;o00000_ooool2o`0000cooooo0ol0001Uooooo`007?ooool00ol0003oooooooooo`1Goooo
o`?o00002oooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`0001[ooooo0_l0000<oooo
o`;o00000_ooool2o`0000Oooooo1?l0000:ooooo`;o0000Toooool001cooooo00?o0000oooooooo
ool0BOooool2o`0000gooooo0_l0000oooooo`;o00000_ooool2o`0000?ooooo0_l0000:ooooo`Co
0000;oooool2o`0006Kooooo000Looooo`03o`000?oooooooooo04Wooooo0_l0000iooooo`Co0000
0oooool2o`0000;ooooo0_l00006ooooo`;o000000?oooooo`000?l000001_ooool2o`0000[ooooo
1?l0000Eooooo`;o00001Oooool2o`0000Kooooo0_l00009ooooo`;o00001Oooool2o`0005oooooo
000Looooo`03o`000?oooooooooo05gooooo0_l0000Looooo`;o00001oooool4o`0000?ooooo0_l0
0002ooooo`;o00001_ooool2o`000003ooooool0003o000000?o00001Oooool2o`0000?ooooo0ol0
0009ooooo`;o00004?ooool3o`0000;ooooo1?l00006ooooo`;o00004?ooool2o`0005oooooo000L
ooooo`03o`000?oooooooooo05gooooo0_l0000?ooooo`;o00001Oooool2o`0000Cooooo0_l00007
ooooo`;o00001oooool2o`0000gooooo0ol00005ooooo`;o00000oooool5o`0000Oooooo1_l0000=
ooooo`;o00000_ooool2o`0007_ooooo000Looooo`03o`000?oooooooooo05kooooo0_l0000>oooo
o`;o00001Oooool2o`0000Oooooo0_l00004ooooo`;o00001oooool4o`0000_ooooo0_l0000=oooo
o`Ko00001?ooool6o`0000Oooooo1?l0000Dooooo`?o0000K?ooool001cooooo00?o0000oooooooo
ool0G_ooool2o`0001kooooo0_l0000?ooooo`;o00003oooool4o`0000Sooooo1Ol0000>ooooo`;o
000000?oooooo`000?l000000_l0000@ooooo`;o00000_ooool3o`0000?ooooo0_l0001Wooooo`00
7?ooool00ol0003oooooooooo`1Pooooo`;o00004oooool2o`0001gooooo0_l0000:ooooo`Co0000
1_ooool2o`0000?ooooo0_l00005ooooo`;o00001oooool2o`0000?ooooo0_l0000@ooooo`;o0000
2?ooool2o`0006Oooooo000Looooo`03o`000?oooooooooo063ooooo0_l0000Cooooo`;o00003?oo
ool2o`0000oooooo0_l0000Dooooo`;o00002_ooool3o`0001[ooooo0_l0001dooooo`007?ooool0
0ol0003oooooooooo`1jooooo`;o00001oooool2o`0000_ooooo0_l00002ooooo`;o00005?ooool2
o`0000_ooooo0ol00009ooooo`;o00003_ooool2o`0000[ooooo0_l0001Xooooo`0000Koooooonk^
k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo
00?o0000ooooooooool0L?ooool2o`0000Gooooo0_l000000ooooooo0000o`00000?ooooo`;o0000
0oooool2o`0000Gooooo0_l000000ooooooo0000o`00000:ooooo`;o00000_ooool2o`0000cooooo
0_l00005ooooo`;o00000_ooool2o`0001[ooooo0_l0001Xooooo`0000KoooooogMgMonHV9Sooooo
oiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000oooo
ooooool0L?ooool3o`0000Cooooo1?l0000@ooooo`;o00002_ooool5o`0000;ooooo0_l00006oooo
o`Oo00002oooool2o`0000Gooooo0_l0000:ooooo`;o000000?oooooo`000?l000001Oooool2o`00
00Cooooo0_l0001/ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`1aooooo`;o00001Oooool4o`00
00kooooo0ol00003ooooo`;o00000_ooool2o`0000;ooooo0_l00004ooooo`;o00002?ooool8o`00
00Cooooo0ol0000<ooooo`;o00001?ooool4o`000003ooooool0003o000000Gooooo0_l00004oooo
o`;o0000K?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Olb<S;o
V9RHoooooonHV9So<S8b00Kooooo0ol0001fooooo`;o00000_ooool2o`0000kooooo0_l00004oooo
o`?o000000?oooooo`000?l000005oooool4o`0000?ooooo1?l00002ooooo`;o00001_ooool3o`00
00Cooooo0_l0001nooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05
olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`1fooooo`;o00006Oooool2o`00
0003ooooool0003o000001Wooooo1?l00003ooooo`;o00000_ooool3o`000003ooooool0003o0000
00;ooooo0ol00024ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05
oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`1looooo`;o00005_ooool2o`00
00Gooooo0_l00007ooooo`;o00002oooool2o`0000?ooooo0_l00003ooooo`;o000000?oooooo`00
0?l000000oooool2o`0008Cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000
okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo07cooooo0_l00008ooooo`;o00004ooo
ool2o`0000Oooooo0_l0000@ooooo`;o00001_ooool2o`0008Wooooo00001_ooooook^k^oc8b<_l0
003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo07go
oooo0_l00007ooooo`;o00002_ooool2o`0000kooooo0_l000001?oooooo0000o`000?l0000Foooo
o`;o0000ROooool001cooooo00?o0000ooooooooool0OOooool2o`0000[ooooo1?l00005ooooo`;o
00003?ooool4o`000004ooooool0003o0000o`000:7ooooo000Looooo`03o`000?oooooooooo05co
oooo0_l0000[ooooo`Co00004oooool2o`0000[ooooo0_l0002Kooooo`007?ooool00ol0003ooooo
ooooo`1Looooo`;o0000:oooool2o`0000?ooooo0_l0000@ooooo`Go00001oooool2o`0009_ooooo
000Looooo`03o`000?oooooooooo08kooooo0_l00002ooooo`?o00002oooool5o`0000Wooooo0_l0
002Iooooo`007?ooool00ol0003oooooooooo`2?ooooo`;o000000Coooooo`000?l0003o00002_oo
ool3o`0000[ooooo1?l0002Iooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o0000;Oooool2
o`0000Wooooo0_l00003ooooo`?o00002_ooool2o`0009_ooooo000Looooo`03o`000?oooooooooo
063ooooo0_l0000hooooo`;o00001?ooool2o`0000[ooooo0_l00002ooooo`;o00001Oooool2o`00
093ooooo000Looooo`03o`000?oooooooooo0:cooooo0_l00002ooooo`;o00001Oooool2o`00093o
oooo000Looooo`03o`000?oooooooooo0:?ooooo0_l0002Tooooo`007?ooool00ol0003ooooooooo
o`2Sooooo`;o0000Y?ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`00
06_ooooo0_l0003Mooooo`007?ooool00ol0003oooooooooo`1Zooooo`;o0000gOooool001cooooo
00?o0000ooooooooool0K?ooool2o`000=_ooooo000Looooo`03o`000?oooooooooo06cooooo0_l0
003Kooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
07?ooooo0_l0003Dooooo`007?ooool00ol0003oooooooooo`1cooooo`;o0000e?ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0Noooool2o`00
0<cooooo000Looooo`03o`000?oooooooooo07_ooooo0_l0003<ooooo`007?ooool00ol0003ooooo
ooooo`1nooooo`;o0000bOooool001cooooo00?o0000ooooooooool0O_ooool2o`000<Wooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0Qoooool2o`000<3ooooo
000Looooo`03o`000?oooooooooo08Oooooo0_l00030ooooo`007?ooool00ol0003oooooooooo`2V
ooooo`;o0000XOooool001cooooo00?o0000ooooooooool0Soooool2o`0001Gooooo0_l00002oooo
o`;o0000WOooool001cooooo00?o0000ooooooooool0Soooool2o`0000?ooooo0_l0000:ooooo`;o
00002?ooool2o`0009gooooo000Looooo`03o`000?oooooooooo09Cooooo0_l0000:ooooo`;o0000
Yoooool001cooooo00?o0000ooooooooool0V?ooool2o`0000?ooooo0_l0002Zooooo`007?ooool0
0ol0003oooooooooo`2Hooooo`;o00000oooool2o`000:[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001;ooooo1?l000000ol@413o
ooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo0ol0
003ooooood[ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000oooo
ooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`00
0?oooooooooo0?ooooooD_ooool001;ooooo00?oEEEEofIVI_l00000oooooomDooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00YOooool01?l@413o0000o`000?ooool2o`000003
oa0@4?oooooooooo01Kooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`Go00000oooool01Oo<
c<co8B4Qo`000?lQ8B7oc<c<093ooooo002Vooooo`05o`000?ooooooooooooooool000002Oooool6
o`0000gooooo00WoMgMgoc8b<_oooooooooooiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OlQ8B7o
V9RHoooooonHV9So8B4Q093ooooo002Vooooo`05o`000?ooooooooooooooool000007Oooool01ol0
003oooooooooooooooooV9RHob4Q8Oo^k^h01?ooool01Ol0003ooooooooooooooooo0000093ooooo
002Vooooo`05o`000?ooooooooooooooool000002Oooool6o`0000gooooo00?oMgMgoc8b<_ooool0
0oooool00onHV9So8B4Qonk^kP03ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80T?ooool00:Kooooo
00Go0000ohN7QoooooooZJVYo`00000Iooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00omg
MgOoIVIVooooo`02ooooo`05olc<c?l0003o0000o`000?o<c<`0T?ooool00:Gooooo00?o410@o`00
0?mgMgL00_l000000onHV9Soooooooooo`0Gooooo`03o`000?oooooooooo00Sooooo00Wo0000oooo
oooooooooooooa0@4?nj^[[ooooookZj^_l@4100T?ooool00<Cooooo00?o0000ooooooooool01?oo
ool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go0000okZj^_oooooo^[Zjo`00002@ooooo`00
a?ooool4o`0000?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05ojVYZOl@413o0000oa0@
4?nYZJT0T?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(534) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.64147 .53392 Mdot
.67284 .51075 Mdot
.34044 .36005 Mdot
.50154 .60887 Mdot
.33227 .52835 Mdot
.33678 .39631 Mdot
.50625 .30736 Mdot
.52853 .32757 Mdot
.34238 .38399 Mdot
.59578 .71853 Mdot
.52969 .29015 Mdot
.52866 .69453 Mdot
.51916 .30414 Mdot
.49704 .64979 Mdot
.58146 .43772 Mdot
.41114 .6406 Mdot
.71704 .54043 Mdot
.30148 .57934 Mdot
.40999 .63919 Mdot
.33164 .36737 Mdot
.38641 .63235 Mdot
.48569 .64324 Mdot
.71642 .52635 Mdot
.4933 .64866 Mdot
.53351 .62232 Mdot
.67357 .5198 Mdot
.6423 .52677 Mdot
.53098 .59985 Mdot
.50241 .58688 Mdot
.53163 .30352 Mdot
.23388 .37927 Mdot
.8355 .57512 Mdot
.5552 .62368 Mdot
.74748 .63845 Mdot
.53002 .32858 Mdot
.49102 .21204 Mdot
.36483 .38519 Mdot
.5153 .33218 Mdot
.54222 .31464 Mdot
.54122 .322 Mdot
.50207 .31242 Mdot
.66604 .52585 Mdot
.54614 .28684 Mdot
.3843 .34412 Mdot
.51934 .65944 Mdot
.77267 .48886 Mdot
.24977 .31416 Mdot
.51965 .59182 Mdot
.65936 .55507 Mdot
.31758 .38299 Mdot
.30179 .71717 Mdot
.49051 .31135 Mdot
.64484 .42019 Mdot
.34418 .85467 Mdot
.52614 .29545 Mdot
.49997 .59976 Mdot
.32352 .39088 Mdot
.49351 .62254 Mdot
.47414 .61484 Mdot
.74533 .6163 Mdot
.46912 .643 Mdot
.30115 .54345 Mdot
.66038 .49769 Mdot
.38305 .40513 Mdot
.33687 .38716 Mdot
.50256 .32189 Mdot
.69029 .50115 Mdot
.5183 .31677 Mdot
.48983 .57938 Mdot
.32105 .37194 Mdot
.5097 .59154 Mdot
.53288 .29758 Mdot
.68976 .50489 Mdot
.52518 .65865 Mdot
.72786 .42996 Mdot
.53036 .36412 Mdot
.3401 .46969 Mdot
.70042 .73112 Mdot
.34471 .78413 Mdot
.28307 .3954 Mdot
.50174 .66339 Mdot
.25616 .73561 Mdot
.56536 .40219 Mdot
.6652 .5097 Mdot
.72115 .49076 Mdot
.73647 .30931 Mdot
.52053 .58775 Mdot
.37839 .50066 Mdot
.54171 .66572 Mdot
.49336 .50297 Mdot
.34609 .37842 Mdot
.69087 .51457 Mdot
.51859 .66244 Mdot
.53684 .66416 Mdot
.60876 .62607 Mdot
.47698 .59321 Mdot
.51391 .62948 Mdot
.67284 .4818 Mdot
.51801 .27765 Mdot
.57348 .65978 Mdot
.2343 .53283 Mdot
.63467 .4166 Mdot
.51371 .6126 Mdot
.35444 .41102 Mdot
.64528 .50412 Mdot
.51987 .63827 Mdot
.51994 .32358 Mdot
.48987 .65646 Mdot
.49061 .26805 Mdot
.70972 .54366 Mdot
.53852 .66525 Mdot
.29696 .50895 Mdot
.5593 .50538 Mdot
.68475 .55002 Mdot
.59278 .78577 Mdot
.47172 .6446 Mdot
.47436 .63202 Mdot
.66193 .51458 Mdot
.35242 .36586 Mdot
.41157 .45855 Mdot
.71138 .5189 Mdot
.54359 .31531 Mdot
.68336 .55912 Mdot
.5099 .69176 Mdot
.34951 .3654 Mdot
.63605 .42775 Mdot
.63843 .41698 Mdot
.27081 .59519 Mdot
.52589 .66168 Mdot
.59016 .5232 Mdot
.34401 .40947 Mdot
.66322 .52126 Mdot
.52342 .31334 Mdot
.46166 .62086 Mdot
.67187 .54439 Mdot
.54341 .30042 Mdot
.30201 .5596 Mdot
.33373 .53158 Mdot
.65646 .54488 Mdot
.48449 .76014 Mdot
.48638 .2988 Mdot
.54332 .32259 Mdot
.30176 .7117 Mdot
.65903 .513 Mdot
.31864 .53503 Mdot
.53741 .27953 Mdot
.34928 .65991 Mdot
.45863 .64362 Mdot
.27077 .63382 Mdot
.19174 .65427 Mdot
.30146 .71478 Mdot
.79769 .60899 Mdot
.30807 .50537 Mdot
.53859 .27952 Mdot
.51726 .599 Mdot
.67697 .53703 Mdot
.66627 .53758 Mdot
.53247 .66591 Mdot
.53803 .63927 Mdot
.51227 .6523 Mdot
.46069 .62823 Mdot
.42957 .19536 Mdot
.5094 .66367 Mdot
.59417 .29335 Mdot
.68046 .54461 Mdot
.53273 .63827 Mdot
.35986 .41668 Mdot
.44954 .6692 Mdot
.51818 .33148 Mdot
.47948 .61136 Mdot
.5384 .63062 Mdot
.45022 .65582 Mdot
.54396 .28564 Mdot
.72674 .39688 Mdot
.42105 .81992 Mdot
.51014 .21638 Mdot
.65343 .40073 Mdot
.33301 .41179 Mdot
.48074 .66683 Mdot
.30931 .51495 Mdot
.5377 .69688 Mdot
.46945 .62506 Mdot
.30166 .72316 Mdot
.54397 .63407 Mdot
.76521 .66217 Mdot
.579 .63382 Mdot
.72194 .28649 Mdot
.60591 .27088 Mdot
.4643 .63024 Mdot
.56306 .74357 Mdot
.26597 .61596 Mdot
.20484 .40459 Mdot
.52845 .30893 Mdot
.36151 .42206 Mdot
.36042 .37032 Mdot
.53759 .33278 Mdot
.5446 .57375 Mdot
.59981 .7259 Mdot
.47276 .59115 Mdot
.63447 .42646 Mdot
.73768 .54809 Mdot
.31535 .50894 Mdot
.65543 .545 Mdot
.28045 .76144 Mdot
.3846 .53006 Mdot
.29425 .39362 Mdot
.30841 .57618 Mdot
.314 .40687 Mdot
.61862 .43065 Mdot
.31729 .52384 Mdot
.50561 .62045 Mdot
.6916 .55385 Mdot
.26205 .61689 Mdot
.42083 .64163 Mdot
.5637 .13547 Mdot
.66903 .50379 Mdot
.52508 .46986 Mdot
.52589 .30214 Mdot
.38102 .39979 Mdot
.52112 .58836 Mdot
.5004 .63562 Mdot
.65167 .5038 Mdot
.51231 .58889 Mdot
.41729 .49117 Mdot
.54046 .62835 Mdot
.37009 .42968 Mdot
.27434 .54686 Mdot
.49002 .26289 Mdot
.32193 .57924 Mdot
.69964 .50949 Mdot
.56119 .35265 Mdot
.35709 .41348 Mdot
.54159 .54221 Mdot
.53192 .31511 Mdot
.29571 .55573 Mdot
.36399 .39483 Mdot
.28884 .51522 Mdot
.50647 .67892 Mdot
.35966 .37866 Mdot
.30971 .54858 Mdot
.4661 .37807 Mdot
.51484 .62902 Mdot
.30105 .64661 Mdot
.51636 .26885 Mdot
.64422 .53398 Mdot
.46614 .63606 Mdot
.63729 .43387 Mdot
.47392 .68582 Mdot
.57918 .50003 Mdot
.61343 .43304 Mdot
.60813 .40957 Mdot
.29747 .42036 Mdot
.32217 .54895 Mdot
.70786 .44567 Mdot
.44403 .43597 Mdot
.71822 .53894 Mdot
.49473 .67867 Mdot
.77259 .39577 Mdot
.5169 .2679 Mdot
.50229 .61886 Mdot
.71629 .29696 Mdot
.53683 .27807 Mdot
.48602 .62308 Mdot
.49996 .30556 Mdot
.67074 .53912 Mdot
.51365 .39347 Mdot
.66505 .56232 Mdot
.4978 .60924 Mdot
.50665 .2858 Mdot
.36466 .41606 Mdot
.67401 .52043 Mdot
.4845 .65144 Mdot
.50191 .66639 Mdot
.63015 .42701 Mdot
.53201 .65008 Mdot
.78349 .3821 Mdot
.52168 .59343 Mdot
.31139 .39888 Mdot
.48634 .58569 Mdot
.24553 .62024 Mdot
.33511 .53849 Mdot
.71296 .50809 Mdot
.60883 .42944 Mdot
.34422 .37531 Mdot
.49162 .38438 Mdot
.28348 .59275 Mdot
.49836 .65924 Mdot
.61949 .41411 Mdot
.5249 .46449 Mdot
.51003 .32662 Mdot
.53128 .58619 Mdot
.41381 .47423 Mdot
.35319 .38392 Mdot
.62811 .43041 Mdot
.45115 .58366 Mdot
.63871 .54037 Mdot
.50429 .5987 Mdot
.36623 .39211 Mdot
.64716 .54944 Mdot
.47171 .60606 Mdot
.32861 .25366 Mdot
.64075 .43158 Mdot
.50297 .28256 Mdot
.60694 .57772 Mdot
.50103 .67212 Mdot
.36622 .37514 Mdot
.66599 .54286 Mdot
.5173 .28714 Mdot
.70641 .54065 Mdot
.25156 .60105 Mdot
.60319 .52771 Mdot
.42847 .22672 Mdot
.29493 .57836 Mdot
.75424 .72567 Mdot
.50439 .2165 Mdot
.59166 .54676 Mdot
.36955 .45432 Mdot
.64422 .20786 Mdot
.36137 .40154 Mdot
.51572 .76155 Mdot
.33453 .37847 Mdot
.51343 .60522 Mdot
.33725 .39292 Mdot
.79157 .36704 Mdot
.54054 .61587 Mdot
.32547 .4073 Mdot
.40618 .2279 Mdot
.54524 .6369 Mdot
.67773 .547 Mdot
.8144 .51585 Mdot
.61589 .78641 Mdot
.44528 .74632 Mdot
.3213 .40289 Mdot
.50805 .77193 Mdot
.5284 .59487 Mdot
.41308 .62987 Mdot
.67866 .53199 Mdot
.50246 .69661 Mdot
.31575 .50038 Mdot
.29741 .50461 Mdot
.3353 .71844 Mdot
.64313 .7889 Mdot
.48143 .55225 Mdot
.67048 .52629 Mdot
.32744 .77316 Mdot
.73368 .43148 Mdot
.64348 .42821 Mdot
.53862 .31873 Mdot
.71724 .3952 Mdot
.44915 .58121 Mdot
.58411 .66146 Mdot
.44873 .46983 Mdot
.69213 .5134 Mdot
.44295 .28024 Mdot
.51253 .28983 Mdot
.5117 .78778 Mdot
.63183 .69159 Mdot
.51373 .65002 Mdot
.49524 .28381 Mdot
.57037 .64798 Mdot
.43579 .47578 Mdot
.28962 .64276 Mdot
.31595 .30185 Mdot
.50594 .61645 Mdot
.72045 .44686 Mdot
.47187 .62389 Mdot
.27602 .61889 Mdot
.4982 .6136 Mdot
.70256 .542 Mdot
.49405 .55879 Mdot
.44825 .41457 Mdot
.51307 .80757 Mdot
.3869 .52501 Mdot
.32384 .53529 Mdot
.49788 .64698 Mdot
.50822 .6389 Mdot
.30224 .54807 Mdot
.69515 .51913 Mdot
.48148 .67513 Mdot
.25691 .30203 Mdot
.51092 .66443 Mdot
.49361 .31795 Mdot
.49692 .40993 Mdot
.76109 .68139 Mdot
.54664 .62813 Mdot
.63788 .53321 Mdot
.5103 .32374 Mdot
.53932 .3048 Mdot
.47984 .55561 Mdot
.50991 .27114 Mdot
.51538 .5956 Mdot
.49924 .41017 Mdot
.71694 .53073 Mdot
.55412 .67985 Mdot
.6988 .52242 Mdot
.29372 .73525 Mdot
.5317 .26999 Mdot
.61378 .4124 Mdot
.49065 .77336 Mdot
.5089 .30288 Mdot
.4107 .55254 Mdot
.51105 .56305 Mdot
.43093 .61854 Mdot
.60927 .55892 Mdot
.36922 .40955 Mdot
.60992 .41868 Mdot
.5242 .29137 Mdot
.51108 .66261 Mdot
.51997 .62973 Mdot
.49104 .29121 Mdot
.70522 .61121 Mdot
.2364 .3759 Mdot
.49405 .60833 Mdot
.707 .53572 Mdot
.66414 .52228 Mdot
.45487 .64686 Mdot
.46873 .62987 Mdot
.33222 .42673 Mdot
.61834 .41363 Mdot
.60637 .42203 Mdot
.6286 .4089 Mdot
.35425 .44042 Mdot
.7194 .75757 Mdot
.54355 .32235 Mdot
.80871 .61153 Mdot
.724 .3427 Mdot
.44856 .56591 Mdot
.36861 .38591 Mdot
.49136 .63178 Mdot
.51892 .61784 Mdot
.50951 .28167 Mdot
.61577 .81116 Mdot
.5582 .62156 Mdot
.6448 .52443 Mdot
.49069 .3078 Mdot
.5384 .68888 Mdot
.55308 .33327 Mdot
.28836 .52975 Mdot
.39542 .659 Mdot
.49674 .27821 Mdot
.70582 .54446 Mdot
.49483 .28072 Mdot
.51008 .64336 Mdot
.44032 .59635 Mdot
.69088 .51168 Mdot
.30828 .56679 Mdot
.51208 .67408 Mdot
.48435 .62232 Mdot
.1721 .49721 Mdot
.72769 .43251 Mdot
.28735 .47567 Mdot
.52543 .61293 Mdot
.43598 .62089 Mdot
.29765 .56782 Mdot
.49324 .67471 Mdot
.49701 .58778 Mdot
.55689 .50145 Mdot
.48425 .27716 Mdot
.32904 .53107 Mdot
.50023 .80021 Mdot
.66296 .50533 Mdot
.77343 .36522 Mdot
.63767 .42123 Mdot
.50726 .24715 Mdot
.51931 .39074 Mdot
.61545 .4242 Mdot
.70516 .30024 Mdot
.5199 .2134 Mdot
.61431 .4165 Mdot
.38288 .38942 Mdot
.51121 .72308 Mdot
.49607 .58581 Mdot
.48087 .61417 Mdot
.32065 .55026 Mdot
.6516 .52438 Mdot
.59871 .29339 Mdot
.47856 .30134 Mdot
.4804 .63929 Mdot
.65695 .56474 Mdot
.72908 .29735 Mdot
.62286 .42983 Mdot
.30409 .51136 Mdot
.31851 .56208 Mdot
.4729 .62571 Mdot
.48822 .5245 Mdot
.67019 .52366 Mdot
.48453 .65133 Mdot
.46578 .65188 Mdot
.33184 .3753 Mdot
.68444 .55608 Mdot
.35504 .41966 Mdot
.605 .42844 Mdot
.59948 .17413 Mdot
.16743 .44886 Mdot
.52517 .27192 Mdot
.46262 .26351 Mdot
.52325 .25618 Mdot
.33645 .28274 Mdot
.61652 .41348 Mdot
.48435 .64748 Mdot
.70768 .51176 Mdot
.4875 .65506 Mdot
.51411 .66405 Mdot
.51784 .64645 Mdot
.47899 .55232 Mdot
.29113 .72016 Mdot
.29811 .5248 Mdot
.50529 .5743 Mdot
.32494 .42516 Mdot
.71892 .28818 Mdot
.80343 .4705 Mdot
.50182 .64372 Mdot
.47579 .63061 Mdot
.67524 .49962 Mdot
.50641 .67993 Mdot
.52061 .32551 Mdot
.66425 .50748 Mdot
.51413 .61726 Mdot
.22953 .5521 Mdot
.47346 .6698 Mdot
.47066 .24487 Mdot
.49641 .27698 Mdot
.42747 .69248 Mdot
.44504 .5991 Mdot
.61473 .41342 Mdot
.61049 .41882 Mdot
.63303 .4372 Mdot
.49278 .30552 Mdot
.33465 .37394 Mdot
.35097 .34879 Mdot
.4631 .57931 Mdot
.52032 .59898 Mdot
.43683 .60401 Mdot
.32744 .44103 Mdot
.44 .43028 Mdot
.73468 .4775 Mdot
.5791 .62771 Mdot
.34618 .43918 Mdot
.63369 .49759 Mdot
.54215 .80411 Mdot
.65325 .5147 Mdot
.35987 .45827 Mdot
.53073 .32142 Mdot
.30524 .5036 Mdot
.3424 .75569 Mdot
.71391 .52476 Mdot
.64886 .50784 Mdot
.32941 .41108 Mdot
.54128 .43547 Mdot
.43501 .90696 Mdot
.35115 .40847 Mdot
.33155 .47519 Mdot
.67661 .52905 Mdot
.55782 .63084 Mdot
.52648 .46061 Mdot
.54928 .45862 Mdot
.32648 .39857 Mdot
.50026 .66577 Mdot
.4185 .53983 Mdot
.33172 .42614 Mdot
.53362 .58519 Mdot
.32134 .40566 Mdot
.50224 .2791 Mdot
.34291 .41367 Mdot
.70181 .56214 Mdot
.5198 .66484 Mdot
.37154 .87273 Mdot
.56265 .39604 Mdot
.47797 .65228 Mdot
.48938 .30088 Mdot
.3825 .22289 Mdot
.51103 .63672 Mdot
.31888 .50771 Mdot
.3393 .4405 Mdot
.31057 .29365 Mdot
.49634 .58995 Mdot
.33143 .39689 Mdot
.72391 .54709 Mdot
.36542 .45308 Mdot
.27124 .48097 Mdot
.60769 .42054 Mdot
.6737 .54039 Mdot
.61027 .39997 Mdot
.52826 .33097 Mdot
.46672 .67428 Mdot
.47017 .66153 Mdot
.69102 .54393 Mdot
.47727 .37599 Mdot
.54405 .58432 Mdot
.50206 .66305 Mdot
.33697 .42715 Mdot
.32092 .42711 Mdot
.6051 .44972 Mdot
.36172 .40875 Mdot
.43669 .62098 Mdot
.69214 .54518 Mdot
.50753 .60365 Mdot
.66759 .54685 Mdot
.49892 .67861 Mdot
.66077 .4418 Mdot
.651 .51889 Mdot
.55413 .53831 Mdot
.53167 .65864 Mdot
.69199 .58617 Mdot
.50736 .67184 Mdot
.5104 .62385 Mdot
.33426 .44116 Mdot
.30698 .52919 Mdot
.54907 .61386 Mdot
.55913 .34914 Mdot
.28918 .55929 Mdot
.77842 .59055 Mdot
.35103 .36632 Mdot
.30678 .56332 Mdot
.33051 .6822 Mdot
.60907 .4295 Mdot
.2977 .53835 Mdot
.61207 .44178 Mdot
.52013 .27101 Mdot
.70313 .55344 Mdot
.54279 .64607 Mdot
.64554 .20244 Mdot
.23404 .38015 Mdot
.62838 .42429 Mdot
.46732 .63664 Mdot
.49472 .62959 Mdot
.64282 .54761 Mdot
.27193 .75071 Mdot
.3764 .42428 Mdot
.50856 .61566 Mdot
.70709 .51641 Mdot
.22831 .70215 Mdot
.32503 .41274 Mdot
.29396 .52938 Mdot
.51084 .26141 Mdot
.70963 .57061 Mdot
.6081 .4159 Mdot
.53223 .27016 Mdot
.33361 .4626 Mdot
.30306 .73019 Mdot
.4948 .59109 Mdot
.36903 .40205 Mdot
.3013 .71536 Mdot
.57782 .63862 Mdot
.5525 .30161 Mdot
.65518 .44777 Mdot
.68842 .5133 Mdot
.49032 .2958 Mdot
.32495 .5398 Mdot
.71429 .54217 Mdot
.69691 .51907 Mdot
.53163 .3243 Mdot
.60072 .24004 Mdot
.5289 .46686 Mdot
.50771 .33038 Mdot
.55416 .48298 Mdot
.30056 .70871 Mdot
.62109 .41086 Mdot
.30508 .51035 Mdot
.2246 .57781 Mdot
.66802 .52334 Mdot
.71865 .39528 Mdot
.30219 .72104 Mdot
.51368 .62885 Mdot
.31565 .54634 Mdot
.73368 .3165 Mdot
.49643 .25219 Mdot
.54256 .29586 Mdot
.39124 .47445 Mdot
.3209 .51748 Mdot
.46179 .65438 Mdot
.74705 .70189 Mdot
.54043 .65414 Mdot
.53333 .27352 Mdot
.43856 .48064 Mdot
.68398 .55552 Mdot
.52617 .3332 Mdot
.41179 .4932 Mdot
.51949 .61625 Mdot
.47172 .65134 Mdot
.32238 .59074 Mdot
.6787 .5581 Mdot
.60849 .41257 Mdot
.49369 .66189 Mdot
.49168 .62069 Mdot
.46102 .66772 Mdot
.47018 .7764 Mdot
.54164 .52411 Mdot
.51218 .61892 Mdot
.37778 .40544 Mdot
.43122 .63437 Mdot
.46404 .62405 Mdot
.6437 .55211 Mdot
.24403 .63108 Mdot
.60484 .42867 Mdot
.48344 .61353 Mdot
.49325 .60859 Mdot
.53963 .32094 Mdot
.52716 .46537 Mdot
.55127 .46059 Mdot
.31329 .3995 Mdot
.36618 .48221 Mdot
.46422 .59537 Mdot
.68135 .54137 Mdot
.31529 .49851 Mdot
.44302 .64672 Mdot
.65184 .51372 Mdot
.49203 .57237 Mdot
.32222 .42046 Mdot
.61901 .41634 Mdot
.57981 .59087 Mdot
.30279 .54025 Mdot
.48521 .29006 Mdot
.81582 .58721 Mdot
.35743 .42373 Mdot
.53085 .60934 Mdot
.3359 .345 Mdot
.35226 .39604 Mdot
.63144 .42431 Mdot
.42059 .63118 Mdot
.66863 .53567 Mdot
.69303 .55133 Mdot
.28253 .68545 Mdot
.36243 .43552 Mdot
.16807 .56288 Mdot
.50403 .27663 Mdot
.52736 .58574 Mdot
.77957 .45125 Mdot
.68475 .55408 Mdot
.27314 .60437 Mdot
.30605 .56423 Mdot
.54223 .2951 Mdot
.59808 .41402 Mdot
.64834 .52156 Mdot
.6727 .55363 Mdot
.51801 .66211 Mdot
.49358 .64107 Mdot
.36335 .4641 Mdot
.26932 .62447 Mdot
.50031 .30578 Mdot
.29335 .52433 Mdot
.31362 .38789 Mdot
.52001 .61073 Mdot
.67693 .50876 Mdot
.74837 .69396 Mdot
.4986 .67188 Mdot
.32329 .42046 Mdot
.67971 .51251 Mdot
.29293 .5415 Mdot
.30714 .55703 Mdot
.51252 .62767 Mdot
.74277 .68046 Mdot
.50926 .30648 Mdot
.68434 .54776 Mdot
.70703 .48696 Mdot
.5006 .57703 Mdot
.49839 .64401 Mdot
.55483 .66302 Mdot
.54875 .31693 Mdot
.584 .59978 Mdot
.29421 .57089 Mdot
.65697 .53253 Mdot
.48417 .65627 Mdot
.30068 .54329 Mdot
.58754 .65294 Mdot
.61826 .42224 Mdot
.32587 .41199 Mdot
.31686 .50521 Mdot
.31285 .53758 Mdot
.28977 .55699 Mdot
.71707 .39767 Mdot
.64443 .50383 Mdot
.47054 .8152 Mdot
.51482 .66669 Mdot
.30026 .70614 Mdot
.50807 .68246 Mdot
.49718 .29608 Mdot
.36211 .42407 Mdot
.51523 .65906 Mdot
.51595 .66665 Mdot
.77885 .64259 Mdot
.40771 .65253 Mdot
.40677 .66751 Mdot
.70262 .54826 Mdot
.62377 .58579 Mdot
.36864 .38009 Mdot
.17057 .62944 Mdot
.83401 .48473 Mdot
.46975 .59436 Mdot
.53761 .43143 Mdot
.66462 .50804 Mdot
.54449 .29632 Mdot
.54389 .47398 Mdot
.53177 .23895 Mdot
.65577 .5252 Mdot
.51573 .60807 Mdot
.80803 .59432 Mdot
.28338 .53422 Mdot
.51109 .65042 Mdot
.52391 .31589 Mdot
.51168 .65132 Mdot
.4946 .30497 Mdot
.73042 .56564 Mdot
.55514 .44311 Mdot
.54405 .63029 Mdot
.4798 .58959 Mdot
.58341 .64295 Mdot
.49927 .64242 Mdot
.36053 .30618 Mdot
.68774 .52254 Mdot
.54311 .53891 Mdot
.452 .64459 Mdot
.70057 .71148 Mdot
.47197 .6662 Mdot
.49688 .37437 Mdot
.47235 .66012 Mdot
.42223 .74137 Mdot
.46012 .64981 Mdot
.47913 .6657 Mdot
.51091 .28731 Mdot
.54399 .31218 Mdot
.7287 .5444 Mdot
.61197 .40904 Mdot
.72097 .28656 Mdot
.48001 .62622 Mdot
.32556 .43599 Mdot
.63019 .46344 Mdot
.31129 .53214 Mdot
.65801 .52832 Mdot
.12218 .50711 Mdot
.50484 .31935 Mdot
.38303 .40141 Mdot
.28871 .37049 Mdot
.37434 .3784 Mdot
.32551 .44612 Mdot
.66755 .58653 Mdot
.30043 .51177 Mdot
.46595 .66004 Mdot
.75043 .6457 Mdot
.72898 .44349 Mdot
.50478 .57918 Mdot
.35401 .34441 Mdot
.48041 .70723 Mdot
.29225 .70808 Mdot
.28901 .51226 Mdot
.31192 .50749 Mdot
.51962 .2893 Mdot
.34464 .36095 Mdot
.57548 .63311 Mdot
.306 .56308 Mdot
.35922 .42577 Mdot
.63991 .41511 Mdot
.35042 .53613 Mdot
.66704 .52716 Mdot
.46727 .75169 Mdot
.77667 .47308 Mdot
.50276 .31541 Mdot
.5525 .35889 Mdot
.63961 .49902 Mdot
.72143 .50732 Mdot
.6174 .40711 Mdot
.32874 .42919 Mdot
.71574 .54416 Mdot
.5189 .66456 Mdot
.42085 .64132 Mdot
.47162 .6271 Mdot
.31562 .55626 Mdot
.46481 .64609 Mdot
.33792 .43271 Mdot
.50603 .31185 Mdot
.34854 .37885 Mdot
.50577 .30345 Mdot
.79967 .56366 Mdot
.46917 .61998 Mdot
.49571 .64484 Mdot
.50856 .41296 Mdot
.66309 .55016 Mdot
.73899 .63886 Mdot
.32632 .42808 Mdot
.3266 .38467 Mdot
.50835 .60545 Mdot
.70622 .50347 Mdot
.29006 .58461 Mdot
.52818 .44565 Mdot
.46961 .65757 Mdot
.68852 .52318 Mdot
.50399 .60149 Mdot
.34456 .26448 Mdot
.56512 .43301 Mdot
.70253 .54391 Mdot
.51587 .80902 Mdot
.53028 .65441 Mdot
.41697 .66969 Mdot
.43537 .67885 Mdot
.38414 .65958 Mdot
.544 .59578 Mdot
.67135 .50394 Mdot
.47784 .61148 Mdot
.68397 .53769 Mdot
.35658 .39893 Mdot
.5463 .31764 Mdot
.68119 .53575 Mdot
.53732 .65707 Mdot
.82976 .5025 Mdot
.51125 .32056 Mdot
.50609 .65512 Mdot
.52641 .28843 Mdot
.69 .56033 Mdot
.65698 .55104 Mdot
.60231 .43947 Mdot
.30127 .42585 Mdot
.51603 .3221 Mdot
.51935 .59717 Mdot
.72695 .41313 Mdot
.50756 .6031 Mdot
.36112 .48346 Mdot
.45281 .63061 Mdot
.49265 .5821 Mdot
.76767 .7134 Mdot
.48951 .38023 Mdot
.14752 .54495 Mdot
.48452 .33544 Mdot
.72912 .40288 Mdot
.73964 .52035 Mdot
.28972 .51119 Mdot
.45488 .28709 Mdot
.62221 .43549 Mdot
.37769 .39814 Mdot
.51437 .66128 Mdot
.77784 .52852 Mdot
.49914 .32422 Mdot
.30615 .52441 Mdot
.54394 .63272 Mdot
.33866 .35686 Mdot
.59306 .38532 Mdot
.53953 .28224 Mdot
.66484 .52728 Mdot
.65467 .54538 Mdot
.36576 .79861 Mdot
.48026 .65278 Mdot
.48874 .64233 Mdot
.5229 .32869 Mdot
.57354 .61301 Mdot
.28717 .54864 Mdot
.40815 .23673 Mdot
.52697 .31438 Mdot
.56637 .4224 Mdot
.70628 .54695 Mdot
.49352 .63063 Mdot
.49506 .41021 Mdot
.68065 .35594 Mdot
.60232 .67105 Mdot
.32099 .5337 Mdot
.35491 .5889 Mdot
.67118 .50385 Mdot
.52524 .31183 Mdot
.33076 .705 Mdot
.52985 .67574 Mdot
.49464 .62723 Mdot
.34483 .59738 Mdot
.53145 .45058 Mdot
.3546 .49986 Mdot
.54051 .67658 Mdot
.50895 .46481 Mdot
.50949 .60663 Mdot
.52004 .62935 Mdot
.48801 .58016 Mdot
.47138 .6098 Mdot
.68992 .52731 Mdot
.63327 .77682 Mdot
.33804 .40224 Mdot
.56602 .72556 Mdot
.38949 .46685 Mdot
.52968 .59464 Mdot
.51711 .6116 Mdot
.60757 .75823 Mdot
.6036 .5007 Mdot
.68191 .52273 Mdot
.7034 .48677 Mdot
.54136 .3249 Mdot
.40717 .651 Mdot
.3554 .44131 Mdot
.4414 .69697 Mdot
.34585 .38791 Mdot
.69019 .52357 Mdot
.34305 .36999 Mdot
.49855 .33758 Mdot
.36893 .40187 Mdot
.36241 .43318 Mdot
.52731 .26466 Mdot
.66385 .5579 Mdot
.48348 .66904 Mdot
.52255 .26484 Mdot
.30779 .59364 Mdot
.31508 .5565 Mdot
.6091 .4445 Mdot
.55815 .63057 Mdot
.40929 .66151 Mdot
.32536 .25664 Mdot
.35541 .37359 Mdot
.57291 .485 Mdot
.65065 .51982 Mdot
.32387 .5145 Mdot
.68938 .53099 Mdot
.40295 .78702 Mdot
.30825 .54392 Mdot
.61101 .44495 Mdot
.32226 .69587 Mdot
.56638 .30742 Mdot
.46616 .68282 Mdot
.60806 .56494 Mdot
.34814 .38691 Mdot
.49263 .31613 Mdot
.72711 .30601 Mdot
.52788 .64997 Mdot
.63987 .40557 Mdot
.71194 .49762 Mdot
.60818 .42783 Mdot
.52202 .31394 Mdot
.4707 .32017 Mdot
.47625 .6483 Mdot
.55822 .33661 Mdot
.47582 .59712 Mdot
.49489 .77254 Mdot
.36487 .47618 Mdot
.61443 .52088 Mdot
.50556 .59755 Mdot
.32649 .42093 Mdot
.50619 .59949 Mdot
.50265 .74212 Mdot
.31208 .71234 Mdot
.46376 .60319 Mdot
.60235 .55039 Mdot
.31443 .28171 Mdot
.68283 .51032 Mdot
.44002 .61569 Mdot
.62639 .41584 Mdot
.52942 .62404 Mdot
.69815 .20818 Mdot
.29942 .53674 Mdot
.29951 .47742 Mdot
.53444 .6596 Mdot
.49164 .65911 Mdot
.75707 .66429 Mdot
.62378 .57543 Mdot
.59698 .41579 Mdot
.49945 .62549 Mdot
.36029 .59761 Mdot
.51564 .28547 Mdot
.46807 .61036 Mdot
.47724 .615 Mdot
.18039 .46948 Mdot
.51742 .28348 Mdot
.36151 .37604 Mdot
.61112 .43128 Mdot
.31511 .40264 Mdot
.31571 .4902 Mdot
.52242 .49133 Mdot
.2788 .60923 Mdot
.56795 .43508 Mdot
.32349 .52116 Mdot
.52809 .59104 Mdot
.69516 .47889 Mdot
.48289 .66085 Mdot
.31379 .5111 Mdot
.53168 .30299 Mdot
.68654 .52781 Mdot
.47955 .75771 Mdot
.63445 .42516 Mdot
.51546 .57811 Mdot
.28469 .51788 Mdot
.67554 .53588 Mdot
.61685 .33775 Mdot
.6541 .51956 Mdot
.50814 .29772 Mdot
.53284 .33442 Mdot
.30836 .53727 Mdot
.69072 .52916 Mdot
.31741 .39288 Mdot
.48419 .33724 Mdot
.45464 .62399 Mdot
.50685 .34337 Mdot
.72658 .531 Mdot
.64218 .52346 Mdot
.71214 .51169 Mdot
.47473 .60953 Mdot
.53498 .44559 Mdot
.51424 .68377 Mdot
.51575 .32467 Mdot
.36636 .37049 Mdot
.27529 .64067 Mdot
.74379 .66203 Mdot
.56396 .4189 Mdot
.54833 .6097 Mdot
.46551 .6421 Mdot
.47292 .62624 Mdot
.49477 .60178 Mdot
.41192 .23696 Mdot
.46974 .61943 Mdot
.50462 .28921 Mdot
.34665 .39671 Mdot
.46905 .64199 Mdot
.62321 .41462 Mdot
.43975 .43627 Mdot
.31618 .49872 Mdot
.41919 .72091 Mdot
.79707 .44479 Mdot
.67695 .53448 Mdot
.36607 .40223 Mdot
.33714 .37026 Mdot
.30185 .5595 Mdot
.52764 .2682 Mdot
.65222 .52584 Mdot
.39615 .71009 Mdot
.28534 .55531 Mdot
.4843 .61341 Mdot
.50243 .41099 Mdot
.52863 .80584 Mdot
.54344 .6127 Mdot
.51421 .6365 Mdot
.60502 .41539 Mdot
.38218 .40273 Mdot
.72303 .25105 Mdot
.60209 .25527 Mdot
.30712 .53132 Mdot
.28981 .53628 Mdot
.69788 .50467 Mdot
.52478 .58295 Mdot
.51033 .31009 Mdot
.5175 .46576 Mdot
.33757 .2405 Mdot
.76071 .33906 Mdot
.33584 .28533 Mdot
.47547 .67117 Mdot
.65134 .75389 Mdot
.44905 .64886 Mdot
.64498 .50427 Mdot
.7076 .50643 Mdot
.67552 .52421 Mdot
.51155 .28889 Mdot
.30608 .73758 Mdot
.50384 .2887 Mdot
.80047 .44703 Mdot
.69613 .51125 Mdot
.46487 .38993 Mdot
.32253 .3928 Mdot
.42416 .60857 Mdot
.30242 .51024 Mdot
.26079 .54906 Mdot
.43882 .61294 Mdot
.48309 .52776 Mdot
.36847 .38568 Mdot
.64995 .54823 Mdot
.51253 .56401 Mdot
.71049 .27424 Mdot
.54313 .43399 Mdot
.26208 .30722 Mdot
.61855 .59435 Mdot
.30321 .54767 Mdot
.58079 .73245 Mdot
.28493 .54583 Mdot
.54135 .29002 Mdot
.52752 .65414 Mdot
.52825 .66746 Mdot
.50523 .61413 Mdot
.47906 .60498 Mdot
.5252 .29176 Mdot
.44779 .63939 Mdot
.24627 .62189 Mdot
.64014 .4234 Mdot
.44914 .38351 Mdot
.30158 .55408 Mdot
.49708 .2854 Mdot
.35033 .39694 Mdot
.61566 .40636 Mdot
.31266 .58635 Mdot
.45649 .65767 Mdot
.51022 .66882 Mdot
.63962 .41792 Mdot
.5632 .58784 Mdot
.44636 .5831 Mdot
.335 .39863 Mdot
.44261 .46077 Mdot
.32481 .54938 Mdot
.30141 .50662 Mdot
.49373 .28521 Mdot
.6897 .53095 Mdot
.31479 .56082 Mdot
.34315 .36005 Mdot
.47773 .59897 Mdot
.4815 .58781 Mdot
.7267 .53166 Mdot
.30159 .72097 Mdot
.31154 .49458 Mdot
.58108 .62817 Mdot
.65907 .54125 Mdot
.70377 .49299 Mdot
.50093 .62691 Mdot
.50725 .69892 Mdot
.64303 .51114 Mdot
.29272 .54958 Mdot
.49941 .27818 Mdot
.48585 .39185 Mdot
.50056 .29106 Mdot
.66394 .54036 Mdot
.42733 .63695 Mdot
.68384 .55803 Mdot
.53136 .64849 Mdot
.16006 .6609 Mdot
.46245 .6332 Mdot
.46277 .54806 Mdot
.37239 .54076 Mdot
.32177 .40789 Mdot
.32305 .41245 Mdot
.62024 .41564 Mdot
.65526 .51136 Mdot
.44274 .64953 Mdot
.29474 .51733 Mdot
.72921 .40453 Mdot
.61928 .53535 Mdot
.35452 .43818 Mdot
.3778 .41639 Mdot
.53084 .30131 Mdot
.46812 .66125 Mdot
.48887 .63122 Mdot
.36959 .39647 Mdot
.39134 .22434 Mdot
.69104 .53671 Mdot
.4888 .64263 Mdot
.46688 .61723 Mdot
.34068 .40137 Mdot
.4723 .31598 Mdot
.69146 .48762 Mdot
.46732 .61582 Mdot
.30849 .68519 Mdot
.49644 .31052 Mdot
.52557 .59714 Mdot
.4494 .64696 Mdot
.31453 .53183 Mdot
.28195 .59015 Mdot
.30158 .71015 Mdot
.54428 .28398 Mdot
.60691 .41856 Mdot
.52165 .67111 Mdot
.32263 .40004 Mdot
.55612 .61727 Mdot
.51653 .20103 Mdot
.63856 .42851 Mdot
.47753 .64414 Mdot
.46377 .59379 Mdot
.67179 .54853 Mdot
.48286 .64916 Mdot
.65743 .44306 Mdot
.33987 .42456 Mdot
.47666 .64408 Mdot
.73895 .68321 Mdot
.53074 .30443 Mdot
.43784 .61281 Mdot
.31122 .50174 Mdot
.37198 .50319 Mdot
.80738 .5301 Mdot
.32044 .43388 Mdot
.30836 .5553 Mdot
.46508 .64778 Mdot
.31368 .40552 Mdot
.51181 .26089 Mdot
.52847 .53047 Mdot
.52338 .58684 Mdot
.49986 .29511 Mdot
.50847 .31558 Mdot
.30533 .53511 Mdot
.13712 .5562 Mdot
.46561 .5931 Mdot
.50629 .64867 Mdot
.30744 .2514 Mdot
.63164 .5357 Mdot
.5091 .6554 Mdot
.47024 .66269 Mdot
.51606 .26917 Mdot
.38305 .7579 Mdot
.38758 .57061 Mdot
.40679 .2273 Mdot
.49537 .30494 Mdot
.3856 .39767 Mdot
.34909 .42549 Mdot
.307 .55421 Mdot
.67667 .51151 Mdot
.32673 .53997 Mdot
.33877 .41213 Mdot
.50937 .62228 Mdot
.53675 .2895 Mdot
.65465 .61997 Mdot
.48871 .3002 Mdot
.32864 .36089 Mdot
.66631 .49261 Mdot
.79785 .48215 Mdot
.42107 .16781 Mdot
.77443 .48105 Mdot
.54879 .29688 Mdot
.31147 .53198 Mdot
.59837 .27229 Mdot
.46768 .64677 Mdot
.52996 .78207 Mdot
.50938 .65022 Mdot
.59566 .63871 Mdot
.36099 .42509 Mdot
.6259 .40624 Mdot
.52753 .64983 Mdot
.35759 .58775 Mdot
.53379 .27086 Mdot
.52351 .32326 Mdot
.48767 .60632 Mdot
.50781 .30019 Mdot
.48597 .63477 Mdot
.34604 .40122 Mdot
.14182 .55944 Mdot
.4767 .662 Mdot
.4352 .63319 Mdot
.48967 .26446 Mdot
.61147 .44582 Mdot
.36526 .35418 Mdot
.66185 .75315 Mdot
.71005 .26809 Mdot
.51077 .30462 Mdot
.43417 .56788 Mdot
.36161 .38212 Mdot
.60795 .40963 Mdot
.35798 .44706 Mdot
.50532 .63943 Mdot
.48274 .67476 Mdot
.50671 .60917 Mdot
.46645 .64276 Mdot
.55333 .76772 Mdot
.43741 .592 Mdot
.64945 .6912 Mdot
.5125 .66686 Mdot
.46554 .54847 Mdot
.50741 .28269 Mdot
.42121 .67583 Mdot
.35311 .50397 Mdot
.47397 .67193 Mdot
.61206 .57107 Mdot
.499 .2822 Mdot
.77035 .41545 Mdot
.52197 .28724 Mdot
.34415 .3769 Mdot
.54182 .31111 Mdot
.53204 .6518 Mdot
.6659 .52122 Mdot
.35287 .41516 Mdot
.73495 .47681 Mdot
.37535 .39281 Mdot
.47791 .65207 Mdot
.53127 .23239 Mdot
.31874 .39996 Mdot
.41644 .69059 Mdot
.66545 .51936 Mdot
.35184 .61949 Mdot
.63117 .52516 Mdot
.48894 .65179 Mdot
.4965 .65524 Mdot
.61968 .40416 Mdot
.53936 .28124 Mdot
.7187 .53122 Mdot
.17626 .5082 Mdot
.28765 .5098 Mdot
.68222 .51766 Mdot
.43265 .67259 Mdot
.53515 .42807 Mdot
.68736 .54964 Mdot
.36943 .62055 Mdot
.53382 .27375 Mdot
.69095 .50588 Mdot
.48519 .69148 Mdot
.54838 .72969 Mdot
.2881 .52075 Mdot
.31623 .41365 Mdot
.50875 .44707 Mdot
.3463 .42576 Mdot
.48736 .31402 Mdot
.36323 .43659 Mdot
.51199 .28287 Mdot
.63873 .46908 Mdot
.42897 .48626 Mdot
.49531 .32868 Mdot
.48039 .30533 Mdot
.33241 .40724 Mdot
.49344 .60413 Mdot
.44694 .41849 Mdot
.48266 .69806 Mdot
.42826 .62028 Mdot
.49805 .30724 Mdot
.67663 .50325 Mdot
.70341 .55033 Mdot
.55077 .54382 Mdot
.66507 .55281 Mdot
.3553 .40836 Mdot
.5731 .44591 Mdot
.49821 .77749 Mdot
.53314 .30481 Mdot
.29464 .38315 Mdot
.5105 .60286 Mdot
.32725 .40762 Mdot
.35876 .40302 Mdot
.50478 .30612 Mdot
.57788 .71552 Mdot
.43555 .60921 Mdot
.63993 .54785 Mdot
.70537 .51586 Mdot
.69212 .54818 Mdot
.70371 .50331 Mdot
.32104 .75526 Mdot
.49246 .31571 Mdot
.66663 .50558 Mdot
.4886 .59818 Mdot
.50057 .67316 Mdot
.61355 .42926 Mdot
.29327 .5479 Mdot
.49486 .68433 Mdot
.44905 .66702 Mdot
.50023 .6277 Mdot
.32128 .40618 Mdot
.54937 .69749 Mdot
.63698 .42868 Mdot
.36977 .42884 Mdot
.35496 .44088 Mdot
.613 .41393 Mdot
.64391 .47303 Mdot
.75646 .29942 Mdot
.50775 .61475 Mdot
.75801 .55053 Mdot
.3244 .40011 Mdot
.49546 .51028 Mdot
.53489 .55929 Mdot
.51612 .5953 Mdot
.44105 .39062 Mdot
.35008 .40447 Mdot
.73816 .5362 Mdot
.50286 .64186 Mdot
.62154 .4086 Mdot
.29945 .50661 Mdot
.46714 .6924 Mdot
.60511 .41446 Mdot
.69334 .52421 Mdot
.27575 .33843 Mdot
.65138 .56033 Mdot
.3178 .3987 Mdot
.43924 .6153 Mdot
.411 .89615 Mdot
.34941 .38645 Mdot
.72093 .38586 Mdot
.42113 .48955 Mdot
.47417 .65748 Mdot
.35604 .41767 Mdot
.73022 .51831 Mdot
.49681 .31096 Mdot
.51071 .42102 Mdot
.67674 .50896 Mdot
.61688 .40625 Mdot
.61023 .42287 Mdot
.3385 .40133 Mdot
.7119 .52595 Mdot
.45039 .6332 Mdot
.65285 .53922 Mdot
.53763 .3064 Mdot
.53791 .63121 Mdot
.7208 .2859 Mdot
.41878 .63662 Mdot
.65402 .5372 Mdot
.34874 .35855 Mdot
.3039 .56807 Mdot
.54322 .6221 Mdot
.76808 .37867 Mdot
.46715 .65872 Mdot
.52889 .29235 Mdot
.45437 .50685 Mdot
.65094 .6264 Mdot
.49682 .61221 Mdot
.51372 .60745 Mdot
.50029 .27151 Mdot
.50004 .61446 Mdot
.50162 .58419 Mdot
.49737 .36183 Mdot
.68052 .55038 Mdot
.47407 .63537 Mdot
.35117 .42822 Mdot
.73605 .59606 Mdot
.52486 .65528 Mdot
.66283 .43067 Mdot
.35219 .60528 Mdot
.44083 .49709 Mdot
.44148 .64462 Mdot
.27188 .60031 Mdot
.49897 .6533 Mdot
.51187 .58854 Mdot
.50147 .60739 Mdot
.64225 .75887 Mdot
.33502 .41101 Mdot
.34682 .43708 Mdot
.302 .50313 Mdot
.35838 .59486 Mdot
.31721 .54336 Mdot
.50397 .2699 Mdot
.29246 .37745 Mdot
.63883 .42064 Mdot
.68829 .53316 Mdot
.52252 .65479 Mdot
.37544 .40117 Mdot
.49644 .63221 Mdot
.52946 .62115 Mdot
.34857 .41131 Mdot
.35614 .4023 Mdot
.32764 .44242 Mdot
.2828 .54479 Mdot
.68028 .52753 Mdot
.51734 .6379 Mdot
.28925 .55977 Mdot
.45362 .64127 Mdot
.53937 .40515 Mdot
.68012 .52548 Mdot
.65409 .54074 Mdot
.68666 .5595 Mdot
.51199 .67008 Mdot
.53616 .6459 Mdot
.50345 .28914 Mdot
.72569 .53362 Mdot
.52428 .32603 Mdot
.35475 .41913 Mdot
.3281 .41651 Mdot
.5059 .6398 Mdot
.58005 .61931 Mdot
.29638 .54847 Mdot
.34825 .37382 Mdot
.62823 .4369 Mdot
.30632 .50037 Mdot
.4668 .63414 Mdot
.35037 .42312 Mdot
.31512 .49976 Mdot
.61118 .62708 Mdot
.68001 .23922 Mdot
.28332 .5542 Mdot
.487 .60636 Mdot
.75721 .65666 Mdot
.30803 .69532 Mdot
.28112 .52374 Mdot
.52296 .28247 Mdot
.48227 .67033 Mdot
.42009 .19539 Mdot
.3223 .55699 Mdot
.30377 .72011 Mdot
.34537 .41497 Mdot
.59199 .58959 Mdot
.46087 .68973 Mdot
.51246 .78406 Mdot
.32053 .56137 Mdot
.65538 .53316 Mdot
.71001 .51462 Mdot
.48763 .61187 Mdot
.33522 .48012 Mdot
.48919 .31495 Mdot
.33729 .37005 Mdot
.36457 .42897 Mdot
.71226 .53564 Mdot
.56807 .42988 Mdot
.35113 .42713 Mdot
.50609 .57401 Mdot
.29496 .48688 Mdot
.40729 .64892 Mdot
.36366 .79347 Mdot
.79069 .54266 Mdot
.44165 .63436 Mdot
.29924 .56838 Mdot
.52688 .2635 Mdot
.50468 .29636 Mdot
.51102 .29184 Mdot
.32988 .41962 Mdot
.53678 .46558 Mdot
.36372 .42628 Mdot
.6526 .38665 Mdot
.29936 .54296 Mdot
.35619 .65428 Mdot
.46277 .67566 Mdot
.4747 .6572 Mdot
.48891 .58913 Mdot
.50817 .61032 Mdot
.49782 .65171 Mdot
.5022 .3139 Mdot
.32106 .38231 Mdot
.33592 .25932 Mdot
.70561 .53644 Mdot
.61134 .33374 Mdot
.32291 .39098 Mdot
.60268 .42289 Mdot
.3021 .52056 Mdot
.29099 .60869 Mdot
.27751 .4944 Mdot
.33914 .37204 Mdot
.53686 .59764 Mdot
.682 .50091 Mdot
.4643 .77591 Mdot
.50212 .66317 Mdot
.35082 .37317 Mdot
.38379 .41121 Mdot
.5887 .71277 Mdot
.56056 .64195 Mdot
.33106 .47354 Mdot
.53589 .43244 Mdot
.29502 .57455 Mdot
.55256 .62204 Mdot
.50931 .50822 Mdot
.33836 .4099 Mdot
.33779 .38327 Mdot
.27957 .53846 Mdot
.49854 .71541 Mdot
.6943 .51308 Mdot
.63039 .40784 Mdot
.51909 .2782 Mdot
.49098 .66563 Mdot
.33244 .42169 Mdot
.74705 .52142 Mdot
.50576 .40315 Mdot
.52506 .29845 Mdot
.37354 .42444 Mdot
.4744 .66806 Mdot
.49192 .61257 Mdot
.30688 .54666 Mdot
.20707 .42835 Mdot
.48048 .69719 Mdot
.72832 .40258 Mdot
.55828 .46565 Mdot
.39599 .49825 Mdot
.49412 .62731 Mdot
.68747 .5553 Mdot
.61621 .41329 Mdot
.30659 .51075 Mdot
.45653 .64873 Mdot
.73441 .27573 Mdot
.6652 .56804 Mdot
.51449 .32023 Mdot
.61698 .41079 Mdot
.52782 .47154 Mdot
.46649 .65674 Mdot
.50912 .6497 Mdot
.4757 .60873 Mdot
.73485 .27229 Mdot
.3546 .43159 Mdot
.7206 .51794 Mdot
.32146 .53865 Mdot
.65135 .54057 Mdot
.34053 .44175 Mdot
.39122 .49652 Mdot
.46622 .62261 Mdot
.65032 .55581 Mdot
.65389 .52664 Mdot
.53124 .30544 Mdot
.52102 .2644 Mdot
.31182 .41247 Mdot
.46617 .6472 Mdot
.63583 .41441 Mdot
.68152 .50525 Mdot
.33457 .36837 Mdot
.30659 .5458 Mdot
.5351 .3412 Mdot
.51281 .66715 Mdot
.33706 .40426 Mdot
.44656 .62178 Mdot
.68027 .54554 Mdot
.33339 .37606 Mdot
.60051 .41807 Mdot
.292 .54476 Mdot
.49589 .67594 Mdot
.30632 .28834 Mdot
.61824 .40824 Mdot
.53956 .65513 Mdot
.77866 .55163 Mdot
.34652 .49302 Mdot
.75371 .4928 Mdot
.36493 .41621 Mdot
.63363 .41637 Mdot
.71476 .51066 Mdot
.54332 .73685 Mdot
.33927 .38638 Mdot
.78435 .61695 Mdot
.46352 .39827 Mdot
.51185 .62281 Mdot
.68953 .51547 Mdot
.28052 .56275 Mdot
.73547 .39891 Mdot
.29468 .66801 Mdot
.4829 .63934 Mdot
.3455 .42618 Mdot
.30263 .50535 Mdot
.52603 .32363 Mdot
.65887 .42172 Mdot
.40293 .80697 Mdot
.37099 .42589 Mdot
.52088 .65096 Mdot
.68204 .50397 Mdot
.50896 .31201 Mdot
.8062 .59886 Mdot
.33943 .36009 Mdot
.36084 .41943 Mdot
.49747 .58981 Mdot
.32162 .53471 Mdot
.42656 .19686 Mdot
.34805 .43529 Mdot
.31467 .39969 Mdot
.58027 .38038 Mdot
.29199 .51005 Mdot
.4846 .60279 Mdot
.54984 .5435 Mdot
.46643 .61332 Mdot
.66596 .37014 Mdot
.63404 .41549 Mdot
.70413 .53653 Mdot
.51293 .65863 Mdot
.31621 .27963 Mdot
.34555 .38995 Mdot
.5384 .43577 Mdot
.48028 .25838 Mdot
.5233 .26532 Mdot
.33874 .42324 Mdot
.49714 .63768 Mdot
.52802 .33725 Mdot
.3004 .55055 Mdot
.46702 .61626 Mdot
.53357 .64723 Mdot
.7282 .51319 Mdot
.53739 .294 Mdot
.74432 .59001 Mdot
.5375 .31477 Mdot
.49317 .28492 Mdot
.70387 .49278 Mdot
.48631 .61257 Mdot
.34205 .37434 Mdot
.32856 .35876 Mdot
.44759 .63017 Mdot
.49497 .50954 Mdot
.69256 .51343 Mdot
.32259 .4495 Mdot
.70857 .24344 Mdot
.47173 .59172 Mdot
.61581 .43503 Mdot
.60177 .59057 Mdot
.5008 .32189 Mdot
.50828 .62315 Mdot
.68405 .53907 Mdot
.31783 .38144 Mdot
.34142 .42945 Mdot
.53925 .66896 Mdot
.50399 .3064 Mdot
.32104 .50968 Mdot
.36091 .40062 Mdot
.51059 .39702 Mdot
.47786 .64679 Mdot
.6327 .3984 Mdot
.36226 .39711 Mdot
.82275 .52551 Mdot
.3226 .27168 Mdot
.7073 .53974 Mdot
.52471 .60964 Mdot
.65888 .50298 Mdot
.32103 .54307 Mdot
.36215 .44199 Mdot
.50145 .29825 Mdot
.46804 .74946 Mdot
.17572 .45475 Mdot
.32958 .41134 Mdot
.68957 .52617 Mdot
.51883 .6481 Mdot
.53006 .56329 Mdot
.47154 .65952 Mdot
.38396 .75295 Mdot
.29898 .49199 Mdot
.48997 .32965 Mdot
.51932 .32714 Mdot
.51916 .61551 Mdot
.28736 .55202 Mdot
.3098 .3842 Mdot
.34696 .41163 Mdot
.15357 .60874 Mdot
.6042 .41458 Mdot
.36094 .45864 Mdot
.5116 .66988 Mdot
.34212 .36556 Mdot
.74103 .66348 Mdot
.52385 .32802 Mdot
.46405 .61369 Mdot
.37902 .38942 Mdot
.6635 .34827 Mdot
.53294 .42802 Mdot
.47912 .64311 Mdot
.57459 .61904 Mdot
.5224 .2849 Mdot
.59875 .27151 Mdot
.36811 .41177 Mdot
.45582 .63361 Mdot
.54566 .26885 Mdot
.6164 .45981 Mdot
.18045 .50362 Mdot
.67982 .52742 Mdot
.36481 .36259 Mdot
.50538 .27443 Mdot
.5643 .67493 Mdot
.29734 .55264 Mdot
.31589 .37817 Mdot
.37627 .38641 Mdot
.53516 .62226 Mdot
.4973 .68345 Mdot
.57018 .63316 Mdot
.6941 .51933 Mdot
.51842 .26975 Mdot
.52452 .62924 Mdot
.55353 .41012 Mdot
.51222 .61762 Mdot
.51207 .27195 Mdot
.28657 .81605 Mdot
.5442 .65435 Mdot
.50337 .66679 Mdot
.39547 .6728 Mdot
.71513 .53789 Mdot
.67049 .55035 Mdot
.5584 .43589 Mdot
.51013 .67123 Mdot
.47291 .38113 Mdot
.68162 .52944 Mdot
.68438 .51305 Mdot
.47061 .38264 Mdot
.53943 .62637 Mdot
.52995 .24585 Mdot
.50774 .30893 Mdot
.52191 .26496 Mdot
.67004 .54801 Mdot
.42223 .60952 Mdot
.51598 .2607 Mdot
.56374 .76407 Mdot
.33149 .37642 Mdot
.50995 .50825 Mdot
.65237 .5376 Mdot
.48705 .41106 Mdot
.53833 .28067 Mdot
.84206 .56052 Mdot
.45506 .76566 Mdot
.46414 .60818 Mdot
.49277 .61077 Mdot
.31459 .53659 Mdot
.48588 .55561 Mdot
.60661 .42045 Mdot
.50712 .29676 Mdot
.41456 .24211 Mdot
.67503 .52381 Mdot
.49037 .66971 Mdot
.27178 .6323 Mdot
.79767 .54331 Mdot
.5406 .5356 Mdot
.67529 .51085 Mdot
.67162 .52071 Mdot
.36964 .38667 Mdot
.33255 .37428 Mdot
.47362 .61546 Mdot
.50897 .2879 Mdot
.70179 .51129 Mdot
.52914 .2773 Mdot
.33934 .41124 Mdot
.33164 .37857 Mdot
.63204 .43354 Mdot
.45202 .58497 Mdot
.33844 .41948 Mdot
.58447 .3769 Mdot
.55219 .40876 Mdot
.72784 .51713 Mdot
.40282 .18195 Mdot
.80613 .61554 Mdot
.40249 .68265 Mdot
.29842 .50737 Mdot
.63268 .46723 Mdot
.54567 .30015 Mdot
.51753 .61391 Mdot
.51111 .64134 Mdot
.62191 .42962 Mdot
.54453 .28842 Mdot
.30925 .52171 Mdot
.54138 .28614 Mdot
.29979 .51511 Mdot
.33832 .43588 Mdot
.5246 .65873 Mdot
.4619 .64213 Mdot
.51988 .32149 Mdot
.36362 .37907 Mdot
.31856 .40151 Mdot
.28678 .52872 Mdot
.30638 .60603 Mdot
.33934 .40282 Mdot
.65216 .53752 Mdot
.72464 .61281 Mdot
.61147 .42457 Mdot
.50236 .64223 Mdot
.27633 .61579 Mdot
.56911 .74382 Mdot
.51464 .62665 Mdot
.61752 .40988 Mdot
.13493 .57786 Mdot
.52657 .65636 Mdot
.23539 .71237 Mdot
.63652 .42712 Mdot
.68642 .55739 Mdot
.36337 .38745 Mdot
.60881 .41104 Mdot
.55256 .6945 Mdot
.35449 .47437 Mdot
.4472 .61352 Mdot
.6902 .5101 Mdot
.65647 .55688 Mdot
.43435 .47671 Mdot
.6635 .36818 Mdot
.32289 .53384 Mdot
.30187 .52738 Mdot
.33876 .38925 Mdot
.52262 .36676 Mdot
.53492 .58017 Mdot
.30475 .52677 Mdot
.44988 .21617 Mdot
.50994 .60145 Mdot
.36456 .50297 Mdot
.44935 .40001 Mdot
.6973 .55013 Mdot
.42362 .67957 Mdot
.34232 .38848 Mdot
.68886 .52598 Mdot
.44403 .44057 Mdot
.4757 .60108 Mdot
.67841 .52453 Mdot
.52266 .26922 Mdot
.46352 .34438 Mdot
.65768 .5497 Mdot
.50998 .41734 Mdot
.51207 .31064 Mdot
.34874 .49468 Mdot
.3438 .68278 Mdot
.77163 .26591 Mdot
.50679 .2932 Mdot
.35865 .37705 Mdot
.33135 .41763 Mdot
.34267 .40077 Mdot
.6803 .50876 Mdot
.35548 .39695 Mdot
.70376 .52863 Mdot
.48146 .28056 Mdot
.28899 .60094 Mdot
.30765 .54029 Mdot
.31146 .46193 Mdot
.66031 .53239 Mdot
.66259 .38828 Mdot
.32894 .22062 Mdot
.48866 .6017 Mdot
.4936 .32495 Mdot
.29195 .56606 Mdot
.58102 .48102 Mdot
.31515 .5327 Mdot
.36284 .38397 Mdot
.51231 .50822 Mdot
.48478 .6344 Mdot
.77661 .52804 Mdot
.30728 .50417 Mdot
.67606 .50986 Mdot
.52873 .59297 Mdot
.31506 .36648 Mdot
.31215 .55328 Mdot
.29407 .51281 Mdot
.49894 .65035 Mdot
.65393 .55229 Mdot
.34019 .37337 Mdot
.54514 .31144 Mdot
.27734 .53325 Mdot
.5737 .604 Mdot
.49508 .60686 Mdot
.54833 .62388 Mdot
.54587 .44626 Mdot
.4304 .18914 Mdot
.51269 .30586 Mdot
.30133 .69589 Mdot
.32698 .4122 Mdot
.29803 .67422 Mdot
.73622 .43115 Mdot
.27637 .48963 Mdot
.63602 .41798 Mdot
.63351 .41445 Mdot
.48511 .64585 Mdot
.46475 .18006 Mdot
.47627 .54206 Mdot
.52362 .25067 Mdot
.61404 .42368 Mdot
.31824 .39976 Mdot
.71261 .55531 Mdot
.44882 .7024 Mdot
.47516 .68406 Mdot
.54379 .28383 Mdot
.34292 .40818 Mdot
.51688 .20043 Mdot
.30001 .54187 Mdot
.5725 .47628 Mdot
.46783 .64026 Mdot
.49214 .64339 Mdot
.52248 .30766 Mdot
.5035 .29179 Mdot
.62915 .38894 Mdot
.46373 .47826 Mdot
.73166 .30288 Mdot
.49011 .27401 Mdot
.51419 .19797 Mdot
.72793 .57539 Mdot
.66856 .54404 Mdot
.61167 .43231 Mdot
.50651 .26502 Mdot
.51029 .65688 Mdot
.69181 .55529 Mdot
.51183 .53533 Mdot
.74086 .53337 Mdot
.36579 .50352 Mdot
.48952 .39233 Mdot
.46641 .63965 Mdot
.68735 .50024 Mdot
.68647 .52509 Mdot
.67455 .49802 Mdot
.61316 .41555 Mdot
.49635 .62556 Mdot
.49345 .60266 Mdot
.52771 .65483 Mdot
.5259 .56332 Mdot
.48242 .64941 Mdot
.73724 .42712 Mdot
.56226 .40433 Mdot
.22295 .47026 Mdot
.51704 .66538 Mdot
.51002 .27055 Mdot
.52125 .66047 Mdot
.29031 .55431 Mdot
.51042 .67457 Mdot
.36277 .50391 Mdot
.51474 .29568 Mdot
.51395 .72141 Mdot
.29948 .39944 Mdot
.4653 .63051 Mdot
.32303 .5183 Mdot
.43603 .18546 Mdot
.27602 .64937 Mdot
.58089 .38013 Mdot
.65283 .53846 Mdot
.31759 .42339 Mdot
.50112 .33016 Mdot
.33938 .37631 Mdot
.45878 .61824 Mdot
.63337 .43472 Mdot
.73359 .74591 Mdot
.47737 .4221 Mdot
.51103 .65833 Mdot
.45902 .57965 Mdot
.6868 .55408 Mdot
.34804 .39013 Mdot
.74245 .55592 Mdot
.49589 .59125 Mdot
.31627 .55808 Mdot
.30213 .56514 Mdot
.40917 .47897 Mdot
.45419 .26833 Mdot
.47712 .77091 Mdot
.52062 .30653 Mdot
.33408 .42763 Mdot
.32203 .55929 Mdot
.60778 .56255 Mdot
.48897 .31224 Mdot
.50169 .32264 Mdot
.53669 .29215 Mdot
.4774 .65509 Mdot
.62363 .43404 Mdot
.44836 .24512 Mdot
.61356 .40793 Mdot
.48533 .59564 Mdot
.37714 .39014 Mdot
.61019 .40841 Mdot
.3161 .54073 Mdot
.49247 .28946 Mdot
.32067 .40166 Mdot
.49355 .65505 Mdot
.67626 .53285 Mdot
.28376 .68289 Mdot
.24322 .32029 Mdot
.32143 .46147 Mdot
.31996 .45948 Mdot
.67536 .56307 Mdot
.78265 .39101 Mdot
.50976 .34645 Mdot
.57506 .72208 Mdot
.2772 .56755 Mdot
.44808 .628 Mdot
.17146 .58768 Mdot
.36454 .42417 Mdot
.35421 .41365 Mdot
.47421 .64022 Mdot
.33788 .36346 Mdot
.47939 .66682 Mdot
.37034 .40494 Mdot
.71048 .36568 Mdot
.47508 .68536 Mdot
.35485 .40996 Mdot
.5437 .58915 Mdot
.54466 .62681 Mdot
.68013 .55669 Mdot
.31752 .37688 Mdot
.4652 .60647 Mdot
.67558 .80092 Mdot
.52979 .31138 Mdot
.61229 .41639 Mdot
.30657 .43958 Mdot
.54284 .30443 Mdot
.70302 .52083 Mdot
.52102 .66985 Mdot
.30166 .54928 Mdot
.66366 .53888 Mdot
.30691 .37868 Mdot
.31234 .50476 Mdot
.57203 .44352 Mdot
.66807 .54604 Mdot
.61747 .43014 Mdot
.29116 .54149 Mdot
.44744 .61293 Mdot
.35107 .41449 Mdot
.29803 .28322 Mdot
.61202 .41016 Mdot
.48927 .63229 Mdot
.36147 .35864 Mdot
.54152 .28706 Mdot
.47457 .61866 Mdot
.33434 .4256 Mdot
.61449 .41246 Mdot
.54008 .65208 Mdot
.54054 .65532 Mdot
.47632 .71912 Mdot
.44812 .51796 Mdot
.30995 .54263 Mdot
.68996 .48963 Mdot
.48756 .59809 Mdot
.28598 .54904 Mdot
.33464 .29477 Mdot
.45437 .66497 Mdot
.64439 .52268 Mdot
.51545 .74254 Mdot
.34334 .36779 Mdot
.52148 .32769 Mdot
.33111 .35973 Mdot
.30998 .49953 Mdot
.17284 .3728 Mdot
.6087 .42866 Mdot
.47355 .57532 Mdot
.49632 .58465 Mdot
.3702 .43413 Mdot
.68523 .52259 Mdot
.74435 .32122 Mdot
.50293 .67469 Mdot
.42136 .63458 Mdot
.50169 .64675 Mdot
.31016 .29339 Mdot
.68828 .5126 Mdot
.5029 .64469 Mdot
.57254 .5932 Mdot
.48184 .58702 Mdot
.32645 .53001 Mdot
.36247 .6687 Mdot
.52214 .64257 Mdot
.47952 .92028 Mdot
.64167 .42261 Mdot
.34856 .40852 Mdot
.52257 .42403 Mdot
.27775 .38208 Mdot
.33079 .77722 Mdot
.7004 .52265 Mdot
.64061 .58512 Mdot
.33911 .37498 Mdot
.266 .66991 Mdot
.78458 .4083 Mdot
.5427 .61671 Mdot
.4814 .67119 Mdot
.36278 .38388 Mdot
.33201 .37054 Mdot
.64117 .42929 Mdot
.46939 .6714 Mdot
.42026 .62993 Mdot
.35714 .36201 Mdot
.49235 .65947 Mdot
.61256 .72941 Mdot
.52541 .33487 Mdot
.67178 .54916 Mdot
.52686 .32283 Mdot
.50486 .32384 Mdot
.51292 .77143 Mdot
.55803 .46758 Mdot
.50615 .27877 Mdot
.5502 .29126 Mdot
.35384 .54657 Mdot
.44625 .74461 Mdot
.3263 .53509 Mdot
.46305 .27491 Mdot
.33856 .39478 Mdot
.49811 .625 Mdot
.67264 .50747 Mdot
.45411 .80434 Mdot
.64902 .24024 Mdot
.53285 .50839 Mdot
.49388 .599 Mdot
.3446 .39267 Mdot
.61432 .41032 Mdot
.47016 .6836 Mdot
.30581 .68832 Mdot
.48655 .6407 Mdot
.32996 .37509 Mdot
.50024 .77853 Mdot
.65292 .44722 Mdot
.48953 .27686 Mdot
.71934 .55401 Mdot
.5228 .6581 Mdot
.69138 .54011 Mdot
.49993 .28663 Mdot
.28354 .54653 Mdot
.3103 .53188 Mdot
.46386 .63538 Mdot
.43013 .48552 Mdot
.30334 .58815 Mdot
.54227 .6164 Mdot
.53652 .6252 Mdot
.63622 .42024 Mdot
.53688 .62695 Mdot
.45754 .63396 Mdot
.52199 .62746 Mdot
.45857 .66447 Mdot
.49718 .27547 Mdot
.7623 .5131 Mdot
.4972 .68077 Mdot
.48284 .5828 Mdot
.54068 .32737 Mdot
.53101 .69358 Mdot
.51973 .28624 Mdot
.67851 .25083 Mdot
.51529 .27792 Mdot
.30969 .53346 Mdot
.349 .35281 Mdot
.69095 .58628 Mdot
.70332 .51246 Mdot
.50807 .27018 Mdot
.2952 .52647 Mdot
.50842 .29297 Mdot
.34354 .43262 Mdot
.35646 .21389 Mdot
.64298 .50391 Mdot
.54301 .39708 Mdot
.41448 .71546 Mdot
.62984 .39658 Mdot
.35229 .36646 Mdot
.71217 .53389 Mdot
.65581 .44288 Mdot
.52123 .61859 Mdot
.30651 .54993 Mdot
.48605 .64558 Mdot
.49066 .29677 Mdot
.34247 .39404 Mdot
.50999 .24001 Mdot
.31083 .54211 Mdot
.20394 .34406 Mdot
.375 .39912 Mdot
.47938 .57808 Mdot
.53771 .32929 Mdot
.37704 .19685 Mdot
.51672 .2813 Mdot
.28877 .60201 Mdot
.64747 .48338 Mdot
.42457 .79171 Mdot
.66577 .52508 Mdot
.64135 .40259 Mdot
.81679 .38662 Mdot
.75858 .39456 Mdot
.67309 .54013 Mdot
.29923 .40065 Mdot
.48116 .65355 Mdot
.51119 .61379 Mdot
.51693 .57278 Mdot
.73447 .55111 Mdot
.47763 .60721 Mdot
.60764 .4232 Mdot
.55393 .45053 Mdot
.42932 .20859 Mdot
.3145 .41584 Mdot
.4752 .66452 Mdot
.49841 .309 Mdot
.48979 .2923 Mdot
.61303 .4063 Mdot
.53958 .30292 Mdot
.54352 .63225 Mdot
.66135 .53062 Mdot
.44625 .42231 Mdot
.31963 .54493 Mdot
.72182 .40766 Mdot
.28431 .57729 Mdot
.27984 .50551 Mdot
.4754 .5899 Mdot
.3324 .37766 Mdot
.16392 .51403 Mdot
.51368 .61064 Mdot
.68426 .52951 Mdot
.50239 .58664 Mdot
.52302 .63326 Mdot
.52115 .64527 Mdot
.33274 .42561 Mdot
.52442 .42123 Mdot
.49517 .66078 Mdot
.50385 .27968 Mdot
.46889 .3853 Mdot
.47748 .68326 Mdot
.42136 .25052 Mdot
.36744 .50382 Mdot
.6327 .39886 Mdot
.72843 .51896 Mdot
.35192 .37805 Mdot
.67267 .52334 Mdot
.66201 .57322 Mdot
.70341 .52113 Mdot
.43078 .23658 Mdot
.55319 .7297 Mdot
.2592 .73859 Mdot
.7221 .67964 Mdot
.50653 .783 Mdot
.64361 .5519 Mdot
.37954 .28726 Mdot
.67784 .54177 Mdot
.7024 .52207 Mdot
.19987 .71728 Mdot
.65103 .517 Mdot
.50537 .63825 Mdot
.52936 .67039 Mdot
.79111 .50319 Mdot
.35472 .55028 Mdot
.51523 .66906 Mdot
.47634 .60981 Mdot
.31254 .56463 Mdot
.56709 .68869 Mdot
.645 .42259 Mdot
.56733 .46956 Mdot
.61519 .43697 Mdot
.49806 .65046 Mdot
.46961 .63204 Mdot
.54201 .66524 Mdot
.82771 .39635 Mdot
.42629 .80519 Mdot
.67293 .56121 Mdot
.5476 .68593 Mdot
.59131 .42249 Mdot
.50514 .5828 Mdot
.49755 .58612 Mdot
.53113 .65147 Mdot
.34135 .3743 Mdot
.71069 .55571 Mdot
.46414 .68655 Mdot
.72239 .44691 Mdot
.46774 .6384 Mdot
.26997 .52618 Mdot
.30459 .5817 Mdot
.49804 .63724 Mdot
.64572 .52516 Mdot
.50349 .60329 Mdot
.66778 .5014 Mdot
.67511 .54838 Mdot
.44744 .58723 Mdot
.45095 .25022 Mdot
.70877 .55958 Mdot
.5445 .62134 Mdot
.36025 .37451 Mdot
.72625 .39608 Mdot
.49147 .63289 Mdot
.32079 .52821 Mdot
.5085 .62247 Mdot
.3229 .51529 Mdot
.53576 .63871 Mdot
.61549 .40701 Mdot
.64227 .63471 Mdot
.33683 .38509 Mdot
.27684 .54195 Mdot
.34324 .36403 Mdot
.41083 .6777 Mdot
.63982 .53096 Mdot
.64733 .43923 Mdot
.41634 .81349 Mdot
.63652 .42214 Mdot
.2991 .70361 Mdot
.46935 .37373 Mdot
.51265 .32501 Mdot
.70778 .50511 Mdot
.49535 .77356 Mdot
.43324 .28217 Mdot
.34234 .44786 Mdot
.35319 .44237 Mdot
.1773 .52305 Mdot
.14155 .56126 Mdot
.49811 .66361 Mdot
.41349 .19528 Mdot
.65394 .67596 Mdot
.54132 .58065 Mdot
.53851 .67791 Mdot
.37423 .38081 Mdot
.519 .66835 Mdot
.50582 .43709 Mdot
.33265 .40817 Mdot
.29646 .53242 Mdot
.70251 .53708 Mdot
.28769 .53525 Mdot
.61766 .21911 Mdot
.56469 .38021 Mdot
.33529 .41567 Mdot
.46246 .67052 Mdot
.4832 .66431 Mdot
.71934 .51285 Mdot
.78976 .61388 Mdot
.67852 .55049 Mdot
.32375 .53167 Mdot
.32949 .39603 Mdot
.49275 .79743 Mdot
.51298 .63221 Mdot
.65441 .52295 Mdot
.3 .39319 Mdot
.49289 .61322 Mdot
.51327 .32211 Mdot
.4955 .59842 Mdot
.65157 .52846 Mdot
.53678 .628 Mdot
.66325 .5301 Mdot
.37033 .39473 Mdot
.46194 .65083 Mdot
.46983 .62924 Mdot
.30219 .71044 Mdot
.31072 .52183 Mdot
.64002 .53624 Mdot
.50853 .43885 Mdot
.46697 .6128 Mdot
.30893 .68869 Mdot
.52523 .65807 Mdot
.41254 .58695 Mdot
.51932 .69442 Mdot
.60959 .42672 Mdot
.49406 .58448 Mdot
.49069 .63367 Mdot
.76222 .66122 Mdot
.75004 .65911 Mdot
.39835 .65411 Mdot
.51934 .26395 Mdot
.64701 .53264 Mdot
.33293 .41958 Mdot
.31667 .38626 Mdot
.35685 .39193 Mdot
.35024 .57149 Mdot
.57822 .63706 Mdot
.48338 .63198 Mdot
.48152 .3152 Mdot
.30214 .53048 Mdot
.66481 .51349 Mdot
.30554 .53554 Mdot
.56381 .47616 Mdot
.31703 .51375 Mdot
.6059 .42282 Mdot
.32473 .26885 Mdot
.58863 .74232 Mdot
.3118 .51231 Mdot
.67746 .54999 Mdot
.49179 .38466 Mdot
.44893 .62468 Mdot
.63479 .34775 Mdot
.3162 .55846 Mdot
.17428 .50584 Mdot
.53618 .65628 Mdot
.51291 .42496 Mdot
.52413 .2906 Mdot
.28809 .53422 Mdot
.53698 .29667 Mdot
.50614 .60539 Mdot
.76143 .4999 Mdot
.6899 .52903 Mdot
.52279 .33418 Mdot
.48859 .58674 Mdot
.28784 .53587 Mdot
.33924 .41757 Mdot
.46976 .76097 Mdot
.54917 .30913 Mdot
.277 .67412 Mdot
.29466 .6686 Mdot
.32901 .39893 Mdot
.53929 .79729 Mdot
.53121 .28877 Mdot
.44434 .64242 Mdot
.59168 .59827 Mdot
.50328 .59865 Mdot
.31856 .40545 Mdot
.35639 .41216 Mdot
.77205 .45046 Mdot
.46519 .63865 Mdot
.52256 .67554 Mdot
.70369 .55714 Mdot
.32615 .40774 Mdot
.70328 .51937 Mdot
.71934 .51846 Mdot
.36258 .38194 Mdot
.70794 .53959 Mdot
.30584 .50488 Mdot
.54803 .48252 Mdot
.5292 .28607 Mdot
.50768 .31621 Mdot
.33677 .41899 Mdot
.32797 .42712 Mdot
.32849 .38113 Mdot
.50349 .59409 Mdot
.71304 .52422 Mdot
.52501 .60562 Mdot
.52201 .65602 Mdot
.68828 .48305 Mdot
.71058 .54838 Mdot
.51673 .60126 Mdot
.4506 .3883 Mdot
.32724 .52519 Mdot
.3548 .40771 Mdot
.52828 .27499 Mdot
.29308 .71281 Mdot
.52875 .33149 Mdot
.47061 .61016 Mdot
.66346 .35088 Mdot
.68055 .50925 Mdot
.31517 .53435 Mdot
.33907 .4858 Mdot
.31292 .54013 Mdot
.52215 .33453 Mdot
.72538 .52499 Mdot
.56856 .43924 Mdot
.46375 .64229 Mdot
.54744 .44891 Mdot
.33168 .71153 Mdot
.73667 .43739 Mdot
.51862 .26911 Mdot
.48727 .60198 Mdot
.63646 .42576 Mdot
.59041 .71302 Mdot
.47989 .63443 Mdot
.46442 .61262 Mdot
.24753 .39004 Mdot
.47908 .58577 Mdot
.7225 .50878 Mdot
.41213 .49088 Mdot
.45802 .65188 Mdot
.40853 .66899 Mdot
.15183 .62811 Mdot
.5376 .65642 Mdot
.46763 .63048 Mdot
.50644 .63153 Mdot
.51674 .61075 Mdot
.65118 .50721 Mdot
.23285 .38278 Mdot
.49776 .29949 Mdot
.5471 .48184 Mdot
.53371 .28814 Mdot
.34942 .42061 Mdot
.48432 .43968 Mdot
.66281 .50203 Mdot
.31347 .54023 Mdot
.4027 .19524 Mdot
.52069 .50198 Mdot
.36834 .38311 Mdot
.35518 .78138 Mdot
.31718 .55436 Mdot
.44716 .62869 Mdot
.30272 .50229 Mdot
.37369 .37709 Mdot
.50364 .30419 Mdot
.53888 .60142 Mdot
.69005 .50856 Mdot
.65707 .54868 Mdot
.49179 .59727 Mdot
.71737 .40169 Mdot
.54386 .30155 Mdot
.24251 .5228 Mdot
.47357 .6511 Mdot
.46172 .61629 Mdot
.68793 .55007 Mdot
.34786 .39181 Mdot
.46968 .37599 Mdot
.30373 .51838 Mdot
.51766 .57761 Mdot
.50461 .60598 Mdot
.56088 .47383 Mdot
.5008 .273 Mdot
.62106 .42137 Mdot
.46839 .64522 Mdot
.55912 .45884 Mdot
.46987 .61325 Mdot
.44195 .57658 Mdot
.3521 .36908 Mdot
.42717 .62048 Mdot
.47671 .67125 Mdot
.75679 .52725 Mdot
.53354 .29413 Mdot
.68253 .52568 Mdot
.6341 .49794 Mdot
.6228 .40836 Mdot
.52663 .31535 Mdot
.5137 .59939 Mdot
.50423 .32672 Mdot
.51804 .62753 Mdot
.49346 .65729 Mdot
.51911 .2689 Mdot
.70732 .52253 Mdot
.73034 .31057 Mdot
.76254 .51178 Mdot
.52847 .62464 Mdot
.50485 .61747 Mdot
.3574 .55308 Mdot
.47603 .82321 Mdot
.47696 .67223 Mdot
.71526 .52583 Mdot
.49079 .61278 Mdot
.50312 .31285 Mdot
.32268 .52765 Mdot
.67998 .53372 Mdot
.33507 .43194 Mdot
.36841 .40553 Mdot
.32709 .33967 Mdot
.60691 .42637 Mdot
.46829 .66951 Mdot
.69009 .48929 Mdot
.69869 .55681 Mdot
.57862 .49923 Mdot
.34938 .40906 Mdot
.31904 .51352 Mdot
.52651 .66638 Mdot
.4877 .75968 Mdot
.4974 .31428 Mdot
.48977 .91724 Mdot
.56779 .43527 Mdot
.29849 .58114 Mdot
.43688 .49684 Mdot
.63386 .42603 Mdot
.50507 .66793 Mdot
.2884 .55056 Mdot
.36456 .40825 Mdot
.50951 .61071 Mdot
.5739 .62899 Mdot
.4332 .29572 Mdot
.33281 .43514 Mdot
.51039 .32973 Mdot
.36136 .42303 Mdot
.32448 .51863 Mdot
.60626 .42176 Mdot
.66059 .55476 Mdot
.49185 .63768 Mdot
.41453 .66288 Mdot
.34555 .4006 Mdot
.62304 .40535 Mdot
.46443 .62914 Mdot
.64873 .5392 Mdot
.35584 .40135 Mdot
.50345 .65295 Mdot
.57957 .71777 Mdot
.66455 .58553 Mdot
.3342 .39601 Mdot
.52955 .58821 Mdot
.44958 .71868 Mdot
.34092 .44009 Mdot
.3793 .39543 Mdot
.47611 .60931 Mdot
.28979 .53231 Mdot
.46745 .66019 Mdot
.51308 .28355 Mdot
.52445 .42056 Mdot
.51995 .31967 Mdot
.30817 .69752 Mdot
.52596 .67673 Mdot
.52624 .53328 Mdot
.69097 .502 Mdot
.31168 .49075 Mdot
.74135 .6989 Mdot
.4542 .62821 Mdot
.74594 .29948 Mdot
.49019 .40968 Mdot
.56704 .39572 Mdot
.6818 .23013 Mdot
.30538 .51357 Mdot
.51131 .2915 Mdot
.46742 .62625 Mdot
.50788 .35543 Mdot
.29978 .51327 Mdot
.30884 .69978 Mdot
.50853 .58075 Mdot
.68262 .51271 Mdot
.47497 .64931 Mdot
.65003 .53363 Mdot
.49824 .61669 Mdot
.54341 .71075 Mdot
.27266 .52972 Mdot
.29039 .60252 Mdot
.44544 .63132 Mdot
.40993 .18589 Mdot
.42873 .7303 Mdot
.32112 .53706 Mdot
.53156 .62697 Mdot
.62751 .42508 Mdot
.53923 .28034 Mdot
.36234 .23209 Mdot
.33595 .3761 Mdot
.50932 .27649 Mdot
.69786 .5445 Mdot
.34965 .35571 Mdot
.62779 .40822 Mdot
.59089 .58992 Mdot
.28779 .53978 Mdot
.52914 .31208 Mdot
.49348 .63523 Mdot
.48828 .59161 Mdot
.30909 .29296 Mdot
.55342 .81755 Mdot
.71756 .52341 Mdot
.17787 .40623 Mdot
.69455 .491 Mdot
.30532 .52356 Mdot
.34899 .36903 Mdot
.51315 .65471 Mdot
.47488 .6328 Mdot
.32359 .41559 Mdot
.71365 .54083 Mdot
.29892 .48535 Mdot
.43249 .79628 Mdot
.47108 .28041 Mdot
.34081 .62655 Mdot
.68143 .53592 Mdot
.3376 .62453 Mdot
.31987 .56581 Mdot
.49499 .21926 Mdot
.39567 .70325 Mdot
.51958 .3251 Mdot
.34423 .62936 Mdot
.66241 .51311 Mdot
.49943 .66485 Mdot
.61784 .42971 Mdot
.63841 .42808 Mdot
.69287 .54238 Mdot
.35951 .38034 Mdot
.29604 .55168 Mdot
.47484 .64543 Mdot
.58 .53497 Mdot
.8107 .59428 Mdot
.32755 .42393 Mdot
.47124 .57327 Mdot
.54233 .30033 Mdot
.49629 .61233 Mdot
.30442 .56653 Mdot
.50715 .30247 Mdot
.60237 .41587 Mdot
.52244 .49582 Mdot
.52519 .66849 Mdot
.39855 .49711 Mdot
.52727 .30067 Mdot
.48178 .82479 Mdot
.47066 .62867 Mdot
.5315 .28923 Mdot
.41373 .65651 Mdot
.69025 .44969 Mdot
.45321 .4086 Mdot
.7575 .38746 Mdot
.31323 .42229 Mdot
.36721 .41196 Mdot
.64101 .81411 Mdot
.27648 .56665 Mdot
.50223 .27775 Mdot
.60683 .41707 Mdot
.37566 .68189 Mdot
.53611 .30635 Mdot
.54265 .61102 Mdot
.5253 .66008 Mdot
.5025 .77973 Mdot
.40291 .67579 Mdot
.6436 .42472 Mdot
.58209 .56679 Mdot
.53862 .61596 Mdot
.43779 .62178 Mdot
.47911 .61344 Mdot
.6582 .55778 Mdot
.52828 .32582 Mdot
.54324 .12715 Mdot
.49839 .32529 Mdot
.55728 .51992 Mdot
.33888 .39457 Mdot
.31097 .38883 Mdot
.49825 .63842 Mdot
.45228 .54455 Mdot
.45732 .1734 Mdot
.51626 .63707 Mdot
.34313 .49028 Mdot
.29303 .6674 Mdot
.45392 .67204 Mdot
.66044 .56653 Mdot
.42008 .63152 Mdot
.6636 .49487 Mdot
.50646 .30419 Mdot
.30455 .51265 Mdot
.32969 .53662 Mdot
.51636 .28872 Mdot
.48159 .62839 Mdot
.3312 .53499 Mdot
.49541 .64416 Mdot
.48805 .66475 Mdot
.5687 .47566 Mdot
.2898 .56623 Mdot
.328 .38094 Mdot
.31112 .53435 Mdot
.69788 .51965 Mdot
.21581 .74467 Mdot
.30328 .54363 Mdot
.44969 .74726 Mdot
.5003 .42597 Mdot
.34312 .63216 Mdot
.66099 .55077 Mdot
.32365 .5361 Mdot
.52338 .32742 Mdot
.57415 .42677 Mdot
.5351 .79521 Mdot
.52514 .33167 Mdot
.47469 .63656 Mdot
.66562 .50113 Mdot
.68133 .56187 Mdot
.49346 .27217 Mdot
.69221 .55336 Mdot
.45398 .59376 Mdot
.54442 .61969 Mdot
.49905 .28538 Mdot
.80671 .53078 Mdot
.5244 .32882 Mdot
.48044 .75829 Mdot
.53473 .64821 Mdot
.68206 .53144 Mdot
.4227 .57615 Mdot
.7334 .51047 Mdot
.63252 .43385 Mdot
.5105 .67526 Mdot
.31121 .548 Mdot
.53633 .46504 Mdot
.33472 .39424 Mdot
.66791 .34999 Mdot
.65262 .53891 Mdot
.49111 .32445 Mdot
.67709 .55677 Mdot
.71894 .52845 Mdot
.52093 .33286 Mdot
.69297 .52251 Mdot
.46896 .63672 Mdot
.6032 .24684 Mdot
.6549 .53938 Mdot
.52181 .30303 Mdot
.30916 .55238 Mdot
.71008 .5369 Mdot
.31117 .47759 Mdot
.48863 .6675 Mdot
.35811 .36614 Mdot
.27803 .5373 Mdot
.67307 .49876 Mdot
.32209 .52801 Mdot
.34826 .40385 Mdot
.29536 .55317 Mdot
.48413 .33455 Mdot
.49779 .33894 Mdot
.53287 .51211 Mdot
.66752 .45125 Mdot
.67607 .50651 Mdot
.31385 .42736 Mdot
.50151 .6725 Mdot
.4763 .65688 Mdot
.31523 .49734 Mdot
.66731 .5631 Mdot
.71072 .39299 Mdot
.49287 .54581 Mdot
.72117 .40917 Mdot
.51143 .26478 Mdot
.23084 .59271 Mdot
.56913 .43144 Mdot
.57431 .37826 Mdot
.55469 .6261 Mdot
.63271 .4272 Mdot
.50241 .64667 Mdot
.27516 .64781 Mdot
.32562 .53943 Mdot
.347 .31439 Mdot
.53423 .57947 Mdot
.32476 .39746 Mdot
.505 .62284 Mdot
.40256 .20693 Mdot
.41613 .62835 Mdot
.32078 .55346 Mdot
.53589 .33501 Mdot
.70327 .51239 Mdot
.31946 .54759 Mdot
.36998 .39973 Mdot
.36404 .61658 Mdot
.54869 .63018 Mdot
.54182 .62273 Mdot
.36095 .43667 Mdot
.69986 .51613 Mdot
.3507 .41805 Mdot
.52963 .28639 Mdot
.30423 .54032 Mdot
.51979 .61281 Mdot
.43079 .61888 Mdot
.37286 .43067 Mdot
.49224 .31412 Mdot
.32284 .42152 Mdot
.50119 .32378 Mdot
.63015 .42945 Mdot
.4611 .66429 Mdot
.37565 .42062 Mdot
.55769 .62749 Mdot
.7506 .6434 Mdot
.55547 .49239 Mdot
.70153 .73108 Mdot
.328 .38045 Mdot
.35978 .58234 Mdot
.51728 .29363 Mdot
.53218 .30688 Mdot
.50737 .77174 Mdot
.45794 .17755 Mdot
.47258 .3812 Mdot
.33257 .23267 Mdot
.52869 .28533 Mdot
.52661 .30824 Mdot
.36445 .40271 Mdot
.70147 .52711 Mdot
.64615 .56571 Mdot
.37181 .37059 Mdot
.27689 .61605 Mdot
.66402 .51382 Mdot
.77611 .33965 Mdot
.3642 .42808 Mdot
.55068 .64603 Mdot
.64294 .43954 Mdot
.31868 .55614 Mdot
.27613 .64015 Mdot
.34866 .22378 Mdot
.50998 .64865 Mdot
.21834 .68625 Mdot
.34798 .37737 Mdot
.46595 .30974 Mdot
.50939 .21575 Mdot
.4791 .59677 Mdot
.50365 .62454 Mdot
.48123 .62291 Mdot
.28098 .52531 Mdot
.78135 .6109 Mdot
.51081 .65249 Mdot
.30356 .59679 Mdot
.47567 .68595 Mdot
.29873 .28755 Mdot
.31084 .53442 Mdot
.38264 .7566 Mdot
.30467 .40035 Mdot
.71529 .43739 Mdot
.47466 .59188 Mdot
.525 .28411 Mdot
.44164 .34186 Mdot
.51151 .27129 Mdot
.4791 .20996 Mdot
.39308 .70438 Mdot
.65573 .55712 Mdot
.49548 .59784 Mdot
.36954 .42358 Mdot
.66945 .50015 Mdot
.44604 .36662 Mdot
.18608 .70522 Mdot
.50078 .26834 Mdot
.12879 .48566 Mdot
.52903 .31914 Mdot
.63999 .42714 Mdot
.69028 .54683 Mdot
.38817 .58323 Mdot
.54982 .45532 Mdot
.70406 .52025 Mdot
.22411 .50084 Mdot
.62692 .53807 Mdot
.34421 .60725 Mdot
.63109 .51734 Mdot
.51663 .29961 Mdot
.49899 .33887 Mdot
.56385 .65628 Mdot
.48785 .67478 Mdot
.5466 .43858 Mdot
.54722 .66771 Mdot
.50971 .67177 Mdot
.33246 .4081 Mdot
.67018 .44571 Mdot
.52275 .36084 Mdot
.68591 .53853 Mdot
.49438 .30214 Mdot
.50521 .62475 Mdot
.52885 .62446 Mdot
.49132 .58051 Mdot
.27332 .67864 Mdot
.77215 .33268 Mdot
.49663 .66009 Mdot
.4203 .6209 Mdot
.3664 .38155 Mdot
.30522 .29311 Mdot
.19997 .38539 Mdot
.38213 .68441 Mdot
.46303 .62957 Mdot
.3113 .52474 Mdot
.31477 .56435 Mdot
.46796 .58495 Mdot
.52116 .52887 Mdot
.31028 .47368 Mdot
.49346 .63496 Mdot
.37191 .58553 Mdot
.3613 .44672 Mdot
.61861 .40503 Mdot
.34556 .40122 Mdot
.66731 .4996 Mdot
.63761 .42225 Mdot
.34123 .42746 Mdot
.41198 .55466 Mdot
.62134 .40902 Mdot
.69508 .44774 Mdot
.32405 .53285 Mdot
.47474 .6188 Mdot
.72087 .57265 Mdot
.32652 .41752 Mdot
.52941 .30426 Mdot
.66747 .53424 Mdot
.53091 .26717 Mdot
.31205 .28007 Mdot
.2807 .63222 Mdot
.61024 .42964 Mdot
.52094 .28147 Mdot
.4491 .46756 Mdot
.31089 .52673 Mdot
.53686 .31311 Mdot
.51142 .53607 Mdot
.49117 .68439 Mdot
.51722 .17953 Mdot
.53558 .6052 Mdot
.77635 .43801 Mdot
.53053 .2973 Mdot
.59898 .42256 Mdot
.49039 .63847 Mdot
.3744 .39879 Mdot
.52336 .69871 Mdot
.49456 .64526 Mdot
.3537 .43193 Mdot
.49932 .66315 Mdot
.28913 .55998 Mdot
.67275 .4942 Mdot
.48529 .41642 Mdot
.25495 .64134 Mdot
.30379 .557 Mdot
.60905 .50133 Mdot
.4832 .67526 Mdot
.20616 .48859 Mdot
.68441 .51496 Mdot
.46017 .61984 Mdot
.31744 .73833 Mdot
.6985 .53547 Mdot
.67188 .52259 Mdot
.53462 .61862 Mdot
.52862 .32948 Mdot
.31963 .40373 Mdot
.3117 .52913 Mdot
.5204 .36712 Mdot
.50534 .6546 Mdot
.48479 .60324 Mdot
.31761 .55301 Mdot
.52561 .31392 Mdot
.51979 .61023 Mdot
.70149 .3253 Mdot
.57553 .50056 Mdot
.5017 .32141 Mdot
.47769 .68297 Mdot
.58372 .16685 Mdot
.64602 .56717 Mdot
.22755 .70088 Mdot
.27957 .56845 Mdot
.35829 .37568 Mdot
.49891 .56706 Mdot
.45114 .91422 Mdot
.32206 .53915 Mdot
.72272 .43278 Mdot
.49102 .66135 Mdot
.51696 .6536 Mdot
.64646 .54618 Mdot
.52138 .60079 Mdot
.65023 .52221 Mdot
.24197 .6279 Mdot
.40861 .16945 Mdot
.68662 .55456 Mdot
.64964 .52669 Mdot
.40434 .65704 Mdot
.28102 .69447 Mdot
.70289 .53848 Mdot
.54893 .63226 Mdot
.22409 .48007 Mdot
.57428 .61028 Mdot
.29934 .57814 Mdot
.32708 .48854 Mdot
.65313 .56187 Mdot
.59539 .7891 Mdot
.40634 .64631 Mdot
.50224 .72333 Mdot
.33791 .55069 Mdot
.51757 .27494 Mdot
.52791 .64214 Mdot
.60487 .42306 Mdot
.35836 .4024 Mdot
.42461 .6447 Mdot
.4744 .62338 Mdot
.65189 .51284 Mdot
.29008 .50634 Mdot
.53784 .30324 Mdot
.47325 .61434 Mdot
.38553 .403 Mdot
.29714 .52673 Mdot
.65824 .54179 Mdot
.45829 .74978 Mdot
.32687 .5485 Mdot
.43731 .6058 Mdot
.51387 .66682 Mdot
.46516 .62285 Mdot
.55614 .58986 Mdot
.51904 .28882 Mdot
.36311 .36149 Mdot
.5035 .56845 Mdot
.56839 .45707 Mdot
.52643 .46405 Mdot
.48949 .5725 Mdot
.71535 .52815 Mdot
.51597 .26538 Mdot
.61792 .41367 Mdot
.35645 .65479 Mdot
.5365 .653 Mdot
.76036 .3142 Mdot
.39183 .79807 Mdot
.62443 .41272 Mdot
.63568 .52612 Mdot
.31409 .53579 Mdot
.54056 .63138 Mdot
.28454 .58965 Mdot
.54146 .60953 Mdot
.57397 .58835 Mdot
.35335 .37498 Mdot
.52469 .27533 Mdot
.59233 .52663 Mdot
.35882 .40441 Mdot
.67243 .52307 Mdot
.80629 .45245 Mdot
.63492 .5539 Mdot
.71926 .52286 Mdot
.45579 .24221 Mdot
.50332 .29657 Mdot
.46671 .92048 Mdot
.47138 .82558 Mdot
.54033 .66113 Mdot
.50015 .29647 Mdot
.68633 .5459 Mdot
.51072 .59169 Mdot
.67153 .50821 Mdot
.7039 .56153 Mdot
.51717 .66962 Mdot
.50827 .67092 Mdot
.29995 .60366 Mdot
.78793 .36179 Mdot
.30568 .54966 Mdot
.68933 .55621 Mdot
.53376 .76063 Mdot
.51159 .65719 Mdot
.46453 .64479 Mdot
.4379 .31716 Mdot
.32319 .54046 Mdot
.61336 .71855 Mdot
.47808 .65625 Mdot
.30623 .73317 Mdot
.50778 .67409 Mdot
.67322 .57527 Mdot
.50096 .25915 Mdot
.54868 .52816 Mdot
.31787 .40281 Mdot
.70887 .5048 Mdot
.3178 .50257 Mdot
.73019 .52353 Mdot
.54999 .74033 Mdot
.50468 .30339 Mdot
.65148 .52807 Mdot
.33342 .35569 Mdot
.51718 .31376 Mdot
.5179 .32625 Mdot
.44744 .37372 Mdot
.34077 .35643 Mdot
.28008 .54137 Mdot
.5355 .27766 Mdot
.57637 .71837 Mdot
.51492 .30219 Mdot
.55682 .73787 Mdot
.46244 .65787 Mdot
.32253 .5978 Mdot
.58028 .52582 Mdot
.5689 .6418 Mdot
.53212 .32235 Mdot
.2937 .54272 Mdot
.50904 .59755 Mdot
.69731 .55063 Mdot
.2981 .54288 Mdot
.49615 .36102 Mdot
.30882 .38955 Mdot
.67918 .56364 Mdot
.52856 .33595 Mdot
.65635 .51295 Mdot
.28661 .65778 Mdot
.27642 .49428 Mdot
.44081 .39262 Mdot
.5447 .44935 Mdot
.44381 .61983 Mdot
.40658 .66642 Mdot
.49127 .58796 Mdot
.47623 .62961 Mdot
.3348 .39631 Mdot
.35019 .57318 Mdot
.71063 .53643 Mdot
.82441 .57423 Mdot
.52353 .28564 Mdot
.41479 .4907 Mdot
.57868 .59084 Mdot
.51511 .62169 Mdot
.67597 .54407 Mdot
.71746 .55102 Mdot
.74988 .66005 Mdot
.32297 .41544 Mdot
.57285 .61225 Mdot
.4675 .59565 Mdot
.57573 .66292 Mdot
.52383 .32413 Mdot
.71536 .31845 Mdot
.31366 .40375 Mdot
.11683 .53828 Mdot
.35523 .40853 Mdot
.2272 .41564 Mdot
.69382 .52317 Mdot
.31502 .50886 Mdot
.46766 .65218 Mdot
.69927 .47255 Mdot
.64494 .51312 Mdot
.33342 .45569 Mdot
.3156 .54041 Mdot
.72623 .31435 Mdot
.50399 .28439 Mdot
.45721 .64282 Mdot
.51515 .67271 Mdot
.52821 .61126 Mdot
.5106 .58755 Mdot
.49663 .29097 Mdot
.53676 .59968 Mdot
.55018 .30598 Mdot
.56785 .74404 Mdot
.32278 .73916 Mdot
.37849 .40753 Mdot
.29447 .30004 Mdot
.71818 .5283 Mdot
.61577 .62214 Mdot
.6071 .72995 Mdot
.55658 .49306 Mdot
.47808 .31454 Mdot
.46098 .66057 Mdot
.36051 .38294 Mdot
.42031 .18779 Mdot
.3768 .41015 Mdot
.48151 .12849 Mdot
.49159 .77398 Mdot
.7738 .39963 Mdot
.52074 .59253 Mdot
.38312 .39894 Mdot
.62046 .77206 Mdot
.43005 .61845 Mdot
.32872 .5145 Mdot
.54172 .73213 Mdot
.77656 .48995 Mdot
.32095 .51759 Mdot
.49451 .66797 Mdot
.71777 .54209 Mdot
.46975 .63944 Mdot
.47239 .66012 Mdot
.51477 .63304 Mdot
.51127 .25569 Mdot
.51129 .67798 Mdot
.46758 .65993 Mdot
.53802 .81572 Mdot
.36462 .49936 Mdot
.37075 .38702 Mdot
.71803 .71037 Mdot
.30183 .53089 Mdot
.67432 .49946 Mdot
.49511 .41009 Mdot
.51012 .28165 Mdot
.74627 .66246 Mdot
.52749 .59654 Mdot
.73834 .42062 Mdot
.498 .33612 Mdot
.29437 .52379 Mdot
.61686 .41129 Mdot
.69092 .2699 Mdot
.33448 .37089 Mdot
.64193 .42999 Mdot
.33489 .39284 Mdot
.67133 .76228 Mdot
.64863 .52734 Mdot
.44267 .61991 Mdot
.53858 .29343 Mdot
.37458 .38218 Mdot
.29236 .59348 Mdot
.48418 .61592 Mdot
.32601 .38265 Mdot
.44123 .62988 Mdot
.52786 .45492 Mdot
.50477 .41136 Mdot
.36506 .36621 Mdot
.50858 .34105 Mdot
.51539 .31678 Mdot
.31283 .50211 Mdot
.69433 .50071 Mdot
.69335 .51128 Mdot
.51091 .3071 Mdot
.15118 .58735 Mdot
.50563 .65298 Mdot
.51702 .662 Mdot
.56855 .44897 Mdot
.50591 .58961 Mdot
.36655 .57241 Mdot
.64044 .41274 Mdot
.68051 .50423 Mdot
.49772 .59008 Mdot
.52068 .6112 Mdot
.52675 .66397 Mdot
.28383 .63208 Mdot
.34682 .3989 Mdot
.53943 .61891 Mdot
.28778 .54569 Mdot
.6306 .38965 Mdot
.49814 .67275 Mdot
.4314 .62313 Mdot
.65232 .51874 Mdot
.17968 .50365 Mdot
.5291 .29782 Mdot
.32495 .4079 Mdot
.35899 .43446 Mdot
.33031 .69204 Mdot
.73556 .54546 Mdot
.64437 .42175 Mdot
.33693 .27952 Mdot
.60971 .41586 Mdot
.31984 .53271 Mdot
.45989 .39102 Mdot
.37236 .44329 Mdot
.36958 .40713 Mdot
.52199 .34215 Mdot
.48559 .59632 Mdot
.50992 .67252 Mdot
.71488 .42991 Mdot
.52035 .64809 Mdot
.31342 .54769 Mdot
.53924 .32579 Mdot
.65197 .52263 Mdot
.30173 .56568 Mdot
.5328 .30915 Mdot
.70172 .51696 Mdot
.46152 .67829 Mdot
.5098 .57389 Mdot
.66686 .53026 Mdot
.65926 .54555 Mdot
.50237 .63454 Mdot
.60191 .8148 Mdot
.68658 .50493 Mdot
.66861 .54155 Mdot
.59287 .40118 Mdot
.34554 .36548 Mdot
.43204 .57317 Mdot
.5008 .29795 Mdot
.46652 .64021 Mdot
.37889 .40879 Mdot
.31506 .51474 Mdot
.66296 .52369 Mdot
.53055 .64388 Mdot
.4984 .65512 Mdot
.31255 .52597 Mdot
.29852 .57336 Mdot
.31087 .55466 Mdot
.51513 .25788 Mdot
.54371 .6191 Mdot
.70504 .5383 Mdot
.5031 .28493 Mdot
.31877 .55981 Mdot
.29714 .50518 Mdot
.53642 .81038 Mdot
.50824 .6461 Mdot
.33243 .53435 Mdot
.27481 .80462 Mdot
.36641 .62795 Mdot
.63797 .41777 Mdot
.38105 .41995 Mdot
.32734 .59191 Mdot
.27965 .52238 Mdot
.50675 .27361 Mdot
.37313 .50282 Mdot
.30277 .49474 Mdot
.52238 .64484 Mdot
.49669 .60942 Mdot
.54848 .60849 Mdot
.29783 .53634 Mdot
.2872 .64622 Mdot
.69357 .55751 Mdot
.66462 .64865 Mdot
.30177 .53114 Mdot
.36125 .36404 Mdot
.37776 .42177 Mdot
.3555 .41177 Mdot
.45567 .6529 Mdot
.74773 .67884 Mdot
.54773 .75332 Mdot
.62481 .70595 Mdot
.50739 .27883 Mdot
.71428 .55343 Mdot
.51205 .23877 Mdot
.67149 .52206 Mdot
.35459 .38996 Mdot
.2949 .53098 Mdot
.6484 .5498 Mdot
.51455 .32371 Mdot
.51672 .32007 Mdot
.32182 .42302 Mdot
.34653 .40632 Mdot
.33685 .41665 Mdot
.70545 .50353 Mdot
.6934 .52262 Mdot
.52398 .61795 Mdot
.6578 .5283 Mdot
.40216 .80808 Mdot
.29179 .57951 Mdot
.3495 .44508 Mdot
.52425 .29628 Mdot
.66873 .54599 Mdot
.47257 .62144 Mdot
.25586 .39503 Mdot
.33409 .454 Mdot
.3021 .55982 Mdot
.59355 .28406 Mdot
.36156 .17594 Mdot
.46728 .67774 Mdot
.49148 .30643 Mdot
.52248 .53118 Mdot
.48668 .62134 Mdot
.34527 .37216 Mdot
.40621 .782 Mdot
.61436 .40873 Mdot
.47739 .66857 Mdot
.46476 .61015 Mdot
.5279 .32816 Mdot
.49882 .41079 Mdot
.5197 .63938 Mdot
.44336 .44217 Mdot
.49287 .28064 Mdot
.31387 .40494 Mdot
.6612 .8132 Mdot
.46908 .32109 Mdot
.25233 .59759 Mdot
.63046 .41157 Mdot
.52335 .65098 Mdot
.33239 .40521 Mdot
.29374 .55715 Mdot
.33818 .40504 Mdot
.6332 .5323 Mdot
.34302 .36795 Mdot
.48615 .60888 Mdot
.7067 .53474 Mdot
.52776 .31363 Mdot
.40418 .49675 Mdot
.56831 .8071 Mdot
.37407 .39769 Mdot
.61225 .40366 Mdot
.50056 .67054 Mdot
.59858 .69346 Mdot
.56241 .66009 Mdot
.47856 .67226 Mdot
.51663 .26876 Mdot
.68078 .54232 Mdot
.51214 .26505 Mdot
.4442 .65705 Mdot
.61511 .59581 Mdot
.52076 .28467 Mdot
.76344 .49195 Mdot
.31817 .55315 Mdot
.2765 .61738 Mdot
.48148 .63833 Mdot
.53777 .29179 Mdot
.54537 .627 Mdot
.68818 .55702 Mdot
.51893 .48343 Mdot
.60115 .54337 Mdot
.54259 .29976 Mdot
.78907 .44494 Mdot
.50893 .44029 Mdot
.42271 .58616 Mdot
.53312 .28959 Mdot
.74125 .69739 Mdot
.62565 .42313 Mdot
.3067 .51757 Mdot
.30454 .57111 Mdot
.29053 .51948 Mdot
.5204 .65226 Mdot
.54453 .71717 Mdot
.28739 .51821 Mdot
.51314 .25995 Mdot
.28335 .54368 Mdot
.28343 .68546 Mdot
.71648 .39938 Mdot
.3093 .55806 Mdot
.48176 .64218 Mdot
.43341 .63786 Mdot
.36483 .50359 Mdot
.32145 .36749 Mdot
.72614 .28982 Mdot
.50803 .80452 Mdot
.5135 .65345 Mdot
.56841 .70526 Mdot
.63824 .54847 Mdot
.44312 .52193 Mdot
.59827 .57008 Mdot
.49359 .38824 Mdot
.66734 .54339 Mdot
.52926 .42606 Mdot
.68471 .50242 Mdot
.44316 .64532 Mdot
.49222 .65691 Mdot
.65474 .50168 Mdot
.65036 .34302 Mdot
.79584 .63894 Mdot
.72546 .40827 Mdot
.7106 .52057 Mdot
.53371 .29457 Mdot
.491 .29095 Mdot
.51877 .26944 Mdot
.32889 .41743 Mdot
.65132 .54051 Mdot
.54123 .64328 Mdot
.36916 .39404 Mdot
.47122 .65361 Mdot
.50983 .31292 Mdot
.57577 .50293 Mdot
.65149 .52244 Mdot
.49118 .63438 Mdot
.54598 .78753 Mdot
.34128 .38871 Mdot
.30916 .52504 Mdot
.5993 .27103 Mdot
.37302 .43647 Mdot
.5017 .32873 Mdot
.70226 .56551 Mdot
.32996 .34419 Mdot
.23308 .37722 Mdot
.54622 .65362 Mdot
.54605 .65121 Mdot
.29531 .40903 Mdot
.56602 .79405 Mdot
.5133 .62494 Mdot
.36944 .40242 Mdot
.34905 .36395 Mdot
.54602 .63843 Mdot
.66339 .55425 Mdot
.28994 .50963 Mdot
.31569 .49771 Mdot
.44999 .61921 Mdot
.54346 .44019 Mdot
.31426 .59813 Mdot
.51642 .60275 Mdot
.49252 .56116 Mdot
.32725 .35878 Mdot
.62808 .40863 Mdot
.55719 .47055 Mdot
.30294 .50576 Mdot
.48921 .66192 Mdot
.80239 .60183 Mdot
.65305 .53415 Mdot
.31966 .39682 Mdot
.50035 .31442 Mdot
.33082 .53751 Mdot
.33231 .4394 Mdot
.54595 .63902 Mdot
.52015 .61047 Mdot
.53925 .30367 Mdot
.67821 .57492 Mdot
.29577 .5357 Mdot
.3687 .39034 Mdot
.31528 .50861 Mdot
.69154 .51913 Mdot
.66096 .53938 Mdot
.46363 .59772 Mdot
.56632 .64719 Mdot
.36854 .41865 Mdot
.52537 .58048 Mdot
.35734 .41629 Mdot
.30851 .29278 Mdot
.49672 .31254 Mdot
.47156 .6049 Mdot
.74042 .53482 Mdot
.51001 .3119 Mdot
.51285 .64331 Mdot
.29472 .40519 Mdot
.51159 .6097 Mdot
.37762 .38035 Mdot
.43173 .78975 Mdot
.30247 .51002 Mdot
.43722 .6942 Mdot
.39611 .61017 Mdot
.50434 .59012 Mdot
.33978 .36033 Mdot
.52462 .72885 Mdot
.51717 .28479 Mdot
.69448 .53031 Mdot
.16698 .51941 Mdot
.51962 .30311 Mdot
.47897 .64927 Mdot
.3028 .54248 Mdot
.70566 .51285 Mdot
.6241 .43334 Mdot
.55596 .42931 Mdot
.42513 .64739 Mdot
.50933 .69922 Mdot
.46848 .61827 Mdot
.33466 .23025 Mdot
.33611 .41251 Mdot
.67957 .54573 Mdot
.49161 .29689 Mdot
.50626 .29531 Mdot
.34778 .39136 Mdot
.77593 .47312 Mdot
.69254 .35949 Mdot
.32452 .84361 Mdot
.34153 .44416 Mdot
.28461 .53574 Mdot
.51742 .47355 Mdot
.35936 .40842 Mdot
.32783 .40587 Mdot
.30907 .38318 Mdot
.71318 .41832 Mdot
.71156 .52376 Mdot
.5 .65671 Mdot
.73154 .52345 Mdot
.52284 .65231 Mdot
.25442 .59144 Mdot
.5082 .30595 Mdot
.69491 .52868 Mdot
.27986 .47646 Mdot
.40946 .64853 Mdot
.49553 .62169 Mdot
.24443 .57067 Mdot
.45683 .68349 Mdot
.34998 .63831 Mdot
.49194 .57948 Mdot
.34059 .39943 Mdot
.62049 .58559 Mdot
.457 .58114 Mdot
.53845 .78621 Mdot
.5206 .32027 Mdot
.61677 .43383 Mdot
.45284 .67353 Mdot
.45383 .56934 Mdot
.70689 .51232 Mdot
.64656 .54808 Mdot
.2876 .51715 Mdot
.60593 .25667 Mdot
.52314 .31906 Mdot
.74686 .36002 Mdot
.48549 .6749 Mdot
.53084 .35787 Mdot
.42143 .79046 Mdot
.50893 .63594 Mdot
.44924 .38213 Mdot
.74734 .6614 Mdot
.51238 .618 Mdot
.63604 .69489 Mdot
.52102 .29648 Mdot
.3112 .73479 Mdot
.50501 .57691 Mdot
.34263 .37354 Mdot
.69995 .52697 Mdot
.68023 .56328 Mdot
.29997 .56175 Mdot
.43274 .81891 Mdot
.55526 .2507 Mdot
.69541 .5249 Mdot
.4808 .62032 Mdot
.52829 .29873 Mdot
.62558 .43475 Mdot
.4191 .65321 Mdot
.46704 .19701 Mdot
.65523 .52685 Mdot
.50045 .56796 Mdot
.73716 .41302 Mdot
.51622 .41713 Mdot
.78851 .3532 Mdot
.5287 .27362 Mdot
.30439 .50425 Mdot
.56245 .60761 Mdot
.33308 .28348 Mdot
.51381 .57533 Mdot
.25363 .59364 Mdot
.74688 .53543 Mdot
.32239 .52672 Mdot
.48637 .62532 Mdot
.51906 .6365 Mdot
.54251 .46175 Mdot
.30892 .57095 Mdot
.52002 .63934 Mdot
.52389 .57022 Mdot
.6921 .51347 Mdot
.63983 .41156 Mdot
.65389 .52063 Mdot
.47368 .6354 Mdot
.42909 .77811 Mdot
.65817 .55492 Mdot
.7282 .29929 Mdot
.27297 .55302 Mdot
.51095 .2808 Mdot
.46365 .57444 Mdot
.46645 .66407 Mdot
.69656 .22507 Mdot
.63412 .43294 Mdot
.1812 .41855 Mdot
.38266 .39889 Mdot
.80575 .6676 Mdot
.36899 .44269 Mdot
.78242 .41481 Mdot
.42082 .47961 Mdot
.53819 .59186 Mdot
.40873 .69509 Mdot
.62777 .69583 Mdot
.51385 .35422 Mdot
.60943 .64961 Mdot
.48805 .67476 Mdot
.50304 .66657 Mdot
.36608 .40211 Mdot
.77327 .45759 Mdot
.54587 .53025 Mdot
.55452 .46717 Mdot
.29622 .52225 Mdot
.68437 .52276 Mdot
.48955 .60924 Mdot
.61869 .32614 Mdot
.37369 .38592 Mdot
.44271 .75166 Mdot
.48974 .63613 Mdot
.55028 .52214 Mdot
.75104 .46483 Mdot
.52986 .31041 Mdot
.36216 .36331 Mdot
.35244 .35872 Mdot
.52622 .6535 Mdot
.49869 .29106 Mdot
.51942 .61825 Mdot
.5075 .44624 Mdot
.42432 .63937 Mdot
.31891 .5237 Mdot
.46361 .6453 Mdot
.38952 .66218 Mdot
.8171 .44906 Mdot
.42706 .59823 Mdot
.7118 .51029 Mdot
.3383 .42119 Mdot
.35119 .39954 Mdot
.69449 .51145 Mdot
.35165 .39882 Mdot
.66387 .65666 Mdot
.59314 .66179 Mdot
.32053 .53131 Mdot
.60107 .74374 Mdot
.3014 .51306 Mdot
.61411 .43274 Mdot
.50688 .64204 Mdot
.39682 .26101 Mdot
.33959 .44415 Mdot
.29261 .71053 Mdot
.51196 .30264 Mdot
.6369 .43077 Mdot
.53169 .66444 Mdot
.33515 .52094 Mdot
.35773 .38688 Mdot
.45825 .32414 Mdot
.5282 .65845 Mdot
.70826 .54564 Mdot
.51487 .62242 Mdot
.50479 .69165 Mdot
.64132 .42443 Mdot
.47091 .61382 Mdot
.53285 .30889 Mdot
.64872 .53743 Mdot
.77223 .40662 Mdot
.3267 .41713 Mdot
.484 .66929 Mdot
.48179 .6207 Mdot
.64027 .54135 Mdot
.52884 .67019 Mdot
.50366 .27828 Mdot
.5202 .91588 Mdot
.32003 .54822 Mdot
.6259 .40746 Mdot
.61761 .21911 Mdot
.49434 .60165 Mdot
.51059 .6001 Mdot
.5013 .37749 Mdot
.79557 .60826 Mdot
.52753 .28832 Mdot
.46159 .68134 Mdot
.36585 .37666 Mdot
.29487 .53897 Mdot
.53988 .28123 Mdot
.5423 .61356 Mdot
.50567 .66464 Mdot
.32209 .53572 Mdot
.25034 .57713 Mdot
.29891 .48336 Mdot
.51059 .2744 Mdot
.58425 .67117 Mdot
.25949 .39459 Mdot
.50074 .64763 Mdot
.5955 .42647 Mdot
.67532 .53958 Mdot
.52953 .28416 Mdot
.7834 .60291 Mdot
.44339 .64148 Mdot
.51456 .33229 Mdot
.52655 .31549 Mdot
.52522 .67259 Mdot
.73252 .55028 Mdot
.72926 .53907 Mdot
.67402 .54102 Mdot
.32705 .73619 Mdot
.22447 .34995 Mdot
.33443 .4166 Mdot
.52498 .30133 Mdot
.37753 .41373 Mdot
.30651 .49482 Mdot
.5281 .46227 Mdot
.35855 .36364 Mdot
.71909 .53193 Mdot
.3714 .42251 Mdot
.5168 .61343 Mdot
.51083 .32159 Mdot
.3621 .42953 Mdot
.51284 .59346 Mdot
.50314 .56124 Mdot
.40467 .6827 Mdot
.28871 .50999 Mdot
.53039 .42576 Mdot
.47612 .64413 Mdot
.61867 .41144 Mdot
.49934 .63516 Mdot
.49974 .28296 Mdot
.37529 .50637 Mdot
.53436 .606 Mdot
.34151 .44483 Mdot
.24058 .34905 Mdot
.33225 .36477 Mdot
.51942 .68346 Mdot
.47431 .6372 Mdot
.5036 .64925 Mdot
.51496 .67017 Mdot
.77624 .49756 Mdot
.54687 .32608 Mdot
.57402 .59196 Mdot
.33192 .43605 Mdot
.66736 .52396 Mdot
.66697 .5598 Mdot
.49227 .38197 Mdot
.63669 .43401 Mdot
.49927 .29548 Mdot
.50413 .6511 Mdot
.45835 .32804 Mdot
.56578 .41615 Mdot
.73148 .40895 Mdot
.32204 .3421 Mdot
.36854 .41083 Mdot
.71826 .51402 Mdot
.35441 .42853 Mdot
.54473 .61949 Mdot
.51787 .57346 Mdot
.77222 .40081 Mdot
.52564 .25599 Mdot
.29542 .53361 Mdot
.46907 .65102 Mdot
.27981 .60893 Mdot
.36644 .38168 Mdot
.33243 .35705 Mdot
.52184 .62061 Mdot
.66338 .57061 Mdot
.83178 .41737 Mdot
.49923 .30558 Mdot
.59476 .69746 Mdot
.62831 .57568 Mdot
.58518 .64429 Mdot
.51432 .28896 Mdot
.44965 .39997 Mdot
.31504 .37895 Mdot
.48482 .814 Mdot
.66453 .5299 Mdot
.29675 .53123 Mdot
.48723 .57637 Mdot
.71921 .53135 Mdot
.37215 .42739 Mdot
.67327 .50143 Mdot
.44152 .62093 Mdot
.5074 .26381 Mdot
.35539 .40407 Mdot
.52965 .34742 Mdot
.65117 .50579 Mdot
.30141 .5121 Mdot
.30192 .7063 Mdot
.58591 .71503 Mdot
.74765 .66056 Mdot
.53985 .62058 Mdot
.42783 .2662 Mdot
.54007 .64507 Mdot
.7243 .53159 Mdot
.4813 .63884 Mdot
.41047 .67221 Mdot
.31079 .39094 Mdot
.47255 .57702 Mdot
.46393 .65101 Mdot
.5312 .78274 Mdot
.50399 .62701 Mdot
.53571 .65896 Mdot
.46026 .61211 Mdot
.6774 .57734 Mdot
.46956 .57947 Mdot
.70828 .54498 Mdot
.7289 .43159 Mdot
.32743 .40336 Mdot
.31074 .49672 Mdot
.32326 .51499 Mdot
.2464 .59023 Mdot
.27981 .61435 Mdot
.77113 .46447 Mdot
.66621 .51417 Mdot
.52753 .32417 Mdot
.51961 .61673 Mdot
.7237 .7199 Mdot
.40198 .75232 Mdot
.31223 .39296 Mdot
.36969 .42092 Mdot
.50047 .57374 Mdot
.42908 .16904 Mdot
.47824 .57608 Mdot
.56796 .43752 Mdot
.52154 .65505 Mdot
.46469 .61278 Mdot
.34207 .35431 Mdot
.28395 .65422 Mdot
.53951 .61894 Mdot
.70585 .51173 Mdot
.30107 .52318 Mdot
.59209 .59501 Mdot
.38853 .7519 Mdot
.4867 .76134 Mdot
.47839 .54495 Mdot
.53005 .59573 Mdot
.36336 .38109 Mdot
.71061 .51847 Mdot
.56499 .45724 Mdot
.50619 .27796 Mdot
.54837 .4334 Mdot
.56675 .74035 Mdot
.51914 .2231 Mdot
.29686 .52755 Mdot
.31657 .4447 Mdot
.48585 .60829 Mdot
.33024 .41775 Mdot
.44687 .65719 Mdot
.56452 .40165 Mdot
.31853 .51857 Mdot
.69204 .49785 Mdot
.53371 .29548 Mdot
.71135 .54546 Mdot
.70483 .72767 Mdot
.41007 .75953 Mdot
.80531 .66939 Mdot
.327 .3764 Mdot
.74603 .58831 Mdot
.69499 .54142 Mdot
.53279 .65404 Mdot
.31777 .83792 Mdot
.67978 .53639 Mdot
.71323 .5413 Mdot
.49227 .39254 Mdot
.30778 .6975 Mdot
.48605 .57038 Mdot
.6772 .50308 Mdot
.30298 .39242 Mdot
.31169 .54003 Mdot
.51631 .59609 Mdot
.44423 .62952 Mdot
.64699 .5477 Mdot
.35481 .3864 Mdot
.26595 .60764 Mdot
.34407 .40247 Mdot
.71135 .52705 Mdot
.33724 .38487 Mdot
.72526 .30311 Mdot
.36819 .37453 Mdot
.46234 .64942 Mdot
.50308 .65064 Mdot
.42522 .2188 Mdot
.66095 .53934 Mdot
.50926 .59863 Mdot
.49595 .66291 Mdot
.70047 .54099 Mdot
.37389 .44148 Mdot
.77494 .595 Mdot
.50207 .59404 Mdot
.50285 .65486 Mdot
.32535 .53576 Mdot
.52221 .43837 Mdot
.5777 .4092 Mdot
.51341 .59671 Mdot
.28774 .52645 Mdot
.71169 .50654 Mdot
.49994 .63368 Mdot
.28206 .6526 Mdot
.36441 .44384 Mdot
.5199 .58686 Mdot
.61644 .4317 Mdot
.5144 .63046 Mdot
.82803 .41798 Mdot
.49681 .67041 Mdot
.68763 .5476 Mdot
.7 .53325 Mdot
.33055 .46753 Mdot
.67286 .52464 Mdot
.63854 .42066 Mdot
.51391 .31477 Mdot
.80411 .46534 Mdot
.63856 .4236 Mdot
.45671 .62985 Mdot
.46934 .82626 Mdot
.44526 .6229 Mdot
.42923 .62731 Mdot
.28413 .70193 Mdot
.63283 .41405 Mdot
.68524 .54124 Mdot
.64934 .33895 Mdot
.53172 .58791 Mdot
.49869 .30023 Mdot
.4302 .6196 Mdot
.52025 .58681 Mdot
.40886 .68059 Mdot
.59331 .65148 Mdot
.54055 .32628 Mdot
.42637 .57838 Mdot
.5167 .59667 Mdot
.79324 .61023 Mdot
.48046 .61484 Mdot
.30753 .56021 Mdot
.67362 .50941 Mdot
.34697 .4314 Mdot
.31829 .53404 Mdot
.49011 .60485 Mdot
.29933 .53464 Mdot
.331 .41473 Mdot
.53689 .28301 Mdot
.46289 .64055 Mdot
.30027 .57873 Mdot
.2941 .53177 Mdot
.53291 .63162 Mdot
.69701 .5269 Mdot
.55805 .66798 Mdot
.50169 .63296 Mdot
.54266 .65179 Mdot
.69247 .51109 Mdot
.27473 .75445 Mdot
.51989 .66656 Mdot
.44936 .39559 Mdot
.67026 .49115 Mdot
.64049 .41558 Mdot
.36232 .41721 Mdot
.55533 .61266 Mdot
.50463 .29618 Mdot
.51239 .31051 Mdot
.31853 .42184 Mdot
.64321 .53579 Mdot
.35556 .40046 Mdot
.41424 .62738 Mdot
.51431 .57176 Mdot
.48881 .57616 Mdot
.1668 .51791 Mdot
.68219 .25995 Mdot
.67189 .55018 Mdot
.32402 .36764 Mdot
.54832 .44398 Mdot
.50272 .31083 Mdot
.31975 .36305 Mdot
.72672 .50962 Mdot
.64713 .51892 Mdot
.69369 .50961 Mdot
.28889 .5313 Mdot
.35083 .40931 Mdot
.71147 .49412 Mdot
.72555 .54533 Mdot
.5278 .62546 Mdot
.51884 .5973 Mdot
.62906 .53954 Mdot
.36718 .46398 Mdot
.31118 .51287 Mdot
.35678 .3728 Mdot
.79472 .30328 Mdot
.49899 .30555 Mdot
.53101 .78349 Mdot
.51106 .59331 Mdot
.12542 .62731 Mdot
.47582 .57785 Mdot
.4805 .61868 Mdot
.6671 .49962 Mdot
.32547 .55758 Mdot
.30939 .53807 Mdot
.69629 .54049 Mdot
.68679 .56905 Mdot
.29143 .54744 Mdot
.47387 .38826 Mdot
.82302 .48935 Mdot
.55978 .45115 Mdot
.69 .54921 Mdot
.59094 .71491 Mdot
.53983 .28314 Mdot
.6881 .49237 Mdot
.53596 .33931 Mdot
.32643 .40423 Mdot
.37474 .40235 Mdot
.53991 .30634 Mdot
.52995 .66281 Mdot
.33123 .37545 Mdot
.41733 .6181 Mdot
.76992 .37427 Mdot
.49803 .20575 Mdot
.7352 .72765 Mdot
.47998 .67526 Mdot
.53108 .52812 Mdot
.68629 .42453 Mdot
.47621 .60848 Mdot
.42003 .57784 Mdot
.29665 .53468 Mdot
.6761 .4916 Mdot
.54482 .28807 Mdot
.74254 .29386 Mdot
.50184 .64854 Mdot
.71088 .53585 Mdot
.50634 .3184 Mdot
.71949 .30344 Mdot
.44355 .44076 Mdot
.52278 .63229 Mdot
.38045 .87862 Mdot
.6508 .5073 Mdot
.34681 .43119 Mdot
.57637 .77076 Mdot
.72246 .51161 Mdot
.25414 .37472 Mdot
.36864 .36405 Mdot
.59124 .48556 Mdot
.65871 .50572 Mdot
.3014 .4853 Mdot
.68635 .51863 Mdot
.29197 .56226 Mdot
.69977 .56688 Mdot
.34659 .38485 Mdot
.49263 .62586 Mdot
.34505 .38798 Mdot
.31878 .55688 Mdot
.31818 .39166 Mdot
.54494 .2887 Mdot
.62596 .40998 Mdot
.51358 .31913 Mdot
.52417 .4648 Mdot
.74253 .61953 Mdot
.52457 .27504 Mdot
.45216 .33316 Mdot
.50912 .61966 Mdot
.67219 .57516 Mdot
.34008 .43199 Mdot
.32559 .43953 Mdot
.5362 .43085 Mdot
.70547 .52166 Mdot
.34743 .38014 Mdot
.57853 .72073 Mdot
.14985 .59911 Mdot
.44625 .58414 Mdot
.23456 .33394 Mdot
.69864 .54324 Mdot
.31162 .38295 Mdot
.56831 .44642 Mdot
.6655 .56251 Mdot
.36573 .42427 Mdot
.53503 .2929 Mdot
.50697 .29096 Mdot
.52178 .67305 Mdot
.49398 .26996 Mdot
.34066 .35939 Mdot
.80072 .60445 Mdot
.68031 .50846 Mdot
.66104 .24538 Mdot
.3052 .55702 Mdot
.32801 .40925 Mdot
.47849 .57362 Mdot
.74326 .52021 Mdot
.35847 .43631 Mdot
.46405 .18349 Mdot
.75014 .26055 Mdot
.34728 .37947 Mdot
.6721 .50968 Mdot
.66525 .52127 Mdot
.42751 .60012 Mdot
.54777 .45225 Mdot
.35447 .38313 Mdot
.39554 .26009 Mdot
.28478 .59748 Mdot
.63028 .42956 Mdot
.52253 .81085 Mdot
.53991 .61902 Mdot
.52852 .59387 Mdot
.50633 .27569 Mdot
.49723 .61982 Mdot
.70488 .56145 Mdot
.47939 .57806 Mdot
.49467 .27925 Mdot
.31465 .40603 Mdot
.50485 .6442 Mdot
.29534 .54525 Mdot
.51701 .26684 Mdot
.49101 .31552 Mdot
.33067 .39109 Mdot
.67727 .50606 Mdot
.63384 .34705 Mdot
.34552 .40358 Mdot
.54099 .61218 Mdot
.62619 .416 Mdot
.49051 .58105 Mdot
.42688 .22524 Mdot
.69673 .55657 Mdot
.3536 .42872 Mdot
.63659 .51612 Mdot
.52501 .30695 Mdot
.31135 .41633 Mdot
.47918 .61113 Mdot
.37109 .40856 Mdot
.44128 .40123 Mdot
.21727 .4587 Mdot
.71434 .55643 Mdot
.34961 .49508 Mdot
.64431 .54621 Mdot
.62969 .43031 Mdot
.33028 .67532 Mdot
.30864 .51619 Mdot
.35333 .36703 Mdot
.72486 .29338 Mdot
.3357 .43277 Mdot
.50679 .62928 Mdot
.51357 .66537 Mdot
.36562 .40448 Mdot
.29472 .5171 Mdot
.24473 .6172 Mdot
.30559 .58751 Mdot
.65142 .53529 Mdot
.43506 .48267 Mdot
.8213 .34572 Mdot
.35049 .34332 Mdot
.53078 .32206 Mdot
.50302 .54972 Mdot
.50748 .60921 Mdot
.52339 .33118 Mdot
.49468 .30395 Mdot
.31728 .56153 Mdot
.32702 .41468 Mdot
.68498 .48853 Mdot
.54418 .29941 Mdot
.73561 .50463 Mdot
.26935 .62503 Mdot
.47151 .69037 Mdot
.55984 .69301 Mdot
.45803 .65181 Mdot
.51694 .41724 Mdot
.50172 .27174 Mdot
.4826 .6483 Mdot
.53361 .57411 Mdot
.52549 .28211 Mdot
.31062 .56495 Mdot
.66996 .47763 Mdot
.34094 .37769 Mdot
.1364 .60838 Mdot
.46301 .64195 Mdot
.49643 .62833 Mdot
.50718 .27925 Mdot
.58038 .79212 Mdot
.6784 .55258 Mdot
.67329 .50627 Mdot
.33639 .41339 Mdot
.54556 .39644 Mdot
.53402 .66721 Mdot
.46827 .62445 Mdot
.33599 .37416 Mdot
.61919 .41204 Mdot
.66187 .79788 Mdot
.49601 .65347 Mdot
.51921 .29267 Mdot
.44193 .34388 Mdot
.50573 .26799 Mdot
.46212 .67493 Mdot
.51035 .63396 Mdot
.46004 .63263 Mdot
.49498 .68016 Mdot
.54094 .31178 Mdot
.47273 .61452 Mdot
.52487 .69726 Mdot
.68035 .54131 Mdot
.53508 .60385 Mdot
.28731 .59972 Mdot
.49609 .64974 Mdot
.29613 .54525 Mdot
.57829 .39491 Mdot
.48586 .66854 Mdot
.53481 .60263 Mdot
.28237 .59344 Mdot
.48265 .62592 Mdot
.51321 .3255 Mdot
.6629 .5274 Mdot
.52647 .30576 Mdot
.52739 .32085 Mdot
.36629 .42938 Mdot
.29526 .56794 Mdot
.53427 .58071 Mdot
.28953 .54587 Mdot
.41965 .62007 Mdot
.44159 .63697 Mdot
.5243 .45175 Mdot
.56757 .43626 Mdot
.29822 .49468 Mdot
.47363 .61735 Mdot
.3334 .40876 Mdot
.358 .42639 Mdot
.37275 .50275 Mdot
.42122 .63521 Mdot
.54297 .28747 Mdot
.53756 .29164 Mdot
.36738 .57347 Mdot
.38058 .54373 Mdot
.29266 .53673 Mdot
.50668 .49761 Mdot
.44813 .64306 Mdot
.49411 .66637 Mdot
.43208 .63433 Mdot
.3814 .39671 Mdot
.62491 .40866 Mdot
.3173 .41067 Mdot
.59584 .40064 Mdot
.53173 .26848 Mdot
.47945 .67489 Mdot
.51725 .20035 Mdot
.65444 .54906 Mdot
.66205 .52828 Mdot
.49246 .28294 Mdot
.33375 .36361 Mdot
.42343 .63925 Mdot
.15198 .45199 Mdot
.6826 .56565 Mdot
.31013 .4983 Mdot
.4699 .63761 Mdot
.32914 .39692 Mdot
.64695 .53583 Mdot
.28492 .56093 Mdot
.47024 .67 Mdot
.34445 .35021 Mdot
.48711 .64346 Mdot
.63598 .71283 Mdot
.68954 .53666 Mdot
.57659 .49836 Mdot
.64023 .56115 Mdot
.52941 .32555 Mdot
.53013 .29457 Mdot
.51254 .64162 Mdot
.13826 .52329 Mdot
.63202 .49984 Mdot
.52203 .33455 Mdot
.28224 .54936 Mdot
.61982 .40792 Mdot
.28411 .55639 Mdot
.35835 .41486 Mdot
.29989 .52298 Mdot
.35587 .43748 Mdot
.37547 .45774 Mdot
.63767 .50096 Mdot
.32027 .54026 Mdot
.58138 .79706 Mdot
.51879 .57384 Mdot
.32118 .55672 Mdot
.4961 .57513 Mdot
.40672 .65888 Mdot
.32921 .3809 Mdot
.29022 .53158 Mdot
.53093 .64326 Mdot
.61636 .21274 Mdot
.53209 .30852 Mdot
.54464 .29032 Mdot
.52172 .57636 Mdot
.31109 .38046 Mdot
.70515 .56329 Mdot
.48939 .42098 Mdot
.63614 .41018 Mdot
.46845 .6251 Mdot
.45961 .66224 Mdot
.64087 .51471 Mdot
.71926 .52397 Mdot
.51345 .6405 Mdot
.58574 .70213 Mdot
.48609 .60695 Mdot
.50881 .28785 Mdot
.65122 .53912 Mdot
.66213 .52455 Mdot
.3508 .36099 Mdot
.64375 .53773 Mdot
.57671 .62591 Mdot
.47901 .30097 Mdot
.45423 .59802 Mdot
.52257 .30587 Mdot
.37974 .47385 Mdot
.32248 .4117 Mdot
.72218 .28703 Mdot
.64437 .53247 Mdot
.49716 .58993 Mdot
.66656 .55901 Mdot
.31141 .55375 Mdot
.65925 .53776 Mdot
.63415 .54444 Mdot
.49731 .67484 Mdot
.52343 .6453 Mdot
.62067 .41419 Mdot
.54347 .44351 Mdot
.69001 .53134 Mdot
.49123 .59786 Mdot
.48926 .58448 Mdot
.52281 .66298 Mdot
.50943 .43721 Mdot
.67856 .49829 Mdot
.51329 .77149 Mdot
.45664 .21663 Mdot
.69354 .52681 Mdot
.79075 .33124 Mdot
.60768 .41861 Mdot
.63516 .43497 Mdot
.50777 .33753 Mdot
.50073 .65626 Mdot
.35308 .39641 Mdot
.52618 .59079 Mdot
.4196 .63279 Mdot
.48049 .66738 Mdot
.32293 .53418 Mdot
.54808 .65007 Mdot
.61625 .42697 Mdot
.34347 .39808 Mdot
.49494 .59847 Mdot
.50786 .65031 Mdot
.6244 .43648 Mdot
.6325 .55123 Mdot
.64726 .51979 Mdot
.62382 .45087 Mdot
.31133 .5628 Mdot
.51274 .27065 Mdot
.53475 .59879 Mdot
.33515 .41075 Mdot
.34766 .39275 Mdot
.71193 .54416 Mdot
.34602 .37317 Mdot
.50801 .27068 Mdot
.4842 .61417 Mdot
.53132 .32461 Mdot
.32288 .53465 Mdot
.67442 .5093 Mdot
.54159 .61069 Mdot
.52874 .62938 Mdot
.69979 .53348 Mdot
.51204 .62302 Mdot
.32408 .5304 Mdot
.3783 .39045 Mdot
.65988 .54446 Mdot
.51409 .31381 Mdot
.35539 .36207 Mdot
.51812 .61178 Mdot
.63159 .17223 Mdot
.4976 .61901 Mdot
.46378 .63125 Mdot
.79538 .44632 Mdot
.47254 .59454 Mdot
.32922 .42482 Mdot
.6606 .55807 Mdot
.47053 .67967 Mdot
.28127 .59615 Mdot
.25707 .50337 Mdot
.35995 .35089 Mdot
.46854 .6367 Mdot
.77606 .33051 Mdot
.50124 .58926 Mdot
.74359 .32131 Mdot
.52521 .45235 Mdot
.34931 .22605 Mdot
.55666 .69569 Mdot
.52074 .33458 Mdot
.62131 .41192 Mdot
.32784 .42676 Mdot
.65126 .75387 Mdot
.50525 .62027 Mdot
.76092 .65456 Mdot
.53559 .598 Mdot
.51253 .2891 Mdot
.45962 .55621 Mdot
.35438 .37217 Mdot
.51133 .80482 Mdot
.54277 .64413 Mdot
.66391 .50154 Mdot
.31055 .42058 Mdot
.61424 .41059 Mdot
.53046 .64787 Mdot
.29679 .55552 Mdot
.26936 .5021 Mdot
.57517 .6288 Mdot
.52212 .30857 Mdot
.49236 .66349 Mdot
.45442 .56487 Mdot
.15691 .59085 Mdot
.67569 .54347 Mdot
.53479 .31138 Mdot
.43509 .53675 Mdot
.51709 .66411 Mdot
.64849 .51724 Mdot
.66551 .52783 Mdot
.29335 .5587 Mdot
.56677 .37715 Mdot
.24335 .50967 Mdot
.52408 .1805 Mdot
.73842 .68622 Mdot
.38039 .38875 Mdot
.74496 .48596 Mdot
.53111 .60552 Mdot
.41407 .7635 Mdot
.52332 .32247 Mdot
.49345 .6276 Mdot
.7228 .67881 Mdot
.66924 .54183 Mdot
.48807 .64824 Mdot
.3128 .51456 Mdot
.66432 .38336 Mdot
.54341 .73475 Mdot
.6677 .20621 Mdot
.3053 .38345 Mdot
.44672 .59328 Mdot
.5738 .64642 Mdot
.63992 .41511 Mdot
.46288 .67454 Mdot
.3351 .42976 Mdot
.4324 .27203 Mdot
.30382 .50723 Mdot
.65231 .54653 Mdot
.60844 .41573 Mdot
.53139 .59158 Mdot
.45615 .61198 Mdot
.30633 .49853 Mdot
.53595 .64717 Mdot
.5664 .76797 Mdot
.62127 .43874 Mdot
.36963 .37627 Mdot
.67686 .50142 Mdot
.45717 .65182 Mdot
.62078 .40923 Mdot
.5028 .67371 Mdot
.39019 .62265 Mdot
.4697 .64399 Mdot
.79449 .48228 Mdot
.69973 .52589 Mdot
.5212 .31413 Mdot
.55118 .64363 Mdot
.49473 .64243 Mdot
.26096 .39875 Mdot
.42174 .63888 Mdot
.49969 .66956 Mdot
.72092 .53415 Mdot
.65825 .55354 Mdot
.71431 .53235 Mdot
.35933 .36629 Mdot
.55906 .45859 Mdot
.51169 .29751 Mdot
.42899 .63742 Mdot
.54295 .29119 Mdot
.52395 .70968 Mdot
.29496 .5087 Mdot
.70126 .25955 Mdot
.49461 .61015 Mdot
.70222 .5157 Mdot
.79548 .54921 Mdot
.71416 .50783 Mdot
.54214 .24934 Mdot
.52195 .31995 Mdot
.68244 .53419 Mdot
.47846 .62693 Mdot
.55348 .46806 Mdot
.62098 .17807 Mdot
.50418 .31248 Mdot
.43385 .61961 Mdot
.30437 .38407 Mdot
.32892 .43921 Mdot
.81598 .38232 Mdot
.52004 .32756 Mdot
.68366 .42355 Mdot
.49909 .5926 Mdot
.65042 .54759 Mdot
.52409 .27218 Mdot
.50942 .32594 Mdot
.34097 .37219 Mdot
.5234 .62889 Mdot
.49293 .64349 Mdot
.61312 .43005 Mdot
.5403 .2893 Mdot
.44597 .68604 Mdot
.52007 .63067 Mdot
.77872 .41094 Mdot
.72403 .50613 Mdot
.28289 .76392 Mdot
.41251 .61137 Mdot
.72995 .67119 Mdot
.40995 .46179 Mdot
.66355 .54894 Mdot
.53815 .65533 Mdot
.42747 .63637 Mdot
.37496 .37688 Mdot
.48837 .61463 Mdot
.31876 .37751 Mdot
.52432 .32762 Mdot
.7101 .26237 Mdot
.4613 .34753 Mdot
.47739 .30965 Mdot
.50023 .62301 Mdot
.54345 .7317 Mdot
.31745 .543 Mdot
.53513 .26193 Mdot
.6998 .54792 Mdot
.45114 .64241 Mdot
.38233 .39033 Mdot
.36113 .36899 Mdot
.66831 .53328 Mdot
.71739 .443 Mdot
.72978 .30021 Mdot
.4881 .68002 Mdot
.36052 .41687 Mdot
.46391 .29579 Mdot
.61317 .63104 Mdot
.49952 .33116 Mdot
.30679 .50584 Mdot
.32637 .42102 Mdot
.50457 .25995 Mdot
.40733 .66315 Mdot
.67752 .52898 Mdot
.64338 .51377 Mdot
.27461 .37262 Mdot
.35108 .38396 Mdot
.31373 .52934 Mdot
.39571 .49553 Mdot
.40075 .49643 Mdot
.31741 .51696 Mdot
.31204 .39277 Mdot
.66147 .55137 Mdot
.71158 .53273 Mdot
.66411 .52593 Mdot
.53875 .78633 Mdot
.68618 .56101 Mdot
.35188 .77919 Mdot
.45277 .65682 Mdot
.60106 .68982 Mdot
.48188 .60013 Mdot
.54443 .31229 Mdot
.69132 .5358 Mdot
.53231 .4601 Mdot
.45473 .6235 Mdot
.64696 .19616 Mdot
.47468 .64348 Mdot
.44658 .36983 Mdot
.50225 .65624 Mdot
.5925 .75305 Mdot
.67358 .49079 Mdot
.47526 .61411 Mdot
.48476 .32256 Mdot
.29768 .53986 Mdot
.62463 .51767 Mdot
.49751 .66862 Mdot
.74067 .418 Mdot
.49672 .57547 Mdot
.77014 .34559 Mdot
.23242 .3841 Mdot
.32426 .51167 Mdot
.47443 .58672 Mdot
.35647 .44195 Mdot
.49823 .54224 Mdot
.60228 .70283 Mdot
.50491 .3133 Mdot
.55691 .72855 Mdot
.34352 .369 Mdot
.4186 .58005 Mdot
.49686 .69615 Mdot
.29764 .51162 Mdot
.64493 .48446 Mdot
.51011 .28492 Mdot
.50537 .61801 Mdot
.53568 .65699 Mdot
.42937 .19689 Mdot
.5983 .71605 Mdot
.48483 .70089 Mdot
.29624 .50316 Mdot
.55559 .73618 Mdot
.48219 .66574 Mdot
.35967 .35116 Mdot
.65884 .55914 Mdot
.5487 .57449 Mdot
.50222 .7803 Mdot
.48969 .6004 Mdot
.67783 .53523 Mdot
.64366 .5317 Mdot
.81124 .55175 Mdot
.29269 .51297 Mdot
.47012 .64477 Mdot
.26637 .37176 Mdot
.54135 .61226 Mdot
.50994 .29354 Mdot
.45553 .67001 Mdot
.32286 .39966 Mdot
.57275 .44822 Mdot
.35755 .36536 Mdot
.52673 .65583 Mdot
.68383 .51496 Mdot
.50979 .28036 Mdot
.32876 .27443 Mdot
.52865 .37562 Mdot
.34743 .7757 Mdot
.26738 .50652 Mdot
.29299 .54626 Mdot
.28869 .56444 Mdot
.50936 .24382 Mdot
.47186 .63157 Mdot
.50833 .41206 Mdot
.42984 .60721 Mdot
.50479 .66046 Mdot
.46842 .65291 Mdot
.49054 .35475 Mdot
.52151 .31886 Mdot
.34096 .38424 Mdot
.51326 .63884 Mdot
.49039 .59798 Mdot
.68885 .52464 Mdot
.29385 .53159 Mdot
.37675 .38971 Mdot
.31331 .55975 Mdot
.33946 .40091 Mdot
.82812 .40856 Mdot
.44685 .66064 Mdot
.29883 .541 Mdot
.50843 .26516 Mdot
.71253 .52266 Mdot
.62856 .43549 Mdot
.35807 .41373 Mdot
.35495 .37363 Mdot
.4733 .61305 Mdot
.66179 .51119 Mdot
.65326 .51452 Mdot
.29145 .54652 Mdot
.53544 .28627 Mdot
.51316 .68102 Mdot
.52203 .6393 Mdot
.30106 .28789 Mdot
.37196 .37332 Mdot
.56785 .72987 Mdot
.78706 .5007 Mdot
.47157 .62917 Mdot
.65396 .51189 Mdot
.50183 .64018 Mdot
.47191 .24816 Mdot
.71739 .52619 Mdot
.47406 .59866 Mdot
.42489 .69434 Mdot
.38112 .3979 Mdot
.82001 .60325 Mdot
.54223 .5928 Mdot
.54214 .35293 Mdot
.5346 .62135 Mdot
.83901 .62504 Mdot
.79196 .55961 Mdot
.53675 .5985 Mdot
.49624 .67933 Mdot
.52573 .17078 Mdot
.50742 .58981 Mdot
.61274 .42696 Mdot
.41849 .63661 Mdot
.64863 .51612 Mdot
.43954 .43376 Mdot
.52696 .42337 Mdot
.28428 .53427 Mdot
.33575 .41386 Mdot
.29956 .67631 Mdot
.30056 .56623 Mdot
.69113 .54668 Mdot
.45199 .61867 Mdot
.7659 .54207 Mdot
.35271 .45293 Mdot
.49981 .69023 Mdot
.51053 .29181 Mdot
.52793 .42292 Mdot
.31903 .41183 Mdot
.51467 .31582 Mdot
.49567 .58665 Mdot
.18119 .4489 Mdot
.56524 .32009 Mdot
.82361 .54447 Mdot
.50987 .27515 Mdot
.52935 .31037 Mdot
.56306 .47493 Mdot
.28424 .53519 Mdot
.40065 .21976 Mdot
.58316 .58812 Mdot
.50005 .30727 Mdot
.35787 .65458 Mdot
.35297 .35526 Mdot
.55973 .40205 Mdot
.6837 .49117 Mdot
.44665 .66173 Mdot
.48088 .63103 Mdot
.52937 .28227 Mdot
.75947 .50814 Mdot
.40802 .53441 Mdot
.51029 .31826 Mdot
.57086 .65038 Mdot
.56313 .39633 Mdot
.62736 .41361 Mdot
.60638 .423 Mdot
.28159 .54081 Mdot
.21803 .50196 Mdot
.69971 .52069 Mdot
.3169 .50524 Mdot
.59931 .51214 Mdot
.47482 .65059 Mdot
.54151 .29144 Mdot
.60912 .4307 Mdot
.51278 .30851 Mdot
.30675 .54224 Mdot
.30203 .50281 Mdot
.67947 .54182 Mdot
.67826 .55341 Mdot
.62215 .59397 Mdot
.35873 .59459 Mdot
.52264 .59243 Mdot
.77425 .60395 Mdot
.71761 .52959 Mdot
.61822 .77619 Mdot
.28675 .54038 Mdot
.29693 .5199 Mdot
.63965 .66229 Mdot
.52312 .61807 Mdot
.44317 .35227 Mdot
.48821 .66864 Mdot
.34666 .68216 Mdot
.52499 .58416 Mdot
.34137 .37306 Mdot
.54338 .63051 Mdot
.62558 .33348 Mdot
.50128 .59978 Mdot
.4708 .65993 Mdot
.35427 .41123 Mdot
.54561 .66119 Mdot
.32241 .39434 Mdot
.51909 .66739 Mdot
.32358 .56305 Mdot
.33551 .41081 Mdot
.32203 .57725 Mdot
.45443 .40226 Mdot
.6163 .41719 Mdot
.28455 .55418 Mdot
.29762 .55448 Mdot
.2638 .60093 Mdot
.68813 .55431 Mdot
.39723 .65147 Mdot
.47273 .63434 Mdot
.32777 .35851 Mdot
.52276 .26767 Mdot
.48795 .60142 Mdot
.47455 .57908 Mdot
.54315 .5923 Mdot
.67922 .53904 Mdot
.31204 .38654 Mdot
.30252 .53662 Mdot
.36141 .42391 Mdot
.31627 .5744 Mdot
.33914 .43946 Mdot
.4868 .56063 Mdot
.41409 .63243 Mdot
.5331 .69414 Mdot
.7501 .6481 Mdot
.46946 .81948 Mdot
.67272 .52956 Mdot
.62781 .42196 Mdot
.29377 .50951 Mdot
.43039 .48656 Mdot
.69702 .51419 Mdot
.3564 .37626 Mdot
.48694 .64326 Mdot
.56798 .65916 Mdot
.58693 .62175 Mdot
.73321 .50939 Mdot
.35018 .57517 Mdot
.3453 .41954 Mdot
.63583 .4241 Mdot
.55979 .44386 Mdot
.66653 .58101 Mdot
.52784 .46474 Mdot
.49879 .64188 Mdot
.29278 .55187 Mdot
.647 .536 Mdot
.4099 .23194 Mdot
.53286 .28837 Mdot
.54592 .44802 Mdot
.49813 .62181 Mdot
.69666 .45247 Mdot
.68311 .51511 Mdot
.30344 .51136 Mdot
.5286 .28192 Mdot
.28743 .5246 Mdot
.60975 .41029 Mdot
.59674 .43547 Mdot
.5337 .64513 Mdot
.49829 .67044 Mdot
.53178 .26914 Mdot
.69775 .5192 Mdot
.30313 .47813 Mdot
.44481 .19614 Mdot
.36181 .41154 Mdot
.52179 .39501 Mdot
.64937 .53876 Mdot
.66981 .44608 Mdot
.36998 .407 Mdot
.51075 .25982 Mdot
.51097 .41553 Mdot
.49173 .28736 Mdot
.47539 .66211 Mdot
.66126 .51777 Mdot
.5194 .32801 Mdot
.31158 .29228 Mdot
.80189 .39568 Mdot
.67838 .48041 Mdot
.51626 .63722 Mdot
.70128 .25767 Mdot
.7175 .3912 Mdot
.70712 .47546 Mdot
.5435 .3057 Mdot
.50799 .63723 Mdot
.48395 .67908 Mdot
.54332 .64179 Mdot
.53393 .30335 Mdot
.53514 .36454 Mdot
.36264 .37618 Mdot
.48336 .65096 Mdot
.30612 .55662 Mdot
.32543 .39364 Mdot
.34647 .44713 Mdot
.32934 .42815 Mdot
.71861 .52778 Mdot
.4446 .63745 Mdot
.57903 .52482 Mdot
.8427 .56082 Mdot
.5258 .31334 Mdot
.61622 .41751 Mdot
.46128 .63761 Mdot
.30296 .73012 Mdot
.71401 .52818 Mdot
.36235 .40597 Mdot
.49498 .62866 Mdot
.24237 .38256 Mdot
.61518 .43877 Mdot
.3481 .40859 Mdot
.70114 .54653 Mdot
.70378 .47466 Mdot
.48805 .6138 Mdot
.53279 .61797 Mdot
.70641 .53329 Mdot
.69402 .39483 Mdot
.56283 .43448 Mdot
.50304 .64283 Mdot
.51897 .31592 Mdot
.14 .57683 Mdot
.47975 .59004 Mdot
.74658 .53127 Mdot
.62389 .4073 Mdot
.78359 .47226 Mdot
.57493 .71578 Mdot
.45915 .57656 Mdot
.63757 .21035 Mdot
.28403 .68265 Mdot
.72939 .27569 Mdot
.34655 .70506 Mdot
.51909 .2178 Mdot
.83591 .4607 Mdot
.48581 .3224 Mdot
.60097 .74557 Mdot
.43455 .17435 Mdot
.69454 .42159 Mdot
.20655 .43296 Mdot
.35372 .27465 Mdot
.24307 .36161 Mdot
.58175 .81988 Mdot
.34079 .44181 Mdot
.37301 .71572 Mdot
.52891 .66653 Mdot
.69641 .38248 Mdot
.5659 .75021 Mdot
.43075 .8206 Mdot
.70232 .26406 Mdot
.25971 .3748 Mdot
.5968 .15783 Mdot
.71191 .28386 Mdot
.68506 .59385 Mdot
.45233 .75416 Mdot
.22585 .51687 Mdot
.39654 .49868 Mdot
.30067 .68569 Mdot
.52816 .72918 Mdot
.62566 .31821 Mdot
.49333 .33878 Mdot
.71581 .61045 Mdot
.17044 .62144 Mdot
.3421 .42819 Mdot
.65823 .55935 Mdot
.38934 .22185 Mdot
.73879 .57188 Mdot
.53998 .24203 Mdot
.63761 .21016 Mdot
.78599 .41654 Mdot
.59125 .75152 Mdot
.58443 .50248 Mdot
.64611 .70036 Mdot
.23509 .61177 Mdot
.43603 .75652 Mdot
.73467 .54034 Mdot
.35386 .30324 Mdot
.39955 .49879 Mdot
.2369 .54908 Mdot
.59719 .76332 Mdot
.285 .56273 Mdot
.31506 .5834 Mdot
.70773 .54146 Mdot
.61889 .61968 Mdot
.63815 .43539 Mdot
.60177 .51763 Mdot
.38327 .38936 Mdot
.46181 .26067 Mdot
.66682 .37884 Mdot
.71904 .41366 Mdot
.78348 .66865 Mdot
.67276 .198 Mdot
.30953 .6274 Mdot
.42991 .25221 Mdot
.56033 .28257 Mdot
.28359 .66475 Mdot
.56077 .50974 Mdot
.34043 .61781 Mdot
.38967 .64455 Mdot
.52061 .13315 Mdot
.75033 .41383 Mdot
.57966 .14462 Mdot
.68903 .57156 Mdot
.556 .59725 Mdot
.4444 .25161 Mdot
.72149 .70837 Mdot
.27068 .58127 Mdot
.67445 .20344 Mdot
.31929 .49977 Mdot
.66328 .4908 Mdot
.69414 .4243 Mdot
.56313 .76504 Mdot
.3065 .47374 Mdot
.27426 .53825 Mdot
.54887 .57582 Mdot
.50683 .11812 Mdot
.62458 .20268 Mdot
.80476 .52494 Mdot
.77642 .41311 Mdot
.36058 .3439 Mdot
.35297 .44705 Mdot
.51738 .33113 Mdot
.81426 .42314 Mdot
.67239 .51505 Mdot
.84549 .56381 Mdot
.80409 .41595 Mdot
.47459 .54286 Mdot
.49293 .11975 Mdot
.65818 .79542 Mdot
.59734 .69167 Mdot
.40628 .78079 Mdot
.21012 .38013 Mdot
.55157 .50017 Mdot
.66209 .43814 Mdot
.32542 .35014 Mdot
.79995 .46322 Mdot
.81021 .38838 Mdot
.36559 .66046 Mdot
.54156 .21615 Mdot
.6024 .52503 Mdot
.37504 .48284 Mdot
.6558 .48618 Mdot
.19726 .46176 Mdot
.37274 .57843 Mdot
.59189 .15132 Mdot
.54971 .74 Mdot
.15018 .51412 Mdot
.33507 .6926 Mdot
.57565 .79268 Mdot
.63209 .22313 Mdot
.39344 .38246 Mdot
.3894 .57852 Mdot
.74051 .4336 Mdot
.44262 .60582 Mdot
.51509 .49853 Mdot
.40142 .60217 Mdot
.33633 .50187 Mdot
.56252 .46386 Mdot
.7318 .35085 Mdot
.32168 .67661 Mdot
.4955 .19986 Mdot
.45633 .75112 Mdot
.69417 .50266 Mdot
.32944 .6118 Mdot
.33286 .65229 Mdot
.76624 .39752 Mdot
.43705 .53656 Mdot
.81201 .50712 Mdot
.42818 .5335 Mdot
.43969 .59446 Mdot
.60792 .74089 Mdot
.51937 .72978 Mdot
.34765 .6434 Mdot
.53951 .59197 Mdot
.79443 .6476 Mdot
.78542 .43592 Mdot
.73626 .63996 Mdot
.30346 .65996 Mdot
.74769 .64421 Mdot
.80425 .46439 Mdot
.44965 .24384 Mdot
.66269 .42834 Mdot
.74524 .49165 Mdot
.51247 .12102 Mdot
.33308 .38471 Mdot
.35843 .64028 Mdot
.52309 .35638 Mdot
.31708 .28872 Mdot
.40925 .19379 Mdot
.41688 .53269 Mdot
.81143 .45861 Mdot
.71056 .42123 Mdot
.33839 .45855 Mdot
.60992 .29087 Mdot
.47428 .33784 Mdot
.76005 .61032 Mdot
.54028 .58378 Mdot
.40008 .58687 Mdot
.32376 .52769 Mdot
.67944 .73452 Mdot
.44692 .22402 Mdot
.29348 .43543 Mdot
.48281 .56611 Mdot
.28832 .37776 Mdot
.63257 .42974 Mdot
.54044 .42147 Mdot
.82835 .39773 Mdot
.42689 .58574 Mdot
.63391 .80422 Mdot
.71131 .40182 Mdot
.51812 .41391 Mdot
.24848 .5759 Mdot
.77164 .49733 Mdot
.55974 .13458 Mdot
.81696 .45103 Mdot
.7105 .36957 Mdot
.69279 .24957 Mdot
.70385 .78968 Mdot
.36581 .20772 Mdot
.71302 .73169 Mdot
.52201 .35635 Mdot
.50601 .91171 Mdot
.36643 .41672 Mdot
.43852 .78641 Mdot
.71824 .70956 Mdot
.24437 .3979 Mdot
.74341 .56856 Mdot
.51538 .74203 Mdot
.25831 .54239 Mdot
.63312 .54805 Mdot
.51079 .56703 Mdot
.72195 .24549 Mdot
.52894 .1296 Mdot
.70831 .23188 Mdot
.58818 .42388 Mdot
.73782 .27518 Mdot
.51451 .15511 Mdot
.35742 .78328 Mdot
.4189 .20173 Mdot
.45746 .67167 Mdot
.36905 .62949 Mdot
.68048 .77772 Mdot
.28422 .49711 Mdot
.58865 .52376 Mdot
.73847 .53161 Mdot
.50207 .14328 Mdot
.82896 .39486 Mdot
.66023 .65847 Mdot
.64651 .60431 Mdot
.43323 .41837 Mdot
.35171 .6173 Mdot
.75815 .56006 Mdot
.63139 .30347 Mdot
.77384 .37947 Mdot
.5029 .15587 Mdot
.33084 .66128 Mdot
.35253 .28121 Mdot
.70119 .35704 Mdot
.6967 .75796 Mdot
.63066 .21844 Mdot
.38266 .22209 Mdot
.43886 .54887 Mdot
.61383 .54804 Mdot
.40897 .53534 Mdot
.62024 .30922 Mdot
.43781 .31138 Mdot
.29233 .63445 Mdot
.31839 .38953 Mdot
.3655 .64995 Mdot
.48188 .4625 Mdot
.41645 .20204 Mdot
.27822 .63941 Mdot
.36962 .67135 Mdot
.72622 .3636 Mdot
.72429 .253 Mdot
.71072 .40464 Mdot
.19002 .40218 Mdot
.66123 .25654 Mdot
.41146 .58438 Mdot
.55673 .64173 Mdot
.80795 .46004 Mdot
.78067 .29709 Mdot
.81248 .45698 Mdot
.70685 .45819 Mdot
.27597 .35638 Mdot
.49417 .27036 Mdot
.2712 .64328 Mdot
.303 .4395 Mdot
.78064 .37832 Mdot
.45613 .4781 Mdot
.50393 .2564 Mdot
.66471 .3866 Mdot
.62654 .59223 Mdot
.29858 .70761 Mdot
.69287 .6155 Mdot
.44572 .67259 Mdot
.60878 .65093 Mdot
.63685 .52165 Mdot
.69935 .45615 Mdot
.34513 .62236 Mdot
.33033 .39056 Mdot
.28775 .29368 Mdot
.75235 .53244 Mdot
.53659 .57657 Mdot
.43161 .2828 Mdot
.65504 .48545 Mdot
.74397 .66145 Mdot
.32383 .44483 Mdot
.83116 .44015 Mdot
.77332 .67448 Mdot
.76209 .55663 Mdot
.31785 .61779 Mdot
.29846 .29695 Mdot
.55382 .42212 Mdot
.5289 .3506 Mdot
.7021 .26751 Mdot
.4651 .40504 Mdot
.32863 .61903 Mdot
.60154 .66431 Mdot
.44434 .20458 Mdot
.42746 .6192 Mdot
.80127 .53961 Mdot
.34169 .76672 Mdot
.54116 .41115 Mdot
.74321 .55965 Mdot
.68565 .56369 Mdot
.50944 .8385 Mdot
.63793 .33205 Mdot
.54421 .5367 Mdot
.66253 .23414 Mdot
.50133 .32628 Mdot
.71085 .51367 Mdot
.37613 .67649 Mdot
.22163 .45496 Mdot
.60205 .6286 Mdot
.4437 .30661 Mdot
.70178 .5896 Mdot
.46508 .37554 Mdot
.68048 .2408 Mdot
.60172 .18035 Mdot
.14448 .56929 Mdot
.65987 .56816 Mdot
.41541 .23835 Mdot
.40876 .24122 Mdot
.73421 .53357 Mdot
.74057 .51803 Mdot
.53989 .73621 Mdot
.76966 .30469 Mdot
.44111 .46966 Mdot
.62202 .2904 Mdot
.51173 .41283 Mdot
.20688 .44333 Mdot
.4246 .21189 Mdot
.29038 .6608 Mdot
.59559 .20609 Mdot
.66345 .6128 Mdot
.24329 .30638 Mdot
.50955 .70642 Mdot
.44381 .78838 Mdot
.27088 .64318 Mdot
.42199 .72822 Mdot
.6029 .76063 Mdot
.7472 .34187 Mdot
.53681 .60402 Mdot
.69484 .21273 Mdot
.75004 .39048 Mdot
.50584 .503 Mdot
.38061 .35475 Mdot
.51422 .60159 Mdot
.44542 .64169 Mdot
.77942 .53709 Mdot
.78481 .48681 Mdot
.31188 .23479 Mdot
.34068 .69001 Mdot
.42988 .56441 Mdot
.59516 .68357 Mdot
.63484 .80355 Mdot
.44893 .26117 Mdot
.75543 .31767 Mdot
.47954 .47306 Mdot
.69858 .76316 Mdot
.60744 .25147 Mdot
.60989 .31236 Mdot
.65365 .24588 Mdot
.52111 .15581 Mdot
.52652 .55518 Mdot
.76434 .46474 Mdot
.39064 .22849 Mdot
.46203 .63934 Mdot
.71841 .44347 Mdot
.66472 .24085 Mdot
.17825 .54726 Mdot
.5515 .51601 Mdot
.77304 .28237 Mdot
.43262 .68356 Mdot
.75924 .45034 Mdot
.42095 .17838 Mdot
.16697 .3803 Mdot
.61677 .32641 Mdot
.60098 .15652 Mdot
.60421 .29695 Mdot
.64855 .22401 Mdot
.51728 .3354 Mdot
.45347 .44007 Mdot
.77242 .62399 Mdot
.77511 .31128 Mdot
.23856 .47145 Mdot
.51099 .21009 Mdot
.78783 .58903 Mdot
.76645 .29419 Mdot
.42305 .6852 Mdot
.51073 .83375 Mdot
.38643 .41304 Mdot
.70641 .76734 Mdot
.74492 .70284 Mdot
.68442 .58513 Mdot
.35817 .66404 Mdot
.50635 .82564 Mdot
.40711 .80748 Mdot
.7387 .70455 Mdot
.395 .69667 Mdot
.77874 .49917 Mdot
.30923 .61635 Mdot
.78768 .38365 Mdot
.56622 .82296 Mdot
.42197 .22222 Mdot
.62544 .38936 Mdot
.59268 .42278 Mdot
.79138 .49443 Mdot
.70436 .32725 Mdot
.43771 .27057 Mdot
.57509 .41675 Mdot
.67624 .59147 Mdot
.16987 .67701 Mdot
.58929 .26795 Mdot
.58166 .66934 Mdot
.54992 .13884 Mdot
.77159 .38207 Mdot
.44373 .47991 Mdot
.58876 .76998 Mdot
.3036 .71925 Mdot
.38293 .44419 Mdot
.48199 .66796 Mdot
.76009 .28809 Mdot
.35611 .46171 Mdot
.62511 .17675 Mdot
.82848 .54394 Mdot
.63028 .62729 Mdot
.48256 .55684 Mdot
.31408 .35988 Mdot
.4525 .76563 Mdot
.39726 .7076 Mdot
.55035 .14769 Mdot
.44723 .78708 Mdot
.5044 .39493 Mdot
.45424 .36789 Mdot
.45594 .3362 Mdot
.53043 .54331 Mdot
.68397 .77779 Mdot
.77665 .48831 Mdot
.31211 .68095 Mdot
.69266 .35915 Mdot
.35348 .63948 Mdot
.5743 .71837 Mdot
.26778 .63313 Mdot
.46981 .51348 Mdot
.25158 .54766 Mdot
.36255 .36243 Mdot
.51172 .17886 Mdot
.70713 .28794 Mdot
.80029 .63053 Mdot
.19418 .39794 Mdot
.74061 .43687 Mdot
.3859 .72594 Mdot
.46999 .20942 Mdot
.54021 .50866 Mdot
.23721 .49237 Mdot
.32227 .71204 Mdot
.55571 .73165 Mdot
.7533 .3313 Mdot
.46184 .74713 Mdot
.81392 .39024 Mdot
.2924 .63843 Mdot
.47281 .18122 Mdot
.43 .42552 Mdot
.69602 .71254 Mdot
.61502 .69557 Mdot
.22053 .36173 Mdot
.53854 .41219 Mdot
.50764 .11928 Mdot
.70824 .50348 Mdot
.66776 .1951 Mdot
.50844 .27421 Mdot
.17158 .59255 Mdot
.7638 .35587 Mdot
.50826 .48185 Mdot
.49899 .43852 Mdot
.8051 .54798 Mdot
.70413 .40471 Mdot
.71988 .40525 Mdot
.41117 .53737 Mdot
.32113 .42314 Mdot
.51149 .38423 Mdot
.62655 .2896 Mdot
.51993 .18772 Mdot
.50063 .68295 Mdot
.32559 .46434 Mdot
.42219 .74038 Mdot
.54349 .34356 Mdot
.78968 .44518 Mdot
.73481 .31594 Mdot
.54585 .71223 Mdot
.35127 .61347 Mdot
.51554 .14926 Mdot
.78753 .40281 Mdot
.40937 .52533 Mdot
.40073 .62126 Mdot
.56345 .27969 Mdot
.32554 .24456 Mdot
.60011 .19408 Mdot
.4568 .35263 Mdot
.56439 .42409 Mdot
.31138 .62981 Mdot
.77887 .27316 Mdot
.52452 .13126 Mdot
.21382 .34881 Mdot
.51068 .41 Mdot
.6601 .57445 Mdot
.31397 .73209 Mdot
.47597 .18165 Mdot
.71977 .75767 Mdot
.72782 .38027 Mdot
.35689 .64458 Mdot
.17641 .52367 Mdot
.47479 .81202 Mdot
.48718 .39424 Mdot
.61591 .69603 Mdot
.74566 .67041 Mdot
.54337 .25371 Mdot
.38272 .44915 Mdot
.48361 .4165 Mdot
.54614 .24351 Mdot
.77869 .49746 Mdot
.70346 .40781 Mdot
.47047 .18052 Mdot
.45983 .79267 Mdot
.4008 .62538 Mdot
.5094 .20127 Mdot
.65722 .48918 Mdot
.40627 .23717 Mdot
.3094 .27733 Mdot
.48982 .4062 Mdot
.35784 .43119 Mdot
.57931 .64939 Mdot
.55257 .39255 Mdot
.6035 .27862 Mdot
.17661 .48383 Mdot
.327 .55154 Mdot
.72563 .55578 Mdot
.48876 .81482 Mdot
.67061 .57066 Mdot
.81852 .33911 Mdot
.63352 .30246 Mdot
.6026 .66849 Mdot
.59417 .23748 Mdot
.36794 .28635 Mdot
.16975 .4331 Mdot
.67046 .59532 Mdot
.28096 .59386 Mdot
.70058 .56998 Mdot
.63793 .52794 Mdot
.6029 .23148 Mdot
.64204 .44426 Mdot
.6311 .60818 Mdot
.60581 .81337 Mdot
.29605 .29911 Mdot
.69318 .56655 Mdot
.45238 .37489 Mdot
.69008 .47718 Mdot
.83062 .40392 Mdot
.35525 .43005 Mdot
.51962 .12178 Mdot
.41126 .61624 Mdot
.31633 .24794 Mdot
.80074 .45301 Mdot
.57539 .45453 Mdot
.511 .4036 Mdot
.3217 .29646 Mdot
.43666 .60119 Mdot
.43674 .55994 Mdot
.68796 .55287 Mdot
.42978 .19343 Mdot
.29749 .52447 Mdot
.34929 .58689 Mdot
.51487 .35226 Mdot
.60944 .79089 Mdot
.72227 .74288 Mdot
.63643 .52557 Mdot
.43839 .38414 Mdot
.40007 .25189 Mdot
.42404 .69539 Mdot
.42073 .7355 Mdot
.51887 .17279 Mdot
.64887 .60007 Mdot
.70521 .50273 Mdot
.21202 .35699 Mdot
.37264 .56716 Mdot
.83091 .46165 Mdot
.50406 .7164 Mdot
.44473 .76026 Mdot
.43393 .73716 Mdot
.79145 .52379 Mdot
.57386 .7163 Mdot
.77099 .34345 Mdot
.33294 .61373 Mdot
.38283 .53984 Mdot
.37058 .66934 Mdot
.54694 .71244 Mdot
.47171 .36534 Mdot
.68095 .78604 Mdot
.17475 .51678 Mdot
.63937 .70989 Mdot
.56734 .51631 Mdot
.74218 .56519 Mdot
.64283 .79998 Mdot
.73384 .54843 Mdot
.33397 .52677 Mdot
.7236 .61278 Mdot
.7636 .35789 Mdot
.81367 .41656 Mdot
.76547 .39749 Mdot
.45297 .76781 Mdot
.45817 .33764 Mdot
.35954 .75263 Mdot
.40251 .65117 Mdot
.51897 .47461 Mdot
.46074 .58454 Mdot
.45041 .55832 Mdot
.44892 .491 Mdot
.79912 .56254 Mdot
.51196 .54781 Mdot
.76751 .30747 Mdot
.82621 .457 Mdot
.71364 .25389 Mdot
.43589 .30923 Mdot
.6552 .56177 Mdot
.54814 .13313 Mdot
.49618 .79173 Mdot
.7888 .39004 Mdot
.73383 .71517 Mdot
.52398 .84214 Mdot
.43102 .17248 Mdot
.73966 .35087 Mdot
.60773 .55809 Mdot
.82174 .60049 Mdot
.75172 .41263 Mdot
.51549 .83199 Mdot
.55095 .73353 Mdot
.79627 .452 Mdot
.49339 .12541 Mdot
.66862 .76313 Mdot
.72221 .4123 Mdot
.6095 .70143 Mdot
.57338 .69919 Mdot
.57968 .81311 Mdot
.43972 .63039 Mdot
.35058 .44248 Mdot
.22899 .39902 Mdot
.35416 .65642 Mdot
.56023 .69791 Mdot
.56547 .81633 Mdot
.39887 .71168 Mdot
.37739 .72216 Mdot
.314 .29725 Mdot
.43456 .17328 Mdot
.59393 .67208 Mdot
.57335 .64831 Mdot
.74158 .53665 Mdot
.2943 .56638 Mdot
.33375 .70467 Mdot
.51037 .60927 Mdot
.52872 .43647 Mdot
.55683 .56915 Mdot
.73616 .25413 Mdot
.21758 .43663 Mdot
.48875 .26076 Mdot
.665 .56639 Mdot
.78948 .49956 Mdot
.4691 .23848 Mdot
.69362 .42177 Mdot
.55148 .81408 Mdot
.61239 .59822 Mdot
.66705 .22861 Mdot
.72456 .42279 Mdot
.31151 .65094 Mdot
.22773 .5892 Mdot
.53877 .32412 Mdot
.75712 .65524 Mdot
.54367 .15111 Mdot
.7343 .44536 Mdot
.66616 .48899 Mdot
.69688 .34575 Mdot
.47203 .36863 Mdot
.74711 .46252 Mdot
.70696 .40033 Mdot
.43872 .21839 Mdot
.63218 .64735 Mdot
.59681 .18188 Mdot
.30283 .38925 Mdot
.33878 .6663 Mdot
.65636 .33487 Mdot
.57833 .81624 Mdot
.42833 .69888 Mdot
.79693 .36249 Mdot
.50716 .47522 Mdot
.35183 .54685 Mdot
.53342 .63506 Mdot
.49518 .78438 Mdot
.78725 .52632 Mdot
.68381 .35206 Mdot
.46216 .54109 Mdot
.63219 .51855 Mdot
.78153 .66812 Mdot
.38214 .36073 Mdot
.38832 .42287 Mdot
.41903 .77973 Mdot
.69885 .46248 Mdot
.34548 .50891 Mdot
.61025 .37815 Mdot
.4148 .6411 Mdot
.22614 .5635 Mdot
.44824 .329 Mdot
.76457 .64467 Mdot
.7031 .74054 Mdot
.51688 .17737 Mdot
.44387 .29334 Mdot
.78861 .66446 Mdot
.76774 .65516 Mdot
.79291 .47497 Mdot
.47942 .80598 Mdot
.59441 .54477 Mdot
.53247 .58196 Mdot
.33393 .52605 Mdot
.72699 .52062 Mdot
.53127 .18194 Mdot
.40501 .57184 Mdot
.34609 .54784 Mdot
.49995 .49345 Mdot
.44187 .2545 Mdot
.40993 .44413 Mdot
.78491 .44005 Mdot
.8218 .6012 Mdot
.34414 .62161 Mdot
.52733 .34056 Mdot
.60756 .28644 Mdot
.5414 .51776 Mdot
.78099 .3332 Mdot
.43873 .50243 Mdot
.76793 .54893 Mdot
.61474 .39594 Mdot
.72866 .66991 Mdot
.81974 .49945 Mdot
.36005 .58589 Mdot
.52803 .47027 Mdot
.7586 .54017 Mdot
.58996 .51946 Mdot
.63044 .43538 Mdot
.24192 .41245 Mdot
.48604 .79387 Mdot
.53967 .22018 Mdot
.5438 .36507 Mdot
.42608 .66831 Mdot
.31788 .73495 Mdot
.58153 .18246 Mdot
.43126 .48725 Mdot
.49848 .4777 Mdot
.38645 .2319 Mdot
.35846 .46235 Mdot
.1399 .59553 Mdot
.71334 .22902 Mdot
.53299 .63309 Mdot
.48542 .43693 Mdot
.35472 .58259 Mdot
.31722 .37871 Mdot
.69096 .61205 Mdot
.52672 .1756 Mdot
.51308 .32464 Mdot
.29653 .31852 Mdot
.60467 .37755 Mdot
.80379 .55301 Mdot
.24135 .3206 Mdot
.51219 .25185 Mdot
.81604 .33316 Mdot
.72261 .38069 Mdot
.76162 .49533 Mdot
.14304 .62108 Mdot
.79417 .55287 Mdot
.39412 .65008 Mdot
.28564 .34144 Mdot
.738 .26104 Mdot
.51499 .40455 Mdot
.27581 .36471 Mdot
.68352 .7524 Mdot
.33976 .61975 Mdot
.3398 .68198 Mdot
.63309 .38695 Mdot
.79795 .60501 Mdot
.48343 .8423 Mdot
.36972 .28493 Mdot
.17711 .40729 Mdot
.63138 .61547 Mdot
.62269 .18651 Mdot
.61754 .32425 Mdot
.18331 .53955 Mdot
.81223 .42021 Mdot
.37584 .65547 Mdot
.57915 .80474 Mdot
.22168 .47998 Mdot
.30054 .59363 Mdot
.31104 .73613 Mdot
.58508 .4262 Mdot
.66226 .59984 Mdot
.33378 .30225 Mdot
.48548 .53503 Mdot
.36759 .65963 Mdot
.72978 .68325 Mdot
.52568 .47012 Mdot
.57173 .15882 Mdot
.53271 .80736 Mdot
.32165 .62433 Mdot
.35795 .24745 Mdot
.31852 .58331 Mdot
.54625 .18659 Mdot
.47434 .25184 Mdot
.39413 .66531 Mdot
.38886 .17981 Mdot
.5916 .15159 Mdot
.59431 .5423 Mdot
.4481 .64892 Mdot
.83613 .46443 Mdot
.38041 .49363 Mdot
.71335 .73 Mdot
.6657 .37014 Mdot
.34527 .69523 Mdot
.54268 .55677 Mdot
.50663 .57556 Mdot
.38241 .77018 Mdot
.6142 .56548 Mdot
.73496 .67929 Mdot
.26863 .30065 Mdot
.32217 .61984 Mdot
.54307 .79972 Mdot
.24987 .30115 Mdot
.50421 .71765 Mdot
.6477 .51553 Mdot
.73684 .25789 Mdot
.74737 .58813 Mdot
.39785 .60577 Mdot
.60906 .67475 Mdot
.42545 .51092 Mdot
.2546 .49393 Mdot
.40172 .62757 Mdot
.55224 .42138 Mdot
.35647 .66478 Mdot
.48252 .18645 Mdot
.77789 .61256 Mdot
.50064 .11454 Mdot
.81328 .46257 Mdot
.67866 .57062 Mdot
.69149 .74146 Mdot
.4843 .40487 Mdot
.70084 .24412 Mdot
.3379 .29095 Mdot
.30193 .2908 Mdot
.45505 .82897 Mdot
.31597 .59235 Mdot
.5486 .63821 Mdot
.58793 .42262 Mdot
.81539 .4062 Mdot
.47111 .83025 Mdot
.81234 .38871 Mdot
.49754 .55194 Mdot
.55826 .6273 Mdot
.14586 .41131 Mdot
.66241 .23081 Mdot
.44128 .58257 Mdot
.56653 .54488 Mdot
.53989 .54012 Mdot
.52378 .66773 Mdot
.6389 .44976 Mdot
.29952 .6935 Mdot
.35003 .68948 Mdot
.76692 .3032 Mdot
.70268 .55867 Mdot
.52063 .40798 Mdot
.53972 .27109 Mdot
.51446 .43115 Mdot
.55096 .70046 Mdot
.50223 .32468 Mdot
.36242 .69939 Mdot
.39301 .4797 Mdot
.28242 .47464 Mdot
.61808 .58697 Mdot
.58255 .43882 Mdot
.64619 .58898 Mdot
.41516 .75432 Mdot
.65917 .44641 Mdot
.40326 .80712 Mdot
.39749 .71112 Mdot
.40091 .68167 Mdot
.77769 .43663 Mdot
.6737 .80709 Mdot
.53055 .40793 Mdot
.66452 .4571 Mdot
.45032 .70257 Mdot
.52534 .76895 Mdot
.62018 .65689 Mdot
.27198 .50454 Mdot
.63881 .42468 Mdot
.48551 .55217 Mdot
.76191 .55347 Mdot
.4888 .29814 Mdot
.77695 .27713 Mdot
.53176 .57622 Mdot
.67245 .62438 Mdot
.78214 .34886 Mdot
.41226 .22916 Mdot
.55089 .73089 Mdot
.46504 .58383 Mdot
.3907 .52553 Mdot
.38927 .48244 Mdot
.73815 .49778 Mdot
.42456 .2082 Mdot
.63467 .20385 Mdot
.42932 .77478 Mdot
.65282 .62419 Mdot
.47277 .64098 Mdot
.32525 .50672 Mdot
.54606 .43075 Mdot
.19103 .51798 Mdot
.35363 .48497 Mdot
.77849 .39832 Mdot
.40233 .74136 Mdot
.34011 .68997 Mdot
.59423 .71955 Mdot
.6446 .18607 Mdot
.55705 .52101 Mdot
.62551 .63199 Mdot
.47307 .50488 Mdot
.71036 .33159 Mdot
.39394 .69778 Mdot
.52965 .2179 Mdot
.48981 .5483 Mdot
.59282 .5572 Mdot
.81517 .35459 Mdot
.68461 .59438 Mdot
.49089 .34545 Mdot
.75465 .33105 Mdot
.49531 .79807 Mdot
.49827 .43976 Mdot
.14956 .64329 Mdot
.33421 .28896 Mdot
.80565 .32064 Mdot
.46036 .19898 Mdot
.44395 .72672 Mdot
.77291 .49479 Mdot
.50499 .56538 Mdot
.3524 .4011 Mdot
.67802 .22661 Mdot
.75288 .54815 Mdot
.59912 .53621 Mdot
.4481 .65952 Mdot
.41357 .48554 Mdot
.74311 .50616 Mdot
.52852 .21123 Mdot
.3286 .43964 Mdot
.41273 .52248 Mdot
.51691 .21273 Mdot
.38832 .4825 Mdot
.5461 .84391 Mdot
.55295 .1472 Mdot
.70657 .27169 Mdot
.4508 .3385 Mdot
.15497 .56982 Mdot
.70704 .57174 Mdot
.73114 .50429 Mdot
.49392 .33475 Mdot
.36617 .75946 Mdot
.74084 .4545 Mdot
.47237 .18615 Mdot
.80271 .50062 Mdot
.42713 .69872 Mdot
.18965 .711 Mdot
.3775 .66798 Mdot
.41429 .50086 Mdot
.72303 .45198 Mdot
.77703 .31908 Mdot
.27658 .33888 Mdot
.82376 .54556 Mdot
.62945 .3196 Mdot
.55551 .70074 Mdot
.35735 .77438 Mdot
.2159 .35473 Mdot
.44909 .36088 Mdot
.17457 .41148 Mdot
.64165 .22873 Mdot
.30042 .68474 Mdot
.67589 .34995 Mdot
.65853 .56846 Mdot
.45191 .55223 Mdot
.63575 .29625 Mdot
.58797 .52517 Mdot
.76045 .50845 Mdot
.63072 .20639 Mdot
.24986 .6393 Mdot
.35322 .23814 Mdot
.70237 .2554 Mdot
.5443 .34446 Mdot
.68588 .58332 Mdot
.39829 .71834 Mdot
.33539 .477 Mdot
.32687 .37461 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Oooooo`;o
0000Z?ooool001cooooo00?o0000ooooooooool0W?ooool2o`000003ooooool0003o000000;o0000
Y_ooool001cooooo00?o0000ooooooooool0W?ooool2o`0000?ooooo1_l0002Rooooo`007?ooool0
0ol0003oooooooooo`2Mooooo`;o00001?ooool4o`000:;ooooo000Looooo`03o`000?oooooooooo
09Wooooo0_l00002ooooo`;o00003_ooool2o`0009[ooooo000Looooo`03o`000?oooooooooo09Wo
oooo0_l0000<ooooo`?o00000oooool2o`0009[ooooo000Looooo`03o`000?oooooooooo0:Gooooo
1Ol00004ooooo`;o00000_ooool2o`0009Gooooo000Looooo`03o`000?oooooooooo0:Gooooo0_l0
0007ooooo`;o00000_ooool3o`0009Cooooo000Looooo`03o`000?oooooooooo0:oooooo0_l00002
ooooo`;o0000U?ooool001cooooo00?o0000ooooooooool0Woooool2o`0000kooooo0_l0002Hoooo
o`007?ooool00ol0003oooooooooo`2Oooooo`;o00003oooool2o`0000Oooooo0_l0002>ooooo`00
7?ooool00ol0003oooooooooo`2Tooooo`;o00002Oooool3o`0000Oooooo0_l0002>ooooo`007?oo
ool2o`000:Gooooo0_l00007ooooo`Co00002oooool2o`0008_ooooo000Looooo`03o`000?oooooo
oooo0:3ooooo0_l000001?oooooo0000o`000?ooool2o`0000Gooooo0_l0000=ooooo`;o000000?o
ooooo`000?l00000R?ooool001cooooo00?o0000ooooooooool0X?ooool2o`000004ooooool0003o
0000ooooo`;o00003_ooool2o`0000Kooooo0ol00028ooooo`007?ooool00ol0003oooooooooo`2f
ooooo`;o00001_ooool2o`0008Wooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0QOooool2o`000003ooooool0003o0000033ooooo0_l0002=ooooo`00
7?ooool00ol0003oooooooooo`21ooooo`;o00000_ooool2o`000003ooooool0003o000001gooooo
0_l0000Aooooo`;o00003Oooool2o`0007kooooo000Looooo`03o`000?oooooooooo087ooooo0_l0
0005ooooo`?o00001_ooool2o`0001;ooooo1?l0000Fooooo`;o00002?ooool2o`0007kooooo000L
ooooo`03o`000?oooooooooo07;ooooo0_l0000Aooooo`;o000000Coooooo`000?l0003o00001_oo
ool2o`00017ooooo1Ol0000Fooooo`;o00001Oooool3o`00083ooooo000Looooo`03o`000?oooooo
oooo07;ooooo0_l00007ooooo`;o00002?ooool2o`0000[ooooo1ol0000:ooooo`Oo00005oooool2
o`0000Cooooo0ol00020ooooo`007?ooool00ol0003oooooooooo`1kooooo`;o00000_ooool2o`00
01;ooooo1_l00009ooooo`Ko000000?oooooo`000?l000003_ooool2o`0000?ooooo1?l00027oooo
o`007?ooool00ol0003oooooooooo`1oooooo`Co00001oooool2o`0000Oooooo0_l000000ooooooo
0000o`000003o`0000[ooooo0_l00002ooooo`;o00000oooool2o`0000Wooooo0_l00003ooooo`;o
00001_ooool2o`0000Kooooo0_l0001iooooo`007?ooool00ol0003oooooooooo`21ooooo`;o0000
0_ooool2o`000003ooooool0003o000000;o00002_ooool2o`000003ooooool0003o000000[ooooo
0_l00007ooooo`;o00005_ooool2o`0000Kooooo0_l0001iooooo`0000Koooooonk^k_lb<S;o0000
oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0POooool2o`0000;o
oooo0_l000000ooooooo0000o`00002oooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5oooo
o`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0Moooool2
o`0000Kooooo2ol00003ooooo`;o0000<?ooool2o`0000gooooo0_l00005ooooo`;o0000L_ooool0
0003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07oooo
o`03o`000?oooooooooo07Oooooo0_l00006ooooo`;o00000_ooool7o`0000?ooooo0_l00003oooo
o`Co00001oooool2o`0000Cooooo0_l0000Jooooo`;o00003Oooool2o`0000Gooooo1?l0001`oooo
o`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Ko
oooo0ol00024ooooo`;o00003?ooool4o`0000Oooooo0_l00003ooooo`Co00008Oooool2o`0000Go
oooo0_l00007ooooo`;o0000L?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
3?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo08Cooooo0_l00007ooooo`;o0000
3oooool2o`0000;ooooo1?l0000Hooooo`;o00001oooool2o`000003ooooool0003o000000;ooooo
0_l00005ooooo`Co0000L?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool03Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07?ooooo0_l0000:ooooo`;o00001Ooo
ool4o`0000?ooooo0_l0000?ooooo`;o00007_ooool2o`0000Wooooo0ol000000ooooooo0000o`00
0006ooooo`Co00001_ooool2o`0006Sooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo
00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo07?ooooo0_l0000:ooooo`;o
00001Oooool4o`0000_ooooo0_l000000ooooooo0000o`000002ooooo`;o00001?ooool2o`0000Co
oooo0_l0000Oooooo`Ko00004?ooool2o`0006Sooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^
kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo073ooooo0_l0000D
ooooo`;o00003Oooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`Go000000?ooooo
o`000?l000006_ooool2o`0000Gooooo0_l0000Aooooo`;o0000JOooool001cooooo00?o0000oooo
ooooool0L?ooool2o`0001Wooooo0_l000001?oooooo0000o`000?ooool2o`0000gooooo1ol00000
0ooooooo0000o`000002ooooo`;o00005_ooool2o`0000?ooooo0_l0000Cooooo`;o0000JOooool0
01cooooo00?o0000ooooooooool0Ioooool2o`0001Gooooo0_l00006ooooo`;o00000oooool2o`00
0004ooooool0003o0000ooooo`;o00002_ooool2o`000003ooooool0003o000000;o000000Cooooo
o`000?l0003ooooo0_l00002ooooo`;o00005oooool2o`0000;ooooo0_l0001nooooo`007?ooool0
0ol0003oooooooooo`1Wooooo`;o00001Oooool2o`0000Wooooo1?l000000ooooooo0000o`000005
ooooo`?o00001Oooool2o`0000kooooo0_l00006ooooo`;o00001Oooool2o`0001Oooooo0_l00003
ooooo`;o00000oooool2o`0007Sooooo000Looooo`03o`000?oooooooooo06kooooo0_l00009oooo
o`Co00000oooool2o`0000?ooooo1?l00004ooooo`;o00005_ooool2o`0002?ooooo0_l00003oooo
o`;o00001oooool2o`0000Cooooo0_l0001Yooooo`007?ooool00ol0003oooooooooo`1Yooooo`;o
00000oooool2o`0000_ooooo0_l00003ooooo`Co00000oooool2o`0004Cooooo0_l00004ooooo`Co
000000?oooooo`000?l000000_l00002ooooo`;o00001?ooool2o`0006?ooooo000Looooo`03o`00
0?oooooooooo06Sooooo0ol00007ooooo`;o00001_ooool3o`0000?ooooo1?l0000Uooooo`;o0000
5Oooool2o`0000_ooooo0_l00004ooooo`Co00000oooool2o`0000Kooooo1?l0001Sooooo`007?oo
ool00ol0003oooooooooo`1Rooooo`;o00001?ooool2o`0000Sooooo0_l00006ooooo`;o00001Ooo
ool3o`0000Cooooo0_l0000Oooooo`;o00005Oooool2o`00017ooooo0_l0000=ooooo`;o0000IOoo
ool001cooooo00?o0000ooooooooool0H_ooool2o`0000_ooooo0_l0000?ooooo`Go00000oooool2
o`0000_ooooo0_l0000;ooooo`?o00001?ooool2o`0001;ooooo1?l0000Booooo`;o00001?ooool2
o`0006kooooo000Looooo`03o`000?oooooooooo06[ooooo0_l00003ooooo`;o00003oooool5o`00
00_ooooo0_l00003ooooo`;o00002oooool3o`0000Cooooo0_l000000ooooooo0000o`00000?oooo
o`Co00003_ooool2o`0000?ooooo0_l00003ooooo`;o0000K_ooool001cooooo00?o0000oooooooo
ool0I_ooool2o`0000;ooooo0_l0000Eooooo`Co00002Oooool4o`0000?ooooo0_l0000;ooooo`;o
00001?ooool2o`0000;ooooo1?l0000Oooooo`Oo00000oooool2o`0000Gooooo1?l00003ooooo`;o
0000H?ooool001cooooo00?o0000ooooooooool0Hoooool2o`000003ooooool0003o000000Wooooo
0_l0000Kooooo`;o00001Oooool3o`0000Wooooo0ol00004ooooo`;o00001?ooool2o`00013ooooo
0_l0000?ooooo`Co00002oooool4o`0000?ooooo0_l0001Pooooo`007?ooool2o`00067ooooo0_l0
00000ooooooo0000o`00000<ooooo`;o00002oooool2o`0000Gooooo0_l000000ooooooo0000o`00
0003ooooo`Co00001Oooool2o`0000Gooooo0_l00002ooooo`Co000000?oooooo`000?l000001?oo
ool2o`0000?ooooo0_l0000=ooooo`Co00005Oooool2o`0000;ooooo0_l00008ooooo`;o0000H?oo
ool001cooooo00?o0000ooooooooool0H?ooool2o`0000Gooooo0_l0000Eooooo`;o00001Oooool2
o`000003ooooool0003o000000;ooooo1Ol00005ooooo`;o00001Oooool2o`0000Cooooo0_l00000
0ooooooo0000o`000004ooooo`?o00000_ooool2o`0000gooooo1?l0000Eooooo`;o00000_ooool2
o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000002ooooo`;o0000G?ooool0
01cooooo00?o0000ooooooooool0I_ooool3o`0002?ooooo0_l0000:ooooo`;o00001_ooool9o`00
00Cooooo0_l0000Aooooo`?o00004?ooool2o`0000_ooooo0_l00002ooooo`;o000000?oooooo`00
0?l000000_ooool3o`0005_ooooo000Looooo`03o`000?oooooooooo06Kooooo0_l000000ooooooo
0000o`00000Booooo`;o00003oooool2o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l0
00000_ooool:o`0001Sooooo0_l0000@ooooo`;o00001Oooool2o`0000Cooooo0_l0000:ooooo`;o
00000_ooool2o`0005Oooooo000Looooo`03o`000?oooooooooo06Wooooo0_l000000ooooooo0000
o`00000?ooooo`;o00003oooool2o`0000;ooooo0ol00006ooooo`;o00000_ooool=o`0002kooooo
0_l00004ooooo`;o000000?oooooo`000?l000001oooool2o`0000;ooooo0_l0001Gooooo`007?oo
ool00ol0003oooooooooo`1/ooooo`;o00006Oooool2o`0000[ooooo0_l00006ooooo`;o00001?oo
ool;o`0003Cooooo0_l000000ooooooo0000o`00000Booooo`;o0000D?ooool001cooooo00?o0000
ooooooooool0I_ooool2o`0001oooooo0_l000000ooooooo0000o`000004ooooo`;o00002_ooool@
o`000003ooooool0003o000000gooooo0_l00003ooooo`;o00006_ooool2o`000004ooooool0003o
0000ooooo`;o00004_ooool2o`00053ooooo000Looooo`03o`000?oooooooooo06Gooooo0ol0000Q
ooooo`?o00001?ooool2o`0000[ooooo4ol0000=ooooo`;o000000?oooooo`000?l000000_l0000J
ooooo`;o00000oooool3o`0000Kooooo0_l0000<ooooo`;o0000C_ooool001cooooo00?o0000oooo
ooooool0IOooool4o`0000Kooooo0_l0000Hooooo`;o00002?ooool2o`0000Kooooo4ol0000Aoooo
o`;o00008Oooool3o`0000Cooooo1Ol0000;ooooo`;o0000C_ooool001cooooo00?o0000oooooooo
ool0HOooool4o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o00008_ooool2o`0000Go
oooo4ol00006ooooo`;o00002oooool2o`00027ooooo0_l00004ooooo`Go00002oooool2o`0004ko
oooo000Looooo`03o`000?oooooooooo05gooooo0_l00002ooooo`Co00001Oooool2o`0000?ooooo
0_l0000Gooooo`?o000000?oooooo`000?l000001oooool2o`0000;ooooo5Ol00004ooooo`?o0000
2oooool2o`0003Gooooo1?l0001>ooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o00000ooo
ool2o`0000Cooooo1?l00003ooooo`;o00000oooool2o`0001;ooooo0ol000000ooooooo0000o`00
0007ooooo`;o00000_ooool2o`000003ooooool0003o0000017o00000oooool2o`0000Wooooo0_l0
000Tooooo`;o000000?oooooo`000?l000003oooool2o`00053ooooo000Looooo`03o`000?oooooo
oooo05gooooo1Ol000000ooooooo0000o`000003ooooo`?o00002Oooool2o`0000;ooooo0_l0000F
ooooo`;o00002_oooolDo`0000gooooo0_l00003ooooo`;o00007_ooool3o`000004ooooool0003o
0000o`0000[ooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`1Mooooo`So00001?ooool3
o`0000Sooooo0_l00002ooooo`;o00005_ooool2o`0000Sooooo5ol0000Aooooo`;o00000_ooool4
o`0001Sooooo0_l00002ooooo`Co00002Oooool2o`0005Cooooo000Looooo`03o`000?oooooooooo
05[ooooo0_l00002ooooo`Go00001_ooool3o`00023ooooo0_l0000<oooooaOo00003?ooool4o`00
0003ooooool0003o000000;ooooo1?l0000Nooooo`;o00000oooool2o`0000Kooooo0_l0001Boooo
o`007?ooool00ol0003oooooooooo`1Jooooo`;o000000?oooooo`000?l000001Ol000000ooooooo
0000o`000002ooooo`;o00007_ooool2o`000003ooooool0003o000000Gooooo0_l00006oooooaGo
00003Oooool5o`0000Wooooo0_l0000Hooooo`;o000000Coooooo`000?l0003o00000_ooool2o`00
00Kooooo0_l00003ooooo`;o0000COooool001cooooo0_l0001>ooooo`;o00001Oooool2o`0000Ko
oooo0ol00003ooooo`;o000000?oooooo`000?l000008_ooool2o`0000Sooooo0_l00003oooooa[o
00003_ooool2o`0000Wooooo0_l0000Dooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o
00000_ooool2o`0000Kooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o0000
00?oooooo`000?l000000_ooool2o`0000Kooooo0_l00005ooooo`;o00001?ooool2o`0000Cooooo
0_l0000WoooooaOo000000?oooooo`000?l000005oooool3o`0001Gooooo0_l00003ooooo`Ko0000
0_ooool2o`0000;ooooo0_l000001?oooooo0000o`000?l00006ooooo`;o0000BOooool001cooooo
00?o0000ooooooooool0Boooool2o`0000?ooooo0ol0000@ooooo`;o00001?ooool2o`0000Cooooo
1?l0000Iooooo`;o00002_ooool2o`0000;ooooo5Ol00003ooooo`;o00004oooool3o`0001[ooooo
1_l00009ooooo`?o00001_ooool2o`0004Wooooo000Looooo`03o`000?oooooooooo04_ooooo0_l0
0004ooooo`;o00007_ooool2o`0001Oooooo1?l00006ooooo`;o000000Coooooo`000?l0003o0000
0_oooolEo`0000?ooooo0_l0000@ooooo`;o00008?ooool5o`0000Sooooo0_l0001Booooo`007?oo
ool00ol0003oooooooooo`2:ooooo`;o00002?ooool2o`000003ooooool0003o000000;ooooo5_l0
000Aooooo`;o00000_ooool2o`00027ooooo1?l0000;ooooo`;o0000Coooool001cooooo00?o0000
ooooooooool0COooool2o`0001kooooo0_l0000Kooooo`;o00002_oooolJo`0001;ooooo0_l0000T
ooooo`;o000000?oooooo`000?l000001_ooool2o`0000?ooooo0_l0001?ooooo`007?ooool00ol0
003oooooooooo`1=ooooo`;o00003_ooool2o`0000kooooo0_l0000Kooooo`;o00002OoooolKo`00
00Cooooo0_l0000Aooooo`Co00006_ooool2o`000004ooooool0003o0000ooooo`;o00001Oooool3
o`0000Cooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o00004?ooool2o`00
02_ooooo0_l00009ooooo`;o00000oooool2o`000003ooooool0003o0000017o00001?ooool2o`00
017ooooo1?l0000Jooooo`;o00001oooool2o`0000;ooooo0_l00005ooooo`;o00001oooool2o`00
04Gooooo000Looooo`03o`000?oooooooooo04_ooooo0_l00014ooooo`;o00000_ooool2o`0000?o
oooo5_l0000Eooooo`;o00006Oooool2o`0000cooooo0_l0000Booooo`;o0000AOooool001cooooo
00?o0000ooooooooool0S_ooool2o`000003ooooool0003o000000Wooooo5?l0000Eooooo`;o0000
6Oooool3o`0006Kooooo000Looooo`03o`000?oooooooooo08kooooo0_l000000ooooooo0000o`00
0008ooooo`oo000000Coooooo`000?l0003o00005oooool2o`0000Cooooo0_l0000Dooooo`Co0000
3?ooool2o`0000Gooooo0_l00003ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0B?oo
ool2o`0004Gooooo0_l00009oooooa?o00000oooool2o`00017ooooo0_l00002ooooo`;o00000_oo
ool2o`0000Cooooo0_l0000@ooooo`;o00003?ooool2o`0000Cooooo1Ol000000ooooooo0000o`00
0006ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0B?ooool2o`0000cooooo0_l0000g
ooooo`Co00000oooool2o`0000;ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o000000?o
ooooo`000?l000001ol00003ooooo`Co00003oooool6o`0000Sooooo0_l0000Tooooo`;o000000?o
ooooo`000?l000002Oooool2o`0004;ooooo000Looooo`03o`000?oooooooooo05Kooooo0_l00000
0ooooooo0000o`00000<ooooo`;o00009_ooool4o`0000?ooooo0_l00002ooooo`Ko000000?ooooo
o`000?l000001Oooool4o`0000Kooooo0_l0000Aooooo`;o00002?ooool2o`0002;ooooo0_l00003
ooooo`;o00003?ooool2o`00047ooooo000Looooo`03o`000?oooooooooo03oooooo0_l0000Eoooo
o`;o000000?oooooo`000?l000002_ooool4o`0000Gooooo1Ol00006ooooo`;o00004Oooool2o`00
00Gooooo0_l00007ooooo`Co000000?oooooo`000?l000000oooool6o`000003ooooool0003o0000
023ooooo0_l0000Fooooo`;o00001_ooool2o`0000;ooooo0_l00002ooooo`?o00003?ooool2o`00
047ooooo000Looooo`03o`000?oooooooooo03oooooo0_l0000Tooooo`Ko00000oooool5o`0000Ko
oooo0_l0000Aooooo`;o00001?ooool3o`0000Oooooo0_l00003ooooo`?o00000_ooool4o`0000?o
oooo0_l0000Kooooo`;o00000oooool2o`0000kooooo0_l00006ooooo`;o00001_ooool2o`0000Go
oooo0ol0000>ooooo`;o0000@?ooool001cooooo0_l00013ooooo`;o000000?oooooo`000?l00000
0oooool2o`0001[ooooo0_l000001?oooooo0000o`000?ooool4o`000003ooooool0003o000001oo
oooo0_l00008ooooo`;o00001?ooool2o`0000Cooooo0_l00008ooooo`;o00005_ooool2o`0000So
oooo0ol000000ooooooo0000o`000005ooooo`;o00002Oooool4o`0000Sooooo0_l00002ooooo`;o
00002oooool2o`00043ooooo000Looooo`03o`000?oooooooooo04;ooooo0_l000000ooooooo0000
o`000003ooooo`;o00006_ooool2o`0000Cooooo1?l000000ooooooo0000o`00000Iooooo`;o0000
0oooool2o`00013ooooo0_l00003ooooo`;o00000_ooool2o`0000Cooooo0ol0000Oooooo`?o0000
00?oooooo`000?l000000_l0000>ooooo`Co00003?ooool4o`0004_ooooo000Looooo`03o`000?oo
oooooooo047ooooo0ol0000Booooo`;o00004?ooool5o`000003ooooool0003o000000Go00000ooo
ool2o`0001;ooooo0_l00003ooooo`;o00002Oooool2o`0000?ooooo1?l000000ooooooo0000o`00
0004ooooo`;o00001Oooool2o`0002Cooooo0ol00004ooooo`;o00004_ooool2o`0000Kooooo0_l0
0007ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0@Oooool3o`0001;ooooo0_l0000:
ooooo`;o00000oooool:o`000004ooooool0003o0000o`0000?ooooo0_l0000Rooooo`;o00000ooo
ool4o`000004ooooool0003o0000ooooo`;o00001Oooool2o`0002Oooooo0_l00002ooooo`;o0000
00?oooooo`000?l000003Oooool2o`0000?ooooo0_l0000?ooooo`;o0000@_ooool001cooooo00?o
0000ooooooooool0A?ooool2o`0000Gooooo0_l0000Eooooo`Co000000Goooooo`000?l0003o0000
ooooo`0:o`0000?ooooo0_l0000Dooooo`;o00003Oooool3o`0000Kooooo0_l000000ooooooo0000
o`000005ooooo`;o0000:oooool2o`00013ooooo0_l00003ooooo`;o00001_ooool2o`000003oooo
ool0003o000004Sooooo000Looooo`03o`000?oooooooooo04Cooooo0_l00005ooooo`;o00002Ooo
ool2o`0000cooooo0_l000000ooooooo0000o`00000=o`0000;ooooo0_l0000Dooooo`;o00001Ooo
ool2o`0000Kooooo0ol00006ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0003Cooooo
0_l00003ooooo`;o00003Oooool2o`0000?ooooo0_l000000ooooooo0000o`000018ooooo`007?oo
ool00ol0003oooooooooo`1Fooooo`;o00002ooooolCo`0001Oooooo0_l000000ooooooo0000o`00
0003ooooo`?o00003Oooool3o`000005ooooool0003o0000o`000?ooool00_l0000Uooooo`;o0000
3Oooool2o`0000?ooooo0_l0000=ooooo`;o00001?ooool2o`0004[ooooo000Looooo`03o`000?oo
oooooooo05?ooooo0_l00005ooooo`;o00001ooooolDo`0001Kooooo0_l000000ooooooo0000o`00
0004ooooo`;o00003Oooool3o`0002cooooo0ol0000<ooooo`;o00006?ooool2o`0004[ooooo000L
ooooo`03o`000?oooooooooo03Cooooo0_l0000Iooooo`So00000oooool2o`0000Wooooo4_l0000F
ooooo`Co00000_ooool4o`0000Oooooo0_l00008ooooo`;o0000:_ooool3o`0000cooooo0_l0000A
ooooo`;o0000DOooool001cooooo00?o0000ooooooooool0=?ooool2o`0001;ooooo0ol00004oooo
o`Co00000_ooool2o`0000?ooooo0ol00003ooooo`;o000000?oooooo`000?l000004ol0000Foooo
o`?o00000_ooool6o`0000Gooooo0ol00007ooooo`;o00002_ooool2o`000004ooooool0003o0000
ooooo`;o00001Oooool3o`0003;ooooo0_l00002ooooo`;o0000COooool001cooooo00?o0000oooo
ooooool0<oooool2o`0000cooooo0_l00005ooooo`?o00003oooool3o`0000?ooooo6Ol0000Koooo
o`Go00000_ooool2o`0000;ooooo0_l0000Cooooo`;o000000?oooooo`000?l000000ol00005oooo
o`?o00004Oooool2o`00013ooooo1?l0000;ooooo`Ko0000COooool001cooooo00?o0000oooooooo
ool0<oooool2o`0000cooooo0_l00005ooooo`;o000000?oooooo`000?l000002_ooool2o`0000?o
oooo0_l000000ooooooo0000o`00000Ho`0000?ooooo0_l0000=ooooo`;o000000?oooooo`000?l0
00001Oooool3o`0000?ooooo0ol00004ooooo`;o00004?ooool2o`0000?ooooo0_l0000Iooooo`?o
00001oooool2o`0000Oooooo1?l0000<ooooo`?o000000Coooooo`000?l0003o00001oooool2o`00
04;ooooo000Looooo`03o`000?oooooooooo03gooooo0_l00009ooooo`;o000000?oooooo`000?l0
00002_ooool2o`0000?ooooo0_l000000ooooooo0000o`00000Go`0000Cooooo0_l0000=ooooo`;o
000000?oooooo`000?l000001Oooool2o`0000Gooooo0_l00004ooooo`;o00006Oooool2o`0000_o
oooo0_l00004ooooo`;o00000_ooool2o`0000Sooooo0_l00006ooooo`;o00002_ooool2o`0000?o
oooo0_l00002ooooo`?o00001oooool2o`0004;ooooo000Looooo`03o`000?oooooooooo03gooooo
0_l0000>ooooo`;o00004?ooool8o`000003ooooool0003o0000017o00004Oooool2o`000004oooo
ool0003o0000ooooo`Ko00001Oooool2o`0000Kooooo0_l0000Fooooo`;o00002?ooool5o`0000Co
oooo0_l000001?oooooo0000o`000?l0000@ooooo`;o00002?ooool4o`0000Kooooo1?l00005oooo
o`Co0000@_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l00000
0ol@413oooooooooo`04ooooo`03o`000?oooooooooo04gooooo0_l0000=oooooaKo000000?ooooo
o`000?l000001_l0000@ooooo`?o000000Coooooo`000?l0003ooooo0ol000000ooooooo0000o`00
0002ooooo`Go00001?ooool4o`0000Wooooo0_l0000Eooooo`Co00002?ooool2o`0000kooooo1?l0
0009ooooo`;o00002?ooool4o`0000Gooooo1?l00012ooooo`0000KoooooogMgMonHV9SooooooiRH
V?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04oooooo
1?l00005ooooo`;o00000_ooool5o`000003ooooool0003o000001Ko00004Oooool2o`000003oooo
ool0003o000000[ooooo1?l00002ooooo`Go000000?oooooo`000?l000001Oooool2o`000004oooo
ool0003o0000ooooo`?o00000_ooool2o`0000[ooooo0_l00003ooooo`;o00004oooool2o`0000?o
oooo1ol00009ooooo`;o00000_ooool2o`0000Sooooo0_l00006ooooo`;o0000?_ooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo00?o0000ooooooooool0
>oooool2o`0000[ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l00005ooooo`;o0000
1?ooool2o`000003ooooool0003o000001Wo00004_ooool2o`0000?ooooo0_l00005ooooo`;o0000
1?ooool4o`0000;ooooo0_l00005ooooo`;o00001?ooool3o`0000;ooooo0_l00008ooooo`Co0000
0oooool3o`0001;ooooo0_l00005ooooo`Go000000?oooooo`000?l000001_ooool8o`0000Kooooo
0_l00006ooooo`;o0000?_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Ooo
ool01?m4A4CogMgMooooool00007ooooo`?o0000>_ooool3o`0000[ooooo0_l00003ooooo`;o0000
0oooool2o`0000[ooooo7ol0000@ooooo`Ko000000?oooooo`000?l000003?ooool2o`0000oooooo
1?l00007ooooo`?o00000_ooool2o`0000Kooooo0_l000001?oooooo0000o`000?ooool2o`00013o
oooo1Ol00002ooooo`Co00002?ooool6o`000003ooooool0003o000000_ooooo0_l0000nooooo`00
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oo
oooo00?o0000ooooooooool0=_ooool2o`0000;ooooo0_l00003ooooo`;o00006oooool5o`000003
ooooool0003o000001Oo00004Oooool2o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`?o
00001?ooool5o`0000Gooooo0_l00005ooooo`Co00001oooool3o`0000?ooooo1ol00002ooooo`?o
000000?oooooo`000?l000003oooool7o`000003ooooool0003o000000cooooo0_l00003ooooo`;o
00001oooool2o`0000?ooooo0_l0000mooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooo
ooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0=_ooool2o`0000Oooooo
0_l0000Kooooo`;o00001?oooolIo`0001Cooooo0_l00002ooooo`;o00001Oooool3o`0000Gooooo
1Ol00002ooooo`Co00000oooool2o`000003ooooool0003o000000?ooooo0_l00008ooooo`Wo0000
00?oooooo`000?l000004oooool4o`000003ooooool0003o000000Co00002oooool2o`0000;ooooo
0_l00008ooooo`;o00000_ooool3o`0003gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`co
oooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0/ooooo`;o00001oooool3o`0001?o
oooo0_l0000?ooooo`;o00001?oooolIo`0001Cooooo0_l00009ooooo`[o000000?oooooo`000?l0
00000_ooool5o`0000;ooooo0_l00006ooooo`;o00002?ooool<o`0001?ooooo0_l00003ooooo`Ko
00002oooool6o`0000cooooo0_l0000nooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h=oooo
o`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0;?ooool2o`0000Oooooo0_l0000?oooo
o`;o00000oooool2o`0001Gooooo5?l000000ooooooo0000o`000003o`0001;ooooo0_l0000:oooo
o`[o000000?oooooo`000?l000001?ooool3o`0000;ooooo0_l0000<oooooa3o00006?ooool4o`00
00;ooooo0_l00002ooooo`;o00001?ooool6o`0004gooooo000Looooo`03o`000?oooooooooo03Oo
oooo0_l0000=ooooo`;o00006OoooolEo`000004ooooool0003o0000ooooo`;o00003Oooool2o`00
00;ooooo0ol00009ooooo`?o00001Oooool6o`0000gooooo0_l000000ooooooo0000o`000005oooo
oa3o00005_ooool6o`0000;ooooo0ol000000ooooooo0000o`000004ooooo`Oo00001?ooool2o`00
0003ooooool0003o000000?ooooo0ol0000mooooo`007?ooool00ol0003oooooooooo`0gooooo`;o
00009?ooool2o`0000;ooooo6Ol0000?ooooo`;o00000_ooool2o`0000[ooooo1?l00005ooooo`Co
000000?oooooo`000?l000000oooool2o`0000;ooooo0_l000001Ooooooo0000o`000?l0003ooooo
00;o00001OoooolBo`0000;ooooo0_l0000:ooooo`;o00000oooool3o`0000Kooooo0ol0000<oooo
o`;o00001?ooool2o`000003ooooool0003o000000?ooooo0ol0000mooooo`007?ooool00ol0003o
ooooooooo`1Mooooo`;o00000_oooolKo`00017ooooo0_l00008ooooo`;o00000_ooool2o`0000Go
oooo0_l00002ooooo`Co00000_ooool2o`0000;ooooo0_l000001?oooooo0000o`000?l00005oooo
oaGo00000_ooool2o`0000Kooooo0ol000000ooooooo0000o`000003ooooo`;o00000oooool2o`00
00;ooooo0_l0000Fooooo`?o0000@_ooool001cooooo00?o0000ooooooooool0G_ooool2o`0000;o
oooo5ol000000ooooooo0000o`00000<ooooo`;o00000oooool2o`0000Sooooo0_l00006ooooo`;o
00000_ooool2o`000003ooooool0003o000000?o00001Oooool2o`0000;ooooo0_l000001?oooooo
0000o`000?oooolFo`0000[ooooo0ol000000ooooooo0000o`000008ooooo`;o00000_ooool2o`00
01Oooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00007?ooool2o`0000;o
oooo0_l000000ooooooo0000o`00000@o`00017ooooo0_l000000ooooooo0000o`00000Booooo`;o
00000_ooool2o`0000?ooooo1?l00002ooooo`;o000000?oooooo`000?l000000_ooool4o`000003
ooooool0003o000000;ooooo0_l000000ooooooo0000o`00000<o`0000Cooooo0ol0000>ooooo`;o
00000oooool2o`000003ooooool0003o000005_ooooo000Looooo`03o`000?oooooooooo03?ooooo
0_l0000:ooooo`?o00008_oooolCo`0001Cooooo0_l0000Fooooo`;o00001?ooool7o`000004oooo
ool0003o0000ooooo`?o00002_ooool>o`0000Cooooo0ol0000>ooooo`;o000000?oooooo`000?l0
00001_l0001Jooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00002_ooool2o`0000;ooooo
0_l0000Gooooo`;o00001_ooool@o`000003ooooool0003o000001Cooooo0ol0000<ooooo`;o0000
1Oooool4o`0000?ooooo2?l00002ooooo`Go00001oooool2o`0000?ooooo2ol0000Iooooo`So0000
2_ooool4o`0004cooooo000Looooo`03o`000?oooooooooo04?ooooo0_l0000Gooooo`;o000000Co
ooooo`000?l0003o00001?ooool>o`000003ooooool0003o000001Cooooo0ol00002ooooo`;o0000
2?ooool2o`0000;ooooo0_l000001?oooooo0000o`000?l00002ooooo`Co000000?oooooo`000?l0
00000ol00002ooooo`Go00000_ooool2o`0000?ooooo1?l00002ooooo`co00000oooool2o`00013o
oooo0_l00004ooooo`Co00002Oooool5o`0000gooooo0_l0000mooooo`007?ooool00ol0003ooooo
ooooo`10ooooo`;o00007Oooool3o`0000Cooooo4_l0000Dooooo`;o00000_ooool2o`0000Sooooo
0_l00002ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0000Gooooo0ol000000ooooooo
0000o`000002ooooo`;o00000_ooool2o`0000Gooooo0_l000000ooooooo0000o`000003o`0000Go
oooo0ol000000ooooooo0000o`000002o`00013ooooo0_l00004ooooo`;o00002oooool2o`000003
ooooool0003o000000gooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`10ooooo`;o0000
8Oooool:o`000003ooooool0003o000000So000000?oooooo`000?l000001_ooool2o`0000Wooooo
0_l0000Cooooo`;o00001Oooool4o`000005ooooool0003o0000o`000?ooool00ol000001?oooooo
0000o`000?l0000:ooooo`?o00002?ooool2o`0000;ooooo1?l000000ooooooo0000o`00000:oooo
o`;o000000Goooooo`000?l0003o0000ooooo`04o`0000oooooo1Ol00018ooooo`007?ooool00ol0
003oooooooooo`0cooooo`;o00000_ooool2o`0002[ooooo1Ol00003ooooo`[o00001?ooool2o`00
00Kooooo0_l0000Nooooo`;o00001Oooool4o`000004ooooool0003o0000o`0000;ooooo0_l00000
1?oooooo0000o`000?l0000:ooooo`?o00002?ooool2o`000003ooooool0003o000000;o00000_oo
ool2o`0000Kooooo0_l00002ooooo`;o00000_ooool7o`0000oooooo1_l00004ooooo`;o0000@Ooo
ool001cooooo0_l0000_ooooo`;o00000oooool2o`0000;ooooo0_l0000/ooooo`;o00001?ooool9
o`0000Gooooo0_l0000Vooooo`;o00001?ooool4o`0000;ooooo1ol000001?oooooo0000o`000?l0
0009ooooo`;o00001?ooool2o`0000?ooooo0_l00002ooooo`?o00000_ooool2o`0000Gooooo1?l0
0006ooooo`?o00002_ooool2o`0000;ooooo1?l00004ooooo`Go00000_ooool2o`00047ooooo000L
ooooo`03o`000?oooooooooo02kooooo0_l00005ooooo`;o00003Oooool2o`0002?ooooo0_l00004
ooooo`;o00000_ooool3o`00037ooooo1?l00003ooooo`Ko00000oooool2o`0000Sooooo0_l00004
ooooo`;o00000oooool2o`0000Oooooo0_l00005ooooo`Co00001oooool2o`0000Cooooo0_l00004
ooooo`;o00000_ooool4o`0000Cooooo1Ol00002ooooo`;o0000@Oooool001cooooo00?o0000oooo
ooooool0=Oooool2o`0000cooooo0ol0000Sooooo`?o00000oooool9o`0000[ooooo0_l0000Toooo
o`;o00001Oooool2o`000003ooooool0003o000000Go00006oooool2o`0000Wooooo0_l000000ooo
oooo0000o`000009ooooo`;o00002?ooool2o`0000Oooooo0_l00002ooooo`;o00000oooool2o`00
03kooooo000Looooo`03o`000?oooooooooo03cooooo0_l00005ooooo`;o00007oooool3o`0000?o
oooo0_l00004ooooo`Co00000_ooool2o`0000Wooooo0ol00008ooooo`;o00006Oooool4o`000004
ooooool0003o0000ooooo`;o000000?oooooo`000?l000000ol0000=ooooo`;o00003_ooool2o`00
00Wooooo0_l000000ooooooo0000o`00000Cooooo`;o00002_ooool3o`0000?ooooo1Ol0000koooo
o`007?ooool00ol0003oooooooooo`0looooo`;o00008oooool2o`000003ooooool0003o000000;o
000000?oooooo`000?l000001Oooool6o`0000_ooooo0_l00009ooooo`;o00002oooool2o`0000Oo
oooo0_l00003ooooo`Co000000Coooooo`000?l0003ooooo0_l000001?oooooo0000o`000?l0000?
ooooo`;o00000oooool2o`0001Cooooo0_l0000>ooooo`?o00000_ooool2o`000003ooooool0003o
000000Oooooo1_l00004ooooo`Co0000>oooool001cooooo00?o0000ooooooooool0HOooool2o`00
00?ooooo1Ol00006ooooo`Go00001Oooool2o`00017ooooo0_l00009ooooo`;o00001oooool4o`00
0003ooooool0003o000000Co00000oooool5o`0001Cooooo0ol0000Cooooo`;o00003_ooool3o`00
00;ooooo0_l000000ooooooo0000o`000007ooooo`?o000000?oooooo`000?l000001_ooool2o`00
03_ooooo000Looooo`03o`000?oooooooooo03Oooooo0_l0000<ooooo`;o00008Oooool2o`000003
ooooool0003o000000kooooo0_l0000?ooooo`Co00005?ooool2o`000003ooooool0003o000000Co
00000oooool4o`000003ooooool0003o000001?ooooo1?l0000cooooo`;o0000A_ooool001cooooo
00?o0000ooooooooool0=oooool2o`0000cooooo0_l00003ooooo`;o00005?ooool3o`0000Gooooo
0_l000000ooooooo0000o`00000;ooooo`;o00004_ooool4o`0000Sooooo0_l0000:ooooo`;o0000
00Coooooo`000?l0003o00000oooool2o`000003ooooool0003o000000;o000000?oooooo`000?l0
00005Oooool3o`00013ooooo0_l0000Gooooo`;o000000?oooooo`000?l000001?ooool2o`0004Ko
oooo000Looooo`03o`000?oooooooooo04[ooooo0_l0000;ooooo`Go00001?ooool3o`0000Gooooo
0ol00004ooooo`;o00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`;o0000
1?ooool3o`0000cooooo0_l00007ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000?o
oooo0_l00003ooooo`Ko00005Oooool2o`0000gooooo0_l000000ooooooo0000o`000003o`0000Oo
oooo0_l0000;ooooo`;o000000Coooooo`000?l0003ooooo0_l00019ooooo`007?ooool00ol0003o
ooooooooo`14ooooo`?o00004?ooool5o`0000;ooooo1Ol00005ooooo`?o00001?ooool2o`0000;o
oooo0_l00006ooooo`?o00000oooool6o`0000;ooooo1Ol00002ooooo`;o000000?oooooo`000?l0
00002Oooool2o`000003ooooool0003o000000;ooooo0_l0000<ooooo`Go00007_ooool2o`0000Co
oooo1?l000001?oooooo0000o`000?l00007ooooo`;o00004Oooool2o`0004Wooooo000Looooo`03
o`000?oooooooooo04Cooooo0ol0000=ooooo`;o00001oooool6o`0000Kooooo0_l00008ooooo`;o
000000?oooooo`000?l000000_ooool4o`0000?ooooo0_l00002ooooo`;o00000oooool4o`0000;o
oooo0_l000000ooooooo0000o`000009ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Oo
oooo1?l00007ooooo`;o00005?ooool2o`0000Gooooo1Ol000000ooooooo0000o`000002o`0000_o
oooo0_l0000;ooooo`;o00001?ooool3o`0004Sooooo000Looooo`03o`000?oooooooooo02Kooooo
0_l0000>ooooo`;o00007?ooool2o`0000Oooooo0ol0000:ooooo`;o00000oooool2o`000005oooo
ool0003o0000o`000?ooool00_l00002ooooo`?o00001_ooool2o`0000?ooooo1Ol0000Dooooo`;o
00000_ooool2o`0000Oooooo1?l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l0000@oooo
o`Go00001?ooool4o`000003ooooool0003o0000013ooooo0_l00008ooooo`;o00001?ooool3o`00
00[ooooo0_l0000looooo`007?ooool00ol0003oooooooooo`0Vooooo`;o00003_ooool2o`0000Oo
oooo0_l0000Kooooo`Co00001oooool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo
0000o`00000?ooooo`Co000000?oooooo`000?l00000;?ooool2o`0000Cooooo0_l0000@ooooo`;o
000000Goooooo`000?l0003o0000ooooo`02o`0000Cooooo1?l00002ooooo`?o00002_ooool2o`00
00Oooooo0ol000000ooooooo0000o`00000;ooooo`;o000000?oooooo`000?l00000??ooool001co
oooo00?o0000ooooooooool0?oooool2o`0000Sooooo0_l0000;ooooo`;o00001?ooool3o`0000?o
oooo0ol00002ooooo`;o00000oooool2o`0001Cooooo1Ol000000ooooooo0000o`000004ooooo`;o
00005_ooool2o`0000Wooooo0_l0000Oooooo`ko000000Coooooo`000?l0003o00000_ooool2o`00
00Kooooo0_l00004ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000_ooooo0_l0000o
ooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00001?ooool2o`0000Gooooo0_l00005oooo
o`So00001oooool4o`0000Sooooo0_l00003ooooo`;o00000oooool4o`0000Sooooo0_l0000?oooo
o`;o00001Oooool2o`0000Wooooo0_l0000Qooooo`co000000?oooooo`000?l000000_l000000ooo
oooo0000o`000006ooooo`;o000000Coooooo`000?l0003ooooo0_l000001?oooooo0000o`000?l0
0003ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0=?ooool2o`0001Wooooo0_l00005
ooooo`;o000000?oooooo`000?l000000_ooool8o`0000Sooooo0ol00008ooooo`;o000000?ooooo
o`000?l000001ol00006ooooo`?o00004_ooool4o`000003ooooool0003o000000;o00002Oooool2
o`0000Gooooo0_l0000@ooooo`;o00001oooool3o`000003ooooool0003o000000;o00000_ooool2
o`0000;ooooo1?l00007ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`Co00000_oo
ool2o`0004[ooooo000Looooo`;o0000=Oooool2o`0000oooooo0_l0000Booooo`;o00001Oooool6
o`0000Cooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo0_l00002ooooo`Oo000000?ooooo
o`000?l000001Oooool3o`0001Cooooo0_l000000ooooooo0000o`000002o`0000Oooooo1?l00004
ooooo`?o00001_ooool4o`0000Kooooo1?l00003ooooo`oo00000oooool2o`0000Oooooo0_l00006
ooooo`;o000000?oooooo`000?l000000_l000001?oooooo0000o`000?l00002ooooo`;o00000ooo
ool2o`00047ooooo000Looooo`03o`000?oooooooooo03Oooooo0_l0000:ooooo`Co00002Oooool2
o`0000;ooooo0ol00006ooooo`Wo00001?ooool2o`0000?ooooo0_l000000ooooooo0000o`000005
o`0000[ooooo0_l00006ooooo`;o00002Oooool2o`0000Gooooo0_l00002ooooo`;o00000_ooool2
o`0000Sooooo1?l00004ooooo`Go00001?ooool4o`0000Kooooo6_l00006ooooo`?o00001oooool2
o`0000?ooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00000oooool2o`0000;ooooo0_l0
000mooooo`007?ooool00ol0003oooooooooo`0Tooooo`;o00003oooool4o`0000[ooooo0_l0000;
ooooo`;o000000?oooooo`000?l000001?l00002ooooo`go00001oooool2o`000003ooooool0003o
000000Co00004oooool2o`0000?ooooo0_l00004ooooo`;o00001Oooool2o`0000;ooooo0_l00002
ooooo`;o00002oooool2o`0000?ooooo0_l000000ooooooo0000o`00000AoooooaWo000000Cooooo
o`000?l0003ooooo0ol000000ooooooo0000o`00000=ooooo`;o00001Oooool2o`0000Cooooo0_l0
000mooooo`007?ooool00ol0003oooooooooo`0Tooooo`;o00003oooool3o`0001?ooooo0_l00006
ooooo`;o00000_ooool2o`000003ooooool0003o000000co00001?ooool2o`0000Sooooo0_l0000>
ooooo`;o00002?ooool2o`0000_ooooo0_l00003ooooo`?o00001?ooool2o`000003ooooool0003o
000000Cooooo0_l0000IoooooaCo000000?oooooo`000?l000000_l000000ooooooo0000o`000003
o`0000;ooooo0_l00003ooooo`;o00003oooool2o`0004?ooooo000Looooo`03o`000?oooooooooo
02gooooo0_l00003ooooo`;o00000_ooool2o`0001?ooooo0_l0000=ooooo`ko00001?ooool2o`00
01Sooooo0_l0000=ooooo`;o00001_ooool2o`0000?ooooo0ol00004ooooo`;o000000?oooooo`00
0?l000001?ooool2o`0000_ooooo0_l0000<oooooaoo00001oooool3o`0005?ooooo000Looooo`03
o`000?oooooooooo02gooooo0_l00003ooooo`;o000000?oooooo`000?l000003oooool2o`0001;o
oooo3ol0000/ooooo`;o00004_ooool2o`0000Cooooo0_l00004ooooo`;o00002?ooool2o`0000[o
oooo8?l00009ooooo`;o00003oooool2o`0004;ooooo000Looooo`03o`000?oooooooooo03;ooooo
1Ol00003ooooo`;o00002_ooool2o`00017ooooo4?l0000Uooooo`;o00007?ooool2o`000003oooo
ool0003o000000;o00000_ooool2o`0000Gooooo0_l00002ooooo`;o00001Oooool?o`000004oooo
ool0003o0000ooooo`_o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000002o`00
01Gooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`0Yooooo`;o00001oooool3o`000003
ooooool0003o000000;ooooo0_l0000?ooooo`;o00002_ooool<o`000003ooooool0003o000000;o
000000?oooooo`000?l000005oooool2o`0000Sooooo1?l0000Looooo`;o000000?oooooo`000?l0
00000_l00009ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000@o`000003
ooooool0003o000001Go0000F?ooool001cooooo00?o0000ooooooooool0:Oooool2o`0000_ooooo
0_l0000Cooooo`;o00001oooool2o`000003ooooool0003o000001;o00003oooool3o`0000Cooooo
0ol00008ooooo`;o00003Oooool2o`0000oooooo0_l000000ooooooo0000o`000002o`0000Gooooo
1_l00002ooooo`;o00000_ooool2o`0000?ooooo8ol00003ooooo`;o00002oooool3o`0000?ooooo
0_l00003ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0=_ooool2o`0001cooooo0_l0
0002oooooa?o00003oooool3o`0000Cooooo0_l0000Fooooo`Co00002Oooool2o`000004ooooool0
003o0000ooooo`Co00002?ooool7o`000003ooooool0003o000000Oooooo8_l00007ooooo`;o0000
1?ooool3o`000004ooooool0003o0000o`0000?ooooo0_l00003ooooo`;o0000@?ooool001cooooo
00?o0000ooooooooool0EOooool2o`0000;ooooo4_l0000>ooooo`;o00002Oooool2o`0001?ooooo
0_l0000;ooooo`Go00000oooool2o`0000gooooo0_l000000ooooooo0000o`000008ooooob3o0000
0_ooool2o`000003ooooool0003o000000?o00001?ooool3o`0000Oooooo0_l00015ooooo`007?oo
ool00ol0003oooooooooo`18ooooo`;o00002ooooolFo`0000kooooo0_l00006ooooo`;o000000Co
ooooo`000?l0003ooooo0_l0000Aooooo`;o00001_ooool2o`0000;ooooo1?l00002ooooo`Co0000
2Oooool2o`0000[ooooo0_l00002ooooo`ko000000?oooooo`000?l000004?l000000ooooooo0000
o`000006o`0000oooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`0Rooooo`;o00009?oo
ool2o`0000_ooooo5_l00003ooooo`;o00004Oooool3o`0000?ooooo0_l000000ooooooo0000o`00
000>ooooo`;o00001_ooool2o`0000?ooooo0_l00003ooooo`?o000000?oooooo`000?l000001ooo
ool2o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l000003Ol000000ooooooo0000o`00
000@o`000003ooooool0003o000000Co00002?ooool2o`0004kooooo000Looooo`03o`000?oooooo
oooo02;ooooo0_l0000Dooooo`;o00006ooooolFo`0000?ooooo0_l00005ooooo`;o00000_ooool2
o`0000Oooooo1?l00004ooooo`;o00001_ooool2o`0000kooooo0_l00008ooooo`?o000000?ooooo
o`000?l000003Oooool2o`0000Oooooo0ol000000ooooooo0000o`00000Io`0000;ooooo1_l00004
ooooo`;o00001?ooool2o`0000Gooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`0/oooo
o`;o00002_ooool2o`0001Kooooo0_l00004oooooa;o00003Oooool2o`000004ooooool0003o0000
o`0000Wooooo0_l00009ooooo`;o000000?oooooo`000?l000000_ooool4o`0000Cooooo0_l00009
ooooo`;o000000?oooooo`000?l000000ol00003ooooo`;o00001oooool4o`0000Sooooo1Ol00000
0ooooooo0000o`00000Fo`0000;ooooo1?l00006ooooo`Co00001_ooool5o`0000Kooooo0ol0000n
ooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00002?ooool2o`0001Kooooo1?l00003oooo
o`;o000000?oooooo`000?l000003Ol00006ooooo`Co00001oooool2o`0001Gooooo0_l00002oooo
o`;o000000?oooooo`000?l000000_l00002ooooo`Co00000oooool2o`0000Cooooo0_l000001?oo
oooo0000o`000?ooool2o`0000?ooooo0_l00006ooooo`Go00000oooool2o`0000Cooooo9?l00007
ooooo`;o00001_ooool4o`000003ooooool0003o000000Cooooo0ol0000nooooo`007?ooool2o`00
03Oooooo0_l0000Aooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo0_l000000ooo
oooo0000o`00000>o`0000;ooooo0_l000000ooooooo0000o`000002o`0001[ooooo0_l00006oooo
o`;o00001_ooool3o`0000;ooooo0_l000000ooooooo0000o`00000Gooooo`;o00000_ooool2o`00
00;ooooo0_l00004ooooobCo00000oooool3o`0000;ooooo0_l00007ooooo`;o000000?oooooo`00
0?l000001?ooool2o`0003oooooo000Looooo`03o`000?oooooooooo04Oooooo1?l00006ooooo`;o
00000_ooool2o`000003ooooool0003o000000ko00000_ooool2o`0000?ooooo0ol0000@ooooo`;o
00001oooool2o`0000;ooooo0_l00002ooooo`;o00000oooool5o`000003ooooool0003o000000;o
00007_ooool2o`0000Sooooo7_l00002ooooo`?o00001?ooool7o`000003ooooool0003o000000?o
oooo1Ol000000ooooooo0000o`000013ooooo`007?ooool00ol0003oooooooooo`0Yooooo`;o0000
7?ooool2o`0000cooooo0_l000000ooooooo0000o`00000>o`0000Sooooo0_l0000@ooooo`;o0000
2oooool2o`000003ooooool0003o000000Cooooo1?l00002ooooo`;o00001oooool2o`0000Cooooo
0_l0000>ooooo`;o00002oooool2o`000003ooooool0003o000000Oo000000?oooooo`000?l00000
4Ol00003ooooo`;o00001Oooool2o`0000?ooooo0_l00003ooooo`;o000000Coooooo`000?l0003o
oooo0_l00013ooooo`007?ooool00ol0003oooooooooo`0Yooooo`?o0000;Oooool?o`0001[ooooo
0_l00006ooooo`;o00000oooool2o`000003ooooool0003o000000Cooooo1?l000000ooooooo0000
o`000008ooooo`;o000000Coooooo`000?l0003ooooo0_l0000>ooooo`;o00000oooool2o`0000_o
oooo2?l000000ooooooo0000o`00000<o`0000;ooooo0_l00003ooooo`?o00000_ooool4o`0000Oo
oooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`0Zooooo`;o00001oooool2o`00017ooooo
0_l0000?oooooa7o00008_ooool2o`0000?ooooo0_l00009ooooo`Go000000?oooooo`000?l00000
0_l00003ooooo`Go00005_ooool2o`0000Sooooo0_l00002ooooo`oo000000?oooooo`000?l00000
0_l0000:ooooo`;o00000_ooool2o`0000Wooooo0_l000000ooooooo0000o`00000<ooooo`;o0000
>Oooool001cooooo00?o0000ooooooooool0:_ooool2o`0000Oooooo0_l0000Aooooo`;o00003ooo
ool@o`00027ooooo0_l00004ooooo`Co00001oooool5o`0000;ooooo1Ol00002ooooo`?o00006?oo
ool4o`0000Kooooo4ol000001?oooooo0000o`000?l00006ooooo`;o00000_ooool2o`00017ooooo
0_l0000<ooooo`?o0000>?ooool001cooooo00?o0000ooooooooool0:oooool2o`0002Wooooo0ol0
00000ooooooo0000o`00000:o`0000oooooo0_l0000Aooooo`?o00000oooool4o`0000Oooooo0_l0
0003ooooo`Oo00003?ooool2o`0000Kooooo0_l00007ooooo`Co00002?ooool2o`0000;ooooo1?l0
0003ooooo`Ko000000?oooooo`000?l000001oooool2o`0000;ooooo0ol0000@ooooo`;o00003Ooo
ool2o`0003Sooooo000Looooo`03o`000?oooooooooo02_ooooo0_l00002ooooo`;o00006oooool2
o`0000Sooooo0ol00003ooooo`Oo00002oooool2o`0000?ooooo1?l00003ooooo`;o00001?ooool2
o`0000Oooooo0_l00005ooooo`;o00002?ooool>o`0000Wooooo0_l00006ooooo`;o00001?ooool2
o`0000;ooooo0_l00009ooooo`;o00000_ooool6o`000003ooooool0003o000000?o00000_ooool5
o`000003ooooool0003o000000Cooooo1?l0001Iooooo`007?ooool00ol0003oooooooooo`0_oooo
o`;o00006oooool2o`0000kooooo2Ol00009ooooo`;o00000oooool3o`0000Cooooo0_l00004oooo
o`;o00001oooool2o`0000Sooooo5Ol00002ooooo`;o000000?oooooo`000?l000000_l0000>oooo
o`;o00000_ooool2o`0000;ooooo0ol00009ooooo`So000000?oooooo`000?l000000_ooool5o`00
0004ooooool0003o0000ooooo`;o000000?oooooo`000?l000006_ooool2o`0000;ooooo0_l0000k
ooooo`007?ooool00ol0003oooooooooo`0Xooooo`Co00006Oooool2o`0000Kooooo0ol00009oooo
o`;o000000?oooooo`000?l000001?l000000ooooooo0000o`000002o`0000Oooooo0_l00004oooo
o`?o00001?ooool2o`0000Sooooo1_l000000ooooooo0000o`000003ooooo`Wo000000?oooooo`00
0?l000002ol000000ooooooo0000o`000006o`00013ooooo0_l00004ooooo`?o00002Oooool2o`00
00;ooooo1?l0000>ooooo`;o00007Oooool2o`0000;ooooo0_l0000kooooo`007?ooool00ol0003o
ooooooooo`0Xooooo`Co00006Oooool2o`0000Kooooo0ol00004ooooo`;o00000oooool9o`0000?o
oooo0_l0000>ooooo`;o00001?ooool2o`0000Oooooo1Ol00003ooooo`Co000000?oooooo`000?l0
00001ol000001Ooooooo0000o`000?l0003ooooo00Co000000?oooooo`000?l000002?l0000Coooo
o`;o00004_ooool2o`000003ooooool0003o000006oooooo000Looooo`03o`000?oooooooooo05Co
oooo0_l00005ooooo`Ko00000_ooool4o`0000Sooooo1?l00007ooooo`;o00001_ooool4o`0000Ko
oooo3?l000000ooooooo0000o`000008o`0000Cooooo2?l0000Vooooo`;o00001?ooool2o`0006co
oooo000Looooo`03o`000?oooooooooo02gooooo0_l00005ooooo`;o00009Oooool2o`0000;ooooo
1ol00008ooooo`Go00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo
0ol00003ooooo`Go000000?oooooo`000?l000004?l000000ooooooo0000o`000008o`0000Cooooo
0_l00005ooooo`;o00002Oooool4o`0000?ooooo0_l00006ooooo`?o00001?ooool4o`00013ooooo
0_l0000Dooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0;Oooool4o`0000?ooooo0_l0
000@ooooo`;o00001?ooool2o`0000[ooooo0ol00004ooooo`Go000000?oooooo`000?l000001ooo
ool5o`0000;ooooo0_l00007ooooo`;o00000_ooool2o`0000;ooooo0ol00005ooooo`;o00001_oo
oolFo`000003ooooool0003o000000;ooooo1?l00002ooooo`So000000?oooooo`000?l000000ooo
ool4o`0000?ooooo1?l00004ooooo`?o00001?ooool4o`000003ooooool0003o000000cooooo0ol0
0008ooooo`;o000000?oooooo`000?l000001oooool2o`0004;ooooo00001_ooooook^k^oc8b<_l0
003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003o
ooooooooo`0_ooooo`;o00000oooool2o`00013ooooo0ol00003ooooo`;o000000?oooooo`000?l0
00001oooool5o`000003ooooool0003o000000;o000000?oooooo`000?l000001?l00007ooooo`;o
00006?ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000001Ol000000ooo
oooo0000o`00000Bo`0000;ooooo0_l00003ooooo`Go000000Goooooo`000?l0003o0000ooooo`02
o`0000Cooooo1?l00004ooooo`;o00002?ooool2o`000003ooooool0003o000000?ooooo0_l0000<
ooooo`?o00002?ooool2o`000003ooooool0003o000000Gooooo0ol00013ooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo
00?o0000ooooooooool0:_ooool2o`0000Sooooo0_l0000Aooooo`;o00001_ooool2o`0000?ooooo
0_l00002ooooo`;o000000Coooooo`000?l0003ooooo1?l000000ooooooo0000o`000002ooooo`;o
00000oooool2o`0000?ooooo0_l0000Gooooo`Go000000Coooooo`000?l0003ooooo7?l00002oooo
o`;o00000oooool3o`0000Cooooo0_l00005ooooo`Ko00003?ooool4o`000003ooooool0003o0000
00kooooo0_l0000;ooooo`;o00002Oooool3o`0004?ooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
02[ooooo0_l000000ooooooo0000o`00000Oooooo`;o00001?ooool3o`000003ooooool0003o0000
00;o00000oooool2o`000004ooooool0003o0000ooooo`;o00001Oooool2o`0000?ooooo0_l0000D
ooooo`;o00000_ooool4o`000004ooooool0003o0000oooooaco00000_ooool2o`0000Oooooo1Ol0
0004ooooo`Co00002?ooool2o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o00003_oo
ool2o`0000_ooooo0_l00008ooooo`;o00000oooool2o`00043ooooo00000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo00Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000;Ooo
ool2o`0001oooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool4o`0000Gooooo0_l0
00000ooooooo0000o`00000:ooooo`;o00003?ooool2o`0000Kooooo0_l000001?oooooo0000o`00
0?ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000004?l000000ooooooo
0000o`000002o`0000gooooo1?l00005ooooo`;o00002_ooool2o`0000;ooooo0_l0000Vooooo`;o
00001?ooool3o`0000?ooooo0_l00010ooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooo
ooooo`09ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`1>ooooo`;o
00000_ooool2o`000003ooooool0003o000000?ooooo0ol000000ooooooo0000o`000002o`0000go
oooo0_l0000<ooooo`Co00002Oooool4o`0000Gooooo3?l000000ooooooo0000o`00000;o`0000[o
oooo0_l0000Eooooo`;o0000:?ooool2o`000003ooooool0003o000000;ooooo1?l00004ooooo`;o
0000@?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7
ooooo`08ooooo`03o`000?oooooooooo02Wooooo0_l00003ooooo`;o00008oooool6o`0000;ooooo
0_l000000ooooooo0000o`000002o`0000[ooooo0_l000000ooooooo0000o`00000<ooooo`;o0000
1_ooool9o`0000Gooooo4ol000000ooooooo0000o`000007o`0000?ooooo0_l00002ooooo`;o0000
4?ooool2o`0000?ooooo0_l0000Xooooo`;o00001Oooool3o`0004Oooooo00001_ooooooMgMgoiRH
V?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0Yooooo`;o
00000oooool2o`0001Wooooo0_l00008ooooo`;o00000_ooool2o`0000;ooooo0_l0000:ooooo`;o
00000oooool2o`0000oooooo0_l00003ooooo`;o000000?oooooo`000?l000001Ol00004oooooa_o
000000?oooooo`000?l000000_l000000ooooooo0000o`000002o`000004ooooool0003o0000o`00
013ooooo0_l00009ooooo`;o00001oooool2o`0000;ooooo0_l00002ooooo`Go00002Oooool2o`00
00Cooooo0ol00002ooooo`?o00000_ooool2o`0004Cooooo00001_ooooook^k^oc8b<_l0003o<S8b
onk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`19ooooo`;o00002ooo
ool3o`0000kooooo0ol00004ooooo`;o00003Oooool2o`0000?ooooo0_l00006ooooo`?o000000?o
ooooo`000?l000006_l00002ooooo`Oo00000oooool3o`00013ooooo0_l00009ooooo`;o00001ooo
ool2o`0000;ooooo0_l00002ooooo`Go00002Oooool2o`0000Cooooo0ol000001?oooooo0000o`00
0?l00002ooooo`?o0000A?ooool001cooooo00?o0000ooooooooool0C?ooool2o`0000?ooooo1?l0
00001?oooooo0000o`000?l00008ooooo`;o000000?oooooo`000?l000000_ooool2o`000004oooo
ool0003o0000ooooo`?o00000_ooool2o`0000gooooo1?l00002ooooo`;o000000Coooooo`000?l0
003ooooo9Ol00004ooooo`;o00004?ooool2o`0001;ooooo0_l0000?ooooo`;o00002oooool4o`00
00?ooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o00001oooool2o`0001Ko
oooo0_l00003ooooo`Co000000?oooooo`000?l000002Oooool2o`000003ooooool0003o000000?o
00000_ooool3o`000003ooooool0003o000000;ooooo0ol00008ooooo`;o00000_ooool]o`000003
ooooool0003o000000;o00000oooool6o`0000Sooooo0_l0000:ooooo`;o00006_ooool3o`0000_o
oooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o00001oooool2o`0001Kooooo
0_l00006ooooo`;o00003oooool4o`000003ooooool0003o000000;o000000?oooooo`000?l00000
0oooool2o`0000Gooooo0_l000000ooooooo0000o`000005oooooboo00000oooool6o`0000Oooooo
0ol00009ooooo`?o00001?ooool2o`0001Cooooo0_l00008ooooo`;o00005?ooool2o`0003[ooooo
000Looooo`03o`000?oooooooooo02Gooooo0_l00007ooooo`;o00006oooool2o`0000Oooooo0_l0
000;ooooo`;o00000_ooool2o`0000?ooooo1?l00005ooooo`;o00001_ooool2o`000004ooooool0
003o0000o`0000;ooooo0_l00003ooooo`;o00000oooool5o`000003ooooool0003o000001oo0000
1?ooool3o`0000Oooooo1?l00003ooooo`;o00001Oooool2o`0000Gooooo0_l0000Nooooo`;o0000
5?ooool2o`0003[ooooo000Looooo`03o`000?oooooooooo02Gooooo0_l00007ooooo`;o00001?oo
ool2o`0001Gooooo0ol0000Cooooo`;o00002?ooool3o`0000Gooooo0ol00008ooooo`?o000000?o
ooooo`000?l000000ol000001?oooooo0000o`000?oooolYo`0000?ooooo1?l00005ooooo`Go0000
1?ooool2o`0000Gooooo0_l0000^ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0=?oo
ool2o`0001Kooooo0_l00005ooooo`Oo00001oooool2o`0000Wooooo0_l00006ooooo`;o00001?oo
ool2o`0000Kooooo1Ol000000ooooooo0000o`00000Zo`000003ooooool0003o000000?o00001_oo
ool2o`000003ooooool0003o000000;ooooo0_l0000gooooo`;o0000Aoooool001cooooo00?o0000
ooooooooool0Doooool7o`000003ooooool0003o000000oooooo0_l0000<ooooo`;o00001ooooolU
o`000003ooooool0003o000000Ko00001?ooool5o`0000gooooo0_l00004ooooo`;o0000N_ooool0
01cooooo00?o0000ooooooooool0COooool2o`0000Oooooo0ol00002ooooo`;o00004Oooool5o`00
00kooooo0_l000000ooooooo0000o`000005o`000003ooooool0003o000000;o00000_oooolFo`00
0003ooooool0003o000000Go00002?ooool2o`0000Cooooo0_l0000=ooooo`;o00007?ooool3o`00
0003ooooool0003o000000kooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o
00007_ooool4o`0000?ooooo1Ol000001?oooooo0000o`000?l0000@ooooo`Ko00003_ooool7o`00
0004ooooool0003o0000ooooobSo000000Coooooo`000?l0003ooooo1?l00002ooooo`;o0000:ooo
ool3o`000004ooooool0003o0000o`0000Oooooo0_l00004ooooo`;o0000B?ooool001cooooo00?o
0000ooooooooool0;Oooool2o`00023ooooo0_l00003ooooo`Co00000_ooool2o`0000;ooooo0_l0
000=ooooo`;o000000?oooooo`000?l000002Oooool2o`0000?ooooo2?l00004ooooobSo000000?o
ooooo`000?l000000_l000000ooooooo0000o`00000cooooo`?o00000oooool2o`0000;ooooo0_l0
001>ooooo`007?ooool00ol0003oooooooooo`1Fooooo`;o00000_ooool2o`0000;ooooo0_l0000@
ooooo`;o00002Oooool2o`0000?ooooo0ol00003ooooo`;o00001?oooolLo`000003ooooool0003o
000000Ko00000oooool8o`0000Kooooo0_l00006ooooo`;o00002?ooool2o`0001Wooooo0ol00003
ooooo`;o00001oooool2o`0004Wooooo000Looooo`;o0000Eoooool4o`0000Oooooo0_l00005oooo
o`;o00002Oooool2o`0000Oooooo1ol00003ooooo`;o00001?oooolTo`0000Cooooo1_l00003oooo
o`;o00000oooool2o`0000Kooooo0_l00008ooooo`;o00006_ooool2o`0000cooooo0_l00019oooo
o`007?ooool00ol0003oooooooooo`0kooooo`;o00006oooool3o`0000Kooooo0_l00005ooooo`;o
00001_ooool5o`000003ooooool0003o000000Cooooo1ol000000ooooooo0000o`000008ooooob;o
00001_ooool2o`0000?ooooo1?l00003ooooo`;o0000;_ooool3o`000003ooooool0003o0000057o
oooo000Looooo`03o`000?oooooooooo03_ooooo0_l0000Looooo`;o00005?ooool4o`0000?ooooo
0_l00005ooooo`Go000000Coooooo`000?l0003o00001ooooolSo`0000?ooooo0_l00006ooooo`;o
00002Oooool2o`0000_ooooo0ol0000Looooo`?o000000?oooooo`000?l00000DOooool001cooooo
00?o0000ooooooooool0<?ooool2o`0002Oooooo1?l00002ooooo`;o00001oooool2o`0000Cooooo
0ol00002ooooo`?o00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000003o`0000Sooooo
8_l00004ooooo`Ko000000Coooooo`000?l0003ooooo0_l00007ooooo`;o00002oooool3o`0001So
oooo2?l0001Cooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00009_ooool2o`000003oooo
ool0003o000000;ooooo0_l00007ooooo`;o00001?ooool8o`0000?ooooo1?l00004ooooo`Co0000
2?oooolRo`000004ooooool0003o0000ooooo`Ko000000Coooooo`000?l0003ooooo0_l000000ooo
oooo0000o`00000:ooooo`;o00007oooool:o`0000Gooooo0_l0001;ooooo`007?ooool00ol0003o
ooooooooo`1Hooooo`;o000000Coooooo`000?l0003o00003?ooool2o`0000Cooooo0ol00004oooo
o`;o00000_ooool3o`0000;ooooo1Ol00009ooooobKo00000oooool2o`0000Oooooo0_l0000:oooo
o`;o00007oooool4o`000004ooooool0003o0000ooooo`;o00000oooool4o`0000Cooooo0_l00015
ooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00001_ooool3o`0000cooooo0_l00006oooo
o`Oo00000oooool2o`0000;ooooo0ol000001?oooooo0000o`000?ooool2o`0000Gooooo8_l00002
ooooo`;o00001Oooool3o`0000Cooooo0_l0000Wooooo`;o00000oooool2o`0000[ooooo0ol00005
ooooo`;o0000AOooool001cooooo00?o0000ooooooooool0Doooool2o`000003ooooool0003o0000
00Cooooo0ol0000Cooooo`Go00001_ooool2o`0000;ooooo1Ol000000ooooooo0000o`000002o`00
00;ooooo7Ol000000ooooooo0000o`00000<ooooo`?o000000Coooooo`000?l0003ooooo0_l0000W
ooooo`;o00000oooool2o`0000_ooooo0_l00005ooooo`;o0000AOooool001cooooo00?o0000oooo
ooooool0<oooool2o`00027ooooo0_l00005ooooo`?o00001Oooool2o`000003ooooool0003o0000
00cooooo0_l00005ooooo`Co000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00000_oooolM
o`0000;ooooo0_l00006ooooo`;o00001oooool2o`0000?ooooo0_l0000=ooooo`;o00009?ooool2
o`00053ooooo000Looooo`03o`000?oooooooooo03?ooooo0_l0000Pooooo`;o00001oooool2o`00
00Gooooo0_l000000ooooooo0000o`00000<ooooo`;o00001oooool5o`000004ooooool0003o0000
o`0000;ooooo0_l00006ooooo`Go000000?oooooo`000?l000002_l00002ooooo`Co000000Cooooo
o`000?l0003o00000_ooool2o`0000;ooooo0_l0000<ooooo`;o00003Oooool2o`0001Cooooo0_l0
0002ooooo`Ko00001_ooool2o`00053ooooo000Looooo`03o`000?oooooooooo05Gooooo0_l00000
1?oooooo0000o`000?l00007ooooo`;o00001?ooool2o`000003ooooool0003o000000;o00001ooo
ool2o`0000Kooooo1_l00002ooooo`;o000000Coooooo`000?l0003o00001OoooolFo`0000Cooooo
0_l00003ooooo`;o00003?ooool2o`0002Oooooo2_l00002ooooo`;o0000E?ooool001cooooo00?o
0000ooooooooool0@oooool2o`0001?ooooo0ol00003ooooo`Ko00001?ooool2o`000003ooooool0
003o000000;o00001oooool4o`0000Cooooo1?l00004ooooo`;o000000?oooooo`000?l000000_oo
ool2o`0000;ooooo2?l00003ooooo`_o00001oooool2o`0000kooooo0_l0000Yooooo`;o000000?o
ooooo`000?l000001Oooool2o`0005Cooooo000Looooo`03o`000?oooooooooo04?ooooo0_l0000C
ooooo`;o00001?ooool5o`0000_ooooo0_l00008ooooo`;o00003?ooool2o`0000Gooooo0_l00003
ooooo`?o000000Coooooo`000?l0003o00000oooool3o`0000Cooooo0_l00006ooooo`;o000000?o
ooooo`000?l000001?ooool2o`0000Wooooo0_l0000[ooooo`;o0000Foooool001cooooo00?o0000
ooooooooool0H?ooool3o`0000Gooooo1Ol000000ooooooo0000o`00000Dooooo`;o000000?ooooo
o`000?l000002Oooool5o`0000?ooooo0_l00003ooooo`Go00001oooool2o`0000Oooooo0_l00008
ooooo`?o00002?ooool2o`0000Cooooo0_l0001hooooo`007?ooool00ol0003oooooooooo`1Hoooo
o`;o00001?ooool4o`0000?ooooo0_l000000ooooooo0000o`000004o`0001?ooooo0_l000000ooo
oooo0000o`000003o`000003ooooool0003o000000Sooooo0ol00003ooooo`;o00000oooool5o`00
0004ooooool0003o0000ooooo`?o00001Oooool4o`0000[ooooo0ol00003ooooo`;o00000_ooool5
o`0000;ooooo0_l0000Nooooo`;o0000F?ooool001cooooo00?o0000ooooooooool0F?ooool2o`00
00Cooooo1?l00003ooooo`;o00001Oooool2o`0000kooooo0ol00002ooooo`;o00000oooool3o`00
0003ooooool0003o000000;o00002_ooool3o`0000?ooooo1Ol00002ooooo`So00000_ooool5o`00
00Wooooo1?l00003ooooo`;o00000_ooool2o`000003ooooool0003o0000023ooooo1?l0001Hoooo
o`007?ooool2o`0004Oooooo0_l0000Aooooo`;o00001Oooool3o`0000oooooo0_l00008ooooo`?o
00002?ooool2o`0000?ooooo0_l0000:ooooo`Co00000_ooool6o`0000;ooooo0ol00002ooooo`;o
00000_ooool5o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000000oooool4o`0000So
oooo0_l0000Mooooo`Co0000F?ooool001cooooo00?o0000ooooooooool0>Oooool2o`0000_ooooo
0_l0000Aooooo`;o00000_ooool2o`0000;ooooo0_l00005ooooo`?o00000_ooool2o`0000?ooooo
0_l00008ooooo`?o00003oooool3o`0000Wooooo0_l00006ooooo`;o00002oooool4o`0000?ooooo
0_l00002ooooo`;o00001?ooool4o`0000[ooooo0_l0000Looooo`Go0000F?ooool001cooooo00?o
0000ooooooooool0>Oooool2o`00023ooooo1Ol00008ooooo`?o00000_ooool2o`0000gooooo0ol0
000?ooooo`?o00001oooool2o`0000Sooooo0_l0000Aooooo`;o00002Oooool2o`0000Gooooo0_l0
000Sooooo`Co0000FOooool001cooooo00?o0000ooooooooool0>_ooool2o`0001oooooo1Ol0000M
ooooo`;o00006Oooool2o`0000Sooooo0_l00002ooooo`;o00001Oooool2o`0000Kooooo0_l0000@
ooooo`;o00000oooool2o`0001Oooooo1?l0001Pooooo`007?ooool00ol0003oooooooooo`0joooo
o`;o00003Oooool2o`00013ooooo0_l000000ooooooo0000o`000002ooooo`;o000000Coooooo`00
0?l0003ooooo0_l0000Cooooo`?o00009_ooool2o`0000Gooooo0ol0000;ooooo`?o00003Oooool3
o`00013ooooo1?l00003ooooo`Co00003Oooool2o`00057ooooo000Looooo`03o`000?oooooooooo
03gooooo0_l0000:ooooo`;o00004?ooool2o`000003ooooool0003o000000;ooooo0_l000001?oo
oooo0000o`000?ooool2o`0000_ooooo0_l00007ooooo`;o00000oooool2o`0001Wooooo1?l0000;
ooooo`?o00001oooool3o`000005ooooool0003o0000o`000?ooool00_l0000:ooooo`;o00004Ooo
ool4o`0000Wooooo0_l00009ooooo`;o0000DOooool001cooooo00?o0000ooooooooool0?Oooool2
o`0001cooooo0_l000001?oooooo0000o`000?l00008ooooo`;o00002_ooool2o`0000Oooooo0_l0
0003ooooo`;o00002Oooool2o`0000Oooooo0_l00005ooooo`Co00002oooool2o`0000Sooooo0ol0
00000ooooooo0000o`000004o`0000;ooooo0_l0000Rooooo`;o00000_ooool2o`0005cooooo000L
ooooo`03o`000?oooooooooo05_ooooo0_l000001?oooooo0000o`000?l00008ooooo`;o00003?oo
ool2o`0000Gooooo0_l00004ooooo`;o00002?ooool2o`0000Oooooo0_l00006ooooo`Ko00004_oo
ool3o`0000?ooooo0ol00003ooooo`;o00008_ooool2o`00063ooooo000Looooo`03o`000?oooooo
oooo05kooooo0_l0000Gooooo`;o000000?oooooo`000?l000002?ooool2o`0000Kooooo0_l0000A
ooooo`;o000000Coooooo`000?l0003o00003oooool2o`000004ooooool0003o0000o`0000Gooooo
0_l0000`ooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0N_ooool2o`0000Wooooo0_l0
0005ooooo`;o00005oooool5o`0000Cooooo1Ol000001?oooooo0000o`000?l00008ooooo`;o0000
0_ooool2o`0001cooooo0_l00008ooooo`;o00001?ooool2o`0005Kooooo000Looooo`03o`000?oo
oooooooo05oooooo0_l000000ooooooo0000o`00000Qooooo`;o000000?oooooo`000?l000006ooo
ool5o`0000;ooooo1ol00002ooooo`;o00000_ooool2o`0000Kooooo1?l0000Kooooo`?o000000?o
ooooo`000?l000001Oooool2o`0005cooooo000Looooo`03o`000?oooooooooo04oooooo0_l0000;
ooooo`;o000000?oooooo`000?l000001Ol0000Oooooo`;o000000?oooooo`000?l000008_ooool7
o`0000Kooooo0_l00006ooooo`;o00005_ooool2o`0000Gooooo0_l00002ooooo`;o0000Hoooool0
01cooooo00?o0000ooooooooool0Coooool3o`0000[ooooo0_l00002ooooo`Ko000000?oooooo`00
0?l000007?ooool2o`0000;ooooo0_l0000Qooooo`Oo00009_ooool2o`0006kooooo000Looooo`03
o`000?oooooooooo053ooooo0_l0000>ooooo`Wo00005_ooool2o`0000Cooooo0_l00002ooooo`;o
00005Oooool2o`0000;ooooo0_l00006ooooo`Oo000000?oooooo`000?l000003?ooool2o`0001Wo
oooo0_l00002ooooo`;o0000I_ooool001cooooo00?o0000ooooooooool0@_ooool2o`00027ooooo
0_l0000Hooooo`;o00001?ooool2o`0000Kooooo0_l0000Aooooo`;o00000_ooool2o`0000Wooooo
0_l00002ooooo`Co00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000Iooooo`;o0000
0_ooool2o`0000Cooooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`12ooooo`;o0000BOoo
ool3o`0000;ooooo0_l0000@ooooo`;o00003Oooool4o`0000Cooooo0_l00002ooooo`;o00009_oo
ool2o`000003ooooool0003o000005gooooo000Looooo`;o0000E_ooool2o`0003Kooooo2Ol0000N
ooooo`;o00002Oooool2o`0002Wooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1Eoooo
o`?o00006Oooool2o`0000Kooooo0ol00003ooooo`;o00000_ooool2o`0000Oooooo0_l000000ooo
oooo0000o`000002o`000003ooooool0003o000001Sooooo0_l00004ooooo`;o00001_ooool3o`00
017ooooo0_l000000ooooooo0000o`000005ooooo`;o0000KOooool001cooooo00?o0000oooooooo
ool0E_ooool2o`0000gooooo0_l00004ooooo`;o00001?ooool2o`0000Kooooo0ol00003ooooo`;o
00000_ooool2o`0000Gooooo1?l000000ooooooo0000o`000003ooooo`;o00006?ooool2o`0000co
oooo0ol0000Aooooo`;o000000?oooooo`000?l000001Oooool2o`0000[ooooo0_l0001Qooooo`00
7?ooool00ol0003oooooooooo`1Uooooo`;o00001?ooool2o`0000Kooooo0_l00004ooooo`;o0000
1_ooool2o`0000Oooooo0_l000000ooooooo0000o`000009ooooo`Go00003Oooool2o`0001Cooooo
1?l00009ooooo`;o00004?ooool2o`0000Gooooo0_l0001Qooooo`007?ooool00ol0003ooooooooo
o`1Gooooo`;o00006_ooool2o`0000Cooooo0_l00006ooooo`Co00002?ooool2o`0000Kooooo0_l0
00000ooooooo0000o`000003o`0000Oooooo0_l00004ooooo`;o00004_ooool6o`0000Wooooo0_l0
0006ooooo`?o00001oooool2o`0000Gooooo0_l0001Qooooo`007?ooool00ol0003oooooooooo`1G
ooooo`?o00004Oooool2o`0001Kooooo0_l0000:ooooo`?o00000oooool2o`0000?ooooo0_l00008
ooooo`;o00003Oooool2o`0000Wooooo0_l0000Eooooo`?o00001oooool2o`0006Sooooo000Loooo
o`03o`000?oooooooooo05Sooooo0_l0000Aooooo`;o00008_ooool3o`0001Gooooo0_l00007oooo
o`;o000000Coooooo`000?l0003o0000;?ooool2o`0006Gooooo000Looooo`03o`000?oooooooooo
07Sooooo0_l0000Eooooo`;o00001_ooool2o`0000Cooooo0_l00002ooooo`Co00000_ooool2o`00
00Oooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Wooooo0_l0000Joooo
o`;o0000IOooool001cooooo00?o0000ooooooooool0Ioooool2o`0000Cooooo0_l000000ooooooo
0000o`000006ooooo`;o00003_ooool2o`0000Wooooo0_l00002ooooo`;o00000oooool3o`0000;o
oooo1?l0000Booooo`;o00000_ooool2o`0000Wooooo0_l00021ooooo`007?ooool00ol0003ooooo
ooooo`1Wooooo`?o00000oooool2o`000003ooooool0003o000001Kooooo0_l00009ooooo`Co0000
1Oooool5o`0002Cooooo0_l00003ooooo`;o00003Oooool3o`0006gooooo000Looooo`03o`000?oo
oooooooo06Sooooo0_l00005ooooo`?o00003_ooool2o`0000;ooooo0_l00002ooooo`;o00002ooo
ool2o`0000Oooooo0ol00007ooooo`;o00006oooool2o`0000?ooooo0_l0000=ooooo`?o0000KOoo
ool001cooooo00?o0000ooooooooool0K?ooool2o`000004ooooool0003o0000o`0000kooooo0_l0
0002ooooo`;o00005oooool8o`0000?ooooo0ol0002Nooooo`007?ooool00ol0003oooooooooo`1/
ooooo`;o00000_ooool2o`0000gooooo0_l0000:ooooo`Go00003Oooool2o`0000;ooooo1?l00004
ooooo`Co000000?oooooo`000?l000003Oooool2o`0000Gooooo0_l0000Cooooo`;o0000K_ooool0
01cooooo00?o0000ooooooooool0Ooooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool5
o`0001;ooooo0_l00007ooooo`;o000000?oooooo`000?l000003Oooool3o`0000;ooooo1?l00007
ooooo`;o00002_ooool2o`0000Kooooo0_l0001Vooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^
k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0
L_ooool2o`00017ooooo1Ol00008ooooo`;o00001_ooool2o`000003ooooool0003o000001Gooooo
0_l000000ooooooo0000o`000002o`0000?ooooo0_l00002ooooo`;o00002Oooool2o`0001;ooooo
0_l0001Vooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7o
V9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0L_ooool2o`0001;ooooo0_l000000ooo
oooo0000o`000007ooooo`;o00001_ooool5o`0000_ooooo0ol00007ooooo`;o000000?oooooo`00
0?l000000_l0000Gooooo`;o0000MOooool00003ooooool@413ooooo00;ooooo00?o410@oooooooo
ool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0Loooool2o`00
00Oooooo0_l0000;ooooo`;o00004Oooool5o`0000Wooooo1Ol0000:ooooo`;o00004_ooool2o`00
00?ooooo0ol0001dooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05
oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`0007?ooooo0_l00007ooooo`;o00007oooool4o`00
00cooooo0_l0000Kooooo`;o000000?oooooo`000?l000001?ooool2o`0000?ooooo0_l0001_oooo
o`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05olc<c?l0003o0000o`00
0?o<c<`01_ooool00ol0003oooooooooo`1Fooooo`;o0000;oooool2o`0000Oooooo0_l00006oooo
o`;o00001oooool3o`0000Cooooo0_l00002ooooo`;o00002_ooool2o`00013ooooo0_l0000<oooo
o`;o0000Koooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol@413o
^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0E_ooool2o`0002Oooooo1?l00004oooo
o`;o00001oooool2o`0000Kooooo0_l00007ooooo`Go00000_ooool3o`000003ooooool0003o0000
00Oooooo0_l000000ooooooo0000o`00000@ooooo`;o00002oooool2o`00073ooooo00001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oo
oooooooo07oooooo1?l0000Cooooo`;o00002oooool5o`000004ooooool0003o0000o`0000Wooooo
0_l0000=ooooo`;o00004Oooool2o`00073ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_o
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo05Wooooo0_l0000Xoooo
o`;o00004?ooool3o`0000;ooooo0ol00009ooooo`;o00000_ooool3o`0000;ooooo0_l00008oooo
o`;o00001Oooool3o`000003ooooool0003o000000Kooooo0_l00005ooooo`;o0000M?ooool001co
oooo00?o0000ooooooooool0FOooool2o`0002Sooooo0_l00004ooooo`;o00002_ooool2o`0000?o
oooo0ol0000>ooooo`;o00000_ooool3o`0000;ooooo0_l00002ooooo`?o00001Oooool3o`0000Wo
oooo0_l00005ooooo`;o0000M?ooool001cooooo00?o0000ooooooooool0QOooool2o`000004oooo
ool0003o0000o`0000[ooooo0_l0000Iooooo`;o00000_ooool2o`0000;ooooo0ol0002>ooooo`00
7?ooool00ol0003oooooooooo`25ooooo`;o000000?oooooo`000?l000002oooool6o`0001Wooooo
0_l00003ooooo`;o0000S_ooool001cooooo00?o0000ooooooooool0UOooool6o`0000Kooooo0_l0
000Aooooo`;o0000Toooool001cooooo00?o0000ooooooooool0T?ooool2o`0000?ooooo0_l0000:
ooooo`;o0000Y_ooool001cooooo00?o0000ooooooooool0T?ooool2o`0000?ooooo0_l0000;oooo
o`Co0000Xoooool001cooooo00?o0000ooooooooool0X_ooool4o`000:?ooooo000Looooo`03o`00
0?oooooooooo06?ooooo0_l0000mooooo`;o0000YOooool001cooooo00?o0000ooooooooool0Hooo
ool2o`000003ooooool0003o0000037ooooo0_l00007ooooo`;o00000_ooool2o`000:7ooooo000L
ooooo`03o`000?oooooooooo06Kooooo0_l0000aooooo`;o00002oooool2o`0000Kooooo0_l0002I
ooooo`007?ooool00ol0003oooooooooo`2^ooooo`;o0000VOooool001cooooo0_l0003ooooood_o
oooo000Looooo`03o`000?oooooooooo06cooooo0_l0003Kooooo`007?ooool00ol0003ooooooooo
o`1/ooooo`;o0000foooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`1eooooo`;o0000d_oo
ool001cooooo00?o0000ooooooooool0MOooool2o`000=;ooooo000Looooo`03o`000?oooooooooo
07Sooooo0_l0003?ooooo`007?ooool00ol0003oooooooooo`1hooooo`;o0000coooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0P_ooool2o`00
0<Gooooo000Looooo`03o`000?oooooooooo08;ooooo0_l00035ooooo`007?ooool2o`000?oooooo
Boooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2:
ooooo`;o0000_Oooool001cooooo00?o0000ooooooooool0R_ooool2o`000;gooooo000Looooo`03
o`000?oooooooooo08oooooo0_l0000@ooooo`;o0000Y_ooool001cooooo00?o0000ooooooooool0
Soooool2o`0000[ooooo0_l00004ooooo`;o00000_ooool2o`000:;ooooo000Looooo`03o`000?oo
oooooooo09Cooooo0_l00002ooooo`;o000000?oooooo`000?l000002?ooool2o`000:;ooooo000L
ooooo`03o`000?oooooooooo09Cooooo0_l00002ooooo`;o0000[oooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Booooo`Co000000?o410@ooooooooool00oooool00ol0003ooooo
ooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooo
oom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`?o0000oooooom:ooooo`005?ooool00ol0
003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo
00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000B
ooooo`03oeEEEOmVIVKo00000?ooooooE?ooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00:Gooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0Fooooo`05odA4
A?l0003o0000oc8b<_oMgMd00_ooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_l000000ol@
413oooooooooo`2>ooooo`00Y_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l0000=oooo
o`09ogMgMolb<S;oooooooooool@413o^[ZjoooooomgMgOo<S8b00Kooooo00?o0000ooooooooool0
Soooool00:Kooooo00Go0000ooooooooooooooooo`00000Mooooo`03o`000?oooooooooo00Cooooo
00Co0000oooooooooooooooo1Ol0002@ooooo`00Y_ooool01Ol0003ooooooooooooooooo000000Wo
oooo1_l0000=ooooo`03ogMgMolb<S;ooooo00Cooooo00?oZJVYoa0@4?ooool00_ooool01?m4A4Co
gMgMooooool0002Aooooo`00Y_ooool01Ol0003oQhN7oooooonYZJWo000001Wooooo00Go0000ob4Q
8Ol0003o<S8bolc<c004ooooo`03oa0@4?l0003o^[Zj00?ooooo00CogMgMoeEEEOoooooo0000TOoo
ool00:Gooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Gooooo`03o`000?oooooo
oooo00Oooooo00?o^[Zjob4Q8Oooool00oooool00omgMgOoc<c<o`00002Aooooo`00a?ooool00ol0
003oooooooooo`04ooooo`05oa0@4?nHV9SooooookZj^_l000001?ooool00oo^k^koA4A4o`00002A
ooooo`00a?ooool4o`0000?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@05ooooo`03ogMgMol0003o
oooo093ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(540) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.64419 .53401 Mdot
.68699 .54086 Mdot
.38647 .34544 Mdot
.49913 .62149 Mdot
.32432 .51903 Mdot
.36456 .37109 Mdot
.53461 .29896 Mdot
.53385 .33476 Mdot
.37591 .36802 Mdot
.55783 .73986 Mdot
.55819 .31344 Mdot
.46818 .69929 Mdot
.54276 .31042 Mdot
.46194 .64027 Mdot
.59337 .44401 Mdot
.39533 .60116 Mdot
.68983 .58567 Mdot
.27711 .54231 Mdot
.39483 .59996 Mdot
.37693 .34508 Mdot
.37053 .59819 Mdot
.46285 .62744 Mdot
.70186 .57622 Mdot
.46127 .63643 Mdot
.50547 .65422 Mdot
.67995 .54693 Mdot
.65033 .52999 Mdot
.52186 .63365 Mdot
.51548 .60274 Mdot
.5491 .32302 Mdot
.25323 .34542 Mdot
.82459 .60517 Mdot
.5254 .66187 Mdot
.72316 .66665 Mdot
.53446 .33702 Mdot
.52846 .21072 Mdot
.38788 .38722 Mdot
.52265 .32532 Mdot
.55136 .33815 Mdot
.54697 .34216 Mdot
.5286 .29827 Mdot
.66987 .54432 Mdot
.57243 .32117 Mdot
.41976 .33991 Mdot
.46617 .66547 Mdot
.77576 .52857 Mdot
.27465 .28687 Mdot
.52112 .62015 Mdot
.63801 .56001 Mdot
.35804 .34685 Mdot
.27521 .69019 Mdot
.52085 .29026 Mdot
.6634 .45409 Mdot
.3236 .84098 Mdot
.55242 .3131 Mdot
.50591 .61308 Mdot
.35959 .35624 Mdot
.4845 .62403 Mdot
.48216 .6018 Mdot
.71955 .64732 Mdot
.45503 .61371 Mdot
.29405 .50616 Mdot
.6841 .52197 Mdot
.39119 .41134 Mdot
.37086 .36517 Mdot
.5216 .30569 Mdot
.70559 .54498 Mdot
.53297 .31577 Mdot
.51132 .58506 Mdot
.36537 .34095 Mdot
.51631 .61329 Mdot
.55441 .32082 Mdot
.70263 .5482 Mdot
.47137 .67046 Mdot
.74288 .46406 Mdot
.53707 .37146 Mdot
.34161 .44822 Mdot
.67403 .75165 Mdot
.31659 .76417 Mdot
.30761 .35084 Mdot
.45224 .65019 Mdot
.23426 .71063 Mdot
.58493 .41174 Mdot
.68243 .53454 Mdot
.73234 .53831 Mdot
.75644 .33312 Mdot
.52453 .61564 Mdot
.3786 .49095 Mdot
.48639 .68696 Mdot
.50538 .50028 Mdot
.38137 .36707 Mdot
.69489 .55591 Mdot
.46387 .66634 Mdot
.48042 .6828 Mdot
.5808 .65653 Mdot
.49629 .5874 Mdot
.48714 .6459 Mdot
.69732 .51377 Mdot
.56049 .29433 Mdot
.53203 .6907 Mdot
.23486 .48866 Mdot
.65475 .44697 Mdot
.50132 .63403 Mdot
.36349 .39677 Mdot
.66487 .51678 Mdot
.48296 .65596 Mdot
.5298 .32222 Mdot
.45256 .63641 Mdot
.5407 .26061 Mdot
.68012 .58423 Mdot
.48226 .6846 Mdot
.31202 .47471 Mdot
.56555 .51201 Mdot
.65675 .57215 Mdot
.55971 .799 Mdot
.45495 .61637 Mdot
.46787 .61282 Mdot
.67684 .53515 Mdot
.39264 .36122 Mdot
.41841 .45473 Mdot
.70484 .56909 Mdot
.5526 .33949 Mdot
.64963 .57903 Mdot
.44775 .68286 Mdot
.39108 .35844 Mdot
.64916 .45429 Mdot
.65821 .44918 Mdot
.25351 .55407 Mdot
.47023 .67265 Mdot
.59316 .52971 Mdot
.35888 .38567 Mdot
.67225 .53988 Mdot
.53781 .31949 Mdot
.46979 .59663 Mdot
.65466 .55914 Mdot
.56057 .3307 Mdot
.28386 .52019 Mdot
.32417 .522 Mdot
.64565 .55032 Mdot
.44267 .75253 Mdot
.52492 .27856 Mdot
.54958 .34394 Mdot
.27582 .68423 Mdot
.67583 .5319 Mdot
.30843 .51661 Mdot
.57067 .31132 Mdot
.32462 .62897 Mdot
.44639 .60746 Mdot
.25005 .59913 Mdot
.17733 .62863 Mdot
.27519 .68754 Mdot
.77954 .64018 Mdot
.32009 .48134 Mdot
.5715 .31192 Mdot
.51416 .62631 Mdot
.66438 .55824 Mdot
.65851 .5507 Mdot
.47459 .68026 Mdot
.49614 .66863 Mdot
.46673 .65546 Mdot
.46343 .60023 Mdot
.45984 .18648 Mdot
.45662 .65794 Mdot
.61989 .32155 Mdot
.65883 .5653 Mdot
.49217 .66509 Mdot
.36356 .40539 Mdot
.41569 .62693 Mdot
.52474 .32699 Mdot
.48794 .60371 Mdot
.50287 .66272 Mdot
.42704 .61307 Mdot
.57134 .31948 Mdot
.74656 .42769 Mdot
.39001 .8074 Mdot
.54991 .2206 Mdot
.67899 .43548 Mdot
.35107 .37667 Mdot
.43858 .63549 Mdot
.31642 .49223 Mdot
.48136 .70674 Mdot
.47121 .60508 Mdot
.2745 .6967 Mdot
.50559 .66766 Mdot
.74157 .68968 Mdot
.54764 .66968 Mdot
.74373 .30856 Mdot
.63419 .29659 Mdot
.46418 .60389 Mdot
.52115 .75584 Mdot
.24716 .57864 Mdot
.21908 .37305 Mdot
.54339 .32268 Mdot
.36156 .41048 Mdot
.3946 .3707 Mdot
.53997 .3471 Mdot
.54696 .6017 Mdot
.56263 .74674 Mdot
.49382 .58242 Mdot
.64814 .4526 Mdot
.7132 .59527 Mdot
.32273 .49201 Mdot
.64489 .54985 Mdot
.25628 .73887 Mdot
.38304 .51706 Mdot
.3229 .34749 Mdot
.28299 .54287 Mdot
.34012 .36068 Mdot
.63065 .44364 Mdot
.31497 .50769 Mdot
.49104 .63318 Mdot
.6585 .57996 Mdot
.24367 .57944 Mdot
.40542 .60088 Mdot
.5872 .144 Mdot
.68879 .53302 Mdot
.53338 .46933 Mdot
.54726 .31644 Mdot
.39162 .40682 Mdot
.52445 .61659 Mdot
.476 .63762 Mdot
.67266 .52039 Mdot
.51938 .61268 Mdot
.42331 .48379 Mdot
.50639 .66208 Mdot
.36776 .42334 Mdot
.27314 .49404 Mdot
.54004 .25645 Mdot
.2959 .55328 Mdot
.70505 .55689 Mdot
.5759 .37207 Mdot
.36365 .40084 Mdot
.54944 .55473 Mdot
.54165 .32972 Mdot
.28273 .51178 Mdot
.38044 .39414 Mdot
.30334 .47393 Mdot
.44576 .66583 Mdot
.38886 .37855 Mdot
.29468 .51767 Mdot
.48168 .37098 Mdot
.48798 .64638 Mdot
.27851 .61597 Mdot
.56395 .28482 Mdot
.64647 .53554 Mdot
.46014 .60814 Mdot
.64736 .45868 Mdot
.42225 .65364 Mdot
.58533 .50766 Mdot
.62443 .44213 Mdot
.6364 .4243 Mdot
.31553 .37043 Mdot
.30271 .52892 Mdot
.72468 .48024 Mdot
.45409 .43291 Mdot
.69227 .58523 Mdot
.4383 .65642 Mdot
.78765 .42594 Mdot
.56468 .28443 Mdot
.49103 .62936 Mdot
.73761 .31875 Mdot
.57124 .30962 Mdot
.48113 .61786 Mdot
.53232 .29189 Mdot
.6592 .55488 Mdot
.52596 .39559 Mdot
.63693 .57163 Mdot
.49724 .61865 Mdot
.54947 .28721 Mdot
.36776 .40881 Mdot
.67957 .54757 Mdot
.45468 .62964 Mdot
.45017 .65234 Mdot
.64345 .45003 Mdot
.48312 .67144 Mdot
.79906 .41091 Mdot
.52109 .62281 Mdot
.34274 .35402 Mdot
.5063 .58863 Mdot
.22875 .58332 Mdot
.32202 .52789 Mdot
.71596 .5603 Mdot
.62318 .43779 Mdot
.3823 .36279 Mdot
.50401 .38132 Mdot
.26308 .55306 Mdot
.45404 .64487 Mdot
.644 .43503 Mdot
.53343 .46358 Mdot
.52227 .31552 Mdot
.53181 .61787 Mdot
.4204 .46851 Mdot
.38162 .37794 Mdot
.63945 .45052 Mdot
.46956 .56481 Mdot
.63666 .53885 Mdot
.5086 .61559 Mdot
.38383 .39379 Mdot
.63538 .55019 Mdot
.48632 .5935 Mdot
.35879 .23516 Mdot
.65281 .45914 Mdot
.54951 .28132 Mdot
.59139 .59527 Mdot
.44592 .65573 Mdot
.39555 .37854 Mdot
.65322 .55417 Mdot
.55389 .29939 Mdot
.67942 .58047 Mdot
.23656 .56096 Mdot
.60513 .53205 Mdot
.45979 .2159 Mdot
.27278 .53787 Mdot
.73041 .74789 Mdot
.54391 .21879 Mdot
.58829 .556 Mdot
.36648 .44473 Mdot
.66965 .22595 Mdot
.37403 .39664 Mdot
.47387 .76189 Mdot
.37483 .35658 Mdot
.50735 .62814 Mdot
.36718 .36939 Mdot
.80747 .39466 Mdot
.51622 .65248 Mdot
.34946 .36791 Mdot
.43608 .2143 Mdot
.50502 .67014 Mdot
.6552 .56495 Mdot
.81095 .55165 Mdot
.5853 .80146 Mdot
.40483 .7289 Mdot
.34963 .36212 Mdot
.46781 .77063 Mdot
.52405 .62724 Mdot
.40337 .59125 Mdot
.67033 .55676 Mdot
.44153 .68346 Mdot
.32639 .48163 Mdot
.31344 .47094 Mdot
.30604 .69428 Mdot
.61544 .80493 Mdot
.50247 .55009 Mdot
.6719 .54786 Mdot
.29997 .75185 Mdot
.74793 .46615 Mdot
.65793 .45841 Mdot
.54534 .33818 Mdot
.73811 .42515 Mdot
.46702 .56227 Mdot
.54559 .69198 Mdot
.45817 .46588 Mdot
.69674 .55607 Mdot
.47617 .26322 Mdot
.54975 .29577 Mdot
.47351 .7876 Mdot
.59895 .7172 Mdot
.46947 .65598 Mdot
.54188 .27463 Mdot
.53132 .68187 Mdot
.44448 .47108 Mdot
.26745 .61087 Mdot
.34821 .2793 Mdot
.49458 .63071 Mdot
.73519 .48255 Mdot
.47349 .60631 Mdot
.25553 .5832 Mdot
.49381 .62212 Mdot
.67517 .57904 Mdot
.51563 .56364 Mdot
.46019 .41109 Mdot
.47729 .80766 Mdot
.38611 .51267 Mdot
.31194 .52094 Mdot
.46485 .64003 Mdot
.4765 .64631 Mdot
.29127 .51058 Mdot
.69278 .56147 Mdot
.4327 .64365 Mdot
.28264 .27585 Mdot
.45724 .65993 Mdot
.51887 .29701 Mdot
.50826 .40713 Mdot
.73629 .70724 Mdot
.51264 .66416 Mdot
.64094 .53275 Mdot
.52419 .31293 Mdot
.554 .33027 Mdot
.50147 .55291 Mdot
.55844 .28006 Mdot
.51598 .62177 Mdot
.51069 .40782 Mdot
.69818 .57933 Mdot
.50302 .7014 Mdot
.69142 .56567 Mdot
.26701 .70939 Mdot
.57257 .29843 Mdot
.64036 .42985 Mdot
.45063 .76767 Mdot
.53919 .2991 Mdot
.41505 .53459 Mdot
.52825 .57782 Mdot
.43298 .58321 Mdot
.59908 .5676 Mdot
.3752 .4081 Mdot
.63255 .43107 Mdot
.55442 .30888 Mdot
.45845 .65904 Mdot
.49013 .65091 Mdot
.53418 .27595 Mdot
.67136 .64 Mdot
.25653 .34216 Mdot
.49644 .61464 Mdot
.68421 .57777 Mdot
.67192 .54109 Mdot
.43992 .60715 Mdot
.46684 .60716 Mdot
.34028 .38751 Mdot
.6434 .43388 Mdot
.62663 .43136 Mdot
.65457 .43756 Mdot
.35062 .42015 Mdot
.69477 .77749 Mdot
.54994 .34393 Mdot
.79139 .64204 Mdot
.74464 .3682 Mdot
.46582 .55027 Mdot
.39007 .38995 Mdot
.47574 .62732 Mdot
.49937 .64193 Mdot
.55364 .28798 Mdot
.5873 .8242 Mdot
.53012 .6603 Mdot
.65455 .52987 Mdot
.5234 .2874 Mdot
.48064 .70075 Mdot
.56214 .35684 Mdot
.29561 .48589 Mdot
.37099 .62323 Mdot
.54519 .27217 Mdot
.67596 .58262 Mdot
.54246 .2723 Mdot
.47355 .6499 Mdot
.45386 .57051 Mdot
.69757 .55405 Mdot
.28452 .53258 Mdot
.45222 .66694 Mdot
.48109 .61587 Mdot
.17587 .46693 Mdot
.74243 .46687 Mdot
.30283 .43526 Mdot
.50725 .64279 Mdot
.43859 .58555 Mdot
.27745 .52578 Mdot
.4397 .65158 Mdot
.5119 .59939 Mdot
.56335 .50757 Mdot
.53023 .26306 Mdot
.31948 .52036 Mdot
.46318 .79756 Mdot
.68322 .52975 Mdot
.79063 .39267 Mdot
.65483 .45145 Mdot
.55722 .25282 Mdot
.53156 .39434 Mdot
.63299 .43787 Mdot
.72692 .32158 Mdot
.55911 .2208 Mdot
.63801 .43268 Mdot
.39991 .39807 Mdot
.45865 .71953 Mdot
.51233 .59664 Mdot
.48624 .60696 Mdot
.30082 .52865 Mdot
.66075 .53364 Mdot
.62454 .32085 Mdot
.51472 .27824 Mdot
.46419 .62111 Mdot
.63073 .57212 Mdot
.74998 .32028 Mdot
.63502 .44633 Mdot
.31533 .48367 Mdot
.29394 .5361 Mdot
.47253 .60822 Mdot
.50373 .52242 Mdot
.67427 .54632 Mdot
.45479 .62961 Mdot
.44392 .61606 Mdot
.37422 .35179 Mdot
.65222 .57694 Mdot
.35858 .40284 Mdot
.62053 .43597 Mdot
.62561 .18758 Mdot
.17564 .42041 Mdot
.56771 .29594 Mdot
.50108 .24965 Mdot
.57205 .27581 Mdot
.36899 .26497 Mdot
.64201 .43246 Mdot
.45834 .62788 Mdot
.70886 .56179 Mdot
.45272 .63374 Mdot
.45972 .6629 Mdot
.47476 .65827 Mdot
.49992 .54906 Mdot
.26538 .69219 Mdot
.30553 .48969 Mdot
.52282 .59028 Mdot
.3366 .38156 Mdot
.74065 .31 Mdot
.80713 .50543 Mdot
.46949 .64247 Mdot
.46982 .61331 Mdot
.69602 .534 Mdot
.44527 .66668 Mdot
.52932 .32456 Mdot
.68303 .53226 Mdot
.49755 .63782 Mdot
.22549 .50966 Mdot
.43196 .63392 Mdot
.51066 .23636 Mdot
.54513 .27102 Mdot
.38866 .65987 Mdot
.45985 .57399 Mdot
.64053 .43114 Mdot
.63295 .43152 Mdot
.64104 .45819 Mdot
.52681 .28656 Mdot
.37698 .35309 Mdot
.39656 .33924 Mdot
.48475 .56664 Mdot
.51582 .62822 Mdot
.4474 .57472 Mdot
.3316 .40094 Mdot
.45055 .42747 Mdot
.74525 .5196 Mdot
.55029 .66393 Mdot
.34443 .41123 Mdot
.65042 .50717 Mdot
.50719 .8095 Mdot
.66995 .52874 Mdot
.3563 .44402 Mdot
.53797 .33253 Mdot
.31907 .47672 Mdot
.31343 .73358 Mdot
.70113 .57418 Mdot
.66818 .52131 Mdot
.34931 .37328 Mdot
.55401 .43863 Mdot
.41837 .90088 Mdot
.36338 .39204 Mdot
.33706 .45241 Mdot
.6723 .55375 Mdot
.52372 .66809 Mdot
.5351 .45979 Mdot
.55759 .46292 Mdot
.35653 .36347 Mdot
.4497 .65039 Mdot
.42483 .52494 Mdot
.34028 .3866 Mdot
.53382 .61753 Mdot
.34762 .36389 Mdot
.55004 .27814 Mdot
.35532 .38704 Mdot
.66351 .59354 Mdot
.46342 .6688 Mdot
.35179 .86119 Mdot
.58223 .40644 Mdot
.45065 .62478 Mdot
.52676 .2813 Mdot
.41143 .20774 Mdot
.47968 .64766 Mdot
.32547 .49277 Mdot
.33914 .40681 Mdot
.34185 .27071 Mdot
.5104 .60104 Mdot
.361 .36662 Mdot
.69431 .59254 Mdot
.36126 .4415 Mdot
.28608 .43805 Mdot
.62905 .431 Mdot
.65941 .55781 Mdot
.64289 .41901 Mdot
.53214 .33709 Mdot
.42457 .63621 Mdot
.43722 .62478 Mdot
.66578 .57241 Mdot
.49144 .36943 Mdot
.54139 .61763 Mdot
.45266 .65026 Mdot
.34293 .3909 Mdot
.33284 .38098 Mdot
.61176 .45822 Mdot
.36989 .40159 Mdot
.43951 .58572 Mdot
.66553 .57406 Mdot
.50602 .62217 Mdot
.65016 .55806 Mdot
.44098 .6595 Mdot
.67767 .47315 Mdot
.6652 .5299 Mdot
.55892 .5502 Mdot
.4775 .67569 Mdot
.65291 .61288 Mdot
.45028 .66115 Mdot
.49021 .63941 Mdot
.33588 .40491 Mdot
.30681 .5015 Mdot
.5258 .65251 Mdot
.57256 .3692 Mdot
.27687 .51048 Mdot
.75947 .62487 Mdot
.3916 .36061 Mdot
.28484 .52778 Mdot
.30497 .654 Mdot
.62334 .43793 Mdot
.29595 .49965 Mdot
.61959 .45048 Mdot
.56531 .29074 Mdot
.66792 .58729 Mdot
.49659 .67541 Mdot
.67081 .2202 Mdot
.25329 .3462 Mdot
.64361 .4473 Mdot
.46031 .60928 Mdot
.47897 .62913 Mdot
.6338 .54732 Mdot
.24839 .72689 Mdot
.3754 .42374 Mdot
.49638 .63229 Mdot
.70394 .56546 Mdot
.2095 .6763 Mdot
.3451 .3711 Mdot
.29991 .48984 Mdot
.56217 .27203 Mdot
.67057 .60448 Mdot
.63283 .42824 Mdot
.57281 .29895 Mdot
.33564 .43492 Mdot
.27536 .70455 Mdot
.5089 .60089 Mdot
.37917 .40308 Mdot
.27498 .68815 Mdot
.54431 .67399 Mdot
.56975 .33531 Mdot
.67049 .47634 Mdot
.69464 .55341 Mdot
.53091 .27837 Mdot
.31012 .52471 Mdot
.68571 .58553 Mdot
.69383 .56264 Mdot
.53743 .33551 Mdot
.63092 .26133 Mdot
.53709 .46687 Mdot
.51903 .31805 Mdot
.56063 .48822 Mdot
.27508 .6808 Mdot
.64744 .43407 Mdot
.31635 .48365 Mdot
.21571 .53875 Mdot
.67338 .54454 Mdot
.73941 .42534 Mdot
.27515 .69446 Mdot
.48753 .64533 Mdot
.29957 .52144 Mdot
.7534 .34038 Mdot
.54621 .25086 Mdot
.56277 .32732 Mdot
.3942 .4676 Mdot
.32112 .50445 Mdot
.43867 .61515 Mdot
.72159 .72562 Mdot
.48916 .67948 Mdot
.57172 .30326 Mdot
.44727 .47586 Mdot
.65229 .57612 Mdot
.52961 .33677 Mdot
.41692 .48533 Mdot
.50099 .6412 Mdot
.44814 .6198 Mdot
.29752 .56364 Mdot
.64746 .57506 Mdot
.63523 .42644 Mdot
.44954 .64221 Mdot
.48536 .62134 Mdot
.42573 .6269 Mdot
.43098 .76664 Mdot
.55002 .53165 Mdot
.49522 .63751 Mdot
.38496 .41057 Mdot
.4229 .59417 Mdot
.46894 .60029 Mdot
.63051 .55272 Mdot
.2263 .59563 Mdot
.62023 .43613 Mdot
.48781 .60882 Mdot
.4959 .61411 Mdot
.54547 .34039 Mdot
.53553 .46495 Mdot
.55934 .46535 Mdot
.34449 .35519 Mdot
.36678 .47159 Mdot
.48418 .58005 Mdot
.66229 .5639 Mdot
.32669 .47877 Mdot
.42741 .60443 Mdot
.66916 .52714 Mdot
.51365 .57858 Mdot
.33764 .37541 Mdot
.64196 .43597 Mdot
.56623 .62015 Mdot
.29719 .50519 Mdot
.52796 .27185 Mdot
.80199 .61906 Mdot
.35786 .40808 Mdot
.51401 .64275 Mdot
.3826 .32656 Mdot
.37266 .3853 Mdot
.64649 .44945 Mdot
.4118 .59177 Mdot
.66161 .55136 Mdot
.66138 .57903 Mdot
.25977 .65422 Mdot
.35835 .42261 Mdot
.16305 .53504 Mdot
.5522 .27817 Mdot
.5298 .61573 Mdot
.78826 .48551 Mdot
.65374 .5754 Mdot
.25429 .56567 Mdot
.28399 .52812 Mdot
.56299 .32663 Mdot
.62291 .42216 Mdot
.66037 .53001 Mdot
.64698 .56672 Mdot
.46362 .6656 Mdot
.46828 .63387 Mdot
.36083 .45182 Mdot
.24935 .58873 Mdot
.53239 .29235 Mdot
.30257 .48524 Mdot
.35154 .34788 Mdot
.50583 .63752 Mdot
.69118 .54235 Mdot
.7228 .71824 Mdot
.44459 .65339 Mdot
.33838 .37609 Mdot
.69018 .54691 Mdot
.29105 .49821 Mdot
.28825 .52218 Mdot
.48795 .64364 Mdot
.71688 .705 Mdot
.5367 .30137 Mdot
.65838 .57025 Mdot
.72306 .53269 Mdot
.51911 .59049 Mdot
.46772 .63942 Mdot
.50547 .69068 Mdot
.55806 .34407 Mdot
.56626 .63095 Mdot
.2743 .52767 Mdot
.65788 .54171 Mdot
.44998 .63158 Mdot
.29393 .50566 Mdot
.55151 .68515 Mdot
.63685 .43872 Mdot
.34623 .37122 Mdot
.32531 .48857 Mdot
.30371 .51291 Mdot
.27874 .50837 Mdot
.73763 .42781 Mdot
.6639 .51612 Mdot
.43658 .80792 Mdot
.45863 .66509 Mdot
.27511 .67797 Mdot
.44598 .6708 Mdot
.53665 .28372 Mdot
.36114 .41256 Mdot
.46341 .66126 Mdot
.45946 .66615 Mdot
.75711 .67159 Mdot
.38588 .61417 Mdot
.3785 .63112 Mdot
.67062 .58328 Mdot
.60183 .60402 Mdot
.3942 .38487 Mdot
.15874 .60507 Mdot
.83477 .51655 Mdot
.4898 .5829 Mdot
.55075 .43445 Mdot
.68298 .53293 Mdot
.56426 .32858 Mdot
.55091 .47719 Mdot
.57683 .25591 Mdot
.66354 .5366 Mdot
.50604 .63217 Mdot
.79271 .62632 Mdot
.28935 .48561 Mdot
.46783 .65361 Mdot
.53628 .32138 Mdot
.46731 .65452 Mdot
.52869 .28737 Mdot
.69799 .60636 Mdot
.56669 .4486 Mdot
.50836 .66494 Mdot
.50003 .58665 Mdot
.54947 .6771 Mdot
.46953 .63965 Mdot
.39624 .2914 Mdot
.68505 .55822 Mdot
.55067 .5503 Mdot
.4392 .60461 Mdot
.67383 .73291 Mdot
.43408 .62975 Mdot
.50799 .37085 Mdot
.43988 .62521 Mdot
.38419 .72003 Mdot
.44179 .61151 Mdot
.43864 .63349 Mdot
.55061 .29263 Mdot
.55462 .33787 Mdot
.7022 .59181 Mdot
.64065 .42643 Mdot
.74276 .30854 Mdot
.47584 .61443 Mdot
.33186 .39365 Mdot
.63788 .47869 Mdot
.30671 .50776 Mdot
.66247 .53978 Mdot
.12358 .48523 Mdot
.5247 .30517 Mdot
.39306 .40841 Mdot
.32128 .33151 Mdot
.39963 .38561 Mdot
.32942 .40665 Mdot
.63228 .60595 Mdot
.31314 .48056 Mdot
.43599 .62137 Mdot
.72637 .67338 Mdot
.7426 .47929 Mdot
.52075 .59617 Mdot
.39881 .33507 Mdot
.42568 .68692 Mdot
.26746 .67905 Mdot
.30426 .47153 Mdot
.32144 .48742 Mdot
.55361 .30313 Mdot
.38925 .34973 Mdot
.54382 .66949 Mdot
.28444 .5269 Mdot
.35816 .41145 Mdot
.66083 .44865 Mdot
.34208 .52697 Mdot
.66918 .54573 Mdot
.42506 .73935 Mdot
.78255 .51005 Mdot
.52665 .30086 Mdot
.56453 .37507 Mdot
.65867 .51054 Mdot
.7236 .56026 Mdot
.64675 .42883 Mdot
.33683 .38798 Mdot
.68601 .58746 Mdot
.46288 .66779 Mdot
.40563 .60059 Mdot
.47068 .60798 Mdot
.29411 .52893 Mdot
.44904 .61234 Mdot
.34093 .39717 Mdot
.53108 .30135 Mdot
.38242 .36967 Mdot
.53715 .29626 Mdot
.78677 .59942 Mdot
.47511 .60165 Mdot
.46582 .63727 Mdot
.52042 .41234 Mdot
.64462 .55793 Mdot
.71341 .66635 Mdot
.33586 .38532 Mdot
.36569 .35448 Mdot
.5049 .62426 Mdot
.7148 .5533 Mdot
.26855 .54423 Mdot
.53863 .44563 Mdot
.44071 .62192 Mdot
.6848 .55908 Mdot
.50623 .61762 Mdot
.37594 .24768 Mdot
.57881 .43947 Mdot
.67366 .58027 Mdot
.48039 .80965 Mdot
.47869 .67242 Mdot
.38686 .63225 Mdot
.39901 .6409 Mdot
.35962 .62545 Mdot
.53411 .63312 Mdot
.6904 .53477 Mdot
.48702 .60238 Mdot
.66722 .5636 Mdot
.37297 .39099 Mdot
.55481 .34285 Mdot
.66774 .56057 Mdot
.4842 .67906 Mdot
.82835 .53552 Mdot
.52692 .31115 Mdot
.46129 .65057 Mdot
.55767 .30928 Mdot
.65352 .58443 Mdot
.6402 .55557 Mdot
.61192 .44598 Mdot
.31705 .37623 Mdot
.52819 .31666 Mdot
.51676 .62599 Mdot
.74432 .44549 Mdot
.50648 .62175 Mdot
.36156 .47213 Mdot
.45262 .59748 Mdot
.51211 .59018 Mdot
.74458 .73648 Mdot
.50214 .37647 Mdot
.14511 .51944 Mdot
.50173 .31506 Mdot
.74786 .43444 Mdot
.73201 .57298 Mdot
.30523 .47111 Mdot
.48926 .26821 Mdot
.63101 .44951 Mdot
.38901 .40467 Mdot
.46148 .66157 Mdot
.77006 .57078 Mdot
.51809 .30544 Mdot
.3096 .49722 Mdot
.50651 .66667 Mdot
.38569 .34064 Mdot
.62148 .40116 Mdot
.57023 .31481 Mdot
.66785 .54415 Mdot
.64405 .54974 Mdot
.33698 .78065 Mdot
.45137 .62679 Mdot
.46503 .62987 Mdot
.52939 .3297 Mdot
.55111 .64978 Mdot
.28291 .49919 Mdot
.43813 .22285 Mdot
.53901 .32395 Mdot
.58289 .42924 Mdot
.67461 .58458 Mdot
.47761 .62864 Mdot
.5063 .40707 Mdot
.70513 .38264 Mdot
.56677 .69965 Mdot
.31067 .51786 Mdot
.33926 .56582 Mdot
.69034 .53458 Mdot
.53972 .32071 Mdot
.30276 .67959 Mdot
.46849 .68448 Mdot
.48094 .62773 Mdot
.32611 .57229 Mdot
.54128 .45103 Mdot
.35487 .48982 Mdot
.48305 .69313 Mdot
.51808 .46148 Mdot
.50443 .62609 Mdot
.49048 .65072 Mdot
.50985 .58452 Mdot
.48395 .59602 Mdot
.6812 .56219 Mdot
.60385 .79356 Mdot
.36094 .37582 Mdot
.52323 .74057 Mdot
.39195 .46082 Mdot
.52501 .6275 Mdot
.50374 .63591 Mdot
.5735 .77563 Mdot
.61155 .50741 Mdot
.68158 .55433 Mdot
.72059 .53172 Mdot
.54644 .34414 Mdot
.38605 .61261 Mdot
.35145 .42208 Mdot
.39843 .66564 Mdot
.37505 .37409 Mdot
.68533 .56042 Mdot
.3848 .35732 Mdot
.51047 .32086 Mdot
.37919 .40288 Mdot
.3588 .42055 Mdot
.5723 .28931 Mdot
.63876 .56553 Mdot
.43831 .6393 Mdot
.56941 .28624 Mdot
.2824 .56184 Mdot
.29361 .52867 Mdot
.61641 .45298 Mdot
.52428 .66791 Mdot
.38324 .62398 Mdot
.35572 .23767 Mdot
.38955 .37065 Mdot
.57955 .49276 Mdot
.66411 .53027 Mdot
.32519 .50219 Mdot
.677 .56377 Mdot
.37039 .76955 Mdot
.29699 .51289 Mdot
.61789 .45381 Mdot
.2961 .66923 Mdot
.58563 .3403 Mdot
.4189 .64703 Mdot
.59611 .5766 Mdot
.3769 .37551 Mdot
.51939 .29511 Mdot
.74752 .32902 Mdot
.47945 .66832 Mdot
.66582 .43994 Mdot
.72277 .54805 Mdot
.62382 .43636 Mdot
.53673 .3183 Mdot
.49734 .29642 Mdot
.45364 .62159 Mdot
.57004 .36026 Mdot
.49368 .58971 Mdot
.45474 .76787 Mdot
.36462 .46511 Mdot
.62026 .52283 Mdot
.51004 .61559 Mdot
.34022 .37853 Mdot
.50881 .61775 Mdot
.4561 .73742 Mdot
.2852 .68639 Mdot
.48068 .58586 Mdot
.59634 .5582 Mdot
.34581 .26017 Mdot
.69394 .54759 Mdot
.44674 .58306 Mdot
.64809 .44111 Mdot
.50097 .65324 Mdot
.7208 .22704 Mdot
.2981 .49981 Mdot
.31434 .44121 Mdot
.4797 .67841 Mdot
.45104 .63911 Mdot
.73265 .69111 Mdot
.60454 .58874 Mdot
.62082 .4231 Mdot
.48429 .63098 Mdot
.34498 .57275 Mdot
.55418 .29666 Mdot
.48097 .59404 Mdot
.4838 .60443 Mdot
.18735 .43846 Mdot
.55639 .2974 Mdot
.39176 .37707 Mdot
.62378 .43998 Mdot
.34425 .35818 Mdot
.32811 .4673 Mdot
.53123 .49214 Mdot
.25839 .57237 Mdot
.58106 .44168 Mdot
.32083 .50938 Mdot
.52666 .62263 Mdot
.71572 .5191 Mdot
.44505 .6329 Mdot
.32077 .49306 Mdot
.5495 .32279 Mdot
.67878 .56016 Mdot
.43741 .74869 Mdot
.64898 .45185 Mdot
.52743 .60115 Mdot
.29828 .47362 Mdot
.66482 .55656 Mdot
.64226 .36168 Mdot
.66733 .53233 Mdot
.54226 .29547 Mdot
.53504 .34413 Mdot
.30181 .50841 Mdot
.67968 .56371 Mdot
.35298 .35316 Mdot
.50084 .31764 Mdot
.46042 .59443 Mdot
.51334 .33353 Mdot
.70867 .58237 Mdot
.65289 .52782 Mdot
.71231 .56345 Mdot
.4866 .5984 Mdot
.5457 .44691 Mdot
.45121 .67756 Mdot
.52657 .3185 Mdot
.39843 .37362 Mdot
.25386 .60696 Mdot
.71859 .68754 Mdot
.58123 .4258 Mdot
.52805 .64842 Mdot
.45357 .61079 Mdot
.47209 .60854 Mdot
.5021 .61051 Mdot
.44206 .22342 Mdot
.47587 .60171 Mdot
.54608 .28698 Mdot
.36931 .38063 Mdot
.45601 .61317 Mdot
.64648 .43806 Mdot
.44978 .43331 Mdot
.32715 .47963 Mdot
.38036 .6958 Mdot
.80538 .47793 Mdot
.66694 .55683 Mdot
.37688 .40083 Mdot
.38046 .35224 Mdot
.28383 .51997 Mdot
.57099 .29363 Mdot
.65996 .5349 Mdot
.36104 .68208 Mdot
.27714 .50436 Mdot
.48827 .60951 Mdot
.51403 .40927 Mdot
.4932 .80884 Mdot
.52124 .65055 Mdot
.48143 .65026 Mdot
.63007 .42619 Mdot
.39142 .4093 Mdot
.74581 .2724 Mdot
.6318 .27911 Mdot
.30543 .50313 Mdot
.29271 .4919 Mdot
.70797 .55178 Mdot
.53007 .61117 Mdot
.53447 .30435 Mdot
.52636 .46351 Mdot
.36681 .22315 Mdot
.77906 .36469 Mdot
.36853 .26741 Mdot
.43211 .63634 Mdot
.62232 .77285 Mdot
.43222 .607 Mdot
.66446 .51671 Mdot
.71341 .55677 Mdot
.67662 .55054 Mdot
.54988 .2942 Mdot
.27795 .71293 Mdot
.546 .28587 Mdot
.80824 .48016 Mdot
.70112 .55694 Mdot
.479 .38419 Mdot
.35755 .35674 Mdot
.4281 .5755 Mdot
.31486 .48097 Mdot
.25842 .49646 Mdot
.44646 .58104 Mdot
.49927 .52473 Mdot
.39013 .38967 Mdot
.6384 .54972 Mdot
.5292 .57984 Mdot
.73287 .29527 Mdot
.55619 .43765 Mdot
.2885 .28039 Mdot
.59592 .61664 Mdot
.29202 .5111 Mdot
.54066 .74969 Mdot
.2835 .49523 Mdot
.56594 .32231 Mdot
.47632 .67014 Mdot
.46911 .67775 Mdot
.49626 .62846 Mdot
.4923 .59871 Mdot
.55466 .31007 Mdot
.43946 .59982 Mdot
.22923 .58512 Mdot
.65631 .45398 Mdot
.4661 .37714 Mdot
.28697 .51494 Mdot
.54314 .2772 Mdot
.37103 .38414 Mdot
.64565 .4271 Mdot
.28652 .55602 Mdot
.4311 .61595 Mdot
.45407 .66185 Mdot
.65886 .4504 Mdot
.55395 .62054 Mdot
.46331 .56279 Mdot
.36187 .37086 Mdot
.45199 .45695 Mdot
.30494 .53113 Mdot
.31571 .47644 Mdot
.53977 .27422 Mdot
.67721 .56397 Mdot
.2914 .53202 Mdot
.38846 .34758 Mdot
.49432 .59281 Mdot
.50205 .58656 Mdot
.70825 .58286 Mdot
.27462 .6943 Mdot
.32496 .47071 Mdot
.55229 .66402 Mdot
.65086 .54886 Mdot
.719 .54013 Mdot
.48365 .63315 Mdot
.44611 .68941 Mdot
.66007 .52022 Mdot
.2853 .50428 Mdot
.54785 .27458 Mdot
.49826 .38797 Mdot
.54253 .28378 Mdot
.65456 .55103 Mdot
.41606 .5961 Mdot
.65062 .57833 Mdot
.48361 .67012 Mdot
.14708 .63966 Mdot
.4602 .60415 Mdot
.48107 .53917 Mdot
.36775 .52741 Mdot
.34633 .3656 Mdot
.3439 .36964 Mdot
.64346 .43648 Mdot
.67359 .52799 Mdot
.4247 .60672 Mdot
.30712 .48044 Mdot
.7477 .43626 Mdot
.61915 .53514 Mdot
.35127 .41821 Mdot
.37847 .41925 Mdot
.55034 .32104 Mdot
.43627 .62341 Mdot
.47523 .62482 Mdot
.38296 .39954 Mdot
.42064 .20954 Mdot
.67222 .56802 Mdot
.46478 .63004 Mdot
.47576 .598 Mdot
.36299 .37783 Mdot
.50081 .2917 Mdot
.71216 .52947 Mdot
.477 .59736 Mdot
.28479 .65643 Mdot
.5264 .29236 Mdot
.52055 .62855 Mdot
.43432 .60557 Mdot
.30843 .51065 Mdot
.26229 .54931 Mdot
.27584 .68252 Mdot
.5728 .31805 Mdot
.62983 .42926 Mdot
.46117 .67392 Mdot
.35271 .36134 Mdot
.5307 .65623 Mdot
.55289 .20654 Mdot
.65167 .45616 Mdot
.45835 .62074 Mdot
.48421 .57854 Mdot
.65068 .56193 Mdot
.45607 .62729 Mdot
.67339 .47345 Mdot
.34625 .39101 Mdot
.45798 .62002 Mdot
.71289 .70727 Mdot
.5479 .32265 Mdot
.44522 .5807 Mdot
.32326 .47995 Mdot
.37167 .49332 Mdot
.80129 .56686 Mdot
.32939 .38813 Mdot
.28994 .52179 Mdot
.44754 .61339 Mdot
.34073 .35958 Mdot
.56308 .27242 Mdot
.53944 .5377 Mdot
.52677 .61556 Mdot
.53925 .28555 Mdot
.52941 .30575 Mdot
.30202 .50402 Mdot
.13369 .53258 Mdot
.48635 .57915 Mdot
.46712 .64844 Mdot
.33617 .23085 Mdot
.63231 .53493 Mdot
.46244 .65355 Mdot
.43618 .62574 Mdot
.56362 .28484 Mdot
.35051 .73648 Mdot
.38373 .54947 Mdot
.43672 .21379 Mdot
.52934 .28788 Mdot
.39775 .406 Mdot
.35166 .40124 Mdot
.28982 .51968 Mdot
.689 .54412 Mdot
.31166 .52595 Mdot
.35416 .38211 Mdot
.49109 .6375 Mdot
.56294 .31913 Mdot
.62295 .64553 Mdot
.52652 .28051 Mdot
.37573 .33722 Mdot
.69068 .5213 Mdot
.79998 .51885 Mdot
.4489 .15893 Mdot
.77906 .51936 Mdot
.56823 .33068 Mdot
.3069 .50782 Mdot
.62705 .29873 Mdot
.4503 .61459 Mdot
.49176 .78601 Mdot
.46719 .65192 Mdot
.56459 .67182 Mdot
.35974 .41248 Mdot
.65401 .43371 Mdot
.47925 .66798 Mdot
.34275 .5649 Mdot
.57346 .30052 Mdot
.53237 .32609 Mdot
.49544 .60751 Mdot
.54045 .2965 Mdot
.4708 .62394 Mdot
.36583 .38283 Mdot
.13801 .53523 Mdot
.44064 .62925 Mdot
.42905 .59378 Mdot
.53966 .25746 Mdot
.61805 .45486 Mdot
.40476 .35317 Mdot
.63376 .77222 Mdot
.73266 .28907 Mdot
.53879 .30189 Mdot
.44695 .54834 Mdot
.38786 .3829 Mdot
.63618 .42422 Mdot
.35329 .4304 Mdot
.47476 .644 Mdot
.43364 .64399 Mdot
.5011 .62585 Mdot
.45354 .61175 Mdot
.51382 .77635 Mdot
.4505 .56661 Mdot
.618 .71628 Mdot
.45689 .66294 Mdot
.48439 .54037 Mdot
.5519 .2863 Mdot
.38833 .6391 Mdot
.35297 .49457 Mdot
.43067 .63644 Mdot
.59718 .58456 Mdot
.54625 .27697 Mdot
.78319 .44765 Mdot
.55619 .30433 Mdot
.38128 .36403 Mdot
.55276 .33574 Mdot
.48204 .6724 Mdot
.674 .54188 Mdot
.35998 .39782 Mdot
.74555 .51872 Mdot
.39037 .39923 Mdot
.45082 .62464 Mdot
.57502 .24701 Mdot
.34963 .35847 Mdot
.38005 .65793 Mdot
.67539 .54057 Mdot
.33246 .59124 Mdot
.63891 .52588 Mdot
.45641 .63362 Mdot
.45678 .64174 Mdot
.65024 .4281 Mdot
.57082 .31385 Mdot
.69947 .58032 Mdot
.1785 .47734 Mdot
.30359 .46854 Mdot
.68691 .55176 Mdot
.39949 .63308 Mdot
.5486 .4311 Mdot
.65875 .57375 Mdot
.35284 .59113 Mdot
.57191 .30374 Mdot
.70257 .54972 Mdot
.42825 .66649 Mdot
.50266 .73911 Mdot
.30019 .47835 Mdot
.33757 .3667 Mdot
.51824 .44386 Mdot
.3497 .39863 Mdot
.51628 .29143 Mdot
.35893 .42415 Mdot
.55409 .29131 Mdot
.65093 .48668 Mdot
.43656 .4803 Mdot
.51275 .30832 Mdot
.51467 .28193 Mdot
.35405 .37352 Mdot
.49964 .61111 Mdot
.45843 .41529 Mdot
.42608 .67472 Mdot
.42842 .58395 Mdot
.52978 .29146 Mdot
.69469 .53793 Mdot
.66993 .58523 Mdot
.556 .55733 Mdot
.64327 .56111 Mdot
.36574 .3959 Mdot
.5834 .45343 Mdot
.45872 .77376 Mdot
.5491 .32516 Mdot
.32708 .34 Mdot
.50797 .62393 Mdot
.35045 .36948 Mdot
.37137 .3955 Mdot
.53471 .29688 Mdot
.5369 .73445 Mdot
.44371 .57785 Mdot
.63114 .5475 Mdot
.70318 .56434 Mdot
.66311 .57609 Mdot
.71312 .55231 Mdot
.29282 .73275 Mdot
.51955 .29468 Mdot
.68594 .53265 Mdot
.50163 .60214 Mdot
.44502 .65612 Mdot
.6274 .43969 Mdot
.28674 .50338 Mdot
.43615 .66281 Mdot
.41676 .62425 Mdot
.48271 .63298 Mdot
.3472 .36416 Mdot
.49835 .71255 Mdot
.64969 .45539 Mdot
.36756 .42245 Mdot
.35115 .42126 Mdot
.63866 .43025 Mdot
.65998 .49219 Mdot
.77644 .32367 Mdot
.49681 .63096 Mdot
.7399 .59525 Mdot
.35394 .36277 Mdot
.5084 .50845 Mdot
.54398 .5791 Mdot
.51655 .6221 Mdot
.45745 .38594 Mdot
.36559 .38863 Mdot
.71978 .58673 Mdot
.47157 .6427 Mdot
.64923 .43278 Mdot
.31448 .47466 Mdot
.41641 .66135 Mdot
.63067 .42566 Mdot
.68642 .56289 Mdot
.30533 .30713 Mdot
.62956 .5643 Mdot
.34963 .35707 Mdot
.44589 .58262 Mdot
.39314 .88799 Mdot
.37788 .37637 Mdot
.74233 .41526 Mdot
.4277 .48262 Mdot
.44353 .62485 Mdot
.36041 .40255 Mdot
.72353 .57174 Mdot
.52635 .29293 Mdot
.52216 .41996 Mdot
.69091 .54235 Mdot
.64676 .42784 Mdot
.62953 .4339 Mdot
.36185 .37573 Mdot
.6981 .5742 Mdot
.44769 .59769 Mdot
.64883 .54371 Mdot
.55145 .32989 Mdot
.502 .66288 Mdot
.74263 .30786 Mdot
.40624 .59656 Mdot
.65153 .54299 Mdot
.39263 .34999 Mdot
.28119 .53061 Mdot
.51384 .65846 Mdot
.78517 .40712 Mdot
.43808 .62097 Mdot
.55612 .31404 Mdot
.46528 .50064 Mdot
.61957 .65259 Mdot
.49439 .6199 Mdot
.50564 .6301 Mdot
.55055 .27053 Mdot
.49383 .62439 Mdot
.5164 .59928 Mdot
.5071 .35523 Mdot
.65392 .56942 Mdot
.46477 .61417 Mdot
.35179 .40563 Mdot
.7066 .63006 Mdot
.47322 .6685 Mdot
.68118 .4647 Mdot
.33435 .57911 Mdot
.44944 .49086 Mdot
.42738 .60267 Mdot
.25373 .56056 Mdot
.45966 .64329 Mdot
.51941 .61197 Mdot
.50032 .62029 Mdot
.61262 .77735 Mdot
.35284 .37799 Mdot
.34555 .40972 Mdot
.31699 .47333 Mdot
.34296 .57055 Mdot
.30238 .52077 Mdot
.5542 .27287 Mdot
.32539 .33615 Mdot
.65642 .45171 Mdot
.67411 .56417 Mdot
.47162 .66625 Mdot
.38504 .40632 Mdot
.47739 .63212 Mdot
.50333 .65122 Mdot
.36005 .39121 Mdot
.37033 .39282 Mdot
.33144 .40288 Mdot
.2829 .49281 Mdot
.67569 .55566 Mdot
.48189 .6536 Mdot
.27659 .51103 Mdot
.44376 .60358 Mdot
.55498 .41148 Mdot
.67771 .55452 Mdot
.64816 .54566 Mdot
.65147 .5815 Mdot
.45458 .66436 Mdot
.48988 .67182 Mdot
.54547 .28571 Mdot
.70535 .58403 Mdot
.5316 .3291 Mdot
.35873 .40223 Mdot
.34441 .37594 Mdot
.47469 .64467 Mdot
.55488 .65521 Mdot
.288 .50629 Mdot
.38543 .36519 Mdot
.63634 .45487 Mdot
.32057 .47402 Mdot
.46223 .60772 Mdot
.35369 .40067 Mdot
.32622 .48037 Mdot
.58288 .65722 Mdot
.70371 .25916 Mdot
.27649 .50251 Mdot
.49513 .60694 Mdot
.73326 .68406 Mdot
.2834 .6673 Mdot
.29254 .47613 Mdot
.55996 .30233 Mdot
.43662 .63954 Mdot
.44984 .18499 Mdot
.29935 .53489 Mdot
.2767 .69366 Mdot
.35578 .39025 Mdot
.57643 .61525 Mdot
.41298 .65596 Mdot
.4739 .78408 Mdot
.29597 .53704 Mdot
.65611 .5412 Mdot
.70796 .56516 Mdot
.4909 .6114 Mdot
.34007 .46125 Mdot
.51731 .29281 Mdot
.38066 .35219 Mdot
.36197 .41862 Mdot
.68901 .58045 Mdot
.58259 .43662 Mdot
.35224 .40466 Mdot
.5234 .59041 Mdot
.31206 .45049 Mdot
.38716 .61036 Mdot
.33464 .77504 Mdot
.78065 .58159 Mdot
.4365 .5953 Mdot
.27818 .52752 Mdot
.57248 .2876 Mdot
.54126 .29118 Mdot
.54766 .29526 Mdot
.34331 .3795 Mdot
.54463 .46708 Mdot
.36181 .4157 Mdot
.68022 .41763 Mdot
.2935 .50437 Mdot
.33226 .62308 Mdot
.42109 .63672 Mdot
.4441 .62507 Mdot
.50626 .59402 Mdot
.50077 .62791 Mdot
.46056 .64167 Mdot
.52752 .29938 Mdot
.36197 .34862 Mdot
.36679 .24163 Mdot
.68235 .57743 Mdot
.63617 .35778 Mdot
.35905 .35583 Mdot
.62241 .43055 Mdot
.30993 .49017 Mdot
.26836 .57412 Mdot
.29347 .45087 Mdot
.38118 .35554 Mdot
.52741 .63372 Mdot
.70006 .53968 Mdot
.42531 .76514 Mdot
.45259 .65039 Mdot
.38724 .36668 Mdot
.38884 .41637 Mdot
.54962 .73392 Mdot
.52086 .677 Mdot
.33638 .44978 Mdot
.54876 .43503 Mdot
.27362 .53286 Mdot
.52363 .66018 Mdot
.52072 .50862 Mdot
.35554 .38043 Mdot
.37389 .3632 Mdot
.28399 .48629 Mdot
.44318 .70508 Mdot
.6983 .55737 Mdot
.65666 .4378 Mdot
.56073 .29583 Mdot
.44507 .6424 Mdot
.34354 .38299 Mdot
.7396 .57232 Mdot
.51814 .40291 Mdot
.54966 .31365 Mdot
.37232 .42182 Mdot
.43388 .63265 Mdot
.49208 .61576 Mdot
.29443 .51361 Mdot
.21934 .39545 Mdot
.42456 .67249 Mdot
.74719 .43406 Mdot
.56577 .47174 Mdot
.39848 .48919 Mdot
.48068 .62731 Mdot
.65465 .57828 Mdot
.64189 .43212 Mdot
.317 .4855 Mdot
.43968 .60904 Mdot
.75629 .29848 Mdot
.63382 .57925 Mdot
.52869 .31378 Mdot
.64421 .43111 Mdot
.53586 .47161 Mdot
.43959 .61938 Mdot
.46753 .65148 Mdot
.48781 .59861 Mdot
.75681 .29493 Mdot
.3529 .41202 Mdot
.71372 .57168 Mdot
.30797 .52139 Mdot
.64655 .54391 Mdot
.33964 .40908 Mdot
.39325 .48745 Mdot
.47132 .60106 Mdot
.63189 .55807 Mdot
.66065 .53634 Mdot
.54746 .32369 Mdot
.56863 .28453 Mdot
.33414 .36418 Mdot
.44886 .61381 Mdot
.65725 .4462 Mdot
.69676 .54289 Mdot
.37912 .34836 Mdot
.2949 .5127 Mdot
.53764 .35215 Mdot
.45694 .66341 Mdot
.35894 .37604 Mdot
.45191 .5894 Mdot
.6579 .56578 Mdot
.37513 .35369 Mdot
.62374 .42572 Mdot
.28823 .49995 Mdot
.44047 .65473 Mdot
.33717 .26505 Mdot
.64677 .43022 Mdot
.48767 .67949 Mdot
.76489 .59206 Mdot
.34881 .4816 Mdot
.75803 .5358 Mdot
.36789 .40914 Mdot
.65393 .44622 Mdot
.7152 .5635 Mdot
.49785 .74402 Mdot
.37269 .36683 Mdot
.764 .64768 Mdot
.47651 .3932 Mdot
.49174 .6399 Mdot
.69323 .55551 Mdot
.26895 .51199 Mdot
.75412 .43035 Mdot
.27222 .63735 Mdot
.46525 .62329 Mdot
.34896 .39814 Mdot
.3169 .47626 Mdot
.53389 .32916 Mdot
.67852 .45731 Mdot
.37188 .79145 Mdot
.36937 .42103 Mdot
.47303 .66306 Mdot
.69803 .54225 Mdot
.53237 .30411 Mdot
.79015 .6306 Mdot
.38566 .34466 Mdot
.36259 .40803 Mdot
.51114 .60182 Mdot
.31052 .51899 Mdot
.45672 .18744 Mdot
.347 .40913 Mdot
.34588 .3559 Mdot
.60392 .39569 Mdot
.30762 .47175 Mdot
.49685 .60219 Mdot
.55535 .55687 Mdot
.4779 .595 Mdot
.69172 .39812 Mdot
.65489 .44591 Mdot
.68111 .57659 Mdot
.46208 .65872 Mdot
.34764 .25851 Mdot
.37348 .37524 Mdot
.55093 .43838 Mdot
.52507 .24842 Mdot
.56967 .28737 Mdot
.34641 .38902 Mdot
.47285 .63564 Mdot
.52993 .34202 Mdot
.28864 .51103 Mdot
.47649 .59745 Mdot
.48653 .67092 Mdot
.72547 .56653 Mdot
.56003 .32253 Mdot
.71689 .62577 Mdot
.54621 .3348 Mdot
.53929 .27359 Mdot
.71914 .53987 Mdot
.48978 .61072 Mdot
.38175 .36003 Mdot
.37574 .33529 Mdot
.44712 .59464 Mdot
.50783 .50757 Mdot
.69697 .55639 Mdot
.32729 .40991 Mdot
.73182 .26403 Mdot
.49268 .58214 Mdot
.6252 .44475 Mdot
.58376 .6145 Mdot
.52068 .30441 Mdot
.48988 .63716 Mdot
.66593 .56444 Mdot
.35897 .34595 Mdot
.34459 .39669 Mdot
.48229 .68737 Mdot
.53407 .2963 Mdot
.32592 .49591 Mdot
.37437 .39567 Mdot
.52319 .39834 Mdot
.45597 .62214 Mdot
.66329 .42964 Mdot
.37773 .39435 Mdot
.81802 .55997 Mdot
.354 .2519 Mdot
.68093 .58039 Mdot
.50958 .63971 Mdot
.68078 .52487 Mdot
.30498 .52396 Mdot
.35693 .42823 Mdot
.53811 .28898 Mdot
.42546 .73707 Mdot
.18379 .42492 Mdot
.34923 .37357 Mdot
.68221 .56135 Mdot
.47384 .65997 Mdot
.54049 .58443 Mdot
.43997 .62434 Mdot
.35113 .73093 Mdot
.31577 .45847 Mdot
.50842 .308 Mdot
.52764 .32442 Mdot
.50144 .6404 Mdot
.28078 .50209 Mdot
.34831 .34364 Mdot
.35895 .38982 Mdot
.14411 .58532 Mdot
.62966 .42522 Mdot
.35731 .44498 Mdot
.45442 .66386 Mdot
.38601 .35241 Mdot
.71558 .6886 Mdot
.53036 .33019 Mdot
.47579 .59362 Mdot
.39618 .39727 Mdot
.68929 .37422 Mdot
.54619 .43066 Mdot
.46006 .62163 Mdot
.54938 .65609 Mdot
.55803 .30332 Mdot
.6275 .29783 Mdot
.37305 .40868 Mdot
.45307 .60077 Mdot
.58249 .3022 Mdot
.62124 .47046 Mdot
.18351 .47212 Mdot
.67557 .55527 Mdot
.4019 .36443 Mdot
.55393 .27792 Mdot
.51786 .70052 Mdot
.28564 .5104 Mdot
.35787 .34251 Mdot
.39582 .39366 Mdot
.5068 .65505 Mdot
.43801 .66352 Mdot
.53747 .67015 Mdot
.69198 .56087 Mdot
.56486 .2878 Mdot
.49335 .65391 Mdot
.57076 .41762 Mdot
.49635 .6366 Mdot
.55985 .28313 Mdot
.26601 .79879 Mdot
.49353 .68152 Mdot
.45072 .65396 Mdot
.36646 .63847 Mdot
.68993 .58322 Mdot
.64837 .56247 Mdot
.57151 .44176 Mdot
.45253 .66325 Mdot
.48729 .37504 Mdot
.67441 .55758 Mdot
.69245 .55043 Mdot
.4851 .37656 Mdot
.50705 .66012 Mdot
.5767 .26477 Mdot
.53414 .30123 Mdot
.56899 .28589 Mdot
.65028 .56044 Mdot
.42502 .57581 Mdot
.56617 .27594 Mdot
.52457 .77481 Mdot
.37347 .35238 Mdot
.5213 .50876 Mdot
.65005 .54229 Mdot
.49811 .40706 Mdot
.57051 .31282 Mdot
.83353 .59039 Mdot
.41554 .75234 Mdot
.47876 .5898 Mdot
.49391 .61524 Mdot
.30526 .51387 Mdot
.50756 .55585 Mdot
.62811 .43035 Mdot
.54234 .29389 Mdot
.44483 .22845 Mdot
.67676 .54999 Mdot
.44159 .64502 Mdot
.25104 .5976 Mdot
.78819 .58106 Mdot
.54891 .54578 Mdot
.68857 .54269 Mdot
.67797 .54592 Mdot
.39029 .39114 Mdot
.37523 .35157 Mdot
.48132 .60185 Mdot
.54924 .29087 Mdot
.70494 .55918 Mdot
.56693 .30406 Mdot
.35511 .38214 Mdot
.37269 .35419 Mdot
.64159 .45515 Mdot
.47065 .56611 Mdot
.34874 .38614 Mdot
.60924 .39342 Mdot
.56933 .4163 Mdot
.722 .57077 Mdot
.43057 .17005 Mdot
.78811 .64582 Mdot
.37001 .64911 Mdot
.31354 .47449 Mdot
.64192 .48282 Mdot
.56293 .33184 Mdot
.50201 .63796 Mdot
.47577 .64993 Mdot
.6343 .4455 Mdot
.56987 .3222 Mdot
.31264 .49813 Mdot
.56885 .31897 Mdot
.3113 .48302 Mdot
.34001 .40093 Mdot
.47082 .66999 Mdot
.45071 .60856 Mdot
.53078 .32049 Mdot
.39125 .38136 Mdot
.34838 .35932 Mdot
.29495 .48393 Mdot
.28202 .5745 Mdot
.36122 .37738 Mdot
.64997 .54212 Mdot
.69421 .64314 Mdot
.62929 .43564 Mdot
.47103 .6424 Mdot
.25597 .57965 Mdot
.52806 .75741 Mdot
.48983 .64472 Mdot
.6452 .43086 Mdot
.12911 .55526 Mdot
.47403 .67047 Mdot
.21567 .68682 Mdot
.65005 .45421 Mdot
.65264 .57944 Mdot
.38525 .38823 Mdot
.63638 .42568 Mdot
.50237 .71142 Mdot
.35464 .46021 Mdot
.45723 .58451 Mdot
.69855 .5525 Mdot
.63488 .56094 Mdot
.44289 .47188 Mdot
.68955 .39586 Mdot
.31202 .51937 Mdot
.30588 .49523 Mdot
.37051 .36838 Mdot
.52954 .37075 Mdot
.53764 .61136 Mdot
.30748 .49759 Mdot
.4831 .20869 Mdot
.50887 .62235 Mdot
.36392 .49306 Mdot
.46319 .39556 Mdot
.66527 .58108 Mdot
.38902 .64348 Mdot
.37287 .37118 Mdot
.682 .56077 Mdot
.45374 .43742 Mdot
.49189 .5928 Mdot
.67779 .55281 Mdot
.56763 .29117 Mdot
.4835 .32866 Mdot
.64188 .55481 Mdot
.52163 .41653 Mdot
.53484 .30634 Mdot
.35045 .48373 Mdot
.31683 .65434 Mdot
.79139 .28758 Mdot
.54455 .29154 Mdot
.38928 .37626 Mdot
.3457 .37913 Mdot
.36446 .37938 Mdot
.69346 .54472 Mdot
.37377 .38871 Mdot
.68843 .5719 Mdot
.52577 .26408 Mdot
.26682 .56457 Mdot
.29931 .50979 Mdot
.32046 .42431 Mdot
.66043 .54353 Mdot
.68829 .41954 Mdot
.35608 .20329 Mdot
.49959 .6051 Mdot
.51389 .30367 Mdot
.27489 .52023 Mdot
.58799 .48952 Mdot
.30815 .51183 Mdot
.38738 .3851 Mdot
.52344 .50913 Mdot
.47063 .62271 Mdot
.76887 .57062 Mdot
.32008 .47925 Mdot
.68981 .54253 Mdot
.52565 .62519 Mdot
.35929 .33359 Mdot
.29332 .52353 Mdot
.30852 .47582 Mdot
.4623 .6422 Mdot
.63722 .55534 Mdot
.38124 .35758 Mdot
.55625 .33825 Mdot
.28436 .48164 Mdot
.55549 .63903 Mdot
.49807 .61452 Mdot
.51772 .66104 Mdot
.55667 .44989 Mdot
.46046 .18068 Mdot
.53872 .30448 Mdot
.27721 .66712 Mdot
.34685 .37217 Mdot
.27539 .64408 Mdot
.75028 .4659 Mdot
.29207 .44644 Mdot
.65515 .44861 Mdot
.6551 .44487 Mdot
.46019 .62792 Mdot
.49573 .1763 Mdot
.49509 .53758 Mdot
.57259 .26832 Mdot
.63222 .43664 Mdot
.34932 .35802 Mdot
.67712 .59362 Mdot
.40301 .67375 Mdot
.4237 .65158 Mdot
.57249 .31778 Mdot
.35922 .38386 Mdot
.5531 .206 Mdot
.29464 .50405 Mdot
.57934 .48429 Mdot
.45704 .61145 Mdot
.46556 .63344 Mdot
.5416 .31565 Mdot
.54369 .2873 Mdot
.66185 .41672 Mdot
.47378 .47439 Mdot
.75213 .32617 Mdot
.53858 .26433 Mdot
.54988 .20267 Mdot
.69431 .61309 Mdot
.65337 .55668 Mdot
.62346 .44093 Mdot
.5577 .2713 Mdot
.4617 .65524 Mdot
.65768 .58127 Mdot
.52662 .5404 Mdot
.72503 .58433 Mdot
.36515 .49363 Mdot
.50175 .3889 Mdot
.45671 .61015 Mdot
.70421 .54246 Mdot
.68162 .55868 Mdot
.69622 .53201 Mdot
.63771 .43133 Mdot
.48302 .62827 Mdot
.50085 .61005 Mdot
.47602 .67063 Mdot
.53786 .58321 Mdot
.45563 .62702 Mdot
.75173 .4615 Mdot
.58111 .41332 Mdot
.23258 .43293 Mdot
.46098 .66646 Mdot
.55871 .27965 Mdot
.46706 .66779 Mdot
.28081 .50629 Mdot
.45073 .66568 Mdot
.36193 .49403 Mdot
.54695 .3014 Mdot
.46098 .71887 Mdot
.32744 .3516 Mdot
.4645 .6048 Mdot
.32226 .50607 Mdot
.46619 .17798 Mdot
.25427 .61623 Mdot
.60473 .39556 Mdot
.64955 .54315 Mdot
.33246 .37549 Mdot
.51546 .31314 Mdot
.37907 .35922 Mdot
.46894 .59313 Mdot
.64244 .45677 Mdot
.70931 .76674 Mdot
.48763 .41744 Mdot
.46103 .65662 Mdot
.47965 .5649 Mdot
.65505 .57679 Mdot
.37462 .37767 Mdot
.71725 .60076 Mdot
.50947 .60194 Mdot
.29374 .53094 Mdot
.28116 .52596 Mdot
.41486 .4725 Mdot
.49015 .25318 Mdot
.437 .76217 Mdot
.54162 .31315 Mdot
.34092 .38954 Mdot
.29821 .53641 Mdot
.59667 .57324 Mdot
.51889 .29043 Mdot
.52059 .30574 Mdot
.56094 .32081 Mdot
.44763 .62582 Mdot
.63315 .44955 Mdot
.48333 .23382 Mdot
.64281 .42678 Mdot
.50079 .59683 Mdot
.39395 .39738 Mdot
.63917 .42483 Mdot
.30337 .51802 Mdot
.53664 .2758 Mdot
.35006 .36088 Mdot
.45559 .639 Mdot
.66826 .55545 Mdot
.26105 .65165 Mdot
.26728 .29255 Mdot
.32736 .42732 Mdot
.32612 .42355 Mdot
.64266 .57837 Mdot
.79743 .42061 Mdot
.51497 .33929 Mdot
.5337 .73958 Mdot
.26427 .51805 Mdot
.44938 .59368 Mdot
.16346 .56061 Mdot
.3633 .41462 Mdot
.36172 .3982 Mdot
.46048 .6164 Mdot
.38345 .34672 Mdot
.43782 .63454 Mdot
.3786 .40597 Mdot
.73287 .39323 Mdot
.42311 .65336 Mdot
.36442 .3965 Mdot
.53821 .62461 Mdot
.5116 .66256 Mdot
.64917 .5746 Mdot
.36009 .34251 Mdot
.48053 .58924 Mdot
.65104 .81728 Mdot
.54249 .32539 Mdot
.63637 .43121 Mdot
.31711 .39292 Mdot
.55764 .33255 Mdot
.69612 .56711 Mdot
.46139 .67265 Mdot
.29014 .51105 Mdot
.65588 .5498 Mdot
.34622 .33903 Mdot
.3228 .48463 Mdot
.58294 .4508 Mdot
.65118 .55779 Mdot
.63003 .44254 Mdot
.29004 .4968 Mdot
.45785 .58422 Mdot
.35931 .39561 Mdot
.3281 .25914 Mdot
.6401 .42721 Mdot
.47443 .6257 Mdot
.40121 .35803 Mdot
.5683 .31982 Mdot
.47928 .60496 Mdot
.34219 .38765 Mdot
.64097 .4304 Mdot
.48994 .67806 Mdot
.48868 .68024 Mdot
.42551 .70179 Mdot
.45937 .50994 Mdot
.29872 .51361 Mdot
.71054 .53138 Mdot
.50102 .60107 Mdot
.28197 .49859 Mdot
.36809 .27628 Mdot
.42279 .62266 Mdot
.65565 .52853 Mdot
.46905 .74152 Mdot
.386 .35563 Mdot
.52888 .32731 Mdot
.37842 .33791 Mdot
.32322 .47615 Mdot
.1875 .34717 Mdot
.62366 .43717 Mdot
.49642 .56899 Mdot
.51307 .59565 Mdot
.3671 .42698 Mdot
.68358 .55652 Mdot
.76366 .34576 Mdot
.44575 .65947 Mdot
.41061 .59453 Mdot
.46675 .64346 Mdot
.3414 .27039 Mdot
.69519 .55285 Mdot
.46911 .64383 Mdot
.5593 .62546 Mdot
.50266 .58614 Mdot
.31747 .51877 Mdot
.33588 .63762 Mdot
.48067 .66007 Mdot
.46474 .91821 Mdot
.65855 .45422 Mdot
.36197 .38956 Mdot
.53512 .42512 Mdot
.30422 .34122 Mdot
.30333 .75628 Mdot
.69216 .56681 Mdot
.61395 .6014 Mdot
.37965 .35791 Mdot
.24447 .63757 Mdot
.79728 .43933 Mdot
.51753 .65383 Mdot
.43546 .63967 Mdot
.3874 .385 Mdot
.37622 .34806 Mdot
.65446 .45796 Mdot
.42832 .63378 Mdot
.41216 .59077 Mdot
.39744 .36017 Mdot
.45105 .63987 Mdot
.57738 .75077 Mdot
.52829 .33738 Mdot
.65011 .5624 Mdot
.53481 .32946 Mdot
.52139 .3091 Mdot
.47263 .77137 Mdot
.56534 .47359 Mdot
.55322 .2822 Mdot
.57326 .3265 Mdot
.34379 .53474 Mdot
.4055 .72711 Mdot
.31428 .52228 Mdot
.50097 .25829 Mdot
.36658 .3718 Mdot
.48418 .62949 Mdot
.68916 .5384 Mdot
.41937 .79429 Mdot
.67392 .26025 Mdot
.54202 .51248 Mdot
.5038 .60751 Mdot
.37111 .37617 Mdot
.64213 .42889 Mdot
.42095 .64927 Mdot
.28205 .65954 Mdot
.46557 .62717 Mdot
.37276 .35008 Mdot
.46091 .77535 Mdot
.6673 .47525 Mdot
.53722 .26584 Mdot
.68558 .59552 Mdot
.46975 .66807 Mdot
.66925 .57023 Mdot
.54517 .28055 Mdot
.28223 .4947 Mdot
.30644 .50661 Mdot
.45915 .60625 Mdot
.43788 .47972 Mdot
.27803 .55402 Mdot
.51737 .65346 Mdot
.50557 .65784 Mdot
.65387 .45013 Mdot
.5045 .65927 Mdot
.45457 .60186 Mdot
.49315 .65098 Mdot
.4266 .62292 Mdot
.54636 .27063 Mdot
.75889 .55851 Mdot
.43885 .66037 Mdot
.50527 .58307 Mdot
.54492 .34539 Mdot
.47109 .69993 Mdot
.55571 .30147 Mdot
.70189 .27091 Mdot
.55891 .29168 Mdot
.30508 .50711 Mdot
.3942 .34312 Mdot
.65194 .61268 Mdot
.70499 .56076 Mdot
.5573 .2773 Mdot
.30269 .48852 Mdot
.54561 .29309 Mdot
.34473 .40192 Mdot
.38416 .19821 Mdot
.66197 .51545 Mdot
.55916 .40482 Mdot
.37633 .68895 Mdot
.66167 .42628 Mdot
.39221 .36171 Mdot
.69054 .57935 Mdot
.67121 .47293 Mdot
.49993 .64425 Mdot
.29213 .51577 Mdot
.46085 .62867 Mdot
.5306 .27924 Mdot
.3691 .37507 Mdot
.55804 .24648 Mdot
.29953 .51408 Mdot
.22292 .3167 Mdot
.38579 .40454 Mdot
.5024 .57562 Mdot
.5406 .34466 Mdot
.40429 .18262 Mdot
.55748 .29537 Mdot
.26663 .56579 Mdot
.66796 .50219 Mdot
.39047 .77704 Mdot
.67044 .54373 Mdot
.66841 .43696 Mdot
.82984 .41433 Mdot
.77511 .42491 Mdot
.65936 .5572 Mdot
.32655 .35246 Mdot
.45107 .62788 Mdot
.49916 .63294 Mdot
.53033 .59435 Mdot
.70738 .59704 Mdot
.49006 .59912 Mdot
.62691 .43277 Mdot
.56383 .4559 Mdot
.46009 .19902 Mdot
.33447 .3677 Mdot
.43744 .63003 Mdot
.52883 .2929 Mdot
.53227 .27582 Mdot
.64314 .42528 Mdot
.55545 .32941 Mdot
.50643 .66617 Mdot
.66276 .54325 Mdot
.45729 .41929 Mdot
.30292 .52402 Mdot
.7405 .43905 Mdot
.26595 .53233 Mdot
.29561 .46093 Mdot
.49655 .58337 Mdot
.37367 .35412 Mdot
.1651 .48489 Mdot
.50295 .63252 Mdot
.67574 .55947 Mdot
.51558 .60247 Mdot
.4891 .65544 Mdot
.4777 .66061 Mdot
.3412 .38669 Mdot
.53753 .42307 Mdot
.45121 .64285 Mdot
.5512 .28031 Mdot
.48323 .37937 Mdot
.42543 .65128 Mdot
.45235 .23665 Mdot
.36684 .49394 Mdot
.66313 .43018 Mdot
.72113 .57255 Mdot
.38475 .37202 Mdot
.67594 .54801 Mdot
.6299 .58559 Mdot
.69609 .56748 Mdot
.46264 .22493 Mdot
.50835 .74059 Mdot
.23698 .71377 Mdot
.69539 .70255 Mdot
.46777 .78155 Mdot
.63062 .55247 Mdot
.41207 .27273 Mdot
.66012 .56162 Mdot
.69427 .56757 Mdot
.18294 .69554 Mdot
.66654 .52873 Mdot
.47579 .6435 Mdot
.46897 .68038 Mdot
.78976 .54225 Mdot
.34423 .53733 Mdot
.45751 .66686 Mdot
.48753 .59992 Mdot
.28826 .53374 Mdot
.5221 .71098 Mdot
.66245 .45575 Mdot
.57448 .47691 Mdot
.62368 .44619 Mdot
.4618 .64144 Mdot
.46546 .60896 Mdot
.48691 .68686 Mdot
.83915 .42386 Mdot
.39323 .7921 Mdot
.64225 .57478 Mdot
.49384 .70325 Mdot
.61043 .42785 Mdot
.51914 .60047 Mdot
.51305 .59812 Mdot
.4814 .67157 Mdot
.3814 .35938 Mdot
.67474 .59307 Mdot
.41597 .65189 Mdot
.73682 .48273 Mdot
.45883 .61046 Mdot
.2788 .47526 Mdot
.27925 .54693 Mdot
.47361 .63625 Mdot
.65478 .53085 Mdot
.50455 .61865 Mdot
.68915 .53025 Mdot
.65258 .56408 Mdot
.46452 .56619 Mdot
.48649 .2383 Mdot
.67124 .59503 Mdot
.51569 .65817 Mdot
.3919 .3748 Mdot
.74622 .42677 Mdot
.4748 .62799 Mdot
.31395 .51413 Mdot
.49055 .6369 Mdot
.324 .50272 Mdot
.49447 .66703 Mdot
.64517 .42745 Mdot
.61123 .66188 Mdot
.37221 .36367 Mdot
.27882 .48927 Mdot
.38736 .3519 Mdot
.37863 .64258 Mdot
.64481 .53137 Mdot
.65931 .46738 Mdot
.38489 .79997 Mdot
.65305 .45138 Mdot
.27433 .67508 Mdot
.48494 .36605 Mdot
.52464 .316 Mdot
.71464 .55552 Mdot
.45533 .76902 Mdot
.4653 .26538 Mdot
.34023 .41832 Mdot
.3495 .42129 Mdot
.17706 .49217 Mdot
.13753 .53716 Mdot
.45026 .64704 Mdot
.44288 .1839 Mdot
.62263 .70175 Mdot
.54158 .61248 Mdot
.48013 .6928 Mdot
.39797 .38784 Mdot
.46064 .66996 Mdot
.51568 .43401 Mdot
.35352 .37426 Mdot
.29958 .49422 Mdot
.67932 .57594 Mdot
.29188 .48954 Mdot
.6452 .23714 Mdot
.58406 .39383 Mdot
.3496 .38101 Mdot
.4245 .63039 Mdot
.44209 .63538 Mdot
.71712 .567 Mdot
.77024 .64479 Mdot
.6527 .56808 Mdot
.31402 .51853 Mdot
.36031 .36443 Mdot
.45559 .7931 Mdot
.48442 .64679 Mdot
.66447 .53446 Mdot
.33096 .34729 Mdot
.49196 .61709 Mdot
.52679 .31405 Mdot
.50494 .60835 Mdot
.65708 .53617 Mdot
.5036 .65998 Mdot
.66431 .5444 Mdot
.3848 .39855 Mdot
.44221 .61312 Mdot
.46795 .60772 Mdot
.27637 .68292 Mdot
.31322 .49966 Mdot
.64106 .53524 Mdot
.51839 .43596 Mdot
.47865 .59502 Mdot
.28489 .66023 Mdot
.47178 .67022 Mdot
.41614 .5599 Mdot
.45754 .69289 Mdot
.62594 .43611 Mdot
.51179 .59369 Mdot
.47378 .62768 Mdot
.73839 .68867 Mdot
.72541 .68554 Mdot
.3759 .61744 Mdot
.56762 .28264 Mdot
.64983 .53623 Mdot
.3453 .38169 Mdot
.35574 .34848 Mdot
.37809 .38652 Mdot
.33485 .55269 Mdot
.54541 .67261 Mdot
.47225 .62034 Mdot
.51024 .29108 Mdot
.30391 .49771 Mdot
.67959 .53667 Mdot
.3018 .50452 Mdot
.57044 .48289 Mdot
.321 .49858 Mdot
.62556 .43173 Mdot
.35604 .24948 Mdot
.55037 .75947 Mdot
.31909 .49226 Mdot
.6525 .56694 Mdot
.50416 .38163 Mdot
.45292 .59217 Mdot
.66161 .3725 Mdot
.2935 .53119 Mdot
.17688 .47523 Mdot
.48343 .67783 Mdot
.52422 .42395 Mdot
.55493 .30837 Mdot
.29276 .48908 Mdot
.55773 .32383 Mdot
.50399 .62244 Mdot
.76267 .54311 Mdot
.67936 .56308 Mdot
.52668 .33414 Mdot
.50724 .59148 Mdot
.29163 .4901 Mdot
.35056 .38573 Mdot
.42866 .75008 Mdot
.56181 .33955 Mdot
.25473 .64217 Mdot
.27219 .63795 Mdot
.35797 .36578 Mdot
.5034 .80248 Mdot
.56007 .31397 Mdot
.43274 .60129 Mdot
.57324 .62708 Mdot
.50819 .61474 Mdot
.34554 .36185 Mdot
.36401 .39934 Mdot
.78143 .4851 Mdot
.45683 .60883 Mdot
.45986 .67756 Mdot
.66689 .59047 Mdot
.34962 .3687 Mdot
.69791 .56623 Mdot
.71197 .57184 Mdot
.38864 .3833 Mdot
.68163 .58065 Mdot
.31898 .4787 Mdot
.55472 .48674 Mdot
.56088 .31045 Mdot
.52855 .30544 Mdot
.3481 .38436 Mdot
.3374 .38531 Mdot
.36907 .35346 Mdot
.5116 .61078 Mdot
.7009 .57348 Mdot
.51317 .63653 Mdot
.47038 .66635 Mdot
.71033 .5223 Mdot
.67821 .58781 Mdot
.51208 .6277 Mdot
.46652 .38241 Mdot
.32137 .51475 Mdot
.36588 .39503 Mdot
.56781 .30121 Mdot
.26778 .68431 Mdot
.53227 .33797 Mdot
.48315 .59571 Mdot
.68928 .37696 Mdot
.69328 .54526 Mdot
.30705 .51295 Mdot
.3431 .47097 Mdot
.30197 .51471 Mdot
.52605 .33377 Mdot
.71251 .57783 Mdot
.58058 .44599 Mdot
.45207 .60975 Mdot
.55771 .45286 Mdot
.30311 .68679 Mdot
.75 .47281 Mdot
.56526 .28737 Mdot
.49874 .60403 Mdot
.65076 .45339 Mdot
.55161 .73439 Mdot
.46846 .61852 Mdot
.4767 .59313 Mdot
.26689 .35354 Mdot
.50132 .58273 Mdot
.72342 .56187 Mdot
.41747 .48326 Mdot
.43806 .61172 Mdot
.37953 .63259 Mdot
.14091 .606 Mdot
.48486 .67888 Mdot
.46575 .60661 Mdot
.48195 .64081 Mdot
.50428 .63498 Mdot
.67107 .52235 Mdot
.25158 .3487 Mdot
.53484 .28626 Mdot
.5538 .48587 Mdot
.56197 .31584 Mdot
.3545 .39789 Mdot
.49377 .43527 Mdot
.68471 .52715 Mdot
.30218 .51529 Mdot
.43144 .18256 Mdot
.53038 .50359 Mdot
.39188 .38736 Mdot
.32615 .76164 Mdot
.29614 .52879 Mdot
.44775 .59363 Mdot
.31766 .47304 Mdot
.39989 .38401 Mdot
.53541 .29467 Mdot
.52601 .63847 Mdot
.69983 .55135 Mdot
.64244 .55369 Mdot
.50387 .60418 Mdot
.73735 .43217 Mdot
.56034 .33163 Mdot
.24639 .47701 Mdot
.4494 .62103 Mdot
.4725 .59377 Mdot
.65881 .57449 Mdot
.37335 .37862 Mdot
.48499 .36873 Mdot
.31185 .48987 Mdot
.52893 .60144 Mdot
.50283 .62168 Mdot
.56761 .48016 Mdot
.55056 .27213 Mdot
.63975 .4403 Mdot
.45234 .61427 Mdot
.56724 .46519 Mdot
.48059 .5974 Mdot
.45745 .55669 Mdot
.39049 .36398 Mdot
.42681 .58391 Mdot
.43277 .63702 Mdot
.74749 .57522 Mdot
.55744 .31936 Mdot
.67881 .55631 Mdot
.65101 .50755 Mdot
.65035 .43343 Mdot
.53822 .32412 Mdot
.51223 .62374 Mdot
.51916 .31155 Mdot
.49088 .64796 Mdot
.45352 .63984 Mdot
.56567 .28766 Mdot
.69775 .57008 Mdot
.75041 .334 Mdot
.75961 .55695 Mdot
.49981 .65309 Mdot
.49325 .63054 Mdot
.34728 .53905 Mdot
.44283 .81737 Mdot
.43219 .63815 Mdot
.70127 .57543 Mdot
.49145 .6149 Mdot
.52881 .29946 Mdot
.31568 .51505 Mdot
.6692 .55862 Mdot
.33942 .39463 Mdot
.37681 .40483 Mdot
.3712 .31694 Mdot
.62378 .43477 Mdot
.42909 .63126 Mdot
.71073 .53101 Mdot
.66238 .58713 Mdot
.58482 .50687 Mdot
.36204 .39067 Mdot
.32234 .49949 Mdot
.46821 .67568 Mdot
.44572 .7528 Mdot
.52436 .29592 Mdot
.4745 .91609 Mdot
.58086 .44186 Mdot
.27476 .54308 Mdot
.44502 .49035 Mdot
.64779 .45197 Mdot
.45103 .6563 Mdot
.2823 .5017 Mdot
.37234 .40353 Mdot
.50103 .62927 Mdot
.54385 .66599 Mdot
.46436 .27816 Mdot
.33686 .39696 Mdot
.52091 .3192 Mdot
.36098 .41112 Mdot
.32321 .50694 Mdot
.62674 .43111 Mdot
.63901 .56036 Mdot
.47064 .63069 Mdot
.38749 .62474 Mdot
.36602 .382 Mdot
.65226 .43116 Mdot
.46512 .60342 Mdot
.64612 .54124 Mdot
.37084 .39194 Mdot
.46201 .64732 Mdot
.53893 .73671 Mdot
.63009 .60394 Mdot
.36328 .36854 Mdot
.52945 .61972 Mdot
.40469 .69591 Mdot
.34023 .40721 Mdot
.39228 .40284 Mdot
.4877 .59937 Mdot
.2951 .48894 Mdot
.43684 .62219 Mdot
.55419 .29285 Mdot
.53765 .42249 Mdot
.53167 .31912 Mdot
.2833 .6697 Mdot
.46378 .68176 Mdot
.53782 .54073 Mdot
.70546 .54614 Mdot
.32535 .46554 Mdot
.71545 .72244 Mdot
.45637 .59677 Mdot
.76629 .32355 Mdot
.50137 .40595 Mdot
.5875 .4066 Mdot
.70563 .24985 Mdot
.31503 .48703 Mdot
.54803 .29538 Mdot
.4691 .60417 Mdot
.51438 .35057 Mdot
.3121 .48131 Mdot
.28366 .67224 Mdot
.52214 .60067 Mdot
.69171 .549 Mdot
.45198 .6211 Mdot
.65151 .53851 Mdot
.49125 .62435 Mdot
.49324 .72099 Mdot
.28057 .47826 Mdot
.26791 .56681 Mdot
.44372 .59424 Mdot
.43857 .17454 Mdot
.38898 .70781 Mdot
.30873 .52008 Mdot
.50023 .65654 Mdot
.64229 .4471 Mdot
.57138 .31299 Mdot
.39124 .21621 Mdot
.37695 .35598 Mdot
.55619 .28398 Mdot
.66987 .57755 Mdot
.39392 .34714 Mdot
.65435 .43651 Mdot
.57545 .61596 Mdot
.28922 .49288 Mdot
.54165 .32507 Mdot
.47354 .63101 Mdot
.50465 .59583 Mdot
.34023 .2698 Mdot
.52076 .82394 Mdot
.70574 .57469 Mdot
.19032 .37802 Mdot
.71333 .53491 Mdot
.30977 .49575 Mdot
.38882 .36148 Mdot
.465 .65721 Mdot
.46744 .61363 Mdot
.34198 .37228 Mdot
.68607 .58437 Mdot
.31535 .45073 Mdot
.39813 .78308 Mdot
.51114 .26219 Mdot
.31927 .59714 Mdot
.66768 .56083 Mdot
.31586 .59514 Mdot
.29447 .54032 Mdot
.53433 .21869 Mdot
.36105 .67398 Mdot
.52882 .32304 Mdot
.3228 .59979 Mdot
.67817 .5346 Mdot
.44996 .64902 Mdot
.63066 .44253 Mdot
.65173 .45582 Mdot
.66824 .5727 Mdot
.38768 .38014 Mdot
.28562 .50865 Mdot
.45574 .61918 Mdot
.58077 .54404 Mdot
.79563 .62609 Mdot
.33903 .382 Mdot
.4939 .56575 Mdot
.5596 .32991 Mdot
.49408 .61951 Mdot
.28206 .52926 Mdot
.53855 .2971 Mdot
.62699 .42513 Mdot
.53151 .49707 Mdot
.46583 .67564 Mdot
.40147 .48825 Mdot
.54901 .31713 Mdot
.44861 .82 Mdot
.46887 .60808 Mdot
.5599 .31452 Mdot
.38975 .61766 Mdot
.70943 .48337 Mdot
.46557 .40445 Mdot
.77478 .41698 Mdot
.32938 .37305 Mdot
.37224 .4081 Mdot
.61493 .82818 Mdot
.2641 .51685 Mdot
.55038 .27711 Mdot
.63082 .42826 Mdot
.34604 .65077 Mdot
.55021 .32864 Mdot
.5218 .64882 Mdot
.47059 .67128 Mdot
.46335 .77717 Mdot
.37229 .6411 Mdot
.65974 .45635 Mdot
.57563 .58498 Mdot
.51456 .65183 Mdot
.4405 .58642 Mdot
.48606 .60488 Mdot
.63537 .5627 Mdot
.53445 .3332 Mdot
.56625 .13309 Mdot
.51691 .30604 Mdot
.56311 .52797 Mdot
.36689 .37198 Mdot
.34788 .34717 Mdot
.47265 .63705 Mdot
.46807 .53345 Mdot
.48719 .16885 Mdot
.48202 .65225 Mdot
.34636 .47787 Mdot
.27059 .63655 Mdot
.41718 .6306 Mdot
.63185 .5755 Mdot
.41099 .59208 Mdot
.68771 .52169 Mdot
.53701 .29735 Mdot
.31499 .48534 Mdot
.3168 .52497 Mdot
.55237 .2993 Mdot
.47468 .617 Mdot
.31948 .52409 Mdot
.46631 .63674 Mdot
.44429 .63939 Mdot
.57547 .48312 Mdot
.27351 .51932 Mdot
.36879 .35293 Mdot
.30511 .50909 Mdot
.6938 .56362 Mdot
.19759 .72383 Mdot
.29493 .50811 Mdot
.40883 .73078 Mdot
.51063 .42268 Mdot
.32128 .60231 Mdot
.64286 .5573 Mdot
.31127 .52135 Mdot
.53032 .32921 Mdot
.5898 .4333 Mdot
.49873 .7997 Mdot
.52957 .33449 Mdot
.464 .61521 Mdot
.68752 .5285 Mdot
.64681 .58058 Mdot
.54314 .26536 Mdot
.6593 .58 Mdot
.47239 .57348 Mdot
.51688 .65679 Mdot
.54502 .27898 Mdot
.80046 .56762 Mdot
.53038 .33142 Mdot
.43837 .74953 Mdot
.48697 .67222 Mdot
.67259 .55891 Mdot
.43109 .55279 Mdot
.73228 .56275 Mdot
.64196 .45566 Mdot
.45038 .66625 Mdot
.29588 .51861 Mdot
.54423 .46642 Mdot
.36486 .3679 Mdot
.69342 .37609 Mdot
.64898 .54335 Mdot
.51237 .30239 Mdot
.64736 .57266 Mdot
.70234 .57854 Mdot
.52597 .33104 Mdot
.68802 .56176 Mdot
.46108 .6106 Mdot
.633 .26926 Mdot
.65001 .54505 Mdot
.54474 .31265 Mdot
.2921 .52012 Mdot
.68584 .58012 Mdot
.32376 .44668 Mdot
.44235 .64188 Mdot
.39574 .36506 Mdot
.28299 .48506 Mdot
.69473 .53169 Mdot
.31498 .51496 Mdot
.3651 .38652 Mdot
.28425 .50934 Mdot
.50182 .31382 Mdot
.50944 .32235 Mdot
.54232 .51658 Mdot
.68638 .48197 Mdot
.69218 .54009 Mdot
.3273 .37854 Mdot
.44603 .65647 Mdot
.4453 .62603 Mdot
.327 .47713 Mdot
.63787 .57386 Mdot
.73224 .42236 Mdot
.51229 .54756 Mdot
.73968 .44064 Mdot
.5616 .27583 Mdot
.21909 .55407 Mdot
.58323 .43816 Mdot
.59621 .39339 Mdot
.52313 .66386 Mdot
.64582 .45189 Mdot
.46715 .6441 Mdot
.2535 .6145 Mdot
.31096 .52488 Mdot
.38492 .29771 Mdot
.53761 .61011 Mdot
.35603 .36144 Mdot
.48876 .6342 Mdot
.43194 .19369 Mdot
.40796 .58978 Mdot
.29937 .53111 Mdot
.53811 .34736 Mdot
.70502 .56068 Mdot
.30132 .52574 Mdot
.38112 .40231 Mdot
.34702 .58834 Mdot
.51342 .66624 Mdot
.51203 .65848 Mdot
.35678 .42246 Mdot
.69875 .56245 Mdot
.35687 .3975 Mdot
.56089 .31104 Mdot
.29778 .50656 Mdot
.50401 .63889 Mdot
.43264 .58341 Mdot
.37061 .42607 Mdot
.52047 .29324 Mdot
.33739 .37677 Mdot
.51953 .30647 Mdot
.64191 .4514 Mdot
.42872 .62334 Mdot
.3751 .42054 Mdot
.52564 .66537 Mdot
.7266 .67133 Mdot
.562 .49797 Mdot
.67519 .75164 Mdot
.36901 .35258 Mdot
.3462 .56067 Mdot
.54951 .30305 Mdot
.54702 .3254 Mdot
.4671 .77027 Mdot
.48832 .17298 Mdot
.48699 .37509 Mdot
.36101 .21506 Mdot
.56112 .30953 Mdot
.54299 .32036 Mdot
.37542 .39983 Mdot
.6883 .56975 Mdot
.62344 .57171 Mdot
.40218 .37601 Mdot
.25643 .58003 Mdot
.67881 .53627 Mdot
.79378 .36562 Mdot
.36176 .41759 Mdot
.50599 .67822 Mdot
.65292 .46533 Mdot
.29639 .53148 Mdot
.25467 .6065 Mdot
.37685 .20746 Mdot
.46887 .65189 Mdot
.20089 .65992 Mdot
.38303 .36793 Mdot
.49659 .28644 Mdot
.549 .21969 Mdot
.4962 .59217 Mdot
.48676 .63411 Mdot
.47932 .61345 Mdot
.29177 .47726 Mdot
.76112 .6423 Mdot
.46585 .65413 Mdot
.2787 .56387 Mdot
.42329 .65441 Mdot
.32891 .26318 Mdot
.30493 .50886 Mdot
.3501 .73501 Mdot
.33358 .35315 Mdot
.73126 .47129 Mdot
.49507 .58445 Mdot
.55995 .30532 Mdot
.46596 .32776 Mdot
.55963 .28192 Mdot
.51476 .2066 Mdot
.35876 .67538 Mdot
.63425 .56102 Mdot
.50532 .60782 Mdot
.36823 .41814 Mdot
.6912 .53043 Mdot
.46619 .35784 Mdot
.17041 .68384 Mdot
.55192 .2686 Mdot
.13242 .46283 Mdot
.53781 .32914 Mdot
.65411 .4561 Mdot
.663 .57386 Mdot
.38301 .55899 Mdot
.55873 .45978 Mdot
.69755 .5672 Mdot
.22985 .46099 Mdot
.62587 .53702 Mdot
.32475 .58047 Mdot
.64321 .51965 Mdot
.54505 .30549 Mdot
.51022 .32279 Mdot
.51967 .68768 Mdot
.43653 .64745 Mdot
.55902 .44245 Mdot
.49378 .69105 Mdot
.45189 .66317 Mdot
.35345 .37405 Mdot
.68912 .47765 Mdot
.52785 .36422 Mdot
.66748 .56546 Mdot
.5304 .28533 Mdot
.48722 .63558 Mdot
.50023 .65319 Mdot
.51203 .58752 Mdot
.25117 .64683 Mdot
.79019 .35829 Mdot
.4525 .64373 Mdot
.41735 .58369 Mdot
.39158 .385 Mdot
.33603 .2693 Mdot
.21571 .3553 Mdot
.35163 .65288 Mdot
.46401 .60257 Mdot
.31164 .50249 Mdot
.29018 .5352 Mdot
.49028 .57409 Mdot
.53347 .53444 Mdot
.32208 .44066 Mdot
.47377 .63085 Mdot
.36134 .56255 Mdot
.35608 .43247 Mdot
.64889 .42809 Mdot
.36559 .38238 Mdot
.68972 .52846 Mdot
.65417 .45201 Mdot
.34545 .39477 Mdot
.41671 .53622 Mdot
.64883 .43296 Mdot
.71372 .48165 Mdot
.31357 .51949 Mdot
.47925 .6052 Mdot
.68475 .60955 Mdot
.34262 .3757 Mdot
.54731 .32125 Mdot
.66246 .54972 Mdot
.57343 .29464 Mdot
.34323 .25823 Mdot
.25915 .59856 Mdot
.62427 .43847 Mdot
.55954 .29976 Mdot
.45857 .46367 Mdot
.31016 .50354 Mdot
.5466 .33325 Mdot
.52639 .54119 Mdot
.43361 .66012 Mdot
.54949 .18392 Mdot
.52076 .64077 Mdot
.78671 .47152 Mdot
.55326 .3185 Mdot
.61899 .42909 Mdot
.46928 .6297 Mdot
.38541 .40403 Mdot
.46291 .69984 Mdot
.46493 .63636 Mdot
.35214 .41146 Mdot
.4512 .64783 Mdot
.27639 .51119 Mdot
.69633 .52704 Mdot
.49594 .41214 Mdot
.23526 .60654 Mdot
.28636 .51926 Mdot
.61763 .50751 Mdot
.43355 .64479 Mdot
.21222 .45277 Mdot
.69076 .55168 Mdot
.46939 .59499 Mdot
.28883 .71477 Mdot
.67807 .57237 Mdot
.67625 .54704 Mdot
.50928 .65206 Mdot
.53307 .33631 Mdot
.34771 .36144 Mdot
.30893 .50605 Mdot
.52724 .37013 Mdot
.46141 .64969 Mdot
.49666 .60271 Mdot
.29713 .52813 Mdot
.5385 .32219 Mdot
.50615 .63697 Mdot
.7238 .34893 Mdot
.58154 .50808 Mdot
.5215 .30467 Mdot
.42571 .65099 Mdot
.60999 .17866 Mdot
.62263 .57394 Mdot
.20884 .67498 Mdot
.26569 .51934 Mdot
.38994 .37467 Mdot
.51931 .57668 Mdot
.43547 .90954 Mdot
.30811 .5222 Mdot
.73806 .46672 Mdot
.44872 .63962 Mdot
.4683 .66052 Mdot
.63794 .54635 Mdot
.51496 .63041 Mdot
.66151 .53149 Mdot
.22476 .59224 Mdot
.4356 .15901 Mdot
.65457 .57706 Mdot
.65697 .53399 Mdot
.38054 .61971 Mdot
.25784 .66357 Mdot
.67829 .577 Mdot
.51222 .66793 Mdot
.23275 .44182 Mdot
.55309 .64647 Mdot
.27574 .53967 Mdot
.33532 .47011 Mdot
.6299 .56698 Mdot
.56292 .80234 Mdot
.38744 .60773 Mdot
.4496 .71615 Mdot
.32067 .53743 Mdot
.56181 .2917 Mdot
.48523 .66424 Mdot
.6244 .43146 Mdot
.37156 .39477 Mdot
.40762 .60334 Mdot
.47529 .60803 Mdot
.66964 .52659 Mdot
.30677 .46712 Mdot
.55376 .32824 Mdot
.48204 .60072 Mdot
.39512 .41017 Mdot
.30378 .49034 Mdot
.6498 .54884 Mdot
.41675 .73533 Mdot
.30741 .53181 Mdot
.44755 .57604 Mdot
.45789 .66425 Mdot
.47051 .60041 Mdot
.5474 .62439 Mdot
.55364 .30223 Mdot
.40145 .36256 Mdot
.52263 .58136 Mdot
.57649 .46468 Mdot
.5349 .46341 Mdot
.51152 .57696 Mdot
.69912 .57699 Mdot
.56477 .28088 Mdot
.64303 .4336 Mdot
.33245 .62358 Mdot
.48568 .67617 Mdot
.7795 .339 Mdot
.361 .78098 Mdot
.64877 .4377 Mdot
.64378 .5269 Mdot
.30555 .51288 Mdot
.50413 .66437 Mdot
.26416 .54924 Mdot
.52187 .64716 Mdot
.5625 .61829 Mdot
.38749 .37038 Mdot
.56555 .299 Mdot
.59443 .53297 Mdot
.37048 .39644 Mdot
.67608 .54769 Mdot
.81288 .48567 Mdot
.62217 .55512 Mdot
.70781 .57498 Mdot
.49205 .23211 Mdot
.54037 .28987 Mdot
.45198 .91721 Mdot
.43871 .81909 Mdot
.48575 .68342 Mdot
.53851 .28664 Mdot
.6612 .5704 Mdot
.5167 .61426 Mdot
.68788 .53814 Mdot
.6657 .59416 Mdot
.45856 .669 Mdot
.45141 .66129 Mdot
.27582 .5705 Mdot
.8043 .38907 Mdot
.29186 .51481 Mdot
.65534 .58035 Mdot
.49191 .76515 Mdot
.46218 .65667 Mdot
.45013 .61151 Mdot
.46654 .29936 Mdot
.30819 .52392 Mdot
.57798 .7413 Mdot
.44689 .62693 Mdot
.2782 .70815 Mdot
.44929 .66317 Mdot
.63716 .59246 Mdot
.55371 .26092 Mdot
.5555 .53719 Mdot
.34687 .35968 Mdot
.71568 .5556 Mdot
.32688 .48574 Mdot
.71928 .5767 Mdot
.50592 .74935 Mdot
.53657 .29518 Mdot
.65735 .53588 Mdot
.38091 .33567 Mdot
.53475 .3131 Mdot
.52715 .32213 Mdot
.46624 .36596 Mdot
.38751 .34176 Mdot
.28274 .48881 Mdot
.57061 .30856 Mdot
.53515 .73661 Mdot
.54241 .30496 Mdot
.51341 .74905 Mdot
.43569 .61804 Mdot
.29849 .56996 Mdot
.58281 .53388 Mdot
.53191 .67722 Mdot
.53854 .33461 Mdot
.2906 .49974 Mdot
.51159 .61838 Mdot
.66491 .58145 Mdot
.29287 .50336 Mdot
.50618 .35374 Mdot
.34469 .34692 Mdot
.64456 .58121 Mdot
.53059 .34137 Mdot
.67365 .52983 Mdot
.26437 .62601 Mdot
.29218 .45049 Mdot
.45683 .38819 Mdot
.55486 .45268 Mdot
.44961 .58705 Mdot
.37874 .62992 Mdot
.50833 .59487 Mdot
.47092 .61315 Mdot
.36341 .36927 Mdot
.33462 .55389 Mdot
.68677 .58011 Mdot
.81276 .60595 Mdot
.55811 .30485 Mdot
.42051 .48322 Mdot
.56533 .62043 Mdot
.49421 .64181 Mdot
.65698 .56173 Mdot
.68448 .5927 Mdot
.7252 .68639 Mdot
.34164 .37178 Mdot
.55079 .64907 Mdot
.48722 .58239 Mdot
.53451 .693 Mdot
.53218 .32712 Mdot
.73616 .34153 Mdot
.34195 .35831 Mdot
.11514 .5176 Mdot
.36559 .39595 Mdot
.24163 .38053 Mdot
.68779 .56269 Mdot
.32258 .49165 Mdot
.44482 .61751 Mdot
.71875 .51166 Mdot
.66195 .5225 Mdot
.33469 .42469 Mdot
.30329 .51736 Mdot
.74631 .33769 Mdot
.54904 .28353 Mdot
.44579 .6063 Mdot
.45526 .66897 Mdot
.51053 .64305 Mdot
.51945 .60994 Mdot
.53971 .2801 Mdot
.52586 .63583 Mdot
.56466 .3378 Mdot
.52664 .75735 Mdot
.29399 .71602 Mdot
.38452 .41243 Mdot
.32437 .27423 Mdot
.70173 .57815 Mdot
.58806 .65102 Mdot
.57117 .7509 Mdot
.56308 .49878 Mdot
.5073 .28994 Mdot
.43202 .61977 Mdot
.38653 .38292 Mdot
.44977 .1778 Mdot
.38114 .41403 Mdot
.50433 .12631 Mdot
.45165 .76852 Mdot
.78827 .43018 Mdot
.52122 .62142 Mdot
.39439 .40651 Mdot
.58929 .78875 Mdot
.43182 .58301 Mdot
.32881 .50384 Mdot
.49523 .73919 Mdot
.77895 .52938 Mdot
.3211 .50458 Mdot
.44508 .64697 Mdot
.6895 .58705 Mdot
.459 .61246 Mdot
.4399 .62523 Mdot
.48463 .64875 Mdot
.56327 .2659 Mdot
.44938 .66891 Mdot
.43718 .62203 Mdot
.50416 .81998 Mdot
.36436 .4893 Mdot
.39088 .39202 Mdot
.69187 .73222 Mdot
.30349 .4977 Mdot
.6954 .53321 Mdot
.50637 .40696 Mdot
.55396 .28863 Mdot
.72122 .68823 Mdot
.52221 .62869 Mdot
.75359 .45438 Mdot
.51069 .31863 Mdot
.3036 .48563 Mdot
.6438 .43135 Mdot
.71357 .29025 Mdot
.37811 .35043 Mdot
.65505 .45875 Mdot
.36594 .36715 Mdot
.64434 .78081 Mdot
.65554 .53383 Mdot
.4481 .58662 Mdot
.56126 .32315 Mdot
.39733 .38923 Mdot
.26955 .55639 Mdot
.48618 .61119 Mdot
.36626 .3526 Mdot
.4395 .59224 Mdot
.53711 .45454 Mdot
.51649 .4101 Mdot
.40004 .36844 Mdot
.51499 .33144 Mdot
.5317 .31279 Mdot
.32406 .48172 Mdot
.70858 .54641 Mdot
.69942 .55552 Mdot
.53699 .30334 Mdot
.14389 .56308 Mdot
.46298 .64939 Mdot
.46295 .66458 Mdot
.57832 .45625 Mdot
.51574 .60833 Mdot
.35633 .55286 Mdot
.66271 .44712 Mdot
.69679 .54141 Mdot
.51114 .6023 Mdot
.50581 .63835 Mdot
.46973 .67461 Mdot
.26204 .59882 Mdot
.36787 .38216 Mdot
.51292 .65457 Mdot
.28523 .49736 Mdot
.66302 .41811 Mdot
.44375 .65369 Mdot
.43096 .58635 Mdot
.66648 .53067 Mdot
.18272 .47228 Mdot
.55213 .31738 Mdot
.34864 .36792 Mdot
.35558 .41876 Mdot
.3037 .66505 Mdot
.71132 .59337 Mdot
.66213 .45494 Mdot
.36928 .26187 Mdot
.63437 .42924 Mdot
.31055 .51625 Mdot
.47434 .38526 Mdot
.36841 .43592 Mdot
.37682 .4068 Mdot
.52407 .34147 Mdot
.50062 .59766 Mdot
.4516 .66386 Mdot
.73146 .46289 Mdot
.47483 .66131 Mdot
.29733 .52041 Mdot
.54339 .34334 Mdot
.66268 .53275 Mdot
.2807 .52624 Mdot
.54586 .32726 Mdot
.69929 .56378 Mdot
.41855 .6398 Mdot
.52572 .59247 Mdot
.6661 .54719 Mdot
.64679 .55228 Mdot
.47771 .63884 Mdot
.57263 .82678 Mdot
.70045 .54616 Mdot
.65579 .55497 Mdot
.62019 .41264 Mdot
.38842 .35529 Mdot
.44417 .55188 Mdot
.53792 .28816 Mdot
.45622 .6105 Mdot
.38423 .41356 Mdot
.31942 .4978 Mdot
.66992 .54092 Mdot
.48614 .66702 Mdot
.45775 .64342 Mdot
.3114 .50462 Mdot
.27611 .53318 Mdot
.29179 .5235 Mdot
.56622 .27194 Mdot
.51665 .65612 Mdot
.68021 .57819 Mdot
.5482 .28288 Mdot
.29482 .53443 Mdot
.31311 .47128 Mdot
.50187 .81458 Mdot
.4703 .64928 Mdot
.32123 .52388 Mdot
.25427 .78649 Mdot
.34805 .59789 Mdot
.65726 .44947 Mdot
.38135 .42293 Mdot
.30381 .56575 Mdot
.29171 .47414 Mdot
.55525 .27877 Mdot
.37292 .49297 Mdot
.31852 .46427 Mdot
.47892 .66139 Mdot
.49664 .61779 Mdot
.52903 .64725 Mdot
.29748 .49827 Mdot
.26509 .61419 Mdot
.65779 .5843 Mdot
.63307 .67505 Mdot
.30331 .49782 Mdot
.39886 .36455 Mdot
.37718 .4229 Mdot
.36368 .39826 Mdot
.43498 .61174 Mdot
.72209 .70391 Mdot
.5052 .76107 Mdot
.5909 .73027 Mdot
.55398 .2837 Mdot
.67974 .59301 Mdot
.55978 .24615 Mdot
.67656 .5465 Mdot
.3782 .38331 Mdot
.2995 .49186 Mdot
.63593 .55087 Mdot
.52644 .31654 Mdot
.52982 .31584 Mdot
.33578 .37753 Mdot
.36246 .3863 Mdot
.34982 .38297 Mdot
.71419 .55311 Mdot
.68814 .56211 Mdot
.50214 .64565 Mdot
.66232 .53964 Mdot
.37128 .79261 Mdot
.27044 .53799 Mdot
.3463 .4212 Mdot
.55088 .31167 Mdot
.65156 .55817 Mdot
.47587 .60529 Mdot
.27545 .35673 Mdot
.33498 .42258 Mdot
.28379 .52047 Mdot
.62079 .3121 Mdot
.38554 .16242 Mdot
.42261 .64066 Mdot
.52505 .28661 Mdot
.53471 .53749 Mdot
.48282 .61731 Mdot
.38487 .36115 Mdot
.37299 .76429 Mdot
.64316 .42788 Mdot
.4352 .6346 Mdot
.4783 .59162 Mdot
.53314 .33458 Mdot
.5102 .4083 Mdot
.48192 .65642 Mdot
.45298 .43899 Mdot
.54036 .27065 Mdot
.34134 .35925 Mdot
.63662 .82824 Mdot
.49538 .2978 Mdot
.23774 .5569 Mdot
.6544 .44089 Mdot
.47495 .66516 Mdot
.35553 .37234 Mdot
.28076 .51146 Mdot
.35897 .37753 Mdot
.63629 .53199 Mdot
.38571 .35548 Mdot
.49272 .60796 Mdot
.68487 .57702 Mdot
.53991 .3244 Mdot
.40794 .48818 Mdot
.5355 .81605 Mdot
.38578 .403 Mdot
.64354 .42288 Mdot
.44659 .65409 Mdot
.56136 .71837 Mdot
.51677 .69022 Mdot
.43308 .63896 Mdot
.56416 .285 Mdot
.66111 .56408 Mdot
.56205 .27677 Mdot
.41994 .6135 Mdot
.59288 .61917 Mdot
.5573 .30158 Mdot
.76679 .53329 Mdot
.29746 .52872 Mdot
.25603 .58153 Mdot
.46556 .62162 Mdot
.56192 .32145 Mdot
.51217 .66293 Mdot
.65401 .58025 Mdot
.52756 .48287 Mdot
.59775 .54985 Mdot
.56018 .32977 Mdot
.79788 .47839 Mdot
.51868 .43733 Mdot
.43054 .55991 Mdot
.56058 .31621 Mdot
.71533 .721 Mdot
.6421 .4447 Mdot
.31377 .49208 Mdot
.28071 .53451 Mdot
.30295 .47892 Mdot
.4717 .66321 Mdot
.49599 .72684 Mdot
.30066 .47565 Mdot
.56436 .27268 Mdot
.28394 .49239 Mdot
.26064 .65429 Mdot
.73686 .4296 Mdot
.289 .52497 Mdot
.4621 .62352 Mdot
.42292 .59693 Mdot
.36413 .4937 Mdot
.36693 .33774 Mdot
.74763 .31233 Mdot
.47166 .80359 Mdot
.46631 .65708 Mdot
.52503 .72404 Mdot
.62908 .54837 Mdot
.45383 .51288 Mdot
.58704 .58609 Mdot
.50574 .38552 Mdot
.65338 .55543 Mdot
.54238 .42828 Mdot
.701 .54286 Mdot
.42877 .60337 Mdot
.45328 .63863 Mdot
.67679 .52097 Mdot
.67658 .36849 Mdot
.77555 .66758 Mdot
.74372 .44005 Mdot
.70253 .57001 Mdot
.55721 .31978 Mdot
.53427 .27576 Mdot
.56522 .28785 Mdot
.34425 .37716 Mdot
.64658 .54384 Mdot
.49661 .67288 Mdot
.38447 .39725 Mdot
.44558 .62072 Mdot
.53209 .30542 Mdot
.58155 .51047 Mdot
.66243 .53235 Mdot
.47335 .62847 Mdot
.50921 .79424 Mdot
.37219 .37036 Mdot
.3105 .50061 Mdot
.62805 .29724 Mdot
.36986 .43069 Mdot
.5166 .31195 Mdot
.66336 .59678 Mdot
.37575 .3226 Mdot
.25262 .34367 Mdot
.49636 .6819 Mdot
.49746 .68022 Mdot
.31789 .35996 Mdot
.53159 .80346 Mdot
.49059 .64255 Mdot
.37928 .40364 Mdot
.39132 .35653 Mdot
.5049 .67149 Mdot
.6411 .56144 Mdot
.30585 .46992 Mdot
.32716 .47794 Mdot
.45792 .58932 Mdot
.55545 .44338 Mdot
.28935 .56836 Mdot
.51072 .6286 Mdot
.51446 .56574 Mdot
.37429 .33446 Mdot
.65433 .43702 Mdot
.56421 .47636 Mdot
.31694 .47697 Mdot
.44732 .63847 Mdot
.7856 .63351 Mdot
.65348 .5405 Mdot
.35263 .3571 Mdot
.52616 .29805 Mdot
.31751 .52605 Mdot
.33511 .40164 Mdot
.50443 .6719 Mdot
.50613 .63742 Mdot
.55468 .32958 Mdot
.64084 .59426 Mdot
.29677 .49615 Mdot
.38687 .39387 Mdot
.32285 .49158 Mdot
.69072 .55899 Mdot
.65387 .5485 Mdot
.4827 .58156 Mdot
.5262 .68122 Mdot
.36935 .41365 Mdot
.53191 .60815 Mdot
.36205 .40291 Mdot
.33959 .26954 Mdot
.52515 .29412 Mdot
.48681 .59251 Mdot
.72358 .58554 Mdot
.53295 .305 Mdot
.47493 .65231 Mdot
.31882 .35663 Mdot
.5028 .63015 Mdot
.40106 .38843 Mdot
.39682 .7758 Mdot
.31497 .4808 Mdot
.39582 .6618 Mdot
.38892 .57798 Mdot
.51462 .6076 Mdot
.38587 .34518 Mdot
.47491 .73053 Mdot
.55539 .29789 Mdot
.68069 .56684 Mdot
.16734 .48994 Mdot
.54372 .3104 Mdot
.45411 .62413 Mdot
.29554 .50684 Mdot
.70634 .56196 Mdot
.634 .44944 Mdot
.57042 .43533 Mdot
.40644 .60588 Mdot
.44801 .69102 Mdot
.47601 .59993 Mdot
.36298 .21288 Mdot
.3524 .37985 Mdot
.65733 .56539 Mdot
.5314 .27997 Mdot
.54283 .2922 Mdot
.37363 .37826 Mdot
.78189 .51014 Mdot
.71604 .38656 Mdot
.30394 .82863 Mdot
.33979 .41273 Mdot
.28941 .4876 Mdot
.52615 .4719 Mdot
.36833 .39949 Mdot
.35214 .3689 Mdot
.34781 .34266 Mdot
.73114 .45 Mdot
.70007 .5726 Mdot
.45706 .64544 Mdot
.72088 .57652 Mdot
.47356 .66538 Mdot
.24049 .5496 Mdot
.53662 .30004 Mdot
.68261 .56627 Mdot
.29508 .43465 Mdot
.38952 .6096 Mdot
.48599 .62526 Mdot
.23581 .52654 Mdot
.41263 .64629 Mdot
.32808 .60796 Mdot
.51278 .58685 Mdot
.36436 .37663 Mdot
.59944 .6042 Mdot
.4771 .56517 Mdot
.50112 .79163 Mdot
.53181 .32036 Mdot
.62679 .44438 Mdot
.41542 .63237 Mdot
.47275 .55464 Mdot
.70777 .56199 Mdot
.63622 .54851 Mdot
.30132 .47486 Mdot
.63512 .28057 Mdot
.53404 .32246 Mdot
.76591 .387 Mdot
.4351 .64598 Mdot
.53573 .36536 Mdot
.38751 .77525 Mdot
.47935 .64546 Mdot
.46643 .37556 Mdot
.72241 .68736 Mdot
.4961 .637 Mdot
.60347 .72011 Mdot
.54922 .3085 Mdot
.28287 .71043 Mdot
.52182 .59352 Mdot
.38258 .35991 Mdot
.6874 .56874 Mdot
.64538 .58143 Mdot
.2816 .52071 Mdot
.4009 .80747 Mdot
.59382 .27751 Mdot
.68686 .56464 Mdot
.48128 .61131 Mdot
.55101 .31708 Mdot
.63468 .45148 Mdot
.39667 .61302 Mdot
.49975 .19285 Mdot
.66158 .53724 Mdot
.52044 .57879 Mdot
.75361 .44599 Mdot
.52851 .41767 Mdot
.80514 .37991 Mdot
.56886 .3002 Mdot
.31833 .47666 Mdot
.54285 .64585 Mdot
.36552 .26521 Mdot
.52762 .59657 Mdot
.23945 .55223 Mdot
.73164 .58524 Mdot
.31607 .51416 Mdot
.4794 .61955 Mdot
.48402 .6543 Mdot
.55057 .46445 Mdot
.28411 .53749 Mdot
.48213 .65666 Mdot
.53522 .59297 Mdot
.69666 .55609 Mdot
.66277 .44592 Mdot
.66617 .53281 Mdot
.46455 .61387 Mdot
.39339 .76245 Mdot
.63742 .5594 Mdot
.74899 .32218 Mdot
.26809 .50052 Mdot
.55494 .28901 Mdot
.48522 .56283 Mdot
.43259 .62504 Mdot
.71994 .24482 Mdot
.64409 .45616 Mdot
.19271 .38942 Mdot
.39392 .40638 Mdot
.78598 .6931 Mdot
.3644 .43336 Mdot
.79455 .44642 Mdot
.42793 .47366 Mdot
.53229 .62778 Mdot
.37297 .66381 Mdot
.59439 .72115 Mdot
.51866 .35159 Mdot
.57713 .68026 Mdot
.43665 .64757 Mdot
.45069 .65351 Mdot
.37695 .40076 Mdot
.78169 .49284 Mdot
.55319 .5395 Mdot
.56192 .47255 Mdot
.30573 .48594 Mdot
.68292 .55602 Mdot
.49383 .61126 Mdot
.64388 .35085 Mdot
.39402 .39227 Mdot
.40308 .73453 Mdot
.47116 .62801 Mdot
.55713 .53006 Mdot
.76066 .50281 Mdot
.54318 .32496 Mdot
.39984 .36414 Mdot
.39514 .35288 Mdot
.4756 .66876 Mdot
.5412 .28203 Mdot
.49927 .64263 Mdot
.51698 .44293 Mdot
.41085 .59841 Mdot
.31583 .50919 Mdot
.4489 .61121 Mdot
.36411 .62746 Mdot
.82349 .48146 Mdot
.43507 .56895 Mdot
.71324 .56199 Mdot
.34748 .38715 Mdot
.36964 .3866 Mdot
.69993 .55631 Mdot
.37039 .38655 Mdot
.63255 .6829 Mdot
.55676 .69215 Mdot
.31183 .51596 Mdot
.56491 .76228 Mdot
.31306 .48269 Mdot
.62523 .44223 Mdot
.47321 .64644 Mdot
.42709 .24575 Mdot
.33859 .41161 Mdot
.26756 .68176 Mdot
.54081 .30209 Mdot
.6484 .45656 Mdot
.47443 .67883 Mdot
.33094 .51309 Mdot
.38211 .38383 Mdot
.48425 .30345 Mdot
.47423 .67288 Mdot
.67728 .58479 Mdot
.49347 .64212 Mdot
.4431 .67902 Mdot
.65714 .45513 Mdot
.48094 .59857 Mdot
.54607 .32716 Mdot
.64753 .5401 Mdot
.78595 .43788 Mdot
.34301 .3755 Mdot
.4384 .63988 Mdot
.48138 .61247 Mdot
.63748 .53977 Mdot
.4684 .67982 Mdot
.55142 .27903 Mdot
.505 .9175 Mdot
.30135 .52668 Mdot
.65333 .43478 Mdot
.64516 .23714 Mdot
.50203 .61004 Mdot
.51026 .62181 Mdot
.51229 .37594 Mdot
.77729 .63959 Mdot
.55833 .31031 Mdot
.41681 .64392 Mdot
.39436 .37998 Mdot
.29392 .49785 Mdot
.5712 .3141 Mdot
.51955 .65104 Mdot
.45353 .65476 Mdot
.31026 .51998 Mdot
.23968 .53299 Mdot
.31504 .44833 Mdot
.55789 .28363 Mdot
.54465 .69944 Mdot
.27968 .35564 Mdot
.46554 .6429 Mdot
.61273 .432 Mdot
.66101 .55849 Mdot
.56242 .30952 Mdot
.76419 .63518 Mdot
.43244 .60047 Mdot
.52215 .32487 Mdot
.53809 .32412 Mdot
.46362 .678 Mdot
.70495 .59626 Mdot
.70594 .58843 Mdot
.65895 .55843 Mdot
.2981 .7131 Mdot
.2456 .3202 Mdot
.34839 .38085 Mdot
.54745 .31507 Mdot
.37971 .41721 Mdot
.32136 .46722 Mdot
.53657 .46187 Mdot
.39747 .36282 Mdot
.69924 .58093 Mdot
.37035 .41874 Mdot
.50206 .63705 Mdot
.52595 .31159 Mdot
.35924 .41714 Mdot
.51642 .61768 Mdot
.52273 .57156 Mdot
.37187 .64901 Mdot
.30457 .4694 Mdot
.54368 .42823 Mdot
.45767 .61961 Mdot
.64515 .43273 Mdot
.47599 .63639 Mdot
.54668 .27817 Mdot
.37482 .49639 Mdot
.51926 .64106 Mdot
.33969 .41361 Mdot
.26377 .31819 Mdot
.37829 .3433 Mdot
.45666 .68207 Mdot
.46324 .61518 Mdot
.46538 .64614 Mdot
.45666 .66726 Mdot
.77677 .5381 Mdot
.55375 .34855 Mdot
.56105 .62333 Mdot
.33595 .39749 Mdot
.67241 .54435 Mdot
.63949 .56956 Mdot
.50466 .37901 Mdot
.64656 .45842 Mdot
.53857 .28524 Mdot
.46398 .6473 Mdot
.48322 .30806 Mdot
.58375 .42335 Mdot
.74908 .44125 Mdot
.36552 .31702 Mdot
.37393 .40841 Mdot
.71506 .56795 Mdot
.35385 .4091 Mdot
.51733 .6567 Mdot
.53066 .59568 Mdot
.78668 .4315 Mdot
.5736 .27699 Mdot
.29809 .4943 Mdot
.44686 .6178 Mdot
.25922 .57218 Mdot
.39152 .38513 Mdot
.37988 .33629 Mdot
.49863 .6461 Mdot
.63152 .58221 Mdot
.84059 .44593 Mdot
.53178 .29132 Mdot
.55682 .72147 Mdot
.60766 .58845 Mdot
.55118 .67806 Mdot
.55121 .29725 Mdot
.46347 .39549 Mdot
.3567 .34257 Mdot
.45009 .80911 Mdot
.66521 .54526 Mdot
.30058 .49352 Mdot
.50947 .57966 Mdot
.69988 .58059 Mdot
.37037 .42304 Mdot
.69343 .53414 Mdot
.446 .58674 Mdot
.55874 .27105 Mdot
.36868 .39329 Mdot
.53276 .35415 Mdot
.67149 .5214 Mdot
.31351 .48181 Mdot
.27662 .67838 Mdot
.54636 .73545 Mdot
.72278 .68661 Mdot
.51195 .65606 Mdot
.4598 .25097 Mdot
.4942 .67357 Mdot
.70536 .58233 Mdot
.465 .62169 Mdot
.38013 .6361 Mdot
.34656 .34847 Mdot
.4954 .56995 Mdot
.44348 .61442 Mdot
.49313 .78691 Mdot
.4848 .63592 Mdot
.48137 .67901 Mdot
.47341 .59001 Mdot
.63999 .597 Mdot
.49224 .57036 Mdot
.67774 .58434 Mdot
.74361 .46595 Mdot
.3537 .3671 Mdot
.3242 .47304 Mdot
.32445 .50252 Mdot
.23371 .54893 Mdot
.25896 .5785 Mdot
.77884 .50073 Mdot
.68009 .53819 Mdot
.53467 .33118 Mdot
.50065 .64164 Mdot
.69792 .74176 Mdot
.36712 .73101 Mdot
.34723 .35037 Mdot
.36915 .41617 Mdot
.5199 .58623 Mdot
.45744 .16119 Mdot
.50124 .5728 Mdot
.58043 .44415 Mdot
.47066 .66549 Mdot
.47684 .59343 Mdot
.38896 .34032 Mdot
.2618 .62206 Mdot
.51296 .65463 Mdot
.70753 .56106 Mdot
.30798 .49125 Mdot
.57469 .62266 Mdot
.35516 .72989 Mdot
.44506 .75435 Mdot
.49787 .54121 Mdot
.52443 .62887 Mdot
.38976 .38305 Mdot
.70463 .56848 Mdot
.57316 .4644 Mdot
.55348 .2816 Mdot
.56181 .43805 Mdot
.52504 .75384 Mdot
.56135 .23135 Mdot
.30309 .49073 Mdot
.32377 .40067 Mdot
.49308 .60726 Mdot
.34489 .37839 Mdot
.42254 .61386 Mdot
.584 .41125 Mdot
.31879 .50454 Mdot
.70866 .54224 Mdot
.55651 .32033 Mdot
.68056 .58624 Mdot
.67858 .74848 Mdot
.37479 .73971 Mdot
.78546 .69474 Mdot
.36977 .34872 Mdot
.71907 .6245 Mdot
.6704 .57355 Mdot
.48132 .67414 Mdot
.29707 .82239 Mdot
.66639 .55991 Mdot
.6853 .58447 Mdot
.50438 .38955 Mdot
.28294 .66963 Mdot
.50857 .57227 Mdot
.69521 .53818 Mdot
.33533 .34739 Mdot
.30142 .51348 Mdot
.51603 .623 Mdot
.44361 .59272 Mdot
.63689 .54818 Mdot
.38078 .38111 Mdot
.24802 .56884 Mdot
.36396 .38171 Mdot
.69644 .57473 Mdot
.37258 .36389 Mdot
.7459 .32586 Mdot
.3973 .37893 Mdot
.44386 .61262 Mdot
.46391 .64615 Mdot
.45603 .20807 Mdot
.6539 .54846 Mdot
.51084 .61949 Mdot
.44976 .64472 Mdot
.67438 .57702 Mdot
.37018 .43521 Mdot
.75498 .62884 Mdot
.51096 .60962 Mdot
.46003 .64742 Mdot
.31297 .52221 Mdot
.53311 .43765 Mdot
.59844 .41741 Mdot
.51422 .62118 Mdot
.29693 .48282 Mdot
.71633 .55835 Mdot
.47749 .63613 Mdot
.26 .62018 Mdot
.35906 .43159 Mdot
.52476 .6143 Mdot
.62799 .44279 Mdot
.48658 .6469 Mdot
.837 .44691 Mdot
.44458 .65072 Mdot
.66062 .57251 Mdot
.6811 .57211 Mdot
.33468 .44073 Mdot
.67479 .5488 Mdot
.6561 .45158 Mdot
.53255 .31031 Mdot
.80866 .49973 Mdot
.65442 .45327 Mdot
.4576 .59908 Mdot
.43684 .81949 Mdot
.44954 .58948 Mdot
.42537 .58891 Mdot
.26034 .67162 Mdot
.65477 .44416 Mdot
.66456 .56658 Mdot
.67542 .36433 Mdot
.53095 .62022 Mdot
.535 .28753 Mdot
.43146 .58379 Mdot
.52499 .61438 Mdot
.37604 .64621 Mdot
.55876 .68354 Mdot
.54499 .34456 Mdot
.43621 .55489 Mdot
.51577 .62386 Mdot
.77448 .64143 Mdot
.48553 .60708 Mdot
.28673 .52533 Mdot
.68846 .54047 Mdot
.3476 .40425 Mdot
.30888 .51564 Mdot
.49766 .60865 Mdot
.2996 .49818 Mdot
.34765 .37689 Mdot
.5678 .31409 Mdot
.45311 .60834 Mdot
.27629 .54087 Mdot
.29843 .49185 Mdot
.49758 .66059 Mdot
.68569 .56675 Mdot
.50954 .69472 Mdot
.4788 .63733 Mdot
.49308 .67917 Mdot
.69906 .55477 Mdot
.25095 .73107 Mdot
.46244 .66981 Mdot
.46404 .39062 Mdot
.69457 .52231 Mdot
.66115 .44922 Mdot
.36519 .40771 Mdot
.53287 .65177 Mdot
.54135 .29103 Mdot
.53509 .30659 Mdot
.33412 .37446 Mdot
.64431 .53611 Mdot
.37132 .39111 Mdot
.40615 .58911 Mdot
.52909 .59176 Mdot
.51083 .5806 Mdot
.1674 .48844 Mdot
.70523 .28014 Mdot
.64928 .56325 Mdot
.36957 .33958 Mdot
.55964 .44815 Mdot
.53016 .29781 Mdot
.36543 .33325 Mdot
.72669 .56243 Mdot
.6615 .52761 Mdot
.70108 .55436 Mdot
.29507 .48749 Mdot
.36264 .39224 Mdot
.72397 .54316 Mdot
.69742 .59177 Mdot
.49867 .65328 Mdot
.51637 .62584 Mdot
.62728 .53827 Mdot
.36528 .45309 Mdot
.31848 .49217 Mdot
.39086 .37082 Mdot
.8124 .32672 Mdot
.53163 .2911 Mdot
.49302 .7876 Mdot
.51569 .61609 Mdot
.11583 .6085 Mdot
.49884 .57286 Mdot
.48247 .60987 Mdot
.68953 .52832 Mdot
.30264 .53734 Mdot
.3017 .50995 Mdot
.67202 .57384 Mdot
.64853 .59163 Mdot
.28606 .50156 Mdot
.48735 .38284 Mdot
.82329 .52316 Mdot
.56938 .45749 Mdot
.66084 .57532 Mdot
.55221 .73611 Mdot
.5698 .31574 Mdot
.70841 .53401 Mdot
.5383 .35108 Mdot
.35237 .36683 Mdot
.38369 .40696 Mdot
.55353 .33161 Mdot
.47349 .67657 Mdot
.37366 .3514 Mdot
.41471 .58181 Mdot
.78709 .40235 Mdot
.53478 .20625 Mdot
.71008 .74959 Mdot
.43178 .6429 Mdot
.54145 .53528 Mdot
.70617 .45725 Mdot
.48832 .59885 Mdot
.4273 .55366 Mdot
.29802 .49609 Mdot
.69978 .52647 Mdot
.57038 .32195 Mdot
.76329 .31764 Mdot
.46521 .64425 Mdot
.68754 .57988 Mdot
.52619 .3058 Mdot
.74036 .32573 Mdot
.45324 .43762 Mdot
.48975 .65465 Mdot
.36107 .86787 Mdot
.67061 .52217 Mdot
.34758 .4039 Mdot
.53975 .78306 Mdot
.7212 .5653 Mdot
.27701 .33903 Mdot
.40357 .36745 Mdot
.59852 .49398 Mdot
.67937 .52669 Mdot
.31737 .452 Mdot
.68829 .55514 Mdot
.27679 .51554 Mdot
.66063 .59674 Mdot
.37751 .37257 Mdot
.48134 .62519 Mdot
.37459 .3734 Mdot
.29615 .53215 Mdot
.35445 .35287 Mdot
.57002 .32257 Mdot
.65179 .43677 Mdot
.5291 .31233 Mdot
.53272 .46377 Mdot
.71642 .64996 Mdot
.56566 .29864 Mdot
.47656 .31535 Mdot
.49323 .63554 Mdot
.63643 .59187 Mdot
.34259 .39781 Mdot
.33074 .39792 Mdot
.54933 .4337 Mdot
.69715 .56875 Mdot
.38103 .36974 Mdot
.53774 .73907 Mdot
.14141 .57559 Mdot
.46312 .56353 Mdot
.25746 .3052 Mdot
.67138 .57725 Mdot
.3511 .34366 Mdot
.57868 .45353 Mdot
.63709 .57209 Mdot
.36436 .41566 Mdot
.55927 .31993 Mdot
.54618 .29044 Mdot
.46009 .67511 Mdot
.54436 .2642 Mdot
.38679 .3449 Mdot
.78344 .63596 Mdot
.69368 .5445 Mdot
.68519 .26549 Mdot
.28713 .5205 Mdot
.34975 .37107 Mdot
.5015 .57053 Mdot
.73613 .57214 Mdot
.35482 .41999 Mdot
.49537 .17955 Mdot
.77134 .28263 Mdot
.38136 .36905 Mdot
.68723 .53958 Mdot
.67353 .54141 Mdot
.43538 .57032 Mdot
.55734 .45625 Mdot
.38285 .37852 Mdot
.42577 .24481 Mdot
.26375 .5593 Mdot
.64198 .45155 Mdot
.4875 .81267 Mdot
.51322 .6549 Mdot
.52486 .62616 Mdot
.55428 .27997 Mdot
.48823 .62559 Mdot
.6667 .59463 Mdot
.50242 .5756 Mdot
.54268 .27118 Mdot
.34137 .36037 Mdot
.4704 .64544 Mdot
.2897 .50296 Mdot
.56507 .28343 Mdot
.51847 .29397 Mdot
.36456 .36227 Mdot
.69332 .54059 Mdot
.66059 .37174 Mdot
.3639 .38373 Mdot
.51946 .64943 Mdot
.64782 .44106 Mdot
.51127 .58745 Mdot
.458 .21434 Mdot
.66085 .58564 Mdot
.35323 .40847 Mdot
.65069 .5203 Mdot
.54324 .31799 Mdot
.33116 .36719 Mdot
.48799 .60328 Mdot
.37721 .40892 Mdot
.45551 .39774 Mdot
.22753 .42289 Mdot
.67874 .59518 Mdot
.35113 .48424 Mdot
.63629 .54589 Mdot
.64101 .45158 Mdot
.3054 .64637 Mdot
.31545 .49273 Mdot
.39244 .36296 Mdot
.74614 .31584 Mdot
.33951 .39594 Mdot
.48403 .63976 Mdot
.45854 .66311 Mdot
.37529 .40192 Mdot
.30721 .48022 Mdot
.22839 .57992 Mdot
.27995 .55425 Mdot
.65128 .54029 Mdot
.44342 .47752 Mdot
.83602 .36987 Mdot
.39588 .33216 Mdot
.53775 .33304 Mdot
.52163 .55626 Mdot
.5014 .62649 Mdot
.52855 .33227 Mdot
.52944 .28675 Mdot
.29301 .53468 Mdot
.34504 .37384 Mdot
.70735 .52784 Mdot
.56189 .33059 Mdot
.73774 .55527 Mdot
.24933 .58936 Mdot
.41961 .65956 Mdot
.51256 .71265 Mdot
.43813 .61167 Mdot
.52932 .41793 Mdot
.55172 .27208 Mdot
.45678 .6267 Mdot
.53971 .60208 Mdot
.56159 .30456 Mdot
.28678 .53252 Mdot
.69419 .50794 Mdot
.37911 .36176 Mdot
.12769 .58706 Mdot
.45181 .60913 Mdot
.4807 .62993 Mdot
.55369 .28379 Mdot
.54694 .80347 Mdot
.65102 .56971 Mdot
.69041 .53797 Mdot
.35192 .38063 Mdot
.56206 .40462 Mdot
.47599 .68231 Mdot
.47105 .60379 Mdot
.37787 .35445 Mdot
.64517 .43349 Mdot
.63622 .81396 Mdot
.45814 .64065 Mdot
.55107 .30457 Mdot
.4659 .33025 Mdot
.55619 .27307 Mdot
.42115 .63564 Mdot
.48169 .64558 Mdot
.45855 .60243 Mdot
.43771 .65808 Mdot
.55142 .33554 Mdot
.48157 .60046 Mdot
.46428 .69937 Mdot
.6618 .56314 Mdot
.52148 .63928 Mdot
.26556 .56268 Mdot
.46156 .63938 Mdot
.29012 .50359 Mdot
.6015 .40678 Mdot
.44001 .64056 Mdot
.52225 .63799 Mdot
.26224 .55369 Mdot
.47734 .61657 Mdot
.52466 .31693 Mdot
.6666 .54275 Mdot
.54478 .31895 Mdot
.53599 .32856 Mdot
.36372 .42029 Mdot
.27599 .5245 Mdot
.53695 .61184 Mdot
.28609 .49886 Mdot
.41695 .58309 Mdot
.43411 .59708 Mdot
.53392 .45079 Mdot
.58038 .44283 Mdot
.31507 .46099 Mdot
.47979 .60325 Mdot
.35353 .37526 Mdot
.3571 .41079 Mdot
.37252 .49289 Mdot
.41002 .59509 Mdot
.56921 .32075 Mdot
.5619 .32119 Mdot
.35724 .55362 Mdot
.37728 .52885 Mdot
.29421 .49445 Mdot
.5172 .49657 Mdot
.4365 .60246 Mdot
.44605 .64542 Mdot
.42406 .59423 Mdot
.39372 .40438 Mdot
.65181 .43507 Mdot
.34066 .36495 Mdot
.62454 .4128 Mdot
.57335 .29673 Mdot
.43173 .64223 Mdot
.55345 .20603 Mdot
.64046 .55266 Mdot
.6653 .54257 Mdot
.53921 .27182 Mdot
.37989 .34343 Mdot
.4099 .5984 Mdot
.15921 .42576 Mdot
.64621 .58548 Mdot
.32353 .47464 Mdot
.46077 .61175 Mdot
.35946 .36467 Mdot
.64733 .53816 Mdot
.27312 .51065 Mdot
.42988 .63257 Mdot
.39139 .33725 Mdot
.46327 .62881 Mdot
.60329 .73633 Mdot
.67139 .56695 Mdot
.5828 .50596 Mdot
.62172 .56443 Mdot
.53535 .33416 Mdot
.55513 .31652 Mdot
.47624 .65129 Mdot
.13826 .49862 Mdot
.64793 .50817 Mdot
.52595 .33367 Mdot
.27914 .49705 Mdot
.64828 .43109 Mdot
.2755 .50516 Mdot
.36362 .40289 Mdot
.30753 .48993 Mdot
.3525 .41877 Mdot
.37403 .45036 Mdot
.65556 .51096 Mdot
.30615 .52146 Mdot
.54856 .80821 Mdot
.53107 .59658 Mdot
.29838 .53388 Mdot
.51663 .58481 Mdot
.38198 .62139 Mdot
.36972 .3539 Mdot
.29585 .48871 Mdot
.48691 .66694 Mdot
.64391 .23 Mdot
.54583 .32622 Mdot
.56859 .32389 Mdot
.53181 .6012 Mdot
.35135 .34175 Mdot
.66666 .59635 Mdot
.49969 .41669 Mdot
.66018 .44295 Mdot
.47062 .60432 Mdot
.42947 .62087 Mdot
.65646 .5214 Mdot
.70675 .57573 Mdot
.47764 .65159 Mdot
.5462 .72442 Mdot
.49427 .60654 Mdot
.5492 .29067 Mdot
.64786 .54267 Mdot
.66864 .54074 Mdot
.39346 .35458 Mdot
.64338 .53759 Mdot
.54848 .66256 Mdot
.51545 .27801 Mdot
.47208 .57671 Mdot
.54296 .31486 Mdot
.38052 .46607 Mdot
.34404 .36874 Mdot
.74393 .30912 Mdot
.64773 .53469 Mdot
.5109 .60169 Mdot
.63972 .5684 Mdot
.29261 .52324 Mdot
.65442 .54638 Mdot
.62864 .54371 Mdot
.44198 .65483 Mdot
.47929 .66248 Mdot
.64485 .43594 Mdot
.55479 .44665 Mdot
.67697 .56438 Mdot
.50323 .60422 Mdot
.50879 .58986 Mdot
.46697 .67056 Mdot
.51946 .43456 Mdot
.69915 .53499 Mdot
.47301 .77153 Mdot
.49068 .20986 Mdot
.68377 .56437 Mdot
.80794 .35657 Mdot
.63053 .42971 Mdot
.64431 .45808 Mdot
.51597 .32665 Mdot
.4578 .64596 Mdot
.37284 .38627 Mdot
.5257 .62153 Mdot
.40965 .59315 Mdot
.43797 .63574 Mdot
.31184 .51962 Mdot
.50061 .6802 Mdot
.63147 .43996 Mdot
.36676 .37853 Mdot
.50464 .60793 Mdot
.46639 .65052 Mdot
.63272 .45189 Mdot
.62206 .55197 Mdot
.66096 .52827 Mdot
.62856 .4645 Mdot
.2881 .53101 Mdot
.56076 .28267 Mdot
.52516 .63408 Mdot
.35311 .37795 Mdot
.3726 .37905 Mdot
.68186 .58569 Mdot
.38463 .36267 Mdot
.55711 .27768 Mdot
.48761 .60997 Mdot
.53708 .33542 Mdot
.31152 .51989 Mdot
.68908 .54096 Mdot
.52111 .64825 Mdot
.49622 .65662 Mdot
.68075 .57209 Mdot
.49165 .6402 Mdot
.31507 .51788 Mdot
.39479 .39801 Mdot
.64823 .55175 Mdot
.53336 .30998 Mdot
.39625 .35905 Mdot
.50406 .63684 Mdot
.656 .1875 Mdot
.48905 .62539 Mdot
.46307 .60399 Mdot
.80358 .47962 Mdot
.49214 .58505 Mdot
.33954 .38384 Mdot
.63665 .56398 Mdot
.42332 .64415 Mdot
.26124 .55685 Mdot
.26762 .45736 Mdot
.40207 .3465 Mdot
.46089 .61026 Mdot
.794 .35605 Mdot
.51359 .6043 Mdot
.76292 .34582 Mdot
.53478 .45154 Mdot
.37768 .20971 Mdot
.50841 .71369 Mdot
.52499 .33233 Mdot
.6469 .43493 Mdot
.33752 .38486 Mdot
.62223 .77283 Mdot
.49105 .63276 Mdot
.73738 .68244 Mdot
.5263 .63359 Mdot
.55023 .29538 Mdot
.47854 .54543 Mdot
.38985 .36857 Mdot
.4751 .80454 Mdot
.49776 .67411 Mdot
.68586 .52759 Mdot
.3279 .37079 Mdot
.6419 .42901 Mdot
.48323 .66914 Mdot
.28345 .51243 Mdot
.28332 .45591 Mdot
.54539 .66563 Mdot
.54076 .31573 Mdot
.44753 .64202 Mdot
.4732 .55119 Mdot
.14907 .56607 Mdot
.65741 .56115 Mdot
.54587 .33041 Mdot
.44567 .52418 Mdot
.46179 .66582 Mdot
.66395 .52729 Mdot
.66769 .54493 Mdot
.2796 .51259 Mdot
.58652 .39165 Mdot
.25019 .46514 Mdot
.55633 .18646 Mdot
.71234 .71009 Mdot
.39792 .397 Mdot
.75238 .52889 Mdot
.51737 .63926 Mdot
.37865 .74449 Mdot
.53261 .32527 Mdot
.48017 .6269 Mdot
.69612 .7018 Mdot
.65583 .55559 Mdot
.45929 .6315 Mdot
.31841 .49538 Mdot
.69004 .4135 Mdot
.49762 .74209 Mdot
.69188 .22476 Mdot
.34237 .34188 Mdot
.46297 .57038 Mdot
.53635 .68055 Mdot
.66083 .44866 Mdot
.42192 .63535 Mdot
.34037 .3923 Mdot
.46478 .25622 Mdot
.31687 .47927 Mdot
.64148 .5494 Mdot
.63327 .42835 Mdot
.52825 .62465 Mdot
.46928 .58749 Mdot
.32089 .47178 Mdot
.48884 .67242 Mdot
.52816 .77895 Mdot
.6287 .45144 Mdot
.3973 .38149 Mdot
.69605 .5366 Mdot
.43736 .61137 Mdot
.64826 .43273 Mdot
.44622 .65859 Mdot
.37792 .58887 Mdot
.45439 .6146 Mdot
.79692 .51924 Mdot
.68837 .56805 Mdot
.53622 .31752 Mdot
.50794 .6767 Mdot
.46757 .63548 Mdot
.28054 .35907 Mdot
.40822 .59824 Mdot
.44677 .65257 Mdot
.69919 .5831 Mdot
.6387 .55823 Mdot
.69402 .57937 Mdot
.39636 .36598 Mdot
.56722 .46493 Mdot
.54423 .29909 Mdot
.41771 .5964 Mdot
.56645 .32394 Mdot
.4678 .71139 Mdot
.31052 .47283 Mdot
.72417 .28002 Mdot
.49518 .61644 Mdot
.70096 .56297 Mdot
.78451 .58691 Mdot
.71707 .56049 Mdot
.5849 .27433 Mdot
.53284 .3217 Mdot
.66996 .56062 Mdot
.4744 .61354 Mdot
.56081 .47321 Mdot
.64643 .19318 Mdot
.52966 .30011 Mdot
.43644 .58437 Mdot
.34081 .34207 Mdot
.33299 .39946 Mdot
.82946 .40979 Mdot
.52792 .32557 Mdot
.70375 .4565 Mdot
.51045 .6059 Mdot
.63928 .54928 Mdot
.56697 .29542 Mdot
.52235 .31437 Mdot
.38235 .35731 Mdot
.49288 .65294 Mdot
.46581 .63421 Mdot
.62642 .43999 Mdot
.56561 .32125 Mdot
.40416 .6499 Mdot
.48942 .65159 Mdot
.79147 .44238 Mdot
.72682 .55848 Mdot
.25857 .74164 Mdot
.41086 .57719 Mdot
.70363 .69498 Mdot
.41647 .4575 Mdot
.64604 .55722 Mdot
.48606 .67864 Mdot
.41664 .59561 Mdot
.401 .38425 Mdot
.48895 .61403 Mdot
.36133 .34368 Mdot
.53088 .3304 Mdot
.73291 .28332 Mdot
.48118 .33298 Mdot
.50911 .28531 Mdot
.48669 .63018 Mdot
.49718 .73935 Mdot
.30274 .52074 Mdot
.57817 .2902 Mdot
.66863 .58122 Mdot
.44034 .60286 Mdot
.39877 .39882 Mdot
.39586 .36972 Mdot
.66384 .54984 Mdot
.73278 .47787 Mdot
.75048 .32326 Mdot
.43329 .65285 Mdot
.36396 .40604 Mdot
.49862 .27429 Mdot
.58402 .6612 Mdot
.51399 .31315 Mdot
.31916 .48063 Mdot
.34008 .37853 Mdot
.55755 .265 Mdot
.38073 .6261 Mdot
.67282 .55438 Mdot
.65983 .52211 Mdot
.30201 .33434 Mdot
.38047 .37605 Mdot
.30972 .50819 Mdot
.3984 .4867 Mdot
.40404 .48773 Mdot
.3192 .50199 Mdot
.34711 .35017 Mdot
.64258 .55803 Mdot
.69107 .57835 Mdot
.66865 .54292 Mdot
.50145 .7918 Mdot
.65039 .58268 Mdot
.32302 .75912 Mdot
.42852 .61447 Mdot
.56434 .71542 Mdot
.49652 .59751 Mdot
.55505 .33825 Mdot
.67327 .5677 Mdot
.54071 .46043 Mdot
.4609 .59416 Mdot
.67201 .21354 Mdot
.45759 .61818 Mdot
.46613 .36153 Mdot
.45853 .64735 Mdot
.55578 .76937 Mdot
.69766 .524 Mdot
.48342 .60216 Mdot
.50855 .29903 Mdot
.29486 .50075 Mdot
.63443 .51975 Mdot
.44618 .64995 Mdot
.75606 .45154 Mdot
.517 .58568 Mdot
.78795 .37179 Mdot
.25091 .34995 Mdot
.32706 .49926 Mdot
.49693 .57995 Mdot
.35223 .42365 Mdot
.51636 .54513 Mdot
.56548 .72674 Mdot
.5294 .30126 Mdot
.51263 .74072 Mdot
.38559 .35689 Mdot
.42522 .55508 Mdot
.43682 .67945 Mdot
.31149 .47781 Mdot
.66464 .50187 Mdot
.55179 .29044 Mdot
.49301 .63135 Mdot
.48248 .67789 Mdot
.45969 .18791 Mdot
.56075 .73801 Mdot
.42799 .6797 Mdot
.31274 .46857 Mdot
.51183 .74716 Mdot
.4403 .63571 Mdot
.40182 .34675 Mdot
.63494 .5647 Mdot
.54944 .60259 Mdot
.46314 .77768 Mdot
.50096 .60504 Mdot
.66661 .55787 Mdot
.64771 .53382 Mdot
.80137 .58697 Mdot
.3074 .47485 Mdot
.45387 .61528 Mdot
.29199 .33477 Mdot
.5197 .64961 Mdot
.546 .29502 Mdot
.41986 .62842 Mdot
.35313 .3613 Mdot
.58254 .4559 Mdot
.39587 .36394 Mdot
.4745 .67034 Mdot
.69042 .55128 Mdot
.55464 .28754 Mdot
.36053 .25561 Mdot
.53875 .3823 Mdot
.31878 .75515 Mdot
.28026 .45946 Mdot
.28772 .50188 Mdot
.27369 .51654 Mdot
.55846 .25044 Mdot
.46701 .61054 Mdot
.52024 .41148 Mdot
.4366 .57553 Mdot
.45604 .65141 Mdot
.44457 .61844 Mdot
.50205 .34352 Mdot
.53309 .32039 Mdot
.37501 .36687 Mdot
.47897 .65063 Mdot
.50272 .60357 Mdot
.68343 .56007 Mdot
.29838 .49151 Mdot
.39391 .39687 Mdot
.29076 .52983 Mdot
.36268 .3764 Mdot
.83812 .43687 Mdot
.41963 .61718 Mdot
.29465 .5025 Mdot
.55911 .27324 Mdot
.70204 .57223 Mdot
.63729 .45411 Mdot
.36414 .40189 Mdot
.38926 .37035 Mdot
.48314 .59982 Mdot
.67897 .53286 Mdot
.67006 .52863 Mdot
.2867 .50086 Mdot
.56447 .31578 Mdot
.45006 .67346 Mdot
.48339 .65828 Mdot
.33146 .2638 Mdot
.40076 .37915 Mdot
.5256 .74482 Mdot
.78632 .54015 Mdot
.46891 .60907 Mdot
.6721 .52741 Mdot
.47258 .64114 Mdot
.51255 .23916 Mdot
.70294 .57647 Mdot
.49167 .58956 Mdot
.38625 .66241 Mdot
.39274 .40532 Mdot
.80478 .63358 Mdot
.53467 .62945 Mdot
.54854 .36636 Mdot
.50707 .65411 Mdot
.8241 .65092 Mdot
.77866 .59685 Mdot
.52671 .63459 Mdot
.43891 .6582 Mdot
.55617 .17638 Mdot
.51637 .60973 Mdot
.62851 .43783 Mdot
.40591 .59658 Mdot
.66471 .52664 Mdot
.44978 .43088 Mdot
.54015 .42547 Mdot
.28999 .48629 Mdot
.3512 .38034 Mdot
.27683 .64639 Mdot
.27977 .52595 Mdot
.66369 .57436 Mdot
.4608 .58985 Mdot
.75244 .5865 Mdot
.34925 .43343 Mdot
.43872 .67361 Mdot
.54744 .2947 Mdot
.5413 .42528 Mdot
.34132 .36674 Mdot
.5321 .31159 Mdot
.51167 .59715 Mdot
.19006 .41852 Mdot
.58112 .34966 Mdot
.81597 .57829 Mdot
.5571 .28347 Mdot
.54291 .32439 Mdot
.56974 .48156 Mdot
.28945 .48693 Mdot
.43025 .20587 Mdot
.56996 .61538 Mdot
.53117 .29308 Mdot
.33392 .62331 Mdot
.39632 .34871 Mdot
.57838 .4112 Mdot
.70567 .53038 Mdot
.4186 .61831 Mdot
.47199 .61774 Mdot
.56366 .30814 Mdot
.75795 .55341 Mdot
.41146 .52025 Mdot
.52823 .30894 Mdot
.53107 .68366 Mdot
.58279 .40673 Mdot
.65047 .44034 Mdot
.62588 .43207 Mdot
.28443 .489 Mdot
.22293 .46323 Mdot
.6938 .56536 Mdot
.32532 .48862 Mdot
.60503 .51797 Mdot
.45061 .62165 Mdot
.565 .32354 Mdot
.6225 .43884 Mdot
.53677 .30592 Mdot
.29751 .51029 Mdot
.31707 .47301 Mdot
.66087 .56282 Mdot
.65034 .57034 Mdot
.5988 .61562 Mdot
.34342 .57034 Mdot
.52241 .62203 Mdot
.75354 .63649 Mdot
.69995 .5788 Mdot
.58708 .79233 Mdot
.28818 .49252 Mdot
.30745 .48465 Mdot
.60773 .68947 Mdot
.5015 .64516 Mdot
.46574 .34053 Mdot
.44121 .64243 Mdot
.31945 .6535 Mdot
.52942 .61279 Mdot
.38213 .35838 Mdot
.50752 .66486 Mdot
.65121 .35808 Mdot
.50645 .61412 Mdot
.43913 .6241 Mdot
.36325 .39673 Mdot
.4928 .68638 Mdot
.35644 .35764 Mdot
.4613 .66951 Mdot
.29893 .54032 Mdot
.35327 .37831 Mdot
.29605 .5516 Mdot
.46745 .39771 Mdot
.63917 .43447 Mdot
.27742 .50283 Mdot
.28456 .51215 Mdot
.24707 .56067 Mdot
.65577 .57791 Mdot
.37583 .61476 Mdot
.46502 .61259 Mdot
.37487 .33455 Mdot
.5684 .2896 Mdot
.49945 .60423 Mdot
.49757 .5732 Mdot
.53574 .62882 Mdot
.66345 .56099 Mdot
.35017 .34622 Mdot
.29976 .50234 Mdot
.3606 .41185 Mdot
.2902 .54588 Mdot
.33935 .40549 Mdot
.5094 .56203 Mdot
.40323 .59331 Mdot
.47417 .70171 Mdot
.72593 .67552 Mdot
.43607 .8123 Mdot
.66983 .55116 Mdot
.64478 .44566 Mdot
.30932 .47262 Mdot
.43813 .48067 Mdot
.69883 .55972 Mdot
.38843 .37389 Mdot
.46338 .62858 Mdot
.52474 .69001 Mdot
.5608 .65624 Mdot
.73278 .56145 Mdot
.3344 .55533 Mdot
.35264 .39301 Mdot
.65113 .45206 Mdot
.57106 .44999 Mdot
.63176 .59803 Mdot
.5362 .46443 Mdot
.4698 .639 Mdot
.28378 .50623 Mdot
.64724 .53829 Mdot
.43995 .21853 Mdot
.56131 .31521 Mdot
.55636 .45164 Mdot
.4869 .6276 Mdot
.71528 .487 Mdot
.68985 .55087 Mdot
.31497 .48305 Mdot
.56347 .30723 Mdot
.29764 .48109 Mdot
.63774 .42579 Mdot
.6088 .44069 Mdot
.48808 .6698 Mdot
.44539 .65201 Mdot
.57305 .29751 Mdot
.69418 .56328 Mdot
.31741 .44371 Mdot
.47604 .18935 Mdot
.36829 .40349 Mdot
.53498 .39907 Mdot
.64696 .54131 Mdot
.68872 .47792 Mdot
.3772 .40703 Mdot
.56258 .2704 Mdot
.52283 .41512 Mdot
.53676 .274 Mdot
.43979 .62843 Mdot
.67404 .53654 Mdot
.52726 .32525 Mdot
.34291 .26961 Mdot
.81489 .425 Mdot
.70248 .51496 Mdot
.4819 .65233 Mdot
.72427 .27813 Mdot
.73873 .42086 Mdot
.72448 .51685 Mdot
.55756 .33371 Mdot
.47781 .64531 Mdot
.43153 .6494 Mdot
.49977 .67278 Mdot
.55072 .32503 Mdot
.54251 .37393 Mdot
.39242 .37788 Mdot
.45459 .62848 Mdot
.28789 .52094 Mdot
.35917 .35955 Mdot
.34369 .42107 Mdot
.33774 .38724 Mdot
.70264 .57798 Mdot
.43743 .59785 Mdot
.58179 .53296 Mdot
.83417 .59056 Mdot
.53898 .3221 Mdot
.63886 .4346 Mdot
.45471 .60586 Mdot
.27527 .70447 Mdot
.69781 .5765 Mdot
.372 .40026 Mdot
.47986 .62883 Mdot
.2623 .34745 Mdot
.62297 .44798 Mdot
.36168 .38914 Mdot
.67063 .58112 Mdot
.72204 .51527 Mdot
.48949 .61316 Mdot
.50835 .65069 Mdot
.68598 .57601 Mdot
.71636 .42422 Mdot
.57618 .44072 Mdot
.4708 .64325 Mdot
.53389 .31605 Mdot
.13418 .5535 Mdot
.49978 .58701 Mdot
.73355 .58174 Mdot
.65181 .4333 Mdot
.78885 .5087 Mdot
.53339 .73411 Mdot
.4797 .56245 Mdot
.66338 .22836 Mdot
.26132 .65142 Mdot
.75148 .29815 Mdot
.31699 .67914 Mdot
.55947 .22532 Mdot
.83991 .49156 Mdot
.50952 .299 Mdot
.56491 .76386 Mdot
.46367 .16706 Mdot
.71407 .45349 Mdot
.21838 .3999 Mdot
.38597 .25878 Mdot
.26587 .32889 Mdot
.55136 .82969 Mdot
.33979 .40931 Mdot
.34065 .68915 Mdot
.47034 .67778 Mdot
.7193 .4111 Mdot
.52499 .76241 Mdot
.39922 .80908 Mdot
.72506 .2846 Mdot
.28351 .3383 Mdot
.62159 .17022 Mdot
.7339 .30505 Mdot
.64749 .61928 Mdot
.41191 .73906 Mdot
.229 .47562 Mdot
.39906 .48961 Mdot
.27748 .65625 Mdot
.47902 .73207 Mdot
.6511 .34349 Mdot
.50659 .32087 Mdot
.68346 .64035 Mdot
.1592 .5966 Mdot
.34567 .3963 Mdot
.63444 .56476 Mdot
.41851 .20704 Mdot
.70947 .61182 Mdot
.58334 .2631 Mdot
.66341 .22816 Mdot
.79777 .44814 Mdot
.55418 .76786 Mdot
.59058 .50991 Mdot
.61442 .72488 Mdot
.22035 .57486 Mdot
.3976 .73899 Mdot
.7126 .58987 Mdot
.38932 .28751 Mdot
.40246 .48982 Mdot
.23365 .50438 Mdot
.56217 .77908 Mdot
.27217 .51293 Mdot
.28874 .55406 Mdot
.67996 .58173 Mdot
.5913 .64775 Mdot
.64769 .46012 Mdot
.6069 .52245 Mdot
.40033 .39808 Mdot
.5 .24742 Mdot
.69238 .40811 Mdot
.73705 .44534 Mdot
.76132 .69543 Mdot
.69633 .2161 Mdot
.28624 .59645 Mdot
.46202 .23863 Mdot
.58834 .31873 Mdot
.26128 .63289 Mdot
.56682 .51675 Mdot
.31955 .58937 Mdot
.37037 .609 Mdot
.54474 .13622 Mdot
.76529 .44688 Mdot
.60368 .15496 Mdot
.64999 .59562 Mdot
.54318 .63406 Mdot
.47877 .23898 Mdot
.69535 .73038 Mdot
.25569 .53596 Mdot
.69817 .22188 Mdot
.3287 .48274 Mdot
.68777 .51762 Mdot
.71349 .45644 Mdot
.52406 .77562 Mdot
.31904 .4392 Mdot
.27815 .48575 Mdot
.5491 .60463 Mdot
.52856 .11916 Mdot
.65118 .21945 Mdot
.7995 .56217 Mdot
.78907 .44482 Mdot
.40363 .33688 Mdot
.34915 .4265 Mdot
.52442 .32595 Mdot
.82363 .45365 Mdot
.68341 .54336 Mdot
.83677 .59291 Mdot
.81479 .44659 Mdot
.49345 .53784 Mdot
.51458 .11886 Mdot
.6321 .81151 Mdot
.55994 .71677 Mdot
.37295 .76296 Mdot
.22699 .34891 Mdot
.55849 .50562 Mdot
.67937 .47053 Mdot
.37135 .32568 Mdot
.8051 .49769 Mdot
.82348 .41669 Mdot
.3406 .62863 Mdot
.5798 .23008 Mdot
.60518 .52956 Mdot
.37613 .47352 Mdot
.67927 .50882 Mdot
.20576 .42856 Mdot
.36343 .55696 Mdot
.6162 .16295 Mdot
.50555 .74895 Mdot
.15124 .48724 Mdot
.30789 .66562 Mdot
.54188 .8034 Mdot
.65824 .24197 Mdot
.41411 .39024 Mdot
.38529 .5553 Mdot
.75393 .46868 Mdot
.45466 .57776 Mdot
.52492 .49891 Mdot
.39809 .57118 Mdot
.33909 .49197 Mdot
.57013 .4706 Mdot
.75202 .37709 Mdot
.29744 .64785 Mdot
.53087 .19991 Mdot
.41517 .73644 Mdot
.70715 .54835 Mdot
.30714 .58322 Mdot
.30924 .62173 Mdot
.78166 .428 Mdot
.44809 .52428 Mdot
.80989 .54321 Mdot
.4367 .52085 Mdot
.45327 .56899 Mdot
.57263 .76048 Mdot
.46941 .72964 Mdot
.32493 .61269 Mdot
.5331 .62831 Mdot
.77386 .67564 Mdot
.7955 .46892 Mdot
.71026 .66711 Mdot
.2809 .62975 Mdot
.72335 .6718 Mdot
.80896 .49868 Mdot
.4848 .23286 Mdot
.68144 .46279 Mdot
.75117 .53607 Mdot
.53475 .12292 Mdot
.37023 .35999 Mdot
.33704 .60954 Mdot
.52711 .35942 Mdot
.34876 .26729 Mdot
.4383 .18194 Mdot
.42253 .51915 Mdot
.81668 .49199 Mdot
.72848 .45306 Mdot
.33825 .43132 Mdot
.63625 .3173 Mdot
.49346 .31852 Mdot
.73678 .64239 Mdot
.53894 .61725 Mdot
.39874 .56023 Mdot
.31653 .5157 Mdot
.65201 .75469 Mdot
.48044 .21554 Mdot
.30736 .38813 Mdot
.5057 .56568 Mdot
.31948 .33664 Mdot
.64419 .45324 Mdot
.55536 .42614 Mdot
.8396 .4253 Mdot
.43652 .56021 Mdot
.60644 .81868 Mdot
.73174 .43185 Mdot
.53081 .41524 Mdot
.23832 .53185 Mdot
.77269 .53849 Mdot
.58328 .14267 Mdot
.82307 .48359 Mdot
.73295 .39741 Mdot
.71608 .26976 Mdot
.68037 .80736 Mdot
.39339 .19259 Mdot
.68714 .75269 Mdot
.52599 .3587 Mdot
.48989 .91203 Mdot
.36879 .41067 Mdot
.40265 .77301 Mdot
.69206 .73143 Mdot
.26206 .36117 Mdot
.71626 .6097 Mdot
.46886 .74095 Mdot
.25843 .49032 Mdot
.62487 .5481 Mdot
.52784 .58336 Mdot
.74476 .26658 Mdot
.55252 .1338 Mdot
.73146 .25209 Mdot
.60607 .4292 Mdot
.75955 .29806 Mdot
.54236 .15785 Mdot
.3283 .7638 Mdot
.44885 .19085 Mdot
.42009 .63062 Mdot
.35082 .59891 Mdot
.65479 .79553 Mdot
.30134 .45574 Mdot
.59152 .53049 Mdot
.72315 .58303 Mdot
.52752 .14374 Mdot
.84048 .42217 Mdot
.62885 .68478 Mdot
.6164 .62716 Mdot
.44506 .41642 Mdot
.33255 .58935 Mdot
.73752 .60271 Mdot
.65718 .32895 Mdot
.79042 .40803 Mdot
.53072 .15675 Mdot
.30694 .63106 Mdot
.38533 .2653 Mdot
.72406 .38392 Mdot
.67086 .77723 Mdot
.65695 .23682 Mdot
.41158 .20697 Mdot
.45168 .53449 Mdot
.60752 .55175 Mdot
.41266 .52101 Mdot
.64578 .33478 Mdot
.46728 .29318 Mdot
.27 .60242 Mdot
.35583 .35168 Mdot
.3428 .61815 Mdot
.49151 .45831 Mdot
.44629 .19076 Mdot
.25664 .60595 Mdot
.34231 .6398 Mdot
.7473 .39107 Mdot
.74702 .27447 Mdot
.73079 .43487 Mdot
.20357 .3727 Mdot
.68515 .27727 Mdot
.41493 .5581 Mdot
.51599 .67638 Mdot
.81318 .49372 Mdot
.79938 .32081 Mdot
.81794 .4902 Mdot
.72394 .49486 Mdot
.30541 .32153 Mdot
.54447 .26461 Mdot
.24995 .60933 Mdot
.31438 .39265 Mdot
.79675 .40682 Mdot
.46591 .47424 Mdot
.55627 .26047 Mdot
.69022 .41738 Mdot
.60251 .61273 Mdot
.27338 .67935 Mdot
.65868 .64279 Mdot
.41051 .63117 Mdot
.57625 .68157 Mdot
.64873 .52405 Mdot
.71777 .49153 Mdot
.32452 .59357 Mdot
.36469 .36161 Mdot
.31686 .26797 Mdot
.73995 .58139 Mdot
.54057 .6064 Mdot
.46353 .26603 Mdot
.67821 .50776 Mdot
.7188 .68702 Mdot
.32855 .40397 Mdot
.83794 .47023 Mdot
.74991 .70099 Mdot
.7435 .5994 Mdot
.29433 .58755 Mdot
.32869 .27182 Mdot
.56965 .42841 Mdot
.53237 .3569 Mdot
.72471 .28806 Mdot
.4771 .40038 Mdot
.30612 .58959 Mdot
.56649 .69398 Mdot
.47607 .19736 Mdot
.42791 .5831 Mdot
.79293 .57697 Mdot
.31314 .74529 Mdot
.55689 .41706 Mdot
.71732 .60336 Mdot
.64903 .58513 Mdot
.47845 .83831 Mdot
.66385 .35723 Mdot
.5516 .54746 Mdot
.68693 .25378 Mdot
.51792 .30907 Mdot
.7095 .56468 Mdot
.34753 .6447 Mdot
.2326 .41882 Mdot
.57379 .66049 Mdot
.47391 .28738 Mdot
.66381 .61931 Mdot
.48111 .36799 Mdot
.70413 .26077 Mdot
.62827 .19436 Mdot
.13945 .54509 Mdot
.63063 .57765 Mdot
.44573 .22505 Mdot
.43876 .22712 Mdot
.71637 .5849 Mdot
.73452 .57047 Mdot
.49387 .74236 Mdot
.7888 .32911 Mdot
.45026 .46547 Mdot
.6484 .31613 Mdot
.52384 .41289 Mdot
.21782 .40974 Mdot
.45517 .20143 Mdot
.26805 .6295 Mdot
.62478 .22202 Mdot
.63042 .63754 Mdot
.26742 .28008 Mdot
.45042 .69977 Mdot
.40769 .7759 Mdot
.24966 .60919 Mdot
.38311 .70468 Mdot
.56837 .77731 Mdot
.76616 .36741 Mdot
.52257 .64014 Mdot
.71789 .23184 Mdot
.76785 .42063 Mdot
.51691 .50229 Mdot
.41498 .3562 Mdot
.51067 .62593 Mdot
.43466 .60094 Mdot
.76947 .57863 Mdot
.78724 .52506 Mdot
.33923 .21565 Mdot
.31319 .6626 Mdot
.44104 .54507 Mdot
.55752 .70987 Mdot
.6074 .8181 Mdot
.48405 .24716 Mdot
.77458 .34248 Mdot
.48967 .46904 Mdot
.67305 .78223 Mdot
.63659 .2745 Mdot
.63472 .33806 Mdot
.67819 .26618 Mdot
.54906 .15968 Mdot
.53877 .57101 Mdot
.77265 .50163 Mdot
.41998 .2135 Mdot
.45362 .6072 Mdot
.73362 .47848 Mdot
.68885 .26075 Mdot
.17463 .51677 Mdot
.55848 .52293 Mdot
.79264 .30524 Mdot
.395 .64758 Mdot
.76961 .48608 Mdot
.44975 .16895 Mdot
.18072 .35496 Mdot
.64183 .35107 Mdot
.62544 .16916 Mdot
.62979 .32381 Mdot
.67368 .24314 Mdot
.5223 .33003 Mdot
.46332 .43676 Mdot
.75059 .65435 Mdot
.79373 .33596 Mdot
.24965 .43197 Mdot
.54935 .21434 Mdot
.77065 .62289 Mdot
.78615 .31808 Mdot
.38674 .65066 Mdot
.47896 .83372 Mdot
.39116 .41831 Mdot
.68153 .7864 Mdot
.71934 .72641 Mdot
.64574 .60925 Mdot
.33256 .63291 Mdot
.47315 .82485 Mdot
.37576 .7924 Mdot
.71284 .72768 Mdot
.36122 .66618 Mdot
.77863 .53956 Mdot
.28545 .5853 Mdot
.80277 .41258 Mdot
.53517 .83081 Mdot
.45262 .21087 Mdot
.65873 .41578 Mdot
.61185 .42822 Mdot
.79181 .53287 Mdot
.72642 .35109 Mdot
.47077 .25492 Mdot
.59404 .42343 Mdot
.63948 .61435 Mdot
.15584 .6556 Mdot
.61934 .29494 Mdot
.54148 .69793 Mdot
.57434 .14599 Mdot
.78813 .41087 Mdot
.45279 .47545 Mdot
.55346 .78404 Mdot
.27663 .6927 Mdot
.38163 .44153 Mdot
.43834 .63732 Mdot
.78035 .31171 Mdot
.35362 .44583 Mdot
.65025 .19199 Mdot
.82128 .57694 Mdot
.60061 .65485 Mdot
.50451 .55559 Mdot
.35804 .32823 Mdot
.4132 .75185 Mdot
.36211 .67912 Mdot
.5759 .15535 Mdot
.41069 .77493 Mdot
.51654 .3947 Mdot
.47296 .35891 Mdot
.47913 .31863 Mdot
.54131 .55498 Mdot
.65847 .79569 Mdot
.77942 .5275 Mdot
.28841 .65215 Mdot
.71615 .38619 Mdot
.33174 .60896 Mdot
.5327 .73621 Mdot
.24738 .5981 Mdot
.48321 .50819 Mdot
.24919 .49814 Mdot
.40058 .36336 Mdot
.5439 .18206 Mdot
.72902 .3089 Mdot
.78069 .65967 Mdot
.20839 .36812 Mdot
.75367 .47226 Mdot
.35194 .70039 Mdot
.50451 .20482 Mdot
.5486 .51369 Mdot
.24579 .45098 Mdot
.29455 .68721 Mdot
.51152 .7431 Mdot
.77211 .35642 Mdot
.41957 .73307 Mdot
.8268 .41842 Mdot
.2701 .60665 Mdot
.50428 .17851 Mdot
.44076 .42381 Mdot
.66902 .73395 Mdot
.58013 .72088 Mdot
.24027 .331 Mdot
.55394 .41763 Mdot
.52957 .12046 Mdot
.71624 .554 Mdot
.69149 .21295 Mdot
.55636 .28112 Mdot
.16304 .56577 Mdot
.78175 .38258 Mdot
.51767 .47968 Mdot
.50844 .43455 Mdot
.79538 .58431 Mdot
.72473 .43468 Mdot
.7391 .43626 Mdot
.41547 .52269 Mdot
.33523 .37719 Mdot
.52264 .38588 Mdot
.65285 .31508 Mdot
.55365 .19325 Mdot
.44038 .6653 Mdot
.33061 .43368 Mdot
.38409 .71888 Mdot
.54893 .35943 Mdot
.79841 .47862 Mdot
.75452 .33986 Mdot
.49678 .7231 Mdot
.33244 .58606 Mdot
.54234 .15197 Mdot
.80064 .43334 Mdot
.41308 .51292 Mdot
.39173 .58571 Mdot
.59271 .31473 Mdot
.35474 .22597 Mdot
.62792 .20901 Mdot
.47692 .33982 Mdot
.58035 .43082 Mdot
.28813 .59901 Mdot
.79809 .29506 Mdot
.54837 .13487 Mdot
.2337 .32004 Mdot
.52289 .41014 Mdot
.62838 .58695 Mdot
.28559 .70784 Mdot
.50763 .17937 Mdot
.69517 .77758 Mdot
.74887 .40934 Mdot
.33465 .61359 Mdot
.17607 .49293 Mdot
.44026 .80525 Mdot
.49939 .39054 Mdot
.58113 .72131 Mdot
.72021 .6957 Mdot
.58532 .28111 Mdot
.38189 .44551 Mdot
.49426 .41213 Mdot
.58766 .26651 Mdot
.77901 .53764 Mdot
.72371 .43805 Mdot
.50176 .1775 Mdot
.42326 .78253 Mdot
.39037 .58904 Mdot
.54573 .20477 Mdot
.68119 .51233 Mdot
.43618 .22308 Mdot
.34031 .25525 Mdot
.50126 .4026 Mdot
.35539 .41478 Mdot
.5423 .68263 Mdot
.57004 .40229 Mdot
.63118 .3052 Mdot
.18211 .45303 Mdot
.30636 .534 Mdot
.69314 .59872 Mdot
.45399 .8107 Mdot
.63622 .58511 Mdot
.83369 .36304 Mdot
.6593 .32789 Mdot
.56732 .69749 Mdot
.62529 .25843 Mdot
.40093 .27147 Mdot
.17941 .4049 Mdot
.63507 .61772 Mdot
.2612 .55392 Mdot
.66096 .60004 Mdot
.64502 .52875 Mdot
.63265 .25124 Mdot
.65133 .46826 Mdot
.60357 .63276 Mdot
.5767 .8257 Mdot
.32608 .27352 Mdot
.65457 .5926 Mdot
.47032 .36706 Mdot
.71187 .51536 Mdot
.84102 .43172 Mdot
.35388 .41127 Mdot
.54211 .1247 Mdot
.40732 .58078 Mdot
.34542 .2283 Mdot
.80759 .48654 Mdot
.58366 .46287 Mdot
.52366 .40454 Mdot
.35413 .27545 Mdot
.44799 .57279 Mdot
.44993 .54277 Mdot
.65674 .57667 Mdot
.45998 .18468 Mdot
.30534 .48886 Mdot
.33228 .56414 Mdot
.51921 .3495 Mdot
.57855 .80517 Mdot
.69714 .76372 Mdot
.64511 .52666 Mdot
.45635 .37903 Mdot
.42994 .2368 Mdot
.3854 .66381 Mdot
.3825 .71307 Mdot
.5499 .17715 Mdot
.61846 .62191 Mdot
.71463 .55219 Mdot
.23112 .32753 Mdot
.36486 .54828 Mdot
.83492 .49317 Mdot
.44884 .70878 Mdot
.4057 .74454 Mdot
.394 .71653 Mdot
.7857 .56331 Mdot
.53213 .73434 Mdot
.7888 .36955 Mdot
.31114 .58523 Mdot
.3803 .52539 Mdot
.34365 .6375 Mdot
.49825 .72365 Mdot
.48767 .35621 Mdot
.65575 .80342 Mdot
.17554 .4862 Mdot
.60704 .73364 Mdot
.57254 .52387 Mdot
.71485 .60726 Mdot
.61583 .81513 Mdot
.70761 .59517 Mdot
.32684 .51823 Mdot
.69296 .64304 Mdot
.78154 .38473 Mdot
.82364 .44661 Mdot
.78096 .428 Mdot
.41384 .75436 Mdot
.48067 .32021 Mdot
.32925 .7303 Mdot
.38134 .61352 Mdot
.52756 .4733 Mdot
.48177 .56965 Mdot
.46747 .54456 Mdot
.45843 .48594 Mdot
.78629 .5985 Mdot
.52837 .55683 Mdot
.78664 .33204 Mdot
.83106 .48888 Mdot
.73665 .27492 Mdot
.46566 .29123 Mdot
.63125 .56738 Mdot
.57185 .13983 Mdot
.45832 .78794 Mdot
.8032 .41948 Mdot
.70817 .73762 Mdot
.49401 .84411 Mdot
.45979 .16476 Mdot
.75921 .3771 Mdot
.59812 .56687 Mdot
.80698 .63088 Mdot
.76669 .4455 Mdot
.48352 .83267 Mdot
.50616 .74332 Mdot
.80358 .48565 Mdot
.51593 .1246 Mdot
.64147 .78156 Mdot
.74014 .44414 Mdot
.57376 .72595 Mdot
.53092 .72019 Mdot
.5483 .82309 Mdot
.43712 .59236 Mdot
.34734 .41909 Mdot
.24517 .36433 Mdot
.32988 .62529 Mdot
.51364 .71644 Mdot
.53347 .82439 Mdot
.36328 .68395 Mdot
.34442 .69623 Mdot
.3457 .27468 Mdot
.46357 .16602 Mdot
.55662 .70045 Mdot
.53507 .68204 Mdot
.72403 .5869 Mdot
.2761 .52195 Mdot
.30546 .67918 Mdot
.50262 .62884 Mdot
.54043 .43721 Mdot
.55641 .59394 Mdot
.75828 .27592 Mdot
.22983 .40199 Mdot
.53791 .25401 Mdot
.63462 .57695 Mdot
.78893 .53862 Mdot
.50786 .23067 Mdot
.71322 .45374 Mdot
.51825 .82037 Mdot
.59013 .62283 Mdot
.69139 .24811 Mdot
.74081 .45587 Mdot
.28855 .62074 Mdot
.21676 .5507 Mdot
.54332 .34188 Mdot
.73324 .68274 Mdot
.57001 .15816 Mdot
.74716 .48162 Mdot
.69074 .51759 Mdot
.72003 .3716 Mdot
.48765 .36021 Mdot
.7574 .50046 Mdot
.72793 .42999 Mdot
.47078 .20947 Mdot
.60066 .67555 Mdot
.62378 .19567 Mdot
.33658 .34521 Mdot
.31406 .63612 Mdot
.68219 .3603 Mdot
.54721 .82587 Mdot
.38824 .66835 Mdot
.8127 .38961 Mdot
.51652 .47246 Mdot
.34111 .53523 Mdot
.4952 .66331 Mdot
.45654 .78007 Mdot
.78067 .56656 Mdot
.70806 .37849 Mdot
.4792 .53271 Mdot
.64444 .52066 Mdot
.75919 .69505 Mdot
.41447 .36469 Mdot
.39076 .42613 Mdot
.38445 .76306 Mdot
.71781 .49898 Mdot
.34484 .50079 Mdot
.64253 .39923 Mdot
.39901 .60113 Mdot
.21982 .5228 Mdot
.47398 .31095 Mdot
.74177 .67346 Mdot
.677 .76077 Mdot
.54877 .18157 Mdot
.476 .27479 Mdot
.76708 .6914 Mdot
.74472 .68333 Mdot
.79671 .51121 Mdot
.44393 .79958 Mdot
.59128 .55298 Mdot
.53514 .61281 Mdot
.32718 .51759 Mdot
.71819 .57429 Mdot
.56348 .1896 Mdot
.40694 .54908 Mdot
.33312 .53643 Mdot
.51077 .49105 Mdot
.47579 .24125 Mdot
.41653 .44242 Mdot
.79457 .47334 Mdot
.80697 .63153 Mdot
.32347 .59287 Mdot
.5294 .34478 Mdot
.6343 .31298 Mdot
.54997 .52393 Mdot
.79862 .35884 Mdot
.44702 .49547 Mdot
.75288 .59193 Mdot
.64871 .41801 Mdot
.70227 .69368 Mdot
.81872 .53418 Mdot
.34611 .56344 Mdot
.53611 .47031 Mdot
.74416 .58664 Mdot
.59391 .52584 Mdot
.63919 .45529 Mdot
.25748 .37525 Mdot
.44868 .78795 Mdot
.57909 .23453 Mdot
.55411 .3774 Mdot
.39565 .6291 Mdot
.28929 .71126 Mdot
.60964 .19529 Mdot
.43906 .48136 Mdot
.50842 .47417 Mdot
.41573 .21663 Mdot
.35577 .44773 Mdot
.13217 .57305 Mdot
.73619 .24915 Mdot
.49646 .66168 Mdot
.49498 .43252 Mdot
.33963 .5609 Mdot
.35926 .34366 Mdot
.65615 .63919 Mdot
.55797 .18176 Mdot
.52509 .31601 Mdot
.32802 .29131 Mdot
.6356 .3973 Mdot
.79301 .58918 Mdot
.26519 .2929 Mdot
.56354 .26187 Mdot
.8316 .35689 Mdot
.74419 .40968 Mdot
.76421 .53757 Mdot
.13301 .59962 Mdot
.78232 .59047 Mdot
.37312 .61383 Mdot
.31769 .30984 Mdot
.75999 .28323 Mdot
.52789 .4063 Mdot
.30458 .32804 Mdot
.6569 .77165 Mdot
.31864 .59102 Mdot
.31334 .65359 Mdot
.6651 .41557 Mdot
.78029 .63656 Mdot
.45301 .83838 Mdot
.40252 .27008 Mdot
.18942 .37914 Mdot
.6029 .64144 Mdot
.64866 .20217 Mdot
.64264 .34906 Mdot
.18061 .5079 Mdot
.82198 .45064 Mdot
.35231 .62241 Mdot
.54691 .81516 Mdot
.23009 .44209 Mdot
.27587 .55925 Mdot
.2827 .71184 Mdot
.60155 .43173 Mdot
.62877 .62221 Mdot
.36818 .28317 Mdot
.50314 .53308 Mdot
.34281 .6276 Mdot
.70342 .7065 Mdot
.53393 .46972 Mdot
.5977 .16912 Mdot
.49764 .81104 Mdot
.29848 .59401 Mdot
.38782 .23146 Mdot
.29228 .55553 Mdot
.57823 .19712 Mdot
.51603 .2423 Mdot
.3675 .63027 Mdot
.41528 .16709 Mdot
.61596 .16321 Mdot
.59196 .54995 Mdot
.43114 .6069 Mdot
.8396 .49538 Mdot
.38127 .48434 Mdot
.68745 .75108 Mdot
.6915 .39811 Mdot
.31673 .66827 Mdot
.54938 .57545 Mdot
.52326 .59283 Mdot
.35044 .75017 Mdot
.60069 .57586 Mdot
.7088 .70314 Mdot
.29575 .2743 Mdot
.299 .58981 Mdot
.50768 .80546 Mdot
.27477 .27522 Mdot
.44946 .71032 Mdot
.66406 .52568 Mdot
.75892 .2799 Mdot
.72081 .62438 Mdot
.39242 .57438 Mdot
.57424 .70275 Mdot
.4321 .50177 Mdot
.26585 .44972 Mdot
.39066 .59074 Mdot
.56811 .42757 Mdot
.33082 .63375 Mdot
.51504 .18483 Mdot
.75709 .64387 Mdot
.52164 .1147 Mdot
.81776 .4961 Mdot
.64192 .5891 Mdot
.66491 .76135 Mdot
.49583 .40087 Mdot
.72424 .26448 Mdot
.37115 .27315 Mdot
.33242 .26663 Mdot
.42358 .82043 Mdot
.29052 .56323 Mdot
.50802 .67212 Mdot
.60643 .42796 Mdot
.82637 .43539 Mdot
.43913 .82398 Mdot
.82545 .4169 Mdot
.51751 .55683 Mdot
.52642 .6653 Mdot
.15599 .38748 Mdot
.68689 .25034 Mdot
.4565 .56092 Mdot
.56789 .55787 Mdot
.54825 .55179 Mdot
.46506 .67399 Mdot
.64656 .47077 Mdot
.27574 .66436 Mdot
.32163 .66156 Mdot
.78625 .32758 Mdot
.66536 .5911 Mdot
.53391 .41055 Mdot
.57727 .30357 Mdot
.52535 .4298 Mdot
.50119 .71544 Mdot
.51945 .30807 Mdot
.33191 .67175 Mdot
.39633 .47228 Mdot
.29752 .4333 Mdot
.59728 .60655 Mdot
.59407 .44516 Mdot
.61724 .60698 Mdot
.3789 .73421 Mdot
.67573 .47633 Mdot
.3722 .79165 Mdot
.36214 .68329 Mdot
.36888 .64808 Mdot
.7881 .46998 Mdot
.64951 .823 Mdot
.545 .41257 Mdot
.68349 .48628 Mdot
.40404 .67414 Mdot
.48486 .77181 Mdot
.58759 .68599 Mdot
.28632 .45805 Mdot
.65407 .45402 Mdot
.50654 .55183 Mdot
.74408 .5969 Mdot
.52797 .27893 Mdot
.79631 .29944 Mdot
.53781 .60457 Mdot
.63946 .65051 Mdot
.79926 .37534 Mdot
.44241 .21619 Mdot
.50577 .74093 Mdot
.48704 .57143 Mdot
.39056 .513 Mdot
.39201 .47442 Mdot
.74309 .54577 Mdot
.45503 .19791 Mdot
.66062 .22123 Mdot
.3933 .75873 Mdot
.62131 .65015 Mdot
.45908 .61553 Mdot
.33013 .49391 Mdot
.55984 .43526 Mdot
.19198 .48466 Mdot
.35515 .47259 Mdot
.79276 .42866 Mdot
.36682 .71846 Mdot
.31269 .66256 Mdot
.55604 .74056 Mdot
.66934 .20272 Mdot
.56281 .52927 Mdot
.59561 .66044 Mdot
.48539 .50018 Mdot
.73192 .35592 Mdot
.36017 .66755 Mdot
.56963 .22903 Mdot
.50994 .54926 Mdot
.58635 .56917 Mdot
.83 .38 Mdot
.64716 .61975 Mdot
.50293 .33013 Mdot
.77342 .35619 Mdot
.45815 .79431 Mdot
.50761 .43568 Mdot
.13783 .62232 Mdot
.36708 .27068 Mdot
.82228 .34439 Mdot
.49279 .19393 Mdot
.40131 .70539 Mdot
.7745 .53539 Mdot
.52385 .57807 Mdot
.36917 .3887 Mdot
.70198 .24615 Mdot
.73406 .59427 Mdot
.59835 .54175 Mdot
.42171 .61626 Mdot
.41947 .47852 Mdot
.7437 .55551 Mdot
.56692 .22116 Mdot
.33267 .3998 Mdot
.4172 .51067 Mdot
.55597 .21907 Mdot
.39092 .47441 Mdot
.5174 .84867 Mdot
.57832 .15513 Mdot
.72903 .29247 Mdot
.4743 .32235 Mdot
.14958 .54431 Mdot
.66757 .60446 Mdot
.73416 .55534 Mdot
.5086 .31537 Mdot
.3355 .73786 Mdot
.75236 .49172 Mdot
.50434 .18318 Mdot
.80164 .53801 Mdot
.38733 .66814 Mdot
.17359 .6897 Mdot
.35075 .63522 Mdot
.41924 .49235 Mdot
.73713 .48864 Mdot
.7953 .34409 Mdot
.30636 .30751 Mdot
.81596 .57931 Mdot
.65497 .3449 Mdot
.50757 .71721 Mdot
.3279 .7541 Mdot
.23562 .32516 Mdot
.46956 .35069 Mdot
.18635 .38346 Mdot
.66705 .24807 Mdot
.27732 .65522 Mdot
.70081 .37615 Mdot
.62967 .57782 Mdot
.46861 .53983 Mdot
.66159 .32148 Mdot
.59051 .53207 Mdot
.75877 .55354 Mdot
.65698 .22375 Mdot
.23083 .60443 Mdot
.38243 .22192 Mdot
.72543 .2759 Mdot
.55022 .36054 Mdot
.64678 .60765 Mdot
.3626 .6918 Mdot
.33987 .45675 Mdot
.37022 .34722 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Vooooo`;o
0000XOooool001cooooo00?o0000ooooooooool0Xoooool2o`000003ooooool0003o000000;o0000
Woooool001cooooo00?o0000ooooooooool0Xoooool2o`0000?ooooo1?l0002Mooooo`007?ooool0
0ol0003oooooooooo`2Tooooo`;o00000_ooool6o`0009_ooooo000Looooo`03o`000?oooooooooo
0:3ooooo0_l00002ooooo`;o00001_ooool2o`0009_ooooo000Looooo`03o`000?oooooooooo0:3o
oooo0_l0002Wooooo`007?ooool00ol0003oooooooooo`2^ooooo`Co00000_ooool2o`0009?ooooo
000Looooo`03o`000?oooooooooo0:gooooo1Ol00002ooooo`;o0000Toooool001cooooo00?o0000
ooooooooool0[Oooool2o`0000Oooooo0_l0002Aooooo`007?ooool00ol0003oooooooooo`2Xoooo
o`;o00003?ooool2o`0000;ooooo0ol0002<ooooo`007?ooool00ol0003oooooooooo`2Xooooo`;o
00003Oooool2o`000004ooooool0003o0000o`0008cooooo000Looooo`03o`000?oooooooooo0;Oo
oooo0_l0002@ooooo`007?ooool2o`000:gooooo0_l0002Kooooo`007?ooool00ol0003ooooooooo
o`2Yooooo`;o000000?oooooo`000?l000002Oooool3o`0000Kooooo0_l00027ooooo`007?ooool0
0ol0003oooooooooo`2:ooooo`;o00000_ooool2o`0001Wooooo0_l000001?oooooo0000o`000?oo
ool2o`0000Cooooo1Ol00006ooooo`;o0000Qoooool001cooooo00?o0000ooooooooool0NOooool2
o`0000oooooo0_l00002ooooo`;o000000?oooooo`000?l000006Oooool2o`000003ooooool0003o
000000Cooooo0_l0000=ooooo`;o0000Poooool001cooooo00?o0000ooooooooool0NOooool2o`00
01Kooooo1?l0000_ooooo`;o0000Poooool001cooooo00?o0000ooooooooool0Poooool2o`0000Wo
oooo0_l00002ooooo`?o00001Oooool2o`0002;ooooo0_l00004ooooo`;o000000?oooooo`000?l0
0000P?ooool001cooooo00?o0000ooooooooool0Poooool2o`0000?ooooo0_l00004ooooo`;o0000
0oooool2o`0000Gooooo0_l0000Rooooo`;o00001_ooool3o`00083ooooo000Looooo`03o`000?oo
oooooooo08Sooooo0_l000000ooooooo0000o`00000>ooooo`;o0000:Oooool2o`00087ooooo000L
ooooo`03o`000?oooooooooo08_ooooo0_l000000ooooooo0000o`000004ooooo`;o00001Oooool6
o`0000kooooo1?l0002Fooooo`007?ooool00ol0003oooooooooo`2>ooooo`;o00000_ooool4o`00
00Oooooo1_l0000<ooooo`Co00003oooool2o`0008Gooooo000Looooo`03o`000?oooooooooo083o
oooo0_l00006ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`0000Wooooo0_l000001?oo
oooo0000o`000?l0000:ooooo`Ko00003oooool2o`0008Gooooo000Looooo`03o`000?oooooooooo
083ooooo0_l00006ooooo`;o000000?oooooo`000?l000000ol000001?oooooo0000o`000?l0000<
ooooo`;o00000_ooool2o`0000Oooooo1_l0000Dooooo`;o00002?ooool2o`0007Kooooo000Loooo
o`03o`000?oooooooooo08gooooo0ol000001?oooooo0000o`000?l00003ooooo`;o00002oooool2
o`0000_ooooo1?l0000Booooo`;o00002?ooool2o`0007Kooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`1looooo`;o00002ooo
ool2o`0000;ooooo0ol00002ooooo`;o00000oooool2o`0000Kooooo0_l0000?ooooo`;o000000?o
ooooo`000?l000006Oooool3o`0007Sooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1looooo`;o
00002oooool2o`0000?ooooo0_l0000<ooooo`;o000000?oooooo`000?l000003oooool2o`00013o
oooo0_l00003ooooo`?o00001?ooool3o`0007Sooooo00000ooooooo410@ooooo`02ooooo`03oa0@
4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`1iooooo`;o0000
5Oooool4o`0000?ooooo0_l00003ooooo`;o00002oooool2o`0000gooooo0_l00008ooooo`;o0000
0oooool3o`0007oooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o
V9RHob4Q8Oo^k^h01_ooool3o`0007Wooooo0_l0000Eooooo`Co00000oooool2o`00013ooooo0_l0
0004ooooo`;o00001oooool2o`0001Gooooo0_l00005ooooo`;o0000LOooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooo
oooo073ooooo0_l0000Fooooo`;o00001_ooool2o`0000kooooo0_l0000<ooooo`Co00007Oooool2
o`0000Gooooo0_l0001aooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0=oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0L?ooool2o`0000Gooooo0_l00009oooo
o`Co00000_ooool2o`0000Kooooo0_l00007ooooo`;o00001Oooool2o`000003ooooool0003o0000
00Gooooo0_l00002ooooo`Co00005_ooool2o`0007oooooo00001_ooooooMgMgoiRHV?ooooooV9RH
ogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo07Oooooo0_l0
0009ooooo`Go00002?ooool3o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000001Ooo
ool2o`0000?ooooo1?l00004ooooo`;o00005_ooool2o`0007oooooo00001_ooooook^k^oc8b<_l0
003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo07;o
oooo0_l00003ooooo`;o00003?ooool2o`0000?ooooo0_l00003ooooo`Co00000_ooool2o`0000Go
oooo0_l0000:ooooo`;o00001Oooool2o`0002Gooooo0_l00005ooooo`;o0000J_ooool001cooooo
00?o0000ooooooooool0J_ooool2o`0000Kooooo0_l00007ooooo`;o00001_ooool4o`0000?ooooo
1?l00003ooooo`?o00001?ooool2o`0001Gooooo0_l0000Uooooo`;o00001Oooool3o`0006Wooooo
000Looooo`03o`000?oooooooooo06[ooooo0_l0000?ooooo`;o00001_ooool2o`0000Kooooo0ol0
0004ooooo`;o00001?ooool2o`00013ooooo0_l000000ooooooo0000o`000007o`0001[ooooo0_l0
00001?oooooo0000o`000?ooool2o`0000Kooooo0_l0001Yooooo`007?ooool00ol0003ooooooooo
o`1cooooo`;o00000oooool2o`00013ooooo1?l0000Looooo`;o000000?oooooo`000?l000001ol0
000Aooooo`;o00001oooool5o`000003ooooool0003o000000Oooooo0_l0001Xooooo`007?ooool0
0ol0003oooooooooo`1`ooooo`;o000000?oooooo`000?l000000oooool2o`00013ooooo1Ol00004
ooooo`;o00007Oooool2o`0001?ooooo0_l00009ooooo`;o00000_ooool2o`0000Gooooo1?l00005
ooooo`;o0000HOooool001cooooo00?o0000ooooooooool0JOooool2o`000003ooooool0003o0000
00;ooooo0_l0000Iooooo`Co00001?ooool2o`0000cooooo0_l0000?ooooo`;o000000?oooooo`00
0?l000000_ooool2o`0001;ooooo0_l00005ooooo`Co00001Oooool2o`0000Oooooo0_l0001Qoooo
o`007?ooool00ol0003oooooooooo`1Yooooo`;o000000?oooooo`000?l000003?ooool2o`00017o
oooo0_l0000:ooooo`Go00000oooool2o`00013ooooo1?l00002ooooo`;o00004_ooool2o`0000Go
oooo0_l0000?ooooo`;o0000H_ooool001cooooo00?o0000ooooooooool0LOooool2o`0000Oooooo
0_l0000<ooooo`;o00001Oooool2o`0000Sooooo1Ol00004ooooo`;o00003oooool2o`0000?ooooo
0_l0000Hooooo`;o00004Oooool2o`0006;ooooo000Looooo`03o`000?oooooooooo073ooooo0ol0
000Eooooo`;o00001Oooool2o`000003ooooool0003o000000Cooooo1?l00006ooooo`?o00004ooo
ool2o`0001Cooooo0_l00002ooooo`;o0000MOooool001cooooo00?o0000ooooooooool0L?ooool2
o`000003ooooool0003o000001gooooo0_l00003ooooo`Go00001oooool3o`0002Sooooo0_l00002
ooooo`;o00000oooool2o`00073ooooo000Looooo`03o`000?oooooooooo07?ooooo0_l0000Boooo
o`;o00003_ooool2o`0000_ooooo0_l0000<ooooo`;o00007_ooool2o`0000?ooooo0_l00007oooo
o`;o00001?ooool2o`00067ooooo000Looooo`03o`000?oooooooooo07Kooooo0_l0000?ooooo`;o
00004?ooool2o`0000Cooooo0_l00006ooooo`;o00002?ooool3o`0000?ooooo0_l0000Looooo`;o
00001_ooool2o`000003ooooool0003o000000Cooooo0_l00003ooooo`;o0000G?ooool001cooooo
0_l0001`ooooo`?o00001?ooool2o`0001[ooooo0_l00005ooooo`;o00001?ooool2o`0000Kooooo
0_l00005ooooo`;o000000Coooooo`000?l0003o00000oooool2o`00017ooooo0_l00009ooooo`;o
00001?ooool4o`0000;ooooo0_l00007ooooo`?o0000G?ooool001cooooo00?o0000ooooooooool0
Joooool2o`0000;ooooo0ol0000Pooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo
0_l0000:ooooo`;o000000Coooooo`000?l0003ooooo0ol0000Fooooo`;o00003oooool2o`0000Co
oooo0_l00007ooooo`;o0000GOooool001cooooo00?o0000ooooooooool0Joooool4o`0000;ooooo
0_l0000Pooooo`Co00001?ooool2o`0000;ooooo0_l0000:ooooo`?o00000oooool2o`0000Gooooo
0_l0000=ooooo`;o00004_ooool2o`0006cooooo000Looooo`03o`000?oooooooooo06Oooooo0_l0
0003ooooo`?o00000_ooool2o`0000Oooooo0_l0000Gooooo`;o00002_ooool2o`0000_ooooo0_l0
0002ooooo`?o00001Oooool2o`0000gooooo1?l0000<ooooo`;o00000oooool2o`0000?ooooo0_l0
001Vooooo`007?ooool00ol0003oooooooooo`1Wooooo`?o00000oooool2o`0000Gooooo0_l00004
ooooo`;o00006oooool2o`0000Wooooo0_l00003ooooo`?o000000?oooooo`000?l000000_l00000
0ooooooo0000o`000003o`0000Gooooo0_l0000=ooooo`;o00003?ooool2o`0000?ooooo0_l00003
ooooo`;o00001?ooool2o`000003ooooool0003o000005gooooo000Looooo`03o`000?oooooooooo
06Oooooo1Ol00002ooooo`;o00000oooool3o`0000?ooooo0_l0000Hooooo`;o00000_ooool2o`00
00Wooooo0_l00003ooooo`?o000000?oooooo`000?l000000_l00002ooooo`Co00000oooool5o`00
01cooooo1?l0000:ooooo`;o000000?oooooo`000?l000000_ooool2o`0005Wooooo000Looooo`03
o`000?oooooooooo06?ooooo0_l00003ooooo`So00000oooool3o`0000?ooooo0_l00004ooooo`;o
00004_ooool2o`0000Kooooo0_l0000>ooooo`[o000000?oooooo`000?l000000_l000000ooooooo
0000o`00000=ooooo`;o00003Oooool4o`0000Sooooo0_l00007ooooo`;o0000FOooool001cooooo
00?o0000ooooooooool0Hoooool2o`000003ooooool0003o000000Ko00001_ooool3o`0000Oooooo
0ol000000ooooooo0000o`00000Gooooo`;o00002oooool2o`000003ooooool0003o000000_o0000
4_ooool2o`0001Cooooo0_l00003ooooo`;o00001oooool2o`0005Wooooo000Looooo`03o`000?oo
oooooooo05Kooooo1?l00002ooooo`;o00002?ooool3o`0000Cooooo1?l00003ooooo`?o00001ooo
ool2o`0000;ooooo0_l0000Cooooo`;o00001Oooool2o`0000Sooooo4Ol000000ooooooo0000o`00
000?ooooo`;o00004oooool2o`0000Kooooo0_l000001?oooooo0000o`000?ooool3o`0000;ooooo
0_l0001Dooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o000000?oooooo`000?l000000_l0
0002ooooo`;o00002?ooool2o`0000Gooooo1?l00003ooooo`;o00007Oooool2o`0000;ooooo0_l0
0005ooooo`;o00000oooool3o`000003ooooool0003o0000013o000000Coooooo`000?l0003ooooo
0_l0000:ooooo`Co00003_ooool2o`0000Cooooo0_l00004ooooo`?o000000?oooooo`000?l00000
0_ooool2o`0000;ooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00001Ooo
ool2o`00017ooooo0_l00005ooooo`;o00007Oooool2o`0000kooooo0ol000000ooooooo0000o`00
0002o`000003ooooool0003o000000Wo00000oooool2o`000003ooooool0003o000000[ooooo1?l0
000>ooooo`;o00001?ooool2o`0000Cooooo0_l0000:ooooo`;o00000_ooool2o`00053ooooo000L
ooooo`03o`000?oooooooooo05[ooooo0_l0000Hooooo`;o0000;?ooool3o`0000;ooooo4?l00003
ooooo`;o00003oooool2o`0001_ooooo1?l00007ooooo`;o00000_ooool2o`00053ooooo000Loooo
o`03o`000?oooooooooo05Kooooo0_l0000Sooooo`;o00006Oooool2o`0000Kooooo0_l00002oooo
o`;o00000_oooolBo`00033ooooo1?l00007ooooo`;o00002?ooool2o`0004[ooooo000Looooo`03
o`000?oooooooooo05Kooooo0_l0000?ooooo`;o00004_ooool4o`0001Gooooo1?l00006oooooaco
0000:_ooool2o`0000;ooooo1?l0000Aooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0
D_ooool3o`0001;ooooo0_l0000Dooooo`;o00005Oooool2o`0000Wooooo6ol0000;ooooo`;o0000
7Oooool2o`0000?ooooo0ol00006ooooo`;o00002oooool2o`0004Sooooo000Looooo`03o`000?oo
oooooooo05;ooooo0ol0000Tooooo`;o00006Oooool2o`0000Oooooo0ol00004oooooaCo00003Ooo
ool2o`000003ooooool0003o000000;o00007Oooool3o`0000Cooooo1Ol0000:ooooo`;o0000B?oo
ool001cooooo0_l0001jooooo`;o00006Oooool2o`0000Oooooo0ol000001Ooooooo0000o`000?l0
003ooooo01Co00003oooool4o`0002Cooooo1Ol0000:ooooo`;o0000B?ooool001cooooo00?o0000
ooooooooool0U?ooool2o`0000Cooooo0_l00005oooooa[o00003Oooool2o`0003Gooooo0_l00018
ooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00003Oooool3o`0003Sooooo0_l00007oooo
oaSo00003_ooool2o`00023ooooo1?l0000?ooooo`;o0000BOooool001cooooo00?o0000oooooooo
ool0D?ooool2o`0000gooooo0ol000000ooooooo0000o`00000dooooo`;o00001_oooolDo`000003
ooooool0003o0000017ooooo0_l0000Nooooo`Oo00003_ooool2o`0004Wooooo000Looooo`03o`00
0?oooooooooo06?ooooo0_l0000aooooo`;o000000?oooooo`000?l000001?oooolFo`000003oooo
ool0003o000000kooooo0_l00002ooooo`;o00007Oooool2o`0000;ooooo1?l00009ooooo`;o0000
COooool001cooooo00?o0000ooooooooool0AOooool2o`0002cooooo1?l0000Oooooo`?o00001_oo
oolIo`0000Gooooo0_l00007ooooo`;o00000_ooool2o`0000?ooooo0ol0000Mooooo`;o00002Ooo
ool2o`0004gooooo000Looooo`03o`000?oooooooooo04Gooooo0_l000000ooooooo0000o`000008
ooooo`;o00007oooool4o`00023ooooo0ol00003ooooo`Oo000000?oooooo`000?l000004Ol00003
ooooo`Co00003?ooool2o`0000;ooooo0ol0000Jooooo`;o000000?oooooo`000?l000000oooool2
o`0000Kooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`18ooooo`;o00000_ooool2o`00
00Cooooo0_l0000;ooooo`;o00005Oooool2o`0001kooooo1?l00003ooooo`Oo000000?oooooo`00
0?l000004Ol00003ooooo`;o00002Oooool3o`0000;ooooo0_l00006ooooo`;o00004oooool2o`00
00;ooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00001_ooool2o`0000;ooooo0_l00017
ooooo`007?ooool00ol0003oooooooooo`19ooooo`;o000000?oooooo`000?l000004Oooool2o`00
01Cooooo0ol0000Nooooo`Co00001oooool3o`0000;ooooo4_l0000>ooooo`Go00002?ooool2o`00
01?ooooo0_l00003ooooo`Ko00000_ooool2o`000003ooooool0003o000000Kooooo0_l00017oooo
o`007?ooool00ol0003oooooooooo`17ooooo`Co00002?ooool2o`0000[ooooo0_l0000@ooooo`;o
00000_ooool2o`0000;ooooo0_l0000Iooooo`;o00000oooool2o`0000Wooooo5?l0000Aooooo`;o
00001oooool2o`0001Wooooo1_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Ko
oooo0_l00013ooooo`007?ooool00ol0003oooooooooo`17ooooo`;o000000?oooooo`000?l00000
1oooool2o`0000[ooooo0_l00004ooooo`;o00002_ooool2o`0000Kooooo0_l00002ooooo`;o0000
5Oooool2o`0000?ooooo0_l00005ooooo`;o00000_oooolDo`0001[ooooo0_l0000Kooooo`;o0000
2oooool2o`0000Kooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o00003ooo
ool2o`000003ooooool0003o000000Gooooo0_l0000:ooooo`Co000000?oooooo`000?l000001Ooo
ool3o`0001Cooooo0_l00003ooooo`;o00001Oooool2o`000003ooooool0003o000001;o00005ooo
ool2o`00023ooooo1?l00008ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0F?ooool2
o`000004ooooool0003o0000ooooo`;o00001?ooool4o`0000Wooooo1?l000000ooooooo0000o`00
0002o`000004ooooool0003o0000ooooo`?o00006?ooool2o`0000Sooooo0_l00002ooooo`co0000
00Coooooo`000?l0003o00004oooool2o`0000;ooooo0_l0000Oooooo`Go00002_ooool2o`0004Wo
oooo000Looooo`03o`000?oooooooooo05Kooooo1?l00005ooooo`;o00000oooool5o`0000Cooooo
0_l00004ooooo`ko00001?ooool2o`0000gooooo0_l000000ooooooo0000o`00000;ooooo`So0000
00?oooooo`000?l000001ol00004ooooo`;o00003_ooool2o`0001oooooo0_l00002ooooo`Co0000
1_ooool2o`0000?ooooo0_l00019ooooo`007?ooool00ol0003oooooooooo`1>ooooo`Co00001?oo
ool2o`0000Oooooo0_l00006ooooo`;o00000_ooool;o`000003ooooool0003o000000Ko00001_oo
ool2o`0000gooooo0_l000000ooooooo0000o`000006ooooo`;o00000ooooolAo`0000Gooooo0_l0
000Dooooo`;o00006Oooool2o`0000Cooooo0_l00005ooooo`?o00001?ooool2o`0000Kooooo0_l0
0010ooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00004oooool5o`0001;ooooo0_l00000
0ooooooo0000o`00000:o`000003ooooool0003o000000Oo000000?oooooo`000?l000007_ooool2
o`0000Oooooo3?l0000Looooo`?o00008Oooool2o`0000;ooooo0_l00005ooooo`;o00001_ooool2
o`00043ooooo000Looooo`;o0000>_ooool2o`0000_ooooo0_l00006ooooo`Go00003Oooool2o`00
00?ooooo0_l000000ooooooo0000o`00000Go`0001Cooooo0_l0000<ooooo`Co00001?ooool4o`00
0003ooooool0003o000000Oooooo0_l0000Booooo`;o00000_ooool2o`0001Cooooo0_l0000;oooo
o`;o0000Doooool001cooooo00?o0000ooooooooool0A_ooool2o`0000Kooooo0_l00003ooooo`;o
00002oooool2o`0000Cooooo1Ol000000ooooooo0000o`00000Ao`000003ooooool0003o000001?o
oooo0_l0000:ooooo`Ko00001?ooool2o`0000?ooooo0_l00007ooooo`;o00004_ooool2o`0001So
oooo0ol0001Oooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00002Oooool2o`0000oooooo
0_l000001?oooooo0000o`000?l0000;ooooo`Oo000000?oooooo`000?l000004Ol000001?oooooo
0000o`000?ooool2o`0001Kooooo0_l00004ooooo`;o00000_ooool2o`0000;ooooo1?l00006oooo
o`;o00006?ooool2o`0001Wooooo1?l0000;ooooo`;o00001Oooool2o`0000?ooooo0_l00005oooo
o`;o0000?Oooool001cooooo00?o0000ooooooooool0=oooool2o`0000Wooooo0_l0000Booooo`?o
00002oooool2o`0000Gooooo5_l00002ooooo`;o00003oooool4o`0000?ooooo0_l00004ooooo`;o
00001?ooool4o`0000Cooooo0_l00002ooooo`;o00005_ooool2o`0000?ooooo0_l00002ooooo`;o
00005?ooool2o`0000_ooooo0_l00004ooooo`Go000000?oooooo`000?l000001Oooool2o`0003go
oooo000Looooo`03o`000?oooooooooo057ooooo0_l00004ooooo`;o00002oooool2o`0000Gooooo
5_l0000Cooooo`Co00000oooool2o`0000[ooooo0_l00006ooooo`;o00001?ooool2o`0001Cooooo
1?l000000ooooooo0000o`000002ooooo`;o00001?ooool2o`00027ooooo0_l000000ooooooo0000
o`000009ooooo`;o0000??ooool001cooooo00?o0000ooooooooool0C?ooool2o`0000?ooooo0_l0
000FoooooaSo00000_ooool2o`0000oooooo0_l00004ooooo`;o00003?ooool4o`0000;ooooo0ol0
0004ooooo`;o00005_ooool2o`0000Wooooo1?l0000Mooooo`;o00000oooool2o`0000_ooooo0_l0
000looooo`007?ooool00ol0003oooooooooo`10ooooo`;o00002_ooool2o`0001[ooooo6Ol00002
ooooo`;o00003oooool3o`0000;ooooo1Ol0000:ooooo`Co00000_ooool2o`0000Kooooo0_l0000P
ooooo`;o00005?ooool2o`0000Gooooo0_l00002ooooo`;o00000oooool2o`0004Wooooo000Loooo
o`03o`000?oooooooooo043ooooo0_l0000Qooooo`;o00000_oooolJo`0001Cooooo0_l00002oooo
o`Go00000oooool2o`0000Cooooo0ol000000ooooooo0000o`000009ooooo`?o00006_ooool2o`00
00?ooooo0_l0000<ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00003_ooool2o`00
03_ooooo000Looooo`03o`000?oooooooooo03kooooo0_l00003ooooo`;o00002oooool2o`00017o
oooo0_l00002oooooaWo00005?ooool2o`0000?ooooo1?l00004ooooo`;o00001?ooool3o`000004
ooooool0003o0000o`0000Kooooo0_l000000ooooooo0000o`00000Jooooo`;o00001oooool2o`00
00Sooooo0_l0000Dooooo`;o00000_ooool2o`0000[ooooo0_l0000kooooo`007?ooool00ol0003o
ooooooooo`0jooooo`;o00000_ooool2o`0000?ooooo0_l0000;ooooo`;o00004Oooool2o`0000;o
oooo6_l0000Cooooo`;o00001?ooool3o`0000;ooooo0_l00002ooooo`;o00001oooool2o`0000;o
oooo0_l00002ooooo`;o00009_ooool3o`000003ooooool0003o000000;o00003?ooool2o`000003
ooooool0003o000000_ooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`0jooooo`;o0000
3oooool2o`0001Kooooo0_l00002oooooa[o00003oooool2o`0000;ooooo0_l00003ooooo`?o0000
0oooool3o`000003ooooool0003o000000_ooooo0_l0000Zooooo`?o000000?oooooo`000?l00000
0_l0000<ooooo`;o000000?oooooo`000?l000003Oooool2o`0000Kooooo0_l0000mooooo`007?oo
ool00ol0003oooooooooo`0iooooo`?o00003oooool2o`0001_ooooo6Ol0000?ooooo`;o00000_oo
ool2o`0000;ooooo1Ol00003ooooo`;o00002Oooool2o`0003Cooooo0_l00004ooooo`;o00004Ooo
ool2o`0000Kooooo0_l00006ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0;oooool2
o`0000Sooooo0_l0000^oooooaSo00004?ooool2o`000003ooooool0003o000000Co000000?ooooo
o`000?l000001?ooool2o`0000?ooooo0_l00003ooooo`;o0000=?ooool2o`0000;ooooo1?l0000<
ooooo`;o00000oooool2o`0004gooooo000Looooo`03o`000?oooooooooo02oooooo0_l0000:oooo
o`;o00008oooool2o`0000Gooooo6_l00002ooooo`;o00003?ooool4o`000003ooooool0003o0000
00Kooooo1Ol00003ooooo`;o0000?Oooool2o`0000kooooo0_l0000:ooooo`;o000000?oooooo`00
0?l00000@oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l00000
0ol@413oooooooooo`04ooooo`03o`000?oooooooooo03_ooooo0_l0000Sooooo`Go00000_oooolA
o`000003ooooool0003o000000Ko00000_ooool2o`0000cooooo1?l00002ooooo`;o00001Oooool4
o`0001Sooooo0ol000000ooooooo0000o`000002ooooo`;o00009_ooool2o`0000?ooooo0_l0000<
ooooo`;o00000_ooool2o`000003ooooool0003o000004?ooooo00001_ooooooMgMgoiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0A?oo
ool2o`0001cooooo0ol00003oooooaSo00004oooool2o`0000;ooooo0_l0000;ooooo`;o000000?o
ooooo`000?l000000_l0000?ooooo`?o000000?oooooo`000?l000001?l0000Hooooo`;o00003?oo
ool2o`0000?ooooo0_l0000<ooooo`;o00000oooool2o`0004Gooooo00000ooooooo410@ooooo`02
ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006ooooo`03o`000?oooooooooo04?ooooo0ol0000R
oooooaSo00004?ooool2o`000004ooooool0003o0000o`0000kooooo2?l0000Dooooo`?o00002?oo
ool4o`0000gooooo0ol0000;ooooo`;o00005_ooool2o`0004Gooooo00000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`0004?ooooo0_l0
0002ooooo`;o00007?ooool2o`000003ooooool0003o000001Ko00004?ooool2o`0000;ooooo0_l0
00000ooooooo0000o`000004ooooo`Co00001?ooool3o`0000;ooooo0_l00009ooooo`;o00003ooo
ool2o`0000?ooooo1?l0000>ooooo`;o00002oooool2o`00013ooooo0_l0001;ooooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o
0000ooooooooool0=oooool2o`0000kooooo0_l0000Loooooa[o00005?ooool2o`0000;ooooo0_l0
0004ooooo`Co00001?ooool5o`0000Sooooo1Ol0000?ooooo`;o0000=?ooool2o`0004_ooooo0000
0ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oMgMgolc<c?l000001oooool0
0ol0003oooooooooo`0gooooo`;o0000;_oooolHo`0001Cooooo0_l00009ooooo`Oo000000?ooooo
o`000?l000000_l00008ooooo`?o00001?ooool4o`0000?ooooo0_l0000Kooooo`;o00004?ooool2
o`0000[ooooo1_l00018ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4
A4Co000000Oooooo00?o0000ooooooooool0@oooool2o`0002;ooooo0_l000000ooooooo0000o`00
000Co`0001?ooooo0_l00009ooooo`?o000000?oooooo`000?l000001Ol00002ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0000Gooooo1Ol00003ooooo`;o00006oooool2o`0000Oooooo0_l0
0006ooooo`?o00002_ooool8o`0000Oooooo0_l0000mooooo`0000Koooooonk^k_lb<S;o0000oc8b
<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0@oooool2o`0002;ooooo
0_l000000ooooooo0000o`00000:o`0000;ooooo1ol0000Booooo`?o00002Oooool2o`0000Gooooo
1?l000001Ooooooo0000o`000?l0003ooooo00;o00000_ooool2o`0000Gooooo1?l0000:ooooo`?o
00002oooool2o`0000Kooooo0_l00008ooooo`;o00001Oooool3o`0000cooooo0_l00002ooooo`?o
00001oooool2o`0003gooooo000Looooo`03o`000?oooooooooo03[ooooo0_l0000_ooooo`;o0000
00?oooooo`000?l000001ol000000ooooooo0000o`000003o`00013ooooo0_l00002ooooo`;o0000
2?ooool2o`0000;ooooo0_l00005ooooo`Go00001Oooool3o`0000;ooooo0ol000000ooooooo0000
o`000004ooooo`;o00001Oooool3o`0000Kooooo0_l000000ooooooo0000o`000002o`0000?ooooo
0_l000000ooooooo0000o`00000?ooooo`;o00002Oooool2o`0000kooooo1?l0000mooooo`007?oo
ool00ol0003oooooooooo`0eooooo`;o00000oooool2o`0000cooooo0_l0000Qooooo`oo000000?o
ooooo`000?l000004?ooool2o`0000;ooooo0_l00008ooooo`;o00000_ooool2o`0000Gooooo1?l0
0006ooooo`?o00000_ooool3o`0000Oooooo0_l0000<ooooo`Co000000?oooooo`000?l000000_l0
0003ooooo`;o000000?oooooo`000?l000003_ooool2o`0000Sooooo1?l00005ooooo`Co00001Ooo
ool3o`0003kooooo000Looooo`03o`000?oooooooooo03Gooooo0_l000000ooooooo0000o`00000<
ooooo`Co00006_ooool4o`000004ooooool0003o0000ooooo`ko00004Oooool2o`0000Cooooo0_l0
000?ooooo`;o00000_ooool3o`0000;ooooo0_l0000=ooooo`;o000000?oooooo`000?l000001ooo
ool3o`0000;ooooo1?l0000=ooooo`;o00001oooool2o`0000?ooooo1?l00008ooooo`Co00001Ooo
ool4o`0000[ooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00001_ooool2
o`0000cooooo0_l0000Looooo`Oo00000oooool5o`000003ooooool0003o000000Co000000?ooooo
o`000?l000003_ooool2o`0000;ooooo0_l0000Aooooo`;o00000oooool2o`000003ooooool0003o
000000;o00000oooool2o`0000;ooooo0_l00002ooooo`?o000000?oooooo`000?l000000_ooool4
o`000003ooooool0003o000000So00000oooool2o`00013ooooo0_l00003ooooo`Co000000?ooooo
o`000?l000001oooool6o`0000Oooooo0_l00006ooooo`;o0000>_ooool001cooooo00?o0000oooo
ooooool0<?ooool2o`0000gooooo0_l0000Vooooo`;o00001Oooool4o`0000;ooooo0ol00004oooo
o`;o00004Oooool3o`0001Kooooo0_l000000ooooooo0000o`000004o`000003ooooool0003o0000
00;ooooo0_l00002ooooo`?o00001Oooool@o`0000;ooooo0ol0000Cooooo`;o000000Coooooo`00
0?l0003ooooo1?l00007ooooo`Ko00001Oooool2o`0000Kooooo0_l0000jooooo`007?ooool00ol0
003oooooooooo`0oooooo`;o00001oooool2o`0000?ooooo0_l0000>ooooo`;o00002Oooool4o`00
00;ooooo2?l0000Hooooo`Co00002oooool2o`0000Gooooo0_l000000ooooooo0000o`000003oooo
o`Go00001?ooool2o`0000;ooooo1Ol00002oooooa?o000000?oooooo`000?l000004oooool5o`00
0003ooooool0003o000000;o00002Oooool6o`0000_ooooo0_l0000jooooo`007?ooool00ol0003o
ooooooooo`18ooooo`;o00000oooool2o`0000gooooo1Ol00007ooooo`Co00000_ooool9o`0001Oo
oooo1?l000000ooooooo0000o`000008ooooo`;o00000_ooool2o`000004ooooool0003o0000o`00
00Gooooo1Ol000000ooooooo0000o`000002ooooo`;o000000Coooooo`000?l0003ooooo0_l00002
ooooo`;o000000Coooooo`000?l0003ooooo3Ol00002ooooo`;o00000_ooool2o`0000gooooo1_l0
00000ooooooo0000o`00000;ooooo`;o00000_ooool2o`0000Oooooo0_l000001?oooooo0000o`00
0?l0000jooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00007_ooool2o`000004ooooool0
003o0000ooooo`;o00000oooool2o`0000?ooooo0_l00009ooooo`?o00006?ooool3o`000003oooo
ool0003o000000Sooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000
o`000007o`000003ooooool0003o000000Co00002_oooolAo`0000;ooooo0_l0000<ooooo`[o0000
2_ooool2o`0000;ooooo0_l00008ooooo`;o000000?oooooo`000?l00000>oooool001cooooo00?o
0000ooooooooool0>Oooool2o`0000cooooo0ol0000?ooooo`;o00001oooool5o`0000;ooooo0_l0
0007ooooo`;o00001?ooool2o`0000[ooooo0_l00009ooooo`?o00004_ooool3o`0000;ooooo0_l0
0004ooooo`Ko000000?oooooo`000?l000001?l00006ooooo`;o00000_ooool@o`00017ooooo0_l0
0003ooooo`Ko00002Oooool6o`0004Sooooo000Looooo`03o`000?oooooooooo04Oooooo0ol0000A
ooooo`;o00001Oooool5o`0000;ooooo0_l00004ooooo`Ko00000oooool2o`0000[ooooo0_l0000N
ooooo`?o00001?ooool2o`0000Cooooo0ol00002ooooo`Go00000_ooool2o`0000?ooooo0ol00002
ooooo`Go000000?oooooo`000?l000001_l0000Gooooo`Oo00000_ooool2o`0000Gooooo1?l0000=
ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0Foooool2o`0000Kooooo1?l00004oooo
o`;o00000_ooool3o`000003ooooool0003o000000?ooooo0_l0000[ooooo`;o00001?ooool4o`00
0003ooooool0003o000000Co00000oooool2o`0000;ooooo0_l00004ooooo`;o00000_ooool5o`00
0005ooooool0003o0000o`000?ooool01?l0000Gooooo`Co000000?oooooo`000?l000000_ooool2
o`0000Cooooo1_l00004ooooo`;o000000?oooooo`000?l000000_ooool3o`0003[ooooo000Loooo
o`;o0000COooool2o`0000Gooooo0_l00006ooooo`?o00001?ooool5o`0000?ooooo0ol00003oooo
o`?o00000oooool2o`0003;ooooo1Ol000000ooooooo0000o`000006o`0000;ooooo0_l00009oooo
oa3o00005Oooool2o`0000Kooooo0_l000000ooooooo0000o`000004ooooo`;o00000_ooool2o`00
00Cooooo1Ol00002ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0=oooool2o`0000So
oooo0_l00009ooooo`;o00001Oooool2o`0000Kooooo0ol00004ooooo`?o00001Oooool2o`0000Go
oooo1?l000000ooooooo0000o`00000<ooooo`;o00009?ooool4o`0000;ooooo0ol00003ooooo`Ko
00002?ooool3o`000003ooooool0003o000000co00003_ooool2o`0000?ooooo0ol00005ooooo`?o
00004oooool3o`0003oooooo000Looooo`03o`000?oooooooooo03Oooooo0_l00008ooooo`;o0000
4?ooool2o`0000?ooooo0ol00003ooooo`;o00000oooool2o`0000Kooooo0_l00006ooooo`;o0000
3oooool2o`0000Wooooo0_l0000;ooooo`;o00003Oooool2o`0000?ooooo1ol000000ooooooo0000
o`000002o`0000Oooooo1?l00004ooooo`_o00000oooool2o`0000Kooooo1Ol00003ooooo`;o0000
0_ooool2o`0000;ooooo0_l0000Eooooo`;o0000?oooool001cooooo00?o0000ooooooooool0Aooo
ool2o`0000[ooooo0_l00002ooooo`Co000000?oooooo`000?l000000_l00003ooooo`;o00001_oo
ool2o`0000;ooooo0_l0000;ooooo`;o00001_ooool2o`0000Wooooo0_l0000;ooooo`;o00001ooo
ool2o`0000?ooooo1?l00003ooooo`Ko000000Coooooo`000?l0003o00002?ooool2o`0000Oooooo
2Ol00004ooooo`;o00001_ooool5o`0000Oooooo0_l000000ooooooo0000o`00001Gooooo`007?oo
ool00ol0003oooooooooo`0Wooooo`;o00007?ooool4o`0000kooooo0_l00003ooooo`;o00001Ooo
ool3o`0000Gooooo0_l00002ooooo`;o00002oooool2o`0001?ooooo0_l0000Booooo`Wo000000?o
ooooo`000?l000002?l000000ooooooo0000o`00000<ooooo`;o00001Oooool3o`0000Oooooo0ol0
000>ooooo`;o00000_ooool4o`0005Oooooo000Looooo`03o`000?oooooooooo02Oooooo0_l0000<
ooooo`;o00003_ooool2o`0000Oooooo0_l0000@ooooo`;o00000_ooool5o`0000[ooooo0_l00003
ooooo`;o00000_ooool2o`00017ooooo1?l0000Doooooa;o000000?oooooo`000?l000003?ooool2
o`0000Kooooo1?l00005ooooo`?o00003_ooool8o`0005Oooooo000Looooo`03o`000?oooooooooo
03Gooooo0_l0000Gooooo`;o00003oooool5o`000003ooooool0003o000000Co000000?oooooo`00
0?l000001Oooool2o`0000?ooooo0_l00002ooooo`;o00001oooool2o`0000Kooooo1_l00008oooo
o`;o00003?ooool6o`0000?ooooo1Ol0000?ooooo`;o00001_ooool6o`0000Gooooo0_l0000Aoooo
o`Oo00002Oooool2o`000003ooooool0003o000000_ooooo0_l0000kooooo`007?ooool00ol0003o
ooooooooo`0hooooo`;o00008Oooool=o`000004ooooool0003o0000ooooo`;o00000_ooool5o`00
0003ooooool0003o000000Gooooo0_l00004ooooo`Ko00000oooool3o`0000cooooo0_l00004oooo
o`;o000000Coooooo`000?l0003ooooo1Ol00006ooooo`Go00003oooool2o`0000Kooooo1?l00004
ooooo`Go00003oooool2o`0000Cooooo0ol00009ooooo`Go00002oooool2o`0003_ooooo000Loooo
o`03o`000?oooooooooo03Kooooo1?l0000=ooooo`;o00000oooool2o`0000Wooooo0_l00002oooo
o`go00002?ooool5o`000003ooooool0003o000000?ooooo1?l00004ooooo`;o00000_ooool2o`00
00?ooooo1Ol00003ooooo`Co00002Oooool2o`000004ooooool0003o0000ooooo`Go00000oooool2
o`000003ooooool0003o000000;o000000?oooooo`000?l000007?ooool5o`00013ooooo0_l00004
ooooo`?o00002Oooool4o`0004Wooooo000Looooo`03o`000?oooooooooo03Kooooo0_l0000?oooo
o`;o00000oooool2o`0000Wooooo0_l00002ooooo`;o000000?oooooo`000?l000002Ol00004oooo
o`;o00003?ooool3o`0000Oooooo0_l00003ooooo`Oo00000oooool4o`0000cooooo0_l00009oooo
o`;o00000oooool5o`0001;ooooo0_l00008ooooo`Go00000_ooool2o`0000[ooooo1?l000000ooo
oooo0000o`00000@ooooo`Ko0000A?ooool001cooooo00?o0000ooooooooool0=_ooool2o`0001oo
oooo1?l00002ooooo`co00001?ooool3o`0001Cooooo1Ol000000ooooooo0000o`000002o`0001Ko
oooo0_l00002ooooo`;o00002oooool4o`0001;ooooo1?l0000<ooooo`?o00001Oooool3o`0000;o
oooo2Ol0000>ooooo`Ko00000oooool2o`0003oooooo000Looooo`03o`000?oooooooooo02Cooooo
0_l0000<ooooo`;o000000?oooooo`000?l000001?ooool2o`0001[ooooo4_l00005ooooo`;o0000
2?ooool2o`0000[ooooo1Ol00002ooooo`;o00001?ooool2o`0001Gooooo0_l00006ooooo`;o0000
0oooool5o`0001?ooooo0_l0000;ooooo`?o00001_ooool3o`0000Gooooo0ol000000ooooooo0000
o`000005ooooo`;o00000_ooool4o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o0000
?oooool001cooooo00?o0000ooooooooool09?ooool2o`0000Oooooo0_l00003ooooo`Go00001?oo
ool2o`0000cooooo0_l0000<ooooo`Oo000000Goooooo`000?l0003o0000ooooo`05o`0000Kooooo
0_l00003ooooo`;o00000oooool2o`0000;ooooo1ol000000ooooooo0000o`000002o`0000Wooooo
0_l0000Mooooo`Co00001?ooool2o`000003ooooool0003o000001?ooooo0_l00008ooooo`;o0000
2Oooool2o`0000Gooooo0_l00008ooooo`;o00000_ooool4o`0000?ooooo1Ol00002ooooo`Co0000
?Oooool001cooooo00?o0000ooooooooool0;Oooool2o`0000Cooooo0_l000000ooooooo0000o`00
000Aooooo`;o00001Oooool2o`0000Gooooo4Ol00002ooooo`;o00001?ooool2o`000003ooooool0
003o000000;ooooo0_l00003ooooo`Oo000000?oooooo`000?l000001oooool3o`0001;ooooo0_l0
0005ooooo`;o00001Oooool4o`0000Oooooo0_l0000Cooooo`;o000000?oooooo`000?l000004?oo
ool2o`0000Gooooo0_l00003ooooo`;o00004?ooool5o`0000;ooooo0_l000000ooooooo0000o`00
000jooooo`007?ooool00ol0003oooooooooo`0cooooo`Go00006?ooool2o`0000?ooooo0_l00000
0ooooooo0000o`00000Bo`0000?ooooo2_l00005ooooo`?o00000oooool2o`0000Oooooo0ol0000B
ooooo`;o00001Oooool2o`0000gooooo0_l00005ooooo`;o00004_ooool2o`00013ooooo1?l00008
ooooo`;o00001oooool2o`0000Sooooo1?l00003ooooo`Co0000>_ooool001cooooo00?o0000oooo
ooooool0:Oooool2o`0000[ooooo0_l0000Fooooo`;o000000?oooooo`000?l000000ooooolEo`00
00Gooooo0_l000000ooooooo0000o`000004o`0001Gooooo0_l0000Eooooo`;o00000oooool2o`00
00Sooooo0_l00003ooooo`;o00001Oooool2o`0002Kooooo0_l0000Aooooo`;o00001_ooool6o`00
00?ooooo1?l0000jooooo`007?ooool2o`0002[ooooo0_l0000Rooooo`;o000000Coooooo`000?l0
003ooooo0_l00002oooooa;o00000oooool2o`0000Sooooo0_l0000Aooooo`;o00002?ooool2o`00
00Gooooo0_l00004ooooo`;o00000_ooool2o`000003ooooool0003o000000;o00002?ooool2o`00
01oooooo0_l0000?ooooo`;o00002oooool2o`0000?ooooo1?l00007ooooo`?o000000?oooooo`00
0?l00000@Oooool001cooooo00?o0000ooooooooool0B?ooool2o`0000Wooooo0_l000000ooooooo
0000o`00000Ao`0000?ooooo0_l0000Kooooo`;o00002?ooool2o`0000Gooooo0_l00004ooooo`;o
00000_ooool2o`000003ooooool0003o000000;o0000:Oooool3o`0000kooooo0_l0000;ooooo`?o
00000_ooool4o`0000Sooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0gooooo`;o0000
3oooool2o`0000cooooo4ol0000hooooo`;o000000?oooooo`000?l000000oooool2o`0000Oooooo
0ol00004ooooo`?o00001oooool4o`0000Sooooo0ol00003ooooo`;o00000_ooool2o`0000?ooooo
0_l0000Cooooo`;o00003Oooool2o`0004Gooooo000Looooo`03o`000?oooooooooo03Oooooo0_l0
000=ooooo`;o00003OoooolBo`0001gooooo0_l0000;ooooo`;o00001_ooool2o`0000Kooooo0_l0
0002ooooo`?o00002_ooool3o`0000Cooooo1Ol00005ooooo`Co00002?ooool5o`0000Gooooo0_l0
0003ooooo`;o00006_ooool4o`0000Cooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`16
ooooo`;o00003?oooolBo`0000;ooooo0_l0000@ooooo`?o00001Oooool4o`0000[ooooo0ol00006
ooooo`;o00001_ooool2o`0000;ooooo0ol00004ooooo`Co00001?ooool2o`0000?ooooo0_l00000
0ooooooo0000o`00000Aooooo`Go00001Oooool2o`0000Cooooo0_l00005ooooo`;o00004_ooool4
o`000003ooooool0003o000004Sooooo000Looooo`03o`000?oooooooooo03Gooooo0_l0000Koooo
oaGo000000?oooooo`000?l000003oooool4o`0000Gooooo0_l0000<ooooo`;o00006_ooool4o`00
00Cooooo0_l0000Mooooo`?o00000oooool2o`0000Cooooo0ol000001?oooooo0000o`000?ooool4
o`0001Gooooo0_l0000:ooooo`;o0000??ooool001cooooo00?o0000ooooooooool08_ooool2o`00
00Oooooo0_l00008ooooo`;o00006ooooolGo`00013ooooo0_l00007ooooo`;o00000_ooool2o`00
02Cooooo0_l00006ooooo`;o00002oooool2o`0000Oooooo0_l000001?oooooo0000o`000?ooool2
o`000005ooooool0003o0000o`000?ooool00_l00003ooooo`?o000000Coooooo`000?l0003ooooo
1ol00004ooooo`;o00002Oooool2o`0000Cooooo0ol00009ooooo`;o0000??ooool001cooooo00?o
0000ooooooooool08_ooool2o`0000Oooooo0_l0000Gooooo`;o00003?oooolGo`0001Wooooo0ol0
00000ooooooo0000o`000002ooooo`;o00005?ooool2o`00013ooooo0_l0000=ooooo`;o00000ooo
ool2o`0000;ooooo0_l000000ooooooo0000o`00000Ao`0000?ooooo1?l00007ooooo`;o00002Ooo
ool2o`0000Cooooo0ol00006ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0A?ooool2
o`0000?ooooo0_l0000;oooooa;o00004?ooool2o`0000Sooooo0ol000000ooooooo0000o`000002
ooooo`;o000000Coooooo`000?l0003o00003_ooool4o`0000gooooo0_l000000ooooooo0000o`00
0002ooooo`;o00001Oooool2o`0000;ooooo0_l00003ooooo`;o00001?oooolFo`000003ooooool0
003o000001Oooooo0_l0000:ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0BOooool2
o`0000[ooooo4_l00004ooooo`;o00001oooool2o`000004ooooool0003o0000o`0000cooooo0_l0
0005ooooo`?o00003_ooool2o`0000oooooo0_l00002ooooo`;o000000?oooooo`000?l000001Ooo
ool2o`0000;ooooo0_l00009oooooa[o00002oooool2o`0000Gooooo0ol000000ooooooo0000o`00
001;ooooo`007?ooool00ol0003oooooooooo`0Xooooo`;o00008?ooool2o`0000Oooooo3ol00003
ooooo`;o00001?ooool2o`0000Oooooo0_l000000ooooooo0000o`00000Oooooo`;o00005Oooool6
o`0000Oooooo0ol00002ooooo`;o00002?oooolEo`000003ooooool0003o000000Ko00002?ooool2
o`0000Gooooo0ol0001>ooooo`007?ooool00ol0003oooooooooo`0Xooooo`?o00001_ooool2o`00
01Oooooo0_l00007ooooo`oo00002Oooool3o`0001Gooooo0_l0000:ooooo`;o00000oooool2o`00
00;ooooo0_l00006ooooo`;o00002?ooool4o`000003ooooool0003o000000;o00001_ooool6o`00
00;ooooo0_l00002ooooo`;o00000ooooolOo`0000Wooooo0_l000001?oooooo0000o`000?ooool2
o`0000?ooooo0_l00007ooooo`;o000000?oooooo`000?l00000?_ooool001cooooo00?o0000oooo
ooooool0:Oooool2o`0000Kooooo0_l0000?ooooo`;o00001_ooool2o`0000?ooooo0_l00003oooo
o`ko00000_ooool2o`0000;ooooo0_l000001?oooooo0000o`000?l0000Eooooo`?o00002Oooool2
o`0000?ooooo0_l00007ooooo`;o000000?oooooo`000?l000002?ooool4o`0000?ooooo0_l00006
ooooo`?o000000?oooooo`000?l000001_ooool2o`000003ooooool0003o000001Oo000000?ooooo
o`000?l000000_l00004ooooo`;o00001?ooool;o`000004ooooool0003o0000o`0000;ooooo0_l0
0003ooooo`;o000000?oooooo`000?l00000?_ooool001cooooo00?o0000ooooooooool0:Oooool2
o`0001Oooooo0_l0000;ooooo`;o00000oooool4o`000004ooooool0003o0000ooooo`Go00000ooo
ool2o`0000;ooooo0_l00002ooooo`?o00005Oooool2o`0000kooooo0_l00003ooooo`?o000000Co
ooooo`000?l0003o00001oooool2o`000004ooooool0003o0000o`0000?ooooo0ol0000<ooooo`;o
00001oooool2o`000003ooooool0003o000001Go00001?ooool2o`0000;ooooo0_l00004ooooo`;o
00000_ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000000oooool2o`0004Ko
oooo000Looooo`03o`000?oooooooooo02gooooo0_l0000Uooooo`Ko00000_ooool3o`0000kooooo
0_l0000Oooooo`;o00001?ooool2o`0000?ooooo0ol00002ooooo`;o00001oooool2o`0000;ooooo
0_l00003ooooo`;o00001oooool2o`0000Cooooo0_l00007ooooo`;o000000Coooooo`000?l0003o
oooo5_l00002ooooo`?o00002oooool2o`0000?ooooo0_l000001?oooooo0000o`000?l00004oooo
o`;o0000A?ooool001cooooo00?o0000ooooooooool0:_ooool2o`000003ooooool0003o000002Go
oooo1_l000000ooooooo0000o`00000_ooooo`Co00001?ooool2o`0000;ooooo0_l00009ooooo`?o
00002Oooool2o`0000Sooooo0_l0000<ooooo`Ko000000?oooooo`000?l000005?l00003ooooo`;o
00001Oooool2o`0000Cooooo0_l00007ooooo`;o00001?ooool2o`0004Cooooo000Looooo`;o0000
:oooool2o`0001Oooooo0_l00003ooooo`Co00001Oooool3o`0000?ooooo0_l00002ooooo`;o0000
5_ooool2o`0000Cooooo0_l00005ooooo`;o00002_ooool3o`0000Gooooo1_l00005ooooo`;o0000
00?oooooo`000?l000000_l00009ooooo`;o000000?oooooo`000?l000002Oooool3o`0000Oooooo
5?l000000ooooooo0000o`000006o`0000?ooooo0_l00005ooooo`;o0000FOooool001cooooo00?o
0000ooooooooool0:?ooool2o`0001Wooooo0_l00003ooooo`Co00000oooool5o`0000?ooooo0_l0
00000ooooooo0000o`000002o`0000_ooooo0_l00005ooooo`;o000000?oooooo`000?l000001?oo
ool2o`0000Gooooo0_l00005ooooo`?o00000oooool2o`0000Gooooo1?l00007ooooo`Go00002_oo
ool3o`000003ooooool0003o000000Sooooo1?l00002ooooo`;o00000_ooool2o`000003ooooool0
003o000000oo000000?oooooo`000?l000002_l0000;ooooo`?o00003oooool2o`0004?ooooo000L
ooooo`03o`000?oooooooooo02Kooooo1?l0000Iooooo`;o00001Oooool2o`0000?ooooo1ol00000
0ooooooo0000o`000005o`0000_ooooo0_l00005ooooo`Co00001Oooool2o`0000_ooooo1_l00000
0ooooooo0000o`000002ooooo`;o00000oooool2o`0000Oooooo1?l000000ooooooo0000o`000004
o`0000;ooooo1ol00008ooooo`?o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000L
o`0000Cooooo1Ol00002ooooo`?o00003oooool2o`0004?ooooo000Looooo`03o`000?oooooooooo
02Kooooo0_l0000Rooooo`;o00001Oooool7o`000003ooooool0003o000000;o00003?ooool2o`00
00Oooooo0_l00005ooooo`;o00000oooool2o`0000?ooooo0_l000000ooooooo0000o`000004o`00
00Gooooo0_l00003ooooo`;o00002?ooool3o`000003ooooool0003o000000Co00000_ooool2o`00
0003ooooool0003o000000;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`000006oooo
o`;o000000?oooooo`000?l000006?l000000ooooooo0000o`000004o`000003ooooool0003o0000
00?o00000oooool2o`00017ooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o
00001?ooool2o`0001Kooooo0_l00002ooooo`Co000000Goooooo`000?l0003o0000ooooo`04o`00
0003ooooool0003o000000kooooo1?l00003ooooo`;o00001Oooool2o`0000?ooooo0_l00003oooo
o`;o00000oooool4o`0000Gooooo1Ol00002ooooo`Co00001_ooool2o`00017ooooo0_l00007oooo
o`;o00002OoooolSo`0000Oooooo0_l00006ooooo`;o00000oooool2o`0000Cooooo0_l00011oooo
o`007?ooool00ol0003oooooooooo`0[ooooo`Co00000_ooool2o`0001Kooooo0_l00002ooooo`Co
00000_ooool2o`0000;ooooo0ol000000ooooooo0000o`000004o`0000Oooooo1ol00003ooooo`;o
00006oooool=o`000003ooooool0003o000000;ooooo1Ol0000Pooooo`;o000000?oooooo`000?l0
00008Ol0000>ooooo`?o00000oooool2o`0004Oooooo000Looooo`03o`000?oooooooooo02gooooo
0_l00002ooooo`;o00006_ooool4o`0000;ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o
oooo1?l00007ooooo`Ko00007?ooool2o`0000?ooooo0_l00002ooooo`Wo000000?oooooo`000?l0
00000_ooool5o`0001Gooooo0_l00002ooooo`;o00001Oooool2o`000003ooooool0003o000001oo
00004?ooool2o`0000Cooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o0000
00Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l0
00001oooool2o`0000Cooooo0_l0000@ooooo`;o00002_ooool2o`0000?ooooo0ol000000ooooooo
0000o`000004ooooo`[o00000oooool2o`0000?ooooo0_l0000>ooooo`;o00000_ooool2o`0000Ko
oooo8_l00002ooooo`?o00002?ooool2o`0000Sooooo0_l00017ooooo`007?ooool00ol0003ooooo
ooooo`0Wooooo`;o000000?oooooo`000?l000006?ooool2o`0000[ooooo0_l000001?oooooo0000
o`000?ooool4o`0000?ooooo0_l00007ooooo`;o00001?ooool2o`0000kooooo1?l00006ooooo`?o
000000?oooooo`000?l000000_ooool7o`000003ooooool0003o000000;ooooo2Ol00003ooooo`;o
00000oooool2o`0000;ooooo0_l0000=ooooo`?o00001OoooolEo`000003ooooool0003o000000_o
000000?oooooo`000?l000000_l000000ooooooo0000o`000005ooooo`;o0000DOooool001cooooo
00?o0000ooooooooool09oooool2o`000003ooooool0003o000001Sooooo0_l00007ooooo`;o0000
00Coooooo`000?l0003ooooo0_l00003ooooo`;o00008Oooool3o`0000Cooooo0_l00002ooooo`?o
000000?oooooo`000?l000002?l00002ooooo`;o00000_ooool7o`000003ooooool0003o000000Ko
00001Oooool2o`0000gooooo0ol00005ooooo`;o000000?oooooo`000?l000007Ol00002ooooo`;o
00000oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool4o`00043ooooo000Looooo`03o`00
0?oooooooooo04Kooooo0_l00003ooooo`Oo00005?ooool2o`000003ooooool0003o0000013ooooo
0_l00004ooooo`Co00001oooool6o`0000Cooooo0_l000001?oooooo0000o`000?l00002ooooo`;o
00000_ooool8o`0000?ooooo0_l0000?ooooo`;o00002Oooool3o`000003ooooool0003o000001Co
000000?oooooo`000?l000000_l00002ooooo`;o000000?oooooo`000?l000001oooool2o`0000;o
oooo1_l00005ooooo`Co0000@?ooool001cooooo00?o0000ooooooooool0A_ooool3o`0000;ooooo
0_l00002ooooo`?o00003_ooool2o`0000Cooooo0_l000000ooooooo0000o`00000Fooooo`Go0000
00?oooooo`000?l000000ol000000ooooooo0000o`000002ooooo`;o00001_oooolAo`000003oooo
ool0003o000000;o00002?ooool2o`0000Gooooo0_l00009ooooo`?o00000_oooolFo`000003oooo
ool0003o000000Go000000?oooooo`000?l000002oooool4o`000003ooooool0003o000000Cooooo
0_l00012ooooo`007?ooool00ol0003oooooooooo`0Vooooo`;o00000oooool2o`0001[ooooo0_l0
0006ooooo`;o00002?ooool2o`000003ooooool0003o000000;ooooo0ol00005ooooo`;o00004_oo
ool2o`0000Kooooo0_l000000ooooooo0000o`000007o`000003ooooool0003o000000;ooooo0_l0
00001?oooooo0000o`000?ooool<o`000004ooooool0003o0000ooooo`?o00002Oooool2o`0000;o
oooo0_l000000ooooooo0000o`000008ooooo`Go000000?oooooo`000?l000005?l000000ooooooo
0000o`000005o`0000;ooooo0_l000000ooooooo0000o`000008ooooo`;o00000_ooool3o`0004Oo
oooo000Looooo`03o`000?oooooooooo02Kooooo0_l00003ooooo`;o00006_ooool2o`0000Cooooo
0_l0000:ooooo`;o000000Goooooo`000?l0003o0000ooooo`03o`000003ooooool0003o000000;o
oooo0_l00003ooooo`Co00001_ooool2o`0000;ooooo0ol000000ooooooo0000o`000003o`0000;o
oooo1?l000000ooooooo0000o`000007o`000003ooooool0003o000000?o00000_ooool<o`0001?o
oooo0_l00004ooooo`?o00001?ooool9o`0000;ooooo1Ol000000ooooooo0000o`000004o`0000?o
oooo1ol000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000001oooool3o`000003
ooooool0003o000000;o00002Oooool2o`0003cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^
kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`15
ooooo`;o00001_ooool2o`0000kooooo0_l000000ooooooo0000o`000002ooooo`Ko00000oooool4
o`0000Kooooo0_l00002ooooo`;o00000_ooool5o`0000;ooooo3_l000000ooooooo0000o`000008
o`0000;ooooo2ol00005ooooo`;o00003_ooool3o`0000Oooooo2?l000000ooooooo0000o`000007
o`000003ooooool0003o000000Ko00001Oooool2o`0000Cooooo0_l00002ooooo`;o00000oooool2
o`0000;ooooo0_l0000;ooooo`?o0000>oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Ooo
ool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo033ooooo
0_l0000Cooooo`?o00004Oooool2o`0000;ooooo0_l00004ooooo`Go00005ooooolEo`000003oooo
ool0003o000001Go00001Oooool2o`0000Wooooo0_l0000=ooooo`?o000000?oooooo`000?l00000
3?l000000ooooooo0000o`000006o`0000Gooooo1Ol000000ooooooo0000o`000002ooooo`;o0000
0_ooool2o`00017ooooo0_l0000kooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Xooooo`;o0000
1_ooool2o`0001Cooooo0_l00005ooooo`Ko00001_ooool3o`0000Oooooo1?l00006ooooo`?o0000
1Oooool2o`0000Kooooo0_l000000ooooooo0000o`000006o`000003ooooool0003o000001co0000
00Coooooo`000?l0003o00004Oooool2o`0000_ooooo0_l000001?oooooo0000o`000?ooool2o`00
00;ooooo1Ol000000ooooooo0000o`000004o`0000;ooooo1Ol00007ooooo`?o00002Oooool2o`00
0003ooooool0003o000004_ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wo
oooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000:?ooool2o`0002?ooooo1_l000000ooo
oooo0000o`000004ooooo`;o00002Oooool2o`0000Kooooo0ol00005ooooo`;o00001_ooool7o`00
00?ooooo9?l000000ooooooo0000o`000003o`0001?ooooo0_l00003ooooo`;o00002?ooool2o`00
00Sooooo0_l00006ooooo`;o00001Oooool4o`0000cooooo0_l0001;ooooo`0000?oooooo`000?oo
ool00_ooool00ol0003oooooooooo`09ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0
003oooooooooo`0Zooooo`;o00001?ooool2o`0001Gooooo1?l00004ooooo`?o00000_ooool2o`00
00oooooo0_l0000Fooooo`Ko00001?oooolZo`0000gooooo1?l00002ooooo`;o00000oooool3o`00
00Wooooo0ol00007ooooo`;o00001?ooool2o`0000Gooooo0_l0000Fooooo`;o00000_ooool2o`00
03oooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qooo
ool02?ooool00ol0003oooooooooo`0Rooooo`;o00001_ooool2o`0000Cooooo0_l0000Eooooo`Co
00000_ooool5o`0000;ooooo0_l0000Aooooo`Go00002Oooool2o`0000?ooooo0ol00003ooooo`;o
00001?oooolPo`0000?ooooo1Ol000000ooooooo0000o`00000=ooooo`Co00000oooool2o`0000;o
oooo0ol00002ooooo`;o00001Oooool3o`0000?ooooo0_l00002ooooo`;o00000oooool3o`0001go
oooo0_l00002ooooo`;o0000?oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool00ooM
gMgo410@oiRHV008ooooo`03o`000?oooooooooo02;ooooo0_l0000Yooooo`Co00000_ooool2o`00
017ooooo1_l00009ooooo`;o00000oooool3o`0000Wooooo8Ol000000ooooooo0000o`000004o`00
01;ooooo0_l00003ooooo`;o00001oooool4o`0000Wooooo0_l00006ooooo`Co0000H_ooool00006
ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oo
oooooooo04oooooo0_l000001?oooooo0000o`000?l0000Aooooo`;o000000?oooooo`000?l00000
2_ooool7o`000003ooooool0003o000000Kooooo1?l000000ooooooo0000o`00000Ro`0000Oooooo
1?l000000ooooooo0000o`000003ooooo`?o00002_ooool2o`0000;ooooo0_l0000<ooooo`;o0000
0oooool2o`0006Cooooo000Looooo`03o`000?oooooooooo04oooooo0_l000000ooooooo0000o`00
0003ooooo`;o00004?ooool2o`000003ooooool0003o000000Oooooo2_l00005ooooob;o000000?o
ooooo`000?l000001Ol00005ooooo`Ko000000?oooooo`000?l000000_ooool3o`0000[ooooo0ol0
0002ooooo`;o00003?ooool2o`0006Wooooo000Looooo`03o`000?oooooooooo04oooooo1?l00004
ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Wooooo0_l00008ooooo`Co000000?ooooo
o`000?l000001oooool3o`000003ooooool0003o000002Co00000_ooool2o`000005ooooool0003o
0000o`000?ooool00_l00004ooooo`?o00001Oooool2o`0000Cooooo0_l000001?oooooo0000o`00
0?l00003ooooo`;o0000:oooool2o`0004Kooooo000Looooo`03o`000?oooooooooo02Wooooo0_l0
000Vooooo`;o00001oooool2o`0000Gooooo0_l00005ooooo`?o00001?ooool2o`0000Cooooo0_l0
00000ooooooo0000o`000002o`0000Sooooo:Ol000000ooooooo0000o`000006o`000003ooooool0
003o000000?ooooo0ol00006ooooo`;o000000?oooooo`000?l000001?ooool3o`0000?ooooo0_l0
000@ooooo`;o00002oooool2o`0000;ooooo0_l00008ooooo`;o0000A_ooool001cooooo00?o0000
ooooooooool0:Oooool2o`0002Oooooo0_l0000Cooooo`Co000000Coooooo`000?l0003ooooo2?l0
00000ooooooo0000o`000002o`0000Oooooo:_l000000ooooooo0000o`000002ooooo`;o00000_oo
ool3o`0000?ooooo0_l00006ooooo`;o00000_ooool2o`0001_ooooo0ol0000;ooooo`;o00000_oo
ool2o`0000Gooooo0ol00018ooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00006_ooool3
o`0000?ooooo0_l00006ooooo`;o00001?ooool3o`0000;ooooo0ol00003ooooo`Go000000Cooooo
o`000?l0003o00000oooool2o`0000?ooooo:_l00006ooooo`Ko00003?ooool2o`0001cooooo0_l0
00000ooooooo0000o`00000:ooooo`;o00002_ooool4o`000003ooooool0003o000004Gooooo000L
ooooo`03o`000?oooooooooo03Kooooo0_l0000Iooooo`Co00000oooool2o`0000Kooooo0_l00004
ooooo`Co000000?oooooo`000?l000001oooool2o`000003ooooool0003o000000?o000000Cooooo
o`000?l0003o00000_oooolZo`000003ooooool0003o000000Gooooo0_l0000:ooooo`;o00008?oo
ool2o`0000gooooo0_l00008ooooo`Co00000oooool2o`0004Gooooo000Looooo`03o`000?oooooo
oooo057ooooo0_l000001?oooooo0000o`000?l0000;ooooo`;o00001?ooool2o`0000Cooooo0_l0
0008ooooo`Co00000_ooool2o`0000?ooooo8_l000000ooooooo0000o`000004o`000003ooooool0
003o0000017ooooo0_l0000_ooooo`;o000000?oooooo`000?l000001?ooool3o`0000Gooooo0_l0
0015ooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00007_ooool2o`0000Kooooo0ol0000;
ooooo`;o00001Oooool7o`0000?ooooo0_l00003ooooo`Co00002?oooolUo`0000Sooooo0_l0000F
ooooo`;o00001_ooool2o`0000?ooooo0_l00002ooooo`;o00005Oooool2o`000003ooooool0003o
000000?ooooo1?l0001<ooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00007_ooool2o`00
0003ooooool0003o000000Cooooo0_l0000Booooo`Go00001Oooool6o`000005ooooool0003o0000
o`000?ooool00_l00004ooooobGo00002?ooool2o`0000gooooo0_l00007ooooo`;o00001_ooool3
o`0000;ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00003?ooool2o`0000Gooooo0_l0
0003ooooo`?o00000_ooool2o`0004[ooooo000Looooo`03o`000?oooooooooo04oooooo0_l00005
ooooo`;o00001oooool2o`0000cooooo0_l00006ooooo`Co00000_ooool2o`000003ooooool0003o
000000;ooooo9Ol00006ooooo`;o000000?oooooo`000?l000003_ooool2o`0000Gooooo0_l00009
ooooo`;o00002Oooool3o`0000cooooo0_l00004ooooo`?o000000?oooooo`000?l000000_l00002
ooooo`?o0000B_ooool001cooooo00?o0000ooooooooool0C_ooool2o`0000Kooooo0_l00005oooo
o`Co00003?ooool2o`0000Gooooo1?l00005ooooo`;o00000ooooolOo`0000Cooooo1Ol00003oooo
o`Go00002_ooool2o`0000Wooooo0_l0000Mooooo`;o00002_ooool6o`0000Cooooo0_l0001;oooo
o`007?ooool2o`0004oooooo0_l000000ooooooo0000o`000007ooooo`;o000000?oooooo`000?l0
00003_ooool2o`0000Gooooo0ol00003ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooo
oooo0000o`00000Io`0000;ooooo2ol00004ooooo`;o00002_ooool3o`0000Oooooo0ol00004oooo
o`;o00005oooool3o`0000cooooo0_l0000Booooo`;o0000?oooool001cooooo00?o0000oooooooo
ool0;oooool2o`00023ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l000000ooooooo
0000o`000002o`0000Oooooo0ol0000:ooooo`;o00001?ooool2o`000003ooooool0003o000002Ko
00001Oooool2o`0000Wooooo0_l00002ooooo`;o00001?ooool3o`0000Cooooo0_l0000Gooooo`;o
00002Oooool2o`0001Kooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o0000
8?ooool2o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l00000
0_l00008ooooo`;o00002?ooool2o`0000Sooooo0_l000001?oooooo0000o`000?l00002ooooo`ko
000000?oooooo`000?l000002ol00003ooooo`;o00001?ooool5o`0000Gooooo0ol00003ooooo`;o
0000;oooool2o`0005Oooooo000Looooo`03o`000?oooooooooo03kooooo0_l0000Fooooo`Go0000
2_ooool2o`00017ooooo0_l000000ooooooo0000o`000002o`0000?ooooo1Ol00002oooooa;o0000
0_ooool>o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`Go00000_ooool2o`0000?ooooo
0_l0000eooooo`;o0000COooool001cooooo00?o0000ooooooooool0?_ooool2o`00013ooooo0_l0
0004ooooo`Go00001?ooool2o`000004ooooool0003o0000ooooo`;o00003_ooool2o`0000;ooooo
1_l00005ooooo`?o00000_oooolQo`0000Cooooo1?l00005ooooo`;o000000?oooooo`000?l00000
0_ooool2o`0000?ooooo0_l0000eooooo`;o0000COooool001cooooo00?o0000ooooooooool0D?oo
ool2o`0000Cooooo1?l00005ooooo`Ko00003?ooool3o`000003ooooool0003o000000;ooooo0ol0
0002ooooo`;o00001oooool2o`000003ooooool0003o000001Wo000000Coooooo`000?l0003o0000
1?ooool5o`00037ooooo0ol000000ooooooo0000o`00000?ooooo`;o0000Coooool001cooooo00?o
0000ooooooooool0E_ooool4o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000003?oo
ool3o`0000Kooooo0_l00002ooooo`;o00001oooool2o`0000;ooooo5?l000000ooooooo0000o`00
0003o`000004ooooool0003o0000o`0000;ooooo1Ol0000cooooo`?o000000Coooooo`000?l0003o
00003_ooool2o`0004oooooo000Looooo`03o`000?oooooooooo057ooooo0_l00005ooooo`;o0000
0_ooool2o`0000[ooooo0_l00008ooooo`;o00001_ooool2o`0000?ooooo0ol00004ooooo`;o0000
0ooooolHo`0000Sooooo1Ol00004ooooo`;o0000<Oooool3o`0000?ooooo0_l00003ooooo`;o0000
EOooool001cooooo00?o0000ooooooooool0@?ooool2o`0000oooooo0_l00002ooooo`;o000000?o
ooooo`000?l000003_ooool2o`0000Oooooo0ol0000;ooooo`?o00001?ooool3o`0000;ooooo0_l0
00000ooooooo0000o`000002oooooa7o000000Coooooo`000?l0003o00000_ooool2o`0000;ooooo
1?l00003ooooo`;o00002Oooool2o`0000Wooooo0_l0000Kooooo`?o00000oooool2o`0000?ooooo
0_l00004ooooo`;o0000Coooool001cooooo00?o0000ooooooooool0@?ooool2o`00017ooooo1Ol0
0007ooooo`?o000000?oooooo`000?l000003?ooool3o`0001?ooooo0_l000000ooooooo0000o`00
0002o`000004ooooool0003o0000oooooa7o000000Coooooo`000?l0003o00000_ooool3o`0000?o
oooo0_l00007ooooo`;o00001Oooool2o`0000Wooooo0_l0000Looooo`;o00003_ooool2o`0004oo
oooo000Looooo`03o`000?oooooooooo05?ooooo1Ol00007ooooo`?o000000?oooooo`000?l00000
3Oooool2o`0001?ooooo0_l000000ooooooo0000o`00000Go`0000Cooooo1ol000001?oooooo0000
o`000?ooool2o`0000?ooooo0ol0000@ooooo`;o00007_ooool6o`0005Wooooo000Looooo`03o`00
0?oooooooooo03Cooooo0_l0000Mooooo`;o000000Coooooo`000?l0003ooooo0_l0000Gooooo`;o
00006?ooool4o`000003ooooool0003o000000?o000000?oooooo`000?l000001_l00008ooooo`Oo
000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00000_ooool2o`0000_ooooo1?l0000Koooo
o`Wo0000FOooool001cooooo00?o0000ooooooooool0=?ooool3o`0000_ooooo0_l0000?ooooo`;o
000000Coooooo`000?l0003ooooo0_l000001?oooooo0000o`000?ooool2o`0000[ooooo0_l00005
ooooo`;o00000oooool2o`0000kooooo0_l00004ooooo`;o00001Oooool2o`0000?ooooo1Ol00007
ooooo`;o00002?ooool2o`0000[ooooo0_l00005ooooo`;o00001?ooool2o`0001_ooooo2_l0001J
ooooo`007?ooool00ol0003oooooooooo`0eooooo`;o00002oooool2o`0000kooooo0_l00002oooo
o`;o00001?ooool2o`000003ooooool0003o000000[ooooo0_l00005ooooo`;o00000oooool2o`00
00kooooo0_l00004ooooo`?o000000?oooooo`000?l000001Oooool4o`000004ooooool0003o0000
ooooo`;o00000_ooool7o`0000;ooooo0_l00002ooooo`;o00003oooool2o`00027ooooo1?l00000
0ooooooo0000o`000003o`0000Kooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`0hoooo
o`;o00006?ooool2o`000004ooooool0003o0000o`0000Sooooo0_l0000@ooooo`;o00001?ooool2
o`0000Kooooo0_l0000<ooooo`;o000000?oooooo`000?l000001Oooool3o`0000;ooooo0_l00000
0ooooooo0000o`000004o`000003ooooool0003o000000?o000000?oooooo`000?l000000_ooool2
o`000003ooooool0003o000002[ooooo0ol00003ooooo`;o00000_ooool2o`0000Oooooo1?l00004
ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0>?ooool2o`0001_ooooo0ol00008oooo
o`;o00002_ooool2o`0000[ooooo0_l00006ooooo`;o00005oooool2o`0000Oooooo0_l00006oooo
o`Co00001_ooool3o`0002Wooooo0ol00003ooooo`;o00002oooool2o`0000Kooooo0_l0001<oooo
o`007?ooool2o`0005Kooooo0_l0000Eooooo`;o000000?oooooo`000?l000005Oooool2o`0000Oo
oooo0_l00002ooooo`Oo00001_ooool2o`0000;ooooo0_l00006ooooo`?o00000_ooool2o`000004
ooooool0003o0000o`0000oooooo0_l0000Fooooo`;o00004?ooool2o`0005Oooooo000Looooo`03
o`000?oooooooooo05Kooooo0_l0000Gooooo`;o00002?ooool2o`0000_ooooo0_l00004ooooo`;o
000000?oooooo`000?l000000_ooool7o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o
00001oooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000gooooo0_l0000Foooo
o`;o00000_ooool2o`000003ooooool0003o000000;o00001oooool2o`0005Oooooo000Looooo`03
o`000?oooooooooo05Kooooo1Ol0000Nooooo`Co00000_ooool2o`0000_ooooo0_l0000;ooooo`;o
00000_ooool2o`0001Sooooo0_l0000Uooooo`;o000000?oooooo`000?l000001_l00002ooooo`;o
0000G?ooool001cooooo00?o0000ooooooooool0B?ooool2o`0000Wooooo0_l00002ooooo`Go0000
7oooool2o`0000;ooooo0_l0000=ooooo`;o00001?ooool2o`0000?ooooo0_l0000;ooooo`;o0000
2Oooool2o`0002kooooo0_l000000ooooooo0000o`000005ooooo`;o0000G?ooool001cooooo00?o
0000ooooooooool0B?ooool3o`0000Sooooo0_l00002ooooo`Go000000?oooooo`000?l000006_oo
ool2o`0001?ooooo0_l00004ooooo`;o00002?ooool7o`000003ooooool0003o000000Wooooo0_l0
000aooooo`;o0000Hoooool001cooooo00?o0000ooooooooool0BOooool2o`0000cooooo2?l0000J
ooooo`;o000000?oooooo`000?l000004?ooool2o`0000kooooo1ol0000=ooooo`Co00002Oooool2
o`0000Cooooo0_l00022ooooo`007?ooool00ol0003oooooooooo`1Jooooo`Co00005Oooool2o`00
00Cooooo0_l000000ooooooo0000o`00000@ooooo`;o000000Coooooo`000?l0003o00002oooool6
o`0000Cooooo0_l00007ooooo`Co00002Oooool3o`0000?ooooo0_l0000Pooooo`;o0000H?ooool0
01cooooo00?o0000ooooooooool0Loooool2o`0000Cooooo0_l0000Fooooo`?o00002?ooool4o`00
00Wooooo0_l00006ooooo`Co00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000Soooo
o`Co0000H?ooool001cooooo00?o0000ooooooooool0??ooool2o`0005kooooo1?l00007ooooo`;o
00001Oooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000000_l00002oooo
o`;o00001Oooool2o`0001oooooo1?l0001Pooooo`007?ooool00ol0003oooooooooo`0looooo`;o
00003oooool2o`00037ooooo0_l0000Cooooo`;o00001_ooool2o`0000Sooooo0_l00005ooooo`;o
00001?ooool2o`000003ooooool0003o000000_ooooo0_l0000Nooooo`Go0000H?ooool001cooooo
00?o0000ooooooooool0COooool3o`0000_ooooo0_l0000:ooooo`;o00001Oooool4o`0000;ooooo
0_l0000:ooooo`?o00004_ooool5o`0000?ooooo0_l0000Mooooo`;o00006Oooool2o`0000Cooooo
0ol00004ooooo`;o0000Hoooool001cooooo00?o0000ooooooooool0C_ooool2o`0000_ooooo0_l0
0005ooooo`;o00000oooool2o`0000Gooooo1?l00002ooooo`;o000000?oooooo`000?l000001_oo
ool4o`000004ooooool0003o0000o`00013ooooo0ol0000?ooooo`Co000000Coooooo`000?l0003o
00002oooool2o`0000?ooooo0_l0000Cooooo`?o00001?ooool3o`0006Wooooo000Looooo`03o`00
0?oooooooooo053ooooo0_l0000@ooooo`;o00001Oooool2o`0000?ooooo0_l00007ooooo`;o0000
1?ooool4o`000003ooooool0003o000000Co00002?ooool2o`0000kooooo0_l00007ooooo`Co0000
00?oooooo`000?l000001?l0000<ooooo`?o00004oooool2o`0000[ooooo0_l0000:ooooo`;o0000
FOooool001cooooo00?o0000ooooooooool0D?ooool2o`0001Oooooo0_l00003ooooo`;o00001_oo
ool2o`0000Gooooo0_l00003ooooo`?o000000?oooooo`000?l000002?ooool2o`0000?ooooo0_l0
0006ooooo`So000000Coooooo`000?l0003ooooo1?l00003ooooo`Co00001?ooool2o`0000Kooooo
0_l0000Mooooo`;o000000?oooooo`000?l000002_ooool2o`0005Wooooo000Looooo`03o`000?oo
oooooooo053ooooo0_l0000Tooooo`?o00001oooool2o`0000Cooooo0_l0000=ooooo`;o00001_oo
ool3o`000003ooooool0003o000000;o000000Goooooo`000?l0003o0000ooooo`02o`0000Gooooo
0_l00005ooooo`;o00009Oooool2o`0006Sooooo000Looooo`03o`000?oooooooooo06;ooooo0_l0
000Cooooo`;o00001oooool2o`0001_ooooo0ol000001?oooooo0000o`000?l00003ooooo`;o0000
2_ooool2o`0003Cooooo0_l0001Nooooo`007?ooool2o`0006?ooooo0_l0000:ooooo`;o00005ooo
ool2o`000004ooooool0003o0000o`0001?ooooo1Ol00007ooooo`;o00001Oooool2o`000003oooo
ool0003o000000;o00007oooool2o`000003ooooool0003o000000Gooooo0_l00004ooooo`;o0000
G_ooool001cooooo00?o0000ooooooooool0G_ooool2o`0000Oooooo0_l00005ooooo`;o00004_oo
ool3o`0000;ooooo0_l000000ooooooo0000o`000003o`00017ooooo1Ol00002ooooo`;o00000ooo
ool2o`0000Sooooo1?l0000Mooooo`Oo00001Oooool2o`0006Cooooo000Looooo`03o`000?oooooo
oooo05kooooo0ol00003ooooo`;o000000?oooooo`000?l000006Oooool3o`0000Oooooo0ol0000G
ooooo`Co00009_ooool2o`0000Gooooo0ol000000ooooooo0000o`00001/ooooo`007?ooool00ol0
003oooooooooo`1Oooooo`;o00000oooool3o`0001Gooooo0_l0000Xooooo`Co00001Oooool2o`00
00Gooooo0_l0000Hooooo`;o0000Moooool001cooooo00?o0000ooooooooool0IOooool3o`0000go
oooo0_l00002ooooo`;o000000?oooooo`000?l000003?ooool2o`0000[ooooo0_l00008ooooo`;o
00001Oooool2o`0000Kooooo0_l00003ooooo`Co00007?ooool2o`0000;ooooo0_l00005ooooo`;o
0000J?ooool001cooooo00?o0000ooooooooool0Hoooool2o`000004ooooool0003o0000o`0000co
oooo0_l00002ooooo`;o000000?oooooo`000?l000002?ooool6o`0000[ooooo0_l00004ooooo`;o
00000_ooool2o`0000Gooooo0_l0000;ooooo`;o00007_ooool2o`0000;ooooo0_l00005ooooo`;o
00000_ooool2o`0006Cooooo000Looooo`03o`000?oooooooooo06?ooooo0_l00002ooooo`;o0000
3?ooool2o`0000oooooo1?l00005ooooo`?o00002_ooool2o`0001;ooooo0ol000000ooooooo0000
o`00000]ooooo`;o0000I?ooool001cooooo00?o0000ooooooooool0MOooool2o`0001Sooooo0ol0
0002ooooo`Co00000_ooool2o`0001Cooooo0ol0000Cooooo`;o00000_ooool2o`0000Kooooo0_l0
001eooooo`007?ooool00ol0003oooooooooo`1Yooooo`;o00003oooool2o`000003ooooool0003o
000000Go00003Oooool7o`0000;ooooo0_l0000:ooooo`?o00003_ooool2o`0000gooooo0_l00002
ooooo`;o00001_ooool2o`0007Gooooo000Looooo`03o`000?oooooooooo06Wooooo0_l0000?oooo
o`[o00003Oooool4o`0000kooooo0_l000000ooooooo0000o`000002o`0000Wooooo1_l0000:oooo
o`;o00004Oooool2o`0000Kooooo0_l0001Yooooo`007?ooool00ol0003oooooooooo`1Zooooo`;o
00001_ooool2o`0000Oooooo0_l0000Dooooo`Go00003Oooool2o`0000?ooooo0_l00009ooooo`Co
00003?ooool2o`0000Sooooo0ol00006ooooo`?o00001Oooool2o`0006Wooooo000Looooo`03o`00
0?oooooooooo06[ooooo0_l00006ooooo`;o00002_ooool2o`0000Kooooo0_l00009ooooo`;o0000
00?oooooo`000?l000000_l0000Dooooo`;o00000_ooool2o`0001_ooooo0ol00007ooooo`;o0000
L?ooool001cooooo00?o0000ooooooooool0Coooool2o`0002gooooo0_l00006ooooo`;o00001_oo
ool2o`000003ooooool0003o000000?ooooo0_l00004ooooo`;o00003_ooool2o`0000;ooooo0_l0
000Xooooo`;o0000KOooool001cooooo00?o0000ooooooooool0Coooool2o`0002Cooooo0_l0000G
ooooo`;o000000?oooooo`000?l000000oooool2o`0000Cooooo0_l0000Nooooo`;o00007?ooool2
o`0006gooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ
8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1eooooo`?o00001?ooool2o`0000Kooooo
0_l0000:ooooo`?o00003?ooool2o`000003ooooool0003o000001Oooooo0ol00002ooooo`;o0000
Qoooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?oo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo07Gooooo0ol00004ooooo`;o00001_ooool2o`00
00[ooooo1Ol0000:ooooo`;o000000?oooooo`000?l000005oooool2o`0000?ooooo0_l0000?oooo
o`?o0000MOooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool0Doooool2o`0002Cooooo0_l0000Aoooo
o`;o00001Oooool2o`0000Wooooo0_l0000Booooo`;o00007Oooool3o`0007Gooooo00000ooooooo
0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06oooo
o`?o0000Doooool2o`0002Cooooo0_l0000Aooooo`;o00001oooool2o`0000Oooooo1?l00007oooo
o`;o000000?oooooo`000?l000000_l00002ooooo`?o00001Oooool2o`0001Gooooo0_l0001foooo
o`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05olc<c?l0003o0000o`00
0?o<c<`01_ooool00ol0003oooooooooo`2;ooooo`;o00002?ooool4o`0000Oooooo0ol00006oooo
o`;o000000?oooooo`000?l000000_l00003ooooo`;o00000oooool4o`0000Sooooo0_l0000;oooo
o`;o0000M_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol@413o
^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0Noooool2o`000003ooooool0003o0000
00[ooooo0ol000000ooooooo0000o`000007ooooo`?o00000_ooool2o`0000?ooooo0_l0000;oooo
o`;o00002?ooool2o`0000[ooooo0_l0000Cooooo`;o0000K_ooool00006oooooomgMgOoV9RHoooo
oonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0Nooo
ool2o`000003ooooool0003o000000[ooooo0_l00002ooooo`Co00001Oooool3o`000003ooooool0
003o000000?o000000?oooooo`000?l000002oooool2o`0001[ooooo0_l0000=ooooo`;o0000K_oo
ool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Ko
oooo00?o0000ooooooooool0R_ooool2o`0000Cooooo0_l00009ooooo`;o000000Coooooo`000?l0
003o00002Oooool2o`0000;ooooo0_l0000Dooooo`;o00001?ooool3o`0007cooooo000Looooo`03
o`000?oooooooooo08_ooooo0ol0000Aooooo`;o00002Oooool2o`0000;ooooo0_l0000Aooooo`Go
00001Oooool2o`0000?ooooo0_l0001gooooo`007?ooool00ol0003oooooooooo`26ooooo`;o0000
0_ooool6o`00013ooooo0_l00003ooooo`;o00006_ooool3o`0000cooooo0_l0001gooooo`007?oo
ool00ol0003oooooooooo`1Mooooo`;o00009oooool2o`0000;ooooo0ol000000ooooooo0000o`00
0006ooooo`;o00002?ooool2o`0000?ooooo0_l00003ooooo`;o00000_ooool2o`0000_ooooo0_l0
000Booooo`;o0000N?ooool001cooooo00?o0000ooooooooool0GOooool2o`0002cooooo0_l00009
ooooo`;o00003Oooool2o`0000?ooooo0_l00002ooooo`;o00001_ooool4o`000003ooooool0003o
000000Oooooo0_l00005ooooo`;o00000_ooool2o`0007Sooooo000Looooo`03o`000?oooooooooo
05oooooo0_l00019ooooo`;o00000_ooool3o`0000Gooooo1?l0000:ooooo`;o00001Oooool2o`00
07cooooo000Looooo`03o`000?oooooooooo05oooooo0_l0000gooooo`?o00003oooool2o`0000?o
oooo0_l0002Hooooo`007?ooool00ol0003oooooooooo`2Hooooo`?o0000[_ooool001cooooo00?o
0000ooooooooool0Soooool2o`0000Oooooo0_l0002_ooooo`007?ooool00ol0003oooooooooo`1U
ooooo`;o0000:?ooool2o`0000Oooooo0_l0002_ooooo`007?ooool00ol0003oooooooooo`1Uoooo
o`;o0000=_ooool2o`000:[ooooo000Looooo`03o`000?oooooooooo09gooooo0_l00005ooooo`;o
0000Xoooool001cooooo0_l0002Uooooo`;o0000Xoooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
06oooooo0_l0003Hooooo`007?ooool00ol0003oooooooooo`1_ooooo`;o0000f?ooool001cooooo
00?o0000ooooooooool0L_ooool2o`000=Gooooo000Looooo`03o`000?oooooooooo07;ooooo0_l0
003Eooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0O?ooool2o`000<_ooooo000Looooo`03o`000?oooooooooo07cooooo0_l0003;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo0_l00025ooooo`;o0000`oooool001cooooo00?o0000ooooooooool0Q?ooool2
o`000<?ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0R_ooool2o`000;gooooo000Looooo`03o`000?oooooooooo08[ooooo0_l0000?ooooo`;o0000
[?ooool001cooooo00?o0000ooooooooool0Soooool2o`0000Gooooo0_l00003ooooo`;o00000ooo
ool2o`000:Oooooo000Looooo`03o`000?oooooooooo08oooooo0_l00002ooooo`;o000000?ooooo
o`000?l000002?ooool2o`000:Oooooo000Looooo`03o`000?oooooooooo09?ooooo0_l0002doooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001;ooooo1?l000000ol@413ooooooooo
o`03ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo0ol0003ooooo
od[ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0
oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooo
oooo0?ooooooD_ooool001;ooooo00?oEEEEofIVI_l00000oooooomDooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00YOooool01?l@413o0000o`000?ooool2o`000003oa0@4?oo
oooooooo01Kooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`;o000000Wo410@oooooooooooo
ooooonk^k_lb<S;o0000oc8b<_o^k^h0T?ooool00:Kooooo00Go0000ooooooooooooooooo`000009
ooooo`Ko00003Oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`2@ooooo`00Y_ooool01Ol0003ooooooooooooooooo000001gooooo00?o
0000ooooooooool01Ol00003ooooo`05oa0@4?ooooooooooooooool@4100T?ooool00:Kooooo00Go
0000ooooooooooooooooo`000009ooooo`Ko00003Oooool02?mgMgOo<S8booooooooooooA4A4omgM
gOoooooo00001?ooool01Ol0003ooooooooooooooooo0000093ooooo002Vooooo`05o`000?n7QhOo
ooooojVYZOl000006Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00CogMgMoeEEEOoooooo
00001?ooool01Ol0003ooooooooooooooooo0000093ooooo002Uooooo`03oa0@4?l0003oMgMg00;o
000000?oV9RHooooooooool05oooool00ol0003oooooooooo`05ooooo`03ogMgMoo<c<co000000Co
oooo00Go410@oooooooooooooooooa0@402@ooooo`00a?ooool00ol0003oooooooooo`05ooooo`03
onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`2@ooooo`00a?ooool4o`0000Go
oooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^093ooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(546) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.6596 .54742 Mdot
.68595 .58386 Mdot
.42516 .34926 Mdot
.47531 .63877 Mdot
.30827 .50191 Mdot
.39537 .35669 Mdot
.57328 .30206 Mdot
.54513 .32673 Mdot
.40329 .36464 Mdot
.51807 .75335 Mdot
.57077 .33469 Mdot
.41168 .67651 Mdot
.56674 .31738 Mdot
.44058 .61823 Mdot
.60605 .45384 Mdot
.39483 .56504 Mdot
.64981 .61042 Mdot
.26461 .49748 Mdot
.39457 .56417 Mdot
.41993 .34405 Mdot
.36311 .56483 Mdot
.45276 .61357 Mdot
.66617 .61217 Mdot
.44382 .61603 Mdot
.45331 .66287 Mdot
.67557 .58286 Mdot
.66704 .54893 Mdot
.48115 .66109 Mdot
.50269 .63405 Mdot
.56001 .33177 Mdot
.27665 .31418 Mdot
.81044 .63544 Mdot
.4728 .68135 Mdot
.69413 .6922 Mdot
.54387 .32937 Mdot
.56492 .21497 Mdot
.39664 .3879 Mdot
.54574 .31028 Mdot
.55345 .34585 Mdot
.54955 .34606 Mdot
.56995 .29599 Mdot
.67175 .57358 Mdot
.57911 .35138 Mdot
.45131 .34346 Mdot
.42034 .63543 Mdot
.7721 .56775 Mdot
.30178 .26189 Mdot
.49084 .65138 Mdot
.63644 .5604 Mdot
.40603 .33264 Mdot
.25211 .66096 Mdot
.56816 .28417 Mdot
.67274 .48707 Mdot
.30266 .82569 Mdot
.56796 .32898 Mdot
.48717 .63779 Mdot
.40285 .34183 Mdot
.46557 .62932 Mdot
.48615 .61405 Mdot
.68775 .67478 Mdot
.46155 .60028 Mdot
.29842 .46852 Mdot
.69717 .56535 Mdot
.38954 .40893 Mdot
.40303 .35836 Mdot
.5605 .29516 Mdot
.69639 .59651 Mdot
.55898 .31089 Mdot
.51443 .61223 Mdot
.41313 .33187 Mdot
.49334 .64382 Mdot
.56373 .3356 Mdot
.69056 .59776 Mdot
.42004 .64432 Mdot
.75138 .4997 Mdot
.54298 .37608 Mdot
.34919 .42614 Mdot
.64593 .76887 Mdot
.2899 .7413 Mdot
.34161 .31409 Mdot
.42701 .61471 Mdot
.21445 .68463 Mdot
.60305 .42576 Mdot
.68817 .57647 Mdot
.72704 .58872 Mdot
.77365 .35801 Mdot
.49757 .64916 Mdot
.37947 .4807 Mdot
.42611 .67368 Mdot
.51616 .50108 Mdot
.40682 .36804 Mdot
.67725 .5974 Mdot
.4185 .63412 Mdot
.42122 .66385 Mdot
.54511 .68243 Mdot
.50485 .60861 Mdot
.44668 .64316 Mdot
.70943 .55934 Mdot
.58589 .32474 Mdot
.48112 .70451 Mdot
.24439 .44452 Mdot
.66618 .47753 Mdot
.46496 .64779 Mdot
.37633 .37341 Mdot
.68407 .54875 Mdot
.43621 .64498 Mdot
.55217 .31256 Mdot
.4399 .60833 Mdot
.59179 .27381 Mdot
.64251 .60296 Mdot
.42251 .66747 Mdot
.32764 .45284 Mdot
.57124 .51949 Mdot
.63738 .57875 Mdot
.52665 .80765 Mdot
.45901 .60148 Mdot
.46887 .6102 Mdot
.68403 .5737 Mdot
.41812 .36941 Mdot
.42501 .45102 Mdot
.67431 .61033 Mdot
.55424 .34843 Mdot
.62693 .58163 Mdot
.40009 .64331 Mdot
.41913 .36612 Mdot
.657 .47787 Mdot
.66857 .48103 Mdot
.24422 .5107 Mdot
.41815 .64517 Mdot
.59716 .53608 Mdot
.38162 .36102 Mdot
.67728 .57343 Mdot
.55788 .31759 Mdot
.48366 .60141 Mdot
.6489 .56944 Mdot
.56307 .34808 Mdot
.2831 .47133 Mdot
.30706 .50392 Mdot
.65012 .55823 Mdot
.4019 .7367 Mdot
.57588 .27872 Mdot
.55148 .35064 Mdot
.25339 .6545 Mdot
.68566 .57041 Mdot
.29595 .48893 Mdot
.58156 .34395 Mdot
.30498 .5953 Mdot
.45947 .58967 Mdot
.23495 .56312 Mdot
.16544 .6032 Mdot
.25241 .65805 Mdot
.75722 .67086 Mdot
.32756 .46613 Mdot
.58198 .34489 Mdot
.4804 .65169 Mdot
.65536 .57572 Mdot
.65905 .56764 Mdot
.41753 .65623 Mdot
.43915 .66544 Mdot
.42884 .62973 Mdot
.47735 .59926 Mdot
.48983 .18179 Mdot
.42208 .62246 Mdot
.64014 .35195 Mdot
.64531 .57584 Mdot
.4371 .65929 Mdot
.37119 .38064 Mdot
.41128 .58364 Mdot
.54571 .31314 Mdot
.48709 .61917 Mdot
.44748 .66661 Mdot
.43507 .57889 Mdot
.57848 .34951 Mdot
.76094 .46012 Mdot
.3592 .79109 Mdot
.58879 .23122 Mdot
.69589 .47508 Mdot
.38387 .34817 Mdot
.43118 .59739 Mdot
.31728 .47583 Mdot
.42461 .6939 Mdot
.47796 .60862 Mdot
.25073 .66804 Mdot
.44834 .6723 Mdot
.71431 .71548 Mdot
.50285 .69362 Mdot
.76318 .33209 Mdot
.65843 .32671 Mdot
.47559 .60248 Mdot
.4787 .75985 Mdot
.23465 .53996 Mdot
.23751 .34276 Mdot
.55784 .32568 Mdot
.36745 .38368 Mdot
.41224 .37884 Mdot
.54333 .34538 Mdot
.52984 .63542 Mdot
.52403 .76022 Mdot
.50633 .60085 Mdot
.65682 .47592 Mdot
.67285 .63063 Mdot
.32142 .47915 Mdot
.64985 .55744 Mdot
.2339 .71499 Mdot
.38343 .5029 Mdot
.36395 .31283 Mdot
.26802 .49997 Mdot
.38481 .32934 Mdot
.64638 .4575 Mdot
.30603 .48717 Mdot
.45966 .63938 Mdot
.6318 .58652 Mdot
.23151 .54081 Mdot
.4092 .56528 Mdot
.61146 .15461 Mdot
.69363 .57895 Mdot
.54128 .47068 Mdot
.5635 .32556 Mdot
.39096 .40556 Mdot
.49668 .64992 Mdot
.44849 .62924 Mdot
.68929 .55756 Mdot
.49595 .64478 Mdot
.43069 .47745 Mdot
.45105 .66892 Mdot
.36666 .40398 Mdot
.29109 .44519 Mdot
.59084 .26839 Mdot
.27545 .51873 Mdot
.68481 .60412 Mdot
.58733 .39081 Mdot
.37384 .37671 Mdot
.55091 .56916 Mdot
.55237 .32912 Mdot
.28878 .46406 Mdot
.38709 .38714 Mdot
.32317 .44529 Mdot
.409 .62171 Mdot
.40224 .38246 Mdot
.28928 .47824 Mdot
.4986 .36633 Mdot
.44681 .64412 Mdot
.26091 .58295 Mdot
.59539 .31852 Mdot
.66117 .55013 Mdot
.46965 .60166 Mdot
.65358 .47965 Mdot
.39918 .60505 Mdot
.5915 .51607 Mdot
.64131 .45372 Mdot
.66414 .44956 Mdot
.34896 .32751 Mdot
.28539 .49497 Mdot
.73341 .51766 Mdot
.46369 .43172 Mdot
.65216 .61161 Mdot
.41187 .61014 Mdot
.79847 .45662 Mdot
.59612 .31854 Mdot
.46347 .63729 Mdot
.75646 .34205 Mdot
.58314 .34304 Mdot
.47009 .62334 Mdot
.57597 .29516 Mdot
.65562 .5703 Mdot
.53713 .39984 Mdot
.62422 .57126 Mdot
.47718 .63562 Mdot
.58696 .3093 Mdot
.37163 .38798 Mdot
.67473 .58286 Mdot
.44691 .60732 Mdot
.42382 .61432 Mdot
.65385 .47043 Mdot
.42716 .65601 Mdot
.8109 .43987 Mdot
.48866 .65323 Mdot
.38964 .32663 Mdot
.50927 .61461 Mdot
.2176 .54565 Mdot
.30314 .50705 Mdot
.69396 .61055 Mdot
.64285 .44997 Mdot
.41067 .36511 Mdot
.51655 .3801 Mdot
.25208 .50952 Mdot
.43289 .61347 Mdot
.66434 .46253 Mdot
.54178 .46464 Mdot
.55344 .3024 Mdot
.50294 .65266 Mdot
.42764 .46341 Mdot
.39847 .37627 Mdot
.64981 .46729 Mdot
.49146 .56692 Mdot
.65024 .54568 Mdot
.48628 .64119 Mdot
.38978 .38955 Mdot
.64061 .55257 Mdot
.49522 .60955 Mdot
.3903 .21998 Mdot
.65854 .48409 Mdot
.59108 .30433 Mdot
.57297 .61175 Mdot
.41817 .61311 Mdot
.40749 .38613 Mdot
.65263 .5657 Mdot
.57901 .32236 Mdot
.64451 .59944 Mdot
.22827 .51968 Mdot
.61067 .53691 Mdot
.49109 .21005 Mdot
.26378 .49007 Mdot
.70464 .76837 Mdot
.58229 .22736 Mdot
.58475 .56289 Mdot
.3663 .43081 Mdot
.69456 .24688 Mdot
.38164 .38339 Mdot
.43242 .75422 Mdot
.411 .3543 Mdot
.47394 .64862 Mdot
.39797 .35793 Mdot
.82005 .4223 Mdot
.46509 .66965 Mdot
.3889 .34133 Mdot
.46628 .20512 Mdot
.4469 .67367 Mdot
.64351 .57326 Mdot
.80303 .5869 Mdot
.55483 .81243 Mdot
.36774 .70329 Mdot
.39274 .33772 Mdot
.4279 .76219 Mdot
.48796 .65773 Mdot
.40915 .55864 Mdot
.66026 .57962 Mdot
.39605 .64253 Mdot
.33139 .46901 Mdot
.33001 .44873 Mdot
.28022 .66714 Mdot
.58771 .81737 Mdot
.51769 .55984 Mdot
.66976 .57688 Mdot
.27432 .7279 Mdot
.75566 .5021 Mdot
.66457 .48708 Mdot
.5487 .3396 Mdot
.75365 .4571 Mdot
.48913 .56289 Mdot
.49934 .70968 Mdot
.46794 .46388 Mdot
.67849 .59868 Mdot
.51221 .25389 Mdot
.58051 .31586 Mdot
.43549 .78152 Mdot
.56336 .73657 Mdot
.42955 .6325 Mdot
.59104 .29039 Mdot
.47958 .69764 Mdot
.45381 .46787 Mdot
.25053 .57701 Mdot
.38268 .26107 Mdot
.46392 .64077 Mdot
.74197 .52038 Mdot
.47786 .61108 Mdot
.24124 .54587 Mdot
.47205 .63526 Mdot
.6429 .59564 Mdot
.52576 .58203 Mdot
.47142 .41015 Mdot
.44173 .8029 Mdot
.38712 .49943 Mdot
.29539 .49524 Mdot
.44195 .62069 Mdot
.4408 .63392 Mdot
.29359 .46983 Mdot
.67039 .5986 Mdot
.41856 .59858 Mdot
.31034 .25205 Mdot
.42056 .62405 Mdot
.5626 .28753 Mdot
.51915 .40696 Mdot
.7085 .73115 Mdot
.45702 .6749 Mdot
.65663 .54423 Mdot
.55674 .30202 Mdot
.55785 .34163 Mdot
.51703 .56328 Mdot
.59595 .31071 Mdot
.48555 .64973 Mdot
.52156 .40796 Mdot
.66054 .61147 Mdot
.44646 .70022 Mdot
.66549 .59949 Mdot
.24325 .68166 Mdot
.5919 .33492 Mdot
.6646 .45636 Mdot
.41125 .75497 Mdot
.57485 .30699 Mdot
.42497 .51956 Mdot
.52931 .60443 Mdot
.45349 .56447 Mdot
.59064 .57293 Mdot
.37611 .39431 Mdot
.65666 .45139 Mdot
.57193 .3285 Mdot
.42197 .62453 Mdot
.44446 .64843 Mdot
.58534 .28442 Mdot
.63332 .66151 Mdot
.28068 .31115 Mdot
.48071 .63247 Mdot
.64977 .60067 Mdot
.67598 .57373 Mdot
.45376 .58418 Mdot
.47382 .60635 Mdot
.36914 .34706 Mdot
.66459 .46132 Mdot
.65029 .44771 Mdot
.67153 .47143 Mdot
.35704 .3873 Mdot
.66899 .79498 Mdot
.55177 .35095 Mdot
.77032 .67225 Mdot
.76179 .39515 Mdot
.48658 .54904 Mdot
.39661 .39158 Mdot
.45835 .62407 Mdot
.45735 .65085 Mdot
.5879 .31388 Mdot
.55932 .83377 Mdot
.47959 .68237 Mdot
.67084 .55207 Mdot
.57195 .28424 Mdot
.42226 .68592 Mdot
.56457 .37229 Mdot
.31398 .45175 Mdot
.35685 .58583 Mdot
.59375 .29075 Mdot
.64078 .59907 Mdot
.59216 .28839 Mdot
.43646 .63307 Mdot
.47715 .56545 Mdot
.68102 .59817 Mdot
.27402 .48625 Mdot
.41201 .6262 Mdot
.47204 .62222 Mdot
.18358 .4361 Mdot
.75058 .50277 Mdot
.32319 .39597 Mdot
.46228 .65735 Mdot
.46024 .5699 Mdot
.2742 .47563 Mdot
.41756 .60691 Mdot
.50362 .62928 Mdot
.5692 .51485 Mdot
.58142 .26892 Mdot
.30251 .50003 Mdot
.42644 .7897 Mdot
.69207 .57272 Mdot
.80428 .42051 Mdot
.66376 .48038 Mdot
.604 .2741 Mdot
.54251 .40002 Mdot
.65267 .45567 Mdot
.74608 .34464 Mdot
.59764 .23427 Mdot
.66077 .45645 Mdot
.40123 .40382 Mdot
.40886 .70035 Mdot
.50626 .62669 Mdot
.4832 .6203 Mdot
.28436 .49323 Mdot
.67395 .55993 Mdot
.64537 .35086 Mdot
.56312 .27193 Mdot
.45925 .61178 Mdot
.61866 .57062 Mdot
.76837 .3445 Mdot
.64856 .46167 Mdot
.32335 .46628 Mdot
.27728 .49629 Mdot
.47554 .61136 Mdot
.51676 .52594 Mdot
.67264 .57807 Mdot
.447 .60741 Mdot
.45166 .59173 Mdot
.41391 .34919 Mdot
.63023 .58051 Mdot
.37005 .37349 Mdot
.64106 .44762 Mdot
.6522 .20393 Mdot
.18741 .39175 Mdot
.58956 .33043 Mdot
.54163 .24572 Mdot
.60656 .31304 Mdot
.40321 .25134 Mdot
.66439 .45937 Mdot
.45028 .60982 Mdot
.68451 .6087 Mdot
.44234 .60734 Mdot
.4192 .62799 Mdot
.43011 .63871 Mdot
.51575 .55798 Mdot
.24305 .66232 Mdot
.31555 .46395 Mdot
.51785 .62256 Mdot
.36982 .3404 Mdot
.76003 .33333 Mdot
.80594 .5398 Mdot
.44146 .62582 Mdot
.46931 .61199 Mdot
.69791 .58418 Mdot
.40802 .62239 Mdot
.55009 .31405 Mdot
.69025 .5749 Mdot
.45947 .64708 Mdot
.22931 .46648 Mdot
.42627 .59259 Mdot
.55095 .23626 Mdot
.59412 .2894 Mdot
.3618 .61949 Mdot
.48302 .57258 Mdot
.66398 .45738 Mdot
.65677 .45195 Mdot
.6476 .47403 Mdot
.57515 .28655 Mdot
.41456 .35231 Mdot
.43497 .34404 Mdot
.50403 .57576 Mdot
.48016 .65393 Mdot
.47061 .56602 Mdot
.35375 .3554 Mdot
.4602 .4266 Mdot
.74555 .56297 Mdot
.50718 .68975 Mdot
.35743 .37232 Mdot
.66809 .52883 Mdot
.47238 .81023 Mdot
.68346 .56373 Mdot
.35815 .42545 Mdot
.54873 .32772 Mdot
.33006 .45982 Mdot
.28679 .70824 Mdot
.66668 .61055 Mdot
.68544 .55561 Mdot
.38511 .34458 Mdot
.56627 .44516 Mdot
.40092 .89357 Mdot
.37937 .36975 Mdot
.34652 .43124 Mdot
.66438 .57985 Mdot
.46943 .68462 Mdot
.54374 .46099 Mdot
.56556 .46927 Mdot
.39644 .34453 Mdot
.42537 .61287 Mdot
.43577 .51358 Mdot
.36972 .3464 Mdot
.50529 .65266 Mdot
.39021 .33721 Mdot
.59334 .30181 Mdot
.37884 .3587 Mdot
.62596 .60423 Mdot
.41661 .63581 Mdot
.33136 .84805 Mdot
.59997 .42093 Mdot
.44918 .60157 Mdot
.57786 .28262 Mdot
.44087 .19651 Mdot
.44113 .63756 Mdot
.32331 .4807 Mdot
.35641 .36422 Mdot
.37508 .25156 Mdot
.5013 .63018 Mdot
.39687 .35063 Mdot
.65132 .61885 Mdot
.36119 .42391 Mdot
.30802 .39791 Mdot
.65309 .44897 Mdot
.65296 .57197 Mdot
.67194 .44882 Mdot
.54266 .32813 Mdot
.41637 .59092 Mdot
.43915 .59097 Mdot
.64251 .58461 Mdot
.50724 .36449 Mdot
.51325 .65346 Mdot
.42715 .61509 Mdot
.36875 .35165 Mdot
.36641 .33805 Mdot
.6207 .46601 Mdot
.37657 .38336 Mdot
.46134 .57069 Mdot
.64089 .58553 Mdot
.4784 .64397 Mdot
.64728 .56564 Mdot
.41116 .61363 Mdot
.68988 .50757 Mdot
.67927 .56085 Mdot
.55924 .56258 Mdot
.42124 .65448 Mdot
.61505 .62829 Mdot
.41576 .61987 Mdot
.4537 .64214 Mdot
.3551 .36086 Mdot
.30692 .47558 Mdot
.47627 .67535 Mdot
.58216 .38756 Mdot
.28559 .45965 Mdot
.73491 .658 Mdot
.41789 .36837 Mdot
.27756 .4802 Mdot
.28382 .62302 Mdot
.64293 .45012 Mdot
.30468 .4646 Mdot
.63164 .45893 Mdot
.59172 .32468 Mdot
.63228 .59891 Mdot
.437 .67096 Mdot
.69571 .24068 Mdot
.27663 .31487 Mdot
.65573 .46903 Mdot
.46864 .6024 Mdot
.45798 .62761 Mdot
.64087 .55009 Mdot
.22679 .70189 Mdot
.37227 .41049 Mdot
.46348 .64302 Mdot
.67623 .60798 Mdot
.19317 .64988 Mdot
.38353 .33983 Mdot
.31354 .45913 Mdot
.60291 .30391 Mdot
.62866 .6211 Mdot
.65848 .44977 Mdot
.59177 .33546 Mdot
.34552 .40185 Mdot
.25083 .67674 Mdot
.50059 .62934 Mdot
.38046 .39334 Mdot
.25214 .6587 Mdot
.49784 .69607 Mdot
.57267 .35867 Mdot
.68168 .50811 Mdot
.67945 .59596 Mdot
.58207 .28372 Mdot
.29231 .49686 Mdot
.64627 .60762 Mdot
.6701 .59988 Mdot
.54639 .32983 Mdot
.65889 .28788 Mdot
.54502 .46876 Mdot
.54917 .30211 Mdot
.56675 .49491 Mdot
.25317 .65067 Mdot
.66775 .46444 Mdot
.32381 .46695 Mdot
.2129 .49894 Mdot
.67373 .57653 Mdot
.7548 .45734 Mdot
.25157 .66564 Mdot
.44739 .64317 Mdot
.28832 .48542 Mdot
.77023 .36539 Mdot
.59494 .26519 Mdot
.56678 .3475 Mdot
.39775 .46034 Mdot
.31158 .48951 Mdot
.44762 .58707 Mdot
.69344 .74719 Mdot
.42903 .66787 Mdot
.58781 .3384 Mdot
.45676 .47276 Mdot
.63101 .57979 Mdot
.54159 .32655 Mdot
.42353 .4781 Mdot
.45899 .65168 Mdot
.45202 .59707 Mdot
.27773 .53067 Mdot
.62899 .57702 Mdot
.66186 .45026 Mdot
.43296 .60851 Mdot
.46868 .6285 Mdot
.42486 .58528 Mdot
.39273 .75035 Mdot
.55551 .54056 Mdot
.4583 .64506 Mdot
.38335 .40435 Mdot
.43727 .56616 Mdot
.48109 .60397 Mdot
.6332 .5535 Mdot
.21371 .55945 Mdot
.64064 .44761 Mdot
.48218 .62262 Mdot
.48095 .63174 Mdot
.54846 .34229 Mdot
.54369 .46646 Mdot
.56702 .47198 Mdot
.39109 .32879 Mdot
.36863 .46216 Mdot
.50166 .5927 Mdot
.64869 .57732 Mdot
.33328 .46561 Mdot
.44016 .57445 Mdot
.68365 .56172 Mdot
.51966 .60431 Mdot
.37459 .33688 Mdot
.66202 .46152 Mdot
.53964 .65058 Mdot
.30054 .47032 Mdot
.579 .27532 Mdot
.78427 .65085 Mdot
.36669 .37777 Mdot
.46788 .66212 Mdot
.42778 .32247 Mdot
.38843 .37368 Mdot
.65702 .47265 Mdot
.42175 .56049 Mdot
.66034 .57026 Mdot
.63424 .58705 Mdot
.24127 .62138 Mdot
.36038 .3953 Mdot
.16111 .50705 Mdot
.59435 .30377 Mdot
.50249 .65053 Mdot
.7913 .51994 Mdot
.63256 .57981 Mdot
.24246 .52501 Mdot
.27684 .48025 Mdot
.56732 .34722 Mdot
.64975 .43971 Mdot
.67555 .5569 Mdot
.63681 .56938 Mdot
.4189 .63331 Mdot
.44897 .621 Mdot
.36223 .43787 Mdot
.23537 .55166 Mdot
.57575 .29553 Mdot
.31767 .45704 Mdot
.39995 .32845 Mdot
.46521 .6532 Mdot
.68746 .58745 Mdot
.69432 .7403 Mdot
.41942 .61085 Mdot
.37483 .33783 Mdot
.68249 .5895 Mdot
.30342 .4592 Mdot
.28332 .47673 Mdot
.44901 .64258 Mdot
.68778 .72693 Mdot
.57228 .30577 Mdot
.64019 .57851 Mdot
.7209 .58459 Mdot
.515 .62258 Mdot
.4436 .62293 Mdot
.44729 .69155 Mdot
.55833 .35787 Mdot
.53527 .66133 Mdot
.27058 .47729 Mdot
.66623 .56248 Mdot
.44287 .60397 Mdot
.2988 .46801 Mdot
.50699 .70571 Mdot
.65562 .45897 Mdot
.38431 .3408 Mdot
.3259 .47645 Mdot
.29652 .482 Mdot
.28879 .45866 Mdot
.75278 .45995 Mdot
.6834 .5474 Mdot
.40268 .79607 Mdot
.41685 .62871 Mdot
.25358 .6476 Mdot
.40547 .62721 Mdot
.58346 .29358 Mdot
.36619 .38544 Mdot
.42234 .63004 Mdot
.41643 .63019 Mdot
.73141 .69929 Mdot
.37786 .5761 Mdot
.36248 .59201 Mdot
.63689 .59645 Mdot
.57867 .62045 Mdot
.40261 .39074 Mdot
.14926 .58111 Mdot
.83167 .54792 Mdot
.5037 .59937 Mdot
.56336 .44071 Mdot
.68976 .57547 Mdot
.56795 .34964 Mdot
.55736 .48205 Mdot
.61708 .2852 Mdot
.67413 .56428 Mdot
.46965 .65016 Mdot
.7732 .65807 Mdot
.30976 .44675 Mdot
.4309 .62975 Mdot
.5558 .31737 Mdot
.4299 .62975 Mdot
.57612 .28875 Mdot
.6544 .63326 Mdot
.57735 .45709 Mdot
.4521 .67243 Mdot
.50733 .60942 Mdot
.50456 .69934 Mdot
.44407 .6246 Mdot
.43344 .28193 Mdot
.66801 .59156 Mdot
.55282 .56333 Mdot
.4545 .58231 Mdot
.64487 .75076 Mdot
.43174 .59171 Mdot
.52033 .36751 Mdot
.44164 .59274 Mdot
.35013 .69171 Mdot
.45285 .58783 Mdot
.43312 .59639 Mdot
.58325 .31458 Mdot
.55608 .34871 Mdot
.65969 .62277 Mdot
.66672 .45401 Mdot
.76223 .332 Mdot
.47103 .61732 Mdot
.35803 .34857 Mdot
.64315 .49315 Mdot
.30199 .48045 Mdot
.67109 .56528 Mdot
.12703 .46294 Mdot
.56316 .29722 Mdot
.39208 .40771 Mdot
.36104 .30131 Mdot
.40753 .39336 Mdot
.34913 .36114 Mdot
.60158 .61783 Mdot
.32473 .46097 Mdot
.4404 .58842 Mdot
.69797 .69868 Mdot
.74903 .51655 Mdot
.51162 .6297 Mdot
.43746 .33843 Mdot
.38444 .64729 Mdot
.2464 .648 Mdot
.32453 .44305 Mdot
.32385 .47383 Mdot
.57596 .32432 Mdot
.42396 .35554 Mdot
.49765 .69278 Mdot
.27802 .47891 Mdot
.36511 .38157 Mdot
.6718 .48207 Mdot
.33116 .51151 Mdot
.67006 .5737 Mdot
.38517 .71834 Mdot
.78225 .54682 Mdot
.56724 .29595 Mdot
.57366 .3902 Mdot
.67787 .53757 Mdot
.70348 .61171 Mdot
.67028 .45992 Mdot
.36606 .34527 Mdot
.64566 .6095 Mdot
.41696 .63444 Mdot
.40964 .56512 Mdot
.47489 .60979 Mdot
.28107 .48821 Mdot
.45838 .59436 Mdot
.3633 .35561 Mdot
.56987 .3002 Mdot
.40538 .3708 Mdot
.57609 .30291 Mdot
.76916 .63462 Mdot
.48307 .60942 Mdot
.44486 .62036 Mdot
.53136 .41424 Mdot
.64395 .56159 Mdot
.68291 .69058 Mdot
.36681 .3427 Mdot
.40743 .34544 Mdot
.47579 .64454 Mdot
.6983 .60509 Mdot
.25871 .49783 Mdot
.54896 .44831 Mdot
.44507 .59171 Mdot
.667 .59174 Mdot
.48291 .64111 Mdot
.40885 .23488 Mdot
.59188 .44977 Mdot
.641 .59565 Mdot
.44512 .80548 Mdot
.42349 .65271 Mdot
.37142 .59166 Mdot
.38143 .59691 Mdot
.3432 .5894 Mdot
.49508 .66525 Mdot
.69337 .58137 Mdot
.4879 .61761 Mdot
.65178 .58061 Mdot
.38469 .37813 Mdot
.55579 .35401 Mdot
.65501 .5794 Mdot
.42521 .66334 Mdot
.823 .5681 Mdot
.55982 .30287 Mdot
.43096 .6224 Mdot
.57336 .33174 Mdot
.62559 .58976 Mdot
.64198 .55759 Mdot
.62586 .45401 Mdot
.34935 .33173 Mdot
.55591 .30754 Mdot
.4827 .65297 Mdot
.75569 .47947 Mdot
.47907 .64399 Mdot
.36341 .46246 Mdot
.47041 .58872 Mdot
.51125 .61911 Mdot
.71936 .75814 Mdot
.51527 .3739 Mdot
.14531 .49379 Mdot
.53392 .2957 Mdot
.76097 .46761 Mdot
.70742 .62074 Mdot
.32525 .44322 Mdot
.52818 .259 Mdot
.6426 .46134 Mdot
.38882 .4021 Mdot
.42118 .6286 Mdot
.75548 .61143 Mdot
.55747 .29267 Mdot
.3112 .47428 Mdot
.44959 .6723 Mdot
.42776 .34306 Mdot
.64949 .42254 Mdot
.57933 .34587 Mdot
.67067 .57186 Mdot
.64926 .5568 Mdot
.30915 .75942 Mdot
.44778 .6031 Mdot
.4514 .61648 Mdot
.54634 .3188 Mdot
.51113 .6793 Mdot
.29772 .45409 Mdot
.46857 .21367 Mdot
.55514 .32199 Mdot
.59829 .44052 Mdot
.63854 .59997 Mdot
.45787 .62625 Mdot
.51717 .40661 Mdot
.72551 .41191 Mdot
.52636 .71955 Mdot
.29647 .49176 Mdot
.32626 .53988 Mdot
.69347 .58118 Mdot
.55766 .32033 Mdot
.27842 .65139 Mdot
.4121 .65611 Mdot
.46024 .62848 Mdot
.31033 .54368 Mdot
.55098 .45404 Mdot
.35365 .48066 Mdot
.42346 .67831 Mdot
.52692 .46005 Mdot
.47383 .64538 Mdot
.44483 .64861 Mdot
.514 .61087 Mdot
.49206 .61048 Mdot
.66163 .59036 Mdot
.57434 .80626 Mdot
.38998 .35641 Mdot
.47928 .7459 Mdot
.39487 .45394 Mdot
.48873 .65832 Mdot
.465 .65072 Mdot
.53907 .7877 Mdot
.6206 .51644 Mdot
.66951 .58733 Mdot
.71905 .5841 Mdot
.54892 .34794 Mdot
.37872 .57476 Mdot
.35683 .39049 Mdot
.36901 .62402 Mdot
.39809 .36811 Mdot
.66607 .5927 Mdot
.41612 .36156 Mdot
.53936 .30175 Mdot
.38056 .39317 Mdot
.36129 .39277 Mdot
.59774 .32703 Mdot
.63155 .56572 Mdot
.42745 .5992 Mdot
.59782 .32273 Mdot
.26458 .52488 Mdot
.281 .48752 Mdot
.62726 .46054 Mdot
.47021 .68483 Mdot
.37075 .58485 Mdot
.38743 .22203 Mdot
.4088 .3762 Mdot
.58583 .50166 Mdot
.67824 .56021 Mdot
.31653 .48992 Mdot
.65743 .5879 Mdot
.33904 .74764 Mdot
.29399 .47636 Mdot
.6283 .46145 Mdot
.27378 .63976 Mdot
.59484 .36827 Mdot
.40068 .59901 Mdot
.58414 .58487 Mdot
.39789 .37067 Mdot
.56415 .28652 Mdot
.76528 .3533 Mdot
.42599 .65009 Mdot
.68135 .47847 Mdot
.71109 .60135 Mdot
.64442 .44929 Mdot
.55843 .31587 Mdot
.536 .28048 Mdot
.45359 .60279 Mdot
.57624 .37899 Mdot
.50189 .61011 Mdot
.41518 .7561 Mdot
.36692 .45511 Mdot
.63114 .52985 Mdot
.48714 .64205 Mdot
.37491 .34069 Mdot
.48427 .64284 Mdot
.4111 .72195 Mdot
.26167 .65787 Mdot
.49648 .59746 Mdot
.59204 .56281 Mdot
.37879 .24234 Mdot
.68445 .59226 Mdot
.4699 .57364 Mdot
.66368 .46931 Mdot
.44968 .65868 Mdot
.74273 .24769 Mdot
.3054 .4666 Mdot
.33222 .40604 Mdot
.42187 .65882 Mdot
.43669 .60823 Mdot
.70458 .71586 Mdot
.58644 .59867 Mdot
.64682 .4393 Mdot
.45856 .63288 Mdot
.33302 .54614 Mdot
.58128 .3209 Mdot
.492 .6066 Mdot
.48445 .61694 Mdot
.19843 .40721 Mdot
.58159 .32345 Mdot
.40527 .38307 Mdot
.64207 .45181 Mdot
.38987 .33073 Mdot
.33936 .45126 Mdot
.53895 .49511 Mdot
.2447 .53343 Mdot
.5937 .4519 Mdot
.30867 .49305 Mdot
.49401 .65539 Mdot
.72081 .56801 Mdot
.43892 .6004 Mdot
.31898 .47964 Mdot
.56033 .33201 Mdot
.66206 .58764 Mdot
.39675 .73135 Mdot
.65797 .47612 Mdot
.51271 .63605 Mdot
.32015 .44104 Mdot
.65723 .57522 Mdot
.66474 .38815 Mdot
.67959 .56454 Mdot
.57851 .30781 Mdot
.54048 .33824 Mdot
.29951 .47682 Mdot
.65919 .58989 Mdot
.39959 .33393 Mdot
.53155 .29802 Mdot
.47803 .59229 Mdot
.5337 .31557 Mdot
.67062 .61992 Mdot
.67018 .5492 Mdot
.68718 .61108 Mdot
.49137 .61432 Mdot
.55611 .45116 Mdot
.40459 .63762 Mdot
.55348 .30761 Mdot
.41321 .38296 Mdot
.23785 .57177 Mdot
.68956 .71054 Mdot
.59707 .43749 Mdot
.48059 .6737 Mdot
.46308 .59756 Mdot
.47501 .61119 Mdot
.48757 .63361 Mdot
.47265 .21475 Mdot
.48337 .60996 Mdot
.58587 .30582 Mdot
.3903 .36738 Mdot
.46262 .60087 Mdot
.66438 .4663 Mdot
.45913 .43213 Mdot
.33308 .46689 Mdot
.34776 .66322 Mdot
.80886 .51087 Mdot
.65819 .57699 Mdot
.38046 .38928 Mdot
.41708 .35372 Mdot
.28324 .47112 Mdot
.59379 .33022 Mdot
.67261 .56013 Mdot
.33205 .64876 Mdot
.29012 .45466 Mdot
.48174 .62339 Mdot
.52487 .40993 Mdot
.45798 .80704 Mdot
.47143 .67173 Mdot
.43997 .64053 Mdot
.65661 .44655 Mdot
.39022 .40742 Mdot
.76693 .29525 Mdot
.65815 .30829 Mdot
.30515 .47572 Mdot
.30889 .45485 Mdot
.69242 .60226 Mdot
.50647 .64646 Mdot
.56908 .30526 Mdot
.53497 .46348 Mdot
.39714 .20901 Mdot
.79425 .39099 Mdot
.40295 .25367 Mdot
.42447 .59391 Mdot
.59259 .78758 Mdot
.44527 .5786 Mdot
.68374 .54839 Mdot
.69382 .60746 Mdot
.6701 .58185 Mdot
.5818 .31493 Mdot
.25287 .68608 Mdot
.58663 .30483 Mdot
.81127 .51306 Mdot
.6811 .60197 Mdot
.49353 .38125 Mdot
.40127 .3405 Mdot
.44749 .55602 Mdot
.32515 .46269 Mdot
.27164 .44597 Mdot
.46969 .57159 Mdot
.51327 .52804 Mdot
.39682 .39143 Mdot
.64435 .55321 Mdot
.52895 .60748 Mdot
.75318 .31801 Mdot
.56874 .4447 Mdot
.31712 .25618 Mdot
.56957 .63828 Mdot
.29348 .47084 Mdot
.49938 .75874 Mdot
.30043 .45121 Mdot
.57201 .34686 Mdot
.42308 .6486 Mdot
.41489 .64898 Mdot
.46698 .64077 Mdot
.49385 .61837 Mdot
.57118 .32942 Mdot
.45726 .57996 Mdot
.21778 .54763 Mdot
.66408 .483 Mdot
.48324 .37419 Mdot
.28835 .46975 Mdot
.59065 .29431 Mdot
.38849 .37135 Mdot
.67034 .45774 Mdot
.26796 .5189 Mdot
.43834 .58269 Mdot
.41722 .62293 Mdot
.66873 .4822 Mdot
.5259 .65418 Mdot
.48581 .56187 Mdot
.3942 .35413 Mdot
.46142 .45482 Mdot
.28611 .49884 Mdot
.3286 .45762 Mdot
.58992 .28794 Mdot
.65738 .58815 Mdot
.27786 .4895 Mdot
.42492 .35264 Mdot
.49991 .61408 Mdot
.50846 .61014 Mdot
.66992 .62 Mdot
.2511 .66541 Mdot
.33646 .45463 Mdot
.50981 .69003 Mdot
.65526 .56112 Mdot
.71262 .59386 Mdot
.45612 .63351 Mdot
.3972 .65249 Mdot
.67913 .54851 Mdot
.29559 .46006 Mdot
.59418 .29595 Mdot
.51085 .38616 Mdot
.58644 .2996 Mdot
.65621 .56497 Mdot
.42683 .56427 Mdot
.62809 .58127 Mdot
.42805 .65539 Mdot
.13588 .61897 Mdot
.4728 .59937 Mdot
.49924 .54103 Mdot
.36426 .51137 Mdot
.38819 .33726 Mdot
.38356 .33792 Mdot
.66296 .46303 Mdot
.6865 .56556 Mdot
.4354 .57425 Mdot
.32246 .45604 Mdot
.76048 .46958 Mdot
.62773 .53846 Mdot
.35821 .38521 Mdot
.37533 .40798 Mdot
.56175 .33163 Mdot
.43914 .58967 Mdot
.46058 .62237 Mdot
.38539 .39329 Mdot
.45035 .19889 Mdot
.65048 .5865 Mdot
.45113 .61634 Mdot
.48636 .60694 Mdot
.38944 .3596 Mdot
.54208 .27718 Mdot
.7133 .5811 Mdot
.48749 .60718 Mdot
.26508 .62526 Mdot
.57158 .29017 Mdot
.4837 .65695 Mdot
.44863 .57924 Mdot
.30048 .48419 Mdot
.25256 .50432 Mdot
.25364 .65263 Mdot
.5805 .34978 Mdot
.65484 .4484 Mdot
.41222 .63885 Mdot
.39542 .33978 Mdot
.48145 .67995 Mdot
.5886 .21676 Mdot
.65851 .48107 Mdot
.45681 .60664 Mdot
.50225 .59077 Mdot
.64382 .56834 Mdot
.44971 .60754 Mdot
.68491 .50669 Mdot
.37089 .35404 Mdot
.4573 .60597 Mdot
.68371 .72857 Mdot
.55974 .33031 Mdot
.46836 .57046 Mdot
.33047 .46566 Mdot
.37151 .48296 Mdot
.79039 .60296 Mdot
.35866 .343 Mdot
.28428 .47779 Mdot
.45641 .59357 Mdot
.38589 .32907 Mdot
.60322 .30492 Mdot
.54607 .54772 Mdot
.49972 .64968 Mdot
.58373 .29755 Mdot
.5658 .30129 Mdot
.30326 .47351 Mdot
.13247 .509 Mdot
.50339 .59269 Mdot
.43518 .62651 Mdot
.36609 .21294 Mdot
.64591 .54096 Mdot
.42876 .62494 Mdot
.43725 .59085 Mdot
.59518 .31836 Mdot
.32053 .71054 Mdot
.38484 .52829 Mdot
.46692 .20472 Mdot
.57629 .28967 Mdot
.39733 .40871 Mdot
.36732 .36645 Mdot
.28584 .47583 Mdot
.68432 .58715 Mdot
.2931 .49904 Mdot
.38175 .35431 Mdot
.4558 .6418 Mdot
.57067 .34229 Mdot
.58881 .667 Mdot
.57772 .28174 Mdot
.42144 .33374 Mdot
.70235 .56785 Mdot
.79703 .55492 Mdot
.47633 .15326 Mdot
.77728 .55728 Mdot
.5718 .35428 Mdot
.30202 .48066 Mdot
.65105 .32971 Mdot
.45761 .59652 Mdot
.45352 .78381 Mdot
.43213 .62831 Mdot
.52446 .69666 Mdot
.36544 .38398 Mdot
.67338 .46829 Mdot
.42602 .64963 Mdot
.33065 .53955 Mdot
.59131 .33702 Mdot
.55051 .31765 Mdot
.48712 .62698 Mdot
.57719 .30657 Mdot
.45948 .61842 Mdot
.38701 .36557 Mdot
.1365 .51108 Mdot
.43886 .59533 Mdot
.44616 .56919 Mdot
.59066 .26937 Mdot
.62798 .46247 Mdot
.43264 .36341 Mdot
.60484 .78731 Mdot
.75331 .31178 Mdot
.57251 .30824 Mdot
.46685 .5402 Mdot
.3991 .3848 Mdot
.66395 .44935 Mdot
.35621 .40381 Mdot
.44209 .63117 Mdot
.41913 .5992 Mdot
.47206 .64286 Mdot
.46229 .59802 Mdot
.47433 .77849 Mdot
.47371 .5597 Mdot
.584 .73587 Mdot
.41776 .62572 Mdot
.50229 .54332 Mdot
.5885 .31088 Mdot
.37001 .59775 Mdot
.35045 .48515 Mdot
.423 .59308 Mdot
.58187 .59532 Mdot
.59222 .29701 Mdot
.79128 .4805 Mdot
.57616 .32747 Mdot
.40915 .36549 Mdot
.55505 .34492 Mdot
.42594 .65581 Mdot
.67655 .57579 Mdot
.37392 .3708 Mdot
.74603 .56186 Mdot
.39136 .39873 Mdot
.4494 .60166 Mdot
.61576 .27186 Mdot
.39459 .33523 Mdot
.3542 .61903 Mdot
.67862 .57632 Mdot
.31727 .56081 Mdot
.65524 .53798 Mdot
.44418 .61058 Mdot
.43707 .61433 Mdot
.67344 .46139 Mdot
.58031 .34577 Mdot
.66119 .61296 Mdot
.18471 .44591 Mdot
.32498 .43884 Mdot
.67559 .59003 Mdot
.38623 .58973 Mdot
.56132 .43734 Mdot
.63701 .58097 Mdot
.34142 .56094 Mdot
.58767 .33887 Mdot
.6891 .59868 Mdot
.3953 .61876 Mdot
.45636 .73776 Mdot
.31993 .44777 Mdot
.37927 .33146 Mdot
.52744 .44302 Mdot
.36786 .36277 Mdot
.56259 .28219 Mdot
.36038 .3978 Mdot
.5855 .31696 Mdot
.66021 .50836 Mdot
.4454 .47581 Mdot
.55024 .29191 Mdot
.56316 .27462 Mdot
.38796 .34879 Mdot
.4857 .63238 Mdot
.46922 .41445 Mdot
.38899 .62958 Mdot
.44741 .56241 Mdot
.57452 .29254 Mdot
.69378 .58663 Mdot
.63501 .59784 Mdot
.5553 .5718 Mdot
.64014 .56278 Mdot
.37796 .3749 Mdot
.59326 .46328 Mdot
.41963 .76333 Mdot
.55865 .33327 Mdot
.37036 .3088 Mdot
.47805 .64633 Mdot
.38851 .34315 Mdot
.38101 .38 Mdot
.57452 .30081 Mdot
.49396 .7439 Mdot
.46666 .56678 Mdot
.63751 .54971 Mdot
.67631 .60699 Mdot
.63763 .58542 Mdot
.69735 .60399 Mdot
.26703 .70769 Mdot
.56453 .28633 Mdot
.69196 .57694 Mdot
.4954 .62701 Mdot
.41718 .61289 Mdot
.64595 .45324 Mdot
.29706 .46041 Mdot
.40447 .61562 Mdot
.41454 .58186 Mdot
.45585 .63265 Mdot
.38974 .33704 Mdot
.44493 .70934 Mdot
.65699 .47901 Mdot
.36668 .4027 Mdot
.35694 .38916 Mdot
.6629 .45538 Mdot
.67394 .51869 Mdot
.79392 .34879 Mdot
.46493 .64259 Mdot
.7114 .6361 Mdot
.39531 .3418 Mdot
.51955 .5106 Mdot
.53957 .60547 Mdot
.4857 .65028 Mdot
.47309 .3848 Mdot
.38272 .36935 Mdot
.68408 .62756 Mdot
.44203 .62775 Mdot
.66999 .46469 Mdot
.32895 .4545 Mdot
.38796 .61422 Mdot
.65752 .44658 Mdot
.66446 .59457 Mdot
.33831 .28006 Mdot
.62412 .56265 Mdot
.39517 .33421 Mdot
.469 .57265 Mdot
.37442 .87847 Mdot
.39771 .37209 Mdot
.75884 .44641 Mdot
.43559 .47691 Mdot
.44499 .59529 Mdot
.37116 .37496 Mdot
.69605 .61949 Mdot
.57124 .2905 Mdot
.53295 .42169 Mdot
.68726 .58728 Mdot
.67083 .4591 Mdot
.65191 .45103 Mdot
.39049 .35718 Mdot
.6638 .60845 Mdot
.46606 .58511 Mdot
.65757 .55684 Mdot
.55672 .33893 Mdot
.44661 .66605 Mdot
.76215 .3313 Mdot
.41187 .5626 Mdot
.66031 .55838 Mdot
.42586 .35729 Mdot
.27338 .4824 Mdot
.46015 .67185 Mdot
.79832 .43611 Mdot
.44305 .5895 Mdot
.56912 .33314 Mdot
.47734 .49799 Mdot
.5852 .67471 Mdot
.47455 .63437 Mdot
.47113 .64864 Mdot
.59732 .29352 Mdot
.46982 .63661 Mdot
.5063 .63124 Mdot
.52116 .34582 Mdot
.63836 .5752 Mdot
.46611 .60851 Mdot
.36472 .37071 Mdot
.6689 .65758 Mdot
.42222 .64441 Mdot
.69358 .50089 Mdot
.32004 .55048 Mdot
.45974 .48706 Mdot
.44093 .57347 Mdot
.24297 .51877 Mdot
.43692 .61752 Mdot
.49664 .64417 Mdot
.47709 .63887 Mdot
.58243 .79146 Mdot
.38399 .35052 Mdot
.35886 .3713 Mdot
.33092 .45429 Mdot
.33066 .54418 Mdot
.28994 .48717 Mdot
.59825 .29935 Mdot
.36747 .30551 Mdot
.66533 .48161 Mdot
.65528 .58594 Mdot
.42273 .64112 Mdot
.38453 .40069 Mdot
.45437 .62782 Mdot
.45294 .65935 Mdot
.37833 .366 Mdot
.38214 .37696 Mdot
.3526 .35743 Mdot
.30109 .44885 Mdot
.66458 .58335 Mdot
.43752 .64275 Mdot
.28494 .46002 Mdot
.45939 .58545 Mdot
.5694 .42127 Mdot
.66693 .58443 Mdot
.65555 .55745 Mdot
.62636 .5854 Mdot
.41532 .62517 Mdot
.4325 .66238 Mdot
.58652 .30419 Mdot
.66597 .61913 Mdot
.54795 .31975 Mdot
.37051 .37311 Mdot
.37978 .3423 Mdot
.44148 .63145 Mdot
.51465 .68339 Mdot
.29548 .46378 Mdot
.41061 .36904 Mdot
.64436 .46779 Mdot
.3325 .4571 Mdot
.47105 .60307 Mdot
.3688 .36753 Mdot
.33206 .46741 Mdot
.54731 .68283 Mdot
.72609 .28144 Mdot
.29069 .45287 Mdot
.48751 .62636 Mdot
.70542 .70943 Mdot
.26258 .6368 Mdot
.3153 .43977 Mdot
.57962 .32967 Mdot
.42573 .59832 Mdot
.47942 .17863 Mdot
.28106 .49874 Mdot
.25305 .66492 Mdot
.37683 .36137 Mdot
.55209 .642 Mdot
.38796 .60894 Mdot
.43548 .77798 Mdot
.27812 .49879 Mdot
.66531 .56083 Mdot
.68085 .60999 Mdot
.48117 .62646 Mdot
.3479 .44635 Mdot
.56306 .28372 Mdot
.41723 .35378 Mdot
.36394 .39303 Mdot
.65154 .60574 Mdot
.59652 .44704 Mdot
.36554 .37007 Mdot
.51818 .62275 Mdot
.33127 .41867 Mdot
.38097 .57279 Mdot
.30673 .7533 Mdot
.76513 .61946 Mdot
.45546 .57502 Mdot
.27348 .47787 Mdot
.59904 .32554 Mdot
.58117 .30373 Mdot
.58026 .31339 Mdot
.37661 .34373 Mdot
.55235 .47061 Mdot
.3651 .38954 Mdot
.70126 .45397 Mdot
.29966 .46656 Mdot
.31357 .58936 Mdot
.41162 .5909 Mdot
.4452 .59587 Mdot
.50509 .62101 Mdot
.46996 .64382 Mdot
.43876 .61761 Mdot
.56867 .29572 Mdot
.40864 .33741 Mdot
.39906 .22756 Mdot
.64878 .59918 Mdot
.65796 .38399 Mdot
.40276 .34106 Mdot
.64592 .4449 Mdot
.31662 .46828 Mdot
.25266 .53663 Mdot
.31617 .41277 Mdot
.41523 .3576 Mdot
.48682 .66369 Mdot
.69629 .59083 Mdot
.38742 .74789 Mdot
.427 .61511 Mdot
.41053 .37137 Mdot
.38591 .4118 Mdot
.50831 .74642 Mdot
.46503 .68931 Mdot
.34602 .42669 Mdot
.56115 .44079 Mdot
.26697 .48367 Mdot
.47094 .67935 Mdot
.53038 .51221 Mdot
.38374 .35443 Mdot
.40602 .35947 Mdot
.30499 .44395 Mdot
.39495 .67576 Mdot
.67843 .60037 Mdot
.67332 .47277 Mdot
.5849 .32602 Mdot
.42991 .60524 Mdot
.37442 .34629 Mdot
.71819 .61962 Mdot
.52943 .40498 Mdot
.56642 .32649 Mdot
.37027 .4059 Mdot
.42921 .59311 Mdot
.4775 .63013 Mdot
.29244 .4748 Mdot
.23649 .36352 Mdot
.3889 .62678 Mdot
.76042 .46715 Mdot
.5727 .47938 Mdot
.40215 .4798 Mdot
.46053 .62805 Mdot
.63068 .58297 Mdot
.66451 .45905 Mdot
.32264 .46957 Mdot
.45242 .58492 Mdot
.77599 .32249 Mdot
.61563 .57855 Mdot
.55854 .30607 Mdot
.66698 .46002 Mdot
.54342 .47348 Mdot
.44585 .58972 Mdot
.43266 .6284 Mdot
.49177 .6153 Mdot
.77666 .31882 Mdot
.36194 .37853 Mdot
.68297 .61619 Mdot
.29249 .4924 Mdot
.65557 .55533 Mdot
.35561 .36702 Mdot
.39627 .47807 Mdot
.48183 .6064 Mdot
.63131 .55773 Mdot
.6722 .56167 Mdot
.55889 .3306 Mdot
.59853 .32072 Mdot
.37636 .32773 Mdot
.45712 .59491 Mdot
.6692 .47858 Mdot
.69086 .59133 Mdot
.41896 .34883 Mdot
.29335 .47446 Mdot
.54116 .35095 Mdot
.41738 .62608 Mdot
.3888 .35474 Mdot
.47374 .58243 Mdot
.64429 .57553 Mdot
.41313 .35168 Mdot
.64952 .4425 Mdot
.30051 .45862 Mdot
.41523 .60957 Mdot
.36987 .24526 Mdot
.66954 .46109 Mdot
.42783 .66664 Mdot
.7447 .63097 Mdot
.34979 .47312 Mdot
.75317 .57846 Mdot
.37155 .38844 Mdot
.6658 .47652 Mdot
.69064 .6122 Mdot
.45217 .74124 Mdot
.40264 .36108 Mdot
.73918 .67746 Mdot
.48962 .39071 Mdot
.45422 .64365 Mdot
.67641 .59614 Mdot
.27649 .45985 Mdot
.76734 .46319 Mdot
.25425 .60466 Mdot
.45765 .6137 Mdot
.36773 .36182 Mdot
.32927 .4581 Mdot
.54909 .32153 Mdot
.69106 .49468 Mdot
.34142 .77212 Mdot
.36832 .40256 Mdot
.4256 .64004 Mdot
.69234 .59175 Mdot
.56842 .30308 Mdot
.76994 .66204 Mdot
.4252 .34802 Mdot
.36926 .3822 Mdot
.501 .63122 Mdot
.29562 .49254 Mdot
.48664 .1822 Mdot
.36002 .3715 Mdot
.39223 .33038 Mdot
.6261 .41473 Mdot
.32643 .44577 Mdot
.49285 .62416 Mdot
.55492 .57129 Mdot
.48965 .60553 Mdot
.71291 .42939 Mdot
.66693 .47697 Mdot
.64861 .59779 Mdot
.42396 .62734 Mdot
.38064 .2411 Mdot
.39645 .36751 Mdot
.56305 .44427 Mdot
.57143 .25167 Mdot
.59718 .32395 Mdot
.3723 .35272 Mdot
.44911 .62566 Mdot
.53853 .33299 Mdot
.2921 .46807 Mdot
.48716 .60692 Mdot
.43008 .65867 Mdot
.70195 .61619 Mdot
.56618 .34201 Mdot
.68081 .65604 Mdot
.55108 .33758 Mdot
.58975 .28683 Mdot
.71292 .59361 Mdot
.4813 .62523 Mdot
.41246 .36247 Mdot
.42169 .33123 Mdot
.46697 .58267 Mdot
.51898 .50954 Mdot
.67835 .599 Mdot
.34608 .36458 Mdot
.7536 .28639 Mdot
.50579 .59989 Mdot
.64035 .45599 Mdot
.55934 .63884 Mdot
.56049 .29366 Mdot
.45537 .64064 Mdot
.65023 .58013 Mdot
.40705 .33252 Mdot
.36602 .35752 Mdot
.42236 .67075 Mdot
.5745 .29979 Mdot
.32165 .48393 Mdot
.38243 .38297 Mdot
.53462 .40196 Mdot
.45431 .60514 Mdot
.68351 .46856 Mdot
.38517 .38505 Mdot
.80926 .59391 Mdot
.3869 .23587 Mdot
.64555 .60034 Mdot
.46633 .65719 Mdot
.69328 .56672 Mdot
.28922 .49213 Mdot
.35856 .40257 Mdot
.581 .2989 Mdot
.3853 .71566 Mdot
.19576 .39496 Mdot
.38485 .34469 Mdot
.66309 .59075 Mdot
.4283 .63879 Mdot
.5342 .61422 Mdot
.44246 .59234 Mdot
.32114 .70427 Mdot
.33418 .43204 Mdot
.54545 .29035 Mdot
.54932 .31271 Mdot
.45991 .65156 Mdot
.29438 .45501 Mdot
.39765 .32248 Mdot
.37875 .36398 Mdot
.13681 .56233 Mdot
.6566 .44564 Mdot
.3589 .42722 Mdot
.41565 .62464 Mdot
.4202 .35693 Mdot
.68635 .71109 Mdot
.54652 .31994 Mdot
.48927 .60274 Mdot
.39742 .40144 Mdot
.71115 .40289 Mdot
.55872 .43644 Mdot
.45686 .60858 Mdot
.50729 .68391 Mdot
.57787 .32852 Mdot
.65163 .32875 Mdot
.37463 .39288 Mdot
.46922 .59135 Mdot
.6002 .34099 Mdot
.62762 .48026 Mdot
.19079 .44 Mdot
.66489 .58309 Mdot
.42284 .37556 Mdot
.59534 .30492 Mdot
.46446 .70701 Mdot
.29123 .46521 Mdot
.40677 .32824 Mdot
.39881 .39863 Mdot
.45421 .66442 Mdot
.40541 .61675 Mdot
.48865 .69163 Mdot
.67035 .59775 Mdot
.59371 .32175 Mdot
.44405 .65278 Mdot
.58682 .42925 Mdot
.45974 .64545 Mdot
.5943 .31459 Mdot
.24592 .78038 Mdot
.43286 .67374 Mdot
.42263 .61569 Mdot
.34679 .60089 Mdot
.65098 .6085 Mdot
.64193 .56704 Mdot
.58382 .4514 Mdot
.41517 .62301 Mdot
.50277 .37106 Mdot
.66192 .58318 Mdot
.68071 .59293 Mdot
.50053 .37283 Mdot
.45237 .66801 Mdot
.61474 .29859 Mdot
.57153 .30309 Mdot
.59779 .32218 Mdot
.64507 .56712 Mdot
.44327 .55486 Mdot
.60291 .3108 Mdot
.48524 .77914 Mdot
.41309 .34929 Mdot
.53091 .51243 Mdot
.65966 .55691 Mdot
.50888 .40538 Mdot
.58052 .3449 Mdot
.82189 .62031 Mdot
.37783 .73203 Mdot
.4932 .60065 Mdot
.4789 .63108 Mdot
.2964 .48407 Mdot
.5213 .56882 Mdot
.65245 .44796 Mdot
.57968 .3068 Mdot
.47571 .21991 Mdot
.67072 .58172 Mdot
.42489 .60429 Mdot
.23601 .56152 Mdot
.77369 .61797 Mdot
.5523 .55777 Mdot
.68535 .58599 Mdot
.67527 .58084 Mdot
.39608 .39263 Mdot
.41461 .34962 Mdot
.48573 .61355 Mdot
.58416 .31195 Mdot
.6826 .60535 Mdot
.58313 .33619 Mdot
.38225 .35516 Mdot
.41144 .3505 Mdot
.64936 .47212 Mdot
.49243 .56891 Mdot
.37574 .35241 Mdot
.63262 .4136 Mdot
.58535 .42787 Mdot
.6945 .61864 Mdot
.45807 .16155 Mdot
.76637 .67572 Mdot
.34714 .61112 Mdot
.32854 .45362 Mdot
.64863 .49986 Mdot
.56536 .35091 Mdot
.46222 .65058 Mdot
.4374 .63515 Mdot
.6485 .46076 Mdot
.57611 .35 Mdot
.31167 .47762 Mdot
.57621 .3472 Mdot
.32228 .46237 Mdot
.36031 .35859 Mdot
.41999 .64341 Mdot
.46249 .59396 Mdot
.55408 .31205 Mdot
.40231 .38621 Mdot
.39317 .33482 Mdot
.31448 .44932 Mdot
.26414 .5392 Mdot
.38893 .35767 Mdot
.65973 .55676 Mdot
.65748 .66737 Mdot
.65058 .4519 Mdot
.44211 .62713 Mdot
.24194 .54182 Mdot
.48632 .76307 Mdot
.44927 .64474 Mdot
.66792 .46051 Mdot
.12534 .53289 Mdot
.42158 .6468 Mdot
.19832 .66057 Mdot
.65787 .47852 Mdot
.62855 .58339 Mdot
.39422 .38655 Mdot
.66339 .45054 Mdot
.44917 .71016 Mdot
.35826 .44752 Mdot
.48044 .58207 Mdot
.68321 .59798 Mdot
.63243 .56056 Mdot
.45215 .46849 Mdot
.7111 .42681 Mdot
.29638 .49405 Mdot
.31147 .4693 Mdot
.40038 .36024 Mdot
.53678 .37273 Mdot
.51368 .64738 Mdot
.31019 .47279 Mdot
.51597 .20627 Mdot
.48005 .64588 Mdot
.36284 .48291 Mdot
.47652 .39417 Mdot
.63509 .5912 Mdot
.36882 .60191 Mdot
.39932 .3642 Mdot
.66351 .59035 Mdot
.46312 .43604 Mdot
.49871 .61259 Mdot
.66863 .58375 Mdot
.59295 .32636 Mdot
.5096 .31307 Mdot
.64401 .55803 Mdot
.53251 .41841 Mdot
.56758 .3068 Mdot
.35073 .47527 Mdot
.29461 .62283 Mdot
.80947 .30987 Mdot
.5821 .30752 Mdot
.40409 .38092 Mdot
.37859 .34532 Mdot
.38895 .36199 Mdot
.68684 .59034 Mdot
.3866 .37721 Mdot
.65764 .60025 Mdot
.57644 .26693 Mdot
.25252 .52491 Mdot
.29741 .47583 Mdot
.33714 .38269 Mdot
.66656 .5655 Mdot
.70791 .45515 Mdot
.38394 .1886 Mdot
.49145 .62818 Mdot
.55409 .28915 Mdot
.27629 .46879 Mdot
.59493 .49904 Mdot
.29939 .4849 Mdot
.39752 .38598 Mdot
.53281 .51307 Mdot
.46061 .61765 Mdot
.75418 .61152 Mdot
.32898 .46351 Mdot
.68634 .58668 Mdot
.49112 .65693 Mdot
.40886 .3196 Mdot
.28435 .48221 Mdot
.32534 .45163 Mdot
.43896 .61937 Mdot
.63889 .5568 Mdot
.41385 .3597 Mdot
.55732 .35059 Mdot
.3069 .44014 Mdot
.51962 .67048 Mdot
.48162 .63354 Mdot
.46359 .67627 Mdot
.56682 .45646 Mdot
.49021 .17626 Mdot
.57039 .30966 Mdot
.25693 .63606 Mdot
.38412 .34189 Mdot
.25707 .6118 Mdot
.75783 .50189 Mdot
.31439 .40756 Mdot
.66562 .47881 Mdot
.66773 .47644 Mdot
.45113 .61148 Mdot
.52606 .17637 Mdot
.51121 .54249 Mdot
.6107 .3032 Mdot
.65278 .45444 Mdot
.39453 .33465 Mdot
.63593 .61051 Mdot
.37039 .63292 Mdot
.40235 .60332 Mdot
.58025 .34942 Mdot
.3831 .36009 Mdot
.58871 .21624 Mdot
.30046 .46723 Mdot
.5858 .49355 Mdot
.46485 .60087 Mdot
.4483 .61848 Mdot
.56217 .31922 Mdot
.58471 .30351 Mdot
.68701 .45301 Mdot
.48422 .47304 Mdot
.76997 .35065 Mdot
.58984 .27631 Mdot
.58496 .21183 Mdot
.65133 .63835 Mdot
.65047 .56716 Mdot
.64113 .45245 Mdot
.60083 .30006 Mdot
.42694 .62518 Mdot
.63038 .58765 Mdot
.5359 .5505 Mdot
.69225 .62759 Mdot
.36413 .48339 Mdot
.51399 .38764 Mdot
.46587 .59992 Mdot
.69745 .5941 Mdot
.66529 .58918 Mdot
.69956 .58216 Mdot
.66135 .45536 Mdot
.46066 .63044 Mdot
.48734 .63248 Mdot
.42264 .64873 Mdot
.53296 .61257 Mdot
.44974 .60702 Mdot
.75977 .49716 Mdot
.59865 .42669 Mdot
.24872 .39629 Mdot
.41692 .6317 Mdot
.59635 .31052 Mdot
.41925 .6381 Mdot
.29161 .45837 Mdot
.41214 .62406 Mdot
.36043 .48382 Mdot
.5752 .31651 Mdot
.41056 .70024 Mdot
.37027 .31673 Mdot
.47494 .60325 Mdot
.31153 .49154 Mdot
.49592 .17446 Mdot
.23766 .58156 Mdot
.62711 .41473 Mdot
.65859 .55704 Mdot
.36915 .33398 Mdot
.55005 .29647 Mdot
.41153 .35986 Mdot
.48487 .59751 Mdot
.64946 .47404 Mdot
.68354 .78542 Mdot
.49764 .41529 Mdot
.42541 .62532 Mdot
.50003 .57137 Mdot
.63212 .58168 Mdot
.3951 .37018 Mdot
.67828 .63612 Mdot
.49994 .63058 Mdot
.27964 .49005 Mdot
.27679 .47654 Mdot
.42133 .4665 Mdot
.52844 .24681 Mdot
.39782 .74637 Mdot
.56421 .31772 Mdot
.36826 .34914 Mdot
.27975 .49964 Mdot
.58603 .58041 Mdot
.56608 .28297 Mdot
.55964 .29447 Mdot
.56798 .34166 Mdot
.44665 .59933 Mdot
.64455 .46234 Mdot
.51879 .22921 Mdot
.6683 .45571 Mdot
.49981 .62168 Mdot
.39529 .39997 Mdot
.66628 .45177 Mdot
.29243 .48575 Mdot
.58734 .28666 Mdot
.39379 .33726 Mdot
.439 .61211 Mdot
.66031 .57741 Mdot
.24267 .61875 Mdot
.29369 .26699 Mdot
.34122 .38784 Mdot
.34111 .38224 Mdot
.62282 .57876 Mdot
.8083 .45041 Mdot
.53164 .32323 Mdot
.49082 .74779 Mdot
.2683 .46504 Mdot
.46944 .58367 Mdot
.15827 .53376 Mdot
.36645 .38978 Mdot
.37454 .37278 Mdot
.46198 .60635 Mdot
.42255 .34926 Mdot
.43138 .59644 Mdot
.37893 .39543 Mdot
.75094 .42277 Mdot
.40029 .60487 Mdot
.37695 .37409 Mdot
.50527 .65917 Mdot
.4564 .67304 Mdot
.63051 .57723 Mdot
.40869 .32987 Mdot
.49463 .60118 Mdot
.62644 .83093 Mdot
.55566 .32672 Mdot
.6602 .45427 Mdot
.34346 .34608 Mdot
.55961 .34687 Mdot
.66781 .60354 Mdot
.41308 .63771 Mdot
.29273 .46929 Mdot
.65813 .56527 Mdot
.39593 .31704 Mdot
.32696 .47114 Mdot
.5934 .46071 Mdot
.64814 .56622 Mdot
.64656 .45649 Mdot
.3039 .45714 Mdot
.48106 .58222 Mdot
.37504 .36854 Mdot
.35985 .23836 Mdot
.66588 .45425 Mdot
.45936 .6222 Mdot
.42659 .36911 Mdot
.57529 .34726 Mdot
.48186 .61439 Mdot
.3704 .3486 Mdot
.66477 .45717 Mdot
.43015 .66734 Mdot
.42849 .66821 Mdot
.38277 .66905 Mdot
.47265 .50629 Mdot
.29406 .47836 Mdot
.71098 .58324 Mdot
.49609 .62584 Mdot
.29748 .45294 Mdot
.40356 .26219 Mdot
.42417 .58148 Mdot
.67232 .5519 Mdot
.42378 .73002 Mdot
.418 .36045 Mdot
.5478 .31614 Mdot
.42333 .3361 Mdot
.33274 .46086 Mdot
.20464 .32192 Mdot
.64374 .44973 Mdot
.51246 .58358 Mdot
.5075 .62601 Mdot
.36564 .40809 Mdot
.66866 .58975 Mdot
.78007 .37126 Mdot
.41451 .61578 Mdot
.4191 .56204 Mdot
.43953 .62386 Mdot
.37458 .25116 Mdot
.68038 .59601 Mdot
.44009 .6261 Mdot
.52968 .65767 Mdot
.50907 .60987 Mdot
.3014 .49748 Mdot
.31491 .60354 Mdot
.43163 .64522 Mdot
.44963 .91508 Mdot
.66651 .48455 Mdot
.38038 .36661 Mdot
.54689 .42922 Mdot
.33784 .30712 Mdot
.27755 .73264 Mdot
.66499 .60054 Mdot
.58926 .61403 Mdot
.41273 .35897 Mdot
.22744 .60396 Mdot
.80553 .47067 Mdot
.46595 .6714 Mdot
.42457 .59771 Mdot
.39759 .38592 Mdot
.41753 .3467 Mdot
.66049 .48442 Mdot
.42267 .59036 Mdot
.42255 .55991 Mdot
.42221 .37046 Mdot
.436 .60859 Mdot
.54099 .7657 Mdot
.54051 .32661 Mdot
.64302 .56822 Mdot
.54934 .32252 Mdot
.55804 .29724 Mdot
.43259 .76415 Mdot
.57202 .48112 Mdot
.592 .3085 Mdot
.57869 .35527 Mdot
.33309 .51705 Mdot
.36827 .7012 Mdot
.29676 .49799 Mdot
.54273 .2528 Mdot
.39581 .35897 Mdot
.45999 .63201 Mdot
.68958 .5835 Mdot
.38499 .77931 Mdot
.69737 .28335 Mdot
.54948 .51849 Mdot
.49144 .63246 Mdot
.39459 .36604 Mdot
.66659 .45689 Mdot
.40124 .60105 Mdot
.26226 .62836 Mdot
.45414 .61574 Mdot
.41423 .34657 Mdot
.42189 .76554 Mdot
.67717 .50546 Mdot
.5886 .27686 Mdot
.64244 .61697 Mdot
.42054 .64079 Mdot
.64663 .58565 Mdot
.58965 .29944 Mdot
.29964 .45 Mdot
.3028 .47932 Mdot
.47065 .5998 Mdot
.44683 .47542 Mdot
.26212 .51397 Mdot
.46593 .67106 Mdot
.4518 .66533 Mdot
.66344 .47885 Mdot
.4502 .66545 Mdot
.46986 .59325 Mdot
.44629 .65097 Mdot
.42851 .58373 Mdot
.59494 .29007 Mdot
.74651 .60253 Mdot
.40873 .61371 Mdot
.5124 .60691 Mdot
.54756 .34803 Mdot
.41409 .67911 Mdot
.57812 .32535 Mdot
.72363 .29339 Mdot
.58724 .32137 Mdot
.30185 .47857 Mdot
.43125 .34888 Mdot
.61434 .62788 Mdot
.68119 .60623 Mdot
.59733 .30699 Mdot
.31541 .46032 Mdot
.5813 .30973 Mdot
.36276 .36249 Mdot
.41237 .18576 Mdot
.68162 .54524 Mdot
.57339 .41594 Mdot
.34478 .65549 Mdot
.68352 .46462 Mdot
.41748 .36963 Mdot
.65347 .606 Mdot
.68211 .50541 Mdot
.45593 .65263 Mdot
.28982 .4746 Mdot
.45074 .61238 Mdot
.58169 .28426 Mdot
.39449 .36345 Mdot
.60359 .26556 Mdot
.29397 .4794 Mdot
.24424 .29045 Mdot
.3857 .39971 Mdot
.51438 .59523 Mdot
.54413 .3427 Mdot
.43165 .17169 Mdot
.58367 .32304 Mdot
.25217 .52641 Mdot
.68578 .534 Mdot
.35732 .75747 Mdot
.67263 .57376 Mdot
.68517 .47659 Mdot
.83967 .44177 Mdot
.78707 .45606 Mdot
.65352 .57162 Mdot
.36884 .31699 Mdot
.44667 .60332 Mdot
.46453 .64553 Mdot
.52053 .62801 Mdot
.66504 .62936 Mdot
.4924 .6172 Mdot
.64985 .44874 Mdot
.57292 .46357 Mdot
.49057 .19397 Mdot
.37537 .33009 Mdot
.43497 .59385 Mdot
.57302 .29266 Mdot
.58364 .28252 Mdot
.66928 .45462 Mdot
.55918 .34239 Mdot
.44968 .67187 Mdot
.66827 .56726 Mdot
.46762 .41848 Mdot
.2881 .49048 Mdot
.7534 .47226 Mdot
.2621 .48125 Mdot
.31926 .42508 Mdot
.50745 .60348 Mdot
.41203 .35112 Mdot
.16967 .45526 Mdot
.46728 .64814 Mdot
.66087 .58503 Mdot
.50299 .63386 Mdot
.4402 .65006 Mdot
.42971 .64282 Mdot
.37034 .34712 Mdot
.54971 .42798 Mdot
.43329 .61018 Mdot
.59253 .30508 Mdot
.4983 .37607 Mdot
.4044 .60322 Mdot
.4841 .22836 Mdot
.36598 .48363 Mdot
.68314 .46907 Mdot
.69225 .61948 Mdot
.40486 .37428 Mdot
.67208 .58017 Mdot
.60862 .58795 Mdot
.66746 .60369 Mdot
.49478 .21889 Mdot
.4628 .74118 Mdot
.21682 .68789 Mdot
.66542 .72221 Mdot
.4292 .77383 Mdot
.6335 .55333 Mdot
.44614 .26292 Mdot
.64967 .57456 Mdot
.66596 .60243 Mdot
.16762 .67379 Mdot
.6809 .56105 Mdot
.44295 .63185 Mdot
.41356 .65154 Mdot
.7828 .58044 Mdot
.33355 .51893 Mdot
.41489 .62924 Mdot
.49044 .61615 Mdot
.27526 .48964 Mdot
.47264 .71849 Mdot
.67109 .48771 Mdot
.58099 .48595 Mdot
.63798 .45666 Mdot
.43945 .6186 Mdot
.47143 .60624 Mdot
.42657 .67398 Mdot
.84741 .45098 Mdot
.36075 .7746 Mdot
.62566 .57525 Mdot
.43649 .69695 Mdot
.63149 .43962 Mdot
.50688 .63364 Mdot
.50538 .62852 Mdot
.42574 .65452 Mdot
.41271 .36161 Mdot
.63421 .60857 Mdot
.39388 .60394 Mdot
.74336 .52057 Mdot
.46678 .60185 Mdot
.30229 .4321 Mdot
.26441 .50461 Mdot
.44884 .62658 Mdot
.67064 .553 Mdot
.48094 .64072 Mdot
.69586 .57664 Mdot
.64281 .57097 Mdot
.48701 .56626 Mdot
.52286 .2336 Mdot
.631 .60929 Mdot
.46225 .67298 Mdot
.40698 .38122 Mdot
.76078 .4591 Mdot
.45727 .62367 Mdot
.30114 .49141 Mdot
.45599 .64103 Mdot
.31505 .48984 Mdot
.43833 .66278 Mdot
.66976 .45772 Mdot
.57641 .6847 Mdot
.40483 .35847 Mdot
.29896 .44368 Mdot
.42135 .3571 Mdot
.35811 .6031 Mdot
.6611 .54593 Mdot
.6658 .49484 Mdot
.3538 .78251 Mdot
.662 .47903 Mdot
.25324 .64437 Mdot
.50236 .36052 Mdot
.55443 .3045 Mdot
.69627 .60684 Mdot
.41589 .75748 Mdot
.49989 .25521 Mdot
.35188 .37854 Mdot
.35602 .38818 Mdot
.1807 .46077 Mdot
.13579 .51312 Mdot
.42883 .61152 Mdot
.47212 .17635 Mdot
.58835 .72222 Mdot
.51686 .64841 Mdot
.4206 .6757 Mdot
.40442 .3948 Mdot
.41432 .6344 Mdot
.52516 .43336 Mdot
.38711 .34877 Mdot
.31021 .46287 Mdot
.64796 .59615 Mdot
.30969 .45213 Mdot
.67199 .25889 Mdot
.60154 .41045 Mdot
.37985 .34971 Mdot
.42094 .58677 Mdot
.43429 .59959 Mdot
.69051 .61486 Mdot
.74639 .67494 Mdot
.63895 .57353 Mdot
.29845 .49492 Mdot
.39804 .34854 Mdot
.41878 .78336 Mdot
.44443 .64128 Mdot
.67615 .56361 Mdot
.37603 .31524 Mdot
.47613 .63089 Mdot
.55733 .3047 Mdot
.49126 .63375 Mdot
.66966 .55862 Mdot
.44907 .66522 Mdot
.66827 .56911 Mdot
.38743 .39396 Mdot
.45216 .58893 Mdot
.47382 .60751 Mdot
.25407 .65312 Mdot
.31083 .47936 Mdot
.65606 .5461 Mdot
.52793 .43559 Mdot
.49005 .60604 Mdot
.2648 .62929 Mdot
.42042 .6445 Mdot
.43011 .53969 Mdot
.40403 .66171 Mdot
.64682 .45021 Mdot
.50837 .62316 Mdot
.45714 .62269 Mdot
.71086 .71427 Mdot
.69691 .70971 Mdot
.36457 .5801 Mdot
.59925 .31844 Mdot
.6638 .55306 Mdot
.37653 .34673 Mdot
.4036 .33228 Mdot
.39045 .3795 Mdot
.32036 .52889 Mdot
.49949 .69532 Mdot
.46363 .61768 Mdot
.55524 .27909 Mdot
.30893 .46981 Mdot
.68455 .57646 Mdot
.30277 .47373 Mdot
.57672 .49107 Mdot
.31536 .48461 Mdot
.64892 .44731 Mdot
.38883 .23381 Mdot
.51126 .76956 Mdot
.31831 .4781 Mdot
.63995 .57268 Mdot
.51667 .38044 Mdot
.47322 .58514 Mdot
.68502 .4004 Mdot
.27937 .49013 Mdot
.18336 .44408 Mdot
.42504 .66162 Mdot
.53498 .42578 Mdot
.57256 .32868 Mdot
.31051 .4524 Mdot
.56371 .34078 Mdot
.47693 .64278 Mdot
.75551 .58539 Mdot
.65959 .58937 Mdot
.54179 .32201 Mdot
.50763 .6185 Mdot
.3092 .45243 Mdot
.37711 .35364 Mdot
.38917 .73141 Mdot
.56244 .35635 Mdot
.23699 .6087 Mdot
.2542 .60528 Mdot
.39574 .34736 Mdot
.46762 .80269 Mdot
.57163 .33668 Mdot
.44872 .57591 Mdot
.54432 .65574 Mdot
.48687 .64033 Mdot
.38951 .33424 Mdot
.37493 .37584 Mdot
.78495 .52005 Mdot
.46705 .59932 Mdot
.40961 .64193 Mdot
.62957 .60181 Mdot
.38848 .34195 Mdot
.66999 .60439 Mdot
.68065 .61549 Mdot
.3994 .38571 Mdot
.64584 .60099 Mdot
.32874 .46228 Mdot
.56093 .49254 Mdot
.57457 .33524 Mdot
.5656 .30036 Mdot
.37658 .35068 Mdot
.36816 .34362 Mdot
.40993 .34706 Mdot
.4928 .6393 Mdot
.66689 .61001 Mdot
.47158 .65776 Mdot
.42199 .64003 Mdot
.71563 .57192 Mdot
.63913 .60505 Mdot
.47772 .65134 Mdot
.48236 .37996 Mdot
.30671 .49729 Mdot
.37859 .37438 Mdot
.58584 .33467 Mdot
.24607 .65375 Mdot
.54214 .3292 Mdot
.49189 .60966 Mdot
.71113 .4058 Mdot
.68621 .59054 Mdot
.29796 .48487 Mdot
.34813 .4606 Mdot
.29438 .48193 Mdot
.54168 .32125 Mdot
.67766 .61911 Mdot
.59214 .45608 Mdot
.46271 .59573 Mdot
.56728 .45952 Mdot
.27803 .65923 Mdot
.75662 .50937 Mdot
.59429 .32157 Mdot
.49204 .62682 Mdot
.65891 .47854 Mdot
.51059 .74728 Mdot
.46366 .61373 Mdot
.49013 .60286 Mdot
.29135 .3205 Mdot
.5105 .60478 Mdot
.70215 .61286 Mdot
.42415 .47632 Mdot
.44917 .58497 Mdot
.36306 .59321 Mdot
.132 .58444 Mdot
.42581 .66376 Mdot
.47382 .6052 Mdot
.44798 .63593 Mdot
.46613 .65057 Mdot
.68723 .55854 Mdot
.27447 .3172 Mdot
.58082 .29367 Mdot
.56005 .49151 Mdot
.57191 .33942 Mdot
.37104 .36597 Mdot
.50303 .43303 Mdot
.69481 .57111 Mdot
.29399 .48256 Mdot
.46009 .17351 Mdot
.53862 .50768 Mdot
.39939 .39112 Mdot
.29861 .73864 Mdot
.2821 .4897 Mdot
.46804 .58247 Mdot
.33141 .45431 Mdot
.40871 .39211 Mdot
.57615 .30007 Mdot
.48247 .66636 Mdot
.68524 .59817 Mdot
.64522 .55782 Mdot
.4947 .62986 Mdot
.75179 .46465 Mdot
.56246 .34859 Mdot
.2607 .43251 Mdot
.45176 .59873 Mdot
.48699 .60062 Mdot
.63638 .58158 Mdot
.39375 .36971 Mdot
.50191 .36366 Mdot
.31746 .46972 Mdot
.51374 .63649 Mdot
.47703 .64151 Mdot
.5739 .48795 Mdot
.59668 .29546 Mdot
.65706 .46211 Mdot
.45932 .59816 Mdot
.57504 .47325 Mdot
.4893 .60957 Mdot
.47936 .55267 Mdot
.41464 .37083 Mdot
.4452 .56154 Mdot
.42448 .59468 Mdot
.72733 .62046 Mdot
.56633 .33762 Mdot
.66586 .58603 Mdot
.66887 .52957 Mdot
.67051 .46592 Mdot
.55469 .32131 Mdot
.48115 .64885 Mdot
.55455 .29732 Mdot
.4473 .6474 Mdot
.43729 .61067 Mdot
.59434 .32205 Mdot
.66668 .60612 Mdot
.7677 .35863 Mdot
.74782 .60075 Mdot
.44883 .65764 Mdot
.4634 .63966 Mdot
.33755 .52038 Mdot
.40957 .80725 Mdot
.42296 .59491 Mdot
.66606 .61134 Mdot
.47804 .62913 Mdot
.56948 .29695 Mdot
.30188 .49342 Mdot
.65776 .57957 Mdot
.3639 .35235 Mdot
.37839 .39273 Mdot
.41685 .3061 Mdot
.64528 .44827 Mdot
.42538 .58952 Mdot
.71133 .58282 Mdot
.62904 .59624 Mdot
.59099 .51531 Mdot
.37965 .36747 Mdot
.31576 .4862 Mdot
.41531 .64618 Mdot
.4047 .7376 Mdot
.56808 .29077 Mdot
.45904 .91383 Mdot
.59344 .45208 Mdot
.26292 .49792 Mdot
.4549 .48601 Mdot
.6568 .47522 Mdot
.42061 .61727 Mdot
.29562 .45577 Mdot
.37671 .38737 Mdot
.46889 .64481 Mdot
.49815 .69031 Mdot
.49873 .26661 Mdot
.36043 .35326 Mdot
.54953 .30414 Mdot
.36681 .38376 Mdot
.31193 .49277 Mdot
.65053 .44762 Mdot
.63717 .56087 Mdot
.4529 .62154 Mdot
.37542 .58484 Mdot
.38773 .3652 Mdot
.67341 .4653 Mdot
.47652 .60296 Mdot
.65725 .55352 Mdot
.38297 .37679 Mdot
.43421 .62143 Mdot
.49645 .74647 Mdot
.6006 .61504 Mdot
.39666 .35392 Mdot
.49911 .65375 Mdot
.36776 .66164 Mdot
.35692 .36525 Mdot
.39242 .40287 Mdot
.49103 .61584 Mdot
.31203 .45414 Mdot
.44072 .58937 Mdot
.58432 .31827 Mdot
.54988 .42751 Mdot
.55561 .31193 Mdot
.26216 .63942 Mdot
.40992 .64952 Mdot
.54433 .55163 Mdot
.69517 .59735 Mdot
.33829 .44724 Mdot
.68686 .74353 Mdot
.47379 .59104 Mdot
.78406 .34863 Mdot
.51226 .40479 Mdot
.60614 .42171 Mdot
.72832 .27184 Mdot
.3206 .46986 Mdot
.58027 .31386 Mdot
.47782 .60649 Mdot
.52691 .33906 Mdot
.32379 .46106 Mdot
.26214 .64223 Mdot
.50885 .63475 Mdot
.68156 .59164 Mdot
.45313 .60107 Mdot
.66379 .5558 Mdot
.46857 .63465 Mdot
.44217 .71578 Mdot
.30393 .4353 Mdot
.25303 .52786 Mdot
.46406 .57991 Mdot
.46693 .16672 Mdot
.35448 .67723 Mdot
.29376 .49193 Mdot
.44735 .66014 Mdot
.65465 .46781 Mdot
.5813 .34556 Mdot
.42103 .204 Mdot
.41258 .35517 Mdot
.59201 .31249 Mdot
.64069 .59103 Mdot
.42854 .35406 Mdot
.67199 .47056 Mdot
.55085 .64314 Mdot
.30603 .45303 Mdot
.55552 .3256 Mdot
.4538 .6241 Mdot
.50273 .62231 Mdot
.3733 .25036 Mdot
.48859 .82631 Mdot
.67134 .61379 Mdot
.20606 .35023 Mdot
.71106 .58765 Mdot
.31236 .47314 Mdot
.41548 .36776 Mdot
.42658 .62914 Mdot
.46788 .6103 Mdot
.38035 .33807 Mdot
.64711 .60685 Mdot
.33352 .42029 Mdot
.36452 .76504 Mdot
.55726 .25866 Mdot
.30223 .5651 Mdot
.65473 .57949 Mdot
.29859 .563 Mdot
.276 .50195 Mdot
.57255 .22444 Mdot
.33328 .63954 Mdot
.55101 .31247 Mdot
.30595 .56773 Mdot
.68532 .5741 Mdot
.42679 .61235 Mdot
.64717 .45685 Mdot
.65869 .48088 Mdot
.64377 .58646 Mdot
.40052 .38273 Mdot
.29251 .46382 Mdot
.45688 .60355 Mdot
.58059 .55208 Mdot
.77648 .6577 Mdot
.37169 .34223 Mdot
.51092 .57824 Mdot
.5623 .34667 Mdot
.47479 .63391 Mdot
.27487 .48093 Mdot
.57609 .30496 Mdot
.65369 .44392 Mdot
.53933 .50061 Mdot
.41395 .64426 Mdot
.40564 .47923 Mdot
.56373 .32779 Mdot
.41532 .81101 Mdot
.47391 .60843 Mdot
.57114 .33687 Mdot
.38129 .57847 Mdot
.72033 .52121 Mdot
.47733 .40311 Mdot
.78785 .44722 Mdot
.36657 .33115 Mdot
.37443 .39155 Mdot
.58925 .83922 Mdot
.2688 .46386 Mdot
.5941 .30102 Mdot
.65642 .44841 Mdot
.32278 .61611 Mdot
.55694 .33685 Mdot
.47281 .67093 Mdot
.41913 .6443 Mdot
.42443 .76809 Mdot
.35202 .60264 Mdot
.66742 .48671 Mdot
.56318 .60333 Mdot
.46359 .66808 Mdot
.46244 .57195 Mdot
.48509 .61874 Mdot
.63114 .56237 Mdot
.54652 .32563 Mdot
.58989 .14091 Mdot
.55599 .29233 Mdot
.56737 .53638 Mdot
.39583 .35937 Mdot
.39657 .32517 Mdot
.4477 .62612 Mdot
.48606 .53165 Mdot
.51654 .16799 Mdot
.43868 .64213 Mdot
.34863 .46888 Mdot
.25268 .60374 Mdot
.41092 .58631 Mdot
.61695 .57435 Mdot
.42042 .56054 Mdot
.7 .56697 Mdot
.57532 .3035 Mdot
.3219 .46795 Mdot
.29819 .50174 Mdot
.57856 .32078 Mdot
.46799 .61779 Mdot
.3012 .5028 Mdot
.44553 .62055 Mdot
.4322 .60314 Mdot
.5818 .49206 Mdot
.27577 .46763 Mdot
.41013 .34637 Mdot
.30022 .48017 Mdot
.66918 .60029 Mdot
.18067 .70279 Mdot
.29713 .47084 Mdot
.37115 .70592 Mdot
.5205 .42196 Mdot
.30412 .56994 Mdot
.64309 .56003 Mdot
.29466 .49505 Mdot
.5472 .31892 Mdot
.60498 .44406 Mdot
.46249 .79903 Mdot
.5431 .32389 Mdot
.46475 .60846 Mdot
.69587 .57398 Mdot
.62398 .58257 Mdot
.59365 .28108 Mdot
.63224 .58692 Mdot
.49407 .57841 Mdot
.46408 .67289 Mdot
.59057 .29786 Mdot
.78937 .6038 Mdot
.54566 .32118 Mdot
.39769 .73248 Mdot
.42994 .6601 Mdot
.65949 .58234 Mdot
.44892 .53862 Mdot
.71333 .61322 Mdot
.64948 .47282 Mdot
.41152 .62439 Mdot
.28899 .47998 Mdot
.55203 .46985 Mdot
.39792 .35489 Mdot
.71497 .40487 Mdot
.65797 .55674 Mdot
.55293 .28766 Mdot
.63119 .57479 Mdot
.66523 .61379 Mdot
.54351 .31802 Mdot
.66665 .59526 Mdot
.46775 .60372 Mdot
.66011 .29691 Mdot
.65749 .55843 Mdot
.56549 .3208 Mdot
.28636 .47807 Mdot
.6492 .60334 Mdot
.33836 .4171 Mdot
.42837 .60313 Mdot
.41743 .37422 Mdot
.30451 .44232 Mdot
.69872 .58132 Mdot
.3014 .49283 Mdot
.38398 .36739 Mdot
.29131 .46332 Mdot
.53469 .29458 Mdot
.53734 .30302 Mdot
.54983 .52296 Mdot
.69968 .51782 Mdot
.69019 .58665 Mdot
.36139 .33467 Mdot
.41753 .61371 Mdot
.44518 .59735 Mdot
.33438 .46369 Mdot
.62307 .57354 Mdot
.74863 .454 Mdot
.52501 .55858 Mdot
.75235 .47395 Mdot
.60047 .30821 Mdot
.21332 .51459 Mdot
.59684 .44848 Mdot
.61631 .4118 Mdot
.46939 .68151 Mdot
.65503 .47355 Mdot
.4391 .6245 Mdot
.23702 .57969 Mdot
.29292 .49763 Mdot
.42436 .28734 Mdot
.51454 .64613 Mdot
.39744 .34268 Mdot
.45751 .63814 Mdot
.46127 .18444 Mdot
.41647 .55851 Mdot
.28247 .49462 Mdot
.54202 .34443 Mdot
.6813 .6062 Mdot
.2863 .49077 Mdot
.38238 .39419 Mdot
.33442 .55895 Mdot
.45718 .67689 Mdot
.45824 .67055 Mdot
.35954 .39415 Mdot
.67408 .60323 Mdot
.37255 .36771 Mdot
.57419 .3356 Mdot
.29959 .47195 Mdot
.46285 .65264 Mdot
.45303 .56441 Mdot
.3684 .40966 Mdot
.56617 .28598 Mdot
.3735 .33763 Mdot
.55824 .29423 Mdot
.65162 .46994 Mdot
.43067 .58516 Mdot
.37256 .40669 Mdot
.47251 .68378 Mdot
.69818 .69686 Mdot
.56802 .50491 Mdot
.64713 .76893 Mdot
.41048 .34621 Mdot
.33522 .53654 Mdot
.57462 .32017 Mdot
.5576 .33137 Mdot
.42719 .76162 Mdot
.51813 .17222 Mdot
.50249 .37112 Mdot
.39043 .20041 Mdot
.57538 .33488 Mdot
.5592 .32358 Mdot
.38034 .38714 Mdot
.65945 .5991 Mdot
.61247 .57059 Mdot
.41543 .38601 Mdot
.24228 .5423 Mdot
.68438 .57571 Mdot
.80835 .39201 Mdot
.36427 .39166 Mdot
.44633 .68072 Mdot
.65812 .48925 Mdot
.28061 .4927 Mdot
.23864 .57136 Mdot
.40585 .19437 Mdot
.43283 .62982 Mdot
.18609 .63326 Mdot
.40709 .36981 Mdot
.5373 .27302 Mdot
.58762 .22993 Mdot
.50133 .61435 Mdot
.45664 .63649 Mdot
.47359 .61952 Mdot
.31441 .44042 Mdot
.73612 .67265 Mdot
.42965 .62824 Mdot
.26163 .52648 Mdot
.39961 .60583 Mdot
.36091 .24219 Mdot
.30033 .47984 Mdot
.32018 .70888 Mdot
.37873 .32037 Mdot
.74005 .5075 Mdot
.50605 .60421 Mdot
.57749 .33141 Mdot
.49385 .31593 Mdot
.59511 .31334 Mdot
.54971 .20854 Mdot
.33096 .64137 Mdot
.63173 .5605 Mdot
.49199 .63358 Mdot
.36832 .39832 Mdot
.69716 .578 Mdot
.48782 .35224 Mdot
.15632 .66264 Mdot
.59879 .29226 Mdot
.13838 .43937 Mdot
.55102 .32482 Mdot
.66081 .48287 Mdot
.6395 .58373 Mdot
.3839 .53529 Mdot
.5671 .46642 Mdot
.66886 .60461 Mdot
.24293 .42141 Mdot
.6368 .54096 Mdot
.30893 .55067 Mdot
.66125 .5361 Mdot
.57136 .31695 Mdot
.53779 .30355 Mdot
.46444 .69695 Mdot
.4186 .6027 Mdot
.57076 .4498 Mdot
.43413 .68394 Mdot
.41488 .62257 Mdot
.38721 .34859 Mdot
.70201 .51392 Mdot
.5345 .36383 Mdot
.65013 .58178 Mdot
.57852 .28884 Mdot
.4554 .63764 Mdot
.44908 .65804 Mdot
.51315 .61577 Mdot
.23339 .61356 Mdot
.80524 .38437 Mdot
.43315 .61166 Mdot
.4317 .55708 Mdot
.40048 .38921 Mdot
.36881 .24905 Mdot
.23485 .32648 Mdot
.32799 .61762 Mdot
.47643 .60146 Mdot
.30812 .48036 Mdot
.27545 .49269 Mdot
.50742 .58785 Mdot
.54163 .54342 Mdot
.33712 .40727 Mdot
.45406 .62421 Mdot
.35462 .53848 Mdot
.35763 .40842 Mdot
.67237 .46057 Mdot
.38723 .36505 Mdot
.69744 .57521 Mdot
.66281 .48026 Mdot
.36784 .35654 Mdot
.42733 .52117 Mdot
.66956 .46458 Mdot
.72405 .51927 Mdot
.29744 .49536 Mdot
.48162 .61454 Mdot
.64109 .63167 Mdot
.37858 .34076 Mdot
.56038 .32871 Mdot
.66236 .57017 Mdot
.59514 .33218 Mdot
.37602 .23996 Mdot
.24331 .56321 Mdot
.64356 .45087 Mdot
.58128 .32778 Mdot
.46828 .46172 Mdot
.3067 .47999 Mdot
.55228 .33676 Mdot
.53565 .55154 Mdot
.40455 .61238 Mdot
.58134 .19181 Mdot
.47548 .66519 Mdot
.79182 .50542 Mdot
.56466 .33299 Mdot
.64239 .44248 Mdot
.45328 .61997 Mdot
.38547 .39901 Mdot
.40781 .67465 Mdot
.44535 .6192 Mdot
.36179 .37737 Mdot
.42864 .61265 Mdot
.28462 .46012 Mdot
.70295 .57644 Mdot
.5063 .41011 Mdot
.22067 .57095 Mdot
.28482 .47262 Mdot
.62756 .51706 Mdot
.4183 .59974 Mdot
.22397 .41672 Mdot
.67832 .59254 Mdot
.48423 .59959 Mdot
.26305 .68859 Mdot
.65018 .59307 Mdot
.67317 .57997 Mdot
.45811 .66439 Mdot
.54366 .32783 Mdot
.39157 .3357 Mdot
.30429 .48095 Mdot
.5349 .3712 Mdot
.43181 .62206 Mdot
.49227 .62441 Mdot
.28296 .4898 Mdot
.55613 .32016 Mdot
.46587 .6531 Mdot
.74286 .37439 Mdot
.58737 .51639 Mdot
.56105 .29442 Mdot
.40493 .60298 Mdot
.63689 .19331 Mdot
.61013 .57337 Mdot
.19264 .64854 Mdot
.26885 .46652 Mdot
.40574 .38001 Mdot
.52402 .60245 Mdot
.41913 .90379 Mdot
.29208 .4932 Mdot
.74665 .50252 Mdot
.43489 .60659 Mdot
.42512 .63394 Mdot
.64634 .55094 Mdot
.47771 .65489 Mdot
.67564 .55897 Mdot
.21272 .55588 Mdot
.46217 .15161 Mdot
.63161 .5817 Mdot
.67086 .55705 Mdot
.3693 .58147 Mdot
.23881 .63108 Mdot
.64647 .5962 Mdot
.45529 .67724 Mdot
.24821 .40417 Mdot
.51453 .67666 Mdot
.26477 .49336 Mdot
.34267 .45856 Mdot
.62213 .56535 Mdot
.5305 .81122 Mdot
.38228 .57063 Mdot
.40112 .69321 Mdot
.30026 .5136 Mdot
.58879 .3234 Mdot
.43195 .65231 Mdot
.64777 .4465 Mdot
.38155 .37962 Mdot
.41161 .56723 Mdot
.47704 .61342 Mdot
.68427 .56157 Mdot
.32735 .43913 Mdot
.55882 .33995 Mdot
.4871 .61321 Mdot
.39386 .41029 Mdot
.31449 .46303 Mdot
.65446 .56035 Mdot
.37793 .71232 Mdot
.28771 .50127 Mdot
.47077 .5674 Mdot
.41715 .62745 Mdot
.48189 .60528 Mdot
.51624 .659 Mdot
.57666 .32384 Mdot
.42374 .37367 Mdot
.52372 .60959 Mdot
.58447 .47426 Mdot
.54322 .46473 Mdot
.51915 .60103 Mdot
.66295 .61075 Mdot
.59879 .31525 Mdot
.66448 .46086 Mdot
.31368 .58983 Mdot
.42746 .6622 Mdot
.79591 .36454 Mdot
.33106 .75998 Mdot
.6665 .46777 Mdot
.66092 .5419 Mdot
.29733 .48354 Mdot
.44812 .66881 Mdot
.25398 .50435 Mdot
.47365 .66989 Mdot
.53654 .64972 Mdot
.40773 .37474 Mdot
.58574 .33152 Mdot
.59793 .53887 Mdot
.37999 .37988 Mdot
.67246 .58014 Mdot
.81481 .51857 Mdot
.62236 .55362 Mdot
.67351 .61516 Mdot
.52859 .22891 Mdot
.5816 .30186 Mdot
.43674 .91293 Mdot
.4059 .8085 Mdot
.42567 .66915 Mdot
.58266 .29761 Mdot
.64169 .58036 Mdot
.49266 .64479 Mdot
.68891 .5825 Mdot
.62723 .60583 Mdot
.41377 .63187 Mdot
.41626 .62071 Mdot
.25898 .53369 Mdot
.81733 .41644 Mdot
.29048 .47362 Mdot
.62959 .58555 Mdot
.45011 .76202 Mdot
.42586 .62635 Mdot
.45987 .59492 Mdot
.49956 .28588 Mdot
.29115 .49471 Mdot
.54101 .75727 Mdot
.44528 .59917 Mdot
.25324 .68087 Mdot
.41345 .62094 Mdot
.60967 .59759 Mdot
.60172 .28348 Mdot
.55925 .54707 Mdot
.39175 .33387 Mdot
.69738 .60707 Mdot
.32904 .47396 Mdot
.68732 .62135 Mdot
.46153 .74923 Mdot
.57646 .30159 Mdot
.67004 .55865 Mdot
.42539 .33431 Mdot
.5619 .31088 Mdot
.55085 .31054 Mdot
.48607 .36167 Mdot
.42814 .34502 Mdot
.30288 .44539 Mdot
.58321 .34187 Mdot
.49218 .74542 Mdot
.57107 .31383 Mdot
.46952 .75116 Mdot
.44249 .58645 Mdot
.2793 .53731 Mdot
.58536 .54116 Mdot
.48028 .69452 Mdot
.54756 .32994 Mdot
.30204 .46024 Mdot
.48547 .6449 Mdot
.63462 .5914 Mdot
.3002 .4652 Mdot
.52076 .34358 Mdot
.39344 .32268 Mdot
.62206 .58267 Mdot
.53919 .33245 Mdot
.68564 .56733 Mdot
.24694 .59244 Mdot
.31491 .41204 Mdot
.47201 .38723 Mdot
.56441 .45876 Mdot
.47244 .57908 Mdot
.36322 .59086 Mdot
.50551 .62292 Mdot
.46998 .61276 Mdot
.39618 .35451 Mdot
.3201 .52979 Mdot
.64994 .60397 Mdot
.79743 .63778 Mdot
.57681 .3295 Mdot
.42756 .47662 Mdot
.53856 .65113 Mdot
.45426 .64667 Mdot
.64773 .57255 Mdot
.64235 .61356 Mdot
.69666 .71048 Mdot
.38038 .33749 Mdot
.51089 .67875 Mdot
.50238 .59729 Mdot
.48472 .70724 Mdot
.54966 .31839 Mdot
.75404 .36612 Mdot
.3876 .32909 Mdot
.11534 .49686 Mdot
.37787 .37479 Mdot
.26136 .34739 Mdot
.66563 .5955 Mdot
.32153 .47876 Mdot
.45135 .59316 Mdot
.72516 .55741 Mdot
.67992 .552 Mdot
.34644 .38533 Mdot
.29289 .48515 Mdot
.76356 .36229 Mdot
.5894 .30579 Mdot
.45967 .58858 Mdot
.4121 .62993 Mdot
.46468 .65988 Mdot
.49856 .64241 Mdot
.58746 .29381 Mdot
.48384 .66452 Mdot
.56617 .35699 Mdot
.48478 .76267 Mdot
.26801 .69008 Mdot
.38242 .40574 Mdot
.3565 .25189 Mdot
.66483 .61318 Mdot
.55388 .67634 Mdot
.53402 .76514 Mdot
.56908 .50585 Mdot
.55159 .2773 Mdot
.43706 .5852 Mdot
.3982 .38376 Mdot
.47891 .17165 Mdot
.37863 .40499 Mdot
.52688 .12631 Mdot
.41232 .7561 Mdot
.79842 .46125 Mdot
.48991 .65232 Mdot
.39382 .40706 Mdot
.55802 .801 Mdot
.45202 .56363 Mdot
.31945 .49242 Mdot
.44857 .73533 Mdot
.77496 .56822 Mdot
.31149 .48959 Mdot
.42565 .60765 Mdot
.64895 .61135 Mdot
.46496 .60305 Mdot
.44164 .59276 Mdot
.44298 .64253 Mdot
.60615 .29624 Mdot
.40893 .6266 Mdot
.44122 .5895 Mdot
.47053 .81997 Mdot
.36395 .47958 Mdot
.396 .39372 Mdot
.66335 .75099 Mdot
.3088 .46944 Mdot
.69807 .58315 Mdot
.51724 .40651 Mdot
.58754 .31471 Mdot
.69236 .7116 Mdot
.48512 .6579 Mdot
.76258 .48948 Mdot
.54121 .29971 Mdot
.31778 .45833 Mdot
.66651 .45991 Mdot
.73421 .3127 Mdot
.41699 .35036 Mdot
.66097 .48541 Mdot
.39903 .35535 Mdot
.61666 .79577 Mdot
.66981 .55578 Mdot
.47094 .57765 Mdot
.56708 .34343 Mdot
.4029 .39576 Mdot
.25596 .51497 Mdot
.47912 .62307 Mdot
.40896 .34421 Mdot
.45999 .57534 Mdot
.54631 .4564 Mdot
.52736 .41124 Mdot
.41835 .37884 Mdot
.53627 .31342 Mdot
.56088 .30791 Mdot
.32983 .46816 Mdot
.69793 .59822 Mdot
.68104 .60013 Mdot
.57076 .30722 Mdot
.1389 .53902 Mdot
.43273 .62329 Mdot
.41935 .63195 Mdot
.58752 .46607 Mdot
.49771 .63924 Mdot
.34867 .53094 Mdot
.67475 .48192 Mdot
.69222 .59043 Mdot
.50056 .63166 Mdot
.46454 .65368 Mdot
.41677 .64646 Mdot
.24594 .56374 Mdot
.38847 .36704 Mdot
.46069 .66863 Mdot
.30049 .45412 Mdot
.6875 .45487 Mdot
.41858 .61047 Mdot
.45041 .56551 Mdot
.67986 .56255 Mdot
.18993 .44028 Mdot
.56487 .33116 Mdot
.38834 .34063 Mdot
.36027 .38849 Mdot
.28123 .63521 Mdot
.67055 .62846 Mdot
.67086 .48697 Mdot
.40326 .24831 Mdot
.65946 .45153 Mdot
.29745 .4904 Mdot
.48905 .38242 Mdot
.36688 .42058 Mdot
.37756 .39456 Mdot
.5358 .32952 Mdot
.49899 .62246 Mdot
.41413 .62297 Mdot
.74132 .49816 Mdot
.42776 .64055 Mdot
.28821 .48269 Mdot
.54654 .34389 Mdot
.67587 .56092 Mdot
.27626 .47675 Mdot
.55587 .33155 Mdot
.67328 .60423 Mdot
.406 .59305 Mdot
.51836 .62561 Mdot
.66686 .5719 Mdot
.6496 .56008 Mdot
.44801 .63129 Mdot
.54392 .83516 Mdot
.69055 .59554 Mdot
.6535 .56796 Mdot
.64852 .43161 Mdot
.41967 .3615 Mdot
.46439 .54258 Mdot
.58141 .29811 Mdot
.46524 .59969 Mdot
.38181 .40657 Mdot
.31496 .48279 Mdot
.6749 .57203 Mdot
.43123 .65524 Mdot
.43598 .61592 Mdot
.30645 .48186 Mdot
.26841 .48469 Mdot
.28376 .48092 Mdot
.60525 .30601 Mdot
.46407 .67229 Mdot
.64677 .5983 Mdot
.58949 .30442 Mdot
.27852 .49488 Mdot
.3297 .44898 Mdot
.46751 .81429 Mdot
.43567 .62979 Mdot
.30315 .50369 Mdot
.23442 .76736 Mdot
.3348 .56677 Mdot
.66737 .48067 Mdot
.37694 .41384 Mdot
.28427 .53421 Mdot
.31508 .43724 Mdot
.59539 .30685 Mdot
.37295 .48261 Mdot
.33492 .44211 Mdot
.42978 .64448 Mdot
.47773 .63464 Mdot
.4823 .67335 Mdot
.3064 .4647 Mdot
.24813 .58026 Mdot
.62829 .59118 Mdot
.59836 .69656 Mdot
.30865 .46938 Mdot
.42021 .3749 Mdot
.3737 .41086 Mdot
.37545 .3747 Mdot
.44573 .58282 Mdot
.69318 .7266 Mdot
.46267 .76089 Mdot
.55484 .74816 Mdot
.59125 .31052 Mdot
.63823 .61125 Mdot
.60485 .26589 Mdot
.67387 .57997 Mdot
.39261 .37724 Mdot
.31197 .46066 Mdot
.64074 .55319 Mdot
.55503 .30618 Mdot
.5574 .30833 Mdot
.37147 .33714 Mdot
.38289 .36476 Mdot
.37861 .35118 Mdot
.69781 .60483 Mdot
.66641 .5955 Mdot
.45638 .65515 Mdot
.67108 .56507 Mdot
.34095 .77337 Mdot
.26228 .48962 Mdot
.35429 .38615 Mdot
.56834 .32664 Mdot
.64801 .5667 Mdot
.48 .61233 Mdot
.3009 .3225 Mdot
.34721 .38236 Mdot
.28286 .47151 Mdot
.64235 .34331 Mdot
.40935 .15142 Mdot
.41026 .59403 Mdot
.57381 .28504 Mdot
.54233 .5473 Mdot
.47146 .62433 Mdot
.41339 .36526 Mdot
.34115 .74189 Mdot
.66797 .4568 Mdot
.42887 .59492 Mdot
.49195 .60232 Mdot
.5449 .32611 Mdot
.52103 .40834 Mdot
.43525 .64429 Mdot
.46226 .43753 Mdot
.59114 .28462 Mdot
.38663 .32928 Mdot
.61227 .84053 Mdot
.53303 .28143 Mdot
.23018 .51484 Mdot
.6694 .47355 Mdot
.4252 .64338 Mdot
.38969 .34937 Mdot
.28797 .46235 Mdot
.38769 .35571 Mdot
.65131 .54077 Mdot
.41793 .36012 Mdot
.48537 .6254 Mdot
.65081 .60064 Mdot
.55523 .32325 Mdot
.41315 .47976 Mdot
.50301 .8207 Mdot
.38607 .3984 Mdot
.67077 .45277 Mdot
.42014 .61258 Mdot
.52081 .73476 Mdot
.46097 .69748 Mdot
.42306 .59589 Mdot
.59538 .31879 Mdot
.64783 .57663 Mdot
.60008 .30948 Mdot
.42562 .57542 Mdot
.56605 .64208 Mdot
.57881 .32685 Mdot
.76236 .57404 Mdot
.28275 .49067 Mdot
.24181 .54399 Mdot
.45938 .61311 Mdot
.56852 .3429 Mdot
.4569 .6737 Mdot
.62883 .5849 Mdot
.53546 .48437 Mdot
.59635 .55412 Mdot
.56298 .34707 Mdot
.80154 .51171 Mdot
.52817 .43691 Mdot
.44951 .5445 Mdot
.57056 .33848 Mdot
.68666 .74213 Mdot
.65611 .46637 Mdot
.31645 .47341 Mdot
.27054 .48742 Mdot
.32114 .45075 Mdot
.42482 .63891 Mdot
.44656 .72303 Mdot
.32109 .44514 Mdot
.6038 .30601 Mdot
.30218 .44911 Mdot
.24211 .62148 Mdot
.75179 .46185 Mdot
.28156 .47998 Mdot
.45607 .61121 Mdot
.43659 .56784 Mdot
.36297 .48348 Mdot
.41466 .32914 Mdot
.76673 .33622 Mdot
.43548 .79768 Mdot
.42725 .63025 Mdot
.47878 .73126 Mdot
.6344 .54998 Mdot
.46725 .50824 Mdot
.57258 .60081 Mdot
.51787 .38471 Mdot
.65162 .5665 Mdot
.55472 .43354 Mdot
.69418 .59358 Mdot
.44254 .5746 Mdot
.43826 .60993 Mdot
.69219 .56053 Mdot
.69915 .39682 Mdot
.75162 .69548 Mdot
.75614 .47351 Mdot
.6712 .60934 Mdot
.5659 .33766 Mdot
.58545 .28433 Mdot
.5939 .32199 Mdot
.37885 .34296 Mdot
.65565 .55532 Mdot
.43797 .66904 Mdot
.38803 .39269 Mdot
.44957 .59526 Mdot
.56723 .30357 Mdot
.58727 .51867 Mdot
.67589 .5604 Mdot
.45618 .62272 Mdot
.47243 .79556 Mdot
.39964 .36305 Mdot
.30901 .47792 Mdot
.65226 .32809 Mdot
.36765 .41492 Mdot
.55197 .29619 Mdot
.62483 .60844 Mdot
.42227 .31479 Mdot
.2761 .31267 Mdot
.43575 .67661 Mdot
.4368 .67586 Mdot
.35474 .32027 Mdot
.49724 .80809 Mdot
.45145 .64417 Mdot
.38026 .39394 Mdot
.42062 .36431 Mdot
.44629 .67456 Mdot
.63797 .56236 Mdot
.326 .44216 Mdot
.33403 .46478 Mdot
.47869 .58645 Mdot
.56686 .44998 Mdot
.27048 .53392 Mdot
.47598 .65106 Mdot
.5246 .58495 Mdot
.4207 .32933 Mdot
.67165 .47091 Mdot
.57063 .48363 Mdot
.32883 .45901 Mdot
.43513 .60493 Mdot
.76457 .6648 Mdot
.66384 .55844 Mdot
.39766 .33667 Mdot
.56834 .29371 Mdot
.29854 .50303 Mdot
.35626 .35716 Mdot
.44569 .6745 Mdot
.4655 .65336 Mdot
.5586 .34177 Mdot
.61106 .60005 Mdot
.30772 .46216 Mdot
.39193 .392 Mdot
.32182 .47876 Mdot
.67123 .59602 Mdot
.65784 .5631 Mdot
.49997 .59367 Mdot
.47243 .69513 Mdot
.37048 .39448 Mdot
.51067 .64379 Mdot
.3718 .3769 Mdot
.37262 .24997 Mdot
.56965 .29027 Mdot
.49621 .60887 Mdot
.68985 .62798 Mdot
.56792 .30417 Mdot
.43498 .63562 Mdot
.35665 .31818 Mdot
.46922 .64663 Mdot
.40759 .39602 Mdot
.36288 .75671 Mdot
.32532 .46257 Mdot
.36799 .62011 Mdot
.39118 .54873 Mdot
.49771 .63806 Mdot
.42498 .34871 Mdot
.42627 .71913 Mdot
.58078 .32284 Mdot
.65684 .59206 Mdot
.17117 .45998 Mdot
.56702 .3184 Mdot
.45157 .60438 Mdot
.29845 .47031 Mdot
.68161 .60754 Mdot
.64542 .46275 Mdot
.58404 .44518 Mdot
.40882 .56875 Mdot
.39824 .6555 Mdot
.48505 .60878 Mdot
.39222 .19846 Mdot
.38239 .3513 Mdot
.64433 .57493 Mdot
.58223 .28566 Mdot
.58105 .30614 Mdot
.39417 .36971 Mdot
.78162 .54698 Mdot
.73537 .41598 Mdot
.28324 .81216 Mdot
.35396 .37129 Mdot
.30903 .44858 Mdot
.53443 .47237 Mdot
.37704 .38016 Mdot
.39001 .34425 Mdot
.39728 .32127 Mdot
.74292 .48394 Mdot
.6667 .60898 Mdot
.43381 .61628 Mdot
.68964 .62176 Mdot
.42433 .64226 Mdot
.23441 .50589 Mdot
.57331 .30491 Mdot
.65867 .59324 Mdot
.31642 .39458 Mdot
.3843 .57195 Mdot
.46506 .63115 Mdot
.23592 .48078 Mdot
.39402 .59899 Mdot
.31102 .57536 Mdot
.51402 .61523 Mdot
.39102 .36008 Mdot
.57662 .62131 Mdot
.49792 .57059 Mdot
.46377 .79136 Mdot
.55466 .31281 Mdot
.64212 .45619 Mdot
.40722 .58755 Mdot
.49353 .55642 Mdot
.68314 .60826 Mdot
.64285 .55157 Mdot
.32171 .44475 Mdot
.66104 .30947 Mdot
.55402 .31614 Mdot
.78125 .41493 Mdot
.41866 .60113 Mdot
.5405 .36791 Mdot
.3546 .75516 Mdot
.44279 .63609 Mdot
.48393 .37239 Mdot
.69365 .71096 Mdot
.45925 .64547 Mdot
.56841 .7393 Mdot
.57016 .32313 Mdot
.25747 .68364 Mdot
.51459 .62676 Mdot
.413 .36289 Mdot
.6597 .59793 Mdot
.62246 .58319 Mdot
.2815 .47039 Mdot
.36924 .79203 Mdot
.62339 .31474 Mdot
.66314 .59568 Mdot
.47665 .6198 Mdot
.56458 .32983 Mdot
.64471 .46442 Mdot
.39224 .57394 Mdot
.53184 .19317 Mdot
.67229 .56304 Mdot
.52374 .60578 Mdot
.76408 .48037 Mdot
.53998 .42116 Mdot
.81853 .40672 Mdot
.58742 .3345 Mdot
.32972 .45938 Mdot
.5012 .6759 Mdot
.39963 .25099 Mdot
.51665 .63086 Mdot
.23282 .50914 Mdot
.70177 .62892 Mdot
.30268 .49304 Mdot
.46763 .6229 Mdot
.43815 .64501 Mdot
.55843 .46927 Mdot
.27083 .4927 Mdot
.43517 .64462 Mdot
.5253 .62616 Mdot
.67841 .59865 Mdot
.6754 .48114 Mdot
.67843 .5639 Mdot
.4663 .60817 Mdot
.35913 .74121 Mdot
.63625 .55985 Mdot
.76725 .34637 Mdot
.28236 .44928 Mdot
.58764 .31585 Mdot
.5045 .57112 Mdot
.43383 .58832 Mdot
.74225 .2665 Mdot
.65135 .475 Mdot
.20786 .36062 Mdot
.39336 .40667 Mdot
.76349 .71808 Mdot
.36323 .41467 Mdot
.80214 .47836 Mdot
.43595 .46873 Mdot
.49638 .66074 Mdot
.346 .62659 Mdot
.55842 .74003 Mdot
.52947 .34157 Mdot
.53856 .70372 Mdot
.41861 .60284 Mdot
.42303 .6154 Mdot
.38053 .38929 Mdot
.78407 .52826 Mdot
.55693 .54984 Mdot
.56871 .47949 Mdot
.31829 .4605 Mdot
.66872 .58904 Mdot
.48272 .62841 Mdot
.66576 .37798 Mdot
.39821 .39628 Mdot
.3664 .70979 Mdot
.45568 .62072 Mdot
.56164 .5389 Mdot
.76258 .54121 Mdot
.55624 .32712 Mdot
.42126 .37489 Mdot
.42558 .36181 Mdot
.42344 .64682 Mdot
.58695 .29685 Mdot
.45676 .65117 Mdot
.52613 .44195 Mdot
.41835 .56454 Mdot
.30551 .48903 Mdot
.45908 .5937 Mdot
.34769 .59067 Mdot
.82579 .51338 Mdot
.45632 .55409 Mdot
.68941 .61066 Mdot
.37424 .35217 Mdot
.38606 .37175 Mdot
.68068 .6009 Mdot
.38645 .37242 Mdot
.59805 .70415 Mdot
.51378 .7121 Mdot
.2985 .49119 Mdot
.52802 .77451 Mdot
.32317 .46341 Mdot
.64204 .45406 Mdot
.43934 .631 Mdot
.45848 .2354 Mdot
.35372 .36939 Mdot
.24617 .65095 Mdot
.57294 .31046 Mdot
.6553 .47883 Mdot
.41791 .6547 Mdot
.31845 .50016 Mdot
.39472 .38083 Mdot
.51821 .28705 Mdot
.42044 .64905 Mdot
.64015 .60172 Mdot
.45355 .64627 Mdot
.39882 .63659 Mdot
.66445 .48429 Mdot
.48851 .61082 Mdot
.55603 .3317 Mdot
.65933 .55388 Mdot
.79515 .46978 Mdot
.37902 .34094 Mdot
.42701 .59954 Mdot
.47556 .62054 Mdot
.65067 .54677 Mdot
.41347 .65051 Mdot
.59344 .30398 Mdot
.49005 .91801 Mdot
.28577 .49171 Mdot
.67217 .46876 Mdot
.67195 .25888 Mdot
.48798 .63324 Mdot
.48144 .64641 Mdot
.52377 .37463 Mdot
.75472 .67034 Mdot
.57301 .33294 Mdot
.40061 .59634 Mdot
.40557 .38682 Mdot
.30516 .46126 Mdot
.58055 .34619 Mdot
.46931 .671 Mdot
.42346 .61825 Mdot
.29477 .49311 Mdot
.23806 .48683 Mdot
.33311 .41663 Mdot
.59303 .3135 Mdot
.49877 .71539 Mdot
.30599 .3211 Mdot
.43959 .62254 Mdot
.63321 .44279 Mdot
.65322 .57344 Mdot
.57634 .33595 Mdot
.74 .66646 Mdot
.44871 .57528 Mdot
.54578 .30956 Mdot
.55463 .32117 Mdot
.41149 .64509 Mdot
.66212 .6276 Mdot
.66506 .62242 Mdot
.6521 .572 Mdot
.27201 .68714 Mdot
.2697 .29233 Mdot
.37919 .34862 Mdot
.56455 .32499 Mdot
.37674 .40694 Mdot
.33566 .44787 Mdot
.54499 .46345 Mdot
.42038 .37284 Mdot
.66065 .61321 Mdot
.36965 .40086 Mdot
.46297 .6501 Mdot
.55895 .30238 Mdot
.36298 .38885 Mdot
.48942 .64711 Mdot
.52816 .59463 Mdot
.34902 .61074 Mdot
.32535 .44059 Mdot
.55616 .43378 Mdot
.45751 .60549 Mdot
.66674 .46185 Mdot
.44966 .62866 Mdot
.59177 .29865 Mdot
.37471 .48559 Mdot
.47376 .66454 Mdot
.35349 .37227 Mdot
.29017 .28987 Mdot
.42189 .34287 Mdot
.40562 .64571 Mdot
.46442 .60785 Mdot
.43658 .62386 Mdot
.41413 .62911 Mdot
.77078 .57782 Mdot
.55442 .35917 Mdot
.53263 .65521 Mdot
.35937 .35339 Mdot
.67329 .57565 Mdot
.62831 .56966 Mdot
.51726 .37743 Mdot
.65291 .47881 Mdot
.58357 .29663 Mdot
.43499 .62317 Mdot
.51588 .2914 Mdot
.60025 .4355 Mdot
.76081 .47509 Mdot
.41155 .30399 Mdot
.37524 .39342 Mdot
.68725 .61466 Mdot
.36394 .37579 Mdot
.46463 .67314 Mdot
.51979 .62969 Mdot
.79675 .46278 Mdot
.60686 .31494 Mdot
.30962 .46164 Mdot
.45268 .59504 Mdot
.2454 .53327 Mdot
.40037 .38925 Mdot
.42459 .33469 Mdot
.45363 .65266 Mdot
.61196 .5828 Mdot
.84602 .47402 Mdot
.57596 .29427 Mdot
.5157 .73673 Mdot
.58916 .59732 Mdot
.50674 .70033 Mdot
.57982 .31832 Mdot
.4768 .39407 Mdot
.40572 .32744 Mdot
.4154 .79956 Mdot
.66807 .57026 Mdot
.31106 .46311 Mdot
.51674 .60404 Mdot
.66145 .61341 Mdot
.36862 .40577 Mdot
.69596 .58273 Mdot
.46868 .57626 Mdot
.6015 .30048 Mdot
.38105 .37573 Mdot
.53786 .35173 Mdot
.68796 .55786 Mdot
.32398 .46272 Mdot
.2549 .64821 Mdot
.50471 .74709 Mdot
.69406 .71032 Mdot
.45905 .66888 Mdot
.49312 .24196 Mdot
.4356 .66751 Mdot
.66669 .61804 Mdot
.45906 .61272 Mdot
.36228 .59647 Mdot
.39497 .32526 Mdot
.5116 .58447 Mdot
.45239 .5906 Mdot
.45502 .78499 Mdot
.45391 .63586 Mdot
.42295 .66081 Mdot
.48956 .59744 Mdot
.60934 .60419 Mdot
.50943 .58373 Mdot
.64073 .6016 Mdot
.75178 .50178 Mdot
.39227 .34446 Mdot
.33503 .45742 Mdot
.31561 .48988 Mdot
.22817 .50632 Mdot
.24454 .54073 Mdot
.78026 .53702 Mdot
.68361 .57784 Mdot
.54806 .32393 Mdot
.45842 .65167 Mdot
.66997 .76084 Mdot
.33525 .70419 Mdot
.39518 .32729 Mdot
.3695 .397 Mdot
.51864 .61683 Mdot
.48566 .15672 Mdot
.51463 .59076 Mdot
.59243 .4543 Mdot
.4227 .63961 Mdot
.49006 .60327 Mdot
.42982 .34367 Mdot
.24461 .58817 Mdot
.4607 .6687 Mdot
.68364 .60767 Mdot
.31518 .46756 Mdot
.54745 .65076 Mdot
.32471 .70302 Mdot
.4043 .73919 Mdot
.51374 .54755 Mdot
.48714 .65905 Mdot
.40031 .38642 Mdot
.67458 .60989 Mdot
.58114 .47354 Mdot
.59256 .30816 Mdot
.57455 .44614 Mdot
.48267 .75894 Mdot
.60229 .24719 Mdot
.31396 .46278 Mdot
.34684 .35391 Mdot
.48621 .62517 Mdot
.37852 .34422 Mdot
.4289 .57683 Mdot
.60202 .42524 Mdot
.31015 .48775 Mdot
.70165 .5945 Mdot
.56514 .33735 Mdot
.64177 .60502 Mdot
.65051 .76606 Mdot
.34199 .71422 Mdot
.76292 .71958 Mdot
.41346 .34322 Mdot
.68339 .65541 Mdot
.64435 .58848 Mdot
.42471 .6566 Mdot
.27637 .80538 Mdot
.65489 .57805 Mdot
.64645 .60645 Mdot
.5164 .3887 Mdot
.26185 .63931 Mdot
.51917 .59289 Mdot
.69393 .58715 Mdot
.38215 .31736 Mdot
.29516 .4805 Mdot
.48457 .65056 Mdot
.46454 .57885 Mdot
.64385 .55159 Mdot
.39557 .37782 Mdot
.23687 .52836 Mdot
.38696 .36306 Mdot
.66194 .60755 Mdot
.40486 .35894 Mdot
.76396 .34994 Mdot
.40888 .38713 Mdot
.45389 .59007 Mdot
.436 .62256 Mdot
.48669 .20205 Mdot
.6579 .5631 Mdot
.48396 .64522 Mdot
.43073 .60994 Mdot
.64398 .59361 Mdot
.36834 .42075 Mdot
.72922 .66127 Mdot
.49355 .63803 Mdot
.43332 .61975 Mdot
.29568 .49698 Mdot
.54391 .4397 Mdot
.61864 .43127 Mdot
.48476 .64832 Mdot
.31622 .44981 Mdot
.69592 .60929 Mdot
.45051 .62983 Mdot
.24295 .58609 Mdot
.35943 .40867 Mdot
.4989 .64813 Mdot
.64438 .4556 Mdot
.44555 .64323 Mdot
.84242 .47552 Mdot
.42182 .60938 Mdot
.63931 .58128 Mdot
.65235 .59506 Mdot
.3447 .41119 Mdot
.67063 .57961 Mdot
.66505 .48132 Mdot
.56331 .30711 Mdot
.80831 .53358 Mdot
.66244 .48124 Mdot
.47371 .59373 Mdot
.40421 .80866 Mdot
.47167 .5809 Mdot
.44222 .56413 Mdot
.24051 .63963 Mdot
.66779 .4758 Mdot
.64735 .58036 Mdot
.69796 .39254 Mdot
.50026 .6545 Mdot
.58015 .29474 Mdot
.45147 .56399 Mdot
.49903 .64827 Mdot
.35411 .60718 Mdot
.51641 .70559 Mdot
.5477 .34705 Mdot
.45561 .54226 Mdot
.48366 .65098 Mdot
.75142 .67198 Mdot
.48276 .6199 Mdot
.28037 .47846 Mdot
.68729 .58453 Mdot
.3631 .36654 Mdot
.29693 .48853 Mdot
.48711 .62932 Mdot
.30721 .46648 Mdot
.38145 .34549 Mdot
.57756 .34341 Mdot
.46458 .59589 Mdot
.26463 .49522 Mdot
.3116 .45971 Mdot
.44334 .66072 Mdot
.66036 .59575 Mdot
.45257 .69738 Mdot
.44989 .63153 Mdot
.43256 .67098 Mdot
.68148 .5995 Mdot
.22907 .70647 Mdot
.41543 .63585 Mdot
.47835 .38891 Mdot
.70452 .57027 Mdot
.67193 .48261 Mdot
.37081 .38443 Mdot
.48576 .67778 Mdot
.58131 .30372 Mdot
.56747 .30719 Mdot
.37154 .33417 Mdot
.6589 .549 Mdot
.38376 .37664 Mdot
.41393 .55775 Mdot
.52144 .62458 Mdot
.517 .60597 Mdot
.17147 .45847 Mdot
.72644 .30264 Mdot
.64169 .56818 Mdot
.41657 .33307 Mdot
.57023 .45538 Mdot
.5712 .2971 Mdot
.41392 .32283 Mdot
.70614 .61335 Mdot
.67752 .55594 Mdot
.68346 .60058 Mdot
.31282 .4528 Mdot
.37888 .36919 Mdot
.71578 .59645 Mdot
.65466 .62003 Mdot
.44793 .65682 Mdot
.48251 .65264 Mdot
.63849 .54209 Mdot
.3664 .44084 Mdot
.31809 .47753 Mdot
.4095 .3771 Mdot
.82792 .35038 Mdot
.57598 .29398 Mdot
.45501 .78566 Mdot
.49034 .64558 Mdot
.10773 .59052 Mdot
.51315 .58989 Mdot
.47864 .61972 Mdot
.69739 .57497 Mdot
.28249 .50366 Mdot
.29815 .47795 Mdot
.64512 .58981 Mdot
.61758 .59737 Mdot
.29805 .45837 Mdot
.50144 .38006 Mdot
.81927 .55645 Mdot
.57827 .46612 Mdot
.63688 .58337 Mdot
.5114 .74894 Mdot
.57853 .34606 Mdot
.70764 .58604 Mdot
.54171 .34977 Mdot
.39158 .34313 Mdot
.38305 .4003 Mdot
.55698 .3422 Mdot
.41822 .65174 Mdot
.41386 .34845 Mdot
.42814 .55491 Mdot
.80045 .43092 Mdot
.57056 .21181 Mdot
.68302 .76922 Mdot
.41838 .59768 Mdot
.54803 .54472 Mdot
.71914 .49301 Mdot
.4918 .61583 Mdot
.44421 .53811 Mdot
.30826 .4632 Mdot
.70577 .57633 Mdot
.57672 .35026 Mdot
.78155 .34248 Mdot
.43824 .62286 Mdot
.6507 .60434 Mdot
.56381 .29874 Mdot
.75866 .34947 Mdot
.46259 .43622 Mdot
.44124 .65017 Mdot
.34094 .85559 Mdot
.68695 .55807 Mdot
.3633 .36617 Mdot
.50297 .78974 Mdot
.69694 .61495 Mdot
.30451 .30723 Mdot
.42225 .37871 Mdot
.60617 .50387 Mdot
.69138 .56783 Mdot
.3349 .42299 Mdot
.67324 .59259 Mdot
.28167 .46418 Mdot
.62295 .60743 Mdot
.40051 .36913 Mdot
.46293 .62746 Mdot
.39841 .36723 Mdot
.28022 .49327 Mdot
.40092 .3349 Mdot
.57616 .35036 Mdot
.66962 .4692 Mdot
.55996 .30545 Mdot
.54109 .46473 Mdot
.68438 .67662 Mdot
.58607 .33132 Mdot
.50682 .30004 Mdot
.45875 .6424 Mdot
.60953 .59677 Mdot
.36399 .35721 Mdot
.35462 .35216 Mdot
.56188 .43976 Mdot
.66723 .60505 Mdot
.40456 .36986 Mdot
.4953 .74833 Mdot
.13515 .55246 Mdot
.48567 .56261 Mdot
.283 .2785 Mdot
.64189 .59178 Mdot
.40039 .32441 Mdot
.58843 .4634 Mdot
.62396 .57173 Mdot
.36665 .39196 Mdot
.56719 .33964 Mdot
.58344 .30848 Mdot
.41099 .63936 Mdot
.59464 .28071 Mdot
.4257 .34874 Mdot
.76194 .66703 Mdot
.6872 .59035 Mdot
.7078 .2884 Mdot
.28416 .4743 Mdot
.38699 .34354 Mdot
.51537 .58765 Mdot
.71358 .61994 Mdot
.35938 .38962 Mdot
.52606 .1796 Mdot
.79079 .30569 Mdot
.40528 .36956 Mdot
.68726 .58317 Mdot
.67669 .57519 Mdot
.45679 .55539 Mdot
.56625 .46271 Mdot
.39872 .37765 Mdot
.45713 .23439 Mdot
.2511 .51784 Mdot
.6516 .47009 Mdot
.45269 .80982 Mdot
.46085 .66906 Mdot
.48961 .65729 Mdot
.59413 .30728 Mdot
.46584 .63306 Mdot
.62777 .60679 Mdot
.51439 .59521 Mdot
.59257 .28734 Mdot
.38623 .33006 Mdot
.43912 .62801 Mdot
.29895 .46234 Mdot
.59711 .31783 Mdot
.56375 .28519 Mdot
.40177 .35072 Mdot
.69054 .58771 Mdot
.68399 .39957 Mdot
.38543 .36436 Mdot
.46988 .66993 Mdot
.66348 .46907 Mdot
.51279 .61533 Mdot
.48908 .20832 Mdot
.62919 .59394 Mdot
.36392 .37467 Mdot
.66975 .54153 Mdot
.5609 .3223 Mdot
.37139 .32817 Mdot
.48752 .61889 Mdot
.37702 .39693 Mdot
.46868 .39722 Mdot
.24378 .38777 Mdot
.63673 .61307 Mdot
.35125 .47575 Mdot
.64488 .54989 Mdot
.65064 .46925 Mdot
.28512 .61464 Mdot
.31657 .47543 Mdot
.41671 .37086 Mdot
.76499 .33969 Mdot
.36312 .35359 Mdot
.4499 .63716 Mdot
.41844 .62718 Mdot
.37907 .38874 Mdot
.32262 .45587 Mdot
.21775 .54187 Mdot
.26337 .51474 Mdot
.66228 .55669 Mdot
.45271 .47394 Mdot
.84824 .39374 Mdot
.43598 .3337 Mdot
.54828 .32796 Mdot
.53088 .57166 Mdot
.47163 .64346 Mdot
.54408 .32086 Mdot
.57701 .28897 Mdot
.27734 .49387 Mdot
.38164 .34151 Mdot
.71055 .57862 Mdot
.56462 .3491 Mdot
.72404 .60528 Mdot
.23528 .55237 Mdot
.39221 .61136 Mdot
.46161 .7161 Mdot
.44928 .585 Mdot
.54086 .42158 Mdot
.59731 .29642 Mdot
.45059 .60791 Mdot
.5226 .63712 Mdot
.5791 .3323 Mdot
.27526 .48729 Mdot
.70814 .55091 Mdot
.40974 .36221 Mdot
.12089 .56624 Mdot
.46296 .59519 Mdot
.45796 .62944 Mdot
.59105 .31037 Mdot
.51359 .81022 Mdot
.63635 .57385 Mdot
.6908 .58396 Mdot
.38157 .35138 Mdot
.57665 .41626 Mdot
.41803 .65967 Mdot
.47914 .6078 Mdot
.41412 .35428 Mdot
.66628 .46239 Mdot
.61053 .82698 Mdot
.43866 .61504 Mdot
.57386 .32272 Mdot
.49327 .31891 Mdot
.59919 .30122 Mdot
.41253 .59012 Mdot
.4439 .63823 Mdot
.47266 .59686 Mdot
.40984 .61139 Mdot
.55407 .34339 Mdot
.48714 .61272 Mdot
.40876 .67466 Mdot
.64915 .57657 Mdot
.47712 .66459 Mdot
.25187 .52235 Mdot
.44124 .61751 Mdot
.29866 .4632 Mdot
.62338 .42339 Mdot
.42781 .60086 Mdot
.47873 .66416 Mdot
.25126 .51031 Mdot
.46962 .61966 Mdot
.55369 .30515 Mdot
.67115 .57018 Mdot
.56083 .32451 Mdot
.55055 .32273 Mdot
.36448 .39663 Mdot
.27405 .47378 Mdot
.51265 .64779 Mdot
.29999 .45607 Mdot
.43121 .55654 Mdot
.45197 .57442 Mdot
.54348 .4522 Mdot
.5927 .45303 Mdot
.33364 .43542 Mdot
.48371 .61356 Mdot
.38638 .34941 Mdot
.36487 .38004 Mdot
.37251 .48256 Mdot
.41805 .56229 Mdot
.57587 .34857 Mdot
.56861 .34271 Mdot
.34981 .53155 Mdot
.37622 .51235 Mdot
.30783 .45844 Mdot
.52662 .49826 Mdot
.45276 .57913 Mdot
.42776 .60751 Mdot
.43894 .56678 Mdot
.39355 .40501 Mdot
.67071 .46807 Mdot
.38345 .33244 Mdot
.65397 .4336 Mdot
.59374 .33385 Mdot
.41895 .59717 Mdot
.58906 .21635 Mdot
.64434 .55593 Mdot
.67047 .56901 Mdot
.59007 .28486 Mdot
.42271 .34388 Mdot
.41691 .56438 Mdot
.16948 .39912 Mdot
.62021 .5887 Mdot
.3338 .45914 Mdot
.46651 .60408 Mdot
.39739 .34795 Mdot
.66051 .55253 Mdot
.28176 .45894 Mdot
.42519 .59067 Mdot
.43219 .3402 Mdot
.45166 .61453 Mdot
.56878 .75405 Mdot
.65098 .58534 Mdot
.58884 .5144 Mdot
.61628 .56229 Mdot
.5463 .32715 Mdot
.56687 .33367 Mdot
.43647 .6363 Mdot
.14068 .47373 Mdot
.66543 .52839 Mdot
.5417 .32107 Mdot
.29604 .44996 Mdot
.67024 .46278 Mdot
.28806 .45464 Mdot
.37262 .37842 Mdot
.31601 .46594 Mdot
.35863 .38666 Mdot
.37406 .44026 Mdot
.67465 .53593 Mdot
.29141 .49093 Mdot
.51588 .815 Mdot
.51943 .63081 Mdot
.28086 .49691 Mdot
.5175 .61423 Mdot
.37032 .58275 Mdot
.41001 .34795 Mdot
.31258 .45456 Mdot
.4319 .6559 Mdot
.67092 .25083 Mdot
.55654 .33076 Mdot
.57423 .35005 Mdot
.51641 .63633 Mdot
.4009 .32282 Mdot
.62724 .609 Mdot
.50971 .41487 Mdot
.67397 .47803 Mdot
.47842 .60775 Mdot
.43328 .5843 Mdot
.67546 .5467 Mdot
.67184 .61495 Mdot
.43693 .63777 Mdot
.50358 .73715 Mdot
.48748 .62549 Mdot
.58429 .31176 Mdot
.65758 .55557 Mdot
.67423 .57088 Mdot
.42329 .3633 Mdot
.65731 .54934 Mdot
.50496 .68859 Mdot
.5641 .2721 Mdot
.49388 .58208 Mdot
.56321 .32017 Mdot
.38243 .45765 Mdot
.38427 .33746 Mdot
.76334 .33268 Mdot
.66275 .55044 Mdot
.50098 .631 Mdot
.62962 .5686 Mdot
.28428 .48135 Mdot
.65991 .56235 Mdot
.63705 .54639 Mdot
.41626 .61035 Mdot
.42928 .64559 Mdot
.66446 .46378 Mdot
.56552 .45298 Mdot
.65683 .58816 Mdot
.49431 .62956 Mdot
.50969 .61722 Mdot
.41743 .64038 Mdot
.52917 .43448 Mdot
.6995 .58608 Mdot
.43298 .76441 Mdot
.52427 .2083 Mdot
.66124 .59324 Mdot
.82234 .38208 Mdot
.65533 .44915 Mdot
.65085 .47671 Mdot
.54018 .30855 Mdot
.43366 .61716 Mdot
.38783 .37455 Mdot
.4939 .65425 Mdot
.41806 .561 Mdot
.4304 .59716 Mdot
.2961 .4941 Mdot
.4402 .67848 Mdot
.64976 .4558 Mdot
.39071 .36358 Mdot
.49151 .63326 Mdot
.43306 .62689 Mdot
.64266 .46376 Mdot
.62389 .5513 Mdot
.67682 .55603 Mdot
.63498 .47528 Mdot
.27693 .48609 Mdot
.59515 .31474 Mdot
.48406 .66306 Mdot
.38417 .35073 Mdot
.39306 .36934 Mdot
.64311 .60536 Mdot
.41209 .36643 Mdot
.59699 .30722 Mdot
.48099 .62324 Mdot
.54629 .3295 Mdot
.29569 .49406 Mdot
.68727 .58524 Mdot
.47228 .67018 Mdot
.44391 .65681 Mdot
.65213 .5948 Mdot
.45391 .64374 Mdot
.29971 .49517 Mdot
.39587 .401 Mdot
.6511 .56081 Mdot
.56393 .30764 Mdot
.42214 .369 Mdot
.46449 .6515 Mdot
.68064 .20519 Mdot
.46645 .63357 Mdot
.47486 .60163 Mdot
.80686 .51272 Mdot
.50403 .60346 Mdot
.37091 .3439 Mdot
.63109 .56388 Mdot
.40813 .59693 Mdot
.2497 .51444 Mdot
.28866 .41517 Mdot
.43452 .3545 Mdot
.46799 .60338 Mdot
.80902 .38201 Mdot
.50013 .63461 Mdot
.77934 .37131 Mdot
.54429 .45308 Mdot
.40689 .19666 Mdot
.45703 .71528 Mdot
.54207 .31899 Mdot
.66677 .46466 Mdot
.36854 .34337 Mdot
.59249 .78755 Mdot
.46008 .63916 Mdot
.70993 .70845 Mdot
.48567 .66317 Mdot
.58098 .31608 Mdot
.49769 .54763 Mdot
.41066 .37453 Mdot
.43909 .7993 Mdot
.43852 .67095 Mdot
.69531 .57217 Mdot
.3656 .32929 Mdot
.66632 .45682 Mdot
.42819 .65426 Mdot
.28866 .46511 Mdot
.3066 .41573 Mdot
.50032 .69032 Mdot
.56186 .31838 Mdot
.43188 .60688 Mdot
.49354 .55261 Mdot
.14361 .54146 Mdot
.64855 .5725 Mdot
.55381 .3339 Mdot
.46024 .5173 Mdot
.41782 .6319 Mdot
.67961 .55773 Mdot
.66987 .57211 Mdot
.28642 .46248 Mdot
.60432 .40899 Mdot
.26681 .42233 Mdot
.58842 .1959 Mdot
.68321 .73123 Mdot
.39915 .40243 Mdot
.74975 .57213 Mdot
.47308 .66221 Mdot
.34549 .71974 Mdot
.55124 .31713 Mdot
.46071 .62743 Mdot
.66615 .72153 Mdot
.65294 .56832 Mdot
.44744 .61221 Mdot
.31606 .48003 Mdot
.7103 .4477 Mdot
.45159 .73912 Mdot
.71545 .2457 Mdot
.39165 .31711 Mdot
.48574 .57022 Mdot
.48653 .69853 Mdot
.67181 .48208 Mdot
.41373 .58998 Mdot
.36612 .35091 Mdot
.49897 .24701 Mdot
.32727 .46186 Mdot
.64743 .55484 Mdot
.65886 .45015 Mdot
.49419 .65738 Mdot
.48798 .59229 Mdot
.33374 .4542 Mdot
.43137 .66191 Mdot
.48971 .78382 Mdot
.63935 .46221 Mdot
.40744 .38925 Mdot
.69585 .58646 Mdot
.44863 .58429 Mdot
.66925 .46405 Mdot
.41564 .61537 Mdot
.37449 .55689 Mdot
.46033 .60013 Mdot
.7941 .55559 Mdot
.66104 .59832 Mdot
.55887 .31493 Mdot
.44851 .68085 Mdot
.44719 .6211 Mdot
.30661 .32387 Mdot
.41439 .56401 Mdot
.42163 .61183 Mdot
.65971 .61468 Mdot
.63842 .55922 Mdot
.65665 .60854 Mdot
.41723 .37529 Mdot
.57505 .47299 Mdot
.57628 .3123 Mdot
.42917 .56504 Mdot
.57198 .34834 Mdot
.41408 .69309 Mdot
.32768 .44927 Mdot
.74531 .30242 Mdot
.47834 .63275 Mdot
.67543 .60495 Mdot
.7685 .62373 Mdot
.69516 .61096 Mdot
.61705 .31211 Mdot
.55406 .31457 Mdot
.65625 .5811 Mdot
.47122 .61571 Mdot
.56751 .47993 Mdot
.67208 .21097 Mdot
.56968 .29813 Mdot
.45777 .56756 Mdot
.38981 .31632 Mdot
.35571 .35431 Mdot
.83975 .43696 Mdot
.54858 .31391 Mdot
.71691 .49248 Mdot
.49682 .63462 Mdot
.64559 .55338 Mdot
.58939 .32957 Mdot
.55442 .30165 Mdot
.41469 .36013 Mdot
.44455 .65184 Mdot
.44768 .61904 Mdot
.64476 .45296 Mdot
.57211 .34591 Mdot
.38233 .60461 Mdot
.44349 .6482 Mdot
.79971 .47426 Mdot
.70887 .61031 Mdot
.23603 .71799 Mdot
.42296 .55073 Mdot
.67379 .71554 Mdot
.42296 .45335 Mdot
.64546 .56221 Mdot
.42685 .66458 Mdot
.42782 .56417 Mdot
.40984 .39252 Mdot
.47768 .62682 Mdot
.40952 .33201 Mdot
.54666 .32048 Mdot
.75387 .306 Mdot
.50629 .31889 Mdot
.55512 .27468 Mdot
.46051 .63436 Mdot
.4506 .73615 Mdot
.29012 .48743 Mdot
.6022 .32998 Mdot
.63709 .59335 Mdot
.45652 .5823 Mdot
.39958 .40415 Mdot
.41396 .37852 Mdot
.66308 .57134 Mdot
.7405 .51497 Mdot
.7686 .34757 Mdot
.41069 .60605 Mdot
.37104 .38163 Mdot
.54042 .26447 Mdot
.54801 .68637 Mdot
.54858 .29585 Mdot
.32753 .4648 Mdot
.37481 .34059 Mdot
.60322 .29161 Mdot
.36701 .58708 Mdot
.66408 .58053 Mdot
.67824 .54994 Mdot
.33516 .3019 Mdot
.3993 .37402 Mdot
.303 .48329 Mdot
.40213 .47762 Mdot
.40863 .47902 Mdot
.31202 .48607 Mdot
.39513 .32704 Mdot
.64238 .56022 Mdot
.65462 .60578 Mdot
.67228 .57193 Mdot
.46414 .7916 Mdot
.62486 .58642 Mdot
.29573 .73587 Mdot
.43608 .58044 Mdot
.52412 .73263 Mdot
.49703 .62025 Mdot
.55637 .3495 Mdot
.65141 .58709 Mdot
.54919 .46291 Mdot
.47851 .59244 Mdot
.69679 .23351 Mdot
.45878 .60473 Mdot
.487 .35664 Mdot
.4327 .61844 Mdot
.51863 .77952 Mdot
.70574 .57299 Mdot
.4864 .61511 Mdot
.54977 .28391 Mdot
.30331 .46461 Mdot
.65045 .53131 Mdot
.42364 .61002 Mdot
.76535 .48639 Mdot
.51714 .61557 Mdot
.80249 .3985 Mdot
.27361 .31836 Mdot
.32048 .4876 Mdot
.50939 .59898 Mdot
.35672 .39314 Mdot
.52806 .55595 Mdot
.52603 .74287 Mdot
.5689 .2986 Mdot
.46753 .74273 Mdot
.41689 .36156 Mdot
.44167 .53862 Mdot
.39451 .63586 Mdot
.32584 .45639 Mdot
.68237 .53182 Mdot
.58535 .31413 Mdot
.46248 .63992 Mdot
.42425 .66083 Mdot
.48974 .18316 Mdot
.52128 .7522 Mdot
.38821 .63649 Mdot
.33046 .445 Mdot
.46755 .74883 Mdot
.43252 .59857 Mdot
.4342 .35481 Mdot
.62879 .5642 Mdot
.53172 .63584 Mdot
.42429 .76858 Mdot
.49225 .62895 Mdot
.65699 .57722 Mdot
.6631 .54981 Mdot
.78721 .62181 Mdot
.32515 .44953 Mdot
.45939 .59999 Mdot
.32261 .30255 Mdot
.47006 .67021 Mdot
.57995 .31147 Mdot
.41622 .58482 Mdot
.39573 .34011 Mdot
.59187 .46574 Mdot
.41837 .37325 Mdot
.42193 .64712 Mdot
.67847 .59209 Mdot
.58864 .31439 Mdot
.39383 .24066 Mdot
.54716 .38916 Mdot
.29183 .73149 Mdot
.30366 .41843 Mdot
.29878 .45989 Mdot
.278 .46478 Mdot
.6046 .27131 Mdot
.47065 .6083 Mdot
.5312 .4134 Mdot
.45836 .56037 Mdot
.42779 .61845 Mdot
.45051 .59337 Mdot
.52025 .32893 Mdot
.55523 .31389 Mdot
.40374 .3631 Mdot
.43837 .63849 Mdot
.49464 .62876 Mdot
.66513 .59112 Mdot
.31181 .45935 Mdot
.39547 .39957 Mdot
.27895 .48647 Mdot
.39038 .35838 Mdot
.84466 .46484 Mdot
.42312 .5774 Mdot
.30177 .4659 Mdot
.60062 .30353 Mdot
.66893 .6101 Mdot
.64564 .46781 Mdot
.37348 .37808 Mdot
.40886 .37576 Mdot
.48845 .61324 Mdot
.68707 .57312 Mdot
.6836 .56371 Mdot
.29893 .45826 Mdot
.57393 .34154 Mdot
.40617 .63205 Mdot
.43457 .64663 Mdot
.36371 .24312 Mdot
.41225 .38831 Mdot
.48235 .75058 Mdot
.77975 .57871 Mdot
.47297 .609 Mdot
.68569 .56402 Mdot
.44385 .6279 Mdot
.55374 .23936 Mdot
.66714 .61302 Mdot
.50098 .60882 Mdot
.35868 .62292 Mdot
.39239 .4051 Mdot
.78601 .66387 Mdot
.49804 .66254 Mdot
.55276 .37541 Mdot
.45492 .66403 Mdot
.80668 .67717 Mdot
.7602 .63322 Mdot
.48552 .664 Mdot
.41077 .61174 Mdot
.58661 .18506 Mdot
.49678 .6408 Mdot
.64834 .45274 Mdot
.41137 .56256 Mdot
.68049 .55782 Mdot
.45923 .42984 Mdot
.55246 .43063 Mdot
.31001 .44782 Mdot
.38133 .35059 Mdot
.25835 .61427 Mdot
.27584 .47617 Mdot
.63948 .58452 Mdot
.48063 .58888 Mdot
.73032 .62851 Mdot
.35358 .40627 Mdot
.39886 .62838 Mdot
.58062 .31278 Mdot
.55375 .43071 Mdot
.38317 .33406 Mdot
.56205 .30751 Mdot
.50544 .62691 Mdot
.20297 .38816 Mdot
.58942 .37421 Mdot
.80443 .61173 Mdot
.59279 .31275 Mdot
.5565 .32643 Mdot
.57604 .48967 Mdot
.30935 .44801 Mdot
.4601 .19626 Mdot
.5456 .64423 Mdot
.57453 .29489 Mdot
.31528 .58954 Mdot
.42911 .35673 Mdot
.59562 .42455 Mdot
.70778 .5815 Mdot
.42094 .578 Mdot
.46603 .61608 Mdot
.57815 .33615 Mdot
.74724 .59761 Mdot
.4187 .50742 Mdot
.56239 .30247 Mdot
.47937 .69887 Mdot
.60063 .42124 Mdot
.66619 .47063 Mdot
.6491 .44771 Mdot
.30435 .44649 Mdot
.23476 .4245 Mdot
.66758 .60107 Mdot
.32587 .47651 Mdot
.61304 .52548 Mdot
.45189 .6001 Mdot
.57061 .34686 Mdot
.64148 .45049 Mdot
.56858 .30851 Mdot
.29631 .47472 Mdot
.33111 .45391 Mdot
.64893 .57576 Mdot
.63533 .57403 Mdot
.57243 .6363 Mdot
.33124 .54404 Mdot
.49043 .65333 Mdot
.72735 .66757 Mdot
.66259 .61238 Mdot
.55593 .80413 Mdot
.30546 .45197 Mdot
.3198 .46074 Mdot
.57223 .71101 Mdot
.45631 .65437 Mdot
.49098 .33152 Mdot
.42699 .60266 Mdot
.29712 .62175 Mdot
.50453 .64784 Mdot
.41381 .3611 Mdot
.45126 .67176 Mdot
.67365 .38533 Mdot
.48645 .63885 Mdot
.44177 .59171 Mdot
.37624 .37315 Mdot
.43242 .67824 Mdot
.40002 .34025 Mdot
.41498 .63458 Mdot
.27891 .50466 Mdot
.38401 .35109 Mdot
.27547 .51685 Mdot
.48015 .396 Mdot
.66062 .45842 Mdot
.29135 .45353 Mdot
.2894 .46575 Mdot
.23765 .51855 Mdot
.63167 .58313 Mdot
.36539 .57781 Mdot
.46774 .60785 Mdot
.42112 .32977 Mdot
.59462 .32543 Mdot
.4922 .62745 Mdot
.51228 .58984 Mdot
.49971 .66219 Mdot
.65218 .5765 Mdot
.399 .32601 Mdot
.30393 .47018 Mdot
.36622 .38415 Mdot
.27165 .50718 Mdot
.35727 .36296 Mdot
.52185 .57821 Mdot
.40829 .55997 Mdot
.41699 .68341 Mdot
.69753 .70055 Mdot
.40268 .80075 Mdot
.6654 .57674 Mdot
.65785 .4691 Mdot
.32708 .44811 Mdot
.44708 .47634 Mdot
.67666 .60192 Mdot
.40548 .37834 Mdot
.45192 .61452 Mdot
.47117 .70108 Mdot
.52191 .684 Mdot
.71473 .61211 Mdot
.31989 .53087 Mdot
.37327 .36069 Mdot
.65987 .47798 Mdot
.58152 .45922 Mdot
.60342 .60633 Mdot
.54439 .46604 Mdot
.44478 .62455 Mdot
.29331 .4605 Mdot
.66035 .55255 Mdot
.47034 .20973 Mdot
.57176 .33848 Mdot
.56615 .45808 Mdot
.46318 .63313 Mdot
.7251 .52558 Mdot
.67847 .59151 Mdot
.32366 .46528 Mdot
.57861 .33544 Mdot
.31736 .44863 Mdot
.66458 .45157 Mdot
.62474 .44912 Mdot
.43175 .65919 Mdot
.42121 .61062 Mdot
.59296 .33437 Mdot
.66978 .60041 Mdot
.33437 .41056 Mdot
.50689 .1869 Mdot
.37468 .38347 Mdot
.54658 .40563 Mdot
.65789 .55416 Mdot
.70163 .51414 Mdot
.37771 .39514 Mdot
.6039 .30199 Mdot
.53385 .41741 Mdot
.5878 .28492 Mdot
.43877 .59438 Mdot
.68116 .57285 Mdot
.54846 .31319 Mdot
.37615 .25074 Mdot
.82409 .45429 Mdot
.71269 .56141 Mdot
.43855 .64207 Mdot
.74551 .30052 Mdot
.75488 .45247 Mdot
.72854 .56351 Mdot
.55924 .34776 Mdot
.44222 .63461 Mdot
.41212 .60275 Mdot
.4408 .6716 Mdot
.55945 .33478 Mdot
.54891 .38137 Mdot
.40525 .3841 Mdot
.44792 .60674 Mdot
.28412 .47531 Mdot
.40059 .34405 Mdot
.35288 .38438 Mdot
.36726 .34524 Mdot
.66588 .61367 Mdot
.45581 .57726 Mdot
.58442 .54039 Mdot
.82256 .62037 Mdot
.5564 .32059 Mdot
.66025 .45825 Mdot
.46757 .59585 Mdot
.25076 .67664 Mdot
.662 .60954 Mdot
.37841 .38427 Mdot
.45866 .62819 Mdot
.28674 .31547 Mdot
.63623 .45789 Mdot
.38053 .36605 Mdot
.63845 .59449 Mdot
.72695 .5618 Mdot
.4788 .62663 Mdot
.45792 .66286 Mdot
.65237 .60076 Mdot
.73331 .45646 Mdot
.58885 .45087 Mdot
.44124 .62733 Mdot
.55913 .31191 Mdot
.13051 .53039 Mdot
.50696 .60977 Mdot
.70564 .6267 Mdot
.67179 .46676 Mdot
.78828 .54487 Mdot
.48996 .74267 Mdot
.50008 .56838 Mdot
.68866 .24937 Mdot
.24294 .61853 Mdot
.77141 .32197 Mdot
.29155 .65003 Mdot
.59914 .23957 Mdot
.84025 .52205 Mdot
.55097 .28426 Mdot
.52821 .77594 Mdot
.49252 .16337 Mdot
.727 .48823 Mdot
.23516 .36771 Mdot
.41978 .24709 Mdot
.29227 .29912 Mdot
.52154 .83584 Mdot
.35559 .36737 Mdot
.31286 .65839 Mdot
.41564 .65004 Mdot
.73742 .44237 Mdot
.48377 .76718 Mdot
.36787 .79365 Mdot
.74594 .30704 Mdot
.31227 .30608 Mdot
.64698 .18509 Mdot
.75364 .32789 Mdot
.61077 .63601 Mdot
.37406 .71611 Mdot
.23996 .43439 Mdot
.4028 .4802 Mdot
.25826 .62458 Mdot
.43055 .72219 Mdot
.67317 .37131 Mdot
.53549 .30135 Mdot
.64553 .66327 Mdot
.15039 .57215 Mdot
.36695 .35796 Mdot
.62828 .56414 Mdot
.44808 .19628 Mdot
.66887 .64237 Mdot
.61984 .29643 Mdot
.6887 .24915 Mdot
.80501 .47999 Mdot
.51666 .77788 Mdot
.59711 .51826 Mdot
.58049 .74379 Mdot
.21109 .53726 Mdot
.36182 .71451 Mdot
.67308 .62667 Mdot
.4264 .27686 Mdot
.40675 .48069 Mdot
.23947 .45907 Mdot
.52688 .78941 Mdot
.27915 .46106 Mdot
.26972 .51719 Mdot
.64396 .60079 Mdot
.55777 .67271 Mdot
.65342 .48105 Mdot
.61455 .52903 Mdot
.40179 .4039 Mdot
.53997 .24367 Mdot
.71282 .44109 Mdot
.74909 .47898 Mdot
.73603 .72099 Mdot
.71948 .23639 Mdot
.26833 .56285 Mdot
.49496 .23104 Mdot
.60143 .35423 Mdot
.24367 .59935 Mdot
.57224 .52438 Mdot
.30289 .55806 Mdot
.36051 .57355 Mdot
.56905 .14135 Mdot
.7747 .48087 Mdot
.62848 .1676 Mdot
.61635 .60316 Mdot
.506 .66723 Mdot
.51402 .23316 Mdot
.66677 .74943 Mdot
.25173 .4869 Mdot
.72133 .24255 Mdot
.33226 .47126 Mdot
.70154 .56204 Mdot
.72609 .49147 Mdot
.48482 .77983 Mdot
.33526 .40422 Mdot
.29943 .44055 Mdot
.53008 .6383 Mdot
.55029 .1221 Mdot
.67752 .23935 Mdot
.78928 .59871 Mdot
.79717 .47704 Mdot
.44041 .34117 Mdot
.35435 .39551 Mdot
.5463 .31198 Mdot
.82906 .48392 Mdot
.68124 .58316 Mdot
.82511 .62214 Mdot
.82139 .47728 Mdot
.50986 .54247 Mdot
.53605 .11992 Mdot
.60596 .82442 Mdot
.51906 .73312 Mdot
.34106 .74041 Mdot
.24732 .31929 Mdot
.56448 .51247 Mdot
.69158 .50557 Mdot
.41901 .31677 Mdot
.80521 .53166 Mdot
.83332 .44477 Mdot
.3215 .59431 Mdot
.61723 .25016 Mdot
.61118 .53487 Mdot
.3778 .46447 Mdot
.69674 .54724 Mdot
.21922 .39545 Mdot
.35768 .53424 Mdot
.64119 .17695 Mdot
.46108 .74872 Mdot
.15515 .45989 Mdot
.28495 .63574 Mdot
.5082 .80945 Mdot
.68343 .26417 Mdot
.42255 .39977 Mdot
.38707 .53266 Mdot
.76074 .50496 Mdot
.47812 .57353 Mdot
.53355 .50184 Mdot
.40476 .54437 Mdot
.33624 .4836 Mdot
.57724 .47905 Mdot
.76858 .40463 Mdot
.2776 .61645 Mdot
.56537 .2046 Mdot
.37667 .71343 Mdot
.69476 .59944 Mdot
.2892 .55113 Mdot
.29044 .58839 Mdot
.79263 .45917 Mdot
.46301 .51792 Mdot
.80318 .57874 Mdot
.44938 .5124 Mdot
.47655 .56355 Mdot
.53652 .7739 Mdot
.42096 .71638 Mdot
.3071 .57966 Mdot
.49696 .66132 Mdot
.74981 .70284 Mdot
.80054 .50201 Mdot
.67936 .69082 Mdot
.26292 .59725 Mdot
.69459 .69683 Mdot
.80877 .53244 Mdot
.52039 .22856 Mdot
.69389 .4993 Mdot
.74637 .58064 Mdot
.5571 .12669 Mdot
.40635 .35382 Mdot
.32075 .5769 Mdot
.53363 .35718 Mdot
.38223 .24979 Mdot
.46722 .17374 Mdot
.43212 .50819 Mdot
.81738 .52492 Mdot
.74004 .48736 Mdot
.34733 .39685 Mdot
.65837 .34672 Mdot
.5232 .29968 Mdot
.7077 .67216 Mdot
.51085 .65296 Mdot
.406 .53685 Mdot
.30215 .49456 Mdot
.62314 .77103 Mdot
.51381 .21235 Mdot
.33385 .34332 Mdot
.51892 .58226 Mdot
.35883 .3047 Mdot
.65275 .47302 Mdot
.56917 .43436 Mdot
.84765 .45244 Mdot
.45702 .54715 Mdot
.57925 .82977 Mdot
.74668 .46411 Mdot
.54249 .41949 Mdot
.23701 .48592 Mdot
.76671 .57882 Mdot
.60758 .15282 Mdot
.82504 .51564 Mdot
.75096 .42727 Mdot
.7378 .29204 Mdot
.65646 .82273 Mdot
.42128 .18079 Mdot
.65949 .77073 Mdot
.53302 .35564 Mdot
.47381 .91114 Mdot
.37136 .39085 Mdot
.36786 .75417 Mdot
.6635 .75022 Mdot
.28501 .3276 Mdot
.67756 .64273 Mdot
.42345 .72932 Mdot
.27338 .4413 Mdot
.62946 .54897 Mdot
.52601 .61263 Mdot
.76603 .28916 Mdot
.57647 .13994 Mdot
.75337 .27403 Mdot
.62543 .44013 Mdot
.77912 .32212 Mdot
.56993 .16326 Mdot
.30061 .74102 Mdot
.47862 .18418 Mdot
.41496 .5864 Mdot
.33805 .56744 Mdot
.62858 .81027 Mdot
.32373 .42135 Mdot
.59526 .53694 Mdot
.68991 .6263 Mdot
.55284 .14672 Mdot
.84889 .44902 Mdot
.5943 .70603 Mdot
.58497 .64711 Mdot
.45507 .41655 Mdot
.31749 .55917 Mdot
.70705 .64127 Mdot
.67956 .35725 Mdot
.80312 .43697 Mdot
.55816 .16052 Mdot
.28775 .59813 Mdot
.41975 .25369 Mdot
.74287 .41292 Mdot
.64398 .79349 Mdot
.68246 .25852 Mdot
.44097 .19576 Mdot
.46918 .5284 Mdot
.60666 .55359 Mdot
.42028 .50819 Mdot
.66767 .36291 Mdot
.50107 .28008 Mdot
.25318 .56829 Mdot
.40256 .33508 Mdot
.32583 .58447 Mdot
.50098 .45645 Mdot
.47597 .18366 Mdot
.24053 .57094 Mdot
.32106 .60521 Mdot
.7642 .42003 Mdot
.76804 .29742 Mdot
.74529 .46733 Mdot
.22076 .34399 Mdot
.70718 .30081 Mdot
.42824 .53801 Mdot
.45861 .68596 Mdot
.81369 .52693 Mdot
.81588 .34498 Mdot
.81891 .523 Mdot
.73153 .53506 Mdot
.33948 .29201 Mdot
.59471 .28128 Mdot
.234 .57403 Mdot
.34054 .34621 Mdot
.80911 .43554 Mdot
.47614 .47254 Mdot
.60354 .28453 Mdot
.70994 .4523 Mdot
.57648 .63178 Mdot
.25181 .64891 Mdot
.6215 .66359 Mdot
.40136 .5864 Mdot
.5375 .70485 Mdot
.66699 .54311 Mdot
.72685 .53111 Mdot
.30822 .56229 Mdot
.40228 .35035 Mdot
.34797 .24528 Mdot
.71503 .6264 Mdot
.5202 .64193 Mdot
.49792 .25573 Mdot
.69577 .54545 Mdot
.68979 .71008 Mdot
.34963 .35804 Mdot
.84104 .49991 Mdot
.72342 .726 Mdot
.71573 .63904 Mdot
.27605 .55413 Mdot
.36103 .25022 Mdot
.58424 .43881 Mdot
.53728 .35558 Mdot
.7454 .3105 Mdot
.48887 .39825 Mdot
.28819 .55705 Mdot
.52592 .71484 Mdot
.50746 .19466 Mdot
.44682 .56155 Mdot
.77962 .6136 Mdot
.28658 .72077 Mdot
.57169 .42661 Mdot
.67857 .63816 Mdot
.62226 .58909 Mdot
.44758 .83457 Mdot
.68639 .38515 Mdot
.5541 .55971 Mdot
.71009 .27614 Mdot
.55515 .29492 Mdot
.68296 .61051 Mdot
.32544 .60961 Mdot
.24973 .38361 Mdot
.53663 .68675 Mdot
.50903 .27434 Mdot
.62372 .63791 Mdot
.4987 .36287 Mdot
.72642 .28308 Mdot
.65519 .21139 Mdot
.13674 .521 Mdot
.61434 .57678 Mdot
.47653 .21681 Mdot
.46933 .21787 Mdot
.6796 .62504 Mdot
.71221 .61882 Mdot
.44785 .73819 Mdot
.80545 .35416 Mdot
.45977 .46295 Mdot
.67112 .34502 Mdot
.53499 .4156 Mdot
.2339 .37676 Mdot
.48552 .19553 Mdot
.25042 .59629 Mdot
.65375 .24194 Mdot
.59604 .65781 Mdot
.29352 .2558 Mdot
.39945 .66976 Mdot
.37254 .75796 Mdot
.23375 .57387 Mdot
.34961 .67358 Mdot
.53352 .78863 Mdot
.78185 .39388 Mdot
.47778 .66572 Mdot
.74012 .25284 Mdot
.78111 .45166 Mdot
.52663 .50465 Mdot
.43982 .36631 Mdot
.47816 .64931 Mdot
.45131 .57702 Mdot
.75291 .61863 Mdot
.78386 .56268 Mdot
.36743 .19896 Mdot
.2902 .63216 Mdot
.45938 .53516 Mdot
.51573 .7267 Mdot
.58022 .82927 Mdot
.52073 .24096 Mdot
.79093 .36807 Mdot
.4996 .4675 Mdot
.6466 .79843 Mdot
.6629 .30248 Mdot
.65571 .36585 Mdot
.70112 .28946 Mdot
.57691 .16616 Mdot
.5386 .59445 Mdot
.7742 .53863 Mdot
.4498 .2027 Mdot
.46581 .5957 Mdot
.74114 .51568 Mdot
.71158 .28334 Mdot
.17465 .48584 Mdot
.56365 .53092 Mdot
.81021 .32871 Mdot
.37341 .6046 Mdot
.77346 .52224 Mdot
.4783 .16311 Mdot
.19695 .32986 Mdot
.66363 .37807 Mdot
.6505 .1842 Mdot
.65092 .3531 Mdot
.69786 .26525 Mdot
.54209 .31495 Mdot
.47287 .43539 Mdot
.72409 .68325 Mdot
.8098 .36116 Mdot
.26817 .39387 Mdot
.58664 .2242 Mdot
.74842 .65598 Mdot
.80353 .34268 Mdot
.36342 .60978 Mdot
.44733 .82992 Mdot
.38794 .41468 Mdot
.65576 .80287 Mdot
.69112 .74773 Mdot
.61019 .62254 Mdot
.31236 .599 Mdot
.44003 .8199 Mdot
.34497 .77344 Mdot
.68445 .74833 Mdot
.33476 .63072 Mdot
.77224 .5791 Mdot
.26743 .55113 Mdot
.8142 .44153 Mdot
.50462 .83492 Mdot
.48323 .20423 Mdot
.68492 .45131 Mdot
.63325 .44011 Mdot
.78675 .57054 Mdot
.74523 .3767 Mdot
.50569 .24625 Mdot
.61196 .43584 Mdot
.60505 .62937 Mdot
.14357 .63459 Mdot
.64389 .32707 Mdot
.49452 .71338 Mdot
.59945 .15534 Mdot
.80077 .4401 Mdot
.46257 .47293 Mdot
.51803 .79276 Mdot
.25311 .66386 Mdot
.37961 .43332 Mdot
.42927 .5982 Mdot
.79834 .33618 Mdot
.35663 .42707 Mdot
.67559 .20984 Mdot
.81039 .60968 Mdot
.56627 .67863 Mdot
.51915 .56764 Mdot
.40715 .31317 Mdot
.37577 .73115 Mdot
.33343 .6453 Mdot
.60208 .16538 Mdot
.37514 .75719 Mdot
.52784 .39637 Mdot
.49353 .35262 Mdot
.50847 .30295 Mdot
.54464 .57039 Mdot
.63243 .81062 Mdot
.77584 .56613 Mdot
.26883 .62089 Mdot
.73549 .41559 Mdot
.31492 .57637 Mdot
.4894 .74441 Mdot
.23262 .56185 Mdot
.49651 .50755 Mdot
.2595 .44899 Mdot
.42241 .37437 Mdot
.57547 .18877 Mdot
.74859 .33159 Mdot
.75733 .68827 Mdot
.22626 .33924 Mdot
.76002 .50881 Mdot
.32235 .66998 Mdot
.53839 .20538 Mdot
.55544 .52024 Mdot
.26264 .41087 Mdot
.27014 .65948 Mdot
.46664 .74472 Mdot
.78786 .38231 Mdot
.38013 .70995 Mdot
.8363 .44635 Mdot
.25317 .57281 Mdot
.53502 .17971 Mdot
.4498 .42351 Mdot
.63989 .75162 Mdot
.54248 .73916 Mdot
.26311 .3021 Mdot
.56843 .42662 Mdot
.55151 .12353 Mdot
.69931 .60589 Mdot
.71488 .23304 Mdot
.59422 .31003 Mdot
.15724 .53923 Mdot
.79621 .40991 Mdot
.5266 .47955 Mdot
.51773 .43316 Mdot
.78105 .62007 Mdot
.7397 .4672 Mdot
.75265 .46915 Mdot
.42396 .50995 Mdot
.37112 .3366 Mdot
.53298 .38856 Mdot
.67567 .34375 Mdot
.58698 .20262 Mdot
.40582 .61914 Mdot
.3426 .39833 Mdot
.35006 .69035 Mdot
.5511 .36775 Mdot
.80201 .51192 Mdot
.77134 .36489 Mdot
.44655 .71954 Mdot
.31754 .55631 Mdot
.569 .15718 Mdot
.80951 .46407 Mdot
.41997 .50151 Mdot
.39402 .55408 Mdot
.6083 .35103 Mdot
.38515 .21038 Mdot
.65584 .2274 Mdot
.50086 .32837 Mdot
.59529 .44185 Mdot
.27015 .56559 Mdot
.81556 .31744 Mdot
.57249 .14048 Mdot
.25627 .29273 Mdot
.53406 .41284 Mdot
.60667 .5901 Mdot
.26013 .68103 Mdot
.53852 .18103 Mdot
.66942 .79509 Mdot
.76514 .4399 Mdot
.3175 .58058 Mdot
.17957 .46168 Mdot
.40582 .79371 Mdot
.51166 .38895 Mdot
.54362 .7396 Mdot
.6912 .71851 Mdot
.61415 .32025 Mdot
.38074 .4375 Mdot
.50463 .41 Mdot
.62202 .30118 Mdot
.77306 .57702 Mdot
.7382 .47091 Mdot
.53232 .17835 Mdot
.3873 .7669 Mdot
.39141 .55647 Mdot
.58124 .21299 Mdot
.69781 .55245 Mdot
.46658 .21365 Mdot
.37284 .23657 Mdot
.51241 .40157 Mdot
.36198 .38339 Mdot
.49475 .70181 Mdot
.58554 .41553 Mdot
.65435 .33554 Mdot
.19161 .42178 Mdot
.28621 .50267 Mdot
.64877 .62382 Mdot
.41929 .80196 Mdot
.6136 .58693 Mdot
.84643 .38674 Mdot
.68172 .35615 Mdot
.52696 .71781 Mdot
.65425 .28501 Mdot
.43555 .26121 Mdot
.19259 .37667 Mdot
.60142 .63392 Mdot
.25039 .51057 Mdot
.6224 .61209 Mdot
.66209 .54412 Mdot
.66083 .27577 Mdot
.65633 .49073 Mdot
.57252 .65528 Mdot
.54814 .83446 Mdot
.35831 .25147 Mdot
.62061 .60016 Mdot
.48947 .36243 Mdot
.71912 .56268 Mdot
.84817 .45903 Mdot
.36285 .37825 Mdot
.56476 .12944 Mdot
.41742 .55249 Mdot
.37563 .21153 Mdot
.80955 .51974 Mdot
.59202 .47271 Mdot
.535 .40786 Mdot
.38865 .25869 Mdot
.47123 .56448 Mdot
.46903 .53585 Mdot
.63326 .58236 Mdot
.48991 .18007 Mdot
.31607 .46299 Mdot
.31754 .53758 Mdot
.53012 .33853 Mdot
.54783 .81536 Mdot
.67047 .782 Mdot
.66252 .54261 Mdot
.47359 .37772 Mdot
.46079 .22657 Mdot
.35745 .6247 Mdot
.34882 .68349 Mdot
.58061 .18473 Mdot
.58764 .64048 Mdot
.69907 .60413 Mdot
.25304 .29957 Mdot
.35997 .52758 Mdot
.83511 .52428 Mdot
.39931 .68256 Mdot
.36898 .72174 Mdot
.3585 .68782 Mdot
.77433 .60172 Mdot
.48857 .74254 Mdot
.8034 .39615 Mdot
.29361 .55341 Mdot
.38001 .50955 Mdot
.32292 .60278 Mdot
.44827 .72073 Mdot
.50641 .34784 Mdot
.6302 .81791 Mdot
.18017 .45508 Mdot
.57279 .75169 Mdot
.57674 .5318 Mdot
.67542 .64037 Mdot
.58897 .82695 Mdot
.66551 .62804 Mdot
.3116 .50251 Mdot
.65609 .66709 Mdot
.79595 .41219 Mdot
.82978 .47651 Mdot
.79199 .45919 Mdot
.37647 .73412 Mdot
.50951 .30428 Mdot
.3015 .7042 Mdot
.37257 .5761 Mdot
.53566 .47405 Mdot
.50168 .57821 Mdot
.4874 .54324 Mdot
.46898 .48347 Mdot
.76873 .63385 Mdot
.53527 .57291 Mdot
.80322 .35727 Mdot
.83198 .52027 Mdot
.75796 .29762 Mdot
.49955 .27842 Mdot
.62301 .56602 Mdot
.59629 .1486 Mdot
.4208 .7784 Mdot
.81384 .44893 Mdot
.68022 .75757 Mdot
.46431 .84274 Mdot
.48844 .16058 Mdot
.77521 .40442 Mdot
.59005 .57237 Mdot
.78872 .66123 Mdot
.77621 .47929 Mdot
.45169 .82953 Mdot
.46085 .74321 Mdot
.80582 .51902 Mdot
.53829 .12589 Mdot
.61367 .79637 Mdot
.75212 .4778 Mdot
.53545 .74313 Mdot
.4851 .72949 Mdot
.51743 .82919 Mdot
.45706 .57363 Mdot
.35567 .38395 Mdot
.26606 .33194 Mdot
.31076 .59153 Mdot
.46401 .72017 Mdot
.50198 .82848 Mdot
.33382 .65071 Mdot
.31586 .66588 Mdot
.37947 .25615 Mdot
.49236 .16234 Mdot
.51399 .71874 Mdot
.4848 .69916 Mdot
.69021 .62896 Mdot
.27605 .47085 Mdot
.28094 .65084 Mdot
.47024 .64573 Mdot
.55193 .44086 Mdot
.54304 .62252 Mdot
.77871 .29896 Mdot
.24765 .36853 Mdot
.58821 .26414 Mdot
.61798 .5761 Mdot
.78272 .57682 Mdot
.54661 .23032 Mdot
.72618 .48857 Mdot
.48542 .82245 Mdot
.56244 .64694 Mdot
.71462 .27019 Mdot
.75069 .49066 Mdot
.27042 .58805 Mdot
.21166 .51146 Mdot
.54664 .34194 Mdot
.70544 .70821 Mdot
.59689 .16761 Mdot
.75286 .51905 Mdot
.70372 .56309 Mdot
.7394 .39958 Mdot
.50566 .35317 Mdot
.75981 .53897 Mdot
.74343 .4621 Mdot
.50269 .20545 Mdot
.56471 .69841 Mdot
.65111 .2126 Mdot
.38417 .31643 Mdot
.29411 .60314 Mdot
.70443 .38839 Mdot
.51663 .83172 Mdot
.35877 .62943 Mdot
.82525 .41675 Mdot
.52549 .47168 Mdot
.32928 .51708 Mdot
.44036 .66066 Mdot
.41827 .76956 Mdot
.76823 .60563 Mdot
.72833 .40736 Mdot
.49654 .5334 Mdot
.66258 .53762 Mdot
.73367 .72067 Mdot
.4348 .3755 Mdot
.38773 .42161 Mdot
.35132 .74114 Mdot
.72631 .54051 Mdot
.33935 .4918 Mdot
.67202 .42672 Mdot
.39971 .56483 Mdot
.22043 .48129 Mdot
.50532 .29595 Mdot
.71479 .70061 Mdot
.6494 .7779 Mdot
.58023 .18918 Mdot
.51192 .26362 Mdot
.7424 .71724 Mdot
.71789 .70986 Mdot
.79515 .54698 Mdot
.4086 .78813 Mdot
.58872 .55886 Mdot
.51013 .64857 Mdot
.31224 .5022 Mdot
.68722 .61951 Mdot
.59568 .20067 Mdot
.41628 .52975 Mdot
.31758 .51671 Mdot
.52065 .49149 Mdot
.51079 .23479 Mdot
.42192 .4401 Mdot
.7991 .50669 Mdot
.78866 .66182 Mdot
.30708 .56158 Mdot
.53714 .33646 Mdot
.6567 .34277 Mdot
.55609 .53174 Mdot
.81332 .38481 Mdot
.45739 .49095 Mdot
.72965 .63267 Mdot
.67678 .45052 Mdot
.67229 .71418 Mdot
.81338 .56835 Mdot
.33496 .53872 Mdot
.54377 .47216 Mdot
.71933 .62971 Mdot
.59868 .53255 Mdot
.64688 .47009 Mdot
.27878 .34079 Mdot
.41173 .77634 Mdot
.61731 .25567 Mdot
.56181 .38916 Mdot
.38347 .58707 Mdot
.26356 .68489 Mdot
.63819 .21146 Mdot
.44808 .47709 Mdot
.51786 .47307 Mdot
.44559 .20547 Mdot
.35822 .43061 Mdot
.12649 .55099 Mdot
.75785 .2709 Mdot
.44199 .66056 Mdot
.50429 .43026 Mdot
.32683 .53595 Mdot
.40783 .3305 Mdot
.61888 .65963 Mdot
.58921 .19116 Mdot
.55469 .30483 Mdot
.36222 .2685 Mdot
.66506 .42292 Mdot
.77762 .62481 Mdot
.29137 .26732 Mdot
.60762 .29049 Mdot
.8448 .38042 Mdot
.76089 .44033 Mdot
.75868 .57904 Mdot
.12491 .57876 Mdot
.76538 .62718 Mdot
.36242 .57734 Mdot
.35348 .28351 Mdot
.78014 .30662 Mdot
.53935 .41054 Mdot
.33857 .2971 Mdot
.62922 .78748 Mdot
.30182 .55947 Mdot
.29152 .62221 Mdot
.68972 .45167 Mdot
.75837 .66763 Mdot
.42257 .83111 Mdot
.43693 .25985 Mdot
.20502 .35136 Mdot
.57032 .66467 Mdot
.67469 .22068 Mdot
.66442 .37623 Mdot
.1818 .47578 Mdot
.8278 .48091 Mdot
.33564 .58755 Mdot
.51495 .82144 Mdot
.24515 .4047 Mdot
.25997 .52017 Mdot
.25727 .68516 Mdot
.61917 .44207 Mdot
.596 .63982 Mdot
.40462 .26891 Mdot
.51737 .53853 Mdot
.32408 .59318 Mdot
.67394 .72664 Mdot
.54177 .47117 Mdot
.62439 .18213 Mdot
.46276 .81005 Mdot
.2803 .56088 Mdot
.41892 .21923 Mdot
.27252 .52013 Mdot
.6105 .2114 Mdot
.55861 .24311 Mdot
.35059 .59283 Mdot
.44147 .15751 Mdot
.64099 .17722 Mdot
.59036 .55561 Mdot
.44399 .57786 Mdot
.8394 .52603 Mdot
.38293 .47484 Mdot
.65973 .76918 Mdot
.71271 .42938 Mdot
.29268 .63817 Mdot
.54513 .5984 Mdot
.51621 .62606 Mdot
.32045 .72594 Mdot
.5886 .58225 Mdot
.67941 .72403 Mdot
.32494 .25069 Mdot
.2808 .55674 Mdot
.47238 .80637 Mdot
.30153 .25145 Mdot
.39999 .68499 Mdot
.68035 .55645 Mdot
.77923 .30314 Mdot
.68562 .65565 Mdot
.39646 .5463 Mdot
.53518 .72286 Mdot
.44112 .49458 Mdot
.28642 .40849 Mdot
.39141 .55767 Mdot
.58271 .43783 Mdot
.31047 .59995 Mdot
.54676 .18735 Mdot
.73143 .674 Mdot
.54256 .11666 Mdot
.8177 .52912 Mdot
.615 .59277 Mdot
.63696 .77781 Mdot
.50711 .39912 Mdot
.74616 .28677 Mdot
.40633 .25969 Mdot
.36484 .24591 Mdot
.39198 .80794 Mdot
.27128 .52853 Mdot
.44912 .67732 Mdot
.62622 .43927 Mdot
.83364 .4644 Mdot
.40689 .81386 Mdot
.83519 .44484 Mdot
.52806 .57217 Mdot
.4736 .68407 Mdot
.16858 .36338 Mdot
.71021 .27256 Mdot
.4791 .55674 Mdot
.56518 .57017 Mdot
.55063 .56542 Mdot
.4144 .642 Mdot
.65129 .49001 Mdot
.25588 .63297 Mdot
.29807 .63046 Mdot
.8031 .35263 Mdot
.62823 .60188 Mdot
.54579 .41593 Mdot
.5934 .3408 Mdot
.53588 .43129 Mdot
.44919 .71368 Mdot
.55718 .29523 Mdot
.30639 .64047 Mdot
.40008 .4647 Mdot
.31857 .39312 Mdot
.574 .62504 Mdot
.60648 .45491 Mdot
.5901 .62114 Mdot
.34554 .70799 Mdot
.68803 .50996 Mdot
.34172 .77237 Mdot
.33288 .65004 Mdot
.34632 .61021 Mdot
.79333 .50371 Mdot
.6254 .83626 Mdot
.55827 .42028 Mdot
.69753 .52174 Mdot
.37117 .6332 Mdot
.44442 .76751 Mdot
.55022 .70853 Mdot
.30997 .41862 Mdot
.66171 .48147 Mdot
.52075 .56305 Mdot
.71696 .6372 Mdot
.57919 .28167 Mdot
.81382 .32227 Mdot
.51904 .63998 Mdot
.60404 .6716 Mdot
.81314 .40209 Mdot
.47283 .20782 Mdot
.46005 .74065 Mdot
.50563 .58286 Mdot
.39249 .49983 Mdot
.39521 .46631 Mdot
.73447 .5938 Mdot
.48524 .1921 Mdot
.68624 .24154 Mdot
.35886 .73694 Mdot
.58701 .67203 Mdot
.46207 .60474 Mdot
.32688 .48307 Mdot
.57295 .44323 Mdot
.19767 .45084 Mdot
.35764 .46278 Mdot
.80279 .45938 Mdot
.33511 .68979 Mdot
.28975 .63215 Mdot
.51607 .75364 Mdot
.69399 .22184 Mdot
.56693 .53781 Mdot
.56046 .68458 Mdot
.4975 .49925 Mdot
.75019 .38194 Mdot
.33354 .63237 Mdot
.60877 .24673 Mdot
.52326 .56041 Mdot
.57806 .57907 Mdot
.84201 .40516 Mdot
.61049 .63659 Mdot
.52678 .31109 Mdot
.78914 .38208 Mdot
.4213 .7852 Mdot
.51685 .43419 Mdot
.12792 .60199 Mdot
.40177 .2566 Mdot
.83657 .36811 Mdot
.5247 .19334 Mdot
.3646 .67409 Mdot
.76925 .57525 Mdot
.52634 .60468 Mdot
.38437 .3728 Mdot
.72488 .26803 Mdot
.70314 .63516 Mdot
.59978 .54628 Mdot
.4265 .57759 Mdot
.42645 .47229 Mdot
.73081 .60388 Mdot
.60478 .23679 Mdot
.35525 .35455 Mdot
.42471 .50013 Mdot
.59422 .23137 Mdot
.39399 .46623 Mdot
.48923 .85026 Mdot
.60434 .16544 Mdot
.74949 .31505 Mdot
.50277 .308 Mdot
.14679 .51877 Mdot
.62639 .62009 Mdot
.71981 .6063 Mdot
.54133 .29649 Mdot
.30712 .71234 Mdot
.7563 .5299 Mdot
.5356 .18434 Mdot
.79558 .57475 Mdot
.358 .62936 Mdot
.15907 .66855 Mdot
.33093 .59983 Mdot
.42626 .48452 Mdot
.74289 .52739 Mdot
.81088 .36957 Mdot
.33957 .28044 Mdot
.80428 .61268 Mdot
.67717 .37279 Mdot
.45719 .71835 Mdot
.30019 .73039 Mdot
.25822 .29718 Mdot
.49224 .3431 Mdot
.20143 .35573 Mdot
.69139 .27059 Mdot
.25818 .6235 Mdot
.72177 .4049 Mdot
.61345 .57701 Mdot
.48777 .53846 Mdot
.68415 .34967 Mdot
.59389 .5385 Mdot
.74807 .59751 Mdot
.68285 .2442 Mdot
.21682 .56877 Mdot
.41269 .20922 Mdot
.7468 .2983 Mdot
.55268 .36975 Mdot
.61125 .6203 Mdot
.33243 .65964 Mdot
.34818 .43919 Mdot
.4147 .34208 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2/ooooo`;o
0000Voooool001cooooo00?o0000ooooooooool0Z_ooool4o`0009_ooooo000Looooo`03o`000?oo
oooooooo0:[ooooo0_l00003ooooo`;o0000V?ooool001cooooo00?o0000ooooooooool0Zoooool2
o`0000;ooooo0_l0002Hooooo`007?ooool00ol0003oooooooooo`2Wooooo`;o00000_ooool2o`00
00;ooooo1?l0002Fooooo`007?ooool00ol0003oooooooooo`2Wooooo`;o00002?ooool2o`000003
ooooool0003o000009?ooooo000Looooo`03o`000?oooooooooo0;Cooooo0_l0002Cooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0;Gooooo1?l00003
ooooo`;o0000Roooool001cooooo00?o0000ooooooooool0]Oooool4o`0000?ooooo0_l0002;oooo
o`007?ooool00ol0003oooooooooo`2`ooooo`;o0000Uoooool001cooooo00?o0000ooooooooool0
/?ooool2o`0000cooooo0_l00029ooooo`007?ooool2o`0008;ooooo0_l0000?ooooo`;o00000ooo
ool2o`0002Gooooo0_l00002ooooo`;o0000QOooool001cooooo00?o0000ooooooooool0POooool2
o`0000oooooo0_l00003ooooo`;o000000?oooooo`000?l000008oooool2o`000004ooooool0003o
0000o`0008Cooooo000Looooo`03o`000?oooooooooo08cooooo0_l0000<ooooo`;o00006Oooool2
o`0000Sooooo0_l00002ooooo`;o0000Q?ooool001cooooo00?o0000ooooooooool0S?ooool2o`00
00?ooooo0_l00008ooooo`?o00005?ooool2o`000003ooooool0003o000009;ooooo000Looooo`03
o`000?oooooooooo097ooooo0_l00005ooooo`;o000000Coooooo`000?l0003o00005?ooool2o`00
0004ooooool0003o0000ooooo`;o00001_ooool3o`0008Kooooo000Looooo`03o`000?oooooooooo
09Cooooo0_l00002ooooo`;o00000_ooool2o`0000Kooooo0_l0000?ooooo`;o000000?oooooo`00
0?l000001?ooool5o`0000Gooooo0_l0001oooooo`007?ooool00ol0003oooooooooo`28ooooo`;o
00002_ooool2o`0000;ooooo0_l0000:ooooo`?o00005oooool2o`0000Sooooo0_l0001oooooo`00
7?ooool00ol0003oooooooooo`28ooooo`;o00002?ooool4o`0000;ooooo0_l00003ooooo`;o0000
1_ooool2o`000:;ooooo000Looooo`03o`000?oooooooooo09;ooooo1_l00003ooooo`Co00002?oo
ool4o`00027ooooo0_l0001kooooo`007?ooool00ol0003oooooooooo`25ooooo`;o00003oooool4
o`000003ooooool0003o000000[ooooo1_l0000Oooooo`;o0000Noooool001cooooo00?o0000oooo
ooooool0QOooool2o`0000_ooooo0_l00003ooooo`Ko00002_ooool2o`000004ooooool0003o0000
o`0001[ooooo0_l00007ooooo`;o0000Moooool001cooooo00?o0000ooooooooool0P_ooool2o`00
00kooooo0_l00003ooooo`Ko00001?ooool2o`0000Oooooo0_l00002ooooo`;o00002Oooool4o`00
00[ooooo0_l00005ooooo`Co0000Moooool001cooooo00?o0000ooooooooool0NOooool2o`0000Oo
oooo0_l0000Mooooo`;o00002oooool2o`0000Oooooo1_l0000Aooooo`;o0000NOooool00006oooo
ooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo
07Wooooo0_l0000Oooooo`;o00002oooool4o`0000cooooo1?l000000ooooooo0000o`00000=oooo
o`;o0000O?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo083ooooo0_l00009ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0000Kooooo1?l00003ooooo`;o00001?ooool4o`0000kooooo1Ol0
000=ooooo`;o0000O?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool0
0onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo07Cooooo0_l00006ooooo`;o00000_ooool2
o`0000Wooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00001_ooool4o`0000?ooooo0_l0
000Hooooo`;o0000S?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool0
0onHV9So8B4Qonk^kP06ooooo`?o0000M?ooool2o`0000Gooooo0ol0000@ooooo`?o00002Oooool2
o`0001oooooo0_l000000ooooooo0000o`000029ooooo`0000?oooooo`000?ooool00_ooool00ol0
003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0Noooool2o`00
00Sooooo0_l00006ooooo`?o00001?ooool2o`0000?ooooo0ol00004ooooo`;o00002Oooool2o`00
00Oooooo0_l00005ooooo`;o000000?oooooo`000?l000004?ooool2o`0000Oooooo0_l0001^oooo
o`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0OOooool2o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`;o
00001Oooool4o`000003ooooool0003o000000;o00000oooool2o`0000;ooooo0_l000000ooooooo
0000o`000002ooooo`;o00000_ooool2o`0000?ooooo0_l0000Jooooo`;o00001oooool2o`0006ko
oooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4006
ooooo`03o`000?oooooooooo07Kooooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool2
o`00017ooooo0ol00003ooooo`?o00001Oooool3o`000003ooooool0003o000000Kooooo0_l00005
ooooo`;o00000_ooool2o`0000Oooooo0_l00007ooooo`;o00000oooool2o`0000Cooooo0ol0001_
ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
1_ooool00ol0003oooooooooo`1cooooo`;o000000Coooooo`000?l0003ooooo0_l0000Iooooo`Co
00001?ooool2o`0000Gooooo0_l0000?ooooo`Co000000Coooooo`000?l0003o00001oooool2o`00
00Oooooo0_l00002ooooo`?o00001?ooool3o`0006oooooo000Looooo`03o`000?oooooooooo07?o
oooo0_l0000Oooooo`Go00006oooool2o`0000?ooooo1Ol0000Booooo`;o0000Moooool001cooooo
00?o0000ooooooooool0Noooool2o`0000Oooooo0_l0000?ooooo`Co00001?ooool2o`0001cooooo
0ol0000Iooooo`;o0000L?ooool001cooooo00?o0000ooooooooool0N_ooool3o`0000Oooooo0_l0
000Aooooo`;o00001?ooool2o`0001Oooooo0_l00003ooooo`;o00006_ooool2o`0000Gooooo0_l0
001Yooooo`007?ooool00ol0003oooooooooo`1jooooo`;o00000_ooool2o`0001;ooooo0_l0000R
ooooo`;o000000?oooooo`000?l000000_l0000Dooooo`;o00002oooool2o`0006Wooooo000Loooo
o`03o`000?oooooooooo07kooooo0_l0000Booooo`;o00001Oooool2o`0000[ooooo0_l000000ooo
oooo0000o`000004ooooo`;o00002Oooool4o`0001Cooooo0_l0001fooooo`007?ooool00ol0003o
ooooooooo`1kooooo`;o00007?ooool2o`0000;ooooo0_l00004ooooo`Oo00001?ooool2o`0000_o
oooo1?l0000Pooooo`;o00000oooool2o`0006?ooooo000Looooo`03o`000?oooooooooo07Gooooo
0_l00003ooooo`?o00001?ooool2o`0000kooooo0_l0000:ooooo`;o00000oooool3o`000003oooo
ool0003o000000Oooooo0_l0000:ooooo`Go000000?oooooo`000?l000007?ooool2o`0000?ooooo
1?l0001Qooooo`007?ooool00ol0003oooooooooo`1aooooo`;o00000_ooool3o`0000;ooooo0_l0
0005ooooo`;o00003_ooool2o`0000oooooo0_l0000;ooooo`?o00003?ooool5o`0001Gooooo0_l0
000<ooooo`;o0000HOooool001cooooo00?o0000ooooooooool0LOooool3o`0000;ooooo1?l00002
ooooo`;o00007_ooool2o`0000Oooooo0_l00009ooooo`Co00002oooool2o`00013ooooo0_l00005
ooooo`;o000000Coooooo`000?l0003ooooo0_l00007ooooo`;o0000H?ooool001cooooo00?o0000
ooooooooool0KOooool2o`0000?ooooo1?l000001?oooooo0000o`000?l00002ooooo`;o00007_oo
ool2o`0000?ooooo0_l00002ooooo`;o00001Oooool2o`0000Cooooo0_l0000Mooooo`;o00001ooo
ool3o`000003ooooool0003o000000Gooooo1?l0001Pooooo`007?ooool00ol0003oooooooooo`1]
ooooo`;o00001?ooool3o`0000Wooooo0_l00004ooooo`;o00005oooool2o`000003ooooool0003o
000000Gooooo0_l00002ooooo`;o00004_ooool4o`0001Kooooo1_l00005ooooo`;o00001_ooool2
o`0005[ooooo000Looooo`;o0000Goooool2o`000003ooooool0003o000000?ooooo0_l00008oooo
o`[o00001?ooool3o`0000Cooooo0_l0000Gooooo`;o00002?ooool2o`0000cooooo0_l00008oooo
o`Co000000?oooooo`000?l000003oooool2o`0000Cooooo1?l0000=ooooo`;o0000F_ooool001co
oooo00?o0000ooooooooool0G_ooool2o`000003ooooool0003o000000?ooooo0_l00008ooooo`Co
000000?oooooo`000?l000000ol00004ooooo`?o00001?ooool2o`0001Sooooo0_l00002ooooo`;o
00002?ooool2o`0000Oooooo0_l0000=ooooo`;o00003oooool2o`0000Cooooo0_l0000?ooooo`;o
0000F_ooool001cooooo00?o0000ooooooooool0G?ooool2o`0000Gooooo0_l0000Cooooo`;o0000
1Oooool2o`0000Cooooo0_l0000Gooooo`?o00000_ooool2o`0000Sooooo0_l0000Fooooo`;o0000
4oooool2o`00017ooooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`1Looooo`;o00001Ooo
ool2o`0001?ooooo1Ol00002ooooo`?o00002?ooool2o`0001;ooooo0_l00008ooooo`;o00001ooo
ool2o`0001;ooooo0_l0000?ooooo`;o00000_ooool2o`0006gooooo000Looooo`03o`000?oooooo
oooo05kooooo0_l0000Iooooo`Co00000_ooool3o`0000Sooooo0_l000000ooooooo0000o`00000D
ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00002?ooool2o`0001Wooooo0_l00002
ooooo`;o0000KOooool001cooooo00?o0000ooooooooool0Foooool5o`0001oooooo0_l0000<oooo
o`;o00003oooool2o`0000?ooooo0_l00007ooooo`;o00002Oooool2o`0000;ooooo1?l000001?oo
oooo0000o`000?l0000Gooooo`;o00000oooool2o`0000cooooo0_l0001Jooooo`007?ooool00ol0
003oooooooooo`1Kooooo`?o00005?ooool2o`0000cooooo0_l0000Looooo`;o00005oooool4o`00
0005ooooool0003o0000o`000?ooool00ol0000Jooooo`Co00000oooool2o`0000;ooooo0_l00003
ooooo`;o0000F_ooool001cooooo00?o0000ooooooooool0L_ooool2o`0000cooooo0_l0000Yoooo
o`;o00001_ooool2o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`00
0?l000005oooool2o`0000Cooooo0ol00002ooooo`?o00001oooool2o`0005Gooooo000Looooo`03
o`000?oooooooooo08Oooooo0_l0000Iooooo`;o00001oooool2o`0000Cooooo1?l00003ooooo`;o
000000Coooooo`000?l0003o00000_ooool3o`000003ooooool0003o000000gooooo0_l0000>oooo
o`;o00001?ooool2o`0000Kooooo0ol0001Eooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o
00004?ooool2o`0001_ooooo0_l0000Fooooo`;o000000?oooooo`000?l000002?ooool2o`000003
ooooool0003o000000Co00000_ooool3o`000004ooooool0003o0000o`0000;ooooo0_l0000Aoooo
o`;o00003_ooool2o`0000cooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o
00004?ooool3o`0001cooooo0_l0000Dooooo`;o00002?ooool5o`000003ooooool0003o000000Go
000000?oooooo`000?l000000ol000000ooooooo0000o`00000Yooooo`;o0000Goooool001cooooo
00?o0000ooooooooool0Joooool2o`0000;ooooo0_l0000Hooooo`;o00005?ooool2o`0000Sooooo
0ol00003ooooo`;o00000_ooool<o`000003ooooool0003o000000?ooooo0_l0000:ooooo`;o0000
3?ooool2o`0000;ooooo0_l00003ooooo`;o0000Goooool001cooooo00?o0000ooooooooool0Kooo
ool2o`0001Gooooo0_l0000Gooooo`;o00001?ooool2o`0000Sooooo0ol000000ooooooo0000o`00
000:o`000003ooooool0003o000000?ooooo0_l0000:ooooo`?o00002oooool2o`000004ooooool0
003o0000o`0000[ooooo1?l00002ooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0C?oo
ool2o`0000Kooooo0_l00005ooooo`;o00003_ooool2o`0001Wooooo0_l0000Looooo`?o00001_oo
ool=o`000003ooooool0003o000000Oo00003_ooool2o`0000cooooo1?l00008ooooo`;o000000?o
ooooo`000?l000000_l00002ooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0C?ooool2
o`0000;ooooo0_l00002ooooo`;o00001Oooool2o`0000kooooo0_l0000gooooo`;o00001?ooool2
o`000003ooooool0003o000000Go000000?oooooo`000?l000003Ol0000Looooo`;o00001Oooool2
o`0000?ooooo0_l00007ooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0D?ooool2o`00
01Sooooo0_l0000dooooo`;o00001ooooolGo`000004ooooool0003o0000ooooo`Co00002oooool2
o`0001;ooooo0_l00006ooooo`;o000000Coooooo`000?l0003ooooo0ol0001Aooooo`007?ooool2
o`0004oooooo1?l00009ooooo`;o00003Oooool2o`0000Kooooo0_l0000/ooooo`?o00000oooool2
o`000003ooooool0003o000001So000000?oooooo`000?l000000_l0000;ooooo`;o00003Oooool2
o`0000[ooooo0ol000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l00000C_ooool0
01cooooo00?o0000ooooooooool0C_ooool2o`0000;ooooo0_l00007ooooo`;o00002?ooool2o`00
00;ooooo0_l00006ooooo`?o00003_ooool2o`0001gooooo0ol00002ooooo`;o00000_ooool4o`00
0003ooooool0003o0000017o000000Coooooo`000?l0003ooooo0_l0000<ooooo`;o00003?ooool2
o`0000Cooooo0_l00004ooooo`;o00002Oooool2o`0004kooooo000Looooo`03o`000?oooooooooo
05;ooooo0_l0000;ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`?o00001Oooool2
o`000003ooooool0003o000000cooooo1?l0000Kooooo`?o00001oooool2o`0000;ooooo5_l0000?
ooooo`;o00004_ooool2o`0000Cooooo0_l000000ooooooo0000o`000006ooooo`?o000000?ooooo
o`000?l00000B_ooool001cooooo00?o0000ooooooooool0Goooool2o`000003ooooool0003o0000
00Kooooo0_l00008ooooo`?o00003Oooool2o`0001[ooooo0_l0000:oooooaOo00003oooool3o`00
01Wooooo0_l000000ooooooo0000o`000007ooooo`;o000000?oooooo`000?l000001?ooool2o`00
04Cooooo000Looooo`03o`000?oooooooooo05Kooooo0ol0000Iooooo`;o000000?oooooo`000?l0
00002_ooool2o`0001gooooo1?l00003ooooo`;o000000?oooooo`000?l000005ol00002ooooo`;o
00002oooool3o`0001Kooooo0_l000001?oooooo0000o`000?ooool2o`00013ooooo0_l00014oooo
o`007?ooool00ol0003oooooooooo`1Fooooo`Go00004?ooool2o`0000Gooooo1_l000000ooooooo
0000o`000004o`0000;ooooo0_l000001?oooooo0000o`000?l0000Fooooo`;o00000oooool2o`00
00?ooooo0_l000000ooooooo0000o`000008o`0000;ooooo3Ol00002ooooo`Co00008_ooool2o`00
00?ooooo0ol0001Fooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00001_ooool3o`000003
ooooool0003o0000013ooooo0_l00003ooooo`;o00000_ooool;o`0000;ooooo0_l000001?oooooo
0000o`000?l0000Eooooo`?o00000_ooool2o`0000Oooooo6Ol00004ooooo`;o00009oooool3o`00
00Gooooo0_l0000;ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0?oooool2o`0000co
oooo0_l00006ooooo`;o00001?ooool2o`000003ooooool0003o000000;o00003_ooool2o`0000Go
oooo0ol000000ooooooo0000o`000003o`000003ooooool0003o000000;o00000_ooool2o`0001?o
oooo0_l00003ooooo`;o00001_ooool2o`000003ooooool0003o000001?o00000oooool2o`0002_o
oooo0_l00004ooooo`Co00002_ooool2o`0004;ooooo000Looooo`03o`000?oooooooooo03oooooo
0_l0000Jooooo`;o000000?oooooo`000?l000000_l0000>ooooo`;o00001Oooool2o`0000?ooooo
1?l00003ooooo`;o00000_ooool2o`00023ooooo0_l000000ooooooo0000o`00000Co`0000?ooooo
0_l0000aooooo`Co00002_ooool2o`0004;ooooo000Looooo`03o`000?oooooooooo04Wooooo0_l0
000>ooooo`;o00001Oooool2o`0000cooooo0_l00003ooooo`oo000000?oooooo`000?l000000_l0
000Hooooo`;o00001?ooool2o`0000Gooooo5Ol0000<ooooo`;o000000?oooooo`000?l000000_l0
000Mooooo`;o00004?ooool2o`0004Cooooo000Looooo`03o`000?oooooooooo03cooooo0_l0000;
ooooo`;o00002?ooool2o`0000Cooooo0_l0000Cooooo`;o00000ooooolDo`0001Gooooo0_l00000
0ooooooo0000o`000004ooooo`;o00000ooooolHo`0000_ooooo0_l000000ooooooo0000o`000002
o`0001_ooooo1?l000000ooooooo0000o`00000=ooooo`;o0000A?ooool001cooooo00?o0000oooo
ooooool0??ooool2o`0001Gooooo0_l0000Iooooo`;o00000_oooolFo`0000;ooooo0_l0000@oooo
o`;o00003?ooool3o`000003ooooool0003o000001;o00003_ooool3o`0001cooooo0_l00002oooo
o`?o0000Doooool001cooooo00?o0000ooooooooool0L_oooolAo`000003ooooool0003o000000;o
00000_ooool2o`0001cooooo0_l000001Ooooooo0000o`000?l0003ooooo013o00004_ooool2o`00
023ooooo1?l00009ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0A_ooool2o`0000oo
oooo0_l0000Joooooa3o00000oooool2o`000003ooooool0003o000000;o00006_ooool3o`000003
ooooool0003o000001Co0000=?ooool2o`0000Wooooo0_l00017ooooo`007?ooool00ol0003ooooo
ooooo`14ooooo`Co000000?oooooo`000?l000003?ooool2o`00013ooooo0_l00006oooooaco0000
0_ooool2o`0000_ooooo0_l00007ooooo`Go00000_oooolEo`0000cooooo0_l00003ooooo`;o0000
1?ooool2o`0001Gooooo0_l000001?oooooo0000o`000?ooool3o`0000;ooooo0_l00005ooooo`;o
0000A_ooool001cooooo00?o0000ooooooooool0A?ooool2o`0000?ooooo0_l00006ooooo`;o0000
5_ooool5o`0000?ooooo6ol00003ooooo`;o00002oooool2o`0000?ooooo0_l00002ooooo`?o0000
1?ooool@o`00017ooooo0_l00003ooooo`;o00000_ooool4o`0001Gooooo0_l000001?oooooo0000
o`000?ooool3o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`0004;ooooo000Looooo`;o0000
@?ooool2o`00013ooooo0_l0000Hooooo`?o00000ooooolIo`0001Oooooo0_l00003ooooo`;o0000
1?ooool?o`0001?ooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo0_l0000Gooooo`Go0000
0oooool2o`000003ooooool0003o000000Gooooo0_l00002ooooo`;o0000?_ooool001cooooo00?o
0000ooooooooool0?oooool2o`0002cooooo7Ol0000Aooooo`Co000000?oooooo`000?l000002Ooo
ool@o`0000Oooooo0_l00008ooooo`Ko00002?ooool2o`0001Oooooo1Ol00003ooooo`;o000000Co
ooooo`000?l0003ooooo0_l00006ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0?_oo
ool3o`0002cooooo7_l0000?ooooo`Go000000?oooooo`000?l000001oooool4o`0000Cooooo2Ol0
0006ooooo`Co00002?ooool2o`0000;ooooo0_l00008ooooo`;o00006Oooool2o`0000[ooooo0ol0
0015ooooo`007?ooool00ol0003oooooooooo`0nooooo`;o0000;_ooool8o`000003ooooool0003o
000001;o00003oooool2o`0000gooooo1?l00003ooooo`[o00001_ooool2o`0001Oooooo0ol0000J
ooooo`?o00002?ooool3o`0004Gooooo000Looooo`03o`000?oooooooooo043ooooo0_l0000/oooo
oa_o00004Oooool3o`000004ooooool0003o0000o`0000Wooooo0_l00004ooooo`Co00000_ooool2
o`0001gooooo0_l00002ooooo`;o00006Oooool5o`0000Sooooo1?l00014ooooo`007?ooool00ol0
003oooooooooo`0cooooo`;o00002oooool2o`0000Oooooo0_l0000Roooooa_o000000?oooooo`00
0?l000000_l0000=ooooo`?o000000?oooooo`000?l000000ol00007ooooo`;o00009Oooool2o`00
00;ooooo0_l0000Jooooo`;o000000?oooooo`000?l000000ol00006ooooo`;o00000_ooool2o`00
04Cooooo000Looooo`03o`000?oooooooooo03?ooooo0_l0000Dooooo`;o00000_ooool2o`0001ko
oooo8?l0000Aooooo`Go00000_ooool2o`0000?ooooo1?l000000ooooooo0000o`00000<ooooo`;o
00004_ooool2o`0001kooooo0_l00003ooooo`?o00001?ooool4o`0000_ooooo0_l0000kooooo`00
7?ooool00ol0003oooooooooo`19ooooo`;o00000_ooool2o`00023ooooo6_l0000@ooooo`;o0000
1?ooool3o`0000?ooooo0_l00003ooooo`Co000000Coooooo`000?l0003o00000_ooool2o`0000Oo
oooo0_l0000Hooooo`;o00008?ooool3o`000003ooooool0003o000000Gooooo0_l00006ooooo`;o
0000>oooool001cooooo00?o0000ooooooooool0KooooolIo`000003ooooool0003o000000kooooo
0_l00004ooooo`?o00000_ooool4o`0000;ooooo0ol00003ooooo`;o00000_ooool2o`0000Kooooo
0_l0000Iooooo`?o00004oooool2o`0000[ooooo0ol00008ooooo`;o0000@oooool001cooooo00?o
0000ooooooooool0>oooool2o`0000_ooooo0_l0000Uooooo`;o000000?oooooo`000?l000005?l0
00000ooooooo0000o`00000;ooooo`;o000000?oooooo`000?l000000oooool3o`0000?ooooo1?l0
0003ooooo`Co000000?oooooo`000?l000002_ooool2o`0001Kooooo0_l00002ooooo`;o00004ooo
ool3o`0005Wooooo000Looooo`03o`000?oooooooooo03_ooooo0_l0000;ooooo`;o00009Oooool2
o`000003ooooool0003o000001?o00003oooool2o`000003ooooool0003o000000;ooooo1?l00003
ooooo`;o00001oooool4o`0000Kooooo0_l0000Kooooo`;o00006?ooool2o`0001oooooo0_l0000h
ooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00006oooool@o`000003ooooool0003o0000
00Wo00004?ooool2o`000003ooooool0003o000000Ko00000oooool2o`0000Wooooo0_l00006oooo
o`;o00006Oooool2o`0001cooooo0_l0000:ooooo`?o00000oooool4o`000003ooooool0003o0000
00Kooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`1;ooooo`Co00006ooooolKo`00017o
oooo0_l00003ooooo`;o00001Oooool4o`0001?ooooo0_l0000Gooooo`;o00000oooool2o`0000;o
oooo0_l0000Cooooo`;o00002_ooool3o`0000?ooooo1?l000000ooooooo0000o`000006ooooo`;o
0000>?ooool001cooooo00?o0000ooooooooool0?_ooool2o`0000_ooooo0_l0000Noooooa[o0000
4Oooool4o`000003ooooool0003o000000Gooooo1?l00003ooooo`;o00000oooool2o`0000?ooooo
0_l00002ooooo`Ko00005oooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o0000
6oooool2o`0000oooooo0_l0000hooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o
8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0>Oooool2o`0000?o
oooo0_l0000Cooooo`;o00003oooool2o`0000[ooooo5?l0000Cooooo`?o000000?oooooo`000?l0
00001Oooool4o`0000?ooooo0_l00003ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`;o
00005oooool2o`0000Wooooo1?l0000Gooooo`;o00000_ooool2o`0000?ooooo0_l0000;ooooo`;o
0000=oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0iooooo`;o000000?oooooo`000?l000001_ooool2o`00
00Oooooo0_l00004ooooo`;o00003_ooool4o`0000Kooooo5_l0000Dooooo`?o00003_ooool2o`00
03Gooooo0_l0000Cooooo`;o00001?ooool2o`0000Gooooo1?l0000;ooooo`;o0000=oooool00003
ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo00?o0000oooooooo
ool0<oooool2o`0000Oooooo0_l00006ooooo`;o00001oooool2o`00017ooooo0_l000000ooooooo
0000o`000002o`0000Gooooo5ol00003ooooo`;o00003?ooool2o`000005ooooool0003o0000o`00
0?ooool00_l00004ooooo`;o00001Oooool2o`000004ooooool0003o0000o`0002cooooo0_l00003
ooooo`;o00002oooool2o`0000Kooooo0_l0000;ooooo`;o0000A_ooool00003ooooool0003ooooo
00;ooooo00?o0000ooooooooool02Oooool01?m4A4CogMgMooooool00007ooooo`?o0000<oooool2
o`0002_ooooo0_l0000:ooooo`?o00000_ooool5o`0000?ooooo1ol00006ooooo`;o00003?ooool2
o`000003ooooool0003o000000;ooooo0_l00004ooooo`Co00001Oooool4o`0002cooooo0ol00006
ooooo`;o00001oooool2o`0001?ooooo0_l000000ooooooo0000o`000013ooooo`0000?oooooo`00
0?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000
ooooooooool0C?ooool3o`0001Wooooo0ol00002oooooaCo00005_ooool2o`0000Wooooo0ol00003
ooooo`Co00000_ooool2o`0002_ooooo0_l00006ooooo`?o000000?oooooo`000?l000003Oooool4
o`0000[ooooo0_l00008ooooo`;o0000>Oooool00003ooooool@413ooooo00;ooooo00?o410@oooo
ooooool02_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo03gooooo0_l0000=oooo
o`?o00002_ooool2o`0000Oooooo0_l00004ooooo`Co00000ooooolBo`00027ooooo2_l00002oooo
o`;o00004Oooool2o`00023ooooo0ol000000ooooooo0000o`000002o`0000_ooooo1?l0000<oooo
o`;o00001_ooool2o`0003Wooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^
odA4A?l000001oooool00ol0003oooooooooo`0mooooo`;o00004oooool2o`0000Gooooo0_l00007
ooooo`?o00001?ooool5o`0000;ooooo3ol0000Fooooo`;o00002Oooool3o`000003ooooool0003o
000000Oo00004oooool3o`000003ooooool0003o000002;ooooo0ol0000Dooooo`;o00001Oooool2
o`00047ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_oo
ool00ol0003oooooooooo`1Booooo`;o00001_ooool2o`0000Oooooo0_l00004ooooo`;o000000?o
ooooo`000?l000001?ooool7o`000003ooooool0003o000000;o00005oooool2o`0000Oooooo1_l0
0003ooooo`Ko00003Oooool2o`0000Cooooo0_l00002ooooo`;o00000_ooool4o`0001cooooo0_l0
00000ooooooo0000o`000002o`0000_ooooo0_l00003ooooo`;o0000B?ooool001cooooo00?o0000
ooooooooool0AOooool2o`0001?ooooo0_l00003ooooo`Ko00000oooool4o`0000Kooooo1?l00000
1?oooooo0000o`000?ooool2o`0001Cooooo0_l00002ooooo`?o00001oooool2o`0000;ooooo0_l0
0005ooooo`?o00000_ooool2o`0000Kooooo1_l0000<ooooo`Co00007oooool4o`0000_ooooo0_l0
000:ooooo`Co0000?oooool001cooooo00?o0000ooooooooool0>oooool2o`0000Sooooo0_l00004
ooooo`;o00004_ooool4o`0000;ooooo0_l000000ooooooo0000o`000002o`0000Oooooo0ol00004
ooooo`;o00005?ooool2o`0000;ooooo0_l0000Cooooo`Oo00000_ooool2o`000003ooooool0003o
000000?o00001Oooool4o`0002Sooooo0_l00007ooooo`;o00002oooool2o`0000?ooooo1?l0000o
ooooo`007?ooool00ol0003oooooooooo`0kooooo`;o00003?ooool4o`0000Kooooo0_l0000@oooo
o`;o00000_ooool2o`0000Oooooo1?l00004ooooo`;o00004_ooool2o`0001Gooooo0_l00002oooo
o`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000Oooooo1Ol00004oooo
o`;o00001_ooool2o`0000?ooooo0_l0000Jooooo`;o00000_ooool2o`0000_ooooo0_l00004oooo
o`;o0000@?ooool001cooooo00?o0000ooooooooool0BOooool2o`0000Sooooo0_l0000?ooooo`;o
00000oooool2o`0000;ooooo1ol0000Jooooo`;o00000_ooool2o`00017ooooo0_l00003ooooo`;o
00000oooool2o`0000Cooooo0ol00002ooooo`;o00000_ooool4o`0000Gooooo0_l00006ooooo`;o
00000oooool4o`0000_ooooo0_l0000;ooooo`;o00005Oooool2o`00043ooooo000Looooo`03o`00
0?oooooooooo06Cooooo0_l00007ooooo`So00007?ooool3o`0000cooooo0_l00008ooooo`;o0000
0_ooool4o`0000?ooooo0ol00002ooooo`?o00000_ooool3o`0001Cooooo0_l0000;ooooo`?o0000
2_ooool2o`0000kooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o00002ooo
ool2o`0000Wooooo0_l00002ooooo`;o00000_ooool4o`0000?ooooo0_l0000Gooooo`Co00002ooo
ool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo1Ol00008ooooo`;o0000
2?ooool2o`0000Sooooo1?l0000Aooooo`;o00006_ooool2o`0004Oooooo000Looooo`03o`000?oo
oooooooo03Sooooo0_l0000@ooooo`;o00001Oooool2o`0000_ooooo0ol00002ooooo`;o00001?oo
ool2o`0000;ooooo0_l00009ooooo`;o00005oooool4o`000003ooooool0003o000000Sooooo0_l0
0002ooooo`;o000000?oooooo`000?l000000ol00004ooooo`Co000000?oooooo`000?l000002?oo
ool2o`0000;ooooo1?l00008ooooo`Co0000;?ooool6o`0000Sooooo0_l0000jooooo`007?ooool0
0ol0003oooooooooo`0Yooooo`;o00003Oooool4o`0000kooooo0_l0000Cooooo`?o000000Cooooo
o`000?l0003ooooo1Ol00002ooooo`;o00000oooool2o`0000;ooooo1?l0000;ooooo`;o00002ooo
ool3o`000003ooooool0003o000000cooooo0_l00002ooooo`;o00000oooool2o`0000?ooooo1Ol0
0003ooooo`;o00000_ooool3o`0000;ooooo0_l00002ooooo`Go00000_ooool3o`0002Cooooo0_l0
0008ooooo`Oo00001oooool2o`0003[ooooo000Looooo`03o`000?oooooooooo02Wooooo0_l0000?
ooooo`;o00006Oooool2o`0000Oooooo3Ol00002ooooo`;o00000oooool3o`000003ooooool0003o
000000;o00002oooool2o`0000_ooooo0_l0000Cooooo`?o00000oooool2o`000004ooooool0003o
0000ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0ol00004ooooo`Oo000000?o
ooooo`000?l000000_l0000Cooooo`;o00001_ooool2o`0000Gooooo1?l00009ooooo`;o00000_oo
ool3o`0000Kooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00004_ooool2
o`0000Oooooo0_l00004ooooo`Ko000000?oooooo`000?l000001ol00002ooooo`;o00001?ooool2
o`0003;ooooo0ol00006ooooo`;o000000?oooooo`000?l000001?l000000ooooooo0000o`000002
ooooo`Go00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000004o`00017ooooo0_l00006
ooooo`;o00001Oooool2o`00013ooooo0_l00004ooooo`Co0000>_ooool001cooooo00?o0000oooo
ooooool0>?ooool2o`0001;ooooo0_l00003ooooo`;o00000_ooool2o`000004ooooool0003o0000
oooooa7o000000?oooooo`000?l000000_ooool2o`0003cooooo0_l00002ooooo`Ko000000?ooooo
o`000?l000000_ooool2o`000003ooooool0003o000000Cooooo0_l00003ooooo`co00002oooool2
o`0000kooooo0_l00007ooooo`;o00001oooool2o`0000Cooooo0ol00002ooooo`;o0000=oooool0
01cooooo0_l0000nooooo`;o00004_ooool2o`0000Gooooo0_l00002oooooa7o00001?ooool2o`00
01?ooooo0_l0000Uooooo`Ko000000?oooooo`000?l000000_l00002ooooo`Ko00001oooool2o`00
00?ooooo3_l000001?oooooo0000o`000?l00005ooooo`;o00003?ooool2o`0000Oooooo1?l00005
ooooo`Co00002?ooool3o`0003Oooooo000Looooo`03o`000?oooooooooo03?ooooo0_l00002oooo
o`;o00001?ooool2o`0001_ooooo4ol00006ooooo`;o00002?ooool2o`0000Oooooo0_l0000:oooo
o`;o00006Oooool6o`000003ooooool0003o000000;o00000_ooool5o`0000;ooooo0_l00005oooo
o`;o00000_ooool>o`000004ooooool0003o0000o`0000;ooooo1Ol0000:ooooo`Co00001oooool2
o`0000Oooooo0_l00003ooooo`;o00001Oooool3o`0003Oooooo000Looooo`03o`000?oooooooooo
03?ooooo0ol000000ooooooo0000o`00000QoooooaCo00001Oooool2o`0000?ooooo0_l00003oooo
o`;o00001oooool2o`0000[ooooo0_l0000;ooooo`;o00003?ooool4o`0000?ooooo0ol000000ooo
oooo0000o`000003ooooo`;o00000_ooool2o`0000Gooooo0_l000000ooooooo0000o`000005o`00
0003ooooool0003o000000?o00000oooool3o`0000;ooooo1?l00006ooooo`;o00000oooool4o`00
00Wooooo0_l00002ooooo`;o00001_ooool2o`0003oooooo000Looooo`03o`000?oooooooooo02oo
oooo0_l00003ooooo`;o000000?oooooo`000?l000004Oooool2o`0000[ooooo5Ol000001?oooooo
0000o`000?l00009ooooo`;o00000oooool2o`0001Gooooo0_l00009ooooo`;o00001_ooool2o`00
00Cooooo0ol00004ooooo`;o00000_ooool3o`0000;ooooo0_l00009oooooa7o00004Oooool2o`00
00Cooooo1Ol00007ooooo`Oo00003Oooool2o`0003Oooooo000Looooo`03o`000?oooooooooo02Ko
oooo0_l00007ooooo`;o00000oooool2o`000003ooooool0003o0000017ooooo0_l00008oooooaOo
00000_ooool2o`000003ooooool0003o000000Co000000?oooooo`000?l000001?ooool3o`0000Oo
oooo0_l00009ooooo`Co00004Oooool2o`000003ooooool0003o000000Go00000oooool4o`000003
ooooool0003o000000Co00002Oooool3o`000003ooooool0003o000000_o000000?oooooo`000?l0
00004_ooool9o`0000Kooooo2?l00006ooooo`;o00000_ooool3o`0003Oooooo000Looooo`03o`00
0?oooooooooo02Kooooo0_l0000Oooooo`;o00002_oooolHo`0000Gooooo1_l000000ooooooo0000
o`000003ooooo`Co00001Oooool4o`0000Oooooo1_l00009ooooo`;o00002Oooool7o`0000?ooooo
1_l000000ooooooo0000o`000002o`0000Oooooo1?l00002ooooo`go000000?oooooo`000?l00000
4?ooool6o`000003ooooool0003o000000;o00002?ooool2o`0000;ooooo0_l00006ooooo`;o0000
0_ooool2o`0003Sooooo000Looooo`03o`000?oooooooooo04Oooooo0_l0000:oooooaSo00000ooo
ool2o`0000cooooo0ol00006ooooo`;o00000oooool2o`0000?ooooo0ol0000=ooooo`;o00002ooo
ool3o`000003ooooool0003o000000Co00000_ooool2o`000004ooooool0003o0000o`0000Sooooo
0_l00006ooooo`_o000000?oooooo`000?l000004?ooool4o`000003ooooool0003o000000;o0000
2Oooool2o`0000;ooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`0Zooooo`;o0000:Ooo
oolEo`0000Cooooo0_l0000Gooooo`;o000000?oooooo`000?l000000oooool6o`0000;ooooo0_l0
00000ooooooo0000o`000008ooooo`;o000000Coooooo`000?l0003ooooo1Ol000000ooooooo0000
o`000004o`000003ooooool0003o000000;o00000_ooool2o`0000oooooo2ol000000ooooooo0000
o`00000@ooooo`;o00000oooool4o`0000Wooooo0_l00002ooooo`;o00002oooool2o`0003Sooooo
000Looooo`03o`000?oooooooooo02[ooooo0_l0000;ooooo`;o00007?oooolEo`0000Cooooo0_l0
0009ooooo`;o00002oooool3o`000004ooooool0003o0000ooooo`So00000_ooool2o`000003oooo
ool0003o000000Sooooo0_l000001?oooooo0000o`000?ooool5o`0000Gooooo0_l000000ooooooo
0000o`000003o`000003ooooool0003o000000_ooooo0_l00003ooooo`[o00000_ooool2o`000003
ooooool0003o0000017ooooo1?l0000:ooooo`?o00001Oooool2o`000003ooooool0003o000000;o
oooo0ol0000hooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00006ooooolDo`0000Kooooo
0_l00002ooooo`;o00001Oooool2o`0000;ooooo1ol00002ooooo`Ko000000Coooooo`000?l0003o
00005oooool2o`0000cooooo1ol0000<ooooo`Co00001?ooool9o`000005ooooool0003o0000o`00
0?ooool00_l0000@ooooo`Go00000oooool2o`0000Gooooo1Ol00003ooooo`;o000000?oooooo`00
0?l000000_ooool2o`0003Wooooo000Looooo`03o`000?oooooooooo04Cooooo0_l00003ooooo`;o
00001_ooool2o`000003ooooool0003o000001;o00001oooool2o`000003ooooool0003o000000?o
000000?oooooo`000?l000000oooool7o`0000;ooooo1?l0000Mooooo`;o00002?ooool2o`0000;o
oooo1Ol0000>ooooo`;o00001_ooool<o`0001Cooooo1_l00002ooooo`;o00000oooool2o`0000;o
oooo0ol00005ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0=Oooool2o`0000gooooo
0_l00003ooooo`;o00001_oooolGo`000003ooooool0003o000000?ooooo3?l00006ooooo`;o0000
1Oooool2o`0000Oooooo0_l00003ooooo`;o00004oooool2o`0000Gooooo0_l00003ooooo`;o0000
00?oooooo`000?l000005Oooool:o`0001Cooooo0_l00004ooooo`?o000000?oooooo`000?l00000
0oooool2o`0000[ooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0eooooo`;o00004_oo
ool3o`0000;ooooo0_l00003oooooaCo00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`00
0002o`000003ooooool0003o000000oooooo0_l00007ooooo`Co000000?oooooo`000?l000004ooo
ool2o`0000[ooooo1Ol0000Gooooo`Oo00003oooool2o`0000?ooooo0ol00004ooooo`?o00004_oo
ool2o`0003kooooo000Looooo`03o`000?oooooooooo04[ooooo0_l00002ooooo`;o000000?ooooo
o`000?l000004ol00005ooooo`;o00009?ooool3o`00017ooooo0_l0000;ooooo`;o00000oooool4
o`0001Gooooo2Ol0000<ooooo`;o000000?oooooo`000?l000000oooool2o`000003ooooool0003o
000000;ooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00008ooooolEo`00
00Gooooo0_l0000Oooooo`;o00000oooool2o`0001;ooooo0_l00004ooooo`;o00001Oooool4o`00
0003ooooool0003o000000Co00004?ooool2o`000005ooooool0003o0000o`000?ooool00_l00007
ooooo`;o00001_ooool5o`0000Kooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`0Roooo
o`;o00002?ooool2o`0002;ooooo5?l0000Xooooo`;o00002Oooool2o`0000kooooo0_l00002oooo
o`;o00001oooool2o`0000Gooooo0_l0000@ooooo`;o00001Oooool2o`0000Oooooo0_l00007oooo
o`;o00001Oooool2o`0000Cooooo0_l0001Dooooo`007?ooool2o`0002?ooooo0_l0000Mooooo`;o
00003Oooool5o`000003ooooool0003o000000[o00000_ooool2o`0001Cooooo1?l00007ooooo`?o
00003oooool2o`0000Gooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0ol0000>oooo
o`Co00004?ooool2o`0000cooooo0ol0000=ooooo`;o000000?oooooo`000?l000000ol0000Hoooo
o`;o0000>_ooool001cooooo00?o0000ooooooooool0@Oooool2o`0000_ooooo0ol000001Ooooooo
0000o`000?l0003ooooo013o00004oooool5o`0000Oooooo0ol0000Fooooo`;o00001?ooool2o`00
0004ooooool0003o0000ooooo`?o00002?ooool2o`0000Cooooo1?l00002ooooo`;o00003?ooool2
o`0000cooooo0ol0000?ooooo`Ko00002Oooool4o`0000_ooooo0_l0000jooooo`007?ooool00ol0
003oooooooooo`0aooooo`;o00004oooool4o`0000Cooooo0ol000001?oooooo0000o`000?ooool6
o`0000;ooooo1ol0000Eooooo`;o00002Oooool2o`00013ooooo0_l00006ooooo`;o00001oooool2
o`0000;ooooo0_l00008ooooo`;o00002_ooool2o`0001Gooooo1ol0000>ooooo`So00002?ooool5
o`0004Oooooo000Looooo`03o`000?oooooooooo02Oooooo1?l00006ooooo`;o00004oooool4o`00
00;ooooo1?l00005ooooo`;o00002?ooool2o`0001Oooooo0_l0000:ooooo`Co000000?oooooo`00
0?l000002Oooool4o`0000Kooooo0_l00005ooooo`;o00001?ooool2o`0000Sooooo0_l0000Loooo
o`;o00000oooool7o`0000kooooo0_l00003ooooo`?o00002?ooool2o`000004ooooool0003o0000
ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool09oooool4o`0001Kooooo0_l00005oooo
o`;o00000_ooool4o`000003ooooool0003o000000_ooooo0_l00008ooooo`;o00002Oooool2o`00
0003ooooool0003o000000;o00002oooool3o`000004ooooool0003o0000o`0000;ooooo0_l00004
ooooo`;o00003oooool2o`0000;ooooo0_l00009ooooo`;o00007Oooool2o`0000Gooooo1?l00002
ooooo`;o00004?ooool3o`0000cooooo1Ol00002ooooo`;o0000?oooool001cooooo00?o0000oooo
ooooool0:?ooool2o`0001Oooooo0ol00003ooooo`;o00001?ooool;o`0000Kooooo0_l00003oooo
o`;o00000_ooool3o`0000Wooooo0_l000000ooooooo0000o`00000Booooo`;o00000_ooool2o`00
00;ooooo0_l0000Eooooo`;o00002Oooool3o`0000Cooooo0ol00008ooooo`Co00005_ooool2o`00
00_ooooo1?l0000@ooooo`Go00000_ooool2o`0003oooooo000Looooo`03o`000?oooooooooo02co
oooo0_l0000Dooooo`;o00000_oooolBo`0000_ooooo0_l00002ooooo`Go00006_ooool2o`0000[o
oooo0ol0000Jooooo`Co00000_ooool3o`0000?ooooo1Ol00006ooooo`Co00003Oooool2o`0000Ko
oooo0_l00006ooooo`;o000000Coooooo`000?l0003ooooo1_l00008ooooo`Co00000oooool5o`00
0003ooooool0003o000000;o0000?Oooool001cooooo00?o0000ooooooooool0:Oooool2o`000003
ooooool0003o000001Sooooo0_l000000ooooooo0000o`000002o`000004ooooool0003o0000oooo
o`Oo00004Oooool3o`0001[ooooo0ol0000:ooooo`;o00006_ooool4o`0000?ooooo0_l00003oooo
o`;o000000?oooooo`000?l000005oooool2o`0000Kooooo0_l00005ooooo`?o000000Coooooo`00
0?l0003ooooo0ol000000ooooooo0000o`000004ooooo`;o00000_ooool4o`0000?ooooo1_l00002
ooooo`;o000000?oooooo`000?l00000>_ooool001cooooo00?o0000ooooooooool0:Oooool2o`00
023ooooo0_l000001?oooooo0000o`000?ooool3o`0003?ooooo0_l0000Kooooo`;o00002Oooool2
o`0000Gooooo0_l0000;ooooo`;o00006_ooool2o`0000Gooooo1?l00004ooooo`;o00001oooool2
o`0000gooooo0_l00003ooooo`Co0000>_ooool001cooooo00?o0000ooooooooool0BOooool4o`00
0004ooooool0003o0000ooooo`Go00003_ooool2o`0000_ooooo0_l00006ooooo`;o00006_ooool2
o`0000cooooo0ol0000@ooooo`;o00002oooool3o`0000kooooo0ol0000Aooooo`;o00001?ooool2
o`0000_ooooo0_l00007ooooo`Co00000oooool4o`0003[ooooo000Looooo`03o`000?oooooooooo
02Oooooo0_l0000Pooooo`;o00000oooool2o`0000Cooooo0_l000000ooooooo0000o`00000;oooo
o`;o00002?ooool2o`000003ooooool0003o000000Kooooo0ol00007ooooo`;o00004?ooool2o`00
00?ooooo0_l00007ooooo`;o00003?ooool4o`0000?ooooo0_l00005ooooo`;o00000oooool2o`00
00?ooooo0_l00004ooooo`;o00000oooool3o`0000?ooooo0_l0000<ooooo`;o00001?ooool2o`00
00;ooooo0_l00007ooooo`;o00001Oooool6o`00047ooooo000Looooo`03o`000?oooooooooo02Go
oooo1?l00007ooooo`;o00006_ooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l0
00000_l00009ooooo`;o00002?ooool4o`0000Oooooo0ol00007ooooo`;o00003?ooool2o`0000Oo
oooo0_l00002ooooo`;o00004Oooool4o`0000?ooooo0_l00005ooooo`;o00000_ooool2o`0000Co
oooo0_l00004ooooo`;o00002Oooool3o`0000_ooooo1?l00006ooooo`;o00003_ooool3o`0004Co
oooo000Looooo`03o`000?oooooooooo02Gooooo0_l00009ooooo`;o00003oooool2o`0000Wooooo
1_l00002ooooo`;o000000?oooooo`000?l000000_l00008ooooo`;o000000Coooooo`000?l0003o
oooo0_l00004ooooo`?o00001oooool2o`0000Gooooo0_l00005ooooo`;o00000oooool4o`000003
ooooool0003o000000;ooooo0_l00004ooooo`;o000000?oooooo`000?l000001?ooool2o`0000ko
oooo0ol00006ooooo`?o00000oooool2o`0000?ooooo0_l00007ooooo`Co00000_ooool3o`000003
ooooool0003o000000gooooo0_l0000<ooooo`Co00001oooool2o`0004Cooooo000Looooo`03o`00
0?oooooooooo02Wooooo1?l00002ooooo`;o00004?ooool4o`0000;ooooo2Ol00002ooooo`;o0000
0oooool2o`0000[ooooo0_l000000ooooooo0000o`000003o`0000Cooooo0_l0000?ooooo`;o0000
1Oooool3o`0000;ooooo1?l00004ooooo`?o00001?ooool2o`000003ooooool0003o000000Cooooo
0_l0000;ooooo`Ko00000oooool2o`000004ooooool0003o0000o`0000?ooooo0_l00003ooooo`;o
000000Coooooo`000?l0003ooooo1ol000000ooooooo0000o`000002o`0000kooooo0_l00009oooo
o`?o00000_ooool4o`0000Kooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`0Yooooo`Co
00000_ooool2o`0001;ooooo0_l00002ooooo`Oo00001?ooool2o`0000gooooo0_l00003ooooo`Co
00005_ooool2o`0000Kooooo0_l00004ooooo`Co000000Coooooo`000?l0003o00001Oooool2o`00
0005ooooool0003o0000o`000?ooool00_l00008ooooo`Co000000?oooooo`000?l000000_l00005
ooooo`;o00003oooool=o`00013ooooo0_l00009ooooo`?o00001_ooool2o`0000Cooooo0_l00015
ooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00001_ooool2o`0001Cooooo0_l00005oooo
o`;o00004oooool2o`000003ooooool0003o000000cooooo1ol00006ooooo`;o000000Goooooo`00
0?l0003o0000ooooo`03o`0000Oooooo1?l00002ooooo`;o00002oooool2o`0000[ooooo0ol00000
0ooooooo0000o`000006o`000003ooooool0003o000000;o00000_ooool3o`0001Wooooo1_l0000:
ooooo`;o0000?Oooool001cooooo0_l0000Vooooo`;o00007?ooool2o`0000Kooooo0_l00006oooo
o`;o00001Oooool2o`0000Gooooo0_l000000ooooooo0000o`000002ooooo`;o00004Oooool4o`00
00Oooooo0_l00009ooooo`;o00001oooool2o`0000;ooooo0_l00003ooooo`;o00001Oooool6o`00
0004ooooool0003o0000o`0000_ooooo0_l00008oooooa?o00000_ooool3o`000003ooooool0003o
000001Kooooo0_l00002ooooo`;o00002_ooool2o`0003gooooo000Looooo`03o`000?oooooooooo
02Gooooo0_l000000ooooooo0000o`00000Oooooo`;o00002?ooool2o`000003ooooool0003o0000
00;ooooo1?l00003ooooo`;o000000?oooooo`000?l000005Oooool3o`0000Kooooo1?l00008oooo
o`;o00001_ooool4o`000003ooooool0003o000000_ooooo0_l000000ooooooo0000o`000002oooo
o`;o00001_ooool2o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`[o00000_ooool:o`00
00?ooooo0_l000000ooooooo0000o`00001Uooooo`007?ooool00ol0003oooooooooo`0Xooooo`;o
00005oooool2o`0000Kooooo0_l0000;ooooo`?o000000?oooooo`000?l000000_l00005ooooo`;o
00004Oooool2o`0000?ooooo0ol00006ooooo`;o000000Coooooo`000?l0003o00000_ooool7o`00
00Gooooo0_l00003ooooo`;o00002Oooool4o`000003ooooool0003o000000[ooooo0_l000000ooo
oooo0000o`000002o`000003ooooool0003o000000?ooooo0ol000000ooooooo0000o`00000Ao`00
00;ooooo0_l0000Hooooo`;o00000oooool3o`0000Gooooo0_l00011ooooo`007?ooool00ol0003o
ooooooooo`11ooooo`?o00004oooool2o`000003ooooool0003o000000;ooooo0ol00002ooooo`;o
00001?ooool2o`0000_ooooo0_l00003ooooo`;o00001?ooool9o`0000;ooooo1?l000000ooooooo
0000o`000003ooooo`Co00000oooool2o`0000Gooooo1_l00006ooooo`;o00002Oooool3o`0000_o
oooo5Ol00005ooooo`;o00000oooool2o`0000oooooo0_l00003ooooo`?o00001Oooool2o`00047o
oooo000Looooo`03o`000?oooooooooo02Wooooo0_l0000Gooooo`;o00001?ooool5o`0000Kooooo
0_l00002ooooo`;o00001?ooool5o`000003ooooool0003o000000Cooooo1?l0000>ooooo`;o0000
1?ooool7o`0000Gooooo0ol000000ooooooo0000o`000003ooooo`;o00000_ooool3o`0000Oooooo
1Ol00007ooooo`Co00001_ooool5o`0000Gooooo0_l000000ooooooo0000o`00000Fo`000003oooo
ool0003o000000Wo00000oooool3o`0000[ooooo0_l0001<ooooo`007?ooool00ol0003ooooooooo
o`0Tooooo`;o00000oooool2o`0001gooooo1_l00005ooooo`?o000000?oooooo`000?l000001?oo
ool5o`000003ooooool0003o000000Kooooo0_l00005ooooo`;o00002?ooool4o`000003ooooool0
003o000000oo00000oooool4o`000004ooooool0003o0000o`0000Oooooo0ol00008ooooo`Go0000
1_ooool2o`000003ooooool0003o000000Gooooo7ol000000ooooooo0000o`000005o`0000?ooooo
0ol00007ooooo`;o000000?oooooo`000?l00000C?ooool001cooooo00?o0000ooooooooool09?oo
ool2o`0001gooooo0_l00007ooooo`;o000000?oooooo`000?l000000oooool2o`0000Sooooo1?l0
0007ooooo`?o00001_ooool2o`0000Sooooo1?l000000ooooooo0000o`000003o`000003ooooool0
003o000000[o000000?oooooo`000?l000000ol000000ooooooo0000o`000002o`000003ooooool0
003o000000Cooooo0ol00007ooooo`;o00005Oooool>o`000003ooooool0003o000000_o00001?oo
ool2o`0000oooooo0ol0000:ooooo`;o00000_ooool2o`0003oooooo000Looooo`03o`000?oooooo
oooo02gooooo0_l0000Dooooo`?o00001?ooool2o`0000?ooooo0_l0000>ooooo`?o00001oooool3
o`0000cooooo0ol00006ooooo`?o00001_ooool5o`0000;ooooo1_l00002ooooo`Wo00000oooool6
o`0000;ooooo1_l000000ooooooo0000o`000006ooooo`;o00001OoooolFo`0000;ooooo2?l00002
ooooo`?o00002?ooool2o`0000Gooooo0ol00002ooooo`;o00001_ooool2o`0000;ooooo0_l0000o
ooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o00005Oooool2o`0000;ooooo1?l00003oooo
o`;o00003_ooool4o`0000kooooo0_l00004ooooo`Co000000?oooooo`000?l000002Oooool2o`00
0003ooooool0003o000000_o000000?oooooo`000?l000000_l00002ooooo`Co00001_ooool4o`00
0004ooooool0003o0000ooooo`?o000000?oooooo`000?l000001_ooool2o`0000Cooooo8Ol00002
ooooo`;o00002Oooool2o`0000;ooooo1?l00004ooooo`;o000000?oooooo`000?l00000B?ooool0
01cooooo00?o0000ooooooooool09Oooool2o`00027ooooo0_l00004ooooo`?o00004?ooool5o`00
00_ooooo2Ol00002ooooo`;o00001ooooolBo`000003ooooool0003o000000?ooooo1ol00002oooo
o`;o00000_ooool2o`00013ooooo0_l00004ooooob?o00003?ooool2o`000003ooooool0003o0000
00Ko00000oooool4o`0004Kooooo000Looooo`03o`000?oooooooooo02Gooooo0_l00006ooooo`;o
00006_ooool2o`0000;ooooo0ol0000@ooooo`;o000000Coooooo`000?l0003o00003?ooool8o`00
00Wooooo5Ol00005ooooo`Co000000?oooooo`000?l000000_ooool2o`00013ooooo0_l000000ooo
oooo0000o`000006ooooob?o00002Oooool=o`0000Gooooo0_l00016ooooo`007?ooool00ol0003o
ooooooooo`0Wooooo`;o00001?ooool2o`0001[ooooo0_l00002ooooo`;o00000_ooool2o`0000go
oooo0_l000001?oooooo0000o`000?ooool2o`0000_ooooo1Ol0000:ooooo`?o000000?oooooo`00
0?l000004ol00002ooooo`;o000000?oooooo`000?l000001ol0000?ooooo`Go00001_ooool2o`00
0003ooooool0003o000001Wo000000?oooooo`000?l000001?l00007ooooo`;o00000_ooool2o`00
00;ooooo0_l000000ooooooo0000o`00001=ooooo`007?ooool00ol0003oooooooooo`0Wooooo`;o
00008_ooool3o`0000?ooooo0_l000000ooooooo0000o`00000@ooooo`;o000000?oooooo`000?l0
00001Oooool2o`000003ooooool0003o000000?o000000?oooooo`000?l000001?oooolDo`000003
ooooool0003o000000Go00000_ooool2o`000003ooooool0003o000000Oo00004Oooool3o`0000Go
oooo7ol000001Ooooooo0000o`000?l0003ooooo00;o00002_ooool2o`0000gooooo0_l00016oooo
o`007?ooool00ol0003oooooooooo`0Oooooo`;o0000:_ooool3o`0000Kooooo0_l00005ooooo`;o
00001Oooool3o`0000Cooooo0_l000001Ooooooo0000o`000?l0003ooooo00Go00001?ooool3o`00
00?ooooo6ol00005ooooo`Oo00006ooooolPo`000004ooooool0003o0000o`0000?ooooo0_l00008
ooooo`;o00003Oooool2o`0004Kooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ
8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0Oooooo`;o0000
;?ooool2o`0000cooooo0_l00004ooooo`Oo00001?ooool4o`0000;ooooo0_l000000ooooooo0000
o`000003ooooo`;o00001?oooolDo`000003ooooool0003o000000?o000000?oooooo`000?l00000
0_ooool3o`000003ooooool0003o000000;o00006_ooool2o`000003ooooool0003o000000_o0000
00?oooooo`000?l000003Ol00003ooooo`;o00000_ooool2o`000003ooooool0003o000001Kooooo
0_l00014ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGo
MgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0COooool3o`0000;ooooo0_l0000;oooo
o`Co00000_ooool3o`0000Kooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l00004
oooooaco000000?oooooo`000?l000000_ooool3o`000003ooooool0003o000000;o000000Cooooo
o`000?l0003ooooo0_l0000<ooooo`;o000000?oooooo`000?l000001?ooool5o`0000;ooooo6Ol0
0002ooooo`?o00001?ooool2o`0001Kooooo0_l00014ooooo`0000?ooooooa0@4?ooool00_ooool0
0ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`1;ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Kooooo0_l00003ooooo`Go00001?oo
ool2o`0000Sooooo1?l00002ooooo`;o00000_ooool4o`000004ooooool0003o0000oooooaGo0000
00Goooooo`000?l0003o0000ooooo`07o`0000?ooooo0_l000000ooooooo0000o`000002o`0000[o
oooo1Ol00004ooooo`Ko000000?oooooo`000?l000005ol00003ooooo`;o00002?ooool2o`0000co
oooo0_l0001:ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`00
0?nHV9SooooooiRHV?lQ8B401_ooool3o`0002Kooooo0_l0000:ooooo`;o00005oooool2o`0000go
oooo1?l00003ooooo`Ko000000?oooooo`000?l000000oooool6o`000003ooooool0003o000000Ko
oooo:?l000001?oooooo0000o`000?l00005ooooo`;o00001?ooool2o`000003ooooool0003o0000
00?ooooo0_l00005oooooaoo00000_ooool2o`0000[ooooo0_l00007ooooo`;o00000oooool2o`00
04[ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oeEEEOl0
003o410@olc<c006ooooo`03o`000?oooooooooo02Kooooo0_l0000:ooooo`;o00004_ooool2o`00
00Kooooo0ol0000;ooooo`;o00001Oooool4o`0000Kooooo1_l000000ooooooo0000o`000004o`00
00;ooooo8ol000000ooooooo0000o`000008o`0000;ooooo0_l00005ooooo`;o000000?oooooo`00
0?l000002?ooool6o`0000;ooooo0ol000000ooooooo0000o`000005o`000003ooooool0003o0000
00_o00000_ooool2o`000005ooooool0003o0000o`000?ooool00_l00003ooooo`;o00001Oooool4
o`0000?ooooo0_l0001:ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09oooo
o`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0A_ooool2o`000003ooooool0003o0000
00?ooooo0ol0000Dooooo`?o00001oooool2o`0000Gooooo2_l00002ooooobSo00000_ooool2o`00
01;ooooo1?l00003oooooaKo000000Coooooo`000?l0003o00001Oooool3o`000003ooooool0003o
000000[ooooo0_l00005ooooo`;o00001?ooool2o`0004Cooooo00001_ooooooMgMgoiRHV?oooooo
V9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`19ooooo`;o00001Ooo
ool2o`0001Cooooo0_l00005ooooo`Co000000?oooooo`000?l000001_ooool4o`0000;ooooo9Ol0
00000ooooooo0000o`000003o`0000_ooooo0_l0000>ooooob3o00002oooool3o`0000gooooo1?l0
0014ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co0000oa0@40Ko
oooo00?o0000ooooooooool0B?ooool2o`0000Kooooo0_l00007ooooo`;o00004_ooool3o`0000;o
oooo0_l00006ooooo`Co00000_oooolVo`000003ooooool0003o000000?o00002_ooool2o`0000Co
oooo0_l000000ooooooo0000o`000005ooooo`;o00000oooool7o`000003ooooool0003o0000017o
00002oooool3o`0000Gooooo0_l00006ooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0
:?ooool2o`0001kooooo0_l000000ooooooo0000o`000003ooooo`;o00001?ooool2o`000003oooo
ool0003o000000[ooooo1?l0000Aooooo`;o000000Coooooo`000?l0003ooooo9ol00003ooooo`;o
00004?ooool2o`000004ooooool0003o0000o`0000Wooooo1?l000001?oooooo0000o`000?oooolC
o`0000_ooooo0_l00005ooooo`?o0000C_ooool001cooooo00?o0000ooooooooool0:?ooool2o`00
027ooooo0_l00007ooooo`Co00001Oooool2o`0000Kooooo1?l00006ooooo`;o000000?oooooo`00
0?l000000_l00007ooooo`;o000000?oooooo`000?l000008_l000000ooooooo0000o`00000Aoooo
o`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o00000oooool2o`00
0004ooooool0003o0000o`0000;ooooo4_l000000ooooooo0000o`000007ooooo`;o00000_ooool2
o`000003ooooool0003o000000Co00002Oooool2o`00043ooooo000Looooo`03o`000?oooooooooo
04_ooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`00
013ooooo1ol0000:ooooo`Oo000000?oooooo`000?l000007_l00005ooooo`;o00002?ooool3o`00
00;ooooo0_l00004ooooo`?o00000oooool2o`0000Gooooo4Ol00002ooooo`Go000000?oooooo`00
0?l000002oooool3o`000003ooooool0003o000000?o00002Oooool3o`0003oooooo000Looooo`03
o`000?oooooooooo053ooooo1?l00004ooooo`;o000000Coooooo`000?l0003o00003oooool2o`00
0005ooooool0003o0000o`000?ooool00_l00005ooooo`;o00000ooooolYo`0000Cooooo0_l00008
ooooo`;o00002Oooool4o`0000Wooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o
000000Ko00000_ooool2o`000003ooooool0003o000000oooooo0ol000000ooooooo0000o`00000=
ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0B_ooool2o`0000Gooooo0ol00009oooo
o`;o00002_ooool2o`0000;ooooo0_l00002ooooo`;o00002?ooool2o`000003ooooool0003o0000
01Ko000000?oooooo`000?l000004?l0000Hooooo`;o000000?oooooo`000?l000003Oooool6o`00
0003ooooool0003o000000?o000000Goooooo`000?l0003o0000ooooo`04o`000003ooooool0003o
000000?ooooo0_l00005ooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0>Oooool2o`00
00oooooo0_l00003ooooo`Go00001_ooool5o`0000[ooooo0_l00006ooooo`;o00000_ooool2o`00
00Cooooo0_l000000ooooooo0000o`00000Wo`00013ooooo0_l00007ooooo`?o000000?oooooo`00
0?l000001_ooool2o`0000?ooooo0_l000000ooooooo0000o`000003o`0000?ooooo0_l00002oooo
o`;o00001?ooool2o`000003ooooool0003o000000?ooooo0_l00003ooooo`;o000000?oooooo`00
0?l00000DOooool001cooooo00?o0000ooooooooool0:oooool2o`0000cooooo0_l0000Dooooo`Go
00001?ooool5o`0000cooooo0_l0000:ooooo`;o00000oooool8o`000003ooooool0003o000002Ko
00002oooool3o`0000Oooooo0_l000000ooooooo0000o`000007ooooo`;o00000oooool2o`0000Ko
oooo0_l00006ooooo`Ko00000_ooool2o`0000Sooooo0_l000000ooooooo0000o`00000;ooooo`;o
0000A?ooool001cooooo00?o0000ooooooooool0:oooool2o`0001gooooo0_l00004ooooo`Co0000
00Coooooo`000?l0003ooooo1Ol00003ooooo`;o00001oooool2o`0000oooooo7ol000000ooooooo
0000o`000005o`000003ooooool0003o000000Oo00001oooool2o`000004ooooool0003o0000o`00
00?ooooo0_l000000ooooooo0000o`000003ooooo`;o00000_ooool2o`0000Oooooo0_l00006oooo
o`?o00001_ooool6o`0000oooooo0_l00007ooooo`;o00000_ooool2o`0004Cooooo000Looooo`03
o`000?oooooooooo04[ooooo0_l00005ooooo`;o00000_ooool2o`0000Cooooo0_l00003ooooo`;o
00001_ooool3o`0001;ooooo8ol00005ooooo`;o000000?oooooo`000?l000001Oooool8o`0000Co
oooo0_l000000ooooooo0000o`000007ooooo`;o00001oooool2o`0000?ooooo0_l000001?oooooo
0000o`000?l00007ooooo`;o000000?oooooo`000?l000006?ooool2o`0004Sooooo000Looooo`03
o`000?oooooooooo04oooooo1?l0000Eooooo`?o00004_oooolSo`000003ooooool0003o000000Co
00001_ooool5o`0000;ooooo0_l0000Oooooo`;o000000?oooooo`000?l000002?ooool2o`0006Go
oooo000Looooo`03o`000?oooooooooo03_ooooo0_l0000?ooooo`Go00005oooool3o`0000kooooo
0_l00005ooooobKo00001Oooool4o`0000Cooooo0_l00005ooooo`;o0000SOooool001cooooo0_l0
000looooo`;o00003oooool5o`0000Kooooo0ol000000ooooooo0000o`00000;ooooo`?o00003_oo
ool2o`0000;ooooo0_l00002ooooobGo00001Oooool5o`0000?ooooo0_l00005ooooo`;o0000?ooo
ool2o`0004cooooo000Looooo`03o`000?oooooooooo03_ooooo0_l0000?ooooo`;o000000?ooooo
o`000?l000001_ooool3o`000003ooooool0003o000000_ooooo0ol000000ooooooo0000o`00000?
ooooo`?o00000oooool<o`000003ooooool0003o000001?o00000_ooool9o`0000Kooooo0_l0000R
ooooo`?o00007_ooool2o`0004cooooo000Looooo`03o`000?oooooooooo04cooooo1ol0000?oooo
o`;o00002?ooool2o`00013ooooo0_l00002ooooo`Wo000000?oooooo`000?l000004ol000000ooo
oooo0000o`000002o`000003ooooool0003o000000;o00000_ooool2o`0000Oooooo0_l00006oooo
o`;o00005Oooool2o`0000;ooooo1?l0000>ooooo`;o00000_ooool2o`0000Kooooo0ol0001?oooo
o`007?ooool00ol0003oooooooooo`0mooooo`;o00003oooool2o`000004ooooool0003o0000oooo
o`;o000000?oooooo`000?l000002Oooool2o`0000Cooooo0_l0000:ooooo`;o00002_oooolAo`00
0003ooooool0003o000000?o00000_ooool9o`0000;ooooo0_l00002ooooo`Co00004_ooool2o`00
00Gooooo0_l00003ooooo`;o00002Oooool2o`0000;ooooo0_l0000>ooooo`Co00000_ooool2o`00
00Gooooo1?l00002ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0;oooool2o`0000co
oooo0_l0000<ooooo`;o000000Coooooo`000?l0003o00000oooool2o`000003ooooool0003o0000
00oooooo0_l00003ooooo`;o00001Oooool2o`0000[ooooo0_l00002oooooaSo000000?oooooo`00
0?l000000ol00008ooooo`;o00002Oooool2o`0000kooooo0ol00002ooooo`;o00000_ooool2o`00
01Wooooo0_l0000:ooooo`?o00001?ooool2o`0004_ooooo000Looooo`03o`000?oooooooooo02oo
oooo0_l0000Jooooo`;o000000Coooooo`000?l0003o00001_ooool2o`0000[ooooo0_l00008oooo
o`;o00005_oooolGo`000003ooooool0003o000000Co00004_ooool2o`0000Cooooo0_l00009oooo
o`;o00001_ooool2o`000004ooooool0003o0000o`0001Cooooo0_l00003ooooo`;o00001?ooool4
o`0000Gooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00007?ooool2o`00
00Oooooo0_l0000:ooooo`Co00004_ooool2o`0000?ooooo0_l00005oooooaKo00000_ooool2o`00
00;ooooo0_l00002ooooo`;o00005?ooool2o`0001Cooooo0ol0000Dooooo`;o00000oooool2o`00
00;ooooo1Ol0001Cooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o000000?oooooo`000?l0
0000<?ooool2o`0000Oooooo0_l00003ooooo`;o00001?ooool2o`0000?ooooo0_l00005oooooaKo
00002_ooool2o`0000[ooooo0_l00008ooooo`;o00000oooool2o`00023ooooo0_l00006ooooo`?o
00000oooool4o`0000;ooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`0cooooo`;o0000
6Oooool2o`0001kooooo0ol00002ooooo`;o00002?ooool2o`0000;ooooo0ol000000ooooooo0000
o`00000Do`0000Cooooo0_l00002ooooo`;o00002oooool3o`0000Oooooo0ol00003ooooo`;o0000
6Oooool3o`0000Cooooo0_l00006ooooo`Co000000Coooooo`000?l0003o00000oooool3o`0000[o
oooo0_l00015ooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o00007oooool2o`0000cooooo
0_l00002ooooo`Oo000000?oooooo`000?l000004Ol00003ooooo`;o000000Coooooo`000?l0003o
00002oooool2o`0000;ooooo0_l00004ooooo`;o00007oooool3o`0000kooooo0_l000000ooooooo
0000o`000004ooooo`;o00002oooool2o`0004Gooooo000Looooo`03o`000?oooooooooo04_ooooo
0_l00002ooooo`Co00006oooool2o`0000kooooo0_l00003ooooo`Go000000?oooooo`000?l00000
1Ol00005ooooo`Oo00001_ooool3o`0000Sooooo0ol00004ooooo`;o0000<Oooool2o`00063ooooo
000Looooo`03o`000?oooooooooo04;ooooo0_l00007ooooo`;o000000?oooooo`000?l000001?l0
000Jooooo`;o00003_ooool2o`0000Cooooo0ol00002ooooo`;o00000_ooool3o`000003ooooool0
003o000000;ooooo1Ol00007ooooo`Co000000?oooooo`000?l000000oooool5o`0000;ooooo0_l0
0003ooooo`;o0000;_ooool2o`00063ooooo000Looooo`03o`000?oooooooooo04;ooooo0ol00009
ooooo`Ko000000?oooooo`000?l000004_ooool2o`0000Kooooo0_l0000;ooooo`;o00001Oooool2
o`0000;ooooo0_l00006ooooo`Oo00002?ooool3o`0000?ooooo0_l00003ooooo`;o000000?ooooo
o`000?l000000_ooool2o`0000?ooooo0_l0000iooooo`;o0000EOooool001cooooo00?o0000oooo
ooooool0@oooool2o`0000gooooo1Ol0000Booooo`;o00000oooool2o`000003ooooool0003o0000
01_ooooo0_l00003ooooo`;o00001_ooool2o`000003ooooool0003o000000Co0000=Oooool3o`00
00;ooooo0_l0000Booooo`;o0000EOooool001cooooo00?o0000ooooooooool0Doooool2o`0001Wo
oooo0_l0000?ooooo`;o00000_ooool2o`000003ooooool0003o000000Kooooo0_l00006ooooo`Co
000000Coooooo`000?l0003ooooo1_l0000eooooo`?o00000_ooool2o`00013ooooo0_l0001Goooo
o`007?ooool00ol0003oooooooooo`1oooooo`;o00000_ooool2o`000003ooooool0003o000000;o
oooo0_l00003ooooo`;o000000Goooooo`000?l0003o0000ooooo`06o`0000;ooooo1?l00005oooo
o`;o00002oooool2o`0000Wooooo0_l0000Mooooo`?o00003oooool2o`0005Oooooo000Looooo`;o
0000Aoooool2o`0002cooooo0_l0000;ooooo`?o00001_ooool2o`000003ooooool0003o000000;o
000000?oooooo`000?l000000ol000000ooooooo0000o`000002o`000003ooooool0003o000000Co
00001?ooool2o`0000_ooooo0_l00009ooooo`;o00007Oooool3o`0000?ooooo0_l00004ooooo`;o
0000GOooool001cooooo00?o0000ooooooooool0=oooool2o`0000gooooo0_l0000Fooooo`;o0000
1Oooool3o`000003ooooool0003o000000Wooooo0_l0000;ooooo`?o00002Oooool2o`0000Kooooo
0_l00002ooooo`?o000000Coooooo`000?l0003ooooo0ol00008ooooo`;o00004Oooool2o`0001oo
oooo0_l00003ooooo`;o00001?ooool2o`0000Cooooo0_l0001Gooooo`007?ooool00ol0003ooooo
ooooo`0gooooo`;o00003_ooool2o`0000[ooooo0_l00004ooooo`;o00000oooool2o`0000Gooooo
0ol000000ooooooo0000o`000002ooooo`;o00001Oooool3o`0001cooooo0_l00004ooooo`?o0000
1Oooool2o`000003ooooool0003o000000Gooooo0_l0000@ooooo`?o00008Oooool2o`0000gooooo
0_l0001Gooooo`007?ooool00ol0003oooooooooo`17ooooo`;o00002_ooool2o`0000Cooooo0_l0
0009ooooo`;o00001oooool2o`0000Cooooo1?l000000ooooooo0000o`00000Cooooo`?o00000ooo
ool2o`0000Gooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l00009ooooo`;o0000
1Oooool2o`0000Gooooo0_l0000Looooo`co0000H_ooool001cooooo00?o0000ooooooooool0H?oo
ool2o`0000;ooooo0_l00005ooooo`;o00001_ooool2o`0000;ooooo0ol0000Cooooo`?o00003Ooo
ool3o`0000?ooooo0_l0000:ooooo`;o00001Oooool2o`0001oooooo0_l00002ooooo`co0000H_oo
ool001cooooo00?o0000ooooooooool0B?ooool2o`0001Kooooo0_l00009ooooo`;o00001Oooool2
o`0000;ooooo1Ol0000:ooooo`;o00001Oooool4o`000004ooooool0003o0000o`0000Wooooo0ol0
0003ooooo`;o00000_ooool2o`0002kooooo0_l00004ooooo`;o00000_ooool5o`0000Oooooo0_l0
001Jooooo`007?ooool00ol0003oooooooooo`18ooooo`?o00008Oooool2o`0000Cooooo0_l00002
ooooo`;o000000?oooooo`000?l000002_ooool4o`0000?ooooo0ol00002ooooo`Co000000?ooooo
o`000?l000001_ooool2o`0000?ooooo0_l00002ooooo`;o0000;_ooool2o`0000Cooooo0_l00002
ooooo`;o000000?oooooo`000?l000001oooool2o`0000Gooooo0_l0001Cooooo`007?ooool00ol0
003oooooooooo`19ooooo`;o00003_ooool2o`00017ooooo0_l00006ooooo`;o00000oooool2o`00
00Oooooo0_l00003ooooo`?o00000oooool3o`000003ooooool0003o000000;o000000?oooooo`00
0?l000002oooool2o`0000;ooooo0_l000000ooooooo0000o`00000?ooooo`;o00005oooool3o`00
00Kooooo0_l0000<ooooo`;o00001oooool2o`0005?ooooo000Looooo`03o`000?oooooooooo05Wo
oooo0_l00009ooooo`;o00003_ooool2o`0000cooooo0_l00004ooooo`;o00000oooool3o`0001Co
oooo0_l00004ooooo`;o00003oooool2o`0001Oooooo1ol00002ooooo`;o00002?ooool2o`0000;o
oooo0_l0001Looooo`007?ooool00ol0003oooooooooo`1Eooooo`;o00003Oooool2o`00023ooooo
0_l0000Booooo`;o00002?ooool2o`00037ooooo2?l00008ooooo`;o0000H?ooool001cooooo00?o
0000ooooooooool0EOooool3o`0000?ooooo0_l000000ooooooo0000o`00000Fooooo`?o00000_oo
ool4o`0000Oooooo0_l0000@ooooo`Co00002_ooool2o`0003;ooooo1?l00004ooooo`;o0000IOoo
ool001cooooo00?o0000ooooooooool0E_ooool2o`0000?ooooo1Ol0000Fooooo`?o00000_ooool4
o`0000Oooooo0_l00006ooooo`;o00002?ooool2o`0000_ooooo0ol0000Booooo`;o00007_ooool2
o`0000Kooooo0_l0001Uooooo`007?ooool00ol0003oooooooooo`1Looooo`?o00004_ooool2o`00
00Cooooo0_l00006ooooo`?o00003?ooool4o`0000kooooo0_l00002ooooo`?o00003?ooool2o`00
00Gooooo0_l0002=ooooo`007?ooool00ol0003oooooooooo`1Jooooo`;o000000Coooooo`000?l0
003o00002oooool2o`000004ooooool0003o0000ooooo`;o00003?ooool3o`0000cooooo1ol0000;
ooooo`;o00000_ooool2o`0000Kooooo0ol00003ooooo`Go00009?ooool2o`000003ooooool0003o
000006Wooooo000Looooo`03o`000?oooooooooo05[ooooo0_l00002ooooo`;o00002oooool2o`00
0004ooooool0003o0000ooooo`;o00003Oooool2o`0000gooooo0_l000000ooooooo0000o`000002
o`0000Gooooo1?l00008ooooo`;o000000?oooooo`000?l000000ol00003ooooo`;o000000?ooooo
o`000?l000000_ooool2o`00023ooooo0_l000000ooooooo0000o`00001Yooooo`007?ooool00ol0
003oooooooooo`1Zooooo`;o00003_ooool2o`000003ooooool0003o000001?ooooo1?l00002oooo
o`;o000000?oooooo`000?l000001ol00003ooooo`;o000000?oooooo`000?l000001?ooool2o`00
00Oooooo0_l0000Pooooo`Co0000J_ooool001cooooo0_l0001[ooooo`;o00003_ooool5o`0001?o
oooo1Ol000001Ooooooo0000o`000?l0003ooooo00So00003?ooool2o`0001cooooo0_l00004oooo
o`?o00001?ooool4o`0006[ooooo000Looooo`03o`000?oooooooooo063ooooo0_l0000Booooo`;o
00001_ooool2o`0000_ooooo0_l00007ooooo`Go00000_ooool2o`0000Oooooo1_l0000=ooooo`?o
00005?ooool4o`0000Cooooo0ol0001booooo`007?ooool00ol0003oooooooooo`1Pooooo`;o0000
3Oooool9o`0000[ooooo0ol00004ooooo`;o00006Oooool4o`0000Cooooo0_l00007ooooo`?o0000
5?ooool2o`0000_ooooo0_l0001^ooooo`007?ooool00ol0003oooooooooo`1Qooooo`;o00001Ooo
ool2o`0000Gooooo1Ol000001?oooooo0000o`000?l0000:ooooo`?o00004oooool3o`0000?ooooo
0_l00006ooooo`;o00001?ooool2o`0002_ooooo0_l0000;ooooo`;o0000HOooool001cooooo00?o
0000ooooooooool0HOooool2o`0000Gooooo0_l0000;ooooo`;o00003_ooool4o`0000Gooooo0_l0
0003ooooo`;o00000oooool4o`0000;ooooo0_l00006ooooo`;o0000;_ooool2o`0000kooooo0_l0
001Qooooo`007?ooool00ol0003oooooooooo`1cooooo`;o00004?ooool6o`0000?ooooo0_l00003
ooooo`;o00001Oooool2o`0000kooooo1?l0000Rooooo`;o00001?ooool2o`00077ooooo000Loooo
o`03o`000?oooooooooo04Sooooo0_l0000Yooooo`;o00001Oooool2o`0000Sooooo1?l000000ooo
oooo0000o`000002ooooo`;o00002_ooool2o`0000Oooooo0_l00006ooooo`Co00008?ooool4o`00
0003ooooool0003o000000Gooooo0_l00005ooooo`;o0000I_ooool001cooooo00?o0000oooooooo
ool0B?ooool2o`00027ooooo0_l0000=ooooo`;o00002?ooool4o`0000Gooooo0_l0000:ooooo`;o
00001oooool2o`0002?ooooo0_l00005ooooo`;o00000_ooool3o`0000Gooooo0_l00005ooooo`;o
0000I_ooool001cooooo00?o0000ooooooooool0Joooool3o`0000?ooooo0_l0000Eooooo`;o0000
7_ooool2o`000003ooooool0003o000001[ooooo0_l00009ooooo`;o0000MOooool001cooooo00?o
0000ooooooooool0Joooool3o`0000?ooooo0_l0000?ooooo`;o000000Coooooo`000?l0003ooooo
1?l0000:ooooo`;o00000_ooool2o`0000Sooooo0_l00002ooooo`;o000000?oooooo`000?l00000
7_ooool2o`0000;ooooo0_l0001hooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o0000:ooo
ool2o`0000Oooooo0_l000000ooooooo0000o`000003ooooo`;o00002_ooool2o`0000;ooooo0_l0
0008ooooo`?o00009?ooool2o`0000;ooooo0_l00005ooooo`;o0000LOooool001cooooo00?o0000
ooooooooool0C?ooool2o`00027ooooo0_l00008ooooo`;o00002Oooool3o`0000?ooooo0_l00004
ooooo`;o00002?ooool3o`0000Sooooo0_l0000_ooooo`;o0000LOooool001cooooo00?o0000oooo
ooooool0Koooool2o`00013ooooo0_l000001?oooooo0000o`000?l00009ooooo`;o00002Oooool2
o`0000kooooo0_l0000@ooooo`;o00000_ooool2o`0000Kooooo0_l0000?ooooo`;o0000KOooool0
01cooooo00?o0000ooooooooool0LOooool2o`0000kooooo0_l00004ooooo`;o00001oooool2o`00
0003ooooool0003o000000_ooooo0_l00005ooooo`;o000000Coooooo`000?l0003o00003?ooool2
o`0000;ooooo0_l00002ooooo`;o00001_ooool2o`0000oooooo0_l0001]ooooo`0000Koooooonk^
k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo
00?o0000ooooooooool0LOooool2o`000003ooooool0003o000000[ooooo0_l00005ooooo`;o0000
2_ooool2o`0000_ooooo0_l00003ooooo`Co000000?oooooo`000?l000003Oooool2o`0001;ooooo
0_l0001jooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7o
V9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0M?ooool2o`0000Wooooo0ol0000Aoooo
o`;o000000?oooooo`000?l000003Oooool2o`0001gooooo0ol00006ooooo`;o00001oooool2o`00
077ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo07oooooo0_l00002ooooo`;o00001Oooool3o`00
00Gooooo0_l00002ooooo`;o0000;?ooool3o`0000Oooooo0_l00006ooooo`;o0000LOooool00003
ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Olb<S;oV9RHoooooonHV9So<S8b
00Kooooo0ol0001oooooo`;o00000_ooool3o`0000Cooooo1?l00004ooooo`Co00006oooool2o`00
01_ooooo0_l000000ooooooo0000o`00001fooooo`0000?oooooo`000?ooool00_ooool00ol0003o
ooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`1Foooo
o`;o00009oooool2o`0000?ooooo0_l00006ooooo`?o00001Oooool4o`0001Wooooo0_l00004oooo
o`;o00006?ooool2o`0007Kooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wo
oooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo05Kooooo0_l0000Toooo
o`;o00000_ooool3o`0000[ooooo1_l00003ooooo`;o00001_ooool2o`000003ooooool0003o0000
00Cooooo0_l00008ooooo`;o00001?ooool2o`00093ooooo00001_ooooooMgMgoiRHV?ooooooV9RH
ogMgM`_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo05Sooooo0_l0
000Rooooo`;o00000_ooool5o`0000[ooooo1_l000000ooooooo0000o`000006ooooo`;o000000?o
ooooo`000?l000000_l00002ooooo`Co00001Oooool2o`0001Kooooo1?l0001mooooo`0000Kooooo
onk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003o
ooooooooo`1Hooooo`;o00009_ooool2o`000003ooooool0003o000000kooooo1Ol0000;ooooo`?o
00000oooool2o`0000?ooooo1?l0000Fooooo`Co0000OOooool001cooooo00?o0000ooooooooool0
P?ooool2o`0001;ooooo0_l0000>ooooo`;o00002?ooool2o`0000_ooooo0_l0000<ooooo`;o0000
O_ooool001cooooo00?o0000ooooooooool0Roooool2o`0000Sooooo0_l00009ooooo`;o00000_oo
ool2o`0001Gooooo0_l0000<ooooo`;o0000O_ooool001cooooo00?o0000ooooooooool0Roooool2
o`0000Sooooo0_l00003ooooo`;o00001?ooool2o`0000;ooooo0_l0000Kooooo`;o00003_ooool2
o`0007Kooooo000Looooo`03o`000?oooooooooo05oooooo0_l0000iooooo`?o00007oooool2o`00
00?ooooo1?l0000<ooooo`;o0000M_ooool001cooooo00?o0000ooooooooool0Goooool2o`0002Go
oooo0_l00006ooooo`?o00002_ooool2o`0000;ooooo0_l00003ooooo`;o00004_ooool3o`000003
ooooool0003o000000Gooooo0_l00003ooooo`;o0000Ooooool001cooooo00?o0000ooooooooool0
Q_ooool2o`0000Kooooo0ol0000>ooooo`;o00000oooool2o`0000Sooooo0_l00002ooooo`;o0000
1?ooool3o`0000gooooo0_l0001oooooo`007?ooool00ol0003oooooooooo`2>ooooo`;o00004?oo
ool2o`0000;ooooo1?l00005ooooo`?o00000_ooool2o`0001?ooooo0_l00020ooooo`007?ooool0
0ol0003oooooooooo`2Pooooo`;o00001?ooool2o`0000Gooooo0_l0000=ooooo`;o00001Oooool2
o`0000;ooooo0_l00020ooooo`007?ooool00ol0003oooooooooo`2Cooooo`;o00009oooool2o`00
00Gooooo0_l00024ooooo`007?ooool00ol0003oooooooooo`2Cooooo`;o0000]?ooool001cooooo
00?o0000ooooooooool0J?ooool2o`000=oooooo000Looooo`;o0000JOooool2o`00037ooooo0_l0
002/ooooo`007?ooool00ol0003oooooooooo`1[ooooo`;o0000;_ooool2o`000:cooooo000Loooo
o`03o`000?oooooooooo06_ooooo0_l0003Looooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`1fooooo`;o0000dOooool001cooooo00?o0000ooooooooool0M_ooool2o`000=7ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo07kooooo
0_l00039ooooo`007?ooool00ol0003oooooooooo`1nooooo`;o0000bOooool001cooooo0_l0003o
oooood_ooooo000Looooo`03o`000?oooooooooo08Cooooo0_l00033ooooo`007?ooool00ol0003o
ooooooooo`24ooooo`;o0000`oooool001cooooo00?o0000ooooooooool0U_ooool2o`000;7ooooo
000Looooo`03o`000?oooooooooo08[ooooo0_l00005ooooo`;o00000oooool2o`000;7ooooo000L
ooooo`03o`000?oooooooooo08[ooooo0_l00002ooooo`;o000000?oooooo`000?l00000]_ooool0
01cooooo00?o0000ooooooooool0S_ooool2o`0000_ooooo0_l0002/ooooo`007?ooool00ol0003o
ooooooooo`2Kooooo`;o0000[?ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000B
ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooood[ooooo000Doooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003o
ooooooooo`05ooooo`?o0000oooooom:ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo
000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomB
ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Booooo`03oeEEEOmVIVKo00000?oo
ooooE?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Gooooo00Co410@o`00
0?l0003ooooo0_l000000ol@413oooooooooo`0Fooooo`05odA4A?l0003o0000oc8b<_oMgMd01?oo
ool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?l@413oc<c<093ooooo002Vooooo`05
o`000?ooooooooooooooool000002Oooool6o`0000gooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`02ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40T?ooool00:Kooooo00Go0000oooo
ooooooooooooo`00000Mooooo`03o`000?oooooooooo00Go00000oooool01Ol0003ooooooooooooo
oooo0000093ooooo002Vooooo`05o`000?ooooooooooooooool000002Oooool6o`0000gooooo00So
MgMgoc8b<_ooooooooooodA4A?oMgMgoooooo`0000Cooooo00Go0000oiRHV?ooooooV9RHob4Q8@2@
ooooo`00Y_ooool01Ol0003oQhN7oooooonYZJWo000001Wooooo00Go0000ob4Q8Ol0003o<S8bolc<
c002ooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000oeEEEOl0003o410@olc<c02@ooooo`00
YOooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo01Oooooo00?o0000ooooooooool0
1Oooool00omgMgOoc<c<o`000004ooooo`03oeEEEOn7QhOooooo09;ooooo0034ooooo`03o`000?oo
oooooooo00Gooooo00?ok^k^odA4A?l000001?ooool00ooMgMgo410@oiRHV02Booooo`00a?ooool4
o`0000Gooooo00?oMgMgo`000?ooool01?ooool01?o<c<coA4A4o`000?l@412@ooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(552) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.67152 .58066 Mdot
.66132 .6252 Mdot
.44754 .36285 Mdot
.43483 .63713 Mdot
.29225 .47126 Mdot
.42226 .35111 Mdot
.60878 .32426 Mdot
.57506 .31641 Mdot
.41992 .36323 Mdot
.47778 .75911 Mdot
.57966 .34233 Mdot
.37214 .63194 Mdot
.59345 .32726 Mdot
.43453 .59962 Mdot
.61786 .46768 Mdot
.40749 .53727 Mdot
.61557 .61437 Mdot
.26617 .44738 Mdot
.40712 .53661 Mdot
.44736 .35668 Mdot
.36339 .5338 Mdot
.44506 .60802 Mdot
.62564 .62527 Mdot
.43828 .60157 Mdot
.40449 .63491 Mdot
.65488 .61674 Mdot
.67625 .58803 Mdot
.42488 .65682 Mdot
.45978 .6557 Mdot
.57846 .3306 Mdot
.30349 .2862 Mdot
.79313 .66538 Mdot
.41435 .6694 Mdot
.66092 .71394 Mdot
.57208 .31779 Mdot
.60012 .22442 Mdot
.39997 .37736 Mdot
.58745 .30531 Mdot
.56432 .33912 Mdot
.56198 .33772 Mdot
.61212 .31664 Mdot
.66075 .60905 Mdot
.577 .36572 Mdot
.4772 .35234 Mdot
.4072 .59082 Mdot
.7622 .60585 Mdot
.33058 .23982 Mdot
.43743 .65776 Mdot
.64769 .57276 Mdot
.44613 .339 Mdot
.23299 .63009 Mdot
.61684 .30349 Mdot
.67495 .51866 Mdot
.28157 .80888 Mdot
.58347 .33562 Mdot
.44378 .6468 Mdot
.4382 .3463 Mdot
.43745 .62484 Mdot
.46474 .63441 Mdot
.65054 .69678 Mdot
.46202 .60973 Mdot
.31193 .43447 Mdot
.68698 .61705 Mdot
.38816 .3952 Mdot
.42456 .35851 Mdot
.60791 .30703 Mdot
.66227 .63832 Mdot
.59575 .31626 Mdot
.48992 .64426 Mdot
.4512 .34123 Mdot
.44461 .65513 Mdot
.57635 .33667 Mdot
.655 .63551 Mdot
.3989 .59613 Mdot
.75323 .53614 Mdot
.55026 .37917 Mdot
.36136 .40456 Mdot
.61642 .78237 Mdot
.26509 .71583 Mdot
.38161 .28635 Mdot
.43032 .58623 Mdot
.19709 .658 Mdot
.6186 .4435 Mdot
.66968 .62239 Mdot
.70647 .63615 Mdot
.78787 .38365 Mdot
.44508 .66158 Mdot
.38151 .46955 Mdot
.38226 .63103 Mdot
.52534 .50484 Mdot
.41936 .36861 Mdot
.64366 .62492 Mdot
.40702 .58906 Mdot
.38426 .61662 Mdot
.50274 .69996 Mdot
.48432 .63938 Mdot
.41441 .61505 Mdot
.70261 .61073 Mdot
.59458 .34933 Mdot
.42774 .69962 Mdot
.26346 .4018 Mdot
.67039 .50519 Mdot
.42176 .63345 Mdot
.40125 .34699 Mdot
.68755 .59614 Mdot
.40733 .60781 Mdot
.59053 .31149 Mdot
.44356 .59519 Mdot
.63466 .30543 Mdot
.61635 .60419 Mdot
.38299 .62159 Mdot
.33847 .43933 Mdot
.57611 .5279 Mdot
.63523 .58495 Mdot
.49402 .81195 Mdot
.45947 .60857 Mdot
.45712 .61984 Mdot
.66871 .61838 Mdot
.42599 .3771 Mdot
.43159 .44698 Mdot
.63291 .62992 Mdot
.56341 .34295 Mdot
.62387 .58114 Mdot
.38208 .59031 Mdot
.4296 .37483 Mdot
.66259 .49748 Mdot
.67156 .51009 Mdot
.24359 .46605 Mdot
.39681 .59602 Mdot
.60304 .54394 Mdot
.41312 .34178 Mdot
.66427 .61338 Mdot
.59009 .31919 Mdot
.47514 .62553 Mdot
.65087 .58817 Mdot
.56849 .34881 Mdot
.30097 .42672 Mdot
.29065 .47258 Mdot
.65981 .58264 Mdot
.36372 .71306 Mdot
.6238 .30337 Mdot
.56072 .34497 Mdot
.23509 .62312 Mdot
.6729 .61722 Mdot
.29119 .45078 Mdot
.58098 .3606 Mdot
.29077 .55986 Mdot
.46902 .60043 Mdot
.22581 .52663 Mdot
.15622 .57816 Mdot
.23368 .62693 Mdot
.73102 .70016 Mdot
.32738 .45201 Mdot
.58096 .3618 Mdot
.42933 .64944 Mdot
.64939 .59674 Mdot
.65847 .59577 Mdot
.38705 .6068 Mdot
.39416 .62706 Mdot
.4178 .59383 Mdot
.47264 .62077 Mdot
.5196 .18108 Mdot
.42068 .58526 Mdot
.65483 .38294 Mdot
.6435 .58851 Mdot
.39685 .61957 Mdot
.3934 .34941 Mdot
.43074 .55678 Mdot
.58524 .30729 Mdot
.46027 .63762 Mdot
.39879 .63417 Mdot
.45782 .57146 Mdot
.57681 .36342 Mdot
.76995 .49348 Mdot
.32905 .77121 Mdot
.62589 .24788 Mdot
.70333 .51653 Mdot
.42375 .33529 Mdot
.44638 .58162 Mdot
.31232 .45459 Mdot
.37755 .66014 Mdot
.46442 .62599 Mdot
.23083 .63776 Mdot
.39707 .64106 Mdot
.68387 .73869 Mdot
.45077 .69998 Mdot
.78004 .35677 Mdot
.67776 .35976 Mdot
.46857 .6211 Mdot
.43683 .75601 Mdot
.22846 .50104 Mdot
.25989 .3141 Mdot
.58313 .32437 Mdot
.38921 .34983 Mdot
.41502 .38084 Mdot
.55885 .33462 Mdot
.49169 .66401 Mdot
.48517 .76662 Mdot
.49272 .63207 Mdot
.66341 .49576 Mdot
.62536 .64774 Mdot
.31279 .45987 Mdot
.66009 .58187 Mdot
.21372 .69013 Mdot
.38624 .4881 Mdot
.4119 .29183 Mdot
.2669 .4511 Mdot
.43494 .32058 Mdot
.66513 .47678 Mdot
.29748 .45614 Mdot
.42523 .6242 Mdot
.62311 .58707 Mdot
.22558 .50202 Mdot
.42857 .54279 Mdot
.63621 .16724 Mdot
.6725 .62674 Mdot
.54862 .47417 Mdot
.58516 .32929 Mdot
.38972 .39199 Mdot
.44378 .6614 Mdot
.42796 .61049 Mdot
.68627 .60741 Mdot
.44619 .65769 Mdot
.43975 .47205 Mdot
.40023 .63934 Mdot
.37603 .37435 Mdot
.32124 .40877 Mdot
.63452 .29678 Mdot
.26469 .47883 Mdot
.64549 .63476 Mdot
.59589 .40907 Mdot
.39761 .3479 Mdot
.54654 .58317 Mdot
.57743 .32281 Mdot
.31034 .42415 Mdot
.39586 .36854 Mdot
.34109 .42771 Mdot
.40916 .57672 Mdot
.40632 .37658 Mdot
.29828 .43629 Mdot
.51666 .36432 Mdot
.41372 .61574 Mdot
.24879 .54852 Mdot
.60474 .35276 Mdot
.67165 .58464 Mdot
.46557 .61623 Mdot
.65913 .49718 Mdot
.40657 .56322 Mdot
.598 .52599 Mdot
.66136 .47135 Mdot
.68501 .48403 Mdot
.39303 .29766 Mdot
.28152 .44937 Mdot
.73385 .55647 Mdot
.47231 .4319 Mdot
.61623 .61655 Mdot
.42063 .5725 Mdot
.8052 .48745 Mdot
.60536 .35321 Mdot
.42923 .62646 Mdot
.77257 .36652 Mdot
.58265 .36111 Mdot
.44551 .62622 Mdot
.61533 .32125 Mdot
.6542 .59427 Mdot
.54716 .40567 Mdot
.62767 .5734 Mdot
.43856 .63725 Mdot
.60741 .34037 Mdot
.38828 .357 Mdot
.65436 .61604 Mdot
.44812 .60087 Mdot
.42872 .58327 Mdot
.66419 .4897 Mdot
.39339 .61041 Mdot
.81895 .46868 Mdot
.43435 .65718 Mdot
.43929 .32161 Mdot
.48273 .64559 Mdot
.21219 .50814 Mdot
.28669 .47385 Mdot
.65187 .64498 Mdot
.66474 .46977 Mdot
.42379 .36935 Mdot
.52937 .3804 Mdot
.25035 .46415 Mdot
.43489 .59098 Mdot
.6776 .49371 Mdot
.5496 .46808 Mdot
.59935 .30617 Mdot
.4499 .6676 Mdot
.43571 .45873 Mdot
.40856 .36843 Mdot
.66265 .48496 Mdot
.50128 .58634 Mdot
.66496 .57188 Mdot
.44076 .64801 Mdot
.39561 .37321 Mdot
.65467 .57022 Mdot
.47575 .63661 Mdot
.42274 .20843 Mdot
.6614 .50428 Mdot
.61409 .33982 Mdot
.55079 .62688 Mdot
.4254 .57811 Mdot
.40892 .38375 Mdot
.65614 .58929 Mdot
.59276 .34172 Mdot
.62068 .60202 Mdot
.22665 .47816 Mdot
.62012 .54581 Mdot
.52223 .20895 Mdot
.27029 .43871 Mdot
.6773 .78683 Mdot
.61914 .24185 Mdot
.58261 .56824 Mdot
.37137 .41647 Mdot
.71852 .27035 Mdot
.3961 .36027 Mdot
.3923 .73861 Mdot
.43252 .36128 Mdot
.42711 .64191 Mdot
.42244 .35413 Mdot
.82919 .44974 Mdot
.40971 .65092 Mdot
.43083 .33481 Mdot
.49654 .20045 Mdot
.39563 .64167 Mdot
.64452 .58567 Mdot
.79083 .62134 Mdot
.52481 .81932 Mdot
.3357 .67039 Mdot
.43502 .33487 Mdot
.38916 .74672 Mdot
.43202 .65986 Mdot
.42803 .53779 Mdot
.64876 .60254 Mdot
.37804 .5898 Mdot
.32853 .45606 Mdot
.3427 .43597 Mdot
.25839 .63769 Mdot
.56012 .82617 Mdot
.52245 .57649 Mdot
.65663 .60915 Mdot
.25093 .70177 Mdot
.75672 .53868 Mdot
.6666 .51232 Mdot
.56613 .32978 Mdot
.76387 .49037 Mdot
.50087 .58026 Mdot
.44986 .71303 Mdot
.47776 .4639 Mdot
.64357 .6266 Mdot
.54935 .25214 Mdot
.5989 .33913 Mdot
.398 .76974 Mdot
.52624 .74924 Mdot
.41549 .59574 Mdot
.62591 .32771 Mdot
.42419 .69147 Mdot
.46368 .46635 Mdot
.23923 .54192 Mdot
.41867 .24769 Mdot
.4265 .62841 Mdot
.74106 .5589 Mdot
.46204 .62709 Mdot
.23348 .50783 Mdot
.43595 .63279 Mdot
.62303 .59855 Mdot
.52021 .60577 Mdot
.48107 .41142 Mdot
.40656 .79346 Mdot
.39059 .48564 Mdot
.28659 .45661 Mdot
.43281 .60171 Mdot
.41961 .60577 Mdot
.30851 .432 Mdot
.63817 .61967 Mdot
.43491 .5713 Mdot
.33945 .23118 Mdot
.41797 .58507 Mdot
.61181 .30201 Mdot
.52921 .40871 Mdot
.67802 .75258 Mdot
.40227 .65023 Mdot
.67031 .57512 Mdot
.6016 .30881 Mdot
.56923 .33656 Mdot
.52088 .58131 Mdot
.61136 .34755 Mdot
.4344 .65253 Mdot
.53155 .41019 Mdot
.62191 .62084 Mdot
.39419 .67655 Mdot
.63444 .61611 Mdot
.22286 .6526 Mdot
.59307 .36172 Mdot
.68173 .48994 Mdot
.37339 .73535 Mdot
.60504 .32889 Mdot
.43964 .50986 Mdot
.51041 .63445 Mdot
.47604 .56963 Mdot
.58574 .57599 Mdot
.38617 .36695 Mdot
.67808 .48039 Mdot
.58513 .33898 Mdot
.4186 .58624 Mdot
.40904 .6166 Mdot
.62667 .31703 Mdot
.59388 .67559 Mdot
.30817 .28352 Mdot
.44344 .63882 Mdot
.62343 .60615 Mdot
.66319 .6125 Mdot
.46937 .59159 Mdot
.46388 .62171 Mdot
.41433 .32166 Mdot
.67859 .49319 Mdot
.67369 .47307 Mdot
.67776 .50556 Mdot
.38055 .34807 Mdot
.64223 .80988 Mdot
.56072 .34552 Mdot
.74575 .7014 Mdot
.77531 .42302 Mdot
.50168 .56069 Mdot
.39847 .38104 Mdot
.43802 .61657 Mdot
.41481 .62882 Mdot
.60355 .34423 Mdot
.53186 .8399 Mdot
.42091 .67574 Mdot
.67689 .59399 Mdot
.61943 .30671 Mdot
.37641 .64763 Mdot
.56617 .3813 Mdot
.33209 .43056 Mdot
.35189 .54973 Mdot
.62701 .32952 Mdot
.61822 .59973 Mdot
.62783 .32595 Mdot
.4183 .60169 Mdot
.49218 .58147 Mdot
.64591 .62849 Mdot
.28191 .4357 Mdot
.40845 .58093 Mdot
.44774 .62739 Mdot
.19504 .40471 Mdot
.75201 .53943 Mdot
.34963 .3567 Mdot
.41357 .63759 Mdot
.47963 .58019 Mdot
.29079 .42599 Mdot
.42939 .57477 Mdot
.46434 .65345 Mdot
.57433 .52324 Mdot
.62832 .29332 Mdot
.28822 .46607 Mdot
.39025 .77678 Mdot
.67646 .62163 Mdot
.81431 .44842 Mdot
.66716 .50531 Mdot
.64192 .30924 Mdot
.55216 .4071 Mdot
.67231 .48021 Mdot
.76236 .36908 Mdot
.6344 .25347 Mdot
.67877 .48706 Mdot
.39735 .39726 Mdot
.36692 .66721 Mdot
.46922 .65312 Mdot
.45654 .63547 Mdot
.28252 .44692 Mdot
.67348 .60295 Mdot
.661 .38194 Mdot
.6138 .28602 Mdot
.45002 .61271 Mdot
.62185 .57084 Mdot
.78401 .36966 Mdot
.66492 .48074 Mdot
.32408 .45021 Mdot
.27556 .44825 Mdot
.46026 .62544 Mdot
.52618 .53371 Mdot
.65731 .61205 Mdot
.44808 .60097 Mdot
.46296 .59607 Mdot
.43879 .35884 Mdot
.62768 .58219 Mdot
.39802 .34238 Mdot
.66351 .46713 Mdot
.67882 .22296 Mdot
.20269 .36296 Mdot
.59352 .35645 Mdot
.58237 .25053 Mdot
.61983 .35415 Mdot
.43877 .24235 Mdot
.67969 .4918 Mdot
.44739 .60458 Mdot
.64272 .6372 Mdot
.44574 .5969 Mdot
.41324 .58623 Mdot
.40985 .59939 Mdot
.52151 .57404 Mdot
.22462 .63112 Mdot
.32183 .44378 Mdot
.48509 .65333 Mdot
.41817 .31737 Mdot
.77681 .35784 Mdot
.79984 .57369 Mdot
.42762 .60317 Mdot
.45568 .62096 Mdot
.67272 .63194 Mdot
.40766 .57648 Mdot
.58804 .31077 Mdot
.67291 .62242 Mdot
.4189 .62823 Mdot
.24129 .42332 Mdot
.44492 .57436 Mdot
.59034 .24364 Mdot
.62823 .32815 Mdot
.34775 .57734 Mdot
.49369 .59252 Mdot
.68061 .49013 Mdot
.67789 .48087 Mdot
.65677 .48902 Mdot
.62023 .31196 Mdot
.43656 .36179 Mdot
.46046 .35757 Mdot
.50684 .59897 Mdot
.42766 .65065 Mdot
.48763 .58015 Mdot
.39517 .31851 Mdot
.46868 .42692 Mdot
.73648 .60546 Mdot
.45562 .69853 Mdot
.39054 .33349 Mdot
.68001 .56351 Mdot
.43793 .80648 Mdot
.67697 .61147 Mdot
.36652 .40562 Mdot
.57673 .3192 Mdot
.33442 .44738 Mdot
.26306 .68014 Mdot
.62695 .62428 Mdot
.68462 .60427 Mdot
.42677 .33397 Mdot
.57705 .45493 Mdot
.38271 .88506 Mdot
.40541 .34639 Mdot
.35916 .41269 Mdot
.65091 .60605 Mdot
.41136 .6705 Mdot
.55185 .46475 Mdot
.5727 .47747 Mdot
.43264 .34372 Mdot
.43085 .58405 Mdot
.45038 .50717 Mdot
.41519 .32164 Mdot
.45282 .66896 Mdot
.43382 .33226 Mdot
.61761 .33951 Mdot
.41367 .33765 Mdot
.60262 .60238 Mdot
.40403 .58884 Mdot
.3104 .83338 Mdot
.61517 .43885 Mdot
.45436 .60031 Mdot
.62361 .30961 Mdot
.47059 .18923 Mdot
.41641 .60762 Mdot
.31348 .46212 Mdot
.39411 .32637 Mdot
.40971 .23675 Mdot
.4614 .6526 Mdot
.42787 .3483 Mdot
.61142 .62402 Mdot
.36851 .40403 Mdot
.33571 .36013 Mdot
.6759 .47595 Mdot
.65123 .5929 Mdot
.69121 .48726 Mdot
.57221 .31613 Mdot
.43518 .56491 Mdot
.45605 .58454 Mdot
.63351 .59138 Mdot
.52477 .36137 Mdot
.46294 .67318 Mdot
.4301 .58651 Mdot
.41158 .32461 Mdot
.41521 .31316 Mdot
.63193 .47729 Mdot
.39394 .35596 Mdot
.48019 .5818 Mdot
.63139 .59107 Mdot
.43328 .64297 Mdot
.6527 .58467 Mdot
.41745 .57387 Mdot
.69535 .54483 Mdot
.67613 .60757 Mdot
.55622 .57373 Mdot
.39095 .60616 Mdot
.58181 .63635 Mdot
.41732 .57995 Mdot
.41939 .62046 Mdot
.39447 .32313 Mdot
.30793 .44674 Mdot
.41816 .66605 Mdot
.58881 .40446 Mdot
.31092 .41861 Mdot
.70503 .68861 Mdot
.42664 .37614 Mdot
.29025 .43087 Mdot
.26768 .59002 Mdot
.66478 .46993 Mdot
.31768 .43611 Mdot
.64718 .47108 Mdot
.59815 .35435 Mdot
.61184 .59715 Mdot
.39009 .63233 Mdot
.71981 .26359 Mdot
.30344 .28681 Mdot
.66663 .49026 Mdot
.46428 .61587 Mdot
.4346 .6177 Mdot
.6556 .56841 Mdot
.20753 .67611 Mdot
.37694 .38697 Mdot
.42443 .62926 Mdot
.6359 .63002 Mdot
.17957 .62317 Mdot
.42861 .32875 Mdot
.32569 .43798 Mdot
.62267 .34599 Mdot
.59442 .62445 Mdot
.68036 .48046 Mdot
.59276 .36203 Mdot
.36493 .36429 Mdot
.23 .64731 Mdot
.46143 .6517 Mdot
.38887 .36916 Mdot
.23334 .62762 Mdot
.44509 .69975 Mdot
.57162 .36892 Mdot
.68738 .5432 Mdot
.64634 .6261 Mdot
.62538 .31406 Mdot
.28377 .45622 Mdot
.61535 .61018 Mdot
.63694 .62008 Mdot
.57332 .31963 Mdot
.6834 .31913 Mdot
.55239 .4729 Mdot
.59631 .30247 Mdot
.57206 .50311 Mdot
.23545 .61892 Mdot
.67898 .49776 Mdot
.32381 .45103 Mdot
.21607 .45886 Mdot
.65935 .61214 Mdot
.76489 .49061 Mdot
.23187 .63519 Mdot
.41482 .61565 Mdot
.29102 .44215 Mdot
.78401 .3912 Mdot
.63723 .29345 Mdot
.57082 .35154 Mdot
.40221 .45265 Mdot
.30003 .46193 Mdot
.46388 .58924 Mdot
.66309 .76606 Mdot
.38679 .62463 Mdot
.58837 .36106 Mdot
.4669 .47155 Mdot
.62901 .58213 Mdot
.57259 .31426 Mdot
.43186 .47164 Mdot
.41525 .6308 Mdot
.45932 .60017 Mdot
.26566 .49377 Mdot
.62897 .57933 Mdot
.68299 .4833 Mdot
.43922 .58897 Mdot
.44 .62714 Mdot
.4462 .5681 Mdot
.35647 .72782 Mdot
.55846 .54968 Mdot
.41975 .626 Mdot
.38504 .38449 Mdot
.46261 .56129 Mdot
.47087 .62583 Mdot
.64719 .56571 Mdot
.20644 .52356 Mdot
.66297 .4669 Mdot
.45359 .6358 Mdot
.44425 .63871 Mdot
.56384 .33247 Mdot
.55131 .47031 Mdot
.57379 .4804 Mdot
.43901 .32483 Mdot
.37122 .4537 Mdot
.49542 .62226 Mdot
.64416 .59203 Mdot
.33234 .45411 Mdot
.46334 .57151 Mdot
.6788 .6098 Mdot
.50125 .6359 Mdot
.42386 .31854 Mdot
.6765 .4912 Mdot
.49953 .67478 Mdot
.3109 .43755 Mdot
.62646 .30103 Mdot
.76283 .68187 Mdot
.39301 .34384 Mdot
.41454 .64601 Mdot
.4658 .33051 Mdot
.40606 .35765 Mdot
.66541 .49355 Mdot
.44479 .54598 Mdot
.65698 .59817 Mdot
.62457 .58869 Mdot
.22754 .58742 Mdot
.37762 .35934 Mdot
.16208 .4789 Mdot
.61643 .34157 Mdot
.45003 .66592 Mdot
.78897 .55419 Mdot
.63028 .58299 Mdot
.23826 .48329 Mdot
.28962 .43063 Mdot
.57125 .35172 Mdot
.67584 .46649 Mdot
.67665 .6019 Mdot
.64184 .57851 Mdot
.40807 .58888 Mdot
.43604 .6077 Mdot
.36815 .42585 Mdot
.22755 .51421 Mdot
.61496 .32139 Mdot
.32936 .4385 Mdot
.44455 .33065 Mdot
.4182 .63723 Mdot
.6597 .62802 Mdot
.66344 .75954 Mdot
.42835 .57802 Mdot
.42362 .31949 Mdot
.65376 .62557 Mdot
.32174 .43053 Mdot
.29673 .43122 Mdot
.41624 .61668 Mdot
.65589 .74555 Mdot
.60527 .32577 Mdot
.63781 .58627 Mdot
.70067 .63399 Mdot
.48196 .65283 Mdot
.43145 .60395 Mdot
.39362 .66506 Mdot
.56082 .35742 Mdot
.49142 .68293 Mdot
.28599 .42649 Mdot
.66678 .59835 Mdot
.44888 .59575 Mdot
.31253 .43435 Mdot
.45826 .71228 Mdot
.67308 .48451 Mdot
.42853 .33025 Mdot
.31865 .45996 Mdot
.29755 .44467 Mdot
.31391 .41965 Mdot
.76248 .49345 Mdot
.68771 .59434 Mdot
.36918 .77974 Mdot
.41058 .58522 Mdot
.23627 .61561 Mdot
.40142 .57776 Mdot
.61987 .32588 Mdot
.38725 .35085 Mdot
.41363 .58931 Mdot
.40892 .58576 Mdot
.70212 .7249 Mdot
.38173 .5427 Mdot
.35735 .55436 Mdot
.61769 .59629 Mdot
.55291 .63526 Mdot
.40313 .3847 Mdot
.14215 .55765 Mdot
.82484 .57888 Mdot
.4918 .63026 Mdot
.57458 .45022 Mdot
.67196 .62258 Mdot
.57039 .35495 Mdot
.56314 .4885 Mdot
.64688 .32578 Mdot
.67006 .60572 Mdot
.42321 .63911 Mdot
.74981 .68875 Mdot
.33326 .42178 Mdot
.41882 .59551 Mdot
.58918 .3173 Mdot
.41833 .59468 Mdot
.61955 .31514 Mdot
.6098 .64362 Mdot
.58689 .46825 Mdot
.39963 .64396 Mdot
.48579 .64065 Mdot
.45398 .70573 Mdot
.43008 .60497 Mdot
.47128 .27816 Mdot
.64269 .61429 Mdot
.55023 .57582 Mdot
.47104 .59049 Mdot
.61411 .76443 Mdot
.45033 .57858 Mdot
.53469 .36444 Mdot
.45627 .58786 Mdot
.32154 .65739 Mdot
.46636 .59394 Mdot
.44837 .58269 Mdot
.60109 .34076 Mdot
.5643 .34419 Mdot
.61637 .63235 Mdot
.68467 .48957 Mdot
.7791 .35663 Mdot
.45167 .62454 Mdot
.40275 .3154 Mdot
.64792 .50696 Mdot
.30114 .44714 Mdot
.66737 .60384 Mdot
.13243 .44019 Mdot
.60825 .31128 Mdot
.39017 .39545 Mdot
.40509 .28083 Mdot
.40635 .3904 Mdot
.38752 .32137 Mdot
.57446 .62519 Mdot
.32992 .44591 Mdot
.45864 .58398 Mdot
.66572 .72067 Mdot
.74827 .55432 Mdot
.47264 .65718 Mdot
.46636 .35072 Mdot
.36275 .59785 Mdot
.22961 .61558 Mdot
.34304 .42524 Mdot
.3182 .45708 Mdot
.59003 .34017 Mdot
.44172 .36851 Mdot
.4442 .69675 Mdot
.29166 .43001 Mdot
.38939 .34634 Mdot
.67457 .51365 Mdot
.31959 .48889 Mdot
.65963 .60777 Mdot
.34934 .68926 Mdot
.77605 .58304 Mdot
.61088 .31406 Mdot
.58025 .40461 Mdot
.68724 .58017 Mdot
.66416 .6508 Mdot
.68375 .49666 Mdot
.41254 .31803 Mdot
.61348 .61188 Mdot
.40552 .58833 Mdot
.42918 .54289 Mdot
.46134 .6242 Mdot
.28539 .43979 Mdot
.46501 .60349 Mdot
.40483 .32366 Mdot
.60894 .31984 Mdot
.41654 .36952 Mdot
.60903 .32732 Mdot
.74706 .66836 Mdot
.46713 .63002 Mdot
.43459 .60407 Mdot
.54117 .41844 Mdot
.65291 .57946 Mdot
.64809 .7103 Mdot
.41429 .31677 Mdot
.43788 .35197 Mdot
.43114 .641 Mdot
.65965 .64434 Mdot
.26152 .44726 Mdot
.55831 .45387 Mdot
.45908 .59024 Mdot
.64193 .61352 Mdot
.43838 .64515 Mdot
.44271 .2264 Mdot
.60312 .46382 Mdot
.62162 .59758 Mdot
.41021 .79671 Mdot
.3938 .60541 Mdot
.36941 .55379 Mdot
.38137 .557 Mdot
.33423 .55337 Mdot
.43872 .6715 Mdot
.67024 .62814 Mdot
.46239 .63738 Mdot
.64301 .59608 Mdot
.40123 .35818 Mdot
.56139 .35122 Mdot
.64593 .59817 Mdot
.38707 .61756 Mdot
.81378 .60014 Mdot
.6026 .31214 Mdot
.42577 .5927 Mdot
.58291 .34247 Mdot
.61472 .58739 Mdot
.65386 .57525 Mdot
.64161 .4669 Mdot
.39356 .30068 Mdot
.59673 .31153 Mdot
.43009 .65215 Mdot
.76085 .5144 Mdot
.43372 .64358 Mdot
.3657 .45428 Mdot
.4766 .60758 Mdot
.48076 .64954 Mdot
.69237 .77795 Mdot
.52954 .37257 Mdot
.14795 .46796 Mdot
.57881 .28934 Mdot
.76837 .50157 Mdot
.66781 .65795 Mdot
.34333 .42584 Mdot
.56897 .25949 Mdot
.65894 .47723 Mdot
.38931 .38608 Mdot
.41422 .58779 Mdot
.73451 .64963 Mdot
.60631 .3021 Mdot
.31081 .4489 Mdot
.39793 .64195 Mdot
.4547 .3564 Mdot
.675 .44959 Mdot
.57845 .36056 Mdot
.6616 .60727 Mdot
.65997 .58086 Mdot
.28272 .73521 Mdot
.45234 .59981 Mdot
.44161 .60799 Mdot
.58169 .3115 Mdot
.45908 .69132 Mdot
.32246 .42143 Mdot
.49915 .20923 Mdot
.58537 .31951 Mdot
.61172 .45598 Mdot
.61577 .59968 Mdot
.43577 .61704 Mdot
.52726 .40802 Mdot
.74133 .44301 Mdot
.48348 .72976 Mdot
.28925 .45384 Mdot
.31639 .51144 Mdot
.67049 .62807 Mdot
.58795 .32059 Mdot
.2584 .6209 Mdot
.38324 .60541 Mdot
.43511 .61997 Mdot
.29874 .51174 Mdot
.55978 .45959 Mdot
.34991 .46876 Mdot
.37897 .6367 Mdot
.53524 .46129 Mdot
.42926 .63978 Mdot
.40912 .61703 Mdot
.49072 .6429 Mdot
.47252 .63573 Mdot
.63997 .60844 Mdot
.54496 .81477 Mdot
.42017 .34619 Mdot
.4356 .74209 Mdot
.39851 .44639 Mdot
.43269 .66096 Mdot
.4197 .63537 Mdot
.50485 .79463 Mdot
.63 .52923 Mdot
.64728 .61365 Mdot
.69866 .63389 Mdot
.56064 .34017 Mdot
.38311 .54182 Mdot
.37842 .35172 Mdot
.35459 .57989 Mdot
.41457 .36159 Mdot
.64054 .61318 Mdot
.43051 .36985 Mdot
.5854 .29562 Mdot
.38903 .36908 Mdot
.37966 .35664 Mdot
.60157 .36041 Mdot
.63901 .57337 Mdot
.44258 .57942 Mdot
.60421 .35721 Mdot
.25576 .48494 Mdot
.28597 .43911 Mdot
.64119 .47204 Mdot
.41211 .67134 Mdot
.37038 .54881 Mdot
.42009 .21003 Mdot
.41446 .37629 Mdot
.59174 .51193 Mdot
.67592 .60654 Mdot
.30382 .46542 Mdot
.63975 .60397 Mdot
.30966 .72157 Mdot
.30228 .43774 Mdot
.64211 .47276 Mdot
.25581 .60827 Mdot
.59794 .39087 Mdot
.41112 .56052 Mdot
.5732 .59058 Mdot
.41254 .36344 Mdot
.61326 .30239 Mdot
.78015 .37851 Mdot
.39745 .60429 Mdot
.6855 .51625 Mdot
.67893 .64663 Mdot
.66681 .4703 Mdot
.59168 .31867 Mdot
.58291 .27924 Mdot
.45558 .60472 Mdot
.57894 .39369 Mdot
.48031 .63984 Mdot
.37706 .7373 Mdot
.37034 .44661 Mdot
.64451 .54484 Mdot
.44084 .64922 Mdot
.42232 .32177 Mdot
.43822 .64732 Mdot
.37018 .69625 Mdot
.24213 .62745 Mdot
.48781 .62653 Mdot
.59124 .56657 Mdot
.41295 .22865 Mdot
.65313 .62838 Mdot
.48478 .59012 Mdot
.67278 .49728 Mdot
.40487 .62849 Mdot
.76369 .26988 Mdot
.31604 .43828 Mdot
.35458 .36936 Mdot
.38796 .61092 Mdot
.44178 .59224 Mdot
.67327 .73791 Mdot
.56927 .60549 Mdot
.67277 .46446 Mdot
.43028 .62043 Mdot
.3248 .51779 Mdot
.59487 .34282 Mdot
.47626 .63294 Mdot
.4607 .63475 Mdot
.21368 .37589 Mdot
.5931 .34468 Mdot
.40823 .37943 Mdot
.66313 .4705 Mdot
.43721 .32579 Mdot
.34716 .44161 Mdot
.54551 .50008 Mdot
.23827 .49341 Mdot
.60461 .46594 Mdot
.29601 .46321 Mdot
.43903 .663 Mdot
.70908 .61792 Mdot
.44935 .59026 Mdot
.31075 .45865 Mdot
.57835 .33106 Mdot
.64265 .60757 Mdot
.3591 .70606 Mdot
.6642 .49677 Mdot
.46937 .66175 Mdot
.34177 .42018 Mdot
.6509 .59803 Mdot
.68368 .41695 Mdot
.67325 .61024 Mdot
.60547 .33259 Mdot
.56237 .32514 Mdot
.30396 .44212 Mdot
.63897 .60625 Mdot
.44131 .33636 Mdot
.57534 .29019 Mdot
.47888 .6156 Mdot
.57158 .30318 Mdot
.62562 .63537 Mdot
.67808 .59069 Mdot
.64412 .64068 Mdot
.46814 .63775 Mdot
.56542 .45809 Mdot
.39142 .58575 Mdot
.59528 .30946 Mdot
.41463 .38489 Mdot
.22763 .53592 Mdot
.65719 .73008 Mdot
.61092 .45319 Mdot
.42239 .66794 Mdot
.46525 .60917 Mdot
.46008 .62496 Mdot
.44725 .64488 Mdot
.50328 .21085 Mdot
.46681 .63049 Mdot
.61019 .33713 Mdot
.41162 .3542 Mdot
.4621 .61078 Mdot
.67521 .49602 Mdot
.46763 .43209 Mdot
.33134 .45505 Mdot
.32289 .6252 Mdot
.80771 .54362 Mdot
.6499 .59966 Mdot
.3915 .36496 Mdot
.43729 .36419 Mdot
.30125 .42663 Mdot
.5967 .35986 Mdot
.6725 .60199 Mdot
.31026 .61188 Mdot
.31704 .41699 Mdot
.45257 .63578 Mdot
.53476 .41282 Mdot
.4231 .80067 Mdot
.41443 .65837 Mdot
.41309 .60808 Mdot
.68015 .47655 Mdot
.38886 .39378 Mdot
.78614 .3193 Mdot
.67987 .34165 Mdot
.30712 .44552 Mdot
.32732 .43035 Mdot
.65431 .63919 Mdot
.45648 .66552 Mdot
.60452 .32243 Mdot
.543 .46566 Mdot
.42832 .19831 Mdot
.80617 .41764 Mdot
.43877 .24461 Mdot
.44262 .57361 Mdot
.56252 .79796 Mdot
.46659 .57988 Mdot
.68748 .59563 Mdot
.65318 .64304 Mdot
.65245 .61172 Mdot
.60022 .3397 Mdot
.2312 .6576 Mdot
.61145 .33698 Mdot
.80975 .54573 Mdot
.64346 .63054 Mdot
.50794 .38126 Mdot
.43838 .34432 Mdot
.47148 .55647 Mdot
.32864 .44777 Mdot
.29948 .40266 Mdot
.48542 .58731 Mdot
.52328 .53613 Mdot
.39865 .38105 Mdot
.65765 .57385 Mdot
.50803 .63808 Mdot
.77115 .34214 Mdot
.57975 .45508 Mdot
.34725 .23515 Mdot
.53797 .65797 Mdot
.30753 .43274 Mdot
.45804 .76006 Mdot
.3258 .42047 Mdot
.57399 .35546 Mdot
.39698 .60141 Mdot
.39097 .59862 Mdot
.42828 .631 Mdot
.46585 .64152 Mdot
.58408 .33887 Mdot
.47415 .59024 Mdot
.21206 .5103 Mdot
.66683 .50803 Mdot
.49991 .37491 Mdot
.30568 .42848 Mdot
.62265 .33154 Mdot
.40784 .35579 Mdot
.68514 .49489 Mdot
.25947 .47768 Mdot
.45986 .57773 Mdot
.41603 .58246 Mdot
.67153 .51127 Mdot
.47994 .67702 Mdot
.4989 .57815 Mdot
.42379 .34844 Mdot
.47079 .45427 Mdot
.27895 .45427 Mdot
.33526 .44444 Mdot
.62693 .32405 Mdot
.63949 .60404 Mdot
.28198 .44005 Mdot
.44473 .36612 Mdot
.47477 .64221 Mdot
.48616 .64149 Mdot
.62504 .635 Mdot
.23148 .63491 Mdot
.34267 .44487 Mdot
.45904 .69977 Mdot
.66138 .58893 Mdot
.68495 .64167 Mdot
.42832 .61864 Mdot
.37307 .60044 Mdot
.68421 .59474 Mdot
.31751 .42541 Mdot
.62312 .33531 Mdot
.52353 .38644 Mdot
.61616 .33313 Mdot
.65893 .59193 Mdot
.45118 .55246 Mdot
.62518 .58153 Mdot
.3944 .6103 Mdot
.12655 .59889 Mdot
.46964 .61738 Mdot
.51177 .55151 Mdot
.36245 .49309 Mdot
.4326 .33054 Mdot
.42959 .32713 Mdot
.67623 .49285 Mdot
.67784 .61395 Mdot
.45907 .56744 Mdot
.3329 .43989 Mdot
.76748 .50371 Mdot
.64179 .55145 Mdot
.38269 .34625 Mdot
.37928 .38461 Mdot
.57916 .33206 Mdot
.45697 .58369 Mdot
.44077 .61776 Mdot
.39132 .37337 Mdot
.48026 .19232 Mdot
.63692 .59782 Mdot
.44161 .60772 Mdot
.47185 .63049 Mdot
.41746 .34779 Mdot
.59048 .27895 Mdot
.69333 .6321 Mdot
.47243 .63122 Mdot
.24994 .59236 Mdot
.61641 .31264 Mdot
.42834 .65559 Mdot
.46902 .58325 Mdot
.29702 .44949 Mdot
.2528 .4571 Mdot
.23558 .62109 Mdot
.57832 .36517 Mdot
.67776 .47677 Mdot
.39785 .58854 Mdot
.4355 .33911 Mdot
.42252 .67454 Mdot
.62316 .2316 Mdot
.66235 .50135 Mdot
.45359 .60881 Mdot
.49722 .61981 Mdot
.64835 .58324 Mdot
.44927 .60327 Mdot
.69035 .5426 Mdot
.41182 .32794 Mdot
.45444 .60896 Mdot
.65176 .74648 Mdot
.57966 .32932 Mdot
.48493 .5852 Mdot
.33003 .45292 Mdot
.37181 .47117 Mdot
.77485 .63789 Mdot
.40513 .31174 Mdot
.29638 .43264 Mdot
.46441 .60133 Mdot
.43574 .32118 Mdot
.62209 .34696 Mdot
.54865 .55859 Mdot
.44718 .66349 Mdot
.61676 .32953 Mdot
.60643 .31682 Mdot
.30863 .44225 Mdot
.13341 .48543 Mdot
.49679 .6223 Mdot
.42396 .59796 Mdot
.39663 .19807 Mdot
.66189 .56407 Mdot
.4223 .59171 Mdot
.45495 .58281 Mdot
.60468 .35252 Mdot
.29394 .6806 Mdot
.39087 .50853 Mdot
.49717 .20015 Mdot
.61913 .31628 Mdot
.39428 .40001 Mdot
.40153 .33449 Mdot
.29892 .43198 Mdot
.65719 .62573 Mdot
.28282 .45911 Mdot
.4183 .33736 Mdot
.42091 .62207 Mdot
.57549 .34949 Mdot
.55198 .68396 Mdot
.62393 .30844 Mdot
.45605 .3454 Mdot
.68995 .62041 Mdot
.78915 .59015 Mdot
.5034 .15068 Mdot
.76941 .59445 Mdot
.57099 .3632 Mdot
.30095 .44735 Mdot
.66944 .3633 Mdot
.46288 .60451 Mdot
.41577 .77573 Mdot
.42079 .59598 Mdot
.47849 .7096 Mdot
.38787 .34892 Mdot
.68099 .50495 Mdot
.39786 .60389 Mdot
.32171 .51189 Mdot
.59176 .36286 Mdot
.58569 .31337 Mdot
.45259 .64143 Mdot
.60616 .33066 Mdot
.44388 .61535 Mdot
.41175 .34986 Mdot
.13722 .48697 Mdot
.45278 .58706 Mdot
.46933 .57044 Mdot
.63435 .2982 Mdot
.64136 .47365 Mdot
.44532 .37673 Mdot
.57544 .79825 Mdot
.77175 .33591 Mdot
.60319 .32746 Mdot
.48641 .54492 Mdot
.40297 .37641 Mdot
.68496 .48371 Mdot
.37068 .36926 Mdot
.42285 .60577 Mdot
.43522 .57214 Mdot
.42981 .63665 Mdot
.46441 .6089 Mdot
.43534 .77437 Mdot
.49128 .57247 Mdot
.5484 .74953 Mdot
.414 .58421 Mdot
.5139 .55461 Mdot
.60662 .34267 Mdot
.36555 .55831 Mdot
.34476 .47195 Mdot
.44146 .57179 Mdot
.56626 .60323 Mdot
.6212 .33496 Mdot
.79453 .5137 Mdot
.58739 .34234 Mdot
.42255 .36855 Mdot
.56573 .3387 Mdot
.39282 .6096 Mdot
.66175 .61401 Mdot
.40207 .34291 Mdot
.73726 .60416 Mdot
.3923 .38429 Mdot
.45442 .60056 Mdot
.65023 .30681 Mdot
.43754 .33389 Mdot
.3393 .5782 Mdot
.66259 .61591 Mdot
.30666 .52867 Mdot
.67049 .5673 Mdot
.44371 .59981 Mdot
.43643 .59506 Mdot
.68533 .49965 Mdot
.57911 .36124 Mdot
.62146 .62255 Mdot
.19494 .41385 Mdot
.34524 .41898 Mdot
.64864 .62002 Mdot
.39125 .5527 Mdot
.57281 .4467 Mdot
.63278 .58619 Mdot
.33496 .53055 Mdot
.58804 .36133 Mdot
.65283 .63504 Mdot
.39321 .57139 Mdot
.41124 .72619 Mdot
.33786 .42938 Mdot
.42996 .31801 Mdot
.53601 .44481 Mdot
.40433 .33197 Mdot
.61303 .29691 Mdot
.37612 .36255 Mdot
.5999 .34414 Mdot
.66549 .53338 Mdot
.45528 .47279 Mdot
.59927 .29567 Mdot
.61418 .28918 Mdot
.42537 .33947 Mdot
.44687 .64282 Mdot
.47838 .41557 Mdot
.37747 .57955 Mdot
.47185 .56379 Mdot
.61646 .31754 Mdot
.66652 .63134 Mdot
.61495 .59687 Mdot
.54959 .58519 Mdot
.64926 .57699 Mdot
.40086 .34961 Mdot
.60206 .47649 Mdot
.38178 .74622 Mdot
.57661 .33056 Mdot
.41912 .29127 Mdot
.43141 .64409 Mdot
.42953 .33595 Mdot
.39832 .3566 Mdot
.61033 .32456 Mdot
.4506 .74425 Mdot
.48475 .57951 Mdot
.65241 .5655 Mdot
.63656 .62947 Mdot
.62889 .58936 Mdot
.65907 .64317 Mdot
.24405 .68056 Mdot
.6136 .30253 Mdot
.67268 .6246 Mdot
.45892 .64706 Mdot
.42459 .57729 Mdot
.66684 .47385 Mdot
.31803 .42677 Mdot
.40831 .57103 Mdot
.4354 .55766 Mdot
.42893 .61805 Mdot
.43363 .3317 Mdot
.39493 .68807 Mdot
.66204 .49844 Mdot
.37668 .37255 Mdot
.37931 .35021 Mdot
.68104 .48794 Mdot
.6827 .55299 Mdot
.80868 .37449 Mdot
.42562 .63026 Mdot
.67275 .6696 Mdot
.43423 .34086 Mdot
.5285 .51584 Mdot
.52002 .63267 Mdot
.43413 .65298 Mdot
.48696 .3871 Mdot
.4071 .34903 Mdot
.6369 .65118 Mdot
.42606 .60439 Mdot
.68054 .49984 Mdot
.33797 .44156 Mdot
.38438 .56838 Mdot
.68093 .47719 Mdot
.63796 .61272 Mdot
.37356 .25765 Mdot
.63294 .56784 Mdot
.43845 .33332 Mdot
.48458 .58839 Mdot
.3549 .86761 Mdot
.41137 .36441 Mdot
.77021 .47864 Mdot
.44508 .47227 Mdot
.45642 .59249 Mdot
.39754 .34444 Mdot
.65192 .65196 Mdot
.61605 .31267 Mdot
.54253 .42584 Mdot
.65966 .62781 Mdot
.68468 .49631 Mdot
.67388 .47659 Mdot
.41978 .34715 Mdot
.62631 .62075 Mdot
.47621 .60095 Mdot
.66583 .58779 Mdot
.57084 .33338 Mdot
.39848 .63295 Mdot
.77908 .35592 Mdot
.4321 .5421 Mdot
.66642 .59102 Mdot
.44226 .3705 Mdot
.28484 .43153 Mdot
.40537 .64925 Mdot
.80768 .46512 Mdot
.45944 .587 Mdot
.58018 .33962 Mdot
.48958 .49929 Mdot
.54778 .69183 Mdot
.43819 .63452 Mdot
.42521 .63942 Mdot
.62698 .33419 Mdot
.43347 .63148 Mdot
.46563 .65595 Mdot
.54224 .33412 Mdot
.63909 .58317 Mdot
.45704 .61699 Mdot
.39686 .33636 Mdot
.62573 .67569 Mdot
.40014 .59758 Mdot
.69859 .5389 Mdot
.30966 .51975 Mdot
.47097 .48609 Mdot
.46418 .57113 Mdot
.24029 .4758 Mdot
.43336 .59614 Mdot
.44719 .65784 Mdot
.43591 .63878 Mdot
.55212 .80115 Mdot
.42217 .33694 Mdot
.39234 .33331 Mdot
.33931 .44231 Mdot
.32189 .51582 Mdot
.29009 .44486 Mdot
.62279 .34037 Mdot
.41452 .28699 Mdot
.66832 .50782 Mdot
.64026 .60135 Mdot
.40343 .59569 Mdot
.3872 .38089 Mdot
.43245 .61479 Mdot
.40639 .63155 Mdot
.40783 .34256 Mdot
.40107 .35496 Mdot
.39297 .31968 Mdot
.32749 .41842 Mdot
.64793 .60776 Mdot
.40993 .6074 Mdot
.31022 .41855 Mdot
.47184 .59667 Mdot
.58159 .43386 Mdot
.64833 .61019 Mdot
.6642 .58666 Mdot
.61976 .58354 Mdot
.41229 .58246 Mdot
.39208 .62 Mdot
.612 .33645 Mdot
.62231 .63173 Mdot
.58227 .31313 Mdot
.39855 .34237 Mdot
.42494 .3273 Mdot
.42228 .60535 Mdot
.46436 .69607 Mdot
.31462 .42846 Mdot
.42073 .37233 Mdot
.65721 .48254 Mdot
.3382 .44579 Mdot
.46516 .61798 Mdot
.40171 .33638 Mdot
.33011 .45505 Mdot
.50537 .70038 Mdot
.7468 .30573 Mdot
.31837 .41571 Mdot
.45344 .64141 Mdot
.67411 .73205 Mdot
.24603 .6046 Mdot
.33975 .41585 Mdot
.58744 .34709 Mdot
.44168 .57739 Mdot
.50884 .17612 Mdot
.27608 .45208 Mdot
.23331 .63449 Mdot
.41068 .3378 Mdot
.51755 .66585 Mdot
.38696 .56492 Mdot
.39762 .76588 Mdot
.27416 .45158 Mdot
.66754 .59658 Mdot
.63862 .63509 Mdot
.44931 .63664 Mdot
.35619 .43655 Mdot
.61306 .29877 Mdot
.43736 .36431 Mdot
.38091 .3584 Mdot
.62053 .61133 Mdot
.60856 .46172 Mdot
.39786 .33631 Mdot
.48531 .65354 Mdot
.35207 .3882 Mdot
.38668 .54065 Mdot
.28045 .72857 Mdot
.74437 .65547 Mdot
.47504 .5834 Mdot
.28845 .42763 Mdot
.60396 .35985 Mdot
.61013 .33212 Mdot
.601 .33749 Mdot
.42196 .32552 Mdot
.55924 .47609 Mdot
.38383 .35468 Mdot
.71424 .49442 Mdot
.31418 .43385 Mdot
.3004 .55414 Mdot
.42923 .56158 Mdot
.45613 .59306 Mdot
.47285 .64918 Mdot
.42778 .63537 Mdot
.43422 .5978 Mdot
.6117 .31522 Mdot
.44502 .34583 Mdot
.43231 .21754 Mdot
.62397 .60436 Mdot
.6763 .41225 Mdot
.43877 .34567 Mdot
.67005 .46817 Mdot
.3182 .44813 Mdot
.24438 .49786 Mdot
.34214 .37771 Mdot
.43286 .36632 Mdot
.43 .66394 Mdot
.66601 .63506 Mdot
.35171 .72448 Mdot
.42999 .58638 Mdot
.41899 .37398 Mdot
.38512 .39644 Mdot
.46629 .75045 Mdot
.40796 .67308 Mdot
.35953 .40476 Mdot
.5722 .44979 Mdot
.27771 .43215 Mdot
.41274 .6657 Mdot
.53787 .51827 Mdot
.41911 .33925 Mdot
.42527 .36162 Mdot
.3321 .41538 Mdot
.36068 .63136 Mdot
.64233 .62741 Mdot
.67877 .50795 Mdot
.59313 .34929 Mdot
.43991 .58474 Mdot
.41895 .32543 Mdot
.68395 .65944 Mdot
.53958 .40898 Mdot
.58523 .33259 Mdot
.37727 .37906 Mdot
.44738 .57727 Mdot
.44372 .6352 Mdot
.30322 .4353 Mdot
.25829 .333 Mdot
.37893 .57726 Mdot
.76796 .50109 Mdot
.57874 .48875 Mdot
.40752 .47047 Mdot
.43566 .62003 Mdot
.62565 .58409 Mdot
.67998 .49169 Mdot
.32055 .45286 Mdot
.46809 .59123 Mdot
.79328 .34744 Mdot
.61334 .57683 Mdot
.59933 .31296 Mdot
.68123 .49438 Mdot
.55042 .47742 Mdot
.46099 .58963 Mdot
.42095 .59647 Mdot
.46745 .63855 Mdot
.79416 .34365 Mdot
.38962 .34153 Mdot
.63763 .64097 Mdot
.28684 .45171 Mdot
.66539 .58499 Mdot
.39195 .32824 Mdot
.40078 .46835 Mdot
.46913 .62762 Mdot
.64391 .56779 Mdot
.67102 .60261 Mdot
.57907 .32882 Mdot
.60611 .35606 Mdot
.42803 .31249 Mdot
.46386 .60295 Mdot
.67282 .50863 Mdot
.65987 .63223 Mdot
.44266 .36105 Mdot
.30397 .43564 Mdot
.55466 .34171 Mdot
.41334 .58418 Mdot
.42099 .34405 Mdot
.48276 .60289 Mdot
.64317 .58751 Mdot
.43617 .36042 Mdot
.67472 .46858 Mdot
.32097 .42775 Mdot
.425 .5743 Mdot
.40382 .22954 Mdot
.68245 .49703 Mdot
.3867 .62258 Mdot
.7184 .66703 Mdot
.34722 .46288 Mdot
.74011 .61972 Mdot
.38792 .35742 Mdot
.67045 .50408 Mdot
.64726 .64378 Mdot
.40802 .72877 Mdot
.42216 .36013 Mdot
.71024 .70531 Mdot
.50232 .39112 Mdot
.41845 .62172 Mdot
.64403 .62358 Mdot
.30266 .41431 Mdot
.77516 .49663 Mdot
.24126 .57061 Mdot
.44741 .6121 Mdot
.40487 .33116 Mdot
.33531 .44524 Mdot
.58183 .31504 Mdot
.69565 .53225 Mdot
.31207 .74912 Mdot
.37756 .37319 Mdot
.40615 .59689 Mdot
.66108 .63338 Mdot
.60603 .32044 Mdot
.74589 .69234 Mdot
.44857 .36157 Mdot
.39123 .34961 Mdot
.46031 .65303 Mdot
.28833 .45403 Mdot
.51637 .18093 Mdot
.3932 .33402 Mdot
.43883 .32727 Mdot
.64583 .43708 Mdot
.34256 .43015 Mdot
.45946 .64392 Mdot
.54943 .58468 Mdot
.47558 .63115 Mdot
.72879 .46323 Mdot
.67129 .50543 Mdot
.62504 .60322 Mdot
.41736 .589 Mdot
.41477 .22783 Mdot
.4142 .35972 Mdot
.57374 .45339 Mdot
.61578 .26648 Mdot
.60284 .35779 Mdot
.41365 .32813 Mdot
.43166 .60962 Mdot
.56523 .31867 Mdot
.30932 .42957 Mdot
.47244 .63088 Mdot
.39311 .61468 Mdot
.66085 .65286 Mdot
.57328 .34493 Mdot
.63784 .67746 Mdot
.56917 .32905 Mdot
.62753 .32253 Mdot
.6855 .64151 Mdot
.45054 .63621 Mdot
.42707 .36847 Mdot
.45759 .34219 Mdot
.47832 .59919 Mdot
.52799 .5146 Mdot
.64324 .62664 Mdot
.38245 .3239 Mdot
.77365 .3102 Mdot
.49311 .63102 Mdot
.6592 .47231 Mdot
.52689 .66113 Mdot
.60847 .3057 Mdot
.42164 .62115 Mdot
.64254 .59459 Mdot
.44686 .33929 Mdot
.40613 .32683 Mdot
.38127 .62586 Mdot
.61117 .32381 Mdot
.31038 .46375 Mdot
.39673 .36056 Mdot
.54477 .40717 Mdot
.45375 .60618 Mdot
.69137 .50873 Mdot
.39642 .36487 Mdot
.79658 .62717 Mdot
.42079 .22389 Mdot
.62071 .60333 Mdot
.41635 .64093 Mdot
.68254 .61701 Mdot
.28562 .44919 Mdot
.37257 .36824 Mdot
.61442 .32863 Mdot
.34949 .68595 Mdot
.21159 .36499 Mdot
.42655 .33381 Mdot
.64048 .60981 Mdot
.40882 .59813 Mdot
.50926 .64437 Mdot
.45704 .58833 Mdot
.29486 .67353 Mdot
.35211 .41107 Mdot
.59423 .29117 Mdot
.58849 .30935 Mdot
.4159 .63151 Mdot
.31984 .42 Mdot
.44635 .32258 Mdot
.40958 .34138 Mdot
.13171 .53985 Mdot
.68048 .47578 Mdot
.36678 .40881 Mdot
.41306 .5824 Mdot
.43736 .36819 Mdot
.65379 .72997 Mdot
.58105 .31236 Mdot
.47792 .62875 Mdot
.39504 .39196 Mdot
.72854 .43372 Mdot
.57009 .4453 Mdot
.4518 .60956 Mdot
.45481 .69367 Mdot
.58734 .34466 Mdot
.6702 .36237 Mdot
.38636 .36434 Mdot
.47393 .60898 Mdot
.60053 .37174 Mdot
.63575 .49016 Mdot
.20221 .40742 Mdot
.64834 .6079 Mdot
.42677 .38365 Mdot
.61602 .343 Mdot
.41142 .69398 Mdot
.31111 .42666 Mdot
.4489 .33389 Mdot
.39696 .38998 Mdot
.40429 .6371 Mdot
.40879 .5721 Mdot
.43305 .69076 Mdot
.63886 .61922 Mdot
.60107 .35405 Mdot
.4056 .61946 Mdot
.60066 .44439 Mdot
.42029 .62745 Mdot
.60687 .34928 Mdot
.22654 .76096 Mdot
.38647 .63391 Mdot
.42688 .58277 Mdot
.3359 .56295 Mdot
.6179 .61333 Mdot
.64778 .58093 Mdot
.59451 .46403 Mdot
.41407 .58122 Mdot
.5192 .36949 Mdot
.64656 .60548 Mdot
.64961 .6257 Mdot
.51671 .37162 Mdot
.40149 .63938 Mdot
.63782 .34211 Mdot
.60725 .32333 Mdot
.60449 .35679 Mdot
.65009 .58361 Mdot
.4674 .55296 Mdot
.61764 .35098 Mdot
.44626 .77729 Mdot
.43818 .35844 Mdot
.53832 .51854 Mdot
.66703 .58943 Mdot
.51912 .40607 Mdot
.5797 .36059 Mdot
.80729 .65002 Mdot
.34315 .70511 Mdot
.48267 .62842 Mdot
.44366 .63675 Mdot
.2955 .4465 Mdot
.52229 .58839 Mdot
.67575 .47476 Mdot
.60676 .33297 Mdot
.50658 .21632 Mdot
.65293 .61219 Mdot
.43714 .57977 Mdot
.22696 .52495 Mdot
.75432 .65342 Mdot
.55162 .56942 Mdot
.65899 .62588 Mdot
.65648 .61555 Mdot
.39772 .38166 Mdot
.43888 .35962 Mdot
.46494 .63388 Mdot
.6038 .33989 Mdot
.64283 .6337 Mdot
.58585 .35522 Mdot
.4179 .33837 Mdot
.4361 .35845 Mdot
.65933 .48835 Mdot
.50128 .58925 Mdot
.4162 .3308 Mdot
.6537 .43717 Mdot
.5991 .44287 Mdot
.65013 .65046 Mdot
.48538 .15635 Mdot
.74113 .70452 Mdot
.33365 .57201 Mdot
.3384 .44051 Mdot
.65275 .51773 Mdot
.56832 .35412 Mdot
.41804 .63286 Mdot
.4168 .6034 Mdot
.66541 .48014 Mdot
.57496 .36205 Mdot
.30806 .45198 Mdot
.57612 .35934 Mdot
.32705 .44606 Mdot
.40075 .32402 Mdot
.39969 .59539 Mdot
.46778 .60616 Mdot
.59219 .31269 Mdot
.40473 .38015 Mdot
.43691 .33237 Mdot
.33406 .428 Mdot
.25373 .50183 Mdot
.41874 .34608 Mdot
.66717 .58937 Mdot
.6166 .68383 Mdot
.67218 .47621 Mdot
.42668 .60422 Mdot
.23462 .50318 Mdot
.44504 .7612 Mdot
.41466 .61816 Mdot
.68161 .49546 Mdot
.12357 .51077 Mdot
.39762 .59903 Mdot
.1836 .63394 Mdot
.66296 .49865 Mdot
.62351 .58322 Mdot
.39946 .37399 Mdot
.684 .48446 Mdot
.39867 .6909 Mdot
.36371 .43886 Mdot
.48733 .60458 Mdot
.64788 .63019 Mdot
.6436 .57037 Mdot
.462 .46673 Mdot
.72736 .4604 Mdot
.28786 .45607 Mdot
.31548 .44508 Mdot
.42171 .35768 Mdot
.54618 .37269 Mdot
.46533 .66934 Mdot
.31176 .44693 Mdot
.54839 .20855 Mdot
.43306 .64557 Mdot
.36136 .47083 Mdot
.4885 .39564 Mdot
.62125 .59189 Mdot
.36253 .56158 Mdot
.41811 .35966 Mdot
.64109 .60998 Mdot
.47177 .43599 Mdot
.47536 .64049 Mdot
.64991 .61133 Mdot
.59807 .35652 Mdot
.54326 .30173 Mdot
.65523 .57726 Mdot
.5422 .42273 Mdot
.60267 .32191 Mdot
.34774 .46455 Mdot
.27781 .58919 Mdot
.82571 .33252 Mdot
.60704 .3354 Mdot
.40836 .37659 Mdot
.42243 .32844 Mdot
.41537 .34898 Mdot
.65681 .6291 Mdot
.4027 .35904 Mdot
.629 .6109 Mdot
.62445 .28784 Mdot
.24627 .48389 Mdot
.30421 .43972 Mdot
.36602 .34002 Mdot
.66451 .60039 Mdot
.7202 .49403 Mdot
.41219 .17668 Mdot
.45474 .64504 Mdot
.60378 .29638 Mdot
.29741 .42135 Mdot
.60168 .51041 Mdot
.29594 .44937 Mdot
.40142 .37623 Mdot
.53996 .51936 Mdot
.4452 .616 Mdot
.73295 .64989 Mdot
.33061 .45035 Mdot
.6593 .62691 Mdot
.43554 .66179 Mdot
.45426 .32378 Mdot
.29231 .43656 Mdot
.33809 .43691 Mdot
.43262 .59862 Mdot
.65174 .57212 Mdot
.43022 .36716 Mdot
.56401 .34728 Mdot
.33447 .41176 Mdot
.46986 .68744 Mdot
.44309 .64004 Mdot
.40701 .65674 Mdot
.57598 .4654 Mdot
.51967 .17566 Mdot
.60128 .32628 Mdot
.24094 .60341 Mdot
.42781 .33097 Mdot
.24354 .57807 Mdot
.75872 .53843 Mdot
.34085 .371 Mdot
.66941 .50569 Mdot
.67222 .50574 Mdot
.44623 .6059 Mdot
.55589 .18023 Mdot
.52081 .55393 Mdot
.63066 .3467 Mdot
.67305 .47951 Mdot
.43782 .33326 Mdot
.60578 .61093 Mdot
.35299 .5877 Mdot
.41183 .56367 Mdot
.57817 .36464 Mdot
.41446 .34245 Mdot
.62318 .23104 Mdot
.31387 .43499 Mdot
.59176 .50422 Mdot
.4634 .61236 Mdot
.43813 .60619 Mdot
.59052 .32401 Mdot
.61181 .33466 Mdot
.70167 .49519 Mdot
.4943 .4741 Mdot
.78496 .376 Mdot
.63286 .30827 Mdot
.61893 .22534 Mdot
.60753 .64944 Mdot
.65363 .58826 Mdot
.66171 .47042 Mdot
.62405 .34205 Mdot
.42117 .5902 Mdot
.62088 .5871 Mdot
.53934 .56289 Mdot
.6466 .65592 Mdot
.36284 .47125 Mdot
.52624 .38821 Mdot
.46488 .6126 Mdot
.6651 .63754 Mdot
.64317 .61093 Mdot
.676 .6313 Mdot
.67989 .48678 Mdot
.43362 .62115 Mdot
.44799 .64415 Mdot
.39659 .6013 Mdot
.50895 .64285 Mdot
.44977 .6031 Mdot
.76131 .53334 Mdot
.61365 .4438 Mdot
.27137 .36132 Mdot
.40797 .58687 Mdot
.61186 .34763 Mdot
.40397 .59162 Mdot
.31605 .42119 Mdot
.41037 .57987 Mdot
.35823 .47141 Mdot
.5966 .3347 Mdot
.36811 .66725 Mdot
.42085 .29843 Mdot
.46745 .62101 Mdot
.29897 .46367 Mdot
.52533 .17478 Mdot
.22659 .54618 Mdot
.64708 .43724 Mdot
.6663 .58871 Mdot
.419 .31213 Mdot
.5983 .299 Mdot
.42846 .36585 Mdot
.47947 .62272 Mdot
.65836 .48998 Mdot
.65651 .80173 Mdot
.50708 .4154 Mdot
.42018 .58906 Mdot
.50573 .59301 Mdot
.62808 .584 Mdot
.41156 .36065 Mdot
.63087 .65619 Mdot
.45979 .65202 Mdot
.28283 .44104 Mdot
.29251 .42761 Mdot
.42888 .46086 Mdot
.56729 .24856 Mdot
.36074 .72383 Mdot
.5924 .32508 Mdot
.4125 .32246 Mdot
.27464 .45298 Mdot
.57734 .58492 Mdot
.61558 .30053 Mdot
.60757 .30561 Mdot
.57438 .34628 Mdot
.45455 .5966 Mdot
.66045 .47892 Mdot
.55406 .23067 Mdot
.68485 .492 Mdot
.46733 .64691 Mdot
.3942 .38872 Mdot
.68557 .48734 Mdot
.29238 .44527 Mdot
.6264 .32096 Mdot
.4359 .33525 Mdot
.43958 .59594 Mdot
.65074 .60157 Mdot
.22908 .58472 Mdot
.3219 .24421 Mdot
.36774 .34569 Mdot
.36997 .33963 Mdot
.62191 .57727 Mdot
.81522 .48018 Mdot
.56494 .30845 Mdot
.44779 .7472 Mdot
.29059 .41634 Mdot
.47929 .60197 Mdot
.15587 .50704 Mdot
.38439 .3557 Mdot
.40088 .34507 Mdot
.4566 .6129 Mdot
.44522 .36247 Mdot
.44714 .58122 Mdot
.38681 .37016 Mdot
.76449 .45361 Mdot
.40829 .56346 Mdot
.40103 .34807 Mdot
.45142 .67347 Mdot
.40234 .64771 Mdot
.63032 .58025 Mdot
.4493 .33672 Mdot
.48322 .62941 Mdot
.60181 .84179 Mdot
.58125 .32338 Mdot
.67961 .48514 Mdot
.38417 .30943 Mdot
.56722 .3441 Mdot
.63269 .62041 Mdot
.39963 .58799 Mdot
.30855 .43098 Mdot
.65985 .59369 Mdot
.44518 .31446 Mdot
.32307 .45603 Mdot
.60265 .47407 Mdot
.65283 .58573 Mdot
.66585 .47628 Mdot
.32347 .42897 Mdot
.48767 .60488 Mdot
.40434 .34186 Mdot
.3927 .22115 Mdot
.68392 .48921 Mdot
.44027 .61668 Mdot
.4351 .37985 Mdot
.57559 .35865 Mdot
.46146 .63169 Mdot
.41456 .32374 Mdot
.68135 .49063 Mdot
.38775 .62452 Mdot
.38629 .62482 Mdot
.35296 .6247 Mdot
.48627 .50763 Mdot
.30021 .43961 Mdot
.6891 .63385 Mdot
.46055 .64686 Mdot
.32305 .42016 Mdot
.44033 .25314 Mdot
.44648 .56467 Mdot
.67794 .59503 Mdot
.38139 .70843 Mdot
.43292 .36989 Mdot
.58474 .31062 Mdot
.45608 .34834 Mdot
.33543 .44967 Mdot
.22426 .29732 Mdot
.66586 .47018 Mdot
.50914 .60952 Mdot
.47107 .65327 Mdot
.37409 .3801 Mdot
.64466 .61402 Mdot
.79332 .39737 Mdot
.41949 .57703 Mdot
.44159 .54567 Mdot
.42857 .60077 Mdot
.40915 .23625 Mdot
.64699 .62691 Mdot
.42668 .60208 Mdot
.48444 .6799 Mdot
.48698 .64134 Mdot
.28879 .4628 Mdot
.29997 .56764 Mdot
.40473 .60456 Mdot
.43416 .91093 Mdot
.669 .51157 Mdot
.40826 .3448 Mdot
.55736 .43601 Mdot
.37599 .2805 Mdot
.25387 .70675 Mdot
.6333 .61638 Mdot
.56509 .624 Mdot
.42997 .36595 Mdot
.21532 .5696 Mdot
.80955 .50215 Mdot
.40984 .65339 Mdot
.44099 .57602 Mdot
.40149 .37623 Mdot
.44341 .35848 Mdot
.66309 .50623 Mdot
.44225 .56977 Mdot
.44568 .54596 Mdot
.42941 .37941 Mdot
.44105 .59177 Mdot
.50441 .77437 Mdot
.57167 .31376 Mdot
.64783 .5825 Mdot
.58128 .31587 Mdot
.6053 .30645 Mdot
.39358 .75001 Mdot
.57797 .49032 Mdot
.61067 .34349 Mdot
.57647 .36936 Mdot
.32285 .49368 Mdot
.33629 .66785 Mdot
.28566 .46037 Mdot
.58535 .25752 Mdot
.42065 .35296 Mdot
.43186 .62126 Mdot
.66484 .6273 Mdot
.35153 .75958 Mdot
.71885 .3092 Mdot
.55521 .52601 Mdot
.45108 .64727 Mdot
.41448 .35695 Mdot
.68288 .49179 Mdot
.41122 .5619 Mdot
.24692 .59552 Mdot
.44371 .60997 Mdot
.4412 .35688 Mdot
.38402 .74918 Mdot
.68208 .53908 Mdot
.63197 .30841 Mdot
.60575 .61924 Mdot
.40238 .59403 Mdot
.6353 .59461 Mdot
.61781 .33525 Mdot
.32606 .41866 Mdot
.30261 .44678 Mdot
.4679 .61602 Mdot
.45675 .47265 Mdot
.25673 .47007 Mdot
.40993 .65302 Mdot
.40228 .63616 Mdot
.66738 .50375 Mdot
.40116 .63505 Mdot
.4729 .61103 Mdot
.40822 .61988 Mdot
.45033 .56998 Mdot
.6282 .32926 Mdot
.72583 .64352 Mdot
.41453 .57251 Mdot
.49271 .6388 Mdot
.5598 .3398 Mdot
.37283 .636 Mdot
.58992 .34281 Mdot
.7434 .31791 Mdot
.59752 .34834 Mdot
.30302 .44541 Mdot
.45344 .36306 Mdot
.58137 .63593 Mdot
.64109 .63308 Mdot
.61553 .34568 Mdot
.32532 .44033 Mdot
.6047 .33616 Mdot
.40068 .32848 Mdot
.44106 .17657 Mdot
.68752 .59133 Mdot
.58554 .42969 Mdot
.32138 .61724 Mdot
.69314 .50545 Mdot
.4252 .37701 Mdot
.62161 .61269 Mdot
.68725 .54052 Mdot
.4127 .62886 Mdot
.30222 .43337 Mdot
.44519 .60591 Mdot
.62489 .31443 Mdot
.41649 .35489 Mdot
.64283 .29619 Mdot
.29912 .44049 Mdot
.26764 .26585 Mdot
.38836 .38072 Mdot
.50363 .62517 Mdot
.5611 .33151 Mdot
.45902 .16409 Mdot
.59447 .34623 Mdot
.24565 .48569 Mdot
.69322 .57698 Mdot
.32582 .73335 Mdot
.66113 .60985 Mdot
.69053 .51567 Mdot
.84627 .46884 Mdot
.79468 .48766 Mdot
.65185 .59319 Mdot
.41914 .29789 Mdot
.45153 .5989 Mdot
.42314 .63165 Mdot
.48422 .6579 Mdot
.61851 .64257 Mdot
.46599 .63998 Mdot
.67286 .47352 Mdot
.5812 .47355 Mdot
.5208 .19324 Mdot
.42659 .31371 Mdot
.45134 .58273 Mdot
.61568 .31636 Mdot
.62684 .31362 Mdot
.6862 .49164 Mdot
.56939 .33839 Mdot
.39814 .64154 Mdot
.66407 .60278 Mdot
.47638 .41936 Mdot
.2865 .44678 Mdot
.7603 .50665 Mdot
.27448 .42945 Mdot
.3442 .39533 Mdot
.49132 .63492 Mdot
.43594 .35931 Mdot
.17757 .42516 Mdot
.42296 .6357 Mdot
.64431 .60544 Mdot
.46024 .65576 Mdot
.40536 .61437 Mdot
.40585 .60164 Mdot
.41532 .32264 Mdot
.56048 .43561 Mdot
.438 .58998 Mdot
.61421 .34131 Mdot
.51379 .37538 Mdot
.41472 .56468 Mdot
.51605 .22547 Mdot
.36506 .4715 Mdot
.69076 .50906 Mdot
.64712 .64964 Mdot
.41366 .37179 Mdot
.65511 .61262 Mdot
.59822 .58576 Mdot
.63236 .62025 Mdot
.52683 .21789 Mdot
.41814 .73199 Mdot
.19909 .66136 Mdot
.63261 .73767 Mdot
.39137 .75998 Mdot
.64755 .56575 Mdot
.48132 .25829 Mdot
.64711 .59148 Mdot
.63242 .61831 Mdot
.15403 .65226 Mdot
.67722 .60841 Mdot
.42264 .60678 Mdot
.38788 .60087 Mdot
.77051 .61741 Mdot
.32368 .49527 Mdot
.40842 .58435 Mdot
.46564 .63821 Mdot
.27982 .43983 Mdot
.42293 .71107 Mdot
.67321 .51802 Mdot
.58692 .4964 Mdot
.65605 .47158 Mdot
.4336 .59877 Mdot
.46246 .61985 Mdot
.38242 .63161 Mdot
.85256 .47761 Mdot
.32936 .75298 Mdot
.62675 .57656 Mdot
.3861 .66809 Mdot
.6528 .45791 Mdot
.46443 .65772 Mdot
.4668 .65385 Mdot
.39372 .60826 Mdot
.42791 .36796 Mdot
.60591 .60849 Mdot
.3987 .56191 Mdot
.74232 .55904 Mdot
.46366 .61424 Mdot
.33176 .39927 Mdot
.26225 .45679 Mdot
.43065 .60975 Mdot
.67623 .59473 Mdot
.43723 .64325 Mdot
.67664 .62597 Mdot
.64578 .58384 Mdot
.49854 .58461 Mdot
.55908 .23543 Mdot
.60297 .60899 Mdot
.40663 .65214 Mdot
.41019 .37903 Mdot
.77001 .49237 Mdot
.43782 .61552 Mdot
.29198 .45671 Mdot
.42167 .62186 Mdot
.30264 .46443 Mdot
.39522 .6237 Mdot
.68472 .49453 Mdot
.53809 .70173 Mdot
.42541 .35998 Mdot
.32819 .41142 Mdot
.43828 .36875 Mdot
.34872 .56372 Mdot
.67309 .58022 Mdot
.66752 .52112 Mdot
.32358 .76139 Mdot
.66611 .5026 Mdot
.23643 .61208 Mdot
.52155 .35713 Mdot
.59828 .30836 Mdot
.65638 .64416 Mdot
.37783 .73896 Mdot
.53554 .25187 Mdot
.38182 .33736 Mdot
.37927 .34876 Mdot
.18825 .4288 Mdot
.13626 .48914 Mdot
.43412 .58655 Mdot
.50123 .17268 Mdot
.55208 .73675 Mdot
.46915 .67116 Mdot
.37807 .63211 Mdot
.40299 .38985 Mdot
.40348 .58678 Mdot
.53394 .43526 Mdot
.42498 .33869 Mdot
.32106 .4389 Mdot
.6261 .60173 Mdot
.32973 .42803 Mdot
.69731 .28408 Mdot
.61637 .42976 Mdot
.4205 .33262 Mdot
.44159 .56586 Mdot
.44701 .58567 Mdot
.6462 .64539 Mdot
.71852 .7034 Mdot
.64098 .58238 Mdot
.28848 .45832 Mdot
.43013 .3478 Mdot
.38262 .76832 Mdot
.4148 .61219 Mdot
.67187 .60697 Mdot
.42736 .30029 Mdot
.44224 .63438 Mdot
.59977 .31104 Mdot
.44994 .64783 Mdot
.67179 .59848 Mdot
.40052 .63394 Mdot
.66254 .60386 Mdot
.392 .37582 Mdot
.4652 .5943 Mdot
.4628 .62229 Mdot
.2359 .62167 Mdot
.30612 .45281 Mdot
.66939 .57667 Mdot
.53672 .43779 Mdot
.47539 .63172 Mdot
.24915 .59663 Mdot
.39897 .59648 Mdot
.45086 .53086 Mdot
.37357 .61094 Mdot
.6691 .47247 Mdot
.47431 .65172 Mdot
.43865 .61503 Mdot
.68009 .73723 Mdot
.665 .73076 Mdot
.36311 .54517 Mdot
.60848 .35474 Mdot
.67189 .58939 Mdot
.42018 .3276 Mdot
.44476 .33718 Mdot
.40255 .36431 Mdot
.30841 .50054 Mdot
.44697 .69989 Mdot
.44683 .6185 Mdot
.60683 .28863 Mdot
.31413 .44356 Mdot
.66669 .62026 Mdot
.30824 .44206 Mdot
.58214 .50077 Mdot
.30538 .46025 Mdot
.67243 .47184 Mdot
.4226 .2222 Mdot
.4723 .77295 Mdot
.31134 .45705 Mdot
.64252 .58244 Mdot
.52944 .38078 Mdot
.48079 .60586 Mdot
.70422 .43094 Mdot
.28255 .44108 Mdot
.19378 .41229 Mdot
.38803 .61545 Mdot
.54449 .43001 Mdot
.58515 .33969 Mdot
.32993 .4289 Mdot
.57259 .34109 Mdot
.43311 .64094 Mdot
.7407 .62607 Mdot
.63967 .60633 Mdot
.57583 .31105 Mdot
.4776 .64816 Mdot
.32927 .42801 Mdot
.41623 .33281 Mdot
.35274 .70533 Mdot
.56389 .35805 Mdot
.22424 .57441 Mdot
.24117 .57125 Mdot
.42999 .34516 Mdot
.43215 .79809 Mdot
.57882 .34486 Mdot
.46985 .57962 Mdot
.50434 .67848 Mdot
.44177 .64799 Mdot
.43506 .32888 Mdot
.39877 .348 Mdot
.78281 .55489 Mdot
.46613 .61312 Mdot
.39276 .59038 Mdot
.60733 .59973 Mdot
.43023 .33495 Mdot
.63347 .62261 Mdot
.63572 .63871 Mdot
.40267 .37752 Mdot
.6204 .60407 Mdot
.33145 .44912 Mdot
.56636 .49987 Mdot
.58111 .34639 Mdot
.60711 .316 Mdot
.41781 .33037 Mdot
.41519 .31843 Mdot
.43805 .35478 Mdot
.44711 .65204 Mdot
.62743 .62401 Mdot
.41948 .64581 Mdot
.40398 .5945 Mdot
.70153 .62312 Mdot
.61225 .60523 Mdot
.42778 .64692 Mdot
.49737 .38106 Mdot
.29266 .46591 Mdot
.40152 .34968 Mdot
.58861 .3564 Mdot
.22851 .62184 Mdot
.57097 .31677 Mdot
.4732 .63511 Mdot
.72841 .43686 Mdot
.65609 .62877 Mdot
.2954 .44834 Mdot
.34997 .45244 Mdot
.29678 .44312 Mdot
.57625 .31046 Mdot
.63157 .63933 Mdot
.60219 .46962 Mdot
.46652 .60763 Mdot
.57597 .46841 Mdot
.25707 .62937 Mdot
.75642 .54638 Mdot
.60163 .35432 Mdot
.45642 .64473 Mdot
.66378 .49947 Mdot
.4689 .7518 Mdot
.45058 .61706 Mdot
.47842 .62916 Mdot
.31991 .29161 Mdot
.49285 .63648 Mdot
.66191 .65087 Mdot
.43247 .4701 Mdot
.4662 .58883 Mdot
.35773 .55528 Mdot
.12511 .5635 Mdot
.38718 .61831 Mdot
.46495 .62114 Mdot
.42155 .61279 Mdot
.42056 .63628 Mdot
.68401 .60783 Mdot
.30091 .28888 Mdot
.61857 .32396 Mdot
.56551 .49868 Mdot
.57747 .34768 Mdot
.40422 .33664 Mdot
.51174 .43323 Mdot
.68031 .6212 Mdot
.29601 .44344 Mdot
.48859 .16818 Mdot
.54515 .51379 Mdot
.40034 .38281 Mdot
.27313 .71275 Mdot
.28454 .44191 Mdot
.47912 .59973 Mdot
.3396 .44256 Mdot
.40786 .38996 Mdot
.61161 .32546 Mdot
.42539 .66275 Mdot
.64954 .63189 Mdot
.65628 .57813 Mdot
.45592 .64814 Mdot
.76051 .4985 Mdot
.56789 .34883 Mdot
.2854 .39146 Mdot
.45796 .60102 Mdot
.47825 .62621 Mdot
.63166 .58623 Mdot
.41129 .35911 Mdot
.5203 .36091 Mdot
.31725 .4499 Mdot
.4703 .6624 Mdot
.43404 .64026 Mdot
.57949 .49732 Mdot
.62504 .33589 Mdot
.67226 .48749 Mdot
.46254 .6069 Mdot
.58177 .48328 Mdot
.4714 .6337 Mdot
.49633 .56425 Mdot
.4219 .3765 Mdot
.47006 .56153 Mdot
.44229 .5741 Mdot
.69691 .6604 Mdot
.57564 .34052 Mdot
.64629 .61 Mdot
.68084 .56499 Mdot
.68018 .50106 Mdot
.58563 .31873 Mdot
.43178 .6483 Mdot
.60257 .30334 Mdot
.41144 .61819 Mdot
.43995 .59382 Mdot
.60132 .35471 Mdot
.62997 .62118 Mdot
.782 .38409 Mdot
.72784 .64175 Mdot
.40504 .62698 Mdot
.42713 .62744 Mdot
.32898 .49725 Mdot
.37644 .79307 Mdot
.44074 .57292 Mdot
.62604 .62451 Mdot
.44495 .63522 Mdot
.61123 .31699 Mdot
.29127 .45913 Mdot
.64736 .60049 Mdot
.40706 .32162 Mdot
.38826 .36683 Mdot
.46038 .30666 Mdot
.66817 .47015 Mdot
.44532 .57154 Mdot
.68981 .63354 Mdot
.61162 .5941 Mdot
.59745 .52526 Mdot
.40728 .34482 Mdot
.30481 .46184 Mdot
.39375 .59595 Mdot
.36617 .7145 Mdot
.61421 .31013 Mdot
.44336 .91048 Mdot
.60431 .46608 Mdot
.26475 .44762 Mdot
.4659 .48434 Mdot
.66378 .49522 Mdot
.4242 .58176 Mdot
.32018 .42154 Mdot
.39112 .35999 Mdot
.42638 .63502 Mdot
.44434 .69482 Mdot
.53492 .2621 Mdot
.40343 .32007 Mdot
.59519 .3041 Mdot
.3888 .34952 Mdot
.29875 .465 Mdot
.67397 .47317 Mdot
.64804 .57355 Mdot
.43752 .61113 Mdot
.37669 .54886 Mdot
.41232 .35022 Mdot
.68289 .50269 Mdot
.46874 .62206 Mdot
.66744 .58476 Mdot
.40153 .35553 Mdot
.42831 .5952 Mdot
.45352 .74743 Mdot
.5748 .62171 Mdot
.42508 .35037 Mdot
.44511 .66572 Mdot
.34162 .61945 Mdot
.39409 .32741 Mdot
.39136 .38984 Mdot
.46637 .6384 Mdot
.32929 .43185 Mdot
.45815 .58488 Mdot
.59835 .34387 Mdot
.56067 .43522 Mdot
.59319 .3139 Mdot
.24527 .6074 Mdot
.38656 .59793 Mdot
.54632 .56336 Mdot
.66028 .63814 Mdot
.34876 .43669 Mdot
.65588 .76167 Mdot
.47708 .61216 Mdot
.79902 .37435 Mdot
.52253 .40567 Mdot
.6221 .44036 Mdot
.74955 .29579 Mdot
.31867 .45216 Mdot
.60059 .33777 Mdot
.46632 .62483 Mdot
.55052 .32507 Mdot
.32924 .44554 Mdot
.24483 .61045 Mdot
.46579 .6593 Mdot
.65131 .6258 Mdot
.45691 .60365 Mdot
.67023 .59175 Mdot
.43448 .6296 Mdot
.39403 .6954 Mdot
.33284 .40398 Mdot
.24605 .48751 Mdot
.4782 .59446 Mdot
.49516 .16251 Mdot
.327 .64012 Mdot
.28778 .45213 Mdot
.40243 .62787 Mdot
.66654 .4887 Mdot
.5801 .36185 Mdot
.45144 .19552 Mdot
.43288 .36288 Mdot
.60708 .34632 Mdot
.62585 .59445 Mdot
.44707 .36811 Mdot
.6786 .50537 Mdot
.51576 .66713 Mdot
.3273 .42638 Mdot
.58223 .32244 Mdot
.43558 .61285 Mdot
.46944 .64883 Mdot
.40775 .23519 Mdot
.45691 .82475 Mdot
.62882 .63039 Mdot
.22503 .32301 Mdot
.68649 .63711 Mdot
.3123 .44885 Mdot
.42507 .37446 Mdot
.41714 .5918 Mdot
.45641 .61913 Mdot
.42757 .32446 Mdot
.61653 .60986 Mdot
.35326 .39116 Mdot
.33234 .74242 Mdot
.60382 .26864 Mdot
.29035 .53094 Mdot
.64569 .59798 Mdot
.28664 .52866 Mdot
.27087 .4555 Mdot
.60939 .23622 Mdot
.31303 .602 Mdot
.58982 .31052 Mdot
.29415 .53372 Mdot
.6694 .61937 Mdot
.43217 .58508 Mdot
.66632 .4769 Mdot
.66256 .50131 Mdot
.63257 .59327 Mdot
.40505 .37555 Mdot
.3129 .42641 Mdot
.45648 .60773 Mdot
.58096 .55891 Mdot
.75354 .68833 Mdot
.41896 .3202 Mdot
.51074 .60217 Mdot
.5688 .34644 Mdot
.43873 .63452 Mdot
.28736 .4306 Mdot
.60724 .32867 Mdot
.67838 .47238 Mdot
.54581 .50614 Mdot
.39441 .59374 Mdot
.41155 .47038 Mdot
.58321 .33102 Mdot
.38222 .79803 Mdot
.46199 .6228 Mdot
.57847 .34455 Mdot
.38628 .54469 Mdot
.72177 .56161 Mdot
.48781 .40425 Mdot
.79667 .47785 Mdot
.41646 .30817 Mdot
.38717 .36276 Mdot
.56394 .84721 Mdot
.29171 .41553 Mdot
.61872 .33943 Mdot
.67917 .4779 Mdot
.30626 .57948 Mdot
.57275 .3319 Mdot
.41579 .65878 Mdot
.39829 .59569 Mdot
.38654 .75256 Mdot
.34162 .56394 Mdot
.66957 .5143 Mdot
.54465 .62055 Mdot
.40913 .64813 Mdot
.48061 .58403 Mdot
.45934 .63606 Mdot
.64093 .5709 Mdot
.57694 .31633 Mdot
.61386 .15066 Mdot
.60501 .30054 Mdot
.57074 .54463 Mdot
.42034 .35323 Mdot
.44428 .32487 Mdot
.43048 .60862 Mdot
.50132 .53838 Mdot
.54545 .17068 Mdot
.41106 .60797 Mdot
.3471 .45963 Mdot
.23977 .5696 Mdot
.42968 .5583 Mdot
.61738 .57363 Mdot
.44314 .54521 Mdot
.68825 .61931 Mdot
.60826 .32703 Mdot
.32141 .45107 Mdot
.28466 .46534 Mdot
.59394 .34034 Mdot
.44932 .62218 Mdot
.28627 .46823 Mdot
.43474 .6047 Mdot
.44302 .58574 Mdot
.58748 .50234 Mdot
.29761 .42024 Mdot
.43875 .35434 Mdot
.30074 .44557 Mdot
.63604 .61954 Mdot
.16524 .6818 Mdot
.3092 .43537 Mdot
.33833 .67358 Mdot
.52956 .42345 Mdot
.29207 .53564 Mdot
.65333 .57782 Mdot
.2863 .45593 Mdot
.58227 .31212 Mdot
.61852 .45934 Mdot
.42656 .79332 Mdot
.57559 .31317 Mdot
.45626 .61591 Mdot
.67888 .62389 Mdot
.62048 .58031 Mdot
.63296 .3168 Mdot
.62309 .58757 Mdot
.49853 .60265 Mdot
.40803 .65347 Mdot
.61964 .33457 Mdot
.77362 .63878 Mdot
.57954 .31266 Mdot
.35994 .70751 Mdot
.39202 .61603 Mdot
.64591 .60313 Mdot
.47029 .53729 Mdot
.67817 .65457 Mdot
.65905 .48899 Mdot
.40951 .57966 Mdot
.29646 .43763 Mdot
.55902 .47528 Mdot
.42488 .35207 Mdot
.732 .43575 Mdot
.66614 .58802 Mdot
.6029 .29429 Mdot
.63254 .57908 Mdot
.62405 .62603 Mdot
.57996 .30927 Mdot
.63867 .61488 Mdot
.46253 .61588 Mdot
.68334 .32911 Mdot
.6647 .58888 Mdot
.59005 .32812 Mdot
.29711 .43423 Mdot
.62086 .60805 Mdot
.35656 .38695 Mdot
.4404 .58229 Mdot
.42135 .38082 Mdot
.33226 .41312 Mdot
.67577 .6304 Mdot
.29133 .45824 Mdot
.40912 .34858 Mdot
.31254 .42517 Mdot
.57999 .28884 Mdot
.58245 .29563 Mdot
.55523 .53082 Mdot
.70437 .55824 Mdot
.66291 .62933 Mdot
.40977 .3074 Mdot
.4243 .57795 Mdot
.45507 .59398 Mdot
.33453 .45298 Mdot
.62513 .57425 Mdot
.75968 .48718 Mdot
.52855 .57403 Mdot
.75896 .50847 Mdot
.61714 .34816 Mdot
.21333 .47503 Mdot
.60864 .46303 Mdot
.63366 .43314 Mdot
.41121 .66684 Mdot
.66328 .4927 Mdot
.42775 .60063 Mdot
.22614 .54421 Mdot
.2836 .45746 Mdot
.46413 .28374 Mdot
.46688 .66883 Mdot
.43463 .34318 Mdot
.42506 .62183 Mdot
.49065 .17902 Mdot
.4378 .54126 Mdot
.28035 .44725 Mdot
.5587 .33293 Mdot
.64119 .63315 Mdot
.28546 .44582 Mdot
.38928 .37173 Mdot
.32648 .5286 Mdot
.40184 .65257 Mdot
.40447 .6464 Mdot
.37786 .35743 Mdot
.63721 .6253 Mdot
.4037 .33926 Mdot
.58071 .34634 Mdot
.30898 .43815 Mdot
.41698 .63477 Mdot
.47571 .5693 Mdot
.37511 .38389 Mdot
.61493 .30363 Mdot
.4226 .31821 Mdot
.6066 .30411 Mdot
.6626 .48789 Mdot
.45199 .57293 Mdot
.37821 .38136 Mdot
.41422 .67192 Mdot
.66583 .71903 Mdot
.57324 .51326 Mdot
.61763 .78253 Mdot
.43911 .35441 Mdot
.32719 .5101 Mdot
.59321 .33634 Mdot
.57788 .32831 Mdot
.38846 .74592 Mdot
.54748 .17512 Mdot
.51893 .36957 Mdot
.42048 .18889 Mdot
.58174 .34688 Mdot
.58559 .32402 Mdot
.3929 .36272 Mdot
.63111 .61136 Mdot
.61369 .57081 Mdot
.41565 .38883 Mdot
.23486 .50374 Mdot
.66722 .61973 Mdot
.81975 .41851 Mdot
.38197 .35684 Mdot
.39314 .64984 Mdot
.65996 .5094 Mdot
.28104 .4443 Mdot
.22842 .53551 Mdot
.4354 .18458 Mdot
.41967 .59717 Mdot
.17413 .6065 Mdot
.41822 .37013 Mdot
.5831 .27345 Mdot
.62456 .2461 Mdot
.47565 .64302 Mdot
.426 .62037 Mdot
.45122 .62756 Mdot
.33903 .41627 Mdot
.70665 .70097 Mdot
.41964 .5938 Mdot
.25312 .48663 Mdot
.40687 .56375 Mdot
.39411 .22491 Mdot
.30113 .44535 Mdot
.29372 .67876 Mdot
.43069 .30722 Mdot
.74161 .54468 Mdot
.48945 .63547 Mdot
.58508 .34632 Mdot
.5257 .30776 Mdot
.60853 .34889 Mdot
.58386 .21533 Mdot
.31043 .60425 Mdot
.64291 .56994 Mdot
.45066 .64828 Mdot
.37985 .36744 Mdot
.67675 .62747 Mdot
.51071 .34992 Mdot
.1439 .64179 Mdot
.62888 .33322 Mdot
.14654 .41518 Mdot
.58061 .31855 Mdot
.66378 .50501 Mdot
.63209 .5892 Mdot
.39047 .51377 Mdot
.57472 .47504 Mdot
.63256 .62189 Mdot
.26359 .38315 Mdot
.65221 .5578 Mdot
.29758 .51808 Mdot
.67528 .56893 Mdot
.59511 .33137 Mdot
.58291 .29617 Mdot
.4089 .68185 Mdot
.43295 .57355 Mdot
.58117 .46015 Mdot
.38436 .64844 Mdot
.41419 .58081 Mdot
.42517 .33867 Mdot
.70653 .55358 Mdot
.54542 .35955 Mdot
.64101 .59527 Mdot
.62073 .31724 Mdot
.42428 .61983 Mdot
.40492 .6275 Mdot
.48561 .64719 Mdot
.22043 .57944 Mdot
.8172 .41063 Mdot
.43662 .59048 Mdot
.45581 .54863 Mdot
.40202 .38172 Mdot
.40294 .23295 Mdot
.25723 .29924 Mdot
.31147 .58037 Mdot
.47004 .62122 Mdot
.30393 .45167 Mdot
.27731 .44348 Mdot
.50298 .61559 Mdot
.54554 .55394 Mdot
.35768 .37139 Mdot
.43562 .61311 Mdot
.35196 .51368 Mdot
.36968 .37681 Mdot
.68496 .49843 Mdot
.41225 .34967 Mdot
.67936 .62538 Mdot
.6663 .50434 Mdot
.40817 .32731 Mdot
.44281 .51206 Mdot
.68028 .49941 Mdot
.72532 .55904 Mdot
.28767 .45809 Mdot
.46116 .6316 Mdot
.60033 .63937 Mdot
.42497 .32504 Mdot
.58131 .32871 Mdot
.65821 .59978 Mdot
.59684 .36236 Mdot
.40994 .22571 Mdot
.23354 .527 Mdot
.66523 .47083 Mdot
.58977 .34725 Mdot
.47801 .46175 Mdot
.30357 .45029 Mdot
.57052 .32899 Mdot
.53891 .56417 Mdot
.41024 .56951 Mdot
.61262 .20309 Mdot
.41912 .65558 Mdot
.79171 .53935 Mdot
.57891 .3356 Mdot
.66671 .46434 Mdot
.43922 .61084 Mdot
.38855 .37973 Mdot
.37034 .62885 Mdot
.43597 .60404 Mdot
.39032 .34039 Mdot
.43304 .58685 Mdot
.30992 .41844 Mdot
.68407 .62793 Mdot
.51615 .41057 Mdot
.21153 .53507 Mdot
.301 .42876 Mdot
.63748 .53118 Mdot
.43414 .57176 Mdot
.24164 .38108 Mdot
.64821 .62353 Mdot
.47724 .62442 Mdot
.2406 .66045 Mdot
.63052 .60127 Mdot
.65594 .61344 Mdot
.40685 .64008 Mdot
.57315 .31645 Mdot
.43546 .33195 Mdot
.30162 .44933 Mdot
.54501 .3702 Mdot
.42652 .59332 Mdot
.45879 .64366 Mdot
.28483 .44258 Mdot
.58731 .31918 Mdot
.41871 .63774 Mdot
.75837 .40124 Mdot
.59339 .52597 Mdot
.60853 .30689 Mdot
.41556 .56483 Mdot
.66396 .21065 Mdot
.60914 .57294 Mdot
.17917 .62181 Mdot
.29051 .41758 Mdot
.40989 .37703 Mdot
.50663 .63322 Mdot
.40216 .89695 Mdot
.28605 .45223 Mdot
.74848 .53919 Mdot
.44204 .58986 Mdot
.41172 .59318 Mdot
.66018 .57362 Mdot
.42537 .64918 Mdot
.67524 .60361 Mdot
.20603 .51984 Mdot
.48829 .14726 Mdot
.62764 .58374 Mdot
.67364 .59824 Mdot
.36918 .54631 Mdot
.22434 .59755 Mdot
.62502 .60087 Mdot
.40041 .65166 Mdot
.27056 .36819 Mdot
.46331 .6905 Mdot
.2689 .44252 Mdot
.34552 .44997 Mdot
.62902 .56869 Mdot
.49859 .81586 Mdot
.38892 .53929 Mdot
.36179 .65628 Mdot
.28422 .47957 Mdot
.5971 .351 Mdot
.399 .61011 Mdot
.67154 .47049 Mdot
.39883 .35675 Mdot
.43197 .54544 Mdot
.45926 .62757 Mdot
.67941 .60984 Mdot
.34634 .42046 Mdot
.57091 .33557 Mdot
.46623 .63457 Mdot
.3915 .39968 Mdot
.32235 .4422 Mdot
.66147 .5878 Mdot
.3436 .6815 Mdot
.27836 .45828 Mdot
.48741 .5821 Mdot
.41195 .58473 Mdot
.47022 .62705 Mdot
.46589 .67808 Mdot
.59068 .34051 Mdot
.42887 .38246 Mdot
.50113 .64147 Mdot
.59131 .48565 Mdot
.551 .46846 Mdot
.50331 .63208 Mdot
.62411 .62191 Mdot
.61026 .35224 Mdot
.6788 .49281 Mdot
.30047 .55458 Mdot
.38916 .61717 Mdot
.80942 .39054 Mdot
.30256 .7354 Mdot
.67594 .49878 Mdot
.6741 .57567 Mdot
.29636 .44666 Mdot
.39829 .63703 Mdot
.25401 .45695 Mdot
.41671 .6585 Mdot
.4956 .67431 Mdot
.41494 .37436 Mdot
.59027 .35392 Mdot
.60361 .54625 Mdot
.39798 .35559 Mdot
.65537 .61292 Mdot
.8123 .55117 Mdot
.63386 .56079 Mdot
.62986 .63307 Mdot
.56476 .23198 Mdot
.61203 .33122 Mdot
.42101 .90768 Mdot
.37321 .79391 Mdot
.38409 .62491 Mdot
.61624 .3288 Mdot
.63713 .58828 Mdot
.44342 .65519 Mdot
.66503 .62639 Mdot
.60248 .60448 Mdot
.40526 .58509 Mdot
.41708 .58071 Mdot
.24994 .495 Mdot
.82698 .44374 Mdot
.30349 .43295 Mdot
.62226 .58525 Mdot
.40926 .75164 Mdot
.41946 .58989 Mdot
.46546 .605 Mdot
.53609 .27915 Mdot
.28456 .45315 Mdot
.50357 .7665 Mdot
.45388 .59524 Mdot
.23183 .65192 Mdot
.41418 .57905 Mdot
.59271 .59607 Mdot
.63653 .32267 Mdot
.56042 .55659 Mdot
.4366 .33033 Mdot
.65761 .64498 Mdot
.32341 .45905 Mdot
.64094 .64794 Mdot
.4182 .74032 Mdot
.61034 .32677 Mdot
.672 .59881 Mdot
.45875 .34625 Mdot
.59711 .31894 Mdot
.59116 .30921 Mdot
.50632 .36099 Mdot
.45354 .3586 Mdot
.33034 .41577 Mdot
.5832 .36013 Mdot
.44893 .74525 Mdot
.59781 .3293 Mdot
.4264 .74464 Mdot
.46128 .58449 Mdot
.26715 .50119 Mdot
.58871 .54845 Mdot
.42427 .68871 Mdot
.57394 .32041 Mdot
.3204 .4304 Mdot
.43769 .64956 Mdot
.62069 .59179 Mdot
.31557 .43315 Mdot
.54287 .33132 Mdot
.44331 .3201 Mdot
.61839 .5801 Mdot
.56621 .31827 Mdot
.67557 .61501 Mdot
.23478 .55773 Mdot
.34114 .37662 Mdot
.48529 .3896 Mdot
.57308 .46704 Mdot
.48386 .59824 Mdot
.35861 .55341 Mdot
.47161 .65052 Mdot
.45536 .62181 Mdot
.42438 .35038 Mdot
.30822 .50127 Mdot
.62086 .60899 Mdot
.77855 .66903 Mdot
.58611 .34431 Mdot
.43625 .47084 Mdot
.49795 .67528 Mdot
.41608 .62351 Mdot
.64765 .58884 Mdot
.60815 .61536 Mdot
.66475 .73143 Mdot
.42789 .32401 Mdot
.4587 .69078 Mdot
.49246 .62781 Mdot
.43246 .70427 Mdot
.58453 .3133 Mdot
.76877 .3918 Mdot
.43674 .3225 Mdot
.11732 .47595 Mdot
.4009 .34944 Mdot
.2858 .31683 Mdot
.63786 .61414 Mdot
.31314 .45964 Mdot
.46178 .59688 Mdot
.71807 .6048 Mdot
.68284 .59901 Mdot
.37328 .34351 Mdot
.29312 .44505 Mdot
.77786 .38781 Mdot
.61186 .3397 Mdot
.4699 .59963 Mdot
.40545 .583 Mdot
.41354 .64143 Mdot
.44997 .65822 Mdot
.62152 .32891 Mdot
.427 .66222 Mdot
.56631 .36191 Mdot
.44341 .76042 Mdot
.24532 .66202 Mdot
.38397 .38555 Mdot
.39011 .23333 Mdot
.62407 .62522 Mdot
.51332 .69495 Mdot
.49674 .77286 Mdot
.57428 .5143 Mdot
.6026 .28443 Mdot
.4579 .57865 Mdot
.40303 .37468 Mdot
.5079 .16919 Mdot
.38197 .38188 Mdot
.54932 .12854 Mdot
.37447 .73679 Mdot
.80438 .49248 Mdot
.43601 .6576 Mdot
.39152 .39588 Mdot
.527 .80874 Mdot
.47514 .56782 Mdot
.30562 .46928 Mdot
.40361 .72105 Mdot
.76497 .60602 Mdot
.29992 .46194 Mdot
.43515 .58203 Mdot
.61427 .61492 Mdot
.46147 .61353 Mdot
.45626 .58788 Mdot
.41295 .61166 Mdot
.6316 .33895 Mdot
.40532 .57925 Mdot
.45835 .5854 Mdot
.43732 .81587 Mdot
.36322 .46826 Mdot
.39723 .38272 Mdot
.63278 .76613 Mdot
.31444 .44317 Mdot
.67365 .63141 Mdot
.52734 .40794 Mdot
.60263 .3445 Mdot
.66021 .73164 Mdot
.42919 .65755 Mdot
.76541 .52501 Mdot
.58809 .29517 Mdot
.32823 .43984 Mdot
.68095 .49392 Mdot
.75251 .33691 Mdot
.43995 .36141 Mdot
.66333 .50762 Mdot
.42502 .35329 Mdot
.58845 .80696 Mdot
.6739 .59644 Mdot
.48365 .59579 Mdot
.57303 .34735 Mdot
.40123 .38985 Mdot
.25153 .4714 Mdot
.45127 .63356 Mdot
.43983 .35191 Mdot
.47789 .58674 Mdot
.55483 .46079 Mdot
.53721 .41462 Mdot
.41996 .38493 Mdot
.5759 .30244 Mdot
.59903 .31621 Mdot
.32768 .45474 Mdot
.66298 .64017 Mdot
.64457 .62949 Mdot
.60351 .32521 Mdot
.13615 .51531 Mdot
.42583 .59459 Mdot
.40968 .58842 Mdot
.59571 .47831 Mdot
.45129 .65567 Mdot
.34386 .50731 Mdot
.67748 .51581 Mdot
.66193 .6326 Mdot
.45955 .65303 Mdot
.41744 .63696 Mdot
.39461 .59671 Mdot
.23592 .52768 Mdot
.41116 .3523 Mdot
.40687 .64636 Mdot
.32397 .42346 Mdot
.70138 .49718 Mdot
.42786 .57719 Mdot
.47348 .56904 Mdot
.67513 .60908 Mdot
.20126 .4078 Mdot
.58058 .33446 Mdot
.43091 .33371 Mdot
.38186 .35088 Mdot
.26342 .60324 Mdot
.62336 .64425 Mdot
.67305 .5172 Mdot
.43849 .23937 Mdot
.68038 .48256 Mdot
.29065 .45321 Mdot
.50342 .38276 Mdot
.37223 .40064 Mdot
.38671 .36823 Mdot
.56543 .31452 Mdot
.46594 .64688 Mdot
.41315 .58054 Mdot
.74439 .53453 Mdot
.40686 .59875 Mdot
.29354 .43958 Mdot
.56163 .3338 Mdot
.67386 .60511 Mdot
.29188 .42759 Mdot
.57694 .32715 Mdot
.63595 .62521 Mdot
.42074 .55973 Mdot
.48345 .65569 Mdot
.65931 .60426 Mdot
.65827 .58343 Mdot
.42581 .6109 Mdot
.51577 .84007 Mdot
.65657 .6343 Mdot
.65486 .59125 Mdot
.67501 .4583 Mdot
.43359 .37144 Mdot
.48454 .54721 Mdot
.61528 .3283 Mdot
.46471 .61202 Mdot
.38333 .3862 Mdot
.3061 .4585 Mdot
.66401 .61071 Mdot
.39633 .61208 Mdot
.43437 .5947 Mdot
.30183 .45174 Mdot
.27826 .43336 Mdot
.29322 .43503 Mdot
.62324 .34838 Mdot
.40819 .65284 Mdot
.62329 .60246 Mdot
.61316 .33882 Mdot
.27758 .44668 Mdot
.34236 .43615 Mdot
.43351 .80973 Mdot
.42104 .59965 Mdot
.28747 .47026 Mdot
.21548 .74737 Mdot
.32668 .53503 Mdot
.67044 .50874 Mdot
.37882 .39414 Mdot
.27141 .49842 Mdot
.34019 .41204 Mdot
.61426 .34448 Mdot
.37357 .47094 Mdot
.34918 .42807 Mdot
.4044 .60277 Mdot
.43974 .6373 Mdot
.42412 .66895 Mdot
.31815 .43751 Mdot
.23672 .5452 Mdot
.61575 .58925 Mdot
.5612 .7124 Mdot
.31444 .44301 Mdot
.42388 .38241 Mdot
.37763 .38819 Mdot
.39987 .34743 Mdot
.46562 .58446 Mdot
.66148 .74615 Mdot
.421 .75318 Mdot
.51781 .75938 Mdot
.60837 .34442 Mdot
.60693 .61201 Mdot
.64362 .29692 Mdot
.65638 .614 Mdot
.40515 .36427 Mdot
.32371 .43829 Mdot
.6546 .57084 Mdot
.5973 .30992 Mdot
.59692 .31332 Mdot
.4208 .31624 Mdot
.41074 .34562 Mdot
.41878 .3325 Mdot
.65916 .64391 Mdot
.63832 .6148 Mdot
.41126 .63109 Mdot
.66753 .60372 Mdot
.3117 .75051 Mdot
.26935 .438 Mdot
.37926 .34589 Mdot
.58568 .33445 Mdot
.65237 .58588 Mdot
.46221 .62933 Mdot
.33093 .29308 Mdot
.37548 .34041 Mdot
.30066 .42675 Mdot
.6579 .37571 Mdot
.43296 .14289 Mdot
.42643 .56261 Mdot
.62019 .30915 Mdot
.54543 .55847 Mdot
.44543 .62777 Mdot
.42553 .37124 Mdot
.31154 .71511 Mdot
.68395 .49269 Mdot
.44616 .57812 Mdot
.48023 .6294 Mdot
.57536 .31581 Mdot
.53099 .41044 Mdot
.40742 .60664 Mdot
.4709 .43736 Mdot
.62959 .32051 Mdot
.43607 .32196 Mdot
.58818 .85006 Mdot
.57887 .27902 Mdot
.22955 .4725 Mdot
.67489 .50513 Mdot
.40285 .59883 Mdot
.42566 .34139 Mdot
.31102 .42225 Mdot
.41977 .34368 Mdot
.66689 .56773 Mdot
.4331 .36961 Mdot
.45294 .63942 Mdot
.62418 .60674 Mdot
.5843 .32047 Mdot
.42025 .47174 Mdot
.47103 .8212 Mdot
.38921 .37958 Mdot
.68832 .49066 Mdot
.42766 .57937 Mdot
.47892 .7425 Mdot
.40583 .68048 Mdot
.4404 .5736 Mdot
.60453 .35296 Mdot
.64428 .59099 Mdot
.61583 .34886 Mdot
.44923 .56093 Mdot
.53321 .66266 Mdot
.58906 .3444 Mdot
.7509 .61348 Mdot
.28398 .44326 Mdot
.23422 .50568 Mdot
.44884 .6133 Mdot
.57407 .34813 Mdot
.40251 .6488 Mdot
.62227 .58441 Mdot
.54247 .48786 Mdot
.59889 .55856 Mdot
.56896 .34755 Mdot
.80034 .54485 Mdot
.53692 .43906 Mdot
.47193 .54411 Mdot
.57728 .34548 Mdot
.65557 .76027 Mdot
.66868 .48906 Mdot
.31375 .4521 Mdot
.2779 .4366 Mdot
.33644 .43367 Mdot
.40676 .59572 Mdot
.39943 .70606 Mdot
.34008 .42646 Mdot
.62182 .348 Mdot
.3279 .41945 Mdot
.22835 .58752 Mdot
.76113 .49551 Mdot
.29305 .43277 Mdot
.44895 .60987 Mdot
.46162 .5624 Mdot
.36143 .47127 Mdot
.45362 .338 Mdot
.78319 .36116 Mdot
.39984 .78695 Mdot
.41645 .59285 Mdot
.43223 .72693 Mdot
.64914 .56367 Mdot
.48139 .50885 Mdot
.55484 .61367 Mdot
.53005 .38548 Mdot
.65488 .58887 Mdot
.56592 .44176 Mdot
.66179 .63545 Mdot
.46523 .57352 Mdot
.44119 .5944 Mdot
.68648 .61118 Mdot
.71742 .42741 Mdot
.7244 .72192 Mdot
.76257 .50799 Mdot
.63112 .62686 Mdot
.57541 .34014 Mdot
.62678 .31697 Mdot
.60104 .35436 Mdot
.42394 .32694 Mdot
.66545 .58504 Mdot
.39155 .63048 Mdot
.393 .375 Mdot
.4592 .59668 Mdot
.60513 .31962 Mdot
.59318 .52806 Mdot
.67429 .60481 Mdot
.43812 .61426 Mdot
.43597 .79167 Mdot
.41913 .35907 Mdot
.30653 .45027 Mdot
.67099 .3617 Mdot
.37343 .39183 Mdot
.60035 .30028 Mdot
.59877 .60767 Mdot
.46393 .31981 Mdot
.30295 .28488 Mdot
.38733 .639 Mdot
.38823 .63849 Mdot
.40073 .29413 Mdot
.4633 .80807 Mdot
.4164 .61966 Mdot
.3884 .36963 Mdot
.43241 .37398 Mdot
.39492 .64233 Mdot
.64775 .57504 Mdot
.34425 .42456 Mdot
.3335 .45374 Mdot
.48346 .6094 Mdot
.57699 .45944 Mdot
.25951 .49649 Mdot
.4268 .64524 Mdot
.51777 .61009 Mdot
.45772 .33958 Mdot
.67814 .50532 Mdot
.57643 .49253 Mdot
.33427 .44596 Mdot
.44356 .58929 Mdot
.73968 .69485 Mdot
.66848 .59382 Mdot
.43857 .33781 Mdot
.61279 .31314 Mdot
.28432 .46698 Mdot
.39722 .32094 Mdot
.39452 .64187 Mdot
.4183 .63759 Mdot
.5695 .33725 Mdot
.59239 .59851 Mdot
.3209 .43643 Mdot
.39549 .37758 Mdot
.31337 .4598 Mdot
.64083 .61911 Mdot
.66141 .59219 Mdot
.49337 .62339 Mdot
.41628 .68459 Mdot
.38329 .36367 Mdot
.46284 .66582 Mdot
.39644 .34658 Mdot
.40701 .23466 Mdot
.61533 .31104 Mdot
.47715 .63648 Mdot
.64361 .65491 Mdot
.60494 .32065 Mdot
.41519 .60165 Mdot
.40308 .29317 Mdot
.42528 .63644 Mdot
.40539 .39295 Mdot
.33067 .73282 Mdot
.32887 .44774 Mdot
.35479 .57667 Mdot
.40176 .52485 Mdot
.45214 .65495 Mdot
.44781 .36227 Mdot
.38179 .69528 Mdot
.59314 .3436 Mdot
.63561 .60547 Mdot
.1784 .42954 Mdot
.59262 .32812 Mdot
.45313 .60364 Mdot
.3102 .43594 Mdot
.64068 .63419 Mdot
.66111 .47963 Mdot
.59577 .45841 Mdot
.42811 .54511 Mdot
.37225 .60377 Mdot
.46914 .63086 Mdot
.42208 .18719 Mdot
.4208 .33598 Mdot
.64368 .58724 Mdot
.6244 .31647 Mdot
.60788 .33365 Mdot
.41148 .35947 Mdot
.77541 .58326 Mdot
.7502 .44705 Mdot
.26266 .79428 Mdot
.38796 .3312 Mdot
.33178 .4235 Mdot
.54196 .47488 Mdot
.3965 .35341 Mdot
.42967 .33816 Mdot
.44633 .32085 Mdot
.74832 .51921 Mdot
.62797 .62311 Mdot
.43286 .59289 Mdot
.64364 .64974 Mdot
.40335 .59749 Mdot
.23606 .46169 Mdot
.60635 .32616 Mdot
.63566 .60744 Mdot
.3439 .35577 Mdot
.39171 .54047 Mdot
.43553 .62517 Mdot
.24524 .43456 Mdot
.40087 .55888 Mdot
.29902 .54115 Mdot
.48695 .64689 Mdot
.41773 .3495 Mdot
.55064 .63696 Mdot
.50452 .59194 Mdot
.42681 .78561 Mdot
.59199 .31363 Mdot
.66114 .47344 Mdot
.42423 .55694 Mdot
.50561 .57157 Mdot
.64166 .63584 Mdot
.6569 .57125 Mdot
.34063 .42624 Mdot
.68254 .34239 Mdot
.58904 .31512 Mdot
.79279 .44341 Mdot
.43382 .57279 Mdot
.54901 .36653 Mdot
.32341 .73057 Mdot
.41862 .60839 Mdot
.50113 .37289 Mdot
.66156 .73129 Mdot
.41998 .62705 Mdot
.5319 .75206 Mdot
.58935 .33396 Mdot
.23553 .65506 Mdot
.4783 .65583 Mdot
.42712 .36913 Mdot
.63224 .6108 Mdot
.61826 .58066 Mdot
.3006 .42509 Mdot
.33824 .77274 Mdot
.63984 .35578 Mdot
.63621 .61217 Mdot
.45287 .63017 Mdot
.58166 .33324 Mdot
.65942 .48041 Mdot
.4032 .54281 Mdot
.56328 .19775 Mdot
.66995 .60349 Mdot
.50396 .63715 Mdot
.76859 .51521 Mdot
.55002 .42706 Mdot
.82868 .43351 Mdot
.58986 .35763 Mdot
.33455 .44677 Mdot
.44554 .68387 Mdot
.43513 .24144 Mdot
.47768 .65923 Mdot
.23357 .46568 Mdot
.65916 .66145 Mdot
.29197 .4593 Mdot
.44443 .62395 Mdot
.40832 .60929 Mdot
.56537 .47595 Mdot
.2739 .44273 Mdot
.4071 .60679 Mdot
.49137 .65677 Mdot
.64354 .62651 Mdot
.67824 .51568 Mdot
.67304 .60897 Mdot
.45748 .61699 Mdot
.32727 .71479 Mdot
.6479 .57229 Mdot
.78273 .3715 Mdot
.31172 .40841 Mdot
.60178 .34531 Mdot
.50907 .59248 Mdot
.45377 .57809 Mdot
.76321 .28983 Mdot
.65946 .49178 Mdot
.22656 .33237 Mdot
.39122 .39509 Mdot
.73857 .74208 Mdot
.37106 .38947 Mdot
.80521 .51052 Mdot
.44509 .46465 Mdot
.44057 .66885 Mdot
.32849 .58672 Mdot
.5211 .75214 Mdot
.55128 .32783 Mdot
.496 .71776 Mdot
.43289 .57362 Mdot
.42736 .58301 Mdot
.39153 .36504 Mdot
.78066 .5635 Mdot
.55779 .55989 Mdot
.57469 .48808 Mdot
.32643 .44227 Mdot
.64531 .61375 Mdot
.44842 .6387 Mdot
.6839 .40714 Mdot
.39754 .3871 Mdot
.33416 .67821 Mdot
.43974 .61309 Mdot
.56461 .54752 Mdot
.75741 .57924 Mdot
.58114 .32413 Mdot
.42518 .38268 Mdot
.43904 .37387 Mdot
.39872 .60007 Mdot
.61875 .33132 Mdot
.41422 .62853 Mdot
.53467 .44361 Mdot
.44085 .54727 Mdot
.29596 .45747 Mdot
.46592 .60349 Mdot
.33943 .55411 Mdot
.82403 .54499 Mdot
.47893 .55845 Mdot
.6467 .642 Mdot
.41538 .32934 Mdot
.40657 .35396 Mdot
.64378 .6296 Mdot
.40622 .35486 Mdot
.56122 .71966 Mdot
.46766 .71999 Mdot
.29066 .45469 Mdot
.4912 .78062 Mdot
.32665 .44748 Mdot
.66206 .47198 Mdot
.42165 .60332 Mdot
.49057 .23013 Mdot
.38874 .32953 Mdot
.229 .61878 Mdot
.60135 .32914 Mdot
.66081 .49725 Mdot
.38851 .60525 Mdot
.3029 .47513 Mdot
.40335 .36911 Mdot
.55848 .28048 Mdot
.39495 .60049 Mdot
.61563 .60202 Mdot
.41598 .62266 Mdot
.38548 .58461 Mdot
.66701 .5096 Mdot
.4696 .63404 Mdot
.57688 .32738 Mdot
.66871 .58672 Mdot
.79984 .50192 Mdot
.42518 .32557 Mdot
.44204 .57923 Mdot
.45149 .62959 Mdot
.66501 .57326 Mdot
.38863 .5998 Mdot
.61573 .34112 Mdot
.47526 .91737 Mdot
.28443 .44639 Mdot
.67974 .50433 Mdot
.69728 .28407 Mdot
.44786 .64502 Mdot
.4337 .64708 Mdot
.53613 .37404 Mdot
.7282 .69964 Mdot
.58186 .34302 Mdot
.41184 .55904 Mdot
.40711 .38305 Mdot
.32075 .43368 Mdot
.5792 .36182 Mdot
.41264 .65575 Mdot
.42533 .5845 Mdot
.28753 .45402 Mdot
.24573 .43997 Mdot
.35346 .38533 Mdot
.60686 .34772 Mdot
.45042 .71803 Mdot
.33703 .29166 Mdot
.42987 .60033 Mdot
.65433 .46056 Mdot
.65013 .59386 Mdot
.58157 .34869 Mdot
.71124 .69588 Mdot
.46997 .57891 Mdot
.58805 .30483 Mdot
.5857 .3186 Mdot
.39162 .5938 Mdot
.61665 .63921 Mdot
.62055 .6348 Mdot
.6507 .5922 Mdot
.24931 .65891 Mdot
.29623 .26691 Mdot
.4208 .33129 Mdot
.586 .3299 Mdot
.38031 .38374 Mdot
.34665 .43695 Mdot
.55285 .4675 Mdot
.42544 .38081 Mdot
.62092 .62243 Mdot
.37909 .3715 Mdot
.41885 .63318 Mdot
.60254 .31103 Mdot
.38314 .35276 Mdot
.43922 .65406 Mdot
.51552 .6224 Mdot
.33586 .57144 Mdot
.34466 .42186 Mdot
.56748 .44232 Mdot
.45499 .60896 Mdot
.67987 .49531 Mdot
.42914 .61124 Mdot
.61956 .33602 Mdot
.3755 .47343 Mdot
.41797 .65344 Mdot
.38702 .33184 Mdot
.31901 .26476 Mdot
.44992 .35572 Mdot
.38584 .59311 Mdot
.45664 .61541 Mdot
.42716 .59819 Mdot
.40788 .58381 Mdot
.75868 .61612 Mdot
.55811 .35806 Mdot
.48892 .67837 Mdot
.40226 .31962 Mdot
.65986 .61135 Mdot
.63292 .57437 Mdot
.53048 .3771 Mdot
.65897 .49605 Mdot
.61747 .32867 Mdot
.42706 .59654 Mdot
.55495 .2836 Mdot
.6147 .45171 Mdot
.76659 .50963 Mdot
.4566 .3025 Mdot
.38631 .36536 Mdot
.64248 .64302 Mdot
.39277 .34032 Mdot
.40837 .65415 Mdot
.48218 .65901 Mdot
.80255 .49424 Mdot
.61911 .35555 Mdot
.322 .43743 Mdot
.4612 .5994 Mdot
.23888 .49326 Mdot
.40191 .38168 Mdot
.45792 .34669 Mdot
.41133 .62704 Mdot
.60611 .58045 Mdot
.84818 .50175 Mdot
.61597 .32045 Mdot
.47341 .74315 Mdot
.57257 .60272 Mdot
.4569 .70744 Mdot
.5965 .33998 Mdot
.48881 .39552 Mdot
.44865 .33248 Mdot
.38104 .78556 Mdot
.66144 .60433 Mdot
.32112 .43976 Mdot
.49893 .63569 Mdot
.6214 .62312 Mdot
.37645 .37804 Mdot
.67179 .63017 Mdot
.4829 .59293 Mdot
.62426 .34261 Mdot
.40154 .35294 Mdot
.5523 .34183 Mdot
.68504 .60734 Mdot
.32783 .44723 Mdot
.23738 .61637 Mdot
.46247 .75018 Mdot
.66198 .73077 Mdot
.40562 .64529 Mdot
.52702 .23897 Mdot
.39095 .62749 Mdot
.62328 .63105 Mdot
.44905 .6129 Mdot
.35576 .55792 Mdot
.44327 .32398 Mdot
.50802 .61078 Mdot
.46417 .59581 Mdot
.4174 .77725 Mdot
.42498 .61779 Mdot
.38724 .61361 Mdot
.48287 .62418 Mdot
.5883 .60457 Mdot
.50682 .60986 Mdot
.61615 .60212 Mdot
.75325 .53837 Mdot
.43073 .34034 Mdot
.33965 .44731 Mdot
.30308 .46482 Mdot
.22979 .46334 Mdot
.237 .502 Mdot
.77561 .573 Mdot
.66471 .62044 Mdot
.57932 .31603 Mdot
.41489 .6303 Mdot
.64016 .77672 Mdot
.30744 .6726 Mdot
.4423 .32625 Mdot
.38124 .36637 Mdot
.49035 .64879 Mdot
.51348 .15548 Mdot
.50668 .61918 Mdot
.60283 .46802 Mdot
.4048 .59473 Mdot
.47799 .62947 Mdot
.45603 .35721 Mdot
.23277 .55324 Mdot
.40686 .64644 Mdot
.64245 .63588 Mdot
.31834 .44648 Mdot
.50948 .67417 Mdot
.29814 .6719 Mdot
.36594 .71634 Mdot
.52217 .56042 Mdot
.43091 .66022 Mdot
.40306 .37888 Mdot
.63339 .62985 Mdot
.58797 .48453 Mdot
.61132 .34361 Mdot
.58571 .45763 Mdot
.44075 .75611 Mdot
.64061 .27029 Mdot
.32241 .4416 Mdot
.38707 .3155 Mdot
.45373 .63991 Mdot
.42304 .3276 Mdot
.4523 .56461 Mdot
.61746 .44292 Mdot
.29985 .45946 Mdot
.66981 .63988 Mdot
.57532 .33917 Mdot
.6142 .606 Mdot
.62087 .77998 Mdot
.31285 .68368 Mdot
.73799 .74342 Mdot
.44347 .35367 Mdot
.64061 .67763 Mdot
.631 .59486 Mdot
.39144 .60986 Mdot
.25591 .78702 Mdot
.64706 .59744 Mdot
.61639 .60915 Mdot
.52831 .38958 Mdot
.245 .60725 Mdot
.50885 .62181 Mdot
.66627 .63171 Mdot
.43366 .30623 Mdot
.29849 .44233 Mdot
.43308 .65223 Mdot
.47909 .59362 Mdot
.65778 .57209 Mdot
.406 .36729 Mdot
.23251 .48751 Mdot
.41371 .34798 Mdot
.62586 .61893 Mdot
.42504 .36034 Mdot
.77919 .37499 Mdot
.40973 .38557 Mdot
.4654 .59656 Mdot
.42813 .5972 Mdot
.51712 .2006 Mdot
.66144 .59223 Mdot
.43635 .64849 Mdot
.43665 .58759 Mdot
.62577 .59782 Mdot
.37311 .40145 Mdot
.69804 .69103 Mdot
.44864 .65187 Mdot
.42944 .59378 Mdot
.28562 .45861 Mdot
.5537 .4447 Mdot
.63676 .44972 Mdot
.43479 .65103 Mdot
.33458 .4297 Mdot
.65491 .64539 Mdot
.4285 .61241 Mdot
.23131 .55103 Mdot
.37059 .37792 Mdot
.44697 .66192 Mdot
.66398 .47433 Mdot
.41371 .61415 Mdot
.84443 .50379 Mdot
.43125 .57942 Mdot
.63436 .58756 Mdot
.63005 .60391 Mdot
.36142 .37848 Mdot
.65474 .61116 Mdot
.66813 .50731 Mdot
.60068 .31803 Mdot
.80314 .56702 Mdot
.66571 .50492 Mdot
.47495 .61426 Mdot
.37168 .79386 Mdot
.48233 .60012 Mdot
.46729 .56253 Mdot
.2251 .6065 Mdot
.6725 .50531 Mdot
.64069 .59235 Mdot
.71631 .42296 Mdot
.44623 .66705 Mdot
.61747 .32447 Mdot
.47464 .56793 Mdot
.44704 .6621 Mdot
.34278 .56764 Mdot
.46984 .71523 Mdot
.56039 .33843 Mdot
.47715 .54381 Mdot
.43213 .65172 Mdot
.72436 .701 Mdot
.45664 .63496 Mdot
.29363 .43086 Mdot
.6619 .62642 Mdot
.3985 .3319 Mdot
.29193 .45108 Mdot
.4505 .64247 Mdot
.31673 .43957 Mdot
.4241 .33118 Mdot
.57861 .35672 Mdot
.46754 .60911 Mdot
.26759 .44466 Mdot
.32446 .43717 Mdot
.3996 .62538 Mdot
.63447 .61005 Mdot
.39863 .67585 Mdot
.4266 .61258 Mdot
.38737 .63015 Mdot
.64536 .62953 Mdot
.20946 .68103 Mdot
.40308 .58818 Mdot
.4915 .39035 Mdot
.69048 .62278 Mdot
.67461 .51421 Mdot
.3904 .3528 Mdot
.42692 .67552 Mdot
.61021 .33222 Mdot
.60231 .32205 Mdot
.42159 .31403 Mdot
.67046 .58173 Mdot
.40196 .35607 Mdot
.43438 .53933 Mdot
.48772 .65536 Mdot
.49762 .63784 Mdot
.17894 .42802 Mdot
.74547 .32711 Mdot
.64686 .58136 Mdot
.45295 .34362 Mdot
.57974 .46515 Mdot
.61187 .31873 Mdot
.45611 .32948 Mdot
.66753 .65286 Mdot
.67861 .60238 Mdot
.64632 .63171 Mdot
.33072 .43094 Mdot
.40563 .34552 Mdot
.68799 .64363 Mdot
.61342 .62659 Mdot
.40506 .62564 Mdot
.43017 .65179 Mdot
.65397 .5598 Mdot
.37124 .43047 Mdot
.31156 .45648 Mdot
.41419 .3775 Mdot
.84118 .374 Mdot
.61619 .32022 Mdot
.41747 .77795 Mdot
.441 .65387 Mdot
.10114 .57327 Mdot
.50608 .61807 Mdot
.45418 .63175 Mdot
.67951 .62517 Mdot
.274 .45933 Mdot
.30227 .4421 Mdot
.63024 .59614 Mdot
.6003 .59473 Mdot
.31998 .42569 Mdot
.51563 .37987 Mdot
.81116 .58913 Mdot
.58626 .47703 Mdot
.63029 .58767 Mdot
.46996 .75356 Mdot
.57792 .3601 Mdot
.68302 .6357 Mdot
.55554 .34017 Mdot
.43126 .33875 Mdot
.38646 .37914 Mdot
.56841 .33661 Mdot
.39116 .60227 Mdot
.43938 .3582 Mdot
.4515 .5445 Mdot
.81005 .45953 Mdot
.60511 .2222 Mdot
.65422 .78623 Mdot
.43511 .57064 Mdot
.55097 .55493 Mdot
.72439 .53072 Mdot
.46694 .63887 Mdot
.46549 .53498 Mdot
.32012 .4377 Mdot
.68742 .62819 Mdot
.57536 .36279 Mdot
.7971 .36806 Mdot
.42891 .59927 Mdot
.6211 .60972 Mdot
.60759 .31312 Mdot
.7741 .37425 Mdot
.47123 .43613 Mdot
.40589 .61525 Mdot
.32019 .84181 Mdot
.68412 .60727 Mdot
.39889 .33172 Mdot
.46649 .79096 Mdot
.65416 .64946 Mdot
.33558 .2799 Mdot
.42474 .38595 Mdot
.6138 .51541 Mdot
.67997 .61734 Mdot
.35375 .39584 Mdot
.64497 .61919 Mdot
.3051 .42008 Mdot
.59793 .60641 Mdot
.41506 .36439 Mdot
.43757 .62183 Mdot
.41539 .36118 Mdot
.28024 .44492 Mdot
.4416 .3383 Mdot
.57493 .36246 Mdot
.67749 .5024 Mdot
.6006 .31386 Mdot
.54891 .46803 Mdot
.64707 .69778 Mdot
.5906 .35407 Mdot
.54293 .29072 Mdot
.42214 .62489 Mdot
.5931 .5952 Mdot
.40461 .32529 Mdot
.39741 .31649 Mdot
.57314 .44902 Mdot
.63117 .62093 Mdot
.41678 .36815 Mdot
.45253 .74894 Mdot
.13108 .52978 Mdot
.49862 .57918 Mdot
.31069 .25448 Mdot
.62601 .59556 Mdot
.44699 .32641 Mdot
.5971 .47592 Mdot
.62711 .57356 Mdot
.38302 .3585 Mdot
.57494 .34332 Mdot
.6067 .33706 Mdot
.39627 .58858 Mdot
.63373 .31661 Mdot
.44842 .36241 Mdot
.73658 .69684 Mdot
.65712 .62935 Mdot
.72839 .31375 Mdot
.29922 .42975 Mdot
.42844 .33487 Mdot
.50908 .61493 Mdot
.67703 .65897 Mdot
.38058 .35176 Mdot
.55622 .18351 Mdot
.80829 .32946 Mdot
.4174 .36851 Mdot
.66304 .62569 Mdot
.66236 .61381 Mdot
.47943 .56025 Mdot
.57441 .47126 Mdot
.40762 .36977 Mdot
.48917 .229 Mdot
.24688 .47501 Mdot
.66249 .48797 Mdot
.41822 .80254 Mdot
.40683 .64692 Mdot
.43384 .66086 Mdot
.61308 .34398 Mdot
.4343 .62663 Mdot
.60223 .60571 Mdot
.50365 .62515 Mdot
.6287 .32485 Mdot
.4354 .32235 Mdot
.4244 .60196 Mdot
.31744 .42983 Mdot
.60677 .35325 Mdot
.61326 .30076 Mdot
.43026 .35214 Mdot
.6624 .63009 Mdot
.70322 .43 Mdot
.41207 .34758 Mdot
.41333 .65517 Mdot
.67277 .49696 Mdot
.48562 .64677 Mdot
.51999 .207 Mdot
.61388 .59198 Mdot
.39354 .33933 Mdot
.68072 .58171 Mdot
.58733 .32477 Mdot
.42248 .30913 Mdot
.46084 .63777 Mdot
.38499 .37055 Mdot
.4795 .39936 Mdot
.26591 .35411 Mdot
.60452 .61403 Mdot
.34826 .46492 Mdot
.65918 .57147 Mdot
.66217 .4868 Mdot
.26994 .58099 Mdot
.31227 .45377 Mdot
.42352 .37765 Mdot
.78117 .36458 Mdot
.4057 .32205 Mdot
.4215 .61494 Mdot
.4133 .58536 Mdot
.39124 .36323 Mdot
.33314 .4398 Mdot
.21291 .50397 Mdot
.25736 .47128 Mdot
.66873 .59127 Mdot
.4628 .47215 Mdot
.85792 .41717 Mdot
.46752 .34511 Mdot
.57623 .31911 Mdot
.52872 .59065 Mdot
.4291 .63663 Mdot
.57848 .31156 Mdot
.6199 .31618 Mdot
.27763 .44526 Mdot
.42654 .32839 Mdot
.69157 .63018 Mdot
.56882 .3514 Mdot
.69611 .64968 Mdot
.22739 .51498 Mdot
.39253 .56658 Mdot
.41132 .70357 Mdot
.46624 .58894 Mdot
.55096 .42766 Mdot
.62466 .33709 Mdot
.44934 .60413 Mdot
.48123 .66477 Mdot
.58535 .34853 Mdot
.28198 .43706 Mdot
.70531 .60062 Mdot
.42545 .36646 Mdot
.11594 .54599 Mdot
.4671 .60741 Mdot
.43297 .61845 Mdot
.6084 .34417 Mdot
.48066 .81255 Mdot
.63823 .58119 Mdot
.66564 .62823 Mdot
.42031 .33528 Mdot
.5891 .43059 Mdot
.38483 .61066 Mdot
.46595 .62649 Mdot
.43467 .36309 Mdot
.67917 .49526 Mdot
.58489 .83685 Mdot
.43661 .59675 Mdot
.59079 .3372 Mdot
.52452 .3109 Mdot
.62185 .34244 Mdot
.43065 .56168 Mdot
.41723 .61026 Mdot
.47173 .61572 Mdot
.41733 .57198 Mdot
.56612 .33629 Mdot
.46675 .63432 Mdot
.37096 .62896 Mdot
.64509 .59204 Mdot
.42065 .65647 Mdot
.24634 .48068 Mdot
.43555 .59992 Mdot
.31664 .43034 Mdot
.643 .44399 Mdot
.44167 .58064 Mdot
.42218 .65751 Mdot
.24941 .46523 Mdot
.4486 .62431 Mdot
.59733 .30812 Mdot
.66334 .60674 Mdot
.58529 .32612 Mdot
.58196 .31679 Mdot
.37893 .36325 Mdot
.29194 .42449 Mdot
.46385 .6692 Mdot
.32248 .42497 Mdot
.45518 .5478 Mdot
.47264 .58029 Mdot
.55228 .45626 Mdot
.60335 .46689 Mdot
.35105 .4167 Mdot
.46355 .63258 Mdot
.42416 .33843 Mdot
.39035 .3447 Mdot
.37305 .47088 Mdot
.44025 .54526 Mdot
.57528 .36044 Mdot
.57421 .34802 Mdot
.34538 .50788 Mdot
.37786 .49496 Mdot
.32412 .43317 Mdot
.5345 .50249 Mdot
.47178 .58621 Mdot
.43666 .58384 Mdot
.46398 .56309 Mdot
.39163 .39324 Mdot
.67901 .50261 Mdot
.43243 .32225 Mdot
.68083 .46291 Mdot
.59498 .36243 Mdot
.4359 .57081 Mdot
.62352 .23125 Mdot
.65654 .576 Mdot
.66393 .60556 Mdot
.62889 .32022 Mdot
.44979 .35688 Mdot
.43896 .54628 Mdot
.18276 .37204 Mdot
.61036 .58598 Mdot
.33751 .44847 Mdot
.46144 .61516 Mdot
.4303 .34688 Mdot
.67015 .58641 Mdot
.30811 .41595 Mdot
.44466 .57214 Mdot
.4606 .35329 Mdot
.4436 .60747 Mdot
.53335 .76577 Mdot
.63829 .59761 Mdot
.59508 .52424 Mdot
.62377 .56469 Mdot
.57557 .31737 Mdot
.57902 .33803 Mdot
.41528 .60318 Mdot
.14536 .44852 Mdot
.67765 .56133 Mdot
.57638 .31035 Mdot
.32385 .41623 Mdot
.68191 .49874 Mdot
.31548 .41576 Mdot
.39573 .3485 Mdot
.32011 .44581 Mdot
.38203 .34799 Mdot
.37732 .43026 Mdot
.68524 .57675 Mdot
.28757 .44954 Mdot
.48368 .81754 Mdot
.48102 .65976 Mdot
.27742 .44967 Mdot
.49129 .64639 Mdot
.37028 .54727 Mdot
.43735 .35554 Mdot
.3292 .43266 Mdot
.39622 .61311 Mdot
.69677 .27499 Mdot
.57795 .32706 Mdot
.57368 .36062 Mdot
.47366 .66303 Mdot
.44811 .32474 Mdot
.60027 .60845 Mdot
.51913 .41531 Mdot
.67753 .5122 Mdot
.46553 .62591 Mdot
.45477 .57454 Mdot
.68273 .5913 Mdot
.62865 .63171 Mdot
.41414 .60427 Mdot
.4601 .74037 Mdot
.45425 .64097 Mdot
.60403 .33988 Mdot
.66666 .5868 Mdot
.66459 .60955 Mdot
.43582 .37412 Mdot
.66921 .58087 Mdot
.45256 .69663 Mdot
.61473 .28685 Mdot
.49645 .60746 Mdot
.58996 .32558 Mdot
.38561 .44899 Mdot
.43025 .32734 Mdot
.78014 .35738 Mdot
.67263 .58619 Mdot
.46047 .65289 Mdot
.63499 .57433 Mdot
.29306 .43576 Mdot
.66321 .59334 Mdot
.65227 .56246 Mdot
.4256 .57539 Mdot
.40313 .60315 Mdot
.67688 .49455 Mdot
.57514 .46186 Mdot
.63916 .6036 Mdot
.45585 .64771 Mdot
.48082 .64771 Mdot
.40064 .59185 Mdot
.53805 .43694 Mdot
.67299 .63385 Mdot
.39395 .7504 Mdot
.55731 .2116 Mdot
.63718 .60943 Mdot
.83386 .4075 Mdot
.67788 .47769 Mdot
.65821 .49303 Mdot
.58369 .30066 Mdot
.43199 .59311 Mdot
.40517 .35785 Mdot
.43924 .6621 Mdot
.44016 .54421 Mdot
.44599 .5808 Mdot
.28767 .45593 Mdot
.38961 .64355 Mdot
.66946 .4781 Mdot
.4148 .35166 Mdot
.45051 .64775 Mdot
.42259 .59624 Mdot
.65767 .47893 Mdot
.63601 .55971 Mdot
.67808 .60212 Mdot
.64431 .48455 Mdot
.28447 .43613 Mdot
.6074 .3499 Mdot
.42744 .66112 Mdot
.42212 .33724 Mdot
.41127 .3582 Mdot
.61489 .60683 Mdot
.42368 .37135 Mdot
.61507 .34565 Mdot
.45225 .63512 Mdot
.57356 .31927 Mdot
.28747 .45561 Mdot
.66131 .62677 Mdot
.41544 .65757 Mdot
.4027 .62252 Mdot
.63015 .6036 Mdot
.4182 .62151 Mdot
.28901 .4594 Mdot
.39418 .3903 Mdot
.65889 .58519 Mdot
.6005 .31894 Mdot
.43046 .3782 Mdot
.41884 .63543 Mdot
.70516 .2251 Mdot
.4342 .62736 Mdot
.46886 .62011 Mdot
.80544 .5456 Mdot
.48839 .63444 Mdot
.41748 .32078 Mdot
.6398 .57191 Mdot
.4225 .56307 Mdot
.24678 .47065 Mdot
.31742 .3779 Mdot
.4529 .36874 Mdot
.46298 .61589 Mdot
.82101 .40812 Mdot
.45682 .65451 Mdot
.7926 .39742 Mdot
.55304 .45726 Mdot
.43669 .18697 Mdot
.40685 .70063 Mdot
.57807 .30912 Mdot
.67809 .49706 Mdot
.41565 .31854 Mdot
.56241 .79793 Mdot
.42566 .62445 Mdot
.67899 .73175 Mdot
.42896 .66254 Mdot
.59889 .33967 Mdot
.51005 .56003 Mdot
.41676 .37642 Mdot
.40354 .78926 Mdot
.39107 .63311 Mdot
.67989 .62224 Mdot
.4155 .3061 Mdot
.68273 .49156 Mdot
.39536 .60933 Mdot
.30951 .42493 Mdot
.33446 .38036 Mdot
.44705 .69595 Mdot
.59115 .32323 Mdot
.43986 .58725 Mdot
.50638 .56634 Mdot
.14048 .5172 Mdot
.64819 .5895 Mdot
.57384 .32755 Mdot
.47638 .51709 Mdot
.40851 .5875 Mdot
.67882 .60496 Mdot
.66091 .60676 Mdot
.30984 .42141 Mdot
.61938 .4289 Mdot
.29296 .38328 Mdot
.61996 .20877 Mdot
.65137 .74902 Mdot
.39597 .39433 Mdot
.7383 .61403 Mdot
.41825 .65067 Mdot
.31571 .68987 Mdot
.58656 .31354 Mdot
.43631 .61993 Mdot
.63331 .73707 Mdot
.65423 .59098 Mdot
.44372 .60313 Mdot
.30855 .45703 Mdot
.72396 .48499 Mdot
.40709 .72624 Mdot
.73809 .26872 Mdot
.44176 .31196 Mdot
.49637 .58982 Mdot
.43211 .69612 Mdot
.67457 .51366 Mdot
.43222 .56241 Mdot
.40978 .32212 Mdot
.53389 .24425 Mdot
.33081 .44801 Mdot
.65954 .57779 Mdot
.68053 .48105 Mdot
.43874 .66459 Mdot
.48578 .61832 Mdot
.34113 .44351 Mdot
.39171 .61886 Mdot
.45157 .78288 Mdot
.65494 .47609 Mdot
.40778 .38653 Mdot
.66879 .63234 Mdot
.46635 .58786 Mdot
.68037 .4988 Mdot
.421 .57753 Mdot
.37897 .52859 Mdot
.46145 .60882 Mdot
.7862 .5911 Mdot
.63273 .61205 Mdot
.59261 .31851 Mdot
.39465 .6513 Mdot
.43505 .60628 Mdot
.33769 .29394 Mdot
.43561 .54454 Mdot
.42926 .58032 Mdot
.6194 .62326 Mdot
.65023 .57346 Mdot
.62167 .61648 Mdot
.42046 .38159 Mdot
.58181 .48304 Mdot
.6007 .33327 Mdot
.45391 .55468 Mdot
.57325 .35698 Mdot
.37052 .65707 Mdot
.34105 .43547 Mdot
.76441 .32641 Mdot
.44181 .637 Mdot
.63713 .62748 Mdot
.74764 .65891 Mdot
.65325 .64594 Mdot
.63275 .35448 Mdot
.59024 .31422 Mdot
.64513 .59995 Mdot
.45333 .62403 Mdot
.57345 .48829 Mdot
.69755 .23124 Mdot
.61047 .31814 Mdot
.47843 .57582 Mdot
.44016 .30982 Mdot
.39783 .31857 Mdot
.8469 .46377 Mdot
.58707 .30956 Mdot
.72232 .53038 Mdot
.45389 .65227 Mdot
.65862 .57502 Mdot
.59383 .35569 Mdot
.60054 .30655 Mdot
.43051 .36796 Mdot
.40658 .61915 Mdot
.43729 .60589 Mdot
.66564 .4729 Mdot
.57451 .35457 Mdot
.37995 .56206 Mdot
.40865 .61565 Mdot
.80344 .50635 Mdot
.67241 .65192 Mdot
.21563 .69328 Mdot
.44488 .538 Mdot
.6408 .7322 Mdot
.42955 .44894 Mdot
.65363 .5811 Mdot
.38731 .6197 Mdot
.45233 .55301 Mdot
.40872 .39103 Mdot
.44687 .63396 Mdot
.44873 .33977 Mdot
.58078 .3128 Mdot
.77272 .33012 Mdot
.53798 .30776 Mdot
.60618 .28399 Mdot
.43009 .62271 Mdot
.40562 .72259 Mdot
.28993 .44523 Mdot
.60578 .36429 Mdot
.62079 .59426 Mdot
.47222 .5919 Mdot
.39605 .39652 Mdot
.41647 .3818 Mdot
.65762 .60097 Mdot
.74068 .55293 Mdot
.78393 .3728 Mdot
.42179 .56963 Mdot
.39258 .35026 Mdot
.58531 .26732 Mdot
.50616 .70339 Mdot
.59687 .29743 Mdot
.32847 .45083 Mdot
.42229 .32161 Mdot
.63253 .33343 Mdot
.36475 .55044 Mdot
.65013 .60611 Mdot
.68287 .59617 Mdot
.37214 .27604 Mdot
.41072 .36727 Mdot
.29891 .45046 Mdot
.40748 .46854 Mdot
.415 .47054 Mdot
.30219 .45926 Mdot
.4424 .32595 Mdot
.65266 .57735 Mdot
.62257 .61319 Mdot
.66251 .60858 Mdot
.4272 .78593 Mdot
.61736 .5841 Mdot
.27055 .70977 Mdot
.45844 .57374 Mdot
.48242 .74122 Mdot
.46643 .64449 Mdot
.56405 .34537 Mdot
.63694 .59883 Mdot
.55703 .46781 Mdot
.47908 .6159 Mdot
.72092 .25579 Mdot
.45633 .60974 Mdot
.50866 .35514 Mdot
.43031 .59275 Mdot
.48161 .78369 Mdot
.68984 .62531 Mdot
.46385 .63512 Mdot
.60017 .28911 Mdot
.31719 .43506 Mdot
.66512 .55635 Mdot
.43197 .58129 Mdot
.76867 .5216 Mdot
.48984 .64753 Mdot
.81372 .42536 Mdot
.29988 .28992 Mdot
.30798 .46599 Mdot
.49684 .63006 Mdot
.37677 .3549 Mdot
.53173 .57029 Mdot
.48559 .75099 Mdot
.60979 .31777 Mdot
.42315 .73517 Mdot
.43114 .37024 Mdot
.46305 .53454 Mdot
.38058 .58412 Mdot
.33458 .44189 Mdot
.69099 .57319 Mdot
.6023 .34228 Mdot
.42638 .62679 Mdot
.38803 .61419 Mdot
.51955 .18242 Mdot
.48124 .75869 Mdot
.37263 .58572 Mdot
.34519 .43091 Mdot
.4241 .74162 Mdot
.44651 .5835 Mdot
.45235 .36906 Mdot
.63708 .57103 Mdot
.49399 .66418 Mdot
.38645 .75308 Mdot
.45468 .64598 Mdot
.649 .59878 Mdot
.67312 .58581 Mdot
.76884 .65562 Mdot
.33949 .43439 Mdot
.46105 .60809 Mdot
.35691 .27588 Mdot
.41345 .65561 Mdot
.6026 .33612 Mdot
.43676 .56083 Mdot
.43551 .33969 Mdot
.60021 .47862 Mdot
.42297 .38044 Mdot
.39755 .59948 Mdot
.64868 .62345 Mdot
.60348 .34516 Mdot
.42823 .23014 Mdot
.55499 .39605 Mdot
.26709 .70508 Mdot
.33213 .38316 Mdot
.31926 .4276 Mdot
.30155 .41882 Mdot
.64291 .30512 Mdot
.46004 .62027 Mdot
.54104 .41758 Mdot
.48053 .56726 Mdot
.42764 .58839 Mdot
.46115 .5963 Mdot
.54956 .31434 Mdot
.59147 .31476 Mdot
.42129 .36248 Mdot
.41417 .60578 Mdot
.45678 .6475 Mdot
.64136 .61168 Mdot
.32487 .43698 Mdot
.39449 .38844 Mdot
.28566 .43717 Mdot
.41879 .34783 Mdot
.84802 .49239 Mdot
.44623 .56066 Mdot
.31552 .43493 Mdot
.621 .34488 Mdot
.62894 .62567 Mdot
.65844 .4832 Mdot
.3964 .34883 Mdot
.41481 .376 Mdot
.46715 .63539 Mdot
.67171 .61972 Mdot
.6771 .61151 Mdot
.32049 .42624 Mdot
.57753 .35167 Mdot
.398 .58164 Mdot
.4051 .60772 Mdot
.39716 .22628 Mdot
.41222 .38878 Mdot
.43936 .74767 Mdot
.76769 .61605 Mdot
.46086 .62236 Mdot
.6785 .61241 Mdot
.42681 .60602 Mdot
.59409 .24747 Mdot
.62589 .62662 Mdot
.48081 .63844 Mdot
.34313 .58103 Mdot
.3908 .39249 Mdot
.76396 .69338 Mdot
.44233 .67146 Mdot
.5572 .38097 Mdot
.40495 .63726 Mdot
.78693 .70331 Mdot
.73684 .66767 Mdot
.4287 .66315 Mdot
.41821 .5727 Mdot
.61667 .19678 Mdot
.44946 .65591 Mdot
.66956 .47517 Mdot
.43142 .54182 Mdot
.6794 .60529 Mdot
.46771 .42994 Mdot
.56346 .43863 Mdot
.33275 .42323 Mdot
.42075 .33455 Mdot
.24459 .58067 Mdot
.29191 .42698 Mdot
.63129 .58969 Mdot
.4831 .61266 Mdot
.69991 .66605 Mdot
.36813 .37228 Mdot
.39173 .57821 Mdot
.60168 .33745 Mdot
.56488 .43901 Mdot
.43137 .32343 Mdot
.59984 .31707 Mdot
.46819 .65289 Mdot
.21989 .358 Mdot
.59297 .39404 Mdot
.78904 .64441 Mdot
.60735 .34704 Mdot
.58191 .32381 Mdot
.58153 .49932 Mdot
.33229 .42303 Mdot
.48997 .1907 Mdot
.50907 .669 Mdot
.6149 .31976 Mdot
.30225 .55434 Mdot
.44578 .37065 Mdot
.61031 .44149 Mdot
.68624 .63243 Mdot
.44378 .55945 Mdot
.44974 .61989 Mdot
.58242 .35063 Mdot
.72801 .63911 Mdot
.42955 .49711 Mdot
.60404 .3143 Mdot
.42423 .6926 Mdot
.61591 .43922 Mdot
.67396 .50034 Mdot
.67247 .47225 Mdot
.33054 .41799 Mdot
.25363 .38652 Mdot
.63445 .61869 Mdot
.31858 .46 Mdot
.62255 .53626 Mdot
.45705 .60201 Mdot
.57323 .35426 Mdot
.66293 .4693 Mdot
.60168 .32389 Mdot
.30494 .43798 Mdot
.33971 .44202 Mdot
.64567 .59147 Mdot
.6371 .58076 Mdot
.54142 .65518 Mdot
.32259 .51578 Mdot
.43597 .65868 Mdot
.69608 .69618 Mdot
.62284 .623 Mdot
.52509 .81156 Mdot
.32775 .42486 Mdot
.32701 .44332 Mdot
.53415 .72594 Mdot
.41174 .63045 Mdot
.51933 .32524 Mdot
.43978 .58082 Mdot
.28032 .5878 Mdot
.45352 .66535 Mdot
.42911 .36822 Mdot
.39928 .64259 Mdot
.6924 .4149 Mdot
.44248 .64681 Mdot
.45709 .58732 Mdot
.40141 .3467 Mdot
.38469 .6398 Mdot
.43785 .34332 Mdot
.40384 .58725 Mdot
.2713 .4599 Mdot
.42177 .33733 Mdot
.26504 .4763 Mdot
.49178 .39712 Mdot
.67742 .4882 Mdot
.31858 .41671 Mdot
.30954 .42591 Mdot
.23558 .47593 Mdot
.6263 .58472 Mdot
.36465 .5435 Mdot
.45866 .61789 Mdot
.45784 .34019 Mdot
.59969 .35729 Mdot
.45598 .64516 Mdot
.50545 .61805 Mdot
.44434 .67231 Mdot
.64687 .5945 Mdot
.44529 .32733 Mdot
.31213 .44004 Mdot
.38819 .34956 Mdot
.26557 .46201 Mdot
.39557 .3258 Mdot
.51887 .60126 Mdot
.42698 .53842 Mdot
.37359 .64277 Mdot
.66537 .72232 Mdot
.36957 .78491 Mdot
.65424 .60548 Mdot
.6683 .49208 Mdot
.34148 .43369 Mdot
.45705 .47359 Mdot
.63998 .62676 Mdot
.41094 .37548 Mdot
.44374 .60768 Mdot
.41636 .69047 Mdot
.47393 .69871 Mdot
.68054 .65405 Mdot
.3081 .50218 Mdot
.40923 .33439 Mdot
.66483 .49985 Mdot
.59078 .47093 Mdot
.58174 .60921 Mdot
.55202 .47002 Mdot
.43048 .60556 Mdot
.3159 .42417 Mdot
.67003 .58631 Mdot
.50078 .20558 Mdot
.57789 .34664 Mdot
.57501 .46677 Mdot
.43271 .62442 Mdot
.72532 .56633 Mdot
.6492 .62318 Mdot
.32523 .44945 Mdot
.58312 .35052 Mdot
.33597 .42896 Mdot
.68442 .48608 Mdot
.64149 .46334 Mdot
.39373 .61617 Mdot
.4299 .57943 Mdot
.59412 .36216 Mdot
.63631 .62011 Mdot
.35515 .37611 Mdot
.53731 .18851 Mdot
.39299 .35461 Mdot
.55639 .4137 Mdot
.66759 .58583 Mdot
.70619 .55385 Mdot
.38641 .36897 Mdot
.62513 .34451 Mdot
.54364 .4221 Mdot
.62767 .31901 Mdot
.45339 .58638 Mdot
.66727 .61606 Mdot
.58753 .30899 Mdot
.41075 .23621 Mdot
.82959 .48335 Mdot
.70457 .6124 Mdot
.41105 .60783 Mdot
.76476 .32452 Mdot
.76584 .48534 Mdot
.71916 .6108 Mdot
.56655 .34488 Mdot
.4197 .60728 Mdot
.42536 .56873 Mdot
.39229 .63526 Mdot
.5756 .3323 Mdot
.55518 .38734 Mdot
.40785 .38034 Mdot
.44916 .60149 Mdot
.29838 .43054 Mdot
.43509 .34653 Mdot
.3792 .34365 Mdot
.41363 .31893 Mdot
.62461 .62636 Mdot
.47447 .58625 Mdot
.5878 .5478 Mdot
.80802 .64998 Mdot
.58713 .31965 Mdot
.67725 .48782 Mdot
.46939 .61125 Mdot
.22995 .64721 Mdot
.62431 .62036 Mdot
.39409 .35831 Mdot
.43447 .61851 Mdot
.31486 .28728 Mdot
.65335 .47167 Mdot
.40876 .34449 Mdot
.62077 .59561 Mdot
.71823 .60935 Mdot
.4477 .63481 Mdot
.40749 .63851 Mdot
.62513 .60787 Mdot
.74446 .49051 Mdot
.59978 .46438 Mdot
.42607 .60355 Mdot
.59504 .317 Mdot
.12893 .50752 Mdot
.48512 .64091 Mdot
.66475 .66138 Mdot
.68065 .50267 Mdot
.78215 .58049 Mdot
.44628 .74194 Mdot
.50687 .58882 Mdot
.71294 .27309 Mdot
.22936 .58449 Mdot
.78891 .34684 Mdot
.27091 .61848 Mdot
.6367 .26012 Mdot
.83706 .55216 Mdot
.60146 .29017 Mdot
.49156 .78199 Mdot
.52117 .1632 Mdot
.73258 .52493 Mdot
.25668 .33682 Mdot
.45471 .24018 Mdot
.32156 .27297 Mdot
.49224 .83846 Mdot
.39175 .32852 Mdot
.29048 .62461 Mdot
.39066 .59989 Mdot
.75031 .47536 Mdot
.44305 .76478 Mdot
.33715 .77445 Mdot
.76469 .33105 Mdot
.34467 .27876 Mdot
.67262 .20227 Mdot
.77087 .35206 Mdot
.57625 .64718 Mdot
.34025 .68597 Mdot
.25904 .39423 Mdot
.40828 .47091 Mdot
.24359 .59133 Mdot
.38576 .70016 Mdot
.69141 .40122 Mdot
.5803 .29378 Mdot
.6049 .67805 Mdot
.14404 .54814 Mdot
.40662 .32775 Mdot
.63655 .57075 Mdot
.47784 .18954 Mdot
.62261 .6591 Mdot
.64416 .33921 Mdot
.71299 .27285 Mdot
.80777 .51202 Mdot
.47924 .78177 Mdot
.60417 .52839 Mdot
.54524 .75681 Mdot
.20724 .49995 Mdot
.33003 .68371 Mdot
.62583 .64377 Mdot
.46449 .27204 Mdot
.41286 .4718 Mdot
.25503 .41448 Mdot
.49188 .79452 Mdot
.30472 .41631 Mdot
.26107 .47568 Mdot
.61918 .6029 Mdot
.51811 .69167 Mdot
.65851 .4985 Mdot
.62456 .53964 Mdot
.39782 .39767 Mdot
.58003 .24819 Mdot
.72738 .47681 Mdot
.7549 .51387 Mdot
.70799 .74469 Mdot
.74189 .25861 Mdot
.25665 .52754 Mdot
.52808 .22914 Mdot
.6033 .3817 Mdot
.23122 .56477 Mdot
.57668 .53271 Mdot
.2912 .52433 Mdot
.35877 .54021 Mdot
.59343 .14872 Mdot
.7786 .51545 Mdot
.6537 .18234 Mdot
.59514 .60155 Mdot
.45161 .67969 Mdot
.54927 .23361 Mdot
.63607 .76492 Mdot
.26027 .43613 Mdot
.74362 .26519 Mdot
.32808 .45814 Mdot
.69339 .6149 Mdot
.73122 .52844 Mdot
.44594 .77791 Mdot
.3572 .36688 Mdot
.32916 .40815 Mdot
.49072 .66612 Mdot
.57206 .12692 Mdot
.70311 .2621 Mdot
.77427 .63406 Mdot
.80062 .50949 Mdot
.46746 .35337 Mdot
.37385 .35724 Mdot
.58663 .30684 Mdot
.83058 .514 Mdot
.65833 .62144 Mdot
.81065 .65125 Mdot
.82386 .50793 Mdot
.51978 .55385 Mdot
.5575 .12298 Mdot
.57989 .83407 Mdot
.47677 .74059 Mdot
.31146 .71343 Mdot
.27083 .29174 Mdot
.56973 .52055 Mdot
.69686 .54323 Mdot
.46156 .32233 Mdot
.80038 .56527 Mdot
.83976 .47258 Mdot
.30832 .5588 Mdot
.6523 .27629 Mdot
.62077 .54423 Mdot
.38067 .45534 Mdot
.69728 .59741 Mdot
.2376 .36284 Mdot
.35568 .51057 Mdot
.66653 .19315 Mdot
.41768 .73963 Mdot
.16179 .43202 Mdot
.26679 .60368 Mdot
.47492 .81098 Mdot
.70719 .28943 Mdot
.42059 .40305 Mdot
.39442 .51222 Mdot
.761 .54155 Mdot
.49009 .59281 Mdot
.54059 .507 Mdot
.42009 .52515 Mdot
.32681 .46869 Mdot
.58339 .48926 Mdot
.78132 .43294 Mdot
.26268 .58313 Mdot
.59892 .21374 Mdot
.34251 .68283 Mdot
.65852 .63904 Mdot
.27701 .5162 Mdot
.27705 .55317 Mdot
.79934 .49064 Mdot
.47912 .51833 Mdot
.79207 .6135 Mdot
.46448 .50954 Mdot
.49225 .57867 Mdot
.5004 .78141 Mdot
.37722 .69056 Mdot
.29445 .54486 Mdot
.44118 .66975 Mdot
.72259 .72851 Mdot
.80079 .5351 Mdot
.64416 .7099 Mdot
.2501 .56327 Mdot
.66187 .7183 Mdot
.80378 .56581 Mdot
.55573 .23032 Mdot
.69889 .53743 Mdot
.73215 .6234 Mdot
.57949 .13238 Mdot
.43018 .3577 Mdot
.30956 .54322 Mdot
.54706 .34967 Mdot
.41702 .23669 Mdot
.49599 .16939 Mdot
.44507 .50108 Mdot
.8137 .55749 Mdot
.74509 .52288 Mdot
.36836 .35754 Mdot
.67596 .37806 Mdot
.56368 .28998 Mdot
.67331 .69811 Mdot
.45992 .67184 Mdot
.42036 .51947 Mdot
.29079 .4604 Mdot
.59321 .78314 Mdot
.54679 .2141 Mdot
.37118 .30712 Mdot
.5146 .60741 Mdot
.40313 .28303 Mdot
.6617 .49083 Mdot
.58147 .44579 Mdot
.8526 .47912 Mdot
.47885 .55027 Mdot
.55244 .83748 Mdot
.75581 .49799 Mdot
.55279 .42622 Mdot
.24489 .43935 Mdot
.75424 .61762 Mdot
.63233 .16497 Mdot
.82293 .5474 Mdot
.76433 .45844 Mdot
.75765 .31609 Mdot
.63226 .83571 Mdot
.44952 .17234 Mdot
.63029 .78548 Mdot
.54728 .34732 Mdot
.45771 .90907 Mdot
.38615 .35998 Mdot
.33496 .73022 Mdot
.63286 .76537 Mdot
.31236 .2979 Mdot
.63107 .66285 Mdot
.38103 .7075 Mdot
.30201 .39932 Mdot
.64333 .56024 Mdot
.50128 .64443 Mdot
.78552 .31295 Mdot
.60061 .14816 Mdot
.7738 .29741 Mdot
.64446 .45698 Mdot
.79629 .34705 Mdot
.59725 .17147 Mdot
.2749 .7153 Mdot
.50829 .18147 Mdot
.43483 .56099 Mdot
.33057 .53563 Mdot
.60199 .82182 Mdot
.34712 .39082 Mdot
.60072 .5446 Mdot
.64377 .65359 Mdot
.57809 .1523 Mdot
.85424 .47539 Mdot
.55738 .72146 Mdot
.55102 .66405 Mdot
.4632 .41759 Mdot
.3069 .52722 Mdot
.66709 .6724 Mdot
.69805 .38773 Mdot
.81205 .46588 Mdot
.58526 .16722 Mdot
.27392 .5633 Mdot
.45539 .2469 Mdot
.75734 .44339 Mdot
.6162 .8065 Mdot
.70669 .28325 Mdot
.47065 .1885 Mdot
.48665 .53164 Mdot
.61275 .55799 Mdot
.43152 .49818 Mdot
.68564 .39303 Mdot
.53794 .27405 Mdot
.2423 .53286 Mdot
.44255 .33959 Mdot
.31449 .54998 Mdot
.5099 .45698 Mdot
.50558 .18048 Mdot
.23023 .53513 Mdot
.30618 .56894 Mdot
.77679 .44988 Mdot
.78711 .32156 Mdot
.75381 .50142 Mdot
.24143 .3163 Mdot
.72684 .32683 Mdot
.44827 .52844 Mdot
.40216 .66447 Mdot
.80967 .55977 Mdot
.83002 .36934 Mdot
.81557 .55545 Mdot
.72939 .57676 Mdot
.37637 .26822 Mdot
.63346 .31745 Mdot
.22379 .53816 Mdot
.38008 .30926 Mdot
.81774 .46413 Mdot
.4864 .47339 Mdot
.63719 .32433 Mdot
.72271 .49033 Mdot
.5468 .64913 Mdot
.23447 .6169 Mdot
.58322 .67807 Mdot
.41557 .55363 Mdot
.49487 .71862 Mdot
.67822 .5815 Mdot
.72598 .57269 Mdot
.2968 .52889 Mdot
.43085 .35224 Mdot
.38034 .22622 Mdot
.67845 .66348 Mdot
.47583 .66775 Mdot
.53338 .25217 Mdot
.6973 .59487 Mdot
.65741 .72969 Mdot
.38919 .31921 Mdot
.84058 .52911 Mdot
.69426 .74889 Mdot
.67902 .67251 Mdot
.2642 .51855 Mdot
.3948 .23251 Mdot
.59704 .45266 Mdot
.55018 .34754 Mdot
.76388 .33451 Mdot
.50003 .39879 Mdot
.27597 .52197 Mdot
.48245 .72543 Mdot
.5384 .19624 Mdot
.47146 .56248 Mdot
.76152 .6489 Mdot
.26254 .69359 Mdot
.5842 .43923 Mdot
.63139 .65844 Mdot
.61213 .58642 Mdot
.41688 .82743 Mdot
.70501 .41536 Mdot
.55258 .57137 Mdot
.73161 .30087 Mdot
.60368 .30193 Mdot
.64034 .63712 Mdot
.31012 .57284 Mdot
.27281 .35017 Mdot
.49257 .70306 Mdot
.54698 .26943 Mdot
.58637 .6481 Mdot
.51767 .36034 Mdot
.747 .30738 Mdot
.682 .23122 Mdot
.13625 .49704 Mdot
.61269 .5755 Mdot
.50731 .2134 Mdot
.50006 .21348 Mdot
.63214 .64604 Mdot
.67519 .65801 Mdot
.40348 .72406 Mdot
.81943 .37956 Mdot
.46953 .46217 Mdot
.68978 .37622 Mdot
.54487 .42065 Mdot
.25497 .34495 Mdot
.51567 .19396 Mdot
.23796 .56184 Mdot
.68178 .26547 Mdot
.55991 .67388 Mdot
.32109 .23407 Mdot
.36627 .62221 Mdot
.33913 .73489 Mdot
.22356 .53799 Mdot
.32311 .63652 Mdot
.49895 .79475 Mdot
.79412 .42091 Mdot
.42106 .65813 Mdot
.76127 .27547 Mdot
.7898 .48324 Mdot
.53456 .50962 Mdot
.45246 .37865 Mdot
.42944 .64603 Mdot
.47156 .58278 Mdot
.7301 .65608 Mdot
.77493 .59938 Mdot
.39603 .18501 Mdot
.27228 .59951 Mdot
.47924 .53685 Mdot
.47211 .73388 Mdot
.55341 .83706 Mdot
.55762 .24191 Mdot
.80428 .39418 Mdot
.50893 .46841 Mdot
.61933 .81154 Mdot
.68522 .33469 Mdot
.6727 .3952 Mdot
.72191 .3154 Mdot
.60458 .17536 Mdot
.52497 .61915 Mdot
.76933 .57533 Mdot
.4799 .19608 Mdot
.46844 .60986 Mdot
.74114 .5537 Mdot
.73247 .30826 Mdot
.17815 .45453 Mdot
.56767 .5392 Mdot
.82559 .35254 Mdot
.3678 .5631 Mdot
.77107 .55834 Mdot
.50676 .16071 Mdot
.21565 .30516 Mdot
.68168 .40706 Mdot
.6758 .20149 Mdot
.66729 .38377 Mdot
.72061 .28999 Mdot
.58085 .30632 Mdot
.48175 .43588 Mdot
.69329 .70969 Mdot
.82315 .38661 Mdot
.29373 .3584 Mdot
.62261 .23942 Mdot
.72151 .6872 Mdot
.81839 .36772 Mdot
.3529 .56874 Mdot
.41581 .82251 Mdot
.38675 .40147 Mdot
.62925 .81655 Mdot
.66068 .7663 Mdot
.57986 .62943 Mdot
.29787 .56332 Mdot
.40712 .81093 Mdot
.31527 .75073 Mdot
.65376 .76606 Mdot
.31612 .5926 Mdot
.75989 .61724 Mdot
.25612 .51507 Mdot
.82181 .47032 Mdot
.47455 .8354 Mdot
.51366 .20216 Mdot
.70052 .49292 Mdot
.65512 .45878 Mdot
.77638 .60718 Mdot
.76047 .40364 Mdot
.54132 .24439 Mdot
.62797 .45283 Mdot
.57336 .63953 Mdot
.13314 .61409 Mdot
.66179 .36189 Mdot
.44514 .71459 Mdot
.62493 .16681 Mdot
.80956 .46932 Mdot
.47278 .4724 Mdot
.48291 .7963 Mdot
.2335 .63333 Mdot
.38086 .42228 Mdot
.44452 .58044 Mdot
.81387 .36121 Mdot
.36545 .40796 Mdot
.70074 .23009 Mdot
.79584 .64175 Mdot
.52733 .69656 Mdot
.52105 .58712 Mdot
.45336 .31416 Mdot
.3414 .70394 Mdot
.31216 .60804 Mdot
.62862 .17776 Mdot
.34138 .73419 Mdot
.53835 .39998 Mdot
.51594 .34906 Mdot
.54441 .29298 Mdot
.54039 .58631 Mdot
.60598 .82244 Mdot
.76627 .60378 Mdot
.25396 .58788 Mdot
.75033 .44662 Mdot
.30321 .54234 Mdot
.4459 .7435 Mdot
.2238 .52521 Mdot
.5083 .51121 Mdot
.28285 .40395 Mdot
.4269 .38259 Mdot
.60648 .19888 Mdot
.76557 .35567 Mdot
.73076 .71558 Mdot
.24763 .31159 Mdot
.75965 .54569 Mdot
.29826 .63575 Mdot
.57161 .21067 Mdot
.56064 .52804 Mdot
.28756 .37349 Mdot
.2497 .62965 Mdot
.42259 .73701 Mdot
.80041 .40871 Mdot
.34547 .67866 Mdot
.84243 .474 Mdot
.24201 .53762 Mdot
.56519 .18468 Mdot
.45709 .4237 Mdot
.60903 .76502 Mdot
.50356 .75001 Mdot
.28871 .27562 Mdot
.58069 .43856 Mdot
.57347 .12851 Mdot
.66059 .64536 Mdot
.73761 .25509 Mdot
.61067 .34602 Mdot
.15416 .51285 Mdot
.80715 .43746 Mdot
.53447 .48175 Mdot
.52626 .4339 Mdot
.76222 .65464 Mdot
.7486 .5013 Mdot
.7603 .50332 Mdot
.43616 .50069 Mdot
.42061 .31557 Mdot
.54306 .39208 Mdot
.69453 .3748 Mdot
.61954 .21578 Mdot
.40776 .57348 Mdot
.36437 .35898 Mdot
.3216 .65581 Mdot
.55594 .36944 Mdot
.80078 .54504 Mdot
.78511 .3907 Mdot
.39863 .70174 Mdot
.30698 .52464 Mdot
.59546 .165 Mdot
.81433 .49486 Mdot
.43004 .4921 Mdot
.40597 .52928 Mdot
.61283 .38098 Mdot
.41633 .19803 Mdot
.68327 .24897 Mdot
.5298 .31889 Mdot
.60819 .45696 Mdot
.25829 .53044 Mdot
.83113 .34007 Mdot
.59673 .14824 Mdot
.28112 .26743 Mdot
.54398 .41771 Mdot
.59468 .5885 Mdot
.23819 .65233 Mdot
.5688 .18643 Mdot
.64269 .81001 Mdot
.77661 .47122 Mdot
.30568 .54626 Mdot
.18689 .42987 Mdot
.37182 .77757 Mdot
.5239 .38943 Mdot
.50485 .75054 Mdot
.65917 .73801 Mdot
.62531 .36097 Mdot
.38249 .42758 Mdot
.5145 .41041 Mdot
.64416 .34383 Mdot
.76119 .61509 Mdot
.74646 .50522 Mdot
.56236 .18298 Mdot
.35265 .74595 Mdot
.40245 .53047 Mdot
.61557 .22578 Mdot
.69578 .60411 Mdot
.49715 .20895 Mdot
.40643 .22175 Mdot
.52296 .40257 Mdot
.38628 .34627 Mdot
.44266 .70362 Mdot
.59884 .4316 Mdot
.67236 .36824 Mdot
.20516 .39021 Mdot
.27675 .4594 Mdot
.60813 .62976 Mdot
.38485 .78882 Mdot
.6045 .58452 Mdot
.85667 .41004 Mdot
.70025 .38661 Mdot
.48398 .72832 Mdot
.67963 .31668 Mdot
.47125 .25603 Mdot
.20918 .34852 Mdot
.5689 .64601 Mdot
.24861 .46563 Mdot
.59443 .61264 Mdot
.67431 .57897 Mdot
.68647 .30475 Mdot
.65846 .51025 Mdot
.53687 .67443 Mdot
.52014 .83973 Mdot
.39201 .23321 Mdot
.60101 .59733 Mdot
.50932 .36119 Mdot
.71004 .61248 Mdot
.85224 .48593 Mdot
.39038 .34183 Mdot
.58752 .13604 Mdot
.43823 .53674 Mdot
.40665 .19784 Mdot
.80688 .55265 Mdot
.59927 .48518 Mdot
.54503 .41305 Mdot
.42468 .24675 Mdot
.48842 .57826 Mdot
.48771 .54027 Mdot
.62834 .58507 Mdot
.51961 .17939 Mdot
.32297 .44327 Mdot
.30619 .50762 Mdot
.55378 .32419 Mdot
.51765 .82156 Mdot
.6425 .7975 Mdot
.67504 .57759 Mdot
.48914 .38016 Mdot
.49206 .22122 Mdot
.34123 .58292 Mdot
.3212 .64795 Mdot
.61089 .19546 Mdot
.55506 .65629 Mdot
.6611 .64421 Mdot
.27746 .2736 Mdot
.35818 .50553 Mdot
.83158 .55499 Mdot
.36216 .64074 Mdot
.33579 .69243 Mdot
.32926 .65218 Mdot
.7576 .63859 Mdot
.4448 .74142 Mdot
.81472 .42289 Mdot
.28155 .51889 Mdot
.38246 .49309 Mdot
.30855 .56655 Mdot
.40042 .70385 Mdot
.52893 .34018 Mdot
.60438 .82939 Mdot
.18863 .42335 Mdot
.5375 .7638 Mdot
.58051 .53991 Mdot
.62854 .65942 Mdot
.56237 .83541 Mdot
.61912 .64131 Mdot
.29519 .47361 Mdot
.61522 .68334 Mdot
.80681 .43987 Mdot
.83204 .50626 Mdot
.79874 .49072 Mdot
.34201 .70749 Mdot
.5454 .29398 Mdot
.277 .67481 Mdot
.37458 .54251 Mdot
.54302 .47678 Mdot
.50403 .60253 Mdot
.50254 .55321 Mdot
.47995 .48377 Mdot
.74665 .66772 Mdot
.53168 .59154 Mdot
.81704 .38286 Mdot
.82908 .55132 Mdot
.7773 .3217 Mdot
.53615 .27257 Mdot
.62957 .56952 Mdot
.62105 .15937 Mdot
.38405 .76323 Mdot
.82053 .47831 Mdot
.65024 .77463 Mdot
.43484 .83817 Mdot
.51688 .15981 Mdot
.78748 .43238 Mdot
.58526 .57565 Mdot
.76719 .69086 Mdot
.78031 .51375 Mdot
.42004 .82276 Mdot
.41658 .73357 Mdot
.80332 .5521 Mdot
.56059 .12932 Mdot
.5854 .80739 Mdot
.75793 .51261 Mdot
.49612 .75277 Mdot
.43851 .72725 Mdot
.48711 .83153 Mdot
.47652 .5828 Mdot
.38164 .344 Mdot
.29107 .3024 Mdot
.29711 .55615 Mdot
.41483 .70942 Mdot
.471 .82871 Mdot
.31164 .61371 Mdot
.29252 .63218 Mdot
.41478 .2422 Mdot
.52094 .16215 Mdot
.4689 .72598 Mdot
.43029 .69582 Mdot
.64399 .65589 Mdot
.29576 .42289 Mdot
.26082 .6202 Mdot
.42659 .63678 Mdot
.56229 .44769 Mdot
.51484 .65028 Mdot
.79721 .32294 Mdot
.2707 .33686 Mdot
.63266 .28941 Mdot
.61768 .57495 Mdot
.7711 .61387 Mdot
.58457 .23668 Mdot
.73174 .52538 Mdot
.45306 .82048 Mdot
.52797 .66816 Mdot
.73638 .29452 Mdot
.75413 .52647 Mdot
.2577 .55376 Mdot
.21226 .47209 Mdot
.56309 .33143 Mdot
.67412 .73092 Mdot
.624 .17953 Mdot
.75139 .55684 Mdot
.69483 .61591 Mdot
.75471 .42905 Mdot
.52663 .34729 Mdot
.75501 .57725 Mdot
.75315 .49591 Mdot
.53423 .2061 Mdot
.5253 .71439 Mdot
.67835 .23242 Mdot
.43537 .30646 Mdot
.27963 .56819 Mdot
.72252 .41856 Mdot
.4866 .83387 Mdot
.34125 .58718 Mdot
.83459 .4436 Mdot
.53361 .47337 Mdot
.31791 .49292 Mdot
.39785 .62314 Mdot
.38106 .7529 Mdot
.75022 .64287 Mdot
.74417 .438 Mdot
.50996 .54167 Mdot
.67614 .57172 Mdot
.70537 .74436 Mdot
.44142 .38687 Mdot
.38665 .41023 Mdot
.32048 .71442 Mdot
.72383 .58414 Mdot
.32958 .47552 Mdot
.69557 .46044 Mdot
.41457 .53859 Mdot
.22798 .43938 Mdot
.54165 .28747 Mdot
.68408 .72501 Mdot
.62055 .7916 Mdot
.61117 .20011 Mdot
.54988 .26074 Mdot
.71489 .74141 Mdot
.68767 .73389 Mdot
.78843 .5821 Mdot
.37386 .7718 Mdot
.58881 .56376 Mdot
.46031 .66864 Mdot
.2959 .47366 Mdot
.64104 .6464 Mdot
.62746 .21527 Mdot
.43189 .51649 Mdot
.30318 .48902 Mdot
.52918 .49448 Mdot
.54589 .23463 Mdot
.42682 .43665 Mdot
.79869 .53993 Mdot
.76708 .69139 Mdot
.2956 .5281 Mdot
.56134 .32224 Mdot
.67435 .37456 Mdot
.5603 .54013 Mdot
.825 .4109 Mdot
.46901 .48959 Mdot
.69863 .66913 Mdot
.69407 .49064 Mdot
.63913 .73066 Mdot
.80388 .6018 Mdot
.32698 .51187 Mdot
.55088 .47614 Mdot
.68445 .66643 Mdot
.60516 .54105 Mdot
.65829 .4855 Mdot
.30488 .30987 Mdot
.37567 .75919 Mdot
.65262 .28354 Mdot
.5681 .4 Mdot
.38767 .55074 Mdot
.24123 .65653 Mdot
.66662 .23077 Mdot
.45813 .47448 Mdot
.52643 .4742 Mdot
.47585 .19855 Mdot
.36604 .41421 Mdot
.12282 .52935 Mdot
.77809 .29397 Mdot
.3989 .62424 Mdot
.51304 .43046 Mdot
.31677 .50816 Mdot
.44841 .33711 Mdot
.58086 .67389 Mdot
.62003 .20378 Mdot
.59817 .30879 Mdot
.39808 .25046 Mdot
.68956 .45437 Mdot
.75782 .65917 Mdot
.31936 .24446 Mdot
.63667 .33251 Mdot
.85554 .40361 Mdot
.77273 .47192 Mdot
.74579 .6192 Mdot
.11872 .55849 Mdot
.7436 .66214 Mdot
.36072 .54305 Mdot
.39152 .26305 Mdot
.79818 .33092 Mdot
.54937 .41678 Mdot
.37586 .27244 Mdot
.60072 .79957 Mdot
.29007 .52557 Mdot
.275 .58876 Mdot
.70448 .49366 Mdot
.73249 .69734 Mdot
.39211 .82053 Mdot
.47242 .25469 Mdot
.22383 .32413 Mdot
.53305 .68351 Mdot
.70035 .24181 Mdot
.6824 .40536 Mdot
.18699 .44321 Mdot
.82966 .51103 Mdot
.32557 .55225 Mdot
.48355 .82366 Mdot
.26696 .36879 Mdot
.25317 .47846 Mdot
.23527 .65668 Mdot
.63583 .45802 Mdot
.56279 .65404 Mdot
.4426 .26022 Mdot
.5262 .54904 Mdot
.31132 .55773 Mdot
.6417 .74309 Mdot
.54904 .47477 Mdot
.65139 .19771 Mdot
.42822 .80462 Mdot
.26815 .52553 Mdot
.45089 .21111 Mdot
.2624 .48016 Mdot
.64232 .22921 Mdot
.6003 .25267 Mdot
.34247 .55575 Mdot
.46738 .15101 Mdot
.66636 .19342 Mdot
.59163 .56069 Mdot
.46571 .57805 Mdot
.83564 .55622 Mdot
.38576 .46467 Mdot
.63042 .78397 Mdot
.72862 .46324 Mdot
.27367 .60573 Mdot
.52911 .62201 Mdot
.4807 .6556 Mdot
.29314 .69791 Mdot
.57929 .58601 Mdot
.64715 .74132 Mdot
.35551 .23031 Mdot
.26869 .52134 Mdot
.43742 .80264 Mdot
.32968 .23034 Mdot
.36212 .64424 Mdot
.68025 .60385 Mdot
.7975 .32731 Mdot
.64321 .67853 Mdot
.40881 .52417 Mdot
.49387 .73433 Mdot
.45254 .49007 Mdot
.31444 .37128 Mdot
.40251 .53134 Mdot
.59557 .45151 Mdot
.2958 .56429 Mdot
.57771 .19373 Mdot
.70121 .70188 Mdot
.56353 .12045 Mdot
.81325 .56174 Mdot
.60128 .5903 Mdot
.60789 .79053 Mdot
.51796 .39987 Mdot
.76633 .31067 Mdot
.4428 .25112 Mdot
.39854 .22915 Mdot
.36053 .79167 Mdot
.26052 .49036 Mdot
.396 .64743 Mdot
.64569 .45648 Mdot
.83734 .49319 Mdot
.37473 .79994 Mdot
.84155 .47251 Mdot
.52631 .59181 Mdot
.41528 .67309 Mdot
.18364 .33901 Mdot
.73198 .29714 Mdot
.49557 .56972 Mdot
.55946 .58068 Mdot
.54757 .57876 Mdot
.39685 .59185 Mdot
.65456 .50707 Mdot
.24037 .60005 Mdot
.27999 .59701 Mdot
.81727 .37808 Mdot
.60618 .59967 Mdot
.55631 .42378 Mdot
.59289 .36729 Mdot
.54523 .43519 Mdot
.39952 .69542 Mdot
.60541 .30397 Mdot
.28654 .60661 Mdot
.40504 .4569 Mdot
.34607 .35384 Mdot
.5467 .64216 Mdot
.61812 .46859 Mdot
.56316 .63269 Mdot
.31626 .67642 Mdot
.69385 .54692 Mdot
.31235 .74941 Mdot
.31085 .61313 Mdot
.33297 .57129 Mdot
.79344 .53747 Mdot
.60132 .84687 Mdot
.56979 .43075 Mdot
.70243 .56299 Mdot
.35377 .58774 Mdot
.40473 .75646 Mdot
.50958 .72296 Mdot
.33735 .38443 Mdot
.66497 .50447 Mdot
.52381 .58061 Mdot
.68074 .67139 Mdot
.62482 .30949 Mdot
.8293 .34539 Mdot
.47503 .6662 Mdot
.56673 .68751 Mdot
.82376 .4289 Mdot
.50321 .20407 Mdot
.41533 .73053 Mdot
.50449 .60885 Mdot
.39713 .4865 Mdot
.39967 .45794 Mdot
.71379 .63875 Mdot
.51527 .19051 Mdot
.71106 .26452 Mdot
.32703 .70983 Mdot
.54978 .68909 Mdot
.4582 .6123 Mdot
.31588 .46561 Mdot
.58444 .45466 Mdot
.20803 .41654 Mdot
.35948 .45481 Mdot
.80878 .49021 Mdot
.30838 .65626 Mdot
.27185 .59954 Mdot
.47559 .75898 Mdot
.71823 .24318 Mdot
.57007 .5461 Mdot
.52055 .70199 Mdot
.5085 .50194 Mdot
.76488 .40914 Mdot
.31459 .59448 Mdot
.64554 .27088 Mdot
.52662 .57666 Mdot
.56948 .58625 Mdot
.85126 .42994 Mdot
.57592 .64793 Mdot
.56539 .29868 Mdot
.80167 .40846 Mdot
.38508 .77085 Mdot
.52532 .43481 Mdot
.11985 .58234 Mdot
.43791 .2473 Mdot
.84844 .39171 Mdot
.55603 .19702 Mdot
.33642 .63489 Mdot
.75768 .61373 Mdot
.50729 .63543 Mdot
.4051 .35332 Mdot
.74639 .29193 Mdot
.66109 .66651 Mdot
.60457 .55212 Mdot
.44973 .5634 Mdot
.43482 .46673 Mdot
.70566 .64764 Mdot
.64092 .25781 Mdot
.39722 .31852 Mdot
.43522 .49186 Mdot
.63084 .24934 Mdot
.39832 .45779 Mdot
.4615 .84884 Mdot
.63075 .17805 Mdot
.76765 .3391 Mdot
.537 .2983 Mdot
.14649 .49329 Mdot
.59304 .62319 Mdot
.68983 .65056 Mdot
.58857 .29297 Mdot
.28178 .68339 Mdot
.75293 .56813 Mdot
.56622 .18938 Mdot
.78475 .61045 Mdot
.34043 .58728 Mdot
.14621 .64772 Mdot
.3179 .56336 Mdot
.43526 .47789 Mdot
.7407 .56667 Mdot
.82363 .39523 Mdot
.37505 .25813 Mdot
.78875 .64531 Mdot
.69551 .40282 Mdot
.40784 .70443 Mdot
.2748 .70366 Mdot
.28328 .27133 Mdot
.51752 .33808 Mdot
.21973 .32843 Mdot
.71413 .29597 Mdot
.24363 .5902 Mdot
.73826 .43557 Mdot
.61145 .57568 Mdot
.50301 .547 Mdot
.70288 .38014 Mdot
.59896 .54591 Mdot
.72902 .63885 Mdot
.70784 .26743 Mdot
.20815 .53318 Mdot
.44375 .20025 Mdot
.76621 .32229 Mdot
.55702 .37279 Mdot
.58142 .6262 Mdot
.30893 .62344 Mdot
.35846 .42589 Mdot
.44526 .35305 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0/Ooo
ool4o`0009Cooooo000Looooo`03o`000?oooooooooo0;7ooooo1?l0002Dooooo`007?ooool00ol0
003oooooooooo`2_ooooo`;o00001Oooool3o`00093ooooo000Looooo`03o`000?oooooooooo0:oo
oooo0_l000000ooooooo0000o`000002ooooo`?o0000T?ooool001cooooo00?o0000ooooooooool0
/_ooool2o`0000Cooooo0_l0002?ooooo`007?ooool00ol0003oooooooooo`2hooooo`;o000000?o
ooooo`000?l00000S?ooool001cooooo00?o0000ooooooooool0^oooool2o`0008cooooo000Loooo
o`03o`000?oooooooooo08Wooooo0_l0002nooooo`007?ooool00ol0003oooooooooo`29ooooo`;o
00004?ooool2o`000:cooooo000Looooo`03o`000?oooooooooo09_ooooo0_l00003ooooo`;o0000
6oooool4o`0000?ooooo0_l00023ooooo`007?ooool2o`0009Gooooo0_l0000:ooooo`;o00005_oo
ool2o`0000?ooooo1?l00003ooooo`;o0000Poooool001cooooo00?o0000ooooooooool0U?ooool2
o`0000Cooooo0_l00007ooooo`;o00004oooool2o`0008oooooo000Looooo`03o`000?oooooooooo
09[ooooo0_l00007ooooo`?o00008?ooool2o`00087ooooo000Looooo`03o`000?oooooooooo09go
oooo0_l00002ooooo`;o000000Coooooo`000?l0003o00007oooool2o`00087ooooo000Looooo`03
o`000?oooooooooo097ooooo0_l0000:ooooo`;o00000_ooool2o`0000;ooooo0ol0000Fooooo`;o
00002_ooool2o`0007gooooo000Looooo`03o`000?oooooooooo097ooooo0_l00008ooooo`;o0000
1?ooool2o`0000?ooooo0_l0000Booooo`;o00000_ooool2o`0000Oooooo0_l000001?oooooo0000
o`000?l0001looooo`007?ooool00ol0003oooooooooo`2Kooooo`Co00000_ooool2o`0000[ooooo
0_l0000;ooooo`;o00000_ooool2o`0000Oooooo0_l00002ooooo`;o0000O?ooool001cooooo00?o
0000ooooooooool0S_ooool2o`0000gooooo1?l00006ooooo`;o00001?ooool3o`0000kooooo0_l0
00000ooooooo0000o`000026ooooo`007?ooool00ol0003oooooooooo`22ooooo`;o00002?ooool4
o`0000oooooo0_l000001?oooooo0000o`000?ooool4o`0000Gooooo0_l0000Aooooo`;o00001Ooo
ool3o`0007kooooo000Looooo`03o`000?oooooooooo08;ooooo0_l00008ooooo`;o00003_ooool2
o`0000;ooooo1ol0000:ooooo`;o00005?ooool4o`0007kooooo000Looooo`03o`000?oooooooooo
08[ooooo0_l0000@ooooo`;o00000_ooool3o`000004ooooool0003o0000o`0000[ooooo1?l0000B
ooooo`;o00002?ooool2o`0007Kooooo000Looooo`03o`000?oooooooooo07gooooo0_l00006oooo
o`;o00000oooool2o`0001Wooooo0_l0000:ooooo`Ko00006_ooool2o`0007Kooooo000Looooo`03
o`000?oooooooooo07gooooo0_l00006ooooo`;o00000oooool2o`0000Wooooo1?l00002ooooo`;o
00001oooool2o`0000Gooooo0_l00007ooooo`?o0000T_ooool00006ooooooo^k^ko<S8bo`000?lb
<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo08Gooooo0_l0000>oooo
o`Go000000?oooooo`000?l000001oooool3o`0000Cooooo0_l00007ooooo`;o00000_ooool2o`00
01_ooooo0_l0001booooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0Soooool2o`0000Oooooo0_l0
000:ooooo`?o00001?ooool2o`0000_ooooo0_l00009ooooo`Co00003_ooool2o`0007;ooooo0000
0ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01oooool0
0ol0003oooooooooo`1mooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00001_oo
ool2o`0000Kooooo0ol0000:ooooo`;o00001Oooool2o`0000Cooooo1?l0000<ooooo`Ko00002Ooo
ool2o`0007Oooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RH
ob4Q8Oo^k^h01_ooool3o`0007gooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l0
0003ooooo`;o00002Oooool2o`0000Gooooo0_l00003ooooo`?o00002oooool4o`0000cooooo1?l0
000;ooooo`;o00001Oooool3o`0006oooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`2<ooooo`;o00004?ooool4
o`000004ooooool0003o0000o`0000Cooooo0_l0000Gooooo`;o000000?oooooo`000?l000003ooo
ool3o`0006oooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`26ooooo`;o00005_ooool4o`0000?ooooo0ol00002
ooooo`;o00000_ooool2o`0001Kooooo0_l00021ooooo`0000KoooooogMgMonHV9SooooooiRHV?mg
MgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`25ooooo`?o0000
1oooool2o`0000gooooo1?l00003ooooo`?o00001_ooool2o`000003ooooool0003o000000?ooooo
0_l0000>ooooo`;o00003?ooool2o`0007?ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo08Gooooo0_l00008oooo
o`;o00003_ooool4o`0000_ooooo0_l000000ooooooo0000o`000003ooooo`;o00000_ooool2o`00
00?ooooo0_l00007ooooo`;o00002_ooool2o`0007?ooooo000Looooo`03o`000?oooooooooo08Wo
oooo0_l0000Dooooo`Co00001?ooool2o`0000Gooooo0_l0000:ooooo`;o00000oooool2o`0000Co
oooo0_l000000ooooooo0000o`00001oooooo`007?ooool00ol0003oooooooooo`1looooo`;o0000
2oooool2o`00017ooooo0_l00003ooooo`;o00001?ooool2o`0001cooooo0_l00022ooooo`007?oo
ool00ol0003oooooooooo`1looooo`;o00000_ooool2o`0000?ooooo0ol0000Dooooo`;o00008Ooo
ool4o`0001Kooooo0_l0001^ooooo`007?ooool00ol0003oooooooooo`1hooooo`;o00000_ooool3
o`000004ooooool0003o0000o`0000;ooooo0ol00004ooooo`;o00005_ooool2o`0001Wooooo1?l0
00001?oooooo0000o`000?l0000Booooo`;o00001_ooool2o`0006Kooooo000Looooo`03o`000?oo
oooooooo06Oooooo0_l00007ooooo`;o00001_ooool2o`0000;ooooo2Ol00002ooooo`;o00000ooo
ool2o`0000gooooo0ol00006ooooo`;o00000_ooool2o`0000Kooooo0ol0000Aooooo`?o00001_oo
ool2o`0000Kooooo0_l00009ooooo`?o0000I_ooool001cooooo00?o0000ooooooooool0Ioooool2
o`0000;ooooo0_l00003ooooo`;o00002Oooool6o`000004ooooool0003o0000o`0000;ooooo0_l0
000Booooo`?o00002_ooool2o`0000Gooooo1?l000000ooooooo0000o`00000Aooooo`;o00001?oo
ool2o`0000Kooooo0_l00002ooooo`?o00000oooool3o`0006Oooooo000Looooo`03o`000?oooooo
oooo06Gooooo0_l00004ooooo`Co00003?ooool;o`0002Sooooo0ol000000ooooooo0000o`000002
o`0000Cooooo0_l00006ooooo`;o00000oooool2o`00013ooooo0ol00003ooooo`;o0000J?ooool0
01cooooo00?o0000ooooooooool0IOooool2o`000003ooooool0003o000000?ooooo0_l0000Aoooo
o`Ko00001Oooool2o`0001[ooooo0_l00005ooooo`;o00000_ooool2o`0000Kooooo0_l00006oooo
o`;o00000_ooool2o`00087ooooo000Looooo`03o`000?oooooooooo06Sooooo0_l0000Iooooo`;o
00001Oooool3o`0000?ooooo0_l0000Eooooo`;o00002?ooool2o`0001;ooooo0ol0000Hooooo`;o
0000Ioooool001cooooo00?o0000ooooooooool0I?ooool3o`0001cooooo0_l00005ooooo`?o0000
0oooool2o`0001Sooooo1?l00003ooooo`;o00002Oooool2o`0000Oooooo1?l0000Gooooo`;o0000
1?ooool2o`00067ooooo000Looooo`03o`000?oooooooooo06Cooooo0ol0000Mooooo`Co00000_oo
ool3o`0000?ooooo0_l0000Hooooo`Co00001oooool2o`0000;ooooo0_l000001?oooooo0000o`00
0?l00008ooooo`?o00004?ooool2o`0000[ooooo0_l0001Qooooo`007?ooool2o`0007oooooo0_l0
0004ooooo`Co00000_ooool4o`0000;ooooo0_l0000Gooooo`?o00000oooool2o`0000Cooooo0_l0
0002ooooo`;o00000_ooool2o`0000Wooooo0ol0000?ooooo`;o0000KOooool001cooooo00?o0000
ooooooooool0HOooool2o`0001_ooooo0_l0000;ooooo`?o00002?ooool2o`00017ooooo0ol00003
ooooo`;o00002?ooool2o`0000Cooooo0_l00008ooooo`?o00008?ooool2o`0005_ooooo000Loooo
o`03o`000?oooooooooo067ooooo0_l0000Cooooo`;o00004oooool2o`0000Sooooo0ol000000ooo
oooo0000o`00000Oooooo`;o00000oooool2o`0000Wooooo1?l0000Hooooo`;o00001?ooool2o`00
05_ooooo000Looooo`03o`000?oooooooooo07Kooooo0_l0000Dooooo`;o00001oooool2o`0000;o
oooo0_l0000Dooooo`;o00001?ooool2o`0000?ooooo0_l0000?ooooo`?o00006?ooool2o`0000Go
oooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`1kooooo`;o00003oooool2o`0001cooooo
0_l00003ooooo`;o00001?ooool2o`0001Cooooo0_l0000Dooooo`Co000000?oooooo`000?l00000
1Oooool2o`0005[ooooo000Looooo`03o`000?oooooooooo05?ooooo0_l00003ooooo`;o00000ooo
ool2o`0000Gooooo0_l0000Eooooo`;o0000;Oooool2o`0000kooooo0_l00008ooooo`;o00005?oo
ool2o`0000Gooooo1?l000000ooooooo0000o`000006ooooo`;o0000FOooool001cooooo00?o0000
ooooooooool0Doooool2o`0000?ooooo0_l00003ooooo`;o00001Oooool2o`00017ooooo0_l0000e
ooooo`;o00002_ooool2o`0000Cooooo0_l00002ooooo`;o00001_ooool4o`0000[ooooo0_l00006
ooooo`;o00000_ooool2o`0000Cooooo1?l00004ooooo`;o0000Doooool001cooooo00?o0000oooo
ooooool0E_ooool4o`0000_ooooo0_l0000?ooooo`?o00006_ooool2o`0001Gooooo0_l00002oooo
o`;o00002_ooool2o`0000Cooooo0_l0000:ooooo`Co00005?ooool4o`0000Cooooo0_l00006oooo
o`;o0000Doooool001cooooo00?o0000ooooooooool0E_ooool6o`0000Wooooo0_l00009ooooo`;o
00000oooool3o`0001_ooooo0_l0000Eooooo`?o00003Oooool2o`0001Cooooo0_l0000=ooooo`;o
00000oooool2o`0000gooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`1Jooooo`;o0000
3Oooool2o`000003ooooool0003o000000;ooooo0_l00003ooooo`;o00007_ooool2o`0001?ooooo
0ol0000;ooooo`Ko00004_ooool2o`0000gooooo0_l0000Booooo`;o0000E?ooool001cooooo00?o
0000ooooooooool0JOooool2o`000003ooooool0003o000000Sooooo0_l00007ooooo`?o00004ooo
ool2o`0001?ooooo0_l00006ooooo`;o00001?ooool6o`0008_ooooo000Looooo`03o`000?oooooo
oooo05oooooo0ol0000Dooooo`;o00001oooool3o`00017ooooo0_l0000Kooooo`Co00003?ooool3
o`000003ooooool0003o000000[ooooo0_l0000=ooooo`;o000000?oooooo`000?l00000IOooool0
01cooooo00?o0000ooooooooool0G_ooool4o`000003ooooool0003o000001?ooooo0_l00009oooo
o`;o00003_ooool2o`0001Oooooo0_l00002ooooo`;o00001_ooool3o`0000Cooooo1?l000001?oo
oooo0000o`000?ooool2o`0000Oooooo0_l0000=ooooo`;o000000?oooooo`000?l00000IOooool0
01cooooo00?o0000ooooooooool0E?ooool2o`0000Sooooo0ol00002ooooo`?o00001?ooool2o`00
00cooooo0_l00008ooooo`Co00009_ooool3o`0000Cooooo0_l00002ooooo`Co00000_ooool6o`00
0004ooooool0003o0000ooooo`;o000000?oooooo`000?l000005_ooool2o`0000;ooooo0_l00007
ooooo`;o00000oooool2o`0005?ooooo000Looooo`03o`000?oooooooooo05Cooooo0_l00008oooo
o`;o00001?ooool2o`0000;ooooo1?l0000Booooo`?o000000?oooooo`000?l000000_l0000Woooo
o`;o00001?ooool2o`0000;ooooo2?l000000ooooooo0000o`000006ooooo`Go00005Oooool2o`00
00;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00003ooooo`;o0000C_ooool001co
oooo00?o0000ooooooooool0AOooool2o`0001_ooooo0_l00004ooooo`Co00004?ooool5o`0000?o
oooo0ol0000Tooooo`Co00002_ooool4o`000003ooooool0003o000000;o000000?oooooo`000?l0
00000oooool7o`0001Gooooo0_l00004ooooo`?o00000oooool2o`0000Kooooo0ol0001>ooooo`00
7?ooool2o`0004Kooooo0_l00009ooooo`;o00004?ooool2o`0001Sooooo0_l00006ooooo`Go0000
8_ooool2o`0000Oooooo0_l00003ooooo`?o00000_ooool8o`0000;ooooo1?l000000ooooooo0000
o`00000Eooooo`;o00001?ooool2o`0000Cooooo0_l00006ooooo`;o0000Coooool001cooooo00?o
0000ooooooooool0D?ooool2o`0000Wooooo0_l0000Oooooo`;o00002Oooool2o`0000Sooooo0_l0
000Jooooo`;o00001Oooool5o`000003ooooool0003o000000;ooooo3?l0000Aooooo`;o00003Ooo
ool2o`0005gooooo000Looooo`03o`000?oooooooooo04;ooooo0_l0000Gooooo`;o00006?ooool2
o`0000[ooooo1?l00003ooooo`Co00001Oooool3o`0001?ooooo0_l00002ooooo`Co00001oooool7
o`000003ooooool0003o000000Wo000000Coooooo`000?l0003ooooo1?l0000:ooooo`;o00004_oo
ool2o`0005Sooooo000Looooo`03o`000?oooooooooo04;ooooo0_l0000Kooooo`;o00005?ooool2
o`000004ooooool0003o0000o`0000Kooooo1_l000000ooooooo0000o`000003o`0000Gooooo0_l0
000Cooooo`;o00000_ooool2o`0000Oooooo0_l000000ooooooo0000o`00000Co`000003ooooool0
003o000000;o00005Oooool2o`0000;ooooo0_l00003ooooo`;o00001?ooool4o`00053ooooo000L
ooooo`03o`000?oooooooooo04gooooo0_l0000@ooooo`;o00005oooool3o`0000Gooooo0_l00000
0ooooooo0000o`000004o`0000;ooooo0ol0000Iooooo`;o00002ooooolHo`000003ooooool0003o
000001Oooooo0_l000001?oooooo0000o`000?l00009ooooo`Co00000_ooool2o`0004cooooo000L
ooooo`03o`000?oooooooooo04_ooooo1?l00002ooooo`;o00001_ooool2o`0001oooooo0_l00000
0ooooooo0000o`000003o`000003ooooool0003o000000Co00000oooool3o`000003ooooool0003o
000001gooooo0_l00003oooooaSo00003Oooool2o`0000cooooo1?l00007ooooo`;o00001oooool2
o`0004cooooo000Looooo`03o`000?oooooooooo04_ooooo0_l00004ooooo`;o00001_ooool2o`00
01oooooo1ol000000ooooooo0000o`000006o`0000;ooooo0ol000001?oooooo0000o`000?ooool2
o`0001?ooooo0_l00005ooooo`;o00000ooooolHo`0000gooooo0ol0000;ooooo`;o00001Oooool2
o`0000;ooooo0_l00008ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0AOooool2o`00
03?ooooo5Ol00003ooooo`?o00004oooool2o`0000Wooooo6_l0000=ooooo`;o00004_ooool2o`00
00Gooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l00018ooooo`007?ooool00ol0
003oooooooooo`15ooooo`;o0000<OoooolLo`00017ooooo0_l00008ooooo`?o000000?oooooo`00
0?l000000_ooool8o`000003ooooool0003o000000_o000000?oooooo`000?l000009Oooool2o`00
00;ooooo0_l000001?oooooo0000o`000?ooool2o`0004Sooooo000Looooo`03o`000?oooooooooo
04Cooooo0ol0000aooooo`;o00000_oooolFo`0001?ooooo0_l00008ooooo`?o000000?oooooo`00
0?l000005Ol000001?oooooo0000o`000?ooool2o`0000[ooooo0_l0000<ooooo`;o00001?ooool2
o`0000Cooooo0ol00008ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0A?ooool4o`00
03;ooooo6?l00002ooooo`;o00005oooool4o`000003ooooool0003o000001Ko00004?ooool2o`00
00cooooo0_l00004ooooo`;o00001?ooool5o`0000Kooooo0_l00002ooooo`;o0000A?ooool001co
oooo00?o0000ooooooooool0A_ooool2o`0000Sooooo0_l0000XoooooaSo00000_ooool2o`0001Ko
oooo0ol00003oooooa_o00003_ooool2o`0001Oooooo1Ol00006ooooo`;o00000_ooool2o`0000?o
oooo0_l0000oooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00000_ooool2o`0002;ooooo
0_l000000ooooooo0000o`00000Eo`0001;ooooo0_l00006ooooo`;o00001?oooolKo`0000kooooo
0_l0000Dooooo`;o000000Coooooo`000?l0003ooooo0_l0000?ooooo`;o0000?oooool001cooooo
00?o0000ooooooooool0>?ooool2o`0001Kooooo0_l00002ooooo`;o00007Oooool7o`000003oooo
ool0003o000001Ko00004Oooool2o`0000;ooooo0_l00006oooooa_o00000_ooool2o`0000[ooooo
0_l0000Fooooo`;o00000oooool3o`00017ooooo0_l0000mooooo`007?ooool00ol0003ooooooooo
o`0hooooo`;o0000>Oooool7o`000003ooooool0003o000001Ko00005Oooool2o`0000Kooooo7ol0
000:ooooo`?o00006_ooool3o`0000Gooooo0_l0000:ooooo`;o0000?Oooool001cooooo00?o0000
ooooooooool0Coooool2o`0002?ooooo4ol000000ooooooo0000o`000009o`000003ooooool0003o
0000017ooooo0_l00005ooooob7o00002oooool2o`0001_ooooo0_l00003ooooo`Go00002Oooool2
o`0003gooooo000Looooo`;o0000@Oooool2o`0000gooooo0_l00004ooooo`;o00007Oooool2o`00
0003ooooool0003o000001Ko000000Goooooo`000?l0003o0000ooooo`02o`0000cooooo1?l00000
0ooooooo0000o`000005ooooo`?o000000?oooooo`000?l000005ol0000aooooo`Go00002Oooool2
o`0003gooooo000Looooo`03o`000?oooooooooo043ooooo0_l0000Cooooo`;o00005_ooool2o`00
00Sooooo6?l000000ooooooo0000o`000004o`000003ooooool0003o000000Wooooo1?l00008oooo
o`;o00000ooooolFo`0002kooooo0_l0000?ooooo`;o0000?oooool001cooooo00?o0000oooooooo
ool0Doooool2o`0001Oooooo1?l00007oooooaoo000000?oooooo`000?l000002?ooool2o`0000?o
oooo0_l0000;ooooo`Oo000000?oooooo`000?l000001ol000001?oooooo0000o`000?l00002oooo
o`Co00009oooool7o`0000cooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`14ooooo`;o
00003Oooool2o`0000Oooooo0_l0000;ooooo`;o000000?oooooo`000?l000000_l00003ooooob7o
00003Oooool2o`0000?ooooo0_l00005ooooo`;o00000ooooolBo`000004ooooool0003o0000o`00
00;ooooo1?l0000:ooooo`;o00006oooool2o`0000;ooooo0ol0001=ooooo`007?ooool00ol0003o
ooooooooo`0nooooo`;o00001?ooool2o`0000?ooooo0_l00009ooooo`;o00001_ooool2o`0000_o
oooo0_l00008ooooob7o00003Oooool8o`0000Cooooo0_l00003oooooa3o00001Oooool2o`0000[o
oooo0_l000000ooooooo0000o`000002o`0001oooooo1?l00008ooooo`;o0000@_ooool001cooooo
00?o0000ooooooooool0?_ooool2o`000003ooooool0003o000000Kooooo0_l00009ooooo`;o0000
7Oooool2o`000003ooooool0003o000001[o00003oooool8o`000003ooooool0003o000000Sooooo
3ol00004ooooo`;o00002_ooool2o`000003ooooool0003o000002;ooooo0ol00008ooooo`;o0000
@_ooool001cooooo00?o0000ooooooooool0@Oooool2o`00013ooooo0ol0000Iooooo`?o000000?o
ooooo`000?l000000_l000000ooooooo0000o`00000Go`0001?ooooo0_l00004ooooo`;o00000ooo
ool4o`0000?ooooo1?l00003ooooo`;o00000_ooool2o`0001Cooooo0_l0000Kooooo`;o000000Co
ooooo`000?l0003ooooo0_l00003ooooo`;o00001Oooool2o`0000;ooooo0_l0000mooooo`007?oo
ool00ol0003oooooooooo`0hooooo`;o00006Oooool3o`0000cooooo0_l00007ooooo`;o00000_oo
ool3o`0000;ooooo7Ol0000Cooooo`?o00001_ooool6o`0000?ooooo0ol00004ooooo`Co00005_oo
ool2o`0001_ooooo0_l000001?oooooo0000o`000?ooool3o`0000;ooooo0_l00005ooooo`;o0000
0_ooool2o`0003gooooo000Looooo`03o`000?oooooooooo03Sooooo0_l0000Pooooo`;o00001_oo
ool2o`0000Oooooo0_l00003ooooo`;o00000_oooolKo`00013ooooo0_l00002ooooo`Co000000?o
ooooo`000?l000000_l000001Ooooooo0000o`000?l0003ooooo00;o00003?ooool2o`0001Kooooo
0_l00005ooooo`;o00006?ooool5o`0000?ooooo0_l000000ooooooo0000o`000008ooooo`;o0000
>_ooool001cooooo00?o0000ooooooooool0@_ooool2o`0001Kooooo0_l00007ooooo`;o00001_oo
ool2o`0000?ooooo2Ol00002oooooaKo00003_ooool2o`0000;ooooo0_l00003ooooo`Co00000_oo
ool2o`000003ooooool0003o000001oooooo0_l00003ooooo`?o00000_ooool4o`0001Sooooo1Ol0
0003ooooo`;o000000Coooooo`000?l0003ooooo0_l00005ooooo`;o0000>_ooool001cooooo00?o
0000ooooooooool0@_ooool2o`0000Oooooo0_l0000Fooooo`;o00001?ooool4o`0000?ooooo2Ol0
00000ooooooo0000o`00000@o`000003ooooool0003o000000;o00002_ooool2o`000004ooooool0
003o0000ooooo`;o000000?oooooo`000?l000000_ooool3o`0000Cooooo1?l000000ooooooo0000
o`00000:ooooo`;o000000?oooooo`000?l000003Oooool2o`0000Cooooo0_l00002ooooo`;o0000
0oooool2o`0001Oooooo0ol00009ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0Booo
ool2o`0000Gooooo0_l00007ooooo`;o00002oooool4o`0000[ooooo5_l0000?ooooo`;o000000?o
ooooo`000?l000000ol000000ooooooo0000o`000002ooooo`;o00001Oooool4o`000003ooooool0
003o000000[ooooo0_l000000ooooooo0000o`00000<ooooo`Ko00002_ooool2o`0001Oooooo1?l0
0008ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0Coooool2o`000003ooooool0003o
000000Oooooo0_l0000;ooooo`Co00000oooool3o`0000Cooooo5?l00002ooooo`;o00003?ooool2
o`0000Cooooo0_l00004ooooo`Co00001oooool2o`0001kooooo1_l00008ooooo`?o00005oooool5
o`0000Sooooo1?l0000oooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00003_ooool2o`00
01cooooo1Ol00003oooooa?o00001?ooool2o`0000cooooo1?l00008ooooo`Co00001oooool2o`00
00_ooooo0_l0000Oooooo`?o00005oooool4o`0000Kooooo0_l00003ooooo`;o0000?oooool00006
ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04
ooooo`03o`000?oooooooooo03oooooo0_l0000Hooooo`;o00004_ooool4o`0000Cooooo1?l00002
ooooo`[o00005Oooool4o`000003ooooool0003o000000Gooooo1?l00003ooooo`;o00002Oooool2
o`0000?ooooo0ol0000Kooooo`;o00006Oooool2o`0000?ooooo0_l00006ooooo`;o00002oooool2
o`0003Oooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0D?ooool2o`0000Oooooo0_l0000Aooooo`;o000000?o
ooooo`000?l000001Oooool9o`000003ooooool0003o000001Wooooo0ol000000ooooooo0000o`00
000<ooooo`;o00000_ooool2o`0000Gooooo0_l00003ooooo`;o00006?ooool2o`0000;ooooo0_l0
000Iooooo`;o00000oooool2o`0000Cooooo0_l00005ooooo`;o00001_ooool2o`0003Oooooo0000
0ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006ooooo`03o`000?oooooo
oooo053ooooo0_l0000<ooooo`;o00002?ooool2o`0000;ooooo0_l000000ooooooo0000o`000006
ooooo`So00006Oooool2o`000005ooooool0003o0000o`000?ooool00_l00003ooooo`;o00001Ooo
ool2o`0000Cooooo0_l00002ooooo`;o00008?ooool2o`0002Gooooo0_l000000ooooooo0000o`00
0005ooooo`;o0000?oooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool0
1?m4A4CogMgMooooool00007ooooo`?o0000D_ooool2o`0000[ooooo0_l00008ooooo`;o00002ooo
ool2o`0000?ooooo1Ol00006ooooo`;o00004Oooool2o`0000Gooooo0_l00003ooooo`Co00000ooo
ool2o`0000Sooooo0_l0000Vooooo`?o00004oooool2o`0000Wooooo0_l00019ooooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o
0000ooooooooool0??ooool2o`0001Cooooo0_l00004ooooo`;o00001?ooool2o`0000Sooooo0_l0
0007ooooo`Ko00000oooool2o`0000Wooooo0_l0000Dooooo`;o00002?ooool3o`0000Kooooo0_l0
0009ooooo`Co00007Oooool2o`000004ooooool0003o0000o`0001?ooooo0_l0000Mooooo`;o0000
=Oooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00omgMgOoc<c<o`00
0007ooooo`03o`000?oooooooooo03cooooo1?l0000Hooooo`;o00002?ooool2o`000003ooooool0
003o000000?o00001oooool5o`0002Gooooo0_l00008ooooo`Go00000_ooool6o`0000Oooooo1?l0
00000ooooooo0000o`00000Jooooo`;o00005oooool4o`0000Wooooo0ol00004ooooo`;o00000_oo
ool2o`0000Gooooo0_l0000eooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<ooooo`03onk^
k_m4A4Co000000Oooooo00?o0000ooooooooool0>oooool2o`000003ooooool0003o000002;ooooo
0_l000000ooooooo0000o`000006o`0000;ooooo0_l00002ooooo`;o00001Oooool2o`0001gooooo
0_l00008ooooo`?o00000_ooool3o`000005ooooool0003o0000o`000?ooool00_l0000<ooooo`;o
00006?ooool4o`0001Wooooo0_l00009ooooo`?o00000oooool4o`000003ooooool0003o000000Go
oooo0_l0000eooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo
00Kooooo00?o0000ooooooooool0;?ooool2o`0000gooooo0ol0000Aooooo`;o00002_ooool2o`00
00;ooooo0_l00006ooooo`Ko00000_ooool6o`0000Gooooo0_l0000Looooo`?o00001_ooool6o`00
00;ooooo1_l00002ooooo`;o00009Oooool2o`0000?ooooo0_l00002ooooo`;o00008oooool4o`00
00Sooooo0_l0000eooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00003_ooool2o`0000;o
oooo0_l0000=ooooo`;o00002_ooool2o`0000;ooooo3_l000001?oooooo0000o`000?ooool6o`00
01cooooo0_l00003ooooo`;o00001oooool2o`0000;ooooo0_l00003ooooo`Wo00009oooool2o`00
0003ooooool0003o000000;ooooo0_l00004ooooo`;o00006Oooool2o`0000;ooooo0_l0000;oooo
o`;o0000=?ooool001cooooo00?o0000ooooooooool0@?ooool2o`0001Wooooo5Ol00005ooooo`;o
00007?ooool2o`0000;ooooo0_l0000Cooooo`Go0000:Oooool2o`0000_ooooo0_l0000Eooooo`;o
00000_ooool2o`0000;ooooo0_l0000;ooooo`;o0000=?ooool001cooooo00?o0000ooooooooool0
>_ooool2o`0000oooooo0_l0000>oooooaCo00002Oooool2o`0001Oooooo0_l00004ooooo`;o0000
3oooool2o`0000;ooooo0ol00002ooooo`;o0000<_ooool2o`00017ooooo0_l00004ooooo`;o0000
1Oooool2o`0004;ooooo000Looooo`03o`000?oooooooooo03Kooooo0_l00002ooooo`;o00003ooo
ool2o`0000cooooo1ol000000ooooooo0000o`00000;o`0000?ooooo0_l000000ooooooo0000o`00
0002ooooo`?o00005_ooool2o`000003ooooool0003o000001;ooooo0_l00002ooooo`Oo0000<_oo
ool2o`00017ooooo0_l0000:ooooo`?o0000@_ooool001cooooo00?o0000ooooooooool0=_ooool2
o`000003ooooool0003o000001[ooooo0_l00002oooooaOo000000Coooooo`000?l0003ooooo1ol0
000Iooooo`;o00003Oooool2o`0000Oooooo1_l00003ooooo`;o00000oooool4o`0000Kooooo0ol0
000Jooooo`;o00000_ooool2o`0000[ooooo0_l0000Aooooo`;o00000_ooool2o`0000Oooooo0_l0
000fooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00000oooool2o`000003ooooool0003o
000001[ooooo6ol00005ooooo`Co00006oooool4o`0000[ooooo0ol00002ooooo`;o00001?ooool2
o`0000Kooooo0_l00002ooooo`Go000000?oooooo`000?l000000oooool3o`0000?ooooo0_l0000E
ooooo`;o00001_ooool2o`0000Kooooo0_l00007ooooo`Co00002_ooool3o`0000Kooooo0_l0000f
ooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00006Oooool2o`0000?ooooo0_l00003oooo
oa?o000000?oooooo`000?l000001_l0000Eooooo`;o00002oooool4o`000003ooooool0003o0000
00Oooooo0_l00003ooooo`;o000000?oooooo`000?l000000ol00002ooooo`?o00001Oooool2o`00
00Cooooo0_l00009ooooo`;o00000_ooool2o`000003ooooool0003o000001Kooooo1Ol0000<oooo
o`Co00002oooool2o`0003kooooo000Looooo`03o`000?oooooooooo02Oooooo0_l0000Mooooo`;o
00001?ooool2o`0000?ooooo0_l000001?oooooo0000o`000?oooolMo`0001?ooooo0_l0000<oooo
o`;o00000_ooool2o`0000cooooo0_l000000ooooooo0000o`000003o`0000;ooooo1Ol00003oooo
o`?o00002?ooool2o`0000Sooooo0_l000000ooooooo0000o`00000Fooooo`Oo00004_ooool2o`00
04Gooooo000Looooo`03o`000?oooooooooo02Oooooo0_l0000@ooooo`;o00002oooool2o`0000Co
oooo0_l00006oooooa_o00000oooool2o`00027ooooo0_l0000Dooooo`;o00001_ooool4o`0000;o
oooo0ol00003ooooo`;o000000?oooooo`000?l000001?l0000Uooooo`?o00000_ooool2o`0000ko
oooo0_l00015ooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00006?oooolLo`0000oooooo
0_l0000Zooooo`;o00001?ooool2o`0000;ooooo0ol00002ooooo`;o00001?ooool2o`000003oooo
ool0003o000000Co00001Oooool2o`0001kooooo0_l00003ooooo`;o00002_ooool2o`0000Wooooo
1?l0000looooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00008oooool4o`000003ooooool0
003o000001Ko00001oooool2o`0000?ooooo0_l00002ooooo`;o00002?ooool2o`00023ooooo0_l0
0004ooooo`;o000000?oooooo`000?l000000ol000000ooooooo0000o`000004ooooo`;o00000ooo
ool3o`0000Kooooo0_l0000Qooooo`;o00003?ooool2o`0000Gooooo0_l00002ooooo`Co0000??oo
ool001cooooo0_l0000]ooooo`;o00008ooooolOo`0000Gooooo0_l00003ooooo`;o00003?ooool2
o`0002Wooooo0_l000001?oooooo0000o`000?l00005ooooo`;o00001?ooool2o`0000Gooooo0_l0
000:ooooo`;o00005oooool2o`0000Oooooo0_l0000:ooooo`;o00000oooool2o`0003gooooo000L
ooooo`03o`000?oooooooooo03Kooooo0_l0000KoooooaSo00000_ooool3o`000003ooooool0003o
000000Co000000?oooooo`000?l000001Oooool2o`0001Cooooo0_l0000Kooooo`;o00000_ooool6
o`0000;ooooo0_l00003ooooo`?o00000_ooool2o`000003ooooool0003o000000[ooooo0_l00003
ooooo`;o00005oooool2o`0000;ooooo0_l0000?ooooo`;o0000?Oooool001cooooo00?o0000oooo
ooooool0=_ooool2o`0001Kooooo1Ol000000ooooooo0000o`000009o`000003ooooool0003o0000
00Wo00001_ooool6o`000003ooooool0003o000000Cooooo1?l00008ooooo`;o00002Oooool2o`00
00_ooooo0_l0000<ooooo`Ko000000?oooooo`000?l000000ol00002ooooo`;o00000_ooool3o`00
00?ooooo0_l000001?oooooo0000o`000?ooool5o`0000Cooooo0_l00003ooooo`;o00005_ooool3
o`0005;ooooo000Looooo`03o`000?oooooooooo04;ooooo0_l00005ooooo`;o00000oooool5o`00
0003ooooool0003o000001?o00001?ooool2o`0000oooooo1?l00006ooooo`Co00003?ooool2o`00
00Sooooo0_l00006ooooo`;o00001?ooool6o`000003ooooool0003o000000?o00000_ooool2o`00
00;ooooo1Ol00004ooooo`;o000000?oooooo`000?l000000ol00004ooooo`;o00001Oooool2o`00
00Sooooo0_l0000:ooooo`;o00003Oooool2o`0004Cooooo000Looooo`03o`000?oooooooooo04;o
oooo0_l00003ooooo`Co00000oooool2o`0000?ooooo5?l00006ooooo`;o00002oooool2o`0000co
oooo0_l00003ooooo`;o00001_ooool5o`00013ooooo0_l00003ooooo`Go00000oooool4o`0000;o
oooo1ol000000ooooooo0000o`000006ooooo`;o00000_ooool2o`0000;ooooo1_l00003ooooo`;o
00002?ooool3o`0001Sooooo0_l000000ooooooo0000o`000007ooooo`;o0000>?ooool001cooooo
00?o0000ooooooooool0;?ooool2o`0001Wooooo0ol000000ooooooo0000o`000003o`0000?ooooo
0_l00004ooooo`co00002?ooool2o`0000_ooooo0_l0000=ooooo`;o00000_ooool2o`0000?ooooo
1ol0000Dooooo`Ko00000oooool5o`0000;ooooo1ol000000ooooooo0000o`000006ooooo`;o0000
1Oooool7o`0000kooooo0_l0000Hooooo`Go00001oooool2o`0003Sooooo000Looooo`03o`000?oo
oooooooo02cooooo0_l0000Jooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`00
0007ooooo`Wo000000Coooooo`000?l0003ooooo0_l00006ooooo`;o00000_ooool2o`000003oooo
ool0003o000000?o00001?ooool2o`000003ooooool0003o000000;o00001?ooool3o`0000Kooooo
0ol0000=ooooo`;o00002Oooool6o`0000?ooooo2?l00002ooooo`?o00000_ooool2o`0000Kooooo
0ol00003ooooo`Oo0000:Oooool6o`0000Kooooo0_l0000hooooo`007?ooool00ol0003ooooooooo
o`11ooooo`;o00001?ooool2o`0000?ooooo1_l00007ooooo`Go00000_ooool2o`0000Cooooo0_l0
0004ooooo`Co000000?oooooo`000?l000001ol00004ooooo`;o000000?oooooo`000?l000001?l0
0002ooooo`Ko000000?oooooo`000?l000001_l00002ooooo`;o000000?oooooo`000?l000000ooo
ool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`Co00001Oooool7o`0000;ooooo0_l0
0003ooooo`;o00001Oooool?o`0001cooooo0ol00009ooooo`;o000000Coooooo`000?l0003o0000
1?ooool4o`0003Sooooo000Looooo`03o`000?oooooooooo02;ooooo0_l0000Mooooo`?o00000ooo
ool=o`0000Gooooo1Ol000000ooooooo0000o`000006ooooo`;o00000oooool2o`0000?ooooo1ol0
000:ooooo`;o000000?oooooo`000?l000000_ooool6o`000003ooooool0003o000000Ko00000_oo
ool2o`000003ooooool0003o000000Sooooo0_l000000ooooooo0000o`00000:o`000003ooooool0
003o000000Co000000?oooooo`000?l000000_l0000:ooooo`?o000000?oooooo`000?l000002Ol0
000=ooooo`;o00001_ooool2o`0000Gooooo0ol0000Cooooo`?o00000_ooool2o`0003Gooooo000L
ooooo`03o`000?oooooooooo02;ooooo0_l0000=ooooo`;o00003oooool2o`0000;ooooo0_l00000
0ooooooo0000o`000003o`000003ooooool0003o000000?o00001Oooool2o`0000Cooooo0_l00006
ooooo`;o00008Oooool2o`0000Gooooo0_l0000Iooooo`Go000000?oooooo`000?l000001Ol00002
ooooo`;o000000?oooooo`000?l000000_l00007ooooo`;o00001_ooool:o`0000gooooo0_l00006
ooooo`;o00001?ooool2o`0000Oooooo0_l00004ooooo`Co00002?ooool3o`0003Gooooo000Loooo
o`03o`000?oooooooooo037ooooo0_l0000Cooooo`;o00000_ooool4o`000003ooooool0003o0000
00?o00001Oooool2o`0002oooooo0_l0000Nooooo`;o00000oooool2o`0000Gooooo1Ol00003oooo
o`?o00002?ooool2o`0000Oooooo2_l0000Jooooo`;o00001Oooool4o`0000Cooooo1?l000000ooo
oooo0000o`000005ooooo`;o0000=_ooool001cooooo00?o0000ooooooooool0:?ooool2o`00023o
oooo1?l000000ooooooo0000o`00000Zooooo`Co00005Oooool3o`000003ooooool0003o0000013o
oooo0_l0000;ooooo`Oo000000?oooooo`000?l000003Oooool2o`0000;ooooo1?l000000ooooooo
0000o`000004o`0000[ooooo0_l0000<ooooo`;o00001_ooool2o`0000_ooooo0_l00005ooooo`;o
0000=_ooool001cooooo00?o0000ooooooooool0:?ooool3o`0001gooooo0_l00002ooooo`;o0000
00?oooooo`000?l000003_ooool2o`0000?ooooo0_l0000Dooooo`Go00005Oooool3o`000003oooo
ool0003o000001;ooooo0_l00005ooooo`;o00000_ooool7o`000003ooooool0003o000000gooooo
0_l00002ooooo`go00002?ooool2o`0000[ooooo1?l00007ooooo`;o00000_ooool2o`0000gooooo
0_l0000fooooo`007?ooool00ol0003oooooooooo`0Yooooo`;o00007Oooool2o`0000;ooooo0_l0
00000ooooooo0000o`000002o`0000cooooo0_l00003ooooo`;o00005?ooool2o`0000cooooo1?l0
0003ooooo`;o00001?ooool2o`0001Gooooo0_l00005ooooo`;o00000_ooool5o`0000oooooo0_l0
0005ooooo`ko00001oooool2o`0000Gooooo0_l00003ooooo`Go00001_ooool7o`0000_ooooo0_l0
000gooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00007?ooool2o`000003ooooool0003o
000000;ooooo1?l0000?ooooo`?o00002oooool2o`0000?ooooo0ol0000>ooooo`Co00000oooool2
o`0001Oooooo0_l0000=ooooo`?o00004Oooool2o`0000Gooooo1Ol000000ooooooo0000o`000009
o`000003ooooool0003o000000?o00001Oooool2o`0000?ooooo1Ol00008ooooo`Oo00001Oooool2
o`0000;ooooo0_l0000gooooo`007?ooool00ol0003oooooooooo`0Yooooo`;o000000?oooooo`00
0?l000007?ooool5o`0000;ooooo1Ol0000>ooooo`Go00002Oooool2o`0000?ooooo0ol0000>oooo
o`;o00007_ooool2o`0000[ooooo0_l00002ooooo`;o000000?oooooo`000?l000005Oooool4o`00
0003ooooool0003o000000Co00000oooool3o`000003ooooool0003o000000;o00002Oooool9o`00
00Oooooo0_l00002ooooo`;o00001Oooool2o`0003_ooooo000Looooo`;o0000:_ooool2o`0001Go
oooo0_l00005ooooo`;o00000oooool2o`000003ooooool0003o000000Go00002_ooool2o`0000Go
oooo0_l0000Oooooo`Co000000?oooooo`000?l000003?ooool2o`00013ooooo0_l00005ooooo`;o
00000_ooool5o`0001Gooooo1?l000000ooooooo0000o`000004o`0000?ooooo0_l0000=ooooo`Ko
000000?oooooo`000?l000000_l00006ooooo`;o00003_ooool2o`0003Oooooo000Looooo`03o`00
0?oooooooooo043ooooo0ol00003ooooo`Go00001?ooool2o`0000;ooooo0_l0000;ooooo`;o0000
:?ooool2o`000003ooooool0003o000000cooooo0_l00004ooooo`;o00001?ooool2o`000004oooo
ool0003o0000ooooo`;o00001Oooool4o`000003ooooool0003o000000?o00005Oooool:o`0001;o
oooo2Ol00008ooooo`;o000000?oooooo`000?l000002Oooool4o`0003Oooooo000Looooo`03o`00
0?oooooooooo02Kooooo0_l00007ooooo`;o00004?ooool2o`0000?ooooo1Ol0000Eooooo`;o0000
2_ooool2o`0000?ooooo0_l0000Looooo`;o00002Oooool2o`0000Gooooo0_l00004ooooo`;o0000
00?oooooo`000?l000001?l00006ooooo`;o00000oooool3o`00017ooooo3Ol000000ooooooo0000
o`00000@ooooo`;o00000_ooool4o`0000[ooooo1?l00003ooooo`Co00000_ooool2o`0003Wooooo
000Looooo`03o`000?oooooooooo02Cooooo1?l00007ooooo`;o00004?ooool2o`0000Gooooo0_l0
000Fooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l00002ooooo`?o00002?oo
ool2o`0000kooooo0_l00002ooooo`;o00000_ooool2o`0000Cooooo0ol0000>ooooo`Ko00004?oo
ool2o`0000gooooo3?l00002ooooo`;o00004?ooool2o`0000;ooooo1?l00009ooooo`Co00001?oo
ool4o`0003gooooo000Looooo`03o`000?oooooooooo02Cooooo0_l00008ooooo`;o00004Oooool2
o`0000?ooooo0_l0000Eooooo`;o00001?ooool6o`0000Kooooo0ol00009ooooo`?o00003Oooool3
o`0000Gooooo0_l00004ooooo`;o00001_ooool2o`0000Oooooo0_l000000ooooooo0000o`000007
ooooo`;o00001?ooool2o`0000;ooooo0_l0000@ooooo`So00000oooool2o`0001;ooooo1_l00003
ooooo`;o00000_ooool7o`0000Gooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0Yoooo
o`?o00000_ooool2o`0001Kooooo0_l00007ooooo`;o00001Oooool2o`0000Gooooo0_l00004oooo
o`Go00001oooool2o`0000[ooooo0ol0000;ooooo`;o000000?oooooo`000?l000002Oooool2o`00
00Sooooo0_l00005ooooo`;o00000oooool2o`0000Oooooo0ol00003ooooo`;o00001_ooool2o`00
00oooooo2_l00002ooooo`;o00003_ooool4o`000004ooooool0003o0000ooooo`?o00000_ooool2
o`0000?ooooo0_l00005ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0:Oooool3o`00
01?ooooo0_l00005ooooo`;o00001oooool2o`000003ooooool0003o000000;ooooo1?l00003oooo
o`;o00000_ooool2o`0000;ooooo0ol0000Mooooo`;o00000_ooool2o`0000cooooo0ol0000>oooo
o`;o000000Coooooo`000?l0003o00002Oooool2o`0000_ooooo0_l0000:ooooo`;o00001?ooool9
o`0000;ooooo0_l0000<ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o0000C_oo
ool001cooooo00?o0000ooooooooool0?oooool2o`00017ooooo2?l00003ooooo`;o00000_ooool2
o`0000?ooooo0_l0000Mooooo`;o00004Oooool2o`00017ooooo0ol00007ooooo`Co00005oooool2
o`0000?ooooo1?l0000Eooooo`?o00001Oooool2o`00057ooooo000Looooo`03o`000?oooooooooo
03oooooo0_l00004ooooo`?o00002oooool5o`0000?ooooo0_l00003ooooo`;o00007Oooool4o`00
00;ooooo0_l0000Zooooo`;o00000_ooool4o`0000Cooooo0ol0000Eooooo`;o00004oooool2o`00
00;ooooo0_l000000ooooooo0000o`000002ooooo`?o0000DOooool001cooooo00?o0000oooooooo
ool09?ooool2o`0001Wooooo0_l00004ooooo`Ko00001Oooool2o`000003ooooool0003o000000Co
oooo1_l000000ooooooo0000o`000004ooooo`;o00003oooool2o`0000Kooooo1?l00002ooooo`;o
00001oooool2o`00027ooooo0ol00003ooooo`;o00001?ooool5o`0000Oooooo0_l0000Oooooo`;o
00001Oooool2o`0000;ooooo0_l0000Fooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0
9?ooool2o`000003ooooool0003o000001gooooo1Ol00005ooooo`;o00001oooool6o`000003oooo
ool0003o000000Cooooo0_l000000ooooooo0000o`00000<ooooo`;o00001_ooool3o`0000cooooo
0ol00009ooooo`;o00005Oooool3o`0000?ooooo0ol00003ooooo`;o000000?oooooo`000?l00000
1oooool4o`00017ooooo0_l00007ooooo`;o000000?oooooo`000?l000008Oooool2o`0003[ooooo
000Looooo`03o`000?oooooooooo02Oooooo0_l0000Gooooo`?o00000oooool3o`0000;ooooo0_l0
0003ooooo`;o00002Oooool3o`0000Sooooo1Ol00007ooooo`;o00002oooool2o`0000kooooo0_l0
0002ooooo`;o00001Oooool2o`0000_ooooo0_l00008ooooo`;o00001Oooool2o`00017ooooo0_l0
0007ooooo`;o00002?ooool2o`0000Oooooo0_l00005ooooo`;o00000oooool2o`0000_ooooo0_l0
0017ooooo`007?ooool00ol0003oooooooooo`10ooooo`?o00000_ooool4o`0000;ooooo0_l0000>
ooooo`?o00002?ooool4o`0000Sooooo0_l0000=ooooo`Co00000_ooool2o`0000;ooooo1?l00004
ooooo`Co000000?oooooo`000?l000001Oooool2o`0000Gooooo0ol0000Mooooo`;o00003?ooool2
o`0000Wooooo0_l0000=ooooo`;o000000?oooooo`000?l000000_l00009ooooo`Co0000Aoooool0
01cooooo00?o0000ooooooooool09oooool2o`0001cooooo0ol00002ooooo`?o00004?ooool2o`00
01;ooooo0_l00006ooooo`Go00000oooool4o`0000;ooooo2?l00006ooooo`;o000000Coooooo`00
0?l0003ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000[ooooo0_l00000
0ooooooo0000o`000002ooooo`;o00001_ooool2o`0000?ooooo0ol0000Aooooo`?o00000_ooool2
o`0000kooooo1_l00008ooooo`Go0000Aoooool001cooooo00?o0000ooooooooool09oooool2o`00
01gooooo0_l00002ooooo`;o00004?ooool7o`0000kooooo1?l000000ooooooo0000o`000006o`00
0003ooooool0003o000000Kooooo1_l00002ooooo`;o00001Oooool3o`000004ooooool0003o0000
o`0000Gooooo0_l0000>ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000Cooooo1?l0
0003ooooo`?o00001Oooool2o`0000[ooooo1ol0000<ooooo`Go000000?oooooo`000?l000002?oo
ool2o`000004ooooool0003o0000ooooo`;o00000oooool2o`0003oooooo000Looooo`03o`000?oo
oooooooo02;ooooo0_l0000Rooooo`;o000000?oooooo`000?l000004Oooool2o`000003ooooool0
003o000000;o00003_ooool;o`0000?ooooo0_l00006ooooo`_o00001?ooool3o`000003ooooool0
003o000000Cooooo0_l0000Booooo`Co00000oooool2o`0000;ooooo0ol00004ooooo`;o00001_oo
ool2o`0000_ooooo1_l0000<ooooo`;o00000oooool3o`0000_ooooo1Ol00002ooooo`?o0000?ooo
ool001cooooo0_l0000Sooooo`;o00001oooool2o`0001Wooooo1Ol00002ooooo`;o00004Oooool4
o`0000_ooooo0_l000000ooooooo0000o`000005o`000003ooooool0003o000000_ooooo2?l00000
0ooooooo0000o`000006ooooo`Co00001?ooool2o`0000Gooooo0_l00009ooooo`Go00001?ooool2
o`0000;ooooo0ol00004ooooo`;o00005_ooool2o`0001;ooooo0ol0000=ooooo`Co000000?ooooo
o`000?l00000@?ooool001cooooo00?o0000ooooooooool0:oooool2o`0001[ooooo0ol00003oooo
o`;o000000?oooooo`000?l000001?ooool2o`0000Kooooo0_l00002ooooo`;o00000_ooool2o`00
0003ooooool0003o000000;o00000_ooool:o`000004ooooool0003o0000o`0000Kooooo0_l0000:
ooooo`?o00000_ooool2o`0000;ooooo0_l00005ooooo`;o000000Coooooo`000?l0003ooooo1?l0
0004ooooo`;o00000oooool2o`0000Oooooo0_l00004ooooo`;o00002_ooool2o`0000_ooooo0_l0
0006ooooo`;o00002Oooool2o`0000gooooo0_l00003ooooo`Go00000oooool2o`000003ooooool0
003o000003_ooooo000Looooo`03o`000?oooooooooo04Sooooo0_l00006ooooo`;o00001?ooool2
o`0000Gooooo0ol00006ooooo`;o000000?oooooo`000?l000000ol00002ooooo`?o000000?ooooo
o`000?l000000_ooool2o`000003ooooool0003o000000Kooooo0_l000000ooooooo0000o`000002
o`0000Gooooo0ol00002ooooo`?o00002?ooool2o`000003ooooool0003o000000?o00001_ooool4
o`000003ooooool0003o000000gooooo0_l0000:ooooo`;o00001Oooool2o`0000Cooooo0_l00006
ooooo`;o00001oooool7o`0000Sooooo1?l00003ooooo`?o000000?oooooo`000?l000000_ooool5
o`0003_ooooo000Looooo`03o`000?oooooooooo02?ooooo0_l00005ooooo`;o00007Oooool2o`00
013ooooo2?l00009ooooo`;o00000_ooool2o`000003ooooool0003o000000?ooooo0_l00004oooo
o`;o00000_ooool2o`000003ooooool0003o000000Oo00000_ooool2o`0000?ooooo0_l000000ooo
oooo0000o`000008ooooo`?o000000?oooooo`000?l000001Oooool7o`0000Gooooo0_l00004oooo
o`;o00000_ooool2o`0000Kooooo1?l000001Ooooooo0000o`000?l0003ooooo00;o00002oooool2
o`0000Gooooo0_l000000ooooooo0000o`000005o`0000Gooooo0_l000000ooooooo0000o`000007
ooooo`Co00000oooool4o`0003_ooooo000Looooo`03o`000?oooooooooo02?ooooo1?l00003oooo
o`;o00007Oooool3o`0000;ooooo0_l00005ooooo`;o00001?ooool4o`000005ooooool0003o0000
o`000?ooool00_l00003ooooo`;o00001Oooool6o`0000;ooooo0_l00004ooooo`Ko000000?ooooo
o`000?l000002Ol00002ooooo`Go000000?oooooo`000?l000001Oooool2o`000003ooooool0003o
000000;ooooo0_l00003ooooo`Go000000?oooooo`000?l000001_ooool2o`000004ooooool0003o
0000ooooo`;o00000_ooool2o`0000Gooooo1Ol000001?oooooo0000o`000?l00005ooooo`?o0000
1Oooool3o`0000Cooooo0ol00003ooooo`;o00002?ooool2o`000003ooooool0003o000000Oooooo
0ol00013ooooo`007?ooool00ol0003oooooooooo`0Uooooo`;o00008?ooool2o`000003ooooool0
003o000000;ooooo0_l00005ooooo`;o00001Oooool3o`0000;ooooo0_l000000ooooooo0000o`00
0003ooooo`Co000000?oooooo`000?l000000_ooool4o`0000;ooooo6Ol000000ooooooo0000o`00
0004o`0000Gooooo1_l00008ooooo`;o000000?oooooo`000?l000002oooool3o`0000Wooooo0_l0
00000ooooooo0000o`000002ooooo`Co000000?oooooo`000?l000000oooool3o`0000Gooooo0_l0
0005ooooo`?o00004?ooool2o`0000Cooooo0ol000000ooooooo0000o`000013ooooo`007?ooool0
0ol0003oooooooooo`12ooooo`;o00000oooool2o`000003ooooool0003o000000_ooooo0_l00003
ooooo`Oo00002?ooool6o`0000Sooooo1Ol00002ooooo`So00000_ooool9o`0000?ooooo1?l00003
ooooo`;o00000_ooool2o`0000Sooooo0_l00002ooooo`;o00002?ooool5o`0000Wooooo1Ol00000
0ooooooo0000o`00000<o`0000gooooo0_l00003ooooo`;o00000_ooool2o`0000gooooo0ol00016
ooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00001_ooool3o`0000[ooooo0_l00005oooo
o`Co00001_ooool3o`000004ooooool0003o0000ooooo`;o00002?ooool2o`000003ooooool0003o
000000?ooooo1ol000000ooooooo0000o`00000?o`0000;ooooo0ol000000ooooooo0000o`000007
ooooo`;o00001?ooool3o`0000Oooooo0_l00009ooooo`Co000000?oooooo`000?l000003ol0000>
ooooo`;o00000oooool2o`0000;ooooo0_l0000>ooooo`;o0000A_ooool001cooooo00?o0000oooo
ooooool07Oooool2o`0002Kooooo0_l00004ooooo`;o00005?ooool2o`0000Gooooo0ol0000Aoooo
o`;o00000ooooolFo`000003ooooool0003o000000;ooooo0ol000000ooooooo0000o`000004oooo
o`Go00001?ooool4o`0000Oooooo0_l00006oooooaSo00000oooool2o`0000Wooooo0_l0000<oooo
o`Co00001_ooool2o`0004Oooooo000Looooo`03o`000?oooooooooo01gooooo0_l0000@ooooo`;o
00005?ooool2o`0000Cooooo0_l0000Dooooo`;o00001oooool2o`000004ooooool0003o0000oooo
o`;o00001Oooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o0000
017o000000Coooooo`000?l0003ooooo1Ol00006ooooo`Co00001?ooool5o`0000Oooooo0_l00006
oooooaOo00000_ooool4o`0000[ooooo0_l00006ooooo`;o00000oooool4o`0000Kooooo0_l00006
ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0;oooool2o`0001?ooooo0_l00005oooo
o`?o00001_ooool2o`0000[ooooo0ol00007ooooo`So00001Oooool2o`0000?ooooo9Ol00004oooo
o`Co00001Oooool2o`0000;ooooo0_l00006ooooo`;o00001OoooolDo`000003ooooool0003o0000
00Oo00002_ooool2o`0000Kooooo0ol00006ooooo`;o00003?ooool2o`0003oooooo000Looooo`03
o`000?oooooooooo02?ooooo0_l0000Oooooo`;o000000?oooooo`000?l000000oooool2o`0000Co
oooo1?l0000:ooooo`?o00002?ooool3o`000003ooooool0003o000000Kooooo1?l00003ooooob?o
00001?ooool3o`0000Kooooo0ol000000ooooooo0000o`000004ooooo`;o00001oooool2o`0000;o
oooo6?l0000:ooooo`;o00002Oooool2o`0000Cooooo1_l0001;ooooo`007?ooool00ol0003ooooo
ooooo`0Sooooo`;o00008Oooool3o`0000Kooooo0_l000000ooooooo0000o`000003ooooo`;o0000
3_ooool2o`0000;ooooo0_l00002ooooo`;o00001?ooool2o`000003ooooool0003o000000?o0000
00?oooooo`000?l000007Ol000001?oooooo0000o`000?l00004ooooo`;o00001Oooool5o`0000Co
oooo0_l000000ooooooo0000o`000005oooooa_o00003Oooool2o`0000oooooo0_l00002ooooo`;o
0000Boooool001cooooo00?o0000ooooooooool0A_ooool2o`0000?ooooo0_l00002ooooo`;o0000
0_ooool2o`000004ooooool0003o0000o`0000kooooo0_l00002ooooo`;o00000_ooool2o`0000Co
oooo1Ol000000ooooooo0000o`00000Lo`000004ooooool0003o0000ooooo`Ko00000_ooool5o`00
00;ooooo0_l000000ooooooo0000o`000004ooooo`Go00000ooooolMo`0002;ooooo0ol00005oooo
o`;o0000@oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo04_ooooo1?l00004ooooo`;o000000Co
ooooo`000?l0003o00002_ooool2o`0001;ooooo;Ol00002ooooo`Go00002oooool2o`0000Gooooo
0_l000001?oooooo0000o`000?oooolKo`0001kooooo0ol00005ooooo`;o0000@oooool00006oooo
oomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06
ooooo`03o`000?oooooooooo04_ooooo1?l00008ooooo`;o00002Oooool3o`0001Gooooo9Ol00000
0ooooooo0000o`000002o`0000?ooooo1?l0000Booooo`Co00000_oooolKo`000003ooooool0003o
000001Gooooo0_l0001Aooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Uooooo`;o00007_ooool2
o`0000?ooooo1Ol00006ooooo`Co00002Oooool2o`0000kooooo0_l000000ooooooo0000o`000003
ooooob7o00001_ooool2o`0001[ooooo8Ol000000ooooooo0000o`00000Eooooo`Co00002oooool2
o`0004;ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oiRH
V?ooooooV9RHob4Q8@06ooooo`?o00009Oooool2o`0001kooooo0_l00003ooooo`?o00001Oooool2
o`000003ooooool0003o000000_ooooo0_l0000>ooooo`;o000000?oooooo`000?l000000ooooolQ
o`0000?ooooo1_l000000ooooooo0000o`00000=ooooo`Co00001Oooool6o`000003ooooool0003o
000001Ko00001Oooool2o`0001Gooooo0_l00007ooooo`;o00000_ooool2o`0004;ooooo00000ooo
oooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006
ooooo`03o`000?oooooooooo03Gooooo0_l0000>ooooo`;o00001?ooool3o`0000Cooooo1Ol00002
ooooo`;o00001_ooool3o`00017ooooo0_l00002oooooago000000?oooooo`000?l000001?l00000
0ooooooo0000o`000004o`000003ooooool0003o000000gooooo1?l00003ooooo`;o000000?ooooo
o`000?l000000_l000000ooooooo0000o`00000Ho`000004ooooool0003o0000ooooo`;o00000_oo
ool2o`0000Cooooo0ol00006ooooo`?o00002_ooool2o`0004Kooooo00000ooooooo410@ooooo`02
ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`0e
ooooo`;o00003_ooool2o`0000Gooooo0_l000000ooooooo0000o`000002ooooo`Co00000_ooool2
o`0000Kooooo0ol0000Aooooo`;o00000_ooool6o`000003ooooool0003o000001_o000000?ooooo
o`000?l000001ol0000>ooooo`;o00000_ooool4o`000003ooooool0003o000001go000000?ooooo
o`000?l000001Oooool3o`0000?ooooo0ol00006ooooo`?o000000?oooooo`000?l00000Coooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oo
oooooooo04Wooooo0_l000001?oooooo0000o`000?ooool2o`00013ooooo0ol0000Booooo`;o0000
00?oooooo`000?l000008?l00003ooooo`So00004oooool2o`0000;ooooo8?l00003ooooo`Go0000
00?oooooo`000?l000004?ooool2o`000003ooooool0003o000004cooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`0Xoooo
o`;o00007Oooool4o`000003ooooool0003o000001?ooooo0ol0000Booooo`;o000000?oooooo`00
0?l000005Ol000000ooooooo0000o`000008o`0000Gooooo1_l0000:ooooo`;o00002oooool2o`00
00;ooooo1ol000000ooooooo0000o`00000;o`000003ooooool0003o000000Ko000000?oooooo`00
0?l000000ol000000ooooooo0000o`000004ooooo`;o00000_ooool5o`0000;ooooo0_l00002oooo
o`Co0000B_ooool001cooooo00?o0000ooooooooool0:?ooool2o`0001gooooo1?l00009ooooo`;o
00002oooool3o`000003ooooool0003o000001;ooooo1_l000000ooooooo0000o`00000Jo`0000Co
oooo1?l0000<ooooo`;o00003oooool?o`000003ooooool0003o000000go00000oooool2o`0000Oo
oooo0_l00002ooooo`Go000000Coooooo`000?l0003o00001?ooool2o`0004[ooooo000Looooo`03
o`000?oooooooooo03Oooooo0_l0000>ooooo`Co00001Oooool3o`000003ooooool0003o000000oo
oooo0_l00004ooooo`;o00003?ooool6o`000003ooooool0003o000001Ko00000_ooool2o`0000;o
oooo1_l00003ooooo`?o00000oooool2o`0000Sooooo0_l00008ooooo`;o000000?oooooo`000?l0
00006_l00003ooooo`;o00002?ooool3o`000003ooooool0003o000000;o000000?oooooo`000?l0
00001Oooool2o`0004[ooooo000Looooo`03o`000?oooooooooo03Oooooo0_l0000>ooooo`Co0000
1Oooool3o`0000Sooooo0_l00004ooooo`;o00002?ooool2o`0000;ooooo0_l00002ooooo`;o0000
1?oooolCo`000003ooooool0003o000000co00000_ooool3o`000003ooooool0003o000000?o0000
00Coooooo`000?l0003o00000oooool2o`0000Gooooo0_l000000ooooooo0000o`000004ooooo`;o
00000_ooool@o`000003ooooool0003o000000Oo000000?oooooo`000?l000000_ooool2o`0000So
oooo0_l000001?oooooo0000o`000?l0000=ooooo`;o0000B_ooool001cooooo00?o0000oooooooo
ool0=oooool2o`0000oooooo1Ol0000>ooooo`;o00001?ooool2o`0000;ooooo0_l00008ooooo`;o
00000_ooool2o`0000?ooooo:_l00002ooooo`;o00002Oooool2o`0000?ooooo0_l000000ooooooo
0000o`000002o`0000;ooooo0_l00004oooooa_o00000_ooool2o`0000Sooooo0_l000000ooooooo
0000o`00000@ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0AOooool2o`000004oooo
ool0003o0000ooooo`Co000000?oooooo`000?l000004oooool2o`0000kooooo0_l000000ooooooo
0000o`00000Xo`0000gooooo0_l00006ooooo`Co00001oooool3o`0000;ooooo6?l0000>ooooo`;o
00004?ooool2o`0004Sooooo000Looooo`03o`000?oooooooooo03Sooooo0_l0000;ooooo`;o0000
00?oooooo`000?l000000oooool2o`000003ooooool0003o000000Wooooo0_l0000Dooooo`;o0000
0_ooool8o`000003ooooool0003o000001_o000000?oooooo`000?l000001Ol00002ooooo`;o0000
3?ooool2o`0000Cooooo0_l00007oooooaSo000000?oooooo`000?l000001Ol0000Fooooo`;o0000
Coooool001cooooo00?o0000ooooooooool0>?ooool2o`0000gooooo0ol0000Aooooo`Co00001_oo
ool2o`0000?ooooo0_l00005ooooo`;o00000_ooool=o`000003ooooool0003o000001Co00000_oo
ool9o`000003ooooool0003o000000Sooooo0ol000000ooooooo0000o`000004ooooo`;o00002Ooo
ool7o`000003ooooool0003o000000_o000000?oooooo`000?l000002?l0000Dooooo`;o0000Cooo
ool001cooooo00?o0000ooooooooool0Aoooool3o`0000Kooooo0_l0000;ooooo`;o00001_ooool3
o`0000;ooooo0_l00009oooooboo00002oooool3o`0000Cooooo0_l000000ooooooo0000o`000004
ooooo`;o00001?oooolCo`0000;ooooo0ol00005ooooo`Co00000oooool2o`0000Oooooo0_l00003
ooooo`?o0000Coooool001cooooo00?o0000ooooooooool0:oooool2o`0001[ooooo0_l00007oooo
o`;o00005?ooool2o`0000[ooooo0_l00002ooooo`;o000000?oooooo`000?l00000:Ol0000:oooo
o`;o00001_ooool2o`0000Oooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo3ol00003
ooooo`?o00001_ooool2o`0000;ooooo0ol00005ooooo`Co00000oooool3o`0000Gooooo0_l00018
ooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o0000AOooool2o`0000;ooooo0_l00003oooo
o`Oo000000?oooooo`000?l000003_l000000ooooooo0000o`000008o`000004ooooool0003o0000
ooooo`;o00002_ooool2o`0000Gooooo0_l0000;ooooo`;o000000?oooooo`000?l000003_l00004
ooooo`Go00002_ooool3o`0000Gooooo0_l0000:ooooo`;o000000?oooooo`000?l00000B?ooool0
01cooooo00?o0000ooooooooool0;?ooool2o`0001Wooooo0_l0000Looooo`;o00002oooool2o`00
00?ooooo1?l00002ooooob7o000000Coooooo`000?l0003ooooo0_l0000:ooooo`;o00001Oooool4
o`0000;ooooo0_l00005ooooo`;o00000oooool>o`0000Cooooo0_l00003ooooo`;o000000?ooooo
o`000?l000002?ooool2o`0000Oooooo0_l00006ooooo`;o0000Boooool001cooooo0_l0000]oooo
o`Co00005Oooool7o`0001Wooooo1?l0000>ooooo`Co000000?oooooo`000?l000001Ol000000ooo
oooo0000o`00000Ho`0000Gooooo0_l00009ooooo`;o00001oooool2o`0000;ooooo0_l00005oooo
o`;o00000oooool2o`0000;ooooo3_l00003ooooo`Co000000?oooooo`000?l000001oooool3o`00
00Oooooo0_l0000<ooooo`Co0000@oooool001cooooo00?o0000ooooooooool0;_ooool2o`0001Go
oooo0_l000000ooooooo0000o`000002o`0001Wooooo1?l0000Cooooo`[o000000?oooooo`000?l0
00005?l00006ooooo`;o00001oooool2o`0000Gooooo0_l0000Fooooo`Oo000000?oooooo`000?l0
00001_l000000ooooooo0000o`00000<ooooo`;o00000_ooool2o`000004ooooool0003o0000oooo
o`Co00002_ooool4o`0004?ooooo000Looooo`03o`000?oooooooooo03cooooo0_l00009ooooo`So
00004Oooool2o`0000?ooooo0_l0000;ooooo`;o000000?oooooo`000?l000002OoooolNo`0000go
oooo0ol00003ooooo`Co00005?ooool2o`0000;ooooo0ol00005ooooo`;o000000Coooooo`000?l0
003o00003_ooool2o`0000?ooooo1Ol000000ooooooo0000o`000002o`00057ooooo000Looooo`03
o`000?oooooooooo03cooooo0ol00008ooooo`So00004Oooool2o`0000?ooooo0_l0000;ooooo`;o
000000?oooooo`000?l000000_l00007ooooo`;o000000?oooooo`000?l000002ol00003ooooo`_o
00002Oooool2o`0000;ooooo0_l00004ooooo`;o00004oooool5o`0000Oooooo1Ol000000ooooooo
0000o`000002o`0000?ooooo0_l00008ooooo`;o00001?ooool2o`000003ooooool0003o000005Go
oooo000Looooo`03o`000?oooooooooo03gooooo0_l0000;ooooo`Co0000:Oooool2o`0000?ooooo
0_l000000ooooooo0000o`000005ooooo`[o00001?ooool7o`000004ooooool0003o0000o`0000So
oooo1?l00004ooooo`;o00005Oooool5o`0000Oooooo1?l00003ooooo`?o00000oooool2o`0000go
oooo0_l00002ooooo`;o0000EOooool001cooooo00?o0000ooooooooool0J_ooool2o`0000Oooooo
0ol00004ooooo`Co000000Coooooo`000?l0003ooooo2?l000000ooooooo0000o`00000>o`000004
ooooool0003o0000o`0000Gooooo0_l00002ooooo`?o00001?ooool2o`0001Sooooo0_l00008oooo
o`;o00001?ooool4o`0000?ooooo0_l00004ooooo`;o00001?ooool5o`0000gooooo0_l00019oooo
o`007?ooool00ol0003oooooooooo`1Yooooo`?o00001oooool3o`0000Cooooo0_l00006ooooo`Ko
00000oooool>o`0000?ooooo0_l00004ooooo`Co00000_ooool2o`0002Wooooo0_l00002ooooo`;o
00000_ooool2o`0000;ooooo0ol00004ooooo`;o00001?ooool2o`000003ooooool0003o000000So
oooo0_l00003ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0G?ooool3o`000003oooo
ool0003o000000Oooooo0ol0000Eooooo`Co000000?oooooo`000?l000000oooool6o`000003oooo
ool0003o000000?o00001_ooool2o`0000?ooooo0_l00007ooooo`;o00001Oooool2o`0000Gooooo
0_l0000Jooooo`Ko00001?ooool2o`0000kooooo0_l00008ooooo`;o0000C_ooool001cooooo00?o
0000ooooooooool0@?ooool2o`0001Cooooo0_l00004ooooo`?o000000Coooooo`000?l0003ooooo
0_l00005ooooo`;o00004?ooool4o`000003ooooool0003o000000Ko00000_ooool6o`000004oooo
ool0003o0000o`0000?ooooo0_l00003ooooo`Co000000?oooooo`000?l000001oooool2o`0000Go
oooo0_l00005ooooo`;o00000_ooool2o`0000Sooooo0_l00002ooooo`;o00002?ooool2o`0000;o
oooo0_l0001^ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00002_ooool2o`0000Cooooo
0_l00002ooooo`;o00001?ooool2o`0000Gooooo0_l00004ooooo`;o000000?oooooo`000?l00000
3_ooool6o`0000?ooooo1?l00006ooooo`;o00000oooool2o`0000;ooooo1Ol000000ooooooo0000
o`000002o`0001Sooooo0_l000000ooooooo0000o`000002ooooo`;o00001?ooool2o`0000;ooooo
1?l0001jooooo`007?ooool00ol0003oooooooooo`0booooo`;o00003?ooool2o`0000[ooooo0_l0
0004ooooo`;o00001?ooool2o`0000;ooooo0_l0000;ooooo`;o000000?oooooo`000?l000004_oo
ool3o`0000cooooo0_l00003ooooo`;o00001?ooool4o`0000;ooooo0_l00007ooooo`;o00003ooo
ool2o`0000Gooooo0_l000000ooooooo0000o`000006ooooo`?o00009Oooool2o`0005?ooooo000L
ooooo`03o`000?oooooooooo03;ooooo0_l0000<ooooo`;o00005_ooool2o`0000;ooooo0_l00004
ooooo`;o00000oooool2o`0000;ooooo1Ol0000Aooooo`Co00002?ooool2o`0000gooooo0_l0000;
ooooo`;o00001Oooool2o`0001;ooooo0ol0000]ooooo`;o0000Doooool001cooooo00?o0000oooo
ooooool0H_ooool2o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000003Oooool2o`00
00Cooooo0_l000000ooooooo0000o`000005ooooo`;o00001_ooool2o`0001Sooooo0ol00002oooo
o`;o00003oooool2o`0001[ooooo0_l00004ooooo`;o00001oooool3o`0005Kooooo000Looooo`03
o`000?oooooooooo04;ooooo0_l0000Oooooo`;o00001?ooool2o`0000?ooooo0_l00007ooooo`;o
00001?ooool3o`0000Cooooo1?l000000ooooooo0000o`000006ooooo`Ko00003_ooool2o`0000Oo
oooo0ol00003ooooo`;o0000:Oooool4o`0000Cooooo0_l00005ooooo`Go00000_ooool2o`0005;o
oooo000Looooo`03o`000?oooooooooo04;ooooo0_l0000>ooooo`;o00003oooool2o`0000Cooooo
0_l0000<ooooo`?o00000_ooool4o`0000;ooooo2Ol00002ooooo`;o000000?oooooo`000?l00000
0ol0000>ooooo`Co00001oooool2o`0002oooooo0_l00002ooooo`;o00001oooool4o`0000Cooooo
0ol0001Booooo`007?ooool00ol0003oooooooooo`12ooooo`;o00003_ooool2o`0000Sooooo0_l0
000Gooooo`;o000000?oooooo`000?l000000_ooool4o`0000;ooooo0_l00004ooooo`?o00000_oo
ool5o`000004ooooool0003o0000ooooo`;o00002oooool2o`0000?ooooo0_l0000Tooooo`Co0000
1Oooool2o`0000Gooooo0_l00003ooooo`;o00001Oooool4o`0000Kooooo0_l0001Cooooo`007?oo
ool2o`0004oooooo0_l0000<ooooo`;o00005oooool2o`0000?ooooo0_l00002ooooo`Co00001Ooo
ool4o`0000;ooooo2?l000000ooooooo0000o`000008ooooo`;o00000oooool2o`000004ooooool0
003o0000ooooo`;o00008Oooool4o`0000Gooooo0_l00005ooooo`Ko00000oooool6o`000003oooo
ool0003o000005Wooooo000Looooo`03o`000?oooooooooo04kooooo0_l00003ooooo`;o000000?o
ooooo`000?l000004oooool3o`0000cooooo0_l00002ooooo`Ko00000oooool4o`000003ooooool0
003o000000Go00002Oooool2o`0000;ooooo0ol00002ooooo`;o00001?ooool2o`0003?ooooo1?l0
0002ooooo`Ko000000Coooooo`000?l0003o00003?ooool2o`0004_ooooo000Looooo`03o`000?oo
oooooooo04oooooo0_l00002ooooo`;o000000?oooooo`000?l000004oooool3o`000003ooooool0
003o000000;o00001Oooool2o`0000Cooooo0_l000001?oooooo0000o`000?l00005ooooo`;o0000
00?oooooo`000?l000000_ooool3o`0000Wooooo0_l00003ooooo`;o0000@?ooool2o`000003oooo
ool0003o000000Gooooo0_l0000=ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0Cooo
ool2o`0000?ooooo0_l0000Aooooo`;o00000_ooool2o`0000;ooooo1?l00005ooooo`;o00001?oo
ool2o`0000?ooooo0_l000000ooooooo0000o`000008ooooo`?o00001Oooool2o`0003?ooooo1?l0
000<ooooo`;o00001?ooool2o`0006Cooooo000Looooo`03o`000?oooooooooo05Cooooo0ol0000:
ooooo`;o000000Coooooo`000?l0003ooooo0_l00009ooooo`;o00001?ooool2o`0000Wooooo0_l0
00000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l000001Oooool2o`0000gooooo0_l0
000:ooooo`;o00006?ooool4o`0000;ooooo0_l00008ooooo`;o0000J_ooool001cooooo00?o0000
ooooooooool0D_ooool2o`000004ooooool0003o0000o`0000Wooooo0_l000001?oooooo0000o`00
0?ooool2o`0000Wooooo0ol0000Hooooo`?o000000?oooooo`000?l000000_ooool2o`00013ooooo
0_l0000:ooooo`;o00007_ooool2o`0001Gooooo0_l0001Mooooo`007?ooool00ol0003ooooooooo
o`1Booooo`;o00000_ooool2o`0000Wooooo0_l00004ooooo`;o00002_ooool2o`0001Sooooo1?l0
0003ooooo`?o00001_ooool2o`0001Cooooo0_l0000Nooooo`?o00005?ooool2o`0005gooooo000L
ooooo`03o`000?oooooooooo067ooooo0_l0000Looooo`?o00003Oooool2o`0000?ooooo0_l00007
ooooo`;o00000oooool2o`0000gooooo1?l0000Nooooo`?o00004_ooool2o`0005oooooo000Loooo
o`03o`000?oooooooooo067ooooo0_l0000<ooooo`Co00003?ooool5o`00017ooooo0_l00002oooo
o`;o00001oooool2o`0000Kooooo0_l00005ooooo`;o00008Oooool2o`0000Cooooo0_l00004oooo
o`;o00001_ooool2o`0005oooooo000Looooo`03o`000?oooooooooo05Oooooo0_l0000Fooooo`Co
00003?ooool5o`0000Gooooo1?l00008ooooo`;o00000_ooool2o`0000oooooo0_l0000Vooooo`;o
00001_ooool2o`0000Cooooo0_l00005ooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0
Eoooool2o`0000cooooo0_l000001?oooooo0000o`000?l00005ooooo`;o00003oooool5o`0000?o
oooo1?l0000<ooooo`;o0000<Oooool2o`0000?ooooo1Ol000000ooooooo0000o`000002o`0000co
oooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o00001Oooool2o`0000Cooooo
2?l00009ooooo`;o00002oooool5o`0000kooooo0_l00005ooooo`;o0000;Oooool2o`0000?ooooo
1Ol000000ooooooo0000o`000002o`000003ooooool0003o000006_ooooo000Looooo`03o`000?oo
oooooooo05Sooooo0_l00005ooooo`;o00001Oooool2o`0000;ooooo0ol00009ooooo`?o00000ooo
ool2o`0000Kooooo1?l0000>ooooo`;o00001Oooool2o`00017ooooo0_l0000Hooooo`;o00001_oo
ool2o`0000?ooooo1ol0001[ooooo`007?ooool00ol0003oooooooooo`1fooooo`?o00000oooool2
o`0000Kooooo1?l00002ooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo1?l0000E
ooooo`;o00006?ooool2o`0000;ooooo0_l00002ooooo`;o00000oooool5o`0000Sooooo0_l00006
ooooo`;o0000Foooool001cooooo00?o0000ooooooooool0J?ooool2o`0001[ooooo1Ol000001?oo
oooo0000o`000?ooool4o`000003ooooool0003o000000;ooooo1Ol0000booooo`?o00004Oooool5
o`0000Kooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00009?ooool2o`00
00Gooooo0_l00007ooooo`Go00002_ooool2o`0000;ooooo1ol00004ooooo`Co0000<oooool2o`00
0003ooooool0003o000000?o00003?ooool3o`0000Sooooo0_l0001Kooooo`007?ooool2o`0004?o
oooo0_l0000Nooooo`?o00002_ooool2o`0000Oooooo1_l0000=ooooo`;o000000?oooooo`000?l0
00001_l00004ooooo`;o00001?ooool2o`0000Gooooo0_l00005ooooo`;o00008?ooool5o`0000Wo
oooo0_l0001Yooooo`007?ooool00ol0003oooooooooo`1Rooooo`?o00000_ooool2o`0000oooooo
1_l00003ooooo`;o00000_ooool2o`0000Sooooo0_l000000ooooooo0000o`000003o`0000?ooooo
0_l000001?oooooo0000o`000?ooool2o`0000Cooooo1Ol00003ooooo`;o00008?ooool2o`0000Ko
oooo0_l00004ooooo`;o0000JOooool001cooooo00?o0000ooooooooool0Ioooool2o`0000oooooo
1?l00004ooooo`?o00000_ooool2o`0000?ooooo0ol00008ooooo`;o00001_ooool2o`0000Oooooo
0_l000000ooooooo0000o`000002ooooo`;o0000:Oooool2o`0006oooooo000Looooo`03o`000?oo
oooooooo06kooooo0_l00006ooooo`;o00000oooool2o`0000?ooooo0_l00008ooooo`Co00000ooo
ool2o`0000Cooooo1?l00009ooooo`;o00001oooool2o`0002;ooooo0_l000000ooooooo0000o`00
001cooooo`007?ooool00ol0003oooooooooo`16ooooo`;o00007Oooool2o`0000Oooooo0_l00006
ooooo`;o000000?oooooo`000?l000000_l0000?ooooo`?o00000_ooool2o`0000Cooooo1?l00009
ooooo`;o0000:oooool2o`000003ooooool0003o000007?ooooo000Looooo`03o`000?oooooooooo
04Kooooo0_l0000Mooooo`;o00004_ooool2o`0000;ooooo0_l0000=ooooo`?o00002oooool2o`00
00Cooooo0_l00007ooooo`Co00005Oooool4o`0000Cooooo0ol00004ooooo`Go0000Loooool001co
oooo00?o0000ooooooooool0NOooool2o`0000;ooooo0ol0000<ooooo`;o00003?ooool2o`0000Co
oooo0_l00007ooooo`Co00005Oooool4o`0000Cooooo0ol00004ooooo`Go0000Loooool001cooooo
00?o0000ooooooooool0Ioooool2o`000003ooooool0003o000000[ooooo0_l000000ooooooo0000
o`000003ooooo`;o00005_ooool2o`0000Kooooo0_l0002Yooooo`007?ooool00ol0003ooooooooo
o`1Wooooo`;o000000?oooooo`000?l000002_ooool2o`000003ooooool0003o000000Sooooo0_l0
0005ooooo`;o00002_ooool2o`0000Kooooo1?l0000]ooooo`;o0000N?ooool001cooooo00?o0000
ooooooooool0J_ooool2o`0000Wooooo0_l00004ooooo`;o00001_ooool3o`0000Cooooo0_l00000
0ooooooo0000o`00000Aooooo`;o0000:_ooool2o`000003ooooool0003o000000cooooo0_l0001Z
ooooo`007?ooool00ol0003oooooooooo`1dooooo`?o00001?ooool2o`0000Oooooo0_l00007oooo
o`;o00002Oooool2o`0000;ooooo0_l000000ooooooo0000o`00000Uooooo`;o00001?ooool2o`00
00oooooo0_l0001Zooooo`007?ooool00ol0003oooooooooo`1dooooo`;o00006Oooool2o`0000Oo
oooo0ol000001?oooooo0000o`000?ooool2o`0001cooooo0_l00005ooooo`Co000000?oooooo`00
0?l00000O_ooool001cooooo00?o0000ooooooooool0Coooool2o`0002?ooooo0_l00002ooooo`;o
00001?ooool2o`0000Oooooo0_l00006ooooo`;o00002?ooool2o`0002;ooooo0_l00005ooooo`?o
00000_ooool2o`0000Kooooo0_l00005ooooo`;o0000Koooool001cooooo00?o0000ooooooooool0
Coooool2o`0002Oooooo0ol00003ooooo`?o00001_ooool2o`0000_ooooo0_l0000/ooooo`;o0000
1Oooool2o`0000Kooooo0_l00005ooooo`;o0000Koooool00006ooooooo^k^ko<S8bo`000?lb<S;o
k^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo
05;ooooo0_l0000Mooooo`;o00000_ooool6o`0000Cooooo0ol00005ooooo`;o000000?oooooo`00
0?l000002?ooool2o`0000Kooooo0_l0000Tooooo`;o00000_ooool2o`00087ooooo00001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_oo
ool00ol0003oooooooooo`1Booooo`;o00007Oooool2o`0000;ooooo1?l00007ooooo`Co00000ooo
ool2o`000003ooooool0003o000000gooooo0_l000000ooooooo0000o`000004o`0002Cooooo0_l0
0005ooooo`;o0000N_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0M_ooool4o`0000Sooooo0_l0
0002ooooo`;o000000?oooooo`000?l000003_ooool2o`0000?ooooo1?l0000Aooooo`;o00000_oo
ool2o`0000Kooooo0_l0000<ooooo`;o0000N_ooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool02Oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0001fooooo`Co00002_oo
ool4o`000004ooooool0003o0000o`0002Cooooo0_l000000ooooooo0000o`000002ooooo`;o0000
1_ooool2o`00013ooooo0_l0001fooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooooooo
o`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`24ooooo`;o0000
00Coooooo`000?l0003ooooo0ol0000Sooooo`;o00004_ooool2o`0000_ooooo0_l0001fooooo`00
00?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@
41001_ooool00ol0003oooooooooo`1Hooooo`;o0000;Oooool6o`0000Kooooo0_l0000Booooo`;o
00004Oooool3o`0000Oooooo0_l00007ooooo`;o0000N_ooool00006oooooomgMgOoV9RHoooooonH
V9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0F?ooool2
o`0002Oooooo0_l00006ooooo`;o00002?ooool2o`0000;ooooo0ol00003ooooo`;o00002?ooool2
o`00017ooooo0ol00008ooooo`;o00001_ooool2o`0007[ooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo087ooooo
0_l00007ooooo`;o00002oooool3o`0000?ooooo0ol00007ooooo`;o00001?ooool2o`0001Kooooo
0_l00006ooooo`;o0000N_ooool001cooooo00?o0000ooooooooool0R_ooool2o`0000gooooo0_l0
0003ooooo`;o00003Oooool2o`0001[ooooo0_l0001nooooo`007?ooool00ol0003oooooooooo`1l
ooooo`;o00004Oooool2o`0000Cooooo0_l00002ooooo`;o00002Oooool2o`000003ooooool0003o
000001Oooooo0_l00007ooooo`;o0000O_ooool001cooooo00?o0000ooooooooool0O?ooool2o`00
00Gooooo1?l00008ooooo`Co00000_ooool2o`0000;ooooo0_l00009ooooo`;o000000?oooooo`00
0?l000005oooool3o`0008Kooooo000Looooo`03o`000?oooooooooo08?ooooo1?l0000:ooooo`;o
00001_ooool2o`0001Oooooo0_l0000=ooooo`;o0000Q_ooool001cooooo00?o0000ooooooooool0
Q?ooool2o`0000oooooo0_l00003ooooo`;o00005_ooool2o`0000gooooo0_l00026ooooo`007?oo
ool00ol0003oooooooooo`1Qooooo`;o0000<_ooool2o`0000?ooooo0_l0000Mooooo`;o00001_oo
ool2o`0008Kooooo000Looooo`03o`000?oooooooooo067ooooo0_l0000cooooo`;o00000_ooool2
o`0001Cooooo0_l000000ooooooo0000o`000004ooooo`?o00003_ooool2o`0007gooooo000Loooo
o`03o`000?oooooooooo08[ooooo0_l0000:ooooo`;o00001?ooool2o`0000Kooooo0ol00002oooo
o`;o00001Oooool2o`000003ooooool0003o000000Gooooo0_l0000>ooooo`;o0000OOooool001co
oooo00?o0000ooooooooool0I?ooool2o`0002Cooooo0_l0000@ooooo`;o00001_ooool3o`0000;o
oooo0_l0000Eooooo`;o0000Qoooool001cooooo00?o0000ooooooooool0I?ooool2o`0005[ooooo
0_l00027ooooo`007?ooool00ol0003oooooooooo`2Booooo`;o00007oooool2o`0000_ooooo0_l0
0027ooooo`007?ooool2o`0009?ooooo0_l0000Oooooo`;o00001_ooool2o`0008cooooo000Loooo
o`03o`000?oooooooooo0;_ooooo0_l0002<ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`1`ooooo`;o0000eoooool001cooooo00?o0000oooo
ooooool0L?ooool2o`000=Oooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0NOooool2o`00
0<kooooo000Looooo`03o`000?oooooooooo07Wooooo0_l0003>ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0Ooooool2o`000<Sooooo000Looooo`;o0000P?ooool2o`000<Sooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0QOooool2o`000<;ooooo
000Looooo`03o`000?oooooooooo08Gooooo0_l00002ooooo`;o000000?oooooo`000?l000000ooo
ool2o`000;Kooooo000Looooo`03o`000?oooooooooo08Wooooo0_l000000ooooooo0000o`000003
ooooo`;o0000]_ooool001cooooo00?o0000ooooooooool0Uoooool2o`000;3ooooo000Looooo`03
o`000?oooooooooo09Oooooo0_l0002`ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`004_ooool4o`000003oa0@4?oooooooooo
00?ooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool3o`000?oooooo
B_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3o
oooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000oooooooo
ool0oooooomBooooo`004_ooool00omEEEGoIVIVo`00003ooooooeCooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo002Uooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@oooo
ooooool05_ooool01Om4A4Co0000o`000?lb<S;ogMgM00?ooooo00GoA4A4o`000?l0003o<S8bomgM
g@02ooooo`Go0000T?ooool00:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00003Ooo
ool00omgMgOo<S8booooo`05ooooo`09ogMgMolb<S;ooooooooooonHV9So8B4Qonk^k_ooooooA4A4
093ooooo002Vooooo`05o`000?ooooooooooooooool000007Oooool00ol0003oooooooooo`05oooo
o`07o`000?oooooooooooooooonHV9So8B4Qonk^kP2Aooooo`00Y_ooool01Ol0003ooooooooooooo
oooo000000Wooooo1_l0000=ooooo`03ogMgMolb<S;ooooo00Gooooo00?oMgMgoc8b<_ooool00ooo
ool00onHV9So8B4Qonk^kP2@ooooo`00Y_ooool01Ol0003oQhN7oooooonYZJWo000001Wooooo00Go
0000ob4Q8Ol0003o<S8bolc<c003ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00omgMgOo
IVIVooooo`2?ooooo`00YOooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo01Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo08kooooo
0034ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool01Ol0003o^[Zjoooo
oonHV9So410@093ooooo0034ooooo`Co00001?ooool4o`0000?ooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c02@ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(558) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.66487 .62754 Mdot
.62176 .64839 Mdot
.45366 .37306 Mdot
.40168 .61002 Mdot
.28654 .42997 Mdot
.44373 .34853 Mdot
.62893 .35607 Mdot
.61946 .32189 Mdot
.43219 .35578 Mdot
.43794 .7577 Mdot
.60124 .34273 Mdot
.35693 .57816 Mdot
.62017 .34462 Mdot
.43212 .59266 Mdot
.62733 .48548 Mdot
.42945 .52258 Mdot
.59992 .61029 Mdot
.28284 .39729 Mdot
.42881 .52182 Mdot
.45644 .36855 Mdot
.36998 .50624 Mdot
.43073 .60614 Mdot
.59916 .62245 Mdot
.43234 .59703 Mdot
.3849 .58672 Mdot
.62402 .63834 Mdot
.66258 .6363 Mdot
.38202 .61771 Mdot
.40493 .64465 Mdot
.61084 .33378 Mdot
.33312 .26195 Mdot
.77296 .69446 Mdot
.36963 .62778 Mdot
.62431 .73064 Mdot
.61623 .32055 Mdot
.63401 .23852 Mdot
.41259 .35451 Mdot
.63364 .3243 Mdot
.59385 .33192 Mdot
.59296 .32984 Mdot
.63778 .35375 Mdot
.63376 .63954 Mdot
.58098 .36519 Mdot
.49574 .36482 Mdot
.42283 .56361 Mdot
.74659 .64218 Mdot
.36057 .22114 Mdot
.38887 .62747 Mdot
.65513 .60511 Mdot
.46866 .35446 Mdot
.21821 .59811 Mdot
.65111 .34367 Mdot
.67084 .5474 Mdot
.26057 .7907 Mdot
.60884 .34093 Mdot
.39958 .62372 Mdot
.45627 .35643 Mdot
.41284 .60573 Mdot
.42041 .63621 Mdot
.60923 .71133 Mdot
.43861 .6226 Mdot
.3292 .4077 Mdot
.65227 .66125 Mdot
.39573 .37314 Mdot
.43827 .35575 Mdot
.64368 .34268 Mdot
.61531 .65812 Mdot
.63084 .34047 Mdot
.4411 .66045 Mdot
.47148 .35769 Mdot
.39474 .63089 Mdot
.60452 .33624 Mdot
.61087 .64991 Mdot
.41188 .5591 Mdot
.74867 .57267 Mdot
.55935 .38119 Mdot
.37731 .38442 Mdot
.58569 .79185 Mdot
.24268 .6882 Mdot
.42482 .26793 Mdot
.44152 .5836 Mdot
.18243 .6311 Mdot
.63074 .46428 Mdot
.63034 .65361 Mdot
.6732 .67649 Mdot
.79906 .4098 Mdot
.39174 .63711 Mdot
.38535 .45729 Mdot
.36837 .57698 Mdot
.5325 .51107 Mdot
.42799 .36008 Mdot
.6111 .63374 Mdot
.42394 .5626 Mdot
.38138 .5644 Mdot
.45647 .70662 Mdot
.4365 .65467 Mdot
.40818 .58078 Mdot
.67685 .65844 Mdot
.6002 .35941 Mdot
.37865 .67674 Mdot
.29242 .36282 Mdot
.67134 .53005 Mdot
.39725 .59696 Mdot
.4381 .32865 Mdot
.667 .64669 Mdot
.40989 .57136 Mdot
.63199 .33226 Mdot
.44068 .59909 Mdot
.66185 .35029 Mdot
.60991 .60406 Mdot
.37619 .56845 Mdot
.34075 .42756 Mdot
.58006 .53743 Mdot
.63996 .60518 Mdot
.46206 .812 Mdot
.43815 .61976 Mdot
.42765 .62259 Mdot
.63207 .65064 Mdot
.42648 .37268 Mdot
.4389 .44273 Mdot
.60029 .63041 Mdot
.59028 .33464 Mdot
.63236 .59396 Mdot
.39264 .54747 Mdot
.43055 .37307 Mdot
.66984 .51685 Mdot
.67025 .53576 Mdot
.2511 .42156 Mdot
.4097 .55754 Mdot
.61064 .55512 Mdot
.44785 .33447 Mdot
.63225 .64456 Mdot
.62605 .33724 Mdot
.43533 .64111 Mdot
.64666 .62001 Mdot
.58886 .34218 Mdot
.33057 .39442 Mdot
.28488 .43114 Mdot
.65591 .62381 Mdot
.32975 .68209 Mdot
.65553 .34574 Mdot
.58663 .33543 Mdot
.22117 .59066 Mdot
.63666 .65309 Mdot
.30129 .40673 Mdot
.58541 .35968 Mdot
.28268 .52326 Mdot
.45102 .62215 Mdot
.22273 .49021 Mdot
.14972 .55346 Mdot
.21931 .59471 Mdot
.70143 .72707 Mdot
.32276 .42944 Mdot
.58496 .36136 Mdot
.38935 .61401 Mdot
.63883 .62391 Mdot
.6442 .63093 Mdot
.39094 .55908 Mdot
.38304 .57595 Mdot
.42842 .57453 Mdot
.43713 .6367 Mdot
.54913 .18428 Mdot
.43657 .57355 Mdot
.66412 .41385 Mdot
.64256 .61415 Mdot
.39148 .57178 Mdot
.43166 .32468 Mdot
.45582 .5573 Mdot
.63127 .32394 Mdot
.41522 .63332 Mdot
.38118 .5833 Mdot
.46781 .59065 Mdot
.58176 .3616 Mdot
.77353 .52734 Mdot
.30013 .74796 Mdot
.66072 .26997 Mdot
.70076 .55698 Mdot
.45785 .33819 Mdot
.45358 .59351 Mdot
.31022 .4221 Mdot
.34752 .61113 Mdot
.42694 .63227 Mdot
.21511 .60641 Mdot
.37421 .58877 Mdot
.65084 .75867 Mdot
.3988 .68773 Mdot
.7941 .38229 Mdot
.69168 .3945 Mdot
.43367 .63378 Mdot
.39626 .74493 Mdot
.22868 .46255 Mdot
.28588 .2875 Mdot
.61854 .33391 Mdot
.42851 .32226 Mdot
.41729 .36895 Mdot
.59235 .32619 Mdot
.43892 .6744 Mdot
.44685 .76639 Mdot
.45106 .65418 Mdot
.67134 .51625 Mdot
.58449 .64726 Mdot
.30647 .42678 Mdot
.65672 .62335 Mdot
.19598 .66456 Mdot
.39219 .47345 Mdot
.46148 .28498 Mdot
.28091 .40109 Mdot
.47565 .33208 Mdot
.68341 .50418 Mdot
.29989 .41439 Mdot
.4066 .5945 Mdot
.62835 .59706 Mdot
.22598 .46368 Mdot
.45398 .5391 Mdot
.66109 .18186 Mdot
.63053 .6583 Mdot
.55488 .47947 Mdot
.61502 .33854 Mdot
.39805 .36871 Mdot
.39093 .63591 Mdot
.41944 .5904 Mdot
.65759 .65471 Mdot
.39431 .6344 Mdot
.45013 .46826 Mdot
.37811 .58803 Mdot
.40152 .33992 Mdot
.35255 .3851 Mdot
.66637 .33832 Mdot
.26429 .43642 Mdot
.60439 .64186 Mdot
.60158 .42685 Mdot
.43539 .32654 Mdot
.53734 .59531 Mdot
.61716 .32813 Mdot
.33811 .39822 Mdot
.41756 .34267 Mdot
.35261 .41786 Mdot
.43283 .55756 Mdot
.41606 .35832 Mdot
.3204 .39995 Mdot
.5356 .36521 Mdot
.40719 .58053 Mdot
.2425 .51333 Mdot
.60396 .37059 Mdot
.66198 .63129 Mdot
.43558 .62883 Mdot
.66745 .51372 Mdot
.4325 .54503 Mdot
.60419 .53805 Mdot
.6812 .49708 Mdot
.69397 .52325 Mdot
.44214 .28194 Mdot
.29601 .40165 Mdot
.72633 .59549 Mdot
.4799 .43313 Mdot
.59867 .61192 Mdot
.44397 .5649 Mdot
.80781 .51833 Mdot
.6042 .3715 Mdot
.40698 .59922 Mdot
.78571 .39189 Mdot
.58625 .36183 Mdot
.41624 .61391 Mdot
.63516 .35914 Mdot
.64336 .62656 Mdot
.55588 .41241 Mdot
.63909 .59082 Mdot
.4037 .61326 Mdot
.61376 .36417 Mdot
.42249 .32765 Mdot
.62431 .63755 Mdot
.43842 .60591 Mdot
.44294 .5806 Mdot
.67539 .51264 Mdot
.39529 .56425 Mdot
.82327 .49723 Mdot
.38741 .62464 Mdot
.47746 .33515 Mdot
.4313 .65731 Mdot
.21242 .47135 Mdot
.28166 .43148 Mdot
.60458 .65635 Mdot
.68507 .49804 Mdot
.43025 .36412 Mdot
.54244 .38247 Mdot
.2581 .41809 Mdot
.43974 .58977 Mdot
.68188 .52641 Mdot
.55636 .47353 Mdot
.63994 .33544 Mdot
.39372 .64771 Mdot
.44461 .45473 Mdot
.42307 .35156 Mdot
.67684 .50817 Mdot
.49084 .61251 Mdot
.66616 .61467 Mdot
.39698 .62199 Mdot
.41371 .3473 Mdot
.66104 .60794 Mdot
.42849 .64711 Mdot
.45575 .20074 Mdot
.66569 .52182 Mdot
.61793 .36946 Mdot
.52387 .6397 Mdot
.44385 .57358 Mdot
.41254 .36811 Mdot
.64855 .62523 Mdot
.60656 .35242 Mdot
.61643 .60447 Mdot
.23146 .43733 Mdot
.63067 .56085 Mdot
.55298 .21243 Mdot
.2935 .39012 Mdot
.64875 .80287 Mdot
.65399 .2617 Mdot
.58341 .57347 Mdot
.38028 .40442 Mdot
.74104 .29595 Mdot
.42462 .335 Mdot
.3546 .7157 Mdot
.44057 .364 Mdot
.39358 .60664 Mdot
.44116 .35086 Mdot
.83502 .47691 Mdot
.37621 .60324 Mdot
.46171 .34326 Mdot
.52681 .19996 Mdot
.37256 .58904 Mdot
.64518 .6131 Mdot
.77453 .65464 Mdot
.49534 .82221 Mdot
.31077 .63161 Mdot
.46393 .34619 Mdot
.35237 .72462 Mdot
.38445 .62557 Mdot
.45234 .53332 Mdot
.63336 .62634 Mdot
.38672 .5459 Mdot
.32143 .43305 Mdot
.34787 .42562 Mdot
.24101 .60636 Mdot
.53269 .8313 Mdot
.51639 .59481 Mdot
.63146 .63613 Mdot
.23016 .67384 Mdot
.7515 .57518 Mdot
.66617 .53435 Mdot
.60285 .32542 Mdot
.76852 .52427 Mdot
.49449 .60538 Mdot
.40119 .70232 Mdot
.48719 .46603 Mdot
.60964 .63475 Mdot
.58636 .25757 Mdot
.61115 .35594 Mdot
.36167 .7526 Mdot
.48862 .75522 Mdot
.42536 .57313 Mdot
.63744 .36946 Mdot
.37465 .66428 Mdot
.47364 .46672 Mdot
.23384 .50653 Mdot
.45558 .2395 Mdot
.40391 .59794 Mdot
.73269 .59733 Mdot
.42462 .63048 Mdot
.23217 .47004 Mdot
.40571 .60855 Mdot
.62167 .6036 Mdot
.49853 .62901 Mdot
.48877 .41408 Mdot
.37215 .77961 Mdot
.39713 .47209 Mdot
.29263 .41033 Mdot
.42946 .59178 Mdot
.41927 .58081 Mdot
.32995 .40358 Mdot
.61229 .62625 Mdot
.45343 .57575 Mdot
.36947 .21366 Mdot
.43495 .57078 Mdot
.64927 .33959 Mdot
.5386 .41251 Mdot
.64541 .77082 Mdot
.37158 .59975 Mdot
.66759 .62083 Mdot
.63923 .3396 Mdot
.59975 .33217 Mdot
.51247 .6012 Mdot
.61167 .37228 Mdot
.39027 .62047 Mdot
.54082 .41425 Mdot
.59997 .61695 Mdot
.35519 .63394 Mdot
.61317 .62138 Mdot
.20624 .62272 Mdot
.59248 .37074 Mdot
.68764 .52613 Mdot
.33813 .70927 Mdot
.62296 .3556 Mdot
.45663 .50714 Mdot
.47242 .65758 Mdot
.48092 .59356 Mdot
.58603 .57954 Mdot
.41361 .33562 Mdot
.69116 .51644 Mdot
.60639 .34437 Mdot
.43457 .57199 Mdot
.40368 .57699 Mdot
.64687 .36159 Mdot
.55431 .68302 Mdot
.33833 .25975 Mdot
.40525 .61843 Mdot
.61478 .60849 Mdot
.63227 .64325 Mdot
.45918 .61493 Mdot
.43003 .6299 Mdot
.46349 .31962 Mdot
.68296 .52672 Mdot
.69183 .50705 Mdot
.67602 .53608 Mdot
.42276 .31617 Mdot
.61467 .82207 Mdot
.58621 .33594 Mdot
.71809 .72869 Mdot
.78501 .45144 Mdot
.50532 .57953 Mdot
.4092 .35755 Mdot
.41983 .60267 Mdot
.39693 .58874 Mdot
.60881 .36335 Mdot
.50483 .8426 Mdot
.37235 .63978 Mdot
.65837 .64155 Mdot
.65028 .34864 Mdot
.3522 .59494 Mdot
.57036 .3859 Mdot
.34396 .41751 Mdot
.35468 .51667 Mdot
.63711 .37121 Mdot
.61606 .60192 Mdot
.6404 .36952 Mdot
.42214 .57793 Mdot
.48594 .6077 Mdot
.60942 .63767 Mdot
.30822 .39092 Mdot
.43031 .55961 Mdot
.41652 .6166 Mdot
.21026 .37302 Mdot
.74693 .57611 Mdot
.38501 .3205 Mdot
.38889 .59413 Mdot
.47587 .60709 Mdot
.32269 .38795 Mdot
.44809 .57438 Mdot
.40961 .64698 Mdot
.57832 .53285 Mdot
.66371 .33265 Mdot
.28646 .42184 Mdot
.35515 .75905 Mdot
.63737 .65805 Mdot
.82073 .47624 Mdot
.66911 .52751 Mdot
.66578 .35456 Mdot
.56056 .41496 Mdot
.68728 .51243 Mdot
.77558 .39468 Mdot
.66855 .27803 Mdot
.68728 .52215 Mdot
.4001 .37947 Mdot
.33729 .62286 Mdot
.41378 .6509 Mdot
.41494 .6288 Mdot
.29907 .39991 Mdot
.64795 .64583 Mdot
.67138 .41335 Mdot
.65626 .31795 Mdot
.42965 .61277 Mdot
.63377 .58467 Mdot
.79665 .39546 Mdot
.68122 .50701 Mdot
.32122 .42611 Mdot
.29199 .39879 Mdot
.42489 .62807 Mdot
.53207 .54379 Mdot
.62931 .6381 Mdot
.43831 .60592 Mdot
.45093 .61565 Mdot
.44674 .36604 Mdot
.63512 .59744 Mdot
.43978 .32274 Mdot
.68443 .49493 Mdot
.70487 .2444 Mdot
.22139 .33428 Mdot
.59478 .36511 Mdot
.62164 .26291 Mdot
.61528 .38344 Mdot
.47506 .23831 Mdot
.68475 .52638 Mdot
.43491 .60695 Mdot
.60106 .642 Mdot
.44042 .60181 Mdot
.4308 .56685 Mdot
.41846 .56975 Mdot
.51666 .59208 Mdot
.21042 .59908 Mdot
.32508 .42033 Mdot
.43096 .6635 Mdot
.46737 .31812 Mdot
.79081 .38323 Mdot
.78916 .60703 Mdot
.42562 .5873 Mdot
.42599 .62164 Mdot
.62808 .6617 Mdot
.43133 .55606 Mdot
.63113 .32939 Mdot
.63336 .65605 Mdot
.39983 .59145 Mdot
.26151 .38117 Mdot
.45812 .58654 Mdot
.62812 .25741 Mdot
.63922 .37106 Mdot
.34514 .53755 Mdot
.47907 .62027 Mdot
.6866 .52566 Mdot
.69073 .51672 Mdot
.66946 .5064 Mdot
.64649 .35462 Mdot
.44311 .36712 Mdot
.47138 .37207 Mdot
.48805 .62536 Mdot
.38755 .61386 Mdot
.48294 .60649 Mdot
.44728 .30169 Mdot
.47574 .42792 Mdot
.71914 .64558 Mdot
.40308 .68854 Mdot
.43886 .31084 Mdot
.67878 .60929 Mdot
.40407 .79854 Mdot
.64452 .65264 Mdot
.38001 .38662 Mdot
.61956 .32525 Mdot
.33165 .43056 Mdot
.24279 .64986 Mdot
.60093 .62239 Mdot
.65789 .65212 Mdot
.46037 .3395 Mdot
.58619 .4675 Mdot
.36388 .87541 Mdot
.44059 .33154 Mdot
.37329 .39876 Mdot
.63127 .62985 Mdot
.36745 .62831 Mdot
.5589 .47057 Mdot
.57848 .48762 Mdot
.45513 .35104 Mdot
.44357 .58306 Mdot
.46619 .5073 Mdot
.46416 .32033 Mdot
.39592 .65171 Mdot
.46541 .34319 Mdot
.6205 .37204 Mdot
.45129 .33186 Mdot
.59644 .59811 Mdot
.42144 .55994 Mdot
.28914 .81728 Mdot
.62705 .45956 Mdot
.44234 .61111 Mdot
.65074 .35311 Mdot
.50057 .18585 Mdot
.41576 .57893 Mdot
.3057 .4293 Mdot
.44473 .30755 Mdot
.44509 .22657 Mdot
.40777 .64386 Mdot
.44867 .3509 Mdot
.58799 .61782 Mdot
.38166 .38384 Mdot
.36962 .32572 Mdot
.6921 .51118 Mdot
.643 .62326 Mdot
.69715 .52958 Mdot
.61686 .31953 Mdot
.45693 .56968 Mdot
.45662 .603 Mdot
.63412 .60782 Mdot
.54422 .36018 Mdot
.40527 .66423 Mdot
.44118 .58352 Mdot
.46032 .31998 Mdot
.46598 .31115 Mdot
.64287 .49276 Mdot
.42689 .33008 Mdot
.47498 .60894 Mdot
.63282 .60592 Mdot
.39625 .6122 Mdot
.65037 .61922 Mdot
.44101 .56299 Mdot
.6926 .58466 Mdot
.64668 .64998 Mdot
.55153 .58303 Mdot
.39576 .56041 Mdot
.55198 .63991 Mdot
.43769 .56714 Mdot
.40646 .58756 Mdot
.44586 .30514 Mdot
.31464 .41343 Mdot
.37312 .62451 Mdot
.59344 .4202 Mdot
.3421 .39295 Mdot
.67051 .71542 Mdot
.4276 .37224 Mdot
.31901 .3914 Mdot
.25703 .5558 Mdot
.68507 .4982 Mdot
.33033 .41267 Mdot
.66383 .48982 Mdot
.59855 .36653 Mdot
.61029 .59753 Mdot
.37514 .5791 Mdot
.74262 .28852 Mdot
.33307 .26249 Mdot
.67685 .51503 Mdot
.43502 .62758 Mdot
.41699 .59986 Mdot
.66224 .60619 Mdot
.19092 .6498 Mdot
.39395 .35649 Mdot
.40208 .59665 Mdot
.60212 .63223 Mdot
.1688 .59633 Mdot
.46561 .33648 Mdot
.33317 .41896 Mdot
.62228 .37926 Mdot
.57065 .62101 Mdot
.69272 .51783 Mdot
.59219 .37089 Mdot
.39822 .32715 Mdot
.21316 .61682 Mdot
.40825 .64327 Mdot
.4134 .3393 Mdot
.2189 .59544 Mdot
.39342 .68459 Mdot
.57655 .36875 Mdot
.68567 .58139 Mdot
.61163 .6365 Mdot
.64842 .35828 Mdot
.29117 .40879 Mdot
.60339 .60752 Mdot
.61118 .62564 Mdot
.61685 .32271 Mdot
.7032 .35432 Mdot
.55859 .47876 Mdot
.64056 .32938 Mdot
.57615 .51276 Mdot
.22216 .58614 Mdot
.68032 .53049 Mdot
.32037 .42652 Mdot
.22498 .41924 Mdot
.63032 .63987 Mdot
.76942 .52448 Mdot
.21643 .60363 Mdot
.4079 .58141 Mdot
.31009 .39987 Mdot
.79464 .41752 Mdot
.66959 .33344 Mdot
.58774 .34588 Mdot
.40807 .44439 Mdot
.2967 .42159 Mdot
.45755 .61067 Mdot
.63084 .78172 Mdot
.37816 .57145 Mdot
.58978 .3664 Mdot
.47708 .47253 Mdot
.63632 .59841 Mdot
.61782 .31853 Mdot
.44182 .46642 Mdot
.39556 .59039 Mdot
.44517 .61549 Mdot
.26219 .455 Mdot
.63795 .59651 Mdot
.69289 .52148 Mdot
.44358 .59237 Mdot
.41245 .60919 Mdot
.46239 .58084 Mdot
.32332 .69947 Mdot
.55997 .55861 Mdot
.4021 .59086 Mdot
.39992 .35581 Mdot
.47633 .57928 Mdot
.43152 .63803 Mdot
.6568 .59679 Mdot
.20446 .48802 Mdot
.68393 .49439 Mdot
.41313 .62612 Mdot
.4058 .61909 Mdot
.59861 .32648 Mdot
.55781 .47602 Mdot
.57927 .49068 Mdot
.47479 .33846 Mdot
.37367 .44359 Mdot
.46022 .6475 Mdot
.64016 .61687 Mdot
.32613 .43386 Mdot
.47132 .5924 Mdot
.64747 .65289 Mdot
.45984 .65842 Mdot
.47094 .32355 Mdot
.68282 .52374 Mdot
.44931 .68505 Mdot
.32552 .40916 Mdot
.65883 .34326 Mdot
.73807 .71137 Mdot
.43553 .32017 Mdot
.38289 .60136 Mdot
.49394 .3467 Mdot
.43131 .34039 Mdot
.67401 .5163 Mdot
.46718 .55227 Mdot
.64134 .63098 Mdot
.6287 .59913 Mdot
.21883 .55267 Mdot
.41299 .3245 Mdot
.16597 .45075 Mdot
.61835 .37245 Mdot
.3941 .64589 Mdot
.78151 .58802 Mdot
.63692 .59995 Mdot
.24115 .44194 Mdot
.3186 .39091 Mdot
.58783 .34624 Mdot
.6953 .50151 Mdot
.65156 .64711 Mdot
.64852 .6058 Mdot
.42493 .56344 Mdot
.42601 .59722 Mdot
.37546 .4178 Mdot
.22603 .47699 Mdot
.6348 .35899 Mdot
.33508 .42156 Mdot
.47421 .34631 Mdot
.39209 .59691 Mdot
.61873 .64872 Mdot
.63048 .77539 Mdot
.44571 .57624 Mdot
.4704 .32452 Mdot
.61634 .6421 Mdot
.33821 .4112 Mdot
.32417 .39527 Mdot
.40785 .5831 Mdot
.62165 .76017 Mdot
.626 .35406 Mdot
.64092 .60811 Mdot
.66523 .67475 Mdot
.4271 .66098 Mdot
.42685 .5913 Mdot
.35766 .61715 Mdot
.57633 .34991 Mdot
.43965 .68913 Mdot
.31764 .38608 Mdot
.6469 .63871 Mdot
.44314 .60387 Mdot
.32962 .40802 Mdot
.40932 .70491 Mdot
.68508 .51625 Mdot
.46431 .33776 Mdot
.31065 .43042 Mdot
.3116 .40529 Mdot
.3435 .39595 Mdot
.76659 .52759 Mdot
.66846 .64517 Mdot
.33656 .75928 Mdot
.42944 .56388 Mdot
.22343 .58261 Mdot
.42412 .5516 Mdot
.63372 .36498 Mdot
.42631 .32197 Mdot
.42896 .5687 Mdot
.42779 .56267 Mdot
.66978 .74752 Mdot
.39577 .51727 Mdot
.36125 .52059 Mdot
.6176 .59946 Mdot
.52305 .64765 Mdot
.40908 .36522 Mdot
.13747 .5347 Mdot
.81426 .60962 Mdot
.45096 .65274 Mdot
.58405 .46253 Mdot
.63232 .65547 Mdot
.58428 .34931 Mdot
.56784 .49652 Mdot
.66231 .37084 Mdot
.64284 .64503 Mdot
.39354 .60178 Mdot
.72297 .71755 Mdot
.35214 .4083 Mdot
.42772 .57612 Mdot
.62723 .33521 Mdot
.42807 .57535 Mdot
.64331 .35728 Mdot
.57415 .64148 Mdot
.59441 .48208 Mdot
.37406 .59224 Mdot
.43763 .65626 Mdot
.40336 .69593 Mdot
.42528 .59034 Mdot
.50923 .28067 Mdot
.61958 .62687 Mdot
.54441 .58656 Mdot
.46127 .61452 Mdot
.5817 .7736 Mdot
.45825 .59441 Mdot
.55203 .36184 Mdot
.45397 .60541 Mdot
.29992 .61858 Mdot
.45504 .61586 Mdot
.4538 .5957 Mdot
.61059 .35888 Mdot
.59003 .33606 Mdot
.58611 .62754 Mdot
.69032 .52758 Mdot
.79319 .3821 Mdot
.42095 .61922 Mdot
.45495 .30411 Mdot
.65359 .52026 Mdot
.31093 .40927 Mdot
.64254 .64207 Mdot
.13971 .4171 Mdot
.64061 .34685 Mdot
.39669 .37425 Mdot
.45081 .27032 Mdot
.40794 .37471 Mdot
.43857 .29958 Mdot
.54969 .62953 Mdot
.32905 .42684 Mdot
.45866 .60386 Mdot
.63025 .73824 Mdot
.74057 .59187 Mdot
.41511 .6564 Mdot
.48272 .3662 Mdot
.3606 .5509 Mdot
.21738 .58223 Mdot
.3559 .41556 Mdot
.31226 .42777 Mdot
.60701 .34909 Mdot
.44424 .37498 Mdot
.39187 .68044 Mdot
.3209 .39148 Mdot
.4311 .31973 Mdot
.67124 .54163 Mdot
.31041 .45927 Mdot
.63424 .63799 Mdot
.31967 .65309 Mdot
.76426 .61838 Mdot
.63949 .35096 Mdot
.58535 .41808 Mdot
.67729 .63116 Mdot
.61417 .67008 Mdot
.68535 .53257 Mdot
.46283 .31433 Mdot
.60011 .6078 Mdot
.42315 .56095 Mdot
.45458 .53956 Mdot
.42651 .62858 Mdot
.3081 .39537 Mdot
.44571 .62156 Mdot
.45529 .31344 Mdot
.63324 .35362 Mdot
.4258 .3587 Mdot
.6261 .35808 Mdot
.72088 .69977 Mdot
.42547 .63655 Mdot
.42833 .59438 Mdot
.5498 .4244 Mdot
.65443 .61566 Mdot
.60983 .72411 Mdot
.46447 .3144 Mdot
.45097 .36044 Mdot
.39656 .6092 Mdot
.6107 .66123 Mdot
.27789 .39756 Mdot
.56661 .46145 Mdot
.45358 .60924 Mdot
.61985 .62587 Mdot
.39762 .61793 Mdot
.47733 .22254 Mdot
.61199 .48077 Mdot
.6212 .60203 Mdot
.376 .78358 Mdot
.3995 .56122 Mdot
.37839 .52209 Mdot
.39615 .52732 Mdot
.33187 .51861 Mdot
.38489 .64429 Mdot
.62764 .65743 Mdot
.41666 .63527 Mdot
.6362 .61823 Mdot
.42882 .337 Mdot
.58177 .34261 Mdot
.63586 .62178 Mdot
.3837 .56601 Mdot
.80085 .63153 Mdot
.6372 .34322 Mdot
.43372 .58169 Mdot
.60229 .34533 Mdot
.61947 .59229 Mdot
.65782 .61278 Mdot
.65697 .48586 Mdot
.44368 .28504 Mdot
.63493 .3378 Mdot
.38802 .61694 Mdot
.76003 .54966 Mdot
.39604 .61296 Mdot
.36706 .44392 Mdot
.4509 .63109 Mdot
.427 .65813 Mdot
.66399 .7955 Mdot
.5449 .37306 Mdot
.15298 .44207 Mdot
.62869 .3019 Mdot
.77024 .536 Mdot
.61831 .67882 Mdot
.35569 .41631 Mdot
.60941 .26864 Mdot
.67682 .49992 Mdot
.40119 .35979 Mdot
.43044 .56853 Mdot
.70774 .68442 Mdot
.64627 .33645 Mdot
.31413 .41683 Mdot
.37424 .58983 Mdot
.46449 .37099 Mdot
.69572 .48188 Mdot
.58399 .35808 Mdot
.6358 .63935 Mdot
.65747 .62246 Mdot
.25832 .70843 Mdot
.44164 .60908 Mdot
.42882 .60276 Mdot
.62695 .32404 Mdot
.40453 .68213 Mdot
.34669 .40271 Mdot
.52975 .20931 Mdot
.6238 .33317 Mdot
.62214 .47473 Mdot
.61339 .60082 Mdot
.41817 .60071 Mdot
.5367 .41161 Mdot
.7523 .47536 Mdot
.44018 .73055 Mdot
.29695 .40877 Mdot
.31067 .48043 Mdot
.62791 .65759 Mdot
.62393 .33609 Mdot
.24305 .58874 Mdot
.38735 .55655 Mdot
.41543 .6013 Mdot
.29269 .4771 Mdot
.56759 .46722 Mdot
.34416 .45148 Mdot
.36102 .5823 Mdot
.54248 .4645 Mdot
.39644 .60686 Mdot
.40336 .57727 Mdot
.44279 .66001 Mdot
.42588 .64393 Mdot
.62338 .62186 Mdot
.51583 .81928 Mdot
.44713 .34335 Mdot
.39332 .72971 Mdot
.40381 .43829 Mdot
.3843 .62725 Mdot
.39452 .59667 Mdot
.47119 .79663 Mdot
.63748 .54496 Mdot
.6226 .63041 Mdot
.66224 .67443 Mdot
.59003 .33125 Mdot
.39764 .51702 Mdot
.41843 .31834 Mdot
.3537 .53916 Mdot
.43131 .35016 Mdot
.6194 .62456 Mdot
.4343 .36943 Mdot
.63513 .3133 Mdot
.41355 .3393 Mdot
.41642 .32299 Mdot
.59818 .37512 Mdot
.64872 .59896 Mdot
.45326 .58927 Mdot
.60145 .37402 Mdot
.25556 .44403 Mdot
.30918 .39513 Mdot
.65568 .4895 Mdot
.36765 .62975 Mdot
.37996 .51875 Mdot
.45329 .20194 Mdot
.42009 .3638 Mdot
.59694 .52419 Mdot
.64727 .64931 Mdot
.29685 .42709 Mdot
.62728 .61954 Mdot
.28308 .69189 Mdot
.32114 .40359 Mdot
.65677 .49018 Mdot
.24272 .57521 Mdot
.59786 .40788 Mdot
.43777 .54608 Mdot
.56449 .59418 Mdot
.42887 .35008 Mdot
.64983 .34084 Mdot
.7919 .40431 Mdot
.4044 .56231 Mdot
.68002 .55064 Mdot
.63208 .67599 Mdot
.68693 .49989 Mdot
.62714 .33835 Mdot
.63054 .29379 Mdot
.43931 .61436 Mdot
.58152 .40483 Mdot
.43145 .65248 Mdot
.34143 .71191 Mdot
.37335 .43797 Mdot
.65301 .56855 Mdot
.39619 .62294 Mdot
.46825 .32596 Mdot
.39598 .61933 Mdot
.33583 .66115 Mdot
.22689 .59573 Mdot
.44833 .6489 Mdot
.59495 .57203 Mdot
.44779 .21941 Mdot
.61385 .64319 Mdot
.47227 .61807 Mdot
.67662 .52516 Mdot
.39057 .5821 Mdot
.78341 .29328 Mdot
.32724 .41307 Mdot
.38612 .33261 Mdot
.38916 .56215 Mdot
.4422 .5961 Mdot
.63941 .75626 Mdot
.55318 .61013 Mdot
.69332 .49773 Mdot
.41242 .59704 Mdot
.32017 .48807 Mdot
.60633 .35491 Mdot
.43115 .64575 Mdot
.41772 .63248 Mdot
.23302 .34485 Mdot
.60395 .35477 Mdot
.41498 .36272 Mdot
.68333 .49759 Mdot
.4729 .33859 Mdot
.34814 .43171 Mdot
.55077 .50668 Mdot
.23873 .45363 Mdot
.61324 .48288 Mdot
.29332 .42148 Mdot
.38712 .63394 Mdot
.68237 .663 Mdot
.44805 .60111 Mdot
.30606 .42447 Mdot
.61037 .334 Mdot
.62566 .62364 Mdot
.32624 .67336 Mdot
.67134 .51764 Mdot
.41116 .65767 Mdot
.35849 .4086 Mdot
.63844 .62586 Mdot
.69838 .44765 Mdot
.64198 .64958 Mdot
.61971 .35799 Mdot
.60329 .31986 Mdot
.31747 .40769 Mdot
.62474 .62002 Mdot
.46688 .3506 Mdot
.62482 .30071 Mdot
.44657 .63784 Mdot
.62038 .31003 Mdot
.59098 .63219 Mdot
.66196 .63938 Mdot
.60054 .64656 Mdot
.42082 .64098 Mdot
.57367 .46735 Mdot
.40814 .54892 Mdot
.63572 .33485 Mdot
.41502 .37329 Mdot
.22329 .49993 Mdot
.62205 .74527 Mdot
.62162 .47212 Mdot
.37499 .62928 Mdot
.44112 .62489 Mdot
.42517 .62769 Mdot
.40293 .6255 Mdot
.53389 .21157 Mdot
.42485 .63647 Mdot
.61772 .36467 Mdot
.43664 .34218 Mdot
.43779 .62319 Mdot
.67887 .52623 Mdot
.47499 .43278 Mdot
.32469 .43395 Mdot
.30686 .5842 Mdot
.80213 .57615 Mdot
.63651 .62588 Mdot
.41828 .33649 Mdot
.44228 .36947 Mdot
.33082 .39452 Mdot
.59529 .37117 Mdot
.648 .64463 Mdot
.29616 .57307 Mdot
.34678 .39451 Mdot
.4126 .62517 Mdot
.54381 .41736 Mdot
.38883 .78991 Mdot
.3745 .61329 Mdot
.4134 .5763 Mdot
.69473 .51417 Mdot
.39673 .37115 Mdot
.80322 .34427 Mdot
.69595 .37772 Mdot
.31546 .41205 Mdot
.34141 .41467 Mdot
.60865 .65256 Mdot
.39923 .65085 Mdot
.62887 .35158 Mdot
.55005 .47004 Mdot
.46004 .19122 Mdot
.81473 .44443 Mdot
.47537 .24065 Mdot
.45717 .58405 Mdot
.53232 .80389 Mdot
.46724 .60261 Mdot
.66729 .64625 Mdot
.60629 .65538 Mdot
.62701 .63385 Mdot
.61114 .35744 Mdot
.21336 .62795 Mdot
.6185 .36565 Mdot
.80381 .57814 Mdot
.6063 .63736 Mdot
.52176 .38433 Mdot
.4581 .35512 Mdot
.48425 .57487 Mdot
.32669 .42728 Mdot
.33625 .37004 Mdot
.47521 .61505 Mdot
.5293 .5468 Mdot
.40928 .35769 Mdot
.66087 .61391 Mdot
.46771 .6604 Mdot
.7866 .36737 Mdot
.58897 .46825 Mdot
.37836 .21771 Mdot
.50015 .67282 Mdot
.32872 .40347 Mdot
.41749 .75424 Mdot
.34912 .4032 Mdot
.58595 .35106 Mdot
.40606 .56043 Mdot
.40094 .55575 Mdot
.40283 .60094 Mdot
.41697 .64091 Mdot
.60612 .34347 Mdot
.46364 .61545 Mdot
.21198 .47365 Mdot
.66777 .52991 Mdot
.51514 .37903 Mdot
.33176 .39892 Mdot
.63147 .36998 Mdot
.43369 .34034 Mdot
.68759 .53203 Mdot
.26078 .43474 Mdot
.46458 .5983 Mdot
.43524 .56741 Mdot
.66984 .53695 Mdot
.42362 .6788 Mdot
.49402 .6031 Mdot
.44674 .34783 Mdot
.47979 .45537 Mdot
.28964 .40509 Mdot
.33425 .42916 Mdot
.64105 .36779 Mdot
.62705 .61937 Mdot
.30508 .39404 Mdot
.44894 .37433 Mdot
.42455 .64928 Mdot
.43767 .65695 Mdot
.59084 .63165 Mdot
.21612 .60331 Mdot
.34092 .43309 Mdot
.40682 .6917 Mdot
.65165 .62927 Mdot
.6406 .67546 Mdot
.41284 .59443 Mdot
.37535 .55225 Mdot
.66445 .64493 Mdot
.34084 .40402 Mdot
.62914 .37255 Mdot
.53597 .38912 Mdot
.62447 .36705 Mdot
.64775 .62913 Mdot
.47148 .56376 Mdot
.6333 .59516 Mdot
.39644 .56464 Mdot
.11905 .57935 Mdot
.43755 .63262 Mdot
.51671 .56624 Mdot
.36309 .4735 Mdot
.4662 .34081 Mdot
.46746 .3356 Mdot
.68148 .52474 Mdot
.64369 .65459 Mdot
.47104 .58625 Mdot
.33619 .42469 Mdot
.76891 .53827 Mdot
.65242 .57586 Mdot
.42578 .31579 Mdot
.39672 .35372 Mdot
.60994 .33525 Mdot
.45788 .60287 Mdot
.42041 .60579 Mdot
.41141 .34507 Mdot
.51031 .18975 Mdot
.6311 .61422 Mdot
.42904 .60265 Mdot
.42862 .641 Mdot
.44463 .34227 Mdot
.63785 .29736 Mdot
.65465 .67234 Mdot
.42864 .6418 Mdot
.23973 .55837 Mdot
.64365 .35341 Mdot
.38484 .61886 Mdot
.46603 .60678 Mdot
.3063 .40843 Mdot
.26362 .40907 Mdot
.22194 .5885 Mdot
.58199 .36475 Mdot
.69298 .51304 Mdot
.41539 .55466 Mdot
.46069 .34972 Mdot
.37354 .63877 Mdot
.65621 .2507 Mdot
.66772 .51994 Mdot
.43483 .61451 Mdot
.46391 .6457 Mdot
.64905 .61457 Mdot
.43707 .60808 Mdot
.68821 .58115 Mdot
.45812 .32287 Mdot
.43517 .61538 Mdot
.61752 .76024 Mdot
.61261 .3339 Mdot
.47648 .61272 Mdot
.32452 .43167 Mdot
.37344 .4574 Mdot
.75498 .67123 Mdot
.45772 .30236 Mdot
.32265 .39613 Mdot
.4472 .61993 Mdot
.47566 .33308 Mdot
.62106 .37962 Mdot
.54855 .56891 Mdot
.39257 .64085 Mdot
.62808 .36529 Mdot
.63493 .34964 Mdot
.31957 .41084 Mdot
.13648 .46192 Mdot
.46184 .64762 Mdot
.42831 .58188 Mdot
.42747 .1864 Mdot
.66724 .6032 Mdot
.43277 .57803 Mdot
.45741 .60094 Mdot
.60403 .37034 Mdot
.2716 .64737 Mdot
.4018 .49178 Mdot
.52742 .19975 Mdot
.64203 .35806 Mdot
.39759 .38285 Mdot
.4476 .31946 Mdot
.32489 .39723 Mdot
.61848 .64517 Mdot
.28801 .41126 Mdot
.45363 .33543 Mdot
.40597 .58969 Mdot
.59241 .34615 Mdot
.51258 .69512 Mdot
.6519 .35186 Mdot
.47322 .36201 Mdot
.65439 .66424 Mdot
.77653 .62442 Mdot
.53024 .15105 Mdot
.75596 .63026 Mdot
.57835 .35974 Mdot
.31063 .40929 Mdot
.68194 .39799 Mdot
.44352 .6206 Mdot
.37891 .76214 Mdot
.42843 .57813 Mdot
.43057 .70954 Mdot
.42816 .32073 Mdot
.67855 .5378 Mdot
.40516 .56232 Mdot
.31625 .48205 Mdot
.59131 .37119 Mdot
.62833 .32917 Mdot
.40835 .62814 Mdot
.62172 .35755 Mdot
.4241 .60785 Mdot
.44052 .33907 Mdot
.14017 .46293 Mdot
.45266 .60197 Mdot
.47591 .59296 Mdot
.66561 .3404 Mdot
.65562 .49069 Mdot
.44438 .3829 Mdot
.54568 .80491 Mdot
.78777 .36116 Mdot
.62356 .35325 Mdot
.49779 .55981 Mdot
.41462 .35568 Mdot
.69412 .52296 Mdot
.40071 .33297 Mdot
.42101 .58364 Mdot
.45318 .5768 Mdot
.39924 .60552 Mdot
.44078 .62411 Mdot
.39729 .76436 Mdot
.4912 .59643 Mdot
.51204 .75708 Mdot
.43269 .5665 Mdot
.51763 .5697 Mdot
.61166 .36497 Mdot
.37255 .52469 Mdot
.3371 .45256 Mdot
.45741 .58131 Mdot
.55081 .60895 Mdot
.62736 .3713 Mdot
.79311 .54706 Mdot
.60406 .34861 Mdot
.43001 .36247 Mdot
.59532 .33219 Mdot
.3953 .56346 Mdot
.63012 .64278 Mdot
.44168 .32628 Mdot
.72029 .64418 Mdot
.40387 .35849 Mdot
.44216 .61129 Mdot
.67459 .34969 Mdot
.46633 .34669 Mdot
.33424 .53865 Mdot
.62918 .64443 Mdot
.30112 .49497 Mdot
.67151 .61107 Mdot
.43677 .60153 Mdot
.43701 .59278 Mdot
.68525 .53592 Mdot
.58405 .35931 Mdot
.59819 .61804 Mdot
.20893 .38152 Mdot
.36146 .40746 Mdot
.61787 .63475 Mdot
.41075 .52789 Mdot
.58237 .45882 Mdot
.6372 .604 Mdot
.33317 .50029 Mdot
.58949 .36649 Mdot
.60957 .64781 Mdot
.41415 .54167 Mdot
.36927 .70503 Mdot
.34885 .41869 Mdot
.47465 .32668 Mdot
.54332 .44849 Mdot
.45106 .31982 Mdot
.653 .33361 Mdot
.40963 .327 Mdot
.60709 .3601 Mdot
.66603 .56137 Mdot
.4659 .47194 Mdot
.64545 .32408 Mdot
.65614 .32285 Mdot
.45519 .34274 Mdot
.40417 .6238 Mdot
.48583 .41789 Mdot
.38835 .53994 Mdot
.4814 .58519 Mdot
.63931 .35729 Mdot
.62247 .65658 Mdot
.61407 .59866 Mdot
.53981 .59647 Mdot
.65392 .61048 Mdot
.4358 .33026 Mdot
.60909 .49227 Mdot
.34596 .72282 Mdot
.60985 .33236 Mdot
.46841 .28772 Mdot
.39436 .61151 Mdot
.4601 .34322 Mdot
.42877 .33361 Mdot
.62937 .35747 Mdot
.40832 .73617 Mdot
.48091 .60594 Mdot
.66079 .60044 Mdot
.603 .63219 Mdot
.63203 .60288 Mdot
.61066 .65976 Mdot
.22433 .65183 Mdot
.64993 .34116 Mdot
.6319 .65717 Mdot
.40878 .63783 Mdot
.44377 .57217 Mdot
.68597 .50304 Mdot
.33986 .4056 Mdot
.43347 .55269 Mdot
.45948 .56173 Mdot
.41364 .5947 Mdot
.46578 .34257 Mdot
.35439 .65118 Mdot
.66895 .51717 Mdot
.40328 .33785 Mdot
.42021 .31743 Mdot
.6884 .52419 Mdot
.68237 .59379 Mdot
.82058 .40048 Mdot
.40194 .59823 Mdot
.62634 .69182 Mdot
.45846 .35012 Mdot
.53507 .52335 Mdot
.48538 .65462 Mdot
.38983 .62067 Mdot
.49775 .39211 Mdot
.43922 .33476 Mdot
.59132 .65481 Mdot
.42379 .58624 Mdot
.68051 .53315 Mdot
.33844 .42893 Mdot
.40093 .53577 Mdot
.69492 .51512 Mdot
.61834 .62225 Mdot
.41003 .24026 Mdot
.64527 .58931 Mdot
.46738 .34668 Mdot
.47353 .6162 Mdot
.33474 .8555 Mdot
.42756 .35002 Mdot
.77641 .51134 Mdot
.45557 .46948 Mdot
.45015 .6085 Mdot
.43798 .32392 Mdot
.60238 .66347 Mdot
.64342 .35325 Mdot
.55082 .43179 Mdot
.61883 .64855 Mdot
.6864 .53287 Mdot
.69035 .51045 Mdot
.44613 .34371 Mdot
.60351 .61912 Mdot
.45588 .626 Mdot
.65548 .63122 Mdot
.60364 .33056 Mdot
.38193 .58225 Mdot
.79324 .38138 Mdot
.45718 .54034 Mdot
.65307 .63395 Mdot
.44366 .37682 Mdot
.31349 .38931 Mdot
.37444 .5997 Mdot
.81308 .49411 Mdot
.45659 .6069 Mdot
.60405 .34093 Mdot
.50047 .50432 Mdot
.50769 .70259 Mdot
.40562 .61142 Mdot
.39444 .60351 Mdot
.63385 .37407 Mdot
.40535 .60569 Mdot
.40934 .64975 Mdot
.57349 .3255 Mdot
.64384 .60701 Mdot
.42991 .62129 Mdot
.44315 .31732 Mdot
.58139 .68345 Mdot
.41212 .56073 Mdot
.69543 .57831 Mdot
.30416 .48699 Mdot
.48215 .48842 Mdot
.47211 .5922 Mdot
.24504 .43319 Mdot
.43454 .59023 Mdot
.39494 .63538 Mdot
.40101 .61187 Mdot
.52181 .8064 Mdot
.45575 .33827 Mdot
.4407 .31184 Mdot
.33893 .43024 Mdot
.31673 .48574 Mdot
.30664 .40139 Mdot
.62529 .37559 Mdot
.4627 .28063 Mdot
.66885 .53091 Mdot
.62996 .61869 Mdot
.41618 .56265 Mdot
.40354 .3518 Mdot
.41816 .59658 Mdot
.38909 .58526 Mdot
.44481 .3307 Mdot
.4315 .33436 Mdot
.44485 .30132 Mdot
.35146 .40132 Mdot
.62823 .62815 Mdot
.41196 .57334 Mdot
.34164 .39246 Mdot
.45636 .62058 Mdot
.59167 .44873 Mdot
.62624 .62965 Mdot
.65536 .62948 Mdot
.62736 .59251 Mdot
.43246 .56391 Mdot
.3867 .56992 Mdot
.6192 .36582 Mdot
.59138 .62755 Mdot
.62648 .3258 Mdot
.44011 .32313 Mdot
.46498 .33267 Mdot
.4211 .58294 Mdot
.41126 .69022 Mdot
.33652 .40484 Mdot
.42626 .3645 Mdot
.67279 .50237 Mdot
.33579 .43181 Mdot
.43387 .62938 Mdot
.44629 .32106 Mdot
.3235 .43324 Mdot
.45964 .70746 Mdot
.76548 .33163 Mdot
.34815 .39355 Mdot
.40882 .62893 Mdot
.64001 .75088 Mdot
.23419 .57118 Mdot
.35991 .40177 Mdot
.59963 .35244 Mdot
.45418 .58688 Mdot
.53812 .17744 Mdot
.28911 .40242 Mdot
.21785 .60291 Mdot
.44976 .32951 Mdot
.4738 .68083 Mdot
.40526 .53456 Mdot
.36099 .74822 Mdot
.28772 .40169 Mdot
.64901 .63817 Mdot
.59968 .63764 Mdot
.41018 .62258 Mdot
.36097 .42927 Mdot
.65201 .33611 Mdot
.44227 .36961 Mdot
.41627 .32507 Mdot
.60731 .61035 Mdot
.61802 .47951 Mdot
.44396 .318 Mdot
.4312 .66377 Mdot
.37693 .35682 Mdot
.40253 .51722 Mdot
.25634 .70126 Mdot
.71883 .68882 Mdot
.46992 .60909 Mdot
.31959 .38809 Mdot
.60019 .3763 Mdot
.62202 .36179 Mdot
.61347 .35681 Mdot
.46502 .32896 Mdot
.56489 .48315 Mdot
.42097 .32336 Mdot
.71785 .53628 Mdot
.33094 .40877 Mdot
.293 .51813 Mdot
.4545 .56195 Mdot
.4495 .60859 Mdot
.4192 .65158 Mdot
.3991 .60305 Mdot
.43353 .59167 Mdot
.63887 .35244 Mdot
.46187 .35963 Mdot
.46619 .21194 Mdot
.61697 .60767 Mdot
.69057 .44225 Mdot
.4572 .35631 Mdot
.69026 .49995 Mdot
.31885 .42097 Mdot
.24328 .45881 Mdot
.37226 .34379 Mdot
.43795 .36819 Mdot
.38125 .62879 Mdot
.62011 .65868 Mdot
.31929 .6954 Mdot
.44123 .58337 Mdot
.42398 .36475 Mdot
.3936 .37407 Mdot
.42488 .74666 Mdot
.36463 .63105 Mdot
.37617 .38468 Mdot
.58157 .46152 Mdot
.30595 .38684 Mdot
.36992 .62196 Mdot
.54322 .52615 Mdot
.45251 .33755 Mdot
.43607 .35874 Mdot
.35594 .3989 Mdot
.34495 .58028 Mdot
.60825 .63444 Mdot
.67576 .53893 Mdot
.59971 .35835 Mdot
.44748 .59057 Mdot
.46366 .32659 Mdot
.63893 .68783 Mdot
.54873 .41438 Mdot
.61219 .34053 Mdot
.39911 .34591 Mdot
.45757 .59107 Mdot
.40819 .61671 Mdot
.32399 .40248 Mdot
.28446 .30448 Mdot
.39098 .53904 Mdot
.76997 .5355 Mdot
.58347 .49976 Mdot
.41513 .46128 Mdot
.41569 .60184 Mdot
.63225 .59712 Mdot
.68506 .52648 Mdot
.31664 .4259 Mdot
.45863 .6141 Mdot
.80791 .37315 Mdot
.62334 .58445 Mdot
.63505 .34124 Mdot
.68441 .52924 Mdot
.55632 .48301 Mdot
.45531 .60977 Mdot
.4281 .57846 Mdot
.41979 .64075 Mdot
.80908 .36922 Mdot
.43444 .31624 Mdot
.59573 .64291 Mdot
.29751 .40583 Mdot
.65754 .62877 Mdot
.44204 .30764 Mdot
.40745 .45845 Mdot
.42883 .63729 Mdot
.65391 .59681 Mdot
.64631 .64398 Mdot
.61274 .33312 Mdot
.60342 .37455 Mdot
.47536 .31859 Mdot
.44546 .62044 Mdot
.67161 .53525 Mdot
.61636 .65163 Mdot
.44939 .36952 Mdot
.32405 .40322 Mdot
.58317 .33141 Mdot
.43221 .56586 Mdot
.44934 .34253 Mdot
.45993 .62984 Mdot
.64312 .61323 Mdot
.44358 .36579 Mdot
.69399 .50315 Mdot
.34049 .4084 Mdot
.44562 .57015 Mdot
.43846 .21815 Mdot
.68393 .53207 Mdot
.37959 .56971 Mdot
.6865 .69886 Mdot
.34068 .44655 Mdot
.71995 .6581 Mdot
.42193 .32782 Mdot
.67185 .52906 Mdot
.60167 .65204 Mdot
.36683 .70731 Mdot
.43581 .35504 Mdot
.67769 .73021 Mdot
.51382 .39444 Mdot
.40488 .58747 Mdot
.61243 .63319 Mdot
.33741 .38354 Mdot
.77771 .53055 Mdot
.23364 .5359 Mdot
.42871 .61001 Mdot
.45199 .31964 Mdot
.33377 .42971 Mdot
.62521 .32681 Mdot
.69247 .57045 Mdot
.28453 .72291 Mdot
.40344 .33887 Mdot
.41753 .5655 Mdot
.61672 .65345 Mdot
.6314 .35169 Mdot
.7184 .72069 Mdot
.45533 .37258 Mdot
.43006 .32341 Mdot
.4067 .64321 Mdot
.29619 .40857 Mdot
.5459 .1836 Mdot
.44119 .31295 Mdot
.47272 .34092 Mdot
.66217 .46233 Mdot
.35209 .42038 Mdot
.41079 .63625 Mdot
.53985 .59599 Mdot
.43167 .64431 Mdot
.73884 .49891 Mdot
.67183 .53099 Mdot
.6189 .60762 Mdot
.43181 .57213 Mdot
.44959 .21903 Mdot
.4328 .34842 Mdot
.5829 .46525 Mdot
.6558 .291 Mdot
.60012 .37341 Mdot
.45888 .32451 Mdot
.4221 .59369 Mdot
.60888 .31681 Mdot
.33273 .40222 Mdot
.42889 .64166 Mdot
.39177 .56689 Mdot
.61058 .66986 Mdot
.59558 .34087 Mdot
.59197 .6876 Mdot
.60611 .32632 Mdot
.64282 .36684 Mdot
.64137 .67561 Mdot
.41117 .62351 Mdot
.4329 .36579 Mdot
.47751 .35925 Mdot
.45899 .62532 Mdot
.53466 .52197 Mdot
.60942 .63454 Mdot
.43233 .29887 Mdot
.79172 .33516 Mdot
.45214 .65359 Mdot
.67857 .4964 Mdot
.48636 .67681 Mdot
.64494 .34174 Mdot
.40714 .58983 Mdot
.63724 .61703 Mdot
.46907 .35491 Mdot
.45519 .31727 Mdot
.37115 .57211 Mdot
.63048 .3577 Mdot
.30252 .42899 Mdot
.4247 .33567 Mdot
.55364 .41354 Mdot
.43711 .61345 Mdot
.68819 .54672 Mdot
.42088 .33947 Mdot
.78015 .65938 Mdot
.45536 .21641 Mdot
.61514 .60534 Mdot
.38796 .59841 Mdot
.64673 .65916 Mdot
.29913 .40307 Mdot
.40297 .33208 Mdot
.62752 .36305 Mdot
.3202 .64909 Mdot
.23119 .33532 Mdot
.4604 .3392 Mdot
.62243 .62292 Mdot
.4187 .56833 Mdot
.46703 .66499 Mdot
.45401 .60638 Mdot
.27319 .63952 Mdot
.36964 .3957 Mdot
.64251 .31463 Mdot
.6322 .32867 Mdot
.39537 .59133 Mdot
.34651 .39972 Mdot
.48171 .33814 Mdot
.44654 .33126 Mdot
.12886 .51776 Mdot
.69537 .5136 Mdot
.37922 .39231 Mdot
.43309 .56458 Mdot
.43993 .37275 Mdot
.61849 .74436 Mdot
.62609 .32409 Mdot
.43565 .64481 Mdot
.40082 .3706 Mdot
.74107 .46598 Mdot
.57954 .4568 Mdot
.43323 .61317 Mdot
.40101 .68246 Mdot
.60186 .3504 Mdot
.68291 .39718 Mdot
.41572 .33316 Mdot
.4476 .6306 Mdot
.59541 .38686 Mdot
.64531 .50296 Mdot
.21784 .37458 Mdot
.62831 .62856 Mdot
.42432 .37953 Mdot
.61728 .37302 Mdot
.3657 .66336 Mdot
.33635 .40098 Mdot
.47525 .3506 Mdot
.40282 .36844 Mdot
.38294 .58829 Mdot
.43375 .55391 Mdot
.38132 .6673 Mdot
.61309 .62645 Mdot
.60052 .36843 Mdot
.39895 .57608 Mdot
.61151 .46243 Mdot
.40125 .59213 Mdot
.60747 .36974 Mdot
.20805 .74074 Mdot
.37041 .58004 Mdot
.44215 .57847 Mdot
.33288 .52636 Mdot
.60304 .61054 Mdot
.65048 .61251 Mdot
.60297 .4798 Mdot
.43458 .56484 Mdot
.53632 .37063 Mdot
.6296 .6259 Mdot
.61378 .63877 Mdot
.53326 .37331 Mdot
.37902 .58859 Mdot
.64282 .38358 Mdot
.62915 .35432 Mdot
.60184 .37386 Mdot
.64973 .61628 Mdot
.4825 .56932 Mdot
.61477 .37962 Mdot
.40821 .76968 Mdot
.44642 .36542 Mdot
.54362 .52646 Mdot
.65487 .63312 Mdot
.52872 .40885 Mdot
.58468 .3587 Mdot
.78984 .67908 Mdot
.3129 .67214 Mdot
.44108 .64759 Mdot
.40696 .6175 Mdot
.3085 .40536 Mdot
.51014 .60924 Mdot
.69258 .51 Mdot
.61987 .35934 Mdot
.53741 .21757 Mdot
.62685 .63447 Mdot
.45001 .58549 Mdot
.22403 .48846 Mdot
.73045 .68668 Mdot
.54813 .57964 Mdot
.61961 .6468 Mdot
.62588 .6391 Mdot
.4084 .35786 Mdot
.44636 .36669 Mdot
.42095 .63618 Mdot
.61249 .36071 Mdot
.60335 .63915 Mdot
.59161 .35801 Mdot
.45265 .33588 Mdot
.44469 .36423 Mdot
.6722 .50775 Mdot
.48885 .61583 Mdot
.45794 .32866 Mdot
.67135 .4638 Mdot
.60987 .46074 Mdot
.60112 .66082 Mdot
.51248 .15442 Mdot
.71287 .73135 Mdot
.32867 .53386 Mdot
.33962 .42849 Mdot
.65512 .53442 Mdot
.58375 .34772 Mdot
.39557 .59375 Mdot
.41972 .57735 Mdot
.68201 .50697 Mdot
.58119 .35903 Mdot
.30989 .41732 Mdot
.58359 .35581 Mdot
.32674 .42514 Mdot
.4517 .31043 Mdot
.41321 .55937 Mdot
.44531 .62499 Mdot
.63201 .33473 Mdot
.4128 .36099 Mdot
.4672 .34501 Mdot
.34744 .41599 Mdot
.25093 .46367 Mdot
.44665 .34211 Mdot
.65502 .63316 Mdot
.5745 .69178 Mdot
.68931 .50895 Mdot
.42424 .58677 Mdot
.23383 .46485 Mdot
.40476 .75235 Mdot
.40569 .58249 Mdot
.68409 .5303 Mdot
.12377 .4889 Mdot
.40848 .55961 Mdot
.17167 .60716 Mdot
.66949 .5181 Mdot
.63086 .595 Mdot
.4149 .3506 Mdot
.69294 .52302 Mdot
.35677 .65585 Mdot
.36782 .43141 Mdot
.4633 .63206 Mdot
.60914 .64023 Mdot
.65294 .59936 Mdot
.47203 .46686 Mdot
.73787 .49587 Mdot
.29394 .41032 Mdot
.32012 .41716 Mdot
.43775 .35287 Mdot
.55838 .37178 Mdot
.40743 .66203 Mdot
.31645 .41606 Mdot
.5802 .21525 Mdot
.39421 .61387 Mdot
.36026 .45576 Mdot
.49795 .39939 Mdot
.62407 .59851 Mdot
.36774 .52656 Mdot
.43445 .35148 Mdot
.62261 .6235 Mdot
.47955 .43702 Mdot
.42599 .64881 Mdot
.62604 .63152 Mdot
.59744 .36861 Mdot
.58379 .29971 Mdot
.6573 .61576 Mdot
.55063 .42875 Mdot
.62859 .34979 Mdot
.3412 .44786 Mdot
.26692 .55407 Mdot
.84 .35533 Mdot
.61778 .36092 Mdot
.41701 .35981 Mdot
.46284 .33169 Mdot
.44274 .34141 Mdot
.61594 .64688 Mdot
.42868 .33886 Mdot
.61441 .6147 Mdot
.66274 .32375 Mdot
.24784 .4426 Mdot
.32008 .40623 Mdot
.40879 .30601 Mdot
.64359 .6382 Mdot
.72421 .53461 Mdot
.44053 .16761 Mdot
.40719 .63252 Mdot
.64811 .32807 Mdot
.33082 .38759 Mdot
.60767 .52372 Mdot
.30576 .40777 Mdot
.41408 .35437 Mdot
.54511 .5274 Mdot
.4243 .60939 Mdot
.70581 .68472 Mdot
.32662 .43024 Mdot
.61913 .64768 Mdot
.38555 .63009 Mdot
.48708 .34063 Mdot
.31626 .39659 Mdot
.34271 .4253 Mdot
.43202 .59045 Mdot
.65823 .60777 Mdot
.43573 .36699 Mdot
.58722 .3389 Mdot
.3592 .39406 Mdot
.41479 .68376 Mdot
.40412 .61877 Mdot
.37071 .60852 Mdot
.58355 .47701 Mdot
.54893 .17881 Mdot
.62392 .35099 Mdot
.22967 .56972 Mdot
.46336 .33782 Mdot
.23525 .54357 Mdot
.75343 .57486 Mdot
.37276 .33621 Mdot
.67047 .52972 Mdot
.6723 .53201 Mdot
.43315 .60642 Mdot
.58525 .18763 Mdot
.5238 .56789 Mdot
.63184 .38378 Mdot
.68821 .5124 Mdot
.46703 .34629 Mdot
.59293 .60564 Mdot
.34988 .54495 Mdot
.43845 .54957 Mdot
.5821 .36391 Mdot
.44791 .33607 Mdot
.65616 .25008 Mdot
.3296 .40936 Mdot
.5968 .51695 Mdot
.43731 .62507 Mdot
.42837 .59866 Mdot
.62192 .34027 Mdot
.62044 .36467 Mdot
.70391 .53902 Mdot
.50358 .47765 Mdot
.7969 .40191 Mdot
.65862 .35337 Mdot
.6516 .24297 Mdot
.57041 .64946 Mdot
.64804 .6224 Mdot
.68181 .49655 Mdot
.62589 .37739 Mdot
.43331 .57635 Mdot
.62639 .59545 Mdot
.53786 .57504 Mdot
.59748 .66484 Mdot
.36213 .45627 Mdot
.53826 .39106 Mdot
.43808 .6264 Mdot
.61817 .65977 Mdot
.62288 .62566 Mdot
.63179 .66364 Mdot
.68828 .52263 Mdot
.41366 .60046 Mdot
.40386 .62568 Mdot
.40572 .56015 Mdot
.46712 .6639 Mdot
.43749 .60843 Mdot
.75674 .56952 Mdot
.62529 .46389 Mdot
.30017 .32931 Mdot
.42624 .56238 Mdot
.61198 .37274 Mdot
.41946 .56123 Mdot
.34364 .3989 Mdot
.43254 .5607 Mdot
.35598 .45552 Mdot
.61434 .35135 Mdot
.3382 .62272 Mdot
.47188 .29724 Mdot
.43297 .63281 Mdot
.29486 .42316 Mdot
.55449 .17875 Mdot
.22113 .51049 Mdot
.66366 .46267 Mdot
.655 .63217 Mdot
.46915 .31266 Mdot
.64369 .32737 Mdot
.4354 .36463 Mdot
.44159 .64253 Mdot
.6705 .50812 Mdot
.62854 .81544 Mdot
.51543 .41754 Mdot
.43358 .57489 Mdot
.49085 .61914 Mdot
.63442 .5989 Mdot
.43092 .34706 Mdot
.58541 .65938 Mdot
.40683 .64203 Mdot
.30487 .39516 Mdot
.32337 .39013 Mdot
.43753 .4557 Mdot
.60538 .25756 Mdot
.32697 .69499 Mdot
.62173 .34253 Mdot
.46183 .31881 Mdot
.28699 .40305 Mdot
.57186 .58811 Mdot
.6524 .33944 Mdot
.64455 .34109 Mdot
.59489 .34268 Mdot
.4456 .6093 Mdot
.67779 .50219 Mdot
.58862 .23776 Mdot
.68904 .52958 Mdot
.4154 .64547 Mdot
.40212 .36548 Mdot
.69237 .52634 Mdot
.30777 .40283 Mdot
.64326 .36509 Mdot
.46415 .347 Mdot
.43784 .59616 Mdot
.63521 .62753 Mdot
.22056 .54996 Mdot
.35147 .22469 Mdot
.40951 .31052 Mdot
.41393 .30641 Mdot
.63241 .58987 Mdot
.81827 .50977 Mdot
.61117 .3098 Mdot
.40588 .73846 Mdot
.32603 .37982 Mdot
.4575 .62802 Mdot
.15626 .48057 Mdot
.42069 .3245 Mdot
.43941 .32693 Mdot
.43304 .61911 Mdot
.45137 .37176 Mdot
.45433 .59383 Mdot
.41144 .33932 Mdot
.77326 .48515 Mdot
.43449 .54654 Mdot
.43713 .32926 Mdot
.39456 .65587 Mdot
.37335 .597 Mdot
.63862 .59818 Mdot
.47336 .3533 Mdot
.44108 .64846 Mdot
.57711 .84987 Mdot
.61862 .33168 Mdot
.68916 .52116 Mdot
.43351 .2883 Mdot
.59231 .33718 Mdot
.60822 .62293 Mdot
.41777 .5558 Mdot
.331 .40284 Mdot
.64671 .63094 Mdot
.48592 .32821 Mdot
.3164 .42982 Mdot
.61001 .4901 Mdot
.64961 .62004 Mdot
.68427 .50433 Mdot
.34065 .41101 Mdot
.46343 .63236 Mdot
.44361 .32736 Mdot
.42608 .20782 Mdot
.6899 .52685 Mdot
.42101 .60487 Mdot
.4325 .38087 Mdot
.58392 .35491 Mdot
.42061 .63189 Mdot
.46285 .32177 Mdot
.68689 .52645 Mdot
.37924 .57153 Mdot
.37748 .57156 Mdot
.33892 .57587 Mdot
.4982 .5136 Mdot
.31829 .40352 Mdot
.64802 .67214 Mdot
.41007 .6392 Mdot
.34797 .40152 Mdot
.47815 .24981 Mdot
.46421 .57698 Mdot
.65838 .64286 Mdot
.34395 .67734 Mdot
.43591 .37112 Mdot
.62932 .32616 Mdot
.4711 .36454 Mdot
.33125 .43266 Mdot
.24621 .27361 Mdot
.68608 .49915 Mdot
.48411 .63542 Mdot
.41542 .65254 Mdot
.39629 .34653 Mdot
.62088 .62837 Mdot
.8033 .42385 Mdot
.44069 .56713 Mdot
.4648 .55026 Mdot
.42816 .58734 Mdot
.44448 .22595 Mdot
.61133 .6375 Mdot
.42609 .586 Mdot
.42977 .68369 Mdot
.43877 .6573 Mdot
.289 .41806 Mdot
.29121 .5309 Mdot
.41062 .56773 Mdot
.41836 .90573 Mdot
.66804 .53537 Mdot
.44322 .33268 Mdot
.56629 .445 Mdot
.41666 .26159 Mdot
.23271 .67901 Mdot
.61223 .6207 Mdot
.54043 .6316 Mdot
.4363 .36582 Mdot
.20828 .53515 Mdot
.80948 .53372 Mdot
.37466 .60589 Mdot
.45468 .58512 Mdot
.41411 .35442 Mdot
.45151 .36795 Mdot
.66596 .52503 Mdot
.45896 .57981 Mdot
.46786 .55267 Mdot
.42744 .37706 Mdot
.4422 .59527 Mdot
.46824 .77707 Mdot
.61705 .31755 Mdot
.64932 .61363 Mdot
.62441 .32689 Mdot
.64277 .34031 Mdot
.35633 .72928 Mdot
.58251 .50111 Mdot
.61357 .36896 Mdot
.57926 .37063 Mdot
.31488 .46505 Mdot
.31173 .62854 Mdot
.28879 .41387 Mdot
.62646 .27113 Mdot
.4414 .34857 Mdot
.41261 .59889 Mdot
.6233 .65263 Mdot
.31968 .73542 Mdot
.73776 .33738 Mdot
.55932 .53464 Mdot
.40359 .63063 Mdot
.43536 .34655 Mdot
.68747 .52823 Mdot
.43784 .54743 Mdot
.2364 .56163 Mdot
.42838 .60558 Mdot
.45023 .36575 Mdot
.34803 .72656 Mdot
.68014 .5751 Mdot
.65783 .3534 Mdot
.58604 .61314 Mdot
.41649 .56101 Mdot
.6328 .61115 Mdot
.62391 .36947 Mdot
.35055 .40098 Mdot
.31201 .40998 Mdot
.43736 .63058 Mdot
.46733 .47205 Mdot
.26142 .42472 Mdot
.37495 .60554 Mdot
.38222 .58652 Mdot
.66997 .52624 Mdot
.3823 .5851 Mdot
.44518 .63121 Mdot
.4004 .57805 Mdot
.46407 .58556 Mdot
.63841 .37172 Mdot
.69792 .68023 Mdot
.43946 .5594 Mdot
.44738 .65838 Mdot
.58956 .33066 Mdot
.35527 .58221 Mdot
.60454 .35094 Mdot
.76082 .34414 Mdot
.60219 .36083 Mdot
.31361 .4093 Mdot
.45999 .37568 Mdot
.55176 .63956 Mdot
.60283 .63753 Mdot
.61565 .37438 Mdot
.33067 .42028 Mdot
.61617 .35929 Mdot
.45016 .31409 Mdot
.47001 .1707 Mdot
.67037 .64246 Mdot
.59531 .44548 Mdot
.30684 .57659 Mdot
.69112 .54495 Mdot
.42599 .37206 Mdot
.60699 .61172 Mdot
.68522 .57796 Mdot
.39559 .58725 Mdot
.32535 .40042 Mdot
.43254 .60544 Mdot
.64774 .35849 Mdot
.43798 .34663 Mdot
.67272 .33684 Mdot
.31682 .40342 Mdot
.29286 .2433 Mdot
.40428 .35207 Mdot
.46849 .65025 Mdot
.5969 .3245 Mdot
.48651 .15969 Mdot
.60301 .35696 Mdot
.24686 .44473 Mdot
.68407 .62643 Mdot
.29689 .70503 Mdot
.6333 .64024 Mdot
.68603 .55235 Mdot
.8497 .49544 Mdot
.79793 .51931 Mdot
.64308 .62395 Mdot
.47023 .29578 Mdot
.44197 .60791 Mdot
.39946 .59697 Mdot
.42904 .66609 Mdot
.58125 .63964 Mdot
.41783 .64013 Mdot
.69104 .50698 Mdot
.58772 .4858 Mdot
.55068 .19669 Mdot
.47411 .31933 Mdot
.45543 .59803 Mdot
.63994 .35596 Mdot
.64993 .35817 Mdot
.69043 .53012 Mdot
.59841 .33364 Mdot
.37472 .58948 Mdot
.64125 .63905 Mdot
.48366 .42132 Mdot
.30213 .40133 Mdot
.76137 .54153 Mdot
.30343 .38416 Mdot
.36971 .36792 Mdot
.44769 .65547 Mdot
.44404 .36479 Mdot
.18867 .39464 Mdot
.39613 .59937 Mdot
.62848 .624 Mdot
.40524 .64509 Mdot
.40323 .57279 Mdot
.41374 .56736 Mdot
.46392 .32141 Mdot
.56963 .4454 Mdot
.4421 .59195 Mdot
.6171 .37048 Mdot
.52921 .37771 Mdot
.44141 .55296 Mdot
.54774 .2278 Mdot
.36492 .45675 Mdot
.68741 .5467 Mdot
.59916 .65816 Mdot
.42277 .35866 Mdot
.62765 .63652 Mdot
.59937 .58597 Mdot
.60815 .62258 Mdot
.55847 .22177 Mdot
.37592 .71377 Mdot
.18406 .63451 Mdot
.59744 .74821 Mdot
.35498 .74033 Mdot
.65708 .59711 Mdot
.517 .25932 Mdot
.6421 .61898 Mdot
.6099 .62125 Mdot
.14223 .63105 Mdot
.64704 .65112 Mdot
.42002 .58386 Mdot
.39568 .55577 Mdot
.7533 .65268 Mdot
.3161 .46683 Mdot
.42823 .56146 Mdot
.4185 .63886 Mdot
.30344 .39303 Mdot
.37677 .68962 Mdot
.66957 .5456 Mdot
.59156 .50869 Mdot
.67504 .49393 Mdot
.43239 .59145 Mdot
.43067 .62777 Mdot
.36812 .57754 Mdot
.85474 .50389 Mdot
.29981 .7275 Mdot
.6372 .59278 Mdot
.3515 .6214 Mdot
.67266 .48195 Mdot
.40752 .65 Mdot
.41131 .64929 Mdot
.39728 .563 Mdot
.43376 .36598 Mdot
.59522 .60347 Mdot
.42268 .53855 Mdot
.73387 .59734 Mdot
.43594 .62624 Mdot
.36124 .37316 Mdot
.27276 .40743 Mdot
.42146 .59274 Mdot
.65723 .64184 Mdot
.39833 .61568 Mdot
.63518 .66074 Mdot
.64719 .61287 Mdot
.48942 .61084 Mdot
.59449 .24328 Mdot
.59133 .60395 Mdot
.37337 .60323 Mdot
.4162 .36369 Mdot
.77382 .52615 Mdot
.42057 .60206 Mdot
.29591 .41265 Mdot
.40657 .59022 Mdot
.29662 .42547 Mdot
.38667 .57399 Mdot
.68741 .53149 Mdot
.49724 .71162 Mdot
.43734 .35751 Mdot
.35577 .39146 Mdot
.44035 .37374 Mdot
.34898 .52717 Mdot
.66621 .62784 Mdot
.6654 .54591 Mdot
.29482 .73685 Mdot
.66963 .52411 Mdot
.22415 .57881 Mdot
.54277 .35605 Mdot
.63795 .33658 Mdot
.60824 .65875 Mdot
.34218 .71392 Mdot
.57127 .2551 Mdot
.42877 .30863 Mdot
.42109 .31621 Mdot
.19948 .39655 Mdot
.13894 .46525 Mdot
.44306 .58705 Mdot
.53022 .17267 Mdot
.51472 .74494 Mdot
.41137 .66663 Mdot
.36314 .57797 Mdot
.4062 .37178 Mdot
.4224 .55845 Mdot
.5414 .43899 Mdot
.45566 .34184 Mdot
.32933 .41671 Mdot
.62095 .60761 Mdot
.34489 .41395 Mdot
.72045 .31222 Mdot
.62786 .45129 Mdot
.45849 .33356 Mdot
.46051 .5752 Mdot
.45058 .59649 Mdot
.60023 .65306 Mdot
.68718 .72917 Mdot
.64546 .60797 Mdot
.29228 .41285 Mdot
.45021 .35221 Mdot
.34773 .74827 Mdot
.41085 .57971 Mdot
.64332 .64692 Mdot
.47746 .30234 Mdot
.40798 .61494 Mdot
.6367 .34008 Mdot
.40255 .63 Mdot
.65045 .6421 Mdot
.38274 .58394 Mdot
.63934 .63841 Mdot
.40988 .34814 Mdot
.45395 .61556 Mdot
.42892 .62914 Mdot
.22213 .58914 Mdot
.30807 .4167 Mdot
.6661 .62221 Mdot
.54409 .44185 Mdot
.4311 .64445 Mdot
.23835 .56283 Mdot
.41171 .55933 Mdot
.47128 .53545 Mdot
.37076 .56003 Mdot
.68837 .50342 Mdot
.41922 .6543 Mdot
.42143 .60267 Mdot
.64667 .7568 Mdot
.63028 .74777 Mdot
.36991 .51475 Mdot
.60586 .37536 Mdot
.65831 .63551 Mdot
.46246 .3293 Mdot
.46902 .35246 Mdot
.42405 .34328 Mdot
.30115 .46759 Mdot
.39518 .6857 Mdot
.42317 .61195 Mdot
.65146 .31877 Mdot
.32083 .41529 Mdot
.6291 .65003 Mdot
.31958 .41045 Mdot
.58645 .51202 Mdot
.30124 .42242 Mdot
.69132 .50507 Mdot
.45702 .21505 Mdot
.43397 .7701 Mdot
.30772 .42348 Mdot
.64632 .60926 Mdot
.54244 .38289 Mdot
.45578 .63175 Mdot
.71868 .46348 Mdot
.30459 .39509 Mdot
.20789 .38022 Mdot
.38614 .56507 Mdot
.55269 .43623 Mdot
.60573 .34488 Mdot
.3442 .41489 Mdot
.59852 .33729 Mdot
.39773 .61079 Mdot
.71925 .66373 Mdot
.6251 .62062 Mdot
.62198 .31875 Mdot
.42435 .65494 Mdot
.34465 .41368 Mdot
.45633 .33024 Mdot
.32097 .67243 Mdot
.57772 .35139 Mdot
.21663 .53942 Mdot
.23351 .53655 Mdot
.45247 .35021 Mdot
.39733 .78886 Mdot
.59846 .34423 Mdot
.46958 .60347 Mdot
.45605 .68906 Mdot
.39758 .62284 Mdot
.469 .34068 Mdot
.43597 .32748 Mdot
.77525 .58923 Mdot
.43847 .62769 Mdot
.40784 .55214 Mdot
.60366 .59728 Mdot
.46128 .34293 Mdot
.60683 .62513 Mdot
.59524 .63923 Mdot
.4137 .35666 Mdot
.61412 .60567 Mdot
.32809 .42992 Mdot
.5705 .50863 Mdot
.59792 .34719 Mdot
.63596 .34963 Mdot
.45905 .32964 Mdot
.46486 .31692 Mdot
.4488 .36261 Mdot
.39818 .63059 Mdot
.6015 .62245 Mdot
.38613 .6042 Mdot
.4175 .56258 Mdot
.66985 .66759 Mdot
.6048 .60293 Mdot
.39022 .61083 Mdot
.51081 .38524 Mdot
.28938 .42338 Mdot
.43607 .33083 Mdot
.59194 .36113 Mdot
.2154 .58896 Mdot
.61543 .31911 Mdot
.42687 .64422 Mdot
.74075 .46936 Mdot
.61563 .64603 Mdot
.30652 .40668 Mdot
.34726 .44013 Mdot
.31277 .40376 Mdot
.62258 .31864 Mdot
.59206 .63827 Mdot
.61014 .48598 Mdot
.44323 .62496 Mdot
.58309 .47982 Mdot
.24065 .59774 Mdot
.74991 .58314 Mdot
.6008 .36917 Mdot
.40841 .63391 Mdot
.66962 .51944 Mdot
.42774 .74863 Mdot
.42639 .61504 Mdot
.43587 .64538 Mdot
.35161 .26734 Mdot
.44878 .65699 Mdot
.61177 .66864 Mdot
.44232 .46508 Mdot
.45945 .61113 Mdot
.36165 .52131 Mdot
.12026 .54304 Mdot
.38327 .56656 Mdot
.43119 .63063 Mdot
.41418 .58567 Mdot
.39429 .59791 Mdot
.65456 .65434 Mdot
.33025 .26425 Mdot
.63467 .36293 Mdot
.56966 .50727 Mdot
.59515 .34572 Mdot
.44744 .32331 Mdot
.51941 .43512 Mdot
.64172 .6603 Mdot
.31199 .40352 Mdot
.51703 .16646 Mdot
.55027 .52161 Mdot
.4089 .3609 Mdot
.25023 .6844 Mdot
.30545 .39656 Mdot
.45917 .6261 Mdot
.339 .43055 Mdot
.40904 .37511 Mdot
.62911 .35899 Mdot
.37899 .62438 Mdot
.60902 .6427 Mdot
.65729 .6174 Mdot
.40608 .63575 Mdot
.76359 .53298 Mdot
.58843 .34199 Mdot
.31925 .35644 Mdot
.44372 .61467 Mdot
.43781 .64363 Mdot
.63621 .60313 Mdot
.43217 .34565 Mdot
.5402 .36059 Mdot
.31691 .42166 Mdot
.41231 .6591 Mdot
.39878 .61111 Mdot
.58366 .50819 Mdot
.63077 .37402 Mdot
.68255 .51776 Mdot
.44128 .62158 Mdot
.58718 .49516 Mdot
.42611 .64201 Mdot
.49938 .58532 Mdot
.42405 .36927 Mdot
.48121 .58171 Mdot
.45667 .58427 Mdot
.65723 .6923 Mdot
.60089 .3386 Mdot
.62536 .62783 Mdot
.67892 .61138 Mdot
.67952 .53396 Mdot
.62457 .33292 Mdot
.39156 .61498 Mdot
.64346 .33516 Mdot
.40378 .5798 Mdot
.43987 .59547 Mdot
.60036 .36923 Mdot
.60577 .62168 Mdot
.79325 .41013 Mdot
.70072 .67865 Mdot
.39197 .58109 Mdot
.40503 .59795 Mdot
.32259 .47014 Mdot
.34396 .77508 Mdot
.45635 .58191 Mdot
.60008 .62204 Mdot
.40886 .61782 Mdot
.63701 .35336 Mdot
.29334 .41491 Mdot
.63453 .62417 Mdot
.45763 .31345 Mdot
.41494 .33656 Mdot
.49914 .31725 Mdot
.68819 .50066 Mdot
.4601 .58405 Mdot
.64911 .67222 Mdot
.61174 .59549 Mdot
.60357 .53732 Mdot
.44274 .33191 Mdot
.29976 .42364 Mdot
.40616 .55559 Mdot
.33173 .68397 Mdot
.64456 .34983 Mdot
.42743 .90604 Mdot
.6129 .48298 Mdot
.28115 .39764 Mdot
.47715 .48568 Mdot
.67191 .51616 Mdot
.44105 .57506 Mdot
.34547 .40165 Mdot
.42207 .33172 Mdot
.39859 .60165 Mdot
.39152 .67814 Mdot
.57161 .26465 Mdot
.45493 .30904 Mdot
.63901 .32998 Mdot
.42844 .32176 Mdot
.29382 .4246 Mdot
.69198 .50732 Mdot
.65507 .60622 Mdot
.42399 .60003 Mdot
.38889 .52022 Mdot
.44044 .3398 Mdot
.68139 .53697 Mdot
.43302 .6344 Mdot
.65907 .62948 Mdot
.43122 .33515 Mdot
.43282 .58504 Mdot
.41158 .74025 Mdot
.55166 .62538 Mdot
.44561 .35024 Mdot
.39054 .64182 Mdot
.32794 .57415 Mdot
.44442 .30838 Mdot
.40003 .36607 Mdot
.41898 .63965 Mdot
.34112 .41707 Mdot
.45759 .6045 Mdot
.60669 .35857 Mdot
.56983 .44509 Mdot
.6316 .33653 Mdot
.23303 .57416 Mdot
.39573 .55345 Mdot
.54467 .5743 Mdot
.6137 .65638 Mdot
.35332 .42769 Mdot
.62296 .77623 Mdot
.44771 .63448 Mdot
.81101 .40052 Mdot
.53218 .40882 Mdot
.63476 .46191 Mdot
.76902 .32134 Mdot
.31595 .4242 Mdot
.61305 .35661 Mdot
.42914 .6335 Mdot
.58867 .31696 Mdot
.3288 .42616 Mdot
.2321 .57745 Mdot
.40803 .65236 Mdot
.61467 .64017 Mdot
.44092 .61502 Mdot
.65514 .63665 Mdot
.4074 .60554 Mdot
.3535 .66142 Mdot
.36093 .38079 Mdot
.24674 .44688 Mdot
.46291 .62098 Mdot
.52331 .16164 Mdot
.30804 .59882 Mdot
.29772 .4066 Mdot
.38922 .58037 Mdot
.67775 .51388 Mdot
.5844 .3607 Mdot
.48233 .19093 Mdot
.43991 .36551 Mdot
.60945 .36781 Mdot
.62645 .6035 Mdot
.45051 .37681 Mdot
.67663 .53652 Mdot
.47129 .68174 Mdot
.34507 .41096 Mdot
.61989 .332 Mdot
.4215 .59884 Mdot
.41626 .64848 Mdot
.44296 .22459 Mdot
.42577 .81943 Mdot
.59713 .62858 Mdot
.24707 .2967 Mdot
.64354 .67321 Mdot
.31499 .41774 Mdot
.42765 .36962 Mdot
.42957 .5731 Mdot
.42784 .62158 Mdot
.46861 .33178 Mdot
.60482 .60781 Mdot
.37677 .36132 Mdot
.30237 .71558 Mdot
.64679 .2903 Mdot
.28432 .49523 Mdot
.6359 .62148 Mdot
.28065 .49258 Mdot
.28139 .40556 Mdot
.64435 .2533 Mdot
.30066 .56304 Mdot
.63223 .33084 Mdot
.28804 .49831 Mdot
.63196 .6517 Mdot
.44334 .58468 Mdot
.68446 .50517 Mdot
.66789 .52007 Mdot
.63205 .60818 Mdot
.41617 .35628 Mdot
.33751 .40191 Mdot
.43728 .61663 Mdot
.58322 .56594 Mdot
.72723 .71719 Mdot
.46741 .32199 Mdot
.49027 .62777 Mdot
.59134 .34002 Mdot
.40593 .6119 Mdot
.31657 .38976 Mdot
.62404 .35737 Mdot
.69541 .50909 Mdot
.55098 .5133 Mdot
.40825 .55484 Mdot
.4196 .46176 Mdot
.61268 .33793 Mdot
.34968 .78125 Mdot
.42802 .6286 Mdot
.5986 .34373 Mdot
.40253 .52014 Mdot
.71392 .60258 Mdot
.49628 .40732 Mdot
.80143 .50843 Mdot
.46808 .30647 Mdot
.41746 .33206 Mdot
.53892 .85213 Mdot
.32733 .37958 Mdot
.62155 .37271 Mdot
.69332 .51487 Mdot
.2964 .542 Mdot
.60626 .33055 Mdot
.37513 .61429 Mdot
.41154 .55844 Mdot
.35037 .7309 Mdot
.33977 .52706 Mdot
.66772 .53887 Mdot
.51955 .63547 Mdot
.37777 .60022 Mdot
.47348 .61135 Mdot
.41594 .63175 Mdot
.65086 .59792 Mdot
.62111 .32338 Mdot
.63797 .16237 Mdot
.64665 .33395 Mdot
.57359 .55323 Mdot
.44103 .34853 Mdot
.47853 .34014 Mdot
.42234 .59213 Mdot
.51052 .55106 Mdot
.57398 .17685 Mdot
.41221 .57454 Mdot
.34126 .44429 Mdot
.23226 .53484 Mdot
.45495 .55837 Mdot
.62866 .58408 Mdot
.46598 .55046 Mdot
.65265 .6631 Mdot
.62605 .35726 Mdot
.3185 .42508 Mdot
.28465 .41949 Mdot
.60823 .35242 Mdot
.42156 .61587 Mdot
.28391 .42383 Mdot
.42787 .59477 Mdot
.44833 .59345 Mdot
.59218 .51446 Mdot
.33153 .3867 Mdot
.44972 .36267 Mdot
.31236 .40792 Mdot
.61109 .62465 Mdot
.15142 .66103 Mdot
.32695 .40652 Mdot
.3126 .63509 Mdot
.53776 .42703 Mdot
.28582 .49994 Mdot
.65583 .61465 Mdot
.29307 .40954 Mdot
.62701 .32504 Mdot
.62924 .47829 Mdot
.39137 .78285 Mdot
.62103 .32007 Mdot
.43036 .62006 Mdot
.63869 .66101 Mdot
.62982 .59102 Mdot
.65247 .3627 Mdot
.62805 .59735 Mdot
.47669 .63034 Mdot
.37344 .6052 Mdot
.62608 .37018 Mdot
.75352 .67214 Mdot
.62479 .32294 Mdot
.32685 .67516 Mdot
.38966 .56727 Mdot
.63141 .62423 Mdot
.48665 .54875 Mdot
.63076 .68153 Mdot
.67162 .50797 Mdot
.43193 .5598 Mdot
.31803 .39976 Mdot
.56475 .4823 Mdot
.44403 .35131 Mdot
.74416 .46801 Mdot
.65548 .63156 Mdot
.64815 .32472 Mdot
.64125 .59906 Mdot
.59729 .62234 Mdot
.62641 .3208 Mdot
.6168 .62387 Mdot
.4339 .6261 Mdot
.70138 .3648 Mdot
.65378 .63138 Mdot
.6181 .34208 Mdot
.3217 .39774 Mdot
.61068 .60843 Mdot
.38054 .35475 Mdot
.44977 .58953 Mdot
.42059 .37315 Mdot
.35732 .39556 Mdot
.63202 .66291 Mdot
.29415 .41399 Mdot
.44051 .33605 Mdot
.33845 .40059 Mdot
.62982 .30209 Mdot
.6327 .31103 Mdot
.55912 .53955 Mdot
.69858 .60107 Mdot
.62049 .65226 Mdot
.46261 .30119 Mdot
.44326 .57242 Mdot
.44812 .60822 Mdot
.3288 .43435 Mdot
.63639 .58973 Mdot
.76523 .52108 Mdot
.52345 .59017 Mdot
.75962 .54347 Mdot
.61555 .37727 Mdot
.21895 .436 Mdot
.6179 .4807 Mdot
.64739 .45697 Mdot
.36855 .62297 Mdot
.67296 .51395 Mdot
.42788 .5865 Mdot
.22089 .50845 Mdot
.28995 .40995 Mdot
.50336 .28718 Mdot
.40894 .66267 Mdot
.4567 .35201 Mdot
.40845 .59312 Mdot
.51999 .17746 Mdot
.46205 .54255 Mdot
.29713 .39934 Mdot
.59346 .32474 Mdot
.60284 .63765 Mdot
.30232 .40012 Mdot
.41159 .34228 Mdot
.32273 .49782 Mdot
.36973 .60224 Mdot
.37581 .59642 Mdot
.41439 .32291 Mdot
.60694 .62948 Mdot
.44525 .32489 Mdot
.59782 .34684 Mdot
.32399 .40829 Mdot
.39337 .59436 Mdot
.48089 .59311 Mdot
.39463 .35173 Mdot
.6499 .34304 Mdot
.47034 .32232 Mdot
.64508 .33891 Mdot
.67516 .51012 Mdot
.46326 .58978 Mdot
.39817 .34906 Mdot
.36876 .63134 Mdot
.6302 .73669 Mdot
.5773 .52307 Mdot
.58692 .79214 Mdot
.44996 .36291 Mdot
.32234 .48153 Mdot
.61164 .34934 Mdot
.61254 .33186 Mdot
.35173 .72356 Mdot
.57649 .18164 Mdot
.53605 .37075 Mdot
.45099 .18061 Mdot
.59769 .34808 Mdot
.61985 .33593 Mdot
.4209 .33518 Mdot
.61538 .6164 Mdot
.62448 .58006 Mdot
.41446 .37851 Mdot
.23396 .46548 Mdot
.6299 .65017 Mdot
.82792 .44498 Mdot
.4181 .32425 Mdot
.36491 .59761 Mdot
.66252 .52559 Mdot
.30041 .39714 Mdot
.22409 .49952 Mdot
.46542 .1782 Mdot
.42683 .57751 Mdot
.16507 .57972 Mdot
.42627 .36057 Mdot
.62899 .28756 Mdot
.65933 .26763 Mdot
.42504 .65048 Mdot
.41016 .59319 Mdot
.4183 .6201 Mdot
.35922 .40222 Mdot
.67329 .72603 Mdot
.42958 .57626 Mdot
.2529 .44604 Mdot
.43284 .54571 Mdot
.42792 .21162 Mdot
.31276 .40802 Mdot
.27159 .64537 Mdot
.47836 .31303 Mdot
.73606 .58205 Mdot
.44502 .65502 Mdot
.59947 .35009 Mdot
.56153 .30511 Mdot
.60888 .37087 Mdot
.61686 .22659 Mdot
.29756 .56559 Mdot
.65256 .59839 Mdot
.40272 .63098 Mdot
.40922 .33315 Mdot
.63458 .66174 Mdot
.53459 .35097 Mdot
.13323 .62139 Mdot
.63639 .37455 Mdot
.15674 .39035 Mdot
.62241 .32814 Mdot
.66697 .52444 Mdot
.63463 .60534 Mdot
.40245 .49612 Mdot
.58083 .48576 Mdot
.60687 .62397 Mdot
.29183 .3478 Mdot
.66179 .59014 Mdot
.29178 .48336 Mdot
.67374 .61527 Mdot
.61694 .34827 Mdot
.63304 .31194 Mdot
.36397 .64486 Mdot
.45098 .57631 Mdot
.58974 .47328 Mdot
.35858 .59513 Mdot
.43493 .56472 Mdot
.45576 .34197 Mdot
.70139 .59516 Mdot
.5629 .35317 Mdot
.63585 .61614 Mdot
.64222 .35964 Mdot
.40968 .5914 Mdot
.39144 .5814 Mdot
.43401 .65993 Mdot
.21252 .54477 Mdot
.82598 .437 Mdot
.441 .59108 Mdot
.47519 .56043 Mdot
.41046 .36084 Mdot
.43782 .22128 Mdot
.28259 .27399 Mdot
.30199 .54246 Mdot
.4347 .63497 Mdot
.30779 .41432 Mdot
.29782 .3952 Mdot
.47334 .64216 Mdot
.5467 .56445 Mdot
.38816 .33474 Mdot
.42131 .59897 Mdot
.35302 .48877 Mdot
.39516 .34185 Mdot
.68555 .53472 Mdot
.44089 .33934 Mdot
.63839 .6622 Mdot
.66898 .5259 Mdot
.45649 .31941 Mdot
.46026 .51057 Mdot
.68051 .53264 Mdot
.71776 .59923 Mdot
.29196 .41225 Mdot
.42051 .63156 Mdot
.56782 .6378 Mdot
.46685 .33072 Mdot
.61388 .33493 Mdot
.64056 .63283 Mdot
.59463 .37411 Mdot
.44449 .21583 Mdot
.22991 .49073 Mdot
.68531 .4993 Mdot
.60034 .35427 Mdot
.48732 .46382 Mdot
.30893 .41309 Mdot
.60721 .32704 Mdot
.53703 .57654 Mdot
.4359 .55318 Mdot
.64303 .21771 Mdot
.37922 .61289 Mdot
.78663 .57308 Mdot
.60679 .33731 Mdot
.68797 .49424 Mdot
.42517 .60155 Mdot
.40509 .35095 Mdot
.3568 .57527 Mdot
.42905 .59571 Mdot
.43569 .31583 Mdot
.4423 .58628 Mdot
.34147 .39216 Mdot
.64316 .66639 Mdot
.52524 .41293 Mdot
.20785 .49961 Mdot
.32899 .39607 Mdot
.64446 .54869 Mdot
.4527 .57556 Mdot
.26526 .34666 Mdot
.6148 .63637 Mdot
.43816 .64196 Mdot
.22198 .63082 Mdot
.62408 .61086 Mdot
.6274 .63761 Mdot
.38237 .59192 Mdot
.6177 .32043 Mdot
.46667 .34382 Mdot
.30894 .41114 Mdot
.55832 .36827 Mdot
.43355 .58263 Mdot
.41052 .63545 Mdot
.30506 .39719 Mdot
.62492 .33471 Mdot
.39198 .59762 Mdot
.77012 .42899 Mdot
.59908 .53752 Mdot
.64411 .34299 Mdot
.44227 .55385 Mdot
.69066 .23049 Mdot
.6182 .58004 Mdot
.16855 .59495 Mdot
.32567 .38086 Mdot
.41743 .36136 Mdot
.46812 .65669 Mdot
.3846 .88901 Mdot
.29648 .406 Mdot
.74365 .57599 Mdot
.44435 .59501 Mdot
.42465 .56868 Mdot
.66246 .61484 Mdot
.38718 .611 Mdot
.64892 .64729 Mdot
.20461 .48419 Mdot
.51422 .14583 Mdot
.63419 .5984 Mdot
.65215 .64303 Mdot
.37833 .51674 Mdot
.21474 .56315 Mdot
.62104 .60635 Mdot
.36931 .60079 Mdot
.29949 .33524 Mdot
.40863 .68354 Mdot
.2894 .39298 Mdot
.34206 .43738 Mdot
.64146 .58754 Mdot
.46732 .81642 Mdot
.40541 .51687 Mdot
.3361 .60942 Mdot
.27835 .43857 Mdot
.59996 .36264 Mdot
.40139 .56653 Mdot
.69098 .50318 Mdot
.4289 .3341 Mdot
.45715 .54427 Mdot
.42264 .628 Mdot
.64806 .65328 Mdot
.36132 .40993 Mdot
.60183 .33227 Mdot
.42119 .63771 Mdot
.39609 .38147 Mdot
.32695 .41964 Mdot
.65266 .62863 Mdot
.31592 .64412 Mdot
.28558 .40899 Mdot
.48122 .60886 Mdot
.43082 .56487 Mdot
.43006 .63802 Mdot
.40841 .67127 Mdot
.60692 .34987 Mdot
.42643 .37963 Mdot
.45713 .66233 Mdot
.59687 .49939 Mdot
.55769 .47412 Mdot
.46442 .65577 Mdot
.60083 .61884 Mdot
.60843 .37483 Mdot
.68338 .52657 Mdot
.29303 .51855 Mdot
.38603 .56671 Mdot
.81985 .41676 Mdot
.27628 .70761 Mdot
.67779 .5289 Mdot
.66968 .62319 Mdot
.30885 .40596 Mdot
.37843 .58536 Mdot
.26491 .40863 Mdot
.37589 .61444 Mdot
.44388 .68342 Mdot
.42162 .36215 Mdot
.59447 .36009 Mdot
.61146 .55729 Mdot
.42943 .3326 Mdot
.62753 .63688 Mdot
.80545 .58343 Mdot
.64675 .58269 Mdot
.59565 .63142 Mdot
.59995 .24082 Mdot
.62374 .36282 Mdot
.40484 .90138 Mdot
.34114 .77564 Mdot
.37503 .57139 Mdot
.62845 .36447 Mdot
.639 .60887 Mdot
.39395 .62993 Mdot
.62401 .65224 Mdot
.59469 .59989 Mdot
.42506 .55908 Mdot
.43706 .56738 Mdot
.24857 .45575 Mdot
.83328 .47078 Mdot
.32641 .40096 Mdot
.62862 .59534 Mdot
.37011 .7343 Mdot
.43251 .57454 Mdot
.44471 .62274 Mdot
.57445 .2803 Mdot
.29459 .40624 Mdot
.46651 .76934 Mdot
.44638 .60792 Mdot
.2144 .62181 Mdot
.4359 .56359 Mdot
.58665 .59429 Mdot
.65169 .36866 Mdot
.56073 .56536 Mdot
.46872 .34295 Mdot
.60887 .66039 Mdot
.31491 .43243 Mdot
.5954 .65277 Mdot
.37694 .72332 Mdot
.62725 .35879 Mdot
.65035 .64244 Mdot
.47579 .36284 Mdot
.62912 .34339 Mdot
.63377 .33101 Mdot
.52631 .36383 Mdot
.462 .37246 Mdot
.35474 .3988 Mdot
.58693 .36095 Mdot
.40678 .73675 Mdot
.61982 .34955 Mdot
.38496 .7301 Mdot
.45991 .60528 Mdot
.26291 .46344 Mdot
.59353 .55728 Mdot
.37439 .66042 Mdot
.61699 .32374 Mdot
.33762 .41024 Mdot
.39411 .62054 Mdot
.62364 .59803 Mdot
.33236 .40919 Mdot
.57564 .32291 Mdot
.48135 .33461 Mdot
.62796 .58947 Mdot
.61004 .31712 Mdot
.64072 .65371 Mdot
.22818 .52257 Mdot
.37168 .34263 Mdot
.49535 .39442 Mdot
.58032 .47784 Mdot
.46464 .626 Mdot
.36301 .52003 Mdot
.41737 .65133 Mdot
.42513 .62168 Mdot
.44529 .34968 Mdot
.30107 .46829 Mdot
.6098 .60903 Mdot
.75647 .69909 Mdot
.60174 .34921 Mdot
.4464 .46646 Mdot
.44718 .68494 Mdot
.40205 .58649 Mdot
.64446 .61776 Mdot
.59173 .60963 Mdot
.63005 .74835 Mdot
.46913 .33155 Mdot
.404 .68128 Mdot
.45323 .65119 Mdot
.38347 .68458 Mdot
.62776 .32806 Mdot
.78007 .41832 Mdot
.47523 .33493 Mdot
.12105 .45484 Mdot
.43596 .33016 Mdot
.31433 .28956 Mdot
.617 .62286 Mdot
.30689 .42679 Mdot
.44948 .61549 Mdot
.69853 .64963 Mdot
.65976 .64793 Mdot
.41693 .31003 Mdot
.30848 .40306 Mdot
.78888 .41394 Mdot
.61664 .36753 Mdot
.45235 .62204 Mdot
.42647 .55813 Mdot
.38578 .59703 Mdot
.39675 .63814 Mdot
.63254 .36777 Mdot
.38023 .62478 Mdot
.57627 .35669 Mdot
.4031 .75115 Mdot
.22644 .63233 Mdot
.3987 .35693 Mdot
.42448 .21907 Mdot
.59799 .62165 Mdot
.46846 .70388 Mdot
.45997 .77442 Mdot
.57832 .52419 Mdot
.6488 .31077 Mdot
.46264 .59851 Mdot
.41593 .35392 Mdot
.53674 .17034 Mdot
.39999 .35113 Mdot
.57184 .13299 Mdot
.33913 .71105 Mdot
.80619 .52383 Mdot
.38812 .62626 Mdot
.39723 .37538 Mdot
.49641 .81219 Mdot
.48139 .59107 Mdot
.2965 .43234 Mdot
.36228 .69687 Mdot
.74944 .6421 Mdot
.29661 .42156 Mdot
.44729 .58548 Mdot
.59823 .6102 Mdot
.43518 .62399 Mdot
.45395 .60541 Mdot
.41022 .57788 Mdot
.63612 .37949 Mdot
.42807 .55588 Mdot
.45728 .60504 Mdot
.40472 .80799 Mdot
.36262 .45407 Mdot
.40743 .35885 Mdot
.60042 .77721 Mdot
.32137 .41523 Mdot
.6293 .66203 Mdot
.53679 .41154 Mdot
.6081 .36272 Mdot
.62531 .74749 Mdot
.3842 .62138 Mdot
.76233 .5606 Mdot
.63728 .31488 Mdot
.33305 .42177 Mdot
.68445 .52872 Mdot
.76817 .36255 Mdot
.44637 .36862 Mdot
.66555 .5266 Mdot
.44301 .35231 Mdot
.55982 .81425 Mdot
.6539 .642 Mdot
.4664 .62371 Mdot
.59309 .34291 Mdot
.4052 .37059 Mdot
.25628 .42705 Mdot
.41362 .62287 Mdot
.45248 .36151 Mdot
.46915 .61345 Mdot
.56233 .46718 Mdot
.5461 .41966 Mdot
.41814 .37673 Mdot
.62516 .31242 Mdot
.63227 .3433 Mdot
.32133 .43157 Mdot
.61507 .66011 Mdot
.60782 .63739 Mdot
.62581 .35229 Mdot
.13567 .49193 Mdot
.43212 .58244 Mdot
.42655 .56466 Mdot
.60215 .49336 Mdot
.39897 .63722 Mdot
.34181 .48229 Mdot
.67279 .54578 Mdot
.61785 .65362 Mdot
.40614 .64253 Mdot
.39185 .5962 Mdot
.40668 .55649 Mdot
.23207 .49149 Mdot
.43813 .34038 Mdot
.37754 .59732 Mdot
.34583 .40587 Mdot
.70282 .54088 Mdot
.44583 .5751 Mdot
.47949 .59247 Mdot
.64461 .65016 Mdot
.21674 .37505 Mdot
.60858 .33788 Mdot
.46264 .34244 Mdot
.42205 .31914 Mdot
.25076 .56982 Mdot
.58428 .64234 Mdot
.66947 .54455 Mdot
.47447 .23522 Mdot
.69143 .51956 Mdot
.29848 .40875 Mdot
.51675 .38627 Mdot
.38487 .378 Mdot
.41291 .33724 Mdot
.61012 .31417 Mdot
.41427 .64419 Mdot
.4343 .5636 Mdot
.74067 .57126 Mdot
.41674 .56694 Mdot
.31432 .39941 Mdot
.59559 .32659 Mdot
.64653 .64724 Mdot
.32284 .38978 Mdot
.61304 .3304 Mdot
.60621 .62863 Mdot
.44747 .55308 Mdot
.42834 .66397 Mdot
.63716 .63599 Mdot
.65439 .62316 Mdot
.41803 .58854 Mdot
.48817 .84152 Mdot
.61268 .65025 Mdot
.64625 .62534 Mdot
.69604 .49198 Mdot
.43545 .37286 Mdot
.49609 .56279 Mdot
.62835 .36346 Mdot
.43843 .62597 Mdot
.39796 .35763 Mdot
.30312 .42132 Mdot
.63431 .64303 Mdot
.39706 .56668 Mdot
.43628 .59066 Mdot
.30659 .41298 Mdot
.30589 .38785 Mdot
.31835 .396 Mdot
.6218 .3812 Mdot
.37395 .6046 Mdot
.6183 .60609 Mdot
.61802 .36811 Mdot
.29529 .39792 Mdot
.3474 .4257 Mdot
.40013 .80113 Mdot
.42543 .57971 Mdot
.28375 .42696 Mdot
.19766 .72673 Mdot
.32308 .50328 Mdot
.66997 .53354 Mdot
.39127 .36808 Mdot
.26682 .46055 Mdot
.36233 .39596 Mdot
.61534 .37257 Mdot
.37566 .45746 Mdot
.35881 .41992 Mdot
.41176 .56665 Mdot
.40433 .6143 Mdot
.37565 .63159 Mdot
.32912 .41392 Mdot
.2311 .50983 Mdot
.61958 .59396 Mdot
.5224 .72187 Mdot
.32153 .41513 Mdot
.42193 .3765 Mdot
.39367 .35848 Mdot
.43704 .32789 Mdot
.46279 .60675 Mdot
.62739 .7619 Mdot
.38095 .73832 Mdot
.48074 .7641 Mdot
.61153 .36763 Mdot
.59327 .60662 Mdot
.67306 .33775 Mdot
.62714 .63825 Mdot
.42515 .34519 Mdot
.33161 .41794 Mdot
.66068 .60861 Mdot
.63638 .33701 Mdot
.63369 .33939 Mdot
.46954 .31869 Mdot
.44369 .33526 Mdot
.45778 .33209 Mdot
.61045 .6605 Mdot
.61667 .62355 Mdot
.39279 .58791 Mdot
.64277 .64213 Mdot
.2842 .72448 Mdot
.29274 .38952 Mdot
.42262 .31393 Mdot
.61077 .34199 Mdot
.64925 .61977 Mdot
.42294 .6316 Mdot
.36437 .2689 Mdot
.42052 .30845 Mdot
.33035 .39424 Mdot
.66752 .40801 Mdot
.45641 .13669 Mdot
.45216 .56094 Mdot
.64881 .3516 Mdot
.54539 .56925 Mdot
.41496 .61454 Mdot
.43012 .36707 Mdot
.28504 .68453 Mdot
.68784 .52958 Mdot
.45625 .59087 Mdot
.43768 .64669 Mdot
.61994 .32173 Mdot
.54024 .41443 Mdot
.41092 .5709 Mdot
.47873 .43824 Mdot
.64638 .3657 Mdot
.47525 .33405 Mdot
.56416 .85681 Mdot
.62616 .29161 Mdot
.23568 .43083 Mdot
.6743 .53351 Mdot
.4135 .56357 Mdot
.4537 .34432 Mdot
.34002 .39684 Mdot
.44914 .34129 Mdot
.66921 .61018 Mdot
.4362 .37102 Mdot
.41 .62732 Mdot
.61481 .60928 Mdot
.62251 .33276 Mdot
.42929 .46442 Mdot
.43962 .81777 Mdot
.40556 .35106 Mdot
.69284 .53061 Mdot
.4446 .57675 Mdot
.43724 .74199 Mdot
.36215 .64195 Mdot
.45576 .58234 Mdot
.60369 .37057 Mdot
.64104 .61633 Mdot
.61423 .37674 Mdot
.46773 .57386 Mdot
.49382 .6775 Mdot
.60273 .35144 Mdot
.73315 .65073 Mdot
.30374 .3974 Mdot
.23311 .46766 Mdot
.4285 .61187 Mdot
.59292 .34417 Mdot
.37272 .59825 Mdot
.6291 .59484 Mdot
.54841 .49315 Mdot
.60567 .56661 Mdot
.59037 .34116 Mdot
.79449 .57782 Mdot
.54426 .4431 Mdot
.48718 .55811 Mdot
.59715 .34373 Mdot
.6225 .77477 Mdot
.67906 .51591 Mdot
.31311 .42109 Mdot
.30367 .39007 Mdot
.34427 .42194 Mdot
.41887 .5655 Mdot
.35762 .67684 Mdot
.35279 .41635 Mdot
.6202 .3802 Mdot
.35096 .40289 Mdot
.2196 .55279 Mdot
.76488 .52981 Mdot
.32012 .39427 Mdot
.43139 .61061 Mdot
.47519 .5805 Mdot
.36036 .4561 Mdot
.47648 .35525 Mdot
.79676 .38685 Mdot
.36503 .77168 Mdot
.4283 .57288 Mdot
.38779 .71207 Mdot
.65865 .59573 Mdot
.49409 .51464 Mdot
.53361 .62439 Mdot
.54231 .3881 Mdot
.64822 .62389 Mdot
.57526 .45245 Mdot
.61622 .65553 Mdot
.47117 .59528 Mdot
.44005 .59676 Mdot
.65532 .65729 Mdot
.73093 .45971 Mdot
.69433 .74611 Mdot
.7632 .54288 Mdot
.60166 .6269 Mdot
.60107 .33818 Mdot
.64701 .36156 Mdot
.60033 .36868 Mdot
.4648 .33162 Mdot
.65754 .62884 Mdot
.378 .57772 Mdot
.41104 .34773 Mdot
.44811 .61348 Mdot
.63178 .3505 Mdot
.59889 .53944 Mdot
.64713 .64735 Mdot
.42177 .60184 Mdot
.40026 .78287 Mdot
.4354 .35186 Mdot
.31053 .41503 Mdot
.6839 .39658 Mdot
.3893 .36329 Mdot
.6442 .33039 Mdot
.58718 .60324 Mdot
.49776 .33408 Mdot
.33252 .26075 Mdot
.36735 .58507 Mdot
.36854 .58467 Mdot
.45023 .28199 Mdot
.42998 .80367 Mdot
.40543 .5847 Mdot
.41276 .33956 Mdot
.43308 .3742 Mdot
.37147 .5896 Mdot
.65416 .60746 Mdot
.35725 .41502 Mdot
.32745 .43428 Mdot
.4557 .63544 Mdot
.58552 .47167 Mdot
.25665 .45784 Mdot
.39089 .60883 Mdot
.49356 .63406 Mdot
.47959 .35704 Mdot
.67636 .53614 Mdot
.58076 .50295 Mdot
.33246 .42954 Mdot
.44566 .59589 Mdot
.71131 .72276 Mdot
.65209 .63708 Mdot
.4637 .35056 Mdot
.64124 .35158 Mdot
.28336 .42143 Mdot
.44903 .30518 Mdot
.37148 .58907 Mdot
.39185 .59723 Mdot
.5994 .33283 Mdot
.58504 .59619 Mdot
.33176 .41492 Mdot
.41029 .35193 Mdot
.30692 .42708 Mdot
.61433 .62791 Mdot
.64887 .6313 Mdot
.45706 .64812 Mdot
.36858 .65135 Mdot
.41421 .33106 Mdot
.40477 .65642 Mdot
.43569 .3247 Mdot
.44215 .22391 Mdot
.64441 .35127 Mdot
.42996 .64823 Mdot
.59507 .66215 Mdot
.63073 .35097 Mdot
.42023 .57525 Mdot
.45254 .28214 Mdot
.39686 .60164 Mdot
.40646 .37747 Mdot
.30111 .70451 Mdot
.32689 .4274 Mdot
.35459 .53687 Mdot
.41906 .50915 Mdot
.39993 .63741 Mdot
.45421 .37275 Mdot
.34463 .66004 Mdot
.60498 .35403 Mdot
.62341 .61695 Mdot
.1889 .39875 Mdot
.61909 .34434 Mdot
.43888 .61165 Mdot
.32685 .40758 Mdot
.60169 .63808 Mdot
.67819 .50321 Mdot
.60515 .47479 Mdot
.45385 .54143 Mdot
.37258 .55467 Mdot
.42621 .63877 Mdot
.45236 .17911 Mdot
.45589 .33642 Mdot
.64359 .61346 Mdot
.64561 .3603 Mdot
.6197 .36069 Mdot
.43193 .34607 Mdot
.76359 .61865 Mdot
.76029 .47918 Mdot
.24242 .77519 Mdot
.43703 .3075 Mdot
.34996 .40989 Mdot
.54851 .47918 Mdot
.43042 .32986 Mdot
.45833 .34502 Mdot
.48293 .33619 Mdot
.74717 .55521 Mdot
.60266 .62204 Mdot
.43708 .58854 Mdot
.59661 .65626 Mdot
.41483 .56339 Mdot
.24538 .41799 Mdot
.62608 .35518 Mdot
.62167 .61794 Mdot
.37896 .32051 Mdot
.40943 .51877 Mdot
.4115 .60417 Mdot
.26381 .38934 Mdot
.42554 .53757 Mdot
.29265 .50582 Mdot
.43592 .66052 Mdot
.44324 .34371 Mdot
.52004 .65006 Mdot
.49031 .61823 Mdot
.39072 .77478 Mdot
.63123 .33522 Mdot
.6804 .4986 Mdot
.45037 .55262 Mdot
.50378 .593 Mdot
.60104 .63999 Mdot
.66178 .61041 Mdot
.35337 .41621 Mdot
.69864 .37802 Mdot
.6288 .33358 Mdot
.80046 .47206 Mdot
.45194 .57628 Mdot
.56274 .36221 Mdot
.29488 .70183 Mdot
.41637 .58116 Mdot
.51704 .37691 Mdot
.62671 .74748 Mdot
.40139 .59164 Mdot
.49488 .75837 Mdot
.61253 .34471 Mdot
.21758 .62516 Mdot
.4218 .66024 Mdot
.43251 .3664 Mdot
.61661 .61689 Mdot
.62751 .58975 Mdot
.33134 .39277 Mdot
.30845 .74982 Mdot
.64288 .39269 Mdot
.61779 .62061 Mdot
.41715 .62288 Mdot
.6101 .33798 Mdot
.67611 .50248 Mdot
.42549 .52557 Mdot
.59407 .2063 Mdot
.6447 .64376 Mdot
.46278 .65959 Mdot
.76738 .55028 Mdot
.55855 .43477 Mdot
.83559 .46008 Mdot
.59203 .36347 Mdot
.33214 .43024 Mdot
.39034 .6648 Mdot
.47135 .23673 Mdot
.42069 .6624 Mdot
.24166 .4228 Mdot
.60921 .67756 Mdot
.29363 .41538 Mdot
.41746 .61186 Mdot
.40932 .57288 Mdot
.57118 .48446 Mdot
.29489 .39382 Mdot
.41058 .5707 Mdot
.43897 .66909 Mdot
.6097 .63467 Mdot
.67336 .5461 Mdot
.64279 .64875 Mdot
.43015 .62171 Mdot
.29888 .68366 Mdot
.65546 .6048 Mdot
.79518 .39728 Mdot
.3462 .38109 Mdot
.60697 .36249 Mdot
.49465 .61775 Mdot
.46061 .59614 Mdot
.78256 .31447 Mdot
.67054 .51015 Mdot
.24866 .30505 Mdot
.3974 .37404 Mdot
.71165 .7645 Mdot
.38898 .35928 Mdot
.80403 .54281 Mdot
.45493 .46202 Mdot
.38661 .6422 Mdot
.31995 .5468 Mdot
.48347 .75752 Mdot
.58831 .31921 Mdot
.45178 .72166 Mdot
.4509 .57632 Mdot
.44229 .5791 Mdot
.41823 .33658 Mdot
.77176 .5982 Mdot
.55723 .56892 Mdot
.57944 .49832 Mdot
.32959 .42225 Mdot
.62147 .6288 Mdot
.40812 .6228 Mdot
.69788 .43799 Mdot
.40479 .36471 Mdot
.3082 .64094 Mdot
.42363 .60294 Mdot
.56677 .55617 Mdot
.74577 .61641 Mdot
.6179 .33204 Mdot
.42298 .37761 Mdot
.43799 .37833 Mdot
.40894 .56087 Mdot
.6281 .36762 Mdot
.39681 .58812 Mdot
.54195 .44715 Mdot
.46416 .55195 Mdot
.29773 .41513 Mdot
.44628 .62219 Mdot
.33827 .51922 Mdot
.81829 .57648 Mdot
.48881 .57815 Mdot
.60193 .64977 Mdot
.45874 .32685 Mdot
.43479 .3379 Mdot
.60727 .63694 Mdot
.43384 .33833 Mdot
.52287 .72883 Mdot
.42137 .7162 Mdot
.297 .41013 Mdot
.45501 .78095 Mdot
.32536 .42584 Mdot
.68182 .49809 Mdot
.42256 .58159 Mdot
.52289 .23002 Mdot
.43835 .30669 Mdot
.21632 .58566 Mdot
.62127 .35256 Mdot
.66868 .51516 Mdot
.39365 .55875 Mdot
.29342 .4381 Mdot
.42039 .34846 Mdot
.60162 .28535 Mdot
.40443 .55875 Mdot
.61126 .6023 Mdot
.40269 .58595 Mdot
.39965 .54559 Mdot
.66734 .5317 Mdot
.4243 .64058 Mdot
.6128 .3305 Mdot
.6583 .63175 Mdot
.80024 .53423 Mdot
.46652 .33134 Mdot
.45309 .58871 Mdot
.41685 .62127 Mdot
.66548 .6164 Mdot
.39729 .55543 Mdot
.61817 .37161 Mdot
.46054 .91556 Mdot
.301 .4002 Mdot
.67774 .53644 Mdot
.72042 .31222 Mdot
.40318 .62614 Mdot
.39351 .61548 Mdot
.5501 .37429 Mdot
.69823 .72647 Mdot
.60139 .34499 Mdot
.43854 .54518 Mdot
.41207 .36603 Mdot
.3345 .41293 Mdot
.58387 .36019 Mdot
.37494 .60964 Mdot
.44 .57785 Mdot
.29568 .40823 Mdot
.26285 .39375 Mdot
.3789 .35257 Mdot
.60838 .36859 Mdot
.40299 .70813 Mdot
.37145 .26782 Mdot
.42918 .58844 Mdot
.67459 .4847 Mdot
.64165 .6229 Mdot
.59594 .34945 Mdot
.67841 .72203 Mdot
.47023 .60275 Mdot
.63426 .32445 Mdot
.6247 .3329 Mdot
.40456 .55329 Mdot
.58145 .63551 Mdot
.58768 .63058 Mdot
.64332 .6224 Mdot
.23051 .62896 Mdot
.32478 .24443 Mdot
.45972 .33274 Mdot
.61485 .33958 Mdot
.39786 .35292 Mdot
.35101 .42742 Mdot
.55959 .47347 Mdot
.42376 .37587 Mdot
.59785 .61767 Mdot
.40575 .33726 Mdot
.3958 .59455 Mdot
.63803 .34224 Mdot
.42178 .32138 Mdot
.3921 .62551 Mdot
.48445 .64629 Mdot
.33144 .53331 Mdot
.35933 .41157 Mdot
.57689 .45337 Mdot
.43547 .61589 Mdot
.68263 .52917 Mdot
.41941 .59186 Mdot
.62493 .37104 Mdot
.37819 .45974 Mdot
.37983 .6101 Mdot
.4358 .30745 Mdot
.34976 .2434 Mdot
.45949 .36908 Mdot
.39689 .5505 Mdot
.43098 .62021 Mdot
.42968 .58504 Mdot
.4281 .56069 Mdot
.74095 .65245 Mdot
.57407 .35016 Mdot
.4353 .68422 Mdot
.45396 .3077 Mdot
.63128 .63991 Mdot
.64357 .59545 Mdot
.54428 .37853 Mdot
.6679 .51275 Mdot
.62942 .36521 Mdot
.43105 .58433 Mdot
.59757 .28702 Mdot
.62584 .47122 Mdot
.76666 .5445 Mdot
.49718 .31149 Mdot
.41492 .3341 Mdot
.59848 .64809 Mdot
.4378 .31736 Mdot
.37323 .60609 Mdot
.42636 .66553 Mdot
.80417 .52587 Mdot
.61438 .38398 Mdot
.33138 .41632 Mdot
.44691 .61662 Mdot
.2393 .45343 Mdot
.41043 .36072 Mdot
.4745 .36318 Mdot
.39625 .58504 Mdot
.61263 .58444 Mdot
.84717 .52926 Mdot
.63631 .35904 Mdot
.4315 .74128 Mdot
.55832 .60593 Mdot
.40668 .69914 Mdot
.60947 .35436 Mdot
.49832 .39927 Mdot
.47613 .34921 Mdot
.34748 .76735 Mdot
.63829 .63775 Mdot
.32851 .41729 Mdot
.45695 .65799 Mdot
.59766 .61848 Mdot
.39925 .34447 Mdot
.62808 .65989 Mdot
.46813 .62077 Mdot
.62587 .37787 Mdot
.4334 .33323 Mdot
.58063 .33145 Mdot
.65615 .65431 Mdot
.32646 .42641 Mdot
.22432 .5835 Mdot
.42091 .74541 Mdot
.62711 .74707 Mdot
.37746 .59579 Mdot
.56077 .24182 Mdot
.3799 .57489 Mdot
.59263 .6271 Mdot
.42895 .61191 Mdot
.35885 .52316 Mdot
.47845 .33888 Mdot
.48209 .63684 Mdot
.45192 .61618 Mdot
.38065 .76407 Mdot
.41176 .59103 Mdot
.38657 .56354 Mdot
.44412 .64535 Mdot
.57611 .60215 Mdot
.48127 .63618 Mdot
.61169 .60261 Mdot
.7483 .57497 Mdot
.45702 .34735 Mdot
.33628 .43361 Mdot
.29668 .42609 Mdot
.2384 .42101 Mdot
.23612 .46349 Mdot
.76519 .60837 Mdot
.62739 .64853 Mdot
.62306 .3252 Mdot
.39576 .5898 Mdot
.60878 .78902 Mdot
.28488 .63709 Mdot
.47598 .34113 Mdot
.41093 .33267 Mdot
.43974 .66339 Mdot
.5412 .15742 Mdot
.47556 .64492 Mdot
.61105 .48458 Mdot
.41801 .56338 Mdot
.43523 .64523 Mdot
.46572 .37176 Mdot
.22656 .51793 Mdot
.37747 .59739 Mdot
.60158 .64059 Mdot
.32039 .41991 Mdot
.46265 .68651 Mdot
.27641 .63736 Mdot
.3315 .68621 Mdot
.5229 .57537 Mdot
.3836 .62517 Mdot
.41291 .35841 Mdot
.60066 .63064 Mdot
.5935 .49764 Mdot
.6139 .36958 Mdot
.59483 .47194 Mdot
.40004 .74598 Mdot
.67477 .30001 Mdot
.32756 .41929 Mdot
.43801 .29461 Mdot
.41003 .62828 Mdot
.46383 .33146 Mdot
.46803 .57997 Mdot
.6295 .46361 Mdot
.29835 .41877 Mdot
.62195 .66499 Mdot
.6018 .33744 Mdot
.60605 .60429 Mdot
.58994 .78988 Mdot
.2885 .64892 Mdot
.7111 .76568 Mdot
.4545 .36449 Mdot
.59447 .68846 Mdot
.62979 .60784 Mdot
.39364 .56301 Mdot
.23593 .76749 Mdot
.63706 .62234 Mdot
.60533 .6073 Mdot
.54002 .3926 Mdot
.2328 .57399 Mdot
.4767 .64696 Mdot
.62205 .65662 Mdot
.48059 .313 Mdot
.31456 .40428 Mdot
.3897 .61922 Mdot
.46427 .62054 Mdot
.66185 .61187 Mdot
.42295 .3486 Mdot
.23479 .44719 Mdot
.44297 .33932 Mdot
.60476 .61765 Mdot
.43689 .35749 Mdot
.79131 .40069 Mdot
.412 .37086 Mdot
.45206 .61741 Mdot
.43101 .5856 Mdot
.5472 .2035 Mdot
.64885 .63135 Mdot
.39408 .61863 Mdot
.44343 .58963 Mdot
.62406 .60536 Mdot
.38512 .37955 Mdot
.66216 .71655 Mdot
.39925 .63183 Mdot
.43461 .58559 Mdot
.29021 .41191 Mdot
.5621 .45202 Mdot
.65177 .47182 Mdot
.39148 .61951 Mdot
.3463 .41783 Mdot
.60665 .65888 Mdot
.41809 .59175 Mdot
.22529 .51562 Mdot
.39516 .34332 Mdot
.39296 .63901 Mdot
.68312 .50137 Mdot
.40855 .57975 Mdot
.8432 .53186 Mdot
.44678 .58013 Mdot
.63747 .60615 Mdot
.62144 .61176 Mdot
.38785 .34337 Mdot
.6287 .6355 Mdot
.66893 .53025 Mdot
.63139 .34589 Mdot
.79342 .59999 Mdot
.66831 .52595 Mdot
.44428 .63451 Mdot
.33977 .7754 Mdot
.46166 .62742 Mdot
.47892 .58229 Mdot
.21445 .57249 Mdot
.67268 .53183 Mdot
.63813 .61422 Mdot
.73 .45507 Mdot
.39101 .64419 Mdot
.63346 .36253 Mdot
.48097 .59116 Mdot
.39295 .63927 Mdot
.34061 .53002 Mdot
.42247 .71217 Mdot
.59107 .32977 Mdot
.49107 .5582 Mdot
.38949 .61808 Mdot
.69386 .72745 Mdot
.41539 .62867 Mdot
.32195 .3932 Mdot
.62147 .64962 Mdot
.44684 .31511 Mdot
.30145 .40731 Mdot
.40646 .62684 Mdot
.32623 .41438 Mdot
.46138 .33518 Mdot
.5873 .35427 Mdot
.44273 .62652 Mdot
.28636 .39475 Mdot
.33316 .41767 Mdot
.38909 .57712 Mdot
.61864 .61822 Mdot
.35819 .63334 Mdot
.41699 .59002 Mdot
.37426 .5766 Mdot
.60824 .63795 Mdot
.19242 .65503 Mdot
.42104 .5588 Mdot
.50238 .39451 Mdot
.65394 .66587 Mdot
.67111 .54223 Mdot
.42712 .32532 Mdot
.37636 .64257 Mdot
.62196 .36191 Mdot
.62832 .34957 Mdot
.47058 .3166 Mdot
.6634 .6281 Mdot
.43095 .3359 Mdot
.45871 .53841 Mdot
.43418 .66638 Mdot
.4542 .65921 Mdot
.1897 .3972 Mdot
.76198 .35323 Mdot
.64964 .61206 Mdot
.47131 .36004 Mdot
.58749 .47764 Mdot
.63571 .35502 Mdot
.48497 .34732 Mdot
.6179 .67409 Mdot
.65297 .64851 Mdot
.607 .64008 Mdot
.34278 .41715 Mdot
.44138 .33109 Mdot
.6447 .6781 Mdot
.58785 .62087 Mdot
.39314 .58014 Mdot
.3883 .61669 Mdot
.66299 .5939 Mdot
.37724 .42239 Mdot
.30831 .42315 Mdot
.41915 .36487 Mdot
.8521 .39752 Mdot
.63666 .35903 Mdot
.38081 .76484 Mdot
.39324 .62673 Mdot
.09605 .55665 Mdot
.47547 .644 Mdot
.41662 .62485 Mdot
.63868 .66218 Mdot
.28108 .40993 Mdot
.31668 .40658 Mdot
.6283 .60796 Mdot
.59755 .59244 Mdot
.34187 .40587 Mdot
.52967 .38233 Mdot
.79903 .62121 Mdot
.5925 .49016 Mdot
.6342 .60294 Mdot
.42904 .7506 Mdot
.58397 .35726 Mdot
.63914 .6706 Mdot
.58511 .33003 Mdot
.45866 .34659 Mdot
.40441 .3493 Mdot
.59909 .3318 Mdot
.3987 .55807 Mdot
.44766 .36587 Mdot
.47232 .55332 Mdot
.81585 .48806 Mdot
.63836 .23705 Mdot
.62414 .80023 Mdot
.45391 .57526 Mdot
.55178 .56483 Mdot
.72153 .56912 Mdot
.41918 .64044 Mdot
.48309 .54484 Mdot
.32999 .41531 Mdot
.64762 .66803 Mdot
.58114 .36026 Mdot
.80974 .39418 Mdot
.42962 .58712 Mdot
.60931 .6096 Mdot
.6387 .34786 Mdot
.78643 .39981 Mdot
.479 .4371 Mdot
.40288 .57364 Mdot
.29902 .82663 Mdot
.6551 .654 Mdot
.44726 .31526 Mdot
.43067 .78701 Mdot
.6047 .6623 Mdot
.36924 .25762 Mdot
.42215 .38062 Mdot
.62091 .52921 Mdot
.64357 .65789 Mdot
.37559 .3688 Mdot
.61656 .63124 Mdot
.33732 .39098 Mdot
.5871 .60223 Mdot
.4291 .35289 Mdot
.41531 .60443 Mdot
.43199 .35049 Mdot
.29922 .39733 Mdot
.46546 .35236 Mdot
.58101 .35964 Mdot
.67708 .5331 Mdot
.63488 .34299 Mdot
.5557 .47337 Mdot
.60582 .7115 Mdot
.59452 .36047 Mdot
.58299 .2907 Mdot
.40433 .59224 Mdot
.58761 .59359 Mdot
.45458 .31466 Mdot
.44974 .30139 Mdot
.5826 .46105 Mdot
.60678 .6223 Mdot
.42688 .35763 Mdot
.41076 .74153 Mdot
.12921 .50747 Mdot
.49314 .60441 Mdot
.34001 .23363 Mdot
.62584 .60427 Mdot
.47943 .34258 Mdot
.60388 .49132 Mdot
.6385 .59056 Mdot
.41773 .32622 Mdot
.59808 .34041 Mdot
.6162 .3616 Mdot
.41343 .55351 Mdot
.65333 .36261 Mdot
.4548 .37312 Mdot
.70776 .72439 Mdot
.61601 .64732 Mdot
.74647 .34114 Mdot
.32706 .39571 Mdot
.46044 .34155 Mdot
.48087 .6406 Mdot
.6296 .68449 Mdot
.42039 .31928 Mdot
.58583 .19099 Mdot
.82366 .3537 Mdot
.42696 .35844 Mdot
.62282 .65015 Mdot
.63065 .64319 Mdot
.48844 .58069 Mdot
.58104 .48213 Mdot
.42163 .35221 Mdot
.52146 .22872 Mdot
.25093 .4319 Mdot
.67502 .51009 Mdot
.38433 .79102 Mdot
.37709 .59786 Mdot
.38503 .62793 Mdot
.61479 .37128 Mdot
.40966 .60379 Mdot
.59326 .60104 Mdot
.46852 .65023 Mdot
.64204 .36906 Mdot
.47455 .33414 Mdot
.42507 .58375 Mdot
.33665 .40784 Mdot
.60526 .37273 Mdot
.65091 .33877 Mdot
.44637 .3555 Mdot
.61962 .65233 Mdot
.71775 .46245 Mdot
.44264 .33771 Mdot
.37576 .60929 Mdot
.67679 .52491 Mdot
.43426 .65969 Mdot
.55052 .21023 Mdot
.61567 .59502 Mdot
.43895 .31716 Mdot
.67054 .6325 Mdot
.61993 .33787 Mdot
.47232 .31123 Mdot
.41543 .63394 Mdot
.41008 .33885 Mdot
.48754 .40296 Mdot
.29362 .32297 Mdot
.58889 .60846 Mdot
.34191 .44826 Mdot
.66297 .61177 Mdot
.67542 .50904 Mdot
.26041 .54616 Mdot
.31086 .42143 Mdot
.42435 .3715 Mdot
.79439 .39021 Mdot
.45641 .31272 Mdot
.4123 .58666 Mdot
.43145 .56648 Mdot
.41954 .33472 Mdot
.33644 .42478 Mdot
.21376 .4668 Mdot
.26148 .42627 Mdot
.65447 .63545 Mdot
.47316 .47251 Mdot
.86505 .44027 Mdot
.48742 .36088 Mdot
.61927 .32477 Mdot
.51554 .60966 Mdot
.39886 .60491 Mdot
.62425 .32124 Mdot
.64259 .35837 Mdot
.29663 .39673 Mdot
.46486 .33475 Mdot
.65271 .67078 Mdot
.58659 .34502 Mdot
.65603 .68448 Mdot
.22578 .47783 Mdot
.41373 .53825 Mdot
.36649 .67647 Mdot
.45938 .61125 Mdot
.55951 .43557 Mdot
.62956 .37455 Mdot
.43639 .60854 Mdot
.42518 .66951 Mdot
.59752 .35209 Mdot
.30739 .39189 Mdot
.68499 .64938 Mdot
.43315 .36288 Mdot
.11284 .52624 Mdot
.44381 .62525 Mdot
.41548 .59863 Mdot
.61172 .36749 Mdot
.44833 .81065 Mdot
.64458 .60497 Mdot
.62339 .65385 Mdot
.45623 .33549 Mdot
.599 .44709 Mdot
.38594 .56058 Mdot
.42754 .6339 Mdot
.44095 .36694 Mdot
.68208 .52868 Mdot
.5592 .84361 Mdot
.43564 .59359 Mdot
.61 .34781 Mdot
.55969 .30805 Mdot
.62313 .37643 Mdot
.45552 .56317 Mdot
.41394 .58084 Mdot
.44047 .63327 Mdot
.44201 .56155 Mdot
.59753 .33047 Mdot
.42174 .6381 Mdot
.35741 .57529 Mdot
.64062 .61765 Mdot
.37963 .61469 Mdot
.24875 .43879 Mdot
.43237 .59377 Mdot
.33573 .40773 Mdot
.65939 .46797 Mdot
.45182 .58946 Mdot
.37993 .61668 Mdot
.25677 .41962 Mdot
.41946 .61608 Mdot
.63763 .33551 Mdot
.63731 .64048 Mdot
.61787 .33684 Mdot
.62423 .32819 Mdot
.41146 .32863 Mdot
.32448 .38733 Mdot
.40596 .66075 Mdot
.3438 .40666 Mdot
.47479 .55908 Mdot
.47089 .60514 Mdot
.56016 .46231 Mdot
.61177 .48361 Mdot
.36637 .40472 Mdot
.42115 .63428 Mdot
.45548 .341 Mdot
.43297 .3191 Mdot
.375 .45734 Mdot
.46382 .54905 Mdot
.58227 .35682 Mdot
.59311 .34414 Mdot
.34381 .483 Mdot
.38294 .47771 Mdot
.33689 .41472 Mdot
.54071 .50868 Mdot
.46542 .61068 Mdot
.44655 .58762 Mdot
.47645 .58204 Mdot
.39842 .37131 Mdot
.67794 .53443 Mdot
.4729 .33264 Mdot
.69976 .49964 Mdot
.59345 .37292 Mdot
.45432 .57606 Mdot
.65649 .25036 Mdot
.65894 .61569 Mdot
.63873 .64035 Mdot
.646 .36526 Mdot
.45877 .36983 Mdot
.46276 .54962 Mdot
.19896 .3447 Mdot
.61487 .58967 Mdot
.33376 .4331 Mdot
.43383 .62476 Mdot
.45111 .35166 Mdot
.65953 .63214 Mdot
.34117 .3883 Mdot
.45933 .58414 Mdot
.47373 .36867 Mdot
.43036 .60451 Mdot
.49779 .7716 Mdot
.63213 .61522 Mdot
.60092 .53611 Mdot
.6362 .58054 Mdot
.61957 .32298 Mdot
.60483 .339 Mdot
.41898 .57596 Mdot
.15226 .42309 Mdot
.67772 .60554 Mdot
.62275 .31866 Mdot
.35099 .39678 Mdot
.68246 .53309 Mdot
.34635 .39216 Mdot
.43383 .32559 Mdot
.32203 .42058 Mdot
.42408 .31687 Mdot
.38271 .42177 Mdot
.67738 .62724 Mdot
.30014 .40415 Mdot
.45207 .81605 Mdot
.42482 .66529 Mdot
.29247 .4005 Mdot
.44196 .66237 Mdot
.37983 .51764 Mdot
.44765 .36278 Mdot
.34031 .41761 Mdot
.3961 .5673 Mdot
.7208 .30197 Mdot
.61367 .33116 Mdot
.58126 .35668 Mdot
.41622 .66248 Mdot
.48153 .34095 Mdot
.58847 .60372 Mdot
.52776 .41768 Mdot
.67359 .54212 Mdot
.42773 .63326 Mdot
.46383 .5929 Mdot
.66551 .64172 Mdot
.59593 .62962 Mdot
.41731 .57548 Mdot
.41731 .73488 Mdot
.40956 .62942 Mdot
.6126 .3609 Mdot
.65686 .63091 Mdot
.6357 .64289 Mdot
.43547 .37653 Mdot
.66321 .62667 Mdot
.39964 .68471 Mdot
.65676 .31954 Mdot
.47118 .63499 Mdot
.62031 .3406 Mdot
.39009 .44002 Mdot
.46763 .33622 Mdot
.79415 .3829 Mdot
.66142 .63307 Mdot
.4069 .64324 Mdot
.6453 .59691 Mdot
.31755 .39643 Mdot
.64896 .63334 Mdot
.66129 .59642 Mdot
.44539 .57157 Mdot
.41052 .56576 Mdot
.68081 .52649 Mdot
.58322 .4735 Mdot
.62725 .6189 Mdot
.40627 .63538 Mdot
.42803 .65716 Mdot
.41631 .55851 Mdot
.54553 .4413 Mdot
.62739 .66312 Mdot
.35667 .72981 Mdot
.58965 .21943 Mdot
.62081 .6201 Mdot
.84245 .43285 Mdot
.69255 .51394 Mdot
.66881 .51008 Mdot
.63261 .31699 Mdot
.43646 .58778 Mdot
.43077 .33984 Mdot
.38756 .63307 Mdot
.4638 .54765 Mdot
.45404 .59271 Mdot
.29394 .41011 Mdot
.36612 .59004 Mdot
.68633 .50855 Mdot
.44015 .34289 Mdot
.40294 .63046 Mdot
.42911 .57994 Mdot
.67477 .50024 Mdot
.64871 .58276 Mdot
.65268 .64805 Mdot
.65679 .49933 Mdot
.31033 .39231 Mdot
.60749 .37065 Mdot
.38107 .62382 Mdot
.45548 .33846 Mdot
.43296 .34493 Mdot
.60598 .60514 Mdot
.42884 .36581 Mdot
.61534 .374 Mdot
.41294 .62455 Mdot
.61719 .32264 Mdot
.29412 .40971 Mdot
.62078 .64933 Mdot
.37562 .61282 Mdot
.39403 .57662 Mdot
.62177 .61169 Mdot
.40491 .58715 Mdot
.2917 .41423 Mdot
.40121 .3678 Mdot
.6533 .62485 Mdot
.63049 .3463 Mdot
.42898 .37663 Mdot
.39395 .59611 Mdot
.72909 .24693 Mdot
.40902 .60409 Mdot
.43471 .6335 Mdot
.7995 .57825 Mdot
.44428 .65396 Mdot
.46613 .32135 Mdot
.64975 .5981 Mdot
.44884 .55818 Mdot
.25235 .42662 Mdot
.35073 .34547 Mdot
.45698 .37947 Mdot
.43417 .6265 Mdot
.82988 .43423 Mdot
.40343 .64117 Mdot
.80258 .4239 Mdot
.56087 .46339 Mdot
.46697 .18078 Mdot
.36283 .67132 Mdot
.62476 .31911 Mdot
.6801 .52931 Mdot
.4652 .3174 Mdot
.5322 .80385 Mdot
.40663 .59501 Mdot
.64519 .7515 Mdot
.38128 .62644 Mdot
.61065 .35626 Mdot
.5126 .57708 Mdot
.4211 .36551 Mdot
.3688 .77471 Mdot
.3754 .58002 Mdot
.64069 .66066 Mdot
.46776 .30353 Mdot
.68749 .52795 Mdot
.39819 .56444 Mdot
.33702 .3984 Mdot
.36536 .34759 Mdot
.39425 .68094 Mdot
.62287 .34042 Mdot
.44536 .59193 Mdot
.50696 .58604 Mdot
.13971 .49331 Mdot
.64422 .61863 Mdot
.61077 .32836 Mdot
.49069 .52372 Mdot
.42625 .56317 Mdot
.6512 .65011 Mdot
.63585 .63854 Mdot
.3398 .39525 Mdot
.63106 .45095 Mdot
.32681 .34984 Mdot
.65063 .22495 Mdot
.61728 .76269 Mdot
.40023 .37452 Mdot
.71918 .65323 Mdot
.38187 .60769 Mdot
.29045 .65565 Mdot
.62866 .33012 Mdot
.41614 .60241 Mdot
.59809 .7477 Mdot
.64615 .62464 Mdot
.434 .60292 Mdot
.3059 .42166 Mdot
.73033 .52421 Mdot
.36576 .70403 Mdot
.75941 .29347 Mdot
.4847 .324 Mdot
.48369 .617 Mdot
.38152 .67404 Mdot
.67124 .54164 Mdot
.45636 .56509 Mdot
.45974 .31618 Mdot
.5687 .24763 Mdot
.32824 .42878 Mdot
.6594 .61913 Mdot
.69248 .5184 Mdot
.38642 .63561 Mdot
.4515 .64298 Mdot
.34001 .4317 Mdot
.38721 .56899 Mdot
.41428 .7765 Mdot
.67256 .49659 Mdot
.41046 .37072 Mdot
.62405 .659 Mdot
.46038 .61027 Mdot
.68095 .53221 Mdot
.44141 .56894 Mdot
.39032 .50543 Mdot
.43903 .62165 Mdot
.77342 .62563 Mdot
.61579 .61792 Mdot
.62766 .33909 Mdot
.36517 .59952 Mdot
.42668 .59568 Mdot
.37232 .26977 Mdot
.46019 .5454 Mdot
.44507 .57902 Mdot
.59589 .61799 Mdot
.65655 .60791 Mdot
.6036 .6141 Mdot
.41964 .3734 Mdot
.58726 .49493 Mdot
.61718 .35418 Mdot
.47293 .56776 Mdot
.58412 .35241 Mdot
.34306 .60845 Mdot
.34669 .42481 Mdot
.78122 .35171 Mdot
.40573 .61598 Mdot
.60504 .63101 Mdot
.72229 .69166 Mdot
.6052 .65826 Mdot
.63276 .38973 Mdot
.63 .33404 Mdot
.63388 .62203 Mdot
.42226 .62064 Mdot
.57818 .49829 Mdot
.7223 .25369 Mdot
.63557 .35361 Mdot
.47837 .60178 Mdot
.48419 .32053 Mdot
.44994 .30352 Mdot
.8509 .49007 Mdot
.63123 .3275 Mdot
.71951 .56899 Mdot
.40252 .63688 Mdot
.66074 .61574 Mdot
.59535 .36456 Mdot
.64031 .33674 Mdot
.43545 .36786 Mdot
.39992 .57649 Mdot
.42817 .59772 Mdot
.68513 .50138 Mdot
.58707 .3504 Mdot
.39398 .53022 Mdot
.40425 .57618 Mdot
.80297 .5386 Mdot
.6237 .67621 Mdot
.19764 .66781 Mdot
.46744 .54196 Mdot
.60521 .74388 Mdot
.43693 .44434 Mdot
.65363 .61753 Mdot
.38239 .56755 Mdot
.47219 .56496 Mdot
.40919 .37701 Mdot
.41091 .61896 Mdot
.47036 .35584 Mdot
.62567 .32417 Mdot
.78924 .35535 Mdot
.57601 .30419 Mdot
.65123 .31179 Mdot
.41047 .59801 Mdot
.36411 .69923 Mdot
.30614 .40159 Mdot
.60056 .38216 Mdot
.62236 .59952 Mdot
.46087 .6163 Mdot
.39954 .37791 Mdot
.41746 .37099 Mdot
.6392 .63294 Mdot
.7335 .59097 Mdot
.79623 .39863 Mdot
.44623 .56363 Mdot
.43048 .32479 Mdot
.62932 .28173 Mdot
.46101 .71034 Mdot
.64334 .32443 Mdot
.32446 .42927 Mdot
.46837 .32579 Mdot
.64011 .37663 Mdot
.37193 .5189 Mdot
.63083 .62922 Mdot
.66199 .64572 Mdot
.41128 .25697 Mdot
.4249 .35209 Mdot
.30639 .41021 Mdot
.41491 .45953 Mdot
.42344 .46242 Mdot
.29997 .41958 Mdot
.47629 .34083 Mdot
.65576 .61367 Mdot
.60735 .61248 Mdot
.6352 .64074 Mdot
.39113 .7752 Mdot
.62459 .59135 Mdot
.24802 .68132 Mdot
.46665 .59347 Mdot
.4408 .74155 Mdot
.41593 .6432 Mdot
.58889 .33706 Mdot
.6302 .61475 Mdot
.56369 .47455 Mdot
.44652 .63816 Mdot
.74393 .28 Mdot
.43553 .61746 Mdot
.53067 .35709 Mdot
.43594 .58605 Mdot
.44529 .78224 Mdot
.65196 .6673 Mdot
.41931 .63567 Mdot
.64706 .31599 Mdot
.33118 .41161 Mdot
.67049 .59346 Mdot
.44613 .58231 Mdot
.7662 .55691 Mdot
.43953 .66236 Mdot
.82158 .4523 Mdot
.3291 .26515 Mdot
.2996 .42982 Mdot
.45733 .65357 Mdot
.41494 .32035 Mdot
.52809 .58503 Mdot
.44537 .75154 Mdot
.63557 .35288 Mdot
.38077 .71875 Mdot
.43449 .37019 Mdot
.48125 .5437 Mdot
.39222 .54346 Mdot
.33566 .42707 Mdot
.68379 .62181 Mdot
.6098 .36095 Mdot
.40514 .59693 Mdot
.38702 .56426 Mdot
.54912 .18561 Mdot
.4416 .758 Mdot
.37935 .54296 Mdot
.35381 .42164 Mdot
.38246 .72622 Mdot
.45211 .59477 Mdot
.45618 .3795 Mdot
.64798 .59527 Mdot
.44206 .67551 Mdot
.35031 .73148 Mdot
.40659 .63311 Mdot
.63686 .62467 Mdot
.66207 .63297 Mdot
.7465 .68782 Mdot
.34614 .42352 Mdot
.43941 .62094 Mdot
.39349 .25503 Mdot
.37554 .60981 Mdot
.61536 .3574 Mdot
.45991 .56654 Mdot
.4602 .35014 Mdot
.60686 .49414 Mdot
.42202 .37385 Mdot
.40809 .55979 Mdot
.61512 .63672 Mdot
.60804 .36389 Mdot
.46339 .22411 Mdot
.56268 .40301 Mdot
.24507 .6764 Mdot
.3631 .35105 Mdot
.33974 .40716 Mdot
.33521 .38755 Mdot
.66888 .34921 Mdot
.42888 .62566 Mdot
.54971 .42353 Mdot
.48574 .59035 Mdot
.43835 .58189 Mdot
.44959 .6147 Mdot
.58993 .30924 Mdot
.63018 .33557 Mdot
.43346 .35624 Mdot
.41606 .57616 Mdot
.40702 .63612 Mdot
.62121 .62452 Mdot
.3336 .41779 Mdot
.40243 .36519 Mdot
.31063 .39357 Mdot
.44514 .34339 Mdot
.84823 .51966 Mdot
.46592 .57201 Mdot
.33047 .41042 Mdot
.62084 .37763 Mdot
.60115 .6247 Mdot
.67384 .50365 Mdot
.43399 .32632 Mdot
.42046 .36374 Mdot
.42136 .63893 Mdot
.63378 .65363 Mdot
.64461 .65274 Mdot
.34163 .40671 Mdot
.59142 .34919 Mdot
.41867 .55113 Mdot
.40846 .56945 Mdot
.43125 .21352 Mdot
.41216 .37639 Mdot
.39771 .73669 Mdot
.75053 .6516 Mdot
.42769 .62734 Mdot
.64536 .65418 Mdot
.42275 .58757 Mdot
.63249 .26245 Mdot
.5982 .62373 Mdot
.43281 .65203 Mdot
.33827 .54065 Mdot
.39836 .36988 Mdot
.73895 .72152 Mdot
.3875 .6468 Mdot
.56439 .38384 Mdot
.3833 .58875 Mdot
.76513 .72878 Mdot
.70898 .69926 Mdot
.38082 .62698 Mdot
.44222 .56285 Mdot
.64609 .21148 Mdot
.39752 .63576 Mdot
.68787 .50618 Mdot
.45651 .53964 Mdot
.6515 .65064 Mdot
.47492 .43072 Mdot
.57278 .44895 Mdot
.35071 .41002 Mdot
.45702 .33528 Mdot
.23602 .54625 Mdot
.32328 .38933 Mdot
.63369 .60499 Mdot
.45287 .63799 Mdot
.66201 .69705 Mdot
.39671 .33619 Mdot
.41094 .54493 Mdot
.61379 .35738 Mdot
.57428 .44966 Mdot
.47138 .33324 Mdot
.63188 .34459 Mdot
.41298 .64988 Mdot
.24071 .32843 Mdot
.59432 .40982 Mdot
.77003 .67591 Mdot
.60913 .36853 Mdot
.61852 .33251 Mdot
.58579 .51051 Mdot
.35062 .40956 Mdot
.51989 .18918 Mdot
.46226 .68255 Mdot
.63632 .35789 Mdot
.2949 .51839 Mdot
.44767 .37829 Mdot
.62179 .46126 Mdot
.64431 .67014 Mdot
.46484 .56924 Mdot
.42363 .61532 Mdot
.59447 .35169 Mdot
.70139 .67654 Mdot
.44328 .49076 Mdot
.6361 .34602 Mdot
.37483 .66585 Mdot
.62785 .46001 Mdot
.67575 .52852 Mdot
.69123 .50549 Mdot
.35336 .40199 Mdot
.27969 .35061 Mdot
.61085 .62294 Mdot
.31058 .43041 Mdot
.63141 .55168 Mdot
.44238 .61432 Mdot
.58663 .34956 Mdot
.6834 .49643 Mdot
.62631 .35004 Mdot
.32222 .40551 Mdot
.33952 .43021 Mdot
.64136 .61778 Mdot
.64398 .60378 Mdot
.50466 .66974 Mdot
.3175 .48585 Mdot
.38749 .62726 Mdot
.66043 .72064 Mdot
.59891 .6191 Mdot
.49474 .81477 Mdot
.34662 .40949 Mdot
.32905 .4233 Mdot
.49471 .73375 Mdot
.39364 .58776 Mdot
.5512 .3225 Mdot
.45065 .58823 Mdot
.26952 .55243 Mdot
.39695 .64823 Mdot
.43437 .36707 Mdot
.37483 .59077 Mdot
.70679 .44633 Mdot
.39882 .62262 Mdot
.45489 .60575 Mdot
.4384 .32855 Mdot
.36437 .58562 Mdot
.4586 .35409 Mdot
.42239 .55899 Mdot
.2784 .4107 Mdot
.45525 .33825 Mdot
.26531 .43302 Mdot
.50132 .40054 Mdot
.68553 .52216 Mdot
.34782 .39496 Mdot
.33619 .3993 Mdot
.24067 .43379 Mdot
.63245 .59801 Mdot
.37204 .5138 Mdot
.43005 .62327 Mdot
.47927 .35757 Mdot
.59813 .37059 Mdot
.40788 .63379 Mdot
.47474 .64407 Mdot
.38889 .64928 Mdot
.63948 .62056 Mdot
.47742 .34313 Mdot
.32351 .41167 Mdot
.42796 .32142 Mdot
.27242 .41358 Mdot
.44634 .30809 Mdot
.49956 .62466 Mdot
.45145 .53346 Mdot
.35219 .5896 Mdot
.63002 .73974 Mdot
.33723 .76512 Mdot
.63346 .63236 Mdot
.6769 .51767 Mdot
.34853 .42332 Mdot
.4677 .47305 Mdot
.60741 .63235 Mdot
.41898 .36048 Mdot
.43026 .60473 Mdot
.3689 .6599 Mdot
.42257 .69727 Mdot
.63385 .68229 Mdot
.30109 .46918 Mdot
.45168 .32573 Mdot
.67012 .52061 Mdot
.59803 .48543 Mdot
.56562 .60913 Mdot
.55853 .47584 Mdot
.42498 .59095 Mdot
.34109 .40182 Mdot
.65953 .632 Mdot
.5312 .20584 Mdot
.59635 .34509 Mdot
.58235 .47806 Mdot
.41053 .60123 Mdot
.71628 .60736 Mdot
.61563 .63699 Mdot
.32272 .4263 Mdot
.59483 .35211 Mdot
.34786 .41766 Mdot
.69224 .5246 Mdot
.65722 .48322 Mdot
.39121 .56814 Mdot
.44594 .57888 Mdot
.593 .37202 Mdot
.61078 .62522 Mdot
.38384 .34057 Mdot
.56728 .19413 Mdot
.42739 .3284 Mdot
.56482 .42321 Mdot
.65829 .6305 Mdot
.70103 .59551 Mdot
.41215 .33786 Mdot
.62599 .37959 Mdot
.55212 .4285 Mdot
.64597 .36382 Mdot
.45357 .60205 Mdot
.63249 .64829 Mdot
.6318 .32748 Mdot
.44613 .22628 Mdot
.83154 .5121 Mdot
.67865 .65946 Mdot
.41232 .57447 Mdot
.78176 .3498 Mdot
.77125 .51881 Mdot
.69784 .6547 Mdot
.59119 .33757 Mdot
.41797 .58156 Mdot
.44887 .5658 Mdot
.37475 .58223 Mdot
.60778 .33273 Mdot
.56289 .39189 Mdot
.41416 .36344 Mdot
.43848 .60712 Mdot
.32585 .39579 Mdot
.45405 .3547 Mdot
.42359 .31218 Mdot
.46356 .31619 Mdot
.59744 .6229 Mdot
.46721 .6117 Mdot
.59248 .55664 Mdot
.79066 .67896 Mdot
.62443 .33484 Mdot
.68567 .52175 Mdot
.44231 .62906 Mdot
.21312 .6167 Mdot
.60231 .61776 Mdot
.42512 .33208 Mdot
.41626 .60008 Mdot
.34582 .26335 Mdot
.67172 .49258 Mdot
.44371 .33286 Mdot
.62155 .60033 Mdot
.69719 .65366 Mdot
.41071 .62017 Mdot
.38408 .59109 Mdot
.61448 .61051 Mdot
.74959 .52593 Mdot
.60839 .48092 Mdot
.42452 .58594 Mdot
.62995 .34035 Mdot
.12942 .48488 Mdot
.43667 .65601 Mdot
.6151 .68039 Mdot
.67917 .53559 Mdot
.77077 .61531 Mdot
.4037 .73255 Mdot
.49476 .61414 Mdot
.73569 .29913 Mdot
.22085 .54973 Mdot
.80372 .37252 Mdot
.25547 .58526 Mdot
.67109 .28648 Mdot
.8305 .58193 Mdot
.6478 .31816 Mdot
.45558 .78235 Mdot
.54962 .16643 Mdot
.73072 .56237 Mdot
.28269 .30787 Mdot
.49028 .23834 Mdot
.35299 .25091 Mdot
.46354 .83769 Mdot
.44175 .30773 Mdot
.27414 .58874 Mdot
.39974 .55638 Mdot
.75805 .50947 Mdot
.40329 .7557 Mdot
.30756 .75171 Mdot
.78107 .35634 Mdot
.37964 .25693 Mdot
.69803 .22161 Mdot
.78542 .37727 Mdot
.54303 .65408 Mdot
.31242 .64965 Mdot
.28646 .35674 Mdot
.41602 .46178 Mdot
.23384 .55717 Mdot
.34736 .66693 Mdot
.70536 .43281 Mdot
.63075 .30747 Mdot
.56404 .68519 Mdot
.14019 .52464 Mdot
.45515 .31845 Mdot
.64765 .59463 Mdot
.50776 .18672 Mdot
.57907 .66179 Mdot
.65285 .38146 Mdot
.73575 .29887 Mdot
.80631 .54415 Mdot
.4425 .77992 Mdot
.61109 .54102 Mdot
.5094 .76389 Mdot
.20878 .46326 Mdot
.30381 .64762 Mdot
.58626 .64213 Mdot
.50281 .2736 Mdot
.42121 .46325 Mdot
.28067 .37256 Mdot
.45758 .79463 Mdot
.33848 .38681 Mdot
.26269 .43205 Mdot
.61406 .60438 Mdot
.47401 .70165 Mdot
.66627 .51438 Mdot
.63401 .55575 Mdot
.40027 .38025 Mdot
.61879 .25993 Mdot
.73549 .51446 Mdot
.75448 .54935 Mdot
.6777 .76591 Mdot
.76323 .28241 Mdot
.25145 .49123 Mdot
.56091 .23261 Mdot
.60017 .39958 Mdot
.22419 .52967 Mdot
.5806 .54205 Mdot
.28542 .48883 Mdot
.36403 .51022 Mdot
.61784 .15834 Mdot
.77708 .55023 Mdot
.67895 .19918 Mdot
.58711 .59825 Mdot
.39514 .66343 Mdot
.58395 .23984 Mdot
.60354 .77641 Mdot
.28221 .38799 Mdot
.76469 .28941 Mdot
.3198 .43433 Mdot
.66222 .66121 Mdot
.72875 .56607 Mdot
.40799 .77027 Mdot
.38962 .32977 Mdot
.35753 .38664 Mdot
.43748 .67551 Mdot
.59395 .13365 Mdot
.72734 .28728 Mdot
.75482 .66778 Mdot
.79974 .54211 Mdot
.48279 .36829 Mdot
.41077 .3215 Mdot
.63242 .32485 Mdot
.82834 .54397 Mdot
.62222 .64371 Mdot
.79348 .67979 Mdot
.82248 .53849 Mdot
.52288 .56796 Mdot
.57906 .12805 Mdot
.55379 .84047 Mdot
.43475 .73964 Mdot
.28504 .68265 Mdot
.29714 .26671 Mdot
.57381 .52997 Mdot
.69387 .58298 Mdot
.49425 .33791 Mdot
.79097 .59841 Mdot
.84288 .50003 Mdot
.30105 .52272 Mdot
.68345 .30791 Mdot
.63104 .55944 Mdot
.38458 .44525 Mdot
.67722 .64785 Mdot
.26085 .33138 Mdot
.35727 .48677 Mdot
.69176 .21141 Mdot
.3764 .72242 Mdot
.17105 .40391 Mdot
.25391 .57014 Mdot
.44225 .80822 Mdot
.72887 .31728 Mdot
.41679 .39686 Mdot
.40701 .49577 Mdot
.75508 .57798 Mdot
.47528 .62093 Mdot
.54612 .51393 Mdot
.44069 .51643 Mdot
.31592 .44256 Mdot
.58825 .5012 Mdot
.79024 .46174 Mdot
.25318 .54879 Mdot
.63132 .22692 Mdot
.3148 .64579 Mdot
.61186 .65568 Mdot
.2716 .47957 Mdot
.26954 .5169 Mdot
.8018 .52219 Mdot
.49305 .5255 Mdot
.77675 .64712 Mdot
.47938 .51309 Mdot
.488 .6043 Mdot
.46483 .78327 Mdot
.34155 .65367 Mdot
.28768 .50899 Mdot
.3869 .64379 Mdot
.69268 .75195 Mdot
.79656 .5681 Mdot
.60556 .7229 Mdot
.2428 .52837 Mdot
.6259 .73505 Mdot
.79426 .5987 Mdot
.59032 .23768 Mdot
.69571 .57677 Mdot
.70989 .66279 Mdot
.60204 .14007 Mdot
.44136 .35959 Mdot
.30374 .50872 Mdot
.57032 .3404 Mdot
.45258 .22818 Mdot
.52466 .16858 Mdot
.45955 .49901 Mdot
.80577 .58966 Mdot
.74345 .55915 Mdot
.40506 .32076 Mdot
.68866 .41062 Mdot
.60993 .29481 Mdot
.63447 .7183 Mdot
.40221 .66054 Mdot
.43936 .51076 Mdot
.29199 .41609 Mdot
.56238 .79089 Mdot
.57913 .22054 Mdot
.41562 .28257 Mdot
.49148 .63215 Mdot
.44941 .27185 Mdot
.67282 .51138 Mdot
.59144 .45997 Mdot
.85457 .50544 Mdot
.4913 .56692 Mdot
.52588 .84175 Mdot
.7592 .53268 Mdot
.56144 .43464 Mdot
.26205 .39344 Mdot
.73593 .65427 Mdot
.65721 .1791 Mdot
.81681 .57904 Mdot
.77279 .4903 Mdot
.77537 .34156 Mdot
.60772 .8463 Mdot
.47792 .1672 Mdot
.5998 .79656 Mdot
.57208 .33752 Mdot
.44155 .90581 Mdot
.41889 .32903 Mdot
.30487 .70161 Mdot
.60043 .77645 Mdot
.3431 .27264 Mdot
.5854 .668 Mdot
.34366 .67612 Mdot
.33845 .36729 Mdot
.6547 .58772 Mdot
.45625 .66436 Mdot
.803 .33767 Mdot
.62478 .1585 Mdot
.79252 .32191 Mdot
.6617 .47889 Mdot
.81086 .3727 Mdot
.62422 .18244 Mdot
.25173 .68709 Mdot
.53784 .18271 Mdot
.45858 .56539 Mdot
.32791 .50406 Mdot
.57503 .83007 Mdot
.37272 .36095 Mdot
.60786 .55524 Mdot
.59534 .66067 Mdot
.60329 .16044 Mdot
.85667 .5014 Mdot
.519 .73048 Mdot
.51368 .67647 Mdot
.46899 .41856 Mdot
.30139 .49365 Mdot
.62022 .69212 Mdot
.71223 .41989 Mdot
.81709 .49465 Mdot
.61212 .17684 Mdot
.26589 .52739 Mdot
.49168 .24548 Mdot
.76727 .47478 Mdot
.58771 .8161 Mdot
.72904 .31055 Mdot
.50058 .18511 Mdot
.49942 .54272 Mdot
.62403 .56985 Mdot
.44556 .49236 Mdot
.69918 .42462 Mdot
.57609 .27589 Mdot
.23759 .49711 Mdot
.46512 .35377 Mdot
.30873 .51517 Mdot
.51786 .45953 Mdot
.53511 .18122 Mdot
.22587 .49917 Mdot
.29754 .53205 Mdot
.78506 .48025 Mdot
.80399 .34657 Mdot
.7564 .53642 Mdot
.26537 .29004 Mdot
.74365 .35492 Mdot
.46875 .53153 Mdot
.36367 .61726 Mdot
.80125 .59218 Mdot
.84168 .39381 Mdot
.80802 .58752 Mdot
.71799 .61808 Mdot
.41483 .2506 Mdot
.65244 .36343 Mdot
.21932 .50214 Mdot
.4281 .28649 Mdot
.82263 .4925 Mdot
.49598 .47646 Mdot
.65133 .3701 Mdot
.72773 .53018 Mdot
.51217 .66299 Mdot
.22159 .5839 Mdot
.54427 .68663 Mdot
.44229 .54241 Mdot
.4507 .72224 Mdot
.66881 .63136 Mdot
.71554 .61429 Mdot
.29097 .49394 Mdot
.44656 .35601 Mdot
.41335 .21106 Mdot
.63221 .68895 Mdot
.41877 .66833 Mdot
.56895 .25511 Mdot
.67868 .64539 Mdot
.62226 .74494 Mdot
.44069 .29875 Mdot
.83669 .5581 Mdot
.66291 .76893 Mdot
.63482 .69679 Mdot
.25911 .48175 Mdot
.42932 .2191 Mdot
.60719 .46963 Mdot
.57486 .33742 Mdot
.77993 .35981 Mdot
.50984 .4018 Mdot
.2704 .48546 Mdot
.43836 .72601 Mdot
.56885 .20197 Mdot
.48175 .58331 Mdot
.73902 .68226 Mdot
.24152 .66427 Mdot
.59446 .45439 Mdot
.5856 .66241 Mdot
.61684 .59063 Mdot
.38637 .81714 Mdot
.71917 .44724 Mdot
.54852 .58146 Mdot
.75105 .32756 Mdot
.64501 .33461 Mdot
.59939 .64033 Mdot
.30144 .53556 Mdot
.30146 .31961 Mdot
.4451 .70722 Mdot
.58602 .27306 Mdot
.55238 .65254 Mdot
.53787 .3605 Mdot
.76552 .3333 Mdot
.70807 .25356 Mdot
.13795 .47325 Mdot
.62277 .58319 Mdot
.538 .21474 Mdot
.53082 .21376 Mdot
.58996 .64689 Mdot
.62715 .6828 Mdot
.36251 .70053 Mdot
.83063 .40518 Mdot
.47907 .46328 Mdot
.70389 .40912 Mdot
.55343 .42742 Mdot
.28084 .31503 Mdot
.54552 .19662 Mdot
.23103 .52686 Mdot
.70805 .29222 Mdot
.52155 .68479 Mdot
.34974 .21529 Mdot
.35568 .56968 Mdot
.30837 .70709 Mdot
.21912 .50196 Mdot
.30489 .59576 Mdot
.465 .79594 Mdot
.80285 .44813 Mdot
.37887 .61662 Mdot
.78108 .29938 Mdot
.79407 .51487 Mdot
.54056 .51655 Mdot
.4535 .38642 Mdot
.39182 .61143 Mdot
.4681 .60722 Mdot
.7016 .68987 Mdot
.76081 .63475 Mdot
.42473 .17387 Mdot
.25994 .56532 Mdot
.49346 .54904 Mdot
.4287 .73167 Mdot
.52684 .84142 Mdot
.59388 .24929 Mdot
.81444 .4205 Mdot
.5172 .47143 Mdot
.59137 .82142 Mdot
.70243 .37006 Mdot
.68525 .42574 Mdot
.74002 .34359 Mdot
.63185 .18726 Mdot
.49726 .64098 Mdot
.75849 .61128 Mdot
.51016 .19353 Mdot
.44274 .62759 Mdot
.73379 .59175 Mdot
.75108 .33511 Mdot
.18509 .42317 Mdot
.57104 .54804 Mdot
.83867 .37652 Mdot
.37544 .52834 Mdot
.76268 .59405 Mdot
.53504 .16167 Mdot
.23674 .28113 Mdot
.6956 .43771 Mdot
.7009 .22088 Mdot
.67876 .41527 Mdot
.74144 .31691 Mdot
.62826 .3193 Mdot
.48967 .43764 Mdot
.65882 .73253 Mdot
.83365 .41213 Mdot
.32542 .32702 Mdot
.6567 .25953 Mdot
.69042 .71544 Mdot
.83067 .39302 Mdot
.35356 .53111 Mdot
.38459 .81177 Mdot
.39289 .38294 Mdot
.60209 .82736 Mdot
.62837 .78161 Mdot
.55332 .63246 Mdot
.28956 .52675 Mdot
.3747 .79817 Mdot
.28735 .72474 Mdot
.62129 .78028 Mdot
.30542 .55361 Mdot
.74203 .65338 Mdot
.25187 .47805 Mdot
.82583 .4988 Mdot
.44504 .83248 Mdot
.54379 .2045 Mdot
.70349 .53719 Mdot
.67565 .48358 Mdot
.76111 .64235 Mdot
.77198 .43148 Mdot
.57673 .24885 Mdot
.641 .47342 Mdot
.54255 .64623 Mdot
.12453 .59406 Mdot
.6727 .39711 Mdot
.39702 .70219 Mdot
.65045 .18039 Mdot
.8144 .49845 Mdot
.48281 .47431 Mdot
.44849 .79491 Mdot
.2182 .60165 Mdot
.38639 .41274 Mdot
.45353 .5914 Mdot
.82685 .3866 Mdot
.37867 .39077 Mdot
.7252 .25243 Mdot
.77785 .67283 Mdot
.48492 .70656 Mdot
.50959 .60814 Mdot
.49179 .32832 Mdot
.31152 .67077 Mdot
.29878 .56903 Mdot
.6551 .1924 Mdot
.31031 .70633 Mdot
.54811 .40492 Mdot
.54024 .34849 Mdot
.58495 .29269 Mdot
.52955 .60077 Mdot
.57912 .83104 Mdot
.75119 .63978 Mdot
.2442 .55372 Mdot
.76045 .4787 Mdot
.29693 .50729 Mdot
.40356 .73408 Mdot
.22106 .48868 Mdot
.51748 .51812 Mdot
.3178 .36686 Mdot
.42453 .37858 Mdot
.63662 .21233 Mdot
.77979 .38091 Mdot
.70125 .74073 Mdot
.27224 .28558 Mdot
.75312 .58228 Mdot
.28045 .59894 Mdot
.60398 .22035 Mdot
.56455 .53684 Mdot
.31964 .34054 Mdot
.2336 .59829 Mdot
.38049 .72067 Mdot
.80961 .43534 Mdot
.31792 .64052 Mdot
.8453 .50123 Mdot
.2369 .50213 Mdot
.59473 .19314 Mdot
.46282 .42358 Mdot
.57665 .77382 Mdot
.46458 .75361 Mdot
.31657 .25207 Mdot
.59088 .45304 Mdot
.59555 .13545 Mdot
.61129 .66279 Mdot
.75931 .27875 Mdot
.61203 .37065 Mdot
.15385 .48676 Mdot
.81452 .4651 Mdot
.54124 .48566 Mdot
.53382 .43681 Mdot
.73922 .68737 Mdot
.75132 .53667 Mdot
.76221 .53804 Mdot
.45076 .49617 Mdot
.46955 .31777 Mdot
.55276 .39656 Mdot
.70894 .40763 Mdot
.65104 .23254 Mdot
.43226 .55403 Mdot
.40022 .32184 Mdot
.30022 .61683 Mdot
.56678 .3662 Mdot
.7949 .57798 Mdot
.79577 .41701 Mdot
.35683 .67094 Mdot
.30146 .49119 Mdot
.62174 .1755 Mdot
.81515 .52569 Mdot
.44281 .48587 Mdot
.42543 .51473 Mdot
.61051 .40324 Mdot
.44807 .18916 Mdot
.70955 .27336 Mdot
.56424 .31405 Mdot
.61832 .47517 Mdot
.25279 .49427 Mdot
.8447 .36279 Mdot
.62101 .15819 Mdot
.30792 .24463 Mdot
.55262 .42437 Mdot
.59309 .58834 Mdot
.22032 .62224 Mdot
.59842 .19533 Mdot
.61516 .82225 Mdot
.78325 .50293 Mdot
.29929 .51113 Mdot
.19787 .39777 Mdot
.33877 .75717 Mdot
.53581 .39232 Mdot
.46603 .75428 Mdot
.6246 .75345 Mdot
.62175 .39127 Mdot
.38743 .41908 Mdot
.52358 .41272 Mdot
.65139 .38464 Mdot
.74382 .65123 Mdot
.74834 .54084 Mdot
.59182 .19109 Mdot
.32021 .72007 Mdot
.4213 .51443 Mdot
.64855 .24286 Mdot
.67164 .65356 Mdot
.52778 .20874 Mdot
.44053 .21111 Mdot
.53291 .40586 Mdot
.42879 .31775 Mdot
.39213 .68814 Mdot
.60922 .44995 Mdot
.68501 .40208 Mdot
.22269 .35862 Mdot
.28331 .41005 Mdot
.58073 .62458 Mdot
.3512 .7715 Mdot
.60826 .58655 Mdot
.86444 .43303 Mdot
.71449 .41875 Mdot
.44048 .72924 Mdot
.70002 .35259 Mdot
.50745 .25645 Mdot
.22909 .32073 Mdot
.5362 .65464 Mdot
.25587 .42024 Mdot
.57806 .60853 Mdot
.66784 .62704 Mdot
.70837 .33759 Mdot
.66111 .52564 Mdot
.49646 .6873 Mdot
.49264 .84154 Mdot
.42646 .21926 Mdot
.59714 .59434 Mdot
.52932 .36333 Mdot
.68581 .65843 Mdot
.85328 .51249 Mdot
.43492 .31694 Mdot
.61045 .14468 Mdot
.46163 .53736 Mdot
.43803 .18753 Mdot
.7997 .58519 Mdot
.60527 .50021 Mdot
.55378 .41983 Mdot
.46156 .23993 Mdot
.48501 .6041 Mdot
.49944 .55373 Mdot
.63403 .59978 Mdot
.54908 .18258 Mdot
.32631 .42072 Mdot
.29981 .47421 Mdot
.5933 .31663 Mdot
.48807 .8238 Mdot
.61342 .81 Mdot
.66918 .62585 Mdot
.50171 .38569 Mdot
.52343 .22073 Mdot
.33555 .54235 Mdot
.30105 .60828 Mdot
.64043 .20929 Mdot
.51925 .66835 Mdot
.61205 .66214 Mdot
.30399 .25012 Mdot
.35962 .48303 Mdot
.8245 .58552 Mdot
.34227 .59004 Mdot
.3078 .65743 Mdot
.308 .61159 Mdot
.73594 .67326 Mdot
.40217 .73159 Mdot
.82272 .44971 Mdot
.27594 .48243 Mdot
.38831 .47699 Mdot
.30044 .5298 Mdot
.35822 .67415 Mdot
.55664 .33438 Mdot
.57826 .83784 Mdot
.20072 .39134 Mdot
.50197 .77002 Mdot
.58447 .54902 Mdot
.58344 .66307 Mdot
.53592 .84046 Mdot
.58221 .63798 Mdot
.28782 .43391 Mdot
.57328 .69115 Mdot
.81405 .46764 Mdot
.8307 .53587 Mdot
.80122 .52232 Mdot
.31179 .67497 Mdot
.58627 .29359 Mdot
.2564 .64288 Mdot
.38575 .5151 Mdot
.54942 .48126 Mdot
.4827 .6295 Mdot
.5086 .5696 Mdot
.49047 .48699 Mdot
.72046 .69923 Mdot
.51819 .60961 Mdot
.82803 .4087 Mdot
.82247 .58219 Mdot
.79447 .34684 Mdot
.57391 .27433 Mdot
.64188 .58869 Mdot
.64595 .17218 Mdot
.3487 .74271 Mdot
.82354 .5074 Mdot
.61867 .78833 Mdot
.40579 .83058 Mdot
.5452 .16239 Mdot
.79604 .46071 Mdot
.58545 .5793 Mdot
.74272 .71916 Mdot
.77905 .54842 Mdot
.38866 .81261 Mdot
.37475 .7152 Mdot
.7962 .58484 Mdot
.58298 .1349 Mdot
.55676 .81447 Mdot
.75764 .54788 Mdot
.45694 .75511 Mdot
.39362 .71441 Mdot
.45736 .83031 Mdot
.47142 .60903 Mdot
.42589 .31356 Mdot
.31948 .27631 Mdot
.28947 .5199 Mdot
.36996 .68502 Mdot
.44058 .8253 Mdot
.29729 .57467 Mdot
.2752 .59616 Mdot
.45074 .23306 Mdot
.54933 .16534 Mdot
.42388 .72271 Mdot
.38001 .67283 Mdot
.59532 .6635 Mdot
.32869 .38801 Mdot
.24546 .5879 Mdot
.39732 .60288 Mdot
.57112 .45691 Mdot
.47278 .6693 Mdot
.81356 .34762 Mdot
.29859 .30783 Mdot
.66776 .32734 Mdot
.62879 .58528 Mdot
.75451 .64926 Mdot
.62102 .24891 Mdot
.72978 .56292 Mdot
.42124 .81466 Mdot
.48668 .68241 Mdot
.75629 .32072 Mdot
.75124 .56259 Mdot
.25073 .51848 Mdot
.21837 .4332 Mdot
.59879 .32531 Mdot
.63996 .74982 Mdot
.65098 .19381 Mdot
.74318 .59428 Mdot
.66365 .66206 Mdot
.76574 .45949 Mdot
.55154 .34314 Mdot
.74357 .61472 Mdot
.75707 .53073 Mdot
.56536 .21116 Mdot
.48382 .72247 Mdot
.70479 .25486 Mdot
.4817 .31404 Mdot
.27099 .53199 Mdot
.73608 .45022 Mdot
.45712 .83254 Mdot
.33469 .54585 Mdot
.84068 .47027 Mdot
.54062 .47674 Mdot
.30951 .46275 Mdot
.38945 .57474 Mdot
.34559 .73038 Mdot
.72711 .67765 Mdot
.75536 .4698 Mdot
.51709 .55446 Mdot
.67305 .61928 Mdot
.67478 .7655 Mdot
.43889 .38971 Mdot
.39126 .39678 Mdot
.29302 .68336 Mdot
.71079 .62731 Mdot
.31917 .44995 Mdot
.71106 .49953 Mdot
.43826 .52712 Mdot
.24237 .39797 Mdot
.58127 .2879 Mdot
.65023 .74595 Mdot
.59059 .80164 Mdot
.64127 .2143 Mdot
.58812 .26574 Mdot
.68505 .76324 Mdot
.65467 .75469 Mdot
.77684 .61643 Mdot
.34022 .75094 Mdot
.59225 .56989 Mdot
.4024 .65737 Mdot
.28833 .43419 Mdot
.59608 .65108 Mdot
.65827 .23312 Mdot
.45077 .51185 Mdot
.29383 .45413 Mdot
.53612 .49967 Mdot
.58049 .24028 Mdot
.43207 .43207 Mdot
.79366 .57308 Mdot
.74258 .71963 Mdot
.28977 .49304 Mdot
.60347 .31735 Mdot
.68694 .40752 Mdot
.5633 .54889 Mdot
.83357 .43687 Mdot
.48067 .49183 Mdot
.66048 .69916 Mdot
.69799 .53398 Mdot
.60332 .74212 Mdot
.79033 .63441 Mdot
.32227 .48309 Mdot
.55684 .48177 Mdot
.64078 .69362 Mdot
.61301 .55296 Mdot
.67261 .50508 Mdot
.33499 .28315 Mdot
.34112 .73682 Mdot
.68294 .31775 Mdot
.57381 .41012 Mdot
.40528 .52505 Mdot
.22287 .62667 Mdot
.69427 .25295 Mdot
.4688 .47413 Mdot
.53383 .47744 Mdot
.50632 .19568 Mdot
.37724 .4011 Mdot
.12117 .50808 Mdot
.79668 .31805 Mdot
.38944 .57599 Mdot
.52077 .43232 Mdot
.31081 .47739 Mdot
.47226 .35342 Mdot
.5423 .68242 Mdot
.65009 .21953 Mdot
.63761 .33686 Mdot
.43477 .23755 Mdot
.70715 .491 Mdot
.73387 .6916 Mdot
.34872 .22478 Mdot
.64566 .37668 Mdot
.86388 .4265 Mdot
.77956 .50397 Mdot
.72641 .65676 Mdot
.11445 .53875 Mdot
.71733 .6945 Mdot
.36663 .51269 Mdot
.43056 .24878 Mdot
.81393 .35588 Mdot
.55803 .42475 Mdot
.41498 .25438 Mdot
.57153 .80778 Mdot
.28425 .48992 Mdot
.26427 .55387 Mdot
.70754 .53716 Mdot
.70311 .72466 Mdot
.36192 .80684 Mdot
.5084 .2551 Mdot
.24573 .29777 Mdot
.49161 .69537 Mdot
.72506 .26519 Mdot
.69623 .43613 Mdot
.19596 .41046 Mdot
.82779 .54102 Mdot
.3212 .51764 Mdot
.45272 .8221 Mdot
.29529 .33568 Mdot
.25519 .43594 Mdot
.21721 .6269 Mdot
.65027 .47834 Mdot
.52773 .66459 Mdot
.48126 .25757 Mdot
.52982 .56147 Mdot
.30452 .52185 Mdot
.60711 .75495 Mdot
.55523 .48013 Mdot
.67819 .21569 Mdot
.39426 .79496 Mdot
.26255 .48903 Mdot
.48349 .20718 Mdot
.26222 .4381 Mdot
.67299 .25042 Mdot
.63942 .2699 Mdot
.34195 .52062 Mdot
.49319 .14751 Mdot
.69162 .2117 Mdot
.5963 .56759 Mdot
.46812 .60042 Mdot
.8285 .58617 Mdot
.39015 .45363 Mdot
.5998 .79506 Mdot
.73868 .49895 Mdot
.26027 .57166 Mdot
.50089 .6424 Mdot
.42487 .66194 Mdot
.26938 .66668 Mdot
.57376 .58853 Mdot
.61249 .75413 Mdot
.38688 .21358 Mdot
.26332 .48471 Mdot
.40307 .79453 Mdot
.35878 .21234 Mdot
.34075 .59419 Mdot
.65338 .65033 Mdot
.81354 .35216 Mdot
.59708 .69017 Mdot
.42754 .51108 Mdot
.45205 .73727 Mdot
.46514 .48927 Mdot
.34779 .3387 Mdot
.4216 .51523 Mdot
.60578 .4683 Mdot
.28737 .52766 Mdot
.60793 .20385 Mdot
.66703 .72627 Mdot
.58466 .12609 Mdot
.80459 .59392 Mdot
.60116 .58913 Mdot
.57787 .79929 Mdot
.52821 .40283 Mdot
.78451 .33584 Mdot
.48022 .24811 Mdot
.43293 .21658 Mdot
.32967 .77182 Mdot
.25843 .45073 Mdot
.36869 .59523 Mdot
.66336 .47873 Mdot
.83758 .52179 Mdot
.34307 .78252 Mdot
.84464 .49977 Mdot
.51247 .61181 Mdot
.36921 .63351 Mdot
.20107 .31452 Mdot
.75178 .32369 Mdot
.49616 .59257 Mdot
.55239 .58901 Mdot
.54034 .59033 Mdot
.4123 .55553 Mdot
.65915 .52126 Mdot
.22963 .56614 Mdot
.26786 .56197 Mdot
.82867 .4038 Mdot
.60236 .59677 Mdot
.56502 .43316 Mdot
.59044 .37735 Mdot
.55328 .44134 Mdot
.35735 .66238 Mdot
.64454 .33796 Mdot
.27289 .57101 Mdot
.41137 .44861 Mdot
.38173 .31843 Mdot
.51417 .65631 Mdot
.62751 .48626 Mdot
.53485 .6417 Mdot
.29244 .64044 Mdot
.69138 .58696 Mdot
.28477 .72323 Mdot
.29656 .57422 Mdot
.32797 .5333 Mdot
.78869 .57108 Mdot
.57726 .85478 Mdot
.57932 .44308 Mdot
.69594 .60736 Mdot
.35092 .5449 Mdot
.36653 .7389 Mdot
.46747 .72885 Mdot
.36705 .35242 Mdot
.66802 .52492 Mdot
.51566 .59943 Mdot
.63678 .69644 Mdot
.65172 .35321 Mdot
.84265 .36861 Mdot
.41785 .66639 Mdot
.52777 .69762 Mdot
.83111 .45554 Mdot
.53353 .2047 Mdot
.37329 .71128 Mdot
.47925 .63559 Mdot
.40504 .47394 Mdot
.40562 .44893 Mdot
.68279 .67781 Mdot
.54504 .19307 Mdot
.7345 .28975 Mdot
.29892 .67789 Mdot
.50995 .7 Mdot
.43438 .62036 Mdot
.30598 .43408 Mdot
.59389 .4689 Mdot
.22308 .38202 Mdot
.35954 .44409 Mdot
.8107 .52108 Mdot
.28775 .61907 Mdot
.25952 .56539 Mdot
.43558 .75711 Mdot
.74158 .26641 Mdot
.57272 .55464 Mdot
.47751 .71095 Mdot
.51752 .50766 Mdot
.77584 .43715 Mdot
.30348 .55559 Mdot
.6785 .30085 Mdot
.52035 .59382 Mdot
.56176 .59138 Mdot
.85764 .45435 Mdot
.54247 .65502 Mdot
.6138 .30302 Mdot
.81087 .43507 Mdot
.35006 .75154 Mdot
.53284 .4376 Mdot
.11364 .56328 Mdot
.47494 .24329 Mdot
.8579 .41501 Mdot
.58675 .20469 Mdot
.31851 .59115 Mdot
.74035 .65028 Mdot
.4679 .65841 Mdot
.43469 .33629 Mdot
.76619 .31748 Mdot
.61189 .6837 Mdot
.61303 .56273 Mdot
.46691 .57718 Mdot
.4445 .46228 Mdot
.67021 .6843 Mdot
.6743 .28397 Mdot
.44935 .30307 Mdot
.44819 .4869 Mdot
.6651 .27257 Mdot
.40415 .44865 Mdot
.43412 .84451 Mdot
.65712 .19293 Mdot
.78334 .36434 Mdot
.57578 .29659 Mdot
.14865 .46796 Mdot
.56996 .61992 Mdot
.64685 .68345 Mdot
.63788 .31269 Mdot
.26019 .65161 Mdot
.74279 .60578 Mdot
.59617 .19809 Mdot
.76937 .6449 Mdot
.33371 .54601 Mdot
.13504 .62732 Mdot
.31129 .52693 Mdot
.44604 .47302 Mdot
.73087 .60562 Mdot
.83339 .42089 Mdot
.41174 .24092 Mdot
.76962 .67675 Mdot
.70957 .43455 Mdot
.36389 .67665 Mdot
.25229 .67441 Mdot
.31042 .24814 Mdot
.54561 .33597 Mdot
.24112 .30186 Mdot
.73469 .32375 Mdot
.23403 .556 Mdot
.75003 .46751 Mdot
.6211 .58286 Mdot
.51047 .56172 Mdot
.71728 .41232 Mdot
.60574 .55604 Mdot
.70269 .67621 Mdot
.73138 .29305 Mdot
.20481 .49787 Mdot
.47533 .19508 Mdot
.78343 .34754 Mdot
.56632 .37152 Mdot
.55646 .62807 Mdot
.29285 .58477 Mdot
.36727 .41856 Mdot
.45658 .36495 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`2jooooo`;o0000SOooool001cooooo00?o0000oooo
ooooool0^?ooool4o`0008gooooo000Looooo`03o`000?oooooooooo0;Sooooo0_l0002?ooooo`00
7?ooool00ol0003oooooooooo`2fooooo`;o00000_ooool2o`000003ooooool0003o000008[ooooo
000Looooo`03o`000?oooooooooo097ooooo0_l0000Sooooo`;o00000_ooool2o`000004ooooool0
003o0000o`0008Wooooo000Looooo`03o`000?oooooooooo097ooooo0_l0000[ooooo`Co0000Qooo
ool001cooooo00?o0000ooooooooool0`?ooool2o`0008Oooooo000Looooo`03o`000?oooooooooo
09cooooo0_l00005ooooo`;o00007_ooool2o`0008Cooooo000Looooo`03o`000?oooooooooo09co
oooo0_l00005ooooo`;o00007_ooool2o`0008Cooooo000Looooo`;o0000ZOooool2o`0009oooooo
000Looooo`03o`000?oooooooooo0:?ooooo0_l00003ooooo`;o0000Woooool001cooooo00?o0000
ooooooooool0V_ooool2o`0000Oooooo0_l00007ooooo`;o00005oooool4o`00083ooooo000Loooo
o`03o`000?oooooooooo09[ooooo0_l0000:ooooo`;o00000_ooool5o`00017ooooo0_l00003oooo
o`Co00000_ooool2o`0007cooooo000Looooo`03o`000?oooooooooo0:Kooooo0_l00002ooooo`;o
000000?oooooo`000?l000000_l0000?ooooo`;o00002Oooool2o`0007cooooo000Looooo`03o`00
0?oooooooooo08_ooooo0_l0000:ooooo`;o00002oooool2o`000003ooooool0003o000000Kooooo
0_l0002Hooooo`007?ooool00ol0003oooooooooo`2;ooooo`;o00002?ooool4o`0000_ooooo0_l0
00000ooooooo0000o`000002ooooo`;o00000_ooool2o`0001gooooo0_l0001iooooo`007?ooool0
0ol0003oooooooooo`26ooooo`;o00003Oooool2o`00017ooooo0_l000000ooooooo0000o`00000Q
ooooo`;o0000NOooool001cooooo00?o0000ooooooooool0Q_ooool2o`0000_ooooo0_l0000@oooo
o`;o000000Coooooo`000?l0003ooooo0_l0000:ooooo`;o00002_ooool2o`000003ooooool0003o
0000087ooooo000Looooo`03o`000?oooooooooo08oooooo0_l00002ooooo`?o00003oooool2o`00
00?ooooo0ol00002ooooo`?o00001Oooool2o`0000[ooooo0_l000000ooooooo0000o`000007oooo
o`;o000000?oooooo`000?l00000MOooool001cooooo00?o0000ooooooooool0Soooool2o`0000?o
oooo0_l0000Dooooo`?o000000?oooooo`000?l000000_l00005ooooo`;o00003_ooool2o`0000Ko
oooo0_l000001?oooooo0000o`000?l0001dooooo`007?ooool00ol0003oooooooooo`27ooooo`;o
00000_ooool2o`0001;ooooo1?l00008ooooo`;o000000Coooooo`000?l0003o00001_ooool2o`00
0003ooooool0003o000000_ooooo1?l00008ooooo`;o0000M?ooool001cooooo00?o0000oooooooo
ool0Qoooool2o`0000;ooooo0_l000000ooooooo0000o`00000?ooooo`Go000000?oooooo`000?l0
00002?ooool2o`0000Wooooo0_l0000=ooooo`;o0000O_ooool00006ooooooo^k^ko<S8bo`000?lb
<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo08kooooo0_l00002oooo
o`;o00001Oooool2o`0000Oooooo0_l000000ooooooo0000o`000006ooooo`;o00003?ooool4o`00
017ooooo1?l0001eooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0T_ooool2o`0000?ooooo1?l0
0006ooooo`?o00002Oooool4o`0000?ooooo0_l00005ooooo`Ko00003oooool4o`0007Gooooo0000
0ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01oooool0
0ol0003oooooooooo`2Gooooo`;o00002?ooool2o`0000Cooooo0ol00003ooooo`Co00000oooool2
o`0000Sooooo0ol0000Hooooo`;o0000K_ooool00003ooooool0003ooooo00;ooooo00?o0000oooo
ooooool02oooool00onHV9So8B4Qonk^kP06ooooo`?o0000Soooool3o`0001Gooooo0ol0000;oooo
o`;o00001oooool2o`0001Wooooo0_l0001^ooooo`0000?oooooo`000?ooool00_ooool00ol0003o
ooooooooo`0<ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0Soooool3o`0001Oo
oooo0ol000001?oooooo0000o`000?l00005ooooo`;o00001?ooool2o`0000Gooooo0_l00025oooo
o`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0Qoooool2o`00013ooooo0_l0000=ooooo`Co000000Coooooo`000?l0
003o00002oooool4o`0000?ooooo0_l00008ooooo`;o0000Noooool00006oooooomgMgOoV9RHoooo
oonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0LOoo
ool2o`00013ooooo0_l00002ooooo`;o00000_ooool2o`0000Oooooo0_l00003ooooo`;o00003Ooo
ool4o`0000?ooooo0_l00003ooooo`;o00001oooool2o`0000cooooo1Ol0000=ooooo`;o0000J_oo
ool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Ko
oooo00?o0000ooooooooool0K_ooool2o`000004ooooool0003o0000ooooo`;o00001?ooool2o`00
00Oooooo0_l00002ooooo`?o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o0000
01;ooooo1Ol00002ooooo`?o00000_ooool2o`0000?ooooo0_l0000@ooooo`Go00003Oooool2o`00
06[ooooo000Looooo`03o`000?oooooooooo06kooooo0_l00004ooooo`;o000000Coooooo`000?l0
003ooooo0_l0000<ooooo`Oo000000Coooooo`000?l0003o00005_ooool4o`0000?ooooo0_l00007
ooooo`;o00004_ooool2o`0000[ooooo0_l0001^ooooo`007?ooool00ol0003oooooooooo`1aoooo
o`;o00001?ooool2o`0000gooooo3?l0000Dooooo`;o00000oooool2o`0000_ooooo0_l00002oooo
o`;o00000_ooool2o`0000_ooooo1?l00008ooooo`;o00001?ooool3o`0006Oooooo000Looooo`03
o`000?oooooooooo06kooooo0_l000000ooooooo0000o`00000Cooooo`[o00000oooool2o`0000;o
oooo0_l0000=ooooo`;o00002_ooool2o`0000Cooooo0_l00002ooooo`;o00000_ooool2o`0000go
oooo0_l0000>ooooo`?o0000Ioooool001cooooo00?o0000ooooooooool0K_ooool2o`0001cooooo
0ol00004ooooo`;o00000_ooool2o`0001Wooooo0_l0000Aooooo`;o00000_ooool2o`0000Gooooo
0_l0001gooooo`007?ooool00ol0003oooooooooo`1^ooooo`;o00007Oooool4o`0001Gooooo0_l0
0006ooooo`;o00005Oooool2o`0000;ooooo0_l00005ooooo`;o00002oooool2o`0006[ooooo000L
ooooo`03o`000?oooooooooo06_ooooo0_l0000Rooooo`;o00005Oooool2o`0000Kooooo0_l00002
ooooo`;o00007?ooool4o`0000Wooooo0_l0001Zooooo`007?ooool00ol0003oooooooooo`1[oooo
o`;o00008_ooool2o`0000Cooooo0ol0000Jooooo`;o00007?ooool4o`0007Gooooo000Looooo`03
o`000?oooooooooo08Wooooo0_l00005ooooo`Co000000?oooooo`000?l000000_l00003ooooo`;o
00007?ooool4o`0000cooooo1?l0001kooooo`007?ooool00ol0003oooooooooo`21ooooo`?o0000
1Oooool2o`0000Gooooo1?l00003ooooo`;o00000oooool2o`0001Cooooo0_l00005ooooo`Go0000
00?oooooo`000?l000002Oooool4o`000004ooooool0003o0000o`0007Oooooo000Looooo`03o`00
0?oooooooooo05_ooooo0_l00003ooooo`;o00001?ooool2o`0000Kooooo0_l0000Aooooo`?o0000
4oooool2o`0000?ooooo0_l0000Dooooo`;o00001Oooool2o`0000;ooooo1?l0000>ooooo`?o0000
3oooool2o`0006Kooooo000Looooo`03o`000?oooooooooo05_ooooo0_l00003ooooo`?o00000ooo
ool2o`0000Kooooo0_l0000Hooooo`;o00003Oooool3o`0000;ooooo0_l0000Gooooo`;o000000?o
ooooo`000?l000000oooool2o`0000Oooooo0_l0000Iooooo`;o00001_ooool2o`0005kooooo000L
ooooo`;o0000H?ooool6o`0000[ooooo0_l0000Booooo`;o00000oooool2o`0000kooooo0_l0000K
ooooo`;o000000?oooooo`000?l000000oooool2o`0000Oooooo0_l00009ooooo`;o00001?ooool2
o`00013ooooo0_l0001Nooooo`007?ooool00ol0003oooooooooo`1Oooooo`;o00000_ooool2o`00
00[ooooo0_l0000;ooooo`;o00001Oooool2o`0001?ooooo0_l00007ooooo`;o00004_ooool3o`00
01Kooooo0_l000000ooooooo0000o`000004ooooo`;o00001Oooool2o`000004ooooool0003o0000
o`0000?ooooo0ol0001Oooooo`007?ooool00ol0003oooooooooo`1dooooo`;o00000_ooool2o`00
00;ooooo0_l00004ooooo`?o00005?ooool2o`0000Kooooo0_l0000Booooo`?o00000oooool2o`00
00Cooooo0_l00005ooooo`;o00001?ooool2o`0000kooooo0_l000001?oooooo0000o`000?l00003
ooooo`?o0000Goooool001cooooo00?o0000ooooooooool0J?ooool4o`0000Sooooo0_l00002oooo
o`;o00002?ooool4o`0001?ooooo0_l00006ooooo`;o000000?oooooo`000?l000005Oooool2o`00
00Cooooo0_l00002ooooo`;o000000?oooooo`000?l000002?ooool2o`0007Gooooo000Looooo`03
o`000?oooooooooo06Sooooo1?l000000ooooooo0000o`00000Eooooo`;o00007_ooool2o`00013o
oooo0_l0000=ooooo`?o00000_ooool2o`0000Gooooo0ol0001eooooo`007?ooool00ol0003ooooo
ooooo`1Mooooo`;o00002?ooool3o`0000?ooooo0ol00016ooooo`;o00000oooool2o`0000Wooooo
0_l00002ooooo`;o00001Oooool3o`0001Cooooo0_l00003ooooo`;o0000F_ooool001cooooo00?o
0000ooooooooool0GOooool2o`0000Sooooo0_l00005ooooo`;o00000oooool4o`0000oooooo0_l0
0007ooooo`;o0000:_ooool2o`0000Gooooo0_l00008ooooo`;o00001?ooool3o`0001?ooooo0_l0
0003ooooo`;o0000F_ooool001cooooo00?o0000ooooooooool0C?ooool2o`0001kooooo0_l00005
ooooo`Co00003oooool2o`0000Kooooo0ol0000?ooooo`;o00006Oooool2o`0000Gooooo0_l00004
ooooo`;o00000_ooool2o`0000Gooooo0ol0000=ooooo`;o0000I?ooool001cooooo00?o0000oooo
ooooool0C?ooool2o`0000[ooooo0_l0000:ooooo`;o00001_ooool2o`00023ooooo0_l0000@oooo
o`;o00005Oooool2o`0000;ooooo0_l0000;ooooo`;o00002_ooool2o`0000gooooo0_l0001Toooo
o`007?ooool00ol0003oooooooooo`1Hooooo`;o00002_ooool2o`00057ooooo0_l0000Looooo`;o
00005oooool2o`0000?ooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`19ooooo`;o0000
7_ooool2o`0001Sooooo0_l00007ooooo`Go00000_ooool2o`0000gooooo0_l0000Cooooo`;o0000
4?ooool2o`0000[ooooo0_l0000Gooooo`;o00000oooool3o`0005?ooooo000Looooo`03o`000?oo
oooooooo04Wooooo0_l0000:ooooo`;o00004_ooool2o`0001Sooooo0_l00007ooooo`Go000000Co
ooooo`000?l0003o00003Oooool2o`0001?ooooo0_l00007ooooo`;o00001oooool2o`0000cooooo
0_l0000Kooooo`;o0000Doooool001cooooo00?o0000ooooooooool0EOooool2o`0000;ooooo0_l0
000/ooooo`Co000000?oooooo`000?l000001?ooool4o`0000[ooooo0_l0000Gooooo`;o00000ooo
ool4o`0000Oooooo0_l0000;ooooo`?o00003oooool2o`0000?ooooo0_l0001Jooooo`007?ooool0
0ol0003oooooooooo`1Booooo`;o00001Oooool2o`0000Oooooo0_l0000Sooooo`Co00002Oooool2
o`0000[ooooo0_l0000Gooooo`?o00000_ooool2o`0000Sooooo0ol00003ooooo`;o000000?ooooo
o`000?l000000oooool2o`0000[ooooo0_l00004ooooo`;o000000?oooooo`000?l000000_l00006
ooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0D_ooool2o`0000kooooo0_l0000Woooo
o`;o0000;Oooool3o`0000Gooooo0_l00004ooooo`?o00000oooool2o`000003ooooool0003o0000
00oooooo0_l00006ooooo`?o00001_ooool4o`0000Cooooo0_l0001<ooooo`007?ooool00ol0003o
ooooooooo`1<ooooo`?o0000??ooool2o`0000Sooooo0ol0000Oooooo`;o000000Coooooo`000?l0
003o00001Oooool2o`0000Gooooo1?l0000Mooooo`;o000000?oooooo`000?l000001?ooool2o`00
00Kooooo0_l0001<ooooo`007?ooool2o`0004gooooo0ol0000jooooo`Oo00000oooool5o`0001oo
oooo0_l000000ooooooo0000o`00000;ooooo`;o00000_ooool2o`0000[ooooo1?l0000@ooooo`Co
00002oooool2o`0004gooooo000Looooo`03o`000?oooooooooo04_ooooo0_l0000<ooooo`;o0000
;_ooool=o`000003ooooool0003o000001kooooo0_l000000ooooooo0000o`000008ooooo`;o0000
00?oooooo`000?l000000_l0000<ooooo`Co00002oooool2o`0000?ooooo0_l0000=ooooo`;o0000
COooool001cooooo00?o0000ooooooooool0Boooool4o`0000[ooooo0_l00002ooooo`;o00008_oo
ool4o`0000Gooooo2Ol000001?oooooo0000o`000?ooool2o`0001[ooooo0_l00002ooooo`;o0000
2oooool2o`0000;ooooo0ol0000Kooooo`;o0000HOooool001cooooo00?o0000ooooooooool0COoo
ool2o`0000Wooooo0_l00003ooooo`;o00008_ooool6o`000003ooooool0003o000000So00000_oo
ool2o`0001cooooo0ol00007ooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`;o0000
1?ooool2o`0000Wooooo0_l0000=ooooo`;o0000G_ooool001cooooo00?o0000ooooooooool0F?oo
ool2o`0002Oooooo0_l000000ooooooo0000o`000004o`000003ooooool0003o000000Ko000000?o
ooooo`000?l000001?l00004ooooo`;o00004_ooool2o`0000Sooooo0_l00005ooooo`;o000000Go
ooooo`000?l0003o0000ooooo`03o`0000;ooooo0ol00008ooooo`;o00002_ooool2o`000003oooo
ool0003o000005kooooo000Looooo`03o`000?oooooooooo03kooooo0_l0000Hooooo`;o0000:ooo
oolFo`0000?ooooo0_l0000Dooooo`;o00001Oooool4o`0000?ooooo0_l00003ooooo`;o000000?o
ooooo`000?l000001_l0000Dooooo`;o00001Oooool2o`0000_ooooo0_l0001=ooooo`007?ooool0
0ol0003oooooooooo`0nooooo`;o00006?ooool2o`0000Cooooo0_l0000Hooooo`;o00002_oooolG
o`0000?ooooo0_l0000Dooooo`;o00001Oooool4o`000003ooooool0003o000001;o00001_ooool2
o`0000gooooo0_l00002ooooo`;o00001_ooool2o`0000?ooooo0_l00003ooooo`;o0000B?ooool0
01cooooo00?o0000ooooooooool0Aoooool2o`0001?ooooo1?l0000Gooooo`Co00000ooooolKo`00
0003ooooool0003o000000;ooooo0_l0000?ooooo`;o00001_ooool2o`0000;ooooo0_l00003oooo
o`[o00001Oooool5o`0000Kooooo0_l0000=ooooo`;o00001oooool2o`000004ooooool0003o0000
o`0000Kooooo0ol00018ooooo`007?ooool00ol0003oooooooooo`17ooooo`;o00004oooool2o`00
01Kooooo0_l000000ooooooo0000o`000002o`0000?ooooo6Ol00003ooooo`;o00004oooool2o`00
00Kooooo0_l00004ooooo`Ko000000?oooooo`000?l000001_l000000ooooooo0000o`000006o`00
01Kooooo0_l00003ooooo`Co00000_ooool2o`0000Kooooo0_l00019ooooo`007?ooool00ol0003o
ooooooooo`1:ooooo`;o00004_ooool2o`0000Kooooo0_l0000<ooooo`;o00002?ooool2o`000003
ooooool0003o000001Go00000_ooool4o`0001Wooooo0_l00004oooooaCo00000_ooool4o`0001Co
oooo0_l00003ooooo`;o0000Eoooool001cooooo00?o0000ooooooooool0B_ooool2o`0000Gooooo
0_l0000;ooooo`;o00001_ooool2o`0001?ooooo0_l000000ooooooo0000o`00000Io`000003oooo
ool0003o000000;o00006ooooolHo`0000Cooooo0_l0000Iooooo`;o00000oooool2o`0005;ooooo
000Looooo`03o`000?oooooooooo04Cooooo0_l000000ooooooo0000o`000008ooooo`;o00002ooo
ool2o`0001[ooooo0ol000000ooooooo0000o`00000Ko`0000?ooooo0_l0000Aooooo`;o00001_oo
oolIo`0000;ooooo1?l0000Hooooo`;o00000oooool2o`0000Kooooo0_l0001:ooooo`007?ooool0
0ol0003oooooooooo`14ooooo`;o000000?oooooo`000?l000004oooool4o`0001Gooooo0_l00003
ooooo`;o000000?oooooo`000?l000007?l00002ooooo`?o00003Oooool2o`0000;ooooo0_l00003
ooooo`?o00000_oooolGo`0000;ooooo1Ol00009ooooo`;o00002?ooool2o`0000;ooooo0_l00003
ooooo`;o00001?ooool4o`0000;ooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`1Loooo
o`;o00001_ooool2o`0000Oooooo0_l00006ooooo`;o00000_ooool2o`0000;ooooo7ol000000ooo
oooo0000o`00000>ooooo`;o00001_ooool4o`0000;ooooo5ol00002ooooo`Go00002Oooool2o`00
00Sooooo0_l000000ooooooo0000o`000007ooooo`;o000000?oooooo`000?l000001?ooool2o`00
04Kooooo000Looooo`03o`000?oooooooooo03gooooo0_l0000Uooooo`;o00001oooool2o`0000Ko
oooo0_l00002ooooo`?o000000?oooooo`000?l000007Ol0000Cooooo`;o00001?ooool2o`0000;o
oooo7Ol0000Gooooo`Co00000_ooool2o`0000?ooooo0_l00007ooooo`;o0000A_ooool001cooooo
00?o0000ooooooooool0?Oooool2o`0000Wooooo0_l00008ooooo`;o00001oooool2o`00017ooooo
0_l00003ooooo`Co00000oooool2o`000004ooooool0003o0000o`0000;ooooo6_l000000ooooooo
0000o`00000@ooooo`;o00002?ooool?o`000003ooooool0003o000000Wo00006Oooool2o`0000Co
oooo0_l00006ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000013oooo
o`007?ooool2o`0004Wooooo0_l00008ooooo`;o00000oooool2o`0000;ooooo0_l00009ooooo`;o
00001_ooool2o`0000?ooooo0_l00008oooooaco000000Coooooo`000?l0003ooooo0_l0000;oooo
o`Co00002Oooool2o`000003ooooool0003o000001go00008Oooool3o`000004ooooool0003o0000
ooooo`;o000000?oooooo`000?l00000@oooool001cooooo00?o0000ooooooooool0Eoooool2o`00
00gooooo0_l0000:ooooo`?o00000_ooool2o`0000?ooooo7Ol0000Aooooo`Co00001Oooool2o`00
00;ooooo8_l00007ooooo`;o00004_ooool2o`0000Cooooo0_l00008ooooo`;o00000_ooool2o`00
03oooooo000Looooo`03o`000?oooooooooo05Wooooo0_l00009ooooo`;o00003?ooool3o`0000;o
oooo0ol00002oooooako00003oooool2o`0000;ooooo0_l00004ooooo`;o00000_oooolOo`0000[o
oooo0ol0000;ooooo`;o00001?ooool2o`0000Cooooo0_l000000ooooooo0000o`000005ooooo`?o
000000?oooooo`000?l000000oooool2o`0003[ooooo000Looooo`03o`000?oooooooooo04Gooooo
0_l0000Booooo`;o00002Oooool2o`00017ooooo0ol000000ooooooo0000o`00000Bo`000003oooo
ool0003o000000So00003oooool2o`0000;ooooo0_l00008oooooa[o00000oooool2o`0000_ooooo
0_l0000;ooooo`;o00002_ooool2o`000003ooooool0003o000000Kooooo0_l00006ooooo`;o0000
>_ooool001cooooo00?o0000ooooooooool0AOooool2o`0001Cooooo0_l0000Hooooo`Co00000_oo
oolFo`000004ooooool0003o0000ooooo`Go000000?oooooo`000?l000003_ooool4o`000004oooo
ool0003o0000ooooo`;o00000ooooolJo`0002Cooooo0_l00002ooooo`Co00004Oooool2o`0003So
oooo000Looooo`03o`000?oooooooooo05_ooooo0_l0000Hooooo`Co00000_ooool2o`000003oooo
ool0003o000001?o00000_ooool:o`0000Sooooo1ol00002ooooo`;o000000Coooooo`000?l0003o
00000ooooolCo`000003ooooool0003o000000?o00003_ooool2o`0001Cooooo0_l00003ooooo`?o
00004Oooool2o`0003Sooooo000Looooo`03o`000?oooooooooo06Cooooo0_l00004ooooo`;o0000
2?ooool4o`0000?ooooo0_l000000ooooooo0000o`00000Do`000005ooooool0003o0000o`000?oo
ool00_l00002ooooo`;o00002?ooool5o`0000Kooooo1?l00002ooooo`?o000000?oooooo`000?l0
00000ol000000ooooooo0000o`00000>o`0000kooooo0_l0000Iooooo`?o00001Oooool2o`0000Wo
oooo0_l0000iooooo`007?ooool00ol0003oooooooooo`1Tooooo`;o00000oooool3o`0000Sooooo
1?l00003oooooago000000?oooooo`000?l000003oooool2o`0000Kooooo1?l00002ooooo`;o0000
0_oooolCo`000004ooooool0003o0000ooooo`;o00002oooool2o`0001[ooooo0_l00003ooooo`Co
00002Oooool2o`0003Wooooo000Looooo`03o`000?oooooooooo047ooooo1?l0000Booooo`;o0000
4?ooool2o`0000Oooooo0_l00008oooooa_o00004_ooool3o`000003ooooool0003o000000;o0000
00?oooooo`000?l000000_l00002ooooo`;o00000_oooolBo`0000;ooooo0_l000000ooooooo0000
o`00000;ooooo`;o00007oooool5o`0004?ooooo000Looooo`03o`000?oooooooooo047ooooo1?l0
000Booooo`;o00006Oooool2o`0000Gooooo0_l000000ooooooo0000o`00000Fo`00013ooooo0_l0
0002ooooo`?o00000_ooool4o`0000_ooooo5?l0000>ooooo`?o00006_ooool2o`0000Kooooo0ol0
0007ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0@?ooool2o`0000oooooo0_l0000C
ooooo`?o00001?ooool2o`0000?ooooo0_l00005ooooo`;o00000_oooolGo`00013ooooo0_l00002
ooooo`;o00000oooool2o`0000?ooooo0_l00008ooooo`;o000000?oooooo`000?l000000oooool6
o`000003ooooool0003o000000Go00003?ooool3o`0001Sooooo1?l000000ooooooo0000o`00000=
ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0@?ooool2o`0000?ooooo0_l0000:oooo
o`;o00003?ooool2o`0000Gooooo0ol000001?oooooo0000o`000?ooool2o`0000?ooooo0_l00002
ooooo`Go000000?oooooo`000?l000000_l00005ooooo`Ko00000_ooool2o`000004ooooool0003o
0000o`00017ooooo1_l00002ooooo`;o00001?ooool4o`0000Wooooo0_l00003ooooo`_o000000?o
ooooo`000?l000009oooool2o`0000;ooooo0ol00019ooooo`007?ooool00ol0003oooooooooo`15
ooooo`;o00006?ooool3o`000003ooooool0003o000000Oo00000oooool3o`0000Cooooo1?l00002
ooooo`?o00003_ooool2o`000003ooooool0003o000000gooooo0_l000000ooooooo0000o`000006
o`0000;ooooo0_l00006ooooo`?o00001oooool3o`0000?ooooo0_l00003ooooo`;o00000_ooool2
o`000003ooooool0003o000002_ooooo1?l00008ooooo`;o0000?_ooool001cooooo00?o0000oooo
ooooool0;oooool2o`00027ooooo0_l00004ooooo`;o000000Goooooo`000?l0003o0000ooooo`0>
o`0000;ooooo0ol00005ooooo`?o00004Oooool2o`0000?ooooo0_l0000=ooooo`;o000000?ooooo
o`000?l000000_l00004ooooo`Co00001oooool2o`0000Oooooo0_l0000:ooooo`;o0000<_ooool3
o`0000Sooooo0_l0000nooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0;oooool2o`0000gooooo0_l0
000Aooooo`?o00001?ooool6o`000003ooooool0003o000000ko000000Coooooo`000?l0003o0000
1?ooool2o`0001;ooooo0_l0000Aooooo`;o00002_ooool4o`0000Gooooo0_l0000Aooooo`;o0000
0_ooool2o`000003ooooool0003o000002cooooo0_l000000ooooooo0000o`00000:ooooo`;o0000
0_ooool2o`0003Wooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0>_ooool2o`000004ooooool0003o0000o`00
017ooooo0ol00005oooooa7o000000?oooooo`000?l000002Ol000000ooooooo0000o`000002oooo
o`;o00001oooool2o`0001Oooooo1?l00002ooooo`;o00001Oooool4o`0000;ooooo0_l000000ooo
oooo0000o`00000Aooooo`;o00001Oooool2o`0000Sooooo0_l000001?oooooo0000o`000?ooool2
o`0001Wooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool2o`0000Gooooo0_l00002
ooooo`;o0000>Oooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool5o`00
00Kooooo00?o0000ooooooooool0>_ooool2o`000003ooooool0003o000000cooooo0_l0000:oooo
ob7o00000oooool2o`0000Oooooo0_l0000Gooooo`Co00000_ooool2o`0000_ooooo0_l0000=oooo
o`;o00005_ooool2o`000004ooooool0003o0000ooooo`;o00006Oooool2o`0000;ooooo1Ol00002
ooooo`;o00003?ooool2o`0003Kooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`0003[ooooo0_l000000ooooooo0000o`00000<
ooooo`;o00002_oooolLo`0000?ooooo0ol0000Rooooo`;o000000Goooooo`000?l0003o0000oooo
o`02o`0000Cooooo0_l00009ooooo`;o00002_ooool2o`0000;ooooo0_l0000Eooooo`?o00007ooo
ool5o`0000?ooooo0_l000000ooooooo0000o`000008ooooo`;o0000=_ooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool02Oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oo
oooooooo03Cooooo0_l0000Roooooago00000_ooool3o`00027ooooo0_l00002ooooo`;o000000?o
ooooo`000?l000001?ooool3o`0000?ooooo0_l00003ooooo`;o00001?ooool2o`0000Sooooo0_l0
000Fooooo`;o00008?ooool4o`0000?ooooo0_l000000ooooooo0000o`000003o`0003gooooo0000
0ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oMgMgolc<c?l000001oooool0
0ol0003oooooooooo`0dooooo`;o00007?ooool2o`000004ooooool0003o0000oooooago00000ooo
ool2o`0002?ooooo0_l00009ooooo`?o00000oooool2o`0000Wooooo0_l00003ooooo`;o00005Ooo
ool2o`0000Cooooo0_l00004ooooo`?o00006Oooool2o`0000[ooooo0ol0000mooooo`0000Kooooo
ogMgMonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0
??ooool2o`0001Cooooo0_l000000ooooooo0000o`00000Mo`0002Wooooo0_l00009ooooo`Go0000
1?ooool2o`0000Cooooo0_l00004ooooo`?o00005Oooool2o`0000Cooooo0ol00003ooooo`?o0000
00?oooooo`000?l000005oooool4o`0000Oooooo1?l0000looooo`0000Koooooonk^k_lb<S;o0000
oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0??ooool2o`0001Oo
oooo7ol00006ooooo`;o00007oooool2o`0000Wooooo0ol00002ooooo`Wo00000oooool2o`0000Co
oooo0_l0000Eooooo`Co000000Coooooo`000?l0003ooooo0_l00007ooooo`;o00005Oooool6o`00
00Wooooo0_l00006ooooo`;o0000=?ooool001cooooo00?o0000ooooooooool0:_ooool2o`00023o
oooo0_l00002ooooo`;o00000oooool2o`0000?ooooo6?l00002ooooo`Co00000_ooool2o`0001Wo
oooo0_l00003ooooo`?o00001oooool6o`0000;ooooo2?l00006ooooo`;o00006?ooool4o`000003
ooooool0003o000000Wooooo0_l0000Dooooo`Oo00001Oooool2o`0000_ooooo0_l0000dooooo`00
7?ooool00ol0003oooooooooo`0Zooooo`;o00006Oooool2o`0000?ooooo2?l00006oooooa_o0000
00?oooooo`000?l000000_l000001?oooooo0000o`000?l0000Iooooo`;o00000_ooool3o`0000So
oooo0_l00002ooooo`;o00000oooool5o`0000Sooooo0_l000000ooooooo0000o`00000Uooooo`;o
00005?ooool2o`0000;ooooo0ol00004ooooo`?o00000oooool2o`0003cooooo000Looooo`03o`00
0?oooooooooo02kooooo0_l00008ooooo`;o00002oooool2o`0000?ooooo0ol000000ooooooo0000
o`000003o`0000Gooooo6ol00004ooooo`Go00005oooool2o`0000Cooooo0_l0000Cooooo`Go0000
00?oooooo`000?l000001oooool2o`00023ooooo0_l00003ooooo`;o00006oooool2o`0000;ooooo
0_l00004ooooo`;o0000??ooool001cooooo00?o0000ooooooooool0;_ooool2o`0000Sooooo0_l0
000Aooooo`;o000000?oooooo`000?l000000ol00005oooooaWo00001_ooool2o`0001[ooooo0_l0
0002ooooo`;o00004_ooool2o`0000;ooooo1?l000000ooooooo0000o`00000:ooooo`;o00006Ooo
ool2o`0000;ooooo0_l0000Pooooo`;o00004_ooool2o`0003;ooooo000Looooo`03o`000?oooooo
oooo04Wooooo0_l00003ooooo`Go00001Oooool3o`0000;ooooo5?l000000ooooooo0000o`00000S
ooooo`;o00004_ooool2o`0000;ooooo0ol0000>ooooo`;o00006Oooool2o`0001Wooooo0_l0000M
ooooo`;o0000<_ooool001cooooo00?o0000ooooooooool0@oooool2o`0000Cooooo1ol00002oooo
o`;o00001?ooool4o`000003ooooool0003o0000013o00000oooool4o`0001?ooooo0_l0000<oooo
o`?o00002oooool2o`0000Sooooo0ol00002ooooo`;o0000:oooool2o`0001?ooooo0ol0000Eoooo
o`;o00001Oooool2o`0003;ooooo000Looooo`03o`000?oooooooooo04?ooooo0_l00005ooooo`[o
00001?ooool4o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000002_l00005oooo
o`;o00004oooool2o`0000cooooo0ol0000;ooooo`;o00000oooool2o`0000?ooooo1ol0000Xoooo
o`;o000000?oooooo`000?l000000_l0000Booooo`?o00002Oooool3o`0000;ooooo1Ol000000ooo
oooo0000o`000005ooooo`;o0000<_ooool001cooooo00?o0000ooooooooool0@oooool2o`0000;o
oooo0_l00004ooooo`Oo00000oooool2o`000003ooooool0003o000000;o00001_ooool2o`000003
ooooool0003o000000;ooooo1?l00007ooooo`;o00000oooool2o`0000;ooooo0_l0000Gooooo`;o
000000?oooooo`000?l000002?ooool2o`0000;ooooo1Ol00002ooooo`Go0000:Oooool3o`0000;o
oooo0_l0000Cooooo`;o00002Oooool3o`0000;ooooo1Ol00008ooooo`;o0000<_ooool001cooooo
00?o0000ooooooooool0;_ooool2o`0001Oooooo0_l00002ooooo`Co00000_ooool2o`0000Cooooo
0_l00003ooooo`;o00001Oooool2o`0000Kooooo1?l00007ooooo`;o00000oooool2o`0000;ooooo
0_l0000:ooooo`;o00002oooool2o`000003ooooool0003o000000cooooo0_l000001Ooooooo0000
o`000?l0003ooooo00;o00001_ooool2o`0002?ooooo1?l0000dooooo`;o0000<_ooool001cooooo
00?o0000ooooooooool0;_ooool2o`0001_ooooo1_l0000Booooo`;o00001_ooool2o`0000Cooooo
1?l000001?oooooo0000o`000?ooool2o`0000Kooooo0_l00007ooooo`?o00008?ooool2o`000003
ooooool0003o000000;ooooo0ol000000ooooooo0000o`000004ooooo`;o00007Oooool2o`0000?o
oooo0_l0000Qooooo`;o00000_ooool2o`0003kooooo000Looooo`03o`000?oooooooooo04Wooooo
0_l000000ooooooo0000o`000003o`0001[ooooo0_l00004ooooo`Co000000Coooooo`000?l0003o
oooo0_l00005ooooo`Co00001_ooool2o`00023ooooo0ol00005ooooo`Co00001?ooool5o`0001ko
oooo0_l000000ooooooo0000o`000002ooooo`;o00006Oooool2o`0000;ooooo0_l00002ooooo`;o
0000?_ooool001cooooo0_l0000cooooo`;o00005Oooool2o`000003ooooool0003o000000;ooooo
0_l0000Booooo`;o00001?ooool4o`0001;ooooo1?l0000Xooooo`?o00001?ooool2o`000004oooo
ool0003o0000o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0000Cooooo0ol0000Doooo
o`;o00001Oooool2o`0000?ooooo0_l0000>ooooo`;o00001?ooool2o`0000Cooooo0_l00010oooo
o`007?ooool00ol0003oooooooooo`0Tooooo`;o00003?ooool2o`0001Kooooo0_l00004ooooo`?o
00002Oooool2o`0000Kooooo0_l00004ooooo`Co00000_ooool4o`0000Oooooo0_l0000=ooooo`;o
000000?oooooo`000?l000002Oooool2o`0001Wooooo0_l00002ooooo`?o00000_ooool3o`0000?o
oooo0_l00004ooooo`?o00007_ooool4o`0000kooooo0_l0000:ooooo`;o000000?oooooo`000?l0
00001oooool2o`0003Cooooo000Looooo`03o`000?oooooooooo02Cooooo0_l0000Tooooo`;o0000
00Coooooo`000?l0003ooooo0ol00009ooooo`;o00004_ooool5o`000004ooooool0003o0000oooo
o`Co00001?ooool2o`0000Oooooo0_l000000ooooooo0000o`000009ooooo`;o00007?ooool4o`00
00;ooooo0ol0000@ooooo`;o00006?ooool2o`0001oooooo0_l00007ooooo`;o0000=?ooool001co
oooo00?o0000ooooooooool0Boooool4o`000004ooooool0003o0000ooooo`;o00003?ooool2o`00
00kooooo1?l000000ooooooo0000o`000003o`0000Kooooo1_l0000Mooooo`;o00003_ooool7o`00
0003ooooool0003o000000Cooooo0_l00002ooooo`Co00001Oooool2o`0001Wooooo0_l00009oooo
o`;o00001_ooool4o`0000_ooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0Yooooo`?o
00005?ooool2o`0000Cooooo1ol000000ooooooo0000o`000002ooooo`?o00003?ooool2o`0001Co
oooo0_l0000:ooooo`Oo00000oooool2o`000003ooooool0003o000000Kooooo0_l000000ooooooo
0000o`000007ooooo`;o00001_ooool2o`0000Cooooo1?l00003ooooo`Go00001?ooool3o`000003
ooooool0003o000000Co00001oooool5o`0000gooooo0ol00002ooooo`;o00002Oooool2o`0000Ko
oooo1?l0000;ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0:Oooool3o`000003oooo
ool0003o0000017ooooo1?l00002ooooo`Go00000oooool2o`0000;ooooo0_l0000:ooooo`;o0000
00?oooooo`000?l000000_l0000Pooooo`Go00000_ooool3o`000003ooooool0003o000000Cooooo
1ol0000?ooooo`;o00001?ooool7o`000004ooooool0003o0000o`0000Kooooo0_l00002ooooo`Go
00001_ooool6o`0000gooooo0ol00005ooooo`Go00004oooool2o`0004;ooooo000Looooo`03o`00
0?oooooooooo02Wooooo0_l00002ooooo`;o00004oooool2o`0000Cooooo0_l0000Dooooo`;o0000
0oooool4o`0002Gooooo1_l00004ooooo`;o00000_ooool2o`0001?ooooo0_l000000ooooooo0000
o`000005o`000003ooooool0003o000000?o00000_ooool2o`0000oooooo0_l0000Iooooo`Oo0000
4Oooool2o`0000Cooooo1?l0000jooooo`007?ooool00ol0003oooooooooo`0Yooooo`;o00005_oo
ool2o`0000Gooooo0_l0000Dooooo`;o00001Oooool2o`0000_ooooo0_l00008ooooo`?o000000?o
ooooo`000?l000002oooool5o`0000;ooooo1Ol0000;ooooo`;o00002Oooool5o`0000Kooooo1Ol0
0002ooooo`;o00000oooool4o`0000;ooooo0_l00002ooooo`;o00006oooool2o`0000?ooooo0_l0
000<ooooo`;o00002Oooool4o`0003[ooooo000Looooo`03o`000?oooooooooo02Wooooo0_l0000F
ooooo`;o00000oooool2o`0001?ooooo0_l000000ooooooo0000o`00000Booooo`;o00001_ooool5
o`000003ooooool0003o000000_ooooo0_l00005ooooo`Oo00000_ooool2o`0000Gooooo0_l00006
ooooo`;o00000oooool4o`0000Gooooo1Ol00002ooooo`;o00000_ooool5o`0000;ooooo0_l00002
ooooo`;o00007oooool2o`0000;ooooo0_l00009ooooo`;o00001Oooool2o`0000;ooooo0_l0000l
ooooo`007?ooool00ol0003oooooooooo`16ooooo`;o00001_ooool2o`0000Gooooo0_l00004oooo
o`;o000000Coooooo`000?l0003ooooo0_l0000Fooooo`?o00007Oooool2o`0000;ooooo0_l00000
0ooooooo0000o`000008ooooo`_o00001?ooool4o`0000?ooooo0ol00002ooooo`?o000000?ooooo
o`000?l000001?ooool2o`0000;ooooo0ol0000Kooooo`Ko00001?ooool2o`0000[ooooo0_l00002
ooooo`;o0000??ooool001cooooo00?o0000ooooooooool0;oooool2o`0001Gooooo0_l00006oooo
o`Co00000oooool3o`0000?ooooo0_l00004ooooo`Ko00001?ooool3o`0000?ooooo0_l00006oooo
o`;o00009Oooool2o`0000Sooooo0_l00002ooooo`So00000oooool6o`000003ooooool0003o0000
00Go00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o0000
00Gooooo0_l0000Cooooo`;o00001_ooool2o`0004cooooo000Looooo`03o`000?oooooooooo02Ko
oooo0_l00007ooooo`;o00003_ooool2o`0000oooooo2?l00003ooooo`;o00001?ooool6o`0000Co
oooo0ol00003ooooo`;o00006Oooool2o`0000Wooooo0_l0000Cooooo`;o000000?oooooo`000?l0
00000_l000000ooooooo0000o`000002o`000003ooooool0003o000000Go00000_ooool5o`000003
ooooool0003o000000Sooooo0_l00003ooooo`?o00001?ooool2o`0001Oooooo0_l0001@ooooo`00
7?ooool00ol0003oooooooooo`0Uooooo`?o00001_ooool2o`0000oooooo0_l00003ooooo`?o0000
2oooool4o`0000?ooooo0_l00004ooooo`;o00000_ooool3o`0000Wooooo0ol0000Jooooo`Co0000
0oooool2o`0000;ooooo1?l000000ooooooo0000o`00000>ooooo`;o00002?ooool7o`000003oooo
ool0003o000000;ooooo0ol00003ooooo`;o00001oooool3o`0000?ooooo0ol0000Mooooo`;o0000
3?ooool2o`0004;ooooo000Looooo`03o`000?oooooooooo02Gooooo0_l000000ooooooo0000o`00
0004ooooo`;o00003oooool2o`0000?ooooo1_l00004ooooo`;o00000_ooool2o`0000?ooooo1?l0
0003ooooo`?o00000oooool2o`0000Wooooo0ol0000=ooooo`;o00002oooool4o`0000?ooooo0_l0
0003ooooo`?o000000?oooooo`000?l000006_ooool2o`0000?ooooo0_l000000ooooooo0000o`00
0002o`0000gooooo1ol00006ooooo`;o00000_ooool2o`0001?ooooo0_l0000<ooooo`Co00002?oo
ool2o`0003Kooooo000Looooo`03o`000?oooooooooo02Sooooo1?l0000Iooooo`Go00001?ooool2
o`0000Oooooo1_l000000ooooooo0000o`00000Oooooo`?o00002_ooool3o`0000Wooooo0_l0000D
ooooo`;o00002?ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000000_l00009
ooooo`;o00000_ooool8o`000003ooooool0003o000000Co00000_ooool2o`0001?ooooo0_l0000;
ooooo`Go00001oooool3o`0003Kooooo000Looooo`03o`000?oooooooooo02[ooooo0_l0000Coooo
o`;o00002?ooool2o`0000?ooooo0_l00009ooooo`Co000000?oooooo`000?l000001Oooool2o`00
01Sooooo0ol0000=ooooo`;o00007Oooool2o`0000Gooooo0_l000001?oooooo0000o`000?ooool4
o`000004ooooool0003o0000o`0000[ooooo0_l00008ooooo`So00003Oooool2o`0001Kooooo1_l0
0006ooooo`;o0000=oooool001cooooo0_l00010ooooo`?o00000oooool3o`000003ooooool0003o
000000kooooo0ol00009ooooo`;o000000?oooooo`000?l000005Oooool2o`0000kooooo0_l00000
0ooooooo0000o`00000Fooooo`;o00002Oooool2o`000003ooooool0003o000000Ko000000?ooooo
o`000?l000003oooool2o`0000?ooooo2ol000000ooooooo0000o`000007ooooo`;o00005oooool2
o`000003ooooool0003o000000Cooooo0ol000000ooooooo0000o`00000eooooo`007?ooool00ol0
003oooooooooo`10ooooo`;o000000?oooooo`000?l000000ol000000ooooooo0000o`00000>oooo
o`;o00002_ooool5o`0002Sooooo0_l0000;ooooo`;o00002Oooool2o`0000gooooo1?l000001?oo
oooo0000o`000?ooool2o`0000_ooooo0_l00002ooooo`;o00000oooool;o`000003ooooool0003o
000000Oooooo0_l0000;ooooo`Co00004Oooool3o`000003ooooool0003o000003Gooooo000Loooo
o`03o`000?oooooooooo02Cooooo1?l0000Kooooo`?o00000_ooool3o`00013ooooo1?l00006oooo
o`Co00002oooool2o`0000Gooooo0_l0000Dooooo`;o000000?oooooo`000?l000002Oooool2o`00
00?ooooo0_l00009ooooo`;o00001?ooool2o`0000;ooooo0_l0000Cooooo`;o00001_ooool:o`00
01Wooooo1?l0000;ooooo`;o00002?ooool2o`0003Gooooo000Looooo`03o`000?oooooooooo02Co
oooo1?l0000Looooo`;o000000Coooooo`000?l0003o00004?ooool7o`0001;ooooo0ol00005oooo
o`;o00001oooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`Go00003_ooool2o`00
00?ooooo0_l000001?oooooo0000o`000?ooool2o`0000Cooooo0ol00002ooooo`Co00005oooool;
o`0001;ooooo0_l0000=ooooo`;o00000oooool4o`0000Sooooo0_l0000eooooo`007?ooool00ol0
003oooooooooo`14ooooo`;o000000?oooooo`000?l000000_ooool2o`0000gooooo0_l000000ooo
oooo0000o`000002o`0001;ooooo1?l0000=ooooo`;o000000?oooooo`000?l000000_ooool2o`00
00;ooooo0_l000000ooooooo0000o`000004ooooo`;o00001?ooool2o`0000Wooooo0_l000000ooo
oooo0000o`000003o`0000Gooooo0ol000000ooooooo0000o`000002o`0001Oooooo1Ol000000ooo
oooo0000o`000003o`0001;ooooo0_l00004ooooo`;o00001oooool2o`0000?ooooo0_l00002oooo
o`;o00001Oooool2o`0003Kooooo000Looooo`03o`000?oooooooooo04Gooooo0_l00004ooooo`;o
00001oooool2o`0000_ooooo0_l0000<ooooo`;o00000_ooool6o`000004ooooool0003o0000oooo
o`Go00000oooool3o`0000?ooooo0_l00002ooooo`;o00001oooool2o`0000?ooooo0ol0000<oooo
o`Go00001_ooool2o`0000;ooooo1Ol0000Eooooo`_o00002oooool2o`0000_ooooo0_l00004oooo
o`;o00002_ooool2o`0000Gooooo0_l0000fooooo`007?ooool00ol0003oooooooooo`0Vooooo`;o
00007Oooool3o`0000Kooooo0_l00004ooooo`;o00001?ooool4o`0000?ooooo0_l00002ooooo`;o
000000?oooooo`000?l000000_l00003ooooo`;o000000?oooooo`000?l000003ol00002ooooo`?o
00000oooool2o`00013ooooo0_l00005ooooo`;o00001_ooool2o`0000oooooo0ol0000Aooooo`;o
00000_ooool;o`0000_ooooo0_l0000:ooooo`;o00001Oooool3o`0000;ooooo0_l0000;ooooo`;o
0000=oooool001cooooo00?o0000ooooooooool09_ooool2o`0001kooooo0_l00006ooooo`;o0000
2?ooool9o`0000Cooooo0_l000000ooooooo0000o`000003o`0000Cooooo0ol000000ooooooo0000
o`000003o`000003ooooool0003o000000;ooooo1?l00005ooooo`;o00006_ooool2o`0000Cooooo
0_l00003ooooo`;o00001oooool2o`0001Oooooo3ol0000Eooooo`Co00001_ooool7o`0000Kooooo
0_l00002ooooo`;o0000=oooool001cooooo00?o0000ooooooooool08Oooool2o`0000Oooooo0_l0
000Jooooo`;o00004?ooool2o`0000Cooooo0ol00007ooooo`;o000000?oooooo`000?l000001?oo
ool8o`0000Oooooo0_l00004ooooo`Co00004_ooool2o`0000cooooo0_l000000ooooooo0000o`00
0002o`0000Oooooo0_l00004ooooo`;o00000_ooool2o`0000kooooo3_l00009ooooo`;o00001Ooo
ool2o`0000?ooooo1Ol00006ooooo`Oo00001Oooool2o`0003_ooooo000Looooo`03o`000?oooooo
oooo027ooooo0_l00007ooooo`;o00006oooool2o`0000;ooooo0_l00006ooooo`;o00001Oooool2
o`0000Gooooo0_l00005ooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`Co00001Ooo
ool2o`000003ooooool0003o000000;o00000_ooool2o`0000?ooooo0_l0000?ooooo`;o00003ooo
ool2o`0000Wooooo0_l00004ooooo`;o00000_ooool2o`0000;ooooo0_l0000;ooooo`ko00002?oo
ool2o`0000Gooooo0_l00003ooooo`Go00001oooool3o`000003ooooool0003o000000Sooooo0_l0
000hooooo`007?ooool00ol0003oooooooooo`15ooooo`Co00000_ooool2o`0000Kooooo0ol00004
ooooo`Ko000000?oooooo`000?l000002?ooool2o`000004ooooool0003o0000o`0000Gooooo0_l0
0004ooooo`?o00000oooool2o`0000Oooooo0_l00008ooooo`;o00005_ooool2o`0000Sooooo0_l0
000=ooooo`;o00003?ooool=o`0000Sooooo0_l00007ooooo`Wo00004oooool3o`0003Sooooo000L
ooooo`03o`000?oooooooooo02Wooooo0_l0000Eooooo`;o00000oooool2o`000003ooooool0003o
000000[ooooo0_l00005ooooo`Go00001oooool3o`000003ooooool0003o000000;ooooo0_l0000;
ooooo`Ko00003Oooool2o`0000Cooooo0_l0000Kooooo`;o00000oooool3o`0001Oooooo0_l00002
ooooo`co00001_ooool4o`0000Oooooo1_l000000ooooooo0000o`000005ooooo`;o000000?ooooo
o`000?l000002Oooool2o`0003Wooooo000Looooo`03o`000?oooooooooo027ooooo0_l00006oooo
o`;o00005Oooool2o`0000Kooooo0_l0000Dooooo`;o00001oooool4o`000004ooooool0003o0000
ooooo`;o00003Oooool4o`000004ooooool0003o0000ooooo`;o00001oooool5o`000003ooooool0
003o000001_ooooo1?l00002ooooo`?o00001?ooool3o`0000oooooo0_l00002ooooo`So00000_oo
ool5o`000003ooooool0003o000000;o00001oooool8o`0000Sooooo1Ol00002ooooo`;o000000?o
ooooo`000?l00000?Oooool001cooooo00?o0000ooooooooool08Oooool2o`00023ooooo0_l00003
ooooo`;o00007oooool5o`000003ooooool0003o000000Wooooo0ol00006ooooo`;o000000?ooooo
o`000?l000002?ooool6o`0001cooooo1?l00003ooooo`;o00001?ooool3o`000003ooooool0003o
0000013ooooo2?l00003ooooo`Co000000?oooooo`000?l000002?ooool9o`0000Wooooo0_l00004
ooooo`Go0000?Oooool001cooooo00?o0000ooooooooool08oooool2o`0001cooooo1?l00004oooo
o`;o00004_ooool3o`0000Wooooo0ol00002ooooo`?o00001_ooool2o`000003ooooool0003o0000
00;o00001?ooool3o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`Ko00000oooool2o`00
00?ooooo0_l00009ooooo`;o00001oooool2o`0000Gooooo0_l00004ooooo`;o00000_ooool2o`00
00Kooooo0_l00009ooooo`Co00000oooool2o`000004ooooool0003o0000o`0000cooooo0_l00002
ooooo`Co00002Oooool4o`0000Gooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0Soooo
o`;o00007?ooool2o`0000Kooooo0_l00006ooooo`;o00002_ooool3o`0000Cooooo0_l00003oooo
o`;o00000oooool2o`0000Oooooo0_l000000ooooooo0000o`000004o`0000;ooooo0_l00005oooo
o`Go00000oooool4o`0000Cooooo0_l00003ooooo`;o00002?ooool3o`0000_ooooo0_l000000ooo
oooo0000o`00000@ooooo`;o00001oooool5o`0000;ooooo1?l0000Cooooo`Go00001oooool6o`00
00Gooooo0_l0000nooooo`007?ooool2o`0004Gooooo0_l00003ooooo`;o00001?ooool4o`00017o
oooo0_l00003ooooo`;o00001_ooool2o`0000Oooooo1_l000001?oooooo0000o`000?ooool2o`00
00?ooooo1?l00005ooooo`Co00001?ooool2o`000003ooooool0003o000000?ooooo0_l00004oooo
o`;o00002Oooool2o`000003ooooool0003o000000;ooooo0_l0000Booooo`;o00001?ooool:o`00
01?ooooo1_l00002ooooo`;o00000oooool2o`0004Wooooo000Looooo`03o`000?oooooooooo02go
oooo0_l0000Dooooo`?o00001_ooool2o`000004ooooool0003o0000ooooo`Co00002Oooool2o`00
013ooooo0_l00003ooooo`;o00001Oooool2o`000003ooooool0003o000000Ko000000?oooooo`00
0?l000001_l00002ooooo`Go00000_ooool2o`000004ooooool0003o0000o`0000;ooooo0_l0000?
ooooo`;o00000_ooool2o`000003ooooool0003o000000Oooooo0_l00004ooooo`;o00000oooool2
o`0000Wooooo1?l0000Dooooo`Ko00000_ooool2o`0004kooooo000Looooo`03o`000?oooooooooo
01cooooo0_l0000?ooooo`;o00005?ooool3o`0000;ooooo0_l00002ooooo`;o00000_ooool6o`00
00Wooooo0_l0000Dooooo`?o00000_ooool2o`000003ooooool0003o000001?o000000?oooooo`00
0?l000000ol00006ooooo`;o00001?ooool2o`0000kooooo1Ol00004ooooo`;o00000_ooool4o`00
00Cooooo0ol0000?ooooo`;o00000oooool2o`0000gooooo0_l00004ooooo`;o0000D_ooool001co
oooo00?o0000ooooooooool07?ooool2o`0002[ooooo1?l00004ooooo`;o00003Oooool2o`0001Co
oooo0_l00003oooooa?o000000?oooooo`000?l000000_l00004ooooo`?o000000?oooooo`000?l0
00001?l00004ooooo`;o00003?ooool6o`0000Gooooo0_l00002ooooo`Co00001?ooool3o`0001Co
oooo0_l0000<ooooo`?o00001?ooool2o`0001Gooooo0_l0000kooooo`007?ooool00ol0003ooooo
ooooo`0Qooooo`;o00007oooool2o`0000Gooooo0ol00007ooooo`;o00002Oooool2o`0001Gooooo
0_l00003oooooa[o00000_ooool3o`000003ooooool0003o000000Co00000_ooool2o`0000Cooooo
0_l00008ooooo`;o00003oooool2o`0000Cooooo0_l0000:ooooo`;o00004_ooool3o`0000;ooooo
1?l00002ooooo`;o00005_ooool2o`0003_ooooo000Looooo`03o`000?oooooooooo027ooooo0_l0
000Oooooo`;o00000oooool5o`0000Gooooo1?l00008ooooo`?o00006?oooolLo`000004ooooool0
003o0000o`0000Gooooo0_l00003ooooo`Co00000_ooool2o`0000Cooooo0ol000000ooooooo0000
o`000006ooooo`;o00001Oooool4o`0000Cooooo0_l0000:ooooo`;o00004_ooool3o`0000Cooooo
0_l00002ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0Aoooool2o`0000Sooooo0_l0
000:ooooo`;o00004Oooool2o`0000Cooooo8_l000001?oooooo0000o`000?ooool2o`0000?ooooo
0_l000000ooooooo0000o`000002o`0000Gooooo1ol00006ooooo`;o00000_ooool2o`000003oooo
ool0003o000000gooooo0_l0000Dooooo`Go00001oooool2o`0000_ooooo0_l00018ooooo`007?oo
ool00ol0003oooooooooo`12ooooo`;o00000oooool3o`0000Cooooo1Ol00002ooooo`;o00001_oo
ool2o`00017ooooo0_l00003ooooo`[o00000_ooool>o`0000;ooooo1ol000001?oooooo0000o`00
0?ooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`0000Gooooo0ol000000ooooooo0000
o`00000:ooooo`?o00001oooool2o`0000Oooooo0_l0000;ooooo`;o00001oooool3o`0000Cooooo
1?l000000ooooooo0000o`000008ooooo`;o000000?oooooo`000?l00000B?ooool001cooooo00?o
0000ooooooooool0@_ooool2o`0000?ooooo0ol000001?oooooo0000o`000?ooool5o`0000;ooooo
0_l00005ooooo`?o00002?ooool2o`0000Oooooo0_l00003ooooo`So00000_oooolGo`0000Cooooo
0_l0000:ooooo`;o00000oooool4o`0000_ooooo0_l000000ooooooo0000o`000008ooooo`;o0000
1oooool2o`0000Oooooo0_l00002ooooo`;o00003_ooool6o`0000Wooooo1?l00019ooooo`007?oo
ool00ol0003oooooooooo`15ooooo`;o000000Coooooo`000?l0003ooooo0_l0000?ooooo`?o0000
00?oooooo`000?l000001Oooool2o`000003ooooool0003o000000Cooooo9_l00004ooooo`?o0000
1_ooool2o`000003ooooool0003o000000?ooooo1?l0000;ooooo`;o00005?ooool2o`0000Oooooo
1?l000000ooooooo0000o`00000>ooooo`Go00002Oooool7o`0000?ooooo0_l00011ooooo`007?oo
ool00ol0003oooooooooo`0Sooooo`;o00003Oooool2o`00017ooooo0_l000000ooooooo0000o`00
000Fooooo`;o00002?ooool4o`0000;ooooo9_l000000ooooooo0000o`000004o`0000?ooooo0_l0
00000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l000002_ooool3o`0000Sooooo1?l0
0002ooooo`;o00003_ooool5o`0000kooooo1Ol0000;ooooo`Go00000oooool2o`0000;ooooo0_l0
000mooooo`007?ooool00ol0003oooooooooo`0Sooooo`;o00003Oooool2o`0000oooooo1?l0000D
ooooo`;o00000oooool2o`0000[ooooo0_l00002oooooaoo000000?oooooo`000?l000001?l00000
0ooooooo0000o`000004o`0000?ooooo0_l00006ooooo`;o00001?ooool3o`0000Wooooo0ol00006
ooooo`[o000000Coooooo`000?l0003o00002_ooool5o`0000_ooooo0_l00003ooooo`?o00003?oo
ool2o`000003ooooool0003o000000;ooooo0ol000000ooooooo0000o`00000mooooo`007?ooool0
0ol0003oooooooooo`13ooooo`Co00001Oooool2o`000003ooooool0003o000000[ooooo0_l00003
ooooo`;o00003_ooool[o`0000?ooooo0_l000000ooooooo0000o`000005ooooo`;o00000oooool4
o`0000Gooooo0_l00007ooooo`;o000000Goooooo`000?l0003o0000ooooo`06o`000003ooooool0
003o000000Co00002_ooool3o`0000_ooooo0_l00003ooooo`?o00001oooool2o`0000?ooooo1_l0
0002ooooo`Co0000?_ooool001cooooo00?o0000ooooooooool0@_ooool4o`0000Gooooo0ol00000
0ooooooo0000o`000004ooooo`;o00003Oooool2o`0000Gooooo0_l00002ooooo`;o00000_oooolT
o`000003ooooool0003o000000;o00000_ooool2o`000003ooooool0003o000000?ooooo0_l00004
ooooo`?o000000?oooooo`000?l000001?ooool3o`0000Cooooo1?l000000ooooooo0000o`000003
o`000003ooooool0003o000000Ko000000?oooooo`000?l000000_l00008ooooo`;o00002oooool2
o`0000cooooo1?l00004ooooo`Go00000oooool3o`0003kooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003ooooo
ooooo`0Uooooo`;o00006oooool4o`0000Gooooo0_l00008ooooo`;o00003Oooool2o`0000Gooooo
0_l00002ooooo`;o00000_oooolYo`000004ooooool0003o0000ooooo`;o00000_ooool4o`0000Co
oooo0_l00002ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000;ooooo1_l00003oooo
o`co00000oooool5o`0000;ooooo0_l0000>ooooo`Ko00001?ooool2o`0000;ooooo0_l00006oooo
o`Co0000AOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEE
ogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo02Gooooo0_l0000<ooooo`;o00003_oo
ool5o`0000kooooo0_l00007ooooo`;o00002_ooool2o`0000;ooooo1?l000000ooooooo0000o`00
000To`0000;ooooo0ol000000ooooooo0000o`000002ooooo`?o00001?ooool3o`0000Gooooo0ol0
0004ooooo`?o000000?oooooo`000?l000000_l000000ooooooo0000o`00000Co`0000;ooooo0_l0
0004ooooo`;o00001_ooool8o`0000Cooooo0_l0000:ooooo`Co0000AOooool00003ooooool@413o
oooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool0<oooool2o`0000cooooo2ol0000:ooooo`?o00001_ooool3o`0000gooooo2_l0
00000ooooooo0000o`00000Ko`0000Gooooo0_l00006ooooo`;o00001Oooool3o`0000cooooo6ol0
000;ooooo`;o00000oooool2o`000003ooooool0003o000000?o00002_ooool2o`0000Cooooo0ol0
0019ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9So
oooooiRHV?lQ8B401_ooool3o`00047ooooo1?l00003ooooo`Co00002oooool2o`0000Oooooo0_l0
000Aoooooa[o000000?oooooo`000?l000001ol000000ooooooo0000o`000003ooooo`;o00001?oo
ool3o`0000;ooooo0_l0000=ooooo`;o00000_ooool5o`000003ooooool0003o000000oo000000?o
ooooo`000?l000000_l00008ooooo`;o00000oooool3o`00013ooooo0_l00004ooooo`?o0000BOoo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oEEEEo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0@_ooool3o`0000Kooooo0_l0000Wooooo`Co000000?o
ooooo`000?l000007?l000000ooooooo0000o`000005o`0000Cooooo0_l00003ooooo`;o00002?oo
ool2o`0000?ooooo0_l00002ooooo`Go000000?oooooo`000?l000005?l000000ooooooo0000o`00
0005ooooo`;o00000oooool2o`0000Cooooo0_l000000ooooooo0000o`00001Jooooo`0000?ooooo
oa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000
ooooooooool0=?ooool2o`0000cooooo0ol00006ooooo`;o00004Oooool2o`0000Wooooo0_l00000
0ooooooo0000o`000007ooooob[o00000oooool5o`0000Sooooo0_l000000ooooooo0000o`000002
o`0000;ooooo0_l000000ooooooo0000o`00000Ho`0000?ooooo0ol00003ooooo`;o00001Oooool2
o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`;o00001_ooool2o`0000Kooooo0_l00012
ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o
0000ooooooooool0=?ooool2o`0002Sooooo1?l00007ooooo`;o000000Coooooo`000?l0003o0000
1_oooolYo`0000Cooooo1Ol00008ooooo`?o00000_ooool2o`0000;ooooo0_l00002ooooo`;o0000
00?oooooo`000?l000005ol000000ooooooo0000o`000003ooooo`;o00001Oooool2o`0000cooooo
1?l00006ooooo`;o00001_ooool2o`0004;ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPco
oooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`1Pooooo`;o00002oooool2o`00
00Oooooo8ol00002ooooo`Co00001?ooool2o`0000_ooooo0_l00009ooooo`;o00000_oooolLo`00
00[ooooo0_l00007ooooo`;o00000oooool2o`0000;ooooo0_l0001@ooooo`007?ooool00ol0003o
ooooooooo`12ooooo`;o00006_ooool2o`00013ooooo1?l00002ooooobWo00007?ooool2o`000003
ooooool0003o000000?o000000?oooooo`000?l000004ol0000<ooooo`;o00001oooool2o`0000Co
oooo0_l000000ooooooo0000o`000002o`0004kooooo000Looooo`03o`000?oooooooooo02Sooooo
0_l0000Hooooo`;o00005_ooool2o`0000;ooooo0_l0000>ooooo`So000000?oooooo`000?l00000
1_l000000ooooooo0000o`00000Io`000004ooooool0003o0000o`0001Kooooo0ol00003ooooo`;o
000000?oooooo`000?l000006Ol000000ooooooo0000o`000009ooooo`;o00001oooool2o`0000Co
oooo0_l00003ooooo`;o00001Oooool2o`0004Oooooo000Looooo`03o`000?oooooooooo02Sooooo
0_l0000Eooooo`;o000000?oooooo`000?l000000_l0000Dooooo`;o00003_ooool2o`0000;ooooo
0_l00004oooooako000000Goooooo`000?l0003o0000ooooo`03o`0000;ooooo0_l000000ooooooo
0000o`000009ooooo`;o00002Oooool3o`000003ooooool0003o000000;o000000?oooooo`000?l0
00005?l000000ooooooo0000o`000002o`000003ooooool0003o000001cooooo0_l00006ooooo`;o
0000Aoooool001cooooo00?o0000ooooooooool0:?ooool2o`0001Gooooo0_l000000ooooooo0000
o`000003o`0002?ooooo0_l00008ooooob;o00001Oooool2o`0000;ooooo0_l00009ooooo`;o0000
0oooool4o`0000Kooooo8ol00007ooooo`;o00004_ooool3o`0004oooooo000Looooo`03o`000?oo
oooooooo02Sooooo0_l000000ooooooo0000o`00000;ooooo`;o00002?ooool7o`0001Wooooo0_l0
000?oooooa;o000000?oooooo`000?l000003Ol00002ooooo`Ko000000?oooooo`000?l000003ooo
ool4o`0000Sooooo8Ol00007ooooo`;o00003Oooool2o`0000?ooooo0_l0001@ooooo`007?ooool0
0ol0003oooooooooo`0[ooooo`;o00002oooool2o`0000[ooooo1Ol0000Hooooo`?o00003?oooolU
o`0000;ooooo1?l000000ooooooo0000o`000002o`0000cooooo0_l000001?oooooo0000o`000?l0
0009oooooaoo00006?ooool2o`0000cooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`0h
ooooo`;o00003?ooool2o`0000kooooo0_l000000ooooooo0000o`000006ooooo`?o00003?ooool3
o`000003ooooool0003o000000;o00000_oooolHo`000003ooooool0003o000000;o000000Gooooo
o`000?l0003o0000ooooo`03o`0000Kooooo0_l00005ooooo`;o00000_ooool2o`0000Oooooo0_l0
00000ooooooo0000o`000009o`000003ooooool0003o000000Co000000?oooooo`000?l000001ol0
000Kooooo`;o00002?ooool2o`000003ooooool0003o000004Oooooo000Looooo`03o`000?oooooo
oooo03Sooooo0_l0000Kooooo`?o000000?oooooo`000?l000000_l00005ooooo`Co00003oooool3
o`0000;ooooo4_l000000ooooooo0000o`000003o`0000?ooooo0_l000001?oooooo0000o`000?l0
000:ooooo`?o00001oooool3o`0000?ooooo0_l00002ooooo`;o00000_oooolHo`0001_ooooo0_l0
00000ooooooo0000o`000008ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0D?ooool2
o`0000?ooooo0_l00004ooooo`;o00000oooool2o`0000;ooooo0_l0000<ooooo`;o000000?ooooo
o`000?l000000_l000000ooooooo0000o`00000Eo`0000Gooooo1?l00004ooooo`?o00001Oooool2
o`0000;ooooo0_l00003ooooo`?o00000ooooolAo`000003ooooool0003o000000oo00005oooool3
o`000003ooooool0003o000005Cooooo000Looooo`03o`000?oooooooooo053ooooo0_l00003oooo
o`;o00002Oooool2o`000003ooooool0003o000000gooooo0_l00003ooooo`Oo000000?oooooo`00
0?l000004?l00002ooooo`;o000000?oooooo`000?l000001?l00002ooooo`?o00002Oooool4o`00
00Wooooo0_l000001Ooooooo0000o`000?l0003ooooo00[o000000?oooooo`000?l000003Ol00000
0ooooooo0000o`00000;ooooo`;o00001oooool3o`000004ooooool0003o0000ooooo`;o0000DOoo
ool001cooooo00?o0000ooooooooool0EOooool2o`0000?ooooo0_l00003ooooo`;o000000?ooooo
o`000?l000000_l0000<ooooo`;o00001Oooool6o`000003ooooool0003o000000?o000000?ooooo
o`000?l000002?l000000ooooooo0000o`000002o`000005ooooool0003o0000o`000?ooool00_l0
000:ooooo`;o00001?ooool2o`0000Sooooo0_l00002ooooo`Co000000?oooooo`000?l000002ol0
00000ooooooo0000o`000003o`000003ooooool0003o000000;o000000?oooooo`000?l000000ol0
0002ooooo`;o00001Oooool2o`0000Wooooo0_l00003ooooo`Co0000Coooool001cooooo0_l0000k
ooooo`;o00002Oooool2o`0000Cooooo0_l00004ooooo`;o00000_ooool2o`0000?ooooo0_l00003
ooooo`;o000000?oooooo`000?l000000_l00009ooooo`;o00000oooool2o`0000Cooooo1_l00000
0ooooooo0000o`000008o`000003ooooool0003o000000So000000?oooooo`000?l000003?ooool3
o`0000Sooooo0_l00004ooooo`;o00000_oooolBo`000003ooooool0003o000000Ko00000oooool2
o`000003ooooool0003o000000;ooooo0_l00009ooooo`;o000000?oooooo`000?l000001?l00005
ooooo`;o0000Coooool001cooooo00?o0000ooooooooool0>_ooool3o`0000Sooooo0_l00004oooo
o`;o00001?ooool2o`0000Sooooo0_l00007ooooo`;o00001Oooool2o`0000;ooooo0ol00002oooo
o`;o00001_ooool4o`000003ooooool0003o000000Wo000000?oooooo`000?l000001ol00004oooo
o`;o00002Oooool2o`0000?ooooo1Ol000000ooooooo0000o`00000:oooooaSo00000_ooool2o`00
00Oooooo0_l00005ooooo`;o00000_ooool9o`0000Gooooo0_l0001?ooooo`007?ooool00ol0003o
ooooooooo`0kooooo`;o00007_ooool2o`0000?ooooo0_l00002ooooo`;o00001Oooool2o`0000?o
oooo0_l0000:ooooo`;o000000?oooooo`000?l000005ol00002ooooo`;o00001oooool2o`0000Go
oooo1Ol0000=oooooaSo00000_ooool4o`000003ooooool0003o000000;ooooo0_l00005ooooo`Co
000000?oooooo`000?l000000_l00009ooooo`;o0000Coooool001cooooo00?o0000ooooooooool0
;Oooool2o`00037ooooo0_l00007ooooo`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`Co
00001ooooolIo`0000_ooooo0_l0000Cooooo`Co00000_oooolHo`0000;ooooo1Ol00009ooooo`Co
00004?ooool2o`0004gooooo000Looooo`03o`000?oooooooooo02gooooo0_l0000=ooooo`;o0000
3Oooool2o`0001cooooo0_l000001?oooooo0000o`000?ooool3o`000003ooooool0003o000000?o
00000ooooolCo`0000;ooooo1_l0000=ooooo`;o00000oooool2o`0000kooooo1?l00002oooooaSo
00000oooool3o`0000Oooooo0_l000000ooooooo0000o`00000Booooo`;o0000COooool001cooooo
00?o0000ooooooooool0??ooool3o`0000cooooo0_l00007ooooo`;o00005oooool2o`000004oooo
ool0003o0000ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000002o`000003
ooooool0003o000000co00000_ooool3o`000003ooooool0003o000000gooooo0_l00003ooooo`;o
00004?ooool2o`0000;ooooo1ol000000ooooooo0000o`00000;o`0000?ooooo0_l00002ooooo`;o
00001oooool2o`000003ooooool0003o000000Wooooo0_l0001Fooooo`007?ooool00ol0003ooooo
ooooo`0mooooo`;o00005Oooool2o`0000_ooooo0_l0000:ooooo`;o000000?oooooo`000?l00000
0_l00002ooooo`Co00001oooool<o`0000Wooooo0_l00008ooooo`;o00000oooool2o`0001?ooooo
0_l00007ooooo`?o00001_ooool7o`0000?ooooo0_l0000Iooooo`;o0000E_ooool001cooooo00?o
0000ooooooooool0Aoooool2o`0000Gooooo0_l0000Aooooo`?o000000Coooooo`000?l0003o0000
2?ooool4o`0000Cooooo0_l00007ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o0000
2Oooool2o`0000Oooooo0ol00003ooooo`;o00007?ooool4o`0000Gooooo2Ol0000Fooooo`;o0000
1?ooool2o`0000Kooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`17ooooo`;o00000ooo
ool4o`0001;ooooo0_l000001?oooooo0000o`000?l00004ooooo`;o00000_ooool5o`0000;ooooo
0ol0000@ooooo`Co00003?ooool2o`000003ooooool0003o000000;o00000_ooool2o`00023ooooo
1?l000000ooooooo0000o`00000:o`000003ooooool0003o000000Oooooo0_l00009ooooo`;o0000
1?ooool2o`0000?ooooo0_l000000ooooooo0000o`00001>ooooo`007?ooool00ol0003ooooooooo
o`18ooooo`;o00000_ooool2o`0000oooooo0_l00003ooooo`;o00000_ooool2o`0000Cooooo0_l0
0002ooooo`Go00000_ooool2o`0000;ooooo0ol00008ooooo`;o00000_ooool4o`0000cooooo0_l0
00000ooooooo0000o`000004ooooo`;o00007Oooool7o`000003ooooool0003o000000Co00001?oo
ool2o`000004ooooool0003o0000ooooo`;o00000oooool3o`0000Kooooo0_l0000<ooooo`;o0000
1Oooool3o`0004Wooooo000Looooo`03o`000?oooooooooo04Sooooo0_l00003ooooo`;o00002_oo
ool6o`0000Sooooo0_l0000Booooo`?o000000?oooooo`000?l000000_l00003ooooo`;o00001?oo
ool2o`0000Cooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00004?ooool2o`0000;ooooo
0_l00007ooooo`;o00001oooool5o`000003ooooool0003o000000;o00000_ooool2o`0000[ooooo
0_l00003ooooo`?o00001_ooool2o`0000;ooooo0_l0000?ooooo`?o0000BOooool001cooooo00?o
0000ooooooooool0COooool3o`0000Wooooo1_l00008ooooo`?o00002_ooool2o`0000?ooooo0_l0
00000ooooooo0000o`000007o`0000?ooooo2?l00002ooooo`Ko00000_ooool2o`0000[ooooo0_l0
0004ooooo`?o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o00002?ooool2o`0000?ooooo
1?l00002ooooo`;o000000?oooooo`000?l000000oooool2o`0000Wooooo0ol00005ooooo`;o0000
00?oooooo`000?l00000Foooool001cooooo00?o0000ooooooooool0Boooool2o`000003ooooool0
003o000000Wooooo0_l0000=ooooo`;o00002_ooool2o`000003ooooool0003o000000;o000000?o
ooooo`000?l000000ol00002ooooo`;o00000oooool5o`000003ooooool0003o000000;o000000?o
ooooo`000?l000002Oooool2o`0000Kooooo0_l00005ooooo`;o00001?ooool2o`0000Sooooo0_l0
0004ooooo`;o00001?ooool5o`0000?ooooo0_l00003ooooo`;o00002Oooool3o`0000;ooooo0_l0
00001?oooooo0000o`000?ooool2o`000003ooooool0003o000005Sooooo000Looooo`03o`000?oo
oooooooo04_ooooo0_l000000ooooooo0000o`000008ooooo`;o00007Oooool2o`0000?ooooo2?l0
0007ooooo`;o00000oooool2o`0000cooooo0_l0000Fooooo`?o00001?ooool3o`0000Kooooo2?l0
0004ooooo`;o00003?ooool2o`0000Cooooo0ol00002ooooo`?o000000?oooooo`000?l00000F?oo
ool001cooooo00?o0000ooooooooool0F?ooool2o`0000[ooooo1?l0000Gooooo`Go00006?ooool2
o`0000Gooooo0_l0000Aooooo`?o00001Oooool2o`0000Kooooo1?l00002ooooo`;o00001?ooool2
o`0000cooooo0_l00003ooooo`Co00000_ooool2o`0000[ooooo0_l0001@ooooo`007?ooool00ol0
003oooooooooo`1Tooooo`Co00002_ooool2o`0000_ooooo0_l00005ooooo`;o00005?ooool2o`00
00Gooooo0_l00003ooooo`;o00008?ooool4o`0000Gooooo0_l00006ooooo`;o00002?ooool2o`00
013ooooo0_l0001@ooooo`007?ooool2o`00057ooooo0_l0000:ooooo`;o000000?oooooo`000?l0
00001?ooool2o`0000_ooooo0ol0000;ooooo`;o00001?ooool2o`0000kooooo0_l0000:ooooo`;o
00001?ooool2o`00023ooooo0ol00006ooooo`;o00001_ooool2o`0000Gooooo0_l00002ooooo`;o
00002_ooool2o`0005Gooooo000Looooo`03o`000?oooooooooo053ooooo0_l0000:ooooo`Go0000
1?ooool2o`0000_ooooo1?l00007ooooo`Ko00004Oooool4o`0000Wooooo0ol0000_ooooo`;o0000
3Oooool2o`0000;ooooo0_l0000:ooooo`;o0000EOooool001cooooo00?o0000ooooooooool0E_oo
ool2o`0000Gooooo1_l0000@ooooo`?o00001oooool6o`0000[ooooo0_l00002ooooo`Go00001?oo
ool2o`0000Gooooo0_l0002Vooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00001?ooool2
o`0000Sooooo0ol00007ooooo`;o00001oooool2o`000003ooooool0003o000000Oooooo0_l00007
ooooo`;o00000oooool2o`0000;ooooo0ol00003ooooo`;o000000?oooooo`000?l000009_ooool2
o`0002Sooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00006?ooool3o`00
00Wooooo0_l00002ooooo`Co00001oooool2o`000003ooooool0003o000000Sooooo0_l00003oooo
o`;o00001Oooool2o`00027ooooo0ol0000Xooooo`;o0000Foooool001cooooo00?o0000oooooooo
ool0G_ooool2o`0000_ooooo0_l00002ooooo`;o00001Oooool2o`0000;ooooo1?l00007ooooo`;o
00005oooool2o`00027ooooo0_l0000@ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Wo
oooo0ol0001Oooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o00001?ooool2o`0000Wooooo
0_l00005ooooo`Co00002oooool2o`0004?ooooo0_l00007ooooo`;o000000?oooooo`000?l00000
1?ooool2o`0000Wooooo0ol00003ooooo`;o0000F_ooool001cooooo00?o0000ooooooooool0FOoo
ool2o`0000Wooooo0_l00007ooooo`Co00001_ooool3o`0000cooooo0_l00007ooooo`;o00002?oo
ool2o`0000_ooooo0_l0000Iooooo`;o00001oooool2o`0000Oooooo0_l00004ooooo`;o00002?oo
ool2o`000003ooooool0003o000000Cooooo0ol0001Jooooo`007?ooool00ol0003oooooooooo`0m
ooooo`;o00006_ooool3o`00017ooooo1?l00006ooooo`?o00003?ooool2o`0000?ooooo0_l00002
ooooo`;o00002?ooool2o`0000_ooooo0_l0000Iooooo`?o00004Oooool6o`0000Cooooo1_l00000
0ooooooo0000o`000004ooooo`;o0000Foooool001cooooo00?o0000ooooooooool0?Oooool2o`00
01[ooooo0ol00002ooooo`;o00003Oooool5o`0000Kooooo0_l00002ooooo`;o00003Oooool2o`00
00Oooooo0_l0000@ooooo`;o00006_ooool2o`00017ooooo1?l00002ooooo`;o000000?oooooo`00
0?l000001?l000000ooooooo0000o`00000>ooooo`;o0000D_ooool001cooooo00?o0000oooooooo
ool0G_ooool2o`0000gooooo1Ol00007ooooo`;o000000Coooooo`000?l0003ooooo0_l00007oooo
o`;o000000?oooooo`000?l000001oooool2o`0000oooooo0ol0000Oooooo`;o00002Oooool2o`00
00Cooooo0_l000001?oooooo0000o`000?ooool4o`0000;ooooo0ol0000>ooooo`;o0000D_ooool0
01cooooo00?o0000ooooooooool0I?ooool2o`0000Oooooo0ol00004ooooo`;o00000oooool2o`00
00Cooooo0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o0000013ooooo0_l00006oooo
o`;o00008?ooool3o`0000Sooooo0_l00004ooooo`;o00002_ooool2o`0006?ooooo000Looooo`03
o`000?oooooooooo05cooooo0_l00006ooooo`;o00001Oooool2o`0000Kooooo0ol00002ooooo`;o
00000oooool6o`000003ooooool0003o000000Wooooo0_l0000<ooooo`;o0000:Oooool3o`0007ko
oooo000Looooo`03o`000?oooooooooo043ooooo0_l0000Jooooo`;o00003Oooool2o`0000?ooooo
0_l000000ooooooo0000o`000003ooooo`;o00000oooool2o`000003ooooool0003o000000;o0000
1?ooool5o`0000;ooooo0_l0000_ooooo`;o00001oooool2o`0001Gooooo0_l0001Wooooo`007?oo
ool00ol0003oooooooooo`10ooooo`;o0000;?ooool4o`0000_ooooo0_l00003ooooo`;o00001?oo
ool5o`0001Kooooo0_l0000Kooooo`?o00000_ooool3o`000003ooooool0003o000001Gooooo0_l0
001Wooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o00003Oooool3o`0000;ooooo0_l00009
ooooo`?o00001Oooool3o`0001_ooooo0_l0000Iooooo`;o000000?oooooo`000?l000000_ooool6
o`0000Cooooo0_l00005ooooo`;o00001_ooool2o`0006Wooooo000Looooo`;o0000Goooool4o`00
00Wooooo1?l00003ooooo`;o00002_ooool3o`0000Cooooo1Ol0000dooooo`;o00001oooool4o`00
0004ooooool0003o0000ooooo`;o00001Oooool2o`0000Kooooo0_l0001Yooooo`007?ooool00ol0
003oooooooooo`1Pooooo`;o00002Oooool2o`000003ooooool0003o000000;ooooo0_l0000;oooo
o`?o00000_ooool2o`000004ooooool0003o0000o`0000?ooooo0_l00004ooooo`?o0000;Oooool2
o`0000;ooooo0_l00003ooooo`Co00003Oooool2o`0006[ooooo000Looooo`03o`000?oooooooooo
063ooooo0_l00008ooooo`;o00000_ooool2o`0000;ooooo0_l0000;ooooo`?o00000_ooool2o`00
00Cooooo0_l000000ooooooo0000o`000002ooooo`Go00000oooool4o`0000Kooooo0_l0000Loooo
o`Co00000_ooool2o`0000?ooooo1?l000000ooooooo0000o`00000:ooooo`;o0000J_ooool001co
oooo00?o0000ooooooooool0J_ooool2o`0000Cooooo0_l0000=ooooo`;o00002Oooool4o`0000?o
oooo0_l00006ooooo`Ko00001?ooool2o`0001cooooo0_l00002ooooo`?o00001?ooool7o`0007Ko
oooo000Looooo`03o`000?oooooooooo06[ooooo0_l00004ooooo`;o00001Oooool2o`0001;ooooo
0ol0000?ooooo`;o00009_ooool5o`0000Kooooo0_l00009ooooo`;o0000K?ooool001cooooo00?o
0000ooooooooool0J_ooool2o`0000_ooooo0ol00003ooooo`;o00003_ooool2o`0000Wooooo0_l0
0008ooooo`;o00008Oooool2o`000003ooooool0003o000000gooooo0ol000000ooooooo0000o`00
0006ooooo`;o0000I?ooool001cooooo00?o0000ooooooooool0BOooool2o`0001oooooo0_l00000
0ooooooo0000o`000009ooooo`;o00000oooool2o`0000;ooooo0_l0000:ooooo`;o00001Oooool2
o`0000;ooooo0_l00008ooooo`;o0000<?ooool2o`000004ooooool0003o0000o`0000Wooooo0_l0
001Tooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00007?ooool2o`0000Cooooo0ol00003
ooooo`;o00003?ooool2o`0000Kooooo0_l00009ooooo`;o00002?ooool3o`0002gooooo0_l00004
ooooo`;o0000Loooool001cooooo00?o0000ooooooooool0Boooool2o`0001[ooooo0_l00002oooo
o`Go00000oooool3o`0000Gooooo0_l00004ooooo`;o00001_ooool2o`0000Oooooo0_l0000:oooo
o`?o00005oooool3o`0000_ooooo0_l000000ooooooo0000o`000003ooooo`;o0000NOooool001co
oooo00?o0000ooooooooool0Boooool2o`0001kooooo0ol00006ooooo`;o00001Oooool2o`0000Ko
oooo0_l0000=ooooo`Co00008_ooool3o`0000Cooooo0ol00004ooooo`Go0000O_ooool001cooooo
00?o0000ooooooooool0K_ooool2o`0000Gooooo0_l0000<ooooo`;o00001oooool3o`000003oooo
ool0003o000000;ooooo0_l0000Yooooo`?o00001?ooool5o`0007kooooo000Looooo`03o`000?oo
oooooooo06cooooo1?l00005ooooo`?o00000oooool2o`000003ooooool0003o000000cooooo0ol0
00001?oooooo0000o`000?ooool2o`00037ooooo1Ol0001nooooo`007?ooool00ol0003ooooooooo
o`1/ooooo`;o00002?ooool2o`0000?ooooo0_l000000ooooooo0000o`000008ooooo`;o00001_oo
ool2o`000003ooooool0003o0000033ooooo0_l00022ooooo`007?ooool00ol0003oooooooooo`1A
ooooo`;o00009_ooool6o`0000Wooooo0_l0000Yooooo`;o00001oooool2o`0000Cooooo0_l00000
0ooooooo0000o`000022ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0DOooool2o`0002Kooooo
2?l0000booooo`;o00001Oooool4o`0000Cooooo0_l00025ooooo`0000KoooooogMgMonHV9Sooooo
oiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000oooo
ooooool0O?ooool2o`000003ooooool0003o000000gooooo0_l000000ooooooo0000o`000004o`00
02?ooooo0ol00002ooooo`;o00004oooool2o`0007?ooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
07Kooooo0_l00004ooooo`;o00000_ooool2o`0000cooooo0_l000000ooooooo0000o`000004o`00
027ooooo0_l00005ooooo`;o00001_ooool2o`0000_ooooo0_l0001cooooo`0000?oooooo`000?oo
ool00_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`00
07Kooooo0_l00006ooooo`Co00001_ooool2o`0002kooooo0_l00002ooooo`;o00002Oooool2o`00
00Kooooo0_l0001hooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05
olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`1booooo`;o00002_ooool2o`00
00Sooooo0_l0000Looooo`;o000000?oooooo`000?l000000_ooool2o`0000gooooo0_l0000Aoooo
o`;o0000N?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol@413o
^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0L_ooool2o`0000cooooo0_l0000:oooo
o`;o00006?ooool2o`000003ooooool0003o000000;ooooo0_l00007ooooo`;o0000TOooool00006
oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o
0000ooooooooool0NOooool4o`0000?ooooo0_l0000:ooooo`Co00000_ooool2o`0000Wooooo0_l0
000Gooooo`;o00002oooool2o`0008Cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo
00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo07Wooooo1?l00008ooooo`;o
00001oooool3o`000003ooooool0003o000000Wooooo0_l0000Booooo`?o00001oooool2o`0000Ko
oooo0_l00003ooooo`;o0000Ooooool001cooooo00?o0000ooooooooool0F_ooool2o`0001kooooo
0_l00009ooooo`;o00001?ooool2o`0000;ooooo0_l00003ooooo`;o00001oooool2o`0001;ooooo
0ol00007ooooo`;o00002oooool2o`0007oooooo000Looooo`03o`000?oooooooooo05[ooooo0_l0
000Nooooo`;o00002oooool2o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0000Oooooo0_l0
0005ooooo`;o00005_ooool2o`0000Kooooo0_l00023ooooo`007?ooool00ol0003oooooooooo`27
ooooo`;o00000_ooool2o`0000;ooooo0_l0000:ooooo`Co00001Oooool2o`0001Kooooo0_l00006
ooooo`;o0000Poooool001cooooo00?o0000ooooooooool0GOooool2o`0002cooooo0_l0000>oooo
o`;o00008oooool2o`0008Oooooo000Looooo`03o`000?oooooooooo05gooooo0_l0000Qooooo`;o
00003oooool2o`0001Kooooo0_l0000<ooooo`?o00001_ooool2o`0008Oooooo000Looooo`03o`00
0?oooooooooo083ooooo0_l0000;ooooo`;o00000_ooool2o`0001Kooooo0_l0000<ooooo`?o0000
Soooool001cooooo00?o0000ooooooooool0SOooool2o`0000;ooooo1?l0002dooooo`007?ooool0
0ol0003oooooooooo`2Cooooo`;o00005Oooool2o`0000Cooooo0_l00006ooooo`;o0000Soooool0
01cooooo00?o0000ooooooooool0Voooool3o`0000;ooooo0_l00005ooooo`;o000000?oooooo`00
0?l000001?ooool4o`0000Cooooo0_l0002?ooooo`007?ooool00ol0003oooooooooo`29ooooo`;o
00004?ooool3o`0000;ooooo0_l00005ooooo`;o00002Oooool2o`0000kooooo0_l00025ooooo`00
7?ooool00ol0003oooooooooo`29ooooo`;o0000;Oooool2o`0000Sooooo0_l00025ooooo`007?oo
ool2o`000:cooooo0_l0000;ooooo`;o0000Soooool001cooooo00?o0000ooooooooool0JOooool2
o`00043ooooo0_l0000;ooooo`;o0000Soooool001cooooo00?o0000ooooooooool0JOooool2o`00
04Sooooo0_l00003ooooo`;o0000Soooool001cooooo00?o0000ooooooooool0/oooool2o`0009Co
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0L_ooool2o`000=Gooooo000Looooo`03o`00
0?oooooooooo07;ooooo0_l0003Eooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0NOooool2o`00
0<kooooo000Looooo`03o`000?oooooooooo07Wooooo0_l0003>ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l00021
ooooo`;o0000aoooool001cooooo00?o0000ooooooooool0P?ooool2o`000<Oooooo000Looooo`03
o`000?oooooooooo08Cooooo0_l000000ooooooo0000o`000003ooooo`;o0000^oooool001cooooo
00?o0000ooooooooool0Q?ooool2o`000003ooooool0003o000000?ooooo0_l0002kooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo09;ooooo0_l0002e
ooooo`007?ooool00ol0003oooooooooo`2Booooo`;o0000]Oooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001;ooooo1?l00000
0ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Go
oooo0ol0003ooooood[ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o
0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Doooo
o`03o`000?oooooooooo0?ooooooD_ooool001;ooooo00?oEEEEofIVI_l00000oooooomDooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00YOooool01?l@413o0000o`000?ooool2
o`000003oa0@4?oooooooooo01Kooooo00GoA4A4o`000?l0003o<S8bomgMg@03ooooo`05odA4A?l0
003o0000oc8b<_oMgMd00_ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<093ooooo002Vooooo`05o`00
0?ooooooooooooooool000002Oooool6o`0000gooooo00?oMgMgoc8b<_ooool01Oooool02OmgMgOo
<S8boooooooooooo8B4QoiRHV?ooooooV9RHob4Q8@2@ooooo`00Y_ooool01Ol0003ooooooooooooo
oooo000001gooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo08kooooo002Vooooo`05o`000?ooooooooooooooool000002Oooool6o`0000gooooo
00?oMgMgoc8b<_ooool01Oooool02OmgMgOo<S8boooooooooooo<S8boiRHV?ooooooV9RHoc8b<P2@
ooooo`00Y_ooool01Ol0003oQhN7oooooonYZJWo000001Wooooo00Go0000ob4Q8Ol0003o<S8bolc<
c003ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Oo<c<co0000o`000?l0003oc<c<093o
oooo002Uooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool05oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Cooooo00Go410@okZj^_oooooo^[Zjoa0@402@ooooo`00
a?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00Go0000okZj^_oooooo
^[Zjo`00002@ooooo`00a?ooool4o`0000Cooooo1?l00003ooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT0T?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(564) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.63264 .67164 Mdot
.58575 .65135 Mdot
.45232 .37152 Mdot
.3928 .57381 Mdot
.29524 .3835 Mdot
.46283 .34424 Mdot
.63489 .38293 Mdot
.66058 .35257 Mdot
.45085 .34233 Mdot
.39938 .74987 Mdot
.63547 .35294 Mdot
.36516 .53075 Mdot
.64225 .36965 Mdot
.42109 .59199 Mdot
.63398 .50604 Mdot
.45251 .52347 Mdot
.60147 .61347 Mdot
.31469 .35377 Mdot
.45183 .52223 Mdot
.45647 .36922 Mdot
.3822 .48316 Mdot
.40919 .5978 Mdot
.59288 .62054 Mdot
.41743 .59439 Mdot
.39759 .54829 Mdot
.59558 .64634 Mdot
.62417 .67571 Mdot
.37222 .56548 Mdot
.36712 .60068 Mdot
.64798 .35542 Mdot
.3649 .24185 Mdot
.75014 .72215 Mdot
.35355 .57107 Mdot
.58505 .74096 Mdot
.65953 .34873 Mdot
.66602 .25674 Mdot
.442 .32967 Mdot
.66601 .36499 Mdot
.63692 .34037 Mdot
.63677 .33835 Mdot
.6416 .38899 Mdot
.60007 .6552 Mdot
.59954 .35968 Mdot
.50597 .37804 Mdot
.44156 .56769 Mdot
.72581 .67621 Mdot
.39139 .20614 Mdot
.3698 .57646 Mdot
.64258 .64926 Mdot
.47406 .36488 Mdot
.20798 .56546 Mdot
.66168 .39029 Mdot
.66397 .57321 Mdot
.23996 .77139 Mdot
.641 .35816 Mdot
.38012 .5802 Mdot
.46157 .35927 Mdot
.40213 .58119 Mdot
.38096 .60609 Mdot
.56574 .71678 Mdot
.39858 .6148 Mdot
.34632 .38619 Mdot
.60184 .68439 Mdot
.41505 .34603 Mdot
.45354 .34641 Mdot
.65624 .38573 Mdot
.57374 .65495 Mdot
.6504 .37602 Mdot
.38449 .64753 Mdot
.47527 .36852 Mdot
.37115 .58244 Mdot
.64285 .35178 Mdot
.57767 .64577 Mdot
.4363 .55378 Mdot
.73799 .60861 Mdot
.57127 .38301 Mdot
.39634 .36644 Mdot
.55381 .79695 Mdot
.22309 .65884 Mdot
.46896 .2588 Mdot
.43271 .59592 Mdot
.17065 .60407 Mdot
.63895 .48735 Mdot
.58663 .66109 Mdot
.62945 .70603 Mdot
.80683 .43628 Mdot
.36424 .58633 Mdot
.39151 .44415 Mdot
.38263 .53321 Mdot
.53759 .51912 Mdot
.44477 .3435 Mdot
.59181 .63434 Mdot
.44285 .56794 Mdot
.40396 .53243 Mdot
.41006 .70184 Mdot
.38137 .63829 Mdot
.42008 .56395 Mdot
.63547 .6947 Mdot
.61901 .36181 Mdot
.33971 .63792 Mdot
.33072 .33041 Mdot
.67112 .5531 Mdot
.40045 .56302 Mdot
.47836 .32655 Mdot
.62405 .68424 Mdot
.42858 .56038 Mdot
.65866 .37111 Mdot
.41894 .60311 Mdot
.6696 .39673 Mdot
.61386 .61691 Mdot
.39615 .53175 Mdot
.33811 .40586 Mdot
.58329 .54859 Mdot
.63297 .64144 Mdot
.43085 .80805 Mdot
.40044 .61252 Mdot
.3945 .60431 Mdot
.58986 .6604 Mdot
.43343 .35572 Mdot
.44708 .43865 Mdot
.58651 .62618 Mdot
.63217 .33996 Mdot
.63602 .62555 Mdot
.41924 .52802 Mdot
.43563 .35845 Mdot
.67807 .54039 Mdot
.66738 .55817 Mdot
.26655 .37871 Mdot
.43492 .55047 Mdot
.61765 .57086 Mdot
.47788 .33758 Mdot
.59504 .65677 Mdot
.65148 .37029 Mdot
.38501 .62465 Mdot
.62448 .65586 Mdot
.62715 .34398 Mdot
.3595 .37707 Mdot
.29325 .385 Mdot
.62744 .66437 Mdot
.30165 .64481 Mdot
.66477 .39289 Mdot
.62795 .33836 Mdot
.21196 .55745 Mdot
.59156 .6658 Mdot
.32821 .36717 Mdot
.60773 .35515 Mdot
.28064 .48616 Mdot
.40706 .62539 Mdot
.22548 .45429 Mdot
.14594 .52897 Mdot
.20955 .5618 Mdot
.66898 .75069 Mdot
.32274 .39392 Mdot
.60592 .35637 Mdot
.3814 .56651 Mdot
.61657 .65179 Mdot
.61336 .65968 Mdot
.41664 .53586 Mdot
.40162 .54084 Mdot
.43501 .57934 Mdot
.38868 .62309 Mdot
.57838 .19122 Mdot
.43931 .58633 Mdot
.66783 .44399 Mdot
.62715 .64946 Mdot
.41246 .54459 Mdot
.4781 .31898 Mdot
.46376 .58029 Mdot
.66508 .36314 Mdot
.38078 .59937 Mdot
.39592 .54379 Mdot
.44678 .6148 Mdot
.60303 .35597 Mdot
.7719 .56139 Mdot
.27301 .72175 Mdot
.69246 .2967 Mdot
.68907 .59514 Mdot
.47975 .34734 Mdot
.43152 .60997 Mdot
.31984 .38155 Mdot
.33908 .55756 Mdot
.38673 .60974 Mdot
.20388 .57442 Mdot
.38472 .54281 Mdot
.61581 .77462 Mdot
.35312 .65866 Mdot
.80531 .40847 Mdot
.69975 .42981 Mdot
.38877 .61751 Mdot
.35792 .72737 Mdot
.23492 .42502 Mdot
.31506 .26357 Mdot
.65137 .36199 Mdot
.47693 .31452 Mdot
.43145 .34636 Mdot
.63745 .33541 Mdot
.38342 .66115 Mdot
.40971 .76009 Mdot
.3956 .64938 Mdot
.67971 .54084 Mdot
.55759 .63754 Mdot
.31311 .38374 Mdot
.62846 .6646 Mdot
.18082 .63854 Mdot
.40183 .45971 Mdot
.50852 .29165 Mdot
.31014 .35579 Mdot
.49845 .35222 Mdot
.69431 .53855 Mdot
.31969 .37097 Mdot
.40819 .56959 Mdot
.63185 .62554 Mdot
.23223 .42635 Mdot
.47112 .55398 Mdot
.68578 .19837 Mdot
.58436 .66518 Mdot
.55975 .48626 Mdot
.64597 .36204 Mdot
.42003 .34015 Mdot
.36459 .58484 Mdot
.41812 .57904 Mdot
.6094 .68375 Mdot
.36807 .58514 Mdot
.46117 .46665 Mdot
.38989 .5444 Mdot
.44427 .31213 Mdot
.37979 .3706 Mdot
.68205 .38642 Mdot
.27329 .39385 Mdot
.57995 .6356 Mdot
.60508 .44395 Mdot
.47887 .32316 Mdot
.52501 .60469 Mdot
.65515 .35635 Mdot
.36076 .38431 Mdot
.45525 .32189 Mdot
.35616 .4061 Mdot
.45061 .56984 Mdot
.44068 .33486 Mdot
.34868 .37573 Mdot
.55484 .36954 Mdot
.4197 .56294 Mdot
.242 .47814 Mdot
.61059 .3732 Mdot
.62681 .67244 Mdot
.39291 .61597 Mdot
.67759 .5363 Mdot
.45556 .554 Mdot
.60942 .55268 Mdot
.69574 .53024 Mdot
.69022 .56275 Mdot
.49191 .28006 Mdot
.32755 .36127 Mdot
.71134 .63327 Mdot
.48652 .43481 Mdot
.59886 .61397 Mdot
.45086 .58325 Mdot
.80651 .54911 Mdot
.60992 .37408 Mdot
.40461 .57235 Mdot
.79579 .41799 Mdot
.60661 .35716 Mdot
.39707 .58887 Mdot
.63595 .38989 Mdot
.61672 .65678 Mdot
.56392 .42026 Mdot
.64182 .62646 Mdot
.39127 .57737 Mdot
.62111 .37483 Mdot
.4695 .31387 Mdot
.59644 .64614 Mdot
.41223 .60486 Mdot
.43633 .59523 Mdot
.68489 .54059 Mdot
.41962 .54293 Mdot
.82409 .52544 Mdot
.37104 .5734 Mdot
.49766 .35516 Mdot
.37674 .63624 Mdot
.21815 .43531 Mdot
.29051 .38549 Mdot
.56816 .64927 Mdot
.69811 .53351 Mdot
.44199 .34882 Mdot
.55571 .3868 Mdot
.275 .37348 Mdot
.42646 .59752 Mdot
.67978 .55684 Mdot
.56173 .48054 Mdot
.6601 .3787 Mdot
.35847 .59857 Mdot
.45415 .45171 Mdot
.45068 .33276 Mdot
.68816 .53781 Mdot
.45868 .63356 Mdot
.64385 .66217 Mdot
.37992 .57716 Mdot
.44892 .32364 Mdot
.64447 .65458 Mdot
.37823 .62318 Mdot
.48904 .19709 Mdot
.67194 .54197 Mdot
.61822 .3814 Mdot
.49114 .64895 Mdot
.44339 .59062 Mdot
.42947 .34344 Mdot
.62109 .66004 Mdot
.6291 .36233 Mdot
.6193 .62231 Mdot
.2424 .3978 Mdot
.63665 .582 Mdot
.58324 .22038 Mdot
.33121 .35269 Mdot
.61934 .81622 Mdot
.68616 .28609 Mdot
.58815 .58161 Mdot
.38983 .39723 Mdot
.76167 .32324 Mdot
.46563 .32073 Mdot
.32049 .68636 Mdot
.4472 .35528 Mdot
.39013 .56558 Mdot
.45952 .34432 Mdot
.83758 .50387 Mdot
.37762 .55287 Mdot
.47774 .35318 Mdot
.55703 .20371 Mdot
.38242 .5423 Mdot
.6296 .65064 Mdot
.75454 .68634 Mdot
.46634 .82116 Mdot
.29471 .58885 Mdot
.47676 .35652 Mdot
.3186 .6967 Mdot
.368 .57275 Mdot
.47108 .54544 Mdot
.61152 .64842 Mdot
.4117 .52259 Mdot
.31987 .39622 Mdot
.3465 .40864 Mdot
.22843 .57376 Mdot
.50524 .83275 Mdot
.50057 .61088 Mdot
.60173 .65148 Mdot
.2124 .64455 Mdot
.74035 .61099 Mdot
.66566 .55396 Mdot
.64783 .34233 Mdot
.7678 .55846 Mdot
.46772 .62725 Mdot
.35656 .67923 Mdot
.49587 .47007 Mdot
.58992 .63401 Mdot
.62229 .26948 Mdot
.62767 .36777 Mdot
.32728 .73057 Mdot
.45138 .75473 Mdot
.43482 .57561 Mdot
.63194 .39819 Mdot
.33944 .61958 Mdot
.48315 .4693 Mdot
.23414 .47122 Mdot
.49279 .23676 Mdot
.404 .56896 Mdot
.71742 .63448 Mdot
.38714 .60632 Mdot
.23706 .43295 Mdot
.39635 .57631 Mdot
.62362 .62573 Mdot
.46134 .64529 Mdot
.49407 .41701 Mdot
.33891 .76177 Mdot
.40719 .45951 Mdot
.31667 .36538 Mdot
.42084 .58909 Mdot
.42597 .57401 Mdot
.35082 .38412 Mdot
.59938 .63114 Mdot
.44752 .59782 Mdot
.40009 .19977 Mdot
.44101 .58304 Mdot
.66333 .38639 Mdot
.54701 .41776 Mdot
.61116 .78538 Mdot
.37457 .54886 Mdot
.64055 .66769 Mdot
.65584 .38119 Mdot
.64233 .34489 Mdot
.49265 .61843 Mdot
.6128 .37953 Mdot
.37668 .57161 Mdot
.54899 .41981 Mdot
.59738 .61759 Mdot
.33641 .57999 Mdot
.60431 .62956 Mdot
.19355 .59224 Mdot
.60339 .36793 Mdot
.68392 .56073 Mdot
.30685 .67748 Mdot
.63286 .37745 Mdot
.47212 .51221 Mdot
.42123 .66313 Mdot
.45897 .61875 Mdot
.59153 .58707 Mdot
.45752 .31404 Mdot
.6923 .55513 Mdot
.63655 .35796 Mdot
.43977 .58368 Mdot
.42019 .55794 Mdot
.6455 .39921 Mdot
.51505 .68445 Mdot
.3705 .24026 Mdot
.38781 .58167 Mdot
.61542 .62362 Mdot
.59616 .65604 Mdot
.41825 .62661 Mdot
.38977 .6112 Mdot
.50002 .33648 Mdot
.68028 .55789 Mdot
.69819 .54724 Mdot
.67047 .56219 Mdot
.47455 .30488 Mdot
.58642 .83137 Mdot
.6273 .33851 Mdot
.68781 .75329 Mdot
.79089 .48012 Mdot
.49587 .59882 Mdot
.43704 .33114 Mdot
.40779 .58591 Mdot
.40673 .55835 Mdot
.61955 .3709 Mdot
.47817 .84194 Mdot
.34806 .58505 Mdot
.61659 .67612 Mdot
.65725 .39317 Mdot
.3522 .54301 Mdot
.57901 .38747 Mdot
.34812 .40107 Mdot
.36375 .48767 Mdot
.6309 .39914 Mdot
.62056 .62023 Mdot
.63433 .40055 Mdot
.4295 .57521 Mdot
.45511 .63019 Mdot
.58717 .6356 Mdot
.34571 .36116 Mdot
.44801 .57034 Mdot
.39502 .59063 Mdot
.22892 .34158 Mdot
.73563 .61213 Mdot
.43012 .29399 Mdot
.39625 .55512 Mdot
.44262 .62847 Mdot
.35858 .36626 Mdot
.44528 .59369 Mdot
.36824 .6063 Mdot
.58129 .54397 Mdot
.68272 .38079 Mdot
.30068 .37386 Mdot
.32187 .737 Mdot
.5897 .6703 Mdot
.82374 .50385 Mdot
.67122 .54922 Mdot
.67264 .39996 Mdot
.5679 .42373 Mdot
.69237 .54887 Mdot
.78551 .42079 Mdot
.69928 .30702 Mdot
.6862 .55714 Mdot
.41339 .35615 Mdot
.32335 .57246 Mdot
.36828 .61388 Mdot
.38423 .59624 Mdot
.33187 .36191 Mdot
.60489 .6707 Mdot
.67636 .44448 Mdot
.68481 .36317 Mdot
.40327 .6006 Mdot
.64002 .61549 Mdot
.80618 .42176 Mdot
.69155 .53974 Mdot
.32403 .3903 Mdot
.32508 .35767 Mdot
.38911 .60501 Mdot
.5346 .55469 Mdot
.5988 .65067 Mdot
.41218 .60476 Mdot
.41066 .62135 Mdot
.45017 .3612 Mdot
.63583 .63126 Mdot
.48449 .32415 Mdot
.69869 .5298 Mdot
.7298 .26795 Mdot
.24329 .30613 Mdot
.61024 .36323 Mdot
.65813 .28169 Mdot
.61016 .39443 Mdot
.51173 .2395 Mdot
.68174 .5589 Mdot
.41004 .60217 Mdot
.57724 .63415 Mdot
.41651 .6044 Mdot
.44243 .57669 Mdot
.43444 .5673 Mdot
.50223 .60809 Mdot
.2007 .56652 Mdot
.3314 .38964 Mdot
.37553 .64267 Mdot
.50382 .3366 Mdot
.80189 .40935 Mdot
.7743 .63958 Mdot
.42321 .58328 Mdot
.39468 .60218 Mdot
.58119 .66667 Mdot
.45073 .56713 Mdot
.66078 .36823 Mdot
.58754 .66544 Mdot
.40674 .56212 Mdot
.28974 .34167 Mdot
.4412 .60808 Mdot
.66309 .27673 Mdot
.63266 .4007 Mdot
.35186 .50225 Mdot
.43864 .63811 Mdot
.6835 .5596 Mdot
.69186 .55505 Mdot
.68279 .53137 Mdot
.64941 .39465 Mdot
.44701 .35983 Mdot
.47055 .37888 Mdot
.44838 .64285 Mdot
.38017 .56527 Mdot
.45197 .62926 Mdot
.49839 .30723 Mdot
.4818 .42903 Mdot
.69479 .68186 Mdot
.35624 .66136 Mdot
.48922 .31193 Mdot
.65971 .65729 Mdot
.37112 .78669 Mdot
.59813 .67217 Mdot
.39702 .36997 Mdot
.65833 .35578 Mdot
.32939 .40169 Mdot
.22635 .6179 Mdot
.59477 .62134 Mdot
.61073 .6823 Mdot
.4801 .34991 Mdot
.59278 .48226 Mdot
.34458 .86459 Mdot
.47702 .33024 Mdot
.38663 .39039 Mdot
.60723 .6483 Mdot
.35117 .5717 Mdot
.56451 .47819 Mdot
.58252 .49929 Mdot
.46615 .35432 Mdot
.43439 .59709 Mdot
.47992 .514 Mdot
.49985 .33741 Mdot
.35771 .60446 Mdot
.48043 .35549 Mdot
.61795 .38533 Mdot
.482 .33854 Mdot
.60401 .60412 Mdot
.44335 .56356 Mdot
.26787 .79994 Mdot
.63519 .48237 Mdot
.40944 .61144 Mdot
.65474 .39616 Mdot
.53071 .18634 Mdot
.42575 .56979 Mdot
.31075 .38587 Mdot
.49454 .31245 Mdot
.48078 .22133 Mdot
.36922 .60165 Mdot
.46291 .34968 Mdot
.58228 .61297 Mdot
.39943 .36478 Mdot
.41041 .29793 Mdot
.696 .55121 Mdot
.61942 .65482 Mdot
.68977 .56981 Mdot
.66051 .34819 Mdot
.45493 .5948 Mdot
.42539 .61772 Mdot
.62768 .63857 Mdot
.56594 .3616 Mdot
.35859 .62639 Mdot
.43259 .59563 Mdot
.49767 .33542 Mdot
.50745 .32814 Mdot
.65206 .5129 Mdot
.47111 .31895 Mdot
.44021 .62955 Mdot
.62843 .63619 Mdot
.38749 .57084 Mdot
.62756 .65797 Mdot
.45068 .57995 Mdot
.68076 .62564 Mdot
.60134 .67222 Mdot
.54668 .59029 Mdot
.42157 .54073 Mdot
.52424 .64045 Mdot
.44549 .58181 Mdot
.41365 .56595 Mdot
.4962 .31044 Mdot
.33166 .37894 Mdot
.35894 .56807 Mdot
.59653 .43469 Mdot
.36791 .38028 Mdot
.63202 .73689 Mdot
.43436 .35586 Mdot
.35388 .36774 Mdot
.25209 .52067 Mdot
.69805 .53369 Mdot
.34207 .38963 Mdot
.67892 .5149 Mdot
.61142 .36633 Mdot
.61786 .61262 Mdot
.39101 .53759 Mdot
.76367 .31505 Mdot
.36486 .24234 Mdot
.68459 .54361 Mdot
.39353 .61457 Mdot
.40887 .58182 Mdot
.64677 .65329 Mdot
.17706 .62325 Mdot
.4261 .32556 Mdot
.40403 .56669 Mdot
.58646 .62825 Mdot
.16092 .56946 Mdot
.48642 .35109 Mdot
.33791 .39496 Mdot
.61579 .39378 Mdot
.55711 .61623 Mdot
.69247 .55741 Mdot
.60305 .368 Mdot
.44564 .30104 Mdot
.20068 .5856 Mdot
.36989 .60137 Mdot
.45505 .31673 Mdot
.20905 .56259 Mdot
.34923 .65256 Mdot
.59298 .36371 Mdot
.67513 .62195 Mdot
.58968 .6363 Mdot
.64903 .39801 Mdot
.31648 .36385 Mdot
.60618 .61426 Mdot
.59926 .62997 Mdot
.65856 .35127 Mdot
.71696 .39231 Mdot
.5634 .48617 Mdot
.66577 .37374 Mdot
.5788 .52387 Mdot
.21367 .55261 Mdot
.676 .5594 Mdot
.32314 .38995 Mdot
.23922 .38093 Mdot
.59784 .65247 Mdot
.76861 .55863 Mdot
.20551 .57141 Mdot
.41941 .56404 Mdot
.34131 .36882 Mdot
.80167 .44416 Mdot
.6881 .38053 Mdot
.62238 .34606 Mdot
.41585 .43585 Mdot
.31009 .37494 Mdot
.41968 .62297 Mdot
.5972 .79367 Mdot
.3978 .53476 Mdot
.60533 .36274 Mdot
.48667 .47596 Mdot
.63596 .63317 Mdot
.66161 .34781 Mdot
.45278 .4632 Mdot
.40438 .55815 Mdot
.40695 .61649 Mdot
.26681 .41608 Mdot
.63816 .63264 Mdot
.69043 .56057 Mdot
.42601 .60206 Mdot
.39916 .58275 Mdot
.4499 .60604 Mdot
.29456 .66602 Mdot
.56116 .56736 Mdot
.40856 .56379 Mdot
.43176 .32617 Mdot
.46496 .60557 Mdot
.38494 .61841 Mdot
.64933 .64109 Mdot
.20767 .45307 Mdot
.69846 .52893 Mdot
.38553 .59299 Mdot
.38754 .58251 Mdot
.64364 .33985 Mdot
.56292 .48328 Mdot
.58297 .50231 Mdot
.49226 .35679 Mdot
.37628 .43082 Mdot
.40701 .65007 Mdot
.62346 .64917 Mdot
.32333 .40036 Mdot
.44908 .61695 Mdot
.60052 .67479 Mdot
.40538 .65852 Mdot
.50179 .34319 Mdot
.68226 .55525 Mdot
.39661 .67764 Mdot
.34274 .38446 Mdot
.67024 .3911 Mdot
.71047 .73862 Mdot
.4832 .31855 Mdot
.38619 .5545 Mdot
.50992 .36503 Mdot
.46463 .32923 Mdot
.68184 .54262 Mdot
.47508 .57397 Mdot
.61168 .65733 Mdot
.63083 .62766 Mdot
.21526 .51777 Mdot
.46259 .30528 Mdot
.17281 .42272 Mdot
.61642 .38421 Mdot
.35978 .5965 Mdot
.76914 .62127 Mdot
.63524 .63501 Mdot
.25067 .40192 Mdot
.35391 .36705 Mdot
.62212 .34636 Mdot
.70348 .54315 Mdot
.60729 .67436 Mdot
.63775 .64686 Mdot
.44261 .56935 Mdot
.41491 .58867 Mdot
.38172 .4106 Mdot
.23043 .44046 Mdot
.63583 .38951 Mdot
.33727 .39787 Mdot
.48491 .36227 Mdot
.39663 .55905 Mdot
.58365 .64952 Mdot
.59598 .78731 Mdot
.44213 .59374 Mdot
.50057 .34387 Mdot
.58782 .64309 Mdot
.34849 .394 Mdot
.35472 .37428 Mdot
.41802 .56487 Mdot
.58569 .77002 Mdot
.6355 .37933 Mdot
.63123 .64429 Mdot
.61792 .70222 Mdot
.3728 .63652 Mdot
.42026 .58642 Mdot
.34771 .56147 Mdot
.60731 .34492 Mdot
.3874 .67788 Mdot
.35589 .36173 Mdot
.6087 .6658 Mdot
.41599 .60801 Mdot
.34625 .38665 Mdot
.36387 .68513 Mdot
.68869 .55059 Mdot
.48434 .35125 Mdot
.31357 .38916 Mdot
.33772 .37292 Mdot
.36623 .38403 Mdot
.76523 .56205 Mdot
.62664 .68392 Mdot
.30552 .73517 Mdot
.44424 .57331 Mdot
.21548 .54884 Mdot
.4479 .55666 Mdot
.6315 .39214 Mdot
.47533 .31251 Mdot
.44009 .57645 Mdot
.44448 .57108 Mdot
.63504 .76632 Mdot
.41701 .5022 Mdot
.37276 .49249 Mdot
.62321 .61947 Mdot
.488 .65604 Mdot
.43003 .33891 Mdot
.13526 .51197 Mdot
.80018 .63985 Mdot
.3957 .64813 Mdot
.59099 .47696 Mdot
.58706 .66414 Mdot
.61591 .34701 Mdot
.57094 .50584 Mdot
.66248 .41136 Mdot
.60139 .66597 Mdot
.39394 .56282 Mdot
.69311 .74365 Mdot
.36208 .39955 Mdot
.4334 .57955 Mdot
.65386 .36985 Mdot
.43418 .57946 Mdot
.64428 .39444 Mdot
.5495 .6341 Mdot
.59954 .49784 Mdot
.38242 .54487 Mdot
.38202 .64076 Mdot
.3573 .67155 Mdot
.42048 .58447 Mdot
.5463 .28971 Mdot
.6033 .63728 Mdot
.53683 .59472 Mdot
.42058 .6276 Mdot
.54809 .77764 Mdot
.43427 .61348 Mdot
.57332 .36091 Mdot
.42128 .61739 Mdot
.28657 .57702 Mdot
.414 .6244 Mdot
.42974 .61144 Mdot
.62455 .36899 Mdot
.63142 .34075 Mdot
.57399 .61937 Mdot
.68493 .56382 Mdot
.80442 .40826 Mdot
.39478 .59611 Mdot
.50279 .31447 Mdot
.6611 .53506 Mdot
.33338 .37446 Mdot
.6032 .66401 Mdot
.14886 .39379 Mdot
.64997 .38658 Mdot
.41489 .34776 Mdot
.49624 .26976 Mdot
.42128 .35053 Mdot
.49199 .29951 Mdot
.52596 .63157 Mdot
.32927 .39687 Mdot
.42615 .61963 Mdot
.59239 .75023 Mdot
.72634 .62835 Mdot
.36677 .62168 Mdot
.4866 .37797 Mdot
.37394 .51451 Mdot
.20986 .54848 Mdot
.36094 .40632 Mdot
.31653 .38728 Mdot
.63245 .36094 Mdot
.44378 .36784 Mdot
.34831 .6461 Mdot
.35519 .3689 Mdot
.48001 .31446 Mdot
.66552 .5657 Mdot
.30782 .42364 Mdot
.60167 .6548 Mdot
.29823 .61123 Mdot
.7474 .65247 Mdot
.6455 .38838 Mdot
.58939 .43093 Mdot
.6457 .67675 Mdot
.56783 .66843 Mdot
.67796 .56479 Mdot
.50353 .33079 Mdot
.60314 .61213 Mdot
.44371 .566 Mdot
.47138 .55479 Mdot
.38936 .60691 Mdot
.34274 .36442 Mdot
.40336 .62066 Mdot
.49936 .32605 Mdot
.63898 .38543 Mdot
.44516 .34088 Mdot
.63193 .38149 Mdot
.69115 .72808 Mdot
.38296 .61127 Mdot
.41819 .58935 Mdot
.55702 .4316 Mdot
.63347 .65809 Mdot
.56895 .7306 Mdot
.50453 .33157 Mdot
.45569 .35906 Mdot
.39011 .56935 Mdot
.56878 .65634 Mdot
.30804 .35288 Mdot
.57326 .47138 Mdot
.41757 .61948 Mdot
.60438 .63704 Mdot
.38366 .57521 Mdot
.51229 .22346 Mdot
.61783 .50006 Mdot
.62428 .62418 Mdot
.34286 .76653 Mdot
.42488 .54449 Mdot
.39595 .49914 Mdot
.42035 .5119 Mdot
.33526 .48571 Mdot
.3546 .59143 Mdot
.58251 .66219 Mdot
.37996 .60201 Mdot
.6202 .64672 Mdot
.46621 .32509 Mdot
.61973 .34094 Mdot
.61691 .64831 Mdot
.40642 .53509 Mdot
.78441 .6621 Mdot
.65111 .38217 Mdot
.43112 .58815 Mdot
.63352 .35521 Mdot
.62743 .61418 Mdot
.63835 .65749 Mdot
.66999 .50929 Mdot
.49389 .2845 Mdot
.65499 .37718 Mdot
.37793 .56775 Mdot
.75335 .58495 Mdot
.38673 .57111 Mdot
.36759 .42962 Mdot
.40179 .63126 Mdot
.3733 .63327 Mdot
.6346 .81044 Mdot
.56114 .37609 Mdot
.16043 .41626 Mdot
.67173 .33216 Mdot
.76677 .5706 Mdot
.56823 .68038 Mdot
.36024 .40678 Mdot
.64765 .28548 Mdot
.69169 .53044 Mdot
.42958 .33046 Mdot
.44088 .57766 Mdot
.67618 .71483 Mdot
.6637 .38242 Mdot
.32778 .38023 Mdot
.38411 .54345 Mdot
.46326 .37521 Mdot
.70922 .51839 Mdot
.60786 .35351 Mdot
.60137 .65683 Mdot
.62982 .66449 Mdot
.23635 .67949 Mdot
.41087 .60965 Mdot
.41134 .59416 Mdot
.66284 .36028 Mdot
.35676 .65287 Mdot
.3624 .39252 Mdot
.56022 .21384 Mdot
.65426 .36571 Mdot
.62925 .49593 Mdot
.61888 .61738 Mdot
.40869 .58335 Mdot
.54522 .41666 Mdot
.75836 .50838 Mdot
.39823 .72264 Mdot
.32246 .36605 Mdot
.31007 .4474 Mdot
.58265 .66253 Mdot
.65171 .36791 Mdot
.2328 .5556 Mdot
.41247 .53121 Mdot
.40697 .58116 Mdot
.29328 .44078 Mdot
.57372 .47726 Mdot
.33824 .42746 Mdot
.36981 .53416 Mdot
.54852 .46972 Mdot
.39194 .56791 Mdot
.41977 .55782 Mdot
.38616 .64837 Mdot
.37837 .61753 Mdot
.61009 .63807 Mdot
.48693 .81973 Mdot
.46934 .34282 Mdot
.35373 .70999 Mdot
.41082 .4296 Mdot
.36652 .57412 Mdot
.39865 .56077 Mdot
.43836 .79395 Mdot
.64153 .56209 Mdot
.60189 .64134 Mdot
.61368 .70074 Mdot
.6331 .33754 Mdot
.41916 .5028 Mdot
.47006 .30371 Mdot
.36357 .50476 Mdot
.45584 .33688 Mdot
.60528 .63608 Mdot
.43997 .35662 Mdot
.67369 .35176 Mdot
.45517 .3168 Mdot
.46649 .30613 Mdot
.60348 .37374 Mdot
.64294 .64003 Mdot
.43504 .60721 Mdot
.60636 .37431 Mdot
.26328 .40377 Mdot
.34384 .36493 Mdot
.66838 .5118 Mdot
.35042 .57336 Mdot
.39731 .497 Mdot
.48679 .19792 Mdot
.43757 .34241 Mdot
.60078 .53866 Mdot
.60222 .67227 Mdot
.30558 .38028 Mdot
.61435 .6402 Mdot
.26015 .65914 Mdot
.34574 .37846 Mdot
.66979 .51262 Mdot
.23478 .54136 Mdot
.5977 .42015 Mdot
.45858 .5582 Mdot
.55954 .597 Mdot
.45482 .3352 Mdot
.6627 .38767 Mdot
.80041 .43063 Mdot
.42879 .54959 Mdot
.66929 .58168 Mdot
.5802 .68385 Mdot
.69863 .53667 Mdot
.65088 .37186 Mdot
.67241 .3216 Mdot
.40542 .61052 Mdot
.58525 .41359 Mdot
.37811 .63147 Mdot
.30962 .68066 Mdot
.3761 .4264 Mdot
.65298 .59899 Mdot
.37864 .57722 Mdot
.49773 .34424 Mdot
.38147 .57476 Mdot
.31061 .61836 Mdot
.21638 .56293 Mdot
.39335 .64312 Mdot
.60283 .58284 Mdot
.48279 .21472 Mdot
.5853 .64228 Mdot
.43105 .63487 Mdot
.67747 .55214 Mdot
.40589 .54988 Mdot
.80163 .31756 Mdot
.33982 .3876 Mdot
.4293 .30353 Mdot
.41389 .53658 Mdot
.42216 .60284 Mdot
.60356 .77027 Mdot
.53865 .61282 Mdot
.70384 .53782 Mdot
.40911 .57612 Mdot
.31982 .45706 Mdot
.62652 .36353 Mdot
.38045 .62457 Mdot
.38261 .60109 Mdot
.25626 .31468 Mdot
.62549 .36166 Mdot
.43589 .33864 Mdot
.69707 .53198 Mdot
.49038 .35617 Mdot
.34449 .41314 Mdot
.55446 .51473 Mdot
.24586 .41479 Mdot
.61886 .50225 Mdot
.30717 .37402 Mdot
.36344 .58131 Mdot
.64341 .69843 Mdot
.42114 .61043 Mdot
.3148 .38156 Mdot
.64759 .35518 Mdot
.60977 .64078 Mdot
.29998 .63432 Mdot
.67887 .542 Mdot
.36408 .62067 Mdot
.36777 .40121 Mdot
.61463 .65243 Mdot
.7084 .47986 Mdot
.59776 .66799 Mdot
.62935 .37587 Mdot
.65036 .33804 Mdot
.33937 .37812 Mdot
.61254 .63835 Mdot
.47506 .36134 Mdot
.66909 .32882 Mdot
.39404 .63258 Mdot
.6656 .33911 Mdot
.5757 .62392 Mdot
.62157 .67711 Mdot
.57315 .63806 Mdot
.37762 .60998 Mdot
.57993 .47903 Mdot
.43637 .54183 Mdot
.65821 .37563 Mdot
.42653 .3505 Mdot
.22467 .46427 Mdot
.58475 .75511 Mdot
.62894 .49345 Mdot
.35726 .57308 Mdot
.39844 .61872 Mdot
.38952 .60505 Mdot
.38061 .58395 Mdot
.56426 .21676 Mdot
.38275 .61061 Mdot
.62247 .37794 Mdot
.46561 .33419 Mdot
.39782 .61439 Mdot
.67805 .55458 Mdot
.48154 .43381 Mdot
.3221 .39935 Mdot
.29986 .54255 Mdot
.79237 .60837 Mdot
.61359 .65083 Mdot
.46056 .3175 Mdot
.44519 .36146 Mdot
.35957 .37729 Mdot
.60502 .36907 Mdot
.60561 .67002 Mdot
.29002 .5337 Mdot
.3696 .38319 Mdot
.38605 .59195 Mdot
.55161 .42344 Mdot
.35556 .77519 Mdot
.36828 .55962 Mdot
.42658 .56624 Mdot
.69593 .55573 Mdot
.41721 .34332 Mdot
.81797 .36981 Mdot
.70572 .41501 Mdot
.33363 .37883 Mdot
.34804 .39791 Mdot
.57403 .64697 Mdot
.36016 .6048 Mdot
.63893 .38061 Mdot
.5558 .47623 Mdot
.49206 .18792 Mdot
.81992 .47126 Mdot
.5123 .24202 Mdot
.44267 .60587 Mdot
.50203 .80537 Mdot
.43562 .62316 Mdot
.62463 .68409 Mdot
.57017 .64873 Mdot
.60128 .64659 Mdot
.6262 .36856 Mdot
.19958 .59749 Mdot
.6219 .37911 Mdot
.79377 .61023 Mdot
.58521 .63366 Mdot
.53404 .39047 Mdot
.46398 .35942 Mdot
.47618 .60001 Mdot
.32715 .39538 Mdot
.37368 .34706 Mdot
.43654 .63371 Mdot
.53161 .55832 Mdot
.43699 .33129 Mdot
.6397 .65988 Mdot
.41537 .66376 Mdot
.79933 .39353 Mdot
.59558 .48363 Mdot
.41008 .20422 Mdot
.45677 .67918 Mdot
.3502 .3833 Mdot
.37874 .74211 Mdot
.36365 .39405 Mdot
.61585 .34894 Mdot
.43095 .54968 Mdot
.42782 .54162 Mdot
.40103 .56958 Mdot
.37584 .60625 Mdot
.63726 .35727 Mdot
.42246 .62949 Mdot
.21736 .43775 Mdot
.66899 .55055 Mdot
.52772 .38624 Mdot
.35625 .38164 Mdot
.62702 .39349 Mdot
.46584 .33083 Mdot
.68014 .56583 Mdot
.27082 .39223 Mdot
.43659 .6192 Mdot
.44402 .58044 Mdot
.66659 .55924 Mdot
.3703 .65746 Mdot
.46854 .62539 Mdot
.46489 .34589 Mdot
.48828 .45802 Mdot
.3178 .36088 Mdot
.33215 .40249 Mdot
.63573 .39985 Mdot
.61438 .63993 Mdot
.3409 .36162 Mdot
.44788 .36999 Mdot
.37497 .62146 Mdot
.38193 .64144 Mdot
.576 .62344 Mdot
.20526 .57107 Mdot
.33606 .41005 Mdot
.35939 .66715 Mdot
.61965 .66449 Mdot
.58827 .68857 Mdot
.41149 .57514 Mdot
.39625 .5206 Mdot
.62161 .68186 Mdot
.35713 .39064 Mdot
.62395 .39336 Mdot
.54809 .39427 Mdot
.62395 .38518 Mdot
.61714 .66153 Mdot
.4716 .58851 Mdot
.63607 .62758 Mdot
.42062 .54415 Mdot
.11339 .56022 Mdot
.39153 .62057 Mdot
.51398 .5813 Mdot
.36658 .45317 Mdot
.48302 .35442 Mdot
.48854 .35148 Mdot
.68071 .55512 Mdot
.5964 .6728 Mdot
.45398 .61198 Mdot
.33606 .40069 Mdot
.76493 .57299 Mdot
.65302 .6099 Mdot
.47718 .30678 Mdot
.43052 .32342 Mdot
.64646 .3557 Mdot
.42644 .61849 Mdot
.40548 .58815 Mdot
.44912 .32055 Mdot
.54043 .19118 Mdot
.62093 .64032 Mdot
.41151 .5943 Mdot
.3815 .6178 Mdot
.46919 .34012 Mdot
.67793 .32896 Mdot
.60389 .69491 Mdot
.38104 .61849 Mdot
.23476 .52373 Mdot
.64735 .39224 Mdot
.37373 .56754 Mdot
.43094 .62537 Mdot
.33065 .37111 Mdot
.28461 .36329 Mdot
.21304 .55513 Mdot
.60071 .35935 Mdot
.69545 .55354 Mdot
.44053 .55285 Mdot
.47108 .35698 Mdot
.34962 .58381 Mdot
.68721 .27362 Mdot
.67461 .54162 Mdot
.40367 .60641 Mdot
.41166 .65063 Mdot
.63076 .65415 Mdot
.40988 .60483 Mdot
.67731 .62152 Mdot
.49381 .3366 Mdot
.40306 .60721 Mdot
.5816 .76913 Mdot
.64875 .35701 Mdot
.43961 .63246 Mdot
.32303 .39721 Mdot
.37707 .442 Mdot
.73129 .70239 Mdot
.50527 .31359 Mdot
.35311 .3741 Mdot
.40532 .62088 Mdot
.49761 .35302 Mdot
.61485 .39337 Mdot
.54707 .57808 Mdot
.36203 .59024 Mdot
.62754 .38737 Mdot
.64338 .38457 Mdot
.33747 .38109 Mdot
.14177 .43843 Mdot
.40892 .65104 Mdot
.42888 .58319 Mdot
.45817 .17809 Mdot
.65309 .65096 Mdot
.43388 .58547 Mdot
.42782 .61698 Mdot
.61085 .37305 Mdot
.25429 .61156 Mdot
.41666 .47956 Mdot
.55761 .20358 Mdot
.64237 .39418 Mdot
.41005 .36161 Mdot
.49106 .32736 Mdot
.35364 .37634 Mdot
.58652 .64676 Mdot
.31099 .36469 Mdot
.47993 .34255 Mdot
.41169 .56659 Mdot
.6262 .34866 Mdot
.47091 .699 Mdot
.6567 .39605 Mdot
.47573 .37238 Mdot
.60387 .68826 Mdot
.75948 .65751 Mdot
.55701 .15435 Mdot
.7373 .66434 Mdot
.60147 .35377 Mdot
.33313 .37427 Mdot
.68823 .43246 Mdot
.40251 .61808 Mdot
.34368 .74359 Mdot
.43205 .58136 Mdot
.38448 .69732 Mdot
.47731 .31298 Mdot
.67113 .56558 Mdot
.42945 .55027 Mdot
.31552 .45029 Mdot
.60216 .36825 Mdot
.65961 .36603 Mdot
.38145 .59007 Mdot
.63059 .37738 Mdot
.40529 .59266 Mdot
.47024 .33492 Mdot
.1454 .43893 Mdot
.42341 .61438 Mdot
.45379 .61809 Mdot
.67997 .38849 Mdot
.6683 .51269 Mdot
.44035 .37586 Mdot
.51562 .80716 Mdot
.80118 .38733 Mdot
.63529 .37682 Mdot
.49761 .57898 Mdot
.44225 .33171 Mdot
.69049 .56261 Mdot
.44644 .3063 Mdot
.42445 .57711 Mdot
.44642 .59851 Mdot
.39496 .5693 Mdot
.3987 .61788 Mdot
.36081 .74911 Mdot
.46941 .62003 Mdot
.47563 .75855 Mdot
.44357 .57786 Mdot
.51363 .5847 Mdot
.61939 .37402 Mdot
.38857 .49907 Mdot
.33106 .42554 Mdot
.44528 .6042 Mdot
.53608 .61257 Mdot
.62319 .39076 Mdot
.78725 .58038 Mdot
.63135 .35838 Mdot
.44339 .34703 Mdot
.63825 .3416 Mdot
.41994 .54241 Mdot
.59531 .65398 Mdot
.48226 .32779 Mdot
.69636 .68048 Mdot
.43251 .33011 Mdot
.40921 .61138 Mdot
.68597 .39534 Mdot
.47806 .35836 Mdot
.33754 .50196 Mdot
.59339 .65423 Mdot
.30103 .46027 Mdot
.65167 .65948 Mdot
.41528 .60084 Mdot
.42284 .59651 Mdot
.67631 .56784 Mdot
.60688 .35447 Mdot
.59454 .61751 Mdot
.22657 .3494 Mdot
.3713 .40045 Mdot
.59515 .63964 Mdot
.43661 .5206 Mdot
.58959 .47297 Mdot
.63234 .63834 Mdot
.33578 .47051 Mdot
.60503 .36274 Mdot
.57858 .64329 Mdot
.44271 .53906 Mdot
.33208 .67513 Mdot
.35187 .40456 Mdot
.50205 .34743 Mdot
.54951 .45406 Mdot
.49258 .33001 Mdot
.67173 .38143 Mdot
.45812 .30544 Mdot
.62174 .36725 Mdot
.66047 .59161 Mdot
.47631 .47343 Mdot
.67338 .36942 Mdot
.68203 .36981 Mdot
.47408 .34842 Mdot
.38272 .58394 Mdot
.49123 .42021 Mdot
.41332 .51871 Mdot
.46577 .61109 Mdot
.64014 .39216 Mdot
.57932 .65779 Mdot
.62079 .61631 Mdot
.52746 .60504 Mdot
.63749 .65364 Mdot
.47576 .32581 Mdot
.61356 .51018 Mdot
.31325 .69379 Mdot
.64854 .35357 Mdot
.51398 .29701 Mdot
.38677 .56898 Mdot
.47662 .35213 Mdot
.46912 .32274 Mdot
.63392 .38404 Mdot
.36824 .72056 Mdot
.44974 .62862 Mdot
.64977 .64705 Mdot
.58726 .62866 Mdot
.6302 .63329 Mdot
.56959 .65469 Mdot
.20814 .6219 Mdot
.66254 .38795 Mdot
.58589 .6652 Mdot
.37406 .59703 Mdot
.4446 .58944 Mdot
.69655 .53918 Mdot
.35494 .3913 Mdot
.45363 .56444 Mdot
.46322 .58626 Mdot
.41166 .57601 Mdot
.48121 .35533 Mdot
.32874 .60253 Mdot
.67714 .54009 Mdot
.44692 .31106 Mdot
.47195 .30414 Mdot
.68569 .55964 Mdot
.66965 .63834 Mdot
.82947 .42681 Mdot
.40271 .56738 Mdot
.57692 .69948 Mdot
.46911 .35587 Mdot
.53917 .5324 Mdot
.43819 .66394 Mdot
.37619 .57151 Mdot
.50458 .39835 Mdot
.47345 .33122 Mdot
.55875 .6458 Mdot
.42343 .58103 Mdot
.67451 .56205 Mdot
.33559 .40527 Mdot
.42774 .52297 Mdot
.69551 .55667 Mdot
.6067 .63416 Mdot
.44693 .22816 Mdot
.64611 .62692 Mdot
.47883 .35901 Mdot
.43369 .63402 Mdot
.31419 .84218 Mdot
.45425 .3343 Mdot
.77762 .54418 Mdot
.46652 .46895 Mdot
.41594 .61647 Mdot
.48253 .32353 Mdot
.56177 .65642 Mdot
.64722 .39201 Mdot
.55748 .43919 Mdot
.58386 .64945 Mdot
.67867 .56578 Mdot
.69537 .54929 Mdot
.46853 .34232 Mdot
.59981 .62075 Mdot
.40911 .6315 Mdot
.62109 .6682 Mdot
.64598 .34697 Mdot
.39728 .54374 Mdot
.80456 .40754 Mdot
.47288 .55645 Mdot
.61701 .66801 Mdot
.44232 .36926 Mdot
.35096 .36272 Mdot
.37803 .54983 Mdot
.81471 .52282 Mdot
.42189 .62009 Mdot
.63863 .35423 Mdot
.50896 .5126 Mdot
.46587 .70572 Mdot
.39388 .57793 Mdot
.39321 .56449 Mdot
.62695 .39856 Mdot
.39854 .57435 Mdot
.36646 .60926 Mdot
.61459 .32692 Mdot
.63386 .6454 Mdot
.39635 .60565 Mdot
.48976 .32196 Mdot
.53961 .68178 Mdot
.43595 .55537 Mdot
.6841 .61785 Mdot
.30407 .45282 Mdot
.49216 .49396 Mdot
.45014 .61692 Mdot
.25669 .3921 Mdot
.4241 .593 Mdot
.36772 .58632 Mdot
.39085 .57433 Mdot
.49162 .80727 Mdot
.47848 .34589 Mdot
.49015 .31431 Mdot
.33539 .40656 Mdot
.31628 .45412 Mdot
.33723 .36747 Mdot
.61937 .39232 Mdot
.50893 .28611 Mdot
.66911 .55226 Mdot
.61655 .64195 Mdot
.43847 .56083 Mdot
.43762 .32367 Mdot
.41219 .58114 Mdot
.4025 .55051 Mdot
.47981 .33292 Mdot
.46991 .32525 Mdot
.4969 .30544 Mdot
.36699 .3928 Mdot
.60711 .64498 Mdot
.42816 .56333 Mdot
.36804 .37961 Mdot
.41241 .6283 Mdot
.59893 .4653 Mdot
.60466 .644 Mdot
.62239 .66716 Mdot
.63303 .6201 Mdot
.44559 .57556 Mdot
.40832 .53975 Mdot
.62206 .37975 Mdot
.58002 .6203 Mdot
.6613 .36159 Mdot
.48431 .32465 Mdot
.48941 .348 Mdot
.42505 .57684 Mdot
.36257 .66694 Mdot
.35351 .38894 Mdot
.43981 .34683 Mdot
.68745 .53005 Mdot
.33218 .40561 Mdot
.39176 .61465 Mdot
.48912 .32772 Mdot
.32144 .3978 Mdot
.41359 .70353 Mdot
.78185 .35881 Mdot
.37129 .38232 Mdot
.38105 .59095 Mdot
.60373 .76517 Mdot
.22751 .53691 Mdot
.37338 .39478 Mdot
.6253 .35712 Mdot
.43791 .60611 Mdot
.56732 .18246 Mdot
.31925 .35896 Mdot
.20691 .57062 Mdot
.48336 .33591 Mdot
.4246 .68221 Mdot
.43217 .5246 Mdot
.32642 .72547 Mdot
.31813 .35802 Mdot
.61064 .66721 Mdot
.57966 .63058 Mdot
.38699 .58829 Mdot
.36067 .41779 Mdot
.66874 .38381 Mdot
.44511 .36159 Mdot
.46549 .30763 Mdot
.60796 .61881 Mdot
.62428 .49989 Mdot
.48992 .32329 Mdot
.37572 .64321 Mdot
.4099 .32588 Mdot
.42488 .50523 Mdot
.23486 .67181 Mdot
.68926 .7187 Mdot
.4338 .6283 Mdot
.35628 .36481 Mdot
.60375 .37545 Mdot
.62693 .37994 Mdot
.62786 .37006 Mdot
.49281 .34516 Mdot
.5693 .49206 Mdot
.47042 .30949 Mdot
.71154 .57744 Mdot
.34628 .38795 Mdot
.2917 .48191 Mdot
.45942 .58592 Mdot
.41543 .61604 Mdot
.37094 .61903 Mdot
.39687 .56782 Mdot
.42248 .5928 Mdot
.64365 .38888 Mdot
.46478 .36492 Mdot
.50031 .2106 Mdot
.61769 .6249 Mdot
.70021 .47362 Mdot
.46227 .35978 Mdot
.70083 .53896 Mdot
.32687 .38543 Mdot
.24902 .42051 Mdot
.41009 .31331 Mdot
.44284 .3575 Mdot
.3629 .57424 Mdot
.57636 .6581 Mdot
.29146 .66131 Mdot
.43276 .59558 Mdot
.43852 .34574 Mdot
.41295 .34733 Mdot
.38513 .73587 Mdot
.34686 .57503 Mdot
.39547 .36711 Mdot
.58855 .47538 Mdot
.34593 .35657 Mdot
.35767 .56526 Mdot
.54668 .5353 Mdot
.47742 .34301 Mdot
.44966 .34752 Mdot
.37241 .39066 Mdot
.34726 .53256 Mdot
.58925 .63294 Mdot
.66907 .56515 Mdot
.61978 .36081 Mdot
.42989 .60408 Mdot
.49399 .3426 Mdot
.58814 .70085 Mdot
.5568 .42125 Mdot
.64293 .36076 Mdot
.43836 .31663 Mdot
.43674 .61084 Mdot
.39083 .58321 Mdot
.34844 .37963 Mdot
.31459 .27878 Mdot
.4165 .51955 Mdot
.76663 .5701 Mdot
.58658 .51215 Mdot
.42494 .45284 Mdot
.40664 .58169 Mdot
.63425 .62865 Mdot
.68188 .5592 Mdot
.32095 .38747 Mdot
.41826 .62575 Mdot
.81977 .39935 Mdot
.63207 .60836 Mdot
.65174 .37952 Mdot
.67948 .56113 Mdot
.56075 .49008 Mdot
.41842 .62101 Mdot
.43165 .58123 Mdot
.3773 .6088 Mdot
.82128 .39531 Mdot
.48381 .31389 Mdot
.57178 .63378 Mdot
.32553 .36449 Mdot
.62475 .6682 Mdot
.49266 .31074 Mdot
.41647 .4488 Mdot
.384 .61515 Mdot
.64749 .63983 Mdot
.60465 .66826 Mdot
.64939 .35656 Mdot
.60688 .37603 Mdot
.50918 .33923 Mdot
.40382 .61972 Mdot
.66843 .55851 Mdot
.57973 .65033 Mdot
.45053 .36592 Mdot
.34776 .38014 Mdot
.6252 .33408 Mdot
.44388 .57698 Mdot
.4712 .34391 Mdot
.41075 .63683 Mdot
.62826 .64928 Mdot
.44801 .35893 Mdot
.70165 .54457 Mdot
.35275 .39351 Mdot
.44746 .5888 Mdot
.47329 .21122 Mdot
.6773 .56334 Mdot
.40021 .53461 Mdot
.64968 .72517 Mdot
.33386 .42124 Mdot
.69376 .69261 Mdot
.46897 .31357 Mdot
.67203 .5525 Mdot
.56947 .64405 Mdot
.33023 .67763 Mdot
.45314 .34412 Mdot
.64216 .7511 Mdot
.52319 .40013 Mdot
.41282 .56451 Mdot
.59317 .63492 Mdot
.37089 .36647 Mdot
.7752 .56457 Mdot
.2314 .50087 Mdot
.40523 .59814 Mdot
.49321 .33042 Mdot
.3315 .40256 Mdot
.65994 .36152 Mdot
.68163 .60858 Mdot
.25939 .69387 Mdot
.44659 .31194 Mdot
.43748 .56403 Mdot
.57844 .65196 Mdot
.63985 .38288 Mdot
.68796 .74619 Mdot
.4539 .37203 Mdot
.47757 .31669 Mdot
.36908 .60036 Mdot
.32188 .3656 Mdot
.57518 .19002 Mdot
.49007 .31583 Mdot
.48817 .3578 Mdot
.67412 .48991 Mdot
.35382 .40748 Mdot
.37629 .59744 Mdot
.5277 .60459 Mdot
.38144 .62378 Mdot
.74287 .5357 Mdot
.67087 .55433 Mdot
.61918 .62648 Mdot
.43847 .58126 Mdot
.48456 .21476 Mdot
.45815 .3364 Mdot
.58958 .47931 Mdot
.68991 .32325 Mdot
.60621 .37292 Mdot
.4928 .33835 Mdot
.41639 .58321 Mdot
.65568 .33925 Mdot
.35374 .38482 Mdot
.38126 .61862 Mdot
.41502 .54177 Mdot
.56534 .66691 Mdot
.63376 .34758 Mdot
.54814 .68667 Mdot
.64993 .34571 Mdot
.63808 .40036 Mdot
.58906 .68921 Mdot
.38672 .5897 Mdot
.44187 .35208 Mdot
.48118 .37232 Mdot
.41233 .63319 Mdot
.5389 .53093 Mdot
.58996 .63374 Mdot
.48605 .29482 Mdot
.8076 .36099 Mdot
.3969 .64963 Mdot
.694 .52807 Mdot
.43975 .68125 Mdot
.65804 .38586 Mdot
.41222 .5677 Mdot
.62179 .6469 Mdot
.47419 .36539 Mdot
.49685 .33006 Mdot
.38802 .53135 Mdot
.63433 .38512 Mdot
.30862 .38409 Mdot
.46511 .32128 Mdot
.56173 .42118 Mdot
.40539 .60792 Mdot
.67612 .58071 Mdot
.4599 .32145 Mdot
.76033 .6902 Mdot
.4901 .21334 Mdot
.61766 .62184 Mdot
.39232 .55672 Mdot
.59704 .67864 Mdot
.32937 .36381 Mdot
.44918 .30637 Mdot
.62867 .38549 Mdot
.29961 .60661 Mdot
.25432 .30646 Mdot
.48039 .34974 Mdot
.60858 .63778 Mdot
.43573 .56671 Mdot
.41488 .66723 Mdot
.42043 .61802 Mdot
.25692 .60299 Mdot
.38549 .38617 Mdot
.67737 .35632 Mdot
.6619 .3684 Mdot
.4035 .5585 Mdot
.36494 .38935 Mdot
.49988 .35848 Mdot
.48015 .33459 Mdot
.12829 .4959 Mdot
.69666 .55571 Mdot
.39398 .3797 Mdot
.44533 .57657 Mdot
.44167 .36308 Mdot
.58104 .7533 Mdot
.66237 .35971 Mdot
.38351 .62823 Mdot
.42028 .34327 Mdot
.74858 .49914 Mdot
.58688 .47031 Mdot
.40422 .60415 Mdot
.35439 .65192 Mdot
.62847 .35766 Mdot
.68936 .43182 Mdot
.46072 .31345 Mdot
.39939 .6283 Mdot
.59614 .38966 Mdot
.65451 .52096 Mdot
.23728 .34212 Mdot
.60678 .64523 Mdot
.42804 .36275 Mdot
.61543 .384 Mdot
.3335 .61821 Mdot
.35712 .38588 Mdot
.48283 .36562 Mdot
.42327 .34087 Mdot
.39477 .54774 Mdot
.45321 .56613 Mdot
.34313 .62442 Mdot
.59969 .63188 Mdot
.61079 .36913 Mdot
.41713 .5533 Mdot
.61914 .48267 Mdot
.40708 .56369 Mdot
.61306 .37486 Mdot
.19063 .71995 Mdot
.38433 .53583 Mdot
.43786 .59334 Mdot
.33647 .49208 Mdot
.60419 .61573 Mdot
.63349 .65353 Mdot
.60865 .49743 Mdot
.44583 .5778 Mdot
.55356 .37504 Mdot
.6099 .64509 Mdot
.58906 .63901 Mdot
.54941 .37832 Mdot
.39062 .54525 Mdot
.6345 .41268 Mdot
.63653 .38222 Mdot
.60669 .37443 Mdot
.62972 .65568 Mdot
.47792 .59409 Mdot
.61086 .3893 Mdot
.37159 .75687 Mdot
.45023 .36044 Mdot
.54705 .53563 Mdot
.61906 .66884 Mdot
.5373 .41357 Mdot
.60794 .35419 Mdot
.76976 .70712 Mdot
.28866 .63404 Mdot
.38653 .63599 Mdot
.38951 .5826 Mdot
.33531 .3709 Mdot
.48555 .62674 Mdot
.69697 .55047 Mdot
.62818 .37671 Mdot
.5679 .22344 Mdot
.60063 .64676 Mdot
.43618 .60279 Mdot
.22696 .45248 Mdot
.70277 .71696 Mdot
.54379 .58795 Mdot
.58582 .64869 Mdot
.59599 .64829 Mdot
.43624 .3311 Mdot
.44959 .36153 Mdot
.38123 .60658 Mdot
.62372 .37156 Mdot
.5814 .63328 Mdot
.61433 .35618 Mdot
.47901 .34209 Mdot
.44956 .35825 Mdot
.6848 .53427 Mdot
.45413 .63628 Mdot
.48849 .34103 Mdot
.68465 .49301 Mdot
.61751 .48074 Mdot
.56237 .65307 Mdot
.53953 .15559 Mdot
.68201 .75534 Mdot
.33092 .4979 Mdot
.33673 .40576 Mdot
.6576 .54935 Mdot
.61689 .34563 Mdot
.40176 .55997 Mdot
.4289 .57262 Mdot
.69206 .54023 Mdot
.60464 .35349 Mdot
.32426 .378 Mdot
.60945 .35162 Mdot
.32851 .39384 Mdot
.4983 .32032 Mdot
.43729 .55523 Mdot
.40112 .62255 Mdot
.65645 .37304 Mdot
.43628 .33591 Mdot
.48013 .3578 Mdot
.35255 .40207 Mdot
.25526 .42583 Mdot
.47029 .34156 Mdot
.61915 .66897 Mdot
.53333 .6919 Mdot
.69561 .54721 Mdot
.42314 .58172 Mdot
.23934 .4273 Mdot
.36649 .73727 Mdot
.41723 .56264 Mdot
.67854 .56185 Mdot
.12601 .4672 Mdot
.4333 .55116 Mdot
.16257 .58031 Mdot
.67707 .54122 Mdot
.63452 .62546 Mdot
.44694 .32711 Mdot
.6896 .56184 Mdot
.32909 .60847 Mdot
.36936 .42045 Mdot
.41344 .64012 Mdot
.58474 .63704 Mdot
.64534 .6424 Mdot
.48166 .46918 Mdot
.74241 .53253 Mdot
.31805 .36581 Mdot
.33141 .38443 Mdot
.45608 .34359 Mdot
.57456 .37137 Mdot
.36043 .62433 Mdot
.33016 .38136 Mdot
.61111 .22616 Mdot
.38478 .57023 Mdot
.35993 .43741 Mdot
.50425 .40434 Mdot
.62817 .6235 Mdot
.38228 .49897 Mdot
.45597 .34012 Mdot
.60816 .63819 Mdot
.48652 .43867 Mdot
.376 .62238 Mdot
.60284 .64469 Mdot
.60881 .36753 Mdot
.62741 .3095 Mdot
.63545 .65972 Mdot
.55753 .43611 Mdot
.64046 .37947 Mdot
.33449 .42272 Mdot
.26217 .51833 Mdot
.85229 .3782 Mdot
.62589 .37581 Mdot
.43983 .33673 Mdot
.48882 .34612 Mdot
.46915 .33808 Mdot
.58347 .64642 Mdot
.4646 .32633 Mdot
.61071 .62711 Mdot
.68694 .3704 Mdot
.25663 .40241 Mdot
.3425 .3792 Mdot
.46057 .28865 Mdot
.60679 .66281 Mdot
.71941 .57519 Mdot
.46886 .16144 Mdot
.37733 .59181 Mdot
.67216 .37452 Mdot
.3645 .36984 Mdot
.61218 .53929 Mdot
.33088 .37044 Mdot
.44308 .33023 Mdot
.54844 .53663 Mdot
.40411 .59371 Mdot
.6738 .71504 Mdot
.32543 .39762 Mdot
.58478 .649 Mdot
.36526 .57716 Mdot
.50453 .36091 Mdot
.3484 .37052 Mdot
.34118 .40545 Mdot
.42296 .5908 Mdot
.64259 .65316 Mdot
.44241 .35498 Mdot
.62747 .34095 Mdot
.37859 .38431 Mdot
.36422 .6597 Mdot
.38687 .58092 Mdot
.36776 .55469 Mdot
.58902 .49061 Mdot
.57801 .18562 Mdot
.63754 .376 Mdot
.22352 .53525 Mdot
.48362 .35073 Mdot
.2323 .50865 Mdot
.74231 .61058 Mdot
.41245 .30659 Mdot
.67078 .55221 Mdot
.67056 .55562 Mdot
.40984 .60022 Mdot
.61399 .1984 Mdot
.52077 .58131 Mdot
.62277 .40559 Mdot
.69294 .54951 Mdot
.47891 .35854 Mdot
.59531 .60767 Mdot
.3583 .50839 Mdot
.45789 .56331 Mdot
.60149 .35841 Mdot
.47647 .33861 Mdot
.68712 .2729 Mdot
.34491 .38738 Mdot
.60021 .53178 Mdot
.3963 .61516 Mdot
.41459 .59159 Mdot
.64706 .36885 Mdot
.6237 .38019 Mdot
.6939 .58008 Mdot
.51152 .48318 Mdot
.8056 .42826 Mdot
.66361 .39917 Mdot
.6825 .26424 Mdot
.54094 .64388 Mdot
.62325 .65816 Mdot
.69632 .53003 Mdot
.6191 .39455 Mdot
.43551 .58509 Mdot
.63117 .62239 Mdot
.53361 .58555 Mdot
.55747 .65742 Mdot
.36242 .43829 Mdot
.54992 .39621 Mdot
.39577 .6168 Mdot
.57446 .65803 Mdot
.60636 .63941 Mdot
.58339 .67123 Mdot
.68656 .55826 Mdot
.40685 .57907 Mdot
.381 .58481 Mdot
.43076 .54916 Mdot
.41492 .66638 Mdot
.40974 .60543 Mdot
.74646 .60509 Mdot
.63329 .48623 Mdot
.33452 .30174 Mdot
.44404 .56966 Mdot
.61254 .38009 Mdot
.44149 .56287 Mdot
.36375 .38736 Mdot
.44821 .57289 Mdot
.35438 .43572 Mdot
.63354 .36806 Mdot
.32434 .572 Mdot
.51631 .31069 Mdot
.38905 .6161 Mdot
.30709 .37592 Mdot
.58345 .1864 Mdot
.22124 .47495 Mdot
.67585 .49049 Mdot
.61992 .66842 Mdot
.50873 .33081 Mdot
.66956 .37267 Mdot
.44401 .35248 Mdot
.38839 .63198 Mdot
.68315 .53346 Mdot
.59983 .82639 Mdot
.52235 .42108 Mdot
.43687 .58455 Mdot
.45513 .63858 Mdot
.63447 .63205 Mdot
.45853 .33404 Mdot
.5506 .65109 Mdot
.36997 .59929 Mdot
.34002 .36229 Mdot
.35777 .36892 Mdot
.4472 .45154 Mdot
.64157 .27293 Mdot
.29803 .66059 Mdot
.64484 .36988 Mdot
.49962 .335 Mdot
.31634 .35867 Mdot
.57122 .59189 Mdot
.66627 .38711 Mdot
.65832 .3852 Mdot
.63151 .34816 Mdot
.41257 .61328 Mdot
.69146 .53312 Mdot
.62203 .24994 Mdot
.68275 .56467 Mdot
.37207 .60918 Mdot
.42539 .33694 Mdot
.68724 .56419 Mdot
.33694 .36904 Mdot
.63954 .39946 Mdot
.4762 .35721 Mdot
.42026 .59895 Mdot
.61142 .65053 Mdot
.21727 .51493 Mdot
.382 .20874 Mdot
.46167 .29265 Mdot
.46712 .29123 Mdot
.63756 .62094 Mdot
.81757 .53916 Mdot
.65843 .3328 Mdot
.3662 .72244 Mdot
.36475 .35807 Mdot
.40946 .63398 Mdot
.15951 .45439 Mdot
.46969 .31016 Mdot
.48057 .32648 Mdot
.39922 .60732 Mdot
.45105 .36907 Mdot
.4318 .61066 Mdot
.45342 .31578 Mdot
.77744 .51704 Mdot
.45637 .55709 Mdot
.47733 .32619 Mdot
.35492 .60968 Mdot
.3785 .54767 Mdot
.63747 .63474 Mdot
.47921 .3666 Mdot
.38638 .63675 Mdot
.55215 .85513 Mdot
.65319 .36041 Mdot
.68806 .55767 Mdot
.48497 .28342 Mdot
.63338 .34292 Mdot
.59989 .62631 Mdot
.44201 .55602 Mdot
.35213 .38424 Mdot
.61492 .66166 Mdot
.5118 .34966 Mdot
.31798 .39096 Mdot
.61471 .50832 Mdot
.62632 .65797 Mdot
.69478 .53927 Mdot
.35051 .39525 Mdot
.41348 .6404 Mdot
.48223 .32993 Mdot
.4596 .19874 Mdot
.68509 .56292 Mdot
.40648 .58819 Mdot
.4326 .36836 Mdot
.61055 .35101 Mdot
.38439 .60338 Mdot
.49771 .33807 Mdot
.68318 .56048 Mdot
.39915 .53551 Mdot
.39687 .53442 Mdot
.33977 .52985 Mdot
.50695 .52325 Mdot
.34412 .37654 Mdot
.59612 .69038 Mdot
.37369 .59919 Mdot
.36434 .39187 Mdot
.51623 .2525 Mdot
.45506 .60316 Mdot
.61592 .67691 Mdot
.31394 .63803 Mdot
.43999 .35927 Mdot
.66242 .36397 Mdot
.47271 .37321 Mdot
.32808 .40309 Mdot
.27028 .25111 Mdot
.69836 .53533 Mdot
.43949 .64947 Mdot
.36845 .61714 Mdot
.43522 .31648 Mdot
.60273 .63902 Mdot
.80987 .45056 Mdot
.44714 .58358 Mdot
.47437 .57122 Mdot
.42415 .58569 Mdot
.48008 .22054 Mdot
.58859 .6367 Mdot
.42451 .58309 Mdot
.37648 .66692 Mdot
.3828 .6427 Mdot
.30609 .37025 Mdot
.28888 .49401 Mdot
.43149 .55893 Mdot
.40226 .89941 Mdot
.66629 .55631 Mdot
.47726 .33294 Mdot
.57327 .45546 Mdot
.4582 .25041 Mdot
.21444 .6498 Mdot
.60435 .62848 Mdot
.51401 .63672 Mdot
.44356 .35419 Mdot
.20635 .5007 Mdot
.8054 .56524 Mdot
.37393 .55421 Mdot
.43988 .60519 Mdot
.44306 .33029 Mdot
.45287 .36582 Mdot
.67047 .54491 Mdot
.44774 .60408 Mdot
.47538 .57452 Mdot
.43147 .36138 Mdot
.42285 .6024 Mdot
.43301 .77417 Mdot
.66165 .34618 Mdot
.63176 .6537 Mdot
.6595 .36097 Mdot
.65769 .38371 Mdot
.32189 .70276 Mdot
.58556 .51328 Mdot
.61663 .37823 Mdot
.59386 .36609 Mdot
.31231 .43163 Mdot
.29633 .58536 Mdot
.30953 .36682 Mdot
.66404 .29209 Mdot
.46176 .3426 Mdot
.40767 .57725 Mdot
.58309 .65544 Mdot
.29023 .70722 Mdot
.75357 .36741 Mdot
.56211 .54415 Mdot
.37684 .5878 Mdot
.46102 .33664 Mdot
.68238 .5624 Mdot
.4582 .56009 Mdot
.23112 .52699 Mdot
.40882 .59531 Mdot
.45288 .36313 Mdot
.31496 .69841 Mdot
.67132 .61356 Mdot
.66256 .39917 Mdot
.58219 .60949 Mdot
.43935 .55976 Mdot
.62434 .63977 Mdot
.62185 .38623 Mdot
.36663 .39214 Mdot
.33341 .37552 Mdot
.39272 .61896 Mdot
.47764 .47382 Mdot
.27544 .38024 Mdot
.37451 .55406 Mdot
.39508 .54627 Mdot
.67255 .54865 Mdot
.39599 .54556 Mdot
.39724 .62666 Mdot
.41708 .55566 Mdot
.44735 .61002 Mdot
.63171 .40052 Mdot
.66386 .71132 Mdot
.45266 .57576 Mdot
.39091 .65035 Mdot
.63279 .33687 Mdot
.36148 .53336 Mdot
.62943 .35999 Mdot
.77562 .37172 Mdot
.61866 .36436 Mdot
.33522 .37626 Mdot
.45658 .37715 Mdot
.52412 .64018 Mdot
.58237 .632 Mdot
.61365 .38414 Mdot
.33508 .39382 Mdot
.62668 .37358 Mdot
.49578 .32357 Mdot
.4992 .16808 Mdot
.63046 .68308 Mdot
.60226 .46281 Mdot
.30109 .53563 Mdot
.67932 .58019 Mdot
.43359 .35474 Mdot
.6069 .61936 Mdot
.67504 .61753 Mdot
.40686 .5565 Mdot
.35115 .37908 Mdot
.41044 .59909 Mdot
.64816 .39776 Mdot
.46208 .33854 Mdot
.68955 .38352 Mdot
.34322 .37546 Mdot
.31963 .22314 Mdot
.43799 .32417 Mdot
.41679 .65608 Mdot
.64274 .33715 Mdot
.51414 .15845 Mdot
.62284 .36229 Mdot
.25518 .40483 Mdot
.65679 .6731 Mdot
.27132 .67313 Mdot
.59922 .65519 Mdot
.67364 .58609 Mdot
.8501 .52168 Mdot
.797 .55089 Mdot
.61886 .65523 Mdot
.51541 .30834 Mdot
.41201 .60927 Mdot
.40207 .56472 Mdot
.37383 .64432 Mdot
.55907 .63055 Mdot
.37681 .60645 Mdot
.69774 .5466 Mdot
.59221 .49975 Mdot
.58031 .20411 Mdot
.50766 .33983 Mdot
.42888 .61393 Mdot
.64174 .39171 Mdot
.65076 .39879 Mdot
.68356 .56607 Mdot
.64045 .34491 Mdot
.38493 .54347 Mdot
.60469 .66129 Mdot
.48928 .42335 Mdot
.33347 .36461 Mdot
.75669 .57661 Mdot
.34421 .35293 Mdot
.39877 .34071 Mdot
.39167 .64812 Mdot
.44883 .35834 Mdot
.20279 .36425 Mdot
.39774 .56348 Mdot
.61102 .64329 Mdot
.367 .60131 Mdot
.42262 .55526 Mdot
.434 .56163 Mdot
.49872 .33824 Mdot
.57674 .45668 Mdot
.42561 .60063 Mdot
.617 .38166 Mdot
.54371 .38327 Mdot
.45794 .56927 Mdot
.57907 .23511 Mdot
.36608 .43938 Mdot
.67541 .58033 Mdot
.56281 .64993 Mdot
.44381 .33898 Mdot
.59925 .64844 Mdot
.60827 .59613 Mdot
.60016 .62609 Mdot
.58952 .23027 Mdot
.33764 .6874 Mdot
.17189 .60755 Mdot
.56046 .75309 Mdot
.32087 .7155 Mdot
.64932 .64161 Mdot
.55252 .26632 Mdot
.62268 .65187 Mdot
.60243 .62687 Mdot
.13225 .61024 Mdot
.60105 .67327 Mdot
.42385 .57627 Mdot
.4225 .53723 Mdot
.73159 .68569 Mdot
.31361 .43397 Mdot
.44565 .57048 Mdot
.37807 .60615 Mdot
.3401 .35992 Mdot
.33746 .65567 Mdot
.66354 .57005 Mdot
.59461 .52284 Mdot
.69145 .52371 Mdot
.42223 .59163 Mdot
.39159 .61042 Mdot
.38205 .53348 Mdot
.85401 .52984 Mdot
.27273 .69871 Mdot
.6398 .62797 Mdot
.33871 .56673 Mdot
.68908 .51129 Mdot
.36534 .60838 Mdot
.36773 .61011 Mdot
.42206 .54377 Mdot
.44215 .35278 Mdot
.59973 .60717 Mdot
.4498 .54059 Mdot
.71861 .6344 Mdot
.39488 .61459 Mdot
.39046 .35026 Mdot
.29624 .36042 Mdot
.41695 .58213 Mdot
.61535 .67547 Mdot
.38599 .57445 Mdot
.58694 .67094 Mdot
.63105 .65179 Mdot
.45778 .63239 Mdot
.62864 .25645 Mdot
.59417 .60601 Mdot
.37438 .55185 Mdot
.43564 .34021 Mdot
.77242 .56011 Mdot
.40861 .58626 Mdot
.31777 .36815 Mdot
.41159 .5674 Mdot
.30671 .37859 Mdot
.40646 .54225 Mdot
.68028 .56524 Mdot
.4552 .71345 Mdot
.45142 .3473 Mdot
.37798 .38061 Mdot
.44143 .36429 Mdot
.35704 .49494 Mdot
.63391 .67231 Mdot
.66088 .5681 Mdot
.26821 .70935 Mdot
.67364 .54652 Mdot
.21682 .5448 Mdot
.56605 .35792 Mdot
.65789 .37825 Mdot
.56883 .65271 Mdot
.31022 .68307 Mdot
.60624 .26446 Mdot
.48229 .30252 Mdot
.4731 .30374 Mdot
.21426 .36452 Mdot
.14389 .44142 Mdot
.43043 .59891 Mdot
.55913 .17633 Mdot
.47715 .74668 Mdot
.36173 .63329 Mdot
.3745 .53216 Mdot
.42253 .34608 Mdot
.44454 .56281 Mdot
.54744 .44428 Mdot
.47516 .34815 Mdot
.33753 .39092 Mdot
.62054 .62811 Mdot
.35173 .39939 Mdot
.7407 .34278 Mdot
.63551 .47443 Mdot
.48433 .34482 Mdot
.45312 .60097 Mdot
.42679 .60966 Mdot
.56757 .64472 Mdot
.65289 .75123 Mdot
.63412 .64716 Mdot
.31403 .36699 Mdot
.46243 .3518 Mdot
.31487 .72368 Mdot
.4225 .56577 Mdot
.60048 .66749 Mdot
.51883 .31847 Mdot
.3922 .58202 Mdot
.65383 .37989 Mdot
.37676 .5866 Mdot
.60918 .67053 Mdot
.39712 .54523 Mdot
.60413 .65935 Mdot
.44553 .32257 Mdot
.41324 .62349 Mdot
.38988 .6096 Mdot
.21311 .55583 Mdot
.3236 .37662 Mdot
.63791 .66836 Mdot
.55024 .44767 Mdot
.38105 .62333 Mdot
.23278 .52827 Mdot
.43609 .55382 Mdot
.48397 .55116 Mdot
.38972 .52364 Mdot
.69787 .54119 Mdot
.36986 .62224 Mdot
.40848 .58738 Mdot
.61122 .7722 Mdot
.59338 .75972 Mdot
.38344 .49019 Mdot
.60738 .37825 Mdot
.62043 .67255 Mdot
.49073 .34413 Mdot
.47562 .36375 Mdot
.45847 .32654 Mdot
.30073 .43106 Mdot
.35046 .65464 Mdot
.40157 .59411 Mdot
.681 .36395 Mdot
.33372 .38406 Mdot
.58863 .65774 Mdot
.33787 .38092 Mdot
.58931 .52504 Mdot
.31304 .37745 Mdot
.69889 .5449 Mdot
.49162 .21227 Mdot
.3969 .76163 Mdot
.31684 .38151 Mdot
.63357 .64862 Mdot
.55562 .38726 Mdot
.40571 .6353 Mdot
.72786 .49746 Mdot
.33983 .36206 Mdot
.22556 .34835 Mdot
.4096 .53624 Mdot
.55914 .44399 Mdot
.63576 .35769 Mdot
.3504 .39959 Mdot
.63847 .34754 Mdot
.38961 .57116 Mdot
.69214 .6975 Mdot
.61219 .63892 Mdot
.66386 .35114 Mdot
.37258 .62735 Mdot
.35172 .3991 Mdot
.48615 .34108 Mdot
.29563 .63365 Mdot
.60757 .34642 Mdot
.21429 .50452 Mdot
.23122 .50153 Mdot
.46548 .35183 Mdot
.36354 .7755 Mdot
.6324 .35162 Mdot
.43766 .62443 Mdot
.40537 .6844 Mdot
.37961 .57814 Mdot
.48524 .35589 Mdot
.47833 .3242 Mdot
.7625 .62307 Mdot
.39518 .61806 Mdot
.43504 .54434 Mdot
.61173 .60786 Mdot
.47772 .3527 Mdot
.59696 .62649 Mdot
.57425 .63056 Mdot
.44082 .33218 Mdot
.61657 .62124 Mdot
.3268 .3985 Mdot
.57335 .51887 Mdot
.62918 .35294 Mdot
.644 .38531 Mdot
.48824 .34248 Mdot
.50304 .33444 Mdot
.45323 .35951 Mdot
.37365 .58413 Mdot
.59527 .62168 Mdot
.38663 .55849 Mdot
.4395 .56205 Mdot
.6244 .69883 Mdot
.61001 .61249 Mdot
.3845 .56536 Mdot
.52136 .39223 Mdot
.30208 .3756 Mdot
.47539 .32637 Mdot
.6118 .35855 Mdot
.20689 .55564 Mdot
.65987 .34663 Mdot
.37874 .61881 Mdot
.748 .50276 Mdot
.584 .64557 Mdot
.33253 .37035 Mdot
.3416 .41899 Mdot
.33999 .37288 Mdot
.66425 .35147 Mdot
.57191 .62926 Mdot
.61528 .50454 Mdot
.39976 .62068 Mdot
.5882 .49313 Mdot
.22919 .56494 Mdot
.73736 .61901 Mdot
.61028 .36992 Mdot
.37688 .59381 Mdot
.67643 .54241 Mdot
.38813 .73858 Mdot
.40023 .59884 Mdot
.38343 .62898 Mdot
.38559 .24812 Mdot
.39262 .65019 Mdot
.56664 .6658 Mdot
.45311 .46191 Mdot
.42102 .62448 Mdot
.37336 .49317 Mdot
.11745 .52289 Mdot
.40577 .53514 Mdot
.38974 .61283 Mdot
.41945 .57184 Mdot
.39751 .56127 Mdot
.60638 .68127 Mdot
.36184 .24373 Mdot
.63328 .39167 Mdot
.57255 .51734 Mdot
.62872 .35014 Mdot
.48772 .33009 Mdot
.52581 .43855 Mdot
.59223 .67553 Mdot
.33964 .37223 Mdot
.54543 .16817 Mdot
.55369 .53066 Mdot
.43387 .33426 Mdot
.23043 .65408 Mdot
.33967 .36362 Mdot
.41209 .63383 Mdot
.33534 .40685 Mdot
.42161 .3513 Mdot
.63258 .3846 Mdot
.36434 .56964 Mdot
.58257 .6388 Mdot
.63401 .66104 Mdot
.37423 .5934 Mdot
.76107 .56776 Mdot
.62694 .34363 Mdot
.35876 .32928 Mdot
.40699 .61472 Mdot
.38534 .62935 Mdot
.63243 .63686 Mdot
.4604 .33375 Mdot
.56156 .36333 Mdot
.32491 .3846 Mdot
.36418 .62326 Mdot
.39004 .57215 Mdot
.5865 .52064 Mdot
.6245 .39593 Mdot
.68621 .55001 Mdot
.40059 .61666 Mdot
.59066 .5085 Mdot
.37957 .61607 Mdot
.48598 .60692 Mdot
.43468 .35053 Mdot
.46812 .6078 Mdot
.44211 .60573 Mdot
.61051 .7135 Mdot
.63913 .35028 Mdot
.60581 .64244 Mdot
.65871 .65959 Mdot
.67351 .56221 Mdot
.65481 .36611 Mdot
.38213 .56878 Mdot
.66277 .38019 Mdot
.4182 .55954 Mdot
.42162 .60045 Mdot
.61 .36967 Mdot
.5995 .62379 Mdot
.80106 .43658 Mdot
.66762 .71016 Mdot
.40785 .55039 Mdot
.40459 .56997 Mdot
.31998 .43921 Mdot
.31268 .75364 Mdot
.44397 .60399 Mdot
.59428 .62069 Mdot
.39026 .58442 Mdot
.64137 .38824 Mdot
.31317 .36874 Mdot
.61408 .64837 Mdot
.50078 .32736 Mdot
.458 .31553 Mdot
.53144 .33486 Mdot
.69913 .5383 Mdot
.44489 .6075 Mdot
.59739 .69119 Mdot
.61998 .61194 Mdot
.60871 .55189 Mdot
.47772 .3321 Mdot
.31087 .37778 Mdot
.43246 .54584 Mdot
.30304 .64703 Mdot
.65107 .39057 Mdot
.41127 .90043 Mdot
.61849 .50227 Mdot
.31234 .35352 Mdot
.48746 .49041 Mdot
.68023 .54112 Mdot
.44036 .59021 Mdot
.36253 .39096 Mdot
.46664 .31651 Mdot
.39765 .56665 Mdot
.34825 .64258 Mdot
.60776 .27383 Mdot
.50104 .32058 Mdot
.66434 .37358 Mdot
.47708 .31404 Mdot
.305 .37725 Mdot
.69814 .54761 Mdot
.64167 .65027 Mdot
.41175 .5883 Mdot
.40938 .50193 Mdot
.46955 .33532 Mdot
.67313 .56642 Mdot
.38805 .61729 Mdot
.62544 .66964 Mdot
.46907 .32558 Mdot
.4279 .58891 Mdot
.37174 .72574 Mdot
.53018 .62697 Mdot
.4621 .34697 Mdot
.36 .59042 Mdot
.32621 .53039 Mdot
.49402 .31316 Mdot
.42357 .33709 Mdot
.3777 .60719 Mdot
.34584 .39919 Mdot
.42479 .61929 Mdot
.62301 .3659 Mdot
.57694 .45643 Mdot
.65456 .37397 Mdot
.2259 .54005 Mdot
.42279 .53544 Mdot
.54144 .58367 Mdot
.57415 .65271 Mdot
.35176 .41311 Mdot
.58842 .78675 Mdot
.39704 .63111 Mdot
.81992 .42713 Mdot
.54094 .41367 Mdot
.64322 .48569 Mdot
.7864 .34809 Mdot
.32188 .38577 Mdot
.62786 .36962 Mdot
.38679 .61275 Mdot
.6359 .32646 Mdot
.32948 .39619 Mdot
.22447 .54352 Mdot
.36438 .61156 Mdot
.58841 .64053 Mdot
.4055 .61239 Mdot
.61682 .67097 Mdot
.39973 .57606 Mdot
.32484 .61653 Mdot
.38727 .36288 Mdot
.25453 .40724 Mdot
.41865 .63255 Mdot
.55137 .16415 Mdot
.29851 .55604 Mdot
.32509 .36506 Mdot
.40571 .54791 Mdot
.68582 .54331 Mdot
.606 .35566 Mdot
.51355 .19024 Mdot
.44576 .35622 Mdot
.61575 .37468 Mdot
.62652 .62935 Mdot
.44797 .37313 Mdot
.67059 .56304 Mdot
.42169 .68236 Mdot
.3541 .39764 Mdot
.65352 .36172 Mdot
.41173 .58538 Mdot
.37075 .61298 Mdot
.47839 .21878 Mdot
.39529 .81062 Mdot
.58499 .62364 Mdot
.27195 .27173 Mdot
.59123 .68825 Mdot
.32741 .3812 Mdot
.43625 .35302 Mdot
.43669 .57964 Mdot
.39539 .60389 Mdot
.49286 .34913 Mdot
.60726 .61546 Mdot
.4077 .33082 Mdot
.27546 .68507 Mdot
.68348 .32098 Mdot
.28456 .45864 Mdot
.6172 .64819 Mdot
.28121 .4556 Mdot
.30783 .3591 Mdot
.67699 .27482 Mdot
.29605 .52396 Mdot
.66003 .37015 Mdot
.28803 .46214 Mdot
.58904 .66104 Mdot
.43276 .59784 Mdot
.69447 .54018 Mdot
.67468 .54184 Mdot
.62627 .63717 Mdot
.44267 .333 Mdot
.35697 .38726 Mdot
.40276 .6099 Mdot
.58767 .57506 Mdot
.69798 .7435 Mdot
.50057 .34027 Mdot
.45042 .64472 Mdot
.63105 .34421 Mdot
.39364 .57848 Mdot
.35312 .36485 Mdot
.6317 .37931 Mdot
.69923 .55166 Mdot
.5546 .52194 Mdot
.43449 .54694 Mdot
.42961 .45415 Mdot
.6455 .35973 Mdot
.31826 .76109 Mdot
.38994 .60839 Mdot
.63297 .35145 Mdot
.42576 .50822 Mdot
.69738 .64237 Mdot
.50215 .41155 Mdot
.80204 .53894 Mdot
.51096 .32254 Mdot
.46285 .31367 Mdot
.5139 .85396 Mdot
.36577 .35823 Mdot
.61822 .38668 Mdot
.69462 .55534 Mdot
.29345 .50456 Mdot
.64772 .3492 Mdot
.36817 .56057 Mdot
.43621 .55289 Mdot
.31689 .7038 Mdot
.34504 .49327 Mdot
.6645 .56012 Mdot
.48699 .64642 Mdot
.38162 .55133 Mdot
.43666 .6308 Mdot
.38235 .59902 Mdot
.64492 .63978 Mdot
.66037 .3552 Mdot
.66196 .17608 Mdot
.66621 .38023 Mdot
.57652 .56291 Mdot
.46164 .34229 Mdot
.49474 .35918 Mdot
.41783 .58262 Mdot
.51299 .56626 Mdot
.60224 .18641 Mdot
.42733 .56421 Mdot
.33433 .41942 Mdot
.23012 .49977 Mdot
.46242 .58154 Mdot
.63627 .61128 Mdot
.47513 .57154 Mdot
.60201 .68611 Mdot
.63263 .38102 Mdot
.32293 .38773 Mdot
.30081 .37128 Mdot
.62987 .36366 Mdot
.39778 .59481 Mdot
.29699 .3761 Mdot
.41768 .58912 Mdot
.42794 .60629 Mdot
.59529 .52853 Mdot
.36545 .36903 Mdot
.45386 .36015 Mdot
.33575 .37475 Mdot
.6001 .62943 Mdot
.13923 .64058 Mdot
.34621 .38402 Mdot
.29569 .5923 Mdot
.54466 .43184 Mdot
.28572 .46352 Mdot
.63534 .65811 Mdot
.31783 .365 Mdot
.66212 .36127 Mdot
.63665 .49991 Mdot
.35725 .76808 Mdot
.6626 .35192 Mdot
.3975 .60537 Mdot
.58955 .67385 Mdot
.6353 .62029 Mdot
.65156 .40296 Mdot
.6315 .62556 Mdot
.43095 .64425 Mdot
.37308 .55327 Mdot
.62296 .38878 Mdot
.72957 .70328 Mdot
.66253 .35758 Mdot
.30022 .63648 Mdot
.41268 .54035 Mdot
.61238 .64582 Mdot
.49223 .56787 Mdot
.57952 .68944 Mdot
.68421 .53407 Mdot
.44863 .5717 Mdot
.34728 .37404 Mdot
.56926 .49119 Mdot
.46039 .34673 Mdot
.75134 .5011 Mdot
.62082 .66839 Mdot
.67476 .37081 Mdot
.63839 .63691 Mdot
.59079 .61968 Mdot
.6649 .35661 Mdot
.60428 .63368 Mdot
.39411 .61247 Mdot
.71326 .40258 Mdot
.61958 .66714 Mdot
.64393 .36658 Mdot
.35125 .37484 Mdot
.61196 .62028 Mdot
.41437 .32351 Mdot
.43234 .60508 Mdot
.42982 .35285 Mdot
.3761 .38628 Mdot
.58381 .67067 Mdot
.31481 .36838 Mdot
.47293 .333 Mdot
.35881 .38665 Mdot
.6725 .33296 Mdot
.67328 .34747 Mdot
.56171 .54897 Mdot
.68236 .64388 Mdot
.58174 .65326 Mdot
.50896 .31398 Mdot
.44407 .58936 Mdot
.4149 .61473 Mdot
.32532 .40275 Mdot
.64046 .62369 Mdot
.76538 .55537 Mdot
.5109 .60389 Mdot
.75447 .57869 Mdot
.61222 .3871 Mdot
.2298 .39823 Mdot
.62401 .50097 Mdot
.65698 .48274 Mdot
.35566 .56621 Mdot
.68235 .53997 Mdot
.42476 .58501 Mdot
.22124 .47288 Mdot
.31418 .36424 Mdot
.54112 .29762 Mdot
.36114 .62607 Mdot
.46615 .35612 Mdot
.41029 .57053 Mdot
.54925 .17963 Mdot
.47551 .56028 Mdot
.33027 .36048 Mdot
.63915 .33507 Mdot
.58226 .63208 Mdot
.33466 .36403 Mdot
.45143 .31827 Mdot
.32337 .46668 Mdot
.37078 .54991 Mdot
.3819 .54817 Mdot
.46455 .30486 Mdot
.59288 .62915 Mdot
.48526 .32964 Mdot
.62945 .35267 Mdot
.34272 .38295 Mdot
.39959 .55863 Mdot
.45928 .61835 Mdot
.43003 .32106 Mdot
.66103 .38939 Mdot
.50238 .34178 Mdot
.66061 .38402 Mdot
.68603 .53831 Mdot
.44284 .61277 Mdot
.4352 .31933 Mdot
.35041 .57516 Mdot
.59214 .74865 Mdot
.58004 .53426 Mdot
.55503 .7974 Mdot
.45393 .36051 Mdot
.32147 .45107 Mdot
.6344 .36482 Mdot
.65024 .35548 Mdot
.31807 .69537 Mdot
.60502 .19153 Mdot
.55322 .37522 Mdot
.48167 .17566 Mdot
.62818 .35328 Mdot
.65025 .36448 Mdot
.46336 .3182 Mdot
.61002 .62885 Mdot
.63355 .60401 Mdot
.42246 .35734 Mdot
.23936 .42798 Mdot
.58898 .65844 Mdot
.83283 .47134 Mdot
.46756 .30819 Mdot
.3677 .54514 Mdot
.6676 .54316 Mdot
.33484 .36091 Mdot
.2255 .46386 Mdot
.49568 .17519 Mdot
.43188 .57947 Mdot
.15902 .55296 Mdot
.44353 .34291 Mdot
.6699 .31284 Mdot
.69114 .29376 Mdot
.37476 .62319 Mdot
.41113 .5721 Mdot
.39294 .59416 Mdot
.37244 .39526 Mdot
.63671 .74675 Mdot
.43408 .58145 Mdot
.26032 .40617 Mdot
.45557 .55507 Mdot
.46191 .20271 Mdot
.33595 .37507 Mdot
.25455 .60942 Mdot
.51513 .33277 Mdot
.72358 .6187 Mdot
.38908 .6457 Mdot
.62741 .35569 Mdot
.60032 .30982 Mdot
.61274 .37665 Mdot
.64847 .24191 Mdot
.29248 .5266 Mdot
.64569 .64109 Mdot
.37606 .58742 Mdot
.4549 .30995 Mdot
.58614 .67142 Mdot
.55905 .35556 Mdot
.12424 .60141 Mdot
.62883 .40097 Mdot
.16889 .36526 Mdot
.65762 .36054 Mdot
.67154 .54506 Mdot
.62988 .63723 Mdot
.4186 .48407 Mdot
.58516 .49812 Mdot
.59807 .62585 Mdot
.32728 .31726 Mdot
.65588 .63408 Mdot
.29233 .44735 Mdot
.6511 .66373 Mdot
.63754 .36872 Mdot
.67308 .34893 Mdot
.33884 .59212 Mdot
.44542 .59684 Mdot
.59585 .48854 Mdot
.36068 .54246 Mdot
.4461 .57792 Mdot
.4751 .34831 Mdot
.68659 .63667 Mdot
.58922 .34916 Mdot
.62184 .64529 Mdot
.64137 .39529 Mdot
.41233 .57076 Mdot
.40716 .55015 Mdot
.37844 .64125 Mdot
.20974 .51014 Mdot
.83152 .46325 Mdot
.42586 .59928 Mdot
.47672 .58449 Mdot
.43494 .33478 Mdot
.4729 .21419 Mdot
.31055 .25116 Mdot
.29929 .50488 Mdot
.38852 .61942 Mdot
.32589 .37512 Mdot
.33351 .3582 Mdot
.42399 .65168 Mdot
.546 .57399 Mdot
.43119 .30542 Mdot
.41153 .58528 Mdot
.3575 .46421 Mdot
.43665 .31217 Mdot
.67705 .56689 Mdot
.47017 .33537 Mdot
.58892 .6747 Mdot
.67211 .54766 Mdot
.49592 .33283 Mdot
.47559 .5171 Mdot
.67481 .56157 Mdot
.702 .63829 Mdot
.31425 .36648 Mdot
.3846 .60306 Mdot
.544 .63272 Mdot
.49253 .34743 Mdot
.64853 .35881 Mdot
.60962 .65758 Mdot
.60194 .372 Mdot
.47919 .21029 Mdot
.23222 .45484 Mdot
.69778 .535 Mdot
.62398 .35874 Mdot
.4959 .46772 Mdot
.32803 .3751 Mdot
.65022 .34722 Mdot
.53217 .58715 Mdot
.45478 .5666 Mdot
.67223 .23532 Mdot
.37342 .56086 Mdot
.77682 .6063 Mdot
.64322 .35439 Mdot
.70148 .53111 Mdot
.41094 .5902 Mdot
.43955 .32337 Mdot
.36564 .52893 Mdot
.41732 .5907 Mdot
.48491 .3145 Mdot
.43071 .59792 Mdot
.36819 .37923 Mdot
.59151 .68179 Mdot
.53315 .41726 Mdot
.20945 .46457 Mdot
.35713 .37769 Mdot
.64634 .56781 Mdot
.4472 .59725 Mdot
.29476 .31462 Mdot
.59182 .63834 Mdot
.38623 .62821 Mdot
.20741 .60011 Mdot
.61992 .63274 Mdot
.59814 .64879 Mdot
.39195 .54925 Mdot
.66047 .34975 Mdot
.48077 .3567 Mdot
.33003 .37411 Mdot
.57632 .36694 Mdot
.43024 .58844 Mdot
.37677 .59667 Mdot
.33894 .36381 Mdot
.65336 .3677 Mdot
.396 .55935 Mdot
.77795 .45737 Mdot
.604 .55155 Mdot
.65629 .38618 Mdot
.45792 .5708 Mdot
.71643 .25257 Mdot
.62826 .60065 Mdot
.16082 .56806 Mdot
.36406 .35924 Mdot
.43855 .33849 Mdot
.41574 .66094 Mdot
.36662 .87997 Mdot
.3244 .3641 Mdot
.73236 .61215 Mdot
.42419 .60407 Mdot
.43817 .57238 Mdot
.64028 .66129 Mdot
.38223 .56314 Mdot
.60486 .67237 Mdot
.20837 .44921 Mdot
.54007 .14719 Mdot
.63464 .6314 Mdot
.61002 .67242 Mdot
.39475 .49466 Mdot
.21007 .52863 Mdot
.62143 .62728 Mdot
.37118 .54877 Mdot
.3344 .30697 Mdot
.35971 .65665 Mdot
.32505 .35294 Mdot
.33595 .41407 Mdot
.64423 .62298 Mdot
.43677 .81307 Mdot
.42796 .50618 Mdot
.32679 .55916 Mdot
.28466 .395 Mdot
.61583 .36412 Mdot
.4244 .54978 Mdot
.69966 .54277 Mdot
.46877 .32316 Mdot
.47158 .56231 Mdot
.38827 .60284 Mdot
.60085 .67552 Mdot
.36987 .40255 Mdot
.64377 .3467 Mdot
.3802 .6079 Mdot
.40985 .3592 Mdot
.33324 .39067 Mdot
.6209 .66489 Mdot
.29675 .60173 Mdot
.31017 .36243 Mdot
.44817 .63076 Mdot
.44406 .57516 Mdot
.38418 .61695 Mdot
.35952 .63849 Mdot
.63168 .36128 Mdot
.42934 .36395 Mdot
.40243 .66039 Mdot
.60033 .51493 Mdot
.56299 .48138 Mdot
.41102 .65866 Mdot
.5972 .61914 Mdot
.60906 .37947 Mdot
.68066 .55807 Mdot
.2917 .48231 Mdot
.40905 .53724 Mdot
.82715 .44319 Mdot
.25282 .67711 Mdot
.67563 .55629 Mdot
.64119 .66989 Mdot
.33503 .37145 Mdot
.39178 .5431 Mdot
.28629 .36263 Mdot
.36884 .56093 Mdot
.3902 .67349 Mdot
.43985 .3417 Mdot
.61462 .35891 Mdot
.61882 .57335 Mdot
.47037 .32255 Mdot
.59886 .64852 Mdot
.79454 .61532 Mdot
.64866 .61815 Mdot
.58105 .62488 Mdot
.63377 .25476 Mdot
.62678 .38203 Mdot
.38827 .89395 Mdot
.31021 .754 Mdot
.39364 .5329 Mdot
.62831 .38719 Mdot
.62954 .64329 Mdot
.37139 .58125 Mdot
.58384 .65564 Mdot
.60127 .60463 Mdot
.44574 .56574 Mdot
.44496 .58164 Mdot
.25437 .41711 Mdot
.83631 .49764 Mdot
.35125 .38011 Mdot
.63279 .62402 Mdot
.33366 .71084 Mdot
.43673 .58333 Mdot
.40205 .62054 Mdot
.61295 .28932 Mdot
.32224 .36346 Mdot
.43042 .7662 Mdot
.41419 .61313 Mdot
.20121 .59091 Mdot
.4475 .57758 Mdot
.59068 .59782 Mdot
.6484 .4063 Mdot
.56104 .57351 Mdot
.48304 .35731 Mdot
.56803 .65464 Mdot
.31525 .39287 Mdot
.56374 .64387 Mdot
.33897 .69928 Mdot
.63177 .38287 Mdot
.60888 .67064 Mdot
.47824 .37412 Mdot
.64678 .3764 Mdot
.66061 .37138 Mdot
.54517 .37043 Mdot
.45992 .37534 Mdot
.37157 .39035 Mdot
.60792 .3566 Mdot
.36686 .7208 Mdot
.63735 .37179 Mdot
.3463 .70867 Mdot
.42588 .62134 Mdot
.26636 .42543 Mdot
.59945 .56923 Mdot
.34032 .61386 Mdot
.65802 .35236 Mdot
.34899 .39307 Mdot
.3793 .57412 Mdot
.62812 .62275 Mdot
.3467 .38913 Mdot
.61822 .32576 Mdot
.5021 .35578 Mdot
.63443 .61717 Mdot
.65653 .34042 Mdot
.5944 .66968 Mdot
.22705 .48731 Mdot
.40977 .3123 Mdot
.50144 .40008 Mdot
.58558 .49065 Mdot
.41803 .63669 Mdot
.37506 .49254 Mdot
.37006 .61722 Mdot
.39433 .60141 Mdot
.46246 .3463 Mdot
.30069 .43184 Mdot
.61084 .61995 Mdot
.73152 .72732 Mdot
.62955 .35689 Mdot
.45731 .46408 Mdot
.39418 .67661 Mdot
.41192 .56152 Mdot
.62512 .65298 Mdot
.59139 .60967 Mdot
.5932 .76024 Mdot
.49345 .34922 Mdot
.3564 .65141 Mdot
.39846 .64845 Mdot
.34235 .64995 Mdot
.66019 .36459 Mdot
.78791 .44528 Mdot
.49564 .35432 Mdot
.12657 .43362 Mdot
.47593 .32587 Mdot
.34622 .26628 Mdot
.60532 .63337 Mdot
.3134 .38395 Mdot
.4097 .62009 Mdot
.66871 .68839 Mdot
.61474 .68094 Mdot
.47065 .29597 Mdot
.33733 .36964 Mdot
.79655 .44055 Mdot
.61931 .37915 Mdot
.40818 .62634 Mdot
.44697 .56582 Mdot
.39163 .55434 Mdot
.36678 .58962 Mdot
.62911 .39293 Mdot
.36515 .57037 Mdot
.60174 .35093 Mdot
.36483 .73562 Mdot
.21157 .60142 Mdot
.42985 .32698 Mdot
.45907 .20934 Mdot
.59211 .61956 Mdot
.4225 .70202 Mdot
.42427 .77029 Mdot
.58108 .53548 Mdot
.68279 .3519 Mdot
.4344 .61855 Mdot
.44467 .33066 Mdot
.56547 .175 Mdot
.43535 .32176 Mdot
.59455 .13955 Mdot
.30766 .67958 Mdot
.80401 .55508 Mdot
.37023 .57509 Mdot
.41444 .34949 Mdot
.46629 .81138 Mdot
.4614 .61654 Mdot
.30181 .38628 Mdot
.3266 .66357 Mdot
.72888 .67597 Mdot
.31004 .37489 Mdot
.43441 .60104 Mdot
.59939 .61269 Mdot
.39617 .61235 Mdot
.42126 .61738 Mdot
.42357 .56423 Mdot
.62727 .40473 Mdot
.44901 .56454 Mdot
.42408 .6194 Mdot
.37291 .7966 Mdot
.36273 .4366 Mdot
.4347 .33171 Mdot
.56659 .78365 Mdot
.33411 .38442 Mdot
.58202 .66788 Mdot
.54532 .41661 Mdot
.6198 .36994 Mdot
.58828 .75817 Mdot
.37114 .56923 Mdot
.75341 .59591 Mdot
.67421 .35499 Mdot
.3356 .39649 Mdot
.67986 .5607 Mdot
.78095 .38938 Mdot
.44867 .36326 Mdot
.66932 .54602 Mdot
.459 .34683 Mdot
.53068 .81751 Mdot
.61215 .67314 Mdot
.42118 .63607 Mdot
.62987 .34713 Mdot
.42292 .34428 Mdot
.26964 .38387 Mdot
.38844 .59152 Mdot
.45635 .36092 Mdot
.42996 .6308 Mdot
.56833 .4758 Mdot
.55369 .42616 Mdot
.4258 .356 Mdot
.66838 .34528 Mdot
.64827 .37877 Mdot
.32044 .39467 Mdot
.57222 .65685 Mdot
.58628 .63453 Mdot
.63707 .37829 Mdot
.1375 .46875 Mdot
.42986 .58702 Mdot
.44234 .57157 Mdot
.60622 .51006 Mdot
.36892 .5899 Mdot
.34275 .45603 Mdot
.66549 .57205 Mdot
.57899 .65275 Mdot
.36924 .59933 Mdot
.397 .55848 Mdot
.43266 .54702 Mdot
.23417 .45563 Mdot
.46795 .33405 Mdot
.38339 .54938 Mdot
.35896 .39462 Mdot
.69236 .58135 Mdot
.44325 .59295 Mdot
.45818 .61779 Mdot
.59952 .67059 Mdot
.23598 .34268 Mdot
.64366 .35623 Mdot
.47913 .35324 Mdot
.47298 .30689 Mdot
.2436 .53529 Mdot
.56067 .63272 Mdot
.66372 .56855 Mdot
.51085 .2362 Mdot
.69055 .55795 Mdot
.32392 .36677 Mdot
.52811 .39266 Mdot
.40453 .35402 Mdot
.45596 .31486 Mdot
.65718 .33721 Mdot
.3723 .60699 Mdot
.44671 .57655 Mdot
.73024 .60756 Mdot
.43591 .56414 Mdot
.345 .37138 Mdot
.64061 .33781 Mdot
.60285 .6704 Mdot
.35763 .36828 Mdot
.65156 .35482 Mdot
.59317 .62819 Mdot
.46128 .57232 Mdot
.37338 .64112 Mdot
.60499 .65626 Mdot
.62691 .66296 Mdot
.41902 .57679 Mdot
.46107 .83962 Mdot
.57857 .64706 Mdot
.61954 .65839 Mdot
.70791 .53134 Mdot
.43879 .36085 Mdot
.49468 .58287 Mdot
.62891 .38647 Mdot
.39624 .61686 Mdot
.42871 .32748 Mdot
.31543 .37748 Mdot
.5975 .65763 Mdot
.42036 .54601 Mdot
.42439 .59481 Mdot
.3264 .37367 Mdot
.34528 .35736 Mdot
.35031 .37139 Mdot
.61485 .39564 Mdot
.37408 .55302 Mdot
.61984 .62497 Mdot
.6194 .38045 Mdot
.32926 .35862 Mdot
.34596 .40843 Mdot
.36757 .78882 Mdot
.42952 .57931 Mdot
.29478 .37984 Mdot
.18107 .70566 Mdot
.32412 .4717 Mdot
.66837 .55565 Mdot
.41556 .33878 Mdot
.27029 .42214 Mdot
.37969 .38689 Mdot
.61454 .38222 Mdot
.37991 .44259 Mdot
.36109 .41065 Mdot
.43299 .55932 Mdot
.39076 .57851 Mdot
.35621 .57567 Mdot
.34012 .38938 Mdot
.2311 .47451 Mdot
.62698 .6159 Mdot
.48283 .72452 Mdot
.33431 .38449 Mdot
.42832 .35767 Mdot
.42445 .32759 Mdot
.47851 .32527 Mdot
.42749 .62379 Mdot
.59161 .77314 Mdot
.34338 .71718 Mdot
.44433 .7627 Mdot
.61689 .37592 Mdot
.59516 .60842 Mdot
.68947 .3844 Mdot
.59744 .64891 Mdot
.45739 .32877 Mdot
.33785 .39326 Mdot
.6437 .65507 Mdot
.65657 .37756 Mdot
.65285 .37738 Mdot
.50485 .33796 Mdot
.47515 .3349 Mdot
.48528 .34334 Mdot
.569 .6554 Mdot
.60449 .63343 Mdot
.404 .5547 Mdot
.60331 .66423 Mdot
.25904 .69565 Mdot
.33053 .35196 Mdot
.47526 .30286 Mdot
.64091 .36031 Mdot
.62633 .65755 Mdot
.38559 .60543 Mdot
.40019 .25038 Mdot
.47469 .29676 Mdot
.35951 .37678 Mdot
.67113 .43946 Mdot
.47969 .1327 Mdot
.45872 .58397 Mdot
.65375 .39414 Mdot
.54351 .57877 Mdot
.39597 .58806 Mdot
.43949 .35176 Mdot
.26258 .65075 Mdot
.68183 .56385 Mdot
.43588 .60997 Mdot
.38415 .63197 Mdot
.66096 .35278 Mdot
.5484 .41989 Mdot
.42956 .56105 Mdot
.48582 .43981 Mdot
.6429 .40158 Mdot
.4964 .35365 Mdot
.53996 .86079 Mdot
.6686 .31719 Mdot
.2482 .39054 Mdot
.67089 .55846 Mdot
.43592 .55888 Mdot
.47177 .34842 Mdot
.36321 .38392 Mdot
.47227 .3429 Mdot
.65007 .6584 Mdot
.44023 .35932 Mdot
.38298 .59097 Mdot
.61491 .62414 Mdot
.65403 .3644 Mdot
.43986 .45872 Mdot
.40887 .81067 Mdot
.43981 .32365 Mdot
.68545 .56801 Mdot
.44097 .59349 Mdot
.39686 .73395 Mdot
.33873 .58853 Mdot
.44317 .60393 Mdot
.61049 .373 Mdot
.62441 .64957 Mdot
.6116 .38559 Mdot
.46099 .59999 Mdot
.44896 .68264 Mdot
.62795 .35891 Mdot
.70988 .68499 Mdot
.33766 .36312 Mdot
.23827 .43036 Mdot
.40361 .59902 Mdot
.62851 .34778 Mdot
.37693 .54827 Mdot
.63334 .62388 Mdot
.55267 .49997 Mdot
.61402 .58116 Mdot
.62937 .34431 Mdot
.78421 .61042 Mdot
.55043 .44893 Mdot
.48875 .57926 Mdot
.63203 .35038 Mdot
.58779 .78517 Mdot
.68545 .54594 Mdot
.32278 .3821 Mdot
.34199 .35784 Mdot
.34489 .40408 Mdot
.43814 .56524 Mdot
.32457 .63695 Mdot
.35739 .40523 Mdot
.6141 .39347 Mdot
.36525 .39438 Mdot
.21602 .51785 Mdot
.76308 .56444 Mdot
.35275 .371 Mdot
.4057 .60098 Mdot
.4629 .60676 Mdot
.3601 .43772 Mdot
.48156 .36924 Mdot
.80739 .41311 Mdot
.33164 .7523 Mdot
.43632 .57828 Mdot
.34708 .6879 Mdot
.6511 .64062 Mdot
.50341 .52452 Mdot
.50851 .63246 Mdot
.55438 .39295 Mdot
.62207 .65908 Mdot
.5827 .46495 Mdot
.57642 .65331 Mdot
.44645 .61906 Mdot
.42062 .60128 Mdot
.60613 .68384 Mdot
.73943 .49297 Mdot
.66204 .76719 Mdot
.75815 .57791 Mdot
.59102 .62461 Mdot
.63955 .35014 Mdot
.64568 .39927 Mdot
.61048 .3692 Mdot
.49023 .34713 Mdot
.62468 .66824 Mdot
.39516 .53846 Mdot
.44671 .32268 Mdot
.41031 .61783 Mdot
.6411 .38258 Mdot
.60393 .55334 Mdot
.60329 .67096 Mdot
.40931 .58724 Mdot
.36568 .76964 Mdot
.45602 .3411 Mdot
.32715 .37709 Mdot
.69052 .43135 Mdot
.41738 .33266 Mdot
.66743 .37595 Mdot
.58892 .60405 Mdot
.52164 .35339 Mdot
.36419 .24071 Mdot
.37754 .53799 Mdot
.37938 .53813 Mdot
.499 .28349 Mdot
.39749 .79522 Mdot
.41534 .56356 Mdot
.45435 .31661 Mdot
.43659 .36106 Mdot
.38065 .54229 Mdot
.64008 .65098 Mdot
.36266 .4063 Mdot
.32421 .4017 Mdot
.4036 .63786 Mdot
.59167 .48606 Mdot
.26134 .41943 Mdot
.38653 .56474 Mdot
.45278 .64936 Mdot
.48484 .37123 Mdot
.67062 .56246 Mdot
.5837 .51473 Mdot
.33052 .40148 Mdot
.4242 .60559 Mdot
.67999 .74759 Mdot
.61388 .66902 Mdot
.47265 .3594 Mdot
.64652 .38976 Mdot
.2982 .37337 Mdot
.49833 .31237 Mdot
.38098 .54195 Mdot
.3962 .55904 Mdot
.64171 .34509 Mdot
.58813 .59864 Mdot
.34074 .3918 Mdot
.44263 .3263 Mdot
.3132 .38423 Mdot
.59912 .63356 Mdot
.61597 .66354 Mdot
.4032 .64865 Mdot
.33961 .6008 Mdot
.46062 .31097 Mdot
.36083 .61499 Mdot
.48067 .32224 Mdot
.4775 .21789 Mdot
.64975 .39138 Mdot
.37868 .62577 Mdot
.55696 .65398 Mdot
.64024 .38192 Mdot
.43081 .57197 Mdot
.50098 .28462 Mdot
.39642 .56531 Mdot
.41844 .35429 Mdot
.27506 .67239 Mdot
.32724 .39562 Mdot
.36472 .50324 Mdot
.43974 .50345 Mdot
.36939 .59057 Mdot
.45291 .37156 Mdot
.31824 .61576 Mdot
.62672 .36202 Mdot
.61451 .63573 Mdot
.2025 .36809 Mdot
.64212 .36858 Mdot
.40755 .60858 Mdot
.34508 .38453 Mdot
.58096 .6318 Mdot
.69131 .53431 Mdot
.61154 .49317 Mdot
.47028 .55743 Mdot
.3923 .52092 Mdot
.38169 .61358 Mdot
.48284 .17436 Mdot
.48023 .34482 Mdot
.62834 .64977 Mdot
.6447 .39768 Mdot
.62689 .3773 Mdot
.4599 .33392 Mdot
.74668 .65277 Mdot
.76555 .51183 Mdot
.22279 .75513 Mdot
.48916 .30721 Mdot
.35913 .3996 Mdot
.55377 .48517 Mdot
.47332 .32148 Mdot
.47384 .35216 Mdot
.50271 .35719 Mdot
.73977 .59112 Mdot
.59676 .62203 Mdot
.42651 .59451 Mdot
.56216 .6477 Mdot
.43706 .56005 Mdot
.26171 .37608 Mdot
.63449 .37996 Mdot
.61265 .63481 Mdot
.42233 .2937 Mdot
.4328 .51003 Mdot
.4028 .5791 Mdot
.29143 .34749 Mdot
.45194 .54086 Mdot
.29217 .47004 Mdot
.37991 .64344 Mdot
.46717 .34012 Mdot
.48372 .65865 Mdot
.45487 .63795 Mdot
.35584 .7593 Mdot
.65562 .37283 Mdot
.69475 .53133 Mdot
.46324 .57274 Mdot
.48664 .61336 Mdot
.57885 .63271 Mdot
.64321 .65714 Mdot
.35804 .40546 Mdot
.70866 .41496 Mdot
.65599 .36985 Mdot
.80435 .50073 Mdot
.44607 .59738 Mdot
.58391 .35797 Mdot
.26981 .66958 Mdot
.4243 .57151 Mdot
.53042 .38407 Mdot
.5897 .75851 Mdot
.40754 .56357 Mdot
.45817 .75843 Mdot
.63921 .36319 Mdot
.2038 .59436 Mdot
.36936 .6314 Mdot
.44121 .35247 Mdot
.6104 .63014 Mdot
.63402 .61714 Mdot
.36134 .37588 Mdot
.28044 .72369 Mdot
.63587 .42053 Mdot
.60785 .63295 Mdot
.39011 .59468 Mdot
.64429 .35759 Mdot
.69008 .5323 Mdot
.44968 .52555 Mdot
.62405 .21858 Mdot
.6036 .66679 Mdot
.40909 .66097 Mdot
.76056 .58527 Mdot
.56518 .44383 Mdot
.83925 .48654 Mdot
.60977 .36063 Mdot
.32993 .40179 Mdot
.34949 .62218 Mdot
.50799 .2372 Mdot
.36807 .63326 Mdot
.25637 .38156 Mdot
.56163 .67627 Mdot
.31302 .36916 Mdot
.39927 .58883 Mdot
.42702 .5607 Mdot
.57551 .49475 Mdot
.33126 .3558 Mdot
.42953 .56063 Mdot
.38269 .65533 Mdot
.59003 .634 Mdot
.66576 .57277 Mdot
.59892 .66816 Mdot
.39609 .60614 Mdot
.27509 .64858 Mdot
.64304 .64911 Mdot
.80448 .42354 Mdot
.37757 .36375 Mdot
.61947 .369 Mdot
.461 .63724 Mdot
.43466 .61594 Mdot
.80003 .34008 Mdot
.68224 .53519 Mdot
.2739 .27913 Mdot
.41551 .3475 Mdot
.68313 .7848 Mdot
.41974 .32817 Mdot
.79869 .57502 Mdot
.46523 .46105 Mdot
.35708 .58925 Mdot
.31936 .50844 Mdot
.44637 .75646 Mdot
.63535 .32817 Mdot
.40841 .71608 Mdot
.44536 .5968 Mdot
.43735 .59387 Mdot
.46046 .31754 Mdot
.75769 .63223 Mdot
.55662 .57709 Mdot
.58251 .50974 Mdot
.33273 .39418 Mdot
.60268 .63969 Mdot
.38572 .58666 Mdot
.70722 .47003 Mdot
.42779 .33689 Mdot
.29016 .59944 Mdot
.40916 .58953 Mdot
.56895 .56535 Mdot
.72818 .65187 Mdot
.65259 .36008 Mdot
.42835 .35963 Mdot
.43748 .36793 Mdot
.43325 .55257 Mdot
.62599 .38887 Mdot
.40713 .55793 Mdot
.54808 .45249 Mdot
.47304 .57347 Mdot
.31711 .37046 Mdot
.4034 .62158 Mdot
.34314 .48681 Mdot
.80883 .60763 Mdot
.47889 .6024 Mdot
.57153 .64176 Mdot
.4906 .34012 Mdot
.4685 .32998 Mdot
.58628 .63394 Mdot
.46765 .32959 Mdot
.48395 .73132 Mdot
.37727 .70202 Mdot
.32125 .36695 Mdot
.41992 .77595 Mdot
.32705 .39328 Mdot
.69588 .53162 Mdot
.42677 .57754 Mdot
.5552 .23508 Mdot
.49041 .30724 Mdot
.2083 .55212 Mdot
.63502 .37449 Mdot
.67797 .53826 Mdot
.41977 .53779 Mdot
.29643 .39384 Mdot
.45208 .32837 Mdot
.64395 .30131 Mdot
.43005 .54695 Mdot
.6161 .61677 Mdot
.41272 .5618 Mdot
.4276 .53188 Mdot
.66774 .55201 Mdot
.37951 .613 Mdot
.65137 .35469 Mdot
.62301 .6704 Mdot
.79632 .56653 Mdot
.49172 .34775 Mdot
.43543 .60674 Mdot
.3913 .5935 Mdot
.64183 .66353 Mdot
.42436 .53836 Mdot
.61682 .38333 Mdot
.44575 .9125 Mdot
.33347 .36325 Mdot
.67122 .56363 Mdot
.74067 .34277 Mdot
.38023 .58454 Mdot
.38302 .5706 Mdot
.56566 .37647 Mdot
.66532 .74988 Mdot
.63338 .3543 Mdot
.45935 .55737 Mdot
.43108 .34093 Mdot
.34435 .39267 Mdot
.60597 .35509 Mdot
.37146 .55706 Mdot
.43714 .59167 Mdot
.32167 .36518 Mdot
.28911 .35082 Mdot
.41377 .32135 Mdot
.61453 .37458 Mdot
.35907 .68714 Mdot
.40819 .24992 Mdot
.4236 .58718 Mdot
.69116 .51463 Mdot
.61898 .65356 Mdot
.62571 .35285 Mdot
.6422 .74386 Mdot
.439 .62414 Mdot
.66624 .36548 Mdot
.65488 .3662 Mdot
.43177 .54267 Mdot
.56212 .62688 Mdot
.57336 .62216 Mdot
.62038 .65462 Mdot
.21583 .5977 Mdot
.3549 .22533 Mdot
.48579 .34508 Mdot
.64498 .36251 Mdot
.43212 .32291 Mdot
.34921 .41166 Mdot
.56496 .48119 Mdot
.42983 .35793 Mdot
.59435 .61716 Mdot
.44955 .31156 Mdot
.40128 .56059 Mdot
.65259 .3821 Mdot
.47191 .30853 Mdot
.37373 .57663 Mdot
.43802 .65754 Mdot
.33437 .49758 Mdot
.36691 .40379 Mdot
.58435 .46628 Mdot
.40274 .60778 Mdot
.67829 .55978 Mdot
.41682 .57977 Mdot
.62159 .38832 Mdot
.38326 .44502 Mdot
.37627 .559 Mdot
.48829 .30635 Mdot
.38191 .22615 Mdot
.45872 .37138 Mdot
.42439 .53399 Mdot
.39759 .60603 Mdot
.4267 .58599 Mdot
.4462 .56979 Mdot
.71824 .68606 Mdot
.60446 .34501 Mdot
.38176 .67031 Mdot
.50085 .31836 Mdot
.59835 .65329 Mdot
.64208 .6339 Mdot
.55837 .38224 Mdot
.67849 .53577 Mdot
.62846 .38851 Mdot
.42783 .58692 Mdot
.64011 .30175 Mdot
.6335 .49314 Mdot
.76121 .57943 Mdot
.53176 .32858 Mdot
.45948 .31368 Mdot
.57013 .63924 Mdot
.48589 .3177 Mdot
.37221 .55383 Mdot
.37179 .64157 Mdot
.80171 .55738 Mdot
.60942 .39457 Mdot
.33923 .39224 Mdot
.40713 .61863 Mdot
.24642 .41457 Mdot
.43503 .33464 Mdot
.47676 .37378 Mdot
.40899 .55585 Mdot
.62285 .60217 Mdot
.84317 .55662 Mdot
.63674 .39081 Mdot
.39107 .73186 Mdot
.54711 .60779 Mdot
.36046 .67695 Mdot
.62851 .36564 Mdot
.50468 .40424 Mdot
.48486 .36493 Mdot
.31543 .74535 Mdot
.60411 .65812 Mdot
.33646 .39062 Mdot
.40182 .65645 Mdot
.59364 .61756 Mdot
.4394 .31539 Mdot
.58181 .66483 Mdot
.42464 .63493 Mdot
.61889 .39499 Mdot
.47191 .3259 Mdot
.6221 .333 Mdot
.60799 .68243 Mdot
.32749 .39455 Mdot
.21614 .54981 Mdot
.38115 .73358 Mdot
.59007 .75821 Mdot
.38429 .54846 Mdot
.59379 .25016 Mdot
.39867 .53802 Mdot
.58169 .62059 Mdot
.40374 .59946 Mdot
.36977 .49385 Mdot
.49568 .35824 Mdot
.4364 .65017 Mdot
.41113 .62242 Mdot
.34546 .74598 Mdot
.41373 .57242 Mdot
.41049 .53555 Mdot
.38966 .63672 Mdot
.57376 .6018 Mdot
.43543 .64955 Mdot
.61629 .6173 Mdot
.7372 .61093 Mdot
.47081 .35292 Mdot
.33196 .40741 Mdot
.30625 .37923 Mdot
.25348 .38024 Mdot
.24169 .42573 Mdot
.74957 .64273 Mdot
.58891 .65545 Mdot
.66011 .35842 Mdot
.405 .55798 Mdot
.57599 .79735 Mdot
.26857 .59865 Mdot
.49119 .35915 Mdot
.45677 .31039 Mdot
.38309 .64958 Mdot
.56886 .16244 Mdot
.42652 .65452 Mdot
.61638 .50342 Mdot
.43935 .56314 Mdot
.38309 .6282 Mdot
.46433 .37635 Mdot
.22584 .48258 Mdot
.38326 .54939 Mdot
.57878 .63336 Mdot
.32884 .38594 Mdot
.41232 .68425 Mdot
.26034 .60023 Mdot
.30259 .6498 Mdot
.51697 .58907 Mdot
.36762 .57207 Mdot
.43871 .33347 Mdot
.58663 .62651 Mdot
.59696 .51244 Mdot
.61623 .37891 Mdot
.60124 .48845 Mdot
.36149 .72928 Mdot
.7033 .33535 Mdot
.33397 .39094 Mdot
.49052 .29319 Mdot
.38221 .59159 Mdot
.4897 .34649 Mdot
.45622 .60629 Mdot
.63767 .48655 Mdot
.31416 .37322 Mdot
.57536 .66615 Mdot
.64049 .35026 Mdot
.61034 .61422 Mdot
.55775 .79545 Mdot
.2701 .61086 Mdot
.68264 .78583 Mdot
.45662 .36467 Mdot
.55017 .6878 Mdot
.6253 .63516 Mdot
.41844 .54073 Mdot
.21666 .74703 Mdot
.61704 .64956 Mdot
.60799 .61552 Mdot
.55127 .39781 Mdot
.22572 .53987 Mdot
.4277 .65639 Mdot
.57904 .65756 Mdot
.51688 .33283 Mdot
.34081 .37438 Mdot
.3773 .57037 Mdot
.42035 .63298 Mdot
.64215 .65851 Mdot
.45326 .33017 Mdot
.24352 .40794 Mdot
.47116 .33691 Mdot
.6017 .62089 Mdot
.45123 .34699 Mdot
.80026 .42694 Mdot
.42675 .34646 Mdot
.41048 .62324 Mdot
.42673 .5875 Mdot
.57709 .2105 Mdot
.61592 .66355 Mdot
.38086 .57287 Mdot
.42832 .60054 Mdot
.62387 .62889 Mdot
.40383 .3566 Mdot
.62241 .73633 Mdot
.37333 .58572 Mdot
.4281 .59083 Mdot
.31277 .36572 Mdot
.56905 .46107 Mdot
.66307 .4967 Mdot
.37838 .57162 Mdot
.35007 .40259 Mdot
.56764 .6524 Mdot
.41632 .5785 Mdot
.22482 .48023 Mdot
.43588 .31342 Mdot
.36364 .58862 Mdot
.69541 .53567 Mdot
.42113 .56373 Mdot
.83883 .55985 Mdot
.43919 .5972 Mdot
.63083 .6401 Mdot
.61774 .63123 Mdot
.42782 .31247 Mdot
.60075 .64883 Mdot
.66953 .55168 Mdot
.64534 .37961 Mdot
.7795 .63229 Mdot
.67162 .54727 Mdot
.39448 .62821 Mdot
.30899 .75362 Mdot
.41393 .63615 Mdot
.46528 .60846 Mdot
.20855 .53831 Mdot
.67088 .5557 Mdot
.62466 .646 Mdot
.73878 .48813 Mdot
.3588 .5933 Mdot
.63275 .3904 Mdot
.46086 .61663 Mdot
.36344 .58885 Mdot
.34604 .49573 Mdot
.3774 .69782 Mdot
.63478 .33713 Mdot
.49223 .57854 Mdot
.37809 .56942 Mdot
.66039 .75034 Mdot
.38455 .59656 Mdot
.35478 .37113 Mdot
.58453 .65201 Mdot
.49318 .32238 Mdot
.32787 .3676 Mdot
.38151 .58765 Mdot
.33792 .38751 Mdot
.48464 .34776 Mdot
.61411 .35179 Mdot
.39848 .62127 Mdot
.32045 .35314 Mdot
.33911 .39426 Mdot
.40733 .54592 Mdot
.61053 .63249 Mdot
.33953 .5786 Mdot
.41726 .57662 Mdot
.391 .53562 Mdot
.58608 .63511 Mdot
.17809 .6287 Mdot
.44353 .56201 Mdot
.50981 .40024 Mdot
.60324 .68922 Mdot
.66528 .56641 Mdot
.47433 .31578 Mdot
.34951 .58847 Mdot
.6268 .37995 Mdot
.64056 .37912 Mdot
.50714 .33588 Mdot
.63067 .67127 Mdot
.46827 .32589 Mdot
.47451 .55387 Mdot
.37823 .64873 Mdot
.39858 .65569 Mdot
.20357 .36651 Mdot
.77567 .38069 Mdot
.63332 .65268 Mdot
.47425 .37006 Mdot
.593 .4921 Mdot
.63922 .38822 Mdot
.49758 .3655 Mdot
.56904 .67458 Mdot
.60774 .67631 Mdot
.58335 .63574 Mdot
.34732 .40019 Mdot
.4778 .33056 Mdot
.59272 .69381 Mdot
.58058 .61462 Mdot
.40953 .55079 Mdot
.37836 .56773 Mdot
.65509 .63929 Mdot
.38238 .41478 Mdot
.31755 .38152 Mdot
.4361 .34298 Mdot
.8607 .42093 Mdot
.63697 .39111 Mdot
.34568 .74686 Mdot
.37349 .57825 Mdot
.09242 .54056 Mdot
.42652 .6538 Mdot
.38825 .59535 Mdot
.58915 .67489 Mdot
.30439 .36241 Mdot
.34002 .37704 Mdot
.62438 .63406 Mdot
.60595 .60033 Mdot
.35611 .3925 Mdot
.54312 .38783 Mdot
.78315 .6525 Mdot
.59657 .50498 Mdot
.6314 .63508 Mdot
.38963 .74089 Mdot
.60854 .35287 Mdot
.58698 .68284 Mdot
.62801 .33401 Mdot
.47259 .35347 Mdot
.44031 .32158 Mdot
.642 .34411 Mdot
.42513 .54153 Mdot
.45092 .36162 Mdot
.47835 .57545 Mdot
.81795 .51635 Mdot
.66985 .25574 Mdot
.59291 .81103 Mdot
.44827 .59771 Mdot
.55141 .57384 Mdot
.71078 .60669 Mdot
.37723 .60798 Mdot
.49061 .56343 Mdot
.33929 .39071 Mdot
.59588 .68651 Mdot
.60358 .35458 Mdot
.81935 .42074 Mdot
.42489 .58695 Mdot
.6101 .61991 Mdot
.64757 .38604 Mdot
.79562 .42601 Mdot
.48598 .43869 Mdot
.42178 .55541 Mdot
.27773 .81023 Mdot
.60705 .68145 Mdot
.49337 .32285 Mdot
.39593 .77831 Mdot
.56404 .65565 Mdot
.40466 .2406 Mdot
.42603 .36304 Mdot
.62633 .54512 Mdot
.59482 .67515 Mdot
.40296 .34083 Mdot
.59748 .63689 Mdot
.36652 .37653 Mdot
.58937 .6034 Mdot
.4523 .33775 Mdot
.40433 .58276 Mdot
.45584 .33761 Mdot
.3336 .36035 Mdot
.47248 .36171 Mdot
.60398 .35399 Mdot
.67268 .55984 Mdot
.64996 .38045 Mdot
.56108 .48027 Mdot
.56259 .71627 Mdot
.61432 .3592 Mdot
.62454 .30099 Mdot
.40873 .56645 Mdot
.59213 .59762 Mdot
.49819 .32695 Mdot
.50017 .30827 Mdot
.58964 .47517 Mdot
.59958 .62487 Mdot
.44672 .34058 Mdot
.3711 .72692 Mdot
.12959 .48539 Mdot
.46658 .62665 Mdot
.37061 .21625 Mdot
.62564 .62946 Mdot
.49385 .36114 Mdot
.60821 .50842 Mdot
.64155 .62587 Mdot
.46625 .30945 Mdot
.63582 .34921 Mdot
.62459 .37493 Mdot
.4393 .5501 Mdot
.65262 .40336 Mdot
.45323 .3722 Mdot
.67603 .7488 Mdot
.58315 .64679 Mdot
.76162 .37016 Mdot
.3562 .37627 Mdot
.47835 .35125 Mdot
.43405 .65273 Mdot
.57889 .69232 Mdot
.47154 .3058 Mdot
.61481 .20195 Mdot
.83681 .37822 Mdot
.44594 .34137 Mdot
.58489 .65333 Mdot
.59527 .65467 Mdot
.47683 .60529 Mdot
.58581 .4948 Mdot
.44936 .33242 Mdot
.55375 .23355 Mdot
.26279 .39014 Mdot
.68594 .53818 Mdot
.3514 .77565 Mdot
.38248 .54955 Mdot
.36655 .575 Mdot
.61515 .38076 Mdot
.40223 .57719 Mdot
.5986 .60487 Mdot
.41684 .65608 Mdot
.63618 .40137 Mdot
.4957 .35346 Mdot
.42604 .58104 Mdot
.35066 .39099 Mdot
.60935 .37576 Mdot
.66551 .38609 Mdot
.45756 .35183 Mdot
.58116 .65279 Mdot
.72701 .49635 Mdot
.47244 .33565 Mdot
.37259 .55709 Mdot
.67775 .55203 Mdot
.37868 .64121 Mdot
.58066 .21782 Mdot
.62361 .61423 Mdot
.48683 .31846 Mdot
.63608 .67667 Mdot
.64856 .36578 Mdot
.51166 .32987 Mdot
.3804 .59995 Mdot
.45257 .31475 Mdot
.49204 .40661 Mdot
.3265 .29559 Mdot
.58834 .60785 Mdot
.33529 .42344 Mdot
.64318 .65878 Mdot
.68674 .53757 Mdot
.25681 .51075 Mdot
.3209 .38132 Mdot
.43309 .35315 Mdot
.80462 .41643 Mdot
.50044 .3259 Mdot
.41762 .57067 Mdot
.44302 .57693 Mdot
.46275 .31694 Mdot
.33619 .40093 Mdot
.22014 .43042 Mdot
.27483 .38204 Mdot
.61706 .66983 Mdot
.48303 .47536 Mdot
.86971 .46306 Mdot
.4949 .37503 Mdot
.65851 .35511 Mdot
.49216 .62536 Mdot
.39519 .56867 Mdot
.66349 .35551 Mdot
.64273 .3947 Mdot
.33136 .35856 Mdot
.48745 .34944 Mdot
.60155 .69232 Mdot
.62216 .34491 Mdot
.6071 .70616 Mdot
.23008 .44135 Mdot
.44162 .53464 Mdot
.33122 .63654 Mdot
.42088 .62451 Mdot
.56615 .44484 Mdot
.62328 .3953 Mdot
.40925 .60445 Mdot
.37085 .64602 Mdot
.62424 .35553 Mdot
.34437 .36144 Mdot
.64976 .68957 Mdot
.44444 .3494 Mdot
.11162 .50681 Mdot
.39996 .6214 Mdot
.40922 .57977 Mdot
.6171 .37594 Mdot
.41676 .80473 Mdot
.63594 .64409 Mdot
.58213 .65637 Mdot
.48128 .34448 Mdot
.60602 .46521 Mdot
.41038 .53309 Mdot
.38579 .61147 Mdot
.44556 .35824 Mdot
.67828 .55896 Mdot
.53332 .84714 Mdot
.42163 .59567 Mdot
.63515 .36268 Mdot
.59806 .31223 Mdot
.61745 .39141 Mdot
.45916 .58759 Mdot
.42329 .56913 Mdot
.39275 .62385 Mdot
.45237 .57909 Mdot
.64104 .34199 Mdot
.38018 .60872 Mdot
.36654 .52902 Mdot
.62303 .64997 Mdot
.37241 .5623 Mdot
.25852 .39807 Mdot
.42024 .59277 Mdot
.35019 .39036 Mdot
.6717 .49462 Mdot
.43383 .60641 Mdot
.37115 .56386 Mdot
.27304 .37543 Mdot
.39674 .59301 Mdot
.65869 .37729 Mdot
.60126 .65871 Mdot
.64864 .36344 Mdot
.65843 .36197 Mdot
.45927 .30762 Mdot
.36016 .36645 Mdot
.35997 .62168 Mdot
.35677 .39407 Mdot
.47718 .5828 Mdot
.43792 .62593 Mdot
.56655 .47046 Mdot
.61724 .50264 Mdot
.37736 .39826 Mdot
.38278 .60548 Mdot
.47584 .34746 Mdot
.48165 .3154 Mdot
.37906 .44233 Mdot
.47424 .56953 Mdot
.6074 .35203 Mdot
.62868 .34788 Mdot
.34529 .45713 Mdot
.39179 .46154 Mdot
.34433 .39529 Mdot
.54518 .5165 Mdot
.42747 .62746 Mdot
.43192 .6018 Mdot
.46296 .60823 Mdot
.41822 .34376 Mdot
.67239 .56169 Mdot
.49556 .35164 Mdot
.70789 .54171 Mdot
.60216 .3705 Mdot
.44784 .59859 Mdot
.68743 .27327 Mdot
.63672 .66045 Mdot
.60216 .65985 Mdot
.64267 .40109 Mdot
.45784 .3716 Mdot
.47321 .57028 Mdot
.21786 .3174 Mdot
.62438 .60862 Mdot
.33001 .40525 Mdot
.39508 .61154 Mdot
.4634 .352 Mdot
.62378 .67146 Mdot
.37072 .37412 Mdot
.4442 .60714 Mdot
.47428 .37734 Mdot
.41043 .59653 Mdot
.46256 .77173 Mdot
.62064 .64174 Mdot
.60584 .55043 Mdot
.64262 .61133 Mdot
.65987 .35367 Mdot
.6408 .35381 Mdot
.42965 .57118 Mdot
.16139 .39766 Mdot
.66077 .65319 Mdot
.66433 .35162 Mdot
.37054 .38698 Mdot
.6757 .56329 Mdot
.37125 .38022 Mdot
.47893 .32136 Mdot
.32924 .38751 Mdot
.47543 .30644 Mdot
.38835 .41412 Mdot
.64795 .6739 Mdot
.3294 .36501 Mdot
.4212 .8107 Mdot
.3707 .64016 Mdot
.32452 .35895 Mdot
.3853 .65018 Mdot
.39691 .496 Mdot
.45233 .35892 Mdot
.34464 .39908 Mdot
.41913 .54559 Mdot
.74235 .33124 Mdot
.65133 .35593 Mdot
.60663 .35159 Mdot
.36542 .63027 Mdot
.49759 .36045 Mdot
.59041 .60481 Mdot
.53522 .42186 Mdot
.66678 .56772 Mdot
.38634 .61121 Mdot
.44065 .61517 Mdot
.62443 .68056 Mdot
.58286 .62381 Mdot
.42925 .56938 Mdot
.37657 .72143 Mdot
.38105 .59188 Mdot
.62359 .37177 Mdot
.62249 .66893 Mdot
.59839 .65872 Mdot
.43684 .36481 Mdot
.63154 .67034 Mdot
.35351 .65466 Mdot
.68441 .36542 Mdot
.42246 .64561 Mdot
.64614 .36766 Mdot
.39594 .42997 Mdot
.4881 .35203 Mdot
.80528 .40909 Mdot
.62503 .67318 Mdot
.36917 .60051 Mdot
.64218 .63624 Mdot
.34943 .37121 Mdot
.61432 .66467 Mdot
.65254 .64232 Mdot
.4461 .58987 Mdot
.43247 .55757 Mdot
.67902 .55613 Mdot
.5891 .48725 Mdot
.61491 .63985 Mdot
.37462 .59326 Mdot
.37427 .63311 Mdot
.44003 .55731 Mdot
.55173 .44742 Mdot
.5802 .66767 Mdot
.32218 .70342 Mdot
.62095 .2315 Mdot
.61019 .63516 Mdot
.84808 .45805 Mdot
.69467 .55401 Mdot
.68061 .53408 Mdot
.67045 .35579 Mdot
.42693 .59358 Mdot
.46484 .32846 Mdot
.36444 .58076 Mdot
.47487 .56762 Mdot
.43257 .6098 Mdot
.31825 .36568 Mdot
.37329 .54075 Mdot
.69402 .54471 Mdot
.46658 .33722 Mdot
.37661 .58721 Mdot
.43083 .583 Mdot
.6899 .52945 Mdot
.64986 .61895 Mdot
.60773 .67581 Mdot
.66939 .51956 Mdot
.34665 .36352 Mdot
.61227 .37557 Mdot
.36657 .56993 Mdot
.47814 .34581 Mdot
.46142 .33373 Mdot
.60979 .6147 Mdot
.4399 .34971 Mdot
.61367 .38355 Mdot
.38672 .59188 Mdot
.6588 .3515 Mdot
.31877 .36549 Mdot
.58438 .65132 Mdot
.36977 .55966 Mdot
.41241 .5495 Mdot
.618 .63146 Mdot
.41309 .56437 Mdot
.31217 .36778 Mdot
.42282 .33965 Mdot
.62465 .6632 Mdot
.64454 .37914 Mdot
.43268 .36167 Mdot
.39866 .56003 Mdot
.75197 .27035 Mdot
.40168 .57676 Mdot
.38947 .61837 Mdot
.78932 .61056 Mdot
.38854 .64421 Mdot
.50025 .33918 Mdot
.64412 .6395 Mdot
.45879 .57924 Mdot
.26599 .38403 Mdot
.38764 .31762 Mdot
.45263 .37895 Mdot
.39394 .61301 Mdot
.83558 .46028 Mdot
.36864 .59623 Mdot
.80914 .45063 Mdot
.56718 .47171 Mdot
.49754 .17802 Mdot
.32946 .62941 Mdot
.6652 .35367 Mdot
.67663 .55817 Mdot
.50289 .33508 Mdot
.50191 .80533 Mdot
.40779 .56988 Mdot
.60921 .76685 Mdot
.36473 .57219 Mdot
.62714 .36754 Mdot
.5051 .59388 Mdot
.43646 .3448 Mdot
.33538 .75606 Mdot
.39093 .53827 Mdot
.59124 .67504 Mdot
.51167 .31844 Mdot
.68258 .56218 Mdot
.42239 .54555 Mdot
.35992 .38394 Mdot
.40176 .31785 Mdot
.34988 .64749 Mdot
.64727 .36971 Mdot
.42739 .60324 Mdot
.4942 .60521 Mdot
.14137 .46963 Mdot
.62422 .65329 Mdot
.65165 .35126 Mdot
.50019 .53572 Mdot
.44341 .57026 Mdot
.60532 .67593 Mdot
.60209 .65645 Mdot
.36449 .38215 Mdot
.63874 .4746 Mdot
.36511 .32312 Mdot
.67999 .24412 Mdot
.58158 .77164 Mdot
.41692 .34866 Mdot
.69358 .68848 Mdot
.38027 .55803 Mdot
.2709 .61797 Mdot
.659 .36708 Mdot
.40637 .58242 Mdot
.56102 .75264 Mdot
.62009 .65795 Mdot
.41308 .59903 Mdot
.31714 .37913 Mdot
.7287 .56404 Mdot
.32934 .67329 Mdot
.77904 .31953 Mdot
.51348 .34539 Mdot
.44655 .63677 Mdot
.34201 .63437 Mdot
.66552 .56571 Mdot
.45825 .59 Mdot
.50032 .33143 Mdot
.60272 .25677 Mdot
.32747 .39769 Mdot
.63412 .66351 Mdot
.69197 .55772 Mdot
.36166 .5825 Mdot
.39769 .64056 Mdot
.33577 .40841 Mdot
.40931 .53956 Mdot
.37831 .76513 Mdot
.68883 .52479 Mdot
.42596 .34584 Mdot
.57913 .66107 Mdot
.42248 .62455 Mdot
.67532 .56145 Mdot
.44601 .58548 Mdot
.40731 .48906 Mdot
.39941 .61459 Mdot
.75612 .65889 Mdot
.60901 .63 Mdot
.65039 .37273 Mdot
.36695 .54648 Mdot
.41646 .58849 Mdot
.40939 .2517 Mdot
.47328 .56434 Mdot
.43915 .59542 Mdot
.59179 .61647 Mdot
.64134 .6525 Mdot
.60269 .6181 Mdot
.42911 .35259 Mdot
.59075 .50831 Mdot
.6319 .37181 Mdot
.47016 .59316 Mdot
.61294 .34922 Mdot
.33512 .55615 Mdot
.34561 .40741 Mdot
.7955 .37803 Mdot
.39011 .58068 Mdot
.58999 .62901 Mdot
.69314 .7212 Mdot
.56711 .65138 Mdot
.62416 .4122 Mdot
.65613 .37107 Mdot
.61566 .64682 Mdot
.39411 .59812 Mdot
.58123 .50943 Mdot
.74582 .27793 Mdot
.64022 .38734 Mdot
.44959 .62521 Mdot
.51544 .34157 Mdot
.49955 .31095 Mdot
.8519 .51602 Mdot
.66236 .36665 Mdot
.70866 .6067 Mdot
.37131 .59184 Mdot
.63806 .66137 Mdot
.61113 .36304 Mdot
.65917 .37984 Mdot
.44165 .35566 Mdot
.41768 .55438 Mdot
.4153 .59091 Mdot
.69676 .53699 Mdot
.6175 .34889 Mdot
.41841 .51338 Mdot
.42117 .55801 Mdot
.79824 .57081 Mdot
.57267 .67944 Mdot
.1822 .64183 Mdot
.47944 .55991 Mdot
.5676 .74985 Mdot
.44532 .44 Mdot
.63127 .65893 Mdot
.40444 .53516 Mdot
.47139 .58991 Mdot
.42036 .35411 Mdot
.39036 .58687 Mdot
.47498 .3667 Mdot
.66211 .35946 Mdot
.80326 .3815 Mdot
.61814 .31104 Mdot
.68398 .35386 Mdot
.40735 .57486 Mdot
.32802 .66686 Mdot
.33664 .36727 Mdot
.60073 .38294 Mdot
.62649 .62308 Mdot
.41906 .62847 Mdot
.41411 .35362 Mdot
.42981 .34872 Mdot
.60876 .65649 Mdot
.71938 .62797 Mdot
.80534 .42493 Mdot
.45317 .58331 Mdot
.47717 .31809 Mdot
.66883 .30554 Mdot
.41564 .70676 Mdot
.67167 .36936 Mdot
.3242 .39514 Mdot
.49797 .34414 Mdot
.63169 .40539 Mdot
.38677 .49424 Mdot
.60756 .64764 Mdot
.61833 .68092 Mdot
.45129 .24472 Mdot
.4511 .33437 Mdot
.32898 .37208 Mdot
.42453 .45113 Mdot
.43361 .45556 Mdot
.31472 .37452 Mdot
.49176 .35904 Mdot
.63612 .65727 Mdot
.60677 .62007 Mdot
.59987 .65708 Mdot
.35626 .75981 Mdot
.63139 .6168 Mdot
.22863 .65094 Mdot
.44308 .61653 Mdot
.40038 .73431 Mdot
.37376 .60734 Mdot
.62987 .34071 Mdot
.62001 .63993 Mdot
.56903 .48334 Mdot
.39382 .63278 Mdot
.76539 .30569 Mdot
.40145 .60873 Mdot
.55248 .36257 Mdot
.42822 .59226 Mdot
.4101 .7756 Mdot
.60089 .68897 Mdot
.38088 .60472 Mdot
.67946 .35923 Mdot
.34361 .38967 Mdot
.66086 .63858 Mdot
.43668 .59831 Mdot
.75797 .592 Mdot
.3829 .64831 Mdot
.82609 .47911 Mdot
.36062 .24447 Mdot
.30588 .38372 Mdot
.40279 .65315 Mdot
.46607 .30318 Mdot
.51856 .59735 Mdot
.40627 .74519 Mdot
.64087 .38693 Mdot
.34189 .69457 Mdot
.43962 .35752 Mdot
.48941 .56217 Mdot
.41854 .52428 Mdot
.33426 .40194 Mdot
.65855 .66927 Mdot
.62225 .36978 Mdot
.40546 .56954 Mdot
.41083 .53636 Mdot
.57841 .19258 Mdot
.40318 .75085 Mdot
.40139 .51597 Mdot
.35479 .40927 Mdot
.34384 .70373 Mdot
.42931 .60977 Mdot
.45186 .37857 Mdot
.64479 .63549 Mdot
.38685 .66418 Mdot
.31684 .70447 Mdot
.37654 .59176 Mdot
.61485 .65054 Mdot
.62576 .6735 Mdot
.72076 .71768 Mdot
.34579 .40621 Mdot
.40007 .61449 Mdot
.43138 .2402 Mdot
.37197 .55741 Mdot
.6281 .37189 Mdot
.45984 .592 Mdot
.47031 .35699 Mdot
.61108 .51156 Mdot
.43011 .35451 Mdot
.43292 .55097 Mdot
.59171 .63875 Mdot
.61868 .37078 Mdot
.49884 .22291 Mdot
.57029 .41005 Mdot
.2263 .64592 Mdot
.3986 .3218 Mdot
.35337 .3923 Mdot
.36738 .37145 Mdot
.6792 .39574 Mdot
.39251 .60734 Mdot
.557 .4307 Mdot
.46706 .6154 Mdot
.4327 .59251 Mdot
.41031 .61975 Mdot
.63653 .32019 Mdot
.6548 .37231 Mdot
.45095 .34359 Mdot
.42808 .56859 Mdot
.37446 .59437 Mdot
.60641 .63753 Mdot
.33928 .39465 Mdot
.42584 .3367 Mdot
.34605 .36467 Mdot
.46836 .34132 Mdot
.8454 .54669 Mdot
.46083 .59801 Mdot
.34436 .38855 Mdot
.61545 .39108 Mdot
.59269 .62294 Mdot
.68779 .53184 Mdot
.47835 .32194 Mdot
.43779 .34258 Mdot
.37937 .60896 Mdot
.58912 .66386 Mdot
.59816 .67232 Mdot
.35515 .39297 Mdot
.62243 .35013 Mdot
.44427 .55215 Mdot
.4288 .55799 Mdot
.46555 .20513 Mdot
.4225 .35376 Mdot
.35845 .71867 Mdot
.72875 .68482 Mdot
.39077 .60726 Mdot
.59804 .67392 Mdot
.42189 .5807 Mdot
.66781 .28325 Mdot
.5906 .62095 Mdot
.37918 .63234 Mdot
.34245 .50368 Mdot
.4193 .34177 Mdot
.71144 .74753 Mdot
.35495 .59526 Mdot
.5747 .38559 Mdot
.39483 .54824 Mdot
.74157 .75303 Mdot
.67719 .72703 Mdot
.36394 .57247 Mdot
.45147 .58042 Mdot
.67448 .22893 Mdot
.36913 .58794 Mdot
.69614 .54352 Mdot
.47264 .55531 Mdot
.60532 .67651 Mdot
.48125 .43172 Mdot
.58012 .4609 Mdot
.35971 .40009 Mdot
.48192 .34492 Mdot
.23277 .51137 Mdot
.35822 .36805 Mdot
.62959 .6362 Mdot
.39987 .63763 Mdot
.61787 .71917 Mdot
.44078 .30788 Mdot
.43973 .54024 Mdot
.62744 .37061 Mdot
.5817 .46198 Mdot
.49375 .35151 Mdot
.64685 .37922 Mdot
.36828 .61199 Mdot
.26516 .29996 Mdot
.59529 .42219 Mdot
.74773 .70575 Mdot
.61495 .37502 Mdot
.65251 .36097 Mdot
.58864 .52341 Mdot
.35993 .39975 Mdot
.54977 .19162 Mdot
.41094 .68039 Mdot
.63752 .39021 Mdot
.29364 .48231 Mdot
.44484 .37293 Mdot
.62977 .48323 Mdot
.59216 .68595 Mdot
.46203 .59493 Mdot
.399 .59643 Mdot
.6224 .35347 Mdot
.66865 .70854 Mdot
.45782 .48953 Mdot
.64762 .38317 Mdot
.33914 .6219 Mdot
.63604 .48292 Mdot
.67469 .5546 Mdot
.69861 .54525 Mdot
.36784 .39407 Mdot
.3129 .31832 Mdot
.60149 .62843 Mdot
.31352 .38912 Mdot
.63636 .57025 Mdot
.40669 .61332 Mdot
.61789 .3481 Mdot
.69747 .5308 Mdot
.63935 .37761 Mdot
.34449 .38028 Mdot
.33589 .40695 Mdot
.62333 .65064 Mdot
.63653 .64275 Mdot
.46239 .6767 Mdot
.31704 .45438 Mdot
.36895 .5756 Mdot
.62121 .73974 Mdot
.59479 .61844 Mdot
.46488 .8138 Mdot
.35655 .39755 Mdot
.33149 .39441 Mdot
.45516 .73428 Mdot
.40483 .55526 Mdot
.58658 .32494 Mdot
.43411 .60491 Mdot
.26501 .51643 Mdot
.36021 .6005 Mdot
.44163 .35424 Mdot
.38428 .54429 Mdot
.71643 .47903 Mdot
.38055 .57895 Mdot
.42166 .61823 Mdot
.47861 .32672 Mdot
.37313 .53734 Mdot
.46535 .35894 Mdot
.4443 .56338 Mdot
.30088 .363 Mdot
.47822 .34551 Mdot
.27553 .38953 Mdot
.50807 .40546 Mdot
.68507 .55588 Mdot
.36991 .38402 Mdot
.35858 .38436 Mdot
.25233 .3931 Mdot
.63382 .62963 Mdot
.38607 .49006 Mdot
.39481 .60699 Mdot
.48421 .37153 Mdot
.60747 .36955 Mdot
.3767 .59328 Mdot
.42557 .65362 Mdot
.35454 .59902 Mdot
.61988 .65063 Mdot
.49113 .36099 Mdot
.339 .38426 Mdot
.47686 .31339 Mdot
.29229 .36602 Mdot
.49545 .31415 Mdot
.46451 .64189 Mdot
.47045 .5454 Mdot
.35437 .53894 Mdot
.59232 .75166 Mdot
.30631 .74184 Mdot
.60615 .65133 Mdot
.68297 .5458 Mdot
.34837 .40745 Mdot
.47804 .47494 Mdot
.59056 .63118 Mdot
.4402 .33846 Mdot
.41022 .59656 Mdot
.33674 .61314 Mdot
.37354 .6804 Mdot
.5825 .69196 Mdot
.30075 .43287 Mdot
.48773 .33471 Mdot
.67619 .54371 Mdot
.6028 .50178 Mdot
.55544 .60832 Mdot
.56365 .48326 Mdot
.41985 .58449 Mdot
.35937 .38902 Mdot
.62388 .67139 Mdot
.56149 .21046 Mdot
.63016 .35061 Mdot
.58765 .49133 Mdot
.40475 .5766 Mdot
.69876 .64692 Mdot
.59179 .63924 Mdot
.32492 .39159 Mdot
.62229 .35395 Mdot
.3517 .40336 Mdot
.68818 .56265 Mdot
.67024 .50726 Mdot
.41387 .54211 Mdot
.43983 .59582 Mdot
.60263 .3694 Mdot
.59939 .62944 Mdot
.4243 .30995 Mdot
.59673 .20346 Mdot
.47265 .3182 Mdot
.57153 .43317 Mdot
.62401 .66969 Mdot
.68616 .63713 Mdot
.45492 .31498 Mdot
.61832 .39677 Mdot
.55905 .43617 Mdot
.64336 .40014 Mdot
.424 .61506 Mdot
.59203 .65922 Mdot
.66267 .36705 Mdot
.48179 .22129 Mdot
.83005 .54058 Mdot
.6381 .69568 Mdot
.42745 .56427 Mdot
.79625 .37612 Mdot
.77151 .55253 Mdot
.66676 .6923 Mdot
.63211 .34246 Mdot
.42476 .57319 Mdot
.45301 .58679 Mdot
.38897 .53923 Mdot
.64718 .35209 Mdot
.57179 .39633 Mdot
.43472 .33902 Mdot
.41124 .60561 Mdot
.35537 .37567 Mdot
.46202 .35642 Mdot
.47676 .30204 Mdot
.50274 .33312 Mdot
.59054 .62008 Mdot
.42881 .62888 Mdot
.59815 .56848 Mdot
.77069 .70694 Mdot
.65305 .36742 Mdot
.68544 .55564 Mdot
.39661 .62263 Mdot
.20066 .58548 Mdot
.59946 .61923 Mdot
.46844 .31898 Mdot
.40835 .58126 Mdot
.37892 .24411 Mdot
.68826 .52075 Mdot
.47733 .33342 Mdot
.6255 .62313 Mdot
.66605 .6916 Mdot
.38926 .58737 Mdot
.39405 .55004 Mdot
.6138 .62464 Mdot
.74859 .56191 Mdot
.6141 .49952 Mdot
.42396 .58158 Mdot
.65013 .37527 Mdot
.13202 .4624 Mdot
.38128 .63971 Mdot
.56584 .68134 Mdot
.67242 .56361 Mdot
.75452 .64909 Mdot
.36356 .71553 Mdot
.46304 .63441 Mdot
.7564 .327 Mdot
.21759 .51469 Mdot
.81578 .3987 Mdot
.24565 .55082 Mdot
.70133 .31779 Mdot
.82073 .61157 Mdot
.67882 .36245 Mdot
.42067 .77745 Mdot
.57777 .17291 Mdot
.72139 .5995 Mdot
.31279 .28169 Mdot
.52606 .24174 Mdot
.38599 .23335 Mdot
.43549 .83371 Mdot
.49242 .31065 Mdot
.26433 .55168 Mdot
.42657 .5411 Mdot
.76048 .54399 Mdot
.36546 .74067 Mdot
.27969 .72584 Mdot
.79484 .38264 Mdot
.41624 .24072 Mdot
.72272 .2429 Mdot
.79708 .40336 Mdot
.50911 .65739 Mdot
.29229 .60844 Mdot
.32222 .32426 Mdot
.42591 .45348 Mdot
.2293 .52237 Mdot
.31866 .62436 Mdot
.71457 .46541 Mdot
.67267 .34126 Mdot
.52423 .68549 Mdot
.13888 .50141 Mdot
.49594 .33118 Mdot
.64499 .63462 Mdot
.53777 .18784 Mdot
.54349 .65498 Mdot
.64817 .41556 Mdot
.75648 .3267 Mdot
.80076 .57619 Mdot
.40695 .77283 Mdot
.61687 .55651 Mdot
.47366 .76504 Mdot
.21553 .42743 Mdot
.28468 .60738 Mdot
.56294 .63245 Mdot
.54057 .28177 Mdot
.43143 .45592 Mdot
.31642 .33609 Mdot
.42421 .79008 Mdot
.3699 .37142 Mdot
.27357 .38873 Mdot
.6173 .62033 Mdot
.42827 .70103 Mdot
.67615 .53614 Mdot
.63891 .57607 Mdot
.41306 .35748 Mdot
.65495 .27787 Mdot
.73659 .55295 Mdot
.74804 .5849 Mdot
.64564 .78401 Mdot
.78312 .30735 Mdot
.25266 .45483 Mdot
.59301 .24113 Mdot
.59796 .4092 Mdot
.22253 .49443 Mdot
.58399 .55302 Mdot
.28605 .45232 Mdot
.37511 .48484 Mdot
.64222 .17022 Mdot
.7705 .58481 Mdot
.70381 .21797 Mdot
.59087 .6008 Mdot
.35278 .62123 Mdot
.61755 .25129 Mdot
.56949 .78329 Mdot
.31724 .34755 Mdot
.78421 .31481 Mdot
.31811 .39685 Mdot
.61378 .69106 Mdot
.71878 .60321 Mdot
.37146 .75747 Mdot
.43439 .30161 Mdot
.38219 .37324 Mdot
.38218 .66151 Mdot
.61605 .14243 Mdot
.74965 .31444 Mdot
.73147 .6993 Mdot
.79455 .57471 Mdot
.48608 .37943 Mdot
.46136 .30182 Mdot
.66496 .36483 Mdot
.82263 .57388 Mdot
.59 .6484 Mdot
.77381 .70743 Mdot
.81743 .56905 Mdot
.51976 .58157 Mdot
.60084 .13511 Mdot
.52749 .84356 Mdot
.39407 .73091 Mdot
.26277 .64864 Mdot
.32587 .24459 Mdot
.57669 .54074 Mdot
.68215 .62349 Mdot
.51521 .35766 Mdot
.77721 .63088 Mdot
.8428 .52711 Mdot
.2997 .48679 Mdot
.70903 .34455 Mdot
.63679 .58027 Mdot
.38968 .43384 Mdot
.63848 .68797 Mdot
.28874 .30183 Mdot
.3622 .46338 Mdot
.71643 .23158 Mdot
.33847 .69811 Mdot
.18284 .37575 Mdot
.24666 .53542 Mdot
.41035 .80141 Mdot
.74781 .34726 Mdot
.419 .38456 Mdot
.42353 .48516 Mdot
.74345 .61359 Mdot
.43338 .63757 Mdot
.55005 .52244 Mdot
.46065 .51976 Mdot
.31222 .4047 Mdot
.59145 .51471 Mdot
.79527 .49065 Mdot
.24933 .51369 Mdot
.66221 .24385 Mdot
.29532 .60377 Mdot
.57356 .65132 Mdot
.27329 .44227 Mdot
.26822 .48031 Mdot
.80015 .55366 Mdot
.50197 .53791 Mdot
.7576 .67915 Mdot
.49126 .52234 Mdot
.46001 .62727 Mdot
.43024 .77987 Mdot
.31746 .60817 Mdot
.28691 .47262 Mdot
.35628 .59122 Mdot
.66068 .77237 Mdot
.78783 .60087 Mdot
.56453 .72849 Mdot
.24109 .49329 Mdot
.58751 .74588 Mdot
.78053 .63096 Mdot
.62374 .25012 Mdot
.68445 .61605 Mdot
.68101 .69744 Mdot
.62473 .14988 Mdot
.45127 .35184 Mdot
.30339 .47405 Mdot
.60637 .33669 Mdot
.4885 .22474 Mdot
.55325 .17136 Mdot
.47333 .50272 Mdot
.79376 .6214 Mdot
.73535 .59527 Mdot
.45536 .29859 Mdot
.69623 .4437 Mdot
.65512 .3148 Mdot
.59239 .73103 Mdot
.35784 .61953 Mdot
.4584 .51231 Mdot
.31077 .36923 Mdot
.5308 .79391 Mdot
.61057 .23133 Mdot
.46334 .27013 Mdot
.45051 .64792 Mdot
.49542 .2711 Mdot
.68363 .53774 Mdot
.59872 .4763 Mdot
.85364 .53143 Mdot
.48804 .58888 Mdot
.49944 .84264 Mdot
.75684 .56772 Mdot
.56811 .44435 Mdot
.28814 .3507 Mdot
.71244 .68802 Mdot
.68192 .19517 Mdot
.80695 .61025 Mdot
.77652 .52247 Mdot
.79071 .36816 Mdot
.58298 .85448 Mdot
.50657 .16534 Mdot
.56804 .8038 Mdot
.6094 .33492 Mdot
.42526 .90129 Mdot
.46582 .31232 Mdot
.27856 .66895 Mdot
.56652 .78285 Mdot
.3764 .25227 Mdot
.54676 .66173 Mdot
.31391 .63646 Mdot
.37556 .3435 Mdot
.65236 .62846 Mdot
.40157 .66168 Mdot
.81831 .36299 Mdot
.64891 .17097 Mdot
.80926 .34722 Mdot
.67572 .50502 Mdot
.82267 .39886 Mdot
.65073 .19615 Mdot
.23161 .65684 Mdot
.56724 .1878 Mdot
.45969 .59059 Mdot
.32989 .47306 Mdot
.54754 .83502 Mdot
.40426 .33096 Mdot
.61471 .57033 Mdot
.55803 .65233 Mdot
.62842 .17114 Mdot
.85625 .5271 Mdot
.48012 .73277 Mdot
.47248 .68222 Mdot
.47342 .41854 Mdot
.30133 .459 Mdot
.57153 .6974 Mdot
.72168 .45319 Mdot
.81846 .52311 Mdot
.63865 .18925 Mdot
.26394 .4911 Mdot
.52811 .24963 Mdot
.77263 .50661 Mdot
.55837 .82218 Mdot
.74885 .33993 Mdot
.53067 .18558 Mdot
.50472 .55855 Mdot
.63234 .59126 Mdot
.46017 .49191 Mdot
.70811 .45722 Mdot
.61411 .28548 Mdot
.23881 .46157 Mdot
.47118 .36248 Mdot
.30848 .48055 Mdot
.52462 .46385 Mdot
.5645 .18582 Mdot
.22726 .46354 Mdot
.29539 .49528 Mdot
.78912 .51079 Mdot
.81851 .37216 Mdot
.75302 .57176 Mdot
.2923 .26565 Mdot
.7571 .38475 Mdot
.4828 .54559 Mdot
.35439 .56075 Mdot
.78865 .62413 Mdot
.85086 .41822 Mdot
.79648 .61917 Mdot
.69839 .65722 Mdot
.45375 .23921 Mdot
.65121 .40339 Mdot
.22051 .46649 Mdot
.4789 .27887 Mdot
.82402 .52054 Mdot
.50445 .48197 Mdot
.64752 .40705 Mdot
.72435 .57033 Mdot
.47202 .67076 Mdot
.21354 .55021 Mdot
.50478 .68938 Mdot
.46254 .55522 Mdot
.40743 .71643 Mdot
.63457 .67552 Mdot
.69652 .65399 Mdot
.29113 .45808 Mdot
.45717 .35239 Mdot
.44654 .20012 Mdot
.58193 .69877 Mdot
.36629 .64003 Mdot
.60381 .26417 Mdot
.64134 .6866 Mdot
.58492 .75484 Mdot
.4937 .29979 Mdot
.82957 .58688 Mdot
.62988 .78556 Mdot
.58628 .70852 Mdot
.26085 .44467 Mdot
.46406 .21021 Mdot
.61419 .48871 Mdot
.61302 .33527 Mdot
.79329 .3861 Mdot
.51766 .40672 Mdot
.27163 .44838 Mdot
.39582 .71741 Mdot
.59875 .21154 Mdot
.46754 .60927 Mdot
.71268 .71294 Mdot
.22398 .63328 Mdot
.60192 .47162 Mdot
.54908 .65455 Mdot
.62582 .61079 Mdot
.35647 .80393 Mdot
.72846 .48035 Mdot
.54361 .58945 Mdot
.76796 .35577 Mdot
.66441 .38026 Mdot
.57718 .6323 Mdot
.2992 .49858 Mdot
.33501 .29316 Mdot
.39836 .69919 Mdot
.62448 .28479 Mdot
.51991 .65318 Mdot
.5591 .36392 Mdot
.7817 .36049 Mdot
.73284 .27805 Mdot
.14192 .44955 Mdot
.6318 .60658 Mdot
.56835 .22062 Mdot
.56141 .21861 Mdot
.56329 .63714 Mdot
.5764 .68905 Mdot
.32677 .66839 Mdot
.83896 .43087 Mdot
.48809 .46635 Mdot
.71301 .44285 Mdot
.56046 .43536 Mdot
.31114 .28787 Mdot
.5752 .20324 Mdot
.22953 .49168 Mdot
.73185 .32159 Mdot
.48099 .68946 Mdot
.37914 .19978 Mdot
.3651 .52528 Mdot
.28118 .67517 Mdot
.22034 .46632 Mdot
.29568 .55372 Mdot
.43193 .79249 Mdot
.80807 .47553 Mdot
.37016 .56347 Mdot
.79926 .32426 Mdot
.79407 .54645 Mdot
.54474 .52508 Mdot
.44998 .38407 Mdot
.38512 .56695 Mdot
.43294 .62651 Mdot
.66837 .71898 Mdot
.74185 .66839 Mdot
.45322 .16576 Mdot
.25343 .53021 Mdot
.49788 .56719 Mdot
.38713 .72095 Mdot
.50037 .84239 Mdot
.6288 .26248 Mdot
.82141 .4471 Mdot
.5241 .47631 Mdot
.5627 .82801 Mdot
.7136 .40725 Mdot
.69318 .45711 Mdot
.75495 .37358 Mdot
.65857 .20181 Mdot
.45623 .65437 Mdot
.74219 .64602 Mdot
.5405 .19506 Mdot
.39782 .62201 Mdot
.71953 .62875 Mdot
.767 .36349 Mdot
.19539 .39206 Mdot
.57382 .55788 Mdot
.84941 .40058 Mdot
.39314 .50295 Mdot
.74882 .62895 Mdot
.56316 .16591 Mdot
.26001 .25805 Mdot
.7049 .46956 Mdot
.7253 .24212 Mdot
.68513 .447 Mdot
.75987 .3456 Mdot
.66681 .35602 Mdot
.49648 .44038 Mdot
.62144 .75069 Mdot
.84126 .43772 Mdot
.3618 .30104 Mdot
.6883 .28386 Mdot
.6557 .73951 Mdot
.84018 .41847 Mdot
.36316 .49872 Mdot
.354 .79794 Mdot
.40706 .36189 Mdot
.5743 .83523 Mdot
.59461 .79315 Mdot
.52904 .63298 Mdot
.28749 .48995 Mdot
.34312 .78208 Mdot
.26181 .69586 Mdot
.58726 .79056 Mdot
.30225 .51497 Mdot
.71928 .68686 Mdot
.2544 .44104 Mdot
.82637 .52694 Mdot
.41616 .82632 Mdot
.57375 .211 Mdot
.69388 .57857 Mdot
.69217 .51396 Mdot
.74126 .67563 Mdot
.77958 .45984 Mdot
.61121 .25911 Mdot
.65025 .49685 Mdot
.5112 .64991 Mdot
.11772 .57445 Mdot
.67672 .43108 Mdot
.35321 .67779 Mdot
.67568 .19603 Mdot
.81548 .5273 Mdot
.4921 .47846 Mdot
.415 .78891 Mdot
.20741 .56928 Mdot
.39361 .40501 Mdot
.43335 .60868 Mdot
.83702 .41217 Mdot
.39424 .37736 Mdot
.74848 .27648 Mdot
.75672 .70247 Mdot
.44114 .70746 Mdot
.4854 .62591 Mdot
.51803 .34905 Mdot
.28764 .63257 Mdot
.29334 .52968 Mdot
.68112 .20923 Mdot
.28291 .67426 Mdot
.55715 .41118 Mdot
.56627 .35136 Mdot
.62731 .30343 Mdot
.51336 .61213 Mdot
.55174 .83643 Mdot
.73105 .67368 Mdot
.23977 .51901 Mdot
.76575 .51132 Mdot
.29641 .47189 Mdot
.3636 .71717 Mdot
.22412 .45271 Mdot
.5236 .52738 Mdot
.35859 .3402 Mdot
.42877 .36168 Mdot
.6657 .2288 Mdot
.79098 .40692 Mdot
.66939 .76291 Mdot
.29979 .26165 Mdot
.74076 .61797 Mdot
.26954 .56062 Mdot
.63518 .23407 Mdot
.56736 .54672 Mdot
.357 .31353 Mdot
.22235 .5656 Mdot
.34178 .69682 Mdot
.81546 .46211 Mdot
.29947 .59733 Mdot
.84504 .52809 Mdot
.2376 .46678 Mdot
.62362 .20504 Mdot
.46767 .42249 Mdot
.54313 .77747 Mdot
.42649 .75039 Mdot
.34628 .23179 Mdot
.5983 .46942 Mdot
.61785 .14446 Mdot
.56842 .65842 Mdot
.77963 .30362 Mdot
.61441 .37852 Mdot
.15635 .46094 Mdot
.8184 .49266 Mdot
.54656 .4913 Mdot
.53988 .44099 Mdot
.71262 .71748 Mdot
.74783 .57241 Mdot
.75843 .57301 Mdot
.46539 .49756 Mdot
.50559 .33695 Mdot
.56248 .40236 Mdot
.71844 .44146 Mdot
.68106 .25253 Mdot
.4523 .56533 Mdot
.44946 .29751 Mdot
.28718 .57519 Mdot
.58549 .36197 Mdot
.78461 .61055 Mdot
.80281 .44362 Mdot
.32505 .62906 Mdot
.30144 .45656 Mdot
.64766 .18859 Mdot
.81221 .55637 Mdot
.45645 .48382 Mdot
.44718 .51239 Mdot
.60678 .4179 Mdot
.47991 .18388 Mdot
.73403 .3001 Mdot
.60376 .31732 Mdot
.6251 .49589 Mdot
.25366 .45794 Mdot
.85623 .38547 Mdot
.64526 .17033 Mdot
.33632 .22472 Mdot
.55988 .43213 Mdot
.60037 .59545 Mdot
.20665 .59119 Mdot
.62735 .20769 Mdot
.58695 .83159 Mdot
.78528 .53469 Mdot
.2986 .4758 Mdot
.21234 .36589 Mdot
.30739 .73295 Mdot
.54724 .39756 Mdot
.42808 .75125 Mdot
.58811 .76393 Mdot
.61328 .40731 Mdot
.39368 .41131 Mdot
.53143 .41699 Mdot
.64645 .41737 Mdot
.72153 .68479 Mdot
.74389 .57675 Mdot
.62064 .20262 Mdot
.29085 .68973 Mdot
.44332 .51041 Mdot
.67974 .26368 Mdot
.62841 .69025 Mdot
.55833 .21299 Mdot
.47483 .20465 Mdot
.54209 .41087 Mdot
.47886 .31083 Mdot
.34843 .65722 Mdot
.61648 .47001 Mdot
.69186 .43606 Mdot
.244 .32753 Mdot
.30678 .36286 Mdot
.56908 .61725 Mdot
.31899 .75042 Mdot
.61805 .60159 Mdot
.86974 .45573 Mdot
.72403 .45207 Mdot
.39835 .72134 Mdot
.714 .39134 Mdot
.54355 .26278 Mdot
.25207 .29369 Mdot
.50127 .6595 Mdot
.27189 .37631 Mdot
.57345 .60608 Mdot
.63633 .67226 Mdot
.72541 .37354 Mdot
.66643 .54233 Mdot
.45259 .69138 Mdot
.46561 .83999 Mdot
.46113 .20987 Mdot
.60537 .6016 Mdot
.54872 .36918 Mdot
.64909 .69564 Mdot
.8514 .53876 Mdot
.4839 .31494 Mdot
.63347 .15536 Mdot
.47677 .55275 Mdot
.46944 .18061 Mdot
.7883 .61735 Mdot
.6091 .51702 Mdot
.56137 .4278 Mdot
.49876 .23848 Mdot
.45628 .62737 Mdot
.50156 .57164 Mdot
.63368 .63254 Mdot
.57828 .18948 Mdot
.33188 .39081 Mdot
.29975 .43829 Mdot
.64123 .3286 Mdot
.45906 .8222 Mdot
.58339 .81926 Mdot
.63878 .67169 Mdot
.51007 .39313 Mdot
.55484 .22505 Mdot
.33894 .5049 Mdot
.2895 .5665 Mdot
.66899 .22595 Mdot
.47973 .67474 Mdot
.56924 .65796 Mdot
.33233 .22956 Mdot
.36426 .46067 Mdot
.81396 .6159 Mdot
.34059 .54025 Mdot
.28654 .61776 Mdot
.29609 .56855 Mdot
.70994 .70501 Mdot
.36204 .71412 Mdot
.82739 .47639 Mdot
.27734 .44518 Mdot
.39799 .46211 Mdot
.29857 .49329 Mdot
.32546 .63331 Mdot
.59029 .33368 Mdot
.55173 .84323 Mdot
.21634 .35948 Mdot
.4667 .77049 Mdot
.5885 .56015 Mdot
.54684 .65569 Mdot
.50947 .84212 Mdot
.56132 .62899 Mdot
.29408 .3885 Mdot
.53227 .69127 Mdot
.81779 .49532 Mdot
.82592 .56543 Mdot
.79958 .55384 Mdot
.28732 .63749 Mdot
.62906 .3047 Mdot
.24023 .60892 Mdot
.40405 .49611 Mdot
.55446 .48748 Mdot
.43939 .64501 Mdot
.50424 .58712 Mdot
.49966 .49308 Mdot
.69068 .72759 Mdot
.49549 .62442 Mdot
.83603 .4346 Mdot
.81231 .6129 Mdot
.80926 .37278 Mdot
.61148 .28359 Mdot
.64418 .62472 Mdot
.67061 .187 Mdot
.31555 .71737 Mdot
.82296 .53622 Mdot
.58571 .79831 Mdot
.37725 .82016 Mdot
.57317 .16812 Mdot
.80082 .48906 Mdot
.59078 .58676 Mdot
.71573 .74546 Mdot
.77286 .58292 Mdot
.358 .79935 Mdot
.33676 .68896 Mdot
.78476 .6172 Mdot
.60556 .14261 Mdot
.52766 .81753 Mdot
.75145 .58327 Mdot
.41877 .75071 Mdot
.35217 .69227 Mdot
.4283 .82568 Mdot
.4357 .62868 Mdot
.47812 .3049 Mdot
.35071 .25416 Mdot
.28792 .48334 Mdot
.33274 .64849 Mdot
.41076 .81841 Mdot
.29098 .53506 Mdot
.26444 .55878 Mdot
.48722 .22924 Mdot
.5774 .17174 Mdot
.38112 .70998 Mdot
.34113 .63241 Mdot
.55645 .65558 Mdot
.36279 .36938 Mdot
.23525 .55463 Mdot
.39574 .56637 Mdot
.57829 .46818 Mdot
.42236 .67252 Mdot
.82765 .37274 Mdot
.3308 .28242 Mdot
.68947 .37378 Mdot
.6361 .61282 Mdot
.73335 .68245 Mdot
.65532 .26624 Mdot
.72032 .60011 Mdot
.39019 .80531 Mdot
.44063 .68612 Mdot
.77394 .34836 Mdot
.74232 .59838 Mdot
.24967 .48286 Mdot
.22965 .39553 Mdot
.64427 .3391 Mdot
.60359 .76412 Mdot
.67741 .21039 Mdot
.72856 .63057 Mdot
.61569 .69237 Mdot
.77242 .49041 Mdot
.5814 .34247 Mdot
.72605 .65046 Mdot
.75515 .56593 Mdot
.59577 .22047 Mdot
.44203 .72238 Mdot
.72988 .27956 Mdot
.51726 .33404 Mdot
.26854 .4955 Mdot
.74485 .48289 Mdot
.42833 .82788 Mdot
.33765 .50764 Mdot
.84357 .49664 Mdot
.54638 .48161 Mdot
.30745 .42757 Mdot
.40892 .54478 Mdot
.31284 .70259 Mdot
.6996 .70916 Mdot
.76179 .50227 Mdot
.5183 .56864 Mdot
.64763 .66734 Mdot
.64241 .7834 Mdot
.4359 .38143 Mdot
.401 .38466 Mdot
.26989 .64872 Mdot
.68853 .66744 Mdot
.31389 .41472 Mdot
.71726 .54177 Mdot
.46033 .53286 Mdot
.26319 .35823 Mdot
.62197 .29787 Mdot
.61395 .7624 Mdot
.5596 .80772 Mdot
.67026 .23143 Mdot
.62548 .27795 Mdot
.65339 .78211 Mdot
.61952 .77134 Mdot
.76064 .64975 Mdot
.30846 .72594 Mdot
.59922 .58031 Mdot
.35905 .6151 Mdot
.29432 .38884 Mdot
.56564 .6421 Mdot
.68771 .25402 Mdot
.46805 .51682 Mdot
.29402 .41462 Mdot
.54134 .50646 Mdot
.61409 .25119 Mdot
.4383 .42663 Mdot
.78411 .60587 Mdot
.71557 .74587 Mdot
.29001 .45705 Mdot
.65117 .3358 Mdot
.69421 .44088 Mdot
.56555 .55828 Mdot
.839 .46282 Mdot
.49099 .49765 Mdot
.61644 .72054 Mdot
.68891 .57379 Mdot
.56551 .74777 Mdot
.77307 .66595 Mdot
.32157 .45262 Mdot
.56138 .48889 Mdot
.59144 .70768 Mdot
.61988 .56912 Mdot
.6862 .53226 Mdot
.36805 .26129 Mdot
.30897 .70968 Mdot
.70642 .35746 Mdot
.57933 .41956 Mdot
.43017 .5146 Mdot
.20862 .59575 Mdot
.72046 .27762 Mdot
.47912 .47629 Mdot
.53988 .48195 Mdot
.53693 .19697 Mdot
.38861 .39337 Mdot
.12158 .48705 Mdot
.81341 .34286 Mdot
.40827 .54551 Mdot
.52727 .43585 Mdot
.30997 .4442 Mdot
.47809 .3661 Mdot
.50303 .6854 Mdot
.67897 .23813 Mdot
.65743 .37823 Mdot
.47178 .23012 Mdot
.71652 .53094 Mdot
.70637 .72126 Mdot
.37905 .20861 Mdot
.6382 .40877 Mdot
.86977 .44911 Mdot
.78159 .53613 Mdot
.70138 .69089 Mdot
.1121 .51936 Mdot
.6872 .72342 Mdot
.37884 .48759 Mdot
.46965 .24078 Mdot
.82725 .38131 Mdot
.56515 .43356 Mdot
.45473 .24293 Mdot
.54157 .8119 Mdot
.28486 .45331 Mdot
.25955 .51837 Mdot
.69867 .57889 Mdot
.67078 .74868 Mdot
.33232 .79027 Mdot
.54431 .26137 Mdot
.27047 .2727 Mdot
.44742 .69793 Mdot
.74831 .29041 Mdot
.70545 .46806 Mdot
.20848 .37809 Mdot
.8224 .571 Mdot
.3222 .48394 Mdot
.42257 .81684 Mdot
.32968 .30695 Mdot
.2654 .39431 Mdot
.20329 .59622 Mdot
.6615 .50201 Mdot
.48984 .67035 Mdot
.52004 .26143 Mdot
.52907 .5736 Mdot
.30358 .48625 Mdot
.57082 .76139 Mdot
.56002 .48698 Mdot
.70428 .23591 Mdot
.36126 .78142 Mdot
.26354 .45212 Mdot
.51637 .20753 Mdot
.27092 .39616 Mdot
.70185 .27466 Mdot
.67496 .29338 Mdot
.34784 .48855 Mdot
.51899 .14684 Mdot
.71633 .23189 Mdot
.60388 .57915 Mdot
.4385 .62193 Mdot
.81809 .61599 Mdot
.39683 .44174 Mdot
.56787 .80224 Mdot
.74271 .53576 Mdot
.25267 .53657 Mdot
.4609 .65523 Mdot
.37104 .63589 Mdot
.24986 .63281 Mdot
.57371 .59208 Mdot
.57606 .76168 Mdot
.41867 .20078 Mdot
.26469 .44766 Mdot
.36968 .78236 Mdot
.38853 .19769 Mdot
.33746 .54402 Mdot
.60723 .67777 Mdot
.82722 .37748 Mdot
.55233 .69004 Mdot
.44818 .50882 Mdot
.41117 .73224 Mdot
.47709 .49248 Mdot
.38523 .31124 Mdot
.44381 .51147 Mdot
.61286 .48718 Mdot
.28515 .49073 Mdot
.63725 .21739 Mdot
.62962 .74607 Mdot
.60602 .13361 Mdot
.79181 .62564 Mdot
.61015 .59968 Mdot
.5469 .8038 Mdot
.53751 .40788 Mdot
.80045 .36201 Mdot
.51789 .25098 Mdot
.46754 .20847 Mdot
.29998 .74886 Mdot
.26422 .41138 Mdot
.37381 .54492 Mdot
.6778 .50538 Mdot
.83456 .55015 Mdot
.31239 .76192 Mdot
.84458 .52665 Mdot
.48725 .62833 Mdot
.34941 .57763 Mdot
.22066 .29014 Mdot
.76916 .35175 Mdot
.47794 .61519 Mdot
.54577 .59521 Mdot
.53057 .59922 Mdot
.43769 .55095 Mdot
.66653 .53753 Mdot
.22405 .53151 Mdot
.26197 .52616 Mdot
.83715 .4296 Mdot
.61059 .60661 Mdot
.57171 .44367 Mdot
.59652 .37545 Mdot
.55976 .44899 Mdot
.32757 .6174 Mdot
.66103 .38302 Mdot
.26576 .53451 Mdot
.41977 .44023 Mdot
.42593 .2922 Mdot
.4752 .66481 Mdot
.63412 .50673 Mdot
.50371 .64778 Mdot
.27525 .60113 Mdot
.67922 .62858 Mdot
.25959 .69423 Mdot
.29027 .53472 Mdot
.33008 .49741 Mdot
.77926 .60425 Mdot
.55296 .86005 Mdot
.58649 .45676 Mdot
.67776 .65152 Mdot
.35976 .50849 Mdot
.33077 .71558 Mdot
.42573 .72645 Mdot
.40203 .32261 Mdot
.67202 .54617 Mdot
.49741 .61563 Mdot
.58814 .70894 Mdot
.6557 .39677 Mdot
.85384 .39183 Mdot
.36579 .63673 Mdot
.48725 .70125 Mdot
.83518 .48206 Mdot
.5637 .20962 Mdot
.33544 .68376 Mdot
.43286 .64868 Mdot
.41616 .46301 Mdot
.41364 .43975 Mdot
.64332 .70861 Mdot
.57462 .19954 Mdot
.75609 .31678 Mdot
.27574 .64194 Mdot
.46816 .70338 Mdot
.39866 .60928 Mdot
.30791 .39101 Mdot
.60058 .48538 Mdot
.24253 .34801 Mdot
.35771 .42788 Mdot
.80876 .55183 Mdot
.27424 .57942 Mdot
.253 .53029 Mdot
.39691 .74883 Mdot
.76355 .29111 Mdot
.57555 .56418 Mdot
.43358 .71058 Mdot
.52407 .51571 Mdot
.78292 .46557 Mdot
.29985 .51689 Mdot
.7061 .33604 Mdot
.50563 .60854 Mdot
.55668 .59526 Mdot
.86125 .47859 Mdot
.50818 .65842 Mdot
.66044 .32618 Mdot
.81672 .4618 Mdot
.31702 .72775 Mdot
.53887 .44173 Mdot
.10926 .54462 Mdot
.5123 .24484 Mdot
.86491 .43821 Mdot
.61674 .21613 Mdot
.3117 .54677 Mdot
.7179 .6841 Mdot
.41549 .66223 Mdot
.46986 .32885 Mdot
.78396 .34432 Mdot
.56368 .68461 Mdot
.62136 .57954 Mdot
.45748 .60352 Mdot
.45493 .45944 Mdot
.62624 .71113 Mdot
.70388 .31463 Mdot
.49931 .31005 Mdot
.46162 .48624 Mdot
.69624 .30014 Mdot
.41204 .43929 Mdot
.4071 .83741 Mdot
.68305 .20997 Mdot
.7963 .39054 Mdot
.61696 .30462 Mdot
.15335 .4428 Mdot
.55668 .61554 Mdot
.59584 .70049 Mdot
.6755 .35207 Mdot
.24291 .61764 Mdot
.72642 .64191 Mdot
.62541 .21034 Mdot
.74983 .6776 Mdot
.33642 .50777 Mdot
.12557 .60736 Mdot
.31084 .49123 Mdot
.4577 .47077 Mdot
.71413 .64298 Mdot
.84018 .44661 Mdot
.44882 .22907 Mdot
.74721 .70653 Mdot
.71886 .46739 Mdot
.32929 .63671 Mdot
.23326 .64311 Mdot
.33929 .22799 Mdot
.57689 .33775 Mdot
.26537 .27642 Mdot
.75246 .35346 Mdot
.22963 .5212 Mdot
.75695 .5002 Mdot
.63055 .60523 Mdot
.50938 .57801 Mdot
.72703 .44571 Mdot
.61256 .57063 Mdot
.67035 .70829 Mdot
.75296 .32057 Mdot
.20666 .46298 Mdot
.50727 .19394 Mdot
.79818 .37382 Mdot
.58183 .36902 Mdot
.53488 .6277 Mdot
.28471 .54506 Mdot
.37189 .41045 Mdot
.45802 .36629 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`2Hooooo`;o00009Oooool4o`0008Kooooo000Looooo`03o`000?oooooooooo09Sooooo0_l0
000Uooooo`Co0000Q_ooool001cooooo00?o0000ooooooooool0_Oooool2o`0008[ooooo000Loooo
o`03o`000?oooooooooo0;gooooo0_l00002ooooo`;o000000Coooooo`000?l0003o0000P_ooool0
01cooooo00?o0000ooooooooool0YOooool2o`0000Gooooo0_l0000Cooooo`;o000000Coooooo`00
0?l0003o0000P_ooool001cooooo00?o0000ooooooooool0YOooool2o`0000Gooooo0_l0000Ioooo
o`;o0000P?ooool001cooooo0_l00038ooooo`;o0000P?ooool001cooooo00?o0000ooooooooool0
Zoooool2o`0000Cooooo0_l0000Gooooo`;o0000OOooool001cooooo00?o0000ooooooooool0Xooo
ool2o`0000Kooooo0_l00004ooooo`;o00005oooool2o`0007gooooo000Looooo`03o`000?oooooo
oooo09Gooooo0_l0000<ooooo`;o00004?ooool2o`0009;ooooo000Looooo`03o`000?oooooooooo
08oooooo0_l00004ooooo`;o00002_ooool2o`0000cooooo0_l00002ooooo`Co0000T_ooool001co
oooo00?o0000ooooooooool0Soooool2o`0000gooooo0_l000000ooooooo0000o`00000:ooooo`Co
00000_ooool2o`000003ooooool0003o0000097ooooo000Looooo`03o`000?oooooooooo09kooooo
0_l0000=ooooo`;o000000?oooooo`000?l000001?ooool4o`0000kooooo0_l00003ooooo`Co0000
N?ooool001cooooo00?o0000ooooooooool0VOooool2o`0000;ooooo0_l0000Aooooo`;o00000_oo
ool2o`0000;ooooo0_l0000>ooooo`;o00000oooool4o`0007Sooooo000Looooo`03o`000?oooooo
oooo097ooooo0_l00006ooooo`;o00000_ooool3o`0001;ooooo1?l00002ooooo`;o00006Oooool2
o`0007Cooooo000Looooo`03o`000?oooooooooo097ooooo0_l00002ooooo`;o00000_ooool2o`00
00?ooooo0_l0000?ooooo`;o000000?oooooo`000?l000007oooool2o`0007Cooooo000Looooo`03
o`000?oooooooooo09Gooooo0_l000000ooooooo0000o`00000Eooooo`;o00001?ooool2o`0009;o
oooo000Looooo`03o`000?oooooooooo09Sooooo0_l0000?ooooo`;o00002Oooool3o`000003oooo
ool0003o000000;o00001?ooool2o`0001Cooooo0_l0001aooooo`007?ooool00ol0003ooooooooo
o`2Looooo`;o00001Oooool2o`0000Cooooo1?l00007ooooo`;o000000?oooooo`000?l000000ol0
0004ooooo`;o00002_ooool2o`000003ooooool0003o000000Gooooo0_l0001aooooo`0000Kooooo
onk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0
W?ooool2o`0000Gooooo0_l00006ooooo`?o000000?oooooo`000?l000000oooool2o`000004oooo
ool0003o0000o`0000Oooooo0_l00009ooooo`;o000000?oooooo`000?l00000N?ooool00006oooo
oomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006
ooooo`03o`000?oooooooooo0:7ooooo0_l00009ooooo`;o000000?oooooo`000?l000001oooool2
o`0000Oooooo0_l0000=ooooo`;o00001_ooool4o`0006gooooo00000ooooooo410@ooooo`02oooo
o`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`1goooo
o`;o000000?oooooo`000?l000000_ooool2o`0001;ooooo0_l00006ooooo`?o00001?ooool2o`00
00Sooooo0ol00009ooooo`;o00002oooool2o`0000[ooooo0_l00006ooooo`Go0000K?ooool00003
ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06ooooo`?o
0000Moooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o00001oooool2o`0000?o
oooo0_l00006ooooo`?o00003_ooool2o`0000[ooooo0_l0000;ooooo`Co00002_ooool2o`0000Oo
oooo0_l0001/ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMg
MomVIVKooooo00Gooooo00?o0000ooooooooool0Noooool2o`0000Cooooo0_l000000ooooooo0000
o`000007ooooo`;o00000oooool3o`000003ooooool0003o000001Wooooo0_l00004ooooo`Co0000
0oooool2o`0000Cooooo1Ol00009ooooo`;o0000MOooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07Oooooo0ol0
00000ooooooo0000o`000004ooooo`;o00004?ooool5o`0000cooooo0_l0000;ooooo`;o00001?oo
ool4o`0000?ooooo0_l00007ooooo`?o00003oooool2o`0006kooooo00001_ooooooMgMgoiRHV?oo
ooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo07Oo
oooo0ol0000Gooooo`Wo00000_ooool2o`000003ooooool0003o000000?ooooo0_l0000=ooooo`;o
00000_ooool3o`0000Gooooo0_l00006ooooo`?o00003_ooool4o`0006gooooo00001_ooooook^k^
oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooo
oooo097ooooo1?l000000ooooooo0000o`000006o`000003ooooool0003o0000017ooooo0ol00002
ooooo`?o00001Oooool2o`0000Kooooo0_l0000?ooooo`Co0000KOooool001cooooo00?o0000oooo
ooooool0MOooool2o`0001oooooo1ol0000Eooooo`Co00000oooool2o`0000[ooooo0_l00004oooo
o`;o00005?ooool2o`0006Kooooo000Looooo`03o`000?oooooooooo07Gooooo0_l0000Pooooo`Co
00006?ooool4o`0000;ooooo0ol00002ooooo`;o00001Oooool4o`0000;ooooo0_l0000Dooooo`;o
0000I_ooool001cooooo00?o0000ooooooooool0I?ooool2o`0003;ooooo0ol00003ooooo`;o0000
0oooool2o`0000kooooo1?l00003ooooo`;o00000_ooool2o`0000Oooooo0_l00020ooooo`007?oo
ool00ol0003oooooooooo`1Tooooo`;o00001?ooool2o`0000Cooooo0_l00006ooooo`;o00008Ooo
ool2o`000003ooooool0003o000000?ooooo0_l0000;ooooo`;o00000oooool2o`0000cooooo0_l0
000Aooooo`;o0000LOooool001cooooo00?o0000ooooooooool0J?ooool4o`0000Cooooo0_l00006
ooooo`;o00004oooool3o`0000Gooooo0_l00004ooooo`;o00004oooool2o`0000[ooooo0_l00005
ooooo`;o00003oooool5o`00073ooooo000Looooo`03o`000?oooooooooo06Sooooo1?l000000ooo
oooo0000o`00000;ooooo`;o00004Oooool3o`0000Gooooo0_l00004ooooo`;o00004oooool2o`00
00[ooooo0_l00005ooooo`;o000000?oooooo`000?l000003?ooool5o`0000cooooo0_l0001Roooo
o`007?ooool00ol0003oooooooooo`1]ooooo`;o00002oooool2o`00023ooooo0_l00004ooooo`;o
00003?ooool3o`0000Gooooo0_l00009ooooo`;o000000?oooooo`000?l000000oooool2o`0000Wo
oooo0ol00008ooooo`;o00000_ooool2o`0006;ooooo000Looooo`03o`000?oooooooooo093ooooo
0_l0000:ooooo`Co000000Coooooo`000?l0003o00003Oooool2o`0000Gooooo0_l0000Aooooo`;o
00002_ooool4o`0000Kooooo0_l0001Vooooo`007?ooool00ol0003oooooooooo`1cooooo`Co0000
2Oooool2o`000003ooooool0003o000000?ooooo0_l00006ooooo`;o00000oooool2o`0000Oooooo
0_l000000ooooooo0000o`000002o`0000;ooooo0_l0000Dooooo`;o00004?ooool2o`0000Sooooo
0_l0000<ooooo`?o0000Goooool001cooooo00?o0000ooooooooool0I_ooool2o`0000Wooooo2?l0
0007ooooo`;o000000?oooooo`000?l000000oooool2o`0000Gooooo0ol00003ooooo`;o00003?oo
ool2o`0000;ooooo0_l0000Dooooo`;o00004?ooool2o`0000;ooooo0_l00004ooooo`;o00003?oo
ool3o`0005oooooo000Looooo`03o`000?oooooooooo06Kooooo0_l00009ooooo`?o00000oooool2
o`000003ooooool0003o000001?ooooo0_l0000Booooo`;o0000;_ooool2o`0000Cooooo0_l0001^
ooooo`007?ooool2o`0005Gooooo0_l0000;ooooo`;o00005?ooool2o`000003ooooool0003o0000
00;ooooo0_l000000ooooooo0000o`00000>ooooo`;o00004Oooool2o`0000;ooooo0_l0000Coooo
o`;o00001Oooool5o`00083ooooo000Looooo`03o`000?oooooooooo05Cooooo0_l0000;ooooo`;o
00002oooool2o`0000Oooooo0_l00005ooooo`;o000000?oooooo`000?l000003_ooool2o`00017o
oooo0_l00002ooooo`;o00004oooool2o`0000Gooooo1Ol000000ooooooo0000o`00000=ooooo`;o
000000?oooooo`000?l000001oooool2o`0006;ooooo000Looooo`03o`000?oooooooooo057ooooo
0_l0000Kooooo`;o0000=?ooool2o`0001[ooooo0_l00006ooooo`Co00002Oooool3o`000004oooo
ool0003o0000ooooo`;o00001oooool2o`0006;ooooo000Looooo`03o`000?oooooooooo057ooooo
0_l0000;ooooo`;o00005?ooool2o`0001oooooo0_l0000>ooooo`;o00001_ooool2o`00017ooooo
0_l000000ooooooo0000o`000003ooooo`;o00002oooool3o`00077ooooo000Looooo`03o`000?oo
oooooooo05kooooo0_l00003ooooo`;o00003oooool2o`0001oooooo0_l0000>ooooo`;o00001_oo
ool2o`00017ooooo1Ol00003ooooo`;o00003oooool3o`0006gooooo000Looooo`03o`000?oooooo
oooo05_ooooo0_l00006ooooo`;o00002?ooool2o`0003kooooo0_l000000ooooooo0000o`00000>
ooooo`?o00001Oooool2o`0000Oooooo0_l00006ooooo`?o0000KOooool001cooooo00?o0000oooo
ooooool0Foooool2o`00013ooooo0_l0000Tooooo`;o00002?ooool2o`00017ooooo0_l0000Doooo
o`;o00002Oooool2o`0001Kooooo0_l00005ooooo`;o0000Eoooool001cooooo00?o0000oooooooo
ool0E?ooool3o`0003cooooo0_l00008ooooo`;o00008oooool2o`0000;ooooo0_l00005ooooo`;o
00003?ooool3o`0000_ooooo0_l00005ooooo`;o0000Eoooool001cooooo00?o0000ooooooooool0
D_ooool5o`0004Kooooo0_l0000Sooooo`;o00002Oooool2o`0000Gooooo0_l00002ooooo`;o0000
00Coooooo`000?l0003o00000_ooool2o`0000gooooo0_l0001Hooooo`007?ooool00ol0003ooooo
ooooo`1Booooo`;o000000?oooooo`000?l000002oooool2o`0003Cooooo0_l00002ooooo`;o0000
:Oooool2o`0000Sooooo0_l000000ooooooo0000o`000002ooooo`;o00001_ooool2o`0000Cooooo
0_l000001?oooooo0000o`000?l00002ooooo`?o0000F?ooool001cooooo00?o0000ooooooooool0
EOooool2o`0000_ooooo0_l00004ooooo`;o0000;_ooool2o`0000;ooooo0_l0000>ooooo`;o0000
6Oooool2o`0000Sooooo0ol0000Booooo`;o000000Coooooo`000?l0003o00000_ooool2o`0005Wo
oooo000Looooo`03o`000?oooooooooo06;ooooo0_l00004ooooo`;o0000<?ooool2o`000003oooo
ool0003o000000;o000000?oooooo`000?l000002?ooool2o`0001Gooooo0ol000000ooooooo0000
o`000006ooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`?o0000Joooool001cooooo
00?o0000ooooooooool0HOooool2o`0002oooooo0_l00006ooooo`;o000000?oooooo`000?l00000
0_l000000ooooooo0000o`00000Oooooo`?o000000?oooooo`000?l000001_ooool2o`0000Cooooo
0_l00004ooooo`?o0000Joooool001cooooo00?o0000ooooooooool0A?ooool2o`0001_ooooo0_l0
000Tooooo`;o00002Oooool4o`0000_ooooo0_l0000;ooooo`;o00004oooool2o`0000oooooo0_l0
000Iooooo`;o00000oooool2o`0005?ooooo000Looooo`03o`000?oooooooooo04Cooooo0_l00008
ooooo`;o00006Oooool2o`0001[ooooo1Ol00008ooooo`Co00001?ooool4o`0000?ooooo0_l0000;
ooooo`;o00009?ooool2o`000003ooooool0003o000000Cooooo0_l0000@ooooo`;o00000oooool2
o`0005?ooooo000Looooo`03o`000?oooooooooo04kooooo0_l0000Fooooo`;o000000?oooooo`00
0?l000005oooool2o`000004ooooool0003o0000ooooo`;o00001?ooool6o`000004ooooool0003o
0000o`0000;ooooo1?l00005ooooo`;o00001oooool2o`0001Sooooo0_l0000?ooooo`;o00001?oo
ool2o`0006[ooooo000Looooo`;o0000Doooool2o`0001;ooooo0_l0000:ooooo`;o00003_ooool2
o`0000Gooooo0_l00002ooooo`Go00000oooool3o`0000Cooooo0ol00004ooooo`;o00001oooool2
o`0001Sooooo0ol00004ooooo`;o00003_ooool3o`0000_ooooo0_l0001Looooo`007?ooool00ol0
003oooooooooo`1Booooo`;o00001_ooool2o`0000gooooo0_l00007ooooo`;o00005?ooool3o`00
00;ooooo0_l00003ooooo`Wo000000Coooooo`000?l0003o00009_ooool6o`000004ooooool0003o
0000o`0000oooooo0_l0000;ooooo`;o00003?ooool2o`0004kooooo000Looooo`03o`000?oooooo
oooo04_ooooo0_l00002ooooo`;o00002Oooool2o`0000_ooooo1?l0000Gooooo`;o00001?ooool2
o`0000?ooooo0ol000000ooooooo0000o`00000=o`0002Gooooo0_l000001Ooooooo0000o`000?l0
003ooooo00;o00001oooool2o`0000Sooooo0_l0000Dooooo`;o00000_ooool4o`0004cooooo000L
ooooo`03o`000?oooooooooo04_ooooo0_l00002ooooo`;o00005_ooool4o`0001Oooooo0_l00002
ooooo`Co000000?oooooo`000?l000003Ol000000ooooooo0000o`000004o`0000?ooooo0_l0000I
ooooo`;o00001oooool2o`0000_ooooo0_l00008ooooo`;o00005?ooool2o`0000Cooooo0_l0001<
ooooo`007?ooool00ol0003oooooooooo`1`ooooo`;o00001oooool2o`0000Kooooo0_l00003oooo
o`?o000000?oooooo`000?l000006_l0000Hooooo`?o00001?ooool2o`000003ooooool0003o0000
00cooooo0_l0001aooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00002_ooool2o`0001;o
oooo0_l00007ooooo`;o00001_ooool2o`0000Cooooo0_l000000ooooooo0000o`00000Ho`0001[o
oooo0_l00005ooooo`;o00002_ooool2o`0000?ooooo0_l00009ooooo`;o00003Oooool6o`0000Go
oooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00002oooool2o`0000[ooooo
0_l00004ooooo`;o00000oooool2o`00017ooooo0_l00003ooooo`;o00002Oooool3o`0000;ooooo
5Ol000000ooooooo0000o`00000Iooooo`;o00003oooool2o`0000;ooooo0_l00009ooooo`?o0000
3Oooool6o`0000?ooooo1?l00004ooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0@ooo
ool2o`0001gooooo0_l00003ooooo`;o00002_ooool2o`0000Gooooo0_l00002ooooo`?o00000_oo
ool2o`0000?ooooo6Ol000001?oooooo0000o`000?ooool2o`0001Wooooo0_l00009ooooo`;o0000
2?ooool4o`000003ooooool0003o000000;o00000_ooool2o`0000Sooooo0_l00005ooooo`;o0000
00?oooooo`000?l000000oooool2o`0000Kooooo0_l00016ooooo`007?ooool00ol0003ooooooooo
o`1Uooooo`;o00003?ooool2o`0000Wooooo1ol00002oooooa[o000000?oooooo`000?l000005ooo
ool2o`0000Sooooo0_l00004ooooo`;o00001_ooool2o`0000;ooooo0_l000000ooooooo0000o`00
0002o`0000cooooo0_l00005ooooo`;o000000?oooooo`000?l000002_ooool2o`0004Oooooo000L
ooooo`03o`000?oooooooooo04cooooo0_l0000Gooooo`;o00002_ooool2o`0000kooooo8_l00006
ooooo`;o00004?ooool2o`0000Oooooo0ol00004ooooo`Co00001?ooool2o`000003ooooool0003o
000000;o00006?ooool2o`0000cooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`1<oooo
o`;o00006_ooool2o`0000Oooooo0_l0000=ooooo`?o00000_oooolOo`0000Gooooo0_l0000Ioooo
o`;o00001Oooool4o`0000Oooooo1?l0000Cooooo`;o00000oooool2o`0005Gooooo000Looooo`03
o`000?oooooooooo06Sooooo0_l0000Fooooo`?o000000?oooooo`000?l000000_oooolNo`0000?o
oooo0_l0000Aooooo`;o00001?ooool3o`000003ooooool0003o000000;o000000Coooooo`000?l0
003o00001?ooool2o`0000;ooooo0ol00008ooooo`;o00002_ooool2o`0005[ooooo000Looooo`03
o`000?oooooooooo06?ooooo0_l0000Oooooo`[o000000?oooooo`000?l000004_l000000ooooooo
0000o`000003ooooo`;o00003Oooool2o`0000;ooooo0_l00003ooooo`Co000000?oooooo`000?l0
00003?l00003ooooo`;o00002?ooool3o`0006Gooooo000Looooo`03o`000?oooooooooo04Oooooo
0_l0000Aooooo`;o00001oooool2o`0000cooooo0_l0000;ooooo`?o00000_oooolSo`0001;ooooo
0_l00007ooooo`;o00000oooool@o`000003ooooool0003o000000Wooooo0_l0000;ooooo`;o0000
3oooool2o`0004Oooooo000Looooo`03o`000?oooooooooo04Oooooo1?l0000?ooooo`;o00005Ooo
ool2o`0000?ooooo0_l00006ooooo`?o00000_oooolSo`0001?ooooo0_l0000;ooooo`go000000Co
ooooo`000?l0003ooooo0_l0000:ooooo`;o00002?ooool4o`0000[ooooo0_l00003ooooo`;o0000
0_ooool2o`0004?ooooo000Looooo`03o`000?oooooooooo04Wooooo0_l0000@ooooo`;o00001_oo
ool2o`00017ooooo0_l0000:oooooaoo00000_ooool2o`0001Cooooo0_l00006oooooa3o00000_oo
ool6o`0000[ooooo0_l00008ooooo`Co00000_ooool2o`0000Kooooo0_l00006ooooo`?o0000@ooo
ool001cooooo0_l00017ooooo`;o00000oooool2o`0000gooooo0ol00006ooooo`;o00004Oooool2
o`0000?ooooo0_l00005oooooaoo000000?oooooo`000?l000000ol0000Eooooo`;o00000_oooolA
o`000003ooooool0003o000000Go00005_ooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2
o`0000Gooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`16ooooo`;o00000oooool2o`00
00gooooo0_l00004ooooo`[o00000_ooool2o`0000gooooo0_l00003ooooo`;o000000?oooooo`00
0?l000006ol00002ooooo`;o000000Coooooo`000?l0003o00003?ooool2o`0000Kooooo0_l00002
oooooaKo000000?oooooo`000?l000000ol0000Eooooo`;o00000oooool4o`0000;ooooo0_l0001;
ooooo`007?ooool00ol0003oooooooooo`1Pooooo`[o00000_ooool3o`00013ooooo0ol000000ooo
oooo0000o`00000Lo`0000Gooooo0_l0000:ooooo`Co00002_oooolLo`0001Gooooo0_l00003oooo
o`;o0000DOooool001cooooo00?o0000ooooooooool0@oooool2o`0000gooooo0_l0000<ooooo`oo
00001?ooool2o`0000[ooooo8ol00002ooooo`;o00003?ooool4o`0000Cooooo0_l00003ooooo`Oo
000000?oooooo`000?l000004_l00007ooooo`;o00004_ooool2o`0000;ooooo0_l0001=ooooo`00
7?ooool00ol0003oooooooooo`13ooooo`;o00003Oooool2o`0000Gooooo0_l00002oooooaGo0000
00?oooooo`000?l000001Oooool2o`0000Cooooo1?l000000ooooooo0000o`00000Ko`0000;ooooo
0_l0000:ooooo`;o00000_ooool4o`0000;ooooo0_l00003oooooaOo00000oooool4o`0000Gooooo
0_l0000Fooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`;o0000@Oooool001cooooo
00?o0000ooooooooool0<oooool2o`0000Wooooo0_l000001?oooooo0000o`000?l0000Eoooooa[o
00001?ooool2o`000003ooooool0003o000000;ooooo1Ol00004oooooago00003?ooool8o`0000;o
oooo0_l000000ooooooo0000o`000002oooooaKo00000_ooool4o`0001Sooooo0_l00003ooooo`;o
00001?ooool2o`000004ooooool0003o0000ooooo`;o0000@Oooool001cooooo00?o0000oooooooo
ool0<oooool2o`0000Wooooo0_l000001?oooooo0000o`000?l0000Gooooo`;o00001?oooolHo`00
00Cooooo0ol00008ooooo`Ko000000?oooooo`000?l000001?l000000ooooooo0000o`000004o`00
00;ooooo0_l00002ooooo`;o00002_ooool2o`0000;ooooo0ol00002ooooo`Co00000_ooool2o`00
0003ooooool0003o000001_o00005?ooool2o`0000;ooooo0_l00006ooooo`;o0000B_ooool001co
oooo00?o0000ooooooooool0?_ooool2o`0001kooooo6Ol000000ooooooo0000o`000003ooooo`;o
00002_ooool:o`0000?ooooo1_l0000Aooooo`Go00001Oooool4o`0000Gooooo5Ol000001Ooooooo
0000o`000?l0003ooooo00?o00005?ooool2o`000003ooooool0003o000000;ooooo0_l00003oooo
o`;o00001oooool2o`00047ooooo000Looooo`03o`000?oooooooooo05Gooooo0ol00005oooooaGo
000000?oooooo`000?l000000_l000000ooooooo0000o`000003ooooo`;o00003_ooool8o`000003
ooooool0003o000000Co000000?oooooo`000?l000003_ooool2o`000003ooooool0003o000000Go
oooo0_l00005oooooa_o000000?oooooo`000?l000000_l0000:ooooo`;o00001oooool2o`000003
ooooool0003o000000;ooooo0_l00005ooooo`;o00000_ooool2o`000004ooooool0003o0000oooo
o`;o0000?_ooool001cooooo00?o0000ooooooooool0>?ooool2o`0000Kooooo0_l0000?ooooo`Oo
00001OoooolJo`000003ooooool0003o000000;ooooo0_l0000=ooooo`[o000000?oooooo`000?l0
00001?l000000ooooooo0000o`000002ooooo`;o00003?ooool3o`000004ooooool0003o0000o`00
00Sooooo6ol00003ooooo`;o00002_ooool2o`0000Oooooo0_l0000<ooooo`;o00000_ooool2o`00
00Cooooo0_l000000ooooooo0000o`000003ooooo`;o0000=_ooool001cooooo00?o0000oooooooo
ool0>?ooool2o`0000Kooooo0_l00008ooooo`;o00000oooool9o`0000Cooooo7Ol00003ooooo`;o
00003?ooool3o`0000;ooooo2Ol00002ooooo`;o00001Oooool2o`0000cooooo0_l00002ooooo`?o
00002ooooolGo`0000;ooooo1?l0000Jooooo`;o00001Oooool4o`0000Kooooo0_l000000ooooooo
0000o`000003ooooo`;o0000=_ooool001cooooo00?o0000ooooooooool0B_ooool2o`0000?ooooo
0ol000000ooooooo0000o`000003o`0000Cooooo0_l00002oooooaWo00000oooool2o`000003oooo
ool0003o000000?ooooo0_l00004ooooo`;o00000_ooool3o`0000Cooooo0_l00003ooooo`;o0000
3Oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000Oooooo0_l000000ooooooo0000
o`00000Do`0000;ooooo1?l0000Dooooo`;o00001?ooool2o`0000Cooooo0_l000000ooooooo0000
o`000006ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0Doooool5o`0000?ooooo8?l0
0004ooooo`;o00000oooool2o`0000Sooooo0_l0000Hooooo`?o00000_ooool2o`0000;ooooo0ol0
0002ooooo`Co00001Oooool2o`0000;ooooo5?l00003ooooo`Co00005?ooool2o`0000[ooooo1?l0
000@ooooo`;o0000=Oooool001cooooo00?o0000ooooooooool0COooool2o`0000?ooooo0_l00000
1?oooooo0000o`000?l00003ooooob7o0000;?ooool4o`000003ooooool0003o000000;ooooo0_l0
0004ooooo`?o00001?ooool2o`0000?ooooo5?l00002ooooo`?o00007_ooool2o`0000;ooooo1?l0
000@ooooo`;o0000=Oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo
0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo02gooooo0_l0000=ooooo`;o0000
3oooool;o`0000Cooooo0ol000000ooooooo0000o`00000Eo`0000?ooooo0_l0000Vooooo`;o0000
0_ooool6o`0000Cooooo0_l0000<ooooo`;o00000ooooolEo`000003ooooool0003o000000Wooooo
0ol0000Cooooo`;o00000oooool3o`00013ooooo0_l0000eooooo`0000KoooooogMgMonHV9Sooooo
oiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02go
oooo0_l0000=ooooo`;o00002Oooool2o`0000Gooooo2Ol00002ooooo`;o00000_ooool2o`0000Co
oooo5Ol00002ooooo`;o00009_ooool2o`0000;ooooo1?l00004ooooo`Co00001?ooool2o`0000[o
oooo5_l000000ooooooo0000o`000002o`0000Oooooo0ol0000Iooooo`;o00001Oooool2o`0000Wo
oooo0_l0000eooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`Go0000
1_ooool00ol0003oooooooooo`0aooooo`;o00005?ooool2o`0000;ooooo0_l00003ooooo`Ko0000
0oooool2o`0000Wooooo5Ol00002ooooo`;o00008_ooool5o`0000;ooooo0_l00006ooooo`?o0000
1Oooool2o`0000[ooooo6ol0000Xooooo`Co0000@?ooool00003ooooool0003ooooo00;ooooo00?o
0000ooooooooool02Oooool01?m4A4CogMgMooooool00007ooooo`?o0000<Oooool2o`0001Cooooo
0_l00002ooooo`;o000000?oooooo`000?l000000_l0000CoooooaCo00000_ooool2o`0002;ooooo
1Ol00002ooooo`;o00001_ooool3o`0000;ooooo0_l0000Cooooo`[o000000Goooooo`000?l0003o
0000ooooo`02o`0000_ooooo0_l0000Oooooo`Co00001oooool2o`0003Oooooo00000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003o
ooooooooo`1>ooooo`Ko00003_ooool2o`000003ooooool0003o0000013o00001Oooool2o`0002;o
oooo0ol0000@ooooo`;o00004_ooool;o`0001;ooooo0_l0000Iooooo`;o00003oooool2o`0003Oo
oooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oMgMgolc<c?l00000
1oooool00ol0003oooooooooo`1;ooooo`;o00000_ooool5o`0000kooooo0_l00003ooooo`ko0000
1oooool2o`0001kooooo0_l00002ooooo`?o000000?oooooo`000?l000001Oooool2o`00017ooooo
0_l00003ooooo`;o00000_ooool4o`000004ooooool0003o0000ooooo`?o00004_ooool2o`0001Oo
oooo1ol00015ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co0000
00Oooooo00?o0000ooooooooool0Boooool2o`0000;ooooo0_l000000ooooooo0000o`00000Doooo
o`?o00000_ooool7o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0001kooooo0_l00000
0ooooooo0000o`000003ooooo`;o00001Oooool3o`0000?ooooo0_l00002ooooo`;o00001oooool2
o`0000?ooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo0_l0000?
ooooo`;o00005oooool2o`0000;ooooo0ol00008ooooo`;o0000>oooool00006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo04cooooo0_l0
0004ooooo`;o00002?ooool2o`0000Cooooo0_l00005ooooo`;o000000?oooooo`000?l000000ol0
00001?oooooo0000o`000?ooool2o`000003ooooool0003o000000Co00008Oooool2o`0000[ooooo
0ol00003ooooo`;o00000_ooool2o`0000?ooooo0_l0000;ooooo`;o000000?oooooo`000?l00000
0oooool2o`0000;ooooo0_l0000<ooooo`?o00007_ooool2o`0000Sooooo0_l0000kooooo`007?oo
ool00ol0003oooooooooo`0`ooooo`;o00006_ooool2o`000003ooooool0003o000000;ooooo0_l0
0007ooooo`;o00001?ooool2o`0000Gooooo0_l000001?oooooo0000o`000?ooool4o`0000Gooooo
1?l0000Jooooo`;o00001Oooool2o`0000[ooooo1ol0000:ooooo`;o00001Oooool2o`0000Oooooo
0_l00002ooooo`?o00004?ooool3o`0001_ooooo0_l000000ooooooo0000o`000009ooooo`;o0000
0_ooool2o`0003Kooooo000Looooo`03o`000?oooooooooo033ooooo0_l0000Kooooo`So00005?oo
ool4o`0000Cooooo0_l000000ooooooo0000o`00000Pooooo`;o00001?ooool3o`0000Oooooo0_l0
00000ooooooo0000o`000002ooooo`So00000oooool2o`0000Cooooo0_l000000ooooooo0000o`00
0008ooooo`;o000000?oooooo`000?l00000:oooool2o`0000;ooooo0_l000000ooooooo0000o`00
0002ooooo`;o00001Oooool2o`0000;ooooo0_l000000ooooooo0000o`00000cooooo`007?ooool0
0ol0003oooooooooo`0dooooo`;o00005oooool2o`0000;ooooo0_l000000ooooooo0000o`00000:
ooooo`;o00001oooool4o`0000Oooooo0_l0000Nooooo`;o00001Oooool3o`0000Sooooo0_l00002
ooooo`;o00000_ooool9o`000003ooooool0003o000000Cooooo0_l0000;ooooo`;o0000;_ooool2
o`0000Cooooo0ol00002ooooo`;o00003?ooool2o`0003?ooooo000Looooo`03o`000?oooooooooo
03Cooooo0_l0000<ooooo`;o00001?ooool5o`0000;ooooo0_l00002ooooo`?o00002_ooool2o`00
00Kooooo1?l00004ooooo`;o00001?ooool2o`0001?ooooo0_l00007ooooo`;o00001Oooool2o`00
00gooooo0_l00003ooooo`?o000000?oooooo`000?l000000_l00007ooooo`;o0000?oooool5o`00
00?ooooo0_l000000ooooooo0000o`00000mooooo`007?ooool00ol0003oooooooooo`12ooooo`Co
00000_ooool5o`0000;ooooo0_l00002ooooo`;o00002Oooool4o`0000Kooooo1?l00004ooooo`;o
00000_ooool4o`0000Gooooo0_l00003ooooo`;o00001oooool2o`0000cooooo0_l0000Eooooo`Go
00001oooool2o`0001[ooooo0_l00006ooooo`;o00007Oooool5o`0000?ooooo0_l000000ooooooo
0000o`000003o`0003[ooooo000Looooo`03o`000?oooooooooo02Gooooo0_l0000Mooooo`;o0000
0oooool3o`0001;ooooo0_l00002ooooo`;o00004?ooool4o`0000?ooooo1?l00003ooooo`;o0000
5Oooool2o`0001;ooooo0_l00002ooooo`Oo00001?ooool2o`0001[ooooo0_l00002ooooo`?o0000
00?oooooo`000?l000007_ooool4o`0000Sooooo0ol0000jooooo`007?ooool00ol0003ooooooooo
o`0Uooooo`;o00007?ooool2o`0000Cooooo0_l0000Cooooo`;o00000_ooool2o`0000_ooooo0_l0
00000ooooooo0000o`000007ooooo`;o00001_ooool2o`0001Cooooo0ol0000<ooooo`;o00000ooo
ool2o`0000;ooooo1ol00006ooooo`;o00007?ooool3o`00027ooooo1?l00008ooooo`;o0000>ooo
ool001cooooo00?o0000ooooooooool0:_ooool4o`0001Gooooo0_l0000Iooooo`;o00001?ooool2
o`0000Wooooo1_l0000=ooooo`Go00001_ooool2o`0000_ooooo0_l0000;ooooo`?o00001oooool3
o`0000[ooooo0_l0000Fooooo`;o00001Oooool2o`00027ooooo1?l00008ooooo`?o00001_ooool2
o`0003;ooooo000Looooo`03o`000?oooooooooo02[ooooo1_l0000Cooooo`;o00000_ooool2o`00
00Kooooo0_l00004ooooo`;o00001Oooool4o`0000Cooooo0_l0000;ooooo`Co00000_ooool3o`00
00?ooooo0_l00003ooooo`Go00001_ooool2o`0000_ooooo0_l00002ooooo`;o00001oooool2o`00
00;ooooo0ol00003ooooo`;o00008oooool2o`0000Kooooo0_l00004ooooo`Co00005oooool2o`00
00Sooooo0_l00002ooooo`;o00001_ooool2o`0003;ooooo000Looooo`03o`000?oooooooooo02_o
oooo0_l000000ooooooo0000o`00000Gooooo`;o00001_ooool4o`0000;ooooo0ol00004ooooo`;o
00000oooool2o`0001Cooooo2?l0000Oooooo`;o00002oooool5o`0000;ooooo1_l00009ooooo`;o
00004_ooool2o`000003ooooool0003o000000Cooooo0_l00004ooooo`Ko00004_ooool2o`000003
ooooool0003o000000;o00001_ooool2o`0003kooooo000Looooo`03o`000?oooooooooo02[ooooo
0_l0000Dooooo`;o00003oooool3o`000004ooooool0003o0000o`0000?ooooo0_l00004ooooo`;o
00005_ooool4o`0000Oooooo0_l0000Xooooo`?o000000?oooooo`000?l000001?l00009ooooo`;o
00004_ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000002?ooool2o`00
01;ooooo0_l00003ooooo`;o00001?ooool2o`0000Cooooo0_l00008ooooo`;o0000<?ooool001co
oooo0_l0000[ooooo`;o00005?ooool2o`0000Cooooo0_l0000:ooooo`;o000000?oooooo`000?l0
00000_ooool4o`0000Cooooo1_l0000Mooooo`Co00001_ooool4o`0001cooooo0ol000000ooooooo
0000o`00000Wooooo`;o00002_ooool2o`0001[ooooo0_l00002ooooo`;o00001?ooool2o`0000So
oooo0_l0000`ooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00003_ooool2o`0000?ooooo
1Ol00004ooooo`;o00000_ooool2o`0000Cooooo0ol00004ooooo`;o00000_ooool4o`0000cooooo
0_l0000Aooooo`Go00000oooool4o`0001cooooo0ol00005ooooo`;o0000;oooool2o`0001[ooooo
0_l00014ooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00003_ooool2o`0000?ooooo1Ol0
0004ooooo`?o00001oooool5o`000004ooooool0003o0000o`0000;ooooo0ol00006ooooo`;o0000
1Oooool2o`00017ooooo1ol0000>ooooo`;o00004_ooool2o`0000Gooooo1?l000000ooooooo0000
o`00000Pooooo`;o00000oooool2o`0000?ooooo0_l0000@ooooo`;o00005Oooool2o`0000Gooooo
0_l0000`ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00006Oooool2o`0000?ooooo0_l0
0008ooooo`Co000000?oooooo`000?l000001?ooool2o`0000Kooooo0_l00005ooooo`;o00001ooo
ool2o`000003ooooool0003o000000;o00001Oooool2o`000003ooooool0003o000000?ooooo0_l0
00000ooooooo0000o`000006ooooo`;o00006?ooool2o`000003ooooool0003o000000?o00008?oo
ool2o`0000?ooooo0_l0000Eooooo`;o00002_ooool2o`0000Gooooo0_l00002ooooo`;o00001Ooo
ool2o`00033ooooo000Looooo`03o`000?oooooooooo02Oooooo0_l00006ooooo`;o00003_ooool3
o`0000?ooooo0ol00002ooooo`;o00003Oooool3o`0000;ooooo0_l0000@ooooo`Go00001oooool9
o`0000[ooooo1_l0000Booooo`;o00003?ooool2o`0000;ooooo0ol00004ooooo`;o0000=oooool2
o`0000[ooooo0_l00003ooooo`Go00002?ooool2o`00033ooooo000Looooo`03o`000?oooooooooo
02Gooooo1?l0000Fooooo`?o00000_ooool4o`000003ooooool0003o000000kooooo0ol00009oooo
o`;o00002Oooool4o`0000[ooooo0_l00003ooooo`;o00002_ooool5o`0000Oooooo1?l00008oooo
o`;o00004?ooool3o`0000?ooooo1?l0000Qooooo`Co00004oooool2o`0000Sooooo0_l00003oooo
o`;o000000?oooooo`000?l000002?ooool2o`00033ooooo000Looooo`03o`000?oooooooooo02Go
oooo0_l00002ooooo`?o00006?ooool2o`0000?ooooo0_l0000@ooooo`;o00002?ooool2o`0000;o
oooo0_l0000Vooooo`Go00000oooool6o`0000oooooo0_l00004ooooo`;o00000_ooool5o`0000;o
oooo1?l000000ooooooo0000o`00000Kooooo`Oo00004oooool2o`0004cooooo000Looooo`03o`00
0?oooooooooo02Wooooo0ol0000Hooooo`;o00000_ooool2o`0000oooooo2?l00005ooooo`Go0000
9_ooool2o`000004ooooool0003o0000ooooo`Co00000_ooool2o`0000oooooo0_l00004ooooo`Ko
000000Goooooo`000?l0003o0000ooooo`03o`0000;ooooo0_l0000Jooooo`Co00008oooool2o`00
00;ooooo0_l0000looooo`007?ooool00ol0003oooooooooo`14ooooo`;o000000Coooooo`000?l0
003o00003oooool2o`0000;ooooo1?l00005ooooo`?o0000;_ooool5o`0000[ooooo0_l00009oooo
o`;o000000?oooooo`000?l000000ol00002ooooo`?o000000Coooooo`000?l0003o00002Oooool3
o`0001;ooooo0_l0000Qooooo`;o00000_ooool6o`0003cooooo000Looooo`03o`000?oooooooooo
04Cooooo1Ol00002ooooo`;o00001_ooool2o`0000Sooooo0_l0000Uooooo`;o00004_ooool6o`00
00Sooooo0_l00009ooooo`go000000?oooooo`000?l000002_ooool3o`0001Cooooo0_l000000ooo
oooo0000o`000002ooooo`;o00004_ooool2o`0000Cooooo0_l00004ooooo`;o00002Oooool2o`00
03?ooooo000Looooo`03o`000?oooooooooo04Gooooo0ol00003ooooo`Co00001?ooool2o`0000Go
oooo1?l00002ooooo`;o00005_ooool2o`0000[ooooo0_l0000Fooooo`;o00000_ooool4o`0000So
oooo1?l00002ooooo`Go00000_ooool2o`000004ooooool0003o0000o`0000Kooooo0_l00002oooo
o`Co00001Oooool2o`0000kooooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool2o`00
00gooooo0_l0000:ooooo`Co00001oooool2o`0003?ooooo000Looooo`03o`000?oooooooooo02Ko
oooo0_l0000Nooooo`;o00001Oooool2o`0000Sooooo0_l000000ooooooo0000o`000002o`000004
ooooool0003o0000o`0000?ooooo0_l00002ooooo`;o00002oooool4o`0000[ooooo1?l00009oooo
o`?o00003?ooool4o`0000Sooooo2ol00005ooooo`Go00001?ooool2o`0000;ooooo1_l00003oooo
o`;o00006_ooool2o`0001_ooooo0_l0000looooo`007?ooool00ol0003oooooooooo`0Tooooo`Co
00007_ooool2o`0000oooooo0_l00005ooooo`?o00001?ooool2o`0000;ooooo0_l000001?oooooo
0000o`000?l00003ooooo`;o00000_ooool3o`0000Sooooo0_l000000ooooooo0000o`000002o`00
00Wooooo0ol0000Looooo`Go00001oooool6o`000004ooooool0003o0000o`0000Cooooo1Ol0000M
ooooo`;o00004_ooool2o`0000_ooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`0Toooo
o`;o00008?ooool3o`0000Wooooo0_l00005ooooo`?o00000_ooool2o`000003ooooool0003o0000
00Oooooo1Ol00003ooooo`;o000000?oooooo`000?l000001Ol00005ooooo`;o00003_ooool3o`00
00?ooooo0_l00002ooooo`;o00004Oooool9o`0000?ooooo2?l000001?oooooo0000o`000?l00005
ooooo`?o00002Oooool3o`0001;ooooo0_l00009ooooo`;o00001_ooool3o`0000Cooooo0_l00005
ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0AOooool4o`0000;ooooo0_l00005oooo
o`Co00000oooool6o`0000;ooooo0_l00007ooooo`Go000000?oooooo`000?l000000_ooool4o`00
0003ooooool0003o000000?o00005?ooool2o`0000?ooooo0_l00002ooooo`?o000000?oooooo`00
0?l000003Oooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o0000
00?o00001?ooool2o`0000Cooooo0ol0000:ooooo`Co000000?oooooo`000?l000003oooool2o`00
00Wooooo0_l00006ooooo`;o00001Oooool2o`00047ooooo000Looooo`03o`000?oooooooooo02Ko
oooo0_l0000Mooooo`;o00001?ooool2o`0000Oooooo0_l00004ooooo`Go00002?ooool4o`000005
ooooool0003o0000o`000?ooool02?l00002ooooo`Go000000?oooooo`000?l000004Oooool2o`00
00Oooooo0_l000000ooooooo0000o`00000Fooooo`;o000000Coooooo`000?l0003o00000_ooool2
o`000004ooooool0003o0000o`0000;ooooo1Ol00003ooooo`;o00000oooool4o`0000?ooooo0_l0
000;ooooo`?o000000?oooooo`000?l000006?ooool2o`0000Cooooo1?l0000iooooo`007?ooool2
o`0002Oooooo0_l000000ooooooo0000o`00000Dooooo`;o00001_ooool2o`0001Cooooo0_l00008
ooooo`Co00001oooool2o`0000Cooooo1?l000001?oooooo0000o`000?ooool3o`00013ooooo0_l0
0007ooooo`;o00004_ooool2o`0000Oooooo0ol000000ooooooo0000o`00000>o`0000;ooooo0_l0
0003ooooo`;o00004_ooool3o`0000Cooooo1Ol0000=ooooo`;o00002Oooool4o`0003Wooooo000L
ooooo`03o`000?oooooooooo02Wooooo0_l0000Dooooo`;o000000?oooooo`000?l000000oooool2
o`0001?ooooo0ol0000;ooooo`Co000000Coooooo`000?l0003ooooo0ol00003ooooo`Oo00000_oo
ool2o`000003ooooool0003o000000Gooooo0_l00009ooooo`;o00006?ooool2o`0000Oooooo0ol0
00000ooooooo0000o`000003o`0000;ooooo1Ol00002ooooo`;o00001_ooool2o`0001[ooooo1ol0
000;ooooo`;o00001Oooool2o`0000;ooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0Q
ooooo`;o00007oooool2o`0001Sooooo0ol0000;ooooo`Co000000Coooooo`000?l0003ooooo0ol0
0007ooooo`;o00001_ooool5o`0000;ooooo0_l00009ooooo`;o00005?ooool2o`0000Sooooo0_l0
0002ooooo`;o00000_ooool2o`0000Cooooo0ol00003ooooo`;o00001oooool2o`000003ooooool0
003o000000;o00005Oooool2o`0000?ooooo0_l000000ooooooo0000o`00000?ooooo`;o00000_oo
ool2o`0003_ooooo000Looooo`03o`000?oooooooooo027ooooo0_l0000Mooooo`;o00001_ooool2
o`0000Kooooo0_l0000Booooo`;o00001?ooool2o`0000Gooooo0_l0000Cooooo`Go000000?ooooo
o`000?l000000_l0000Looooo`;o00002?ooool2o`000004ooooool0003o0000ooooo`;o00000ooo
ool5o`0000Cooooo0_l0000:ooooo`Co00006Oooool2o`0000;ooooo0_l00004ooooo`;o0000B_oo
ool001cooooo00?o0000ooooooooool0:?ooool2o`0001Kooooo0_l00006ooooo`;o00000oooool2
o`000003ooooool0003o000001;ooooo0_l0000;ooooo`;o00004Oooool7o`000003ooooool0003o
000000;o000000?oooooo`000?l000000oooool4o`0000Sooooo0_l0000Eooooo`Oo000000?ooooo
o`000?l000000ol0000:ooooo`;o00000oooool3o`0000Cooooo0ol0000Dooooo`Co00001_ooool2
o`0004[ooooo000Looooo`03o`000?oooooooooo02Sooooo0_l0000Iooooo`;o00000oooool2o`00
00?ooooo0_l00003ooooo`;o00002_ooool2o`0001Kooooo0_l00007ooooo`;o00000oooool3o`00
0003ooooool0003o000000;ooooo1?l000001?oooooo0000o`000?ooool6o`0000Sooooo0_l00002
ooooo`;o00001Oooool2o`000003ooooool0003o000000Sooooo1ol000001?oooooo0000o`000?l0
000;ooooo`;o00000oooool3o`000004ooooool0003o0000ooooo`?o00005_ooool2o`0000;ooooo
0_l0000;ooooo`;o00002Oooool2o`0003Kooooo000Looooo`03o`000?oooooooooo027ooooo0_l0
000Oooooo`?o00001Oooool2o`0000Gooooo0ol0000:ooooo`;o00005_ooool2o`0000Oooooo0_l0
0002ooooo`?o00000_ooool2o`0000Sooooo1?l000000ooooooo0000o`00000=ooooo`;o00000ooo
ool4o`000003ooooool0003o000000Cooooo0_l00002ooooo`Co000000Coooooo`000?l0003ooooo
0_l0000Booooo`;o000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l0000Dooooo`;o0000
2oooool2o`0000Wooooo0_l0000fooooo`007?ooool00ol0003oooooooooo`0Qooooo`?o00007_oo
ool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l00000:Ooo
ool3o`0000?ooooo1?l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l000000ooooooo0000
o`000008ooooo`;o00000oooool2o`0000Sooooo0_l00002ooooo`?o00001?ooool2o`0000?ooooo
1?l0000Booooo`;o00000oooool2o`0000Cooooo0_l00005ooooo`;o00004oooool2o`0000_ooooo
1Ol00006ooooo`;o0000=oooool001cooooo00?o0000ooooooooool08_ooool2o`0002?ooooo1?l0
0003ooooo`;o000000?oooooo`000?l000002Oooool2o`0001Gooooo0_l00006ooooo`Co00000ooo
ool4o`000003ooooool0003o000000?o00000_ooool3o`0000_ooooo0_l00002ooooo`?o00002_oo
ool5o`0000Kooooo0_l000000ooooooo0000o`000002o`0001;ooooo0_l00009ooooo`?o00006Ooo
ool2o`0000_ooooo1Ol00006ooooo`;o0000=oooool001cooooo00?o0000ooooooooool0;?ooool2
o`0001?ooooo0_l00004ooooo`Co00001_ooool2o`0000Sooooo0ol0000Eooooo`;o00001_ooool2
o`0000Oooooo0_l00003ooooo`;o00000oooool2o`00013ooooo0_l00004ooooo`;o00001Oooool2
o`0000Wooooo0_l00002ooooo`Co00007?ooool5o`0002Cooooo0_l000001?oooooo0000o`000?l0
0003ooooo`?o000000?oooooo`000?l00000=Oooool001cooooo00?o0000ooooooooool0;?ooool2
o`0001?ooooo0_l00002ooooo`Go00001?ooool3o`0000[ooooo0ol00008ooooo`;o00000oooool4
o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000_l00000
0ooooooo0000o`000002o`000003ooooool0003o000001gooooo0_l00003ooooo`;o00000oooool2
o`0000cooooo0ol0000Iooooo`[o000000?oooooo`000?l000001_ooool2o`0001Kooooo0_l00002
ooooo`;o00000oooool6o`0003Gooooo000Looooo`03o`000?oooooooooo04Gooooo0_l00004oooo
o`Ko00000_ooool2o`0000Gooooo1_l00006ooooo`;o00000oooool4o`0000?ooooo4_l00002oooo
o`?o00000oooool2o`0000Cooooo0_l0000;ooooo`;o00002_ooool2o`000003ooooool0003o0000
00;o00001oooool2o`0000Cooooo0_l0000Booooo`;o00001?ooool;o`000003ooooool0003o0000
00Kooooo0_l0000<ooooo`;o00005?ooool3o`0003Gooooo000Looooo`03o`000?oooooooooo043o
oooo0_l00003ooooo`?o00000oooool5o`0000?ooooo0_l00005ooooo`?o000000?oooooo`000?l0
00004_oooolFo`0000Cooooo0_l00004ooooo`;o00002oooool2o`0000gooooo0_l00009ooooo`;o
00001?ooool2o`0001;ooooo1?l000000ooooooo0000o`000009o`0000[ooooo0_l0000;ooooo`?o
00002_ooool2o`0000Sooooo0_l0000fooooo`007?ooool00ol0003oooooooooo`0Jooooo`;o0000
9?ooool2o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`;o00006oooool2o`0000;ooooo
0_l00004oooooaCo000000?oooooo`000?l000001Ol0000>ooooo`;o00003Oooool2o`0000Sooooo
0_l00005ooooo`;o00000_ooool2o`00013ooooo3ol000000ooooooo0000o`00000Cooooo`;o0000
1Oooool2o`0000?ooooo0ol000000ooooooo0000o`000005ooooo`;o0000=_ooool001cooooo00?o
0000ooooooooool06_ooool2o`0000Cooooo0_l0000Qooooo`Go000000?oooooo`000?l000004ooo
ool2o`0000[ooooo0ol00002ooooo`Co00000ooooolKo`0002;ooooo0_l00003ooooo`?o00002?oo
ool2o`00013ooooo3ol000000ooooooo0000o`00000<ooooo`;o00001?ooool2o`0000Kooooo0_l0
0003ooooo`;o00000_ooool2o`0003gooooo000Looooo`03o`000?oooooooooo023ooooo0_l0000Q
ooooo`Co00004_ooool2o`0000?ooooo0_l00002ooooo`;o00001_ooool2o`0000?ooooo4?l00000
0ooooooo0000o`00000:o`0000Wooooo0_l00002ooooo`;o00006?ooool4o`0000;ooooo0_l0000=
ooooo`;o00002oooool8o`000003ooooool0003o000000?o00004?ooool2o`0000Cooooo0_l00003
ooooo`;o00003oooool2o`0003Sooooo000Looooo`;o0000@Oooool5o`0000Oooooo0_l0000;oooo
o`;o00001oooool2o`0000oooooo6_l00008ooooo`;o00000_ooool2o`0001Sooooo1?l00003oooo
o`;o00001Oooool2o`0000Gooooo0_l00008ooooo`;o00000_ooool3o`000003ooooool0003o0000
00Go00007Oooool3o`000003ooooool0003o000000Oooooo0_l00002ooooo`;o0000>?ooool001co
oooo00?o0000ooooooooool0<?ooool2o`0000kooooo1Ol00007ooooo`;o00001?ooool2o`0000So
oooo0_l0000Gooooo`Ko000000?oooooo`000?l000004Ol000000ooooooo0000o`000003ooooo`Ko
00006?ooool2o`0000Gooooo0_l00004ooooo`Co00003_ooool8o`000003ooooool0003o000000Co
00002_ooool2o`0000[ooooo0_l00006ooooo`Ko00001_ooool2o`0003cooooo000Looooo`03o`00
0?oooooooooo033ooooo0_l0000>ooooo`Co00001?ooool3o`0000Oooooo0_l00008ooooo`?o0000
2_ooool2o`0000Wooooo3ol000000ooooooo0000o`000002o`000003ooooool0003o000000Wo0000
00?oooooo`000?l000000_l0000Aooooo`;o00003_ooool2o`0000Cooooo1?l000000ooooooo0000
o`00000=ooooo`go00002_ooool2o`0000Sooooo1?l00007ooooo`Ko00002?ooool2o`0003Wooooo
000Looooo`03o`000?oooooooooo027ooooo0_l0000Mooooo`Co00001?ooool3o`0000Oooooo0_l0
0009ooooo`;o00001oooool2o`000004ooooool0003o0000o`0000Sooooo3ol000000ooooooo0000
o`00000>o`000003ooooool0003o000000?o00001_ooool2o`0000Oooooo0ol00008ooooo`;o0000
00?oooooo`000?l000000_ooool2o`0000Sooooo0_l0000=ooooo`co00005Oooool4o`0000Sooooo
0_l000000ooooooo0000o`000007ooooo`?o0000>Oooool001cooooo00?o0000ooooooooool08Ooo
ool2o`0001gooooo1Ol0000=ooooo`Co00004?ooool2o`0000;ooooo0_l000000ooooooo0000o`00
0002o`0000?ooooo6ol00002ooooo`;o00000_ooool5o`000004ooooool0003o0000o`0000;ooooo
0_l00007ooooo`;o00002Oooool2o`000003ooooool0003o000000;ooooo0_l0000@ooooo`;o0000
1Oooool;o`00013ooooo0_l00004ooooo`Co00002?ooool2o`0000[ooooo0_l0000jooooo`007?oo
ool00ol0003oooooooooo`0mooooo`;o000000Coooooo`000?l0003ooooo1_l0000;ooooo`;o0000
1?ooool2o`00017ooooo1Ol00002oooooaoo00000_ooool3o`0000?ooooo0ol00005ooooo`;o0000
4?ooool4o`0001Cooooo0_l00005ooooo`[o00002oooool2o`0000Cooooo1?l000000ooooooo0000
o`000004o`0000Gooooo0_l000000ooooooo0000o`000004ooooo`;o0000?oooool001cooooo00?o
0000ooooooooool0<Oooool2o`0000[ooooo0_l000000ooooooo0000o`000003ooooo`Co00004Ooo
ool4o`0000cooooo0_l00004ooooob?o00000oooool2o`0000Cooooo1?l00003ooooo`Co00003?oo
ool6o`0000Kooooo0_l00005ooooo`;o00001_ooool2o`0000?ooooo2_l0000<ooooo`;o00001_oo
ool5o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l000000_ooool4o`0003oooooo000L
ooooo`03o`000?oooooooooo037ooooo0_l0000<ooooo`?o00006_ooool2o`0000Oooooo0ol00002
ooooo`;o00000_oooolWo`000004ooooool0003o0000o`0000?ooooo1Ol00004ooooo`;o00003?oo
ool2o`0000[ooooo0_l00002ooooo`Go00000oooool2o`000003ooooool0003o000000?ooooo1?l0
00001?oooooo0000o`000?ooool3o`0000Wooooo0_l00006ooooo`So00002?ooool2o`0000Gooooo
0ol00010ooooo`007?ooool00ol0003oooooooooo`0Sooooo`;o00006_ooool3o`0000Cooooo0_l0
000Booooo`;o00002Oooool3o`0000Gooooo:?l000000ooooooo0000o`000002o`0000Gooooo0_l0
0007ooooo`;o00001?ooool3o`000003ooooool0003o000000Oooooo0_l00006ooooo`Co00001?oo
ool2o`0000Oooooo0_l00006ooooo`;o00002?ooool3o`0000Kooooo2?l00007ooooo`Co00001Ooo
ool2o`00043ooooo000Looooo`03o`000?oooooooooo02?ooooo0_l0000Jooooo`;o00001Oooool2
o`00017ooooo0ol0000?ooooobKo00001Oooool4o`0000;ooooo0_l00004ooooo`;o00001?ooool2
o`0000?ooooo1ol00007ooooo`;o00002?ooool2o`0000Gooooo0_l00006ooooo`;o00001_ooool5
o`0000;ooooo0_l000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l000001?l00007
ooooo`Co00001Oooool2o`00043ooooo000Looooo`03o`000?oooooooooo037ooooo0_l0000Roooo
o`;o00000_ooool2o`0000oooooo0ol000000ooooooo0000o`000002ooooob?o00001_ooool5o`00
00;ooooo1Ol00006ooooo`?o000000?oooooo`000?l000002?ooool2o`0000;ooooo0ol00002oooo
o`Co00000oooool3o`0000Sooooo1Ol00002ooooo`Co00000_ooool2o`0000Wooooo0_l000000ooo
oooo0000o`000002o`0000Oooooo0_l00002ooooo`;o0000Aoooool001cooooo00?o0000oooooooo
ool0<Oooool2o`0002;ooooo0_l0000Cooooo`;o000000Coooooo`000?l0003o00000_oooolSo`00
00;ooooo0_l00002ooooo`Go00000oooool4o`0000Gooooo0_l0000=ooooo`;o00000_ooool3o`00
00;ooooo1?l00003ooooo`;o00002Oooool5o`0000;ooooo0ol0000?ooooo`Ko000000Coooooo`00
0?l0003o00000oooool2o`0004_ooooo000Looooo`03o`000?oooooooooo03gooooo0_l0000Noooo
o`;o00003_ooool3o`0000;ooooo8ol00002ooooo`;o00001?ooool2o`000004ooooool0003o0000
ooooo`;o00001?ooool6o`0000gooooo0_l00002ooooo`;o00005Oooool2o`0001Kooooo1_l00000
1?oooooo0000o`000?l0000Aooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0?Oooool4
o`0001_ooooo0ol0000;ooooo`;o00000_oooolYo`0000Cooooo0_l00003ooooo`;o00000_ooool2
o`0000?ooooo0ol000001?oooooo0000o`000?l0000<ooooo`;o00003?ooool2o`0000_ooooo0_l0
000Cooooo`;o00001Oooool2o`0001Gooooo0_l0000mooooo`0000Koooooonk^k_lb<S;o0000oc8b
<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000oooooooo
ool0>oooool2o`000004ooooool0003o0000o`0001_ooooo0_l0000<ooooo`;o00000_oooolRo`00
0005ooooool0003o0000o`000?ooool01?l00002ooooo`;o00000oooool2o`0000;ooooo0_l00007
ooooo`?o00001_ooool3o`00017ooooo0_l00007ooooo`;o00005oooool2o`0000Cooooo0_l0001E
ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooo
oonHV9So8B4Q00Kooooo00?o0000ooooooooool0>oooool2o`000003ooooool0003o000000;o0000
6_ooool4o`0000[ooooo0_l00003ooooo`Co000000?oooooo`000?l000007_l000000ooooooo0000
o`000002o`0000Oooooo0_l00003ooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`?o
00000_ooool3o`0000Kooooo0_l000000ooooooo0000o`00000?ooooo`;o00001oooool2o`0000go
oooo0_l00004ooooo`?o0000EOooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool0
2Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0?Oooool7o`0000go
oooo0_l000000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l000003oooool4o`000003
ooooool0003o000001ko00000oooool2o`0000Cooooo0_l00006ooooo`;o00000_ooool4o`000004
ooooool0003o0000ooooo`?o00001oooool9o`0000cooooo0_l0000:ooooo`;o00002?ooool3o`00
00;ooooo1?l00002ooooo`;o0000E_ooool00003ooooool0003ooooo00;ooooo00?o0000oooooooo
ool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0000Uooooo`;o00005_ooool2o`00
0003ooooool0003o000000;o00003?ooool3o`000003ooooool0003o000000;o00000oooool4o`00
00Sooooo0_l00002ooooo`;o00000_oooolMo`000003ooooool0003o000000Go00000oooool3o`00
00?ooooo0_l0000:ooooo`;o00003?ooool2o`0000;ooooo1?l00002ooooo`?o000000?oooooo`00
0?l000000ol00006ooooo`;o00005?ooool3o`0000Cooooo0_l0000=ooooo`;o0000Boooool00003
ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oEEEEo`000?l@413oc<c<
00Kooooo00?o0000ooooooooool09Oooool2o`0000gooooo0_l0000;ooooo`;o00003Oooool2o`00
00Cooooo0_l00004ooooo`Co00001oooool2o`0000;ooooo0_l00003ooooobGo00000_ooool3o`00
00?ooooo0_l00003ooooo`;o00000oooool3o`0000gooooo0_l00003oooooa3o00006_ooool2o`00
00Oooooo0_l00008ooooo`Go0000Boooool00003ooooool@413ooooo00;ooooo00?o410@oooooooo
ool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo02Gooooo0_l0000=ooooo`;o
00005?ooool2o`0000?ooooo0_l00008ooooo`Oo00000oooool2o`0000;ooooo0_l00007ooooob;o
000000Goooooo`000?l0003o0000ooooo`02o`000004ooooool0003o0000ooooo`Oo00000oooool3
o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`_o000000?oooooo`000?l000000_ooool5
o`0000kooooo0_l00006ooooo`?o00001?ooool2o`000004ooooool0003o0000ooooo`;o00002?oo
ool4o`000003ooooool0003o000000?ooooo0_l00014ooooo`0000KoooooogMgMonHV9SooooooiRH
V?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool09Oooool4o`0000_ooooo
0_l0000Dooooo`;o00000oooool2o`0000?ooooo0_l00003ooooo`Ko00001?ooool2o`0000;ooooo
0_l00007ooooo`;o000000?oooooo`000?l000007Ol000001?oooooo0000o`000?l00004ooooo`;o
00000oooool3o`000003ooooool0003o000000Gooooo0ol000001?oooooo0000o`000?ooool2o`00
00Kooooo5_l000000ooooooo0000o`000008ooooo`;o00001_ooool3o`0000Cooooo1_l0000<oooo
o`Go00000_ooool3o`0000;ooooo0_l00010ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<
ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool09oooool2o`0002Kooooo0_l0
0003ooooo`;o00001oooool2o`0000Gooooo0_l00004ooooo`?o00001?oooolQo`0000;ooooo0_l0
00001?oooooo0000o`000?ooool2o`0000;ooooo0ol00002ooooo`;o00001Oooool3o`0000Cooooo
0_l00006ooooo`;o00001?ooool5o`000003ooooool0003o000000?o000000?oooooo`000?l00000
0_l000000ooooooo0000o`000004ooooo`;o00004_ooool6o`0000_ooooo1Ol00002ooooo`Oo0000
@?ooool001cooooo00?o0000ooooooooool0A_ooool2o`0000?ooooo0_l00007ooooo`;o00000ooo
ool2o`0000Kooooo0_l000000ooooooo0000o`000007o`0000Cooooo0_l000000ooooooo0000o`00
000Po`000004ooooool0003o0000ooooo`Ko00004Oooool2o`0000;ooooo0_l00002ooooo`;o0000
00?oooooo`000?l000004?l000000ooooooo0000o`000005ooooo`?o000000Coooooo`000?l0003o
00002_ooool2o`0000Cooooo0ol0000;ooooo`Go00001?ooool4o`00047ooooo000Looooo`03o`00
0?oooooooooo043ooooo0_l00004ooooo`;o00000oooool2o`0000Oooooo0_l00003ooooo`;o0000
1_ooool2o`0000?ooooo1ol00002ooooobGo000000?oooooo`000?l000001Oooool2o`0001?ooooo
0_l00002ooooo`Ko000000?oooooo`000?l000003ol00002ooooo`;o00001_ooool6o`0000[ooooo
0_l00003ooooo`?o00001oooool2o`0000?ooooo1_l00005ooooo`;o0000@Oooool001cooooo00?o
0000ooooooooool0=_ooool2o`0000Sooooo0_l0000Rooooo`;o00001?oooolOo`000003ooooool0
003o000000?o00001_ooool2o`0000Kooooo0_l0000GoooooaWo00002Oooool4o`00013ooooo0_l0
0006ooooo`Co00001?ooool5o`0004Sooooo000Looooo`03o`000?oooooooooo03Kooooo0_l0000/
ooooo`;o00001_ooool4o`000003ooooool0003o000001[o000000?oooooo`000?l000001_l00004
ooooo`Go00002Oooool4o`0000Oooooo0_l000000ooooooo0000o`00000:o`000003ooooool0003o
000000_o00002Oooool3o`0000[ooooo0_l0000<ooooo`;o00001_ooool3o`0004[ooooo000Loooo
o`03o`000?oooooooooo03Kooooo0_l0000^ooooo`?o00002?oooolUo`0000Cooooo1?l0000:oooo
o`Co00001_ooool3o`000003ooooool0003o000001[o00001oooool2o`0000_ooooo1Ol00004oooo
o`;o00002?ooool3o`000003ooooool0003o000004[ooooo000Looooo`03o`000?oooooooooo03Ko
oooo0_l0000=ooooo`;o00001_ooool2o`0000_ooooo1_l00006ooooo`?o00000_ooool2o`0000Go
oooo5Ol000000ooooooo0000o`000009o`0000Sooooo0_l00004ooooo`;o00001?ooool3o`0000?o
oooo1?l000001Ooooooo0000o`000?l0003ooooo01Wo000000Coooooo`000?l0003o00001_ooool2
o`0000Sooooo0_l000000ooooooo0000o`000003o`0000Cooooo0_l000000ooooooo0000o`000005
ooooo`?o0000COooool001cooooo00?o0000ooooooooool0AOooool2o`0000Kooooo0_l0000;oooo
o`Ko00000_ooool2o`0000;ooooo1?l000000ooooooo0000o`000005ooooo`co00000_ooool?o`00
0003ooooool0003o000000?o00003?ooool4o`0000;ooooo0ol00003ooooo`Co000000Goooooo`00
0?l0003o0000ooooo`0Jo`000003ooooool0003o000000Sooooo0_l00006ooooo`Go00002_ooool2
o`0000Gooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00008Oooool2o`00
00;ooooo0_l00002ooooo`;o00000_ooool4o`000003ooooool0003o000000Cooooo3?l000000ooo
oooo0000o`00000?o`000003ooooool0003o000000?o00003_ooool2o`000004ooooool0003o0000
o`0000Sooooo1ol000000ooooooo0000o`00000Jo`000003ooooool0003o000000?ooooo0_l00003
ooooo`;o00000oooool3o`00013ooooo0_l00006ooooo`;o0000Aoooool001cooooo00?o0000oooo
ooooool0:_ooool2o`0000_ooooo0_l0000?ooooo`;o00003?ooool2o`0000;ooooo0_l00006oooo
o`;o00001oooool4o`0000;ooooo2_l000000ooooooo0000o`000003o`0000;ooooo0_l00004oooo
o`Co000000?oooooo`000?l000000_l000000ooooooo0000o`00000Aooooo`?o00002?ooool2o`00
0003ooooool0003o000001oo000000?oooooo`000?l000001oooool3o`0000;ooooo0_l00002oooo
o`;o00001_ooool2o`0000Kooooo0_l00006ooooo`;o0000Aoooool001cooooo00?o0000oooooooo
ool0:_ooool2o`0000_ooooo0_l00008ooooo`;o00000oooool4o`0000cooooo0_l00006ooooo`;o
00003Oooool2o`0000Kooooo2_l00006ooooo`;o000000Coooooo`000?l0003ooooo0_l000001Ooo
oooo0000o`000?l0003ooooo00?o00001Oooool2o`00013ooooo0_l00004ooooo`_o000000?ooooo
o`000?l000003Ol000000ooooooo0000o`000002o`0000Sooooo0_l00003ooooo`;o00000oooool2
o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l00000Eoooool001cooooo00?o0000oooo
ooooool0@Oooool2o`0000?ooooo0_l0000:ooooo`Ko00001_ooool3o`0000Oooooo0_l00003oooo
o`?o00001Oooool<o`0000Cooooo0_l000000ooooooo0000o`000003o`0000;ooooo0_l000000ooo
oooo0000o`000006ooooo`Co00000_ooool2o`0000[ooooo0_l00004oooooaoo00002Oooool2o`00
00?ooooo0_l0000<ooooo`;o00000_ooool4o`0005Cooooo000Looooo`;o0000@oooool2o`0000?o
oooo0_l00009ooooo`Ko00001oooool2o`0000Oooooo0_l000001?oooooo0000o`000?ooool4o`00
00Gooooo3Ol00002ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00002oooool2o`00
00;ooooo1?l0000;ooooob?o00001_ooool2o`0000Gooooo0_l00007ooooo`?o00001?ooool6o`00
00Kooooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00000oooool2o`0000Wo
oooo0_l0000;ooooo`;o00002Oooool3o`000003ooooool0003o000000;o00001oooool;o`0000;o
oooo1_l00004ooooo`Co00003_ooool2o`000003ooooool0003o000000Kooooo9Ol000000ooooooo
0000o`000003ooooo`;o00001?ooool2o`0000Sooooo0ol00004ooooo`;o00002_ooool2o`0004co
oooo000Looooo`03o`000?oooooooooo04Gooooo1Ol0000Pooooo`;o000000?oooooo`000?l00000
1?l00002ooooo`;o00000_ooool2o`0000?ooooo2ol00002ooooo`;o00000oooool4o`0000Gooooo
1?l00004ooooo`?o000000?oooooo`000?l000001_oooolTo`0000;ooooo0_l00009ooooo`?o0000
4Oooool3o`0005Cooooo000Looooo`03o`000?oooooooooo04Gooooo0_l000000ooooooo0000o`00
0007ooooo`;o00002?ooool4o`0000kooooo2_l000001?oooooo0000o`000?l00004ooooo`Oo0000
00?oooooo`000?l000000_ooool2o`0000cooooo1?l00002ooooo`Go00002_ooool2o`000003oooo
ool0003o000002;o00002_ooool2o`00017ooooo0ol00006ooooo`;o0000C?ooool001cooooo00?o
0000ooooooooool0DOooool2o`0000Sooooo1?l00007ooooo`;o00002?ooool2o`000003ooooool0
003o000000?ooooo1?l00003ooooo`So00001?ooool2o`0000[ooooo0_l00006ooooo`;o00003Ooo
ool2o`0000Sooooo1ol000000ooooooo0000o`00000=o`000003ooooool0003o000000;o00006?oo
ool2o`0000gooooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`1Looooo`;o00002?ooool3
o`0000Sooooo0ol00003ooooo`;o000000?oooooo`000?l000001oooool4o`0000Cooooo0_l0000:
ooooo`;o00006oooool2o`000003ooooool0003o000001Wo00002_ooool2o`0000kooooo0_l00009
ooooo`;o0000D?ooool001cooooo00?o0000ooooooooool0E?ooool2o`000003ooooool0003o0000
00?ooooo0_l00008ooooo`?o00002?ooool3o`0000?ooooo0ol00009ooooo`;o00004Oooool2o`00
00?ooooo0_l0000Goooooa[o000000Coooooo`000?l0003ooooo0_l00008ooooo`;o00003oooool2
o`0000Sooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00002Oooool6o`00
00cooooo0ol00007ooooo`;o00001_ooool2o`000003ooooool0003o000000Sooooo0_l0000?oooo
o`;o00000oooool2o`0001Sooooo0_l00003oooooaCo000000Coooooo`000?l0003ooooo0_l0000F
ooooo`;o000000?oooooo`000?l00000F_ooool001cooooo00?o0000ooooooooool0BOooool2o`00
00?ooooo0_l00004ooooo`Ko00001_ooool2o`0000Gooooo0ol00006ooooo`?o00002?ooool3o`00
00Oooooo0_l0000;ooooo`;o00001?ooool2o`0001Wooooo1?l00004oooooaKo000000?oooooo`00
0?l000005?ooool4o`000003ooooool0003o000005[ooooo000Looooo`03o`000?oooooooooo04Wo
oooo0_l00003ooooo`;o00002?ooool2o`0000Kooooo0_l00006ooooo`;o00001Oooool4o`0000?o
oooo0_l00002ooooo`Go00000oooool2o`0000gooooo0ol00004ooooo`;o00006Oooool5o`0000Co
oooo3Ol000001Ooooooo0000o`000?l0003ooooo00;o00003_ooool2o`0000Sooooo0ol00002oooo
o`;o000000?oooooo`000?l000000_l0001Eooooo`007?ooool00ol0003oooooooooo`19ooooo`;o
00005Oooool3o`0000Gooooo0_l00005ooooo`?o00001?ooool2o`0000;ooooo0_l000000ooooooo
0000o`000003ooooo`;o000000Coooooo`000?l0003o00000oooool2o`000004ooooool0003o0000
ooooo`;o00000oooool2o`0001Cooooo0_l00006ooooo`Co00000oooool5o`000003ooooool0003o
000000So00004oooool2o`0000[ooooo0_l00004ooooo`Co0000EOooool001cooooo00?o0000oooo
ooooool0E_ooool2o`0000Wooooo0_l000000ooooooo0000o`000003ooooo`;o00001oooool2o`00
00cooooo1?l000001?oooooo0000o`000?l00003ooooo`;o000000?oooooo`000?l000001_ooool2
o`0000Sooooo0_l00002ooooo`;o000000?oooooo`000?l000000oooool4o`0000?ooooo0ol00003
oooooa;o00000_ooool2o`0000oooooo0_l00003ooooo`Wo00001Oooool2o`0005Kooooo000Loooo
o`03o`000?oooooooooo05Kooooo0_l00003ooooo`;o00001oooool2o`0000?ooooo0ol000000ooo
oooo0000o`000002ooooo`?o00003?ooool4o`0000Oooooo0_l0000;ooooo`;o00001_ooool2o`00
00;ooooo0_l000000ooooooo0000o`000005ooooo`?o00000_ooool2o`0000;ooooo3Ol00003oooo
o`?o00000_ooool5o`0000Cooooo0_l00006ooooo`;o00001?ooool9o`0000Gooooo0_l0001Foooo
o`007?ooool00ol0003oooooooooo`1Kooooo`;o00003Oooool2o`000003ooooool0003o000000Co
00007?ooool2o`0000Oooooo0_l00006ooooo`;o00001oooool2o`0000Cooooo0ol00005ooooo`_o
00000_ooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Ko
oooo1Ol00002ooooo`Co00002oooool2o`0005Cooooo000Looooo`03o`000?oooooooooo053ooooo
0ol0000?ooooo`Co00001Oooool2o`0000;ooooo0_l0000Nooooo`;o00006?ooool2o`0000Gooooo
0_l00006ooooo`?o00000_ooool5o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l00000
0_ooool2o`0000Cooooo0_l00007ooooo`Co00004Oooool2o`0005Cooooo000Looooo`03o`000?oo
oooooooo053ooooo0ol00002ooooo`;o00002oooool4o`0000Cooooo0ol0000:ooooo`Co00004ooo
ool2o`0000Gooooo0_l0000Oooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0
003o000000Gooooo0_l00002ooooo`Ko00002?ooool2o`0000;ooooo0_l0001Zooooo`007?ooool2
o`0005Kooooo0_l0000<ooooo`?o00001?ooool3o`0000[ooooo1?l00003ooooo`;o000000?ooooo
o`000?l000000_ooool4o`0000Gooooo0_l00005ooooo`;o00001?ooool2o`0001Wooooo1ol00000
0ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000001?ooool2o`0000[ooooo0_l00002
ooooo`;o00002oooool2o`0005gooooo000Looooo`03o`000?oooooooooo06;ooooo1Ol00003oooo
o`Co00002Oooool2o`0000Gooooo0_l000000ooooooo0000o`000006o`0000_ooooo0_l00005oooo
o`;o00006oooool2o`000004ooooool0003o0000ooooo`;o00001?ooool3o`0001cooooo0_l00004
ooooo`?o00001_ooool2o`0005Gooooo000Looooo`03o`000?oooooooooo03Oooooo0_l0000Roooo
o`;o00001Oooool5o`0000Gooooo0_l0000Eooooo`;o00001oooool2o`0000Kooooo0_l0000Voooo
o`;o00000oooool2o`0000;ooooo0_l00002ooooo`;o00002oooool2o`0000_ooooo0_l00004oooo
o`?o00000oooool2o`000003ooooool0003o000000;ooooo1?l0001?ooooo`007?ooool00ol0003o
ooooooooo`0gooooo`;o00006_ooool2o`0000Kooooo0_l00004ooooo`;o00001_ooool2o`0000;o
oooo1?l00007ooooo`;o00002Oooool2o`0000Cooooo0_l000000ooooooo0000o`000006ooooo`;o
00009Oooool3o`0000?ooooo0_l00005ooooo`?o00000_ooool2o`0000Gooooo1?l00007ooooo`;o
00003_ooool2o`0000Gooooo1?l0001?ooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o0000
3?ooool2o`0000Kooooo0_l00002ooooo`Co000000?oooooo`000?l000001?ooool2o`0000oooooo
0_l00005ooooo`;o0000:Oooool2o`0000Kooooo0_l00003ooooo`;o00000oooool2o`0000Gooooo
0ol00008ooooo`;o00000oooool2o`0006?ooooo000Looooo`03o`000?oooooooooo06?ooooo1?l0
00000ooooooo0000o`000002ooooo`;o00001?ooool2o`0000Wooooo0_l00002ooooo`;o00003Ooo
ool2o`00027ooooo0ol0000=ooooo`;o00004_ooool3o`0000Kooooo0_l00002ooooo`;o0000Hooo
ool001cooooo00?o0000ooooooooool0>_ooool2o`0002Oooooo1?l000000ooooooo0000o`000002
ooooo`;o00000oooool5o`0000Oooooo0_l00002ooooo`;o0000<?ooool3o`0000kooooo0ol0000>
ooooo`Go00000_ooool2o`0000;ooooo0_l00002ooooo`Co0000HOooool001cooooo00?o0000oooo
ooooool0>_ooool2o`0001Wooooo1?l0000:ooooo`;o00003?ooool5o`000004ooooool0003o0000
ooooo`;o00000_ooool2o`0000cooooo0_l0000fooooo`?o00003_ooool2o`0000Cooooo1?l00003
ooooo`;o00000_ooool2o`0000Sooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`1Eoooo
o`Co00001oooool2o`000004ooooool0003o0000ooooo`;o00002oooool6o`000003ooooool0003o
000000;ooooo0_l00007ooooo`;o00000oooool2o`0000_ooooo0_l0000dooooo`;o00002_ooool4
o`0000?ooooo0_l0000<ooooo`;o0000Eoooool001cooooo00?o0000ooooooooool0Eoooool2o`00
00Oooooo0_l000001?oooooo0000o`000?ooool2o`0000Wooooo0ol000000ooooooo0000o`00000@
ooooo`;o00004?ooool2o`0001Wooooo0_l0000Iooooo`;o00001oooool2o`0000?ooooo0_l0000;
ooooo`;o0000GOooool001cooooo00?o0000ooooooooool0H?ooool2o`000003ooooool0003o0000
00;ooooo0_l00008ooooo`?o000000?oooooo`000?l000001?ooool3o`0000Cooooo0_l0000Doooo
o`?o00006Oooool3o`0000Kooooo0_l0000Iooooo`;o00000oooool2o`0000_ooooo0_l0001Moooo
o`007?ooool00ol0003oooooooooo`1Pooooo`;o00001Oooool2o`0000[ooooo0_l00003ooooo`So
00000_ooool2o`0000cooooo0_l00006ooooo`?o00006_ooool2o`0000Kooooo0_l0002:ooooo`00
7?ooool00ol0003oooooooooo`1Pooooo`;o00000oooool2o`0000cooooo0_l00003ooooo`Co0000
00Coooooo`000?l0003o00004?ooool2o`0003Cooooo0_l00002ooooo`;o00005oooool2o`0006Co
oooo000Looooo`03o`000?oooooooooo063ooooo0_l00003ooooo`;o00003?ooool2o`0000;ooooo
0_l000001?oooooo0000o`000?l0000mooooo`;o00002_ooool2o`0000;ooooo0_l00005ooooo`;o
00004?ooool2o`0006Cooooo000Looooo`03o`000?oooooooooo063ooooo0_l0000:ooooo`;o0000
1Oooool2o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0003Sooooo0_l0000:ooooo`;o0000
1Oooool2o`0000;ooooo0_l0000:ooooo`Co0000J?ooool001cooooo00?o0000ooooooooool0@ooo
ool2o`0001kooooo0_l00007ooooo`?o00004Oooool2o`0001Gooooo0_l0000Kooooo`;o00001Ooo
ool2o`0000cooooo1_l0000:ooooo`;o000000?oooooo`000?l000000ol00002ooooo`Co0000H_oo
ool001cooooo0_l00014ooooo`;o00006Oooool2o`0000?ooooo0ol00006ooooo`?o00000_ooool2
o`0000[ooooo1?l00003ooooo`;o000000?oooooo`000?l000003_ooool2o`0001_ooooo0ol00004
ooooo`Co00001oooool2o`000003ooooool0003o000000Co000000Coooooo`000?l0003ooooo2?l0
00000ooooooo0000o`000005ooooo`Co0000H_ooool001cooooo00?o0000ooooooooool0G_ooool2
o`000003ooooool0003o000000?o00000_ooool2o`0000Oooooo0_l0000:ooooo`Co00000oooool2
o`000003ooooool0003o000002Wooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool2
o`0000Oooooo0_l00005ooooo`;o000000Coooooo`000?l0003ooooo1ol00002ooooo`;o00003ooo
ool2o`0005[ooooo000Looooo`03o`000?oooooooooo04Gooooo0_l0000Jooooo`?o00001?ooool3
o`0000[ooooo0_l0000Fooooo`Co00008Oooool2o`0000Gooooo0ol000000ooooooo0000o`00000K
ooooo`Co00003oooool2o`0005[ooooo000Looooo`03o`000?oooooooooo04Gooooo0_l0000Roooo
o`;o00001Oooool2o`0000?ooooo0_l0000:ooooo`;o00002_ooool6o`0000Cooooo0_l0000Qoooo
o`Go00006oooool2o`0006gooooo000Looooo`03o`000?oooooooooo06;ooooo1?l00004ooooo`;o
00001?ooool2o`0000_ooooo0_l00002ooooo`;o00002_ooool2o`0000;ooooo0_l00004ooooo`;o
00007Oooool3o`0000;ooooo1?l00005ooooo`;o00004?ooool2o`00077ooooo000Looooo`03o`00
0?oooooooooo06;ooooo1?l00004ooooo`Co00002Oooool2o`0000Cooooo0_l00009ooooo`;o0000
0oooool2o`0000Oooooo0_l0000Nooooo`?o00000_ooool2o`0000?ooooo0_l00002ooooo`;o0000
1?ooool2o`0000[ooooo0_l0001aooooo`007?ooool00ol0003oooooooooo`1/ooooo`;o00000_oo
ool2o`000003ooooool0003o000000;ooooo0_l0000?ooooo`;o00003?ooool2o`00027ooooo1?l0
0003ooooo`Co00001_ooool2o`0000Oooooo0_l0001dooooo`007?ooool00ol0003oooooooooo`1:
ooooo`;o00009?ooool2o`000003ooooool0003o000000_ooooo0_l00004ooooo`;o00002oooool3
o`0002?ooooo0ol00004ooooo`Oo00003?ooool2o`0007Cooooo000Looooo`03o`000?oooooooooo
04[ooooo0_l0000Rooooo`Ko00003?ooool3o`0000;ooooo0ol000000ooooooo0000o`000008oooo
o`?o00008oooool5o`0000;ooooo0_l000000ooooooo0000o`000002o`0000cooooo0_l0001doooo
o`007?ooool00ol0003oooooooooo`1^ooooo`Ko00002Oooool2o`0000;ooooo0_l00002ooooo`;o
00000_ooool2o`0002;ooooo0ol0000<ooooo`;o00001_ooool2o`0008?ooooo000Looooo`03o`00
0?oooooooooo06cooooo0_l00004ooooo`;o00002Oooool2o`0000Kooooo0_l000000ooooooo0000
o`00000Sooooo`?o00008?ooool2o`0007Oooooo000Looooo`03o`000?oooooooooo06cooooo0_l0
0004ooooo`Co00004_ooool2o`0002[ooooo0ol00004ooooo`;o00004?ooool5o`0000Sooooo0_l0
001]ooooo`007?ooool00ol0003oooooooooo`1dooooo`?o0000?Oooool3o`0000Cooooo0_l00000
0ooooooo0000o`000003ooooo`;o00001?ooool2o`0000;ooooo0ol0000:ooooo`;o0000KOooool0
01cooooo00?o0000ooooooooool0J?ooool2o`0000[ooooo0ol0000<ooooo`;o000000?oooooo`00
0?l00000<oooool2o`000003ooooool0003o000000?ooooo0_l00004ooooo`;o00003oooool2o`00
06gooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Xooooo`;o00002_ooool2o`0000gooooo0_l0
00001?oooooo0000o`000?ooool4o`0001cooooo0_l0000@ooooo`Go0000ROooool00006oooooomg
MgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06oooo
o`03o`000?oooooooooo07Gooooo0_l00006ooooo`;o00002_ooool4o`0001cooooo0_l00005oooo
o`?o00001?ooool2o`0000Cooooo0ol00029ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413o
ooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`1Coooo
o`;o00006_ooool4o`0000;ooooo0_l00006ooooo`;o0000<Oooool3o`0000Cooooo0_l000000ooo
oooo0000o`00002=ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05
oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`0005?ooooo0_l0000Jooooo`Co00003oooool2o`00
02[ooooo0_l00005ooooo`;o00000oooool2o`0008gooooo00000ooooooo0000ooooo`02ooooo`03
o`000?oooooooooo00Wooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo
073ooooo0_l00009ooooo`;o00001Oooool4o`0001Wooooo0_l0000=ooooo`;o00001Oooool2o`00
09;ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go410@okZj^_oo
oooo^[Zjoa0@4006ooooo`03o`000?oooooooooo073ooooo0_l00009ooooo`;o00001oooool2o`00
00;ooooo0_l0000Booooo`;o000000?oooooo`000?l000000oooool2o`0000cooooo0_l0002Eoooo
o`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l000001_oo
ool00ol0003oooooooooo`1Gooooo`;o00009?ooool2o`0000;ooooo0_l00002ooooo`;o000000?o
ooooo`000?l000002_ooool2o`0000Kooooo0_l00006ooooo`;o00001_ooool2o`0000Cooooo0_l0
0009ooooo`;o00002oooool2o`0007gooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo
00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo05Oooooo0_l0000Tooooo`;o
00000_ooool2o`0000;ooooo0_l00003ooooo`;o00001oooool3o`0001Kooooo0_l0000?ooooo`;o
00002oooool2o`0007gooooo000Looooo`03o`000?oooooooooo08;ooooo0_l00002ooooo`;o0000
0_ooool2o`0000Oooooo0_l0000Cooooo`?o00006_ooool2o`0008;ooooo000Looooo`03o`000?oo
oooooooo07Oooooo0_l00009ooooo`;o00000_ooool2o`0000Wooooo0_l000000ooooooo0000o`00
0004ooooo`;o00003?ooool3o`0000Oooooo0_l00006ooooo`;o00002Oooool2o`0008;ooooo000L
ooooo`03o`000?oooooooooo07Oooooo0_l0000Hooooo`;o000000?oooooo`000?l000001?ooool2
o`0001Kooooo0_l00006ooooo`;o0000SOooool001cooooo00?o0000ooooooooool0Poooool2o`00
00;ooooo0_l0000Zooooo`;o00002_ooool2o`0008Sooooo000Looooo`03o`000?oooooooooo08?o
oooo0_l00002ooooo`;o0000:_ooool2o`0000Kooooo0_l00002ooooo`;o0000R?ooool001cooooo
00?o0000ooooooooool0R_ooool2o`0001Cooooo0_l0000Iooooo`;o0000S?ooool001cooooo00?o
0000ooooooooool0P?ooool2o`0000Sooooo0_l0000Dooooo`;o00003?ooool3o`0000Kooooo0_l0
0002ooooo`;o0000S?ooool001cooooo00?o0000ooooooooool0P?ooool2o`00013ooooo0ol0000I
ooooo`?o00001_ooool2o`00093ooooo000Looooo`03o`000?oooooooooo06;ooooo0_l0000^oooo
o`?o00000oooool2o`0000Cooooo0ol000000ooooooo0000o`000004ooooo`;o00001Oooool2o`00
09Sooooo000Looooo`03o`000?oooooooooo06;ooooo0_l0000dooooo`;o00001?ooool3o`000003
ooooool0003o000000Cooooo0_l00005ooooo`;o0000V?ooool001cooooo00?o0000ooooooooool0
ZOooool2o`0009kooooo000Looooo`;o0000Z_ooool2o`0009kooooo000Looooo`03o`000?oooooo
oooo0:?ooooo0_l0000;ooooo`;o00002?ooool2o`0008gooooo000Looooo`03o`000?oooooooooo
0:?ooooo0_l0000;ooooo`;o00002?ooool2o`0008gooooo000Looooo`03o`000?oooooooooo0:co
oooo0_l00002ooooo`;o0000Uoooool001cooooo00?o0000ooooooooool0K?ooool2o`0003kooooo
0_l00002ooooo`;o0000Uoooool001cooooo00?o0000ooooooooool0K?ooool2o`000=_ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo07?ooooo
0_l0003Dooooo`007?ooool00ol0003oooooooooo`1cooooo`;o0000e?ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0N_ooool2o`000<gooooo
000Looooo`03o`000?oooooooooo07[ooooo0_l0003=ooooo`007?ooool2o`00083ooooo0_l00000
0ooooooo0000o`000002ooooo`;o0000`Oooool001cooooo00?o0000ooooooooool0Ooooool2o`00
0003ooooool0003o000000;ooooo0_l00031ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0SOoo
ool2o`000;[ooooo000Looooo`03o`000?oooooooooo08gooooo0_l0002jooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Booooo`Co000000?o410@ooooooooool00oooool0
0ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`?o0000oooooom:ooooo`00
5?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_oo
ool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooo
oe;ooooo000Booooo`03oeEEEOmVIVKo00000?ooooooE?ooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00:Gooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0F
ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Gooooo
0_l000000ol@413oooooooooo`2>ooooo`00Y_ooool01Ol0003ooooooooooooooooo000000Wooooo
1_l0000=ooooo`09ogMgMolb<S;ooooooooooomEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000
ooooooooool0Soooool00:Kooooo00Go0000ooooooooooooooooo`00000Mooooo`04o`000?oooooo
ooooo`0000?ooooo00Co0000oooooooooooooooo1Ol0002@ooooo`00Y_ooool01Ol0003ooooooooo
oooooooo000000Wooooo1_l0000=ooooo`09ogMgMolb<S;oooooooooool0003oV9RHoooooonHV9So
8B4Q00?ooooo00CoA4A4omgMgOoooooo0000TOooool00:Kooooo00Go0000ohN7QoooooooZJVYo`00
000Iooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00CogMgMoeEEEOoooooo0000TOooool00:Gooooo00?o410@o`000?mgMgL00_l000000onHV9So
ooooooooo`0Gooooo`03o`000?oooooooooo00Cooooo00?oEEEEohN7Qoooool01_ooool00omgMgOo
c<c<o`00002Aooooo`00a?ooool00ol0003oooooooooo`04ooooo`03omgMgOl@413oV9RH00Kooooo
00?ok^k^odA4A?l00000TOooool00<Cooooo1?l00004ooooo`04olc<c?m4A4Co0000oa0@40Gooooo
00?oMgMgo`000?ooool0T?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001
\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(570) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.58271 .69507 Mdot
.56597 .64664 Mdot
.45552 .35681 Mdot
.40248 .55186 Mdot
.31877 .33814 Mdot
.48559 .33946 Mdot
.63971 .39756 Mdot
.68162 .39952 Mdot
.48007 .33068 Mdot
.36277 .73639 Mdot
.66784 .38293 Mdot
.38896 .49994 Mdot
.65547 .39725 Mdot
.39975 .58519 Mdot
.63696 .52876 Mdot
.46704 .5387 Mdot
.60505 .6348 Mdot
.35808 .323 Mdot
.46671 .53683 Mdot
.45957 .35548 Mdot
.39885 .46553 Mdot
.38912 .57853 Mdot
.59489 .63409 Mdot
.39586 .58347 Mdot
.42253 .53998 Mdot
.57717 .65073 Mdot
.57261 .69116 Mdot
.39258 .52905 Mdot
.36522 .54688 Mdot
.67197 .39401 Mdot
.39824 .22626 Mdot
.72513 .74796 Mdot
.36795 .52178 Mdot
.54418 .74383 Mdot
.68421 .39524 Mdot
.69574 .27857 Mdot
.48577 .31649 Mdot
.67444 .41111 Mdot
.67696 .37314 Mdot
.67781 .37082 Mdot
.63816 .40644 Mdot
.57177 .65848 Mdot
.63514 .3616 Mdot
.50651 .38744 Mdot
.43307 .58766 Mdot
.70058 .7072 Mdot
.42278 .195 Mdot
.38445 .53388 Mdot
.60546 .68822 Mdot
.47506 .36112 Mdot
.20266 .53224 Mdot
.65205 .4247 Mdot
.65446 .59542 Mdot
.22002 .75128 Mdot
.66613 .39066 Mdot
.39034 .54427 Mdot
.47034 .34885 Mdot
.40153 .5638 Mdot
.36943 .56009 Mdot
.52231 .71239 Mdot
.36884 .57963 Mdot
.36125 .36474 Mdot
.55219 .68209 Mdot
.44844 .31948 Mdot
.47778 .33511 Mdot
.65016 .41739 Mdot
.55186 .64352 Mdot
.65327 .40703 Mdot
.3411 .60786 Mdot
.47467 .36525 Mdot
.38158 .53862 Mdot
.67267 .3877 Mdot
.56429 .63898 Mdot
.44307 .5736 Mdot
.72127 .64322 Mdot
.58624 .38693 Mdot
.41781 .35152 Mdot
.52085 .79739 Mdot
.20659 .6282 Mdot
.51237 .25856 Mdot
.40078 .59666 Mdot
.16168 .57706 Mdot
.64287 .51217 Mdot
.55754 .65269 Mdot
.57908 .72184 Mdot
.81136 .46305 Mdot
.37284 .53631 Mdot
.40042 .43084 Mdot
.41165 .5137 Mdot
.54058 .52826 Mdot
.47497 .32813 Mdot
.58495 .64162 Mdot
.43382 .58841 Mdot
.43146 .52945 Mdot
.36662 .68643 Mdot
.34339 .59314 Mdot
.42564 .5697 Mdot
.58381 .7145 Mdot
.65133 .37464 Mdot
.31616 .58733 Mdot
.37495 .30772 Mdot
.67067 .57633 Mdot
.41508 .55239 Mdot
.51065 .33868 Mdot
.57018 .69834 Mdot
.43303 .57405 Mdot
.66248 .41098 Mdot
.38792 .58937 Mdot
.66041 .43349 Mdot
.61146 .64738 Mdot
.42529 .523 Mdot
.34077 .3704 Mdot
.58513 .56169 Mdot
.60347 .67777 Mdot
.40058 .80025 Mdot
.37164 .57964 Mdot
.37699 .56966 Mdot
.56045 .65428 Mdot
.45528 .33307 Mdot
.45607 .43484 Mdot
.58618 .63256 Mdot
.67405 .36935 Mdot
.61913 .66696 Mdot
.44386 .53446 Mdot
.45426 .3363 Mdot
.68461 .56881 Mdot
.66493 .57884 Mdot
.28891 .33879 Mdot
.44475 .56962 Mdot
.62067 .59047 Mdot
.50027 .34558 Mdot
.56725 .6557 Mdot
.65885 .40533 Mdot
.35487 .57761 Mdot
.58511 .67946 Mdot
.66851 .36921 Mdot
.37896 .36759 Mdot
.31565 .33985 Mdot
.58131 .68649 Mdot
.28117 .60246 Mdot
.65462 .42839 Mdot
.67163 .36467 Mdot
.20771 .52384 Mdot
.55719 .65915 Mdot
.36545 .34151 Mdot
.64688 .3627 Mdot
.28491 .44952 Mdot
.36409 .59495 Mdot
.2336 .41919 Mdot
.14486 .50448 Mdot
.20473 .5284 Mdot
.63424 .77023 Mdot
.33845 .35223 Mdot
.64422 .36259 Mdot
.40012 .5375 Mdot
.58381 .67068 Mdot
.57542 .6718 Mdot
.44075 .54295 Mdot
.42822 .53687 Mdot
.41834 .58987 Mdot
.35769 .57848 Mdot
.60735 .20182 Mdot
.4135 .59699 Mdot
.66628 .47277 Mdot
.59231 .67836 Mdot
.43427 .54899 Mdot
.5172 .33306 Mdot
.44181 .6041 Mdot
.67528 .40946 Mdot
.37536 .55577 Mdot
.42276 .53474 Mdot
.39884 .61838 Mdot
.64091 .36079 Mdot
.76546 .59536 Mdot
.24826 .69319 Mdot
.72035 .32697 Mdot
.6702 .63059 Mdot
.49248 .3525 Mdot
.38968 .60385 Mdot
.3467 .34242 Mdot
.35046 .51084 Mdot
.36882 .56677 Mdot
.19733 .54181 Mdot
.41276 .52383 Mdot
.5793 .78579 Mdot
.31874 .6162 Mdot
.81325 .43523 Mdot
.70185 .46486 Mdot
.36259 .57379 Mdot
.32279 .70432 Mdot
.24684 .38873 Mdot
.34698 .24285 Mdot
.66718 .40069 Mdot
.51989 .32829 Mdot
.46275 .32403 Mdot
.67951 .36792 Mdot
.33802 .62676 Mdot
.37423 .74839 Mdot
.34761 .61604 Mdot
.68538 .57029 Mdot
.54461 .62896 Mdot
.33825 .34071 Mdot
.58208 .68745 Mdot
.16829 .61218 Mdot
.41457 .44799 Mdot
.55021 .3098 Mdot
.35207 .32212 Mdot
.50343 .36774 Mdot
.69484 .57796 Mdot
.35532 .33705 Mdot
.41467 .56294 Mdot
.61626 .66536 Mdot
.24403 .39024 Mdot
.47118 .57739 Mdot
.70989 .2167 Mdot
.55236 .65472 Mdot
.56295 .49438 Mdot
.66457 .39672 Mdot
.45816 .31505 Mdot
.3741 .53563 Mdot
.41126 .57613 Mdot
.55823 .68687 Mdot
.37702 .53818 Mdot
.4721 .46774 Mdot
.41715 .52976 Mdot
.49639 .30394 Mdot
.40149 .36312 Mdot
.68006 .43102 Mdot
.29076 .35318 Mdot
.57409 .63398 Mdot
.60648 .46018 Mdot
.51395 .33662 Mdot
.51098 .61052 Mdot
.67482 .3994 Mdot
.37334 .37336 Mdot
.50148 .31909 Mdot
.35576 .38475 Mdot
.43837 .59263 Mdot
.48043 .31954 Mdot
.37238 .36065 Mdot
.5735 .37776 Mdot
.42636 .56883 Mdot
.24709 .44321 Mdot
.6342 .37496 Mdot
.5765 .69104 Mdot
.36563 .57591 Mdot
.68634 .56473 Mdot
.45667 .57944 Mdot
.61235 .56975 Mdot
.70061 .57014 Mdot
.67608 .59723 Mdot
.53807 .29106 Mdot
.36895 .33718 Mdot
.68974 .66858 Mdot
.49224 .43659 Mdot
.60311 .63346 Mdot
.42523 .6023 Mdot
.80147 .57958 Mdot
.63277 .37516 Mdot
.41042 .56129 Mdot
.80258 .44458 Mdot
.64461 .36348 Mdot
.3924 .56352 Mdot
.63419 .40286 Mdot
.57968 .67324 Mdot
.57043 .42865 Mdot
.62268 .66984 Mdot
.39897 .55244 Mdot
.64051 .38242 Mdot
.51574 .32242 Mdot
.57785 .65131 Mdot
.38355 .5849 Mdot
.40332 .59919 Mdot
.68835 .57355 Mdot
.43971 .55278 Mdot
.82146 .55331 Mdot
.38729 .53297 Mdot
.50081 .36934 Mdot
.34229 .58834 Mdot
.22894 .40018 Mdot
.31232 .3408 Mdot
.55104 .63784 Mdot
.70035 .57506 Mdot
.46792 .33062 Mdot
.56892 .39409 Mdot
.30005 .33241 Mdot
.3964 .59243 Mdot
.67316 .58516 Mdot
.5655 .4891 Mdot
.65708 .41646 Mdot
.35852 .54232 Mdot
.46425 .45011 Mdot
.4891 .32381 Mdot
.69192 .57307 Mdot
.40907 .63766 Mdot
.59948 .69657 Mdot
.39222 .54237 Mdot
.49536 .3162 Mdot
.60409 .69242 Mdot
.353 .57206 Mdot
.52228 .1976 Mdot
.67859 .56667 Mdot
.63258 .38397 Mdot
.45211 .65235 Mdot
.41194 .60231 Mdot
.46389 .32087 Mdot
.57957 .6787 Mdot
.65647 .38306 Mdot
.61073 .65602 Mdot
.25877 .36041 Mdot
.63453 .60642 Mdot
.61281 .23255 Mdot
.37536 .3318 Mdot
.58933 .82656 Mdot
.71495 .31402 Mdot
.59416 .59493 Mdot
.39782 .39023 Mdot
.77994 .35169 Mdot
.50921 .32574 Mdot
.29143 .65162 Mdot
.46495 .33829 Mdot
.40656 .54475 Mdot
.48354 .33733 Mdot
.83686 .5306 Mdot
.40305 .52521 Mdot
.48572 .35448 Mdot
.5871 .21153 Mdot
.41074 .52142 Mdot
.59302 .68089 Mdot
.7312 .71589 Mdot
.43773 .81624 Mdot
.28887 .54421 Mdot
.48194 .35582 Mdot
.28905 .66395 Mdot
.38461 .53039 Mdot
.47558 .56708 Mdot
.584 .66477 Mdot
.43908 .52299 Mdot
.33448 .35249 Mdot
.34633 .37946 Mdot
.22093 .54022 Mdot
.4776 .83047 Mdot
.47538 .62185 Mdot
.57605 .65799 Mdot
.19786 .61424 Mdot
.72336 .64546 Mdot
.66641 .57386 Mdot
.68229 .38239 Mdot
.76211 .59266 Mdot
.42311 .63603 Mdot
.31925 .64604 Mdot
.50336 .4762 Mdot
.58377 .63986 Mdot
.65618 .28692 Mdot
.65073 .38436 Mdot
.29574 .70437 Mdot
.41518 .74817 Mdot
.42185 .58765 Mdot
.62666 .40737 Mdot
.32534 .56443 Mdot
.49192 .47395 Mdot
.24 .43642 Mdot
.52983 .23978 Mdot
.41301 .55902 Mdot
.69595 .6692 Mdot
.37216 .56486 Mdot
.24777 .39691 Mdot
.40265 .5563 Mdot
.61061 .66143 Mdot
.41222 .64735 Mdot
.49753 .41926 Mdot
.30749 .74041 Mdot
.4201 .44909 Mdot
.35603 .33201 Mdot
.40258 .58349 Mdot
.41936 .57987 Mdot
.36592 .36717 Mdot
.59232 .64611 Mdot
.41037 .60889 Mdot
.43109 .18969 Mdot
.41769 .5964 Mdot
.65562 .42328 Mdot
.554 .4245 Mdot
.57587 .79563 Mdot
.40109 .51977 Mdot
.59303 .69815 Mdot
.65251 .41434 Mdot
.67736 .38126 Mdot
.46146 .62936 Mdot
.6303 .37958 Mdot
.39344 .53634 Mdot
.55583 .42675 Mdot
.60031 .63562 Mdot
.34059 .52686 Mdot
.5965 .64929 Mdot
.18488 .56145 Mdot
.63214 .3686 Mdot
.6729 .59153 Mdot
.28076 .64103 Mdot
.6438 .39287 Mdot
.48267 .52428 Mdot
.36873 .64664 Mdot
.41297 .62778 Mdot
.59887 .60163 Mdot
.50686 .31394 Mdot
.68215 .59162 Mdot
.66429 .38708 Mdot
.41637 .59586 Mdot
.4308 .56601 Mdot
.63509 .41837 Mdot
.47579 .68038 Mdot
.4041 .22538 Mdot
.3938 .55175 Mdot
.60741 .65387 Mdot
.56863 .65609 Mdot
.37013 .6051 Mdot
.36872 .57006 Mdot
.51723 .35807 Mdot
.67269 .58648 Mdot
.69122 .58844 Mdot
.66431 .58479 Mdot
.52329 .3166 Mdot
.55761 .83775 Mdot
.67106 .36433 Mdot
.65556 .77462 Mdot
.79291 .50882 Mdot
.47413 .61353 Mdot
.48053 .31493 Mdot
.40005 .57103 Mdot
.42227 .555 Mdot
.64326 .37933 Mdot
.45163 .83787 Mdot
.35405 .53071 Mdot
.56603 .68508 Mdot
.64689 .42313 Mdot
.37104 .50306 Mdot
.59234 .38958 Mdot
.35103 .3745 Mdot
.378 .46358 Mdot
.62556 .40765 Mdot
.61314 .65536 Mdot
.62729 .41196 Mdot
.41985 .5833 Mdot
.40523 .63375 Mdot
.58073 .63852 Mdot
.38221 .3476 Mdot
.43557 .59232 Mdot
.38988 .5627 Mdot
.25081 .31109 Mdot
.71829 .64666 Mdot
.4811 .28193 Mdot
.41735 .54347 Mdot
.39067 .6254 Mdot
.38788 .35791 Mdot
.41115 .60518 Mdot
.36183 .55126 Mdot
.58279 .55679 Mdot
.68264 .42711 Mdot
.33121 .33042 Mdot
.29115 .71126 Mdot
.55243 .66186 Mdot
.8233 .5312 Mdot
.6734 .57284 Mdot
.6643 .43697 Mdot
.57377 .43271 Mdot
.68648 .58621 Mdot
.79198 .44789 Mdot
.72561 .33961 Mdot
.67669 .58963 Mdot
.43887 .33103 Mdot
.32588 .52356 Mdot
.35507 .55851 Mdot
.38001 .55655 Mdot
.37183 .3405 Mdot
.56192 .67187 Mdot
.67601 .47479 Mdot
.69533 .41289 Mdot
.38403 .57512 Mdot
.62886 .65733 Mdot
.81247 .44849 Mdot
.69256 .57727 Mdot
.34242 .35032 Mdot
.36823 .33267 Mdot
.3742 .56563 Mdot
.53501 .56541 Mdot
.57513 .65532 Mdot
.38362 .58481 Mdot
.36871 .59419 Mdot
.46124 .34476 Mdot
.61436 .67211 Mdot
.51633 .34092 Mdot
.7029 .5706 Mdot
.7531 .29319 Mdot
.26798 .27911 Mdot
.64337 .36921 Mdot
.69097 .30576 Mdot
.61527 .39404 Mdot
.54819 .24617 Mdot
.67279 .58836 Mdot
.38521 .5816 Mdot
.57189 .63187 Mdot
.38575 .58815 Mdot
.42475 .59381 Mdot
.42947 .58265 Mdot
.47886 .61918 Mdot
.19563 .53356 Mdot
.34844 .35445 Mdot
.33807 .59705 Mdot
.5211 .35958 Mdot
.80974 .43605 Mdot
.75544 .67101 Mdot
.40944 .58249 Mdot
.37906 .56862 Mdot
.54862 .65482 Mdot
.44117 .59034 Mdot
.66705 .41036 Mdot
.55458 .65643 Mdot
.41985 .55756 Mdot
.32564 .30698 Mdot
.39805 .61032 Mdot
.69475 .30066 Mdot
.62614 .41091 Mdot
.36565 .47254 Mdot
.38443 .63042 Mdot
.67334 .59017 Mdot
.68189 .59128 Mdot
.69152 .56323 Mdot
.64007 .41754 Mdot
.46048 .3422 Mdot
.46706 .37309 Mdot
.39539 .64014 Mdot
.39989 .53563 Mdot
.4015 .63149 Mdot
.53798 .33001 Mdot
.48701 .42967 Mdot
.66472 .71337 Mdot
.32031 .62052 Mdot
.52901 .33252 Mdot
.6231 .69769 Mdot
.33952 .77134 Mdot
.55667 .66824 Mdot
.41634 .35683 Mdot
.67727 .40079 Mdot
.33754 .36225 Mdot
.21414 .58477 Mdot
.59582 .63615 Mdot
.55964 .68633 Mdot
.49031 .35422 Mdot
.59662 .49838 Mdot
.32508 .85261 Mdot
.50657 .34028 Mdot
.3967 .38415 Mdot
.58183 .66108 Mdot
.36435 .5216 Mdot
.56852 .48744 Mdot
.58451 .51197 Mdot
.47779 .34814 Mdot
.40058 .59862 Mdot
.48888 .52651 Mdot
.5163 .35863 Mdot
.35327 .54745 Mdot
.48526 .35766 Mdot
.6287 .38669 Mdot
.5018 .34899 Mdot
.60984 .62666 Mdot
.4387 .58508 Mdot
.24694 .78163 Mdot
.63913 .50675 Mdot
.37635 .58638 Mdot
.64361 .42334 Mdot
.5609 .19064 Mdot
.42309 .57732 Mdot
.33404 .34147 Mdot
.53218 .33517 Mdot
.51622 .22105 Mdot
.36597 .54896 Mdot
.48035 .34305 Mdot
.58817 .62024 Mdot
.42132 .34763 Mdot
.45705 .2804 Mdot
.68725 .59045 Mdot
.58285 .67462 Mdot
.6724 .60371 Mdot
.68525 .39506 Mdot
.42035 .61109 Mdot
.38003 .60381 Mdot
.60223 .67263 Mdot
.58979 .36727 Mdot
.33812 .57009 Mdot
.40102 .59641 Mdot
.51595 .35629 Mdot
.5315 .35307 Mdot
.65836 .53616 Mdot
.51349 .32824 Mdot
.38792 .62462 Mdot
.60482 .67167 Mdot
.40127 .54547 Mdot
.58557 .68309 Mdot
.42822 .60019 Mdot
.65957 .66547 Mdot
.55863 .67039 Mdot
.54367 .59639 Mdot
.44217 .55207 Mdot
.49682 .63872 Mdot
.42201 .59861 Mdot
.42071 .56575 Mdot
.53465 .3333 Mdot
.35824 .3498 Mdot
.37639 .52201 Mdot
.59826 .44794 Mdot
.38317 .37372 Mdot
.5906 .75187 Mdot
.45584 .33347 Mdot
.38333 .35792 Mdot
.25315 .48532 Mdot
.70018 .57526 Mdot
.35564 .3629 Mdot
.69037 .54502 Mdot
.64141 .37163 Mdot
.61659 .64627 Mdot
.41965 .52455 Mdot
.78256 .3427 Mdot
.39824 .22671 Mdot
.68606 .57614 Mdot
.36713 .57542 Mdot
.40432 .56981 Mdot
.60762 .69253 Mdot
.16602 .59652 Mdot
.47304 .30587 Mdot
.4148 .5578 Mdot
.58483 .63376 Mdot
.15598 .54257 Mdot
.49346 .35938 Mdot
.3485 .36222 Mdot
.61957 .39396 Mdot
.55357 .6147 Mdot
.6809 .59369 Mdot
.63173 .3685 Mdot
.49994 .29496 Mdot
.19247 .55391 Mdot
.36665 .54926 Mdot
.50362 .31459 Mdot
.20413 .52922 Mdot
.31772 .60705 Mdot
.62344 .36298 Mdot
.65525 .66246 Mdot
.58213 .64096 Mdot
.63817 .42004 Mdot
.35668 .331 Mdot
.60783 .63894 Mdot
.59312 .64532 Mdot
.68151 .39732 Mdot
.72394 .43164 Mdot
.56661 .4951 Mdot
.66696 .41642 Mdot
.57967 .53599 Mdot
.21016 .51876 Mdot
.66924 .58529 Mdot
.34203 .34961 Mdot
.25831 .34465 Mdot
.57294 .65548 Mdot
.76286 .59276 Mdot
.19936 .53854 Mdot
.42524 .56922 Mdot
.37363 .35165 Mdot
.80541 .47105 Mdot
.69035 .42661 Mdot
.6641 .36708 Mdot
.42574 .42733 Mdot
.34218 .33389 Mdot
.37287 .60296 Mdot
.5626 .80157 Mdot
.42608 .52732 Mdot
.63908 .36627 Mdot
.49528 .48169 Mdot
.61286 .67371 Mdot
.68627 .39493 Mdot
.46418 .46246 Mdot
.42085 .55275 Mdot
.37085 .58762 Mdot
.2788 .37808 Mdot
.61496 .6743 Mdot
.67738 .59536 Mdot
.39202 .59455 Mdot
.39873 .56207 Mdot
.40768 .61508 Mdot
.27139 .62843 Mdot
.56261 .57693 Mdot
.41987 .56025 Mdot
.4786 .30869 Mdot
.42653 .62124 Mdot
.36019 .57154 Mdot
.6188 .68448 Mdot
.21584 .41892 Mdot
.70321 .56946 Mdot
.38352 .55584 Mdot
.39302 .55198 Mdot
.68131 .37705 Mdot
.56642 .49211 Mdot
.58472 .51507 Mdot
.49474 .36691 Mdot
.38001 .41542 Mdot
.35577 .62332 Mdot
.59013 .67527 Mdot
.33409 .35785 Mdot
.40081 .62125 Mdot
.55616 .67171 Mdot
.35434 .63297 Mdot
.51375 .36318 Mdot
.67574 .58527 Mdot
.34943 .65362 Mdot
.36057 .361 Mdot
.66256 .42987 Mdot
.68055 .76292 Mdot
.52043 .33587 Mdot
.41007 .53409 Mdot
.51427 .37957 Mdot
.50081 .3308 Mdot
.68525 .57337 Mdot
.46118 .59762 Mdot
.5764 .66912 Mdot
.61383 .66681 Mdot
.21687 .48286 Mdot
.51472 .30927 Mdot
.18263 .39493 Mdot
.62867 .38499 Mdot
.36152 .54074 Mdot
.75219 .65355 Mdot
.61076 .6747 Mdot
.26628 .36397 Mdot
.38392 .35734 Mdot
.66376 .3671 Mdot
.69817 .58697 Mdot
.56048 .67608 Mdot
.60262 .68402 Mdot
.43219 .58929 Mdot
.40056 .5784 Mdot
.38564 .40043 Mdot
.24032 .40494 Mdot
.6344 .40249 Mdot
.34569 .3634 Mdot
.4856 .36582 Mdot
.41516 .54643 Mdot
.5661 .64435 Mdot
.56054 .79481 Mdot
.40846 .60296 Mdot
.51182 .36316 Mdot
.57552 .64324 Mdot
.35632 .37056 Mdot
.37794 .36318 Mdot
.42383 .56863 Mdot
.54833 .77455 Mdot
.64326 .39594 Mdot
.59973 .67834 Mdot
.56504 .71223 Mdot
.34004 .5873 Mdot
.40505 .58165 Mdot
.36263 .5143 Mdot
.64993 .35564 Mdot
.34207 .65104 Mdot
.3891 .35198 Mdot
.568 .67159 Mdot
.38233 .58979 Mdot
.3608 .36489 Mdot
.32488 .65527 Mdot
.68305 .58532 Mdot
.49192 .358 Mdot
.33431 .34477 Mdot
.36774 .35168 Mdot
.37852 .37587 Mdot
.75876 .59652 Mdot
.57271 .6999 Mdot
.27691 .70797 Mdot
.42947 .59273 Mdot
.21252 .51481 Mdot
.44885 .57995 Mdot
.6299 .4012 Mdot
.52021 .32521 Mdot
.42352 .59211 Mdot
.43189 .59138 Mdot
.59855 .78053 Mdot
.43996 .49939 Mdot
.39009 .47083 Mdot
.61542 .65605 Mdot
.44716 .65787 Mdot
.46855 .31738 Mdot
.13554 .48923 Mdot
.78273 .66953 Mdot
.34783 .61442 Mdot
.59529 .49288 Mdot
.55528 .65511 Mdot
.65815 .3627 Mdot
.57256 .51635 Mdot
.65135 .44168 Mdot
.56358 .66607 Mdot
.4109 .54644 Mdot
.66104 .7664 Mdot
.36448 .38385 Mdot
.41741 .58876 Mdot
.6605 .40707 Mdot
.41785 .58931 Mdot
.63655 .413 Mdot
.53446 .6271 Mdot
.60182 .51472 Mdot
.41011 .52351 Mdot
.34246 .59698 Mdot
.31986 .63539 Mdot
.40712 .58084 Mdot
.58195 .30505 Mdot
.58951 .65264 Mdot
.52989 .60087 Mdot
.37127 .60792 Mdot
.51342 .77622 Mdot
.3891 .60823 Mdot
.59917 .36422 Mdot
.37767 .60017 Mdot
.28233 .53448 Mdot
.36868 .59958 Mdot
.38745 .60332 Mdot
.64794 .38237 Mdot
.67311 .36957 Mdot
.57723 .62072 Mdot
.67175 .5952 Mdot
.81239 .43501 Mdot
.38478 .56543 Mdot
.53714 .33916 Mdot
.66939 .55591 Mdot
.36339 .34919 Mdot
.56622 .66617 Mdot
.15994 .37045 Mdot
.64536 .41245 Mdot
.44686 .32119 Mdot
.53977 .27874 Mdot
.45043 .32488 Mdot
.53694 .3181 Mdot
.50237 .63125 Mdot
.34092 .358 Mdot
.37912 .60571 Mdot
.55269 .75565 Mdot
.70618 .66268 Mdot
.34742 .56623 Mdot
.48165 .37966 Mdot
.39745 .49113 Mdot
.20735 .51442 Mdot
.36015 .38818 Mdot
.33867 .34439 Mdot
.65955 .38521 Mdot
.45189 .34942 Mdot
.31931 .59786 Mdot
.38325 .35946 Mdot
.52173 .33026 Mdot
.65931 .58566 Mdot
.31425 .38427 Mdot
.57301 .65955 Mdot
.28679 .56566 Mdot
.726 .68463 Mdot
.64112 .4095 Mdot
.59206 .44279 Mdot
.59724 .70647 Mdot
.53518 .6539 Mdot
.6671 .59216 Mdot
.52537 .35494 Mdot
.60672 .63464 Mdot
.43647 .58735 Mdot
.47093 .57829 Mdot
.37254 .56699 Mdot
.37797 .34914 Mdot
.36575 .58781 Mdot
.52521 .35001 Mdot
.63943 .40201 Mdot
.47775 .32642 Mdot
.63959 .39448 Mdot
.65859 .75251 Mdot
.36576 .565 Mdot
.40123 .58145 Mdot
.56261 .43959 Mdot
.59049 .68771 Mdot
.52701 .72868 Mdot
.52579 .35574 Mdot
.46684 .34539 Mdot
.40397 .54696 Mdot
.54538 .64358 Mdot
.35013 .31919 Mdot
.57779 .48287 Mdot
.37389 .59844 Mdot
.5903 .65342 Mdot
.39587 .54455 Mdot
.54707 .22908 Mdot
.62031 .52098 Mdot
.61233 .66059 Mdot
.31141 .74598 Mdot
.44214 .55784 Mdot
.41869 .48701 Mdot
.44453 .51349 Mdot
.3437 .45498 Mdot
.35873 .53631 Mdot
.55337 .65154 Mdot
.37257 .55678 Mdot
.59029 .67138 Mdot
.50554 .32916 Mdot
.66392 .36083 Mdot
.58704 .66933 Mdot
.43294 .53431 Mdot
.76472 .69159 Mdot
.64896 .41082 Mdot
.40786 .5914 Mdot
.66504 .38294 Mdot
.62163 .65168 Mdot
.59563 .69073 Mdot
.67978 .53685 Mdot
.53987 .29775 Mdot
.65493 .41153 Mdot
.39674 .53513 Mdot
.74122 .61967 Mdot
.40061 .54495 Mdot
.36876 .41098 Mdot
.35782 .59704 Mdot
.34253 .58293 Mdot
.60454 .82246 Mdot
.57805 .38225 Mdot
.17039 .39051 Mdot
.70193 .37512 Mdot
.75816 .60509 Mdot
.52885 .66744 Mdot
.35926 .38815 Mdot
.68235 .30859 Mdot
.69798 .56781 Mdot
.474 .31096 Mdot
.4228 .59335 Mdot
.64074 .73994 Mdot
.6584 .42094 Mdot
.35423 .34738 Mdot
.41203 .52383 Mdot
.46246 .36539 Mdot
.71473 .55722 Mdot
.64765 .36167 Mdot
.57102 .66029 Mdot
.58336 .68848 Mdot
.21725 .64895 Mdot
.3786 .58651 Mdot
.39359 .57835 Mdot
.6761 .40649 Mdot
.32269 .60799 Mdot
.36922 .37944 Mdot
.59043 .22257 Mdot
.66483 .40494 Mdot
.63252 .51888 Mdot
.61421 .65174 Mdot
.40285 .57045 Mdot
.55227 .42323 Mdot
.75948 .54151 Mdot
.35906 .70729 Mdot
.36156 .33654 Mdot
.3153 .4133 Mdot
.55319 .65186 Mdot
.66124 .40436 Mdot
.22803 .52137 Mdot
.43829 .53409 Mdot
.40396 .56787 Mdot
.30093 .40385 Mdot
.57784 .48875 Mdot
.33685 .39599 Mdot
.39584 .50526 Mdot
.55298 .47647 Mdot
.40613 .54773 Mdot
.43066 .56559 Mdot
.34182 .60988 Mdot
.35796 .56648 Mdot
.59245 .65869 Mdot
.45814 .81615 Mdot
.49068 .34284 Mdot
.31824 .6841 Mdot
.41982 .42056 Mdot
.3823 .5303 Mdot
.4154 .54935 Mdot
.40654 .78683 Mdot
.64175 .57925 Mdot
.58516 .65344 Mdot
.56042 .7083 Mdot
.67576 .36743 Mdot
.44196 .50098 Mdot
.52069 .31249 Mdot
.38136 .47833 Mdot
.48845 .3299 Mdot
.59162 .65368 Mdot
.45902 .33624 Mdot
.69196 .40172 Mdot
.50369 .31474 Mdot
.51711 .31265 Mdot
.627 .37244 Mdot
.61287 .68227 Mdot
.39406 .60497 Mdot
.62931 .37377 Mdot
.27804 .36508 Mdot
.37837 .35015 Mdot
.6782 .53873 Mdot
.36263 .5226 Mdot
.41949 .48535 Mdot
.52018 .19805 Mdot
.47116 .32353 Mdot
.60238 .55503 Mdot
.55913 .67102 Mdot
.33273 .33609 Mdot
.59286 .66328 Mdot
.24151 .62406 Mdot
.36793 .36032 Mdot
.68004 .53987 Mdot
.23235 .50674 Mdot
.59896 .42908 Mdot
.45587 .5845 Mdot
.56005 .60176 Mdot
.48943 .32808 Mdot
.65435 .4237 Mdot
.80557 .45731 Mdot
.44163 .56556 Mdot
.65503 .60976 Mdot
.53683 .67231 Mdot
.6985 .57896 Mdot
.65713 .40552 Mdot
.70446 .35927 Mdot
.37545 .58248 Mdot
.58971 .42089 Mdot
.34631 .58234 Mdot
.28282 .64472 Mdot
.37909 .41155 Mdot
.64333 .63405 Mdot
.39127 .54129 Mdot
.5084 .36224 Mdot
.3948 .54236 Mdot
.29709 .57041 Mdot
.21085 .52962 Mdot
.34774 .6063 Mdot
.60892 .60084 Mdot
.51766 .21468 Mdot
.57454 .6411 Mdot
.37793 .62256 Mdot
.67544 .57931 Mdot
.42699 .54807 Mdot
.81811 .34239 Mdot
.35594 .36008 Mdot
.48144 .28983 Mdot
.43852 .54178 Mdot
.38955 .59184 Mdot
.5662 .77913 Mdot
.52709 .61398 Mdot
.70231 .58084 Mdot
.4094 .56707 Mdot
.32444 .42528 Mdot
.654 .38149 Mdot
.35294 .57479 Mdot
.37483 .55818 Mdot
.2829 .28609 Mdot
.65511 .37978 Mdot
.47346 .31986 Mdot
.70053 .57284 Mdot
.49325 .36522 Mdot
.34326 .3824 Mdot
.55636 .52383 Mdot
.25897 .37766 Mdot
.62113 .52325 Mdot
.33923 .33232 Mdot
.37523 .53272 Mdot
.59513 .72114 Mdot
.38276 .59553 Mdot
.34184 .33991 Mdot
.672 .39357 Mdot
.58988 .65974 Mdot
.28212 .59044 Mdot
.68408 .57079 Mdot
.34631 .56443 Mdot
.37006 .38796 Mdot
.58219 .6693 Mdot
.71323 .51283 Mdot
.55967 .66494 Mdot
.64366 .38928 Mdot
.68626 .37868 Mdot
.36422 .35554 Mdot
.59353 .66084 Mdot
.47718 .35844 Mdot
.70116 .36988 Mdot
.35299 .59295 Mdot
.69505 .38476 Mdot
.57707 .62451 Mdot
.56983 .69017 Mdot
.56472 .63235 Mdot
.36417 .56039 Mdot
.5839 .49199 Mdot
.45093 .56045 Mdot
.65806 .41346 Mdot
.45482 .32619 Mdot
.23147 .42928 Mdot
.54597 .75873 Mdot
.63237 .51648 Mdot
.37215 .52435 Mdot
.36533 .58236 Mdot
.37434 .56599 Mdot
.38793 .54675 Mdot
.59432 .22627 Mdot
.36626 .56438 Mdot
.63821 .38505 Mdot
.49671 .3348 Mdot
.36892 .57873 Mdot
.67388 .58195 Mdot
.48739 .43476 Mdot
.3339 .35633 Mdot
.30168 .50212 Mdot
.77862 .6401 Mdot
.58302 .66767 Mdot
.50767 .31915 Mdot
.45784 .34305 Mdot
.37881 .36779 Mdot
.63273 .37001 Mdot
.56287 .67196 Mdot
.29171 .49501 Mdot
.38223 .37687 Mdot
.38464 .55573 Mdot
.55813 .43068 Mdot
.3238 .75699 Mdot
.39081 .52235 Mdot
.4267 .57593 Mdot
.68448 .59423 Mdot
.45286 .31718 Mdot
.83026 .39585 Mdot
.70854 .45212 Mdot
.35974 .3513 Mdot
.35319 .37244 Mdot
.55956 .6379 Mdot
.35566 .5479 Mdot
.64364 .3994 Mdot
.55997 .48365 Mdot
.52414 .18846 Mdot
.82171 .49799 Mdot
.54903 .24907 Mdot
.40081 .61008 Mdot
.47166 .80231 Mdot
.38484 .61619 Mdot
.57073 .6986 Mdot
.55383 .63786 Mdot
.58017 .65537 Mdot
.64925 .38351 Mdot
.18985 .56645 Mdot
.63679 .38525 Mdot
.77978 .64181 Mdot
.58047 .63588 Mdot
.54382 .39903 Mdot
.47164 .35039 Mdot
.44567 .6182 Mdot
.3406 .35573 Mdot
.40932 .32991 Mdot
.38332 .62542 Mdot
.5315 .56932 Mdot
.48037 .31502 Mdot
.59552 .693 Mdot
.36344 .64445 Mdot
.8091 .42036 Mdot
.59935 .5004 Mdot
.44214 .19483 Mdot
.41027 .67447 Mdot
.36628 .36626 Mdot
.34246 .72445 Mdot
.36966 .38107 Mdot
.65743 .36406 Mdot
.44287 .56692 Mdot
.44555 .55652 Mdot
.41071 .55674 Mdot
.3664 .55666 Mdot
.66524 .38722 Mdot
.37189 .61117 Mdot
.22785 .40269 Mdot
.67088 .57274 Mdot
.5363 .3957 Mdot
.37204 .36923 Mdot
.6264 .39896 Mdot
.49997 .33273 Mdot
.66774 .59447 Mdot
.28886 .35185 Mdot
.38701 .61381 Mdot
.42221 .59696 Mdot
.66377 .57941 Mdot
.33009 .61738 Mdot
.42475 .63492 Mdot
.4852 .34181 Mdot
.49614 .46212 Mdot
.35953 .33003 Mdot
.33888 .36434 Mdot
.62846 .41213 Mdot
.59312 .66317 Mdot
.37854 .34569 Mdot
.45327 .35345 Mdot
.35269 .5688 Mdot
.34211 .59791 Mdot
.5778 .62431 Mdot
.19919 .53818 Mdot
.3375 .37401 Mdot
.32161 .62934 Mdot
.57523 .67993 Mdot
.54129 .68074 Mdot
.41145 .56858 Mdot
.42482 .51093 Mdot
.56853 .69439 Mdot
.36516 .37538 Mdot
.62492 .39667 Mdot
.55882 .40192 Mdot
.63224 .39093 Mdot
.57609 .67612 Mdot
.4461 .61017 Mdot
.61756 .66888 Mdot
.43964 .55461 Mdot
.10948 .54133 Mdot
.361 .57837 Mdot
.50558 .59378 Mdot
.37305 .43252 Mdot
.48808 .35888 Mdot
.49461 .36111 Mdot
.67497 .58412 Mdot
.55508 .66758 Mdot
.40877 .62096 Mdot
.34266 .36459 Mdot
.75569 .60757 Mdot
.64086 .65014 Mdot
.52423 .32033 Mdot
.47868 .30607 Mdot
.67096 .39312 Mdot
.38015 .60518 Mdot
.39686 .57025 Mdot
.49711 .31391 Mdot
.57051 .19654 Mdot
.59641 .66877 Mdot
.39352 .57857 Mdot
.35922 .56862 Mdot
.49312 .34115 Mdot
.70693 .37041 Mdot
.551 .69608 Mdot
.35841 .56885 Mdot
.23526 .48877 Mdot
.63993 .41389 Mdot
.39313 .53154 Mdot
.38018 .61429 Mdot
.36423 .34547 Mdot
.3151 .32255 Mdot
.20913 .52141 Mdot
.63672 .3619 Mdot
.68533 .59214 Mdot
.44664 .57406 Mdot
.47817 .35284 Mdot
.35676 .52994 Mdot
.71551 .29957 Mdot
.68121 .56778 Mdot
.37858 .57863 Mdot
.35945 .62679 Mdot
.59091 .68366 Mdot
.38261 .58295 Mdot
.65746 .66156 Mdot
.51159 .3552 Mdot
.37757 .57856 Mdot
.5443 .77264 Mdot
.67082 .39563 Mdot
.38667 .6265 Mdot
.33615 .35503 Mdot
.383 .42548 Mdot
.70438 .73082 Mdot
.53978 .33835 Mdot
.37696 .36219 Mdot
.36647 .58957 Mdot
.50193 .36791 Mdot
.61928 .3934 Mdot
.54613 .58647 Mdot
.36835 .53719 Mdot
.63208 .39511 Mdot
.64258 .40528 Mdot
.36029 .35532 Mdot
.14931 .41487 Mdot
.35723 .62566 Mdot
.41184 .58707 Mdot
.48862 .17326 Mdot
.61699 .69253 Mdot
.41178 .59224 Mdot
.38215 .60531 Mdot
.63456 .37501 Mdot
.24264 .57387 Mdot
.43389 .47313 Mdot
.58766 .21147 Mdot
.63544 .4113 Mdot
.43202 .33915 Mdot
.51772 .34723 Mdot
.37521 .36403 Mdot
.571 .64448 Mdot
.34982 .32823 Mdot
.49697 .34987 Mdot
.41913 .56442 Mdot
.66533 .37232 Mdot
.42833 .69477 Mdot
.64548 .42484 Mdot
.47361 .36917 Mdot
.55272 .68809 Mdot
.73844 .68893 Mdot
.58384 .1605 Mdot
.71413 .69601 Mdot
.63974 .35864 Mdot
.36339 .34891 Mdot
.68824 .46578 Mdot
.36758 .58516 Mdot
.31089 .72076 Mdot
.41502 .58868 Mdot
.34312 .67486 Mdot
.52113 .32703 Mdot
.66269 .58899 Mdot
.44157 .56664 Mdot
.32016 .41733 Mdot
.63059 .36829 Mdot
.66813 .40842 Mdot
.38374 .55082 Mdot
.64277 .391 Mdot
.39249 .5725 Mdot
.49856 .33852 Mdot
.15296 .41491 Mdot
.38124 .59997 Mdot
.40631 .62476 Mdot
.67667 .43229 Mdot
.67821 .53951 Mdot
.44528 .3585 Mdot
.48518 .8049 Mdot
.81168 .41422 Mdot
.64553 .39457 Mdot
.48626 .59618 Mdot
.48437 .31811 Mdot
.67636 .59726 Mdot
.50073 .30031 Mdot
.41589 .58034 Mdot
.40887 .60852 Mdot
.40709 .55121 Mdot
.36618 .58194 Mdot
.32662 .72919 Mdot
.4273 .6315 Mdot
.43976 .75405 Mdot
.42444 .59517 Mdot
.50377 .5968 Mdot
.64026 .38074 Mdot
.41057 .48365 Mdot
.33138 .39138 Mdot
.40415 .61102 Mdot
.52357 .61427 Mdot
.62682 .39425 Mdot
.77728 .61361 Mdot
.66122 .38298 Mdot
.4706 .32997 Mdot
.67701 .37526 Mdot
.44021 .55255 Mdot
.56999 .65443 Mdot
.51174 .34219 Mdot
.6667 .71212 Mdot
.4771 .31197 Mdot
.37631 .58615 Mdot
.68384 .43711 Mdot
.48096 .35776 Mdot
.34748 .46904 Mdot
.56854 .65322 Mdot
.30687 .42556 Mdot
.61084 .69814 Mdot
.3886 .58515 Mdot
.3959 .58897 Mdot
.66446 .59461 Mdot
.64611 .36181 Mdot
.59808 .63326 Mdot
.24754 .31826 Mdot
.37454 .38924 Mdot
.5829 .64722 Mdot
.45669 .53129 Mdot
.59412 .48861 Mdot
.60572 .67539 Mdot
.34254 .44128 Mdot
.63878 .36612 Mdot
.5673 .63799 Mdot
.45646 .55874 Mdot
.30147 .63803 Mdot
.35257 .38025 Mdot
.51107 .36594 Mdot
.55411 .46092 Mdot
.51647 .34997 Mdot
.66831 .42434 Mdot
.51122 .30656 Mdot
.64794 .37933 Mdot
.64871 .6232 Mdot
.48596 .47766 Mdot
.67768 .41766 Mdot
.68773 .4187 Mdot
.48808 .34927 Mdot
.38917 .54857 Mdot
.49515 .42196 Mdot
.43995 .51894 Mdot
.42509 .62494 Mdot
.63516 .40783 Mdot
.55469 .64717 Mdot
.61614 .65187 Mdot
.51417 .61023 Mdot
.59724 .68795 Mdot
.50991 .33637 Mdot
.61499 .52965 Mdot
.28475 .66026 Mdot
.67392 .39305 Mdot
.55336 .31714 Mdot
.40206 .54375 Mdot
.48604 .35312 Mdot
.50918 .32959 Mdot
.63827 .39756 Mdot
.33171 .69856 Mdot
.39893 .62982 Mdot
.61518 .6892 Mdot
.58518 .63462 Mdot
.60859 .67077 Mdot
.54773 .64238 Mdot
.19562 .59108 Mdot
.65403 .42378 Mdot
.55353 .65542 Mdot
.37293 .54961 Mdot
.41396 .60248 Mdot
.69568 .58012 Mdot
.36282 .37429 Mdot
.44618 .58884 Mdot
.43639 .60839 Mdot
.41077 .56917 Mdot
.48597 .35812 Mdot
.32246 .54914 Mdot
.68414 .56794 Mdot
.49917 .30463 Mdot
.52183 .31415 Mdot
.67468 .5916 Mdot
.64354 .68099 Mdot
.8353 .45316 Mdot
.41343 .557 Mdot
.53067 .69223 Mdot
.47806 .35093 Mdot
.54106 .54226 Mdot
.38614 .65517 Mdot
.39309 .53587 Mdot
.50682 .40327 Mdot
.50374 .3384 Mdot
.54146 .63451 Mdot
.4118 .58153 Mdot
.66672 .58711 Mdot
.33943 .36864 Mdot
.45041 .53155 Mdot
.68364 .59479 Mdot
.59404 .65385 Mdot
.48374 .22135 Mdot
.62601 .67106 Mdot
.48106 .35873 Mdot
.38058 .62369 Mdot
.29357 .82776 Mdot
.48993 .32711 Mdot
.77411 .57694 Mdot
.47704 .47117 Mdot
.37523 .595 Mdot
.5157 .33924 Mdot
.53733 .64294 Mdot
.63998 .4136 Mdot
.56241 .44728 Mdot
.56634 .64442 Mdot
.66693 .59361 Mdot
.6881 .58843 Mdot
.49069 .34201 Mdot
.60006 .63989 Mdot
.36208 .60284 Mdot
.57364 .68329 Mdot
.67798 .3857 Mdot
.42395 .53593 Mdot
.81262 .4343 Mdot
.47135 .57997 Mdot
.57089 .67966 Mdot
.44999 .35058 Mdot
.38504 .35174 Mdot
.40442 .52337 Mdot
.81272 .55126 Mdot
.37606 .60252 Mdot
.66853 .38635 Mdot
.5143 .5231 Mdot
.42367 .7007 Mdot
.40005 .55502 Mdot
.40932 .54682 Mdot
.6231 .40371 Mdot
.40544 .55714 Mdot
.35782 .55336 Mdot
.65983 .3442 Mdot
.60073 .68074 Mdot
.37643 .572 Mdot
.52153 .34238 Mdot
.50174 .67353 Mdot
.44152 .57505 Mdot
.66461 .65633 Mdot
.3099 .41821 Mdot
.49984 .50265 Mdot
.40209 .62188 Mdot
.27474 .35335 Mdot
.39996 .58817 Mdot
.37592 .53866 Mdot
.40092 .55042 Mdot
.46152 .80369 Mdot
.49304 .35078 Mdot
.52797 .33553 Mdot
.33866 .36992 Mdot
.32097 .42154 Mdot
.37185 .3481 Mdot
.62326 .39302 Mdot
.55086 .30235 Mdot
.66987 .57435 Mdot
.5925 .66597 Mdot
.43789 .58121 Mdot
.48561 .30958 Mdot
.40655 .57225 Mdot
.42447 .54574 Mdot
.50563 .34403 Mdot
.50733 .33187 Mdot
.53786 .32736 Mdot
.37401 .38199 Mdot
.58473 .65945 Mdot
.43012 .57546 Mdot
.38388 .37312 Mdot
.36565 .60204 Mdot
.60342 .48308 Mdot
.58429 .65695 Mdot
.57535 .68381 Mdot
.62129 .66032 Mdot
.42828 .59487 Mdot
.43373 .54124 Mdot
.63628 .38578 Mdot
.58463 .62412 Mdot
.67369 .40656 Mdot
.51578 .34118 Mdot
.4982 .35971 Mdot
.4164 .58068 Mdot
.32376 .6296 Mdot
.36356 .37186 Mdot
.46848 .32796 Mdot
.69528 .56472 Mdot
.337 .36741 Mdot
.36637 .57403 Mdot
.51604 .34642 Mdot
.33453 .35467 Mdot
.37024 .68921 Mdot
.79571 .38696 Mdot
.38446 .37661 Mdot
.38275 .55101 Mdot
.56586 .77407 Mdot
.22608 .50219 Mdot
.37997 .3865 Mdot
.65891 .37729 Mdot
.39682 .60661 Mdot
.5963 .19109 Mdot
.36191 .32966 Mdot
.2008 .5377 Mdot
.50498 .34831 Mdot
.37605 .66886 Mdot
.45323 .53566 Mdot
.29485 .69844 Mdot
.36096 .32824 Mdot
.56798 .67403 Mdot
.57725 .63062 Mdot
.38815 .55458 Mdot
.35848 .39754 Mdot
.66346 .4244 Mdot
.45769 .34314 Mdot
.51574 .31348 Mdot
.60654 .64448 Mdot
.62703 .52184 Mdot
.52048 .34353 Mdot
.33793 .59791 Mdot
.4539 .30214 Mdot
.44705 .50636 Mdot
.21646 .64079 Mdot
.65641 .74428 Mdot
.38196 .61896 Mdot
.38732 .35571 Mdot
.6258 .37365 Mdot
.63857 .38969 Mdot
.64865 .38552 Mdot
.50309 .36028 Mdot
.57191 .50216 Mdot
.51837 .3187 Mdot
.69502 .61606 Mdot
.35971 .36555 Mdot
.29641 .44623 Mdot
.43199 .60736 Mdot
.37527 .59426 Mdot
.35239 .56463 Mdot
.40938 .55205 Mdot
.3995 .58674 Mdot
.63952 .40809 Mdot
.4679 .35548 Mdot
.53435 .21375 Mdot
.60773 .6566 Mdot
.70487 .50574 Mdot
.47026 .34963 Mdot
.69871 .58206 Mdot
.34888 .3491 Mdot
.26097 .3836 Mdot
.45684 .29251 Mdot
.46005 .33833 Mdot
.37834 .52812 Mdot
.55158 .64656 Mdot
.26933 .62324 Mdot
.40114 .59653 Mdot
.46864 .32651 Mdot
.44527 .32079 Mdot
.34798 .71894 Mdot
.35689 .52342 Mdot
.4167 .35295 Mdot
.59294 .49072 Mdot
.38498 .34268 Mdot
.37574 .51961 Mdot
.54825 .54538 Mdot
.49506 .3484 Mdot
.47419 .33369 Mdot
.381 .38331 Mdot
.36316 .49466 Mdot
.58395 .63871 Mdot
.66173 .58722 Mdot
.65273 .37478 Mdot
.39274 .59895 Mdot
.5064 .35928 Mdot
.53868 .69692 Mdot
.56369 .42915 Mdot
.66451 .39365 Mdot
.48914 .30437 Mdot
.3927 .60854 Mdot
.39425 .55518 Mdot
.36857 .36291 Mdot
.34813 .25665 Mdot
.44275 .52177 Mdot
.75814 .60459 Mdot
.58757 .52564 Mdot
.43676 .44612 Mdot
.40334 .56786 Mdot
.6154 .6692 Mdot
.67266 .58874 Mdot
.34242 .34667 Mdot
.37056 .60431 Mdot
.82872 .42598 Mdot
.62743 .64553 Mdot
.65121 .4099 Mdot
.67006 .58916 Mdot
.56357 .49843 Mdot
.3733 .60028 Mdot
.41498 .58829 Mdot
.36502 .55936 Mdot
.83066 .42177 Mdot
.52433 .332 Mdot
.56575 .62918 Mdot
.3652 .33792 Mdot
.57673 .68649 Mdot
.53199 .33268 Mdot
.42791 .44036 Mdot
.36272 .56846 Mdot
.61771 .68318 Mdot
.5637 .67007 Mdot
.67156 .39578 Mdot
.62826 .37507 Mdot
.52509 .36275 Mdot
.36673 .58743 Mdot
.66536 .5798 Mdot
.56199 .64268 Mdot
.45768 .34975 Mdot
.36767 .36273 Mdot
.67023 .35813 Mdot
.42553 .59483 Mdot
.49068 .34472 Mdot
.36103 .6099 Mdot
.59323 .67913 Mdot
.46198 .3418 Mdot
.69544 .58798 Mdot
.35963 .37382 Mdot
.41708 .60382 Mdot
.50805 .20899 Mdot
.66755 .5902 Mdot
.42812 .52904 Mdot
.60893 .74487 Mdot
.3336 .38683 Mdot
.66269 .72238 Mdot
.51551 .32175 Mdot
.6717 .57631 Mdot
.5568 .63436 Mdot
.29986 .6412 Mdot
.47978 .33328 Mdot
.60434 .76707 Mdot
.52936 .40704 Mdot
.42157 .5643 Mdot
.58547 .64308 Mdot
.39708 .35879 Mdot
.76801 .5984 Mdot
.23463 .46598 Mdot
.38719 .57542 Mdot
.51658 .35061 Mdot
.3384 .3641 Mdot
.67275 .40581 Mdot
.66365 .64615 Mdot
.23733 .66267 Mdot
.49851 .30517 Mdot
.43399 .58309 Mdot
.55926 .643 Mdot
.64207 .4013 Mdot
.65534 .76826 Mdot
.4565 .35798 Mdot
.51871 .33074 Mdot
.36686 .54805 Mdot
.36128 .33582 Mdot
.60422 .20012 Mdot
.52677 .33707 Mdot
.49035 .36475 Mdot
.68144 .51913 Mdot
.35327 .38418 Mdot
.37413 .55146 Mdot
.51464 .60983 Mdot
.35405 .57444 Mdot
.74121 .57297 Mdot
.66966 .57732 Mdot
.6073 .65887 Mdot
.41811 .59354 Mdot
.5194 .21511 Mdot
.49031 .33109 Mdot
.59367 .49477 Mdot
.71673 .36121 Mdot
.63041 .37284 Mdot
.50921 .35583 Mdot
.40662 .5768 Mdot
.6888 .38266 Mdot
.36724 .36964 Mdot
.35839 .5691 Mdot
.43749 .54848 Mdot
.53373 .65235 Mdot
.67065 .37743 Mdot
.50888 .67726 Mdot
.68116 .38711 Mdot
.62978 .41438 Mdot
.54172 .68191 Mdot
.38687 .55509 Mdot
.46461 .33312 Mdot
.47807 .37186 Mdot
.36343 .60707 Mdot
.54091 .54072 Mdot
.58396 .63974 Mdot
.5343 .30966 Mdot
.82109 .38744 Mdot
.34845 .61707 Mdot
.70064 .56669 Mdot
.39166 .67252 Mdot
.65133 .41897 Mdot
.41842 .56543 Mdot
.5911 .67277 Mdot
.47497 .36169 Mdot
.51979 .35215 Mdot
.41744 .5162 Mdot
.63747 .39854 Mdot
.33319 .33965 Mdot
.50845 .32575 Mdot
.56832 .42947 Mdot
.37784 .58094 Mdot
.6597 .61057 Mdot
.5053 .32207 Mdot
.73743 .71912 Mdot
.5247 .21485 Mdot
.61013 .65438 Mdot
.41369 .54108 Mdot
.55121 .67277 Mdot
.36871 .3402 Mdot
.50323 .30197 Mdot
.63436 .39468 Mdot
.28952 .56068 Mdot
.28054 .27906 Mdot
.49066 .35432 Mdot
.5919 .65728 Mdot
.43063 .5833 Mdot
.36354 .64832 Mdot
.37666 .59988 Mdot
.24666 .56466 Mdot
.39701 .38046 Mdot
.69174 .40694 Mdot
.66788 .41103 Mdot
.42004 .5522 Mdot
.37376 .37872 Mdot
.50211 .37241 Mdot
.50429 .34533 Mdot
.13002 .47406 Mdot
.68505 .59462 Mdot
.4085 .37196 Mdot
.42704 .5954 Mdot
.45417 .34325 Mdot
.54209 .75581 Mdot
.67629 .40585 Mdot
.35133 .58089 Mdot
.45593 .31779 Mdot
.75106 .5325 Mdot
.59151 .48527 Mdot
.38096 .57785 Mdot
.32142 .60644 Mdot
.66028 .38021 Mdot
.68955 .46538 Mdot
.50962 .31562 Mdot
.3581 .5919 Mdot
.60801 .38719 Mdot
.6618 .54297 Mdot
.2603 .3109 Mdot
.58433 .65929 Mdot
.44488 .3396 Mdot
.62814 .38436 Mdot
.32012 .56441 Mdot
.36887 .37243 Mdot
.48229 .3671 Mdot
.46079 .3166 Mdot
.42036 .53696 Mdot
.44424 .59018 Mdot
.32616 .56935 Mdot
.59194 .64678 Mdot
.63815 .37285 Mdot
.43204 .55984 Mdot
.62326 .5045 Mdot
.41897 .55882 Mdot
.63476 .37718 Mdot
.1744 .69888 Mdot
.41352 .51742 Mdot
.40584 .59946 Mdot
.34554 .46059 Mdot
.60577 .63887 Mdot
.59373 .68522 Mdot
.6112 .5164 Mdot
.42621 .59643 Mdot
.57007 .38294 Mdot
.5861 .66185 Mdot
.57992 .64194 Mdot
.56433 .38677 Mdot
.41756 .53113 Mdot
.62438 .42722 Mdot
.64111 .39829 Mdot
.62952 .37396 Mdot
.58899 .68362 Mdot
.45147 .6138 Mdot
.61989 .38832 Mdot
.33712 .73942 Mdot
.46196 .34406 Mdot
.5486 .54572 Mdot
.57165 .6819 Mdot
.54429 .41957 Mdot
.64752 .36216 Mdot
.74741 .7337 Mdot
.27172 .59206 Mdot
.34738 .59266 Mdot
.39401 .55372 Mdot
.36777 .34884 Mdot
.44896 .63636 Mdot
.68839 .59041 Mdot
.64227 .38878 Mdot
.59806 .2339 Mdot
.57966 .65492 Mdot
.39789 .60326 Mdot
.23529 .41734 Mdot
.67195 .74353 Mdot
.54038 .59449 Mdot
.56858 .64517 Mdot
.57563 .65203 Mdot
.47986 .31451 Mdot
.46058 .34485 Mdot
.36914 .56059 Mdot
.64506 .38284 Mdot
.57728 .63321 Mdot
.65253 .3679 Mdot
.49684 .34897 Mdot
.46364 .34185 Mdot
.69187 .56735 Mdot
.40258 .63753 Mdot
.50367 .35492 Mdot
.69238 .52411 Mdot
.62172 .50232 Mdot
.54069 .64026 Mdot
.56661 .15982 Mdot
.64919 .77594 Mdot
.33931 .46473 Mdot
.33993 .36968 Mdot
.66204 .56596 Mdot
.65956 .3624 Mdot
.41798 .55164 Mdot
.42197 .58137 Mdot
.69252 .57808 Mdot
.64374 .36003 Mdot
.35341 .34381 Mdot
.64999 .36146 Mdot
.34282 .35524 Mdot
.52911 .34464 Mdot
.44249 .57545 Mdot
.36321 .58761 Mdot
.65897 .41074 Mdot
.4762 .31803 Mdot
.48288 .35881 Mdot
.35424 .37889 Mdot
.26603 .38905 Mdot
.49238 .34273 Mdot
.57164 .68206 Mdot
.49398 .68546 Mdot
.68958 .58684 Mdot
.41099 .58164 Mdot
.25075 .39095 Mdot
.33095 .71683 Mdot
.42542 .56677 Mdot
.66911 .58936 Mdot
.13034 .44554 Mdot
.44324 .56962 Mdot
.15634 .55346 Mdot
.6834 .5689 Mdot
.61815 .66629 Mdot
.49155 .31755 Mdot
.67607 .59605 Mdot
.32024 .5551 Mdot
.36975 .40372 Mdot
.36189 .61542 Mdot
.57786 .63757 Mdot
.6134 .6848 Mdot
.49057 .47366 Mdot
.74128 .5697 Mdot
.35725 .33319 Mdot
.35312 .35195 Mdot
.48215 .33468 Mdot
.59519 .37383 Mdot
.34093 .56786 Mdot
.355 .34967 Mdot
.6409 .24097 Mdot
.39992 .54269 Mdot
.36099 .41528 Mdot
.50698 .40877 Mdot
.61546 .66193 Mdot
.40324 .48076 Mdot
.48544 .33219 Mdot
.59132 .65715 Mdot
.49268 .44069 Mdot
.3525 .57016 Mdot
.58271 .65577 Mdot
.63786 .37088 Mdot
.66919 .33131 Mdot
.59135 .69004 Mdot
.56263 .44421 Mdot
.64535 .40014 Mdot
.33395 .38893 Mdot
.26377 .48254 Mdot
.8626 .40102 Mdot
.64202 .38656 Mdot
.47808 .32047 Mdot
.49945 .3582 Mdot
.495 .33983 Mdot
.569 .64242 Mdot
.5035 .32883 Mdot
.60202 .65265 Mdot
.69375 .41877 Mdot
.272 .36411 Mdot
.36521 .35837 Mdot
.51331 .28952 Mdot
.56931 .6682 Mdot
.70528 .61372 Mdot
.49697 .15823 Mdot
.37941 .54885 Mdot
.67298 .42022 Mdot
.38943 .36236 Mdot
.61423 .55707 Mdot
.36497 .34533 Mdot
.4862 .31751 Mdot
.54993 .54677 Mdot
.39099 .57207 Mdot
.63779 .73987 Mdot
.33761 .35663 Mdot
.5675 .6447 Mdot
.37939 .53138 Mdot
.50775 .37541 Mdot
.37702 .3571 Mdot
.34315 .37195 Mdot
.40171 .5861 Mdot
.60276 .69059 Mdot
.46215 .33587 Mdot
.67027 .36679 Mdot
.39052 .37912 Mdot
.3258 .61931 Mdot
.39381 .55054 Mdot
.39173 .51867 Mdot
.59197 .50531 Mdot
.60678 .19597 Mdot
.64728 .3961 Mdot
.2225 .50048 Mdot
.49191 .35717 Mdot
.23479 .47374 Mdot
.72546 .64501 Mdot
.46017 .28761 Mdot
.67107 .5753 Mdot
.66859 .57833 Mdot
.38702 .58037 Mdot
.64209 .2125 Mdot
.5139 .59209 Mdot
.6179 .41087 Mdot
.6864 .58711 Mdot
.48142 .35844 Mdot
.6024 .62496 Mdot
.37505 .47946 Mdot
.45079 .58907 Mdot
.63808 .36166 Mdot
.49852 .34521 Mdot
.7154 .29874 Mdot
.35934 .36414 Mdot
.60127 .54827 Mdot
.36766 .57805 Mdot
.3975 .57968 Mdot
.65831 .40093 Mdot
.63671 .38735 Mdot
.67428 .61536 Mdot
.51765 .49066 Mdot
.81108 .45499 Mdot
.65209 .43223 Mdot
.71099 .28856 Mdot
.51785 .63626 Mdot
.58247 .67958 Mdot
.70111 .57015 Mdot
.6211 .39517 Mdot
.41292 .59334 Mdot
.61833 .66201 Mdot
.5283 .59366 Mdot
.53146 .64431 Mdot
.36431 .41703 Mdot
.56039 .40374 Mdot
.36599 .5788 Mdot
.54978 .64604 Mdot
.58928 .65623 Mdot
.54703 .65996 Mdot
.67614 .59089 Mdot
.40572 .56669 Mdot
.38753 .54756 Mdot
.4431 .56628 Mdot
.36344 .64733 Mdot
.38199 .58316 Mdot
.73061 .63956 Mdot
.63714 .51022 Mdot
.37337 .28009 Mdot
.43299 .59018 Mdot
.6296 .37979 Mdot
.43795 .58398 Mdot
.37381 .3768 Mdot
.43317 .59426 Mdot
.35467 .41169 Mdot
.65323 .38934 Mdot
.32728 .52301 Mdot
.55078 .33459 Mdot
.36398 .57296 Mdot
.33785 .33346 Mdot
.61202 .19745 Mdot
.22681 .43993 Mdot
.68335 .52 Mdot
.57255 .68238 Mdot
.53087 .35556 Mdot
.67155 .41774 Mdot
.4656 .33449 Mdot
.35077 .58839 Mdot
.69117 .56548 Mdot
.5706 .83443 Mdot
.52738 .42584 Mdot
.41409 .59414 Mdot
.40371 .63976 Mdot
.61271 .67207 Mdot
.49279 .32975 Mdot
.5269 .64003 Mdot
.3683 .54803 Mdot
.3775 .34585 Mdot
.3851 .3603 Mdot
.45774 .44875 Mdot
.67515 .29359 Mdot
.27517 .62173 Mdot
.65634 .39951 Mdot
.51808 .35688 Mdot
.35873 .32758 Mdot
.57559 .59964 Mdot
.65872 .42539 Mdot
.6519 .41881 Mdot
.66892 .37611 Mdot
.37619 .59011 Mdot
.69649 .57053 Mdot
.65379 .26663 Mdot
.66991 .59476 Mdot
.36173 .55598 Mdot
.46567 .31422 Mdot
.67318 .5969 Mdot
.37043 .34893 Mdot
.63105 .4144 Mdot
.48095 .35591 Mdot
.39241 .58815 Mdot
.5821 .66566 Mdot
.2192 .47993 Mdot
.41323 .19652 Mdot
.51499 .29472 Mdot
.51966 .29593 Mdot
.62369 .66282 Mdot
.81343 .5682 Mdot
.69343 .37438 Mdot
.32998 .70024 Mdot
.39754 .34733 Mdot
.36122 .6058 Mdot
.16565 .42835 Mdot
.51755 .31887 Mdot
.51194 .34013 Mdot
.37596 .57541 Mdot
.45595 .35347 Mdot
.38938 .60449 Mdot
.50269 .31268 Mdot
.77716 .54888 Mdot
.45492 .5829 Mdot
.5104 .33772 Mdot
.34673 .55201 Mdot
.40559 .5222 Mdot
.61269 .67561 Mdot
.47852 .36564 Mdot
.34688 .59363 Mdot
.52672 .85764 Mdot
.66975 .40096 Mdot
.67753 .5913 Mdot
.53319 .29356 Mdot
.67322 .37301 Mdot
.59629 .64366 Mdot
.44506 .57764 Mdot
.36667 .3682 Mdot
.57473 .67426 Mdot
.52216 .37056 Mdot
.33706 .34769 Mdot
.61632 .52813 Mdot
.58461 .6821 Mdot
.69464 .579 Mdot
.35684 .37296 Mdot
.36187 .61577 Mdot
.50978 .34365 Mdot
.4929 .19377 Mdot
.67236 .5944 Mdot
.39729 .57113 Mdot
.44389 .34738 Mdot
.65136 .36177 Mdot
.37362 .56094 Mdot
.51373 .35811 Mdot
.67259 .59081 Mdot
.42707 .52915 Mdot
.42538 .52625 Mdot
.35227 .49144 Mdot
.51157 .53517 Mdot
.36865 .35809 Mdot
.54651 .68648 Mdot
.37096 .55063 Mdot
.37169 .38003 Mdot
.55375 .26131 Mdot
.41528 .61613 Mdot
.56521 .68518 Mdot
.2937 .59228 Mdot
.45651 .3387 Mdot
.67236 .40862 Mdot
.47088 .36842 Mdot
.33577 .36298 Mdot
.29613 .23014 Mdot
.69924 .57732 Mdot
.38564 .6417 Mdot
.3524 .56177 Mdot
.48608 .30273 Mdot
.58767 .65302 Mdot
.81316 .47741 Mdot
.42159 .6006 Mdot
.46237 .59517 Mdot
.40738 .58448 Mdot
.51544 .22006 Mdot
.58108 .64028 Mdot
.41015 .58346 Mdot
.33304 .6327 Mdot
.34201 .60014 Mdot
.34035 .32961 Mdot
.29285 .45778 Mdot
.43582 .57537 Mdot
.38582 .89182 Mdot
.66539 .5764 Mdot
.50422 .34227 Mdot
.57823 .46702 Mdot
.49945 .24676 Mdot
.19931 .61956 Mdot
.59738 .64867 Mdot
.48464 .63855 Mdot
.46365 .33569 Mdot
.20953 .46645 Mdot
.79758 .59644 Mdot
.39881 .52302 Mdot
.39889 .60761 Mdot
.48613 .31754 Mdot
.45927 .35047 Mdot
.67557 .56853 Mdot
.40669 .61256 Mdot
.46113 .59806 Mdot
.44856 .33841 Mdot
.39025 .59216 Mdot
.39909 .76601 Mdot
.68762 .39309 Mdot
.59207 .68418 Mdot
.67301 .4052 Mdot
.65232 .41739 Mdot
.29142 .67143 Mdot
.58649 .52654 Mdot
.6345 .3809 Mdot
.6226 .36494 Mdot
.31723 .39485 Mdot
.2914 .54064 Mdot
.34705 .32869 Mdot
.697 .31897 Mdot
.48654 .33769 Mdot
.40769 .56644 Mdot
.56001 .64747 Mdot
.26398 .67589 Mdot
.76577 .39884 Mdot
.56348 .55468 Mdot
.38227 .54604 Mdot
.49179 .33319 Mdot
.67099 .59223 Mdot
.45392 .5863 Mdot
.23122 .49202 Mdot
.39141 .57687 Mdot
.4613 .34769 Mdot
.28586 .66578 Mdot
.65408 .65324 Mdot
.65085 .43158 Mdot
.58845 .61749 Mdot
.43963 .58053 Mdot
.59899 .67104 Mdot
.63018 .39005 Mdot
.37399 .38139 Mdot
.36248 .34968 Mdot
.36288 .57796 Mdot
.48716 .47827 Mdot
.29811 .33862 Mdot
.39946 .5234 Mdot
.42118 .53605 Mdot
.67477 .5731 Mdot
.42223 .5363 Mdot
.35839 .58856 Mdot
.43058 .56173 Mdot
.40243 .61583 Mdot
.62557 .40997 Mdot
.62502 .73578 Mdot
.43425 .59811 Mdot
.34436 .61496 Mdot
.67587 .36651 Mdot
.38399 .49999 Mdot
.6588 .38223 Mdot
.78743 .40025 Mdot
.64874 .37558 Mdot
.36311 .35144 Mdot
.45672 .36516 Mdot
.49677 .63853 Mdot
.57918 .63289 Mdot
.62667 .38368 Mdot
.34753 .35945 Mdot
.64462 .3861 Mdot
.52439 .34668 Mdot
.52857 .16872 Mdot
.57698 .70185 Mdot
.60634 .481 Mdot
.3038 .49607 Mdot
.66188 .61094 Mdot
.45633 .33219 Mdot
.60551 .64413 Mdot
.65638 .65737 Mdot
.42348 .55376 Mdot
.37087 .36439 Mdot
.38836 .58025 Mdot
.63763 .4191 Mdot
.4906 .33521 Mdot
.69141 .42869 Mdot
.36906 .35689 Mdot
.34769 .2056 Mdot
.48569 .31016 Mdot
.36383 .63624 Mdot
.68216 .37333 Mdot
.54187 .16031 Mdot
.65308 .37793 Mdot
.27001 .36675 Mdot
.6143 .70774 Mdot
.24995 .63846 Mdot
.57127 .65786 Mdot
.65775 .61714 Mdot
.84758 .54764 Mdot
.79195 .58223 Mdot
.58217 .67433 Mdot
.55095 .33187 Mdot
.37944 .58724 Mdot
.41496 .55488 Mdot
.33639 .5989 Mdot
.55074 .62428 Mdot
.36679 .55744 Mdot
.69132 .58765 Mdot
.59422 .51479 Mdot
.60946 .21545 Mdot
.52283 .36303 Mdot
.38508 .60419 Mdot
.63645 .40868 Mdot
.63918 .42217 Mdot
.66972 .59667 Mdot
.67628 .38004 Mdot
.41279 .52456 Mdot
.56928 .66555 Mdot
.49358 .42492 Mdot
.37127 .34365 Mdot
.7464 .61146 Mdot
.38577 .33788 Mdot
.43493 .31555 Mdot
.34523 .61227 Mdot
.46308 .3416 Mdot
.2198 .33446 Mdot
.41297 .55023 Mdot
.5883 .66196 Mdot
.36466 .5472 Mdot
.43413 .56581 Mdot
.43454 .57894 Mdot
.51454 .35868 Mdot
.58176 .46906 Mdot
.39302 .5934 Mdot
.6315 .38337 Mdot
.55643 .39208 Mdot
.4455 .59417 Mdot
.60949 .24723 Mdot
.3691 .41938 Mdot
.65924 .60982 Mdot
.54384 .63775 Mdot
.47865 .3243 Mdot
.5774 .65459 Mdot
.61411 .61959 Mdot
.59665 .64375 Mdot
.61966 .24318 Mdot
.30491 .65439 Mdot
.16254 .58056 Mdot
.52225 .75147 Mdot
.29012 .68633 Mdot
.6184 .68491 Mdot
.58716 .2793 Mdot
.58732 .67596 Mdot
.59748 .64611 Mdot
.12401 .58978 Mdot
.55765 .67095 Mdot
.41637 .57942 Mdot
.44428 .54854 Mdot
.70599 .71577 Mdot
.31827 .39788 Mdot
.43347 .59145 Mdot
.36779 .55811 Mdot
.37906 .34372 Mdot
.30827 .61156 Mdot
.65571 .59059 Mdot
.59539 .53827 Mdot
.70012 .56019 Mdot
.40057 .58594 Mdot
.37015 .57101 Mdot
.41103 .51348 Mdot
.8505 .55552 Mdot
.2489 .66722 Mdot
.61994 .67062 Mdot
.34786 .51709 Mdot
.69957 .54486 Mdot
.35771 .55216 Mdot
.35804 .55462 Mdot
.44078 .55527 Mdot
.46411 .33385 Mdot
.60604 .6273 Mdot
.46059 .56234 Mdot
.69722 .66903 Mdot
.36763 .57652 Mdot
.42212 .32905 Mdot
.33189 .32054 Mdot
.40792 .57671 Mdot
.56535 .68347 Mdot
.39784 .54618 Mdot
.54999 .661 Mdot
.59312 .68259 Mdot
.40818 .63647 Mdot
.66089 .27433 Mdot
.60163 .62258 Mdot
.39997 .52174 Mdot
.47184 .32093 Mdot
.76626 .594 Mdot
.40011 .5719 Mdot
.35548 .33427 Mdot
.41837 .56474 Mdot
.33533 .33517 Mdot
.43171 .54242 Mdot
.66813 .59392 Mdot
.41346 .70706 Mdot
.47555 .33453 Mdot
.39225 .37551 Mdot
.45303 .34448 Mdot
.37103 .46784 Mdot
.58378 .69647 Mdot
.655 .58706 Mdot
.24434 .67948 Mdot
.67705 .57177 Mdot
.21448 .51055 Mdot
.59157 .36382 Mdot
.65587 .41452 Mdot
.54867 .64067 Mdot
.28309 .64756 Mdot
.63957 .27937 Mdot
.52943 .31823 Mdot
.52279 .31444 Mdot
.23234 .33335 Mdot
.15117 .41755 Mdot
.39683 .59637 Mdot
.58796 .18344 Mdot
.44007 .74209 Mdot
.33566 .5798 Mdot
.40187 .50676 Mdot
.45547 .321 Mdot
.44039 .58476 Mdot
.55218 .45072 Mdot
.48895 .34983 Mdot
.3516 .35979 Mdot
.60676 .66106 Mdot
.35497 .3764 Mdot
.75747 .37516 Mdot
.63912 .49878 Mdot
.49771 .35425 Mdot
.41432 .6139 Mdot
.38677 .59978 Mdot
.55397 .63442 Mdot
.61628 .76867 Mdot
.5994 .68194 Mdot
.35221 .33127 Mdot
.47802 .34419 Mdot
.28491 .69542 Mdot
.42517 .57254 Mdot
.56182 .66642 Mdot
.54948 .34318 Mdot
.39593 .55573 Mdot
.65218 .4119 Mdot
.38311 .54525 Mdot
.56453 .67495 Mdot
.42331 .53707 Mdot
.5705 .66391 Mdot
.49312 .31324 Mdot
.36881 .59815 Mdot
.37024 .56912 Mdot
.20907 .52214 Mdot
.354 .34268 Mdot
.58972 .69685 Mdot
.55495 .45458 Mdot
.35425 .57369 Mdot
.23263 .49334 Mdot
.44291 .57355 Mdot
.48489 .57153 Mdot
.41849 .50971 Mdot
.69507 .58291 Mdot
.34899 .56779 Mdot
.39899 .57238 Mdot
.57426 .78264 Mdot
.555 .76592 Mdot
.4021 .47279 Mdot
.62676 .3767 Mdot
.57067 .68561 Mdot
.50248 .35831 Mdot
.47672 .361 Mdot
.49988 .32463 Mdot
.30808 .39301 Mdot
.31792 .61011 Mdot
.38953 .57015 Mdot
.69022 .41397 Mdot
.35507 .35357 Mdot
.56204 .65203 Mdot
.3607 .35557 Mdot
.59012 .53938 Mdot
.34341 .3366 Mdot
.6931 .58696 Mdot
.5261 .21403 Mdot
.36162 .74817 Mdot
.34397 .34073 Mdot
.59778 .68243 Mdot
.5687 .39456 Mdot
.35825 .60452 Mdot
.73162 .53184 Mdot
.3775 .34553 Mdot
.24651 .31741 Mdot
.43523 .53806 Mdot
.56396 .45235 Mdot
.66418 .38631 Mdot
.35371 .3754 Mdot
.67337 .38088 Mdot
.4024 .54755 Mdot
.66048 .72649 Mdot
.59283 .66085 Mdot
.68503 .39913 Mdot
.3465 .57486 Mdot
.35514 .37621 Mdot
.50212 .35336 Mdot
.27827 .59046 Mdot
.64971 .35681 Mdot
.21724 .46975 Mdot
.2344 .46663 Mdot
.47979 .34605 Mdot
.3313 .75844 Mdot
.6671 .3795 Mdot
.38651 .61877 Mdot
.35841 .66488 Mdot
.39136 .54265 Mdot
.48867 .36138 Mdot
.51273 .33699 Mdot
.745 .65576 Mdot
.36464 .57926 Mdot
.44877 .56291 Mdot
.6143 .63614 Mdot
.48617 .35419 Mdot
.59397 .64125 Mdot
.57074 .62826 Mdot
.48292 .31764 Mdot
.60998 .65309 Mdot
.33792 .35804 Mdot
.57438 .53012 Mdot
.66432 .37787 Mdot
.64241 .40628 Mdot
.50224 .35562 Mdot
.52197 .35777 Mdot
.46478 .34455 Mdot
.38251 .54144 Mdot
.59598 .63678 Mdot
.40854 .5372 Mdot
.4373 .58267 Mdot
.57109 .71217 Mdot
.61124 .64001 Mdot
.40294 .53959 Mdot
.52761 .40044 Mdot
.33191 .33191 Mdot
.5092 .3365 Mdot
.64888 .36761 Mdot
.20335 .52191 Mdot
.68611 .39318 Mdot
.35703 .56781 Mdot
.75015 .53637 Mdot
.57026 .64224 Mdot
.36626 .34653 Mdot
.33943 .38686 Mdot
.3693 .35332 Mdot
.68503 .39957 Mdot
.56874 .62646 Mdot
.61722 .52466 Mdot
.36413 .58491 Mdot
.59086 .50747 Mdot
.22289 .53122 Mdot
.71906 .65326 Mdot
.63695 .373 Mdot
.37746 .54973 Mdot
.6822 .56958 Mdot
.35098 .72245 Mdot
.38448 .57159 Mdot
.35071 .58176 Mdot
.42114 .23424 Mdot
.34552 .61559 Mdot
.53575 .65121 Mdot
.46434 .46108 Mdot
.37296 .60538 Mdot
.39098 .47167 Mdot
.11665 .50282 Mdot
.43242 .53388 Mdot
.36721 .57114 Mdot
.4183 .5736 Mdot
.4143 .54864 Mdot
.55647 .6817 Mdot
.39512 .22769 Mdot
.6313 .4022 Mdot
.57362 .52841 Mdot
.66602 .37552 Mdot
.51302 .34722 Mdot
.53064 .44307 Mdot
.55035 .66783 Mdot
.36964 .3527 Mdot
.57379 .1733 Mdot
.55525 .54069 Mdot
.47553 .31565 Mdot
.21409 .62227 Mdot
.37638 .34679 Mdot
.36299 .60757 Mdot
.33848 .37021 Mdot
.45 .32576 Mdot
.6371 .39695 Mdot
.38216 .52614 Mdot
.57464 .63735 Mdot
.58923 .68971 Mdot
.37588 .54757 Mdot
.75309 .60255 Mdot
.66854 .36875 Mdot
.39987 .30995 Mdot
.3724 .58647 Mdot
.3513 .58331 Mdot
.60707 .67446 Mdot
.49417 .33082 Mdot
.58379 .3703 Mdot
.34809 .3474 Mdot
.3444 .56739 Mdot
.40196 .54849 Mdot
.5873 .53428 Mdot
.62299 .39894 Mdot
.68209 .58313 Mdot
.36802 .58261 Mdot
.59185 .52295 Mdot
.35987 .56596 Mdot
.45646 .622 Mdot
.46118 .32881 Mdot
.42989 .62326 Mdot
.40041 .60959 Mdot
.56069 .72114 Mdot
.67182 .3837 Mdot
.58629 .65719 Mdot
.62079 .69922 Mdot
.66605 .58668 Mdot
.66471 .40554 Mdot
.39913 .53948 Mdot
.65877 .41896 Mdot
.42855 .56564 Mdot
.39147 .59005 Mdot
.63694 .37271 Mdot
.59775 .64171 Mdot
.80551 .46333 Mdot
.62982 .73535 Mdot
.42791 .55004 Mdot
.4125 .56005 Mdot
.3236 .40536 Mdot
.28341 .72934 Mdot
.40315 .60994 Mdot
.59589 .63533 Mdot
.39299 .55533 Mdot
.63858 .40572 Mdot
.35003 .33174 Mdot
.58544 .66694 Mdot
.52541 .35151 Mdot
.50656 .31559 Mdot
.55623 .35552 Mdot
.69772 .58096 Mdot
.4017 .61265 Mdot
.54721 .68809 Mdot
.61836 .64676 Mdot
.6116 .56888 Mdot
.50525 .34204 Mdot
.34073 .33597 Mdot
.44627 .56357 Mdot
.28191 .60489 Mdot
.64362 .41605 Mdot
.39483 .89349 Mdot
.62075 .52321 Mdot
.35539 .32159 Mdot
.49587 .4983 Mdot
.68548 .57091 Mdot
.41018 .59986 Mdot
.37028 .3785 Mdot
.51248 .3228 Mdot
.41071 .55205 Mdot
.32068 .59288 Mdot
.6422 .2891 Mdot
.53118 .34547 Mdot
.66566 .41555 Mdot
.5203 .32793 Mdot
.33434 .33381 Mdot
.69096 .58871 Mdot
.6038 .68837 Mdot
.39956 .57559 Mdot
.4329 .49594 Mdot
.49781 .3383 Mdot
.66336 .59116 Mdot
.36251 .57305 Mdot
.57657 .688 Mdot
.50659 .3315 Mdot
.40569 .58918 Mdot
.33513 .70501 Mdot
.5099 .62649 Mdot
.4825 .34074 Mdot
.36615 .53634 Mdot
.33459 .49106 Mdot
.53133 .33585 Mdot
.46379 .3137 Mdot
.36666 .55853 Mdot
.35064 .37133 Mdot
.3785 .60436 Mdot
.64991 .37973 Mdot
.58196 .46886 Mdot
.65718 .4096 Mdot
.22399 .50546 Mdot
.44506 .54643 Mdot
.53834 .59108 Mdot
.55435 .64198 Mdot
.3501 .3878 Mdot
.55286 .79267 Mdot
.35529 .59325 Mdot
.8256 .4539 Mdot
.54816 .41997 Mdot
.64742 .51106 Mdot
.80146 .3757 Mdot
.34464 .34608 Mdot
.64906 .38534 Mdot
.36609 .56882 Mdot
.67937 .35549 Mdot
.34161 .35757 Mdot
.22198 .50912 Mdot
.35411 .55507 Mdot
.57834 .64226 Mdot
.37381 .58372 Mdot
.56873 .68136 Mdot
.40469 .55906 Mdot
.31226 .56483 Mdot
.41251 .34943 Mdot
.26883 .36934 Mdot
.36802 .61124 Mdot
.5793 .1699 Mdot
.2986 .51393 Mdot
.36443 .33794 Mdot
.42808 .54643 Mdot
.68695 .5767 Mdot
.64462 .36216 Mdot
.5449 .19343 Mdot
.46312 .33843 Mdot
.63707 .37862 Mdot
.60949 .66586 Mdot
.45179 .3574 Mdot
.66386 .58579 Mdot
.37318 .66807 Mdot
.35804 .37729 Mdot
.6686 .402 Mdot
.40239 .57404 Mdot
.35755 .55864 Mdot
.51365 .21784 Mdot
.36571 .79857 Mdot
.58663 .62987 Mdot
.29928 .24855 Mdot
.54353 .68158 Mdot
.35307 .34756 Mdot
.45992 .33157 Mdot
.41883 .59132 Mdot
.37773 .57018 Mdot
.49979 .36277 Mdot
.60793 .64089 Mdot
.44926 .3059 Mdot
.25235 .65162 Mdot
.71233 .3584 Mdot
.29109 .42231 Mdot
.58731 .66952 Mdot
.2881 .41895 Mdot
.34837 .3232 Mdot
.70663 .30012 Mdot
.29898 .48595 Mdot
.66453 .41117 Mdot
.29419 .42615 Mdot
.55931 .65416 Mdot
.39902 .59769 Mdot
.69388 .57968 Mdot
.68114 .56802 Mdot
.60252 .67086 Mdot
.48354 .31928 Mdot
.36763 .37318 Mdot
.37495 .57991 Mdot
.59258 .58833 Mdot
.66653 .76662 Mdot
.51469 .36083 Mdot
.39813 .64268 Mdot
.67101 .37243 Mdot
.39949 .55511 Mdot
.38507 .35484 Mdot
.64148 .39294 Mdot
.68916 .59276 Mdot
.55633 .53148 Mdot
.44689 .56563 Mdot
.44145 .4484 Mdot
.66665 .39502 Mdot
.28864 .73804 Mdot
.37139 .56839 Mdot
.66754 .37982 Mdot
.44818 .51066 Mdot
.67326 .67896 Mdot
.50532 .41526 Mdot
.79884 .56915 Mdot
.53911 .34801 Mdot
.51109 .31734 Mdot
.48861 .85273 Mdot
.39821 .34747 Mdot
.62762 .38787 Mdot
.68372 .59315 Mdot
.29708 .46802 Mdot
.6773 .38897 Mdot
.39036 .5229 Mdot
.44374 .57266 Mdot
.28716 .67227 Mdot
.35599 .46345 Mdot
.66194 .57902 Mdot
.44702 .65068 Mdot
.40734 .52769 Mdot
.3841 .62313 Mdot
.37654 .55674 Mdot
.61507 .68258 Mdot
.67908 .40148 Mdot
.6857 .19178 Mdot
.6626 .4208 Mdot
.57917 .57446 Mdot
.48677 .3374 Mdot
.49622 .37009 Mdot
.40785 .57769 Mdot
.50967 .58027 Mdot
.63001 .19923 Mdot
.42891 .57533 Mdot
.33418 .3847 Mdot
.23345 .46486 Mdot
.43911 .60488 Mdot
.62872 .65071 Mdot
.46301 .59533 Mdot
.55187 .6843 Mdot
.64035 .39469 Mdot
.34376 .34794 Mdot
.3329 .32871 Mdot
.6557 .38432 Mdot
.38725 .56729 Mdot
.32524 .33151 Mdot
.40125 .58092 Mdot
.38995 .59867 Mdot
.59614 .54415 Mdot
.39084 .36159 Mdot
.46456 .34536 Mdot
.36482 .35119 Mdot
.59409 .6457 Mdot
.12864 .62053 Mdot
.36312 .3636 Mdot
.28912 .54734 Mdot
.55003 .43786 Mdot
.2918 .42737 Mdot
.59227 .68905 Mdot
.35747 .33257 Mdot
.67462 .40678 Mdot
.63999 .52371 Mdot
.32482 .74954 Mdot
.68352 .39957 Mdot
.37714 .57282 Mdot
.54974 .66498 Mdot
.62265 .66134 Mdot
.63916 .42672 Mdot
.616 .66526 Mdot
.37639 .63142 Mdot
.39817 .52169 Mdot
.62845 .39268 Mdot
.70243 .73163 Mdot
.67838 .40437 Mdot
.2818 .59288 Mdot
.4367 .54537 Mdot
.58678 .6643 Mdot
.48544 .5874 Mdot
.53464 .67925 Mdot
.6916 .56676 Mdot
.43473 .59357 Mdot
.37303 .35874 Mdot
.57196 .50131 Mdot
.48172 .3395 Mdot
.75353 .53439 Mdot
.57329 .68317 Mdot
.67812 .41923 Mdot
.61157 .6777 Mdot
.59382 .63186 Mdot
.68094 .4048 Mdot
.59313 .65158 Mdot
.36925 .57442 Mdot
.71825 .44118 Mdot
.57316 .68133 Mdot
.6592 .39727 Mdot
.37494 .36169 Mdot
.60797 .64875 Mdot
.46024 .30092 Mdot
.39365 .60154 Mdot
.45526 .32929 Mdot
.38706 .38066 Mdot
.54775 .65956 Mdot
.35217 .33247 Mdot
.50181 .33919 Mdot
.3697 .37385 Mdot
.70216 .37636 Mdot
.69481 .39656 Mdot
.5631 .55937 Mdot
.65605 .68316 Mdot
.56093 .64547 Mdot
.5427 .33896 Mdot
.41358 .60211 Mdot
.37609 .59298 Mdot
.33406 .36127 Mdot
.6237 .66674 Mdot
.76044 .58969 Mdot
.49239 .61348 Mdot
.74368 .61356 Mdot
.62282 .38607 Mdot
.24549 .36217 Mdot
.62665 .52281 Mdot
.66187 .50987 Mdot
.37272 .51938 Mdot
.68741 .57127 Mdot
.40832 .58464 Mdot
.22705 .43786 Mdot
.35392 .32975 Mdot
.57656 .31435 Mdot
.34023 .56998 Mdot
.47607 .34936 Mdot
.41492 .56522 Mdot
.57847 .18549 Mdot
.47147 .58385 Mdot
.37153 .33836 Mdot
.68073 .36854 Mdot
.57902 .63289 Mdot
.37252 .344 Mdot
.49998 .31349 Mdot
.32874 .43566 Mdot
.39651 .51755 Mdot
.40863 .52558 Mdot
.51632 .31015 Mdot
.58912 .63947 Mdot
.51186 .34539 Mdot
.66468 .37791 Mdot
.36193 .36031 Mdot
.41739 .54878 Mdot
.41351 .62764 Mdot
.47912 .30405 Mdot
.65184 .42364 Mdot
.5155 .36249 Mdot
.65428 .41993 Mdot
.69044 .57213 Mdot
.3963 .61436 Mdot
.4851 .30499 Mdot
.36193 .52383 Mdot
.55219 .7539 Mdot
.58102 .54692 Mdot
.52206 .79804 Mdot
.46427 .3457 Mdot
.32562 .41924 Mdot
.65675 .3886 Mdot
.67303 .39562 Mdot
.2887 .66233 Mdot
.63305 .20478 Mdot
.56963 .38318 Mdot
.51236 .1741 Mdot
.66349 .37726 Mdot
.66406 .40133 Mdot
.5094 .32187 Mdot
.60025 .65329 Mdot
.62973 .63963 Mdot
.44533 .33236 Mdot
.25067 .39166 Mdot
.56164 .65263 Mdot
.83449 .49768 Mdot
.51693 .31542 Mdot
.39341 .51205 Mdot
.6739 .56549 Mdot
.37464 .34155 Mdot
.23234 .42888 Mdot
.52609 .17566 Mdot
.41681 .58754 Mdot
.15596 .52612 Mdot
.47472 .32702 Mdot
.70324 .3464 Mdot
.71926 .3234 Mdot
.3511 .57061 Mdot
.41395 .56673 Mdot
.38576 .56281 Mdot
.37867 .38635 Mdot
.59766 .76214 Mdot
.41584 .59032 Mdot
.27461 .36786 Mdot
.45588 .58057 Mdot
.49577 .19812 Mdot
.36466 .35148 Mdot
.24324 .57163 Mdot
.53684 .3574 Mdot
.70474 .65334 Mdot
.34438 .60754 Mdot
.66124 .37817 Mdot
.64024 .3233 Mdot
.63286 .37794 Mdot
.67829 .26084 Mdot
.29497 .48849 Mdot
.61483 .68382 Mdot
.38195 .54524 Mdot
.5066 .3086 Mdot
.54903 .66115 Mdot
.58392 .36394 Mdot
.11693 .58184 Mdot
.6235 .40834 Mdot
.18297 .3402 Mdot
.67223 .40382 Mdot
.67636 .56925 Mdot
.60491 .67323 Mdot
.43675 .47874 Mdot
.58728 .51148 Mdot
.59523 .6418 Mdot
.36849 .29373 Mdot
.63076 .67863 Mdot
.29948 .41101 Mdot
.60853 .7005 Mdot
.65434 .39293 Mdot
.69361 .3983 Mdot
.33877 .5365 Mdot
.40902 .60693 Mdot
.59913 .5051 Mdot
.38362 .506 Mdot
.42632 .59664 Mdot
.48876 .34989 Mdot
.66269 .67546 Mdot
.62483 .35256 Mdot
.59253 .67202 Mdot
.63416 .41154 Mdot
.41575 .56707 Mdot
.42762 .5493 Mdot
.34029 .59612 Mdot
.21212 .47558 Mdot
.8338 .48953 Mdot
.39437 .59285 Mdot
.45573 .60653 Mdot
.47602 .31654 Mdot
.50789 .21191 Mdot
.34072 .23116 Mdot
.30321 .46847 Mdot
.36079 .57503 Mdot
.35713 .34367 Mdot
.37527 .3384 Mdot
.36996 .63532 Mdot
.54536 .58292 Mdot
.4838 .29208 Mdot
.4024 .57382 Mdot
.36521 .4404 Mdot
.48919 .29991 Mdot
.6654 .59395 Mdot
.49811 .33877 Mdot
.54871 .66544 Mdot
.67511 .57194 Mdot
.51662 .35369 Mdot
.48508 .53047 Mdot
.66718 .58679 Mdot
.67903 .67444 Mdot
.35278 .3311 Mdot
.37401 .56091 Mdot
.5271 .62724 Mdot
.50081 .36157 Mdot
.66897 .39667 Mdot
.57505 .66748 Mdot
.62699 .37075 Mdot
.5138 .20933 Mdot
.24011 .41972 Mdot
.69907 .57673 Mdot
.6569 .37712 Mdot
.50334 .47361 Mdot
.35882 .3453 Mdot
.68024 .38879 Mdot
.52608 .59518 Mdot
.44516 .59104 Mdot
.69987 .25568 Mdot
.39592 .5271 Mdot
.76239 .63888 Mdot
.67058 .38986 Mdot
.7044 .57253 Mdot
.39735 .57592 Mdot
.48755 .31034 Mdot
.38938 .49882 Mdot
.39952 .58145 Mdot
.52455 .33325 Mdot
.39785 .59608 Mdot
.38435 .37278 Mdot
.54582 .67357 Mdot
.5393 .42266 Mdot
.21615 .43015 Mdot
.3765 .36687 Mdot
.64411 .58621 Mdot
.41043 .60836 Mdot
.32974 .28616 Mdot
.5821 .64385 Mdot
.35255 .58239 Mdot
.197 .56853 Mdot
.60249 .66358 Mdot
.57645 .6539 Mdot
.41731 .53553 Mdot
.68395 .39669 Mdot
.48435 .3586 Mdot
.3612 .3464 Mdot
.5996 .36897 Mdot
.40718 .59085 Mdot
.37509 .55134 Mdot
.37573 .34648 Mdot
.66227 .40549 Mdot
.41455 .54607 Mdot
.78179 .48609 Mdot
.60684 .56797 Mdot
.64993 .4177 Mdot
.44406 .59546 Mdot
.74075 .27652 Mdot
.62732 .63337 Mdot
.15605 .54116 Mdot
.39643 .34908 Mdot
.47553 .3211 Mdot
.36341 .64131 Mdot
.34833 .86973 Mdot
.36451 .33682 Mdot
.71489 .64674 Mdot
.38948 .59422 Mdot
.42647 .58839 Mdot
.59546 .69419 Mdot
.40262 .5362 Mdot
.56062 .67298 Mdot
.21709 .41502 Mdot
.56589 .15131 Mdot
.61339 .67164 Mdot
.56354 .67682 Mdot
.41604 .48182 Mdot
.21042 .494 Mdot
.60798 .66113 Mdot
.39731 .51705 Mdot
.37406 .28505 Mdot
.32356 .61387 Mdot
.3695 .3285 Mdot
.33644 .37878 Mdot
.62721 .66682 Mdot
.40705 .8059 Mdot
.44964 .50871 Mdot
.33337 .51273 Mdot
.30171 .35212 Mdot
.64707 .37332 Mdot
.43881 .56251 Mdot
.69501 .58555 Mdot
.50862 .32964 Mdot
.46595 .58673 Mdot
.37585 .56367 Mdot
.55582 .67247 Mdot
.37198 .38998 Mdot
.67692 .3839 Mdot
.36744 .5607 Mdot
.43354 .33567 Mdot
.34887 .35632 Mdot
.57572 .68122 Mdot
.28787 .55634 Mdot
.34988 .32644 Mdot
.39654 .6305 Mdot
.42746 .59383 Mdot
.36117 .5699 Mdot
.33087 .58699 Mdot
.65883 .38472 Mdot
.44485 .34127 Mdot
.35198 .63381 Mdot
.60114 .53157 Mdot
.56668 .49024 Mdot
.35907 .63614 Mdot
.59924 .63668 Mdot
.62721 .37804 Mdot
.67278 .58689 Mdot
.29639 .44662 Mdot
.43464 .53882 Mdot
.83118 .46958 Mdot
.23277 .64458 Mdot
.67119 .58206 Mdot
.59299 .69988 Mdot
.36713 .34895 Mdot
.4192 .53032 Mdot
.31751 .3219 Mdot
.39097 .52362 Mdot
.34369 .64607 Mdot
.47347 .32413 Mdot
.65097 .36985 Mdot
.62168 .59359 Mdot
.51 .33034 Mdot
.57711 .65432 Mdot
.7798 .64664 Mdot
.63387 .66142 Mdot
.58272 .62765 Mdot
.66567 .27322 Mdot
.6366 .39098 Mdot
.37135 .88533 Mdot
.28124 .7296 Mdot
.42284 .52215 Mdot
.63263 .39555 Mdot
.59938 .67663 Mdot
.38264 .53803 Mdot
.56041 .648 Mdot
.60775 .62556 Mdot
.43839 .58771 Mdot
.42175 .59821 Mdot
.26668 .37983 Mdot
.8361 .52432 Mdot
.36997 .36512 Mdot
.61812 .66421 Mdot
.30101 .6823 Mdot
.41523 .59337 Mdot
.36525 .58663 Mdot
.64993 .30567 Mdot
.3628 .33477 Mdot
.39572 .75751 Mdot
.37711 .59138 Mdot
.19223 .55943 Mdot
.42783 .59712 Mdot
.59889 .61253 Mdot
.63587 .42778 Mdot
.56248 .58269 Mdot
.4858 .36068 Mdot
.54602 .64211 Mdot
.33307 .34818 Mdot
.54965 .63331 Mdot
.30558 .66938 Mdot
.6383 .39526 Mdot
.56428 .67479 Mdot
.47499 .37208 Mdot
.65104 .4041 Mdot
.66385 .41224 Mdot
.56169 .38061 Mdot
.45976 .36391 Mdot
.38026 .38272 Mdot
.64636 .36379 Mdot
.33049 .69855 Mdot
.65126 .39412 Mdot
.31174 .68147 Mdot
.37798 .6068 Mdot
.2769 .38806 Mdot
.60417 .58504 Mdot
.32944 .55776 Mdot
.68024 .39793 Mdot
.35736 .37046 Mdot
.39381 .54006 Mdot
.61605 .66124 Mdot
.35899 .36649 Mdot
.66355 .34489 Mdot
.50629 .3713 Mdot
.62416 .65743 Mdot
.68867 .38453 Mdot
.55615 .66392 Mdot
.23137 .45236 Mdot
.45654 .29168 Mdot
.5032 .40433 Mdot
.58847 .50447 Mdot
.36623 .61499 Mdot
.39286 .47173 Mdot
.35343 .56238 Mdot
.37966 .5679 Mdot
.48337 .34053 Mdot
.30799 .39395 Mdot
.60755 .64764 Mdot
.70422 .75307 Mdot
.66149 .38065 Mdot
.4684 .46424 Mdot
.34731 .65151 Mdot
.42362 .56183 Mdot
.58794 .67854 Mdot
.59817 .62397 Mdot
.55487 .76641 Mdot
.50019 .36322 Mdot
.32293 .60583 Mdot
.34965 .61635 Mdot
.3136 .60338 Mdot
.66993 .40788 Mdot
.79203 .47281 Mdot
.49911 .36763 Mdot
.13399 .41227 Mdot
.50995 .33653 Mdot
.38078 .2477 Mdot
.59395 .65227 Mdot
.33839 .34094 Mdot
.36914 .59241 Mdot
.631 .71917 Mdot
.56306 .68804 Mdot
.52331 .30388 Mdot
.37021 .34956 Mdot
.80062 .46744 Mdot
.63538 .38322 Mdot
.36414 .59676 Mdot
.43932 .58813 Mdot
.4146 .53889 Mdot
.37282 .54005 Mdot
.62794 .40003 Mdot
.38273 .5271 Mdot
.64112 .35688 Mdot
.32937 .71469 Mdot
.20099 .56953 Mdot
.47627 .30846 Mdot
.49358 .20422 Mdot
.59495 .63283 Mdot
.37842 .68968 Mdot
.39003 .76087 Mdot
.58212 .54834 Mdot
.70027 .40164 Mdot
.38562 .61158 Mdot
.48704 .31873 Mdot
.59411 .18306 Mdot
.48425 .30697 Mdot
.61753 .14831 Mdot
.28125 .64348 Mdot
.79805 .58605 Mdot
.3856 .53339 Mdot
.44504 .32304 Mdot
.43665 .8064 Mdot
.41697 .62718 Mdot
.3242 .34043 Mdot
.29859 .62283 Mdot
.70394 .70693 Mdot
.34217 .33384 Mdot
.39785 .60081 Mdot
.60402 .63263 Mdot
.37014 .57601 Mdot
.37767 .60014 Mdot
.42708 .57248 Mdot
.62119 .41227 Mdot
.44226 .58761 Mdot
.37796 .60385 Mdot
.34232 .78194 Mdot
.36428 .41557 Mdot
.47808 .31419 Mdot
.53155 .78504 Mdot
.35501 .35402 Mdot
.54836 .65623 Mdot
.55237 .42319 Mdot
.64433 .37902 Mdot
.54983 .76292 Mdot
.38969 .53056 Mdot
.73918 .63031 Mdot
.68982 .4054 Mdot
.34563 .36135 Mdot
.67052 .58895 Mdot
.79065 .41719 Mdot
.45852 .34624 Mdot
.67392 .56889 Mdot
.48077 .33871 Mdot
.50089 .81672 Mdot
.56419 .67887 Mdot
.36893 .61664 Mdot
.66853 .37397 Mdot
.45745 .31948 Mdot
.29054 .34334 Mdot
.38612 .55755 Mdot
.46547 .34717 Mdot
.37785 .61821 Mdot
.57255 .48601 Mdot
.55994 .43367 Mdot
.44919 .33143 Mdot
.69286 .39327 Mdot
.64983 .40651 Mdot
.3361 .3516 Mdot
.54856 .64465 Mdot
.58073 .63721 Mdot
.64494 .39674 Mdot
.14175 .44559 Mdot
.40844 .58981 Mdot
.42976 .59062 Mdot
.60745 .52799 Mdot
.37438 .5417 Mdot
.34733 .42877 Mdot
.65591 .59422 Mdot
.55904 .64373 Mdot
.36775 .54754 Mdot
.41576 .54638 Mdot
.44568 .56495 Mdot
.24192 .42053 Mdot
.49812 .33634 Mdot
.40959 .52785 Mdot
.36425 .37899 Mdot
.67267 .61626 Mdot
.40995 .60338 Mdot
.41216 .6268 Mdot
.55878 .66798 Mdot
.25878 .31149 Mdot
.66913 .39145 Mdot
.48654 .35547 Mdot
.52132 .31773 Mdot
.24209 .50034 Mdot
.55191 .6257 Mdot
.65662 .58851 Mdot
.547 .24243 Mdot
.67913 .59306 Mdot
.36221 .33802 Mdot
.53608 .40083 Mdot
.43246 .33004 Mdot
.50522 .31359 Mdot
.69073 .3803 Mdot
.36372 .55462 Mdot
.42821 .59607 Mdot
.71335 .64239 Mdot
.43312 .58194 Mdot
.37396 .35566 Mdot
.68053 .37278 Mdot
.56096 .67015 Mdot
.38554 .35967 Mdot
.67436 .39599 Mdot
.58997 .63912 Mdot
.44604 .59743 Mdot
.33761 .59405 Mdot
.57358 .66293 Mdot
.58166 .68525 Mdot
.41369 .57575 Mdot
.43431 .83438 Mdot
.56398 .64018 Mdot
.57997 .67652 Mdot
.70954 .57346 Mdot
.45425 .33976 Mdot
.48046 .60047 Mdot
.63358 .39551 Mdot
.36612 .57922 Mdot
.47484 .30837 Mdot
.34593 .33766 Mdot
.568 .65785 Mdot
.43841 .55608 Mdot
.39825 .58934 Mdot
.35872 .34339 Mdot
.3841 .34328 Mdot
.37753 .35883 Mdot
.61743 .39593 Mdot
.39933 .52233 Mdot
.60891 .65835 Mdot
.63422 .38413 Mdot
.37161 .33615 Mdot
.3459 .3788 Mdot
.33632 .77316 Mdot
.41595 .5856 Mdot
.32039 .33482 Mdot
.16581 .68443 Mdot
.32991 .44056 Mdot
.66716 .57703 Mdot
.45433 .31301 Mdot
.28119 .38436 Mdot
.39058 .3813 Mdot
.62916 .38247 Mdot
.38651 .42673 Mdot
.3594 .39175 Mdot
.43622 .57678 Mdot
.39784 .55261 Mdot
.36972 .52554 Mdot
.35458 .36115 Mdot
.23664 .43964 Mdot
.62031 .65359 Mdot
.44341 .72023 Mdot
.35509 .35421 Mdot
.44958 .33369 Mdot
.47031 .30673 Mdot
.51188 .33787 Mdot
.37798 .61017 Mdot
.55442 .7792 Mdot
.30941 .69076 Mdot
.40908 .75557 Mdot
.63679 .37995 Mdot
.60208 .6256 Mdot
.69104 .42933 Mdot
.57593 .65343 Mdot
.4971 .32542 Mdot
.34986 .36127 Mdot
.60295 .6923 Mdot
.6556 .41306 Mdot
.6535 .40979 Mdot
.52115 .36088 Mdot
.50125 .34202 Mdot
.49961 .35406 Mdot
.54645 .64286 Mdot
.59345 .65162 Mdot
.42278 .55001 Mdot
.56611 .6664 Mdot
.23689 .66469 Mdot
.37491 .33071 Mdot
.52464 .31479 Mdot
.66408 .39185 Mdot
.58496 .68189 Mdot
.37228 .56312 Mdot
.4375 .23771 Mdot
.52629 .30719 Mdot
.37923 .36738 Mdot
.66909 .46908 Mdot
.50278 .13088 Mdot
.43275 .60587 Mdot
.64366 .42092 Mdot
.54183 .58704 Mdot
.39259 .56215 Mdot
.46339 .33178 Mdot
.24489 .61452 Mdot
.66981 .59336 Mdot
.39269 .60733 Mdot
.34884 .58601 Mdot
.68169 .39986 Mdot
.5552 .42676 Mdot
.4329 .57519 Mdot
.49214 .44181 Mdot
.6324 .41902 Mdot
.50018 .36772 Mdot
.51537 .86205 Mdot
.70227 .35237 Mdot
.26635 .35262 Mdot
.6669 .58124 Mdot
.43823 .57841 Mdot
.48674 .34777 Mdot
.37589 .37424 Mdot
.49223 .34484 Mdot
.60916 .69691 Mdot
.45661 .33885 Mdot
.38388 .55257 Mdot
.60671 .65384 Mdot
.66608 .40399 Mdot
.45167 .45511 Mdot
.37899 .80011 Mdot
.48767 .31071 Mdot
.66997 .59971 Mdot
.40777 .60197 Mdot
.35887 .71924 Mdot
.34027 .53334 Mdot
.40249 .60932 Mdot
.63429 .37479 Mdot
.59037 .67625 Mdot
.62371 .38435 Mdot
.42432 .61672 Mdot
.4021 .67606 Mdot
.65891 .38045 Mdot
.68201 .71542 Mdot
.37525 .34509 Mdot
.24929 .39418 Mdot
.38568 .57454 Mdot
.66731 .37345 Mdot
.40381 .52128 Mdot
.6186 .66427 Mdot
.55525 .50794 Mdot
.61806 .60235 Mdot
.66985 .37121 Mdot
.76971 .64237 Mdot
.55512 .45588 Mdot
.47481 .59906 Mdot
.66775 .37828 Mdot
.55203 .79087 Mdot
.68478 .57885 Mdot
.34861 .34473 Mdot
.38153 .34238 Mdot
.34672 .37398 Mdot
.43318 .58428 Mdot
.30348 .58893 Mdot
.35709 .38494 Mdot
.61869 .39342 Mdot
.37122 .38213 Mdot
.21762 .4829 Mdot
.756 .59909 Mdot
.3796 .3598 Mdot
.38462 .57735 Mdot
.42308 .62143 Mdot
.36128 .41563 Mdot
.47959 .36932 Mdot
.81476 .4399 Mdot
.30038 .72933 Mdot
.41997 .59028 Mdot
.3122 .65621 Mdot
.62114 .68433 Mdot
.50819 .53704 Mdot
.47878 .6366 Mdot
.56586 .40031 Mdot
.58097 .67904 Mdot
.58743 .47877 Mdot
.55608 .64308 Mdot
.39708 .621 Mdot
.39027 .5897 Mdot
.55563 .68448 Mdot
.74271 .52659 Mdot
.62799 .78452 Mdot
.74759 .61268 Mdot
.59071 .63518 Mdot
.67216 .38391 Mdot
.63519 .41857 Mdot
.6378 .37272 Mdot
.4995 .35978 Mdot
.57665 .68646 Mdot
.42326 .52898 Mdot
.49405 .31409 Mdot
.37134 .59131 Mdot
.64291 .40221 Mdot
.60691 .56973 Mdot
.56078 .67086 Mdot
.3995 .57299 Mdot
.3328 .75245 Mdot
.48453 .3329 Mdot
.3565 .34553 Mdot
.6909 .46513 Mdot
.45982 .30858 Mdot
.66698 .41869 Mdot
.59629 .61724 Mdot
.53466 .37259 Mdot
.3974 .22512 Mdot
.40612 .51383 Mdot
.40825 .51541 Mdot
.54351 .29756 Mdot
.36613 .78292 Mdot
.42367 .56581 Mdot
.5031 .31402 Mdot
.45253 .33927 Mdot
.40907 .51986 Mdot
.60164 .68793 Mdot
.3622 .38907 Mdot
.33391 .35964 Mdot
.35586 .60603 Mdot
.59513 .5017 Mdot
.27293 .38199 Mdot
.4047 .54102 Mdot
.40142 .64757 Mdot
.48218 .37304 Mdot
.66423 .58518 Mdot
.58459 .52758 Mdot
.33844 .3626 Mdot
.38826 .59513 Mdot
.64642 .76873 Mdot
.56835 .67773 Mdot
.4768 .35539 Mdot
.64087 .41135 Mdot
.3283 .3297 Mdot
.53496 .33613 Mdot
.40947 .51988 Mdot
.41488 .54605 Mdot
.67688 .38103 Mdot
.59609 .61195 Mdot
.35297 .3629 Mdot
.4886 .31433 Mdot
.33794 .34108 Mdot
.59025 .64725 Mdot
.57386 .67623 Mdot
.35303 .61926 Mdot
.33563 .54425 Mdot
.51066 .31328 Mdot
.34822 .55786 Mdot
.51574 .33715 Mdot
.51271 .21672 Mdot
.64219 .41544 Mdot
.35107 .57531 Mdot
.53318 .64132 Mdot
.64308 .40116 Mdot
.42345 .5825 Mdot
.54499 .2995 Mdot
.41085 .55017 Mdot
.44473 .32844 Mdot
.25337 .6373 Mdot
.34046 .35597 Mdot
.38254 .47743 Mdot
.45837 .50845 Mdot
.37427 .54243 Mdot
.45593 .35706 Mdot
.3058 .56571 Mdot
.65545 .38096 Mdot
.5969 .66105 Mdot
.21907 .33807 Mdot
.65646 .39667 Mdot
.37814 .58312 Mdot
.36196 .36295 Mdot
.57786 .63203 Mdot
.6958 .57168 Mdot
.61464 .513 Mdot
.46816 .58157 Mdot
.42073 .50855 Mdot
.36309 .56569 Mdot
.51332 .17296 Mdot
.49509 .35139 Mdot
.59287 .67946 Mdot
.63524 .41632 Mdot
.64106 .38812 Mdot
.49372 .33059 Mdot
.7252 .68494 Mdot
.76609 .5445 Mdot
.20401 .73442 Mdot
.53177 .32702 Mdot
.36116 .38227 Mdot
.55731 .4926 Mdot
.51249 .33165 Mdot
.48438 .35134 Mdot
.50649 .37242 Mdot
.72599 .6263 Mdot
.59689 .63824 Mdot
.39946 .59091 Mdot
.54474 .63601 Mdot
.43778 .57998 Mdot
.28433 .33713 Mdot
.64219 .39544 Mdot
.59669 .65904 Mdot
.4715 .27938 Mdot
.45382 .5155 Mdot
.40367 .56326 Mdot
.32769 .31129 Mdot
.46199 .563 Mdot
.29769 .4345 Mdot
.3401 .59987 Mdot
.49201 .33978 Mdot
.44152 .65987 Mdot
.40337 .63914 Mdot
.32285 .73978 Mdot
.65871 .40996 Mdot
.69941 .57077 Mdot
.44792 .59791 Mdot
.45472 .6267 Mdot
.57478 .63166 Mdot
.60123 .69325 Mdot
.35761 .38561 Mdot
.71195 .452 Mdot
.66179 .40857 Mdot
.80456 .52925 Mdot
.40927 .60767 Mdot
.61431 .35929 Mdot
.249 .63459 Mdot
.42085 .57716 Mdot
.54015 .39388 Mdot
.55126 .76367 Mdot
.41936 .55918 Mdot
.42235 .75255 Mdot
.66048 .39184 Mdot
.19424 .56284 Mdot
.34164 .57913 Mdot
.46381 .33316 Mdot
.59941 .65441 Mdot
.62391 .65727 Mdot
.38161 .36746 Mdot
.25483 .69498 Mdot
.62633 .43806 Mdot
.59568 .65412 Mdot
.38405 .56067 Mdot
.66816 .39279 Mdot
.69606 .56874 Mdot
.46479 .54141 Mdot
.65294 .23436 Mdot
.56424 .66831 Mdot
.3576 .63791 Mdot
.74845 .61973 Mdot
.57 .45343 Mdot
.83973 .51291 Mdot
.6455 .36745 Mdot
.33785 .36261 Mdot
.33326 .5656 Mdot
.54442 .24305 Mdot
.33961 .58116 Mdot
.27714 .34298 Mdot
.52504 .66316 Mdot
.34957 .33187 Mdot
.39342 .56536 Mdot
.43197 .57305 Mdot
.57786 .50601 Mdot
.37441 .33488 Mdot
.43327 .57492 Mdot
.33823 .61825 Mdot
.58386 .63995 Mdot
.65574 .5954 Mdot
.56029 .66584 Mdot
.37588 .57206 Mdot
.25674 .61045 Mdot
.60606 .68833 Mdot
.81055 .45025 Mdot
.40416 .35417 Mdot
.64499 .37831 Mdot
.41159 .64115 Mdot
.38762 .6101 Mdot
.81539 .36629 Mdot
.68988 .56661 Mdot
.30188 .25515 Mdot
.44768 .32097 Mdot
.65348 .80256 Mdot
.46483 .30559 Mdot
.78932 .60711 Mdot
.47536 .46225 Mdot
.36342 .53479 Mdot
.32584 .47258 Mdot
.4104 .74943 Mdot
.67892 .35738 Mdot
.36756 .70207 Mdot
.40898 .60687 Mdot
.40509 .59932 Mdot
.50757 .31911 Mdot
.73886 .66491 Mdot
.55737 .58569 Mdot
.58366 .52227 Mdot
.34559 .35806 Mdot
.58706 .65331 Mdot
.3888 .55263 Mdot
.71154 .50271 Mdot
.46804 .31496 Mdot
.2815 .55533 Mdot
.39721 .57409 Mdot
.5711 .57591 Mdot
.70542 .68479 Mdot
.66976 .40037 Mdot
.44777 .33578 Mdot
.44761 .3474 Mdot
.44216 .57104 Mdot
.62994 .39499 Mdot
.42279 .55504 Mdot
.55271 .45913 Mdot
.45912 .59757 Mdot
.35324 .33502 Mdot
.36503 .5886 Mdot
.35303 .45756 Mdot
.79583 .63843 Mdot
.44838 .61969 Mdot
.56071 .63371 Mdot
.50596 .3557 Mdot
.50222 .33404 Mdot
.58111 .63689 Mdot
.50213 .33318 Mdot
.44527 .72707 Mdot
.33781 .67901 Mdot
.35984 .33611 Mdot
.38626 .76605 Mdot
.34219 .35402 Mdot
.69995 .57184 Mdot
.4165 .58244 Mdot
.58691 .2452 Mdot
.53256 .32763 Mdot
.20527 .51823 Mdot
.64764 .39333 Mdot
.68567 .56677 Mdot
.44235 .54763 Mdot
.31423 .34839 Mdot
.49422 .32163 Mdot
.68192 .32659 Mdot
.44409 .56358 Mdot
.61291 .64898 Mdot
.42387 .56271 Mdot
.44914 .54414 Mdot
.66906 .57333 Mdot
.36257 .56375 Mdot
.67438 .39577 Mdot
.574 .68639 Mdot
.78842 .59862 Mdot
.49996 .36121 Mdot
.39466 .60499 Mdot
.38564 .56106 Mdot
.5964 .69635 Mdot
.44501 .55097 Mdot
.62978 .38454 Mdot
.43074 .90809 Mdot
.37216 .34262 Mdot
.66388 .58683 Mdot
.75744 .37516 Mdot
.38726 .54676 Mdot
.39853 .54133 Mdot
.58281 .38156 Mdot
.63008 .76904 Mdot
.66567 .38221 Mdot
.45731 .58356 Mdot
.46759 .31939 Mdot
.35459 .36636 Mdot
.64479 .36177 Mdot
.39517 .52302 Mdot
.40714 .59803 Mdot
.36131 .3354 Mdot
.32403 .31349 Mdot
.46019 .29917 Mdot
.63623 .37782 Mdot
.32136 .65704 Mdot
.44631 .23809 Mdot
.40565 .58478 Mdot
.70154 .54949 Mdot
.58367 .67363 Mdot
.6623 .37492 Mdot
.6033 .76038 Mdot
.38789 .61955 Mdot
.67422 .41153 Mdot
.66466 .40565 Mdot
.4475 .55963 Mdot
.55754 .62178 Mdot
.5753 .62242 Mdot
.58358 .67534 Mdot
.20567 .5654 Mdot
.38625 .20987 Mdot
.49841 .35544 Mdot
.66367 .39619 Mdot
.48055 .30637 Mdot
.34797 .38452 Mdot
.56867 .49052 Mdot
.45047 .3343 Mdot
.59812 .63283 Mdot
.50126 .30665 Mdot
.41726 .5516 Mdot
.64991 .41207 Mdot
.51986 .31874 Mdot
.38782 .53694 Mdot
.38494 .64879 Mdot
.34338 .46487 Mdot
.36802 .38937 Mdot
.58904 .48053 Mdot
.3769 .57861 Mdot
.67027 .58709 Mdot
.41 .57542 Mdot
.62815 .39133 Mdot
.3909 .42968 Mdot
.39951 .52825 Mdot
.53168 .32558 Mdot
.41502 .2133 Mdot
.46024 .35877 Mdot
.44648 .54535 Mdot
.37655 .57328 Mdot
.40813 .58672 Mdot
.43463 .59118 Mdot
.69127 .71623 Mdot
.64661 .35421 Mdot
.33694 .63903 Mdot
.53272 .34323 Mdot
.57249 .65626 Mdot
.61712 .67682 Mdot
.57303 .38905 Mdot
.68723 .5648 Mdot
.63152 .39655 Mdot
.40766 .58812 Mdot
.67882 .32617 Mdot
.63706 .51691 Mdot
.75035 .61405 Mdot
.55921 .34961 Mdot
.50858 .31497 Mdot
.56064 .63162 Mdot
.52271 .33676 Mdot
.39706 .52141 Mdot
.33652 .5942 Mdot
.79538 .58863 Mdot
.61466 .39411 Mdot
.35162 .36187 Mdot
.36915 .58928 Mdot
.25955 .3774 Mdot
.4762 .31649 Mdot
.47393 .37103 Mdot
.42526 .55511 Mdot
.6235 .63429 Mdot
.8362 .58391 Mdot
.63398 .40415 Mdot
.35325 .71585 Mdot
.54051 .60922 Mdot
.32204 .64344 Mdot
.65317 .3841 Mdot
.50748 .40874 Mdot
.48457 .3679 Mdot
.28565 .72019 Mdot
.5715 .66319 Mdot
.35113 .35876 Mdot
.35154 .62852 Mdot
.59732 .63257 Mdot
.4906 .30391 Mdot
.55057 .65343 Mdot
.37209 .61798 Mdot
.62059 .39564 Mdot
.50779 .33372 Mdot
.66763 .35489 Mdot
.55745 .68431 Mdot
.3415 .35526 Mdot
.21296 .51582 Mdot
.34414 .71563 Mdot
.55159 .76346 Mdot
.41071 .52795 Mdot
.6256 .26351 Mdot
.42629 .53143 Mdot
.58592 .62554 Mdot
.38531 .57489 Mdot
.38677 .47098 Mdot
.49748 .37008 Mdot
.38234 .64071 Mdot
.36826 .59547 Mdot
.31262 .72364 Mdot
.41497 .5691 Mdot
.43606 .53794 Mdot
.3486 .59544 Mdot
.57911 .60805 Mdot
.38125 .63956 Mdot
.61267 .64961 Mdot
.7201 .64547 Mdot
.48188 .34994 Mdot
.33598 .36929 Mdot
.33431 .3355 Mdot
.27431 .34209 Mdot
.25319 .38926 Mdot
.72918 .67539 Mdot
.56438 .65092 Mdot
.67588 .40378 Mdot
.42136 .55319 Mdot
.54208 .80143 Mdot
.2593 .55825 Mdot
.49274 .36776 Mdot
.50793 .31021 Mdot
.33961 .61021 Mdot
.59629 .1704 Mdot
.3727 .63982 Mdot
.61846 .52384 Mdot
.43608 .58347 Mdot
.35117 .58062 Mdot
.46292 .36723 Mdot
.23059 .44762 Mdot
.40947 .52775 Mdot
.57425 .63205 Mdot
.34988 .35076 Mdot
.36472 .66702 Mdot
.25061 .56126 Mdot
.28097 .60827 Mdot
.50625 .59973 Mdot
.38459 .52972 Mdot
.48016 .31749 Mdot
.58607 .63285 Mdot
.59786 .52833 Mdot
.63358 .381 Mdot
.60463 .50626 Mdot
.32607 .70705 Mdot
.72496 .37497 Mdot
.34914 .35699 Mdot
.5375 .3089 Mdot
.38295 .55227 Mdot
.4997 .35904 Mdot
.41476 .61857 Mdot
.64155 .51122 Mdot
.34809 .33466 Mdot
.54383 .65291 Mdot
.6726 .38474 Mdot
.61062 .64201 Mdot
.52444 .79632 Mdot
.25853 .57047 Mdot
.65307 .80345 Mdot
.46254 .35065 Mdot
.51052 .67823 Mdot
.60367 .669 Mdot
.44022 .54995 Mdot
.19834 .72598 Mdot
.58602 .67003 Mdot
.60838 .6415 Mdot
.56153 .4053 Mdot
.22385 .50527 Mdot
.37409 .64248 Mdot
.55464 .64692 Mdot
.53895 .35732 Mdot
.36851 .35468 Mdot
.39469 .53612 Mdot
.3691 .61296 Mdot
.59919 .6935 Mdot
.49327 .32362 Mdot
.25796 .37061 Mdot
.4972 .34048 Mdot
.60116 .64139 Mdot
.47574 .3342 Mdot
.80589 .45358 Mdot
.45877 .32257 Mdot
.36736 .59566 Mdot
.40662 .58751 Mdot
.60641 .22164 Mdot
.57382 .67619 Mdot
.39564 .54072 Mdot
.39443 .59556 Mdot
.60818 .66393 Mdot
.43014 .33367 Mdot
.57999 .74904 Mdot
.38104 .54222 Mdot
.40385 .59032 Mdot
.35147 .32984 Mdot
.57381 .47162 Mdot
.67 .52385 Mdot
.39472 .53779 Mdot
.35188 .37725 Mdot
.54758 .64025 Mdot
.41086 .57436 Mdot
.2298 .44526 Mdot
.48792 .30057 Mdot
.37083 .53729 Mdot
.69731 .57582 Mdot
.42634 .57035 Mdot
.83151 .58769 Mdot
.40369 .6025 Mdot
.60305 .67565 Mdot
.60257 .66088 Mdot
.47918 .2965 Mdot
.57789 .65597 Mdot
.67054 .57408 Mdot
.64756 .40437 Mdot
.76155 .66367 Mdot
.67499 .5713 Mdot
.35603 .58808 Mdot
.28015 .72909 Mdot
.36345 .61145 Mdot
.42555 .62314 Mdot
.20766 .50393 Mdot
.66873 .57859 Mdot
.59366 .67466 Mdot
.74238 .52164 Mdot
.36263 .53814 Mdot
.63198 .40086 Mdot
.41617 .62708 Mdot
.37051 .53729 Mdot
.35749 .46574 Mdot
.33729 .67396 Mdot
.67705 .36811 Mdot
.47969 .59739 Mdot
.39591 .53625 Mdot
.6246 .76884 Mdot
.37988 .55699 Mdot
.38091 .36095 Mdot
.56442 .64629 Mdot
.52344 .34468 Mdot
.36484 .34148 Mdot
.38575 .54955 Mdot
.3548 .35848 Mdot
.49528 .35618 Mdot
.65467 .36475 Mdot
.36314 .58441 Mdot
.36477 .32586 Mdot
.34987 .36281 Mdot
.4303 .54618 Mdot
.59754 .65599 Mdot
.34521 .52535 Mdot
.41298 .57419 Mdot
.41995 .52265 Mdot
.58023 .63739 Mdot
.16653 .60215 Mdot
.44043 .58377 Mdot
.51327 .40583 Mdot
.55198 .68882 Mdot
.65876 .58638 Mdot
.51755 .32766 Mdot
.35417 .53344 Mdot
.63849 .3896 Mdot
.64573 .40007 Mdot
.52526 .35976 Mdot
.58085 .69333 Mdot
.5059 .33116 Mdot
.47443 .57666 Mdot
.33708 .60696 Mdot
.34913 .6259 Mdot
.22041 .33647 Mdot
.78622 .40909 Mdot
.59424 .68464 Mdot
.47327 .36616 Mdot
.59585 .50771 Mdot
.63734 .40408 Mdot
.49733 .37608 Mdot
.53267 .66078 Mdot
.55928 .67775 Mdot
.5775 .63588 Mdot
.35101 .37321 Mdot
.5067 .34106 Mdot
.54329 .68945 Mdot
.5862 .62034 Mdot
.42874 .55171 Mdot
.39712 .53549 Mdot
.62658 .68345 Mdot
.38647 .40383 Mdot
.34464 .3411 Mdot
.46957 .32324 Mdot
.86687 .44426 Mdot
.6339 .40456 Mdot
.31286 .72466 Mdot
.38652 .53774 Mdot
.0902 .52475 Mdot
.37262 .63905 Mdot
.38264 .55943 Mdot
.54873 .66573 Mdot
.34234 .32407 Mdot
.3656 .35547 Mdot
.60405 .6677 Mdot
.61204 .62352 Mdot
.36291 .37584 Mdot
.55474 .39626 Mdot
.76376 .68275 Mdot
.59805 .5209 Mdot
.60787 .67269 Mdot
.35256 .72522 Mdot
.64861 .36168 Mdot
.54219 .67304 Mdot
.67257 .35999 Mdot
.4824 .35137 Mdot
.48907 .30936 Mdot
.67767 .38028 Mdot
.44392 .55495 Mdot
.46133 .34546 Mdot
.46404 .59831 Mdot
.81653 .54431 Mdot
.69913 .27784 Mdot
.56093 .81824 Mdot
.41115 .60932 Mdot
.55153 .5828 Mdot
.69253 .64235 Mdot
.3657 .55874 Mdot
.4859 .58339 Mdot
.35293 .36114 Mdot
.54729 .68141 Mdot
.64207 .36019 Mdot
.82577 .44757 Mdot
.40641 .58573 Mdot
.60713 .64704 Mdot
.6441 .40993 Mdot
.8014 .45266 Mdot
.49218 .44063 Mdot
.43353 .56527 Mdot
.25666 .79284 Mdot
.55695 .68245 Mdot
.52317 .34514 Mdot
.36265 .76534 Mdot
.54061 .64246 Mdot
.44117 .22907 Mdot
.44319 .33982 Mdot
.62917 .56307 Mdot
.55233 .66868 Mdot
.43931 .31503 Mdot
.58656 .64772 Mdot
.38534 .36963 Mdot
.59686 .61694 Mdot
.48537 .32828 Mdot
.40125 .56648 Mdot
.48775 .3304 Mdot
.37412 .34038 Mdot
.47516 .35721 Mdot
.64276 .36001 Mdot
.66704 .58364 Mdot
.64946 .40884 Mdot
.56488 .48867 Mdot
.5196 .71143 Mdot
.65049 .3698 Mdot
.66416 .32083 Mdot
.41774 .56181 Mdot
.60049 .61315 Mdot
.5235 .3504 Mdot
.53872 .33163 Mdot
.59405 .4908 Mdot
.59705 .64247 Mdot
.47906 .32708 Mdot
.33461 .70618 Mdot
.13227 .46335 Mdot
.42165 .63538 Mdot
.40205 .20263 Mdot
.60882 .66544 Mdot
.49475 .37087 Mdot
.60961 .52683 Mdot
.62292 .66923 Mdot
.51546 .31578 Mdot
.67071 .38031 Mdot
.64224 .38512 Mdot
.44788 .5708 Mdot
.64023 .42794 Mdot
.45595 .35798 Mdot
.64204 .76937 Mdot
.56834 .64246 Mdot
.77343 .40045 Mdot
.37714 .36539 Mdot
.48793 .35378 Mdot
.38019 .64201 Mdot
.53358 .68297 Mdot
.52081 .31565 Mdot
.64307 .21625 Mdot
.84767 .40291 Mdot
.4778 .32721 Mdot
.56344 .64725 Mdot
.56934 .65476 Mdot
.44386 .62178 Mdot
.58827 .50846 Mdot
.48857 .32276 Mdot
.58548 .2434 Mdot
.28144 .35071 Mdot
.69047 .57195 Mdot
.31996 .75692 Mdot
.40871 .52715 Mdot
.38187 .53087 Mdot
.63103 .38162 Mdot
.40501 .56178 Mdot
.60576 .6242 Mdot
.36388 .63627 Mdot
.62822 .41427 Mdot
.49962 .36717 Mdot
.41282 .58367 Mdot
.36003 .37072 Mdot
.63074 .37589 Mdot
.65826 .42432 Mdot
.47503 .34123 Mdot
.5609 .64488 Mdot
.73087 .53066 Mdot
.49908 .34058 Mdot
.39638 .52393 Mdot
.67571 .57938 Mdot
.34044 .59617 Mdot
.61011 .22966 Mdot
.61923 .65057 Mdot
.52267 .33793 Mdot
.5846 .70097 Mdot
.66198 .40074 Mdot
.53479 .35485 Mdot
.37464 .55583 Mdot
.50245 .31124 Mdot
.49369 .4086 Mdot
.36375 .27326 Mdot
.59521 .62019 Mdot
.33451 .3901 Mdot
.60025 .69421 Mdot
.69129 .57189 Mdot
.25924 .47534 Mdot
.34779 .34303 Mdot
.45747 .33058 Mdot
.81158 .44315 Mdot
.52628 .3502 Mdot
.41847 .57151 Mdot
.42495 .5943 Mdot
.50953 .32026 Mdot
.34259 .36486 Mdot
.23153 .39513 Mdot
.29676 .34053 Mdot
.5696 .68082 Mdot
.49202 .4806 Mdot
.87189 .48568 Mdot
.49182 .3814 Mdot
.67801 .40037 Mdot
.45866 .6345 Mdot
.4077 .55106 Mdot
.68094 .40325 Mdot
.63538 .41203 Mdot
.37344 .33747 Mdot
.49563 .35915 Mdot
.54994 .69168 Mdot
.66453 .36599 Mdot
.55546 .71115 Mdot
.23986 .40587 Mdot
.45743 .55275 Mdot
.30944 .58714 Mdot
.37285 .60529 Mdot
.57096 .45465 Mdot
.62289 .39761 Mdot
.38272 .58222 Mdot
.33393 .60054 Mdot
.65955 .37545 Mdot
.38109 .34721 Mdot
.60316 .71675 Mdot
.46894 .33231 Mdot
.11228 .48744 Mdot
.36363 .58568 Mdot
.40631 .56905 Mdot
.63693 .38009 Mdot
.38617 .79509 Mdot
.60353 .68117 Mdot
.55837 .64748 Mdot
.49607 .35192 Mdot
.61003 .48426 Mdot
.43639 .5349 Mdot
.36685 .5672 Mdot
.46108 .34016 Mdot
.67083 .58627 Mdot
.50697 .8475 Mdot
.39625 .58754 Mdot
.65913 .38823 Mdot
.63807 .32518 Mdot
.62275 .39166 Mdot
.43038 .60834 Mdot
.42252 .57505 Mdot
.35869 .58228 Mdot
.43068 .60031 Mdot
.67845 .37754 Mdot
.3667 .56123 Mdot
.39066 .49938 Mdot
.58916 .67531 Mdot
.39423 .52721 Mdot
.27495 .3594 Mdot
.39861 .5849 Mdot
.36021 .37 Mdot
.67948 .52339 Mdot
.39377 .60352 Mdot
.39221 .52721 Mdot
.29717 .33456 Mdot
.38848 .56543 Mdot
.65708 .4147 Mdot
.56933 .66123 Mdot
.66437 .39953 Mdot
.6713 .40521 Mdot
.51114 .3093 Mdot
.38887 .35846 Mdot
.34247 .56479 Mdot
.36245 .37725 Mdot
.45747 .60502 Mdot
.38643 .62014 Mdot
.57101 .4803 Mdot
.61942 .5233 Mdot
.38278 .39037 Mdot
.3709 .56104 Mdot
.49 .34989 Mdot
.522 .33213 Mdot
.38545 .4263 Mdot
.46348 .59355 Mdot
.64764 .36043 Mdot
.66735 .37367 Mdot
.35029 .43053 Mdot
.40424 .44729 Mdot
.35256 .36781 Mdot
.54777 .52555 Mdot
.37657 .61334 Mdot
.39566 .59926 Mdot
.42243 .62235 Mdot
.45351 .31774 Mdot
.66572 .58543 Mdot
.50054 .36599 Mdot
.70368 .58538 Mdot
.62854 .36982 Mdot
.41018 .60952 Mdot
.71569 .29918 Mdot
.59218 .69136 Mdot
.56893 .66263 Mdot
.63243 .41833 Mdot
.45953 .35874 Mdot
.46174 .59449 Mdot
.23915 .29065 Mdot
.62245 .64365 Mdot
.33573 .36601 Mdot
.37046 .57457 Mdot
.4784 .34491 Mdot
.57409 .68775 Mdot
.39098 .36768 Mdot
.40132 .61195 Mdot
.47063 .3733 Mdot
.39087 .57887 Mdot
.42813 .76641 Mdot
.59497 .66929 Mdot
.60861 .56709 Mdot
.63287 .65231 Mdot
.68016 .40004 Mdot
.66994 .38765 Mdot
.42364 .58115 Mdot
.1728 .37235 Mdot
.62622 .69479 Mdot
.68496 .39975 Mdot
.38089 .38003 Mdot
.66666 .58918 Mdot
.38617 .37454 Mdot
.51555 .33537 Mdot
.34878 .35184 Mdot
.5232 .31885 Mdot
.3938 .40417 Mdot
.60094 .70562 Mdot
.36796 .34106 Mdot
.39119 .80175 Mdot
.33663 .59173 Mdot
.36731 .33339 Mdot
.34073 .61204 Mdot
.41876 .48412 Mdot
.46479 .34366 Mdot
.34985 .37022 Mdot
.43787 .5548 Mdot
.76085 .36228 Mdot
.67317 .39663 Mdot
.64687 .35975 Mdot
.3401 .57641 Mdot
.49866 .37269 Mdot
.5978 .61888 Mdot
.54116 .42711 Mdot
.65892 .58889 Mdot
.36731 .56744 Mdot
.39266 .61425 Mdot
.57132 .69533 Mdot
.58483 .62836 Mdot
.4251 .5798 Mdot
.33921 .70124 Mdot
.38197 .55154 Mdot
.64479 .38282 Mdot
.57434 .68498 Mdot
.56756 .65904 Mdot
.44952 .3435 Mdot
.58212 .69339 Mdot
.31997 .61036 Mdot
.69347 .41483 Mdot
.36853 .62758 Mdot
.65908 .39963 Mdot
.40371 .41902 Mdot
.49384 .36112 Mdot
.81315 .43585 Mdot
.57448 .69005 Mdot
.3668 .54821 Mdot
.61528 .67888 Mdot
.37709 .35821 Mdot
.57204 .67549 Mdot
.62157 .68592 Mdot
.41491 .60365 Mdot
.43753 .57519 Mdot
.67325 .58402 Mdot
.5924 .50216 Mdot
.59348 .66357 Mdot
.37628 .54776 Mdot
.34315 .58308 Mdot
.44249 .57843 Mdot
.55645 .45455 Mdot
.54704 .65536 Mdot
.29163 .67225 Mdot
.65099 .24743 Mdot
.59506 .65724 Mdot
.85072 .48321 Mdot
.6845 .59207 Mdot
.68923 .56452 Mdot
.6859 .40572 Mdot
.40057 .59077 Mdot
.50164 .33043 Mdot
.37657 .53303 Mdot
.46559 .59155 Mdot
.3905 .60458 Mdot
.35753 .33325 Mdot
.40093 .5128 Mdot
.69043 .58352 Mdot
.4944 .33747 Mdot
.38254 .5455 Mdot
.41287 .58855 Mdot
.69723 .56561 Mdot
.63441 .66243 Mdot
.55963 .67738 Mdot
.68025 .54601 Mdot
.38137 .35043 Mdot
.63345 .37712 Mdot
.38457 .52769 Mdot
.49291 .35051 Mdot
.49478 .33152 Mdot
.61001 .64207 Mdot
.46569 .33022 Mdot
.62724 .38319 Mdot
.38501 .55627 Mdot
.68145 .39765 Mdot
.35818 .3335 Mdot
.56496 .6458 Mdot
.39247 .52348 Mdot
.43133 .55299 Mdot
.60252 .66123 Mdot
.42183 .56444 Mdot
.34952 .33066 Mdot
.46128 .31545 Mdot
.5797 .68347 Mdot
.64754 .40346 Mdot
.44919 .33899 Mdot
.41589 .54888 Mdot
.77338 .29497 Mdot
.40509 .56109 Mdot
.3621 .57498 Mdot
.77508 .64231 Mdot
.34454 .60516 Mdot
.51524 .35998 Mdot
.61448 .68216 Mdot
.43694 .6025 Mdot
.28663 .34409 Mdot
.42898 .29585 Mdot
.45324 .36632 Mdot
.36869 .57465 Mdot
.83808 .48642 Mdot
.36963 .54527 Mdot
.81241 .47749 Mdot
.57163 .4817 Mdot
.52827 .17883 Mdot
.31096 .57863 Mdot
.6838 .4021 Mdot
.67044 .58447 Mdot
.52131 .35819 Mdot
.47153 .80226 Mdot
.41422 .56274 Mdot
.57159 .77694 Mdot
.38139 .52798 Mdot
.65068 .38383 Mdot
.48876 .60688 Mdot
.46809 .3248 Mdot
.30396 .73383 Mdot
.41947 .52514 Mdot
.55004 .66691 Mdot
.54251 .34397 Mdot
.67124 .59213 Mdot
.43996 .55713 Mdot
.3729 .37272 Mdot
.44576 .29544 Mdot
.31988 .59984 Mdot
.65757 .4015 Mdot
.39182 .59638 Mdot
.46895 .61893 Mdot
.14558 .44596 Mdot
.58709 .67795 Mdot
.67759 .39319 Mdot
.50385 .55025 Mdot
.43189 .5903 Mdot
.55815 .67574 Mdot
.57177 .66068 Mdot
.37854 .37365 Mdot
.64232 .49943 Mdot
.40556 .30309 Mdot
.7076 .26595 Mdot
.5445 .77527 Mdot
.4481 .32229 Mdot
.66276 .71894 Mdot
.40359 .53114 Mdot
.25794 .57774 Mdot
.66667 .40869 Mdot
.40256 .56801 Mdot
.52274 .75109 Mdot
.58066 .67678 Mdot
.38949 .58238 Mdot
.34628 .33945 Mdot
.71895 .6033 Mdot
.29954 .63553 Mdot
.79664 .34648 Mdot
.52675 .36758 Mdot
.39324 .63404 Mdot
.31976 .58234 Mdot
.6593 .58567 Mdot
.42757 .60953 Mdot
.52165 .35469 Mdot
.63522 .27108 Mdot
.33902 .35774 Mdot
.58801 .69121 Mdot
.68033 .59368 Mdot
.37277 .53228 Mdot
.35112 .60545 Mdot
.33798 .37207 Mdot
.43453 .54182 Mdot
.34418 .74938 Mdot
.69774 .55991 Mdot
.45869 .32176 Mdot
.55147 .64949 Mdot
.37396 .60666 Mdot
.66755 .58698 Mdot
.41875 .60111 Mdot
.4273 .48076 Mdot
.36935 .58017 Mdot
.73476 .69036 Mdot
.59877 .65325 Mdot
.6561 .40549 Mdot
.3923 .5125 Mdot
.40139 .57959 Mdot
.44792 .23986 Mdot
.46623 .58852 Mdot
.40497 .60155 Mdot
.5963 .63021 Mdot
.60183 .68953 Mdot
.60354 .63991 Mdot
.45496 .32882 Mdot
.59196 .52278 Mdot
.64886 .3896 Mdot
.44107 .6136 Mdot
.65451 .36211 Mdot
.34501 .50976 Mdot
.346 .37758 Mdot
.80714 .40514 Mdot
.39586 .55322 Mdot
.58704 .63701 Mdot
.66087 .74668 Mdot
.54788 .63936 Mdot
.61671 .42117 Mdot
.66069 .40939 Mdot
.58768 .66755 Mdot
.38264 .56594 Mdot
.58241 .52167 Mdot
.76766 .30357 Mdot
.63857 .4042 Mdot
.39951 .62731 Mdot
.53159 .36466 Mdot
.53673 .33479 Mdot
.85 .54169 Mdot
.66988 .4102 Mdot
.69025 .64249 Mdot
.37487 .54455 Mdot
.59304 .6928 Mdot
.64434 .36964 Mdot
.6555 .41639 Mdot
.46101 .33615 Mdot
.43174 .56117 Mdot
.39847 .57991 Mdot
.69722 .57806 Mdot
.65887 .36531 Mdot
.44321 .51458 Mdot
.43129 .56681 Mdot
.78955 .60286 Mdot
.53306 .66646 Mdot
.16934 .61548 Mdot
.47567 .58267 Mdot
.52866 .74919 Mdot
.45463 .43607 Mdot
.58796 .68649 Mdot
.43135 .53287 Mdot
.44489 .61122 Mdot
.44651 .32842 Mdot
.39102 .55672 Mdot
.47512 .36337 Mdot
.67634 .40554 Mdot
.81445 .40838 Mdot
.66024 .32958 Mdot
.70025 .4037 Mdot
.40961 .56493 Mdot
.29922 .62712 Mdot
.37159 .34758 Mdot
.61702 .37934 Mdot
.6147 .66079 Mdot
.36986 .60755 Mdot
.44146 .32785 Mdot
.45917 .32554 Mdot
.57548 .6662 Mdot
.69896 .66271 Mdot
.81124 .45166 Mdot
.42745 .6034 Mdot
.51741 .33168 Mdot
.70204 .33656 Mdot
.37277 .69329 Mdot
.67605 .41675 Mdot
.3386 .35397 Mdot
.50874 .36228 Mdot
.62389 .41622 Mdot
.40706 .47808 Mdot
.58259 .66106 Mdot
.56593 .69093 Mdot
.491 .23929 Mdot
.48783 .32519 Mdot
.36212 .34464 Mdot
.43614 .44428 Mdot
.44543 .45063 Mdot
.34768 .33566 Mdot
.49334 .36806 Mdot
.59357 .6891 Mdot
.605 .64463 Mdot
.56993 .65928 Mdot
.32328 .7404 Mdot
.62246 .656 Mdot
.21273 .61914 Mdot
.39408 .61692 Mdot
.36224 .72031 Mdot
.36425 .55591 Mdot
.67206 .36837 Mdot
.59622 .66785 Mdot
.57253 .49357 Mdot
.35278 .59306 Mdot
.78482 .33246 Mdot
.37552 .5781 Mdot
.57329 .37215 Mdot
.40245 .59115 Mdot
.37639 .76426 Mdot
.5503 .68717 Mdot
.37063 .55916 Mdot
.69174 .40986 Mdot
.35658 .36421 Mdot
.63349 .68283 Mdot
.40122 .60109 Mdot
.7445 .62634 Mdot
.33992 .60828 Mdot
.82726 .5058 Mdot
.39387 .22825 Mdot
.33048 .33874 Mdot
.35241 .62479 Mdot
.51813 .30941 Mdot
.50509 .60627 Mdot
.3691 .73273 Mdot
.63927 .40441 Mdot
.30804 .66394 Mdot
.45793 .33691 Mdot
.48523 .5824 Mdot
.44389 .5291 Mdot
.34063 .36482 Mdot
.61781 .70553 Mdot
.64589 .38087 Mdot
.41332 .56057 Mdot
.43618 .53918 Mdot
.60742 .20323 Mdot
.36665 .73802 Mdot
.42871 .50865 Mdot
.35366 .38642 Mdot
.30956 .67542 Mdot
.38836 .60193 Mdot
.4528 .36562 Mdot
.61837 .67887 Mdot
.34032 .63225 Mdot
.28708 .67307 Mdot
.37887 .54826 Mdot
.58396 .66862 Mdot
.57504 .6909 Mdot
.69211 .7446 Mdot
.34663 .37665 Mdot
.36971 .58065 Mdot
.46974 .23148 Mdot
.3956 .52364 Mdot
.64699 .3865 Mdot
.42797 .6114 Mdot
.4777 .35239 Mdot
.61236 .53046 Mdot
.45393 .33093 Mdot
.44315 .56924 Mdot
.58171 .64398 Mdot
.64279 .37865 Mdot
.53415 .22657 Mdot
.57772 .41751 Mdot
.21109 .61407 Mdot
.44114 .29868 Mdot
.36089 .37365 Mdot
.39039 .36445 Mdot
.6743 .43671 Mdot
.37337 .56982 Mdot
.56271 .4387 Mdot
.42534 .628 Mdot
.4042 .59491 Mdot
.36973 .59265 Mdot
.6797 .34778 Mdot
.65875 .40904 Mdot
.4789 .33163 Mdot
.42527 .57844 Mdot
.37529 .54831 Mdot
.59096 .65536 Mdot
.34966 .36315 Mdot
.46629 .31418 Mdot
.38012 .35113 Mdot
.49154 .3413 Mdot
.83967 .57357 Mdot
.42532 .61548 Mdot
.358 .36426 Mdot
.62165 .39093 Mdot
.59312 .63548 Mdot
.69485 .56678 Mdot
.51473 .33539 Mdot
.47116 .32377 Mdot
.36605 .56085 Mdot
.55699 .65611 Mdot
.55658 .66836 Mdot
.36179 .37542 Mdot
.66198 .37023 Mdot
.44982 .57424 Mdot
.43528 .57265 Mdot
.49973 .20125 Mdot
.44855 .32851 Mdot
.32286 .69467 Mdot
.70296 .715 Mdot
.37277 .56836 Mdot
.55529 .66948 Mdot
.41153 .5801 Mdot
.69933 .30887 Mdot
.59282 .63253 Mdot
.34623 .58393 Mdot
.35381 .47153 Mdot
.45622 .31623 Mdot
.68199 .77079 Mdot
.35658 .53942 Mdot
.58878 .3888 Mdot
.4202 .53739 Mdot
.7166 .77555 Mdot
.64234 .75028 Mdot
.38038 .52767 Mdot
.42847 .60087 Mdot
.70151 .24893 Mdot
.37596 .54064 Mdot
.69247 .58386 Mdot
.47182 .57868 Mdot
.55772 .67614 Mdot
.48684 .43247 Mdot
.58499 .47407 Mdot
.36142 .38295 Mdot
.49608 .35261 Mdot
.23495 .47644 Mdot
.38616 .3596 Mdot
.60561 .67239 Mdot
.35367 .60315 Mdot
.57003 .73015 Mdot
.49462 .29848 Mdot
.45394 .55958 Mdot
.64792 .38542 Mdot
.58648 .47552 Mdot
.49896 .36473 Mdot
.64869 .4055 Mdot
.35675 .55668 Mdot
.29285 .27331 Mdot
.59703 .43177 Mdot
.72265 .73345 Mdot
.63616 .37829 Mdot
.66881 .40087 Mdot
.58945 .53758 Mdot
.36189 .38284 Mdot
.57958 .19801 Mdot
.36258 .66207 Mdot
.63487 .40429 Mdot
.29835 .44678 Mdot
.44963 .35609 Mdot
.63372 .50673 Mdot
.54475 .67894 Mdot
.42881 .6139 Mdot
.38625 .56922 Mdot
.65993 .37258 Mdot
.63109 .7342 Mdot
.47113 .49392 Mdot
.64615 .4083 Mdot
.32378 .56723 Mdot
.63996 .50743 Mdot
.67186 .5799 Mdot
.69271 .58708 Mdot
.37422 .38326 Mdot
.35259 .2918 Mdot
.59573 .64628 Mdot
.33429 .34472 Mdot
.63583 .58943 Mdot
.3735 .58531 Mdot
.65959 .36502 Mdot
.70147 .57152 Mdot
.64658 .39837 Mdot
.36548 .3604 Mdot
.33879 .37056 Mdot
.58878 .67589 Mdot
.60514 .68069 Mdot
.41642 .6733 Mdot
.32168 .42195 Mdot
.38406 .53278 Mdot
.57947 .75218 Mdot
.59776 .63418 Mdot
.43549 .80875 Mdot
.36013 .37917 Mdot
.34452 .35744 Mdot
.41643 .7278 Mdot
.42295 .55112 Mdot
.62522 .33455 Mdot
.39502 .60285 Mdot
.2669 .48045 Mdot
.35903 .54407 Mdot
.46237 .33488 Mdot
.41198 .52467 Mdot
.7208 .51255 Mdot
.39144 .54394 Mdot
.37728 .60105 Mdot
.51063 .33897 Mdot
.40063 .51001 Mdot
.47291 .35085 Mdot
.43963 .5852 Mdot
.33727 .32329 Mdot
.49324 .35038 Mdot
.29463 .34814 Mdot
.51151 .41034 Mdot
.67692 .58773 Mdot
.38193 .37764 Mdot
.37143 .37227 Mdot
.27006 .35477 Mdot
.61429 .66981 Mdot
.40509 .47371 Mdot
.37459 .57151 Mdot
.48141 .37291 Mdot
.6347 .37138 Mdot
.37776 .54928 Mdot
.37167 .63832 Mdot
.35365 .54239 Mdot
.58668 .673 Mdot
.49209 .36902 Mdot
.35839 .35789 Mdot
.5206 .32714 Mdot
.32422 .32403 Mdot
.53168 .33734 Mdot
.41647 .64556 Mdot
.47506 .56712 Mdot
.37407 .50099 Mdot
.55286 .75717 Mdot
.27762 .7156 Mdot
.57856 .66157 Mdot
.68357 .57703 Mdot
.3484 .37988 Mdot
.48756 .47955 Mdot
.58606 .63875 Mdot
.47674 .32195 Mdot
.39075 .57871 Mdot
.32603 .55798 Mdot
.33179 .65087 Mdot
.53632 .6834 Mdot
.30797 .39516 Mdot
.50881 .3504 Mdot
.68105 .57063 Mdot
.60473 .51924 Mdot
.55256 .60946 Mdot
.56716 .49226 Mdot
.40683 .58032 Mdot
.36839 .37567 Mdot
.57422 .68779 Mdot
.59154 .21923 Mdot
.66653 .37698 Mdot
.5905 .50563 Mdot
.40679 .56362 Mdot
.67394 .68298 Mdot
.58136 .6443 Mdot
.342 .35168 Mdot
.65952 .37279 Mdot
.3529 .37914 Mdot
.67459 .59598 Mdot
.67976 .53503 Mdot
.43658 .54793 Mdot
.40513 .6023 Mdot
.63001 .36925 Mdot
.5936 .64512 Mdot
.47521 .29321 Mdot
.62557 .21653 Mdot
.51489 .32867 Mdot
.57642 .44359 Mdot
.57525 .68679 Mdot
.6621 .67599 Mdot
.50431 .313 Mdot
.61874 .39753 Mdot
.56412 .44454 Mdot
.63323 .41776 Mdot
.3811 .60091 Mdot
.56304 .65498 Mdot
.66979 .41059 Mdot
.51721 .22125 Mdot
.82531 .56872 Mdot
.58743 .71667 Mdot
.42892 .57546 Mdot
.80813 .40321 Mdot
.76692 .58622 Mdot
.6282 .72182 Mdot
.67264 .37167 Mdot
.41955 .57846 Mdot
.42432 .60541 Mdot
.41751 .52438 Mdot
.67453 .3909 Mdot
.58188 .40163 Mdot
.47223 .31958 Mdot
.38245 .58451 Mdot
.37709 .36454 Mdot
.47333 .34712 Mdot
.52599 .31474 Mdot
.52271 .35667 Mdot
.59336 .63194 Mdot
.37721 .61566 Mdot
.60285 .58403 Mdot
.74846 .73349 Mdot
.6624 .4051 Mdot
.67732 .58775 Mdot
.36124 .58413 Mdot
.19247 .55378 Mdot
.60082 .63848 Mdot
.512 .32635 Mdot
.40456 .56909 Mdot
.41347 .22986 Mdot
.69828 .55519 Mdot
.50381 .34263 Mdot
.614 .66038 Mdot
.62722 .72128 Mdot
.39007 .55603 Mdot
.41876 .53805 Mdot
.60569 .65333 Mdot
.74163 .59782 Mdot
.61655 .51962 Mdot
.41146 .58225 Mdot
.65377 .40644 Mdot
.13685 .43993 Mdot
.34254 .59512 Mdot
.52633 .6687 Mdot
.66458 .58754 Mdot
.73387 .68118 Mdot
.32723 .69203 Mdot
.41477 .63972 Mdot
.77456 .35616 Mdot
.21954 .47967 Mdot
.82484 .4255 Mdot
.24166 .51571 Mdot
.72643 .35287 Mdot
.80787 .64088 Mdot
.6887 .41283 Mdot
.38717 .7677 Mdot
.60591 .1827 Mdot
.70487 .63504 Mdot
.34646 .2591 Mdot
.56147 .25046 Mdot
.42008 .22051 Mdot
.4081 .82653 Mdot
.53188 .33251 Mdot
.26136 .5142 Mdot
.44505 .55527 Mdot
.75766 .57859 Mdot
.33022 .72045 Mdot
.25415 .69745 Mdot
.80589 .40972 Mdot
.45373 .2303 Mdot
.74619 .26578 Mdot
.80565 .43006 Mdot
.47307 .65695 Mdot
.28146 .564 Mdot
.36463 .29938 Mdot
.43779 .44698 Mdot
.23013 .48735 Mdot
.30284 .57514 Mdot
.71878 .49876 Mdot
.69857 .38852 Mdot
.48544 .68012 Mdot
.14014 .47818 Mdot
.51807 .35252 Mdot
.61924 .67816 Mdot
.56776 .19279 Mdot
.51573 .64543 Mdot
.63605 .43765 Mdot
.77468 .35584 Mdot
.7912 .60808 Mdot
.37291 .76099 Mdot
.61981 .57458 Mdot
.43849 .76046 Mdot
.22721 .39252 Mdot
.27396 .56437 Mdot
.55539 .62559 Mdot
.57677 .29658 Mdot
.4434 .45059 Mdot
.36084 .30891 Mdot
.39202 .78114 Mdot
.39248 .36457 Mdot
.29291 .34764 Mdot
.61112 .65301 Mdot
.38392 .68994 Mdot
.68523 .56373 Mdot
.63687 .59773 Mdot
.43756 .33274 Mdot
.68779 .30092 Mdot
.73076 .59167 Mdot
.73583 .61982 Mdot
.61231 .79848 Mdot
.80125 .33303 Mdot
.25993 .41903 Mdot
.62402 .25439 Mdot
.60099 .41333 Mdot
.22632 .45944 Mdot
.5862 .56616 Mdot
.29307 .41591 Mdot
.39108 .46464 Mdot
.66647 .18433 Mdot
.75895 .61888 Mdot
.72784 .23846 Mdot
.59882 .6155 Mdot
.33676 .56411 Mdot
.64953 .26743 Mdot
.53425 .78516 Mdot
.36236 .31948 Mdot
.80183 .34101 Mdot
.33255 .35226 Mdot
.55973 .69786 Mdot
.70156 .63864 Mdot
.33706 .74005 Mdot
.48742 .29008 Mdot
.40186 .36603 Mdot
.33715 .62683 Mdot
.63836 .15326 Mdot
.76958 .34301 Mdot
.70475 .72804 Mdot
.78529 .60722 Mdot
.48115 .38073 Mdot
.51538 .30516 Mdot
.6737 .41045 Mdot
.81356 .60371 Mdot
.57183 .6477 Mdot
.75196 .73372 Mdot
.80896 .59933 Mdot
.51258 .59256 Mdot
.62293 .14416 Mdot
.50075 .84332 Mdot
.35599 .71545 Mdot
.24536 .61216 Mdot
.3566 .2258 Mdot
.57797 .55295 Mdot
.6615 .66284 Mdot
.52368 .37607 Mdot
.75938 .66242 Mdot
.83961 .55393 Mdot
.30432 .45165 Mdot
.72762 .38491 Mdot
.63476 .60381 Mdot
.39678 .42121 Mdot
.58705 .71078 Mdot
.32088 .27518 Mdot
.37048 .44092 Mdot
.74009 .25336 Mdot
.30521 .66786 Mdot
.1971 .34804 Mdot
.24523 .50024 Mdot
.37946 .7908 Mdot
.7635 .37878 Mdot
.42754 .37186 Mdot
.44151 .48137 Mdot
.72619 .64787 Mdot
.37949 .62653 Mdot
.55204 .53194 Mdot
.47346 .5338 Mdot
.32281 .35946 Mdot
.59228 .52934 Mdot
.79647 .51947 Mdot
.25127 .4785 Mdot
.69125 .26406 Mdot
.28582 .55867 Mdot
.55506 .64075 Mdot
.28174 .40521 Mdot
.27302 .44409 Mdot
.79455 .58487 Mdot
.50517 .55245 Mdot
.73497 .70924 Mdot
.49768 .5358 Mdot
.41235 .63394 Mdot
.39693 .77151 Mdot
.30789 .55797 Mdot
.29225 .43661 Mdot
.36098 .53631 Mdot
.62704 .78918 Mdot
.77504 .63321 Mdot
.52267 .72567 Mdot
.2449 .45838 Mdot
.54727 .74968 Mdot
.76278 .66233 Mdot
.65547 .26705 Mdot
.66525 .6543 Mdot
.64695 .72631 Mdot
.64754 .16174 Mdot
.47097 .33769 Mdot
.30862 .43978 Mdot
.65112 .34912 Mdot
.52425 .22641 Mdot
.58178 .1775 Mdot
.48382 .51229 Mdot
.77804 .65249 Mdot
.7206 .63052 Mdot
.50982 .29795 Mdot
.69844 .47681 Mdot
.69301 .34672 Mdot
.54875 .73472 Mdot
.34223 .56221 Mdot
.47237 .52362 Mdot
.34693 .33068 Mdot
.49852 .79203 Mdot
.64077 .2462 Mdot
.51079 .26957 Mdot
.3985 .64545 Mdot
.5394 .28022 Mdot
.68936 .56998 Mdot
.60312 .49417 Mdot
.84993 .55718 Mdot
.46833 .60753 Mdot
.47289 .84011 Mdot
.74873 .60278 Mdot
.57292 .45456 Mdot
.32272 .31342 Mdot
.68462 .71806 Mdot
.70609 .21309 Mdot
.79353 .64116 Mdot
.77569 .55456 Mdot
.80353 .3956 Mdot
.55789 .86031 Mdot
.53537 .16667 Mdot
.53524 .80674 Mdot
.65462 .34911 Mdot
.40874 .89537 Mdot
.51384 .31823 Mdot
.2569 .63313 Mdot
.5314 .78418 Mdot
.41149 .23718 Mdot
.51635 .65068 Mdot
.29415 .59042 Mdot
.41196 .32475 Mdot
.63073 .67306 Mdot
.35137 .63505 Mdot
.83129 .38876 Mdot
.6729 .18558 Mdot
.82384 .37302 Mdot
.68559 .53429 Mdot
.83164 .42529 Mdot
.67658 .21241 Mdot
.21489 .62509 Mdot
.59643 .19658 Mdot
.42879 .61045 Mdot
.33636 .44272 Mdot
.51943 .83656 Mdot
.44513 .30608 Mdot
.61806 .58925 Mdot
.53574 .6397 Mdot
.65342 .18437 Mdot
.85308 .55252 Mdot
.44155 .72832 Mdot
.42868 .6794 Mdot
.4773 .41692 Mdot
.3072 .42429 Mdot
.52694 .68895 Mdot
.72606 .48697 Mdot
.81627 .55126 Mdot
.66467 .20438 Mdot
.26805 .45514 Mdot
.56401 .25949 Mdot
.77351 .53847 Mdot
.52823 .8246 Mdot
.76568 .37088 Mdot
.56081 .18983 Mdot
.50305 .57461 Mdot
.63113 .62 Mdot
.47324 .49721 Mdot
.71191 .49022 Mdot
.65044 .30197 Mdot
.2457 .4266 Mdot
.47381 .35711 Mdot
.31369 .44677 Mdot
.52994 .4696 Mdot
.59368 .1941 Mdot
.23412 .42858 Mdot
.29948 .45934 Mdot
.78906 .54118 Mdot
.83054 .39823 Mdot
.74381 .6069 Mdot
.3218 .24362 Mdot
.76675 .41588 Mdot
.48593 .56519 Mdot
.37258 .5154 Mdot
.77222 .65534 Mdot
.85744 .44269 Mdot
.78125 .65024 Mdot
.67182 .6923 Mdot
.49241 .23401 Mdot
.63878 .42687 Mdot
.22709 .43146 Mdot
.52788 .28535 Mdot
.82199 .54825 Mdot
.51119 .48943 Mdot
.635 .42798 Mdot
.71237 .6092 Mdot
.42732 .66947 Mdot
.21047 .51624 Mdot
.46459 .68619 Mdot
.46216 .58038 Mdot
.36669 .70226 Mdot
.58328 .69909 Mdot
.67016 .68975 Mdot
.29753 .42223 Mdot
.47424 .34139 Mdot
.47956 .19346 Mdot
.5345 .69233 Mdot
.33417 .59027 Mdot
.63709 .27874 Mdot
.5908 .71131 Mdot
.5461 .75849 Mdot
.53799 .31896 Mdot
.81938 .61556 Mdot
.59565 .79826 Mdot
.53824 .70605 Mdot
.26904 .40822 Mdot
.49871 .20605 Mdot
.61782 .50934 Mdot
.65852 .35135 Mdot
.80388 .41319 Mdot
.52255 .41263 Mdot
.2794 .41156 Mdot
.35621 .70089 Mdot
.62785 .22498 Mdot
.42841 .6241 Mdot
.68323 .74023 Mdot
.21024 .60103 Mdot
.60636 .49014 Mdot
.52292 .64353 Mdot
.62253 .64699 Mdot
.32749 .7881 Mdot
.73264 .5139 Mdot
.53985 .59571 Mdot
.78208 .38515 Mdot
.66055 .41988 Mdot
.57307 .63067 Mdot
.30334 .46263 Mdot
.37264 .27209 Mdot
.35548 .68043 Mdot
.66071 .30335 Mdot
.48734 .65105 Mdot
.58066 .37155 Mdot
.79534 .38865 Mdot
.75576 .30423 Mdot
.14827 .42582 Mdot
.62781 .64289 Mdot
.59834 .23096 Mdot
.59171 .22783 Mdot
.55311 .62875 Mdot
.53235 .67827 Mdot
.2981 .62914 Mdot
.84439 .45671 Mdot
.49625 .47127 Mdot
.71687 .47711 Mdot
.56555 .44397 Mdot
.34537 .26447 Mdot
.60449 .21383 Mdot
.23349 .45676 Mdot
.75245 .35291 Mdot
.43873 .6867 Mdot
.40909 .18766 Mdot
.38804 .49577 Mdot
.25849 .63998 Mdot
.22694 .43128 Mdot
.29576 .51222 Mdot
.39996 .7846 Mdot
.8098 .5029 Mdot
.39134 .52623 Mdot
.81556 .34973 Mdot
.78982 .5778 Mdot
.5469 .53463 Mdot
.45 .37233 Mdot
.40233 .54109 Mdot
.38158 .61682 Mdot
.63125 .74248 Mdot
.71867 .6997 Mdot
.48138 .16073 Mdot
.25308 .49464 Mdot
.49224 .58515 Mdot
.34871 .70301 Mdot
.47378 .83992 Mdot
.66172 .28066 Mdot
.82505 .47368 Mdot
.52949 .48278 Mdot
.5333 .83117 Mdot
.7182 .44513 Mdot
.69609 .48876 Mdot
.76614 .40494 Mdot
.68448 .21883 Mdot
.40603 .65287 Mdot
.72099 .67878 Mdot
.57079 .20061 Mdot
.36225 .58453 Mdot
.699 .66346 Mdot
.77993 .39302 Mdot
.20898 .36166 Mdot
.57591 .56939 Mdot
.8577 .42466 Mdot
.41683 .4897 Mdot
.72982 .66234 Mdot
.59105 .17326 Mdot
.28508 .23625 Mdot
.70921 .50206 Mdot
.74853 .26489 Mdot
.68624 .47839 Mdot
.77549 .37556 Mdot
.68285 .40497 Mdot
.50218 .44392 Mdot
.58197 .76325 Mdot
.84592 .46338 Mdot
.40148 .28162 Mdot
.71671 .31153 Mdot
.61811 .75848 Mdot
.84696 .44407 Mdot
.37953 .47305 Mdot
.32451 .7814 Mdot
.42935 .34045 Mdot
.54597 .84011 Mdot
.55992 .80056 Mdot
.50601 .63143 Mdot
.29164 .45376 Mdot
.31283 .76293 Mdot
.23935 .66472 Mdot
.5522 .79643 Mdot
.30624 .47776 Mdot
.69236 .71694 Mdot
.26315 .40479 Mdot
.82351 .55475 Mdot
.38789 .81701 Mdot
.60318 .22168 Mdot
.67439 .61387 Mdot
.70242 .54905 Mdot
.71739 .70647 Mdot
.78319 .48855 Mdot
.64402 .27456 Mdot
.65545 .52226 Mdot
.47744 .65028 Mdot
.11266 .55514 Mdot
.67413 .46281 Mdot
.31687 .64355 Mdot
.70031 .21371 Mdot
.81294 .55586 Mdot
.50009 .48513 Mdot
.38274 .77862 Mdot
.20149 .53627 Mdot
.40033 .3972 Mdot
.39182 .60452 Mdot
.8445 .43795 Mdot
.41008 .36853 Mdot
.77012 .30187 Mdot
.73286 .73022 Mdot
.39806 .69911 Mdot
.44899 .63579 Mdot
.53124 .36997 Mdot
.27109 .59059 Mdot
.29567 .49122 Mdot
.70633 .22813 Mdot
.26012 .63882 Mdot
.5654 .41885 Mdot
.59404 .35824 Mdot
.66749 .32438 Mdot
.49244 .61947 Mdot
.52374 .83851 Mdot
.70652 .7048 Mdot
.24084 .48411 Mdot
.76634 .54394 Mdot
.3018 .43673 Mdot
.32736 .69387 Mdot
.23248 .4176 Mdot
.52663 .53799 Mdot
.39919 .32291 Mdot
.44631 .33834 Mdot
.69333 .24808 Mdot
.79902 .43379 Mdot
.6357 .78142 Mdot
.32984 .24027 Mdot
.72276 .65216 Mdot
.26595 .5218 Mdot
.66498 .25147 Mdot
.5688 .55779 Mdot
.39763 .29354 Mdot
.21596 .53239 Mdot
.30792 .66673 Mdot
.81791 .48887 Mdot
.29194 .5515 Mdot
.84172 .5547 Mdot
.24391 .43196 Mdot
.65165 .22016 Mdot
.47266 .42019 Mdot
.50865 .77563 Mdot
.38999 .74102 Mdot
.37746 .21521 Mdot
.60289 .48721 Mdot
.64031 .15554 Mdot
.54322 .6452 Mdot
.79819 .32927 Mdot
.63251 .37981 Mdot
.16164 .43532 Mdot
.81884 .51999 Mdot
.55012 .49848 Mdot
.54457 .4461 Mdot
.68302 .74428 Mdot
.73835 .60777 Mdot
.74904 .60787 Mdot
.47767 .50489 Mdot
.52273 .36031 Mdot
.57179 .40934 Mdot
.72274 .47598 Mdot
.70909 .27534 Mdot
.44423 .58923 Mdot
.50343 .29347 Mdot
.28332 .53268 Mdot
.61449 .36218 Mdot
.77011 .64248 Mdot
.8066 .47049 Mdot
.30703 .57921 Mdot
.30739 .42174 Mdot
.67311 .20421 Mdot
.80577 .58678 Mdot
.46943 .48656 Mdot
.46422 .52218 Mdot
.60521 .42682 Mdot
.51179 .18221 Mdot
.75609 .32859 Mdot
.64583 .33115 Mdot
.62825 .51819 Mdot
.26057 .42221 Mdot
.86574 .4081 Mdot
.66937 .18466 Mdot
.36601 .20796 Mdot
.56531 .44058 Mdot
.60796 .61483 Mdot
.19739 .55935 Mdot
.65535 .22325 Mdot
.5582 .83804 Mdot
.78292 .56628 Mdot
.30374 .44085 Mdot
.23007 .33483 Mdot
.27852 .70556 Mdot
.55724 .40507 Mdot
.39168 .74208 Mdot
.55018 .76885 Mdot
.61139 .412 Mdot
.40031 .40254 Mdot
.53745 .42233 Mdot
.63467 .43883 Mdot
.69505 .71504 Mdot
.73323 .6122 Mdot
.64868 .21737 Mdot
.26557 .65592 Mdot
.46139 .5187 Mdot
.70851 .2877 Mdot
.57443 .70653 Mdot
.58862 .22141 Mdot
.50907 .20264 Mdot
.54977 .41749 Mdot
.52336 .32585 Mdot
.31589 .61369 Mdot
.62037 .49126 Mdot
.69287 .46941 Mdot
.26871 .29775 Mdot
.34534 .32519 Mdot
.57064 .61758 Mdot
.28891 .72616 Mdot
.62067 .63229 Mdot
.8726 .47826 Mdot
.72847 .48584 Mdot
.35902 .70587 Mdot
.72075 .43136 Mdot
.5788 .27525 Mdot
.2777 .26794 Mdot
.46309 .6597 Mdot
.29557 .33559 Mdot
.57815 .61107 Mdot
.58642 .6982 Mdot
.73646 .41178 Mdot
.67323 .56418 Mdot
.4075 .68519 Mdot
.43888 .83506 Mdot
.49572 .20513 Mdot
.61142 .62464 Mdot
.56644 .37884 Mdot
.60275 .72087 Mdot
.84675 .56483 Mdot
.52363 .33306 Mdot
.65657 .16812 Mdot
.47715 .57498 Mdot
.50075 .17725 Mdot
.7729 .64882 Mdot
.61012 .53532 Mdot
.56723 .43633 Mdot
.5358 .24274 Mdot
.40741 .63235 Mdot
.49453 .58838 Mdot
.61171 .67206 Mdot
.60719 .2 Mdot
.34778 .35542 Mdot
.30684 .40141 Mdot
.68326 .3612 Mdot
.43052 .81679 Mdot
.55254 .82515 Mdot
.5894 .69952 Mdot
.51326 .39994 Mdot
.58596 .23409 Mdot
.34942 .47174 Mdot
.28719 .52438 Mdot
.69618 .24527 Mdot
.43671 .67346 Mdot
.54449 .64495 Mdot
.36214 .21218 Mdot
.37221 .43894 Mdot
.80024 .64589 Mdot
.35399 .49905 Mdot
.27339 .57478 Mdot
.29418 .52529 Mdot
.68054 .73314 Mdot
.32578 .69016 Mdot
.82874 .50299 Mdot
.28541 .40813 Mdot
.41104 .4494 Mdot
.30286 .45767 Mdot
.30567 .58428 Mdot
.63026 .34189 Mdot
.52467 .84548 Mdot
.23517 .3285 Mdot
.43213 .76546 Mdot
.59165 .57392 Mdot
.51952 .64516 Mdot
.48276 .84036 Mdot
.55506 .6232 Mdot
.31464 .34319 Mdot
.493 .68495 Mdot
.81808 .52277 Mdot
.81795 .59487 Mdot
.79396 .58511 Mdot
.26978 .59617 Mdot
.6695 .32636 Mdot
.22898 .57351 Mdot
.4261 .48724 Mdot
.55777 .49503 Mdot
.38502 .63735 Mdot
.49073 .60136 Mdot
.50652 .50182 Mdot
.65805 .75205 Mdot
.46358 .63323 Mdot
.84104 .46067 Mdot
.79884 .64319 Mdot
.82142 .3994 Mdot
.64746 .29956 Mdot
.62593 .66863 Mdot
.69482 .20381 Mdot
.28556 .68811 Mdot
.81896 .56466 Mdot
.5517 .80423 Mdot
.34947 .80706 Mdot
.60101 .17697 Mdot
.80191 .51734 Mdot
.59796 .60102 Mdot
.6868 .76906 Mdot
.76181 .61694 Mdot
.32838 .78333 Mdot
.30416 .65626 Mdot
.7692 .64881 Mdot
.62834 .15256 Mdot
.49797 .81648 Mdot
.73963 .6181 Mdot
.38229 .74029 Mdot
.31623 .66254 Mdot
.39985 .81771 Mdot
.38365 .6207 Mdot
.52569 .31881 Mdot
.38413 .23644 Mdot
.29249 .44732 Mdot
.30653 .6024 Mdot
.38169 .80827 Mdot
.29263 .49616 Mdot
.26056 .5208 Mdot
.52354 .23081 Mdot
.60545 .1814 Mdot
.34217 .68917 Mdot
.32004 .57993 Mdot
.53144 .64286 Mdot
.38847 .36173 Mdot
.23062 .52025 Mdot
.40967 .5502 Mdot
.58301 .48095 Mdot
.37157 .65763 Mdot
.83934 .39808 Mdot
.36662 .26163 Mdot
.69531 .42132 Mdot
.62784 .6527 Mdot
.70821 .71281 Mdot
.68695 .28793 Mdot
.70362 .63564 Mdot
.36012 .7926 Mdot
.39367 .67757 Mdot
.78902 .37704 Mdot
.72741 .63321 Mdot
.25437 .44758 Mdot
.24567 .35963 Mdot
.6821 .37659 Mdot
.5656 .77298 Mdot
.70295 .22915 Mdot
.7082 .66475 Mdot
.56102 .70042 Mdot
.77469 .52145 Mdot
.61637 .34818 Mdot
.70326 .6836 Mdot
.74744 .60115 Mdot
.62536 .23382 Mdot
.40134 .71436 Mdot
.75305 .30603 Mdot
.53867 .35833 Mdot
.27228 .4593 Mdot
.74863 .51588 Mdot
.40017 .81995 Mdot
.34798 .47372 Mdot
.84334 .52279 Mdot
.55051 .48834 Mdot
.3136 .38928 Mdot
.43195 .54647 Mdot
.2838 .67061 Mdot
.66863 .73659 Mdot
.76347 .53486 Mdot
.51497 .58127 Mdot
.60243 .70144 Mdot
.60876 .79757 Mdot
.44032 .36627 Mdot
.41243 .37645 Mdot
.25197 .61128 Mdot
.6587 .70216 Mdot
.32039 .37227 Mdot
.71312 .58557 Mdot
.47113 .55191 Mdot
.28973 .32143 Mdot
.66085 .31671 Mdot
.57592 .77345 Mdot
.52761 .80959 Mdot
.69777 .2513 Mdot
.66053 .29633 Mdot
.62039 .79748 Mdot
.58275 .78321 Mdot
.74029 .68152 Mdot
.27943 .6976 Mdot
.60551 .59694 Mdot
.34657 .55775 Mdot
.31472 .3435 Mdot
.55336 .63228 Mdot
.71517 .27746 Mdot
.47929 .53 Mdot
.30457 .37323 Mdot
.54466 .51456 Mdot
.6461 .26685 Mdot
.44612 .42063 Mdot
.77032 .6381 Mdot
.68664 .76942 Mdot
.29651 .42107 Mdot
.68787 .37612 Mdot
.69594 .474 Mdot
.56723 .56884 Mdot
.84128 .48884 Mdot
.49876 .50683 Mdot
.56897 .73105 Mdot
.67034 .60728 Mdot
.52638 .74665 Mdot
.75242 .69607 Mdot
.32583 .4209 Mdot
.56432 .49737 Mdot
.54229 .70668 Mdot
.62254 .58846 Mdot
.69367 .5662 Mdot
.40334 .24479 Mdot
.28019 .67871 Mdot
.72124 .40101 Mdot
.5844 .4287 Mdot
.45238 .52081 Mdot
.19873 .56394 Mdot
.74459 .30429 Mdot
.48858 .48118 Mdot
.54425 .48815 Mdot
.56749 .2023 Mdot
.3978 .38679 Mdot
.12409 .46604 Mdot
.82809 .36806 Mdot
.43112 .54657 Mdot
.53213 .44039 Mdot
.31523 .40967 Mdot
.47782 .36458 Mdot
.46278 .68253 Mdot
.70628 .2593 Mdot
.65561 .41412 Mdot
.50862 .22824 Mdot
.7168 .57381 Mdot
.67594 .74746 Mdot
.41012 .19609 Mdot
.62732 .42435 Mdot
.87326 .47156 Mdot
.77909 .56814 Mdot
.67181 .72074 Mdot
.11164 .50006 Mdot
.65403 .74818 Mdot
.3961 .46854 Mdot
.50814 .23912 Mdot
.83806 .40697 Mdot
.57023 .44293 Mdot
.49405 .23813 Mdot
.51078 .81178 Mdot
.29184 .41685 Mdot
.26106 .48278 Mdot
.67959 .61551 Mdot
.63612 .76864 Mdot
.3038 .77124 Mdot
.57938 .2737 Mdot
.29765 .24938 Mdot
.403 .69064 Mdot
.76962 .317 Mdot
.70966 .50061 Mdot
.22443 .34656 Mdot
.81369 .60085 Mdot
.32852 .45163 Mdot
.39318 .80813 Mdot
.36905 .28432 Mdot
.28278 .35478 Mdot
.19351 .56482 Mdot
.66874 .52833 Mdot
.44859 .66981 Mdot
.55801 .27223 Mdot
.52604 .58407 Mdot
.30844 .45158 Mdot
.53322 .76189 Mdot
.56314 .49516 Mdot
.7292 .25803 Mdot
.32965 .76448 Mdot
.27092 .41575 Mdot
.54926 .21223 Mdot
.28764 .3561 Mdot
.7283 .30135 Mdot
.70597 .32187 Mdot
.35882 .46009 Mdot
.54487 .14893 Mdot
.74 .2537 Mdot
.60934 .59691 Mdot
.38786 .61744 Mdot
.8046 .64547 Mdot
.40614 .42979 Mdot
.53488 .80508 Mdot
.74104 .57307 Mdot
.25127 .50093 Mdot
.41194 .65483 Mdot
.33948 .58585 Mdot
.23518 .59697 Mdot
.57891 .60025 Mdot
.5383 .76344 Mdot
.45066 .1921 Mdot
.27254 .41112 Mdot
.33773 .76658 Mdot
.41869 .18658 Mdot
.34936 .50135 Mdot
.55814 .67862 Mdot
.83844 .40302 Mdot
.51213 .68054 Mdot
.4648 .51754 Mdot
.37239 .72011 Mdot
.48699 .49997 Mdot
.42671 .29041 Mdot
.46179 .52023 Mdot
.6166 .50758 Mdot
.2892 .45437 Mdot
.66548 .23421 Mdot
.58976 .76023 Mdot
.62769 .14307 Mdot
.77534 .65664 Mdot
.61539 .62521 Mdot
.515 .80377 Mdot
.54529 .41445 Mdot
.81399 .38889 Mdot
.55506 .25984 Mdot
.50206 .205 Mdot
.27216 .72331 Mdot
.27719 .37318 Mdot
.40117 .51629 Mdot
.6878 .53519 Mdot
.82846 .57826 Mdot
.28345 .73866 Mdot
.84145 .55328 Mdot
.4509 .63732 Mdot
.35947 .52544 Mdot
.24212 .26628 Mdot
.78383 .38094 Mdot
.44131 .6287 Mdot
.54155 .60038 Mdot
.52032 .60521 Mdot
.4462 .57119 Mdot
.67497 .56022 Mdot
.22364 .49659 Mdot
.26251 .49021 Mdot
.84273 .45558 Mdot
.61387 .63384 Mdot
.57653 .45461 Mdot
.61837 .37261 Mdot
.56448 .45746 Mdot
.31462 .56507 Mdot
.65525 .41964 Mdot
.26535 .49783 Mdot
.4301 .43231 Mdot
.47576 .27915 Mdot
.4309 .66476 Mdot
.63709 .52939 Mdot
.46849 .64991 Mdot
.26568 .55963 Mdot
.6572 .66887 Mdot
.23748 .66305 Mdot
.29189 .4959 Mdot
.33829 .46423 Mdot
.76534 .63682 Mdot
.52827 .86272 Mdot
.59106 .47122 Mdot
.64856 .69096 Mdot
.37702 .48004 Mdot
.29853 .68744 Mdot
.38578 .71639 Mdot
.44514 .29923 Mdot
.67601 .57053 Mdot
.4691 .62629 Mdot
.5398 .70713 Mdot
.64435 .4246 Mdot
.86284 .41505 Mdot
.33596 .5854 Mdot
.44604 .69782 Mdot
.83603 .5085 Mdot
.59361 .21869 Mdot
.30341 .64951 Mdot
.37849 .6372 Mdot
.42972 .45478 Mdot
.42389 .43083 Mdot
.59734 .72938 Mdot
.60389 .20991 Mdot
.77536 .34508 Mdot
.25837 .60289 Mdot
.42582 .69867 Mdot
.37391 .57609 Mdot
.32729 .34515 Mdot
.60428 .50323 Mdot
.26599 .3155 Mdot
.3564 .40525 Mdot
.80318 .58228 Mdot
.26856 .53863 Mdot
.25263 .49475 Mdot
.36025 .7349 Mdot
.78376 .31686 Mdot
.57822 .57555 Mdot
.39093 .70103 Mdot
.52808 .52535 Mdot
.78604 .49429 Mdot
.30343 .47946 Mdot
.72721 .37515 Mdot
.48334 .61864 Mdot
.55629 .60039 Mdot
.86213 .5027 Mdot
.47172 .65794 Mdot
.69625 .36486 Mdot
.81919 .48851 Mdot
.28679 .70028 Mdot
.54355 .44671 Mdot
.10665 .52616 Mdot
.54938 .25221 Mdot
.86944 .46125 Mdot
.6457 .23117 Mdot
.31561 .50462 Mdot
.69108 .71448 Mdot
.36335 .6427 Mdot
.50401 .33426 Mdot
.79938 .37203 Mdot
.52325 .67274 Mdot
.6237 .60165 Mdot
.41796 .61744 Mdot
.46578 .45869 Mdot
.5768 .72533 Mdot
.72891 .34859 Mdot
.53709 .33368 Mdot
.47399 .49039 Mdot
.7234 .33123 Mdot
.42217 .43012 Mdot
.3806 .82764 Mdot
.70816 .22902 Mdot
.80641 .41746 Mdot
.65733 .3224 Mdot
.16068 .41776 Mdot
.55306 .61425 Mdot
.54446 .69929 Mdot
.69324 .40226 Mdot
.23047 .58208 Mdot
.70454 .67563 Mdot
.65368 .22588 Mdot
.72656 .7081 Mdot
.34645 .47362 Mdot
.11774 .58781 Mdot
.31614 .45689 Mdot
.46934 .47172 Mdot
.69129 .67755 Mdot
.84392 .4724 Mdot
.48581 .22255 Mdot
.72205 .73416 Mdot
.72312 .50094 Mdot
.3077 .58772 Mdot
.21807 .61025 Mdot
.36954 .21117 Mdot
.61172 .34509 Mdot
.29208 .25261 Mdot
.76701 .3846 Mdot
.23061 .48618 Mdot
.75903 .53308 Mdot
.62745 .6406 Mdot
.50126 .59208 Mdot
.73161 .47963 Mdot
.61616 .58915 Mdot
.63328 .7342 Mdot
.77208 .34945 Mdot
.2135 .42883 Mdot
.53932 .19672 Mdot
.81036 .40084 Mdot
.60503 .36921 Mdot
.51618 .62574 Mdot
.28467 .5056 Mdot
.37301 .39693 Mdot
.46236 .35285 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0X?ooool2o`000:Oooooo000Looooo`03o`00
0?oooooooooo0:3ooooo0_l0002Wooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0aoooool3o`00
07oooooo000Looooo`03o`000?oooooooooo0<Oooooo0ol0001oooooo`007?ooool00ol0003ooooo
ooooo`2]ooooo`;o00005_ooool2o`0008;ooooo000Looooo`;o0000[_ooool2o`0000Gooooo0_l0
000?ooooo`;o000000?oooooo`000?l000000_ooool2o`0007_ooooo000Looooo`03o`000?oooooo
oooo0;Cooooo0_l0000Booooo`;o00000_ooool2o`0007_ooooo000Looooo`03o`000?oooooooooo
09kooooo0_l0000Dooooo`;o00005_ooool2o`0007_ooooo000Looooo`03o`000?oooooooooo09Wo
oooo0_l00003ooooo`;o00003?ooool2o`0000Kooooo0_l00004ooooo`;o00004oooool2o`0007So
oooo000Looooo`03o`000?oooooooooo09Wooooo0_l0000Aooooo`;o00003?ooool2o`0001?ooooo
0_l0001hooooo`007?ooool00ol0003oooooooooo`2Xooooo`Co00009Oooool2o`0007Kooooo000L
ooooo`03o`000?oooooooooo0:Sooooo1?l0000<ooooo`;o00001?ooool2o`00017ooooo0_l0001f
ooooo`007?ooool00ol0003oooooooooo`2Kooooo`;o00001_ooool2o`0001;ooooo0ol00002oooo
o`Co0000ROooool001cooooo00?o0000ooooooooool0Voooool2o`0000;ooooo0_l00002ooooo`;o
00000_ooool2o`0000kooooo1?l000001?oooooo0000o`000?ooool2o`0008Sooooo000Looooo`03
o`000?oooooooooo09oooooo0_l00006ooooo`?o00003oooool2o`0000Cooooo1?l00026ooooo`00
7?ooool00ol0003oooooooooo`2Rooooo`;o00001?ooool2o`00017ooooo1?l00002ooooo`;o0000
3Oooool2o`0000?ooooo0_l0001booooo`007?ooool00ol0003oooooooooo`21ooooo`;o000000?o
ooooo`000?l000007?ooool2o`0001Cooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l0
000=ooooo`;o00000oooool4o`00073ooooo000Looooo`03o`000?oooooooooo087ooooo0_l00000
0ooooooo0000o`000002ooooo`;o00007?ooool2o`0000[ooooo0_l00004ooooo`;o00007?ooool3
o`00073ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_oo
ool00ol0003oooooooooo`28ooooo`;o00001Oooool2o`0000Oooooo0_l00002ooooo`;o00002?oo
ool2o`0000Gooooo0_l00003ooooo`;o000000?oooooo`000?l000001oooool2o`0001_ooooo0_l0
001/ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Q
onk^k_ooooooA4A400Kooooo00?o0000ooooooooool0POooool3o`0000;ooooo0_l00004ooooo`;o
000000?oooooo`000?l000001oooool2o`0000;ooooo0_l0000=ooooo`Co00001_ooool3o`0000Go
oooo0ol000000ooooooo0000o`00000Hooooo`;o0000K?ooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo087ooooo
0ol00002ooooo`;o00001?ooool2o`0000oooooo0_l00006ooooo`?o00000oooool2o`0000Wooooo
1?l00003ooooo`?o000000?oooooo`000?l000000_l00004ooooo`;o0000O_ooool00003ooooool0
003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06ooooo`?o0000Oooo
ool2o`0001cooooo1?l000001?oooooo0000o`000?ooool3o`0000gooooo1Ol00006ooooo`Go0000
1?ooool2o`0007kooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?o
MgMgofIVI_ooool01Oooool00ol0003oooooooooo`1]ooooo`;o00004?ooool2o`0001cooooo1?l0
00000ooooooo0000o`00000Aooooo`?o00002?ooool4o`0000Kooooo0_l00008ooooo`;o000000?o
ooooo`000?l000001Oooool2o`0006Wooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooo
oooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1]ooooo`;o00001?ooool2
o`0002Sooooo1_l0000Oooooo`;o00001_ooool2o`0000Sooooo0_l000000ooooooo0000o`000005
ooooo`;o0000JOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooo
oonHV9So410@00Kooooo00?o0000ooooooooool0L_ooool4o`0000Cooooo0_l0000Uooooo`Co0000
2_ooool2o`0000[ooooo0_l00003ooooo`;o0000Qoooool00006ooooooo^k^ko<S8bo`000?lb<S;o
k^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0L_ooool4o`00
0004ooooool0003o0000ooooo`;o00001oooool2o`0001cooooo2?l000000ooooooo0000o`000003
ooooo`;o00002_ooool2o`0000?ooooo1?l00009ooooo`;o00002Oooool2o`0000Kooooo1?l0001U
ooooo`007?ooool00ol0003oooooooooo`1gooooo`;o00002_ooool2o`0001kooooo1_l000000ooo
oooo0000o`00000Eooooo`?o00000oooool2o`0000Cooooo1?l00007ooooo`;o00001_ooool5o`00
06Cooooo000Looooo`03o`000?oooooooooo08Gooooo0_l0000Booooo`;o00002?ooool3o`0001Go
oooo1?l00008ooooo`;o00001?ooool5o`0000Wooooo0_l00006ooooo`;o0000I?ooool001cooooo
00?o0000ooooooooool0QOooool2o`0001;ooooo0ol00008ooooo`;o00005Oooool4o`000004oooo
ool0003o0000o`0000gooooo0ol00008ooooo`;o0000K?ooool001cooooo00?o0000ooooooooool0
L?ooool2o`0000_ooooo1Ol0000Hooooo`;o00002oooool2o`000003ooooool0003o0000013ooooo
0ol000001?oooooo0000o`000?l00005ooooo`;o00001oooool2o`0007Kooooo000Looooo`03o`00
0?oooooooooo05cooooo0_l0000Booooo`;o00002_ooool6o`000003ooooool0003o000000Oooooo
0_l00002ooooo`;o00003oooool2o`0000?ooooo0ol000000ooooooo0000o`000002ooooo`;o0000
3?ooool3o`0000?ooooo0_l00004ooooo`;o00001oooool2o`0000kooooo0ol0001Uooooo`007?oo
ool00ol0003oooooooooo`1Looooo`;o00003Oooool2o`0000oooooo0_l00005ooooo`;o00001ooo
ool2o`0000;ooooo0_l00003ooooo`;o00002_ooool2o`0000?ooooo0_l00006ooooo`;o00003?oo
ool5o`000004ooooool0003o0000o`0000;ooooo0_l00005ooooo`;o00004Oooool3o`0006Gooooo
000Looooo`03o`000?oooooooooo05Wooooo0_l0000@ooooo`;o00003?ooool2o`0000[ooooo0_l0
000>ooooo`;o00001Oooool2o`0001gooooo0_l000001?oooooo0000o`000?l00002ooooo`;o0000
0_ooool2o`0000Gooooo1?l00002ooooo`;o0000Loooool001cooooo00?o0000ooooooooool0FOoo
ool2o`0001kooooo0_l00007ooooo`;o000000?oooooo`000?l000000oooool2o`000004ooooool0
003o0000o`0000cooooo0ol00002ooooo`;o00001Oooool2o`00017ooooo0_l0000Cooooo`;o0000
0_ooool2o`0001?ooooo0_l0001Nooooo`007?ooool00ol0003oooooooooo`1Wooooo`;o00001?oo
ool2o`0001?ooooo0_l00006ooooo`;o000000Coooooo`000?l0003o00003?ooool3o`0000;ooooo
0_l00005ooooo`Co000000Coooooo`000?l0003o00007?ooool2o`0001_ooooo0_l0001Nooooo`00
7?ooool00ol0003oooooooooo`1Uooooo`Co00001?ooool2o`00013ooooo0_l0000Yooooo`;o0000
00Coooooo`000?l0003o00002_ooool3o`0000Wooooo0_l00004ooooo`;o00004?ooool2o`0006Wo
oooo000Looooo`03o`000?oooooooooo05gooooo0_l00006ooooo`;o00004Oooool2o`0000Gooooo
0_l0000Mooooo`;o00003_ooool3o`0000Wooooo0ol00005ooooo`;o00000_ooool2o`0000Cooooo
0_l00002ooooo`;o00002oooool5o`0006Oooooo000Looooo`;o0000G_ooool2o`0001Wooooo0_l0
000Tooooo`;o00003oooool2o`0000;ooooo0_l0000=ooooo`;o00003?ooool2o`0000;ooooo0_l0
0007ooooo`Go0000Ioooool001cooooo00?o0000ooooooooool0Foooool5o`0004oooooo0_l00002
ooooo`;o00004_ooool2o`0000_ooooo0_l00009ooooo`;o00003?ooool2o`0005[ooooo000Loooo
o`03o`000?oooooooooo05_ooooo0_l000000ooooooo0000o`00000=ooooo`;o0000=?ooool2o`00
02;ooooo0_l0000Gooooo`;o00001oooool2o`0000;ooooo0_l0001Jooooo`007?ooool00ol0003o
ooooooooo`1]ooooo`;o00001?ooool2o`0002kooooo0_l0000;ooooo`Go00009?ooool2o`0000Go
oooo1?l00005ooooo`;o0000G_ooool001cooooo00?o0000ooooooooool0K?ooool3o`0000Cooooo
0_l0000kooooo`Go00004_ooool2o`00013ooooo0_l00002ooooo`;o00000oooool2o`0006Gooooo
000Looooo`03o`000?oooooooooo04_ooooo0_l0000Oooooo`;o0000FOooool2o`0000Gooooo1Ol0
000:ooooo`;o00000oooool2o`0000_ooooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`1;
ooooo`;o00002Oooool2o`0004[ooooo0_l0000Zooooo`Go00003oooool2o`0000_ooooo0_l0001H
ooooo`007?ooool00ol0003oooooooooo`1Fooooo`;o00000oooool2o`0001Gooooo0_l000000ooo
oooo0000o`00000[ooooo`;o00003Oooool2o`0000Gooooo0_l0000Aooooo`;o00001oooool2o`00
07?ooooo000Looooo`03o`000?oooooooooo05_ooooo0_l00008ooooo`;o00002oooool2o`000003
ooooool0003o000003[ooooo0_l00005ooooo`;o00004Oooool4o`0000Cooooo0ol0000=ooooo`;o
00002?ooool2o`0005[ooooo000Looooo`03o`000?oooooooooo05?ooooo0_l00002ooooo`;o0000
3?ooool2o`0000oooooo0_l0000Mooooo`Co00004oooool2o`0000[ooooo0_l000000ooooooo0000
o`00000>ooooo`Co00001?ooool2o`0000Wooooo0ol00002ooooo`Co00001_ooool2o`0005[ooooo
000Looooo`03o`000?oooooooooo05?ooooo0_l00002ooooo`;o00007Oooool2o`0000Oooooo0_l0
000@ooooo`;o00000_ooool6o`00013ooooo0ol0000=ooooo`;o00003_ooool3o`0000Gooooo0_l0
0009ooooo`?o00001?ooool2o`0006;ooooo000Looooo`03o`000?oooooooooo05Sooooo0_l0000=
ooooo`;o00002oooool4o`0000Oooooo0_l0000@ooooo`;o00001_ooool2o`0000gooooo0_l00000
0ooooooo0000o`00000Vooooo`;o0000M?ooool001cooooo00?o0000ooooooooool0F?ooool2o`00
00gooooo0_l0000;ooooo`Co00006_ooool2o`0001Cooooo0_l0000Sooooo`;o00000_ooool2o`00
00Sooooo0_l00005ooooo`?o0000I?ooool001cooooo00?o0000ooooooooool0B_ooool2o`0002?o
oooo0_l0000Fooooo`;o00002?ooool3o`0000Gooooo1?l00006ooooo`;o00001_ooool2o`00023o
oooo0_l00002ooooo`;o00002?ooool2o`0000Gooooo0ol0001Tooooo`007?ooool00ol0003ooooo
ooooo`1:ooooo`;o00008oooool2o`0000?ooooo0_l00007ooooo`;o00002?ooool2o`0000Cooooo
0_l00002ooooo`;o00001?ooool6o`0000;ooooo0ol000001?oooooo0000o`000?l00003ooooo`Co
0000:oooool2o`0001Oooooo0_l00004ooooo`;o0000D?ooool001cooooo00?o0000ooooooooool0
E?ooool2o`0001kooooo0_l00007ooooo`;o00002Oooool2o`0000?ooooo0_l00002ooooo`;o0000
1?ooool3o`0000?ooooo2_l00002ooooo`;o000000Coooooo`000?l0003o00002Oooool2o`0001Wo
oooo0_l00003ooooo`;o00005oooool2o`0000Cooooo0_l0001@ooooo`007?ooool2o`0005Gooooo
0_l0000Mooooo`;o00004oooool2o`0000;ooooo0ol00003ooooo`;o00001?ooool2o`000003oooo
ool0003o000000Co000000Coooooo`000?l0003ooooo0_l00005ooooo`?o00002Oooool2o`0001Go
oooo0_l00002ooooo`;o00001oooool4o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o
0000G_ooool001cooooo00?o0000ooooooooool0Loooool2o`0000_ooooo0_l0000:ooooo`?o0000
00?oooooo`000?l000000_l00004ooooo`[o00001?ooool2o`0000Gooooo1?l0000Nooooo`;o0000
0_ooool2o`0000Oooooo1?l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo
0_l00002ooooo`;o00000_ooool2o`00057ooooo000Looooo`03o`000?oooooooooo06Kooooo0_l0
000>ooooo`;o00002?ooool2o`0000_ooooo1Ol000000ooooooo0000o`00000Do`0000Kooooo0_l0
0008ooooo`;o00005?ooool2o`0000;ooooo0_l00008ooooo`;o00003oooool2o`000004ooooool0
003o0000o`0000;ooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o00004ooo
ool2o`0000Wooooo0_l00003ooooo`;o00001_ooool2o`0000gooooo0ol00002ooooo`_o000000?o
ooooo`000?l000002Ol000001?oooooo0000o`000?l00002ooooo`;o00002?ooool2o`0001Cooooo
0_l00009ooooo`;o000000?oooooo`000?l000000_l0000@ooooo`;o0000E_ooool001cooooo00?o
0000ooooooooool0C_ooool5o`0001;ooooo1?l00008ooooo`;o00002oooool2o`00013ooooo1Ol0
00000ooooooo0000o`00000?o`0000?ooooo0ol00002ooooo`;o0000:Oooool2o`0000?ooooo0_l0
0003ooooo`?o0000H_ooool001cooooo00?o0000ooooooooool0C_ooool4o`000003ooooool0003o
0000013ooooo1?l0000Qooooo`?o00000ooooolIo`0000oooooo0_l0000Iooooo`;o00003oooool3
o`0000oooooo0_l00003ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0C?ooool3o`00
00Cooooo0_l0000Iooooo`;o00000_ooool2o`0001Kooooo0ol000000ooooooo0000o`00000Jo`00
0003ooooool0003o000000?ooooo0_l00006ooooo`;o00006Oooool2o`0000[ooooo0_l0000Eoooo
o`;o00000oooool2o`0004cooooo000Looooo`03o`000?oooooooooo04cooooo0ol0000;ooooo`;o
00001oooool2o`0000?ooooo0_l00003ooooo`Oo00002_ooool2o`0000gooooo7Ol000000ooooooo
0000o`000003ooooo`;o00008?ooool4o`0000Wooooo0_l000000ooooooo0000o`00001Uooooo`00
7?ooool00ol0003oooooooooo`1Jooooo`;o00001oooool2o`000003ooooool0003o000000go0000
2Oooool2o`0000;ooooo0_l00009ooooo`go000000?oooooo`000?l000003_l0000Pooooo`?o0000
1?ooool5o`0000;ooooo0_l00007ooooo`;o00000_ooool2o`00067ooooo000Looooo`03o`000?oo
oooooooo04Wooooo0_l0000Kooooo`[o000000?oooooo`000?l000000ol0000<ooooo`;o000000?o
ooooo`000?l000001OoooolLo`000003ooooool0003o000000;o00007_ooool3o`0000Oooooo0ol0
00001?oooooo0000o`000?l0000:ooooo`;o00002_ooool2o`0000_ooooo0_l00018ooooo`007?oo
ool00ol0003oooooooooo`19ooooo`;o00004oooool2o`0000Kooooo4_l00009ooooo`;o00000_oo
ool2o`0000;ooooo9?l00002ooooo`;o00007Oooool2o`0000?ooooo0_l000000ooooooo0000o`00
0002ooooo`;o00002_ooool3o`0000Wooooo0_l00007ooooo`;o00000_ooool2o`0004Sooooo000L
ooooo`03o`000?oooooooooo04Cooooo0_l000001?oooooo0000o`000?l0000Cooooo`?o00001?oo
oolDo`0000Wooooo0_l00005ooooobGo00000_ooool2o`0001Kooooo0_l00005ooooo`;o00000ooo
ool2o`000003ooooool0003o000000oooooo0_l0000Booooo`;o00000oooool2o`0004Oooooo000L
ooooo`03o`000?oooooooooo04?ooooo0ol000001?oooooo0000o`000?l0000?ooooo`;o000000Co
ooooo`000?l0003o00001Oooool2o`0000;ooooo4?l00002ooooo`;o00003?ooool4o`000003oooo
ool0003o000001oo000000?oooooo`000?l000005_ooool2o`0001Oooooo0_l0000Nooooo`;o0000
Aoooool001cooooo00?o0000ooooooooool0>?ooool2o`0000Wooooo0ol0000Cooooo`Ko00000ooo
ool=o`000003ooooool0003o000000Ko00000_ooool2o`0000cooooo0ol000000ooooooo0000o`00
000Qo`00037ooooo0_l00006ooooo`;o00005oooool2o`0004Kooooo000Looooo`03o`000?oooooo
oooo03Sooooo0_l0000Fooooo`;o00000oooool3o`000003ooooool0003o000000Co00000oooool3
o`000003ooooool0003o000001?o00003Oooool3o`000003ooooool0003o000000Oo000000?ooooo
o`000?l000006Ol0000Hooooo`;o00002?ooool2o`0001?ooooo0_l0000<ooooo`;o00000_ooool2
o`0000Gooooo0_l00003ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0AOooool2o`00
00Wooooo0_l00003ooooo`?o000000?oooooo`000?l000000_l00005ooooo`?o00000_oooolDo`00
00;ooooo0ol00005ooooo`;o00001OoooolOo`000004ooooool0003o0000ooooo`;o00004_ooool2
o`0000Cooooo0_l00008ooooo`?o00000oooool2o`0000;ooooo0_l00002ooooo`;o00004oooool6
o`0000?ooooo0_l00005ooooo`;o0000@Oooool001cooooo0_l0000mooooo`;o00001oooool2o`00
017ooooo0_l000001?oooooo0000o`000?l00004ooooo`;o00000ooooolCo`0000?ooooo0ol00002
ooooo`;o000000?oooooo`000?l000001OoooolQo`0000Gooooo0_l0000?ooooo`?o00002_ooool3
o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o00000_ooool2o`0000Kooooo0_l0000<
ooooo`?o00001Oooool2o`0000Cooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`0loooo
o`;o00005Oooool2o`000003ooooool0003o000000So00000_ooool2o`0000Cooooo5ol00003oooo
o`Co00002?ooool6o`000003ooooool0003o000001Ko00001Oooool2o`00013ooooo0_l000000ooo
oooo0000o`000007ooooo`Co00003?ooool2o`0000Kooooo0ol00006ooooo`;o00001?ooool2o`00
0003ooooool0003o000000Wooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`1Cooooo`[o
000000?oooooo`000?l000002?oooolEo`0000?ooooo0_l000001?oooooo0000o`000?l00008oooo
oako00001Oooool2o`0001Cooooo0_l00003ooooo`Go000000Coooooo`000?l0003ooooo0_l00002
ooooo`;o00001Oooool2o`0000Kooooo0_l00007ooooo`;o00001Oooool4o`0004gooooo000Loooo
o`03o`000?oooooooooo04cooooo0_l00006ooooo`So00002Oooool2o`0000;ooooo5_l000001?oo
oooo0000o`000?ooool2o`0000Sooooo8?l00004ooooo`;o00002_ooool2o`0000Gooooo0_l00006
ooooo`Go00001?ooool6o`0000Kooooo0_l000000ooooooo0000o`00000Booooo`;o0000Coooool0
01cooooo00?o0000ooooooooool0@?ooool2o`0000[ooooo0_l00002ooooo`;o00001?ooool2o`00
00gooooo0_l00002oooooaSo00003?ooool7o`0000?ooooo4_l00002ooooo`;o00004?ooool2o`00
00Gooooo0_l000000ooooooo0000o`000002oooooa7o00001Oooool2o`000004ooooool0003o0000
o`0000cooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00002_ooool2o`00
00;ooooo0_l000000ooooooo0000o`000004o`00013ooooo5Ol000000ooooooo0000o`00000:oooo
o`;o00000_ooool5o`0000;ooooo5Ol0000?ooooo`Co000000?oooooo`000?l000000oooool5o`00
00;ooooo3Ol00002ooooo`;o00000_ooool2o`0000Gooooo0_l0000<ooooo`;o00004?ooool2o`00
04;ooooo000Looooo`03o`000?oooooooooo05?ooooo1_l0000@oooooa7o000000Goooooo`000?l0
003o0000ooooo`04o`0000Sooooo0_l00002oooooaGo00000oooool4o`0000oooooo1?l000000ooo
oooo0000o`000002o`0000?ooooo0_l000000ooooooo0000o`00000@o`0000?ooooo0_l0000Uoooo
o`;o00000_ooool2o`0003kooooo000Looooo`03o`000?oooooooooo033ooooo0_l00002ooooo`;o
00006_ooool2o`0000;ooooo0ol0000=ooooo`;o00000ooooolDo`0000Cooooo0_l00004ooooo`;o
00001Oooool2o`0000?ooooo4?l00003ooooo`Go00002oooool2o`000003ooooool0003o000000?o
000000?oooooo`000?l000000_l00005ooooo`[o000000?oooooo`000?l000001_l00005ooooo`Co
00004Oooool2o`0000Wooooo0_l00007ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0
<?ooool2o`0000;ooooo0_l0000Jooooo`;o00001?ooool2o`0000Oooooo0_l00003ooooo`;o0000
1?oooolDo`0000?ooooo0_l00004ooooo`;o00001Oooool2o`0000Cooooo1ol00002ooooo`Ko0000
0oooool2o`000004ooooool0003o0000o`0000[ooooo0_l000001?oooooo0000o`000?l00002oooo
o`;o00001OoooolGo`000004ooooool0003o0000ooooo`Co00001?ooool2o`0000Sooooo0_l00000
1?oooooo0000o`000?ooool2o`0000Kooooo0_l00006ooooo`;o0000?oooool001cooooo00?o0000
ooooooooool0D?ooool3o`0000?ooooo0ol00006ooooo`;o00002Oooool2o`000003ooooool0003o
000000oo00001?ooool2o`00013ooooo0ol00002ooooo`;o00000oooool2o`000003ooooool0003o
000000?ooooo0_l00002ooooo`;o00002oooool2o`0000Gooooo0_l00005oooooa[o000000?ooooo
o`000?l000001_ooool2o`0000Sooooo0_l00004ooooo`;o00000_ooool2o`0000?ooooo0_l00005
ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0D?ooool5o`0000;ooooo0_l0000Aoooo
o`;o000000?oooooo`000?l000004?l00003ooooo`;o00005Oooool2o`000003ooooool0003o0000
00;o00000oooool2o`000003ooooool0003o000000_ooooo0ol000001?oooooo0000o`000?ooool2
o`0000Wooooo0_l000000ooooooo0000o`00000Eo`000003ooooool0003o000001;ooooo0_l00005
ooooo`?o00000oooool2o`0004Kooooo000Looooo`03o`000?oooooooooo057ooooo1_l000000ooo
oooo0000o`000008ooooo`;o00001OoooolFo`0001[ooooo0_l000000ooooooo0000o`000005oooo
o`;o00003_ooool4o`000003ooooool0003o000000;o00002OoooolKo`0001Cooooo0ol00004oooo
o`;o0000C?ooool001cooooo00?o0000ooooooooool0DOooool2o`0000;ooooo0_l000000ooooooo
0000o`000008ooooo`;o00001OoooolAo`0000?ooooo0_l0000Rooooo`;o00004Oooool3o`000004
ooooool0003o0000ooooo`;o00001Oooool2o`0000?ooooo6Ol00009ooooo`;o00002_ooool2o`00
00?ooooo0_l00003ooooo`;o00001_ooool2o`00043ooooo000Looooo`03o`000?oooooooooo03Co
oooo0_l0000Fooooo`Go00000_ooool2o`000003ooooool0003o000000[ooooo0_l00005ooooo`Co
000000?oooooo`000?l000002ol00002ooooo`;o00008_ooool2o`00017ooooo1?l00003ooooo`Co
00000oooool2o`0000;ooooo5Ol00004ooooo`;o00002?ooool2o`0000oooooo0_l00003ooooo`;o
00001?ooool4o`000003ooooool0003o000003gooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^
kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0doooo
o`;o00004?ooool2o`0000Cooooo1Ol00002ooooo`;o000000?oooooo`000?l000002?ooool4o`00
00Cooooo0ol00006ooooo`Oo000000?oooooo`000?l000000_ooool2o`0002gooooo0_l00003oooo
o`;o00000_ooool3o`0000?ooooo1?l00005oooooago00006Oooool2o`0000?ooooo0_l00004oooo
o`;o00000oooool2o`0003gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>?ooool2o`0000cooooo1?l00003
ooooo`?o00004?ooool2o`000003ooooool0003o000000?ooooo1?l00005ooooo`;o00000_ooool2
o`0003?ooooo1?l00002ooooo`?o00000_ooool2o`0000gooooo7?l0000Jooooo`;o00001Oooool2
o`0000Oooooo0_l0000mooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09oooo
o`Go00001_ooool00ol0003oooooooooo`0hooooo`;o00003Oooool3o`0000?ooooo0_l0000Aoooo
o`;o000000Coooooo`000?l0003o00001?ooool2o`0000Gooooo0_l00002ooooo`;o00001oooool2
o`0002?ooooo0_l00005ooooo`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00003_oo
oolHo`000003ooooool0003o000001Gooooo0_l00005ooooo`;o00000oooool2o`0000Cooooo0_l0
00001?oooooo0000o`000?ooool2o`0003[ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oo
oooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`0004Kooooo0ol0000Gooooo`;o0000
0_ooool2o`0000_ooooo0_l00007ooooo`;o00000_ooool2o`00027ooooo1?l00003ooooo`Co0000
00?oooooo`000?l000000oooool4o`0000?ooooo0_l0000:ooooo`_o000000?oooooo`000?l00000
3ol00004ooooo`;o00003Oooool4o`0000?ooooo0_l00005ooooo`;o00000_ooool2o`000004oooo
ool0003o0000ooooo`;o000000?oooooo`000?l000000_ooool2o`0003?ooooo00000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003o
ooooooooo`16ooooo`;o00000_ooool2o`0000Kooooo0_l00004ooooo`;o00001?ooool4o`0000?o
oooo0_l00009ooooo`;o00000_ooool2o`0000Cooooo1_l0000Pooooo`Go00000oooool4o`0000Go
oooo1Ol00003ooooo`;o00003?oooolHo`000003ooooool0003o000000Cooooo0_l0000=ooooo`Co
00002Oooool3o`0000Sooooo0_l000000ooooooo0000o`000002ooooo`;o0000<oooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00omgMgOoc<c<o`000007ooooo`03o`00
0?oooooooooo04[ooooo0_l00006ooooo`Co00000_ooool3o`0000?ooooo0_l00005ooooo`;o0000
2Oooool2o`0000;ooooo0_l00004ooooo`Co00007oooool2o`000003ooooool0003o000000?o0000
0oooool2o`0000Oooooo1?l000000ooooooo0000o`00000?oooooaSo000000?oooooo`000?l00000
4oooool2o`0000Gooooo0_l00004ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Oooooo
0_l0000booooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co000000Oo
oooo00?o0000ooooooooool0:?ooool2o`0002[ooooo1ol00003ooooo`;o00000oooool2o`0000[o
oooo0_l00003ooooo`;o000000?oooooo`000?l000009?ooool2o`0000;ooooo0ol00004ooooo`;o
00003?ooool2o`0000_ooooo5ol00003ooooo`;o00003?ooool2o`0000oooooo0_l00004ooooo`;o
000000?oooooo`000?l000001Oooool2o`0000Oooooo0_l0000booooo`0000Koooooonk^k_lb<S;o
0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0:?ooool2o`00
00?ooooo0ol0000Cooooo`;o00004?ooool4o`0000Gooooo0_l00003ooooo`;o00002_ooool2o`00
0003ooooool0003o000000;o000000Coooooo`000?l0003o00009_ooool4o`0000;ooooo0_l00005
ooooo`;o00004?ooool2o`0000;ooooo5_l00003ooooo`Co00002oooool2o`0001Cooooo1Ol0000>
ooooo`;o0000<oooool001cooooo00?o0000ooooooooool0;Oooool3o`000003ooooool0003o0000
013ooooo0_l00003ooooo`?o00002Oooool2o`0000Gooooo0_l00004ooooo`Go00003?ooool3o`00
00?ooooo0_l0000Mooooo`;o00001oooool2o`0000Cooooo0_l00005ooooo`Co00001oooool2o`00
00Gooooo0_l00006oooooa?o00000_ooool4o`0001Gooooo0_l00006ooooo`;o00000_ooool5o`00
00kooooo0_l0000cooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o00000_ooool2o`0000oo
oooo0_l00004ooooo`Go00001?ooool2o`000003ooooool0003o000000Cooooo1Ol000001Ooooooo
0000o`000?l0003ooooo00Co00002oooool3o`0000Oooooo1?l00004ooooo`;o00001_ooool2o`00
00Oooooo0ol00005ooooo`;o00003Oooool4o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`00
00Oooooo1?l000000ooooooo0000o`00000>o`0000;ooooo1?l0000Eooooo`;o00001_ooool2o`00
00?ooooo0ol00005ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0@_ooool2o`0000Co
oooo1Ol00004ooooo`;o00001oooool5o`000003ooooool0003o000000?ooooo0ol0000<ooooo`;o
00001oooool4o`0000Cooooo0_l00006ooooo`;o00001oooool2o`0000Gooooo0ol0000;ooooo`Oo
00000_ooool2o`0000Kooooo0_l00007ooooo`;o000000?oooooo`000?l000004?l00004ooooo`;o
00008oooool2o`0000Gooooo0_l00007ooooo`;o0000=?ooool001cooooo00?o0000ooooooooool0
;?ooool2o`0001kooooo0_l00003ooooo`;o00002?ooool4o`000003ooooool0003o000000?ooooo
0ol0000Aooooo`?o00002oooool2o`0001Cooooo0_l00009ooooo`;o000000Coooooo`000?l0003o
00000_ooool3o`0000kooooo0_l00004oooooa3o00000oooool4o`0002[ooooo1?l00007ooooo`;o
0000=?ooool001cooooo00?o0000ooooooooool0;?ooool2o`0000Cooooo0_l0000>ooooo`?o0000
0_ooool3o`0000;ooooo0_l0000=ooooo`?o00000_ooool2o`0000Cooooo0_l00005ooooo`?o0000
2Oooool4o`000003ooooool0003o000000;o00000oooool4o`00017ooooo0_l0000<ooooo`;o0000
0_ooool2o`0000?ooooo1ol00002ooooo`;o00000oooool4o`0000Cooooo0_l000000ooooooo0000
o`000002o`0000?ooooo1?l00004ooooo`Ko00008oooool2o`0000Cooooo1?l0000mooooo`007?oo
ool00ol0003oooooooooo`0booooo`;o00003_ooool3o`000003ooooool0003o000000;o00000_oo
ool2o`0001oooooo0ol00005ooooo`;o00001?ooool2o`000003ooooool0003o000000;o00000ooo
ool5o`00013ooooo0_l0000Fooooo`Oo000000?oooooo`000?l000000_ooool3o`0000oooooo1Ol0
0003ooooo`?o00000_ooool2o`0000Oooooo0ol0000Gooooo`Co0000AOooool001cooooo00?o0000
ooooooooool0<Oooool2o`0001?ooooo0_l00002ooooo`Co00003Oooool5o`0000Oooooo0_l0000<
ooooo`;o00004Oooool2o`0000Kooooo0_l00008ooooo`Co00005?ooool4o`000003ooooool0003o
000000Gooooo0_l0000@ooooo`;o000000Goooooo`000?l0003o0000ooooo`05o`0000[ooooo0ol0
000Gooooo`;o000000Coooooo`000?l0003o0000@oooool001cooooo00?o0000ooooooooool0:Ooo
ool2o`0000Kooooo0_l0000Cooooo`;o000000Coooooo`000?l0003o00003oooool5o`000003oooo
ool0003o000000Cooooo0_l0000<ooooo`;o00006Oooool2o`0000Wooooo0ol0000Aooooo`;o0000
0_ooool3o`0001;ooooo1Ol00007ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Wooooo`Co
00001oooool2o`0003Wooooo000Looooo`03o`000?oooooooooo02Wooooo0_l0000Kooooo`;o0000
00?oooooo`000?l000000_ooool2o`00013ooooo1?l00004ooooo`;o000000?oooooo`000?l00000
0_l00005ooooo`Co00004?ooool2o`0001?ooooo0_l0000;ooooo`;o00001?ooool2o`0000;ooooo
1?l00006ooooo`;o00002Oooool5o`0000?ooooo0_l0000Dooooo`;o00007?ooool3o`0000Oooooo
0_l00003ooooo`;o0000=?ooool001cooooo00?o0000ooooooooool09oooool2o`000003ooooool0
003o000000;o00006Oooool2o`0000Cooooo0_l00006ooooo`;o00001_ooool4o`0000Kooooo0_l0
00000ooooooo0000o`000002o`0000Gooooo1?l0000@ooooo`;o000000?oooooo`000?l000004?oo
ool2o`000003ooooool0003o000000Sooooo0_l00002ooooo`;o00001?ooool6o`0000Cooooo0_l0
000Aooooo`;o00004oooool3o`0001Wooooo0_l000000ooooooo0000o`000009ooooo`;o00000_oo
ool2o`000003ooooool0003o0000037ooooo000Looooo`03o`000?oooooooooo02Oooooo0_l00000
0ooooooo0000o`000002o`0001Wooooo0_l00006ooooo`;o00001?ooool2o`0000;ooooo1_l00003
ooooo`;o00007?ooool7o`0000?ooooo1?l00003ooooo`;o00003?ooool2o`0000cooooo0_l00004
ooooo`?o000000?oooooo`000?l000001_ooool2o`0002Cooooo0_l0000Fooooo`;o00000_ooool2
o`000003ooooool0003o000000;ooooo0_l00005ooooo`;o00001Oooool2o`00037ooooo000Loooo
o`;o0000B?ooool2o`0000Kooooo0_l00008ooooo`_o00000oooool2o`0001Oooooo1ol00003oooo
o`Go00000_ooool4o`0001Sooooo0_l000001?oooooo0000o`000?ooool2o`0000[ooooo0_l0000Q
ooooo`?o00006?ooool2o`0000Cooooo0ol00002ooooo`;o0000?oooool001cooooo00?o0000oooo
ooooool0Aoooool2o`0000[ooooo0_l00005ooooo`?o00000_ooool3o`0000Gooooo0_l00003oooo
o`;o00006_ooool2o`0000;ooooo1Ol00002ooooo`;o00006oooool9o`0002Wooooo0ol0000Koooo
o`Ko00000_ooool2o`0000;ooooo1?l0000iooooo`007?ooool00ol0003oooooooooo`18ooooo`;o
00000_ooool2o`0000Gooooo0_l00005ooooo`?o00000_ooool2o`0000;ooooo0_l00007ooooo`;o
000000?oooooo`000?l000005oooool2o`0000Gooooo0_l00003ooooo`;o00006_ooool3o`000003
ooooool0003o000000?o0000Aoooool6o`0000;ooooo0_l00002ooooo`Co0000>Oooool001cooooo
00?o0000ooooooooool0A_ooool4o`0000;ooooo0_l00007ooooo`;o00001?ooool2o`000004oooo
ool0003o0000o`0000;ooooo0_l00008ooooo`Ko00008?ooool3o`0001[ooooo0ol000000ooooooo
0000o`00000;ooooo`;o0000?oooool2o`0000Wooooo0ol00007ooooo`;o0000<?ooool001cooooo
00?o0000ooooooooool09oooool2o`0001gooooo1?l0000;ooooo`;o00001oooool3o`0000Wooooo
1Ol000001?oooooo0000o`000?l00004ooooo`;o00000_ooool2o`0001Kooooo0ol000000ooooooo
0000o`000004ooooo`;o00004Oooool2o`0000oooooo0_l0000Dooooo`;o00001oooool2o`00023o
oooo1?l00007ooooo`Co00001_ooool2o`00033ooooo000Looooo`03o`000?oooooooooo02Gooooo
1?l0000Gooooo`;o00001_ooool3o`0001;ooooo1?l00009ooooo`Co00000_ooool2o`0000?ooooo
1?l00002ooooo`;o000000?oooooo`000?l000004oooool6o`0000Cooooo0_l0000Iooooo`;o0000
7Oooool2o`0000?ooooo0ol000000ooooooo0000o`00000Nooooo`Ko00002Oooool2o`0003Sooooo
000Looooo`03o`000?oooooooooo02Gooooo0_l0000Iooooo`;o000000?oooooo`000?l000000ooo
ool3o`0001;ooooo1?l0000<ooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo1_l0
000Fooooo`;o00004?ooool2o`0000kooooo0ol0000Kooooo`;o00001?ooool3o`00027ooooo1?l0
0006ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool09oooool2o`0001[ooooo0_l00004
ooooo`;o00005?ooool2o`0000Gooooo0_l00005ooooo`Co00000_ooool2o`0000?ooooo2_l00007
ooooo`;o00002_ooool4o`0000?ooooo0ol000000ooooooo0000o`000006ooooo`;o00003Oooool7
o`0001Oooooo0ol00005ooooo`?o00007Oooool2o`0000?ooooo0_l00004ooooo`Co00000_ooool2
o`0000Sooooo0_l0000_ooooo`007?ooool00ol0003oooooooooo`0Wooooo`;o00006?ooool2o`00
00Kooooo0_l00005ooooo`;o00005?ooool2o`0000Gooooo1?l00002ooooo`;o00000oooool2o`00
0005ooooool0003o0000o`000?ooool00ol00007ooooo`;o00002_ooool4o`0000?ooooo0ol00000
0ooooooo0000o`00000>ooooo`;o00001Oooool2o`000003ooooool0003o000000;o00005oooool2
o`000003ooooool0003o000000Cooooo0ol00004ooooo`Co00005?ooool2o`0000Wooooo0_l00004
ooooo`;o00002?ooool2o`0002oooooo000Looooo`03o`000?oooooooooo02[ooooo0_l0000Eoooo
o`Go00000oooool2o`0000?ooooo1?l0000=ooooo`?o00005?ooool5o`0000Gooooo0_l00008oooo
o`;o00003_ooool3o`0000?ooooo0_l0000>ooooo`;o00001?ooool2o`0000?ooooo0_l0000Koooo
o`;o000000?oooooo`000?l000000_ooool2o`0000Cooooo1?l000000ooooooo0000o`00000Hoooo
o`;o00004_ooool2o`0002oooooo000Looooo`03o`000?oooooooooo02[ooooo0_l0000Gooooo`?o
00002?ooool2o`000003ooooool0003o000000;o00002_ooool3o`0001Cooooo1Ol00004ooooo`?o
000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000;o00003?ooool5o`0000Wo
oooo0_l0000<ooooo`So00000_ooool3o`0001Sooooo0_l0000=ooooo`;o00006?ooool2o`0000_o
oooo0_l00005ooooo`;o0000;oooool001cooooo00?o0000ooooooooool0@oooool2o`0000;ooooo
0_l00002ooooo`;o00000_ooool6o`0000Sooooo0_l0000Pooooo`;o000000?oooooo`000?l00000
1Ol00003ooooo`;o00003Oooool6o`0000Oooooo0_l00008ooooo`;o00000_ooool8o`0000;ooooo
1?l0000Uooooo`;o00003oooool2o`00013ooooo0_l00003ooooo`;o00001?ooool2o`00033ooooo
000Looooo`03o`000?oooooooooo027ooooo0_l00005ooooo`;o00007Oooool6o`0000;ooooo0_l0
000;ooooo`?o00008oooool7o`0000cooooo0_l00008ooooo`;o000000?oooooo`000?l000002Ooo
ool4o`000003ooooool0003o000000Ko00000_ooool3o`000003ooooool0003o000000;o00006_oo
ool2o`0000Sooooo0ol0000?ooooo`?o00002Oooool2o`0000?ooooo1?l00008ooooo`;o0000<?oo
ool001cooooo00?o0000ooooooooool08Oooool2o`0000Gooooo0_l0000Mooooo`Co00001oooool2
o`0000Sooooo0_l0000;ooooo`;o00001?ooool2o`0000cooooo0_l00005ooooo`;o000000?ooooo
o`000?l000003?ooool3o`0000[ooooo1?l00007ooooo`Ko000000Goooooo`000?l0003o0000oooo
o`04o`000004ooooool0003o0000ooooo`?o00000oooool2o`0001Kooooo0_l00003ooooo`;o0000
0oooool2o`00017ooooo0_l00009ooooo`;o00000oooool4o`0003[ooooo000Looooo`03o`000?oo
oooooooo047ooooo0_l00004ooooo`?o00001?ooool2o`0000;ooooo0_l00007ooooo`?o00002ooo
ool2o`0000Cooooo0_l000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l000001Ooo
ool2o`0000oooooo0ol0000<ooooo`;o00002oooool7o`0000;ooooo0_l000000ooooooo0000o`00
0004o`0000?ooooo0_l0000Kooooo`;o00005oooool2o`0004_ooooo000Looooo`03o`000?oooooo
oooo047ooooo0_l00002ooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo0_l00007
ooooo`;o00000_ooool2o`00017ooooo0_l00006ooooo`?o00003?ooool2o`0000[ooooo0ol00005
ooooo`;o00004?ooool9o`0000Gooooo1Ol0000:ooooo`;o00006?ooool2o`0001Cooooo0_l00009
ooooo`;o00000_ooool2o`0003cooooo000Looooo`;o00008_ooool2o`0002;ooooo0_l00004oooo
o`Go00000_ooool2o`0000Oooooo0_l00002ooooo`;o00003Oooool3o`0000Gooooo0_l000000ooo
oooo0000o`000002o`0000cooooo1Ol00008ooooo`;o00000_ooool2o`000003ooooool0003o0000
00;ooooo0_l0000<ooooo`;o00000_ooool5o`0000Kooooo0ol0000;ooooo`?o00005?ooool2o`00
0004ooooool0003o0000o`0001kooooo0_l00002ooooo`;o0000??ooool001cooooo00?o0000oooo
ooooool08Oooool3o`0000Oooooo0_l0000Cooooo`;o00000oooool3o`0000?ooooo1Ol0000>oooo
o`;o00000oooool2o`0000Wooooo0ol00004ooooo`?o000000?oooooo`000?l000000_l0000>oooo
o`?o00002Oooool2o`000003ooooool0003o000000?ooooo1?l0000Cooooo`;o00000oooool8o`00
00?ooooo0ol00004ooooo`;o00005?ooool2o`0000;ooooo0_l0000Jooooo`;o00001?ooool2o`00
00Wooooo0_l0000cooooo`007?ooool00ol0003oooooooooo`0Rooooo`;o00001oooool2o`0001?o
oooo0_l00003ooooo`Go00003oooool2o`0000?ooooo0_l00003ooooo`;o00004?ooool2o`0000;o
oooo0_l00002ooooo`Co00003?ooool2o`0000Sooooo0_l00005ooooo`?o00004?ooool2o`0000?o
oooo1?l000000ooooooo0000o`000006o`0000;ooooo1?l000000ooooooo0000o`000002o`0001?o
oooo1?l0000Nooooo`;o00001?ooool2o`0000Wooooo0_l0000cooooo`007?ooool00ol0003ooooo
ooooo`12ooooo`Go000000?oooooo`000?l000003oooool2o`00017ooooo1?l00009ooooo`;o0000
0_ooool4o`0000?ooooo1_l00003ooooo`?o000000?oooooo`000?l000002oooool2o`00017ooooo
0_l00005ooooo`;o000000?oooooo`000?l000001_l00002ooooo`;o00000oooool4o`000003oooo
ool0003o000000;ooooo0_l0000<ooooo`;o00006oooool2o`0000Wooooo0_l000000ooooooo0000
o`00000kooooo`007?ooool00ol0003oooooooooo`12ooooo`Co00002oooool2o`0000Wooooo0ol0
000:ooooo`;o000000?oooooo`000?l000000_l0000<ooooo`ko00000oooool3o`000003ooooool0
003o000000Kooooo0_l0000Oooooo`?o00001oooool3o`0000Cooooo1_l00002ooooo`;o00003ooo
ool4o`0000;ooooo0_l0000Booooo`;o00003?ooool3o`0003[ooooo000Looooo`03o`000?oooooo
oooo043ooooo0ol00008ooooo`;o00001?ooool2o`0000Wooooo0ol0000:ooooo`;o00000_ooool2
o`0000?ooooo0_l000000ooooooo0000o`000005ooooo`[o00001_ooool3o`000003ooooool0003o
000000Oooooo0_l0000Booooo`;o00001oooool2o`0000;ooooo1Ol000001?oooooo0000o`000?oo
ool3o`0000Cooooo1Ol0000Eooooo`Co00000_ooool2o`0000?ooooo0_l0000Looooo`;o0000>_oo
ool001cooooo00?o0000ooooooooool0?oooool4o`0000Cooooo0_l00002ooooo`;o00008?ooool2
o`0000?ooooo0_l000001?oooooo0000o`000?l00004ooooo`[o00001Oooool3o`0000;ooooo1Ol0
000Hooooo`;o00001oooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool6o`0000;ooooo
1Ol0000=ooooo`;o00004oooool2o`0000kooooo1?l00003ooooo`;o0000@Oooool001cooooo00?o
0000ooooooooool0?_ooool5o`0000?ooooo0ol00008ooooo`Co00004_ooool2o`0000Oooooo2Ol0
0002ooooo`go00000oooool3o`000004ooooool0003o0000ooooo`?o00003_ooool2o`0001Cooooo
1ol000001?oooooo0000o`000?ooool8o`0000Gooooo0_l00006ooooo`?o00004Oooool2o`0000Wo
oooo0_l00005ooooo`Co00000oooool2o`0000Kooooo0_l0000iooooo`007?ooool00ol0003ooooo
ooooo`0Jooooo`;o00000oooool2o`0000kooooo0_l0000=ooooo`Co00001?ooool2o`0000Wooooo
1?l00005ooooo`Co00002?ooool3o`0000?ooooo0_l00002ooooo`[o000000?oooooo`000?l00000
2ol00003ooooo`?o000000?oooooo`000?l000000_ooool2o`000004ooooool0003o0000ooooo`Co
00001_ooool2o`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l000001_ooool7o`0000Go
oooo1Ol00002ooooo`;o00000oooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o
00003_ooool2o`0000Wooooo0_l0000<ooooo`;o00001?ooool4o`0003Wooooo000Looooo`03o`00
0?oooooooooo01[ooooo0_l00003ooooo`;o00003_ooool2o`0000kooooo1?l0000Gooooo`Co0000
2?ooool2o`0000?ooooo0ol00003oooooaWo00000_ooool2o`0000Sooooo0_l000000ooooooo0000
o`000002o`0000_ooooo0_l00002ooooo`Co000000?oooooo`000?l000001?ooool2o`000003oooo
ool0003o000000Co00000_ooool5o`0000Cooooo0ol00007ooooo`?o00001Oooool2o`0000kooooo
0_l0000Cooooo`;o00002?ooool2o`0003_ooooo000Looooo`03o`000?oooooooooo03kooooo1_l0
00000ooooooo0000o`00000Aooooo`;o00004Oooool2o`0000;ooooo0ol00003oooooaGo00000_oo
ool2o`000003ooooool0003o000000;o00001Oooool4o`00013ooooo0_l00002ooooo`?o00001?oo
ool2o`000004ooooool0003o0000ooooo`Co000000?oooooo`000?l000000_l00005ooooo`;o0000
2?ooool2o`0001?ooooo0_l000001?oooooo0000o`000?ooool2o`00013ooooo0_l00004ooooo`;o
00000_ooool2o`0003_ooooo000Looooo`03o`000?oooooooooo03cooooo1?l00002ooooo`;o0000
00?oooooo`000?l000004Oooool2o`00017ooooo0_l00002ooooo`Go000000?oooooo`000?l00000
3?l000000ooooooo0000o`000008o`000003ooooool0003o000000;o00000oooool6o`0000;ooooo
0_l00002ooooo`;o00002_ooool5o`0000Cooooo0_l00002ooooo`;o00000_ooool2o`000004oooo
ool0003o0000o`0001Cooooo1Ol0000<ooooo`;o00001?ooool6o`0001;ooooo0_l00002ooooo`;o
0000>oooool001cooooo00?o0000ooooooooool0??ooool4o`0001Cooooo0_l00002ooooo`;o0000
4?ooool3o`0000;ooooo7ol000000ooooooo0000o`000003ooooo`Co00001_ooool2o`000004oooo
ool0003o0000o`0000?ooooo0_l00005ooooo`;o00002Oooool7o`0000;ooooo0_l0000>ooooo`;o
00001Oooool5o`0001;ooooo1_l000000ooooooo0000o`00001@ooooo`007?ooool00ol0003ooooo
ooooo`0Pooooo`;o00003Oooool2o`0000_ooooo1?l00004ooooo`;o00003_ooool2o`0000Gooooo
0_l0000=ooooo`;o00001?oooolMo`0000Kooooo0ol0000;ooooo`;o00001?ooool2o`0000?ooooo
0_l00003ooooo`;o00001_ooool2o`000003ooooool0003o000000;o00004_ooool2o`0000Gooooo
0_l0000Eooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l0000Booooo`;o0000
=oooool001cooooo00?o0000ooooooooool08?ooool2o`0000gooooo0_l0000;ooooo`;o00001_oo
ool2o`0001Cooooo0ol0000<ooooo`;o00001?ooool5o`000003ooooool0003o000000_o000000?o
ooooo`000?l000002?l000000ooooooo0000o`000003ooooo`;o00005oooool2o`0000?ooooo0_l0
0009ooooo`Co00004oooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0001;ooooo
1?l00005ooooo`;o00001oooool2o`0000Wooooo0_l0000gooooo`007?ooool00ol0003ooooooooo
o`0_ooooo`;o0000:Oooool2o`0000gooooo0_l00004ooooob7o00007?ooool5o`0000Sooooo0_l0
0003ooooo`;o00004oooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0001Cooooo
0_l0000>ooooo`;o00002?ooool2o`0003Sooooo000Looooo`;o0000Foooool2o`0000Wooooo0_l0
0008ooooo`?o000000?oooooo`000?l000006_l0000Aooooo`;o00003?ooool3o`0000Sooooo0_l0
0005ooooo`;o00005oooool2o`0000Gooooo0_l0000Gooooo`;o00003?ooool2o`0000Kooooo0_l0
000hooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00002_ooool2o`0001kooooo0_l00008
ooooo`;o00001_ooool2o`000003ooooool0003o000001go00000_ooool2o`0000;ooooo0_l00009
ooooo`;o00005_ooool3o`0000Gooooo0_l0000Nooooo`;o00005oooool2o`0000Wooooo1Ol00004
ooooo`?o000000?oooooo`000?l00000=_ooool001cooooo00?o0000ooooooooool08Oooool2o`00
00cooooo0_l0000:ooooo`;o00006oooool5o`0000Oooooo0_l00007ooooob;o00000_ooool2o`00
00;ooooo0_l00009ooooo`;o00004Oooool2o`0000?ooooo1?l00004ooooo`;o00000_ooool2o`00
013ooooo0_l00007ooooo`;o00000oooool2o`0001;ooooo0_l0000:ooooo`Ko00000oooool6o`00
03Kooooo000Looooo`03o`000?oooooooooo027ooooo0_l0000Hooooo`?o00004oooool4o`0000?o
oooo1?l00004ooooo`;o00000_ooool5o`0000Cooooo6ol000000ooooooo0000o`000008o`00023o
oooo1?l00003ooooo`;o00001?ooool2o`0000;ooooo0_l0000@ooooo`?o00001_ooool3o`0000;o
oooo0_l0000Booooo`;o00002_ooool2o`0000;ooooo0_l00004ooooo`Co0000=oooool001cooooo
00?o0000ooooooooool0>?ooool2o`000004ooooool0003o0000o`00013ooooo0_l000000ooooooo
0000o`000002o`0000Cooooo0ol00004ooooo`;o00001?ooool3o`0000;ooooo1ol000000ooooooo
0000o`000003o`000003ooooool0003o000001Wo00007oooool4o`0000?ooooo0_l0000=ooooo`;o
00003?ooool2o`0000Cooooo1Ol0001Wooooo`007?ooool00ol0003oooooooooo`0hooooo`Wo0000
2oooool4o`0000Gooooo0_l000000ooooooo0000o`000002o`0000Cooooo2?l000000ooooooo0000
o`00000=o`000003ooooool0003o000001Go00000_ooool2o`0000Kooooo0_l0000>ooooo`;o0000
3_ooool3o`0000cooooo0_l00008ooooo`;o00000_ooool2o`0000;ooooo1_l0000Jooooo`;o0000
2Oooool2o`0000Oooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0jooooo`Oo00002ooo
ool2o`0000Oooooo0_l000001?oooooo0000o`000?l00005ooooo`So000000?oooooo`000?l00000
4ol000000ooooooo0000o`00000:o`000004ooooool0003o0000o`0000Sooooo0_l000000ooooooo
0000o`00000=ooooo`?o00002?ooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`Co
00003_ooool2o`0000;ooooo3?l0000:ooooo`;o00002_ooool4o`0000?ooooo0_l00002ooooo`Ko
00001Oooool2o`0003Sooooo000Looooo`03o`000?oooooooooo03cooooo1?l0000;ooooo`;o0000
0oooool2o`0000_ooooo0_l00006ooooo`?o00000_oooolVo`0000Oooooo0_l000000ooooooo0000
o`00000=ooooo`;o00002Oooool2o`000003ooooool0003o000000Sooooo1?l0000Aooooo`go0000
2_ooool2o`0000[ooooo0_l00005ooooo`;o00000_ooool2o`0000;ooooo0_l0000oooooo`007?oo
ool00ol0003oooooooooo`17ooooo`;o00000_ooool2o`0000?ooooo0_l00003ooooo`;o00001_oo
ool4o`0000Wooooo9_l00007ooooo`;o000000?oooooo`000?l000001?ooool2o`0001Kooooo0_l0
0002ooooo`;o00000oooool4o`000003ooooool0003o000000gooooo4_l00006ooooo`;o00007_oo
ool2o`0003[ooooo000Looooo`03o`000?oooooooooo037ooooo0_l0000Dooooo`;o00000_ooool2
o`0000?ooooo0_l00003ooooo`;o00002?ooool4o`0000Sooooo9Ol00005ooooo`Co00001oooool2
o`00017ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00008ooooo`;o00003?ooool5
o`000003ooooool0003o000000Ko000000?oooooo`000?l000000_l00006ooooo`;o00000oooool2
o`0000Cooooo0_l00003ooooo`;o00002_ooool2o`0000;ooooo0_l0000jooooo`007?ooool00ol0
003oooooooooo`0Rooooo`;o00003Oooool2o`0001gooooo0_l0000>ooooo`?o000000?oooooo`00
0?l000000oooool4o`000003ooooool0003o000002So00002_ooool4o`0000gooooo0_l000000ooo
oooo0000o`00000Eooooo`;o00001?ooool?o`00013ooooo0_l00004ooooo`;o00000oooool2o`00
00;ooooo0_l00006ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool08_ooool2o`0000go
oooo0_l0000?ooooo`;o00000oooool2o`0001Oooooo0_l00002ooooo`;o00000ooooolTo`000003
ooooool0003o000000Wo000000?oooooo`000?l000001_ooool4o`000003ooooool0003o000000Co
oooo1?l00002ooooo`;o00002oooool2o`0000_ooooo0_l00004ooooo`oo00006oooool3o`000003
ooooool0003o000000Wooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0Sooooo`;o0000
7Oooool2o`0000?ooooo0_l0000Gooooo`Ko00000_oooolVo`0000;ooooo0ol000000ooooooo0000
o`000003o`000003ooooool0003o000000;o00002Oooool2o`0000?ooooo2Ol0000;ooooo`;o0000
2oooool2o`0000;ooooo4_l000000ooooooo0000o`00000?ooooo`;o00001_ooool7o`0000Kooooo
1?l0000kooooo`007?ooool00ol0003oooooooooo`0Sooooo`Co00005Oooool2o`0001Kooooo0_l0
00001?oooooo0000o`000?l00002ooooo`;o000000?oooooo`000?l000001?l00003ooooo`Go0000
00?oooooo`000?l000008_l00002ooooo`;o00001?ooool5o`0000cooooo1Ol000000ooooooo0000
o`00000:ooooo`;o00001Oooool4o`0000?ooooo1?l00002oooooa;o000000?oooooo`000?l00000
3Oooool4o`0000Oooooo0ol000000ooooooo0000o`000006ooooo`;o0000?Oooool00006ooooooo^
k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006oooo
o`03o`000?oooooooooo02Gooooo0_l0000Eooooo`;o00005_ooool6o`0000;ooooo0_l000000ooo
oooo0000o`000003ooooo`;o00000ooooolXo`0000;ooooo0ol00007ooooo`Go000000?oooooo`00
0?l000000oooool2o`000003ooooool0003o0000013ooooo0_l00005ooooo`Co00000oooool2o`00
00Cooooo3_l0000;ooooo`;o00001oooool4o`0000Sooooo0_l00018ooooo`0000KoooooogMgMonH
V9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o
0000ooooooooool0<_ooool2o`0001Gooooo0_l00009ooooo`?o000000?oooooo`000?l000000_oo
ool2o`0000Kooooo0_l00004ooooobGo00000oooool3o`0000?ooooo1?l00003ooooo`?o000000?o
ooooo`000?l000000_ooool3o`0000;ooooo0ol0000>ooooo`;o00000_ooool3o`0000;ooooo0_l0
0009ooooo`;o000000?oooooo`000?l000002?l0000<ooooo`;o00001oooool4o`0000Sooooo0_l0
0005ooooo`;o0000@Oooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0<_ooool2o`0001Gooooo0_l0
0009ooooo`;o00003_ooool2o`0000Cooooo2?l000000ooooooo0000o`00000Fo`000003ooooool0
003o000000;o000000?oooooo`000?l000000_l000000ooooooo0000o`000004o`0000Cooooo0ol0
0004ooooo`;o00000oooool3o`0000;ooooo0_l00004ooooo`?o00000oooool2o`0000;ooooo0ol0
0007ooooo`;o00001?ooool2o`000003ooooool0003o000000Oo00004?ooool2o`0000?ooooo1_l0
0004ooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o0000047ooooo0000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oiRHV?ooooooV9RHob4Q
8@06ooooo`?o0000<_ooool2o`0000gooooo0_l0000=ooooo`;o00001_ooool2o`0000Kooooo1_l0
0003ooooo`Co00000_ooool2o`000003ooooool0003o000001So000000Goooooo`000?l0003o0000
ooooo`04o`000003ooooool0003o000000;o00000_ooool2o`0000?ooooo0_l00005ooooo`;o0000
0_ooool2o`0000?ooooo0ol00003ooooo`?o00001?ooool3o`000004ooooool0003o0000ooooo`Co
00000_ooool2o`0000Wooooo0_l0000>ooooo`;o00001Oooool7o`0000;ooooo0_l00004ooooo`?o
00001?ooool3o`0004?ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo
00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo03;ooooo0_l0000=ooooo`;o
00003Oooool2o`0000Kooooo0_l00006ooooo`Co000000?oooooo`000?l000000_ooool2o`000003
ooooool0003o0000023o00000_ooool3o`0000Wooooo0_l00002ooooo`;o00000oooool2o`000003
ooooool0003o000000Sooooo0_l0000:ooooo`?o000000Coooooo`000?l0003ooooo1?l000000ooo
oooo0000o`00000;ooooo`;o00003Oooool2o`0000Oooooo1Ol00009ooooo`;o00001Oooool2o`00
04?ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qooo
ool02?ooool00ol0003oooooooooo`1Hooooo`;o00002Oooool4o`0000?ooooo9?l00002ooooo`?o
000000?oooooo`000?l000001Oooool2o`0000?ooooo0_l00003ooooo`;o00001Oooool2o`0000;o
oooo0_l00006ooooo`;o00004?ooool2o`0000[ooooo0ol0000;ooooo`;o00001_ooool8o`0000Oo
oooo1?l00005ooooo`;o0000@oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool00ooM
gMgo410@oiRHV008ooooo`03o`000?oooooooooo03?ooooo0_l0000>ooooo`;o00001oooool6o`00
00Kooooo0_l00006ooooo`;o000000?oooooo`000?l000000_l00003ooooo`Co00001?ooool7o`00
0003ooooool0003o000000So000000?oooooo`000?l000001Ol000000ooooooo0000o`000005oooo
o`;o00001Oooool2o`0000Gooooo0ol00007ooooo`;o00000_ooool2o`0000Kooooo0_l00004oooo
o`?o00004?ooool4o`000003ooooool0003o000000cooooo0_l00004ooooo`[o00001oooool4o`00
04[ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_oo
ool00ol0003oooooooooo`0cooooo`;o00002?ooool2o`0000;ooooo1?l00007ooooo`Ko00003_oo
ool2o`000003ooooool0003o000000;o00001?ooool4o`0000?ooooo6?l00002ooooo`Go00001Ooo
ool2o`0000Cooooo0_l00004ooooo`?o000000Coooooo`000?l0003o00001oooool2o`0000Kooooo
0_l00004ooooo`?o000000?oooooo`000?l000003Oooool4o`0000;ooooo1?l00006ooooo`;o0000
1oooool2o`0000;ooooo1?l00007ooooo`;o00002oooool2o`00047ooooo000Looooo`03o`000?oo
oooooooo03?ooooo0_l00008ooooo`;o00000_ooool2o`0000Wooooo0_l0000Eooooo`Ko000000?o
ooooo`000?l000001?l00002oooooaSo00000_ooool5o`0000Cooooo0ol000001?oooooo0000o`00
0?ooool2o`0000Sooooo0ol00007ooooo`;o00001?ooool2o`0000?ooooo0_l000001Ooooooo0000
o`000?l0003ooooo00;o00003_ooool2o`0000?ooooo1?l00003ooooo`;o000000?oooooo`000?l0
00002Oooool6o`000004ooooool0003o0000o`0000?ooooo0_l0000;ooooo`;o0000@Oooool001co
oooo00?o0000ooooooooool09_ooool2o`0001Gooooo0_l00002ooooo`;o00004oooool2o`0000co
oooo1Ol000001?oooooo0000o`000?ooool4o`0000?ooooo5Ol00003ooooo`Co000000?oooooo`00
0?l000000_ooool6o`000003ooooool0003o000001?ooooo0_l00003ooooo`Co000000Coooooo`00
0?l0003ooooo0_l00004ooooo`;o00000oooool2o`0000Oooooo0_l00003ooooo`;o00001Oooool2
o`0000_ooooo1_l00002ooooo`?o0000Doooool001cooooo00?o0000ooooooooool09_ooool2o`00
01Gooooo0_l00002ooooo`?o00001oooool2o`0000Oooooo1?l00005ooooo`;o00001Oooool4o`00
00Oooooo0ol00005ooooo`Go000000?oooooo`000?l000001?l00002ooooo`Go00000_ooool4o`00
0003ooooool0003o000000Cooooo0ol00002ooooo`;o00004Oooool4o`0000Cooooo1_l000000ooo
oooo0000o`000006o`0000?ooooo0_l00004ooooo`;o00006_ooool6o`0005Sooooo000Looooo`03
o`000?oooooooooo03oooooo0_l000000ooooooo0000o`000007ooooo`;o00001oooool2o`0000Oo
oooo0_l0000;ooooo`;o00000_ooool5o`000004ooooool0003o0000ooooo`Ko000000?oooooo`00
0?l000002_l00006ooooo`;o00000oooool2o`0000_ooooo1?l000001?oooooo0000o`000?ooool2
o`0000?ooooo1?l00002ooooo`So00000_ooool7o`0000Wooooo0_l0000Gooooo`;o00001?ooool2
o`0005Wooooo000Looooo`03o`000?oooooooooo03oooooo0_l0000Cooooo`;o00001oooool2o`00
00Kooooo0_l00003ooooo`;o00000_ooool5o`000003ooooool0003o000000;ooooo2?l00002oooo
o`Ko00001?ooool2o`0000;ooooo1?l000000ooooooo0000o`000008ooooo`;o000000?oooooo`00
0?l000000_l000001?oooooo0000o`000?ooool2o`000004ooooool0003o0000ooooo`?o000000?o
ooooo`000?l000001ol000000ooooooo0000o`000006o`00013ooooo0_l0000>ooooo`Co00000_oo
ool4o`0005Wooooo000Looooo`03o`000?oooooooooo053ooooo0_l00002ooooo`;o00001oooool2
o`0000Kooooo0_l000001?oooooo0000o`000?ooool2o`000004ooooool0003o0000o`0000Kooooo
1?l000000ooooooo0000o`000006o`0000?ooooo0_l00003ooooo`;o00001?ooool3o`0000[ooooo
1?l0000:oooooaGo00000_ooool6o`0000?ooooo0_l00007ooooo`;o00003_ooool4o`0000;ooooo
0_l0000:ooooo`;o0000Coooool001cooooo00?o0000ooooooooool0COooool5o`0000cooooo0_l0
0004ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`So000000?oooooo`000?l00000
0_l000001?oooooo0000o`000?ooool5o`000003ooooool0003o000000;o00001Oooool7o`0000?o
oooo0_l00007ooooo`;o000000?oooooo`000?l000001_oooolGo`000003ooooool0003o000000Co
00000oooool2o`0001;ooooo0_l00005ooooo`;o00002oooool2o`000003ooooool0003o000004oo
oooo000Looooo`03o`000?oooooooooo04gooooo1_l0000;ooooo`;o00001?ooool2o`0000Cooooo
0_l00002ooooo`go00000_ooool;o`0000Kooooo1Ol00005ooooo`Co00000_ooool2o`0000Cooooo
0_l000001?oooooo0000o`000?oooolLo`0000?ooooo0_l0000Eooooo`?o00001oooool2o`0000So
oooo1?l000000ooooooo0000o`000004ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0
@oooool2o`0000Sooooo0_l000001?oooooo0000o`000?l00004ooooo`?o00001?ooool2o`0000?o
oooo1?l00003ooooo`;o00001?ooool4o`000003ooooool0003o000000Go000000?oooooo`000?l0
00001_l0000Eooooo`;o00000_ooool2o`0000Kooooo7ol00003ooooo`?o00004Oooool3o`000003
ooooool0003o000000;ooooo1?l00002ooooo`;o00002?ooool7o`0000?ooooo1?l000000ooooooo
0000o`000014ooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00000oooool2o`0000gooooo
0ol00004ooooo`;o00000oooool4o`0000Gooooo0_l00004ooooo`[o00000_ooool2o`0000;ooooo
1?l0000Nooooo`Co000000?oooooo`000?l000004Ol000000ooooooo0000o`00000;o`0000[ooooo
0_l00006ooooo`?o00001Oooool6o`0000cooooo1Ol00003ooooo`Oo0000A?ooool001cooooo00?o
0000ooooooooool0@oooool2o`0000?ooooo0_l0000>ooooo`;o00001Oooool2o`0000?ooooo0_l0
0006ooooo`;o00001?ooool4o`0000?ooooo0_l00003ooooo`?o000000?oooooo`000?l000000_l0
000Nooooo`?o00000_ooool2o`0000;ooooo2ol000000ooooooo0000o`000005o`000003ooooool0
003o000000Oo00002_ooool2o`0000kooooo1_l0000<ooooo`Go00001Oooool4o`0004Gooooo000L
ooooo`;o0000A?ooool2o`0000Wooooo0_l00008ooooo`;o000000?oooooo`000?l000000_ooool2
o`0000Oooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l00005ooooo`;o00001?ooool5
o`0000Wooooo1?l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Oooooo0_l00004
ooooo`;o00000ooooolOo`0001Kooooo0_l000001?oooooo0000o`000?l0000<ooooo`Ko0000COoo
ool001cooooo00?o0000ooooooooool0C_ooool2o`0000?ooooo0_l00006ooooo`;o00000_ooool2
o`0000Gooooo1?l000000ooooooo0000o`000003o`0000[ooooo0_l00004ooooo`Co00002Oooool4
o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o00001oooool2o`0000Cooooo0_l00000
0ooooooo0000o`00000Oo`0000?ooooo0_l000000ooooooo0000o`00000;ooooo`;o00000oooool3
o`0000Gooooo0_l000000ooooooo0000o`000004ooooo`Go0000COooool001cooooo00?o0000oooo
ooooool0Doooool2o`0000[ooooo0_l000001?oooooo0000o`000?ooool3o`0000Kooooo0_l00005
ooooo`;o00000oooool2o`0000Kooooo0_l0000:ooooo`;o00001Oooool3o`0001;ooooo0_l00000
0ooooooo0000o`00000Ko`0000Oooooo0_l000000ooooooo0000o`00000;ooooo`;o00000oooool2
o`0000Kooooo0_l000000ooooooo0000o`000004ooooo`?o0000Coooool001cooooo00?o0000oooo
ooooool0FOooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0000_ooooo0_l00000
0ooooooo0000o`00000Eooooo`Co00000oooool5o`00017ooooo0_l00003ooooo`Go00000_oooolG
o`0000Gooooo1Ol0000Rooooo`;o0000Coooool001cooooo00?o0000ooooooooool0BOooool3o`00
00gooooo0ol00004ooooo`;o000000?oooooo`000?l000003?ooool3o`0001Cooooo0_l00002oooo
o`;o00001Oooool2o`0001;ooooo1?l00003ooooo`Ko000000?oooooo`000?l000004_l000000ooo
oooo0000o`000005ooooo`Co00002_ooool2o`000003ooooool0003o000000Gooooo0_l000000ooo
oooo0000o`000005ooooo`?o0000Doooool001cooooo00?o0000ooooooooool0BOooool3o`000003
ooooool0003o000000[ooooo0ol00003ooooo`?o000000?oooooo`000?l000003?ooool6o`00017o
oooo0_l0000Mooooo`Co00000ooooolNo`0000Gooooo1?l0000:ooooo`;o000000?oooooo`000?l0
00001Oooool2o`000003ooooool0003o000000Gooooo0ol0001Cooooo`007?ooool00ol0003ooooo
ooooo`1=ooooo`;o00002Oooool3o`0000Cooooo0ol0000Aooooo`Go00003oooool2o`0000Gooooo
0_l0000Gooooo`Co00000ooooolLo`0000Sooooo0_l00008ooooo`Go00004Oooool2o`0000Kooooo
0_l0001=ooooo`007?ooool00ol0003oooooooooo`1Hooooo`Go00000oooool2o`0000Sooooo0_l0
000:ooooo`;o00000oooool2o`0000Oooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo
0_l0000?ooooo`;o00001Oooool3o`0000;ooooo8?l00007ooooo`;o00002?ooool5o`00017ooooo
0_l00006ooooo`;o0000COooool001cooooo00?o0000ooooooooool0D_ooool2o`0000Kooooo0ol0
0004ooooo`;o00001oooool4o`0000gooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l0
0004ooooo`;o00004oooool2o`000003ooooool0003o000000;ooooo0_l00003oooooaco00000_oo
ool2o`0000Sooooo0_l00004ooooo`;o00001_ooool2o`0000Kooooo0_l0001Nooooo`007?ooool0
0ol0003oooooooooo`1<ooooo`;o00001?ooool2o`0000?ooooo0_l00008ooooo`;o00001oooool4
o`0000;ooooo0_l0000:ooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o00003Ooo
ool2o`000003ooooool0003o000000Kooooo0ol00004ooooo`?o000000?oooooo`000?l000000_oo
oolFo`0000;ooooo0_l00008ooooo`;o00000_ooool4o`0000;ooooo0_l00002ooooo`;o00000ooo
ool2o`000003ooooool0003o000005kooooo000Looooo`03o`000?oooooooooo04cooooo0_l00009
ooooo`;o00001Oooool2o`0000;ooooo0_l00006ooooo`;o00001?ooool2o`0000[ooooo0_l0000:
ooooo`;o00002Oooool2o`0000;ooooo0_l000000ooooooo0000o`000006ooooo`?o00001?oooolN
o`000003ooooool0003o000000;o000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l00004
ooooo`;o00000_ooool2o`0000?ooooo0_l00003ooooo`Co00001Oooool2o`0005?ooooo000Loooo
o`03o`000?oooooooooo03;ooooo0_l0000Wooooo`;o000000?oooooo`000?l000000_ooool4o`00
00gooooo0_l0000<ooooo`;o00002?ooool2o`0000Kooooo0_l00007ooooo`?o00002ooooolRo`00
0003ooooool0003o000000;ooooo0_l00004ooooo`;o00002?ooool2o`0000Gooooo0_l000000ooo
oooo0000o`000002o`0000Gooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`0booooo`;o
00009Oooool6o`0000Gooooo0_l00005ooooo`;o00001_ooool6o`0000Sooooo0_l00008ooooo`;o
00001_ooool2o`0000Oooooo0ol00008ooooo`;o00001?oooolKo`0000kooooo0_l00009ooooo`;o
00001Oooool2o`0000;ooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o0000
0_ooool2o`0000;ooooo0_l00003ooooo`?o00000_ooool2o`0000Sooooo1_l00004ooooo`;o0000
9_ooool5o`000003ooooool0003o000001So00002?ooool2o`0000Gooooo0_l0000Cooooo`?o0000
1oooool2o`0005;ooooo000Looooo`03o`000?oooooooooo04gooooo1?l00008ooooo`;o00001_oo
ool2o`0000;ooooo1?l0000<ooooo`;o00000_ooool2o`0000Cooooo0_l00006ooooo`;o00008?oo
ool3o`0000?ooooo0_l00003oooooa3o000000Coooooo`000?l0003ooooo0_l00005ooooo`;o0000
1Oooool2o`0001?ooooo0_l00008ooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0=Ooo
ool2o`0001Kooooo1?l00006ooooo`Co000000?oooooo`000?l000001oooool5o`0000_ooooo0_l0
000@ooooo`;o00001?ooool2o`0001cooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo
0ol000000ooooooo0000o`00000:o`0000;ooooo0ol0000Jooooo`;o00002oooool2o`0005Kooooo
000Looooo`;o0000=_ooool2o`0001Sooooo0_l00006ooooo`Co000000?oooooo`000?l000002Ooo
ool5o`0000Cooooo0_l00002ooooo`;o00001Oooool2o`000003ooooool0003o000000Kooooo0ol0
0004ooooo`;o00007?ooool6o`000004ooooool0003o0000oooooa3o000000Coooooo`000?l0003o
00006oooool4o`0000Wooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o0000
00?oooooo`000?l000001oooool7o`0000;ooooo1?l000001?oooooo0000o`000?l00005ooooo`;o
000000?oooooo`000?l000001_ooool2o`0002Gooooo0_l00003ooooo`;o00000_ooool9o`000003
ooooool0003o000000;o00000_ooool2o`0000[ooooo0_l0000>ooooo`;o00000_ooool2o`00067o
oooo000Looooo`03o`000?oooooooooo05Kooooo0ol00003ooooo`;o00001oooool3o`000003oooo
ool0003o000000?ooooo0_l000000ooooooo0000o`000002o`0000kooooo0_l0000Vooooo`?o0000
1?ooool2o`0000?ooooo0_l00005ooooo`?o00000oooool3o`0000_ooooo0_l0000<ooooo`Co0000
00Coooooo`000?l0003ooooo0_l0001Oooooo`007?ooool00ol0003oooooooooo`1Fooooo`?o0000
0_ooool2o`0000Wooooo0_l000000ooooooo0000o`000006ooooo`;o00004?ooool2o`0002Kooooo
0ol00003ooooo`?o00000oooool2o`0000;ooooo1_l00003ooooo`?o00006Oooool3o`0000;ooooo
0_l000001?oooooo0000o`000?ooool2o`0005cooooo000Looooo`03o`000?oooooooooo05_ooooo
0_l0000Rooooo`;o00009?ooool3o`0000Wooooo0_l000000ooooooo0000o`000002o`0000?ooooo
0ol0000Fooooo`?o00001_ooool2o`0000?ooooo0_l00007ooooo`;o0000G?ooool001cooooo00?o
0000ooooooooool0E_ooool2o`0000oooooo0ol00002ooooo`;o000000Coooooo`000?l0003o0000
2?ooool2o`0000?ooooo0_l0000Tooooo`?o00003?ooool4o`0000;ooooo0ol00003ooooo`;o0000
4_ooool3o`0000?ooooo0_l000001Ooooooo0000o`000?l0003ooooo00?o00001_ooool2o`0005go
oooo000Looooo`03o`000?oooooooooo05Kooooo0_l000000ooooooo0000o`00000<ooooo`?o0000
0_ooool8o`000003ooooool0003o000000?ooooo0_l0000@ooooo`;o0000;?ooool3o`0000?ooooo
0_l00007ooooo`;o00002?ooool2o`0000Gooooo1_l000001?oooooo0000o`000?l00006ooooo`Co
0000Foooool001cooooo00?o0000ooooooooool0EOooool2o`0000;ooooo0_l00006ooooo`?o0000
1?ooool2o`0000?ooooo0ol000001Ooooooo0000o`000?l0003ooooo00;o00005Oooool2o`0002Co
oooo0_l00004ooooo`;o00001?ooool4o`0000Kooooo0ol00008ooooo`;o000000?oooooo`000?l0
00000oooool2o`0000oooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`0mooooo`;o0000
5_ooool2o`0000?ooooo0_l00005ooooo`?o00002?ooool5o`0003Gooooo0_l0000:ooooo`;o0000
1?ooool2o`0000Cooooo1?l00006ooooo`;o00001?ooool2o`0000?ooooo0_l000000ooooooo0000
o`00001aooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00006?ooool5o`0000;ooooo0_l0
0002ooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`00000Cooooo`;o00001_oo
ool3o`0001Oooooo0ol0000?ooooo`;o00001?ooool2o`0000kooooo0_l00003ooooo`;o00003?oo
ool2o`0006Kooooo000Looooo`03o`000?oooooooooo05Oooooo0ol00004ooooo`;o00001_ooool2
o`0000cooooo0_l0000>ooooo`;o00001_ooool3o`0001Sooooo0_l0000<ooooo`;o00001oooool2
o`00023ooooo0ol00007ooooo`;o0000GOooool001cooooo00?o0000ooooooooool0?oooool2o`00
01kooooo0_l0000@ooooo`;o000000?oooooo`000?l00000>?ooool2o`0000Gooooo0_l0000@oooo
o`Go00003Oooool2o`0000Gooooo0ol00004ooooo`;o000000?oooooo`000?l000000oooool3o`00
05Oooooo000Looooo`03o`000?oooooooooo03oooooo0_l0000Gooooo`Co00000oooool2o`00013o
oooo1?l0000iooooo`;o00005oooool5o`0000Wooooo0_l00002ooooo`;o00003?ooool2o`0000Ko
oooo0ol0001Gooooo`007?ooool00ol0003oooooooooo`1Hooooo`Co00001?ooool2o`0000?ooooo
0_l00003ooooo`;o00001_ooool3o`0000?ooooo0_l000000ooooooo0000o`00000>ooooo`;o0000
?_ooool3o`0000Oooooo0_l00003ooooo`;o0000KOooool001cooooo00?o0000ooooooooool0H?oo
ool2o`0000?ooooo0_l00003ooooo`;o00003?ooool2o`000003ooooool0003o000000kooooo0_l0
000Pooooo`;o00004oooool2o`0000Gooooo1Ol00003ooooo`;o00000oooool2o`0000;ooooo0_l0
00000ooooooo0000o`00001Zooooo`007?ooool00ol0003oooooooooo`1Qooooo`;o00003oooool2
o`0000oooooo0_l0000Rooooo`;o00001?ooool2o`0001?ooooo0_l00005ooooo`;o00001_ooool4
o`000003ooooool0003o000000Co000000?oooooo`000?l000002Oooool2o`0005oooooo000Loooo
o`;o0000AOooool2o`0001_ooooo0_l00003ooooo`;o00001?ooool2o`0000Cooooo0_l00002oooo
o`;o00002_ooool3o`00027ooooo1?l00004ooooo`;o00002Oooool2o`0001;ooooo0_l00002oooo
o`Co00000oooool2o`0000kooooo0_l0001Oooooo`007?ooool00ol0003oooooooooo`14ooooo`;o
00008?ooool4o`0000;ooooo0_l00008ooooo`;o00002_ooool2o`000003ooooool0003o000000Co
oooo0_l0000Iooooo`Co00001?ooool4o`0000Kooooo0ol000000ooooooo0000o`00000?ooooo`;o
00000oooool2o`0000gooooo0_l0001Vooooo`007?ooool00ol0003oooooooooo`1Tooooo`?o0000
00?oooooo`000?l000004oooool2o`0000;ooooo0_l00002ooooo`;o00001?ooool2o`0001Wooooo
0_l00004ooooo`;o00000_ooool2o`0000Kooooo0_l00002ooooo`;o00005?ooool2o`0000gooooo
0_l0001Vooooo`007?ooool00ol0003oooooooooo`1Tooooo`?o000000?oooooo`000?l000004ooo
ool2o`0000;ooooo0_l00008ooooo`;o00007oooool6o`0000[ooooo0_l00002ooooo`;o00000ooo
ool2o`0008;ooooo000Looooo`03o`000?oooooooooo06;ooooo0_l00004ooooo`;o00002oooool2
o`0000Cooooo0_l0000>ooooo`;o00007?ooool4o`000004ooooool0003o0000o`0000Sooooo0_l0
00000ooooooo0000o`000004o`0000?ooooo0_l0000Booooo`;o0000K_ooool001cooooo00?o0000
ooooooooool0H_ooool2o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`;o000000?ooooo
o`000?l000000_l000001Ooooooo0000o`000?l0003ooooo00;o00001oooool4o`0001kooooo1?l0
0002ooooo`Co00001_ooool2o`0000?ooooo0_l0000Cooooo`Co00000_ooool2o`0006kooooo000L
ooooo`03o`000?oooooooooo06Oooooo0_l000000ooooooo0000o`000006ooooo`;o00000oooool2
o`000003ooooool0003o000000;ooooo0_l00007ooooo`Co00009?ooool4o`0000kooooo0_l00000
1?oooooo0000o`000?ooool9o`000003ooooool0003o000000Co00001?ooool2o`0006cooooo000L
ooooo`03o`000?oooooooooo05oooooo0_l0000:ooooo`;o00003Oooool2o`000003ooooool0003o
000002kooooo1?l00003ooooo`;o00002oooool2o`000004ooooool0003o0000ooooo`Wo000000?o
ooooo`000?l000001oooool3o`0006cooooo000Looooo`03o`000?oooooooooo05oooooo0_l00009
ooooo`?o00004?ooool2o`0002;ooooo0_l0000:ooooo`?o00001?ooool2o`000003ooooool0003o
0000017ooooo0_l00003ooooo`Co00001oooool2o`0000Wooooo0_l0001Rooooo`007?ooool00ol0
003oooooooooo`1Zooooo`;o00003Oooool2o`0002Kooooo1?l00008ooooo`?o00001?ooool5o`00
01Kooooo1?l0000Booooo`;o0000H_ooool001cooooo00?o0000ooooooooool0COooool2o`0001Oo
oooo0_l00003ooooo`;o00003?ooool2o`000003ooooool0003o000002Gooooo0_l0000;ooooo`;o
00000_ooool4o`0000Oooooo0_l0000:ooooo`;o0000O?ooool001cooooo00?o0000ooooooooool0
COooool2o`0001Oooooo0ol00002ooooo`;o00001_ooool2o`0000Oooooo1?l0000Yooooo`?o0000
1?ooool2o`0000Gooooo0_l000000ooooooo0000o`000003ooooo`;o00001oooool2o`000003oooo
ool0003o000007cooooo000Looooo`03o`000?oooooooooo06Oooooo0_l0000:ooooo`;o00002Ooo
ool4o`0002Oooooo0ol0000;ooooo`Go00003?ooool2o`0007oooooo000Looooo`03o`000?oooooo
oooo06Oooooo0_l0000?ooooo`;o00001_ooool2o`0002kooooo0_l00006ooooo`;o00003_ooool2
o`0007oooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ
8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1@ooooo`;o00007oooool2o`0000Gooooo
0_l0000Tooooo`;o00004?ooool2o`0001Kooooo0_l0001oooooo`0000KoooooogMgMonHV9Sooooo
oiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000oooo
ooooool0D?ooool2o`0001oooooo0_l00007ooooo`;o00008_ooool2o`0000Gooooo1?l00007oooo
o`Co00000oooool2o`0000Wooooo0_l00002ooooo`;o0000POooool00003ooooool@413ooooo00;o
oooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool0Loooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00009Oooool4o`00
00Oooooo1?l00003ooooo`;o00001Oooool2o`0000;ooooo0ol000000ooooooo0000o`000021oooo
o`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRH
V?lb<S801_ooool3o`0007?ooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o0000
01;ooooo0_l000000ooooooo0000o`00000=ooooo`Co00001?ooool2o`0000Cooooo0ol00009oooo
o`;o00000oooool2o`0000_ooooo0_l0001gooooo`0000?oooooo`000?ooool00_ooool00ol0003o
ooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`1koooo
o`;o00000oooool2o`0000Sooooo0_l00006ooooo`;o000000?oooooo`000?l000000oooool2o`00
00Sooooo0_l00004ooooo`Co000000?oooooo`000?l000000_ooool2o`0001_ooooo0_l0001goooo
o`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj
^_l@41001_ooool00ol0003oooooooooo`1^ooooo`;o00002?ooool2o`0000;ooooo0_l00002oooo
o`;o00002?ooool2o`0000kooooo0_l0000<ooooo`Co00000oooool2o`0009Sooooo00001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oo
oooooooo06kooooo0_l00008ooooo`;o00000_ooool2o`0000cooooo0_l0000Fooooo`;o00001?oo
ool2o`0009oooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@06ooooo`03o`000?oooooooooo0:;ooooo0_l0002Uooooo`007?ooool00ol0003ooooo
ooooo`1jooooo`;o00000_ooool2o`0000Sooooo1?l00005ooooo`;o00002oooool3o`00017ooooo
0_l0002Eooooo`007?ooool00ol0003oooooooooo`1jooooo`;o00000_ooool2o`0000Sooooo1?l0
0005ooooo`;o00002oooool3o`00017ooooo0_l0002Eooooo`007?ooool00ol0003oooooooooo`1n
ooooo`;o0000:?ooool2o`0000Kooooo0_l0000?ooooo`;o0000Q_ooool001cooooo00?o0000oooo
ooooool0G?ooool2o`0001[ooooo0_l00007ooooo`;o00009Oooool2o`0000Kooooo0_l0000:oooo
o`;o00000oooool2o`0008Kooooo000Looooo`03o`000?oooooooooo05cooooo0_l0000Jooooo`;o
00001oooool2o`0001Cooooo0_l0000@ooooo`;o00004Oooool2o`0008_ooooo000Looooo`03o`00
0?oooooooooo08Wooooo0_l0000<ooooo`;o00004?ooool2o`0000_ooooo0_l0002Aooooo`007?oo
ool00ol0003oooooooooo`29ooooo`Co00006?ooool2o`0000oooooo0_l0002Aooooo`007?ooool0
0ol0003oooooooooo`2;ooooo`;o00000_ooool2o`0000Gooooo0_l000000ooooooo0000o`00000:
ooooo`?o00001_ooool2o`000004ooooool0003o0000o`0009Gooooo000Looooo`03o`000?oooooo
oooo08oooooo0_l00005ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Gooooo0_l00006
ooooo`;o000000Coooooo`000?l0003o0000UOooool001cooooo00?o0000ooooooooool0Woooool2
o`0000Kooooo0_l0002Pooooo`007?ooool00ol0003oooooooooo`2Qooooo`;o00001?ooool2o`00
0:3ooooo000Looooo`;o0000Ioooool2o`0003?ooooo0_l00004ooooo`;o0000Y_ooool001cooooo
00?o0000ooooooooool0I_ooool2o`0003?ooooo0_l0002/ooooo`007?ooool00ol0003ooooooooo
o`2Wooooo`;o0000X?ooool001cooooo00?o0000ooooooooool0Y?ooool2o`000003ooooool0003o
000000Sooooo0_l0002Fooooo`007?ooool00ol0003oooooooooo`2Tooooo`;o00000_ooool2o`00
00Oooooo0_l0002Fooooo`007?ooool00ol0003oooooooooo`2Xooooo`;o0000Woooool001cooooo
00?o0000ooooooooool0KOooool2o`000=[ooooo000Looooo`03o`000?oooooooooo06gooooo0_l0
003Jooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`1eooooo`;o0000d_ooool001cooooo00?o0000ooooooooool0MOooool2o`000=;ooooo000L
ooooo`03o`000?oooooooooo07[ooooo0_l0003=ooooo`007?ooool00ol0003oooooooooo`1joooo
o`;o000000?oooooo`000?l000000_ooool2o`000<Kooooo000Looooo`03o`000?oooooooooo07go
oooo0_l00002ooooo`;o0000a_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0R?ooool2o`000;oooooo000Loooo
o`03o`000?oooooooooo08Sooooo0_l0002oooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0
oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB_oo
ool001Cooooo00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o0000oooo
ooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`00
0?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`004_ooool0
0omEEEGoIVIVo`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
002Uooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05_ooool01Om4A4Co0000
o`000?lb<S;ogMgM00Cooooo00?o0000onk^k_ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
093ooooo002Vooooo`05o`000?ooooooooooooooool000002Oooool6o`0000gooooo00?oMgMgoc8b
<_ooool00oooool00omEEEGoZJVYooooo`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0T?ooool0
0:Kooooo00Go0000ooooooooooooooooo`00000Mooooo`03o`000?oooooooooo00;ooooo00?oZJVY
oeEEEOooool00oooool01Ol@413ooooooooooooooooo410@093ooooo002Vooooo`05o`000?oooooo
ooooooooool000002Oooool6o`0000gooooo00?oMgMgoc8b<_ooool01?ooool00olQ8B7ooooooooo
o`02ooooo`05o`000?ooooooooooooooool00000T?ooool00:Kooooo00Go0000ohN7QoooooooZJVY
o`00000Iooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00omEEEGoc<c<ooooo`02ooooo`05
o`000?ooooooooooooooool00000T?ooool00:Gooooo00?o410@o`000?mgMgL00_l000000onHV9So
ooooooooo`0Gooooo`03o`000?oooooooooo00Oooooo00?oZJVYogMgMoooool00_ooool01Ol@413o
oooooooooooooooo410@093ooooo0034ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooo
oooooooooc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0T?ooool00<Cooooo1?l00003oooo
o`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^093ooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(576) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.53122 .69149 Mdot
.55966 .65063 Mdot
.47325 .33602 Mdot
.40928 .55033 Mdot
.35517 .30029 Mdot
.51245 .33811 Mdot
.65488 .40835 Mdot
.67719 .44369 Mdot
.51651 .3298 Mdot
.32882 .7181 Mdot
.68194 .42518 Mdot
.41854 .48859 Mdot
.66189 .42164 Mdot
.37823 .56431 Mdot
.63608 .55268 Mdot
.46749 .56071 Mdot
.593 .67053 Mdot
.40531 .30937 Mdot
.46796 .55857 Mdot
.47769 .33531 Mdot
.41836 .45403 Mdot
.37928 .55248 Mdot
.58732 .66363 Mdot
.37798 .56026 Mdot
.43033 .55591 Mdot
.56377 .6614 Mdot
.52664 .68166 Mdot
.41973 .52413 Mdot
.39189 .51438 Mdot
.6742 .43388 Mdot
.43273 .21542 Mdot
.69836 .77142 Mdot
.40013 .4968 Mdot
.50291 .73819 Mdot
.68364 .4418 Mdot
.72276 .30324 Mdot
.53225 .32467 Mdot
.66339 .44481 Mdot
.69659 .42163 Mdot
.69897 .41954 Mdot
.64572 .41236 Mdot
.55408 .66071 Mdot
.67713 .38336 Mdot
.50283 .38852 Mdot
.39615 .59232 Mdot
.67177 .73449 Mdot
.45453 .18786 Mdot
.4122 .52119 Mdot
.55314 .70417 Mdot
.48498 .34488 Mdot
.20216 .49851 Mdot
.64001 .43881 Mdot
.64371 .61516 Mdot
.20107 .7307 Mdot
.67375 .42757 Mdot
.40873 .53526 Mdot
.49214 .33378 Mdot
.39911 .55669 Mdot
.38586 .52679 Mdot
.48139 .69871 Mdot
.36832 .53648 Mdot
.37833 .33988 Mdot
.51752 .66389 Mdot
.49552 .30436 Mdot
.51081 .3306 Mdot
.64288 .42969 Mdot
.54818 .63967 Mdot
.65227 .42497 Mdot
.32282 .55263 Mdot
.48161 .34878 Mdot
.40786 .52262 Mdot
.68027 .43139 Mdot
.56421 .64527 Mdot
.41738 .59098 Mdot
.69892 .67559 Mdot
.60337 .3946 Mdot
.44099 .34044 Mdot
.48701 .79285 Mdot
.19348 .59677 Mdot
.5541 .26689 Mdot
.36822 .57072 Mdot
.15567 .55001 Mdot
.64257 .53788 Mdot
.54698 .64788 Mdot
.5272 .72136 Mdot
.81248 .49007 Mdot
.40273 .51287 Mdot
.41203 .41819 Mdot
.43722 .52066 Mdot
.54127 .5382 Mdot
.51515 .32512 Mdot
.5762 .66267 Mdot
.39616 .59317 Mdot
.44337 .54927 Mdot
.32837 .66245 Mdot
.33704 .53561 Mdot
.40625 .57865 Mdot
.53008 .71458 Mdot
.68059 .40716 Mdot
.31232 .53251 Mdot
.42012 .2957 Mdot
.66921 .60242 Mdot
.41593 .56098 Mdot
.52919 .35504 Mdot
.52113 .68763 Mdot
.40772 .58581 Mdot
.6544 .43505 Mdot
.36873 .55642 Mdot
.64449 .45436 Mdot
.5874 .68393 Mdot
.4426 .53914 Mdot
.36032 .32964 Mdot
.58457 .5768 Mdot
.55692 .69614 Mdot
.37128 .7888 Mdot
.36967 .53877 Mdot
.3815 .53838 Mdot
.54863 .6505 Mdot
.49431 .31615 Mdot
.46587 .43169 Mdot
.5834 .6561 Mdot
.69759 .41659 Mdot
.57902 .70071 Mdot
.4495 .55716 Mdot
.49042 .31784 Mdot
.68358 .60345 Mdot
.66358 .60107 Mdot
.31723 .3032 Mdot
.42264 .58919 Mdot
.6176 .61122 Mdot
.51621 .35169 Mdot
.55318 .65596 Mdot
.65656 .42863 Mdot
.36088 .52651 Mdot
.5425 .68172 Mdot
.69426 .41391 Mdot
.3886 .35565 Mdot
.35027 .3012 Mdot
.53543 .68362 Mdot
.2697 .55682 Mdot
.64031 .44472 Mdot
.69945 .41032 Mdot
.2085 .48981 Mdot
.54151 .65068 Mdot
.40038 .33037 Mdot
.68549 .39375 Mdot
.29526 .4143 Mdot
.3504 .54409 Mdot
.24692 .38525 Mdot
.14647 .47978 Mdot
.20483 .49451 Mdot
.5979 .78511 Mdot
.37267 .31579 Mdot
.68379 .39142 Mdot
.41854 .53815 Mdot
.54922 .67618 Mdot
.54347 .67004 Mdot
.4411 .56677 Mdot
.43642 .55611 Mdot
.38358 .58221 Mdot
.36245 .52827 Mdot
.6358 .21595 Mdot
.37457 .5815 Mdot
.65998 .49946 Mdot
.54828 .68717 Mdot
.43127 .57009 Mdot
.53913 .35535 Mdot
.39574 .60714 Mdot
.66507 .44452 Mdot
.39246 .52922 Mdot
.43425 .55107 Mdot
.3523 .58757 Mdot
.68238 .38714 Mdot
.75448 .62898 Mdot
.22649 .66296 Mdot
.74366 .35994 Mdot
.64616 .66332 Mdot
.50463 .34976 Mdot
.35657 .56646 Mdot
.3871 .31674 Mdot
.3752 .47796 Mdot
.37997 .53012 Mdot
.19528 .50888 Mdot
.43419 .5339 Mdot
.54183 .79181 Mdot
.29955 .56501 Mdot
.81799 .46252 Mdot
.69774 .49881 Mdot
.3704 .52865 Mdot
.29172 .67683 Mdot
.26369 .35414 Mdot
.38102 .22592 Mdot
.6655 .43309 Mdot
.5455 .3534 Mdot
.50834 .31478 Mdot
.70223 .41694 Mdot
.30998 .57794 Mdot
.34102 .73203 Mdot
.32221 .5636 Mdot
.68321 .60538 Mdot
.54351 .6272 Mdot
.37993 .30941 Mdot
.53538 .68496 Mdot
.15832 .58573 Mdot
.42968 .43894 Mdot
.58422 .33656 Mdot
.40018 .30489 Mdot
.50246 .36814 Mdot
.68412 .61719 Mdot
.39677 .31988 Mdot
.40656 .56672 Mdot
.57732 .69815 Mdot
.26071 .35579 Mdot
.45298 .59625 Mdot
.73309 .23669 Mdot
.54009 .64552 Mdot
.56437 .50355 Mdot
.6673 .42904 Mdot
.50806 .30566 Mdot
.40405 .51342 Mdot
.39234 .5703 Mdot
.51892 .67018 Mdot
.40544 .51808 Mdot
.48208 .47163 Mdot
.4337 .54293 Mdot
.54599 .31885 Mdot
.41584 .35914 Mdot
.66489 .46359 Mdot
.31548 .31607 Mdot
.57465 .64885 Mdot
.6058 .47544 Mdot
.5334 .35578 Mdot
.49706 .61295 Mdot
.67164 .43874 Mdot
.38032 .35552 Mdot
.54117 .3365 Mdot
.36129 .35115 Mdot
.39656 .59824 Mdot
.52645 .3237 Mdot
.38852 .34684 Mdot
.59075 .3898 Mdot
.40755 .57871 Mdot
.25763 .40918 Mdot
.67033 .39239 Mdot
.52938 .68394 Mdot
.37017 .5321 Mdot
.68691 .59997 Mdot
.43047 .59814 Mdot
.61176 .58867 Mdot
.69377 .61249 Mdot
.65653 .62466 Mdot
.57857 .31301 Mdot
.40584 .32889 Mdot
.66264 .6999 Mdot
.49747 .43847 Mdot
.59267 .66832 Mdot
.3785 .59437 Mdot
.79292 .60967 Mdot
.6691 .39138 Mdot
.40596 .56252 Mdot
.80599 .4717 Mdot
.68364 .39256 Mdot
.39449 .5487 Mdot
.64669 .40763 Mdot
.54454 .67403 Mdot
.57549 .43761 Mdot
.58112 .7042 Mdot
.40691 .54789 Mdot
.66862 .40191 Mdot
.54772 .34687 Mdot
.56374 .66225 Mdot
.37071 .55075 Mdot
.36723 .5742 Mdot
.68289 .61008 Mdot
.43222 .57591 Mdot
.81556 .58073 Mdot
.41433 .52292 Mdot
.49933 .36766 Mdot
.34049 .53031 Mdot
.24449 .36644 Mdot
.34541 .30191 Mdot
.54924 .63586 Mdot
.69034 .61697 Mdot
.50758 .32191 Mdot
.58034 .40424 Mdot
.33201 .29681 Mdot
.36997 .56487 Mdot
.66415 .6115 Mdot
.56729 .4988 Mdot
.64757 .43477 Mdot
.38713 .50602 Mdot
.47431 .45029 Mdot
.5289 .33191 Mdot
.68565 .61134 Mdot
.35682 .61681 Mdot
.54475 .70582 Mdot
.41102 .53543 Mdot
.5393 .33049 Mdot
.55037 .70609 Mdot
.36419 .52187 Mdot
.55537 .20223 Mdot
.68051 .59827 Mdot
.66213 .39622 Mdot
.40742 .64601 Mdot
.36949 .58333 Mdot
.51112 .31337 Mdot
.53934 .67653 Mdot
.67577 .41616 Mdot
.57954 .68943 Mdot
.28003 .32562 Mdot
.62456 .63151 Mdot
.64142 .24873 Mdot
.41406 .32556 Mdot
.55891 .83373 Mdot
.73972 .34469 Mdot
.59619 .61383 Mdot
.40368 .38118 Mdot
.79557 .38091 Mdot
.54034 .34584 Mdot
.26863 .613 Mdot
.49786 .32442 Mdot
.41707 .54906 Mdot
.51292 .33561 Mdot
.83308 .55704 Mdot
.42779 .52893 Mdot
.49838 .34661 Mdot
.61669 .22335 Mdot
.4343 .53012 Mdot
.54719 .68932 Mdot
.70508 .7429 Mdot
.40942 .80745 Mdot
.29393 .50009 Mdot
.49465 .34505 Mdot
.26483 .62773 Mdot
.41405 .5183 Mdot
.46431 .58695 Mdot
.55486 .67363 Mdot
.45188 .5424 Mdot
.36834 .31369 Mdot
.35795 .34112 Mdot
.21859 .50601 Mdot
.44958 .8244 Mdot
.44068 .6255 Mdot
.55696 .66398 Mdot
.18678 .58335 Mdot
.70092 .6777 Mdot
.66742 .59789 Mdot
.69287 .43173 Mdot
.75168 .62652 Mdot
.37036 .62271 Mdot
.29148 .60514 Mdot
.50944 .484 Mdot
.577 .66068 Mdot
.6872 .30902 Mdot
.67184 .41184 Mdot
.26796 .67494 Mdot
.38071 .73604 Mdot
.38765 .58408 Mdot
.63687 .4087 Mdot
.33561 .51145 Mdot
.49934 .48081 Mdot
.25118 .40246 Mdot
.56613 .24869 Mdot
.40935 .56339 Mdot
.66927 .70014 Mdot
.38339 .53186 Mdot
.26356 .36242 Mdot
.40584 .55322 Mdot
.57501 .69262 Mdot
.36096 .62923 Mdot
.50036 .41998 Mdot
.27847 .71621 Mdot
.43508 .44149 Mdot
.40041 .31661 Mdot
.3812 .56603 Mdot
.39289 .57874 Mdot
.37929 .34529 Mdot
.57632 .67095 Mdot
.36453 .58727 Mdot
.46233 .18351 Mdot
.37748 .58473 Mdot
.64295 .44 Mdot
.55934 .43227 Mdot
.53969 .80117 Mdot
.42912 .52161 Mdot
.53827 .70202 Mdot
.64627 .42917 Mdot
.68978 .42913 Mdot
.41943 .62993 Mdot
.66418 .39218 Mdot
.41554 .53128 Mdot
.56108 .43462 Mdot
.58928 .66897 Mdot
.36367 .48663 Mdot
.57576 .67595 Mdot
.18022 .53019 Mdot
.67187 .38637 Mdot
.65882 .61712 Mdot
.26114 .60124 Mdot
.66098 .40967 Mdot
.48629 .5408 Mdot
.32619 .61089 Mdot
.36034 .60809 Mdot
.60048 .62345 Mdot
.54854 .33489 Mdot
.66429 .62272 Mdot
.67608 .42439 Mdot
.37721 .58336 Mdot
.41342 .58006 Mdot
.63313 .42207 Mdot
.43613 .67091 Mdot
.43873 .21537 Mdot
.40481 .54333 Mdot
.57865 .68623 Mdot
.55388 .65717 Mdot
.34494 .55629 Mdot
.37698 .53175 Mdot
.51905 .37078 Mdot
.6628 .61235 Mdot
.67337 .62476 Mdot
.65918 .60557 Mdot
.55815 .34419 Mdot
.52839 .84108 Mdot
.69934 .4097 Mdot
.62191 .79206 Mdot
.79106 .5374 Mdot
.44076 .61994 Mdot
.52874 .3198 Mdot
.39171 .55864 Mdot
.4181 .5678 Mdot
.67263 .40284 Mdot
.42512 .83043 Mdot
.38299 .49487 Mdot
.52584 .67206 Mdot
.63774 .43322 Mdot
.39978 .48111 Mdot
.60993 .39511 Mdot
.36443 .33864 Mdot
.39593 .44483 Mdot
.6358 .40861 Mdot
.58216 .69032 Mdot
.63328 .41332 Mdot
.39019 .58058 Mdot
.35346 .61001 Mdot
.57635 .65753 Mdot
.40799 .34349 Mdot
.3943 .59623 Mdot
.3939 .5461 Mdot
.27546 .28238 Mdot
.69532 .67877 Mdot
.53299 .28598 Mdot
.4243 .55593 Mdot
.3444 .59083 Mdot
.40453 .35356 Mdot
.36715 .58481 Mdot
.38671 .51464 Mdot
.58191 .57134 Mdot
.66804 .46187 Mdot
.37527 .29891 Mdot
.26386 .68259 Mdot
.53459 .64938 Mdot
.81955 .55824 Mdot
.6732 .60106 Mdot
.64802 .46044 Mdot
.5782 .44212 Mdot
.67143 .62049 Mdot
.79481 .47558 Mdot
.74706 .37454 Mdot
.66254 .61768 Mdot
.47758 .31054 Mdot
.34305 .48202 Mdot
.37676 .51457 Mdot
.39427 .53397 Mdot
.40558 .33363 Mdot
.5346 .66033 Mdot
.67058 .50348 Mdot
.68812 .45716 Mdot
.37988 .54673 Mdot
.59675 .69716 Mdot
.81538 .47562 Mdot
.68297 .61555 Mdot
.37762 .31759 Mdot
.40848 .32407 Mdot
.38376 .53401 Mdot
.53417 .57537 Mdot
.55875 .66195 Mdot
.37084 .55076 Mdot
.35397 .54573 Mdot
.48859 .32659 Mdot
.57052 .70106 Mdot
.5311 .35982 Mdot
.69552 .61347 Mdot
.77431 .31965 Mdot
.29496 .25391 Mdot
.67972 .39624 Mdot
.71961 .33381 Mdot
.63703 .39441 Mdot
.58374 .2584 Mdot
.66132 .61411 Mdot
.37456 .55058 Mdot
.57388 .64542 Mdot
.36879 .5541 Mdot
.38422 .58917 Mdot
.39747 .58752 Mdot
.44639 .62352 Mdot
.19504 .50042 Mdot
.37883 .32427 Mdot
.3285 .54006 Mdot
.52268 .37382 Mdot
.81433 .46332 Mdot
.73294 .70082 Mdot
.38544 .57149 Mdot
.38343 .53959 Mdot
.5359 .64364 Mdot
.40147 .59877 Mdot
.65796 .4383 Mdot
.54103 .64777 Mdot
.41426 .56797 Mdot
.36837 .27969 Mdot
.35633 .57867 Mdot
.72265 .32809 Mdot
.63338 .41195 Mdot
.38427 .44932 Mdot
.339 .59414 Mdot
.66016 .6161 Mdot
.66438 .62227 Mdot
.69141 .60084 Mdot
.63679 .42268 Mdot
.49042 .32444 Mdot
.472 .35691 Mdot
.34546 .61251 Mdot
.41962 .53628 Mdot
.35067 .60503 Mdot
.56154 .35948 Mdot
.49216 .42981 Mdot
.63045 .73917 Mdot
.299 .57038 Mdot
.55005 .35978 Mdot
.57308 .72225 Mdot
.30969 .7529 Mdot
.53347 .65525 Mdot
.43622 .34791 Mdot
.6724 .44142 Mdot
.36388 .32144 Mdot
.20619 .55064 Mdot
.58641 .66624 Mdot
.52038 .67015 Mdot
.5016 .34932 Mdot
.59751 .51552 Mdot
.30555 .8394 Mdot
.52507 .35331 Mdot
.40228 .37602 Mdot
.55716 .67016 Mdot
.39583 .49421 Mdot
.57039 .49779 Mdot
.58404 .52532 Mdot
.49867 .33762 Mdot
.3664 .57164 Mdot
.49155 .5424 Mdot
.51797 .37049 Mdot
.37942 .50628 Mdot
.49521 .34831 Mdot
.65666 .39498 Mdot
.5139 .35455 Mdot
.60122 .66169 Mdot
.40347 .59465 Mdot
.22672 .76261 Mdot
.63885 .53195 Mdot
.36565 .54589 Mdot
.6357 .43158 Mdot
.591 .19871 Mdot
.39741 .58052 Mdot
.37469 .30715 Mdot
.55114 .36273 Mdot
.55122 .22588 Mdot
.39141 .5164 Mdot
.50537 .33637 Mdot
.59053 .64385 Mdot
.44698 .33356 Mdot
.50726 .27528 Mdot
.66876 .6245 Mdot
.54498 .67721 Mdot
.65119 .63069 Mdot
.68494 .44206 Mdot
.37064 .59727 Mdot
.3517 .56008 Mdot
.55946 .69237 Mdot
.61546 .37789 Mdot
.34978 .51534 Mdot
.36855 .57077 Mdot
.51872 .36881 Mdot
.53861 .37452 Mdot
.66116 .56156 Mdot
.54091 .35009 Mdot
.34299 .5882 Mdot
.56221 .69394 Mdot
.41362 .54533 Mdot
.54062 .68463 Mdot
.382 .59524 Mdot
.62991 .70052 Mdot
.53334 .65753 Mdot
.54417 .60353 Mdot
.43522 .57583 Mdot
.4682 .6348 Mdot
.37819 .58932 Mdot
.40703 .57292 Mdot
.55538 .3617 Mdot
.38908 .33001 Mdot
.40887 .50333 Mdot
.5988 .45993 Mdot
.39019 .36209 Mdot
.54744 .7594 Mdot
.4945 .31666 Mdot
.40015 .35165 Mdot
.2603 .45048 Mdot
.69007 .61708 Mdot
.3764 .33411 Mdot
.69457 .57917 Mdot
.67709 .39631 Mdot
.59249 .68518 Mdot
.43813 .5385 Mdot
.79895 .37101 Mdot
.43277 .21585 Mdot
.67933 .6115 Mdot
.3714 .53308 Mdot
.39495 .5617 Mdot
.55428 .709 Mdot
.15778 .5697 Mdot
.52613 .30719 Mdot
.41135 .56412 Mdot
.58192 .65635 Mdot
.15396 .51552 Mdot
.49879 .3544 Mdot
.37238 .32824 Mdot
.64212 .39504 Mdot
.55806 .62115 Mdot
.66192 .62389 Mdot
.67153 .38598 Mdot
.55095 .30986 Mdot
.1887 .52182 Mdot
.39174 .51716 Mdot
.54601 .33398 Mdot
.20412 .49536 Mdot
.30302 .55376 Mdot
.66404 .37691 Mdot
.62577 .69873 Mdot
.57514 .66013 Mdot
.63412 .4252 Mdot
.40143 .31624 Mdot
.59171 .67557 Mdot
.57742 .671 Mdot
.67889 .44224 Mdot
.72336 .471 Mdot
.56792 .50508 Mdot
.65395 .44241 Mdot
.57824 .54895 Mdot
.21174 .48459 Mdot
.66176 .60911 Mdot
.37787 .31693 Mdot
.28172 .31107 Mdot
.55727 .66025 Mdot
.75242 .62656 Mdot
.19782 .50529 Mdot
.40645 .57811 Mdot
.39748 .34243 Mdot
.8057 .49816 Mdot
.67817 .46476 Mdot
.69324 .4095 Mdot
.43749 .4193 Mdot
.3871 .30783 Mdot
.34833 .55551 Mdot
.52726 .80489 Mdot
.44099 .54473 Mdot
.67855 .39025 Mdot
.50187 .48995 Mdot
.5679 .70095 Mdot
.68617 .44235 Mdot
.47511 .46455 Mdot
.41913 .56531 Mdot
.36164 .5422 Mdot
.29723 .34211 Mdot
.56958 .7027 Mdot
.65855 .62348 Mdot
.36598 .56245 Mdot
.39907 .55351 Mdot
.35961 .59086 Mdot
.25488 .58798 Mdot
.56376 .58858 Mdot
.41177 .56951 Mdot
.52974 .313 Mdot
.37322 .61035 Mdot
.37095 .52566 Mdot
.56964 .71131 Mdot
.22872 .38544 Mdot
.69654 .61232 Mdot
.39655 .53677 Mdot
.40424 .54282 Mdot
.69653 .42693 Mdot
.56798 .50204 Mdot
.584 .52842 Mdot
.49563 .36186 Mdot
.38551 .39734 Mdot
.3238 .57456 Mdot
.54894 .68358 Mdot
.36383 .31703 Mdot
.35216 .59214 Mdot
.52991 .6573 Mdot
.31915 .58807 Mdot
.514 .37186 Mdot
.66555 .61323 Mdot
.31237 .61689 Mdot
.38094 .33732 Mdot
.64656 .45176 Mdot
.64905 .78376 Mdot
.53912 .3589 Mdot
.42663 .54292 Mdot
.51015 .38468 Mdot
.53042 .34381 Mdot
.68098 .60839 Mdot
.42633 .60984 Mdot
.5466 .6695 Mdot
.57386 .69762 Mdot
.22378 .44793 Mdot
.55672 .33321 Mdot
.19543 .36742 Mdot
.65805 .39406 Mdot
.39077 .50713 Mdot
.73091 .68438 Mdot
.56526 .7 Mdot
.28727 .32867 Mdot
.40122 .35157 Mdot
.69303 .40936 Mdot
.68064 .62619 Mdot
.52957 .66236 Mdot
.55245 .69917 Mdot
.39394 .59253 Mdot
.38503 .5622 Mdot
.38899 .38499 Mdot
.25532 .37075 Mdot
.6472 .4075 Mdot
.36941 .32697 Mdot
.48915 .35485 Mdot
.42064 .55688 Mdot
.56155 .64956 Mdot
.52426 .79748 Mdot
.36705 .58091 Mdot
.51221 .37054 Mdot
.56886 .65612 Mdot
.37077 .33921 Mdot
.39066 .35215 Mdot
.40612 .57676 Mdot
.51016 .77303 Mdot
.6579 .41065 Mdot
.55357 .69341 Mdot
.51521 .70307 Mdot
.339 .52938 Mdot
.38414 .56739 Mdot
.39229 .48673 Mdot
.69044 .38822 Mdot
.30726 .61249 Mdot
.41083 .34846 Mdot
.53913 .66427 Mdot
.36554 .55226 Mdot
.37793 .33958 Mdot
.29448 .61763 Mdot
.66983 .61779 Mdot
.49911 .35261 Mdot
.37321 .30922 Mdot
.39334 .33841 Mdot
.38392 .36105 Mdot
.7474 .63062 Mdot
.522 .69047 Mdot
.25146 .67847 Mdot
.38871 .59221 Mdot
.2147 .48049 Mdot
.41927 .5967 Mdot
.64533 .40414 Mdot
.54851 .35105 Mdot
.38487 .58741 Mdot
.39181 .59334 Mdot
.56086 .78963 Mdot
.45796 .50881 Mdot
.41086 .45652 Mdot
.58369 .69186 Mdot
.40201 .64986 Mdot
.51688 .3138 Mdot
.13827 .46627 Mdot
.76228 .69828 Mdot
.32343 .56148 Mdot
.59663 .50979 Mdot
.54274 .64759 Mdot
.69242 .40149 Mdot
.57197 .52749 Mdot
.63727 .45946 Mdot
.54139 .65818 Mdot
.41818 .55367 Mdot
.62738 .7852 Mdot
.36831 .35638 Mdot
.38401 .58093 Mdot
.65607 .43098 Mdot
.38379 .58154 Mdot
.63841 .41716 Mdot
.52879 .62371 Mdot
.60098 .53235 Mdot
.43278 .53196 Mdot
.33265 .53988 Mdot
.2941 .59056 Mdot
.38589 .56882 Mdot
.61526 .32598 Mdot
.56892 .67239 Mdot
.526 .60548 Mdot
.34337 .55974 Mdot
.47806 .76894 Mdot
.3529 .56999 Mdot
.62934 .37384 Mdot
.35348 .5555 Mdot
.28766 .49252 Mdot
.34882 .55027 Mdot
.3559 .56441 Mdot
.67233 .40847 Mdot
.69684 .4164 Mdot
.58248 .63853 Mdot
.65531 .62022 Mdot
.81715 .4623 Mdot
.38901 .543 Mdot
.55415 .36653 Mdot
.67569 .5833 Mdot
.39276 .33377 Mdot
.54321 .66016 Mdot
.17303 .34711 Mdot
.64369 .42146 Mdot
.49286 .30495 Mdot
.57986 .29669 Mdot
.49499 .30881 Mdot
.56843 .34806 Mdot
.47818 .62861 Mdot
.37021 .32059 Mdot
.34961 .56128 Mdot
.51221 .75357 Mdot
.68083 .6937 Mdot
.36319 .51563 Mdot
.48067 .36807 Mdot
.42405 .48258 Mdot
.20982 .48017 Mdot
.36336 .35734 Mdot
.37828 .31175 Mdot
.67529 .4197 Mdot
.47613 .3282 Mdot
.30972 .54282 Mdot
.39872 .35261 Mdot
.54528 .35561 Mdot
.65451 .60479 Mdot
.33084 .34354 Mdot
.55389 .66223 Mdot
.28651 .51888 Mdot
.70059 .7142 Mdot
.64445 .41624 Mdot
.59367 .45351 Mdot
.54234 .714 Mdot
.51839 .63962 Mdot
.65498 .61447 Mdot
.53018 .37284 Mdot
.59426 .67099 Mdot
.39948 .59436 Mdot
.45211 .59695 Mdot
.38172 .53334 Mdot
.40304 .34341 Mdot
.35858 .53905 Mdot
.53286 .36976 Mdot
.65061 .41057 Mdot
.5187 .32602 Mdot
.65766 .4068 Mdot
.62395 .77242 Mdot
.37966 .52658 Mdot
.38249 .56405 Mdot
.56647 .44792 Mdot
.54123 .69183 Mdot
.48583 .7179 Mdot
.53028 .37353 Mdot
.49258 .32974 Mdot
.41394 .54841 Mdot
.53995 .63577 Mdot
.39882 .30077 Mdot
.57991 .49522 Mdot
.35291 .55203 Mdot
.56863 .67341 Mdot
.41147 .54042 Mdot
.5811 .23937 Mdot
.61917 .54268 Mdot
.57725 .6931 Mdot
.28222 .72261 Mdot
.43019 .58051 Mdot
.44112 .48669 Mdot
.45913 .52974 Mdot
.35626 .42685 Mdot
.38848 .50182 Mdot
.54359 .64463 Mdot
.39014 .52739 Mdot
.55216 .68182 Mdot
.53487 .34584 Mdot
.69704 .4024 Mdot
.55221 .67821 Mdot
.4414 .55557 Mdot
.74215 .71957 Mdot
.64692 .42357 Mdot
.37635 .57401 Mdot
.68042 .42303 Mdot
.59287 .69142 Mdot
.54301 .69791 Mdot
.68448 .56732 Mdot
.57899 .32217 Mdot
.64964 .42919 Mdot
.41814 .5331 Mdot
.72359 .65326 Mdot
.41367 .54447 Mdot
.3725 .38829 Mdot
.34427 .54331 Mdot
.34531 .52553 Mdot
.57396 .83133 Mdot
.59497 .39263 Mdot
.18284 .36494 Mdot
.71601 .42503 Mdot
.74487 .63904 Mdot
.50216 .65009 Mdot
.36267 .35675 Mdot
.71258 .33641 Mdot
.69337 .60899 Mdot
.52473 .31211 Mdot
.38333 .58742 Mdot
.60248 .75913 Mdot
.6458 .43978 Mdot
.38857 .32547 Mdot
.43374 .53347 Mdot
.47252 .34652 Mdot
.71226 .59732 Mdot
.68652 .39333 Mdot
.55206 .66097 Mdot
.53566 .68673 Mdot
.2014 .61743 Mdot
.3667 .54768 Mdot
.38166 .55621 Mdot
.66763 .44349 Mdot
.30714 .55401 Mdot
.37407 .35648 Mdot
.62005 .23559 Mdot
.66053 .43333 Mdot
.63176 .54281 Mdot
.58608 .68836 Mdot
.39362 .56076 Mdot
.55757 .43086 Mdot
.75585 .57425 Mdot
.32368 .68575 Mdot
.40127 .32382 Mdot
.3268 .3791 Mdot
.54315 .64467 Mdot
.65864 .43 Mdot
.22885 .48665 Mdot
.44541 .5564 Mdot
.3966 .56055 Mdot
.3152 .3677 Mdot
.57953 .50117 Mdot
.34543 .35856 Mdot
.4266 .49951 Mdot
.55578 .48427 Mdot
.41452 .55065 Mdot
.41373 .57972 Mdot
.32202 .55523 Mdot
.37344 .52136 Mdot
.56494 .67772 Mdot
.42931 .80843 Mdot
.51276 .34342 Mdot
.28793 .65331 Mdot
.43089 .41163 Mdot
.41233 .5161 Mdot
.41848 .55926 Mdot
.37587 .77561 Mdot
.63988 .59632 Mdot
.56592 .66929 Mdot
.51156 .6962 Mdot
.7001 .4151 Mdot
.45921 .51137 Mdot
.55897 .33896 Mdot
.40365 .46081 Mdot
.52307 .33498 Mdot
.5691 .67459 Mdot
.49491 .31995 Mdot
.68831 .44903 Mdot
.54596 .33416 Mdot
.55633 .33795 Mdot
.66525 .3853 Mdot
.5634 .70592 Mdot
.35789 .57075 Mdot
.667 .38774 Mdot
.29906 .3291 Mdot
.4025 .34426 Mdot
.68326 .56887 Mdot
.39377 .49388 Mdot
.44143 .48474 Mdot
.55343 .20238 Mdot
.5163 .32016 Mdot
.60092 .57304 Mdot
.5332 .65818 Mdot
.37533 .30322 Mdot
.56095 .68022 Mdot
.22772 .5874 Mdot
.38594 .34318 Mdot
.68514 .57053 Mdot
.23554 .47182 Mdot
.60175 .43598 Mdot
.42565 .60104 Mdot
.56429 .61201 Mdot
.52535 .33463 Mdot
.64196 .43949 Mdot
.80733 .48436 Mdot
.42272 .58552 Mdot
.6377 .63566 Mdot
.5092 .65337 Mdot
.68619 .61966 Mdot
.65551 .42733 Mdot
.72568 .40364 Mdot
.36887 .54325 Mdot
.59529 .42733 Mdot
.34913 .52652 Mdot
.26235 .60534 Mdot
.38339 .39314 Mdot
.62321 .67131 Mdot
.41124 .53368 Mdot
.5094 .36744 Mdot
.41241 .53773 Mdot
.2971 .52119 Mdot
.21047 .4957 Mdot
.32911 .55113 Mdot
.60761 .62352 Mdot
.55209 .21942 Mdot
.56997 .65417 Mdot
.338 .58029 Mdot
.6702 .60793 Mdot
.42704 .56519 Mdot
.83267 .36741 Mdot
.37896 .33294 Mdot
.53458 .295 Mdot
.44013 .56535 Mdot
.36727 .55902 Mdot
.52798 .78231 Mdot
.52028 .6143 Mdot
.68833 .62261 Mdot
.40003 .56455 Mdot
.33441 .39365 Mdot
.67602 .41333 Mdot
.36174 .52374 Mdot
.3903 .53028 Mdot
.31237 .25997 Mdot
.67812 .41346 Mdot
.52033 .3191 Mdot
.69195 .61508 Mdot
.49514 .35929 Mdot
.35431 .34302 Mdot
.55622 .53367 Mdot
.27742 .34254 Mdot
.61981 .54502 Mdot
.38457 .3047 Mdot
.40584 .51196 Mdot
.54243 .72816 Mdot
.36047 .55579 Mdot
.38418 .3115 Mdot
.67458 .4337 Mdot
.5626 .67613 Mdot
.27405 .54383 Mdot
.68202 .60524 Mdot
.36318 .51398 Mdot
.37229 .36474 Mdot
.54964 .67422 Mdot
.71272 .54603 Mdot
.53919 .65496 Mdot
.66419 .40789 Mdot
.69927 .42994 Mdot
.38777 .33767 Mdot
.56355 .67961 Mdot
.48898 .34386 Mdot
.71811 .41872 Mdot
.34477 .5379 Mdot
.70282 .43697 Mdot
.58136 .64238 Mdot
.52524 .67903 Mdot
.56705 .64066 Mdot
.38241 .52258 Mdot
.58531 .50592 Mdot
.43756 .5841 Mdot
.65009 .43322 Mdot
.49899 .31165 Mdot
.24348 .39532 Mdot
.50645 .75526 Mdot
.63176 .54046 Mdot
.40452 .50218 Mdot
.36399 .53499 Mdot
.38353 .53432 Mdot
.40574 .53494 Mdot
.6237 .24004 Mdot
.38046 .52665 Mdot
.66508 .40117 Mdot
.5242 .34339 Mdot
.3692 .53612 Mdot
.66719 .60918 Mdot
.49304 .43568 Mdot
.3648 .3159 Mdot
.31214 .46441 Mdot
.76108 .67109 Mdot
.55162 .67415 Mdot
.54515 .34016 Mdot
.4873 .32387 Mdot
.38833 .3557 Mdot
.67179 .38784 Mdot
.53522 .66096 Mdot
.30096 .45797 Mdot
.38764 .36376 Mdot
.39718 .53773 Mdot
.56302 .4386 Mdot
.29408 .73578 Mdot
.42099 .51593 Mdot
.40114 .58252 Mdot
.66418 .62632 Mdot
.50145 .30458 Mdot
.84 .42212 Mdot
.70444 .48809 Mdot
.38872 .332 Mdot
.36735 .33829 Mdot
.5603 .64121 Mdot
.38213 .50802 Mdot
.65487 .41268 Mdot
.56219 .49211 Mdot
.55615 .19282 Mdot
.82004 .52466 Mdot
.58476 .26175 Mdot
.35803 .58063 Mdot
.44117 .79467 Mdot
.34544 .57592 Mdot
.52136 .68819 Mdot
.55286 .63754 Mdot
.56154 .66615 Mdot
.67194 .41015 Mdot
.18432 .53491 Mdot
.66403 .4001 Mdot
.76209 .67266 Mdot
.57817 .65538 Mdot
.54929 .40849 Mdot
.49175 .33545 Mdot
.39644 .61802 Mdot
.37181 .31909 Mdot
.44474 .31701 Mdot
.33992 .58677 Mdot
.53021 .57915 Mdot
.52856 .31977 Mdot
.54165 .6994 Mdot
.32279 .60641 Mdot
.81575 .4479 Mdot
.60004 .51817 Mdot
.47437 .18959 Mdot
.36506 .65785 Mdot
.38018 .34505 Mdot
.30938 .70219 Mdot
.37379 .35814 Mdot
.69116 .40248 Mdot
.42284 .58686 Mdot
.43492 .58023 Mdot
.40999 .56011 Mdot
.38652 .52198 Mdot
.67645 .42525 Mdot
.34134 .56357 Mdot
.24311 .36898 Mdot
.67139 .59948 Mdot
.53964 .40505 Mdot
.38176 .35173 Mdot
.64484 .40064 Mdot
.52814 .34443 Mdot
.65356 .61741 Mdot
.31379 .31504 Mdot
.34808 .57449 Mdot
.37978 .58867 Mdot
.66243 .60085 Mdot
.30823 .56537 Mdot
.372 .62246 Mdot
.51002 .33904 Mdot
.50294 .46786 Mdot
.40419 .31728 Mdot
.3634 .32365 Mdot
.63393 .41385 Mdot
.56119 .68038 Mdot
.40644 .34099 Mdot
.47399 .33236 Mdot
.36673 .51967 Mdot
.33152 .54091 Mdot
.58202 .64259 Mdot
.19772 .50493 Mdot
.35527 .33152 Mdot
.29705 .58219 Mdot
.53572 .67385 Mdot
.50856 .66101 Mdot
.39963 .56692 Mdot
.44655 .5228 Mdot
.52204 .68263 Mdot
.37328 .35013 Mdot
.64528 .39861 Mdot
.56743 .4118 Mdot
.65601 .39953 Mdot
.53977 .67264 Mdot
.39949 .613 Mdot
.57604 .70105 Mdot
.4306 .5773 Mdot
.10723 .52253 Mdot
.36523 .52982 Mdot
.49416 .6018 Mdot
.38245 .41218 Mdot
.49593 .35082 Mdot
.49821 .35641 Mdot
.66604 .61175 Mdot
.5325 .65412 Mdot
.35807 .59755 Mdot
.36617 .32588 Mdot
.74172 .64153 Mdot
.61421 .69007 Mdot
.55601 .34808 Mdot
.5309 .31066 Mdot
.6743 .43265 Mdot
.35061 .56138 Mdot
.39082 .55559 Mdot
.54202 .32953 Mdot
.60037 .20575 Mdot
.55827 .68566 Mdot
.38142 .55623 Mdot
.3727 .52346 Mdot
.51599 .34428 Mdot
.72308 .4179 Mdot
.50831 .67885 Mdot
.37186 .52305 Mdot
.2412 .45397 Mdot
.63967 .41896 Mdot
.41845 .5268 Mdot
.3439 .57096 Mdot
.39645 .33225 Mdot
.35376 .28917 Mdot
.21029 .48731 Mdot
.6785 .38479 Mdot
.66609 .62494 Mdot
.42119 .59251 Mdot
.49465 .34075 Mdot
.38668 .49577 Mdot
.7406 .32794 Mdot
.68176 .6007 Mdot
.37403 .5439 Mdot
.32474 .58009 Mdot
.54407 .68941 Mdot
.37204 .5491 Mdot
.62857 .6975 Mdot
.51548 .36503 Mdot
.37359 .54307 Mdot
.50621 .77 Mdot
.67212 .43369 Mdot
.34155 .59001 Mdot
.36822 .316 Mdot
.39151 .4082 Mdot
.67485 .75591 Mdot
.55805 .36623 Mdot
.39058 .35094 Mdot
.35723 .54085 Mdot
.50097 .36719 Mdot
.64222 .39457 Mdot
.54673 .5952 Mdot
.39833 .50981 Mdot
.65254 .4015 Mdot
.64898 .41508 Mdot
.38559 .33435 Mdot
.15915 .39125 Mdot
.32375 .57813 Mdot
.38238 .5755 Mdot
.51866 .17203 Mdot
.56553 .71551 Mdot
.37774 .57777 Mdot
.35154 .56268 Mdot
.67057 .39272 Mdot
.23702 .53502 Mdot
.45099 .47306 Mdot
.61721 .22337 Mdot
.63927 .41524 Mdot
.46409 .31871 Mdot
.5266 .36443 Mdot
.38772 .35091 Mdot
.56479 .65328 Mdot
.39657 .30912 Mdot
.51003 .35152 Mdot
.40745 .57101 Mdot
.68999 .4153 Mdot
.38668 .6822 Mdot
.63598 .4345 Mdot
.47854 .35311 Mdot
.51382 .6698 Mdot
.71388 .71809 Mdot
.6106 .16942 Mdot
.68717 .72452 Mdot
.68217 .38425 Mdot
.393 .33362 Mdot
.68209 .49722 Mdot
.36238 .53827 Mdot
.28124 .69453 Mdot
.38271 .5789 Mdot
.30821 .64448 Mdot
.54765 .35287 Mdot
.65471 .60908 Mdot
.42174 .58616 Mdot
.33072 .38421 Mdot
.67056 .38498 Mdot
.66017 .43804 Mdot
.40059 .53382 Mdot
.66222 .40792 Mdot
.38652 .55283 Mdot
.5219 .34679 Mdot
.16294 .39087 Mdot
.35562 .55752 Mdot
.35527 .60005 Mdot
.66096 .46269 Mdot
.68339 .56969 Mdot
.46306 .33875 Mdot
.45437 .79804 Mdot
.81924 .44173 Mdot
.66014 .41194 Mdot
.46558 .60713 Mdot
.53026 .32513 Mdot
.65671 .62485 Mdot
.5505 .31688 Mdot
.39062 .57606 Mdot
.36379 .58575 Mdot
.41233 .55365 Mdot
.3648 .53547 Mdot
.29537 .70541 Mdot
.37447 .62053 Mdot
.405 .7439 Mdot
.38284 .58957 Mdot
.49068 .60435 Mdot
.66992 .40088 Mdot
.43366 .47904 Mdot
.34238 .35173 Mdot
.35948 .58418 Mdot
.51491 .61442 Mdot
.64887 .39809 Mdot
.76321 .64627 Mdot
.6783 .42002 Mdot
.51019 .32327 Mdot
.69484 .4237 Mdot
.43288 .57586 Mdot
.55617 .65744 Mdot
.52659 .35782 Mdot
.63284 .73819 Mdot
.52703 .31496 Mdot
.36585 .54574 Mdot
.67022 .47047 Mdot
.49228 .34565 Mdot
.36261 .44077 Mdot
.55615 .65575 Mdot
.31834 .39182 Mdot
.5573 .71563 Mdot
.37295 .55495 Mdot
.37291 .56275 Mdot
.65147 .61617 Mdot
.68548 .39234 Mdot
.58974 .66515 Mdot
.27145 .28888 Mdot
.37615 .36902 Mdot
.57028 .66428 Mdot
.46111 .55385 Mdot
.59574 .5052 Mdot
.56031 .69662 Mdot
.35316 .41328 Mdot
.67838 .38987 Mdot
.5671 .64678 Mdot
.44524 .58282 Mdot
.27929 .59562 Mdot
.36155 .34483 Mdot
.51041 .37205 Mdot
.55681 .4684 Mdot
.52323 .36541 Mdot
.6526 .45013 Mdot
.55574 .32875 Mdot
.67502 .40699 Mdot
.63021 .6556 Mdot
.49412 .48442 Mdot
.66378 .45154 Mdot
.67536 .45831 Mdot
.50484 .34504 Mdot
.40502 .5374 Mdot
.49854 .42254 Mdot
.4542 .53702 Mdot
.37157 .61304 Mdot
.64243 .41192 Mdot
.54849 .64332 Mdot
.58766 .68936 Mdot
.50185 .61243 Mdot
.54591 .69738 Mdot
.5309 .35316 Mdot
.61311 .54993 Mdot
.26167 .62338 Mdot
.67625 .43502 Mdot
.5848 .34455 Mdot
.41538 .54484 Mdot
.49985 .34598 Mdot
.53678 .34842 Mdot
.65417 .40715 Mdot
.29955 .6714 Mdot
.34893 .6014 Mdot
.56397 .71207 Mdot
.58156 .65738 Mdot
.56609 .69631 Mdot
.54349 .63652 Mdot
.18706 .55968 Mdot
.64172 .43933 Mdot
.54075 .64661 Mdot
.39558 .52288 Mdot
.37053 .58514 Mdot
.68313 .61951 Mdot
.3724 .34735 Mdot
.40872 .60064 Mdot
.38779 .60676 Mdot
.39873 .56667 Mdot
.49526 .34904 Mdot
.33633 .50055 Mdot
.68371 .6023 Mdot
.54794 .32116 Mdot
.55871 .34111 Mdot
.65981 .61829 Mdot
.60549 .71505 Mdot
.83799 .47984 Mdot
.41129 .56253 Mdot
.49248 .67425 Mdot
.4963 .3395 Mdot
.541 .55258 Mdot
.3394 .62802 Mdot
.41564 .53056 Mdot
.50635 .40499 Mdot
.52513 .35032 Mdot
.53735 .62924 Mdot
.38748 .5731 Mdot
.65883 .60908 Mdot
.36061 .32739 Mdot
.45611 .55402 Mdot
.66323 .62639 Mdot
.57025 .6766 Mdot
.52002 .21984 Mdot
.5846 .70631 Mdot
.4915 .34633 Mdot
.339 .58304 Mdot
.27319 .8123 Mdot
.52655 .33439 Mdot
.7664 .60929 Mdot
.48639 .47607 Mdot
.35691 .55017 Mdot
.53219 .35843 Mdot
.52796 .63339 Mdot
.63996 .41871 Mdot
.56564 .45574 Mdot
.56166 .64977 Mdot
.65375 .61604 Mdot
.67086 .62323 Mdot
.51357 .343 Mdot
.58576 .67231 Mdot
.34187 .55046 Mdot
.53215 .67526 Mdot
.68611 .43271 Mdot
.43423 .55287 Mdot
.81747 .4616 Mdot
.45175 .59811 Mdot
.53337 .67077 Mdot
.4734 .3292 Mdot
.40713 .34751 Mdot
.42961 .52805 Mdot
.80727 .5793 Mdot
.35055 .55673 Mdot
.6791 .42753 Mdot
.51612 .53495 Mdot
.38283 .68762 Mdot
.40544 .55034 Mdot
.417 .55263 Mdot
.63751 .40394 Mdot
.40671 .55601 Mdot
.38207 .51303 Mdot
.69843 .37789 Mdot
.55282 .69563 Mdot
.37908 .53907 Mdot
.53442 .36345 Mdot
.46685 .66161 Mdot
.41447 .59119 Mdot
.63769 .69129 Mdot
.32167 .3842 Mdot
.50433 .5139 Mdot
.35279 .59374 Mdot
.29829 .31786 Mdot
.37552 .56577 Mdot
.40444 .51749 Mdot
.40956 .54819 Mdot
.43151 .79565 Mdot
.50664 .34923 Mdot
.5464 .36186 Mdot
.35906 .32821 Mdot
.3313 .38911 Mdot
.3993 .3392 Mdot
.64653 .3957 Mdot
.58675 .3273 Mdot
.66975 .60028 Mdot
.55828 .68116 Mdot
.40591 .59227 Mdot
.53519 .31818 Mdot
.39373 .56464 Mdot
.42718 .56183 Mdot
.52097 .35472 Mdot
.5335 .34871 Mdot
.56325 .35716 Mdot
.37718 .36219 Mdot
.56018 .67179 Mdot
.40413 .58464 Mdot
.39127 .36206 Mdot
.3448 .55115 Mdot
.6047 .50138 Mdot
.56226 .67027 Mdot
.5329 .67682 Mdot
.58611 .69759 Mdot
.3859 .59234 Mdot
.43691 .56333 Mdot
.66326 .39994 Mdot
.58674 .64628 Mdot
.66571 .44158 Mdot
.53045 .35966 Mdot
.50143 .35754 Mdot
.39057 .57663 Mdot
.29858 .58238 Mdot
.37445 .34627 Mdot
.51046 .32088 Mdot
.69327 .60437 Mdot
.35947 .32534 Mdot
.37222 .5318 Mdot
.52581 .36301 Mdot
.3668 .31495 Mdot
.33176 .66641 Mdot
.80674 .4157 Mdot
.39033 .36477 Mdot
.39994 .53301 Mdot
.527 .77692 Mdot
.23009 .46729 Mdot
.3816 .36999 Mdot
.68228 .41515 Mdot
.35809 .57431 Mdot
.62499 .20327 Mdot
.40621 .31837 Mdot
.19937 .50427 Mdot
.51654 .3565 Mdot
.33341 .64263 Mdot
.45625 .55919 Mdot
.26729 .6681 Mdot
.40615 .31649 Mdot
.5368 .66551 Mdot
.57908 .64843 Mdot
.3998 .54019 Mdot
.36085 .36762 Mdot
.64828 .44684 Mdot
.48707 .32387 Mdot
.55485 .33832 Mdot
.58617 .67934 Mdot
.62598 .54468 Mdot
.53243 .36362 Mdot
.32767 .541 Mdot
.5069 .29367 Mdot
.46216 .51975 Mdot
.20148 .60876 Mdot
.62117 .7649 Mdot
.34219 .57762 Mdot
.4059 .35151 Mdot
.66339 .38538 Mdot
.66137 .4037 Mdot
.66983 .41055 Mdot
.50531 .36188 Mdot
.5725 .5132 Mdot
.55284 .34474 Mdot
.66987 .64988 Mdot
.37673 .33902 Mdot
.30692 .41173 Mdot
.38332 .60311 Mdot
.35763 .54965 Mdot
.36969 .51686 Mdot
.41295 .55604 Mdot
.37664 .56475 Mdot
.64496 .41423 Mdot
.48415 .33764 Mdot
.5679 .22154 Mdot
.57656 .68807 Mdot
.70435 .53811 Mdot
.49134 .33426 Mdot
.68434 .62232 Mdot
.38357 .32198 Mdot
.27844 .34848 Mdot
.50916 .2863 Mdot
.4938 .32172 Mdot
.40969 .51063 Mdot
.54563 .64104 Mdot
.25396 .58245 Mdot
.36851 .57094 Mdot
.51191 .32022 Mdot
.49117 .3041 Mdot
.31418 .69694 Mdot
.38649 .4909 Mdot
.43897 .34284 Mdot
.59443 .50702 Mdot
.41449 .33936 Mdot
.4085 .50056 Mdot
.54798 .55593 Mdot
.51024 .3494 Mdot
.50946 .32751 Mdot
.38347 .36784 Mdot
.38753 .46914 Mdot
.57802 .65999 Mdot
.65542 .60688 Mdot
.68119 .40844 Mdot
.36234 .5655 Mdot
.50872 .36372 Mdot
.49804 .6792 Mdot
.56874 .43758 Mdot
.67006 .4276 Mdot
.54004 .31515 Mdot
.35449 .57279 Mdot
.40228 .54575 Mdot
.38417 .34508 Mdot
.38445 .23893 Mdot
.45496 .54095 Mdot
.74496 .63856 Mdot
.58615 .53984 Mdot
.44985 .44156 Mdot
.3963 .56003 Mdot
.57364 .69996 Mdot
.66093 .61437 Mdot
.38051 .31565 Mdot
.34584 .55569 Mdot
.83467 .45289 Mdot
.60292 .6865 Mdot
.64884 .42493 Mdot
.6591 .6131 Mdot
.56463 .50781 Mdot
.35089 .55325 Mdot
.38304 .57869 Mdot
.38372 .5226 Mdot
.83708 .44856 Mdot
.54605 .35788 Mdot
.56893 .63886 Mdot
.40275 .32729 Mdot
.5322 .6801 Mdot
.55298 .36066 Mdot
.44101 .43345 Mdot
.37505 .52606 Mdot
.56869 .70979 Mdot
.53763 .66035 Mdot
.67247 .43438 Mdot
.6653 .38788 Mdot
.52671 .37768 Mdot
.35957 .53928 Mdot
.66334 .60208 Mdot
.56 .64578 Mdot
.48101 .32942 Mdot
.38378 .34423 Mdot
.70226 .40155 Mdot
.38386 .59026 Mdot
.51095 .34441 Mdot
.33569 .55788 Mdot
.54842 .6884 Mdot
.49206 .32491 Mdot
.67744 .6261 Mdot
.37052 .3442 Mdot
.37158 .58873 Mdot
.54244 .21144 Mdot
.65682 .61262 Mdot
.44138 .54762 Mdot
.56527 .75697 Mdot
.34545 .34572 Mdot
.628 .74658 Mdot
.54817 .34622 Mdot
.66995 .60302 Mdot
.55779 .63705 Mdot
.27741 .59976 Mdot
.51393 .33097 Mdot
.56481 .77741 Mdot
.53174 .41364 Mdot
.40891 .57283 Mdot
.57529 .66398 Mdot
.41362 .35546 Mdot
.75642 .63186 Mdot
.24321 .43163 Mdot
.38117 .54954 Mdot
.52282 .36586 Mdot
.36318 .32326 Mdot
.66555 .44041 Mdot
.63864 .68111 Mdot
.21876 .62998 Mdot
.54725 .32141 Mdot
.40085 .59074 Mdot
.557 .64415 Mdot
.65244 .4124 Mdot
.62115 .78624 Mdot
.47313 .3373 Mdot
.54241 .35466 Mdot
.39263 .51652 Mdot
.40159 .32307 Mdot
.63281 .21377 Mdot
.54391 .36257 Mdot
.49315 .35694 Mdot
.68354 .54939 Mdot
.35996 .34947 Mdot
.39501 .52525 Mdot
.50264 .61211 Mdot
.36309 .52393 Mdot
.7342 .60985 Mdot
.66787 .60263 Mdot
.57429 .68913 Mdot
.38021 .5837 Mdot
.55377 .22023 Mdot
.52327 .33689 Mdot
.59487 .51123 Mdot
.73524 .40328 Mdot
.6684 .38799 Mdot
.51305 .36363 Mdot
.38946 .56667 Mdot
.69843 .43414 Mdot
.37835 .34796 Mdot
.37162 .52318 Mdot
.43395 .57152 Mdot
.51729 .63845 Mdot
.68873 .42277 Mdot
.47425 .66347 Mdot
.68757 .43491 Mdot
.6329 .4164 Mdot
.50821 .66218 Mdot
.39877 .53935 Mdot
.50253 .32131 Mdot
.48055 .35718 Mdot
.33928 .5554 Mdot
.54092 .55103 Mdot
.57721 .66074 Mdot
.57067 .33794 Mdot
.83206 .41417 Mdot
.32219 .56507 Mdot
.69601 .609 Mdot
.34735 .65103 Mdot
.64263 .43221 Mdot
.40613 .57094 Mdot
.55152 .68315 Mdot
.48444 .34535 Mdot
.52509 .3685 Mdot
.44056 .52739 Mdot
.65282 .40704 Mdot
.37457 .30565 Mdot
.53983 .3454 Mdot
.57328 .43827 Mdot
.37152 .54439 Mdot
.64046 .63716 Mdot
.54103 .34091 Mdot
.71197 .74572 Mdot
.55881 .221 Mdot
.58043 .68807 Mdot
.42391 .55175 Mdot
.52432 .65614 Mdot
.4036 .33153 Mdot
.5518 .31993 Mdot
.65449 .40283 Mdot
.29115 .51397 Mdot
.30928 .25388 Mdot
.50173 .3496 Mdot
.56594 .6766 Mdot
.39785 .58861 Mdot
.32246 .61194 Mdot
.35317 .55469 Mdot
.24286 .52524 Mdot
.40348 .37324 Mdot
.68552 .4522 Mdot
.65811 .43941 Mdot
.41906 .56444 Mdot
.37828 .35954 Mdot
.49917 .37117 Mdot
.51892 .35444 Mdot
.13406 .452 Mdot
.66444 .62697 Mdot
.42065 .36629 Mdot
.38446 .59168 Mdot
.48375 .32296 Mdot
.50249 .75106 Mdot
.66817 .44329 Mdot
.35473 .52744 Mdot
.50453 .3065 Mdot
.74855 .56553 Mdot
.59327 .50106 Mdot
.37591 .54544 Mdot
.30684 .55229 Mdot
.68035 .41794 Mdot
.68354 .49709 Mdot
.54917 .33789 Mdot
.34943 .539 Mdot
.63208 .3894 Mdot
.66598 .56853 Mdot
.28638 .28174 Mdot
.56012 .67139 Mdot
.47785 .31834 Mdot
.65813 .39337 Mdot
.32853 .51188 Mdot
.37765 .3512 Mdot
.48606 .35395 Mdot
.51 .30827 Mdot
.43114 .55205 Mdot
.40518 .60043 Mdot
.33432 .51515 Mdot
.57552 .67106 Mdot
.67428 .39433 Mdot
.4203 .57682 Mdot
.62352 .52713 Mdot
.41262 .56806 Mdot
.66933 .39425 Mdot
.15947 .67788 Mdot
.43767 .5269 Mdot
.36833 .57644 Mdot
.3591 .43258 Mdot
.59033 .6746 Mdot
.5451 .69275 Mdot
.61037 .53616 Mdot
.38295 .59155 Mdot
.58481 .3948 Mdot
.55867 .67402 Mdot
.57292 .65894 Mdot
.57662 .39859 Mdot
.43315 .54461 Mdot
.62201 .43074 Mdot
.65479 .40993 Mdot
.66707 .38803 Mdot
.54271 .68781 Mdot
.40594 .61713 Mdot
.64689 .39119 Mdot
.30528 .71809 Mdot
.48986 .32644 Mdot
.54832 .55629 Mdot
.53195 .67285 Mdot
.54898 .42647 Mdot
.68616 .3937 Mdot
.72313 .75845 Mdot
.26307 .54774 Mdot
.34092 .5355 Mdot
.40334 .54469 Mdot
.39586 .33684 Mdot
.40205 .63253 Mdot
.66965 .62505 Mdot
.664 .40644 Mdot
.62732 .24867 Mdot
.56167 .66552 Mdot
.36111 .57245 Mdot
.24883 .38338 Mdot
.63876 .76572 Mdot
.54025 .60128 Mdot
.5626 .65181 Mdot
.56174 .66078 Mdot
.52835 .31898 Mdot
.48796 .32634 Mdot
.38528 .52683 Mdot
.67054 .40615 Mdot
.57764 .65071 Mdot
.68593 .40285 Mdot
.51082 .35097 Mdot
.49336 .32585 Mdot
.68944 .60556 Mdot
.35119 .61303 Mdot
.50942 .35897 Mdot
.69441 .55637 Mdot
.62217 .52474 Mdot
.5343 .63244 Mdot
.5937 .16707 Mdot
.61497 .79254 Mdot
.35267 .43497 Mdot
.36024 .32854 Mdot
.66671 .58909 Mdot
.69347 .40206 Mdot
.41823 .56275 Mdot
.39318 .58145 Mdot
.6823 .61628 Mdot
.68472 .38874 Mdot
.3908 .32288 Mdot
.68807 .39477 Mdot
.37395 .32047 Mdot
.5407 .36845 Mdot
.41515 .59185 Mdot
.35719 .53758 Mdot
.65246 .43201 Mdot
.52354 .31949 Mdot
.49264 .34754 Mdot
.3635 .34432 Mdot
.28264 .35389 Mdot
.51399 .34457 Mdot
.53182 .67297 Mdot
.45606 .67378 Mdot
.67325 .62263 Mdot
.38698 .57246 Mdot
.26726 .35626 Mdot
.29893 .692 Mdot
.40895 .57692 Mdot
.6584 .61267 Mdot
.13685 .4237 Mdot
.42093 .58866 Mdot
.15303 .52648 Mdot
.68269 .60295 Mdot
.57852 .69978 Mdot
.53575 .32925 Mdot
.65725 .62343 Mdot
.33176 .50497 Mdot
.37193 .38084 Mdot
.33236 .56502 Mdot
.57513 .65458 Mdot
.56314 .70791 Mdot
.49817 .48033 Mdot
.73485 .60648 Mdot
.40068 .31839 Mdot
.38411 .32682 Mdot
.51435 .33329 Mdot
.6207 .38158 Mdot
.35469 .5145 Mdot
.38721 .32726 Mdot
.66916 .25938 Mdot
.41504 .54246 Mdot
.36565 .38978 Mdot
.50757 .4108 Mdot
.57908 .69566 Mdot
.42639 .47272 Mdot
.5189 .3342 Mdot
.56575 .67606 Mdot
.49826 .44317 Mdot
.36536 .52045 Mdot
.56252 .66842 Mdot
.67522 .39269 Mdot
.70424 .36282 Mdot
.54042 .69412 Mdot
.56611 .45264 Mdot
.65493 .41453 Mdot
.34504 .34856 Mdot
.27176 .44732 Mdot
.8709 .4237 Mdot
.66586 .4052 Mdot
.52405 .32282 Mdot
.5035 .35752 Mdot
.51847 .34494 Mdot
.56508 .65068 Mdot
.5339 .34434 Mdot
.57592 .68198 Mdot
.68412 .46043 Mdot
.29311 .32852 Mdot
.38596 .33992 Mdot
.56101 .30707 Mdot
.54325 .66353 Mdot
.68217 .64886 Mdot
.5248 .15805 Mdot
.39986 .52835 Mdot
.65798 .44986 Mdot
.40242 .35771 Mdot
.61303 .57651 Mdot
.39706 .33268 Mdot
.53196 .32582 Mdot
.54962 .55739 Mdot
.38615 .55137 Mdot
.59888 .7586 Mdot
.36834 .31778 Mdot
.56224 .65077 Mdot
.40974 .51446 Mdot
.50332 .37726 Mdot
.39522 .34782 Mdot
.36087 .33216 Mdot
.3783 .56638 Mdot
.54953 .70366 Mdot
.49789 .32145 Mdot
.69713 .41216 Mdot
.39626 .36961 Mdot
.30391 .56824 Mdot
.40578 .5426 Mdot
.42218 .51256 Mdot
.59213 .52088 Mdot
.63515 .20975 Mdot
.65947 .41415 Mdot
.22684 .46555 Mdot
.49987 .3521 Mdot
.24261 .43925 Mdot
.70323 .67728 Mdot
.51225 .28314 Mdot
.6701 .60178 Mdot
.66649 .60281 Mdot
.37657 .55152 Mdot
.66927 .22972 Mdot
.5059 .59944 Mdot
.62709 .40968 Mdot
.67065 .62121 Mdot
.492 .34638 Mdot
.59741 .65775 Mdot
.39691 .45936 Mdot
.41498 .60254 Mdot
.67981 .38566 Mdot
.51549 .35024 Mdot
.74053 .32698 Mdot
.37762 .33788 Mdot
.59935 .56606 Mdot
.36923 .53475 Mdot
.38234 .56011 Mdot
.65986 .42576 Mdot
.66221 .40106 Mdot
.64971 .64576 Mdot
.52158 .49977 Mdot
.81314 .48205 Mdot
.63761 .44755 Mdot
.73667 .31528 Mdot
.49987 .62917 Mdot
.54057 .67949 Mdot
.69419 .61265 Mdot
.64276 .39637 Mdot
.37743 .57926 Mdot
.58187 .6972 Mdot
.52465 .59993 Mdot
.51816 .63307 Mdot
.36947 .3931 Mdot
.56889 .41339 Mdot
.36772 .53374 Mdot
.54404 .63965 Mdot
.56551 .67397 Mdot
.52999 .64611 Mdot
.66122 .61851 Mdot
.39858 .56144 Mdot
.40495 .53517 Mdot
.42363 .58653 Mdot
.32249 .6105 Mdot
.37153 .54871 Mdot
.70933 .67214 Mdot
.63681 .53512 Mdot
.41515 .26559 Mdot
.39385 .59349 Mdot
.66343 .39179 Mdot
.40371 .59363 Mdot
.37917 .35826 Mdot
.3904 .59558 Mdot
.35914 .38359 Mdot
.66839 .41627 Mdot
.34492 .4817 Mdot
.5744 .36212 Mdot
.37188 .52935 Mdot
.38249 .30458 Mdot
.64016 .21195 Mdot
.23753 .40583 Mdot
.68546 .55056 Mdot
.53213 .67382 Mdot
.53666 .37572 Mdot
.65738 .44688 Mdot
.50202 .32266 Mdot
.34745 .53298 Mdot
.68991 .60315 Mdot
.54105 .83941 Mdot
.53047 .43089 Mdot
.37742 .58062 Mdot
.35217 .61627 Mdot
.56891 .69995 Mdot
.52614 .33782 Mdot
.51269 .63046 Mdot
.39372 .51771 Mdot
.40549 .34073 Mdot
.39975 .35414 Mdot
.46854 .44789 Mdot
.7053 .31843 Mdot
.2596 .57979 Mdot
.66015 .42342 Mdot
.52035 .3706 Mdot
.40458 .31448 Mdot
.58025 .6146 Mdot
.64429 .44445 Mdot
.64307 .43254 Mdot
.68885 .42064 Mdot
.36204 .54776 Mdot
.69056 .61098 Mdot
.68333 .28725 Mdot
.6546 .61878 Mdot
.38393 .51774 Mdot
.51564 .30947 Mdot
.65494 .62284 Mdot
.39755 .33879 Mdot
.6337 .41681 Mdot
.49389 .34448 Mdot
.37203 .55946 Mdot
.55302 .67248 Mdot
.22646 .44503 Mdot
.44493 .18829 Mdot
.56193 .3147 Mdot
.56501 .31756 Mdot
.58707 .7001 Mdot
.806 .59684 Mdot
.70848 .42572 Mdot
.29805 .6731 Mdot
.42284 .3438 Mdot
.3389 .55315 Mdot
.17478 .4023 Mdot
.55211 .34456 Mdot
.52866 .35673 Mdot
.37572 .54029 Mdot
.47632 .33264 Mdot
.3559 .56677 Mdot
.54667 .33163 Mdot
.7726 .58028 Mdot
.42546 .59991 Mdot
.52994 .3543 Mdot
.3696 .50603 Mdot
.43091 .52767 Mdot
.56651 .7019 Mdot
.48425 .35031 Mdot
.33958 .53647 Mdot
.50068 .85743 Mdot
.66695 .43536 Mdot
.66173 .61973 Mdot
.57478 .31613 Mdot
.69422 .41997 Mdot
.58052 .67213 Mdot
.41634 .5941 Mdot
.37903 .34657 Mdot
.54073 .6707 Mdot
.52013 .38168 Mdot
.37447 .31244 Mdot
.61455 .54873 Mdot
.54054 .68312 Mdot
.68318 .61805 Mdot
.36935 .34131 Mdot
.33212 .56547 Mdot
.52392 .3574 Mdot
.52589 .193 Mdot
.65627 .61969 Mdot
.39023 .55632 Mdot
.47026 .32584 Mdot
.68874 .39606 Mdot
.38744 .5309 Mdot
.51586 .36837 Mdot
.6592 .61622 Mdot
.44062 .54731 Mdot
.44108 .54315 Mdot
.37286 .4621 Mdot
.51209 .54804 Mdot
.38833 .34256 Mdot
.50974 .66705 Mdot
.39365 .52183 Mdot
.3759 .35888 Mdot
.58987 .27645 Mdot
.36477 .59773 Mdot
.5252 .67173 Mdot
.28545 .543 Mdot
.49026 .32034 Mdot
.66331 .44167 Mdot
.47696 .35173 Mdot
.36164 .32139 Mdot
.32336 .21104 Mdot
.68794 .6185 Mdot
.33823 .61 Mdot
.3718 .51505 Mdot
.53823 .31176 Mdot
.56761 .67111 Mdot
.81291 .50438 Mdot
.37649 .59017 Mdot
.42932 .60851 Mdot
.38257 .57055 Mdot
.55037 .22464 Mdot
.5751 .65893 Mdot
.38487 .5725 Mdot
.30444 .58636 Mdot
.32951 .5435 Mdot
.38679 .30357 Mdot
.30287 .42285 Mdot
.40895 .58816 Mdot
.369 .88287 Mdot
.66535 .59938 Mdot
.52177 .35277 Mdot
.58093 .4791 Mdot
.53965 .25054 Mdot
.18753 .5887 Mdot
.57679 .67619 Mdot
.45103 .63651 Mdot
.49931 .32218 Mdot
.21781 .43245 Mdot
.78627 .62736 Mdot
.42671 .52365 Mdot
.35854 .57686 Mdot
.53189 .3258 Mdot
.4817 .33049 Mdot
.67718 .59838 Mdot
.36018 .58764 Mdot
.42607 .61009 Mdot
.48272 .31785 Mdot
.36731 .55974 Mdot
.36675 .75317 Mdot
.68911 .44153 Mdot
.54458 .69068 Mdot
.66618 .44029 Mdot
.64417 .43159 Mdot
.26598 .63663 Mdot
.58506 .54052 Mdot
.6662 .39608 Mdot
.66241 .37777 Mdot
.33085 .3564 Mdot
.29753 .49688 Mdot
.3938 .30756 Mdot
.72476 .35021 Mdot
.51474 .33784 Mdot
.39978 .56288 Mdot
.55394 .64688 Mdot
.2417 .64225 Mdot
.77395 .43152 Mdot
.5631 .56631 Mdot
.40336 .52911 Mdot
.5224 .33906 Mdot
.65716 .61664 Mdot
.42149 .60173 Mdot
.23672 .45713 Mdot
.38194 .55374 Mdot
.48587 .32876 Mdot
.2619 .62984 Mdot
.62729 .69041 Mdot
.63672 .44599 Mdot
.59136 .64055 Mdot
.40804 .59299 Mdot
.55819 .68891 Mdot
.65511 .39771 Mdot
.37738 .3617 Mdot
.39178 .33333 Mdot
.36686 .53085 Mdot
.49513 .48524 Mdot
.32808 .30203 Mdot
.42691 .52457 Mdot
.43231 .55159 Mdot
.67406 .6021 Mdot
.43283 .55236 Mdot
.35289 .53626 Mdot
.41742 .57722 Mdot
.3558 .58753 Mdot
.63378 .41086 Mdot
.58245 .7526 Mdot
.38884 .59843 Mdot
.32057 .56189 Mdot
.70082 .4141 Mdot
.41337 .48557 Mdot
.67772 .4177 Mdot
.79615 .42967 Mdot
.67846 .40553 Mdot
.39065 .33472 Mdot
.46825 .34554 Mdot
.46816 .63468 Mdot
.5793 .65193 Mdot
.65742 .39203 Mdot
.37402 .32601 Mdot
.66746 .40728 Mdot
.53421 .36735 Mdot
.55797 .17264 Mdot
.52434 .6948 Mdot
.60728 .49961 Mdot
.31463 .45929 Mdot
.64176 .63793 Mdot
.49609 .31614 Mdot
.58575 .67854 Mdot
.62857 .69386 Mdot
.41999 .56758 Mdot
.38441 .34782 Mdot
.37733 .55258 Mdot
.63432 .42383 Mdot
.5198 .33933 Mdot
.67976 .46659 Mdot
.38964 .34226 Mdot
.37673 .19091 Mdot
.53503 .31878 Mdot
.32453 .59472 Mdot
.70018 .42354 Mdot
.56969 .16526 Mdot
.67872 .41066 Mdot
.29054 .33124 Mdot
.56194 .72552 Mdot
.2334 .60184 Mdot
.55425 .66003 Mdot
.63766 .64662 Mdot
.8422 .57342 Mdot
.78309 .61315 Mdot
.54488 .67654 Mdot
.57593 .35964 Mdot
.36645 .54871 Mdot
.41387 .56247 Mdot
.32542 .54219 Mdot
.55296 .62713 Mdot
.3862 .52283 Mdot
.67402 .62414 Mdot
.59343 .53055 Mdot
.63797 .23049 Mdot
.52373 .37688 Mdot
.35398 .56354 Mdot
.64245 .41315 Mdot
.63367 .42832 Mdot
.65311 .6209 Mdot
.69007 .42777 Mdot
.4338 .53471 Mdot
.54585 .66217 Mdot
.49745 .42557 Mdot
.40275 .33594 Mdot
.73091 .64549 Mdot
.41841 .33375 Mdot
.4801 .29847 Mdot
.32302 .55846 Mdot
.49314 .3254 Mdot
.23946 .30581 Mdot
.41641 .55784 Mdot
.55973 .67587 Mdot
.39127 .51415 Mdot
.41609 .58193 Mdot
.40482 .58911 Mdot
.51635 .36931 Mdot
.58426 .48185 Mdot
.3675 .56262 Mdot
.66184 .3951 Mdot
.56605 .40338 Mdot
.40437 .60319 Mdot
.63887 .26384 Mdot
.37496 .3974 Mdot
.6404 .63603 Mdot
.53989 .63182 Mdot
.52127 .32547 Mdot
.56068 .66349 Mdot
.60718 .65228 Mdot
.58064 .67244 Mdot
.64853 .26025 Mdot
.27923 .61623 Mdot
.15613 .55356 Mdot
.48374 .74287 Mdot
.26365 .65396 Mdot
.56906 .71133 Mdot
.62027 .29803 Mdot
.54649 .68155 Mdot
.57908 .67463 Mdot
.11746 .56968 Mdot
.53194 .65746 Mdot
.39172 .57605 Mdot
.44012 .57265 Mdot
.67725 .74243 Mdot
.33112 .36032 Mdot
.39315 .59443 Mdot
.38634 .52411 Mdot
.40849 .33959 Mdot
.29238 .56115 Mdot
.64781 .6095 Mdot
.59336 .55458 Mdot
.69929 .60118 Mdot
.37791 .56533 Mdot
.37689 .5334 Mdot
.4368 .51998 Mdot
.84427 .58105 Mdot
.22884 .63385 Mdot
.57735 .70345 Mdot
.37284 .48187 Mdot
.70234 .58154 Mdot
.38252 .51216 Mdot
.3817 .51401 Mdot
.4311 .57817 Mdot
.50144 .32141 Mdot
.59845 .66178 Mdot
.44765 .58589 Mdot
.67066 .6999 Mdot
.37066 .53401 Mdot
.45885 .31133 Mdot
.37808 .29238 Mdot
.39016 .56774 Mdot
.52659 .67031 Mdot
.41125 .54309 Mdot
.5326 .64783 Mdot
.54627 .69052 Mdot
.35592 .61496 Mdot
.69062 .29613 Mdot
.59813 .65424 Mdot
.42791 .52317 Mdot
.51836 .31879 Mdot
.75557 .62754 Mdot
.39091 .55906 Mdot
.3987 .31794 Mdot
.40676 .57055 Mdot
.37884 .30414 Mdot
.43463 .56318 Mdot
.65421 .61698 Mdot
.37368 .69293 Mdot
.5097 .32882 Mdot
.39983 .36804 Mdot
.48157 .32376 Mdot
.38925 .44667 Mdot
.53113 .69336 Mdot
.64956 .60555 Mdot
.22371 .64797 Mdot
.67652 .60229 Mdot
.21733 .47606 Mdot
.61895 .37489 Mdot
.64811 .4322 Mdot
.54535 .63613 Mdot
.26213 .60862 Mdot
.67053 .29901 Mdot
.56186 .34734 Mdot
.55923 .34168 Mdot
.25341 .30361 Mdot
.16083 .39363 Mdot
.3666 .56731 Mdot
.61655 .19405 Mdot
.4042 .73154 Mdot
.33992 .52274 Mdot
.43109 .50512 Mdot
.50264 .30855 Mdot
.40533 .59554 Mdot
.55524 .45777 Mdot
.50489 .34594 Mdot
.3765 .32927 Mdot
.57206 .68995 Mdot
.36567 .34258 Mdot
.77024 .40878 Mdot
.63882 .52369 Mdot
.50625 .35428 Mdot
.36477 .59492 Mdot
.35864 .56134 Mdot
.55409 .63541 Mdot
.578 .78086 Mdot
.55111 .69529 Mdot
.39758 .3133 Mdot
.50254 .33549 Mdot
.25883 .66426 Mdot
.40317 .57981 Mdot
.53967 .65714 Mdot
.56865 .36921 Mdot
.40269 .54746 Mdot
.64783 .42708 Mdot
.40435 .52931 Mdot
.53359 .66384 Mdot
.433 .55364 Mdot
.54819 .66232 Mdot
.53957 .32646 Mdot
.35023 .54911 Mdot
.37863 .53252 Mdot
.2101 .48806 Mdot
.39202 .3227 Mdot
.53525 .6979 Mdot
.55771 .46201 Mdot
.36394 .52351 Mdot
.23792 .45845 Mdot
.41724 .59089 Mdot
.47436 .58839 Mdot
.44237 .51862 Mdot
.68073 .62161 Mdot
.36378 .51729 Mdot
.38991 .5583 Mdot
.53638 .78765 Mdot
.51564 .76549 Mdot
.42336 .46329 Mdot
.6629 .38799 Mdot
.52861 .67525 Mdot
.50574 .35995 Mdot
.48637 .34546 Mdot
.53531 .33932 Mdot
.32335 .35482 Mdot
.3017 .55751 Mdot
.38715 .54929 Mdot
.68043 .45617 Mdot
.38399 .3292 Mdot
.55199 .65048 Mdot
.38563 .33481 Mdot
.58831 .55465 Mdot
.38723 .31058 Mdot
.67603 .62437 Mdot
.56009 .22039 Mdot
.3287 .73041 Mdot
.38573 .31365 Mdot
.54965 .69428 Mdot
.57997 .40466 Mdot
.33801 .55081 Mdot
.72989 .56605 Mdot
.40576 .34049 Mdot
.27031 .28819 Mdot
.44041 .56059 Mdot
.56676 .4612 Mdot
.67675 .42392 Mdot
.36555 .34097 Mdot
.68725 .42704 Mdot
.41262 .54754 Mdot
.62542 .74996 Mdot
.56317 .67905 Mdot
.68148 .44479 Mdot
.35543 .52129 Mdot
.36591 .34254 Mdot
.50992 .35702 Mdot
.27012 .54467 Mdot
.68989 .38946 Mdot
.22552 .43512 Mdot
.24292 .43228 Mdot
.50212 .33767 Mdot
.30111 .73818 Mdot
.68476 .42236 Mdot
.34495 .58001 Mdot
.31906 .63379 Mdot
.41037 .53488 Mdot
.49416 .35288 Mdot
.53219 .35529 Mdot
.72304 .68681 Mdot
.36662 .53286 Mdot
.43297 .58573 Mdot
.59849 .67464 Mdot
.49895 .34672 Mdot
.58133 .66887 Mdot
.5741 .64148 Mdot
.52943 .32377 Mdot
.5814 .68717 Mdot
.36752 .31877 Mdot
.57329 .54213 Mdot
.68466 .41929 Mdot
.64799 .4155 Mdot
.50782 .35827 Mdot
.5246 .37304 Mdot
.4917 .32815 Mdot
.40656 .52578 Mdot
.586 .66686 Mdot
.42369 .54484 Mdot
.40421 .59259 Mdot
.51986 .70548 Mdot
.59338 .67783 Mdot
.41889 .54249 Mdot
.52909 .40741 Mdot
.37576 .3002 Mdot
.53032 .35279 Mdot
.68397 .39973 Mdot
.2047 .48785 Mdot
.68742 .44104 Mdot
.37158 .52154 Mdot
.74729 .5696 Mdot
.5661 .65152 Mdot
.39689 .33436 Mdot
.34962 .34671 Mdot
.39295 .34045 Mdot
.68112 .44509 Mdot
.57264 .63856 Mdot
.61572 .54555 Mdot
.36062 .53595 Mdot
.5908 .52265 Mdot
.22193 .49695 Mdot
.69545 .68497 Mdot
.67341 .39342 Mdot
.39817 .52712 Mdot
.6815 .60304 Mdot
.31702 .70132 Mdot
.38333 .54558 Mdot
.3534 .52785 Mdot
.45764 .22596 Mdot
.32101 .56279 Mdot
.52098 .63805 Mdot
.47518 .46296 Mdot
.34638 .5579 Mdot
.412 .45775 Mdot
.11784 .48259 Mdot
.44132 .55491 Mdot
.37523 .53106 Mdot
.39829 .5749 Mdot
.4184 .5579 Mdot
.52139 .66494 Mdot
.42962 .21638 Mdot
.64534 .40564 Mdot
.57262 .54025 Mdot
.68768 .41849 Mdot
.52266 .36167 Mdot
.53408 .4481 Mdot
.52753 .65233 Mdot
.39372 .34035 Mdot
.60218 .18164 Mdot
.55494 .55137 Mdot
.52401 .31704 Mdot
.20151 .58947 Mdot
.4038 .34105 Mdot
.33862 .55576 Mdot
.35871 .3284 Mdot
.49397 .30923 Mdot
.65411 .40596 Mdot
.4133 .51212 Mdot
.57298 .65188 Mdot
.53908 .69223 Mdot
.39881 .52414 Mdot
.74016 .63681 Mdot
.69462 .41345 Mdot
.44136 .29771 Mdot
.36354 .54281 Mdot
.35248 .52925 Mdot
.56208 .69717 Mdot
.52612 .33936 Mdot
.60654 .38158 Mdot
.38435 .32049 Mdot
.35896 .51537 Mdot
.41165 .5478 Mdot
.58558 .54871 Mdot
.64173 .3996 Mdot
.67099 .61537 Mdot
.36507 .53731 Mdot
.59048 .53811 Mdot
.37533 .52242 Mdot
.4123 .62396 Mdot
.50351 .31675 Mdot
.37677 .6143 Mdot
.35811 .57986 Mdot
.5124 .71373 Mdot
.68356 .42825 Mdot
.56307 .67201 Mdot
.56973 .72233 Mdot
.65879 .60829 Mdot
.65998 .43357 Mdot
.41674 .53909 Mdot
.64709 .43826 Mdot
.41217 .5784 Mdot
.36983 .55965 Mdot
.67358 .39321 Mdot
.58298 .67188 Mdot
.80659 .4904 Mdot
.5884 .75329 Mdot
.42606 .56728 Mdot
.40816 .56356 Mdot
.33417 .37022 Mdot
.25671 .7027 Mdot
.35948 .58236 Mdot
.58706 .66557 Mdot
.40153 .54479 Mdot
.64666 .41215 Mdot
.39544 .31212 Mdot
.5536 .6758 Mdot
.53216 .37076 Mdot
.54722 .33637 Mdot
.57354 .37685 Mdot
.68423 .62102 Mdot
.35708 .58381 Mdot
.50938 .66883 Mdot
.59356 .68629 Mdot
.61101 .58774 Mdot
.52261 .35338 Mdot
.38486 .30818 Mdot
.4295 .58568 Mdot
.26978 .55937 Mdot
.6399 .42272 Mdot
.378 .88512 Mdot
.61943 .54491 Mdot
.40324 .30632 Mdot
.50113 .50901 Mdot
.6829 .60606 Mdot
.37037 .58029 Mdot
.37541 .35666 Mdot
.54514 .34562 Mdot
.4137 .55714 Mdot
.31417 .53723 Mdot
.67398 .30952 Mdot
.54256 .36972 Mdot
.65351 .44076 Mdot
.54615 .3533 Mdot
.37812 .30269 Mdot
.67296 .62487 Mdot
.55136 .70291 Mdot
.38718 .56016 Mdot
.45304 .50271 Mdot
.52164 .34613 Mdot
.65344 .61171 Mdot
.37101 .52822 Mdot
.53119 .68129 Mdot
.53338 .348 Mdot
.37731 .57113 Mdot
.30256 .67924 Mdot
.49074 .62403 Mdot
.50907 .33665 Mdot
.39635 .50738 Mdot
.35084 .45746 Mdot
.54965 .36307 Mdot
.51415 .3079 Mdot
.38534 .52343 Mdot
.36644 .3357 Mdot
.35038 .55972 Mdot
.67562 .40894 Mdot
.58445 .48168 Mdot
.65233 .42982 Mdot
.22749 .47063 Mdot
.44244 .57055 Mdot
.53767 .59823 Mdot
.55214 .64042 Mdot
.35643 .35245 Mdot
.51649 .79357 Mdot
.34611 .53909 Mdot
.82797 .48081 Mdot
.5533 .4273 Mdot
.64725 .5373 Mdot
.81397 .40389 Mdot
.38275 .31712 Mdot
.67019 .41083 Mdot
.3767 .52898 Mdot
.70913 .39994 Mdot
.37112 .32081 Mdot
.22487 .47442 Mdot
.37736 .5118 Mdot
.57157 .65783 Mdot
.36688 .54255 Mdot
.53057 .67051 Mdot
.40476 .55659 Mdot
.31805 .51343 Mdot
.4368 .34044 Mdot
.28883 .33386 Mdot
.33898 .5619 Mdot
.60718 .17872 Mdot
.30815 .47435 Mdot
.40223 .32681 Mdot
.42907 .56449 Mdot
.67947 .61247 Mdot
.68427 .39137 Mdot
.57621 .20045 Mdot
.49623 .3235 Mdot
.66973 .39704 Mdot
.57057 .69435 Mdot
.46956 .3366 Mdot
.65812 .60628 Mdot
.33098 .64098 Mdot
.36713 .34546 Mdot
.66537 .43493 Mdot
.39002 .5619 Mdot
.37893 .5163 Mdot
.54845 .22187 Mdot
.33718 .78345 Mdot
.58524 .65372 Mdot
.32852 .22765 Mdot
.51017 .6619 Mdot
.38767 .3246 Mdot
.50007 .31765 Mdot
.38258 .58326 Mdot
.38138 .53924 Mdot
.5013 .36128 Mdot
.59022 .67729 Mdot
.50103 .29491 Mdot
.23373 .61611 Mdot
.73235 .40068 Mdot
.30382 .38695 Mdot
.55217 .67851 Mdot
.3012 .38344 Mdot
.39651 .30369 Mdot
.73287 .32819 Mdot
.30909 .45004 Mdot
.65563 .43681 Mdot
.30645 .39106 Mdot
.54761 .6497 Mdot
.36647 .56984 Mdot
.68207 .61835 Mdot
.68158 .60091 Mdot
.56097 .69168 Mdot
.52891 .32554 Mdot
.37634 .35068 Mdot
.37104 .5416 Mdot
.59422 .60588 Mdot
.63352 .78595 Mdot
.51565 .37084 Mdot
.34768 .61703 Mdot
.69329 .41837 Mdot
.40507 .54995 Mdot
.40448 .35014 Mdot
.6599 .40771 Mdot
.66892 .62738 Mdot
.55607 .54181 Mdot
.42847 .58722 Mdot
.45426 .44496 Mdot
.67005 .42999 Mdot
.26138 .71266 Mdot
.37987 .5331 Mdot
.68471 .4229 Mdot
.4623 .52601 Mdot
.64303 .71058 Mdot
.50713 .4172 Mdot
.7918 .599 Mdot
.55157 .37278 Mdot
.54887 .34029 Mdot
.46282 .8484 Mdot
.42342 .34387 Mdot
.65474 .39496 Mdot
.66424 .62496 Mdot
.30698 .4331 Mdot
.68233 .4348 Mdot
.42055 .51613 Mdot
.41891 .59068 Mdot
.2623 .63748 Mdot
.37122 .43792 Mdot
.66132 .59951 Mdot
.40101 .64374 Mdot
.42877 .53448 Mdot
.34131 .5841 Mdot
.39235 .53091 Mdot
.56577 .70768 Mdot
.67325 .44322 Mdot
.70899 .20937 Mdot
.64854 .44277 Mdot
.57991 .58892 Mdot
.51515 .33785 Mdot
.4955 .3658 Mdot
.38921 .5681 Mdot
.50312 .59059 Mdot
.65724 .21518 Mdot
.40331 .58377 Mdot
.34678 .34307 Mdot
.24212 .43052 Mdot
.39207 .60614 Mdot
.6009 .69138 Mdot
.43027 .60867 Mdot
.51564 .66578 Mdot
.65782 .40754 Mdot
.3806 .31737 Mdot
.37801 .29858 Mdot
.67421 .4161 Mdot
.38857 .54603 Mdot
.36672 .2973 Mdot
.383 .56385 Mdot
.36123 .56317 Mdot
.59422 .56084 Mdot
.40445 .35752 Mdot
.49075 .32855 Mdot
.39192 .33592 Mdot
.5776 .67193 Mdot
.11954 .60095 Mdot
.38036 .34084 Mdot
.29366 .50268 Mdot
.55385 .44447 Mdot
.30399 .39217 Mdot
.54168 .69415 Mdot
.40121 .31807 Mdot
.66629 .44246 Mdot
.63932 .54856 Mdot
.29464 .72775 Mdot
.67935 .44452 Mdot
.37867 .54003 Mdot
.52917 .65021 Mdot
.58691 .69875 Mdot
.63125 .43439 Mdot
.57715 .69793 Mdot
.33365 .59184 Mdot
.42671 .52161 Mdot
.65152 .3981 Mdot
.67267 .75659 Mdot
.67076 .44416 Mdot
.27302 .54644 Mdot
.43581 .56852 Mdot
.55676 .67569 Mdot
.46822 .6008 Mdot
.50243 .66008 Mdot
.68954 .60477 Mdot
.3924 .5963 Mdot
.39067 .34622 Mdot
.57262 .51236 Mdot
.50965 .33548 Mdot
.7508 .56732 Mdot
.53202 .67494 Mdot
.66373 .45292 Mdot
.56411 .70229 Mdot
.5882 .66067 Mdot
.67275 .44626 Mdot
.57183 .67469 Mdot
.3734 .53434 Mdot
.71604 .47934 Mdot
.53333 .67341 Mdot
.66367 .42485 Mdot
.38942 .34929 Mdot
.58354 .68318 Mdot
.51419 .29558 Mdot
.36051 .56789 Mdot
.4973 .31383 Mdot
.39149 .36894 Mdot
.53117 .6461 Mdot
.39698 .31421 Mdot
.52321 .34944 Mdot
.3774 .35288 Mdot
.71554 .42644 Mdot
.6948 .44664 Mdot
.56297 .571 Mdot
.62165 .71562 Mdot
.55658 .64649 Mdot
.56158 .36681 Mdot
.37055 .58454 Mdot
.35926 .54929 Mdot
.36124 .3195 Mdot
.58434 .7027 Mdot
.7506 .62369 Mdot
.46851 .61801 Mdot
.7275 .64752 Mdot
.6517 .39124 Mdot
.26552 .32831 Mdot
.62553 .54553 Mdot
.66205 .53775 Mdot
.40548 .4981 Mdot
.68391 .60737 Mdot
.38287 .57143 Mdot
.23799 .40379 Mdot
.39967 .31322 Mdot
.60906 .33618 Mdot
.35256 .51567 Mdot
.49621 .33731 Mdot
.40455 .56803 Mdot
.60745 .19493 Mdot
.4497 .60076 Mdot
.40684 .3313 Mdot
.70264 .41792 Mdot
.5792 .65182 Mdot
.40333 .33701 Mdot
.54431 .33086 Mdot
.33888 .40516 Mdot
.42596 .51515 Mdot
.43075 .53316 Mdot
.55733 .33481 Mdot
.58023 .66418 Mdot
.52362 .35981 Mdot
.68482 .41954 Mdot
.38233 .33812 Mdot
.42015 .56017 Mdot
.36081 .60831 Mdot
.5321 .30907 Mdot
.64044 .4375 Mdot
.51587 .37254 Mdot
.64383 .43557 Mdot
.68531 .60969 Mdot
.35296 .58141 Mdot
.5366 .31345 Mdot
.39299 .4944 Mdot
.51148 .75146 Mdot
.57973 .5607 Mdot
.4882 .79371 Mdot
.49018 .32865 Mdot
.33541 .38701 Mdot
.67072 .41896 Mdot
.67355 .4355 Mdot
.26476 .6258 Mdot
.66036 .22117 Mdot
.58419 .39507 Mdot
.54295 .17603 Mdot
.68473 .41831 Mdot
.66298 .4308 Mdot
.54393 .34321 Mdot
.57425 .68113 Mdot
.60887 .6802 Mdot
.48409 .31253 Mdot
.26709 .35698 Mdot
.55111 .6505 Mdot
.83289 .52401 Mdot
.5543 .34084 Mdot
.4242 .50607 Mdot
.67727 .59458 Mdot
.40686 .33595 Mdot
.24441 .39493 Mdot
.55653 .17958 Mdot
.38475 .5799 Mdot
.15588 .49907 Mdot
.51597 .32438 Mdot
.7281 .38591 Mdot
.74294 .35574 Mdot
.36358 .52011 Mdot
.40263 .56801 Mdot
.39178 .54255 Mdot
.38026 .36909 Mdot
.55687 .77136 Mdot
.38175 .58032 Mdot
.29498 .33211 Mdot
.42851 .59873 Mdot
.52931 .19785 Mdot
.39156 .33595 Mdot
.23804 .53268 Mdot
.54385 .3788 Mdot
.68017 .68482 Mdot
.32563 .55238 Mdot
.68271 .41743 Mdot
.67798 .3455 Mdot
.66737 .39318 Mdot
.70596 .28282 Mdot
.30467 .45216 Mdot
.56507 .70831 Mdot
.40378 .52822 Mdot
.55159 .32913 Mdot
.5314 .64754 Mdot
.60872 .37666 Mdot
.1112 .56261 Mdot
.63366 .40861 Mdot
.19897 .31552 Mdot
.66662 .43892 Mdot
.67743 .59952 Mdot
.56118 .69483 Mdot
.45407 .48059 Mdot
.58684 .52557 Mdot
.58155 .67016 Mdot
.41287 .27891 Mdot
.58781 .71246 Mdot
.31302 .3755 Mdot
.55436 .71606 Mdot
.66549 .41879 Mdot
.69227 .4474 Mdot
.3613 .49295 Mdot
.36478 .5845 Mdot
.59932 .52258 Mdot
.41473 .49215 Mdot
.38285 .59173 Mdot
.50471 .34584 Mdot
.6312 .70866 Mdot
.66744 .36962 Mdot
.55306 .68398 Mdot
.63823 .41507 Mdot
.40322 .56962 Mdot
.42648 .56654 Mdot
.33143 .53893 Mdot
.21967 .4411 Mdot
.83281 .51588 Mdot
.36864 .56341 Mdot
.41474 .61398 Mdot
.52404 .31812 Mdot
.5425 .21444 Mdot
.3726 .21435 Mdot
.31348 .43409 Mdot
.36825 .52788 Mdot
.39333 .32576 Mdot
.40952 .3329 Mdot
.32875 .59515 Mdot
.54575 .59189 Mdot
.53712 .29871 Mdot
.39023 .56182 Mdot
.37624 .41793 Mdot
.54171 .31061 Mdot
.65256 .61577 Mdot
.52139 .3466 Mdot
.52767 .65014 Mdot
.675 .60127 Mdot
.52072 .36775 Mdot
.48713 .5475 Mdot
.65936 .6091 Mdot
.6502 .70611 Mdot
.39816 .31358 Mdot
.38768 .53122 Mdot
.51712 .62278 Mdot
.50277 .36111 Mdot
.67005 .43266 Mdot
.54741 .66765 Mdot
.66599 .38414 Mdot
.54805 .21301 Mdot
.25327 .38574 Mdot
.68823 .61789 Mdot
.68139 .4134 Mdot
.50947 .4811 Mdot
.39311 .32804 Mdot
.68514 .43583 Mdot
.5216 .60105 Mdot
.40581 .60132 Mdot
.72558 .27837 Mdot
.42279 .52527 Mdot
.74363 .67032 Mdot
.67706 .43082 Mdot
.69574 .61562 Mdot
.38578 .5584 Mdot
.53649 .32015 Mdot
.41859 .48748 Mdot
.38166 .56258 Mdot
.54515 .3589 Mdot
.36734 .56797 Mdot
.39196 .36208 Mdot
.51831 .65503 Mdot
.54324 .42878 Mdot
.22776 .39629 Mdot
.38677 .35361 Mdot
.63983 .60298 Mdot
.36486 .58687 Mdot
.36944 .26303 Mdot
.57268 .66178 Mdot
.35435 .52907 Mdot
.19099 .53639 Mdot
.5667 .68808 Mdot
.56071 .66236 Mdot
.43017 .54897 Mdot
.68217 .44271 Mdot
.49379 .34833 Mdot
.39374 .33055 Mdot
.62845 .37716 Mdot
.37652 .57317 Mdot
.39565 .52605 Mdot
.40355 .34056 Mdot
.65837 .43148 Mdot
.42056 .5562 Mdot
.78148 .51507 Mdot
.60633 .58641 Mdot
.64256 .42978 Mdot
.40186 .60312 Mdot
.76315 .3019 Mdot
.61018 .67295 Mdot
.1542 .51409 Mdot
.42044 .34571 Mdot
.52159 .32153 Mdot
.32325 .6019 Mdot
.32985 .8582 Mdot
.40304 .3259 Mdot
.69164 .67878 Mdot
.36505 .56024 Mdot
.3902 .58798 Mdot
.54125 .70034 Mdot
.42085 .53914 Mdot
.53256 .66028 Mdot
.23048 .3816 Mdot
.59179 .15817 Mdot
.56989 .70015 Mdot
.53116 .66447 Mdot
.4379 .47883 Mdot
.21584 .45939 Mdot
.57299 .69086 Mdot
.42659 .51515 Mdot
.41663 .27072 Mdot
.30478 .56134 Mdot
.41212 .3203 Mdot
.35143 .33625 Mdot
.58863 .70385 Mdot
.37818 .79514 Mdot
.4637 .52333 Mdot
.35225 .47479 Mdot
.3282 .31314 Mdot
.67915 .40253 Mdot
.42288 .58232 Mdot
.67877 .62385 Mdot
.53638 .3481 Mdot
.43955 .60323 Mdot
.38628 .53436 Mdot
.52891 .65768 Mdot
.37372 .36804 Mdot
.68696 .43097 Mdot
.38424 .52546 Mdot
.46818 .31482 Mdot
.3776 .32548 Mdot
.53501 .67512 Mdot
.29026 .51048 Mdot
.39713 .30759 Mdot
.34715 .60085 Mdot
.38617 .59124 Mdot
.37293 .52558 Mdot
.32905 .52989 Mdot
.67539 .41889 Mdot
.47635 .31988 Mdot
.31732 .58893 Mdot
.59896 .54887 Mdot
.56838 .50022 Mdot
.32141 .59343 Mdot
.58786 .6691 Mdot
.66251 .38914 Mdot
.66251 .61277 Mdot
.30687 .41212 Mdot
.4394 .5613 Mdot
.83191 .49615 Mdot
.2166 .61067 Mdot
.66548 .60757 Mdot
.53814 .70378 Mdot
.39535 .33643 Mdot
.43469 .54467 Mdot
.3573 .28908 Mdot
.42089 .51745 Mdot
.30899 .60555 Mdot
.51769 .32204 Mdot
.68378 .40332 Mdot
.61787 .61501 Mdot
.53663 .3494 Mdot
.56074 .66311 Mdot
.76143 .67719 Mdot
.60029 .70062 Mdot
.58407 .64898 Mdot
.69501 .29537 Mdot
.65911 .40271 Mdot
.3541 .87537 Mdot
.25478 .70294 Mdot
.44143 .5372 Mdot
.65259 .40208 Mdot
.55444 .69216 Mdot
.40877 .5231 Mdot
.55388 .64741 Mdot
.60045 .6597 Mdot
.40094 .59576 Mdot
.37837 .58891 Mdot
.28474 .34452 Mdot
.83274 .55076 Mdot
.38328 .34749 Mdot
.58004 .69846 Mdot
.27314 .64987 Mdot
.37874 .58122 Mdot
.3595 .53787 Mdot
.68366 .32827 Mdot
.40336 .32316 Mdot
.36278 .74392 Mdot
.36132 .54914 Mdot
.18763 .52751 Mdot
.38358 .5931 Mdot
.59969 .63893 Mdot
.62875 .43492 Mdot
.56429 .59425 Mdot
.4929 .35057 Mdot
.54141 .63537 Mdot
.36957 .31057 Mdot
.5488 .6323 Mdot
.27796 .63493 Mdot
.65631 .40608 Mdot
.53356 .66359 Mdot
.4782 .35694 Mdot
.65379 .42152 Mdot
.65444 .437 Mdot
.57468 .39396 Mdot
.47144 .3442 Mdot
.38276 .367 Mdot
.68457 .3943 Mdot
.29848 .67123 Mdot
.66301 .41662 Mdot
.28238 .64971 Mdot
.3481 .56178 Mdot
.29368 .35237 Mdot
.60435 .60385 Mdot
.34388 .50623 Mdot
.67695 .4421 Mdot
.3715 .34002 Mdot
.41341 .53493 Mdot
.58018 .69553 Mdot
.37556 .33894 Mdot
.70096 .38019 Mdot
.50365 .37301 Mdot
.59136 .69653 Mdot
.69685 .43555 Mdot
.53669 .6524 Mdot
.24098 .41812 Mdot
.50871 .28544 Mdot
.50279 .40505 Mdot
.58871 .51916 Mdot
.33534 .56573 Mdot
.41395 .45854 Mdot
.37239 .51602 Mdot
.38436 .53974 Mdot
.50989 .33714 Mdot
.32311 .35595 Mdot
.58419 .68216 Mdot
.67506 .7759 Mdot
.68061 .41911 Mdot
.47882 .46717 Mdot
.31092 .61364 Mdot
.41256 .57295 Mdot
.5451 .68355 Mdot
.59525 .6546 Mdot
.51557 .76597 Mdot
.50147 .36197 Mdot
.30859 .5513 Mdot
.32348 .56424 Mdot
.30091 .55027 Mdot
.66193 .43924 Mdot
.79232 .50067 Mdot
.49871 .36515 Mdot
.14343 .39056 Mdot
.53077 .35328 Mdot
.41735 .23432 Mdot
.57165 .6757 Mdot
.37995 .30964 Mdot
.35598 .54458 Mdot
.58731 .74042 Mdot
.5217 .67328 Mdot
.56523 .3291 Mdot
.39684 .33902 Mdot
.80126 .49459 Mdot
.66484 .39795 Mdot
.34868 .54566 Mdot
.40146 .59655 Mdot
.42612 .55048 Mdot
.40144 .51584 Mdot
.64504 .40219 Mdot
.41355 .51353 Mdot
.68366 .38351 Mdot
.29751 .68936 Mdot
.19473 .53701 Mdot
.52785 .31138 Mdot
.52778 .20369 Mdot
.5882 .66242 Mdot
.3388 .66845 Mdot
.35754 .74676 Mdot
.58082 .56243 Mdot
.69911 .45126 Mdot
.34867 .5711 Mdot
.53176 .32736 Mdot
.62248 .19451 Mdot
.53513 .31484 Mdot
.64077 .15926 Mdot
.26117 .60404 Mdot
.78847 .61663 Mdot
.41314 .52179 Mdot
.48979 .30557 Mdot
.4075 .79729 Mdot
.3638 .61014 Mdot
.36205 .30282 Mdot
.28028 .5769 Mdot
.67548 .73431 Mdot
.3871 .30778 Mdot
.36315 .57075 Mdot
.59387 .66782 Mdot
.37235 .53582 Mdot
.3535 .55548 Mdot
.40453 .58113 Mdot
.62875 .41172 Mdot
.40496 .59804 Mdot
.35051 .55896 Mdot
.31322 .7644 Mdot
.36907 .39148 Mdot
.52692 .31751 Mdot
.49565 .78093 Mdot
.38357 .32936 Mdot
.53447 .64439 Mdot
.55769 .43083 Mdot
.67343 .40364 Mdot
.5105 .7609 Mdot
.41719 .52294 Mdot
.71963 .66325 Mdot
.68366 .45057 Mdot
.37106 .32572 Mdot
.65954 .6132 Mdot
.79708 .44583 Mdot
.48489 .32656 Mdot
.67569 .59778 Mdot
.5097 .33443 Mdot
.47039 .81162 Mdot
.52974 .66622 Mdot
.33588 .56874 Mdot
.69049 .41857 Mdot
.50547 .3085 Mdot
.31797 .30703 Mdot
.3964 .54007 Mdot
.48977 .33022 Mdot
.34018 .57458 Mdot
.57448 .49724 Mdot
.56448 .44166 Mdot
.48916 .3127 Mdot
.69467 .44361 Mdot
.65104 .42182 Mdot
.37073 .31404 Mdot
.54344 .63821 Mdot
.57735 .65659 Mdot
.65788 .41247 Mdot
.14849 .42228 Mdot
.37811 .57379 Mdot
.39076 .59146 Mdot
.60554 .54665 Mdot
.40178 .51844 Mdot
.35585 .40117 Mdot
.64555 .61388 Mdot
.55611 .64438 Mdot
.39364 .51691 Mdot
.42104 .55724 Mdot
.42764 .58646 Mdot
.25493 .38655 Mdot
.52366 .34526 Mdot
.43001 .53616 Mdot
.37044 .35201 Mdot
.64841 .64659 Mdot
.3676 .58244 Mdot
.35974 .60644 Mdot
.53567 .65611 Mdot
.2846 .28232 Mdot
.67476 .43038 Mdot
.49802 .34773 Mdot
.55578 .34483 Mdot
.24644 .46526 Mdot
.55406 .62861 Mdot
.65 .60736 Mdot
.58231 .25406 Mdot
.66133 .62229 Mdot
.40069 .32545 Mdot
.53952 .40929 Mdot
.47042 .30984 Mdot
.54771 .33377 Mdot
.70192 .43245 Mdot
.38622 .51841 Mdot
.38478 .59287 Mdot
.6904 .67466 Mdot
.40106 .58965 Mdot
.39415 .34502 Mdot
.69938 .42254 Mdot
.53552 .65865 Mdot
.40071 .35397 Mdot
.67411 .43675 Mdot
.58097 .66451 Mdot
.40355 .60527 Mdot
.33053 .53684 Mdot
.55095 .66431 Mdot
.53646 .68296 Mdot
.39391 .57216 Mdot
.40785 .82586 Mdot
.56333 .64585 Mdot
.54161 .67579 Mdot
.70049 .61644 Mdot
.48711 .32016 Mdot
.45529 .6111 Mdot
.65326 .40271 Mdot
.36738 .53405 Mdot
.52663 .31043 Mdot
.3891 .31322 Mdot
.55197 .65752 Mdot
.42837 .57778 Mdot
.37365 .56487 Mdot
.39455 .32683 Mdot
.41321 .33994 Mdot
.39406 .34919 Mdot
.63828 .39602 Mdot
.4273 .52332 Mdot
.57604 .68981 Mdot
.6632 .39753 Mdot
.40841 .32905 Mdot
.35807 .34021 Mdot
.30682 .75455 Mdot
.38596 .57834 Mdot
.35857 .29833 Mdot
.15195 .66335 Mdot
.34036 .4104 Mdot
.66627 .60092 Mdot
.50489 .30228 Mdot
.29859 .34828 Mdot
.39542 .37117 Mdot
.66065 .39301 Mdot
.39573 .41051 Mdot
.36214 .36102 Mdot
.40807 .58912 Mdot
.40618 .5471 Mdot
.4019 .50135 Mdot
.37724 .33234 Mdot
.24746 .40562 Mdot
.59013 .69242 Mdot
.40516 .70921 Mdot
.38345 .32951 Mdot
.48782 .31435 Mdot
.52326 .3063 Mdot
.53076 .35533 Mdot
.34555 .56534 Mdot
.51645 .77951 Mdot
.28008 .66022 Mdot
.37548 .74326 Mdot
.6685 .39752 Mdot
.59687 .65849 Mdot
.67923 .46695 Mdot
.5608 .6617 Mdot
.5328 .33803 Mdot
.37412 .32868 Mdot
.54923 .70509 Mdot
.64894 .43085 Mdot
.65015 .42681 Mdot
.52228 .37471 Mdot
.5202 .35053 Mdot
.50763 .35555 Mdot
.54164 .63601 Mdot
.57197 .67496 Mdot
.42266 .5643 Mdot
.54291 .66019 Mdot
.21816 .63226 Mdot
.41444 .32423 Mdot
.5604 .34256 Mdot
.67149 .42643 Mdot
.54091 .68326 Mdot
.38492 .53098 Mdot
.47559 .231 Mdot
.56587 .33389 Mdot
.38899 .35567 Mdot
.66199 .49625 Mdot
.52568 .13124 Mdot
.38465 .60258 Mdot
.63698 .42847 Mdot
.5419 .59503 Mdot
.39575 .54818 Mdot
.50285 .31981 Mdot
.23255 .57663 Mdot
.65562 .61721 Mdot
.35534 .57163 Mdot
.3481 .53028 Mdot
.67699 .44393 Mdot
.5604 .43455 Mdot
.40662 .58628 Mdot
.4979 .44437 Mdot
.63104 .42196 Mdot
.49949 .36583 Mdot
.49018 .86065 Mdot
.72607 .39436 Mdot
.28943 .31775 Mdot
.66346 .60416 Mdot
.40854 .59108 Mdot
.50537 .34331 Mdot
.38209 .35811 Mdot
.51185 .34557 Mdot
.55537 .71352 Mdot
.49021 .32048 Mdot
.39932 .5351 Mdot
.57813 .68579 Mdot
.66213 .43388 Mdot
.46376 .45427 Mdot
.35012 .78626 Mdot
.53644 .32057 Mdot
.65127 .62465 Mdot
.36738 .57963 Mdot
.32407 .69907 Mdot
.36342 .4911 Mdot
.35948 .58127 Mdot
.6705 .39236 Mdot
.54839 .68432 Mdot
.65398 .39075 Mdot
.37234 .60494 Mdot
.35755 .65766 Mdot
.67942 .41693 Mdot
.65066 .74137 Mdot
.40438 .33932 Mdot
.2654 .35959 Mdot
.38122 .54789 Mdot
.69022 .41743 Mdot
.43039 .52545 Mdot
.58049 .69876 Mdot
.55589 .51681 Mdot
.61371 .62678 Mdot
.69354 .41663 Mdot
.75116 .6734 Mdot
.55782 .46336 Mdot
.44716 .61074 Mdot
.68623 .42183 Mdot
.51548 .79147 Mdot
.67623 .61333 Mdot
.38686 .31953 Mdot
.41168 .33877 Mdot
.36191 .33587 Mdot
.39915 .59078 Mdot
.29721 .5372 Mdot
.3621 .35198 Mdot
.64154 .39446 Mdot
.37474 .36022 Mdot
.22454 .44795 Mdot
.74398 .63331 Mdot
.39494 .35101 Mdot
.37814 .54821 Mdot
.36989 .60827 Mdot
.36604 .39031 Mdot
.48287 .35458 Mdot
.81886 .46714 Mdot
.27191 .70346 Mdot
.38416 .58373 Mdot
.28467 .61866 Mdot
.57269 .71252 Mdot
.50846 .55049 Mdot
.44318 .63556 Mdot
.57548 .41 Mdot
.53992 .67786 Mdot
.58952 .49329 Mdot
.55341 .64214 Mdot
.35 .58934 Mdot
.36958 .5585 Mdot
.5186 .66704 Mdot
.74082 .55998 Mdot
.59273 .79765 Mdot
.73192 .64659 Mdot
.58422 .66166 Mdot
.68357 .42858 Mdot
.63307 .42233 Mdot
.67414 .39395 Mdot
.50234 .35857 Mdot
.53216 .68001 Mdot
.43816 .54521 Mdot
.53974 .32781 Mdot
.35831 .54502 Mdot
.65198 .41365 Mdot
.60648 .58817 Mdot
.5347 .659 Mdot
.38959 .559 Mdot
.30213 .73185 Mdot
.51763 .33397 Mdot
.39147 .32635 Mdot
.68508 .49711 Mdot
.51262 .30174 Mdot
.6529 .44419 Mdot
.597 .64455 Mdot
.53719 .38781 Mdot
.43174 .2142 Mdot
.43328 .51728 Mdot
.43462 .52088 Mdot
.58184 .3217 Mdot
.33616 .76716 Mdot
.40876 .57516 Mdot
.54605 .33316 Mdot
.48591 .31931 Mdot
.43409 .52734 Mdot
.54942 .70086 Mdot
.36501 .35998 Mdot
.36229 .31823 Mdot
.33515 .55207 Mdot
.59567 .51828 Mdot
.29063 .34646 Mdot
.4189 .54513 Mdot
.35099 .62456 Mdot
.48337 .36045 Mdot
.65883 .60589 Mdot
.58317 .54116 Mdot
.36441 .3221 Mdot
.36362 .5598 Mdot
.61128 .78555 Mdot
.53359 .66794 Mdot
.49135 .34159 Mdot
.64262 .41718 Mdot
.37153 .2972 Mdot
.55354 .36402 Mdot
.43432 .52762 Mdot
.42077 .5564 Mdot
.68962 .42877 Mdot
.59777 .63692 Mdot
.37476 .33196 Mdot
.53558 .32461 Mdot
.37937 .30942 Mdot
.57419 .67006 Mdot
.53837 .671 Mdot
.32405 .56856 Mdot
.35592 .4976 Mdot
.55151 .33607 Mdot
.36929 .51047 Mdot
.53418 .35717 Mdot
.54748 .22049 Mdot
.63954 .4213 Mdot
.35951 .52336 Mdot
.52209 .63163 Mdot
.65302 .41318 Mdot
.39316 .58309 Mdot
.58267 .32419 Mdot
.41525 .55605 Mdot
.48619 .3094 Mdot
.23674 .60016 Mdot
.3715 .31914 Mdot
.40467 .46038 Mdot
.47013 .52306 Mdot
.40125 .51889 Mdot
.4734 .3363 Mdot
.30946 .5154 Mdot
.67721 .41432 Mdot
.56523 .68245 Mdot
.23838 .30918 Mdot
.66289 .42224 Mdot
.36964 .54567 Mdot
.38019 .33951 Mdot
.57877 .65014 Mdot
.6893 .6118 Mdot
.61423 .53368 Mdot
.44608 .59959 Mdot
.44399 .51785 Mdot
.37752 .52482 Mdot
.54373 .175 Mdot
.50737 .35097 Mdot
.54796 .68829 Mdot
.63468 .41986 Mdot
.66403 .40506 Mdot
.52603 .33892 Mdot
.6997 .71448 Mdot
.76205 .57677 Mdot
.18634 .71344 Mdot
.55726 .35586 Mdot
.36634 .35215 Mdot
.559 .50083 Mdot
.53707 .35174 Mdot
.50038 .34385 Mdot
.50336 .37405 Mdot
.70606 .65984 Mdot
.58534 .66869 Mdot
.37276 .56663 Mdot
.5416 .63129 Mdot
.4068 .59161 Mdot
.31228 .30222 Mdot
.6579 .4095 Mdot
.56696 .68129 Mdot
.5228 .27943 Mdot
.46506 .53279 Mdot
.40072 .55814 Mdot
.3716 .28365 Mdot
.44901 .58633 Mdot
.30905 .39995 Mdot
.32808 .54315 Mdot
.5166 .34277 Mdot
.39568 .65058 Mdot
.35186 .61537 Mdot
.2924 .71684 Mdot
.6529 .43131 Mdot
.69246 .6126 Mdot
.40605 .60636 Mdot
.40974 .62689 Mdot
.57649 .64744 Mdot
.5472 .70445 Mdot
.36218 .35299 Mdot
.7085 .48818 Mdot
.65572 .43293 Mdot
.80113 .55746 Mdot
.36452 .58534 Mdot
.65279 .37097 Mdot
.23312 .59774 Mdot
.39617 .57874 Mdot
.54466 .40406 Mdot
.51191 .76208 Mdot
.41249 .56856 Mdot
.38799 .74121 Mdot
.6695 .42351 Mdot
.18907 .53084 Mdot
.34762 .52231 Mdot
.50187 .32084 Mdot
.57273 .68108 Mdot
.5912 .69634 Mdot
.39139 .35702 Mdot
.23232 .66443 Mdot
.61975 .44701 Mdot
.57091 .67801 Mdot
.39281 .53997 Mdot
.67296 .43021 Mdot
.69144 .60901 Mdot
.46405 .56447 Mdot
.68037 .25336 Mdot
.53973 .6598 Mdot
.32001 .59573 Mdot
.73135 .65315 Mdot
.57273 .46344 Mdot
.83708 .53914 Mdot
.68201 .39668 Mdot
.36387 .32186 Mdot
.34587 .5118 Mdot
.58003 .25444 Mdot
.34366 .52366 Mdot
.30306 .30798 Mdot
.4993 .64719 Mdot
.39496 .31189 Mdot
.39342 .55048 Mdot
.40774 .58464 Mdot
.57798 .51801 Mdot
.41129 .32883 Mdot
.40716 .58638 Mdot
.31404 .56615 Mdot
.57698 .66081 Mdot
.64468 .61534 Mdot
.53894 .65581 Mdot
.37876 .53864 Mdot
.24456 .57031 Mdot
.55373 .70473 Mdot
.81323 .47735 Mdot
.42507 .34955 Mdot
.67434 .40384 Mdot
.35947 .62204 Mdot
.35075 .57074 Mdot
.82846 .39284 Mdot
.68841 .60375 Mdot
.33203 .23367 Mdot
.49394 .30511 Mdot
.62314 .8174 Mdot
.51874 .3022 Mdot
.77647 .63881 Mdot
.48476 .46572 Mdot
.39379 .50413 Mdot
.33846 .44005 Mdot
.37623 .73696 Mdot
.70809 .40268 Mdot
.33078 .68113 Mdot
.36479 .58441 Mdot
.36806 .57574 Mdot
.54512 .34008 Mdot
.71575 .69566 Mdot
.55931 .59627 Mdot
.58253 .53548 Mdot
.37378 .3239 Mdot
.56703 .67076 Mdot
.4017 .53969 Mdot
.71069 .53553 Mdot
.51748 .31157 Mdot
.28288 .51056 Mdot
.38743 .55751 Mdot
.57206 .58902 Mdot
.67834 .71419 Mdot
.66743 .43507 Mdot
.48411 .31562 Mdot
.47382 .32591 Mdot
.41856 .58909 Mdot
.65092 .4002 Mdot
.41841 .56812 Mdot
.55544 .46642 Mdot
.42311 .60944 Mdot
.39655 .31691 Mdot
.35732 .53931 Mdot
.36686 .43153 Mdot
.77959 .66862 Mdot
.40035 .62006 Mdot
.56276 .63898 Mdot
.51041 .36109 Mdot
.52831 .34672 Mdot
.5778 .6566 Mdot
.52905 .34614 Mdot
.40777 .7163 Mdot
.30423 .64911 Mdot
.40041 .32241 Mdot
.3543 .75169 Mdot
.37446 .31937 Mdot
.69214 .61392 Mdot
.38903 .57747 Mdot
.61783 .26026 Mdot
.55757 .35655 Mdot
.20719 .48407 Mdot
.66219 .41315 Mdot
.68537 .60183 Mdot
.43898 .57163 Mdot
.345 .30751 Mdot
.53422 .3338 Mdot
.71338 .35874 Mdot
.42704 .58512 Mdot
.58721 .68582 Mdot
.41188 .57361 Mdot
.44774 .56843 Mdot
.6697 .59894 Mdot
.37878 .52329 Mdot
.6743 .43666 Mdot
.53035 .67816 Mdot
.7768 .63038 Mdot
.50214 .36011 Mdot
.35816 .57124 Mdot
.39322 .54155 Mdot
.54171 .70304 Mdot
.43894 .57508 Mdot
.6594 .39455 Mdot
.41527 .90222 Mdot
.40421 .33576 Mdot
.6573 .6073 Mdot
.77021 .40878 Mdot
.40539 .53433 Mdot
.41519 .54017 Mdot
.60121 .39088 Mdot
.59316 .78337 Mdot
.68145 .42315 Mdot
.42844 .60074 Mdot
.5152 .31475 Mdot
.37292 .33515 Mdot
.68459 .39117 Mdot
.42427 .52064 Mdot
.37023 .57674 Mdot
.40191 .32276 Mdot
.36667 .28426 Mdot
.51391 .29393 Mdot
.6698 .39587 Mdot
.29164 .61994 Mdot
.48502 .2324 Mdot
.38145 .5692 Mdot
.70362 .58727 Mdot
.54637 .67742 Mdot
.68613 .41578 Mdot
.56255 .77072 Mdot
.34532 .58176 Mdot
.66296 .44489 Mdot
.65986 .43358 Mdot
.43435 .58312 Mdot
.56256 .62853 Mdot
.58032 .63918 Mdot
.5447 .67814 Mdot
.19994 .53236 Mdot
.4185 .19828 Mdot
.50553 .35538 Mdot
.66726 .42805 Mdot
.53234 .31204 Mdot
.35632 .34759 Mdot
.57033 .50093 Mdot
.48827 .31509 Mdot
.59005 .66474 Mdot
.54887 .32451 Mdot
.41783 .56222 Mdot
.64643 .4252 Mdot
.55387 .34536 Mdot
.41215 .52684 Mdot
.33782 .61918 Mdot
.35728 .43604 Mdot
.37022 .36469 Mdot
.59102 .49551 Mdot
.37321 .54256 Mdot
.6609 .61134 Mdot
.3924 .56893 Mdot
.65234 .39719 Mdot
.40132 .41472 Mdot
.42403 .52923 Mdot
.55827 .35461 Mdot
.44879 .20502 Mdot
.47557 .33873 Mdot
.44452 .56952 Mdot
.37796 .53977 Mdot
.38082 .57215 Mdot
.39445 .59506 Mdot
.66101 .74237 Mdot
.68832 .38434 Mdot
.30555 .59522 Mdot
.5459 .36862 Mdot
.55635 .66026 Mdot
.57055 .70559 Mdot
.5866 .39945 Mdot
.6875 .60047 Mdot
.65092 .40194 Mdot
.37928 .57235 Mdot
.71101 .35786 Mdot
.63647 .54171 Mdot
.73457 .64782 Mdot
.57975 .37195 Mdot
.54898 .33675 Mdot
.56325 .63743 Mdot
.54038 .36059 Mdot
.42593 .52034 Mdot
.32929 .53708 Mdot
.78539 .61952 Mdot
.63625 .39439 Mdot
.37476 .33036 Mdot
.35909 .54215 Mdot
.27804 .34226 Mdot
.52423 .3182 Mdot
.47788 .35545 Mdot
.41998 .56961 Mdot
.60655 .67419 Mdot
.82657 .6109 Mdot
.64527 .40848 Mdot
.31884 .69438 Mdot
.5405 .61243 Mdot
.29402 .60152 Mdot
.67322 .41383 Mdot
.50807 .41089 Mdot
.48729 .35628 Mdot
.25881 .69248 Mdot
.54949 .66276 Mdot
.37706 .32841 Mdot
.31878 .58136 Mdot
.58975 .66388 Mdot
.5414 .31553 Mdot
.53924 .64378 Mdot
.3369 .5717 Mdot
.6419 .39654 Mdot
.53206 .35016 Mdot
.702 .39615 Mdot
.52015 .66752 Mdot
.37292 .31949 Mdot
.21494 .48154 Mdot
.31066 .69261 Mdot
.5122 .76195 Mdot
.43064 .53703 Mdot
.65566 .28158 Mdot
.43873 .54943 Mdot
.58696 .64863 Mdot
.38072 .54772 Mdot
.40742 .4554 Mdot
.49647 .36649 Mdot
.33597 .60726 Mdot
.35244 .54655 Mdot
.2828 .69792 Mdot
.4009 .57 Mdot
.44111 .56063 Mdot
.33924 .53871 Mdot
.58485 .62488 Mdot
.33536 .6052 Mdot
.58651 .68615 Mdot
.69741 .67768 Mdot
.49996 .34138 Mdot
.35726 .32669 Mdot
.37748 .30373 Mdot
.30006 .30741 Mdot
.26991 .35445 Mdot
.70451 .70563 Mdot
.55496 .65157 Mdot
.66931 .44185 Mdot
.41908 .56593 Mdot
.50723 .80079 Mdot
.25758 .51681 Mdot
.49373 .36145 Mdot
.55157 .3315 Mdot
.32009 .55556 Mdot
.62367 .18134 Mdot
.32965 .60248 Mdot
.61705 .54503 Mdot
.40244 .59221 Mdot
.35485 .52717 Mdot
.47178 .34881 Mdot
.24058 .41343 Mdot
.43 .53597 Mdot
.57584 .64737 Mdot
.38295 .32359 Mdot
.32413 .6378 Mdot
.24768 .52124 Mdot
.26801 .56334 Mdot
.49331 .60606 Mdot
.41426 .51767 Mdot
.52731 .32179 Mdot
.58316 .65631 Mdot
.59592 .54486 Mdot
.66546 .3954 Mdot
.60474 .52492 Mdot
.2946 .68028 Mdot
.73845 .41748 Mdot
.37722 .32601 Mdot
.57359 .33692 Mdot
.39908 .53403 Mdot
.50296 .35819 Mdot
.36353 .59961 Mdot
.64122 .53679 Mdot
.39233 .31279 Mdot
.53134 .64084 Mdot
.68307 .42941 Mdot
.59127 .67937 Mdot
.49024 .79217 Mdot
.25439 .52875 Mdot
.62283 .81818 Mdot
.48414 .33168 Mdot
.47586 .66398 Mdot
.56329 .69167 Mdot
.43506 .57365 Mdot
.1812 .70471 Mdot
.55101 .67769 Mdot
.59004 .678 Mdot
.56988 .41476 Mdot
.22738 .47044 Mdot
.33021 .60667 Mdot
.54864 .64316 Mdot
.54702 .37893 Mdot
.39122 .34063 Mdot
.41636 .5322 Mdot
.33843 .56437 Mdot
.54504 .70295 Mdot
.53187 .33447 Mdot
.27756 .33554 Mdot
.51921 .34686 Mdot
.58517 .67407 Mdot
.51014 .32878 Mdot
.80813 .48064 Mdot
.5053 .31137 Mdot
.35171 .54626 Mdot
.37934 .5712 Mdot
.63509 .2366 Mdot
.53838 .67095 Mdot
.41396 .53711 Mdot
.36621 .56496 Mdot
.57091 .69243 Mdot
.46552 .31353 Mdot
.53607 .75359 Mdot
.40531 .52502 Mdot
.37535 .57006 Mdot
.39747 .31158 Mdot
.57652 .48291 Mdot
.67232 .55234 Mdot
.41533 .53371 Mdot
.36301 .34148 Mdot
.54409 .63526 Mdot
.39384 .56917 Mdot
.24001 .41109 Mdot
.54048 .31059 Mdot
.40065 .51194 Mdot
.68753 .61632 Mdot
.40606 .57952 Mdot
.82145 .61524 Mdot
.36478 .57666 Mdot
.55796 .69462 Mdot
.56901 .6868 Mdot
.53348 .30134 Mdot
.55975 .66455 Mdot
.67039 .60043 Mdot
.65202 .41877 Mdot
.73994 .69363 Mdot
.67529 .60062 Mdot
.35164 .53496 Mdot
.25383 .70235 Mdot
.33605 .56049 Mdot
.3721 .61157 Mdot
.21181 .46947 Mdot
.66644 .60311 Mdot
.5518 .68625 Mdot
.74088 .55497 Mdot
.3924 .50607 Mdot
.6472 .40494 Mdot
.36311 .60948 Mdot
.40035 .51168 Mdot
.37336 .44048 Mdot
.30356 .64274 Mdot
.70046 .41631 Mdot
.45531 .60914 Mdot
.41695 .53338 Mdot
.58711 .78232 Mdot
.39385 .53412 Mdot
.39516 .35241 Mdot
.55886 .64932 Mdot
.53463 .36569 Mdot
.39999 .32992 Mdot
.40258 .53491 Mdot
.37963 .33124 Mdot
.50287 .35361 Mdot
.68911 .40146 Mdot
.36051 .53504 Mdot
.40993 .31576 Mdot
.37283 .32954 Mdot
.43077 .56556 Mdot
.57023 .68044 Mdot
.37021 .48705 Mdot
.39505 .57086 Mdot
.4393 .53651 Mdot
.57693 .65635 Mdot
.15766 .5755 Mdot
.40619 .59506 Mdot
.51348 .4094 Mdot
.51279 .67049 Mdot
.65346 .60545 Mdot
.54433 .35183 Mdot
.38311 .49693 Mdot
.66141 .40359 Mdot
.65515 .4148 Mdot
.52786 .37581 Mdot
.53098 .68877 Mdot
.53326 .34734 Mdot
.45796 .59509 Mdot
.32016 .55149 Mdot
.31817 .57733 Mdot
.23997 .30758 Mdot
.79355 .43846 Mdot
.54582 .69279 Mdot
.48002 .34954 Mdot
.59576 .52419 Mdot
.6475 .41031 Mdot
.494 .3722 Mdot
.51077 .64443 Mdot
.52713 .66296 Mdot
.57608 .65304 Mdot
.36534 .33751 Mdot
.52442 .35384 Mdot
.50521 .67022 Mdot
.5891 .64286 Mdot
.42524 .56907 Mdot
.41812 .53375 Mdot
.58048 .71424 Mdot
.3905 .38844 Mdot
.3861 .31438 Mdot
.51504 .31887 Mdot
.87071 .46749 Mdot
.64481 .40876 Mdot
.28303 .69908 Mdot
.41097 .52636 Mdot
.08933 .509 Mdot
.32974 .60135 Mdot
.39321 .53808 Mdot
.52747 .65035 Mdot
.3904 .30061 Mdot
.38868 .33875 Mdot
.56458 .69133 Mdot
.60419 .65769 Mdot
.37146 .34855 Mdot
.56339 .40686 Mdot
.74123 .71148 Mdot
.59666 .53748 Mdot
.56405 .69684 Mdot
.31859 .70461 Mdot
.68709 .39401 Mdot
.51482 .65401 Mdot
.70292 .40502 Mdot
.49899 .34259 Mdot
.53811 .32012 Mdot
.69091 .4285 Mdot
.43455 .57861 Mdot
.488 .32713 Mdot
.43059 .61055 Mdot
.8117 .57194 Mdot
.72579 .30264 Mdot
.52835 .82169 Mdot
.36478 .58826 Mdot
.55255 .59264 Mdot
.66784 .67455 Mdot
.38461 .52275 Mdot
.47067 .59761 Mdot
.37623 .331 Mdot
.5138 .66209 Mdot
.68348 .38754 Mdot
.82898 .47455 Mdot
.38092 .57025 Mdot
.5844 .68149 Mdot
.64538 .41897 Mdot
.80376 .47971 Mdot
.49782 .44302 Mdot
.41616 .58124 Mdot
.2362 .77466 Mdot
.52118 .66573 Mdot
.53398 .36583 Mdot
.33123 .7485 Mdot
.53332 .63371 Mdot
.47824 .22309 Mdot
.4759 .3184 Mdot
.62895 .58287 Mdot
.52882 .65371 Mdot
.48605 .29849 Mdot
.57182 .66748 Mdot
.39449 .36049 Mdot
.59747 .64447 Mdot
.52237 .33204 Mdot
.39656 .5577 Mdot
.52213 .33478 Mdot
.40732 .33458 Mdot
.48846 .34199 Mdot
.68405 .38794 Mdot
.66172 .6063 Mdot
.64883 .42281 Mdot
.56671 .49824 Mdot
.47902 .69771 Mdot
.68352 .40287 Mdot
.69877 .34836 Mdot
.40918 .56859 Mdot
.60059 .64015 Mdot
.53064 .36916 Mdot
.56127 .3609 Mdot
.59554 .50739 Mdot
.58195 .67189 Mdot
.51904 .32723 Mdot
.30211 .68049 Mdot
.13727 .44112 Mdot
.36878 .62134 Mdot
.43422 .19298 Mdot
.57031 .69366 Mdot
.49406 .36572 Mdot
.60781 .54598 Mdot
.58181 .70391 Mdot
.55302 .34063 Mdot
.68611 .42517 Mdot
.66723 .40473 Mdot
.42536 .59089 Mdot
.63124 .43629 Mdot
.47267 .33728 Mdot
.60646 .7855 Mdot
.5646 .65022 Mdot
.78153 .43164 Mdot
.38832 .35308 Mdot
.50048 .34757 Mdot
.33437 .60811 Mdot
.49926 .66388 Mdot
.55693 .34249 Mdot
.67031 .23372 Mdot
.85616 .42768 Mdot
.51801 .32647 Mdot
.5573 .6491 Mdot
.55545 .65709 Mdot
.39404 .62006 Mdot
.58811 .52291 Mdot
.52946 .33095 Mdot
.61645 .25814 Mdot
.30606 .31476 Mdot
.68546 .60952 Mdot
.29055 .73531 Mdot
.42989 .53484 Mdot
.41182 .51622 Mdot
.66298 .39382 Mdot
.40273 .55845 Mdot
.59989 .65738 Mdot
.32455 .59477 Mdot
.63198 .41582 Mdot
.49929 .36501 Mdot
.38599 .57488 Mdot
.37302 .34246 Mdot
.66707 .39024 Mdot
.64427 .44301 Mdot
.50304 .332 Mdot
.55708 .64617 Mdot
.72924 .56484 Mdot
.52026 .34825 Mdot
.42485 .52264 Mdot
.67031 .60816 Mdot
.33153 .53898 Mdot
.63874 .24545 Mdot
.59145 .68965 Mdot
.53933 .3613 Mdot
.53031 .69851 Mdot
.66216 .42874 Mdot
.54199 .37681 Mdot
.39201 .52861 Mdot
.54734 .33002 Mdot
.49474 .40733 Mdot
.40428 .25718 Mdot
.59523 .64791 Mdot
.34508 .35017 Mdot
.54598 .70444 Mdot
.68605 .60985 Mdot
.2677 .44061 Mdot
.3875 .31792 Mdot
.4985 .31577 Mdot
.81522 .47034 Mdot
.53399 .37038 Mdot
.40038 .574 Mdot
.38393 .58956 Mdot
.54544 .34207 Mdot
.3659 .326 Mdot
.24763 .36129 Mdot
.32593 .30382 Mdot
.53157 .6707 Mdot
.49916 .48842 Mdot
.87158 .50831 Mdot
.48811 .37523 Mdot
.67322 .4418 Mdot
.41525 .63313 Mdot
.41279 .55404 Mdot
.67372 .44544 Mdot
.63856 .41591 Mdot
.40879 .33125 Mdot
.50028 .35556 Mdot
.50957 .67333 Mdot
.69424 .40854 Mdot
.50792 .69902 Mdot
.25476 .3717 Mdot
.4503 .57738 Mdot
.3047 .53394 Mdot
.34639 .55776 Mdot
.57367 .46489 Mdot
.64264 .39863 Mdot
.37277 .54884 Mdot
.32195 .54413 Mdot
.68419 .41436 Mdot
.40731 .34298 Mdot
.54988 .72766 Mdot
.50677 .32343 Mdot
.11484 .46786 Mdot
.35949 .53628 Mdot
.39663 .56301 Mdot
.66846 .39771 Mdot
.35666 .78186 Mdot
.55483 .69816 Mdot
.55216 .64585 Mdot
.50747 .35193 Mdot
.61075 .5038 Mdot
.44346 .55709 Mdot
.37849 .52873 Mdot
.49289 .32339 Mdot
.66188 .61099 Mdot
.47996 .84465 Mdot
.37438 .56237 Mdot
.67224 .42078 Mdot
.67631 .34702 Mdot
.64709 .39465 Mdot
.38131 .6027 Mdot
.39912 .57904 Mdot
.35949 .53143 Mdot
.38423 .59719 Mdot
.69392 .42639 Mdot
.38336 .52516 Mdot
.42008 .48897 Mdot
.54824 .68278 Mdot
.42179 .52393 Mdot
.29716 .32371 Mdot
.37796 .56321 Mdot
.37365 .34215 Mdot
.68228 .55343 Mdot
.35889 .56938 Mdot
.42067 .52219 Mdot
.32791 .29884 Mdot
.39082 .54621 Mdot
.64869 .43334 Mdot
.5501 .66008 Mdot
.66469 .43017 Mdot
.66493 .43891 Mdot
.55426 .33189 Mdot
.40505 .35429 Mdot
.35841 .51293 Mdot
.37019 .34915 Mdot
.41793 .61349 Mdot
.34415 .58163 Mdot
.57338 .49114 Mdot
.61807 .54473 Mdot
.38477 .37478 Mdot
.38589 .5286 Mdot
.50552 .34667 Mdot
.54384 .35711 Mdot
.39445 .40976 Mdot
.43185 .60765 Mdot
.6871 .3921 Mdot
.69006 .41765 Mdot
.35895 .40365 Mdot
.41941 .43563 Mdot
.37046 .33449 Mdot
.54816 .53541 Mdot
.34251 .56817 Mdot
.36346 .56802 Mdot
.36917 .60876 Mdot
.50193 .30529 Mdot
.65959 .60697 Mdot
.50053 .36454 Mdot
.68702 .62661 Mdot
.66802 .38451 Mdot
.36406 .58766 Mdot
.74077 .32749 Mdot
.54019 .69568 Mdot
.5485 .66045 Mdot
.63146 .4211 Mdot
.47502 .33854 Mdot
.42865 .60803 Mdot
.26238 .26506 Mdot
.59953 .68428 Mdot
.35934 .3238 Mdot
.37385 .5354 Mdot
.50216 .33613 Mdot
.52962 .67945 Mdot
.40167 .3621 Mdot
.35724 .58283 Mdot
.4746 .3578 Mdot
.37983 .55411 Mdot
.3948 .75602 Mdot
.55691 .68471 Mdot
.60803 .5857 Mdot
.6044 .69285 Mdot
.67517 .44323 Mdot
.67871 .42927 Mdot
.39444 .58266 Mdot
.18653 .34728 Mdot
.57786 .72143 Mdot
.6809 .44519 Mdot
.38448 .36526 Mdot
.65714 .61107 Mdot
.39325 .36426 Mdot
.53572 .35593 Mdot
.38124 .32325 Mdot
.55637 .34641 Mdot
.39943 .39156 Mdot
.54612 .7157 Mdot
.40242 .33176 Mdot
.36217 .78929 Mdot
.33147 .5344 Mdot
.40738 .32441 Mdot
.31978 .55793 Mdot
.44061 .48281 Mdot
.49256 .32758 Mdot
.36675 .33432 Mdot
.42906 .57653 Mdot
.77591 .39447 Mdot
.6728 .43608 Mdot
.68691 .39084 Mdot
.34781 .52008 Mdot
.49633 .36961 Mdot
.59743 .64772 Mdot
.5451 .43315 Mdot
.65174 .60813 Mdot
.37856 .52925 Mdot
.35098 .57876 Mdot
.52348 .6851 Mdot
.58495 .65099 Mdot
.39663 .58312 Mdot
.30611 .67556 Mdot
.39915 .53262 Mdot
.67043 .40591 Mdot
.53145 .67714 Mdot
.55068 .65773 Mdot
.47907 .32238 Mdot
.53179 .68966 Mdot
.30346 .55742 Mdot
.68484 .45779 Mdot
.33019 .58361 Mdot
.66143 .42579 Mdot
.41342 .4075 Mdot
.4977 .35593 Mdot
.8178 .46313 Mdot
.52856 .6818 Mdot
.3925 .51657 Mdot
.56746 .70555 Mdot
.39426 .34854 Mdot
.53797 .66927 Mdot
.57291 .71374 Mdot
.37032 .58677 Mdot
.41062 .58905 Mdot
.66513 .61057 Mdot
.59288 .518 Mdot
.56102 .68085 Mdot
.3989 .52464 Mdot
.34578 .52582 Mdot
.41269 .59351 Mdot
.55916 .46216 Mdot
.53357 .64336 Mdot
.26607 .6376 Mdot
.6793 .26687 Mdot
.56771 .6791 Mdot
.85038 .50842 Mdot
.66555 .62443 Mdot
.68907 .60114 Mdot
.67831 .44939 Mdot
.37341 .5675 Mdot
.53127 .34413 Mdot
.40689 .51337 Mdot
.43625 .60642 Mdot
.35639 .56768 Mdot
.40086 .31864 Mdot
.42973 .51239 Mdot
.67647 .62026 Mdot
.52029 .34324 Mdot
.40388 .52897 Mdot
.38161 .57703 Mdot
.69419 .60636 Mdot
.6004 .70141 Mdot
.52774 .66286 Mdot
.68593 .57706 Mdot
.40483 .34559 Mdot
.66839 .39316 Mdot
.41489 .51578 Mdot
.50682 .349 Mdot
.52589 .34018 Mdot
.59077 .67919 Mdot
.50617 .32036 Mdot
.65833 .39213 Mdot
.39694 .53838 Mdot
.67855 .44244 Mdot
.40115 .3193 Mdot
.55964 .64947 Mdot
.42209 .51867 Mdot
.42593 .57151 Mdot
.56867 .68693 Mdot
.40894 .57309 Mdot
.39539 .3109 Mdot
.51097 .30772 Mdot
.53617 .68002 Mdot
.65285 .41825 Mdot
.48283 .31843 Mdot
.41915 .55927 Mdot
.79296 .32039 Mdot
.40335 .55814 Mdot
.36909 .52883 Mdot
.75697 .67324 Mdot
.32758 .54947 Mdot
.51643 .37063 Mdot
.56523 .70701 Mdot
.39034 .60318 Mdot
.31338 .30811 Mdot
.4747 .28264 Mdot
.46475 .34732 Mdot
.37291 .53399 Mdot
.83736 .51266 Mdot
.39629 .51688 Mdot
.81216 .50448 Mdot
.57388 .49268 Mdot
.55902 .18321 Mdot
.31056 .52547 Mdot
.67774 .44633 Mdot
.66312 .60917 Mdot
.52357 .37302 Mdot
.44104 .79461 Mdot
.40651 .56625 Mdot
.53301 .78125 Mdot
.41228 .51317 Mdot
.6723 .41155 Mdot
.46543 .61407 Mdot
.5127 .31884 Mdot
.27517 .70868 Mdot
.4377 .53908 Mdot
.52793 .6516 Mdot
.5586 .37019 Mdot
.65738 .61668 Mdot
.42868 .57931 Mdot
.38035 .35474 Mdot
.49604 .28506 Mdot
.30915 .5449 Mdot
.65903 .42546 Mdot
.36424 .56333 Mdot
.4314 .6235 Mdot
.15235 .42217 Mdot
.54489 .68246 Mdot
.67865 .43785 Mdot
.50186 .5645 Mdot
.39276 .59282 Mdot
.52798 .66104 Mdot
.55211 .66176 Mdot
.385 .35954 Mdot
.64191 .5248 Mdot
.44775 .28997 Mdot
.73307 .28995 Mdot
.50663 .77289 Mdot
.49376 .30616 Mdot
.62806 .74368 Mdot
.42454 .53516 Mdot
.25225 .53601 Mdot
.65887 .43697 Mdot
.39578 .55945 Mdot
.48415 .74251 Mdot
.54175 .67644 Mdot
.37592 .55444 Mdot
.38853 .31468 Mdot
.70074 .64047 Mdot
.27823 .59265 Mdot
.81195 .37388 Mdot
.52719 .38152 Mdot
.34441 .60359 Mdot
.31929 .52687 Mdot
.6545 .6048 Mdot
.37799 .60159 Mdot
.52578 .37094 Mdot
.66564 .28997 Mdot
.36878 .31924 Mdot
.53726 .69234 Mdot
.66157 .62355 Mdot
.40369 .5095 Mdot
.33229 .55053 Mdot
.35701 .3299 Mdot
.43701 .56431 Mdot
.31241 .72982 Mdot
.6976 .6001 Mdot
.50563 .31077 Mdot
.5432 .64242 Mdot
.34592 .55966 Mdot
.65942 .6095 Mdot
.37429 .58817 Mdot
.44682 .48099 Mdot
.36805 .53716 Mdot
.70982 .71946 Mdot
.57344 .67994 Mdot
.655 .42646 Mdot
.42324 .50573 Mdot
.38432 .56341 Mdot
.487 .23433 Mdot
.43894 .60441 Mdot
.36619 .57704 Mdot
.59065 .66065 Mdot
.54897 .70213 Mdot
.58796 .67439 Mdot
.49733 .31338 Mdot
.5906 .53796 Mdot
.6662 .41256 Mdot
.39155 .61298 Mdot
.6905 .3986 Mdot
.36757 .47525 Mdot
.35894 .33905 Mdot
.81582 .43291 Mdot
.40467 .54588 Mdot
.58093 .66075 Mdot
.62633 .7675 Mdot
.54473 .63492 Mdot
.61897 .42165 Mdot
.65442 .43256 Mdot
.55421 .67792 Mdot
.38752 .54138 Mdot
.58134 .53455 Mdot
.78739 .33013 Mdot
.64809 .4112 Mdot
.34975 .59862 Mdot
.53452 .3816 Mdot
.55666 .36322 Mdot
.84528 .56715 Mdot
.66027 .44058 Mdot
.66541 .67477 Mdot
.40026 .52102 Mdot
.53992 .69735 Mdot
.68001 .3974 Mdot
.64668 .4334 Mdot
.49669 .32097 Mdot
.41881 .57751 Mdot
.3826 .56104 Mdot
.68586 .61829 Mdot
.69125 .40469 Mdot
.45792 .53117 Mdot
.41298 .58085 Mdot
.77729 .63454 Mdot
.50803 .64881 Mdot
.159 .58904 Mdot
.45654 .59929 Mdot
.48943 .74121 Mdot
.46473 .43292 Mdot
.54016 .68895 Mdot
.44123 .55336 Mdot
.39749 .61314 Mdot
.48829 .30976 Mdot
.39944 .54386 Mdot
.48326 .34696 Mdot
.66841 .44315 Mdot
.82285 .43576 Mdot
.69721 .35839 Mdot
.69828 .45274 Mdot
.40215 .56367 Mdot
.27978 .58214 Mdot
.39956 .33872 Mdot
.65044 .38433 Mdot
.57925 .69456 Mdot
.34283 .5587 Mdot
.48272 .30826 Mdot
.50394 .31354 Mdot
.54887 .6674 Mdot
.67314 .69385 Mdot
.81373 .47875 Mdot
.37998 .59693 Mdot
.54056 .35457 Mdot
.72834 .37264 Mdot
.33439 .6717 Mdot
.66237 .44969 Mdot
.37144 .31686 Mdot
.5097 .36771 Mdot
.62761 .4164 Mdot
.42924 .47113 Mdot
.55758 .67078 Mdot
.522 .67766 Mdot
.52991 .24038 Mdot
.52683 .33192 Mdot
.39573 .33022 Mdot
.44906 .43935 Mdot
.45797 .44815 Mdot
.39153 .31318 Mdot
.49407 .36212 Mdot
.54256 .6952 Mdot
.58495 .6786 Mdot
.55219 .65965 Mdot
.29281 .71757 Mdot
.59058 .69492 Mdot
.20061 .58637 Mdot
.35033 .58273 Mdot
.32722 .70077 Mdot
.38569 .51971 Mdot
.69707 .41463 Mdot
.55891 .68507 Mdot
.5739 .50483 Mdot
.34451 .53791 Mdot
.80192 .35983 Mdot
.373 .5412 Mdot
.59225 .38537 Mdot
.37394 .56927 Mdot
.34451 .74871 Mdot
.51246 .66841 Mdot
.38727 .52723 Mdot
.68417 .45402 Mdot
.37589 .33556 Mdot
.59064 .71578 Mdot
.36454 .57362 Mdot
.72594 .65936 Mdot
.3216 .55311 Mdot
.82508 .5324 Mdot
.42839 .21676 Mdot
.37136 .3038 Mdot
.32089 .57617 Mdot
.559 .33461 Mdot
.48966 .61083 Mdot
.33458 .71506 Mdot
.64828 .41182 Mdot
.28048 .6284 Mdot
.49328 .31982 Mdot
.47018 .59701 Mdot
.45244 .55054 Mdot
.36446 .32483 Mdot
.56636 .72559 Mdot
.6727 .40598 Mdot
.40809 .56447 Mdot
.44029 .56208 Mdot
.63589 .21743 Mdot
.33267 .72031 Mdot
.44939 .52053 Mdot
.35927 .35225 Mdot
.28084 .64239 Mdot
.35753 .56404 Mdot
.46479 .34649 Mdot
.57096 .7076 Mdot
.30977 .58565 Mdot
.26215 .6384 Mdot
.4 .52742 Mdot
.55123 .67535 Mdot
.52846 .68292 Mdot
.66129 .76791 Mdot
.35998 .33843 Mdot
.36777 .53769 Mdot
.50804 .22866 Mdot
.42443 .52169 Mdot
.66819 .40954 Mdot
.37776 .6033 Mdot
.4947 .34019 Mdot
.61039 .55016 Mdot
.49467 .31419 Mdot
.42115 .58839 Mdot
.57233 .66154 Mdot
.67292 .40204 Mdot
.56881 .2352 Mdot
.5845 .42587 Mdot
.1997 .58129 Mdot
.49049 .28643 Mdot
.3715 .34519 Mdot
.40237 .35959 Mdot
.65853 .46542 Mdot
.37963 .53548 Mdot
.56664 .44701 Mdot
.37189 .61621 Mdot
.37141 .57262 Mdot
.35608 .54511 Mdot
.71157 .38848 Mdot
.65362 .43076 Mdot
.5148 .32953 Mdot
.39793 .58264 Mdot
.39793 .52412 Mdot
.5672 .67491 Mdot
.37239 .32958 Mdot
.51624 .30984 Mdot
.40309 .34578 Mdot
.51482 .34323 Mdot
.83109 .60021 Mdot
.37372 .60463 Mdot
.37671 .3368 Mdot
.6466 .39367 Mdot
.58537 .66367 Mdot
.69185 .60646 Mdot
.53512 .35546 Mdot
.51614 .3203 Mdot
.38326 .52439 Mdot
.54368 .64916 Mdot
.53326 .65529 Mdot
.37096 .34727 Mdot
.68968 .41144 Mdot
.42505 .59354 Mdot
.41085 .58644 Mdot
.53363 .20176 Mdot
.49054 .31052 Mdot
.29185 .66588 Mdot
.67396 .74164 Mdot
.38062 .53423 Mdot
.53106 .65543 Mdot
.38871 .57226 Mdot
.72662 .3381 Mdot
.58718 .66063 Mdot
.3477 .52769 Mdot
.3703 .4447 Mdot
.50548 .30551 Mdot
.65118 .79086 Mdot
.38557 .50264 Mdot
.60576 .39551 Mdot
.43072 .55237 Mdot
.69061 .79597 Mdot
.60527 .76831 Mdot
.41153 .51199 Mdot
.38193 .59591 Mdot
.7268 .27111 Mdot
.40349 .51908 Mdot
.67786 .62141 Mdot
.45317 .59709 Mdot
.52726 .66115 Mdot
.49231 .43298 Mdot
.58729 .48779 Mdot
.36619 .35299 Mdot
.50681 .3523 Mdot
.24247 .4419 Mdot
.40136 .35426 Mdot
.56234 .69495 Mdot
.33603 .54831 Mdot
.52195 .72828 Mdot
.54635 .31182 Mdot
.44174 .58347 Mdot
.6696 .40987 Mdot
.58869 .48965 Mdot
.49979 .36242 Mdot
.65148 .42032 Mdot
.37945 .51449 Mdot
.3231 .24919 Mdot
.59935 .43965 Mdot
.69528 .75854 Mdot
.66942 .39608 Mdot
.66641 .43454 Mdot
.58764 .55262 Mdot
.36659 .35329 Mdot
.60906 .20821 Mdot
.32198 .6308 Mdot
.64574 .40902 Mdot
.30881 .4125 Mdot
.4687 .33522 Mdot
.63357 .53103 Mdot
.5132 .65951 Mdot
.37778 .60579 Mdot
.38634 .54606 Mdot
.6867 .41235 Mdot
.58983 .75259 Mdot
.48119 .50335 Mdot
.64778 .41976 Mdot
.33222 .51371 Mdot
.63967 .53278 Mdot
.66757 .60615 Mdot
.67561 .62429 Mdot
.37699 .36339 Mdot
.39696 .27329 Mdot
.57799 .67349 Mdot
.37321 .30918 Mdot
.63113 .60734 Mdot
.36521 .5431 Mdot
.69185 .40485 Mdot
.6936 .61414 Mdot
.65708 .41466 Mdot
.3844 .34117 Mdot
.35871 .32885 Mdot
.54756 .68276 Mdot
.55646 .69914 Mdot
.37094 .65808 Mdot
.33192 .38964 Mdot
.41263 .51989 Mdot
.53643 .75694 Mdot
.58893 .66585 Mdot
.40657 .79965 Mdot
.36726 .34853 Mdot
.37348 .32282 Mdot
.37955 .71482 Mdot
.42187 .56527 Mdot
.66507 .35355 Mdot
.36007 .56989 Mdot
.27521 .4451 Mdot
.3871 .50761 Mdot
.49904 .32098 Mdot
.43325 .53434 Mdot
.71983 .54615 Mdot
.40953 .53599 Mdot
.3525 .55606 Mdot
.5289 .3552 Mdot
.42984 .50859 Mdot
.49235 .33645 Mdot
.40422 .59529 Mdot
.38488 .29705 Mdot
.50715 .34915 Mdot
.32127 .31082 Mdot
.51244 .41348 Mdot
.66422 .61613 Mdot
.38692 .36413 Mdot
.37953 .35322 Mdot
.29301 .31955 Mdot
.57207 .69969 Mdot
.42639 .4654 Mdot
.37866 .53731 Mdot
.48279 .3598 Mdot
.67273 .39038 Mdot
.39865 .52709 Mdot
.32924 .60001 Mdot
.38128 .50302 Mdot
.54859 .67957 Mdot
.49272 .36231 Mdot
.38227 .33397 Mdot
.5471 .35278 Mdot
.36694 .29197 Mdot
.54882 .36428 Mdot
.36479 .62923 Mdot
.46362 .58712 Mdot
.40271 .48072 Mdot
.51261 .75535 Mdot
.25186 .68709 Mdot
.55498 .6677 Mdot
.67695 .61105 Mdot
.35907 .34252 Mdot
.49541 .48679 Mdot
.57911 .66147 Mdot
.52199 .32295 Mdot
.37992 .55394 Mdot
.33905 .50663 Mdot
.29994 .6118 Mdot
.50187 .664 Mdot
.32289 .35742 Mdot
.51697 .36039 Mdot
.68007 .60355 Mdot
.60349 .5374 Mdot
.55614 .61639 Mdot
.5687 .50235 Mdot
.38624 .56836 Mdot
.37545 .35308 Mdot
.52969 .67957 Mdot
.62101 .23212 Mdot
.68668 .41999 Mdot
.59063 .5208 Mdot
.40198 .56079 Mdot
.64334 .71394 Mdot
.57185 .66144 Mdot
.3762 .318 Mdot
.68632 .41224 Mdot
.36245 .34384 Mdot
.65639 .62254 Mdot
.6842 .56541 Mdot
.43373 .57055 Mdot
.36571 .57771 Mdot
.66961 .38522 Mdot
.57785 .67121 Mdot
.52909 .29572 Mdot
.65352 .23307 Mdot
.54148 .35119 Mdot
.57978 .45412 Mdot
.53099 .67935 Mdot
.63039 .70918 Mdot
.54752 .33276 Mdot
.63859 .39742 Mdot
.56756 .45321 Mdot
.63233 .4207 Mdot
.35474 .5582 Mdot
.55042 .65256 Mdot
.65992 .44074 Mdot
.55219 .22631 Mdot
.81739 .59645 Mdot
.53328 .7191 Mdot
.4032 .58383 Mdot
.81711 .43093 Mdot
.75774 .61954 Mdot
.58396 .74185 Mdot
.69492 .41835 Mdot
.39424 .57829 Mdot
.37626 .59591 Mdot
.43684 .53718 Mdot
.67846 .4345 Mdot
.59293 .40897 Mdot
.51935 .31802 Mdot
.37052 .5497 Mdot
.38888 .3525 Mdot
.49617 .33433 Mdot
.56146 .34286 Mdot
.526 .37268 Mdot
.58788 .66042 Mdot
.34134 .57114 Mdot
.60318 .60265 Mdot
.72432 .75822 Mdot
.65875 .43135 Mdot
.66444 .61639 Mdot
.3595 .53393 Mdot
.18872 .52169 Mdot
.58736 .6717 Mdot
.54164 .34793 Mdot
.39574 .56159 Mdot
.44899 .22093 Mdot
.69979 .59441 Mdot
.52118 .35267 Mdot
.57893 .69393 Mdot
.58251 .74118 Mdot
.39953 .54266 Mdot
.42933 .55217 Mdot
.5778 .68484 Mdot
.72907 .63322 Mdot
.61548 .54052 Mdot
.38664 .57311 Mdot
.65301 .42505 Mdot
.144 .41727 Mdot
.3344 .53783 Mdot
.49834 .65151 Mdot
.65717 .60836 Mdot
.70928 .71096 Mdot
.29567 .66334 Mdot
.36232 .62216 Mdot
.78993 .3862 Mdot
.22683 .44478 Mdot
.83088 .45254 Mdot
.24369 .4802 Mdot
.7457 .39053 Mdot
.79219 .66973 Mdot
.67863 .45491 Mdot
.35532 .75352 Mdot
.63363 .19559 Mdot
.68157 .66765 Mdot
.38303 .241 Mdot
.59583 .26459 Mdot
.45487 .2127 Mdot
.38118 .81623 Mdot
.55301 .3605 Mdot
.26553 .47683 Mdot
.43545 .57909 Mdot
.7499 .61287 Mdot
.29832 .69599 Mdot
.23161 .66726 Mdot
.81391 .43751 Mdot
.49157 .22559 Mdot
.76805 .28991 Mdot
.81098 .45747 Mdot
.43376 .65127 Mdot
.28071 .51835 Mdot
.4104 .28438 Mdot
.45087 .44272 Mdot
.23634 .4525 Mdot
.30216 .52422 Mdot
.71777 .53218 Mdot
.70422 .44011 Mdot
.44706 .67 Mdot
.144 .45471 Mdot
.52295 .36787 Mdot
.57234 .70767 Mdot
.59761 .20155 Mdot
.49365 .63568 Mdot
.62604 .44881 Mdot
.79008 .38585 Mdot
.77823 .6396 Mdot
.34081 .74494 Mdot
.61875 .59401 Mdot
.40435 .75046 Mdot
.24337 .35906 Mdot
.27237 .52002 Mdot
.55867 .63024 Mdot
.61065 .31747 Mdot
.4562 .44778 Mdot
.40867 .29417 Mdot
.36117 .76811 Mdot
.40476 .3602 Mdot
.31948 .3106 Mdot
.5824 .68775 Mdot
.34364 .66976 Mdot
.68669 .59837 Mdot
.62913 .61799 Mdot
.47487 .31191 Mdot
.71674 .32785 Mdot
.71816 .62965 Mdot
.71777 .65358 Mdot
.57804 .80892 Mdot
.81733 .35908 Mdot
.27279 .38449 Mdot
.65347 .27208 Mdot
.6088 .41601 Mdot
.23542 .42507 Mdot
.58598 .58156 Mdot
.30647 .3804 Mdot
.4103 .45037 Mdot
.69039 .20064 Mdot
.74287 .65217 Mdot
.75066 .26039 Mdot
.59912 .64333 Mdot
.35136 .51104 Mdot
.67928 .28764 Mdot
.49814 .78158 Mdot
.40937 .30733 Mdot
.81733 .36757 Mdot
.36627 .31271 Mdot
.51403 .68273 Mdot
.67776 .67091 Mdot
.30526 .71878 Mdot
.54005 .29806 Mdot
.41511 .36157 Mdot
.30932 .57806 Mdot
.66089 .16615 Mdot
.7867 .3725 Mdot
.67535 .75344 Mdot
.77239 .63929 Mdot
.47998 .36933 Mdot
.55924 .32853 Mdot
.66313 .44384 Mdot
.80146 .63312 Mdot
.56276 .65559 Mdot
.72826 .75831 Mdot
.79727 .62927 Mdot
.50402 .59996 Mdot
.64533 .15525 Mdot
.47336 .83969 Mdot
.32129 .6944 Mdot
.2334 .57402 Mdot
.38892 .21064 Mdot
.57701 .56656 Mdot
.6328 .69786 Mdot
.52146 .38631 Mdot
.73774 .69251 Mdot
.83345 .58045 Mdot
.31466 .41807 Mdot
.73791 .42762 Mdot
.6255 .62736 Mdot
.40605 .40816 Mdot
.53278 .71194 Mdot
.35664 .2524 Mdot
.3819 .41999 Mdot
.76232 .27645 Mdot
.2778 .63308 Mdot
.21378 .321 Mdot
.24982 .46501 Mdot
.34975 .77668 Mdot
.77551 .41152 Mdot
.44035 .36127 Mdot
.45803 .48478 Mdot
.70369 .67996 Mdot
.3372 .58637 Mdot
.55198 .54222 Mdot
.47534 .55351 Mdot
.35009 .31619 Mdot
.59051 .54467 Mdot
.7939 .54805 Mdot
.25913 .4439 Mdot
.71803 .28705 Mdot
.28727 .51281 Mdot
.55359 .64016 Mdot
.29633 .36949 Mdot
.28372 .40869 Mdot
.78522 .61569 Mdot
.50292 .56643 Mdot
.70943 .73683 Mdot
.49814 .55091 Mdot
.35962 .61458 Mdot
.36512 .75866 Mdot
.31464 .50871 Mdot
.30354 .40164 Mdot
.39101 .50342 Mdot
.59228 .80196 Mdot
.75821 .66479 Mdot
.48181 .71425 Mdot
.25431 .42416 Mdot
.50643 .74543 Mdot
.74135 .69232 Mdot
.68498 .28786 Mdot
.63878 .68922 Mdot
.60907 .74865 Mdot
.67041 .17574 Mdot
.50325 .32759 Mdot
.31922 .40681 Mdot
.69205 .38059 Mdot
.5594 .23328 Mdot
.61026 .18696 Mdot
.48967 .52639 Mdot
.75871 .68271 Mdot
.69957 .66377 Mdot
.55771 .31741 Mdot
.69514 .50919 Mdot
.72066 .38711 Mdot
.50532 .72817 Mdot
.35951 .51114 Mdot
.47743 .54152 Mdot
.39294 .30901 Mdot
.46572 .78499 Mdot
.66935 .26479 Mdot
.55569 .28015 Mdot
.34825 .62065 Mdot
.57966 .29861 Mdot
.6861 .60704 Mdot
.60421 .51287 Mdot
.8435 .58277 Mdot
.43397 .61633 Mdot
.44602 .83409 Mdot
.73554 .63723 Mdot
.57564 .46518 Mdot
.36478 .2839 Mdot
.65352 .74376 Mdot
.72939 .23272 Mdot
.77684 .67141 Mdot
.77055 .58617 Mdot
.81347 .42366 Mdot
.53251 .86375 Mdot
.56424 .1713 Mdot
.50153 .80525 Mdot
.69463 .38235 Mdot
.39184 .88787 Mdot
.55001 .34243 Mdot
.24068 .59512 Mdot
.49543 .77996 Mdot
.44774 .22768 Mdot
.49253 .63946 Mdot
.28661 .54097 Mdot
.44964 .31013 Mdot
.58991 .7089 Mdot
.31654 .5906 Mdot
.84185 .41472 Mdot
.69653 .20226 Mdot
.83614 .39904 Mdot
.68941 .56596 Mdot
.83764 .45208 Mdot
.70154 .23111 Mdot
.20191 .59232 Mdot
.6253 .20903 Mdot
.37895 .60315 Mdot
.34708 .41351 Mdot
.49057 .83466 Mdot
.49579 .29352 Mdot
.61569 .60962 Mdot
.52671 .6312 Mdot
.67812 .2001 Mdot
.84724 .57775 Mdot
.40423 .71735 Mdot
.38476 .6668 Mdot
.48181 .41328 Mdot
.31873 .3905 Mdot
.49008 .67109 Mdot
.72516 .52079 Mdot
.81074 .57902 Mdot
.69003 .22206 Mdot
.27805 .42004 Mdot
.59863 .27515 Mdot
.77002 .57001 Mdot
.49731 .82324 Mdot
.77909 .4029 Mdot
.59086 .19785 Mdot
.49625 .58697 Mdot
.61836 .65331 Mdot
.4826 .50761 Mdot
.71052 .52319 Mdot
.68357 .32433 Mdot
.25793 .39269 Mdot
.48749 .34132 Mdot
.3241 .41453 Mdot
.53372 .47641 Mdot
.62257 .20605 Mdot
.24623 .39464 Mdot
.30958 .42496 Mdot
.78504 .57128 Mdot
.83998 .42455 Mdot
.72922 .64138 Mdot
.35338 .2245 Mdot
.77218 .44818 Mdot
.47803 .58259 Mdot
.40471 .49419 Mdot
.75207 .6855 Mdot
.86143 .46728 Mdot
.76249 .68053 Mdot
.63989 .72188 Mdot
.53042 .2349 Mdot
.63095 .43448 Mdot
.23877 .39747 Mdot
.57138 .30421 Mdot
.81665 .57554 Mdot
.51573 .49861 Mdot
.62813 .43495 Mdot
.69136 .64537 Mdot
.38161 .65667 Mdot
.21249 .48199 Mdot
.42386 .67645 Mdot
.43781 .59919 Mdot
.33003 .68122 Mdot
.52949 .69546 Mdot
.63816 .71984 Mdot
.31004 .38726 Mdot
.50228 .33161 Mdot
.51229 .19103 Mdot
.49599 .67391 Mdot
.33013 .53298 Mdot
.66806 .29812 Mdot
.53628 .71495 Mdot
.50654 .75503 Mdot
.56887 .34899 Mdot
.80633 .64397 Mdot
.56055 .80657 Mdot
.49516 .69068 Mdot
.28307 .37299 Mdot
.53304 .2065 Mdot
.61783 .53088 Mdot
.69725 .38743 Mdot
.81137 .44102 Mdot
.52436 .41779 Mdot
.29319 .37593 Mdot
.32086 .67793 Mdot
.65588 .24197 Mdot
.37511 .61425 Mdot
.65138 .76357 Mdot
.20049 .56783 Mdot
.60743 .5094 Mdot
.50527 .63312 Mdot
.59713 .68752 Mdot
.29983 .76993 Mdot
.73164 .54743 Mdot
.53956 .60227 Mdot
.79308 .41529 Mdot
.6476 .44042 Mdot
.57544 .64527 Mdot
.31358 .42856 Mdot
.41314 .25747 Mdot
.31854 .65328 Mdot
.69331 .32747 Mdot
.45277 .6457 Mdot
.60204 .38328 Mdot
.80611 .4174 Mdot
.77635 .33161 Mdot
.15703 .40203 Mdot
.60506 .68376 Mdot
.62751 .24553 Mdot
.62133 .24142 Mdot
.55471 .63123 Mdot
.50049 .6594 Mdot
.27838 .58483 Mdot
.84676 .4827 Mdot
.5031 .4782 Mdot
.71529 .51119 Mdot
.56902 .45284 Mdot
.38277 .24583 Mdot
.6332 .22814 Mdot
.24278 .4225 Mdot
.76945 .38556 Mdot
.39631 .67542 Mdot
.43943 .17908 Mdot
.41616 .48298 Mdot
.24103 .6025 Mdot
.23864 .39729 Mdot
.30487 .47293 Mdot
.36924 .77265 Mdot
.80796 .5302 Mdot
.42051 .52047 Mdot
.82978 .37547 Mdot
.7817 .60873 Mdot
.54697 .54496 Mdot
.45934 .3559 Mdot
.41753 .54324 Mdot
.34319 .57476 Mdot
.59123 .7597 Mdot
.69191 .72802 Mdot
.50919 .15884 Mdot
.25898 .45935 Mdot
.47868 .59764 Mdot
.31447 .67914 Mdot
.44686 .83395 Mdot
.69187 .30297 Mdot
.82526 .50038 Mdot
.53305 .49053 Mdot
.50321 .83085 Mdot
.71594 .48267 Mdot
.6939 .52021 Mdot
.77329 .43751 Mdot
.70933 .23821 Mdot
.35602 .63278 Mdot
.69547 .70879 Mdot
.60083 .2101 Mdot
.35978 .53471 Mdot
.67311 .69456 Mdot
.78953 .42337 Mdot
.22571 .33225 Mdot
.57618 .58313 Mdot
.86358 .44883 Mdot
.4402 .48961 Mdot
.70619 .69344 Mdot
.61892 .18373 Mdot
.3115 .21612 Mdot
.70835 .53467 Mdot
.77018 .28886 Mdot
.68203 .50879 Mdot
.78797 .40637 Mdot
.67486 .44752 Mdot
.50713 .44782 Mdot
.54114 .76926 Mdot
.84754 .48917 Mdot
.44325 .26956 Mdot
.7413 .3418 Mdot
.57843 .77165 Mdot
.85081 .4698 Mdot
.40012 .45472 Mdot
.29643 .76243 Mdot
.46022 .32113 Mdot
.51709 .84192 Mdot
.52443 .80335 Mdot
.4835 .62806 Mdot
.30181 .41881 Mdot
.28439 .74134 Mdot
.22041 .63204 Mdot
.51629 .79746 Mdot
.31698 .44305 Mdot
.66217 .74304 Mdot
.27763 .36985 Mdot
.8174 .58207 Mdot
.36038 .80471 Mdot
.632 .23624 Mdot
.64997 .64396 Mdot
.70438 .58673 Mdot
.69021 .73423 Mdot
.78269 .51747 Mdot
.67446 .29449 Mdot
.6564 .54884 Mdot
.43984 .6459 Mdot
.10924 .536 Mdot
.66578 .49114 Mdot
.29014 .60187 Mdot
.72404 .23324 Mdot
.80702 .58399 Mdot
.50589 .49399 Mdot
.35191 .76438 Mdot
.2003 .50273 Mdot
.40693 .38731 Mdot
.35712 .56866 Mdot
.84906 .46389 Mdot
.4237 .36299 Mdot
.78975 .32813 Mdot
.70675 .75562 Mdot
.3578 .68239 Mdot
.40206 .63212 Mdot
.53281 .38485 Mdot
.26281 .54635 Mdot
.30539 .45465 Mdot
.73033 .24887 Mdot
.24272 .60102 Mdot
.57183 .42741 Mdot
.62403 .37025 Mdot
.70203 .35353 Mdot
.46664 .62215 Mdot
.49503 .83724 Mdot
.67842 .73242 Mdot
.24758 .44942 Mdot
.76235 .57618 Mdot
.3128 .40277 Mdot
.29578 .66548 Mdot
.246 .38367 Mdot
.52683 .54917 Mdot
.43779 .31228 Mdot
.48044 .31744 Mdot
.7192 .26979 Mdot
.80378 .46113 Mdot
.60073 .7958 Mdot
.3619 .22198 Mdot
.69953 .68398 Mdot
.27002 .48312 Mdot
.69292 .27203 Mdot
.56841 .57023 Mdot
.43995 .28116 Mdot
.21492 .49841 Mdot
.28011 .63184 Mdot
.81687 .51566 Mdot
.29617 .50583 Mdot
.83545 .58111 Mdot
.25558 .39805 Mdot
.67858 .23831 Mdot
.47846 .41654 Mdot
.47357 .76791 Mdot
.3557 .72617 Mdot
.40976 .20246 Mdot
.60424 .50571 Mdot
.66296 .16872 Mdot
.53592 .63598 Mdot
.8147 .35531 Mdot
.66571 .39395 Mdot
.16987 .40967 Mdot
.81584 .54714 Mdot
.5518 .5066 Mdot
.54788 .4521 Mdot
.65121 .76719 Mdot
.72295 .64255 Mdot
.73462 .64204 Mdot
.48534 .51753 Mdot
.52446 .37504 Mdot
.58013 .41824 Mdot
.72156 .51035 Mdot
.73474 .30039 Mdot
.40588 .59993 Mdot
.55365 .30927 Mdot
.28902 .49091 Mdot
.65222 .37286 Mdot
.75158 .67349 Mdot
.80695 .49758 Mdot
.30555 .52692 Mdot
.3191 .3878 Mdot
.69789 .22221 Mdot
.79597 .61678 Mdot
.48003 .49401 Mdot
.4711 .54083 Mdot
.60733 .43203 Mdot
.54352 .18431 Mdot
.77528 .35827 Mdot
.68535 .356 Mdot
.62747 .54139 Mdot
.2731 .38769 Mdot
.87321 .43056 Mdot
.69314 .20112 Mdot
.39671 .19457 Mdot
.56905 .4493 Mdot
.60493 .64396 Mdot
.19262 .527 Mdot
.68219 .2418 Mdot
.52903 .84146 Mdot
.77643 .59743 Mdot
.31443 .40724 Mdot
.25078 .30516 Mdot
.25295 .67575 Mdot
.56522 .41466 Mdot
.35746 .72745 Mdot
.51138 .76736 Mdot
.61971 .41187 Mdot
.40711 .39181 Mdot
.5412 .42828 Mdot
.62516 .45015 Mdot
.66524 .74143 Mdot
.71633 .64676 Mdot
.67567 .2352 Mdot
.24519 .61957 Mdot
.46993 .53658 Mdot
.73446 .31418 Mdot
.52217 .69953 Mdot
.61835 .23413 Mdot
.54299 .20509 Mdot
.55532 .42517 Mdot
.55055 .35263 Mdot
.2982 .56232 Mdot
.62076 .51319 Mdot
.68803 .50141 Mdot
.29625 .27013 Mdot
.39317 .30349 Mdot
.57685 .63161 Mdot
.26163 .69933 Mdot
.60549 .67151 Mdot
.87301 .50079 Mdot
.72766 .51968 Mdot
.32357 .68412 Mdot
.71974 .4712 Mdot
.61248 .29364 Mdot
.30546 .24406 Mdot
.42133 .65317 Mdot
.32571 .29986 Mdot
.58422 .62801 Mdot
.53209 .69662 Mdot
.7407 .45114 Mdot
.6772 .59298 Mdot
.36452 .66883 Mdot
.41238 .82681 Mdot
.53 .205 Mdot
.60324 .65916 Mdot
.58131 .39195 Mdot
.55071 .73159 Mdot
.83932 .59077 Mdot
.54447 .35844 Mdot
.67961 .18295 Mdot
.46254 .59313 Mdot
.53177 .17751 Mdot
.75369 .67938 Mdot
.60798 .55453 Mdot
.57132 .44516 Mdot
.57213 .25295 Mdot
.3553 .60969 Mdot
.4806 .5997 Mdot
.568 .69924 Mdot
.63563 .21403 Mdot
.37757 .3242 Mdot
.32084 .36491 Mdot
.70922 .40849 Mdot
.40238 .80766 Mdot
.52113 .82747 Mdot
.53464 .70042 Mdot
.51249 .40349 Mdot
.61634 .24771 Mdot
.36529 .4437 Mdot
.29431 .4836 Mdot
.72172 .2669 Mdot
.39233 .66241 Mdot
.53794 .63622 Mdot
.39311 .19821 Mdot
.38323 .41848 Mdot
.78351 .67525 Mdot
.37711 .46943 Mdot
.26923 .53003 Mdot
.30233 .48395 Mdot
.64846 .75704 Mdot
.29443 .66103 Mdot
.82675 .52951 Mdot
.29972 .37237 Mdot
.42659 .43967 Mdot
.3131 .42373 Mdot
.30173 .53201 Mdot
.67236 .36205 Mdot
.49693 .8446 Mdot
.25693 .29897 Mdot
.39862 .75526 Mdot
.59198 .59047 Mdot
.49945 .63475 Mdot
.45562 .83507 Mdot
.55898 .6284 Mdot
.34758 .30358 Mdot
.45504 .67346 Mdot
.81492 .55 Mdot
.80696 .62397 Mdot
.78459 .61598 Mdot
.26014 .55243 Mdot
.70386 .35649 Mdot
.22288 .53717 Mdot
.44686 .48935 Mdot
.55926 .50332 Mdot
.33827 .60386 Mdot
.47027 .60993 Mdot
.5106 .51251 Mdot
.62333 .77195 Mdot
.42222 .63286 Mdot
.84294 .48694 Mdot
.78229 .67285 Mdot
.83092 .4263 Mdot
.68036 .3213 Mdot
.58586 .70471 Mdot
.71832 .2225 Mdot
.25968 .65585 Mdot
.81176 .59269 Mdot
.51692 .80559 Mdot
.32261 .79143 Mdot
.6287 .18895 Mdot
.79934 .54538 Mdot
.59977 .62248 Mdot
.65647 .78957 Mdot
.74631 .65031 Mdot
.3002 .76481 Mdot
.27837 .61859 Mdot
.74971 .67942 Mdot
.65139 .16464 Mdot
.46761 .81114 Mdot
.72218 .65186 Mdot
.34814 .72457 Mdot
.28714 .62698 Mdot
.37215 .80657 Mdot
.34226 .58073 Mdot
.55837 .34702 Mdot
.41925 .22361 Mdot
.30296 .41248 Mdot
.29449 .55069 Mdot
.35348 .79499 Mdot
.30193 .45898 Mdot
.26389 .48279 Mdot
.55914 .23785 Mdot
.63312 .19415 Mdot
.30828 .66192 Mdot
.32097 .52454 Mdot
.51874 .63218 Mdot
.40188 .35686 Mdot
.23167 .48536 Mdot
.41457 .55509 Mdot
.58512 .49449 Mdot
.32843 .62687 Mdot
.8486 .42362 Mdot
.40515 .24629 Mdot
.686 .46262 Mdot
.59864 .69319 Mdot
.67984 .7398 Mdot
.71536 .31306 Mdot
.68015 .66818 Mdot
.33126 .77679 Mdot
.35016 .6574 Mdot
.80136 .40644 Mdot
.70671 .66622 Mdot
.26468 .41342 Mdot
.26598 .32595 Mdot
.69753 .42674 Mdot
.52661 .77571 Mdot
.72725 .24984 Mdot
.68279 .69566 Mdot
.51377 .68622 Mdot
.77263 .55223 Mdot
.65593 .36328 Mdot
.67607 .71313 Mdot
.73458 .63578 Mdot
.6537 .25096 Mdot
.3631 .69925 Mdot
.77377 .33377 Mdot
.54623 .37956 Mdot
.28209 .42389 Mdot
.7475 .54873 Mdot
.37266 .8089 Mdot
.36396 .44512 Mdot
.84006 .54881 Mdot
.55277 .49619 Mdot
.329 .3497 Mdot
.43167 .56675 Mdot
.2596 .63547 Mdot
.63493 .75931 Mdot
.76052 .56714 Mdot
.50955 .59066 Mdot
.54764 .71267 Mdot
.57416 .80757 Mdot
.45414 .3501 Mdot
.42358 .37001 Mdot
.23989 .57199 Mdot
.62323 .73012 Mdot
.34098 .32863 Mdot
.69828 .62723 Mdot
.46607 .57396 Mdot
.32109 .28881 Mdot
.69534 .34276 Mdot
.53678 .77854 Mdot
.49471 .80705 Mdot
.72346 .2735 Mdot
.69226 .31969 Mdot
.58639 .80902 Mdot
.54497 .78982 Mdot
.7162 .71119 Mdot
.25401 .66666 Mdot
.60532 .61806 Mdot
.36728 .50968 Mdot
.34756 .30381 Mdot
.55395 .63368 Mdot
.74029 .303 Mdot
.48172 .54802 Mdot
.32454 .33309 Mdot
.54578 .52376 Mdot
.67592 .28666 Mdot
.4556 .41435 Mdot
.75243 .66943 Mdot
.65632 .78988 Mdot
.30921 .38597 Mdot
.70251 .42773 Mdot
.69209 .50617 Mdot
.56761 .58118 Mdot
.84039 .51493 Mdot
.50302 .51878 Mdot
.5213 .72905 Mdot
.64856 .63458 Mdot
.48707 .73813 Mdot
.72878 .72431 Mdot
.33561 .38894 Mdot
.56546 .50688 Mdot
.49825 .69158 Mdot
.61954 .60858 Mdot
.6913 .6052 Mdot
.44006 .23405 Mdot
.25575 .64485 Mdot
.72582 .44581 Mdot
.5887 .43736 Mdot
.46214 .54013 Mdot
.19327 .53156 Mdot
.76615 .33243 Mdot
.49618 .4888 Mdot
.54678 .4957 Mdot
.59783 .21166 Mdot
.40355 .37834 Mdot
.12874 .44484 Mdot
.8406 .39341 Mdot
.43102 .56635 Mdot
.53551 .44532 Mdot
.32703 .37489 Mdot
.48445 .34901 Mdot
.4217 .67304 Mdot
.73162 .2826 Mdot
.64822 .43168 Mdot
.54482 .23201 Mdot
.70795 .61621 Mdot
.64333 .76956 Mdot
.44166 .18749 Mdot
.62518 .42761 Mdot
.87436 .49401 Mdot
.77242 .59972 Mdot
.6387 .74562 Mdot
.11306 .48061 Mdot
.61861 .76804 Mdot
.41638 .45632 Mdot
.54578 .2438 Mdot
.84621 .43293 Mdot
.57371 .45246 Mdot
.53259 .23972 Mdot
.47918 .80728 Mdot
.30517 .38134 Mdot
.26889 .44771 Mdot
.65398 .64682 Mdot
.59982 .78393 Mdot
.27682 .75005 Mdot
.61294 .29191 Mdot
.32675 .22831 Mdot
.36117 .67394 Mdot
.78859 .34448 Mdot
.70873 .53323 Mdot
.2436 .3164 Mdot
.80191 .63031 Mdot
.3397 .42101 Mdot
.3647 .79607 Mdot
.41165 .26916 Mdot
.30646 .31856 Mdot
.18809 .53291 Mdot
.67154 .55642 Mdot
.40498 .66068 Mdot
.59419 .28968 Mdot
.52286 .59201 Mdot
.31884 .41852 Mdot
.49496 .75579 Mdot
.56449 .50439 Mdot
.75249 .2817 Mdot
.29997 .74454 Mdot
.28413 .38043 Mdot
.58163 .2213 Mdot
.31128 .31929 Mdot
.75177 .32991 Mdot
.73201 .35404 Mdot
.3737 .43561 Mdot
.57086 .15374 Mdot
.76225 .27683 Mdot
.60817 .61838 Mdot
.34649 .57922 Mdot
.78826 .67441 Mdot
.41795 .41836 Mdot
.50096 .8034 Mdot
.73401 .60998 Mdot
.25617 .46538 Mdot
.36217 .63723 Mdot
.33954 .52806 Mdot
.22574 .55974 Mdot
.58356 .61616 Mdot
.49981 .75859 Mdot
.4827 .18754 Mdot
.28627 .37571 Mdot
.30766 .74764 Mdot
.44922 .17909 Mdot
.37164 .46978 Mdot
.52541 .66316 Mdot
.8471 .42882 Mdot
.477 .66576 Mdot
.47302 .53467 Mdot
.33662 .70204 Mdot
.4936 .51108 Mdot
.47182 .2781 Mdot
.46976 .53857 Mdot
.61674 .5289 Mdot
.29934 .4193 Mdot
.69227 .25389 Mdot
.54842 .76782 Mdot
.64969 .15445 Mdot
.75528 .68666 Mdot
.60551 .66079 Mdot
.48222 .79911 Mdot
.55043 .42194 Mdot
.82492 .41619 Mdot
.59089 .27483 Mdot
.53626 .20607 Mdot
.24688 .69577 Mdot
.29653 .33729 Mdot
.42949 .5171 Mdot
.69154 .56746 Mdot
.81934 .60606 Mdot
.25675 .71322 Mdot
.83535 .5797 Mdot
.40467 .63366 Mdot
.39003 .49406 Mdot
.26507 .24342 Mdot
.79555 .4109 Mdot
.39118 .62449 Mdot
.54172 .6062 Mdot
.51195 .60835 Mdot
.42302 .59063 Mdot
.68044 .59 Mdot
.22857 .46162 Mdot
.26963 .4547 Mdot
.84523 .48173 Mdot
.59976 .67193 Mdot
.57926 .46593 Mdot
.65465 .38067 Mdot
.56709 .46653 Mdot
.32099 .51318 Mdot
.64459 .43609 Mdot
.27187 .46158 Mdot
.44225 .42527 Mdot
.52716 .28082 Mdot
.38458 .65281 Mdot
.63622 .55326 Mdot
.4282 .64569 Mdot
.26432 .517 Mdot
.62616 .70393 Mdot
.21887 .63039 Mdot
.30113 .45876 Mdot
.35147 .43428 Mdot
.74717 .66837 Mdot
.50306 .86282 Mdot
.59303 .48599 Mdot
.61084 .72189 Mdot
.39931 .46074 Mdot
.27076 .65566 Mdot
.3487 .6997 Mdot
.49571 .28803 Mdot
.67651 .60052 Mdot
.43077 .62855 Mdot
.49625 .69204 Mdot
.63544 .43358 Mdot
.86966 .43819 Mdot
.33584 .52801 Mdot
.40528 .68704 Mdot
.83367 .53484 Mdot
.62294 .23181 Mdot
.27878 .61006 Mdot
.33389 .60078 Mdot
.44472 .45013 Mdot
.43611 .42268 Mdot
.54769 .73802 Mdot
.63262 .22394 Mdot
.79193 .37419 Mdot
.24755 .56183 Mdot
.3847 .68583 Mdot
.37409 .53894 Mdot
.36395 .30661 Mdot
.60466 .52194 Mdot
.2929 .28538 Mdot
.35942 .3764 Mdot
.79415 .61234 Mdot
.27111 .4976 Mdot
.25849 .45947 Mdot
.32631 .71619 Mdot
.80187 .34326 Mdot
.57909 .58989 Mdot
.35148 .68349 Mdot
.5293 .536 Mdot
.78514 .5231 Mdot
.31395 .4444 Mdot
.74059 .4169 Mdot
.45326 .62284 Mdot
.55981 .60983 Mdot
.86026 .52679 Mdot
.43201 .65205 Mdot
.71661 .41304 Mdot
.81817 .51526 Mdot
.26029 .66991 Mdot
.54683 .45259 Mdot
.10573 .5077 Mdot
.58534 .26536 Mdot
.87154 .48427 Mdot
.67328 .24953 Mdot
.32889 .46699 Mdot
.66088 .7408 Mdot
.32298 .60388 Mdot
.5292 .34804 Mdot
.8123 .40031 Mdot
.4927 .65568 Mdot
.6178 .62579 Mdot
.36649 .60099 Mdot
.4763 .46036 Mdot
.52628 .72473 Mdot
.74865 .3849 Mdot
.55792 .36236 Mdot
.48353 .49902 Mdot
.74601 .36474 Mdot
.43436 .42166 Mdot
.35454 .8152 Mdot
.73207 .24989 Mdot
.81339 .44513 Mdot
.69337 .34876 Mdot
.17066 .39268 Mdot
.55731 .62057 Mdot
.50189 .68229 Mdot
.68968 .44983 Mdot
.22318 .54541 Mdot
.67797 .70586 Mdot
.6807 .24448 Mdot
.70019 .73584 Mdot
.36216 .44465 Mdot
.11147 .56864 Mdot
.32687 .42453 Mdot
.47987 .47593 Mdot
.66343 .70808 Mdot
.84456 .49829 Mdot
.52222 .22141 Mdot
.6946 .75917 Mdot
.72218 .53447 Mdot
.30244 .53494 Mdot
.20703 .57629 Mdot
.40087 .19791 Mdot
.6495 .35998 Mdot
.32071 .23093 Mdot
.77791 .41687 Mdot
.23698 .45135 Mdot
.75634 .56564 Mdot
.60618 .68138 Mdot
.48867 .60125 Mdot
.7309 .51364 Mdot
.61416 .60936 Mdot
.59258 .75304 Mdot
.78837 .37922 Mdot
.22515 .39518 Mdot
.57128 .2035 Mdot
.81972 .42843 Mdot
.63634 .3768 Mdot
.50059 .62268 Mdot
.2927 .46749 Mdot
.37446 .37562 Mdot
.48208 .33362 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0Yoooool2o`000:3ooooo000Looooo`03o`00
0?oooooooooo0:Oooooo0_l0002Pooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo0_l0002gooooo`;o0000TOooool001cooooo00?o0000ooooooooool0]_ooool2
o`0001Kooooo0ol0001hooooo`007?ooool00ol0003oooooooooo`2Rooooo`;o00000oooool2o`00
01?ooooo0_l0000>ooooo`Go0000N?ooool001cooooo00?o0000ooooooooool0X_ooool2o`0000?o
oooo0_l0000Cooooo`;o00003_ooool2o`0007_ooooo000Looooo`03o`000?oooooooooo0;Gooooo
0_l0000Iooooo`;o000000?oooooo`000?l00000M?ooool001cooooo00?o0000ooooooooool0]Ooo
ool2o`0000Kooooo0_l0000Aooooo`;o000000Coooooo`000?l0003o0000Loooool001cooooo00?o
0000ooooooooool0YOooool2o`0000gooooo0_l00007ooooo`;o00001?ooool2o`0000oooooo0_l0
001cooooo`007?ooool00ol0003oooooooooo`2Uooooo`;o00001_ooool2o`0000;ooooo0_l00000
0ooooooo0000o`00000=ooooo`;o0000Q?ooool001cooooo00?o0000ooooooooool0ZOooool2o`00
00;ooooo0_l00002ooooo`;o00008oooool2o`00077ooooo000Looooo`03o`000?oooooooooo08_o
oooo0_l000000ooooooo0000o`00000Iooooo`;o00000_ooool2o`0000;ooooo0_l0000>ooooo`;o
00001?ooool2o`0000gooooo0_l0001aooooo`007?ooool00ol0003oooooooooo`2;ooooo`;o0000
00?oooooo`000?l000000_ooool2o`0001Wooooo0_l00002ooooo`?o00003?ooool3o`0000;ooooo
1?l0000@ooooo`;o0000K_ooool001cooooo00?o0000ooooooooool0S?ooool2o`0000Cooooo0_l0
0005ooooo`;o00004_ooool2o`0000?ooooo0_l0000<ooooo`Co000000?oooooo`000?l000004_oo
ool2o`0006kooooo000Looooo`03o`000?oooooooooo08cooooo0ol000000ooooooo0000o`000004
ooooo`;o000000?oooooo`000?l000009oooool2o`0000Cooooo0_l0001oooooo`0000Koooooonk^
k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0Mooo
ool2o`00013ooooo0_l00002ooooo`;o000000?oooooo`000?l000001?ooool2o`0000_ooooo0_l0
0002ooooo`;o00002?ooool2o`0001Gooooo0_l0001oooooo`0000KoooooogMgMonHV9SooooooiRH
V?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000oooooooo
ool0Moooool2o`0000Cooooo0_l0000:ooooo`;o00006?ooool2o`0000;ooooo0_l00008ooooo`;o
00003oooool6o`0000;ooooo0_l0001mooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooo
ooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0O?ooool4o`0000Cooooo
0_l0000Rooooo`;o00004_ooool2o`0000Cooooo1_l00002ooooo`;o0000OOooool00003ooooool0
003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06ooooo`?o0000O?oo
ool4o`000004ooooool0003o0000ooooo`;o00008_ooool4o`0000Cooooo0ol00004ooooo`;o0000
0oooool4o`0001Sooooo0_l00002ooooo`Co0000JOooool00003ooooool0003ooooo00;ooooo00?o
0000ooooooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo087ooooo0_l0
000;ooooo`;o00006?ooool4o`000004ooooool0003o0000ooooo`?o00000oooool3o`0000Gooooo
0ol00005ooooo`?o00003oooool2o`0000;ooooo1?l0001Yooooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0S_oo
ool2o`0001Sooooo1?l000000ooooooo0000o`000007ooooo`;o00001oooool2o`000003ooooool0
003o000000;ooooo0ol00020ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`1Uooooo`;o00005?ooool2o`0002co
oooo0_l000000ooooooo0000o`00000@ooooo`?o000000?oooooo`000?l000000oooool2o`0000;o
oooo0ol0000Eooooo`;o0000I?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnH
V9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0IOooool2o`0000kooooo0_l00004
ooooo`;o00002oooool5o`0000?ooooo0_l0000Jooooo`Co00003_ooool3o`0000Wooooo1?l00004
ooooo`;o00003oooool2o`0006Cooooo000Looooo`03o`000?oooooooooo067ooooo0_l0000Boooo
o`;o00004?ooool6o`0000?ooooo0_l0000Jooooo`Co00006_ooool3o`0000Gooooo0_l0001eoooo
o`007?ooool00ol0003oooooooooo`1Qooooo`;o00009?ooool4o`0000?ooooo0_l0000Eooooo`?o
00001_ooool6o`000003ooooool0003o000000;ooooo0_l0000@ooooo`;o00001_ooool2o`0007Co
oooo000Looooo`03o`000?oooooooooo06oooooo0_l000000ooooooo0000o`00000@ooooo`;o0000
2?ooool2o`0000Sooooo0_l0000;ooooo`?o00001_ooool6o`000003ooooool0003o000000;ooooo
0_l0000:ooooo`;o00000oooool2o`0000Oooooo0_l00007ooooo`;o000000?oooooo`000?l00000
1Oooool2o`00067ooooo000Looooo`03o`000?oooooooooo06Oooooo0_l00006ooooo`;o000000?o
ooooo`000?l000001?ooool2o`0000[ooooo0_l00008ooooo`;o000000?oooooo`000?l000001Ooo
ool2o`0000;ooooo0_l0000@ooooo`Co00004oooool2o`0000?ooooo0_l0000@ooooo`;o000000?o
ooooo`000?l000001Oooool2o`00067ooooo000Looooo`03o`000?oooooooooo06Kooooo0ol0000?
ooooo`;o00005?ooool2o`000003ooooool0003o000000Wooooo0_l00003ooooo`;o00003?ooool3
o`0001Sooooo0ol00009ooooo`;o0000LOooool001cooooo00?o0000ooooooooool0I?ooool6o`00
02gooooo0_l000000ooooooo0000o`000005ooooo`;o00002_ooool2o`0000?ooooo0_l0000Boooo
o`?o000000Coooooo`000?l0003o00000oooool2o`0000Cooooo0_l00008ooooo`;o00001Oooool4
o`0005kooooo000Looooo`03o`000?oooooooooo06Cooooo0_l00002ooooo`;o00006_ooool2o`00
00Gooooo0_l0000:ooooo`;o000000?oooooo`000?l000003Oooool2o`0000;ooooo0_l00003oooo
o`;o000000?oooooo`000?l000003_ooool4o`000004ooooool0003o0000o`0000?ooooo0_l00004
ooooo`Co00001_ooool2o`0000Gooooo1Ol0001Mooooo`007?ooool00ol0003oooooooooo`1ioooo
o`;o00002Oooool2o`0000Gooooo0_l0000=ooooo`;o00003Oooool2o`0000Oooooo0_l000000ooo
oooo0000o`000002ooooo`;o00002_ooool4o`000004ooooool0003o0000o`0000_ooooo0ol00008
ooooo`;o00001Oooool2o`0005gooooo000Looooo`03o`000?oooooooooo07Wooooo0_l0000]oooo
o`?o00001oooool2o`0000Gooooo0_l0000;ooooo`?o00002?ooool2o`0000Kooooo0ol00007oooo
o`;o0000I?ooool001cooooo00?o0000ooooooooool0D_ooool2o`0000cooooo0_l0000Gooooo`;o
0000;Oooool2o`0000Cooooo0_l0000Fooooo`Co00000_ooool2o`0000?ooooo0_l00006ooooo`?o
0000KOooool001cooooo00?o0000ooooooooool0D_ooool2o`0000cooooo0_l00003ooooo`;o0000
4_ooool2o`0000Gooooo0_l0000/ooooo`;o00001?ooool2o`0000kooooo0_l00002ooooo`;o0000
0_ooool3o`0000[ooooo0_l0000>ooooo`;o0000G_ooool001cooooo0_l0001Vooooo`;o00002Ooo
ool2o`0000kooooo0_l0000Zooooo`;o00001_ooool2o`0000kooooo0_l00002ooooo`;o00000ooo
ool2o`0000;ooooo0_l00004ooooo`;o00003oooool4o`0005gooooo000Looooo`03o`000?oooooo
oooo05cooooo0_l00003ooooo`;o00003Oooool2o`0003[ooooo0_l00008ooooo`;o000000?ooooo
o`000?l000005_ooool2o`0000Cooooo1?l00002ooooo`;o00002Oooool4o`0005gooooo000Loooo
o`03o`000?oooooooooo05cooooo0_l00003ooooo`;o00007Oooool4o`0003;ooooo0_l000001?oo
oooo0000o`000?l00008ooooo`;o00004oooool2o`0000;ooooo0_l0001Zooooo`007?ooool00ol0
003oooooooooo`1Rooooo`;o00007?ooool4o`0003Kooooo0_l00008ooooo`?o00002?ooool2o`00
00Gooooo0_l0000Hooooo`;o0000Eoooool001cooooo00?o0000ooooooooool0H_ooool2o`00013o
oooo0_l00014ooooo`;o00000_ooool2o`0000Gooooo0_l00005ooooo`;o000000?oooooo`000?l0
00001Oooool2o`0001Sooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`1Booooo`;o0000
8?ooool2o`0000gooooo0_l0000[ooooo`;o00002?ooool2o`0000;ooooo0_l0000<ooooo`;o0000
2?ooool2o`000003ooooool0003o000000cooooo0_l0001Pooooo`007?ooool00ol0003ooooooooo
o`1Booooo`;o00002Oooool2o`0002?ooooo1?l00006ooooo`;o00008_ooool2o`0000Sooooo0_l0
000Jooooo`;o000000?oooooo`000?l000002oooool3o`00063ooooo000Looooo`03o`000?oooooo
oooo05gooooo0_l0000Nooooo`;o00000oooool4o`0000Kooooo0_l00012ooooo`;o00002oooool2
o`0000Oooooo1?l0001Oooooo`007?ooool00ol0003oooooooooo`1mooooo`;o00008_ooool2o`00
01Wooooo0_l000000ooooooo0000o`00000?ooooo`;o00002oooool2o`0000Sooooo0ol0000:oooo
o`;o0000Doooool001cooooo00?o0000ooooooooool0M?ooool2o`0000cooooo0_l0000Booooo`;o
00002Oooool2o`0000?ooooo0_l0000Dooooo`;o000000?oooooo`000?l000009oooool2o`0000[o
oooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`1Fooooo`;o000000?oooooo`000?l00000
6Oooool2o`0000cooooo0_l00007ooooo`;o00002Oooool2o`0000_ooooo0_l000001?oooooo0000
o`000?l00008ooooo`;o00007_ooool2o`0000oooooo0_l00004ooooo`Co00001Oooool2o`0005Ko
oooo000Looooo`03o`000?oooooooooo05Kooooo0_l000000ooooooo0000o`000002o`0001Kooooo
1?l0000;ooooo`;o00001oooool2o`0000Wooooo0_l00005ooooo`;o00000_ooool4o`0000;ooooo
1?l00006ooooo`;o00007_ooool2o`0000oooooo0_l00006ooooo`;o00001Oooool2o`0005Kooooo
000Looooo`03o`000?oooooooooo05Cooooo0_l00005ooooo`;o00002?ooool2o`0000Sooooo0ol0
00000ooooooo0000o`000002o`0000_ooooo0_l0000Hooooo`?o00000_ooool3o`0000Gooooo0_l0
000]ooooo`Go00002?ooool2o`0000oooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`1D
ooooo`;o00003oooool2o`0000Sooooo0ol000000ooooooo0000o`000002ooooo`;o00005Oooool2
o`0000cooooo0ol0000Nooooo`;o00001?ooool2o`0000oooooo0_l00002ooooo`Go00002?ooool2
o`0000?ooooo0_l0000:ooooo`;o0000DOooool001cooooo00?o0000ooooooooool0Loooool2o`00
00;ooooo0_l00008ooooo`;o00002oooool2o`0000gooooo2?l00005ooooo`;o00004Oooool2o`00
00Cooooo0_l0000?ooooo`;o000000?oooooo`000?l000001Oooool2o`0000[ooooo0_l0000:oooo
o`;o0000DOooool001cooooo00?o0000ooooooooool0J?ooool2o`0000Oooooo2_l00006ooooo`;o
00000_ooool2o`0000Gooooo0_l0000:ooooo`Co000000?oooooo`000?l000001_l00003ooooo`Ko
00002oooool2o`0000Sooooo0_l000000ooooooo0000o`00000=ooooo`Co00001?ooool3o`0006Wo
oooo000Looooo`;o0000DOooool2o`0001Cooooo1?l00004ooooo`oo000000?oooooo`000?l00000
1Oooool2o`0000Gooooo0_l0000:ooooo`Co00001oooool2o`0000?ooooo1_l0000;ooooo`;o0000
2oooool2o`0000gooooo0ol00005ooooo`;o00003?ooool2o`0005cooooo000Looooo`03o`000?oo
oooooooo04oooooo0ol0000@ooooo`?o000000Coooooo`000?l0003o00000oooool8o`000003oooo
ool0003o000000Wo00007?ooool6o`000003ooooool0003o000000;o00000oooool3o`0000Wooooo
0_l0000Nooooo`;o00001Oooool2o`0000Sooooo0ol000000ooooooo0000o`000002o`0000Gooooo
0_l0001Cooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o00000_ooool3o`0000gooooo0_l0
0002ooooo`Oo00000oooool3o`0000?ooooo0_l000000ooooooo0000o`00000<o`0001Sooooo3_l0
0009ooooo`;o00000_ooool2o`0002Gooooo0_l00008ooooo`?o00000oooool2o`0000Gooooo0_l0
001Cooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o00000_ooool2o`0000kooooo0ol00000
0ooooooo0000o`000003o`0000Gooooo0_l00004oooooa7o00002oooool2o`0000Gooooo5_l00000
1?oooooo0000o`000?ooool5o`0002?ooooo0_l00002ooooo`;o0000K?ooool001cooooo00?o0000
ooooooooool0B_ooool2o`0000cooooo0_l00005ooooo`;o000000?oooooo`000?l000001Ol0000:
ooooo`oo00002?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000Co`000003ooooool0003o
000000Wo00001_ooool2o`0001gooooo0_l00002ooooo`;o00002?ooool2o`0006;ooooo000Loooo
o`03o`000?oooooooooo03gooooo0_l0000<ooooo`;o00002oooool2o`0000Kooooo1Ol00002oooo
o`;o00001Oooool2o`0000;ooooo4Ol00007ooooo`;o000000?oooooo`000?l000000_ooool7o`00
0003ooooool0003o000001Ko00000_ooool2o`0000;ooooo0ol0000[ooooo`;o00001?ooool2o`00
05cooooo000Looooo`03o`000?oooooooooo03gooooo0_l0000<ooooo`;o00003Oooool5o`000003
ooooool0003o000000?o00002Oooool2o`0000;ooooo2_l000000ooooooo0000o`000004o`0000[o
oooo0_l00004ooooo`?o000000?oooooo`000?l000007Ol000000ooooooo0000o`00000:ooooo`;o
00006?ooool2o`0000;ooooo0_l00008ooooo`;o00002oooool2o`0004oooooo000Looooo`03o`00
0?oooooooooo04;ooooo0_l0000Fooooo`Go000000Coooooo`000?l0003o00003ooooolBo`0000ko
oooo0ol00002oooooaKo000000?oooooo`000?l000000ol000000ooooooo0000o`000002ooooo`?o
00002?ooool2o`0001Cooooo0_l00002ooooo`;o00000_ooool2o`0001Gooooo0_l00004ooooo`;o
0000BOooool001cooooo00?o0000ooooooooool0@_ooool2o`0000oooooo0_l00002ooooo`;o0000
1?ooool2o`0001;ooooo5?l0000=ooooo`;o000000?oooooo`000?l000005Ol00002ooooo`?o0000
1oooool3o`0000Wooooo0_l0000Cooooo`?o00008_ooool2o`0004Wooooo000Looooo`03o`000?oo
oooooooo05?ooooo0_l00002ooooo`;o000000?oooooo`000?l000000ol0000<ooooo`;o00000ooo
oolEo`00013ooooo6Ol000000ooooooo0000o`000005o`0000?ooooo1?l00007ooooo`;o00005?oo
ool2o`000003ooooool0003o000000Kooooo1?l000001?oooooo0000o`000?ooool2o`0000kooooo
0_l0001:ooooo`007?ooool00ol0003oooooooooo`16ooooo`;o00002oooool2o`0000Gooooo1Ol0
000<ooooo`;o00000oooool3o`000003ooooool0003o000000ko00004_ooool8o`000003ooooool0
003o000001Go00001Oooool2o`0001gooooo0_l000000ooooooo0000o`000006ooooo`Co000000Co
ooooo`000?l0003ooooo0_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l00000
0_ooool3o`0004[ooooo000Looooo`03o`000?oooooooooo04Kooooo0_l0000>ooooo`;o00000_oo
ool4o`0000Sooooo0_l00008oooooa?o000000?oooooo`000?l000001oooool2o`0000Gooooo8_l0
000`ooooo`;o00002?ooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o0000Booo
ool001cooooo00?o0000ooooooooool0E_ooool2o`0000;ooooo0_l000000ooooooo0000o`000007
ooooo`;o00001_ooool2o`000003ooooool0003o0000013o000000?oooooo`000?l000001oooool2
o`0000Gooooo9Ol000000ooooooo0000o`000006ooooo`;o00008?ooool6o`0000kooooo0_l0001?
ooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o00003oooool2o`000003ooooool0003o0000
01;o00001Oooool3o`0000Kooooo1_l000000ooooooo0000o`00000Ho`0000;ooooo0ol000000ooo
oooo0000o`000006ooooo`;o00008?ooool2o`0000;ooooo0_l0001Oooooo`007?ooool00ol0003o
ooooooooo`1Fooooo`Go00000_ooool2o`0000Wooooo0_l00003oooooaSo000000?oooooo`000?l0
00000_ooool3o`0000Kooooo1_l00002oooooa[o00001Oooool2o`0002;ooooo0_l0000<ooooo`?o
00003Oooool2o`0000?ooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`0eooooo`;o0000
0_ooool2o`0001_ooooo2Ol00009ooooo`;o00000_oooolGo`0000;ooooo0ol00002ooooo`?o0000
1_ooool5o`000003ooooool0003o000001[o00001Oooool2o`0001cooooo0_l00004ooooo`;o0000
3?ooool3o`0000gooooo0_l00003ooooo`;o0000A_ooool001cooooo0_l0000fooooo`;o00000_oo
ool2o`0001cooooo0_l00002ooooo`Co00002?ooool2o`0000?ooooo6?l000001?oooooo0000o`00
0?l00002ooooo`;o00001?ooool2o`000003ooooool0003o000002;o00008Oooool2o`0000?ooooo
1?l00007ooooo`;o0000Goooool001cooooo00?o0000ooooooooool0Eoooool3o`0000;ooooo0ol0
0008ooooo`;o00000_ooool3o`0000;ooooo5?l00002ooooo`;o00002?ooool2o`0000?ooooo7_l0
0002ooooo`;o00007Oooool2o`0000Oooooo1Ol00006ooooo`Co0000GOooool001cooooo00?o0000
ooooooooool0DOooool5o`0000;ooooo0_l00002ooooo`;o00001oooool2o`000004ooooool0003o
0000ooooo`;o00000ooooolBo`000003ooooool0003o000000cooooo0_l00003oooooako00008?oo
ool2o`0000Gooooo0_l00003ooooo`?o00001oooool2o`0000;ooooo0_l0000Eooooo`;o0000@_oo
ool001cooooo00?o0000ooooooooool0Boooool2o`0000Cooooo1Ol0000?ooooo`;o000000?ooooo
o`000?l000000_ooool2o`0000Cooooo2ol000000ooooooo0000o`000002o`000003ooooool0003o
000000cooooo0_l00003oooooaoo00000_ooool2o`0001Kooooo0_l0000:ooooo`;o00000_ooool7
o`0000Sooooo0_l00008ooooo`;o00001oooool2o`0000;ooooo0ol00011ooooo`007?ooool00ol0
003oooooooooo`1;ooooo`Co00000oooool2o`00017ooooo0_l000000ooooooo0000o`000002oooo
o`;o00001?ooool3o`000003ooooool0003o000000Ko000000Goooooo`000?l0003o0000ooooo`02
o`000003ooooool0003o000000?ooooo0_l00009ooooo`Go000000?oooooo`000?l000005ol00002
ooooo`;o00005_ooool4o`0000Cooooo0_l00006ooooo`Oo00002?ooool2o`0000Sooooo0_l00007
ooooo`;o00000oooool2o`00047ooooo000Looooo`03o`000?oooooooooo03Sooooo0_l0000Coooo
o`;o00000oooool2o`00013ooooo0_l00002ooooo`;o00002?ooool2o`000003ooooool0003o0000
00Oo000000?oooooo`000?l000000_ooool5o`0000?ooooo0_l0000<ooooo`;o000000?oooooo`00
0?l000005ol00002ooooo`;o00006?ooool2o`0000Cooooo0_l00008ooooo`;o00003?ooool2o`00
05Sooooo000Looooo`03o`000?oooooooooo03Sooooo0_l00002ooooo`;o00003Oooool3o`0001Go
oooo0ol0000;ooooo`;o00000_ooool;o`0000Gooooo0_l0000Aooooo`;o00000ooooolJo`0003So
oooo0_l0000Eooooo`;o00000oooool2o`0003cooooo000Looooo`03o`000?oooooooooo03cooooo
0_l0000=ooooo`?o000000?oooooo`000?l000001Oooool2o`0000Gooooo0ol00003ooooo`;o0000
1?ooool2o`0000Kooooo0_l00003ooooo`[o00001_ooool2o`00013ooooo0_l00003ooooo`Co0000
00?oooooo`000?l000004ol00002ooooo`;o00003?ooool2o`0000Oooooo0_l00003ooooo`;o0000
9Oooool2o`0000;ooooo0_l00004ooooo`;o00000oooool2o`0003cooooo000Looooo`03o`000?oo
oooooooo04oooooo0_l00005ooooo`Co00000oooool3o`0000;ooooo0_l00003ooooo`Co00002ooo
ool5o`0000;ooooo1?l00005ooooo`;o00004ooooolCo`000004ooooool0003o0000ooooo`;o0000
1Oooool2o`0000[ooooo1_l00005ooooo`;o00000oooool2o`0001;ooooo0_l00004ooooo`;o0000
2oooool3o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o0000?Oooool001cooooo00?o
0000ooooooooool0F?ooool3o`000003ooooool0003o000000Cooooo0_l00003ooooo`;o00002?oo
ool2o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`;o00006_ooool2o`0000?ooooo0_l0
0004ooooo`Co000000Goooooo`000?l0003o0000ooooo`02o`0000Kooooo0_l00009ooooo`Go0000
00?oooooo`000?l000000ol00003ooooo`;o000000Coooooo`000?l0003o00002Oooool2o`0000So
oooo0_l00004ooooo`;o00003?ooool2o`0000Gooooo0_l00004ooooo`;o0000?Oooool001cooooo
00?o0000ooooooooool0Aoooool2o`00013ooooo0_l000001?oooooo0000o`000?ooool3o`0000Co
oooo0_l00009ooooo`;o00000_ooool2o`0000Sooooo0_l0000Oooooo`;o00000oooool;o`0000Oo
oooo0_l00008ooooo`Wo000000?oooooo`000?l000001?ooool5o`0000Oooooo1Ol0000Jooooo`;o
000000?oooooo`000?l00000B?ooool001cooooo00?o0000ooooooooool0Aoooool2o`0000?ooooo
0ol00006ooooo`;o00000_ooool2o`0000?ooooo1?l00003ooooo`Go00001oooool2o`0000;ooooo
0_l00008ooooo`;o00008Oooool2o`000003ooooool0003o000000Go000000Coooooo`000?l0003o
00004?ooool3o`0000?ooooo0_l00007ooooo`Co00000_ooool2o`000003ooooool0003o000000So
00006_ooool2o`000003ooooool0003o000004Sooooo000Looooo`03o`000?oooooooooo04Oooooo
0_l00003ooooo`Go00001?ooool2o`0000Oooooo1Ol000001Ooooooo0000o`000?l0003ooooo00?o
00001_ooool2o`0000Sooooo0_l00003ooooo`;o00008?ooool2o`0000;ooooo0_l000000ooooooo
0000o`000002o`00013ooooo0_l000000ooooooo0000o`00000=ooooo`;o00000oooool=o`0000Go
oooo0_l000000ooooooo0000o`000004ooooo`;o00001Oooool2o`0000Gooooo0_l0001:ooooo`00
7?ooool00ol0003oooooooooo`0[ooooo`;o00001?ooool2o`0001Cooooo0_l00003ooooo`;o0000
00?oooooo`000?l000001?ooool2o`0000Sooooo1?l000000ooooooo0000o`000002ooooo`?o0000
2?ooool4o`0000Cooooo0_l00003ooooo`;o00007_ooool2o`0000Cooooo0_l00003ooooo`;o0000
3oooool3o`000003ooooool0003o000000Sooooo0_l00005ooooo`go000000?oooooo`000?l00000
0_ooool2o`000004ooooool0003o0000ooooo`;o00000oooool3o`0000Gooooo0_l00005ooooo`;o
0000B_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@
413oooooooooo`04ooooo`03o`000?oooooooooo02_ooooo0_l00003ooooo`?o000000?oooooo`00
0?l000006_ooool2o`0000gooooo0ol00002ooooo`;o00000_ooool3o`0000Sooooo1?l00002oooo
o`Co000000Coooooo`000?l0003ooooo0_l0000Mooooo`;o00005Oooool4o`000005ooooool0003o
0000o`000?ooool00_l00008ooooo`;o00000_ooool@o`0000Gooooo0_l00009ooooo`;o00006Ooo
ool2o`0000;ooooo0_l0000jooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q
1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo033ooooo0ol000000ooooooo0000
o`00000?ooooo`?o00000oooool3o`0000;ooooo0_l0000=ooooo`?o00000_ooool2o`0000?ooooo
0_l00009ooooo`;o00000oooool2o`0000?ooooo0_l000000ooooooo0000o`00000dooooo`Go0000
00Coooooo`000?l0003ooooo1?l00007oooooa?o00000_ooool2o`0000Kooooo0_l0000>ooooo`;o
00003oooool2o`0000;ooooo0_l0000jooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooo
ooooo`09ooooo`Go00001_ooool00ol0003oooooooooo`15ooooo`?o00000_ooool4o`000003oooo
ool0003o0000013ooooo0_l0000Cooooo`;o000000?oooooo`000?l00000?Oooool5o`0000?ooooo
1?l00007oooooa?o00000_ooool2o`000003ooooool0003o000000?ooooo0_l0000>ooooo`;o0000
4_ooool2o`0003_ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Co
A4A4omgMgOoooooo00001oooool3o`0002oooooo0_l00004ooooo`;o00004oooool2o`0000;ooooo
0ol0000>ooooo`Go00003?ooool2o`0000Cooooo0_l000000ooooooo0000o`00000mooooo`;o0000
00?oooooo`000?l000003ooooolIo`0000Gooooo0ol0000<ooooo`;o00002Oooool2o`0000Kooooo
0_l0000kooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmE
EEGoooooo`0000Oooooo00?o0000ooooooooool0;oooool2o`0000Cooooo0_l0000Booooo`?o0000
00Coooooo`000?l0003o00003oooool2o`000003ooooool0003o000000Kooooo0_l00004ooooo`?o
0000;Oooool5o`0000Oooooo0ol00005ooooo`;o00000oooool2o`00013ooooo0_l000000ooooooo
0000o`00000Do`0000Cooooo1Ol0000<ooooo`;o000000?oooooo`000?l000001_ooool3o`0004;o
oooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oMgMgolc<c?l00000
1oooool00ol0003oooooooooo`19ooooo`?o000000Coooooo`000?l0003ooooo0_l00006ooooo`;o
00002?ooool4o`0000Cooooo0_l00005ooooo`;o00002?ooool2o`0000?ooooo0_l000000ooooooo
0000o`00000Hooooo`;o000000?oooooo`000?l000000ol00003ooooo`;o000000?oooooo`000?l0
00001?l00002ooooo`?o00000oooool2o`0000;ooooo0_l0000;ooooo`?o000000?oooooo`000?l0
00002ol00002ooooo`?o000000?oooooo`000?l000000_l00003ooooo`;o00003?ooool2o`0000Co
oooo0_l00002ooooo`;o00000oooool2o`0004;ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMg
M`cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0cooooo`;o00005Oooool2o`00
00Cooooo0_l00006ooooo`;o00001Oooool7o`0000Gooooo0_l0000;ooooo`;o000000?oooooo`00
0?l000000_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l0000Cooooo`;o00000_ooool4
o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool6o`0000Cooooo0_l00007
oooooa_o00000_ooool2o`00017ooooo1?l00005ooooo`?o0000Aoooool00006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo03?ooooo0_l0
000Eooooo`;o00001_ooool2o`0000Sooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l0
0003ooooo`Ko00001oooool2o`0000;ooooo1Ol00007ooooo`;o00001_ooool2o`0000Oooooo0_l0
0006ooooo`Co00001?ooool2o`0000Wooooo1Ol0000=oooooaco00000oooool2o`00017ooooo0_l0
0004ooooo`?o00002Oooool2o`0000;ooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`0[
ooooo`;o00007Oooool3o`0000Gooooo0_l00008ooooo`;o00001?ooool6o`0000Gooooo1?l00005
ooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000;o00002_ooool2
o`0000Kooooo0ol00006ooooo`Co00000_ooool4o`0000Wooooo0ol00002ooooo`;o00001oooool2
o`0000Cooooo6_l00003ooooo`Co00000oooool3o`0000[ooooo0_l00003ooooo`;o00000_ooool2
o`0000Cooooo1?l00002ooooo`;o0000>Oooool001cooooo00?o0000ooooooooool0:oooool2o`00
01kooooo0_l0000:ooooo`;o00001Oooool2o`0000;ooooo1?l00005ooooo`;o00002Oooool5o`00
00Oooooo1?l00003ooooo`?o00003?ooool2o`0000Gooooo1?l00004ooooo`;o00004?ooool2o`00
00Oooooo0_l000001?oooooo0000o`000?oooolJo`0000?ooooo1?l00003ooooo`?o00002_ooool2
o`0000Oooooo0_l00004ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0:Oooool2o`00
00;ooooo0ol0000Kooooo`;o00000_ooool2o`0000Kooooo0ol00004ooooo`?o000000?oooooo`00
0?l000000_ooool2o`0000?ooooo0_l0000;ooooo`;o00003oooool3o`0001;ooooo0ol0000>oooo
o`;o00005?ooool2o`0000;ooooo6Ol0000Kooooo`;o00001Oooool2o`0000Oooooo0_l000000ooo
oooo0000o`000005ooooo`;o0000<?ooool001cooooo00?o0000ooooooooool0:Oooool2o`0000;o
oooo0ol0000Iooooo`Co00000_ooool2o`0000Oooooo0_l00005ooooo`Go00000_ooool2o`0000So
oooo0_l0000Hooooo`Co00004?ooool2o`0000oooooo1?l00003ooooo`;o00000_ooool2o`0000;o
oooo0_l00007oooooago000000?oooooo`000?l000001Oooool2o`0000oooooo0_l00005ooooo`;o
00001?ooool2o`000004ooooool0003o0000ooooo`Co00000oooool2o`00033ooooo000Looooo`03
o`000?oooooooooo04Wooooo1?l0000Dooooo`?o00003?ooool2o`0001[ooooo0_l0000>ooooo`Co
00002Oooool2o`000003ooooool0003o000000Go00000oooool2o`0000;ooooo0_l00002ooooo`;o
00001_ooool3o`000003ooooool0003o000001So000000?oooooo`000?l000001Oooool2o`00017o
oooo0_l00005ooooo`;o00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`;o
0000;oooool001cooooo00?o0000ooooooooool0@oooool2o`0000Kooooo0_l0000Cooooo`Co0000
3Oooool4o`0001Oooooo0_l00005ooooo`?o00001_ooool2o`0000_ooooo0_l000001?oooooo0000
o`000?l00002ooooo`?o00003Oooool2o`0000?ooooo0_l00002oooooaSo00005_ooool4o`0000?o
oooo0_l00004ooooo`?o00001oooool2o`0000Oooooo0_l0000_ooooo`007?ooool00ol0003ooooo
ooooo`13ooooo`;o000000?oooooo`000?l000000oooool2o`0001?ooooo1?l0000:ooooo`Oo0000
00?oooooo`000?l000003?ooool2o`0000Kooooo0_l00005ooooo`?o00001_ooool2o`0000oooooo
0_l00003ooooo`;o00003?ooool3o`0000Gooooo6_l0000Fooooo`Co00002Oooool4o`0000Kooooo
0_l0000hooooo`007?ooool00ol0003oooooooooo`16ooooo`;o00000oooool2o`0001gooooo0_l0
0002ooooo`Co00000oooool3o`0000cooooo0_l000001?oooooo0000o`000?l00004ooooo`;o0000
3?ooool4o`0001;ooooo1ol00002ooooo`;o00000_ooool3o`0000Kooooo5_l000000ooooooo0000
o`000002o`0001Cooooo0_l00005ooooo`;o00001Oooool4o`0000kooooo0_l0000`ooooo`007?oo
ool00ol0003oooooooooo`0Yooooo`;o00006Oooool2o`0000Gooooo0_l00006ooooo`;o00003_oo
ool2o`0000Gooooo0_l00006ooooo`;o000000Coooooo`000?l0003o00003oooool5o`0000;ooooo
0ol0000=ooooo`;o00004oooool7o`000003ooooool0003o000000;ooooo0_l0000;oooooa;o0000
0oooool2o`0001Cooooo0_l00005ooooo`;o00001?ooool4o`0000oooooo0_l0000`ooooo`007?oo
ool00ol0003oooooooooo`0Vooooo`;o000000?oooooo`000?l000006Oooool4o`0000?ooooo0_l0
0003ooooo`;o000000Coooooo`000?l0003ooooo0_l0000:ooooo`?o00003Oooool6o`0000Gooooo
0_l0000;ooooo`;o00000_ooool4o`0000cooooo0_l0000:ooooo`;o00001?ooool2o`0000;ooooo
1_l0000AoooooaGo00002?ooool2o`0001Gooooo0_l00003ooooo`Co0000@Oooool001cooooo00?o
0000ooooooooool09_ooool2o`0001gooooo0ol00005ooooo`;o000000?oooooo`000?l000000_oo
ool4o`0000[ooooo0_l0000>ooooo`Go00000_ooool6o`00017ooooo0ol000000ooooooo0000o`00
0008ooooo`;o000000?oooooo`000?l000001oooool2o`0000Cooooo0_l00002ooooo`Co00003_oo
ool4o`000003ooooool0003o000001?o00002?ooool2o`0000gooooo0_l00006ooooo`;o00000ooo
ool3o`0000Gooooo0_l00007ooooo`;o0000<_ooool001cooooo0_l0000Yooooo`;o00006oooool2
o`0000;ooooo0_l00002ooooo`;o00000_ooool2o`000004ooooool0003o0000o`0000Sooooo1?l0
000Fooooo`Co00001Oooool2o`0000Wooooo0_l000001Ooooooo0000o`000?l0003ooooo00Co0000
2Oooool2o`0000Oooooo0_l00002ooooo`;o00001?ooool5o`0000gooooo1?l000001?oooooo0000
o`000?ooool8o`000003ooooool0003o000000So00003?ooool2o`0000Sooooo0_l0000<ooooo`;o
00000oooool4o`0000Oooooo0_l0000booooo`007?ooool00ol0003oooooooooo`0Xooooo`;o0000
00?oooooo`000?l000007?ooool4o`0000Cooooo0_l000000ooooooo0000o`000009ooooo`Co0000
6oooool2o`000003ooooool0003o000000?o00001oooool2o`0000Cooooo0_l000000ooooooo0000
o`00000Fooooo`;o00001?ooool7o`0000;ooooo0_l00008ooooo`;o00001Oooool8o`0000?ooooo
1Ol000000ooooooo0000o`00000<ooooo`;o00006oooool4o`0003_ooooo000Looooo`03o`000?oo
oooooooo02_ooooo0_l0000Looooo`Co00001oooool2o`0000Sooooo0ol0000=ooooo`;o00003_oo
ool2o`000003ooooool0003o000000?o00003Oooool2o`0001cooooo0_l000001?oooooo0000o`00
0?l00002ooooo`;o00000_ooool2o`0000oooooo0_l00004ooooo`;o00000_ooool6o`000003oooo
ool0003o000002?ooooo0_l00005ooooo`;o0000??ooool001cooooo00?o0000ooooooooool0@_oo
ool2o`0000?ooooo1Ol00004ooooo`;o00000oooool2o`0000Oooooo0_l00002ooooo`;o00002_oo
ool2o`0000gooooo2Ol0000Aooooo`;o00006?ooool2o`000003ooooool0003o000000Wooooo0_l0
000:ooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`000004o`0002?ooooo0_l0
00000ooooooo0000o`000002o`00047ooooo000Looooo`03o`000?oooooooooo04;ooooo0_l00003
ooooo`;o00001oooool2o`0000?ooooo0_l00007ooooo`;o00000_ooool2o`00017ooooo0_l00006
ooooo`Go00001?ooool2o`0000oooooo0_l0000Hooooo`So00001_ooool2o`0000[ooooo0_l00002
ooooo`;o00000_ooool4o`000003ooooool0003o000000?o00009?ooool2o`0000;ooooo0ol00008
ooooo`;o0000=oooool001cooooo00?o0000ooooooooool08_ooool2o`0000Gooooo0_l0000Koooo
o`?o00000oooool3o`000003ooooool0003o000000Wooooo0_l00005ooooo`;o00000oooool2o`00
00cooooo0_l0000?ooooo`?o00003_ooool5o`0000Cooooo0_l0000?ooooo`Wo00006?ooool4o`00
00;ooooo1Ol0000Xooooo`?o00002?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000`oooo
o`007?ooool00ol0003oooooooooo`0Rooooo`;o00001Oooool2o`0001Kooooo0_l00003ooooo`?o
00000oooool3o`000003ooooool0003o000000Wooooo0_l0000:ooooo`;o00003?ooool4o`000003
ooooool0003o000000_ooooo0_l0000?ooooo`Co00001?ooool2o`0000oooooo0_l000001?oooooo
0000o`000?ooool3o`0001Sooooo0_l00002ooooo`;o000000?oooooo`000?l000003?ooool2o`00
01cooooo0ol00009ooooo`;o000000Coooooo`000?l0003ooooo0_l0000`ooooo`007?ooool00ol0
003oooooooooo`11ooooo`;o00000oooool2o`000003ooooool0003o000001Cooooo0_l0000Doooo
o`Co000000?oooooo`000?l000002oooool3o`0000Gooooo0_l00008ooooo`;o00005_ooool2o`00
02?ooooo0_l0000>ooooo`?o00006Oooool2o`000003ooooool0003o000000[ooooo0_l0000foooo
o`007?ooool00ol0003oooooooooo`13ooooo`Co00000_ooool2o`0000Sooooo0_l0000:ooooo`?o
00003Oooool2o`0000?ooooo0_l0000Aooooo`?o00001Oooool2o`0000Oooooo1?l0000>ooooo`;o
00005Oooool2o`0002?ooooo0_l0000Fooooo`;o00000_ooool2o`000003ooooool0003o000000;o
oooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00004_ooool2o`000003oooo
ool0003o000000;o00001?ooool2o`0000Kooooo0_l0000;ooooo`;o00003Oooool2o`0000?ooooo
1?l0000Aooooo`?o00003?ooool4o`0000;ooooo1?l00008ooooo`;o00003Oooool2o`0000Kooooo
0_l0000Rooooo`;o00005oooool2o`000004ooooool0003o0000ooooo`?o00000_ooool2o`000003
ooooool0003o000003_ooooo000Looooo`03o`000?oooooooooo027ooooo1?l00007ooooo`;o0000
4_ooool4o`0000Oooooo0_l00005ooooo`Co00005_ooool2o`0000Oooooo0ol00006ooooo`?o0000
0_ooool2o`000004ooooool0003o0000ooooo`Ko000000?oooooo`000?l000003?ooool6o`0001?o
oooo1Ol0000Yooooo`;o00006_ooool6o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`00
03Sooooo000Looooo`03o`000?oooooooooo027ooooo1?l0000Kooooo`Co00001?ooool2o`0000So
oooo1?l00006ooooo`Co00003?ooool2o`0000Oooooo0_l00007ooooo`?o00000_ooool2o`000003
ooooool0003o000000?ooooo1?l000001?oooooo0000o`000?l0000:ooooo`?o00000_ooool2o`00
00gooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Vooooo`;o00006oooool4
o`0000?ooooo0_l00004ooooo`;o00001_ooool2o`00033ooooo000Looooo`03o`000?oooooooooo
03oooooo1?l00004ooooo`?o00004_ooool4o`0001;ooooo0_l000000ooooooo0000o`000005oooo
o`;o00001Oooool4o`0000Gooooo0ol00002ooooo`;o00002_ooool3o`0000;ooooo0_l0000=oooo
o`;o00002?ooool4o`0002;ooooo0ol0000Nooooo`;o00002_ooool3o`0000Kooooo0_l0000`oooo
o`007?ooool00ol0003oooooooooo`0oooooo`Co00001?ooool2o`00017ooooo0_l0000Fooooo`;o
000000?oooooo`000?l000000oooool4o`0000Gooooo1?l00004ooooo`Co00003_ooool4o`0000So
oooo0_l00008ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0001Oooooo0_l0000;oooo
o`?o00007_ooool4o`0000Sooooo0ol0000hooooo`007?ooool00ol0003oooooooooo`0oooooo`Co
00005oooool2o`0001Kooooo0_l00005ooooo`Ko000000Coooooo`000?l0003ooooo0_l00006oooo
o`;o00002oooool2o`0000Gooooo1?l00006ooooo`;o00000oooool2o`0000?ooooo0_l000000ooo
oooo0000o`000006o`0001Kooooo0_l0000Zooooo`Ko00004_ooool2o`0002oooooo000Looooo`03
o`000?oooooooooo03kooooo2?l0000>ooooo`;o00001oooool2o`00017ooooo1?l00005ooooo`Wo
00005_ooool2o`0000Oooooo0_l000000ooooooo0000o`000008ooooo`Co00000_ooool:o`0001Go
oooo0_l00005ooooo`?o00000_ooool2o`0001oooooo1?l00006ooooo`;o00000oooool2o`0000Oo
oooo0_l0000_ooooo`007?ooool2o`00033ooooo0_l0000;ooooo`Co00000_ooool4o`0000kooooo
0_l00006ooooo`?o00002oooool2o`0000Cooooo0_l00007ooooo`?o00000_ooool5o`0000Cooooo
0_l0000@ooooo`;o00002Oooool4o`0000Sooooo2_l00003ooooo`;o00000_ooool2o`00013ooooo
0_l00005ooooo`Co000000?oooooo`000?l000007Oooool2o`0000;ooooo0_l00004ooooo`Co0000
0oooool2o`0000Oooooo0_l0000_ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00002ooo
ool3o`0001gooooo0_l0000:ooooo`Co00003?ooool6o`000003ooooool0003o000000;o00001?oo
ool2o`0000Kooooo0_l00008ooooo`;o00002oooool2o`0000[ooooo2?l00003ooooo`;o00000_oo
ool4o`0000kooooo0_l000000ooooooo0000o`000004ooooo`;o00008?ooool2o`0000Cooooo0_l0
0002ooooo`;o00003_ooool2o`0002oooooo000Looooo`03o`000?oooooooooo01oooooo0_l0000L
ooooo`;o00001?ooool2o`0001Oooooo0_l0000:ooooo`Ko00001_ooool2o`0000;ooooo1ol00000
1?oooooo0000o`000?l00003ooooo`Co00001Oooool2o`0000Sooooo0_l0000Dooooo`;o000000?o
ooooo`000?l000001Ol000001?oooooo0000o`000?ooool5o`000003ooooool0003o0000017ooooo
0_l00005ooooo`;o00009Oooool2o`0004?ooooo000Looooo`03o`000?oooooooooo01Wooooo0_l0
0004ooooo`;o00006oooool3o`0000Cooooo0_l0000Cooooo`;o000000Coooooo`000?l0003o0000
1?ooool2o`0000Kooooo1_l000001?oooooo0000o`000?ooool2o`0000;ooooo2ol00003ooooo`Co
00001oooool2o`0000Kooooo0_l00002ooooo`Co00003_ooool2o`0000?ooooo0ol00003ooooo`;o
000000?oooooo`000?l000001Ol0000Fooooo`;o000000Coooooo`000?l0003o00001oooool2o`00
02Oooooo0_l00005ooooo`;o0000<?ooool001cooooo00?o0000ooooooooool06Oooool2o`0001?o
oooo0_l0000<ooooo`;o00006_ooool5o`0000Gooooo2Ol00002ooooo`?o000000?oooooo`000?l0
00000ol000000ooooooo0000o`000004o`000003ooooool0003o000000Oo000000?oooooo`000?l0
00001oooool2o`0000[ooooo1ol0000Booooo`;o00001Oooool7o`0000;ooooo0_l0000Booooo`;o
00000_ooool2o`0000Gooooo1?l000000ooooooo0000o`00000Pooooo`;o00000_ooool2o`0000Go
oooo0_l0000`ooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00008?ooool4o`0000Kooooo
0ol00004ooooo`;o000000?oooooo`000?l000001Ol00002oooooako00001_ooool2o`0000gooooo
1?l0000=ooooo`;o00000oooool2o`0000Gooooo1Ol00004ooooo`;o00007Oooool2o`0000?ooooo
0_l0000>ooooo`;o00002_ooool2o`0000?ooooo1?l0000jooooo`007?ooool00ol0003ooooooooo
o`0^ooooo`;o00008?ooool4o`000003ooooool0003o000000Co00001_ooool2o`0000Kooooo0_l0
0002ooooob7o00001?ooool2o`0000Kooooo0_l00004ooooo`;o00003oooool2o`0000Gooooo0_l0
00000ooooooo0000o`000004o`0001gooooo0_l00009ooooo`;o00003oooool2o`0000[ooooo0_l0
0003ooooo`Co0000>_ooool001cooooo00?o0000ooooooooool07oooool2o`0001Wooooo0_l0000A
ooooo`;o00001_ooool6o`0000;ooooo0_l0000<ooooo`Co000000?oooooo`000?l000007_l00002
ooooo`Go00000oooool2o`0000Cooooo0_l0000Fooooo`;o000000?oooooo`000?l000001_l0000K
ooooo`;o00000oooool2o`0000?ooooo0ol0000?ooooo`?o0000C?ooool001cooooo00?o0000oooo
ooooool07oooool2o`0000gooooo0_l0000:ooooo`;o00003oooool4o`0000kooooo0ol000000ooo
oooo0000o`000002ooooo`;o00001?oooolQo`000004ooooool0003o0000o`0000;ooooo1Ol00004
ooooo`;o00004Oooool2o`0000[ooooo2Ol00003ooooo`;o00001?ooool3o`0001Cooooo0_l00003
ooooo`;o00004Oooool2o`0000[ooooo0_l00002ooooo`;o0000??ooool001cooooo00?o0000oooo
ooooool0;_ooool2o`0000Wooooo1?l0000>ooooo`;o00000_ooool2o`0000gooooo1Ol000001?oo
oooo0000o`000?l00002ooooobCo00001Oooool2o`0000Oooooo0_l0000Aooooo`;o00001_ooool2
o`0000;ooooo0ol000001?oooooo0000o`000?ooool2o`0000;ooooo1?l00003ooooo`?o0000>?oo
ool6o`0000Oooooo0_l0000cooooo`007?ooool00ol0003oooooooooo`0gooooo`So00002oooool2
o`0000?ooooo0_l00003ooooo`;o00002?ooool8o`000003ooooool0003o000002Co00001?ooool2
o`0002?ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l00004ooooo`Co000000?ooooo
o`000?l000000_l0000Gooooo`;o00007?ooool2o`0000?ooooo0ol00009ooooo`;o0000<oooool0
01cooooo00?o0000ooooooooool0=oooool8o`0000[ooooo0ol00008ooooo`;o00002?ooool3o`00
0003ooooool0003o000000?ooooo2Ol000000ooooooo0000o`00000Ho`0000Kooooo1?l000000ooo
oooo0000o`00000<ooooo`;o00002?ooool2o`000003ooooool0003o000000Kooooo0_l00002oooo
o`Co00000oooool3o`0000?ooooo1?l0000Dooooo`Oo00006_ooool2o`0000?ooooo0_l000000ooo
oooo0000o`00000looooo`007?ooool00ol0003oooooooooo`0Pooooo`;o00005_ooool6o`0000Oo
oooo0_l00002ooooo`;o00000oooool2o`0000gooooo1?l000000ooooooo0000o`000003ooooobOo
00000_ooool2o`000003ooooool0003o000000?o00003?ooool2o`0000;ooooo0_l00002ooooo`Co
000000?oooooo`000?l000001_ooool2o`000003ooooool0003o000000So00001Oooool5o`0000?o
oooo0_l0000<ooooo`Co00000_ooool2o`0001Cooooo0_l0000<ooooo`;o0000??ooool001cooooo
00?o0000ooooooooool08?ooool2o`0001Sooooo1?l00007ooooo`;o00001oooool2o`0000Wooooo
0_l00002ooooo`;o00000oooool2o`0000?ooooo8?l000000ooooooo0000o`000004o`0000;ooooo
1?l000000ooooooo0000o`000002o`000003ooooool0003o000000cooooo0_l00002ooooo`;o0000
0oooool2o`0000?ooooo0_l00002ooooo`co00000_ooool8o`0000?ooooo0_l0000<ooooo`;o0000
6_ooool2o`0000gooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`1Dooooo`?o00000_oo
ool2o`0000Kooooo0_l00002ooooo`Go00000_oooolRo`000003ooooool0003o000000?o000000?o
ooooo`000?l000000_l000000ooooooo0000o`000002o`00013ooooo1Ol00003ooooo`;o00000_oo
ool6o`0000Cooooo2Ol0000oooooo`;o0000>oooool001cooooo00?o0000ooooooooool0AOooool2
o`0000_ooooo1Ol00002ooooo`;o00001_ooool2o`0000;ooooo1?l00003ooooob;o000000?ooooo
o`000?l000002?ooool5o`0000Gooooo0_l00009ooooo`Co00001?ooool2o`0000Cooooo1?l00000
0ooooooo0000o`000008o`0001Wooooo1?l00002ooooo`;o00004_ooool4o`0000?ooooo0_l00012
ooooo`007?ooool2o`00033ooooo0_l0000>ooooo`;o00001?ooool2o`0000_ooooo0_l000000ooo
oooo0000o`000005ooooo`Co00001ooooolOo`000003ooooool0003o000000Go000000?oooooo`00
0?l000002?ooool3o`0000;ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00003oooo
o`;o00002_ooool4o`0000?ooooo1ol000000ooooooo0000o`000003ooooo`;o00000oooool2o`00
00Oooooo0ol00007ooooo`Co00000_ooool2o`0000?ooooo0_l0000=ooooo`Co00000oooool2o`00
00Cooooo1?l0000jooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00003_ooool2o`00013o
oooo0_l00009ooooo`Oo000000?oooooo`000?l00000:?l000000ooooooo0000o`000003o`0000?o
oooo0_l00005ooooo`;o000000?oooooo`000?l000001?ooool2o`0000?ooooo0_l00002ooooo`;o
00001_ooool5o`0000;ooooo0_l000000ooooooo0000o`000002o`0000Gooooo0ol00003ooooo`;o
00001?ooool2o`000004ooooool0003o0000o`0001;ooooo0_l00006ooooo`;o00003?ooool2o`00
00Cooooo1?l0000jooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00008?ooool2o`000003
ooooool0003o000000Wooooo1?l000000ooooooo0000o`000002o`000003ooooool0003o000001;o
000000?oooooo`000?l000005?l00003ooooo`;o00004oooool6o`0000Wooooo1?l00003ooooo`;o
00001oooool2o`0000Wooooo0ol000000ooooooo0000o`000002ooooo`;o00003Oooool2o`0000So
oooo0_l0000Booooo`;o0000??ooool001cooooo00?o0000ooooooooool0>Oooool2o`0000_ooooo
0_l0000<ooooo`;o00002?ooool3o`0000?ooooo0ol00002ooooobWo00000_ooool2o`0001Sooooo
0ol0000:ooooo`Co00000oooool2o`0001;ooooo0_l00006ooooo`;o00003Oooool2o`00017ooooo
0_l00004ooooo`;o00000oooool2o`0003cooooo000Looooo`03o`000?oooooooooo023ooooo0_l0
000Gooooo`;o00002oooool2o`0000Gooooo0_l00004ooooo`?o00001Oooool6o`0000?ooooo0ol0
0002ooooobGo00000_ooool2o`0000;ooooo0_l0000Iooooo`;o00002?ooool2o`0000;ooooo0_l0
000Dooooo`;o00006?ooool2o`00017ooooo0_l00004ooooo`;o0000@Oooool001cooooo00?o0000
ooooooooool08?ooool2o`0002_ooooo0_l00004ooooo`;o00001_ooool<o`000003ooooool0003o
000002Co00001Oooool3o`0000Wooooo0ol0000Aooooo`;o00000oooool3o`0000;ooooo1?l0000B
ooooo`;o00001Oooool4o`0000_ooooo0_l00004ooooo`;o000000?oooooo`000?l00000EOooool0
01cooooo00?o0000ooooooooool08Oooool3o`0000cooooo0_l0000;ooooo`;o00007oooool6o`00
0003ooooool0003o000002Wo00000oooool2o`0000[ooooo0ol0000Aooooo`;o00000oooool2o`00
00Gooooo0_l0000Dooooo`;o00000oooool5o`0000[ooooo0_l00004ooooo`Ko00006_ooool2o`00
03Sooooo000Looooo`03o`000?oooooooooo027ooooo0ol0000<ooooo`;o00002oooool2o`0000_o
oooo1?l0000?ooooo`Co00001Oooool2o`000003ooooool0003o000002Go00008oooool4o`0000;o
oooo0_l0000Jooooo`;o00000oooool5o`00013ooooo0ol000001?oooooo0000o`000?ooool2o`00
00?ooooo0_l00007ooooo`;o00002Oooool2o`0003Sooooo000Looooo`03o`000?oooooooooo033o
oooo0_l0000Fooooo`Ko00003oooool2o`0000Kooooo0_l00003oooooa[o00000oooool7o`0000Ko
oooo0_l0000Dooooo`;o00001oooool4o`0000;ooooo0_l00004ooooo`;o00006_ooool2o`0001Go
oooo0_l00002ooooo`;o00000oooool2o`0000Oooooo0ol00007ooooo`;o0000>Oooool001cooooo
00?o0000ooooooooool0<?ooool2o`0000kooooo0_l00006ooooo`;o00003Oooool2o`0000Sooooo
0_l000001?oooooo0000o`000?l00004ooooob;o00000_ooool2o`0000?ooooo0_l0000Dooooo`;o
00003_ooool2o`0000?ooooo0_l00002ooooo`;o00005_ooool2o`0001Gooooo1?l0000?ooooo`;o
00001oooool3o`0003Sooooo000Looooo`03o`000?oooooooooo03gooooo0_l000000ooooooo0000
o`000006ooooo`;o00001oooool2o`0000Cooooo0_l00008ooooo`;o000000?oooooo`000?l00000
0_l00002ooooob;o00000oooool2o`0001Oooooo0_l0000;ooooo`;o00000oooool3o`0000Kooooo
0_l0000Fooooo`;o000000?oooooo`000?l000000_l0000Booooo`;o000000?oooooo`000?l00000
2Oooool5o`0000Cooooo1_l0000hooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00000_oo
ool2o`00013ooooo1?l00004ooooo`;o00001?ooool2o`0000Gooooo8Ol000000ooooooo0000o`00
0007o`0000Wooooo0_l0000>ooooo`;o00002oooool4o`0000;ooooo0_l0000<ooooo`;o00003Ooo
ool2o`0000Cooooo1?l0000Eooooo`;o00002Oooool6o`0000?ooooo1Ol0000iooooo`007?ooool0
0ol0003oooooooooo`0`ooooo`;o00001oooool2o`0000;ooooo0_l00007ooooo`;o00001oooool2
o`0000Kooooo0_l00004ooooo`Ko000000?oooooo`000?l000000_ooool5o`000003ooooool0003o
000001Co000000?oooooo`000?l000002Ol00003ooooo`;o00000oooool2o`0000?ooooo0_l0000H
ooooo`;o00002?ooool4o`0000Cooooo0_l0000=ooooo`;o00001oooool2o`0001?ooooo0_l0000:
ooooo`;o00000_ooool2o`0000Kooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`0`oooo
o`;o00001oooool2o`0000;ooooo0ol00006ooooo`;o00001oooool2o`0000_ooooo0_l000000ooo
oooo0000o`000005o`0000Cooooo8Ol00003ooooo`;o00000oooool2o`000003ooooool0003o0000
00Gooooo0_l000000ooooooo0000o`000002o`0000oooooo0_l000000ooooooo0000o`000003o`00
00;ooooo0_l00002ooooo`Co00004?ooool2o`0000;ooooo0_l00006ooooo`;o00004oooool2o`00
01Gooooo0_l0000jooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool0
1Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0<?ooool2o`0000Oooooo0_l0
0003ooooo`;o00005oooool2o`0000?ooooo0_l00005ooooo`Co00000_oooolOo`0000[ooooo0_l0
0002ooooo`;o00002?ooool4o`0000;ooooo0_l00006ooooo`Co000000?oooooo`000?l000001_l0
0002ooooo`;o00001?ooool4o`0000kooooo0_l000001?oooooo0000o`000?l0000Yooooo`;o0000
1oooool2o`0003[ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05
oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0kooooo`;o000000?oooooo`00
0?l000002_ooool2o`0000_ooooo0_l00007ooooo`;o00000_ooool8o`0000?ooooo0_l00002oooo
oaGo00001oooool5o`000003ooooool0003o000000oooooo0_l00004ooooo`[o00003oooool2o`00
00Gooooo0_l0000:ooooo`;o00001_ooool2o`0000;ooooo0_l0000Looooo`Ko0000@Oooool00003
ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool0>oooool2o`0000_ooooo1?l0000:ooooo`?o00001oooool2o`00
00;ooooo1Ol00005oooooaCo00000_ooool8o`000003ooooool0003o000000Co00000_ooool2o`00
0003ooooool0003o000000Kooooo0ol00004ooooo`;o00000_ooool5o`0000;ooooo0_l0000Hoooo
o`;o00001Oooool;o`000004ooooool0003o0000o`0000;ooooo0_l0000Aooooo`?o00000oooool2
o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`0003gooooo00000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o00008oooool2
o`0002?ooooo1Ol00004ooooo`;o00000oooool2o`0000?ooooo0ol00007ooooo`Ko00000_ooool8
o`0000;ooooo7?l000001Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`000?l000000_l0
00001?oooooo0000o`000?l00003ooooo`?o00000_ooool4o`00017ooooo0_l0000:ooooo`;o0000
1Oooool>o`0001Kooooo0ol00003ooooo`;o00002oooool2o`0003gooooo00000ooooooo0000oooo
o`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`00
0?oooooooooo02?ooooo0_l0000Sooooo`;o000000?oooooo`000?l000001?ooool3o`0000Oooooo
0ol00003ooooo`;o00000_ooool;o`000003ooooool0003o000000_o000000?oooooo`000?l00000
2?l000001Ooooooo0000o`000?l0003ooooo00;o00001?ooool2o`0000Gooooo1?l00007ooooo`?o
00000_ooool4o`0000kooooo0_l000001?oooooo0000o`000?l00009ooooo`;o000000?oooooo`00
0?l000004?l0000:ooooo`;o00006Oooool2o`00047ooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`0nooooo`;o
00004Oooool3o`0000Oooooo0_l00004ooooo`;o00000_ooool2o`000003ooooool0003o000000oo
000000?oooooo`000?l000001_l00004ooooo`Oo00000oooool2o`000003ooooool0003o000000Oo
oooo0_l00005ooooo`;o00000_ooool2o`0000?ooooo0_l0000?ooooo`;o00000_ooool2o`000004
ooooool0003o0000o`0000;ooooo0_l00004ooooo`Wo000000?oooooo`000?l000001Ol0000;oooo
o`;o00002?ooool2o`0000?ooooo0_l00002ooooo`;o00001_ooool2o`00047ooooo00001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0n
ooooo`;o00000oooool2o`0000cooooo0_l00004ooooo`;o00001Oooool4o`0000?ooooo2Ol00000
0ooooooo0000o`000006o`0000?ooooo0_l000000ooooooo0000o`000007ooooo`Go00000oooool4
o`000003ooooool0003o000000;o00001?ooool2o`0000;ooooo0ol000000ooooooo0000o`000007
ooooo`;o00001?ooool4o`0000kooooo0ol00002ooooo`;o00001?oooolAo`0000_ooooo0_l00008
ooooo`;o00000oooool2o`0000;ooooo0_l00009ooooo`;o0000?_ooool00006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo04?ooooo
0_l0000?ooooo`;o000000?oooooo`000?l000001Oooool5o`0000;ooooo0ol00002ooooo`[o0000
00?oooooo`000?l000000_l00002ooooo`Go00000oooool3o`000004ooooool0003o0000o`0000Co
oooo1?l000000ooooooo0000o`000002o`0000Cooooo0_l000000ooooooo0000o`000002o`000003
ooooool0003o000000;o00001Oooool2o`0000Cooooo1?l00003ooooo`;o00000oooool2o`0000Go
oooo0_l00006oooooa?o00002oooool2o`0000?ooooo0_l00009ooooo`;o000000?oooooo`000?l0
00001oooool4o`0003kooooo000Looooo`03o`000?oooooooooo03kooooo0_l00008ooooo`;o0000
2_ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000000oooool3o`0000Wooooo
1_l00002ooooo`Co00000_ooool7o`000004ooooool0003o0000o`0000?ooooo0_l00008ooooo`?o
00002?ooool2o`0000?ooooo1?l0000:ooooo`;o00001_ooool3o`0000;ooooo0_l000001Ooooooo
0000o`000?l0003ooooo00;o00000_ooool2o`0000;ooooo5ol0000<ooooo`;o00002Oooool3o`00
0003ooooool0003o000000Kooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0nooooo`;o
00002?ooool2o`0000;ooooo0_l00009ooooo`Oo00001?ooool2o`0000Kooooo0_l000000ooooooo
0000o`000004o`000003ooooool0003o000000;o00001?ooool6o`0000Oooooo1?l00007ooooo`;o
00006oooool3o`0000Kooooo0_l00005ooooo`?o00001Oooool2o`0000Gooooo3_l00002ooooo`Co
00003_ooool2o`0000Oooooo0ol000000ooooooo0000o`000018ooooo`007?ooool00ol0003ooooo
ooooo`1<ooooo`;o00000oooool2o`0000Sooooo0_l0000=ooooo`;o000000Goooooo`000?l0003o
0000ooooo`07o`0000?ooooo1Ol00002ooooo`;o00001?ooool2o`000003ooooool0003o000000Co
00000oooool2o`0000Kooooo0_l000000ooooooo0000o`000003ooooo`;o00000_ooool2o`0000Oo
oooo0ol00006ooooo`;o00000oooool2o`000003ooooool0003o000000cooooo3_l0000Booooo`Co
00001oooool2o`0000Gooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`1Aooooo`?o0000
1_ooool2o`0000_ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`000003oooo
ool0003o000000Cooooo0_l00004ooooo`?o00001?ooool2o`000003ooooool0003o000000Co0000
0oooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l00002ooooo`;o
00000oooool2o`000003ooooool0003o000000Sooooo0_l00003ooooo`;o000000?oooooo`000?l0
00001Ol00007ooooo`ko000000?oooooo`000?l000003oooool4o`0000Sooooo0_l00004ooooo`;o
0000AOooool001cooooo00?o0000ooooooooool0@oooool2o`0000cooooo0ol00003ooooo`;o0000
00?oooooo`000?l000002Oooool4o`0000;ooooo0_l00005ooooo`?o00003?ooool2o`0000;ooooo
0_l000001?oooooo0000o`000?ooool2o`0000_ooooo0ol00004ooooo`;o00000_ooool2o`0000;o
oooo0_l00002ooooo`Co000000?oooooo`000?l000000ol00005ooooo`;o00002?ooool5o`0000Oo
oooo0_l00002ooooo`?o000000?oooooo`000?l000000ol00002ooooo`;o00001?ooool2o`0000So
oooo1Ol00005ooooo`;o000000Coooooo`000?l0003ooooo1?l00016ooooo`007?ooool00ol0003o
ooooooooo`13ooooo`?o000000?oooooo`000?l000002?ooool2o`0000Cooooo0_l0000;ooooo`?o
00002Oooool5o`0000[ooooo0ol000000ooooooo0000o`000002o`000003ooooool0003o000000ko
oooo0_l00005ooooo`?o000000?oooooo`000?l000004?l00003ooooo`;o00003Oooool2o`0000Oo
oooo0_l0000Cooooo`;o00000_ooool2o`0000?ooooo1_l00005ooooo`;o00001?ooool4o`0004Ko
oooo000Looooo`03o`000?oooooooooo04?ooooo0ol000000ooooooo0000o`000008ooooo`Co0000
0_ooool2o`0000_ooooo0_l0000:ooooo`Co00002oooool3o`000003ooooool0003o000000;o0000
1Oooool2o`000003ooooool0003o000000?ooooo0_l00007ooooo`Go00000oooool@o`0000?ooooo
0_l00004ooooo`;o00001oooool2o`0000;ooooo0ol000000ooooooo0000o`00000Hooooo`Oo0000
0_ooool2o`0000Gooooo0_l00006ooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0DOoo
ool4o`0000;ooooo0_l0000=ooooo`;o00002_ooool2o`0001Sooooo0_l000000ooooooo0000o`00
0003ooooo`;o00001_ooool4o`0000Cooooo0ol00003ooooo`ko000000Coooooo`000?l0003ooooo
1Ol0000:ooooo`Ko00003oooool2o`0000Wooooo1Ol00007ooooo`Co0000C_ooool001cooooo00?o
0000ooooooooool0Boooool2o`0000Cooooo1?l00003ooooo`;o00001Oooool2o`0000Gooooo1Ol0
000aooooo`;o00001_ooool3o`0000;ooooo0ol000000ooooooo0000o`00000<o`000004ooooool0
003o0000ooooo`;o00003?ooool2o`00017ooooo0_l00005ooooo`Wo00001oooool4o`0004kooooo
000Looooo`03o`000?oooooooooo04_ooooo0_l00002ooooo`;o00001oooool2o`0000Gooooo0ol0
0006ooooo`?o00005?ooool4o`0000Cooooo0_l00002ooooo`;o00000_ooool2o`00017ooooo0_l0
0004ooooo`ko000000?oooooo`000?l000002_l00008ooooo`;o00000_ooool2o`0000cooooo0_l0
0008ooooo`So00001Oooool2o`0000cooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`15
ooooo`;o00002?ooool2o`0000Oooooo0_l00005ooooo`?o00007Oooool4o`0000Cooooo0_l00002
ooooo`;o00000_ooool2o`0000gooooo0_l000001?oooooo0000o`000?l00004ooooo`ko000000?o
ooooo`000?l000001ol000000ooooooo0000o`000008ooooo`;o00000_ooool4o`0000Oooooo0_l0
00000ooooooo0000o`000006ooooo`;o00000_ooool4o`0000Oooooo0_l0000<ooooo`;o0000AOoo
ool001cooooo0_l00016ooooo`;o00003_ooool2o`000003ooooool0003o000000Gooooo0_l0000<
ooooo`;o00002_ooool2o`0000;ooooo1?l00008ooooo`;o00004oooool5o`0000Gooooo5Ol00000
1?oooooo0000o`000?ooool2o`0000kooooo0_l00003ooooo`;o00000_ooool2o`0000Wooooo3?l0
001Hooooo`007?ooool00ol0003oooooooooo`1Aooooo`Ko00000oooool2o`0000Sooooo0_l00007
ooooo`;o00002_ooool2o`0000;ooooo1?l00004ooooo`;o00000_ooool2o`00017ooooo1Ol00000
0ooooooo0000o`000003o`000003ooooool0003o000001;o00000_ooool5o`0000;ooooo0_l00002
ooooo`;o00002oooool2o`0000gooooo1?l000001?oooooo0000o`000?ooool4o`0005Sooooo000L
ooooo`03o`000?oooooooooo057ooooo1Ol00004ooooo`;o00002?ooool2o`0000Sooooo1?l00000
0ooooooo0000o`000002o`000003ooooool0003o000000_ooooo0_l0000Eooooo`;o00001?ooool<
o`000003ooooool0003o000000_o00000_ooool4o`0000?ooooo0_l00002ooooo`;o00006_ooool4
o`000003ooooool0003o000005gooooo000Looooo`03o`000?oooooooooo05Oooooo0_l00003oooo
o`;o00000_ooool2o`0000cooooo1?l000000ooooooo0000o`000002o`000003ooooool0003o0000
00Kooooo0_l0000Booooo`;o00002Oooool6o`0000;ooooo7?l0000Oooooo`;o00001?ooool2o`00
05oooooo000Looooo`03o`000?oooooooooo02kooooo0_l0000Fooooo`Co00001_ooool2o`0000Go
oooo0_l00003ooooo`;o00000_ooool2o`0000Gooooo0_l0000Cooooo`;o00000_ooool2o`0001;o
oooo1Ol00005ooooob3o000000?oooooo`000?l000000_l0000;ooooo`;o00003oooool2o`000003
ooooool0003o000000;ooooo1?l00008ooooo`;o0000EOooool001cooooo00?o0000ooooooooool0
;_ooool2o`0001Kooooo1?l00005ooooo`?o000000?oooooo`000?l000001_ooool3o`0000Wooooo
0ol0000?ooooo`;o000000?oooooo`000?l000006?ooool3o`0000Gooooo8Ol0000?ooooo`;o0000
2Oooool3o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o00002_ooool2o`0005Gooooo
000Looooo`03o`000?oooooooooo04Sooooo0_l00005ooooo`Ko00001_ooool4o`0000Wooooo1_l0
0005ooooo`;o00001?ooool2o`0000oooooo0_l000000ooooooo0000o`000008ooooo`;o00000_oo
ool2o`0000?ooooo7ol00008ooooo`;o00003oooool4o`0000Kooooo0_l0000:ooooo`Oo00001?oo
ool2o`0000?ooooo0_l00019ooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o00002_ooool3
o`0000Wooooo1Ol00004ooooo`?o00004?ooool2o`0000?ooooo0_l000001?oooooo0000o`000?oo
ool2o`0000Wooooo1?l000000ooooooo0000o`00000Ro`0000?ooooo0_l0000?ooooo`;o00002Ooo
ool2o`0000Wooooo2?l00003ooooo`Oo0000BOooool001cooooo00?o0000ooooooooool0C_ooool2
o`0000?ooooo0_l00006ooooo`Oo00001oooool2o`0000Oooooo0_l00009ooooo`;o00001_ooool3
o`0000Sooooo0_l0000:ooooo`?o00000oooool2o`0000;ooooo6?l000000ooooooo0000o`000003
o`00013ooooo0ol00005ooooo`;o000000?oooooo`000?l000001?l0000;ooooo`Ko00000oooool5
o`0004_ooooo000Looooo`03o`000?oooooooooo033ooooo0_l0000Looooo`;o00000oooool2o`00
00Kooooo2Ol000000ooooooo0000o`00000Fooooo`;o00001oooool2o`0001Kooooo0_l000000ooo
oooo0000o`000003oooooa_o000000?oooooo`000?l000004?ooool3o`0000Gooooo1ol0000=oooo
o`?o000000?oooooo`000?l000001Oooool2o`0004cooooo000Looooo`03o`000?oooooooooo033o
oooo0_l0000Looooo`;o00000_ooool2o`0000Sooooo1Ol000001?oooooo0000o`000?ooool5o`00
00Cooooo1?l00008ooooo`;o00008_ooool7o`000003ooooool0003o0000017o000000?oooooo`00
0?l000000ol00002ooooo`?o00002?ooool2o`0000oooooo1_l0000=ooooo`Ko0000Doooool001co
oooo00?o0000ooooooooool0D_ooool2o`00017ooooo1Ol00004ooooo`Co00001oooool3o`0002?o
oooo0_l00002ooooo`;o000000?oooooo`000?l000006ol00009ooooo`;o00002oooool2o`0000?o
oooo0ol00009ooooo`;o00001?ooool5o`0005Cooooo000Looooo`03o`000?oooooooooo04kooooo
0_l0000=ooooo`;o00001_ooool2o`0001;ooooo0_l00005ooooo`;o00008Oooool2o`000003oooo
ool0003o000001_o00002Oooool2o`0000_ooooo0_l00003ooooo`?o00001_ooool2o`000003oooo
ool0003o000000Cooooo1?l0001Eooooo`007?ooool00ol0003oooooooooo`1>ooooo`Co00002ooo
ool2o`0000;ooooo0_l0000Fooooo`;o00001Oooool2o`0001_ooooo0ol00006ooooo`;o000000?o
ooooo`000?l000006?l000000ooooooo0000o`000002ooooo`;o000000Coooooo`000?l0003o0000
6Oooool2o`0000?ooooo0ol0001Jooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00000_oo
ool2o`0000Kooooo0_l00003ooooo`;o00000_ooool2o`000004ooooool0003o0000o`0000oooooo
0_l0000Uooooo`?o00001_oooolMo`000003ooooool0003o000000;ooooo0_l000000ooooooo0000
o`00000:ooooo`Go00001_ooool2o`000003ooooool0003o000000Gooooo0ol0001Jooooo`007?oo
ool00ol0003oooooooooo`1<ooooo`;o00002_ooool2o`0000?ooooo0_l00003ooooo`Ko00003_oo
ool2o`00023ooooo0ol00006ooooo`?o00000ooooolJo`0000Kooooo1Ol0000;ooooo`Go00001_oo
ool2o`000003ooooool0003o000000Kooooo0_l00005ooooo`;o0000Doooool001cooooo0_l0001B
ooooo`;o00001Oooool2o`0000Sooooo0ol000001Ooooooo0000o`000?l0003ooooo00;o00000_oo
ool2o`0000;ooooo0_l0000Tooooo`?o00001_ooool3o`0000;ooooo6ol00006ooooo`Go00001ooo
ool2o`000003ooooool0003o000001;ooooo0_l00008ooooo`;o0000Doooool001cooooo00?o0000
ooooooooool0=oooool2o`0001Kooooo1?l00002ooooo`;o000000?oooooo`000?l000001oooool5
o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000;ooooo0_l0000`ooooo`Co00000_oo
oolCo`0000;ooooo0_l00007ooooo`?o00002?ooool2o`000003ooooool0003o000001;ooooo0_l0
001Mooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00005_ooool3o`0000?ooooo0_l00005
ooooo`;o00000oooool2o`000003ooooool0003o000003kooooo0ol00004ooooo`Oo000000?ooooo
o`000?l000002?l0000;ooooo`;o00001Oooool2o`0000?ooooo0_l00002ooooo`;o00001oooool2
o`0006Kooooo000Looooo`03o`000?oooooooooo05Kooooo0_l00004ooooo`;o00008_ooool2o`00
02?ooooo0_l00006ooooo`Go000000?oooooo`000?l000000ol00002ooooo`Co00002oooool2o`00
00;ooooo1?l00003ooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`000004o`00
06;ooooo000Looooo`03o`000?oooooooooo03Wooooo0_l0000Eooooo`?o00000oooool2o`0002So
oooo0_l0000Gooooo`;o00002?ooool2o`0000Cooooo0_l000000ooooooo0000o`00000:o`000003
ooooool0003o000000?o00002oooool2o`0000;ooooo0_l00009ooooo`?o00000oooool4o`000003
ooooool0003o000000;o00001_ooool2o`0005[ooooo000Looooo`03o`000?oooooooooo03Wooooo
0_l0000Eooooo`?o00001?ooool2o`0000;ooooo0_l00009ooooo`;o000000?oooooo`000?l00000
3Oooool2o`0000Kooooo0ol0000Fooooo`;o00002?ooool2o`0000?ooooo4?l000000ooooooo0000
o`000003o`0000?ooooo0_l00003ooooo`;o00001Oooool2o`0000Wooooo0ol00004ooooo`?o0000
2oooool2o`0005[ooooo000Looooo`03o`000?oooooooooo05Oooooo0_l00002ooooo`;o00000_oo
ool2o`0000Gooooo1Ol0000=ooooo`;o00001_ooool3o`0001Oooooo0_l0000<ooooo`Co00000_oo
ool5o`000003ooooool0003o000000Kooooo0_l00003ooooo`;o00000oooool2o`0000Cooooo0_l0
000Eooooo`?o00001oooool2o`0005[ooooo000Looooo`03o`000?oooooooooo05Sooooo0_l00000
0ooooooo0000o`000002ooooo`;o00001_ooool3o`00033ooooo0_l0000;ooooo`Co00002_ooool5
o`0000Wooooo0_l00007ooooo`;o00005Oooool3o`0000Oooooo0_l0001Jooooo`007?ooool00ol0
003oooooooooo`1Hooooo`;o00004oooool2o`000003ooooool0003o000003Gooooo0_l0000:oooo
o`Oo00002Oooool2o`0000Oooooo0_l0000=ooooo`;o00003?ooool2o`0005kooooo000Looooo`03
o`000?oooooooooo05cooooo0_l00004ooooo`;o00002Oooool2o`000003ooooool0003o000002ko
oooo0_l00004ooooo`?o00000oooool2o`000003ooooool0003o000000;ooooo0ol0000Uooooo`Co
00002_ooool2o`0005kooooo000Looooo`03o`000?oooooooooo03kooooo0_l0000Looooo`Co0000
0_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000kooooo0_l0000Nooooo`;o0000
1?ooool2o`0000Cooooo0_l000000ooooooo0000o`00000Fooooo`;o00004?ooool2o`0000;ooooo
0_l0001Zooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00006oooool5o`0000Oooooo0_l0
0002ooooo`;o00002oooool2o`0000Kooooo0_l0000]ooooo`;o00005_ooool2o`0000gooooo1Ol0
00000ooooooo0000o`000002ooooo`;o0000Ioooool001cooooo00?o0000ooooooooool0Foooool5
o`0001Kooooo1?l0000Pooooo`;o00001?ooool2o`0000cooooo0_l0000Jooooo`;o00002_ooool4
o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l00000I?ooool001cooooo00?o0000oooo
ooooool0FOooool2o`0000?ooooo0_l0000Fooooo`;o00000_ooool2o`0001kooooo0ol00003oooo
o`;o00003?ooool2o`0000Wooooo1?l0000<ooooo`?o00001?ooool2o`000005ooooool0003o0000
o`000?ooool01?l00008ooooo`;o0000I?ooool001cooooo00?o0000ooooooooool0FOooool2o`00
00?ooooo0_l0000;ooooo`;o00001Oooool2o`0000;ooooo0_l00002ooooo`;o00001?ooool2o`00
01Oooooo1?l0000Looooo`Co00002oooool3o`0000Gooooo0_l000001Ooooooo0000o`000?l0003o
oooo00Co00001_ooool2o`0006Kooooo000Looooo`03o`000?oooooooooo05kooooo1?l00009oooo
o`;o00000oooool4o`0000;ooooo0_l00008ooooo`;o00005oooool3o`0000Gooooo0_l0000Uoooo
o`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o00001oooool4o`00
06Cooooo000Looooo`;o0000Eoooool2o`0000Sooooo0_l00006ooooo`;o00000_ooool2o`0000;o
oooo0_l0000>ooooo`;o00007Oooool4o`0001oooooo0_l00003ooooo`?o00000_ooool2o`0001Go
oooo0_l0001Tooooo`007?ooool00ol0003oooooooooo`1Fooooo`;o00002Oooool2o`0000Gooooo
0_l00002ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000_ooooo0_l0000Mooooo`;o
000000Coooooo`000?l0003o00001Oooool2o`0000gooooo1_l00003ooooo`;o00000oooool2o`00
00oooooo0_l0001_ooooo`007?ooool00ol0003oooooooooo`1Pooooo`?o00003?ooool3o`000003
ooooool0003o000000Sooooo0ol0000Mooooo`;o00000_ooool4o`0000Gooooo0_l00008ooooo`;o
00000oooool6o`00013ooooo0_l00006ooooo`?o00002?ooool2o`0006Gooooo000Looooo`03o`00
0?oooooooooo063ooooo0_l0000Aooooo`;o00002?ooool3o`0001gooooo2?l00005ooooo`;o0000
0_ooool2o`0000Cooooo0_l00006ooooo`;o000000Coooooo`000?l0003o00002?ooool2o`0000?o
oooo0_l00006ooooo`;o00001Oooool2o`0000;ooooo0_l00003ooooo`Co0000G_ooool001cooooo
00?o0000ooooooooool0A_ooool2o`0001Gooooo0_l0000Dooooo`;o0000:_ooool2o`000004oooo
ool0003o0000o`0000Wooooo0_l0000<ooooo`;o000000Coooooo`000?l0003o00002?ooool2o`00
00Cooooo0_l0000<ooooo`;o00001oooool4o`0005kooooo000Looooo`03o`000?oooooooooo04Ko
oooo0_l0000Eooooo`?o00000_ooool2o`0000_ooooo0_l0000aooooo`Co00008?ooool2o`0000Co
oooo0_l00002ooooo`;o0000Moooool001cooooo00?o0000ooooooooool0G_ooool2o`0000;ooooo
0_l00005ooooo`;o00001?ooool2o`000003ooooool0003o000002;ooooo1?l00008ooooo`Co0000
1_ooool4o`00017ooooo0_l00002ooooo`Go00000_ooool3o`000004ooooool0003o0000ooooo`;o
0000M?ooool001cooooo00?o0000ooooooooool0G_ooool2o`0000Wooooo0_l00007ooooo`Co0000
8?ooool4o`0000Oooooo0ol00008ooooo`Co000000?oooooo`000?l000000_l00003ooooo`;o0000
1oooool2o`0000;ooooo1Ol00003ooooo`;o000000Coooooo`000?l0003ooooo0_l0000:ooooo`;o
0000J?ooool001cooooo00?o0000ooooooooool0BOooool2o`0001?ooooo0_l0000Dooooo`Co0000
:Oooool3o`0000?ooooo0_l00008ooooo`Co00000oooool2o`0000gooooo0_l0000>ooooo`;o0000
1_ooool2o`0006Sooooo000Looooo`03o`000?oooooooooo04Wooooo0_l0000Mooooo`;o00001?oo
ool2o`0000Kooooo0_l0000Zooooo`;o00000oooool2o`0000;ooooo0_l00007ooooo`;o00008Ooo
ool2o`00073ooooo000Looooo`03o`000?oooooooooo06Sooooo0_l00004ooooo`Co0000:oooool3
o`0000Cooooo0_l000000ooooooo0000o`000004o`0000Oooooo0_l00002ooooo`;o0000Soooool0
01cooooo00?o0000ooooooooool0J_ooool2o`0000Cooooo0_l0000Rooooo`;o00001oooool3o`00
00Cooooo0_l00002ooooo`?o00003Oooool2o`000003ooooool0003o000000Co00001oooool2o`00
00Gooooo0_l0001hooooo`007?ooool00ol0003oooooooooo`1Zooooo`;o00000_ooool2o`0002Co
oooo0_l0000Booooo`Co00003oooool:o`000003ooooool0003o000000Co00000oooool2o`0007So
oooo000Looooo`03o`000?oooooooooo06Gooooo0_l00007ooooo`;o00000_ooool2o`000003oooo
ool0003o000002gooooo0_l00004ooooo`;o000000?oooooo`000?l000000oooool2o`0000gooooo
1?l000000ooooooo0000o`000002ooooo`;o00001?ooool3o`0007Kooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0
003oooooooooo`1Uooooo`;o00002oooool2o`000003ooooool0003o000002?ooooo0ol00007oooo
o`;o00001_ooool3o`0000?ooooo0_l0000@ooooo`Co00002?ooool3o`0007Kooooo00001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_oo
ool00ol0003oooooooooo`1_ooooo`;o00000_ooool2o`0000;ooooo0_l00008ooooo`;o00001Ooo
ool2o`0000;ooooo0_l0000<ooooo`?o00001oooool2o`000003ooooool0003o000000?ooooo0_l0
000?ooooo`Co00000oooool4o`0001Gooooo0_l0001Zooooo`0000?ooooooa0@4?ooool00_ooool0
0ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`1_ooooo`;o00000_ooool2o`0000;ooooo0_l00007ooooo`?o00001Oooool2o`0000;ooooo0_l0
0002ooooo`;o00001oooool2o`0000Wooooo0_l000000ooooooo0000o`00000Dooooo`Co00007?oo
ool2o`0006[ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8b
oiRHV?ooooooV9RHoc8b<P06ooooo`?o0000P?ooool2o`0000kooooo0_l00007ooooo`;o00001?oo
ool4o`0000Cooooo0_l00003ooooo`;o00003oooool2o`0008[ooooo00000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo00Wooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oo
oooooooo077ooooo0_l00002ooooo`;o0000:?ooool4o`000004ooooool0003o0000ooooo`?o0000
0_ooool2o`0000Cooooo0_l00009ooooo`;o0000R_ooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0
LOooool2o`0000;ooooo0_l00008ooooo`Co00001Oooool2o`0000kooooo0_l00003ooooo`Co0000
0oooool2o`0000;ooooo0_l00008ooooo`;o00000oooool3o`000003ooooool0003o000008cooooo
00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zjo`000006oooo
o`03o`000?oooooooooo05Gooooo0_l0000Nooooo`;o00002?ooool4o`0000Gooooo0_l0000:oooo
o`?o000000?oooooo`000?l000000oooool2o`0001Sooooo0ol000000ooooooo0000o`00002<oooo
o`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_oo
ool00ol0003oooooooooo`1Eooooo`;o00006?ooool2o`0002?ooooo0ol0002booooo`007?ooool0
0ol0003oooooooooo`1_ooooo`;o00001oooool2o`0004gooooo0_l00020ooooo`007?ooool00ol0
003oooooooooo`1hooooo`;o0000;_ooool2o`0001gooooo0_l00020ooooo`007?ooool00ol0003o
ooooooooo`2>ooooo`;o00003_ooool2o`0000Sooooo0_l0002Oooooo`007?ooool00ol0003ooooo
ooooo`21ooooo`?o00002_ooool2o`0000kooooo0_l00006ooooo`;o0000XOooool001cooooo00?o
0000ooooooooool0POooool3o`0000;ooooo0_l0000Hooooo`;o00001?ooool2o`0000oooooo0_l0
002@ooooo`007?ooool00ol0003oooooooooo`26ooooo`;o00001Oooool2o`00017ooooo0_l0000@
ooooo`;o00000oooool2o`00093ooooo000Looooo`03o`000?oooooooooo08gooooo0_l000000ooo
oooo0000o`00000:ooooo`?o00004oooool2o`0009Gooooo000Looooo`03o`000?oooooooooo063o
oooo0_l0000^ooooo`;o00001?ooool2o`0000Cooooo0ol0000=ooooo`;o0000Voooool001cooooo
00?o0000ooooooooool0H?ooool2o`0003Cooooo0_l0000<ooooo`;o00000_ooool2o`0000;ooooo
0_l0002Kooooo`007?ooool00ol0003oooooooooo`2Hooooo`;o00001?ooool2o`0000Cooooo0_l0
0002ooooo`;o0000Woooool001cooooo00?o0000ooooooooool0Toooool2o`0000?ooooo0_l00004
ooooo`;o0000ZOooool001cooooo0_l0002Dooooo`;o0000]?ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`1Wooooo`;o0000=_ooool2o`000:Sooooo
000Looooo`03o`000?oooooooooo06Oooooo0_l0000booooo`;o00000_ooool2o`000:Sooooo000L
ooooo`03o`000?oooooooooo09_ooooo0_l00003ooooo`;o00001oooool2o`0009kooooo000Loooo
o`03o`000?oooooooooo0:3ooooo0_l00007ooooo`;o0000W_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo06oooooo0_l0003Hooooo`007?ooool00ol0003oooooooooo`1_ooooo`;o0000f?ooool0
01cooooo00?o0000ooooooooool0M?ooool2o`000=?ooooo000Looooo`03o`000?oooooooooo07Co
oooo0_l000000ooooooo0000o`00003@ooooo`007?ooool00ol0003oooooooooo`1gooooo`;o0000
0oooool2o`000<_ooooo000Looooo`03o`000?oooooooooo07cooooo0_l0003;ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo0_l00024ooooo`;o0000a?ooool001cooooo00?o0000ooooooooool0Poooool2o`000<Cooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`004_ooool4o`000003
oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Ooo
ool3o`000?ooooooB_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0
003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo
00?o0000ooooooooool0oooooomBooooo`004_ooool00omEEEGoIVIVo`00003ooooooeCooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo002Uooooo`04oa0@4?l0003o0000ooooo`;o
000000?o410@ooooooooool05_ooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000onk^
k_ooool00oooool01Oo^k^ko<S8bo`000?l@413oc<c<093ooooo002Vooooo`05o`000?oooooooooo
ooooool000002Oooool6o`0000gooooo00?oMgMgoc8b<_ooool00oooool00omEEEGoZJVYooooo`03
ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40T?ooool00:Kooooo00Go0000ooooooooooooooooo`00
000Mooooo`03o`000?oooooooooo00;ooooo00?oZJVYoeEEEOooool00oooool01Ol0003ooooooooo
oooooooo0000093ooooo002Vooooo`05o`000?ooooooooooooooool000002Oooool6o`0000gooooo
00?oMgMgoc8b<_ooool01?ooool00olQ8B7oooooooooo`02ooooo`05o`000?nHV9SooooooiRHV?lQ
8B40T?ooool00:Kooooo00Go0000ohN7QoooooooZJVYo`00000Iooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00omEEEGoc<c<ooooo`02ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0T?ooool0
0:Gooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Gooooo`03o`000?oooooooooo
00Oooooo00?oZJVYogMgMoooool00_ooool00omEEEGoQhN7ooooo`2Booooo`00a?ooool00ol0003o
ooooooooo`04ooooo`05oa0@4?oooooooooooooooolb<S800oooool00ooMgMgo410@oiRHV02Boooo
o`00a?ooool4o`0000?ooooo1Ol00004ooooo`04olc<c?m4A4Co0000oa0@493ooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(582) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.49526 .66967 Mdot
.55058 .66954 Mdot
.50835 .31938 Mdot
.39711 .55348 Mdot
.40209 .27425 Mdot
.54033 .34407 Mdot
.6785 .42972 Mdot
.66036 .46914 Mdot
.55045 .343 Mdot
.29807 .69596 Mdot
.67516 .46171 Mdot
.4424 .49549 Mdot
.66899 .44256 Mdot
.36944 .53439 Mdot
.63136 .577 Mdot
.45309 .57868 Mdot
.55748 .70293 Mdot
.44493 .30979 Mdot
.45451 .57697 Mdot
.51423 .31984 Mdot
.43836 .44876 Mdot
.3806 .52952 Mdot
.55837 .6957 Mdot
.37299 .53228 Mdot
.40854 .57044 Mdot
.54437 .67864 Mdot
.49891 .66033 Mdot
.42713 .54177 Mdot
.41831 .51575 Mdot
.66406 .45973 Mdot
.46799 .20964 Mdot
.67029 .79212 Mdot
.43021 .49967 Mdot
.46287 .72308 Mdot
.66637 .47336 Mdot
.74664 .33001 Mdot
.56652 .34994 Mdot
.65049 .45907 Mdot
.69019 .46902 Mdot
.69373 .46918 Mdot
.66941 .42484 Mdot
.53877 .67065 Mdot
.70825 .42595 Mdot
.50228 .37912 Mdot
.35415 .56461 Mdot
.64029 .75744 Mdot
.48656 .18489 Mdot
.42493 .53586 Mdot
.50313 .69301 Mdot
.51316 .32934 Mdot
.20652 .46451 Mdot
.64006 .43945 Mdot
.63347 .63172 Mdot
.18338 .71003 Mdot
.66884 .45588 Mdot
.41034 .5436 Mdot
.52913 .32638 Mdot
.38566 .54887 Mdot
.40694 .52178 Mdot
.44473 .67835 Mdot
.39008 .51158 Mdot
.40347 .31401 Mdot
.50202 .64657 Mdot
.54873 .30937 Mdot
.54552 .33912 Mdot
.65058 .43427 Mdot
.54848 .65261 Mdot
.66113 .43695 Mdot
.33289 .49826 Mdot
.50668 .33099 Mdot
.42125 .5347 Mdot
.66924 .4638 Mdot
.5576 .66877 Mdot
.37235 .58137 Mdot
.67138 .70463 Mdot
.62219 .40675 Mdot
.46447 .33365 Mdot
.45266 .78301 Mdot
.18397 .56494 Mdot
.59343 .28362 Mdot
.35929 .52892 Mdot
.15246 .52294 Mdot
.63804 .56393 Mdot
.54276 .65746 Mdot
.4809 .7043 Mdot
.81001 .51742 Mdot
.42572 .52222 Mdot
.42611 .40693 Mdot
.44293 .54423 Mdot
.53989 .54851 Mdot
.55314 .33931 Mdot
.55121 .68852 Mdot
.3536 .56528 Mdot
.42714 .57051 Mdot
.2967 .63215 Mdot
.36162 .49004 Mdot
.37055 .56518 Mdot
.48365 .69546 Mdot
.69047 .44979 Mdot
.32886 .48312 Mdot
.46248 .29363 Mdot
.66358 .63241 Mdot
.39222 .56436 Mdot
.53759 .36397 Mdot
.48889 .66332 Mdot
.36632 .57032 Mdot
.65245 .4449 Mdot
.37261 .52238 Mdot
.633 .46047 Mdot
.54221 .70771 Mdot
.43363 .56249 Mdot
.39824 .29555 Mdot
.58067 .59354 Mdot
.5105 .68909 Mdot
.34314 .77387 Mdot
.38898 .51396 Mdot
.39463 .52416 Mdot
.54249 .66052 Mdot
.54302 .31772 Mdot
.47626 .42924 Mdot
.562 .68835 Mdot
.69454 .46656 Mdot
.52593 .71147 Mdot
.42993 .57716 Mdot
.53861 .31604 Mdot
.67278 .64169 Mdot
.66074 .62813 Mdot
.35037 .27306 Mdot
.37885 .58422 Mdot
.60933 .63056 Mdot
.53073 .35273 Mdot
.54215 .66756 Mdot
.65983 .442 Mdot
.39234 .49956 Mdot
.51209 .66962 Mdot
.69394 .46274 Mdot
.39824 .3337 Mdot
.39498 .27329 Mdot
.50499 .6663 Mdot
.26833 .5101 Mdot
.63618 .44714 Mdot
.70167 .46193 Mdot
.21431 .45559 Mdot
.5367 .65496 Mdot
.42495 .3264 Mdot
.70545 .44201 Mdot
.31127 .38079 Mdot
.37116 .50205 Mdot
.26481 .35283 Mdot
.15082 .4547 Mdot
.20987 .4604 Mdot
.56057 .79499 Mdot
.41805 .29581 Mdot
.70636 .43876 Mdot
.41369 .55249 Mdot
.52158 .67257 Mdot
.52337 .66567 Mdot
.41281 .58207 Mdot
.41465 .57338 Mdot
.35533 .54724 Mdot
.39223 .50196 Mdot
.66355 .23347 Mdot
.35187 .54005 Mdot
.64993 .5237 Mdot
.5114 .67694 Mdot
.39872 .5793 Mdot
.54614 .37131 Mdot
.34682 .57813 Mdot
.65165 .45989 Mdot
.40751 .52827 Mdot
.41612 .56903 Mdot
.33319 .53349 Mdot
.70877 .43309 Mdot
.73939 .6617 Mdot
.20813 .63174 Mdot
.76221 .39448 Mdot
.61743 .69244 Mdot
.5244 .34348 Mdot
.35602 .51907 Mdot
.4271 .30808 Mdot
.40532 .4611 Mdot
.4015 .5186 Mdot
.1979 .47562 Mdot
.43005 .55578 Mdot
.50376 .79228 Mdot
.29817 .51101 Mdot
.81935 .49029 Mdot
.68806 .53076 Mdot
.39726 .509 Mdot
.26532 .6461 Mdot
.28493 .32177 Mdot
.4167 .21328 Mdot
.66027 .45134 Mdot
.55412 .37428 Mdot
.55542 .32759 Mdot
.69945 .46782 Mdot
.30252 .52259 Mdot
.3105 .71172 Mdot
.32472 .50668 Mdot
.67089 .64311 Mdot
.54716 .63778 Mdot
.42748 .29726 Mdot
.5038 .66709 Mdot
.15094 .5593 Mdot
.44587 .43307 Mdot
.61023 .3673 Mdot
.44402 .30387 Mdot
.50812 .35493 Mdot
.66266 .65215 Mdot
.43112 .31717 Mdot
.38102 .56 Mdot
.5252 .70808 Mdot
.28173 .32347 Mdot
.41877 .60179 Mdot
.75506 .25813 Mdot
.53878 .65075 Mdot
.56378 .51332 Mdot
.66454 .45086 Mdot
.5588 .31885 Mdot
.42622 .52369 Mdot
.37021 .54942 Mdot
.49958 .65043 Mdot
.42376 .52952 Mdot
.49037 .47849 Mdot
.422 .56277 Mdot
.58176 .35027 Mdot
.4235 .35313 Mdot
.64616 .48155 Mdot
.34595 .28397 Mdot
.56195 .67722 Mdot
.60327 .48934 Mdot
.54055 .36754 Mdot
.48497 .61246 Mdot
.6591 .46038 Mdot
.3931 .32699 Mdot
.56387 .36281 Mdot
.38316 .31265 Mdot
.35087 .56978 Mdot
.56285 .34593 Mdot
.40356 .32683 Mdot
.60561 .40533 Mdot
.37137 .56629 Mdot
.27326 .3766 Mdot
.69874 .43151 Mdot
.49952 .66322 Mdot
.39455 .5108 Mdot
.67825 .63951 Mdot
.38418 .59441 Mdot
.60715 .60859 Mdot
.67562 .65241 Mdot
.63676 .64504 Mdot
.6117 .34319 Mdot
.43098 .32764 Mdot
.63135 .72607 Mdot
.50256 .44054 Mdot
.55901 .70123 Mdot
.34288 .55323 Mdot
.78102 .63912 Mdot
.69892 .42966 Mdot
.38414 .55762 Mdot
.80587 .49936 Mdot
.70536 .44001 Mdot
.39059 .54068 Mdot
.67371 .42288 Mdot
.52047 .668 Mdot
.57862 .44724 Mdot
.52708 .71591 Mdot
.39789 .55024 Mdot
.68992 .43763 Mdot
.56125 .37228 Mdot
.54356 .67898 Mdot
.37864 .52117 Mdot
.3553 .53028 Mdot
.66684 .64654 Mdot
.39621 .58303 Mdot
.80655 .60783 Mdot
.42468 .53836 Mdot
.50611 .35258 Mdot
.36832 .48833 Mdot
.26423 .33435 Mdot
.38788 .27267 Mdot
.55093 .65003 Mdot
.66911 .6546 Mdot
.55018 .33199 Mdot
.58874 .41702 Mdot
.36951 .26796 Mdot
.36549 .52753 Mdot
.65297 .63631 Mdot
.56711 .50912 Mdot
.64866 .44031 Mdot
.42026 .50333 Mdot
.48393 .45241 Mdot
.55799 .35259 Mdot
.66831 .64876 Mdot
.31863 .57368 Mdot
.49649 .68955 Mdot
.41153 .54535 Mdot
.56742 .35778 Mdot
.50037 .69324 Mdot
.39751 .49929 Mdot
.58796 .21103 Mdot
.67431 .63556 Mdot
.69218 .4282 Mdot
.36163 .62648 Mdot
.34759 .53792 Mdot
.55828 .32834 Mdot
.51456 .66509 Mdot
.67934 .4519 Mdot
.53134 .70454 Mdot
.30543 .29392 Mdot
.60791 .65562 Mdot
.6686 .26874 Mdot
.44161 .32713 Mdot
.52819 .83755 Mdot
.7602 .37709 Mdot
.59051 .63571 Mdot
.40922 .36717 Mdot
.80831 .41043 Mdot
.55497 .36722 Mdot
.25303 .57173 Mdot
.54139 .32588 Mdot
.40316 .5583 Mdot
.54287 .34328 Mdot
.82624 .5832 Mdot
.42904 .54905 Mdot
.52283 .33753 Mdot
.64559 .23899 Mdot
.43318 .55268 Mdot
.50895 .67739 Mdot
.67672 .76684 Mdot
.38151 .79486 Mdot
.30964 .459 Mdot
.52135 .33429 Mdot
.24673 .58918 Mdot
.4285 .53412 Mdot
.44002 .59693 Mdot
.52753 .6763 Mdot
.44195 .56519 Mdot
.41487 .2911 Mdot
.38751 .30241 Mdot
.22152 .47125 Mdot
.42107 .81455 Mdot
.39757 .6181 Mdot
.53767 .67431 Mdot
.17926 .55204 Mdot
.67347 .70673 Mdot
.66538 .62754 Mdot
.68035 .47307 Mdot
.73703 .65949 Mdot
.32636 .58612 Mdot
.27457 .55905 Mdot
.51344 .49321 Mdot
.55358 .68798 Mdot
.71446 .33467 Mdot
.68174 .44633 Mdot
.24449 .64319 Mdot
.34843 .71897 Mdot
.35556 .55166 Mdot
.66379 .41747 Mdot
.36571 .4735 Mdot
.50471 .48969 Mdot
.26725 .36993 Mdot
.60128 .26336 Mdot
.38563 .56066 Mdot
.6385 .72623 Mdot
.40137 .52245 Mdot
.2839 .32997 Mdot
.39239 .55257 Mdot
.52566 .70231 Mdot
.31938 .59264 Mdot
.50399 .41889 Mdot
.25239 .68979 Mdot
.45074 .43697 Mdot
.43612 .31587 Mdot
.36913 .53773 Mdot
.36288 .55354 Mdot
.39965 .31823 Mdot
.54375 .69278 Mdot
.34123 .53811 Mdot
.49378 .18136 Mdot
.35026 .54424 Mdot
.64136 .44132 Mdot
.56246 .44026 Mdot
.50303 .80172 Mdot
.43601 .54311 Mdot
.49379 .68215 Mdot
.65321 .43599 Mdot
.67894 .46953 Mdot
.37101 .61451 Mdot
.69597 .42647 Mdot
.41788 .5458 Mdot
.56414 .44264 Mdot
.5553 .7003 Mdot
.39595 .46502 Mdot
.53898 .69471 Mdot
.17957 .49872 Mdot
.70362 .42657 Mdot
.64425 .63851 Mdot
.24879 .55931 Mdot
.67995 .43572 Mdot
.48253 .5576 Mdot
.29992 .56226 Mdot
.32421 .56195 Mdot
.59178 .64848 Mdot
.57197 .36487 Mdot
.64373 .64594 Mdot
.67257 .4563 Mdot
.35139 .54314 Mdot
.3744 .57177 Mdot
.64968 .42457 Mdot
.39615 .65529 Mdot
.47403 .21047 Mdot
.40078 .54587 Mdot
.53271 .70209 Mdot
.54167 .66878 Mdot
.35572 .50643 Mdot
.39867 .51676 Mdot
.51965 .3672 Mdot
.6513 .63628 Mdot
.649 .65233 Mdot
.65386 .62945 Mdot
.5749 .37443 Mdot
.49878 .8412 Mdot
.7021 .46133 Mdot
.58742 .80529 Mdot
.78529 .56575 Mdot
.39737 .61397 Mdot
.56755 .34443 Mdot
.38042 .54347 Mdot
.38827 .56938 Mdot
.69065 .44144 Mdot
.39842 .81958 Mdot
.41692 .48592 Mdot
.50643 .65463 Mdot
.64324 .43439 Mdot
.42851 .47682 Mdot
.63176 .40612 Mdot
.39498 .30393 Mdot
.41619 .43167 Mdot
.66258 .417 Mdot
.5333 .70724 Mdot
.65643 .41893 Mdot
.35988 .55201 Mdot
.31908 .56312 Mdot
.55601 .6855 Mdot
.42096 .33901 Mdot
.35058 .56632 Mdot
.39261 .5388 Mdot
.30245 .25605 Mdot
.66731 .7073 Mdot
.5801 .30544 Mdot
.40285 .56716 Mdot
.32493 .53584 Mdot
.41328 .34351 Mdot
.34495 .5376 Mdot
.41516 .51186 Mdot
.57794 .5872 Mdot
.64861 .48101 Mdot
.42591 .2843 Mdot
.24049 .65183 Mdot
.53078 .64879 Mdot
.81251 .58505 Mdot
.66731 .63367 Mdot
.6344 .47008 Mdot
.58078 .45215 Mdot
.65026 .64751 Mdot
.79385 .50373 Mdot
.76321 .4109 Mdot
.64652 .64052 Mdot
.5275 .30338 Mdot
.37039 .45193 Mdot
.40972 .50382 Mdot
.40393 .53245 Mdot
.42666 .33096 Mdot
.52414 .65469 Mdot
.66062 .53015 Mdot
.66797 .48898 Mdot
.38624 .52705 Mdot
.54717 .72132 Mdot
.81476 .50318 Mdot
.66267 .65043 Mdot
.42065 .30106 Mdot
.43737 .32478 Mdot
.39954 .52385 Mdot
.53252 .58536 Mdot
.54064 .67487 Mdot
.37868 .52128 Mdot
.37309 .50524 Mdot
.53242 .32019 Mdot
.51822 .70425 Mdot
.536 .36816 Mdot
.67689 .65354 Mdot
.79313 .3468 Mdot
.32366 .23111 Mdot
.70001 .44162 Mdot
.74371 .3644 Mdot
.67245 .40884 Mdot
.61757 .27619 Mdot
.64869 .63701 Mdot
.38044 .52439 Mdot
.56387 .67355 Mdot
.37475 .52125 Mdot
.3497 .55255 Mdot
.3583 .56246 Mdot
.40555 .61796 Mdot
.19908 .46697 Mdot
.41669 .30621 Mdot
.34823 .49021 Mdot
.52101 .372 Mdot
.8155 .49113 Mdot
.70719 .72844 Mdot
.36599 .54381 Mdot
.39428 .52647 Mdot
.53574 .64643 Mdot
.35402 .574 Mdot
.65194 .44982 Mdot
.53816 .65285 Mdot
.38528 .56658 Mdot
.41624 .26237 Mdot
.34395 .52682 Mdot
.74644 .35786 Mdot
.65742 .41814 Mdot
.40576 .43298 Mdot
.3185 .53937 Mdot
.64614 .63813 Mdot
.64412 .64555 Mdot
.6814 .64123 Mdot
.65288 .42626 Mdot
.53563 .32032 Mdot
.49074 .33842 Mdot
.31285 .56529 Mdot
.41616 .55178 Mdot
.31973 .55559 Mdot
.56963 .38503 Mdot
.49776 .42957 Mdot
.59324 .75875 Mdot
.29505 .51673 Mdot
.55478 .38051 Mdot
.51787 .72644 Mdot
.28202 .73187 Mdot
.52608 .65115 Mdot
.45459 .34273 Mdot
.65781 .46293 Mdot
.40693 .29271 Mdot
.20292 .516 Mdot
.5553 .69704 Mdot
.50149 .65102 Mdot
.52271 .34122 Mdot
.59526 .53294 Mdot
.28616 .82492 Mdot
.53572 .36002 Mdot
.40702 .3617 Mdot
.53218 .67693 Mdot
.42693 .49335 Mdot
.57024 .50876 Mdot
.58117 .53903 Mdot
.53087 .33297 Mdot
.35741 .52817 Mdot
.48787 .55814 Mdot
.51899 .36637 Mdot
.41472 .49767 Mdot
.51894 .33658 Mdot
.6899 .42265 Mdot
.52655 .35229 Mdot
.57247 .69856 Mdot
.35784 .57254 Mdot
.20753 .74314 Mdot
.63442 .55725 Mdot
.38071 .5143 Mdot
.64285 .43273 Mdot
.62081 .21049 Mdot
.36371 .55839 Mdot
.42362 .29126 Mdot
.55452 .38283 Mdot
.58557 .23578 Mdot
.41685 .51748 Mdot
.53669 .33759 Mdot
.57655 .67742 Mdot
.47615 .32387 Mdot
.55689 .28326 Mdot
.64572 .64982 Mdot
.51788 .66954 Mdot
.62922 .65169 Mdot
.66752 .47461 Mdot
.33647 .55154 Mdot
.35844 .51225 Mdot
.51501 .68891 Mdot
.64403 .394 Mdot
.38386 .48358 Mdot
.3594 .52919 Mdot
.52038 .36527 Mdot
.53489 .38316 Mdot
.65986 .58869 Mdot
.55199 .36969 Mdot
.32583 .5324 Mdot
.51563 .69201 Mdot
.40433 .55347 Mdot
.50818 .66997 Mdot
.34415 .5563 Mdot
.59355 .72799 Mdot
.52459 .65225 Mdot
.54637 .61443 Mdot
.40006 .58455 Mdot
.43697 .62748 Mdot
.34666 .54841 Mdot
.37602 .5632 Mdot
.55994 .38464 Mdot
.41782 .31808 Mdot
.43403 .51331 Mdot
.59791 .47087 Mdot
.39665 .34055 Mdot
.50379 .75866 Mdot
.54299 .31825 Mdot
.40942 .33944 Mdot
.27337 .4165 Mdot
.66875 .65458 Mdot
.40723 .30935 Mdot
.69135 .61526 Mdot
.69866 .43987 Mdot
.54703 .71165 Mdot
.42964 .56102 Mdot
.81263 .39959 Mdot
.46808 .21008 Mdot
.66294 .6455 Mdot
.39453 .51243 Mdot
.37916 .54784 Mdot
.5025 .69918 Mdot
.15232 .54282 Mdot
.57246 .33074 Mdot
.38639 .56252 Mdot
.56071 .68786 Mdot
.15482 .48823 Mdot
.51632 .34243 Mdot
.40935 .30297 Mdot
.67784 .4121 Mdot
.56101 .63962 Mdot
.64122 .64611 Mdot
.70361 .42587 Mdot
.59004 .34072 Mdot
.1893 .48944 Mdot
.41661 .51855 Mdot
.57038 .36315 Mdot
.20901 .46128 Mdot
.30745 .50012 Mdot
.7025 .41014 Mdot
.58846 .72672 Mdot
.55288 .68639 Mdot
.64754 .42728 Mdot
.43721 .3158 Mdot
.55215 .70582 Mdot
.54442 .69367 Mdot
.66224 .46956 Mdot
.7151 .50885 Mdot
.5671 .51558 Mdot
.64666 .4512 Mdot
.57423 .56239 Mdot
.21845 .45027 Mdot
.65327 .63328 Mdot
.42126 .30082 Mdot
.30866 .28082 Mdot
.54124 .67295 Mdot
.73777 .65947 Mdot
.20103 .47166 Mdot
.37115 .56509 Mdot
.41242 .33127 Mdot
.80227 .5255 Mdot
.65819 .49044 Mdot
.69679 .45925 Mdot
.45092 .41218 Mdot
.43343 .30071 Mdot
.35959 .5077 Mdot
.49148 .80338 Mdot
.4276 .56663 Mdot
.7044 .43504 Mdot
.50602 .49998 Mdot
.5159 .70175 Mdot
.66864 .47577 Mdot
.48463 .46965 Mdot
.3911 .56886 Mdot
.38152 .5091 Mdot
.32103 .30911 Mdot
.51697 .70491 Mdot
.63909 .64445 Mdot
.36598 .52298 Mdot
.38849 .54716 Mdot
.33531 .53936 Mdot
.24574 .54577 Mdot
.56289 .60309 Mdot
.38219 .5654 Mdot
.57243 .33863 Mdot
.33084 .56973 Mdot
.39973 .50764 Mdot
.51451 .71278 Mdot
.24598 .35318 Mdot
.67872 .65274 Mdot
.40233 .53585 Mdot
.4009 .54515 Mdot
.68697 .47217 Mdot
.56747 .51253 Mdot
.58088 .54213 Mdot
.50752 .34595 Mdot
.39433 .37745 Mdot
.31879 .51698 Mdot
.51477 .67539 Mdot
.40888 .28994 Mdot
.32943 .53894 Mdot
.52145 .64952 Mdot
.30572 .53276 Mdot
.51535 .36551 Mdot
.65239 .63842 Mdot
.28758 .57169 Mdot
.40709 .3148 Mdot
.63587 .45753 Mdot
.61655 .80071 Mdot
.54365 .37331 Mdot
.41582 .55999 Mdot
.50797 .37729 Mdot
.5484 .35969 Mdot
.66668 .64425 Mdot
.37793 .60064 Mdot
.52595 .66799 Mdot
.5223 .70452 Mdot
.23581 .41363 Mdot
.58138 .36605 Mdot
.21108 .34038 Mdot
.69131 .42304 Mdot
.42172 .50714 Mdot
.70578 .71315 Mdot
.5138 .69837 Mdot
.31277 .29663 Mdot
.41059 .34003 Mdot
.69676 .45902 Mdot
.65427 .65722 Mdot
.51816 .65181 Mdot
.50541 .68796 Mdot
.35273 .56299 Mdot
.37421 .53936 Mdot
.39486 .3649 Mdot
.27481 .33837 Mdot
.67423 .42315 Mdot
.40818 .2999 Mdot
.50829 .33817 Mdot
.39903 .56542 Mdot
.5527 .67033 Mdot
.48753 .79489 Mdot
.34857 .53451 Mdot
.51459 .36325 Mdot
.55237 .67968 Mdot
.39928 .30816 Mdot
.4014 .33246 Mdot
.37212 .56421 Mdot
.47176 .76491 Mdot
.67784 .43358 Mdot
.51032 .68495 Mdot
.47539 .67903 Mdot
.36682 .48699 Mdot
.36914 .5409 Mdot
.42365 .48064 Mdot
.71279 .43708 Mdot
.28502 .56623 Mdot
.42202 .34382 Mdot
.52548 .66009 Mdot
.37499 .51754 Mdot
.4035 .31352 Mdot
.27354 .57474 Mdot
.65125 .64439 Mdot
.5181 .34154 Mdot
.42146 .29168 Mdot
.41311 .32585 Mdot
.39222 .33477 Mdot
.73176 .66382 Mdot
.48786 .6661 Mdot
.22973 .64736 Mdot
.34993 .5585 Mdot
.22212 .44604 Mdot
.37158 .58628 Mdot
.67503 .41998 Mdot
.55888 .37492 Mdot
.35145 .55168 Mdot
.35098 .56197 Mdot
.52231 .79324 Mdot
.46584 .52759 Mdot
.4324 .44967 Mdot
.53399 .70939 Mdot
.35707 .62914 Mdot
.56243 .33257 Mdot
.1434 .44288 Mdot
.73898 .72577 Mdot
.32759 .50507 Mdot
.59486 .52692 Mdot
.53968 .65408 Mdot
.70325 .45247 Mdot
.56931 .53908 Mdot
.62714 .46756 Mdot
.53175 .65906 Mdot
.39983 .56193 Mdot
.59276 .79964 Mdot
.38467 .32074 Mdot
.35666 .54683 Mdot
.6572 .4432 Mdot
.35602 .54701 Mdot
.65959 .42327 Mdot
.53052 .62707 Mdot
.59697 .55044 Mdot
.43048 .55362 Mdot
.35386 .49118 Mdot
.28184 .54057 Mdot
.36861 .54307 Mdot
.64583 .3515 Mdot
.53769 .68755 Mdot
.52595 .61112 Mdot
.35129 .5077 Mdot
.44265 .75534 Mdot
.34976 .51931 Mdot
.66451 .39229 Mdot
.3643 .51041 Mdot
.30233 .45278 Mdot
.36466 .50469 Mdot
.35758 .51738 Mdot
.68513 .44474 Mdot
.69406 .46596 Mdot
.57418 .66965 Mdot
.63912 .64002 Mdot
.81853 .49009 Mdot
.39338 .53302 Mdot
.55666 .3867 Mdot
.67608 .61613 Mdot
.4168 .32295 Mdot
.53204 .66168 Mdot
.18813 .32388 Mdot
.65936 .42931 Mdot
.54605 .3081 Mdot
.61526 .32272 Mdot
.54654 .31259 Mdot
.5856 .37882 Mdot
.45278 .62282 Mdot
.41334 .29688 Mdot
.35551 .51188 Mdot
.47189 .74314 Mdot
.65112 .72042 Mdot
.39871 .49362 Mdot
.49161 .35012 Mdot
.44606 .48786 Mdot
.21733 .44588 Mdot
.38059 .3201 Mdot
.42492 .29766 Mdot
.67611 .45322 Mdot
.5178 .31462 Mdot
.32131 .49054 Mdot
.40756 .33918 Mdot
.55232 .37532 Mdot
.64996 .62692 Mdot
.35687 .30541 Mdot
.5373 .67115 Mdot
.29791 .47387 Mdot
.67187 .74036 Mdot
.66516 .42628 Mdot
.59378 .46352 Mdot
.49241 .69844 Mdot
.51527 .63313 Mdot
.64337 .63475 Mdot
.52798 .37644 Mdot
.55833 .70377 Mdot
.35504 .56898 Mdot
.41716 .6021 Mdot
.39936 .52176 Mdot
.41646 .33561 Mdot
.38196 .50494 Mdot
.53195 .37606 Mdot
.67419 .4275 Mdot
.55512 .34235 Mdot
.68122 .43121 Mdot
.58796 .78737 Mdot
.4041 .51619 Mdot
.37146 .53797 Mdot
.56828 .45643 Mdot
.50281 .67512 Mdot
.44768 .69873 Mdot
.52768 .37701 Mdot
.53297 .3246 Mdot
.40176 .55564 Mdot
.54318 .64343 Mdot
.44502 .29886 Mdot
.57974 .50818 Mdot
.36693 .5081 Mdot
.5366 .68776 Mdot
.40737 .54887 Mdot
.61403 .25449 Mdot
.61432 .56452 Mdot
.52731 .70461 Mdot
.25579 .69697 Mdot
.39144 .58441 Mdot
.4578 .4969 Mdot
.45763 .5528 Mdot
.37245 .40155 Mdot
.42196 .49919 Mdot
.54208 .65274 Mdot
.40817 .52544 Mdot
.51842 .6772 Mdot
.5501 .36368 Mdot
.70629 .45427 Mdot
.52165 .67576 Mdot
.42056 .57465 Mdot
.717 .74564 Mdot
.65928 .43271 Mdot
.35978 .53716 Mdot
.6759 .45934 Mdot
.54443 .71553 Mdot
.49983 .68103 Mdot
.683 .5996 Mdot
.60943 .35364 Mdot
.65525 .43805 Mdot
.41797 .54864 Mdot
.70083 .68504 Mdot
.40512 .55296 Mdot
.38084 .36218 Mdot
.36552 .49806 Mdot
.37601 .48798 Mdot
.54309 .83692 Mdot
.61079 .40681 Mdot
.19781 .33957 Mdot
.71252 .47432 Mdot
.72734 .67198 Mdot
.48585 .63556 Mdot
.38049 .31922 Mdot
.7378 .36722 Mdot
.67762 .64942 Mdot
.56918 .33538 Mdot
.35072 .55057 Mdot
.5623 .77188 Mdot
.64338 .44303 Mdot
.42141 .31529 Mdot
.43003 .55526 Mdot
.49892 .32825 Mdot
.70226 .6375 Mdot
.70642 .442 Mdot
.53727 .6692 Mdot
.50254 .66842 Mdot
.18903 .58544 Mdot
.37969 .51608 Mdot
.37817 .53352 Mdot
.65373 .46079 Mdot
.3124 .49988 Mdot
.38849 .32358 Mdot
.64877 .25256 Mdot
.65751 .44762 Mdot
.62703 .56691 Mdot
.53832 .70919 Mdot
.37939 .54621 Mdot
.5606 .43874 Mdot
.7477 .60615 Mdot
.29291 .65949 Mdot
.43128 .32236 Mdot
.34443 .34597 Mdot
.54172 .65244 Mdot
.65959 .44419 Mdot
.23538 .45176 Mdot
.42501 .57609 Mdot
.38098 .5487 Mdot
.33566 .33339 Mdot
.57886 .51403 Mdot
.36538 .31947 Mdot
.44641 .51397 Mdot
.5566 .49258 Mdot
.40011 .55747 Mdot
.37489 .57184 Mdot
.33017 .50008 Mdot
.40403 .50684 Mdot
.53043 .6865 Mdot
.40057 .79664 Mdot
.53576 .34658 Mdot
.26341 .619 Mdot
.44383 .4032 Mdot
.42917 .53111 Mdot
.39549 .56528 Mdot
.34658 .76049 Mdot
.63746 .61556 Mdot
.53856 .68378 Mdot
.47476 .67136 Mdot
.69828 .46628 Mdot
.46606 .53077 Mdot
.57963 .37104 Mdot
.42695 .45248 Mdot
.55089 .35037 Mdot
.53586 .68866 Mdot
.54215 .32103 Mdot
.66898 .48241 Mdot
.57018 .36328 Mdot
.57747 .36961 Mdot
.70019 .42051 Mdot
.51065 .70261 Mdot
.35277 .52251 Mdot
.69998 .4244 Mdot
.32529 .2967 Mdot
.41543 .33582 Mdot
.68215 .60115 Mdot
.42538 .49166 Mdot
.45812 .49412 Mdot
.58614 .21089 Mdot
.55784 .33711 Mdot
.59591 .59213 Mdot
.52408 .65248 Mdot
.42529 .28841 Mdot
.5257 .68415 Mdot
.21923 .54984 Mdot
.40493 .3223 Mdot
.68387 .60332 Mdot
.24429 .43704 Mdot
.60539 .4423 Mdot
.37742 .59349 Mdot
.56577 .62984 Mdot
.55293 .35174 Mdot
.641 .44037 Mdot
.80554 .51179 Mdot
.38063 .58218 Mdot
.61675 .65915 Mdot
.49561 .63821 Mdot
.66303 .65486 Mdot
.66057 .44051 Mdot
.73443 .45145 Mdot
.38468 .51558 Mdot
.60115 .43553 Mdot
.38036 .49094 Mdot
.24903 .56373 Mdot
.3913 .37189 Mdot
.59228 .70521 Mdot
.41322 .54436 Mdot
.51382 .35857 Mdot
.41032 .54785 Mdot
.31101 .4751 Mdot
.21519 .46144 Mdot
.34183 .49796 Mdot
.59717 .64763 Mdot
.58598 .22892 Mdot
.55476 .67907 Mdot
.3279 .52332 Mdot
.65986 .63722 Mdot
.39818 .57404 Mdot
.84517 .39235 Mdot
.40972 .31088 Mdot
.58152 .3182 Mdot
.41248 .58081 Mdot
.36964 .52241 Mdot
.4893 .77927 Mdot
.51949 .61656 Mdot
.66376 .65782 Mdot
.37907 .55361 Mdot
.34972 .36284 Mdot
.6821 .45047 Mdot
.3946 .49848 Mdot
.4056 .52725 Mdot
.344 .23715 Mdot
.68305 .45205 Mdot
.56163 .33902 Mdot
.672 .65382 Mdot
.50932 .34378 Mdot
.38254 .30324 Mdot
.55402 .54391 Mdot
.30041 .31003 Mdot
.61479 .56695 Mdot
.43298 .2962 Mdot
.42811 .52299 Mdot
.49193 .71773 Mdot
.36951 .51509 Mdot
.42909 .3019 Mdot
.6644 .45998 Mdot
.53028 .6838 Mdot
.27678 .49688 Mdot
.67005 .64237 Mdot
.39889 .49215 Mdot
.38268 .33162 Mdot
.52365 .67219 Mdot
.70699 .57888 Mdot
.53176 .6555 Mdot
.68277 .43755 Mdot
.68816 .47558 Mdot
.41053 .32085 Mdot
.52793 .68613 Mdot
.51766 .33047 Mdot
.71817 .46944 Mdot
.3698 .49515 Mdot
.68937 .48172 Mdot
.57102 .674 Mdot
.49979 .65807 Mdot
.56239 .6657 Mdot
.40825 .51568 Mdot
.58405 .52008 Mdot
.39963 .59018 Mdot
.6516 .44087 Mdot
.54906 .31781 Mdot
.26023 .36268 Mdot
.46705 .74387 Mdot
.62712 .56465 Mdot
.432 .50961 Mdot
.38853 .5071 Mdot
.39916 .5238 Mdot
.40892 .54126 Mdot
.65212 .25783 Mdot
.40447 .51696 Mdot
.68923 .43422 Mdot
.54409 .3551 Mdot
.39087 .51214 Mdot
.65689 .63632 Mdot
.49877 .43673 Mdot
.41036 .28992 Mdot
.33012 .43073 Mdot
.74017 .70096 Mdot
.52498 .6738 Mdot
.56433 .36705 Mdot
.5329 .31778 Mdot
.39804 .33353 Mdot
.70281 .42819 Mdot
.52433 .6555 Mdot
.31738 .42369 Mdot
.39418 .34036 Mdot
.40173 .5369 Mdot
.56578 .44669 Mdot
.26691 .7122 Mdot
.43474 .53448 Mdot
.36422 .56271 Mdot
.64115 .64961 Mdot
.55374 .31343 Mdot
.84706 .4486 Mdot
.69393 .522 Mdot
.41592 .31877 Mdot
.39756 .30538 Mdot
.55729 .66319 Mdot
.41645 .50178 Mdot
.67459 .43213 Mdot
.56259 .50122 Mdot
.58791 .2011 Mdot
.81492 .55142 Mdot
.61863 .28018 Mdot
.34329 .52906 Mdot
.41076 .78232 Mdot
.33838 .5201 Mdot
.48875 .66388 Mdot
.55321 .65431 Mdot
.53863 .67891 Mdot
.68337 .44544 Mdot
.18292 .50304 Mdot
.68982 .43266 Mdot
.74108 .70239 Mdot
.55906 .68497 Mdot
.55033 .417 Mdot
.5274 .32698 Mdot
.34613 .59104 Mdot
.41558 .29723 Mdot
.48174 .30894 Mdot
.32451 .53031 Mdot
.52854 .58865 Mdot
.56744 .34432 Mdot
.49786 .68151 Mdot
.2992 .55626 Mdot
.81929 .476 Mdot
.5975 .53629 Mdot
.50666 .18867 Mdot
.32586 .6306 Mdot
.40035 .31877 Mdot
.28007 .67642 Mdot
.38723 .32504 Mdot
.70139 .453 Mdot
.38014 .58303 Mdot
.39762 .58677 Mdot
.38876 .5596 Mdot
.41084 .51882 Mdot
.67206 .45707 Mdot
.34606 .50917 Mdot
.26257 .33687 Mdot
.66726 .63128 Mdot
.53803 .41158 Mdot
.3964 .32503 Mdot
.67714 .41761 Mdot
.54607 .35838 Mdot
.63997 .63674 Mdot
.34419 .28318 Mdot
.34188 .51958 Mdot
.34798 .54891 Mdot
.66009 .62732 Mdot
.30766 .50991 Mdot
.3275 .5863 Mdot
.53776 .34259 Mdot
.50843 .47494 Mdot
.43873 .31763 Mdot
.40511 .29375 Mdot
.65689 .41945 Mdot
.52574 .68444 Mdot
.42105 .33639 Mdot
.51225 .31684 Mdot
.40062 .49986 Mdot
.35176 .49153 Mdot
.57133 .67443 Mdot
.20099 .4713 Mdot
.39147 .29444 Mdot
.28786 .53007 Mdot
.51417 .66146 Mdot
.49075 .64263 Mdot
.37678 .55433 Mdot
.44972 .54611 Mdot
.4935 .65932 Mdot
.39234 .3175 Mdot
.67892 .41665 Mdot
.57237 .4226 Mdot
.68659 .42539 Mdot
.51843 .66376 Mdot
.34893 .58703 Mdot
.5231 .70916 Mdot
.39342 .58293 Mdot
.10658 .50373 Mdot
.39307 .5052 Mdot
.48213 .60506 Mdot
.39497 .39275 Mdot
.5173 .33854 Mdot
.51416 .34335 Mdot
.654 .63756 Mdot
.52582 .64981 Mdot
.32912 .54703 Mdot
.40639 .29694 Mdot
.72344 .67438 Mdot
.57442 .72071 Mdot
.56945 .37643 Mdot
.57444 .33658 Mdot
.66507 .45914 Mdot
.3563 .51247 Mdot
.38276 .54115 Mdot
.57051 .35818 Mdot
.62978 .21876 Mdot
.51951 .68448 Mdot
.37805 .53332 Mdot
.40223 .50769 Mdot
.53727 .34941 Mdot
.72452 .46714 Mdot
.48013 .65503 Mdot
.40196 .50665 Mdot
.25277 .41963 Mdot
.65916 .42513 Mdot
.4239 .54353 Mdot
.34174 .51545 Mdot
.4205 .32494 Mdot
.39927 .2653 Mdot
.21652 .45305 Mdot
.70825 .42855 Mdot
.64349 .64901 Mdot
.37565 .58515 Mdot
.52513 .33175 Mdot
.41995 .48961 Mdot
.76211 .35782 Mdot
.67353 .63851 Mdot
.38646 .52042 Mdot
.3159 .52271 Mdot
.5067 .67535 Mdot
.38074 .52143 Mdot
.59229 .72571 Mdot
.51979 .36007 Mdot
.38704 .5196 Mdot
.46793 .76063 Mdot
.66312 .45774 Mdot
.32337 .53445 Mdot
.41375 .29251 Mdot
.40281 .3912 Mdot
.64345 .77716 Mdot
.56188 .38827 Mdot
.40207 .33147 Mdot
.37962 .50489 Mdot
.50762 .35309 Mdot
.67815 .41184 Mdot
.54754 .60665 Mdot
.42468 .51556 Mdot
.68273 .42377 Mdot
.66917 .42882 Mdot
.41214 .3173 Mdot
.17138 .36743 Mdot
.31629 .52065 Mdot
.36099 .54292 Mdot
.54833 .17436 Mdot
.50989 .71388 Mdot
.35684 .54013 Mdot
.35579 .51382 Mdot
.6986 .432 Mdot
.23774 .49563 Mdot
.46546 .47901 Mdot
.64608 .23907 Mdot
.66187 .42251 Mdot
.50653 .30616 Mdot
.52962 .36791 Mdot
.4004 .32919 Mdot
.55207 .67508 Mdot
.43868 .30679 Mdot
.52655 .34812 Mdot
.37795 .56267 Mdot
.6896 .46089 Mdot
.34798 .66171 Mdot
.64036 .43544 Mdot
.50025 .33427 Mdot
.49301 .64891 Mdot
.68632 .74438 Mdot
.63726 .1811 Mdot
.6572 .74914 Mdot
.71063 .42931 Mdot
.41707 .32306 Mdot
.67079 .52607 Mdot
.3851 .50756 Mdot
.25539 .66568 Mdot
.35796 .54472 Mdot
.28081 .60867 Mdot
.5567 .37533 Mdot
.64722 .6303 Mdot
.37924 .58184 Mdot
.3472 .35195 Mdot
.70355 .42401 Mdot
.65343 .45096 Mdot
.40717 .53696 Mdot
.68205 .43586 Mdot
.38332 .53603 Mdot
.53929 .35488 Mdot
.17538 .36667 Mdot
.36427 .51283 Mdot
.32555 .54964 Mdot
.64337 .47848 Mdot
.68235 .60208 Mdot
.49327 .32278 Mdot
.4233 .78637 Mdot
.82377 .46979 Mdot
.67751 .4362 Mdot
.43705 .60955 Mdot
.56467 .34922 Mdot
.63675 .6453 Mdot
.58664 .34909 Mdot
.3642 .55035 Mdot
.34216 .53638 Mdot
.39597 .55779 Mdot
.3887 .50804 Mdot
.26764 .67878 Mdot
.32939 .58447 Mdot
.37196 .72859 Mdot
.3487 .55185 Mdot
.47662 .60673 Mdot
.69138 .43801 Mdot
.45288 .48483 Mdot
.36562 .3118 Mdot
.34098 .53256 Mdot
.51156 .61561 Mdot
.68241 .41878 Mdot
.74564 .67795 Mdot
.67716 .456 Mdot
.55097 .33467 Mdot
.68723 .46922 Mdot
.39707 .58335 Mdot
.54295 .67072 Mdot
.53341 .36345 Mdot
.59603 .75816 Mdot
.56932 .33926 Mdot
.38094 .51438 Mdot
.65168 .49272 Mdot
.51891 .3333 Mdot
.38135 .41748 Mdot
.54428 .66979 Mdot
.33534 .35951 Mdot
.50339 .70871 Mdot
.37573 .52527 Mdot
.36864 .52906 Mdot
.63927 .63476 Mdot
.70661 .44044 Mdot
.55911 .69774 Mdot
.29781 .26185 Mdot
.38406 .33855 Mdot
.5459 .685 Mdot
.44721 .57424 Mdot
.59429 .52196 Mdot
.51231 .69189 Mdot
.36757 .38668 Mdot
.7046 .43452 Mdot
.55849 .6715 Mdot
.41111 .59254 Mdot
.26682 .54968 Mdot
.3879 .30699 Mdot
.5125 .36372 Mdot
.55783 .47617 Mdot
.52613 .36602 Mdot
.64055 .45827 Mdot
.58361 .36191 Mdot
.68768 .44589 Mdot
.60427 .68724 Mdot
.49977 .49377 Mdot
.64716 .46597 Mdot
.65482 .48141 Mdot
.52874 .34129 Mdot
.40626 .54231 Mdot
.50262 .42164 Mdot
.44819 .56015 Mdot
.32899 .5728 Mdot
.6671 .42241 Mdot
.54661 .65547 Mdot
.53943 .7109 Mdot
.49233 .61226 Mdot
.50225 .6824 Mdot
.54043 .36433 Mdot
.60774 .57044 Mdot
.24471 .58434 Mdot
.66433 .46226 Mdot
.60846 .37401 Mdot
.40586 .55442 Mdot
.52446 .33812 Mdot
.54948 .3662 Mdot
.67916 .42844 Mdot
.27247 .64042 Mdot
.32062 .55021 Mdot
.50952 .70932 Mdot
.55956 .68845 Mdot
.51635 .69641 Mdot
.54601 .64653 Mdot
.18247 .52783 Mdot
.64094 .44013 Mdot
.53868 .65193 Mdot
.41472 .52667 Mdot
.34646 .53998 Mdot
.66014 .65332 Mdot
.39385 .31475 Mdot
.3596 .58111 Mdot
.34113 .57261 Mdot
.37655 .55345 Mdot
.51834 .33705 Mdot
.36609 .46553 Mdot
.67381 .64078 Mdot
.58188 .35294 Mdot
.57782 .37248 Mdot
.64404 .6399 Mdot
.55885 .73638 Mdot
.83743 .50694 Mdot
.38767 .56172 Mdot
.46261 .65315 Mdot
.5275 .33218 Mdot
.53892 .56314 Mdot
.3047 .58709 Mdot
.41859 .54533 Mdot
.50694 .40209 Mdot
.53847 .35877 Mdot
.54091 .63613 Mdot
.36544 .54631 Mdot
.65085 .63202 Mdot
.40001 .2943 Mdot
.44049 .57472 Mdot
.64042 .6493 Mdot
.53485 .6905 Mdot
.55568 .22358 Mdot
.52996 .72009 Mdot
.51766 .33333 Mdot
.32661 .52629 Mdot
.2533 .79587 Mdot
.55405 .35241 Mdot
.75458 .64063 Mdot
.49392 .48391 Mdot
.37187 .50966 Mdot
.53778 .36813 Mdot
.5288 .63371 Mdot
.65963 .42513 Mdot
.56669 .46417 Mdot
.55262 .67055 Mdot
.64118 .63558 Mdot
.64805 .64964 Mdot
.53671 .34702 Mdot
.5494 .70037 Mdot
.35749 .50138 Mdot
.50981 .6599 Mdot
.67305 .46928 Mdot
.41472 .57032 Mdot
.81897 .48939 Mdot
.41632 .60276 Mdot
.51512 .65842 Mdot
.51376 .31449 Mdot
.41848 .34103 Mdot
.43118 .54903 Mdot
.79848 .60687 Mdot
.36053 .5096 Mdot
.67153 .46061 Mdot
.51477 .54709 Mdot
.34513 .66719 Mdot
.39477 .5506 Mdot
.3999 .5605 Mdot
.66778 .41499 Mdot
.39037 .55484 Mdot
.41357 .5066 Mdot
.72355 .42351 Mdot
.50819 .68582 Mdot
.39304 .52242 Mdot
.53683 .37293 Mdot
.4326 .64697 Mdot
.3694 .57922 Mdot
.6044 .72004 Mdot
.33915 .35152 Mdot
.50539 .52665 Mdot
.32859 .54102 Mdot
.32635 .28633 Mdot
.36698 .53273 Mdot
.42367 .52837 Mdot
.39924 .55234 Mdot
.40173 .78314 Mdot
.52625 .34464 Mdot
.5497 .37955 Mdot
.39778 .294 Mdot
.34725 .35755 Mdot
.41648 .33067 Mdot
.68169 .41551 Mdot
.61582 .35745 Mdot
.6656 .63101 Mdot
.52315 .68227 Mdot
.36113 .57295 Mdot
.57358 .34605 Mdot
.37594 .54817 Mdot
.40096 .57219 Mdot
.53144 .35758 Mdot
.54637 .3641 Mdot
.57328 .38399 Mdot
.38713 .33101 Mdot
.53262 .68005 Mdot
.36456 .56653 Mdot
.39749 .3413 Mdot
.35988 .50323 Mdot
.60282 .51969 Mdot
.53535 .68119 Mdot
.50903 .66118 Mdot
.53414 .71489 Mdot
.34832 .55653 Mdot
.41015 .57808 Mdot
.68964 .43189 Mdot
.57215 .67979 Mdot
.65395 .45776 Mdot
.53555 .36757 Mdot
.51547 .34605 Mdot
.36365 .55055 Mdot
.28926 .52993 Mdot
.39601 .31526 Mdot
.55303 .33353 Mdot
.68066 .64515 Mdot
.39997 .29241 Mdot
.39601 .51246 Mdot
.52974 .36631 Mdot
.41279 .29079 Mdot
.29952 .6373 Mdot
.81489 .44494 Mdot
.39603 .34335 Mdot
.40758 .53601 Mdot
.4877 .77315 Mdot
.23952 .43259 Mdot
.38805 .34303 Mdot
.68426 .45577 Mdot
.34941 .52486 Mdot
.6531 .21877 Mdot
.43966 .31933 Mdot
.20275 .47049 Mdot
.52664 .35507 Mdot
.29995 .60716 Mdot
.43807 .57875 Mdot
.24427 .63546 Mdot
.4409 .31738 Mdot
.52248 .65877 Mdot
.56519 .67926 Mdot
.40068 .54034 Mdot
.37394 .33183 Mdot
.64012 .45232 Mdot
.53268 .31762 Mdot
.57557 .3695 Mdot
.54396 .70447 Mdot
.62106 .56774 Mdot
.53506 .37163 Mdot
.34658 .49065 Mdot
.56012 .30513 Mdot
.4655 .54077 Mdot
.19014 .57626 Mdot
.58432 .78015 Mdot
.334 .52108 Mdot
.41557 .34293 Mdot
.69901 .4192 Mdot
.68555 .43259 Mdot
.68223 .44392 Mdot
.51445 .35124 Mdot
.57081 .5246 Mdot
.56832 .37321 Mdot
.63955 .67765 Mdot
.40329 .31226 Mdot
.32293 .37917 Mdot
.33999 .56548 Mdot
.37286 .50989 Mdot
.40419 .50008 Mdot
.39418 .55969 Mdot
.36837 .53322 Mdot
.66726 .42544 Mdot
.51872 .32422 Mdot
.60079 .23369 Mdot
.5298 .70122 Mdot
.6987 .57013 Mdot
.52809 .32609 Mdot
.65971 .65595 Mdot
.42125 .30891 Mdot
.30067 .31583 Mdot
.56092 .29731 Mdot
.54034 .32132 Mdot
.4312 .52347 Mdot
.54573 .65174 Mdot
.24606 .54002 Mdot
.35922 .52926 Mdot
.55458 .33416 Mdot
.54476 .30635 Mdot
.28439 .67107 Mdot
.41936 .48292 Mdot
.46049 .33685 Mdot
.59289 .5235 Mdot
.43067 .33833 Mdot
.43502 .5094 Mdot
.54566 .56688 Mdot
.5286 .3473 Mdot
.54706 .33644 Mdot
.38991 .3418 Mdot
.41443 .45626 Mdot
.55488 .68828 Mdot
.64941 .62891 Mdot
.68967 .45095 Mdot
.36126 .52171 Mdot
.51548 .35478 Mdot
.4675 .65631 Mdot
.57172 .44638 Mdot
.66706 .4526 Mdot
.5792 .34489 Mdot
.34826 .522 Mdot
.39708 .54551 Mdot
.4025 .32207 Mdot
.42285 .2264 Mdot
.44648 .56374 Mdot
.72753 .67152 Mdot
.58212 .55431 Mdot
.46323 .43939 Mdot
.38131 .54817 Mdot
.52127 .70611 Mdot
.64818 .63705 Mdot
.42386 .30211 Mdot
.35709 .50653 Mdot
.83757 .48037 Mdot
.55966 .71687 Mdot
.65908 .4348 Mdot
.64782 .63526 Mdot
.5636 .51769 Mdot
.36404 .50761 Mdot
.3583 .5449 Mdot
.40893 .51685 Mdot
.84053 .47595 Mdot
.55166 .37705 Mdot
.56467 .6646 Mdot
.42961 .32534 Mdot
.50539 .66243 Mdot
.55752 .38272 Mdot
.45522 .42863 Mdot
.40192 .5116 Mdot
.51409 .71062 Mdot
.52695 .65714 Mdot
.66276 .45844 Mdot
.6989 .4232 Mdot
.5224 .37778 Mdot
.38253 .50585 Mdot
.65988 .62879 Mdot
.55421 .6665 Mdot
.52272 .3173 Mdot
.40294 .32116 Mdot
.71203 .45355 Mdot
.34872 .55322 Mdot
.53359 .34562 Mdot
.34464 .50386 Mdot
.51053 .6778 Mdot
.53668 .32176 Mdot
.6516 .65556 Mdot
.39508 .31129 Mdot
.34383 .54366 Mdot
.5763 .21847 Mdot
.64633 .63397 Mdot
.42595 .56889 Mdot
.52034 .7605 Mdot
.37162 .30543 Mdot
.59083 .76483 Mdot
.56222 .37214 Mdot
.66361 .63332 Mdot
.55745 .65771 Mdot
.26394 .55493 Mdot
.54754 .3417 Mdot
.52424 .78158 Mdot
.53156 .41801 Mdot
.37735 .5647 Mdot
.5494 .68857 Mdot
.42234 .34982 Mdot
.74082 .66442 Mdot
.2571 .39813 Mdot
.38413 .52964 Mdot
.52552 .36603 Mdot
.40512 .29337 Mdot
.65465 .45663 Mdot
.60719 .71108 Mdot
.20411 .59646 Mdot
.58111 .353 Mdot
.35824 .56756 Mdot
.55292 .66283 Mdot
.67361 .43 Mdot
.58603 .79978 Mdot
.50711 .3203 Mdot
.55003 .37299 Mdot
.41751 .51861 Mdot
.43216 .32196 Mdot
.66072 .23081 Mdot
.54662 .37848 Mdot
.5098 .34131 Mdot
.68024 .57998 Mdot
.38331 .31049 Mdot
.41231 .52772 Mdot
.49357 .61209 Mdot
.39545 .49975 Mdot
.72208 .64566 Mdot
.66253 .63179 Mdot
.52736 .69979 Mdot
.35246 .54552 Mdot
.58761 .23011 Mdot
.54933 .35147 Mdot
.59301 .5279 Mdot
.74442 .44764 Mdot
.70071 .42575 Mdot
.51866 .35733 Mdot
.37214 .54531 Mdot
.68525 .47778 Mdot
.39708 .31939 Mdot
.40173 .50653 Mdot
.4009 .58154 Mdot
.51356 .63204 Mdot
.68249 .46484 Mdot
.44194 .64745 Mdot
.67325 .47176 Mdot
.65406 .42064 Mdot
.48963 .6433 Mdot
.40095 .53907 Mdot
.54721 .32795 Mdot
.49894 .33846 Mdot
.35081 .50322 Mdot
.53889 .56157 Mdot
.55366 .68816 Mdot
.59376 .37073 Mdot
.84034 .44118 Mdot
.3237 .50792 Mdot
.6803 .6498 Mdot
.31089 .61953 Mdot
.64802 .43574 Mdot
.37715 .56156 Mdot
.51687 .67732 Mdot
.51227 .32943 Mdot
.52602 .3697 Mdot
.44083 .55138 Mdot
.67847 .42725 Mdot
.42393 .28993 Mdot
.55486 .36668 Mdot
.57628 .44762 Mdot
.3849 .51847 Mdot
.61832 .66091 Mdot
.55988 .36522 Mdot
.68445 .76951 Mdot
.59234 .23182 Mdot
.53298 .70457 Mdot
.40586 .56445 Mdot
.51611 .64531 Mdot
.4267 .32867 Mdot
.58597 .35262 Mdot
.68298 .42615 Mdot
.30452 .46974 Mdot
.33992 .23165 Mdot
.52255 .34148 Mdot
.53205 .68687 Mdot
.35773 .5635 Mdot
.2968 .56387 Mdot
.36476 .50977 Mdot
.24578 .4855 Mdot
.40809 .35955 Mdot
.66533 .48306 Mdot
.65121 .45088 Mdot
.39176 .56836 Mdot
.38921 .32894 Mdot
.50397 .35619 Mdot
.53019 .35594 Mdot
.14038 .42951 Mdot
.64089 .65041 Mdot
.42841 .35934 Mdot
.34802 .5549 Mdot
.52971 .31483 Mdot
.4633 .73832 Mdot
.65416 .46102 Mdot
.38634 .49531 Mdot
.55562 .31729 Mdot
.74124 .5978 Mdot
.59215 .51709 Mdot
.38582 .52289 Mdot
.3129 .49847 Mdot
.68033 .4563 Mdot
.67226 .52626 Mdot
.57013 .36725 Mdot
.37389 .49854 Mdot
.66718 .4036 Mdot
.66598 .59673 Mdot
.31504 .2554 Mdot
.53295 .67985 Mdot
.52481 .30873 Mdot
.69176 .42255 Mdot
.3559 .47164 Mdot
.39433 .32135 Mdot
.50637 .33648 Mdot
.5596 .32278 Mdot
.41229 .56837 Mdot
.35646 .57821 Mdot
.36389 .47573 Mdot
.54313 .69221 Mdot
.69907 .43636 Mdot
.3824 .57559 Mdot
.61993 .54998 Mdot
.384 .56538 Mdot
.69686 .43246 Mdot
.14597 .65725 Mdot
.43851 .5509 Mdot
.35367 .53239 Mdot
.37622 .40811 Mdot
.55142 .70455 Mdot
.50492 .6784 Mdot
.60602 .55621 Mdot
.3473 .55366 Mdot
.5963 .40936 Mdot
.52962 .67963 Mdot
.55252 .68416 Mdot
.58473 .41265 Mdot
.42013 .56384 Mdot
.6296 .43204 Mdot
.67705 .43054 Mdot
.69989 .42476 Mdot
.50701 .67336 Mdot
.35472 .5951 Mdot
.68396 .41247 Mdot
.27661 .69368 Mdot
.53359 .32099 Mdot
.54599 .56726 Mdot
.51192 .65852 Mdot
.5512 .4333 Mdot
.70589 .44224 Mdot
.69737 .781 Mdot
.26346 .50286 Mdot
.36654 .49166 Mdot
.39867 .54565 Mdot
.41609 .32696 Mdot
.35331 .61 Mdot
.64602 .65079 Mdot
.68405 .43656 Mdot
.65543 .26764 Mdot
.53929 .67875 Mdot
.35337 .52536 Mdot
.26694 .35099 Mdot
.60402 .78318 Mdot
.54219 .6111 Mdot
.55174 .67259 Mdot
.54363 .67677 Mdot
.5678 .34353 Mdot
.53202 .31962 Mdot
.40667 .52135 Mdot
.68667 .44186 Mdot
.56252 .68062 Mdot
.69769 .45034 Mdot
.5276 .34844 Mdot
.53691 .32317 Mdot
.67626 .64561 Mdot
.31637 .56701 Mdot
.51964 .35177 Mdot
.69063 .58883 Mdot
.61879 .54739 Mdot
.53686 .63687 Mdot
.62073 .17725 Mdot
.57992 .80476 Mdot
.37006 .40897 Mdot
.39887 .29481 Mdot
.66762 .61854 Mdot
.70353 .45333 Mdot
.39251 .56689 Mdot
.36065 .55509 Mdot
.66159 .65058 Mdot
.70894 .43594 Mdot
.42488 .31562 Mdot
.70616 .44417 Mdot
.41627 .29983 Mdot
.53946 .38019 Mdot
.36975 .58017 Mdot
.38194 .50305 Mdot
.65413 .44158 Mdot
.56379 .34128 Mdot
.51756 .33468 Mdot
.38983 .30753 Mdot
.30424 .32109 Mdot
.53559 .34801 Mdot
.51168 .65849 Mdot
.41887 .65787 Mdot
.65022 .65038 Mdot
.3658 .54559 Mdot
.28832 .32378 Mdot
.27101 .66381 Mdot
.37383 .56662 Mdot
.64759 .63465 Mdot
.14565 .40143 Mdot
.37716 .5827 Mdot
.15253 .49933 Mdot
.67247 .64086 Mdot
.52572 .71031 Mdot
.56559 .35507 Mdot
.63817 .64396 Mdot
.36031 .46752 Mdot
.37979 .35266 Mdot
.33496 .50901 Mdot
.55775 .68248 Mdot
.50992 .70445 Mdot
.50373 .48913 Mdot
.72331 .64216 Mdot
.43502 .31772 Mdot
.41775 .31216 Mdot
.54591 .34325 Mdot
.6512 .39659 Mdot
.38979 .48612 Mdot
.41913 .31507 Mdot
.69543 .2811 Mdot
.40775 .55269 Mdot
.37563 .36235 Mdot
.50876 .40934 Mdot
.52776 .70789 Mdot
.44714 .47482 Mdot
.54847 .34707 Mdot
.5324 .68648 Mdot
.50351 .44614 Mdot
.39921 .49929 Mdot
.53719 .68065 Mdot
.70085 .43551 Mdot
.73049 .40071 Mdot
.50052 .67638 Mdot
.56742 .4611 Mdot
.6729 .43316 Mdot
.36975 .30824 Mdot
.28592 .41336 Mdot
.8772 .44611 Mdot
.68585 .4374 Mdot
.56169 .34383 Mdot
.5169 .34733 Mdot
.53845 .35155 Mdot
.55431 .67352 Mdot
.55064 .36232 Mdot
.53414 .69772 Mdot
.66367 .48954 Mdot
.31903 .29635 Mdot
.40761 .32045 Mdot
.59866 .33738 Mdot
.52915 .66306 Mdot
.65186 .67839 Mdot
.55238 .16099 Mdot
.41186 .53304 Mdot
.64393 .46082 Mdot
.40924 .34523 Mdot
.60822 .59694 Mdot
.42055 .32559 Mdot
.5654 .35062 Mdot
.54728 .56846 Mdot
.38449 .53494 Mdot
.558 .77068 Mdot
.41311 .29373 Mdot
.55229 .67165 Mdot
.42882 .52804 Mdot
.50481 .36527 Mdot
.40708 .33306 Mdot
.3969 .29755 Mdot
.3676 .53539 Mdot
.50083 .69008 Mdot
.54384 .32444 Mdot
.69762 .46327 Mdot
.40012 .35223 Mdot
.30135 .51334 Mdot
.40202 .54612 Mdot
.43784 .53106 Mdot
.58948 .5368 Mdot
.66288 .22684 Mdot
.67516 .43678 Mdot
.23658 .43086 Mdot
.51909 .3417 Mdot
.25589 .4055 Mdot
.67601 .70648 Mdot
.56304 .29477 Mdot
.66467 .63242 Mdot
.66147 .63114 Mdot
.38039 .52664 Mdot
.69524 .24988 Mdot
.49924 .60363 Mdot
.65055 .41523 Mdot
.64921 .6477 Mdot
.51804 .33362 Mdot
.57193 .69411 Mdot
.42061 .44842 Mdot
.3651 .58729 Mdot
.70835 .43025 Mdot
.53153 .35156 Mdot
.76209 .35674 Mdot
.40476 .31231 Mdot
.59415 .5846 Mdot
.39197 .51143 Mdot
.37494 .53603 Mdot
.66436 .44276 Mdot
.68825 .43171 Mdot
.623 .67194 Mdot
.52324 .50988 Mdot
.81165 .50949 Mdot
.63233 .451 Mdot
.75914 .34361 Mdot
.48698 .62287 Mdot
.51276 .66722 Mdot
.67594 .65265 Mdot
.6779 .41341 Mdot
.35531 .5407 Mdot
.52987 .71131 Mdot
.52383 .60624 Mdot
.51544 .6289 Mdot
.3791 .36729 Mdot
.57401 .4241 Mdot
.3918 .50956 Mdot
.5453 .64961 Mdot
.53409 .68541 Mdot
.52816 .64359 Mdot
.64487 .64068 Mdot
.38113 .55087 Mdot
.40827 .54085 Mdot
.38119 .58341 Mdot
.29734 .56189 Mdot
.38088 .52078 Mdot
.683 .70199 Mdot
.63236 .56018 Mdot
.45831 .25914 Mdot
.35206 .56371 Mdot
.69579 .42552 Mdot
.35862 .57203 Mdot
.3906 .32842 Mdot
.34871 .56275 Mdot
.37035 .35297 Mdot
.67636 .44558 Mdot
.37254 .45226 Mdot
.58809 .38843 Mdot
.3977 .51077 Mdot
.43133 .29471 Mdot
.66761 .22968 Mdot
.25315 .37275 Mdot
.68212 .58145 Mdot
.51116 .65914 Mdot
.53265 .38285 Mdot
.64559 .4576 Mdot
.54576 .32823 Mdot
.37535 .49381 Mdot
.67849 .64333 Mdot
.51121 .84117 Mdot
.53198 .43515 Mdot
.35402 .54152 Mdot
.31579 .57187 Mdot
.51704 .70176 Mdot
.55066 .35391 Mdot
.50713 .62575 Mdot
.41749 .52077 Mdot
.42043 .33559 Mdot
.40792 .34099 Mdot
.47909 .44902 Mdot
.73129 .34618 Mdot
.25219 .53611 Mdot
.66669 .44192 Mdot
.52073 .36774 Mdot
.44099 .31488 Mdot
.57813 .6365 Mdot
.63921 .44751 Mdot
.64799 .43621 Mdot
.68432 .46355 Mdot
.37719 .51234 Mdot
.67336 .65034 Mdot
.71001 .31109 Mdot
.6397 .63841 Mdot
.41191 .51265 Mdot
.56365 .32775 Mdot
.63688 .64249 Mdot
.41556 .32923 Mdot
.65476 .42112 Mdot
.52125 .33349 Mdot
.37125 .52671 Mdot
.5274 .67435 Mdot
.23884 .41083 Mdot
.47696 .18407 Mdot
.59706 .34705 Mdot
.59849 .35014 Mdot
.53433 .71727 Mdot
.79534 .625 Mdot
.70207 .47479 Mdot
.27107 .64225 Mdot
.43915 .34223 Mdot
.35215 .50171 Mdot
.18686 .37635 Mdot
.56769 .37282 Mdot
.53592 .36446 Mdot
.39055 .52008 Mdot
.51488 .31756 Mdot
.3552 .5189 Mdot
.57294 .36156 Mdot
.76397 .6109 Mdot
.37732 .59252 Mdot
.53877 .36417 Mdot
.40607 .48976 Mdot
.43249 .54923 Mdot
.51443 .70136 Mdot
.50784 .33304 Mdot
.36447 .49161 Mdot
.47408 .85444 Mdot
.65915 .45396 Mdot
.64422 .64196 Mdot
.60752 .34749 Mdot
.68917 .46658 Mdot
.54551 .69668 Mdot
.36987 .58249 Mdot
.39852 .31893 Mdot
.52086 .66378 Mdot
.51591 .37808 Mdot
.42126 .29502 Mdot
.60926 .56953 Mdot
.50944 .66905 Mdot
.66117 .6523 Mdot
.39659 .3086 Mdot
.33435 .50935 Mdot
.53141 .36105 Mdot
.55844 .1965 Mdot
.64024 .63989 Mdot
.38183 .54101 Mdot
.51167 .31164 Mdot
.70548 .44585 Mdot
.40386 .52532 Mdot
.51843 .36329 Mdot
.6453 .63787 Mdot
.42535 .56846 Mdot
.42886 .56545 Mdot
.39761 .44264 Mdot
.50923 .56039 Mdot
.40673 .32395 Mdot
.48911 .64655 Mdot
.41474 .52462 Mdot
.38813 .32688 Mdot
.62354 .29781 Mdot
.33291 .54941 Mdot
.50598 .65412 Mdot
.2904 .49389 Mdot
.53755 .31768 Mdot
.65257 .45618 Mdot
.49974 .33291 Mdot
.40455 .29123 Mdot
.35146 .19415 Mdot
.66559 .65477 Mdot
.30895 .56109 Mdot
.40652 .5003 Mdot
.57949 .34051 Mdot
.538 .68592 Mdot
.80907 .53155 Mdot
.3451 .54805 Mdot
.3819 .60124 Mdot
.3656 .5409 Mdot
.5847 .23426 Mdot
.55395 .68563 Mdot
.36481 .54375 Mdot
.29306 .53325 Mdot
.3476 .49271 Mdot
.43504 .29643 Mdot
.31856 .39002 Mdot
.36591 .57281 Mdot
.35172 .87237 Mdot
.66307 .62771 Mdot
.53378 .35733 Mdot
.58127 .4912 Mdot
.57837 .26138 Mdot
.17926 .55746 Mdot
.53945 .69568 Mdot
.41242 .6282 Mdot
.54427 .32589 Mdot
.23101 .39893 Mdot
.77172 .65747 Mdot
.43261 .54403 Mdot
.34724 .52674 Mdot
.56537 .35057 Mdot
.52266 .31832 Mdot
.67192 .63368 Mdot
.33834 .53606 Mdot
.37759 .60069 Mdot
.53064 .31087 Mdot
.369 .5228 Mdot
.33636 .73613 Mdot
.67184 .47729 Mdot
.50606 .67655 Mdot
.65508 .45699 Mdot
.64958 .43626 Mdot
.24631 .59948 Mdot
.58104 .55475 Mdot
.69401 .43146 Mdot
.70113 .41019 Mdot
.35287 .31901 Mdot
.31428 .45664 Mdot
.43789 .30404 Mdot
.74712 .3842 Mdot
.54221 .34572 Mdot
.38042 .55262 Mdot
.54886 .66232 Mdot
.22395 .60722 Mdot
.77764 .46499 Mdot
.56067 .57887 Mdot
.41303 .5359 Mdot
.54671 .3519 Mdot
.64336 .63748 Mdot
.37223 .59126 Mdot
.24768 .42263 Mdot
.38053 .53252 Mdot
.52824 .31955 Mdot
.24378 .59176 Mdot
.59207 .72032 Mdot
.63259 .44892 Mdot
.57917 .67299 Mdot
.36249 .57519 Mdot
.51687 .68607 Mdot
.68726 .42339 Mdot
.38751 .3306 Mdot
.41657 .32195 Mdot
.39345 .50721 Mdot
.50054 .49471 Mdot
.36402 .27193 Mdot
.432 .54492 Mdot
.41379 .5686 Mdot
.66708 .63505 Mdot
.41371 .56935 Mdot
.37911 .49921 Mdot
.37975 .57356 Mdot
.3356 .53441 Mdot
.65862 .41762 Mdot
.53756 .76103 Mdot
.34597 .56418 Mdot
.32398 .50519 Mdot
.69997 .46539 Mdot
.43881 .48894 Mdot
.67891 .45433 Mdot
.80153 .45956 Mdot
.69077 .44741 Mdot
.4147 .32175 Mdot
.49467 .32789 Mdot
.43693 .6274 Mdot
.56263 .68266 Mdot
.69198 .42085 Mdot
.41225 .30307 Mdot
.68448 .44 Mdot
.53443 .37534 Mdot
.58736 .17989 Mdot
.48728 .67073 Mdot
.6051 .51808 Mdot
.33246 .42641 Mdot
.619 .6619 Mdot
.54469 .31911 Mdot
.54416 .70378 Mdot
.59296 .72292 Mdot
.3899 .57067 Mdot
.4006 .32419 Mdot
.37972 .52786 Mdot
.64916 .42626 Mdot
.54452 .35016 Mdot
.66024 .4934 Mdot
.4077 .32488 Mdot
.40643 .17919 Mdot
.57304 .34653 Mdot
.30657 .54057 Mdot
.69255 .47217 Mdot
.59752 .17331 Mdot
.68611 .45074 Mdot
.31584 .29899 Mdot
.50757 .72341 Mdot
.22216 .56411 Mdot
.5395 .67049 Mdot
.61323 .67423 Mdot
.834 .59903 Mdot
.77077 .6433 Mdot
.51843 .66921 Mdot
.59112 .38672 Mdot
.37864 .51643 Mdot
.38952 .56361 Mdot
.34288 .49107 Mdot
.55607 .64356 Mdot
.41012 .51928 Mdot
.64989 .65211 Mdot
.58985 .54675 Mdot
.66545 .24912 Mdot
.52028 .37515 Mdot
.35691 .51574 Mdot
.6662 .42312 Mdot
.64394 .42972 Mdot
.63696 .63991 Mdot
.68015 .46884 Mdot
.42906 .55629 Mdot
.53212 .66465 Mdot
.50188 .42511 Mdot
.42216 .33111 Mdot
.71065 .67816 Mdot
.44013 .33421 Mdot
.53256 .29534 Mdot
.32926 .50261 Mdot
.53712 .32279 Mdot
.26147 .27869 Mdot
.39511 .56311 Mdot
.52861 .68122 Mdot
.41808 .51502 Mdot
.37558 .57502 Mdot
.36211 .56991 Mdot
.51834 .36442 Mdot
.58426 .49463 Mdot
.36647 .52435 Mdot
.69287 .42705 Mdot
.57066 .41557 Mdot
.35482 .58005 Mdot
.6665 .2847 Mdot
.38448 .37382 Mdot
.61871 .65929 Mdot
.54349 .63988 Mdot
.55753 .34377 Mdot
.54049 .67709 Mdot
.58432 .68838 Mdot
.54532 .69692 Mdot
.67565 .28118 Mdot
.26138 .57456 Mdot
.15253 .5265 Mdot
.4462 .72677 Mdot
.2422 .61938 Mdot
.51398 .71234 Mdot
.65085 .32206 Mdot
.51495 .67245 Mdot
.54232 .69677 Mdot
.1125 .54989 Mdot
.52329 .65114 Mdot
.36474 .55132 Mdot
.40809 .5851 Mdot
.64612 .76505 Mdot
.35201 .32346 Mdot
.35106 .56393 Mdot
.40931 .5204 Mdot
.42403 .33661 Mdot
.29186 .50894 Mdot
.64069 .62779 Mdot
.58833 .57127 Mdot
.68799 .64294 Mdot
.36838 .53459 Mdot
.39725 .51756 Mdot
.4431 .54341 Mdot
.8353 .60644 Mdot
.2131 .59938 Mdot
.52365 .71227 Mdot
.40422 .46446 Mdot
.69707 .61932 Mdot
.41431 .50612 Mdot
.4128 .50724 Mdot
.39363 .58367 Mdot
.54638 .32716 Mdot
.56975 .69803 Mdot
.41369 .59492 Mdot
.63999 .72603 Mdot
.39338 .51228 Mdot
.50204 .30109 Mdot
.42927 .27933 Mdot
.37151 .54639 Mdot
.50872 .65413 Mdot
.40487 .55036 Mdot
.52975 .64643 Mdot
.50739 .67759 Mdot
.31862 .57074 Mdot
.71714 .32107 Mdot
.57514 .69082 Mdot
.43387 .54407 Mdot
.56038 .33755 Mdot
.74078 .66018 Mdot
.37967 .54301 Mdot
.43388 .31632 Mdot
.37789 .5619 Mdot
.42836 .29184 Mdot
.40768 .57695 Mdot
.64081 .6366 Mdot
.33737 .67209 Mdot
.54616 .33733 Mdot
.40364 .35278 Mdot
.52688 .31404 Mdot
.41007 .43171 Mdot
.49387 .6713 Mdot
.64463 .6255 Mdot
.2068 .61551 Mdot
.66861 .63673 Mdot
.22552 .44148 Mdot
.64947 .39199 Mdot
.6514 .43902 Mdot
.54766 .64749 Mdot
.24811 .56746 Mdot
.69832 .32274 Mdot
.5774 .37737 Mdot
.57802 .37301 Mdot
.2771 .27586 Mdot
.17295 .36954 Mdot
.36186 .5258 Mdot
.64477 .20801 Mdot
.3703 .71548 Mdot
.37013 .48321 Mdot
.44749 .52324 Mdot
.55334 .31781 Mdot
.35887 .57473 Mdot
.55637 .46481 Mdot
.52798 .34176 Mdot
.41129 .3069 Mdot
.52527 .69828 Mdot
.39284 .30737 Mdot
.77868 .44317 Mdot
.63438 .5485 Mdot
.52154 .34708 Mdot
.33506 .54612 Mdot
.36287 .51692 Mdot
.55508 .65323 Mdot
.5385 .7874 Mdot
.50729 .68434 Mdot
.43646 .3113 Mdot
.53544 .33493 Mdot
.23713 .63115 Mdot
.36764 .56308 Mdot
.53085 .65708 Mdot
.57731 .39234 Mdot
.39578 .54683 Mdot
.65626 .43558 Mdot
.41337 .53671 Mdot
.52092 .65554 Mdot
.41292 .57026 Mdot
.53352 .66661 Mdot
.57089 .35479 Mdot
.36696 .50484 Mdot
.39883 .51865 Mdot
.2162 .4538 Mdot
.42577 .31638 Mdot
.4941 .67694 Mdot
.5587 .46951 Mdot
.39632 .50019 Mdot
.24873 .42392 Mdot
.37225 .5812 Mdot
.45507 .59719 Mdot
.44876 .54154 Mdot
.65669 .65361 Mdot
.39888 .49549 Mdot
.3799 .54176 Mdot
.49794 .78679 Mdot
.47603 .75779 Mdot
.44376 .46162 Mdot
.69745 .42146 Mdot
.50654 .65779 Mdot
.51632 .35016 Mdot
.51394 .33033 Mdot
.55643 .3608 Mdot
.34594 .31863 Mdot
.30411 .50348 Mdot
.38683 .53471 Mdot
.65963 .48295 Mdot
.41569 .31332 Mdot
.54516 .66323 Mdot
.41177 .31756 Mdot
.58356 .57031 Mdot
.43159 .30309 Mdot
.65132 .65331 Mdot
.59349 .23136 Mdot
.29863 .70913 Mdot
.42851 .30467 Mdot
.50703 .6826 Mdot
.58821 .4174 Mdot
.35298 .49993 Mdot
.72282 .59963 Mdot
.42085 .33563 Mdot
.29652 .26129 Mdot
.41604 .57781 Mdot
.56765 .47003 Mdot
.67327 .45664 Mdot
.39401 .30615 Mdot
.67795 .46663 Mdot
.40172 .55414 Mdot
.58808 .76745 Mdot
.52815 .68555 Mdot
.66353 .47389 Mdot
.38945 .49182 Mdot
.39306 .30748 Mdot
.52163 .35092 Mdot
.27212 .49848 Mdot
.71154 .43847 Mdot
.23876 .40131 Mdot
.25675 .39875 Mdot
.53329 .33565 Mdot
.27344 .71536 Mdot
.67969 .46199 Mdot
.33424 .52382 Mdot
.28966 .59453 Mdot
.41164 .54453 Mdot
.51411 .33892 Mdot
.53989 .36638 Mdot
.6971 .71557 Mdot
.39178 .50814 Mdot
.3928 .58882 Mdot
.56022 .70785 Mdot
.52316 .33796 Mdot
.549 .69554 Mdot
.56666 .66969 Mdot
.56507 .34776 Mdot
.53445 .70489 Mdot
.4119 .29373 Mdot
.56988 .55455 Mdot
.68222 .45995 Mdot
.66819 .42831 Mdot
.51917 .35041 Mdot
.5231 .37275 Mdot
.53363 .32316 Mdot
.41776 .53598 Mdot
.55442 .69727 Mdot
.41165 .55987 Mdot
.35962 .57172 Mdot
.47849 .68207 Mdot
.5523 .70795 Mdot
.41012 .55545 Mdot
.5276 .41097 Mdot
.42625 .2859 Mdot
.54027 .36373 Mdot
.69929 .44703 Mdot
.21094 .45371 Mdot
.67025 .47574 Mdot
.40274 .50532 Mdot
.73956 .60199 Mdot
.55433 .67476 Mdot
.41898 .32637 Mdot
.3754 .30628 Mdot
.4111 .32662 Mdot
.66312 .47382 Mdot
.56739 .66586 Mdot
.61063 .56662 Mdot
.38565 .50483 Mdot
.58802 .5382 Mdot
.22653 .46217 Mdot
.66717 .71308 Mdot
.69941 .43486 Mdot
.41214 .5311 Mdot
.67146 .64034 Mdot
.28688 .67633 Mdot
.38869 .52947 Mdot
.38468 .49462 Mdot
.4946 .22349 Mdot
.3239 .50595 Mdot
.51949 .63293 Mdot
.48474 .46773 Mdot
.35567 .50814 Mdot
.4336 .45151 Mdot
.12097 .46199 Mdot
.42091 .57415 Mdot
.39828 .51478 Mdot
.36908 .55664 Mdot
.39652 .56449 Mdot
.50656 .64874 Mdot
.46498 .21015 Mdot
.67397 .42084 Mdot
.56931 .55247 Mdot
.68519 .46142 Mdot
.52775 .36285 Mdot
.5361 .45301 Mdot
.52199 .64521 Mdot
.41163 .3272 Mdot
.63034 .19328 Mdot
.5524 .56251 Mdot
.56583 .33971 Mdot
.19294 .55615 Mdot
.41877 .33465 Mdot
.34977 .50323 Mdot
.39727 .29394 Mdot
.54542 .31221 Mdot
.68011 .42769 Mdot
.4325 .52708 Mdot
.55858 .67904 Mdot
.50091 .67419 Mdot
.41517 .52968 Mdot
.72271 .67006 Mdot
.69459 .46268 Mdot
.48338 .29216 Mdot
.38216 .51095 Mdot
.38292 .49481 Mdot
.51305 .6936 Mdot
.54923 .35463 Mdot
.63021 .39732 Mdot
.42282 .30864 Mdot
.39438 .48996 Mdot
.40088 .5536 Mdot
.5811 .56341 Mdot
.67516 .41488 Mdot
.65401 .64319 Mdot
.38751 .50928 Mdot
.58638 .55357 Mdot
.40452 .50931 Mdot
.36212 .60535 Mdot
.55077 .32553 Mdot
.33198 .57665 Mdot
.34407 .52855 Mdot
.47066 .6925 Mdot
.67389 .46473 Mdot
.53429 .68255 Mdot
.51433 .72428 Mdot
.65142 .63139 Mdot
.65699 .44742 Mdot
.41175 .55181 Mdot
.64532 .4425 Mdot
.3748 .56994 Mdot
.37015 .52491 Mdot
.69965 .43479 Mdot
.54755 .6983 Mdot
.80404 .51778 Mdot
.54467 .76335 Mdot
.39555 .57462 Mdot
.38471 .55981 Mdot
.35235 .33496 Mdot
.23312 .67441 Mdot
.34267 .5311 Mdot
.55643 .6969 Mdot
.39752 .54438 Mdot
.67024 .42541 Mdot
.43582 .30913 Mdot
.52473 .67604 Mdot
.53079 .37628 Mdot
.56948 .36543 Mdot
.58323 .39768 Mdot
.66028 .65494 Mdot
.33972 .53102 Mdot
.48754 .64771 Mdot
.54773 .71291 Mdot
.60643 .60768 Mdot
.53386 .35822 Mdot
.43179 .29964 Mdot
.38848 .58678 Mdot
.26771 .51258 Mdot
.65551 .42786 Mdot
.36068 .87518 Mdot
.61441 .56676 Mdot
.44531 .3061 Mdot
.50294 .52154 Mdot
.67007 .64351 Mdot
.35095 .53622 Mdot
.38925 .32454 Mdot
.55978 .37003 Mdot
.39376 .56081 Mdot
.32979 .48643 Mdot
.70218 .33418 Mdot
.54096 .38211 Mdot
.64751 .44924 Mdot
.55486 .37463 Mdot
.42804 .28996 Mdot
.64861 .65223 Mdot
.50247 .69056 Mdot
.37698 .54031 Mdot
.46365 .51965 Mdot
.5397 .35441 Mdot
.64418 .63185 Mdot
.39796 .50928 Mdot
.50344 .66253 Mdot
.54689 .36369 Mdot
.36284 .53667 Mdot
.2747 .64959 Mdot
.47336 .61944 Mdot
.53915 .34071 Mdot
.4248 .51135 Mdot
.37255 .4309 Mdot
.55264 .38217 Mdot
.56315 .32525 Mdot
.40925 .51898 Mdot
.39891 .30322 Mdot
.35762 .51133 Mdot
.68611 .44753 Mdot
.58444 .49447 Mdot
.65622 .44011 Mdot
.23646 .43591 Mdot
.41238 .5848 Mdot
.53887 .60755 Mdot
.55117 .65616 Mdot
.37838 .31269 Mdot
.47973 .78902 Mdot
.37046 .4966 Mdot
.82693 .5081 Mdot
.55599 .43478 Mdot
.64272 .56386 Mdot
.82381 .43229 Mdot
.42421 .30494 Mdot
.68209 .44438 Mdot
.40072 .51494 Mdot
.71978 .45192 Mdot
.41395 .29773 Mdot
.23328 .43973 Mdot
.41166 .50179 Mdot
.55263 .68255 Mdot
.38426 .51354 Mdot
.51274 .6565 Mdot
.38872 .5536 Mdot
.34112 .47059 Mdot
.45909 .33552 Mdot
.3136 .30152 Mdot
.34497 .5074 Mdot
.63492 .19067 Mdot
.32639 .43893 Mdot
.42957 .32481 Mdot
.40079 .57479 Mdot
.66226 .64627 Mdot
.70668 .43888 Mdot
.60719 .2114 Mdot
.54095 .32419 Mdot
.69473 .43508 Mdot
.52094 .69923 Mdot
.50324 .31986 Mdot
.65233 .62956 Mdot
.29816 .60473 Mdot
.39167 .31029 Mdot
.65871 .45235 Mdot
.37669 .54364 Mdot
.41003 .50717 Mdot
.58274 .23086 Mdot
.30998 .76556 Mdot
.56538 .68707 Mdot
.35912 .20956 Mdot
.49266 .64335 Mdot
.4216 .31405 Mdot
.54766 .32353 Mdot
.35394 .54707 Mdot
.39378 .52451 Mdot
.51217 .34833 Mdot
.54942 .70592 Mdot
.55515 .30328 Mdot
.22009 .57942 Mdot
.74253 .44572 Mdot
.32198 .35349 Mdot
.52134 .67584 Mdot
.31975 .34985 Mdot
.4423 .30143 Mdot
.7553 .35814 Mdot
.32569 .41713 Mdot
.65172 .44706 Mdot
.32415 .35783 Mdot
.54217 .65917 Mdot
.35927 .52714 Mdot
.65999 .65192 Mdot
.67324 .63862 Mdot
.51657 .68981 Mdot
.5633 .34866 Mdot
.39389 .31998 Mdot
.38724 .5166 Mdot
.5898 .62615 Mdot
.59958 .80107 Mdot
.51707 .36545 Mdot
.31259 .57212 Mdot
.68969 .46496 Mdot
.39491 .5501 Mdot
.41464 .3411 Mdot
.68136 .43368 Mdot
.644 .65277 Mdot
.55369 .55249 Mdot
.38654 .587 Mdot
.46711 .4441 Mdot
.66503 .45381 Mdot
.23698 .68555 Mdot
.39886 .52004 Mdot
.67919 .4623 Mdot
.46277 .54806 Mdot
.60854 .73587 Mdot
.50935 .41686 Mdot
.7813 .62825 Mdot
.55147 .3892 Mdot
.5678 .36881 Mdot
.43635 .84092 Mdot
.43989 .34227 Mdot
.68866 .42106 Mdot
.64214 .6482 Mdot
.32279 .40055 Mdot
.66861 .46758 Mdot
.4343 .53455 Mdot
.37407 .58237 Mdot
.24297 .60055 Mdot
.38961 .41711 Mdot
.66017 .62564 Mdot
.35481 .62208 Mdot
.42511 .5541 Mdot
.32774 .52762 Mdot
.40591 .52918 Mdot
.51217 .70626 Mdot
.6575 .46513 Mdot
.73157 .22875 Mdot
.64309 .44813 Mdot
.57706 .60609 Mdot
.5425 .34605 Mdot
.50443 .3495 Mdot
.37074 .5457 Mdot
.49598 .59687 Mdot
.68365 .23419 Mdot
.36466 .56532 Mdot
.37448 .3029 Mdot
.25607 .39702 Mdot
.34436 .5746 Mdot
.55479 .7195 Mdot
.38317 .60185 Mdot
.49818 .64683 Mdot
.68061 .43177 Mdot
.42274 .30336 Mdot
.42854 .28576 Mdot
.67876 .45053 Mdot
.39041 .53421 Mdot
.41706 .27754 Mdot
.37186 .53833 Mdot
.36292 .51961 Mdot
.5892 .57811 Mdot
.41152 .34629 Mdot
.53251 .32271 Mdot
.41441 .32341 Mdot
.54371 .69428 Mdot
.11189 .58194 Mdot
.4038 .3162 Mdot
.30908 .461 Mdot
.55587 .45129 Mdot
.3216 .35886 Mdot
.50144 .67717 Mdot
.43569 .3176 Mdot
.65368 .45894 Mdot
.63472 .57364 Mdot
.2672 .70343 Mdot
.66177 .47179 Mdot
.39198 .52257 Mdot
.52487 .64526 Mdot
.53462 .71625 Mdot
.63599 .43538 Mdot
.52512 .70777 Mdot
.31583 .53643 Mdot
.43427 .54214 Mdot
.68445 .42082 Mdot
.64108 .77764 Mdot
.65531 .4638 Mdot
.27489 .4995 Mdot
.40515 .58073 Mdot
.52686 .67864 Mdot
.44253 .60553 Mdot
.48203 .64167 Mdot
.67696 .64491 Mdot
.34943 .56493 Mdot
.40523 .32821 Mdot
.57101 .52378 Mdot
.54058 .34061 Mdot
.74332 .59948 Mdot
.51 .65965 Mdot
.64666 .46748 Mdot
.51224 .69957 Mdot
.56171 .6939 Mdot
.65585 .46734 Mdot
.53754 .69093 Mdot
.39464 .51489 Mdot
.70656 .5154 Mdot
.5126 .65968 Mdot
.6667 .44564 Mdot
.40239 .3293 Mdot
.53898 .70445 Mdot
.56614 .31148 Mdot
.35756 .5221 Mdot
.5467 .31828 Mdot
.3962 .34853 Mdot
.52936 .64442 Mdot
.43539 .31187 Mdot
.53786 .35698 Mdot
.39302 .32255 Mdot
.71126 .47536 Mdot
.67684 .48449 Mdot
.56077 .58382 Mdot
.58147 .73903 Mdot
.5512 .66422 Mdot
.56705 .38941 Mdot
.34703 .53954 Mdot
.3743 .51092 Mdot
.40502 .28982 Mdot
.53068 .71722 Mdot
.7365 .65678 Mdot
.43937 .61634 Mdot
.70635 .68001 Mdot
.68819 .41583 Mdot
.28924 .2971 Mdot
.62056 .5685 Mdot
.65763 .56585 Mdot
.43375 .50438 Mdot
.66984 .64509 Mdot
.36493 .54154 Mdot
.25382 .37077 Mdot
.43799 .31222 Mdot
.63871 .36196 Mdot
.3872 .48561 Mdot
.52931 .33102 Mdot
.37863 .55896 Mdot
.63614 .20791 Mdot
.41255 .60408 Mdot
.42982 .32981 Mdot
.69924 .46865 Mdot
.56265 .6825 Mdot
.42175 .33206 Mdot
.57145 .36013 Mdot
.3535 .37605 Mdot
.43867 .53533 Mdot
.42784 .55381 Mdot
.58087 .36749 Mdot
.55248 .69222 Mdot
.52959 .3623 Mdot
.68213 .46021 Mdot
.40715 .3164 Mdot
.39602 .56692 Mdot
.32438 .56239 Mdot
.57608 .33528 Mdot
.64162 .43825 Mdot
.51643 .36714 Mdot
.64567 .43857 Mdot
.66928 .64743 Mdot
.33907 .5273 Mdot
.57739 .34181 Mdot
.42482 .49192 Mdot
.47107 .74051 Mdot
.57561 .57527 Mdot
.4538 .78412 Mdot
.53197 .32237 Mdot
.351 .35537 Mdot
.6748 .44889 Mdot
.66251 .4601 Mdot
.24701 .58694 Mdot
.68672 .24066 Mdot
.5954 .40959 Mdot
.57333 .18139 Mdot
.68312 .45937 Mdot
.66103 .44786 Mdot
.56057 .36809 Mdot
.53372 .6959 Mdot
.57048 .71382 Mdot
.53421 .30809 Mdot
.28806 .3245 Mdot
.54445 .66252 Mdot
.82796 .55037 Mdot
.57304 .3711 Mdot
.4426 .52318 Mdot
.67435 .62996 Mdot
.42577 .33321 Mdot
.26121 .36233 Mdot
.58685 .18707 Mdot
.35793 .54689 Mdot
.15878 .47175 Mdot
.55433 .33944 Mdot
.74388 .42928 Mdot
.76203 .38969 Mdot
.3979 .49757 Mdot
.37748 .55737 Mdot
.39494 .53514 Mdot
.38711 .34095 Mdot
.51505 .77368 Mdot
.35622 .54467 Mdot
.3204 .29969 Mdot
.38146 .59363 Mdot
.56239 .20198 Mdot
.41418 .32313 Mdot
.23923 .49323 Mdot
.54044 .38966 Mdot
.65082 .71194 Mdot
.33656 .49843 Mdot
.68249 .45748 Mdot
.71002 .37485 Mdot
.69677 .42993 Mdot
.73097 .30728 Mdot
.32109 .41866 Mdot
.51139 .70629 Mdot
.41406 .53562 Mdot
.57942 .36112 Mdot
.52871 .6454 Mdot
.63443 .39368 Mdot
.10695 .54367 Mdot
.65994 .41623 Mdot
.21678 .29148 Mdot
.65631 .45625 Mdot
.67131 .6349 Mdot
.51425 .69162 Mdot
.46751 .48918 Mdot
.58389 .54004 Mdot
.54799 .69639 Mdot
.45762 .27364 Mdot
.53352 .72689 Mdot
.33241 .34184 Mdot
.50111 .70756 Mdot
.67294 .4443 Mdot
.67372 .48364 Mdot
.39527 .47031 Mdot
.3439 .5359 Mdot
.59636 .54045 Mdot
.43996 .49958 Mdot
.34711 .55375 Mdot
.52794 .34159 Mdot
.59431 .73425 Mdot
.70542 .40261 Mdot
.51725 .67907 Mdot
.66097 .42188 Mdot
.37646 .55858 Mdot
.39655 .57446 Mdot
.35273 .49024 Mdot
.23227 .4071 Mdot
.82844 .54233 Mdot
.36624 .5257 Mdot
.36397 .59724 Mdot
.56513 .34058 Mdot
.57658 .22163 Mdot
.40578 .2011 Mdot
.32947 .40228 Mdot
.39643 .50664 Mdot
.42398 .3193 Mdot
.43103 .3319 Mdot
.30975 .54086 Mdot
.54616 .60302 Mdot
.58304 .32389 Mdot
.37686 .54378 Mdot
.39029 .39721 Mdot
.58265 .34012 Mdot
.64043 .63487 Mdot
.53908 .35442 Mdot
.52341 .64416 Mdot
.66836 .63493 Mdot
.52262 .36581 Mdot
.48164 .56372 Mdot
.65131 .63223 Mdot
.61719 .73198 Mdot
.43667 .31186 Mdot
.40366 .52569 Mdot
.5148 .62207 Mdot
.51333 .34912 Mdot
.66288 .45528 Mdot
.52817 .66795 Mdot
.70117 .4198 Mdot
.58177 .22122 Mdot
.2711 .35338 Mdot
.6663 .65446 Mdot
.68519 .45414 Mdot
.51372 .49 Mdot
.42192 .32029 Mdot
.67048 .47052 Mdot
.52033 .60647 Mdot
.35667 .57944 Mdot
.74897 .30287 Mdot
.42837 .54391 Mdot
.72098 .7002 Mdot
.66795 .4606 Mdot
.67591 .65519 Mdot
.37794 .53824 Mdot
.57322 .34834 Mdot
.44241 .49381 Mdot
.37244 .53658 Mdot
.55005 .37707 Mdot
.36157 .52674 Mdot
.39801 .34182 Mdot
.50838 .64215 Mdot
.54489 .43452 Mdot
.24394 .3636 Mdot
.39818 .33057 Mdot
.63534 .62096 Mdot
.34178 .53792 Mdot
.41264 .24674 Mdot
.54976 .68556 Mdot
.38502 .49602 Mdot
.18936 .50381 Mdot
.52322 .69288 Mdot
.54152 .67662 Mdot
.41379 .56588 Mdot
.66475 .47284 Mdot
.51781 .33577 Mdot
.42018 .32205 Mdot
.66324 .39457 Mdot
.36063 .53692 Mdot
.41189 .52867 Mdot
.41894 .33419 Mdot
.65802 .44499 Mdot
.39951 .56498 Mdot
.77694 .54408 Mdot
.60176 .60616 Mdot
.65028 .43414 Mdot
.35264 .5781 Mdot
.78326 .32821 Mdot
.57564 .70849 Mdot
.15524 .48677 Mdot
.43518 .34368 Mdot
.56076 .34142 Mdot
.30159 .55011 Mdot
.31122 .84527 Mdot
.43103 .32448 Mdot
.66333 .70701 Mdot
.36757 .52112 Mdot
.3538 .55646 Mdot
.49695 .68208 Mdot
.41452 .55446 Mdot
.52228 .65305 Mdot
.2482 .34946 Mdot
.61777 .16774 Mdot
.51788 .70285 Mdot
.51825 .65395 Mdot
.45592 .48525 Mdot
.22648 .42484 Mdot
.52516 .69949 Mdot
.4391 .53556 Mdot
.46015 .26497 Mdot
.30582 .50658 Mdot
.44365 .32261 Mdot
.38387 .29709 Mdot
.53522 .721 Mdot
.3503 .78088 Mdot
.46538 .54469 Mdot
.379 .4481 Mdot
.3622 .28044 Mdot
.69399 .44593 Mdot
.38224 .5805 Mdot
.65381 .65435 Mdot
.5494 .36578 Mdot
.3966 .60244 Mdot
.40023 .52618 Mdot
.52027 .64897 Mdot
.3826 .33632 Mdot
.675 .46885 Mdot
.40724 .51954 Mdot
.51347 .30388 Mdot
.41497 .30581 Mdot
.5124 .66162 Mdot
.30389 .46705 Mdot
.44011 .30556 Mdot
.3198 .54915 Mdot
.34925 .55578 Mdot
.40099 .50936 Mdot
.35321 .48386 Mdot
.67685 .45291 Mdot
.52236 .30925 Mdot
.30354 .53416 Mdot
.59377 .56645 Mdot
.56804 .51078 Mdot
.30467 .53926 Mdot
.55394 .69973 Mdot
.69664 .42228 Mdot
.65072 .63647 Mdot
.32287 .37957 Mdot
.41437 .57795 Mdot
.82921 .52299 Mdot
.20457 .57603 Mdot
.65715 .63413 Mdot
.49279 .68406 Mdot
.41613 .32635 Mdot
.42152 .56444 Mdot
.40419 .26635 Mdot
.43354 .53603 Mdot
.28874 .55666 Mdot
.55742 .33921 Mdot
.69596 .44931 Mdot
.60844 .63482 Mdot
.54851 .36658 Mdot
.54086 .67697 Mdot
.73983 .70653 Mdot
.5513 .72525 Mdot
.56829 .68206 Mdot
.7212 .32051 Mdot
.68546 .43003 Mdot
.33648 .86395 Mdot
.2314 .67471 Mdot
.43395 .56071 Mdot
.68232 .42415 Mdot
.51183 .68481 Mdot
.42132 .5356 Mdot
.5485 .66265 Mdot
.57314 .6967 Mdot
.3553 .57127 Mdot
.34709 .54819 Mdot
.30769 .31183 Mdot
.82625 .57696 Mdot
.40021 .32302 Mdot
.52762 .71068 Mdot
.25082 .61474 Mdot
.35406 .54286 Mdot
.38349 .505 Mdot
.71274 .35555 Mdot
.43356 .32265 Mdot
.33207 .726 Mdot
.37561 .51246 Mdot
.18735 .49527 Mdot
.34654 .55551 Mdot
.58576 .67094 Mdot
.63322 .43591 Mdot
.56393 .6095 Mdot
.51511 .33677 Mdot
.54452 .64406 Mdot
.41732 .28989 Mdot
.55154 .64622 Mdot
.25684 .59734 Mdot
.68126 .42962 Mdot
.52106 .6554 Mdot
.497 .33795 Mdot
.66553 .43593 Mdot
.65085 .44644 Mdot
.58263 .40911 Mdot
.49946 .32629 Mdot
.38954 .34032 Mdot
.70443 .44224 Mdot
.27155 .64016 Mdot
.67408 .44108 Mdot
.25885 .6147 Mdot
.35373 .5114 Mdot
.31584 .31923 Mdot
.59867 .62399 Mdot
.3767 .47336 Mdot
.66082 .46768 Mdot
.39913 .30913 Mdot
.41339 .54674 Mdot
.52883 .70875 Mdot
.40265 .31134 Mdot
.72443 .42709 Mdot
.50677 .36078 Mdot
.54057 .71776 Mdot
.68284 .47784 Mdot
.53094 .65211 Mdot
.25572 .38487 Mdot
.56036 .29605 Mdot
.5041 .4012 Mdot
.58627 .53414 Mdot
.33767 .50992 Mdot
.43539 .45306 Mdot
.40638 .50159 Mdot
.39451 .52735 Mdot
.53934 .34161 Mdot
.34545 .3199 Mdot
.54026 .70443 Mdot
.64465 .79532 Mdot
.67941 .45719 Mdot
.48768 .47302 Mdot
.28748 .56738 Mdot
.37983 .56765 Mdot
.51225 .67245 Mdot
.57252 .69064 Mdot
.47602 .75832 Mdot
.51172 .34894 Mdot
.31562 .49746 Mdot
.3257 .50735 Mdot
.30646 .49738 Mdot
.65352 .45311 Mdot
.78868 .52879 Mdot
.50734 .34995 Mdot
.15487 .36856 Mdot
.54023 .36429 Mdot
.45535 .2267 Mdot
.53653 .69125 Mdot
.42738 .29744 Mdot
.37568 .506 Mdot
.53969 .75119 Mdot
.50067 .65329 Mdot
.59274 .36261 Mdot
.41483 .32885 Mdot
.79817 .52202 Mdot
.69192 .43179 Mdot
.36825 .50193 Mdot
.35522 .57229 Mdot
.40884 .56488 Mdot
.42319 .52476 Mdot
.6762 .41864 Mdot
.43172 .52883 Mdot
.71195 .42886 Mdot
.26985 .66071 Mdot
.19303 .50403 Mdot
.57182 .33604 Mdot
.56147 .20782 Mdot
.56017 .6952 Mdot
.30529 .64041 Mdot
.32722 .72854 Mdot
.57666 .5773 Mdot
.68204 .48994 Mdot
.34548 .51771 Mdot
.56402 .3516 Mdot
.65042 .2092 Mdot
.57551 .34271 Mdot
.66423 .17234 Mdot
.2482 .56244 Mdot
.77561 .64649 Mdot
.42496 .53684 Mdot
.54277 .30665 Mdot
.37893 .78421 Mdot
.32538 .56596 Mdot
.41104 .2792 Mdot
.27345 .52822 Mdot
.64433 .75751 Mdot
.43346 .30067 Mdot
.35642 .5255 Mdot
.56054 .70136 Mdot
.39285 .51475 Mdot
.36434 .51041 Mdot
.36738 .56491 Mdot
.65159 .41679 Mdot
.35738 .57624 Mdot
.35843 .51094 Mdot
.286 .74438 Mdot
.37856 .36523 Mdot
.56769 .34156 Mdot
.45937 .77097 Mdot
.41532 .31303 Mdot
.53381 .64582 Mdot
.56074 .43873 Mdot
.69023 .44254 Mdot
.47106 .7513 Mdot
.42646 .53967 Mdot
.6951 .69402 Mdot
.6639 .48035 Mdot
.41035 .30053 Mdot
.64809 .63551 Mdot
.80008 .47492 Mdot
.52886 .31772 Mdot
.67132 .63224 Mdot
.5415 .34013 Mdot
.43924 .80212 Mdot
.5155 .65386 Mdot
.33571 .51248 Mdot
.68731 .46329 Mdot
.55573 .31983 Mdot
.35069 .27619 Mdot
.39913 .53771 Mdot
.53028 .32291 Mdot
.33488 .51809 Mdot
.57428 .50908 Mdot
.56694 .44991 Mdot
.53935 .3115 Mdot
.67744 .48222 Mdot
.66368 .43416 Mdot
.41705 .29314 Mdot
.54542 .64798 Mdot
.55748 .68539 Mdot
.67612 .43454 Mdot
.15769 .39869 Mdot
.36073 .53853 Mdot
.35161 .55956 Mdot
.60031 .56558 Mdot
.42154 .52767 Mdot
.36866 .37375 Mdot
.63595 .63074 Mdot
.55206 .66227 Mdot
.41789 .51985 Mdot
.39906 .56589 Mdot
.38586 .58606 Mdot
.27266 .35419 Mdot
.54198 .35554 Mdot
.42469 .55598 Mdot
.38913 .31753 Mdot
.62182 .67301 Mdot
.34741 .53602 Mdot
.32465 .55947 Mdot
.52766 .65333 Mdot
.31298 .25591 Mdot
.66709 .45828 Mdot
.52158 .33794 Mdot
.57159 .37422 Mdot
.25679 .43048 Mdot
.55683 .64596 Mdot
.64405 .62705 Mdot
.61607 .27107 Mdot
.64196 .64425 Mdot
.42942 .32328 Mdot
.5387 .41554 Mdot
.51839 .30087 Mdot
.57213 .36366 Mdot
.69003 .47844 Mdot
.41278 .51523 Mdot
.34734 .55618 Mdot
.66209 .70307 Mdot
.35911 .56701 Mdot
.40823 .33033 Mdot
.69225 .47121 Mdot
.52598 .65455 Mdot
.40902 .34145 Mdot
.66191 .46138 Mdot
.55269 .69289 Mdot
.35358 .58145 Mdot
.35248 .48867 Mdot
.53352 .6696 Mdot
.50641 .66648 Mdot
.3693 .55158 Mdot
.38141 .81398 Mdot
.5566 .66877 Mdot
.51687 .66638 Mdot
.68096 .65648 Mdot
.53446 .31534 Mdot
.42004 .61131 Mdot
.68233 .42505 Mdot
.39136 .50945 Mdot
.57142 .33451 Mdot
.43087 .30651 Mdot
.54013 .66747 Mdot
.39052 .58181 Mdot
.36702 .53069 Mdot
.42383 .32079 Mdot
.42862 .33856 Mdot
.40539 .33307 Mdot
.67335 .41054 Mdot
.43331 .54396 Mdot
.52822 .70167 Mdot
.69157 .43007 Mdot
.43325 .32857 Mdot
.38829 .30173 Mdot
.27942 .73346 Mdot
.35993 .54724 Mdot
.40686 .2741 Mdot
.13954 .64269 Mdot
.35513 .38183 Mdot
.66273 .62952 Mdot
.55732 .31353 Mdot
.32151 .31496 Mdot
.39934 .35334 Mdot
.69351 .4243 Mdot
.40764 .3949 Mdot
.37764 .32397 Mdot
.36464 .57268 Mdot
.39817 .54921 Mdot
.4309 .50717 Mdot
.4092 .30913 Mdot
.26319 .37291 Mdot
.54077 .7144 Mdot
.36909 .69197 Mdot
.41513 .31301 Mdot
.53738 .31178 Mdot
.57071 .32854 Mdot
.53867 .36531 Mdot
.34836 .51226 Mdot
.47813 .77356 Mdot
.256 .62671 Mdot
.344 .72629 Mdot
.69381 .43445 Mdot
.57089 .69469 Mdot
.65978 .49348 Mdot
.54218 .67641 Mdot
.55561 .35847 Mdot
.41022 .30461 Mdot
.49998 .69139 Mdot
.6532 .43868 Mdot
.65795 .43683 Mdot
.52018 .37241 Mdot
.53464 .35521 Mdot
.52137 .34868 Mdot
.5446 .64479 Mdot
.53739 .69117 Mdot
.3948 .57082 Mdot
.53179 .66144 Mdot
.20329 .59902 Mdot
.44298 .32615 Mdot
.57878 .37388 Mdot
.66871 .45328 Mdot
.50958 .66938 Mdot
.40277 .52329 Mdot
.51381 .23036 Mdot
.59064 .36729 Mdot
.39848 .33403 Mdot
.65094 .52039 Mdot
.54846 .13385 Mdot
.34106 .56567 Mdot
.64719 .43053 Mdot
.54282 .60535 Mdot
.39164 .54148 Mdot
.54855 .32731 Mdot
.22598 .5378 Mdot
.64171 .63737 Mdot
.35001 .52174 Mdot
.37744 .49259 Mdot
.6601 .46915 Mdot
.56344 .44249 Mdot
.36521 .56968 Mdot
.50327 .44753 Mdot
.64742 .42395 Mdot
.50744 .35094 Mdot
.46433 .85653 Mdot
.73898 .44044 Mdot
.31661 .2865 Mdot
.65843 .63043 Mdot
.3639 .57434 Mdot
.53067 .3409 Mdot
.39259 .33062 Mdot
.53318 .3468 Mdot
.50239 .70514 Mdot
.53744 .31774 Mdot
.40529 .53685 Mdot
.53263 .70143 Mdot
.65789 .44911 Mdot
.47532 .45627 Mdot
.32251 .76943 Mdot
.57287 .34868 Mdot
.63297 .64372 Mdot
.34999 .53382 Mdot
.29318 .67463 Mdot
.3971 .4696 Mdot
.34368 .53027 Mdot
.69885 .43161 Mdot
.5138 .67536 Mdot
.69022 .4171 Mdot
.33275 .56198 Mdot
.31966 .62926 Mdot
.68065 .45507 Mdot
.6168 .76235 Mdot
.42068 .33403 Mdot
.28606 .32712 Mdot
.38569 .52883 Mdot
.68801 .46239 Mdot
.43388 .54709 Mdot
.52795 .71126 Mdot
.55444 .52616 Mdot
.60101 .65104 Mdot
.69124 .46401 Mdot
.72896 .70303 Mdot
.55881 .47094 Mdot
.40752 .60971 Mdot
.68129 .4626 Mdot
.47853 .7865 Mdot
.65924 .64489 Mdot
.42501 .3101 Mdot
.42802 .33716 Mdot
.395 .30063 Mdot
.3571 .56613 Mdot
.30686 .48716 Mdot
.38319 .31377 Mdot
.6775 .41135 Mdot
.38653 .32756 Mdot
.23657 .41365 Mdot
.72758 .66661 Mdot
.40502 .33511 Mdot
.38414 .52628 Mdot
.32982 .56546 Mdot
.376 .36309 Mdot
.50303 .33629 Mdot
.81953 .49483 Mdot
.24673 .67546 Mdot
.35425 .54862 Mdot
.26535 .57708 Mdot
.51687 .71623 Mdot
.50505 .56317 Mdot
.40175 .62636 Mdot
.58201 .42186 Mdot
.5138 .66607 Mdot
.58897 .50811 Mdot
.55117 .65841 Mdot
.33015 .53502 Mdot
.37109 .52413 Mdot
.50139 .64865 Mdot
.734 .59265 Mdot
.55672 .80613 Mdot
.71156 .67912 Mdot
.5577 .69287 Mdot
.67365 .46494 Mdot
.64933 .42476 Mdot
.69933 .43593 Mdot
.51522 .34725 Mdot
.50544 .66236 Mdot
.42439 .5661 Mdot
.56997 .35593 Mdot
.37712 .50795 Mdot
.67222 .43031 Mdot
.60189 .60791 Mdot
.52502 .65408 Mdot
.37912 .54184 Mdot
.27416 .70852 Mdot
.54774 .34602 Mdot
.42237 .31812 Mdot
.67388 .52662 Mdot
.56375 .31777 Mdot
.64478 .45235 Mdot
.58071 .67861 Mdot
.53337 .39445 Mdot
.46686 .20828 Mdot
.44231 .53981 Mdot
.44068 .54423 Mdot
.6124 .35256 Mdot
.30794 .74838 Mdot
.37523 .56565 Mdot
.57112 .36253 Mdot
.53355 .31392 Mdot
.43522 .55021 Mdot
.50229 .68732 Mdot
.38016 .32363 Mdot
.4067 .28968 Mdot
.34857 .49984 Mdot
.5932 .53519 Mdot
.31348 .31357 Mdot
.40782 .55712 Mdot
.3131 .58381 Mdot
.49877 .3421 Mdot
.65329 .62955 Mdot
.5792 .55497 Mdot
.40706 .29346 Mdot
.36734 .51969 Mdot
.57518 .79764 Mdot
.51779 .65727 Mdot
.5217 .33029 Mdot
.66297 .42574 Mdot
.42229 .28026 Mdot
.55686 .38492 Mdot
.43518 .55055 Mdot
.39952 .56523 Mdot
.67903 .4692 Mdot
.5854 .66799 Mdot
.40798 .30688 Mdot
.56913 .35156 Mdot
.427 .2968 Mdot
.54317 .69072 Mdot
.51885 .66207 Mdot
.32335 .511 Mdot
.39045 .47202 Mdot
.57393 .36677 Mdot
.40545 .494 Mdot
.54023 .36887 Mdot
.58173 .22915 Mdot
.6567 .42668 Mdot
.39283 .4964 Mdot
.52152 .62928 Mdot
.6732 .43089 Mdot
.35926 .55593 Mdot
.61246 .35508 Mdot
.39576 .56133 Mdot
.53766 .30719 Mdot
.22568 .5618 Mdot
.41529 .29702 Mdot
.42775 .45231 Mdot
.47168 .54277 Mdot
.42093 .52772 Mdot
.50829 .31961 Mdot
.32893 .47113 Mdot
.68174 .45194 Mdot
.52679 .68894 Mdot
.26012 .28183 Mdot
.6688 .44372 Mdot
.38289 .5175 Mdot
.40482 .31528 Mdot
.56371 .68074 Mdot
.67149 .65054 Mdot
.61016 .55461 Mdot
.40693 .60237 Mdot
.45062 .54049 Mdot
.40419 .51304 Mdot
.57394 .18044 Mdot
.52521 .34601 Mdot
.51028 .67736 Mdot
.65366 .42339 Mdot
.6853 .43574 Mdot
.54956 .35436 Mdot
.6709 .74058 Mdot
.75366 .60826 Mdot
.17 .69252 Mdot
.56553 .38177 Mdot
.38616 .31565 Mdot
.55883 .50959 Mdot
.54696 .36804 Mdot
.52673 .33738 Mdot
.50612 .36174 Mdot
.68006 .69058 Mdot
.55221 .69809 Mdot
.36504 .53074 Mdot
.54513 .64046 Mdot
.36219 .57325 Mdot
.34458 .27231 Mdot
.67889 .43295 Mdot
.52883 .68987 Mdot
.57111 .29382 Mdot
.46244 .55458 Mdot
.38514 .55104 Mdot
.42104 .26755 Mdot
.41568 .59543 Mdot
.32578 .36725 Mdot
.34591 .49216 Mdot
.53908 .34923 Mdot
.35124 .62828 Mdot
.3159 .5705 Mdot
.26499 .69126 Mdot
.65507 .44141 Mdot
.67415 .65214 Mdot
.35559 .58427 Mdot
.35993 .60717 Mdot
.56419 .67688 Mdot
.49882 .68944 Mdot
.38258 .3149 Mdot
.69863 .52258 Mdot
.65513 .44426 Mdot
.79425 .58527 Mdot
.34298 .53645 Mdot
.69268 .3976 Mdot
.22263 .5598 Mdot
.3646 .55646 Mdot
.54389 .41194 Mdot
.4724 .75299 Mdot
.38349 .56552 Mdot
.35564 .72493 Mdot
.67032 .45007 Mdot
.18828 .49846 Mdot
.37993 .48726 Mdot
.54714 .3272 Mdot
.53275 .69464 Mdot
.54044 .71753 Mdot
.39952 .33699 Mdot
.21333 .63277 Mdot
.6189 .45063 Mdot
.53409 .6917 Mdot
.39773 .53466 Mdot
.6663 .45656 Mdot
.67568 .64903 Mdot
.44684 .58198 Mdot
.70597 .27526 Mdot
.52928 .65856 Mdot
.30221 .54232 Mdot
.70962 .68496 Mdot
.57354 .47336 Mdot
.83127 .56523 Mdot
.70088 .4434 Mdot
.40666 .29296 Mdot
.37918 .47865 Mdot
.61409 .27135 Mdot
.37457 .48586 Mdot
.33316 .27736 Mdot
.4823 .63367 Mdot
.43566 .30868 Mdot
.38852 .54071 Mdot
.3671 .56964 Mdot
.5758 .53036 Mdot
.43624 .32917 Mdot
.36553 .57019 Mdot
.31375 .50986 Mdot
.55345 .68804 Mdot
.63422 .63204 Mdot
.53098 .65577 Mdot
.3933 .52191 Mdot
.23929 .52911 Mdot
.50331 .69398 Mdot
.81236 .50488 Mdot
.43964 .34656 Mdot
.69043 .44335 Mdot
.31917 .58198 Mdot
.34741 .51861 Mdot
.83912 .41948 Mdot
.67672 .64362 Mdot
.36374 .21526 Mdot
.547 .30893 Mdot
.59241 .82907 Mdot
.56856 .32172 Mdot
.76021 .66973 Mdot
.49278 .47165 Mdot
.42504 .50588 Mdot
.35602 .41144 Mdot
.34429 .71965 Mdot
.71692 .45468 Mdot
.29896 .65488 Mdot
.34399 .53584 Mdot
.35422 .53178 Mdot
.56438 .36699 Mdot
.68877 .72367 Mdot
.55987 .61094 Mdot
.57893 .54892 Mdot
.4137 .30168 Mdot
.53795 .6853 Mdot
.40224 .54137 Mdot
.70479 .56789 Mdot
.56405 .3309 Mdot
.29468 .46742 Mdot
.37949 .53923 Mdot
.57022 .60492 Mdot
.64785 .73924 Mdot
.65963 .45423 Mdot
.533 .31022 Mdot
.51631 .31232 Mdot
.37446 .58116 Mdot
.68253 .42171 Mdot
.38823 .56977 Mdot
.55651 .47397 Mdot
.37372 .59846 Mdot
.43312 .31422 Mdot
.38082 .50412 Mdot
.38389 .40915 Mdot
.76047 .69793 Mdot
.34948 .59525 Mdot
.56024 .66217 Mdot
.51854 .35371 Mdot
.54409 .35954 Mdot
.55776 .68567 Mdot
.54519 .35981 Mdot
.37234 .69954 Mdot
.27745 .61435 Mdot
.43174 .32106 Mdot
.32439 .73345 Mdot
.41735 .29958 Mdot
.67292 .65305 Mdot
.36217 .54958 Mdot
.64716 .28006 Mdot
.56552 .38229 Mdot
.21404 .44987 Mdot
.67708 .43864 Mdot
.67557 .64095 Mdot
.40716 .58403 Mdot
.38653 .27648 Mdot
.5605 .35709 Mdot
.7375 .39518 Mdot
.38574 .58493 Mdot
.54088 .70859 Mdot
.37877 .56742 Mdot
.42116 .58463 Mdot
.66639 .62979 Mdot
.40587 .51302 Mdot
.66208 .4615 Mdot
.50553 .66034 Mdot
.76173 .66129 Mdot
.51372 .34806 Mdot
.35249 .52297 Mdot
.39646 .53584 Mdot
.49569 .68495 Mdot
.40529 .58592 Mdot
.69185 .42454 Mdot
.39909 .89482 Mdot
.4236 .33176 Mdot
.65082 .63001 Mdot
.77866 .44318 Mdot
.4093 .54063 Mdot
.40985 .55138 Mdot
.62014 .40456 Mdot
.55518 .79251 Mdot
.67652 .46017 Mdot
.381 .59499 Mdot
.56062 .33231 Mdot
.40413 .30725 Mdot
.70702 .43876 Mdot
.43334 .54029 Mdot
.35434 .53393 Mdot
.43268 .32186 Mdot
.41534 .266 Mdot
.56596 .30926 Mdot
.69578 .43421 Mdot
.27073 .57806 Mdot
.52362 .23281 Mdot
.36636 .53934 Mdot
.69709 .62666 Mdot
.5186 .67072 Mdot
.6864 .45868 Mdot
.52056 .77422 Mdot
.333 .52571 Mdot
.65019 .45886 Mdot
.65692 .44735 Mdot
.39574 .58804 Mdot
.5636 .65002 Mdot
.57234 .67001 Mdot
.51685 .66966 Mdot
.19886 .49889 Mdot
.45137 .19073 Mdot
.5201 .34729 Mdot
.66536 .45032 Mdot
.57485 .33868 Mdot
.38144 .30775 Mdot
.56988 .5119 Mdot
.53754 .3126 Mdot
.55974 .69757 Mdot
.58029 .35622 Mdot
.39263 .56633 Mdot
.65729 .43349 Mdot
.569 .37396 Mdot
.41987 .54044 Mdot
.30529 .57416 Mdot
.37496 .41116 Mdot
.38134 .33094 Mdot
.59031 .51079 Mdot
.38736 .519 Mdot
.65073 .63461 Mdot
.37148 .54888 Mdot
.68567 .42083 Mdot
.4144 .40081 Mdot
.42591 .54779 Mdot
.5677 .38127 Mdot
.48299 .20151 Mdot
.50882 .32175 Mdot
.4159 .58473 Mdot
.39195 .52181 Mdot
.36339 .54009 Mdot
.35141 .56546 Mdot
.62838 .76391 Mdot
.7141 .43129 Mdot
.2901 .54387 Mdot
.54557 .38335 Mdot
.54063 .67223 Mdot
.51702 .70835 Mdot
.59771 .41277 Mdot
.67839 .64017 Mdot
.68119 .42274 Mdot
.36254 .53887 Mdot
.73578 .39403 Mdot
.63184 .56666 Mdot
.71428 .6802 Mdot
.59366 .39427 Mdot
.57087 .36637 Mdot
.5613 .66071 Mdot
.54389 .37511 Mdot
.43476 .54066 Mdot
.35072 .48849 Mdot
.77207 .64962 Mdot
.67148 .40847 Mdot
.40932 .30603 Mdot
.37996 .50702 Mdot
.30109 .30975 Mdot
.56522 .34076 Mdot
.49782 .33645 Mdot
.3882 .5717 Mdot
.57035 .70936 Mdot
.81436 .63757 Mdot
.67191 .42237 Mdot
.28855 .66874 Mdot
.54428 .62209 Mdot
.27785 .55398 Mdot
.68044 .44854 Mdot
.50919 .40957 Mdot
.50548 .33879 Mdot
.23549 .66294 Mdot
.53397 .66783 Mdot
.41234 .30693 Mdot
.30931 .52498 Mdot
.56022 .69685 Mdot
.5801 .34569 Mdot
.53905 .64904 Mdot
.33414 .51525 Mdot
.67697 .41298 Mdot
.54389 .36377 Mdot
.71581 .4479 Mdot
.50312 .64953 Mdot
.41622 .29838 Mdot
.22216 .44709 Mdot
.28135 .66574 Mdot
.47265 .75291 Mdot
.42447 .55693 Mdot
.68333 .30371 Mdot
.42188 .5694 Mdot
.57065 .68251 Mdot
.38565 .5283 Mdot
.42918 .44727 Mdot
.50469 .35043 Mdot
.30855 .55722 Mdot
.37106 .50473 Mdot
.25666 .6696 Mdot
.37477 .55679 Mdot
.41687 .57804 Mdot
.36293 .49284 Mdot
.58038 .65066 Mdot
.3091 .55434 Mdot
.53995 .70827 Mdot
.66963 .70646 Mdot
.52859 .3358 Mdot
.39665 .29215 Mdot
.42723 .29048 Mdot
.32982 .27691 Mdot
.29121 .32193 Mdot
.67623 .73264 Mdot
.54659 .66634 Mdot
.65571 .46069 Mdot
.39057 .56914 Mdot
.47185 .79509 Mdot
.26377 .47557 Mdot
.50638 .34496 Mdot
.57761 .36314 Mdot
.32759 .50011 Mdot
.65069 .19512 Mdot
.30623 .55059 Mdot
.612 .56638 Mdot
.35848 .56994 Mdot
.38657 .49523 Mdot
.49633 .33046 Mdot
.25565 .38028 Mdot
.42485 .55581 Mdot
.56382 .67647 Mdot
.41967 .30938 Mdot
.29319 .60003 Mdot
.25184 .48108 Mdot
.26472 .51705 Mdot
.48027 .60784 Mdot
.42913 .53359 Mdot
.565 .34517 Mdot
.56164 .6884 Mdot
.59111 .5617 Mdot
.69423 .43031 Mdot
.60146 .54401 Mdot
.26767 .65018 Mdot
.74268 .46137 Mdot
.41431 .30578 Mdot
.59765 .36955 Mdot
.40618 .53603 Mdot
.51596 .3474 Mdot
.33083 .55133 Mdot
.63669 .56263 Mdot
.43323 .30824 Mdot
.53252 .64141 Mdot
.67266 .46503 Mdot
.54901 .70769 Mdot
.4555 .78269 Mdot
.2581 .48683 Mdot
.59221 .82977 Mdot
.52399 .32043 Mdot
.44395 .64763 Mdot
.51812 .69174 Mdot
.40103 .58327 Mdot
.16544 .68356 Mdot
.52136 .67458 Mdot
.54874 .70618 Mdot
.57507 .42538 Mdot
.23638 .43573 Mdot
.30463 .55638 Mdot
.54682 .65547 Mdot
.54463 .39136 Mdot
.40994 .3253 Mdot
.41758 .54697 Mdot
.34221 .50914 Mdot
.49806 .68663 Mdot
.55807 .35595 Mdot
.30148 .30333 Mdot
.53725 .35291 Mdot
.54732 .70098 Mdot
.54652 .33764 Mdot
.80681 .50811 Mdot
.55458 .32233 Mdot
.37063 .50411 Mdot
.36363 .53841 Mdot
.66264 .25534 Mdot
.51891 .66207 Mdot
.4118 .54856 Mdot
.36382 .52436 Mdot
.52255 .6985 Mdot
.51034 .30264 Mdot
.49218 .74889 Mdot
.41777 .53462 Mdot
.363 .53453 Mdot
.43759 .30959 Mdot
.57692 .49453 Mdot
.66962 .58147 Mdot
.41561 .54731 Mdot
.39163 .30511 Mdot
.54684 .64579 Mdot
.37194 .55025 Mdot
.25523 .37797 Mdot
.58171 .33979 Mdot
.42494 .51969 Mdot
.66659 .65308 Mdot
.36967 .56542 Mdot
.80878 .64246 Mdot
.35146 .5302 Mdot
.51229 .68895 Mdot
.52577 .69421 Mdot
.57982 .32635 Mdot
.53894 .6768 Mdot
.66591 .63151 Mdot
.6673 .43311 Mdot
.71499 .72166 Mdot
.66906 .63457 Mdot
.37877 .49762 Mdot
.23058 .67406 Mdot
.34286 .50581 Mdot
.32973 .57095 Mdot
.22106 .43504 Mdot
.66121 .63134 Mdot
.51454 .6792 Mdot
.73445 .58764 Mdot
.42323 .50715 Mdot
.67604 .42172 Mdot
.32525 .56479 Mdot
.4249 .51918 Mdot
.39239 .42041 Mdot
.27726 .60645 Mdot
.69773 .46733 Mdot
.42037 .61009 Mdot
.4169 .54818 Mdot
.54847 .79045 Mdot
.4036 .53222 Mdot
.40439 .33632 Mdot
.55096 .66804 Mdot
.53573 .37453 Mdot
.42502 .32592 Mdot
.40723 .539 Mdot
.41155 .31057 Mdot
.51983 .34457 Mdot
.70091 .45125 Mdot
.38624 .50423 Mdot
.44464 .31751 Mdot
.40866 .30404 Mdot
.40172 .57637 Mdot
.53163 .69223 Mdot
.40321 .46894 Mdot
.37102 .55204 Mdot
.4323 .55985 Mdot
.55742 .68497 Mdot
.1515 .54882 Mdot
.35986 .5751 Mdot
.51341 .40909 Mdot
.49116 .64918 Mdot
.64853 .627 Mdot
.55406 .37271 Mdot
.41725 .48871 Mdot
.68566 .43256 Mdot
.67275 .4335 Mdot
.52438 .3771 Mdot
.49707 .66742 Mdot
.5474 .3633 Mdot
.42732 .60169 Mdot
.33031 .49706 Mdot
.31119 .52061 Mdot
.26196 .28026 Mdot
.79733 .46841 Mdot
.50542 .67892 Mdot
.50457 .33113 Mdot
.59272 .54108 Mdot
.67229 .42498 Mdot
.49957 .35649 Mdot
.50191 .63354 Mdot
.5151 .65059 Mdot
.55963 .68175 Mdot
.39661 .3037 Mdot
.53477 .35976 Mdot
.48102 .6485 Mdot
.57616 .67601 Mdot
.39329 .57512 Mdot
.41737 .54912 Mdot
.5245 .72347 Mdot
.39699 .36946 Mdot
.4282 .3055 Mdot
.55787 .3354 Mdot
.87218 .4908 Mdot
.67134 .42221 Mdot
.25683 .67093 Mdot
.41963 .53938 Mdot
.08975 .49315 Mdot
.3069 .54908 Mdot
.39964 .53396 Mdot
.52308 .64412 Mdot
.43851 .29507 Mdot
.41012 .32218 Mdot
.51925 .69266 Mdot
.57815 .69473 Mdot
.39233 .3151 Mdot
.56743 .41812 Mdot
.71594 .73824 Mdot
.59233 .55442 Mdot
.51461 .69502 Mdot
.28831 .68017 Mdot
.70619 .44298 Mdot
.5038 .64029 Mdot
.70989 .45692 Mdot
.52682 .33571 Mdot
.5745 .349 Mdot
.68046 .46981 Mdot
.39786 .58571 Mdot
.53148 .32007 Mdot
.38357 .6034 Mdot
.80357 .59919 Mdot
.74939 .32942 Mdot
.49533 .82113 Mdot
.34051 .53917 Mdot
.55285 .60529 Mdot
.63821 .70202 Mdot
.4093 .51778 Mdot
.44708 .60344 Mdot
.4097 .30759 Mdot
.49786 .64421 Mdot
.7091 .43399 Mdot
.82882 .50194 Mdot
.36517 .53934 Mdot
.5409 .70425 Mdot
.66312 .42863 Mdot
.80255 .50719 Mdot
.50312 .44594 Mdot
.37601 .57468 Mdot
.21665 .75592 Mdot
.50573 .64906 Mdot
.5351 .37418 Mdot
.30209 .72842 Mdot
.53553 .63725 Mdot
.51531 .22274 Mdot
.5223 .30811 Mdot
.62562 .60411 Mdot
.52247 .64686 Mdot
.5398 .2984 Mdot
.54398 .68767 Mdot
.40048 .34215 Mdot
.5811 .67852 Mdot
.55293 .34833 Mdot
.38354 .54718 Mdot
.55036 .34962 Mdot
.42741 .3324 Mdot
.51885 .32903 Mdot
.70913 .43469 Mdot
.65549 .63112 Mdot
.66128 .43338 Mdot
.5666 .50843 Mdot
.44245 .67764 Mdot
.6962 .44887 Mdot
.72671 .38119 Mdot
.38117 .56294 Mdot
.58578 .67267 Mdot
.53041 .37413 Mdot
.56862 .38581 Mdot
.59395 .52417 Mdot
.54676 .69759 Mdot
.55444 .34331 Mdot
.27425 .65098 Mdot
.14465 .41844 Mdot
.32546 .58366 Mdot
.46676 .18739 Mdot
.52119 .69861 Mdot
.50337 .34907 Mdot
.60264 .56538 Mdot
.52784 .71622 Mdot
.57182 .37055 Mdot
.67834 .46469 Mdot
.68679 .43826 Mdot
.38118 .58708 Mdot
.63444 .43719 Mdot
.50658 .32025 Mdot
.56992 .79681 Mdot
.55435 .67289 Mdot
.78568 .46364 Mdot
.39943 .33136 Mdot
.52349 .33946 Mdot
.30701 .55842 Mdot
.47569 .64416 Mdot
.57474 .37296 Mdot
.69626 .25414 Mdot
.86227 .45246 Mdot
.55425 .34213 Mdot
.54998 .66661 Mdot
.54276 .66998 Mdot
.34406 .59221 Mdot
.58536 .53773 Mdot
.55926 .35239 Mdot
.64587 .27759 Mdot
.33547 .28327 Mdot
.66954 .64737 Mdot
.26366 .71144 Mdot
.42572 .55485 Mdot
.42878 .53101 Mdot
.69432 .42696 Mdot
.3859 .55292 Mdot
.57432 .69438 Mdot
.30656 .54063 Mdot
.65329 .42001 Mdot
.50787 .3501 Mdot
.36315 .54577 Mdot
.39815 .31172 Mdot
.69874 .42703 Mdot
.6402 .44567 Mdot
.53875 .33362 Mdot
.55178 .66439 Mdot
.72226 .59839 Mdot
.53676 .35429 Mdot
.43208 .54234 Mdot
.65974 .63746 Mdot
.35283 .4903 Mdot
.66603 .26509 Mdot
.54349 .71359 Mdot
.54238 .37489 Mdot
.48995 .67595 Mdot
.66252 .44614 Mdot
.53817 .38702 Mdot
.40787 .52756 Mdot
.57483 .3605 Mdot
.49798 .40246 Mdot
.44668 .24854 Mdot
.5773 .68298 Mdot
.36898 .30995 Mdot
.49797 .68869 Mdot
.66983 .64787 Mdot
.28205 .40704 Mdot
.42653 .30934 Mdot
.54705 .32076 Mdot
.81537 .49799 Mdot
.53254 .37723 Mdot
.37101 .55808 Mdot
.34927 .55267 Mdot
.56297 .36832 Mdot
.40604 .29684 Mdot
.26788 .32925 Mdot
.36108 .27336 Mdot
.51355 .6572 Mdot
.50372 .49832 Mdot
.86877 .53116 Mdot
.49416 .35981 Mdot
.65817 .46398 Mdot
.36703 .61594 Mdot
.39591 .55837 Mdot
.65694 .46744 Mdot
.66068 .42256 Mdot
.43173 .33038 Mdot
.51638 .34408 Mdot
.48508 .6509 Mdot
.69829 .45924 Mdot
.47027 .67475 Mdot
.27415 .33933 Mdot
.42094 .59049 Mdot
.31796 .48425 Mdot
.35581 .50806 Mdot
.57444 .47504 Mdot
.67659 .41484 Mdot
.38129 .52192 Mdot
.33716 .49197 Mdot
.6863 .45652 Mdot
.42055 .33822 Mdot
.49775 .72014 Mdot
.54841 .33224 Mdot
.1193 .44783 Mdot
.38463 .50409 Mdot
.37879 .54994 Mdot
.69364 .43456 Mdot
.3285 .76541 Mdot
.50769 .6889 Mdot
.54803 .66012 Mdot
.52443 .34656 Mdot
.60815 .52318 Mdot
.4221 .57621 Mdot
.40186 .51645 Mdot
.53857 .32159 Mdot
.65178 .63478 Mdot
.4522 .83857 Mdot
.36959 .53015 Mdot
.67386 .45109 Mdot
.70887 .3764 Mdot
.68271 .41514 Mdot
.33901 .56376 Mdot
.36595 .55922 Mdot
.38796 .50134 Mdot
.34415 .55982 Mdot
.68473 .4703 Mdot
.40699 .51853 Mdot
.44344 .49659 Mdot
.515 .67441 Mdot
.42879 .54236 Mdot
.32419 .29174 Mdot
.37032 .53365 Mdot
.39881 .31194 Mdot
.67955 .58412 Mdot
.35488 .52216 Mdot
.42946 .5404 Mdot
.36411 .26946 Mdot
.39119 .53624 Mdot
.65066 .44009 Mdot
.5368 .66728 Mdot
.66236 .44909 Mdot
.65542 .45496 Mdot
.57988 .36431 Mdot
.41352 .34434 Mdot
.39405 .48752 Mdot
.39101 .3149 Mdot
.36758 .59876 Mdot
.33216 .52538 Mdot
.5736 .50258 Mdot
.61306 .5663 Mdot
.39016 .35092 Mdot
.40532 .52282 Mdot
.52776 .34258 Mdot
.54981 .37525 Mdot
.40615 .39374 Mdot
.38537 .6019 Mdot
.70778 .44078 Mdot
.68771 .46243 Mdot
.37162 .37719 Mdot
.43636 .42726 Mdot
.40296 .30511 Mdot
.54645 .5457 Mdot
.34314 .51275 Mdot
.35938 .52399 Mdot
.32918 .56584 Mdot
.55389 .31439 Mdot
.65316 .63069 Mdot
.50911 .35042 Mdot
.66049 .66025 Mdot
.70225 .4217 Mdot
.34061 .53821 Mdot
.76228 .35732 Mdot
.49929 .67754 Mdot
.53541 .66615 Mdot
.64877 .42338 Mdot
.50834 .32151 Mdot
.38101 .60053 Mdot
.28721 .24119 Mdot
.55599 .71456 Mdot
.40069 .2914 Mdot
.394 .51586 Mdot
.53463 .33494 Mdot
.50365 .66064 Mdot
.40664 .34823 Mdot
.34073 .53032 Mdot
.49277 .33901 Mdot
.37934 .53084 Mdot
.36311 .7409 Mdot
.51934 .68283 Mdot
.60346 .60556 Mdot
.55929 .72133 Mdot
.65897 .46693 Mdot
.67001 .46122 Mdot
.36033 .55685 Mdot
.20252 .32256 Mdot
.52276 .72864 Mdot
.66289 .47371 Mdot
.39133 .33964 Mdot
.6478 .63288 Mdot
.39843 .34483 Mdot
.54246 .36931 Mdot
.41892 .30771 Mdot
.57112 .37544 Mdot
.40673 .3763 Mdot
.49497 .70253 Mdot
.42548 .32828 Mdot
.33433 .77364 Mdot
.35481 .4874 Mdot
.43611 .3247 Mdot
.3257 .50192 Mdot
.45765 .4913 Mdot
.53481 .32346 Mdot
.40023 .30259 Mdot
.39197 .58161 Mdot
.78731 .42725 Mdot
.66168 .45978 Mdot
.70866 .43919 Mdot
.38082 .48588 Mdot
.50263 .35368 Mdot
.57905 .68286 Mdot
.54706 .43894 Mdot
.64515 .62835 Mdot
.40149 .51682 Mdot
.34008 .52416 Mdot
.49305 .66168 Mdot
.56737 .68441 Mdot
.36116 .55907 Mdot
.27796 .64573 Mdot
.40754 .5352 Mdot
.68685 .44162 Mdot
.50746 .66047 Mdot
.5391 .66658 Mdot
.52467 .3119 Mdot
.49707 .66848 Mdot
.30626 .50319 Mdot
.66428 .48752 Mdot
.31848 .5264 Mdot
.66495 .44414 Mdot
.42542 .39629 Mdot
.51419 .34276 Mdot
.81906 .49089 Mdot
.50059 .66144 Mdot
.41739 .51855 Mdot
.51425 .70564 Mdot
.40595 .33278 Mdot
.52009 .66111 Mdot
.51671 .71748 Mdot
.34487 .54118 Mdot
.3668 .57477 Mdot
.65441 .63615 Mdot
.59048 .53414 Mdot
.52525 .68452 Mdot
.41476 .53005 Mdot
.3765 .48843 Mdot
.36662 .57926 Mdot
.5601 .46981 Mdot
.53353 .64456 Mdot
.24624 .60061 Mdot
.70541 .2894 Mdot
.53109 .68948 Mdot
.84698 .53386 Mdot
.64344 .64824 Mdot
.67921 .64113 Mdot
.6593 .47492 Mdot
.36452 .5317 Mdot
.54876 .36042 Mdot
.42787 .5253 Mdot
.39153 .60318 Mdot
.35468 .51974 Mdot
.43499 .31803 Mdot
.44298 .53305 Mdot
.65414 .65016 Mdot
.54132 .35219 Mdot
.41343 .53617 Mdot
.35924 .54294 Mdot
.68016 .64729 Mdot
.55138 .7258 Mdot
.51588 .65089 Mdot
.68478 .61113 Mdot
.41687 .33827 Mdot
.69725 .43074 Mdot
.43095 .53193 Mdot
.52658 .34464 Mdot
.54831 .35486 Mdot
.5486 .70728 Mdot
.55043 .3301 Mdot
.69254 .42166 Mdot
.40099 .53711 Mdot
.66191 .46941 Mdot
.43475 .31879 Mdot
.5514 .66877 Mdot
.4334 .53765 Mdot
.39197 .57689 Mdot
.52544 .69398 Mdot
.37714 .56484 Mdot
.43665 .30794 Mdot
.5606 .32291 Mdot
.50884 .66467 Mdot
.66826 .43346 Mdot
.53056 .31132 Mdot
.39598 .56574 Mdot
.81045 .34616 Mdot
.38652 .55329 Mdot
.3963 .50795 Mdot
.73539 .70293 Mdot
.34112 .49653 Mdot
.51776 .36568 Mdot
.5119 .70516 Mdot
.34429 .57008 Mdot
.34502 .27724 Mdot
.52383 .28035 Mdot
.48926 .33031 Mdot
.39466 .51427 Mdot
.83332 .53903 Mdot
.41952 .52201 Mdot
.80829 .53167 Mdot
.57401 .50429 Mdot
.5896 .19124 Mdot
.32855 .47819 Mdot
.6599 .47183 Mdot
.65422 .634 Mdot
.52222 .37201 Mdot
.41064 .78226 Mdot
.38137 .55976 Mdot
.49393 .77923 Mdot
.43119 .52783 Mdot
.68219 .44654 Mdot
.43537 .61391 Mdot
.55618 .33381 Mdot
.24953 .68138 Mdot
.42879 .56131 Mdot
.52282 .64512 Mdot
.56141 .39088 Mdot
.6435 .6376 Mdot
.39017 .58281 Mdot
.39359 .32633 Mdot
.54852 .2899 Mdot
.31962 .4922 Mdot
.6643 .44194 Mdot
.36444 .52193 Mdot
.38477 .61347 Mdot
.16165 .39814 Mdot
.51306 .67172 Mdot
.66415 .46621 Mdot
.49634 .57612 Mdot
.35187 .56229 Mdot
.51735 .65008 Mdot
.53658 .66955 Mdot
.39371 .33418 Mdot
.63729 .55009 Mdot
.49142 .28441 Mdot
.75596 .3156 Mdot
.46854 .76395 Mdot
.54643 .30965 Mdot
.59072 .76233 Mdot
.42111 .55295 Mdot
.25427 .49388 Mdot
.65349 .44926 Mdot
.38158 .54742 Mdot
.44655 .72639 Mdot
.51637 .66677 Mdot
.37743 .52759 Mdot
.42947 .30735 Mdot
.67398 .67402 Mdot
.2667 .54645 Mdot
.82475 .40145 Mdot
.52269 .38215 Mdot
.31636 .55252 Mdot
.34053 .47991 Mdot
.64994 .62693 Mdot
.3378 .56054 Mdot
.52527 .37201 Mdot
.69326 .3129 Mdot
.4128 .29497 Mdot
.49943 .67331 Mdot
.64122 .64563 Mdot
.42802 .51855 Mdot
.34626 .49809 Mdot
.39444 .29405 Mdot
.40958 .57873 Mdot
.28348 .7072 Mdot
.68711 .64154 Mdot
.55507 .32204 Mdot
.54308 .65096 Mdot
.35367 .50896 Mdot
.65104 .63257 Mdot
.3457 .54492 Mdot
.46215 .48925 Mdot
.38937 .51171 Mdot
.68189 .74554 Mdot
.53412 .69467 Mdot
.66118 .43964 Mdot
.44209 .52245 Mdot
.37282 .53929 Mdot
.52594 .23501 Mdot
.39562 .60296 Mdot
.35188 .53136 Mdot
.56374 .69483 Mdot
.50123 .68817 Mdot
.54944 .70294 Mdot
.5469 .31794 Mdot
.5865 .55344 Mdot
.67906 .44182 Mdot
.34268 .58247 Mdot
.70441 .44909 Mdot
.39625 .45458 Mdot
.38995 .30125 Mdot
.82164 .46122 Mdot
.39837 .54736 Mdot
.55612 .69056 Mdot
.59026 .78322 Mdot
.54747 .64592 Mdot
.63266 .42346 Mdot
.65474 .44318 Mdot
.52319 .67732 Mdot
.39427 .53091 Mdot
.57784 .54772 Mdot
.80475 .35716 Mdot
.672 .42593 Mdot
.32299 .54669 Mdot
.5303 .38695 Mdot
.561 .38602 Mdot
.83776 .59253 Mdot
.65162 .45321 Mdot
.6357 .70225 Mdot
.41869 .5287 Mdot
.49797 .67879 Mdot
.69913 .44278 Mdot
.64941 .43891 Mdot
.54322 .32319 Mdot
.3806 .57479 Mdot
.37422 .53669 Mdot
.6636 .65375 Mdot
.69943 .45493 Mdot
.45563 .55432 Mdot
.37355 .57186 Mdot
.76159 .66545 Mdot
.49582 .63533 Mdot
.15123 .56263 Mdot
.42399 .60412 Mdot
.45126 .72529 Mdot
.47537 .43064 Mdot
.50427 .67239 Mdot
.42186 .57303 Mdot
.34726 .58601 Mdot
.53961 .30882 Mdot
.39716 .54227 Mdot
.50978 .33016 Mdot
.65438 .46109 Mdot
.82822 .46369 Mdot
.72566 .39422 Mdot
.68078 .49062 Mdot
.38096 .55501 Mdot
.27133 .53409 Mdot
.41711 .3306 Mdot
.68944 .40925 Mdot
.52842 .70733 Mdot
.35169 .50681 Mdot
.53438 .30435 Mdot
.55265 .32323 Mdot
.52935 .66906 Mdot
.64294 .72039 Mdot
.81267 .50625 Mdot
.34188 .55664 Mdot
.54817 .37181 Mdot
.74739 .41196 Mdot
.30179 .64395 Mdot
.64688 .46309 Mdot
.41642 .29553 Mdot
.51392 .35902 Mdot
.64737 .41945 Mdot
.44913 .47339 Mdot
.53189 .6775 Mdot
.49751 .65578 Mdot
.56783 .24775 Mdot
.55642 .35123 Mdot
.42175 .32337 Mdot
.46246 .43666 Mdot
.47033 .44837 Mdot
.43243 .30811 Mdot
.5061 .34563 Mdot
.50135 .67855 Mdot
.54342 .70323 Mdot
.53852 .66871 Mdot
.26537 .6921 Mdot
.54019 .71621 Mdot
.19253 .55307 Mdot
.33599 .5278 Mdot
.29603 .67687 Mdot
.41178 .51607 Mdot
.69556 .46498 Mdot
.52042 .68474 Mdot
.57299 .51651 Mdot
.36952 .49501 Mdot
.81652 .3874 Mdot
.38853 .51812 Mdot
.60881 .40203 Mdot
.36313 .53297 Mdot
.31481 .72945 Mdot
.49205 .64777 Mdot
.40711 .52313 Mdot
.66356 .48364 Mdot
.40571 .30967 Mdot
.5377 .7311 Mdot
.35436 .52816 Mdot
.70257 .69048 Mdot
.33105 .49845 Mdot
.81951 .55897 Mdot
.46379 .21035 Mdot
.42123 .28605 Mdot
.31473 .51898 Mdot
.58278 .36773 Mdot
.47396 .61097 Mdot
.30336 .6932 Mdot
.67163 .42642 Mdot
.25998 .58941 Mdot
.54067 .31962 Mdot
.44645 .60307 Mdot
.43762 .57213 Mdot
.40546 .29517 Mdot
.51174 .72597 Mdot
.68766 .44346 Mdot
.3839 .56018 Mdot
.4149 .57877 Mdot
.66363 .23505 Mdot
.30184 .69867 Mdot
.45368 .54344 Mdot
.38087 .31309 Mdot
.25828 .60616 Mdot
.35924 .51805 Mdot
.48988 .3295 Mdot
.51679 .71048 Mdot
.29834 .53137 Mdot
.24271 .60162 Mdot
.41278 .53256 Mdot
.52363 .67392 Mdot
.49953 .66207 Mdot
.62897 .78725 Mdot
.39143 .30124 Mdot
.38879 .51175 Mdot
.54567 .23161 Mdot
.43257 .54131 Mdot
.68261 .44194 Mdot
.33667 .56244 Mdot
.52566 .33146 Mdot
.60501 .57013 Mdot
.54413 .31653 Mdot
.37754 .5827 Mdot
.54976 .68518 Mdot
.69154 .44115 Mdot
.6025 .24876 Mdot
.58979 .43545 Mdot
.19238 .54797 Mdot
.5428 .28889 Mdot
.39493 .31259 Mdot
.40834 .3466 Mdot
.64156 .48118 Mdot
.39657 .52102 Mdot
.56855 .45555 Mdot
.32847 .57741 Mdot
.35895 .53241 Mdot
.37534 .50636 Mdot
.72846 .43738 Mdot
.65602 .4415 Mdot
.54937 .34157 Mdot
.36227 .55995 Mdot
.41475 .52906 Mdot
.53436 .68722 Mdot
.40832 .30372 Mdot
.56396 .32849 Mdot
.41513 .33721 Mdot
.53739 .34807 Mdot
.81991 .62647 Mdot
.33368 .56216 Mdot
.40514 .31099 Mdot
.68269 .41412 Mdot
.55676 .69482 Mdot
.67785 .64702 Mdot
.54226 .36862 Mdot
.55761 .33708 Mdot
.40749 .51787 Mdot
.53945 .6558 Mdot
.52586 .65101 Mdot
.39297 .3138 Mdot
.69265 .45823 Mdot
.37962 .58841 Mdot
.36848 .57335 Mdot
.567 .20672 Mdot
.54158 .31083 Mdot
.26602 .63369 Mdot
.64255 .76411 Mdot
.39811 .52126 Mdot
.52365 .64941 Mdot
.36675 .54703 Mdot
.74947 .36957 Mdot
.56093 .69347 Mdot
.37825 .49078 Mdot
.39023 .4238 Mdot
.55674 .31702 Mdot
.61954 .80732 Mdot
.41969 .49804 Mdot
.6254 .40697 Mdot
.41163 .56839 Mdot
.66399 .81399 Mdot
.56672 .78064 Mdot
.43149 .52608 Mdot
.34366 .55689 Mdot
.74998 .29504 Mdot
.42196 .52932 Mdot
.6545 .65188 Mdot
.41889 .60233 Mdot
.51649 .64969 Mdot
.49804 .43341 Mdot
.58701 .50168 Mdot
.3855 .31642 Mdot
.52364 .34629 Mdot
.25552 .40805 Mdot
.4096 .34205 Mdot
.51493 .69264 Mdot
.35257 .49765 Mdot
.47711 .71281 Mdot
.58578 .34263 Mdot
.40569 .59168 Mdot
.68279 .44334 Mdot
.5883 .50399 Mdot
.5102 .34823 Mdot
.66546 .43358 Mdot
.4113 .5059 Mdot
.3553 .22837 Mdot
.60202 .44723 Mdot
.66615 .78047 Mdot
.69544 .43409 Mdot
.65955 .45299 Mdot
.58294 .568 Mdot
.38558 .31691 Mdot
.63806 .22218 Mdot
.2921 .5904 Mdot
.67195 .42299 Mdot
.32477 .38015 Mdot
.50326 .31876 Mdot
.62932 .55545 Mdot
.49846 .64259 Mdot
.33542 .56558 Mdot
.38947 .53232 Mdot
.68978 .45689 Mdot
.54619 .76309 Mdot
.48631 .51677 Mdot
.66385 .43067 Mdot
.36103 .47402 Mdot
.63521 .55824 Mdot
.65964 .63432 Mdot
.65102 .65303 Mdot
.38642 .3322 Mdot
.44317 .26471 Mdot
.5426 .69534 Mdot
.42148 .29166 Mdot
.62411 .62515 Mdot
.3829 .51245 Mdot
.69971 .45532 Mdot
.67439 .65359 Mdot
.67372 .43502 Mdot
.40574 .31983 Mdot
.39698 .29422 Mdot
.51458 .67387 Mdot
.50803 .69067 Mdot
.33087 .63184 Mdot
.34776 .35817 Mdot
.42631 .53498 Mdot
.49325 .75303 Mdot
.55779 .6979 Mdot
.37821 .78664 Mdot
.38945 .3128 Mdot
.41428 .30081 Mdot
.34538 .69621 Mdot
.39334 .57081 Mdot
.70049 .38184 Mdot
.35524 .52312 Mdot
.28972 .41119 Mdot
.41938 .50498 Mdot
.54503 .32507 Mdot
.42891 .55577 Mdot
.7137 .57927 Mdot
.41015 .54464 Mdot
.36292 .51021 Mdot
.53723 .36382 Mdot
.44515 .52802 Mdot
.52702 .3279 Mdot
.35805 .57363 Mdot
.43446 .28797 Mdot
.52667 .34495 Mdot
.35401 .27914 Mdot
.51322 .4136 Mdot
.649 .64001 Mdot
.39352 .34023 Mdot
.39406 .3244 Mdot
.32031 .28803 Mdot
.51998 .70447 Mdot
.44638 .46518 Mdot
.39449 .52112 Mdot
.49878 .34136 Mdot
.70141 .4314 Mdot
.41241 .53142 Mdot
.30725 .54731 Mdot
.41632 .49526 Mdot
.51808 .6733 Mdot
.50486 .34545 Mdot
.41068 .31422 Mdot
.5562 .37495 Mdot
.41699 .27307 Mdot
.55113 .3824 Mdot
.32211 .59361 Mdot
.43889 .59707 Mdot
.43066 .4775 Mdot
.4724 .74529 Mdot
.22959 .65702 Mdot
.53302 .67419 Mdot
.66169 .64368 Mdot
.3875 .30399 Mdot
.50061 .49648 Mdot
.55423 .68993 Mdot
.56 .3426 Mdot
.37953 .53083 Mdot
.37033 .47138 Mdot
.27948 .5663 Mdot
.47942 .64419 Mdot
.34491 .32152 Mdot
.52362 .3573 Mdot
.66999 .63993 Mdot
.59896 .55594 Mdot
.55933 .633 Mdot
.56813 .51298 Mdot
.36918 .54318 Mdot
.39167 .32139 Mdot
.5036 .66074 Mdot
.64966 .24888 Mdot
.68316 .46173 Mdot
.58801 .53631 Mdot
.38339 .55352 Mdot
.60869 .73867 Mdot
.54954 .68478 Mdot
.41942 .30014 Mdot
.68962 .45657 Mdot
.38935 .30667 Mdot
.63816 .6427 Mdot
.68256 .59743 Mdot
.40126 .58088 Mdot
.35095 .53146 Mdot
.70285 .4236 Mdot
.54451 .69412 Mdot
.57743 .31757 Mdot
.68027 .25292 Mdot
.55169 .3706 Mdot
.58086 .46467 Mdot
.50502 .66132 Mdot
.59323 .73464 Mdot
.57279 .36278 Mdot
.67314 .4116 Mdot
.56881 .4619 Mdot
.6502 .42328 Mdot
.36288 .51272 Mdot
.54261 .66332 Mdot
.65131 .45315 Mdot
.58649 .23643 Mdot
.8066 .62376 Mdot
.48538 .70251 Mdot
.36454 .56526 Mdot
.82326 .45917 Mdot
.74448 .65195 Mdot
.53597 .75136 Mdot
.69102 .46598 Mdot
.36396 .55454 Mdot
.34059 .55338 Mdot
.42961 .55948 Mdot
.66599 .46396 Mdot
.60347 .41965 Mdot
.56166 .33763 Mdot
.37953 .52044 Mdot
.40012 .33134 Mdot
.53182 .32948 Mdot
.57988 .3743 Mdot
.52451 .37347 Mdot
.56168 .69359 Mdot
.33915 .51517 Mdot
.59775 .62275 Mdot
.69869 .7808 Mdot
.65835 .44515 Mdot
.64892 .64034 Mdot
.38634 .50279 Mdot
.18934 .48931 Mdot
.55127 .70104 Mdot
.55447 .36905 Mdot
.37964 .54847 Mdot
.48508 .21748 Mdot
.69158 .6354 Mdot
.53344 .35685 Mdot
.52843 .70665 Mdot
.53399 .75019 Mdot
.39829 .54164 Mdot
.41043 .56762 Mdot
.53311 .70069 Mdot
.71123 .66746 Mdot
.61078 .56159 Mdot
.36505 .54557 Mdot
.66149 .43747 Mdot
.15349 .39432 Mdot
.3572 .49047 Mdot
.47921 .6363 Mdot
.64993 .63077 Mdot
.68137 .73768 Mdot
.26952 .63097 Mdot
.32104 .5829 Mdot
.80219 .41663 Mdot
.23924 .41059 Mdot
.83383 .48013 Mdot
.25193 .44471 Mdot
.75863 .42984 Mdot
.774 .69782 Mdot
.65819 .4803 Mdot
.32547 .73547 Mdot
.66099 .21159 Mdot
.65243 .69589 Mdot
.42178 .22818 Mdot
.62832 .28415 Mdot
.49007 .20997 Mdot
.35489 .80281 Mdot
.55763 .38265 Mdot
.27683 .44019 Mdot
.39881 .58643 Mdot
.73778 .64612 Mdot
.27038 .66832 Mdot
.2125 .63598 Mdot
.81894 .4659 Mdot
.52912 .22658 Mdot
.78793 .31487 Mdot
.81293 .48548 Mdot
.39141 .6376 Mdot
.29074 .4739 Mdot
.45595 .27966 Mdot
.46416 .44095 Mdot
.24794 .41812 Mdot
.31723 .47726 Mdot
.7117 .56502 Mdot
.69016 .48426 Mdot
.40844 .6548 Mdot
.15046 .43079 Mdot
.52452 .36763 Mdot
.51799 .71168 Mdot
.62706 .21403 Mdot
.47587 .62654 Mdot
.62305 .45272 Mdot
.80238 .41624 Mdot
.7619 .67035 Mdot
.31105 .72524 Mdot
.61374 .61367 Mdot
.37181 .73543 Mdot
.26356 .32731 Mdot
.2804 .4762 Mdot
.56041 .65083 Mdot
.64145 .34352 Mdot
.46885 .44774 Mdot
.45329 .29185 Mdot
.33193 .75142 Mdot
.41067 .34843 Mdot
.35184 .27909 Mdot
.53498 .706 Mdot
.30929 .64247 Mdot
.6791 .63763 Mdot
.61759 .63628 Mdot
.52346 .30341 Mdot
.74138 .35741 Mdot
.69896 .66567 Mdot
.6941 .6853 Mdot
.54323 .81506 Mdot
.83122 .38516 Mdot
.29067 .35172 Mdot
.68082 .29374 Mdot
.62177 .42092 Mdot
.24964 .39153 Mdot
.58225 .59888 Mdot
.32538 .34688 Mdot
.43077 .44209 Mdot
.71379 .21904 Mdot
.72268 .68412 Mdot
.77191 .28345 Mdot
.58298 .67707 Mdot
.38615 .4812 Mdot
.7062 .31126 Mdot
.46163 .7721 Mdot
.44943 .30781 Mdot
.83048 .39421 Mdot
.41307 .28891 Mdot
.48447 .65843 Mdot
.6485 .69874 Mdot
.27661 .69445 Mdot
.58525 .32371 Mdot
.42169 .3547 Mdot
.3018 .52282 Mdot
.68352 .18108 Mdot
.8008 .40245 Mdot
.64399 .77494 Mdot
.756 .67057 Mdot
.4904 .35151 Mdot
.58709 .3621 Mdot
.65102 .45803 Mdot
.78653 .66203 Mdot
.54881 .67497 Mdot
.70312 .78085 Mdot
.78269 .65857 Mdot
.4966 .60388 Mdot
.66802 .16832 Mdot
.44524 .83266 Mdot
.29072 .66905 Mdot
.2273 .53494 Mdot
.42244 .19942 Mdot
.57331 .58122 Mdot
.5975 .72579 Mdot
.51732 .38423 Mdot
.71269 .72063 Mdot
.82444 .60652 Mdot
.33036 .38653 Mdot
.73887 .47108 Mdot
.61038 .6494 Mdot
.41783 .39518 Mdot
.48613 .69256 Mdot
.3951 .23442 Mdot
.39626 .40109 Mdot
.78278 .30048 Mdot
.25696 .59513 Mdot
.23272 .29497 Mdot
.26042 .43021 Mdot
.3215 .75935 Mdot
.78351 .44477 Mdot
.45381 .35355 Mdot
.47017 .49486 Mdot
.67637 .70897 Mdot
.32252 .52972 Mdot
.54981 .55284 Mdot
.46573 .57138 Mdot
.39159 .28306 Mdot
.58599 .56031 Mdot
.78759 .57632 Mdot
.27272 .41028 Mdot
.74212 .31219 Mdot
.29981 .46901 Mdot
.55249 .6571 Mdot
.31645 .33595 Mdot
.29993 .37524 Mdot
.77251 .64574 Mdot
.49743 .57765 Mdot
.68148 .76148 Mdot
.49355 .56496 Mdot
.32106 .57107 Mdot
.33514 .7418 Mdot
.33662 .46685 Mdot
.32023 .36858 Mdot
.42372 .50315 Mdot
.55691 .81028 Mdot
.73782 .6953 Mdot
.44403 .69492 Mdot
.26895 .39115 Mdot
.46634 .73244 Mdot
.71657 .72043 Mdot
.71158 .31185 Mdot
.606 .71815 Mdot
.56861 .7639 Mdot
.69325 .19181 Mdot
.54258 .33164 Mdot
.33499 .37553 Mdot
.71849 .42681 Mdot
.59361 .24529 Mdot
.63839 .19974 Mdot
.48952 .54239 Mdot
.73625 .71161 Mdot
.67246 .69381 Mdot
.5923 .35026 Mdot
.68668 .54026 Mdot
.73689 .4331 Mdot
.46437 .71087 Mdot
.39544 .4868 Mdot
.47242 .56013 Mdot
.43632 .30502 Mdot
.43274 .77255 Mdot
.6958 .28676 Mdot
.59634 .30095 Mdot
.31202 .57755 Mdot
.61498 .32517 Mdot
.67202 .6458 Mdot
.60192 .53177 Mdot
.83432 .6082 Mdot
.38803 .60908 Mdot
.41869 .82457 Mdot
.71757 .67063 Mdot
.57639 .47566 Mdot
.41297 .26487 Mdot
.62002 .76467 Mdot
.75151 .25387 Mdot
.75724 .70074 Mdot
.7613 .61697 Mdot
.82064 .45221 Mdot
.50691 .86475 Mdot
.59314 .17917 Mdot
.4671 .79896 Mdot
.7192 .42994 Mdot
.37439 .87876 Mdot
.56721 .37063 Mdot
.23046 .55581 Mdot
.45909 .76983 Mdot
.4847 .22406 Mdot
.47341 .62887 Mdot
.29248 .49191 Mdot
.49039 .30155 Mdot
.53638 .72539 Mdot
.30194 .53637 Mdot
.84986 .44074 Mdot
.71961 .22092 Mdot
.84606 .4251 Mdot
.68702 .59884 Mdot
.84065 .47948 Mdot
.72531 .25202 Mdot
.1929 .55904 Mdot
.65355 .22489 Mdot
.33741 .56292 Mdot
.3618 .38599 Mdot
.46094 .82921 Mdot
.5498 .29879 Mdot
.60803 .62906 Mdot
.52738 .63144 Mdot
.70229 .21816 Mdot
.8387 .60288 Mdot
.36906 .70048 Mdot
.34419 .64441 Mdot
.48823 .40814 Mdot
.33582 .35813 Mdot
.46065 .65096 Mdot
.71908 .55415 Mdot
.80195 .60639 Mdot
.71441 .2421 Mdot
.29371 .38661 Mdot
.63101 .29655 Mdot
.76236 .60084 Mdot
.46561 .81792 Mdot
.78888 .43544 Mdot
.62065 .20955 Mdot
.48687 .59441 Mdot
.59421 .68745 Mdot
.48684 .52185 Mdot
.70407 .55552 Mdot
.71226 .35112 Mdot
.27502 .36034 Mdot
.51857 .32811 Mdot
.33961 .38415 Mdot
.53595 .48395 Mdot
.65088 .22141 Mdot
.26309 .36209 Mdot
.32528 .39282 Mdot
.77721 .60074 Mdot
.8467 .4511 Mdot
.70958 .67456 Mdot
.38644 .20872 Mdot
.77291 .4813 Mdot
.46187 .59287 Mdot
.43322 .49816 Mdot
.72869 .71414 Mdot
.86281 .492 Mdot
.74063 .70958 Mdot
.60422 .74511 Mdot
.56735 .24163 Mdot
.63562 .43548 Mdot
.25524 .36465 Mdot
.60746 .33296 Mdot
.80816 .60252 Mdot
.51786 .50906 Mdot
.63261 .43594 Mdot
.66222 .67674 Mdot
.3398 .63216 Mdot
.21966 .44762 Mdot
.38362 .65978 Mdot
.39418 .59896 Mdot
.29834 .65491 Mdot
.49121 .6727 Mdot
.60214 .74335 Mdot
.32804 .3541 Mdot
.53855 .33282 Mdot
.54462 .1929 Mdot
.46714 .65224 Mdot
.35355 .48613 Mdot
.69593 .32165 Mdot
.48794 .69756 Mdot
.46712 .74362 Mdot
.58566 .37953 Mdot
.79068 .67194 Mdot
.52494 .81026 Mdot
.46025 .66785 Mdot
.30234 .33986 Mdot
.56684 .21156 Mdot
.61403 .55264 Mdot
.71791 .43717 Mdot
.81575 .46949 Mdot
.52486 .42084 Mdot
.31244 .3424 Mdot
.29059 .6501 Mdot
.68252 .26233 Mdot
.33094 .57591 Mdot
.61795 .7825 Mdot
.19504 .53408 Mdot
.60507 .52871 Mdot
.49501 .62564 Mdot
.55141 .71559 Mdot
.27382 .74974 Mdot
.72548 .58041 Mdot
.54168 .61187 Mdot
.80084 .44596 Mdot
.64409 .44496 Mdot
.56501 .67419 Mdot
.32937 .39688 Mdot
.45515 .25026 Mdot
.28871 .62002 Mdot
.72118 .35558 Mdot
.41489 .63509 Mdot
.62327 .39909 Mdot
.81398 .44668 Mdot
.79433 .35965 Mdot
.16825 .378 Mdot
.56374 .71568 Mdot
.65559 .26422 Mdot
.64995 .25912 Mdot
.55686 .64932 Mdot
.47937 .64121 Mdot
.26914 .53747 Mdot
.84605 .50899 Mdot
.50832 .48674 Mdot
.70838 .54433 Mdot
.5703 .46175 Mdot
.42256 .23285 Mdot
.66101 .24609 Mdot
.25725 .38922 Mdot
.7825 .41889 Mdot
.35608 .65563 Mdot
.47007 .17411 Mdot
.44066 .48605 Mdot
.22936 .56363 Mdot
.25512 .36447 Mdot
.32249 .43738 Mdot
.33998 .75689 Mdot
.80251 .55741 Mdot
.43081 .53881 Mdot
.8418 .40121 Mdot
.77002 .63888 Mdot
.54497 .55555 Mdot
.47793 .3411 Mdot
.40861 .55495 Mdot
.33751 .51865 Mdot
.54926 .76999 Mdot
.6623 .75266 Mdot
.53674 .1602 Mdot
.27101 .42481 Mdot
.45953 .60301 Mdot
.28506 .65078 Mdot
.41948 .82448 Mdot
.71853 .32849 Mdot
.82195 .52734 Mdot
.5347 .49894 Mdot
.47241 .82684 Mdot
.70675 .51831 Mdot
.68678 .55088 Mdot
.77581 .47094 Mdot
.73281 .25965 Mdot
.31601 .5965 Mdot
.66639 .73513 Mdot
.63033 .22345 Mdot
.38599 .50344 Mdot
.64287 .72107 Mdot
.7957 .45439 Mdot
.24533 .30412 Mdot
.57344 .59912 Mdot
.86701 .47302 Mdot
.457 .50108 Mdot
.67842 .72146 Mdot
.64641 .19722 Mdot
.33881 .19803 Mdot
.70246 .56683 Mdot
.7899 .31361 Mdot
.67285 .53783 Mdot
.79716 .43773 Mdot
.65704 .47025 Mdot
.51155 .45206 Mdot
.49969 .76798 Mdot
.84609 .51524 Mdot
.48594 .26537 Mdot
.76183 .37364 Mdot
.53725 .77849 Mdot
.85175 .4958 Mdot
.42251 .44414 Mdot
.27022 .74145 Mdot
.50035 .3082 Mdot
.48773 .84051 Mdot
.4885 .80122 Mdot
.46116 .62219 Mdot
.3176 .38586 Mdot
.25822 .7177 Mdot
.20543 .59849 Mdot
.47998 .79324 Mdot
.33359 .41144 Mdot
.62966 .7646 Mdot
.29714 .33698 Mdot
.80823 .60908 Mdot
.33369 .7895 Mdot
.65978 .25462 Mdot
.62351 .66967 Mdot
.69785 .6259 Mdot
.66037 .75831 Mdot
.77802 .54638 Mdot
.70186 .3182 Mdot
.65292 .57594 Mdot
.39825 .63398 Mdot
.10738 .51696 Mdot
.65307 .51543 Mdot
.27445 .55516 Mdot
.74654 .25443 Mdot
.79774 .61169 Mdot
.50926 .50441 Mdot
.32282 .74662 Mdot
.20394 .46887 Mdot
.4141 .37437 Mdot
.35425 .52076 Mdot
.8507 .4901 Mdot
.43251 .35668 Mdot
.80707 .35481 Mdot
.67886 .77821 Mdot
.3221 .65882 Mdot
.35324 .60954 Mdot
.52872 .38922 Mdot
.26351 .50161 Mdot
.322 .42103 Mdot
.7528 .27117 Mdot
.23127 .56178 Mdot
.57599 .43714 Mdot
.65686 .389 Mdot
.72924 .38803 Mdot
.43581 .61902 Mdot
.46559 .83254 Mdot
.64756 .75595 Mdot
.26 .4154 Mdot
.75403 .60765 Mdot
.32915 .37055 Mdot
.26949 .63344 Mdot
.26406 .35127 Mdot
.52463 .56015 Mdot
.47525 .30707 Mdot
.52826 .30925 Mdot
.74292 .29348 Mdot
.80504 .48915 Mdot
.56495 .80564 Mdot
.3954 .2072 Mdot
.67164 .71244 Mdot
.28162 .4453 Mdot
.71852 .29531 Mdot
.56566 .58385 Mdot
.48334 .27661 Mdot
.21908 .46401 Mdot
.25908 .5936 Mdot
.81228 .54258 Mdot
.31199 .46351 Mdot
.82638 .60706 Mdot
.27211 .36567 Mdot
.7041 .25926 Mdot
.48578 .41172 Mdot
.43851 .754 Mdot
.32415 .70672 Mdot
.4429 .19383 Mdot
.60229 .52429 Mdot
.68568 .18394 Mdot
.53864 .64085 Mdot
.82901 .38142 Mdot
.69542 .42926 Mdot
.18103 .38395 Mdot
.80945 .57411 Mdot
.55146 .51546 Mdot
.54947 .45821 Mdot
.61789 .7858 Mdot
.70204 .6758 Mdot
.71552 .67499 Mdot
.48739 .53318 Mdot
.52189 .3742 Mdot
.58628 .42881 Mdot
.71503 .54403 Mdot
.75752 .32708 Mdot
.35732 .57836 Mdot
.59232 .34019 Mdot
.30405 .45148 Mdot
.69237 .39938 Mdot
.72941 .70312 Mdot
.80359 .52491 Mdot
.3212 .47913 Mdot
.33643 .35527 Mdot
.72167 .24239 Mdot
.78307 .64619 Mdot
.48672 .5054 Mdot
.46547 .56101 Mdot
.6127 .43659 Mdot
.57485 .19013 Mdot
.79134 .38859 Mdot
.71707 .38921 Mdot
.62277 .5648 Mdot
.29069 .35491 Mdot
.87869 .45287 Mdot
.71638 .21962 Mdot
.42815 .18474 Mdot
.57072 .45819 Mdot
.58703 .67767 Mdot
.19236 .49429 Mdot
.70751 .26308 Mdot
.49949 .84167 Mdot
.76613 .6278 Mdot
.33041 .37539 Mdot
.27409 .2774 Mdot
.23122 .64427 Mdot
.56975 .42482 Mdot
.32591 .7082 Mdot
.47236 .75886 Mdot
.63897 .41629 Mdot
.41532 .37893 Mdot
.54261 .43372 Mdot
.62181 .45453 Mdot
.63305 .76334 Mdot
.69337 .67956 Mdot
.70134 .25587 Mdot
.23025 .58164 Mdot
.46601 .5572 Mdot
.75717 .34237 Mdot
.48277 .6752 Mdot
.64722 .25078 Mdot
.57635 .21189 Mdot
.55827 .43315 Mdot
.55987 .37699 Mdot
.29787 .50872 Mdot
.6176 .53517 Mdot
.67784 .53149 Mdot
.32606 .24538 Mdot
.44005 .29978 Mdot
.57309 .65884 Mdot
.23765 .67061 Mdot
.57056 .70723 Mdot
.87096 .52356 Mdot
.72165 .55304 Mdot
.29283 .65761 Mdot
.71064 .50885 Mdot
.6436 .31754 Mdot
.33476 .22275 Mdot
.37759 .63714 Mdot
.3613 .27026 Mdot
.57924 .65513 Mdot
.49249 .67469 Mdot
.73716 .4907 Mdot
.67505 .62816 Mdot
.32669 .64372 Mdot
.38584 .81518 Mdot
.56375 .20951 Mdot
.57622 .69634 Mdot
.59207 .40747 Mdot
.49936 .72573 Mdot
.82922 .6164 Mdot
.54962 .37638 Mdot
.70247 .1998 Mdot
.43538 .6008 Mdot
.56246 .18139 Mdot
.73107 .7085 Mdot
.60246 .57411 Mdot
.57347 .45435 Mdot
.60699 .26891 Mdot
.32037 .56306 Mdot
.46207 .60422 Mdot
.51648 .70032 Mdot
.66338 .23143 Mdot
.41594 .30509 Mdot
.34146 .32998 Mdot
.714 .4602 Mdot
.37473 .79482 Mdot
.48921 .82604 Mdot
.49209 .67928 Mdot
.51166 .40196 Mdot
.64553 .26573 Mdot
.38478 .42124 Mdot
.31055 .44565 Mdot
.74521 .29042 Mdot
.35038 .64082 Mdot
.5411 .64248 Mdot
.42492 .18787 Mdot
.3972 .39983 Mdot
.76415 .70384 Mdot
.40434 .45224 Mdot
.27472 .48546 Mdot
.32011 .44654 Mdot
.61454 .77628 Mdot
.26858 .62824 Mdot
.82139 .55603 Mdot
.31959 .33873 Mdot
.44326 .43329 Mdot
.3288 .39203 Mdot
.31448 .48298 Mdot
.70822 .39435 Mdot
.46852 .84056 Mdot
.2812 .27151 Mdot
.36669 .74027 Mdot
.58819 .60911 Mdot
.48534 .62619 Mdot
.42789 .82626 Mdot
.56106 .64877 Mdot
.39087 .27429 Mdot
.41769 .65764 Mdot
.8084 .57702 Mdot
.79325 .65258 Mdot
.77184 .64608 Mdot
.2591 .50804 Mdot
.73055 .39201 Mdot
.22221 .50032 Mdot
.46158 .50094 Mdot
.55882 .51218 Mdot
.3119 .55247 Mdot
.44381 .61121 Mdot
.51157 .52454 Mdot
.58723 .78684 Mdot
.37483 .61834 Mdot
.84164 .51352 Mdot
.76302 .70169 Mdot
.83754 .45366 Mdot
.70905 .34745 Mdot
.53181 .7198 Mdot
.74085 .24291 Mdot
.23858 .62158 Mdot
.80146 .62031 Mdot
.48166 .80216 Mdot
.29694 .7735 Mdot
.65598 .2039 Mdot
.79316 .57317 Mdot
.59153 .64713 Mdot
.62528 .80657 Mdot
.72682 .6824 Mdot
.27382 .7442 Mdot
.26014 .57753 Mdot
.72668 .70849 Mdot
.67458 .1789 Mdot
.43664 .80136 Mdot
.69945 .68383 Mdot
.31684 .70444 Mdot
.26571 .58735 Mdot
.34524 .79226 Mdot
.33132 .52419 Mdot
.57315 .37636 Mdot
.45551 .2159 Mdot
.31898 .37958 Mdot
.29848 .49888 Mdot
.32637 .77884 Mdot
.31849 .42472 Mdot
.27448 .44547 Mdot
.59377 .25029 Mdot
.66044 .20999 Mdot
.2803 .63004 Mdot
.34361 .47858 Mdot
.51645 .6285 Mdot
.40903 .34428 Mdot
.23846 .4504 Mdot
.3961 .5603 Mdot
.58474 .50849 Mdot
.29719 .58493 Mdot
.85533 .44917 Mdot
.44545 .2373 Mdot
.66618 .49281 Mdot
.55096 .71983 Mdot
.64898 .76283 Mdot
.74013 .34064 Mdot
.65093 .69628 Mdot
.30392 .75827 Mdot
.31369 .62794 Mdot
.81071 .43618 Mdot
.68045 .69645 Mdot
.28029 .38062 Mdot
.28993 .2949 Mdot
.68807 .47264 Mdot
.48719 .77173 Mdot
.74996 .27219 Mdot
.65312 .72235 Mdot
.482 .66152 Mdot
.76637 .58253 Mdot
.69429 .39032 Mdot
.64541 .7382 Mdot
.71684 .66936 Mdot
.68045 .27163 Mdot
.32841 .67819 Mdot
.79179 .36222 Mdot
.54356 .39148 Mdot
.29764 .39032 Mdot
.74152 .58106 Mdot
.34593 .7947 Mdot
.38371 .42228 Mdot
.83379 .5747 Mdot
.55326 .50465 Mdot
.35299 .312 Mdot
.40175 .57757 Mdot
.24089 .59834 Mdot
.59943 .77691 Mdot
.75314 .59871 Mdot
.50432 .59717 Mdot
.49662 .69944 Mdot
.53903 .81315 Mdot
.47523 .33693 Mdot
.43213 .36263 Mdot
.23425 .53169 Mdot
.58396 .75046 Mdot
.37468 .29096 Mdot
.67348 .66386 Mdot
.44653 .58848 Mdot
.35617 .26148 Mdot
.72381 .37386 Mdot
.49711 .77713 Mdot
.46104 .79987 Mdot
.74693 .29756 Mdot
.7197 .34673 Mdot
.55186 .81637 Mdot
.50653 .79077 Mdot
.68892 .73805 Mdot
.23272 .634 Mdot
.59684 .64059 Mdot
.40358 .49161 Mdot
.39081 .27444 Mdot
.55556 .65137 Mdot
.76255 .33001 Mdot
.47522 .56518 Mdot
.35279 .29727 Mdot
.54476 .53344 Mdot
.70296 .31002 Mdot
.46669 .40811 Mdot
.73086 .69948 Mdot
.62514 .80683 Mdot
.32739 .35272 Mdot
.69312 .47557 Mdot
.683 .53687 Mdot
.56567 .59559 Mdot
.83622 .54117 Mdot
.50352 .53204 Mdot
.47667 .71375 Mdot
.6254 .65697 Mdot
.44902 .7216 Mdot
.70261 .7502 Mdot
.35104 .35758 Mdot
.56451 .51691 Mdot
.46324 .66818 Mdot
.61181 .62755 Mdot
.67826 .64566 Mdot
.47778 .22948 Mdot
.23626 .60922 Mdot
.71947 .4889 Mdot
.5919 .44611 Mdot
.45539 .56239 Mdot
.19234 .49876 Mdot
.78484 .36141 Mdot
.50106 .49879 Mdot
.54753 .50398 Mdot
.62759 .22493 Mdot
.40876 .36443 Mdot
.13554 .42321 Mdot
.85084 .41867 Mdot
.40138 .57697 Mdot
.5374 .45013 Mdot
.34532 .34104 Mdot
.50914 .3321 Mdot
.38095 .65626 Mdot
.75458 .30757 Mdot
.65198 .43877 Mdot
.58012 .2412 Mdot
.69027 .65655 Mdot
.60928 .78721 Mdot
.47356 .18283 Mdot
.63533 .42901 Mdot
.87306 .51667 Mdot
.76178 .63043 Mdot
.60319 .76511 Mdot
.1163 .46078 Mdot
.58171 .78259 Mdot
.43707 .45106 Mdot
.58256 .25471 Mdot
.8517 .45902 Mdot
.57502 .4621 Mdot
.5701 .24748 Mdot
.44681 .79813 Mdot
.32399 .34781 Mdot
.28283 .41378 Mdot
.62617 .67324 Mdot
.56251 .79419 Mdot
.2518 .7272 Mdot
.64399 .31561 Mdot
.35721 .21001 Mdot
.32428 .64934 Mdot
.80496 .3724 Mdot
.70277 .56539 Mdot
.26554 .28799 Mdot
.78733 .65924 Mdot
.3552 .39285 Mdot
.33724 .78087 Mdot
.4555 .26263 Mdot
.33527 .28662 Mdot
.18699 .50064 Mdot
.66936 .58547 Mdot
.36205 .64137 Mdot
.62732 .31354 Mdot
.52121 .59919 Mdot
.33448 .38754 Mdot
.45694 .74245 Mdot
.56381 .51419 Mdot
.77372 .30652 Mdot
.27262 .7222 Mdot
.30261 .3471 Mdot
.61334 .23468 Mdot
.34053 .28702 Mdot
.77196 .35962 Mdot
.75282 .38856 Mdot
.39162 .41542 Mdot
.59705 .16122 Mdot
.78271 .3009 Mdot
.59912 .64055 Mdot
.33619 .52336 Mdot
.76941 .7026 Mdot
.43207 .40823 Mdot
.46635 .79685 Mdot
.72185 .64583 Mdot
.26725 .43045 Mdot
.3208 .60383 Mdot
.36799 .48643 Mdot
.22185 .52186 Mdot
.58059 .6386 Mdot
.46143 .74639 Mdot
.51468 .18723 Mdot
.30532 .34239 Mdot
.27988 .72608 Mdot
.47998 .17534 Mdot
.39876 .4504 Mdot
.51295 .64974 Mdot
.85315 .45469 Mdot
.44513 .64885 Mdot
.47016 .55456 Mdot
.30461 .67922 Mdot
.49589 .52469 Mdot
.51931 .27562 Mdot
.46494 .55916 Mdot
.61311 .55045 Mdot
.31512 .3861 Mdot
.71723 .27616 Mdot
.50623 .76803 Mdot
.672 .16775 Mdot
.7321 .71523 Mdot
.57746 .69787 Mdot
.44884 .78939 Mdot
.55282 .42933 Mdot
.8331 .44381 Mdot
.62436 .29592 Mdot
.56993 .21169 Mdot
.22471 .66686 Mdot
.32112 .30454 Mdot
.43972 .53878 Mdot
.68892 .60085 Mdot
.80753 .6334 Mdot
.23285 .68625 Mdot
.82643 .60567 Mdot
.35614 .61229 Mdot
.42248 .48949 Mdot
.28911 .22203 Mdot
.80409 .44129 Mdot
.34204 .59629 Mdot
.54444 .61635 Mdot
.50727 .61065 Mdot
.37861 .58532 Mdot
.67885 .62641 Mdot
.23885 .42698 Mdot
.28312 .42023 Mdot
.8446 .50821 Mdot
.56346 .7064 Mdot
.57995 .47705 Mdot
.69427 .40858 Mdot
.56792 .47567 Mdot
.34534 .47083 Mdot
.64566 .43934 Mdot
.2851 .42645 Mdot
.45575 .41935 Mdot
.57478 .29691 Mdot
.34172 .62824 Mdot
.63152 .57756 Mdot
.38412 .63162 Mdot
.27154 .47477 Mdot
.58833 .73057 Mdot
.20416 .59689 Mdot
.31761 .42444 Mdot
.36873 .40801 Mdot
.72516 .6985 Mdot
.47729 .86035 Mdot
.59238 .50065 Mdot
.56703 .74236 Mdot
.42312 .45089 Mdot
.24822 .62133 Mdot
.31543 .67769 Mdot
.54874 .2929 Mdot
.66996 .63523 Mdot
.3846 .61749 Mdot
.46101 .66904 Mdot
.6407 .43457 Mdot
.87429 .46124 Mdot
.36314 .4848 Mdot
.36643 .66891 Mdot
.82807 .56109 Mdot
.65144 .24878 Mdot
.26247 .56709 Mdot
.31035 .54829 Mdot
.45954 .44912 Mdot
.45001 .41568 Mdot
.49831 .73304 Mdot
.6605 .24156 Mdot
.80561 .40367 Mdot
.24395 .51984 Mdot
.34662 .66544 Mdot
.39108 .51792 Mdot
.41248 .28312 Mdot
.60165 .54104 Mdot
.32259 .25847 Mdot
.37116 .34335 Mdot
.78188 .64177 Mdot
.28185 .45737 Mdot
.27046 .42493 Mdot
.29564 .69367 Mdot
.81764 .36989 Mdot
.57641 .60703 Mdot
.3167 .65954 Mdot
.52802 .54697 Mdot
.78013 .55183 Mdot
.33047 .41235 Mdot
.74524 .46008 Mdot
.41555 .61859 Mdot
.56209 .62636 Mdot
.85561 .55099 Mdot
.38949 .638 Mdot
.7194 .46448 Mdot
.81363 .54214 Mdot
.23804 .63752 Mdot
.54843 .45859 Mdot
.10645 .48909 Mdot
.61931 .28445 Mdot
.87123 .50746 Mdot
.69917 .27094 Mdot
.34994 .43544 Mdot
.62826 .76249 Mdot
.30045 .55278 Mdot
.54354 .36077 Mdot
.82256 .42882 Mdot
.46914 .63933 Mdot
.60467 .64881 Mdot
.33168 .55418 Mdot
.48574 .46469 Mdot
.48014 .70878 Mdot
.76263 .42256 Mdot
.5631 .38589 Mdot
.48902 .5113 Mdot
.76368 .39975 Mdot
.44829 .41434 Mdot
.32918 .80025 Mdot
.75444 .27228 Mdot
.81725 .47339 Mdot
.72255 .38111 Mdot
.18332 .3676 Mdot
.5604 .63864 Mdot
.47067 .65847 Mdot
.67027 .48391 Mdot
.22137 .50825 Mdot
.64765 .73163 Mdot
.70615 .26589 Mdot
.67128 .76029 Mdot
.38172 .42128 Mdot
.10666 .54979 Mdot
.34263 .39471 Mdot
.48831 .4835 Mdot
.63185 .73344 Mdot
.842 .52444 Mdot
.55799 .22558 Mdot
.66541 .78101 Mdot
.71608 .56758 Mdot
.31456 .4851 Mdot
.20041 .54171 Mdot
.43299 .18841 Mdot
.68713 .38503 Mdot
.35069 .2119 Mdot
.78487 .44969 Mdot
.24876 .41702 Mdot
.74909 .59745 Mdot
.56626 .71434 Mdot
.47412 .60478 Mdot
.72493 .54717 Mdot
.6067 .62896 Mdot
.54956 .76422 Mdot
.80161 .40943 Mdot
.24127 .36272 Mdot
.60282 .21431 Mdot
.82624 .45651 Mdot
.67407 .39629 Mdot
.48922 .61901 Mdot
.30854 .43166 Mdot
.38197 .3465 Mdot
.5203 .32058 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`2^ooooo`;o0000VOooool001cooooo00?o0000ooooooooool0[_ooool2o`0009Wooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2[ooooo`;o
00000oooool2o`0000cooooo0_l00029ooooo`007?ooool00ol0003oooooooooo`2[ooooo`;o0000
0oooool2o`0000cooooo0_l00029ooooo`007?ooool00ol0003oooooooooo`35ooooo`;o00003_oo
ool3o`00077ooooo000Looooo`03o`000?oooooooooo0<Gooooo0_l0000>ooooo`?o0000LOooool0
01cooooo00?o0000ooooooooool0UOooool2o`000003ooooool0003o000001Cooooo0_l0000>oooo
o`;o00005?ooool2o`0007?ooooo000Looooo`03o`000?oooooooooo09Gooooo0_l000000ooooooo
0000o`00000Dooooo`;o00003_ooool2o`0000Kooooo0_l0000<ooooo`;o0000Loooool001cooooo
00?o0000ooooooooool0P?ooool2o`0001_ooooo0_l0000Dooooo`;o000000Coooooo`000?l0003o
00000_ooool4o`0000Oooooo0_l00003ooooo`;o00002_ooool2o`000003ooooool0003o000006go
oooo000Looooo`03o`000?oooooooooo083ooooo0_l0000Dooooo`?o00001?ooool2o`0001Cooooo
0_l000001?oooooo0000o`000?l00002ooooo`Co00003?ooool2o`0000[ooooo0_l000001?oooooo
0000o`000?l0001/ooooo`007?ooool00ol0003oooooooooo`27ooooo`;o00002oooool5o`000003
ooooool0003o000000Oooooo0_l0000Fooooo`;o00007_ooool2o`0006cooooo000Looooo`03o`00
0?oooooooooo08Kooooo1Ol00004ooooo`;o00000oooool2o`0000Cooooo0_l00005ooooo`Co0000
4_ooool2o`0000;ooooo0_l0000=ooooo`;o0000OOooool00006ooooooo^k^ko<S8bo`000?lb<S;o
k^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo08Kooooo0_l000001?oooooo
0000o`000?ooool2o`000003ooooool0003o0000013ooooo0_l0000:ooooo`;o00002?ooool2o`00
00?ooooo0_l0000;ooooo`?o00004Oooool2o`0006[ooooo00001_ooooooMgMgoiRHV?ooooooV9RH
ogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003ooooooooo
o`1^ooooo`;o00007?ooool2o`0001oooooo0_l00003ooooo`;o00002?ooool2o`0000_ooooo0_l0
0005ooooo`;o00002oooool2o`0006[ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooo
oooo00[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`1Zooooo`;o00000_ooool2
o`0001Gooooo0_l0000[ooooo`;o00006?ooool6o`0000kooooo0_l0001Wooooo`0000?oooooo`00
0?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0001Zoooo
o`;o00005?ooool2o`0000?ooooo0_l0000Booooo`;o00006?ooool2o`0000Kooooo0_l0000?oooo
o`Co00004?ooool2o`0006Oooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00co
oooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`20ooooo`;o00005oooool2o`0001So
oooo0_l00006ooooo`;o00005?ooool2o`0007Kooooo00000ooooooo410@ooooo`02ooooo`03oa0@
4?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1jooooo`;o0000
00?oooooo`000?l000005Oooool2o`0001gooooo0ol0000Eooooo`;o000000?oooooo`000?l00000
0ol0001fooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRH
V?l@41001_ooool00ol0003oooooooooo`1^ooooo`Go00001oooool2o`000003ooooool0003o0000
01Cooooo1Ol00003ooooo`;o00005_ooool6o`0000;ooooo0_l00004ooooo`;o00000oooool2o`00
00?ooooo0_l000001?oooooo0000o`000?l00002ooooo`;o0000M?ooool00006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0
K_ooool6o`00013ooooo0_l0000=ooooo`Go00000oooool2o`0001Kooooo1_l00002ooooo`;o0000
0oooool3o`0000?ooooo1?l00009ooooo`;o0000M?ooool001cooooo00?o0000ooooooooool0L_oo
ool2o`00013ooooo0_l0000:ooooo`;o00002?ooool2o`0001_ooooo0_l00007ooooo`;o00001_oo
ool2o`0001Kooooo0_l0001Wooooo`007?ooool00ol0003oooooooooo`2@ooooo`;o00002?ooool2
o`0001_ooooo1?l0000>ooooo`;o00001Oooool2o`0000kooooo0_l00002ooooo`Co0000HOooool0
01cooooo00?o0000ooooooooool0F_ooool2o`0000gooooo0_l0000_ooooo`;o000000?oooooo`00
0?l000001Oooool2o`0000_ooooo0_l00005ooooo`?o00003_ooool4o`0000?ooooo0_l0000Boooo
o`Co0000HOooool001cooooo00?o0000ooooooooool0F_ooool2o`0000gooooo0_l0000Kooooo`;o
00002?ooool2o`0000Sooooo0_l000000ooooooo0000o`000005ooooo`;o00000_ooool2o`0000Oo
oooo0_l00005ooooo`;o00003_ooool5o`0000Cooooo0_l000000ooooooo0000o`00001cooooo`00
7?ooool00ol0003oooooooooo`1`ooooo`;o00004oooool3o`0000Sooooo0_l00005ooooo`;o0000
2_ooool2o`0000?ooooo0_l00007ooooo`;o00001_ooool4o`0000_ooooo0_l00007ooooo`Ko0000
4oooool2o`0005gooooo000Looooo`03o`000?oooooooooo06Gooooo0_l00004ooooo`;o00000ooo
ool2o`0001?ooooo0ol0000?ooooo`;o00002_ooool2o`000003ooooool0003o000000Gooooo0_l0
000:ooooo`So00004_ooool4o`0001?ooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1U
ooooo`;o00001?ooool2o`00013ooooo0_l00007ooooo`;o00007_ooool3o`0000Cooooo0_l0000;
ooooo`Oo00000_ooool2o`0000oooooo0_l00004ooooo`;o0000KOooool001cooooo00?o0000oooo
ooooool0K?ooool2o`0000oooooo0_l0000>ooooo`;o00006?ooool2o`00017ooooo0ol00006oooo
o`;o00002Oooool2o`0000Cooooo0_l00004ooooo`;o0000KOooool001cooooo00?o0000oooooooo
ool0F_ooool2o`00013ooooo0_l0000Oooooo`;o00009_ooool2o`0000;ooooo0_l0000Cooooo`;o
00000oooool2o`0000Kooooo0_l00007ooooo`;o000000?oooooo`000?l000001?ooool2o`0005[o
oooo000Looooo`03o`000?oooooooooo05[ooooo0_l0000:ooooo`;o0000COooool2o`0000;ooooo
0_l00002ooooo`;o00005?ooool2o`0000Kooooo0_l00007ooooo`;o000000?oooooo`000?l00000
1?ooool2o`0005[ooooo000Looooo`03o`000?oooooooooo06Kooooo0_l0000Jooooo`;o00002Ooo
ool2o`0002Kooooo0_l00006ooooo`;o000000?oooooo`000?l000003Oooool3o`000004ooooool0
003o0000o`0007?ooooo000Looooo`;o0000Poooool2o`0000Wooooo0_l000000ooooooo0000o`00
000Sooooo`;o00001_ooool2o`000003ooooool0003o000000cooooo1?l00002ooooo`;o00002?oo
ool2o`0000Sooooo0_l0001Oooooo`007?ooool00ol0003oooooooooo`1Sooooo`;o0000:oooool2
o`0002Oooooo0_l00002ooooo`;o00001Oooool2o`0000Sooooo0ol00002ooooo`;o00001?ooool2
o`0000?ooooo0_l00008ooooo`;o00001Oooool3o`0005Oooooo000Looooo`03o`000?oooooooooo
05oooooo0_l000000ooooooo0000o`000003o`0005;ooooo0_l00009ooooo`;o00002Oooool3o`00
0003ooooool0003o000000Cooooo0_l00003ooooo`Co00003Oooool4o`0005Kooooo000Looooo`03
o`000?oooooooooo05gooooo1?l000001?oooooo0000o`000?ooool2o`0000Wooooo0_l0000Ooooo
o`;o00009Oooool2o`0001Gooooo0ol0000>ooooo`?o00001oooool2o`0000Gooooo0_l0001Foooo
o`007?ooool00ol0003oooooooooo`1Mooooo`;o00004Oooool2o`00017ooooo0_l00007ooooo`;o
00000_ooool3o`0002Gooooo0_l00006ooooo`;o00003Oooool4o`0000Oooooo0_l00005ooooo`?o
00001_ooool2o`0005gooooo000Looooo`03o`000?oooooooooo05gooooo0_l0000Oooooo`Wo0000
1Oooool2o`0000;ooooo1?l00006ooooo`;o00009?ooool2o`0000cooooo0_l000000ooooooo0000
o`000002ooooo`;o00000oooool2o`0000Kooooo0_l0001Uooooo`007?ooool00ol0003ooooooooo
o`1booooo`Co00002?ooool9o`0000_ooooo0_l00006ooooo`;o00009Oooool2o`0000_ooooo0_l0
00000ooooooo0000o`000002ooooo`;o00002oooool2o`0006Gooooo000Looooo`03o`000?oooooo
oooo05Sooooo0_l0000Booooo`Co00000_ooool4o`0000Cooooo0_l000000ooooooo0000o`000005
ooooo`;o00002oooool2o`0002kooooo0_l000000ooooooo0000o`00000?ooooo`;o00000_ooool2
o`0000Cooooo0_l0000?ooooo`?o0000E_ooool001cooooo00?o0000ooooooooool0E_ooool4o`00
00gooooo0_l00003ooooo`Co00000_ooool3o`0000Gooooo2?l00002ooooo`;o00002oooool2o`00
00Kooooo0_l0000:ooooo`;o00007Oooool3o`0001;ooooo0_l00004ooooo`;o000000Coooooo`00
0?l0003ooooo0_l00009ooooo`?o0000E_ooool001cooooo00?o0000ooooooooool0DOooool2o`00
00;ooooo0ol0000?ooooo`?o00000_ooool5o`0000Wooooo0ol00002ooooo`Oo00000_ooool2o`00
00Kooooo0_l00007ooooo`;o00002_ooool2o`0001kooooo0_l00007ooooo`;o00004_ooool2o`00
0003ooooool0003o000006;ooooo000Looooo`03o`000?oooooooooo057ooooo0_l00002ooooo`;o
00002_ooool2o`0000Gooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l00007oooo
o`;o00001Oooool5o`000003ooooool0003o000000Kooooo0_l0000Dooooo`;o00007Oooool2o`00
00Oooooo0_l00008ooooo`;o00001?ooool2o`0006Wooooo000Looooo`03o`000?oooooooooo057o
oooo0_l0000>ooooo`;o00001_ooool2o`000004ooooool0003o0000o`0000?ooooo0_l00007oooo
o`;o00001Oooool2o`000003ooooool0003o000000;o00004oooool2o`0000Sooooo0_l00009oooo
o`;o00002_ooool2o`0000Kooooo0_l000000ooooooo0000o`00000;ooooo`;o000000?oooooo`00
0?l000001?ooool2o`0001Oooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o
00003_ooool5o`000003ooooool0003o000000Co00004oooool2o`000003ooooool0003o000000Co
00004Oooool2o`0000oooooo0_l00002ooooo`;o00002_ooool2o`0000Kooooo0_l000000ooooooo
0000o`00000;ooooo`;o00001oooool2o`0001Oooooo0_l0001@ooooo`007?ooool00ol0003ooooo
ooooo`13ooooo`;o00003_ooool2o`0000kooooo1Ol000000ooooooo0000o`000002o`0000Wooooo
0_l00005ooooo`ko00001?ooool2o`0000Sooooo0_l0000Booooo`?o0000;_ooool2o`000003oooo
ool0003o000000_ooooo0_l0001Iooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00000ooo
ool2o`00013ooooo0_l00003ooooo`;o00001Oooool2o`0000kooooo0_l00003ooooo`oo000000?o
ooooo`000?l000000_ooool2o`000003ooooool0003o000000Gooooo0_l0000>ooooo`;o00000ooo
ool2o`0000?ooooo0_l000000ooooooo0000o`00000Qooooo`;o00001_ooool2o`0000?ooooo0_l0
0006ooooo`Co0000Eoooool001cooooo00?o0000ooooooooool0B?ooool2o`00013ooooo0_l00003
ooooo`;o000000?oooooo`000?l000001?l00007ooooo`;o00002?oooolDo`0000Gooooo0_l0000E
ooooo`;o000000?oooooo`000?l000000_l00002ooooo`?o000000Coooooo`000?l0003o00003_oo
ool4o`0000kooooo0_l0000;ooooo`;o00001_ooool4o`0005Oooooo000Looooo`;o0000Foooool2
o`0000Kooooo1_l00007ooooo`;o00002?oooolFo`0000gooooo0_l000000ooooooo0000o`000004
ooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`;o00000oooool2o`0000Gooooo0_l0
0007ooooo`Co00009?ooool2o`0000Wooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`1<
ooooo`;o00004?ooool2o`0000;ooooo1Ol0000?ooooo`;o000000?oooooo`000?l000001Ol00000
0ooooooo0000o`00000<o`0000gooooo0_l000001?oooooo0000o`000?ooool:o`0000?ooooo1?l0
000;ooooo`;o00006_ooool2o`0001?ooooo0_l00009ooooo`;o0000COooool001cooooo00?o0000
ooooooooool0C?ooool2o`00013ooooo0_l00005ooooo`;o00002Oooool2o`0000?ooooo6ol00007
ooooo`;o00002?ooool4o`000003ooooool0003o000000Oo00000_ooool3o`0000Gooooo0_l0000O
ooooo`;o00003_ooool2o`0000?ooooo1?l00005ooooo`;o0000Coooool001cooooo00?o0000oooo
ooooool0G_ooool2o`0000Gooooo0_l00009ooooo`;o00000_oooolLo`0000Oooooo1?l00004oooo
o`Co00000oooool:o`0000;ooooo1?l00003ooooo`;o00009_ooool2o`0000Oooooo0_l00005oooo
o`;o00001Oooool2o`0004oooooo000Looooo`03o`000?oooooooooo05kooooo1_l000000ooooooo
0000o`000008ooooo`;o00000_ooool3o`000003ooooool0003o000001Ko00002_ooool2o`0000Co
oooo0_l000000ooooooo0000o`00000?o`000003ooooool0003o000001;ooooo0_l0000Cooooo`;o
00000_ooool4o`0000Sooooo0_l0000>ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0
G_ooool6o`000003ooooool0003o000000Sooooo0_l00002ooooo`;o00000_oooolFo`0001Gooooo
1?l000000ooooooo0000o`00000:o`000003ooooool0003o000001;ooooo0_l00003ooooo`;o0000
3_ooool2o`0000?ooooo0ol00008ooooo`;o00000oooool2o`0000Sooooo0ol0001:ooooo`007?oo
ool00ol0003oooooooooo`1Nooooo`;o00000oooool4o`0000Gooooo1Ol00002ooooo`;o00000ooo
oolGo`00017ooooo5Ol00003ooooo`?o00004_ooool2o`00017ooooo0_l0000@ooooo`;o00002?oo
ool2o`0004_ooooo000Looooo`03o`000?oooooooooo03kooooo0_l0000Iooooo`Co00000_ooool2
o`0000;ooooo0_l00007ooooo`Go00000_ooool2o`0000?ooooo5ol0000=ooooo`;o00000_oooolG
o`000004ooooool0003o0000o`0000Wooooo0_l00007ooooo`;o000000?oooooo`000?l000003?oo
ool4o`0000?ooooo0ol0001Qooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00000oooool2
o`0001Sooooo1Ol00002ooooo`;o00002oooool2o`000003ooooool0003o000000Kooooo5ol00009
ooooo`;o00000oooool4o`000005ooooool0003o0000o`000?ooool04_l00003ooooo`;o00002?oo
ool2o`0000[ooooo0_l0000<ooooo`?o00001?ooool3o`00067ooooo000Looooo`03o`000?oooooo
oooo03Wooooo0_l0000Gooooo`?o00000oooool4o`0001?ooooo0_l00006oooooaOo00002Oooool2
o`0000Cooooo0ol00003oooooa;o000000Coooooo`000?l0003ooooo0ol00008ooooo`;o00008?oo
ool2o`0000Sooooo1?l00007ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0D_ooool3
o`0000Cooooo0_l0000@ooooo`;o00002OoooolHo`0000gooooo4?l000000ooooooo0000o`000007
o`000004ooooool0003o0000ooooo`;o0000:oooool2o`0000Oooooo1ol00005ooooo`;o0000C?oo
ool001cooooo00?o0000ooooooooool0D_ooool2o`0000Gooooo0_l0000>ooooo`Co00000_ooool2
o`0000Gooooo5?l000000ooooooo0000o`000004ooooo`Co00001_oooolNo`0000Wooooo0_l0000L
ooooo`;o00000_ooool2o`0000Wooooo0_l00003ooooo`;o0000Doooool001cooooo00?o0000oooo
ooooool0D_ooool2o`0000;ooooo0_l00005ooooo`;o00001?ooool2o`0000Cooooo0_l00004oooo
o`;o00002?ooool2o`000003ooooool0003o000000Co000000?oooooo`000?l000001Ol000000ooo
oooo0000o`000004ooooo`Co00000_ooool2o`0000?ooooo1ol000000ooooooo0000o`000007o`00
0003ooooool0003o000000Wo00001_ooool2o`000003ooooool0003o000001cooooo0_l00002oooo
o`;o0000Hoooool001cooooo00?o0000ooooooooool0?Oooool2o`0000;ooooo0_l0000?ooooo`;o
000000Coooooo`000?l0003o00001Oooool3o`0000?ooooo0ol00006ooooo`;o00002ooooolAo`00
00Sooooo0_l00003ooooo`;o00000ooooolOo`000003ooooool0003o000000?o0000;?ooool2o`00
05[ooooo000Looooo`03o`000?oooooooooo03gooooo0_l00002ooooo`;o00004_ooool2o`0000Oo
oooo0ol000000ooooooo0000o`000002o`0000;ooooo0_l00002ooooo`;o00001oooool2o`0000?o
oooo1_l000000ooooooo0000o`000004o`0000?ooooo0ol00003ooooo`;o00001Oooool2o`0000?o
oooo8ol00004ooooo`;o00002?ooool2o`0001kooooo0_l00003ooooo`?o0000E?ooool001cooooo
00?o0000ooooooooool0Goooool2o`000003ooooool0003o000000;ooooo1?l00002ooooo`;o0000
1oooool2o`000003ooooool0003o000000Ko000000?oooooo`000?l000001?l00003ooooo`?o0000
0oooool2o`0000cooooo7ol000000ooooooo0000o`000002ooooo`?o00002?ooool2o`0001Cooooo
0_l000000ooooooo0000o`000002ooooo`;o00001_ooool3o`0000Wooooo0_l00003ooooo`;o0000
A?ooool001cooooo0_l0001>ooooo`;o00001?ooool2o`0000[ooooo0_l00003ooooo`Co00001?oo
ool2o`0000[ooooo0_l000000ooooooo0000o`000007o`000003ooooool0003o000000Cooooo0_l0
000?ooooo`;o00000_oooolBo`000003ooooool0003o000000co000000?oooooo`000?l000007ooo
ool2o`000003ooooool0003o000000;ooooo0_l0000Booooo`;o00000oooool2o`0004Cooooo000L
ooooo`03o`000?oooooooooo04cooooo0ol00003ooooo`Co00001Oooool2o`0000Oooooo1Ol00000
1?oooooo0000o`000?ooool2o`0000Kooooo0_l000001?oooooo0000o`000?ooool9o`000004oooo
ool0003o0000o`0000Sooooo0_l0000:ooooo`;o00000_oooolQo`000004ooooool0003o0000o`00
00Wooooo0_l0000Dooooo`;o0000Hoooool001cooooo00?o0000ooooooooool0C?ooool2o`0000Co
oooo1Ol00004ooooo`;o00002?ooool4o`000004ooooool0003o0000ooooo`?o00001Oooool2o`00
0003ooooool0003o000000Cooooo0ol00004ooooo`?o000000?oooooo`000?l000001Oooool2o`00
00[ooooo0_l000000ooooooo0000o`00000Go`000003ooooool0003o000000;o00001Oooool3o`00
00Wooooo0_l0000Dooooo`Co00003?ooool2o`0000cooooo0_l00015ooooo`007?ooool00ol0003o
ooooooooo`1Eooooo`;o00001?ooool2o`0000Sooooo1ol000001?oooooo0000o`000?l0000Aoooo
o`;o00000_ooool6o`0001;ooooo6ol000000ooooooo0000o`000008ooooo`?o00007_ooool4o`00
00Gooooo1?l000000ooooooo0000o`000002o`000003ooooool0003o000000Gooooo0_l00002oooo
o`;o0000AOooool001cooooo00?o0000ooooooooool0Boooool2o`0000Cooooo0ol00002ooooo`;o
00003Oooool3o`000003ooooool0003o000000;ooooo0ol00006ooooo`Co00001_ooool3o`0000Co
oooo1?l0000Booooo`;o00000_oooolNo`0000Gooooo0_l00006ooooo`;o00007oooool4o`000003
ooooool0003o000000;o000000?oooooo`000?l000000_ooool5o`0000;ooooo0_l00015ooooo`00
7?ooool00ol0003oooooooooo`1;ooooo`?o000000?oooooo`000?l000000ol000001?oooooo0000
o`000?l0000Fooooo`;o00001_ooool4o`0000?ooooo0_l000001?oooooo0000o`000?l00006oooo
o`;o00005OoooolOo`0000gooooo0_l0000Pooooo`;o00002oooool4o`0004[ooooo000Looooo`03
o`000?oooooooooo02oooooo0_l00003ooooo`?o000000?oooooo`000?l000004_ooool2o`000003
ooooool0003o000000Cooooo0_l0000=ooooo`Co00003oooool2o`0000Cooooo0_l00002ooooo`;o
00007Oooool2o`000003ooooool0003o000001Wo00001?ooool2o`0002Sooooo1?l0001Iooooo`00
7?ooool00ol0003oooooooooo`0_ooooo`;o00000oooool3o`000003ooooool0003o000001Gooooo
0_l00002ooooo`;o00003oooool5o`0000kooooo0_l00002ooooo`Co00000_ooool2o`00027ooooo
7?l00002ooooo`;o0000:?ooool2o`0000;ooooo0_l0000@ooooo`;o00000_ooool2o`00047ooooo
000Looooo`03o`000?oooooooooo03Cooooo0_l0000Iooooo`;o000000Coooooo`000?l0003o0000
2Oooool2o`0000Oooooo1?l00009ooooo`;o00000oooool4o`0000Kooooo0_l0000PoooooaKo0000
0_ooool3o`0000;ooooo0_l0000Oooooo`;o00000_ooool2o`0000Oooooo0_l00002ooooo`;o0000
3?ooool2o`0000;ooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00001?oo
ool2o`0001Cooooo0_l000001?oooooo0000o`000?ooool2o`0000Oooooo0_l00008ooooo`?o0000
1?ooool2o`0000?ooooo0ol00002ooooo`;o000000?oooooo`000?l000000_ooool2o`000003oooo
ool0003o000001cooooo0_l000000ooooooo0000o`00000>o`000003ooooool0003o000000Co0000
1oooool2o`0001kooooo0ol00002ooooo`;o00002_ooool3o`0005?ooooo000Looooo`03o`000?oo
oooooooo03?ooooo0_l00004ooooo`;o00005?ooool2o`0000Cooooo1?l00008ooooo`;o000000?o
ooooo`000?l000000_l00007ooooo`;o00001?ooool2o`0000Gooooo0_l00002ooooo`;o000000?o
ooooo`000?l000006_ooool4o`000003ooooool0003o000000Oo000000?oooooo`000?l000003?l0
000Vooooo`;o00000oooool3o`0000Wooooo0_l0000Dooooo`;o0000?_ooool001cooooo00?o0000
ooooooooool0=oooool2o`0001Kooooo0_l00006ooooo`;o00002?ooool2o`000003ooooool0003o
000000;o00000oooool2o`0000?ooooo0_l0000Aooooo`;o00006_ooool2o`0000?ooooo1?l00000
0ooooooo0000o`00000=o`0000;ooooo0_l0000Tooooo`;o00001Oooool3o`0000Gooooo0_l0000H
ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0=oooool2o`0001Kooooo0_l0000;oooo
o`;o00001Oooool2o`0000?ooooo1Ol00003ooooo`Ko0000;_oooolDo`0000Cooooo0_l0000Moooo
o`;o00000oooool2o`0000gooooo0_l0000Dooooo`;o00000oooool2o`0003gooooo000Looooo`03
o`000?oooooooooo053ooooo0_l0000:ooooo`?o00001?ooool3o`0000;ooooo0ol00007ooooo`Co
0000<_ooool2o`000005ooooool0003o0000o`000?ooool02?l00004ooooo`?o00005?ooool2o`00
00Oooooo0_l000000ooooooo0000o`000005ooooo`;o00000_ooool2o`0000Kooooo0_l000000ooo
oooo0000o`000007ooooo`;o00001_ooool2o`0000?ooooo0_l0000mooooo`0000Koooooonk^k_lb
<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000
ooooooooool0COooool2o`000003ooooool0003o000000;ooooo0_l00007ooooo`;o00001Oooool5
o`0000Oooooo0_l0000;ooooo`Go00009_ooool2o`0000;ooooo1Ol00002ooooo`?o00000_ooool2
o`000003ooooool0003o000000gooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o
000000;o00002?ooool2o`0000Gooooo0_l00002ooooo`Co00001?ooool2o`000003ooooool0003o
000000Oooooo0_l0000@ooooo`;o0000>?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Ooo
ool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0^ooooo`;o00007Ooo
ool4o`0000?ooooo0_l0000@ooooo`?o00000oooool2o`0000;ooooo0_l0000;ooooo`Ko000000?o
ooooo`000?l000000_l0000Qooooo`;o00000_ooool2o`0000Wooooo0_l00003ooooo`;o00002ooo
ool2o`000003ooooool0003o000000?o00000_ooool2o`000003ooooool0003o000000Wooooo0_l0
0004ooooo`Ko00001_ooool2o`0001Cooooo0_l00003ooooo`;o0000>?ooool00003ooooool@413o
oooo00;ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo00?o0000ooooooooool0;_ooool5
o`0001Cooooo0_l00006ooooo`?o00005Oooool2o`0000?ooooo0_l0000=ooooo`Co00000_ooool2
o`000003ooooool0003o000000;o00008Oooool2o`0000oooooo0_l000000ooooooo0000o`000008
ooooo`Co00001Oooool2o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`;o00000oooool2
o`0000Cooooo0_l00002ooooo`;o00001_ooool2o`0000kooooo0_l00004ooooo`;o0000?Oooool0
0003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?m4A4CogMgMooooool00007
ooooo`?o0000;?ooool2o`0000;ooooo0ol0000Dooooo`;o000000?oooooo`000?l000001?ooool2
o`0001?ooooo1?l0000<ooooo`;o00001?ooool4o`0000Cooooo0_l00007ooooo`;o00004?ooool6
o`0001Kooooo0_l00006ooooo`;o00000oooool4o`0001;ooooo0_l00002ooooo`;o00001_ooool2
o`0000Wooooo0_l0000:ooooo`;o00000_ooool2o`0000;ooooo0_l00004ooooo`;o0000>Oooool0
0003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo02cooooo0_l0000Looooo`;o00000oooool2o`0001Cooooo1?l0000<
ooooo`;o00001_ooool2o`0000Cooooo0_l00007ooooo`;o00004?ooool6o`0001gooooo0ol00002
ooooo`;o000000?oooooo`000?l000002_ooool2o`0000[ooooo0_l00006ooooo`;o00005Oooool4
o`0000Cooooo0_l00004ooooo`;o0000>Oooool00003ooooool@413ooooo00;ooooo00?o410@oooo
ooooool02_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo04Sooooo0_l00005oooo
o`;o00001oooool2o`0001[ooooo1?l000000ooooooo0000o`00000<ooooo`Co00002Oooool2o`00
00Gooooo0_l00004ooooo`Co00005?ooool2o`0000;ooooo0ol000000ooooooo0000o`000002o`00
0003ooooool0003o000000?o00002_ooool4o`0000?ooooo1?l0000Qooooo`?o0000AOooool00006
oooooomgMgOoV9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooo
oooo04Sooooo1?l00003ooooo`;o00001?ooool2o`000003ooooool0003o000000;o00003?ooool3
o`0000Gooooo0_l00002ooooo`Co000000?oooooo`000?l000003?ooool4o`0000Cooooo0_l00003
ooooo`;o00001?ooool3o`0000Cooooo1?l00003ooooo`;o000000?oooooo`000?l000000_l0000:
ooooo`;o00000_ooool3o`0000?ooooo0_l000001?oooooo0000o`000?l0000=ooooo`co00003Ooo
ool2o`0000?ooooo0_l0000;ooooo`Co0000A?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^
3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo04Wooooo0ol00005ooooo`;o0000
0_ooool2o`000003ooooool0003o000000;o00003?ooool3o`0000Gooooo0_l00004ooooo`;o0000
0oooool2o`00017ooooo0ol00009ooooo`;o00001_ooool3o`0000?ooooo0_l000000ooooooo0000
o`000002o`0000Oooooo0_l00002ooooo`;o00000_ooool2o`00013ooooo0_l00003ooooo`Oo0000
1?ooool2o`0000gooooo0_l00003ooooo`;o00003Oooool2o`0004Cooooo000Looooo`03o`000?oo
oooooooo02_ooooo0_l0000Looooo`;o00000_ooool2o`0000;ooooo0_l00002ooooo`;o000000Co
ooooo`000?l0003o00002_ooool3o`00013ooooo0_l000000ooooooo0000o`00000Aooooo`;o0000
4_ooool3o`0000Cooooo1?l00002ooooo`;o00001?ooool3o`0000;ooooo0ol000000ooooooo0000
o`00000<ooooo`;o00000_ooool7o`000003ooooool0003o000000Co00008oooool2o`0000kooooo
0_l0000fooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o00008?ooool3o`0000Gooooo0_l0
00000ooooooo0000o`00000;ooooo`?o00004?ooool6o`00013ooooo1?l0000>ooooo`Co00000ooo
ool4o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`0000?ooooo0_l00004ooooo`;o00001?oo
ool:o`000003ooooool0003o000000Wo00006?ooool2o`0000Gooooo0_l0000:ooooo`;o00000_oo
ool2o`0003Kooooo000Looooo`03o`000?oooooooooo02Sooooo0_l0000Looooo`;o00001Oooool3
o`0000Cooooo0_l00002ooooo`;o00002Oooool4o`00017ooooo1_l0000Booooo`;o00003_ooool2
o`0000Gooooo0_l0000<ooooo`Ko00001Oooool2o`0000Cooooo0_l00002ooooo`;o00000_oooolE
o`0000Cooooo0_l0000;ooooo`;o00001?ooool2o`00017ooooo0_l0000jooooo`007?ooool00ol0
003oooooooooo`0Xooooo`;o00007?ooool2o`0000;ooooo0_l000000ooooooo0000o`000005oooo
o`;o00000oooool2o`0000Sooooo0ol00002ooooo`;o00003oooool4o`0000gooooo0_l0000Coooo
o`;o00005?ooool6o`0000oooooo0_l00003oooooaGo00000_ooool4o`0000[ooooo0_l00006oooo
o`;o00004Oooool2o`0003Sooooo000Looooo`03o`000?oooooooooo02[ooooo0_l000000ooooooo
0000o`00000Jooooo`?o00001?ooool6o`0000?ooooo0_l0000=ooooo`;o00002oooool2o`0001?o
oooo0_l00004ooooo`;o00001Oooool2o`0000Gooooo0ol0000?ooooo`;o00001Oooool2o`0000;o
oooo0_l0000>oooooa[o000000?oooooo`000?l000000_l00004ooooo`;o00000oooool2o`0000Oo
oooo0_l00009ooooo`;o00001_ooool2o`0003Sooooo000Looooo`03o`000?oooooooooo02[ooooo
0_l000000ooooooo0000o`00000Jooooo`?o00001?ooool5o`0000cooooo0_l00005ooooo`;o0000
2oooool2o`0000Wooooo1Ol00007ooooo`?o000000?oooooo`000?l000001Oooool2o`0000Gooooo
0_l0000<ooooo`;o000000?oooooo`000?l000000ol00007ooooo`;o00003?ooool8o`000003oooo
ool0003o000001Co00001?ooool4o`0000?ooooo0_l0000Booooo`?o0000?oooool001cooooo00?o
0000ooooooooool0A?ooool2o`0000?ooooo1Ol0000Cooooo`;o00002oooool2o`00013ooooo1Ol0
0007ooooo`Go000000?oooooo`000?l000002_ooool2o`0000Wooooo0_l000000ooooooo0000o`00
0006o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Cooooo7_l0
0005ooooo`;o00003_ooool2o`0000Kooooo0_l00002ooooo`;o0000?oooool001cooooo00?o0000
ooooooooool0A?ooool2o`0000;ooooo0ol000000ooooooo0000o`000008ooooo`;o00003Oooool3
o`0000Kooooo0_l0000Oooooo`;o000000Coooooo`000?l0003o00002Oooool2o`0000Wooooo0_l0
0002ooooo`?o000000?oooooo`000?l000000_l00002ooooo`;o00000oooool2o`000003ooooool0
003o000000;ooooo0_l00005ooooo`co000000?oooooo`000?l000003_l00002ooooo`;o00004Ooo
ool2o`000003ooooool0003o000000?ooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`0[
ooooo`;o00006Oooool4o`0000cooooo0_l0000=ooooo`?o00005Oooool2o`0000Wooooo0_l00009
ooooo`;o00002_ooool2o`0000gooooo0_l00002ooooo`?o00003?ooool2o`0000Wooooo6Ol00004
ooooo`;o000000?oooooo`000?l000002oooool2o`0000Cooooo1?l0000:ooooo`;o000000?ooooo
o`000?l00000=oooool001cooooo00?o0000ooooooooool0:oooool2o`0001Kooooo1Ol00006oooo
o`;o00001Oooool2o`000003ooooool0003o000000Oooooo0_l0000Jooooo`;o00001oooool4o`00
00Wooooo0ol00009ooooo`?o00004Oooool2o`000003ooooool0003o000000Cooooo0_l00003oooo
o`;o00002OoooolHo`0000Sooooo0ol0000:ooooo`Co00000oooool3o`0000;ooooo0_l00004oooo
o`Co000000?oooooo`000?l000001oooool2o`0002kooooo000Looooo`03o`000?oooooooooo02?o
oooo0_l0000Nooooo`?o00002?ooool2o`0000Gooooo0_l000000ooooooo0000o`000007ooooo`;o
000000?oooooo`000?l000004Oooool2o`0000cooooo1Ol000000ooooooo0000o`000005ooooo`Go
000000?oooooo`000?l000001_ooool2o`0001;ooooo1_l00002ooooo`;o00000_ooool2o`0000So
oooo6_l000000ooooooo0000o`000006ooooo`?o00002oooool2o`0000?ooooo0_l00003ooooo`;o
00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`;o0000;_ooool001cooooo
0_l0000Tooooo`;o00007Oooool4o`0000?ooooo0ol0000Cooooo`;o00000oooool2o`0000oooooo
1?l00005ooooo`Co00000oooool8o`0000Gooooo0_l000001?oooooo0000o`000?ooool3o`0000Go
oooo1?l00007ooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`Co00001Oooool2o`00
00?ooooo0_l00003oooooaWo00000_ooool3o`0000?ooooo0_l000000ooooooo0000o`00000;oooo
o`;o00002?ooool4o`0000Kooooo0_l000000ooooooo0000o`000002o`0003?ooooo000Looooo`03
o`000?oooooooooo02gooooo0_l0000Booooo`Co00001?ooool3o`0001;ooooo0ol0000Dooooo`;o
00001_ooool5o`0000Cooooo1_l0000=ooooo`;o00001oooool2o`0000Kooooo0ol00004ooooo`;o
000000?oooooo`000?l000001Ol0000:ooooo`Co000000?oooooo`000?l000004_l000000ooooooo
0000o`000007o`0000?ooooo0_l0000>ooooo`;o00000_ooool2o`0000Kooooo0_l00003ooooo`;o
000000?oooooo`000?l000000_l000000ooooooo0000o`000004ooooo`;o0000;Oooool001cooooo
00?o0000ooooooooool0;Oooool2o`0001;ooooo1?l0000Cooooo`;o00001?ooool2o`0000;ooooo
0_l0000Iooooo`;o00001?ooool2o`0000Gooooo0_l0000;ooooo`;o00004Oooool2o`0000;ooooo
0ol00004ooooo`Co00003Oooool3o`0000;ooooo7?l0000Hooooo`;o00002?ooool2o`000003oooo
ool0003o000000?ooooo0_l00007ooooo`;o0000;Oooool001cooooo00?o0000ooooooooool08_oo
ool2o`0001cooooo1?l0000Dooooo`;o00001oooool3o`0001cooooo0_l000000ooooooo0000o`00
0007ooooo`;o00002Oooool2o`0001Gooooo0ol00004ooooo`?o00004_oooolHo`000004ooooool0
003o0000o`0000Oooooo0ol0000Aooooo`;o00001?ooool4o`0000Kooooo0_l00005ooooo`;o0000
;oooool001cooooo00?o0000ooooooooool08_ooool4o`0001Wooooo1_l000000ooooooo0000o`00
000Iooooo`?o00007?ooool2o`0000[ooooo0_l0000<ooooo`;o00005Oooool2o`000003ooooool0
003o000000Go00000_ooool2o`0000_ooooo0_l000000ooooooo0000o`00000Co`0000;ooooo1?l0
0005ooooo`?o00002oooool2o`0000Cooooo0_l00004ooooo`Co00001_ooool2o`0000Gooooo0_l0
000_ooooo`007?ooool00ol0003oooooooooo`0Tooooo`;o00005oooool4o`0000;ooooo0_l00000
0ooooooo0000o`00000Dooooo`;o000000Coooooo`000?l0003ooooo0_l00006ooooo`;o00001Ooo
ool4o`0000Sooooo0_l000000ooooooo0000o`00000;ooooo`;o00002oooool2o`0001Gooooo0_l0
00000ooooooo0000o`000005o`0000;ooooo0_l00009ooooo`;o00001?ooool2o`000003ooooool0
003o000000oo00001?ooool4o`0000oooooo1?l00009ooooo`;o000000?oooooo`000?l00000?_oo
ool001cooooo00?o0000ooooooooool0?Oooool4o`0001_ooooo1Ol00009ooooo`Co00000oooool4
o`0000Sooooo1?l0000<ooooo`;o00002oooool2o`0001Kooooo0_l000000ooooooo0000o`000007
ooooo`;o00002?ooool4o`0000;ooooo0_l000000ooooooo0000o`00000?o`0000?ooooo0_l00000
0ooooooo0000o`000002ooooo`;o00002_ooool3o`0000Cooooo0_l00004ooooo`Go0000?oooool0
01cooooo00?o0000ooooooooool0<?ooool2o`0000cooooo0ol00003ooooo`;o00005Oooool6o`00
00Kooooo0_l00002ooooo`?o00000_ooool9o`0000;ooooo1_l0000=ooooo`;o00002_ooool4o`00
01?ooooo0ol000000ooooooo0000o`000002o`0000Gooooo0_l0000:ooooo`;o00001_ooool?o`00
00Cooooo0_l00005ooooo`;o00002_ooool2o`0000Gooooo0_l00004ooooo`Go00003?ooool2o`00
037ooooo000Looooo`03o`000?oooooooooo033ooooo0_l0000;ooooo`?o00001?ooool2o`0000co
oooo1?l000000ooooooo0000o`000002ooooo`Co00000_ooool4o`0000;ooooo0_l00007ooooo`Wo
00000_ooool2o`0000[ooooo0_l00004ooooo`?o00002oooool3o`0000?ooooo0_l0000>ooooo`;o
00000_ooool6o`0001Oooooo3Ol000001?oooooo0000o`000?ooool3o`0001[ooooo0_l00004oooo
o`;o00001Oooool2o`0000Oooooo0_l0000aooooo`007?ooool00ol0003oooooooooo`0mooooo`;o
00004oooool4o`000003ooooool0003o000000Sooooo2?l00002ooooo`?o00001?ooool2o`0000?o
oooo0_l0000>ooooo`?o00000oooool2o`0000Cooooo0_l00007ooooo`;o00000oooool2o`0000ko
oooo0_l00002ooooo`Ko00004_ooool2o`0000?ooooo1_l00002ooooo`Go000000Coooooo`000?l0
003ooooo0ol0000Jooooo`;o00001?ooool2o`0000?ooooo1?l0000jooooo`007?ooool00ol0003o
ooooooooo`1>ooooo`;o00004_ooool2o`000003ooooool0003o000000;o00000_ooool3o`0000Ko
oooo0_l000001?oooooo0000o`000?ooool2o`0000Sooooo1_l00009ooooo`;o00001oooool2o`00
02oooooo4Ol0000Iooooo`;o00004_ooool4o`0003[ooooo000Looooo`03o`000?oooooooooo04co
oooo1?l00006ooooo`;o00002_ooool4o`000003ooooool0003o000000Kooooo0_l000000ooooooo
0000o`000009o`0000Oooooo1?l00003ooooo`;o00000_ooool3o`0000Wooooo1?l0000;ooooo`;o
00008Oooool=o`0000;ooooo0_l0000Iooooo`;o00002oooool2o`0000Kooooo0_l0000kooooo`00
7?ooool00ol0003oooooooooo`0Oooooo`;o00003_ooool2o`0000Wooooo0_l0000@ooooo`;o0000
0_ooool2o`0000Cooooo0_l00008ooooo`Ko000000?oooooo`000?l000001OoooolAo`0000Gooooo
0ol00004ooooo`_o00001Oooool4o`000004ooooool0003o0000o`0000Oooooo0_l0000Dooooo`;o
00004_ooool6o`0000;ooooo0_l00008ooooo`;o00006_ooool6o`00047ooooo000Looooo`03o`00
0?oooooooooo01oooooo0_l0000>ooooo`;o00002Oooool2o`0001Cooooo0_l00009ooooo`;o0000
0oooool2o`0000;ooooo0ol00003oooooa3o000000?oooooo`000?l000001Ol00002ooooo`Co0000
0oooool4o`0000;ooooo1Ol0000:ooooo`Go00003?ooool2o`0000Kooooo0_l00005ooooo`;o0000
4?ooool5o`0000;ooooo0ol0000:ooooo`;o00001?ooool2o`0001Cooooo0_l000001?oooooo0000
o`000?l00009ooooo`;o000000Coooooo`000?l0003ooooo0_l0000`ooooo`007?ooool00ol0003o
ooooooooo`0Iooooo`;o00007_ooool4o`0000gooooo0_l00003ooooo`;o00002_ooool2o`0000Oo
oooo0ol00003oooooaSo000000?oooooo`000?l000001?l00003ooooo`;o00000oooool2o`0000;o
oooo0_l00008ooooo`?o000000?oooooo`000?l000003?ooool2o`0000Gooooo1?l0000Dooooo`Oo
00000_ooool3o`00013ooooo0_l0000Gooooo`?o00002Oooool2o`000004ooooool0003o0000oooo
o`;o0000<?ooool001cooooo00?o0000ooooooooool06Oooool2o`0001cooooo1_l0000=ooooo`;o
00000oooool2o`0000Cooooo0ol00003ooooo`;o00000oooool5o`0000?ooooo2Ol000000ooooooo
0000o`00000>o`000003ooooool0003o000000Ko000000?oooooo`000?l000000oooool2o`0000;o
oooo0_l00008ooooo`?o000000?oooooo`000?l000004oooool4o`0001Cooooo0_l000000ooooooo
0000o`000002o`0002kooooo0ol00009ooooo`;o0000=_ooool001cooooo0_l0000_ooooo`;o0000
1oooool8o`0000Gooooo0_l0000<ooooo`;o000000Coooooo`000?l0003o00001Oooool2o`000003
ooooool0003o000000?o000000?oooooo`000?l000002_l000000ooooooo0000o`00000Bo`000003
ooooool0003o000000Co00000oooool3o`0000_ooooo1?l00007ooooo`;o00001oooool2o`0000Ko
oooo1?l00013ooooo`;o000000?oooooo`000?l000002_ooool2o`0003Kooooo000Looooo`03o`00
0?oooooooooo01oooooo0_l0000=ooooo`;o00002?ooool7o`0000Gooooo0_l0000<ooooo`;o0000
0_ooool2o`0000Gooooo1ol00002ooooo`Co00000_oooolQo`0000Cooooo0ol0000=ooooo`?o0000
1_ooool2o`0000;ooooo1?l000000ooooooo0000o`000002ooooo`;o00000_ooool4o`0003oooooo
0_l00002ooooo`Go00000_ooool2o`0003kooooo000Looooo`03o`000?oooooooooo01oooooo0_l0
000Gooooo`Go00004oooool4o`0000_ooooo0ol00003ooooo`Co00000ooooolOo`0000oooooo0_l0
0006ooooo`;o00002_ooool4o`0000Gooooo0_l00002ooooo`;o0000@Oooool2o`000004ooooool0
003o0000ooooo`?o00000_ooool2o`000003ooooool0003o000000Wooooo0_l0000`ooooo`007?oo
ool00ol0003oooooooooo`14ooooo`;o00002_ooool2o`000003ooooool0003o000000Kooooo1?l0
00000ooooooo0000o`000002o`000003ooooool0003o000002Go00003_ooool2o`0000Sooooo1?l0
000:ooooo`co00009Oooool3o`0001_ooooo1Ol00003ooooo`;o000000Coooooo`000?l0003ooooo
0_l00006ooooo`;o0000<?ooool001cooooo00?o0000ooooooooool0A?ooool2o`0000gooooo0_l0
0006ooooo`Wo000000?oooooo`000?l000000_oooolLo`000004ooooool0003o0000ooooo`?o0000
00?oooooo`000?l000003?ooool2o`0000Oooooo1?l0000:ooooo`co00009Oooool3o`0001cooooo
1?l00003ooooo`;o00000oooool3o`0003Sooooo000Looooo`03o`000?oooooooooo01oooooo0_l0
000Mooooo`;o00004_ooool3o`0000Oooooo1?l00004ooooo`;o00000ooooolOo`000003ooooool0
003o000000;ooooo0_l0000;ooooo`?o00004_ooool2o`000003ooooool0003o000000Ko00000ooo
ool2o`00017ooooo0_l0000@ooooo`;o00007_ooool2o`0000[ooooo0ol00007ooooo`;o0000;ooo
ool001cooooo00?o0000ooooooooool07oooool2o`0001gooooo0_l0000<ooooo`;o00001?ooool2
o`0000Sooooo0_l00005ooooo`?o00000ooooolPo`0000[ooooo0_l00005ooooo`;o00004oooool2
o`0000;ooooo1Ol00002ooooo`;o000000Coooooo`000?l0003ooooo0ol0000=ooooo`;o00004?oo
ool2o`0001gooooo1?l0000:ooooo`;o00001oooool2o`0002oooooo000Looooo`03o`000?oooooo
oooo02kooooo0_l0000Dooooo`;o00001_ooool2o`00013ooooo1ol00002ooooob?o00000_ooool4
o`0000?ooooo0_l00005ooooo`;o00001?ooool2o`00017ooooo0_l00005ooooo`;o000000Cooooo
o`000?l0003ooooo1?l0000<ooooo`;o00003?ooool3o`000003ooooool0003o000001_ooooo1_l0
0005ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0;_ooool2o`0001Cooooo0_l0000H
ooooobco00000_ooool4o`0000[ooooo0_l000001?oooooo0000o`000?ooool4o`0000cooooo0_l0
0004ooooo`;o00001Oooool2o`000003ooooool0003o000000;o00002oooool2o`0000Gooooo0ol0
0005ooooo`?o00007_ooool4o`0000Oooooo0_l00002ooooo`;o00001oooool2o`00033ooooo000L
ooooo`03o`000?oooooooooo02kooooo0_l00008ooooo`;o00004?ooool2o`0000Wooooo0_l0000:
ooooo`;o000000?oooooo`000?l000009Ol00002ooooo`;o00001Oooool2o`0000Oooooo0_l00000
0ooooooo0000o`000002o`0000cooooo0_l00004ooooo`;o00001Oooool2o`000004ooooool0003o
0000o`0000cooooo0_l00005ooooo`?o00008oooool2o`0000?ooooo0_l00004ooooo`;o00001Ooo
ool2o`0000Oooooo0_l0000`ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00003_ooool4
o`0000Wooooo0_l00003ooooo`;o000000?oooooo`000?l000001_oooolIo`000003ooooool0003o
000000_o000000?oooooo`000?l000001Oooool2o`0000[ooooo0_l0000Eooooo`;o00001?ooool2
o`000004ooooool0003o0000o`00013ooooo0_l00002ooooo`?o00000_ooool2o`0001kooooo0_l0
0005ooooo`;o00000_ooool2o`0000gooooo0_l0000aooooo`007?ooool00ol0003oooooooooo`0l
ooooo`;o00002?ooool4o`0000[ooooo0_l00004ooooo`So00000ooooolYo`0000Kooooo0_l00005
ooooo`;o00000oooool2o`0000_ooooo0_l00008ooooo`;o00000_ooool7o`0000?ooooo0_l0000<
ooooo`;o00000oooool2o`0000;ooooo0_l0000Uooooo`;o00002_ooool2o`0000Gooooo0_l0000a
ooooo`007?ooool00ol0003oooooooooo`0looooo`;o00002?ooool2o`0000Kooooo0_l00004oooo
o`;o00001Oooool2o`000003ooooool0003o000000;o000000?oooooo`000?l00000:Ol0000=oooo
o`;o00004?ooool2o`0000_ooooo1_l00005ooooo`;o00004?ooool2o`000003ooooool0003o0000
03?ooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00001oooool2o`0000Co
oooo1?l00004ooooo`;o00000_ooool2o`0000Cooooo<ol00002ooooo`;o00008?ooool2o`0000;o
oooo2Ol0000Eooooo`;o000000Coooooo`000?l0003o0000;_ooool3o`0003_ooooo000Looooo`03
o`000?oooooooooo01oooooo0_l0000=ooooo`;o00003Oooool2o`0000gooooo0_l0000:ooooo`;o
000000Coooooo`000?l0003ooooo1Ol000001?oooooo0000o`000?oooolMo`000003ooooool0003o
000000_o000000?oooooo`000?l000000_l00004ooooo`;o00004oooool2o`0000?ooooo0_l00002
ooooo`?o000000?oooooo`000?l000000ol0000Iooooo`;o00001Oooool4o`0001?ooooo0_l00009
ooooo`;o00000oooool5o`0003_ooooo000Looooo`03o`000?oooooooooo01oooooo0_l0000=oooo
o`;o00002oooool2o`0000oooooo0_l00005ooooo`;o00001_ooool2o`000003ooooool0003o0000
00;o00000oooool6o`000003ooooool0003o000000ko000000?oooooo`000?l000004ol000000ooo
oooo0000o`000002o`0000Cooooo0_l00006ooooo`;o00000oooool2o`0000Cooooo1?l00006oooo
o`?o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l0000Kooooo`Co00000_ooool2o`00
00oooooo0_l00009ooooo`;o00000oooool2o`0003kooooo000Looooo`;o00008?ooool4o`0000_o
oooo0_l0000;ooooo`;o00001oooool2o`0000Kooooo0_l00005ooooo`;o00002Oooool5o`000003
ooooool0003o000000Go000000?oooooo`000?l000006?l000000ooooooo0000o`000004o`000003
ooooool0003o000000?ooooo0_l0000>ooooo`;o00000oooool2o`0000;ooooo1?l00008ooooo`;o
00000_ooool4o`0000?ooooo1Ol00002ooooo`?o00003_ooool2o`0000_ooooo0_l0000?ooooo`;o
00003_ooool2o`0000Oooooo0_l0000eooooo`007?ooool00ol0003oooooooooo`0Oooooo`Co0000
2oooool2o`0000Oooooo0_l00002ooooo`;o00001oooool2o`0000gooooo0_l00002ooooo`;o0000
1Oooool_o`0000Cooooo0_l0000Iooooo`;o000000Coooooo`000?l0003o00000oooool2o`000004
ooooool0003o0000ooooo`;o000000?oooooo`000?l000000oooool5o`0000;ooooo0ol0000>oooo
o`;o00002Oooool3o`00017ooooo0_l00009ooooo`;o00000_ooool2o`0000Oooooo0_l0000eoooo
o`007?ooool00ol0003oooooooooo`0gooooo`;o00000_ooool2o`0000[ooooo0_l00009ooooo`;o
000000?oooooo`000?l000000_l000001?oooooo0000o`000?ooool9o`0000;ooooo9Ol00003oooo
o`Oo00005_ooool5o`0000?ooooo0_l000000ooooooo0000o`00000<o`0000?ooooo0ol0000Eoooo
o`;o00000oooool3o`00017ooooo0_l00009ooooo`Co0000@?ooool001cooooo00?o0000oooooooo
ool0;Oooool2o`0000Sooooo0_l00002ooooo`;o00002?ooool4o`0000Cooooo0_l00003ooooo`;o
000000?oooooo`000?l000000oooool2o`000003ooooool0003o000000Co000000?oooooo`000?l0
00000_l00003oooooa[o000000?oooooo`000?l000000ol00003ooooo`[o000000?oooooo`000?l0
00000_l00005ooooo`;o00000oooool2o`0000Cooooo0_l00006ooooo`;o000000?oooooo`000?l0
00002_l00005ooooo`Co00005?ooool2o`0001kooooo0_l00003ooooo`?o0000@?ooool001cooooo
00?o0000ooooooooool0;Oooool2o`0000Sooooo0_l00002ooooo`;o00002?ooool4o`0000Cooooo
0_l00006ooooo`;o00001_ooool6o`000003ooooool0003o000001_o000000?oooooo`000?l00000
0ol000001?oooooo0000o`000?l00003ooooo`Co000000Coooooo`000?l0003ooooo0_l000000ooo
oooo0000o`000002o`0000?ooooo1?l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00005oooo
o`Oo00001Oooool2o`0000Gooooo0ol0000dooooo`;o00000oooool2o`000003ooooool0003o0000
03kooooo000Looooo`03o`000?oooooooooo02gooooo0_l00009ooooo`;o00002_ooool5o`0000Co
oooo0_l00008ooooo`Co00000_ooool3o`000003ooooool0003o000002So000000Goooooo`000?l0
003o0000ooooo`02o`000003ooooool0003o000000;ooooo1?l00002ooooo`;o000000?oooooo`00
0?l000002Oooool2o`0000?ooooo0_l00005ooooo`Co000000?oooooo`000?l000001?l000001Ooo
oooo0000o`000?l0003ooooo00?o000000?oooooo`000?l000000_l00003ooooo`;o00003?ooool2
o`000003ooooool0003o000001Kooooo0_l0000<ooooo`?o0000?Oooool001cooooo00?o0000oooo
ooooool0>?ooool2o`0000[ooooo0_l000000ooooooo0000o`000004ooooo`;o00000oooool2o`00
00?ooooo1Ol000000ooooooo0000o`000003ooooo`?o000000?oooooo`000?l000008_l00002oooo
o`?o00002?ooool4o`0000;ooooo0_l0000>ooooo`?o00002_ooool2o`000003ooooool0003o0000
013o00000oooool2o`0000cooooo1ol0000Dooooo`;o00003Oooool2o`0003gooooo000Looooo`03
o`000?oooooooooo04gooooo0ol00002ooooo`;o00001_ooool2o`0000Kooooo2?l000000ooooooo
0000o`00000Lo`000003ooooool0003o000000Sooooo0_l0000Gooooo`?o00002_ooool3o`0000Co
oooo2_l0000Dooooo`Co00000_ooool2o`0006;ooooo000Looooo`03o`000?oooooooooo04kooooo
0_l000000ooooooo0000o`000002ooooo`;o00000oooool2o`0000?ooooo0_l000000ooooooo0000
o`000006o`000003ooooool0003o000001co000000Goooooo`000?l0003o0000ooooo`02o`0000Co
oooo0_l0000Qooooo`;o000000Coooooo`000?l0003o00000oooool4o`0000Kooooo0_l0000Coooo
o`;o00007Oooool2o`0000?ooooo0_l00006ooooo`;o0000??ooool001cooooo00?o0000oooooooo
ool0>_ooool2o`0000?ooooo0_l0000@ooooo`Ko00002?ooool2o`000003ooooool0003o000000;o
000000Coooooo`000?l0003o00000_ooool>o`0000;ooooo3_l000001?oooooo0000o`000?ooool4
o`0000_ooooo0ol0000Booooo`;o00000oooool3o`0000;ooooo0_l00002ooooo`;o00001oooool3
o`0000Cooooo0_l0000@ooooo`;o00006?ooool4o`0000?ooooo0_l00004ooooo`Co0000??ooool0
01cooooo00?o0000ooooooooool08Oooool2o`0001Oooooo0_l00003ooooo`;o00000oooool2o`00
0003ooooool0003o000000Sooooo1Ol0000<ooooo`Co000000Coooooo`000?l0003o00000oooool=
o`000003ooooool0003o000000go000000?oooooo`000?l000001Ol0000;ooooo`?o00004_ooool2
o`0000;ooooo1?l00002ooooo`;o00002oooool2o`0000Gooooo0_l00004ooooo`;o000000Cooooo
o`000?l0003o00001_ooool4o`0000;ooooo0_l00003ooooo`;o00003Oooool2o`0000Gooooo0_l0
0004ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool08Oooool2o`00027ooooo0_l00000
0ooooooo0000o`000003ooooo`;o00003oooool2o`0000?ooooo1ol00003ooooo`;o000000?ooooo
o`000?l000005_l00006ooooo`;o00008oooool6o`0000Gooooo0_l0000Gooooo`;o000000Cooooo
o`000?l0003o00002?ooool2o`0000;ooooo0_l00003ooooo`;o00001_ooool2o`0000gooooo0_l0
0003ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0>_ooool2o`00013ooooo0ol00004
ooooo`;o00002?ooool4o`000004ooooool0003o0000ooooo`Co00000oooool6o`000003ooooool0
003o000001;o00008_ooool2o`0000Oooooo1?l00002ooooo`;o00000oooool2o`0001Oooooo0_l0
00000ooooooo0000o`00000@ooooo`;o00002?ooool2o`0000Oooooo0_l00004ooooo`;o00000ooo
ool2o`0003kooooo000Looooo`03o`000?oooooooooo03[ooooo0_l0000@ooooo`?o00000_ooool4
o`0000Kooooo0_l00002ooooo`;o00001Oooool3o`0000Cooooo0ol00003ooooo`oo00000oooool2
o`0000Kooooo0_l0000Iooooo`?o00003Oooool2o`0001Wooooo0_l000000ooooooo0000o`000005
ooooo`;o00003?ooool2o`00017ooooo0_l00019ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^
k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0
Boooool3o`0000;ooooo0ol00008ooooo`;o00001oooool3o`0000Gooooo0ol00006ooooo`Go0000
0_ooool8o`000003ooooool0003o000000Kooooo0_l00003ooooo`;o00005?ooool2o`0000oooooo
0_l00003ooooo`;o00004oooool2o`0000Sooooo0_l0000<ooooo`;o00007oooool2o`0003_ooooo
00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRH
V?lQ8B401_ooool00ol0003oooooooooo`0oooooo`;o00002_ooool2o`0000?ooooo0_l00008oooo
o`;o00001oooool4o`0000Cooooo1_l000000ooooooo0000o`000003ooooo`Co00001Oooool5o`00
00Kooooo0_l00003ooooo`Co00001_ooool2o`000004ooooool0003o0000ooooo`;o00004_ooool2
o`0000?ooooo0_l00003ooooo`;o00000_ooool2o`00017ooooo0_l0000Dooooo`;o00007oooool2
o`0003_ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo03kooooo0ol000000ooooooo0000o`000007
ooooo`?o00000_ooool2o`0000Sooooo1?l00005ooooo`;o00001_ooool2o`000005ooooool0003o
0000o`000?ooool02Ol000000ooooooo0000o`000005ooooo`;o00001_ooool2o`0000?ooooo0_l0
0008ooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o00003?ooool4o`000003oooo
ool0003o000000Oooooo0_l0000Aooooo`;o00000oooool3o`0000[ooooo0_l00004ooooo`Ko0000
3_ooool2o`0000Sooooo0_l0000looooo`0000?oooooo`000?ooool00_ooool00ol0003ooooooooo
o`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0003kooooo0ol000000ooooooo0000
o`000007ooooo`?o00003_ooool2o`0001Kooooo2ol000001?oooooo0000o`000?ooool3o`000004
ooooool0003o0000ooooo`;o000000?oooooo`000?l000000oooool2o`0001;ooooo0_l00006oooo
o`;o00000oooool2o`000004ooooool0003o0000ooooo`;o00007oooool4o`0000Wooooo0_l00003
ooooo`Oo000000?oooooo`000?l000000oooool2o`0000Kooooo1?l00006ooooo`Co0000>_ooool0
0003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oEEEEo`000?l@413o
c<c<00Kooooo00?o0000ooooooooool0Boooool3o`0000;ooooo0_l00004ooooo`;o00001Oooool2
o`0000Gooooo0_l0000<ooooo`;o00000oooool8o`000003ooooool0003o000000Oo000000?ooooo
o`000?l000000ol00003ooooo`;o00000_ooool2o`000003ooooool0003o000000?ooooo0_l00005
ooooo`?o00001Oooool5o`000003ooooool0003o000000;o000000?oooooo`000?l000001_ooool2
o`0000Gooooo0_l0000Aooooo`Co00003_ooool2o`000003ooooool0003o000000?ooooo0_l00003
ooooo`;o00001_ooool4o`0000?ooooo0ol000001?oooooo0000o`000?l0000jooooo`0000?ooooo
oa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000
ooooooooool0AOooool2o`0000;ooooo0_l00005ooooo`;o00001?ooool4o`0000?ooooo0ol00004
ooooo`;o00002Oooool5o`0000Kooooo0_l00005ooooo`?o00000_ooool2o`0000;ooooo1?l00004
ooooo`;o00000_ooool5o`0000?ooooo0_l00005ooooo`?o00000oooool7o`000003ooooool0003o
000000Go000000?oooooo`000?l000000oooool3o`0000Cooooo0_l0000Vooooo`Co00003Oooool5
o`0000?ooooo1_l0000kooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@
413oV9RH00Sooooo00?o0000ooooooooool0AOooool2o`0000;ooooo0_l0000=ooooo`;o00001?oo
ool2o`0000oooooo1?l00007ooooo`;o00001Oooool2o`0000;ooooo0_l00003ooooo`Co00002?oo
ool9o`0000;ooooo0_l00004ooooo`;o00000_ooool3o`0000Cooooo0ol00002ooooo`;o00000_oo
ool2o`0000?ooooo0ol0000Hooooo`;o00005?ooool2o`000003ooooool0003o000000Wooooo1_l0
0004ooooo`Co0000??ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4
o`000?l@4106ooooo`03o`000?oooooooooo03oooooo0_l0000=ooooo`Co00001?ooool2o`0001Oo
oooo0ol00003ooooo`;o00000_ooool2o`0000;ooooo0_l00006ooooo`;o00000oooool4o`0000So
oooo0_l00002ooooo`Go00000_ooool3o`0000?ooooo0_l00003ooooo`Co00000_ooool2o`00013o
oooo0_l00005ooooo`;o00003_ooool4o`0001Gooooo0_l00009ooooo`;o0000B?ooool001cooooo
00?o0000ooooooooool0?oooool2o`0000gooooo1?l00004ooooo`;o00006oooool5o`000003oooo
ool0003o000000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000Gooooo0ol0000Eooooo`;o
000000?oooooo`000?l000001_ooool3o`0001Cooooo0_l00005ooooo`;o00002?ooool2o`000003
ooooool0003o000000?ooooo0_l0000Dooooo`;o00005Oooool2o`0003gooooo000Looooo`03o`00
0?oooooooooo04[ooooo1Ol00003ooooo`;o00001_ooool2o`0000Gooooo0_l0000@ooooo`;o0000
00Coooooo`000?l0003ooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l00005oooo
o`?o00002Oooool2o`0000?ooooo0_l00008ooooo`;o00001_ooool2o`0001cooooo0_l00008oooo
o`;o000000?oooooo`000?l000001Oooool2o`0001;ooooo0_l0000<ooooo`;o00001oooool2o`00
03gooooo000Looooo`03o`000?oooooooooo04[ooooo1Ol00003ooooo`;o00001_ooool2o`0000Go
oooo0_l0000=ooooo`;o00006?ooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o
00000_ooool3o`0000Kooooo0_l00008ooooo`;o00003oooool3o`0000[ooooo0_l0000Booooo`;o
00007_ooool5o`0004Gooooo000Looooo`03o`000?oooooooooo04oooooo0_l0000Aooooo`;o0000
3?ooool4o`0000_ooooo0_l000000ooooooo0000o`000006ooooo`;o00000oooool2o`000003oooo
ool0003o000000?ooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo1?l00004ooooo`;o
00000_ooool2o`0000Cooooo0_l00007ooooo`Go00000_ooool2o`0000;ooooo0_l00003ooooo`Go
00000_ooool3o`000003ooooool0003o000000;o00001?ooool2o`0001Cooooo0_l00008ooooo`;o
000000?oooooo`000?l000000oooool2o`00043ooooo000Looooo`03o`000?oooooooooo04Wooooo
0_l00004ooooo`;o00000oooool2o`000003ooooool0003o000000Wooooo1_l00003ooooo`;o0000
00?oooooo`000?l000001?l0000;ooooo`;o000000?oooooo`000?l000001_ooool2o`0000[ooooo
0ol000001?oooooo0000o`000?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`000003
ooooool0003o000000Sooooo0ol00006ooooo`;o00000oooool4o`0000;ooooo0_l00002oooooa3o
00001?ooool2o`0001?ooooo0ol00003ooooo`;o00002oooool2o`00043ooooo000Looooo`03o`00
0?oooooooooo043ooooo1?l00004ooooo`?o00002?ooool3o`000003ooooool0003o000000Cooooo
0_l00005ooooo`Ko000000Coooooo`000?l0003ooooo1?l00007ooooo`;o00000oooool2o`0001Ko
oooo0_l000000ooooooo0000o`000004ooooo`;o00000_ooool7o`0000Sooooo1?l0000;ooooo`?o
00001_ooool?o`0001_ooooo0_l00004ooooo`;o00001_ooool2o`0004Gooooo000Looooo`03o`00
0?oooooooooo043ooooo1?l00004ooooo`;o00000_ooool2o`0000Gooooo0ol00007ooooo`?o0000
2?ooool2o`000003ooooool0003o000000[ooooo1?l00003ooooo`;o00000oooool2o`0001?ooooo
1?l000000ooooooo0000o`000002o`0000;ooooo1?l000000ooooooo0000o`000004o`0000Cooooo
0_l00004ooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`oo0000
1?ooool2o`0002?ooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`11ooooo`;o00001ooo
ool4o`0000Kooooo0ol00007ooooo`?o00005_ooool2o`0000;ooooo0_l00006ooooo`;o00004?oo
ool2o`000003ooooool0003o000000;o000000Coooooo`000?l0003ooooo0_l00008ooooo`Ko0000
0_ooool2o`0000Cooooo0ol000001?oooooo0000o`000?ooool2o`000004ooooool0003o0000oooo
o`;o00001?ooool@o`0000;ooooo0_l000000ooooooo0000o`00000Dooooo`;o00000_ooool2o`00
00Wooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`0Zooooo`;o00007_ooool4o`0000Ko
oooo0ol00008ooooo`Co00002oooool2o`0000;ooooo0_l00007ooooo`;o00006?ooool2o`000003
ooooool0003o000000Wo00001Oooool8o`000004ooooool0003o0000o`0000Gooooo0_l00003oooo
o`?o00002_ooool8o`0000?ooooo2?l00002ooooo`;o00001Oooool2o`0000Sooooo0_l00003oooo
o`?o000000?oooooo`000?l000001oooool4o`0004;ooooo000Looooo`03o`000?oooooooooo02[o
oooo0_l0000Kooooo`;o00000oooool2o`0000Cooooo1?l000000ooooooo0000o`000005ooooo`;o
000000?oooooo`000?l000000oooool2o`0000Cooooo1?l00002ooooo`;o00008oooool<o`000003
ooooool0003o000000go00002oooool2o`0000[ooooo5?l00009ooooo`;o00000oooool2o`0000?o
oooo0_l00004ooooo`Ko00001_ooool2o`0004Cooooo000Looooo`03o`000?oooooooooo04Oooooo
0_l00009ooooo`;o00000_ooool3o`0000Gooooo0_l00006ooooo`;o00001?ooool2o`0001_ooooo
0_l000001?oooooo0000o`000?l00008ooooo`?o000000?oooooo`000?l000005ol00008ooooo`Co
000000Coooooo`000?l0003o00001_oooolAo`0000cooooo0_l00003ooooo`;o00002Oooool3o`00
0003ooooool0003o000004cooooo000Looooo`;o0000B?ooool2o`000003ooooool0003o000000Oo
oooo1Ol000000ooooooo0000o`000002o`0000Wooooo0_l0000Qooooo`;o000000Coooooo`000?l0
003o00000oooool4o`0000;ooooo7Ol00004ooooo`;o000000?oooooo`000?l000001_l00005oooo
o`;o000000?oooooo`000?l000003Ol0000Cooooo`;o00001oooool2o`0000Gooooo0_l00019oooo
o`007?ooool00ol0003oooooooooo`1:ooooo`;o00001oooool4o`0000;ooooo1_l0000Aooooo`;o
00002oooool2o`0000;ooooo0_l0000?ooooo`Co00000_ooool4o`0000;ooooo1Ol000000ooooooo
0000o`00000?o`0000?ooooo0ol00004ooooo`;o000000?oooooo`000?l000001Oooool2o`000003
ooooool0003o000000go00004oooool2o`0000kooooo0_l00019ooooo`007?ooool00ol0003ooooo
ooooo`0/ooooo`;o00006Oooool2o`0001;ooooo1?l00006ooooo`;o00002Oooool2o`0000Kooooo
0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o000000gooooo1?l000000ooooooo0000
o`000002o`0000;ooooo5Ol00003ooooo`Co00002?ooool2o`0000?ooooo0_l00007ooooo`_o0000
00?oooooo`000?l000003Oooool2o`0000[ooooo0_l000000ooooooo0000o`00001=ooooo`007?oo
ool00ol0003oooooooooo`0/ooooo`;o00006Oooool2o`0000_ooooo0_l00005ooooo`;o00001_oo
ool4o`0000Kooooo0_l00009ooooo`?o00002Oooool2o`0000kooooo0ol00002oooooa;o000000?o
ooooo`000?l000001ol000000ooooooo0000o`00000=ooooo`Co00002?ooool5o`0000?ooooo0_l0
00000ooooooo0000o`00000=ooooo`Co00001Oooool2o`000004ooooool0003o0000ooooo`Co0000
Boooool001cooooo00?o0000ooooooooool0BOooool2o`0000Wooooo0_l00005ooooo`;o00001_oo
ool2o`0000Sooooo0_l0000:ooooo`;o00007_oooolBo`000003ooooool0003o000000So00003ooo
ool2o`0000cooooo0_l00002ooooo`;o00004Oooool5o`0000Gooooo0_l00006ooooo`;o0000Booo
ool001cooooo00?o0000ooooooooool0AOooool2o`0000;ooooo0_l00004ooooo`;o00000oooool2
o`0000;ooooo0_l0000Booooo`?o00008oooool3o`0000Kooooo0_l000000ooooooo0000o`00000G
o`0000?ooooo0_l0000Kooooo`;o00001_ooool2o`0000;ooooo0_l00004ooooo`?o000000?ooooo
o`000?l000001Oooool2o`0005?ooooo000Looooo`03o`000?oooooooooo04Gooooo0_l00002oooo
o`;o00001?ooool3o`0000;ooooo0_l00002ooooo`Go00003oooool3o`0000Cooooo0_l0000Moooo
o`?o00001_oooolNo`000003ooooool0003o000000_ooooo0_l0000Fooooo`;o00000_ooool8o`00
00Oooooo1?l0001Cooooo`007?ooool00ol0003oooooooooo`17ooooo`Co00001Oooool2o`0000;o
oooo0_l00003ooooo`Co00003Oooool2o`0000Oooooo0_l0000Mooooo`;o00000_ooool2o`0000?o
oooo8_l00006ooooo`;o000000?oooooo`000?l000000_l0000=ooooo`;o00003?ooool6o`0000Oo
oooo1?l00007ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0Aoooool3o`0000;ooooo
0_l00009ooooo`Co000000?oooooo`000?l000003?ooool2o`0002Wooooo0ol000000ooooooo0000
o`00000Ro`0000Kooooo0_l000000ooooooo0000o`000002o`0000Wooooo0_l00002ooooo`;o0000
1oooool2o`000003ooooool0003o000000Ko00004_ooool2o`0004[ooooo000Looooo`03o`000?oo
oooooooo04Oooooo0_l00003ooooo`;o00001Oooool2o`0000;ooooo1ol000000ooooooo0000o`00
0002ooooo`;o00000_ooool2o`0002?ooooo0ol00006ooooobSo00003oooool2o`0000;ooooo0_l0
00000ooooooo0000o`000008ooooo`;o000000?oooooo`000?l000001Ol00007ooooo`;o0000FOoo
ool001cooooo00?o0000ooooooooool0<_ooool2o`0001Wooooo0_l00004ooooo`;o00001Oooool2
o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`0002?ooooo0ol00008ooooo`?o00000_oooolC
o`000003ooooool0003o000000_o00003oooool2o`0000;ooooo0_l0000;ooooo`;o00000oooool4
o`0000;ooooo0_l00004ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0<_ooool2o`00
01Cooooo0ol00002ooooo`;o0000BOooool2o`0000;ooooo4Ol000000ooooooo0000o`00000:o`00
02Cooooo1?l000000ooooooo0000o`000002ooooo`?o0000Goooool001cooooo00?o0000oooooooo
ool0B?ooool3o`0000?ooooo0_l0001<oooooa_o00000oooool2o`000003ooooool0003o000000;o
oooo0_l0000Kooooo`Co000000?oooooo`000?l000000_ooool2o`00063ooooo000Looooo`03o`00
0?oooooooooo03Cooooo0_l0000Hooooo`;o00000_ooool2o`00023ooooo0_l0000Oooooo`;o0000
0oooool2o`0000;ooooo6ol000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00002ooooo`;o
00004_ooool2o`0000Gooooo0_l0001Wooooo`007?ooool00ol0003oooooooooo`0dooooo`;o0000
7?ooool2o`0000;ooooo0_l00004ooooo`Go00004oooool2o`0001Kooooo0_l00007ooooo`;o0000
0_ooool3o`0000?ooooo5_l000000ooooooo0000o`000002o`0000_ooooo0_l00009ooooo`;o0000
1Oooool4o`0000?ooooo1?l0000:ooooo`;o0000Foooool001cooooo00?o0000ooooooooool0Cooo
ool2o`0000Gooooo0_l00004ooooo`Go00002oooool2o`0001kooooo1?l00009ooooo`Go000000Go
ooooo`000?l0003o0000ooooo`0Go`0001Gooooo0ol00005ooooo`Co00000oooool2o`0000Sooooo
0_l00002ooooo`;o00001Oooool2o`0000?ooooo0_l0001?ooooo`007?ooool2o`00053ooooo0_l0
000=ooooo`;o00003?ooool2o`0000Kooooo0ol0000Gooooo`;o00002oooool6o`0000;ooooo4Ol0
00000ooooooo0000o`000003o`0001;ooooo0_l000001?oooooo0000o`000?l00007ooooo`?o0000
2_ooool6o`000003ooooool0003o000000?ooooo1?l00002ooooo`;o0000Coooool001cooooo00?o
0000ooooooooool0Doooool2o`0000kooooo0_l0000?ooooo`?o00008Oooool4o`000003ooooool0
003o000000;o000000?oooooo`000?l000004?l00009ooooo`;o00003?ooool3o`0000Gooooo0_l0
00000ooooooo0000o`000002ooooo`;o00002_ooool2o`000003ooooool0003o000000Co00000ooo
ool6o`00057ooooo000Looooo`03o`000?oooooooooo05?ooooo0_l00003ooooo`;o00002Oooool2
o`000003ooooool0003o0000033ooooo1?l000000ooooooo0000o`000002o`000003ooooool0003o
0000017o000000?oooooo`000?l000001Oooool2o`0000cooooo0_l00006ooooo`Oo00003oooool6
o`0000Gooooo1?l0001Aooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00006oooool2o`00
0003ooooool0003o000000?ooooo0_l00007ooooo`;o0000:oooool2o`0000?ooooo0_l00005oooo
oa[o00002?ooool2o`00017ooooo1_l0000>ooooo`Co000000?oooooo`000?l00000F_ooool001co
oooo00?o0000ooooooooool0>?ooool2o`0001Sooooo1Ol00006ooooo`;o00000_ooool2o`00033o
oooo0_l00002ooooo`?o00001_ooool@o`0000Cooooo1Ol00008ooooo`;o00003Oooool2o`0000?o
oooo1Ol00007ooooo`;o00001Oooool7o`0005[ooooo000Looooo`03o`000?oooooooooo05;ooooo
1Ol0000:ooooo`;o00004_ooool2o`00023ooooo0_l00009oooooaKo00006?ooool2o`0000?ooooo
0ol00007ooooo`Co00001_ooool4o`0005cooooo000Looooo`03o`000?oooooooooo053ooooo0_l0
0003ooooo`;o00005Oooool3o`0000Kooooo0_l0000Uooooo`Co00001?ooool2o`000003ooooool0
003o000000co00002?ooool2o`0000;ooooo0_l0000:ooooo`;o000000?oooooo`000?l000003Ooo
ool2o`0000?ooooo0ol00003ooooo`;o0000GOooool001cooooo00?o0000ooooooooool0D?ooool2
o`0000?ooooo0_l0000Eooooo`?o00007oooool2o`0000?ooooo0_l00007ooooo`Co000000?ooooo
o`000?l000001?ooool=o`0000?ooooo0_l00004ooooo`;o00000_ooool2o`0000[ooooo0_l00000
0ooooooo0000o`000007ooooo`;o000000?oooooo`000?l000001_ooool3o`0006;ooooo000Loooo
o`03o`000?oooooooooo05Gooooo1?l00008ooooo`;o00001Oooool2o`0000;ooooo0_l00002oooo
o`;o00006oooool4o`0000;ooooo0_l00009ooooo`;o000000?oooooo`000?l000000ol000001?oo
oooo0000o`000?ooool2o`0000;ooooo0ol000000ooooooo0000o`000003ooooo`;o00000_ooool5
o`0000Wooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00001oooool2o`000003ooooool0
003o000000Kooooo0_l00006ooooo`;o0000Foooool001cooooo00?o0000ooooooooool0C_ooool2
o`0000Oooooo0_l00005ooooo`;o000000?oooooo`000?l000000_l00002ooooo`?o00000_ooool2
o`0000;ooooo0_l00003ooooo`;o00005_ooool4o`0000gooooo0_l00002ooooo`Ko00000_ooool2
o`0000?ooooo0_l0000:ooooo`Go00002Oooool2o`000003ooooool0003o000001Cooooo0_l00008
ooooo`;o0000Foooool001cooooo00?o0000ooooooooool0C_ooool2o`0000Sooooo0_l00004oooo
o`;o00000oooool2o`0000;ooooo0_l0000<ooooo`;o00007Oooool2o`00013ooooo0_l00002oooo
o`?o00003_ooool4o`0000Kooooo0_l00008ooooo`;o00001oooool2o`0000Sooooo0_l0001Uoooo
o`007?ooool00ol0003oooooooooo`1Gooooo`?o00003?ooool2o`0000gooooo0_l0000Mooooo`;o
00002?ooool2o`0000_ooooo0_l0000>ooooo`Co00000oooool2o`000003ooooool0003o000000;o
oooo0_l00004ooooo`;o00001?ooool2o`000003ooooool0003o000006oooooo000Looooo`03o`00
0?oooooooooo05Oooooo0_l0000=ooooo`;o00000_ooool2o`0000Wooooo0_l0000Looooo`;o0000
2Oooool2o`0001;ooooo0_l00005ooooo`;o00000_ooool2o`0000?ooooo0_l00005ooooo`;o0000
0oooool2o`0000Gooooo0_l00003ooooo`Co00001oooool2o`0006;ooooo000Looooo`03o`000?oo
oooooooo05Cooooo0_l0000Cooooo`?o00001_ooool3o`0001kooooo1?l0000Kooooo`;o00001Ooo
ool2o`0000Oooooo0_l0000:ooooo`?o00001Oooool2o`0000;ooooo1?l00007ooooo`;o0000H_oo
ool001cooooo00?o0000ooooooooool0@?ooool2o`0001;ooooo0ol00002ooooo`;o00003_ooool2
o`0000Oooooo0ol0000Looooo`;o000000?oooooo`000?l000000_l0000Looooo`;o00002_ooool2
o`0000gooooo0_l00005ooooo`;o00000oooool2o`0006cooooo000Looooo`03o`000?oooooooooo
043ooooo0_l0000Cooooo`;o00000_ooool2o`0000[ooooo0_l0000Zooooo`Oo00007?ooool2o`00
00[ooooo0_l0000Hooooo`?o00002?ooool2o`0006;ooooo000Looooo`;o0000E_ooool2o`0000Wo
oooo0_l00003ooooo`;o000000?oooooo`000?l00000:?ooool2o`000004ooooool0003o0000o`00
00Cooooo0_l0000<ooooo`Co00003?ooool2o`0001Kooooo0_l00006ooooo`;o00001?ooool2o`00
00?ooooo0_l0001Rooooo`007?ooool00ol0003oooooooooo`1Eooooo`;o00002Oooool2o`0000Ko
oooo0_l0000Qooooo`;o00002?ooool3o`0000Cooooo0_l0000<ooooo`Co00003?ooool2o`0001Ko
oooo0ol0000;ooooo`;o0000Ioooool001cooooo00?o0000ooooooooool0@oooool2o`0002Kooooo
0_l0000Nooooo`?o00002?ooool2o`0000Cooooo0_l0000^ooooo`Go00000_ooool2o`0007Cooooo
000Looooo`03o`000?oooooooooo04?ooooo0_l0000Jooooo`;o00001?ooool2o`0000Cooooo1?l0
000Mooooo`;o00001_ooool5o`0000Oooooo0_l00003ooooo`;o00005_ooool3o`0000cooooo1Ol0
0002ooooo`;o000000?oooooo`000?l00000LOooool001cooooo00?o0000ooooooooool0Goooool2
o`0000Cooooo0_l00006ooooo`;o00009Oooool5o`0000Oooooo0_l00003ooooo`;o00001?ooool5
o`0000cooooo1?l00005ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o00000_ooool2
o`000003ooooool0003o000000;ooooo0_l0001]ooooo`007?ooool00ol0003oooooooooo`1Qoooo
o`;o00001?ooool2o`0002_ooooo0ol0000Dooooo`Ko00001?ooool2o`0000Gooooo0_l00002oooo
o`;o00000oooool7o`000003ooooool0003o000000;o00001oooool4o`0006gooooo000Looooo`03
o`000?oooooooooo067ooooo0_l00002ooooo`Co0000:?ooool2o`000004ooooool0003o0000o`00
00Sooooo1?l0000<ooooo`;o00001?ooool2o`0000Cooooo0ol00002ooooo`;o00001?ooool5o`00
00;ooooo0ol00008ooooo`;o000000?oooooo`000?l00000K?ooool001cooooo00?o0000oooooooo
ool0IOooool2o`0002;ooooo0_l00006ooooo`?o00001_ooool2o`0000?ooooo1?l0000<ooooo`Ko
00001_ooool2o`0001kooooo0_l0001/ooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o0000
2_ooool2o`000003ooooool0003o000001_ooooo0_l00006ooooo`?o00001?ooool5o`0000Oooooo
0ol00008ooooo`Ko00006?ooool2o`0007[ooooo000Looooo`03o`000?oooooooooo05gooooo0_l0
0007ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Zooooo`;o000000Coooooo`000?l0003o
oooo0_l00004ooooo`?o00001?ooool2o`0001;ooooo0_l00003ooooo`;o00001_ooool3o`0000[o
oooo0_l0001^ooooo`007?ooool00ol0003oooooooooo`1Vooooo`;o00000_ooool2o`0000;ooooo
0_l0000[ooooo`Go00001oooool2o`0000;ooooo0_l00007ooooo`;o00001?ooool2o`0000?ooooo
0_l00003ooooo`;o00001_ooool3o`0000Gooooo0ol00002ooooo`;o00001?ooool4o`0006Kooooo
000Looooo`03o`000?oooooooooo06[ooooo0_l00002ooooo`;o00001oooool2o`0000Kooooo0_l0
00000ooooooo0000o`00000;ooooo`?o00002Oooool4o`0000Sooooo0_l0000;ooooo`;o00000ooo
ool5o`0000;ooooo0_l00003ooooo`;o00003Oooool3o`0000Sooooo1?l0001Vooooo`007?ooool0
0ol0003oooooooooo`1gooooo`;o00001_ooool2o`000003ooooool0003o000000;ooooo0_l00007
ooooo`?o00001_ooool2o`0000Cooooo0_l0000;ooooo`;o00003?ooool5o`0000;ooooo1?l00000
0ooooooo0000o`000002ooooo`;o0000O_ooool001cooooo00?o0000ooooooooool0JOooool2o`00
00cooooo0_l0000=ooooo`;o00001_ooool2o`0000Sooooo0_l00004ooooo`;o000000?oooooo`00
0?l000002?ooool2o`000003ooooool0003o000000_ooooo0_l00005ooooo`;o000000?oooooo`00
0?l000000_ooool2o`0007kooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44
ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Yooooo`;o000000?o
ooooo`000?l000008?ooool2o`0000Sooooo0_l00006ooooo`?o00000oooool2o`0000Kooooo0_l0
00000ooooooo0000o`000002o`00027ooooo0_l0001aooooo`0000KoooooogMgMonHV9SooooooiRH
V?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000oooooooo
ool0Coooool2o`0001_ooooo0ol00007ooooo`Co00001?ooool2o`0001Cooooo1_l000000ooooooo
0000o`000003ooooo`;o00001?ooool2o`0000Wooooo2?l0000Eooooo`;o00001_ooool2o`00077o
oooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo04oooooo0_l0000Fooooo`;o00001?ooool2o`0000Oo
oooo1?l00004ooooo`;o00003Oooool2o`0000?ooooo1_l00003ooooo`;o00005Oooool2o`000003
ooooool0003o000000;o00000_ooool4o`0000Gooooo0_l00008ooooo`;o0000NOooool00003oooo
ool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Olb<S;oV9RHoooooonHV9So<S8b00Ko
oooo0ol0001Wooooo`;o00001oooool2o`0001Sooooo1Ol00003ooooo`Co00000oooool5o`0000;o
oooo0_l0000Iooooo`Ko00000oooool2o`0008?ooooo00000ooooooo0000ooooo`02ooooo`03o`00
0?oooooooooo00Wooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo073o
oooo0_l0000Hooooo`?o00003?ooool5o`0000;ooooo0_l0000?ooooo`;o000000?oooooo`000?l0
00000oooool4o`0000;ooooo0_l00006ooooo`;o0000P?ooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000oooooooo
ool0/Oooool2o`000003ooooool0003o000000?ooooo1?l00008ooooo`Co0000P?ooool00006oooo
oomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000
ooooooooool0Yoooool2o`0000Sooooo0_l0000Booooo`;o0000P_ooool00006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0
N?ooool4o`0000Wooooo0_l0000Pooooo`;o00000_ooool4o`0000;ooooo0_l0000Qooooo`;o0000
Loooool001cooooo00?o0000ooooooooool0N?ooool4o`0000Wooooo0_l0000<ooooo`;o00005_oo
ool6o`0002?ooooo0_l0001cooooo`007?ooool00ol0003oooooooooo`1nooooo`;o00004oooool2
o`0000Sooooo0_l0000@ooooo`;o0000V?ooool001cooooo00?o0000ooooooooool0FOooool2o`00
02?ooooo0_l00004ooooo`?o00005_ooool2o`000:[ooooo000Looooo`03o`000?oooooooooo05Wo
oooo0_l0000Yooooo`Go00003Oooool2o`0000?ooooo0_l0002/ooooo`007?ooool00ol0003ooooo
ooooo`27ooooo`;o00002Oooool2o`0000;ooooo0_l00003ooooo`;o00008?ooool2o`0008[ooooo
000Looooo`03o`000?oooooooooo08gooooo0_l00003ooooo`?o0000:?ooool2o`0008[ooooo000L
ooooo`03o`000?oooooooooo08gooooo0_l00004ooooo`;o00004oooool2o`0000?ooooo0_l0002J
ooooo`007?ooool00ol0003oooooooooo`2?ooooo`;o00000oooool2o`0000Gooooo0_l0000;oooo
o`;o00000oooool2o`0009[ooooo000Looooo`03o`000?oooooooooo08[ooooo0_l00003ooooo`;o
00000oooool2o`0000Gooooo0_l000000ooooooo0000o`000002ooooo`;o0000YOooool001cooooo
00?o0000ooooooooool0HOooool2o`0002Oooooo0_l0000Booooo`;o00000_ooool2o`000:Gooooo
000Looooo`03o`000?oooooooooo067ooooo0_l0003Vooooo`007?ooool2o`000?ooooooBoooool0
01cooooo00?o0000ooooooooool0U_ooool2o`000;7ooooo000Looooo`03o`000?oooooooooo09?o
oooo0_l000000ooooooo0000o`00002aooooo`007?ooool00ol0003oooooooooo`2Cooooo`;o0000
0_ooool2o`000;3ooooo000Looooo`03o`000?oooooooooo06[ooooo0_l0000[ooooo`;o00002?oo
ool2o`000:Kooooo000Looooo`03o`000?oooooooooo06[ooooo0_l0000eooooo`;o0000Y_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`1_ooooo`;o
0000f?ooool001cooooo00?o0000ooooooooool0Koooool4o`000=Kooooo000Looooo`03o`000?oo
oooooooo077ooooo0_l00003ooooo`;o0000dOooool001cooooo00?o0000ooooooooool0M_ooool2
o`000=7ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo07kooooo0_l00039ooooo`007?ooool00ol0003oooooooooo`1nooooo`;o0000bOooool0
01cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Booooo`Co000000?o410@oooo
ooooool00oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`?o0000
oooooom:ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooo
oooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003o
ooooooooo`3ooooooe;ooooo000Booooo`03oeEEEOmVIVKo00000?ooooooE?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00:Gooooo00Co410@o`000?l0003ooooo0_l000000ol@
413oooooooooo`0Fooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<00?ooooo1Ol0002@ooooo`00Y_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l0
000=ooooo`09ogMgMolb<S;ooooooooooolQ8B7oV9RHoooooonHV9So8B4Q00?ooooo00GoV9RHob4Q
8Oo^k^koooooodA4A02@ooooo`00Y_ooool01Ol0003ooooooooooooooooo000001gooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`03oiRHV?lQ8B7ok^k^097ooooo002V
ooooo`05o`000?ooooooooooooooool000002Oooool6o`0000gooooo00WoMgMgoc8b<_oooooooooo
oc8b<_nHV9SooooooiRHV?lb<S801Oooool00onHV9So8B4Qonk^kP2@ooooo`00Y_ooool01Ol0003o
QhN7oooooonYZJWo000001Wooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05olc<c?l0003o
0000o`000?o<c<`01_ooool00omgMgOoIVIVooooo`2?ooooo`00YOooool00ol@413o0000ogMgM`02
o`000003oiRHV?oooooooooo01Oooooo00?o0000ooooooooool01?ooool01Ol@413o^[Zjoooooonj
^[[o410@00Oooooo00?o0000ooooooooool0S_ooool00<Cooooo00?o0000ooooooooool01?ooool0
1Ol0003o^[Zjoooooonj^[[o000000?ooooo00Go0000okZj^_ooooooV9RHoa0@402@ooooo`00a?oo
ool4o`0000?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`0T?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(588) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.47925 .64809 Mdot
.52417 .69264 Mdot
.55727 .31826 Mdot
.37182 .53945 Mdot
.45375 .26313 Mdot
.56554 .356 Mdot
.69535 .4664 Mdot
.64909 .4773 Mdot
.57357 .3636 Mdot
.27107 .67086 Mdot
.66244 .48138 Mdot
.45295 .51478 Mdot
.67815 .46589 Mdot
.37558 .50804 Mdot
.62279 .60123 Mdot
.42629 .58504 Mdot
.50611 .71556 Mdot
.47311 .3163 Mdot
.4288 .58416 Mdot
.56425 .3219 Mdot
.45648 .44946 Mdot
.38571 .51477 Mdot
.51045 .712 Mdot
.37929 .50993 Mdot
.36887 .55876 Mdot
.51213 .69259 Mdot
.48973 .64601 Mdot
.40526 .55494 Mdot
.42036 .53623 Mdot
.65919 .47079 Mdot
.50374 .2092 Mdot
.64138 .80979 Mdot
.4416 .52141 Mdot
.42637 .69879 Mdot
.64952 .48464 Mdot
.76701 .35818 Mdot
.58247 .37852 Mdot
.65075 .46305 Mdot
.66829 .49947 Mdot
.67127 .50211 Mdot
.69442 .45655 Mdot
.51513 .68422 Mdot
.71695 .47862 Mdot
.51174 .36419 Mdot
.33842 .51344 Mdot
.60697 .77555 Mdot
.51885 .18616 Mdot
.40789 .55084 Mdot
.4712 .66652 Mdot
.55707 .32722 Mdot
.21566 .43055 Mdot
.65854 .44565 Mdot
.624 .64989 Mdot
.16716 .68955 Mdot
.66482 .47237 Mdot
.38886 .54401 Mdot
.57196 .33724 Mdot
.3692 .52813 Mdot
.40714 .53176 Mdot
.41199 .65426 Mdot
.40753 .51339 Mdot
.43862 .29476 Mdot
.5013 .64118 Mdot
.59479 .33606 Mdot
.57315 .35784 Mdot
.67393 .44843 Mdot
.53593 .67903 Mdot
.67957 .45734 Mdot
.36622 .4606 Mdot
.54882 .32463 Mdot
.40528 .548 Mdot
.65804 .47799 Mdot
.53034 .69625 Mdot
.3357 .53895 Mdot
.63943 .72913 Mdot
.64269 .42374 Mdot
.48688 .33112 Mdot
.41826 .7677 Mdot
.17817 .53301 Mdot
.62926 .30826 Mdot
.37578 .49734 Mdot
.15211 .4958 Mdot
.62943 .58943 Mdot
.52829 .68015 Mdot
.44504 .67466 Mdot
.8039 .54515 Mdot
.42086 .5433 Mdot
.44219 .39763 Mdot
.42307 .56287 Mdot
.5362 .55872 Mdot
.57868 .36381 Mdot
.50875 .70253 Mdot
.33745 .51374 Mdot
.38878 .57125 Mdot
.27223 .59743 Mdot
.3998 .47376 Mdot
.34652 .52495 Mdot
.45102 .66514 Mdot
.68096 .48622 Mdot
.36184 .44809 Mdot
.50183 .29857 Mdot
.65084 .6663 Mdot
.35989 .54192 Mdot
.54729 .36281 Mdot
.47406 .64185 Mdot
.34 .52541 Mdot
.6659 .45507 Mdot
.38866 .50502 Mdot
.63361 .46111 Mdot
.4904 .70592 Mdot
.40034 .56961 Mdot
.44713 .27936 Mdot
.57307 .61112 Mdot
.48032 .66805 Mdot
.3164 .75577 Mdot
.4048 .51392 Mdot
.39785 .52344 Mdot
.5257 .68191 Mdot
.58714 .34172 Mdot
.48699 .42783 Mdot
.51901 .71052 Mdot
.67307 .50059 Mdot
.47649 .69565 Mdot
.38982 .57703 Mdot
.58509 .33684 Mdot
.6517 .67715 Mdot
.65138 .66108 Mdot
.38705 .249 Mdot
.33839 .54621 Mdot
.59694 .64859 Mdot
.55177 .35195 Mdot
.51981 .68546 Mdot
.67408 .45874 Mdot
.41903 .50669 Mdot
.49766 .66 Mdot
.67439 .49733 Mdot
.41886 .30427 Mdot
.44595 .25864 Mdot
.4935 .65287 Mdot
.27758 .46445 Mdot
.64681 .44956 Mdot
.68154 .50193 Mdot
.22515 .42139 Mdot
.52621 .67376 Mdot
.44037 .31868 Mdot
.69884 .49065 Mdot
.33219 .34984 Mdot
.40339 .49185 Mdot
.28682 .32244 Mdot
.15789 .42914 Mdot
.21973 .42633 Mdot
.52277 .79944 Mdot
.46103 .29459 Mdot
.70287 .48852 Mdot
.38429 .55123 Mdot
.50219 .66958 Mdot
.50924 .6687 Mdot
.36821 .57004 Mdot
.37359 .56516 Mdot
.35587 .50348 Mdot
.41717 .50865 Mdot
.69021 .25409 Mdot
.36081 .49692 Mdot
.63713 .5456 Mdot
.4909 .66252 Mdot
.35558 .55729 Mdot
.54907 .37407 Mdot
.32165 .52435 Mdot
.65091 .4644 Mdot
.40109 .53495 Mdot
.37702 .56325 Mdot
.34972 .48204 Mdot
.71074 .48486 Mdot
.72082 .69289 Mdot
.19344 .60012 Mdot
.77595 .42963 Mdot
.58427 .71633 Mdot
.55579 .34312 Mdot
.3816 .48995 Mdot
.4577 .30913 Mdot
.43289 .45922 Mdot
.407 .52626 Mdot
.20531 .44211 Mdot
.39826 .56377 Mdot
.46553 .78682 Mdot
.31475 .4616 Mdot
.81726 .5187 Mdot
.67358 .56003 Mdot
.41363 .51719 Mdot
.24405 .6132 Mdot
.30981 .29215 Mdot
.45356 .2054 Mdot
.66541 .46307 Mdot
.55375 .3818 Mdot
.58929 .35768 Mdot
.67708 .50486 Mdot
.31656 .47032 Mdot
.28313 .6883 Mdot
.35253 .46252 Mdot
.64888 .67711 Mdot
.54301 .66121 Mdot
.46702 .30181 Mdot
.49159 .65236 Mdot
.14612 .53305 Mdot
.46206 .43051 Mdot
.62978 .39763 Mdot
.47662 .31127 Mdot
.5316 .33991 Mdot
.63457 .67808 Mdot
.45201 .3172 Mdot
.35649 .53027 Mdot
.47775 .69181 Mdot
.30637 .2938 Mdot
.37416 .58888 Mdot
.77549 .2808 Mdot
.53047 .67204 Mdot
.56113 .52303 Mdot
.66781 .46623 Mdot
.59745 .35183 Mdot
.42002 .54445 Mdot
.36112 .51592 Mdot
.49587 .64158 Mdot
.4123 .54712 Mdot
.49634 .48797 Mdot
.38575 .56313 Mdot
.59903 .38519 Mdot
.42973 .33995 Mdot
.63363 .48714 Mdot
.38094 .25764 Mdot
.52722 .70436 Mdot
.59915 .50167 Mdot
.54716 .36736 Mdot
.47651 .61036 Mdot
.65572 .46857 Mdot
.42065 .29565 Mdot
.5705 .38298 Mdot
.42188 .28135 Mdot
.33148 .51681 Mdot
.58198 .37402 Mdot
.4274 .30218 Mdot
.61731 .42332 Mdot
.34604 .52634 Mdot
.29354 .34597 Mdot
.70371 .48043 Mdot
.4889 .64773 Mdot
.41055 .51631 Mdot
.6585 .67757 Mdot
.33919 .56099 Mdot
.59852 .62865 Mdot
.64731 .68516 Mdot
.61848 .66109 Mdot
.63721 .37726 Mdot
.44507 .32379 Mdot
.59724 .74625 Mdot
.50796 .44296 Mdot
.50833 .71569 Mdot
.3424 .49878 Mdot
.76616 .66765 Mdot
.70586 .47895 Mdot
.36041 .53156 Mdot
.80217 .5276 Mdot
.70063 .48916 Mdot
.37947 .52762 Mdot
.69865 .45845 Mdot
.50524 .66694 Mdot
.5792 .4574 Mdot
.47558 .70122 Mdot
.37497 .53822 Mdot
.69245 .47899 Mdot
.56184 .38595 Mdot
.51131 .69201 Mdot
.39294 .5093 Mdot
.3721 .49471 Mdot
.64254 .67696 Mdot
.35188 .55827 Mdot
.79445 .63437 Mdot
.40554 .55185 Mdot
.53151 .33759 Mdot
.40629 .4774 Mdot
.28756 .30445 Mdot
.43686 .25523 Mdot
.53933 .67697 Mdot
.6389 .68334 Mdot
.58212 .35736 Mdot
.59257 .43102 Mdot
.41154 .24698 Mdot
.38018 .50174 Mdot
.63945 .66197 Mdot
.56476 .51943 Mdot
.66713 .45043 Mdot
.43214 .52428 Mdot
.49247 .4567 Mdot
.57233 .37386 Mdot
.64219 .67913 Mdot
.30292 .51807 Mdot
.4672 .66149 Mdot
.38837 .54583 Mdot
.57753 .38314 Mdot
.46856 .66565 Mdot
.42207 .51005 Mdot
.61998 .22377 Mdot
.65759 .67327 Mdot
.70322 .47477 Mdot
.32225 .5937 Mdot
.35991 .49273 Mdot
.59103 .35976 Mdot
.50329 .66052 Mdot
.67312 .47902 Mdot
.48388 .69369 Mdot
.33396 .266 Mdot
.58541 .67743 Mdot
.69395 .29221 Mdot
.45754 .32805 Mdot
.49719 .83791 Mdot
.77621 .41017 Mdot
.5771 .6577 Mdot
.41794 .34927 Mdot
.81809 .43997 Mdot
.55895 .37854 Mdot
.24488 .52914 Mdot
.58058 .34678 Mdot
.37181 .54683 Mdot
.56792 .3577 Mdot
.81621 .60933 Mdot
.40132 .55964 Mdot
.55946 .33885 Mdot
.67338 .25833 Mdot
.40407 .56375 Mdot
.48848 .66078 Mdot
.6467 .78727 Mdot
.35411 .77847 Mdot
.33482 .4237 Mdot
.56069 .33582 Mdot
.23516 .54948 Mdot
.41318 .55183 Mdot
.40475 .59362 Mdot
.50311 .67627 Mdot
.41153 .57472 Mdot
.46165 .28811 Mdot
.43302 .27681 Mdot
.23005 .4362 Mdot
.39225 .80074 Mdot
.35216 .5946 Mdot
.51137 .68479 Mdot
.17543 .52061 Mdot
.64175 .73134 Mdot
.65556 .66295 Mdot
.65871 .49518 Mdot
.71874 .6909 Mdot
.30194 .53398 Mdot
.26925 .51019 Mdot
.51503 .5036 Mdot
.51115 .70425 Mdot
.73737 .36294 Mdot
.67989 .47782 Mdot
.2257 .61002 Mdot
.319 .6977 Mdot
.35169 .50621 Mdot
.69583 .44715 Mdot
.40325 .45848 Mdot
.50746 .50006 Mdot
.28782 .33929 Mdot
.6346 .28364 Mdot
.35856 .53441 Mdot
.60492 .7466 Mdot
.40314 .52782 Mdot
.30804 .30009 Mdot
.36965 .53532 Mdot
.48158 .68733 Mdot
.29446 .54391 Mdot
.50919 .41635 Mdot
.22964 .66193 Mdot
.46607 .43585 Mdot
.45775 .31904 Mdot
.37216 .50934 Mdot
.35371 .51237 Mdot
.43269 .2939 Mdot
.49994 .69777 Mdot
.35481 .48854 Mdot
.52545 .18339 Mdot
.3558 .49814 Mdot
.65828 .44748 Mdot
.56313 .44779 Mdot
.46618 .79693 Mdot
.41454 .56009 Mdot
.46923 .655 Mdot
.67502 .45112 Mdot
.65949 .49075 Mdot
.32832 .58028 Mdot
.70721 .47518 Mdot
.3931 .55073 Mdot
.56473 .45042 Mdot
.50513 .71213 Mdot
.42671 .46183 Mdot
.49536 .69428 Mdot
.18295 .46703 Mdot
.71273 .47774 Mdot
.63071 .6584 Mdot
.244 .5163 Mdot
.69004 .47076 Mdot
.47355 .57069 Mdot
.29255 .50756 Mdot
.31692 .50362 Mdot
.57347 .6733 Mdot
.57803 .38988 Mdot
.62418 .66385 Mdot
.66604 .47577 Mdot
.35753 .49832 Mdot
.34338 .53253 Mdot
.67853 .44241 Mdot
.3576 .63242 Mdot
.50972 .21096 Mdot
.38031 .53798 Mdot
.48622 .6929 Mdot
.51851 .68569 Mdot
.38916 .48218 Mdot
.4072 .52314 Mdot
.53181 .35328 Mdot
.63819 .66085 Mdot
.62343 .67145 Mdot
.64489 .65766 Mdot
.57679 .39705 Mdot
.46884 .83795 Mdot
.6822 .50178 Mdot
.55258 .81408 Mdot
.77565 .59367 Mdot
.35123 .59016 Mdot
.5877 .37574 Mdot
.37168 .52127 Mdot
.35372 .5419 Mdot
.68898 .48161 Mdot
.37158 .80524 Mdot
.43944 .49954 Mdot
.50162 .64848 Mdot
.66581 .44414 Mdot
.44906 .48718 Mdot
.65805 .42405 Mdot
.43963 .28256 Mdot
.43725 .42414 Mdot
.69514 .44592 Mdot
.48383 .69771 Mdot
.68863 .44315 Mdot
.35372 .50935 Mdot
.31096 .50542 Mdot
.5152 .70488 Mdot
.43038 .32476 Mdot
.33453 .51329 Mdot
.38238 .52825 Mdot
.33115 .23266 Mdot
.63511 .73114 Mdot
.61805 .3384 Mdot
.36556 .55217 Mdot
.33811 .48149 Mdot
.42234 .32354 Mdot
.35817 .49076 Mdot
.42167 .53165 Mdot
.57069 .60368 Mdot
.63544 .48683 Mdot
.47311 .28702 Mdot
.2214 .61978 Mdot
.52616 .66425 Mdot
.80226 .61155 Mdot
.65295 .66912 Mdot
.62949 .47268 Mdot
.58103 .46223 Mdot
.62817 .66797 Mdot
.78887 .53259 Mdot
.77413 .44777 Mdot
.631 .66094 Mdot
.57983 .31615 Mdot
.40169 .43499 Mdot
.42511 .52113 Mdot
.39458 .5339 Mdot
.43953 .32301 Mdot
.51822 .66409 Mdot
.64725 .55458 Mdot
.64601 .50575 Mdot
.39094 .51814 Mdot
.49059 .72158 Mdot
.81063 .53129 Mdot
.63578 .6769 Mdot
.45965 .30117 Mdot
.45347 .32516 Mdot
.40068 .52703 Mdot
.52977 .59615 Mdot
.51282 .68771 Mdot
.39286 .50939 Mdot
.40318 .49598 Mdot
.57844 .33557 Mdot
.47526 .68348 Mdot
.54317 .36423 Mdot
.64816 .68648 Mdot
.80923 .37416 Mdot
.3535 .21125 Mdot
.69366 .48826 Mdot
.76292 .39636 Mdot
.70593 .44451 Mdot
.64896 .29948 Mdot
.63557 .6597 Mdot
.39074 .51229 Mdot
.53203 .70292 Mdot
.39085 .50619 Mdot
.34752 .5026 Mdot
.34274 .51441 Mdot
.36071 .59763 Mdot
.20782 .43335 Mdot
.45279 .30133 Mdot
.38614 .46413 Mdot
.52977 .3585 Mdot
.81318 .51958 Mdot
.67871 .75332 Mdot
.36475 .50968 Mdot
.3954 .52412 Mdot
.53097 .66578 Mdot
.32974 .52229 Mdot
.66047 .45764 Mdot
.52863 .67326 Mdot
.35374 .53766 Mdot
.466 .25702 Mdot
.36587 .4844 Mdot
.76575 .38883 Mdot
.68995 .44324 Mdot
.42838 .42341 Mdot
.32806 .48304 Mdot
.63262 .65905 Mdot
.62483 .66369 Mdot
.6606 .67974 Mdot
.68118 .44545 Mdot
.5805 .3382 Mdot
.52213 .32616 Mdot
.3032 .50866 Mdot
.38684 .55259 Mdot
.31755 .49748 Mdot
.56754 .40055 Mdot
.50415 .42916 Mdot
.55423 .77182 Mdot
.30906 .46612 Mdot
.55231 .38716 Mdot
.46643 .70928 Mdot
.25686 .70876 Mdot
.52155 .66282 Mdot
.46847 .33973 Mdot
.65264 .4704 Mdot
.4552 .28374 Mdot
.20445 .48107 Mdot
.5068 .71023 Mdot
.49821 .64309 Mdot
.55664 .34077 Mdot
.5898 .54995 Mdot
.26704 .8092 Mdot
.54862 .35893 Mdot
.41543 .34175 Mdot
.50564 .68074 Mdot
.44287 .51217 Mdot
.56783 .5197 Mdot
.57574 .55248 Mdot
.56854 .34288 Mdot
.37534 .49547 Mdot
.48003 .57069 Mdot
.5319 .35223 Mdot
.43268 .51583 Mdot
.55701 .33529 Mdot
.70771 .46902 Mdot
.54936 .34859 Mdot
.52593 .72193 Mdot
.33335 .52236 Mdot
.18962 .72349 Mdot
.62591 .58212 Mdot
.40035 .50753 Mdot
.66628 .44303 Mdot
.6501 .22589 Mdot
.34939 .51569 Mdot
.46767 .29369 Mdot
.55167 .38913 Mdot
.61881 .25033 Mdot
.41762 .53712 Mdot
.56854 .35019 Mdot
.54305 .70846 Mdot
.50867 .3192 Mdot
.60241 .30363 Mdot
.6227 .66791 Mdot
.50204 .66517 Mdot
.60735 .66754 Mdot
.64962 .48681 Mdot
.33798 .49604 Mdot
.38785 .48806 Mdot
.48401 .67123 Mdot
.67566 .41802 Mdot
.41954 .48255 Mdot
.37558 .49756 Mdot
.53378 .35218 Mdot
.53389 .37663 Mdot
.65381 .61675 Mdot
.55488 .37763 Mdot
.34145 .47924 Mdot
.48212 .67346 Mdot
.37655 .54493 Mdot
.49401 .65689 Mdot
.34023 .50181 Mdot
.55274 .74641 Mdot
.5199 .66262 Mdot
.54495 .63104 Mdot
.35473 .56262 Mdot
.4019 .61396 Mdot
.34962 .498 Mdot
.35109 .52807 Mdot
.55644 .39418 Mdot
.44247 .30834 Mdot
.43564 .538 Mdot
.59585 .48067 Mdot
.41307 .31001 Mdot
.46057 .74869 Mdot
.58682 .34218 Mdot
.42161 .31684 Mdot
.29208 .38421 Mdot
.63856 .68314 Mdot
.44474 .2955 Mdot
.68073 .65184 Mdot
.69427 .48649 Mdot
.49245 .71293 Mdot
.39544 .56666 Mdot
.82346 .42808 Mdot
.50389 .20967 Mdot
.63988 .67403 Mdot
.40904 .51731 Mdot
.36687 .52243 Mdot
.46655 .67149 Mdot
.1496 .51592 Mdot
.60195 .36752 Mdot
.35751 .5361 Mdot
.51795 .70946 Mdot
.15858 .46066 Mdot
.55041 .33647 Mdot
.45086 .29356 Mdot
.70853 .45135 Mdot
.55182 .6669 Mdot
.62185 .66313 Mdot
.71341 .47714 Mdot
.6141 .37811 Mdot
.19435 .45689 Mdot
.41641 .53767 Mdot
.57724 .38789 Mdot
.2187 .42725 Mdot
.33003 .45404 Mdot
.72438 .45829 Mdot
.5459 .74463 Mdot
.51176 .70299 Mdot
.67475 .44265 Mdot
.45894 .31948 Mdot
.49987 .71308 Mdot
.49964 .69874 Mdot
.64981 .47857 Mdot
.69934 .54345 Mdot
.56416 .52605 Mdot
.65443 .45613 Mdot
.56765 .57585 Mdot
.23038 .41604 Mdot
.64188 .66011 Mdot
.46025 .30138 Mdot
.3384 .25432 Mdot
.51481 .68741 Mdot
.71951 .69083 Mdot
.20906 .43791 Mdot
.34691 .52536 Mdot
.42864 .31207 Mdot
.79512 .55313 Mdot
.63923 .50369 Mdot
.67848 .49679 Mdot
.4655 .40628 Mdot
.46894 .30725 Mdot
.39149 .48614 Mdot
.45547 .7967 Mdot
.39083 .56903 Mdot
.70478 .485 Mdot
.50716 .5113 Mdot
.47525 .67992 Mdot
.64982 .48894 Mdot
.49219 .47761 Mdot
.35596 .54384 Mdot
.40555 .5054 Mdot
.34919 .28008 Mdot
.47396 .68321 Mdot
.62117 .66119 Mdot
.38459 .50003 Mdot
.37229 .52938 Mdot
.34783 .4864 Mdot
.24433 .50279 Mdot
.5579 .62019 Mdot
.35271 .5344 Mdot
.59683 .37386 Mdot
.3164 .51217 Mdot
.4162 .51809 Mdot
.4681 .69031 Mdot
.26714 .32254 Mdot
.65072 .68678 Mdot
.39025 .53411 Mdot
.38097 .53768 Mdot
.6642 .4997 Mdot
.56481 .52301 Mdot
.57519 .55564 Mdot
.53852 .33378 Mdot
.40716 .35671 Mdot
.34037 .46725 Mdot
.49487 .66465 Mdot
.45816 .2829 Mdot
.34141 .48456 Mdot
.51877 .65824 Mdot
.31595 .47835 Mdot
.52954 .35001 Mdot
.63736 .66291 Mdot
.2765 .52192 Mdot
.43996 .29808 Mdot
.63861 .45782 Mdot
.58357 .81346 Mdot
.54566 .37327 Mdot
.38051 .55704 Mdot
.51687 .36205 Mdot
.55894 .36961 Mdot
.64413 .67552 Mdot
.33329 .56468 Mdot
.50904 .67185 Mdot
.4779 .68655 Mdot
.2528 .38015 Mdot
.58946 .39494 Mdot
.22943 .31402 Mdot
.70807 .47009 Mdot
.43034 .52878 Mdot
.67725 .73916 Mdot
.47607 .67619 Mdot
.34174 .26857 Mdot
.42207 .31818 Mdot
.67858 .49661 Mdot
.62456 .67837 Mdot
.51441 .65681 Mdot
.47685 .6638 Mdot
.33918 .5113 Mdot
.37286 .51424 Mdot
.40605 .34104 Mdot
.2981 .30833 Mdot
.69874 .45903 Mdot
.452 .29041 Mdot
.54533 .32954 Mdot
.36378 .54802 Mdot
.52516 .69442 Mdot
.45076 .78665 Mdot
.36357 .4916 Mdot
.53062 .34794 Mdot
.51705 .69935 Mdot
.4404 .2883 Mdot
.42166 .30517 Mdot
.34818 .52558 Mdot
.43384 .74968 Mdot
.69126 .46806 Mdot
.48339 .66553 Mdot
.44822 .65086 Mdot
.40503 .47486 Mdot
.36904 .51086 Mdot
.44508 .49245 Mdot
.71103 .4892 Mdot
.27641 .51586 Mdot
.42919 .32969 Mdot
.51536 .66841 Mdot
.39437 .50454 Mdot
.43903 .29453 Mdot
.26273 .52891 Mdot
.63155 .6662 Mdot
.55269 .33729 Mdot
.46591 .29295 Mdot
.4332 .30888 Mdot
.41402 .30234 Mdot
.71246 .6954 Mdot
.47109 .64314 Mdot
.21208 .61531 Mdot
.34193 .50625 Mdot
.23481 .41186 Mdot
.33263 .54376 Mdot
.70192 .45736 Mdot
.55801 .38582 Mdot
.34936 .50331 Mdot
.33914 .50953 Mdot
.48337 .79102 Mdot
.46151 .54761 Mdot
.45195 .44981 Mdot
.4834 .70027 Mdot
.31903 .59632 Mdot
.59161 .36518 Mdot
.15107 .41891 Mdot
.71348 .75152 Mdot
.35711 .46262 Mdot
.58987 .54354 Mdot
.52876 .67546 Mdot
.68821 .49654 Mdot
.56421 .55045 Mdot
.62413 .47079 Mdot
.52007 .67268 Mdot
.36672 .54646 Mdot
.55762 .80948 Mdot
.41793 .28752 Mdot
.35702 .50421 Mdot
.67128 .45737 Mdot
.35647 .50384 Mdot
.68897 .44828 Mdot
.5323 .64133 Mdot
.58992 .5683 Mdot
.39999 .56282 Mdot
.39205 .46894 Mdot
.28421 .48899 Mdot
.36667 .51147 Mdot
.67325 .38115 Mdot
.50038 .69014 Mdot
.52695 .62161 Mdot
.38464 .47948 Mdot
.40819 .7352 Mdot
.37637 .48498 Mdot
.69911 .42242 Mdot
.39329 .49181 Mdot
.32555 .41724 Mdot
.397 .48833 Mdot
.38391 .49033 Mdot
.68311 .47942 Mdot
.67295 .49982 Mdot
.54559 .70137 Mdot
.62467 .65768 Mdot
.81645 .51852 Mdot
.38849 .52623 Mdot
.55288 .39398 Mdot
.66842 .65197 Mdot
.43755 .31009 Mdot
.51817 .67429 Mdot
.20515 .3009 Mdot
.68469 .45187 Mdot
.59346 .33301 Mdot
.64459 .35494 Mdot
.59202 .33856 Mdot
.59045 .40406 Mdot
.42504 .61267 Mdot
.45715 .292 Mdot
.3858 .48543 Mdot
.43337 .72377 Mdot
.61827 .7419 Mdot
.42584 .50385 Mdot
.516 .33498 Mdot
.45852 .50377 Mdot
.23 .41174 Mdot
.41427 .28561 Mdot
.46484 .30093 Mdot
.67048 .47703 Mdot
.56888 .31998 Mdot
.35091 .45065 Mdot
.42053 .31537 Mdot
.55153 .38108 Mdot
.64322 .65331 Mdot
.3908 .2738 Mdot
.51377 .6831 Mdot
.3203 .43374 Mdot
.64051 .76248 Mdot
.69062 .45434 Mdot
.59282 .4731 Mdot
.45798 .66859 Mdot
.51824 .64 Mdot
.63281 .65531 Mdot
.53245 .36675 Mdot
.5066 .71675 Mdot
.33484 .51777 Mdot
.37211 .58835 Mdot
.40266 .52603 Mdot
.42854 .3187 Mdot
.40947 .50328 Mdot
.53544 .36842 Mdot
.69502 .46181 Mdot
.57787 .3668 Mdot
.69514 .4692 Mdot
.55119 .79717 Mdot
.41085 .52694 Mdot
.373 .51135 Mdot
.56817 .46464 Mdot
.48442 .6553 Mdot
.41385 .67328 Mdot
.53193 .36712 Mdot
.57583 .33913 Mdot
.37304 .54424 Mdot
.53787 .66729 Mdot
.48117 .30701 Mdot
.57712 .52107 Mdot
.39673 .49255 Mdot
.49953 .68922 Mdot
.38242 .54461 Mdot
.64538 .27422 Mdot
.60581 .58602 Mdot
.48118 .69043 Mdot
.23257 .66984 Mdot
.34754 .55578 Mdot
.46452 .51467 Mdot
.44051 .56938 Mdot
.3917 .37943 Mdot
.43628 .51944 Mdot
.53133 .67608 Mdot
.40433 .53426 Mdot
.49608 .66846 Mdot
.55755 .37303 Mdot
.69035 .49924 Mdot
.49957 .67077 Mdot
.37932 .57005 Mdot
.68983 .76932 Mdot
.6821 .45373 Mdot
.36833 .50146 Mdot
.66478 .48043 Mdot
.4886 .71396 Mdot
.47679 .65628 Mdot
.6749 .63251 Mdot
.63185 .38716 Mdot
.67488 .45359 Mdot
.39086 .55223 Mdot
.67331 .71416 Mdot
.37752 .54523 Mdot
.39567 .33441 Mdot
.4008 .48392 Mdot
.4127 .48249 Mdot
.5119 .83913 Mdot
.62478 .42416 Mdot
.21515 .31461 Mdot
.69237 .5153 Mdot
.70621 .70322 Mdot
.47735 .62532 Mdot
.41473 .28493 Mdot
.75766 .39974 Mdot
.65137 .68414 Mdot
.59589 .37018 Mdot
.35 .50215 Mdot
.52098 .77775 Mdot
.65884 .44948 Mdot
.44711 .30959 Mdot
.3985 .56347 Mdot
.54086 .32024 Mdot
.68538 .6757 Mdot
.69991 .49093 Mdot
.51538 .68223 Mdot
.48917 .65208 Mdot
.18031 .55335 Mdot
.39815 .5076 Mdot
.38049 .51464 Mdot
.65168 .46634 Mdot
.3369 .45468 Mdot
.41945 .29106 Mdot
.67614 .27338 Mdot
.6672 .45954 Mdot
.61841 .59079 Mdot
.48671 .70379 Mdot
.36855 .5218 Mdot
.56127 .44594 Mdot
.73528 .63683 Mdot
.26713 .62981 Mdot
.44816 .32056 Mdot
.3678 .31494 Mdot
.53129 .67561 Mdot
.67182 .45953 Mdot
.24752 .41726 Mdot
.38392 .57371 Mdot
.36694 .52434 Mdot
.36153 .3024 Mdot
.5758 .52701 Mdot
.39672 .28436 Mdot
.4471 .53757 Mdot
.55582 .50113 Mdot
.37043 .54404 Mdot
.34364 .53297 Mdot
.36211 .46056 Mdot
.41938 .52059 Mdot
.49662 .68298 Mdot
.37202 .78074 Mdot
.56042 .35339 Mdot
.24516 .58258 Mdot
.45833 .39559 Mdot
.4165 .55041 Mdot
.36145 .54511 Mdot
.319 .74191 Mdot
.63458 .63863 Mdot
.50405 .68942 Mdot
.45013 .64516 Mdot
.67654 .50291 Mdot
.46066 .55064 Mdot
.58445 .39744 Mdot
.44791 .45263 Mdot
.56804 .36739 Mdot
.49833 .68891 Mdot
.58447 .34383 Mdot
.64788 .49758 Mdot
.57695 .38781 Mdot
.58208 .39577 Mdot
.7159 .47126 Mdot
.47084 .67796 Mdot
.37655 .48903 Mdot
.71206 .4749 Mdot
.35544 .26869 Mdot
.42769 .31806 Mdot
.67418 .63428 Mdot
.44268 .50953 Mdot
.46574 .51102 Mdot
.61826 .22336 Mdot
.58428 .36589 Mdot
.58734 .61141 Mdot
.5194 .66243 Mdot
.47046 .29131 Mdot
.4954 .67755 Mdot
.21631 .51171 Mdot
.43208 .30031 Mdot
.67552 .63708 Mdot
.25876 .40287 Mdot
.60946 .45063 Mdot
.33415 .55553 Mdot
.55819 .65355 Mdot
.56861 .36962 Mdot
.65881 .44669 Mdot
.80009 .53966 Mdot
.34066 .54557 Mdot
.59226 .6794 Mdot
.49288 .63188 Mdot
.63304 .68027 Mdot
.67592 .45863 Mdot
.7293 .49897 Mdot
.40115 .51141 Mdot
.60575 .44568 Mdot
.41456 .48841 Mdot
.24312 .52103 Mdot
.40395 .34904 Mdot
.55267 .7298 Mdot
.39047 .54657 Mdot
.53391 .3444 Mdot
.38542 .54625 Mdot
.33732 .43674 Mdot
.22495 .42712 Mdot
.3776 .46582 Mdot
.57877 .67067 Mdot
.6189 .24283 Mdot
.51941 .70078 Mdot
.34982 .47382 Mdot
.64407 .66717 Mdot
.35785 .5531 Mdot
.85547 .41686 Mdot
.44488 .29831 Mdot
.61592 .35482 Mdot
.36816 .56884 Mdot
.38705 .50266 Mdot
.45067 .76959 Mdot
.52176 .62535 Mdot
.63196 .68302 Mdot
.36136 .52531 Mdot
.37002 .3337 Mdot
.6758 .48045 Mdot
.42094 .50716 Mdot
.40091 .53305 Mdot
.37714 .21813 Mdot
.67471 .48209 Mdot
.58617 .3693 Mdot
.64243 .68433 Mdot
.54224 .33327 Mdot
.42659 .27481 Mdot
.54961 .55418 Mdot
.32714 .28084 Mdot
.60612 .58853 Mdot
.47185 .30306 Mdot
.42246 .54452 Mdot
.45027 .69115 Mdot
.3935 .49888 Mdot
.46465 .30646 Mdot
.65913 .47122 Mdot
.49872 .6817 Mdot
.29062 .45222 Mdot
.64862 .67625 Mdot
.42648 .50202 Mdot
.40854 .29615 Mdot
.50395 .6713 Mdot
.69622 .61085 Mdot
.52268 .67035 Mdot
.6894 .47376 Mdot
.66386 .50359 Mdot
.43624 .30393 Mdot
.49528 .68049 Mdot
.56038 .33089 Mdot
.70096 .51292 Mdot
.40528 .48483 Mdot
.66438 .51019 Mdot
.53912 .70502 Mdot
.49207 .64548 Mdot
.53683 .69602 Mdot
.41381 .52985 Mdot
.58024 .53412 Mdot
.35302 .56739 Mdot
.66922 .45253 Mdot
.59116 .34572 Mdot
.28131 .33188 Mdot
.42933 .72405 Mdot
.6186 .58857 Mdot
.4365 .53371 Mdot
.41079 .50947 Mdot
.40051 .52672 Mdot
.38966 .54172 Mdot
.67902 .27945 Mdot
.41033 .52765 Mdot
.69565 .47666 Mdot
.55898 .36386 Mdot
.40742 .51433 Mdot
.64253 .66463 Mdot
.50486 .43817 Mdot
.45922 .28392 Mdot
.35426 .40227 Mdot
.71637 .72922 Mdot
.5035 .67307 Mdot
.56831 .38546 Mdot
.58024 .33401 Mdot
.41887 .304 Mdot
.71047 .47885 Mdot
.51788 .66481 Mdot
.33989 .39316 Mdot
.41153 .30875 Mdot
.38889 .53412 Mdot
.5662 .45466 Mdot
.24265 .68685 Mdot
.41995 .5544 Mdot
.34559 .5187 Mdot
.61908 .66619 Mdot
.59655 .34358 Mdot
.85148 .47503 Mdot
.67812 .55223 Mdot
.44083 .30718 Mdot
.44092 .28537 Mdot
.53455 .69207 Mdot
.43077 .52139 Mdot
.69112 .46485 Mdot
.56108 .51047 Mdot
.61914 .2131 Mdot
.80633 .57829 Mdot
.64986 .30426 Mdot
.36359 .48515 Mdot
.38073 .76529 Mdot
.36491 .47696 Mdot
.47357 .64212 Mdot
.53812 .68234 Mdot
.50815 .68754 Mdot
.68157 .47852 Mdot
.18569 .47093 Mdot
.69749 .47623 Mdot
.71724 .73051 Mdot
.51842 .70682 Mdot
.54875 .42222 Mdot
.57034 .33624 Mdot
.31408 .54112 Mdot
.45847 .294 Mdot
.52202 .3068 Mdot
.34116 .47751 Mdot
.52629 .59904 Mdot
.58768 .37561 Mdot
.47429 .65577 Mdot
.29529 .50112 Mdot
.81957 .5047 Mdot
.59169 .55405 Mdot
.53895 .19213 Mdot
.29539 .59536 Mdot
.43266 .29471 Mdot
.25497 .64814 Mdot
.41723 .29164 Mdot
.68612 .49578 Mdot
.33988 .54599 Mdot
.35195 .56273 Mdot
.36143 .53635 Mdot
.4124 .53348 Mdot
.66513 .47581 Mdot
.37883 .47631 Mdot
.28572 .30688 Mdot
.65469 .66719 Mdot
.53597 .41263 Mdot
.42472 .29579 Mdot
.7049 .4567 Mdot
.55804 .36705 Mdot
.62803 .65545 Mdot
.37889 .25697 Mdot
.36884 .47913 Mdot
.34995 .49923 Mdot
.65132 .65992 Mdot
.3276 .46092 Mdot
.30272 .53418 Mdot
.5651 .35329 Mdot
.51247 .48323 Mdot
.45896 .32133 Mdot
.45334 .28317 Mdot
.68887 .44383 Mdot
.49519 .67771 Mdot
.43187 .32279 Mdot
.56228 .31839 Mdot
.42328 .5125 Mdot
.38979 .46772 Mdot
.53917 .70542 Mdot
.20907 .43756 Mdot
.44037 .27399 Mdot
.29533 .47831 Mdot
.50552 .65866 Mdot
.48473 .63198 Mdot
.35952 .52381 Mdot
.43197 .56505 Mdot
.48266 .64213 Mdot
.42764 .28864 Mdot
.7066 .45692 Mdot
.57288 .43316 Mdot
.70334 .46937 Mdot
.50729 .66355 Mdot
.31759 .53607 Mdot
.47572 .69133 Mdot
.34965 .556 Mdot
.10752 .48481 Mdot
.41478 .51153 Mdot
.47176 .60479 Mdot
.41063 .37481 Mdot
.55417 .33513 Mdot
.54766 .3355 Mdot
.6393 .66345 Mdot
.52197 .66152 Mdot
.3346 .49079 Mdot
.45239 .28664 Mdot
.70145 .70547 Mdot
.5255 .73702 Mdot
.56961 .39456 Mdot
.60018 .37306 Mdot
.66019 .47111 Mdot
.38608 .48643 Mdot
.3751 .52196 Mdot
.58045 .38555 Mdot
.65848 .23544 Mdot
.4909 .67238 Mdot
.38063 .51445 Mdot
.41758 .51993 Mdot
.55898 .3558 Mdot
.71051 .512 Mdot
.46375 .6351 Mdot
.41834 .51895 Mdot
.2696 .38642 Mdot
.68742 .44917 Mdot
.40046 .55381 Mdot
.37116 .47672 Mdot
.43811 .31423 Mdot
.44937 .25311 Mdot
.2279 .41881 Mdot
.71459 .48081 Mdot
.62152 .66635 Mdot
.33578 .54486 Mdot
.56534 .33739 Mdot
.44015 .50584 Mdot
.77975 .38833 Mdot
.65478 .67527 Mdot
.39753 .5153 Mdot
.33389 .47064 Mdot
.48817 .65813 Mdot
.39375 .51113 Mdot
.55106 .74448 Mdot
.53762 .34818 Mdot
.39859 .51537 Mdot
.43035 .74401 Mdot
.66057 .46858 Mdot
.33706 .4802 Mdot
.46005 .28855 Mdot
.41739 .37518 Mdot
.61081 .79418 Mdot
.55754 .39825 Mdot
.4228 .30475 Mdot
.40819 .50142 Mdot
.53268 .33842 Mdot
.70885 .45123 Mdot
.54547 .62191 Mdot
.42587 .53767 Mdot
.70294 .46562 Mdot
.69107 .45887 Mdot
.44027 .30342 Mdot
.18596 .34351 Mdot
.33537 .46924 Mdot
.36332 .50516 Mdot
.57772 .18034 Mdot
.46448 .68973 Mdot
.36378 .50061 Mdot
.38481 .48681 Mdot
.70306 .48078 Mdot
.24503 .4564 Mdot
.4755 .49005 Mdot
.67384 .25845 Mdot
.69113 .44944 Mdot
.55681 .30785 Mdot
.53867 .36015 Mdot
.42368 .30164 Mdot
.52071 .69674 Mdot
.46853 .31339 Mdot
.55309 .34678 Mdot
.35255 .52931 Mdot
.67193 .49279 Mdot
.31422 .63472 Mdot
.66148 .44344 Mdot
.53832 .32427 Mdot
.48662 .63675 Mdot
.65638 .76727 Mdot
.66373 .19541 Mdot
.62497 .76936 Mdot
.7159 .48223 Mdot
.43761 .31037 Mdot
.6558 .55176 Mdot
.40866 .50722 Mdot
.23367 .63511 Mdot
.35984 .50394 Mdot
.26142 .56948 Mdot
.55575 .38448 Mdot
.63906 .65423 Mdot
.33988 .54422 Mdot
.36935 .32145 Mdot
.71514 .47547 Mdot
.66062 .45902 Mdot
.39205 .53828 Mdot
.69082 .47234 Mdot
.38047 .51988 Mdot
.55559 .35973 Mdot
.19026 .34244 Mdot
.39161 .49324 Mdot
.32867 .49226 Mdot
.63243 .48231 Mdot
.67432 .63544 Mdot
.53525 .3157 Mdot
.39236 .76984 Mdot
.82508 .4984 Mdot
.68847 .46923 Mdot
.40075 .60131 Mdot
.58123 .37692 Mdot
.61829 .66129 Mdot
.60557 .38523 Mdot
.35747 .5116 Mdot
.35691 .48826 Mdot
.36755 .54101 Mdot
.41004 .51019 Mdot
.24383 .65013 Mdot
.30494 .53144 Mdot
.34133 .70859 Mdot
.3476 .50149 Mdot
.46313 .60505 Mdot
.6927 .48025 Mdot
.4643 .49905 Mdot
.40011 .27813 Mdot
.35881 .48549 Mdot
.51259 .62133 Mdot
.70697 .4611 Mdot
.72493 .70817 Mdot
.6683 .47949 Mdot
.58065 .35956 Mdot
.66577 .49739 Mdot
.35248 .55923 Mdot
.51777 .68772 Mdot
.54439 .35918 Mdot
.55741 .77172 Mdot
.59331 .37311 Mdot
.40039 .50776 Mdot
.63483 .50498 Mdot
.55939 .33342 Mdot
.4027 .39919 Mdot
.51944 .68827 Mdot
.35724 .32953 Mdot
.46206 .68149 Mdot
.38753 .50889 Mdot
.38031 .50496 Mdot
.62865 .65384 Mdot
.70156 .48985 Mdot
.51011 .71373 Mdot
.32604 .2377 Mdot
.4053 .30381 Mdot
.5078 .69654 Mdot
.41715 .58136 Mdot
.58971 .53823 Mdot
.47965 .67102 Mdot
.3855 .36219 Mdot
.70551 .48465 Mdot
.52884 .69867 Mdot
.36501 .57733 Mdot
.26484 .50214 Mdot
.43078 .27984 Mdot
.52839 .34774 Mdot
.557 .48377 Mdot
.53734 .35639 Mdot
.64327 .45796 Mdot
.59465 .39313 Mdot
.68315 .48192 Mdot
.57126 .7138 Mdot
.50232 .50485 Mdot
.64299 .46825 Mdot
.63936 .48953 Mdot
.5605 .34557 Mdot
.38686 .54021 Mdot
.5081 .41969 Mdot
.42302 .57326 Mdot
.31247 .51599 Mdot
.69483 .45325 Mdot
.53252 .68082 Mdot
.48677 .70617 Mdot
.48715 .61225 Mdot
.47813 .65851 Mdot
.54931 .36543 Mdot
.59886 .59063 Mdot
.23432 .54427 Mdot
.6571 .47318 Mdot
.62592 .40268 Mdot
.37686 .54661 Mdot
.56022 .34054 Mdot
.5553 .37386 Mdot
.69686 .46612 Mdot
.25095 .60693 Mdot
.3229 .49215 Mdot
.46629 .6843 Mdot
.51631 .70904 Mdot
.47939 .67668 Mdot
.53808 .67164 Mdot
.18188 .4957 Mdot
.65898 .4465 Mdot
.5296 .67292 Mdot
.40742 .53984 Mdot
.35731 .49303 Mdot
.63168 .67762 Mdot
.43109 .28803 Mdot
.3277 .53178 Mdot
.32217 .51678 Mdot
.36024 .52316 Mdot
.55614 .3351 Mdot
.40178 .44937 Mdot
.65336 .67698 Mdot
.59751 .38699 Mdot
.58121 .39765 Mdot
.62942 .65932 Mdot
.50697 .74318 Mdot
.83352 .53437 Mdot
.35898 .53667 Mdot
.43771 .633 Mdot
.56679 .33958 Mdot
.53485 .57372 Mdot
.28504 .53818 Mdot
.39406 .55102 Mdot
.51146 .3951 Mdot
.55168 .36069 Mdot
.53926 .65763 Mdot
.36203 .51043 Mdot
.64088 .65768 Mdot
.44934 .27975 Mdot
.40611 .57986 Mdot
.61869 .66567 Mdot
.4962 .68875 Mdot
.59042 .2324 Mdot
.47604 .7077 Mdot
.55826 .33254 Mdot
.34636 .47526 Mdot
.23415 .77858 Mdot
.56902 .37081 Mdot
.73923 .67061 Mdot
.49862 .49405 Mdot
.39939 .49782 Mdot
.54453 .36548 Mdot
.53044 .6481 Mdot
.6878 .44952 Mdot
.56613 .47234 Mdot
.52491 .6945 Mdot
.63007 .65503 Mdot
.62471 .66863 Mdot
.56067 .35435 Mdot
.49982 .70707 Mdot
.39312 .48008 Mdot
.50228 .65396 Mdot
.65583 .48541 Mdot
.37504 .56313 Mdot
.81701 .51782 Mdot
.37112 .58848 Mdot
.50799 .65792 Mdot
.56436 .31744 Mdot
.42714 .3247 Mdot
.40388 .56081 Mdot
.78648 .63388 Mdot
.39107 .48815 Mdot
.66175 .47759 Mdot
.51073 .55841 Mdot
.31214 .6408 Mdot
.37274 .53604 Mdot
.36782 .54564 Mdot
.70014 .4478 Mdot
.36647 .535 Mdot
.42517 .52583 Mdot
.73281 .4747 Mdot
.48089 .66449 Mdot
.39881 .52152 Mdot
.54066 .36824 Mdot
.39748 .62837 Mdot
.33509 .53495 Mdot
.56674 .74109 Mdot
.36197 .32117 Mdot
.50275 .53935 Mdot
.33878 .48599 Mdot
.35786 .2594 Mdot
.37601 .50529 Mdot
.41326 .54649 Mdot
.37409 .54044 Mdot
.37246 .76614 Mdot
.55601 .34504 Mdot
.54747 .38235 Mdot
.44744 .27792 Mdot
.36851 .32773 Mdot
.43151 .31492 Mdot
.70893 .45735 Mdot
.63885 .3893 Mdot
.65353 .66624 Mdot
.49522 .67449 Mdot
.33495 .5243 Mdot
.59271 .37947 Mdot
.36503 .51997 Mdot
.3611 .55407 Mdot
.5479 .35458 Mdot
.55427 .37027 Mdot
.57215 .40202 Mdot
.41272 .29683 Mdot
.50334 .68236 Mdot
.34227 .52142 Mdot
.41319 .31128 Mdot
.39412 .48331 Mdot
.59783 .53755 Mdot
.50415 .68538 Mdot
.50086 .65389 Mdot
.48115 .70556 Mdot
.34293 .50394 Mdot
.36689 .56522 Mdot
.69819 .47566 Mdot
.53642 .70975 Mdot
.65448 .46375 Mdot
.54323 .36353 Mdot
.54677 .33765 Mdot
.35701 .5113 Mdot
.29709 .47792 Mdot
.43248 .28974 Mdot
.5831 .36043 Mdot
.65744 .68237 Mdot
.4502 .27833 Mdot
.40979 .51848 Mdot
.53977 .3589 Mdot
.46041 .28637 Mdot
.27419 .60374 Mdot
.82007 .47443 Mdot
.41111 .31291 Mdot
.39326 .5382 Mdot
.44861 .76232 Mdot
.25434 .39853 Mdot
.40582 .30996 Mdot
.67201 .48525 Mdot
.37206 .48753 Mdot
.68041 .23753 Mdot
.45897 .32274 Mdot
.21095 .43665 Mdot
.54691 .34995 Mdot
.27702 .56583 Mdot
.40182 .58147 Mdot
.2262 .60141 Mdot
.46169 .32202 Mdot
.51435 .66519 Mdot
.52895 .7072 Mdot
.38497 .53489 Mdot
.40037 .29536 Mdot
.64735 .45397 Mdot
.58018 .3337 Mdot
.57969 .39478 Mdot
.49334 .70502 Mdot
.61236 .59056 Mdot
.54025 .3663 Mdot
.38415 .46339 Mdot
.60385 .33568 Mdot
.45638 .5596 Mdot
.18268 .54367 Mdot
.54657 .78975 Mdot
.35903 .4751 Mdot
.42416 .32446 Mdot
.71628 .46954 Mdot
.69568 .47309 Mdot
.6826 .47682 Mdot
.54112 .34007 Mdot
.56688 .53595 Mdot
.56959 .39181 Mdot
.60708 .69917 Mdot
.43994 .29373 Mdot
.34374 .34916 Mdot
.32763 .50909 Mdot
.39994 .49883 Mdot
.42498 .5145 Mdot
.36482 .54069 Mdot
.37619 .50665 Mdot
.69261 .45536 Mdot
.56593 .32783 Mdot
.63256 .25018 Mdot
.48496 .68983 Mdot
.6883 .60119 Mdot
.57143 .33621 Mdot
.62961 .67951 Mdot
.45296 .30598 Mdot
.32681 .28642 Mdot
.60599 .3248 Mdot
.58302 .34264 Mdot
.42507 .54577 Mdot
.53458 .67702 Mdot
.24605 .4969 Mdot
.37543 .49743 Mdot
.58384 .36192 Mdot
.59321 .33019 Mdot
.25903 .64243 Mdot
.44176 .49544 Mdot
.47959 .33449 Mdot
.58827 .53951 Mdot
.43934 .33074 Mdot
.4391 .5341 Mdot
.54127 .5779 Mdot
.55518 .348 Mdot
.57638 .35761 Mdot
.40777 .30892 Mdot
.43895 .45511 Mdot
.51207 .70542 Mdot
.64164 .65451 Mdot
.67946 .48634 Mdot
.38308 .49563 Mdot
.5388 .34276 Mdot
.4442 .63504 Mdot
.57227 .4554 Mdot
.66719 .46913 Mdot
.59962 .38066 Mdot
.37323 .48522 Mdot
.37845 .53497 Mdot
.43101 .29825 Mdot
.46263 .21967 Mdot
.41924 .57503 Mdot
.7065 .70279 Mdot
.57531 .56854 Mdot
.47618 .43976 Mdot
.36761 .52434 Mdot
.47622 .68719 Mdot
.63513 .65943 Mdot
.46084 .3037 Mdot
.3902 .48335 Mdot
.83733 .50834 Mdot
.50465 .72677 Mdot
.68027 .4547 Mdot
.6362 .65802 Mdot
.56051 .52745 Mdot
.39483 .48978 Mdot
.35985 .50428 Mdot
.4131 .53102 Mdot
.84093 .50373 Mdot
.55017 .38181 Mdot
.53975 .69557 Mdot
.44498 .32142 Mdot
.49654 .65146 Mdot
.55458 .39105 Mdot
.4697 .42603 Mdot
.41391 .52247 Mdot
.46886 .68772 Mdot
.51855 .66792 Mdot
.65974 .46888 Mdot
.71252 .47341 Mdot
.52773 .36509 Mdot
.40894 .50425 Mdot
.65026 .66109 Mdot
.52944 .69292 Mdot
.57301 .3257 Mdot
.43205 .29807 Mdot
.69786 .50076 Mdot
.34632 .5023 Mdot
.55985 .35124 Mdot
.37939 .47191 Mdot
.48945 .66221 Mdot
.58024 .34008 Mdot
.62336 .67566 Mdot
.43476 .28687 Mdot
.35214 .49328 Mdot
.60944 .22998 Mdot
.63594 .65628 Mdot
.38794 .56953 Mdot
.47527 .75486 Mdot
.41074 .27347 Mdot
.55213 .77685 Mdot
.56303 .38662 Mdot
.65015 .66698 Mdot
.53885 .68717 Mdot
.26024 .50849 Mdot
.57248 .36067 Mdot
.48322 .77914 Mdot
.53147 .4191 Mdot
.35053 .53005 Mdot
.50728 .70102 Mdot
.42842 .33595 Mdot
.72187 .69544 Mdot
.27587 .36612 Mdot
.38732 .51761 Mdot
.53689 .35601 Mdot
.45357 .28288 Mdot
.65607 .46325 Mdot
.57079 .73379 Mdot
.19363 .56267 Mdot
.59652 .38681 Mdot
.33799 .51804 Mdot
.53142 .68965 Mdot
.69254 .46289 Mdot
.55038 .80861 Mdot
.55556 .31834 Mdot
.55104 .37799 Mdot
.41701 .53817 Mdot
.44925 .32083 Mdot
.68761 .25102 Mdot
.54465 .37877 Mdot
.5447 .33201 Mdot
.67183 .61013 Mdot
.42343 .27996 Mdot
.40478 .53842 Mdot
.48891 .61249 Mdot
.42064 .50911 Mdot
.70538 .6793 Mdot
.65043 .66523 Mdot
.48445 .68696 Mdot
.35586 .50045 Mdot
.62043 .24441 Mdot
.56593 .36662 Mdot
.58804 .5441 Mdot
.74348 .49293 Mdot
.71125 .47626 Mdot
.53918 .34597 Mdot
.36605 .51546 Mdot
.66074 .50357 Mdot
.42992 .29275 Mdot
.41831 .5187 Mdot
.35651 .56075 Mdot
.51613 .63778 Mdot
.66452 .49004 Mdot
.40948 .62917 Mdot
.65459 .48792 Mdot
.68546 .44278 Mdot
.48276 .63172 Mdot
.38634 .53449 Mdot
.583 .35256 Mdot
.53365 .32644 Mdot
.38628 .47615 Mdot
.53482 .57212 Mdot
.51109 .7044 Mdot
.60538 .40115 Mdot
.84592 .46819 Mdot
.35067 .46292 Mdot
.65411 .68553 Mdot
.28431 .58119 Mdot
.67036 .4476 Mdot
.35308 .52802 Mdot
.49484 .66719 Mdot
.55611 .32673 Mdot
.5349 .35949 Mdot
.41544 .56649 Mdot
.69755 .46485 Mdot
.46865 .29243 Mdot
.55923 .37819 Mdot
.5768 .45738 Mdot
.39857 .51305 Mdot
.59301 .68119 Mdot
.56474 .38125 Mdot
.65536 .79013 Mdot
.62483 .24706 Mdot
.48496 .69511 Mdot
.36954 .55271 Mdot
.51581 .65081 Mdot
.4407 .32151 Mdot
.6028 .38785 Mdot
.70091 .46748 Mdot
.32886 .43138 Mdot
.37181 .21284 Mdot
.55632 .34076 Mdot
.49736 .68463 Mdot
.34148 .51473 Mdot
.28862 .51014 Mdot
.39406 .4918 Mdot
.25564 .44625 Mdot
.41614 .3396 Mdot
.6454 .49641 Mdot
.65879 .45796 Mdot
.35674 .54405 Mdot
.416 .29563 Mdot
.5262 .3399 Mdot
.54854 .35293 Mdot
.14903 .40642 Mdot
.61825 .66687 Mdot
.43531 .34822 Mdot
.34434 .50277 Mdot
.57931 .32887 Mdot
.42617 .717 Mdot
.65178 .46679 Mdot
.41691 .49736 Mdot
.59599 .34872 Mdot
.72948 .62892 Mdot
.58807 .53268 Mdot
.39485 .51595 Mdot
.33789 .45382 Mdot
.66939 .48235 Mdot
.65723 .55226 Mdot
.57461 .3898 Mdot
.407 .49109 Mdot
.70205 .4357 Mdot
.66056 .6264 Mdot
.34553 .23242 Mdot
.50372 .68258 Mdot
.57663 .31953 Mdot
.70879 .4699 Mdot
.39319 .45096 Mdot
.42624 .29211 Mdot
.5443 .32779 Mdot
.59568 .35578 Mdot
.37344 .56012 Mdot
.32787 .52757 Mdot
.40181 .45995 Mdot
.5 .69698 Mdot
.69841 .48438 Mdot
.34588 .5416 Mdot
.61246 .57248 Mdot
.35384 .53587 Mdot
.7013 .48045 Mdot
.13395 .63723 Mdot
.41237 .56531 Mdot
.36914 .49439 Mdot
.39625 .38746 Mdot
.49982 .71163 Mdot
.48395 .65824 Mdot
.59818 .5761 Mdot
.34506 .50156 Mdot
.60317 .42625 Mdot
.50171 .67934 Mdot
.51328 .70168 Mdot
.58732 .42701 Mdot
.38331 .56259 Mdot
.64697 .439 Mdot
.69385 .46579 Mdot
.71163 .47517 Mdot
.49011 .65745 Mdot
.31845 .54839 Mdot
.71205 .45506 Mdot
.2515 .66707 Mdot
.57868 .33706 Mdot
.54157 .57832 Mdot
.50491 .65507 Mdot
.55144 .43886 Mdot
.6991 .49095 Mdot
.67054 .80102 Mdot
.27338 .45896 Mdot
.40407 .47925 Mdot
.37923 .53626 Mdot
.43392 .312 Mdot
.31563 .56933 Mdot
.6222 .6689 Mdot
.69098 .47416 Mdot
.68173 .29051 Mdot
.5087 .68809 Mdot
.37487 .49091 Mdot
.28914 .32069 Mdot
.56843 .79565 Mdot
.54147 .62623 Mdot
.52254 .69516 Mdot
.51322 .69116 Mdot
.58864 .37526 Mdot
.57855 .33483 Mdot
.40739 .53137 Mdot
.68672 .47894 Mdot
.52511 .70671 Mdot
.68507 .49165 Mdot
.55351 .34771 Mdot
.57944 .3413 Mdot
.65249 .68107 Mdot
.3054 .5101 Mdot
.545 .34334 Mdot
.68147 .62075 Mdot
.61148 .56959 Mdot
.53602 .65655 Mdot
.64768 .1903 Mdot
.54451 .81243 Mdot
.39059 .38701 Mdot
.44811 .2793 Mdot
.6616 .65325 Mdot
.68796 .49725 Mdot
.35829 .54372 Mdot
.3511 .51162 Mdot
.63475 .67637 Mdot
.70819 .48716 Mdot
.44909 .31216 Mdot
.69766 .49245 Mdot
.45745 .29681 Mdot
.53806 .37535 Mdot
.33473 .5361 Mdot
.41081 .50185 Mdot
.67061 .45452 Mdot
.58647 .37182 Mdot
.55719 .33323 Mdot
.43239 .28133 Mdot
.33 .29148 Mdot
.55908 .35385 Mdot
.5047 .65485 Mdot
.38211 .63689 Mdot
.62587 .6703 Mdot
.3629 .51038 Mdot
.31315 .29408 Mdot
.24762 .63342 Mdot
.3471 .52851 Mdot
.63646 .65747 Mdot
.15665 .37872 Mdot
.33803 .54352 Mdot
.15488 .47199 Mdot
.65202 .67648 Mdot
.47694 .69435 Mdot
.5777 .38049 Mdot
.62065 .66058 Mdot
.3967 .44875 Mdot
.39662 .32129 Mdot
.366 .46855 Mdot
.51912 .70464 Mdot
.46921 .67933 Mdot
.50664 .49948 Mdot
.70729 .67582 Mdot
.45489 .31971 Mdot
.4479 .30525 Mdot
.57005 .36011 Mdot
.68535 .4222 Mdot
.42259 .48901 Mdot
.44596 .30781 Mdot
.71927 .30575 Mdot
.37962 .54702 Mdot
.39181 .33386 Mdot
.51275 .40465 Mdot
.47962 .69367 Mdot
.46231 .48513 Mdot
.56879 .36396 Mdot
.4979 .68479 Mdot
.50874 .4496 Mdot
.42295 .51107 Mdot
.50578 .68689 Mdot
.70096 .4843 Mdot
.74741 .44187 Mdot
.48099 .65438 Mdot
.56702 .46927 Mdot
.68928 .46415 Mdot
.40704 .2752 Mdot
.30582 .38146 Mdot
.88158 .46836 Mdot
.69091 .47593 Mdot
.58252 .37214 Mdot
.54694 .33922 Mdot
.55792 .35766 Mdot
.52377 .69734 Mdot
.55891 .37275 Mdot
.49012 .69145 Mdot
.64291 .50448 Mdot
.3486 .2684 Mdot
.43513 .30137 Mdot
.62492 .37407 Mdot
.51525 .67266 Mdot
.61795 .70079 Mdot
.57975 .16706 Mdot
.39913 .54032 Mdot
.64435 .46131 Mdot
.41906 .32304 Mdot
.59966 .6176 Mdot
.43768 .31469 Mdot
.58087 .37817 Mdot
.54277 .57966 Mdot
.38215 .52029 Mdot
.5159 .77567 Mdot
.45889 .28915 Mdot
.52374 .69497 Mdot
.41881 .54826 Mdot
.52021 .34833 Mdot
.42436 .30949 Mdot
.44496 .27979 Mdot
.37375 .50701 Mdot
.47113 .66326 Mdot
.58326 .34762 Mdot
.67728 .50024 Mdot
.41083 .32627 Mdot
.31823 .4633 Mdot
.38091 .53906 Mdot
.42619 .55317 Mdot
.58393 .55236 Mdot
.68963 .24697 Mdot
.68685 .46779 Mdot
.25155 .39681 Mdot
.55341 .3381 Mdot
.27419 .37316 Mdot
.64451 .73141 Mdot
.60749 .32155 Mdot
.65171 .66688 Mdot
.65 .66405 Mdot
.3885 .51329 Mdot
.71967 .27271 Mdot
.49571 .60742 Mdot
.68353 .4369 Mdot
.6272 .66762 Mdot
.55839 .33297 Mdot
.52741 .71904 Mdot
.4429 .44594 Mdot
.32795 .54161 Mdot
.7131 .48233 Mdot
.55333 .35209 Mdot
.77982 .38713 Mdot
.44077 .29496 Mdot
.58554 .60314 Mdot
.40863 .51475 Mdot
.37651 .51324 Mdot
.67569 .46245 Mdot
.69776 .47456 Mdot
.59356 .69386 Mdot
.52224 .52038 Mdot
.8066 .53743 Mdot
.63898 .45277 Mdot
.77799 .37282 Mdot
.48013 .61809 Mdot
.50017 .65968 Mdot
.64755 .68546 Mdot
.70791 .45287 Mdot
.3623 .49976 Mdot
.47953 .69869 Mdot
.52423 .61606 Mdot
.51818 .63594 Mdot
.39425 .34064 Mdot
.57478 .43492 Mdot
.41024 .51347 Mdot
.53571 .67474 Mdot
.49986 .68592 Mdot
.52656 .65772 Mdot
.62949 .66027 Mdot
.36495 .52557 Mdot
.3895 .541 Mdot
.34041 .54711 Mdot
.2902 .50777 Mdot
.39443 .51093 Mdot
.6521 .72801 Mdot
.62387 .58487 Mdot
.50138 .2614 Mdot
.33807 .51156 Mdot
.70812 .47431 Mdot
.33425 .52223 Mdot
.41752 .29578 Mdot
.33685 .50921 Mdot
.38932 .32136 Mdot
.67828 .47321 Mdot
.40382 .43616 Mdot
.59273 .41072 Mdot
.41227 .51869 Mdot
.47144 .30081 Mdot
.69402 .25036 Mdot
.27328 .34127 Mdot
.67364 .61194 Mdot
.5039 .65473 Mdot
.53244 .37528 Mdot
.64813 .45962 Mdot
.58179 .35167 Mdot
.4099 .48774 Mdot
.65629 .68046 Mdot
.48108 .83953 Mdot
.53305 .43804 Mdot
.36072 .49929 Mdot
.30158 .51621 Mdot
.47607 .68071 Mdot
.56506 .36879 Mdot
.50824 .62846 Mdot
.41489 .53941 Mdot
.43174 .32173 Mdot
.41989 .31749 Mdot
.48862 .4524 Mdot
.75272 .37583 Mdot
.25342 .49176 Mdot
.6777 .46381 Mdot
.53224 .35443 Mdot
.46386 .32027 Mdot
.5663 .66099 Mdot
.65028 .45056 Mdot
.67001 .44783 Mdot
.66654 .49059 Mdot
.40033 .50369 Mdot
.64618 .68278 Mdot
.73331 .33758 Mdot
.62648 .65662 Mdot
.41888 .53082 Mdot
.59591 .36165 Mdot
.62048 .65911 Mdot
.43193 .31312 Mdot
.68593 .44354 Mdot
.56119 .33528 Mdot
.38383 .50597 Mdot
.50467 .67545 Mdot
.25622 .37753 Mdot
.50934 .18404 Mdot
.61911 .38323 Mdot
.61951 .38582 Mdot
.48029 .708 Mdot
.78173 .65245 Mdot
.67875 .51157 Mdot
.24953 .60898 Mdot
.44693 .33757 Mdot
.38816 .47615 Mdot
.20185 .35046 Mdot
.56902 .39111 Mdot
.54564 .36176 Mdot
.39988 .51847 Mdot
.56524 .3205 Mdot
.3811 .48918 Mdot
.58094 .38886 Mdot
.7516 .64058 Mdot
.33429 .55429 Mdot
.54808 .36391 Mdot
.43163 .50185 Mdot
.40539 .56159 Mdot
.47444 .67874 Mdot
.54866 .32633 Mdot
.4022 .47752 Mdot
.44694 .84861 Mdot
.66206 .46365 Mdot
.62786 .66097 Mdot
.63134 .38203 Mdot
.66865 .49677 Mdot
.49846 .70123 Mdot
.33349 .53862 Mdot
.43131 .29349 Mdot
.50908 .66575 Mdot
.52269 .36323 Mdot
.46378 .29601 Mdot
.60042 .59001 Mdot
.49592 .65753 Mdot
.63323 .67741 Mdot
.4379 .2865 Mdot
.36503 .46843 Mdot
.54479 .3562 Mdot
.59051 .20413 Mdot
.62591 .65789 Mdot
.37477 .52117 Mdot
.5623 .31414 Mdot
.69549 .49334 Mdot
.40177 .53091 Mdot
.53384 .34957 Mdot
.63212 .65845 Mdot
.38736 .56891 Mdot
.39282 .56902 Mdot
.42335 .43272 Mdot
.50435 .57126 Mdot
.43156 .30268 Mdot
.48115 .6332 Mdot
.4094 .53898 Mdot
.41665 .29346 Mdot
.65369 .32526 Mdot
.33649 .49348 Mdot
.50145 .64788 Mdot
.30847 .44876 Mdot
.58346 .33753 Mdot
.65495 .4619 Mdot
.53861 .3233 Mdot
.45442 .2808 Mdot
.37999 .17978 Mdot
.63537 .68152 Mdot
.30219 .50453 Mdot
.42605 .51586 Mdot
.60284 .3776 Mdot
.50191 .68977 Mdot
.80155 .55892 Mdot
.34899 .49669 Mdot
.33633 .56765 Mdot
.36743 .50796 Mdot
.61795 .2485 Mdot
.51328 .70343 Mdot
.36429 .50867 Mdot
.30031 .48017 Mdot
.38509 .46576 Mdot
.47344 .30374 Mdot
.33924 .35979 Mdot
.3377 .527 Mdot
.3339 .86028 Mdot
.65357 .66206 Mdot
.54969 .35626 Mdot
.57948 .50283 Mdot
.61506 .27892 Mdot
.1746 .52613 Mdot
.49486 .69511 Mdot
.37042 .60937 Mdot
.58251 .34898 Mdot
.2489 .36632 Mdot
.75429 .68645 Mdot
.40963 .559 Mdot
.36884 .4868 Mdot
.58087 .37811 Mdot
.57258 .32651 Mdot
.65687 .67102 Mdot
.35368 .48579 Mdot
.33304 .56458 Mdot
.58142 .32575 Mdot
.38635 .50234 Mdot
.30828 .71546 Mdot
.65131 .49295 Mdot
.48655 .65823 Mdot
.65603 .46373 Mdot
.67155 .44885 Mdot
.23276 .56114 Mdot
.57428 .5688 Mdot
.70069 .47829 Mdot
.7235 .45823 Mdot
.38246 .28579 Mdot
.34022 .42264 Mdot
.47013 .31095 Mdot
.76389 .41951 Mdot
.56544 .35825 Mdot
.36296 .5259 Mdot
.52878 .68707 Mdot
.21102 .57162 Mdot
.7767 .49916 Mdot
.55541 .59203 Mdot
.39735 .54239 Mdot
.56356 .36466 Mdot
.63074 .65726 Mdot
.33108 .54996 Mdot
.26398 .38908 Mdot
.38265 .51608 Mdot
.57599 .33188 Mdot
.23192 .55265 Mdot
.55082 .74051 Mdot
.64078 .45093 Mdot
.54866 .70484 Mdot
.33393 .52715 Mdot
.48768 .67107 Mdot
.70565 .4682 Mdot
.41333 .29657 Mdot
.43828 .30934 Mdot
.41321 .51316 Mdot
.50288 .50586 Mdot
.4045 .24936 Mdot
.40819 .55915 Mdot
.37485 .56133 Mdot
.6517 .67003 Mdot
.37444 .56178 Mdot
.41051 .49592 Mdot
.34546 .53796 Mdot
.35185 .48357 Mdot
.69133 .44364 Mdot
.49172 .76046 Mdot
.33347 .50954 Mdot
.35196 .4613 Mdot
.67842 .50337 Mdot
.45289 .50588 Mdot
.67059 .47998 Mdot
.80359 .49004 Mdot
.68322 .48504 Mdot
.43752 .30774 Mdot
.53488 .31916 Mdot
.40183 .6139 Mdot
.52373 .70785 Mdot
.71057 .46846 Mdot
.45268 .29608 Mdot
.68763 .47634 Mdot
.53756 .36902 Mdot
.61654 .19032 Mdot
.46784 .64583 Mdot
.59985 .53595 Mdot
.35604 .39852 Mdot
.59326 .68226 Mdot
.58744 .34413 Mdot
.49384 .7047 Mdot
.55198 .7425 Mdot
.35396 .54406 Mdot
.42807 .29813 Mdot
.38695 .51331 Mdot
.67712 .44307 Mdot
.56334 .36211 Mdot
.64056 .50856 Mdot
.43126 .30402 Mdot
.43651 .17059 Mdot
.59179 .37958 Mdot
.31292 .48483 Mdot
.66894 .50369 Mdot
.62534 .18434 Mdot
.67759 .48362 Mdot
.34482 .27078 Mdot
.46004 .70153 Mdot
.21645 .52582 Mdot
.51572 .68477 Mdot
.58368 .69861 Mdot
.82304 .62444 Mdot
.75524 .67229 Mdot
.50272 .66554 Mdot
.59769 .4105 Mdot
.39729 .50692 Mdot
.35869 .53929 Mdot
.37977 .46128 Mdot
.54652 .67075 Mdot
.41151 .53314 Mdot
.6243 .67166 Mdot
.5834 .56271 Mdot
.69157 .27099 Mdot
.52753 .36121 Mdot
.38446 .48884 Mdot
.69369 .45308 Mdot
.66913 .44199 Mdot
.62253 .65702 Mdot
.66068 .49123 Mdot
.39672 .56352 Mdot
.51584 .6758 Mdot
.50749 .42391 Mdot
.43562 .3197 Mdot
.68601 .70862 Mdot
.45192 .33218 Mdot
.58504 .31027 Mdot
.36018 .4618 Mdot
.57984 .34119 Mdot
.2854 .25352 Mdot
.36273 .54344 Mdot
.49973 .67904 Mdot
.42087 .53553 Mdot
.34189 .53591 Mdot
.33802 .52224 Mdot
.53286 .35036 Mdot
.58206 .50681 Mdot
.3836 .50107 Mdot
.70479 .47422 Mdot
.57035 .42628 Mdot
.32541 .52899 Mdot
.69186 .30942 Mdot
.3987 .34993 Mdot
.59406 .67901 Mdot
.53978 .66304 Mdot
.57882 .36923 Mdot
.51087 .6885 Mdot
.5468 .7176 Mdot
.49816 .70117 Mdot
.70047 .30563 Mdot
.25184 .53104 Mdot
.15178 .49938 Mdot
.41118 .70332 Mdot
.22607 .58362 Mdot
.46795 .68959 Mdot
.67789 .35071 Mdot
.49746 .66363 Mdot
.49584 .69817 Mdot
.10905 .53039 Mdot
.51944 .66081 Mdot
.35675 .51254 Mdot
.36255 .56915 Mdot
.61334 .78322 Mdot
.38039 .29007 Mdot
.33722 .51129 Mdot
.40993 .53301 Mdot
.43438 .3251 Mdot
.30717 .46028 Mdot
.6344 .64924 Mdot
.58008 .58761 Mdot
.66718 .68198 Mdot
.37489 .50727 Mdot
.40565 .52246 Mdot
.42386 .56244 Mdot
.82374 .63161 Mdot
.20182 .56452 Mdot
.47453 .69488 Mdot
.43249 .46377 Mdot
.685 .65636 Mdot
.42603 .52561 Mdot
.42416 .52619 Mdot
.34956 .55682 Mdot
.58301 .35143 Mdot
.52253 .72042 Mdot
.36801 .5808 Mdot
.60651 .74646 Mdot
.40858 .51634 Mdot
.55187 .30273 Mdot
.47753 .28235 Mdot
.3647 .51548 Mdot
.50407 .65003 Mdot
.37945 .54358 Mdot
.52651 .66139 Mdot
.4869 .65971 Mdot
.30494 .51435 Mdot
.73992 .34845 Mdot
.53344 .71807 Mdot
.41115 .55961 Mdot
.58614 .36769 Mdot
.72251 .69131 Mdot
.37178 .52044 Mdot
.45524 .31819 Mdot
.35318 .52881 Mdot
.47078 .29627 Mdot
.36496 .56261 Mdot
.62897 .65564 Mdot
.30568 .64598 Mdot
.57504 .35741 Mdot
.41325 .32899 Mdot
.57742 .326 Mdot
.43193 .4229 Mdot
.47645 .64822 Mdot
.6395 .64928 Mdot
.1938 .5827 Mdot
.65171 .67193 Mdot
.2389 .40736 Mdot
.6824 .4177 Mdot
.67091 .45146 Mdot
.53865 .67319 Mdot
.24134 .52524 Mdot
.72227 .34967 Mdot
.57871 .40035 Mdot
.58124 .39805 Mdot
.30281 .25052 Mdot
.18748 .34536 Mdot
.37993 .49803 Mdot
.67232 .22516 Mdot
.33916 .69457 Mdot
.40813 .47302 Mdot
.44282 .5471 Mdot
.59407 .34813 Mdot
.33215 .52492 Mdot
.55606 .47167 Mdot
.5596 .34517 Mdot
.44916 .29753 Mdot
.48422 .68449 Mdot
.4355 .28308 Mdot
.78269 .47786 Mdot
.62591 .57271 Mdot
.55066 .34248 Mdot
.34179 .49116 Mdot
.38776 .49443 Mdot
.5402 .68176 Mdot
.49842 .78785 Mdot
.48127 .66301 Mdot
.46238 .31617 Mdot
.56991 .34778 Mdot
.22023 .59695 Mdot
.34695 .52147 Mdot
.52101 .67076 Mdot
.57622 .40986 Mdot
.37656 .53471 Mdot
.67772 .45305 Mdot
.3969 .543 Mdot
.51513 .66178 Mdot
.37322 .56185 Mdot
.51511 .67785 Mdot
.58322 .38389 Mdot
.3987 .49038 Mdot
.40544 .52426 Mdot
.22742 .41956 Mdot
.44893 .31323 Mdot
.47306 .65167 Mdot
.55805 .47681 Mdot
.42079 .51012 Mdot
.26491 .39035 Mdot
.33573 .53871 Mdot
.42872 .59672 Mdot
.43325 .56204 Mdot
.62874 .67617 Mdot
.42505 .50635 Mdot
.37311 .52001 Mdot
.45939 .77974 Mdot
.43719 .74212 Mdot
.46048 .46701 Mdot
.71324 .47123 Mdot
.50018 .65016 Mdot
.5438 .34043 Mdot
.55712 .32827 Mdot
.56471 .37654 Mdot
.37494 .28663 Mdot
.32467 .45606 Mdot
.38355 .52199 Mdot
.64191 .49359 Mdot
.44572 .30428 Mdot
.52536 .6853 Mdot
.43985 .30325 Mdot
.57563 .58565 Mdot
.46549 .30838 Mdot
.62462 .67341 Mdot
.62587 .24673 Mdot
.27184 .68506 Mdot
.46179 .30787 Mdot
.48242 .66188 Mdot
.59187 .43125 Mdot
.38962 .47552 Mdot
.71085 .63185 Mdot
.43209 .32207 Mdot
.32456 .23719 Mdot
.37304 .56917 Mdot
.56673 .47856 Mdot
.66605 .47657 Mdot
.43738 .28318 Mdot
.66055 .48746 Mdot
.37423 .54335 Mdot
.54932 .77872 Mdot
.49589 .68044 Mdot
.64752 .48355 Mdot
.42036 .49559 Mdot
.43563 .28329 Mdot
.5472 .34437 Mdot
.28459 .45405 Mdot
.70858 .48984 Mdot
.25692 .36848 Mdot
.27549 .3667 Mdot
.568 .34644 Mdot
.24867 .6906 Mdot
.66455 .48547 Mdot
.35756 .47682 Mdot
.27108 .55067 Mdot
.38911 .54548 Mdot
.55093 .33317 Mdot
.54743 .36612 Mdot
.66768 .74116 Mdot
.41152 .51255 Mdot
.34739 .56107 Mdot
.5067 .7207 Mdot
.55938 .33935 Mdot
.50207 .70388 Mdot
.53784 .70054 Mdot
.58273 .37636 Mdot
.48578 .69669 Mdot
.45806 .28826 Mdot
.56403 .56685 Mdot
.66742 .4862 Mdot
.69094 .45785 Mdot
.54588 .34231 Mdot
.53095 .36052 Mdot
.57725 .33864 Mdot
.40117 .54601 Mdot
.50588 .70959 Mdot
.37695 .554 Mdot
.33511 .52239 Mdot
.45092 .653 Mdot
.49899 .71464 Mdot
.37915 .55032 Mdot
.52736 .40963 Mdot
.47249 .28892 Mdot
.54961 .36496 Mdot
.68878 .49083 Mdot
.22203 .41968 Mdot
.65085 .48998 Mdot
.41994 .51849 Mdot
.7274 .63318 Mdot
.52275 .69808 Mdot
.4361 .31395 Mdot
.41571 .27461 Mdot
.43153 .30777 Mdot
.64731 .48325 Mdot
.54141 .69717 Mdot
.60197 .58736 Mdot
.41136 .50593 Mdot
.58241 .5534 Mdot
.23677 .42737 Mdot
.63504 .73659 Mdot
.70042 .48333 Mdot
.40129 .53972 Mdot
.65148 .67567 Mdot
.26105 .64851 Mdot
.38972 .52109 Mdot
.41605 .49536 Mdot
.53159 .22695 Mdot
.35159 .46175 Mdot
.5229 .64247 Mdot
.49239 .47528 Mdot
.38812 .48323 Mdot
.4529 .45245 Mdot
.12603 .4409 Mdot
.37994 .56993 Mdot
.40888 .52168 Mdot
.35363 .51882 Mdot
.3627 .54544 Mdot
.50467 .64548 Mdot
.50089 .20927 Mdot
.70054 .45721 Mdot
.5636 .56456 Mdot
.66845 .48974 Mdot
.54084 .35499 Mdot
.53711 .45746 Mdot
.52119 .6552 Mdot
.43134 .30857 Mdot
.65823 .20797 Mdot
.54762 .57371 Mdot
.58962 .37184 Mdot
.18856 .52253 Mdot
.43085 .31975 Mdot
.38522 .47536 Mdot
.44695 .27752 Mdot
.59144 .33744 Mdot
.69802 .46637 Mdot
.42346 .54874 Mdot
.52262 .70337 Mdot
.48306 .65362 Mdot
.40481 .54146 Mdot
.70145 .70158 Mdot
.67496 .49775 Mdot
.52694 .29351 Mdot
.40419 .50693 Mdot
.4148 .49431 Mdot
.47897 .67258 Mdot
.56335 .36794 Mdot
.65603 .41805 Mdot
.45422 .30688 Mdot
.42432 .49658 Mdot
.37412 .54241 Mdot
.57376 .57791 Mdot
.70543 .45276 Mdot
.63468 .66699 Mdot
.40833 .51007 Mdot
.5794 .56874 Mdot
.4175 .52283 Mdot
.32173 .5647 Mdot
.58726 .35321 Mdot
.31186 .52078 Mdot
.36472 .48538 Mdot
.43845 .66378 Mdot
.65945 .48246 Mdot
.50234 .68494 Mdot
.46436 .70497 Mdot
.64175 .65759 Mdot
.66702 .45911 Mdot
.38333 .54946 Mdot
.66146 .45 Mdot
.34493 .53149 Mdot
.38501 .50426 Mdot
.70069 .48337 Mdot
.49925 .7041 Mdot
.79777 .54552 Mdot
.49961 .76497 Mdot
.35552 .55136 Mdot
.35874 .53319 Mdot
.37777 .30192 Mdot
.21299 .64515 Mdot
.36144 .48584 Mdot
.50796 .71109 Mdot
.37967 .53468 Mdot
.6945 .45755 Mdot
.46372 .31445 Mdot
.50146 .67364 Mdot
.53451 .36804 Mdot
.57496 .3884 Mdot
.5846 .41559 Mdot
.63069 .67895 Mdot
.35876 .48387 Mdot
.47826 .63297 Mdot
.49245 .71443 Mdot
.59778 .62777 Mdot
.54895 .35669 Mdot
.46854 .30583 Mdot
.34437 .5558 Mdot
.27627 .46672 Mdot
.68267 .44821 Mdot
.34275 .86357 Mdot
.60575 .58827 Mdot
.47644 .31311 Mdot
.50091 .53437 Mdot
.64781 .67695 Mdot
.36389 .49413 Mdot
.41938 .29209 Mdot
.56143 .38358 Mdot
.36362 .54101 Mdot
.36319 .45093 Mdot
.72598 .36206 Mdot
.53848 .37814 Mdot
.65701 .45528 Mdot
.55429 .38261 Mdot
.47158 .29406 Mdot
.6232 .6712 Mdot
.47232 .66428 Mdot
.37318 .51694 Mdot
.46198 .54 Mdot
.55628 .35988 Mdot
.63554 .65365 Mdot
.41375 .51789 Mdot
.49425 .65006 Mdot
.55498 .37048 Mdot
.37028 .50372 Mdot
.25206 .61743 Mdot
.45806 .61259 Mdot
.56754 .35358 Mdot
.42944 .53374 Mdot
.39736 .41172 Mdot
.54996 .38718 Mdot
.59705 .35927 Mdot
.41125 .53233 Mdot
.44343 .28506 Mdot
.38779 .48682 Mdot
.68072 .48171 Mdot
.58222 .50665 Mdot
.67363 .45527 Mdot
.25073 .4018 Mdot
.36724 .5719 Mdot
.53836 .62137 Mdot
.53533 .68355 Mdot
.41625 .27978 Mdot
.44294 .77867 Mdot
.40522 .48664 Mdot
.82242 .53589 Mdot
.55647 .44123 Mdot
.63406 .59 Mdot
.83076 .46079 Mdot
.45856 .30555 Mdot
.68206 .47698 Mdot
.41009 .52367 Mdot
.70918 .50121 Mdot
.45707 .29319 Mdot
.24697 .40558 Mdot
.42782 .51975 Mdot
.51477 .70097 Mdot
.40284 .51 Mdot
.50671 .6547 Mdot
.36662 .53304 Mdot
.37601 .4428 Mdot
.47814 .33386 Mdot
.34212 .27308 Mdot
.37848 .47444 Mdot
.66236 .20552 Mdot
.35155 .40939 Mdot
.44522 .32105 Mdot
.3596 .55574 Mdot
.6387 .67406 Mdot
.70309 .48871 Mdot
.6377 .22603 Mdot
.58152 .34526 Mdot
.69718 .48108 Mdot
.48064 .68171 Mdot
.55058 .31621 Mdot
.6436 .65677 Mdot
.27598 .56284 Mdot
.4324 .28409 Mdot
.66342 .46249 Mdot
.36978 .51833 Mdot
.42256 .52481 Mdot
.61599 .24442 Mdot
.28441 .74524 Mdot
.52358 .71188 Mdot
.39058 .19469 Mdot
.48769 .6335 Mdot
.44839 .30907 Mdot
.58648 .34964 Mdot
.35522 .5024 Mdot
.3971 .52294 Mdot
.54157 .33718 Mdot
.49734 .71087 Mdot
.601 .33129 Mdot
.21158 .54221 Mdot
.74202 .49186 Mdot
.34505 .32273 Mdot
.4993 .67053 Mdot
.3432 .31903 Mdot
.47657 .30924 Mdot
.7736 .38896 Mdot
.34783 .38807 Mdot
.66307 .45582 Mdot
.3467 .32719 Mdot
.52654 .68086 Mdot
.3774 .49653 Mdot
.63251 .67648 Mdot
.65442 .67524 Mdot
.4845 .67287 Mdot
.58034 .3757 Mdot
.42702 .291 Mdot
.40149 .51399 Mdot
.57902 .64683 Mdot
.56519 .81177 Mdot
.53104 .3506 Mdot
.29856 .51699 Mdot
.66987 .49591 Mdot
.37326 .53587 Mdot
.42431 .32202 Mdot
.69274 .47067 Mdot
.61912 .67009 Mdot
.54903 .56317 Mdot
.34278 .55459 Mdot
.47915 .44586 Mdot
.66513 .46806 Mdot
.21578 .65742 Mdot
.40408 .52495 Mdot
.66406 .48527 Mdot
.44987 .56566 Mdot
.57125 .75431 Mdot
.51332 .4143 Mdot
.76759 .65664 Mdot
.54745 .39317 Mdot
.57116 .38895 Mdot
.40915 .83026 Mdot
.44792 .33778 Mdot
.70852 .46692 Mdot
.621 .6652 Mdot
.3436 .371 Mdot
.65458 .48055 Mdot
.41938 .55429 Mdot
.33622 .54106 Mdot
.22955 .56257 Mdot
.4103 .40107 Mdot
.65239 .65845 Mdot
.31691 .58656 Mdot
.39309 .55993 Mdot
.34703 .47648 Mdot
.39914 .53409 Mdot
.4698 .68222 Mdot
.65059 .47232 Mdot
.7532 .24973 Mdot
.65375 .45262 Mdot
.5699 .62478 Mdot
.56537 .35863 Mdot
.53217 .335 Mdot
.36503 .51451 Mdot
.49038 .60144 Mdot
.70894 .25594 Mdot
.34342 .52068 Mdot
.41568 .27219 Mdot
.27487 .36498 Mdot
.32277 .51971 Mdot
.49899 .72552 Mdot
.33731 .56913 Mdot
.49565 .6389 Mdot
.6943 .46908 Mdot
.45899 .30377 Mdot
.47417 .28959 Mdot
.67422 .47777 Mdot
.38584 .52451 Mdot
.46792 .27544 Mdot
.37282 .51184 Mdot
.38579 .49594 Mdot
.58081 .59524 Mdot
.42023 .32559 Mdot
.5768 .33744 Mdot
.43592 .30844 Mdot
.49869 .69835 Mdot
.10562 .56359 Mdot
.4369 .29614 Mdot
.33429 .42524 Mdot
.5561 .45767 Mdot
.34409 .32809 Mdot
.48137 .65534 Mdot
.45562 .31999 Mdot
.65321 .46459 Mdot
.62621 .59847 Mdot
.2429 .67726 Mdot
.64779 .48043 Mdot
.39817 .52076 Mdot
.52333 .65705 Mdot
.48092 .70722 Mdot
.65529 .44193 Mdot
.47787 .69146 Mdot
.32644 .48072 Mdot
.41318 .55879 Mdot
.70648 .4643 Mdot
.60828 .79442 Mdot
.65025 .47004 Mdot
.28777 .45456 Mdot
.36081 .56341 Mdot
.50071 .67648 Mdot
.40885 .59987 Mdot
.47031 .62782 Mdot
.65369 .68091 Mdot
.33516 .51148 Mdot
.42714 .30438 Mdot
.56716 .53516 Mdot
.56855 .35468 Mdot
.73145 .63047 Mdot
.50257 .654 Mdot
.64158 .46957 Mdot
.47403 .67616 Mdot
.51503 .71343 Mdot
.64775 .47369 Mdot
.49752 .69139 Mdot
.40681 .51887 Mdot
.69064 .54826 Mdot
.505 .65632 Mdot
.67397 .46554 Mdot
.4247 .3031 Mdot
.48938 .70048 Mdot
.60627 .34573 Mdot
.38044 .49276 Mdot
.58928 .34463 Mdot
.40915 .31949 Mdot
.52711 .65928 Mdot
.46082 .31607 Mdot
.55276 .35941 Mdot
.42418 .2923 Mdot
.69062 .51569 Mdot
.65296 .50509 Mdot
.5557 .59761 Mdot
.53746 .75281 Mdot
.52897 .68965 Mdot
.56342 .40218 Mdot
.3581 .49319 Mdot
.40009 .50064 Mdot
.45556 .28004 Mdot
.4777 .70526 Mdot
.71865 .68832 Mdot
.40461 .60653 Mdot
.68057 .71006 Mdot
.7123 .46108 Mdot
.31598 .26899 Mdot
.61182 .59121 Mdot
.64873 .59335 Mdot
.44125 .52787 Mdot
.64645 .67775 Mdot
.3665 .50771 Mdot
.2741 .33938 Mdot
.46302 .31746 Mdot
.66587 .39097 Mdot
.42107 .4869 Mdot
.56884 .34036 Mdot
.35614 .52776 Mdot
.66421 .22421 Mdot
.36667 .58774 Mdot
.44284 .32447 Mdot
.67667 .50534 Mdot
.52387 .70778 Mdot
.43477 .32008 Mdot
.58014 .38716 Mdot
.37256 .34881 Mdot
.42394 .55624 Mdot
.39653 .56143 Mdot
.588 .39566 Mdot
.5072 .70529 Mdot
.54252 .35573 Mdot
.66717 .48631 Mdot
.43855 .29894 Mdot
.36068 .54657 Mdot
.31672 .5041 Mdot
.60264 .37251 Mdot
.66129 .44565 Mdot
.52926 .35179 Mdot
.66574 .44776 Mdot
.64416 .67884 Mdot
.36082 .48143 Mdot
.59976 .37792 Mdot
.44221 .50985 Mdot
.43269 .72043 Mdot
.56851 .58997 Mdot
.41933 .7691 Mdot
.57667 .33677 Mdot
.37224 .32518 Mdot
.67421 .47364 Mdot
.65806 .4701 Mdot
.23587 .54694 Mdot
.71179 .2629 Mdot
.60187 .42637 Mdot
.60333 .19023 Mdot
.66842 .48658 Mdot
.6691 .46216 Mdot
.56351 .38317 Mdot
.49125 .69019 Mdot
.51964 .73062 Mdot
.58512 .32549 Mdot
.31282 .29477 Mdot
.52543 .68443 Mdot
.81977 .57697 Mdot
.576 .39392 Mdot
.43732 .54794 Mdot
.66125 .66804 Mdot
.43763 .3239 Mdot
.28233 .33159 Mdot
.61682 .19795 Mdot
.35768 .50513 Mdot
.16469 .44411 Mdot
.57953 .36479 Mdot
.7502 .4745 Mdot
.77642 .42427 Mdot
.42335 .5083 Mdot
.35704 .52598 Mdot
.38718 .52833 Mdot
.40621 .30724 Mdot
.47308 .76851 Mdot
.35889 .50266 Mdot
.3497 .27145 Mdot
.33719 .55831 Mdot
.59486 .21039 Mdot
.43604 .3081 Mdot
.24705 .454 Mdot
.53712 .38693 Mdot
.61802 .73375 Mdot
.37101 .46276 Mdot
.66957 .48488 Mdot
.73448 .40861 Mdot
.70404 .47837 Mdot
.75289 .33367 Mdot
.34326 .38884 Mdot
.46922 .68189 Mdot
.39843 .54307 Mdot
.58939 .39136 Mdot
.52618 .65973 Mdot
.66227 .41594 Mdot
.10414 .52499 Mdot
.69303 .44339 Mdot
.23624 .26831 Mdot
.65764 .4638 Mdot
.65545 .67176 Mdot
.48137 .67223 Mdot
.47505 .50308 Mdot
.57827 .55416 Mdot
.50069 .70342 Mdot
.50067 .27774 Mdot
.47846 .71859 Mdot
.35694 .31109 Mdot
.46083 .67955 Mdot
.67815 .46984 Mdot
.65065 .50207 Mdot
.42682 .46941 Mdot
.35871 .48917 Mdot
.59025 .55802 Mdot
.449 .52085 Mdot
.34487 .50148 Mdot
.55973 .34507 Mdot
.55378 .7514 Mdot
.72919 .44677 Mdot
.49367 .66819 Mdot
.69091 .44835 Mdot
.3554 .52579 Mdot
.35637 .55207 Mdot
.39095 .46728 Mdot
.24973 .37396 Mdot
.82077 .56908 Mdot
.38226 .50152 Mdot
.32401 .55404 Mdot
.5883 .37206 Mdot
.60986 .23343 Mdot
.43972 .19182 Mdot
.35031 .37368 Mdot
.41529 .51496 Mdot
.44501 .31359 Mdot
.44288 .32664 Mdot
.31651 .48479 Mdot
.54404 .61749 Mdot
.615 .36126 Mdot
.36972 .51854 Mdot
.40729 .3787 Mdot
.60645 .37759 Mdot
.62982 .65427 Mdot
.55585 .35938 Mdot
.52273 .6552 Mdot
.65288 .67056 Mdot
.53498 .35402 Mdot
.47169 .57537 Mdot
.64108 .65812 Mdot
.58136 .75134 Mdot
.46207 .31663 Mdot
.40128 .53091 Mdot
.51701 .62891 Mdot
.54201 .33822 Mdot
.66277 .46701 Mdot
.51054 .6738 Mdot
.7172 .47078 Mdot
.61471 .23383 Mdot
.2931 .32316 Mdot
.63627 .6817 Mdot
.6739 .48496 Mdot
.51566 .50002 Mdot
.44279 .31262 Mdot
.65355 .48456 Mdot
.521 .61546 Mdot
.32703 .52894 Mdot
.76963 .32876 Mdot
.40485 .55671 Mdot
.6949 .7279 Mdot
.66018 .47454 Mdot
.64626 .68712 Mdot
.3757 .51671 Mdot
.59064 .38088 Mdot
.45368 .51244 Mdot
.37482 .51148 Mdot
.54856 .3805 Mdot
.37894 .49822 Mdot
.41323 .31211 Mdot
.50974 .64299 Mdot
.54515 .43888 Mdot
.26427 .33234 Mdot
.42123 .30146 Mdot
.63082 .64248 Mdot
.3554 .48881 Mdot
.45786 .2386 Mdot
.51005 .70006 Mdot
.41574 .49714 Mdot
.19217 .47096 Mdot
.48689 .67981 Mdot
.51194 .68923 Mdot
.37606 .5595 Mdot
.64883 .4831 Mdot
.55661 .33401 Mdot
.44019 .31225 Mdot
.69827 .42437 Mdot
.36899 .50203 Mdot
.40355 .5385 Mdot
.43124 .31953 Mdot
.67009 .45873 Mdot
.36441 .54813 Mdot
.76807 .57301 Mdot
.59303 .62614 Mdot
.67374 .44816 Mdot
.32554 .52613 Mdot
.80078 .35494 Mdot
.52793 .7293 Mdot
.15919 .45917 Mdot
.44179 .3374 Mdot
.58353 .37025 Mdot
.30154 .49426 Mdot
.29252 .8309 Mdot
.44678 .32178 Mdot
.6309 .73037 Mdot
.38715 .5004 Mdot
.34604 .50774 Mdot
.47286 .65586 Mdot
.38335 .5529 Mdot
.51766 .66141 Mdot
.26977 .31901 Mdot
.64374 .17998 Mdot
.47593 .68212 Mdot
.51337 .65823 Mdot
.46653 .49939 Mdot
.24203 .391 Mdot
.48326 .6851 Mdot
.42428 .55653 Mdot
.50306 .26801 Mdot
.32614 .45842 Mdot
.46238 .32594 Mdot
.43037 .2715 Mdot
.47969 .71249 Mdot
.32358 .76332 Mdot
.45472 .56275 Mdot
.40841 .43349 Mdot
.40206 .25571 Mdot
.68633 .48649 Mdot
.34265 .54523 Mdot
.62593 .67544 Mdot
.55553 .37358 Mdot
.34905 .57745 Mdot
.39872 .5285 Mdot
.51802 .65688 Mdot
.40549 .30105 Mdot
.65729 .48665 Mdot
.40949 .53106 Mdot
.56547 .30893 Mdot
.45221 .29988 Mdot
.50378 .6571 Mdot
.32806 .42918 Mdot
.47102 .31259 Mdot
.32282 .4912 Mdot
.34418 .50414 Mdot
.41539 .52022 Mdot
.39187 .46178 Mdot
.67109 .47748 Mdot
.57422 .31835 Mdot
.3126 .47967 Mdot
.58552 .58367 Mdot
.56552 .52133 Mdot
.31142 .48386 Mdot
.50416 .7106 Mdot
.71194 .47173 Mdot
.63759 .6606 Mdot
.34366 .34956 Mdot
.37124 .56812 Mdot
.82309 .55026 Mdot
.1971 .54115 Mdot
.64436 .66332 Mdot
.46686 .65614 Mdot
.43441 .31163 Mdot
.38458 .5639 Mdot
.45498 .25627 Mdot
.41725 .55499 Mdot
.28434 .50396 Mdot
.58232 .36687 Mdot
.68481 .48984 Mdot
.59459 .6529 Mdot
.55426 .3733 Mdot
.51121 .68879 Mdot
.71546 .73424 Mdot
.49608 .72867 Mdot
.53041 .71024 Mdot
.7437 .34793 Mdot
.69823 .47156 Mdot
.31846 .85097 Mdot
.21142 .64555 Mdot
.40133 .5687 Mdot
.70239 .46564 Mdot
.48475 .66658 Mdot
.40458 .54843 Mdot
.52824 .68708 Mdot
.52772 .7211 Mdot
.33293 .52005 Mdot
.35009 .49817 Mdot
.33464 .28266 Mdot
.81657 .60319 Mdot
.42888 .29709 Mdot
.47809 .6962 Mdot
.2344 .57809 Mdot
.35943 .50008 Mdot
.41015 .50445 Mdot
.73628 .38587 Mdot
.45033 .32205 Mdot
.30398 .70442 Mdot
.39937 .50248 Mdot
.19144 .46281 Mdot
.34285 .50216 Mdot
.55703 .70203 Mdot
.65089 .44161 Mdot
.55872 .62791 Mdot
.5535 .33264 Mdot
.53845 .66838 Mdot
.46407 .28863 Mdot
.54201 .67275 Mdot
.24253 .558 Mdot
.69675 .46834 Mdot
.51534 .66184 Mdot
.53132 .32582 Mdot
.68287 .46009 Mdot
.66292 .45501 Mdot
.5843 .42391 Mdot
.54293 .31909 Mdot
.40834 .30712 Mdot
.69749 .49053 Mdot
.25017 .60661 Mdot
.68198 .46916 Mdot
.24161 .57779 Mdot
.38459 .48368 Mdot
.34243 .28964 Mdot
.58788 .64364 Mdot
.41286 .46455 Mdot
.65054 .47615 Mdot
.43958 .28873 Mdot
.3887 .54793 Mdot
.4799 .69531 Mdot
.4403 .29273 Mdot
.73133 .47862 Mdot
.52528 .34412 Mdot
.48459 .71295 Mdot
.65869 .50185 Mdot
.52437 .66715 Mdot
.2751 .35315 Mdot
.60567 .32281 Mdot
.50948 .39363 Mdot
.58109 .54875 Mdot
.36902 .47073 Mdot
.45428 .45475 Mdot
.42497 .51712 Mdot
.39465 .52466 Mdot
.56692 .35412 Mdot
.37416 .28785 Mdot
.49037 .70161 Mdot
.61344 .81109 Mdot
.6682 .4821 Mdot
.49461 .48159 Mdot
.2782 .51663 Mdot
.34959 .53392 Mdot
.49539 .66129 Mdot
.5301 .71721 Mdot
.4372 .74275 Mdot
.54058 .33735 Mdot
.34192 .45373 Mdot
.3537 .46331 Mdot
.3292 .45198 Mdot
.6586 .46038 Mdot
.78101 .55707 Mdot
.53506 .33621 Mdot
.16838 .34615 Mdot
.54917 .36523 Mdot
.49405 .22533 Mdot
.49665 .69061 Mdot
.46683 .30195 Mdot
.40471 .49883 Mdot
.49053 .75036 Mdot
.4958 .64369 Mdot
.60688 .39562 Mdot
.43179 .31227 Mdot
.79126 .54992 Mdot
.6993 .47726 Mdot
.40118 .48928 Mdot
.33197 .52102 Mdot
.37182 .55524 Mdot
.41612 .54425 Mdot
.70363 .45705 Mdot
.42118 .54971 Mdot
.71741 .48225 Mdot
.24682 .62985 Mdot
.19589 .47077 Mdot
.59798 .37167 Mdot
.59446 .21639 Mdot
.51254 .71309 Mdot
.27867 .6076 Mdot
.29949 .70684 Mdot
.56944 .59238 Mdot
.65773 .51462 Mdot
.37345 .48078 Mdot
.57881 .37766 Mdot
.67768 .22701 Mdot
.59714 .37795 Mdot
.68776 .18747 Mdot
.24265 .51979 Mdot
.75972 .67528 Mdot
.40708 .55131 Mdot
.59179 .32943 Mdot
.35118 .76716 Mdot
.31473 .50794 Mdot
.46272 .27388 Mdot
.27885 .47943 Mdot
.6113 .77599 Mdot
.46899 .30724 Mdot
.37694 .49345 Mdot
.50982 .71693 Mdot
.40601 .51739 Mdot
.39332 .49185 Mdot
.34516 .52242 Mdot
.68428 .43862 Mdot
.33001 .52582 Mdot
.38866 .48725 Mdot
.26094 .72228 Mdot
.39384 .33794 Mdot
.59003 .37392 Mdot
.4234 .75468 Mdot
.44578 .30385 Mdot
.52992 .66379 Mdot
.56141 .44596 Mdot
.6877 .48191 Mdot
.43275 .73355 Mdot
.40627 .55355 Mdot
.66585 .72166 Mdot
.6452 .49191 Mdot
.45307 .29267 Mdot
.63623 .65835 Mdot
.79962 .5047 Mdot
.57741 .33082 Mdot
.65736 .6695 Mdot
.56956 .35519 Mdot
.40769 .78803 Mdot
.51074 .65564 Mdot
.36546 .471 Mdot
.66888 .49281 Mdot
.59463 .35128 Mdot
.38731 .25156 Mdot
.38675 .53256 Mdot
.57515 .33582 Mdot
.36188 .47382 Mdot
.57174 .52087 Mdot
.56721 .45801 Mdot
.58775 .3328 Mdot
.65356 .50275 Mdot
.68346 .45781 Mdot
.46195 .29147 Mdot
.53683 .6731 Mdot
.51661 .70593 Mdot
.68955 .46731 Mdot
.16939 .37471 Mdot
.36751 .50285 Mdot
.34186 .50805 Mdot
.59184 .58419 Mdot
.41182 .54503 Mdot
.38587 .34729 Mdot
.62737 .64996 Mdot
.53121 .68884 Mdot
.41609 .53916 Mdot
.3635 .54835 Mdot
.34255 .55315 Mdot
.2946 .32401 Mdot
.55701 .36227 Mdot
.39159 .56071 Mdot
.42469 .28705 Mdot
.59219 .69533 Mdot
.3614 .4916 Mdot
.31943 .50093 Mdot
.52144 .66569 Mdot
.3432 .2328 Mdot
.66185 .47231 Mdot
.55817 .33808 Mdot
.57301 .39471 Mdot
.27277 .39673 Mdot
.5458 .6739 Mdot
.63822 .65013 Mdot
.64765 .2934 Mdot
.62399 .66188 Mdot
.44589 .31997 Mdot
.53718 .41747 Mdot
.57128 .30875 Mdot
.57887 .38938 Mdot
.66514 .50744 Mdot
.41702 .5331 Mdot
.34271 .50307 Mdot
.62952 .72646 Mdot
.33897 .51804 Mdot
.42703 .30813 Mdot
.66909 .5027 Mdot
.51959 .66539 Mdot
.42041 .31869 Mdot
.65661 .4709 Mdot
.50693 .70579 Mdot
.32363 .53019 Mdot
.39083 .46571 Mdot
.51262 .67913 Mdot
.49489 .65402 Mdot
.35858 .51628 Mdot
.35514 .79878 Mdot
.52952 .69573 Mdot
.50391 .6631 Mdot
.65178 .6901 Mdot
.58258 .33301 Mdot
.37692 .59726 Mdot
.70155 .46627 Mdot
.41012 .51307 Mdot
.59862 .37032 Mdot
.46193 .3103 Mdot
.51856 .68378 Mdot
.34777 .55272 Mdot
.37798 .5044 Mdot
.44354 .31431 Mdot
.43741 .32961 Mdot
.42342 .30833 Mdot
.70632 .44701 Mdot
.41055 .55929 Mdot
.48366 .68886 Mdot
.70092 .47587 Mdot
.44686 .3257 Mdot
.43421 .27685 Mdot
.25447 .7104 Mdot
.35848 .5067 Mdot
.4584 .26566 Mdot
.12865 .62268 Mdot
.37395 .35545 Mdot
.65217 .66354 Mdot
.59906 .34546 Mdot
.349 .28549 Mdot
.41007 .32734 Mdot
.70803 .47225 Mdot
.42251 .38069 Mdot
.40863 .28802 Mdot
.33711 .52613 Mdot
.37598 .53786 Mdot
.43728 .5308 Mdot
.4461 .29702 Mdot
.28348 .34195 Mdot
.48623 .71022 Mdot
.33629 .66926 Mdot
.44571 .30369 Mdot
.58622 .33165 Mdot
.60166 .36495 Mdot
.5472 .36449 Mdot
.3793 .4799 Mdot
.44009 .76088 Mdot
.2376 .59142 Mdot
.31514 .70537 Mdot
.69742 .48008 Mdot
.52571 .71893 Mdot
.64025 .50852 Mdot
.51256 .68972 Mdot
.5657 .37481 Mdot
.45029 .29534 Mdot
.46943 .66399 Mdot
.67271 .45249 Mdot
.67782 .45493 Mdot
.52891 .35837 Mdot
.55216 .35607 Mdot
.54907 .3431 Mdot
.53813 .66928 Mdot
.49724 .69136 Mdot
.35728 .54813 Mdot
.51821 .67398 Mdot
.19248 .5655 Mdot
.45981 .32785 Mdot
.58193 .39887 Mdot
.66723 .47083 Mdot
.49577 .65778 Mdot
.40314 .52923 Mdot
.55151 .23572 Mdot
.60212 .39857 Mdot
.41876 .3047 Mdot
.63747 .5418 Mdot
.5713 .13879 Mdot
.32829 .50954 Mdot
.67269 .44426 Mdot
.54148 .61963 Mdot
.37922 .52879 Mdot
.58444 .35311 Mdot
.22555 .49845 Mdot
.6293 .65651 Mdot
.37492 .48645 Mdot
.41187 .48804 Mdot
.64894 .47718 Mdot
.56403 .45015 Mdot
.33992 .52416 Mdot
.50853 .45124 Mdot
.67615 .44071 Mdot
.53432 .3369 Mdot
.43786 .84967 Mdot
.74011 .4883 Mdot
.34698 .25941 Mdot
.64799 .66145 Mdot
.3354 .52718 Mdot
.56206 .34693 Mdot
.41733 .29855 Mdot
.55857 .35141 Mdot
.46303 .67723 Mdot
.58335 .3375 Mdot
.39099 .53679 Mdot
.48658 .69234 Mdot
.66602 .46045 Mdot
.48521 .46124 Mdot
.2964 .74987 Mdot
.59001 .38097 Mdot
.6158 .65923 Mdot
.36524 .49227 Mdot
.26672 .64704 Mdot
.42804 .46906 Mdot
.363 .48606 Mdot
.70368 .48055 Mdot
.49414 .66382 Mdot
.71257 .46358 Mdot
.32456 .50447 Mdot
.29061 .59355 Mdot
.67064 .48188 Mdot
.58147 .77797 Mdot
.4328 .32073 Mdot
.31051 .29732 Mdot
.3889 .51848 Mdot
.66987 .49268 Mdot
.4087 .56122 Mdot
.4781 .69706 Mdot
.55102 .53561 Mdot
.58086 .67381 Mdot
.67159 .49635 Mdot
.70363 .73076 Mdot
.55809 .47831 Mdot
.36147 .59054 Mdot
.66514 .48733 Mdot
.44159 .77563 Mdot
.63732 .67133 Mdot
.45436 .30906 Mdot
.43759 .32823 Mdot
.4416 .28051 Mdot
.33867 .51625 Mdot
.33119 .44479 Mdot
.42116 .28212 Mdot
.70868 .45029 Mdot
.41472 .29353 Mdot
.25359 .38018 Mdot
.70746 .69823 Mdot
.42176 .30994 Mdot
.39068 .51613 Mdot
.31904 .50734 Mdot
.392 .33485 Mdot
.5404 .32638 Mdot
.81669 .52314 Mdot
.22523 .64606 Mdot
.3539 .5035 Mdot
.25472 .53334 Mdot
.46823 .69541 Mdot
.49987 .57389 Mdot
.35822 .60455 Mdot
.58393 .43433 Mdot
.5019 .66019 Mdot
.58567 .52245 Mdot
.53362 .68546 Mdot
.34502 .48197 Mdot
.38622 .50464 Mdot
.49943 .64183 Mdot
.72255 .62414 Mdot
.5204 .80985 Mdot
.68692 .70946 Mdot
.51152 .70998 Mdot
.65916 .48241 Mdot
.67803 .44231 Mdot
.69913 .48414 Mdot
.54549 .33815 Mdot
.49663 .65146 Mdot
.38714 .56681 Mdot
.5814 .38401 Mdot
.40437 .50137 Mdot
.69151 .46204 Mdot
.59308 .62783 Mdot
.5192 .66432 Mdot
.37267 .51941 Mdot
.24928 .68317 Mdot
.56909 .3629 Mdot
.44509 .31179 Mdot
.65888 .55299 Mdot
.60181 .35242 Mdot
.65171 .45602 Mdot
.54714 .70988 Mdot
.53133 .39033 Mdot
.50248 .20762 Mdot
.4253 .5601 Mdot
.41985 .56228 Mdot
.6357 .38575 Mdot
.28179 .72698 Mdot
.34863 .52897 Mdot
.57839 .3881 Mdot
.58257 .33095 Mdot
.40828 .56348 Mdot
.47447 .66181 Mdot
.41153 .28822 Mdot
.45682 .28117 Mdot
.38504 .47208 Mdot
.58765 .55173 Mdot
.34059 .28433 Mdot
.37608 .5496 Mdot
.29273 .53233 Mdot
.5309 .32867 Mdot
.64437 .65737 Mdot
.57257 .56875 Mdot
.45484 .28444 Mdot
.38833 .49953 Mdot
.53856 .80471 Mdot
.51116 .6598 Mdot
.56385 .33376 Mdot
.68965 .45237 Mdot
.47239 .28122 Mdot
.55346 .39254 Mdot
.408 .56363 Mdot
.36425 .5483 Mdot
.65974 .49055 Mdot
.5582 .69888 Mdot
.44718 .2948 Mdot
.58387 .38098 Mdot
.46692 .30112 Mdot
.50126 .69641 Mdot
.50903 .66331 Mdot
.34906 .46473 Mdot
.42346 .46978 Mdot
.57917 .39223 Mdot
.42949 .50757 Mdot
.54596 .36786 Mdot
.61498 .24239 Mdot
.68445 .44836 Mdot
.42099 .50348 Mdot
.52448 .63958 Mdot
.69155 .46312 Mdot
.34955 .51113 Mdot
.6352 .38787 Mdot
.36451 .54289 Mdot
.58804 .32689 Mdot
.22043 .52285 Mdot
.4584 .29358 Mdot
.4485 .45255 Mdot
.46328 .56007 Mdot
.41118 .54475 Mdot
.55717 .3184 Mdot
.36073 .43868 Mdot
.67417 .481 Mdot
.49232 .68079 Mdot
.28389 .2564 Mdot
.67689 .46629 Mdot
.39845 .51092 Mdot
.43828 .29649 Mdot
.52624 .7074 Mdot
.64412 .68196 Mdot
.60243 .57532 Mdot
.35999 .58329 Mdot
.43653 .56134 Mdot
.4139 .52512 Mdot
.60382 .18929 Mdot
.55408 .34484 Mdot
.48963 .66182 Mdot
.68357 .44424 Mdot
.69237 .47463 Mdot
.56383 .36809 Mdot
.63947 .7626 Mdot
.7412 .63858 Mdot
.15515 .67198 Mdot
.56342 .39556 Mdot
.42304 .28459 Mdot
.5567 .5186 Mdot
.552 .37288 Mdot
.56241 .34201 Mdot
.5239 .34488 Mdot
.64824 .71722 Mdot
.50345 .70815 Mdot
.37697 .50283 Mdot
.54068 .66419 Mdot
.33529 .52519 Mdot
.38006 .24802 Mdot
.69236 .46848 Mdot
.49291 .68305 Mdot
.61305 .32142 Mdot
.44703 .57032 Mdot
.36692 .52886 Mdot
.4708 .26493 Mdot
.3704 .58236 Mdot
.34734 .33698 Mdot
.3832 .46417 Mdot
.56034 .3572 Mdot
.31457 .59431 Mdot
.30258 .51447 Mdot
.24107 .66383 Mdot
.67151 .45508 Mdot
.64582 .68431 Mdot
.32336 .53433 Mdot
.32016 .56668 Mdot
.52972 .70528 Mdot
.46962 .66205 Mdot
.41975 .28265 Mdot
.68327 .55373 Mdot
.66872 .45644 Mdot
.78379 .61258 Mdot
.35752 .48884 Mdot
.72185 .43755 Mdot
.21778 .52129 Mdot
.35171 .51527 Mdot
.54134 .41464 Mdot
.43392 .73578 Mdot
.35342 .53555 Mdot
.32591 .70438 Mdot
.67111 .47055 Mdot
.19189 .46584 Mdot
.41569 .48428 Mdot
.58351 .352 Mdot
.49164 .68876 Mdot
.48458 .71266 Mdot
.41729 .3081 Mdot
.1982 .60065 Mdot
.62288 .45473 Mdot
.49476 .68856 Mdot
.38904 .53018 Mdot
.66307 .47059 Mdot
.6495 .68303 Mdot
.41586 .58603 Mdot
.72929 .29972 Mdot
.51895 .67054 Mdot
.30676 .48685 Mdot
.68377 .71439 Mdot
.5723 .48286 Mdot
.82229 .5914 Mdot
.69288 .4897 Mdot
.45487 .28373 Mdot
.41557 .47313 Mdot
.64595 .29366 Mdot
.41204 .47927 Mdot
.36631 .25174 Mdot
.47163 .62317 Mdot
.46397 .31405 Mdot
.37839 .52608 Mdot
.34099 .52551 Mdot
.57123 .54267 Mdot
.44983 .32753 Mdot
.33967 .52477 Mdot
.3359 .46164 Mdot
.51099 .70418 Mdot
.62468 .65035 Mdot
.52201 .66995 Mdot
.39944 .52152 Mdot
.2412 .48758 Mdot
.4707 .6674 Mdot
.80796 .53294 Mdot
.44754 .34122 Mdot
.68699 .4825 Mdot
.29838 .5289 Mdot
.37469 .48276 Mdot
.8472 .44596 Mdot
.6543 .67999 Mdot
.3965 .20042 Mdot
.5938 .33458 Mdot
.56172 .83739 Mdot
.60362 .35777 Mdot
.74118 .69931 Mdot
.49905 .47984 Mdot
.43376 .52804 Mdot
.3775 .38713 Mdot
.31519 .69826 Mdot
.7038 .50254 Mdot
.27261 .62476 Mdot
.35883 .4892 Mdot
.37006 .49454 Mdot
.5684 .38546 Mdot
.65861 .74825 Mdot
.55544 .62922 Mdot
.57279 .5624 Mdot
.45458 .29625 Mdot
.50239 .68946 Mdot
.38494 .53661 Mdot
.69401 .59933 Mdot
.59421 .36451 Mdot
.31635 .42837 Mdot
.37542 .51844 Mdot
.56413 .62296 Mdot
.61488 .75926 Mdot
.66212 .46407 Mdot
.58352 .32684 Mdot
.56754 .31719 Mdot
.33718 .54018 Mdot
.7047 .46392 Mdot
.35342 .54212 Mdot
.55583 .48136 Mdot
.33063 .55988 Mdot
.45661 .31641 Mdot
.40944 .50179 Mdot
.40354 .39057 Mdot
.73887 .72595 Mdot
.31496 .54759 Mdot
.5377 .6923 Mdot
.54234 .34379 Mdot
.55563 .36596 Mdot
.51665 .70628 Mdot
.55631 .36702 Mdot
.34 .67748 Mdot
.25792 .57658 Mdot
.4493 .32002 Mdot
.29694 .71189 Mdot
.45832 .29746 Mdot
.64389 .6843 Mdot
.35727 .50965 Mdot
.67435 .30433 Mdot
.5633 .39594 Mdot
.22594 .41576 Mdot
.68579 .4702 Mdot
.65494 .67782 Mdot
.36177 .56759 Mdot
.43564 .25783 Mdot
.57123 .37782 Mdot
.7542 .43377 Mdot
.34289 .55196 Mdot
.48895 .70549 Mdot
.34913 .53292 Mdot
.37764 .57746 Mdot
.65502 .66555 Mdot
.4149 .5264 Mdot
.6566 .47111 Mdot
.49791 .65061 Mdot
.74372 .6909 Mdot
.54334 .33782 Mdot
.37599 .48903 Mdot
.38724 .52976 Mdot
.46946 .65756 Mdot
.35949 .56779 Mdot
.70686 .47165 Mdot
.38206 .88585 Mdot
.43652 .32126 Mdot
.6421 .65618 Mdot
.78266 .47787 Mdot
.39045 .54168 Mdot
.38224 .54784 Mdot
.63968 .42237 Mdot
.51672 .79606 Mdot
.66431 .48147 Mdot
.33657 .55961 Mdot
.5902 .3641 Mdot
.44442 .29179 Mdot
.70355 .48872 Mdot
.41353 .55739 Mdot
.36823 .49563 Mdot
.44982 .32108 Mdot
.46584 .26081 Mdot
.60679 .34271 Mdot
.69859 .48129 Mdot
.25922 .53352 Mdot
.56138 .2392 Mdot
.36931 .50784 Mdot
.68319 .66521 Mdot
.50159 .66625 Mdot
.67112 .48881 Mdot
.47825 .77031 Mdot
.35486 .47731 Mdot
.65071 .46271 Mdot
.66703 .45903 Mdot
.35002 .56251 Mdot
.54859 .68028 Mdot
.54341 .70163 Mdot
.50117 .66429 Mdot
.20265 .46512 Mdot
.48473 .18742 Mdot
.54946 .34149 Mdot
.6687 .46664 Mdot
.59922 .37479 Mdot
.42294 .27732 Mdot
.56722 .52289 Mdot
.58602 .33264 Mdot
.51081 .71414 Mdot
.59346 .38862 Mdot
.35876 .54347 Mdot
.68013 .45269 Mdot
.57008 .39274 Mdot
.39921 .54958 Mdot
.29101 .52089 Mdot
.39557 .39052 Mdot
.40785 .29508 Mdot
.58676 .52561 Mdot
.3993 .51532 Mdot
.63895 .65938 Mdot
.36223 .51669 Mdot
.7071 .46502 Mdot
.42999 .38888 Mdot
.39893 .55717 Mdot
.5661 .39663 Mdot
.51744 .20294 Mdot
.55739 .32017 Mdot
.37122 .57423 Mdot
.3989 .52043 Mdot
.36722 .50576 Mdot
.33591 .51285 Mdot
.5943 .78041 Mdot
.7172 .48511 Mdot
.29214 .49048 Mdot
.5427 .38298 Mdot
.51502 .68657 Mdot
.47201 .68663 Mdot
.60483 .42869 Mdot
.65818 .67816 Mdot
.70308 .46384 Mdot
.36804 .50449 Mdot
.75299 .43251 Mdot
.62324 .59124 Mdot
.68994 .71045 Mdot
.60062 .41586 Mdot
.57595 .38987 Mdot
.53969 .69132 Mdot
.54461 .37454 Mdot
.41495 .55823 Mdot
.38898 .46434 Mdot
.7557 .67858 Mdot
.70522 .44354 Mdot
.44865 .29541 Mdot
.40666 .50304 Mdot
.32789 .28058 Mdot
.58824 .37221 Mdot
.53349 .325 Mdot
.35216 .54341 Mdot
.52 .7276 Mdot
.79967 .66375 Mdot
.69796 .45675 Mdot
.26282 .64009 Mdot
.54349 .64026 Mdot
.27451 .50377 Mdot
.67694 .47808 Mdot
.51308 .40498 Mdot
.54155 .32879 Mdot
.216 .6323 Mdot
.51439 .67876 Mdot
.44976 .29841 Mdot
.32421 .47187 Mdot
.5117 .71408 Mdot
.60008 .38151 Mdot
.53174 .67071 Mdot
.3622 .4718 Mdot
.70754 .45181 Mdot
.55251 .36805 Mdot
.70649 .49757 Mdot
.50094 .64345 Mdot
.45824 .29549 Mdot
.23469 .4129 Mdot
.25661 .63619 Mdot
.43413 .73572 Mdot
.39085 .56111 Mdot
.70796 .32946 Mdot
.38301 .56737 Mdot
.53283 .71145 Mdot
.38941 .51822 Mdot
.44941 .44605 Mdot
.53173 .33568 Mdot
.30441 .50047 Mdot
.40192 .49382 Mdot
.23455 .63954 Mdot
.35624 .52346 Mdot
.37383 .56991 Mdot
.40054 .4774 Mdot
.5624 .67921 Mdot
.30694 .49755 Mdot
.48836 .70444 Mdot
.63758 .73063 Mdot
.56492 .34265 Mdot
.44694 .27578 Mdot
.47071 .29432 Mdot
.36251 .25127 Mdot
.31632 .29228 Mdot
.64506 .75567 Mdot
.52387 .68807 Mdot
.65314 .46723 Mdot
.35539 .54358 Mdot
.43639 .78401 Mdot
.27793 .43579 Mdot
.53803 .33272 Mdot
.58583 .39193 Mdot
.35848 .45947 Mdot
.67732 .21168 Mdot
.30638 .49416 Mdot
.60336 .5874 Mdot
.33599 .52023 Mdot
.41711 .49744 Mdot
.53554 .32106 Mdot
.27529 .34868 Mdot
.39185 .56071 Mdot
.52965 .70485 Mdot
.45156 .30517 Mdot
.27279 .55733 Mdot
.26324 .44166 Mdot
.27175 .47121 Mdot
.46895 .60634 Mdot
.41432 .55184 Mdot
.58463 .37481 Mdot
.51859 .71033 Mdot
.5833 .57821 Mdot
.70206 .47751 Mdot
.59486 .56304 Mdot
.24577 .61785 Mdot
.73662 .50514 Mdot
.45187 .29939 Mdot
.61142 .40035 Mdot
.39237 .53713 Mdot
.54607 .33863 Mdot
.33253 .49475 Mdot
.62808 .58794 Mdot
.46224 .31265 Mdot
.53086 .65855 Mdot
.65854 .48161 Mdot
.4961 .71176 Mdot
.42073 .76766 Mdot
.26985 .44589 Mdot
.56163 .83804 Mdot
.57259 .32922 Mdot
.41215 .62934 Mdot
.48419 .6751 Mdot
.35601 .56227 Mdot
.1512 .66283 Mdot
.50036 .67009 Mdot
.49659 .71048 Mdot
.57602 .43633 Mdot
.25068 .40161 Mdot
.30083 .50013 Mdot
.53267 .68094 Mdot
.54051 .39111 Mdot
.43204 .306 Mdot
.3919 .5511 Mdot
.37464 .47344 Mdot
.47078 .65962 Mdot
.5698 .3755 Mdot
.32895 .2745 Mdot
.55593 .35724 Mdot
.49776 .70562 Mdot
.57505 .35785 Mdot
.8019 .53608 Mdot
.59218 .35287 Mdot
.40195 .493 Mdot
.36898 .50518 Mdot
.68872 .27747 Mdot
.50908 .66336 Mdot
.38599 .54773 Mdot
.38222 .49895 Mdot
.48227 .68247 Mdot
.56193 .30668 Mdot
.44973 .73435 Mdot
.40235 .54544 Mdot
.37239 .50288 Mdot
.46503 .31529 Mdot
.57525 .50581 Mdot
.66203 .6105 Mdot
.39 .54985 Mdot
.43585 .28095 Mdot
.53907 .67101 Mdot
.36111 .51776 Mdot
.27503 .34642 Mdot
.60563 .37726 Mdot
.42245 .5412 Mdot
.63752 .68095 Mdot
.34585 .52445 Mdot
.79361 .66908 Mdot
.36944 .49168 Mdot
.48188 .66922 Mdot
.48759 .68261 Mdot
.61097 .36414 Mdot
.51011 .68698 Mdot
.65342 .66677 Mdot
.68638 .45994 Mdot
.68717 .74719 Mdot
.65376 .67062 Mdot
.41085 .49405 Mdot
.21073 .64486 Mdot
.37671 .47188 Mdot
.31452 .51369 Mdot
.23529 .40111 Mdot
.64964 .66403 Mdot
.4915 .66603 Mdot
.72335 .61917 Mdot
.43147 .52907 Mdot
.70105 .45938 Mdot
.31555 .50667 Mdot
.42288 .54077 Mdot
.41352 .40556 Mdot
.25873 .56713 Mdot
.67565 .50334 Mdot
.37718 .59638 Mdot
.39035 .55123 Mdot
.5093 .79279 Mdot
.39462 .53356 Mdot
.42057 .31064 Mdot
.52571 .69196 Mdot
.53893 .36899 Mdot
.44067 .31842 Mdot
.39021 .53925 Mdot
.44611 .29964 Mdot
.55177 .34001 Mdot
.68682 .49438 Mdot
.41217 .50597 Mdot
.46648 .32268 Mdot
.44967 .29366 Mdot
.35967 .5576 Mdot
.49282 .68663 Mdot
.4322 .47018 Mdot
.35894 .51792 Mdot
.39939 .56734 Mdot
.51687 .70567 Mdot
.14801 .52219 Mdot
.33245 .52572 Mdot
.51622 .4048 Mdot
.4836 .63577 Mdot
.64199 .65254 Mdot
.55453 .3808 Mdot
.43886 .50389 Mdot
.69576 .47315 Mdot
.6889 .46422 Mdot
.52953 .36549 Mdot
.48303 .64814 Mdot
.55566 .37068 Mdot
.38577 .59253 Mdot
.36284 .4586 Mdot
.32854 .46869 Mdot
.28594 .25491 Mdot
.79765 .49895 Mdot
.48398 .65885 Mdot
.54612 .32386 Mdot
.58668 .55766 Mdot
.69609 .45881 Mdot
.52134 .33981 Mdot
.50239 .632 Mdot
.51206 .65332 Mdot
.52141 .70553 Mdot
.44118 .28362 Mdot
.54817 .35804 Mdot
.46718 .63153 Mdot
.54351 .70724 Mdot
.35355 .54987 Mdot
.38997 .55205 Mdot
.47138 .70848 Mdot
.40812 .34757 Mdot
.46081 .30822 Mdot
.5856 .36482 Mdot
.87125 .51438 Mdot
.69774 .45622 Mdot
.23462 .64104 Mdot
.39988 .5489 Mdot
.09142 .4771 Mdot
.30816 .49259 Mdot
.39067 .53128 Mdot
.5225 .65496 Mdot
.4772 .30306 Mdot
.43484 .30431 Mdot
.4843 .67644 Mdot
.53547 .72142 Mdot
.42947 .28729 Mdot
.56698 .42774 Mdot
.68833 .76255 Mdot
.58506 .57111 Mdot
.47911 .67456 Mdot
.2622 .65291 Mdot
.69872 .49159 Mdot
.5049 .63846 Mdot
.69316 .5025 Mdot
.56371 .34112 Mdot
.59155 .38185 Mdot
.66034 .49231 Mdot
.35244 .56194 Mdot
.57789 .33476 Mdot
.33751 .57124 Mdot
.79226 .62586 Mdot
.76954 .35751 Mdot
.46208 .81639 Mdot
.3534 .48861 Mdot
.54973 .62122 Mdot
.60513 .72381 Mdot
.41244 .53179 Mdot
.41587 .59941 Mdot
.44766 .2966 Mdot
.49603 .63722 Mdot
.71018 .4857 Mdot
.82523 .52984 Mdot
.36877 .50687 Mdot
.49096 .70204 Mdot
.68761 .45427 Mdot
.79769 .53521 Mdot
.50842 .44936 Mdot
.34239 .53598 Mdot
.19827 .73686 Mdot
.50371 .64505 Mdot
.53871 .36839 Mdot
.27559 .70566 Mdot
.53487 .65613 Mdot
.55197 .228 Mdot
.57431 .31729 Mdot
.61911 .62603 Mdot
.5208 .65684 Mdot
.59113 .31772 Mdot
.5043 .69592 Mdot
.41458 .31391 Mdot
.54765 .7098 Mdot
.57131 .36804 Mdot
.36968 .5256 Mdot
.56821 .36663 Mdot
.43944 .32452 Mdot
.56252 .33086 Mdot
.70955 .48625 Mdot
.64516 .66002 Mdot
.68276 .45559 Mdot
.56432 .51861 Mdot
.40946 .65384 Mdot
.68533 .48975 Mdot
.74741 .41679 Mdot
.35405 .53208 Mdot
.55611 .70389 Mdot
.53549 .36594 Mdot
.56612 .40049 Mdot
.58922 .54045 Mdot
.49896 .70293 Mdot
.57654 .36676 Mdot
.25153 .61898 Mdot
.15438 .39524 Mdot
.30239 .53053 Mdot
.49966 .18606 Mdot
.48127 .68152 Mdot
.53132 .33438 Mdot
.59411 .58449 Mdot
.47601 .70211 Mdot
.57488 .39277 Mdot
.66204 .48632 Mdot
.69044 .47707 Mdot
.33874 .55079 Mdot
.65211 .44259 Mdot
.55488 .31804 Mdot
.53289 .80294 Mdot
.52433 .69699 Mdot
.78577 .49637 Mdot
.42138 .30292 Mdot
.55855 .34047 Mdot
.30199 .5019 Mdot
.45948 .62792 Mdot
.57721 .39612 Mdot
.72055 .27725 Mdot
.86596 .47713 Mdot
.57733 .36604 Mdot
.52613 .69046 Mdot
.51825 .68719 Mdot
.31226 .54256 Mdot
.5799 .55218 Mdot
.57365 .3747 Mdot
.67323 .30151 Mdot
.36854 .25687 Mdot
.64445 .67894 Mdot
.23967 .68588 Mdot
.39335 .56071 Mdot
.41617 .55021 Mdot
.7057 .47485 Mdot
.3656 .53045 Mdot
.53042 .72014 Mdot
.31287 .48489 Mdot
.68496 .44189 Mdot
.53552 .33648 Mdot
.36154 .50829 Mdot
.43683 .28939 Mdot
.70849 .47671 Mdot
.65296 .44977 Mdot
.573 .34966 Mdot
.52927 .6901 Mdot
.71039 .6306 Mdot
.55439 .3574 Mdot
.41039 .55787 Mdot
.64379 .66724 Mdot
.39106 .46741 Mdot
.6916 .28818 Mdot
.48873 .71167 Mdot
.54353 .37323 Mdot
.46848 .64982 Mdot
.67148 .46254 Mdot
.53575 .38281 Mdot
.40203 .53493 Mdot
.58385 .38921 Mdot
.50497 .39478 Mdot
.48959 .24821 Mdot
.54059 .71294 Mdot
.40527 .27649 Mdot
.46928 .66118 Mdot
.64435 .6794 Mdot
.30184 .3755 Mdot
.45614 .30952 Mdot
.58796 .34705 Mdot
.81199 .52625 Mdot
.53517 .36973 Mdot
.35318 .52113 Mdot
.34716 .50236 Mdot
.56604 .38509 Mdot
.45221 .28629 Mdot
.29163 .2995 Mdot
.40062 .25016 Mdot
.50713 .6558 Mdot
.50527 .50964 Mdot
.86342 .55451 Mdot
.51292 .34346 Mdot
.65199 .47154 Mdot
.32543 .58094 Mdot
.36703 .54129 Mdot
.64836 .47427 Mdot
.69025 .4486 Mdot
.44435 .32605 Mdot
.5492 .33733 Mdot
.47314 .63389 Mdot
.67975 .4978 Mdot
.44315 .64814 Mdot
.29736 .30926 Mdot
.3772 .58159 Mdot
.34667 .44514 Mdot
.38828 .48329 Mdot
.57312 .48473 Mdot
.70636 .45363 Mdot
.39355 .51181 Mdot
.37261 .45849 Mdot
.67268 .48732 Mdot
.43044 .32387 Mdot
.45387 .69465 Mdot
.58062 .35621 Mdot
.12564 .42725 Mdot
.41151 .50473 Mdot
.36469 .52319 Mdot
.69723 .48001 Mdot
.30194 .74602 Mdot
.47811 .66595 Mdot
.52996 .68519 Mdot
.55306 .34448 Mdot
.60225 .54189 Mdot
.38046 .57204 Mdot
.4093 .52539 Mdot
.58162 .34144 Mdot
.63965 .66017 Mdot
.42371 .82918 Mdot
.37973 .50623 Mdot
.67158 .47399 Mdot
.73359 .41049 Mdot
.70974 .4575 Mdot
.32839 .50732 Mdot
.34967 .51782 Mdot
.41543 .50515 Mdot
.3365 .50489 Mdot
.6633 .49633 Mdot
.41031 .5304 Mdot
.45327 .51615 Mdot
.49586 .66446 Mdot
.4066 .55615 Mdot
.35483 .26423 Mdot
.37671 .50841 Mdot
.43718 .29002 Mdot
.67145 .61457 Mdot
.37844 .49057 Mdot
.40895 .55555 Mdot
.40454 .24742 Mdot
.38421 .52601 Mdot
.66918 .45154 Mdot
.51663 .6809 Mdot
.66856 .46371 Mdot
.65829 .46245 Mdot
.58821 .39344 Mdot
.4222 .32459 Mdot
.4249 .49324 Mdot
.42842 .28637 Mdot
.32621 .55746 Mdot
.35402 .47675 Mdot
.57156 .51386 Mdot
.60442 .58753 Mdot
.40437 .32083 Mdot
.40514 .53097 Mdot
.55876 .34535 Mdot
.54932 .37911 Mdot
.42093 .37898 Mdot
.33909 .57043 Mdot
.70253 .49044 Mdot
.66962 .49247 Mdot
.38841 .35174 Mdot
.45397 .4222 Mdot
.44516 .28955 Mdot
.54255 .55589 Mdot
.374 .47622 Mdot
.38008 .49516 Mdot
.31819 .50772 Mdot
.59623 .34477 Mdot
.64358 .65817 Mdot
.53657 .33713 Mdot
.62793 .68369 Mdot
.71629 .47291 Mdot
.35423 .48818 Mdot
.77995 .38776 Mdot
.47876 .65415 Mdot
.51669 .67922 Mdot
.67802 .44117 Mdot
.55686 .31977 Mdot
.33566 .56625 Mdot
.31315 .21946 Mdot
.50022 .72221 Mdot
.45125 .27808 Mdot
.40556 .51893 Mdot
.56939 .34712 Mdot
.49563 .64933 Mdot
.41638 .32503 Mdot
.36025 .48414 Mdot
.52466 .32629 Mdot
.38376 .51437 Mdot
.33351 .72159 Mdot
.49211 .67147 Mdot
.59475 .62563 Mdot
.50474 .73032 Mdot
.65004 .47464 Mdot
.66056 .47673 Mdot
.34924 .51238 Mdot
.22067 .29838 Mdot
.46984 .71459 Mdot
.64723 .483 Mdot
.41003 .30696 Mdot
.63791 .65638 Mdot
.41195 .31577 Mdot
.54748 .36997 Mdot
.45267 .30373 Mdot
.57195 .3951 Mdot
.41765 .35919 Mdot
.45817 .67295 Mdot
.43987 .32033 Mdot
.30791 .75501 Mdot
.39336 .46618 Mdot
.45204 .32459 Mdot
.35532 .45988 Mdot
.46625 .50741 Mdot
.57783 .3398 Mdot
.44486 .2857 Mdot
.349 .5537 Mdot
.79486 .46029 Mdot
.6579 .46932 Mdot
.70489 .48953 Mdot
.41682 .4834 Mdot
.52681 .33759 Mdot
.54279 .71307 Mdot
.54762 .44379 Mdot
.63852 .65167 Mdot
.40873 .52532 Mdot
.36405 .48032 Mdot
.48086 .64296 Mdot
.52771 .71124 Mdot
.34748 .51425 Mdot
.25529 .61313 Mdot
.39406 .53784 Mdot
.68704 .47894 Mdot
.49978 .65223 Mdot
.51863 .68246 Mdot
.57606 .32235 Mdot
.48233 .64863 Mdot
.32763 .45605 Mdot
.64352 .50197 Mdot
.33554 .47357 Mdot
.67466 .46349 Mdot
.43967 .38603 Mdot
.54814 .33522 Mdot
.81686 .51929 Mdot
.49134 .6476 Mdot
.41698 .53808 Mdot
.47162 .68258 Mdot
.42394 .30844 Mdot
.5108 .66409 Mdot
.46773 .69693 Mdot
.35508 .49261 Mdot
.33671 .52924 Mdot
.6407 .66283 Mdot
.58512 .54989 Mdot
.4948 .67732 Mdot
.40416 .54131 Mdot
.41285 .48326 Mdot
.33331 .53328 Mdot
.55935 .47722 Mdot
.53026 .66235 Mdot
.23251 .56241 Mdot
.72886 .31458 Mdot
.49464 .68487 Mdot
.84043 .55976 Mdot
.62208 .66565 Mdot
.65839 .67911 Mdot
.64442 .48268 Mdot
.37582 .50284 Mdot
.55871 .37027 Mdot
.42021 .54609 Mdot
.34438 .57536 Mdot
.38012 .4892 Mdot
.45455 .3199 Mdot
.43103 .55574 Mdot
.62915 .67203 Mdot
.55934 .36031 Mdot
.39743 .54282 Mdot
.36235 .50386 Mdot
.65549 .68378 Mdot
.49626 .72926 Mdot
.51266 .65418 Mdot
.67579 .64681 Mdot
.42743 .32119 Mdot
.70346 .47925 Mdot
.41774 .55152 Mdot
.55621 .3453 Mdot
.56245 .36728 Mdot
.49593 .71113 Mdot
.58374 .35635 Mdot
.7101 .46944 Mdot
.38827 .53365 Mdot
.64975 .47827 Mdot
.45373 .32025 Mdot
.52544 .69267 Mdot
.41577 .55594 Mdot
.3516 .5501 Mdot
.48755 .68222 Mdot
.35031 .52997 Mdot
.46559 .31375 Mdot
.5964 .35629 Mdot
.49859 .65524 Mdot
.68658 .46084 Mdot
.58122 .32614 Mdot
.36145 .54579 Mdot
.8256 .37189 Mdot
.36563 .53114 Mdot
.41405 .51577 Mdot
.71085 .73089 Mdot
.37696 .46428 Mdot
.53144 .35108 Mdot
.47023 .68103 Mdot
.32668 .51489 Mdot
.38036 .25211 Mdot
.57275 .28993 Mdot
.52503 .32069 Mdot
.4074 .51852 Mdot
.82597 .56565 Mdot
.41532 .54115 Mdot
.80074 .55904 Mdot
.57183 .51574 Mdot
.61984 .20276 Mdot
.36115 .4442 Mdot
.64673 .47964 Mdot
.64212 .66124 Mdot
.5307 .35927 Mdot
.38062 .76521 Mdot
.35691 .53042 Mdot
.45485 .77049 Mdot
.42146 .54886 Mdot
.67988 .47828 Mdot
.3986 .60395 Mdot
.58539 .36266 Mdot
.2274 .65264 Mdot
.39424 .56638 Mdot
.52185 .65563 Mdot
.55641 .40014 Mdot
.63077 .65741 Mdot
.34704 .55329 Mdot
.42155 .29537 Mdot
.59715 .31008 Mdot
.34828 .45122 Mdot
.67646 .46203 Mdot
.38473 .49831 Mdot
.33934 .58419 Mdot
.17358 .37375 Mdot
.49664 .6617 Mdot
.65359 .47655 Mdot
.48947 .58496 Mdot
.33936 .51026 Mdot
.51453 .65497 Mdot
.51464 .68177 Mdot
.41551 .3024 Mdot
.62858 .57477 Mdot
.5367 .28717 Mdot
.77587 .3424 Mdot
.431 .748 Mdot
.59318 .33512 Mdot
.55171 .77459 Mdot
.38998 .55669 Mdot
.26422 .45244 Mdot
.6624 .45799 Mdot
.36846 .52417 Mdot
.41152 .70289 Mdot
.50322 .66279 Mdot
.38609 .51134 Mdot
.46008 .31007 Mdot
.64018 .7012 Mdot
.26579 .4988 Mdot
.83495 .42879 Mdot
.52576 .36985 Mdot
.31621 .4949 Mdot
.37699 .45085 Mdot
.64321 .6533 Mdot
.33038 .50409 Mdot
.533 .36114 Mdot
.71746 .33914 Mdot
.45793 .28998 Mdot
.48199 .65228 Mdot
.62223 .66272 Mdot
.42624 .54113 Mdot
.38279 .46907 Mdot
.44389 .27563 Mdot
.366 .56525 Mdot
.2578 .68223 Mdot
.66683 .68085 Mdot
.59273 .35287 Mdot
.53326 .67505 Mdot
.38598 .48215 Mdot
.64064 .65818 Mdot
.35225 .49531 Mdot
.47059 .504 Mdot
.40706 .51293 Mdot
.65157 .76806 Mdot
.49244 .68993 Mdot
.67707 .45868 Mdot
.43726 .54732 Mdot
.37229 .51308 Mdot
.5639 .24174 Mdot
.34817 .57745 Mdot
.36875 .49254 Mdot
.5168 .71521 Mdot
.47286 .6619 Mdot
.49876 .70886 Mdot
.58961 .34444 Mdot
.57954 .56865 Mdot
.68334 .47336 Mdot
.31575 .52881 Mdot
.6918 .49497 Mdot
.42493 .44776 Mdot
.43635 .27752 Mdot
.82432 .49005 Mdot
.37761 .53698 Mdot
.51157 .70753 Mdot
.55332 .79365 Mdot
.53941 .67133 Mdot
.65541 .4346 Mdot
.66949 .45568 Mdot
.49934 .6727 Mdot
.39102 .52598 Mdot
.57187 .56096 Mdot
.81953 .38424 Mdot
.69516 .45922 Mdot
.32816 .4894 Mdot
.52983 .37932 Mdot
.55716 .39593 Mdot
.82741 .61779 Mdot
.65693 .45959 Mdot
.60253 .72407 Mdot
.40837 .54371 Mdot
.47634 .65418 Mdot
.692 .48836 Mdot
.66918 .45014 Mdot
.58373 .34625 Mdot
.3452 .53956 Mdot
.37552 .51297 Mdot
.63426 .67973 Mdot
.68331 .49572 Mdot
.43693 .57049 Mdot
.34279 .53193 Mdot
.74309 .69501 Mdot
.49325 .63001 Mdot
.146 .53644 Mdot
.38137 .59302 Mdot
.41586 .70159 Mdot
.48624 .42953 Mdot
.48813 .65503 Mdot
.38149 .56976 Mdot
.31697 .53426 Mdot
.58894 .33 Mdot
.38136 .53329 Mdot
.55286 .32577 Mdot
.65188 .46696 Mdot
.83047 .49211 Mdot
.74494 .43367 Mdot
.65662 .51468 Mdot
.36102 .52759 Mdot
.27471 .48539 Mdot
.43196 .31537 Mdot
.71685 .45332 Mdot
.48037 .69367 Mdot
.38553 .47924 Mdot
.58594 .32154 Mdot
.59014 .35261 Mdot
.51039 .67526 Mdot
.60971 .7413 Mdot
.80809 .53427 Mdot
.33796 .50146 Mdot
.55036 .37591 Mdot
.75911 .45264 Mdot
.27562 .61188 Mdot
.64491 .46517 Mdot
.46008 .29315 Mdot
.53361 .34472 Mdot
.67825 .43804 Mdot
.46392 .48323 Mdot
.50497 .68068 Mdot
.48996 .64297 Mdot
.60417 .26105 Mdot
.57198 .37206 Mdot
.44012 .31423 Mdot
.47558 .43636 Mdot
.48155 .45131 Mdot
.46172 .31214 Mdot
.53716 .33305 Mdot
.48024 .6559 Mdot
.49349 .70361 Mdot
.51655 .68306 Mdot
.24139 .66477 Mdot
.48497 .71132 Mdot
.18864 .51947 Mdot
.35707 .47997 Mdot
.26923 .64975 Mdot
.41561 .53278 Mdot
.67468 .50012 Mdot
.49134 .67324 Mdot
.56983 .52827 Mdot
.40512 .48449 Mdot
.82837 .41483 Mdot
.40071 .51582 Mdot
.62249 .42108 Mdot
.37394 .50228 Mdot
.28772 .70719 Mdot
.4855 .63558 Mdot
.40593 .53247 Mdot
.64414 .49629 Mdot
.44354 .29441 Mdot
.48299 .72629 Mdot
.37329 .49301 Mdot
.67485 .71893 Mdot
.36363 .45985 Mdot
.81061 .58564 Mdot
.49977 .20931 Mdot
.46897 .28708 Mdot
.33398 .4679 Mdot
.59062 .39639 Mdot
.45898 .60734 Mdot
.27593 .66816 Mdot
.69453 .45925 Mdot
.24691 .54853 Mdot
.58439 .3416 Mdot
.41486 .59906 Mdot
.40262 .57719 Mdot
.45276 .28453 Mdot
.46245 .70653 Mdot
.68558 .48055 Mdot
.35796 .53273 Mdot
.37142 .56906 Mdot
.69027 .25578 Mdot
.2746 .67399 Mdot
.43912 .56316 Mdot
.419 .28081 Mdot
.2423 .56807 Mdot
.38459 .49207 Mdot
.52649 .32003 Mdot
.47076 .68878 Mdot
.30754 .47777 Mdot
.22913 .56379 Mdot
.40028 .54082 Mdot
.50249 .6719 Mdot
.48958 .64721 Mdot
.59581 .80222 Mdot
.43786 .27844 Mdot
.40672 .51251 Mdot
.58202 .24007 Mdot
.41181 .55756 Mdot
.68479 .47601 Mdot
.32757 .50567 Mdot
.56595 .33764 Mdot
.59616 .58977 Mdot
.58852 .34127 Mdot
.33828 .5438 Mdot
.51037 .6999 Mdot
.68968 .48209 Mdot
.63475 .26706 Mdot
.59249 .4463 Mdot
.18929 .5143 Mdot
.59276 .30667 Mdot
.43367 .28749 Mdot
.41798 .32408 Mdot
.63041 .4863 Mdot
.40191 .52363 Mdot
.5685 .4638 Mdot
.30855 .52188 Mdot
.37238 .49864 Mdot
.40426 .4988 Mdot
.72908 .48845 Mdot
.67213 .45578 Mdot
.57393 .36206 Mdot
.34716 .51555 Mdot
.40511 .54089 Mdot
.49856 .68692 Mdot
.44968 .29317 Mdot
.59571 .36241 Mdot
.42673 .31898 Mdot
.56021 .35533 Mdot
.80617 .65237 Mdot
.32521 .50483 Mdot
.4421 .29462 Mdot
.71043 .45639 Mdot
.50946 .71022 Mdot
.65319 .68266 Mdot
.54779 .36941 Mdot
.5841 .36573 Mdot
.41125 .53044 Mdot
.52734 .67654 Mdot
.52144 .66254 Mdot
.431 .28695 Mdot
.67593 .49321 Mdot
.33708 .55109 Mdot
.33875 .52931 Mdot
.5997 .21605 Mdot
.58951 .33352 Mdot
.2459 .59923 Mdot
.60948 .78199 Mdot
.40247 .52488 Mdot
.52051 .65969 Mdot
.36191 .51188 Mdot
.7675 .40219 Mdot
.51444 .71267 Mdot
.41315 .48678 Mdot
.41223 .40878 Mdot
.59694 .34899 Mdot
.58757 .81992 Mdot
.43553 .51759 Mdot
.64782 .42396 Mdot
.37277 .55967 Mdot
.63706 .82941 Mdot
.5274 .7869 Mdot
.42323 .54773 Mdot
.33923 .50214 Mdot
.77068 .32032 Mdot
.41072 .54605 Mdot
.62815 .6736 Mdot
.37437 .58937 Mdot
.5139 .65397 Mdot
.50432 .43398 Mdot
.5842 .51496 Mdot
.42183 .28483 Mdot
.55278 .34376 Mdot
.2736 .37557 Mdot
.42052 .31969 Mdot
.48112 .67333 Mdot
.38967 .47339 Mdot
.43964 .68534 Mdot
.60836 .3798 Mdot
.35899 .57309 Mdot
.68345 .47691 Mdot
.58525 .51771 Mdot
.53956 .33627 Mdot
.68496 .45881 Mdot
.42438 .52413 Mdot
.38886 .21145 Mdot
.60418 .45602 Mdot
.63586 .79897 Mdot
.69854 .48101 Mdot
.66335 .46334 Mdot
.57516 .58306 Mdot
.42159 .28518 Mdot
.6662 .23968 Mdot
.27406 .54489 Mdot
.69746 .4572 Mdot
.34546 .35037 Mdot
.55072 .31546 Mdot
.62112 .57955 Mdot
.49737 .63659 Mdot
.32366 .50837 Mdot
.38725 .52294 Mdot
.67478 .49021 Mdot
.50116 .76515 Mdot
.48549 .53179 Mdot
.68644 .45601 Mdot
.39886 .45632 Mdot
.62665 .58327 Mdot
.64624 .6652 Mdot
.62457 .67302 Mdot
.41131 .29776 Mdot
.48834 .26666 Mdot
.49711 .69778 Mdot
.46593 .29295 Mdot
.61545 .64289 Mdot
.40318 .50833 Mdot
.68327 .49617 Mdot
.64524 .68536 Mdot
.68798 .46578 Mdot
.43472 .29955 Mdot
.44655 .27751 Mdot
.49598 .66388 Mdot
.47708 .66727 Mdot
.2992 .59719 Mdot
.36888 .32843 Mdot
.4101 .55117 Mdot
.45107 .73966 Mdot
.50875 .71277 Mdot
.35061 .76972 Mdot
.42847 .2842 Mdot
.45551 .29603 Mdot
.31478 .67295 Mdot
.35625 .54694 Mdot
.72733 .41696 Mdot
.37798 .49133 Mdot
.3099 .37946 Mdot
.43029 .52592 Mdot
.58361 .34898 Mdot
.39678 .56314 Mdot
.70283 .61131 Mdot
.38788 .54442 Mdot
.39244 .49054 Mdot
.54711 .36243 Mdot
.43717 .55193 Mdot
.56943 .33652 Mdot
.33257 .52349 Mdot
.47748 .29386 Mdot
.556 .3455 Mdot
.39132 .25413 Mdot
.51621 .41053 Mdot
.63343 .66191 Mdot
.41118 .30834 Mdot
.42347 .29414 Mdot
.35095 .26085 Mdot
.47635 .68482 Mdot
.46228 .47203 Mdot
.40078 .52211 Mdot
.53143 .3282 Mdot
.706 .48119 Mdot
.40115 .54006 Mdot
.30971 .49087 Mdot
.43516 .51307 Mdot
.49906 .66672 Mdot
.53586 .33254 Mdot
.44233 .30072 Mdot
.55543 .38385 Mdot
.46764 .26998 Mdot
.54844 .3863 Mdot
.29617 .54504 Mdot
.403 .59338 Mdot
.45039 .48836 Mdot
.43381 .72649 Mdot
.21114 .626 Mdot
.50848 .68049 Mdot
.64029 .67217 Mdot
.43216 .27779 Mdot
.50266 .5078 Mdot
.51031 .70566 Mdot
.58191 .37043 Mdot
.38387 .51451 Mdot
.40719 .45856 Mdot
.27118 .51735 Mdot
.46555 .62869 Mdot
.37325 .28945 Mdot
.54281 .34905 Mdot
.65044 .67471 Mdot
.5913 .57425 Mdot
.5527 .65764 Mdot
.56542 .52363 Mdot
.36681 .51199 Mdot
.42404 .29079 Mdot
.49552 .64934 Mdot
.67702 .26942 Mdot
.66689 .48828 Mdot
.58257 .55145 Mdot
.36369 .52878 Mdot
.57145 .75669 Mdot
.51055 .69955 Mdot
.45941 .29955 Mdot
.67488 .48987 Mdot
.43247 .28052 Mdot
.62159 .6596 Mdot
.67455 .62991 Mdot
.35708 .56049 Mdot
.36797 .49189 Mdot
.715 .47492 Mdot
.49933 .699 Mdot
.61278 .35416 Mdot
.70544 .27584 Mdot
.55402 .3779 Mdot
.58005 .4749 Mdot
.49679 .65067 Mdot
.55243 .75155 Mdot
.58009 .38941 Mdot
.70578 .44805 Mdot
.56835 .47032 Mdot
.67977 .44196 Mdot
.39069 .49202 Mdot
.52352 .68353 Mdot
.65673 .45941 Mdot
.61969 .25121 Mdot
.79294 .65048 Mdot
.44972 .67239 Mdot
.34341 .52056 Mdot
.82625 .48791 Mdot
.72759 .68289 Mdot
.48691 .74916 Mdot
.67043 .49767 Mdot
.35327 .51373 Mdot
.34017 .49834 Mdot
.39597 .5657 Mdot
.65645 .47574 Mdot
.61198 .43327 Mdot
.58725 .36839 Mdot
.39408 .50966 Mdot
.42181 .30332 Mdot
.57166 .34148 Mdot
.58333 .39951 Mdot
.53161 .36205 Mdot
.51519 .71324 Mdot
.36852 .47469 Mdot
.58724 .64246 Mdot
.672 .80088 Mdot
.67016 .45903 Mdot
.63309 .66209 Mdot
.41348 .50508 Mdot
.19441 .45675 Mdot
.50119 .70915 Mdot
.5573 .37912 Mdot
.3665 .52314 Mdot
.52139 .21971 Mdot
.67462 .67546 Mdot
.54989 .35579 Mdot
.48074 .69306 Mdot
.48462 .74708 Mdot
.38253 .53379 Mdot
.37197 .55826 Mdot
.48736 .69223 Mdot
.68877 .69974 Mdot
.60248 .58238 Mdot
.36259 .50975 Mdot
.6793 .45787 Mdot
.1653 .37096 Mdot
.39547 .47077 Mdot
.46624 .62401 Mdot
.64093 .6562 Mdot
.65077 .76075 Mdot
.24929 .59616 Mdot
.29937 .52994 Mdot
.81135 .44716 Mdot
.25666 .37731 Mdot
.83358 .50823 Mdot
.26616 .40994 Mdot
.76497 .46975 Mdot
.75365 .72483 Mdot
.6417 .4893 Mdot
.29801 .71411 Mdot
.68763 .23051 Mdot
.61943 .71849 Mdot
.46202 .22134 Mdot
.6581 .30904 Mdot
.52541 .21257 Mdot
.3292 .78637 Mdot
.55469 .39105 Mdot
.29486 .4054 Mdot
.35307 .56331 Mdot
.72161 .67777 Mdot
.24678 .63848 Mdot
.19714 .60424 Mdot
.82086 .49482 Mdot
.56587 .23315 Mdot
.80549 .34025 Mdot
.81142 .51418 Mdot
.34997 .61342 Mdot
.31113 .43328 Mdot
.49878 .28458 Mdot
.47689 .44176 Mdot
.26476 .38479 Mdot
.34571 .4398 Mdot
.70082 .59677 Mdot
.66534 .51321 Mdot
.37027 .63329 Mdot
.15951 .40638 Mdot
.53508 .35672 Mdot
.47095 .69069 Mdot
.65593 .23015 Mdot
.46185 .61751 Mdot
.62684 .45582 Mdot
.81159 .44673 Mdot
.74286 .69979 Mdot
.28402 .70259 Mdot
.60551 .63349 Mdot
.34149 .71585 Mdot
.28716 .29774 Mdot
.29798 .43519 Mdot
.5456 .68075 Mdot
.66861 .37361 Mdot
.48039 .45047 Mdot
.49253 .2988 Mdot
.30462 .73147 Mdot
.41908 .32759 Mdot
.3886 .25396 Mdot
.48565 .69813 Mdot
.28179 .61018 Mdot
.66053 .67626 Mdot
.60402 .65259 Mdot
.57607 .31374 Mdot
.76132 .38836 Mdot
.67388 .69887 Mdot
.66499 .71397 Mdot
.50811 .8167 Mdot
.84272 .41099 Mdot
.31295 .32137 Mdot
.70546 .31894 Mdot
.63889 .43252 Mdot
.26858 .35935 Mdot
.57445 .61719 Mdot
.34922 .31618 Mdot
.45047 .43943 Mdot
.73642 .23935 Mdot
.69899 .71403 Mdot
.79123 .30734 Mdot
.55066 .70844 Mdot
.4213 .48078 Mdot
.7297 .33766 Mdot
.42542 .75631 Mdot
.47999 .31448 Mdot
.84117 .4206 Mdot
.46171 .28492 Mdot
.46946 .63792 Mdot
.61561 .72089 Mdot
.25149 .66791 Mdot
.61707 .36084 Mdot
.42793 .34064 Mdot
.31556 .47053 Mdot
.70614 .19794 Mdot
.81174 .43243 Mdot
.6113 .79218 Mdot
.73675 .70044 Mdot
.51358 .33641 Mdot
.59932 .39439 Mdot
.65207 .46247 Mdot
.7691 .69002 Mdot
.51836 .69435 Mdot
.67695 .80105 Mdot
.76542 .68693 Mdot
.49211 .607 Mdot
.69085 .18331 Mdot
.41645 .82212 Mdot
.26472 .64059 Mdot
.22746 .49539 Mdot
.45679 .19245 Mdot
.56658 .59633 Mdot
.55785 .74514 Mdot
.52112 .3709 Mdot
.68468 .74618 Mdot
.81254 .63245 Mdot
.35074 .35766 Mdot
.72922 .51343 Mdot
.59053 .66887 Mdot
.43213 .38342 Mdot
.45484 .66228 Mdot
.43543 .22218 Mdot
.41337 .38471 Mdot
.80113 .32508 Mdot
.24306 .55544 Mdot
.25364 .2702 Mdot
.27679 .39653 Mdot
.295 .73919 Mdot
.7874 .47857 Mdot
.466 .34835 Mdot
.47589 .50972 Mdot
.64493 .73376 Mdot
.33899 .47667 Mdot
.54539 .56341 Mdot
.44764 .58124 Mdot
.44243 .26551 Mdot
.57848 .57558 Mdot
.7775 .60403 Mdot
.29171 .37838 Mdot
.76311 .33893 Mdot
.32283 .4301 Mdot
.5356 .68498 Mdot
.34126 .30555 Mdot
.32103 .34415 Mdot
.75667 .67466 Mdot
.49089 .58624 Mdot
.65168 .78269 Mdot
.48636 .57584 Mdot
.30694 .51443 Mdot
.30731 .72144 Mdot
.36977 .43772 Mdot
.34183 .33794 Mdot
.43474 .52466 Mdot
.52122 .81407 Mdot
.71435 .7241 Mdot
.41034 .66991 Mdot
.28845 .35991 Mdot
.42892 .7101 Mdot
.6889 .74609 Mdot
.73478 .33843 Mdot
.56882 .7396 Mdot
.52647 .77169 Mdot
.71588 .20985 Mdot
.57703 .35146 Mdot
.35548 .34662 Mdot
.72519 .48014 Mdot
.62655 .26225 Mdot
.66608 .21559 Mdot
.48412 .55672 Mdot
.71103 .73873 Mdot
.64002 .71909 Mdot
.61181 .38632 Mdot
.67361 .56946 Mdot
.7412 .48145 Mdot
.42885 .68437 Mdot
.42599 .49299 Mdot
.45967 .57344 Mdot
.46783 .31139 Mdot
.40013 .75458 Mdot
.71968 .3117 Mdot
.63107 .33108 Mdot
.29488 .52407 Mdot
.64398 .35774 Mdot
.64804 .67928 Mdot
.59626 .55048 Mdot
.82257 .63342 Mdot
.34169 .5804 Mdot
.39091 .8115 Mdot
.69554 .70222 Mdot
.57499 .48566 Mdot
.46349 .25853 Mdot
.58515 .78035 Mdot
.77217 .27632 Mdot
.73514 .7287 Mdot
.74832 .64669 Mdot
.82476 .48115 Mdot
.48102 .86323 Mdot
.62189 .19019 Mdot
.43247 .78756 Mdot
.72345 .48352 Mdot
.35624 .8679 Mdot
.56956 .38952 Mdot
.22649 .51589 Mdot
.4231 .75333 Mdot
.52189 .22648 Mdot
.4576 .61835 Mdot
.31146 .44722 Mdot
.53606 .30134 Mdot
.48073 .71858 Mdot
.30961 .48165 Mdot
.85535 .46663 Mdot
.74188 .24138 Mdot
.85343 .45092 Mdot
.67829 .6319 Mdot
.84057 .50726 Mdot
.74757 .27484 Mdot
.18806 .52549 Mdot
.68089 .24406 Mdot
.32778 .50625 Mdot
.38022 .36074 Mdot
.43064 .8201 Mdot
.59825 .32283 Mdot
.59597 .6474 Mdot
.52957 .64479 Mdot
.72572 .2384 Mdot
.82757 .62788 Mdot
.33702 .6784 Mdot
.30992 .61401 Mdot
.49697 .40194 Mdot
.35789 .3281 Mdot
.43519 .63153 Mdot
.70808 .58633 Mdot
.78999 .63316 Mdot
.73746 .26427 Mdot
.31433 .35543 Mdot
.66023 .32351 Mdot
.75081 .63079 Mdot
.43346 .80837 Mdot
.79492 .46837 Mdot
.64991 .22486 Mdot
.4782 .59808 Mdot
.55959 .71587 Mdot
.485 .53699 Mdot
.69285 .58667 Mdot
.73572 .38091 Mdot
.29643 .33019 Mdot
.56296 .33011 Mdot
.35953 .35636 Mdot
.53647 .49164 Mdot
.67833 .24011 Mdot
.28425 .33145 Mdot
.34588 .36345 Mdot
.7657 .62941 Mdot
.85075 .47765 Mdot
.68534 .70557 Mdot
.42039 .19678 Mdot
.76851 .5152 Mdot
.43991 .59476 Mdot
.44462 .51935 Mdot
.70243 .74076 Mdot
.86154 .51704 Mdot
.71609 .73701 Mdot
.56629 .76167 Mdot
.60297 .25394 Mdot
.65471 .44188 Mdot
.27603 .33354 Mdot
.63534 .36783 Mdot
.79657 .62898 Mdot
.51711 .52007 Mdot
.64995 .44153 Mdot
.62751 .70084 Mdot
.30604 .59812 Mdot
.23207 .41343 Mdot
.34605 .63572 Mdot
.34692 .5724 Mdot
.27208 .62477 Mdot
.47209 .64809 Mdot
.56376 .75994 Mdot
.35096 .32355 Mdot
.57349 .34903 Mdot
.57652 .19904 Mdot
.44452 .63233 Mdot
.39217 .46415 Mdot
.72002 .34847 Mdot
.45424 .66726 Mdot
.42938 .72375 Mdot
.59037 .40452 Mdot
.77274 .69911 Mdot
.48903 .80909 Mdot
.43185 .64382 Mdot
.32598 .30942 Mdot
.59994 .22112 Mdot
.60644 .57409 Mdot
.71638 .49073 Mdot
.81693 .49855 Mdot
.52597 .42126 Mdot
.33635 .31174 Mdot
.26582 .61876 Mdot
.70732 .2858 Mdot
.3116 .51985 Mdot
.58366 .79664 Mdot
.1939 .49996 Mdot
.59934 .54771 Mdot
.49211 .62297 Mdot
.49491 .71936 Mdot
.24983 .72791 Mdot
.71453 .61239 Mdot
.54112 .62706 Mdot
.80531 .47693 Mdot
.65771 .45104 Mdot
.53265 .70388 Mdot
.34998 .36815 Mdot
.49741 .25122 Mdot
.26667 .58284 Mdot
.74368 .38611 Mdot
.37452 .61615 Mdot
.64524 .41879 Mdot
.81884 .47626 Mdot
.80945 .38786 Mdot
.1819 .35381 Mdot
.50994 .72848 Mdot
.68196 .28673 Mdot
.67705 .28073 Mdot
.54393 .67789 Mdot
.46599 .62695 Mdot
.27128 .48914 Mdot
.84221 .53571 Mdot
.51111 .49659 Mdot
.69638 .57609 Mdot
.56983 .4704 Mdot
.46399 .22639 Mdot
.68753 .26738 Mdot
.27644 .35746 Mdot
.79156 .45245 Mdot
.32072 .62834 Mdot
.50097 .17293 Mdot
.45511 .50151 Mdot
.22373 .52418 Mdot
.27593 .33337 Mdot
.34702 .40708 Mdot
.31254 .73778 Mdot
.7934 .58447 Mdot
.4118 .55542 Mdot
.85146 .42663 Mdot
.75506 .66789 Mdot
.54076 .56607 Mdot
.50248 .33151 Mdot
.37842 .54894 Mdot
.36481 .47559 Mdot
.50609 .77287 Mdot
.63051 .77314 Mdot
.56412 .16484 Mdot
.28897 .39181 Mdot
.43578 .6009 Mdot
.26102 .61926 Mdot
.39163 .81144 Mdot
.74116 .35642 Mdot
.81521 .55474 Mdot
.53444 .50796 Mdot
.44108 .81909 Mdot
.69135 .55103 Mdot
.67506 .58023 Mdot
.77346 .50515 Mdot
.75459 .28288 Mdot
.29088 .54978 Mdot
.63446 .75714 Mdot
.65904 .24056 Mdot
.41273 .50527 Mdot
.60962 .74193 Mdot
.79833 .48583 Mdot
.26744 .27761 Mdot
.56687 .61659 Mdot
.86798 .49737 Mdot
.46227 .52015 Mdot
.64727 .74551 Mdot
.67346 .21359 Mdot
.36653 .18227 Mdot
.69173 .59808 Mdot
.80737 .33876 Mdot
.65979 .56491 Mdot
.80299 .46927 Mdot
.64625 .47702 Mdot
.51553 .45658 Mdot
.45857 .75887 Mdot
.84148 .54175 Mdot
.52876 .26915 Mdot
.77805 .40611 Mdot
.49545 .77858 Mdot
.84977 .52219 Mdot
.44408 .44055 Mdot
.24618 .71885 Mdot
.54856 .30714 Mdot
.45792 .83572 Mdot
.45238 .79381 Mdot
.43823 .61296 Mdot
.3383 .35546 Mdot
.23474 .69264 Mdot
.19462 .56463 Mdot
.44362 .7834 Mdot
.35525 .38364 Mdot
.59568 .78116 Mdot
.32088 .30676 Mdot
.79602 .63556 Mdot
.30809 .77158 Mdot
.68607 .27649 Mdot
.59468 .69102 Mdot
.68411 .66417 Mdot
.62857 .77824 Mdot
.76908 .57515 Mdot
.72559 .3449 Mdot
.64503 .60298 Mdot
.35609 .61129 Mdot
.1071 .49792 Mdot
.63836 .53609 Mdot
.27062 .50595 Mdot
.76752 .27704 Mdot
.78532 .63878 Mdot
.50953 .51581 Mdot
.29581 .72579 Mdot
.21239 .43498 Mdot
.42375 .35938 Mdot
.37904 .48937 Mdot
.84941 .51667 Mdot
.43949 .34747 Mdot
.82189 .38151 Mdot
.6497 .79765 Mdot
.292 .63013 Mdot
.31559 .56866 Mdot
.52841 .38165 Mdot
.2737 .45787 Mdot
.34444 .39132 Mdot
.7734 .29477 Mdot
.22603 .52194 Mdot
.57723 .44729 Mdot
.69051 .41685 Mdot
.74866 .42539 Mdot
.39962 .60766 Mdot
.43547 .82424 Mdot
.61474 .77484 Mdot
.27766 .38272 Mdot
.74164 .63796 Mdot
.35029 .34074 Mdot
.24901 .59896 Mdot
.28621 .32088 Mdot
.52068 .57052 Mdot
.51359 .3067 Mdot
.57972 .32244 Mdot
.76412 .31873 Mdot
.80277 .51789 Mdot
.52886 .81077 Mdot
.4298 .19635 Mdot
.63985 .73648 Mdot
.30042 .40975 Mdot
.74135 .32083 Mdot
.55999 .59827 Mdot
.527 .28 Mdot
.22853 .42947 Mdot
.24523 .55349 Mdot
.80409 .56966 Mdot
.33808 .42789 Mdot
.81447 .63289 Mdot
.29307 .33536 Mdot
.7278 .28274 Mdot
.49492 .40639 Mdot
.40446 .73364 Mdot
.29588 .68358 Mdot
.47666 .18951 Mdot
.59707 .5425 Mdot
.70833 .20114 Mdot
.53589 .66229 Mdot
.84093 .40727 Mdot
.70391 .47723 Mdot
.19506 .35819 Mdot
.79975 .60081 Mdot
.54912 .52437 Mdot
.54971 .464 Mdot
.58378 .79972 Mdot
.67595 .70651 Mdot
.6923 .706 Mdot
.48341 .54839 Mdot
.52925 .36121 Mdot
.58899 .44056 Mdot
.70331 .57624 Mdot
.77707 .35482 Mdot
.32828 .52802 Mdot
.61687 .37747 Mdot
.32753 .41641 Mdot
.72149 .44008 Mdot
.70413 .73086 Mdot
.79653 .55251 Mdot
.35122 .44241 Mdot
.35886 .32509 Mdot
.74417 .26453 Mdot
.76735 .67464 Mdot
.48822 .51933 Mdot
.44969 .57445 Mdot
.62057 .44407 Mdot
.6058 .19968 Mdot
.80407 .41898 Mdot
.73924 .42739 Mdot
.61425 .58799 Mdot
.31274 .32454 Mdot
.88221 .47511 Mdot
.73885 .23998 Mdot
.46016 .17859 Mdot
.57047 .46681 Mdot
.55504 .70858 Mdot
.19671 .46131 Mdot
.73092 .28682 Mdot
.46961 .83853 Mdot
.75228 .65707 Mdot
.35115 .34599 Mdot
.29945 .25198 Mdot
.21369 .61181 Mdot
.57014 .4346 Mdot
.29759 .68523 Mdot
.43411 .7427 Mdot
.66808 .43214 Mdot
.42605 .36488 Mdot
.54275 .4376 Mdot
.62456 .45761 Mdot
.5993 .78033 Mdot
.66431 .70902 Mdot
.72528 .2791 Mdot
.221 .5431 Mdot
.45142 .57187 Mdot
.77626 .37151 Mdot
.45943 .64797 Mdot
.67477 .2713 Mdot
.60907 .22297 Mdot
.55863 .44006 Mdot
.55818 .38796 Mdot
.31504 .45985 Mdot
.61065 .55639 Mdot
.6636 .55897 Mdot
.35748 .22411 Mdot
.4755 .30782 Mdot
.55166 .69037 Mdot
.21736 .64077 Mdot
.52072 .72635 Mdot
.86643 .5468 Mdot
.71068 .5854 Mdot
.2672 .62762 Mdot
.69408 .54288 Mdot
.67114 .34635 Mdot
.36503 .20437 Mdot
.33699 .60995 Mdot
.40089 .24774 Mdot
.55925 .68516 Mdot
.47251 .64974 Mdot
.72501 .52893 Mdot
.66287 .6664 Mdot
.29579 .61211 Mdot
.35941 .80017 Mdot
.5968 .21849 Mdot
.53208 .72203 Mdot
.59739 .42438 Mdot
.45413 .70293 Mdot
.81653 .64187 Mdot
.54844 .37966 Mdot
.72494 .21857 Mdot
.3976 .59472 Mdot
.59268 .18892 Mdot
.7055 .73575 Mdot
.59352 .59338 Mdot
.57351 .46341 Mdot
.63982 .29048 Mdot
.31231 .50517 Mdot
.43988 .60187 Mdot
.47667 .67928 Mdot
.69007 .25189 Mdot
.4534 .30019 Mdot
.36801 .29832 Mdot
.69703 .50592 Mdot
.34768 .77835 Mdot
.45696 .8207 Mdot
.46908 .65255 Mdot
.51486 .39541 Mdot
.67303 .28795 Mdot
.40664 .40437 Mdot
.33464 .41241 Mdot
.76627 .31542 Mdot
.31472 .61015 Mdot
.53693 .66547 Mdot
.45737 .18129 Mdot
.41399 .38352 Mdot
.74256 .73109 Mdot
.43081 .447 Mdot
.28994 .44307 Mdot
.34569 .41507 Mdot
.57958 .79046 Mdot
.24873 .59305 Mdot
.81269 .58272 Mdot
.34427 .30818 Mdot
.45996 .43044 Mdot
.3493 .36311 Mdot
.3419 .44333 Mdot
.73246 .43438 Mdot
.43943 .8332 Mdot
.30741 .24651 Mdot
.33686 .72095 Mdot
.57971 .6286 Mdot
.47739 .6196 Mdot
.39959 .8139 Mdot
.54727 .67846 Mdot
.44093 .25774 Mdot
.38078 .6366 Mdot
.79856 .60372 Mdot
.777 .68038 Mdot
.75594 .67504 Mdot
.26715 .46421 Mdot
.74911 .4304 Mdot
.22726 .46334 Mdot
.46645 .51898 Mdot
.55646 .52123 Mdot
.31132 .49537 Mdot
.41101 .60393 Mdot
.50922 .53659 Mdot
.55036 .79656 Mdot
.33164 .58652 Mdot
.83708 .54051 Mdot
.74143 .72923 Mdot
.84131 .4813 Mdot
.73273 .37675 Mdot
.47747 .70871 Mdot
.76212 .26482 Mdot
.22255 .58627 Mdot
.78818 .64728 Mdot
.44614 .7936 Mdot
.27267 .7535 Mdot
.68268 .22176 Mdot
.7833 .6006 Mdot
.5738 .67168 Mdot
.59371 .8198 Mdot
.7039 .71259 Mdot
.2496 .72189 Mdot
.24991 .53467 Mdot
.70062 .73557 Mdot
.69778 .1952 Mdot
.40531 .78703 Mdot
.67174 .71305 Mdot
.28889 .68085 Mdot
.2524 .54548 Mdot
.31927 .77499 Mdot
.3537 .4757 Mdot
.574 .39703 Mdot
.49254 .21386 Mdot
.33987 .34918 Mdot
.31823 .45251 Mdot
.30054 .75999 Mdot
.34115 .39432 Mdot
.29196 .40991 Mdot
.62701 .26791 Mdot
.68706 .22874 Mdot
.25877 .59504 Mdot
.38059 .45129 Mdot
.51935 .63618 Mdot
.41926 .32182 Mdot
.25096 .41585 Mdot
.36554 .54254 Mdot
.58177 .52225 Mdot
.27973 .5367 Mdot
.85956 .47468 Mdot
.48663 .23541 Mdot
.64478 .5101 Mdot
.49456 .72291 Mdot
.61638 .78141 Mdot
.76085 .36979 Mdot
.61795 .71872 Mdot
.27839 .73732 Mdot
.28602 .59191 Mdot
.81712 .46615 Mdot
.64907 .72265 Mdot
.30064 .34992 Mdot
.31683 .26702 Mdot
.6649 .50091 Mdot
.44802 .7606 Mdot
.77074 .2959 Mdot
.62034 .74392 Mdot
.46439 .63916 Mdot
.75603 .61205 Mdot
.72322 .4275 Mdot
.61229 .7581 Mdot
.69493 .70113 Mdot
.70514 .29556 Mdot
.29813 .65257 Mdot
.80683 .39084 Mdot
.53947 .39056 Mdot
.31828 .35904 Mdot
.73105 .6124 Mdot
.32009 .77759 Mdot
.40586 .40523 Mdot
.82442 .60055 Mdot
.55179 .51344 Mdot
.38435 .27969 Mdot
.35911 .55847 Mdot
.22804 .56027 Mdot
.5629 .78914 Mdot
.74157 .62921 Mdot
.50111 .60321 Mdot
.46125 .67022 Mdot
.50358 .8141 Mdot
.50072 .32939 Mdot
.43952 .35269 Mdot
.23537 .49098 Mdot
.5423 .76288 Mdot
.41867 .26453 Mdot
.64068 .69251 Mdot
.41517 .58998 Mdot
.39414 .24008 Mdot
.7456 .40771 Mdot
.45744 .76874 Mdot
.42706 .78772 Mdot
.76782 .32306 Mdot
.74229 .37624 Mdot
.517 .8194 Mdot
.46791 .78569 Mdot
.65902 .76155 Mdot
.216 .60036 Mdot
.58129 .66208 Mdot
.42954 .5035 Mdot
.44089 .25784 Mdot
.54176 .67987 Mdot
.78163 .35789 Mdot
.46267 .5768 Mdot
.38729 .26791 Mdot
.54155 .54314 Mdot
.72665 .33626 Mdot
.47905 .40195 Mdot
.70611 .72765 Mdot
.59358 .82004 Mdot
.35049 .32213 Mdot
.66874 .5069 Mdot
.66948 .56547 Mdot
.5602 .61168 Mdot
.82877 .56762 Mdot
.50023 .54498 Mdot
.43909 .68654 Mdot
.60115 .67468 Mdot
.41394 .69752 Mdot
.67443 .77332 Mdot
.37193 .32773 Mdot
.56148 .52686 Mdot
.43565 .64376 Mdot
.60062 .64558 Mdot
.65452 .68196 Mdot
.51584 .23134 Mdot
.22205 .57275 Mdot
.70238 .52727 Mdot
.59333 .45604 Mdot
.43393 .57544 Mdot
.19599 .46571 Mdot
.80038 .39063 Mdot
.50269 .51029 Mdot
.54632 .51265 Mdot
.65656 .24204 Mdot
.41715 .34579 Mdot
.14451 .40095 Mdot
.85873 .44366 Mdot
.35906 .55775 Mdot
.53824 .45436 Mdot
.36958 .30949 Mdot
.55075 .32651 Mdot
.34303 .63168 Mdot
.77476 .33374 Mdot
.67163 .4517 Mdot
.61426 .25554 Mdot
.6643 .69201 Mdot
.57447 .80008 Mdot
.50583 .1823 Mdot
.65712 .43828 Mdot
.86933 .53977 Mdot
.74757 .65992 Mdot
.56623 .77897 Mdot
.12134 .44046 Mdot
.54396 .79159 Mdot
.45553 .45233 Mdot
.61764 .27147 Mdot
.85454 .4852 Mdot
.57448 .4715 Mdot
.60609 .2611 Mdot
.41416 .78414 Mdot
.3477 .31709 Mdot
.30248 .38183 Mdot
.5961 .69495 Mdot
.52471 .79904 Mdot
.22911 .70319 Mdot
.67153 .34422 Mdot
.38852 .19491 Mdot
.2938 .61889 Mdot
.81853 .4003 Mdot
.69199 .59662 Mdot
.28983 .26176 Mdot
.77019 .6873 Mdot
.37462 .36741 Mdot
.31103 .76273 Mdot
.49892 .26514 Mdot
.36791 .25976 Mdot
.19022 .46812 Mdot
.66222 .6147 Mdot
.32427 .61227 Mdot
.65633 .34318 Mdot
.52063 .60848 Mdot
.3547 .35925 Mdot
.42059 .72137 Mdot
.56108 .52393 Mdot
.79254 .33208 Mdot
.24799 .698 Mdot
.32559 .3164 Mdot
.6439 .25221 Mdot
.37402 .26012 Mdot
.78856 .38977 Mdot
.76826 .42413 Mdot
.41182 .39972 Mdot
.62331 .17139 Mdot
.80105 .32553 Mdot
.58339 .66149 Mdot
.36021 .47756 Mdot
.74841 .72957 Mdot
.44798 .39994 Mdot
.43157 .78508 Mdot
.70511 .6795 Mdot
.28439 .39682 Mdot
.29309 .5596 Mdot
.40616 .47516 Mdot
.22384 .48371 Mdot
.56759 .66342 Mdot
.4245 .72637 Mdot
.54656 .19123 Mdot
.32885 .31181 Mdot
.25476 .70247 Mdot
.51104 .17545 Mdot
.42608 .44293 Mdot
.5104 .651 Mdot
.8566 .4806 Mdot
.41371 .63027 Mdot
.45789 .56965 Mdot
.27692 .65289 Mdot
.49347 .53854 Mdot
.56674 .28377 Mdot
.44937 .57326 Mdot
.60569 .57171 Mdot
.33585 .35549 Mdot
.73994 .30069 Mdot
.46428 .76026 Mdot
.69446 .1829 Mdot
.70614 .74188 Mdot
.53315 .72332 Mdot
.4153 .77451 Mdot
.55264 .43521 Mdot
.83839 .47162 Mdot
.65446 .32299 Mdot
.60291 .22172 Mdot
.20595 .63718 Mdot
.34987 .27588 Mdot
.42264 .55874 Mdot
.67987 .63434 Mdot
.79301 .66016 Mdot
.21205 .65837 Mdot
.81465 .6315 Mdot
.31749 .57314 Mdot
.44177 .50603 Mdot
.31382 .20245 Mdot
.8095 .47199 Mdot
.30959 .54832 Mdot
.54352 .63306 Mdot
.50674 .61545 Mdot
.33775 .54718 Mdot
.66668 .66532 Mdot
.25438 .39304 Mdot
.30262 .38783 Mdot
.84082 .53511 Mdot
.51107 .722 Mdot
.57842 .48762 Mdot
.72005 .45421 Mdot
.56674 .48446 Mdot
.38114 .44495 Mdot
.66505 .44819 Mdot
.30469 .39348 Mdot
.47003 .41484 Mdot
.61553 .3262 Mdot
.30741 .59317 Mdot
.62298 .6018 Mdot
.34189 .60515 Mdot
.28728 .43448 Mdot
.54584 .74752 Mdot
.19362 .56312 Mdot
.34019 .39391 Mdot
.38917 .38572 Mdot
.69979 .72659 Mdot
.45099 .85523 Mdot
.58911 .51441 Mdot
.51925 .75177 Mdot
.44495 .44977 Mdot
.23121 .58555 Mdot
.28657 .6516 Mdot
.59755 .31425 Mdot
.65403 .67149 Mdot
.33976 .58895 Mdot
.43261 .64468 Mdot
.66244 .44308 Mdot
.87677 .48435 Mdot
.40164 .46969 Mdot
.33136 .64418 Mdot
.81923 .58749 Mdot
.67864 .26945 Mdot
.25502 .5223 Mdot
.3126 .49145 Mdot
.47291 .45186 Mdot
.46489 .41021 Mdot
.45305 .71339 Mdot
.6872 .26247 Mdot
.81624 .43317 Mdot
.24799 .47778 Mdot
.31332 .63889 Mdot
.40214 .51776 Mdot
.46402 .27917 Mdot
.5953 .56006 Mdot
.35436 .23537 Mdot
.39257 .3089 Mdot
.7667 .67027 Mdot
.30059 .41975 Mdot
.28834 .39191 Mdot
.2688 .66822 Mdot
.83089 .39638 Mdot
.56932 .6258 Mdot
.28743 .63084 Mdot
.52439 .55752 Mdot
.77103 .58031 Mdot
.35219 .38406 Mdot
.74016 .50345 Mdot
.37239 .60178 Mdot
.55603 .64902 Mdot
.84815 .57546 Mdot
.34817 .61342 Mdot
.70364 .50973 Mdot
.80551 .56921 Mdot
.22044 .60397 Mdot
.5487 .46429 Mdot
.10878 .47021 Mdot
.65037 .30939 Mdot
.86844 .53102 Mdot
.72292 .29509 Mdot
.37628 .41105 Mdot
.59413 .77909 Mdot
.29866 .49725 Mdot
.55433 .36614 Mdot
.82993 .45738 Mdot
.44965 .62419 Mdot
.58527 .66993 Mdot
.3307 .49737 Mdot
.49341 .47161 Mdot
.44314 .68007 Mdot
.77098 .46075 Mdot
.55951 .39709 Mdot
.48914 .52555 Mdot
.77652 .43528 Mdot
.4633 .40853 Mdot
.30461 .78286 Mdot
.77493 .29592 Mdot
.81786 .50227 Mdot
.74409 .41677 Mdot
.19864 .34257 Mdot
.55178 .66554 Mdot
.44835 .63638 Mdot
.64832 .50031 Mdot
.22532 .47097 Mdot
.61462 .75216 Mdot
.72959 .28979 Mdot
.64048 .78095 Mdot
.4038 .40354 Mdot
.10325 .5313 Mdot
.36278 .3678 Mdot
.49376 .49395 Mdot
.59772 .75299 Mdot
.83619 .55104 Mdot
.59276 .23485 Mdot
.63509 .79941 Mdot
.70526 .59953 Mdot
.34189 .44487 Mdot
.19833 .50671 Mdot
.46574 .18287 Mdot
.71746 .41939 Mdot
.38153 .19597 Mdot
.78775 .48315 Mdot
.26572 .38377 Mdot
.73754 .62819 Mdot
.51348 .72895 Mdot
.45918 .60343 Mdot
.71382 .57979 Mdot
.5946 .64752 Mdot
.50505 .76724 Mdot
.8117 .43969 Mdot
.26146 .33158 Mdot
.63385 .22892 Mdot
.82964 .48504 Mdot
.7085 .4303 Mdot
.4833 .61622 Mdot
.33116 .39942 Mdot
.39991 .3133 Mdot
.56979 .32657 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0]_ooool2o`00097ooooo000Looooo`03o`000?oooooooooo0;Kooooo0_l0002Aoooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0;?ooooo0_l0002Dooooo`007?ooool00ol0003ooooooooo
o`2cooooo`;o00001?ooool2o`0008kooooo000Looooo`03o`000?oooooooooo08[ooooo0_l0000]
ooooo`;o00003?ooool2o`00083ooooo000Looooo`03o`000?oooooooooo08[ooooo0_l0000Coooo
o`;o00009_ooool2o`00083ooooo000Looooo`03o`000?oooooooooo09oooooo0_l000000ooooooo
0000o`00002Uooooo`007?ooool00ol0003oooooooooo`1hooooo`;o00005oooool3o`0000kooooo
0_l0000Dooooo`;o00004oooool2o`0007[ooooo000Looooo`03o`000?oooooooooo07?ooooo0_l0
0003ooooo`;o00005oooool5o`0000_ooooo0ol00003ooooo`;o00003oooool2o`0000gooooo0_l0
0004ooooo`;o00003_ooool3o`0006Wooooo000Looooo`03o`000?oooooooooo07?ooooo0_l0000O
ooooo`;o00001?ooool2o`0000?ooooo1Ol000000ooooooo0000o`000002o`0001kooooo0_l0000C
ooooo`Co0000JOooool001cooooo00?o0000ooooooooool0Uoooool2o`000003ooooool0003o0000
00?ooooo0_l00004ooooo`;o00005_ooool2o`000003ooooool0003o000000;ooooo1?l00007oooo
o`;o00002oooool2o`0006_ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44
ooooo`Go00001_ooool00ol0003oooooooooo`2;ooooo`;o00001?ooool2o`0000Cooooo0_l0000B
ooooo`;o000000?oooooo`000?l000003Oooool2o`000003ooooool0003o000000;ooooo1?l00007
ooooo`;o0000N?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo07Sooooo1Ol00008ooooo`;o0000
00Coooooo`000?l0003ooooo0_l00004ooooo`;o00006?ooool2o`000003ooooool0003o000002Co
oooo0_l00009ooooo`;o0000J?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool0
2_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo07Sooooo1Ol00008ooooo`;o0000
00?oooooo`000?l00000;Oooool2o`0000Sooooo0_l00002ooooo`;o00003Oooool2o`0000Wooooo
0_l000000ooooooo0000o`00001Uooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooooooo
o`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0001Rooooo`;o00006Oooool2o`0002Gooooo0_l0
000Aooooo`;o00002?ooool2o`0000;ooooo0ol0000Jooooo`;o0000IOooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooo
oooo06;ooooo0_l0000?ooooo`;o00002?ooool2o`00017ooooo0_l0000Booooo`;o00005_ooool2
o`0000Sooooo0_l0000;ooooo`;o00003Oooool2o`0006Gooooo00000ooooooo410@ooooo`02oooo
o`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1coooo
o`;o00006oooool2o`0000gooooo0ol0000Jooooo`;o00005?ooool3o`0007Cooooo00001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oo
oooooooo06oooooo0_l0000:ooooo`;o00008_ooool5o`0001Wooooo0_l0000Cooooo`;o00001?oo
ool2o`0000_ooooo0_l0001Rooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1_ooooo`;o00001?ooool2o`0000Co
oooo0_l0000Oooooo`;o000000?oooooo`000?l000000ol00003ooooo`;o00005?ooool2o`0000Ko
oooo0_l0000@ooooo`?o00002oooool2o`0006;ooooo000Looooo`03o`000?oooooooooo07Gooooo
1?l0000Sooooo`;o00002Oooool2o`0001Cooooo1?l00004ooooo`;o00003_ooool4o`00073ooooo
000Looooo`03o`000?oooooooooo06;ooooo0_l0000Cooooo`;o00006Oooool3o`00017ooooo0_l0
000Eooooo`Co00005?ooool2o`00017ooooo0_l0001Oooooo`007?ooool00ol0003oooooooooo`1R
ooooo`;o00003?ooool2o`0001Sooooo0_l00006ooooo`?o00004Oooool2o`0001Oooooo1Ol00000
1?oooooo0000o`000?l0000<ooooo`;o00001?ooool2o`0000cooooo0_l0001Oooooo`007?ooool0
0ol0003oooooooooo`1`ooooo`;o00006?ooool2o`0000Oooooo0_l00008ooooo`;o00001oooool2
o`000003ooooool0003o000001Gooooo1?l000001?oooooo0000o`000?l00003ooooo`;o00000_oo
ool2o`0000?ooooo0_l000000ooooooo0000o`000003o`0006gooooo000Looooo`03o`000?oooooo
oooo09?ooooo0_l00008ooooo`;o00001oooool2o`000003ooooool0003o000000Gooooo0_l0000@
ooooo`;o00001_ooool3o`0000;ooooo1?l00004ooooo`?o000000Coooooo`000?l0003o0000Jooo
ool001cooooo00?o0000ooooooooool0J?ooool2o`0000;ooooo0ol0000eooooo`;o00002_ooool2
o`0000;ooooo0_l00006ooooo`;o00001?ooool4o`0000Cooooo0_l00005ooooo`;o00002?ooool3
o`0006_ooooo000Looooo`03o`000?oooooooooo06Sooooo0_l00002ooooo`Go0000:Oooool2o`00
00Sooooo0_l00009ooooo`;o00000oooool2o`0000Kooooo0ol00003ooooo`Co00003?ooool2o`00
07Gooooo000Looooo`03o`000?oooooooooo06Kooooo0_l00007ooooo`;o00002oooool2o`0001?o
oooo0_l00007ooooo`;o00004oooool2o`0000;ooooo0_l00004ooooo`;o00000_ooool2o`0001?o
oooo0_l000000ooooooo0000o`000002ooooo`;o00003Oooool2o`000004ooooool0003o0000o`00
05_ooooo000Looooo`03o`000?oooooooooo06Kooooo0_l0000Dooooo`;o00004oooool2o`00023o
oooo0_l00004ooooo`;o00002Oooool3o`0000[ooooo0ol000000ooooooo0000o`000002ooooo`;o
00003Oooool2o`000003ooooool0003o000000;o0000F_ooool001cooooo00?o0000ooooooooool0
/oooool2o`0000oooooo1?l00009ooooo`?o00001Oooool2o`0001;ooooo0_l0001Jooooo`007?oo
ool00ol0003oooooooooo`1Pooooo`;o00005_ooool4o`0000;ooooo1_l0000Gooooo`;o00009ooo
ool6o`0000oooooo0_l000000ooooooo0000o`00001[ooooo`007?ooool2o`0005oooooo1?l0000@
ooooo`?o00000oooool4o`0000;ooooo1_l0000Gooooo`;o000000?oooooo`000?l000009Oooool7
o`000003ooooool0003o000000gooooo1?l0000Aooooo`;o0000E_ooool001cooooo00?o0000oooo
ooooool0FOooool2o`0000?ooooo0ol00009ooooo`;o00001_ooool3o`0000?ooooo1Ol000000ooo
oooo0000o`000002o`0000Sooooo0_l00002ooooo`;o00003_ooool2o`00023ooooo0_l00003oooo
o`?o00000_ooool2o`000003ooooool0003o000000gooooo1?l0000Aooooo`;o0000E_ooool001co
oooo00?o0000ooooooooool0F?ooool3o`0000oooooo0_l00008ooooo`;o000000?oooooo`000?l0
00001?l00002ooooo`;o00002Oooool3o`000003ooooool0003o000000;o000000Coooooo`000?l0
003o0000:_ooool2o`0000;ooooo0_l0000Aooooo`;o00000oooool2o`0000Cooooo0_l0001Uoooo
o`007?ooool00ol0003oooooooooo`1Hooooo`;o00004oooool3o`000004ooooool0003o0000oooo
o`Ko00001Oooool2o`0000Wooooo1Ol000001?oooooo0000o`000?ooool3o`0000Wooooo0_l0000O
ooooo`?o000000?oooooo`000?l000004Oooool2o`0000?ooooo0_l00004ooooo`;o0000IOooool0
01cooooo00?o0000ooooooooool0F_ooool2o`00017ooooo1_l000000ooooooo0000o`000002o`00
00cooooo0_l00007ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Wooooo0_l0000Ooooo
o`?o00001Oooool2o`00017ooooo0_l00006ooooo`;o00001oooool4o`0005Wooooo000Looooo`03
o`000?oooooooooo05[ooooo0_l00007ooooo`;o00001?ooool2o`0000Gooooo0_l0000Booooo`;o
00001_ooool2o`0000;ooooo0ol00002ooooo`;o00001?ooool2o`000003ooooool0003o000002So
oooo1?l0000?ooooo`?o00001Oooool2o`0000Oooooo1?l00004ooooo`;o0000Doooool001cooooo
00?o0000ooooooooool0BOooool2o`0000Cooooo0_l0000Booooo`;o00001?ooool9o`0000Sooooo
0_l0000@ooooo`;o00000oooool2o`000004ooooool0003o0000o`0000Cooooo0_l000000ooooooo
0000o`000002o`0000Kooooo0_l0000Nooooo`Co00003?ooool3o`000003ooooool0003o000001Ko
oooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00001?ooool2o`0001;ooooo
0_l00006ooooo`Oo00002?ooool3o`0000Gooooo0ol00003ooooo`;o00002Oooool3o`0000[ooooo
0_l00006ooooo`;o00006oooool2o`000003ooooool0003o000000gooooo1?l00002ooooo`;o0000
1oooool2o`00067ooooo000Looooo`03o`000?oooooooooo06Oooooo0_l00002ooooo`;o000000?o
ooooo`000?l000002oooool2o`0000?ooooo1Ol00002ooooo`So00001?ooool3o`0002oooooo0_l0
0007ooooo`;o00001oooool3o`000003ooooool0003o000000;o00000_ooool2o`0000?ooooo0_l0
0007ooooo`;o00001Oooool3o`00053ooooo000Looooo`03o`000?oooooooooo05?ooooo0_l0000B
ooooo`;o00001Oooool2o`0000Wooooo0_l00003ooooo`Co000000Coooooo`000?l0003ooooo3?l0
00001?oooooo0000o`000?l00009ooooo`;o00001_ooool2o`0001_ooooo0_l00008ooooo`;o0000
2Oooool5o`0000?ooooo0_l00003ooooo`Co00001Oooool2o`0000Gooooo0ol0001@ooooo`007?oo
ool00ol0003oooooooooo`1Cooooo`;o00004_ooool4o`0000?ooooo0_l00009ooooo`;o00000ooo
ool2o`0000?ooooo4_l000001?oooooo0000o`000?l00006ooooo`;o00001_ooool2o`0001_ooooo
0_l0000Booooo`?o000000?oooooo`000?l000002?ooool5o`0000Kooooo0_l00005ooooo`;o0000
Coooool001cooooo00?o0000ooooooooool0Ioooool6o`000003ooooool0003o000000Sooooo0_l0
0003ooooo`;o00001?oooolAo`0000;ooooo0ol00005ooooo`;o00005?ooool2o`0001Cooooo0_l0
000<ooooo`;o00002?ooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0004oooooo000L
ooooo`03o`000?oooooooooo06Kooooo0_l00003ooooo`;o000000?oooooo`000?l000001_ooool4
o`0000?ooooo0_l00002oooooaOo00001_ooool2o`0000_ooooo0_l00007ooooo`;o00005?ooool2
o`0000_ooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l00006ooooo`;o0000GOoo
ool001cooooo00?o0000ooooooooool0HOooool4o`000004ooooool0003o0000o`0000?ooooo0_l0
0008ooooo`Co00001ooooolGo`0001?ooooo0_l00009ooooo`;o00005?ooool2o`0000Wooooo0_l0
00001?oooooo0000o`000?ooool3o`0000Wooooo0ol0001Mooooo`007?ooool00ol0003ooooooooo
o`1Pooooo`Go00000_ooool2o`0000?ooooo0_l00008ooooo`Co00001?ooool2o`000003ooooool0
003o000001Ko00003_ooool2o`0000gooooo0_l0000Dooooo`Go00002Oooool2o`0000;ooooo0_l0
0007ooooo`Co00003?ooool2o`00053ooooo000Looooo`03o`000?oooooooooo04Cooooo0_l0000D
ooooo`;o00001?ooool4o`00013ooooo0_l00008ooooo`;o000000?oooooo`000?l000005_l00006
ooooo`;o00001_ooool2o`0002Gooooo0ol0000@ooooo`;o00001?ooool2o`0000kooooo0ol0001?
ooooo`007?ooool2o`00043ooooo0_l00003ooooo`;o00005?ooool3o`0000?ooooo0ol0000Aoooo
o`;o00002_oooolGo`0000Gooooo0_l000000ooooooo0000o`000009ooooo`;o00008oooool2o`00
00Kooooo0_l00008ooooo`;o00001_ooool2o`0000;ooooo0_l00008ooooo`?o0000Coooool001co
oooo00?o0000ooooooooool0?oooool2o`0001Wooooo0ol00003ooooo`;o00004?ooool2o`0000?o
oooo0_l00007ooooo`;o000000?oooooo`000?l000005?l00003ooooo`;o00003?ooool2o`0000?o
oooo0_l0000?ooooo`;o00003Oooool2o`0000Kooooo0_l0000@ooooo`;o00000_ooool2o`0005[o
oooo000Looooo`03o`000?oooooooooo05Wooooo0ol00009ooooo`;o00001?ooool2o`0000Gooooo
0_l00003ooooo`;o00001ooooolKo`0000Sooooo0_l000000ooooooo0000o`000006ooooo`Oo0000
2?ooool2o`000003ooooool0003o000000gooooo0_l00006ooooo`;o00001oooool2o`0000Cooooo
0_l0000Eooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0FOooool2o`0000;ooooo0_l0
0006ooooo`?o00000oooool3o`0000Kooooo0_l00006ooooo`;o00000_oooolKo`0000Sooooo0_l0
00000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l000001Ol00002ooooo`;o000000Co
ooooo`000?l0003o00002Oooool2o`0000Cooooo0_l000000ooooooo0000o`000009ooooo`;o0000
00?oooooo`000?l000001?ooool2o`0001Gooooo0_l0001:ooooo`007?ooool00ol0003ooooooooo
o`17ooooo`;o00005?ooool2o`0000Oooooo0ol000000ooooooo0000o`000002o`0000;ooooo0_l0
0002ooooo`;o00001_oooolMo`0001_ooooo1Ol000000ooooooo0000o`000002ooooo`;o00002Ooo
ool2o`0000Cooooo0_l000000ooooooo0000o`000009ooooo`;o00001oooool2o`00067ooooo000L
ooooo`03o`000?oooooooooo04;ooooo0_l00003ooooo`;o00007Oooool3o`000004ooooool0003o
0000ooooo`Go00000_ooool2o`0000Sooooo0_l00002ooooo`ko000000?oooooo`000?l000001ol0
000@ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`Co00000oooool2o`0002Kooooo0_l0
00000ooooooo0000o`00000:ooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0@_ooool2
o`00013ooooo0_l0000@ooooo`;o00001?ooool4o`0000Cooooo0_l0000;ooooo`?o000000?ooooo
o`000?l000003_l000000ooooooo0000o`000002o`0000Oooooo0_l00004ooooo`;o000000Cooooo
o`000?l0003ooooo3_l000000ooooooo0000o`000002o`00027ooooo0_l00006ooooo`;o00002Ooo
ool3o`0005;ooooo000Looooo`03o`000?oooooooooo05?ooooo0ol00003ooooo`Co00001Oooool2
o`0000Sooooo1?l00002ooooo`Co00001Oooool4o`000005ooooool0003o0000o`000?ooool04_l0
000;ooooo`;o00001?ooool2o`000003ooooool0003o000000?o000000?oooooo`000?l000003?l0
00000ooooooo0000o`000004o`0000cooooo0_l0000>ooooo`;o00002_ooool2o`0000Gooooo1Ol0
001@ooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00001?ooool5o`0000Cooooo0_l00008
ooooo`Co000000?oooooo`000?l000001?l00004ooooo`Co000000?oooooo`000?l000005?l0000@
ooooo`co00000_ooool9o`0000;ooooo1ol0000;ooooo`Co00006?ooool2o`0000Oooooo0ol00007
ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0G?ooool2o`0000Cooooo0_l00008oooo
o`Co000000Coooooo`000?l0003ooooo0ol0000:oooooa?o00002oooool2o`0000Gooooo3Ol00000
0ooooooo0000o`000007o`0000Cooooo0_l000000ooooooo0000o`00000;ooooo`Co00008Oooool2
o`0000Sooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`1Aooooo`?o00001?ooool3o`00
00;ooooo0_l0000=ooooo`?o000000Goooooo`000?l0003o0000ooooo`03o`0000[ooooo1Ol00002
ooooo`co00001_ooool2o`0000?ooooo0_l00008oooooaSo00002?ooool2o`0001Oooooo0_l0000B
ooooo`;o00001_ooool2o`0004Wooooo000Looooo`03o`000?oooooooooo057ooooo0ol00002oooo
o`Wo00004Oooool2o`0000;ooooo0_l00006ooooo`?o00002Oooool5o`0000;ooooo0_l00007oooo
o`Co00000oooool2o`0000?ooooo0_l00003ooooo`co00000_ooool:o`0000Sooooo0_l0000Goooo
o`;o00003Oooool2o`0000Gooooo0_l00004ooooo`;o0000BOooool001cooooo00?o0000oooooooo
ool0E_ooool2o`0000?ooooo0_l0000>ooooo`Co00001Oooool2o`0000Kooooo0ol00008ooooo`;o
00000oooool4o`0000Sooooo0_l00009ooooo`?o000000?oooooo`000?l000005_l000000ooooooo
0000o`000003ooooo`;o00008Oooool5o`0000Cooooo0_l00005ooooo`;o0000Coooool001cooooo
00?o0000ooooooooool0EOooool2o`0000?ooooo0_l0000?ooooo`Go00003?ooool2o`0000;ooooo
0_l000000ooooooo0000o`000002ooooo`?o00000_ooool4o`0000Cooooo0_l0000=ooooo`;o0000
00?oooooo`000?l000005ol000000ooooooo0000o`000003ooooo`;o00007_ooool2o`000003oooo
ool0003o000000?o00001oooool2o`0000cooooo0_l00015ooooo`007?ooool00ol0003ooooooooo
o`0iooooo`?o000000?oooooo`000?l000005_ooool2o`000003ooooool0003o000000;o00002Ooo
ool2o`0000Oooooo0_l0000<ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo0ol0
0004ooooo`;o00001?ooool2o`0000gooooo0_l000000ooooooo0000o`00000Ho`000003ooooool0
003o000000kooooo0_l00003ooooo`;o00003Oooool2o`0000gooooo0_l00002ooooo`;o00002?oo
ool2o`0004Gooooo000Looooo`03o`000?oooooooooo03?ooooo0_l00004ooooo`?o000000?ooooo
o`000?l000005oooool4o`0000;ooooo0_l00007ooooo`;o00001oooool4o`0000Sooooo0_l00005
ooooo`Go00001Oooool2o`0001Kooooo0_l000000ooooooo0000o`00000?o`0000;ooooo2_l0000>
ooooo`;o00000oooool2o`00013ooooo0_l0000>ooooo`;o0000Coooool001cooooo0_l0000doooo
o`;o00001?ooool2o`0000?ooooo0_l0000Fooooo`;o00001?ooool4o`0000Sooooo0_l000000ooo
oooo0000o`000005o`0000?ooooo0_l00003ooooo`;o00000_ooool5o`000003ooooool0003o0000
00Cooooo0ol00007ooooo`;o00003ooooolNo`0001?ooooo1?l0000<ooooo`Co00000oooool3o`00
05Wooooo000Looooo`03o`000?oooooooooo03Oooooo0_l00005ooooo`;o00005_ooool2o`0000Ko
oooo0_l00008ooooo`;o000000Coooooo`000?l0003o00001oooool2o`0000?ooooo0_l00002oooo
o`?o00000oooool2o`0000Cooooo0ol00007ooooo`;o00003oooool2o`000003ooooool0003o0000
01So00005_ooool2o`0000cooooo0ol00004ooooo`?o0000FOooool001cooooo00?o0000oooooooo
ool0=oooool2o`0001gooooo0_l0000:ooooo`;o00001Oooool3o`0000Gooooo0_l00003ooooo`;o
00000_ooool2o`0000Gooooo0_l00008ooooo`;o00006oooool?o`000003ooooool0003o000000So
000000Coooooo`000?l0003o00002?ooool2o`0001gooooo0_l0000:ooooo`;o00001Oooool2o`00
04Oooooo000Looooo`03o`000?oooooooooo03cooooo0_l0000Fooooo`Co00000_ooool2o`0000Ko
oooo1?l00003ooooo`?o00000_ooool5o`0000?ooooo0_l00009ooooo`;o000000?oooooo`000?l0
00000_l0000Poooooa[o000000Coooooo`000?l0003o00001oooool3o`0001gooooo0_l00006oooo
o`?o000000Coooooo`000?l0003o00001?ooool2o`0004Oooooo000Looooo`03o`000?oooooooooo
03cooooo0_l0000Fooooo`Co00000_ooool2o`0000Sooooo0_l00004ooooo`;o00000_ooool3o`00
00Oooooo0ol00009ooooo`Co00007?oooolNo`0000;ooooo0ol00006ooooo`;o00006Oooool2o`00
00;ooooo0_l00007ooooo`?o00000_ooool2o`0004gooooo000Looooo`03o`000?oooooooooo04go
oooo0_l00007ooooo`;o00005Oooool3o`0000Sooooo0ol0000<ooooo`;o00006OoooolPo`000003
ooooool0003o000000;o00008Oooool2o`0000;ooooo0_l0001Kooooo`007?ooool00ol0003ooooo
ooooo`1=ooooo`;o000000?oooooo`000?l000001?ooool2o`0001Gooooo0ol00002ooooo`;o0000
0_ooool2o`0000oooooo0_l0000Iooooo`;o00001?oooolGo`000004ooooool0003o0000ooooo`;o
00001_ooool2o`0007cooooo000Looooo`03o`000?oooooooooo03;ooooo0_l0000Looooo`;o0000
1?ooool2o`0001Cooooo1?l00002ooooo`;o00000_ooool2o`0002kooooo7?l00009ooooo`;o0000
9_ooool2o`0000?ooooo0_l0000>ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0<_oo
ool5o`0001Kooooo0_l00006ooooo`;o00001oooool2o`0000cooooo1?l0000Booooo`Co00008?oo
oolLo`0000Gooooo0_l0000<ooooo`;o00007?ooool2o`0000?ooooo0ol00008ooooo`;o00000ooo
ool2o`0003oooooo000Looooo`03o`000?oooooooooo03?ooooo1?l0000Fooooo`;o000000?ooooo
o`000?l000000oooool2o`0000Cooooo0_l000000ooooooo0000o`00000>ooooo`;o00004Oooool5
o`0002?ooooo6_l000000ooooooo0000o`000003o`0000;ooooo0_l00008ooooo`;o00004oooool2
o`000003ooooool0003o000000;ooooo0_l00006ooooo`;o00002?ooool2o`0004Cooooo000Loooo
o`03o`000?oooooooooo02oooooo0_l0000Mooooo`Co00002Oooool2o`0000?ooooo0ol0000Hoooo
o`;o00001?ooool2o`0000;ooooo0ol0000Poooooaoo00001?ooool2o`0000[ooooo0_l0000Aoooo
o`Go00000_ooool2o`0001Cooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o
00007Oooool3o`000005ooooool0003o0000o`000?ooool00_l00003ooooo`;o00000_ooool4o`00
00cooooo0ol00009ooooo`;o00001_ooool5o`000003ooooool0003o000001gooooo1?l000000ooo
oooo0000o`00000Bo`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000cooooo0_l0000B
ooooo`;o00006Oooool3o`00043ooooo000Looooo`03o`000?oooooooooo05;ooooo1_l00003oooo
o`;o00000_ooool2o`0000kooooo0ol00005ooooo`;o00000_ooool4o`0000Cooooo0_l00004oooo
o`Co00007OoooolMo`0000;ooooo1?l0000Nooooo`;o000000?oooooo`000?l000002Oooool3o`00
00Oooooo0_l000000ooooooo0000o`000011ooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o
00001Oooool4o`0000Wooooo0_l0000;ooooo`?o00002?ooool2o`0000;ooooo1_l00007ooooo`;o
000000?oooooo`000?l000007?ooool4o`000003ooooool0003o000000co000000?oooooo`000?l0
00002?l00002ooooo`Go00001oooool2o`0001Cooooo0_l000000ooooooo0000o`000003ooooo`_o
00000_ooool5o`0004Cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`1;ooooo`;o00000_ooool2o`00
0003ooooool0003o000000Kooooo0_l00003ooooo`;o00002_ooool4o`0000kooooo1?l00007oooo
o`;o00006?ooool2o`0000Gooooo2ol000000ooooooo0000o`000008o`0000gooooo0_l00007oooo
o`;o00007?ooool8o`000003ooooool0003o000000;ooooo1?l00015ooooo`0000KoooooogMgMonH
V9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo02kooooo0_l0000Nooooo`?o00001?ooool3o`000004ooooool0003o0000o`0000?ooooo0_l0
000:ooooo`?o00008oooool2o`0000gooooo1Ol00007oooooaOo0000<Oooool2o`0001Cooooo0_l0
000mooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`Go00001_ooool0
0ol0003oooooooooo`0^ooooo`;o00007_ooool3o`0000Cooooo0ol000000ooooooo0000o`00000=
ooooo`;o000000?oooooo`000?l000000oooool2o`0000gooooo0_l000000ooooooo0000o`000008
ooooo`Co000000?oooooo`000?l000003Oooool5o`0000cooooo3Ol000000ooooooo0000o`000002
o`0000Kooooo0_l0000Wooooo`Co00005?ooool2o`0003gooooo00000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`0002_ooooo0_l0000L
ooooo`;o00000oooool4o`0001Kooooo0_l00005ooooo`?o00003Oooool2o`000003ooooool0003o
000000Sooooo1?l00008ooooo`;o00001?ooool2o`00017ooooo2ol00004ooooo`Go00000oooool3
o`0002Oooooo0_l000000ooooooo0000o`00000?ooooo`;o0000@Oooool00003ooooool0003ooooo
00;ooooo00?o0000ooooooooool02Oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooo
oooo02_ooooo1?l000000ooooooo0000o`00000Gooooo`;o00000_ooool5o`0000[ooooo0_l0000A
ooooo`;o00003_ooool6o`0000kooooo0_l00003ooooo`;o00000oooool3o`0000?ooooo0ol0000=
ooooo`Oo00000_ooool2o`0000?ooooo1?l00003ooooo`;o0000:oooool2o`0000;ooooo0_l0000;
ooooo`;o0000@Oooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00omg
MgOoc<c<o`000007ooooo`03o`000?oooooooooo02gooooo0_l000000ooooooo0000o`00000Hoooo
o`;o000000?oooooo`000?l000003Oooool2o`0000oooooo0ol0000?ooooo`Ko00003_ooool2o`00
00Sooooo0_l00004ooooo`?o00005_ooool2o`0002gooooo0_l000000ooooooo0000o`000009oooo
o`;o00004_ooool2o`0003[ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^
odA4A?l000001oooool00ol0003oooooooooo`17ooooo`Go00001oooool2o`0000Kooooo0_l00000
0ooooooo0000o`000009ooooo`;o00000_ooool3o`0000Kooooo0_l00005ooooo`;o00000oooool2
o`0000oooooo0_l0000?ooooo`;o00000_ooool2o`0000gooooo0_l00004ooooo`?o0000:_ooool3
o`000003ooooool0003o000000Sooooo0_l0000Cooooo`?o0000>Oooool00006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo04Oooooo1?l0
0008ooooo`;o00001_ooool2o`000003ooooool0003o000000Wooooo0_l00002ooooo`;o00001ooo
ool2o`0000Gooooo0_l0000Dooooo`Co00003?ooool3o`0000;ooooo1_l00009ooooo`;o000000Co
ooooo`000?l0003ooooo0ol0000Zooooo`;o00003?ooool2o`0000oooooo0_l00003ooooo`;o0000
>Oooool001cooooo00?o0000ooooooooool0A_ooool5o`0000;ooooo0ol0000Fooooo`?o00001?oo
ool2o`0002Kooooo0_l0000;ooooo`?o00001Oooool4o`0000cooooo0_l00003ooooo`;o00004?oo
ool4o`0000?ooooo1?l000000ooooooo0000o`000009ooooo`;o00001?ooool3o`0001Sooooo0_l0
0007ooooo`;o0000=Oooool001cooooo00?o0000ooooooooool0;Oooool2o`0001Gooooo1Ol00004
ooooo`?o00003_ooool2o`0000Kooooo0ol0000hooooo`?o00000oooool6o`0001;ooooo0_l00005
ooooo`;o00001_ooool2o`000003ooooool0003o000000;o00000oooool4o`000003ooooool0003o
000000Kooooo0_l000000ooooooo0000o`000004ooooo`?o00000oooool2o`0000_ooooo0_l0000:
ooooo`;o00000oooool2o`0003Gooooo000Looooo`03o`000?oooooooooo02gooooo0_l0000Eoooo
o`Co00005_ooool2o`0000Wooooo1?l0000Jooooo`Go00001?ooool2o`0000oooooo0_l00004oooo
o`Co00000oooool2o`0000[ooooo0_l00002ooooo`;o00001Oooool4o`0000?ooooo1Ol000000ooo
oooo0000o`000007ooooo`;o00000_ooool2o`0000Cooooo0_l0000=ooooo`Ko00001oooool2o`00
00[ooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`0Uooooo`;o00007?ooool4o`0000;o
oooo0_l0000Nooooo`Co00006_ooool5o`0000Cooooo0_l00003ooooo`;o00000oooool2o`0000Go
oooo0_l0000;ooooo`;o00001?ooool3o`0000?ooooo0ol000000ooooooo0000o`000002o`0000?o
oooo1?l00003ooooo`Go000000?oooooo`000?l000001oooool2o`0000;ooooo0_l00006ooooo`;o
00000oooool2o`000003ooooool0003o000000Gooooo1?l0000Gooooo`;o0000=_ooool001cooooo
00?o0000ooooooooool09Oooool2o`0000Wooooo0_l0000@ooooo`Wo00006?ooool9o`0002Kooooo
0_l000000ooooooo0000o`000003ooooo`;o00001?ooool2o`0001;ooooo0ol00004ooooo`Co0000
00Coooooo`000?l0003o00007oooool2o`0000?ooooo0_l00003ooooo`;o000000Coooooo`000?l0
003o00001_ooool2o`0000kooooo0_l000000ooooooo0000o`000004ooooo`;o0000=_ooool001co
oooo00?o0000ooooooooool0<?ooool2o`0000kooooo1?l00003ooooo`;o00006?ooool8o`0001So
oooo0_l00003ooooo`;o00002_ooool2o`0000Kooooo0_l00004ooooo`;o00005?ooool2o`0000Co
oooo0ol00002ooooo`Co00001oooool2o`0000Oooooo0_l0000;ooooo`;o00002_ooool5o`0000Go
oooo0_l0000:ooooo`?o000000Coooooo`000?l0003ooooo0_l0000looooo`007?ooool00ol0003o
ooooooooo`10ooooo`?o00001?ooool2o`0000kooooo0_l000001?oooooo0000o`000?ooool2o`00
00;ooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000001?ooooo1?l00003
ooooo`;o00003?ooool2o`000003ooooool0003o000000Oooooo0_l0000>ooooo`;o00000oooool4
o`000003ooooool0003o000000;o00001Oooool2o`0000Oooooo0_l00003ooooo`;o00000_ooool2
o`0000?ooooo0_l00004ooooo`;o00002?ooool2o`0000;ooooo0_l000000ooooooo0000o`000005
ooooo`;o00002_ooool3o`0004;ooooo000Looooo`03o`000?oooooooooo043ooooo0ol00004oooo
o`;o00003_ooool2o`000004ooooool0003o0000ooooo`;o00002oooool2o`000003ooooool0003o
000000;ooooo0_l000000ooooooo0000o`000009ooooo`;o00003_ooool2o`0000?ooooo0_l00000
0ooooooo0000o`000007ooooo`;o00001oooool2o`0000;ooooo1ol000000ooooooo0000o`000002
o`000003ooooool0003o000001;ooooo0_l000001?oooooo0000o`000?l00005ooooo`?o00001?oo
ool2o`0000Gooooo0_l000000ooooooo0000o`00000<ooooo`;o00002_ooool4o`00047ooooo000L
ooooo`03o`000?oooooooooo02Cooooo0ol0000Hooooo`?o00004?ooool2o`0000Kooooo0_l0000?
ooooo`Go000000Coooooo`000?l0003ooooo1?l0000?ooooo`;o00001?ooool4o`0000Kooooo0_l0
0007ooooo`?o00001_ooool2o`0000;ooooo1ol00008ooooo`;o00004?oooolAo`0000Sooooo0_l0
0006ooooo`;o00004oooool4o`00047ooooo000Looooo`03o`000?oooooooooo02Cooooo0ol0000;
ooooo`;o00002oooool2o`0000kooooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l0000<
ooooo`;o000000?oooooo`000?l000000ol00002ooooo`;o00000_ooool4o`0000gooooo0_l00003
ooooo`Co00001oooool3o`0000Oooooo0_l0000;ooooo`;o000000?oooooo`000?l000000_l00007
ooooo`?o00000_ooool2o`0000?ooooo0_l00007oooooa7o000000Coooooo`000?l0003o00002ooo
ool2o`0001kooooo0_l00002ooooo`;o0000=?ooool001cooooo00?o0000ooooooooool0<_ooool2
o`0001_ooooo0_l00003ooooo`;o00002_ooool3o`0000Gooooo0_l000000ooooooo0000o`000002
o`0000?ooooo0_l00004ooooo`;o00000oooool4o`0000Gooooo1?l00002ooooo`Co000000?ooooo
o`000?l000001Oooool2o`0000Oooooo0_l0000;ooooo`;o00000oooool2o`0000?ooooo0_l00003
ooooo`;o00000_ooool2o`0000?ooooo0_l00006ooooo`;o00000_oooolBo`0000Gooooo0_l0000=
ooooo`;o00002_ooool2o`0000Wooooo0_l00002ooooo`;o0000=?ooool001cooooo0_l0001Coooo
o`;o00001oooool2o`0000?ooooo0ol000001?oooooo0000o`000?ooool2o`0000Cooooo0ol00002
ooooo`;o00000oooool3o`0000;ooooo1Ol00005ooooo`Co00000oooool6o`0000?ooooo1ol00004
ooooo`;o00004?ooool3o`0000;ooooo0_l00008ooooo`;o00002?ooool=o`000003ooooool0003o
000000So00001Oooool2o`0000Sooooo0_l00003ooooo`;o00000oooool2o`0000Gooooo0_l0000;
ooooo`;o0000=_ooool001cooooo00?o0000ooooooooool0COooool2o`0000?ooooo0_l00005oooo
o`Co00001oooool2o`000004ooooool0003o0000ooooo`Ko00000_ooool2o`0000?ooooo0ol00002
ooooo`;o00003Oooool7o`0000Cooooo1ol00004ooooo`;o00002?ooool2o`0000Kooooo1Ol0000:
ooooo`;o00000oooool2o`0000?ooooo5?l000000ooooooo0000o`000005o`0000_ooooo0_l00008
ooooo`;o00004_ooool2o`0003Kooooo000Looooo`03o`000?oooooooooo03_ooooo0_l0000?oooo
o`?o00001_ooool2o`0000;ooooo0ol0000:ooooo`?o000000Coooooo`000?l0003o00001Oooool2
o`000003ooooool0003o000000Oooooo1Ol00008ooooo`;o00000oooool2o`0000[ooooo0_l00006
ooooo`;o00001Oooool2o`0000Cooooo0_l000000ooooooo0000o`000004o`0000?ooooo0_l00000
0ooooooo0000o`000005ooooo`?o00000_oooolMo`00027ooooo0_l0000mooooo`007?ooool00ol0
003oooooooooo`0`ooooo`;o00002Oooool3o`0000kooooo0_l00007ooooo`;o00002Oooool2o`00
0004ooooool0003o0000ooooo`Go00000oooool9o`000003ooooool0003o000000;ooooo1ol00004
ooooo`Co00003oooool4o`0000Kooooo0_l00005ooooo`;o00001?ooool2o`000003ooooool0003o
000000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000001OoooolOo`000003ooooool0003o
000000kooooo0_l00005ooooo`;o00002_ooool2o`0003gooooo000Looooo`03o`000?oooooooooo
033ooooo0_l00008ooooo`Co00002?ooool2o`0000_ooooo1Ol00008ooooo`;o000000Goooooo`00
0?l0003o0000ooooo`04o`0000?ooooo4?l000001?oooooo0000o`000?ooool2o`0000?ooooo1?l0
000?ooooo`;o00004_ooool3o`0000Cooooo1_l0000?ooooo`;o00000_oooolHo`00017ooooo0_l0
0005ooooo`;o00002_ooool2o`0003gooooo000Looooo`03o`000?oooooooooo03Sooooo2?l00006
ooooo`;o00002oooool2o`000003ooooool0003o000000Wooooo0_l000000ooooooo0000o`000003
ooooo`Co000000?oooooo`000?l000000_l00003ooooo`Wo00001?ooool2o`0000Gooooo0_l00007
ooooo`;o00006_ooool3o`0000Cooooo1_l0000Cooooo`co000000?oooooo`000?l000002Ol0000P
ooooo`;o00002_ooool2o`0003Gooooo000Looooo`03o`000?oooooooooo023ooooo0_l0000Foooo
o`So00001Oooool2o`0000oooooo0_l00009ooooo`Co00000_ooool6o`0000Kooooo0ol000000ooo
oooo0000o`000008o`0000Gooooo1Ol00007ooooo`;o00008?ooool4o`0000oooooo0_l00004oooo
oa[o00003_ooool2o`0000Oooooo0_l000000ooooooo0000o`000003ooooo`;o00001oooool2o`00
0003ooooool0003o000000Oooooo0_l0000/ooooo`007?ooool00ol0003oooooooooo`0Pooooo`;o
00003Oooool2o`0000Sooooo1Ol00007ooooo`;o00003_ooool2o`0000cooooo0_l000000ooooooo
0000o`000003o`0000?ooooo0_l00002oooooa?o000000?oooooo`000?l000000ol00007ooooo`;o
00002Oooool2o`0001;ooooo0_l000000ooooooo0000o`000003o`0000Cooooo0_l00008ooooo`Co
00000_oooolJo`0000kooooo0_l00007ooooo`;o000000?oooooo`000?l000000_l00008ooooo`Co
00002_ooool2o`0002cooooo000Looooo`03o`000?oooooooooo01[ooooo0_l0000Cooooo`;o0000
9?ooool2o`0000oooooo0_l000001Ooooooo0000o`000?l0003ooooo013o000000?oooooo`000?l0
00001Ol0000=ooooo`;o00002?ooool3o`0001;ooooo1Ol000000ooooooo0000o`000002o`0000;o
oooo0_l0000:ooooo`;o00000ooooolIo`0000?ooooo0_l00004ooooo`;o00004?ooool3o`000004
ooooool0003o0000o`0000Cooooo0_l00002ooooo`Ko00001?ooool2o`0002cooooo000Looooo`03
o`000?oooooooooo01[ooooo0_l0000aooooo`;o00002?ooool2o`0000?ooooo2Ol00005oooooa[o
00006?ooool4o`0001;ooooo1?l00003ooooo`;o00004ooooolIo`000003ooooool0003o000000;o
00001?ooool2o`0000Sooooo1?l00004ooooo`;o00000_ooool3o`0000Sooooo1_l00004ooooo`;o
0000;?ooool001cooooo00?o0000ooooooooool0?oooool2o`0000cooooo0_l00008ooooo`;o0000
0oooool9o`000005ooooool0003o0000o`000?ooool07Ol0000<ooooo`;o00001oooool4o`0000?o
oooo0_l0000<ooooo`Oo00001_ooool2o`0000[ooooo0_l00002oooooaWo000000?oooooo`000?l0
00000_l000000ooooooo0000o`00000;ooooo`Co00002_ooool2o`0000?ooooo0_l00002ooooo`?o
0000=Oooool001cooooo00?o0000ooooooooool07oooool2o`0001kooooo0_l00004ooooo`;o0000
3oooool2o`0000Wooooo1?l000001Ooooooo0000o`000?l0003ooooo00_o000000?oooooo`000?l0
00003ol0000;ooooo`?o00002?ooool2o`0000Cooooo0_l0000<ooooo`;o000000?oooooo`000?l0
00000ol00005ooooo`;o00002Oooool3o`0000;ooooo6ol00004ooooo`;o00003Oooool2o`0000;o
oooo0_l00006ooooo`Co000000?oooooo`000?l000000oooool2o`0000Gooooo0_l0000^ooooo`00
7?ooool00ol0003oooooooooo`0Oooooo`;o00009?ooool2o`0000Cooooo0_l00007ooooo`Co0000
00?oooooo`000?l000001Oooool5o`0000;ooooo0_l000000ooooooo0000o`00000Lo`0000Kooooo
0ol000000ooooooo0000o`000009ooooo`;o00004_ooool2o`000003ooooool0003o000000Co0000
3ooooolRo`0000;ooooo0_l0000Aooooo`;o00001oooool3o`0000Kooooo0_l00005ooooo`;o0000
;_ooool001cooooo00?o0000ooooooooool0BOooool4o`0000;ooooo0_l00003ooooo`;o00000ooo
ool4o`0000?ooooo1?l000000ooooooo0000o`000006o`0000;ooooo6Ol00005ooooo`Co00001_oo
ool2o`0000Cooooo0_l0000;ooooo`;o00003?ooool2o`00013ooooo3ol00002ooooo`co00000_oo
ool2o`0000;ooooo0_l0000Booooo`;o00001Oooool4o`0003gooooo000Looooo`03o`000?oooooo
oooo03Oooooo0_l0000=ooooo`;o000000?oooooo`000?l000001?ooool2o`0000[ooooo0_l00000
0ooooooo0000o`00000=o`0000;ooooo6_l00003ooooo`?o00002?ooool2o`0000Cooooo0ol0000:
ooooo`;o00008OoooolGo`000003ooooool0003o000000Kooooo0ol0000Aooooo`;o00001?ooool5
o`0003gooooo000Looooo`03o`000?oooooooooo01oooooo0_l0000=ooooo`;o00001oooool2o`00
00gooooo0_l00004ooooo`;o00001Oooool2o`0000Sooooo2?l00003ooooo`Go000000?oooooo`00
0?l000003Ol000000ooooooo0000o`000009o`0000?ooooo0_l0000?ooooo`?o00000_ooool2o`00
02Wooooo4ol00002ooooo`;o00002_ooool2o`0000_ooooo0_l00009ooooo`Co00003?ooool2o`00
037ooooo000Looooo`;o00008?ooool2o`0000gooooo0_l0000;ooooo`;o00002Oooool2o`0000Co
oooo0_l00005ooooo`;o00001oooool6o`000004ooooool0003o0000o`0000;ooooo8_l000000ooo
oooo0000o`000003ooooo`;o000000Coooooo`000?l0003o00002oooool5o`0000_ooooo0_l0000<
ooooo`;o00003?ooool4o`000003ooooool0003o000000[o000000Coooooo`000?l0003ooooo0ol0
0004ooooo`;o00003Oooool2o`000003ooooool0003o000000;ooooo0_l00005ooooo`Co00003?oo
ool2o`00037ooooo000Looooo`03o`000?oooooooooo02kooooo0_l0000;ooooo`;o00003oooool2
o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000ol00002
ooooob7o000000?oooooo`000?l000000ol000000ooooooo0000o`000003ooooo`Wo00001_ooool4
o`000003ooooool0003o000000_ooooo0_l00005ooooo`;o00001Oooool2o`0000Wooooo6ol00004
ooooo`;o00000_ooool2o`0000Wooooo0_l00005ooooo`?o00001?ooool2o`0000Gooooo0_l0000j
ooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00003Oooool2o`0000Cooooo1Ol00002oooo
o`Co000000Coooooo`000?l0003ooooo:Ol000001Ooooooo0000o`000?l0003ooooo00Co000000?o
ooooo`000?l000000ol00006ooooo`?o00000_ooool2o`0000Cooooo0_l0000;ooooo`Co00003ooo
oolAo`0000;ooooo1_l00008ooooo`Co00002?ooool2o`0000Oooooo0_l00004ooooo`;o00001Ooo
ool2o`0003[ooooo000Looooo`03o`000?oooooooooo03gooooo0_l0000Booooo`;o000000?ooooo
o`000?l000001?ooool3o`0000;ooooo:ol000001Ooooooo0000o`000?l0003ooooo00;o00000ooo
ool2o`000003ooooool0003o000000Oooooo0_l00008ooooo`;o00001_ooool2o`0000?ooooo1?l0
000Aooooo`Ko00000_ooool3o`000003ooooool0003o000000Gooooo1?l00008ooooo`;o00002_oo
ool2o`0001;ooooo1?l0000jooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00003?ooool2
o`000003ooooool0003o000000Cooooo0_l00003ooooo`;o000000?oooooo`000?l000005Ol00000
0ooooooo0000o`00000<o`0000;ooooo1?l00002ooooo`;o00000_ooool2o`000003ooooool0003o
000000Oooooo0ol0000;ooooo`?o000000?oooooo`000?l000000_ooool2o`0001Cooooo1?l00004
ooooo`;o00000oooool2o`0000Gooooo1Ol00004ooooo`;o00006Oooool2o`0000Gooooo0ol0000k
ooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o00002oooool2o`0000Oooooo0_l000000ooo
oooo0000o`000004ooooo`;o00002?ooool3o`0000Cooooo:?l000000ooooooo0000o`000006o`00
0005ooooool0003o0000o`000?ooool00_l0000<ooooo`?o00002_ooool3o`0000Gooooo0_l00002
ooooo`Co00004oooool5o`0000?ooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l0
0004ooooo`;o00002oooool2o`0000cooooo0_l0000:ooooo`;o00000_ooool2o`000003ooooool0
003o0000033ooooo000Looooo`03o`000?oooooooooo02gooooo0_l0000;ooooo`;o00002_ooool2
o`0000?ooooo0ol00006ooooo`Go00001?ooool7o`000003ooooool0003o000002Go000000?ooooo
o`000?l000000_l000000ooooooo0000o`000002o`0000Gooooo0_l00005ooooo`Ko00002Oooool2
o`000003ooooool0003o000000;o00000_ooool4o`0001?ooooo0ol00009ooooo`;o00005oooool2
o`0000Wooooo0_l000000ooooooo0000o`000002o`0000Sooooo0_l00002ooooo`;o000000?ooooo
o`000?l00000<?ooool001cooooo00?o0000ooooooooool0;?ooool2o`0000Oooooo0_l00003oooo
o`;o00001oooool5o`0000?ooooo0_l00002ooooo`;o00000oooool4o`0000?ooooo0_l00002oooo
o`Go000000?oooooo`000?l00000:Ol00002ooooo`Co00001Oooool2o`0000Oooooo1?l00009oooo
o`_o0000AOooool2o`000003ooooool0003o000000;o00002?ooool2o`0003Oooooo000Looooo`03
o`000?oooooooooo01kooooo0_l0000<ooooo`;o00001oooool2o`0000;ooooo0ol00007ooooo`Go
00000oooool2o`0000;ooooo0_l00005ooooo`;o00000oooool3o`0000?ooooo0ol000000ooooooo
0000o`00000To`000003ooooool0003o000000;o00002oooool2o`0001;ooooo3_l00017ooooo`?o
00002Oooool2o`0003Oooooo000Looooo`03o`000?oooooooooo01kooooo0_l0000Eooooo`;o0000
0_ooool2o`0000Sooooo1?l00004ooooo`?o00001?ooool2o`0000Sooooo0ol00004ooooob;o0000
00?oooooo`000?l000000ol000000ooooooo0000o`00000=ooooo`;o00004_ooool2o`000003oooo
ool0003o000000Go00000_ooool2o`0002?ooooo0_l00006ooooo`;o00005oooool2o`000003oooo
ool0003o000004?ooooo000Looooo`03o`000?oooooooooo01kooooo1?l0000Zooooo`Co00000_oo
ool2o`0000Oooooo1_l00002oooooa[o000000?oooooo`000?l000001ol000000ooooooo0000o`00
0004o`0000cooooo0_l0000Fooooo`Oo00000_ooool2o`0002?ooooo0_l00006ooooo`;o00004_oo
ool2o`0000?ooooo1?l00003ooooo`;o00003?ooool2o`00037ooooo000Looooo`03o`000?oooooo
oooo01kooooo1?l0000:ooooo`;o00002?ooool2o`0001Gooooo1Ol00009ooooo`;o000000Cooooo
o`000?l0003o00000_ooool8o`000003ooooool0003o000000So000000?oooooo`000?l000003_l0
00000ooooooo0000o`000003o`0000gooooo0_l00003ooooo`;o00003_ooool2o`0000?ooooo0_l0
0003ooooo`Co0000?oooool2o`000003ooooool0003o000000;ooooo0_l00003ooooo`;o000000?o
ooooo`000?l000000ol00006ooooo`;o0000<Oooool001cooooo00?o0000ooooooooool0;?ooool2
o`0000Sooooo0_l0000Eooooo`Go00001Oooool4o`0000?ooooo0ol00002ooooo`Co00000_oooolV
o`0000_ooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000_ooooo0_l00003
ooooo`;o00000oooool2o`000003ooooool0003o000000?o00002oooool2o`00037ooooo1_l00002
ooooo`;o00000_ooool5o`0003Wooooo000Looooo`03o`000?oooooooooo02cooooo0_l0000>oooo
o`;o00006Oooool4o`0000Oooooo0ol00002ooooob;o000000Coooooo`000?l0003ooooo0_l00003
ooooo`;o00001_ooool2o`000004ooooool0003o0000ooooo`Co00004?ooool2o`0000Gooooo1ol0
0009ooooo`?o0000<_ooool4o`0000?ooooo0_l00003ooooo`Co00001oooool2o`00033ooooo000L
ooooo`03o`000?oooooooooo03Sooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o
000000;ooooo0_l0000;ooooo`;o00001Oooool2o`0000Cooooo0_l00003ooooob;o00002Oooool2
o`0000_ooooo0ol0000:ooooo`;o00002?ooool2o`0000?ooooo1ol00009ooooo`;o00004Oooool3
o`0001oooooo0_l0000:ooooo`Co00001oooool2o`00033ooooo000Looooo`03o`000?oooooooooo
03Sooooo0_l00007ooooo`;o000000?oooooo`000?l000000_ooool3o`0000?ooooo0_l00005oooo
o`;o00001Oooool2o`0000Cooooo0ol00003ooooo`Ko000000?oooooo`000?l000005ol00002oooo
o`Co00001?ooool2o`0000_ooooo0_l0000;ooooo`;o00002?ooool2o`0000?ooooo1_l0000:oooo
o`;o00004Oooool3o`0001kooooo1?l0000Cooooo`;o0000<Oooool001cooooo0_l0001:ooooo`;o
000000?oooooo`000?l000000_l00004ooooo`;o00001Oooool2o`0000Cooooo1Ol00002ooooob3o
00000_ooool4o`0000Cooooo0_l00005ooooo`;o00006Oooool2o`0000?ooooo2?l0000:ooooo`;o
00004?ooool2o`0001kooooo1_l00005ooooo`;o00000_ooool2o`0000Sooooo0_l0000aooooo`00
7?ooool00ol0003oooooooooo`0gooooo`;o00003oooool3o`000003ooooool0003o000000Kooooo
0_l00005ooooo`;o00001?ooool2o`000003ooooool0003o000002?o000000?oooooo`000?l00000
1_ooool2o`0000Gooooo0_l0000Dooooo`;o00000oooool2o`000003ooooool0003o000000Oo0000
4Oooool3o`0000Cooooo1?l000000ooooooo0000o`00000Nooooo`Co00001oooool2o`0000;ooooo
0_l0000kooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00003oooool2o`000004ooooool0
003o0000o`0000Oooooo0_l0000?ooooo`;o000000Coooooo`000?l0003ooooo4Ol000000ooooooo
0000o`00000<o`0000kooooo0_l0000@ooooo`;o000000?oooooo`000?l000001_ooool7o`0000Go
oooo0_l00009ooooo`;o000000Coooooo`000?l0003o00001?ooool4o`0001kooooo0_l00002oooo
o`?o00001?ooool2o`0000kooooo0_l0000booooo`007?ooool00ol0003oooooooooo`16ooooo`;o
00000oooool2o`0000Sooooo0_l00004ooooo`;o00002Oooool=o`000003ooooool0003o000000Co
000000?oooooo`000?l000003Ol00006ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Ko
oooo0_l00003ooooo`;o000000?oooooo`000?l000000_l00009ooooo`;o00000_ooool5o`0000?o
oooo0_l00009ooooo`;o00001?ooool2o`000003ooooool0003o0000027ooooo0_l00004ooooo`?o
00000_ooool2o`0000Kooooo0_l00006ooooo`;o0000<_ooool001cooooo00?o0000ooooooooool0
>oooool2o`0000Wooooo1?l000000ooooooo0000o`000009ooooo`;o00000oooool2o`0000Wooooo
1_l000000ooooooo0000o`00000Io`000003ooooool0003o000000;o00000oooool2o`000003oooo
ool0003o000000gooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo1?l00005ooooo`;o
00000_ooool6o`0001Cooooo0_l000000ooooooo0000o`00000Wooooo`?o00002_ooool2o`0003[o
oooo000Looooo`03o`000?oooooooooo01oooooo0_l0000Jooooo`Go00001oooool3o`0000cooooo
0_l0000=ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`00000Io`000003oooo
ool0003o000000;o000000?oooooo`000?l000000_l0000Jooooo`Go00000_ooool2o`000003oooo
ool0003o000000;ooooo0_l000000ooooooo0000o`00000Dooooo`;o000000?oooooo`000?l00000
<?ooool2o`0003oooooo000Looooo`03o`000?oooooooooo01oooooo0_l0000Jooooo`Go00001ooo
ool2o`0000;ooooo0_l00003ooooo`?o00000oooool2o`0000_ooooo1?l000000ooooooo0000o`00
0002o`0000?ooooo2Ol000000ooooooo0000o`00000:o`0000Cooooo1?l000001?oooooo0000o`00
0?ooool2o`0001Wooooo0_l00005ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o0000
1Oooool2o`0000kooooo0_l000001?oooooo0000o`000?l0000Xooooo`?o00000oooool4o`0003ko
oooo000Looooo`03o`000?oooooooooo047ooooo0_l000000ooooooo0000o`000005ooooo`;o0000
0oooool3o`00013ooooo0ol00004ooooo`;o000000?oooooo`000?l000004_l00009ooooo`Wo0000
0oooool4o`0000Kooooo0_l00003ooooo`;o00000oooool2o`0000Oooooo0_l000000ooooooo0000
o`000006o`0000?ooooo1?l00003ooooo`;o00003Oooool2o`0002Sooooo0ol00003ooooo`Co0000
?_ooool001cooooo00?o0000ooooooooool0@Oooool2o`000003ooooool0003o000001gooooo0_l0
0005ooooo`Go00000_ooool2o`000003ooooool0003o000000Oo00001Oooool6o`000005ooooool0
003o0000o`000?ooool01?l000001?oooooo0000o`000?ooool7o`0000?ooooo0ol00003ooooo`;o
00000oooool2o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l000001?l00002ooooo`Go
00000oooool2o`0002cooooo0_l0000Hooooo`;o0000=oooool001cooooo00?o0000ooooooooool0
B?ooool2o`000003ooooool0003o000000?ooooo0_l0000Aooooo`;o00001oooool4o`000003oooo
ool0003o000000[o00000_ooool2o`000003ooooool0003o000000Co000000?oooooo`000?l00000
0oooool2o`0000;ooooo1Ol00003ooooo`;o00000oooool2o`0000Wooooo1_l00005ooooo`Wo0000
00?oooooo`000?l000000_l00005ooooo`;o00005?ooool2o`000003ooooool0003o000001?ooooo
0_l0000:ooooo`;o00000_ooool2o`0000Sooooo0_l0000gooooo`007?ooool00ol0003ooooooooo
o`18ooooo`;o000000?oooooo`000?l000000oooool2o`0000Oooooo0_l0000;ooooo`?o00000_oo
ool5o`0000?ooooo0ol000000ooooooo0000o`000002ooooo`;o00000_ooool3o`0000;ooooo0_l0
0008ooooo`;o00000oooool2o`0001Oooooo0ol00008ooooo`;o000000?oooooo`000?l000000ooo
ool2o`0000Gooooo0_l0000?ooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`;o0000
4Oooool2o`0000Wooooo0_l00002ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0>ooo
ool2o`0000Wooooo0_l00004ooooo`;o00001Oooool2o`0000Cooooo0_l0000;ooooo`?o00000_oo
ool2o`0000Cooooo0_l000000ooooooo0000o`000003o`0000Kooooo0ol00002ooooo`;o000000Co
ooooo`000?l0003o00001?ooool2o`0000_ooooo0_l0000@ooooo`;o00002?ooool2o`000003oooo
ool0003o000000?o000000?oooooo`000?l000001?ooool4o`0000gooooo0_l0000;ooooo`;o0000
4Oooool2o`0000Gooooo0_l00004ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0>ooo
ool2o`0000Sooooo1?l00003ooooo`;o00001Oooool2o`0000kooooo0_l00003ooooo`;o000000?o
ooooo`000?l000001?ooool6o`0000cooooo0_l00002ooooo`?o00004Oooool3o`0001Wooooo2?l0
00001Ooooooo0000o`000?l0003ooooo00;o000000Coooooo`000?l0003o00004oooool2o`0000?o
oooo0ol0000Iooooo`;o00000oooool5o`00047ooooo000Looooo`03o`000?oooooooooo04Gooooo
1?l0000Jooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`;o00000_ooool6o`0000_o
oooo0_l0000Gooooo`;o00005oooool6o`0000?ooooo3_l0000Aooooo`;o00000oooool3o`0001ko
oooo0_l000000ooooooo0000o`000011ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5oooo
o`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0BOooool2
o`0000;ooooo0_l0000:ooooo`Co00000oooool4o`000003ooooool0003o000000Cooooo0_l00000
0ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000001Ol00003ooooo`?o000000?ooooo
o`000?l00000;?ooool2o`0000;ooooo0_l00006ooooo`oo00000oooool2o`0002Oooooo0_l0000=
ooooo`;o0000@?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go
EEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo04Cooooo0_l00003ooooo`;o0000
0_ooool2o`000003ooooool0003o000000Oooooo1_l000000ooooooo0000o`000005o`0000Sooooo
0_l00006ooooo`Go000000?oooooo`000?l000000ol00006ooooo`;o000000?oooooo`000?l00000
6oooool2o`0000Oooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00000_ooool2o`00013o
oooo0_l0000<ooooo`;o000000?oooooo`000?l000005_ooool2o`0000gooooo0_l00010ooooo`00
00?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`0kooooo`;o00001Oooool4o`0000Kooooo0ol000000ooooooo
0000o`000003ooooo`;o00001Oooool3o`000003ooooool0003o000000;ooooo0_l00009ooooo`Co
00001?ooool2o`0000Cooooo0_l00002ooooo`Co00000oooool2o`000003ooooool0003o000000_o
oooo0_l0000=ooooo`?o00001oooool5o`0000?ooooo0_l0000=ooooo`;o00004oooool6o`0006Ko
oooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oiRHV?oooooo
V9RHob4Q8@06ooooo`?o0000>oooool4o`0000?ooooo0_l00002ooooo`;o00001?ooool3o`0000Ko
oooo0_l00009ooooo`;o00003oooool2o`0000;ooooo0_l00007ooooo`;o000000?oooooo`000?l0
00000_l00005ooooo`?o00001?ooool2o`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l0
00001_ooool2o`0000Sooooo0ol00006ooooo`;o00002oooool3o`0000Cooooo0_l0000<ooooo`Co
000000?oooooo`000?l000006?ooool2o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l0
0000?oooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oEEEE
o`000?l@413oc<c<00Kooooo00?o0000ooooooooool0??ooool3o`0000Gooooo1?l00006ooooo`;o
00001Oooool2o`0001Cooooo0_l00004ooooo`;o00000_ooool2o`0000Oooooo1_l00006ooooo`?o
00001?ooool6o`0000Gooooo0_l000000ooooooo0000o`00000Eooooo`;o00000_ooool2o`0000_o
oooo0_l00005ooooo`;o00003?ooool2o`0001_ooooo1?l00003ooooo`;o00000oooool2o`000003
ooooool0003o000003oooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo
00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`0looooo`;o00001_ooool2o`0000Oooooo
0ol00005ooooo`Co00004_ooool2o`0000Cooooo0_l00002ooooo`;o00001oooool6o`0000gooooo
1_l00005ooooo`?o00001_ooool2o`0000oooooo0_l00011ooooo`;o00001Oooool2o`0000?ooooo
0_l00012ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00So
oooo00?o0000ooooooooool0@_ooool2o`0000;ooooo0_l00005ooooo`?o00001_ooool4o`0000;o
oooo0_l00005ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l00003ooooo`;o
00001oooool2o`0000Kooooo0_l00009ooooo`;o00001?ooool2o`000003ooooool0003o000000?o
00001_ooool2o`0000_ooooo0_l00002ooooo`;o00000oooool2o`0001Kooooo0_l000001?oooooo
0000o`000?l00005ooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o00001_ooool2
o`0000Oooooo0_l00004ooooo`;o00000_ooool2o`0004;ooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`11ooooo`?o0000
0_ooool2o`0000Cooooo0_l000000ooooooo0000o`000005ooooo`Co00000_ooool2o`0000?ooooo
1?l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000ol0000=ooooo`;o0000
1Oooool2o`0000?ooooo0_l00004ooooo`;o00001?ooool2o`000004ooooool0003o0000o`0000Co
oooo0_l00002ooooo`;o00002oooool2o`0000;ooooo0_l00003ooooo`;o00005_ooool2o`000004
ooooool0003o0000o`0000Gooooo0_l000001?oooooo0000o`000?ooool2o`0000Cooooo0_l00006
ooooo`;o00001oooool2o`0000Cooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`11oooo
o`;o00002Oooool5o`0000;ooooo0_l00007ooooo`;o00000oooool2o`0000[ooooo0ol00006oooo
o`;o00001oooool2o`0000[ooooo0_l00004ooooo`?o00001?ooool3o`0000Kooooo0_l00002oooo
o`Co00001?ooool2o`0000Gooooo0_l000000ooooooo0000o`000006ooooo`;o00004?ooool4o`00
0003ooooool0003o0000037ooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`14ooooo`;o
00001_ooool4o`000003ooooool0003o000000;o00001oooool2o`0001Sooooo0_l0000Iooooo`?o
00000oooool4o`0000Sooooo0_l00002ooooo`;o00000_ooool8o`000004ooooool0003o0000oooo
o`;o00001_ooool2o`00013ooooo0_l00007ooooo`;o00002oooool2o`00023ooooo0_l0000noooo
o`007?ooool00ol0003oooooooooo`0Vooooo`;o00007?ooool2o`0000_ooooo0_l00002ooooo`;o
0000=oooool2o`0000Cooooo1Ol00003ooooo`;o00001Oooool2o`0000;ooooo0_l00002ooooo`co
00008oooool2o`0000_ooooo0_l0000Oooooo`;o0000?oooool001cooooo00?o0000ooooooooool0
9_ooool2o`0001Wooooo0_l0000@ooooo`Co0000=oooool2o`0000;ooooo1ol00003ooooo`;o0000
2?ooool2o`0000Cooooo0_l00004ooooo`Go00001_ooool3o`0000Gooooo0_l0000<ooooo`;o0000
4_ooool2o`0000?ooooo0_l0000@ooooo`;o00002?ooool3o`0003kooooo000Looooo`03o`000?oo
oooooooo047ooooo0_l00009ooooo`;o00001Oooool2o`0000Gooooo0ol00007ooooo`;o00005ooo
ool2o`0000;ooooo1?l0000=ooooo`Oo00000oooool2o`0000?ooooo0_l000000ooooooo0000o`00
0002o`0000Cooooo0ol00002ooooo`?o000000?oooooo`000?l000000_ooool2o`0000;ooooo1?l0
0004ooooo`;o00003?ooool2o`0000;ooooo0_l0000:ooooo`;o00001?ooool6o`000003ooooool0
003o000000?ooooo0_l00007ooooo`?o00002?ooool2o`0003kooooo000Looooo`03o`000?oooooo
oooo04;ooooo0_l00008ooooo`?o00001?ooool2o`0000Gooooo0ol00007ooooo`;o00001_ooool2
o`0000;ooooo0_l00003ooooo`;o00001_ooool2o`0000;ooooo1?l00005ooooo`;o000000?ooooo
o`000?l000001?ooool;o`000003ooooool0003o000000;o000000?oooooo`000?l000001oooool2
o`0000;ooooo0_l00006ooooo`;o00001?ooool4o`0001Cooooo1?l00008ooooo`;o00000oooool4
o`000004ooooool0003o0000ooooo`;o00000oooool2o`0000Gooooo1Ol00003ooooo`Ko0000?ooo
ool001cooooo00?o0000ooooooooool0:?ooool2o`0001Gooooo0_l000000ooooooo0000o`000004
ooooo`;o00000oooool2o`000003ooooool0003o0000013ooooo0_l00008ooooo`?o000000?ooooo
o`000?l000000oooool2o`000003ooooool0003o0000013ooooo0_l000001?oooooo0000o`000?l0
0003ooooo`ko00001?ooool2o`0000Kooooo0_l0000Booooo`;o00005?ooool4o`0000Sooooo0_l0
0003ooooo`;o000000?oooooo`000?l000003oooool5o`0000?ooooo1_l0000oooooo`007?ooool0
0ol0003oooooooooo`0Xooooo`;o00005Oooool2o`0000Oooooo0_l00002ooooo`;o00000_ooool4
o`0000kooooo0_l00009ooooo`;o00002Oooool2o`0001?ooooo0ol00003ooooo`Co00000_ooool3
o`000003ooooool0003o000000?o00000_ooool5o`0000Cooooo0_l0000Kooooo`;o00002oooool3
o`00017ooooo1?l0000<ooooo`;o00000_ooool2o`0004Sooooo000Looooo`03o`000?oooooooooo
04?ooooo0_l00003ooooo`?o000000?oooooo`000?l000000_ooool4o`0000kooooo0_l0000_oooo
oaSo00000_ooool2o`0000cooooo0_l00007ooooo`;o00000oooool3o`00027ooooo0_l000000ooo
oooo0000o`000009ooooo`;o00002?ooool2o`0004;ooooo000Looooo`03o`000?oooooooooo047o
oooo1_l00002ooooo`;o00001Oooool4o`0000cooooo1?l00004ooooo`;o00007oooool3o`0000;o
oooo0_l00004oooooa3o00000_ooool5o`00013ooooo0_l00002ooooo`;o00000oooool2o`0000?o
oooo0_l0000Tooooo`?o00004oooool2o`0004;ooooo000Looooo`03o`000?oooooooooo047ooooo
0_l00002ooooo`;o00002?ooool7o`0000[ooooo0_l00006ooooo`;o00007oooool7o`000004oooo
ool0003o0000ooooo`ko00001_ooool3o`0000Kooooo0_l00005ooooo`;o000000?oooooo`000?l0
00001?l00009ooooo`Co00002_ooool2o`0001Gooooo0_l0000;ooooo`;o0000Boooool001cooooo
0_l00017ooooo`;o00000oooool2o`0000;ooooo1ol00003ooooo`;o00000_ooool2o`0002gooooo
1?l000001?oooooo0000o`000?oooolBo`0000?ooooo0_l00006ooooo`;o00001Oooool2o`0000?o
oooo1Ol00005ooooo`So00001_ooool2o`000004ooooool0003o0000o`0001oooooo1_l00002oooo
o`;o0000AOooool001cooooo00?o0000ooooooooool0A_ooool2o`0000?ooooo0_l00004ooooo`;o
00000oooool2o`000003ooooool0003o000000;ooooo0_l0000Rooooo`?o00002_ooool3o`0000?o
oooo5?l0000:ooooo`;o00002Oooool2o`000003ooooool0003o000000Gooooo2?l00004ooooo`Co
00000_ooool2o`0001oooooo0_l00002ooooo`;o00000_ooool2o`0004Gooooo000Looooo`03o`00
0?oooooooooo047ooooo0ol0000=ooooo`;o00000oooool2o`0002Wooooo0ol0000;ooooo`;o0000
0ooooolIo`0000?ooooo1?l00004ooooo`;o00000oooool2o`0000Oooooo3?l000000ooooooo0000
o`000006ooooo`;o00005?ooool2o`0000?ooooo0_l0001Aooooo`007?ooool00ol0003ooooooooo
o`11ooooo`?o00000oooool2o`0004_ooooo6ol000000ooooooo0000o`000002ooooo`;o00000_oo
ool4o`0000Sooooo3ol00008ooooo`;o00004_ooool4o`0000?ooooo0_l00006ooooo`;o0000BOoo
ool001cooooo00?o0000ooooooooool0;Oooool2o`0001Sooooo0_l00002ooooo`;o0000?_ooool2
o`0000;ooooo0ol00002oooooa_o00001Oooool3o`0000;ooooo0ol00008ooooo`oo00001oooool2
o`0001?ooooo0_l0000=ooooo`Co0000Aoooool001cooooo00?o0000ooooooooool0;Oooool2o`00
01cooooo0_l000000ooooooo0000o`000004ooooo`Co0000<oooool2o`0000;ooooo0ol00002oooo
oa[o000000?oooooo`000?l000001?ooool2o`0000_ooooo0_l000000ooooooo0000o`00000@o`00
00?ooooo0_l0000Eooooo`;o00000_ooool2o`0000Wooooo0_l00017ooooo`007?ooool00ol0003o
ooooooooo`18ooooo`;o00001?ooool2o`0000Cooooo1?l0000Booooo`;o00005_ooool2o`0000co
oooo7Ol000001?oooooo0000o`000?l00007ooooo`Ko00001?ooool2o`000003ooooool0003o0000
013o00000oooool2o`00013ooooo0_l00003ooooo`;o00000_ooool2o`0000Oooooo0_l00019oooo
o`007?ooool00ol0003oooooooooo`0_ooooo`;o00005oooool2o`0000[ooooo0ol0000<ooooo`;o
00001Oooool2o`0001Kooooo0ol00009ooooo`;o000000?oooooo`000?l000000ol00002oooooaSo
00001oooool7o`0000Oooooo2Ol00002ooooo`Co00006?ooool2o`0000Cooooo0_l000000ooooooo
0000o`000007ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0;oooool2o`0001[ooooo
0_l00008ooooo`;o00003?ooool2o`0000Kooooo0_l0000Fooooo`;o00002?ooool3o`000003oooo
ool0003o000001go00001oooool5o`0000?ooooo0_l00006ooooo`ko00000_ooool2o`0000;ooooo
0_l00005ooooo`;o00003_ooool5o`0005;ooooo000Looooo`03o`000?oooooooooo04_ooooo0_l0
000Mooooo`?o00007oooool3o`0000?ooooo2_l000000ooooooo0000o`000007o`0000;ooooo2?l0
0003ooooo`;o00001Oooool2o`000003ooooool0003o000000;o00001_ooool>o`0000;ooooo0_l0
0002ooooo`;o00001?ooool3o`0000?ooooo0_l00009ooooo`Go00000_ooool2o`0004kooooo000L
ooooo`03o`000?oooooooooo04gooooo0_l000000ooooooo0000o`000008ooooo`Co00003?ooool2
o`00023ooooo0_l00004ooooo`;o000000?oooooo`000?l000006Ol00003ooooo`;o00002?ooool2
o`0000Sooooo4?l0000:ooooo`;o00001?ooool4o`0000Oooooo0_l00005ooooo`;o0000C_ooool0
01cooooo00?o0000ooooooooool0B_ooool2o`000004ooooool0003o0000ooooo`;o00000oooool2
o`0000?ooooo1Ol0000Yooooo`;o000000?oooooo`000?l000001OoooolMo`0000?ooooo0_l00009
ooooo`;o00002Oooool<o`000003ooooool0003o000001;ooooo0_l00006ooooo`;o0000E_ooool0
01cooooo00?o0000ooooooooool0<oooool2o`0001Gooooo0ol00008ooooo`;o000000?oooooo`00
0?l000000oooool2o`0002Wooooo0_l000000ooooooo0000o`000006oooooa[o00001Oooool2o`00
01Cooooo0_l00003ooooo`Ko00004oooool2o`0000Wooooo0_l00002ooooo`?o0000DOooool001co
oooo00?o0000ooooooooool0<oooool2o`0001Cooooo1_l00009ooooo`;o0000=Oooool2o`0000;o
oooo6ol000000ooooooo0000o`00000<ooooo`;o00003Oooool6o`0000;ooooo0_l0000@ooooo`?o
00001Oooool2o`0000Gooooo0ol0001Aooooo`007?ooool00ol0003oooooooooo`19ooooo`;o0000
0_ooool2o`0001_ooooo0_l0000Sooooo`?o00000_oooolJo`000003ooooool0003o000000cooooo
0ol0000<ooooo`;o00000_ooool2o`0000;ooooo0_l0000>ooooo`Go00001Oooool2o`0000Kooooo
0_l0001Aooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00005?ooool3o`0000Cooooo0_l0
000Gooooo`;o00000_ooool2o`0000Oooooo0_l00002ooooo`So000000?oooooo`000?l000001?l0
0002ooooo`Wo00001?ooool2o`0000Kooooo0_l000001?oooooo0000o`000?l0000Gooooo`;o0000
2Oooool4o`000003ooooool0003o000000Gooooo0_l0001Iooooo`007?ooool2o`0004kooooo0_l0
000Dooooo`?o00007Oooool2o`0000;ooooo0_l00009ooooo`Co000000?oooooo`000?l000005_l0
0002ooooo`?o00001_ooool2o`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l000000_oo
ool2o`0000Wooooo0_l00003ooooo`So00002?ooool3o`0000Sooooo0_l0001@ooooo`007?ooool0
0ol0003oooooooooo`17ooooo`;o00001_ooool2o`0000Sooooo0_l00004ooooo`;o00001Oooool2
o`0001[ooooo0ol0000;ooooo`Go00000_oooolIo`000003ooooool0003o000000kooooo0_l00002
ooooo`;o000000?oooooo`000?l000000_ooool2o`0000kooooo2?l00008ooooo`?o00002?ooool2
o`00053ooooo000Looooo`03o`000?oooooooooo04Oooooo0_l00006ooooo`;o00001Oooool2o`00
0004ooooool0003o0000o`0000;ooooo0ol00002ooooo`;o000000?oooooo`000?l000006_ooool2
o`0000cooooo1Ol00002oooooaWo000000?oooooo`000?l000009Oooool2o`000003ooooool0003o
000000Oo00001?ooool2o`0005oooooo000Looooo`03o`000?oooooooooo04oooooo0ol00004oooo
o`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o00001_ooool2o`0001_ooooo0_l00008oooo
ob7o00008Oooool2o`0000;ooooo1ol000000ooooooo0000o`000006ooooo`;o0000Goooool001co
oooo00?o0000ooooooooool0Coooool3o`0000_ooooo0_l0000<ooooo`;o00006oooool2o`0000Go
oooo0_l00003oooooaoo00000oooool2o`0001cooooo2_l000000ooooooo0000o`000002o`0006Ko
oooo000Looooo`03o`000?oooooooooo05gooooo0_l000000ooooooo0000o`000009ooooo`;o0000
6_ooool2o`0000Kooooo0_l00004ooooo`;o000000?oooooo`000?l000004Ol000001?oooooo0000
o`000?l00003ooooo`;o00000_ooool2o`0000;ooooo0_l0000Cooooo`;o00000oooool5o`000003
ooooool0003o000000?ooooo1?l0001Vooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o0000
4_ooool2o`0000Wooooo0_l0000Jooooo`Co00002_ooool2o`000003ooooool0003o000000?ooooo
0ol000000ooooooo0000o`000009o`0000;ooooo0_l00002ooooo`;o00001_ooool2o`0000Wooooo
0_l00005ooooo`;o000000?oooooo`000?l000001_ooool2o`00073ooooo000Looooo`03o`000?oo
oooooooo03[ooooo0_l0000@ooooo`?o00000_ooool2o`0000gooooo0_l00007ooooo`?o00006Ooo
ool2o`0000;ooooo0_l0000=ooooo`;o00000_ooool8o`0000;ooooo1_l00002ooooo`;o00005?oo
ool3o`0000Gooooo0_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l00000L?oo
ool001cooooo00?o0000ooooooooool0>_ooool2o`00017ooooo0_l00002ooooo`;o00002Oooool2
o`0000;ooooo0_l00007ooooo`?o00006Oooool6o`0000kooooo0_l000000ooooooo0000o`000006
o`000003ooooool0003o000000Go00005?ooool3o`000003ooooool0003o000000?ooooo0_l00004
ooooo`;o00000oooool2o`0000[ooooo0_l00002ooooo`;o00001_ooool2o`0000?ooooo0_l0001F
ooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00002Oooool2o`0000;ooooo0_l0000Xoooo
o`Go00003_ooool2o`0000;ooooo2_l000000ooooooo0000o`000006ooooo`;o00003_ooool3o`00
00Kooooo0_l000000ooooooo0000o`000002ooooo`;o00003?ooool9o`0000Cooooo2?l0001Foooo
o`007?ooool00ol0003oooooooooo`1=ooooo`;o00002Oooool2o`0000Gooooo0_l0000looooo`;o
000000?oooooo`000?l000001Ol000000ooooooo0000o`000006ooooo`;o00005oooool9o`0000co
oooo0_l000000ooooooo0000o`000004o`0000Cooooo1_l0001Hooooo`007?ooool00ol0003ooooo
ooooo`1Oooooo`;o00007oooool3o`0000Kooooo0_l00003ooooo`;o00004?ooool2o`0000?ooooo
0_l0000?ooooo`;o00003Oooool2o`0000;ooooo1ol0000@ooooo`Oo00001_ooool2o`0005[ooooo
000Looooo`03o`000?oooooooooo03gooooo0_l0000Hooooo`;o00002Oooool2o`0001cooooo0ol0
0006ooooo`;o00000oooool2o`0001Oooooo0_l0000=ooooo`;o00003Oooool2o`0000?ooooo1_l0
000@ooooo`Oo0000H_ooool001cooooo00?o0000ooooooooool0?Oooool2o`0001Sooooo0_l00003
ooooo`;o00001?ooool4o`0002Cooooo0_l00003ooooo`;o00005_ooool2o`0000Kooooo0_l00003
ooooo`?o00002oooool2o`000003ooooool0003o000000?ooooo1?l00007ooooo`;o000000?ooooo
o`000?l000001_ooool7o`0006;ooooo000Looooo`03o`000?oooooooooo05Wooooo0_l000000ooo
oooo0000o`000006ooooo`;o00008_ooool4o`0000?ooooo0_l0000@ooooo`;o00002oooool5o`00
0004ooooool0003o0000o`0000_ooooo0_l000001?oooooo0000o`000?l0000=ooooo`;o000000?o
ooooo`000?l000001_ooool4o`0006Gooooo000Looooo`03o`000?oooooooooo05Wooooo0_l00003
ooooo`;o0000:?ooool4o`0000kooooo0_l00005ooooo`;o00002oooool5o`0000_ooooo0_l00000
0ooooooo0000o`000003ooooo`;o00001_ooool2o`0000;ooooo0_l00007ooooo`?o0000Joooool0
01cooooo0_l0001Nooooo`?o0000:?ooool3o`0000Oooooo0_l00006ooooo`Co00004?ooool4o`00
00Oooooo0_l00003ooooo`;o000000?oooooo`000?l000002oooool2o`0000;ooooo0_l00007oooo
o`?o0000Joooool001cooooo00?o0000ooooooooool0EOooool2o`0000Kooooo0_l0000Wooooo`;o
000000?oooooo`000?l000001oooool2o`0000Kooooo1?l00007ooooo`;o00001?ooool2o`0000?o
oooo0_l00004ooooo`;o000000?oooooo`000?l000000oooool2o`0000Cooooo0_l0000Cooooo`;o
00002Oooool2o`0006?ooooo000Looooo`03o`000?oooooooooo05Gooooo0_l00009ooooo`;o0000
00?oooooo`000?l000006Oooool2o`0000Kooooo0_l0000?ooooo`;o00003?ooool2o`0000Cooooo
0_l00003ooooo`;o00001?ooool2o`0000Kooooo0_l00004ooooo`;o00001?ooool2o`0000;ooooo
0_l00009ooooo`;o00002Oooool2o`0006?ooooo000Looooo`03o`000?oooooooooo05kooooo1?l0
00000ooooooo0000o`00000Iooooo`;o00001_ooool2o`0000Kooooo0_l000000ooooooo0000o`00
0002o`0000;ooooo0_l00003ooooo`;o00005Oooool2o`000003ooooool0003o000000_ooooo0ol0
0004ooooo`;o00000_ooool2o`0007Wooooo000Looooo`03o`000?oooooooooo05kooooo0_l00000
0ooooooo0000o`000002ooooo`;o00009?ooool2o`000004ooooool0003o0000ooooo`Co00001ooo
ool2o`0000kooooo0_l00005ooooo`?o00003Oooool3o`0000Kooooo0_l00002ooooo`Co00002?oo
ool2o`0006_ooooo000Looooo`03o`000?oooooooooo067ooooo0_l00002ooooo`;o00003_ooool2
o`000003ooooool0003o0000017ooooo0_l000000ooooooo0000o`00000?ooooo`;o00002oooool2
o`0000Kooooo0_l0000Fooooo`;o00000_ooool4o`0000Sooooo0_l0001[ooooo`007?ooool00ol0
003oooooooooo`1^ooooo`;o00001Oooool2o`000003ooooool0003o000000;ooooo0_l00006oooo
o`?o00002?ooool4o`0000?ooooo0_l00007ooooo`?o00009Oooool2o`0000Oooooo0ol00009oooo
o`;o0000Joooool001cooooo00?o0000ooooooooool0H?ooool2o`0000cooooo0_l0000<ooooo`;o
00001_ooool3o`0000Sooooo1?l00003ooooo`Co00001_ooool3o`0000Cooooo0_l00007ooooo`?o
00005?ooool2o`0000Oooooo0ol00009ooooo`;o0000Joooool001cooooo00?o0000ooooooooool0
H?ooool2o`0000;ooooo0_l0000Mooooo`;o00001oooool2o`0000;ooooo0_l00006ooooo`;o0000
1oooool2o`000004ooooool0003o0000ooooo`;o00001_ooool4o`0000kooooo1Ol00003ooooo`;o
00003?ooool2o`00073ooooo000Looooo`03o`000?oooooooooo04Sooooo0_l0000Jooooo`;o0000
1oooool4o`0001;ooooo0_l00007ooooo`;o00002oooool2o`0000;ooooo0_l00005ooooo`?o0000
2?ooool3o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo1Ol00002ooooo`?o0000
3?ooool2o`00073ooooo000Looooo`03o`000?oooooooooo04Sooooo0_l0000Jooooo`;o00001ooo
ool4o`0000Cooooo0_l0000Eooooo`;o00000oooool2o`0000Kooooo0_l00002ooooo`;o00001_oo
ool2o`0000Sooooo0ol00002ooooo`;o00000oooool3o`000003ooooool0003o000000;o000000?o
ooooo`000?l000000_l00002ooooo`;o00000_ooool2o`0007_ooooo000Looooo`03o`000?oooooo
oooo05oooooo0_l0000Dooooo`;o00003?ooool2o`0000?ooooo1_l00003ooooo`;o00009oooool2
o`000003ooooool0003o000000;o000000?oooooo`000?l000000_l00006ooooo`;o00000_ooool2
o`0007Oooooo000Looooo`03o`000?oooooooooo05oooooo0_l00006ooooo`;o00005oooool5o`00
00;ooooo1ol000000ooooooo0000o`000002ooooo`?o00002?ooool2o`0000Sooooo0_l0000Ioooo
o`;o00002Oooool4o`0007Oooooo000Looooo`03o`000?oooooooooo06Oooooo0_l0000Gooooo`?o
00001?ooool4o`0000Cooooo0_l00002ooooo`?o00000oooool2o`0000?ooooo0_l00008ooooo`;o
00001?ooool2o`0000?ooooo0_l00003ooooo`;o00005?ooool2o`000003ooooool0003o000007Ko
oooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000
ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2=ooooo`Co00002?ooool2o`0000Oooooo0_l00009
ooooo`Go000000?oooooo`000?l000000oooool2o`0000Sooooo0ol0000<ooooo`;o0000M_ooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RH
ob4Q8@06ooooo`03o`000?oooooooooo08gooooo1Ol00002ooooo`;o00003?ooool4o`0000Oooooo
1Ol00003ooooo`;o00000oooool2o`0000Kooooo0ol0000:ooooo`;o0000N?ooool00003ooooool@
413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0L?ooool3o`0001gooooo0_l00002ooooo`;o00003_ooool5o`0000Kooooo
0_l00004ooooo`Co000000?oooooo`000?l000003oooool2o`0000;ooooo0_l0001hooooo`0000?o
ooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80
1_ooool3o`00073ooooo0ol00009ooooo`;o0000:?ooool5o`0000cooooo0_l000000ooooooo0000
o`000002ooooo`;o00002oooool2o`0000Wooooo1?l0001_ooooo`0000?oooooo`000?ooool00_oo
ool00ol0003oooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003ooooo
ooooo`1eooooo`;o00001Oooool2o`0002_ooooo1?l0000Aooooo`;o00005_ooool4o`0006oooooo
00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go410@okZj^_oooooo^[Zj
oa0@4006ooooo`03o`000?oooooooooo05?ooooo0_l0000Pooooo`;o00004_ooool2o`00013ooooo
0_l00008ooooo`;o00001?ooool2o`0000;ooooo1?l0000Jooooo`;o0000N_ooool00006oooooomg
MgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000oooo
ooooool0Doooool2o`0002Kooooo0_l0000<ooooo`;o00004?ooool2o`0000Sooooo0_l000000ooo
oooo0000o`000003ooooo`Ko000000?oooooo`000?l000003Oooool2o`0000Sooooo0_l0001joooo
o`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_oo
ool00ol0003oooooooooo`1kooooo`;o000000?oooooo`000?l000008?ooool2o`0000Cooooo1?l0
0003ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l00007ooooo`;o0000Q?oo
ool001cooooo00?o0000ooooooooool0O_ooool2o`0000cooooo0_l00004ooooo`;o00003?ooool3
o`0000?ooooo0_l00008ooooo`;o00002?ooool2o`0008gooooo000Looooo`03o`000?oooooooooo
08Cooooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo0ol0000=ooooo`;o000000?oooooo`00
0?l000005Oooool4o`0008[ooooo000Looooo`03o`000?oooooooooo08Cooooo0_l00002ooooo`Co
00001Oooool2o`00017ooooo0_l0000Eooooo`Co0000R_ooool001cooooo00?o0000ooooooooool0
R_ooool2o`000;gooooo000Looooo`03o`000?oooooooooo05_ooooo0_l0000Tooooo`;o00000ooo
ool2o`0004?ooooo0_l0001looooo`007?ooool00ol0003oooooooooo`1Kooooo`;o00009?ooool2
o`0000?ooooo0_l00003ooooo`;o0000?_ooool2o`0007cooooo000Looooo`03o`000?oooooooooo
08_ooooo0_l00004ooooo`;o00008?ooool2o`0009Cooooo000Looooo`03o`000?oooooooooo097o
oooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo0_l00003ooooo`;o00003_ooool2o`0009Co
oooo000Looooo`03o`000?oooooooooo09Gooooo0_l00002ooooo`;o00000oooool2o`0000?ooooo
0_l0000>ooooo`;o0000U?ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`2:ooooo`;o000000?oooooo`000?l00000^_ooool001cooooo0_l0001Uoooo
o`;o00009?ooool2o`000003ooooool0003o00000;[ooooo000Looooo`03o`000?oooooooooo06Co
oooo0_l0000Yooooo`;o0000^?ooool001cooooo00?o0000ooooooooool0Soooool2o`000;Sooooo
000Looooo`03o`000?oooooooooo06Wooooo0_l0003Nooooo`007?ooool00ol0003oooooooooo`1Y
ooooo`;o000000?oooooo`000?l00000:_ooool2o`000:oooooo000Looooo`03o`000?oooooooooo
06cooooo0_l00002ooooo`;o00009_ooool2o`000:oooooo000Looooo`03o`000?oooooooooo073o
oooo0_l0003Gooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo07Sooooo0_l0003?ooooo`00
7?ooool00ol0003oooooooooo`1hooooo`;o0000coooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Booooo`Co
000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003ooooooooo
o`05ooooo`?o0000oooooom:ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Doooo
o`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`00
5?ooool00ol0003oooooooooo`3ooooooe;ooooo000Booooo`03oeEEEOmVIVKo00000?ooooooE?oo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Gooooo00Co410@o`000?l0003o
oooo0_l000000ol@413oooooooooo`0Fooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo<
c<co8B4Qo`000?lQ8B7oc<c<00?ooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c02@ooooo`00Y_ooool0
1Ol0003ooooooooooooooooo000000Wooooo1_l0000=ooooo`09ogMgMolb<S;ooooooooooolQ8B7o
V9RHoooooonHV9So8B4Q00?ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@2@ooooo`00Y_ooool01Ol0
003ooooooooooooooooo000001gooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool0S_ooool00:Kooooo00Go0000oooooooooooooooo
o`000009ooooo`Ko00003Oooool02OmgMgOo<S8boooooooooooo<S8boiRHV?ooooooV9RHoc8b<P03
ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80T?ooool00:Kooooo00Go0000ohN7QoooooooZJVYo`00
000Iooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Oo<c<co0000o`000?l0003oc<c<00?o
oooo00Goc<c<o`000?l0003o0000olc<c02@ooooo`00YOooool00ol@413o0000ogMgM`02o`000003
oiRHV?oooooooooo01Oooooo00?o0000ooooooooool01?ooool01Ol@413o^[Zjoooooonj^[[o410@
00?ooooo00Go410@okZj^_oooooo^[Zjoa0@402@ooooo`00a?ooool00ol0003oooooooooo`04oooo
o`05o`000?nj^[[ooooookZj^_l000000oooool01Ol0003o^[Zjoooooonj^[[o0000093ooooo0034
ooooo`Co00000oooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@2@ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(594) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.47703 .64004 Mdot
.48021 .70259 Mdot
.60687 .33983 Mdot
.35524 .50411 Mdot
.50368 .26862 Mdot
.58673 .37108 Mdot
.69326 .50912 Mdot
.65352 .48156 Mdot
.58672 .38181 Mdot
.24807 .64375 Mdot
.65999 .49067 Mdot
.44686 .53587 Mdot
.68397 .49552 Mdot
.38631 .49421 Mdot
.61061 .6247 Mdot
.38956 .57635 Mdot
.45427 .70128 Mdot
.48904 .32193 Mdot
.39331 .57685 Mdot
.61086 .34783 Mdot
.47108 .45563 Mdot
.38646 .50515 Mdot
.45922 .70219 Mdot
.3868 .49807 Mdot
.33829 .51594 Mdot
.47184 .69158 Mdot
.4883 .64722 Mdot
.36752 .53984 Mdot
.392 .54346 Mdot
.66828 .48289 Mdot
.53976 .21431 Mdot
.61195 .82418 Mdot
.42887 .54294 Mdot
.3956 .66762 Mdot
.64731 .48782 Mdot
.78355 .38718 Mdot
.58503 .39736 Mdot
.66659 .47401 Mdot
.64796 .51028 Mdot
.64854 .51511 Mdot
.70306 .50339 Mdot
.48037 .69045 Mdot
.70089 .52726 Mdot
.53154 .35081 Mdot
.35819 .46741 Mdot
.57254 .78846 Mdot
.55137 .19183 Mdot
.37213 .53983 Mdot
.45899 .64364 Mdot
.60301 .34763 Mdot
.22967 .39675 Mdot
.68517 .46969 Mdot
.61512 .67028 Mdot
.15253 .66953 Mdot
.67027 .48792 Mdot
.36276 .51968 Mdot
.60642 .36637 Mdot
.36392 .49653 Mdot
.38487 .53027 Mdot
.38176 .62745 Mdot
.40159 .52305 Mdot
.47705 .28789 Mdot
.50083 .65315 Mdot
.62364 .37719 Mdot
.59062 .37856 Mdot
.69663 .48314 Mdot
.50133 .70245 Mdot
.69345 .49311 Mdot
.40669 .44971 Mdot
.59701 .33932 Mdot
.37138 .5359 Mdot
.66043 .48598 Mdot
.48412 .70942 Mdot
.33158 .48214 Mdot
.60424 .74798 Mdot
.66552 .4465 Mdot
.50627 .33225 Mdot
.38476 .74665 Mdot
.17622 .50124 Mdot
.66031 .3401 Mdot
.39592 .48972 Mdot
.15463 .46852 Mdot
.61702 .61398 Mdot
.49328 .69924 Mdot
.42049 .64273 Mdot
.79421 .5733 Mdot
.38902 .54727 Mdot
.45985 .39088 Mdot
.38428 .55976 Mdot
.53022 .56845 Mdot
.59054 .38617 Mdot
.46249 .69351 Mdot
.35701 .46695 Mdot
.34699 .54061 Mdot
.2551 .56002 Mdot
.4263 .48644 Mdot
.35355 .47836 Mdot
.43131 .63572 Mdot
.66548 .50694 Mdot
.40144 .43292 Mdot
.53925 .30777 Mdot
.62835 .69802 Mdot
.34571 .49707 Mdot
.56883 .35893 Mdot
.47101 .63206 Mdot
.34876 .4741 Mdot
.68619 .4812 Mdot
.39725 .50488 Mdot
.64505 .46691 Mdot
.44846 .68073 Mdot
.35731 .54708 Mdot
.49474 .28448 Mdot
.56182 .62877 Mdot
.46843 .6515 Mdot
.29133 .73474 Mdot
.39935 .52125 Mdot
.38635 .51878 Mdot
.48969 .69836 Mdot
.61359 .3786 Mdot
.49783 .42767 Mdot
.46674 .70881 Mdot
.65036 .51428 Mdot
.44521 .66493 Mdot
.34669 .54743 Mdot
.61566 .37372 Mdot
.62126 .70501 Mdot
.63273 .69495 Mdot
.42616 .23141 Mdot
.32772 .48927 Mdot
.58176 .66493 Mdot
.58099 .35752 Mdot
.4824 .69532 Mdot
.68875 .48953 Mdot
.41564 .52761 Mdot
.48846 .66384 Mdot
.65297 .51146 Mdot
.45522 .27882 Mdot
.49776 .25974 Mdot
.48851 .65512 Mdot
.29745 .42189 Mdot
.66943 .46445 Mdot
.65503 .52078 Mdot
.241 .38774 Mdot
.49685 .69394 Mdot
.45798 .30269 Mdot
.67411 .52305 Mdot
.35729 .32209 Mdot
.41744 .50744 Mdot
.3123 .29462 Mdot
.16765 .40309 Mdot
.23457 .39256 Mdot
.48489 .79838 Mdot
.49227 .30379 Mdot
.67885 .52469 Mdot
.35411 .52052 Mdot
.48387 .67222 Mdot
.48899 .67812 Mdot
.33189 .52737 Mdot
.33781 .52488 Mdot
.37984 .47553 Mdot
.41235 .52777 Mdot
.71537 .27752 Mdot
.38822 .47653 Mdot
.62226 .56525 Mdot
.48163 .65841 Mdot
.33074 .50729 Mdot
.56135 .36771 Mdot
.33033 .46651 Mdot
.66562 .4748 Mdot
.37817 .52592 Mdot
.34122 .52512 Mdot
.38823 .45707 Mdot
.68923 .52779 Mdot
.69922 .72192 Mdot
.18263 .56858 Mdot
.78474 .46469 Mdot
.5476 .7333 Mdot
.5912 .35682 Mdot
.40538 .4905 Mdot
.47773 .30988 Mdot
.45232 .46957 Mdot
.38971 .52808 Mdot
.21734 .40879 Mdot
.3571 .54024 Mdot
.42744 .77528 Mdot
.34687 .42275 Mdot
.81179 .54774 Mdot
.65546 .58617 Mdot
.40236 .52944 Mdot
.22805 .57904 Mdot
.33755 .26586 Mdot
.49109 .20277 Mdot
.6793 .48461 Mdot
.55908 .37628 Mdot
.60369 .39088 Mdot
.65089 .52148 Mdot
.34887 .42992 Mdot
.25932 .66253 Mdot
.39349 .44227 Mdot
.61838 .70318 Mdot
.52143 .68919 Mdot
.49265 .31078 Mdot
.48704 .65299 Mdot
.14384 .50707 Mdot
.47753 .43112 Mdot
.64464 .427 Mdot
.49762 .31958 Mdot
.57211 .33673 Mdot
.60586 .69516 Mdot
.46665 .31024 Mdot
.35444 .48815 Mdot
.44908 .66267 Mdot
.33387 .26738 Mdot
.33279 .55374 Mdot
.79416 .30444 Mdot
.50194 .69506 Mdot
.55653 .53225 Mdot
.67783 .48777 Mdot
.61572 .39085 Mdot
.38746 .5472 Mdot
.37112 .48508 Mdot
.4961 .6495 Mdot
.37827 .54184 Mdot
.49882 .49893 Mdot
.34748 .53056 Mdot
.60047 .41362 Mdot
.44102 .31971 Mdot
.63026 .48851 Mdot
.41875 .23779 Mdot
.47725 .7118 Mdot
.59338 .51186 Mdot
.56513 .36169 Mdot
.47225 .60961 Mdot
.66704 .47963 Mdot
.46329 .27481 Mdot
.57232 .39039 Mdot
.47165 .26689 Mdot
.34801 .4653 Mdot
.5871 .39434 Mdot
.46348 .2832 Mdot
.62509 .44302 Mdot
.35191 .47871 Mdot
.31779 .31796 Mdot
.68546 .52091 Mdot
.48674 .64763 Mdot
.40101 .5267 Mdot
.62855 .70922 Mdot
.3176 .50527 Mdot
.58645 .64793 Mdot
.6127 .70782 Mdot
.60261 .67611 Mdot
.65644 .4121 Mdot
.45746 .31003 Mdot
.56146 .75999 Mdot
.51355 .44581 Mdot
.45593 .70328 Mdot
.37269 .46255 Mdot
.74854 .69494 Mdot
.68861 .5217 Mdot
.35547 .49157 Mdot
.79489 .55652 Mdot
.67651 .52343 Mdot
.37078 .50431 Mdot
.70387 .50679 Mdot
.48786 .67386 Mdot
.57736 .46699 Mdot
.44055 .66893 Mdot
.35834 .50578 Mdot
.67893 .51156 Mdot
.56339 .385 Mdot
.47181 .69055 Mdot
.39606 .50998 Mdot
.39612 .48513 Mdot
.61295 .69896 Mdot
.32771 .50664 Mdot
.77948 .66036 Mdot
.36947 .53829 Mdot
.57288 .33543 Mdot
.42863 .4933 Mdot
.31396 .27721 Mdot
.48843 .25189 Mdot
.50629 .70253 Mdot
.60602 .7017 Mdot
.59779 .38547 Mdot
.59137 .44466 Mdot
.45689 .23489 Mdot
.39477 .49597 Mdot
.62221 .68839 Mdot
.56046 .52911 Mdot
.6901 .47929 Mdot
.41471 .5434 Mdot
.49937 .4632 Mdot
.57876 .38605 Mdot
.61118 .70018 Mdot
.31178 .4617 Mdot
.45624 .6384 Mdot
.361 .52032 Mdot
.57809 .39628 Mdot
.45616 .64154 Mdot
.41552 .53089 Mdot
.65094 .24034 Mdot
.62997 .70605 Mdot
.69017 .51804 Mdot
.29508 .55101 Mdot
.39056 .47325 Mdot
.60395 .39328 Mdot
.49173 .66933 Mdot
.66807 .49718 Mdot
.45267 .66753 Mdot
.36484 .24226 Mdot
.55804 .69583 Mdot
.71686 .31882 Mdot
.46646 .32215 Mdot
.46599 .83464 Mdot
.78766 .44325 Mdot
.55723 .67738 Mdot
.43223 .32866 Mdot
.82475 .4692 Mdot
.56491 .3767 Mdot
.24451 .48645 Mdot
.60466 .3784 Mdot
.34905 .5087 Mdot
.58704 .37396 Mdot
.80321 .63524 Mdot
.36154 .53948 Mdot
.59712 .35764 Mdot
.69966 .28095 Mdot
.36228 .54492 Mdot
.48045 .65515 Mdot
.61552 .80389 Mdot
.32748 .75848 Mdot
.3668 .39666 Mdot
.60021 .35676 Mdot
.23009 .50955 Mdot
.37661 .54508 Mdot
.36276 .57289 Mdot
.47922 .67589 Mdot
.36868 .55977 Mdot
.49815 .29904 Mdot
.48377 .27144 Mdot
.24406 .40149 Mdot
.36332 .78304 Mdot
.31636 .55463 Mdot
.47756 .68728 Mdot
.17534 .48917 Mdot
.60676 .75053 Mdot
.63508 .69805 Mdot
.64464 .50073 Mdot
.69732 .72012 Mdot
.30077 .47699 Mdot
.27586 .46159 Mdot
.51387 .51425 Mdot
.46321 .69702 Mdot
.7556 .39301 Mdot
.67277 .50147 Mdot
.2117 .5761 Mdot
.29296 .67298 Mdot
.37469 .47343 Mdot
.71206 .49536 Mdot
.43348 .46534 Mdot
.5072 .51115 Mdot
.31223 .31111 Mdot
.66523 .30904 Mdot
.35173 .49178 Mdot
.56965 .76076 Mdot
.3858 .52523 Mdot
.33528 .27344 Mdot
.35758 .50029 Mdot
.4557 .66202 Mdot
.28801 .49019 Mdot
.51663 .41269 Mdot
.21044 .63327 Mdot
.48035 .43792 Mdot
.4695 .3153 Mdot
.38322 .49173 Mdot
.37039 .47771 Mdot
.47409 .28279 Mdot
.46046 .68279 Mdot
.38936 .46593 Mdot
.5573 .18961 Mdot
.38403 .47277 Mdot
.68414 .47069 Mdot
.56193 .45392 Mdot
.42944 .78654 Mdot
.3736 .55082 Mdot
.46119 .63611 Mdot
.69578 .48596 Mdot
.64888 .49716 Mdot
.30172 .53181 Mdot
.69331 .52073 Mdot
.36071 .52706 Mdot
.56348 .45702 Mdot
.45493 .69742 Mdot
.4475 .47352 Mdot
.46023 .67701 Mdot
.19024 .43523 Mdot
.69672 .52499 Mdot
.61734 .68014 Mdot
.24695 .47337 Mdot
.68559 .50647 Mdot
.46254 .57788 Mdot
.30476 .45409 Mdot
.33938 .45232 Mdot
.54677 .69525 Mdot
.57512 .40121 Mdot
.60707 .68001 Mdot
.6676 .4903 Mdot
.38511 .47438 Mdot
.34431 .48008 Mdot
.70382 .48169 Mdot
.32366 .60197 Mdot
.54558 .21706 Mdot
.36207 .50979 Mdot
.45503 .66863 Mdot
.48135 .69426 Mdot
.41524 .4899 Mdot
.39264 .52705 Mdot
.5629 .34437 Mdot
.62202 .68685 Mdot
.60087 .68482 Mdot
.6298 .68913 Mdot
.57187 .40596 Mdot
.4386 .83119 Mdot
.65552 .521 Mdot
.5176 .81826 Mdot
.76218 .62114 Mdot
.31586 .54834 Mdot
.59154 .39993 Mdot
.37182 .49572 Mdot
.34193 .49271 Mdot
.67442 .51014 Mdot
.34475 .78746 Mdot
.44109 .52324 Mdot
.49784 .65984 Mdot
.69234 .4739 Mdot
.45654 .50622 Mdot
.68708 .45229 Mdot
.4881 .28215 Mdot
.45787 .42171 Mdot
.71257 .49379 Mdot
.44961 .67021 Mdot
.71041 .48802 Mdot
.37327 .47642 Mdot
.3301 .45219 Mdot
.46617 .70146 Mdot
.44722 .30139 Mdot
.35433 .46505 Mdot
.37207 .50683 Mdot
.36097 .21258 Mdot
.60003 .74922 Mdot
.64395 .37998 Mdot
.3408 .5083 Mdot
.37551 .44827 Mdot
.44267 .29621 Mdot
.39063 .47045 Mdot
.39636 .54228 Mdot
.55997 .62011 Mdot
.63241 .48788 Mdot
.50935 .30149 Mdot
.20674 .58708 Mdot
.50451 .68755 Mdot
.78881 .63771 Mdot
.62816 .70093 Mdot
.63314 .47567 Mdot
.57888 .47202 Mdot
.608 .68459 Mdot
.77982 .56198 Mdot
.7797 .48435 Mdot
.6159 .68194 Mdot
.62403 .34905 Mdot
.43155 .43091 Mdot
.40883 .53892 Mdot
.37498 .5196 Mdot
.45425 .30539 Mdot
.49861 .68259 Mdot
.63138 .57651 Mdot
.63091 .51083 Mdot
.38674 .5108 Mdot
.44114 .69765 Mdot
.80306 .55993 Mdot
.60763 .69493 Mdot
.48571 .30707 Mdot
.46286 .31695 Mdot
.38494 .52268 Mdot
.52461 .6082 Mdot
.47614 .68996 Mdot
.39593 .50993 Mdot
.41407 .51058 Mdot
.61192 .36926 Mdot
.45295 .65578 Mdot
.56459 .35684 Mdot
.61299 .70932 Mdot
.82242 .40137 Mdot
.38393 .19461 Mdot
.67216 .5177 Mdot
.77717 .4287 Mdot
.72062 .49522 Mdot
.67713 .32781 Mdot
.62078 .68432 Mdot
.39194 .50891 Mdot
.48295 .71453 Mdot
.39756 .50717 Mdot
.37438 .46843 Mdot
.36084 .47073 Mdot
.32273 .5606 Mdot
.22107 .40003 Mdot
.48017 .30253 Mdot
.42133 .46641 Mdot
.55639 .34703 Mdot
.80748 .54866 Mdot
.64806 .77483 Mdot
.37903 .48565 Mdot
.38416 .51672 Mdot
.50739 .69072 Mdot
.34109 .46788 Mdot
.6803 .47827 Mdot
.49932 .69496 Mdot
.34582 .49016 Mdot
.51339 .26425 Mdot
.39969 .47301 Mdot
.78038 .42026 Mdot
.71124 .48875 Mdot
.45066 .41983 Mdot
.36254 .44384 Mdot
.61862 .68183 Mdot
.60785 .6802 Mdot
.63004 .71162 Mdot
.70397 .48619 Mdot
.61132 .37254 Mdot
.56415 .32541 Mdot
.3179 .4542 Mdot
.35492 .5233 Mdot
.34352 .44869 Mdot
.56258 .40245 Mdot
.51151 .42891 Mdot
.51459 .7783 Mdot
.33921 .4249 Mdot
.55558 .38098 Mdot
.42877 .67523 Mdot
.2345 .68411 Mdot
.50198 .6841 Mdot
.47774 .33574 Mdot
.66244 .47884 Mdot
.49671 .2924 Mdot
.2109 .44605 Mdot
.45706 .69736 Mdot
.49753 .65276 Mdot
.59371 .35635 Mdot
.58122 .56601 Mdot
.24832 .79227 Mdot
.57292 .35806 Mdot
.43079 .31779 Mdot
.47728 .68012 Mdot
.43657 .53539 Mdot
.56334 .52997 Mdot
.56773 .56553 Mdot
.59959 .36709 Mdot
.39726 .48835 Mdot
.47094 .57846 Mdot
.56388 .34375 Mdot
.42205 .53741 Mdot
.59812 .35347 Mdot
.70005 .51739 Mdot
.58219 .35406 Mdot
.47081 .72334 Mdot
.34496 .46922 Mdot
.17316 .70387 Mdot
.61372 .60608 Mdot
.40224 .51515 Mdot
.69329 .47341 Mdot
.67846 .2446 Mdot
.36446 .47593 Mdot
.49937 .30582 Mdot
.55433 .38278 Mdot
.65039 .26928 Mdot
.38865 .54157 Mdot
.5935 .37083 Mdot
.49468 .72461 Mdot
.54485 .32056 Mdot
.6408 .33489 Mdot
.6027 .68205 Mdot
.48725 .67021 Mdot
.58609 .67999 Mdot
.64551 .48979 Mdot
.37018 .45783 Mdot
.41036 .4938 Mdot
.46997 .65608 Mdot
.70472 .45288 Mdot
.43482 .50265 Mdot
.39563 .48966 Mdot
.566 .34451 Mdot
.54765 .3626 Mdot
.64293 .64465 Mdot
.56274 .37352 Mdot
.37993 .44884 Mdot
.46661 .65555 Mdot
.35363 .5108 Mdot
.48705 .65818 Mdot
.36885 .46268 Mdot
.50946 .75566 Mdot
.50093 .68288 Mdot
.53542 .65188 Mdot
.32665 .51267 Mdot
.3641 .59086 Mdot
.37936 .46757 Mdot
.35332 .48316 Mdot
.55581 .39001 Mdot
.46752 .29781 Mdot
.41155 .55257 Mdot
.59254 .4895 Mdot
.4453 .28037 Mdot
.41968 .72888 Mdot
.61299 .37877 Mdot
.44708 .28951 Mdot
.31585 .35452 Mdot
.60588 .70137 Mdot
.48008 .29311 Mdot
.66347 .68758 Mdot
.67397 .51707 Mdot
.44584 .68876 Mdot
.35375 .5406 Mdot
.83128 .45624 Mdot
.53995 .21484 Mdot
.61299 .69541 Mdot
.39909 .52603 Mdot
.36797 .49232 Mdot
.45051 .64408 Mdot
.14961 .48901 Mdot
.61191 .40319 Mdot
.34953 .49196 Mdot
.46633 .70714 Mdot
.16523 .43279 Mdot
.59272 .34891 Mdot
.48555 .29678 Mdot
.71735 .5038 Mdot
.52663 .6942 Mdot
.60507 .67859 Mdot
.69804 .5249 Mdot
.62473 .41342 Mdot
.20391 .42422 Mdot
.38713 .54079 Mdot
.57543 .39926 Mdot
.23336 .39346 Mdot
.36572 .42218 Mdot
.72607 .51146 Mdot
.50031 .75234 Mdot
.46433 .69673 Mdot
.70064 .47921 Mdot
.47024 .31631 Mdot
.45065 .69386 Mdot
.45953 .68302 Mdot
.65311 .48273 Mdot
.67745 .57344 Mdot
.55903 .53579 Mdot
.67584 .47289 Mdot
.5584 .58876 Mdot
.24731 .38251 Mdot
.62561 .68901 Mdot
.48607 .30752 Mdot
.37001 .23205 Mdot
.47763 .69165 Mdot
.69814 .72002 Mdot
.22174 .40436 Mdot
.35339 .47884 Mdot
.45581 .29001 Mdot
.78416 .58115 Mdot
.6267 .50775 Mdot
.65585 .51354 Mdot
.48098 .40168 Mdot
.49063 .31484 Mdot
.41388 .49477 Mdot
.41959 .7846 Mdot
.34931 .53973 Mdot
.68284 .524 Mdot
.50487 .52293 Mdot
.45541 .65364 Mdot
.64389 .49177 Mdot
.49671 .48768 Mdot
.34161 .49562 Mdot
.40743 .51764 Mdot
.38054 .25581 Mdot
.45182 .65492 Mdot
.60571 .67702 Mdot
.39912 .49935 Mdot
.36466 .49952 Mdot
.38462 .45877 Mdot
.25071 .45994 Mdot
.54776 .6385 Mdot
.34827 .48763 Mdot
.60185 .40553 Mdot
.33289 .45744 Mdot
.40343 .53179 Mdot
.44101 .65734 Mdot
.29167 .29396 Mdot
.61562 .71101 Mdot
.37198 .51589 Mdot
.36278 .51016 Mdot
.64531 .50842 Mdot
.56005 .5328 Mdot
.56694 .56874 Mdot
.58301 .3377 Mdot
.42442 .33621 Mdot
.37951 .43852 Mdot
.48303 .66322 Mdot
.49946 .29322 Mdot
.3786 .4527 Mdot
.5036 .67909 Mdot
.3473 .43557 Mdot
.56288 .3415 Mdot
.61978 .68745 Mdot
.27926 .47127 Mdot
.47499 .29064 Mdot
.65441 .4659 Mdot
.55039 .82185 Mdot
.55948 .36519 Mdot
.34754 .52213 Mdot
.53886 .3482 Mdot
.57179 .37202 Mdot
.61522 .69904 Mdot
.31128 .50954 Mdot
.48636 .67936 Mdot
.45312 .65922 Mdot
.27447 .34818 Mdot
.5863 .41347 Mdot
.2502 .28869 Mdot
.69928 .51823 Mdot
.40916 .54541 Mdot
.64597 .76166 Mdot
.45876 .65218 Mdot
.37326 .24501 Mdot
.44633 .29082 Mdot
.65601 .51342 Mdot
.59711 .6909 Mdot
.50174 .67504 Mdot
.46692 .64671 Mdot
.36066 .46687 Mdot
.37907 .49409 Mdot
.42417 .31551 Mdot
.32463 .28123 Mdot
.70333 .50729 Mdot
.489 .29549 Mdot
.59181 .34018 Mdot
.34294 .50396 Mdot
.48002 .70435 Mdot
.41417 .77256 Mdot
.39373 .47596 Mdot
.56603 .34051 Mdot
.47017 .69964 Mdot
.48374 .28594 Mdot
.45675 .28113 Mdot
.35396 .47985 Mdot
.39779 .72696 Mdot
.6891 .50648 Mdot
.47313 .65282 Mdot
.42971 .62622 Mdot
.42908 .48963 Mdot
.38016 .48969 Mdot
.45069 .51352 Mdot
.68727 .53035 Mdot
.28161 .46525 Mdot
.44375 .30635 Mdot
.49321 .68302 Mdot
.40121 .50955 Mdot
.47749 .28811 Mdot
.26233 .48257 Mdot
.6124 .68542 Mdot
.59383 .35127 Mdot
.49821 .30459 Mdot
.46146 .29107 Mdot
.45197 .2751 Mdot
.68996 .72459 Mdot
.46655 .63071 Mdot
.19864 .58287 Mdot
.36701 .46621 Mdot
.25257 .37845 Mdot
.32503 .48539 Mdot
.70729 .50711 Mdot
.56035 .38227 Mdot
.37529 .47019 Mdot
.36207 .46597 Mdot
.44445 .78279 Mdot
.44746 .56059 Mdot
.46757 .45611 Mdot
.44738 .67179 Mdot
.29241 .5547 Mdot
.60115 .397 Mdot
.16119 .39434 Mdot
.68626 .77506 Mdot
.39813 .44547 Mdot
.58185 .55915 Mdot
.4976 .6965 Mdot
.66267 .52009 Mdot
.55686 .56092 Mdot
.62678 .47501 Mdot
.49294 .68914 Mdot
.34607 .50486 Mdot
.52241 .81458 Mdot
.4649 .26831 Mdot
.37998 .47682 Mdot
.6883 .4867 Mdot
.37993 .4762 Mdot
.707 .49338 Mdot
.52338 .66504 Mdot
.57956 .58525 Mdot
.35893 .5408 Mdot
.42326 .47602 Mdot
.3012 .44035 Mdot
.37833 .48795 Mdot
.69655 .41457 Mdot
.46666 .67949 Mdot
.52303 .63844 Mdot
.41432 .48431 Mdot
.37603 .70869 Mdot
.40633 .48313 Mdot
.7234 .46322 Mdot
.41096 .50077 Mdot
.35547 .38796 Mdot
.41578 .50033 Mdot
.40641 .49257 Mdot
.67291 .50454 Mdot
.65067 .51331 Mdot
.50029 .72098 Mdot
.61196 .67613 Mdot
.81099 .54757 Mdot
.37779 .51109 Mdot
.55336 .38851 Mdot
.65205 .68925 Mdot
.46303 .29493 Mdot
.49033 .68837 Mdot
.22394 .2784 Mdot
.7016 .49384 Mdot
.62453 .37377 Mdot
.66743 .39125 Mdot
.61973 .37833 Mdot
.58648 .42107 Mdot
.39352 .59648 Mdot
.49129 .29981 Mdot
.41108 .49029 Mdot
.39874 .69555 Mdot
.58335 .75743 Mdot
.42477 .52628 Mdot
.55109 .3296 Mdot
.45826 .52355 Mdot
.24755 .37838 Mdot
.46116 .26507 Mdot
.49099 .30942 Mdot
.66868 .49422 Mdot
.61501 .34859 Mdot
.39039 .42968 Mdot
.44752 .28776 Mdot
.55797 .3745 Mdot
.63122 .68471 Mdot
.43046 .251 Mdot
.4804 .68869 Mdot
.35168 .40145 Mdot
.6072 .78004 Mdot
.70292 .4996 Mdot
.59029 .48225 Mdot
.44009 .63922 Mdot
.51364 .66086 Mdot
.62097 .67936 Mdot
.55314 .3535 Mdot
.45415 .70274 Mdot
.35081 .46745 Mdot
.33118 .5523 Mdot
.38711 .52416 Mdot
.45027 .29475 Mdot
.41185 .51924 Mdot
.55484 .35576 Mdot
.69793 .50726 Mdot
.58789 .3871 Mdot
.69022 .50991 Mdot
.51409 .80165 Mdot
.39168 .53163 Mdot
.38182 .49315 Mdot
.56628 .47227 Mdot
.47926 .64836 Mdot
.38432 .64411 Mdot
.55235 .35362 Mdot
.60746 .37033 Mdot
.35192 .50783 Mdot
.51242 .69419 Mdot
.50697 .31733 Mdot
.57205 .53318 Mdot
.4126 .5038 Mdot
.46686 .67827 Mdot
.35782 .51495 Mdot
.67446 .29807 Mdot
.59377 .60644 Mdot
.45303 .66363 Mdot
.21277 .64184 Mdot
.3267 .50216 Mdot
.46018 .53338 Mdot
.41259 .57212 Mdot
.41363 .36081 Mdot
.42351 .54074 Mdot
.4994 .69823 Mdot
.38083 .52865 Mdot
.48085 .66602 Mdot
.56817 .37263 Mdot
.66287 .52392 Mdot
.48129 .6703 Mdot
.33987 .53347 Mdot
.66111 .79022 Mdot
.69833 .49307 Mdot
.3884 .48523 Mdot
.66224 .4917 Mdot
.44278 .68764 Mdot
.47017 .64266 Mdot
.66123 .66466 Mdot
.6485 .41973 Mdot
.69381 .48741 Mdot
.35806 .52618 Mdot
.64138 .73955 Mdot
.35402 .51168 Mdot
.41782 .30635 Mdot
.42119 .49863 Mdot
.43 .50133 Mdot
.48057 .8378 Mdot
.63683 .44403 Mdot
.23467 .29034 Mdot
.66318 .54167 Mdot
.68208 .73185 Mdot
.47594 .62222 Mdot
.46202 .26489 Mdot
.77214 .43278 Mdot
.61745 .70946 Mdot
.60274 .40267 Mdot
.37667 .47011 Mdot
.47922 .7765 Mdot
.68371 .47235 Mdot
.46953 .30226 Mdot
.35743 .54018 Mdot
.59115 .33065 Mdot
.66271 .71014 Mdot
.67469 .52399 Mdot
.48211 .68975 Mdot
.48499 .65061 Mdot
.17537 .52153 Mdot
.40081 .51366 Mdot
.38322 .50049 Mdot
.6648 .47622 Mdot
.37426 .42587 Mdot
.46485 .27139 Mdot
.70161 .29758 Mdot
.68371 .48455 Mdot
.60607 .6136 Mdot
.44733 .67653 Mdot
.36952 .49342 Mdot
.56015 .45155 Mdot
.71907 .66596 Mdot
.24667 .59801 Mdot
.46146 .30956 Mdot
.39629 .28759 Mdot
.49974 .6979 Mdot
.68665 .48816 Mdot
.26531 .38362 Mdot
.34251 .5403 Mdot
.36616 .49315 Mdot
.39195 .27582 Mdot
.57017 .53913 Mdot
.43725 .25887 Mdot
.42908 .55421 Mdot
.5532 .50948 Mdot
.35041 .50585 Mdot
.34406 .48048 Mdot
.40293 .44679 Mdot
.40365 .53533 Mdot
.46993 .67281 Mdot
.34402 .76076 Mdot
.58547 .36544 Mdot
.23331 .54507 Mdot
.47421 .38958 Mdot
.38071 .54722 Mdot
.34392 .50028 Mdot
.29347 .72024 Mdot
.62827 .66518 Mdot
.46947 .68256 Mdot
.43329 .6229 Mdot
.65144 .51895 Mdot
.44574 .56279 Mdot
.57966 .41171 Mdot
.46414 .45996 Mdot
.57995 .37888 Mdot
.46635 .67703 Mdot
.60991 .37875 Mdot
.63605 .49944 Mdot
.57524 .39898 Mdot
.57728 .40866 Mdot
.70588 .52223 Mdot
.45195 .65007 Mdot
.40333 .48588 Mdot
.6985 .52295 Mdot
.38835 .24583 Mdot
.45023 .29378 Mdot
.66049 .66677 Mdot
.43805 .53296 Mdot
.46288 .52952 Mdot
.64931 .23971 Mdot
.59408 .39166 Mdot
.57503 .63013 Mdot
.50074 .68238 Mdot
.50391 .30495 Mdot
.47336 .66933 Mdot
.21905 .4735 Mdot
.46826 .28557 Mdot
.66136 .67016 Mdot
.27856 .37016 Mdot
.61233 .46156 Mdot
.31764 .49796 Mdot
.53984 .6779 Mdot
.5787 .38052 Mdot
.68502 .47057 Mdot
.79091 .5681 Mdot
.32998 .48937 Mdot
.56457 .69593 Mdot
.49436 .63769 Mdot
.60319 .69625 Mdot
.68999 .4909 Mdot
.70966 .54241 Mdot
.3993 .51747 Mdot
.60775 .45802 Mdot
.42762 .50875 Mdot
.24483 .47838 Mdot
.42188 .32592 Mdot
.50753 .74239 Mdot
.36189 .52243 Mdot
.57275 .34038 Mdot
.35862 .51822 Mdot
.37203 .40989 Mdot
.23992 .3932 Mdot
.41537 .46336 Mdot
.55368 .69078 Mdot
.65037 .26095 Mdot
.47146 .70282 Mdot
.3899 .45048 Mdot
.62181 .69436 Mdot
.33525 .50437 Mdot
.86351 .4409 Mdot
.4777 .29468 Mdot
.63539 .39585 Mdot
.33238 .52597 Mdot
.39839 .50274 Mdot
.41291 .75286 Mdot
.51898 .64278 Mdot
.60076 .69831 Mdot
.36203 .4891 Mdot
.39497 .30716 Mdot
.66804 .49985 Mdot
.41703 .52855 Mdot
.37973 .52506 Mdot
.41117 .20328 Mdot
.66585 .50001 Mdot
.59374 .39506 Mdot
.60845 .70432 Mdot
.58724 .34019 Mdot
.47802 .2651 Mdot
.54317 .56393 Mdot
.35668 .2556 Mdot
.59391 .60901 Mdot
.49722 .31324 Mdot
.39031 .54913 Mdot
.42149 .65638 Mdot
.40556 .50621 Mdot
.4865 .31251 Mdot
.66784 .48303 Mdot
.47228 .67415 Mdot
.31526 .41234 Mdot
.61874 .7025 Mdot
.42695 .52471 Mdot
.44914 .26903 Mdot
.48362 .67456 Mdot
.68111 .64114 Mdot
.4968 .68964 Mdot
.68213 .50702 Mdot
.64328 .5133 Mdot
.46769 .29058 Mdot
.47099 .67048 Mdot
.60333 .35304 Mdot
.67145 .54342 Mdot
.42354 .5016 Mdot
.64057 .52214 Mdot
.49034 .72054 Mdot
.4907 .64889 Mdot
.49134 .71372 Mdot
.39117 .5353 Mdot
.57382 .54746 Mdot
.32304 .51773 Mdot
.69045 .4823 Mdot
.61389 .38358 Mdot
.3061 .30343 Mdot
.3953 .69593 Mdot
.60633 .61141 Mdot
.41483 .55039 Mdot
.40723 .52354 Mdot
.38511 .52242 Mdot
.36512 .51907 Mdot
.70386 .30442 Mdot
.39068 .53148 Mdot
.68316 .51311 Mdot
.57621 .36915 Mdot
.40068 .52341 Mdot
.62256 .69194 Mdot
.51141 .44017 Mdot
.49946 .29454 Mdot
.38259 .37997 Mdot
.69031 .75531 Mdot
.48195 .6749 Mdot
.56923 .39033 Mdot
.61427 .369 Mdot
.45544 .27865 Mdot
.69327 .52447 Mdot
.4978 .68281 Mdot
.36709 .36723 Mdot
.44473 .27893 Mdot
.37109 .51475 Mdot
.56493 .46172 Mdot
.22157 .66034 Mdot
.38233 .55224 Mdot
.359 .47467 Mdot
.5999 .67972 Mdot
.62016 .3843 Mdot
.8532 .50141 Mdot
.65845 .57844 Mdot
.46751 .29586 Mdot
.48657 .28475 Mdot
.49093 .70995 Mdot
.41523 .54122 Mdot
.69242 .50523 Mdot
.55777 .51929 Mdot
.64956 .22879 Mdot
.79418 .60517 Mdot
.67759 .33355 Mdot
.3977 .47146 Mdot
.35168 .74356 Mdot
.40232 .46547 Mdot
.47028 .63187 Mdot
.50114 .70566 Mdot
.47342 .68554 Mdot
.67295 .50299 Mdot
.19254 .43868 Mdot
.68474 .51438 Mdot
.69119 .7565 Mdot
.46794 .70581 Mdot
.5475 .42296 Mdot
.60615 .36449 Mdot
.30918 .48244 Mdot
.49059 .30204 Mdot
.5666 .31252 Mdot
.37976 .44727 Mdot
.52182 .61126 Mdot
.59159 .39983 Mdot
.46734 .6404 Mdot
.31138 .44864 Mdot
.81645 .53402 Mdot
.58264 .57082 Mdot
.57123 .20007 Mdot
.27451 .55511 Mdot
.47337 .28318 Mdot
.2343 .61838 Mdot
.46198 .27042 Mdot
.66165 .51798 Mdot
.32906 .48948 Mdot
.32481 .51161 Mdot
.35165 .49489 Mdot
.38692 .53556 Mdot
.66707 .48962 Mdot
.41195 .47628 Mdot
.31194 .27951 Mdot
.63124 .7006 Mdot
.53771 .40826 Mdot
.46679 .27774 Mdot
.71011 .50761 Mdot
.57312 .36994 Mdot
.61662 .67646 Mdot
.41627 .23706 Mdot
.40426 .47108 Mdot
.37885 .46856 Mdot
.63352 .69407 Mdot
.36326 .42691 Mdot
.30147 .47701 Mdot
.58864 .36941 Mdot
.51415 .49233 Mdot
.46941 .31765 Mdot
.49589 .29101 Mdot
.71014 .48887 Mdot
.4731 .66921 Mdot
.44944 .30027 Mdot
.61084 .34306 Mdot
.41454 .53297 Mdot
.42226 .47309 Mdot
.49024 .72082 Mdot
.2218 .40402 Mdot
.491 .27402 Mdot
.31905 .43198 Mdot
.49461 .67023 Mdot
.48517 .63203 Mdot
.36247 .48705 Mdot
.3983 .56634 Mdot
.48287 .63896 Mdot
.47428 .2761 Mdot
.71116 .50845 Mdot
.5705 .44135 Mdot
.69573 .51563 Mdot
.49186 .67407 Mdot
.31654 .47663 Mdot
.44759 .66138 Mdot
.32792 .50326 Mdot
.11004 .46566 Mdot
.40816 .52752 Mdot
.4644 .60331 Mdot
.42934 .359 Mdot
.59629 .3511 Mdot
.59117 .34604 Mdot
.62091 .68909 Mdot
.50335 .68353 Mdot
.36857 .45241 Mdot
.49242 .29315 Mdot
.67647 .73383 Mdot
.47206 .73706 Mdot
.56589 .3983 Mdot
.60671 .4063 Mdot
.66867 .4838 Mdot
.41052 .49128 Mdot
.37325 .49867 Mdot
.57934 .40012 Mdot
.68606 .25542 Mdot
.47439 .66284 Mdot
.38348 .50055 Mdot
.40285 .5337 Mdot
.5825 .36529 Mdot
.6825 .54672 Mdot
.45572 .62101 Mdot
.40428 .53379 Mdot
.29142 .3551 Mdot
.70537 .49334 Mdot
.36407 .53503 Mdot
.40676 .47059 Mdot
.45997 .29798 Mdot
.49932 .25447 Mdot
.24428 .38521 Mdot
.69632 .52764 Mdot
.60249 .68061 Mdot
.32671 .48737 Mdot
.60201 .36143 Mdot
.43758 .5298 Mdot
.79329 .41898 Mdot
.62568 .70571 Mdot
.39354 .51593 Mdot
.37133 .43753 Mdot
.48135 .65334 Mdot
.39491 .51125 Mdot
.507 .75364 Mdot
.57334 .34473 Mdot
.39416 .51691 Mdot
.3949 .71983 Mdot
.67115 .48305 Mdot
.37457 .44669 Mdot
.49641 .29879 Mdot
.43507 .36091 Mdot
.57743 .8067 Mdot
.555 .39459 Mdot
.45797 .2816 Mdot
.41265 .5173 Mdot
.57409 .33651 Mdot
.71767 .50377 Mdot
.53729 .64036 Mdot
.39789 .5479 Mdot
.6995 .5133 Mdot
.6988 .50289 Mdot
.47052 .29352 Mdot
.20282 .3196 Mdot
.37327 .43722 Mdot
.38252 .48258 Mdot
.60682 .18995 Mdot
.43765 .65555 Mdot
.38682 .48095 Mdot
.40953 .49067 Mdot
.68466 .52062 Mdot
.259 .41803 Mdot
.47929 .50403 Mdot
.70008 .28111 Mdot
.70742 .49559 Mdot
.60746 .32784 Mdot
.5642 .35163 Mdot
.46125 .28031 Mdot
.47461 .70168 Mdot
.48521 .31844 Mdot
.58631 .35631 Mdot
.35302 .48484 Mdot
.65442 .50533 Mdot
.28683 .60303 Mdot
.6889 .47029 Mdot
.58675 .33174 Mdot
.48739 .63752 Mdot
.62466 .78624 Mdot
.68976 .21216 Mdot
.59117 .78471 Mdot
.69709 .52897 Mdot
.46283 .29515 Mdot
.63839 .57422 Mdot
.40783 .52082 Mdot
.21638 .6036 Mdot
.38183 .47907 Mdot
.25022 .52857 Mdot
.55924 .37989 Mdot
.62708 .68278 Mdot
.33053 .48792 Mdot
.39653 .29408 Mdot
.70143 .52457 Mdot
.67933 .47907 Mdot
.36959 .51935 Mdot
.68443 .50764 Mdot
.37842 .50204 Mdot
.57701 .36415 Mdot
.20749 .31829 Mdot
.40886 .5007 Mdot
.36058 .45021 Mdot
.63198 .48336 Mdot
.66049 .66818 Mdot
.58523 .32378 Mdot
.36215 .74845 Mdot
.8231 .52751 Mdot
.68628 .5047 Mdot
.35999 .57846 Mdot
.58472 .3954 Mdot
.60225 .6762 Mdot
.61023 .41565 Mdot
.37334 .48036 Mdot
.39113 .4676 Mdot
.35122 .50193 Mdot
.40609 .52335 Mdot
.22422 .62031 Mdot
.30566 .47383 Mdot
.31374 .68456 Mdot
.3753 .46791 Mdot
.45179 .60066 Mdot
.67792 .51232 Mdot
.46609 .51687 Mdot
.44318 .25514 Mdot
.39413 .46733 Mdot
.51174 .63484 Mdot
.7075 .51186 Mdot
.70165 .73619 Mdot
.66506 .49384 Mdot
.595 .38551 Mdot
.64754 .50649 Mdot
.32742 .50791 Mdot
.47923 .69457 Mdot
.56962 .35499 Mdot
.51818 .77885 Mdot
.59836 .40287 Mdot
.40206 .51528 Mdot
.62278 .51008 Mdot
.60101 .35412 Mdot
.42572 .386 Mdot
.47987 .69636 Mdot
.38345 .30275 Mdot
.43951 .64879 Mdot
.393 .50503 Mdot
.39198 .4974 Mdot
.61808 .67569 Mdot
.67685 .52453 Mdot
.45819 .70326 Mdot
.35552 .21688 Mdot
.44115 .27376 Mdot
.46617 .68935 Mdot
.37574 .56857 Mdot
.58215 .5534 Mdot
.46586 .65241 Mdot
.40678 .34023 Mdot
.68376 .52432 Mdot
.48139 .70966 Mdot
.32732 .53501 Mdot
.27362 .45504 Mdot
.48104 .27246 Mdot
.56333 .33963 Mdot
.55476 .49097 Mdot
.56612 .34873 Mdot
.66108 .46765 Mdot
.59303 .41582 Mdot
.67062 .50592 Mdot
.53269 .7323 Mdot
.50134 .51657 Mdot
.6533 .47381 Mdot
.63473 .49025 Mdot
.59217 .36189 Mdot
.36449 .51604 Mdot
.51538 .41697 Mdot
.38399 .56649 Mdot
.32504 .45949 Mdot
.70645 .50086 Mdot
.4966 .70199 Mdot
.44583 .67873 Mdot
.48613 .61572 Mdot
.47088 .64492 Mdot
.56824 .36204 Mdot
.58662 .60977 Mdot
.23042 .50406 Mdot
.66443 .48259 Mdot
.63864 .4301 Mdot
.35249 .51211 Mdot
.59623 .35916 Mdot
.56593 .37143 Mdot
.69445 .5102 Mdot
.23511 .57196 Mdot
.35303 .44751 Mdot
.44288 .65219 Mdot
.46517 .70537 Mdot
.46174 .65489 Mdot
.50928 .69786 Mdot
.18538 .46337 Mdot
.68528 .47057 Mdot
.50045 .69522 Mdot
.37808 .53365 Mdot
.38849 .47108 Mdot
.60378 .69333 Mdot
.47775 .27852 Mdot
.3306 .47386 Mdot
.33692 .46181 Mdot
.36353 .48729 Mdot
.59765 .35265 Mdot
.43288 .45139 Mdot
.62313 .70593 Mdot
.59798 .41394 Mdot
.57603 .40962 Mdot
.61555 .67991 Mdot
.45479 .73445 Mdot
.8263 .56225 Mdot
.34989 .49332 Mdot
.41449 .61311 Mdot
.6012 .36392 Mdot
.52838 .58397 Mdot
.28121 .4865 Mdot
.3612 .52801 Mdot
.52177 .38535 Mdot
.5736 .3613 Mdot
.52045 .68525 Mdot
.3769 .48367 Mdot
.62651 .68667 Mdot
.49595 .28615 Mdot
.3623 .56049 Mdot
.5998 .67927 Mdot
.46512 .67506 Mdot
.62371 .24604 Mdot
.43698 .67527 Mdot
.60082 .35263 Mdot
.386 .44917 Mdot
.21589 .76054 Mdot
.57813 .38147 Mdot
.72073 .69879 Mdot
.49989 .50541 Mdot
.41008 .50951 Mdot
.56466 .35853 Mdot
.51899 .67343 Mdot
.70534 .49387 Mdot
.56378 .47982 Mdot
.47974 .70419 Mdot
.61872 .67741 Mdot
.6042 .68338 Mdot
.58482 .36609 Mdot
.45383 .6885 Mdot
.41894 .49047 Mdot
.49552 .66455 Mdot
.6513 .49118 Mdot
.33988 .52376 Mdot
.81167 .54689 Mdot
.33041 .55208 Mdot
.49678 .67162 Mdot
.61266 .34318 Mdot
.44513 .29971 Mdot
.36317 .54243 Mdot
.77147 .66016 Mdot
.41221 .49619 Mdot
.66349 .48783 Mdot
.5046 .56851 Mdot
.28505 .61016 Mdot
.35888 .50298 Mdot
.34743 .50506 Mdot
.71435 .49752 Mdot
.35593 .49779 Mdot
.40486 .54148 Mdot
.72491 .52522 Mdot
.47113 .65022 Mdot
.38872 .51902 Mdot
.55952 .3582 Mdot
.3619 .60314 Mdot
.33467 .47884 Mdot
.5266 .75392 Mdot
.38934 .29417 Mdot
.49685 .55098 Mdot
.37521 .45187 Mdot
.39166 .23768 Mdot
.38907 .4936 Mdot
.37954 .54237 Mdot
.35579 .50631 Mdot
.34418 .74472 Mdot
.58971 .35791 Mdot
.55433 .3736 Mdot
.49556 .28314 Mdot
.39455 .30078 Mdot
.45528 .29381 Mdot
.71255 .50967 Mdot
.65777 .42136 Mdot
.63086 .69938 Mdot
.47562 .66783 Mdot
.34484 .47104 Mdot
.59484 .40602 Mdot
.36929 .48985 Mdot
.33653 .50707 Mdot
.57606 .35555 Mdot
.56799 .36861 Mdot
.56709 .40764 Mdot
.45387 .27113 Mdot
.47462 .6787 Mdot
.35419 .47365 Mdot
.44447 .28151 Mdot
.41739 .49402 Mdot
.5895 .55394 Mdot
.47272 .68083 Mdot
.4945 .66321 Mdot
.44215 .67509 Mdot
.3696 .46573 Mdot
.33315 .5212 Mdot
.68571 .51469 Mdot
.48527 .72173 Mdot
.66992 .47664 Mdot
.56519 .35645 Mdot
.58923 .34663 Mdot
.37337 .47986 Mdot
.32155 .43177 Mdot
.47753 .28052 Mdot
.5965 .38783 Mdot
.62518 .71169 Mdot
.49728 .28522 Mdot
.39855 .52715 Mdot
.56623 .35156 Mdot
.49847 .29712 Mdot
.25586 .56743 Mdot
.8221 .50401 Mdot
.44135 .28251 Mdot
.37044 .52035 Mdot
.41073 .74394 Mdot
.27431 .36586 Mdot
.43801 .27898 Mdot
.66125 .49991 Mdot
.40206 .48123 Mdot
.70651 .25919 Mdot
.469 .31875 Mdot
.22387 .40297 Mdot
.57926 .3527 Mdot
.26483 .52135 Mdot
.35765 .55929 Mdot
.21317 .56665 Mdot
.47246 .31983 Mdot
.49514 .6805 Mdot
.47777 .71486 Mdot
.36787 .51193 Mdot
.43892 .26684 Mdot
.66857 .46723 Mdot
.61446 .3687 Mdot
.57507 .40614 Mdot
.45098 .68207 Mdot
.60002 .61223 Mdot
.56068 .35652 Mdot
.42039 .46433 Mdot
.63165 .37801 Mdot
.43851 .56885 Mdot
.17913 .51128 Mdot
.50833 .79368 Mdot
.39871 .45879 Mdot
.4433 .29803 Mdot
.70784 .52122 Mdot
.68653 .51172 Mdot
.67517 .50296 Mdot
.58311 .34335 Mdot
.56049 .54648 Mdot
.56721 .39617 Mdot
.57368 .7145 Mdot
.47875 .28843 Mdot
.36863 .32225 Mdot
.34977 .45941 Mdot
.40957 .51052 Mdot
.41455 .53486 Mdot
.34981 .49978 Mdot
.38795 .49426 Mdot
.70312 .50148 Mdot
.60887 .3545 Mdot
.66273 .27063 Mdot
.45644 .66588 Mdot
.67351 .63063 Mdot
.60687 .36526 Mdot
.60081 .69395 Mdot
.47655 .30494 Mdot
.35594 .26085 Mdot
.63864 .36486 Mdot
.60973 .37712 Mdot
.39294 .55168 Mdot
.50165 .70045 Mdot
.25395 .45403 Mdot
.39565 .48946 Mdot
.59618 .38919 Mdot
.62609 .37055 Mdot
.23834 .61214 Mdot
.44595 .51785 Mdot
.49426 .33427 Mdot
.58075 .55454 Mdot
.4501 .31297 Mdot
.41845 .55111 Mdot
.5343 .5887 Mdot
.58665 .3586 Mdot
.59312 .38113 Mdot
.44072 .27839 Mdot
.45734 .46356 Mdot
.46341 .69876 Mdot
.62926 .68485 Mdot
.66446 .50592 Mdot
.40181 .49538 Mdot
.5791 .34296 Mdot
.42435 .61545 Mdot
.57075 .46368 Mdot
.67471 .48844 Mdot
.60275 .41095 Mdot
.40434 .48068 Mdot
.36352 .50689 Mdot
.46927 .2837 Mdot
.50308 .21934 Mdot
.37852 .56528 Mdot
.68245 .73146 Mdot
.5659 .58242 Mdot
.488 .44294 Mdot
.36655 .49368 Mdot
.4511 .65873 Mdot
.62057 .68383 Mdot
.48481 .30909 Mdot
.41504 .49155 Mdot
.83401 .5366 Mdot
.45024 .71229 Mdot
.69632 .49227 Mdot
.62236 .68361 Mdot
.55535 .53675 Mdot
.41338 .50017 Mdot
.38153 .47924 Mdot
.38959 .53519 Mdot
.83833 .53183 Mdot
.55657 .37447 Mdot
.49505 .71502 Mdot
.45887 .30799 Mdot
.49191 .65714 Mdot
.55572 .38606 Mdot
.48395 .42563 Mdot
.39788 .53211 Mdot
.4435 .65567 Mdot
.49575 .68524 Mdot
.67029 .48253 Mdot
.70041 .5222 Mdot
.54937 .3511 Mdot
.41064 .51941 Mdot
.63177 .6944 Mdot
.48507 .70693 Mdot
.6148 .35688 Mdot
.4701 .28441 Mdot
.66902 .53024 Mdot
.37364 .46737 Mdot
.58692 .36399 Mdot
.4141 .47166 Mdot
.48057 .65684 Mdot
.60968 .37381 Mdot
.59777 .68809 Mdot
.48145 .28083 Mdot
.3844 .46678 Mdot
.64135 .24572 Mdot
.62318 .6822 Mdot
.3468 .5383 Mdot
.43171 .73917 Mdot
.45913 .25545 Mdot
.51287 .78247 Mdot
.56412 .38662 Mdot
.62721 .69806 Mdot
.49872 .7092 Mdot
.26642 .46218 Mdot
.58804 .3794 Mdot
.44232 .76973 Mdot
.53385 .41686 Mdot
.35111 .48379 Mdot
.4625 .69114 Mdot
.4409 .31399 Mdot
.69995 .72432 Mdot
.29905 .33627 Mdot
.38489 .5074 Mdot
.56603 .34826 Mdot
.49628 .2909 Mdot
.67188 .47749 Mdot
.53125 .74822 Mdot
.18732 .529 Mdot
.59684 .41315 Mdot
.35378 .46933 Mdot
.4891 .70658 Mdot
.69534 .50566 Mdot
.51461 .81263 Mdot
.60539 .33877 Mdot
.55983 .37177 Mdot
.38746 .54154 Mdot
.46194 .3105 Mdot
.71304 .27405 Mdot
.55475 .36904 Mdot
.59021 .34133 Mdot
.65866 .63914 Mdot
.47374 .26699 Mdot
.37745 .53061 Mdot
.48815 .61665 Mdot
.41491 .52985 Mdot
.68486 .7103 Mdot
.6288 .69714 Mdot
.45826 .66398 Mdot
.38238 .47408 Mdot
.65177 .26288 Mdot
.57901 .37666 Mdot
.58013 .55941 Mdot
.7319 .53698 Mdot
.6964 .52346 Mdot
.57664 .3448 Mdot
.37422 .48897 Mdot
.64138 .51195 Mdot
.47319 .28007 Mdot
.40447 .53365 Mdot
.32889 .51129 Mdot
.5128 .65696 Mdot
.65254 .49875 Mdot
.37586 .60604 Mdot
.64813 .49284 Mdot
.70846 .48603 Mdot
.48298 .63056 Mdot
.36911 .51283 Mdot
.60203 .38355 Mdot
.58018 .33029 Mdot
.41677 .48152 Mdot
.52839 .58228 Mdot
.46309 .69706 Mdot
.607 .42575 Mdot
.84873 .49502 Mdot
.39147 .4414 Mdot
.62004 .712 Mdot
.26792 .53867 Mdot
.69434 .47981 Mdot
.35457 .48455 Mdot
.48103 .6643 Mdot
.60252 .3465 Mdot
.56113 .34947 Mdot
.37367 .55632 Mdot
.69619 .51033 Mdot
.50128 .30522 Mdot
.56538 .37672 Mdot
.57505 .46651 Mdot
.39624 .51619 Mdot
.56468 .69764 Mdot
.5682 .38395 Mdot
.62524 .80728 Mdot
.65576 .26633 Mdot
.45241 .66917 Mdot
.343 .51142 Mdot
.50664 .67086 Mdot
.45604 .30499 Mdot
.60535 .41645 Mdot
.69573 .51343 Mdot
.36136 .40195 Mdot
.40442 .19782 Mdot
.59351 .35609 Mdot
.46911 .67423 Mdot
.35959 .47002 Mdot
.29857 .45713 Mdot
.41146 .50132 Mdot
.27241 .40835 Mdot
.4316 .31495 Mdot
.6351 .49784 Mdot
.67869 .47711 Mdot
.34191 .49632 Mdot
.4583 .27209 Mdot
.56475 .33437 Mdot
.5779 .35533 Mdot
.16003 .38273 Mdot
.59853 .67994 Mdot
.44504 .33254 Mdot
.37167 .46614 Mdot
.61712 .36363 Mdot
.39326 .68777 Mdot
.66454 .47651 Mdot
.42251 .51887 Mdot
.61622 .38802 Mdot
.71368 .65846 Mdot
.58117 .5472 Mdot
.39124 .51369 Mdot
.37535 .42561 Mdot
.66278 .49631 Mdot
.63969 .575 Mdot
.57233 .39858 Mdot
.42041 .50897 Mdot
.72268 .48253 Mdot
.64936 .65662 Mdot
.37718 .2132 Mdot
.47467 .67915 Mdot
.62056 .35201 Mdot
.70016 .5184 Mdot
.42706 .45118 Mdot
.4708 .27691 Mdot
.59153 .3382 Mdot
.61133 .39294 Mdot
.34058 .52001 Mdot
.33446 .47075 Mdot
.43232 .46715 Mdot
.4611 .68244 Mdot
.67843 .51898 Mdot
.33724 .48794 Mdot
.60127 .5939 Mdot
.34755 .48924 Mdot
.68351 .51914 Mdot
.12347 .61798 Mdot
.37024 .55296 Mdot
.39479 .48241 Mdot
.41862 .37087 Mdot
.45133 .69247 Mdot
.47748 .64957 Mdot
.58706 .59498 Mdot
.37318 .46606 Mdot
.60439 .44316 Mdot
.47598 .6759 Mdot
.46611 .69738 Mdot
.58461 .43959 Mdot
.34605 .52852 Mdot
.67222 .45839 Mdot
.69301 .50773 Mdot
.69779 .52295 Mdot
.48335 .65475 Mdot
.30897 .48969 Mdot
.7169 .50885 Mdot
.23021 .63907 Mdot
.61094 .37057 Mdot
.53458 .58917 Mdot
.49669 .66741 Mdot
.55112 .44248 Mdot
.67408 .52343 Mdot
.64304 .81829 Mdot
.29284 .41774 Mdot
.42618 .49487 Mdot
.36289 .50812 Mdot
.45923 .2935 Mdot
.29617 .51703 Mdot
.60147 .68256 Mdot
.68267 .50843 Mdot
.7057 .31689 Mdot
.47332 .68631 Mdot
.40084 .48549 Mdot
.31475 .29303 Mdot
.53252 .80299 Mdot
.5336 .64575 Mdot
.47716 .70248 Mdot
.47363 .69193 Mdot
.59269 .40041 Mdot
.61254 .36872 Mdot
.38539 .53035 Mdot
.67545 .50702 Mdot
.47405 .71154 Mdot
.66376 .51384 Mdot
.58579 .35708 Mdot
.60817 .37416 Mdot
.61993 .70797 Mdot
.31987 .45524 Mdot
.58351 .34814 Mdot
.66737 .65145 Mdot
.60051 .59075 Mdot
.51851 .68371 Mdot
.6743 .20603 Mdot
.50893 .81541 Mdot
.41357 .36931 Mdot
.4954 .28499 Mdot
.64565 .69048 Mdot
.66206 .52054 Mdot
.34316 .49716 Mdot
.36947 .47539 Mdot
.60716 .69394 Mdot
.68513 .52749 Mdot
.46877 .30521 Mdot
.67203 .5234 Mdot
.48738 .30331 Mdot
.55215 .36266 Mdot
.33329 .47959 Mdot
.41399 .51937 Mdot
.69005 .48459 Mdot
.59256 .39671 Mdot
.59963 .35225 Mdot
.48213 .27497 Mdot
.35896 .26576 Mdot
.58419 .36451 Mdot
.49669 .66709 Mdot
.3473 .60919 Mdot
.60407 .68504 Mdot
.37741 .48438 Mdot
.34094 .26777 Mdot
.22901 .60168 Mdot
.35047 .48055 Mdot
.62292 .68342 Mdot
.16991 .3555 Mdot
.32963 .4868 Mdot
.16007 .4445 Mdot
.622 .7048 Mdot
.44652 .66411 Mdot
.57952 .39466 Mdot
.60557 .67641 Mdot
.42945 .44912 Mdot
.42311 .29002 Mdot
.40609 .4582 Mdot
.46952 .70503 Mdot
.44925 .6501 Mdot
.50651 .5106 Mdot
.68741 .70689 Mdot
.46664 .31374 Mdot
.4736 .30064 Mdot
.58672 .377 Mdot
.71318 .46034 Mdot
.43334 .51059 Mdot
.47023 .30038 Mdot
.74031 .33288 Mdot
.35401 .51433 Mdot
.4147 .30592 Mdot
.52096 .39752 Mdot
.44933 .66491 Mdot
.46872 .50092 Mdot
.58302 .37781 Mdot
.46933 .67479 Mdot
.51367 .45369 Mdot
.4155 .53188 Mdot
.4725 .68303 Mdot
.68027 .52087 Mdot
.75555 .48416 Mdot
.47611 .64492 Mdot
.56486 .47681 Mdot
.69213 .50353 Mdot
.45365 .25522 Mdot
.33068 .35264 Mdot
.88403 .49034 Mdot
.68088 .50905 Mdot
.58869 .39371 Mdot
.58839 .34769 Mdot
.58025 .36521 Mdot
.47709 .70474 Mdot
.56936 .3736 Mdot
.45891 .67105 Mdot
.62922 .50872 Mdot
.3808 .24523 Mdot
.46928 .28845 Mdot
.64102 .41049 Mdot
.48969 .68509 Mdot
.58336 .71572 Mdot
.60698 .1763 Mdot
.37232 .52632 Mdot
.66022 .47009 Mdot
.44077 .2943 Mdot
.58751 .63755 Mdot
.45934 .29796 Mdot
.58368 .39585 Mdot
.53566 .5907 Mdot
.37911 .50356 Mdot
.47331 .77321 Mdot
.49503 .29861 Mdot
.47838 .70343 Mdot
.38428 .54809 Mdot
.55166 .33797 Mdot
.45506 .28566 Mdot
.49312 .28349 Mdot
.38624 .49224 Mdot
.46047 .64192 Mdot
.60604 .38061 Mdot
.65315 .51636 Mdot
.43281 .29622 Mdot
.3513 .42515 Mdot
.36151 .51079 Mdot
.39087 .55627 Mdot
.57552 .56726 Mdot
.715 .26984 Mdot
.68688 .50291 Mdot
.27158 .36411 Mdot
.59375 .35234 Mdot
.29701 .34287 Mdot
.60961 .75105 Mdot
.64105 .36046 Mdot
.6287 .69884 Mdot
.62933 .69622 Mdot
.3896 .50721 Mdot
.74218 .29787 Mdot
.49461 .61435 Mdot
.7098 .47835 Mdot
.60736 .68384 Mdot
.60063 .35303 Mdot
.47226 .72182 Mdot
.46145 .45068 Mdot
.32276 .4819 Mdot
.69351 .52777 Mdot
.58191 .35888 Mdot
.79347 .41767 Mdot
.47818 .28971 Mdot
.5734 .62101 Mdot
.40111 .52451 Mdot
.38205 .49671 Mdot
.68608 .49236 Mdot
.68648 .51392 Mdot
.56104 .71098 Mdot
.51866 .53079 Mdot
.79801 .56584 Mdot
.65659 .46316 Mdot
.79299 .40237 Mdot
.47929 .618 Mdot
.49037 .66611 Mdot
.61282 .70819 Mdot
.71569 .50516 Mdot
.38681 .47929 Mdot
.44558 .66843 Mdot
.52106 .63107 Mdot
.51481 .65571 Mdot
.41515 .31436 Mdot
.57255 .4437 Mdot
.40332 .52511 Mdot
.50458 .69928 Mdot
.46968 .67707 Mdot
.50995 .68278 Mdot
.61498 .68056 Mdot
.36383 .49204 Mdot
.3656 .51857 Mdot
.32853 .49066 Mdot
.30171 .45468 Mdot
.39552 .51181 Mdot
.6174 .74904 Mdot
.61169 .60861 Mdot
.54276 .27198 Mdot
.3594 .46629 Mdot
.69506 .52078 Mdot
.34605 .46956 Mdot
.45988 .27303 Mdot
.36011 .46438 Mdot
.41605 .29127 Mdot
.67656 .49832 Mdot
.43332 .43294 Mdot
.58934 .42751 Mdot
.40008 .52912 Mdot
.49833 .31177 Mdot
.71899 .27374 Mdot
.29729 .31194 Mdot
.66036 .64125 Mdot
.49621 .66642 Mdot
.54724 .36098 Mdot
.66645 .47077 Mdot
.60176 .38217 Mdot
.42477 .50664 Mdot
.62455 .70978 Mdot
.45071 .83437 Mdot
.53483 .43959 Mdot
.38635 .47769 Mdot
.31122 .46029 Mdot
.45569 .65457 Mdot
.57676 .37699 Mdot
.50843 .64195 Mdot
.38473 .54029 Mdot
.4501 .29923 Mdot
.44536 .28909 Mdot
.49662 .4582 Mdot
.76937 .40651 Mdot
.26324 .44798 Mdot
.68582 .49441 Mdot
.56243 .34526 Mdot
.47542 .31986 Mdot
.54464 .68427 Mdot
.67369 .467 Mdot
.69392 .47971 Mdot
.65313 .50022 Mdot
.40559 .51328 Mdot
.61255 .70529 Mdot
.75283 .36611 Mdot
.61446 .67638 Mdot
.39412 .53989 Mdot
.60787 .39702 Mdot
.60636 .67534 Mdot
.45704 .29286 Mdot
.70835 .48709 Mdot
.60093 .3568 Mdot
.39333 .50091 Mdot
.48081 .67697 Mdot
.27821 .34583 Mdot
.54198 .18838 Mdot
.63084 .417 Mdot
.63097 .41869 Mdot
.44005 .67715 Mdot
.76528 .67902 Mdot
.65095 .53047 Mdot
.23355 .57426 Mdot
.45522 .32503 Mdot
.41799 .48287 Mdot
.21963 .32484 Mdot
.56706 .39519 Mdot
.56843 .35716 Mdot
.39219 .51903 Mdot
.61227 .34705 Mdot
.40569 .4896 Mdot
.57821 .40267 Mdot
.7358 .66896 Mdot
.31862 .49654 Mdot
.56854 .36018 Mdot
.43194 .52527 Mdot
.36419 .54426 Mdot
.45538 .65251 Mdot
.5962 .34049 Mdot
.42596 .49214 Mdot
.41925 .83982 Mdot
.67636 .48221 Mdot
.61289 .68001 Mdot
.64836 .41605 Mdot
.6497 .50736 Mdot
.45688 .68334 Mdot
.32997 .48113 Mdot
.47351 .28152 Mdot
.49124 .6766 Mdot
.54497 .349 Mdot
.49373 .30596 Mdot
.58817 .60942 Mdot
.48843 .66052 Mdot
.60521 .69394 Mdot
.48374 .28308 Mdot
.40525 .4573 Mdot
.5724 .35391 Mdot
.62182 .21578 Mdot
.61308 .67691 Mdot
.37377 .49811 Mdot
.61171 .33816 Mdot
.66985 .52251 Mdot
.38217 .52508 Mdot
.56829 .34308 Mdot
.61855 .6811 Mdot
.34651 .53727 Mdot
.35094 .54106 Mdot
.44733 .43146 Mdot
.49846 .58067 Mdot
.46588 .28639 Mdot
.4812 .63074 Mdot
.38013 .5351 Mdot
.46031 .27118 Mdot
.67925 .35808 Mdot
.36978 .45525 Mdot
.49799 .65922 Mdot
.33835 .41142 Mdot
.61396 .37352 Mdot
.67197 .47611 Mdot
.58749 .3313 Mdot
.49847 .28968 Mdot
.4086 .16812 Mdot
.60434 .69844 Mdot
.31886 .4511 Mdot
.41452 .53612 Mdot
.60852 .41 Mdot
.4679 .68074 Mdot
.79031 .58658 Mdot
.37964 .4663 Mdot
.31192 .51382 Mdot
.38204 .48721 Mdot
.64958 .26712 Mdot
.46529 .69857 Mdot
.37973 .48485 Mdot
.32559 .43357 Mdot
.42006 .46785 Mdot
.49868 .31413 Mdot
.36402 .33277 Mdot
.34496 .47392 Mdot
.31547 .84654 Mdot
.63393 .69657 Mdot
.5759 .35772 Mdot
.57554 .51359 Mdot
.64878 .30246 Mdot
.17365 .49488 Mdot
.45927 .67699 Mdot
.33187 .5775 Mdot
.6044 .38103 Mdot
.27111 .33519 Mdot
.73441 .71383 Mdot
.36928 .54604 Mdot
.40042 .47767 Mdot
.58371 .39582 Mdot
.61407 .35749 Mdot
.63068 .7042 Mdot
.38998 .46306 Mdot
.31116 .50939 Mdot
.62042 .36122 Mdot
.39824 .50203 Mdot
.28299 .69179 Mdot
.64172 .49596 Mdot
.47989 .65192 Mdot
.67144 .47768 Mdot
.69452 .48162 Mdot
.22547 .52244 Mdot
.56493 .58249 Mdot
.68487 .51768 Mdot
.72516 .51164 Mdot
.41808 .25985 Mdot
.37243 .39735 Mdot
.48913 .31757 Mdot
.77528 .45497 Mdot
.5849 .37206 Mdot
.36237 .49058 Mdot
.48827 .70333 Mdot
.20302 .53601 Mdot
.77089 .53391 Mdot
.54687 .60534 Mdot
.3696 .52583 Mdot
.5788 .37358 Mdot
.61809 .6794 Mdot
.31923 .49099 Mdot
.28531 .35724 Mdot
.38329 .5028 Mdot
.61294 .36461 Mdot
.22634 .5133 Mdot
.50601 .75027 Mdot
.65993 .46269 Mdot
.50362 .7242 Mdot
.34105 .47256 Mdot
.47317 .65925 Mdot
.699 .51603 Mdot
.45476 .27122 Mdot
.4641 .29503 Mdot
.40563 .52716 Mdot
.50169 .51759 Mdot
.44836 .23511 Mdot
.36785 .54489 Mdot
.34083 .52201 Mdot
.62629 .70081 Mdot
.34028 .52216 Mdot
.41897 .51533 Mdot
.34038 .4848 Mdot
.3895 .4599 Mdot
.71181 .4898 Mdot
.44638 .75022 Mdot
.35624 .46258 Mdot
.39286 .44073 Mdot
.65239 .52054 Mdot
.45135 .52708 Mdot
.66577 .49579 Mdot
.80232 .52093 Mdot
.66793 .50786 Mdot
.46505 .29353 Mdot
.58453 .32637 Mdot
.36402 .59078 Mdot
.47218 .7111 Mdot
.70329 .51819 Mdot
.4845 .2997 Mdot
.67851 .50663 Mdot
.55633 .35711 Mdot
.64534 .20392 Mdot
.46143 .62998 Mdot
.59142 .55247 Mdot
.38363 .37631 Mdot
.56454 .69872 Mdot
.61202 .3805 Mdot
.45152 .68216 Mdot
.50789 .75224 Mdot
.34017 .49435 Mdot
.46741 .28138 Mdot
.38859 .50583 Mdot
.70236 .48131 Mdot
.58056 .37212 Mdot
.62589 .51472 Mdot
.46452 .28691 Mdot
.46678 .1653 Mdot
.5938 .40538 Mdot
.34166 .43922 Mdot
.64638 .51584 Mdot
.65291 .19824 Mdot
.66589 .50292 Mdot
.37648 .24719 Mdot
.42687 .66618 Mdot
.21647 .48753 Mdot
.4803 .69126 Mdot
.54939 .71742 Mdot
.80936 .64973 Mdot
.73687 .69979 Mdot
.48739 .67099 Mdot
.59572 .42976 Mdot
.40089 .51274 Mdot
.34732 .4946 Mdot
.41772 .45918 Mdot
.51853 .69848 Mdot
.3866 .53466 Mdot
.60157 .6853 Mdot
.57391 .57795 Mdot
.71584 .29582 Mdot
.55181 .34827 Mdot
.40784 .4919 Mdot
.70591 .5002 Mdot
.69629 .47461 Mdot
.61004 .67469 Mdot
.64919 .49804 Mdot
.35592 .53882 Mdot
.48756 .6871 Mdot
.51454 .42228 Mdot
.4541 .29998 Mdot
.65774 .73605 Mdot
.4603 .32237 Mdot
.62864 .34231 Mdot
.40116 .44677 Mdot
.60853 .37434 Mdot
.31077 .23068 Mdot
.34615 .50008 Mdot
.47498 .67395 Mdot
.39296 .54355 Mdot
.33974 .48173 Mdot
.34991 .47142 Mdot
.56656 .34297 Mdot
.57774 .51833 Mdot
.39758 .49892 Mdot
.69206 .5188 Mdot
.56685 .43316 Mdot
.33072 .4709 Mdot
.71427 .33757 Mdot
.41776 .32643 Mdot
.56664 .69499 Mdot
.51721 .69081 Mdot
.58712 .38917 Mdot
.4743 .68853 Mdot
.499 .73217 Mdot
.45673 .68305 Mdot
.72246 .33316 Mdot
.25085 .48711 Mdot
.15389 .47213 Mdot
.3803 .67369 Mdot
.21548 .54733 Mdot
.44133 .65672 Mdot
.70042 .38325 Mdot
.4855 .66524 Mdot
.45755 .67946 Mdot
.10711 .51121 Mdot
.50207 .68138 Mdot
.37203 .48018 Mdot
.32843 .52372 Mdot
.57955 .79654 Mdot
.41481 .26342 Mdot
.35876 .46563 Mdot
.38561 .53323 Mdot
.4496 .30394 Mdot
.33694 .42013 Mdot
.62516 .67536 Mdot
.56882 .60327 Mdot
.6378 .71509 Mdot
.38663 .49333 Mdot
.39224 .52547 Mdot
.38543 .56006 Mdot
.80957 .65665 Mdot
.19517 .5297 Mdot
.44402 .66352 Mdot
.45091 .47644 Mdot
.66669 .69177 Mdot
.40603 .54181 Mdot
.40339 .54113 Mdot
.32726 .50411 Mdot
.6029 .38286 Mdot
.46669 .7192 Mdot
.32879 .54073 Mdot
.57132 .76075 Mdot
.39965 .52522 Mdot
.60215 .31971 Mdot
.51635 .29671 Mdot
.37347 .48786 Mdot
.499 .6628 Mdot
.35663 .51207 Mdot
.50709 .68571 Mdot
.47958 .65309 Mdot
.31658 .45858 Mdot
.75859 .37756 Mdot
.48016 .72545 Mdot
.37036 .54767 Mdot
.59467 .39414 Mdot
.70122 .72033 Mdot
.37266 .49548 Mdot
.46817 .31311 Mdot
.35387 .48503 Mdot
.50077 .30869 Mdot
.33333 .51747 Mdot
.6174 .67717 Mdot
.27946 .61618 Mdot
.59231 .37992 Mdot
.43336 .30007 Mdot
.6176 .35963 Mdot
.45352 .41958 Mdot
.47315 .6379 Mdot
.62981 .67859 Mdot
.18488 .55002 Mdot
.62489 .70192 Mdot
.25741 .37413 Mdot
.71049 .45417 Mdot
.69244 .48293 Mdot
.5086 .69931 Mdot
.24198 .48309 Mdot
.74188 .3791 Mdot
.57334 .41037 Mdot
.57601 .40999 Mdot
.33001 .22797 Mdot
.20436 .32122 Mdot
.39779 .49383 Mdot
.69895 .24523 Mdot
.31151 .66955 Mdot
.43187 .488 Mdot
.41943 .55964 Mdot
.61475 .38678 Mdot
.3413 .47043 Mdot
.55432 .47796 Mdot
.59193 .36095 Mdot
.48097 .29773 Mdot
.45998 .66255 Mdot
.48435 .27904 Mdot
.78219 .5126 Mdot
.61393 .59594 Mdot
.58831 .35231 Mdot
.37634 .4574 Mdot
.4056 .49856 Mdot
.50376 .70621 Mdot
.45824 .78203 Mdot
.47236 .64978 Mdot
.4765 .31654 Mdot
.59641 .37076 Mdot
.20823 .56224 Mdot
.35719 .47697 Mdot
.4952 .68877 Mdot
.57055 .41831 Mdot
.36254 .50531 Mdot
.69608 .48925 Mdot
.36885 .52578 Mdot
.49837 .67896 Mdot
.3394 .52146 Mdot
.48545 .68743 Mdot
.58299 .4013 Mdot
.41547 .50329 Mdot
.39049 .52597 Mdot
.24367 .38594 Mdot
.4678 .30568 Mdot
.4674 .63721 Mdot
.55586 .48353 Mdot
.41414 .53057 Mdot
.28617 .3585 Mdot
.33182 .48195 Mdot
.39586 .58591 Mdot
.40053 .56514 Mdot
.60227 .69069 Mdot
.42187 .52839 Mdot
.37384 .49637 Mdot
.42122 .76615 Mdot
.40069 .71818 Mdot
.47117 .47847 Mdot
.70318 .52112 Mdot
.49583 .65991 Mdot
.58514 .34578 Mdot
.6025 .34852 Mdot
.57072 .38069 Mdot
.40887 .26104 Mdot
.3592 .42177 Mdot
.37845 .50531 Mdot
.63429 .49454 Mdot
.47297 .29837 Mdot
.48661 .69991 Mdot
.47042 .29309 Mdot
.56499 .60056 Mdot
.48585 .31404 Mdot
.60058 .68673 Mdot
.65669 .26607 Mdot
.24867 .65899 Mdot
.48243 .31186 Mdot
.47419 .65016 Mdot
.59057 .44468 Mdot
.41918 .48303 Mdot
.69451 .66237 Mdot
.4501 .29974 Mdot
.35381 .21638 Mdot
.3356 .52882 Mdot
.56406 .48635 Mdot
.66679 .49067 Mdot
.48597 .28073 Mdot
.65261 .4948 Mdot
.35343 .50815 Mdot
.51001 .78365 Mdot
.47143 .67102 Mdot
.6467 .48597 Mdot
.42682 .51762 Mdot
.48438 .27931 Mdot
.58427 .35039 Mdot
.30749 .41367 Mdot
.68408 .52926 Mdot
.2795 .33728 Mdot
.29863 .33679 Mdot
.59627 .36849 Mdot
.22707 .6645 Mdot
.657 .4951 Mdot
.39697 .45911 Mdot
.2635 .50477 Mdot
.36178 .52071 Mdot
.59509 .3472 Mdot
.56631 .36109 Mdot
.63538 .76295 Mdot
.405 .52561 Mdot
.32294 .50792 Mdot
.4527 .70647 Mdot
.59667 .35786 Mdot
.45732 .6882 Mdot
.49049 .71703 Mdot
.58646 .39629 Mdot
.45184 .67073 Mdot
.49513 .29746 Mdot
.5557 .57849 Mdot
.65784 .49733 Mdot
.69974 .50225 Mdot
.58507 .34838 Mdot
.55613 .34869 Mdot
.60878 .37092 Mdot
.36958 .53106 Mdot
.45659 .69594 Mdot
.34713 .51738 Mdot
.34679 .47004 Mdot
.43355 .62794 Mdot
.44933 .69473 Mdot
.35125 .51624 Mdot
.53144 .40391 Mdot
.50755 .30326 Mdot
.56882 .362 Mdot
.66691 .51593 Mdot
.23799 .38616 Mdot
.64376 .49312 Mdot
.4059 .53475 Mdot
.71119 .66269 Mdot
.47575 .70428 Mdot
.45894 .29631 Mdot
.46593 .25845 Mdot
.4614 .28923 Mdot
.64679 .48561 Mdot
.49644 .71674 Mdot
.58987 .60704 Mdot
.41074 .52211 Mdot
.57397 .56799 Mdot
.25247 .39318 Mdot
.60021 .75454 Mdot
.68062 .51996 Mdot
.37415 .52796 Mdot
.62191 .70397 Mdot
.23973 .61899 Mdot
.38326 .51056 Mdot
.42351 .51662 Mdot
.56812 .23638 Mdot
.39246 .44091 Mdot
.51606 .66567 Mdot
.49721 .48501 Mdot
.41393 .49008 Mdot
.46788 .45967 Mdot
.13304 .41919 Mdot
.34038 .53371 Mdot
.39506 .52785 Mdot
.36397 .48045 Mdot
.34441 .50137 Mdot
.5014 .65891 Mdot
.53709 .21398 Mdot
.70643 .50653 Mdot
.55544 .57594 Mdot
.65496 .50058 Mdot
.57036 .35038 Mdot
.53763 .46142 Mdot
.50752 .6783 Mdot
.46058 .28957 Mdot
.68548 .2255 Mdot
.54024 .58455 Mdot
.59551 .39923 Mdot
.18844 .48891 Mdot
.45094 .29693 Mdot
.41641 .47979 Mdot
.49539 .28241 Mdot
.62005 .3771 Mdot
.69487 .51119 Mdot
.38947 .55204 Mdot
.47322 .70735 Mdot
.47873 .64624 Mdot
.37517 .53198 Mdot
.67702 .73038 Mdot
.65309 .51226 Mdot
.57245 .30328 Mdot
.4052 .51746 Mdot
.42343 .51522 Mdot
.4641 .65263 Mdot
.57619 .37506 Mdot
.68386 .44644 Mdot
.47676 .30631 Mdot
.42949 .51902 Mdot
.35414 .5075 Mdot
.56375 .592 Mdot
.714 .50418 Mdot
.61442 .68789 Mdot
.40507 .52205 Mdot
.56959 .58341 Mdot
.40028 .53497 Mdot
.30272 .50973 Mdot
.60504 .38674 Mdot
.32101 .46317 Mdot
.39834 .47269 Mdot
.41414 .63463 Mdot
.65684 .49018 Mdot
.47198 .67892 Mdot
.429 .67009 Mdot
.62729 .68719 Mdot
.68392 .4842 Mdot
.35474 .51865 Mdot
.68581 .47467 Mdot
.34632 .48057 Mdot
.39564 .50143 Mdot
.68079 .52018 Mdot
.45536 .68586 Mdot
.78775 .5738 Mdot
.45455 .75764 Mdot
.33514 .50152 Mdot
.35297 .49125 Mdot
.40951 .27377 Mdot
.19653 .61543 Mdot
.39582 .46997 Mdot
.45761 .69915 Mdot
.36458 .50769 Mdot
.70213 .50423 Mdot
.47926 .31641 Mdot
.48024 .67326 Mdot
.55422 .35516 Mdot
.57332 .39786 Mdot
.57924 .42765 Mdot
.60208 .69394 Mdot
.39486 .46602 Mdot
.47722 .62858 Mdot
.44512 .69035 Mdot
.58568 .6471 Mdot
.57503 .35731 Mdot
.49128 .31381 Mdot
.32461 .50093 Mdot
.29547 .42374 Mdot
.70328 .48966 Mdot
.32414 .85029 Mdot
.59356 .60868 Mdot
.49601 .32071 Mdot
.49526 .54641 Mdot
.6175 .70238 Mdot
.39208 .47774 Mdot
.46422 .27195 Mdot
.56416 .38271 Mdot
.3488 .49913 Mdot
.40324 .43678 Mdot
.74497 .39228 Mdot
.55055 .36527 Mdot
.67889 .47431 Mdot
.55902 .37731 Mdot
.50315 .30739 Mdot
.60083 .68455 Mdot
.46142 .64337 Mdot
.37675 .49532 Mdot
.44947 .55504 Mdot
.57737 .36481 Mdot
.62422 .67986 Mdot
.40183 .52987 Mdot
.49052 .65398 Mdot
.56834 .36926 Mdot
.38739 .48792 Mdot
.23475 .58371 Mdot
.44475 .60429 Mdot
.59005 .37165 Mdot
.40484 .54775 Mdot
.42326 .3999 Mdot
.55381 .37987 Mdot
.61066 .39591 Mdot
.38714 .53412 Mdot
.48827 .2863 Mdot
.41122 .49278 Mdot
.66944 .50405 Mdot
.5779 .51814 Mdot
.69161 .48742 Mdot
.27022 .36893 Mdot
.33046 .52906 Mdot
.5318 .63927 Mdot
.49736 .70513 Mdot
.46559 .26232 Mdot
.4067 .76217 Mdot
.42235 .50358 Mdot
.81449 .56434 Mdot
.55571 .4458 Mdot
.62148 .61505 Mdot
.83473 .48915 Mdot
.48132 .30865 Mdot
.67473 .50264 Mdot
.3941 .52965 Mdot
.68093 .53735 Mdot
.49019 .30065 Mdot
.26593 .37251 Mdot
.41311 .53922 Mdot
.46758 .69841 Mdot
.40162 .51801 Mdot
.49815 .66838 Mdot
.3578 .49684 Mdot
.41327 .43332 Mdot
.49221 .33379 Mdot
.37336 .24915 Mdot
.41248 .47389 Mdot
.68918 .22307 Mdot
.38133 .38694 Mdot
.45929 .30789 Mdot
.33437 .50776 Mdot
.61203 .69469 Mdot
.67896 .52496 Mdot
.66722 .24419 Mdot
.60655 .37802 Mdot
.68017 .51625 Mdot
.45921 .65824 Mdot
.6014 .33338 Mdot
.62936 .68775 Mdot
.26461 .518 Mdot
.48109 .2771 Mdot
.67835 .48279 Mdot
.37352 .49309 Mdot
.40289 .53948 Mdot
.64775 .26234 Mdot
.26075 .7228 Mdot
.47019 .71355 Mdot
.42249 .18333 Mdot
.48853 .6354 Mdot
.4708 .303 Mdot
.60703 .3839 Mdot
.38033 .47449 Mdot
.38632 .5179 Mdot
.58491 .34203 Mdot
.4501 .68995 Mdot
.63152 .37305 Mdot
.20844 .5051 Mdot
.73023 .53645 Mdot
.37215 .29539 Mdot
.4813 .66994 Mdot
.37064 .29177 Mdot
.49898 .31829 Mdot
.78754 .42004 Mdot
.37417 .3635 Mdot
.68353 .4794 Mdot
.37335 .2999 Mdot
.49125 .69841 Mdot
.39754 .49072 Mdot
.60524 .69282 Mdot
.62531 .70548 Mdot
.46919 .65726 Mdot
.58456 .39399 Mdot
.47222 .27691 Mdot
.3972 .51881 Mdot
.56265 .66579 Mdot
.53075 .81785 Mdot
.56425 .34237 Mdot
.30701 .46124 Mdot
.65101 .50717 Mdot
.35937 .50329 Mdot
.44495 .29543 Mdot
.68728 .50855 Mdot
.59741 .68237 Mdot
.54213 .57342 Mdot
.32445 .49913 Mdot
.48956 .45053 Mdot
.6745 .4864 Mdot
.198 .62882 Mdot
.389 .52504 Mdot
.65694 .49466 Mdot
.42819 .57192 Mdot
.53261 .76566 Mdot
.52018 .40994 Mdot
.75099 .68391 Mdot
.54973 .38545 Mdot
.56991 .39528 Mdot
.38142 .81637 Mdot
.45605 .32575 Mdot
.7029 .51639 Mdot
.60271 .67966 Mdot
.36857 .34494 Mdot
.65509 .48648 Mdot
.38175 .55171 Mdot
.33019 .48411 Mdot
.2222 .52429 Mdot
.43246 .38991 Mdot
.63539 .69329 Mdot
.29239 .5413 Mdot
.35459 .53303 Mdot
.38667 .45066 Mdot
.3777 .52381 Mdot
.44808 .65222 Mdot
.65872 .47918 Mdot
.77362 .27206 Mdot
.67693 .47046 Mdot
.55773 .64376 Mdot
.58455 .37218 Mdot
.57481 .33434 Mdot
.37458 .48776 Mdot
.48738 .60673 Mdot
.7327 .28008 Mdot
.35566 .4741 Mdot
.46619 .25673 Mdot
.29807 .3351 Mdot
.3354 .46377 Mdot
.44614 .7071 Mdot
.31193 .516 Mdot
.49702 .64712 Mdot
.68984 .50922 Mdot
.48308 .30808 Mdot
.50882 .30409 Mdot
.66988 .49736 Mdot
.37763 .50814 Mdot
.51154 .28847 Mdot
.38126 .49318 Mdot
.40323 .49795 Mdot
.56921 .61169 Mdot
.44007 .29769 Mdot
.60942 .36973 Mdot
.4635 .29275 Mdot
.45923 .68201 Mdot
.10073 .5459 Mdot
.4748 .28723 Mdot
.36649 .39797 Mdot
.55524 .46321 Mdot
.37063 .30069 Mdot
.47609 .64575 Mdot
.46695 .31441 Mdot
.66791 .47623 Mdot
.61397 .62253 Mdot
.22204 .64992 Mdot
.64972 .48333 Mdot
.389 .51816 Mdot
.50785 .68092 Mdot
.44098 .67665 Mdot
.68301 .46502 Mdot
.44944 .6625 Mdot
.36087 .44147 Mdot
.37275 .54886 Mdot
.70386 .51387 Mdot
.57477 .80665 Mdot
.66018 .47768 Mdot
.31152 .41411 Mdot
.33016 .51627 Mdot
.47757 .67377 Mdot
.36907 .58049 Mdot
.46573 .61985 Mdot
.62136 .70858 Mdot
.35647 .46451 Mdot
.46142 .28428 Mdot
.56084 .54574 Mdot
.58985 .37305 Mdot
.7156 .6599 Mdot
.49572 .66483 Mdot
.65076 .47407 Mdot
.45662 .65081 Mdot
.46218 .70736 Mdot
.65476 .47888 Mdot
.46388 .67748 Mdot
.3962 .52502 Mdot
.66966 .57664 Mdot
.49593 .66835 Mdot
.68199 .49223 Mdot
.46075 .28189 Mdot
.45152 .67573 Mdot
.6285 .388 Mdot
.40254 .49137 Mdot
.61312 .38185 Mdot
.43519 .28845 Mdot
.50925 .68432 Mdot
.47495 .31556 Mdot
.57535 .36157 Mdot
.4688 .27543 Mdot
.66154 .54126 Mdot
.63582 .51137 Mdot
.54709 .61179 Mdot
.49146 .7568 Mdot
.48667 .70484 Mdot
.55863 .40132 Mdot
.38896 .47189 Mdot
.40808 .51159 Mdot
.49981 .28964 Mdot
.43968 .67338 Mdot
.69761 .71767 Mdot
.36561 .58488 Mdot
.65084 .73687 Mdot
.71186 .51393 Mdot
.34496 .24447 Mdot
.59944 .61278 Mdot
.6358 .61987 Mdot
.42468 .54739 Mdot
.61568 .70196 Mdot
.38178 .48632 Mdot
.29823 .31018 Mdot
.47615 .31762 Mdot
.69001 .42384 Mdot
.43348 .50806 Mdot
.60191 .36599 Mdot
.35663 .48659 Mdot
.69142 .24358 Mdot
.32707 .54943 Mdot
.45559 .30907 Mdot
.65046 .52183 Mdot
.47234 .71117 Mdot
.45326 .2997 Mdot
.57819 .40094 Mdot
.39557 .32403 Mdot
.38627 .55632 Mdot
.35664 .53694 Mdot
.58435 .41295 Mdot
.45983 .69394 Mdot
.57108 .35198 Mdot
.65761 .49726 Mdot
.47342 .28994 Mdot
.34219 .50076 Mdot
.33882 .45255 Mdot
.61039 .40669 Mdot
.68778 .47168 Mdot
.56106 .34257 Mdot
.69051 .47644 Mdot
.61296 .7012 Mdot
.39757 .46588 Mdot
.60396 .40927 Mdot
.4373 .53333 Mdot
.39854 .69153 Mdot
.55845 .60425 Mdot
.3857 .74833 Mdot
.60984 .36913 Mdot
.39861 .29784 Mdot
.67403 .49553 Mdot
.6679 .48182 Mdot
.23133 .50673 Mdot
.73516 .28754 Mdot
.60251 .44307 Mdot
.63288 .20241 Mdot
.65799 .49823 Mdot
.68246 .48715 Mdot
.5662 .38432 Mdot
.46068 .67138 Mdot
.46487 .72743 Mdot
.62308 .36245 Mdot
.34055 .26843 Mdot
.4874 .6995 Mdot
.80824 .60382 Mdot
.57182 .40269 Mdot
.41028 .55872 Mdot
.63721 .70391 Mdot
.45244 .30486 Mdot
.30715 .30322 Mdot
.64628 .21219 Mdot
.37957 .47779 Mdot
.17368 .41613 Mdot
.5906 .38736 Mdot
.74675 .51942 Mdot
.78598 .45875 Mdot
.41842 .52983 Mdot
.35888 .48635 Mdot
.37507 .51078 Mdot
.44017 .27667 Mdot
.43187 .75556 Mdot
.38247 .47771 Mdot
.38178 .24804 Mdot
.31792 .50166 Mdot
.62647 .22284 Mdot
.46387 .29263 Mdot
.26157 .4157 Mdot
.54424 .37386 Mdot
.58297 .74943 Mdot
.41076 .45538 Mdot
.66031 .49794 Mdot
.75141 .4446 Mdot
.68751 .52018 Mdot
.77141 .36151 Mdot
.36982 .36344 Mdot
.44765 .65175 Mdot
.3698 .5271 Mdot
.58708 .41093 Mdot
.50814 .68436 Mdot
.69074 .44654 Mdot
.10275 .50657 Mdot
.71305 .49016 Mdot
.2571 .24627 Mdot
.67282 .47887 Mdot
.62871 .70393 Mdot
.46674 .65436 Mdot
.47526 .51882 Mdot
.56998 .56786 Mdot
.45674 .68665 Mdot
.54136 .28932 Mdot
.4338 .68884 Mdot
.38586 .28438 Mdot
.43897 .64708 Mdot
.6799 .49692 Mdot
.63572 .5064 Mdot
.44552 .48507 Mdot
.39196 .46985 Mdot
.5809 .57468 Mdot
.43892 .54198 Mdot
.37308 .46588 Mdot
.59211 .361 Mdot
.51146 .76003 Mdot
.73751 .49565 Mdot
.47951 .66363 Mdot
.70812 .49443 Mdot
.35811 .48509 Mdot
.33512 .50263 Mdot
.42316 .47319 Mdot
.27161 .34231 Mdot
.80974 .59623 Mdot
.39631 .49785 Mdot
.31055 .49583 Mdot
.59414 .3983 Mdot
.64187 .24951 Mdot
.47423 .18672 Mdot
.37517 .34874 Mdot
.40551 .5296 Mdot
.46492 .30285 Mdot
.45447 .31114 Mdot
.34664 .44018 Mdot
.53661 .63479 Mdot
.63176 .40119 Mdot
.37329 .49311 Mdot
.42704 .3629 Mdot
.61375 .41117 Mdot
.61889 .6767 Mdot
.57747 .3642 Mdot
.5087 .67907 Mdot
.62705 .70177 Mdot
.56574 .34617 Mdot
.46017 .58122 Mdot
.62637 .68711 Mdot
.5441 .76387 Mdot
.47581 .31661 Mdot
.38186 .52463 Mdot
.51515 .64597 Mdot
.58485 .34301 Mdot
.674 .48413 Mdot
.48575 .68154 Mdot
.70766 .52245 Mdot
.64639 .25058 Mdot
.31858 .29566 Mdot
.60494 .69903 Mdot
.66255 .50109 Mdot
.51504 .51048 Mdot
.46425 .30052 Mdot
.65044 .48949 Mdot
.51849 .62995 Mdot
.33242 .47143 Mdot
.78732 .35564 Mdot
.3662 .54058 Mdot
.66626 .75288 Mdot
.66557 .48523 Mdot
.61085 .70877 Mdot
.37841 .49725 Mdot
.59205 .40527 Mdot
.44887 .53353 Mdot
.3827 .49472 Mdot
.55629 .37248 Mdot
.39703 .49303 Mdot
.4439 .28227 Mdot
.50612 .65927 Mdot
.54541 .44149 Mdot
.28822 .30308 Mdot
.45952 .27855 Mdot
.62394 .66733 Mdot
.38967 .46663 Mdot
.50335 .23964 Mdot
.46484 .69314 Mdot
.42178 .51837 Mdot
.19933 .43797 Mdot
.46566 .66257 Mdot
.47438 .68986 Mdot
.3428 .52118 Mdot
.64814 .48616 Mdot
.59871 .35231 Mdot
.46285 .29827 Mdot
.7227 .46579 Mdot
.38823 .48605 Mdot
.3766 .52951 Mdot
.45137 .29699 Mdot
.68632 .48644 Mdot
.34326 .50447 Mdot
.75483 .60169 Mdot
.58061 .64533 Mdot
.69665 .48279 Mdot
.33317 .46902 Mdot
.8154 .38183 Mdot
.47414 .73146 Mdot
.16606 .43126 Mdot
.45076 .32207 Mdot
.59075 .39346 Mdot
.32266 .44364 Mdot
.27382 .8151 Mdot
.45977 .30954 Mdot
.59576 .74776 Mdot
.40049 .50201 Mdot
.36926 .4699 Mdot
.46555 .63934 Mdot
.35227 .52099 Mdot
.50037 .68049 Mdot
.29463 .2907 Mdot
.66958 .19472 Mdot
.45456 .65532 Mdot
.50001 .6754 Mdot
.46814 .51674 Mdot
.26232 .35836 Mdot
.45875 .66207 Mdot
.38662 .55673 Mdot
.54431 .27908 Mdot
.36125 .42429 Mdot
.47265 .32314 Mdot
.48257 .26481 Mdot
.43726 .68185 Mdot
.29834 .74275 Mdot
.43591 .57074 Mdot
.43626 .43022 Mdot
.44588 .23957 Mdot
.66866 .5111 Mdot
.33172 .48978 Mdot
.60029 .68888 Mdot
.56632 .37143 Mdot
.31637 .52981 Mdot
.38237 .52138 Mdot
.50411 .67757 Mdot
.44292 .2717 Mdot
.65116 .49285 Mdot
.38707 .53208 Mdot
.61451 .33327 Mdot
.48091 .30141 Mdot
.49457 .66789 Mdot
.36009 .3997 Mdot
.48893 .3189 Mdot
.35323 .44687 Mdot
.37049 .46673 Mdot
.40096 .53219 Mdot
.42571 .46624 Mdot
.66854 .49491 Mdot
.61937 .3494 Mdot
.34251 .43558 Mdot
.57404 .60002 Mdot
.56095 .53121 Mdot
.33984 .43819 Mdot
.45485 .69523 Mdot
.7014 .5209 Mdot
.62172 .68628 Mdot
.36854 .32266 Mdot
.33481 .52672 Mdot
.81357 .57812 Mdot
.19412 .50635 Mdot
.62511 .69241 Mdot
.45759 .63517 Mdot
.45984 .2936 Mdot
.34627 .53053 Mdot
.50479 .26039 Mdot
.37904 .55029 Mdot
.29615 .45252 Mdot
.59171 .39064 Mdot
.66493 .51226 Mdot
.57772 .66875 Mdot
.56563 .37036 Mdot
.47429 .68898 Mdot
.68895 .75975 Mdot
.44386 .70977 Mdot
.47798 .71779 Mdot
.76217 .37694 Mdot
.68961 .51315 Mdot
.30004 .83641 Mdot
.19505 .61596 Mdot
.35843 .54699 Mdot
.69903 .51309 Mdot
.4738 .65452 Mdot
.37055 .5355 Mdot
.48777 .70295 Mdot
.47289 .72392 Mdot
.34668 .46772 Mdot
.37964 .46806 Mdot
.36459 .25764 Mdot
.80383 .62928 Mdot
.4688 .28148 Mdot
.44619 .666 Mdot
.22405 .54081 Mdot
.38499 .47697 Mdot
.41127 .52039 Mdot
.75398 .41803 Mdot
.46186 .31217 Mdot
.27902 .6799 Mdot
.40604 .51205 Mdot
.19986 .43025 Mdot
.37089 .46475 Mdot
.516 .72356 Mdot
.6772 .46208 Mdot
.54743 .64756 Mdot
.59734 .34888 Mdot
.51213 .6953 Mdot
.49985 .30042 Mdot
.51234 .69997 Mdot
.23529 .51807 Mdot
.69205 .51086 Mdot
.49846 .67913 Mdot
.57744 .3287 Mdot
.69269 .49695 Mdot
.68398 .47884 Mdot
.58035 .4356 Mdot
.5936 .33107 Mdot
.44256 .27692 Mdot
.67329 .52201 Mdot
.23445 .57161 Mdot
.68271 .4996 Mdot
.23078 .54001 Mdot
.41165 .48809 Mdot
.37244 .26437 Mdot
.57261 .66143 Mdot
.43778 .47655 Mdot
.65578 .48143 Mdot
.48286 .28554 Mdot
.35963 .52183 Mdot
.44836 .66623 Mdot
.47984 .2882 Mdot
.72059 .52883 Mdot
.56137 .33654 Mdot
.44049 .68449 Mdot
.64092 .50888 Mdot
.50074 .68859 Mdot
.29868 .3236 Mdot
.63919 .36219 Mdot
.52034 .38371 Mdot
.57319 .56282 Mdot
.40774 .46268 Mdot
.46855 .46276 Mdot
.41219 .53657 Mdot
.38319 .5162 Mdot
.58919 .37138 Mdot
.40778 .2621 Mdot
.45136 .6773 Mdot
.58186 .82295 Mdot
.66239 .49529 Mdot
.49826 .49195 Mdot
.2833 .46554 Mdot
.34687 .48515 Mdot
.486 .66225 Mdot
.47576 .72235 Mdot
.40068 .71895 Mdot
.58382 .34133 Mdot
.38027 .42762 Mdot
.39472 .44382 Mdot
.36448 .42012 Mdot
.67659 .47812 Mdot
.76911 .58549 Mdot
.5779 .33676 Mdot
.18386 .32349 Mdot
.56829 .36182 Mdot
.53283 .23066 Mdot
.46394 .67633 Mdot
.49233 .3108 Mdot
.41266 .51348 Mdot
.44286 .73734 Mdot
.495 .65097 Mdot
.60987 .42258 Mdot
.45767 .29221 Mdot
.78047 .57818 Mdot
.68493 .51618 Mdot
.41787 .50387 Mdot
.34473 .46783 Mdot
.34279 .51495 Mdot
.38355 .54372 Mdot
.70884 .50744 Mdot
.38618 .5508 Mdot
.69906 .52956 Mdot
.22864 .59765 Mdot
.20327 .43737 Mdot
.60447 .4046 Mdot
.62649 .22918 Mdot
.4604 .70493 Mdot
.25908 .5718 Mdot
.27478 .68238 Mdot
.5592 .60707 Mdot
.63549 .52623 Mdot
.40669 .47679 Mdot
.58203 .39387 Mdot
.70396 .24765 Mdot
.60037 .40827 Mdot
.71112 .2045 Mdot
.24466 .4772 Mdot
.74115 .70265 Mdot
.37115 .53938 Mdot
.62553 .3693 Mdot
.32455 .74637 Mdot
.33364 .45445 Mdot
.50821 .28579 Mdot
.29664 .43347 Mdot
.5771 .7894 Mdot
.49071 .31485 Mdot
.3999 .48866 Mdot
.4566 .70561 Mdot
.39702 .52376 Mdot
.41095 .50081 Mdot
.35511 .47617 Mdot
.70966 .48076 Mdot
.33822 .4703 Mdot
.41142 .49374 Mdot
.23832 .69858 Mdot
.4154 .31093 Mdot
.59476 .40074 Mdot
.38894 .73185 Mdot
.47337 .29821 Mdot
.50805 .68881 Mdot
.56028 .4516 Mdot
.67337 .50933 Mdot
.39742 .70742 Mdot
.36919 .53993 Mdot
.63241 .74521 Mdot
.63825 .4929 Mdot
.48776 .29774 Mdot
.62219 .68387 Mdot
.7957 .53518 Mdot
.61461 .36449 Mdot
.63224 .70341 Mdot
.59016 .37417 Mdot
.3763 .76922 Mdot
.50016 .67172 Mdot
.40513 .46022 Mdot
.65255 .50342 Mdot
.61322 .38929 Mdot
.42656 .23355 Mdot
.37106 .51227 Mdot
.60957 .36751 Mdot
.40142 .45994 Mdot
.56693 .53193 Mdot
.56579 .46532 Mdot
.62043 .37126 Mdot
.6373 .50825 Mdot
.69531 .49631 Mdot
.49565 .30196 Mdot
.50695 .69853 Mdot
.46683 .70352 Mdot
.68891 .50487 Mdot
.18353 .35042 Mdot
.38674 .48514 Mdot
.3656 .46705 Mdot
.58011 .60181 Mdot
.37892 .54034 Mdot
.4074 .32257 Mdot
.6186 .67203 Mdot
.48941 .706 Mdot
.38603 .5412 Mdot
.34249 .50402 Mdot
.3254 .49758 Mdot
.32003 .29657 Mdot
.57606 .36664 Mdot
.35304 .53255 Mdot
.47238 .27279 Mdot
.55927 .71272 Mdot
.39229 .47392 Mdot
.34447 .45142 Mdot
.49962 .68588 Mdot
.37458 .21339 Mdot
.66863 .48559 Mdot
.59688 .35615 Mdot
.56877 .40102 Mdot
.29414 .36489 Mdot
.51558 .7014 Mdot
.62829 .67857 Mdot
.67626 .32054 Mdot
.60829 .67863 Mdot
.46048 .30756 Mdot
.53841 .41497 Mdot
.61896 .33556 Mdot
.57607 .4015 Mdot
.64218 .51885 Mdot
.3907 .53933 Mdot
.37008 .46513 Mdot
.59421 .74364 Mdot
.3547 .46992 Mdot
.4581 .28644 Mdot
.64692 .5147 Mdot
.49852 .68442 Mdot
.44479 .29037 Mdot
.66592 .48124 Mdot
.45937 .69405 Mdot
.32791 .47117 Mdot
.42366 .47104 Mdot
.48283 .68582 Mdot
.48919 .65721 Mdot
.36939 .48315 Mdot
.32918 .78032 Mdot
.48356 .70854 Mdot
.49007 .67101 Mdot
.61573 .71414 Mdot
.61661 .36916 Mdot
.33585 .56505 Mdot
.69762 .51316 Mdot
.4036 .52483 Mdot
.60606 .40393 Mdot
.48069 .31318 Mdot
.48293 .69338 Mdot
.32923 .49915 Mdot
.39104 .49505 Mdot
.4634 .30214 Mdot
.44922 .3105 Mdot
.45537 .2843 Mdot
.71908 .49826 Mdot
.36998 .54698 Mdot
.45618 .66439 Mdot
.68731 .51687 Mdot
.45772 .313 Mdot
.48489 .2724 Mdot
.23226 .68587 Mdot
.37855 .47914 Mdot
.5067 .27373 Mdot
.11929 .60346 Mdot
.39657 .33163 Mdot
.63163 .697 Mdot
.62123 .38677 Mdot
.37988 .2607 Mdot
.43172 .29752 Mdot
.69701 .5196 Mdot
.44029 .36855 Mdot
.45281 .26402 Mdot
.34525 .47312 Mdot
.35932 .50638 Mdot
.41749 .54868 Mdot
.47956 .29499 Mdot
.30768 .31336 Mdot
.44306 .68243 Mdot
.30781 .64205 Mdot
.47347 .29807 Mdot
.62011 .36951 Mdot
.61296 .40137 Mdot
.56743 .35988 Mdot
.41089 .48082 Mdot
.40336 .74101 Mdot
.22505 .55522 Mdot
.2894 .68116 Mdot
.68111 .51592 Mdot
.47018 .72036 Mdot
.62568 .51467 Mdot
.47437 .69065 Mdot
.57271 .38064 Mdot
.48363 .29739 Mdot
.4581 .6411 Mdot
.69307 .48502 Mdot
.69456 .49048 Mdot
.55551 .34668 Mdot
.57776 .35962 Mdot
.58671 .35132 Mdot
.51115 .69594 Mdot
.46373 .67722 Mdot
.33879 .49967 Mdot
.49061 .68824 Mdot
.18579 .53211 Mdot
.46912 .32328 Mdot
.57661 .41116 Mdot
.67309 .48915 Mdot
.48818 .66053 Mdot
.38454 .52573 Mdot
.58811 .2469 Mdot
.60209 .42314 Mdot
.45479 .27903 Mdot
.62223 .56062 Mdot
.59435 .14613 Mdot
.35022 .45995 Mdot
.69806 .47899 Mdot
.53437 .63733 Mdot
.36957 .50463 Mdot
.60274 .38483 Mdot
.23131 .45916 Mdot
.61724 .67799 Mdot
.40447 .48298 Mdot
.42595 .50765 Mdot
.65347 .48142 Mdot
.5628 .45659 Mdot
.3499 .47341 Mdot
.51338 .45566 Mdot
.70284 .47851 Mdot
.57676 .33665 Mdot
.41079 .83996 Mdot
.72882 .53415 Mdot
.37951 .23704 Mdot
.62959 .69349 Mdot
.34251 .4731 Mdot
.59202 .36383 Mdot
.45798 .27451 Mdot
.58593 .36299 Mdot
.44294 .64633 Mdot
.6139 .37344 Mdot
.37018 .51776 Mdot
.45573 .66854 Mdot
.68207 .48402 Mdot
.49264 .46908 Mdot
.27214 .72795 Mdot
.59135 .40484 Mdot
.60058 .67403 Mdot
.39431 .4779 Mdot
.24492 .61751 Mdot
.44645 .48455 Mdot
.39678 .47159 Mdot
.68534 .52095 Mdot
.4832 .66216 Mdot
.70975 .51583 Mdot
.34913 .45551 Mdot
.27095 .55328 Mdot
.66391 .49695 Mdot
.54553 .78799 Mdot
.45151 .29898 Mdot
.33799 .27083 Mdot
.38512 .50906 Mdot
.65324 .50389 Mdot
.36743 .54674 Mdot
.44557 .66665 Mdot
.54551 .54467 Mdot
.55462 .69343 Mdot
.65178 .50863 Mdot
.67591 .75603 Mdot
.55585 .48513 Mdot
.32307 .55147 Mdot
.65549 .49689 Mdot
.40534 .75846 Mdot
.61306 .69216 Mdot
.47509 .30753 Mdot
.44996 .30912 Mdot
.49049 .28182 Mdot
.35598 .4689 Mdot
.36613 .41479 Mdot
.47064 .26691 Mdot
.71826 .50267 Mdot
.45807 .27014 Mdot
.27528 .34824 Mdot
.68416 .72732 Mdot
.45282 .28433 Mdot
.3884 .50999 Mdot
.3399 .45516 Mdot
.41462 .30714 Mdot
.58823 .33446 Mdot
.81051 .55204 Mdot
.20767 .61593 Mdot
.37851 .47392 Mdot
.25303 .489 Mdot
.43788 .66149 Mdot
.49381 .58284 Mdot
.32124 .569 Mdot
.58174 .44552 Mdot
.49111 .66796 Mdot
.57988 .53588 Mdot
.49422 .70545 Mdot
.38331 .45349 Mdot
.39605 .50261 Mdot
.49924 .65285 Mdot
.70689 .65405 Mdot
.48401 .80865 Mdot
.65875 .73678 Mdot
.46096 .70162 Mdot
.65668 .49002 Mdot
.7035 .48128 Mdot
.67909 .5194 Mdot
.58792 .34588 Mdot
.49199 .65723 Mdot
.34696 .53496 Mdot
.58112 .39992 Mdot
.4102 .51467 Mdot
.69568 .50453 Mdot
.58058 .64692 Mdot
.49909 .68345 Mdot
.37414 .49581 Mdot
.22776 .65646 Mdot
.58402 .37755 Mdot
.46641 .30186 Mdot
.64119 .57606 Mdot
.62003 .39284 Mdot
.67294 .47098 Mdot
.50032 .72706 Mdot
.53849 .37802 Mdot
.53838 .21243 Mdot
.38757 .55958 Mdot
.37965 .55693 Mdot
.65381 .41866 Mdot
.25804 .70344 Mdot
.35098 .48188 Mdot
.57626 .40026 Mdot
.61805 .36724 Mdot
.36632 .54812 Mdot
.46507 .64378 Mdot
.45661 .26532 Mdot
.49982 .29118 Mdot
.41759 .47564 Mdot
.57906 .56744 Mdot
.37086 .25942 Mdot
.34966 .51356 Mdot
.29191 .47782 Mdot
.57572 .33012 Mdot
.62957 .68863 Mdot
.56338 .5821 Mdot
.49592 .29276 Mdot
.40196 .50257 Mdot
.50182 .80675 Mdot
.49738 .67503 Mdot
.60372 .35783 Mdot
.70413 .49746 Mdot
.51217 .29543 Mdot
.55433 .38718 Mdot
.366 .548 Mdot
.34302 .50449 Mdot
.64923 .49707 Mdot
.51849 .7213 Mdot
.48215 .29467 Mdot
.58508 .39998 Mdot
.49307 .31034 Mdot
.46232 .68329 Mdot
.49317 .67538 Mdot
.38972 .44201 Mdot
.44314 .48562 Mdot
.57528 .40377 Mdot
.4253 .53012 Mdot
.56386 .36119 Mdot
.64681 .25997 Mdot
.70423 .4909 Mdot
.42045 .52536 Mdot
.51835 .66219 Mdot
.69454 .50496 Mdot
.36881 .47401 Mdot
.65297 .42025 Mdot
.34772 .50095 Mdot
.62433 .36513 Mdot
.22117 .48388 Mdot
.49088 .30171 Mdot
.46458 .45985 Mdot
.44873 .5695 Mdot
.37847 .53962 Mdot
.60674 .33991 Mdot
.39816 .42186 Mdot
.66664 .499 Mdot
.46878 .66789 Mdot
.30917 .2333 Mdot
.68285 .49471 Mdot
.39807 .51533 Mdot
.47534 .2885 Mdot
.47486 .71288 Mdot
.61106 .70343 Mdot
.59134 .59512 Mdot
.32263 .54111 Mdot
.40609 .56607 Mdot
.39547 .53336 Mdot
.63324 .20148 Mdot
.58863 .35622 Mdot
.48093 .65681 Mdot
.70633 .4865 Mdot
.68303 .5097 Mdot
.57642 .37556 Mdot
.6061 .78003 Mdot
.72512 .66745 Mdot
.14186 .65205 Mdot
.56026 .39427 Mdot
.47177 .26995 Mdot
.55282 .52746 Mdot
.56435 .3686 Mdot
.59638 .36166 Mdot
.55897 .33662 Mdot
.61195 .73794 Mdot
.45565 .6926 Mdot
.39185 .4935 Mdot
.5172 .69201 Mdot
.34437 .47169 Mdot
.41763 .22969 Mdot
.68932 .50749 Mdot
.46741 .66946 Mdot
.64533 .35994 Mdot
.42337 .5742 Mdot
.36185 .49504 Mdot
.51614 .27551 Mdot
.33033 .54381 Mdot
.37295 .30992 Mdot
.41951 .46478 Mdot
.58225 .36711 Mdot
.28936 .55221 Mdot
.31352 .45882 Mdot
.22084 .63533 Mdot
.69032 .48564 Mdot
.61156 .70627 Mdot
.32421 .47442 Mdot
.30067 .51258 Mdot
.47947 .71426 Mdot
.45918 .64014 Mdot
.46895 .26631 Mdot
.66359 .58107 Mdot
.6873 .4842 Mdot
.77 .63925 Mdot
.39126 .46855 Mdot
.73587 .48442 Mdot
.21874 .48275 Mdot
.36633 .47746 Mdot
.54172 .4115 Mdot
.39825 .71019 Mdot
.34761 .48876 Mdot
.29938 .68022 Mdot
.67549 .49199 Mdot
.19985 .4331 Mdot
.43107 .50424 Mdot
.60286 .38354 Mdot
.46208 .67101 Mdot
.44063 .68415 Mdot
.45069 .28062 Mdot
.18713 .5685 Mdot
.63071 .46343 Mdot
.46432 .67371 Mdot
.37462 .51314 Mdot
.67094 .48583 Mdot
.61581 .70752 Mdot
.37473 .57173 Mdot
.74999 .32635 Mdot
.49391 .68708 Mdot
.33252 .43923 Mdot
.6544 .74064 Mdot
.56936 .49158 Mdot
.81019 .61774 Mdot
.67058 .51812 Mdot
.49649 .29222 Mdot
.43668 .48978 Mdot
.6748 .32089 Mdot
.43141 .49722 Mdot
.40149 .23157 Mdot
.46752 .61736 Mdot
.47982 .31636 Mdot
.3715 .50284 Mdot
.34947 .47474 Mdot
.5642 .55434 Mdot
.45925 .31668 Mdot
.34909 .47359 Mdot
.37379 .43136 Mdot
.46314 .69682 Mdot
.61573 .67094 Mdot
.49661 .68894 Mdot
.38912 .51962 Mdot
.25041 .44636 Mdot
.45795 .6438 Mdot
.80007 .56152 Mdot
.45525 .32916 Mdot
.67242 .50913 Mdot
.29986 .47256 Mdot
.40661 .47983 Mdot
.85266 .47209 Mdot
.62241 .70833 Mdot
.4299 .18946 Mdot
.6238 .37551 Mdot
.53109 .84225 Mdot
.61923 .39717 Mdot
.71976 .72714 Mdot
.50253 .48957 Mdot
.41424 .54617 Mdot
.40187 .36739 Mdot
.28944 .67353 Mdot
.6746 .53547 Mdot
.25193 .59226 Mdot
.39203 .46998 Mdot
.39516 .48327 Mdot
.5693 .39041 Mdot
.62585 .76869 Mdot
.54447 .6492 Mdot
.56411 .57538 Mdot
.48564 .30114 Mdot
.46843 .68104 Mdot
.36634 .51274 Mdot
.67895 .62906 Mdot
.60426 .39808 Mdot
.34638 .39584 Mdot
.37667 .49763 Mdot
.5527 .64179 Mdot
.58028 .77383 Mdot
.67605 .48243 Mdot
.62121 .36329 Mdot
.61511 .34468 Mdot
.33177 .4836 Mdot
.70278 .51292 Mdot
.34155 .49264 Mdot
.55371 .48831 Mdot
.31213 .50306 Mdot
.47076 .31305 Mdot
.41314 .51837 Mdot
.42536 .37604 Mdot
.71539 .75207 Mdot
.30603 .48944 Mdot
.49437 .71188 Mdot
.58116 .34618 Mdot
.57228 .36735 Mdot
.46671 .7038 Mdot
.57194 .36847 Mdot
.31168 .65101 Mdot
.24578 .53712 Mdot
.46256 .30996 Mdot
.27234 .68769 Mdot
.48755 .30423 Mdot
.60978 .70515 Mdot
.37508 .47938 Mdot
.6986 .33263 Mdot
.55999 .39451 Mdot
.24268 .38231 Mdot
.68376 .50293 Mdot
.62438 .70735 Mdot
.3286 .52149 Mdot
.48795 .25421 Mdot
.57552 .38741 Mdot
.76372 .47285 Mdot
.32654 .49647 Mdot
.44777 .67941 Mdot
.34755 .48429 Mdot
.33674 .54111 Mdot
.63275 .69961 Mdot
.39505 .53473 Mdot
.66573 .48133 Mdot
.49356 .65792 Mdot
.7232 .71877 Mdot
.58627 .34388 Mdot
.40301 .48541 Mdot
.37384 .51144 Mdot
.46073 .63763 Mdot
.32701 .5207 Mdot
.69648 .51871 Mdot
.36405 .8753 Mdot
.45352 .30184 Mdot
.62856 .68642 Mdot
.78216 .51262 Mdot
.36566 .5197 Mdot
.35518 .51679 Mdot
.6606 .44486 Mdot
.47813 .79388 Mdot
.66095 .49199 Mdot
.31664 .50318 Mdot
.60045 .39538 Mdot
.48311 .29089 Mdot
.67942 .52529 Mdot
.37389 .54838 Mdot
.39327 .48227 Mdot
.46213 .31107 Mdot
.51302 .26916 Mdot
.63069 .38517 Mdot
.68097 .51746 Mdot
.25739 .48834 Mdot
.59779 .25133 Mdot
.38312 .48876 Mdot
.66273 .70101 Mdot
.48612 .67026 Mdot
.65723 .50152 Mdot
.43653 .75868 Mdot
.39448 .45737 Mdot
.66683 .47382 Mdot
.684 .48417 Mdot
.32369 .5106 Mdot
.51459 .70698 Mdot
.49725 .72033 Mdot
.48738 .66903 Mdot
.21134 .4313 Mdot
.51849 .18862 Mdot
.58833 .35087 Mdot
.67798 .48863 Mdot
.60461 .40707 Mdot
.47373 .26461 Mdot
.56237 .53313 Mdot
.6193 .37036 Mdot
.45858 .70421 Mdot
.59272 .41211 Mdot
.34367 .49732 Mdot
.69794 .49088 Mdot
.56716 .39726 Mdot
.36582 .53141 Mdot
.29596 .46648 Mdot
.41842 .37429 Mdot
.4488 .2681 Mdot
.58058 .5394 Mdot
.39466 .51755 Mdot
.62373 .68648 Mdot
.37097 .4863 Mdot
.70363 .5146 Mdot
.44799 .37952 Mdot
.36092 .53588 Mdot
.56201 .39727 Mdot
.55203 .20948 Mdot
.60636 .34178 Mdot
.33264 .53388 Mdot
.38978 .51874 Mdot
.38396 .48614 Mdot
.35615 .46561 Mdot
.55941 .79164 Mdot
.69722 .53114 Mdot
.31123 .44083 Mdot
.55051 .37173 Mdot
.47843 .69145 Mdot
.44745 .65627 Mdot
.60691 .4452 Mdot
.62786 .7094 Mdot
.70155 .51223 Mdot
.38554 .48632 Mdot
.76294 .47156 Mdot
.6109 .61492 Mdot
.66225 .73774 Mdot
.59987 .43484 Mdot
.57339 .39965 Mdot
.49721 .71231 Mdot
.55777 .3656 Mdot
.37491 .55005 Mdot
.42301 .46823 Mdot
.73666 .706 Mdot
.72077 .4938 Mdot
.48252 .29616 Mdot
.41023 .51714 Mdot
.3575 .25539 Mdot
.594 .39835 Mdot
.58057 .32935 Mdot
.33963 .49267 Mdot
.46485 .72457 Mdot
.78269 .68923 Mdot
.70513 .50517 Mdot
.2419 .60962 Mdot
.53201 .66402 Mdot
.28417 .45434 Mdot
.67099 .49949 Mdot
.52117 .39793 Mdot
.58841 .33683 Mdot
.20055 .60118 Mdot
.48424 .68724 Mdot
.48057 .29868 Mdot
.35884 .43402 Mdot
.45931 .70495 Mdot
.60313 .41164 Mdot
.50414 .69472 Mdot
.4022 .45832 Mdot
.71628 .50396 Mdot
.56847 .36602 Mdot
.67858 .53309 Mdot
.49961 .65507 Mdot
.48911 .30295 Mdot
.25229 .37945 Mdot
.23675 .60502 Mdot
.39842 .71013 Mdot
.35228 .53236 Mdot
.72898 .35815 Mdot
.34355 .53287 Mdot
.48022 .72028 Mdot
.38568 .50944 Mdot
.46625 .45097 Mdot
.57395 .3345 Mdot
.32389 .44812 Mdot
.41497 .50816 Mdot
.21676 .60853 Mdot
.3609 .48454 Mdot
.33583 .53005 Mdot
.42498 .49141 Mdot
.53158 .70446 Mdot
.32872 .4464 Mdot
.44806 .67809 Mdot
.60248 .74914 Mdot
.59744 .36403 Mdot
.49583 .28041 Mdot
.50206 .30729 Mdot
.39712 .23088 Mdot
.34438 .26611 Mdot
.61161 .77414 Mdot
.48323 .7001 Mdot
.66561 .47746 Mdot
.34148 .49505 Mdot
.40125 .76735 Mdot
.29988 .39885 Mdot
.58288 .33674 Mdot
.58267 .40863 Mdot
.39945 .44317 Mdot
.70324 .23076 Mdot
.32932 .44407 Mdot
.59124 .60736 Mdot
.34975 .46931 Mdot
.4226 .51899 Mdot
.5848 .32805 Mdot
.29904 .31926 Mdot
.35322 .53274 Mdot
.47959 .71394 Mdot
.47618 .30348 Mdot
.26315 .51217 Mdot
.28191 .40406 Mdot
.28907 .42764 Mdot
.46073 .60345 Mdot
.37774 .54607 Mdot
.58912 .39693 Mdot
.46647 .7083 Mdot
.57232 .59392 Mdot
.68661 .51839 Mdot
.58489 .58095 Mdot
.22905 .58419 Mdot
.7192 .54648 Mdot
.48107 .30089 Mdot
.61641 .42685 Mdot
.37078 .5191 Mdot
.58809 .34664 Mdot
.36457 .45372 Mdot
.61571 .61232 Mdot
.47916 .31459 Mdot
.5129 .68485 Mdot
.65704 .48912 Mdot
.44883 .68995 Mdot
.38687 .74677 Mdot
.28969 .40728 Mdot
.53112 .84287 Mdot
.61241 .36014 Mdot
.37923 .60664 Mdot
.46726 .65801 Mdot
.32767 .51281 Mdot
.13857 .64275 Mdot
.48232 .67074 Mdot
.44983 .68907 Mdot
.57387 .44546 Mdot
.27019 .36874 Mdot
.31926 .44781 Mdot
.49664 .70214 Mdot
.54522 .37983 Mdot
.46327 .28858 Mdot
.3596 .52631 Mdot
.41041 .46991 Mdot
.46162 .63975 Mdot
.57564 .38472 Mdot
.35896 .24983 Mdot
.57927 .36329 Mdot
.45341 .68572 Mdot
.59198 .38015 Mdot
.7933 .56461 Mdot
.60974 .38928 Mdot
.41562 .50751 Mdot
.3854 .4874 Mdot
.71283 .30268 Mdot
.49316 .67545 Mdot
.35789 .51956 Mdot
.39847 .49647 Mdot
.45996 .65996 Mdot
.61173 .32883 Mdot
.41111 .70921 Mdot
.37078 .53182 Mdot
.38926 .4894 Mdot
.47992 .31767 Mdot
.5714 .51633 Mdot
.64978 .63876 Mdot
.35913 .52401 Mdot
.48543 .27757 Mdot
.51069 .6977 Mdot
.36932 .48579 Mdot
.29885 .31704 Mdot
.61268 .4107 Mdot
.39183 .54746 Mdot
.60635 .69901 Mdot
.35362 .47764 Mdot
.77617 .6949 Mdot
.39725 .48126 Mdot
.46929 .65334 Mdot
.464 .6645 Mdot
.62535 .40334 Mdot
.47505 .68712 Mdot
.63036 .69966 Mdot
.69493 .49965 Mdot
.65711 .76961 Mdot
.62785 .70229 Mdot
.42075 .51368 Mdot
.19448 .61525 Mdot
.41238 .46968 Mdot
.32932 .45811 Mdot
.25439 .3681 Mdot
.62904 .69602 Mdot
.47976 .66062 Mdot
.70806 .64917 Mdot
.41046 .54603 Mdot
.70463 .50845 Mdot
.33557 .45384 Mdot
.39252 .54759 Mdot
.43582 .39591 Mdot
.24824 .52623 Mdot
.6507 .51896 Mdot
.33597 .56409 Mdot
.3584 .52515 Mdot
.47 .78917 Mdot
.37531 .51949 Mdot
.45137 .28411 Mdot
.48202 .70356 Mdot
.55754 .35776 Mdot
.45839 .30274 Mdot
.36756 .51828 Mdot
.47728 .29637 Mdot
.59114 .35204 Mdot
.66302 .51726 Mdot
.41125 .52272 Mdot
.47826 .32308 Mdot
.48471 .29598 Mdot
.33304 .50957 Mdot
.46454 .67107 Mdot
.449 .48605 Mdot
.36798 .4841 Mdot
.35695 .54426 Mdot
.46717 .7036 Mdot
.14718 .49561 Mdot
.3409 .47105 Mdot
.5237 .39753 Mdot
.48395 .63447 Mdot
.63055 .68327 Mdot
.56022 .37576 Mdot
.4375 .52802 Mdot
.68652 .5118 Mdot
.69183 .50324 Mdot
.55101 .35181 Mdot
.48119 .64307 Mdot
.56865 .36989 Mdot
.34314 .56298 Mdot
.40351 .44511 Mdot
.3646 .43344 Mdot
.3114 .23193 Mdot
.79441 .53009 Mdot
.47724 .64993 Mdot
.59481 .33678 Mdot
.57755 .57348 Mdot
.7018 .50595 Mdot
.5576 .33305 Mdot
.50383 .64382 Mdot
.50254 .67065 Mdot
.4711 .70765 Mdot
.48818 .28389 Mdot
.57334 .35731 Mdot
.46111 .62049 Mdot
.49564 .72397 Mdot
.33513 .4991 Mdot
.35754 .52537 Mdot
.43296 .67506 Mdot
.4251 .32454 Mdot
.48121 .31144 Mdot
.59592 .39213 Mdot
.868 .53836 Mdot
.7055 .50465 Mdot
.21668 .6102 Mdot
.36674 .53159 Mdot
.09433 .46073 Mdot
.33236 .44333 Mdot
.37472 .515 Mdot
.50868 .67876 Mdot
.5039 .31459 Mdot
.46651 .28969 Mdot
.46631 .65875 Mdot
.4831 .72949 Mdot
.47675 .27677 Mdot
.56392 .43359 Mdot
.65897 .78394 Mdot
.57457 .58701 Mdot
.46293 .65368 Mdot
.24052 .62389 Mdot
.67337 .52358 Mdot
.50444 .65214 Mdot
.6645 .52891 Mdot
.59794 .36225 Mdot
.59267 .40655 Mdot
.64804 .49881 Mdot
.32559 .51089 Mdot
.61216 .36826 Mdot
.31115 .51901 Mdot
.77788 .652 Mdot
.78595 .38637 Mdot
.42871 .80727 Mdot
.38817 .46478 Mdot
.54087 .63958 Mdot
.56993 .73909 Mdot
.38845 .53493 Mdot
.37798 .58305 Mdot
.48087 .29603 Mdot
.49777 .64579 Mdot
.68814 .5279 Mdot
.81827 .55838 Mdot
.38373 .4879 Mdot
.45145 .67805 Mdot
.70128 .49763 Mdot
.78894 .56397 Mdot
.51343 .45342 Mdot
.34008 .48197 Mdot
.18122 .71769 Mdot
.50089 .65799 Mdot
.5578 .35719 Mdot
.25211 .68081 Mdot
.51784 .68314 Mdot
.58772 .23875 Mdot
.61986 .34815 Mdot
.61034 .64835 Mdot
.50607 .67945 Mdot
.63087 .35415 Mdot
.46455 .68585 Mdot
.44379 .28422 Mdot
.50107 .72716 Mdot
.58184 .38206 Mdot
.36658 .49585 Mdot
.58063 .37865 Mdot
.45324 .30668 Mdot
.60482 .35468 Mdot
.68712 .52784 Mdot
.62834 .69099 Mdot
.69709 .49469 Mdot
.56015 .52818 Mdot
.37878 .62703 Mdot
.66535 .51257 Mdot
.76126 .45346 Mdot
.35128 .48736 Mdot
.51432 .72485 Mdot
.55671 .35395 Mdot
.56118 .40122 Mdot
.58152 .55571 Mdot
.45598 .68483 Mdot
.58683 .38596 Mdot
.23408 .58546 Mdot
.1665 .37148 Mdot
.30335 .47328 Mdot
.53288 .18916 Mdot
.45988 .65866 Mdot
.57393 .33356 Mdot
.58233 .60257 Mdot
.44034 .66989 Mdot
.57115 .40093 Mdot
.65467 .4945 Mdot
.67946 .50913 Mdot
.32445 .49389 Mdot
.67862 .46339 Mdot
.60488 .33802 Mdot
.49574 .80388 Mdot
.47779 .70502 Mdot
.78168 .52949 Mdot
.45841 .27955 Mdot
.5952 .35775 Mdot
.31992 .44914 Mdot
.44878 .61495 Mdot
.57244 .40545 Mdot
.74281 .3027 Mdot
.86729 .50174 Mdot
.58794 .38625 Mdot
.48338 .70317 Mdot
.47996 .69476 Mdot
.30641 .48432 Mdot
.57172 .56614 Mdot
.57934 .38768 Mdot
.69773 .32945 Mdot
.40399 .23615 Mdot
.61312 .70145 Mdot
.21884 .65926 Mdot
.35439 .53383 Mdot
.38047 .54683 Mdot
.69226 .51965 Mdot
.35955 .49474 Mdot
.47625 .72498 Mdot
.34158 .43925 Mdot
.70863 .48483 Mdot
.57835 .33722 Mdot
.37866 .48237 Mdot
.48059 .28376 Mdot
.69312 .52223 Mdot
.67731 .46827 Mdot
.59697 .37425 Mdot
.48667 .70529 Mdot
.69412 .66113 Mdot
.57812 .36205 Mdot
.3706 .54601 Mdot
.62152 .69421 Mdot
.42318 .47341 Mdot
.71489 .31443 Mdot
.444 .68527 Mdot
.55794 .36393 Mdot
.46159 .63273 Mdot
.68353 .48917 Mdot
.54525 .36905 Mdot
.37878 .52678 Mdot
.58129 .40521 Mdot
.51619 .38574 Mdot
.53162 .25651 Mdot
.4903 .72641 Mdot
.45095 .25542 Mdot
.45913 .63943 Mdot
.61272 .70169 Mdot
.32641 .34679 Mdot
.47607 .30904 Mdot
.61022 .3829 Mdot
.80522 .55508 Mdot
.55362 .3567 Mdot
.3614 .48122 Mdot
.37427 .46804 Mdot
.56746 .38809 Mdot
.4926 .29279 Mdot
.31833 .27256 Mdot
.4434 .23487 Mdot
.4977 .66952 Mdot
.5033 .52136 Mdot
.8555 .57855 Mdot
.54304 .33475 Mdot
.66081 .47926 Mdot
.29961 .53274 Mdot
.35065 .50173 Mdot
.65497 .47946 Mdot
.70753 .49433 Mdot
.45578 .31161 Mdot
.59127 .34843 Mdot
.46975 .62577 Mdot
.65605 .51538 Mdot
.42238 .62391 Mdot
.32381 .28213 Mdot
.33559 .54588 Mdot
.38457 .42212 Mdot
.41398 .49025 Mdot
.57011 .49362 Mdot
.71392 .50535 Mdot
.39416 .51128 Mdot
.412 .45124 Mdot
.65951 .5016 Mdot
.44781 .30051 Mdot
.42388 .65964 Mdot
.59737 .38374 Mdot
.13381 .406 Mdot
.41191 .52154 Mdot
.36599 .49087 Mdot
.68103 .51574 Mdot
.27733 .72407 Mdot
.4672 .64875 Mdot
.49074 .70318 Mdot
.58824 .35522 Mdot
.59323 .55958 Mdot
.3402 .53637 Mdot
.39201 .52971 Mdot
.60963 .37551 Mdot
.62374 .6875 Mdot
.3947 .81639 Mdot
.39046 .49731 Mdot
.6723 .49372 Mdot
.7505 .44695 Mdot
.71303 .51009 Mdot
.35201 .45881 Mdot
.3625 .47714 Mdot
.41419 .52461 Mdot
.36307 .4619 Mdot
.64668 .50399 Mdot
.38822 .53254 Mdot
.44655 .53708 Mdot
.48381 .66407 Mdot
.36804 .54174 Mdot
.38799 .2418 Mdot
.38662 .49532 Mdot
.48026 .28435 Mdot
.65849 .64397 Mdot
.40314 .48837 Mdot
.37052 .54344 Mdot
.44811 .23349 Mdot
.37524 .50736 Mdot
.69105 .48163 Mdot
.48399 .69025 Mdot
.68065 .48734 Mdot
.67453 .47877 Mdot
.58511 .41149 Mdot
.44194 .29736 Mdot
.43244 .51553 Mdot
.47628 .27535 Mdot
.31018 .49993 Mdot
.39382 .45622 Mdot
.56745 .5245 Mdot
.59229 .60769 Mdot
.43025 .28945 Mdot
.38427 .52819 Mdot
.59123 .36033 Mdot
.55782 .37176 Mdot
.43866 .3662 Mdot
.31256 .51798 Mdot
.67741 .52559 Mdot
.65325 .50354 Mdot
.40926 .328 Mdot
.47142 .42039 Mdot
.48549 .29024 Mdot
.53654 .56545 Mdot
.40885 .4724 Mdot
.40031 .4924 Mdot
.33849 .45514 Mdot
.61906 .38511 Mdot
.62837 .68875 Mdot
.57932 .3383 Mdot
.59705 .69736 Mdot
.70484 .52345 Mdot
.38909 .46519 Mdot
.79353 .41835 Mdot
.47354 .64303 Mdot
.48538 .68948 Mdot
.70406 .48016 Mdot
.60605 .34103 Mdot
.31213 .51181 Mdot
.3397 .20021 Mdot
.44759 .70369 Mdot
.49812 .28558 Mdot
.39535 .52403 Mdot
.59662 .37 Mdot
.49212 .65479 Mdot
.43763 .29573 Mdot
.39585 .46756 Mdot
.56798 .32611 Mdot
.38558 .5033 Mdot
.30656 .69854 Mdot
.47593 .66358 Mdot
.58247 .64494 Mdot
.45042 .71686 Mdot
.65642 .48033 Mdot
.66367 .48651 Mdot
.36746 .47434 Mdot
.24073 .275 Mdot
.42924 .68242 Mdot
.64695 .48535 Mdot
.44451 .27705 Mdot
.62485 .68367 Mdot
.44013 .28527 Mdot
.56333 .36369 Mdot
.47816 .3036 Mdot
.56766 .40051 Mdot
.4329 .34143 Mdot
.43852 .64206 Mdot
.45635 .30346 Mdot
.2832 .73371 Mdot
.42507 .47299 Mdot
.46187 .31545 Mdot
.39632 .44154 Mdot
.46478 .52567 Mdot
.60827 .37215 Mdot
.48856 .28767 Mdot
.32924 .50064 Mdot
.79866 .49306 Mdot
.66841 .48138 Mdot
.68031 .52669 Mdot
.43239 .50332 Mdot
.56652 .33324 Mdot
.49343 .72754 Mdot
.54758 .44725 Mdot
.62787 .68018 Mdot
.39169 .5292 Mdot
.40037 .46786 Mdot
.48073 .63815 Mdot
.47456 .71642 Mdot
.36453 .47389 Mdot
.23818 .57888 Mdot
.37126 .52086 Mdot
.67563 .50727 Mdot
.49444 .66097 Mdot
.48405 .6928 Mdot
.61868 .35493 Mdot
.48034 .64281 Mdot
.36292 .42291 Mdot
.63072 .50508 Mdot
.37326 .44071 Mdot
.68442 .49197 Mdot
.4563 .37767 Mdot
.59171 .34625 Mdot
.81129 .54832 Mdot
.48904 .64967 Mdot
.38748 .54147 Mdot
.4498 .65335 Mdot
.45564 .2847 Mdot
.49368 .67715 Mdot
.43645 .66252 Mdot
.38714 .46885 Mdot
.34172 .47506 Mdot
.62253 .68972 Mdot
.57689 .56493 Mdot
.47314 .66866 Mdot
.3748 .53129 Mdot
.42967 .50231 Mdot
.33459 .47696 Mdot
.55704 .48404 Mdot
.50949 .68785 Mdot
.225 .52385 Mdot
.74927 .34196 Mdot
.46715 .67188 Mdot
.83077 .58617 Mdot
.60358 .68035 Mdot
.62764 .71011 Mdot
.64491 .48381 Mdot
.39118 .49245 Mdot
.57112 .37216 Mdot
.38686 .54818 Mdot
.31403 .52584 Mdot
.40512 .48883 Mdot
.46624 .31361 Mdot
.39734 .56047 Mdot
.60572 .68777 Mdot
.57913 .3677 Mdot
.36934 .52613 Mdot
.3832 .48118 Mdot
.62229 .71157 Mdot
.44396 .71068 Mdot
.50238 .67177 Mdot
.65999 .68222 Mdot
.44763 .29624 Mdot
.68623 .52018 Mdot
.38144 .54887 Mdot
.58962 .3582 Mdot
.57606 .37393 Mdot
.44905 .68925 Mdot
.59985 .38615 Mdot
.70187 .51864 Mdot
.3711 .51403 Mdot
.65333 .48249 Mdot
.46537 .31325 Mdot
.48134 .70369 Mdot
.37701 .54952 Mdot
.33372 .49834 Mdot
.46427 .66428 Mdot
.35105 .48359 Mdot
.48166 .31719 Mdot
.61179 .39359 Mdot
.4919 .6618 Mdot
.69412 .50018 Mdot
.62005 .36156 Mdot
.34334 .50074 Mdot
.83819 .39727 Mdot
.35893 .49511 Mdot
.40392 .52907 Mdot
.68401 .75655 Mdot
.41542 .46113 Mdot
.56431 .34283 Mdot
.44934 .65166 Mdot
.34393 .46221 Mdot
.41807 .23316 Mdot
.61781 .31125 Mdot
.57077 .32307 Mdot
.3969 .52534 Mdot
.81535 .5928 Mdot
.38427 .54149 Mdot
.78946 .58671 Mdot
.56755 .52656 Mdot
.64945 .21769 Mdot
.39995 .42826 Mdot
.64955 .48214 Mdot
.62493 .68981 Mdot
.55682 .34781 Mdot
.35157 .74349 Mdot
.35454 .48853 Mdot
.41655 .75461 Mdot
.38693 .55058 Mdot
.67232 .50168 Mdot
.35825 .58018 Mdot
.59708 .39081 Mdot
.20908 .62313 Mdot
.35285 .53947 Mdot
.50772 .67903 Mdot
.55353 .39628 Mdot
.61803 .67952 Mdot
.3283 .49942 Mdot
.46432 .27529 Mdot
.6368 .34401 Mdot
.38754 .4288 Mdot
.68695 .49278 Mdot
.40064 .49847 Mdot
.30835 .53794 Mdot
.18801 .3491 Mdot
.48649 .66362 Mdot
.6582 .483 Mdot
.48366 .59166 Mdot
.36167 .46647 Mdot
.50311 .67367 Mdot
.482 .68887 Mdot
.45351 .27581 Mdot
.61632 .59847 Mdot
.58275 .29909 Mdot
.79256 .36995 Mdot
.3954 .72465 Mdot
.62296 .37578 Mdot
.51213 .7803 Mdot
.3544 .52846 Mdot
.28225 .41291 Mdot
.68145 .47999 Mdot
.3672 .49429 Mdot
.38065 .67322 Mdot
.48988 .67027 Mdot
.38984 .50448 Mdot
.47904 .31194 Mdot
.60254 .71979 Mdot
.27573 .45177 Mdot
.84232 .45578 Mdot
.54426 .35482 Mdot
.34272 .4467 Mdot
.41515 .44391 Mdot
.63121 .6847 Mdot
.35667 .45802 Mdot
.55786 .34976 Mdot
.73772 .368 Mdot
.49362 .29872 Mdot
.47825 .64458 Mdot
.60579 .67845 Mdot
.3967 .54993 Mdot
.41736 .47053 Mdot
.49345 .27819 Mdot
.33254 .52079 Mdot
.23563 .65566 Mdot
.63771 .71428 Mdot
.61028 .38954 Mdot
.502 .69849 Mdot
.41348 .48776 Mdot
.62597 .68684 Mdot
.3832 .4681 Mdot
.47049 .52091 Mdot
.40168 .52248 Mdot
.61949 .78652 Mdot
.4617 .6723 Mdot
.69065 .49183 Mdot
.41042 .55835 Mdot
.37984 .4932 Mdot
.60043 .2543 Mdot
.31578 .52958 Mdot
.39616 .48112 Mdot
.46279 .71016 Mdot
.46312 .64256 Mdot
.45212 .68919 Mdot
.61353 .38188 Mdot
.56972 .58333 Mdot
.67908 .50213 Mdot
.31993 .46974 Mdot
.66617 .52124 Mdot
.44842 .45253 Mdot
.48666 .27469 Mdot
.82373 .51928 Mdot
.36119 .50722 Mdot
.46208 .69983 Mdot
.51601 .79866 Mdot
.51077 .69808 Mdot
.68448 .45988 Mdot
.68841 .48438 Mdot
.47964 .6709 Mdot
.37964 .5133 Mdot
.56336 .57366 Mdot
.83151 .41099 Mdot
.7008 .5058 Mdot
.36098 .44816 Mdot
.54235 .36489 Mdot
.55563 .39206 Mdot
.81435 .64303 Mdot
.67583 .47648 Mdot
.56719 .73935 Mdot
.37644 .53649 Mdot
.47055 .64114 Mdot
.67092 .51654 Mdot
.69189 .48068 Mdot
.60747 .37995 Mdot
.33866 .48594 Mdot
.38172 .4958 Mdot
.60452 .69636 Mdot
.65973 .51594 Mdot
.40647 .57151 Mdot
.34448 .47939 Mdot
.72213 .72287 Mdot
.49469 .63608 Mdot
.14328 .51056 Mdot
.3392 .56171 Mdot
.38501 .67154 Mdot
.49707 .42985 Mdot
.48271 .65147 Mdot
.34163 .53446 Mdot
.3172 .47492 Mdot
.62314 .36893 Mdot
.36692 .50834 Mdot
.60027 .34323 Mdot
.6645 .47665 Mdot
.82957 .5209 Mdot
.7557 .4745 Mdot
.63476 .52606 Mdot
.35962 .48998 Mdot
.28991 .43871 Mdot
.4552 .29443 Mdot
.72224 .50754 Mdot
.44995 .66533 Mdot
.41495 .48465 Mdot
.62577 .358 Mdot
.60803 .38801 Mdot
.4845 .68205 Mdot
.5746 .75603 Mdot
.8 .5628 Mdot
.3669 .46093 Mdot
.56089 .36983 Mdot
.76341 .49323 Mdot
.25598 .57708 Mdot
.65786 .47268 Mdot
.4926 .30233 Mdot
.57215 .34038 Mdot
.70559 .47703 Mdot
.47062 .49824 Mdot
.47692 .67947 Mdot
.48993 .64538 Mdot
.63821 .27978 Mdot
.57962 .38474 Mdot
.46126 .2995 Mdot
.48787 .43866 Mdot
.49082 .45724 Mdot
.47903 .314 Mdot
.58171 .33636 Mdot
.47452 .64515 Mdot
.45203 .68107 Mdot
.4822 .69121 Mdot
.22109 .63635 Mdot
.44158 .6829 Mdot
.189 .48582 Mdot
.39541 .46145 Mdot
.24703 .62059 Mdot
.38985 .53803 Mdot
.6516 .51468 Mdot
.47402 .66363 Mdot
.56423 .53921 Mdot
.42365 .50116 Mdot
.83735 .44187 Mdot
.39508 .51888 Mdot
.63324 .44189 Mdot
.39063 .49051 Mdot
.26361 .68251 Mdot
.4861 .63567 Mdot
.38344 .52945 Mdot
.63423 .4976 Mdot
.4803 .29159 Mdot
.43506 .70094 Mdot
.39821 .48526 Mdot
.64321 .7437 Mdot
.40431 .44706 Mdot
.79832 .61229 Mdot
.53604 .21385 Mdot
.50544 .30076 Mdot
.37156 .43545 Mdot
.58741 .41531 Mdot
.44549 .60102 Mdot
.25263 .64093 Mdot
.70039 .50547 Mdot
.24151 .50701 Mdot
.61157 .37713 Mdot
.37653 .58233 Mdot
.35855 .55579 Mdot
.49441 .29176 Mdot
.42669 .67183 Mdot
.67327 .50694 Mdot
.35295 .49047 Mdot
.33453 .52786 Mdot
.71537 .27934 Mdot
.25133 .64719 Mdot
.41051 .56809 Mdot
.46867 .2646 Mdot
.23307 .52921 Mdot
.40549 .49433 Mdot
.57303 .32322 Mdot
.44471 .65723 Mdot
.33597 .4331 Mdot
.22159 .52565 Mdot
.37264 .52757 Mdot
.48224 .67348 Mdot
.48761 .64788 Mdot
.56231 .81261 Mdot
.48784 .27683 Mdot
.40185 .52203 Mdot
.61675 .25379 Mdot
.37208 .54702 Mdot
.67716 .50427 Mdot
.35216 .45752 Mdot
.6022 .36207 Mdot
.58401 .60839 Mdot
.61499 .37899 Mdot
.32959 .48711 Mdot
.46514 .69333 Mdot
.67443 .51094 Mdot
.66495 .2898 Mdot
.59169 .45787 Mdot
.19047 .48056 Mdot
.63408 .33853 Mdot
.48024 .2803 Mdot
.43934 .29505 Mdot
.62729 .48809 Mdot
.38879 .52262 Mdot
.56666 .47147 Mdot
.31619 .46446 Mdot
.39296 .4874 Mdot
.41239 .51317 Mdot
.71287 .53579 Mdot
.69024 .48654 Mdot
.58809 .38134 Mdot
.36313 .47429 Mdot
.37576 .53197 Mdot
.46807 .67634 Mdot
.48514 .2957 Mdot
.60721 .39742 Mdot
.44885 .29391 Mdot
.5837 .36614 Mdot
.79001 .67775 Mdot
.34973 .45599 Mdot
.47926 .29057 Mdot
.71454 .50942 Mdot
.45919 .69987 Mdot
.6201 .70948 Mdot
.564 .36348 Mdot
.59402 .39143 Mdot
.38883 .53337 Mdot
.49548 .69638 Mdot
.50213 .68386 Mdot
.47834 .27781 Mdot
.65658 .50839 Mdot
.323 .49376 Mdot
.34363 .4758 Mdot
.63142 .22947 Mdot
.62125 .37271 Mdot
.2316 .56352 Mdot
.57544 .79492 Mdot
.38802 .52358 Mdot
.50371 .68138 Mdot
.37545 .48414 Mdot
.78067 .43502 Mdot
.46206 .70628 Mdot
.42769 .50654 Mdot
.43523 .39953 Mdot
.61699 .38858 Mdot
.55548 .82853 Mdot
.42402 .53921 Mdot
.67329 .44826 Mdot
.34042 .5192 Mdot
.61007 .84209 Mdot
.48766 .78693 Mdot
.38968 .55135 Mdot
.36768 .46215 Mdot
.78865 .3466 Mdot
.37733 .53987 Mdot
.60363 .68841 Mdot
.33297 .55443 Mdot
.50335 .6724 Mdot
.51128 .43494 Mdot
.57916 .52762 Mdot
.47041 .26922 Mdot
.58866 .35465 Mdot
.29627 .34512 Mdot
.4441 .29137 Mdot
.46575 .65468 Mdot
.42004 .48034 Mdot
.41149 .65213 Mdot
.6158 .41316 Mdot
.32446 .52713 Mdot
.67552 .50363 Mdot
.57988 .53071 Mdot
.58318 .33991 Mdot
.69521 .49797 Mdot
.40541 .54016 Mdot
.42331 .1987 Mdot
.60486 .46618 Mdot
.60478 .81367 Mdot
.68116 .51727 Mdot
.67757 .48309 Mdot
.56472 .59773 Mdot
.47002 .26927 Mdot
.69317 .26049 Mdot
.2681 .49724 Mdot
.70435 .50532 Mdot
.37023 .32369 Mdot
.60164 .3327 Mdot
.60922 .6027 Mdot
.49925 .64634 Mdot
.34531 .45732 Mdot
.37997 .50889 Mdot
.65815 .50505 Mdot
.45606 .75827 Mdot
.47923 .54535 Mdot
.69888 .49773 Mdot
.43092 .46093 Mdot
.6144 .60736 Mdot
.62518 .69468 Mdot
.60082 .6864 Mdot
.45168 .27112 Mdot
.53048 .27829 Mdot
.45866 .68035 Mdot
.49824 .3046 Mdot
.60615 .6622 Mdot
.40331 .51745 Mdot
.65943 .51633 Mdot
.61057 .70678 Mdot
.68964 .50308 Mdot
.47059 .28722 Mdot
.49511 .28213 Mdot
.48435 .66394 Mdot
.46531 .64863 Mdot
.27727 .55711 Mdot
.39478 .30151 Mdot
.37396 .54197 Mdot
.41199 .71628 Mdot
.4575 .70123 Mdot
.32406 .74914 Mdot
.4773 .27395 Mdot
.48654 .30159 Mdot
.28844 .64609 Mdot
.33913 .49804 Mdot
.7447 .45542 Mdot
.40226 .48841 Mdot
.33493 .3509 Mdot
.4111 .54377 Mdot
.60524 .38174 Mdot
.35613 .53855 Mdot
.68744 .64173 Mdot
.36176 .51913 Mdot
.41134 .49912 Mdot
.569 .35858 Mdot
.40857 .56096 Mdot
.60536 .36406 Mdot
.34307 .46963 Mdot
.50985 .30801 Mdot
.58931 .35812 Mdot
.43169 .23628 Mdot
.52295 .40497 Mdot
.6174 .68415 Mdot
.44468 .27849 Mdot
.46693 .27595 Mdot
.38385 .23856 Mdot
.45299 .65724 Mdot
.47173 .48468 Mdot
.38946 .52107 Mdot
.57661 .33012 Mdot
.68692 .52288 Mdot
.37377 .52798 Mdot
.33513 .44249 Mdot
.42702 .5356 Mdot
.48413 .66809 Mdot
.58036 .33521 Mdot
.47411 .29387 Mdot
.55926 .3791 Mdot
.51295 .28169 Mdot
.55299 .37814 Mdot
.28916 .49097 Mdot
.36072 .5718 Mdot
.45726 .5074 Mdot
.39886 .69887 Mdot
.19671 .59459 Mdot
.47919 .68264 Mdot
.61473 .69456 Mdot
.48277 .27168 Mdot
.5011 .51965 Mdot
.46189 .69722 Mdot
.58916 .39228 Mdot
.38551 .50344 Mdot
.43591 .4663 Mdot
.27534 .46809 Mdot
.45873 .61778 Mdot
.40651 .2635 Mdot
.57695 .34906 Mdot
.62157 .70274 Mdot
.58037 .59159 Mdot
.53278 .68408 Mdot
.56055 .53355 Mdot
.37791 .48827 Mdot
.46965 .27449 Mdot
.49201 .65469 Mdot
.70259 .29325 Mdot
.65553 .49858 Mdot
.57432 .56598 Mdot
.36002 .4925 Mdot
.53298 .76778 Mdot
.46549 .69331 Mdot
.48677 .30608 Mdot
.65851 .5049 Mdot
.48246 .27438 Mdot
.60733 .67607 Mdot
.66104 .66161 Mdot
.32941 .51125 Mdot
.39629 .48012 Mdot
.70172 .52417 Mdot
.45913 .6829 Mdot
.63188 .39544 Mdot
.72859 .30137 Mdot
.56193 .37323 Mdot
.57713 .48448 Mdot
.49252 .65684 Mdot
.5098 .75982 Mdot
.57713 .40242 Mdot
.71792 .49924 Mdot
.56607 .4781 Mdot
.70497 .48204 Mdot
.40919 .49903 Mdot
.48665 .69752 Mdot
.67579 .47625 Mdot
.65118 .27039 Mdot
.77665 .67649 Mdot
.42726 .6409 Mdot
.35577 .47403 Mdot
.82604 .517 Mdot
.70768 .71182 Mdot
.43974 .73469 Mdot
.65029 .50943 Mdot
.36881 .47797 Mdot
.371 .46067 Mdot
.35451 .54014 Mdot
.66144 .4837 Mdot
.61712 .44922 Mdot
.59527 .39541 Mdot
.39645 .51111 Mdot
.45841 .28007 Mdot
.60282 .36881 Mdot
.57805 .41264 Mdot
.55568 .3499 Mdot
.46239 .70734 Mdot
.40578 .46636 Mdot
.57217 .6604 Mdot
.64464 .81824 Mdot
.68609 .48663 Mdot
.61698 .68403 Mdot
.41291 .52318 Mdot
.20399 .42408 Mdot
.45352 .69136 Mdot
.56329 .37593 Mdot
.36707 .4923 Mdot
.5576 .22788 Mdot
.64975 .7111 Mdot
.57643 .35768 Mdot
.4507 .66513 Mdot
.43761 .73128 Mdot
.36723 .50948 Mdot
.3408 .51751 Mdot
.45637 .66909 Mdot
.66227 .72882 Mdot
.59076 .60217 Mdot
.37783 .48386 Mdot
.69279 .49317 Mdot
.17941 .34727 Mdot
.42476 .48029 Mdot
.45959 .61504 Mdot
.6276 .68568 Mdot
.61811 .77956 Mdot
.23512 .55996 Mdot
.30036 .47338 Mdot
.8172 .47744 Mdot
.27868 .34564 Mdot
.8302 .53671 Mdot
.28626 .37679 Mdot
.76483 .50942 Mdot
.73163 .75026 Mdot
.63727 .48972 Mdot
.27335 .69007 Mdot
.71317 .25201 Mdot
.5842 .73451 Mdot
.50287 .22104 Mdot
.68433 .33879 Mdot
.56067 .22067 Mdot
.30431 .76707 Mdot
.5558 .3861 Mdot
.31901 .37372 Mdot
.3252 .51277 Mdot
.70219 .70729 Mdot
.22778 .60737 Mdot
.18574 .5725 Mdot
.81944 .52425 Mdot
.60128 .24506 Mdot
.82053 .3658 Mdot
.80654 .54351 Mdot
.31541 .57871 Mdot
.34055 .3991 Mdot
.53817 .29606 Mdot
.48829 .44545 Mdot
.28648 .35323 Mdot
.38234 .41645 Mdot
.68553 .62688 Mdot
.64078 .52671 Mdot
.33532 .60414 Mdot
.17116 .38143 Mdot
.56358 .34788 Mdot
.44359 .65876 Mdot
.68376 .24952 Mdot
.45162 .6088 Mdot
.63663 .4638 Mdot
.8175 .47696 Mdot
.72145 .7275 Mdot
.2601 .6776 Mdot
.59435 .6526 Mdot
.31397 .69227 Mdot
.31362 .27088 Mdot
.32434 .39903 Mdot
.5107 .707 Mdot
.69139 .40723 Mdot
.48996 .45625 Mdot
.52671 .30994 Mdot
.27963 .70875 Mdot
.43822 .29974 Mdot
.42825 .23571 Mdot
.45065 .67157 Mdot
.26133 .57474 Mdot
.63167 .70937 Mdot
.58901 .66759 Mdot
.622 .3443 Mdot
.7764 .41992 Mdot
.64293 .7275 Mdot
.6309 .73836 Mdot
.47289 .81372 Mdot
.85166 .43628 Mdot
.33883 .29413 Mdot
.72684 .34716 Mdot
.65976 .45128 Mdot
.29185 .32916 Mdot
.56271 .63555 Mdot
.37719 .28922 Mdot
.46804 .44202 Mdot
.758 .26131 Mdot
.67245 .74123 Mdot
.80839 .33181 Mdot
.50565 .72707 Mdot
.43705 .50056 Mdot
.74941 .36624 Mdot
.39067 .73393 Mdot
.50053 .32219 Mdot
.84922 .44649 Mdot
.50067 .29636 Mdot
.46435 .62611 Mdot
.5805 .73668 Mdot
.23018 .63998 Mdot
.63456 .40077 Mdot
.43969 .32006 Mdot
.34755 .42975 Mdot
.72852 .21657 Mdot
.81942 .46215 Mdot
.57782 .80485 Mdot
.71502 .72845 Mdot
.54672 .33038 Mdot
.59851 .41958 Mdot
.66852 .47451 Mdot
.74944 .71672 Mdot
.47427 .69824 Mdot
.65011 .81864 Mdot
.74585 .7139 Mdot
.49052 .61261 Mdot
.71359 .20006 Mdot
.38719 .80803 Mdot
.24356 .61024 Mdot
.2339 .45594 Mdot
.49175 .18999 Mdot
.55655 .61122 Mdot
.51583 .75579 Mdot
.53899 .35591 Mdot
.65435 .76851 Mdot
.79796 .65796 Mdot
.37507 .33189 Mdot
.70822 .55239 Mdot
.56707 .68516 Mdot
.44911 .37363 Mdot
.43769 .63438 Mdot
.47672 .21645 Mdot
.43306 .37134 Mdot
.81711 .35 Mdot
.23633 .51518 Mdot
.27619 .247 Mdot
.29858 .36489 Mdot
.27063 .71664 Mdot
.78712 .51245 Mdot
.47545 .34251 Mdot
.47406 .52585 Mdot
.61023 .75338 Mdot
.37722 .44519 Mdot
.53876 .57346 Mdot
.42425 .58098 Mdot
.49461 .26607 Mdot
.56815 .59033 Mdot
.76381 .63117 Mdot
.31553 .34904 Mdot
.78073 .36679 Mdot
.35418 .399 Mdot
.49666 .70614 Mdot
.36987 .2791 Mdot
.34617 .31618 Mdot
.73809 .70211 Mdot
.48542 .59303 Mdot
.62063 .80012 Mdot
.47892 .58336 Mdot
.31906 .45852 Mdot
.28207 .69814 Mdot
.40649 .4245 Mdot
.36747 .31055 Mdot
.41781 .54415 Mdot
.48544 .81313 Mdot
.68849 .75069 Mdot
.38045 .64123 Mdot
.31228 .33115 Mdot
.39654 .6797 Mdot
.65899 .76871 Mdot
.75419 .36699 Mdot
.52902 .75287 Mdot
.4836 .77177 Mdot
.73803 .22967 Mdot
.59836 .37843 Mdot
.37992 .32067 Mdot
.71105 .53049 Mdot
.65757 .28366 Mdot
.69302 .2343 Mdot
.47557 .5672 Mdot
.68368 .76354 Mdot
.60389 .73812 Mdot
.61935 .41821 Mdot
.65662 .59625 Mdot
.73294 .52874 Mdot
.39999 .65279 Mdot
.43351 .51538 Mdot
.44306 .57824 Mdot
.48602 .31692 Mdot
.36886 .73097 Mdot
.74057 .33914 Mdot
.65826 .36873 Mdot
.29865 .46865 Mdot
.66648 .39405 Mdot
.61616 .70397 Mdot
.58719 .56799 Mdot
.80823 .65847 Mdot
.31064 .53269 Mdot
.36288 .79488 Mdot
.67004 .73093 Mdot
.57189 .49481 Mdot
.51153 .2657 Mdot
.54967 .7906 Mdot
.79115 .29982 Mdot
.71116 .75472 Mdot
.73192 .67501 Mdot
.82568 .51034 Mdot
.4548 .85912 Mdot
.6503 .20427 Mdot
.39803 .77087 Mdot
.70675 .53225 Mdot
.33733 .85533 Mdot
.56828 .39441 Mdot
.22885 .47599 Mdot
.38868 .73024 Mdot
.55881 .23512 Mdot
.44483 .60804 Mdot
.34211 .41071 Mdot
.58483 .31206 Mdot
.43537 .68957 Mdot
.33793 .43625 Mdot
.85827 .49234 Mdot
.76308 .26338 Mdot
.85832 .47642 Mdot
.66419 .664 Mdot
.83747 .53535 Mdot
.76803 .29929 Mdot
.18746 .49198 Mdot
.7069 .26619 Mdot
.35203 .45794 Mdot
.40213 .33812 Mdot
.39997 .80722 Mdot
.63361 .36215 Mdot
.58092 .66402 Mdot
.51991 .6693 Mdot
.7481 .26055 Mdot
.81384 .65279 Mdot
.309 .65202 Mdot
.28384 .57803 Mdot
.50836 .39515 Mdot
.38428 .3013 Mdot
.41073 .61176 Mdot
.69244 .61683 Mdot
.77506 .6593 Mdot
.7589 .28827 Mdot
.3392 .32729 Mdot
.68524 .35538 Mdot
.73564 .65946 Mdot
.40104 .79458 Mdot
.79721 .50109 Mdot
.67829 .24347 Mdot
.47206 .6002 Mdot
.51738 .73376 Mdot
.47801 .55007 Mdot
.67722 .61597 Mdot
.75359 .41251 Mdot
.3215 .30274 Mdot
.60558 .35443 Mdot
.38337 .33151 Mdot
.53544 .4995 Mdot
.70456 .26181 Mdot
.30911 .30323 Mdot
.37046 .33737 Mdot
.75079 .65703 Mdot
.85209 .50418 Mdot
.6573 .73353 Mdot
.45499 .18897 Mdot
.75876 .54964 Mdot
.41336 .5879 Mdot
.43419 .54133 Mdot
.67393 .76482 Mdot
.85771 .54253 Mdot
.68949 .76225 Mdot
.52739 .77148 Mdot
.63657 .27129 Mdot
.68225 .46461 Mdot
.30057 .30468 Mdot
.65542 .40443 Mdot
.78201 .65497 Mdot
.51353 .53095 Mdot
.6759 .4615 Mdot
.59165 .71634 Mdot
.28241 .55783 Mdot
.24947 .37998 Mdot
.31391 .60491 Mdot
.31683 .5222 Mdot
.25147 .59226 Mdot
.46709 .63444 Mdot
.52429 .76948 Mdot
.37806 .29643 Mdot
.59783 .37432 Mdot
.60784 .20931 Mdot
.42481 .61374 Mdot
.42506 .46963 Mdot
.73981 .37786 Mdot
.43523 .63753 Mdot
.39537 .69557 Mdot
.58634 .42138 Mdot
.75275 .72511 Mdot
.45302 .80291 Mdot
.40648 .62004 Mdot
.35325 .28256 Mdot
.63192 .23493 Mdot
.59539 .59464 Mdot
.69325 .53402 Mdot
.81474 .52818 Mdot
.52936 .41932 Mdot
.36408 .2848 Mdot
.24675 .5853 Mdot
.72984 .31194 Mdot
.32136 .4624 Mdot
.54901 .80583 Mdot
.19718 .46568 Mdot
.59024 .56562 Mdot
.49313 .62836 Mdot
.44476 .69717 Mdot
.22805 .70482 Mdot
.69923 .64275 Mdot
.53321 .6468 Mdot
.80646 .50808 Mdot
.68184 .47243 Mdot
.48325 .71553 Mdot
.37456 .34285 Mdot
.5388 .26053 Mdot
.25253 .54335 Mdot
.7606 .41803 Mdot
.33665 .58609 Mdot
.66897 .44376 Mdot
.82057 .50597 Mdot
.82147 .41584 Mdot
.19793 .32954 Mdot
.4549 .71813 Mdot
.70612 .31266 Mdot
.70206 .3058 Mdot
.51062 .70454 Mdot
.45937 .61687 Mdot
.28474 .44235 Mdot
.83522 .56296 Mdot
.51125 .50721 Mdot
.67994 .60562 Mdot
.56751 .47842 Mdot
.50594 .22714 Mdot
.71231 .29167 Mdot
.29991 .3279 Mdot
.79662 .48578 Mdot
.29225 .59545 Mdot
.53216 .17564 Mdot
.45588 .52181 Mdot
.22427 .48471 Mdot
.30048 .30451 Mdot
.37634 .3833 Mdot
.28724 .7157 Mdot
.78072 .61146 Mdot
.37321 .54579 Mdot
.85869 .45157 Mdot
.73713 .69545 Mdot
.53429 .57611 Mdot
.53077 .32943 Mdot
.35174 .51475 Mdot
.40278 .46406 Mdot
.46262 .76787 Mdot
.59722 .78899 Mdot
.5915 .17282 Mdot
.31231 .36126 Mdot
.40773 .5909 Mdot
.24249 .58585 Mdot
.36353 .79485 Mdot
.75941 .38598 Mdot
.80493 .58248 Mdot
.53208 .5168 Mdot
.40947 .80737 Mdot
.67096 .5797 Mdot
.65927 .60773 Mdot
.76611 .53995 Mdot
.7744 .30761 Mdot
.28219 .49828 Mdot
.60051 .77421 Mdot
.68651 .26102 Mdot
.41224 .52275 Mdot
.57452 .75663 Mdot
.79752 .51748 Mdot
.29158 .25308 Mdot
.55578 .63456 Mdot
.86655 .52193 Mdot
.45557 .53889 Mdot
.61341 .76484 Mdot
.69977 .23263 Mdot
.39428 .16911 Mdot
.67671 .6276 Mdot
.82237 .36405 Mdot
.64334 .5897 Mdot
.80543 .50079 Mdot
.65096 .48025 Mdot
.51886 .46157 Mdot
.41882 .74128 Mdot
.83371 .56881 Mdot
.57084 .28066 Mdot
.78983 .43857 Mdot
.45356 .77155 Mdot
.8449 .54901 Mdot
.46308 .44323 Mdot
.22457 .69507 Mdot
.59948 .32282 Mdot
.42778 .82746 Mdot
.41642 .78088 Mdot
.41331 .59967 Mdot
.36318 .32823 Mdot
.2142 .66669 Mdot
.18803 .53088 Mdot
.40759 .76771 Mdot
.38076 .36016 Mdot
.56091 .79251 Mdot
.34808 .28001 Mdot
.78097 .66149 Mdot
.28377 .75113 Mdot
.71046 .30148 Mdot
.56298 .70779 Mdot
.664 .69982 Mdot
.59543 .79361 Mdot
.75584 .60366 Mdot
.7452 .37397 Mdot
.63321 .62939 Mdot
.32013 .57703 Mdot
.10836 .47878 Mdot
.62247 .5535 Mdot
.27892 .45723 Mdot
.78676 .30081 Mdot
.76993 .6651 Mdot
.5065 .52735 Mdot
.27126 .70245 Mdot
.22561 .40124 Mdot
.4378 .3432 Mdot
.40441 .48808 Mdot
.84526 .54364 Mdot
.44834 .33315 Mdot
.83401 .40787 Mdot
.61972 .81369 Mdot
.26809 .59816 Mdot
.29637 .51609 Mdot
.53983 .36752 Mdot
.29336 .41685 Mdot
.37131 .36623 Mdot
.79188 .31938 Mdot
.22709 .48211 Mdot
.57542 .45664 Mdot
.71694 .45468 Mdot
.76075 .4637 Mdot
.36019 .58415 Mdot
.40499 .81233 Mdot
.58067 .78871 Mdot
.30018 .35218 Mdot
.72562 .66684 Mdot
.37541 .31402 Mdot
.23447 .56311 Mdot
.31177 .29307 Mdot
.51495 .58027 Mdot
.55435 .31184 Mdot
.6211 .35677 Mdot
.78254 .34515 Mdot
.79707 .54727 Mdot
.49267 .81107 Mdot
.46482 .18981 Mdot
.60512 .7552 Mdot
.32567 .37783 Mdot
.76101 .34814 Mdot
.55079 .61287 Mdot
.57057 .29107 Mdot
.24334 .39533 Mdot
.23878 .51276 Mdot
.79228 .59686 Mdot
.37117 .40175 Mdot
.79991 .6583 Mdot
.3178 .30763 Mdot
.74934 .30837 Mdot
.50618 .40071 Mdot
.37274 .70702 Mdot
.27137 .65766 Mdot
.51092 .18974 Mdot
.58848 .55934 Mdot
.73069 .2201 Mdot
.51442 .68945 Mdot
.85026 .43264 Mdot
.68838 .51957 Mdot
.21183 .33257 Mdot
.78666 .62727 Mdot
.54485 .53303 Mdot
.54892 .46931 Mdot
.54938 .80878 Mdot
.64512 .73361 Mdot
.66567 .73409 Mdot
.47514 .56007 Mdot
.55375 .34866 Mdot
.58782 .45229 Mdot
.68698 .60644 Mdot
.79313 .38318 Mdot
.3345 .4712 Mdot
.6289 .41312 Mdot
.35753 .38764 Mdot
.73462 .4882 Mdot
.67646 .75614 Mdot
.7857 .58053 Mdot
.38914 .42158 Mdot
.38567 .2982 Mdot
.7651 .28832 Mdot
.74905 .70185 Mdot
.48443 .53333 Mdot
.42746 .57721 Mdot
.62877 .45666 Mdot
.63606 .21276 Mdot
.81335 .44913 Mdot
.75237 .46759 Mdot
.60202 .61001 Mdot
.33844 .29725 Mdot
.88382 .49721 Mdot
.76026 .26193 Mdot
.49258 .17635 Mdot
.56836 .47487 Mdot
.51188 .72809 Mdot
.20568 .42825 Mdot
.75207 .31264 Mdot
.43944 .8319 Mdot
.73526 .6849 Mdot
.37587 .31962 Mdot
.32631 .22926 Mdot
.20049 .57894 Mdot
.56811 .44206 Mdot
.273 .65942 Mdot
.39809 .71861 Mdot
.69827 .46485 Mdot
.44065 .35054 Mdot
.54321 .43964 Mdot
.63259 .46515 Mdot
.56469 .79213 Mdot
.62976 .73405 Mdot
.74716 .30456 Mdot
.21769 .50451 Mdot
.43034 .57597 Mdot
.79147 .40107 Mdot
.44785 .62731 Mdot
.70048 .29522 Mdot
.64066 .23815 Mdot
.55769 .44489 Mdot
.55958 .38443 Mdot
.34724 .42148 Mdot
.6002 .57658 Mdot
.64613 .58351 Mdot
.38982 .20666 Mdot
.49848 .3172 Mdot
.5131 .71493 Mdot
.20096 .61041 Mdot
.46549 .72382 Mdot
.85943 .57074 Mdot
.69504 .61602 Mdot
.24695 .5955 Mdot
.6719 .5717 Mdot
.69411 .37922 Mdot
.39578 .18932 Mdot
.30505 .57315 Mdot
.44345 .23293 Mdot
.52512 .71024 Mdot
.46723 .6357 Mdot
.70411 .56426 Mdot
.63989 .70296 Mdot
.27261 .57632 Mdot
.33322 .78184 Mdot
.62882 .23172 Mdot
.47871 .72775 Mdot
.59641 .44051 Mdot
.42076 .66818 Mdot
.8014 .66696 Mdot
.55681 .37174 Mdot
.74679 .23903 Mdot
.35515 .57055 Mdot
.62247 .2 Mdot
.67763 .76055 Mdot
.58126 .61166 Mdot
.57151 .47195 Mdot
.66964 .31722 Mdot
.33209 .45226 Mdot
.41431 .59262 Mdot
.45727 .65416 Mdot
.7153 .27515 Mdot
.48151 .30246 Mdot
.39946 .2716 Mdot
.66779 .53463 Mdot
.32147 .75844 Mdot
.4246 .81128 Mdot
.46172 .63468 Mdot
.52456 .38535 Mdot
.69818 .31392 Mdot
.42978 .39302 Mdot
.36464 .38548 Mdot
.78466 .34156 Mdot
.28784 .57306 Mdot
.51293 .6924 Mdot
.49026 .17868 Mdot
.43342 .37007 Mdot
.71927 .75658 Mdot
.4526 .4518 Mdot
.31456 .40503 Mdot
.37659 .3913 Mdot
.54422 .79952 Mdot
.23506 .5565 Mdot
.8006 .60943 Mdot
.37284 .28158 Mdot
.47585 .431 Mdot
.37373 .33745 Mdot
.37862 .41807 Mdot
.74493 .47793 Mdot
.40989 .82246 Mdot
.33501 .2244 Mdot
.30969 .6978 Mdot
.56674 .64757 Mdot
.47556 .61778 Mdot
.37097 .79789 Mdot
.51416 .70544 Mdot
.49307 .2565 Mdot
.34593 .60876 Mdot
.78536 .63014 Mdot
.75846 .7071 Mdot
.7373 .70249 Mdot
.28444 .42234 Mdot
.76005 .4697 Mdot
.23816 .42662 Mdot
.46082 .537 Mdot
.55226 .53015 Mdot
.33568 .44577 Mdot
.3727 .58494 Mdot
.50374 .54793 Mdot
.51315 .80092 Mdot
.30274 .54096 Mdot
.82924 .56793 Mdot
.71808 .75494 Mdot
.84218 .50899 Mdot
.75094 .40801 Mdot
.43752 .67686 Mdot
.7819 .28795 Mdot
.21182 .55046 Mdot
.77211 .6735 Mdot
.41076 .77966 Mdot
.25005 .73175 Mdot
.70845 .2422 Mdot
.7699 .62751 Mdot
.54785 .69344 Mdot
.56199 .82914 Mdot
.67824 .74018 Mdot
.22775 .69831 Mdot
.24795 .49133 Mdot
.67216 .76005 Mdot
.72075 .21335 Mdot
.37416 .76796 Mdot
.6394 .73847 Mdot
.26477 .6547 Mdot
.24744 .5027 Mdot
.29449 .75494 Mdot
.39369 .45506 Mdot
.5692 .40385 Mdot
.52989 .21774 Mdot
.3649 .32191 Mdot
.35091 .41662 Mdot
.27628 .7387 Mdot
.36849 .36867 Mdot
.31583 .37744 Mdot
.65818 .29021 Mdot
.71262 .25007 Mdot
.24374 .55816 Mdot
.41798 .44628 Mdot
.51562 .65663 Mdot
.44173 .29309 Mdot
.26916 .38227 Mdot
.34865 .50146 Mdot
.57637 .53529 Mdot
.27657 .48635 Mdot
.86125 .50012 Mdot
.52767 .24113 Mdot
.62826 .5171 Mdot
.44355 .70136 Mdot
.58267 .79518 Mdot
.77723 .39981 Mdot
.58278 .73465 Mdot
.25496 .71436 Mdot
.26747 .55175 Mdot
.82036 .496 Mdot
.61354 .74338 Mdot
.3251 .32204 Mdot
.34592 .24271 Mdot
.64516 .51033 Mdot
.41014 .74181 Mdot
.78935 .32071 Mdot
.58549 .75965 Mdot
.45673 .62386 Mdot
.74179 .64051 Mdot
.73981 .46984 Mdot
.57757 .77244 Mdot
.66948 .72999 Mdot
.72726 .32233 Mdot
.27287 .62375 Mdot
.81868 .41926 Mdot
.5446 .37874 Mdot
.3432 .33083 Mdot
.71635 .64234 Mdot
.29534 .7577 Mdot
.42925 .39389 Mdot
.81205 .62652 Mdot
.54853 .52199 Mdot
.42142 .25512 Mdot
.33205 .51015 Mdot
.2212 .52193 Mdot
.52595 .79603 Mdot
.72622 .65834 Mdot
.49957 .61188 Mdot
.44403 .64126 Mdot
.46802 .81029 Mdot
.52868 .32851 Mdot
.44932 .3395 Mdot
.24331 .4505 Mdot
.49949 .76732 Mdot
.47 .25229 Mdot
.60399 .71092 Mdot
.37465 .57476 Mdot
.43407 .22504 Mdot
.76087 .44278 Mdot
.41864 .753 Mdot
.39326 .77036 Mdot
.78585 .34962 Mdot
.75972 .40721 Mdot
.48204 .81795 Mdot
.42944 .77441 Mdot
.62714 .78114 Mdot
.20388 .56631 Mdot
.55991 .68086 Mdot
.42863 .52649 Mdot
.49306 .2566 Mdot
.50683 .70544 Mdot
.79725 .38623 Mdot
.44752 .58097 Mdot
.42628 .24636 Mdot
.53622 .55217 Mdot
.74657 .36478 Mdot
.49286 .39633 Mdot
.67898 .75345 Mdot
.56189 .82935 Mdot
.37776 .295 Mdot
.64465 .51974 Mdot
.65226 .59146 Mdot
.55046 .62862 Mdot
.81814 .59456 Mdot
.49388 .5563 Mdot
.41064 .65333 Mdot
.57597 .68814 Mdot
.38338 .6675 Mdot
.64472 .79316 Mdot
.39783 .30063 Mdot
.55635 .53622 Mdot
.41177 .62028 Mdot
.58675 .66225 Mdot
.6219 .70978 Mdot
.55362 .23976 Mdot
.2134 .53599 Mdot
.67641 .55801 Mdot
.59236 .46646 Mdot
.40125 .57326 Mdot
.2042 .43254 Mdot
.81251 .41972 Mdot
.50064 .52227 Mdot
.54325 .52098 Mdot
.68422 .26255 Mdot
.43171 .32376 Mdot
.15564 .37807 Mdot
.86422 .46825 Mdot
.33255 .50943 Mdot
.53873 .4579 Mdot
.39917 .28201 Mdot
.59806 .34219 Mdot
.31101 .60007 Mdot
.79192 .36074 Mdot
.69283 .48368 Mdot
.64649 .2746 Mdot
.63092 .72101 Mdot
.53945 .80798 Mdot
.53836 .18607 Mdot
.68616 .46371 Mdot
.8632 .56352 Mdot
.73011 .68785 Mdot
.52872 .78703 Mdot
.12819 .41952 Mdot
.50579 .79493 Mdot
.4699 .45949 Mdot
.65029 .29364 Mdot
.8547 .51147 Mdot
.57193 .48025 Mdot
.63984 .28007 Mdot
.38175 .76519 Mdot
.37551 .29005 Mdot
.32714 .35285 Mdot
.56345 .71162 Mdot
.4868 .79835 Mdot
.20898 .67843 Mdot
.69457 .37694 Mdot
.42027 .18328 Mdot
.27037 .58474 Mdot
.82911 .42787 Mdot
.67691 .6261 Mdot
.31588 .23808 Mdot
.75081 .71406 Mdot
.3974 .34515 Mdot
.28634 .74187 Mdot
.54032 .27613 Mdot
.40318 .2386 Mdot
.19773 .43547 Mdot
.65024 .64335 Mdot
.29523 .57561 Mdot
.68012 .37745 Mdot
.51788 .62157 Mdot
.3788 .33405 Mdot
.3878 .69288 Mdot
.55636 .53317 Mdot
.8087 .35811 Mdot
.22632 .6725 Mdot
.35232 .28915 Mdot
.67286 .27349 Mdot
.41033 .23929 Mdot
.80139 .41988 Mdot
.77848 .45968 Mdot
.43359 .38865 Mdot
.64959 .18412 Mdot
.81702 .35049 Mdot
.56237 .67963 Mdot
.39877 .46198 Mdot
.72578 .75488 Mdot
.46524 .39387 Mdot
.39706 .7679 Mdot
.68454 .71051 Mdot
.30708 .36553 Mdot
.28061 .50963 Mdot
.42966 .49033 Mdot
.23179 .44571 Mdot
.54488 .68654 Mdot
.39091 .69865 Mdot
.57833 .19957 Mdot
.35611 .28482 Mdot
.23258 .67737 Mdot
.54241 .17955 Mdot
.44962 .44554 Mdot
.50282 .66755 Mdot
.85743 .50654 Mdot
.38136 .60766 Mdot
.44044 .5755 Mdot
.25387 .62421 Mdot
.48697 .55086 Mdot
.61126 .30227 Mdot
.42699 .57642 Mdot
.59486 .5921 Mdot
.36078 .32805 Mdot
.76007 .32708 Mdot
.42362 .74395 Mdot
.71687 .19974 Mdot
.67805 .76607 Mdot
.48028 .72956 Mdot
.38237 .75429 Mdot
.55193 .43857 Mdot
.84078 .49938 Mdot
.68013 .35539 Mdot
.63476 .23598 Mdot
.19083 .6072 Mdot
.38162 .25205 Mdot
.38382 .55676 Mdot
.66538 .66685 Mdot
.77602 .68615 Mdot
.19451 .6301 Mdot
.8002 .65694 Mdot
.2963 .52208 Mdot
.43927 .52964 Mdot
.33876 .18496 Mdot
.81165 .50275 Mdot
.30044 .49113 Mdot
.53387 .65453 Mdot
.50664 .6262 Mdot
.32643 .48996 Mdot
.64461 .70259 Mdot
.27491 .36056 Mdot
.32738 .35843 Mdot
.83383 .56249 Mdot
.4559 .71138 Mdot
.57512 .4972 Mdot
.72452 .50804 Mdot
.56398 .49258 Mdot
.41797 .43813 Mdot
.68972 .47622 Mdot
.3298 .36371 Mdot
.48474 .41194 Mdot
.64582 .36603 Mdot
.28418 .55114 Mdot
.61085 .62529 Mdot
.30876 .56727 Mdot
.31118 .39791 Mdot
.50081 .75475 Mdot
.18725 .52946 Mdot
.36749 .36805 Mdot
.41215 .36759 Mdot
.67195 .75211 Mdot
.42422 .84737 Mdot
.58348 .52705 Mdot
.46987 .74953 Mdot
.46239 .45601 Mdot
.21997 .54911 Mdot
.26259 .6228 Mdot
.63626 .35009 Mdot
.62749 .70298 Mdot
.30792 .54484 Mdot
.40752 .62072 Mdot
.6899 .47071 Mdot
.87715 .50752 Mdot
.42904 .48136 Mdot
.30179 .61418 Mdot
.80718 .614 Mdot
.70405 .29338 Mdot
.2566 .47727 Mdot
.33895 .44353 Mdot
.4836 .45834 Mdot
.48044 .40636 Mdot
.41662 .68107 Mdot
.71227 .28634 Mdot
.82374 .46234 Mdot
.25976 .43642 Mdot
.28606 .60793 Mdot
.39425 .52073 Mdot
.50658 .29204 Mdot
.58557 .57798 Mdot
.38733 .21644 Mdot
.42405 .27783 Mdot
.74883 .69754 Mdot
.32656 .38637 Mdot
.31161 .36131 Mdot
.246 .64085 Mdot
.8415 .42251 Mdot
.55706 .64487 Mdot
.26413 .59911 Mdot
.51867 .56734 Mdot
.75774 .60849 Mdot
.37789 .36006 Mdot
.72457 .54503 Mdot
.33252 .56902 Mdot
.53963 .67299 Mdot
.83786 .6005 Mdot
.31396 .57849 Mdot
.67421 .54177 Mdot
.79379 .59641 Mdot
.20756 .56986 Mdot
.54797 .46953 Mdot
.1127 .45096 Mdot
.67767 .33972 Mdot
.86325 .55516 Mdot
.74412 .32159 Mdot
.40509 .3944 Mdot
.55918 .79036 Mdot
.31758 .44568 Mdot
.57124 .36639 Mdot
.83436 .48576 Mdot
.43257 .60953 Mdot
.56098 .68794 Mdot
.36122 .45439 Mdot
.49855 .48065 Mdot
.41673 .64712 Mdot
.77363 .49862 Mdot
.55681 .39398 Mdot
.48419 .53914 Mdot
.78437 .47068 Mdot
.47908 .40433 Mdot
.28103 .76315 Mdot
.7933 .32053 Mdot
.81509 .53174 Mdot
.75847 .45375 Mdot
.21649 .31781 Mdot
.5274 .69281 Mdot
.43083 .61705 Mdot
.6349 .50324 Mdot
.23515 .4339 Mdot
.57981 .76702 Mdot
.75069 .31584 Mdot
.60834 .79743 Mdot
.42724 .3914 Mdot
.10124 .51314 Mdot
.3866 .34424 Mdot
.49538 .50593 Mdot
.56211 .7663 Mdot
.82717 .57809 Mdot
.62602 .24893 Mdot
.60399 .81402 Mdot
.68995 .62992 Mdot
.37888 .41951 Mdot
.20084 .47156 Mdot
.49895 .18144 Mdot
.73693 .45925 Mdot
.41276 .1834 Mdot
.78654 .51676 Mdot
.28756 .35232 Mdot
.72211 .65747 Mdot
.45845 .72133 Mdot
.44526 .59845 Mdot
.69797 .61057 Mdot
.57927 .66421 Mdot
.46027 .76159 Mdot
.81851 .4697 Mdot
.28523 .30235 Mdot
.6638 .24712 Mdot
.82992 .51385 Mdot
.72867 .47489 Mdot
.48265 .61777 Mdot
.35902 .37196 Mdot
.43005 .28163 Mdot
.61216 .35588 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0;gooooo0_l0002:ooooo`007?ooool00ol0003oooooooooo`2mooooo`;o0000
R_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo09Cooooo0_l0002cooooo`007?ooool00ol0003ooooooooo
o`1looooo`;o00000oooool2o`00017ooooo0_l0002cooooo`007?ooool00ol0003oooooooooo`1l
ooooo`;o00000oooool2o`000<Kooooo000Looooo`03o`000?oooooooooo0;cooooo0_l0002;oooo
o`007?ooool00ol0003oooooooooo`2Looooo`;o00002oooool2o`00017ooooo0_l00003ooooo`;o
0000Q_ooool001cooooo00?o0000ooooooooool0Voooool5o`0000Wooooo0_l000000ooooooo0000
o`00000Cooooo`;o0000Q_ooool001cooooo00?o0000ooooooooool0P_ooool2o`000003ooooool0
003o000001Cooooo0_l000000ooooooo0000o`00000<ooooo`;o00008Oooool2o`0007Sooooo000L
ooooo`03o`000?oooooooooo06[ooooo0_l0000Fooooo`;o000000?oooooo`000?l000003oooool2
o`0001?ooooo0_l0000Rooooo`;o0000N?ooool001cooooo00?o0000ooooooooool0J_ooool2o`00
017ooooo0_l00009ooooo`;o00001_ooool2o`000004ooooool0003o0000ooooo`;o00001?ooool2
o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`Go00000oooool2o`0000kooooo0_l00026
ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o
0000ooooooooool0OOooool2o`0000Wooooo0_l00006ooooo`;o000000?oooooo`000?l000001ooo
ool2o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o000000Coooooo`000?l0003ooooo
1?l0000>ooooo`;o0000Q_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo07Wooooo0_l0000doooo
o`;o00009Oooool2o`00077ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[o
oooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`1iooooo`;o00001Oooool2o`0000Co
oooo0_l0000`ooooo`;o00003?ooool2o`0000Sooooo0_l00004ooooo`;o00003Oooool2o`0006;o
oooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h0
1_ooool3o`0006_ooooo0_l0000Cooooo`;o00001?ooool2o`0001Cooooo0_l0000Hooooo`Co0000
3?ooool2o`0000;ooooo0_l00004ooooo`;o00004_ooool3o`0006;ooooo00000ooooooo0000oooo
o`02ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`1[ooooo`;o00005Oooool2o`0001Sooooo0_l0000Hooooo`;o00004_ooool2o`0000;ooooo0ol0
0006ooooo`;o00002_ooool3o`0006?ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooo
oooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1kooooo`;o00001Oooool2
o`0004[ooooo0ol00006ooooo`;o00002_ooool2o`0006Cooooo00001_ooooooMgMgoiRHV?oooooo
V9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo07_ooooo
0_l0000cooooo`;o00004?ooool2o`0000[ooooo0_l0000<ooooo`;o0000Joooool00006ooooooo^
k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000oooo
ooooool0L_ooool2o`0000;ooooo0ol0000aooooo`Co00000_ooool2o`00013ooooo0_l00007oooo
o`;o000000?oooooo`000?l000003?ooool2o`0000Sooooo0_l0001Qooooo`007?ooool00ol0003o
ooooooooo`1_ooooo`Go00000_ooool3o`000003ooooool0003o000001_ooooo0_l0000?ooooo`Oo
00005oooool2o`0000?ooooo0_l00002ooooo`;o00005Oooool2o`000003ooooool0003o000005ko
oooo000Looooo`03o`000?oooooooooo06oooooo0ol00008ooooo`;o00006oooool2o`0000Oooooo
0_l00006ooooo`;o00000oooool2o`0000?ooooo0_l0000Booooo`;o00001oooool2o`0001Sooooo
0ol0001Mooooo`007?ooool00ol0003oooooooooo`1Yooooo`;o0000=Oooool2o`00013ooooo0_l0
000Dooooo`;o00004_ooool2o`0000cooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1Y
ooooo`;o00007_ooool2o`0001Kooooo0_l0000Uooooo`;o00004Oooool3o`0006_ooooo000Loooo
o`03o`000?oooooooooo067ooooo0_l00003ooooo`?o00006oooool2o`0000?ooooo0_l0000Foooo
o`;o00001_ooool2o`0000Kooooo0_l0000Eooooo`?o00001?ooool2o`0000[ooooo0_l00004oooo
o`;o00002Oooool2o`0005_ooooo000Looooo`03o`000?oooooooooo067ooooo0_l00003ooooo`?o
00002oooool2o`0000Oooooo1?l00003ooooo`;o000000?oooooo`000?l000000oooool4o`0001Wo
oooo0_l00006ooooo`;o00005Oooool3o`0000Cooooo0_l0000?ooooo`?o00002Oooool2o`0005_o
oooo000Looooo`03o`000?oooooooooo067ooooo0_l0000Aooooo`;o00001oooool4o`0000?ooooo
0_l000001?oooooo0000o`000?l00002ooooo`Co000000?oooooo`000?l000007oooool2o`000003
ooooool0003o0000017ooooo1?l0000Aooooo`;o000000?oooooo`000?l00000Ioooool001cooooo
00?o0000ooooooooool0Hoooool2o`0001?ooooo1Ol00002ooooo`;o000000?oooooo`000?l00000
0_l000001?oooooo0000o`000?l00002ooooo`Co000000?oooooo`000?l000003Oooool2o`0000ko
oooo1?l000000ooooooo0000o`000004ooooo`;o00003?ooool5o`000003ooooool0003o000000co
oooo0_l0000@ooooo`;o0000F?ooool001cooooo00?o0000ooooooooool0Hoooool2o`0000Sooooo
0_l00004ooooo`;o00000oooool5o`0000;ooooo0_l000000ooooooo0000o`000002o`0000Oooooo
0_l0000Aooooo`;o00001_ooool2o`0000Kooooo0_l00009ooooo`;o00003oooool2o`000004oooo
ool0003o0000o`00013ooooo0_l0000;ooooo`;o0000F?ooool001cooooo00?o0000ooooooooool0
K?ooool3o`0000Cooooo0_l000000ooooooo0000o`000004o`0002cooooo0_l0000Fooooo`;o0000
1Oooool2o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`;o00000_ooool2o`0000;ooooo
1?l000000ooooooo0000o`00001Uooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00001?oo
ool2o`0001Cooooo0_l00008ooooo`Ko00002oooool2o`0003;ooooo0_l00003ooooo`;o00001Ooo
ool3o`0000?ooooo0_l00005ooooo`?o00000_ooool2o`0000;ooooo1_l0001Vooooo`007?ooool2
o`00057ooooo0_l00004ooooo`;o00006Oooool2o`0000?ooooo1?l0000=ooooo`?o00002oooool2
o`0000Cooooo0_l0000Nooooo`;o000000?oooooo`000?l000002?ooool2o`0000?ooooo0ol00004
ooooo`;o00001?ooool2o`0000Gooooo0_l000000ooooooo0000o`00001Sooooo`007?ooool00ol0
003oooooooooo`1Kooooo`;o00004oooool3o`0000Gooooo0_l0000;ooooo`;o000000?oooooo`00
0?l000000_ooool2o`000003ooooool0003o000000;o00000_ooool2o`0000Cooooo0_l000000ooo
oooo0000o`00000Nooooo`?o00001?ooool2o`0000Kooooo0ol0000:ooooo`?o00001oooool2o`00
06?ooooo000Looooo`03o`000?oooooooooo05_ooooo0_l0000Cooooo`;o000000?oooooo`000?l0
00000oooool2o`0000_ooooo0_l00005ooooo`;o000000?oooooo`000?l000000_l000000ooooooo
0000o`000005ooooo`Go00002Oooool2o`0001Cooooo0_l00004ooooo`;o00005?ooool2o`0006co
oooo000Looooo`03o`000?oooooooooo073ooooo0_l000000ooooooo0000o`000002o`000003oooo
ool0003o000000Oooooo0_l000000ooooooo0000o`000004ooooo`;o00002?ooool2o`0000Kooooo
1_l00007ooooo`Co00008Oooool3o`0000[ooooo1?l00003ooooo`;o00002oooool2o`000003oooo
ool0003o000005Gooooo000Looooo`03o`000?oooooooooo073ooooo0_l00003ooooo`;o000000?o
ooooo`000?l000001_ooool6o`0000Cooooo0_l00003ooooo`;o00000_ooool5o`0000Kooooo1?l0
00000ooooooo0000o`000006ooooo`;o00008Oooool4o`0000Sooooo1Ol00002ooooo`?o00002ooo
ool2o`000003ooooool0003o000000;o0000Doooool001cooooo00?o0000ooooooooool0JOooool5
o`0000?ooooo0_l00002ooooo`;o00002Oooool5o`0000Kooooo0_l00002ooooo`co00000_ooool2
o`0000?ooooo0ol0000Zooooo`Go00001_ooool2o`0000Gooooo0ol0000?ooooo`?o0000Doooool0
01cooooo00?o0000ooooooooool0H_ooool2o`0000Gooooo1Ol00003ooooo`;o00006?ooool2o`00
0004ooooool0003o0000ooooo`[o00000_ooool2o`000003ooooool0003o000000?o0000:_ooool6
o`0000gooooo1?l0001Sooooo`007?ooool00ol0003oooooooooo`1Rooooo`Co00000oooool4o`00
017ooooo0_l000000ooooooo0000o`000009oooooa3o00001?ooool5o`0000Sooooo0_l0000Loooo
o`;o00000_ooool3o`000003ooooool0003o000000;ooooo0_l0000;ooooo`Co00003oooool2o`00
053ooooo000Looooo`03o`000?oooooooooo04[ooooo0_l0000Hooooo`;o00000oooool2o`00017o
oooo1?l000000ooooooo0000o`000008oooooa?o00000oooool2o`000003ooooool0003o000000Ko
oooo0ol0000Looooo`;o000000?oooooo`000?l000001oooool2o`0000_ooooo1?l0000?ooooo`;o
0000D?ooool001cooooo00?o0000ooooooooool0AOooool2o`0000?ooooo0_l0000Fooooo`;o0000
2Oooool2o`0000Gooooo0_l00006ooooo`;o00002?ooool2o`0000?ooooo5?l00005ooooo`;o0000
0oooool2o`000004ooooool0003o0000o`0001gooooo1?l0000Dooooo`?o00000oooool2o`0005go
oooo000Looooo`03o`000?oooooooooo04Gooooo0_l0000Kooooo`;o000000Coooooo`000?l0003o
00001Oooool4o`0000?ooooo0ol00007ooooo`;o00001_ooool4o`000003ooooool0003o000001;o
00001?ooool2o`0000Cooooo0_l00002ooooo`;o00001oooool2o`0001Cooooo0_l0000Aooooo`?o
00000oooool2o`0000?ooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1Uooooo`?o0000
1oooool3o`000003ooooool0003o000000;o00000oooool2o`0000;ooooo0_l00008ooooo`;o0000
00?oooooo`000?l000004ol000000ooooooo0000o`000002o`00017ooooo0_l0000Jooooo`;o0000
2oooool3o`0006Oooooo000Looooo`03o`000?oooooooooo04kooooo0_l0000Oooooo`?o000000?o
ooooo`000?l000000_ooool2o`000004ooooool0003o0000ooooo`;o00002ooooolFo`000004oooo
ool0003o0000o`0000Sooooo0_l0000Tooooo`;o00004?ooool2o`0000Gooooo0_l00006ooooo`Co
00000oooool2o`0004gooooo000Looooo`03o`000?oooooooooo04Wooooo0_l00003ooooo`;o0000
3?ooool2o`00017ooooo0_l00004ooooo`Co00001?ooool2o`0000Cooooo0_l000000ooooooo0000
o`000004o`000003ooooool0003o000001Go00002?ooool2o`0000Sooooo0_l0000Jooooo`Co0000
3_ooool2o`0000Gooooo0_l00006ooooo`Co00000oooool2o`0004gooooo000Looooo`03o`000?oo
oooooooo04Wooooo0_l0000@ooooo`?o00001?ooool3o`0000Gooooo0_l00009ooooo`Co00000_oo
ool4o`0000Cooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000001So00004Ooo
ool2o`0001Oooooo0_l000000ooooooo0000o`000002o`0000[ooooo0ol000000ooooooo0000o`00
001Sooooo`007?ooool00ol0003oooooooooo`1Kooooo`;o00001Oooool4o`0000Cooooo0_l00009
ooooo`Co000000?oooooo`000?l000001?l00008oooooaWo00000_ooool3o`0000Gooooo0_l0000R
ooooo`;o00001_ooool2o`0000Oooooo0ol00002ooooo`;o00001_ooool2o`0005[ooooo000Loooo
o`;o0000IOooool2o`0000Cooooo0_l00009ooooo`_o00002?oooolNo`0000Gooooo0_l0000=oooo
o`;o00006oooool2o`0000Oooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00002oooo
o`;o00001oooool2o`0000Cooooo0ol0001:ooooo`007?ooool00ol0003oooooooooo`1Iooooo`?o
00000_ooool5o`0000;ooooo0_l0000>ooooo`?o000000Coooooo`000?l0003ooooo0ol0000:oooo
oa_o00004_ooool2o`0000;ooooo0_l00007ooooo`;o00002_ooool2o`00013ooooo1Ol00003oooo
o`;o00000_ooool4o`0000Gooooo0_l00004ooooo`Co0000BOooool001cooooo00?o0000oooooooo
ool0FOooool3o`0000;ooooo1Ol000001?oooooo0000o`000?l0000Booooo`;o00000_ooool2o`00
00Cooooo0ol00006oooooaSo00001oooool2o`0000Wooooo0_l0000;ooooo`;o00002_ooool2o`00
00oooooo0ol000000ooooooo0000o`000007ooooo`Co00001oooool2o`0000Cooooo0_l00019oooo
o`007?ooool00ol0003oooooooooo`1Mooooo`;o00001Oooool2o`0000kooooo0ol00006ooooo`;o
00001?ooool3o`0000Kooooo6?l00003ooooo`;o00000_ooool2o`0002Oooooo0_l0000:ooooo`;o
00003_ooool2o`0000Kooooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o0000
00?oooooo`000?l000000_l0000@ooooo`Co00002oooool2o`0000Kooooo0_l000000ooooooo0000
o`00000Ao`000003ooooool0003o000000?ooooo0_l00007ooooo`;o00000_ooool2o`0000Cooooo
0_l00009ooooo`;o00003Oooool2o`0000Wooooo0_l000000ooooooo0000o`000005ooooo`;o0000
1Oooool2o`0005Oooooo000Looooo`03o`000?oooooooooo05gooooo0_l000000ooooooo0000o`00
0002o`0000Wooooo0_l00007ooooo`;o00002oooool2o`000003ooooool0003o000000;o000000Co
ooooo`000?l0003ooooo5?l0000>ooooo`;o00000_ooool2o`0000Cooooo0_l00009ooooo`;o0000
6?ooool7o`0000?ooooo0_l00005ooooo`;o0000Eoooool001cooooo00?o0000ooooooooool0?_oo
ool4o`000003ooooool0003o000001Sooooo0_l00005ooooo`;o00001oooool2o`0000Oooooo0_l0
000;ooooo`;o000000?oooooo`000?l000000_l000001?oooooo0000o`000?l00003oooooa;o0000
7Oooool2o`0001Cooooo0_l00009ooooo`;o000000Coooooo`000?l0003o00002Oooool2o`0000_o
oooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`0nooooo`Co000000?oooooo`000?l00000
6?ooool2o`0000Gooooo1?l00008ooooo`;o000000?oooooo`000?l000001Ol00007ooooo`;o0000
1Oooool2o`000005ooooool0003o0000o`000?ooool00_l000000ooooooo0000o`00000?o`0000[o
oooo0_l00007ooooo`;o00001oooool3o`0001Cooooo1?l0000;ooooo`;o000000?oooooo`000?l0
00001?ooool2o`0000gooooo0ol00019ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o0000
1Oooool2o`0000?ooooo0_l0000Gooooo`;o00001oooool2o`0000Sooooo0_l000000ooooooo0000
o`000002o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o00000_ooool5o`0000Gooooo
2ol000000ooooooo0000o`000004o`0000cooooo0_l00004ooooo`Go00000_ooool2o`0000?ooooo
0_l0000Fooooo`?o00003_ooool2o`0000Cooooo0_l0000=ooooo`?o0000BOooool001cooooo00?o
0000ooooooooool0>?ooool2o`0000[ooooo0_l0000Eooooo`Go00002_ooool2o`0000Gooooo0ol0
00000ooooooo0000o`000006ooooo`;o00000_ooool2o`000003ooooool0003o000000Go00001Ooo
ool2o`0000?ooooo0_l0000Aooooo`;o00002Oooool4o`000003ooooool0003o000000;o00001_oo
ool3o`0001?ooooo0_l0000Fooooo`;o000000?oooooo`000?l00000E?ooool001cooooo00?o0000
ooooooooool0?Oooool2o`0001cooooo0_l000000ooooooo0000o`000002ooooo`;o00001_ooool4
o`0000?ooooo0ol00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00000
0ooooooo0000o`000003ooooo`;o00001Oooool2o`0000oooooo0_l00005ooooo`?o00000oooool3
o`0000Kooooo2?l00003ooooo`?o00004oooool2o`0000Gooooo0_l0000?ooooo`;o000000?ooooo
o`000?l000003_ooool2o`0004Cooooo000Looooo`03o`000?oooooooooo03gooooo0_l00002oooo
o`;o00004Oooool2o`0000Oooooo0_l00003ooooo`;o00002?ooool2o`0000Gooooo0_l000000ooo
oooo0000o`000003o`0000;ooooo0_l0000>ooooo`?o00003?ooool3o`0000;ooooo0_l00006oooo
o`;o00000_ooool6o`000003ooooool0003o000000Wo000000?oooooo`000?l000000_ooool3o`00
00Gooooo0_l0000:ooooo`;o00001Oooool2o`0000Kooooo0_l00004ooooo`;o00005?ooool2o`00
04Cooooo000Looooo`03o`000?oooooooooo047ooooo0_l0000Aooooo`;o000000?oooooo`000?l0
00001?ooool2o`0001Cooooo1_l00006ooooo`;o00001Oooool2o`0000Gooooo0ol00007ooooo`;o
00000oooool3o`0000kooooo4_l000000ooooooo0000o`000005o`0000?ooooo1?l0000:ooooo`;o
00001Oooool2o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`;o0000F_ooool001cooooo
00?o0000ooooooooool0Eoooool2o`0000Cooooo0_l0000Fooooo`?o00001oooool3o`0000Cooooo
0_l000000ooooooo0000o`000003ooooo`;o00001oooool2o`0001Kooooo0_l000000ooooooo0000
o`00000<o`000003ooooool0003o000000;o00001Oooool2o`0000Oooooo0_l00003ooooo`Co0000
2?ooool2o`0000Oooooo0_l0000<ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0EOoo
ool2o`0000Kooooo0_l0000Gooooo`;o00000_ooool2o`0000Cooooo0_l00007ooooo`?o00000_oo
ool2o`0000Oooooo0_l0000IoooooaSo000000?oooooo`000?l000001_ooool2o`0000?ooooo1?l0
000Aooooo`;o000000?oooooo`000?l000002Oooool2o`0004cooooo000Looooo`03o`000?oooooo
oooo03Oooooo0_l0000Looooo`Co00001?ooool2o`0000Oooooo0_l0000<ooooo`Co00000_ooool2
o`000003ooooool0003o000000_ooooo0_l0000;ooooo`;o00006?oooolIo`000003ooooool0003o
000001_ooooo0_l00006ooooo`;o00002?ooool4o`0004_ooooo000Looooo`;o0000>?ooool4o`00
01[ooooo1?l00004ooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`;o00002Oooool4
o`0000Gooooo0_l0000<ooooo`;o00007?ooool>o`000003ooooool0003o000000So000000?ooooo
o`000?l000001?l00002ooooo`;o00006oooool2o`0000Wooooo0_l00005ooooo`Co00002?ooool2
o`00047ooooo000Looooo`03o`000?oooooooooo03Sooooo0ol0000Jooooo`?o000000Coooooo`00
0?l0003o00000_ooool2o`0000?ooooo0_l00002ooooo`Co00002oooool2o`0001?ooooo0_l0000L
oooooaWo00000_ooool5o`0000;ooooo0_l0000Vooooo`;o00001_ooool2o`0000Wooooo0_l00011
ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00009?ooool4o`000003ooooool0003o0000
00?ooooo0_l00002ooooo`?o0000@OoooolMo`000003ooooool0003o000000kooooo1?l0000Ooooo
o`;o0000Boooool001cooooo00?o0000ooooooooool0<oooool2o`0001cooooo0_l00006ooooo`Co
00001_ooool2o`0000;ooooo0_l0000>ooooo`?o00003_ooool2o`00027ooooo1?l000000ooooooo
0000o`00000Io`0000?ooooo0_l00009ooooo`Co00003?ooool2o`00017ooooo0_l00005ooooo`;o
0000A?ooool001cooooo00?o0000ooooooooool0DOooool2o`0000?ooooo0_l000000ooooooo0000
o`000006ooooo`?o00000oooool2o`0000kooooo0ol00009ooooo`;o00000_ooool5o`0002;ooooo
5?l000000ooooooo0000o`000004o`000003ooooool0003o000000Co00002Oooool2o`0000kooooo
0_l0000<ooooo`;o00001?ooool2o`0000Cooooo0_l00014ooooo`007?ooool00ol0003ooooooooo
o`1Eooooo`?o00001?ooool3o`000003ooooool0003o000000;o00000oooool2o`0000_ooooo1?l0
000;ooooo`;o00000_ooool2o`000004ooooool0003o0000o`0001oooooo7Ol000000ooooooo0000
o`000004o`0001oooooo1?l00004ooooo`;o00001?ooool2o`0000Sooooo0_l00010ooooo`007?oo
ool00ol0003oooooooooo`1?ooooo`;o00000oooool3o`0000Gooooo0ol000000ooooooo0000o`00
0005ooooo`;o00002oooool4o`0000Oooooo0_l000001?oooooo0000o`000?l00006ooooo`;o0000
7ooooolMo`0000?ooooo1?l00002ooooo`;o00006?ooool2o`000003ooooool0003o000000;o0000
1oooool2o`0000_ooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0booooo`;o00006ooo
ool2o`0000;ooooo0ol000000ooooooo0000o`00000Hooooo`;o000000?oooooo`000?l000002Ooo
ool2o`000003ooooool0003o000000;o00000oooool4o`0001oooooo7_l00008ooooo`;o00006?oo
ool2o`0000?ooooo0_l00007ooooo`;o00000_ooool2o`0004Wooooo000Looooo`03o`000?oooooo
oooo03;ooooo0_l0000Looooo`;o000000?oooooo`000?l000000_ooool2o`0000_ooooo0_l0000;
ooooo`;o00004Oooool2o`0000?ooooo0_l00003ooooo`;o00007OoooolCo`0000;ooooo2Ol0000S
ooooo`;o00003_ooool2o`0004Wooooo000Looooo`03o`000?oooooooooo02oooooo0_l0000Loooo
o`Go00001oooool2o`0000Sooooo1Ol0000Aooooo`;o00002Oooool4o`0000Kooooo1?l0000Ioooo
o`Co000000?oooooo`000?l000006Ol0000>ooooo`;o00000oooool2o`0000gooooo0ol00003oooo
o`?o0000Doooool001cooooo00?o0000ooooooooool0;oooool2o`0000?ooooo0_l0000Gooooo`?o
00002Oooool2o`0000Sooooo0_l000000ooooooo0000o`00000Aooooo`;o00002oooool2o`0000Ko
oooo1?l0000Iooooo`Co000000?oooooo`000?l000006Ol00002ooooo`;o00002_ooool2o`0000?o
oooo0_l0000=ooooo`;o00001?ooool3o`0005?ooooo000Looooo`03o`000?oooooooooo033ooooo
0_l00002ooooo`;o00005Oooool5o`0000;ooooo1?l0000Qooooo`Co00004oooool2o`0001Gooooo
0_l00006ooooo`;o000000?oooooo`000?l000005_l00005ooooo`;o00003oooool4o`0000_ooooo
0_l0000?ooooo`;o00001Oooool2o`0004;ooooo000Looooo`03o`000?oooooooooo033ooooo0_l0
000Hooooo`Go00000oooool4o`00013ooooo0_l00008ooooo`;o000000?oooooo`000?l000000_oo
ool3o`0000gooooo0_l0000Kooooo`Go00001_oooolIo`000003ooooool0003o000001Gooooo0_l0
000Aooooo`;o00001_ooool2o`000004ooooool0003o0000o`0000Cooooo0_l00012ooooo`007?oo
ool00ol0003oooooooooo`1:ooooo`Co00006?ooool2o`0000Sooooo0_l000000ooooooo0000o`00
0003ooooo`;o00003Oooool4o`0000Oooooo0_l00002ooooo`;o00003?ooool5o`0000Kooooo2ol0
00000ooooooo0000o`00000>o`0002Sooooo0_l00006ooooo`;o00000_ooool2o`0004Sooooo0000
1_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0
1?ooool00ol0003oooooooooo`18ooooo`Co00000_ooool2o`00023ooooo0_l00005ooooo`;o0000
3_ooool4o`0000Oooooo0ol000000ooooooo0000o`00000Hooooo`?o00000_ooool3o`000003oooo
ool0003o000000oo00002oooool2o`0001Oooooo0_l00002ooooo`;o0000EOooool00006oooooomg
MgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0aooooo`;o00005?ooool6o`000003ooooool0003o000001gooooo0_l00004ooooo`;o
00000_ooool2o`0000Oooooo0_l00005ooooo`Go00001oooool2o`0000Oooooo0_l00003ooooo`;o
00003Oooool7o`000003ooooool0003o000000ko000000?oooooo`000?l000000_l00008ooooo`;o
00005oooool2o`0000;ooooo0_l0001Eooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooo
ooooo`09ooooo`Go00001_ooool00ol0003oooooooooo`0aooooo`;o00004Oooool2o`000003oooo
ool0003o000000;ooooo0_l0000Aooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo
3?l00009ooooo`;o00001?ooool2o`0000;ooooo0_l0000@ooooo`;o00000oooool2o`0000;ooooo
0ol00008oooooaOo00000_ooool4o`0002cooooo0_l0000Aooooo`;o0000>oooool00003ooooool0
003ooooo00;ooooo00?o0000ooooooooool02Oooool01?m4A4CogMgMooooool00007ooooo`?o0000
<oooool2o`0000oooooo1?l00004ooooo`;o00004?ooool2o`000003ooooool0003o000000?ooooo
0_l00003ooooo`;o00000_ooool8o`0000oooooo0_l00002ooooo`;o00003?ooool2o`0000Oooooo
0_l00002ooooo`?o00002_oooolCo`0000;ooooo1Ol0000]ooooo`;o00000_ooool3o`0000Oooooo
0_l00003ooooo`;o0000>oooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Ooo
ool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo02Sooooo0_l00009ooooo`;o0000
3oooool4o`0000Cooooo0_l0000:ooooo`;o00002?ooool2o`0000_ooooo0_l000001?oooooo0000
o`000?ooool2o`00027ooooo0_l00007ooooo`;o00000oooool2o`000003ooooool0003o000000Oo
oooo4ol00002ooooo`Go00001Oooool2o`0002[ooooo0ol00007ooooo`;o0000@?ooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00omgMgOoc<c<o`000007ooooo`03o`00
0?oooooooooo02Sooooo0_l0000Iooooo`?o00003oooool2o`000003ooooool0003o000000;o0000
1_ooool2o`0003Cooooo0_l0000<ooooo`;o000000?oooooo`000?l000000_l00007ooooo`Oo0000
00?oooooo`000?l000001_l0000=ooooo`;o00002_ooool2o`00017ooooo0_l000001?oooooo0000
o`000?ooool2o`0001?ooooo0_l0000looooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<oooo
o`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0@oooool2o`00013ooooo0_l00003oooo
o`;o00001oooool2o`0000Gooooo0ol00008ooooo`;o00008oooool2o`0000Wooooo0_l00004oooo
o`?o00001_oooolBo`0000Kooooo0_l00003ooooo`;o00002_ooool2o`00017ooooo1Ol000000ooo
oooo0000o`00000Booooo`?o0000??ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool0
0omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo05Sooooo0_l00006ooooo`Go00001Oooool3
o`0000Kooooo1?l0000Sooooo`;o00002?ooool3o`0000Cooooo0ol00008oooooa3o000000?ooooo
o`000?l000000_l000000ooooooo0000o`000003ooooo`;o00002oooool2o`00017ooooo0_l0000G
ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0=Oooool2o`0001Wooooo0ol00005oooo
o`;o000000Coooooo`000?l0003o00000_ooool3o`0000_ooooo0_l00003ooooo`;o00000_ooool3
o`0002[ooooo0_l00004ooooo`?o00002OoooolEo`0000Cooooo1?l0000;ooooo`;o00004Oooool4
o`0000Wooooo0_l00007ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool09_ooool4o`00
00_ooooo0_l0000Iooooo`?o00002?ooool3o`0000cooooo0_l000001Ooooooo0000o`000?l0003o
oooo00Co00000_ooool3o`000003ooooool0003o000001;ooooo1?l00002ooooo`;o00003Oooool2
o`0000;ooooo1?l0000:ooooo`;o00000oooool8o`0000;ooooo0_l00002ooooo`;o00001?ooool5
o`0001gooooo1?l00003ooooo`[o00000_ooool5o`00043ooooo000Looooo`03o`000?oooooooooo
02Kooooo1?l0000Eooooo`;o00006?ooool2o`000004ooooool0003o0000o`0000_ooooo0_l00000
0ooooooo0000o`000002ooooo`Co00000_ooool6o`000003ooooool0003o000000;o00003Oooool4
o`0000;ooooo0_l0000<ooooo`;o00000oooool2o`0000Cooooo0_l0000;ooooo`;o00000_ooool5
o`0000_ooooo1Ol00008ooooo`;o00006_ooool:o`0000;ooooo1?l00006ooooo`;o0000>Oooool0
01cooooo00?o0000ooooooooool0?oooool2o`0000Wooooo0_l0000=ooooo`Ko00002oooool2o`00
0004ooooool0003o0000o`0000;ooooo0ol000000ooooooo0000o`000003o`0000?ooooo1?l0000G
ooooo`;o00000oooool2o`0000?ooooo0_l00009ooooo`;o00002?ooool2o`0000;ooooo0_l00002
ooooo`Ko00002?ooool2o`0000cooooo0_l0000[ooooo`;o00000oooool2o`0003Wooooo000Loooo
o`03o`000?oooooooooo03gooooo1?l00009ooooo`;o00003_ooool2o`00017ooooo0ol00002oooo
o`;o00000_ooool7o`000003ooooool0003o000000Sooooo1?l0000;ooooo`Co00000oooool2o`00
00;ooooo0_l0000Dooooo`;o00000_ooool4o`000004ooooool0003o0000ooooo`;o00001_ooool4
o`0002Wooooo0_l0000>ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0<_ooool2o`00
00Wooooo1_l00006ooooo`;o00004_ooool2o`0000Gooooo1?l000000ooooooo0000o`000002oooo
o`?o000000?oooooo`000?l000000_l000000ooooooo0000o`000002ooooo`?o000000Coooooo`00
0?l0003o00000_ooool2o`0000?ooooo1?l00002ooooo`;o00001oooool2o`0000Gooooo0_l00002
ooooo`;o00003oooool3o`0000Sooooo0_l0000<ooooo`;o0000:Oooool4o`0001Gooooo0_l0000g
ooooo`007?ooool00ol0003oooooooooo`0booooo`;o00001_ooool2o`000003ooooool0003o0000
00Co00001_ooool2o`0000Kooooo0_l0000:ooooo`;o00001Oooool4o`000003ooooool0003o0000
00Co00000_ooool7o`0000Oooooo0_l00002ooooo`;o00001?ooool2o`0000?ooooo0_l00007oooo
o`;o00002Oooool2o`0000oooooo0ol00003ooooo`;o00001?ooool2o`0003Kooooo0_l000000ooo
oooo0000o`00000Dooooo`?o0000=_ooool001cooooo00?o0000ooooooooool0>_ooool6o`00017o
oooo0_l00007ooooo`;o00003?ooool7o`0000Kooooo1Ol00005ooooo`;o00000oooool2o`0001;o
oooo0_l000000ooooooo0000o`000005ooooo`;o00001_ooool2o`000004ooooool0003o0000oooo
o`;o00001oooool3o`0000?ooooo0_l0000iooooo`;o000000?oooooo`000?l000004_ooool2o`00
03Kooooo000Looooo`03o`000?oooooooooo03_ooooo1Ol0000Iooooo`?o00000_ooool2o`000003
ooooool0003o000000Gooooo1ol00002ooooo`;o00000_ooool5o`000003ooooool0003o000000?o
00001?ooool2o`0000gooooo0ol00002ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Ko
oooo0_l000000ooooooo0000o`000003o`0000?ooooo0ol00002ooooo`;o00000_ooool5o`0000Co
oooo0_l000000ooooooo0000o`00000Wooooo`;o00001oooool3o`0000gooooo0_l00007ooooo`;o
0000<_ooool001cooooo00?o0000ooooooooool0<?ooool2o`0000oooooo0_l00005ooooo`;o0000
1?ooool2o`0000Wooooo0_l00003ooooo`;o000000?oooooo`000?l000002Ol00005ooooo`?o0000
0_ooool3o`0000;ooooo1_l00002ooooo`?o00002?ooool2o`0000?ooooo0ol00005ooooo`;o0000
1_ooool2o`0000Sooooo1_l00002ooooo`Ko000000?oooooo`000?l000001Ol00004ooooo`;o0000
00Coooooo`000?l0003o00001_ooool2o`000003ooooool0003o000000;ooooo0_l0000Dooooo`;o
000000?oooooo`000?l000001oooool2o`0000kooooo0_l00007ooooo`;o0000<_ooool001cooooo
00?o0000ooooooooool0<?ooool2o`0000oooooo0_l00005ooooo`;o00001?ooool2o`0000;ooooo
0_l0000=ooooo`go000000Coooooo`000?l0003ooooo0_l00002ooooo`co000000Coooooo`000?l0
003o00000_ooool2o`0000Cooooo0_l0000;ooooo`;o00001_ooool2o`0000Wooooo0_l000000ooo
oooo0000o`000003ooooo`Go000000?oooooo`000?l000000oooool2o`0000;ooooo0_l00004oooo
o`;o00001_ooool6o`000004ooooool0003o0000ooooo`;o00004Oooool2o`0001;ooooo0_l0000:
ooooo`;o0000=oooool001cooooo0_l0000Rooooo`;o0000:?ooool2o`0000Gooooo0_l00002oooo
o`;o00001?ooool2o`0000?ooooo0_l000001Ooooooo0000o`000?l0003ooooo00Ko000000?ooooo
o`000?l000003?l00002ooooo`Go00000oooool4o`0000?ooooo0ol000000ooooooo0000o`000002
o`0000Gooooo0_l0000Aooooo`;o00000_ooool2o`0000Oooooo0_l00008ooooo`;o00003?ooool3
o`000003ooooool0003o000000;ooooo1?l0000Aooooo`;o00004_ooool2o`0000[ooooo0_l00000
0ooooooo0000o`00000dooooo`007?ooool00ol0003oooooooooo`0Qooooo`;o0000:?ooool2o`00
00;ooooo0_l00004ooooo`?o000000Coooooo`000?l0003ooooo1Ol00003ooooo`;o00000_ooool8
o`000003ooooool0003o000000_o00000_ooool4o`0000?ooooo1?l00003ooooo`?o000000?ooooo
o`000?l000000ol00004ooooo`;o00001_ooool2o`0000gooooo0ol00006ooooo`;o00005_ooool2
o`0000Kooooo0_l00004ooooo`Ko00001oooool2o`0000?ooooo0_l00003ooooo`;o00006Oooool2
o`0003Cooooo000Looooo`03o`000?oooooooooo04Sooooo0_l00005ooooo`;o00001?ooool6o`00
00;ooooo1?l00002ooooo`?o000000?oooooo`000?l000006ol0000>ooooo`Go00000_ooool7o`00
00?ooooo0_l00006ooooo`;o00001_ooool2o`0000;ooooo0_l00003ooooo`;o00001?ooool2o`00
00Cooooo0_l0000=ooooo`;o00002?ooool6o`0000Oooooo0_l00003ooooo`;o00000oooool2o`00
0003ooooool0003o000000gooooo0_l00002ooooo`;o0000>Oooool001cooooo00?o0000oooooooo
ool06oooool2o`0002[ooooo0ol00004ooooo`;o00001_ooool3o`0000Cooooo0_l000000ooooooo
0000o`00000@o`000003ooooool0003o000000go000000Coooooo`000?l0003o00000_ooool2o`00
00Sooooo1Ol00002ooooo`Oo00001Oooool2o`0000Cooooo0_l00006ooooo`?o000000?oooooo`00
0?l000000oooool2o`0000Cooooo0ol00003ooooo`;o00003Oooool3o`000003ooooool0003o0000
00Oooooo0_l00006ooooo`;o00002oooool4o`0000gooooo0_l00002ooooo`;o0000>Oooool001co
oooo00?o0000ooooooooool06oooool2o`0001cooooo0_l0000<ooooo`;o00001Oooool2o`0000?o
oooo0_l000000ooooooo0000o`000008ooooo`So000000?oooooo`000?l000003?l00003ooooo`go
000000?oooooo`000?l000001oooool6o`0000Oooooo0_l00005ooooo`;o00001?ooool2o`0000Co
oooo0_l000000ooooooo0000o`000002o`0000_ooooo0_l00004ooooo`Co00001?ooool4o`000003
ooooool0003o000000Go00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`;o
00001Oooool2o`0000Cooooo1?l00009ooooo`Co0000?oooool001cooooo00?o0000ooooooooool0
8?ooool2o`0001Oooooo0_l000000ooooooo0000o`00000Eooooo`;o00000oooool2o`0000;ooooo
0_l00005ooooo`Co000000?oooooo`000?l000008_l00005ooooo`;o000000?oooooo`000?l00000
2?ooool2o`00017ooooo0_l000000ooooooo0000o`000004o`0000?ooooo0_l00002ooooo`;o0000
1_ooool4o`000004ooooool0003o0000ooooo`co00000_ooool2o`0000Kooooo0_l00008ooooo`Co
00001_ooool2o`0000Wooooo1?l0000oooooo`007?ooool00ol0003oooooooooo`0Pooooo`;o0000
3Oooool2o`0000_ooooo0_l0000Hooooo`Co00000_ooool3o`0000Gooooo0_l00002ooooobCo0000
0oooool2o`0000_ooooo0_l0000@ooooo`?o00000oooool2o`000004ooooool0003o0000o`0000?o
oooo0_l00002ooooo`;o00001oooool2o`0000;ooooo0_l000000ooooooo0000o`00000;o`0000Wo
oooo0_l00004ooooo`;o00000_ooool4o`0000Kooooo0_l00009ooooo`Co00002oooool2o`0003;o
oooo000Looooo`03o`000?oooooooooo02kooooo0ol0000=ooooo`;o00000oooool2o`0000Sooooo
0_l00007ooooo`?o00001?ooool5o`0000;ooooo0_l000000ooooooo0000o`00000Oo`0000Kooooo
0ol0000;ooooo`;o00004?ooool3o`0000?ooooo1_l0000Fooooo`oo00003_ooool2o`0000Cooooo
0ol00005ooooo`;o00002Oooool4o`0000Oooooo0_l00002ooooo`;o0000<_ooool001cooooo00?o
0000ooooooooool0;_ooool2o`0000kooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0ol0
00000ooooooo0000o`000005ooooo`;o00001Oooool4o`000004ooooool0003o0000ooooob;o0000
0_ooool2o`0000;ooooo0ol0000Sooooo`Ko00003_ooool4o`0000Cooooo4?l000000ooooooo0000
o`000006ooooo`;o00001oooool4o`00013ooooo0_l00009ooooo`Co0000=?ooool001cooooo00?o
0000ooooooooool08?ooool2o`0002Gooooo0_l00003ooooo`;o00000_ooool2o`0000Wooooo0_l0
00000ooooooo0000o`000003ooooo`;o000000Coooooo`000?l0003ooooo7ol00002ooooo`;o0000
0oooool2o`0000Cooooo0_l0000Iooooo`;o000000?oooooo`000?l000000ol0000@ooooo`Co0000
1?oooolEo`0000Cooooo0_l00003ooooo`;o00000_ooool2o`0001;ooooo0_l0000;ooooo`;o0000
=?ooool001cooooo00?o0000ooooooooool08?ooool2o`0001Sooooo0_l00007ooooo`;o000000?o
ooooo`000?l000000oooool3o`0000Cooooo0_l00007ooooo`;o00001?ooool2o`0000;ooooo3?l0
00000ooooooo0000o`00000Fo`0000_ooooo0_l00007ooooo`;o00004?ooool2o`000003ooooool0
003o000000?o00001?ooool2o`0000cooooo0_l00003oooooaKo00000_ooool2o`0000Gooooo0_l0
000Fooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0>_ooool2o`0000Oooooo1Ol00003
ooooo`?o00001?ooool2o`0000;ooooo1?l00006ooooo`?o00000_oooolQo`000004ooooool0003o
0000o`0000;ooooo1?l00005ooooo`;o00001oooool2o`00017ooooo1?l00003ooooo`;o00000_oo
ool2o`0000cooooo0_l00002oooooaOo00000_ooool2o`0000;ooooo0_l00005ooooo`;o00001Ooo
ool2o`0000Cooooo0_l0000:ooooo`;o0000??ooool001cooooo00?o0000ooooooooool0;Oooool2
o`0000Kooooo0_l00003ooooo`;o00001oooool4o`0000Gooooo1_l00004ooooo`Co00001_ooool2
o`0000Cooooo7ol00002ooooo`Co000000?oooooo`000?l000000_l00005ooooo`;o00001oooool3
o`0000oooooo1Ol00003ooooo`;o00000oooool2o`0000Wooooo1?l00002oooooa;o000000?ooooo
o`000?l000000_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00004ooooo`;o00002_ooool2
o`0003cooooo000Looooo`03o`000?oooooooooo02gooooo0_l00006ooooo`;o00000_ooool3o`00
00Oooooo0_l00008ooooo`Go00002?ooool2o`0000;ooooo1Ol000000ooooooo0000o`00000Vo`00
01;ooooo0ol00002ooooo`;o00002oooool2o`000003ooooool0003o000000;o00001_ooool2o`00
00Wooooo7_l00005ooooo`;o00007_ooool2o`0000Kooooo0_l00006ooooo`;o0000;?ooool001co
oooo00?o0000ooooooooool0;?ooool2o`0000Oooooo0_l00002ooooo`;o00004_ooool2o`0000_o
oooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo1_l000000ooooooo0000o`00000Oo`00
01;ooooo0_l00003ooooo`;o00002oooool2o`000003ooooool0003o000000?o00004_oooolNo`00
00Cooooo0_l00006ooooo`;o00002_ooool2o`0000kooooo0_l000000ooooooo0000o`000006oooo
o`;o0000;?ooool001cooooo00?o0000ooooooooool0;?ooool2o`0000Oooooo0_l0000Looooo`;o
00000oooool2o`0000Oooooo1ol000000ooooooo0000o`00000Oo`0000_ooooo0_l0000Nooooo`Co
00004OoooolNo`0000Cooooo0_l00006ooooo`;o000000?oooooo`000?l000001oooool2o`0000Go
oooo0_l00007ooooo`;o00002Oooool2o`0002cooooo000Looooo`;o0000=oooool2o`0001_ooooo
0_l00003ooooo`;o00001ooooolDo`000003ooooool0003o000001Co00002Oooool2o`0000Oooooo
0_l0000:ooooo`;o00002oooool2o`00017ooooo4_l000000ooooooo0000o`000009o`0000oooooo
0_l00006ooooo`;o000000?oooooo`000?l000000oooool2o`0000Cooooo0_l00002ooooo`;o0000
00?oooooo`000?l000000_l00003ooooo`;o0000;?ooool001cooooo00?o0000ooooooooool0=_oo
ool2o`0000_ooooo0_l00002ooooo`;o00001?ooool2o`0000?ooooo0_l0000=ooooob_o00002Ooo
ool2o`000003ooooool0003o000000Cooooo0_l0000:ooooo`;o00007_ooool3o`000003ooooool0
003o000001So00005oooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000001?oo
ool2o`0000;ooooo0_l000000ooooooo0000o`000002o`00037ooooo000Looooo`03o`000?oooooo
oooo01kooooo0_l0000;ooooo`;o00003_ooool2o`0000?ooooo0_l000000ooooooo0000o`000002
ooooo`;o00000_ooool4o`0000?ooooo0_l0000>ooooobWo00001_ooool2o`0000Gooooo0_l00003
ooooo`Co000000?oooooo`000?l000009?ooool5o`000003ooooool0003o000001[o00006?ooool4
o`000003ooooool0003o000000Sooooo1?l00004ooooo`;o0000;_ooool001cooooo00?o0000oooo
ooooool07_ooool2o`0000_ooooo0_l0000>ooooo`;o00000oooool2o`0000Gooooo0_l00002oooo
o`;o00002_ooool2o`0000Kooooo;?l00006ooooo`;o00002_ooool9o`0000[ooooo0_l0000Eoooo
ob?o00002oooool2o`0000_ooooo0_l00003ooooo`?o00001?ooool2o`0000?ooooo0_l00004oooo
o`;o0000;_ooool001cooooo00?o0000ooooooooool07Oooool4o`0000[ooooo0_l00009ooooo`;o
00003_ooool3o`000003ooooool0003o000000Kooooo0_l00003ooooo`;o00001Oooool6o`000003
ooooool0003o000000?o000000?oooooo`000?l000007_l00004ooooo`;o00004?ooool5o`0000[o
oooo0_l00005ooooo`;o00001?ooool2o`0000Sooooo3?l000000ooooooo0000o`00000Ao`000003
ooooool0003o000000_ooooo0_l00003ooooo`Co00002_ooool4o`0000;ooooo0_l00002ooooo`;o
0000=Oooool001cooooo00?o0000ooooooooool07Oooool4o`0001Gooooo0_l0000>ooooo`;o0000
00Coooooo`000?l0003o00001_ooool2o`0000Sooooo1?l00002ooooo`;o00000_ooool<o`000003
ooooool0003o000001?o000000?oooooo`000?l000001?ooool2o`0000?ooooo0_l00009ooooo`;o
00000_ooool2o`0000Cooooo0_l0000;ooooo`?o00001?ooool2o`0000Sooooo0ol000000ooooooo
0000o`00000Ho`0000?ooooo0_l0000@ooooo`Co00002_ooool4o`0000Kooooo0_l0000eooooo`00
7?ooool00ol0003oooooooooo`19ooooo`;o00001oooool2o`0000Sooooo0ol00002ooooo`?o0000
00Coooooo`000?l0003ooooo4?l000000ooooooo0000o`00000@o`0000;ooooo0_l00005ooooo`;o
000000?oooooo`000?l000001_ooool2o`0000Sooooo0_l00006ooooo`;o00000oooool4o`0000go
oooo0ol00003oooooaSo00002_ooool2o`0000_ooooo0_l000000ooooooo0000o`000007ooooo`;o
0000?oooool001cooooo00?o0000ooooooooool0=Oooool2o`0000gooooo1?l000000ooooooo0000
o`000007ooooo`;o00002Oooool2o`0000;ooooo:Ol00002ooooo`?o000000?oooooo`000?l00000
0oooool4o`0000Kooooo0ol0000;ooooo`?o000000?oooooo`000?l000001Oooool2o`0001;ooooo
6?l0000;ooooo`;o00003_ooool4o`0000Gooooo1?l0000:ooooo`;o0000<Oooool001cooooo00?o
0000ooooooooool0=Oooool2o`0000gooooo1?l00005ooooo`;o00000oooool2o`0000Wooooo0_l0
0003ooooo`?o000000?oooooo`000?l000008ol000000ooooooo0000o`000002ooooo`So00001ooo
ool3o`0000_ooooo0ol00005ooooo`;o00004oooool4o`000003ooooool0003o000001?o00001?oo
ool2o`0001Oooooo0_l00003ooooo`;o00000_ooool2o`0000[ooooo0_l0000aooooo`007?ooool0
0ol0003oooooooooo`0iooooo`;o00002Oooool3o`000003ooooool0003o000000?ooooo0ol0000B
ooooo`?o000000?oooooo`000?l000009Ol00002ooooo`Ko000000?oooooo`000?l000002Oooool2
o`0000gooooo1?l000001?oooooo0000o`000?ooool4o`0000kooooo1?l00006ooooo`;o000000?o
ooooo`000?l000002Ol00004ooooo`Ko00003_ooool2o`0000Wooooo1Ol0000oooooo`007?ooool0
0ol0003oooooooooo`0iooooo`;o000000?oooooo`000?l000002_ooool2o`0000Cooooo0_l0000>
ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000003o`0000;ooooo6ol00002
ooooo`?o00000_ooool2o`0000;ooooo0_l0000<ooooo`Ko00002Oooool6o`0000;ooooo1?l0000@
ooooo`;o00000_ooool2o`0000;ooooo1?l000000ooooooo0000o`00000:o`000003ooooool0003o
000000;ooooo0_l0000>ooooo`;o00000_ooool2o`0000Gooooo0_l000000ooooooo0000o`000002
ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0>Oooool2o`000003ooooool0003o0000
023ooooo0_l000000ooooooo0000o`000002o`0000;ooooo2_l00002ooooo`oo000000?oooooo`00
0?l000001?l000001Ooooooo0000o`000?l0003ooooo00;o00000_ooool2o`0000Kooooo0_l00007
ooooo`Co00001_ooool2o`000003ooooool0003o000000Wo00005Oooool2o`0000?ooooo3?l00000
0ooooooo0000o`000002o`0000?ooooo0_l0000<ooooo`;o00001Oooool3o`0000Cooooo0_l00005
ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0?_ooool2o`0000;ooooo0_l00008oooo
o`;o00001Oooool2o`0000Wooooo1?l00005ooooo`?o000000?oooooo`000?l000007?l000000ooo
oooo0000o`000008o`0000Kooooo0_l0000Aooooo`;o00000_ooool4o`000003ooooool0003o0000
00?o00006_ooool6o`0000;ooooo0_l00005ooooo`;o00000oooool3o`0000_ooooo0_l00006oooo
o`;o00001?ooool2o`0000?ooooo1?l00008ooooo`;o0000<Oooool001cooooo00?o0000oooooooo
ool0?_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l00005ooooo`;o
00001_ooool2o`0000;ooooo0ol00003ooooo`Co000000?oooooo`000?l000004_l000000ooooooo
0000o`000007o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000002o`0000Ko
oooo0_l0000Eooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0001Sooooo0ol000000ooo
oooo0000o`000002o`0000kooooo0ol00009ooooo`;o00004oooool3o`0000Wooooo0_l0000aoooo
o`007?ooool00ol0003oooooooooo`15ooooo`Co00001Oooool2o`0000_ooooo0_l00002ooooo`?o
00000ooooolXo`0000gooooo0_l0000Aooooo`;o00001Oooool3o`0000;ooooo0_l0000Hooooo`Ko
00002_ooool2o`0000?ooooo0_l0000;ooooo`;o00002oooool2o`0000_ooooo0_l00002ooooo`;o
0000=?ooool001cooooo00?o0000ooooooooool07Oooool2o`0002?ooooo0_l00004ooooo`;o0000
1?ooool2o`00013ooooo0_l00006ooooo`?o00000_ooool2o`000003ooooool0003o000001So0000
00?oooooo`000?l000002oooool2o`0000?ooooo0_l000000ooooooo0000o`00000;ooooo`;o0000
0oooool2o`0000?ooooo1?l0000Kooooo`;o00000_ooool2o`0000Oooooo0_l000000ooooooo0000
o`000002o`0001Gooooo0_l000000ooooooo0000o`000002o`0000Wooooo0_l00002ooooo`;o0000
=?ooool001cooooo0_l0000Nooooo`;o00006Oooool2o`0000Oooooo1Ol00002ooooo`;o00003ooo
ool2o`000003ooooool0003o000000Gooooo0_l00002ooooo`Co00000_ooool2o`000003ooooool0
003o000001Ko00004?ooool4o`000003ooooool0003o000000?o00004?ooool2o`0000?ooooo1?l0
000Oooooo`;o00002_ooool2o`0000_ooooo0_l0000:ooooo`;o000000?oooooo`000?l000000_l0
0009ooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0>?ooool2o`0000Oooooo0_l00000
0ooooooo0000o`00000=ooooo`?o00000oooool5o`0000Gooooo1ol0000;ooooo`[o00000oooool4
o`0000;ooooo0_l0000>ooooo`Co00000_ooool2o`0000[ooooo0_l0000=ooooo`;o000000?ooooo
o`000?l000002?ooool2o`0001[ooooo0_l0000?ooooo`;o00003Oooool4o`0000Wooooo0_l0000h
ooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00000_ooool2o`0000Sooooo1Ol00002oooo
o`?o00001_ooool4o`000003ooooool0003o000000Oooooo0_l00002ooooo`Wo00001?ooool2o`00
00Cooooo0_l00004ooooo`;o00003Oooool2o`0000_ooooo0_l00007ooooo`;o00001?ooool2o`00
0003ooooool0003o000000Sooooo0_l0000Jooooo`;o00006_ooool2o`0000;ooooo0ol0000@oooo
o`;o0000<_ooool001cooooo00?o0000ooooooooool0AOooool2o`0000;ooooo1?l00002ooooo`;o
00001?ooool5o`000003ooooool0003o000000Kooooo0_l00003ooooo`;o00001_ooool3o`000003
ooooool0003o000000Oo00001Oooool2o`000003ooooool0003o000000Oooooo0_l00007ooooo`;o
00001?ooool2o`0001Cooooo0_l00004ooooo`Ko00006Oooool2o`0002Cooooo0_l000001?oooooo
0000o`000?l00002ooooo`;o00003Oooool2o`0003;ooooo000Looooo`03o`000?oooooooooo043o
oooo0_l00006ooooo`Go00000_ooool2o`0000Oooooo0_l0000;ooooo`;o00000oooool4o`0000;o
oooo1_l00003ooooo`?o000000?oooooo`000?l000000_ooool3o`000003ooooool0003o000000Ko
oooo0ol00007ooooo`;o00006?ooool2o`0000?ooooo0_l000000ooooooo0000o`000004o`0000Oo
oooo0_l0000@ooooo`;o00007oooool2o`0000Gooooo0ol00003ooooo`;o000000?oooooo`000?l0
00000_l00008ooooo`;o0000<_ooool001cooooo00?o0000ooooooooool0?oooool3o`0000Kooooo
0_l0000Kooooo`;o00000_ooool5o`0000Cooooo0_l00003ooooo`Co00000_ooool6o`0000[ooooo
0ol0000Kooooo`Co00000_ooool2o`0000;ooooo1_l000000ooooooo0000o`000008ooooo`;o0000
6Oooool2o`0001Kooooo0_l000000ooooooo0000o`000004o`0000?ooooo0_l00002ooooo`Co0000
2?ooool2o`0003;ooooo000Looooo`03o`000?oooooooooo03Sooooo0ol00004ooooo`;o000000?o
ooooo`000?l000002oooool2o`00013ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o0000
2oooool5o`0000?ooooo1_l00007ooooo`;o000000?oooooo`000?l000001oooool2o`0000Oooooo
0_l00003ooooo`;o000000Coooooo`000?l0003ooooo1?l00005ooooo`[o00002?ooool2o`0001Wo
oooo0_l0000Iooooo`Go00001?ooool2o`0000?ooooo0ol0000looooo`007?ooool00ol0003ooooo
ooooo`0hooooo`?o00001Oooool4o`0000Cooooo0ol00004ooooo`?o00003oooool2o`0000;ooooo
0_l000000ooooooo0000o`000006ooooo`?o00000oooool2o`0000Sooooo1?l00003ooooo`;o0000
00Goooooo`000?l0003o0000ooooo`02o`0000Oooooo0_l00007ooooo`;o00000oooool2o`000003
ooooool0003o000000[ooooo2Ol0000Iooooo`;o00009Oooool2o`0000_ooooo0ol00006ooooo`;o
0000=?ooool001cooooo00?o0000ooooooooool0>Oooool2o`0000Gooooo0_l00006ooooo`?o0000
1Oooool3o`0000Oooooo1?l000000ooooooo0000o`00000?ooooo`Co00000_ooool2o`0000Oooooo
1Ol00002ooooo`?o000000Coooooo`000?l0003o00007_ooool3o`0000Gooooo0_l00003ooooo`?o
00004Oooool2o`0000Sooooo1?l0000Rooooo`Co00004oooool2o`0003Cooooo000Looooo`03o`00
0?oooooooooo03gooooo0_l00002ooooo`;o00001Oooool4o`0000?ooooo1?l00002ooooo`;o0000
00?oooooo`000?l000001?l000001?oooooo0000o`000?ooool4o`0000;ooooo0_l00007ooooo`?o
00000_ooool2o`0000?ooooo0ol000000ooooooo0000o`000005ooooo`Co000000Coooooo`000?l0
003o00001?ooool2o`000003ooooool0003o000001?ooooo1?l00003ooooo`Co00000_ooool5o`00
00?ooooo0_l00008ooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo1?l0000Poooo
o`Ko00001?ooool2o`0000?ooooo0_l00007ooooo`;o0000=Oooool001cooooo00?o0000oooooooo
ool0?Oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00004ooooo`;o
000000?oooooo`000?l000002?ooool4o`0000;ooooo0_l00007ooooo`;o000000?oooooo`000?l0
00001Oooool3o`0000Sooooo1?l00002ooooo`Co00000_ooool2o`000003ooooool0003o000000Oo
oooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo0_l00004ooooo`;o000000?oooooo`000?l0
00000oooool2o`0000Sooooo0_l000000ooooooo0000o`000004ooooo`Ko00008_ooool3o`0000Oo
oooo0_l00003ooooo`;o00001oooool2o`0003Gooooo000Looooo`03o`000?oooooooooo03gooooo
0_l00007ooooo`Go00002Oooool2o`0001_ooooo2?l0000=ooooo`;o00001_ooool2o`0000;ooooo
0_l00004ooooo`;o00000oooool3o`0000Cooooo0_l00002ooooo`;o00000_ooool2o`0000Gooooo
1?l00003ooooo`;o00004_ooool2o`0000Cooooo1?l0000Sooooo`;o00001Oooool2o`0004Gooooo
000Looooo`03o`000?oooooooooo03gooooo1?l00006ooooo`Oo00001_ooool2o`0001Cooooo0_l0
0005ooooo`So00001?ooool2o`0000Cooooo0_l0000Cooooo`;o00000oooool2o`0000Wooooo0_l0
0002ooooo`;o00001Oooool7o`0001Cooooo0_l000000ooooooo0000o`00000Sooooo`;o00001Ooo
ool2o`0000?ooooo0_l00006ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0?oooool2
o`0000Oooooo0_l000001?oooooo0000o`000?l0000Looooo`;o00001oooool2o`0000Sooooo0_l0
0002ooooo`Co00009Oooool2o`0000Kooooo0_l000000ooooooo0000o`000003o`0000Gooooo0_l0
000<ooooo`;o00000_ooool2o`0002?ooooo0_l00005ooooo`;o00002oooool2o`0003gooooo0000
1_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<
c<`01_ooool00ol0003oooooooooo`1>ooooo`;o00008oooool2o`0000cooooo1?l0000Dooooo`?o
00003_ooool2o`0000Kooooo1_l000000ooooooo0000o`000002ooooo`Go00002oooool2o`000003
ooooool0003o000003?ooooo0_l00012ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5oooo
o`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0??ooool2
o`0000oooooo0ol0000;ooooo`;o00007oooool2o`0000Gooooo0_l0000Dooooo`?o00005oooool2
o`000004ooooool0003o0000ooooo`Wo00000_ooool2o`0000[ooooo0ol0000[ooooo`;o00000ooo
ool5o`00047ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo03cooooo0_l00009ooooo`;o00000ooo
ool3o`0000?ooooo0ol00006ooooo`;o00001?ooool2o`0001Wooooo0_l00005ooooo`;o00002?oo
ool2o`0000Oooooo0_l0000Looooo`;o000000?oooooo`000?l000000_ooool5o`0000Cooooo0_l0
000;ooooo`;o0000:oooool2o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`;o0000>ooo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oV9RHoooooonH
V9So8B4Q00Kooooo0ol0000Sooooo`;o00006?ooool2o`0000Sooooo0_l00003ooooo`;o00001?oo
ool3o`0000Cooooo0_l00006ooooo`;o00000_ooool2o`0000_ooooo0_l0000?ooooo`;o00002?oo
ool4o`000005ooooool0003o0000o`000?ooool00_l0000Looooo`Oo000000?oooooo`000?l00000
1?ooool4o`0002_ooooo0_l0000Iooooo`;o0000>oooool00003ooooool0003ooooo00;ooooo00?o
0000ooooooooool02Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0
8oooool2o`0001Sooooo0_l00004ooooo`;o00000_ooool4o`0000kooooo0_l00007ooooo`;o0000
00?oooooo`000?l000000_ooool2o`0000Oooooo0_l00002ooooo`?o00005?ooool4o`000004oooo
ool0003o0000o`0001Wooooo0_l00002ooooo`Go00000_ooool2o`000004ooooool0003o0000o`00
00?ooooo1?l0000Cooooo`Co00005?ooool3o`0000[ooooo0_l00003ooooo`;o0000A?ooool00003
ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03
o`000?oooooooooo03[ooooo0_l00007ooooo`;o000000Coooooo`000?l0003ooooo1?l0000<oooo
o`;o00001oooool2o`0000Gooooo0_l00002ooooo`;o00001oooool4o`0000oooooo0_l00002oooo
o`Co00001Oooool2o`0000?ooooo0_l0000:ooooo`;o00001Oooool2o`0000;ooooo0_l00006oooo
o`Go00001?ooool3o`0000cooooo0_l00005ooooo`Co00005Oooool2o`0000[ooooo1?l000000ooo
oooo0000o`000014ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413o
V9RH00Sooooo00?o0000ooooooooool0>_ooool2o`0000;ooooo0_l00003ooooo`;o000000?ooooo
o`000?l000000_ooool3o`0000cooooo0_l0000Booooo`;o00002Oooool2o`0000Sooooo0_l00005
ooooo`;o00000_ooool4o`0000Gooooo0_l00003ooooo`?o000000?oooooo`000?l000001Oooool3
o`0000Gooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00000_ooool=o`0000cooooo0_l0
000;ooooo`;o00004Oooool2o`0000Kooooo0_l00003ooooo`?o0000Aoooool00006ooooooo^k^ko
<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo03_o
oooo1Ol00003ooooo`;o00001Oooool3o`0000cooooo0_l00003ooooo`;o00008_ooool3o`000003
ooooool0003o000000Kooooo0_l00002ooooo`;o00001_ooool7o`0000Gooooo0_l00006ooooo`Go
00000_ooool2o`0000;ooooo1?l00002ooooo`Wo00005oooool2o`0001Wooooo0_l00003ooooo`;o
000000?oooooo`000?l00000AOooool001cooooo00?o0000ooooooooool09?ooool2o`0001Gooooo
0ol00002ooooo`;o00001_ooool2o`0000;ooooo0_l00009ooooo`;o00001Oooool2o`0002?ooooo
0_l000000ooooooo0000o`000002o`0000Cooooo0_l000000ooooooo0000o`000003o`000003oooo
ool0003o000000Ko00004?ooool2o`00013ooooo1ol0000@ooooo`;o00000oooool3o`0002;ooooo
0ol00014ooooo`007?ooool00ol0003oooooooooo`0Tooooo`;o00005_ooool2o`0000;ooooo0_l0
0003ooooo`;o000000?oooooo`000?l000001Ol00008ooooo`;o00009oooool4o`0000Cooooo0_l0
0006ooooo`Ko000000?oooooo`000?l000001?l00007ooooo`;o00003?ooool2o`0000;ooooo0_l0
000Cooooo`;o00002oooool2o`0000?ooooo0ol0000Dooooo`;o00003Oooool2o`0004Cooooo000L
ooooo`03o`000?oooooooooo043ooooo0_l00003ooooo`;o00000oooool2o`000003ooooool0003o
000000;o000000Coooooo`000?l0003ooooo0_l0000Yooooo`Co000000?oooooo`000?l000000_oo
ool2o`0000Gooooo1_l000000ooooooo0000o`00000;ooooo`;o00003?ooool2o`0000;ooooo0_l0
000;ooooo`?o00001Oooool2o`0002Oooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`10
ooooo`;o00002?ooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`00023ooooo0ol0
000;ooooo`;o000000Coooooo`000?l0003o00000oooool2o`000003ooooool0003o000000Ko0000
2?ooool2o`00023ooooo0ol0000Booooo`;o000000?oooooo`000?l000006Oooool2o`0000Cooooo
0_l00006ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0>oooool4o`0003Sooooo0ol0
000>ooooo`?o00000oooool2o`0000;ooooo2Ol000000ooooooo0000o`000003ooooo`;o00000_oo
ool2o`0000Sooooo0_l00002ooooo`;o00000_ooool2o`0000[ooooo0_l00005ooooo`;o00002ooo
ool7o`0001Kooooo1?l00003ooooo`?o00000oooool2o`000003ooooool0003o000004?ooooo000L
ooooo`03o`000?oooooooooo03_ooooo1?l00002ooooo`;o0000Aoooool2o`0000Kooooo3?l00007
ooooo`;o00002?ooool2o`0000;ooooo0_l00002ooooo`;o00004Oooool2o`0000_ooooo1?l00000
0ooooooo0000o`00000Fooooo`;o00001Oooool2o`0000Cooooo0_l00016ooooo`007?ooool00ol0
003oooooooooo`11ooooo`;o000000?oooooo`000?l00000?Oooool2o`0000?ooooo1?l00005oooo
o`Ko00000_ooool6o`0000?ooooo0_l00006ooooo`?o00001?ooool4o`0004cooooo0_l00016oooo
o`007?ooool00ol0003oooooooooo`14ooooo`;o000000?oooooo`000?l00000>_ooool2o`0000?o
oooo1Ol00003ooooo`oo00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000005o`000003
ooooool0003o000000;o00001_ooool2o`0001;ooooo0_l000000ooooooo0000o`00000Iooooo`;o
00001oooool2o`0000Cooooo0_l00003ooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0
:Oooool2o`0001Kooooo0_l00004ooooo`;o00000oooool4o`00013ooooo0_l0000Fooooo`;o0000
2oooool4o`000003ooooool0003o000000;o00000_ooool?o`0000;ooooo0_l00002ooooo`?o0000
00?oooooo`000?l000001ol00009ooooo`;o00004_ooool2o`000004ooooool0003o0000o`0000Co
oooo0_l000001?oooooo0000o`000?ooool2o`0000Cooooo0_l00006ooooo`;o00001oooool2o`00
00Cooooo0_l00007ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0:Oooool2o`0001Ko
oooo0_l00009ooooo`Co00002_ooool2o`0000Cooooo0_l0000Fooooo`?o00002_ooool4o`0000;o
oooo0ol000000ooooooo0000o`00000<o`000003ooooool0003o000000?o000000Coooooo`000?l0
003o00000oooool2o`0000Cooooo0ol00006ooooo`;o00004_ooool4o`000004ooooool0003o0000
o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0000Cooooo0_l0000Nooooo`;o0000@_oo
ool001cooooo00?o0000ooooooooool0COooool3o`0000[ooooo0_l0000Mooooo`;o00002Oooool2
o`0000Gooooo0ol000000ooooooo0000o`00000Ao`0000;ooooo0_l00003ooooo`?o000000Gooooo
o`000?l0003o0000ooooo`02o`000003ooooool0003o000000?ooooo1?l00005ooooo`;o00002Ooo
ool2o`0000?ooooo0_l0000>ooooo`;o00007oooool2o`0004Cooooo000Looooo`;o0000:oooool2
o`0001Sooooo0_l00008ooooo`;o00004Oooool3o`0001[ooooo0_l00002ooooo`Co00001OoooolG
o`0000Oooooo0ol000001?oooooo0000o`000?l00004ooooo`;o00000oooool6o`0000?ooooo0_l0
000Aooooo`;o00002oooool2o`0001Gooooo0_l00008ooooo`Co0000@_ooool001cooooo00?o0000
ooooooooool0:_ooool2o`0001Sooooo0_l00003ooooo`;o00001oooool2o`0000gooooo0ol0000J
ooooo`;o00000_ooool2o`0000Kooooo6?l000000ooooooo0000o`000005ooooo`;o00004Oooool2
o`0001Kooooo0_l0000;ooooo`;o00005Oooool3o`0000Wooooo0_l00012ooooo`007?ooool00ol0
003oooooooooo`16ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo1?l0000/oooo
o`;o000000?oooooo`000?l000000ooooolGo`0000;ooooo0ol00004ooooo`;o00008oooool2o`00
017ooooo1?l000001?oooooo0000o`000?l00006ooooo`;o00002?ooool2o`0000?ooooo0ol00000
0ooooooo0000o`000014ooooo`007?ooool00ol0003oooooooooo`13ooooo`Go00001Oooool2o`00
00Gooooo0ol0000^ooooo`?o00000_oooolLo`00013ooooo0_l0000Gooooo`;o00000_ooool2o`00
00Wooooo0_l00004ooooo`Ko000000?oooooo`000?l000000oooool2o`0000Gooooo1Ol00003oooo
o`?o000000?oooooo`000?l00000A?ooool001cooooo00?o0000ooooooooool0@oooool5o`0000Wo
oooo0_l00002ooooo`;o0000;oooool2o`0000;ooooo5_l000000ooooooo0000o`000005o`000003
ooooool0003o000000_ooooo1ol00004ooooo`;o00001Oooool2o`0000Wooooo0ol00008ooooo`;o
00000oooool4o`0000Cooooo0_l00009ooooo`Ko0000COooool001cooooo00?o0000ooooooooool0
@_ooool2o`0000;ooooo0_l00009ooooo`;o00009_ooool2o`0000;ooooo0_l00006ooooo`Co0000
00?oooooo`000?l000005_l00002ooooo`Co000000?oooooo`000?l000002?ooool2o`0000?ooooo
1_l00003ooooo`;o00001?ooool3o`0000Wooooo0ol00008ooooo`;o00000oooool2o`000003oooo
ool0003o000000;o00003?ooool2o`0000Sooooo0_l00017ooooo`007?ooool00ol0003ooooooooo
o`0^ooooo`;o00004_ooool2o`0001gooooo0_l0000Fooooo`;o00000_ooool2o`0000Kooooo1Ol0
00000ooooooo0000o`00000Fo`000004ooooool0003o0000o`0000cooooo0_l00003ooooo`;o0000
0_ooool2o`0000Kooooo0_l000000ooooooo0000o`00000:ooooo`?o00004?ooool4o`000003oooo
ool0003o000001?ooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00005_oo
ool2o`0001;ooooo0ol00004ooooo`;o00005Oooool3o`0000cooooo0ol000000ooooooo0000o`00
000Fo`0000;ooooo0_l00005ooooo`;o00002_ooool2o`0000Gooooo0_l00003ooooo`?o00003?oo
ool2o`0001Kooooo0_l0000:ooooo`;o0000D?ooool001cooooo00?o0000ooooooooool0A_ooool4
o`00013ooooo0ol0000Kooooo`?o00003?oooolKo`0000?ooooo0_l00005ooooo`;o00000oooool2
o`0000cooooo2_l0000Qooooo`;o00002oooool3o`0004oooooo000Looooo`03o`000?oooooooooo
043ooooo0_l00006ooooo`;o00001oooool2o`0000Cooooo0_l00005ooooo`;o00007Oooool2o`00
00Wooooo6ol00009ooooo`;o00000oooool4o`0000Kooooo0_l00002ooooo`co00007oooool2o`00
00Wooooo0_l000000ooooooo0000o`000003ooooo`;o0000B_ooool001cooooo00?o0000oooooooo
ool0@?ooool2o`0000cooooo0_l000001?oooooo0000o`000?l00002ooooo`?o000000?oooooo`00
0?l000000_ooool2o`0001gooooo0_l00005ooooo`;o00000_oooolNo`0000Kooooo0_l00004oooo
o`?o00001_ooool2o`000003ooooool0003o000000_o00002?ooool2o`00023ooooo0_l00006oooo
o`;o0000B_ooool001cooooo00?o0000ooooooooool0B?ooool2o`0000Cooooo0_l00002ooooo`;o
00000_ooool2o`0000;ooooo0_l00006ooooo`;o00008?ooool2o`0000;ooooo7ol00002ooooo`;o
00000_ooool2o`0000?ooooo1?l00008ooooo`go00002?ooool2o`0001Kooooo0_l00003ooooo`;o
00001_ooool2o`0004oooooo000Looooo`03o`000?oooooooooo04Sooooo0_l0000;ooooo`;o0000
2oooool2o`0001Sooooo0_l0000;oooooaoo000000?oooooo`000?l000000_ooool2o`0000?ooooo
1?l000000ooooooo0000o`000005ooooo`go00001Oooool2o`0000;ooooo0_l0000Cooooo`Co0000
0oooool2o`0000Kooooo1?l0001=ooooo`007?ooool00ol0003oooooooooo`1Eooooo`;o000000?o
ooooo`000?l000002?ooool2o`0001Kooooo1_l00009ooooob7o00001_ooool4o`0000?ooooo0_l0
0005ooooo`go00000oooool4o`0000;ooooo0ol0000Booooo`;o00003oooool2o`0004gooooo000L
ooooo`03o`000?oooooooooo04Gooooo0_l0000>ooooo`;o000000?oooooo`000?l000002?ooool2
o`0001Kooooo0_l000001?oooooo0000o`000?l0000=ooooo`So000000?oooooo`000?l000000ol0
0003ooooo`So000000Coooooo`000?l0003o00001?ooool5o`000003ooooool0003o000000Sooooo
3ol000000ooooooo0000o`000005ooooo`;o00005Oooool2o`000003ooooool0003o000000Oooooo
0_l0001?ooooo`007?ooool00ol0003oooooooooo`15ooooo`?o00000_ooool2o`0000cooooo0_l0
0006ooooo`?o00006?ooool5o`0000cooooo7Ol00005ooooo`Go000000?oooooo`000?l000002?oo
ool?o`0001Wooooo0_l00004ooooo`;o000000?oooooo`000?l000001oooool2o`0004oooooo000L
ooooo`;o0000Aoooool2o`0000;ooooo0_l0000<ooooo`;o00001_ooool3o`0001Sooooo0_l00000
0ooooooo0000o`00000:ooooo`Go000000?oooooo`000?l000005Ol0000=ooooo`;o00002?ooool8
o`000003ooooool0003o000000Co00001_ooool3o`00013ooooo0_l00004ooooo`;o000000Cooooo
o`000?l0003o0000Eoooool001cooooo00?o0000ooooooooool0=Oooool2o`0000oooooo0_l00008
ooooo`;o00000_ooool2o`0003Cooooo7?l00003ooooo`;o00005_ooool?o`0000?ooooo0ol0000F
ooooo`?o000000?oooooo`000?l00000Eoooool001cooooo00?o0000ooooooooool0=Oooool2o`00
00oooooo0_l00008ooooo`;o00000_ooool2o`0001oooooo0_l00006ooooo`;o00003_oooolHo`00
00Cooooo0_l00008ooooo`;o00003Oooool>o`0000_ooooo0_l00003ooooo`;o00002Oooool4o`00
00Cooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`1Gooooo`;o00007?ooool3o`0000Go
oooo0ol00002ooooo`;o00002?ooool<o`000003ooooool0003o000000[o00000_ooool2o`0000Wo
oooo0ol0000;ooooo`;o000000?oooooo`000?l000001_l00004ooooo`;o00000_ooool2o`0000Ko
oooo0_l00003ooooo`;o00002Oooool2o`0000Kooooo0_l0001Dooooo`007?ooool00ol0003ooooo
ooooo`1?ooooo`;o00001_ooool2o`0001gooooo0_l00006ooooo`;o00000_ooool2o`0000Sooooo
0_l000001Ooooooo0000o`000?l0003ooooo00go00001oooool2o`0000Wooooo0ol0000;ooooo`;o
000000?oooooo`000?l000002?l00002ooooo`;o00000_ooool2o`0000Kooooo0_l00005ooooo`;o
00001oooool2o`000003ooooool0003o000000;o0000Eoooool001cooooo00?o0000ooooooooool0
Coooool2o`0000?ooooo0_l00004ooooo`;o00009_ooool2o`0000_ooooo0_l00004ooooo`Ko0000
00?oooooo`000?l000000_l00003ooooo`;o00002_ooool2o`000004ooooool0003o0000o`0000;o
oooo0_l000000ooooooo0000o`000002o`0000Kooooo2Ol0000Eooooo`;o00001oooool2o`000003
ooooool0003o000000;o0000Eoooool001cooooo00?o0000ooooooooool0=oooool2o`0001_ooooo
0_l00004ooooo`Co00007oooool3o`0000;ooooo0_l0000;ooooo`?o00000_ooool7o`000003oooo
ool0003o000000;o00000oooool2o`0000[ooooo0_l00006ooooo`;o000000?oooooo`000?l00000
0_l00002ooooo`;o00002Oooool2o`0001;ooooo0ol00005ooooo`;o00001oooool2o`0005Oooooo
000Looooo`03o`000?oooooooooo03Oooooo0_l0000Hooooo`;o00002Oooool2o`0001oooooo0ol0
000@ooooo`?o000000?oooooo`000?l000002ol00003ooooo`?o00006Oooool2o`0000Oooooo0_l0
000Dooooo`?o00001Oooool2o`00063ooooo000Looooo`03o`000?oooooooooo057ooooo0_l00003
ooooo`;o00009Oooool2o`0001;ooooo4Ol000000ooooooo0000o`000002o`0002;ooooo0_l0000A
ooooo`;o000000Coooooo`000?l0003o00001Oooool2o`0000Sooooo0_l0001Fooooo`007?ooool0
0ol0003oooooooooo`1Eooooo`?o00009Oooool2o`0000Kooooo0_l0000<ooooo`;o000000?ooooo
o`000?l000000ol000000ooooooo0000o`000004o`000003ooooool0003o000002Sooooo0_l00004
ooooo`;o00001Oooool4o`0000;ooooo0_l00002ooooo`Go00002?ooool2o`0005Kooooo000Loooo
o`03o`000?oooooooooo04kooooo0_l00005ooooo`;o00007Oooool2o`0000Gooooo1?l00006oooo
o`;o00000oooool2o`0000Oooooo0_l000000ooooooo0000o`000003o`0000;ooooo1Ol000000ooo
oooo0000o`000004ooooo`;o00008_ooool2o`0000Cooooo0_l000000ooooooo0000o`000004o`00
00Sooooo1Ol0001Pooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o00002?ooool2o`000003
ooooool0003o000001Oooooo0_l00005ooooo`;o00003Oooool3o`0000?ooooo0_l00004ooooo`;o
00001_ooool2o`0000Cooooo0_l00003ooooo`;o00000oooool2o`0000[ooooo0_l0000=ooooo`;o
00000oooool2o`0000;ooooo2_l0001]ooooo`007?ooool00ol0003oooooooooo`1Fooooo`Co0000
00?oooooo`000?l000007_ooool2o`0000kooooo0ol00002ooooo`;o00001?ooool2o`0000cooooo
0_l00008ooooo`;o00001Oooool2o`0000;ooooo0ol00004ooooo`;o000000?oooooo`000?l00000
1?ooool2o`000003ooooool0003o000000So00000_ooool2o`0000Kooooo0_l0001Wooooo`007?oo
ool00ol0003oooooooooo`1Fooooo`;o000000?oooooo`000?l000009?ooool4o`000003ooooool0
003o000000;ooooo0_l00002ooooo`;o00002?ooool2o`0001cooooo0ol00002ooooo`;o00001Ooo
ool2o`000003ooooool0003o000000Cooooo0_l000001Ooooooo0000o`000?l0003ooooo00Go0000
0_ooool4o`0000Gooooo0_l0001Wooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o00000_oo
ool2o`0000gooooo1Ol0000>ooooo`_o00005oooool2o`00017ooooo0_l00007ooooo`;o00001Ooo
ool2o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o00001?ooool4o`0006kooooo000L
ooooo`03o`000?oooooooooo05gooooo0_l00007ooooo`;o00001?ooool5o`0000Sooooo0ol00006
ooooo`;o00000_ooool2o`0001Wooooo0_l00006ooooo`;o00004_ooool5o`0000;ooooo0_l00004
ooooo`;o000000?oooooo`000?l00000N_ooool001cooooo0_l0001Iooooo`;o00003?ooool2o`00
00[ooooo0_l00005ooooo`?o00004Oooool2o`0000Kooooo0_l0000:ooooo`;o00001_ooool2o`00
00oooooo0_l00002ooooo`Ko000000?oooooo`000?l000005Oooool2o`0000cooooo0_l0001Moooo
o`007?ooool00ol0003oooooooooo`1Hooooo`;o00003?ooool2o`0000[ooooo0_l00004ooooo`;o
00002?ooool4o`0000Oooooo0_l00006ooooo`;o00002?ooool4o`0000Cooooo0ol0000@ooooo`;o
00000oooool5o`000003ooooool0003o000000kooooo0ol000001?oooooo0000o`000?ooool2o`00
00Oooooo0_l00003ooooo`;o0000GOooool001cooooo00?o0000ooooooooool0G?ooool2o`0001[o
oooo0_l00008ooooo`Co00000oooool2o`00017ooooo0_l000000ooooooo0000o`000005o`000004
ooooool0003o0000o`0000gooooo0_l000000ooooooo0000o`000003ooooo`Go00004Oooool:o`00
00Cooooo1ol0001Oooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00006?ooool2o`0000Oo
oooo1?l0000Gooooo`;o00000_ooool2o`0000?ooooo0ol00004ooooo`;o00002_ooool2o`000004
ooooool0003o0000ooooo`Co00003Oooool2o`0000;ooooo0_l000000ooooooo0000o`000003oooo
o`Co00005?ooool8o`0000Cooooo1ol0001Oooooo`007?ooool00ol0003oooooooooo`12ooooo`;o
00005?ooool2o`0000;ooooo0_l00007ooooo`Co00000oooool2o`0001;ooooo0_l00008ooooo`;o
00001?ooool4o`0000kooooo0_l0000?ooooo`Go00000_ooool2o`0000oooooo0_l000000ooooooo
0000o`000007ooooo`Oo0000Joooool001cooooo00?o0000ooooooooool0F?ooool2o`0001;ooooo
0_l0000:ooooo`;o00001_ooool2o`0000?ooooo0_l0000;ooooo`;o00005Oooool2o`0000;ooooo
0_l00004ooooo`Go00002oooool2o`0000Kooooo0_l000000ooooooo0000o`000007ooooo`Oo0000
Joooool001cooooo00?o0000ooooooooool0Goooool2o`0001Gooooo1?l00003ooooo`Ko00000_oo
ool2o`0000Gooooo0_l00005ooooo`;o00002Oooool2o`0000Oooooo1?l00002ooooo`;o00001?oo
ool2o`0000Cooooo0_l00008ooooo`;o00000oooool2o`0000Oooooo0ol00003ooooo`?o0000Kooo
ool001cooooo00?o0000ooooooooool0Goooool2o`0001Gooooo0_l00004ooooo`Wo00001oooool2
o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`;o00000oooool2o`0000Oooooo1?l0000=
ooooo`?o00003Oooool2o`0000Oooooo0ol0001eooooo`007?ooool00ol0003oooooooooo`1loooo
o`Co00000oooool2o`0000;ooooo0ol00006ooooo`;o00001?ooool2o`000003ooooool0003o0000
00gooooo0_l0000>ooooo`?o00001?ooool2o`0000;ooooo0_l0000:ooooo`;o00002_ooool2o`00
06cooooo000Looooo`03o`000?oooooooooo08Oooooo0ol0000<ooooo`Co00002Oooool4o`0001;o
oooo0_l00004ooooo`;o00000_ooool2o`0000[ooooo0_l0000:ooooo`;o0000K?ooool001cooooo
00?o0000ooooooooool0Ioooool4o`0001Oooooo1?l0000;ooooo`;o00001Oooool2o`0000Wooooo
1?l0000Jooooo`;o00000_ooool2o`000003ooooool0003o000007oooooo000Looooo`03o`000?oo
oooooooo06Oooooo1?l00007ooooo`;o00003_ooool5o`0000Kooooo0_l00002ooooo`;o00003ooo
ool3o`0001Oooooo0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o000000Sooooo0_l0
001eooooo`007?ooool00ol0003oooooooooo`1/ooooo`;o00001?ooool2o`00017ooooo0_l00000
0ooooooo0000o`000003ooooo`;o00003?ooool2o`0000Gooooo0ol00003ooooo`;o00000oooool2
o`0000gooooo0_l00007ooooo`Co00002Oooool2o`0007Gooooo000Looooo`03o`000?oooooooooo
06cooooo0_l0000Jooooo`;o00002oooool2o`0000Cooooo0_l0000;ooooo`;o00000oooool4o`00
0003ooooool0003o000000;ooooo1Ol00003ooooo`;o00001Oooool4o`0000[ooooo0_l0001doooo
o`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<00Kooooo00?o0000ooooooooool0COooool2o`0004Kooooo0_l000000ooooooo0000o`00
0007ooooo`;o00003?ooool2o`000003ooooool0003o000000Oo00000oooool2o`0000kooooo0_l0
0003ooooo`;o0000M?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo
00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo04gooooo0_l0000Sooooo`;o
00002oooool2o`0001Oooooo0_l00007ooooo`;o00001?ooool2o`0000Wooooo1?l000000ooooooo
0000o`000002o`0000?ooooo0_l00002ooooo`;o00002_ooool2o`0007Wooooo00000ooooooo410@
ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo07;ooooo0_l000000ooooooo0000o`000008ooooo`;o00006Oooool2o`0000Go
oooo0_l000001?oooooo0000o`000?ooool2o`0000Cooooo0_l00008ooooo`Co00001oooool2o`00
00;ooooo0_l00021ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05
oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`0007Gooooo0_l0000Hooooo`;o00002Oooool2o`00
00Oooooo0ol00003ooooo`;o00000_ooool2o`0001Oooooo0_l00021ooooo`0000?oooooo`000?oo
ool00_ooool00ol0003oooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0
003oooooooooo`2?ooooo`;o00003?ooool4o`0000;ooooo0_l00004ooooo`;o00001?ooool2o`00
00Kooooo0ol0000:ooooo`;o0000Poooool00003ooooool@413ooooo00;ooooo00?o410@oooooooo
ool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0N_ooool2o`00
00;ooooo0_l000000ooooooo0000o`000005ooooo`;o00003oooool2o`0000;ooooo1?l0000:oooo
o`;o00000_ooool2o`0000Kooooo0ol0000:ooooo`;o000000?oooooo`000?l00000P?ooool00006
oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o
0000ooooooooool0N_ooool2o`0000;ooooo1Ol00003ooooo`Co00002_ooool2o`0000?ooooo0_l0
00000ooooooo0000o`000005ooooo`;o00001_ooool2o`0000;ooooo0_l00002ooooo`;o00004_oo
ool2o`00083ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@06ooooo`03o`000?oooooooooo05Gooooo0_l0000Yooooo`;o00001?ooool2o`0000co
oooo1?l00002ooooo`Co00001?ooool3o`000003ooooool0003o000000_ooooo0_l0000;ooooo`?o
00000oooool2o`00087ooooo000Looooo`03o`000?oooooooooo05Gooooo0_l0000Qooooo`;o0000
0_ooool2o`0001Sooooo0_l000001?oooooo0000o`000?l00006ooooo`Ko000000?oooooo`000?l0
00005Oooool3o`0000?ooooo0_l00005ooooo`Co0000N?ooool001cooooo00?o0000ooooooooool0
N?ooool2o`0000;ooooo0_l0000Kooooo`;o00002Oooool2o`0000?ooooo0_l00004ooooo`;o0000
7?ooool4o`0007Sooooo000Looooo`03o`000?oooooooooo087ooooo0_l0000/ooooo`;o00002?oo
ool2o`0000Sooooo0_l00024ooooo`007?ooool00ol0003oooooooooo`21ooooo`;o00001?ooool2
o`00033ooooo0_l00008ooooo`;o0000Q?ooool001cooooo00?o0000ooooooooool0Qoooool2o`00
00;ooooo0_l0000Tooooo`Co0000U?ooool001cooooo00?o0000ooooooooool0Roooool2o`0000;o
oooo0_l0000Pooooo`Co0000U?ooool001cooooo00?o0000ooooooooool0G_ooool2o`0002_ooooo
0_l00002ooooo`;o00000oooool2o`000;?ooooo000Looooo`03o`000?oooooooooo05kooooo0_l0
000Rooooo`Co00003_ooool2o`0000;ooooo0_l0002_ooooo`007?ooool00ol0003oooooooooo`22
ooooo`Co00004_ooool2o`0000oooooo0_l0000Gooooo`;o0000QOooool001cooooo00?o0000oooo
ooooool0Hoooool2o`0004Cooooo0_l0000Gooooo`;o0000QOooool001cooooo00?o0000oooooooo
ool0Hoooool2o`00027ooooo0_l00031ooooo`007?ooool2o`0006Oooooo0_l0000Nooooo`;o0000
`Oooool001cooooo00?o0000ooooooooool0I_ooool2o`0000;ooooo0_l0003Mooooo`007?ooool0
0ol0003oooooooooo`1Zooooo`;o00009?ooool2o`000;Oooooo000Looooo`03o`000?oooooooooo
093ooooo0_l0002gooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo07?ooooo0_l0003Doooo
o`007?ooool00ol0003oooooooooo`1cooooo`;o0000e?ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0
003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Booooo`Co000000?o410@ooooooooool00ooo
ool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`?o0000oooooom:oooo
o`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?oooooo
D_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3o
oooooe;ooooo000Booooo`03oeEEEOmVIVKo00000?ooooooE?ooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00:Gooooo00Co410@o`000?l0003ooooo0_l000000ol@413ooooooooo
o`0Fooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01?l@413o0000odA4A?o<c<`6ooooo`;o
000000?o410@ooooooooool0S_ooool00:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko
00003Oooool00omgMgOo<S8booooo`03ooooo`03oiRHV?l@413ogMgM00Kooooo00?o0000oooooooo
ool0Soooool00:Kooooo00Go0000ooooooooooooooooo`00000Mooooo`03o`000?oooooooooo00?o
oooo00?oQhN7oeEEEOooool00_ooool5o`00093ooooo002Vooooo`05o`000?ooooooooooooooool0
00002Oooool6o`0000gooooo00WoMgMgoc8b<_ooooooooooolc<c?lQ8B7o0000oeEEEOl000000ooo
ool01?m4A4CogMgMooooool0002Aooooo`00Y_ooool01Ol0003oQhN7oooooonYZJWo000001Wooooo
00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05ob4Q8On7QhOooooooiRHV?l000000oooool01?oM
gMgoEEEEooooool0002Aooooo`00YOooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo
01Oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Cooooo00?oMgMg
olc<c?l00000TOooool00<Cooooo00?o0000ooooooooool01?ooool01OlQ8B7oV9RHoooooomgMgOo
EEEE00Cooooo00?ok^k^odA4A?l00000TOooool00<Cooooo1?l00003ooooo`05olc<c?l@413o0000
oc8b<_o^k^h01Oooool00omgMgOo0000ooooo`2@ooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(600) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.47451 .64961 Mdot
.43376 .68778 Mdot
.64253 .38081 Mdot
.36353 .46405 Mdot
.54559 .28827 Mdot
.60557 .38696 Mdot
.67376 .54208 Mdot
.66968 .49838 Mdot
.59761 .39308 Mdot
.22924 .61542 Mdot
.66999 .50743 Mdot
.42817 .54705 Mdot
.68137 .52909 Mdot
.39071 .48801 Mdot
.59505 .64658 Mdot
.35012 .54856 Mdot
.41783 .66682 Mdot
.49833 .31967 Mdot
.35421 .55106 Mdot
.6405 .39046 Mdot
.48091 .46628 Mdot
.38193 .49271 Mdot
.42072 .67057 Mdot
.38779 .49007 Mdot
.34015 .46058 Mdot
.43639 .67381 Mdot
.47947 .66302 Mdot
.34282 .49408 Mdot
.35514 .51654 Mdot
.68242 .51089 Mdot
.5756 .22518 Mdot
.58232 .83515 Mdot
.39925 .54616 Mdot
.37102 .63322 Mdot
.65798 .49818 Mdot
.79619 .41667 Mdot
.58599 .40202 Mdot
.68683 .50404 Mdot
.64102 .51244 Mdot
.63739 .51642 Mdot
.68551 .54766 Mdot
.4425 .68138 Mdot
.66832 .5587 Mdot
.55856 .34676 Mdot
.39407 .44978 Mdot
.53757 .79598 Mdot
.58411 .20191 Mdot
.34574 .4974 Mdot
.45763 .63677 Mdot
.63481 .38649 Mdot
.24836 .3638 Mdot
.70298 .51381 Mdot
.60316 .69454 Mdot
.13955 .65012 Mdot
.67973 .51489 Mdot
.35595 .47787 Mdot
.62275 .40135 Mdot
.37574 .4681 Mdot
.36036 .50214 Mdot
.35363 .59684 Mdot
.37495 .51508 Mdot
.51203 .29228 Mdot
.48487 .67513 Mdot
.63226 .4176 Mdot
.6024 .39435 Mdot
.70032 .53256 Mdot
.45191 .70711 Mdot
.68899 .53571 Mdot
.43483 .46242 Mdot
.63599 .37565 Mdot
.3484 .49415 Mdot
.67385 .50569 Mdot
.4334 .69689 Mdot
.3605 .43598 Mdot
.56718 .76027 Mdot
.68861 .47862 Mdot
.52105 .33514 Mdot
.35335 .71978 Mdot
.17815 .46965 Mdot
.68487 .37787 Mdot
.39926 .49514 Mdot
.16 .44106 Mdot
.60095 .63666 Mdot
.44505 .69762 Mdot
.40318 .61401 Mdot
.78096 .60186 Mdot
.35139 .51713 Mdot
.47856 .3871 Mdot
.34403 .52611 Mdot
.52198 .57739 Mdot
.59696 .39914 Mdot
.42911 .66683 Mdot
.39336 .44843 Mdot
.32784 .48554 Mdot
.24507 .52111 Mdot
.42529 .50872 Mdot
.38342 .45143 Mdot
.41963 .61237 Mdot
.65878 .51861 Mdot
.43507 .43715 Mdot
.57677 .32043 Mdot
.59712 .72334 Mdot
.36249 .45353 Mdot
.60306 .36595 Mdot
.47069 .63618 Mdot
.38211 .44503 Mdot
.69549 .524 Mdot
.38747 .50303 Mdot
.66288 .48477 Mdot
.42746 .64886 Mdot
.33117 .49573 Mdot
.52877 .30184 Mdot
.54664 .64524 Mdot
.46192 .65032 Mdot
.26827 .71113 Mdot
.37487 .51203 Mdot
.37066 .49838 Mdot
.44283 .69379 Mdot
.61973 .4137 Mdot
.50878 .42877 Mdot
.4218 .68197 Mdot
.63957 .51629 Mdot
.4343 .6374 Mdot
.32342 .49331 Mdot
.6251 .41186 Mdot
.5866 .72301 Mdot
.60348 .72403 Mdot
.46666 .22058 Mdot
.3514 .4382 Mdot
.56412 .67889 Mdot
.61256 .37569 Mdot
.44024 .68567 Mdot
.68963 .53026 Mdot
.38563 .52922 Mdot
.46816 .67598 Mdot
.64429 .51546 Mdot
.50178 .26973 Mdot
.54329 .27602 Mdot
.4749 .67032 Mdot
.32695 .38481 Mdot
.69256 .49803 Mdot
.63842 .52367 Mdot
.26167 .35514 Mdot
.45111 .69796 Mdot
.4861 .28402 Mdot
.65084 .5349 Mdot
.38569 .29812 Mdot
.3999 .52062 Mdot
.34056 .27003 Mdot
.18009 .37663 Mdot
.25415 .35971 Mdot
.44716 .7919 Mdot
.51192 .31111 Mdot
.65261 .53901 Mdot
.34889 .47244 Mdot
.45848 .67628 Mdot
.45728 .68368 Mdot
.32517 .46886 Mdot
.33224 .46803 Mdot
.4027 .47352 Mdot
.38189 .52673 Mdot
.73852 .3033 Mdot
.40647 .48119 Mdot
.6056 .58207 Mdot
.46781 .66738 Mdot
.34063 .45146 Mdot
.59004 .36508 Mdot
.3666 .42617 Mdot
.68561 .50385 Mdot
.36038 .49397 Mdot
.33497 .46908 Mdot
.42033 .46438 Mdot
.65817 .54949 Mdot
.67532 .74818 Mdot
.17566 .53719 Mdot
.78893 .4991 Mdot
.50874 .74251 Mdot
.61975 .38431 Mdot
.40446 .50221 Mdot
.49483 .30334 Mdot
.45992 .48778 Mdot
.3646 .50569 Mdot
.23388 .37593 Mdot
.33545 .48842 Mdot
.39024 .75739 Mdot
.38799 .39986 Mdot
.80299 .5772 Mdot
.63426 .60889 Mdot
.37141 .5187 Mdot
.2173 .54441 Mdot
.3674 .24343 Mdot
.52899 .20576 Mdot
.68829 .52049 Mdot
.58139 .36941 Mdot
.60408 .41329 Mdot
.6348 .52342 Mdot
.39117 .40845 Mdot
.23937 .63514 Mdot
.42871 .44756 Mdot
.58552 .71983 Mdot
.48259 .70905 Mdot
.5076 .31497 Mdot
.47528 .66767 Mdot
.14412 .48127 Mdot
.49149 .43472 Mdot
.65638 .45639 Mdot
.50884 .32313 Mdot
.61852 .35549 Mdot
.5807 .70586 Mdot
.48603 .29505 Mdot
.37659 .45639 Mdot
.43965 .63897 Mdot
.36348 .24472 Mdot
.31051 .50097 Mdot
.81088 .3288 Mdot
.4553 .7029 Mdot
.55002 .54087 Mdot
.68475 .52092 Mdot
.6155 .42259 Mdot
.35029 .51565 Mdot
.38985 .4701 Mdot
.48367 .66904 Mdot
.34787 .50353 Mdot
.49749 .51025 Mdot
.33572 .47595 Mdot
.59319 .42848 Mdot
.46218 .29554 Mdot
.63443 .49351 Mdot
.45821 .2247 Mdot
.4273 .69308 Mdot
.58646 .51975 Mdot
.59802 .36446 Mdot
.47086 .61324 Mdot
.68402 .50817 Mdot
.51105 .2735 Mdot
.58187 .38771 Mdot
.52147 .27321 Mdot
.38656 .43948 Mdot
.58918 .40161 Mdot
.50721 .2796 Mdot
.62888 .46287 Mdot
.38187 .45011 Mdot
.34533 .29329 Mdot
.65923 .54104 Mdot
.47816 .66271 Mdot
.37205 .51616 Mdot
.59159 .73082 Mdot
.32848 .44648 Mdot
.57148 .66544 Mdot
.57821 .71971 Mdot
.58883 .69228 Mdot
.67106 .44717 Mdot
.47991 .2895 Mdot
.5248 .76706 Mdot
.51913 .44933 Mdot
.41773 .66953 Mdot
.40796 .45922 Mdot
.72854 .72071 Mdot
.66084 .54423 Mdot
.37441 .45867 Mdot
.78388 .586 Mdot
.65209 .5366 Mdot
.37353 .47757 Mdot
.68347 .54969 Mdot
.45979 .68068 Mdot
.57369 .47528 Mdot
.42627 .63707 Mdot
.36436 .4672 Mdot
.66305 .53099 Mdot
.5788 .37824 Mdot
.43714 .67325 Mdot
.38269 .50403 Mdot
.40342 .49264 Mdot
.58411 .71308 Mdot
.33815 .45004 Mdot
.76177 .68553 Mdot
.34529 .49437 Mdot
.61962 .35499 Mdot
.42288 .51498 Mdot
.34273 .25321 Mdot
.53718 .26345 Mdot
.45756 .71078 Mdot
.57655 .7109 Mdot
.60226 .40484 Mdot
.58634 .45529 Mdot
.50436 .23225 Mdot
.39345 .49685 Mdot
.59903 .71327 Mdot
.55424 .53802 Mdot
.69957 .52595 Mdot
.37746 .53704 Mdot
.50389 .47156 Mdot
.58946 .389 Mdot
.58186 .71275 Mdot
.34277 .41552 Mdot
.45505 .62994 Mdot
.35416 .477 Mdot
.58188 .39564 Mdot
.45467 .63245 Mdot
.38359 .53067 Mdot
.68036 .26032 Mdot
.59447 .72953 Mdot
.66438 .54341 Mdot
.28209 .50293 Mdot
.41034 .48057 Mdot
.6031 .41514 Mdot
.46609 .68164 Mdot
.66988 .5168 Mdot
.44006 .6448 Mdot
.3972 .22313 Mdot
.5268 .70927 Mdot
.73678 .348 Mdot
.47931 .30645 Mdot
.43465 .82766 Mdot
.7946 .47583 Mdot
.53207 .6928 Mdot
.45311 .30711 Mdot
.82817 .49807 Mdot
.586 .37299 Mdot
.25188 .44434 Mdot
.61247 .40631 Mdot
.35503 .4622 Mdot
.60353 .38867 Mdot
.78736 .66101 Mdot
.33909 .48986 Mdot
.6231 .38975 Mdot
.72381 .30632 Mdot
.33587 .49544 Mdot
.46919 .66416 Mdot
.58363 .81646 Mdot
.30205 .73511 Mdot
.40201 .37939 Mdot
.62591 .39154 Mdot
.23166 .46987 Mdot
.34474 .50504 Mdot
.32713 .53209 Mdot
.45276 .67363 Mdot
.33298 .5163 Mdot
.52145 .31243 Mdot
.52926 .28562 Mdot
.26334 .36786 Mdot
.33487 .76145 Mdot
.29799 .50388 Mdot
.4431 .67715 Mdot
.17905 .45781 Mdot
.56981 .76342 Mdot
.60426 .72721 Mdot
.64673 .50419 Mdot
.6735 .74652 Mdot
.32203 .42522 Mdot
.29418 .416 Mdot
.50975 .52446 Mdot
.42702 .66965 Mdot
.76901 .4242 Mdot
.66884 .52224 Mdot
.20251 .54216 Mdot
.27079 .64557 Mdot
.40141 .46787 Mdot
.70198 .5467 Mdot
.44571 .48609 Mdot
.50351 .52182 Mdot
.33983 .28612 Mdot
.69218 .33885 Mdot
.37156 .45566 Mdot
.53342 .76843 Mdot
.36499 .50066 Mdot
.36477 .2506 Mdot
.36845 .46407 Mdot
.44583 .64477 Mdot
.29982 .43777 Mdot
.52681 .40863 Mdot
.19499 .6043 Mdot
.49291 .44292 Mdot
.48504 .30126 Mdot
.39117 .48405 Mdot
.39537 .46622 Mdot
.51461 .28782 Mdot
.43583 .65908 Mdot
.41522 .47375 Mdot
.58932 .20012 Mdot
.40712 .47515 Mdot
.70174 .51424 Mdot
.56047 .4582 Mdot
.39323 .77058 Mdot
.33966 .50849 Mdot
.46097 .63229 Mdot
.697 .53417 Mdot
.65398 .5041 Mdot
.29543 .47659 Mdot
.66487 .54772 Mdot
.34842 .48086 Mdot
.56174 .46209 Mdot
.42097 .66427 Mdot
.45383 .49366 Mdot
.43995 .65617 Mdot
.20145 .40351 Mdot
.66564 .5537 Mdot
.60101 .70456 Mdot
.25769 .43143 Mdot
.67184 .53452 Mdot
.45224 .58042 Mdot
.33444 .40927 Mdot
.38106 .42304 Mdot
.51341 .71099 Mdot
.57687 .39867 Mdot
.59173 .69745 Mdot
.67581 .51367 Mdot
.40644 .47711 Mdot
.3745 .44421 Mdot
.70721 .53295 Mdot
.29733 .56525 Mdot
.58116 .22895 Mdot
.36366 .47204 Mdot
.4414 .64755 Mdot
.44034 .68417 Mdot
.41208 .50849 Mdot
.36692 .50804 Mdot
.60599 .35343 Mdot
.60002 .71218 Mdot
.58185 .69698 Mdot
.60479 .71844 Mdot
.5727 .40246 Mdot
.40819 .82086 Mdot
.63869 .52413 Mdot
.48278 .81781 Mdot
.74507 .64787 Mdot
.29988 .49527 Mdot
.58984 .40994 Mdot
.38137 .47485 Mdot
.363 .44857 Mdot
.66149 .5268 Mdot
.31833 .76636 Mdot
.42314 .53806 Mdot
.47807 .67958 Mdot
.70502 .52198 Mdot
.44987 .52452 Mdot
.70933 .49329 Mdot
.52517 .29686 Mdot
.47664 .42406 Mdot
.70394 .54558 Mdot
.43565 .64364 Mdot
.70715 .54006 Mdot
.39812 .46812 Mdot
.36995 .41673 Mdot
.42574 .675 Mdot
.47852 .27803 Mdot
.39219 .44483 Mdot
.37228 .47989 Mdot
.39132 .19608 Mdot
.56325 .76082 Mdot
.65728 .42266 Mdot
.34911 .4562 Mdot
.41485 .44556 Mdot
.478 .27258 Mdot
.41253 .47839 Mdot
.35895 .51989 Mdot
.54561 .63546 Mdot
.63774 .49319 Mdot
.53466 .31731 Mdot
.19652 .55427 Mdot
.4626 .70085 Mdot
.77243 .6634 Mdot
.59514 .72504 Mdot
.64338 .48566 Mdot
.57498 .48073 Mdot
.58977 .70081 Mdot
.7668 .59178 Mdot
.78029 .52024 Mdot
.59871 .70475 Mdot
.65033 .39469 Mdot
.45578 .4375 Mdot
.37129 .52912 Mdot
.36373 .48825 Mdot
.48111 .28412 Mdot
.46111 .69389 Mdot
.61331 .59556 Mdot
.62372 .51169 Mdot
.37753 .49538 Mdot
.40978 .6585 Mdot
.79198 .58907 Mdot
.58249 .70678 Mdot
.50346 .30797 Mdot
.47939 .29916 Mdot
.3667 .49872 Mdot
.5158 .62155 Mdot
.44023 .67709 Mdot
.38267 .50388 Mdot
.39419 .52022 Mdot
.62489 .40685 Mdot
.4465 .63867 Mdot
.60069 .36153 Mdot
.5775 .72105 Mdot
.83257 .42831 Mdot
.41446 .18147 Mdot
.65341 .52921 Mdot
.78642 .46102 Mdot
.71125 .54866 Mdot
.70093 .36051 Mdot
.60083 .70969 Mdot
.38156 .4996 Mdot
.4308 .70047 Mdot
.38576 .5043 Mdot
.40526 .46487 Mdot
.39422 .45423 Mdot
.30081 .51142 Mdot
.23878 .36736 Mdot
.50153 .301 Mdot
.43552 .48733 Mdot
.59714 .35056 Mdot
.7984 .5782 Mdot
.61585 .79255 Mdot
.39401 .47764 Mdot
.3713 .49545 Mdot
.46375 .70447 Mdot
.37851 .43502 Mdot
.69405 .51761 Mdot
.45262 .70066 Mdot
.36825 .45022 Mdot
.55476 .28304 Mdot
.41579 .48675 Mdot
.79035 .45168 Mdot
.70725 .54089 Mdot
.47108 .42181 Mdot
.4052 .43239 Mdot
.60088 .70658 Mdot
.59241 .69807 Mdot
.59226 .73342 Mdot
.70321 .53697 Mdot
.62186 .40848 Mdot
.61179 .34027 Mdot
.35307 .41222 Mdot
.3472 .47473 Mdot
.38621 .42326 Mdot
.56727 .39373 Mdot
.51996 .429 Mdot
.47496 .77827 Mdot
.38011 .39831 Mdot
.57471 .37139 Mdot
.40811 .63755 Mdot
.21514 .65837 Mdot
.46285 .69723 Mdot
.48688 .32716 Mdot
.68061 .50388 Mdot
.52452 .30812 Mdot
.22232 .41136 Mdot
.42256 .66556 Mdot
.48272 .67302 Mdot
.62182 .38626 Mdot
.56975 .58077 Mdot
.23013 .77425 Mdot
.60674 .3689 Mdot
.4549 .29295 Mdot
.44836 .67363 Mdot
.41215 .54461 Mdot
.55688 .53925 Mdot
.55732 .57719 Mdot
.61725 .39629 Mdot
.40124 .49537 Mdot
.46237 .58278 Mdot
.60736 .35378 Mdot
.38865 .53883 Mdot
.62704 .38796 Mdot
.67222 .55175 Mdot
.61594 .37503 Mdot
.41944 .70123 Mdot
.38153 .4391 Mdot
.15825 .68448 Mdot
.59794 .62815 Mdot
.38153 .51222 Mdot
.70599 .52185 Mdot
.70541 .26626 Mdot
.3931 .46017 Mdot
.51868 .31644 Mdot
.5723 .37247 Mdot
.67969 .29215 Mdot
.35388 .512 Mdot
.61016 .39283 Mdot
.44048 .71959 Mdot
.58507 .32959 Mdot
.66989 .37522 Mdot
.58564 .69618 Mdot
.46227 .67832 Mdot
.56577 .69027 Mdot
.65455 .4984 Mdot
.40781 .45239 Mdot
.40531 .50763 Mdot
.46067 .65476 Mdot
.72198 .49681 Mdot
.42394 .52322 Mdot
.39916 .49487 Mdot
.60899 .35585 Mdot
.57808 .35544 Mdot
.62744 .67165 Mdot
.58665 .36963 Mdot
.41771 .44898 Mdot
.4584 .65138 Mdot
.35667 .46658 Mdot
.47168 .67159 Mdot
.40504 .45609 Mdot
.4652 .75572 Mdot
.46283 .69584 Mdot
.51661 .67271 Mdot
.33218 .45452 Mdot
.32972 .55546 Mdot
.40863 .46808 Mdot
.37973 .45335 Mdot
.56924 .37926 Mdot
.49691 .28865 Mdot
.37277 .54117 Mdot
.58803 .49749 Mdot
.49056 .26375 Mdot
.38338 .69891 Mdot
.61912 .41332 Mdot
.48726 .2701 Mdot
.344 .32834 Mdot
.57662 .71053 Mdot
.50936 .29682 Mdot
.64055 .72009 Mdot
.65512 .52994 Mdot
.41963 .6524 Mdot
.33281 .48758 Mdot
.83596 .48401 Mdot
.57582 .22579 Mdot
.58669 .71071 Mdot
.37127 .51395 Mdot
.38184 .47003 Mdot
.44753 .62926 Mdot
.15235 .46207 Mdot
.60779 .42805 Mdot
.36973 .45397 Mdot
.4224 .68003 Mdot
.17483 .40475 Mdot
.62674 .38085 Mdot
.51036 .30266 Mdot
.70095 .55412 Mdot
.48758 .71311 Mdot
.59041 .69529 Mdot
.66678 .55475 Mdot
.62444 .44181 Mdot
.21774 .39182 Mdot
.35356 .51013 Mdot
.5781 .39685 Mdot
.25273 .36058 Mdot
.40603 .40887 Mdot
.70796 .56044 Mdot
.45349 .74946 Mdot
.42795 .67033 Mdot
.7068 .53008 Mdot
.48503 .30261 Mdot
.4202 .6591 Mdot
.43501 .65841 Mdot
.66844 .49868 Mdot
.65168 .59788 Mdot
.55199 .54477 Mdot
.69468 .51024 Mdot
.54647 .60067 Mdot
.26906 .35031 Mdot
.60129 .71589 Mdot
.50349 .3085 Mdot
.40277 .21437 Mdot
.43991 .67937 Mdot
.67439 .74641 Mdot
.23903 .37142 Mdot
.38296 .45151 Mdot
.49549 .27623 Mdot
.76953 .6093 Mdot
.62103 .50878 Mdot
.64481 .51808 Mdot
.49714 .39876 Mdot
.50287 .31582 Mdot
.40722 .51061 Mdot
.38427 .76705 Mdot
.33017 .48523 Mdot
.6554 .54103 Mdot
.49927 .53357 Mdot
.44986 .63971 Mdot
.65143 .49871 Mdot
.49733 .49885 Mdot
.36037 .44985 Mdot
.38299 .51814 Mdot
.41405 .2369 Mdot
.44578 .63715 Mdot
.59193 .69462 Mdot
.39289 .50251 Mdot
.37368 .46996 Mdot
.4174 .46405 Mdot
.26485 .41845 Mdot
.53213 .65619 Mdot
.37227 .45101 Mdot
.59608 .42269 Mdot
.37243 .42216 Mdot
.3708 .5208 Mdot
.43203 .63042 Mdot
.31899 .26797 Mdot
.57883 .72405 Mdot
.36492 .48387 Mdot
.36382 .47284 Mdot
.64029 .50992 Mdot
.55336 .54179 Mdot
.55633 .58048 Mdot
.62739 .36508 Mdot
.44606 .31672 Mdot
.41915 .43589 Mdot
.465 .67111 Mdot
.52688 .3098 Mdot
.41551 .45271 Mdot
.46812 .69577 Mdot
.39034 .41342 Mdot
.60764 .35175 Mdot
.59787 .71102 Mdot
.29561 .42356 Mdot
.50818 .29182 Mdot
.67614 .48906 Mdot
.51734 .82579 Mdot
.59042 .36224 Mdot
.34261 .46895 Mdot
.57096 .34513 Mdot
.59492 .37512 Mdot
.58585 .7147 Mdot
.31817 .45055 Mdot
.45458 .68189 Mdot
.44501 .64082 Mdot
.30032 .31844 Mdot
.58029 .418 Mdot
.27307 .26478 Mdot
.67106 .55152 Mdot
.37004 .53394 Mdot
.61257 .78018 Mdot
.4537 .64198 Mdot
.4064 .22641 Mdot
.48555 .27059 Mdot
.64506 .51807 Mdot
.57405 .69948 Mdot
.46951 .6923 Mdot
.46327 .64578 Mdot
.39639 .45171 Mdot
.38702 .48103 Mdot
.45002 .29074 Mdot
.35362 .25762 Mdot
.68259 .54952 Mdot
.51452 .30471 Mdot
.63204 .37346 Mdot
.35446 .45525 Mdot
.4326 .68888 Mdot
.37856 .75248 Mdot
.40995 .48503 Mdot
.6112 .35352 Mdot
.42953 .677 Mdot
.51857 .29616 Mdot
.5022 .27242 Mdot
.38272 .45249 Mdot
.36542 .69675 Mdot
.6738 .5375 Mdot
.46482 .65547 Mdot
.41611 .60536 Mdot
.42589 .51189 Mdot
.39126 .48031 Mdot
.43991 .53149 Mdot
.65542 .5501 Mdot
.30043 .41817 Mdot
.47182 .28116 Mdot
.45668 .68959 Mdot
.38568 .50883 Mdot
.51214 .2927 Mdot
.2723 .4372 Mdot
.59348 .70438 Mdot
.62578 .38337 Mdot
.51807 .31517 Mdot
.49904 .28113 Mdot
.50009 .26487 Mdot
.66513 .75079 Mdot
.46653 .6313 Mdot
.18937 .5505 Mdot
.40178 .45716 Mdot
.2751 .34658 Mdot
.3508 .43466 Mdot
.68659 .55205 Mdot
.57815 .37441 Mdot
.4044 .46664 Mdot
.398 .45242 Mdot
.40612 .76845 Mdot
.42843 .56364 Mdot
.47788 .46743 Mdot
.43237 .64293 Mdot
.27879 .50825 Mdot
.59863 .41555 Mdot
.17374 .36928 Mdot
.65784 .79598 Mdot
.43067 .4538 Mdot
.571 .57333 Mdot
.45021 .69999 Mdot
.64483 .52598 Mdot
.54747 .57068 Mdot
.63348 .48451 Mdot
.45185 .69228 Mdot
.35606 .45797 Mdot
.48739 .81492 Mdot
.51531 .26964 Mdot
.40172 .47433 Mdot
.69197 .52855 Mdot
.4022 .47396 Mdot
.6989 .54377 Mdot
.49816 .68932 Mdot
.56635 .60088 Mdot
.33634 .48964 Mdot
.43032 .49829 Mdot
.3314 .39904 Mdot
.39171 .47789 Mdot
.714 .45141 Mdot
.44239 .66325 Mdot
.50997 .65876 Mdot
.41584 .50428 Mdot
.34782 .67647 Mdot
.41148 .49813 Mdot
.73366 .50919 Mdot
.40004 .51224 Mdot
.38964 .36622 Mdot
.40431 .51526 Mdot
.40344 .50417 Mdot
.66597 .52351 Mdot
.64067 .51574 Mdot
.44634 .72014 Mdot
.5984 .69787 Mdot
.80219 .57707 Mdot
.37232 .4871 Mdot
.5679 .3773 Mdot
.6277 .7235 Mdot
.49656 .28398 Mdot
.4506 .6896 Mdot
.24429 .25664 Mdot
.69348 .54205 Mdot
.63532 .4157 Mdot
.68383 .42963 Mdot
.62664 .41684 Mdot
.57953 .42652 Mdot
.36012 .5707 Mdot
.51353 .30846 Mdot
.40868 .50594 Mdot
.37064 .66062 Mdot
.54724 .76661 Mdot
.39772 .53468 Mdot
.59423 .33699 Mdot
.44681 .53838 Mdot
.26975 .34643 Mdot
.51357 .26438 Mdot
.50681 .31313 Mdot
.67304 .51616 Mdot
.6432 .39293 Mdot
.42721 .42918 Mdot
.48894 .26936 Mdot
.5817 .36759 Mdot
.60904 .71592 Mdot
.47414 .23769 Mdot
.44382 .68056 Mdot
.38856 .37942 Mdot
.57248 .79258 Mdot
.6889 .54586 Mdot
.58618 .49098 Mdot
.43404 .61858 Mdot
.49096 .68538 Mdot
.60435 .70647 Mdot
.58969 .35224 Mdot
.41681 .66806 Mdot
.38785 .44321 Mdot
.30996 .49901 Mdot
.36653 .5014 Mdot
.48663 .27488 Mdot
.38624 .52248 Mdot
.59073 .35432 Mdot
.67829 .54526 Mdot
.59462 .3975 Mdot
.67127 .53977 Mdot
.47721 .80089 Mdot
.3629 .50932 Mdot
.38926 .48329 Mdot
.56317 .47884 Mdot
.47199 .65804 Mdot
.3584 .61226 Mdot
.58861 .35191 Mdot
.62036 .40435 Mdot
.35789 .46372 Mdot
.46822 .70935 Mdot
.52344 .32612 Mdot
.56461 .54388 Mdot
.39881 .51514 Mdot
.44343 .6629 Mdot
.3563 .47179 Mdot
.70056 .32554 Mdot
.57842 .62519 Mdot
.44262 .64314 Mdot
.19658 .61346 Mdot
.34067 .44639 Mdot
.44703 .54586 Mdot
.377 .55746 Mdot
.43787 .34593 Mdot
.39068 .54186 Mdot
.45123 .70269 Mdot
.35957 .49765 Mdot
.46141 .67053 Mdot
.59171 .37278 Mdot
.64249 .53004 Mdot
.45836 .673 Mdot
.32743 .47657 Mdot
.63136 .80802 Mdot
.69183 .53963 Mdot
.3993 .48625 Mdot
.67081 .50977 Mdot
.41743 .65004 Mdot
.46783 .64566 Mdot
.64234 .69545 Mdot
.66103 .4519 Mdot
.69448 .53326 Mdot
.34719 .47859 Mdot
.60569 .76008 Mdot
.35622 .46735 Mdot
.44715 .28123 Mdot
.41053 .51749 Mdot
.41881 .52166 Mdot
.44919 .83285 Mdot
.64735 .46645 Mdot
.25615 .26711 Mdot
.6357 .55223 Mdot
.65577 .75735 Mdot
.47608 .6293 Mdot
.51439 .26484 Mdot
.78133 .46584 Mdot
.58101 .7238 Mdot
.59784 .42108 Mdot
.40521 .46766 Mdot
.43757 .768 Mdot
.70047 .51553 Mdot
.49423 .29208 Mdot
.33573 .48848 Mdot
.63564 .36278 Mdot
.63566 .73939 Mdot
.65056 .53606 Mdot
.44413 .68268 Mdot
.47525 .66441 Mdot
.17424 .49005 Mdot
.38201 .51021 Mdot
.38398 .48762 Mdot
.68423 .5042 Mdot
.41426 .41735 Mdot
.51391 .2721 Mdot
.7246 .32464 Mdot
.69104 .52381 Mdot
.5903 .63469 Mdot
.4292 .64567 Mdot
.38188 .47186 Mdot
.559 .45513 Mdot
.69954 .69313 Mdot
.23158 .5651 Mdot
.48298 .29126 Mdot
.42883 .26568 Mdot
.4517 .70278 Mdot
.6897 .52797 Mdot
.28836 .35178 Mdot
.32464 .48417 Mdot
.38002 .46875 Mdot
.42558 .25516 Mdot
.56217 .54988 Mdot
.48411 .2454 Mdot
.3993 .55323 Mdot
.54907 .51727 Mdot
.35846 .46158 Mdot
.374 .44419 Mdot
.43333 .45725 Mdot
.36873 .52272 Mdot
.44945 .66339 Mdot
.31714 .73695 Mdot
.60921 .38324 Mdot
.22764 .50706 Mdot
.49123 .38568 Mdot
.3459 .51009 Mdot
.35836 .45394 Mdot
.27036 .69587 Mdot
.61536 .69475 Mdot
.44183 .66728 Mdot
.42129 .60449 Mdot
.63667 .52047 Mdot
.4263 .56479 Mdot
.57613 .41235 Mdot
.47379 .47288 Mdot
.5953 .38535 Mdot
.44403 .66187 Mdot
.61652 .41083 Mdot
.63784 .50087 Mdot
.57815 .39652 Mdot
.57561 .40801 Mdot
.67543 .55905 Mdot
.44774 .63443 Mdot
.40717 .49791 Mdot
.66795 .55377 Mdot
.423 .22858 Mdot
.48736 .27431 Mdot
.6414 .69799 Mdot
.41506 .54359 Mdot
.45132 .54281 Mdot
.67883 .25951 Mdot
.59582 .40581 Mdot
.55928 .64728 Mdot
.46303 .69545 Mdot
.52515 .31803 Mdot
.45422 .66514 Mdot
.2274 .43576 Mdot
.50842 .28451 Mdot
.64175 .70188 Mdot
.30332 .33964 Mdot
.61241 .47394 Mdot
.33373 .44086 Mdot
.5113 .69751 Mdot
.59331 .38532 Mdot
.70239 .51464 Mdot
.77816 .59694 Mdot
.35384 .43936 Mdot
.53445 .70799 Mdot
.48804 .65547 Mdot
.57739 .70512 Mdot
.68906 .53188 Mdot
.67697 .57577 Mdot
.37799 .51034 Mdot
.6063 .47076 Mdot
.41085 .52625 Mdot
.25419 .43651 Mdot
.44531 .30373 Mdot
.45966 .74291 Mdot
.35305 .47888 Mdot
.61744 .35872 Mdot
.35416 .47417 Mdot
.4095 .39687 Mdot
.25983 .36024 Mdot
.43313 .48282 Mdot
.52325 .70567 Mdot
.67979 .28276 Mdot
.42823 .68038 Mdot
.42375 .45695 Mdot
.59425 .71663 Mdot
.34744 .45102 Mdot
.86915 .4643 Mdot
.50631 .29555 Mdot
.64218 .4337 Mdot
.32666 .46769 Mdot
.38979 .50323 Mdot
.37704 .72891 Mdot
.50505 .66455 Mdot
.57367 .70584 Mdot
.38082 .46346 Mdot
.42397 .28464 Mdot
.66729 .51778 Mdot
.38668 .5307 Mdot
.36198 .49498 Mdot
.4455 .19291 Mdot
.66571 .51605 Mdot
.59376 .40798 Mdot
.57699 .7145 Mdot
.62891 .37019 Mdot
.52727 .27556 Mdot
.5345 .57263 Mdot
.38814 .23475 Mdot
.57839 .6278 Mdot
.51111 .31909 Mdot
.35164 .51999 Mdot
.40348 .62338 Mdot
.39131 .51115 Mdot
.50073 .31165 Mdot
.68199 .5106 Mdot
.44988 .66623 Mdot
.34898 .37979 Mdot
.58622 .71958 Mdot
.40157 .5349 Mdot
.49969 .25908 Mdot
.4565 .67716 Mdot
.662 .66939 Mdot
.45434 .69583 Mdot
.66927 .53183 Mdot
.63436 .51395 Mdot
.50354 .28599 Mdot
.45187 .66338 Mdot
.63107 .39098 Mdot
.64144 .55768 Mdot
.41083 .52034 Mdot
.62613 .52332 Mdot
.43558 .712 Mdot
.48026 .6658 Mdot
.43857 .70699 Mdot
.35992 .51072 Mdot
.56466 .55919 Mdot
.32467 .45773 Mdot
.6972 .528 Mdot
.61728 .41681 Mdot
.33391 .27801 Mdot
.36726 .66132 Mdot
.59062 .63255 Mdot
.37755 .54204 Mdot
.37927 .52051 Mdot
.367 .49876 Mdot
.35808 .47928 Mdot
.72609 .33229 Mdot
.36247 .50828 Mdot
.66429 .5351 Mdot
.60026 .37712 Mdot
.3741 .51433 Mdot
.59666 .71572 Mdot
.51828 .4428 Mdot
.52593 .31061 Mdot
.4132 .36416 Mdot
.66266 .77863 Mdot
.4552 .67579 Mdot
.57965 .38605 Mdot
.62729 .40805 Mdot
.50207 .2698 Mdot
.66295 .55032 Mdot
.4603 .69335 Mdot
.39739 .34659 Mdot
.49051 .26252 Mdot
.3653 .48254 Mdot
.56271 .46742 Mdot
.20387 .63321 Mdot
.34483 .51648 Mdot
.39018 .45463 Mdot
.58377 .69339 Mdot
.62385 .42093 Mdot
.85223 .52768 Mdot
.63608 .60035 Mdot
.49865 .28788 Mdot
.52177 .29744 Mdot
.4394 .7036 Mdot
.37833 .53594 Mdot
.67687 .53984 Mdot
.5529 .52769 Mdot
.6787 .24773 Mdot
.7787 .63205 Mdot
.70072 .36732 Mdot
.41586 .48412 Mdot
.32439 .71739 Mdot
.42311 .48115 Mdot
.47 .6354 Mdot
.45068 .70918 Mdot
.44193 .67239 Mdot
.6675 .52296 Mdot
.20345 .40649 Mdot
.66411 .53698 Mdot
.66357 .77973 Mdot
.4242 .68 Mdot
.54998 .4194 Mdot
.62406 .40009 Mdot
.33145 .42912 Mdot
.5114 .30904 Mdot
.61351 .33001 Mdot
.41811 .44698 Mdot
.51341 .62522 Mdot
.58992 .40991 Mdot
.46652 .64151 Mdot
.34474 .40653 Mdot
.80999 .56372 Mdot
.57057 .58632 Mdot
.6033 .21253 Mdot
.26329 .51223 Mdot
.51379 .28747 Mdot
.21824 .58785 Mdot
.5119 .26913 Mdot
.64558 .52359 Mdot
.35274 .43898 Mdot
.33131 .45308 Mdot
.36885 .45695 Mdot
.35727 .50676 Mdot
.67602 .51293 Mdot
.42096 .49651 Mdot
.34063 .2553 Mdot
.59856 .72671 Mdot
.54578 .40009 Mdot
.5127 .27874 Mdot
.68928 .55385 Mdot
.59751 .37504 Mdot
.60223 .70113 Mdot
.45518 .22371 Mdot
.42017 .48784 Mdot
.40761 .46838 Mdot
.60487 .72385 Mdot
.40458 .41311 Mdot
.323 .4252 Mdot
.60811 .38786 Mdot
.51332 .50185 Mdot
.48366 .30332 Mdot
.52476 .30688 Mdot
.70614 .54073 Mdot
.45415 .66484 Mdot
.48137 .27811 Mdot
.64351 .3858 Mdot
.3812 .53091 Mdot
.43164 .49508 Mdot
.43547 .71221 Mdot
.23913 .37109 Mdot
.53315 .29138 Mdot
.35589 .39649 Mdot
.46751 .68438 Mdot
.48308 .64555 Mdot
.38283 .46306 Mdot
.35738 .54324 Mdot
.47943 .65247 Mdot
.51969 .2837 Mdot
.68988 .55484 Mdot
.56754 .44583 Mdot
.67005 .54705 Mdot
.46245 .68421 Mdot
.34432 .42624 Mdot
.43893 .637 Mdot
.34103 .44759 Mdot
.11412 .44618 Mdot
.37774 .5231 Mdot
.46106 .60351 Mdot
.45079 .34585 Mdot
.62759 .38505 Mdot
.62772 .37759 Mdot
.59753 .71282 Mdot
.46452 .69796 Mdot
.40849 .44558 Mdot
.51965 .30594 Mdot
.64915 .75887 Mdot
.421 .72016 Mdot
.57206 .39139 Mdot
.60123 .42675 Mdot
.682 .51167 Mdot
.40747 .50618 Mdot
.37975 .47737 Mdot
.58038 .39963 Mdot
.71203 .27841 Mdot
.45985 .66305 Mdot
.38407 .4879 Mdot
.36911 .52117 Mdot
.60742 .38057 Mdot
.6495 .5667 Mdot
.45464 .61502 Mdot
.37024 .52255 Mdot
.3176 .32651 Mdot
.6974 .54331 Mdot
.34437 .48837 Mdot
.42211 .48859 Mdot
.49176 .28289 Mdot
.54516 .26943 Mdot
.26551 .3528 Mdot
.66419 .55533 Mdot
.58633 .69517 Mdot
.35156 .43658 Mdot
.62348 .39546 Mdot
.41526 .54155 Mdot
.80263 .44946 Mdot
.5902 .72651 Mdot
.37651 .50409 Mdot
.41253 .43027 Mdot
.47093 .66372 Mdot
.38107 .50346 Mdot
.4618 .75308 Mdot
.61557 .36196 Mdot
.37597 .5051 Mdot
.3636 .68834 Mdot
.68432 .51331 Mdot
.41473 .4432 Mdot
.51965 .31129 Mdot
.45559 .34911 Mdot
.54373 .81449 Mdot
.56576 .38366 Mdot
.50314 .27371 Mdot
.38818 .52226 Mdot
.62035 .35686 Mdot
.70137 .55418 Mdot
.52207 .65937 Mdot
.3581 .52582 Mdot
.67446 .54921 Mdot
.68284 .54417 Mdot
.50271 .28937 Mdot
.22182 .29595 Mdot
.41411 .43093 Mdot
.39848 .47963 Mdot
.63557 .20315 Mdot
.4276 .62771 Mdot
.40213 .48289 Mdot
.40724 .50513 Mdot
.65898 .54019 Mdot
.27941 .38154 Mdot
.4763 .51781 Mdot
.72419 .3065 Mdot
.69706 .54566 Mdot
.64761 .36571 Mdot
.60319 .35846 Mdot
.50686 .2758 Mdot
.43088 .68221 Mdot
.49601 .31446 Mdot
.61691 .37976 Mdot
.37817 .45379 Mdot
.65135 .51207 Mdot
.26638 .56845 Mdot
.70511 .51649 Mdot
.6321 .36139 Mdot
.48314 .65259 Mdot
.59167 .80093 Mdot
.71501 .23113 Mdot
.55636 .79485 Mdot
.66431 .55699 Mdot
.49623 .28391 Mdot
.61903 .59318 Mdot
.38143 .51983 Mdot
.20349 .57182 Mdot
.40093 .47724 Mdot
.24705 .48689 Mdot
.57886 .37206 Mdot
.60687 .71246 Mdot
.35548 .43876 Mdot
.42797 .27176 Mdot
.66992 .55727 Mdot
.69284 .51743 Mdot
.36068 .48317 Mdot
.67006 .53397 Mdot
.38011 .48366 Mdot
.60474 .37531 Mdot
.22691 .2945 Mdot
.39844 .51075 Mdot
.4029 .43765 Mdot
.63905 .49024 Mdot
.64122 .69965 Mdot
.63237 .35119 Mdot
.33362 .72231 Mdot
.81785 .55698 Mdot
.67389 .53445 Mdot
.32533 .53874 Mdot
.58683 .40026 Mdot
.58835 .69216 Mdot
.60454 .4364 Mdot
.39504 .47013 Mdot
.41497 .47632 Mdot
.36244 .46001 Mdot
.37836 .51941 Mdot
.20888 .58999 Mdot
.33007 .42299 Mdot
.28987 .6572 Mdot
.40616 .46524 Mdot
.44346 .59559 Mdot
.66172 .5305 Mdot
.45837 .53222 Mdot
.49185 .24493 Mdot
.41687 .47812 Mdot
.50209 .65473 Mdot
.68319 .55447 Mdot
.67638 .76157 Mdot
.67095 .51301 Mdot
.60026 .40247 Mdot
.64407 .50961 Mdot
.33687 .45091 Mdot
.43877 .68235 Mdot
.60636 .36455 Mdot
.47899 .77956 Mdot
.59407 .41796 Mdot
.38131 .51211 Mdot
.61581 .51148 Mdot
.62856 .39035 Mdot
.44961 .37799 Mdot
.43786 .68387 Mdot
.41319 .28006 Mdot
.43207 .62444 Mdot
.38522 .49899 Mdot
.39092 .49478 Mdot
.60385 .70147 Mdot
.65151 .53772 Mdot
.41931 .67087 Mdot
.38563 .1996 Mdot
.48817 .2573 Mdot
.4346 .66743 Mdot
.33667 .53179 Mdot
.57187 .56709 Mdot
.4595 .6487 Mdot
.43124 .32113 Mdot
.65583 .54199 Mdot
.43111 .69462 Mdot
.31604 .47656 Mdot
.29293 .41092 Mdot
.5268 .28526 Mdot
.60905 .35095 Mdot
.55122 .49766 Mdot
.60674 .35835 Mdot
.6837 .49492 Mdot
.58587 .42536 Mdot
.66316 .52218 Mdot
.49076 .7412 Mdot
.49661 .52763 Mdot
.67316 .49377 Mdot
.64002 .49482 Mdot
.61638 .38756 Mdot
.36015 .47716 Mdot
.52498 .41402 Mdot
.3432 .53393 Mdot
.36185 .41898 Mdot
.69102 .54852 Mdot
.44728 .70274 Mdot
.4262 .646 Mdot
.48479 .62599 Mdot
.46721 .64789 Mdot
.60015 .3671 Mdot
.57113 .62723 Mdot
.23318 .46421 Mdot
.6796 .50747 Mdot
.64792 .45718 Mdot
.35473 .46652 Mdot
.62127 .38977 Mdot
.59089 .3705 Mdot
.67349 .54354 Mdot
.22485 .53632 Mdot
.39608 .42932 Mdot
.43626 .62832 Mdot
.42267 .67753 Mdot
.4549 .64634 Mdot
.46267 .70976 Mdot
.19283 .43104 Mdot
.70256 .5148 Mdot
.45363 .70177 Mdot
.35405 .49793 Mdot
.41086 .4773 Mdot
.57995 .70352 Mdot
.52063 .28821 Mdot
.36381 .43068 Mdot
.37614 .42796 Mdot
.38329 .46409 Mdot
.62735 .38708 Mdot
.45205 .46657 Mdot
.58767 .72488 Mdot
.59077 .42706 Mdot
.57438 .40856 Mdot
.59966 .70314 Mdot
.40793 .70988 Mdot
.81592 .59075 Mdot
.3689 .45485 Mdot
.39119 .59117 Mdot
.6209 .3961 Mdot
.51962 .59384 Mdot
.29287 .43632 Mdot
.34799 .48181 Mdot
.5377 .37619 Mdot
.60469 .37107 Mdot
.48328 .70613 Mdot
.39442 .47484 Mdot
.60371 .71491 Mdot
.52858 .30362 Mdot
.32844 .51456 Mdot
.58387 .69306 Mdot
.44473 .65982 Mdot
.65527 .26416 Mdot
.41831 .63923 Mdot
.62957 .38916 Mdot
.4216 .45298 Mdot
.19866 .7419 Mdot
.59226 .38547 Mdot
.69961 .72467 Mdot
.49727 .51662 Mdot
.39183 .51653 Mdot
.59979 .36246 Mdot
.48861 .69697 Mdot
.69681 .54373 Mdot
.56027 .48638 Mdot
.43253 .68852 Mdot
.60359 .70336 Mdot
.58649 .69779 Mdot
.60828 .38296 Mdot
.42655 .6574 Mdot
.41468 .51106 Mdot
.47268 .68159 Mdot
.66081 .50193 Mdot
.33495 .46751 Mdot
.80301 .57639 Mdot
.30948 .49875 Mdot
.46806 .68682 Mdot
.64479 .38659 Mdot
.47792 .27592 Mdot
.33808 .4934 Mdot
.75363 .68549 Mdot
.40479 .51035 Mdot
.67487 .50913 Mdot
.49688 .57744 Mdot
.26438 .57683 Mdot
.36709 .46632 Mdot
.35691 .45904 Mdot
.70247 .54897 Mdot
.36942 .46165 Mdot
.36634 .52725 Mdot
.70062 .56908 Mdot
.46465 .65184 Mdot
.37159 .50073 Mdot
.59486 .35847 Mdot
.32955 .56927 Mdot
.36608 .43595 Mdot
.48549 .75865 Mdot
.42044 .27195 Mdot
.48855 .56049 Mdot
.41343 .4495 Mdot
.4267 .22159 Mdot
.39261 .4904 Mdot
.34822 .50494 Mdot
.36205 .4656 Mdot
.31762 .71915 Mdot
.6179 .38356 Mdot
.57871 .36541 Mdot
.53054 .30111 Mdot
.42469 .27829 Mdot
.49192 .27761 Mdot
.69068 .55614 Mdot
.67368 .45473 Mdot
.59884 .72572 Mdot
.45678 .6666 Mdot
.38036 .43997 Mdot
.59011 .41786 Mdot
.38474 .47026 Mdot
.34635 .45338 Mdot
.61076 .3704 Mdot
.59474 .3704 Mdot
.5686 .40215 Mdot
.50392 .26364 Mdot
.44785 .67047 Mdot
.387 .44967 Mdot
.48904 .26392 Mdot
.41058 .5125 Mdot
.57839 .56854 Mdot
.44511 .66958 Mdot
.47298 .67999 Mdot
.4245 .64171 Mdot
.40411 .45923 Mdot
.33108 .46357 Mdot
.66441 .53793 Mdot
.4308 .70929 Mdot
.68819 .50859 Mdot
.60149 .3618 Mdot
.62604 .37658 Mdot
.39546 .46993 Mdot
.3592 .39711 Mdot
.51885 .28925 Mdot
.59982 .40524 Mdot
.5871 .73048 Mdot
.53054 .3034 Mdot
.37014 .51394 Mdot
.60523 .36 Mdot
.52305 .31168 Mdot
.24434 .52961 Mdot
.82083 .53359 Mdot
.4848 .26295 Mdot
.3604 .48439 Mdot
.37537 .71778 Mdot
.299 .33532 Mdot
.48214 .25936 Mdot
.66276 .51225 Mdot
.41036 .49418 Mdot
.73094 .2833 Mdot
.48275 .30409 Mdot
.24145 .36997 Mdot
.615 .37175 Mdot
.26316 .47592 Mdot
.32564 .51143 Mdot
.20519 .53191 Mdot
.48464 .30698 Mdot
.45999 .69003 Mdot
.42656 .69651 Mdot
.36556 .4783 Mdot
.48652 .25176 Mdot
.69103 .49996 Mdot
.62769 .40795 Mdot
.57497 .40419 Mdot
.42885 .65139 Mdot
.58432 .63223 Mdot
.59697 .35842 Mdot
.43615 .48475 Mdot
.64194 .42121 Mdot
.41636 .56693 Mdot
.17963 .47917 Mdot
.47022 .79196 Mdot
.42553 .47213 Mdot
.47736 .27409 Mdot
.6781 .55977 Mdot
.66752 .53734 Mdot
.66892 .52474 Mdot
.62405 .36938 Mdot
.55219 .55595 Mdot
.57434 .39014 Mdot
.53943 .72374 Mdot
.51271 .29379 Mdot
.3968 .29914 Mdot
.39067 .43702 Mdot
.39055 .51664 Mdot
.38009 .53182 Mdot
.36324 .45787 Mdot
.3915 .48959 Mdot
.68727 .54687 Mdot
.63416 .39519 Mdot
.6906 .29455 Mdot
.44426 .64749 Mdot
.65482 .65801 Mdot
.62399 .40104 Mdot
.5765 .70241 Mdot
.49698 .29925 Mdot
.38717 .23963 Mdot
.6562 .41047 Mdot
.61738 .40978 Mdot
.3529 .52463 Mdot
.45283 .70598 Mdot
.26967 .41276 Mdot
.39935 .49478 Mdot
.59877 .40589 Mdot
.63901 .41418 Mdot
.22251 .58096 Mdot
.43208 .53494 Mdot
.50418 .33284 Mdot
.57044 .56808 Mdot
.47255 .28952 Mdot
.38288 .54519 Mdot
.52477 .59906 Mdot
.61537 .38118 Mdot
.60215 .39808 Mdot
.48588 .26005 Mdot
.46664 .47888 Mdot
.42588 .67096 Mdot
.60727 .71512 Mdot
.65909 .51739 Mdot
.39781 .50266 Mdot
.62139 .36578 Mdot
.40593 .59593 Mdot
.56781 .47061 Mdot
.68225 .51878 Mdot
.59587 .42773 Mdot
.41229 .49525 Mdot
.3669 .47208 Mdot
.51072 .28453 Mdot
.5435 .22594 Mdot
.33893 .52908 Mdot
.65622 .75702 Mdot
.55395 .59494 Mdot
.49819 .44848 Mdot
.37981 .46931 Mdot
.44344 .63867 Mdot
.60102 .70924 Mdot
.50141 .30841 Mdot
.41065 .50939 Mdot
.82758 .56511 Mdot
.40919 .67736 Mdot
.69143 .53764 Mdot
.60256 .7103 Mdot
.54833 .54534 Mdot
.40248 .51354 Mdot
.40064 .47706 Mdot
.35908 .50914 Mdot
.83273 .56008 Mdot
.58035 .36695 Mdot
.44159 .71112 Mdot
.48241 .28849 Mdot
.47586 .67408 Mdot
.57157 .37563 Mdot
.4975 .4274 Mdot
.36632 .51564 Mdot
.43606 .63081 Mdot
.45691 .6928 Mdot
.68417 .51237 Mdot
.66991 .55487 Mdot
.5858 .34921 Mdot
.38492 .5216 Mdot
.60293 .7231 Mdot
.43509 .69567 Mdot
.63717 .39993 Mdot
.51061 .28547 Mdot
.64259 .539 Mdot
.40566 .46365 Mdot
.6113 .38388 Mdot
.42627 .49228 Mdot
.46819 .66543 Mdot
.61956 .40795 Mdot
.57633 .69772 Mdot
.52129 .29199 Mdot
.4119 .47105 Mdot
.6715 .26527 Mdot
.6042 .70988 Mdot
.32931 .48308 Mdot
.39192 .71307 Mdot
.51154 .25384 Mdot
.47362 .78191 Mdot
.57828 .38004 Mdot
.59605 .72262 Mdot
.44706 .70974 Mdot
.28258 .41792 Mdot
.60015 .39264 Mdot
.40247 .75319 Mdot
.54055 .41195 Mdot
.37748 .45169 Mdot
.43088 .66535 Mdot
.46492 .28849 Mdot
.67583 .75044 Mdot
.326 .30932 Mdot
.37936 .49215 Mdot
.60691 .35801 Mdot
.52524 .30697 Mdot
.68901 .51067 Mdot
.49035 .75446 Mdot
.1853 .49568 Mdot
.5898 .42554 Mdot
.38931 .44693 Mdot
.43879 .69925 Mdot
.67816 .54243 Mdot
.47904 .81182 Mdot
.64203 .37905 Mdot
.58555 .36655 Mdot
.35323 .51095 Mdot
.48264 .29236 Mdot
.73652 .29948 Mdot
.58258 .3622 Mdot
.6302 .37324 Mdot
.64133 .66634 Mdot
.52314 .27476 Mdot
.35613 .49568 Mdot
.4864 .62766 Mdot
.3835 .52972 Mdot
.66124 .73792 Mdot
.59816 .72309 Mdot
.44698 .64821 Mdot
.40521 .47473 Mdot
.68102 .28504 Mdot
.59633 .38326 Mdot
.56938 .57327 Mdot
.70899 .57722 Mdot
.66599 .5523 Mdot
.61835 .36486 Mdot
.38848 .47444 Mdot
.63364 .51257 Mdot
.51638 .2859 Mdot
.3705 .52266 Mdot
.33547 .45408 Mdot
.49262 .6814 Mdot
.65619 .50693 Mdot
.34346 .57524 Mdot
.65599 .50129 Mdot
.70722 .53789 Mdot
.48172 .64308 Mdot
.36561 .47985 Mdot
.60699 .40718 Mdot
.62747 .35561 Mdot
.4201 .50304 Mdot
.51969 .592 Mdot
.42691 .66959 Mdot
.60089 .44333 Mdot
.84872 .52165 Mdot
.42767 .44547 Mdot
.58218 .7275 Mdot
.26152 .49432 Mdot
.70182 .52882 Mdot
.37957 .45502 Mdot
.46287 .66985 Mdot
.63519 .38523 Mdot
.60132 .35496 Mdot
.33749 .51483 Mdot
.67449 .5451 Mdot
.52147 .31715 Mdot
.58636 .37331 Mdot
.57159 .47437 Mdot
.37759 .50681 Mdot
.53404 .70954 Mdot
.5833 .37998 Mdot
.59444 .82076 Mdot
.68451 .28927 Mdot
.43887 .64539 Mdot
.34818 .4595 Mdot
.47729 .6921 Mdot
.48278 .28464 Mdot
.59834 .43408 Mdot
.67164 .54599 Mdot
.39804 .38349 Mdot
.43724 .18685 Mdot
.62189 .38596 Mdot
.44787 .66324 Mdot
.39371 .45269 Mdot
.32515 .41084 Mdot
.39997 .51289 Mdot
.29577 .37296 Mdot
.45677 .28945 Mdot
.6373 .49979 Mdot
.6939 .51564 Mdot
.36005 .45043 Mdot
.50787 .2676 Mdot
.61195 .34803 Mdot
.61217 .3719 Mdot
.1733 .35852 Mdot
.58189 .693 Mdot
.46185 .31347 Mdot
.40544 .46135 Mdot
.6341 .40589 Mdot
.36646 .65289 Mdot
.68387 .50419 Mdot
.39835 .52972 Mdot
.61722 .42122 Mdot
.69436 .686 Mdot
.57161 .56027 Mdot
.37729 .50093 Mdot
.41516 .41751 Mdot
.66717 .5121 Mdot
.62013 .59418 Mdot
.57642 .39479 Mdot
.40176 .52331 Mdot
.72317 .53516 Mdot
.63285 .68605 Mdot
.40939 .19803 Mdot
.44754 .67071 Mdot
.64553 .39765 Mdot
.67167 .55238 Mdot
.44796 .46669 Mdot
.51653 .28157 Mdot
.63293 .37135 Mdot
.6103 .42065 Mdot
.33866 .46448 Mdot
.36982 .43142 Mdot
.44373 .48857 Mdot
.43653 .65946 Mdot
.65646 .53436 Mdot
.36248 .44271 Mdot
.58675 .61368 Mdot
.3704 .45115 Mdot
.65945 .53842 Mdot
.11455 .59959 Mdot
.33648 .50865 Mdot
.40504 .49008 Mdot
.44279 .35862 Mdot
.42172 .65846 Mdot
.46994 .65724 Mdot
.57272 .61237 Mdot
.40641 .46248 Mdot
.59994 .45763 Mdot
.45079 .67054 Mdot
.42863 .67215 Mdot
.5791 .44764 Mdot
.33617 .47358 Mdot
.69659 .49391 Mdot
.67485 .5413 Mdot
.66736 .55315 Mdot
.47151 .66642 Mdot
.32754 .43426 Mdot
.69681 .55728 Mdot
.21296 .6103 Mdot
.62301 .40704 Mdot
.525 .59958 Mdot
.47131 .68423 Mdot
.55163 .44399 Mdot
.65056 .53521 Mdot
.61521 .83268 Mdot
.32105 .38114 Mdot
.41904 .516 Mdot
.36552 .47204 Mdot
.49525 .28038 Mdot
.29707 .46114 Mdot
.58389 .6959 Mdot
.66827 .53281 Mdot
.72669 .34619 Mdot
.44129 .67265 Mdot
.40591 .49609 Mdot
.34312 .26867 Mdot
.49685 .80507 Mdot
.51699 .66614 Mdot
.43193 .68499 Mdot
.43722 .67568 Mdot
.59056 .41133 Mdot
.62586 .4069 Mdot
.36056 .50266 Mdot
.66514 .52646 Mdot
.42521 .69021 Mdot
.65081 .52163 Mdot
.61599 .3797 Mdot
.61813 .40691 Mdot
.5838 .72421 Mdot
.35568 .41371 Mdot
.62109 .37281 Mdot
.64894 .68025 Mdot
.5862 .61024 Mdot
.48166 .70465 Mdot
.70028 .2242 Mdot
.4735 .8137 Mdot
.43844 .35605 Mdot
.52896 .30253 Mdot
.62002 .72487 Mdot
.64409 .52618 Mdot
.36036 .45175 Mdot
.39664 .46428 Mdot
.58278 .70587 Mdot
.65503 .54569 Mdot
.49127 .29308 Mdot
.64926 .53401 Mdot
.50746 .30729 Mdot
.58392 .35683 Mdot
.36411 .4355 Mdot
.38834 .52421 Mdot
.6949 .52888 Mdot
.59204 .40822 Mdot
.62901 .38815 Mdot
.52617 .28828 Mdot
.39019 .24445 Mdot
.60913 .38171 Mdot
.47156 .68403 Mdot
.31755 .57443 Mdot
.58534 .69871 Mdot
.39413 .47561 Mdot
.37092 .24541 Mdot
.21523 .5694 Mdot
.37939 .4497 Mdot
.60313 .71053 Mdot
.18529 .33197 Mdot
.35525 .43764 Mdot
.16819 .41683 Mdot
.58734 .72336 Mdot
.43623 .63782 Mdot
.58398 .39536 Mdot
.59204 .6941 Mdot
.45039 .46359 Mdot
.45858 .26515 Mdot
.43037 .47384 Mdot
.42567 .68057 Mdot
.44468 .63203 Mdot
.50293 .52131 Mdot
.66438 .7347 Mdot
.48376 .29803 Mdot
.49825 .29454 Mdot
.60104 .39007 Mdot
.72657 .50711 Mdot
.4175 .52876 Mdot
.49632 .29177 Mdot
.75811 .36204 Mdot
.35398 .46882 Mdot
.44415 .28125 Mdot
.53377 .3899 Mdot
.43866 .64045 Mdot
.46563 .51721 Mdot
.59807 .38737 Mdot
.44759 .66369 Mdot
.51793 .45878 Mdot
.38298 .53113 Mdot
.4433 .67037 Mdot
.65615 .53693 Mdot
.75536 .52597 Mdot
.47128 .65251 Mdot
.56149 .48339 Mdot
.67831 .53891 Mdot
.50519 .25043 Mdot
.35963 .32774 Mdot
.88453 .51203 Mdot
.66659 .53157 Mdot
.5907 .40256 Mdot
.62475 .37669 Mdot
.60603 .37858 Mdot
.43057 .68668 Mdot
.59188 .37417 Mdot
.44309 .65226 Mdot
.6232 .50968 Mdot
.41466 .22734 Mdot
.5065 .28646 Mdot
.64969 .44404 Mdot
.45258 .68752 Mdot
.54932 .72361 Mdot
.63415 .18874 Mdot
.35667 .48904 Mdot
.68217 .49613 Mdot
.4773 .27053 Mdot
.57219 .65581 Mdot
.49131 .28245 Mdot
.58585 .39967 Mdot
.52589 .60127 Mdot
.37927 .48497 Mdot
.43107 .76314 Mdot
.51825 .31037 Mdot
.43211 .68677 Mdot
.34772 .51381 Mdot
.59481 .34269 Mdot
.49792 .27356 Mdot
.52812 .30039 Mdot
.3923 .48713 Mdot
.45973 .63687 Mdot
.61213 .40873 Mdot
.64008 .51887 Mdot
.46719 .27008 Mdot
.39285 .40466 Mdot
.36246 .47207 Mdot
.35012 .52743 Mdot
.56437 .58082 Mdot
.7385 .29504 Mdot
.67592 .5343 Mdot
.29627 .33348 Mdot
.62493 .38401 Mdot
.32381 .31553 Mdot
.57264 .76449 Mdot
.66082 .406 Mdot
.59692 .72407 Mdot
.59929 .72285 Mdot
.38182 .49662 Mdot
.76237 .32491 Mdot
.49148 .62663 Mdot
.71462 .53088 Mdot
.58958 .69995 Mdot
.62912 .38934 Mdot
.42071 .70023 Mdot
.47439 .46138 Mdot
.35004 .43161 Mdot
.66178 .55312 Mdot
.6121 .37714 Mdot
.80294 .44807 Mdot
.51115 .29392 Mdot
.55797 .63733 Mdot
.37362 .51527 Mdot
.38646 .48494 Mdot
.68551 .52943 Mdot
.66553 .53823 Mdot
.52613 .72216 Mdot
.51246 .54019 Mdot
.78587 .59476 Mdot
.67923 .48839 Mdot
.80407 .43199 Mdot
.4794 .62674 Mdot
.4677 .67875 Mdot
.57806 .72007 Mdot
.69788 .55462 Mdot
.40348 .48187 Mdot
.43254 .63974 Mdot
.51043 .64975 Mdot
.49519 .68018 Mdot
.44216 .29037 Mdot
.56926 .44902 Mdot
.37485 .51767 Mdot
.45656 .70745 Mdot
.44608 .66504 Mdot
.47188 .70156 Mdot
.59881 .7032 Mdot
.37948 .46624 Mdot
.35881 .4794 Mdot
.35128 .43943 Mdot
.33002 .40933 Mdot
.38091 .50428 Mdot
.58008 .76405 Mdot
.59593 .63052 Mdot
.5818 .2897 Mdot
.39569 .45017 Mdot
.66623 .5493 Mdot
.38234 .44022 Mdot
.50892 .26948 Mdot
.39729 .44952 Mdot
.44995 .2669 Mdot
.67431 .52415 Mdot
.45692 .4403 Mdot
.58267 .43603 Mdot
.36978 .51635 Mdot
.51352 .31891 Mdot
.74204 .29935 Mdot
.32464 .28533 Mdot
.64288 .66876 Mdot
.47172 .68328 Mdot
.57829 .35435 Mdot
.68794 .50139 Mdot
.60763 .40611 Mdot
.40857 .524 Mdot
.58722 .72863 Mdot
.42011 .82562 Mdot
.53813 .44015 Mdot
.40451 .48039 Mdot
.34239 .41448 Mdot
.44962 .64051 Mdot
.59458 .38157 Mdot
.49685 .66403 Mdot
.35258 .50768 Mdot
.48282 .27765 Mdot
.48566 .26907 Mdot
.50236 .46619 Mdot
.78124 .43771 Mdot
.28164 .40634 Mdot
.68346 .53012 Mdot
.60499 .35359 Mdot
.48686 .30876 Mdot
.51463 .70191 Mdot
.69559 .50338 Mdot
.70164 .52853 Mdot
.65529 .50816 Mdot
.38528 .51452 Mdot
.57971 .71768 Mdot
.76831 .39613 Mdot
.60044 .69966 Mdot
.35868 .51611 Mdot
.60514 .42079 Mdot
.59338 .6938 Mdot
.49419 .27843 Mdot
.70616 .53877 Mdot
.62639 .39207 Mdot
.38872 .49757 Mdot
.4529 .67562 Mdot
.30439 .31642 Mdot
.57486 .19712 Mdot
.6343 .44609 Mdot
.63464 .44728 Mdot
.42092 .64179 Mdot
.74631 .70446 Mdot
.62996 .53475 Mdot
.22306 .53894 Mdot
.4704 .30524 Mdot
.42001 .50453 Mdot
.24 .29988 Mdot
.57487 .38919 Mdot
.60395 .36472 Mdot
.37324 .50407 Mdot
.64209 .39039 Mdot
.40544 .50186 Mdot
.57857 .40184 Mdot
.71695 .69569 Mdot
.33584 .44005 Mdot
.6019 .36637 Mdot
.40859 .53719 Mdot
.33755 .49576 Mdot
.45042 .63903 Mdot
.63474 .37629 Mdot
.42079 .5137 Mdot
.3912 .82807 Mdot
.68845 .51699 Mdot
.59735 .70141 Mdot
.66051 .44916 Mdot
.64521 .51122 Mdot
.43281 .65647 Mdot
.35933 .43449 Mdot
.51534 .28681 Mdot
.46006 .6849 Mdot
.58019 .34683 Mdot
.51203 .31317 Mdot
.57269 .62715 Mdot
.4708 .67404 Mdot
.58094 .7047 Mdot
.52105 .29466 Mdot
.43038 .47245 Mdot
.60925 .36638 Mdot
.65215 .23123 Mdot
.59901 .6992 Mdot
.38054 .47762 Mdot
.64677 .38036 Mdot
.64839 .53201 Mdot
.36326 .49723 Mdot
.61187 .35683 Mdot
.60132 .70605 Mdot
.32982 .48195 Mdot
.33046 .48712 Mdot
.46741 .43742 Mdot
.49152 .58921 Mdot
.50619 .28296 Mdot
.48035 .6427 Mdot
.35404 .5005 Mdot
.51013 .26845 Mdot
.69912 .39518 Mdot
.40836 .44937 Mdot
.47863 .67913 Mdot
.37657 .38494 Mdot
.62354 .41077 Mdot
.69001 .50982 Mdot
.63277 .36136 Mdot
.52839 .30711 Mdot
.43705 .15933 Mdot
.57703 .70727 Mdot
.35485 .41045 Mdot
.37928 .53239 Mdot
.60279 .43085 Mdot
.44223 .66498 Mdot
.77562 .61438 Mdot
.40975 .46738 Mdot
.31584 .4548 Mdot
.39433 .48108 Mdot
.679 .28962 Mdot
.42723 .6723 Mdot
.39507 .47797 Mdot
.36463 .40004 Mdot
.43354 .48898 Mdot
.51239 .32035 Mdot
.39206 .30959 Mdot
.37889 .44163 Mdot
.29651 .8312 Mdot
.6038 .72571 Mdot
.60906 .37132 Mdot
.56992 .52271 Mdot
.67864 .33143 Mdot
.17643 .46375 Mdot
.43924 .65529 Mdot
.30454 .53429 Mdot
.61051 .40761 Mdot
.29708 .30614 Mdot
.71239 .73926 Mdot
.33966 .50071 Mdot
.41237 .49085 Mdot
.58589 .39968 Mdot
.63609 .40004 Mdot
.59617 .72874 Mdot
.41767 .47164 Mdot
.31814 .45042 Mdot
.63908 .40561 Mdot
.39028 .50279 Mdot
.26086 .66573 Mdot
.64665 .49994 Mdot
.47062 .66132 Mdot
.68858 .51045 Mdot
.7003 .5304 Mdot
.22443 .48382 Mdot
.55307 .59484 Mdot
.66145 .53875 Mdot
.70655 .56053 Mdot
.45764 .24226 Mdot
.40734 .38211 Mdot
.49987 .31645 Mdot
.78132 .49012 Mdot
.60362 .38583 Mdot
.3798 .46435 Mdot
.43922 .69591 Mdot
.20007 .50064 Mdot
.76016 .56851 Mdot
.53506 .61813 Mdot
.35542 .48655 Mdot
.59854 .38145 Mdot
.60205 .70453 Mdot
.34026 .43636 Mdot
.31108 .32795 Mdot
.38217 .48865 Mdot
.6295 .40445 Mdot
.22716 .47418 Mdot
.45978 .74962 Mdot
.68344 .49021 Mdot
.45107 .72521 Mdot
.37602 .43755 Mdot
.46143 .65988 Mdot
.67226 .55012 Mdot
.50479 .26434 Mdot
.49718 .28486 Mdot
.3756 .5207 Mdot
.49681 .5286 Mdot
.4945 .2296 Mdot
.33951 .49868 Mdot
.33721 .46627 Mdot
.59335 .72373 Mdot
.33661 .46623 Mdot
.39607 .52581 Mdot
.36774 .44331 Mdot
.41964 .46845 Mdot
.70685 .54196 Mdot
.40335 .72997 Mdot
.39492 .44476 Mdot
.42877 .44517 Mdot
.63648 .52258 Mdot
.43661 .54136 Mdot
.66965 .51438 Mdot
.79767 .55198 Mdot
.65954 .52077 Mdot
.49915 .28502 Mdot
.63149 .35387 Mdot
.32964 .55534 Mdot
.42422 .68838 Mdot
.67462 .5548 Mdot
.5072 .30314 Mdot
.66744 .52878 Mdot
.59182 .35589 Mdot
.67341 .22045 Mdot
.46176 .6269 Mdot
.58019 .56694 Mdot
.41362 .36008 Mdot
.53355 .71056 Mdot
.61727 .41353 Mdot
.42925 .65183 Mdot
.46253 .7521 Mdot
.3602 .44817 Mdot
.51149 .28205 Mdot
.38244 .49506 Mdot
.70637 .53233 Mdot
.60081 .38216 Mdot
.61675 .51576 Mdot
.50484 .28203 Mdot
.49725 .16345 Mdot
.58954 .41651 Mdot
.38466 .41356 Mdot
.63501 .51667 Mdot
.67997 .21484 Mdot
.66295 .51726 Mdot
.40987 .22871 Mdot
.40899 .63061 Mdot
.22223 .44967 Mdot
.44186 .6817 Mdot
.51153 .72905 Mdot
.7931 .67482 Mdot
.71609 .72544 Mdot
.46174 .67884 Mdot
.58889 .44181 Mdot
.38283 .50989 Mdot
.36582 .45346 Mdot
.43747 .47768 Mdot
.47468 .71463 Mdot
.35781 .506 Mdot
.58238 .6976 Mdot
.56183 .59195 Mdot
.73769 .32306 Mdot
.59055 .34874 Mdot
.40501 .50474 Mdot
.69108 .54791 Mdot
.70717 .52419 Mdot
.59727 .69554 Mdot
.6536 .50478 Mdot
.33567 .48667 Mdot
.44965 .6865 Mdot
.5234 .42057 Mdot
.48549 .28009 Mdot
.62648 .75943 Mdot
.47489 .30376 Mdot
.65771 .38665 Mdot
.4322 .45671 Mdot
.61829 .40729 Mdot
.3371 .21044 Mdot
.36023 .45542 Mdot
.45167 .66873 Mdot
.3558 .51752 Mdot
.36929 .44125 Mdot
.38477 .44463 Mdot
.61033 .3554 Mdot
.57153 .52809 Mdot
.39242 .50083 Mdot
.66516 .54547 Mdot
.56458 .43475 Mdot
.36532 .42904 Mdot
.73305 .36857 Mdot
.44176 .30448 Mdot
.53712 .70661 Mdot
.47615 .70917 Mdot
.59268 .39819 Mdot
.44019 .67464 Mdot
.44695 .72967 Mdot
.43291 .65619 Mdot
.74105 .36324 Mdot
.25845 .44388 Mdot
.15882 .4447 Mdot
.35443 .63994 Mdot
.21029 .51116 Mdot
.43267 .63022 Mdot
.71745 .41879 Mdot
.46503 .67429 Mdot
.43617 .65497 Mdot
.1067 .49227 Mdot
.46496 .69595 Mdot
.39442 .46888 Mdot
.32493 .4646 Mdot
.54518 .80491 Mdot
.45327 .24476 Mdot
.39553 .44916 Mdot
.3584 .50433 Mdot
.47853 .28098 Mdot
.37676 .39278 Mdot
.6099 .70537 Mdot
.55464 .61757 Mdot
.6011 .73983 Mdot
.3916 .48795 Mdot
.36795 .50692 Mdot
.34487 .52726 Mdot
.79296 .68146 Mdot
.19314 .49524 Mdot
.43361 .6358 Mdot
.45569 .4963 Mdot
.64326 .72358 Mdot
.36731 .52854 Mdot
.36514 .52566 Mdot
.33968 .44802 Mdot
.60814 .40749 Mdot
.41731 .69331 Mdot
.31369 .48351 Mdot
.53514 .76858 Mdot
.37217 .51414 Mdot
.64517 .35287 Mdot
.54653 .31492 Mdot
.38896 .47332 Mdot
.47663 .68257 Mdot
.35783 .46938 Mdot
.46665 .70152 Mdot
.46975 .66187 Mdot
.35041 .41471 Mdot
.77297 .40792 Mdot
.42628 .70993 Mdot
.33938 .50307 Mdot
.59492 .4081 Mdot
.67762 .74663 Mdot
.38209 .47552 Mdot
.48529 .29847 Mdot
.37867 .4546 Mdot
.51866 .31863 Mdot
.33434 .46043 Mdot
.60256 .70224 Mdot
.25914 .58409 Mdot
.60249 .39662 Mdot
.46577 .27323 Mdot
.63761 .40325 Mdot
.47336 .42144 Mdot
.4721 .64418 Mdot
.61172 .7103 Mdot
.18004 .51756 Mdot
.59147 .72347 Mdot
.28066 .34255 Mdot
.72596 .49864 Mdot
.69781 .52992 Mdot
.46131 .71022 Mdot
.24999 .44152 Mdot
.75686 .41029 Mdot
.57221 .40828 Mdot
.57423 .40897 Mdot
.35815 .20855 Mdot
.22344 .29736 Mdot
.39667 .4988 Mdot
.72419 .26783 Mdot
.28803 .64122 Mdot
.42988 .51078 Mdot
.38419 .55153 Mdot
.61647 .41937 Mdot
.37745 .43661 Mdot
.55169 .4836 Mdot
.61697 .38692 Mdot
.50577 .29937 Mdot
.44931 .64904 Mdot
.52492 .29281 Mdot
.77723 .54698 Mdot
.59845 .61727 Mdot
.62127 .37942 Mdot
.41236 .45657 Mdot
.39781 .50721 Mdot
.4534 .71151 Mdot
.41857 .76979 Mdot
.46583 .65264 Mdot
.48971 .30697 Mdot
.61216 .39534 Mdot
.20117 .52757 Mdot
.38722 .45407 Mdot
.45382 .69403 Mdot
.56765 .4167 Mdot
.36756 .4705 Mdot
.69409 .536 Mdot
.35499 .48594 Mdot
.46367 .69189 Mdot
.33641 .4654 Mdot
.44797 .68472 Mdot
.58269 .40365 Mdot
.40164 .51677 Mdot
.36669 .50546 Mdot
.26476 .35348 Mdot
.49025 .29266 Mdot
.4668 .63838 Mdot
.55272 .48968 Mdot
.38217 .52947 Mdot
.31192 .32923 Mdot
.36089 .436 Mdot
.35973 .56146 Mdot
.35966 .54359 Mdot
.58003 .70113 Mdot
.39267 .53413 Mdot
.38207 .47696 Mdot
.38426 .74588 Mdot
.36884 .68625 Mdot
.4743 .49361 Mdot
.67301 .5564 Mdot
.47656 .67853 Mdot
.62385 .3727 Mdot
.63384 .38704 Mdot
.58752 .37917 Mdot
.44612 .24265 Mdot
.3999 .405 Mdot
.37744 .48514 Mdot
.63759 .49761 Mdot
.49989 .29317 Mdot
.43967 .69187 Mdot
.50303 .28913 Mdot
.55134 .61414 Mdot
.49924 .31211 Mdot
.58041 .69798 Mdot
.68535 .28905 Mdot
.2293 .63159 Mdot
.49765 .30827 Mdot
.46705 .65458 Mdot
.58554 .45507 Mdot
.42095 .50487 Mdot
.6744 .69063 Mdot
.48239 .278 Mdot
.38369 .19905 Mdot
.32725 .47112 Mdot
.56011 .49328 Mdot
.67493 .51315 Mdot
.52471 .2948 Mdot
.65969 .50462 Mdot
.35875 .46496 Mdot
.4707 .78242 Mdot
.45173 .66404 Mdot
.65833 .49689 Mdot
.40478 .53109 Mdot
.52471 .29299 Mdot
.62001 .37481 Mdot
.33937 .37961 Mdot
.65345 .54662 Mdot
.306 .30839 Mdot
.32556 .30979 Mdot
.61385 .39414 Mdot
.20883 .6376 Mdot
.66382 .50722 Mdot
.42434 .47171 Mdot
.26671 .45869 Mdot
.3544 .47778 Mdot
.62954 .38131 Mdot
.59942 .36507 Mdot
.60088 .78021 Mdot
.37601 .51943 Mdot
.33239 .44956 Mdot
.41357 .67122 Mdot
.62262 .38948 Mdot
.42947 .65961 Mdot
.43669 .70902 Mdot
.58762 .40247 Mdot
.43736 .64572 Mdot
.51914 .30988 Mdot
.54507 .58929 Mdot
.66253 .50885 Mdot
.68401 .54469 Mdot
.62198 .3743 Mdot
.59596 .35129 Mdot
.6209 .40571 Mdot
.35114 .48963 Mdot
.42325 .66428 Mdot
.34624 .46577 Mdot
.38274 .44113 Mdot
.4225 .60812 Mdot
.41855 .65898 Mdot
.35031 .46798 Mdot
.54152 .39549 Mdot
.5312 .318 Mdot
.60063 .36753 Mdot
.65117 .52467 Mdot
.25862 .35367 Mdot
.65055 .49938 Mdot
.37108 .52448 Mdot
.69149 .69014 Mdot
.42999 .68516 Mdot
.49252 .28139 Mdot
.51909 .26121 Mdot
.50068 .28034 Mdot
.65867 .49673 Mdot
.44234 .71355 Mdot
.57451 .62505 Mdot
.3835 .52285 Mdot
.56289 .58126 Mdot
.2735 .36024 Mdot
.56372 .76633 Mdot
.65704 .53656 Mdot
.35641 .49144 Mdot
.58773 .72273 Mdot
.2231 .58853 Mdot
.37594 .49195 Mdot
.40086 .52905 Mdot
.60351 .2516 Mdot
.42846 .44524 Mdot
.49029 .68993 Mdot
.49825 .49594 Mdot
.41096 .50773 Mdot
.47705 .47185 Mdot
.14192 .39687 Mdot
.32767 .47692 Mdot
.36761 .51079 Mdot
.38925 .46176 Mdot
.3578 .45488 Mdot
.48142 .68073 Mdot
.57313 .22448 Mdot
.68619 .55123 Mdot
.54507 .58651 Mdot
.6566 .5093 Mdot
.60977 .36272 Mdot
.5381 .46502 Mdot
.47262 .69765 Mdot
.49981 .27981 Mdot
.71169 .24559 Mdot
.53041 .59456 Mdot
.59321 .41271 Mdot
.19261 .45544 Mdot
.48548 .27656 Mdot
.42132 .50131 Mdot
.53093 .30044 Mdot
.62783 .41617 Mdot
.67285 .54431 Mdot
.35008 .52206 Mdot
.42671 .68562 Mdot
.47267 .65593 Mdot
.35373 .49461 Mdot
.65017 .75588 Mdot
.64367 .51605 Mdot
.61771 .32265 Mdot
.38138 .51604 Mdot
.40155 .52826 Mdot
.45803 .64726 Mdot
.59567 .38011 Mdot
.70654 .48521 Mdot
.49627 .30027 Mdot
.40782 .53289 Mdot
.35982 .4651 Mdot
.55094 .6048 Mdot
.69657 .55355 Mdot
.59345 .70734 Mdot
.37825 .51791 Mdot
.55722 .59673 Mdot
.36622 .51937 Mdot
.30834 .45184 Mdot
.60765 .4117 Mdot
.3553 .41941 Mdot
.41526 .48559 Mdot
.39376 .60715 Mdot
.66752 .50478 Mdot
.4461 .66804 Mdot
.41055 .63369 Mdot
.60398 .71571 Mdot
.69148 .5238 Mdot
.35092 .47178 Mdot
.70031 .51908 Mdot
.37592 .44613 Mdot
.38943 .50002 Mdot
.65698 .53684 Mdot
.42974 .65675 Mdot
.77411 .60234 Mdot
.41093 .74098 Mdot
.34969 .44918 Mdot
.37291 .45644 Mdot
.44576 .25289 Mdot
.18377 .5858 Mdot
.41589 .48159 Mdot
.42167 .66716 Mdot
.36692 .47338 Mdot
.68397 .54734 Mdot
.49206 .30888 Mdot
.45541 .67345 Mdot
.59025 .35368 Mdot
.57756 .39464 Mdot
.57379 .43139 Mdot
.57781 .70305 Mdot
.41826 .47742 Mdot
.47692 .63754 Mdot
.41795 .65314 Mdot
.57054 .66459 Mdot
.60878 .37036 Mdot
.50416 .31568 Mdot
.33946 .44482 Mdot
.32439 .38604 Mdot
.69922 .5397 Mdot
.30492 .83537 Mdot
.57806 .6274 Mdot
.50656 .32305 Mdot
.48705 .55627 Mdot
.58538 .71866 Mdot
.40757 .48514 Mdot
.51314 .27205 Mdot
.58097 .37679 Mdot
.36305 .45681 Mdot
.43615 .44296 Mdot
.75895 .42404 Mdot
.5804 .35796 Mdot
.69597 .51371 Mdot
.58057 .37013 Mdot
.52262 .31913 Mdot
.58196 .6968 Mdot
.46035 .63888 Mdot
.3847 .4793 Mdot
.43087 .56019 Mdot
.60445 .37593 Mdot
.6066 .70884 Mdot
.37071 .51839 Mdot
.47708 .67056 Mdot
.59449 .37101 Mdot
.3965 .48643 Mdot
.22274 .54932 Mdot
.43435 .59545 Mdot
.60727 .39017 Mdot
.36479 .53199 Mdot
.44885 .39507 Mdot
.57371 .37 Mdot
.60834 .42212 Mdot
.35852 .50623 Mdot
.5218 .29943 Mdot
.40677 .50758 Mdot
.66419 .52054 Mdot
.57169 .52789 Mdot
.6932 .53152 Mdot
.29454 .33803 Mdot
.32267 .4701 Mdot
.51741 .65871 Mdot
.44703 .70567 Mdot
.5184 .26501 Mdot
.37185 .73943 Mdot
.40789 .52114 Mdot
.80329 .59312 Mdot
.55537 .44816 Mdot
.60528 .63834 Mdot
.8356 .51724 Mdot
.49867 .30546 Mdot
.66896 .52427 Mdot
.36573 .5107 Mdot
.64865 .55373 Mdot
.51191 .30807 Mdot
.28979 .34128 Mdot
.37592 .53288 Mdot
.4288 .67394 Mdot
.37873 .51284 Mdot
.47167 .68587 Mdot
.37153 .4628 Mdot
.44303 .44013 Mdot
.50179 .3316 Mdot
.40642 .23021 Mdot
.42332 .49425 Mdot
.71501 .24303 Mdot
.41319 .37213 Mdot
.48278 .28862 Mdot
.34371 .45297 Mdot
.58645 .70957 Mdot
.65248 .53928 Mdot
.69526 .26541 Mdot
.61423 .40767 Mdot
.65974 .53411 Mdot
.45093 .64592 Mdot
.64184 .37114 Mdot
.60536 .71722 Mdot
.26388 .47233 Mdot
.52401 .28936 Mdot
.68924 .51884 Mdot
.38463 .47537 Mdot
.36548 .52415 Mdot
.67741 .28405 Mdot
.23931 .69863 Mdot
.42181 .68937 Mdot
.45453 .17564 Mdot
.48466 .65062 Mdot
.49443 .29344 Mdot
.61103 .41155 Mdot
.40378 .4733 Mdot
.37138 .49799 Mdot
.6262 .36999 Mdot
.4225 .65585 Mdot
.64409 .4175 Mdot
.21063 .46834 Mdot
.70663 .57683 Mdot
.40248 .2725 Mdot
.45865 .67284 Mdot
.4012 .26904 Mdot
.51103 .32297 Mdot
.79709 .45097 Mdot
.4035 .34383 Mdot
.69527 .5208 Mdot
.40332 .27682 Mdot
.44388 .69519 Mdot
.39927 .49695 Mdot
.58174 .70403 Mdot
.58994 .7261 Mdot
.45945 .65483 Mdot
.58769 .39918 Mdot
.51766 .28275 Mdot
.37583 .50885 Mdot
.54146 .68122 Mdot
.49644 .81927 Mdot
.60849 .35327 Mdot
.33613 .41449 Mdot
.64656 .51169 Mdot
.36717 .46686 Mdot
.48086 .27299 Mdot
.67082 .53671 Mdot
.57905 .69408 Mdot
.53293 .58252 Mdot
.34068 .44346 Mdot
.49786 .45772 Mdot
.68386 .51768 Mdot
.18379 .60025 Mdot
.36671 .5036 Mdot
.66412 .50697 Mdot
.40083 .5651 Mdot
.49359 .77016 Mdot
.53038 .40477 Mdot
.73176 .70979 Mdot
.56618 .37388 Mdot
.57686 .39071 Mdot
.35346 .79923 Mdot
.47073 .3064 Mdot
.67543 .55356 Mdot
.58718 .69469 Mdot
.39667 .32288 Mdot
.66823 .50182 Mdot
.34461 .51545 Mdot
.35765 .43634 Mdot
.2209 .48613 Mdot
.45541 .38377 Mdot
.60733 .72421 Mdot
.28298 .49112 Mdot
.33918 .48112 Mdot
.42155 .45529 Mdot
.36186 .49257 Mdot
.44275 .63227 Mdot
.67689 .50099 Mdot
.79257 .29543 Mdot
.69688 .50898 Mdot
.5408 .66107 Mdot
.6033 .38558 Mdot
.62168 .35553 Mdot
.3897 .47431 Mdot
.48476 .61587 Mdot
.75448 .30621 Mdot
.38793 .45124 Mdot
.51902 .25943 Mdot
.32501 .30807 Mdot
.37372 .428 Mdot
.40862 .66975 Mdot
.31434 .45701 Mdot
.48565 .66706 Mdot
.67167 .53916 Mdot
.50057 .30649 Mdot
.53259 .31875 Mdot
.67089 .51836 Mdot
.37463 .48564 Mdot
.54409 .30861 Mdot
.38894 .48277 Mdot
.39664 .50515 Mdot
.55443 .62667 Mdot
.47438 .27262 Mdot
.62232 .40549 Mdot
.49886 .28344 Mdot
.43555 .65765 Mdot
.09724 .52883 Mdot
.51113 .2903 Mdot
.402 .38081 Mdot
.55385 .46781 Mdot
.40044 .27747 Mdot
.47083 .65311 Mdot
.48362 .29884 Mdot
.68698 .50674 Mdot
.59824 .64489 Mdot
.20481 .62197 Mdot
.66394 .49693 Mdot
.37245 .50064 Mdot
.47102 .69932 Mdot
.42225 .642 Mdot
.70381 .50753 Mdot
.44005 .63921 Mdot
.40367 .42858 Mdot
.34022 .50592 Mdot
.67804 .55297 Mdot
.54099 .81408 Mdot
.67921 .5013 Mdot
.3445 .38058 Mdot
.33244 .45853 Mdot
.45339 .67112 Mdot
.33253 .5442 Mdot
.46637 .6201 Mdot
.58481 .72565 Mdot
.39421 .44634 Mdot
.50471 .27826 Mdot
.5526 .55522 Mdot
.60605 .39068 Mdot
.69628 .68736 Mdot
.4726 .68191 Mdot
.6699 .49234 Mdot
.45245 .63919 Mdot
.41955 .67727 Mdot
.67284 .49784 Mdot
.44211 .65975 Mdot
.37037 .51061 Mdot
.64545 .6001 Mdot
.46999 .6843 Mdot
.68333 .52615 Mdot
.50558 .27633 Mdot
.43374 .64818 Mdot
.63377 .42653 Mdot
.40179 .50078 Mdot
.61745 .41518 Mdot
.47411 .26467 Mdot
.47 .702 Mdot
.48908 .30514 Mdot
.60569 .37266 Mdot
.51546 .27864 Mdot
.63455 .55124 Mdot
.6284 .51213 Mdot
.53491 .62556 Mdot
.44504 .75072 Mdot
.43729 .69555 Mdot
.56489 .391 Mdot
.4105 .47828 Mdot
.38851 .51591 Mdot
.52983 .30752 Mdot
.42266 .63934 Mdot
.67409 .7442 Mdot
.33023 .54857 Mdot
.61771 .75936 Mdot
.687 .55808 Mdot
.37545 .22391 Mdot
.58372 .63267 Mdot
.61906 .64457 Mdot
.39247 .54681 Mdot
.58427 .71712 Mdot
.39494 .48048 Mdot
.32566 .28371 Mdot
.48878 .30753 Mdot
.70884 .46105 Mdot
.41907 .52701 Mdot
.61978 .39765 Mdot
.37943 .45766 Mdot
.71728 .26566 Mdot
.30807 .49527 Mdot
.47928 .28782 Mdot
.63426 .52376 Mdot
.42429 .68857 Mdot
.48506 .27949 Mdot
.57923 .39994 Mdot
.42216 .3025 Mdot
.34645 .52386 Mdot
.33761 .48528 Mdot
.57898 .41605 Mdot
.42703 .66501 Mdot
.60942 .3642 Mdot
.66239 .50868 Mdot
.50779 .2903 Mdot
.35662 .45296 Mdot
.38037 .42282 Mdot
.60546 .42957 Mdot
.70356 .51745 Mdot
.6051 .35107 Mdot
.70199 .52366 Mdot
.58264 .71477 Mdot
.41995 .47897 Mdot
.59744 .42715 Mdot
.41378 .54359 Mdot
.37112 .65633 Mdot
.54529 .6176 Mdot
.35411 .72174 Mdot
.62315 .40543 Mdot
.42944 .2752 Mdot
.67534 .52107 Mdot
.68298 .51003 Mdot
.2335 .4668 Mdot
.75638 .31415 Mdot
.59753 .45701 Mdot
.66166 .21785 Mdot
.66177 .5094 Mdot
.68807 .52417 Mdot
.58149 .37918 Mdot
.44426 .65403 Mdot
.41482 .70336 Mdot
.64085 .40746 Mdot
.37047 .24602 Mdot
.44045 .69234 Mdot
.79356 .63087 Mdot
.57383 .39863 Mdot
.37109 .54483 Mdot
.60409 .73205 Mdot
.48013 .28286 Mdot
.33499 .27792 Mdot
.67483 .22948 Mdot
.40069 .47448 Mdot
.18556 .38783 Mdot
.59615 .39996 Mdot
.73362 .56242 Mdot
.79106 .49262 Mdot
.38757 .5324 Mdot
.38114 .45955 Mdot
.37092 .48445 Mdot
.48584 .25871 Mdot
.39249 .73445 Mdot
.40238 .47703 Mdot
.41568 .22998 Mdot
.33155 .44363 Mdot
.65691 .23921 Mdot
.4992 .2837 Mdot
.28256 .37943 Mdot
.56714 .36323 Mdot
.5468 .75856 Mdot
.43493 .47135 Mdot
.664 .51071 Mdot
.76128 .48113 Mdot
.66101 .54226 Mdot
.78634 .39034 Mdot
.39946 .34299 Mdot
.44242 .63163 Mdot
.35449 .48745 Mdot
.58196 .4162 Mdot
.46877 .70138 Mdot
.71216 .48687 Mdot
.10279 .48832 Mdot
.7077 .5426 Mdot
.27905 .22564 Mdot
.68875 .51234 Mdot
.59412 .72736 Mdot
.45914 .65074 Mdot
.46847 .53254 Mdot
.55922 .5802 Mdot
.4302 .65826 Mdot
.57989 .30614 Mdot
.40749 .64943 Mdot
.41807 .26278 Mdot
.43152 .62313 Mdot
.67776 .52639 Mdot
.63192 .50736 Mdot
.44603 .50706 Mdot
.41374 .47881 Mdot
.5686 .5901 Mdot
.41537 .54943 Mdot
.40649 .4623 Mdot
.61705 .3871 Mdot
.4685 .76028 Mdot
.73131 .54461 Mdot
.46243 .66813 Mdot
.69891 .54493 Mdot
.38168 .45836 Mdot
.34875 .44986 Mdot
.43234 .49524 Mdot
.29755 .31278 Mdot
.79547 .62362 Mdot
.39264 .49914 Mdot
.32599 .43886 Mdot
.59255 .41083 Mdot
.67204 .26942 Mdot
.50916 .18613 Mdot
.40311 .32783 Mdot
.37396 .5217 Mdot
.49071 .28894 Mdot
.47698 .2892 Mdot
.39013 .41774 Mdot
.52289 .65295 Mdot
.63589 .43602 Mdot
.38446 .47517 Mdot
.44921 .35031 Mdot
.60915 .43505 Mdot
.60408 .70288 Mdot
.605 .37572 Mdot
.47328 .69866 Mdot
.59356 .72487 Mdot
.60782 .3566 Mdot
.44992 .58257 Mdot
.60328 .71512 Mdot
.50627 .76966 Mdot
.48912 .30653 Mdot
.36348 .49674 Mdot
.50052 .66869 Mdot
.62551 .37062 Mdot
.68534 .51612 Mdot
.45255 .68232 Mdot
.67739 .56039 Mdot
.67624 .27099 Mdot
.34687 .27155 Mdot
.57721 .70804 Mdot
.6625 .51381 Mdot
.51151 .52057 Mdot
.49233 .2873 Mdot
.66085 .50059 Mdot
.50866 .64843 Mdot
.36715 .43035 Mdot
.80186 .38315 Mdot
.34143 .49372 Mdot
.63567 .77434 Mdot
.6785 .5097 Mdot
.57617 .7194 Mdot
.38406 .48166 Mdot
.58821 .41503 Mdot
.43153 .54571 Mdot
.38843 .48476 Mdot
.58156 .36537 Mdot
.39697 .49774 Mdot
.488 .26403 Mdot
.48514 .68264 Mdot
.54687 .44246 Mdot
.31523 .27632 Mdot
.50606 .27306 Mdot
.61158 .69605 Mdot
.41488 .47454 Mdot
.54724 .25056 Mdot
.43091 .66847 Mdot
.3977 .52906 Mdot
.21087 .40509 Mdot
.45386 .65457 Mdot
.43923 .67536 Mdot
.33957 .46616 Mdot
.66008 .49767 Mdot
.62833 .3876 Mdot
.49343 .28525 Mdot
.73207 .51295 Mdot
.39851 .48644 Mdot
.35654 .49434 Mdot
.48583 .27681 Mdot
.69103 .52684 Mdot
.35427 .45576 Mdot
.73732 .62977 Mdot
.56479 .66256 Mdot
.70065 .53227 Mdot
.36913 .42955 Mdot
.82696 .40871 Mdot
.42177 .71387 Mdot
.17586 .40316 Mdot
.46833 .3003 Mdot
.59236 .4042 Mdot
.36091 .4067 Mdot
.25521 .79793 Mdot
.48187 .29026 Mdot
.55915 .75859 Mdot
.39151 .5049 Mdot
.40101 .46145 Mdot
.46489 .63891 Mdot
.34713 .47147 Mdot
.46413 .69425 Mdot
.32224 .26503 Mdot
.69504 .21179 Mdot
.44821 .6399 Mdot
.46767 .69137 Mdot
.46076 .53179 Mdot
.28696 .3276 Mdot
.44848 .64764 Mdot
.34659 .52455 Mdot
.58343 .29661 Mdot
.40228 .40897 Mdot
.48325 .31036 Mdot
.5308 .27754 Mdot
.41502 .64393 Mdot
.27489 .71941 Mdot
.41267 .56732 Mdot
.45922 .4364 Mdot
.49274 .23299 Mdot
.65686 .52286 Mdot
.35544 .44047 Mdot
.57886 .69912 Mdot
.5912 .37078 Mdot
.30974 .47147 Mdot
.36648 .49577 Mdot
.46975 .69527 Mdot
.4911 .25698 Mdot
.65955 .50278 Mdot
.36008 .50513 Mdot
.65082 .37457 Mdot
.50289 .30101 Mdot
.46933 .68305 Mdot
.39638 .38049 Mdot
.49891 .31715 Mdot
.39634 .42885 Mdot
.40422 .46072 Mdot
.36852 .51865 Mdot
.43906 .48738 Mdot
.67231 .51632 Mdot
.64617 .39475 Mdot
.38521 .41052 Mdot
.55977 .61502 Mdot
.55443 .54024 Mdot
.38251 .41141 Mdot
.42247 .66265 Mdot
.67139 .55482 Mdot
.60018 .71161 Mdot
.39669 .29955 Mdot
.32819 .46899 Mdot
.80069 .6063 Mdot
.19573 .47181 Mdot
.59837 .71772 Mdot
.4569 .62838 Mdot
.49561 .28089 Mdot
.33479 .47552 Mdot
.54847 .27783 Mdot
.34327 .51182 Mdot
.32266 .40749 Mdot
.59471 .40306 Mdot
.65317 .52126 Mdot
.55839 .68194 Mdot
.59148 .36968 Mdot
.43984 .67485 Mdot
.6609 .78252 Mdot
.40568 .6726 Mdot
.4259 .69968 Mdot
.77644 .40711 Mdot
.66802 .54058 Mdot
.28128 .8203 Mdot
.18234 .5865 Mdot
.332 .49603 Mdot
.67427 .54869 Mdot
.46445 .65728 Mdot
.34822 .49326 Mdot
.43898 .69514 Mdot
.42088 .7033 Mdot
.384 .43975 Mdot
.40842 .46862 Mdot
.39663 .23728 Mdot
.78816 .65528 Mdot
.51238 .28325 Mdot
.43475 .6387 Mdot
.2196 .50344 Mdot
.40434 .47877 Mdot
.38498 .52252 Mdot
.76589 .45091 Mdot
.48145 .29384 Mdot
.25755 .65312 Mdot
.38665 .51435 Mdot
.21258 .39782 Mdot
.40561 .45961 Mdot
.46769 .73095 Mdot
.70017 .50083 Mdot
.52972 .66604 Mdot
.62991 .38412 Mdot
.46734 .70983 Mdot
.52253 .31409 Mdot
.4658 .71278 Mdot
.2349 .47812 Mdot
.67148 .54174 Mdot
.46361 .69206 Mdot
.62528 .35197 Mdot
.68489 .5367 Mdot
.69598 .52076 Mdot
.57498 .44171 Mdot
.63734 .36465 Mdot
.48875 .26 Mdot
.65102 .53347 Mdot
.22429 .53597 Mdot
.67678 .52964 Mdot
.22613 .5019 Mdot
.41087 .50494 Mdot
.40484 .24411 Mdot
.55373 .67624 Mdot
.44288 .49948 Mdot
.6723 .49989 Mdot
.51826 .29537 Mdot
.35193 .47695 Mdot
.4369 .64041 Mdot
.51366 .29452 Mdot
.6933 .57056 Mdot
.60791 .34732 Mdot
.41708 .64677 Mdot
.63569 .50962 Mdot
.45828 .69855 Mdot
.32577 .29683 Mdot
.65798 .40796 Mdot
.53659 .37482 Mdot
.5626 .57546 Mdot
.42845 .47992 Mdot
.47664 .47557 Mdot
.37632 .53075 Mdot
.37122 .49432 Mdot
.60692 .38927 Mdot
.44477 .24348 Mdot
.43251 .64894 Mdot
.55016 .83077 Mdot
.66783 .51137 Mdot
.49818 .50314 Mdot
.30249 .41816 Mdot
.37299 .44872 Mdot
.46774 .67312 Mdot
.42316 .70316 Mdot
.36873 .68717 Mdot
.62589 .3686 Mdot
.41943 .42228 Mdot
.42901 .4502 Mdot
.40452 .40578 Mdot
.69182 .51477 Mdot
.75309 .6139 Mdot
.62356 .36012 Mdot
.20123 .30079 Mdot
.60037 .36702 Mdot
.57084 .24289 Mdot
.443 .65928 Mdot
.50726 .31476 Mdot
.39068 .52058 Mdot
.39987 .71163 Mdot
.48205 .66998 Mdot
.60435 .44201 Mdot
.49525 .27863 Mdot
.76581 .60663 Mdot
.6627 .53801 Mdot
.40323 .51873 Mdot
.38213 .43814 Mdot
.34498 .46145 Mdot
.34962 .50929 Mdot
.68801 .55307 Mdot
.34802 .51805 Mdot
.66585 .55903 Mdot
.21539 .56492 Mdot
.21522 .40414 Mdot
.59907 .42383 Mdot
.65722 .24604 Mdot
.41973 .67366 Mdot
.24638 .53436 Mdot
.25345 .65577 Mdot
.54576 .62076 Mdot
.62017 .52915 Mdot
.41708 .49405 Mdot
.58615 .39695 Mdot
.72877 .27069 Mdot
.59395 .42385 Mdot
.734 .2232 Mdot
.25429 .43542 Mdot
.72027 .72825 Mdot
.34549 .49632 Mdot
.63916 .41307 Mdot
.29957 .72209 Mdot
.37398 .42058 Mdot
.54167 .30606 Mdot
.32562 .39354 Mdot
.54226 .79754 Mdot
.50293 .31588 Mdot
.40252 .49742 Mdot
.41675 .67208 Mdot
.37176 .51085 Mdot
.39999 .51226 Mdot
.38618 .45181 Mdot
.7127 .53332 Mdot
.37427 .43399 Mdot
.40615 .50831 Mdot
.21837 .6737 Mdot
.44336 .28653 Mdot
.59204 .41333 Mdot
.35757 .70249 Mdot
.50029 .29343 Mdot
.46571 .70378 Mdot
.55912 .45521 Mdot
.6616 .52566 Mdot
.36746 .6738 Mdot
.34382 .49534 Mdot
.59544 .76344 Mdot
.64367 .49692 Mdot
.5116 .30484 Mdot
.60224 .71035 Mdot
.78806 .56616 Mdot
.63108 .40526 Mdot
.59836 .72909 Mdot
.60539 .39151 Mdot
.3458 .74573 Mdot
.47067 .68934 Mdot
.42847 .47613 Mdot
.65155 .50995 Mdot
.6138 .41975 Mdot
.46737 .22247 Mdot
.36726 .4814 Mdot
.62425 .40425 Mdot
.42639 .47455 Mdot
.56 .54181 Mdot
.56322 .4714 Mdot
.63205 .41246 Mdot
.63225 .50911 Mdot
.68699 .53856 Mdot
.51677 .31238 Mdot
.45959 .70868 Mdot
.42485 .67716 Mdot
.67521 .53673 Mdot
.20001 .32602 Mdot
.39852 .48466 Mdot
.40018 .45643 Mdot
.56541 .61797 Mdot
.34931 .50293 Mdot
.43317 .30047 Mdot
.6057 .69834 Mdot
.43927 .69908 Mdot
.35267 .50946 Mdot
.35408 .45497 Mdot
.34282 .44267 Mdot
.34829 .27255 Mdot
.60214 .37574 Mdot
.3384 .47999 Mdot
.51964 .27922 Mdot
.5237 .72394 Mdot
.41081 .4824 Mdot
.38688 .42629 Mdot
.4594 .69634 Mdot
.40655 .19794 Mdot
.68049 .51245 Mdot
.62412 .38872 Mdot
.57245 .3953 Mdot
.32027 .33592 Mdot
.46967 .71536 Mdot
.61053 .70968 Mdot
.7009 .35186 Mdot
.59371 .69732 Mdot
.48384 .289 Mdot
.54476 .409 Mdot
.6531 .37802 Mdot
.57745 .39947 Mdot
.6292 .5192 Mdot
.35667 .51246 Mdot
.40481 .4592 Mdot
.5576 .7541 Mdot
.38977 .44812 Mdot
.50024 .27643 Mdot
.63639 .51571 Mdot
.45963 .69472 Mdot
.48418 .26962 Mdot
.6819 .50809 Mdot
.42662 .66475 Mdot
.36161 .42768 Mdot
.43427 .49287 Mdot
.44749 .68152 Mdot
.47389 .67237 Mdot
.3904 .46775 Mdot
.30383 .75876 Mdot
.43322 .6956 Mdot
.46358 .68117 Mdot
.57779 .72699 Mdot
.62948 .40937 Mdot
.30925 .5171 Mdot
.67322 .54749 Mdot
.37526 .5178 Mdot
.60099 .42448 Mdot
.49529 .30779 Mdot
.44201 .68521 Mdot
.34573 .44503 Mdot
.39239 .49288 Mdot
.49033 .28743 Mdot
.47346 .28674 Mdot
.49907 .2731 Mdot
.7072 .55068 Mdot
.33952 .50209 Mdot
.44492 .64649 Mdot
.66354 .54036 Mdot
.47806 .2924 Mdot
.52959 .28712 Mdot
.21298 .66032 Mdot
.39903 .47427 Mdot
.54631 .29426 Mdot
.1115 .58507 Mdot
.42253 .31098 Mdot
.6011 .72468 Mdot
.62401 .42295 Mdot
.41312 .24125 Mdot
.46532 .27106 Mdot
.66841 .55028 Mdot
.46052 .35928 Mdot
.50523 .25789 Mdot
.37958 .44145 Mdot
.36456 .46822 Mdot
.38147 .54286 Mdot
.50729 .29717 Mdot
.33515 .28782 Mdot
.42097 .64672 Mdot
.28445 .61147 Mdot
.50048 .29345 Mdot
.63291 .41116 Mdot
.60925 .42748 Mdot
.60126 .36533 Mdot
.41642 .49965 Mdot
.36931 .71378 Mdot
.21816 .51873 Mdot
.26723 .65439 Mdot
.66059 .53471 Mdot
.41949 .69702 Mdot
.61658 .51573 Mdot
.43863 .67575 Mdot
.58902 .38058 Mdot
.50818 .30139 Mdot
.45705 .63391 Mdot
.6963 .53154 Mdot
.69207 .53537 Mdot
.59626 .34983 Mdot
.60882 .37385 Mdot
.62094 .37744 Mdot
.46581 .70966 Mdot
.4422 .65949 Mdot
.35467 .45008 Mdot
.4509 .68979 Mdot
.18331 .49908 Mdot
.48072 .30892 Mdot
.57423 .41055 Mdot
.68058 .51777 Mdot
.47063 .67386 Mdot
.36394 .49971 Mdot
.62301 .26356 Mdot
.59481 .43843 Mdot
.50126 .26953 Mdot
.60562 .57643 Mdot
.61779 .15594 Mdot
.39095 .43781 Mdot
.70508 .52928 Mdot
.52027 .65613 Mdot
.37251 .47659 Mdot
.60681 .4086 Mdot
.24317 .42061 Mdot
.60203 .7028 Mdot
.41041 .49681 Mdot
.40941 .52501 Mdot
.66971 .49828 Mdot
.56116 .46146 Mdot
.38354 .44568 Mdot
.51734 .46117 Mdot
.70907 .52972 Mdot
.62263 .35912 Mdot
.38331 .8274 Mdot
.70479 .57517 Mdot
.4133 .21979 Mdot
.60151 .72123 Mdot
.37707 .43909 Mdot
.61473 .3883 Mdot
.50641 .26902 Mdot
.61146 .38256 Mdot
.43774 .62468 Mdot
.62354 .41069 Mdot
.36232 .48302 Mdot
.44203 .64816 Mdot
.6905 .52229 Mdot
.49668 .47921 Mdot
.25003 .70402 Mdot
.58782 .41409 Mdot
.58708 .68987 Mdot
.40865 .48688 Mdot
.22795 .5869 Mdot
.44729 .50629 Mdot
.41521 .48364 Mdot
.65914 .54097 Mdot
.46594 .67072 Mdot
.68325 .55794 Mdot
.39097 .43335 Mdot
.26063 .51072 Mdot
.66733 .51329 Mdot
.50954 .79235 Mdot
.48424 .27814 Mdot
.3677 .24821 Mdot
.37814 .49308 Mdot
.65171 .51059 Mdot
.33806 .50012 Mdot
.43365 .63867 Mdot
.53814 .55254 Mdot
.52349 .70782 Mdot
.64587 .51303 Mdot
.64645 .77811 Mdot
.5526 .49141 Mdot
.30426 .49852 Mdot
.66077 .50731 Mdot
.37067 .7349 Mdot
.5892 .70879 Mdot
.49415 .29963 Mdot
.47498 .28565 Mdot
.52729 .29781 Mdot
.39142 .44869 Mdot
.40505 .40026 Mdot
.52061 .27252 Mdot
.70287 .5536 Mdot
.50857 .26606 Mdot
.30117 .31853 Mdot
.65856 .75328 Mdot
.49657 .2711 Mdot
.379 .49663 Mdot
.38116 .42558 Mdot
.4437 .28255 Mdot
.63239 .36536 Mdot
.80097 .58139 Mdot
.1941 .58558 Mdot
.40324 .47145 Mdot
.26024 .44534 Mdot
.42616 .63134 Mdot
.48728 .59097 Mdot
.29786 .52313 Mdot
.57699 .4533 Mdot
.46675 .68038 Mdot
.57164 .54802 Mdot
.44392 .7031 Mdot
.4184 .4567 Mdot
.3887 .50092 Mdot
.48389 .67401 Mdot
.68751 .68188 Mdot
.44782 .80248 Mdot
.62771 .76012 Mdot
.42228 .67121 Mdot
.66748 .50459 Mdot
.7073 .5325 Mdot
.65654 .53508 Mdot
.62568 .37505 Mdot
.47585 .6742 Mdot
.33191 .47986 Mdot
.58179 .40057 Mdot
.38753 .51919 Mdot
.67943 .54225 Mdot
.56472 .66401 Mdot
.46084 .6947 Mdot
.38273 .47701 Mdot
.20982 .62896 Mdot
.59891 .38807 Mdot
.49255 .28954 Mdot
.62143 .59555 Mdot
.61958 .42654 Mdot
.69359 .50652 Mdot
.44756 .72578 Mdot
.55834 .36672 Mdot
.57417 .22292 Mdot
.34666 .52824 Mdot
.34145 .51963 Mdot
.66823 .45199 Mdot
.23697 .67825 Mdot
.37881 .45074 Mdot
.5781 .39822 Mdot
.63235 .40873 Mdot
.33654 .50085 Mdot
.46338 .64225 Mdot
.50938 .26155 Mdot
.52872 .30862 Mdot
.42577 .49731 Mdot
.56761 .58184 Mdot
.40334 .23945 Mdot
.35139 .46537 Mdot
.30964 .4267 Mdot
.62349 .35221 Mdot
.60494 .71796 Mdot
.55171 .59416 Mdot
.52342 .30796 Mdot
.39196 .5064 Mdot
.46523 .80376 Mdot
.4659 .68909 Mdot
.62763 .39447 Mdot
.69206 .54544 Mdot
.54147 .31385 Mdot
.5696 .37625 Mdot
.3364 .50057 Mdot
.35408 .4556 Mdot
.65439 .50423 Mdot
.47084 .73021 Mdot
.50947 .29907 Mdot
.58482 .40429 Mdot
.50834 .31501 Mdot
.4367 .66094 Mdot
.46239 .68595 Mdot
.42633 .44551 Mdot
.44319 .50817 Mdot
.576 .40161 Mdot
.39651 .53697 Mdot
.59737 .36322 Mdot
.67658 .28132 Mdot
.69885 .54099 Mdot
.39245 .53171 Mdot
.49467 .68694 Mdot
.67835 .54148 Mdot
.39736 .46305 Mdot
.6673 .45309 Mdot
.36066 .45701 Mdot
.64042 .40977 Mdot
.22784 .44541 Mdot
.5119 .30908 Mdot
.47421 .47266 Mdot
.43195 .57048 Mdot
.3496 .50207 Mdot
.6424 .38086 Mdot
.43289 .42095 Mdot
.6672 .51632 Mdot
.45248 .66013 Mdot
.33549 .2128 Mdot
.68152 .52788 Mdot
.37921 .50822 Mdot
.51035 .29123 Mdot
.42523 .69222 Mdot
.57973 .71528 Mdot
.57693 .61329 Mdot
.30859 .48454 Mdot
.36655 .54825 Mdot
.36388 .51388 Mdot
.66193 .21688 Mdot
.6185 .38178 Mdot
.46845 .66574 Mdot
.70494 .53778 Mdot
.66729 .53358 Mdot
.59545 .38053 Mdot
.57134 .79241 Mdot
.70582 .69446 Mdot
.13024 .63288 Mdot
.57037 .38485 Mdot
.52032 .27616 Mdot
.54703 .53566 Mdot
.59182 .36776 Mdot
.61937 .39107 Mdot
.60502 .34581 Mdot
.57337 .75125 Mdot
.42495 .66135 Mdot
.39408 .493 Mdot
.47552 .70995 Mdot
.37955 .43992 Mdot
.45633 .21765 Mdot
.67297 .53805 Mdot
.45042 .6595 Mdot
.66561 .40461 Mdot
.39384 .56465 Mdot
.3757 .46566 Mdot
.55451 .29581 Mdot
.31319 .48742 Mdot
.40193 .2868 Mdot
.4352 .4852 Mdot
.60581 .38118 Mdot
.27698 .50569 Mdot
.34605 .41395 Mdot
.20455 .6063 Mdot
.6941 .52963 Mdot
.57829 .71781 Mdot
.35546 .42778 Mdot
.30441 .45504 Mdot
.42807 .69732 Mdot
.45847 .63416 Mdot
.51945 .27077 Mdot
.64081 .60421 Mdot
.69357 .52647 Mdot
.75302 .66512 Mdot
.41433 .47723 Mdot
.73526 .53289 Mdot
.22548 .44468 Mdot
.39308 .46252 Mdot
.54815 .40421 Mdot
.3678 .67695 Mdot
.37084 .45098 Mdot
.27655 .65323 Mdot
.67963 .52093 Mdot
.21214 .40049 Mdot
.41821 .52396 Mdot
.6077 .40788 Mdot
.44558 .65516 Mdot
.41742 .64657 Mdot
.49638 .26744 Mdot
.18003 .5365 Mdot
.63982 .47771 Mdot
.44523 .65846 Mdot
.36874 .48509 Mdot
.68193 .51449 Mdot
.58074 .72132 Mdot
.3361 .53532 Mdot
.76772 .35474 Mdot
.45414 .69212 Mdot
.37385 .4081 Mdot
.62213 .7628 Mdot
.56489 .49925 Mdot
.7951 .64413 Mdot
.65201 .52853 Mdot
.52443 .30792 Mdot
.43383 .51292 Mdot
.69962 .35241 Mdot
.42334 .51856 Mdot
.43771 .21718 Mdot
.46765 .61864 Mdot
.49256 .30925 Mdot
.37519 .47758 Mdot
.38232 .44597 Mdot
.55486 .56459 Mdot
.47691 .29688 Mdot
.38272 .44505 Mdot
.41429 .4239 Mdot
.42712 .66946 Mdot
.60352 .69554 Mdot
.45474 .69533 Mdot
.37128 .50136 Mdot
.26677 .40658 Mdot
.45637 .63587 Mdot
.78863 .59062 Mdot
.46939 .31072 Mdot
.66119 .52482 Mdot
.32234 .42204 Mdot
.41447 .49618 Mdot
.85544 .49783 Mdot
.58588 .72616 Mdot
.46362 .18253 Mdot
.63345 .41655 Mdot
.50069 .84351 Mdot
.61721 .42893 Mdot
.69651 .75263 Mdot
.50267 .50012 Mdot
.37674 .53862 Mdot
.42835 .35238 Mdot
.26751 .64623 Mdot
.64453 .54799 Mdot
.23698 .55843 Mdot
.41369 .47896 Mdot
.4045 .49085 Mdot
.57965 .38615 Mdot
.59115 .78439 Mdot
.52636 .6682 Mdot
.55312 .58709 Mdot
.50729 .3048 Mdot
.44233 .66562 Mdot
.36397 .47726 Mdot
.65994 .65671 Mdot
.60113 .41878 Mdot
.38192 .37198 Mdot
.38273 .48015 Mdot
.53617 .65935 Mdot
.54472 .78257 Mdot
.68806 .51686 Mdot
.63835 .4074 Mdot
.64575 .38885 Mdot
.35973 .43693 Mdot
.67757 .55169 Mdot
.36275 .44826 Mdot
.55044 .49473 Mdot
.32341 .44459 Mdot
.48732 .30021 Mdot
.38805 .52311 Mdot
.44868 .36589 Mdot
.69055 .77589 Mdot
.3237 .43414 Mdot
.44196 .70811 Mdot
.62083 .36962 Mdot
.59894 .37304 Mdot
.4246 .67731 Mdot
.59781 .37336 Mdot
.28812 .62111 Mdot
.24094 .49701 Mdot
.48343 .29224 Mdot
.25095 .6614 Mdot
.50701 .3079 Mdot
.57757 .71591 Mdot
.39684 .47124 Mdot
.71915 .36437 Mdot
.57002 .38492 Mdot
.26412 .35007 Mdot
.67417 .53171 Mdot
.58815 .72675 Mdot
.3268 .46257 Mdot
.53687 .26633 Mdot
.58625 .38743 Mdot
.76674 .51156 Mdot
.34487 .44225 Mdot
.42768 .64764 Mdot
.37419 .44889 Mdot
.31963 .48411 Mdot
.60077 .72695 Mdot
.36264 .51417 Mdot
.68168 .50797 Mdot
.47644 .67564 Mdot
.70062 .74445 Mdot
.62594 .37238 Mdot
.40738 .49741 Mdot
.36964 .4836 Mdot
.46039 .63331 Mdot
.32598 .4614 Mdot
.66857 .54932 Mdot
.3451 .86318 Mdot
.48344 .28111 Mdot
.60561 .71585 Mdot
.77719 .54701 Mdot
.35792 .48005 Mdot
.3528 .47102 Mdot
.68232 .47514 Mdot
.43977 .78599 Mdot
.66962 .50881 Mdot
.32886 .44472 Mdot
.59874 .41381 Mdot
.51366 .29816 Mdot
.65251 .53982 Mdot
.34119 .50625 Mdot
.40434 .48887 Mdot
.48236 .29298 Mdot
.55337 .28897 Mdot
.63783 .42556 Mdot
.65926 .53545 Mdot
.2651 .44386 Mdot
.63219 .26874 Mdot
.3936 .48273 Mdot
.63715 .73225 Mdot
.46148 .67734 Mdot
.6577 .51102 Mdot
.39646 .73899 Mdot
.42393 .46846 Mdot
.68712 .50408 Mdot
.69156 .52384 Mdot
.33108 .45188 Mdot
.46667 .71843 Mdot
.44259 .71727 Mdot
.4633 .67784 Mdot
.22477 .39775 Mdot
.5526 .19451 Mdot
.62236 .37858 Mdot
.68412 .52144 Mdot
.59862 .42586 Mdot
.52406 .27242 Mdot
.55554 .54242 Mdot
.63143 .41138 Mdot
.41895 .67191 Mdot
.58613 .42156 Mdot
.36064 .4522 Mdot
.69366 .53829 Mdot
.57362 .39108 Mdot
.34843 .48715 Mdot
.31901 .41775 Mdot
.44285 .36272 Mdot
.49952 .25823 Mdot
.57192 .55191 Mdot
.37568 .50585 Mdot
.60161 .71308 Mdot
.38875 .47043 Mdot
.67733 .55318 Mdot
.46772 .37318 Mdot
.3415 .48689 Mdot
.56986 .3885 Mdot
.58645 .22135 Mdot
.64102 .38267 Mdot
.32114 .4756 Mdot
.37234 .50163 Mdot
.39624 .48246 Mdot
.39341 .44683 Mdot
.52427 .79736 Mdot
.66366 .55885 Mdot
.34533 .40099 Mdot
.57587 .36274 Mdot
.44056 .68003 Mdot
.44077 .63403 Mdot
.60362 .4601 Mdot
.5908 .73051 Mdot
.67689 .55037 Mdot
.39691 .48402 Mdot
.76629 .51028 Mdot
.59504 .6368 Mdot
.63197 .76123 Mdot
.59351 .44853 Mdot
.57645 .39622 Mdot
.44452 .71081 Mdot
.58843 .36138 Mdot
.34085 .50863 Mdot
.43564 .48958 Mdot
.71535 .73154 Mdot
.71254 .54748 Mdot
.50837 .29999 Mdot
.38591 .52028 Mdot
.38903 .23462 Mdot
.59243 .41076 Mdot
.62794 .35483 Mdot
.3611 .4469 Mdot
.41501 .69934 Mdot
.76359 .71382 Mdot
.68601 .54978 Mdot
.22597 .57818 Mdot
.50809 .68645 Mdot
.3064 .40926 Mdot
.66958 .52005 Mdot
.53386 .39032 Mdot
.63155 .36793 Mdot
.18912 .57 Mdot
.44734 .6835 Mdot
.50461 .29942 Mdot
.40149 .41875 Mdot
.41899 .67302 Mdot
.59619 .42857 Mdot
.45796 .70436 Mdot
.4279 .47283 Mdot
.69952 .55397 Mdot
.59714 .36938 Mdot
.64797 .54712 Mdot
.48271 .67635 Mdot
.50933 .30843 Mdot
.27471 .34752 Mdot
.22181 .57308 Mdot
.36797 .67687 Mdot
.33799 .47949 Mdot
.74587 .38914 Mdot
.33085 .47691 Mdot
.42692 .70394 Mdot
.37812 .49378 Mdot
.47823 .46106 Mdot
.62085 .35499 Mdot
.36229 .4106 Mdot
.39708 .51941 Mdot
.20328 .57721 Mdot
.38395 .46065 Mdot
.32656 .47239 Mdot
.42029 .51294 Mdot
.49127 .72031 Mdot
.36895 .41173 Mdot
.42886 .64706 Mdot
.56558 .76117 Mdot
.61821 .39305 Mdot
.53286 .29894 Mdot
.52123 .31858 Mdot
.43272 .21608 Mdot
.37462 .24399 Mdot
.57659 .78751 Mdot
.43731 .68889 Mdot
.68433 .50569 Mdot
.36073 .44946 Mdot
.36727 .74495 Mdot
.32886 .36627 Mdot
.62767 .36408 Mdot
.57943 .41053 Mdot
.43225 .45103 Mdot
.72803 .25203 Mdot
.36982 .41027 Mdot
.57585 .62563 Mdot
.38587 .44333 Mdot
.3984 .52982 Mdot
.63146 .35598 Mdot
.32622 .29261 Mdot
.3384 .48023 Mdot
.42826 .69712 Mdot
.49769 .29808 Mdot
.2641 .46657 Mdot
.30732 .36949 Mdot
.31605 .3887 Mdot
.45674 .60207 Mdot
.34484 .50681 Mdot
.58932 .40538 Mdot
.42188 .68128 Mdot
.55865 .60833 Mdot
.6619 .54056 Mdot
.57179 .59754 Mdot
.21749 .55001 Mdot
.69076 .58239 Mdot
.50336 .30088 Mdot
.61357 .44842 Mdot
.36161 .48416 Mdot
.62528 .37574 Mdot
.40503 .44399 Mdot
.5997 .63481 Mdot
.49309 .30756 Mdot
.47398 .70389 Mdot
.66851 .50443 Mdot
.42144 .65506 Mdot
.35516 .71995 Mdot
.31695 .3725 Mdot
.50085 .84414 Mdot
.63263 .40117 Mdot
.34701 .57657 Mdot
.45758 .65352 Mdot
.33302 .45495 Mdot
.12758 .62346 Mdot
.45866 .67415 Mdot
.4229 .65507 Mdot
.57041 .45133 Mdot
.29451 .33785 Mdot
.35593 .40835 Mdot
.44728 .70289 Mdot
.56474 .36837 Mdot
.5025 .28163 Mdot
.34823 .47965 Mdot
.42502 .48927 Mdot
.46111 .63597 Mdot
.58823 .38563 Mdot
.39072 .22955 Mdot
.60691 .37686 Mdot
.4283 .65531 Mdot
.60212 .39648 Mdot
.78112 .59364 Mdot
.61051 .41706 Mdot
.39822 .51945 Mdot
.39592 .48433 Mdot
.73437 .33045 Mdot
.46233 .68597 Mdot
.35251 .47445 Mdot
.39482 .50061 Mdot
.45075 .64762 Mdot
.65034 .36803 Mdot
.37928 .67451 Mdot
.35127 .49102 Mdot
.39621 .48881 Mdot
.49183 .31023 Mdot
.56592 .52543 Mdot
.63328 .66543 Mdot
.34976 .47794 Mdot
.5268 .29225 Mdot
.46451 .71048 Mdot
.38817 .46873 Mdot
.32609 .29044 Mdot
.60783 .43405 Mdot
.35336 .51978 Mdot
.5785 .70886 Mdot
.38398 .45115 Mdot
.75668 .71968 Mdot
.40741 .49112 Mdot
.4616 .65233 Mdot
.45139 .6539 Mdot
.62567 .43527 Mdot
.4417 .67468 Mdot
.59813 .72561 Mdot
.68359 .53966 Mdot
.62541 .78845 Mdot
.59407 .72573 Mdot
.3991 .52604 Mdot
.18188 .58577 Mdot
.42654 .48965 Mdot
.36786 .42028 Mdot
.278 .33672 Mdot
.59915 .72254 Mdot
.46492 .66688 Mdot
.68897 .67715 Mdot
.37147 .53548 Mdot
.68284 .55096 Mdot
.37639 .42147 Mdot
.35381 .52048 Mdot
.45854 .39152 Mdot
.24566 .48476 Mdot
.63607 .52032 Mdot
.30952 .51572 Mdot
.34828 .47817 Mdot
.43105 .77957 Mdot
.36401 .4885 Mdot
.49522 .26992 Mdot
.43444 .69015 Mdot
.59289 .35695 Mdot
.48635 .28432 Mdot
.3603 .48084 Mdot
.50448 .29587 Mdot
.62341 .38168 Mdot
.64719 .52363 Mdot
.38366 .52355 Mdot
.48768 .31353 Mdot
.51031 .30163 Mdot
.34087 .45398 Mdot
.44732 .65748 Mdot
.4493 .50726 Mdot
.38875 .46686 Mdot
.33263 .49248 Mdot
.42502 .67749 Mdot
.149 .46912 Mdot
.37671 .43661 Mdot
.5363 .38942 Mdot
.48165 .64794 Mdot
.60942 .71451 Mdot
.58282 .3696 Mdot
.4158 .54043 Mdot
.66744 .53737 Mdot
.67841 .53855 Mdot
.58771 .35027 Mdot
.47625 .65551 Mdot
.59424 .37159 Mdot
.31479 .51426 Mdot
.43422 .45497 Mdot
.40658 .42154 Mdot
.33787 .21159 Mdot
.78749 .56155 Mdot
.46956 .65727 Mdot
.63588 .3718 Mdot
.56564 .58803 Mdot
.68231 .54784 Mdot
.60356 .34241 Mdot
.49231 .66591 Mdot
.47356 .69025 Mdot
.42522 .68421 Mdot
.52378 .29796 Mdot
.60759 .36891 Mdot
.46173 .61805 Mdot
.44143 .71966 Mdot
.3517 .4477 Mdot
.34747 .47775 Mdot
.41345 .63804 Mdot
.44823 .30186 Mdot
.49683 .30708 Mdot
.59691 .40771 Mdot
.86247 .56275 Mdot
.6868 .54978 Mdot
.20303 .57904 Mdot
.34889 .48792 Mdot
.09848 .44393 Mdot
.37368 .41142 Mdot
.36728 .486 Mdot
.47349 .69844 Mdot
.51971 .32323 Mdot
.50359 .28471 Mdot
.45647 .65305 Mdot
.4291 .71677 Mdot
.52111 .28617 Mdot
.56236 .43443 Mdot
.62845 .802 Mdot
.56148 .60163 Mdot
.45653 .64678 Mdot
.2234 .5939 Mdot
.65001 .53493 Mdot
.48834 .67524 Mdot
.64042 .53583 Mdot
.61997 .39266 Mdot
.58818 .41663 Mdot
.65181 .50466 Mdot
.33266 .45272 Mdot
.62585 .40637 Mdot
.31154 .46017 Mdot
.76059 .67736 Mdot
.79853 .41568 Mdot
.39547 .79375 Mdot
.41542 .47199 Mdot
.52551 .65807 Mdot
.53349 .74772 Mdot
.35861 .5079 Mdot
.34045 .55082 Mdot
.50726 .29862 Mdot
.48687 .66599 Mdot
.65724 .54866 Mdot
.80804 .58735 Mdot
.39463 .48296 Mdot
.43207 .64942 Mdot
.68946 .54383 Mdot
.77661 .59309 Mdot
.51776 .45848 Mdot
.36945 .44164 Mdot
.16564 .6986 Mdot
.48168 .67967 Mdot
.59348 .35682 Mdot
.23189 .65445 Mdot
.48116 .7041 Mdot
.62205 .25476 Mdot
.64733 .3935 Mdot
.59886 .6707 Mdot
.47028 .69747 Mdot
.65364 .40024 Mdot
.43622 .66419 Mdot
.48689 .26522 Mdot
.44849 .72631 Mdot
.59429 .38905 Mdot
.37799 .4702 Mdot
.59591 .3858 Mdot
.47933 .28469 Mdot
.63093 .39305 Mdot
.65644 .54772 Mdot
.60217 .71889 Mdot
.68957 .53932 Mdot
.55406 .53703 Mdot
.35036 .59612 Mdot
.65317 .52167 Mdot
.76875 .49013 Mdot
.37484 .45338 Mdot
.46554 .73122 Mdot
.59391 .35444 Mdot
.56689 .39175 Mdot
.57105 .5695 Mdot
.43099 .65662 Mdot
.59475 .39586 Mdot
.2219 .55127 Mdot
.18088 .34733 Mdot
.327 .42251 Mdot
.56637 .19687 Mdot
.45132 .64679 Mdot
.6211 .35414 Mdot
.56748 .61915 Mdot
.42546 .63754 Mdot
.57418 .39639 Mdot
.66207 .5055 Mdot
.66564 .53046 Mdot
.34436 .43986 Mdot
.70094 .50311 Mdot
.64206 .37799 Mdot
.45877 .79966 Mdot
.43085 .68752 Mdot
.77343 .56257 Mdot
.50459 .27282 Mdot
.62169 .38822 Mdot
.35665 .40953 Mdot
.44314 .60567 Mdot
.5733 .40214 Mdot
.76262 .33002 Mdot
.86628 .52624 Mdot
.59526 .39699 Mdot
.43562 .69114 Mdot
.43908 .68313 Mdot
.32673 .43036 Mdot
.56096 .57873 Mdot
.58871 .39056 Mdot
.71864 .36081 Mdot
.44071 .22146 Mdot
.58261 .71507 Mdot
.20138 .63211 Mdot
.33839 .48166 Mdot
.34598 .50954 Mdot
.6647 .5461 Mdot
.37449 .46348 Mdot
.42325 .70674 Mdot
.38456 .41352 Mdot
.70844 .53689 Mdot
.62376 .36088 Mdot
.39649 .47593 Mdot
.51814 .29297 Mdot
.66396 .5486 Mdot
.69823 .50723 Mdot
.60984 .39758 Mdot
.43708 .69589 Mdot
.67407 .68939 Mdot
.60713 .37529 Mdot
.3405 .50159 Mdot
.59414 .71633 Mdot
.43219 .49549 Mdot
.73529 .34327 Mdot
.42013 .64905 Mdot
.58992 .36046 Mdot
.46165 .62951 Mdot
.68698 .526 Mdot
.5714 .35935 Mdot
.36 .49491 Mdot
.57978 .40609 Mdot
.53193 .37765 Mdot
.57142 .27315 Mdot
.43593 .71825 Mdot
.50188 .24909 Mdot
.45847 .63349 Mdot
.58215 .715 Mdot
.35494 .32177 Mdot
.494 .30144 Mdot
.61435 .41351 Mdot
.79498 .5844 Mdot
.58872 .35419 Mdot
.38701 .45977 Mdot
.4055 .46455 Mdot
.57986 .38315 Mdot
.52011 .30587 Mdot
.34726 .24897 Mdot
.48847 .2278 Mdot
.47043 .68623 Mdot
.49789 .53216 Mdot
.84514 .60316 Mdot
.58117 .33787 Mdot
.67887 .50274 Mdot
.293 .47839 Mdot
.36219 .45951 Mdot
.67274 .4983 Mdot
.69844 .54469 Mdot
.47762 .29022 Mdot
.62612 .3794 Mdot
.46996 .62869 Mdot
.64332 .51939 Mdot
.40455 .60143 Mdot
.35276 .25846 Mdot
.31599 .48995 Mdot
.42234 .41696 Mdot
.41086 .50787 Mdot
.56548 .50141 Mdot
.69553 .55432 Mdot
.38068 .50275 Mdot
.43769 .46587 Mdot
.65965 .51214 Mdot
.47974 .27759 Mdot
.40637 .62578 Mdot
.60313 .40341 Mdot
.14384 .38409 Mdot
.385 .52355 Mdot
.38183 .4677 Mdot
.6607 .53455 Mdot
.25499 .69995 Mdot
.46242 .64741 Mdot
.44144 .69813 Mdot
.61901 .38092 Mdot
.58114 .57519 Mdot
.32554 .4795 Mdot
.36455 .50871 Mdot
.61838 .40882 Mdot
.60088 .71374 Mdot
.36548 .8002 Mdot
.39025 .49328 Mdot
.6759 .51896 Mdot
.76018 .48399 Mdot
.69098 .55659 Mdot
.39299 .43843 Mdot
.39094 .45899 Mdot
.3857 .52672 Mdot
.40075 .45021 Mdot
.6456 .50747 Mdot
.36033 .50646 Mdot
.42752 .54781 Mdot
.46484 .67223 Mdot
.34181 .49605 Mdot
.42265 .22493 Mdot
.38996 .48877 Mdot
.51738 .29307 Mdot
.64116 .67171 Mdot
.40487 .49934 Mdot
.34219 .49925 Mdot
.49375 .22798 Mdot
.37381 .48307 Mdot
.69816 .52812 Mdot
.44497 .68468 Mdot
.68681 .52288 Mdot
.69001 .51362 Mdot
.58015 .41519 Mdot
.47649 .2731 Mdot
.4137 .53177 Mdot
.52163 .28464 Mdot
.32312 .44202 Mdot
.42413 .4667 Mdot
.56139 .53394 Mdot
.57686 .62616 Mdot
.46745 .26454 Mdot
.36177 .50059 Mdot
.617 .38603 Mdot
.58364 .36554 Mdot
.459 .35619 Mdot
.31365 .45895 Mdot
.65108 .5389 Mdot
.65206 .51036 Mdot
.43412 .30669 Mdot
.48776 .42178 Mdot
.51612 .29955 Mdot
.52812 .57425 Mdot
.42204 .49137 Mdot
.39943 .49992 Mdot
.37952 .42451 Mdot
.62198 .421 Mdot
.6038 .71738 Mdot
.62412 .36259 Mdot
.57037 .70441 Mdot
.67374 .55911 Mdot
.41563 .47294 Mdot
.80292 .44878 Mdot
.47024 .64882 Mdot
.44642 .6856 Mdot
.7087 .53158 Mdot
.64127 .3818 Mdot
.31751 .45272 Mdot
.36643 .18365 Mdot
.41149 .6662 Mdot
.53108 .30395 Mdot
.37067 .50932 Mdot
.61291 .39516 Mdot
.47764 .67213 Mdot
.47294 .27054 Mdot
.4177 .47944 Mdot
.61615 .34322 Mdot
.38295 .49108 Mdot
.28278 .6724 Mdot
.46024 .66482 Mdot
.56685 .66232 Mdot
.40761 .68344 Mdot
.67378 .49982 Mdot
.67602 .50869 Mdot
.39625 .46203 Mdot
.26242 .25276 Mdot
.40553 .64342 Mdot
.65904 .49666 Mdot
.49098 .26122 Mdot
.60447 .71186 Mdot
.48197 .26413 Mdot
.5949 .36422 Mdot
.49918 .29987 Mdot
.57196 .39425 Mdot
.45265 .32406 Mdot
.43142 .61974 Mdot
.48427 .28359 Mdot
.26052 .71008 Mdot
.43409 .49517 Mdot
.47944 .29704 Mdot
.43076 .4476 Mdot
.45466 .53961 Mdot
.61961 .40596 Mdot
.52085 .30041 Mdot
.34454 .44603 Mdot
.79863 .52542 Mdot
.68371 .51023 Mdot
.65207 .54148 Mdot
.42047 .52343 Mdot
.61394 .34841 Mdot
.43967 .72166 Mdot
.54826 .44925 Mdot
.60925 .71093 Mdot
.36478 .50815 Mdot
.42019 .48261 Mdot
.47823 .65081 Mdot
.42371 .69564 Mdot
.39475 .45929 Mdot
.22659 .54385 Mdot
.36048 .48538 Mdot
.66502 .5267 Mdot
.47473 .67848 Mdot
.44314 .68596 Mdot
.64198 .39995 Mdot
.47572 .65473 Mdot
.40357 .40825 Mdot
.62716 .50614 Mdot
.41427 .43528 Mdot
.68493 .52794 Mdot
.47469 .37184 Mdot
.62794 .37817 Mdot
.80238 .57778 Mdot
.47867 .66577 Mdot
.35329 .51092 Mdot
.44425 .63444 Mdot
.49908 .27353 Mdot
.46143 .68723 Mdot
.42371 .63127 Mdot
.41181 .47457 Mdot
.37529 .43947 Mdot
.5983 .71433 Mdot
.56584 .57859 Mdot
.4546 .66464 Mdot
.35408 .49389 Mdot
.41769 .52238 Mdot
.36714 .43483 Mdot
.55375 .4903 Mdot
.468 .70407 Mdot
.22369 .48536 Mdot
.76625 .37107 Mdot
.44843 .66032 Mdot
.81819 .61309 Mdot
.58774 .69559 Mdot
.59029 .73088 Mdot
.65728 .49485 Mdot
.39462 .49192 Mdot
.59432 .37468 Mdot
.34948 .51605 Mdot
.31001 .46729 Mdot
.40574 .50099 Mdot
.48352 .29764 Mdot
.35563 .53662 Mdot
.58547 .70128 Mdot
.60333 .3788 Mdot
.35501 .48652 Mdot
.39999 .47962 Mdot
.58445 .7286 Mdot
.40537 .67377 Mdot
.47258 .69082 Mdot
.63811 .71537 Mdot
.48292 .27466 Mdot
.66024 .54121 Mdot
.34546 .51222 Mdot
.61761 .38363 Mdot
.59644 .37942 Mdot
.42212 .6547 Mdot
.6035 .40703 Mdot
.67305 .5539 Mdot
.36588 .48223 Mdot
.66884 .4987 Mdot
.48308 .29676 Mdot
.43389 .68962 Mdot
.3424 .50958 Mdot
.35093 .44654 Mdot
.45174 .65405 Mdot
.37759 .45155 Mdot
.4937 .31116 Mdot
.61043 .42142 Mdot
.47221 .6773 Mdot
.68261 .5392 Mdot
.63846 .40573 Mdot
.35752 .45377 Mdot
.84816 .42225 Mdot
.37377 .46307 Mdot
.3729 .52001 Mdot
.65554 .77936 Mdot
.43461 .47993 Mdot
.60829 .35358 Mdot
.44432 .63305 Mdot
.38379 .43399 Mdot
.45708 .22067 Mdot
.65591 .34302 Mdot
.61909 .34206 Mdot
.3705 .51145 Mdot
.80152 .62021 Mdot
.3515 .50816 Mdot
.77471 .6145 Mdot
.56123 .53615 Mdot
.67807 .2357 Mdot
.43412 .43029 Mdot
.66449 .49622 Mdot
.60014 .71598 Mdot
.59725 .35124 Mdot
.3243 .71731 Mdot
.37634 .45662 Mdot
.38003 .73143 Mdot
.34862 .51843 Mdot
.66835 .52196 Mdot
.32414 .54061 Mdot
.5985 .40777 Mdot
.19461 .59338 Mdot
.33297 .48615 Mdot
.47228 .69818 Mdot
.56351 .38526 Mdot
.60193 .70458 Mdot
.34455 .44484 Mdot
.51172 .27472 Mdot
.66379 .38805 Mdot
.42506 .42694 Mdot
.6856 .53031 Mdot
.3945 .5034 Mdot
.29832 .48274 Mdot
.20485 .32441 Mdot
.46699 .67426 Mdot
.67382 .50247 Mdot
.47904 .59866 Mdot
.39741 .4524 Mdot
.47179 .69241 Mdot
.44471 .68216 Mdot
.50136 .26645 Mdot
.60052 .62024 Mdot
.62668 .32088 Mdot
.80589 .39797 Mdot
.36356 .694 Mdot
.63226 .41641 Mdot
.47256 .77961 Mdot
.34263 .47773 Mdot
.30775 .37671 Mdot
.69348 .51963 Mdot
.3797 .47013 Mdot
.35481 .63946 Mdot
.46404 .68061 Mdot
.38413 .4957 Mdot
.49464 .30571 Mdot
.56567 .72848 Mdot
.29617 .40804 Mdot
.84681 .48229 Mdot
.57664 .35009 Mdot
.38561 .42101 Mdot
.44213 .4558 Mdot
.60905 .71591 Mdot
.39721 .44157 Mdot
.59744 .35295 Mdot
.75364 .39883 Mdot
.5167 .30949 Mdot
.47315 .65421 Mdot
.59125 .69564 Mdot
.35653 .52645 Mdot
.42956 .49171 Mdot
.53244 .29628 Mdot
.33087 .46304 Mdot
.21718 .6281 Mdot
.60122 .73924 Mdot
.61089 .41765 Mdot
.45392 .705 Mdot
.41246 .50596 Mdot
.60314 .71469 Mdot
.41026 .47121 Mdot
.46253 .53504 Mdot
.3754 .5149 Mdot
.58616 .80054 Mdot
.4444 .65539 Mdot
.68858 .53285 Mdot
.37127 .54464 Mdot
.38817 .48141 Mdot
.63481 .27213 Mdot
.30934 .47129 Mdot
.4069 .4903 Mdot
.41851 .68061 Mdot
.46213 .63967 Mdot
.42469 .65664 Mdot
.61778 .41552 Mdot
.55735 .59668 Mdot
.67216 .5276 Mdot
.35162 .42305 Mdot
.64667 .52885 Mdot
.46345 .4658 Mdot
.52957 .29016 Mdot
.81991 .54878 Mdot
.36516 .47012 Mdot
.42424 .67063 Mdot
.47887 .79829 Mdot
.46448 .71076 Mdot
.70648 .50208 Mdot
.6941 .52745 Mdot
.45687 .67177 Mdot
.37164 .48978 Mdot
.55261 .5851 Mdot
.84055 .43739 Mdot
.68159 .547 Mdot
.40352 .43588 Mdot
.56987 .35581 Mdot
.56782 .38124 Mdot
.79869 .66817 Mdot
.69245 .51305 Mdot
.53056 .7479 Mdot
.35091 .49841 Mdot
.4689 .64487 Mdot
.6535 .52757 Mdot
.69951 .52827 Mdot
.61372 .40952 Mdot
.36534 .44258 Mdot
.38703 .48427 Mdot
.57862 .70586 Mdot
.64579 .52116 Mdot
.36843 .55346 Mdot
.37507 .44401 Mdot
.69925 .74846 Mdot
.48883 .65371 Mdot
.14311 .48491 Mdot
.31232 .51224 Mdot
.35947 .63759 Mdot
.50785 .43152 Mdot
.47306 .66346 Mdot
.32811 .47796 Mdot
.34594 .42528 Mdot
.63671 .41189 Mdot
.36787 .47581 Mdot
.63578 .38123 Mdot
.68377 .50426 Mdot
.82553 .54993 Mdot
.75847 .51511 Mdot
.61966 .52896 Mdot
.37856 .46165 Mdot
.31638 .39719 Mdot
.49134 .27785 Mdot
.70485 .55757 Mdot
.43897 .64119 Mdot
.41602 .50492 Mdot
.64645 .40402 Mdot
.60965 .41492 Mdot
.45135 .68138 Mdot
.53834 .76427 Mdot
.78838 .59184 Mdot
.40424 .45283 Mdot
.58797 .36606 Mdot
.76091 .53305 Mdot
.24277 .5408 Mdot
.67877 .49619 Mdot
.51325 .31059 Mdot
.61691 .35823 Mdot
.71232 .52868 Mdot
.46842 .51423 Mdot
.44864 .673 Mdot
.48149 .6619 Mdot
.6693 .3033 Mdot
.59095 .38887 Mdot
.49127 .28453 Mdot
.49899 .44318 Mdot
.49749 .46577 Mdot
.49334 .30707 Mdot
.6269 .36283 Mdot
.46992 .65125 Mdot
.43049 .65155 Mdot
.44312 .68347 Mdot
.20471 .60739 Mdot
.41914 .64623 Mdot
.19366 .45229 Mdot
.42188 .47346 Mdot
.22961 .59028 Mdot
.35714 .51094 Mdot
.64026 .51708 Mdot
.45901 .6631 Mdot
.55656 .54899 Mdot
.41131 .52009 Mdot
.8433 .46843 Mdot
.37475 .50681 Mdot
.64143 .46403 Mdot
.39596 .49058 Mdot
.24281 .656 Mdot
.48285 .65005 Mdot
.36029 .50044 Mdot
.63626 .49963 Mdot
.51093 .29635 Mdot
.40259 .66165 Mdot
.40452 .49419 Mdot
.6083 .76395 Mdot
.43413 .45799 Mdot
.78283 .63893 Mdot
.57216 .2242 Mdot
.52964 .31605 Mdot
.41261 .42781 Mdot
.58058 .42062 Mdot
.43458 .59324 Mdot
.23364 .61236 Mdot
.68154 .54654 Mdot
.24362 .46566 Mdot
.61891 .41128 Mdot
.33905 .54938 Mdot
.32768 .50692 Mdot
.52265 .30654 Mdot
.40688 .63476 Mdot
.66384 .52468 Mdot
.37356 .4561 Mdot
.32706 .46995 Mdot
.73842 .30525 Mdot
.2322 .61905 Mdot
.37286 .55283 Mdot
.51992 .26902 Mdot
.23038 .49014 Mdot
.4013 .5046 Mdot
.6215 .34354 Mdot
.43718 .63251 Mdot
.37739 .40443 Mdot
.22004 .48763 Mdot
.35583 .49 Mdot
.45649 .67538 Mdot
.47867 .66336 Mdot
.52862 .81827 Mdot
.52907 .29265 Mdot
.37581 .51485 Mdot
.64934 .27227 Mdot
.34084 .5036 Mdot
.6689 .52684 Mdot
.39351 .43752 Mdot
.6231 .39594 Mdot
.56867 .62537 Mdot
.62083 .41488 Mdot
.35501 .43781 Mdot
.43096 .66884 Mdot
.66074 .52713 Mdot
.69228 .31628 Mdot
.58796 .46837 Mdot
.19593 .44688 Mdot
.66352 .38126 Mdot
.52087 .29096 Mdot
.47526 .27057 Mdot
.63036 .4931 Mdot
.36861 .50233 Mdot
.56358 .47806 Mdot
.34823 .41837 Mdot
.39974 .49144 Mdot
.39065 .52023 Mdot
.68112 .572 Mdot
.69323 .53002 Mdot
.59881 .39393 Mdot
.39347 .45821 Mdot
.35408 .49508 Mdot
.44564 .66317 Mdot
.51091 .30185 Mdot
.60431 .42057 Mdot
.48591 .27367 Mdot
.60752 .38199 Mdot
.77153 .70242 Mdot
.39145 .43422 Mdot
.51112 .29512 Mdot
.69336 .55685 Mdot
.42227 .66862 Mdot
.58326 .72549 Mdot
.59561 .36461 Mdot
.5959 .40559 Mdot
.36001 .50745 Mdot
.44835 .69798 Mdot
.46316 .69721 Mdot
.52154 .28808 Mdot
.65026 .51503 Mdot
.34278 .43934 Mdot
.37653 .44148 Mdot
.66182 .24679 Mdot
.63202 .41374 Mdot
.22295 .52724 Mdot
.54086 .80275 Mdot
.36745 .50202 Mdot
.46648 .69709 Mdot
.3932 .47369 Mdot
.78898 .46762 Mdot
.42008 .67613 Mdot
.41236 .52488 Mdot
.45829 .39588 Mdot
.61773 .42214 Mdot
.52357 .83303 Mdot
.39152 .54125 Mdot
.69726 .48352 Mdot
.33922 .46376 Mdot
.58317 .85198 Mdot
.4481 .78069 Mdot
.35044 .52156 Mdot
.40433 .45458 Mdot
.80367 .37355 Mdot
.34877 .50134 Mdot
.58287 .70046 Mdot
.31037 .50196 Mdot
.47296 .69183 Mdot
.51894 .43642 Mdot
.57185 .53872 Mdot
.51948 .27446 Mdot
.61972 .38099 Mdot
.323 .3176 Mdot
.4828 .26994 Mdot
.45821 .65004 Mdot
.42395 .50249 Mdot
.3904 .61979 Mdot
.61172 .43774 Mdot
.31889 .4675 Mdot
.6685 .52528 Mdot
.57219 .54232 Mdot
.62639 .3671 Mdot
.68533 .53918 Mdot
.36726 .52682 Mdot
.45816 .19036 Mdot
.60272 .47709 Mdot
.57318 .8244 Mdot
.65953 .53549 Mdot
.6885 .5184 Mdot
.5513 .61105 Mdot
.51912 .27421 Mdot
.71844 .28416 Mdot
.27411 .4498 Mdot
.68512 .54935 Mdot
.39829 .30075 Mdot
.64227 .3704 Mdot
.59384 .62409 Mdot
.48765 .66731 Mdot
.38669 .4317 Mdot
.37544 .48813 Mdot
.6549 .51363 Mdot
.4123 .74207 Mdot
.46961 .55527 Mdot
.68772 .54209 Mdot
.44617 .48024 Mdot
.59854 .62955 Mdot
.59672 .71918 Mdot
.58087 .6979 Mdot
.50163 .2621 Mdot
.56871 .29686 Mdot
.43638 .65633 Mdot
.51811 .31519 Mdot
.5961 .68286 Mdot
.38019 .51424 Mdot
.64521 .52132 Mdot
.57719 .71765 Mdot
.6773 .53667 Mdot
.50843 .287 Mdot
.53089 .30011 Mdot
.4653 .67264 Mdot
.46106 .64573 Mdot
.26521 .51414 Mdot
.42478 .27901 Mdot
.34529 .50049 Mdot
.37877 .68321 Mdot
.42017 .66872 Mdot
.29905 .72511 Mdot
.52316 .28409 Mdot
.50782 .30576 Mdot
.26686 .61666 Mdot
.35632 .44941 Mdot
.75363 .49493 Mdot
.40426 .49879 Mdot
.36395 .32631 Mdot
.37255 .53438 Mdot
.61079 .40875 Mdot
.33603 .48651 Mdot
.66811 .67008 Mdot
.35569 .47686 Mdot
.40172 .51153 Mdot
.60344 .3659 Mdot
.36891 .54539 Mdot
.62382 .39929 Mdot
.37956 .43769 Mdot
.53203 .32133 Mdot
.61747 .38331 Mdot
.47406 .2259 Mdot
.53378 .39813 Mdot
.59837 .70722 Mdot
.49062 .26221 Mdot
.51363 .27744 Mdot
.41808 .2216 Mdot
.44584 .63955 Mdot
.47316 .50015 Mdot
.37023 .50229 Mdot
.62429 .35283 Mdot
.65894 .54361 Mdot
.35617 .49115 Mdot
.3771 .41237 Mdot
.39681 .54082 Mdot
.46189 .6745 Mdot
.62622 .36068 Mdot
.50468 .29238 Mdot
.57947 .37152 Mdot
.54883 .30249 Mdot
.57409 .36845 Mdot
.30091 .43815 Mdot
.32574 .52994 Mdot
.45035 .52542 Mdot
.37018 .6642 Mdot
.18622 .56328 Mdot
.44757 .67659 Mdot
.5887 .71147 Mdot
.52843 .28536 Mdot
.49587 .53066 Mdot
.42602 .66875 Mdot
.5919 .40197 Mdot
.38281 .49107 Mdot
.44717 .48706 Mdot
.29172 .42152 Mdot
.45798 .61404 Mdot
.4432 .24459 Mdot
.61586 .36769 Mdot
.58821 .72166 Mdot
.56654 .60759 Mdot
.49986 .70461 Mdot
.55375 .54262 Mdot
.39121 .47762 Mdot
.51659 .27852 Mdot
.47763 .67198 Mdot
.72578 .31989 Mdot
.65915 .50834 Mdot
.56338 .57915 Mdot
.37669 .46301 Mdot
.4942 .77214 Mdot
.4312 .66912 Mdot
.50506 .30827 Mdot
.65537 .5137 Mdot
.52677 .28792 Mdot
.59404 .69493 Mdot
.64253 .69187 Mdot
.33598 .45421 Mdot
.40782 .48979 Mdot
.67037 .55723 Mdot
.43482 .65802 Mdot
.63685 .43243 Mdot
.74922 .32906 Mdot
.58621 .36891 Mdot
.57275 .49288 Mdot
.47649 .67416 Mdot
.46653 .75958 Mdot
.57787 .40102 Mdot
.7051 .55111 Mdot
.56256 .48492 Mdot
.70785 .53352 Mdot
.40012 .51 Mdot
.44138 .69067 Mdot
.69258 .51285 Mdot
.68038 .29348 Mdot
.7579 .70157 Mdot
.41344 .61431 Mdot
.38806 .45131 Mdot
.82262 .54631 Mdot
.68525 .73823 Mdot
.39774 .7074 Mdot
.64383 .5129 Mdot
.39421 .46494 Mdot
.40746 .45599 Mdot
.33369 .48734 Mdot
.67637 .50549 Mdot
.61779 .46554 Mdot
.59474 .40956 Mdot
.38195 .50489 Mdot
.50436 .27317 Mdot
.61822 .39975 Mdot
.57468 .41278 Mdot
.59479 .35166 Mdot
.4197 .67739 Mdot
.42465 .48359 Mdot
.55345 .67541 Mdot
.61695 .83277 Mdot
.69072 .52676 Mdot
.59813 .70683 Mdot
.38513 .52507 Mdot
.21785 .39169 Mdot
.42422 .65911 Mdot
.58527 .37148 Mdot
.38129 .46922 Mdot
.59305 .2419 Mdot
.61869 .74023 Mdot
.60944 .37177 Mdot
.43976 .64176 Mdot
.39641 .70236 Mdot
.36714 .47661 Mdot
.34102 .46252 Mdot
.44222 .64902 Mdot
.63275 .75401 Mdot
.57577 .62031 Mdot
.3948 .47579 Mdot
.68856 .5352 Mdot
.19572 .32342 Mdot
.42837 .50283 Mdot
.45842 .61206 Mdot
.60531 .71482 Mdot
.58401 .79369 Mdot
.22683 .52309 Mdot
.32276 .42261 Mdot
.81968 .50734 Mdot
.30489 .31627 Mdot
.82364 .56551 Mdot
.31171 .34623 Mdot
.75829 .54806 Mdot
.70839 .77376 Mdot
.64382 .49485 Mdot
.25182 .66393 Mdot
.73722 .27577 Mdot
.54819 .74367 Mdot
.54366 .22791 Mdot
.70602 .37271 Mdot
.59537 .23435 Mdot
.2805 .7451 Mdot
.57161 .37569 Mdot
.34849 .34634 Mdot
.33072 .45416 Mdot
.68 .73413 Mdot
.21347 .57573 Mdot
.17822 .54089 Mdot
.81468 .554 Mdot
.63494 .26198 Mdot
.83287 .39138 Mdot
.79831 .57328 Mdot
.29194 .53648 Mdot
.37639 .37363 Mdot
.57574 .31191 Mdot
.49789 .45156 Mdot
.31252 .32425 Mdot
.41958 .40884 Mdot
.66626 .65486 Mdot
.62418 .52942 Mdot
.30708 .56795 Mdot
.18534 .35616 Mdot
.60468 .35592 Mdot
.43518 .63273 Mdot
.71012 .27186 Mdot
.44546 .60215 Mdot
.64923 .47943 Mdot
.82004 .50682 Mdot
.69825 .75291 Mdot
.23961 .65091 Mdot
.58129 .67096 Mdot
.2899 .66535 Mdot
.34225 .24722 Mdot
.35789 .36999 Mdot
.46158 .71641 Mdot
.7087 .44393 Mdot
.49696 .46469 Mdot
.55785 .32269 Mdot
.25731 .68376 Mdot
.4711 .27371 Mdot
.4697 .22466 Mdot
.43573 .64521 Mdot
.24786 .5376 Mdot
.59503 .73278 Mdot
.57326 .68151 Mdot
.65134 .38928 Mdot
.78665 .45156 Mdot
.60719 .75068 Mdot
.59252 .75672 Mdot
.43781 .80611 Mdot
.85799 .4611 Mdot
.36754 .27076 Mdot
.74443 .37778 Mdot
.68282 .48046 Mdot
.31875 .30163 Mdot
.54682 .65247 Mdot
.40833 .26697 Mdot
.48193 .44924 Mdot
.77823 .2846 Mdot
.64374 .76499 Mdot
.82325 .35662 Mdot
.45423 .72884 Mdot
.42796 .5219 Mdot
.76502 .39642 Mdot
.35892 .70495 Mdot
.5131 .32643 Mdot
.85456 .4719 Mdot
.52613 .31215 Mdot
.46485 .62527 Mdot
.54444 .74569 Mdot
.21287 .61128 Mdot
.64033 .43669 Mdot
.46105 .29583 Mdot
.38981 .40753 Mdot
.75032 .2367 Mdot
.82374 .49141 Mdot
.544 .81274 Mdot
.69142 .75401 Mdot
.58752 .33598 Mdot
.5911 .43282 Mdot
.6883 .50594 Mdot
.72788 .74179 Mdot
.43305 .67972 Mdot
.62297 .83353 Mdot
.72427 .73915 Mdot
.48813 .62344 Mdot
.73597 .21837 Mdot
.35785 .79035 Mdot
.2274 .57885 Mdot
.24656 .41734 Mdot
.52712 .19232 Mdot
.5432 .62527 Mdot
.47288 .75777 Mdot
.56845 .34981 Mdot
.62232 .78719 Mdot
.7808 .68301 Mdot
.40267 .30977 Mdot
.67714 .58397 Mdot
.54089 .69754 Mdot
.46821 .36644 Mdot
.42989 .61432 Mdot
.51858 .21788 Mdot
.45474 .36147 Mdot
.8306 .37508 Mdot
.23657 .47496 Mdot
.29997 .22568 Mdot
.32513 .3363 Mdot
.24869 .69208 Mdot
.78265 .54607 Mdot
.48526 .33405 Mdot
.46566 .53887 Mdot
.57347 .76697 Mdot
.41705 .44298 Mdot
.52978 .58253 Mdot
.39699 .57002 Mdot
.53939 .28349 Mdot
.5551 .60378 Mdot
.7467 .65747 Mdot
.34352 .32315 Mdot
.79484 .3954 Mdot
.39054 .37763 Mdot
.44601 .7058 Mdot
.40127 .25739 Mdot
.3746 .29204 Mdot
.71715 .72771 Mdot
.48092 .60032 Mdot
.58871 .81354 Mdot
.4724 .58918 Mdot
.35389 .41556 Mdot
.25981 .67248 Mdot
.43866 .42631 Mdot
.39642 .28711 Mdot
.38202 .54004 Mdot
.44984 .80745 Mdot
.66095 .77443 Mdot
.3539 .60946 Mdot
.33971 .30564 Mdot
.3708 .64453 Mdot
.62745 .78778 Mdot
.76955 .397 Mdot
.4882 .75813 Mdot
.44086 .76406 Mdot
.7594 .25098 Mdot
.60764 .40106 Mdot
.40773 .29835 Mdot
.67924 .56744 Mdot
.68582 .30914 Mdot
.71879 .25554 Mdot
.46615 .57374 Mdot
.65487 .78554 Mdot
.56616 .74981 Mdot
.61643 .44328 Mdot
.63619 .62033 Mdot
.71192 .57165 Mdot
.37636 .62021 Mdot
.41529 .53196 Mdot
.42523 .57513 Mdot
.49763 .31402 Mdot
.34014 .70203 Mdot
.75802 .36858 Mdot
.67669 .4104 Mdot
.32203 .41922 Mdot
.68266 .43222 Mdot
.58334 .71891 Mdot
.57501 .58406 Mdot
.79144 .68325 Mdot
.303 .47582 Mdot
.33502 .77472 Mdot
.64196 .75608 Mdot
.56715 .50275 Mdot
.5529 .28486 Mdot
.5141 .79526 Mdot
.80825 .3241 Mdot
.68583 .77839 Mdot
.71256 .70156 Mdot
.82338 .53965 Mdot
.42829 .85236 Mdot
.67801 .22121 Mdot
.36459 .74876 Mdot
.67311 .56623 Mdot
.3177 .84104 Mdot
.57625 .38913 Mdot
.23747 .4367 Mdot
.35744 .70059 Mdot
.59471 .24981 Mdot
.4355 .59834 Mdot
.38055 .38558 Mdot
.63143 .33675 Mdot
.40878 .65015 Mdot
.38006 .40846 Mdot
.85858 .51784 Mdot
.7829 .2866 Mdot
.86063 .50156 Mdot
.64511 .69447 Mdot
.83132 .56362 Mdot
.78642 .32502 Mdot
.19113 .45863 Mdot
.73109 .29081 Mdot
.39327 .43776 Mdot
.42724 .31852 Mdot
.36926 .79049 Mdot
.65195 .4083 Mdot
.56322 .67816 Mdot
.49209 .69353 Mdot
.7691 .28425 Mdot
.79768 .67756 Mdot
.2857 .62232 Mdot
.26656 .53886 Mdot
.52242 .3892 Mdot
.41422 .27865 Mdot
.38572 .58906 Mdot
.67279 .64507 Mdot
.75734 .68456 Mdot
.77843 .31371 Mdot
.36752 .3029 Mdot
.70504 .39134 Mdot
.71723 .68655 Mdot
.36888 .77635 Mdot
.7957 .53354 Mdot
.70527 .26501 Mdot
.46856 .60345 Mdot
.47083 .73929 Mdot
.46793 .55919 Mdot
.65782 .64292 Mdot
.76587 .44497 Mdot
.34953 .27872 Mdot
.6317 .39328 Mdot
.41044 .31008 Mdot
.53277 .50712 Mdot
.72903 .28603 Mdot
.33696 .27813 Mdot
.39824 .31505 Mdot
.73275 .68335 Mdot
.8507 .53063 Mdot
.62608 .75737 Mdot
.49005 .18555 Mdot
.74336 .58386 Mdot
.383 .57078 Mdot
.40777 .54739 Mdot
.64393 .78574 Mdot
.85134 .56834 Mdot
.66145 .78477 Mdot
.48832 .77464 Mdot
.66761 .29321 Mdot
.70338 .50665 Mdot
.32826 .27864 Mdot
.6696 .44105 Mdot
.76465 .6802 Mdot
.5071 .54072 Mdot
.69921 .49941 Mdot
.55692 .72374 Mdot
.26949 .51408 Mdot
.27165 .34796 Mdot
.28921 .56909 Mdot
.31509 .4629 Mdot
.23658 .55845 Mdot
.46673 .63538 Mdot
.48462 .77222 Mdot
.4085 .27374 Mdot
.61038 .39835 Mdot
.63841 .22361 Mdot
.40628 .59483 Mdot
.43637 .49135 Mdot
.75496 .40909 Mdot
.42613 .6153 Mdot
.36738 .66094 Mdot
.57942 .42681 Mdot
.73116 .74954 Mdot
.41727 .79172 Mdot
.38176 .59455 Mdot
.38315 .25982 Mdot
.66246 .25273 Mdot
.58094 .61347 Mdot
.65923 .55834 Mdot
.80922 .55813 Mdot
.53624 .4156 Mdot
.39466 .26231 Mdot
.23336 .55075 Mdot
.74958 .34028 Mdot
.356 .41909 Mdot
.51443 .8099 Mdot
.20489 .43148 Mdot
.57798 .58182 Mdot
.48955 .6438 Mdot
.41317 .65893 Mdot
.20867 .68083 Mdot
.68003 .67107 Mdot
.51626 .66741 Mdot
.80412 .53921 Mdot
.69913 .51424 Mdot
.43076 .70166 Mdot
.40226 .32137 Mdot
.57795 .27756 Mdot
.24602 .50263 Mdot
.77204 .45047 Mdot
.3078 .54557 Mdot
.69186 .47728 Mdot
.81898 .53571 Mdot
.83029 .44354 Mdot
.21621 .30543 Mdot
.41001 .68641 Mdot
.72742 .34146 Mdot
.72436 .33382 Mdot
.46227 .71478 Mdot
.45863 .61361 Mdot
.30922 .39996 Mdot
.82521 .59063 Mdot
.50826 .51751 Mdot
.65945 .63256 Mdot
.5639 .48547 Mdot
.54745 .23564 Mdot
.73476 .31846 Mdot
.32697 .30119 Mdot
.79768 .51853 Mdot
.27161 .55907 Mdot
.56368 .18236 Mdot
.44415 .53724 Mdot
.23094 .44577 Mdot
.32817 .27846 Mdot
.4082 .36669 Mdot
.26447 .69112 Mdot
.76453 .63814 Mdot
.34226 .50318 Mdot
.86339 .47604 Mdot
.71669 .72121 Mdot
.52543 .58533 Mdot
.56142 .33396 Mdot
.35194 .46749 Mdot
.42438 .47979 Mdot
.41996 .75491 Mdot
.56289 .79993 Mdot
.61901 .18415 Mdot
.3403 .33428 Mdot
.37603 .57094 Mdot
.22946 .55149 Mdot
.3356 .7747 Mdot
.77315 .41667 Mdot
.79128 .61061 Mdot
.52779 .52543 Mdot
.37787 .79165 Mdot
.64714 .60388 Mdot
.63982 .63291 Mdot
.75357 .57456 Mdot
.79197 .33349 Mdot
.28956 .44684 Mdot
.5651 .78588 Mdot
.71227 .28456 Mdot
.38467 .52435 Mdot
.53827 .76485 Mdot
.79306 .54932 Mdot
.31726 .23084 Mdot
.54038 .65157 Mdot
.86277 .5467 Mdot
.44012 .54985 Mdot
.57766 .77879 Mdot
.72494 .25398 Mdot
.42177 .15865 Mdot
.65778 .65503 Mdot
.83475 .38934 Mdot
.62396 .61176 Mdot
.80431 .53217 Mdot
.66752 .49608 Mdot
.52128 .46726 Mdot
.38197 .71496 Mdot
.82296 .59633 Mdot
.61112 .29923 Mdot
.79716 .4706 Mdot
.41251 .75727 Mdot
.83715 .57623 Mdot
.47764 .45138 Mdot
.20557 .67048 Mdot
.64295 .3564 Mdot
.39748 .81562 Mdot
.38113 .76237 Mdot
.38634 .58028 Mdot
.39132 .30482 Mdot
.19678 .64026 Mdot
.18574 .4975 Mdot
.37272 .74603 Mdot
.40915 .34123 Mdot
.52586 .79839 Mdot
.37783 .25731 Mdot
.76321 .68663 Mdot
.26101 .72843 Mdot
.7323 .3291 Mdot
.52921 .71905 Mdot
.63882 .73112 Mdot
.5614 .8042 Mdot
.73841 .63157 Mdot
.7604 .40472 Mdot
.61745 .65424 Mdot
.29576 .53394 Mdot
.11115 .45945 Mdot
.60593 .56749 Mdot
.29909 .41207 Mdot
.80406 .32547 Mdot
.75178 .69044 Mdot
.5003 .53775 Mdot
.24949 .67707 Mdot
.24349 .36822 Mdot
.4564 .32695 Mdot
.40594 .50002 Mdot
.83824 .57097 Mdot
.46414 .31478 Mdot
.84328 .43386 Mdot
.5892 .82612 Mdot
.25051 .56429 Mdot
.29775 .4601 Mdot
.56529 .35736 Mdot
.32169 .38046 Mdot
.40119 .34631 Mdot
.80803 .34477 Mdot
.23441 .44284 Mdot
.57221 .46417 Mdot
.73078 .49878 Mdot
.76611 .50184 Mdot
.32585 .5462 Mdot
.37437 .79666 Mdot
.54587 .79735 Mdot
.32697 .32464 Mdot
.70639 .69387 Mdot
.40399 .29116 Mdot
.2257 .5266 Mdot
.34009 .26847 Mdot
.50718 .58958 Mdot
.59828 .32543 Mdot
.64286 .40222 Mdot
.79793 .37242 Mdot
.78761 .57731 Mdot
.45668 .80654 Mdot
.50031 .18784 Mdot
.56857 .76786 Mdot
.35627 .35092 Mdot
.77723 .37685 Mdot
.53806 .6269 Mdot
.61282 .30986 Mdot
.26326 .3622 Mdot
.23954 .47213 Mdot
.77702 .6241 Mdot
.40709 .38693 Mdot
.78279 .68333 Mdot
.34559 .28325 Mdot
.76835 .33575 Mdot
.51961 .39551 Mdot
.3449 .6749 Mdot
.25097 .62973 Mdot
.54556 .19475 Mdot
.57699 .57455 Mdot
.75241 .24058 Mdot
.47316 .70737 Mdot
.85696 .45751 Mdot
.66203 .54265 Mdot
.23122 .30738 Mdot
.77043 .65332 Mdot
.53862 .54046 Mdot
.54756 .47392 Mdot
.51504 .81284 Mdot
.61024 .75592 Mdot
.63643 .7585 Mdot
.46479 .56749 Mdot
.593 .3499 Mdot
.58365 .4622 Mdot
.66648 .63408 Mdot
.80558 .41187 Mdot
.36965 .43169 Mdot
.63105 .44289 Mdot
.39158 .36643 Mdot
.73201 .53759 Mdot
.64707 .77827 Mdot
.77122 .6087 Mdot
.42595 .41797 Mdot
.41607 .27569 Mdot
.78417 .31341 Mdot
.72854 .72747 Mdot
.47643 .54472 Mdot
.401 .56862 Mdot
.63656 .47306 Mdot
.6654 .22921 Mdot
.81911 .47877 Mdot
.75738 .50797 Mdot
.58642 .63037 Mdot
.36703 .27381 Mdot
.88348 .51913 Mdot
.78031 .28517 Mdot
.52539 .1782 Mdot
.56494 .48193 Mdot
.46267 .73269 Mdot
.2191 .39543 Mdot
.77061 .34015 Mdot
.40909 .82173 Mdot
.71547 .711 Mdot
.40393 .29699 Mdot
.35415 .2096 Mdot
.19161 .54609 Mdot
.56565 .44605 Mdot
.25249 .63156 Mdot
.36652 .68683 Mdot
.7143 .5127 Mdot
.45898 .33691 Mdot
.54518 .44017 Mdot
.64283 .47912 Mdot
.52972 .79852 Mdot
.59057 .7524 Mdot
.76658 .3318 Mdot
.22027 .46635 Mdot
.40518 .5689 Mdot
.80275 .43072 Mdot
.44464 .61489 Mdot
.72374 .322 Mdot
.6707 .25704 Mdot
.55712 .44724 Mdot
.57605 .37572 Mdot
.38815 .39872 Mdot
.58649 .59493 Mdot
.626 .60478 Mdot
.42251 .19334 Mdot
.5106 .322 Mdot
.46281 .72297 Mdot
.18848 .57998 Mdot
.41554 .69864 Mdot
.85003 .59524 Mdot
.67534 .64442 Mdot
.23214 .56226 Mdot
.64646 .59473 Mdot
.71155 .41531 Mdot
.42657 .17773 Mdot
.28465 .53007 Mdot
.48807 .22605 Mdot
.48077 .7238 Mdot
.46676 .63675 Mdot
.67546 .59413 Mdot
.60782 .73276 Mdot
.25732 .53824 Mdot
.30758 .76033 Mdot
.65948 .24898 Mdot
.42511 .71179 Mdot
.59085 .45274 Mdot
.40018 .63176 Mdot
.78387 .69162 Mdot
.58267 .36503 Mdot
.7677 .26091 Mdot
.32198 .52691 Mdot
.65155 .21452 Mdot
.64815 .7823 Mdot
.56583 .62832 Mdot
.56807 .47941 Mdot
.69552 .3484 Mdot
.3724 .418 Mdot
.38576 .57499 Mdot
.45127 .64175 Mdot
.73857 .30074 Mdot
.50274 .30209 Mdot
.43438 .2514 Mdot
.63975 .54366 Mdot
.29649 .7353 Mdot
.39226 .79771 Mdot
.4616 .63139 Mdot
.54056 .37564 Mdot
.72027 .34305 Mdot
.45346 .38728 Mdot
.39788 .36605 Mdot
.80015 .36853 Mdot
.27068 .53217 Mdot
.4697 .70857 Mdot
.52352 .18026 Mdot
.45496 .36001 Mdot
.69478 .77988 Mdot
.46696 .46416 Mdot
.34715 .37352 Mdot
.40983 .37614 Mdot
.50894 .80316 Mdot
.22735 .51931 Mdot
.78532 .6362 Mdot
.40432 .25979 Mdot
.49014 .4347 Mdot
.40135 .31549 Mdot
.41673 .40951 Mdot
.74704 .52222 Mdot
.3801 .80827 Mdot
.36343 .20548 Mdot
.28573 .67145 Mdot
.54948 .66432 Mdot
.4758 .62398 Mdot
.34244 .77829 Mdot
.46659 .71722 Mdot
.54044 .27075 Mdot
.31633 .57382 Mdot
.76904 .6561 Mdot
.73796 .73237 Mdot
.71631 .72809 Mdot
.31035 .38435 Mdot
.76394 .50875 Mdot
.25477 .39073 Mdot
.44737 .5486 Mdot
.54615 .53832 Mdot
.37765 .41543 Mdot
.33617 .551 Mdot
.49589 .55769 Mdot
.47613 .8 Mdot
.29215 .48794 Mdot
.81834 .59591 Mdot
.69349 .77843 Mdot
.8401 .53672 Mdot
.76367 .44034 Mdot
.41809 .64044 Mdot
.79997 .312 Mdot
.20632 .5148 Mdot
.75348 .69873 Mdot
.37608 .76024 Mdot
.22935 .70855 Mdot
.73291 .26489 Mdot
.75311 .65377 Mdot
.5153 .70923 Mdot
.53038 .83446 Mdot
.65054 .76455 Mdot
.20846 .67383 Mdot
.25426 .44853 Mdot
.64203 .78125 Mdot
.74315 .23312 Mdot
.34392 .74426 Mdot
.60308 .75878 Mdot
.24476 .62676 Mdot
.25072 .46006 Mdot
.27114 .73234 Mdot
.42459 .46514 Mdot
.57144 .39861 Mdot
.567 .22777 Mdot
.39318 .29848 Mdot
.39088 .39525 Mdot
.25391 .71533 Mdot
.3989 .34843 Mdot
.34527 .34932 Mdot
.68634 .31673 Mdot
.73672 .27363 Mdot
.23519 .52042 Mdot
.4433 .45961 Mdot
.49539 .6812 Mdot
.47914 .27004 Mdot
.29265 .35063 Mdot
.36092 .45795 Mdot
.56842 .54681 Mdot
.28727 .43739 Mdot
.86043 .52544 Mdot
.56727 .25483 Mdot
.61781 .5179 Mdot
.40964 .66281 Mdot
.54829 .80401 Mdot
.7893 .43025 Mdot
.54678 .74375 Mdot
.23393 .68985 Mdot
.25792 .50958 Mdot
.82033 .5257 Mdot
.57552 .75736 Mdot
.35291 .29755 Mdot
.37645 .22237 Mdot
.63852 .51147 Mdot
.37493 .71511 Mdot
.80556 .34633 Mdot
.54945 .76911 Mdot
.45656 .61813 Mdot
.724 .66759 Mdot
.74513 .51377 Mdot
.54193 .78083 Mdot
.64139 .75527 Mdot
.74635 .35142 Mdot
.25291 .59301 Mdot
.82722 .4474 Mdot
.5647 .36739 Mdot
.37158 .30649 Mdot
.69789 .67042 Mdot
.27195 .73526 Mdot
.4531 .38829 Mdot
.79682 .65248 Mdot
.54353 .52989 Mdot
.46207 .23905 Mdot
.33944 .45414 Mdot
.22041 .48376 Mdot
.48916 .79745 Mdot
.70752 .68571 Mdot
.49539 .62491 Mdot
.43991 .6221 Mdot
.43262 .80167 Mdot
.55808 .33358 Mdot
.46482 .32367 Mdot
.25804 .41115 Mdot
.45635 .7638 Mdot
.52184 .25647 Mdot
.56951 .7188 Mdot
.33635 .53918 Mdot
.47521 .21671 Mdot
.76996 .478 Mdot
.38175 .72965 Mdot
.36045 .7478 Mdot
.80083 .37691 Mdot
.772 .43896 Mdot
.44722 .81201 Mdot
.39189 .75667 Mdot
.59381 .79638 Mdot
.19649 .53226 Mdot
.53404 .69534 Mdot
.40315 .53658 Mdot
.54042 .27088 Mdot
.45729 .71307 Mdot
.80934 .41477 Mdot
.43233 .57856 Mdot
.46828 .23312 Mdot
.52854 .56053 Mdot
.76239 .39503 Mdot
.50794 .39207 Mdot
.65011 .77618 Mdot
.53031 .83465 Mdot
.40835 .27238 Mdot
.63069 .52028 Mdot
.63189 .61454 Mdot
.53629 .6451 Mdot
.80433 .62179 Mdot
.48537 .56534 Mdot
.38925 .6207 Mdot
.55019 .69805 Mdot
.35793 .6338 Mdot
.61402 .8095 Mdot
.42808 .27796 Mdot
.54936 .54491 Mdot
.38888 .59596 Mdot
.571 .67716 Mdot
.58475 .72691 Mdot
.59028 .25463 Mdot
.21014 .49948 Mdot
.64711 .579 Mdot
.58876 .47647 Mdot
.36242 .55204 Mdot
.21691 .39956 Mdot
.82116 .44851 Mdot
.495 .53322 Mdot
.53851 .52862 Mdot
.71012 .28617 Mdot
.45375 .30062 Mdot
.16889 .35462 Mdot
.86725 .49237 Mdot
.34054 .4537 Mdot
.53943 .46103 Mdot
.43286 .26047 Mdot
.63491 .37895 Mdot
.28691 .56341 Mdot
.8059 .38826 Mdot
.69737 .53064 Mdot
.67627 .2979 Mdot
.59124 .74132 Mdot
.50462 .81082 Mdot
.57113 .19423 Mdot
.70656 .50752 Mdot
.85475 .58786 Mdot
.70988 .71388 Mdot
.4913 .78935 Mdot
.13682 .39794 Mdot
.46772 .79268 Mdot
.47881 .47126 Mdot
.67972 .32061 Mdot
.85221 .53777 Mdot
.56801 .48798 Mdot
.67067 .30376 Mdot
.35045 .74116 Mdot
.40648 .26767 Mdot
.35594 .32768 Mdot
.52873 .72243 Mdot
.44905 .79223 Mdot
.1916 .65326 Mdot
.71212 .4129 Mdot
.45215 .17529 Mdot
.25411 .54854 Mdot
.83658 .45506 Mdot
.65794 .65347 Mdot
.34315 .21728 Mdot
.7295 .73921 Mdot
.4231 .32636 Mdot
.26345 .71862 Mdot
.57922 .29392 Mdot
.43984 .22352 Mdot
.20952 .4029 Mdot
.63379 .67062 Mdot
.27634 .53441 Mdot
.6979 .41513 Mdot
.50944 .63793 Mdot
.40615 .31241 Mdot
.36042 .65866 Mdot
.54974 .54178 Mdot
.82207 .38439 Mdot
.20785 .64618 Mdot
.38185 .26597 Mdot
.69956 .29806 Mdot
.44823 .22486 Mdot
.81033 .44972 Mdot
.78358 .49479 Mdot
.45626 .38236 Mdot
.67554 .19935 Mdot
.83049 .37561 Mdot
.53731 .69365 Mdot
.42344 .47572 Mdot
.70198 .77816 Mdot
.48332 .39055 Mdot
.36368 .74523 Mdot
.66087 .73813 Mdot
.33464 .33767 Mdot
.28335 .45866 Mdot
.42603 .51257 Mdot
.24563 .40844 Mdot
.51407 .70387 Mdot
.36268 .66455 Mdot
.60981 .21234 Mdot
.38607 .262 Mdot
.21354 .65124 Mdot
.57405 .18772 Mdot
.46635 .45613 Mdot
.47616 .68817 Mdot
.85567 .53244 Mdot
.34945 .57803 Mdot
.42073 .5723 Mdot
.23562 .59418 Mdot
.47813 .5602 Mdot
.65029 .33009 Mdot
.40008 .56785 Mdot
.5806 .61077 Mdot
.38899 .30442 Mdot
.77732 .35493 Mdot
.38572 .71874 Mdot
.73893 .21808 Mdot
.64852 .7873 Mdot
.42657 .71505 Mdot
.35109 .72861 Mdot
.55255 .43945 Mdot
.84018 .52699 Mdot
.70027 .39211 Mdot
.66513 .25413 Mdot
.17935 .57735 Mdot
.41538 .23359 Mdot
.34453 .52253 Mdot
.64588 .69764 Mdot
.75681 .71111 Mdot
.18046 .60193 Mdot
.78316 .682 Mdot
.29472 .46674 Mdot
.41796 .54178 Mdot
.3636 .16973 Mdot
.81036 .53342 Mdot
.31533 .43608 Mdot
.51409 .67594 Mdot
.50006 .64387 Mdot
.34943 .4381 Mdot
.6141 .73401 Mdot
.29997 .33027 Mdot
.35646 .33306 Mdot
.82381 .59031 Mdot
.41334 .67806 Mdot
.57017 .50543 Mdot
.70779 .55806 Mdot
.55964 .49983 Mdot
.44561 .44761 Mdot
.70165 .52301 Mdot
.35939 .3383 Mdot
.49957 .41075 Mdot
.66397 .41051 Mdot
.27285 .50541 Mdot
.59534 .64721 Mdot
.28869 .522 Mdot
.3422 .36685 Mdot
.45476 .75196 Mdot
.18516 .49617 Mdot
.39788 .34756 Mdot
.43711 .3538 Mdot
.64221 .77427 Mdot
.39699 .83674 Mdot
.57585 .5384 Mdot
.42188 .73522 Mdot
.47362 .46814 Mdot
.2143 .51263 Mdot
.24366 .5924 Mdot
.66071 .39536 Mdot
.59335 .72594 Mdot
.29491 .49188 Mdot
.38324 .59531 Mdot
.70553 .51744 Mdot
.87543 .53069 Mdot
.43156 .50433 Mdot
.27879 .58048 Mdot
.79207 .6406 Mdot
.7271 .32007 Mdot
.26736 .43344 Mdot
.38161 .41565 Mdot
.49094 .46795 Mdot
.49633 .40437 Mdot
.39162 .64291 Mdot
.7351 .31268 Mdot
.82795 .49114 Mdot
.27898 .39702 Mdot
.26538 .57419 Mdot
.37278 .50678 Mdot
.5362 .31065 Mdot
.57268 .59456 Mdot
.42082 .20201 Mdot
.46347 .25582 Mdot
.72864 .72327 Mdot
.3584 .35886 Mdot
.33952 .33426 Mdot
.22744 .61231 Mdot
.84927 .44816 Mdot
.53995 .66227 Mdot
.24693 .56564 Mdot
.51085 .57633 Mdot
.74044 .63603 Mdot
.40653 .34066 Mdot
.69823 .58234 Mdot
.3061 .52276 Mdot
.51302 .6931 Mdot
.82487 .62598 Mdot
.29084 .53629 Mdot
.64345 .55647 Mdot
.77863 .62369 Mdot
.19948 .53574 Mdot
.54667 .47409 Mdot
.11822 .43125 Mdot
.70004 .3746 Mdot
.85571 .57983 Mdot
.76244 .34999 Mdot
.43412 .38574 Mdot
.52396 .79611 Mdot
.35376 .40619 Mdot
.59893 .37173 Mdot
.83568 .51386 Mdot
.41714 .59451 Mdot
.5329 .70151 Mdot
.40218 .44201 Mdot
.50022 .49111 Mdot
.39771 .61646 Mdot
.77077 .53574 Mdot
.56769 .38337 Mdot
.47563 .54992 Mdot
.78759 .50547 Mdot
.4953 .40204 Mdot
.25867 .74139 Mdot
.80932 .34588 Mdot
.80898 .56157 Mdot
.76616 .4908 Mdot
.23669 .2936 Mdot
.48915 .71212 Mdot
.41614 .5993 Mdot
.63343 .50435 Mdot
.2507 .39754 Mdot
.544 .77572 Mdot
.76907 .34362 Mdot
.57531 .80952 Mdot
.45129 .38494 Mdot
.10062 .49526 Mdot
.41339 .3243 Mdot
.49253 .51767 Mdot
.5258 .77318 Mdot
.81502 .6057 Mdot
.65747 .26749 Mdot
.57238 .82463 Mdot
.67067 .65819 Mdot
.41721 .41144 Mdot
.20804 .43656 Mdot
.53258 .1844 Mdot
.74593 .50106 Mdot
.44407 .17435 Mdot
.78118 .55019 Mdot
.31369 .3235 Mdot
.70326 .68494 Mdot
.41123 .6918 Mdot
.43356 .59116 Mdot
.67783 .63911 Mdot
.56116 .67831 Mdot
.41656 .74708 Mdot
.82195 .49927 Mdot
.31199 .27556 Mdot
.69216 .26846 Mdot
.82705 .54282 Mdot
.7332 .52351 Mdot
.4821 .62749 Mdot
.39046 .35007 Mdot
.4704 .259 Mdot
.63575 .39785 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0aOooool2o`0008;ooooo000Loooo
o`03o`000?oooooooooo08Gooooo0_l00003ooooo`;o0000>Oooool2o`0008;ooooo000Looooo`03
o`000?oooooooooo08Gooooo0_l00003ooooo`;o0000_Oooool001cooooo00?o0000ooooooooool0
W_ooool2o`000:Wooooo000Looooo`03o`000?oooooooooo09kooooo0_l0002Yooooo`007?ooool0
0ol0003oooooooooo`1booooo`;o0000eOooool001cooooo00?o0000ooooooooool0L_ooool2o`00
01Sooooo0_l000000ooooooo0000o`00002hooooo`007?ooool00ol0003oooooooooo`27ooooo`;o
00000oooool2o`000004ooooool0003o0000o`0001Gooooo0_l0002Pooooo`007?ooool00ol0003o
ooooooooo`23ooooo`;o00000_ooool2o`0000Oooooo0_l0000Dooooo`?o0000X?ooool001cooooo
00?o0000ooooooooool0Loooool2o`0000kooooo0_l0000>ooooo`;o00004Oooool2o`000003oooo
ool0003o000000Sooooo0_l0000@ooooo`;o0000P_ooool001cooooo00?o0000ooooooooool0Looo
ool2o`0001Gooooo0_l00007ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00002?oo
ool2o`0000;ooooo0_l0000<ooooo`;o0000P_ooool001cooooo00?o0000ooooooooool0R_ooool2
o`0000Gooooo0_l00008ooooo`;o00000_ooool2o`000003ooooool0003o000001?ooooo0_l0000A
ooooo`;o0000OOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol0
0006ooooo`03o`000?oooooooooo08Kooooo0_l00005ooooo`;o00000_ooool2o`0000cooooo0_l0
0006ooooo`;o00008Oooool2o`0007gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1kooooo`;o
00002Oooool2o`0000Gooooo0_l0000Hooooo`;o00001?ooool2o`000003ooooool0003o000000;o
oooo1?l0002Aooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0NOooool4o`0000?ooooo0ol0000Zooooo`;o0000
00?oooooo`000?l000000_ooool5o`0001oooooo0_l0001_ooooo`0000?oooooo`000?ooool00_oo
ool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0001iooooo`?o00001?oo
ool3o`0000;ooooo0_l0000`ooooo`;o000000?oooooo`000?l000000_l0000Jooooo`;o0000Kooo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`05
ooooo`03o`000?oooooooooo07;ooooo0_l0000Aooooo`;o00008Oooool2o`00013ooooo1?l0000=
ooooo`;o0000O?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool03Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo0ol0000dooooo`;o00008Oooool2o`00
07cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@
4006ooooo`03o`000?oooooooooo06[ooooo0_l00003ooooo`Co0000Coooool2o`0001[ooooo0_l0
001Yooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`01_ooool00ol0003oooooooooo`1Yooooo`?o00000oooool2o`0000kooooo0_l0000oooooo`Co
00003?ooool2o`0000Oooooo0_l00003ooooo`;o0000JOooool001cooooo00?o0000ooooooooool0
JOooool2o`000003ooooool0003o0000017ooooo0_l00008ooooo`?o00001?ooool2o`0000Gooooo
0_l0000<ooooo`;o00006Oooool2o`0000kooooo0_l000000ooooooo0000o`000004ooooo`;o0000
4?ooool3o`0005_ooooo000Looooo`03o`000?oooooooooo06cooooo0_l0000Eooooo`?o000000?o
ooooo`000?l000001?l00003ooooo`?o000000Coooooo`000?l0003ooooo0_l0000<ooooo`;o0000
5?ooool2o`0001Kooooo0_l00002ooooo`?o00004Oooool3o`0005_ooooo000Looooo`03o`000?oo
oooooooo07Kooooo0ol00004ooooo`;o00001?ooool3o`000003ooooool0003o000000;ooooo0_l0
0003ooooo`?o000000Coooooo`000?l0003o00007oooool3o`0000;ooooo0_l0000?ooooo`;o0000
2Oooool3o`0000Kooooo0_l00009ooooo`;o0000G?ooool001cooooo00?o0000ooooooooool0Eooo
ool2o`0000Gooooo0_l0000Fooooo`?o00001?ooool2o`000004ooooool0003o0000ooooo`;o0000
00?oooooo`000?l000000oooool2o`000003ooooool0003o000000?o000000?oooooo`000?l00000
0_l00003ooooo`;o00004?ooool2o`0000Gooooo1Ol0000Cooooo`;o00004_ooool2o`0000Wooooo
0_l0001Looooo`007?ooool00ol0003oooooooooo`1Gooooo`;o00001Oooool2o`0000?ooooo0_l0
000Fooooo`;o00000oooool5o`000003ooooool0003o000000Kooooo0_l000000ooooooo0000o`00
0003ooooo`;o00000oooool4o`0000kooooo0_l00005ooooo`;o000000?oooooo`000?l000000_l0
000Iooooo`;o000000?oooooo`000?l00000L?ooool001cooooo00?o0000ooooooooool0Hoooool2
o`0001Kooooo0_l00003ooooo`Go000000?oooooo`000?l000003?ooool2o`0000Gooooo1?l00000
0ooooooo0000o`00000;ooooo`;o00002_ooool2o`0001Gooooo0_l00002ooooo`;o000000?ooooo
o`000?l000002oooool2o`0000Sooooo0_l0001Iooooo`007?ooool00ol0003oooooooooo`1joooo
o`?o00001_ooool2o`0000oooooo0_l00006ooooo`;o00000_ooool2o`0000cooooo0_l0000>oooo
o`;o00004?ooool2o`0000Kooooo0_l0000:ooooo`;o00002?ooool4o`0005Oooooo000Looooo`03
o`000?oooooooooo07[ooooo1ol00002ooooo`;o00003Oooool2o`0000;ooooo0_l0000Fooooo`;o
00003_ooool2o`0001;ooooo0_l00004ooooo`;o00005_ooool2o`0005Oooooo000Looooo`03o`00
0?oooooooooo07[ooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000Wooooo
0_l00002ooooo`?o00000_ooool2o`0001kooooo0_l00005ooooo`;o00004oooool2o`00013ooooo
0_l0000;ooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0L_ooool6o`0000?ooooo0_l0
0003ooooo`Co00002?ooool7o`0000Kooooo0_l000000ooooooo0000o`00000Hooooo`;o00001Ooo
ool2o`0001?ooooo0_l0000?ooooo`?o00002oooool2o`0005Kooooo000Looooo`03o`000?oooooo
oooo06_ooooo1?l00003ooooo`Ko00000oooool2o`0000?ooooo0_l0000:ooooo`Go00002?ooool2
o`000004ooooool0003o0000ooooo`;o0000<Oooool3o`0000Cooooo0_l00008ooooo`;o0000I?oo
ool001cooooo0_l0001/ooooo`Co00001?ooool3o`0001?ooooo0_l0000?ooooo`;o00000oooool3
o`0000cooooo0_l0000=ooooo`;o000000?oooooo`000?l000004?ooool3o`0000Cooooo0_l0000>
ooooo`;o00002?ooool2o`0005Cooooo000Looooo`03o`000?oooooooooo05;ooooo0_l0000Goooo
o`?o00001Oooool2o`00017ooooo0_l000000ooooooo0000o`000002ooooo`;o00002oooool2o`00
00Cooooo1?l0000:ooooo`;o00001?ooool2o`0000Kooooo0ol000000ooooooo0000o`000004oooo
o`;o00002oooool3o`0001;ooooo0ol00008ooooo`;o0000E?ooool001cooooo00?o0000oooooooo
ool0C?ooool2o`0000Cooooo0_l0000Gooooo`?o000000?oooooo`000?l000001_ooool2o`0000Ko
oooo0_l00005ooooo`;o00001Oooool2o`0000Cooooo0_l00006ooooo`?o000000?oooooo`000?l0
00000ol00002ooooo`;o00003?ooool2o`0000Kooooo0_l00008ooooo`;o00002oooool5o`0000ko
oooo1?l0001Oooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00008Oooool2o`0000Kooooo
1?l00004ooooo`?o00001oooool2o`0000Sooooo1?l00002ooooo`Go000000?oooooo`000?l00000
0ol000001?oooooo0000o`000?l0000^ooooo`;o000000?oooooo`000?l000002oooool2o`0000ko
oooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`1iooooo`Go00000_ooool2o`0000;ooooo
0_l00003ooooo`;o00002Oooool4o`000003ooooool0003o000000?o000000?oooooo`000?l00000
1_l00004ooooo`;o00006_ooool2o`000003ooooool0003o000000Gooooo0_l00006ooooo`;o0000
6oooool2o`00057ooooo000Looooo`03o`000?oooooooooo04oooooo0_l00004ooooo`;o00003_oo
ool2o`00017ooooo1_l00002ooooo`?o000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l0
00001?oooooo0000o`000?ooool4o`000003ooooool0003o000000co00001?ooool2o`0001[ooooo
0_l000000ooooooo0000o`000005ooooo`?o00000_ooool2o`0000Kooooo0_l000000ooooooo0000
o`000002ooooo`;o00000oooool2o`0005gooooo000Looooo`03o`000?oooooooooo04oooooo0_l0
0004ooooo`;o00003Oooool3o`0000Cooooo0ol00006ooooo`;o00000_ooool2o`0000Gooooo1?l0
0005ooooo`;o00001?ooool2o`000004ooooool0003o0000oooooa?o00001?ooool4o`0001_ooooo
0_l00006ooooo`;o00000_ooool3o`0000Cooooo0ol000000ooooooo0000o`000002ooooo`Oo0000
GOooool001cooooo00?o0000ooooooooool0I?ooool2o`0000Gooooo1?l00004ooooo`?o00002Ooo
ool4o`0000;ooooo1?l0000:oooooaGo00001?ooool3o`0000Oooooo0_l0000Booooo`;o00000ooo
ool2o`0000Kooooo0ol00003ooooo`;o00001?ooool2o`0000;ooooo1?l000000ooooooo0000o`00
001Kooooo`007?ooool00ol0003oooooooooo`1Rooooo`?o00002?ooool2o`0000Cooooo0_l0000:
ooooo`_o00002OoooolGo`0000?ooooo0_l00007ooooo`;o00004_ooool2o`0000?ooooo0_l00007
ooooo`;o00002Oooool2o`0000Oooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`1Roooo
o`?o00000_ooool5o`0000;ooooo0_l0000>ooooo`?o000000Goooooo`000?l0003o0000ooooo`04
o`0000gooooo5?l00002ooooo`?o00002?ooool2o`0002Wooooo0_l00007ooooo`;o0000Foooool0
01cooooo00?o0000ooooooooool0Ioooool5o`0000;ooooo0_l0000>ooooo`;o00000_ooool3o`00
0004ooooool0003o0000o`0000?ooooo0ol00007oooooa7o00000_ooool2o`0000?ooooo1?l00006
ooooo`;o00007_ooool3o`0000Sooooo0_l0001Tooooo`007?ooool00ol0003oooooooooo`1Voooo
o`;o00000oooool4o`0001Oooooo0_l00004ooooo`?o00001ooooolDo`000003ooooool0003o0000
00?ooooo0_l0000Vooooo`?o00002?ooool5o`000004ooooool0003o0000o`0000[ooooo0_l00000
1?oooooo0000o`000?l0001=ooooo`007?ooool00ol0003oooooooooo`1Vooooo`;o000000?ooooo
o`000?l000001?l0000>ooooo`Co00001Oooool2o`0000Cooooo0_l00005ooooo`;o000000?ooooo
o`000?l000004_l000000ooooooo0000o`000002o`000003ooooool0003o000002Kooooo1Ol00006
ooooo`Go000000Coooooo`000?l0003o00002_ooool2o`000004ooooool0003o0000o`0004gooooo
000Looooo`03o`000?oooooooooo06Kooooo0_l000000ooooooo0000o`00000;ooooo`;o00001Ooo
ool4o`0000_ooooo1?l000000ooooooo0000o`000002o`000003ooooool0003o000000?o000000?o
ooooo`000?l000003Ol00002ooooo`;o000000?oooooo`000?l000001oooool2o`0001kooooo1?l0
000=ooooo`;o00003_ooool2o`0004gooooo000Looooo`03o`000?oooooooooo04Kooooo0_l00000
0ooooooo0000o`00000Kooooo`;o00001?ooool2o`0000Sooooo0_l00007ooooo`;o00002oooool8
o`0000;ooooo5Ol00003ooooo`;o00002?ooool3o`0001[ooooo0_l00002ooooo`;o00000_ooool2
o`0000_ooooo1?l0000@ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0A?ooool4o`00
0003ooooool0003o000001_ooooo0_l00004ooooo`;o000000?oooooo`000?l000002Oooool4o`00
0003ooooool0003o000000;o00003Oooool4o`0000?ooooo5?l00003ooooo`Co00000oooool2o`00
0003ooooool0003o000000;o00006Oooool2o`000004ooooool0003o0000o`0000;ooooo1?l0000;
ooooo`;o00004?ooool2o`0004Wooooo000Looooo`;o0000?oooool2o`0000Cooooo0ol00003oooo
o`;o00006?ooool4o`0000Oooooo0_l00009ooooo`Wo00001_ooool2o`0000Gooooo1_l000000ooo
oooo0000o`00000Bo`0000Gooooo0_l00003ooooo`;o00000oooool2o`0000Oooooo0_l0000Coooo
o`;o00001Oooool2o`0000[ooooo1?l0001Jooooo`007?ooool00ol0003oooooooooo`0nooooo`;o
00002_ooool2o`0001Sooooo1?l0000<ooooo`;o00001Oooool5o`0000Gooooo0_l00002ooooo`;o
000000?oooooo`000?l000001?l00002ooooo`;o000000?oooooo`000?l000004_l00004ooooo`;o
00004_ooool2o`00017ooooo0_l0000Cooooo`Co0000F_ooool001cooooo00?o0000ooooooooool0
@oooool2o`0000;ooooo0_l0000Dooooo`;o00003?ooool2o`0000Oooooo0ol00004ooooo`;o0000
2?ooool2o`0000;ooooo0_l000000ooooooo0000o`000003o`0000Cooooo5_l000001?oooooo0000
o`000?ooool2o`0000Sooooo0_l0000Kooooo`;o00003oooool2o`0000?ooooo0_l00003ooooo`;o
0000E_ooool001cooooo00?o0000ooooooooool0@oooool2o`0000;ooooo0_l0000Dooooo`;o0000
00?oooooo`000?l000001?ooool2o`0000?ooooo0_l00008ooooo`;o00001?ooool3o`000004oooo
ool0003o0000ooooo`;o00001Oooool2o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l0
00005Ol0000:ooooo`;o00002?ooool2o`0001Kooooo0_l0000:ooooo`;o00000oooool2o`0000?o
oooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o000000?oooooo`000?l00000
1?ooool2o`0001Cooooo0_l000000ooooooo0000o`000003o`0000;ooooo0_l0000:ooooo`;o0000
00Coooooo`000?l0003ooooo5ol00008ooooo`;o00002_ooool2o`0001Kooooo0_l0000>ooooo`;o
00003?ooool4o`0000?ooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`1Mooooo`Co0000
1?ooool2o`0001Oooooo1?l00004ooooo`;o00001Oooool2o`0000?ooooo0ol00006ooooo`oo0000
0_ooool4o`0000Oooooo0_l0000Rooooo`Co00003?ooool2o`0000Gooooo0_l00005ooooo`Co0000
0oooool2o`0004Oooooo000Looooo`03o`000?oooooooooo05kooooo0ol00004ooooo`;o00005ooo
ool3o`0000Kooooo0_l00004ooooo`;o00001?ooool2o`0000Sooooo3ol00002ooooo`;o0000:ooo
ool4o`0000Wooooo0_l000000ooooooo0000o`000005ooooo`;o0000EOooool001cooooo00?o0000
ooooooooool0G_ooool2o`0000Gooooo0_l00005ooooo`;o00000_ooool2o`0000_ooooo1?l00006
ooooo`?o00005?ooool2o`000003ooooool0003o000000Wo00001Oooool2o`0000Gooooo0_l0000;
ooooo`;o000000?oooooo`000?l000003oooool2o`0000cooooo0ol000001?oooooo0000o`000?l0
001Kooooo`007?ooool00ol0003oooooooooo`0looooo`Go00008Oooool2o`0000;ooooo0_l00004
ooooo`;o00000_ooool4o`0000Wooooo1?l00002ooooo`;o00000oooool2o`0000Gooooo0_l00002
ooooo`;o00003?ooool7o`000003ooooool0003o000000Kooooo0_l00005ooooo`;o00001Oooool2
o`0000Cooooo0_l000000ooooooo0000o`00000?ooooo`;o00001Oooool2o`0000Gooooo0ol00002
ooooo`;o00001_ooool2o`0000Kooooo0_l00003ooooo`Co0000A?ooool001cooooo00?o0000oooo
ooooool0??ooool5o`0001Sooooo0_l00006ooooo`Co000000?oooooo`000?l000001?ooool2o`00
00;ooooo1?l0000;ooooo`;o00000_ooool2o`000003ooooool0003o000000Oooooo1_l00005oooo
o`;o00001oooool2o`000003ooooool0003o000001Oooooo0_l0000Oooooo`;o00001_ooool4o`00
00Cooooo0_l00002ooooo`;o00001_ooool2o`0000?ooooo1Ol00013ooooo`007?ooool00ol0003o
ooooooooo`0hooooo`;o00007oooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`0000Oo
oooo0_l00002ooooo`?o00003?ooool2o`0000Gooooo0_l00009ooooo`;o00001oooool2o`0000?o
oooo0_l00002ooooo`;o00005Oooool2o`0000Sooooo0_l00009ooooo`;o00002?ooool2o`0000go
oooo1Ol00003ooooo`;o00000_ooool3o`0000gooooo0_l00013ooooo`007?ooool00ol0003ooooo
ooooo`0hooooo`;o00008oooool3o`0000_ooooo0_l00003ooooo`;o0000:?ooool2o`0000?ooooo
0ol00003ooooo`;o00002oooool3o`0000Gooooo0_l00008ooooo`;o00002Oooool2o`0000Sooooo
0_l0000<ooooo`?o000000?oooooo`000?l000001oooool3o`0000Kooooo0_l0001:ooooo`007?oo
ool00ol0003oooooooooo`1Gooooo`;o00000oooool3o`0000Gooooo1?l000000ooooooo0000o`00
0002o`0000?ooooo0ol0000Nooooo`;o00001oooool2o`0000Cooooo0_l00003ooooo`;o00002ooo
ool3o`0000Cooooo1_l0000:ooooo`;o00007?ooool2o`0000gooooo0_l00005ooooo`;o0000B_oo
ool001cooooo00?o0000ooooooooool0Eoooool2o`000003ooooool0003o000000;o000000?ooooo
o`000?l000000oooool4o`000003ooooool0003o000000Kooooo0_l0000=ooooo`?o00003_ooool2
o`0002Kooooo1_l00004ooooo`;o00001?ooool2o`0001;ooooo0_l00009ooooo`;o00001_ooool2
o`0000Cooooo0ol0001@ooooo`007?ooool00ol0003oooooooooo`1Gooooo`;o000000?oooooo`00
0?l000000oooool2o`0001gooooo1Ol0000jooooo`;o000000Coooooo`000?l0003ooooo1Ol00009
ooooo`;o00002_ooool2o`0000Oooooo1?l000000ooooooo0000o`000003ooooo`;o00001?ooool3
o`0000[ooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00006oooool5o`00
00Wooooo0_l00009ooooo`;o00003_ooool4o`0000Wooooo0_l00003ooooo`;o00008Oooool2o`00
00;ooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000001_l00009oooo
o`;o00004oooool4o`000003ooooool0003o000000Wooooo0_l0000:ooooo`?o0000A?ooool001co
oooo0_l0000hooooo`;o00006Oooool6o`0000?ooooo0_l00005ooooo`;o00002?ooool3o`000003
ooooool0003o000000Wooooo1_l00009ooooo`;o00000_ooool4o`00023ooooo0_l000000ooooooo
0000o`000009o`000003ooooool0003o000000?o00006?ooool2o`0000Sooooo0_l00002ooooo`;o
00001_ooool2o`0000cooooo0ol00014ooooo`007?ooool00ol0003oooooooooo`1@ooooo`Oo0000
0oooool3o`0000oooooo0_l00002ooooo`;o00002Oooool2o`000003ooooool0003o000000Oooooo
0_l000000ooooooo0000o`000002ooooo`Co00008oooool2o`000004ooooool0003o0000ooooo`Go
000000?oooooo`000?l000000ol000000ooooooo0000o`000003o`0000;ooooo0_l0000>ooooo`Co
00002_ooool2o`000003ooooool0003o000000?ooooo0_l0001Cooooo`007?ooool00ol0003ooooo
ooooo`0cooooo`;o00001?ooool2o`0001Gooooo1Ol00005ooooo`;o0000:oooool2o`000004oooo
ool0003o0000o`0000Cooooo0_l0000Rooooo`;o000000?oooooo`000?l000004_l000001?oooooo
0000o`000?l0000?ooooo`?o00003Oooool2o`0000Gooooo0_l000000ooooooo0000o`00000=oooo
o`;o0000?oooool001cooooo00?o0000ooooooooool0<oooool4o`0000;ooooo0_l0000Dooooo`Co
00007_ooool2o`00013ooooo0_l00006ooooo`?o00000_ooool4o`00023ooooo5ol00002ooooo`;o
00009oooool2o`000003ooooool0003o000000gooooo0_l0000oooooo`007?ooool00ol0003ooooo
ooooo`0eooooo`;o00005oooool6o`000003ooooool0003o000001[ooooo0_l0000@ooooo`;o0000
1oooool2o`0000;ooooo1?l0000PoooooaWo00004oooool2o`0000Cooooo0_l00005ooooo`;o0000
0oooool2o`0005Gooooo000Looooo`03o`000?oooooooooo04gooooo0ol000001Ooooooo0000o`00
0?l0003ooooo00;o00004?ooool2o`0001;ooooo0_l000000ooooooo0000o`000002ooooo`;o0000
2?ooool6o`0002;ooooo0_l000000ooooooo0000o`00000Do`0000;ooooo0_l0000?ooooo`;o0000
1?ooool2o`0000Gooooo0_l00003ooooo`;o0000EOooool001cooooo00?o0000ooooooooool0=Ooo
ool2o`0001?ooooo1Ol00003ooooo`;o00004oooool2o`0000;ooooo0_l0000>ooooo`;o000000Co
ooooo`000?l0003ooooo0ol0000:ooooo`;o00001?ooool2o`0001cooooo1?l000000ooooooo0000
o`00000Do`0000;ooooo0_l0000?ooooo`;o00001?ooool2o`0000;ooooo0_l00006ooooo`;o0000
3?ooool2o`0004Oooooo000Looooo`03o`000?oooooooooo03Gooooo0_l0000Cooooo`?o00001Ooo
ool2o`0000cooooo0_l000000ooooooo0000o`000006ooooo`;o00001?ooool2o`0000Gooooo0_l0
00000ooooooo0000o`000004ooooo`?o00004?ooool4o`0001[ooooo7ol0000?ooooo`;o00002?oo
ool2o`0000Kooooo0_l000000ooooooo0000o`000008ooooo`?o0000Aoooool001cooooo00?o0000
ooooooooool0B_ooool3o`0000oooooo0_l00002ooooo`;o000000?oooooo`000?l000002?ooool2
o`0000;ooooo0_l00004ooooo`?o00002?ooool2o`00013ooooo1?l0000Cooooo`;o00001ooooolK
o`000003ooooool0003o000000Cooooo0_l00008ooooo`Co00004Oooool2o`0000Sooooo1?l00007
ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0=oooool2o`0000oooooo0_l0000Boooo
o`;o00000_ooool2o`0000_ooooo0_l00008ooooo`;o00000_ooool2o`0000Cooooo0_l0000;oooo
o`;o00001?ooool2o`0001?ooooo1Ol00006oooooa_o000000?oooooo`000?l000001?ooool2o`00
00?ooooo0_l00003ooooo`Co00002_ooool2o`0000Wooooo0_l00005ooooo`?o00001oooool2o`00
03gooooo000Looooo`03o`000?oooooooooo03Oooooo0_l0000?ooooo`;o00003Oooool3o`0000Ko
oooo0_l00003ooooo`;o00001?ooool5o`0000[ooooo2Ol0000;ooooo`;o00006Oooool5o`0000Oo
oooo7Ol00002ooooo`;o00001Oooool2o`00017ooooo0_l00009ooooo`;o00001Oooool2o`0004Oo
oooo000Looooo`03o`000?oooooooooo02_ooooo0_l0000Zooooo`?o00001oooool2o`0000;ooooo
0ol00003ooooo`Go00002_ooool2o`000003ooooool0003o000000Co00003Oooool2o`0002;ooooo
7?l00004ooooo`;o0000:oooool2o`0000Cooooo0_l00010ooooo`007?ooool00ol0003ooooooooo
o`0[ooooo`;o00003?ooool2o`0002Kooooo0_l00003ooooo`;o00003oooool3o`0000Cooooo1Ol0
0006ooooo`;o00001?ooool3o`0000Kooooo0_l00002ooooo`;o00005Oooool5o`000003ooooool0
003o000001Go00000_ooool2o`0002gooooo0_l00004ooooo`;o0000@?ooool001cooooo00?o0000
ooooooooool0>Oooool2o`0001Cooooo0_l0000Booooo`;o000000?oooooo`000?l000003oooool3
o`0000Kooooo0_l00007ooooo`;o00001?ooool3o`0000Kooooo0ol000000ooooooo0000o`000008
ooooo`;o00000_ooool2o`0000Oooooo8ol0000Hooooo`;o00003?ooool2o`0000Cooooo0_l00007
ooooo`;o0000??ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l0
00000ol@413oooooooooo`04ooooo`03o`000?oooooooooo04?ooooo0_l0000:ooooo`;o00004_oo
ool2o`000003ooooool0003o000000oooooo0_l0000Fooooo`Co00001_ooool2o`0000Kooooo0_l0
0003ooooo`;o00000_ooool2o`0000Sooooo1_l000000ooooooo0000o`00000>o`000003ooooool0
003o000000Co00000_ooool2o`0000[ooooo0ol0000;ooooo`;o00003?ooool2o`0000Cooooo0_l0
0007ooooo`;o0000??ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Zooooo`;o00005oooool2o`0001;ooooo
0_l0000:ooooo`;o000000?oooooo`000?l000002?ooool3o`0000Cooooo0_l00002ooooo`;o0000
1?ooool2o`0000_ooooo0_l000000ooooooo0000o`00000>ooooo`;o00000_ooool2o`0000Gooooo
0_l00006oooooaSo000000?oooooo`000?l000000_l00002ooooo`;o00002_ooool4o`00017ooooo
1?l00006ooooo`;o00002oooool2o`0003cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oo
oooooooo00Wooooo1Ol00006ooooo`03o`000?oooooooooo02Wooooo0ol0000Eooooo`Ko00001ooo
ool2o`0000Oooooo0_l00008ooooo`Co00000oooool2o`0000Kooooo1Ol00003ooooo`Go00000ooo
ool3o`0000_ooooo0_l000000ooooooo0000o`00000;ooooo`;o00001Oooool2o`0000?ooooo1_l0
0006oooooaoo00002_ooool2o`00013ooooo0_l000000ooooooo0000o`000002o`0000Kooooo0_l0
0002ooooo`;o0000AOooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool0
1?m4A4CogMgMooooool00007ooooo`?o0000:Oooool2o`0000[ooooo0_l00009ooooo`Oo00001ooo
ool2o`00017ooooo0_l00005ooooo`;o00000_ooool2o`0000Gooooo0_l00003ooooo`Co00001?oo
ool2o`0001_ooooo0ol0000:ooooo`;o00000_ooool2o`0000Gooooo3ol000000ooooooo0000o`00
0002o`000003ooooool0003o000000Co000000?oooooo`000?l000007_ooool2o`0000oooooo0_l0
0015ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGo
ooooo`0000Oooooo00?o0000ooooooooool0=Oooool2o`0000Oooooo1_l0000Dooooo`;o00004_oo
ool2o`000003ooooool0003o000000Kooooo0_l00003ooooo`Ko00006oooool2o`0000[ooooo0_l0
0003ooooo`;o00001OoooolKo`0000?ooooo0ol0000Mooooo`;o0000E?ooool00003ooooool@413o
oooo00;ooooo00?o410@ooooooooool02_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooo
oooo03Gooooo0_l00007ooooo`;o000000Coooooo`000?l0003o00002?ooool2o`0000Gooooo0_l0
0003ooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`Ko000000Coooooo`000?l0003ooooo
1Ol00002ooooo`Co000000?oooooo`000?l000001Ol00002ooooo`?o00005_ooool2o`0000Sooooo
1?l00002ooooo`?o00001_oooolPo`0001_ooooo1?l00002ooooo`?o00003oooool2o`0003kooooo
00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l000001oooool00ol0003o
ooooooooo`0nooooo`;o00001Oooool2o`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l0
00001_ooool4o`000003ooooool0003o000000?ooooo1_l000001?oooooo0000o`000?ooool>o`00
00;ooooo0ol00002ooooo`?o00006?ooool2o`0000Kooooo0_l00003ooooo`?o00001oooool4o`00
00;ooooo4_l00002ooooo`Ko00000_ooool2o`0001Oooooo0ol00003ooooo`?o00002?ooool2o`00
00Gooooo0_l0000nooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003o
oooo00Kooooo00?o0000ooooooooool0AOooool2o`0000Wooooo0_l00002ooooo`;o00001Oooool4
o`0000Oooooo0_l000000ooooooo0000o`00000Bo`0000?ooooo0_l00002ooooo`;o00006Oooool2
o`0000Kooooo0_l000000ooooooo0000o`000002o`0000Wooooo5ol00003ooooo`;o000000?ooooo
o`000?l000000_ooool2o`0000Gooooo0_l00002ooooo`?o00003?ooool2o`0000kooooo0ol00014
ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00005oooool2o`0000Cooooo1?l00002oooo
o`;o00000_ooool5o`0000?ooooo0_l00003ooooo`Wo00000_ooool9o`0000;ooooo0ol000000ooo
oooo0000o`000004o`0001kooooo0_l000000ooooooo0000o`000009oooooa[o00004?ooool2o`00
00;ooooo0ol0000Aooooo`;o00001_ooool3o`000003ooooool0003o000004Cooooo000Looooo`03
o`000?oooooooooo03?ooooo0_l0000Fooooo`?o00001?ooool2o`0000Cooooo0_l000000ooooooo
0000o`000004o`0000?ooooo0ol00006ooooo`;o000000?oooooo`000?l000001ol000001?oooooo
0000o`000?l00002ooooo`?o000000?oooooo`000?l000001_l0000:ooooo`?o00000oooool2o`00
00Wooooo0_l00007ooooo`;o00001?ooool2o`000003ooooool0003o000001Go00005_ooool2o`00
013ooooo0_l00006ooooo`?o0000Aoooool001cooooo00?o0000ooooooooool0Boooool2o`0000ko
oooo0ol00007ooooo`Co00001Oooool>o`0000Cooooo0_l000000ooooooo0000o`000002o`0000;o
oooo0_l0000:ooooo`Co00000_ooool2o`0000Wooooo0_l00007ooooo`;o00002?ooool@o`0000Co
oooo0_l00003ooooo`;o00004Oooool2o`0000cooooo0_l000000ooooooo0000o`00000Hooooo`;o
0000=oooool001cooooo00?o0000ooooooooool0G?ooool2o`0000?ooooo0_l00002ooooo`Co0000
0oooool@o`0000Kooooo1_l00003ooooo`;o00002_ooool2o`0000Gooooo0_l0000Hooooo`;o0000
00?oooooo`000?l000003?l000001?oooooo0000o`000?l00005ooooo`;o00007oooool2o`000003
ooooool0003o000001Sooooo0_l0000gooooo`007?ooool00ol0003oooooooooo`0kooooo`;o0000
9?ooool2o`0000;ooooo1Ol00002ooooo`?o000000?oooooo`000?l000002_l000000ooooooo0000
o`000002o`000005ooooool0003o0000o`000?ooool01ol0000Aooooo`;o00000_ooool2o`000003
ooooool0003o0000017ooooo0_l000000ooooooo0000o`000007o`000003ooooool0003o000000?o
oooo0ol0000=ooooo`;o00008Oooool2o`0000;ooooo0_l00008ooooo`;o0000??ooool001cooooo
00?o0000ooooooooool08oooool2o`0001Kooooo0_l00002ooooo`;o00003oooool2o`000003oooo
ool0003o0000013ooooo1Ol00004ooooo`;o00000_ooool6o`000003ooooool0003o000000[o0000
0_ooool4o`0001Kooooo0ol000000ooooooo0000o`00000@ooooo`;o00000oooool8o`000003oooo
ool0003o000000Cooooo1?l0000;ooooo`;o00008Oooool2o`0000;ooooo0_l00008ooooo`;o0000
00?oooooo`000?l00000>Oooool001cooooo00?o0000ooooooooool08oooool2o`0001[ooooo0ol0
0004ooooo`;o000000?oooooo`000?l000001?ooool3o`000003ooooool0003o000000;o00001?oo
ool2o`0000Kooooo1_l00002ooooo`;o000000?oooooo`000?l000003Ol00002ooooo`?o000000Co
ooooo`000?l0003o00001?ooool2o`0000Gooooo0_l00008ooooo`?o00000oooool2o`0000;ooooo
0_l0000<ooooo`?o000000?oooooo`000?l000000_l000001?oooooo0000o`000?ooool5o`0000?o
oooo0_l00002ooooo`Co00002oooool2o`0002Gooooo0_l0000;ooooo`;o0000>Oooool001cooooo
00?o0000ooooooooool0@?ooool2o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`;o0000
1?ooool2o`0000?ooooo0ol000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l00000
5_l000000ooooooo0000o`000002ooooo`?o00001?ooool4o`0000;ooooo0ol000000ooooooo0000
o`000005ooooo`?o00001oooool2o`0000Cooooo1?l000001?oooooo0000o`000?ooool3o`0000?o
oooo0_l00002ooooo`;o00000_ooool4o`0000;ooooo0_l00002ooooo`?o0000:Oooool2o`000003
ooooool0003o0000017ooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o0000
5_ooool2o`0000?ooooo0_l0000;ooooo`;o00000_ooool2o`0000Gooooo0ol000001?oooooo0000
o`000?oooolEo`0000;ooooo0ol00004ooooo`Co00000_ooool3o`000003ooooool0003o000000Ko
oooo1?l00005ooooo`;o00001?ooool7o`0000Gooooo0_l00003ooooo`[o000000?oooooo`000?l0
00000_l0000;ooooo`;o00007?ooool2o`000004ooooool0003o0000ooooo`;o00004Oooool2o`00
03[ooooo000Looooo`03o`000?oooooooooo01cooooo0_l00003ooooo`;o00003Oooool2o`0001Co
oooo1?l00003ooooo`Oo00004Oooool:o`000003ooooool0003o000001Co000000?oooooo`000?l0
00000ol0000@ooooo`Co00001Oooool2o`0000Oooooo0ol00003ooooo`Go00000oooool2o`000003
ooooool0003o000000;o000000Coooooo`000?l0003ooooo1Ol00003ooooo`;o00001Oooool2o`00
00[ooooo0_l0000@ooooo`?o00004oooool2o`0003gooooo000Looooo`03o`000?oooooooooo01co
oooo0_l00003ooooo`;o00003Oooool2o`0000[ooooo0_l00008ooooo`?o00001Oooool6o`0000Ko
oooo0_l00009ooooo`Go000000?oooooo`000?l000001ol000000ooooooo0000o`000008o`000003
ooooool0003o000000Co000000Coooooo`000?l0003o00000oooool2o`0000[ooooo0_l00003oooo
o`;o00001Oooool2o`0000Oooooo1Ol000001Ooooooo0000o`000?l0003ooooo00;o00000oooool2
o`0000Gooooo0_l00004ooooo`;o00000oooool2o`0000;ooooo0_l000000ooooooo0000o`00000:
ooooo`;o00004Oooool2o`0000[ooooo0_l00004ooooo`Go00001?ooool2o`0003Oooooo000Loooo
o`;o0000??ooool3o`0000Kooooo0_l00009ooooo`;o00001?ooool2o`0000?ooooo0_l00004oooo
o`;o00000_ooool2o`0000;ooooo6?l000000ooooooo0000o`000003o`0000;ooooo0ol00002oooo
o`;o00002?ooool4o`0000?ooooo0_l00005ooooo`;o00001oooool2o`000003ooooool0003o0000
00;ooooo1Ol00003ooooo`;o00001Oooool2o`0000Cooooo0_l00007ooooo`Go00003?ooool2o`00
00oooooo1?l00003ooooo`Wo00000_ooool4o`0000Gooooo0_l0000gooooo`007?ooool00ol0003o
ooooooooo`0kooooo`;o00001oooool2o`0000oooooo0_l00008ooooo`?o000000Coooooo`000?l0
003o00000_oooolOo`000004ooooool0003o0000o`0000cooooo0_l00005ooooo`;o00004_ooool2
o`0000;ooooo2?l0000Eooooo`Ko00002oooool2o`0000oooooo1?l00003ooooo`Go00000_ooool2
o`0000Oooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00000_ooool3o`00
01Kooooo0_l00003ooooo`;o00001Oooool2o`000005ooooool0003o0000o`000?ooool09Ol00000
0ooooooo0000o`000006ooooo`;o00002?ooool2o`0000Cooooo0_l0000<ooooo`;o00001?ooool9
o`0000kooooo1?l00002ooooo`Co0000<oooool2o`0000Gooooo0_l0000dooooo`007?ooool00ol0
003oooooooooo`0Pooooo`;o00005?ooool2o`0000;ooooo0_l0000Booooo`;o00000oooool2o`00
00?ooooo0_l00003ooooo`;o00000_ooool3o`0000;ooooo8_l000001?oooooo0000o`000?ooool2
o`0000Kooooo1_l00004ooooo`;o00001?ooool2o`0000Gooooo0_l00005ooooo`?o00002Oooool4
o`0000gooooo1?l0000?ooooo`;o00006?ooool2o`0001Gooooo0_l0000dooooo`007?ooool00ol0
003oooooooooo`0Pooooo`;o00003?ooool2o`0000Kooooo0_l0000@ooooo`;o00001?ooool2o`00
00gooooo0_l00002ooooo`Co000000?oooooo`000?l000001ol000000ooooooo0000o`00000Ao`00
0004ooooool0003o0000o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo1_l0
0004ooooo`;o00001?ooool2o`0000Gooooo0_l00006ooooo`;o000000?oooooo`000?l000000_oo
ool2o`0000Cooooo0_l00006ooooo`;o00000oooool2o`0001?ooooo0_l0000Hooooo`;o00005Ooo
ool2o`000003ooooool0003o0000037ooooo000Looooo`03o`000?oooooooooo02kooooo0_l00006
ooooo`;o00003?ooool2o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`;o00002?ooool2
o`0000?ooooo8_l000000ooooooo0000o`000002o`000004ooooool0003o0000o`0000;ooooo0ol0
0002ooooo`?o000000Coooooo`000?l0003o00000_ooool5o`0000Gooooo0_l00003ooooo`;o0000
0oooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000Wooooo0_l000000ooooooo
0000o`000003ooooo`?o0000:_ooool4o`0001Sooooo0_l0000aooooo`007?ooool00ol0003ooooo
ooooo`0]ooooo`;o00001oooool2o`0000Wooooo0_l000000ooooooo0000o`000002ooooo`;o0000
00?oooooo`000?l000001Oooool2o`0000Sooooo0_l00003ooooo`;o000000?oooooo`000?l00000
7_l000001?oooooo0000o`000?l00002ooooo`;o00000_ooool3o`0000;ooooo0_l000000ooooooo
0000o`000002o`0000;ooooo1Ol00005ooooo`;o00000oooool2o`0000?ooooo0_l000000ooooooo
0000o`000002o`0000Cooooo0_l00004ooooo`;o00000_ooool2o`0000Oooooo0_l0000Zooooo`Co
000000?oooooo`000?l000003Oooool2o`0003Wooooo000Looooo`03o`000?oooooooooo02gooooo
0_l00007ooooo`;o00001?ooool2o`0000?ooooo0_l00003ooooo`Ko00001_ooool2o`0000gooooo
0_l00002ooooo`Ko000000?oooooo`000?l000007_l0000:ooooo`Co00001_ooool2o`0000cooooo
0_l00003ooooo`Co00001?ooool2o`0000Cooooo1?l00006ooooo`;o0000<_ooool2o`0000gooooo
0_l00002ooooo`;o0000=Oooool001cooooo00?o0000ooooooooool0??ooool2o`0000Sooooo0_l0
00001?oooooo0000o`000?l00006ooooo`;o00002?ooool2o`000003ooooool0003o000000[o0000
0_ooool:o`000003ooooool0003o000001;o00002_ooool4o`0000Kooooo0_l0000<ooooo`;o0000
0oooool2o`000004ooooool0003o0000o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l0
00001_ooool2o`0000gooooo0_l000000ooooooo0000o`00000Oooooo`;o00004_ooool2o`000003
ooooool0003o000003;ooooo000Looooo`03o`000?oooooooooo03Oooooo0_l0000@ooooo`;o0000
1oooool2o`0000Oooooo0ol000000ooooooo0000o`000002ooooobWo000000?oooooo`000?l00000
1Oooool2o`000003ooooool0003o000000Gooooo0_l0000Cooooo`Ko00000_ooool2o`0000?ooooo
0_l0000:ooooo`Go00002Oooool5o`0001Oooooo0_l00006ooooo`;o00001_ooool2o`0000gooooo
0_l0000booooo`007?ooool00ol0003oooooooooo`0[ooooo`;o00002_ooool2o`00013ooooo0_l0
000@ooooo`Co00001ooooolVo`000003ooooool0003o000000Gooooo0_l00008ooooo`;o00004ooo
ool6o`0001?ooooo1Ol00009ooooo`Co00005Oooool2o`000003ooooool0003o000000kooooo0_l0
0007ooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0:oooool2o`0001Oooooo0ol00005
ooooo`;o00003oooool2o`0000;ooooo2ol000001?oooooo0000o`000?oooolHo`000005ooooool0
003o0000o`000?ooool00_l0000Pooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000
o`00000Aooooo`;o000000?oooooo`000?l000001Oooool2o`0000Cooooo0_l00003ooooo`;o0000
00?oooooo`000?l000003oooool2o`0001Oooooo0_l000000ooooooo0000o`00000hooooo`007?oo
ool00ol0003oooooooooo`0Nooooo`;o00002oooool2o`0001Oooooo0ol00005ooooo`?o00003?oo
ool2o`0000Cooooo9ol000000ooooooo0000o`000005o`0000;ooooo0_l0000Kooooo`;o000000?o
ooooo`000?l000000ol0000Cooooo`;o000000?oooooo`000?l000001Oooool2o`0000;ooooo0ol0
0004ooooo`;o000000?oooooo`000?l000000_l0000=ooooo`;o00005oooool2o`0003_ooooo000L
ooooo`03o`000?oooooooooo01kooooo0ol0000Dooooo`;o00003Oooool2o`000003ooooool0003o
000000Cooooo0_l00009ooooo`;o000000Coooooo`000?l0003o00001?ooool3o`0000?ooooo:?l0
0002ooooo`;o00002oooool2o`0000oooooo0_l00003ooooo`;o00001?ooool2o`0000oooooo0_l0
0008ooooo`Ko00002?ooool2o`0000oooooo0ol00002ooooo`;o000000?oooooo`000?l000002Ooo
ool3o`0000_ooooo0_l0000aooooo`007?ooool00ol0003oooooooooo`0Mooooo`Co00005?ooool2
o`000004ooooool0003o0000ooooo`;o00002_ooool2o`0000Sooooo0_l00005ooooo`;o00000_oo
ool6o`000003ooooool0003o000000;o000000?oooooo`000?l000008_l00004ooooo`;o00001?oo
ool2o`0000Oooooo0_l0000>ooooo`Go00000_ooool2o`0000?ooooo0_l0000<ooooo`Ko00000ooo
ool2o`0000;ooooo0ol000000ooooooo0000o`000002ooooo`;o00000oooool2o`0000cooooo0_l0
0002ooooo`?o00000_ooool5o`0000Wooooo0ol0000;ooooo`;o0000<Oooool001cooooo00?o0000
ooooooooool07Oooool2o`0001Wooooo1Ol0000>ooooo`;o00001?ooool2o`0000_ooooo1Ol00002
ooooo`;o000000?oooooo`000?l000008Ol00005ooooo`;o00001?ooool2o`0000Kooooo0_l0000?
ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l0000<ooooo`Ko000000?ooooo
o`000?l000002_l000001?oooooo0000o`000?l00003ooooo`;o00000_ooool5o`0000Gooooo0_l0
0008ooooo`;o00003?ooool2o`0000Oooooo0_l0000eooooo`007?ooool2o`0003Wooooo0ol00002
ooooo`;o00000_ooool2o`0000?ooooo0_l00003ooooo`;o00004_ooool4o`0000Gooooo8_l00002
ooooo`;o00000_ooool2o`0000Cooooo0_l00006ooooo`Co000000?oooooo`000?l000002_ooool2
o`000003ooooool0003o000000;o00001Oooool2o`0000kooooo5ol00005ooooo`Go00000_ooool2
o`0000Gooooo0_l00005ooooo`;o00002Oooool4o`0000Oooooo1?l0000cooooo`007?ooool00ol0
003oooooooooo`0hooooo`;o00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`00
00Cooooo0_l0000:ooooo`;o00000oooool2o`0000;ooooo0_l00007ooooob3o00000_ooool2o`00
00Sooooo0_l00006ooooo`Co000000?oooooo`000?l000003Oooool4o`0001Cooooo0ol000000ooo
oooo0000o`00000Do`0000[ooooo0_l00005ooooo`;o00001Oooool2o`0000Wooooo0_l0000;oooo
o`;o0000<oooool001cooooo00?o0000ooooooooool0A?ooool4o`0000Cooooo0_l00007ooooo`Go
00000oooool2o`0000;ooooo0_l00004ooooo`;o00000_oooolOo`0000?ooooo0ol0000>ooooo`;o
00002Oooool2o`0000Wooooo0ol0000Aooooo`Co00000_oooolFo`0000Cooooo0_l00008ooooo`;o
00002?ooool2o`0000Sooooo0ol00010ooooo`007?ooool00ol0003oooooooooo`11ooooo`;o0000
0oooool2o`0000Sooooo0ol00002ooooo`Co00003_ooool2o`000003ooooool0003o000001Wo0000
00?oooooo`000?l000000_l00002ooooo`Co00003_ooool2o`0000Wooooo0_l0000:ooooo`;o0000
3ooooolNo`0000Cooooo0_l000000ooooooo0000o`000005ooooo`Go00001Oooool2o`0000Sooooo
0ol00010ooooo`007?ooool00ol0003oooooooooo`11ooooo`?o00003?ooool6o`000003ooooool0
003o000000Gooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo4ol000000ooooooo0000o`00
000;o`000003ooooool0003o000000Kooooo0_l00008ooooo`;o00009?oooolOo`000003ooooool0
003o000000Cooooo0ol000000ooooooo0000o`000004ooooo`?o00005Oooool2o`0000gooooo0_l0
000/ooooo`007?ooool00ol0003oooooooooo`0oooooo`;o000000?oooooo`000?l000003_ooool4
o`0000Sooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000002?o00002?ooool3
o`0000Sooooo0_l0000?ooooo`;o00004ooooolOo`000003ooooool0003o000000Cooooo0_l00002
ooooo`;o00000oooool4o`0001Gooooo0_l0000=ooooo`;o0000;?ooool001cooooo00?o0000oooo
ooooool0=oooool2o`0000Kooooo0_l00002ooooo`;o000000?oooooo`000?l000006Oooool4o`00
00;ooooo8Ol0000;ooooo`;o00000_ooool2o`0000?ooooo1?l000000ooooooo0000o`00000<oooo
o`;o00002_ooool2o`0000Sooooo0_l00002ooooo`So000000?oooooo`000?l000003ol0000@oooo
o`;o00001Oooool2o`0000?ooooo0_l0000;ooooo`;o00001Oooool2o`0000Kooooo0_l0000/oooo
o`007?ooool00ol0003oooooooooo`0gooooo`;o00002_ooool2o`000004ooooool0003o0000oooo
o`;o000000?oooooo`000?l000003?ooool2o`000004ooooool0003o0000ooooo`;o00002OoooolN
o`0000kooooo0_l00003ooooo`;o00000_ooool4o`00017ooooo0_l00004ooooo`;o00002?ooool2
o`000003ooooool0003o000001[o00002oooool2o`0000Wooooo0_l00003ooooo`;o00003oooool2
o`000003ooooool0003o000000Kooooo0_l0000/ooooo`007?ooool00ol0003oooooooooo`16oooo
o`;o000000Coooooo`000?l0003ooooo0_l0000<ooooo`;o000000Coooooo`000?l0003ooooo0_l0
000:oooooago00001Oooool3o`0000oooooo1?l00004ooooo`;o00002_ooool3o`00017ooooo7?l0
0006ooooo`;o00000oooool2o`000003ooooool0003o000000cooooo0_l00005ooooo`;o00001ooo
ool2o`0000;ooooo1?l0000aooooo`007?ooool00ol0003oooooooooo`0Looooo`;o00008?ooool2
o`0000Gooooo0ol00004ooooo`;o00005oooool2o`0000?ooooo3Ol000000ooooooo0000o`000002
o`000003ooooool0003o000000Oo00002?ooool3o`0000gooooo0_l00002ooooo`;o00001?ooool2
o`000003ooooool0003o000000?ooooo0_l00002ooooo`Co00003_ooool3o`000003ooooool0003o
000000Ko000000?oooooo`000?l000004Ol00004ooooo`;o00001_ooool2o`0000cooooo0_l00005
ooooo`;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`00037ooooo000Loooo
o`03o`000?oooooooooo01cooooo0_l0000Nooooo`Go00001?ooool3o`0000Cooooo0_l00006oooo
o`;o00000oooool2o`0000[ooooo1?l000000ooooooo0000o`000004o`0000?ooooo3ol000001?oo
oooo0000o`000?l00005ooooo`;o00001?ooool5o`0000Oooooo0ol0000;ooooo`Co000000?ooooo
o`000?l000001?ooool2o`0000kooooo0ol00004oooooaWo00006oooool2o`0000[ooooo0_l00002
ooooo`?o00001Oooool2o`0002kooooo000Looooo`03o`000?oooooooooo03cooooo1Ol0000;oooo
o`;o00001_ooool4o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000001Oooool8
o`0000Gooooo4_l00004ooooo`Co00001?ooool5o`0000Oooooo0ol0000=ooooo`?o00000oooool2
o`0001Cooooo0_l00002oooooaWo000000?oooooo`000?l000000_ooool2o`0000Kooooo0_l00002
ooooo`;o00001_ooool6o`000004ooooool0003o0000o`0000Sooooo0ol00005ooooo`;o0000;_oo
ool001cooooo00?o0000ooooooooool0=Oooool4o`0000Cooooo0_l00006ooooo`;o00001Oooool3
o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000000oooool3o`000003ooooool0
003o000000Gooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00002ooooo`Go0000
0_ooool8o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool4o`0000Oooooo
1?l0000=ooooo`Co000000Coooooo`000?l0003ooooo0ol0000@ooooo`;o000000Coooooo`000?l0
003ooooo5ol000001?oooooo0000o`000?ooool3o`0000Kooooo0_l00002ooooo`;o00001_ooool2
o`0000;ooooo0_l000001?oooooo0000o`000?l00004ooooo`;o00000_ooool2o`0003Kooooo000L
ooooo`03o`000?oooooooooo03Gooooo1?l0000<ooooo`;o00001?ooool4o`000004ooooool0003o
0000ooooo`;o00001_ooool2o`0000Wooooo0_l00002ooooo`;o00001?ooool2o`0000?ooooo1Ol0
00000ooooooo0000o`00000;o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo
0_l00009ooooo`Ko00001_ooool2o`000003ooooool0003o000000Go000000Coooooo`000?l0003o
00004oooool3o`000003ooooool0003o000001;o00001_ooool2o`0001Gooooo0_l00005ooooo`;o
00000oooool2o`0000;ooooo0_l0000fooooo`007?ooool00ol0003oooooooooo`0fooooo`;o0000
1_ooool2o`0000?ooooo1Ol00003ooooo`;o00006Oooool6o`0000Cooooo0ol00002ooooo`Go0000
00?oooooo`000?l000000_l00003ooooo`Co00001?ooool2o`0000?ooooo0ol00005ooooo`;o0000
2?ooool4o`0000Kooooo0_l00002ooooo`Wo00005?ooool3o`000003ooooool0003o000000oo0000
00?oooooo`000?l000001_ooool2o`0001Gooooo0_l00005ooooo`?o0000?_ooool001cooooo00?o
0000ooooooooool0>oooool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`00
000Hooooo`;o00001?ooool4o`0000Kooooo0ol000000ooooooo0000o`000005o`000003ooooool0
003o000000;o000000?oooooo`000?l000000_l00002ooooo`?o00000oooool4o`0000Kooooo0_l0
000Eooooo`Go000000?oooooo`000?l000000_l0000Doooooa[o00001?ooool2o`0000Oooooo0_l0
0004ooooo`?o00002oooool4o`0000Wooooo0_l0000cooooo`007?ooool2o`0003_ooooo0ol00006
ooooo`Co000000?oooooo`000?l000001Oooool2o`0000oooooo0_l00004ooooo`Oo000000Cooooo
o`000?l0003o00000_ooool3o`0000?ooooo0_l000000ooooooo0000o`000002o`000003ooooool0
003o000000;o00000_ooool3o`000003ooooool0003o000000?o00001oooool2o`0001Gooooo0_l0
00000ooooooo0000o`000005o`0001Kooooo6?l0000=ooooo`;o00001?ooool3o`0000;ooooo0_l0
0007ooooo`?o00002_ooool2o`0003?ooooo000Looooo`03o`000?oooooooooo03[ooooo1?l00005
ooooo`Oo00001Oooool2o`0001Oooooo1Ol000001Ooooooo0000o`000?l0003ooooo00Go00000_oo
ool2o`0000?ooooo0_l00003ooooo`;o00001_ooool2o`000003ooooool0003o000000Oooooo0_l0
000Booooo`;o00001?ooool4o`000003ooooool0003o000001;ooooo0ol00002oooooaKo00005Ooo
ool2o`0000;ooooo0ol00004ooooo`Go0000?oooool001cooooo00?o0000ooooooooool0??ooool2
o`0000Kooooo0_l000000ooooooo0000o`00000Nooooo`;o00002Oooool5o`0000;ooooo0_l00003
ooooo`;o00005Oooool2o`0000?ooooo0_l0000?ooooo`;o00000oooool2o`0000Cooooo0_l0000B
ooooo`Oo00000_ooool@o`0001cooooo0_l00004ooooo`?o0000@Oooool001cooooo00?o0000oooo
ooooool0BOooool2o`0000[ooooo0_l0000@ooooo`;o00003_ooool2o`0000oooooo0_l0000:oooo
o`?o000000?oooooo`000?l000000_l000000ooooooo0000o`00000Aooooo`;o00000_ooool4o`00
01Gooooo0_l00003oooooa;o00007oooool2o`000003ooooool0003o000000?ooooo0_l0000loooo
o`007?ooool00ol0003oooooooooo`0iooooo`;o00003Oooool3o`0000[ooooo0_l00002ooooo`;o
00005_ooool2o`0000Cooooo0_l0000?ooooo`;o00002_ooool2o`0000;ooooo0_l000000ooooooo
0000o`000002o`0000Wooooo0_l0000:ooooo`Co00005Oooool2o`0000?ooooo2ol00004ooooo`?o
00001_ooool2o`0000_ooooo0_l00003ooooo`;o00001Oooool2o`0000Kooooo0_l00007ooooo`;o
0000<oooool001cooooo00?o0000ooooooooool0>Oooool2o`0000Oooooo0_l00004ooooo`;o0000
0oooool3o`0000Wooooo0_l00002ooooo`;o00004_ooool2o`0000Wooooo1?l00007ooooo`;o0000
4Oooool3o`0000_ooooo0_l00006ooooo`;o00009Oooool2o`0000Wooooo0_l00006ooooo`;o0000
2oooool2o`0000?ooooo0_l00005ooooo`;o00000oooool4o`0000Sooooo0_l0000cooooo`007?oo
ool00ol0003oooooooooo`12ooooo`;o00001?ooool2o`0000?ooooo0ol00003ooooo`;o00001Ooo
ool2o`000004ooooool0003o0000ooooo`;o00001Oooool2o`0001?ooooo2_l000000ooooooo0000
o`00000:ooooo`;o00001Oooool2o`0001Cooooo0_l00004ooooo`Go00001_ooool2o`0000cooooo
0_l00006ooooo`Co00001Oooool2o`00017ooooo0_l00007ooooo`;o00001Oooool2o`0000?ooooo
1?l00005ooooo`;o0000=_ooool001cooooo00?o0000ooooooooool0>_ooool2o`0000;ooooo0_l0
0002ooooo`;o00003oooool2o`0000Gooooo0_l00004ooooo`;o00001Oooool2o`0000Sooooo0_l0
0003ooooo`;o000000?oooooo`000?l000000_ooool:o`0000;ooooo0_l00008ooooo`;o00005Ooo
ool2o`0000;ooooo0_l00006ooooo`Go00001_ooool2o`0000cooooo0_l00008ooooo`;o00000_oo
ool2o`000004ooooool0003o0000ooooo`;o00003_ooool2o`0001Oooooo0_l00003ooooo`;o0000
=_ooool001cooooo00?o0000ooooooooool0>_ooool2o`0000;ooooo0_l00002ooooo`Co00003?oo
ool2o`0000oooooo0_l00007ooooo`;o00000oooool2o`0000?ooooo0_l000001Ooooooo0000o`00
0?l0003ooooo00;o00001_ooool3o`000003ooooool0003o000000Wooooo0_l0000Booooo`Co0000
0_ooool2o`0000?ooooo2?l0000Mooooo`?o00000_ooool2o`0000;ooooo1?l0000<ooooo`;o0000
3?ooool2o`0000_ooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00001Ooo
ool2o`0000;ooooo1_l0000:ooooo`;o00003oooool2o`0000Oooooo1?l0000:ooooo`;o00002_oo
ool2o`000003ooooool0003o000000Wooooo0_l00008ooooo`;o00000_ooool2o`0000;ooooo1?l0
0007ooooo`[o00001_ooool2o`0001Gooooo0_l00007ooooo`Co00003?ooool2o`0000Wooooo0_l0
00000ooooooo0000o`000002o`0000Wooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0g
ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Gooooo0ol0000:ooooo`;o00000oooool2
o`0001Cooooo0ol0000:ooooo`;o00003Oooool2o`0000Cooooo0_l0000=ooooo`;o00000_ooool2
o`0000;ooooo0_l00009ooooo`Ko000000?oooooo`000?l000001oooool2o`0000_ooooo0_l0000B
ooooo`?o00005oooool2o`0000;ooooo0ol00009ooooo`;o00001?ooool2o`0003Gooooo000Loooo
o`03o`000?oooooooooo027ooooo0_l0000Gooooo`;o00000_ooool2o`0000Gooooo0_l00009oooo
o`;o00001Oooool2o`00027ooooo0_l0000Booooo`?o000000?oooooo`000?l000005?ooool3o`00
00Gooooo2_l00007ooooo`;o00002oooool2o`0000Sooooo0_l00003ooooo`Co00003Oooool2o`00
00kooooo1?l0000@ooooo`;o0000=Oooool001cooooo00?o0000ooooooooool08Oooool2o`0001Co
oooo0ol000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l000002?ooool2o`0003co
oooo0_l00002ooooo`;o00004oooool4o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`Go
00002?ooool2o`0001Gooooo0_l00003ooooo`Co00003Oooool2o`0000_ooooo0_l000000ooooooo
0000o`000003ooooo`;o00003Oooool2o`0003Gooooo000Looooo`03o`000?oooooooooo03Oooooo
0ol000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000001?l0000aooooo`?o0000
3?ooool2o`0000_ooooo0_l00003ooooo`?o00000oooool2o`0000Cooooo0_l00004ooooo`;o0000
00?oooooo`000?l000000_ooool4o`0004?ooooo1?l00004ooooo`Co000000?oooooo`000?l00000
2?ooool2o`0003Gooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05
onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0looooo`;o00000_ooool2o`00
00?ooooo2?l000000ooooooo0000o`00000Zooooo`?o00003?ooool2o`0000_ooooo0_l00003oooo
o`?o00000oooool2o`0000;ooooo0_l00006ooooo`Co00000_ooool4o`0000kooooo0ol0000@oooo
o`;o00006oooool2o`000003ooooool0003o000000Go00000_ooool2o`0000;ooooo0_l000000ooo
oooo0000o`00000oooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0??ooool2o`0000Oooooo0_l0
0002ooooo`Co000000?oooooo`000?l000007_ooool3o`0000Oooooo1Ol00003ooooo`;o00000_oo
ool2o`0000?ooooo0_l000000ooooooo0000o`00000Gooooo`;o00000_ooool2o`0000Cooooo1_l0
00000ooooooo0000o`000003ooooo`;o00001_ooool5o`0000Kooooo0_l00008ooooo`;o00006ooo
ool2o`000003ooooool0003o000000Co00000oooool2o`0000?ooooo0ol00007ooooo`;o0000=ooo
ool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool08_ooool2o`0001Cooooo0_l0000dooooo`?o00001ooo
ool5o`0000?ooooo0_l000001?oooooo0000o`000?l00003ooooo`Go00002_ooool2o`0000gooooo
1?l00005ooooo`?o00000oooool2o`0000?ooooo0_l00006ooooo`;o000000?oooooo`000?l00000
0oooool2o`000003ooooool0003o000000;o00009oooool4o`0000Wooooo0ol00007ooooo`;o0000
=oooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oV9RHoooo
oonHV9So8B4Q00Kooooo0ol0000Rooooo`;o00004oooool3o`0004Kooooo0_l000000ooooooo0000
o`000005ooooo`;o000000?oooooo`000?l000000_ooool5o`0000;ooooo0_l0000=ooooo`;o0000
1Oooool2o`0000?ooooo1Ol0000Cooooo`;o000000?oooooo`000?l000000_l0000Vooooo`Co0000
4oooool2o`0003Sooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go
0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo03Oooooo0_l00003ooooo`;o0000
00?oooooo`000?l00000?oooool2o`000003ooooool0003o000000;o00001Oooool3o`0000;ooooo
1Ol0000Aooooo`;o00001Oooool8o`0001;ooooo0_l00002ooooo`Co00009Oooool2o`000003oooo
ool0003o000000;o00001?ooool2o`0000?ooooo0_l00008ooooo`;o0000>?ooool00003ooooool@
413ooooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo03cooooo0_l000000ooooooo0000o`00000^ooooo`;o00002oooool2o`0000Gooooo1?l0
0005ooooo`;o00008Oooool7o`0001;ooooo2?l0000Uooooo`Co00001oooool2o`0000?ooooo0_l0
0012ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo
00?o0000ooooooooool0?oooool4o`0000?ooooo1?l0000?ooooo`;o00005?ooool4o`0000Wooooo
0_l00007ooooo`;o00002_ooool2o`0001cooooo0_l000000ooooooo0000o`000004o`000003oooo
ool0003o000000;o00002_ooool2o`000003ooooool0003o000002[ooooo0ol00004ooooo`;o0000
B_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106oooo
o`03o`000?oooooooooo03cooooo0_l00003ooooo`;o00000oooool4o`0000oooooo0_l0000Foooo
o`;o00003?ooool2o`0000;ooooo1ol00003ooooo`;o000000Coooooo`000?l0003o00000_ooool2
o`0000?ooooo0_l0000Cooooo`;o000000?oooooo`000?l000000_ooool7o`0000[ooooo1?l0000V
ooooo`;o00001Oooool2o`0000?ooooo0_l00007ooooo`;o0000@Oooool001cooooo00?o0000oooo
ooooool0??ooool2o`0000Wooooo0_l0000:ooooo`;o0000:?ooool4o`0000;ooooo0_l00002oooo
o`Co00000_ooool2o`000003ooooool0003o000000Go00000oooool2o`0000kooooo0_l000000ooo
oooo0000o`000007o`0000;ooooo1Ol00002ooooo`;o00002?ooool2o`0002Kooooo0_l00005oooo
o`;o00003?ooool2o`00047ooooo000Looooo`03o`000?oooooooooo03oooooo0_l00007ooooo`;o
00002Oooool2o`0000Gooooo0_l0000Kooooo`;o00000_ooool4o`0000Wooooo0ol00006ooooo`Go
00003_ooool2o`0000Cooooo0_l000000ooooooo0000o`000003o`0000;ooooo1Ol00006ooooo`;o
00002_ooool2o`0003Cooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`0Vooooo`;o0000
5oooool2o`0000Oooooo0_l0000?ooooo`?o00006oooool2o`0000;ooooo0_l00002ooooo`;o0000
1oooool5o`0000Oooooo0_l000000ooooooo0000o`000002ooooo`Co00001Oooool2o`0000Sooooo
0_l00005ooooo`Co00001?ooool4o`0000[ooooo0_l0000/ooooo`;o00001?ooool4o`0004Kooooo
000Looooo`03o`000?oooooooooo02Kooooo0_l0000Kooooo`;o00001oooool2o`0000_ooooo0_l0
000Tooooo`?o00001Oooool6o`0000Gooooo0ol00002ooooo`So00001?ooool2o`0000Gooooo1Ol0
00000ooooooo0000o`000003ooooo`Go00000oooool3o`0003Wooooo0_l00004ooooo`;o00001ooo
ool2o`0003oooooo000Looooo`03o`000?oooooooooo043ooooo0_l000000ooooooo0000o`000007
ooooo`Co0000<?ooool3o`0000?ooooo1_l00002oooooa3o00001Oooool2o`0000Gooooo1Ol00000
0ooooooo0000o`000002ooooo`Ko000000Coooooo`000?l0003ooooo0ol0000[ooooo`;o00004?oo
ool2o`0000Sooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0Wooooo`;o00005Oooool4
o`0000Gooooo0_l00005ooooo`;o00008Oooool2o`0000;ooooo0_l00007ooooo`;o000000Cooooo
o`000?l0003o00000_oooolCo`0001_ooooo0_l00004ooooo`Oo00002oooool2o`0000Cooooo0_l0
00000ooooooo0000o`00000Eooooo`;o00002oooool2o`0000?ooooo0_l00019ooooo`007?ooool0
0ol0003oooooooooo`0Wooooo`;o00005Oooool3o`0000Kooooo0_l000000ooooooo0000o`000002
ooooo`;o00008Oooool2o`0000;ooooo0_l00007ooooo`Ko00000oooool@o`0001Kooooo0_l00002
ooooo`;o00001oooool7o`0000_ooooo0_l00004ooooo`;o000000?oooooo`000?l000005Oooool3
o`0000[ooooo1?l0001<ooooo`007?ooool00ol0003oooooooooo`0looooo`;o00000_ooool2o`00
00Sooooo0_l0000Sooooo`Co00003OoooolIo`0000Wooooo0_l00009ooooo`;o00000_ooool2o`00
00Wooooo1ol0000Eooooo`;o00004oooool2o`0000Kooooo0_l00003ooooo`?o0000C?ooool001co
oooo00?o0000ooooooooool0??ooool2o`0000;ooooo0_l0000Hooooo`;o00004oooool4o`0000So
oooo0_l00003ooooo`So000000?oooooo`000?l000002ol000000ooooooo0000o`000002o`0000Oo
oooo0_l0000Mooooo`;o00003oooool2o`0000Cooooo0_l0000Kooooo`;o00000oooool2o`000003
ooooool0003o000004[ooooo000Looooo`03o`000?oooooooooo043ooooo0_l0000Aooooo`?o0000
1?ooool2o`0001Wooooo0_l00004ooooo`;o00000oooool2o`000003ooooool0003o000001So0000
0_ooool2o`0000Wooooo0_l00002ooooo`;o00003_ooool3o`0000Cooooo0_l0000;ooooo`;o0000
0oooool3o`0002?ooooo0ol00019ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00004Ooo
ool3o`0001oooooo0_l0000:oooooaOo000000?oooooo`000?l000000_l00002ooooo`Go00001_oo
ool2o`0000;ooooo0_l00002ooooo`;o00002_ooool3o`0000Cooooo0_l0000@ooooo`?o00005?oo
ool2o`0000kooooo0_l00019ooooo`007?ooool2o`0002_ooooo0_l0000Fooooo`;o00001_ooool2
o`0003Gooooo0_l000000ooooooo0000o`000005o`000003ooooool0003o000000ko00001Oooool3
o`0000Sooooo1?l00002ooooo`;o00002_ooool2o`0002kooooo0_l0000?ooooo`;o0000B?ooool0
01cooooo00?o0000ooooooooool0:_ooool2o`0000oooooo0_l00005ooooo`;o00001?ooool4o`00
00?ooooo0ol000001?oooooo0000o`000?ooool2o`0001_ooooo0_l0000<ooooo`;o000000?ooooo
o`000?l000005ol00002ooooo`;o00001Oooool2o`0000Cooooo1?l00006ooooo`;o00003Oooool2
o`0000_ooooo0_l000000ooooooo0000o`00000Jooooo`;o00000oooool2o`0000Cooooo0_l00000
0ooooooo0000o`000018ooooo`007?ooool00ol0003oooooooooo`0kooooo`;o00001Oooool2o`00
00Cooooo0_l000000ooooooo0000o`000002ooooo`?o000000Coooooo`000?l0003ooooo0_l00002
ooooo`;o00005Oooool6o`0000[ooooo6?l00002ooooo`;o00000_ooool2o`000003ooooool0003o
000000Oo00002oooool2o`0000gooooo0_l0000:ooooo`Oo00005oooool4o`0000?ooooo0_l00004
ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0@Oooool3o`0000Oooooo0_l000000ooo
oooo0000o`00000:ooooo`;o00005Oooool2o`000004ooooool0003o0000o`0000Sooooo4_l00000
0ooooooo0000o`000004o`000003ooooool0003o000000Oooooo3?l0000Sooooo`Co000000?ooooo
o`000?l000005oooool2o`0000Gooooo0_l00004ooooo`;o0000Boooool001cooooo00?o0000oooo
ooooool0@Oooool2o`0000_ooooo0_l0000Rooooo`Go00002?ooool4o`0000;ooooo3ol000000ooo
oooo0000o`000004o`0000?ooooo1?l00004ooooo`;o00000_ooool4o`000003ooooool0003o0000
00?ooooo1?l0000iooooo`;o00001?ooool2o`0000?ooooo0_l0001;ooooo`007?ooool00ol0003o
ooooooooo`1>ooooo`;o000000?oooooo`000?l000001oooool2o`0001Kooooo0_l000000ooooooo
0000o`00000:ooooob7o00000_ooool2o`000004ooooool0003o0000o`0000;ooooo0_l000000ooo
oooo0000o`000003ooooo`Co00004_ooool2o`000003ooooool0003o000001Sooooo0_l00008oooo
o`;o00001?ooool2o`0000Oooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`0oooooo`;o
00004?ooool2o`0000Oooooo0_l0000Uooooo`[o000000?oooooo`000?l000004?l000000ooooooo
0000o`000003ooooo`;o000000Coooooo`000?l0003o00003?ooool2o`000003ooooool0003o0000
00Cooooo0_l00009ooooo`;o000000?oooooo`000?l000001?ooool4o`0000;ooooo0_l00004oooo
o`;o00001_ooool2o`0001Oooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`0oooooo`?o
000000?oooooo`000?l000003?ooool2o`0000Gooooo0ol0000Iooooo`;o00002_oooolKo`0000Co
oooo0_l00003ooooo`;o00004oooool2o`0000Cooooo0_l00007ooooo`Oo00001?ooool4o`0000;o
oooo0_l00004ooooo`;o0000J?ooool001cooooo00?o0000ooooooooool0@?ooool2o`000003oooo
ool0003o000000Sooooo0_l00002ooooo`;o00001Oooool3o`00017ooooo0ol00005ooooo`;o0000
00?oooooo`000?l000001oooool3o`000003ooooool0003o000001Oo00001_ooool3o`0000[ooooo
0_l00004ooooo`;o00004?ooool2o`0000;ooooo0_l0000>ooooo`;o00005Oooool2o`0000Wooooo
0_l00019ooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00000_ooool2o`0001gooooo0ol0
0005ooooo`;o000000?oooooo`000?l000002?oooolNo`0000Cooooo0_l0000;ooooo`;o000000Co
ooooo`000?l0003ooooo0_l0000Gooooo`;o00002oooool2o`0001Gooooo1?l00007ooooo`?o0000
B?ooool001cooooo00?o0000ooooooooool0@?ooool2o`0000Oooooo0_l0000/ooooo`;o00002?oo
oolNo`0000gooooo0_l00004ooooo`?o000000?oooooo`000?l000001_ooool2o`0000oooooo0_l0
000;ooooo`;o00003?ooool2o`0000Wooooo0_l00003ooooo`Oo0000B?ooool001cooooo00?o0000
ooooooooool0<?ooool2o`0000kooooo0_l0000>ooooo`;o00008_ooool2o`000003ooooool0003o
000000Sooooo0_l000000ooooooo0000o`00000Io`0000;ooooo0_l00009ooooo`;o00001?ooool2
o`0000;ooooo0_l00006ooooo`;o00002_ooool2o`00013ooooo1?l000001Ooooooo0000o`000?l0
003ooooo00;o00000oooool2o`0000Gooooo1Ol00004ooooo`Ko0000BOooool001cooooo00?o0000
ooooooooool0<?ooool2o`0001kooooo0_l0000Pooooo`Co00002oooool2o`0000;ooooo5?l00003
ooooo`Co000000?oooooo`000?l000009oooool2o`0000_ooooo0_l00005ooooo`;o000000Gooooo
o`000?l0003o0000ooooo`02o`0000[ooooo1Ol0001Cooooo`007?ooool00ol0003oooooooooo`18
ooooo`;o00000oooool2o`0000?ooooo0_l0000Nooooo`Co00003?ooool2o`000003ooooool0003o
000000Oo000000?oooooo`000?l000002?l00003ooooo`Co00002Oooool2o`0000Wooooo0_l00005
ooooo`;o00004?ooool2o`0000Sooooo0_l00004ooooo`?o00004?ooool2o`0000Wooooo0_l0001<
ooooo`007?ooool00ol0003oooooooooo`18ooooo`;o00000oooool2o`0000?ooooo1?l0000Loooo
o`;o00003_ooool<o`000003ooooool0003o000000So00000oooool2o`0000Gooooo0_l00004oooo
o`Co00001oooool2o`0000;ooooo2_l00002ooooo`;o00001oooool3o`0000Oooooo0_l00004oooo
o`Oo000000?oooooo`000?l000002Oooool2o`0000Wooooo0_l0001<ooooo`007?ooool00ol0003o
ooooooooo`0booooo`;o00005_ooool2o`0000Sooooo0_l0000Looooo`?o00001?ooool2o`0000So
oooo5Ol00003ooooo`?o00001?ooool3o`0000Gooooo1?l000000ooooooo0000o`000006ooooo`oo
00001oooool3o`0000oooooo1Ol000000ooooooo0000o`00000:ooooo`;o0000E_ooool001cooooo
0_l0000cooooo`;o00005_ooool2o`0000?ooooo0_l0000Jooooo`;o00000oooool2o`000003oooo
ool0003o000000Cooooo0_l00008oooooaGo00000oooool2o`0000Gooooo0ol00004ooooo`;o0000
00Coooooo`000?l0003ooooo0_l00006ooooo`ko00002?ooool3o`0001Cooooo0_l0000;ooooo`?o
0000EOooool001cooooo00?o0000ooooooooool0C_ooool3o`0001[ooooo0_l00003ooooo`?o0000
2_ooool2o`0000Cooooo1ol000000ooooooo0000o`00000;o`000003ooooool0003o000000Cooooo
0_l00002ooooo`;o00001?ooool2o`0000_ooooo3?l0000;ooooo`;o00005Oooool2o`0000Wooooo
0_l000000ooooooo0000o`000003ooooo`;o0000D?ooool001cooooo00?o0000ooooooooool0C_oo
ool2o`00023ooooo0ol0000:ooooo`;o00001?ooool6o`0000;ooooo3Ol000000ooooooo0000o`00
0004ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo0ol00009ooooo`Ko000000?o
ooooo`000?l000001Ol0000[ooooo`;o00001_ooool2o`00053ooooo000Looooo`03o`000?oooooo
oooo04Oooooo0_l00008ooooo`Co0000:?ooool2o`0000;ooooo0_l00003oooooaGo00002?ooool6
o`000004ooooool0003o0000o`0000[ooooo3_l0000Pooooo`;o00000oooool2o`0000Kooooo0_l0
001Eooooo`007?ooool00ol0003oooooooooo`17ooooo`;o00002?ooool4o`0001oooooo0_l00006
ooooo`Co000000?oooooo`000?l000000_oooolHo`0000Kooooo0ol000001?oooooo0000o`000?oo
ool2o`0000cooooo3Ol0000Nooooo`Co00000oooool2o`0000Kooooo1?l0001Cooooo`007?ooool0
0ol0003oooooooooo`1?ooooo`;o00005Oooool2o`0000cooooo1_l00002ooooo`Co00001Oooool9
o`0000;ooooo2?l00003ooooo`;o00006oooool<o`0000Oooooo0_l0000Fooooo`;o00003oooool2
o`0005?ooooo000Looooo`03o`000?oooooooooo04oooooo0_l000000ooooooo0000o`000002oooo
o`;o00002oooool2o`000003ooooool0003o000000Oooooo0ol00004ooooo`Ko00002Oooool:o`00
00?ooooo1_l00004ooooo`;o00002_ooool2o`0000_ooooo3ol00007ooooo`?o00009?ooool2o`00
05Gooooo000Looooo`03o`000?oooooooooo05;ooooo0_l00002ooooo`;o00001_ooool2o`0000?o
oooo0_l00004ooooo`;o00001?ooool3o`0000Cooooo0_l00002ooooo`;o00002Oooool2o`0000?o
oooo1Ol00004ooooo`?o00001_ooool2o`0000Wooooo0ol00005ooooo`;o00001?ooool>o`0000Go
oooo0_l00002ooooo`?o00005_ooool2o`0000;ooooo0_l00007ooooo`;o0000EOooool001cooooo
00?o0000ooooooooool0GOooool3o`0000Wooooo0_l00004ooooo`;o00006_ooool2o`000004oooo
ool0003o0000o`0000;ooooo0_l00003ooooo`;o00003?ooool4o`000003ooooool0003o000000;o
oooo1?l00005ooooo`_o00000oooool4o`0000?ooooo0_l0000@ooooo`;o00001?ooool2o`0000;o
oooo0_l0001Nooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o00002_ooool2o`0000oooooo
0_l00007ooooo`?o00004oooool5o`0000Kooooo0_l00008ooooo`;o00000_ooool2o`0000?ooooo
0_l00004ooooo`;o000000?oooooo`000?l000000_ooool;o`0000?ooooo0_l0000Gooooo`;o0000
1?ooool3o`000003ooooool0003o000005kooooo000Looooo`03o`000?oooooooooo057ooooo0_l0
00000ooooooo0000o`00000Hooooo`;o00001oooool3o`0000Gooooo0_l0000<ooooo`;o000000Co
ooooo`000?l0003ooooo1?l0000;ooooo`;o00004?ooool2o`0000;ooooo3?l00007ooooo`?o0000
5oooool3o`000004ooooool0003o0000ooooo`;o0000Foooool001cooooo00?o0000ooooooooool0
E?ooool3o`0000Kooooo0ol0000Eooooo`;o000000?oooooo`000?l000000_ooool2o`000003oooo
ool0003o000000Cooooo0_l0000<ooooo`Co00009?ooool;o`0000Gooooo0ol00006ooooo`;o0000
0oooool2o`0000[ooooo0_l00005ooooo`;o0000Foooool001cooooo00?o0000ooooooooool0EOoo
ool2o`0000Kooooo0ol00003ooooo`;o00004?ooool2o`0000Gooooo0ol00006ooooo`;o0000=_oo
ool2o`0000Gooooo0_l0000=ooooo`?o00000oooool4o`0006cooooo000Looooo`03o`000?oooooo
oooo03gooooo0_l0000Aooooo`;o00004Oooool2o`0000Wooooo0_l00005ooooo`;o00001_ooool2
o`0000?ooooo0_l0000Aooooo`;o00001Oooool2o`0001kooooo0_l000001?oooooo0000o`000?l0
0003ooooo`;o00001?ooool2o`0000Kooooo0_l00006ooooo`;o00001oooool2o`000003ooooool0
003o000000;o0000G_ooool001cooooo00?o0000ooooooooool0?Oooool2o`00017ooooo0_l00005
ooooo`;o00004oooool4o`0000;ooooo1Ol0000;ooooo`;o00003_ooool2o`000003ooooool0003o
000000Gooooo0_l00003ooooo`;o00002oooool2o`0000cooooo0_l000001?oooooo0000o`000?l0
0003ooooo`;o00001?ooool2o`0000[ooooo0_l00007ooooo`;o00000_ooool2o`000003ooooool0
003o000000;o0000G_ooool001cooooo00?o0000ooooooooool0Eoooool2o`0001?ooooo0ol00002
ooooo`Ko00000_ooool2o`0000Wooooo0_l0000<ooooo`;o00003Oooool2o`0000Kooooo0ol00000
1?oooooo0000o`000?l0000Wooooo`?o00001_ooool2o`0006Oooooo000Looooo`;o0000K_ooool2
o`0000;ooooo1_l00002ooooo`;o00002Oooool2o`0000Oooooo0_l000000ooooooo0000o`000002
o`0001Gooooo0ol000000ooooooo0000o`000005ooooo`Co00002Oooool2o`00017ooooo0_l00000
1?oooooo0000o`000?l00005ooooo`;o00002Oooool2o`0005gooooo000Looooo`03o`000?oooooo
oooo07?ooooo0_l00002ooooo`;o00001_ooool2o`0000cooooo0_l000000ooooooo0000o`000002
o`0000Sooooo0_l0000Cooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o00000oooool2
o`0000Oooooo0_l00006ooooo`Co00000_ooool2o`0000?ooooo1?l00009ooooo`;o0000GOooool0
01cooooo00?o0000ooooooooool0Moooool2o`0000;ooooo0ol000001?oooooo0000o`000?ooool2
o`000003ooooool0003o000000Wooooo1Ol00007ooooo`;o00004oooool2o`0000Cooooo0_l00003
ooooo`?o00000oooool2o`0000Cooooo1?l000000ooooooo0000o`000005o`0000Wooooo1?l0001X
ooooo`007?ooool00ol0003oooooooooo`1Oooooo`?o00005?ooool2o`0000?ooooo0ol00004oooo
o`;o000000?oooooo`000?l000003?ooool5o`0000;ooooo0ol0000Aooooo`;o00000_ooool4o`00
0003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000002o`000004ooooool0003o0000
ooooo`;o000000?oooooo`000?l000001_l0001fooooo`007?ooool00ol0003oooooooooo`1Ooooo
o`?o00001oooool2o`0000_ooooo1?l0000>ooooo`;o00002_ooool4o`0000;ooooo0ol0000Aoooo
o`;o00000_ooool5o`0000Oooooo1Ol00002ooooo`So00000_ooool2o`0000Oooooo0_l0001_oooo
o`007?ooool00ol0003oooooooooo`1Tooooo`;o00000oooool2o`0000gooooo0_l0000>ooooo`;o
000000?oooooo`000?l000000oooool2o`0001Wooooo0_l000000ooooooo0000o`000003ooooo`Go
000000?oooooo`000?l000000oooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l0
00000_ooool2o`000003ooooool0003o000000Kooooo0_l0001_ooooo`007?ooool00ol0003ooooo
ooooo`1Tooooo`;o00004oooool2o`0000Gooooo0_l00002ooooo`;o00001?ooool3o`0000?ooooo
0_l0000?ooooo`;o00001?ooool2o`000005ooooool0003o0000o`000?ooool00ol00002ooooo`So
00001oooool2o`0000Wooooo0_l000000ooooooo0000o`00001gooooo`007?ooool00ol0003ooooo
ooooo`1iooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00004ooooo`;o0000
3_ooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o000000?oooooo`000?l00000
0oooool2o`0000Cooooo1?l0002@ooooo`007?ooool00ol0003oooooooooo`17ooooo`;o00008?oo
ool2o`00017ooooo0_l0000Looooo`Go00002?ooool2o`0000Cooooo0_l0000Looooo`Co00001?oo
ool2o`0000Sooooo0_l00003ooooo`;o0000IOooool001cooooo00?o0000ooooooooool0Aoooool2
o`00023ooooo0_l000000ooooooo0000o`000006ooooo`;o00008Oooool2o`0000;ooooo0_l0000:
ooooo`;o00001?ooool2o`0000Wooooo0_l0000Aooooo`Ko00000_ooool2o`0000Kooooo1?l00000
0ooooooo0000o`000002o`0006Gooooo000Looooo`03o`000?oooooooooo06cooooo0_l00006oooo
o`;o00004_ooool2o`0000Cooooo0_l00006ooooo`Co00004_ooool2o`0000[ooooo0_l00005oooo
o`;o00000_ooool2o`0000Sooooo2Ol00005ooooo`Oo0000Ioooool001cooooo00?o0000oooooooo
ool0R?ooool2o`0000Cooooo0_l00005ooooo`Go00004_ooool3o`0000gooooo0_l000000ooooooo
0000o`000002ooooo`;o00002?ooool9o`0000Sooooo0_l0001Yooooo`007?ooool00ol0003ooooo
ooooo`2;ooooo`;o00002?ooool2o`0001Kooooo0_l00005ooooo`;o00000_ooool2o`0000;ooooo
0_l00008ooooo`Co00000oooool8o`0007Cooooo000Looooo`03o`000?oooooooooo077ooooo0_l0
00000ooooooo0000o`00000Eooooo`;o00003oooool2o`0001Kooooo0_l00002ooooo`;o00003?oo
ool4o`0000?ooooo1_l0001fooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q
1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0LOooool2o`000004
ooooool0003o0000ooooo`;o00001?ooool2o`0000Gooooo0_l00008ooooo`;o00001?ooool3o`00
00Gooooo0_l00004ooooo`;o00004_ooool2o`0000;ooooo0_l00008ooooo`;o000000?oooooo`00
0?l00000P?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4Q
oiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo07Kooooo0ol00004ooooo`;o00001Ooo
ool2o`0000Sooooo0_l00004ooooo`?o00001?ooool2o`0000Gooooo0ol000001?oooooo0000o`00
0?l00002ooooo`Go000000?oooooo`000?l000000oooool2o`0000;ooooo0_l000000ooooooo0000
o`000005ooooo`;o00003?ooool2o`0007Gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oo
oooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo04oooooo
0_l0000Nooooo`;o00000_ooool2o`000003ooooool0003o000000Cooooo0_l0000Cooooo`;o0000
1?ooool3o`000003ooooool0003o000000Kooooo0_l000000ooooooo0000o`000002o`000003oooo
ool0003o000000?o000000?oooooo`000?l000000_l00006ooooo`Co00004oooool2o`0007Gooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RH
oc8b<P06ooooo`?o0000Coooool2o`0001kooooo0_l00002ooooo`;o00001oooool2o`0000_ooooo
0_l00003ooooo`;o000000?oooooo`000?l000000_l00002ooooo`?o00002?ooool2o`0000?ooooo
0ol00002ooooo`;o00001Oooool2o`0000Kooooo0ol0000:ooooo`;o0000Ooooool00003ooooool0
003ooooo00;ooooo00?o0000ooooooooool02Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo
00?o0000ooooooooool0ROooool3o`0000;ooooo0_l000000ooooooo0000o`000002o`0000;ooooo
0_l00005ooooo`;o00000_ooool2o`0000Sooooo1?l00003ooooo`;o00001oooool2o`0000[ooooo
0_l0001oooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj
^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`1hooooo`;o00004?ooool2o`0000;ooooo
0_l000000ooooooo0000o`00000;ooooo`;o00000oooool2o`0000Sooooo0ol00003ooooo`;o0000
0_ooool2o`0000_ooooo0_l00003ooooo`;o0000O_ooool00006oooooomgMgOoV9RHoooooonHV9So
MgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0N?ooool2o`00
01Cooooo0_l00008ooooo`;o00001_ooool2o`000004ooooool0003o0000o`0000Oooooo0_l00008
ooooo`;o00002oooool2o`0000?ooooo0_l0001nooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^
k^h;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`1mooooo`;o0000
3oooool2o`0000Kooooo1?l000000ooooooo0000o`000003ooooo`;o00000_ooool2o`0000Kooooo
0ol0000<ooooo`;o0000S?ooool001cooooo00?o0000ooooooooool0OOooool2o`0001Oooooo0_l0
00000ooooooo0000o`000002o`0000_ooooo0_l00002ooooo`?o00002oooool3o`0008cooooo000L
ooooo`03o`000?oooooooooo05Sooooo0_l0000Wooooo`;o00005_ooool2o`0000?ooooo0_l00008
ooooo`;o00004?ooool2o`000003ooooool0003o000008[ooooo000Looooo`03o`000?oooooooooo
05Sooooo0_l0000Wooooo`;o00006oooool2o`0001Kooooo0_l00005ooooo`;o0000R_ooool001co
oooo00?o0000ooooooooool0NOooool4o`0000Sooooo0_l00002ooooo`;o00006Oooool2o`00013o
oooo0_l00004ooooo`;o0000Roooool001cooooo00?o0000ooooooooool0GOooool2o`0001[ooooo
1?l00008ooooo`;o00000_ooool2o`0001Wooooo0_l00009ooooo`;o00002oooool2o`0008_ooooo
000Looooo`03o`000?oooooooooo05gooooo0_l0000_ooooo`;o00005_ooool2o`000003ooooool0
003o000000Cooooo0_l0000Cooooo`Go0000P?ooool001cooooo00?o0000ooooooooool0Goooool2
o`0001cooooo0_l0000?ooooo`;o00005_ooool5o`0000kooooo0_l00009ooooo`Go0000P?ooool0
01cooooo00?o0000ooooooooool0Goooool2o`0001cooooo0_l0000Yooooo`;o00003oooool2o`00
08kooooo000Looooo`03o`000?oooooooooo06?ooooo0_l0000jooooo`;o0000Z?ooool001cooooo
00?o0000ooooooooool0Hoooool2o`0003[ooooo0_l0002Xooooo`007?ooool00ol0003ooooooooo
o`2Oooooo`;o0000Z?ooool001cooooo0_l00028ooooo`;o0000<Oooool2o`0008gooooo000Loooo
o`03o`000?oooooooooo08Oooooo0_l0000aooooo`;o0000SOooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo06cooooo0_l0003Kooooo`007?ooool00ol0003oooooooooo`1/ooooo`;o0000foooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01;ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB_ooool001Co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`00
0?oooooooooo00Gooooo0ol0003ooooood[ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_oo
ool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooo
oe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001;ooooo00?oEEEEofIVI_l00000
oooooomDooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00YOooool01?l@413o
0000o`000?ooool2o`000003oa0@4?oooooooooo01Gooooo00Gok^k^oc8b<_l0003o410@olc<c003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^093ooooo
002Vooooo`05o`000?ooooooooooooooool000002Oooool6o`0000Wooooo00GoEEEEogMgMooooooo
V9RHob4Q8@03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg093ooooo002Vooooo`05o`000?ooooooooooooooool000006?ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
4100T?ooool00:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00002Oooool01Ol0003o
V9RHoooooonHV9So8B4Q00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool00000T?ooool00:Kooooo00Go0000ohN7QoooooooZJVYo`00000Hooooo`05o`000?mE
EEGo0000oa0@4?o<c<`00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`00002@ooooo`00YOooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo01Ko
oooo00?oEEEEohN7Qoooool01Oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooo
oooooooooooooa0@402@ooooo`00`oooool00ooMgMgo410@oiRHV005ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg093ooooo0034ooooo`04olc<c?m4A4Co
0000oa0@40?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h0T?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(606) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.45612 .66723 Mdot
.4018 .65528 Mdot
.65619 .42851 Mdot
.38994 .44081 Mdot
.57734 .31374 Mdot
.62346 .40584 Mdot
.65086 .55925 Mdot
.68427 .5352 Mdot
.61375 .40245 Mdot
.21471 .58641 Mdot
.67895 .54176 Mdot
.40352 .54366 Mdot
.6665 .56087 Mdot
.38501 .4782 Mdot
.5764 .66615 Mdot
.32236 .50139 Mdot
.40359 .63046 Mdot
.51198 .30767 Mdot
.32491 .50584 Mdot
.64768 .43463 Mdot
.48465 .47944 Mdot
.37672 .47242 Mdot
.40431 .63449 Mdot
.38182 .4765 Mdot
.37404 .41945 Mdot
.41359 .64919 Mdot
.45081 .68044 Mdot
.35292 .44052 Mdot
.34139 .46251 Mdot
.68443 .55293 Mdot
.61061 .24194 Mdot
.55252 .84263 Mdot
.36342 .52446 Mdot
.35159 .59783 Mdot
.67394 .52585 Mdot
.80487 .44651 Mdot
.59881 .4003 Mdot
.69277 .55033 Mdot
.64681 .52094 Mdot
.64031 .52114 Mdot
.65409 .57253 Mdot
.41194 .65865 Mdot
.63588 .56769 Mdot
.58963 .35277 Mdot
.41749 .45922 Mdot
.50241 .79797 Mdot
.61659 .21657 Mdot
.35233 .44442 Mdot
.45177 .64648 Mdot
.6443 .42951 Mdot
.27147 .33237 Mdot
.69661 .56642 Mdot
.58466 .72179 Mdot
.12828 .6314 Mdot
.67932 .55401 Mdot
.3753 .4421 Mdot
.62412 .42848 Mdot
.39387 .45455 Mdot
.35769 .45811 Mdot
.32931 .56103 Mdot
.35402 .4769 Mdot
.53967 .30148 Mdot
.44824 .69125 Mdot
.62609 .44676 Mdot
.61576 .40724 Mdot
.67739 .57688 Mdot
.40282 .68603 Mdot
.66537 .56983 Mdot
.43964 .48587 Mdot
.65339 .4221 Mdot
.357 .44481 Mdot
.68286 .54379 Mdot
.39556 .66236 Mdot
.40403 .41904 Mdot
.52964 .76547 Mdot
.7034 .52148 Mdot
.53154 .33655 Mdot
.32549 .68747 Mdot
.18389 .43822 Mdot
.70137 .42 Mdot
.38298 .48895 Mdot
.16826 .4134 Mdot
.58165 .65683 Mdot
.40276 .67171 Mdot
.38933 .58783 Mdot
.76431 .63035 Mdot
.33857 .46071 Mdot
.49767 .38678 Mdot
.327 .46873 Mdot
.51185 .58497 Mdot
.60868 .40552 Mdot
.41386 .63884 Mdot
.41796 .45757 Mdot
.34445 .42837 Mdot
.24193 .48195 Mdot
.40016 .5164 Mdot
.41012 .45176 Mdot
.4134 .59448 Mdot
.66294 .53767 Mdot
.45439 .4548 Mdot
.61531 .33897 Mdot
.56165 .7387 Mdot
.39642 .43361 Mdot
.63769 .39197 Mdot
.46112 .6524 Mdot
.41373 .44619 Mdot
.68097 .56935 Mdot
.37022 .48228 Mdot
.68035 .51753 Mdot
.42289 .62749 Mdot
.34014 .43687 Mdot
.54935 .31866 Mdot
.52784 .65902 Mdot
.44624 .66066 Mdot
.24758 .68532 Mdot
.35643 .47509 Mdot
.36629 .46501 Mdot
.40369 .66693 Mdot
.61457 .43405 Mdot
.51955 .43132 Mdot
.39734 .64255 Mdot
.64334 .52188 Mdot
.43306 .62625 Mdot
.33358 .43342 Mdot
.62036 .43713 Mdot
.55378 .73055 Mdot
.56679 .74383 Mdot
.50794 .21675 Mdot
.3951 .41329 Mdot
.54556 .69033 Mdot
.63658 .40614 Mdot
.40749 .65908 Mdot
.67069 .56821 Mdot
.35164 .49684 Mdot
.43211 .68095 Mdot
.64965 .52494 Mdot
.54845 .28033 Mdot
.57958 .30255 Mdot
.44148 .6826 Mdot
.36414 .35598 Mdot
.70083 .54779 Mdot
.63694 .52599 Mdot
.28674 .32451 Mdot
.40657 .67721 Mdot
.52689 .27516 Mdot
.64129 .53806 Mdot
.41665 .27872 Mdot
.3667 .50343 Mdot
.37099 .24916 Mdot
.19517 .35001 Mdot
.27812 .32861 Mdot
.41005 .78011 Mdot
.52683 .3104 Mdot
.63959 .54112 Mdot
.37414 .4331 Mdot
.42551 .6721 Mdot
.41954 .67442 Mdot
.35226 .41643 Mdot
.36122 .41907 Mdot
.40392 .48153 Mdot
.34989 .49125 Mdot
.75913 .33093 Mdot
.39984 .48838 Mdot
.58733 .5956 Mdot
.43819 .67588 Mdot
.37909 .4142 Mdot
.62801 .38014 Mdot
.41152 .41488 Mdot
.69211 .54946 Mdot
.3653 .45422 Mdot
.36365 .42117 Mdot
.4247 .48565 Mdot
.63519 .55304 Mdot
.64974 .77127 Mdot
.17248 .50629 Mdot
.78869 .53264 Mdot
.4689 .74409 Mdot
.63443 .41686 Mdot
.38069 .49701 Mdot
.51856 .29143 Mdot
.45467 .50601 Mdot
.35675 .46321 Mdot
.25471 .34416 Mdot
.35085 .43304 Mdot
.35481 .73323 Mdot
.42871 .39472 Mdot
.79088 .60689 Mdot
.61058 .628 Mdot
.34919 .47619 Mdot
.21158 .50984 Mdot
.39866 .22528 Mdot
.56709 .21478 Mdot
.67933 .56277 Mdot
.61721 .37621 Mdot
.6032 .42042 Mdot
.63258 .525 Mdot
.43102 .40787 Mdot
.22341 .60666 Mdot
.44382 .46877 Mdot
.55484 .72707 Mdot
.43316 .71252 Mdot
.52126 .30976 Mdot
.44374 .68116 Mdot
.14692 .45555 Mdot
.50321 .44093 Mdot
.66601 .48782 Mdot
.51864 .3176 Mdot
.65439 .39557 Mdot
.55912 .7154 Mdot
.51833 .2811 Mdot
.40287 .44873 Mdot
.43773 .63301 Mdot
.39456 .22625 Mdot
.31391 .44223 Mdot
.82547 .35362 Mdot
.40678 .68498 Mdot
.542 .54813 Mdot
.67661 .56065 Mdot
.60792 .43818 Mdot
.33915 .45887 Mdot
.39956 .46896 Mdot
.45071 .68667 Mdot
.34842 .44924 Mdot
.49204 .52056 Mdot
.3601 .42572 Mdot
.58914 .43031 Mdot
.49453 .27436 Mdot
.64335 .50655 Mdot
.4986 .2186 Mdot
.39393 .65512 Mdot
.57886 .52633 Mdot
.63513 .38657 Mdot
.46747 .6237 Mdot
.68769 .55191 Mdot
.55348 .29048 Mdot
.60644 .38775 Mdot
.56146 .29595 Mdot
.41967 .44506 Mdot
.60145 .4019 Mdot
.54665 .29194 Mdot
.62859 .48167 Mdot
.41015 .4495 Mdot
.37549 .27247 Mdot
.64307 .54743 Mdot
.44993 .67947 Mdot
.35162 .47512 Mdot
.55282 .74012 Mdot
.3664 .4036 Mdot
.55458 .68042 Mdot
.5486 .72311 Mdot
.57404 .7116 Mdot
.68162 .48401 Mdot
.51701 .27396 Mdot
.48816 .76765 Mdot
.52445 .45368 Mdot
.40189 .63201 Mdot
.41953 .47642 Mdot
.70655 .74461 Mdot
.64139 .55069 Mdot
.40002 .44799 Mdot
.76938 .61552 Mdot
.64109 .53962 Mdot
.38536 .45743 Mdot
.65125 .57201 Mdot
.42315 .67543 Mdot
.56935 .48197 Mdot
.4253 .61855 Mdot
.38812 .44338 Mdot
.65518 .54546 Mdot
.61032 .3797 Mdot
.41448 .64961 Mdot
.36703 .47842 Mdot
.38752 .4914 Mdot
.55812 .72171 Mdot
.37699 .41155 Mdot
.74159 .70966 Mdot
.35453 .44253 Mdot
.65539 .39571 Mdot
.39419 .51881 Mdot
.37321 .23292 Mdot
.57808 .2882 Mdot
.40598 .69466 Mdot
.55179 .71637 Mdot
.60803 .41354 Mdot
.58078 .4617 Mdot
.55187 .24006 Mdot
.37858 .48466 Mdot
.56954 .73386 Mdot
.54644 .54573 Mdot
.68243 .57293 Mdot
.34327 .49828 Mdot
.50535 .48137 Mdot
.61127 .3938 Mdot
.55626 .71996 Mdot
.38798 .38814 Mdot
.45227 .63691 Mdot
.37473 .44009 Mdot
.60032 .39329 Mdot
.45126 .63933 Mdot
.34962 .49644 Mdot
.70778 .28331 Mdot
.55586 .7411 Mdot
.64446 .55269 Mdot
.2833 .45317 Mdot
.40317 .4909 Mdot
.60137 .42086 Mdot
.42698 .68213 Mdot
.67188 .54635 Mdot
.4359 .63785 Mdot
.43037 .20873 Mdot
.49268 .71645 Mdot
.75314 .37923 Mdot
.50432 .28642 Mdot
.40324 .81716 Mdot
.79708 .50774 Mdot
.50286 .70271 Mdot
.48074 .28705 Mdot
.82829 .52652 Mdot
.61993 .38165 Mdot
.26675 .40379 Mdot
.61339 .42294 Mdot
.38576 .43212 Mdot
.62087 .40501 Mdot
.76882 .68634 Mdot
.35334 .43573 Mdot
.63263 .42244 Mdot
.74526 .33404 Mdot
.34535 .43772 Mdot
.44164 .67492 Mdot
.5512 .82483 Mdot
.27842 .70868 Mdot
.43728 .37188 Mdot
.63338 .42579 Mdot
.23962 .43086 Mdot
.34496 .4477 Mdot
.31188 .47676 Mdot
.4239 .66522 Mdot
.32569 .45609 Mdot
.53488 .31893 Mdot
.56028 .30899 Mdot
.28761 .33621 Mdot
.30746 .73621 Mdot
.29905 .44926 Mdot
.41534 .65716 Mdot
.18646 .42654 Mdot
.53215 .76926 Mdot
.56615 .74642 Mdot
.65783 .52094 Mdot
.64793 .76971 Mdot
.36102 .38668 Mdot
.32325 .37595 Mdot
.50293 .53325 Mdot
.41026 .63867 Mdot
.77755 .45606 Mdot
.66644 .54745 Mdot
.19796 .50827 Mdot
.2529 .6162 Mdot
.40797 .47724 Mdot
.66954 .58544 Mdot
.43774 .50686 Mdot
.49678 .53114 Mdot
.3699 .2649 Mdot
.71448 .37252 Mdot
.40054 .44347 Mdot
.49713 .7697 Mdot
.36166 .46108 Mdot
.39588 .23199 Mdot
.39276 .4454 Mdot
.43985 .6431 Mdot
.3278 .39205 Mdot
.53964 .4054 Mdot
.18324 .57551 Mdot
.50251 .45037 Mdot
.51256 .28447 Mdot
.38866 .47683 Mdot
.40573 .47167 Mdot
.54527 .30191 Mdot
.42363 .64136 Mdot
.41247 .49082 Mdot
.62116 .21501 Mdot
.40552 .4857 Mdot
.69502 .56659 Mdot
.55997 .46067 Mdot
.35822 .74908 Mdot
.33773 .44893 Mdot
.45605 .6445 Mdot
.67318 .57544 Mdot
.66711 .52646 Mdot
.30919 .42268 Mdot
.64095 .55576 Mdot
.36776 .43755 Mdot
.56048 .46529 Mdot
.40844 .631 Mdot
.44491 .51189 Mdot
.42828 .64396 Mdot
.21648 .37208 Mdot
.63647 .56032 Mdot
.57719 .72949 Mdot
.27603 .39155 Mdot
.65667 .55418 Mdot
.4436 .58035 Mdot
.37685 .37892 Mdot
.42305 .42217 Mdot
.47531 .71841 Mdot
.5939 .3928 Mdot
.57426 .7179 Mdot
.67807 .55028 Mdot
.40338 .48625 Mdot
.40983 .43891 Mdot
.68461 .58058 Mdot
.28012 .52468 Mdot
.61577 .24664 Mdot
.38414 .44553 Mdot
.43526 .64082 Mdot
.40861 .65824 Mdot
.38478 .50692 Mdot
.35585 .4663 Mdot
.64705 .38516 Mdot
.57106 .73395 Mdot
.56546 .71074 Mdot
.57107 .74118 Mdot
.58738 .39429 Mdot
.37779 .80697 Mdot
.63693 .52635 Mdot
.44844 .81282 Mdot
.72454 .6735 Mdot
.30538 .43943 Mdot
.59604 .40923 Mdot
.39148 .46327 Mdot
.39971 .43094 Mdot
.65796 .54267 Mdot
.29282 .74219 Mdot
.39403 .5342 Mdot
.43835 .69041 Mdot
.69137 .57315 Mdot
.43336 .53425 Mdot
.71552 .54205 Mdot
.54832 .31378 Mdot
.49231 .4305 Mdot
.67228 .58615 Mdot
.43245 .63238 Mdot
.67938 .58466 Mdot
.40571 .47494 Mdot
.41507 .40649 Mdot
.40538 .64084 Mdot
.52222 .26632 Mdot
.41961 .45375 Mdot
.38288 .45752 Mdot
.4218 .18331 Mdot
.52608 .76541 Mdot
.66131 .46207 Mdot
.38465 .42369 Mdot
.43417 .46485 Mdot
.5244 .26274 Mdot
.40665 .49136 Mdot
.34093 .46748 Mdot
.52777 .64861 Mdot
.64812 .50807 Mdot
.55081 .33048 Mdot
.19064 .52174 Mdot
.41281 .69006 Mdot
.75322 .6884 Mdot
.55911 .73839 Mdot
.65575 .50618 Mdot
.57016 .48785 Mdot
.57071 .71892 Mdot
.74981 .62144 Mdot
.77621 .55525 Mdot
.57529 .72821 Mdot
.65749 .44089 Mdot
.47141 .45153 Mdot
.34226 .48507 Mdot
.37176 .45435 Mdot
.52178 .27152 Mdot
.41577 .68417 Mdot
.5931 .61125 Mdot
.62269 .51437 Mdot
.37222 .46972 Mdot
.39794 .62051 Mdot
.77753 .6183 Mdot
.56035 .71711 Mdot
.52203 .30142 Mdot
.50938 .28014 Mdot
.36416 .46172 Mdot
.50228 .63508 Mdot
.41362 .65436 Mdot
.36714 .47832 Mdot
.36233 .49777 Mdot
.62285 .43369 Mdot
.44315 .63867 Mdot
.63897 .38711 Mdot
.5472 .72416 Mdot
.83955 .45497 Mdot
.44485 .17193 Mdot
.64834 .53764 Mdot
.79084 .49297 Mdot
.68099 .59128 Mdot
.71931 .39686 Mdot
.57351 .73296 Mdot
.37036 .47532 Mdot
.39172 .66448 Mdot
.3683 .48133 Mdot
.41302 .47814 Mdot
.41459 .46288 Mdot
.29833 .45706 Mdot
.26071 .3359 Mdot
.52503 .29506 Mdot
.42396 .50673 Mdot
.64083 .37541 Mdot
.7859 .60793 Mdot
.58264 .80606 Mdot
.39542 .47647 Mdot
.3692 .46426 Mdot
.41253 .69429 Mdot
.41654 .43359 Mdot
.68596 .56478 Mdot
.40607 .68061 Mdot
.40231 .43709 Mdot
.58941 .30839 Mdot
.40205 .49801 Mdot
.79567 .48294 Mdot
.67899 .58518 Mdot
.488 .42862 Mdot
.4347 .44639 Mdot
.57572 .73095 Mdot
.57448 .71884 Mdot
.55228 .74283 Mdot
.6769 .58096 Mdot
.61902 .43213 Mdot
.65472 .37373 Mdot
.39922 .3906 Mdot
.37126 .43307 Mdot
.42614 .42563 Mdot
.58755 .38613 Mdot
.52945 .42987 Mdot
.43607 .7721 Mdot
.42251 .3892 Mdot
.60876 .37325 Mdot
.39968 .60648 Mdot
.19893 .63195 Mdot
.41501 .68789 Mdot
.50156 .31308 Mdot
.68871 .54664 Mdot
.54072 .31916 Mdot
.23858 .37742 Mdot
.40925 .63287 Mdot
.44713 .68893 Mdot
.63437 .41955 Mdot
.55572 .5932 Mdot
.21259 .75532 Mdot
.638 .39704 Mdot
.48775 .27219 Mdot
.42116 .66082 Mdot
.37943 .53221 Mdot
.54881 .54733 Mdot
.54489 .58717 Mdot
.62345 .42095 Mdot
.3838 .49077 Mdot
.45528 .58616 Mdot
.64788 .38649 Mdot
.35181 .50876 Mdot
.6368 .42483 Mdot
.64217 .56385 Mdot
.63919 .40872 Mdot
.38367 .66097 Mdot
.41676 .44053 Mdot
.14492 .66545 Mdot
.57886 .64759 Mdot
.35968 .48124 Mdot
.69251 .57334 Mdot
.73045 .29044 Mdot
.40951 .4663 Mdot
.52948 .31886 Mdot
.60527 .37277 Mdot
.70604 .3183 Mdot
.34465 .45878 Mdot
.62167 .41296 Mdot
.39132 .69235 Mdot
.62793 .34911 Mdot
.68753 .42119 Mdot
.56963 .7127 Mdot
.42639 .67671 Mdot
.54644 .6988 Mdot
.67002 .52338 Mdot
.42465 .46991 Mdot
.37859 .50075 Mdot
.44249 .66279 Mdot
.72459 .54481 Mdot
.39526 .52479 Mdot
.38317 .48873 Mdot
.64799 .38967 Mdot
.6192 .36528 Mdot
.60786 .69696 Mdot
.62231 .38019 Mdot
.4342 .46925 Mdot
.44323 .65835 Mdot
.38398 .43608 Mdot
.43793 .68115 Mdot
.42009 .47199 Mdot
.42102 .74705 Mdot
.41584 .68702 Mdot
.48936 .68856 Mdot
.36814 .41057 Mdot
.30699 .50941 Mdot
.41253 .48275 Mdot
.40674 .44978 Mdot
.59855 .37604 Mdot
.53211 .28629 Mdot
.33894 .49991 Mdot
.58237 .50498 Mdot
.54136 .26666 Mdot
.35485 .66022 Mdot
.61428 .43328 Mdot
.53521 .26815 Mdot
.37555 .30649 Mdot
.55207 .71615 Mdot
.53393 .30064 Mdot
.61338 .74777 Mdot
.64933 .53917 Mdot
.41294 .62312 Mdot
.34868 .43138 Mdot
.83745 .51133 Mdot
.61084 .24265 Mdot
.56183 .72236 Mdot
.35298 .47313 Mdot
.39561 .46135 Mdot
.44669 .63024 Mdot
.15779 .43503 Mdot
.59987 .43767 Mdot
.40072 .44075 Mdot
.39916 .64157 Mdot
.18727 .37663 Mdot
.64194 .42069 Mdot
.53077 .30432 Mdot
.6653 .58908 Mdot
.43967 .71728 Mdot
.5742 .71523 Mdot
.63661 .56215 Mdot
.61595 .46148 Mdot
.23583 .36004 Mdot
.34612 .45739 Mdot
.59632 .39205 Mdot
.2765 .32941 Mdot
.4411 .41362 Mdot
.67297 .59745 Mdot
.40732 .73626 Mdot
.41048 .63981 Mdot
.68642 .57873 Mdot
.51153 .28542 Mdot
.4105 .62747 Mdot
.42355 .64016 Mdot
.68319 .53458 Mdot
.62406 .61659 Mdot
.54334 .55239 Mdot
.69299 .56009 Mdot
.53214 .61093 Mdot
.2952 .32025 Mdot
.56957 .73713 Mdot
.52176 .30185 Mdot
.43602 .20139 Mdot
.41177 .65517 Mdot
.64889 .7696 Mdot
.26067 .33967 Mdot
.40981 .45141 Mdot
.53986 .27924 Mdot
.75134 .63722 Mdot
.6197 .51173 Mdot
.64872 .5266 Mdot
.51363 .39831 Mdot
.51737 .3073 Mdot
.37879 .50407 Mdot
.35024 .74409 Mdot
.34738 .4289 Mdot
.64012 .54477 Mdot
.49069 .5423 Mdot
.44531 .64262 Mdot
.66618 .52129 Mdot
.49364 .50985 Mdot
.39716 .42932 Mdot
.35596 .48581 Mdot
.44872 .22357 Mdot
.44303 .63659 Mdot
.57573 .71561 Mdot
.37338 .48689 Mdot
.39132 .45358 Mdot
.42239 .48476 Mdot
.28652 .37956 Mdot
.51152 .6709 Mdot
.40428 .44145 Mdot
.59317 .42468 Mdot
.41676 .41492 Mdot
.34726 .4772 Mdot
.43264 .6186 Mdot
.34846 .24507 Mdot
.54675 .72753 Mdot
.37589 .45317 Mdot
.38364 .44613 Mdot
.64681 .51915 Mdot
.54507 .5495 Mdot
.54359 .59058 Mdot
.65424 .40904 Mdot
.47221 .29926 Mdot
.44272 .45388 Mdot
.43344 .67575 Mdot
.54225 .32178 Mdot
.43 .47287 Mdot
.41987 .69195 Mdot
.43011 .41438 Mdot
.64883 .38461 Mdot
.57024 .73158 Mdot
.3243 .38163 Mdot
.5373 .29773 Mdot
.6926 .52956 Mdot
.48451 .82517 Mdot
.6299 .37875 Mdot
.3712 .42627 Mdot
.60946 .35498 Mdot
.62588 .39 Mdot
.55849 .72396 Mdot
.35093 .40234 Mdot
.41909 .67075 Mdot
.44141 .63942 Mdot
.32967 .29173 Mdot
.58402 .41135 Mdot
.29765 .24271 Mdot
.64155 .56272 Mdot
.33918 .48943 Mdot
.57766 .79408 Mdot
.44633 .64755 Mdot
.44041 .21294 Mdot
.53334 .26704 Mdot
.649 .52678 Mdot
.5553 .70792 Mdot
.42312 .69116 Mdot
.45008 .65816 Mdot
.41766 .46251 Mdot
.38927 .47156 Mdot
.48312 .27069 Mdot
.38438 .23807 Mdot
.65072 .57112 Mdot
.53304 .30924 Mdot
.6517 .4185 Mdot
.38959 .42749 Mdot
.40027 .65518 Mdot
.34492 .72647 Mdot
.39896 .49291 Mdot
.65058 .38899 Mdot
.40672 .64496 Mdot
.54216 .30884 Mdot
.54765 .28291 Mdot
.409 .45187 Mdot
.33894 .66002 Mdot
.65491 .55709 Mdot
.44485 .66652 Mdot
.4059 .58685 Mdot
.39954 .51863 Mdot
.39191 .47517 Mdot
.41895 .53689 Mdot
.6329 .55248 Mdot
.33133 .37779 Mdot
.51276 .26479 Mdot
.4153 .67708 Mdot
.36458 .48345 Mdot
.5394 .30174 Mdot
.29215 .39466 Mdot
.5715 .72404 Mdot
.63936 .42131 Mdot
.52968 .31769 Mdot
.53986 .28552 Mdot
.54914 .27498 Mdot
.63862 .77359 Mdot
.46039 .64547 Mdot
.18426 .51843 Mdot
.41715 .47065 Mdot
.302 .317 Mdot
.39531 .40991 Mdot
.65234 .57632 Mdot
.61136 .37703 Mdot
.41096 .47862 Mdot
.41819 .46426 Mdot
.3691 .74798 Mdot
.40812 .55686 Mdot
.48126 .48127 Mdot
.42967 .62855 Mdot
.27803 .46008 Mdot
.59817 .41842 Mdot
.18866 .34393 Mdot
.62891 .81391 Mdot
.44169 .47621 Mdot
.55777 .58515 Mdot
.4048 .67792 Mdot
.64248 .53002 Mdot
.53638 .57868 Mdot
.64101 .49988 Mdot
.41044 .67399 Mdot
.38921 .43052 Mdot
.45284 .81054 Mdot
.55871 .28949 Mdot
.40257 .48128 Mdot
.67402 .56926 Mdot
.40321 .48142 Mdot
.66796 .58163 Mdot
.45879 .70331 Mdot
.5503 .61434 Mdot
.35078 .43421 Mdot
.41127 .51258 Mdot
.37168 .36932 Mdot
.3941 .47444 Mdot
.72393 .49081 Mdot
.42491 .6501 Mdot
.48686 .67698 Mdot
.39088 .50748 Mdot
.32509 .63983 Mdot
.38932 .50067 Mdot
.73061 .55582 Mdot
.37148 .49864 Mdot
.42524 .35248 Mdot
.37347 .5042 Mdot
.37876 .49721 Mdot
.66367 .54535 Mdot
.64502 .52231 Mdot
.39567 .69654 Mdot
.57933 .7225 Mdot
.79007 .60678 Mdot
.37695 .46119 Mdot
.59752 .37437 Mdot
.59747 .75161 Mdot
.53575 .28429 Mdot
.41134 .67108 Mdot
.26595 .23596 Mdot
.66425 .57644 Mdot
.63026 .44773 Mdot
.69383 .46926 Mdot
.61969 .44189 Mdot
.57968 .42158 Mdot
.33056 .53299 Mdot
.52982 .31031 Mdot
.38267 .50268 Mdot
.34999 .62245 Mdot
.51097 .76928 Mdot
.3613 .51275 Mdot
.63956 .36051 Mdot
.42885 .54346 Mdot
.29623 .31665 Mdot
.55976 .28317 Mdot
.52169 .30783 Mdot
.67428 .5489 Mdot
.64951 .43716 Mdot
.45144 .44473 Mdot
.53717 .26905 Mdot
.61845 .37533 Mdot
.57694 .74189 Mdot
.52049 .2341 Mdot
.41334 .65949 Mdot
.42652 .36822 Mdot
.53701 .79991 Mdot
.65799 .57457 Mdot
.58059 .49894 Mdot
.43417 .60965 Mdot
.45041 .69981 Mdot
.57865 .73273 Mdot
.63324 .37109 Mdot
.40177 .63058 Mdot
.41814 .44927 Mdot
.31447 .44031 Mdot
.3617 .46273 Mdot
.53221 .27049 Mdot
.35493 .49162 Mdot
.63374 .37353 Mdot
.65073 .56473 Mdot
.60836 .4027 Mdot
.65159 .55595 Mdot
.44087 .79506 Mdot
.3525 .46379 Mdot
.38842 .47471 Mdot
.55963 .48424 Mdot
.44837 .6728 Mdot
.33623 .57717 Mdot
.63217 .37001 Mdot
.62017 .42824 Mdot
.38674 .43549 Mdot
.41621 .7026 Mdot
.53463 .33027 Mdot
.55554 .55301 Mdot
.36886 .49915 Mdot
.42581 .65099 Mdot
.37995 .43887 Mdot
.72286 .35611 Mdot
.56005 .64141 Mdot
.43875 .63929 Mdot
.18406 .58514 Mdot
.38129 .41094 Mdot
.43014 .54936 Mdot
.34269 .52288 Mdot
.46416 .33498 Mdot
.35328 .51338 Mdot
.40414 .68115 Mdot
.36144 .45528 Mdot
.43153 .67221 Mdot
.62505 .38599 Mdot
.63682 .53112 Mdot
.42782 .67048 Mdot
.3502 .42225 Mdot
.60111 .82242 Mdot
.66446 .57389 Mdot
.39075 .48503 Mdot
.67796 .54383 Mdot
.41101 .62029 Mdot
.45347 .66069 Mdot
.61911 .72377 Mdot
.67054 .4854 Mdot
.67176 .57317 Mdot
.36852 .43526 Mdot
.56665 .77454 Mdot
.38312 .43615 Mdot
.48255 .26276 Mdot
.37844 .51079 Mdot
.38793 .52023 Mdot
.41788 .82433 Mdot
.65681 .49261 Mdot
.27927 .24527 Mdot
.61658 .55154 Mdot
.62779 .77917 Mdot
.46787 .64603 Mdot
.56025 .28413 Mdot
.78545 .49849 Mdot
.54879 .72816 Mdot
.59499 .42366 Mdot
.41062 .47989 Mdot
.39685 .75242 Mdot
.69259 .56733 Mdot
.52727 .2853 Mdot
.35109 .4332 Mdot
.66197 .41044 Mdot
.60537 .76313 Mdot
.64013 .53833 Mdot
.41203 .66087 Mdot
.44619 .67899 Mdot
.17683 .4589 Mdot
.36156 .48072 Mdot
.38219 .47187 Mdot
.69093 .54895 Mdot
.44566 .42752 Mdot
.55637 .29101 Mdot
.74448 .35404 Mdot
.67784 .56639 Mdot
.57135 .65317 Mdot
.42571 .62722 Mdot
.39415 .46228 Mdot
.55918 .4569 Mdot
.67721 .71792 Mdot
.22168 .53172 Mdot
.51871 .27695 Mdot
.46414 .25039 Mdot
.40442 .68165 Mdot
.67286 .56735 Mdot
.31609 .32261 Mdot
.34155 .42669 Mdot
.39572 .45898 Mdot
.46115 .24094 Mdot
.55242 .55898 Mdot
.53426 .24528 Mdot
.3651 .53149 Mdot
.54372 .52416 Mdot
.38858 .43475 Mdot
.40951 .43842 Mdot
.44177 .48014 Mdot
.3447 .47716 Mdot
.42926 .65741 Mdot
.29211 .70955 Mdot
.62862 .4071 Mdot
.22803 .46915 Mdot
.50906 .38458 Mdot
.34125 .45198 Mdot
.39328 .43007 Mdot
.25008 .66929 Mdot
.59446 .72508 Mdot
.42171 .65139 Mdot
.41319 .58877 Mdot
.6372 .52343 Mdot
.40553 .55689 Mdot
.58419 .40469 Mdot
.47511 .48819 Mdot
.61822 .39616 Mdot
.42691 .65111 Mdot
.61357 .42935 Mdot
.64698 .51286 Mdot
.59661 .39184 Mdot
.5865 .40016 Mdot
.64078 .5734 Mdot
.44533 .63555 Mdot
.38548 .497 Mdot
.638 .56216 Mdot
.45853 .21709 Mdot
.5332 .27077 Mdot
.61782 .72659 Mdot
.38324 .53331 Mdot
.43542 .54793 Mdot
.70637 .28236 Mdot
.60311 .40922 Mdot
.54041 .66159 Mdot
.41622 .68699 Mdot
.53702 .3251 Mdot
.431 .66286 Mdot
.24122 .39883 Mdot
.54351 .29513 Mdot
.61756 .73056 Mdot
.33226 .31247 Mdot
.60923 .48592 Mdot
.37482 .40267 Mdot
.47505 .70872 Mdot
.6169 .39453 Mdot
.69527 .56704 Mdot
.76181 .62578 Mdot
.39714 .41621 Mdot
.5023 .7147 Mdot
.46464 .67602 Mdot
.55598 .7131 Mdot
.66877 .56839 Mdot
.63988 .59432 Mdot
.35938 .47703 Mdot
.60119 .48192 Mdot
.37709 .5172 Mdot
.27101 .39645 Mdot
.4742 .28443 Mdot
.41149 .73145 Mdot
.37262 .44023 Mdot
.65178 .39805 Mdot
.37681 .43844 Mdot
.44409 .39753 Mdot
.28428 .3292 Mdot
.42384 .50304 Mdot
.48901 .71388 Mdot
.70657 .30774 Mdot
.40331 .64599 Mdot
.43372 .47875 Mdot
.56361 .73194 Mdot
.38602 .41913 Mdot
.87234 .48727 Mdot
.53287 .29732 Mdot
.63933 .46439 Mdot
.35477 .41631 Mdot
.3712 .48446 Mdot
.34474 .69778 Mdot
.47861 .68355 Mdot
.55126 .71196 Mdot
.4002 .45702 Mdot
.45622 .2673 Mdot
.66943 .54448 Mdot
.35197 .49916 Mdot
.36523 .45601 Mdot
.47979 .18705 Mdot
.66974 .5424 Mdot
.60013 .40973 Mdot
.55033 .71886 Mdot
.65167 .4142 Mdot
.56488 .30034 Mdot
.52404 .58011 Mdot
.42077 .21864 Mdot
.55984 .64405 Mdot
.52154 .31503 Mdot
.3364 .46368 Mdot
.39162 .59504 Mdot
.36605 .4899 Mdot
.51791 .3022 Mdot
.6844 .55246 Mdot
.42747 .65911 Mdot
.38857 .35716 Mdot
.55555 .72738 Mdot
.36552 .51625 Mdot
.55107 .26956 Mdot
.42366 .67052 Mdot
.63942 .69504 Mdot
.40998 .67879 Mdot
.65791 .55097 Mdot
.63701 .51882 Mdot
.53892 .29132 Mdot
.43081 .65979 Mdot
.63788 .42976 Mdot
.61849 .55782 Mdot
.37768 .51286 Mdot
.6216 .52287 Mdot
.38986 .68031 Mdot
.44946 .68288 Mdot
.39349 .67562 Mdot
.34953 .46231 Mdot
.5536 .56906 Mdot
.35725 .40919 Mdot
.67863 .57248 Mdot
.61135 .4345 Mdot
.36409 .25621 Mdot
.34634 .62333 Mdot
.57171 .65104 Mdot
.34218 .50411 Mdot
.35212 .48399 Mdot
.36427 .46199 Mdot
.37562 .44475 Mdot
.74502 .36243 Mdot
.3532 .4629 Mdot
.65205 .54808 Mdot
.62793 .39578 Mdot
.35417 .47575 Mdot
.56605 .73337 Mdot
.52517 .44623 Mdot
.54072 .32149 Mdot
.44466 .35473 Mdot
.63408 .79882 Mdot
.42386 .66861 Mdot
.60596 .38515 Mdot
.62451 .43646 Mdot
.54865 .28061 Mdot
.63754 .55625 Mdot
.41551 .68305 Mdot
.4296 .33138 Mdot
.54188 .26577 Mdot
.37713 .45282 Mdot
.56063 .47145 Mdot
.18966 .60578 Mdot
.3348 .45783 Mdot
.41185 .45988 Mdot
.56885 .70927 Mdot
.61534 .44286 Mdot
.84856 .55383 Mdot
.61179 .61788 Mdot
.53398 .28758 Mdot
.54435 .3119 Mdot
.39555 .67252 Mdot
.34415 .49766 Mdot
.65432 .56073 Mdot
.54631 .53499 Mdot
.70614 .26965 Mdot
.76008 .65861 Mdot
.71804 .40474 Mdot
.40436 .49667 Mdot
.29991 .68717 Mdot
.41354 .49942 Mdot
.46103 .65131 Mdot
.40129 .68716 Mdot
.41808 .65381 Mdot
.66503 .54651 Mdot
.21832 .37464 Mdot
.65015 .54878 Mdot
.63507 .79989 Mdot
.4006 .64277 Mdot
.55868 .41329 Mdot
.62603 .42886 Mdot
.37379 .39323 Mdot
.52767 .30876 Mdot
.65594 .36101 Mdot
.43576 .46708 Mdot
.49971 .63984 Mdot
.59612 .40924 Mdot
.45507 .65634 Mdot
.38913 .38102 Mdot
.80033 .59355 Mdot
.55576 .59946 Mdot
.63482 .22945 Mdot
.26152 .46854 Mdot
.54494 .30111 Mdot
.2067 .55716 Mdot
.55647 .28708 Mdot
.64518 .52956 Mdot
.39621 .415 Mdot
.36768 .40918 Mdot
.39808 .44167 Mdot
.35148 .4582 Mdot
.67883 .55011 Mdot
.40026 .50673 Mdot
.37111 .23478 Mdot
.56076 .74205 Mdot
.56073 .39241 Mdot
.55107 .2956 Mdot
.6535 .5797 Mdot
.62768 .39223 Mdot
.58046 .72755 Mdot
.49495 .21713 Mdot
.40494 .50162 Mdot
.41158 .48218 Mdot
.5683 .74464 Mdot
.43976 .41926 Mdot
.36241 .387 Mdot
.62431 .40852 Mdot
.50964 .511 Mdot
.50992 .28533 Mdot
.54169 .31873 Mdot
.67772 .58456 Mdot
.43118 .66265 Mdot
.52532 .26825 Mdot
.65417 .43231 Mdot
.34779 .49469 Mdot
.41457 .51107 Mdot
.38972 .68052 Mdot
.26081 .33935 Mdot
.56091 .31456 Mdot
.39977 .37604 Mdot
.4264 .6849 Mdot
.46554 .66587 Mdot
.40165 .45879 Mdot
.32807 .49546 Mdot
.45831 .6716 Mdot
.55261 .3031 Mdot
.65352 .58088 Mdot
.56704 .4464 Mdot
.64454 .5591 Mdot
.42272 .67996 Mdot
.38997 .39832 Mdot
.43758 .63055 Mdot
.38126 .41202 Mdot
.11973 .42633 Mdot
.34953 .48466 Mdot
.45859 .60897 Mdot
.47462 .33574 Mdot
.63938 .42373 Mdot
.64518 .41918 Mdot
.5687 .73236 Mdot
.41578 .68992 Mdot
.42962 .46297 Mdot
.53703 .31425 Mdot
.62025 .78004 Mdot
.37823 .68684 Mdot
.59437 .38562 Mdot
.59544 .43201 Mdot
.68352 .55322 Mdot
.38136 .5018 Mdot
.38866 .46298 Mdot
.59622 .39521 Mdot
.73589 .30383 Mdot
.43603 .66708 Mdot
.38198 .47208 Mdot
.34601 .47616 Mdot
.62965 .40412 Mdot
.62163 .57228 Mdot
.45458 .61947 Mdot
.34571 .47819 Mdot
.34744 .30159 Mdot
.66694 .5802 Mdot
.35877 .43867 Mdot
.40652 .50316 Mdot
.53295 .27953 Mdot
.58341 .29511 Mdot
.29113 .32245 Mdot
.63458 .56108 Mdot
.57073 .71241 Mdot
.39568 .4121 Mdot
.6287 .42581 Mdot
.38312 .53174 Mdot
.8079 .47969 Mdot
.55437 .7358 Mdot
.36394 .47276 Mdot
.44049 .44542 Mdot
.44327 .67586 Mdot
.36673 .47666 Mdot
.41662 .74316 Mdot
.64849 .39968 Mdot
.36281 .47273 Mdot
.33858 .65092 Mdot
.68359 .5558 Mdot
.43548 .46208 Mdot
.5337 .31693 Mdot
.47848 .34018 Mdot
.50973 .81745 Mdot
.59224 .37797 Mdot
.54769 .28469 Mdot
.35642 .49332 Mdot
.65476 .398 Mdot
.66576 .5894 Mdot
.49999 .67523 Mdot
.33613 .47277 Mdot
.6454 .56386 Mdot
.65446 .56817 Mdot
.53555 .29179 Mdot
.24273 .27292 Mdot
.44131 .44668 Mdot
.39598 .48149 Mdot
.66376 .21978 Mdot
.42743 .61265 Mdot
.39534 .48591 Mdot
.38169 .50102 Mdot
.64361 .54666 Mdot
.30582 .34811 Mdot
.46741 .52898 Mdot
.7456 .33423 Mdot
.66519 .58116 Mdot
.67023 .41462 Mdot
.64263 .38717 Mdot
.54908 .28916 Mdot
.40385 .64919 Mdot
.51279 .30141 Mdot
.63613 .41211 Mdot
.40558 .44862 Mdot
.65997 .52875 Mdot
.2529 .53243 Mdot
.6963 .56909 Mdot
.66018 .40777 Mdot
.46156 .67272 Mdot
.55787 .81102 Mdot
.73911 .252 Mdot
.52101 .79968 Mdot
.63386 .56307 Mdot
.53558 .28397 Mdot
.59791 .60836 Mdot
.35382 .48543 Mdot
.19505 .54009 Mdot
.39954 .48227 Mdot
.2517 .44543 Mdot
.61324 .37607 Mdot
.57699 .73837 Mdot
.39877 .4171 Mdot
.46249 .25572 Mdot
.63759 .56723 Mdot
.68531 .56388 Mdot
.37417 .44914 Mdot
.65631 .55242 Mdot
.38374 .46636 Mdot
.63205 .39888 Mdot
.24829 .27144 Mdot
.37109 .49634 Mdot
.4306 .45238 Mdot
.64993 .50681 Mdot
.61739 .72837 Mdot
.66568 .39582 Mdot
.30785 .69182 Mdot
.80938 .58655 Mdot
.65775 .55596 Mdot
.30765 .48651 Mdot
.6007 .39938 Mdot
.57366 .71119 Mdot
.59535 .44488 Mdot
.40221 .47363 Mdot
.41018 .49203 Mdot
.3922 .43747 Mdot
.35246 .48251 Mdot
.19785 .55962 Mdot
.37221 .38808 Mdot
.27024 .62725 Mdot
.41329 .47905 Mdot
.43902 .59233 Mdot
.65468 .54422 Mdot
.44423 .54064 Mdot
.54261 .24899 Mdot
.41014 .49433 Mdot
.47985 .67456 Mdot
.64838 .5752 Mdot
.64983 .78379 Mdot
.67564 .54559 Mdot
.60846 .41034 Mdot
.65205 .5218 Mdot
.37517 .4112 Mdot
.4089 .65581 Mdot
.64078 .39402 Mdot
.44052 .77426 Mdot
.59356 .41824 Mdot
.35964 .48099 Mdot
.61257 .51415 Mdot
.6363 .42736 Mdot
.47377 .37542 Mdot
.40723 .65589 Mdot
.44553 .26277 Mdot
.4328 .61363 Mdot
.37266 .47833 Mdot
.37918 .48147 Mdot
.58155 .72859 Mdot
.6397 .53967 Mdot
.40275 .63375 Mdot
.41599 .18612 Mdot
.54002 .25921 Mdot
.41707 .64431 Mdot
.31897 .47576 Mdot
.55928 .57836 Mdot
.44567 .65741 Mdot
.45873 .30526 Mdot
.63963 .54577 Mdot
.39549 .65886 Mdot
.33554 .41971 Mdot
.32203 .37204 Mdot
.55804 .30762 Mdot
.65013 .38477 Mdot
.5466 .50357 Mdot
.64513 .39014 Mdot
.69601 .53971 Mdot
.58474 .42266 Mdot
.66306 .54252 Mdot
.44751 .74074 Mdot
.48867 .53682 Mdot
.6889 .53308 Mdot
.65129 .51058 Mdot
.62968 .41565 Mdot
.37839 .44536 Mdot
.53685 .41179 Mdot
.32228 .47929 Mdot
.40821 .40331 Mdot
.65812 .57787 Mdot
.40138 .67778 Mdot
.42281 .62456 Mdot
.47536 .64369 Mdot
.45161 .66227 Mdot
.635 .39007 Mdot
.55268 .64219 Mdot
.2424 .42511 Mdot
.68547 .54888 Mdot
.65446 .48496 Mdot
.38262 .43442 Mdot
.63128 .42095 Mdot
.6258 .38397 Mdot
.64947 .55981 Mdot
.22008 .50065 Mdot
.42997 .43879 Mdot
.43763 .62069 Mdot
.40112 .64018 Mdot
.44429 .6517 Mdot
.41061 .69815 Mdot
.20423 .39889 Mdot
.6953 .56721 Mdot
.40618 .68246 Mdot
.35759 .45113 Mdot
.40634 .48958 Mdot
.55974 .71358 Mdot
.54998 .30635 Mdot
.40834 .41714 Mdot
.41806 .42424 Mdot
.40114 .45981 Mdot
.63768 .42462 Mdot
.45511 .48681 Mdot
.55345 .73284 Mdot
.58785 .42737 Mdot
.58507 .4004 Mdot
.57711 .72767 Mdot
.3719 .67106 Mdot
.80246 .61935 Mdot
.39959 .44047 Mdot
.36764 .56433 Mdot
.62618 .42397 Mdot
.50823 .60263 Mdot
.31858 .39138 Mdot
.36671 .43774 Mdot
.55723 .37242 Mdot
.63514 .39646 Mdot
.43436 .71081 Mdot
.39791 .47554 Mdot
.57234 .73824 Mdot
.54806 .31954 Mdot
.32324 .45364 Mdot
.56907 .70907 Mdot
.42878 .65079 Mdot
.68445 .28608 Mdot
.41519 .61398 Mdot
.63791 .42757 Mdot
.43467 .47428 Mdot
.18255 .72284 Mdot
.61604 .3938 Mdot
.67631 .74801 Mdot
.49084 .52656 Mdot
.36269 .49336 Mdot
.63772 .38691 Mdot
.44274 .70672 Mdot
.66617 .57994 Mdot
.55609 .49199 Mdot
.40046 .65485 Mdot
.58008 .72995 Mdot
.56963 .71449 Mdot
.62828 .40613 Mdot
.41793 .63136 Mdot
.38629 .51043 Mdot
.43225 .6878 Mdot
.67486 .53061 Mdot
.36458 .4202 Mdot
.79104 .60611 Mdot
.3141 .44019 Mdot
.42533 .68676 Mdot
.65513 .43327 Mdot
.52255 .26472 Mdot
.34935 .43729 Mdot
.73325 .70964 Mdot
.37663 .50183 Mdot
.68129 .54702 Mdot
.48766 .585 Mdot
.25014 .54216 Mdot
.39033 .44541 Mdot
.38915 .43191 Mdot
.66919 .58705 Mdot
.39506 .44495 Mdot
.34027 .47943 Mdot
.66348 .60026 Mdot
.44719 .6638 Mdot
.36463 .46688 Mdot
.63591 .38001 Mdot
.30594 .52751 Mdot
.40802 .4239 Mdot
.44459 .75559 Mdot
.45419 .25568 Mdot
.47883 .56793 Mdot
.43065 .46881 Mdot
.46239 .21119 Mdot
.38385 .48096 Mdot
.34741 .45025 Mdot
.38796 .44035 Mdot
.2936 .68979 Mdot
.6338 .4149 Mdot
.61627 .37202 Mdot
.55195 .31922 Mdot
.45795 .26148 Mdot
.53591 .27672 Mdot
.65361 .58248 Mdot
.68603 .49162 Mdot
.56153 .74158 Mdot
.43152 .66596 Mdot
.41566 .44053 Mdot
.59097 .41622 Mdot
.39687 .4642 Mdot
.38375 .41979 Mdot
.63945 .40151 Mdot
.62893 .38718 Mdot
.58361 .39321 Mdot
.55262 .27652 Mdot
.42313 .65892 Mdot
.41336 .4535 Mdot
.53985 .26559 Mdot
.38117 .50796 Mdot
.56495 .58058 Mdot
.42207 .65575 Mdot
.4335 .68706 Mdot
.42251 .62024 Mdot
.417 .47369 Mdot
.36243 .4157 Mdot
.64944 .54948 Mdot
.38756 .67475 Mdot
.69005 .55476 Mdot
.63934 .38797 Mdot
.64474 .41734 Mdot
.40262 .47386 Mdot
.40341 .37808 Mdot
.54758 .30579 Mdot
.6062 .41173 Mdot
.54976 .73731 Mdot
.55066 .32048 Mdot
.35238 .47218 Mdot
.64311 .3901 Mdot
.53706 .31978 Mdot
.23951 .49154 Mdot
.81636 .56306 Mdot
.53639 .26173 Mdot
.37308 .44955 Mdot
.34456 .68404 Mdot
.32777 .30787 Mdot
.5333 .25661 Mdot
.67039 .53812 Mdot
.39098 .4978 Mdot
.75321 .30942 Mdot
.50864 .28562 Mdot
.26344 .33821 Mdot
.6411 .40604 Mdot
.27166 .43111 Mdot
.32303 .44983 Mdot
.20204 .49727 Mdot
.50823 .28892 Mdot
.41732 .68079 Mdot
.3913 .65816 Mdot
.38053 .45077 Mdot
.5376 .25262 Mdot
.69863 .54923 Mdot
.62496 .43673 Mdot
.58839 .39638 Mdot
.42294 .63027 Mdot
.56551 .64959 Mdot
.63773 .38176 Mdot
.42627 .50503 Mdot
.63827 .45559 Mdot
.39212 .55389 Mdot
.18401 .44734 Mdot
.43281 .7848 Mdot
.42355 .49325 Mdot
.52284 .26329 Mdot
.64232 .57605 Mdot
.65182 .55169 Mdot
.66425 .54835 Mdot
.64878 .41084 Mdot
.54203 .56393 Mdot
.59769 .38552 Mdot
.50528 .72757 Mdot
.53895 .30267 Mdot
.42763 .28052 Mdot
.42341 .44544 Mdot
.36177 .4922 Mdot
.34666 .49465 Mdot
.39412 .43695 Mdot
.38401 .47961 Mdot
.65603 .57367 Mdot
.63791 .43453 Mdot
.71563 .32143 Mdot
.43709 .64353 Mdot
.63274 .68283 Mdot
.6254 .42936 Mdot
.55652 .711 Mdot
.52332 .29063 Mdot
.41971 .22319 Mdot
.66056 .45345 Mdot
.61477 .42934 Mdot
.33367 .46926 Mdot
.40388 .68569 Mdot
.2929 .37438 Mdot
.38335 .48886 Mdot
.60507 .41132 Mdot
.6351 .4494 Mdot
.21138 .5496 Mdot
.40733 .53641 Mdot
.5149 .32649 Mdot
.55789 .57931 Mdot
.50901 .27061 Mdot
.34617 .51145 Mdot
.5124 .60831 Mdot
.63404 .41151 Mdot
.61276 .4092 Mdot
.53786 .26017 Mdot
.46543 .49605 Mdot
.40843 .63854 Mdot
.5756 .74047 Mdot
.66414 .53744 Mdot
.37596 .49133 Mdot
.64957 .40648 Mdot
.38823 .57426 Mdot
.56459 .47583 Mdot
.67714 .55781 Mdot
.59131 .43067 Mdot
.39184 .49984 Mdot
.38594 .44848 Mdot
.54512 .29715 Mdot
.58312 .24005 Mdot
.32182 .47205 Mdot
.62833 .7789 Mdot
.53963 .60588 Mdot
.50578 .45602 Mdot
.39517 .45907 Mdot
.44084 .6361 Mdot
.57398 .73281 Mdot
.52019 .30011 Mdot
.38286 .50626 Mdot
.8181 .59388 Mdot
.38849 .63452 Mdot
.66574 .5727 Mdot
.57451 .73456 Mdot
.53974 .5525 Mdot
.37283 .50159 Mdot
.3995 .48196 Mdot
.35043 .46083 Mdot
.82418 .58849 Mdot
.61736 .37401 Mdot
.39414 .68241 Mdot
.5202 .27492 Mdot
.43975 .68553 Mdot
.60299 .3745 Mdot
.50983 .43136 Mdot
.34887 .47015 Mdot
.43667 .62257 Mdot
.41349 .67927 Mdot
.68432 .55507 Mdot
.63873 .56471 Mdot
.62962 .36587 Mdot
.35472 .48984 Mdot
.56667 .74284 Mdot
.39747 .66246 Mdot
.63811 .43954 Mdot
.54428 .29746 Mdot
.63046 .53733 Mdot
.41431 .47764 Mdot
.62939 .40929 Mdot
.40913 .50728 Mdot
.43995 .67499 Mdot
.61735 .42989 Mdot
.55884 .70797 Mdot
.54773 .30886 Mdot
.4123 .4869 Mdot
.69948 .28818 Mdot
.5762 .73522 Mdot
.34794 .42717 Mdot
.35887 .67668 Mdot
.56098 .26995 Mdot
.4352 .77538 Mdot
.60898 .38044 Mdot
.56126 .73739 Mdot
.39847 .68479 Mdot
.30813 .37772 Mdot
.61569 .40432 Mdot
.36475 .72945 Mdot
.55196 .40659 Mdot
.40666 .44666 Mdot
.41616 .63966 Mdot
.50089 .26846 Mdot
.6501 .77339 Mdot
.356 .28602 Mdot
.37599 .46984 Mdot
.64545 .39002 Mdot
.54213 .31914 Mdot
.68887 .55684 Mdot
.44932 .75271 Mdot
.18744 .46279 Mdot
.58761 .42496 Mdot
.41653 .45329 Mdot
.39763 .66805 Mdot
.65282 .56312 Mdot
.44397 .80632 Mdot
.65683 .42701 Mdot
.62286 .37757 Mdot
.34519 .45764 Mdot
.51754 .2774 Mdot
.75754 .32681 Mdot
.62218 .37272 Mdot
.6504 .41741 Mdot
.62032 .69123 Mdot
.56189 .29802 Mdot
.36103 .45164 Mdot
.47619 .64582 Mdot
.34987 .49544 Mdot
.63544 .76185 Mdot
.5626 .73932 Mdot
.43826 .64636 Mdot
.40457 .48407 Mdot
.70756 .31036 Mdot
.62057 .39579 Mdot
.55633 .58486 Mdot
.67504 .61029 Mdot
.63775 .55954 Mdot
.64822 .40382 Mdot
.39533 .46976 Mdot
.63651 .51778 Mdot
.54821 .30222 Mdot
.34578 .47848 Mdot
.37224 .41227 Mdot
.45466 .6974 Mdot
.66811 .52985 Mdot
.31739 .53562 Mdot
.67058 .52637 Mdot
.68103 .58343 Mdot
.46569 .66312 Mdot
.3794 .45167 Mdot
.60931 .41895 Mdot
.66022 .39962 Mdot
.39618 .50992 Mdot
.50844 .60063 Mdot
.41022 .63855 Mdot
.59249 .45149 Mdot
.84591 .54808 Mdot
.44417 .4662 Mdot
.54766 .7322 Mdot
.26484 .44991 Mdot
.682 .57575 Mdot
.40549 .45069 Mdot
.43297 .67322 Mdot
.64557 .42885 Mdot
.64282 .38269 Mdot
.3305 .45503 Mdot
.64865 .56146 Mdot
.53242 .32154 Mdot
.62012 .38211 Mdot
.56755 .48065 Mdot
.36213 .47499 Mdot
.50144 .716 Mdot
.61365 .38381 Mdot
.56331 .8304 Mdot
.71047 .31526 Mdot
.43455 .63695 Mdot
.38193 .42498 Mdot
.43003 .69756 Mdot
.52316 .27304 Mdot
.59093 .43942 Mdot
.64635 .55971 Mdot
.4347 .37611 Mdot
.46994 .18003 Mdot
.63465 .41945 Mdot
.42836 .65572 Mdot
.41533 .46125 Mdot
.36493 .37695 Mdot
.37105 .49895 Mdot
.32506 .34139 Mdot
.49117 .26893 Mdot
.64668 .51196 Mdot
.68769 .56342 Mdot
.39662 .42941 Mdot
.55416 .28295 Mdot
.65308 .38335 Mdot
.63921 .40363 Mdot
.18878 .33403 Mdot
.56697 .70778 Mdot
.48651 .29367 Mdot
.41608 .47598 Mdot
.6324 .44063 Mdot
.34635 .61558 Mdot
.6907 .54873 Mdot
.36267 .50907 Mdot
.60969 .43821 Mdot
.67207 .71113 Mdot
.55985 .57086 Mdot
.36713 .47206 Mdot
.44624 .42785 Mdot
.6737 .54184 Mdot
.5988 .60957 Mdot
.59628 .38981 Mdot
.36747 .50708 Mdot
.70438 .58429 Mdot
.61152 .71396 Mdot
.44174 .18703 Mdot
.42276 .65871 Mdot
.64987 .44123 Mdot
.6414 .56389 Mdot
.4507 .48787 Mdot
.55175 .29973 Mdot
.65396 .41716 Mdot
.60449 .43222 Mdot
.37027 .42074 Mdot
.41248 .42284 Mdot
.43397 .50885 Mdot
.42382 .64227 Mdot
.6468 .54188 Mdot
.40242 .42626 Mdot
.56908 .63094 Mdot
.4031 .43974 Mdot
.64557 .54593 Mdot
.10719 .58204 Mdot
.33471 .44874 Mdot
.39086 .49157 Mdot
.46832 .35094 Mdot
.41252 .62817 Mdot
.44737 .67103 Mdot
.55545 .6274 Mdot
.41577 .47743 Mdot
.59262 .46758 Mdot
.42491 .66189 Mdot
.40963 .64143 Mdot
.57544 .45016 Mdot
.36205 .42458 Mdot
.70578 .54321 Mdot
.65207 .55973 Mdot
.63799 .56118 Mdot
.44168 .67792 Mdot
.36809 .39502 Mdot
.65976 .58818 Mdot
.19975 .58127 Mdot
.62095 .43221 Mdot
.51255 .60889 Mdot
.42955 .68813 Mdot
.55457 .44366 Mdot
.64079 .53798 Mdot
.5873 .84403 Mdot
.35646 .35147 Mdot
.38881 .51667 Mdot
.38519 .44721 Mdot
.5376 .28163 Mdot
.31754 .4095 Mdot
.56806 .71131 Mdot
.65649 .55045 Mdot
.74403 .37787 Mdot
.4175 .65328 Mdot
.38607 .49507 Mdot
.3736 .24808 Mdot
.46164 .80198 Mdot
.49205 .68257 Mdot
.40255 .65183 Mdot
.41276 .6509 Mdot
.59559 .4108 Mdot
.62376 .43455 Mdot
.35731 .45853 Mdot
.6606 .54559 Mdot
.39431 .65133 Mdot
.65229 .53269 Mdot
.63558 .4113 Mdot
.61692 .42803 Mdot
.55085 .72997 Mdot
.40212 .3936 Mdot
.64419 .41148 Mdot
.62681 .70657 Mdot
.56877 .62722 Mdot
.43232 .70897 Mdot
.72522 .24456 Mdot
.4386 .80741 Mdot
.46476 .34741 Mdot
.54919 .31914 Mdot
.58706 .75181 Mdot
.64155 .52955 Mdot
.39604 .43053 Mdot
.40811 .47155 Mdot
.56118 .71679 Mdot
.63598 .54825 Mdot
.52419 .28351 Mdot
.64052 .53657 Mdot
.52555 .3043 Mdot
.62597 .37022 Mdot
.40689 .42181 Mdot
.35565 .49497 Mdot
.67597 .57148 Mdot
.59877 .40898 Mdot
.63814 .42659 Mdot
.55536 .30929 Mdot
.42288 .22803 Mdot
.62979 .40624 Mdot
.42987 .68823 Mdot
.29616 .53404 Mdot
.56808 .71431 Mdot
.39714 .47563 Mdot
.40234 .22741 Mdot
.20616 .53707 Mdot
.40907 .4471 Mdot
.57483 .73509 Mdot
.20269 .30839 Mdot
.3989 .41599 Mdot
.17912 .38903 Mdot
.55413 .73134 Mdot
.43481 .62851 Mdot
.60219 .39429 Mdot
.57605 .71522 Mdot
.4549 .48395 Mdot
.50038 .25046 Mdot
.42728 .49555 Mdot
.40133 .64415 Mdot
.44371 .6308 Mdot
.49623 .53069 Mdot
.63909 .75889 Mdot
.51403 .28167 Mdot
.52811 .28968 Mdot
.61825 .40364 Mdot
.72422 .55609 Mdot
.3861 .52415 Mdot
.52906 .28696 Mdot
.7723 .3927 Mdot
.3805 .43514 Mdot
.47907 .2631 Mdot
.55055 .38499 Mdot
.43639 .6332 Mdot
.45492 .52932 Mdot
.61847 .39959 Mdot
.42785 .65564 Mdot
.52122 .46474 Mdot
.34902 .49639 Mdot
.42039 .65427 Mdot
.64428 .54279 Mdot
.74782 .56633 Mdot
.45169 .66825 Mdot
.55757 .48889 Mdot
.65584 .56159 Mdot
.55603 .26266 Mdot
.3917 .30754 Mdot
.88306 .53352 Mdot
.65677 .54857 Mdot
.60186 .40358 Mdot
.64373 .41656 Mdot
.63034 .40181 Mdot
.40043 .65205 Mdot
.62427 .38694 Mdot
.43303 .64505 Mdot
.62256 .51293 Mdot
.44938 .21489 Mdot
.54057 .29417 Mdot
.65308 .4751 Mdot
.41396 .67169 Mdot
.51657 .7261 Mdot
.66112 .2043 Mdot
.36713 .44877 Mdot
.69435 .54025 Mdot
.52465 .2611 Mdot
.55429 .67146 Mdot
.5328 .27891 Mdot
.60039 .39839 Mdot
.51319 .61078 Mdot
.38222 .46623 Mdot
.39009 .74554 Mdot
.5329 .31531 Mdot
.40141 .65324 Mdot
.33912 .45618 Mdot
.64005 .36632 Mdot
.54336 .27977 Mdot
.5494 .31751 Mdot
.38654 .47923 Mdot
.45308 .64839 Mdot
.61162 .42422 Mdot
.64271 .52348 Mdot
.51142 .25594 Mdot
.43243 .40337 Mdot
.38344 .44448 Mdot
.33015 .47178 Mdot
.55086 .59235 Mdot
.75966 .32207 Mdot
.65889 .55772 Mdot
.32496 .30583 Mdot
.63829 .42093 Mdot
.35383 .29182 Mdot
.53477 .77093 Mdot
.66743 .45032 Mdot
.56105 .73905 Mdot
.56364 .74002 Mdot
.37317 .47417 Mdot
.77982 .35336 Mdot
.4807 .64415 Mdot
.69548 .58124 Mdot
.5711 .71823 Mdot
.63743 .4273 Mdot
.38508 .66006 Mdot
.4801 .47533 Mdot
.39517 .40679 Mdot
.63465 .55783 Mdot
.63518 .40651 Mdot
.80837 .47822 Mdot
.53764 .30129 Mdot
.53942 .65108 Mdot
.35317 .47589 Mdot
.38567 .47289 Mdot
.66857 .56456 Mdot
.64985 .55053 Mdot
.48976 .72701 Mdot
.50394 .54808 Mdot
.77032 .6237 Mdot
.6951 .53022 Mdot
.8112 .46154 Mdot
.47106 .64386 Mdot
.43 .68199 Mdot
.54825 .72338 Mdot
.66172 .58715 Mdot
.39713 .4865 Mdot
.43083 .62642 Mdot
.49072 .66787 Mdot
.45872 .69672 Mdot
.47459 .27141 Mdot
.56794 .45061 Mdot
.35194 .47841 Mdot
.40605 .69042 Mdot
.42594 .65472 Mdot
.42102 .69931 Mdot
.57642 .72717 Mdot
.39737 .45719 Mdot
.37597 .44545 Mdot
.39466 .41418 Mdot
.37121 .37733 Mdot
.36594 .47689 Mdot
.54138 .77201 Mdot
.5769 .6498 Mdot
.61807 .31285 Mdot
.41824 .46073 Mdot
.6404 .55775 Mdot
.41679 .44241 Mdot
.55409 .28544 Mdot
.41968 .46134 Mdot
.48888 .25123 Mdot
.66762 .55294 Mdot
.47141 .4548 Mdot
.57941 .4354 Mdot
.35021 .47336 Mdot
.52341 .3164 Mdot
.76269 .3267 Mdot
.35454 .26214 Mdot
.62171 .69395 Mdot
.43045 .68795 Mdot
.61963 .36466 Mdot
.69551 .54874 Mdot
.61047 .41882 Mdot
.37448 .5136 Mdot
.5509 .73577 Mdot
.38944 .81338 Mdot
.54344 .44005 Mdot
.39918 .48653 Mdot
.38737 .38701 Mdot
.4448 .64314 Mdot
.62072 .39341 Mdot
.46925 .68396 Mdot
.34773 .45513 Mdot
.52706 .26903 Mdot
.5342 .26621 Mdot
.5052 .47562 Mdot
.78831 .46907 Mdot
.30802 .36849 Mdot
.66668 .56305 Mdot
.64628 .3846 Mdot
.50883 .29139 Mdot
.4786 .71167 Mdot
.69927 .55477 Mdot
.68206 .5755 Mdot
.66655 .52981 Mdot
.35999 .48598 Mdot
.55128 .72197 Mdot
.77954 .42722 Mdot
.58 .7254 Mdot
.344 .46471 Mdot
.60042 .42795 Mdot
.57725 .71574 Mdot
.53759 .27937 Mdot
.67908 .58347 Mdot
.63339 .42646 Mdot
.37563 .48081 Mdot
.42255 .66624 Mdot
.3339 .29025 Mdot
.60769 .21048 Mdot
.63104 .47022 Mdot
.63189 .47135 Mdot
.41859 .61732 Mdot
.72516 .72845 Mdot
.61967 .53272 Mdot
.21794 .50362 Mdot
.49737 .2841 Mdot
.39539 .51074 Mdot
.26268 .27598 Mdot
.59893 .38506 Mdot
.63911 .39199 Mdot
.36243 .46981 Mdot
.64964 .43506 Mdot
.38173 .49767 Mdot
.59317 .39586 Mdot
.69554 .72044 Mdot
.37763 .40341 Mdot
.63666 .3912 Mdot
.37398 .5236 Mdot
.3468 .43852 Mdot
.44595 .64244 Mdot
.65183 .42206 Mdot
.39205 .51659 Mdot
.363 .81331 Mdot
.6828 .56074 Mdot
.57653 .72489 Mdot
.66928 .48294 Mdot
.65291 .52351 Mdot
.42333 .63692 Mdot
.40346 .41673 Mdot
.54666 .30193 Mdot
.42055 .67794 Mdot
.62266 .36048 Mdot
.52567 .31172 Mdot
.55421 .64237 Mdot
.43549 .68196 Mdot
.56005 .7149 Mdot
.54554 .31004 Mdot
.42831 .49441 Mdot
.64142 .39774 Mdot
.68111 .25017 Mdot
.57917 .72413 Mdot
.38885 .46384 Mdot
.661 .42948 Mdot
.64127 .53513 Mdot
.36387 .4581 Mdot
.64934 .3927 Mdot
.57644 .73079 Mdot
.34935 .42661 Mdot
.34637 .43023 Mdot
.48159 .44869 Mdot
.48318 .59766 Mdot
.54323 .29254 Mdot
.46477 .66237 Mdot
.35527 .45242 Mdot
.55547 .28526 Mdot
.71222 .43511 Mdot
.42711 .46699 Mdot
.43918 .69048 Mdot
.41733 .37102 Mdot
.61932 .43506 Mdot
.69024 .55683 Mdot
.66069 .40802 Mdot
.54567 .32133 Mdot
.46516 .15347 Mdot
.55434 .71427 Mdot
.40092 .38984 Mdot
.34589 .49459 Mdot
.59511 .43756 Mdot
.42359 .65075 Mdot
.75751 .64196 Mdot
.41387 .48314 Mdot
.34624 .40447 Mdot
.39272 .4784 Mdot
.70554 .31541 Mdot
.40848 .6404 Mdot
.39566 .47762 Mdot
.40928 .38388 Mdot
.42042 .50748 Mdot
.52189 .31679 Mdot
.42264 .29084 Mdot
.41394 .44076 Mdot
.27716 .81439 Mdot
.56629 .74511 Mdot
.6377 .40055 Mdot
.56282 .5304 Mdot
.7036 .36505 Mdot
.18291 .43271 Mdot
.42841 .64278 Mdot
.2924 .48436 Mdot
.61122 .42213 Mdot
.32627 .27989 Mdot
.68875 .76234 Mdot
.34465 .44246 Mdot
.39555 .49774 Mdot
.60042 .39842 Mdot
.637 .43874 Mdot
.55771 .74175 Mdot
.41611 .49119 Mdot
.35093 .40225 Mdot
.63767 .44422 Mdot
.37182 .48469 Mdot
.24225 .63784 Mdot
.65949 .51854 Mdot
.44484 .67417 Mdot
.68878 .55642 Mdot
.67918 .57572 Mdot
.2294 .44561 Mdot
.53885 .60561 Mdot
.64671 .54762 Mdot
.67106 .59679 Mdot
.49947 .23335 Mdot
.44164 .37658 Mdot
.51477 .30571 Mdot
.78246 .52438 Mdot
.62316 .40353 Mdot
.39896 .45649 Mdot
.40003 .66567 Mdot
.20188 .46571 Mdot
.74447 .60234 Mdot
.51976 .62961 Mdot
.36834 .44644 Mdot
.62345 .39665 Mdot
.57803 .73003 Mdot
.38367 .40355 Mdot
.34061 .30214 Mdot
.38044 .47069 Mdot
.62855 .43605 Mdot
.23411 .43566 Mdot
.41354 .73877 Mdot
.69761 .53418 Mdot
.39957 .70614 Mdot
.41385 .43407 Mdot
.43939 .66666 Mdot
.64333 .56271 Mdot
.55301 .27773 Mdot
.53546 .28517 Mdot
.35003 .48106 Mdot
.48874 .53772 Mdot
.54156 .2337 Mdot
.34633 .44104 Mdot
.36777 .42079 Mdot
.55856 .7361 Mdot
.36718 .42037 Mdot
.36157 .50372 Mdot
.40584 .43175 Mdot
.42064 .48919 Mdot
.67783 .58561 Mdot
.36513 .69942 Mdot
.4213 .45566 Mdot
.44522 .46582 Mdot
.63533 .52481 Mdot
.4147 .54274 Mdot
.6737 .54508 Mdot
.78944 .58304 Mdot
.66177 .53907 Mdot
.53671 .28701 Mdot
.66391 .39909 Mdot
.30694 .50925 Mdot
.39482 .64919 Mdot
.64212 .56849 Mdot
.52787 .30154 Mdot
.65979 .54835 Mdot
.6343 .37561 Mdot
.70042 .23972 Mdot
.45832 .63841 Mdot
.56677 .57897 Mdot
.44471 .34983 Mdot
.50062 .71687 Mdot
.61279 .43193 Mdot
.42307 .63091 Mdot
.41713 .7424 Mdot
.39797 .42804 Mdot
.54764 .29646 Mdot
.37486 .47399 Mdot
.68409 .57987 Mdot
.62433 .39903 Mdot
.61277 .51722 Mdot
.54306 .29097 Mdot
.52792 .16503 Mdot
.59145 .41475 Mdot
.42624 .41177 Mdot
.63691 .52064 Mdot
.70616 .23392 Mdot
.66695 .54058 Mdot
.4442 .21553 Mdot
.40073 .60238 Mdot
.2335 .41252 Mdot
.41131 .65821 Mdot
.4718 .73283 Mdot
.77447 .69948 Mdot
.69331 .74893 Mdot
.42568 .67644 Mdot
.58318 .44538 Mdot
.36224 .48132 Mdot
.39863 .43673 Mdot
.43234 .50003 Mdot
.4228 .71181 Mdot
.35252 .45818 Mdot
.56575 .71152 Mdot
.54709 .60406 Mdot
.75663 .3522 Mdot
.63493 .36887 Mdot
.37985 .49889 Mdot
.65852 .57754 Mdot
.69174 .57521 Mdot
.57954 .71961 Mdot
.66637 .52655 Mdot
.35245 .43205 Mdot
.4128 .66828 Mdot
.53414 .41947 Mdot
.52858 .27254 Mdot
.59303 .77814 Mdot
.5022 .28294 Mdot
.66995 .43502 Mdot
.44114 .47958 Mdot
.6168 .4284 Mdot
.36397 .19302 Mdot
.39375 .43267 Mdot
.42678 .66198 Mdot
.34097 .46367 Mdot
.40784 .43148 Mdot
.41546 .44795 Mdot
.6491 .39022 Mdot
.56378 .53623 Mdot
.37453 .48563 Mdot
.6431 .55456 Mdot
.56687 .43181 Mdot
.40995 .41679 Mdot
.74759 .4018 Mdot
.47059 .28574 Mdot
.50586 .71329 Mdot
.42507 .70867 Mdot
.6065 .40171 Mdot
.41538 .65315 Mdot
.39657 .70944 Mdot
.42356 .63688 Mdot
.75574 .39531 Mdot
.2743 .40247 Mdot
.16662 .41708 Mdot
.334 .60353 Mdot
.21035 .47532 Mdot
.43339 .61902 Mdot
.72815 .45645 Mdot
.43111 .67736 Mdot
.42661 .63951 Mdot
.10779 .47349 Mdot
.41735 .68913 Mdot
.40294 .4724 Mdot
.35432 .41362 Mdot
.51054 .80808 Mdot
.49396 .23455 Mdot
.41881 .45978 Mdot
.35444 .45776 Mdot
.52074 .26809 Mdot
.41893 .38064 Mdot
.58434 .73413 Mdot
.53767 .62991 Mdot
.55964 .75431 Mdot
.38549 .47896 Mdot
.35738 .46656 Mdot
.32682 .47029 Mdot
.7741 .70578 Mdot
.19559 .46126 Mdot
.43279 .62429 Mdot
.44645 .51377 Mdot
.61614 .75032 Mdot
.3401 .48148 Mdot
.34054 .47699 Mdot
.37962 .41133 Mdot
.6098 .42009 Mdot
.38651 .65156 Mdot
.32825 .42507 Mdot
.49889 .77001 Mdot
.35332 .47399 Mdot
.67419 .39866 Mdot
.57053 .33231 Mdot
.39648 .46967 Mdot
.43526 .69119 Mdot
.38268 .43876 Mdot
.41583 .69452 Mdot
.44377 .67393 Mdot
.3966 .39155 Mdot
.78293 .43908 Mdot
.38436 .67391 Mdot
.3422 .44425 Mdot
.60085 .41045 Mdot
.65231 .76982 Mdot
.3913 .46428 Mdot
.51495 .28276 Mdot
.40528 .44959 Mdot
.52844 .32021 Mdot
.368 .41546 Mdot
.58 .7286 Mdot
.24466 .55087 Mdot
.61408 .40863 Mdot
.50843 .25751 Mdot
.63712 .4418 Mdot
.49001 .4278 Mdot
.45759 .6611 Mdot
.58321 .73876 Mdot
.17918 .48546 Mdot
.55725 .73444 Mdot
.30816 .31348 Mdot
.72763 .54586 Mdot
.6774 .57388 Mdot
.40929 .69741 Mdot
.26525 .40145 Mdot
.76692 .4426 Mdot
.58332 .3997 Mdot
.58468 .4008 Mdot
.38674 .1925 Mdot
.24449 .27416 Mdot
.37845 .48838 Mdot
.74758 .29252 Mdot
.26926 .61044 Mdot
.40551 .51992 Mdot
.34815 .51971 Mdot
.60973 .436 Mdot
.41515 .43432 Mdot
.54861 .4886 Mdot
.63056 .41585 Mdot
.52929 .29818 Mdot
.43911 .64886 Mdot
.55084 .31143 Mdot
.76787 .58088 Mdot
.57975 .63597 Mdot
.63926 .41555 Mdot
.42477 .47596 Mdot
.37287 .49381 Mdot
.40265 .69189 Mdot
.38009 .75111 Mdot
.4475 .66518 Mdot
.51215 .29113 Mdot
.62097 .41605 Mdot
.19882 .49303 Mdot
.41048 .45691 Mdot
.41067 .67705 Mdot
.57485 .409 Mdot
.38749 .44819 Mdot
.66922 .5741 Mdot
.36852 .44576 Mdot
.41888 .6855 Mdot
.36745 .41975 Mdot
.41298 .66564 Mdot
.59519 .39966 Mdot
.37028 .50268 Mdot
.35806 .46477 Mdot
.29026 .32306 Mdot
.52375 .28254 Mdot
.45719 .65357 Mdot
.54883 .49514 Mdot
.34898 .49407 Mdot
.34148 .30347 Mdot
.40433 .4194 Mdot
.32907 .52129 Mdot
.32951 .49667 Mdot
.56127 .71225 Mdot
.35632 .50768 Mdot
.39012 .46496 Mdot
.34974 .71896 Mdot
.34389 .64812 Mdot
.46927 .50836 Mdot
.64016 .56867 Mdot
.4376 .68871 Mdot
.64615 .41322 Mdot
.64299 .42935 Mdot
.61754 .38643 Mdot
.48519 .23183 Mdot
.43723 .40644 Mdot
.38116 .46469 Mdot
.6476 .51086 Mdot
.53043 .29056 Mdot
.4029 .66283 Mdot
.53597 .29201 Mdot
.53495 .6259 Mdot
.5165 .30146 Mdot
.56345 .71051 Mdot
.71123 .31505 Mdot
.21386 .60336 Mdot
.51734 .297 Mdot
.44707 .66739 Mdot
.58012 .46122 Mdot
.39638 .51155 Mdot
.65114 .71618 Mdot
.52644 .26893 Mdot
.41379 .18546 Mdot
.3534 .41873 Mdot
.55512 .49934 Mdot
.67799 .54923 Mdot
.54923 .3124 Mdot
.67253 .53135 Mdot
.38646 .43695 Mdot
.43222 .77524 Mdot
.43024 .65995 Mdot
.67466 .52517 Mdot
.36936 .51586 Mdot
.5505 .31141 Mdot
.64194 .41202 Mdot
.37775 .35443 Mdot
.63413 .54835 Mdot
.33563 .28271 Mdot
.35556 .28642 Mdot
.62293 .41685 Mdot
.19408 .61027 Mdot
.6744 .53631 Mdot
.42267 .49267 Mdot
.28025 .41418 Mdot
.37433 .44073 Mdot
.64367 .42295 Mdot
.63578 .38819 Mdot
.56478 .79238 Mdot
.35119 .48053 Mdot
.37036 .40763 Mdot
.39656 .63086 Mdot
.63248 .4219 Mdot
.41905 .63528 Mdot
.39152 .67704 Mdot
.59968 .40167 Mdot
.43308 .63556 Mdot
.53408 .31579 Mdot
.53224 .59844 Mdot
.67242 .53615 Mdot
.65486 .56947 Mdot
.64366 .41311 Mdot
.63952 .37511 Mdot
.61979 .42955 Mdot
.36281 .44456 Mdot
.41074 .63262 Mdot
.37636 .42717 Mdot
.41656 .44363 Mdot
.41627 .59251 Mdot
.4086 .62633 Mdot
.37831 .43166 Mdot
.55757 .38896 Mdot
.54526 .32922 Mdot
.63502 .39075 Mdot
.65003 .53418 Mdot
.28352 .32307 Mdot
.6649 .52109 Mdot
.34484 .48044 Mdot
.66886 .7151 Mdot
.4011 .65051 Mdot
.53459 .2795 Mdot
.56497 .28221 Mdot
.54163 .28667 Mdot
.67507 .52531 Mdot
.394 .68586 Mdot
.55618 .64056 Mdot
.35307 .48946 Mdot
.54945 .59257 Mdot
.29934 .32964 Mdot
.52666 .77132 Mdot
.64534 .54327 Mdot
.36492 .44974 Mdot
.55482 .73107 Mdot
.2111 .55781 Mdot
.37452 .46671 Mdot
.36533 .51081 Mdot
.63698 .27227 Mdot
.44493 .46591 Mdot
.4473 .70258 Mdot
.49511 .50694 Mdot
.38402 .50557 Mdot
.47884 .48627 Mdot
.15271 .37404 Mdot
.35026 .42256 Mdot
.35375 .46833 Mdot
.4061 .46401 Mdot
.39233 .43015 Mdot
.44115 .69309 Mdot
.60839 .24093 Mdot
.65248 .57543 Mdot
.53256 .59542 Mdot
.66718 .53147 Mdot
.64427 .3958 Mdot
.53885 .46835 Mdot
.42249 .69703 Mdot
.54145 .28568 Mdot
.73645 .26783 Mdot
.51803 .60335 Mdot
.59648 .41336 Mdot
.20095 .42227 Mdot
.53027 .27049 Mdot
.39839 .5097 Mdot
.5528 .31907 Mdot
.62125 .44235 Mdot
.64849 .55971 Mdot
.33385 .4654 Mdot
.39849 .64835 Mdot
.45042 .67166 Mdot
.36034 .44921 Mdot
.62163 .77749 Mdot
.64858 .52475 Mdot
.65807 .35264 Mdot
.35666 .48315 Mdot
.36617 .51078 Mdot
.44565 .65505 Mdot
.62264 .39344 Mdot
.71603 .53142 Mdot
.52199 .2906 Mdot
.37308 .51972 Mdot
.38704 .438 Mdot
.53569 .6159 Mdot
.66063 .58541 Mdot
.56949 .72584 Mdot
.35357 .48147 Mdot
.54236 .60837 Mdot
.34567 .47245 Mdot
.3363 .40191 Mdot
.60666 .4224 Mdot
.40201 .39918 Mdot
.40262 .49701 Mdot
.37503 .57919 Mdot
.6788 .53802 Mdot
.42379 .65607 Mdot
.40325 .60537 Mdot
.57205 .73893 Mdot
.67815 .56667 Mdot
.37618 .43434 Mdot
.68923 .56965 Mdot
.40963 .44173 Mdot
.37377 .48259 Mdot
.64503 .54336 Mdot
.42091 .63406 Mdot
.75691 .63078 Mdot
.37076 .71506 Mdot
.38903 .41972 Mdot
.40075 .44523 Mdot
.48462 .24014 Mdot
.17475 .55634 Mdot
.40652 .4954 Mdot
.40735 .63316 Mdot
.38498 .44924 Mdot
.65315 .57102 Mdot
.51274 .29399 Mdot
.42568 .66777 Mdot
.63347 .37267 Mdot
.59746 .39021 Mdot
.57427 .42798 Mdot
.55765 .71207 Mdot
.41179 .49496 Mdot
.46495 .65585 Mdot
.41041 .62251 Mdot
.55338 .67944 Mdot
.63823 .39973 Mdot
.51839 .30807 Mdot
.38044 .40903 Mdot
.36118 .35644 Mdot
.67084 .57973 Mdot
.28524 .81892 Mdot
.55954 .64358 Mdot
.51687 .3162 Mdot
.47716 .56376 Mdot
.55548 .72603 Mdot
.39706 .49123 Mdot
.55583 .29051 Mdot
.61322 .38023 Mdot
.39471 .43613 Mdot
.45247 .46235 Mdot
.76771 .45669 Mdot
.62165 .36844 Mdot
.69085 .56348 Mdot
.61601 .37606 Mdot
.53356 .3239 Mdot
.56566 .71068 Mdot
.45238 .65074 Mdot
.38954 .46855 Mdot
.41044 .55504 Mdot
.6314 .39895 Mdot
.57911 .73556 Mdot
.34903 .47539 Mdot
.44324 .68409 Mdot
.62835 .38732 Mdot
.3892 .48265 Mdot
.2159 .51486 Mdot
.42741 .58747 Mdot
.62197 .40903 Mdot
.33676 .48361 Mdot
.47272 .39715 Mdot
.60812 .3719 Mdot
.60248 .43206 Mdot
.35275 .45883 Mdot
.54308 .31291 Mdot
.37997 .50199 Mdot
.66512 .54285 Mdot
.56395 .53602 Mdot
.6722 .57145 Mdot
.32298 .31011 Mdot
.34832 .41638 Mdot
.49514 .67542 Mdot
.39991 .68044 Mdot
.56315 .28627 Mdot
.33965 .71053 Mdot
.37422 .5109 Mdot
.7888 .62209 Mdot
.55714 .4485 Mdot
.58578 .65912 Mdot
.83341 .54502 Mdot
.51986 .29564 Mdot
.6647 .54823 Mdot
.35283 .46679 Mdot
.6258 .55412 Mdot
.52869 .30866 Mdot
.31786 .31288 Mdot
.34343 .49256 Mdot
.40844 .6426 Mdot
.35771 .47895 Mdot
.42885 .68935 Mdot
.39543 .4476 Mdot
.45965 .45743 Mdot
.51278 .32382 Mdot
.44048 .21646 Mdot
.40434 .50692 Mdot
.73945 .26504 Mdot
.44529 .36491 Mdot
.52047 .27524 Mdot
.38151 .41749 Mdot
.56235 .72154 Mdot
.63926 .54119 Mdot
.72126 .28932 Mdot
.61374 .42529 Mdot
.64977 .54416 Mdot
.44212 .64806 Mdot
.66185 .42025 Mdot
.57237 .74081 Mdot
.2734 .42749 Mdot
.55238 .30894 Mdot
.68156 .56241 Mdot
.39267 .46658 Mdot
.34178 .47586 Mdot
.70437 .30907 Mdot
.22034 .67312 Mdot
.39241 .64895 Mdot
.48645 .1717 Mdot
.46414 .6711 Mdot
.52628 .28601 Mdot
.60917 .42521 Mdot
.40483 .48222 Mdot
.36698 .46547 Mdot
.64984 .41252 Mdot
.41475 .62718 Mdot
.6418 .45392 Mdot
.21805 .43208 Mdot
.6718 .60923 Mdot
.43512 .25484 Mdot
.42811 .6707 Mdot
.43395 .25153 Mdot
.52044 .3187 Mdot
.80229 .48175 Mdot
.43474 .32916 Mdot
.68377 .56752 Mdot
.43568 .25898 Mdot
.40347 .66885 Mdot
.38138 .48979 Mdot
.56125 .71504 Mdot
.55442 .7353 Mdot
.44164 .66176 Mdot
.60215 .39911 Mdot
.55171 .30119 Mdot
.35951 .47429 Mdot
.51678 .69205 Mdot
.46255 .81599 Mdot
.64889 .38679 Mdot
.37956 .38399 Mdot
.65436 .5248 Mdot
.38997 .44579 Mdot
.52741 .26485 Mdot
.65414 .55417 Mdot
.56336 .70694 Mdot
.52167 .59053 Mdot
.38229 .40895 Mdot
.50313 .46685 Mdot
.67921 .55824 Mdot
.17302 .57187 Mdot
.3598 .46389 Mdot
.67478 .53641 Mdot
.37063 .54389 Mdot
.45499 .76794 Mdot
.54386 .40046 Mdot
.71033 .73395 Mdot
.59647 .37164 Mdot
.59975 .38704 Mdot
.32568 .77901 Mdot
.49706 .28533 Mdot
.64333 .56805 Mdot
.57173 .71261 Mdot
.42714 .30524 Mdot
.68123 .53677 Mdot
.33554 .45676 Mdot
.40145 .41691 Mdot
.22543 .44836 Mdot
.47829 .38284 Mdot
.57083 .74637 Mdot
.2887 .44039 Mdot
.35999 .43083 Mdot
.43302 .47675 Mdot
.36725 .45482 Mdot
.44217 .62958 Mdot
.68811 .54216 Mdot
.80983 .31952 Mdot
.69554 .5605 Mdot
.51977 .67471 Mdot
.62316 .40312 Mdot
.65641 .39716 Mdot
.39604 .47084 Mdot
.47742 .63017 Mdot
.77383 .33385 Mdot
.41283 .45543 Mdot
.56545 .28004 Mdot
.35498 .28465 Mdot
.41651 .42247 Mdot
.39172 .62823 Mdot
.34327 .40578 Mdot
.45422 .68589 Mdot
.65234 .55601 Mdot
.5206 .29788 Mdot
.54732 .33042 Mdot
.6711 .54786 Mdot
.37933 .46247 Mdot
.56814 .3282 Mdot
.38872 .47417 Mdot
.37352 .4916 Mdot
.5367 .63948 Mdot
.51998 .26074 Mdot
.62121 .43064 Mdot
.53781 .28619 Mdot
.4244 .64031 Mdot
.09516 .51224 Mdot
.54067 .29988 Mdot
.43743 .3737 Mdot
.5527 .47143 Mdot
.43267 .25935 Mdot
.45093 .66851 Mdot
.51326 .2821 Mdot
.69075 .55258 Mdot
.57937 .66491 Mdot
.19128 .59376 Mdot
.68 .52959 Mdot
.36511 .46759 Mdot
.42043 .69677 Mdot
.42019 .61844 Mdot
.70265 .55963 Mdot
.43806 .63365 Mdot
.43515 .44075 Mdot
.34044 .44681 Mdot
.64546 .56974 Mdot
.50695 .81665 Mdot
.6895 .54375 Mdot
.38375 .35672 Mdot
.36678 .41319 Mdot
.42611 .66474 Mdot
.31114 .49379 Mdot
.46338 .63116 Mdot
.5508 .7318 Mdot
.41984 .45651 Mdot
.54598 .28922 Mdot
.54251 .56323 Mdot
.62083 .40829 Mdot
.67403 .71243 Mdot
.432 .68792 Mdot
.68672 .52963 Mdot
.44722 .64433 Mdot
.39869 .6379 Mdot
.68689 .53681 Mdot
.42719 .64806 Mdot
.35531 .47046 Mdot
.61931 .61853 Mdot
.42844 .68702 Mdot
.67044 .56156 Mdot
.54787 .28861 Mdot
.42871 .63331 Mdot
.62735 .45438 Mdot
.37962 .49386 Mdot
.61216 .43333 Mdot
.52247 .25551 Mdot
.41897 .69802 Mdot
.5129 .28934 Mdot
.63462 .39828 Mdot
.5532 .29719 Mdot
.61608 .55043 Mdot
.62923 .51601 Mdot
.51891 .638 Mdot
.39975 .7347 Mdot
.39899 .66398 Mdot
.58661 .38348 Mdot
.40525 .48983 Mdot
.36097 .48984 Mdot
.54726 .32241 Mdot
.42122 .61704 Mdot
.64876 .76754 Mdot
.30854 .49996 Mdot
.58177 .77663 Mdot
.64973 .58122 Mdot
.40683 .20754 Mdot
.5649 .64993 Mdot
.59896 .66685 Mdot
.35577 .51997 Mdot
.55559 .72423 Mdot
.39353 .47869 Mdot
.35559 .26069 Mdot
.51107 .29117 Mdot
.71942 .5016 Mdot
.38829 .5241 Mdot
.62419 .42386 Mdot
.40357 .45223 Mdot
.74131 .28999 Mdot
.31455 .43711 Mdot
.51747 .2726 Mdot
.63166 .52512 Mdot
.39474 .6494 Mdot
.52845 .27184 Mdot
.59506 .39479 Mdot
.45192 .28511 Mdot
.33018 .46651 Mdot
.35547 .43224 Mdot
.58421 .4091 Mdot
.41367 .636 Mdot
.64302 .39647 Mdot
.67242 .53594 Mdot
.53828 .29681 Mdot
.39258 .42793 Mdot
.42264 .42145 Mdot
.59752 .43765 Mdot
.6939 .56956 Mdot
.64721 .38215 Mdot
.6867 .57308 Mdot
.55576 .72166 Mdot
.41199 .49682 Mdot
.59262 .4307 Mdot
.38147 .53244 Mdot
.35099 .61852 Mdot
.52909 .62911 Mdot
.32597 .68971 Mdot
.62201 .43132 Mdot
.46359 .2588 Mdot
.67109 .55283 Mdot
.6855 .55265 Mdot
.24218 .42761 Mdot
.77506 .34227 Mdot
.59047 .46639 Mdot
.68943 .23624 Mdot
.6715 .53582 Mdot
.67546 .56452 Mdot
.61258 .38199 Mdot
.43253 .64719 Mdot
.37933 .66293 Mdot
.63938 .44614 Mdot
.40187 .22797 Mdot
.40308 .66378 Mdot
.77586 .6578 Mdot
.59106 .39163 Mdot
.33712 .50362 Mdot
.56432 .74968 Mdot
.52151 .27013 Mdot
.36519 .25625 Mdot
.70209 .24961 Mdot
.40177 .48061 Mdot
.20041 .35954 Mdot
.60755 .40543 Mdot
.71103 .60202 Mdot
.79172 .52564 Mdot
.35224 .50157 Mdot
.40321 .45507 Mdot
.37849 .45866 Mdot
.53761 .25882 Mdot
.35672 .70508 Mdot
.40069 .48321 Mdot
.45051 .21745 Mdot
.37126 .40333 Mdot
.68578 .25901 Mdot
.53784 .28659 Mdot
.30958 .34638 Mdot
.60198 .36505 Mdot
.51041 .76092 Mdot
.43379 .49429 Mdot
.67231 .53837 Mdot
.7648 .51732 Mdot
.64327 .54953 Mdot
.79754 .41994 Mdot
.43109 .32764 Mdot
.44211 .62873 Mdot
.36702 .44615 Mdot
.58634 .41052 Mdot
.41782 .6964 Mdot
.71966 .53353 Mdot
.10425 .47016 Mdot
.67856 .58636 Mdot
.30176 .20666 Mdot
.68727 .55789 Mdot
.5569 .73927 Mdot
.44412 .65856 Mdot
.45694 .54166 Mdot
.54626 .59077 Mdot
.42036 .63529 Mdot
.61713 .32762 Mdot
.39754 .61377 Mdot
.45243 .24727 Mdot
.43197 .61201 Mdot
.66725 .55675 Mdot
.63598 .51413 Mdot
.43029 .52177 Mdot
.4072 .49245 Mdot
.55349 .60329 Mdot
.3852 .53848 Mdot
.41598 .47737 Mdot
.63047 .416 Mdot
.42584 .75266 Mdot
.712 .58984 Mdot
.43395 .67198 Mdot
.66726 .58224 Mdot
.40433 .4548 Mdot
.38788 .4194 Mdot
.4154 .51141 Mdot
.3268 .28615 Mdot
.77811 .65097 Mdot
.37615 .48502 Mdot
.3651 .39754 Mdot
.59731 .41144 Mdot
.69991 .2927 Mdot
.54446 .19017 Mdot
.4333 .31124 Mdot
.34842 .48051 Mdot
.52723 .28111 Mdot
.51412 .27217 Mdot
.42969 .42026 Mdot
.50268 .66887 Mdot
.63074 .46292 Mdot
.39276 .46633 Mdot
.47341 .34119 Mdot
.59955 .44602 Mdot
.58081 .7298 Mdot
.6319 .39934 Mdot
.42283 .69833 Mdot
.55801 .73707 Mdot
.64682 .38948 Mdot
.44172 .58175 Mdot
.57183 .73806 Mdot
.46865 .76891 Mdot
.512 .29049 Mdot
.3644 .45807 Mdot
.47118 .68788 Mdot
.64888 .41266 Mdot
.68162 .55822 Mdot
.41752 .66891 Mdot
.64161 .57622 Mdot
.70377 .29464 Mdot
.37731 .25129 Mdot
.55411 .71483 Mdot
.66917 .53868 Mdot
.5053 .52947 Mdot
.52986 .28182 Mdot
.6756 .52979 Mdot
.48932 .66685 Mdot
.41106 .41965 Mdot
.81312 .41117 Mdot
.35217 .4393 Mdot
.60385 .79186 Mdot
.68298 .54979 Mdot
.54682 .72207 Mdot
.38731 .46909 Mdot
.59149 .41276 Mdot
.40817 .54412 Mdot
.38676 .47463 Mdot
.61946 .37389 Mdot
.37954 .48815 Mdot
.53884 .26487 Mdot
.4443 .6962 Mdot
.55067 .44212 Mdot
.34463 .25257 Mdot
.55016 .28644 Mdot
.5908 .72591 Mdot
.41157 .491 Mdot
.58774 .2714 Mdot
.41393 .64135 Mdot
.36221 .50792 Mdot
.22662 .3727 Mdot
.43824 .65655 Mdot
.41426 .65259 Mdot
.37016 .42237 Mdot
.67619 .52709 Mdot
.63801 .42573 Mdot
.53245 .28196 Mdot
.72719 .56069 Mdot
.39019 .48442 Mdot
.36252 .45129 Mdot
.53048 .27091 Mdot
.6749 .56785 Mdot
.38914 .42765 Mdot
.71577 .65673 Mdot
.54649 .67665 Mdot
.67795 .57693 Mdot
.41284 .4205 Mdot
.83548 .43544 Mdot
.38025 .67806 Mdot
.18852 .37499 Mdot
.49815 .279 Mdot
.60185 .40588 Mdot
.40672 .38931 Mdot
.23687 .77955 Mdot
.51838 .27564 Mdot
.52225 .76245 Mdot
.37078 .48684 Mdot
.41314 .47302 Mdot
.45551 .65326 Mdot
.37338 .43116 Mdot
.41777 .68732 Mdot
.35187 .24259 Mdot
.71977 .231 Mdot
.44411 .64137 Mdot
.42222 .68899 Mdot
.44742 .54056 Mdot
.31539 .29956 Mdot
.43953 .64722 Mdot
.32978 .46736 Mdot
.62019 .31944 Mdot
.43854 .41276 Mdot
.50514 .29166 Mdot
.56686 .30316 Mdot
.4096 .61488 Mdot
.25358 .69367 Mdot
.38712 .55235 Mdot
.47473 .44937 Mdot
.54083 .23668 Mdot
.65727 .53777 Mdot
.39815 .41839 Mdot
.56113 .71034 Mdot
.62588 .38439 Mdot
.32997 .41591 Mdot
.36665 .46022 Mdot
.42151 .69311 Mdot
.54331 .26114 Mdot
.67328 .53009 Mdot
.35472 .4594 Mdot
.66844 .42417 Mdot
.52597 .29628 Mdot
.42867 .68575 Mdot
.433 .37182 Mdot
.51368 .30571 Mdot
.4303 .43828 Mdot
.41582 .47473 Mdot
.34759 .47382 Mdot
.42844 .5075 Mdot
.67372 .54831 Mdot
.65221 .43946 Mdot
.4268 .40792 Mdot
.54271 .62795 Mdot
.54632 .54805 Mdot
.42485 .40763 Mdot
.41098 .63113 Mdot
.6398 .56581 Mdot
.5716 .73371 Mdot
.4275 .28094 Mdot
.35586 .41778 Mdot
.78467 .63461 Mdot
.20182 .4377 Mdot
.56603 .73599 Mdot
.45417 .63671 Mdot
.53757 .28226 Mdot
.35935 .42496 Mdot
.58424 .30404 Mdot
.33778 .45285 Mdot
.36133 .37361 Mdot
.60434 .40652 Mdot
.65504 .53435 Mdot
.53759 .69186 Mdot
.62679 .38398 Mdot
.41501 .65291 Mdot
.63206 .80216 Mdot
.38697 .63005 Mdot
.38894 .66128 Mdot
.78641 .43803 Mdot
.64914 .55376 Mdot
.26234 .80278 Mdot
.17331 .55723 Mdot
.34077 .43726 Mdot
.64565 .56336 Mdot
.44332 .66744 Mdot
.35762 .44421 Mdot
.40036 .66489 Mdot
.38365 .66383 Mdot
.41802 .44329 Mdot
.41193 .48291 Mdot
.4299 .22189 Mdot
.76975 .6809 Mdot
.54731 .29779 Mdot
.43318 .62776 Mdot
.2209 .46639 Mdot
.4005 .48557 Mdot
.35415 .49054 Mdot
.77222 .4841 Mdot
.51533 .27759 Mdot
.23989 .62468 Mdot
.3609 .48718 Mdot
.22942 .36592 Mdot
.41766 .47499 Mdot
.41681 .7228 Mdot
.70466 .55217 Mdot
.50656 .68035 Mdot
.64177 .42503 Mdot
.41525 .70228 Mdot
.53506 .32062 Mdot
.41332 .70357 Mdot
.24113 .43867 Mdot
.64997 .55718 Mdot
.41873 .68554 Mdot
.66056 .39454 Mdot
.66165 .56666 Mdot
.68435 .56795 Mdot
.57289 .44202 Mdot
.66212 .41284 Mdot
.541 .26244 Mdot
.6426 .53761 Mdot
.21963 .50032 Mdot
.66368 .55694 Mdot
.22754 .46396 Mdot
.38532 .50394 Mdot
.43871 .22919 Mdot
.53256 .68741 Mdot
.42822 .5164 Mdot
.68544 .5383 Mdot
.54242 .30824 Mdot
.37323 .43818 Mdot
.43475 .63132 Mdot
.53913 .30382 Mdot
.65506 .59723 Mdot
.65028 .37991 Mdot
.41177 .61803 Mdot
.64056 .51661 Mdot
.41101 .68437 Mdot
.35566 .27362 Mdot
.66344 .45178 Mdot
.55596 .37143 Mdot
.54993 .58618 Mdot
.42055 .49997 Mdot
.47715 .49028 Mdot
.34448 .49058 Mdot
.37016 .46367 Mdot
.62247 .40824 Mdot
.48359 .23238 Mdot
.42728 .6325 Mdot
.51841 .83449 Mdot
.67469 .54205 Mdot
.4939 .5138 Mdot
.33413 .37796 Mdot
.40627 .44071 Mdot
.43382 .67908 Mdot
.38525 .66441 Mdot
.34362 .64911 Mdot
.65065 .41123 Mdot
.44787 .43507 Mdot
.44251 .47197 Mdot
.44032 .40881 Mdot
.68709 .56148 Mdot
.73301 .64179 Mdot
.65499 .40279 Mdot
.22036 .27835 Mdot
.6352 .39022 Mdot
.60713 .26208 Mdot
.42807 .64873 Mdot
.52113 .30938 Mdot
.35932 .49464 Mdot
.36539 .6738 Mdot
.44838 .68658 Mdot
.59536 .45132 Mdot
.53846 .28054 Mdot
.74744 .63481 Mdot
.64826 .54818 Mdot
.37058 .50524 Mdot
.41753 .43995 Mdot
.37796 .42366 Mdot
.34441 .45382 Mdot
.65291 .57817 Mdot
.33564 .46027 Mdot
.63409 .56649 Mdot
.20689 .53215 Mdot
.23154 .37149 Mdot
.59494 .42754 Mdot
.68618 .26643 Mdot
.40132 .63575 Mdot
.24043 .49655 Mdot
.23581 .62759 Mdot
.52922 .63258 Mdot
.61187 .52854 Mdot
.39746 .50275 Mdot
.60267 .39665 Mdot
.7517 .29574 Mdot
.59121 .42499 Mdot
.75606 .24331 Mdot
.27134 .39546 Mdot
.69751 .75176 Mdot
.35307 .44368 Mdot
.6355 .44881 Mdot
.2768 .6947 Mdot
.41808 .41412 Mdot
.56523 .32634 Mdot
.36367 .36304 Mdot
.50715 .80025 Mdot
.51739 .30739 Mdot
.38271 .49281 Mdot
.39945 .63293 Mdot
.3558 .47175 Mdot
.37143 .49861 Mdot
.41143 .45438 Mdot
.69122 .58255 Mdot
.41426 .42898 Mdot
.37901 .50186 Mdot
.20129 .64801 Mdot
.47689 .26776 Mdot
.59526 .41328 Mdot
.33105 .66719 Mdot
.53049 .29102 Mdot
.41442 .69555 Mdot
.55926 .45699 Mdot
.65909 .54235 Mdot
.34475 .63544 Mdot
.35265 .44191 Mdot
.55607 .77509 Mdot
.65615 .51451 Mdot
.53045 .30664 Mdot
.57421 .73436 Mdot
.77687 .59702 Mdot
.6297 .43784 Mdot
.55942 .74357 Mdot
.61979 .40818 Mdot
.31717 .71767 Mdot
.4259 .69046 Mdot
.42351 .49705 Mdot
.66147 .52782 Mdot
.60751 .43421 Mdot
.50908 .21869 Mdot
.37907 .45392 Mdot
.6237 .43153 Mdot
.42253 .49538 Mdot
.55146 .55038 Mdot
.56057 .476 Mdot
.62735 .44315 Mdot
.63581 .51528 Mdot
.66156 .56927 Mdot
.53022 .31514 Mdot
.40807 .6944 Mdot
.40314 .64145 Mdot
.6563 .55799 Mdot
.21867 .30182 Mdot
.39172 .48366 Mdot
.41667 .46904 Mdot
.54781 .63185 Mdot
.34993 .45002 Mdot
.463 .2824 Mdot
.58487 .7266 Mdot
.39805 .66824 Mdot
.34618 .45629 Mdot
.38944 .427 Mdot
.3849 .41 Mdot
.37871 .25242 Mdot
.63013 .39674 Mdot
.36007 .4297 Mdot
.55601 .30018 Mdot
.48671 .72858 Mdot
.40193 .49216 Mdot
.42537 .42977 Mdot
.41306 .68398 Mdot
.43864 .18662 Mdot
.68191 .55287 Mdot
.63414 .42275 Mdot
.592 .38868 Mdot
.35045 .31079 Mdot
.41713 .70882 Mdot
.58237 .73783 Mdot
.72054 .38681 Mdot
.57594 .71912 Mdot
.52119 .27622 Mdot
.55694 .40219 Mdot
.66892 .42756 Mdot
.59385 .39362 Mdot
.62799 .52062 Mdot
.34597 .46105 Mdot
.41747 .47414 Mdot
.521 .75735 Mdot
.41601 .45456 Mdot
.54391 .28398 Mdot
.6392 .52044 Mdot
.4142 .68321 Mdot
.53251 .26536 Mdot
.68641 .55062 Mdot
.4135 .63552 Mdot
.40708 .41232 Mdot
.41921 .51028 Mdot
.41493 .66347 Mdot
.4392 .68316 Mdot
.40176 .46829 Mdot
.27958 .73438 Mdot
.39627 .66112 Mdot
.42542 .67944 Mdot
.54429 .73002 Mdot
.62605 .4391 Mdot
.3036 .46126 Mdot
.64594 .56178 Mdot
.35206 .47885 Mdot
.59608 .42926 Mdot
.51586 .295 Mdot
.40892 .66039 Mdot
.38719 .41387 Mdot
.38157 .4819 Mdot
.52821 .28017 Mdot
.51171 .26904 Mdot
.5446 .28052 Mdot
.67437 .59082 Mdot
.34323 .44343 Mdot
.43818 .6435 Mdot
.64666 .55013 Mdot
.51308 .27477 Mdot
.55965 .31016 Mdot
.19677 .63412 Mdot
.40092 .47921 Mdot
.57599 .31856 Mdot
.10524 .56745 Mdot
.45149 .29406 Mdot
.56416 .74255 Mdot
.61517 .44464 Mdot
.4477 .22745 Mdot
.50853 .25593 Mdot
.64083 .55989 Mdot
.48268 .35331 Mdot
.55561 .27163 Mdot
.41448 .44124 Mdot
.38747 .44415 Mdot
.34513 .50771 Mdot
.53218 .2988 Mdot
.36515 .26599 Mdot
.41703 .62053 Mdot
.26671 .57861 Mdot
.53061 .2912 Mdot
.62885 .44299 Mdot
.60125 .43819 Mdot
.63693 .39001 Mdot
.39361 .50531 Mdot
.33992 .67948 Mdot
.21681 .48243 Mdot
.24899 .62567 Mdot
.64988 .54505 Mdot
.38602 .65607 Mdot
.61257 .51722 Mdot
.4136 .65221 Mdot
.61758 .38843 Mdot
.52977 .30153 Mdot
.45262 .64302 Mdot
.6747 .57373 Mdot
.66809 .57223 Mdot
.64018 .37404 Mdot
.63567 .40176 Mdot
.64055 .4142 Mdot
.41368 .70081 Mdot
.42743 .64802 Mdot
.39271 .4244 Mdot
.4114 .67147 Mdot
.1849 .46643 Mdot
.50399 .28935 Mdot
.58369 .40246 Mdot
.67707 .55612 Mdot
.43547 .68173 Mdot
.36201 .45977 Mdot
.65544 .28507 Mdot
.58771 .44338 Mdot
.54812 .27976 Mdot
.58778 .58886 Mdot
.64169 .1682 Mdot
.42317 .44652 Mdot
.68513 .57755 Mdot
.49903 .67241 Mdot
.38558 .45601 Mdot
.6082 .41969 Mdot
.26115 .38351 Mdot
.5792 .72874 Mdot
.38905 .49913 Mdot
.37534 .51508 Mdot
.68435 .53514 Mdot
.5601 .4645 Mdot
.41408 .44778 Mdot
.5202 .46748 Mdot
.68942 .57923 Mdot
.65495 .40133 Mdot
.35564 .81192 Mdot
.66915 .6072 Mdot
.44768 .20775 Mdot
.56642 .74061 Mdot
.41389 .43658 Mdot
.62805 .41459 Mdot
.55244 .28321 Mdot
.63053 .40876 Mdot
.43989 .61887 Mdot
.61937 .435 Mdot
.37519 .45049 Mdot
.43524 .64179 Mdot
.679 .5652 Mdot
.49668 .49066 Mdot
.23035 .67843 Mdot
.59184 .41173 Mdot
.57314 .70836 Mdot
.39628 .49292 Mdot
.21573 .55593 Mdot
.43231 .52135 Mdot
.40426 .49596 Mdot
.64305 .54731 Mdot
.43438 .67631 Mdot
.64687 .57822 Mdot
.4252 .44116 Mdot
.25935 .46751 Mdot
.67292 .54254 Mdot
.47387 .79099 Mdot
.52828 .2704 Mdot
.39895 .22988 Mdot
.37457 .46919 Mdot
.66129 .52828 Mdot
.34359 .44156 Mdot
.43214 .62665 Mdot
.5289 .55937 Mdot
.48886 .71554 Mdot
.65284 .52495 Mdot
.61597 .79659 Mdot
.54851 .49698 Mdot
.30849 .44148 Mdot
.6719 .53379 Mdot
.33899 .70502 Mdot
.56516 .72326 Mdot
.52096 .28882 Mdot
.5141 .26891 Mdot
.55005 .31562 Mdot
.41662 .45628 Mdot
.44109 .40112 Mdot
.56117 .29494 Mdot
.66774 .59003 Mdot
.55528 .2819 Mdot
.33056 .29191 Mdot
.63124 .77566 Mdot
.54332 .27681 Mdot
.3718 .47164 Mdot
.42217 .42518 Mdot
.47825 .26425 Mdot
.65775 .41164 Mdot
.78809 .61094 Mdot
.18453 .55547 Mdot
.40607 .48073 Mdot
.27605 .40349 Mdot
.42569 .61426 Mdot
.47954 .59946 Mdot
.29042 .47202 Mdot
.5734 .45717 Mdot
.42826 .68202 Mdot
.56143 .55766 Mdot
.39886 .67537 Mdot
.42937 .47772 Mdot
.37262 .48236 Mdot
.44782 .6901 Mdot
.66504 .70721 Mdot
.4121 .79146 Mdot
.59456 .77886 Mdot
.40524 .636 Mdot
.67888 .53786 Mdot
.68506 .58035 Mdot
.64624 .54224 Mdot
.64566 .41604 Mdot
.43966 .6856 Mdot
.35325 .42617 Mdot
.59662 .3967 Mdot
.35802 .49076 Mdot
.65368 .56414 Mdot
.54645 .67795 Mdot
.41508 .6844 Mdot
.39041 .4656 Mdot
.19555 .60104 Mdot
.61847 .4007 Mdot
.52814 .28289 Mdot
.59984 .61123 Mdot
.61024 .44464 Mdot
.69534 .55648 Mdot
.39668 .70467 Mdot
.58742 .36515 Mdot
.6092 .23925 Mdot
.32744 .47202 Mdot
.32978 .46051 Mdot
.67918 .4876 Mdot
.21886 .65184 Mdot
.40804 .44727 Mdot
.59534 .39303 Mdot
.62931 .441 Mdot
.34139 .44194 Mdot
.45237 .6554 Mdot
.55751 .27773 Mdot
.54521 .32235 Mdot
.40577 .50994 Mdot
.55365 .59404 Mdot
.43714 .22469 Mdot
.3809 .431 Mdot
.34336 .38481 Mdot
.65927 .39411 Mdot
.57151 .74099 Mdot
.53771 .60464 Mdot
.53968 .31821 Mdot
.36988 .48802 Mdot
.42911 .79589 Mdot
.42226 .68605 Mdot
.63273 .42877 Mdot
.66094 .57704 Mdot
.56254 .3309 Mdot
.60017 .37423 Mdot
.34151 .44167 Mdot
.38908 .42739 Mdot
.66749 .52685 Mdot
.42035 .72379 Mdot
.5323 .30162 Mdot
.59633 .40152 Mdot
.52177 .31027 Mdot
.42292 .64321 Mdot
.4216 .68086 Mdot
.44308 .46626 Mdot
.42585 .52214 Mdot
.59103 .39462 Mdot
.35976 .51371 Mdot
.63543 .38524 Mdot
.70373 .30597 Mdot
.66966 .58012 Mdot
.35667 .5053 Mdot
.45478 .70136 Mdot
.65368 .56281 Mdot
.40957 .47135 Mdot
.67832 .48833 Mdot
.39304 .43403 Mdot
.6381 .44748 Mdot
.2403 .40773 Mdot
.52805 .30922 Mdot
.47562 .48785 Mdot
.41535 .56419 Mdot
.35088 .4498 Mdot
.65603 .4285 Mdot
.45796 .43306 Mdot
.67056 .54382 Mdot
.43355 .65879 Mdot
.3624 .19513 Mdot
.66773 .5606 Mdot
.36175 .47715 Mdot
.53931 .29953 Mdot
.39303 .6532 Mdot
.55275 .72037 Mdot
.55951 .62904 Mdot
.32134 .42674 Mdot
.33365 .50588 Mdot
.34902 .46716 Mdot
.68963 .23521 Mdot
.63558 .41449 Mdot
.43991 .67536 Mdot
.67834 .5823 Mdot
.65525 .54991 Mdot
.62214 .39351 Mdot
.53582 .79955 Mdot
.68382 .71923 Mdot
.12025 .6145 Mdot
.59732 .3801 Mdot
.5587 .29808 Mdot
.53983 .54248 Mdot
.62817 .38316 Mdot
.62893 .42004 Mdot
.64852 .37641 Mdot
.5351 .7563 Mdot
.41421 .63227 Mdot
.38229 .48344 Mdot
.42427 .7088 Mdot
.41516 .43974 Mdot
.49549 .21184 Mdot
.65401 .55659 Mdot
.43264 .65638 Mdot
.67378 .44904 Mdot
.36213 .53964 Mdot
.39568 .4532 Mdot
.58618 .31948 Mdot
.32527 .42838 Mdot
.43351 .26849 Mdot
.42481 .50516 Mdot
.62818 .40299 Mdot
.27712 .45771 Mdot
.39158 .38846 Mdot
.19218 .57721 Mdot
.67465 .57128 Mdot
.54983 .72154 Mdot
.40123 .40744 Mdot
.32967 .40414 Mdot
.39181 .65974 Mdot
.45354 .64455 Mdot
.56126 .29278 Mdot
.61581 .62299 Mdot
.67719 .56939 Mdot
.73305 .68989 Mdot
.40895 .49206 Mdot
.72172 .57928 Mdot
.23783 .40735 Mdot
.40754 .46768 Mdot
.56188 .39597 Mdot
.34453 .63858 Mdot
.40348 .44007 Mdot
.25786 .624 Mdot
.67347 .55663 Mdot
.22861 .36839 Mdot
.38711 .52135 Mdot
.60925 .41997 Mdot
.43258 .64912 Mdot
.41231 .61813 Mdot
.54484 .274 Mdot
.1769 .50488 Mdot
.64934 .49808 Mdot
.43004 .65057 Mdot
.37689 .45711 Mdot
.68102 .5551 Mdot
.55002 .72567 Mdot
.31684 .4809 Mdot
.78213 .38444 Mdot
.41201 .67606 Mdot
.41849 .39834 Mdot
.58766 .78026 Mdot
.55914 .50592 Mdot
.77721 .67036 Mdot
.64758 .53634 Mdot
.54074 .31898 Mdot
.41072 .52286 Mdot
.71934 .38763 Mdot
.39438 .52137 Mdot
.47426 .20857 Mdot
.4646 .62966 Mdot
.51289 .29459 Mdot
.3862 .45891 Mdot
.41321 .44703 Mdot
.5438 .57338 Mdot
.50879 .27746 Mdot
.41404 .44668 Mdot
.44379 .43687 Mdot
.41048 .63864 Mdot
.58456 .72302 Mdot
.41054 .67882 Mdot
.36393 .46688 Mdot
.29003 .3694 Mdot
.45135 .64448 Mdot
.77379 .61979 Mdot
.49388 .29009 Mdot
.65952 .54174 Mdot
.36156 .38451 Mdot
.39343 .50198 Mdot
.85549 .52319 Mdot
.55134 .73282 Mdot
.4973 .17977 Mdot
.62779 .44693 Mdot
.47048 .84108 Mdot
.60774 .44524 Mdot
.6719 .77541 Mdot
.49916 .51046 Mdot
.34234 .49954 Mdot
.45642 .34212 Mdot
.24977 .61705 Mdot
.62628 .54693 Mdot
.22756 .5241 Mdot
.40703 .49249 Mdot
.38982 .49148 Mdot
.60588 .38522 Mdot
.55515 .79485 Mdot
.50217 .68283 Mdot
.53985 .59722 Mdot
.52692 .3026 Mdot
.4232 .65115 Mdot
.38044 .44879 Mdot
.63754 .68176 Mdot
.5982 .4228 Mdot
.41948 .35733 Mdot
.38789 .46712 Mdot
.51514 .67349 Mdot
.50891 .78535 Mdot
.68267 .56041 Mdot
.63621 .44483 Mdot
.65488 .43519 Mdot
.40309 .41918 Mdot
.64583 .56828 Mdot
.3997 .43049 Mdot
.54615 .50042 Mdot
.36011 .4003 Mdot
.5152 .28491 Mdot
.35592 .49383 Mdot
.47313 .36045 Mdot
.66486 .79701 Mdot
.36267 .39347 Mdot
.39544 .67925 Mdot
.64642 .40912 Mdot
.63008 .39239 Mdot
.40284 .64137 Mdot
.62909 .39157 Mdot
.26993 .58882 Mdot
.24302 .45693 Mdot
.51836 .27781 Mdot
.23307 .63358 Mdot
.52483 .3043 Mdot
.55018 .71997 Mdot
.40227 .47574 Mdot
.73518 .39882 Mdot
.59685 .38003 Mdot
.28984 .31987 Mdot
.66044 .55528 Mdot
.55269 .73472 Mdot
.35777 .41309 Mdot
.577 .29166 Mdot
.6101 .39053 Mdot
.76387 .5492 Mdot
.38726 .41127 Mdot
.42356 .62696 Mdot
.40681 .44191 Mdot
.33545 .42564 Mdot
.5627 .74381 Mdot
.34806 .46642 Mdot
.68636 .55041 Mdot
.43927 .68688 Mdot
.67653 .76746 Mdot
.64785 .41427 Mdot
.38599 .49692 Mdot
.37854 .45713 Mdot
.45523 .64528 Mdot
.35729 .41202 Mdot
.64174 .5594 Mdot
.32534 .84955 Mdot
.52594 .27154 Mdot
.57346 .74011 Mdot
.76782 .58091 Mdot
.37495 .44505 Mdot
.37812 .43544 Mdot
.69812 .51532 Mdot
.40211 .77251 Mdot
.67774 .54222 Mdot
.36749 .4026 Mdot
.59943 .41704 Mdot
.53644 .30529 Mdot
.63883 .54161 Mdot
.34099 .44729 Mdot
.39147 .49044 Mdot
.51682 .27761 Mdot
.5864 .31388 Mdot
.6328 .4563 Mdot
.64815 .54437 Mdot
.28205 .40142 Mdot
.66391 .29076 Mdot
.39095 .47846 Mdot
.60794 .75766 Mdot
.4266 .67551 Mdot
.66725 .53329 Mdot
.35964 .71117 Mdot
.42486 .48981 Mdot
.69293 .55053 Mdot
.67816 .56675 Mdot
.36787 .40831 Mdot
.41354 .7093 Mdot
.39332 .6906 Mdot
.4274 .67747 Mdot
.24286 .36497 Mdot
.58681 .20516 Mdot
.64064 .41595 Mdot
.67566 .56042 Mdot
.59391 .42972 Mdot
.56397 .29622 Mdot
.54709 .55043 Mdot
.62718 .44197 Mdot
.40176 .63416 Mdot
.58615 .41793 Mdot
.39596 .43107 Mdot
.66705 .57476 Mdot
.59623 .38595 Mdot
.36284 .44108 Mdot
.35683 .38039 Mdot
.46841 .356 Mdot
.5511 .26855 Mdot
.56116 .5618 Mdot
.36202 .47279 Mdot
.57179 .73562 Mdot
.39874 .46808 Mdot
.64485 .56927 Mdot
.48862 .37055 Mdot
.35771 .43571 Mdot
.59406 .38268 Mdot
.62014 .23843 Mdot
.65338 .42938 Mdot
.34288 .41973 Mdot
.36418 .46793 Mdot
.39247 .48071 Mdot
.41904 .45631 Mdot
.48918 .79749 Mdot
.63273 .56508 Mdot
.38893 .37617 Mdot
.61419 .36863 Mdot
.4117 .65609 Mdot
.44016 .62972 Mdot
.59647 .47094 Mdot
.55243 .73942 Mdot
.64623 .56676 Mdot
.39147 .48196 Mdot
.76371 .54797 Mdot
.57597 .6561 Mdot
.59977 .78028 Mdot
.58673 .45538 Mdot
.59527 .39086 Mdot
.39632 .68409 Mdot
.62852 .37664 Mdot
.33863 .44926 Mdot
.42282 .50833 Mdot
.6922 .75484 Mdot
.6833 .59107 Mdot
.53077 .30095 Mdot
.35616 .48981 Mdot
.42173 .21859 Mdot
.59728 .41131 Mdot
.66096 .39891 Mdot
.39931 .428 Mdot
.38135 .658 Mdot
.74262 .73725 Mdot
.65314 .57428 Mdot
.21489 .54645 Mdot
.47387 .70087 Mdot
.33968 .37172 Mdot
.66886 .54736 Mdot
.55056 .38539 Mdot
.65529 .41355 Mdot
.18175 .5391 Mdot
.41344 .66437 Mdot
.52845 .29712 Mdot
.43694 .42639 Mdot
.40107 .63488 Mdot
.59126 .43182 Mdot
.40805 .68877 Mdot
.42545 .49426 Mdot
.66373 .58796 Mdot
.63136 .38873 Mdot
.62963 .54677 Mdot
.44507 .69109 Mdot
.52635 .30661 Mdot
.30152 .31787 Mdot
.21173 .54094 Mdot
.34471 .63849 Mdot
.36 .42915 Mdot
.75821 .42186 Mdot
.35403 .42388 Mdot
.38735 .66658 Mdot
.37393 .46951 Mdot
.48391 .47411 Mdot
.65618 .39626 Mdot
.4085 .39435 Mdot
.36505 .50002 Mdot
.19419 .54595 Mdot
.40402 .45846 Mdot
.35177 .41923 Mdot
.39179 .5158 Mdot
.44489 .72364 Mdot
.41449 .39978 Mdot
.42486 .62775 Mdot
.52823 .76615 Mdot
.6266 .42007 Mdot
.55612 .3191 Mdot
.53177 .32234 Mdot
.46862 .20691 Mdot
.40625 .22631 Mdot
.54066 .79547 Mdot
.40336 .65884 Mdot
.68985 .55019 Mdot
.39763 .42939 Mdot
.33553 .71693 Mdot
.36345 .33978 Mdot
.65515 .40833 Mdot
.58808 .40391 Mdot
.44473 .47285 Mdot
.75135 .27514 Mdot
.41522 .39859 Mdot
.55746 .64138 Mdot
.41693 .44782 Mdot
.3627 .5092 Mdot
.6628 .40155 Mdot
.35612 .26951 Mdot
.35988 .42983 Mdot
.39205 .65964 Mdot
.52477 .29061 Mdot
.27516 .42199 Mdot
.33861 .33948 Mdot
.35113 .35683 Mdot
.45423 .60501 Mdot
.34344 .44888 Mdot
.59885 .4051 Mdot
.39788 .64208 Mdot
.54236 .62084 Mdot
.64538 .54904 Mdot
.55574 .61177 Mdot
.2109 .51586 Mdot
.6542 .60808 Mdot
.52641 .29664 Mdot
.60522 .46291 Mdot
.37392 .45047 Mdot
.64484 .41626 Mdot
.42822 .46004 Mdot
.58044 .65475 Mdot
.51435 .29346 Mdot
.42311 .70296 Mdot
.6798 .53867 Mdot
.41388 .62596 Mdot
.32705 .68757 Mdot
.35043 .34325 Mdot
.47076 .84175 Mdot
.63314 .43663 Mdot
.3205 .53767 Mdot
.44131 .65913 Mdot
.36897 .41133 Mdot
.11828 .60499 Mdot
.42716 .67131 Mdot
.41555 .62703 Mdot
.56855 .45368 Mdot
.32295 .30994 Mdot
.40181 .38831 Mdot
.40131 .67793 Mdot
.59645 .36769 Mdot
.54179 .28875 Mdot
.36853 .43671 Mdot
.40951 .50497 Mdot
.45448 .64851 Mdot
.613 .39086 Mdot
.42352 .21398 Mdot
.63221 .40168 Mdot
.42049 .63188 Mdot
.61395 .40823 Mdot
.7654 .62268 Mdot
.60604 .42909 Mdot
.36592 .5011 Mdot
.39072 .48123 Mdot
.75278 .36023 Mdot
.42154 .68082 Mdot
.37546 .43721 Mdot
.37593 .48764 Mdot
.44091 .64909 Mdot
.67142 .41712 Mdot
.3567 .63473 Mdot
.36174 .44541 Mdot
.38699 .48344 Mdot
.51175 .29504 Mdot
.55884 .53341 Mdot
.61303 .68999 Mdot
.37093 .43697 Mdot
.55325 .3121 Mdot
.41231 .70042 Mdot
.39983 .4667 Mdot
.356 .26735 Mdot
.59838 .44405 Mdot
.33762 .46424 Mdot
.55506 .71592 Mdot
.41062 .45205 Mdot
.73538 .74314 Mdot
.39158 .49398 Mdot
.44473 .66188 Mdot
.43714 .65394 Mdot
.61658 .45623 Mdot
.41628 .65463 Mdot
.56103 .74099 Mdot
.65825 .56663 Mdot
.59275 .80329 Mdot
.55787 .73807 Mdot
.36424 .50676 Mdot
.17296 .5565 Mdot
.41111 .50585 Mdot
.41321 .40929 Mdot
.30559 .30783 Mdot
.56371 .73971 Mdot
.43656 .67335 Mdot
.66672 .70268 Mdot
.33957 .49222 Mdot
.65004 .57232 Mdot
.41986 .41697 Mdot
.33735 .46517 Mdot
.48049 .39246 Mdot
.25076 .44356 Mdot
.63654 .52317 Mdot
.30458 .45952 Mdot
.36968 .43589 Mdot
.39287 .764 Mdot
.37171 .45472 Mdot
.54266 .27477 Mdot
.40063 .65756 Mdot
.63487 .37726 Mdot
.52695 .27549 Mdot
.37573 .44755 Mdot
.53134 .29574 Mdot
.63898 .41846 Mdot
.64684 .53078 Mdot
.35275 .49015 Mdot
.50683 .29653 Mdot
.53137 .30373 Mdot
.37825 .41596 Mdot
.43205 .65215 Mdot
.43488 .52213 Mdot
.40166 .46631 Mdot
.34446 .43462 Mdot
.40304 .64177 Mdot
.15345 .44259 Mdot
.41468 .43368 Mdot
.55348 .38413 Mdot
.46295 .66796 Mdot
.5782 .74106 Mdot
.61857 .37732 Mdot
.38368 .5312 Mdot
.65175 .55164 Mdot
.65621 .56153 Mdot
.63156 .36807 Mdot
.45363 .67307 Mdot
.62778 .38744 Mdot
.31052 .45611 Mdot
.44404 .47739 Mdot
.4394 .43169 Mdot
.3649 .19412 Mdot
.77699 .59283 Mdot
.44706 .67084 Mdot
.65607 .41884 Mdot
.55104 .6005 Mdot
.65162 .56983 Mdot
.64807 .37174 Mdot
.46275 .68565 Mdot
.42779 .69344 Mdot
.39841 .64633 Mdot
.54608 .31353 Mdot
.63853 .3978 Mdot
.46052 .62723 Mdot
.39197 .69293 Mdot
.39152 .42039 Mdot
.36936 .435 Mdot
.40784 .61007 Mdot
.47762 .28202 Mdot
.51746 .29547 Mdot
.60249 .4113 Mdot
.85465 .58745 Mdot
.65376 .57495 Mdot
.19373 .54794 Mdot
.36257 .44186 Mdot
.10384 .42662 Mdot
.41829 .40236 Mdot
.3754 .45631 Mdot
.4231 .69836 Mdot
.52975 .32521 Mdot
.54001 .29088 Mdot
.4409 .6578 Mdot
.38437 .68415 Mdot
.552 .30541 Mdot
.56536 .43121 Mdot
.59732 .81641 Mdot
.54569 .61426 Mdot
.44502 .65341 Mdot
.21084 .5636 Mdot
.6405 .53748 Mdot
.45236 .6925 Mdot
.63041 .53471 Mdot
.62812 .42137 Mdot
.59044 .41417 Mdot
.66442 .52512 Mdot
.36944 .40975 Mdot
.62405 .43422 Mdot
.33799 .40772 Mdot
.74067 .70168 Mdot
.80723 .44529 Mdot
.36278 .77588 Mdot
.41406 .48996 Mdot
.50406 .67348 Mdot
.4968 .74968 Mdot
.35127 .4598 Mdot
.3154 .50315 Mdot
.53094 .29929 Mdot
.45629 .68524 Mdot
.63521 .5519 Mdot
.79461 .61649 Mdot
.39125 .47949 Mdot
.42666 .63234 Mdot
.65974 .57396 Mdot
.76057 .62226 Mdot
.52112 .46444 Mdot
.40777 .43195 Mdot
.15155 .67971 Mdot
.44203 .69257 Mdot
.63544 .37764 Mdot
.21514 .62707 Mdot
.43171 .70832 Mdot
.65424 .27552 Mdot
.65431 .43901 Mdot
.58385 .69273 Mdot
.4206 .69487 Mdot
.65944 .44585 Mdot
.42038 .64434 Mdot
.53728 .26479 Mdot
.39748 .70592 Mdot
.61466 .39747 Mdot
.3935 .45779 Mdot
.61828 .39691 Mdot
.51951 .27075 Mdot
.63637 .43074 Mdot
.6354 .55071 Mdot
.5684 .73962 Mdot
.66294 .57183 Mdot
.5464 .54469 Mdot
.32607 .55992 Mdot
.65467 .5345 Mdot
.77043 .52613 Mdot
.40405 .44529 Mdot
.4144 .72186 Mdot
.63668 .37611 Mdot
.58843 .38446 Mdot
.55827 .58092 Mdot
.4219 .63521 Mdot
.60971 .40182 Mdot
.21482 .51702 Mdot
.1975 .32301 Mdot
.3681 .38644 Mdot
.59984 .2093 Mdot
.4418 .64899 Mdot
.65682 .39545 Mdot
.54973 .6334 Mdot
.42441 .61818 Mdot
.59295 .3901 Mdot
.67395 .53382 Mdot
.65728 .54737 Mdot
.38752 .40917 Mdot
.70367 .55483 Mdot
.65757 .42615 Mdot
.4223 .79045 Mdot
.40003 .65286 Mdot
.76093 .59532 Mdot
.54922 .28515 Mdot
.63278 .42048 Mdot
.40273 .38991 Mdot
.4417 .60238 Mdot
.58815 .3942 Mdot
.77958 .35877 Mdot
.86291 .55065 Mdot
.60917 .40288 Mdot
.40075 .65924 Mdot
.40854 .65653 Mdot
.36732 .39198 Mdot
.54804 .58946 Mdot
.60951 .39421 Mdot
.73514 .39493 Mdot
.47805 .21287 Mdot
.55554 .72185 Mdot
.18738 .60472 Mdot
.35885 .43065 Mdot
.3418 .4515 Mdot
.64226 .55461 Mdot
.3966 .45084 Mdot
.38366 .66887 Mdot
.42617 .41167 Mdot
.68324 .58336 Mdot
.65462 .40357 Mdot
.39803 .47799 Mdot
.54409 .3071 Mdot
.63963 .55573 Mdot
.69806 .55947 Mdot
.6179 .4154 Mdot
.39864 .66412 Mdot
.65084 .71497 Mdot
.63354 .40103 Mdot
.34462 .44339 Mdot
.56373 .73167 Mdot
.41508 .51152 Mdot
.75225 .37415 Mdot
.41501 .6214 Mdot
.63042 .37727 Mdot
.45751 .6416 Mdot
.67287 .56448 Mdot
.60951 .36421 Mdot
.36425 .45434 Mdot
.59131 .40001 Mdot
.55026 .37408 Mdot
.6077 .29668 Mdot
.38851 .68863 Mdot
.55296 .2593 Mdot
.45379 .64383 Mdot
.55518 .72153 Mdot
.38661 .30121 Mdot
.51939 .2897 Mdot
.6106 .4295 Mdot
.78136 .61386 Mdot
.63176 .37189 Mdot
.40641 .46077 Mdot
.41345 .47811 Mdot
.60843 .38338 Mdot
.53752 .3146 Mdot
.37776 .22919 Mdot
.53464 .22973 Mdot
.42762 .68849 Mdot
.48942 .54099 Mdot
.83244 .62839 Mdot
.6241 .35444 Mdot
.68829 .54472 Mdot
.30542 .42494 Mdot
.39238 .43693 Mdot
.68658 .53716 Mdot
.66699 .58174 Mdot
.51412 .27316 Mdot
.64261 .41932 Mdot
.46373 .64335 Mdot
.64615 .52606 Mdot
.38807 .57831 Mdot
.3835 .23883 Mdot
.32716 .43018 Mdot
.45137 .42762 Mdot
.38385 .50557 Mdot
.55966 .50818 Mdot
.65931 .58509 Mdot
.36715 .47598 Mdot
.44018 .48931 Mdot
.66817 .53546 Mdot
.52383 .2668 Mdot
.39627 .59779 Mdot
.6096 .41337 Mdot
.15569 .36163 Mdot
.35356 .49135 Mdot
.3975 .46019 Mdot
.6501 .54507 Mdot
.23524 .67405 Mdot
.44845 .65884 Mdot
.40007 .66912 Mdot
.63658 .41449 Mdot
.56662 .5884 Mdot
.34603 .42345 Mdot
.35397 .46475 Mdot
.61602 .4295 Mdot
.57071 .73551 Mdot
.33649 .78065 Mdot
.38018 .48018 Mdot
.67338 .55258 Mdot
.76331 .52059 Mdot
.65376 .58307 Mdot
.42406 .44861 Mdot
.4092 .46371 Mdot
.35255 .49461 Mdot
.42144 .46436 Mdot
.65498 .52184 Mdot
.35364 .46028 Mdot
.40273 .54395 Mdot
.43251 .67617 Mdot
.35057 .44076 Mdot
.45806 .21373 Mdot
.38399 .47786 Mdot
.54336 .30654 Mdot
.62009 .69719 Mdot
.38272 .49578 Mdot
.34824 .44266 Mdot
.54027 .23171 Mdot
.38106 .46046 Mdot
.6793 .57315 Mdot
.41114 .66277 Mdot
.67595 .56302 Mdot
.68694 .55956 Mdot
.58567 .4086 Mdot
.5223 .2622 Mdot
.38085 .52345 Mdot
.55362 .30478 Mdot
.36037 .3985 Mdot
.42645 .48827 Mdot
.55382 .54231 Mdot
.55842 .64211 Mdot
.51301 .25233 Mdot
.35998 .45844 Mdot
.63127 .41541 Mdot
.6215 .37552 Mdot
.48136 .34931 Mdot
.34155 .407 Mdot
.63842 .54 Mdot
.66185 .52844 Mdot
.46287 .28889 Mdot
.50235 .42608 Mdot
.53765 .30818 Mdot
.51793 .58167 Mdot
.40457 .50461 Mdot
.37883 .49131 Mdot
.42162 .4229 Mdot
.61353 .44154 Mdot
.57084 .73983 Mdot
.65369 .40526 Mdot
.54801 .70987 Mdot
.63958 .57218 Mdot
.41343 .49065 Mdot
.80827 .47896 Mdot
.45331 .66462 Mdot
.4114 .66464 Mdot
.68746 .5803 Mdot
.65421 .42883 Mdot
.34928 .40354 Mdot
.39308 .16998 Mdot
.39683 .62641 Mdot
.55101 .32108 Mdot
.3566 .47004 Mdot
.62157 .41658 Mdot
.44268 .68545 Mdot
.51914 .25867 Mdot
.40971 .49561 Mdot
.65721 .37951 Mdot
.37866 .47257 Mdot
.26267 .6438 Mdot
.43497 .66837 Mdot
.54887 .67672 Mdot
.38351 .63996 Mdot
.68655 .53922 Mdot
.68235 .54751 Mdot
.40976 .46991 Mdot
.28543 .23197 Mdot
.39554 .60922 Mdot
.67548 .52554 Mdot
.54294 .26523 Mdot
.57509 .73679 Mdot
.5329 .26035 Mdot
.63283 .3837 Mdot
.52433 .29256 Mdot
.59223 .38773 Mdot
.47671 .30792 Mdot
.43118 .60876 Mdot
.52532 .27356 Mdot
.24019 .68449 Mdot
.41782 .51178 Mdot
.51106 .27863 Mdot
.44548 .46875 Mdot
.43941 .54595 Mdot
.61854 .42863 Mdot
.54154 .31261 Mdot
.38555 .41366 Mdot
.79476 .55731 Mdot
.6858 .55324 Mdot
.63714 .54283 Mdot
.39028 .52265 Mdot
.65439 .38492 Mdot
.39049 .69475 Mdot
.55067 .45009 Mdot
.5803 .73833 Mdot
.35459 .46463 Mdot
.4092 .49891 Mdot
.45838 .6696 Mdot
.38987 .65611 Mdot
.41115 .46705 Mdot
.22036 .50872 Mdot
.37236 .45013 Mdot
.66032 .54556 Mdot
.436 .68737 Mdot
.4091 .66185 Mdot
.64409 .44153 Mdot
.45374 .67219 Mdot
.43948 .41208 Mdot
.62945 .51192 Mdot
.4395 .45239 Mdot
.66965 .56354 Mdot
.49447 .36926 Mdot
.64489 .41974 Mdot
.79015 .60746 Mdot
.44801 .68201 Mdot
.34525 .45766 Mdot
.44267 .63277 Mdot
.54441 .28084 Mdot
.4201 .68062 Mdot
.42277 .61222 Mdot
.40931 .48881 Mdot
.41259 .43539 Mdot
.56825 .73388 Mdot
.55248 .59017 Mdot
.4316 .66299 Mdot
.36121 .44911 Mdot
.38641 .51985 Mdot
.40916 .42378 Mdot
.54969 .49585 Mdot
.41658 .69795 Mdot
.22835 .44725 Mdot
.77955 .40143 Mdot
.43079 .65485 Mdot
.80272 .64028 Mdot
.57179 .71369 Mdot
.55185 .73945 Mdot
.67381 .52274 Mdot
.3835 .48343 Mdot
.62576 .38926 Mdot
.33828 .45891 Mdot
.33256 .41279 Mdot
.38242 .49745 Mdot
.51414 .2813 Mdot
.32903 .48576 Mdot
.5666 .71602 Mdot
.62852 .39948 Mdot
.36809 .44609 Mdot
.39685 .48274 Mdot
.54882 .73424 Mdot
.3861 .63095 Mdot
.42661 .69294 Mdot
.61129 .74409 Mdot
.52869 .26733 Mdot
.64366 .54824 Mdot
.339 .45389 Mdot
.63355 .41469 Mdot
.62369 .3937 Mdot
.41485 .62624 Mdot
.60724 .41596 Mdot
.64147 .56636 Mdot
.37769 .45315 Mdot
.68348 .5349 Mdot
.51447 .28049 Mdot
.40061 .65671 Mdot
.33908 .45043 Mdot
.3915 .41901 Mdot
.43726 .65434 Mdot
.40681 .44667 Mdot
.51265 .29693 Mdot
.60434 .43308 Mdot
.43453 .6849 Mdot
.65804 .56558 Mdot
.63692 .4439 Mdot
.39276 .42922 Mdot
.85535 .44686 Mdot
.39649 .44991 Mdot
.34903 .47833 Mdot
.62612 .79877 Mdot
.42757 .50123 Mdot
.64863 .38697 Mdot
.44313 .63149 Mdot
.42033 .43662 Mdot
.49681 .21477 Mdot
.68464 .38359 Mdot
.65954 .37932 Mdot
.35465 .47103 Mdot
.78462 .64773 Mdot
.34662 .45458 Mdot
.75653 .64206 Mdot
.5534 .54464 Mdot
.70526 .25656 Mdot
.45628 .44582 Mdot
.6808 .52946 Mdot
.56853 .73634 Mdot
.6407 .3761 Mdot
.29983 .68709 Mdot
.40256 .44863 Mdot
.34699 .70093 Mdot
.33573 .46089 Mdot
.66642 .54692 Mdot
.30608 .48924 Mdot
.60354 .41238 Mdot
.18407 .56383 Mdot
.34989 .43052 Mdot
.42198 .69709 Mdot
.58857 .37863 Mdot
.57791 .73001 Mdot
.38604 .41286 Mdot
.55318 .29194 Mdot
.67648 .43535 Mdot
.45056 .44167 Mdot
.66779 .56496 Mdot
.37355 .48877 Mdot
.30991 .4275 Mdot
.22394 .30002 Mdot
.43246 .67905 Mdot
.685 .54139 Mdot
.47306 .60738 Mdot
.41783 .46382 Mdot
.42496 .69319 Mdot
.41275 .66115 Mdot
.54948 .27722 Mdot
.58153 .63943 Mdot
.66463 .35198 Mdot
.81577 .42634 Mdot
.33766 .65714 Mdot
.62637 .44594 Mdot
.43373 .77288 Mdot
.36544 .43129 Mdot
.33982 .34561 Mdot
.68365 .56567 Mdot
.39445 .45937 Mdot
.3344 .60308 Mdot
.42609 .67961 Mdot
.37508 .47581 Mdot
.51673 .29297 Mdot
.5327 .72911 Mdot
.32639 .36987 Mdot
.84837 .50835 Mdot
.6176 .36082 Mdot
.42643 .42243 Mdot
.45102 .47697 Mdot
.57695 .74188 Mdot
.42471 .45411 Mdot
.64033 .37776 Mdot
.76493 .431 Mdot
.53198 .31357 Mdot
.45201 .67053 Mdot
.57473 .71606 Mdot
.33477 .47286 Mdot
.41368 .50826 Mdot
.55713 .31734 Mdot
.36247 .41526 Mdot
.20255 .59998 Mdot
.55983 .75384 Mdot
.6061 .42994 Mdot
.40499 .68565 Mdot
.38647 .50579 Mdot
.572 .7377 Mdot
.41102 .48579 Mdot
.44951 .54331 Mdot
.35438 .47718 Mdot
.55205 .80987 Mdot
.43166 .64807 Mdot
.66752 .56837 Mdot
.33727 .50349 Mdot
.38951 .47281 Mdot
.66636 .29454 Mdot
.32952 .41578 Mdot
.39195 .49318 Mdot
.39553 .63988 Mdot
.45311 .65256 Mdot
.41663 .62935 Mdot
.61225 .43386 Mdot
.54248 .60834 Mdot
.66331 .55215 Mdot
.39802 .40023 Mdot
.64207 .53257 Mdot
.46724 .48319 Mdot
.55764 .31221 Mdot
.81285 .57833 Mdot
.38643 .44579 Mdot
.40735 .63704 Mdot
.44231 .79277 Mdot
.41224 .70064 Mdot
.70891 .5533 Mdot
.67668 .57023 Mdot
.4278 .66845 Mdot
.37433 .46191 Mdot
.53962 .59496 Mdot
.84663 .46339 Mdot
.65166 .56867 Mdot
.43194 .45039 Mdot
.60761 .36128 Mdot
.59598 .37685 Mdot
.78061 .69304 Mdot
.68907 .56074 Mdot
.49363 .74978 Mdot
.35503 .44892 Mdot
.45476 .66047 Mdot
.64982 .53705 Mdot
.68029 .57408 Mdot
.61226 .42609 Mdot
.4045 .42886 Mdot
.38652 .4731 Mdot
.55693 .71413 Mdot
.64742 .5287 Mdot
.33503 .51373 Mdot
.4103 .43931 Mdot
.67494 .77137 Mdot
.46648 .67443 Mdot
.14545 .45939 Mdot
.30924 .45442 Mdot
.3393 .6014 Mdot
.51822 .43467 Mdot
.44513 .67702 Mdot
.35014 .42339 Mdot
.39183 .39854 Mdot
.63291 .44633 Mdot
.38367 .45143 Mdot
.64905 .42635 Mdot
.69058 .54873 Mdot
.81837 .57907 Mdot
.75437 .55462 Mdot
.61138 .52848 Mdot
.40023 .45377 Mdot
.35228 .36386 Mdot
.53525 .27634 Mdot
.66935 .59389 Mdot
.43641 .63411 Mdot
.39076 .50798 Mdot
.64832 .44584 Mdot
.60637 .42656 Mdot
.41744 .66725 Mdot
.50202 .76594 Mdot
.77336 .62094 Mdot
.42193 .46861 Mdot
.62556 .37906 Mdot
.75214 .57145 Mdot
.23586 .50424 Mdot
.69195 .5386 Mdot
.52825 .31122 Mdot
.65173 .39726 Mdot
.69424 .57928 Mdot
.45867 .52672 Mdot
.42179 .66082 Mdot
.45354 .68061 Mdot
.69684 .33093 Mdot
.61246 .39481 Mdot
.53134 .27981 Mdot
.50784 .44968 Mdot
.50075 .476 Mdot
.51485 .2932 Mdot
.65545 .4068 Mdot
.45147 .66653 Mdot
.42427 .63198 Mdot
.41083 .66034 Mdot
.19225 .57836 Mdot
.4148 .61901 Mdot
.2025 .41907 Mdot
.41869 .4937 Mdot
.21694 .55954 Mdot
.34762 .46049 Mdot
.64385 .52266 Mdot
.43548 .66636 Mdot
.54715 .55734 Mdot
.37828 .51307 Mdot
.84622 .49459 Mdot
.36074 .47239 Mdot
.64745 .48775 Mdot
.38534 .48401 Mdot
.22557 .62821 Mdot
.4628 .67024 Mdot
.35925 .4572 Mdot
.64526 .51129 Mdot
.5355 .30196 Mdot
.3874 .62114 Mdot
.38684 .49303 Mdot
.57052 .77866 Mdot
.442 .48094 Mdot
.76431 .66522 Mdot
.60751 .24053 Mdot
.54336 .3271 Mdot
.44142 .44203 Mdot
.58265 .41408 Mdot
.42686 .5855 Mdot
.21908 .58303 Mdot
.65192 .56835 Mdot
.25309 .42503 Mdot
.61507 .43161 Mdot
.31466 .50107 Mdot
.32797 .44584 Mdot
.53974 .31693 Mdot
.39765 .60404 Mdot
.66141 .54389 Mdot
.40136 .44565 Mdot
.35391 .41791 Mdot
.75889 .33303 Mdot
.21733 .59015 Mdot
.3385 .51507 Mdot
.56248 .29124 Mdot
.23402 .45132 Mdot
.37687 .49554 Mdot
.66086 .38218 Mdot
.43727 .62504 Mdot
.42107 .39573 Mdot
.22429 .44999 Mdot
.36579 .44855 Mdot
.42494 .66971 Mdot
.44985 .68023 Mdot
.49484 .81907 Mdot
.55545 .31355 Mdot
.35463 .47751 Mdot
.67923 .29486 Mdot
.34307 .44497 Mdot
.66231 .54901 Mdot
.42486 .4479 Mdot
.62807 .42575 Mdot
.55041 .63991 Mdot
.61488 .43578 Mdot
.39863 .41593 Mdot
.41369 .64159 Mdot
.65703 .54223 Mdot
.71609 .34596 Mdot
.58244 .47651 Mdot
.20568 .41352 Mdot
.67878 .42913 Mdot
.54811 .30804 Mdot
.52211 .25998 Mdot
.63716 .50475 Mdot
.36183 .46496 Mdot
.56008 .48347 Mdot
.3945 .39379 Mdot
.38647 .4877 Mdot
.35949 .49438 Mdot
.64303 .5918 Mdot
.67363 .57082 Mdot
.61385 .40393 Mdot
.41125 .46525 Mdot
.36016 .44972 Mdot
.42699 .65341 Mdot
.53174 .30443 Mdot
.59986 .42699 Mdot
.53214 .26917 Mdot
.62858 .40495 Mdot
.75105 .72614 Mdot
.42517 .4426 Mdot
.53664 .3017 Mdot
.6562 .58518 Mdot
.407 .63443 Mdot
.54966 .73081 Mdot
.63321 .38455 Mdot
.60333 .40912 Mdot
.35254 .46055 Mdot
.40467 .67473 Mdot
.41525 .68818 Mdot
.55095 .30679 Mdot
.6569 .52937 Mdot
.38592 .40761 Mdot
.41248 .43842 Mdot
.69045 .26753 Mdot
.62674 .44396 Mdot
.21995 .49102 Mdot
.50608 .80527 Mdot
.36158 .4638 Mdot
.4178 .69124 Mdot
.39826 .47383 Mdot
.79258 .4997 Mdot
.39994 .63751 Mdot
.37913 .51742 Mdot
.4801 .39785 Mdot
.60979 .43942 Mdot
.49176 .83334 Mdot
.35412 .5134 Mdot
.70962 .52929 Mdot
.37125 .4207 Mdot
.55642 .85905 Mdot
.40916 .76842 Mdot
.33445 .46497 Mdot
.42074 .47027 Mdot
.81563 .40102 Mdot
.35097 .44877 Mdot
.56467 .7137 Mdot
.31316 .44335 Mdot
.42631 .69384 Mdot
.52711 .43871 Mdot
.56286 .54775 Mdot
.55913 .29622 Mdot
.63699 .41513 Mdot
.35301 .29373 Mdot
.53095 .26449 Mdot
.44398 .65722 Mdot
.40117 .51197 Mdot
.37304 .58868 Mdot
.6021 .45056 Mdot
.34481 .41356 Mdot
.66353 .54816 Mdot
.5627 .55158 Mdot
.6521 .41025 Mdot
.65987 .56803 Mdot
.34109 .4797 Mdot
.49302 .18652 Mdot
.59769 .48695 Mdot
.54135 .83107 Mdot
.64833 .54458 Mdot
.6815 .56167 Mdot
.53525 .62262 Mdot
.55901 .29583 Mdot
.74148 .31013 Mdot
.29138 .405 Mdot
.65268 .57322 Mdot
.429 .28228 Mdot
.66269 .41955 Mdot
.57517 .64284 Mdot
.45634 .68642 Mdot
.42312 .43616 Mdot
.37762 .46443 Mdot
.66294 .53234 Mdot
.37187 .71664 Mdot
.45841 .56102 Mdot
.65946 .57152 Mdot
.44126 .50177 Mdot
.57938 .64914 Mdot
.56381 .73557 Mdot
.56399 .71076 Mdot
.55147 .27362 Mdot
.60358 .31947 Mdot
.42582 .64044 Mdot
.5297 .31772 Mdot
.58205 .70553 Mdot
.35738 .48104 Mdot
.64666 .52833 Mdot
.54883 .72101 Mdot
.65738 .55982 Mdot
.54147 .29615 Mdot
.55293 .31887 Mdot
.43252 .67677 Mdot
.44858 .65655 Mdot
.26281 .47018 Mdot
.45794 .26213 Mdot
.34933 .44565 Mdot
.35417 .64361 Mdot
.40491 .63303 Mdot
.27616 .69802 Mdot
.55542 .30516 Mdot
.52677 .30367 Mdot
.25034 .58558 Mdot
.39434 .4254 Mdot
.75501 .53397 Mdot
.38265 .49496 Mdot
.39589 .30642 Mdot
.34064 .49167 Mdot
.61067 .42309 Mdot
.35295 .43211 Mdot
.6454 .69581 Mdot
.37587 .4413 Mdot
.3733 .49977 Mdot
.63797 .39228 Mdot
.33548 .50314 Mdot
.62633 .4282 Mdot
.41609 .43735 Mdot
.54633 .33183 Mdot
.63371 .41441 Mdot
.51761 .22345 Mdot
.54868 .393 Mdot
.57331 .72957 Mdot
.54213 .26564 Mdot
.55271 .29525 Mdot
.45294 .21006 Mdot
.44242 .63896 Mdot
.46663 .51435 Mdot
.36261 .46635 Mdot
.65953 .3952 Mdot
.64058 .54899 Mdot
.36502 .4494 Mdot
.42087 .40573 Mdot
.35999 .51738 Mdot
.42894 .67457 Mdot
.65643 .40451 Mdot
.5344 .29468 Mdot
.61417 .37615 Mdot
.57682 .3245 Mdot
.6093 .37115 Mdot
.32929 .39232 Mdot
.31177 .47388 Mdot
.43397 .53495 Mdot
.34903 .62583 Mdot
.17979 .5322 Mdot
.41854 .66133 Mdot
.56296 .72437 Mdot
.55959 .30846 Mdot
.48749 .53964 Mdot
.41012 .63734 Mdot
.60314 .40385 Mdot
.3786 .47243 Mdot
.43911 .50743 Mdot
.31946 .38019 Mdot
.45752 .62045 Mdot
.48174 .23315 Mdot
.64464 .40412 Mdot
.55584 .7306 Mdot
.54985 .62139 Mdot
.45795 .71391 Mdot
.54533 .5504 Mdot
.39407 .47385 Mdot
.55414 .2978 Mdot
.44277 .68535 Mdot
.74602 .3488 Mdot
.67001 .53303 Mdot
.55018 .59035 Mdot
.39819 .45271 Mdot
.45587 .76989 Mdot
.41365 .64197 Mdot
.52307 .30289 Mdot
.66336 .53274 Mdot
.5562 .30935 Mdot
.57729 .71718 Mdot
.61973 .71977 Mdot
.37278 .41268 Mdot
.39306 .49368 Mdot
.63793 .56753 Mdot
.42368 .63977 Mdot
.63173 .46073 Mdot
.76688 .35844 Mdot
.62226 .37944 Mdot
.56721 .5 Mdot
.44028 .68598 Mdot
.42349 .75137 Mdot
.59312 .39493 Mdot
.67145 .58994 Mdot
.55837 .49062 Mdot
.68492 .58117 Mdot
.3728 .49746 Mdot
.40479 .66341 Mdot
.68934 .56069 Mdot
.70659 .31984 Mdot
.737 .72543 Mdot
.40463 .59275 Mdot
.41286 .45559 Mdot
.81605 .57568 Mdot
.66098 .76171 Mdot
.36487 .66839 Mdot
.65035 .52331 Mdot
.40615 .46999 Mdot
.42178 .47327 Mdot
.34982 .43156 Mdot
.6847 .54533 Mdot
.61395 .47995 Mdot
.5997 .41155 Mdot
.36594 .47813 Mdot
.54887 .28524 Mdot
.6215 .42365 Mdot
.58272 .4049 Mdot
.63835 .37451 Mdot
.39874 .63806 Mdot
.41322 .50149 Mdot
.53232 .68676 Mdot
.58918 .84428 Mdot
.67475 .56759 Mdot
.57339 .72914 Mdot
.35285 .4927 Mdot
.23596 .35991 Mdot
.41479 .63042 Mdot
.62 .38024 Mdot
.39599 .46043 Mdot
.627 .26163 Mdot
.58241 .76196 Mdot
.63762 .40116 Mdot
.43694 .63539 Mdot
.3653 .6621 Mdot
.38266 .45122 Mdot
.37372 .42127 Mdot
.43476 .64244 Mdot
.60092 .77449 Mdot
.5578 .636 Mdot
.39733 .47634 Mdot
.66546 .56926 Mdot
.21409 .2997 Mdot
.40678 .51446 Mdot
.45759 .61826 Mdot
.57385 .73927 Mdot
.54901 .80288 Mdot
.22434 .48621 Mdot
.36213 .38506 Mdot
.81873 .53675 Mdot
.33442 .29017 Mdot
.81395 .59458 Mdot
.34163 .31942 Mdot
.74558 .58549 Mdot
.68434 .79501 Mdot
.65661 .51321 Mdot
.23376 .63622 Mdot
.75937 .30135 Mdot
.51249 .74593 Mdot
.58352 .2424 Mdot
.72207 .40993 Mdot
.62884 .2534 Mdot
.2581 .7208 Mdot
.60302 .37456 Mdot
.38191 .32437 Mdot
.3665 .40956 Mdot
.65574 .75791 Mdot
.20375 .54405 Mdot
.17458 .50971 Mdot
.80665 .5838 Mdot
.6662 .28328 Mdot
.84246 .41691 Mdot
.7866 .60326 Mdot
.28084 .49009 Mdot
.41484 .35779 Mdot
.61277 .332 Mdot
.50473 .45968 Mdot
.34216 .29879 Mdot
.45051 .41604 Mdot
.64362 .68024 Mdot
.61611 .52808 Mdot
.28796 .52686 Mdot
.20197 .33079 Mdot
.64509 .38646 Mdot
.43523 .62332 Mdot
.73449 .29663 Mdot
.4432 .59972 Mdot
.6635 .5049 Mdot
.81916 .53619 Mdot
.67371 .77566 Mdot
.22277 .62303 Mdot
.56682 .68822 Mdot
.26982 .63581 Mdot
.37246 .22719 Mdot
.39585 .34948 Mdot
.40889 .70363 Mdot
.71899 .48302 Mdot
.50052 .47488 Mdot
.5882 .33785 Mdot
.23801 .65698 Mdot
.51532 .25979 Mdot
.51218 .2212 Mdot
.43185 .63352 Mdot
.24113 .49997 Mdot
.55495 .74409 Mdot
.55761 .69451 Mdot
.66133 .43732 Mdot
.79211 .48306 Mdot
.56693 .76666 Mdot
.55181 .76757 Mdot
.40315 .79389 Mdot
.86164 .48555 Mdot
.39831 .25168 Mdot
.75779 .4103 Mdot
.69877 .52197 Mdot
.34864 .27746 Mdot
.52733 .66646 Mdot
.44164 .25027 Mdot
.49105 .45985 Mdot
.79679 .30887 Mdot
.61363 .78482 Mdot
.83568 .38157 Mdot
.40264 .71257 Mdot
.40122 .52603 Mdot
.77629 .42773 Mdot
.33195 .66988 Mdot
.52242 .32363 Mdot
.8571 .49691 Mdot
.5402 .32242 Mdot
.46095 .63735 Mdot
.50856 .74795 Mdot
.19961 .5823 Mdot
.63716 .4658 Mdot
.49321 .27459 Mdot
.43014 .40597 Mdot
.7712 .25804 Mdot
.82461 .52025 Mdot
.50988 .81574 Mdot
.66646 .77676 Mdot
.63188 .35602 Mdot
.5863 .4348 Mdot
.69227 .55277 Mdot
.70483 .76488 Mdot
.4071 .64945 Mdot
.59577 .84559 Mdot
.70108 .76236 Mdot
.47863 .64021 Mdot
.75764 .23801 Mdot
.32894 .7692 Mdot
.21612 .54715 Mdot
.26542 .38032 Mdot
.5628 .19953 Mdot
.52647 .63748 Mdot
.4301 .75154 Mdot
.60556 .35701 Mdot
.58925 .80177 Mdot
.76127 .70737 Mdot
.43281 .29188 Mdot
.64167 .60481 Mdot
.51261 .70541 Mdot
.48904 .36262 Mdot
.42779 .60244 Mdot
.56039 .22687 Mdot
.47805 .35554 Mdot
.84154 .40017 Mdot
.24356 .4353 Mdot
.32456 .20648 Mdot
.35574 .31172 Mdot
.22949 .66594 Mdot
.7742 .57916 Mdot
.50026 .32237 Mdot
.45339 .54676 Mdot
.53569 .77373 Mdot
.43733 .46225 Mdot
.51872 .59045 Mdot
.36773 .5467 Mdot
.57218 .30972 Mdot
.53962 .61546 Mdot
.72638 .6826 Mdot
.37475 .30146 Mdot
.8053 .42462 Mdot
.42785 .36659 Mdot
.39914 .67974 Mdot
.4345 .24096 Mdot
.40551 .27227 Mdot
.69429 .75116 Mdot
.47469 .60992 Mdot
.55622 .82274 Mdot
.4661 .59519 Mdot
.4004 .39438 Mdot
.24089 .645 Mdot
.46087 .43996 Mdot
.42795 .26841 Mdot
.34589 .50485 Mdot
.41466 .79712 Mdot
.63235 .79492 Mdot
.33136 .57405 Mdot
.36996 .28404 Mdot
.35151 .60791 Mdot
.59495 .80291 Mdot
.78066 .42804 Mdot
.44753 .75567 Mdot
.39907 .74873 Mdot
.77965 .27346 Mdot
.61404 .41566 Mdot
.43831 .28049 Mdot
.6413 .58538 Mdot
.71072 .33793 Mdot
.74295 .27889 Mdot
.4573 .57791 Mdot
.62528 .80424 Mdot
.52911 .75333 Mdot
.60748 .45899 Mdot
.61285 .64135 Mdot
.67864 .6068 Mdot
.35642 .58669 Mdot
.38299 .52477 Mdot
.40771 .56523 Mdot
.51427 .30201 Mdot
.31547 .66824 Mdot
.77175 .3995 Mdot
.68667 .45294 Mdot
.36112 .38235 Mdot
.69267 .4716 Mdot
.55363 .72502 Mdot
.56009 .59755 Mdot
.77244 .70751 Mdot
.31901 .42034 Mdot
.30788 .75123 Mdot
.61209 .77705 Mdot
.56123 .50964 Mdot
.58691 .31026 Mdot
.47873 .79427 Mdot
.82327 .34889 Mdot
.65968 .79929 Mdot
.69072 .72601 Mdot
.81797 .56894 Mdot
.40148 .84295 Mdot
.70467 .24078 Mdot
.33315 .72132 Mdot
.63678 .58026 Mdot
.29751 .82516 Mdot
.60036 .38562 Mdot
.25227 .39849 Mdot
.33118 .66506 Mdot
.62879 .27031 Mdot
.43 .59083 Mdot
.42093 .37315 Mdot
.66866 .37484 Mdot
.39929 .61475 Mdot
.4233 .40237 Mdot
.85631 .54313 Mdot
.80108 .31071 Mdot
.86028 .52635 Mdot
.6219 .72239 Mdot
.82222 .59207 Mdot
.80246 .35166 Mdot
.19895 .42558 Mdot
.75298 .31747 Mdot
.42459 .44802 Mdot
.45532 .30235 Mdot
.33905 .77002 Mdot
.65497 .45059 Mdot
.54443 .68965 Mdot
.4486 .70542 Mdot
.78833 .30914 Mdot
.77926 .70196 Mdot
.26766 .5903 Mdot
.25783 .49832 Mdot
.53871 .38567 Mdot
.44676 .26152 Mdot
.36062 .56041 Mdot
.6496 .67058 Mdot
.73708 .7087 Mdot
.79574 .34023 Mdot
.39847 .28283 Mdot
.71855 .43019 Mdot
.69606 .71165 Mdot
.33764 .75386 Mdot
.79036 .56561 Mdot
.73037 .28907 Mdot
.46479 .61084 Mdot
.42285 .73268 Mdot
.45689 .56435 Mdot
.63508 .66712 Mdot
.77272 .47786 Mdot
.37985 .25864 Mdot
.63685 .4315 Mdot
.44018 .2928 Mdot
.52851 .51425 Mdot
.7513 .31232 Mdot
.36717 .2567 Mdot
.42852 .29705 Mdot
.71195 .70803 Mdot
.8466 .55701 Mdot
.5925 .77643 Mdot
.52535 .18658 Mdot
.72222 .61697 Mdot
.35198 .5407 Mdot
.37413 .53166 Mdot
.61305 .80312 Mdot
.84254 .59443 Mdot
.63266 .80421 Mdot
.44982 .77135 Mdot
.69551 .31898 Mdot
.70299 .55867 Mdot
.35829 .25609 Mdot
.67878 .4782 Mdot
.74474 .70446 Mdot
.49827 .54895 Mdot
.70487 .55046 Mdot
.52499 .72481 Mdot
.26696 .46903 Mdot
.29818 .31815 Mdot
.27284 .53028 Mdot
.3418 .40988 Mdot
.22719 .52414 Mdot
.45872 .65028 Mdot
.44555 .76834 Mdot
.44131 .25651 Mdot
.61766 .4163 Mdot
.66784 .24164 Mdot
.38834 .57348 Mdot
.42282 .50969 Mdot
.76519 .44151 Mdot
.42327 .60081 Mdot
.34652 .62296 Mdot
.57952 .42197 Mdot
.70826 .77212 Mdot
.38215 .77565 Mdot
.35753 .56435 Mdot
.41492 .24182 Mdot
.69108 .27402 Mdot
.56345 .62989 Mdot
.63001 .56226 Mdot
.80044 .58814 Mdot
.5469 .41169 Mdot
.42721 .24485 Mdot
.22543 .51586 Mdot
.7661 .37034 Mdot
.40272 .39932 Mdot
.48005 .80883 Mdot
.21705 .39771 Mdot
.56305 .59542 Mdot
.47237 .66449 Mdot
.40208 .6228 Mdot
.19182 .65624 Mdot
.65748 .69684 Mdot
.49077 .68389 Mdot
.79835 .57003 Mdot
.69261 .56589 Mdot
.39103 .66575 Mdot
.43234 .30415 Mdot
.61396 .30093 Mdot
.24689 .46177 Mdot
.77813 .48303 Mdot
.29196 .49829 Mdot
.70598 .52042 Mdot
.81414 .56536 Mdot
.83582 .4708 Mdot
.23654 .28184 Mdot
.38419 .64315 Mdot
.74521 .37254 Mdot
.7433 .36418 Mdot
.4097 .70259 Mdot
.45805 .62034 Mdot
.34327 .36484 Mdot
.81229 .61868 Mdot
.50234 .52677 Mdot
.6357 .65639 Mdot
.55954 .49134 Mdot
.58736 .2522 Mdot
.75438 .34724 Mdot
.35689 .2781 Mdot
.79482 .55076 Mdot
.25881 .52099 Mdot
.59543 .19319 Mdot
.42505 .54195 Mdot
.24362 .40766 Mdot
.3582 .25591 Mdot
.44081 .35698 Mdot
.2446 .66452 Mdot
.74508 .6642 Mdot
.34471 .44519 Mdot
.86547 .50003 Mdot
.69419 .74484 Mdot
.51436 .5934 Mdot
.59422 .34546 Mdot
.3799 .43268 Mdot
.41608 .49899 Mdot
.37918 .73383 Mdot
.52795 .80576 Mdot
.6465 .19879 Mdot
.37201 .31168 Mdot
.34501 .53817 Mdot
.22175 .51688 Mdot
.3084 .7512 Mdot
.78227 .44803 Mdot
.77442 .63871 Mdot
.52158 .53298 Mdot
.34679 .772 Mdot
.621 .62332 Mdot
.61721 .65529 Mdot
.73567 .60832 Mdot
.80708 .36023 Mdot
.31179 .39975 Mdot
.52901 .79191 Mdot
.73576 .31053 Mdot
.35291 .49169 Mdot
.50197 .76653 Mdot
.78493 .58098 Mdot
.34398 .21122 Mdot
.52083 .66578 Mdot
.85666 .57163 Mdot
.42134 .55048 Mdot
.54079 .78686 Mdot
.74854 .27726 Mdot
.44883 .15099 Mdot
.63547 .67986 Mdot
.84445 .41458 Mdot
.6019 .63072 Mdot
.79966 .56315 Mdot
.68353 .53166 Mdot
.52266 .47353 Mdot
.35051 .68009 Mdot
.80926 .62423 Mdot
.64807 .32427 Mdot
.8001 .50207 Mdot
.37332 .73562 Mdot
.82668 .60372 Mdot
.48658 .46321 Mdot
.18932 .64539 Mdot
.67103 .40358 Mdot
.36729 .80022 Mdot
.34728 .73832 Mdot
.35876 .55206 Mdot
.42202 .2859 Mdot
.18259 .61372 Mdot
.18763 .46453 Mdot
.3401 .71848 Mdot
.43952 .327 Mdot
.49083 .79872 Mdot
.40932 .23917 Mdot
.74302 .71074 Mdot
.2401 .70379 Mdot
.75102 .3588 Mdot
.49374 .72421 Mdot
.61012 .75671 Mdot
.52682 .80974 Mdot
.71703 .65836 Mdot
.77095 .43659 Mdot
.59816 .67695 Mdot
.28489 .48604 Mdot
.11542 .43986 Mdot
.58908 .57764 Mdot
.32995 .37314 Mdot
.81919 .3507 Mdot
.73118 .71452 Mdot
.49137 .54625 Mdot
.23084 .65014 Mdot
.2658 .33653 Mdot
.47939 .31143 Mdot
.38311 .49708 Mdot
.8285 .59853 Mdot
.488 .29519 Mdot
.84964 .45943 Mdot
.5585 .83484 Mdot
.23906 .52959 Mdot
.31882 .40855 Mdot
.60038 .36082 Mdot
.35715 .35103 Mdot
.43294 .33164 Mdot
.8217 .37069 Mdot
.24789 .4045 Mdot
.56884 .46928 Mdot
.73215 .54444 Mdot
.7655 .53912 Mdot
.30584 .49688 Mdot
.34414 .77734 Mdot
.51073 .80061 Mdot
.35727 .30098 Mdot
.68445 .71868 Mdot
.43521 .27296 Mdot
.22264 .49008 Mdot
.37056 .24758 Mdot
.49714 .59833 Mdot
.6417 .35006 Mdot
.64426 .44336 Mdot
.8102 .40032 Mdot
.77464 .60731 Mdot
.42112 .7973 Mdot
.53614 .19054 Mdot
.53122 .77377 Mdot
.39065 .33003 Mdot
.78982 .40651 Mdot
.52165 .63941 Mdot
.65157 .33635 Mdot
.2879 .33109 Mdot
.24731 .43205 Mdot
.75852 .65108 Mdot
.44181 .38307 Mdot
.76333 .70768 Mdot
.37579 .2627 Mdot
.7845 .36447 Mdot
.535 .39238 Mdot
.32241 .6385 Mdot
.2349 .6005 Mdot
.58036 .20459 Mdot
.56297 .58718 Mdot
.77317 .26228 Mdot
.42184 .70499 Mdot
.86098 .48203 Mdot
.6436 .55053 Mdot
.25299 .28304 Mdot
.75125 .67872 Mdot
.53085 .54706 Mdot
.54611 .47796 Mdot
.48087 .81184 Mdot
.57155 .77205 Mdot
.60528 .77853 Mdot
.45484 .57167 Mdot
.63709 .3716 Mdot
.57848 .46894 Mdot
.6426 .65865 Mdot
.81439 .44076 Mdot
.41224 .42295 Mdot
.62541 .46595 Mdot
.42694 .35317 Mdot
.71558 .58434 Mdot
.61666 .79681 Mdot
.75322 .63666 Mdot
.45371 .42904 Mdot
.44906 .25888 Mdot
.80113 .33945 Mdot
.70619 .75118 Mdot
.46583 .55239 Mdot
.37212 .54739 Mdot
.64333 .49281 Mdot
.69338 .24873 Mdot
.82129 .50795 Mdot
.75524 .54744 Mdot
.56765 .6481 Mdot
.39776 .25463 Mdot
.88117 .54094 Mdot
.79871 .30934 Mdot
.55861 .18423 Mdot
.56089 .48775 Mdot
.41167 .72181 Mdot
.23689 .36325 Mdot
.78624 .36896 Mdot
.37873 .80801 Mdot
.6934 .73502 Mdot
.43473 .27885 Mdot
.38246 .19322 Mdot
.18694 .51354 Mdot
.56563 .44644 Mdot
.23627 .60233 Mdot
.34159 .64899 Mdot
.70843 .56509 Mdot
.48105 .32452 Mdot
.5496 .43953 Mdot
.65405 .50089 Mdot
.4947 .79938 Mdot
.5494 .76255 Mdot
.78319 .3604 Mdot
.22853 .4288 Mdot
.37757 .54985 Mdot
.81003 .46035 Mdot
.44513 .61314 Mdot
.74396 .35115 Mdot
.69878 .27924 Mdot
.55883 .44731 Mdot
.60843 .37659 Mdot
.4287 .39325 Mdot
.56977 .6107 Mdot
.60355 .62253 Mdot
.45518 .18423 Mdot
.52018 .31741 Mdot
.40972 .71119 Mdot
.17993 .54975 Mdot
.38213 .65727 Mdot
.83834 .62033 Mdot
.65206 .67011 Mdot
.22259 .52855 Mdot
.61964 .61192 Mdot
.72257 .45362 Mdot
.45714 .16984 Mdot
.27628 .48399 Mdot
.53365 .22783 Mdot
.4312 .72313 Mdot
.45805 .6518 Mdot
.64304 .61652 Mdot
.5685 .75239 Mdot
.24961 .49917 Mdot
.283 .73593 Mdot
.6883 .26976 Mdot
.38303 .67609 Mdot
.58455 .45981 Mdot
.38755 .60002 Mdot
.76418 .7156 Mdot
.62078 .3745 Mdot
.78734 .28387 Mdot
.31014 .47028 Mdot
.67973 .23225 Mdot
.61779 .80055 Mdot
.54742 .6425 Mdot
.56399 .48554 Mdot
.71627 .38348 Mdot
.41699 .40977 Mdot
.35633 .54633 Mdot
.44502 .64539 Mdot
.75936 .32819 Mdot
.52506 .29671 Mdot
.47131 .23821 Mdot
.62472 .54141 Mdot
.27327 .70929 Mdot
.36037 .78001 Mdot
.45686 .64381 Mdot
.56081 .37175 Mdot
.73865 .37475 Mdot
.4766 .38721 Mdot
.43224 .35413 Mdot
.81262 .3961 Mdot
.26303 .4896 Mdot
.41792 .70315 Mdot
.5572 .18616 Mdot
.47821 .35375 Mdot
.66956 .80063 Mdot
.47152 .48044 Mdot
.38518 .35055 Mdot
.44301 .36943 Mdot
.47397 .80147 Mdot
.22552 .48213 Mdot
.76699 .6627 Mdot
.4377 .2434 Mdot
.50203 .44113 Mdot
.43147 .29779 Mdot
.44844 .41669 Mdot
.73982 .565 Mdot
.35049 .79069 Mdot
.39223 .19 Mdot
.26553 .64256 Mdot
.52887 .67727 Mdot
.46913 .63909 Mdot
.31458 .75522 Mdot
.4136 .70816 Mdot
.57866 .29692 Mdot
.29517 .53338 Mdot
.74981 .68135 Mdot
.71583 .75592 Mdot
.69339 .7515 Mdot
.3437 .3523 Mdot
.76168 .54682 Mdot
.27688 .35652 Mdot
.43095 .5516 Mdot
.53864 .54505 Mdot
.42112 .41004 Mdot
.31235 .50331 Mdot
.4861 .56539 Mdot
.43967 .79398 Mdot
.30025 .4343 Mdot
.80439 .62411 Mdot
.66812 .79932 Mdot
.83505 .56444 Mdot
.77098 .47321 Mdot
.41473 .61464 Mdot
.81609 .33668 Mdot
.20584 .47943 Mdot
.7326 .72268 Mdot
.34287 .73546 Mdot
.21075 .68422 Mdot
.75565 .28944 Mdot
.73315 .67905 Mdot
.47808 .71704 Mdot
.4988 .83568 Mdot
.62139 .78513 Mdot
.19189 .64877 Mdot
.26847 .4073 Mdot
.61096 .79883 Mdot
.76463 .2542 Mdot
.31559 .71601 Mdot
.56343 .77264 Mdot
.22907 .5977 Mdot
.26189 .41858 Mdot
.24956 .70754 Mdot
.42811 .48692 Mdot
.5887 .39094 Mdot
.60324 .24421 Mdot
.4241 .27959 Mdot
.43041 .38965 Mdot
.2337 .6902 Mdot
.43114 .33369 Mdot
.37886 .32672 Mdot
.71087 .34672 Mdot
.75896 .29903 Mdot
.23274 .48249 Mdot
.44997 .48109 Mdot
.45853 .69743 Mdot
.52706 .26194 Mdot
.32077 .32183 Mdot
.39261 .43483 Mdot
.55867 .5563 Mdot
.31101 .39277 Mdot
.85711 .55063 Mdot
.6043 .27614 Mdot
.61356 .51866 Mdot
.39604 .62338 Mdot
.51361 .80764 Mdot
.79693 .4609 Mdot
.51105 .74601 Mdot
.21553 .66414 Mdot
.257 .46681 Mdot
.817 .55514 Mdot
.53677 .76394 Mdot
.38344 .2772 Mdot
.40784 .20621 Mdot
.64378 .51881 Mdot
.34454 .68076 Mdot
.81924 .37254 Mdot
.51317 .77215 Mdot
.45653 .62458 Mdot
.70297 .69294 Mdot
.74081 .55687 Mdot
.50608 .7832 Mdot
.61146 .77632 Mdot
.76191 .38233 Mdot
.23833 .56126 Mdot
.83237 .47508 Mdot
.59675 .36704 Mdot
.4026 .2865 Mdot
.67615 .69622 Mdot
.25025 .71063 Mdot
.47627 .38847 Mdot
.77892 .67823 Mdot
.53711 .5365 Mdot
.5049 .23163 Mdot
.37668 .415 Mdot
.22539 .44601 Mdot
.45291 .79355 Mdot
.68595 .71091 Mdot
.48432 .64161 Mdot
.44213 .61802 Mdot
.3977 .78836 Mdot
.58877 .34467 Mdot
.48632 .30691 Mdot
.27941 .37394 Mdot
.41382 .75263 Mdot
.56816 .27714 Mdot
.54032 .71968 Mdot
.31542 .48651 Mdot
.51689 .21508 Mdot
.77337 .51283 Mdot
.34852 .69873 Mdot
.32966 .72007 Mdot
.81265 .40474 Mdot
.77917 .47103 Mdot
.41278 .80165 Mdot
.35617 .73254 Mdot
.55957 .80693 Mdot
.19353 .4985 Mdot
.5047 .70452 Mdot
.36733 .5189 Mdot
.5786 .29707 Mdot
.40538 .69678 Mdot
.81782 .44342 Mdot
.41856 .57125 Mdot
.512 .2282 Mdot
.51906 .56757 Mdot
.77386 .42646 Mdot
.52409 .39006 Mdot
.62016 .79533 Mdot
.49876 .83587 Mdot
.44127 .25523 Mdot
.6295 .52173 Mdot
.60878 .63445 Mdot
.51773 .65929 Mdot
.78751 .64917 Mdot
.47595 .57251 Mdot
.37169 .58917 Mdot
.52412 .70446 Mdot
.33754 .5978 Mdot
.58271 .82202 Mdot
.46167 .26121 Mdot
.54079 .5522 Mdot
.36617 .56791 Mdot
.55488 .69049 Mdot
.55002 .73288 Mdot
.6249 .27559 Mdot
.21214 .4634 Mdot
.61888 .5906 Mdot
.58343 .48512 Mdot
.33052 .50947 Mdot
.23398 .36719 Mdot
.82625 .47691 Mdot
.48628 .54202 Mdot
.53218 .53539 Mdot
.7337 .3123 Mdot
.4836 .27987 Mdot
.18419 .33083 Mdot
.86778 .51612 Mdot
.37804 .41553 Mdot
.54071 .46382 Mdot
.46911 .24593 Mdot
.64999 .42422 Mdot
.27153 .52384 Mdot
.81659 .41619 Mdot
.6764 .57398 Mdot
.70282 .32474 Mdot
.55027 .75055 Mdot
.47017 .8086 Mdot
.60392 .20691 Mdot
.70508 .55954 Mdot
.8441 .61267 Mdot
.68737 .73767 Mdot
.45447 .78601 Mdot
.14721 .37582 Mdot
.43036 .78502 Mdot
.48083 .48525 Mdot
.70502 .35166 Mdot
.84709 .56409 Mdot
.56312 .49446 Mdot
.69797 .33151 Mdot
.32136 .71231 Mdot
.43963 .25074 Mdot
.38797 .30715 Mdot
.49286 .72716 Mdot
.41191 .78082 Mdot
.17707 .62798 Mdot
.72331 .45111 Mdot
.48387 .17101 Mdot
.24478 .51145 Mdot
.84084 .48179 Mdot
.63559 .67823 Mdot
.37114 .19963 Mdot
.70663 .76244 Mdot
.45131 .31117 Mdot
.24269 .69332 Mdot
.61549 .31679 Mdot
.47723 .2146 Mdot
.22541 .3708 Mdot
.61349 .69586 Mdot
.26757 .49102 Mdot
.70892 .4549 Mdot
.49351 .65518 Mdot
.43604 .29493 Mdot
.33947 .62114 Mdot
.5416 .54904 Mdot
.83253 .41072 Mdot
.19266 .61941 Mdot
.41337 .24748 Mdot
.72347 .32545 Mdot
.48697 .21693 Mdot
.81544 .47925 Mdot
.78399 .52898 Mdot
.47902 .38111 Mdot
.70099 .2169 Mdot
.84139 .40074 Mdot
.50909 .70273 Mdot
.41844 .49577 Mdot
.67744 .79906 Mdot
.50171 .39041 Mdot
.33248 .71714 Mdot
.63501 .76204 Mdot
.36617 .31414 Mdot
.30054 .41038 Mdot
.39942 .51911 Mdot
.26533 .37268 Mdot
.47749 .71316 Mdot
.3412 .62668 Mdot
.6407 .22937 Mdot
.418 .24401 Mdot
.19778 .62451 Mdot
.6058 .20008 Mdot
.47426 .47156 Mdot
.43137 .69434 Mdot
.85133 .55826 Mdot
.32275 .53973 Mdot
.40034 .5607 Mdot
.2222 .56352 Mdot
.46801 .56665 Mdot
.68209 .36568 Mdot
.37067 .54615 Mdot
.56331 .62702 Mdot
.41975 .28532 Mdot
.79141 .38393 Mdot
.35297 .6847 Mdot
.76032 .23767 Mdot
.61817 .80509 Mdot
.38308 .68098 Mdot
.32278 .69781 Mdot
.55621 .43807 Mdot
.83657 .55447 Mdot
.71378 .43178 Mdot
.69357 .27572 Mdot
.17157 .54784 Mdot
.45018 .22071 Mdot
.32986 .46448 Mdot
.62228 .72571 Mdot
.73563 .73479 Mdot
.16973 .57402 Mdot
.76377 .7064 Mdot
.31237 .41446 Mdot
.38699 .53376 Mdot
.38807 .1569 Mdot
.80567 .56384 Mdot
.35045 .39219 Mdot
.48517 .69178 Mdot
.48234 .66354 Mdot
.39316 .41166 Mdot
.57657 .75609 Mdot
.32896 .30307 Mdot
.38887 .31251 Mdot
.81085 .61849 Mdot
.3923 .63612 Mdot
.56407 .51248 Mdot
.67313 .59578 Mdot
.55418 .50624 Mdot
.45849 .46648 Mdot
.68695 .57255 Mdot
.3923 .31801 Mdot
.51432 .41169 Mdot
.67073 .45359 Mdot
.27305 .45853 Mdot
.57676 .66686 Mdot
.28249 .47325 Mdot
.37841 .34297 Mdot
.40918 .73945 Mdot
.18722 .46329 Mdot
.43014 .33255 Mdot
.46365 .34455 Mdot
.61133 .79266 Mdot
.36951 .82332 Mdot
.56655 .54741 Mdot
.37842 .70865 Mdot
.47668 .48313 Mdot
.21406 .47645 Mdot
.22984 .56126 Mdot
.67014 .4421 Mdot
.55718 .73768 Mdot
.30151 .43748 Mdot
.35939 .56552 Mdot
.69592 .5699 Mdot
.87161 .55383 Mdot
.41052 .5167 Mdot
.26268 .54475 Mdot
.77405 .667 Mdot
.74721 .34899 Mdot
.28698 .39212 Mdot
.42398 .41277 Mdot
.49384 .47959 Mdot
.51225 .40475 Mdot
.37585 .60662 Mdot
.75521 .34099 Mdot
.82881 .51951 Mdot
.30515 .36094 Mdot
.25134 .53906 Mdot
.35984 .4706 Mdot
.55513 .32723 Mdot
.55683 .60874 Mdot
.4546 .19227 Mdot
.50749 .24472 Mdot
.70652 .7471 Mdot
.39413 .33829 Mdot
.37118 .31156 Mdot
.21317 .58318 Mdot
.85424 .47338 Mdot
.51863 .67583 Mdot
.23561 .53145 Mdot
.50109 .584 Mdot
.71936 .66245 Mdot
.43716 .326 Mdot
.66266 .61105 Mdot
.29808 .46922 Mdot
.4784 .70526 Mdot
.8093 .65183 Mdot
.27995 .4901 Mdot
.62054 .5565 Mdot
.76025 .65073 Mdot
.19596 .5018 Mdot
.54528 .47811 Mdot
.12535 .41103 Mdot
.71625 .41309 Mdot
.8459 .6049 Mdot
.77749 .37983 Mdot
.46174 .3847 Mdot
.48881 .7962 Mdot
.3992 .38499 Mdot
.631 .39165 Mdot
.83393 .54161 Mdot
.40348 .57812 Mdot
.50189 .70965 Mdot
.42756 .45685 Mdot
.49807 .50195 Mdot
.38224 .588 Mdot
.76268 .57182 Mdot
.59485 .37825 Mdot
.46494 .55694 Mdot
.78634 .53934 Mdot
.51163 .40217 Mdot
.23779 .71784 Mdot
.82287 .37173 Mdot
.79965 .5915 Mdot
.76783 .52721 Mdot
.25898 .27034 Mdot
.44193 .71706 Mdot
.40382 .58174 Mdot
.63931 .51278 Mdot
.27191 .36273 Mdot
.50796 .77825 Mdot
.78444 .37271 Mdot
.54168 .81693 Mdot
.47495 .3842 Mdot
.10139 .47754 Mdot
.44264 .30836 Mdot
.48557 .52778 Mdot
.48955 .77372 Mdot
.79991 .63353 Mdot
.68647 .28982 Mdot
.54055 .83119 Mdot
.64802 .68389 Mdot
.44859 .4195 Mdot
.21986 .40205 Mdot
.56658 .19184 Mdot
.74593 .54273 Mdot
.47516 .16895 Mdot
.77182 .58315 Mdot
.34338 .29822 Mdot
.6815 .71016 Mdot
.38238 .64894 Mdot
.42474 .58306 Mdot
.65411 .66486 Mdot
.54172 .6895 Mdot
.37557 .72364 Mdot
.82195 .5284 Mdot
.3411 .25176 Mdot
.71836 .29255 Mdot
.8211 .57181 Mdot
.72337 .57139 Mdot
.47282 .64543 Mdot
.42378 .33417 Mdot
.51747 .24955 Mdot
.63784 .43725 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`0008oooooo0_l00003ooooo`;o0000]?ooool001cooooo00?o0000ooooooooool0N_ooool2
o`0001;ooooo0_l00003ooooo`;o0000]?ooool001cooooo00?o0000ooooooooool0N_ooool2o`00
0<gooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
Z?ooool2o`0009oooooo000Looooo`03o`000?oooooooooo09Oooooo0_l0000?ooooo`;o00008ooo
ool2o`0007[ooooo000Looooo`03o`000?oooooooooo07cooooo0_l0000?ooooo`;o00000_ooool2
o`0000Cooooo1Ol0000aooooo`;o0000N_ooool001cooooo00?o0000ooooooooool0O?ooool2o`00
00oooooo0_l00002ooooo`;o00001_ooool3o`000:gooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0UOooool2o`0000Oooooo0_l0002Yooooo`007?oo
ool00ol0003oooooooooo`25ooooo`;o00002Oooool2o`0000?ooooo0_l00007ooooo`;o00004_oo
ool2o`0009Gooooo000Looooo`03o`000?oooooooooo08?ooooo1?l00004ooooo`?o00000_ooool2
o`0000Kooooo0_l00002ooooo`;o00002Oooool2o`0000Sooooo0ol0002Eooooo`007?ooool00ol0
003oooooooooo`1looooo`;o00001Oooool2o`0000Kooooo0ol0000:ooooo`;o00000_ooool2o`00
00Wooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l0002Fooooo`0000Koooooonk^
k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0L_oo
ool2o`0000Cooooo1_l0000Booooo`;o00006?ooool2o`000003ooooool0003o000000Gooooo0_l0
0008ooooo`;o0000ROooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo
00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo07;ooooo0ol00003ooooo`Co
00005?ooool2o`0002;ooooo0_l00008ooooo`;o0000ROooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo07;ooooo
1Ol0000looooo`;o00006Oooool2o`0007Wooooo00000ooooooo0000ooooo`02ooooo`03o`000?oo
oooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0007Gooooo0_l0000Cooooo`;o00009ooo
ool2o`0000cooooo0_l0000;ooooo`;o0000NOooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo087ooooo0_l00007
ooooo`;o0000;Oooool4o`0000Cooooo0_l0000@ooooo`;o0000M?ooool00003ooooool@413ooooo
00;ooooo00?o410@ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
05kooooo0_l00006ooooo`;o00006?ooool3o`0000Gooooo0_l00004ooooo`;o00001?ooool4o`00
027ooooo1?l00003ooooo`;o00004Oooool2o`0007Cooooo00001_ooooooMgMgoiRHV?ooooooV9RH
ogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo05kooooo0_l0
0006ooooo`;o00001?ooool2o`0001;ooooo0_l00006ooooo`;o00001?ooool3o`000003ooooool0
003o000000Co00001Oooool2o`00023ooooo1Ol00025ooooo`0000Koooooonk^k_lb<S;o0000oc8b
<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1/ooooo`;o
00006?ooool2o`0000?ooooo0_l000000ooooooo0000o`000004o`0000?ooooo0ol00003ooooo`?o
00001?ooool2o`0000kooooo0_l00009ooooo`;o000000?oooooo`000?l000000_ooool2o`00087o
oooo000Looooo`03o`000?oooooooooo08Kooooo0_l00003ooooo`So00001?ooool5o`000005oooo
ool0003o0000o`000?ooool00_l000000ooooooo0000o`00000>ooooo`;o00003oooool3o`0001So
oooo0_l0001Wooooo`007?ooool00ol0003oooooooooo`25ooooo`;o00001?ooool8o`0000Oooooo
0_l000001Ooooooo0000o`000?l0003ooooo00Co00008?ooool2o`0000gooooo0_l0000:ooooo`;o
0000Ioooool001cooooo00?o0000ooooooooool0QOooool2o`000003ooooool0003o000000;o0000
0_ooool2o`0000kooooo0_l00002ooooo`Co0000;_ooool2o`0007?ooooo000Looooo`03o`000?oo
oooooooo07Gooooo0_l00005ooooo`Ko00000oooool2o`000003ooooool0003o000000;o00000_oo
ool2o`0001Cooooo0_l0000<ooooo`;o0000UOooool001cooooo00?o0000ooooooooool0MOooool4
o`0000?ooooo1_l00004ooooo`;o00000oooool2o`000003ooooool0003o000001?ooooo0_l00005
ooooo`;o00001_ooool2o`0001Kooooo1?l0001kooooo`007?ooool00ol0003oooooooooo`1Ioooo
o`;o00006_ooool4o`0000Cooooo1?l00005ooooo`;o00000oooool2o`0000cooooo0ol00002oooo
o`Co000000?oooooo`000?l000001Oooool4o`0001cooooo1?l0000;ooooo`;o00001oooool2o`00
00;ooooo0_l0001Qooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00001?ooool2o`0001[o
oooo0_l00006ooooo`;o00006_ooool3o`000003ooooool0003o000000?o00000oooool2o`0000Go
oooo0_l0000[ooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo0_l0001Qooooo`00
7?ooool00ol0003oooooooooo`1Cooooo`;o00008?ooool2o`0000;ooooo0_l00006ooooo`;o0000
4_ooool2o`0000Kooooo0_l00006ooooo`;o00001Oooool2o`000003ooooool0003o000000Wooooo
0_l00006ooooo`;o00000_ooool2o`0001Cooooo0_l00002ooooo`;o00004?ooool3o`0005Cooooo
000Looooo`03o`000?oooooooooo05gooooo0_l0000@ooooo`;o00002?ooool2o`0000Kooooo1?l0
0004ooooo`;o00001oooool2o`000003ooooool0003o000000?ooooo0_l0000Cooooo`;o00002Ooo
ool2o`0000Kooooo0ol000000ooooooo0000o`00000=ooooo`;o00002Oooool3o`0000oooooo0ol0
001Dooooo`007?ooool00ol0003oooooooooo`1Gooooo`;o00001?ooool2o`0000kooooo1?l0000B
ooooo`?o000000?oooooo`000?l000000ol00006ooooo`;o000000?oooooo`000?l000000oooool2
o`0000Gooooo0_l00007ooooo`;o00003_ooool2o`0000Cooooo1Ol0000@ooooo`;o00002_ooool2
o`0000Gooooo0_l00008ooooo`;o0000EOooool001cooooo00?o0000ooooooooool0Eoooool2o`00
01Cooooo0_l00006ooooo`?o00002oooool3o`000004ooooool0003o0000ooooo`;o00000oooool2
o`0000Cooooo0_l0000:ooooo`;o00001oooool4o`0001;ooooo0_l00002ooooo`;o00005oooool2
o`0000Wooooo0_l00008ooooo`;o0000EOooool001cooooo0_l0001/ooooo`;o00002?ooool4o`00
00Gooooo0_l00003ooooo`;o00001?ooool5o`000003ooooool0003o000000;ooooo0_l00006oooo
o`;o00000_ooool2o`0000;ooooo0ol00006ooooo`;o00003Oooool2o`0000Oooooo0_l0000Coooo
o`;o00000_ooool2o`000003ooooool0003o000000[ooooo0_l0001Kooooo`007?ooool00ol0003o
ooooooooo`1[ooooo`?o00002Oooool2o`0000Cooooo0ol00009ooooo`Go00001Oooool2o`0000Ko
oooo0_l00002ooooo`;o00000_ooool3o`0000Gooooo0_l0000>ooooo`;o00002oooool2o`0000oo
oooo0_l00005ooooo`;o00002_ooool2o`0000Oooooo0_l0001Booooo`007?ooool00ol0003ooooo
ooooo`1/ooooo`;o00000oooool5o`000003ooooool0003o000000Cooooo0_l0000;ooooo`Co0000
0_ooool4o`0000gooooo0ol00002ooooo`;o000000?oooooo`000?l000000_l0000Kooooo`;o0000
5oooool2o`0001;ooooo1?l0001@ooooo`007?ooool00ol0003oooooooooo`1`ooooo`Ko00000_oo
ool2o`0000oooooo3?l0000<ooooo`ko000000?oooooo`000?l000005_ooool2o`00017ooooo0_l0
0004ooooo`;o00005?ooool2o`00053ooooo000Looooo`03o`000?oooooooooo06oooooo0ol00004
ooooo`Co00003oooool3o`000005ooooool0003o0000o`000?ooool01?l00003ooooo`?o00002Ooo
ool;o`000004ooooool0003o0000o`0000kooooo0_l00005ooooo`;o00004Oooool2o`0001[ooooo
0_l0001@ooooo`007?ooool00ol0003oooooooooo`1_ooooo`?o000000?oooooo`000?l000000ol0
000Eooooo`;o000000Coooooo`000?l0003o00001?ooool4o`0000Sooooo0_l000000ooooooo0000
o`000007o`0000;ooooo0_l0000>ooooo`;o00006?ooool3o`0000kooooo0_l00009ooooo`;o0000
D?ooool001cooooo00?o0000ooooooooool0D?ooool2o`0001kooooo0_l000001?oooooo0000o`00
0?l0000Aooooo`Co00001Oooool2o`0000Gooooo1?l000001?oooooo0000o`000?ooool2o`000003
ooooool0003o000000go000000?oooooo`000?l000005?ooool2o`00017ooooo0ol00004ooooo`;o
00001oooool3o`0005_ooooo000Looooo`03o`000?oooooooooo04_ooooo1?l000000ooooooo0000
o`00000Nooooo`;o00001?ooool2o`0000Sooooo0_l00005ooooo`Go00002_ooool2o`000003oooo
ool0003o000000?o000000Coooooo`000?l0003ooooo2ol00002ooooo`Go00001oooool2o`0000_o
oooo0_l000000ooooooo0000o`00000?ooooo`;o00001?ooool2o`0000Oooooo0_l0000<ooooo`;o
0000C_ooool001cooooo00?o0000ooooooooool0Boooool4o`0000?ooooo0_l0000Looooo`;o0000
1?ooool2o`0000Sooooo0_l00008ooooo`;o00002_ooool2o`0000?ooooo1?l00004ooooo`Wo0000
00?oooooo`000?l000001?l00008ooooo`;o00001?ooool2o`0000Cooooo0_l00002ooooo`;o0000
1?ooool2o`0000[ooooo0_l0000Aooooo`;o00001oooool2o`0004kooooo000Looooo`03o`000?oo
oooooooo04Cooooo0_l00006ooooo`;o00001?ooool2o`0001;ooooo0_l00006ooooo`Co00001ooo
ool2o`0000Wooooo1?l000000ooooooo0000o`00000>ooooo`;o000000?oooooo`000?l000000_l0
0002oooooa7o000000Coooooo`000?l0003o00002_ooool2o`0000Cooooo0_l00008ooooo`;o0000
2_ooool4o`0000gooooo1?l0001Gooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00000ooo
ool2o`0000?ooooo0_l0000Fooooo`;o000000?oooooo`000?l000000oooool4o`0000Oooooo0_l0
0003ooooo`;o00001?ooool9o`0000Kooooo0_l00002ooooo`Co00000oooool3o`000003ooooool0
003o000001?o0000:?ooool2o`000003ooooool0003o000000[ooooo0ol0001Hooooo`007?ooool0
0ol0003oooooooooo`19ooooo`;o00000oooool2o`0001Kooooo0_l000000ooooooo0000o`000005
ooooo`;o00000_ooool2o`0000Sooooo0_l00005ooooo`Go000000?oooooo`000?l000000_ooool2
o`0000;ooooo1_l00005oooooaSo00006oooool2o`0000;ooooo0_l00004ooooo`;o00001Oooool2
o`0001Sooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`1Vooooo`;o00002?ooool2o`00
00;ooooo0_l00009ooooo`;o00001?ooool2o`0000Sooooo0_l00002ooooo`Oo00001?oooolGo`00
00?ooooo0_l0000Gooooo`;o00000_ooool2o`0000Cooooo0_l00002ooooo`;o000000?oooooo`00
0?l000000_ooool2o`000003ooooool0003o0000017ooooo0_l0001;ooooo`007?ooool00ol0003o
ooooooooo`1Wooooo`Co00001?ooool3o`0000gooooo0_l00005ooooo`;o000000?oooooo`000?l0
00002?ooool2o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000004ol00003ooooo`;o
00006_ooool2o`0000Gooooo0_l00002ooooo`;o00001Oooool2o`000003ooooool0003o000000;o
oooo0_l00003ooooo`;o0000EOooool001cooooo00?o0000ooooooooool0Ioooool4o`0000Cooooo
0_l0000Eooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00002Oooool5o`000003oooo
ool0003o000001?o00000oooool4o`0001Sooooo0ol00002ooooo`Co00000oooool3o`0000?ooooo
0_l000000ooooooo0000o`000002ooooo`Co000000?oooooo`000?l00000EOooool001cooooo00?o
0000ooooooooool0K?ooool2o`000003ooooool0003o000001Kooooo1_l00002ooooo`;o00002Ooo
ool3o`0000Cooooo5?l00003ooooo`Co00001_ooool2o`00017ooooo0_l00002ooooo`;o00001Ooo
ool3o`0000?ooooo0_l00003ooooo`;o00000_ooool3o`0005Oooooo000Looooo`;o0000@oooool2
o`000003ooooool0003o000001cooooo0_l00006ooooo`Co000000?oooooo`000?l000001?ooool2
o`0000;ooooo0_l0000;ooooo`?o00003?ooool2o`0000Wooooo5Ol00002ooooo`;o00002?ooool4
o`0002Gooooo0_l00003ooooo`;o000000?oooooo`000?l00000E?ooool001cooooo00?o0000oooo
ooooool0@_ooool5o`0001cooooo0_l00002ooooo`;o00000_ooool4o`000003ooooool0003o0000
00Cooooo0_l00002ooooo`;o00003Oooool2o`0000Gooooo0_l00004ooooo`;o00002oooool@o`00
0003ooooool0003o000000;ooooo1?l00008ooooo`;o00009Oooool2o`0000Kooooo0_l0001Doooo
o`007?ooool00ol0003oooooooooo`13ooooo`;o00006oooool2o`0000Cooooo0ol00002ooooo`;o
00002Oooool2o`0000;ooooo1Ol00008ooooo`Co00001Oooool3o`0000Oooooo0_l00007oooooa3o
000000?oooooo`000?l000000_ooool4o`0002Gooooo0ol00007ooooo`;o0000G?ooool001cooooo
00?o0000ooooooooool0?_ooool2o`00023ooooo0_l00003ooooo`Co00001Oooool2o`0000Kooooo
0_l00002ooooo`Go00002?ooool2o`0000?ooooo0_l00003ooooo`;o00001?ooool2o`000003oooo
ool0003o000000Oooooo4Ol00002ooooo`;o00000oooool3o`0002?ooooo0ol00007ooooo`Co0000
0_ooool2o`0000Wooooo0_l000001?oooooo0000o`000?l00017ooooo`007?ooool00ol0003ooooo
ooooo`0nooooo`;o00008?ooool2o`0000;ooooo1_l00004ooooo`Co00000oooool2o`0000Cooooo
0_l0000<ooooo`;o000000Coooooo`000?l0003ooooo0_l00006ooooo`?o00001Oooool2o`0000Co
oooo3ol00002ooooo`Co000000Coooooo`000?l0003o00001oooool2o`0001[ooooo0ol00007oooo
o`Co000000Coooooo`000?l0003o00002Oooool2o`000004ooooool0003o0000o`0004Oooooo000L
ooooo`03o`000?oooooooooo05gooooo1Ol00002ooooo`;o00000_ooool2o`0000Kooooo0_l00000
0ooooooo0000o`000002o`0000Cooooo0_l0000<ooooo`;o00001?ooool2o`0000Oooooo0_l00005
ooooo`;o00000oooool@o`0000Cooooo0_l000000ooooooo0000o`000007ooooo`?o00006_ooool4
o`0000Kooooo0_l00003ooooo`;o0000Eoooool001cooooo00?o0000ooooooooool0F_ooool2o`00
0004ooooool0003o0000o`0000_ooooo0_l00006ooooo`;o00001oooool2o`0002Kooooo4?l00003
ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`Co00005_ooool2o`000003ooooool0003o
000000;o00003?ooool2o`00013ooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0loooo
o`;o00006_ooool8o`0000?ooooo0ol00005ooooo`;o00003oooool2o`00027ooooo0_l00004oooo
o`;o000000?oooooo`000?l000002Ol00004ooooo`;o00000_ooool2o`0000?ooooo0_l00004oooo
o`;o00005_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000:ooooo`Co00003_ooool2o`00
04Cooooo000Looooo`03o`000?oooooooooo03cooooo0_l0000Jooooo`Ko00001Oooool3o`0001;o
oooo0_l0000@ooooo`;o00003Oooool2o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l0
00002Ol00003ooooo`;o00000_ooool2o`0001Gooooo0_l0000?ooooo`;o00000oooool4o`0000[o
oooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`1Fooooo`Go00007?ooool3o`0000kooooo
1Ol0000<ooooo`;o00002?ooool2o`000003ooooool0003o000000Oo00000_ooool2o`000005oooo
ool0003o0000o`000?ooool00_l0000;ooooo`;o00002?ooool2o`0000oooooo0_l00005ooooo`;o
00002Oooool4o`0005?ooooo000Looooo`03o`000?oooooooooo03Sooooo0_l00004ooooo`;o0000
5?ooool8o`0000;ooooo0_l0000Gooooo`;o00000_ooool2o`0000_ooooo1Ol0000Fooooo`;o0000
1Oooool2o`000003ooooool0003o000000Wo00002oooool4o`0001Sooooo0_l0000Aooooo`Co0000
Doooool001cooooo00?o0000ooooooooool0>?ooool4o`0000;ooooo0_l0000Dooooo`;o00001?oo
ool2o`0000;ooooo0_l0000Kooooo`;o00002Oooool5o`0000Sooooo0_l0000Eooooo`;o00000_oo
ool3o`0000;ooooo0_l000000ooooooo0000o`00000;ooooo`;o00006_ooool2o`0000gooooo0_l0
0003ooooo`;o00000oooool2o`0004oooooo000Looooo`03o`000?oooooooooo03[ooooo0_l0000E
ooooo`Co00001Oooool2o`00023ooooo0_l00008ooooo`Co00002Oooool2o`000003ooooool0003o
0000017ooooo0_l0000@ooooo`;o00004oooool2o`00017ooooo0_l00009ooooo`;o00000oooool2
o`0000?ooooo0_l0000;ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0DOooool4o`00
00Gooooo0_l0000:ooooo`;o00000_ooool2o`0000Kooooo0_l00008ooooo`;o00006?ooool4o`00
00oooooo0_l0000@ooooo`;o00001oooool2o`0000[ooooo0_l0000Aooooo`;o00003Oooool2o`00
00_ooooo0ol00003ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0>_ooool2o`0001?o
oooo1?l0000Cooooo`;o00000_ooool2o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0001So
oooo1?l000000ooooooo0000o`000002o`00027ooooo0_l00007ooooo`;o0000;?ooool2o`0000Co
oooo0_l00005ooooo`?o0000Aoooool001cooooo00?o0000ooooooooool0>_ooool2o`0001?ooooo
0_l0000@ooooo`;o00002?ooool2o`000003ooooool0003o000000Oooooo0_l0000Hooooo`Co0000
9_ooool4o`0002Cooooo1?l0000:ooooo`;o00001Oooool2o`0004oooooo000Looooo`;o0000?Ooo
ool2o`0002;ooooo0ol00008ooooo`;o00003?ooool2o`0000;ooooo0_l0000>ooooo`;o00001?oo
ool3o`0000?ooooo0_l0000Rooooo`;o00002Oooool2o`0000?ooooo0_l0000Dooooo`Co00002?oo
ool4o`0001?ooooo1?l0000oooooo`007?ooool00ol0003oooooooooo`0looooo`;o00008_ooool2
o`0000[ooooo0_l00002ooooo`;o00001oooool2o`0000;ooooo0_l00007ooooo`?o00001?ooool2
o`0000Gooooo0_l00002ooooo`?o00008Oooool2o`0000[ooooo0_l00003ooooo`;o00000oooool4
o`0000_ooooo0_l0000;ooooo`?o000000?oooooo`000?l000001Oooool2o`0000Kooooo0_l00003
ooooo`Co0000?oooool001cooooo00?o0000ooooooooool0E_ooool2o`0001Cooooo2Ol00002oooo
o`Co00002oooool9o`0000Gooooo0_l00002ooooo`?o00008Oooool2o`0000?ooooo0ol00003oooo
o`Co00001oooool4o`0000_ooooo0_l00004ooooo`;o00001Oooool2o`0000;ooooo0_l00005oooo
o`;o00001_ooool2o`0000Gooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0mooooo`;o
00002_ooool2o`0000_ooooo0_l0000Fooooo`;o00000_ooool3o`0000;ooooo1Ol00007ooooo`Co
00000_ooool6o`0000Gooooo0_l00002ooooo`;o00009oooool3o`0000?ooooo1?l0000Looooo`;o
00001oooool3o`0000;ooooo0_l00002ooooo`;o00001oooool2o`0004Gooooo000Looooo`03o`00
0?oooooooooo02oooooo0_l0000<ooooo`;o00002_ooool2o`0000[ooooo0_l00008ooooo`;o0000
4Oooool2o`0000Kooooo0_l00007ooooo`Co00003oooool2o`0000?ooooo0_l0000Rooooo`;o0000
00Coooooo`000?l0003ooooo0ol00004ooooo`;o00000oooool2o`0001_ooooo1Ol00002ooooo`;o
00000_ooool4o`0000Gooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o0000
5_ooool6o`0000Sooooo0_l00008ooooo`;o00002oooool2o`000004ooooool0003o0000ooooo`;o
00006Oooool2o`0000Oooooo0_l00003ooooo`;o00007_ooool2o`0000;ooooo1Ol000001Ooooooo
0000o`000?l0003ooooo00;o000000?oooooo`000?l000000oooool2o`0000Oooooo0_l00005oooo
o`;o00002oooool2o`0000_ooooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`17ooooo`?o
000000?oooooo`000?l000003Oooool2o`0000Cooooo0_l0000:ooooo`;o000000?oooooo`000?l0
00001?ooool2o`00013ooooo0_l00003ooooo`?o00003_ooool2o`0001cooooo0_l000000ooooooo
0000o`000008o`000003ooooool0003o000000?o00003?ooool2o`0000Gooooo0_l0000;ooooo`;o
00002oooool3o`0004_ooooo000Looooo`03o`000?oooooooooo04?ooooo0_l000000ooooooo0000
o`000002o`00013ooooo0_l00004ooooo`;o00000oooool3o`0000?ooooo0_l00008ooooo`;o0000
3Oooool2o`000003ooooool0003o000000Go00003Oooool4o`0001;ooooo0ol0000:ooooo`;o0000
0_ooool;o`0000;ooooo0_l0000Cooooo`;o00002?ooool2o`0000Gooooo0_l00005ooooo`;o0000
2?ooool3o`00043ooooo000Looooo`03o`000?oooooooooo02kooooo0_l0000:ooooo`;o00001ooo
ool2o`000003ooooool0003o000000;o00002?ooool2o`0000?ooooo0_l00002ooooo`;o00002?oo
ool4o`0000;ooooo0_l00005ooooo`;o00004?ooool3o`0000;ooooo0ol0000:ooooo`;o00000ooo
ool2o`0001;ooooo1Ol0000:oooooa3o000000?oooooo`000?l000000_l00002ooooo`;o00003Ooo
ool2o`0000Kooooo1?l000000ooooooo0000o`000002ooooo`;o00001?ooool2o`0000Wooooo0ol0
0010ooooo`007?ooool00ol0003oooooooooo`0/ooooo`Co00002Oooool3o`0000Oooooo0_l00000
0ooooooo0000o`000002ooooo`;o00001_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2
o`0000?ooooo1_l00007ooooo`Go00001?ooool2o`000004ooooool0003o0000o`0000Cooooo0_l0
0002ooooo`Go00002?ooool2o`0001Oooooo0_l0000:oooooa?o000000?oooooo`000?l000000_l0
0002ooooo`;o00005Oooool4o`000003ooooool0003o000000Sooooo0_l0001<ooooo`007?ooool0
0ol0003oooooooooo`0/ooooo`;o00002oooool2o`0000oooooo0_l00007ooooo`;o00001?ooool2
o`0000Gooooo0_l00002ooooo`Oo00001Oooool2o`000003ooooool0003o000000Co00000_ooool2
o`000004ooooool0003o0000o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000002_oo
ool2o`00027ooooo1_l000000ooooooo0000o`00000:o`000004ooooool0003o0000ooooo`;o0000
6_ooool2o`000003ooooool0003o000000Kooooo0_l0000Aooooo`;o0000>oooool001cooooo00?o
0000ooooooooool0DOooool4o`0000Cooooo0_l00009ooooo`Co00001?ooool2o`0000;ooooo1?l0
0003ooooo`?o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000Kooooo0_l0
0004ooooo`;o00000oooool3o`0000Sooooo0_l0000<ooooo`;o00002Oooool5o`0000;ooooo4ol0
0006ooooo`;o00002?ooool2o`0000[ooooo0_l000000ooooooo0000o`000003ooooo`?o000000?o
ooooo`000?l000003Oooool2o`0003_ooooo000Looooo`03o`000?oooooooooo057ooooo0_l0000I
ooooo`;o00001?ooool4o`0000;ooooo1?l00002ooooo`;o000000?oooooo`000?l000002Oooool2
o`0000Cooooo0_l00003ooooo`?o00001?ooool2o`0000;ooooo0_l00007ooooo`;o00000_ooool3
o`0000Wooooo6_l00006ooooo`;o00002?ooool3o`0000cooooo0_l00004ooooo`;o000000?ooooo
o`000?l00000B_ooool001cooooo00?o0000ooooooooool0=_ooool2o`0003[ooooo1Ol00003oooo
o`?o000000?oooooo`000?l000000_l00004ooooo`Co00003Oooool2o`0000Gooooo0ol00005oooo
o`;o00000oooool2o`0000;ooooo1?l00008oooooaSo00004oooool2o`00067ooooo00001_oooooo
k^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool0
0ol0003oooooooooo`0fooooo`;o00007_ooool2o`0000;ooooo0_l00005ooooo`;o000000Cooooo
o`000?l0003ooooo0_l00005ooooo`;o00000_ooool6o`0000;ooooo2?l00004ooooo`Co00003Ooo
ool3o`0000Gooooo0_l00005ooooo`;o00000_ooool2o`0000;ooooo0_l000001?oooooo0000o`00
0?l00006ooooo`Oo000000?oooooo`000?l000004?l0000Sooooo`;o0000D?ooool00006oooooomg
MgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`1Dooooo`Co00000_ooool3o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`00
00Gooooo0_l00002ooooo`Ko00001?ooool7o`0000;ooooo0_l000000ooooooo0000o`00000<oooo
o`Co00004?ooool2o`0000;ooooo0_l00002ooooo`?o00001OoooolLo`00013ooooo0_l00003oooo
o`;o00001Oooool2o`0000?ooooo0_l0000;ooooo`;o0000@oooool00003ooooool@413ooooo00;o
oooo00?o410@ooooooooool02Oooool5o`0000Kooooo00?o0000ooooooooool0?oooool2o`0000;o
oooo0_l00006ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Gooooo0_l00005ooooo`;o
00003Oooool5o`0000Gooooo3?l000000ooooooo0000o`000003ooooo`;o00001oooool4o`0000Wo
oooo0_l0000>ooooo`;o00001OoooolLo`000003ooooool0003o000000gooooo0_l00003ooooo`;o
00001Oooool2o`0000?ooooo0_l0000;ooooo`;o00002?ooool2o`0003Wooooo00000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`0003oo
oooo0_l00002ooooo`?o00001Oooool2o`000003ooooool0003o000000;ooooo0_l000001?oooooo
0000o`000?ooool2o`0000Sooooo0_l00006ooooo`;o00000_ooool2o`000003ooooool0003o0000
00Go00000oooool=o`0000Cooooo0ol00009ooooo`;o00002?ooool3o`0000Sooooo0_l00002oooo
o`;o00001ooooolLo`000003ooooool0003o000001;ooooo0_l00002ooooo`;o00001_ooool4o`00
00Sooooo1?l00006ooooo`?o0000>Oooool00003ooooool0003ooooo00;ooooo00?o0000oooooooo
ool02Oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo04Cooooo0_l00007oooo
o`;o00000oooool8o`000003ooooool0003o000000[ooooo0_l000000ooooooo0000o`000004o`00
0003ooooool0003o000000So00001_ooool2o`000003ooooool0003o000000Go000000?oooooo`00
0?l000005?ooool3o`0000Oooooo0ol00002ooooo`;o00001oooool3o`000003ooooool0003o0000
01?o000000?oooooo`000?l000000_l0000=ooooo`;o00002?ooool2o`0000Sooooo0_l00008oooo
o`Co00001_ooool2o`0003[ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[o
oooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`1:ooooo`Go00001?ooool2o`000003
ooooool0003o000000?ooooo0_l00006ooooo`?o000000Coooooo`000?l0003ooooo2?l000000ooo
oooo0000o`000007o`000003ooooool0003o000000;o000000?oooooo`000?l000002Ol0000Foooo
o`;o00001oooool2o`0000;ooooo0_l00005ooooo`;o000000Goooooo`000?l0003o0000ooooo`0G
o`000003ooooool0003o000000gooooo0_l0000Fooooo`;o00001Oooool2o`0004?ooooo00001_oo
ooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l000001oooool00ol0003ooooooooo
o`0Uooooo`;o00008Oooool5o`0000Kooooo0_l00009ooooo`;o00000oooool3o`0000Cooooo0ol0
0003ooooo`;o000000?oooooo`000?l000006?l0000Fooooo`;o00001_ooool2o`000003ooooool0
003o000000;o00001Oooool2o`000003ooooool0003o000001Wo00004_ooool2o`0000Wooooo0_l0
0009ooooo`;o00001Oooool2o`0000Gooooo0_l0000looooo`0000Koooooonk^k_lb<S;o0000oc8b
<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool09Oooool2o`0000cooooo
0_l0000:ooooo`;o00001oooool2o`0000gooooo0_l00005ooooo`;o00000_ooool2o`0000Cooooo
0_l000001Ooooooo0000o`000?l0003ooooo013o000000?oooooo`000?l000002?l000001?oooooo
0000o`000?l0000Eooooo`;o00001_ooool2o`000003ooooool0003o000000;ooooo0_l00005oooo
oaco000000?oooooo`000?l000003Oooool4o`0000Wooooo0_l0000@ooooo`;o00001Oooool2o`00
0003ooooool0003o000003Wooooo000Looooo`03o`000?oooooooooo03;ooooo0ol0000:ooooo`;o
00004?ooool2o`0000Cooooo0_l00009ooooo`;o00000oooool3o`0000;ooooo7_l000000ooooooo
0000o`000004o`00027ooooo0_l00005oooooaco000000?oooooo`000?l000003Oooool2o`0001ko
oooo0_l00007ooooo`;o0000>Oooool001cooooo00?o0000ooooooooool0<_ooool2o`0000[ooooo
0_l0000Aooooo`;o00004Oooool2o`000003ooooool0003o000000;o000000?oooooo`000?l00000
5_l000000ooooooo0000o`000003o`000004ooooool0003o0000ooooo`?o00006Oooool2o`0000go
oooo7?l000000ooooooo0000o`000004ooooo`;o00000_ooool2o`0001gooooo0_l00004ooooo`;o
00001oooool2o`0003Wooooo000Looooo`03o`000?oooooooooo03kooooo0_l0000Fooooo`;o0000
2Oooool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000003o`000003oooo
ool0003o000000[o000000?oooooo`000?l000002Ol000001?oooooo0000o`000?ooool2o`0001[o
oooo0_l0000<ooooo`Co000000?oooooo`000?l000001_l000000ooooooo0000o`00000?o`0000Go
oooo0_l00002ooooo`;o00004?ooool2o`0000_ooooo0_l000000ooooooo0000o`000015ooooo`00
7?ooool00ol0003oooooooooo`0Nooooo`;o00000oooool2o`0001Cooooo0_l00002ooooo`?o0000
2oooool2o`0000;ooooo0_l00004ooooo`?o00001oooool4o`0000;ooooo3ol000000ooooooo0000
o`00000Bo`000004ooooool0003o0000ooooo`Co00002_ooool2o`0000;ooooo0_l0000Foooooago
000000?oooooo`000?l000006oooool2o`0000Cooooo0ol00007ooooo`;o000000?oooooo`000?l0
0000@_ooool001cooooo00?o0000ooooooooool07_ooool2o`0000?ooooo0_l0000Dooooo`;o0000
0_ooool2o`0000Sooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00001?ooool2o`0000So
oooo1?l00002ooooo`ko00000_ooool5o`000003ooooool0003o000000Go000000?oooooo`000?l0
00001?l000001?oooooo0000o`000?ooool5o`0000Wooooo0ol000000ooooooo0000o`000007oooo
o`;o00003Oooool2o`0000;ooooo7?l00002ooooo`;o00002oooool2o`0000gooooo0_l000000ooo
oooo0000o`000002o`0000Wooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o
00002Oooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000Kooooo0_l0000?oooo
o`Go000000?oooooo`000?l000006_l00003ooooo`;o00000oooool3o`0000Sooooo0ol00004oooo
o`;o000000Coooooo`000?l0003ooooo0_l0000:ooooo`;o00001_oooolIo`0000Cooooo0_l00009
ooooo`Co00003Oooool2o`0000?ooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`0`oooo
o`;o00001_ooool2o`0000Wooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l00006oooo
o`;o00001oooool2o`0000;ooooo0_l00005ooooo`Wo000000?oooooo`000?l000004ol00003oooo
o`Go000000?oooooo`000?l000003oooool2o`000003ooooool0003o000000gooooo0_l00002oooo
o`;o000000?oooooo`000?l000004?l00002ooooo`Co00000oooool4o`0000[ooooo0_l0000Aoooo
o`;o00004oooool2o`0003_ooooo000Looooo`03o`000?oooooooooo02;ooooo0_l0000<ooooo`;o
00001_ooool2o`0000Cooooo0_l00008ooooo`;o000000?oooooo`000?l000004Oooool3o`000003
ooooool0003o000000Oooooo7ol00002ooooo`Co00000_ooool2o`00017ooooo1?l00004ooooo`Ko
00001Oooool2o`000003ooooool0003o0000013o00000_ooool6o`000003ooooool0003o000000;o
00002_ooool2o`00017ooooo0_l00002ooooo`?o00003_ooool2o`0003_ooooo000Looooo`03o`00
0?oooooooooo02;ooooo0_l0000:ooooo`;o00002?ooool2o`0000Cooooo0_l0000;ooooo`;o0000
3Oooool2o`0000;ooooo1_l00007ooooob?o000000Coooooo`000?l0003ooooo0_l0000;ooooo`?o
00001Oooool2o`0000Cooooo1_l00003ooooo`;o00000ooooolJo`000003ooooool0003o000001go
oooo0_l00004ooooo`?o00001oooool2o`0004;ooooo000Looooo`03o`000?oooooooooo02kooooo
0_l0000Fooooo`?o00001Oooool2o`0000[ooooo0_l00004ooooo`Co00000oooool2o`0000;ooooo
7Ol000000ooooooo0000o`000003o`000004ooooool0003o0000o`0000gooooo0ol00005ooooo`;o
00001_ooool3o`0000;ooooo1?l00002ooooo`?o000000Goooooo`000?l0003o0000ooooo`0?o`00
0003ooooool0003o000000;ooooo0_l0000Mooooo`;o00002oooool2o`000004ooooool0003o0000
o`00047ooooo000Looooo`03o`000?oooooooooo03Sooooo0_l0000<ooooo`?o00001Oooool2o`00
00gooooo0_l00008ooooob7o000000?oooooo`000?l000000ol000001?oooooo0000o`000?l00004
ooooo`;o000000?oooooo`000?l000003?ooool2o`0000Oooooo1_l00004ooooo`;o00000_ooool3
o`000003ooooool0003o000000;o00000_ooool6o`000004ooooool0003o0000ooooo`;o00000ooo
ool2o`00027ooooo0_l00006ooooo`;o00000_ooool2o`0000[ooooo0_l0000eooooo`007?ooool2
o`0003Wooooo0_l0000;ooooo`Go00002?ooool2o`0000Wooooo0_l00006ooooo`;o00000_oooolC
o`000003ooooool0003o000000oo00001oooool3o`000003ooooool0003o000000Cooooo1?l0000<
ooooo`Go000000?oooooo`000?l000000_l00004ooooo`Go00001_ooool5o`0000Cooooo0_l00000
0ooooooo0000o`000003o`0000kooooo0_l0000Aooooo`;o00001_ooool2o`0000kooooo0_l0000e
ooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00005oooool2o`000003ooooool0003o0000
00Sooooo0_l00004ooooo`;o00001oooool2o`0000;ooooo0_l000000ooooooo0000o`00000To`00
00;ooooo0_l00003ooooo`;o00002?ooool4o`0000Cooooo0_l00006ooooo`;o00001?ooool4o`00
00;ooooo1ol00006ooooo`;o00000_ooool3o`0000;ooooo1ol00003ooooo`;o00001Oooool2o`00
00?ooooo0_l0000Tooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0;?ooool2o`0001go
oooo0_l00008ooooo`Go00000oooool2o`0000;ooooo0_l00002ooooobCo00000oooool2o`0000;o
oooo1?l000000ooooooo0000o`00000:ooooo`;o00001?ooool2o`0000Wooooo0_l000001?oooooo
0000o`000?l00003ooooo`;o00002?ooool2o`000003ooooool0003o000000Go00001?ooool2o`00
0003ooooool0003o000000?ooooo0_l00005ooooo`;o00000oooool4o`0000_ooooo0_l000000ooo
oooo0000o`00000Booooo`;o0000>_ooool001cooooo00?o0000ooooooooool0;?ooool2o`0000So
oooo0_l00004ooooo`;o00003Oooool3o`0000Oooooo1?l00004ooooo`Ko00000oooool?o`000003
ooooool0003o0000017o00002Oooool2o`0000Sooooo0_l00002ooooo`?o00003oooool2o`0000;o
oooo0_l000001?oooooo0000o`000?l00006ooooo`Go00000_ooool3o`0001gooooo0_l0000;oooo
o`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo0ol0000:ooooo`;o0000=oooool001co
oooo00?o0000ooooooooool0;?ooool2o`0000Sooooo0_l000001?oooooo0000o`000?ooool2o`00
00?ooooo0_l00003ooooo`;o00001?ooool2o`0000Wooooo0_l00006ooooo`;o00001_oooolUo`00
00?ooooo0_l00009ooooo`Co00000_ooool2o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`00
00Gooooo0ol00005ooooo`Go00000oooool2o`000003ooooool0003o000000Gooooo0_l0000Zoooo
o`;o00000_ooool3o`0000Wooooo0ol0000gooooo`007?ooool00ol0003oooooooooo`0hooooo`?o
00000oooool2o`000004ooooool0003o0000ooooo`Co00002?ooool3o`0001Cooooo;?l00007oooo
o`;o00001?ooool2o`0000?ooooo0ol00004ooooo`;o00001?ooool2o`0000Sooooo0ol00002oooo
o`;o00001?ooool7o`0000Gooooo0_l0000jooooo`;o0000>?ooool001cooooo00?o0000oooooooo
ool07_ooool2o`0001Sooooo0_l00004ooooo`;o00001?ooool4o`0000Sooooo1Ol00008ooooo`;o
00000_ooool2o`0000?ooooo:Ol00002ooooo`;o00003Oooool2o`0000?ooooo0_l00004ooooo`;o
00001Oooool2o`000004ooooool0003o0000ooooo`;o00000_ooool4o`0000Oooooo1_l0000Aoooo
o`;o00006Oooool2o`000003ooooool0003o000000kooooo0_l0000kooooo`007?ooool00ol0003o
ooooooooo`0Nooooo`?o00009Oooool2o`0000Wooooo1?l00003ooooo`;o000000?oooooo`000?l0
00000_l00002ooooo`?o000000?oooooo`000?l000001?l00002oooooako000000Coooooo`000?l0
003o00001oooool2o`000003ooooool0003o000000_ooooo0_l00003ooooo`;o00000oooool4o`00
0004ooooool0003o0000ooooo`;o00001?ooool2o`0000Wooooo0_l0000Booooo`?o00005oooool4
o`000003ooooool0003o000000kooooo0_l00004ooooo`;o0000=Oooool001cooooo00?o0000oooo
ooooool07oooool2o`00023ooooo0ol0000Dooooo`;o000000?oooooo`000?l000001OoooolYo`00
0003ooooool0003o000000?o00001Oooool5o`0000Cooooo0ol00004ooooo`;o00002?ooool6o`00
00?ooooo0_l0000>ooooo`;o00001Oooool2o`0000_ooooo0_l0000Hooooo`;o00004?ooool4o`00
00Gooooo0_l0000eooooo`007?ooool00ol0003oooooooooo`0Mooooo`;o00008?ooool5o`0001ko
oooo1Ol00004ooooob3o000000Coooooo`000?l0003ooooo0_l00007ooooo`Co000000?oooooo`00
0?l000000ol0000;ooooo`?o00000_ooool4o`0000?ooooo0_l00009ooooo`;o00002_ooool2o`00
00Oooooo0_l0000Looooo`;o00002_ooool4o`0000;ooooo1?l0000looooo`007?ooool00ol0003o
ooooooooo`0Mooooo`;o00008?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`000003
ooooool0003o000001Kooooo1?l00004oooooa[o00000oooool3o`000003ooooool0003o000000;o
00001?ooool8o`000004ooooool0003o0000ooooo`;o00002oooool3o`0000Gooooo0_l00009oooo
o`;o00000_ooool2o`0000;ooooo0_l0000<ooooo`;o000000?oooooo`000?l000002oooool2o`00
00oooooo1?l00002ooooo`[o00001_ooool2o`0000Gooooo0_l0000cooooo`007?ooool00ol0003o
ooooooooo`0gooooo`;o00002_ooool7o`000003ooooool0003o000000Wooooo0_l000000ooooooo
0000o`000002o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l0
00007?l00003ooooo`Oo00000_ooool7o`0000Gooooo0_l0000@ooooo`Go00000oooool2o`0000Co
oooo1?l00004ooooo`;o00001oooool2o`0000?ooooo0_l00002ooooo`;o00002_ooool2o`0000oo
oooo1?l00002ooooo`Ko00002_ooool2o`0000Gooooo0_l0000cooooo`007?ooool00ol0003ooooo
ooooo`0gooooo`;o00003?ooool2o`0000_ooooo0_l00002ooooo`;o000000?oooooo`000?l00000
0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`000005ooooool0003o0000o`000?oo
ool05_l000000ooooooo0000o`000002o`0000;ooooo0_l00002ooooo`?o00001Oooool3o`0001Co
oooo0_l000000ooooooo0000o`000004o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`0000_o
oooo1?l00002ooooo`?o000000Coooooo`000?l0003o00006oooool2o`0001_ooooo0_l00002oooo
o`;o0000;oooool001cooooo00?o0000ooooooooool0A?ooool3o`0000?ooooo0_l00006ooooo`?o
00000_ooool3o`0000Kooooo0_l00008oooooaoo00000_ooool2o`0000;ooooo0ol00005ooooo`;o
00001Oooool2o`0000kooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00001oooool2o`00
00oooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo1?l0000:ooooo`;o0000;oooool2
o`0002oooooo000Looooo`03o`000?oooooooooo03gooooo0_l00005ooooo`?o00000oooool2o`00
00Oooooo0_l00002ooooo`?o00001oooool2o`0000Cooooo0_l00002ooooob3o00003?ooool2o`00
00Gooooo0_l0000?ooooo`Ko00006?ooool2o`0000?ooooo0_l00007ooooo`;o00002_ooool2o`00
01Cooooo0_l0000@ooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0>oooool5o`0000[o
oooo0_l00004ooooo`;o00002Oooool2o`0000?ooooo0ol00004ooooo`;o00000oooool8o`000003
ooooool0003o000001Co00002?ooool2o`0001Wooooo0ol00002ooooo`;o00006?ooool4o`0002[o
oooo1?l0000@ooooo`;o00000_ooool2o`0003Cooooo000Looooo`;o0000??ooool5o`0000Cooooo
0_l00004ooooo`Go000000?oooooo`000?l000002Oooool2o`0000?ooooo1?l000000ooooooo0000
o`000002o`000003ooooool0003o000000Go000000?oooooo`000?l000005ol000000ooooooo0000
o`000005ooooo`;o00006Oooool5o`000003ooooool0003o000000?ooooo0_l0000Aooooo`;o0000
00?oooooo`000?l000000_l0000Cooooo`;o00004oooool2o`000003ooooool0003o000001?ooooo
1?l0000booooo`007?ooool00ol0003oooooooooo`0fooooo`;o00001?ooool2o`0000Gooooo0ol0
0003ooooo`Ko00004_ooool6o`0000;ooooo2?l000000ooooooo0000o`00000;o`000003ooooool0
003o000000Wo000000?oooooo`000?l000004?ooool2o`0000kooooo0_l000001?oooooo0000o`00
0?ooool2o`0000?ooooo0_l0000@ooooo`?o00000oooool2o`000003ooooool0003o0000013ooooo
0_l0000Fooooo`Co00004oooool2o`0003;ooooo000Looooo`03o`000?oooooooooo03Cooooo1?l0
000;ooooo`;o00001?ooool2o`0001Oooooo0ol000001?oooooo0000o`000?ooool6o`000003oooo
ool0003o000001;o000000?oooooo`000?l000000_l000001?oooooo0000o`000?l00003ooooo`;o
00002oooool3o`0000kooooo1_l00005ooooo`;o00004?ooool8o`000003ooooool0003o000002Wo
oooo0ol00005ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0=?ooool3o`0000Kooooo
0_l00002ooooo`;o000000?oooooo`000?l000006_ooool2o`0000Cooooo1Ol000001?oooooo0000
o`000?oooolNo`0000?ooooo0_l00003ooooo`;o00001_ooool3o`0000;ooooo0_l0000<ooooo`Go
00006?ooool6o`0002cooooo0_l00006ooooo`;o00001oooool2o`0003Oooooo000Looooo`03o`00
0?oooooooooo01_ooooo0_l0000Hooooo`;o00000_ooool2o`0000;ooooo0_l00002ooooo`;o0000
00?oooooo`000?l000001_ooool2o`0001;ooooo0_l00006ooooo`?o00000_ooool8o`000005oooo
ool0003o0000o`000?ooool00_l000000ooooooo0000o`000009o`000003ooooool0003o000000;o
oooo0_l00006ooooo`;o00001_ooool3o`0000;ooooo0_l00004ooooo`;o00002?ooool3o`0000ko
oooo0_l000001?oooooo0000o`000?ooool:o`0002Cooooo0_l0000Cooooo`;o00000_ooool2o`00
03Oooooo000Looooo`03o`000?oooooooooo01_ooooo0_l0000Looooo`;o00001_ooool7o`0000Co
oooo0_l0000Kooooo`?o000000?oooooo`000?l000002_l00002ooooo`_o000000?oooooo`000?l0
00001?ooool2o`0000Gooooo0_l00007ooooo`;o00002Oooool2o`0000Wooooo0_l0000>ooooo`;o
000000Coooooo`000?l0003ooooo1ol000000ooooooo0000o`00000<ooooo`;o00005?ooool4o`00
01?ooooo0_l00008ooooo`;o0000<Oooool001cooooo00?o0000ooooooooool0>?ooool2o`0000Oo
oooo1ol0000Rooooo`;o000000Coooooo`000?l0003ooooo2Ol000000ooooooo0000o`000008o`00
00?ooooo0_l0000;ooooo`;o0000;Oooool5o`000003ooooool0003o000000Go000000Coooooo`00
0?l0003o00001Oooool2o`0000Cooooo0_l0000Dooooo`;o00004Oooool3o`0000_ooooo0_l0000a
ooooo`007?ooool00ol0003oooooooooo`0hooooo`Co00005?ooool2o`0001Gooooo0_l00003oooo
o`?o000000Goooooo`000?l0003o0000ooooo`0@o`0000?ooooo1Ol0000@ooooo`;o00009_oooolG
o`0000Cooooo1Ol0000@ooooo`;o00004_ooool3o`0000Oooooo0_l0000eooooo`007?ooool00ol0
003oooooooooo`0jooooo`;o00002_ooool2o`0000Sooooo0_l00002ooooo`;o000000?oooooo`00
0?l000003_ooool2o`0000?ooooo0_l00004ooooo`;o00000_ooool;o`000003ooooool0003o0000
00?ooooo1Ol0000@ooooo`;o00003oooool2o`0000Wooooo0_l0000<oooooaCo00001Oooool5o`00
013ooooo1?l00002ooooo`;o000000?oooooo`000?l000002_ooool2o`0000Oooooo1?l0000coooo
o`007?ooool00ol0003oooooooooo`15ooooo`?o00000_ooool2o`0000Sooooo0_l000001?oooooo
0000o`000?ooool2o`0000Cooooo0_l0000@ooooo`;o00000_ooool2o`000005ooooool0003o0000
o`000?ooool01?l0000?ooooo`?o000000?oooooo`000?l000001?ooool4o`000004ooooool0003o
0000o`0000_ooooo0_l00009ooooo`;o00002Oooool3o`0000?ooooo5_l00004ooooo`;o00004Ooo
ool2o`0000;ooooo1Ol00008ooooo`Co00002Oooool2o`0003?ooooo000Looooo`03o`000?oooooo
oooo03Oooooo0_l00007ooooo`;o00000_ooool3o`0000;ooooo0ol00002ooooo`;o00001Oooool2
o`0000?ooooo0_l00004ooooo`;o00004Oooool2o`000003ooooool0003o000000?o00005Oooool3
o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000003o`00017ooooo0_l0000>
ooooo`Go00000ooooolEo`0000?ooooo1?l0000?ooooo`;o00000oooool3o`0000Wooooo0_l00010
ooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00001oooool2o`0000;ooooo0_l00003oooo
o`;o00000oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000?ooooo0_l00009oooo
o`;o000000?oooooo`000?l000001_l0000;ooooo`;o00004_ooool5o`0000Cooooo0_l000000ooo
oooo0000o`000003ooooo`;o00000_ooool3o`00017ooooo0_l000000ooooooo0000o`000008o`00
0003ooooool0003o000000_o00001?ooool3o`0000Wooooo0_l00009ooooo`;o00007Oooool2o`00
02cooooo000Looooo`03o`000?oooooooooo03oooooo0_l0000Kooooo`;o00001Oooool3o`0000;o
oooo0_l00002ooooo`;o00002oooool5o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`;o
00004?ooool2o`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l000000_l000000ooooooo
0000o`000002ooooo`?o00005?ooool2o`000003ooooool0003o000001?o00001Oooool2o`0000Wo
oooo0_l0000Cooooo`;o00004oooool2o`0002cooooo000Looooo`03o`000?oooooooooo03Oooooo
0_l00003ooooo`;o000000?oooooo`000?l000000_l0000;ooooo`;o00005?ooool3o`0000Gooooo
0_l000001?oooooo0000o`000?ooool2o`0000Gooooo0_l00006ooooo`;o000000?oooooo`000?l0
00000_l00005ooooo`?o000000?oooooo`000?l000002?ooool2o`0000kooooo0_l00006ooooo`;o
00004_ooool4o`000003ooooool0003o000000?o000000?oooooo`000?l000003?l0000Eooooo`;o
00001Oooool2o`0000Sooooo0_l00003ooooo`;o00003Oooool2o`0002gooooo000Looooo`03o`00
0?oooooooooo03Oooooo0_l00003ooooo`Co000000?oooooo`000?l000002oooool2o`0000;ooooo
0_l0000Aooooo`;o00002?ooool2o`000004ooooool0003o0000ooooo`;o00002?ooool6o`000003
ooooool0003o000000;o00000oooool3o`000003ooooool0003o000000Oooooo1?l0000=ooooo`Oo
00005Oooool2o`0000;ooooo5Ol000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l0
00000_l00002ooooo`;o00001Oooool2o`0000Gooooo0_l0000=ooooo`;o00001Oooool2o`0000Ko
oooo0_l0000]ooooo`007?ooool00ol0003oooooooooo`0dooooo`;o00001Oooool2o`000003oooo
ool0003o000000;ooooo0_l0000:ooooo`;o00000_ooool2o`0001cooooo0_l00002ooooo`?o0000
2?ooool6o`0000?ooooo1Ol000000ooooooo0000o`000002o`0000Sooooo1?l00002ooooo`;o0000
1oooool9o`000004ooooool0003o0000o`0001;ooooo5_l00002ooooo`?o00000_ooool2o`000003
ooooool0003o000000;o00000_ooool2o`0000;ooooo1?l0000Eooooo`;o00000_ooool2o`000003
ooooool0003o000003Gooooo000Looooo`;o0000=Oooool2o`000003ooooool0003o000000;ooooo
0_l00004ooooo`?o00002?ooool2o`0002;ooooo0_l00002ooooo`Go00003?ooool2o`000003oooo
ool0003o000000?o00000oooool2o`0000[ooooo1_l00007ooooo`;o000000?oooooo`000?l00000
0ol00002ooooo`?o00003_ooool2o`0000;ooooo6ol00006ooooo`;o00001oooool4o`0000Sooooo
0_l0000?ooooo`;o00000_ooool3o`0003?ooooo000Looooo`03o`000?oooooooooo03Oooooo0_l0
0008ooooo`;o00002Oooool2o`0002?ooooo0_l00004ooooo`;o000000?oooooo`000?l000000_l0
0007ooooo`;o000000?oooooo`000?l000002_ooool2o`0000Sooooo0_l0000<ooooo`Wo00003ooo
ool5o`000003ooooool0003o000001So00004?ooool2o`0000Sooooo0_l0000@ooooo`;o000000Go
ooooo`000?l0003o0000ooooo`02o`00033ooooo000Looooo`03o`000?oooooooooo03Cooooo0ol0
00000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l00000;Oooool2o`0000Oooooo1?l0
0002ooooo`Co00001?ooool2o`0000Wooooo0ol0000Fooooo`Co000000?oooooo`000?l000000_l0
000@ooooo`Co000000?oooooo`000?l000006?l00003ooooo`;o000000Coooooo`000?l0003ooooo
0_l00002ooooo`;o00001Oooool2o`0000Cooooo0_l00006ooooo`;o00001?ooool2o`000004oooo
ool0003o0000o`0000Gooooo0_l0000`ooooo`007?ooool00ol0003oooooooooo`0dooooo`?o0000
00?oooooo`000?l000000oooool8o`00027ooooo0_l00009ooooo`;o00003Oooool4o`0000oooooo
0_l0000Cooooo`;o00001?ooool7o`00013ooooo0ol00002oooooaWo00001?ooool2o`000004oooo
ool0003o0000ooooo`;o00000_ooool2o`0000Gooooo0_l00004ooooo`;o00001_ooool2o`0000Co
oooo0_l000000ooooooo0000o`000002o`0003Kooooo000Looooo`03o`000?oooooooooo03gooooo
0_l00002ooooo`Go000000Coooooo`000?l0003ooooo0_l0000Jooooo`?o00002?ooool2o`0000_o
oooo0_l0000Aooooo`;o00005Oooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l0
00004?ooool2o`0000;ooooo2ol000000ooooooo0000o`00000<o`0000Gooooo0_l0000Fooooo`;o
00000oooool2o`0000[ooooo0_l0000fooooo`007?ooool00ol0003oooooooooo`0hooooo`;o0000
1oooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000006oooool2o`0000Oo
oooo0ol000000ooooooo0000o`000008ooooo`;o000000?oooooo`000?l000000_l0000<ooooo`;o
00001?ooool2o`000003ooooool0003o0000013ooooo0_l00005ooooo`;o00005?ooool;o`000003
ooooool0003o000000Wo00000_ooool2o`0000Cooooo0_l00003ooooo`Co00003?ooool2o`000003
ooooool0003o000000;o000000?oooooo`000?l000001?ooool2o`0000;ooooo0_l0000hooooo`00
7?ooool00ol0003oooooooooo`0Oooooo`;o00005oooool2o`0000Oooooo0_l0000]ooooo`Ko0000
2oooool4o`0000cooooo0_l000001?oooooo0000o`000?ooool5o`0000Wooooo0_l00005ooooo`;o
00000_ooool2o`0001Sooooo5_l00002ooooo`;o00002Oooool4o`0000cooooo0_l00003ooooo`;o
000000Coooooo`000?l0003o00000oooool2o`0000;ooooo0_l0000hooooo`007?ooool00ol0003o
ooooooooo`0Oooooo`;o00005?ooool2o`0003cooooo0_l0000?ooooo`;o00002_ooool2o`0000;o
oooo0_l000001?oooooo0000o`000?l0000;ooooo`;o00002Oooool4o`0001;ooooo0_l00003oooo
oaGo00001oooool2o`0000Sooooo0_l000000ooooooo0000o`00000:ooooo`;o00001?ooool3o`00
00Wooooo0_l0000eooooo`007?ooool00ol0003oooooooooo`0cooooo`Co000000?oooooo`000?l0
0000;_ooool2o`00013ooooo0_l00008ooooo`;o00002_ooool2o`0000Gooooo0_l0000Dooooo`;o
00000oooool2o`0001;ooooo0_l00004oooooaCo00001oooool2o`0000Sooooo0_l000000ooooooo
0000o`00000:ooooo`;o00000oooool4o`0000Wooooo0_l0000eooooo`007?ooool00ol0003ooooo
ooooo`0cooooo`;o00000oooool2o`000003ooooool0003o000001Kooooo0_l0000Cooooo`?o0000
3oooool2o`0000?ooooo0_l0000@ooooo`;o00005oooool2o`000003ooooool0003o000000?ooooo
0_l00008ooooo`;o00003_oooolCo`0002Gooooo0ol00012ooooo`007?ooool00ol0003ooooooooo
o`0kooooo`Co00005?ooool2o`0001Cooooo0_l0000;ooooo`;o00000_ooool2o`0000?ooooo0_l0
000;ooooo`;o00000oooool2o`00017ooooo1?l00002ooooo`;o00001Oooool5o`0000Kooooo0_l0
000=oooooaGo00001oooool2o`0000gooooo1?l000000ooooooo0000o`000007ooooo`Co0000@Ooo
ool001cooooo00?o0000ooooooooool07oooool2o`0001cooooo0_l00003ooooo`?o0000<Oooool2
o`0000Oooooo0_l00005ooooo`;o00001?ooool2o`0000gooooo0_l00002ooooo`;o00000_ooool5
o`0000Wooooo1Ol0000Eooooo`;o00000_oooolAo`000003ooooool0003o000000;ooooo1?l0000=
ooooo`Co000000?oooooo`000?l000000_l00003ooooo`;o00000_ooool2o`00047ooooo000Loooo
o`03o`000?oooooooooo01oooooo0_l0000Gooooo`;o00000oooool2o`0000?ooooo0ol00009oooo
o`;o00008?ooool2o`0000Kooooo0_l000000ooooooo0000o`000003ooooo`;o00001?ooool3o`00
00Oooooo0_l00009ooooo`;o00000_ooool2o`0000;ooooo0_l00008ooooo`So00006?ooool2o`00
00;ooooo2ol000000ooooooo0000o`000002ooooo`;o00000_ooool2o`0000Oooooo0_l00007oooo
o`;o00001?ooool2o`000003ooooool0003o000000?o00003Oooool2o`0003Gooooo000Looooo`03
o`000?oooooooooo03Sooooo0_l00008ooooo`?o00002Oooool2o`0000?ooooo0ol0000Jooooo`;o
00000oooool2o`000004ooooool0003o0000ooooo`;o00000oooool4o`0000?ooooo0ol00006oooo
o`;o00004oooool3o`0000Gooooo2Ol00005ooooo`;o00002?ooool2o`0000Kooooo0_l00002oooo
o`_o00001oooool2o`0000Wooooo0_l0000@ooooo`;o000000?oooooo`000?l000000oooool2o`00
00Sooooo0_l0000eooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool0
1Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0>_ooool2o`0000Oooooo0_l0
000>ooooo`?o00007oooool2o`0000Wooooo1Ol00003ooooo`;o000000?oooooo`000?l000005_oo
ool5o`0000Gooooo1_l000000ooooooo0000o`000005ooooo`;o00002?ooool2o`0000Gooooo0ol0
0005ooooo`So00001oooool2o`0001Cooooo0_l00005ooooo`;o00001?ooool4o`0003oooooo0000
1_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B401_ooool00ol0003oooooooooo`0jooooo`;o0000?oooool2o`0000?ooooo0_l000000ooooooo
0000o`000006ooooo`;o00001oooool2o`0000gooooo0_l00004ooooo`;o000000Coooooo`000?l0
003ooooo1_l00006ooooo`;o00003oooool3o`0000;ooooo0_l00003ooooo`Go00006?ooool2o`00
00Cooooo0_l00005ooooo`;o00000oooool4o`0000Gooooo0_l0000iooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`0nooooo`;o00001oooool4o`0001oooooo0_l00002ooooo`;o00002_ooool5o`00
00Cooooo0_l00007ooooo`;o00001_ooool2o`0000;ooooo0ol00003ooooo`;o00002Oooool2o`00
0004ooooool0003o0000ooooo`Ko00001_ooool2o`0001Cooooo0_l000000ooooooo0000o`000003
o`0001[ooooo0_l00004ooooo`;o00002_ooool2o`0000;ooooo0_l00003ooooo`;o0000>Oooool0
0003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oV9RHoooooonHV9So
8B4Q00Kooooo0ol0000looooo`Co00000_ooool2o`0000?ooooo1?l0000Nooooo`?o00000_ooool2
o`0000[ooooo0_l000001?oooooo0000o`000?l00006ooooo`?o00000oooool2o`0000[ooooo0ol0
0003ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00004ooooo`Go00008?oo
ool2o`000003ooooool0003o000000[ooooo0_l00009ooooo`;o00003?ooool2o`0000_ooooo0_l0
000nooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?mEEEGo
0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0Sooooo`;o00005?ooool5o`0000Cooooo0_l0
00000ooooooo0000o`000002ooooo`;o00007_ooool3o`0000[ooooo0_l00005ooooo`Co00001Ooo
ool3o`0000?ooooo0_l00002ooooo`;o00003oooool2o`0000;ooooo0_l00004ooooo`Oo00006ooo
ool2o`0001Cooooo0_l00009ooooo`;o00003?ooool3o`0000[ooooo0_l00004ooooo`;o0000>?oo
ool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08
ooooo`03o`000?oooooooooo02?ooooo0_l0000Dooooo`?o00002Oooool2o`0002Oooooo0_l00006
ooooo`;o00001Oooool4o`0000Oooooo0ol00005ooooo`?o00000oooool2o`0000_ooooo0_l00006
ooooo`Go000000?oooooo`000?l000002oooool3o`0000cooooo0_l00002ooooo`;o00000oooool2
o`000003ooooool0003o0000013ooooo0_l0000;ooooo`;o000000?oooooo`000?l000000_l0000:
ooooo`;o00001?ooool2o`0003Sooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00?o
gMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0kooooo`;o00005oooool2o`0001Sooooo0_l0
000=ooooo`;o00000_ooool2o`0000?ooooo1Ol00006ooooo`Co000000?oooooo`000?l000002ooo
ool2o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`;o00000_ooool2o`0000Kooooo1?l0
0004ooooo`;o00002_ooool4o`000003ooooool0003o000000?o00004?ooool2o`0000_ooooo0_l0
00000ooooooo0000o`000002o`0000oooooo0_l0000iooooo`0000Koooooonk^k_lb<S;o0000oc8b
<_o^k^h<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool08oooool2o`0001?o
oooo0_l000000ooooooo0000o`00000Gooooo`;o00005oooool2o`0000kooooo0ol000000ooooooo
0000o`000002o`000003ooooool0003o000000?o00000_ooool2o`0000Cooooo0_l000000ooooooo
0000o`00000;ooooo`;o00001?ooool:o`0000;ooooo0_l00006ooooo`Co00001?ooool2o`0000co
oooo0_l00002ooooo`;o00007Oooool2o`0000;ooooo1?l0000@ooooo`;o0000>Oooool001cooooo
00?o0000ooooooooool08oooool2o`0001?ooooo0_l0000Cooooo`?o00007Oooool3o`0000gooooo
0ol000000ooooooo0000o`00000<o`0000;ooooo0_l0000Gooooo`Oo00004_ooool6o`0000Cooooo
0_l0000Hooooo`;o00003Oooool2o`000004ooooool0003o0000o`0000;ooooo0_l00004ooooo`;o
0000@oooool001cooooo00?o0000ooooooooool0>oooool2o`00013ooooo0ol0000Kooooo`;o0000
00?oooooo`000?l000002_ooool2o`0000;ooooo0_l00002ooooo`Ko000000?oooooo`000?l00000
0ol00002ooooo`?o00006Oooool2o`000003ooooool0003o000001;ooooo1_l00004ooooo`;o0000
6?ooool2o`0000Oooooo0_l00005ooooo`Co00000oooool2o`000004ooooool0003o0000ooooo`;o
00001_ooool2o`0003_ooooo000Looooo`03o`000?oooooooooo03_ooooo1?l00006ooooo`;o0000
0oooool2o`0000Cooooo0_l0000Iooooo`Go00002_ooool2o`000003ooooool0003o000000;o0000
00?oooooo`000?l000001?l000001?oooooo0000o`000?l00004ooooo`?o000000?oooooo`000?l0
00005?ooool4o`000003ooooool0003o000000oooooo0_l00002ooooo`Co0000:?ooool2o`000003
ooooool0003o000000Go00000_ooool2o`0000?ooooo1?l00007ooooo`;o0000>oooool001cooooo
00?o0000ooooooooool0=_ooool2o`0000Gooooo0_l00003ooooo`;o000000Goooooo`000?l0003o
0000ooooo`03o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0001Gooooo1Ol0000=oooo
o`So000000?oooooo`000?l000001?l00005ooooo`Go00005?ooool2o`000003ooooool0003o0000
00;ooooo1_l00009ooooo`;o000000?oooooo`000?l000000ol0000[ooooo`Go00001?ooool2o`00
00?ooooo1?l00014ooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00002_ooool2o`0000;o
oooo0_l000000ooooooo0000o`000002ooooo`;o00001Oooool2o`0001Gooooo0_l000000ooooooo
0000o`00000:oooooaGo00000oooool3o`0000;ooooo0_l0000<ooooo`;o000000?oooooo`000?l0
00001Ol00002ooooo`Ko00002Oooool2o`000003ooooool0003o000002gooooo1?l0000Eooooo`;o
0000??ooool001cooooo00?o0000ooooooooool09_ooool2o`0001Cooooo0ol00009ooooo`;o0000
<?oooolEo`0000Cooooo0_l00002ooooo`;o00003?ooool2o`000004ooooool0003o0000ooooo`;o
000000Goooooo`000?l0003o0000ooooo`05o`0000Wooooo0_l0000`ooooo`Co00002_ooool2o`00
00Wooooo0_l0000looooo`007?ooool00ol0003oooooooooo`0Vooooo`;o00005?ooool3o`0000Wo
oooo0_l0000:ooooo`;o00005_ooool2o`0000;ooooo0_l00008oooooa[o00002oooool2o`0000Oo
oooo0_l00004ooooo`Go00001_ooool2o`0000Oooooo0_l0000[ooooo`Co00002?ooool2o`0000?o
oooo0_l00017ooooo`007?ooool00ol0003oooooooooo`18ooooo`;o000000?oooooo`000?l00000
1oooool2o`0000oooooo0ol00004ooooo`;o00000_ooool2o`0000Oooooo6ol000001?oooooo0000
o`000?ooool2o`0000Gooooo0_l00004ooooo`Co00000_ooool2o`0000;ooooo1?l00006ooooo`;o
00001oooool2o`0002_ooooo1?l00005ooooo`;o000000?oooooo`000?l000001?ooool2o`0004Ko
oooo000Looooo`03o`000?oooooooooo04_ooooo0_l00006ooooo`;o00004?ooool3o`0000Cooooo
0_l000000ooooooo0000o`000008ooooo`;o00000_ooool8o`000003ooooool0003o000000oo0000
00?oooooo`000?l000000_l00003ooooo`;o00001?ooool4o`0000;ooooo0_l000000ooooooo0000
o`000004o`0000?ooooo1?l00008ooooo`;o00009Oooool2o`0000Kooooo0_l00004ooooo`;o0000
1oooool2o`0004Kooooo000Looooo`03o`000?oooooooooo03[ooooo0_l0000?ooooo`;o00001Ooo
ool3o`0001[ooooo0_l00008ooooo`;o00000_oooolOo`0001;ooooo1_l00003ooooo`;o00002_oo
ool2o`0002Gooooo0_l00006ooooo`;o0000EOooool001cooooo00?o0000ooooooooool0>_ooool3
o`000003ooooool0003o000000_ooooo0_l00005ooooo`;o00005oooool3o`0000[ooooo0_l00002
ooooo`Ko000000?oooooo`000?l000005Ol0000>ooooo`;o00002?ooool5o`000003ooooool0003o
0000047ooooo0ol0001;ooooo`007?ooool2o`0003cooooo0_l000000ooooooo0000o`000003oooo
o`;o00000_ooool2o`00027ooooo1?l0000:oooooaco00005?ooool2o`000003ooooool0003o0000
00Oooooo1_l0000iooooo`;o00001?ooool5o`0000Gooooo0_l00014ooooo`007?ooool00ol0003o
ooooooooo`13ooooo`;o00000_ooool2o`00027ooooo0_l0000>oooooa;o000000?oooooo`000?l0
00001_l00008ooooo`;o00003?ooool2o`0000Oooooo1ol0000:ooooo`;o0000;?ooool2o`0000Co
oooo0_l00008ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0>oooool2o`0000gooooo
0_l0000Nooooo`;o00003?oooolMo`0000Sooooo0_l00009ooooo`;o00003?ooool5o`0000[ooooo
0_l00004ooooo`Co00005_ooool2o`0000cooooo0_l00003ooooo`;o0000Coooool001cooooo00?o
0000ooooooooool0>oooool2o`0000gooooo0_l0000Nooooo`;o00001?ooool2o`000003ooooool0
003o000000?ooooo6ol0000Aooooo`;o00000_ooool2o`0000;ooooo0_l00009ooooo`Ko00003_oo
ool4o`0001Kooooo0_l0000<ooooo`;o00000oooool2o`0004oooooo000Looooo`03o`000?oooooo
oooo04;ooooo0_l00008ooooo`;o00006_ooool4o`0000Cooooo0_l000000ooooooo0000o`000002
oooooa?o00000_ooool<o`000003ooooool0003o000000Wooooo0_l00006ooooo`;o00002_ooool2
o`000003ooooool0003o000001Cooooo0_l0000Cooooo`;o00001_ooool2o`0000Gooooo0_l0001B
ooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o00005Oooool2o`0000?ooooo0_l00003oooo
o`;o00005Oooool2o`0000?ooooo0_l0000=oooooa_o000000?oooooo`000?l000000ol000000ooo
oooo0000o`000003o`0000Oooooo0_l000000ooooooo0000o`00000=ooooo`?o00001Oooool2o`00
00[ooooo0_l00004ooooo`;o00004oooool2o`0000Kooooo0_l00004ooooo`?o000000?oooooo`00
0?l00000Coooool001cooooo00?o0000ooooooooool0:oooool2o`0001[ooooo0_l00005ooooo`;o
00004oooool2o`0000?ooooo0_l00009ooooo`Co00000_ooool8o`000003ooooool0003o0000017o
00001_ooool3o`0000;ooooo1?l000001?oooooo0000o`000?ooool2o`0000gooooo0ol00005oooo
o`;o00002_ooool2o`0000;ooooo0ol0000Rooooo`;o00000_ooool3o`0004kooooo000Looooo`03
o`000?oooooooooo04Cooooo0_l00003ooooo`;o00000oooool2o`0001Sooooo0_l00009ooooo`Co
00000_ooool2o`0000;ooooo1?l000000ooooooo0000o`00000Bo`0000Sooooo2?l0000:ooooo`;o
00007Oooool3o`0001Kooooo0_l0000?ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0
A?ooool2o`0000?ooooo0_l0000Vooooo`Co00001?oooolMo`0000;ooooo1?l000000ooooooo0000
o`000003o`0000;ooooo0ol000000ooooooo0000o`000004ooooo`Co00003Oooool2o`0002Oooooo
0_l0001Oooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00005oooool2o`0002;ooooo0_l0
00001?oooooo0000o`000?ooool2o`0000Gooooo6Ol00002ooooo`;o00000oooool4o`000003oooo
ool0003o000000Co00000_ooool2o`000003ooooool0003o000000Cooooo1?l0000=ooooo`;o0000
2_ooool4o`0001_ooooo0_l00004ooooo`;o00001oooool2o`0004kooooo000Looooo`03o`000?oo
oooooooo02kooooo0_l0000Gooooo`;o00008_ooool5o`0000Sooooo6_l00006ooooo`;o00000_oo
ool2o`000003ooooool0003o000000;o00002oooool4o`0001Sooooo1Ol0000Iooooo`Co00001?oo
ool2o`0000Cooooo0_l000000ooooooo0000o`00001>ooooo`007?ooool00ol0003oooooooooo`11
ooooo`;o00001oooool2o`000003ooooool0003o000001gooooo0_l000000ooooooo0000o`000008
ooooo`;o000000?oooooo`000?l000005?l000000ooooooo0000o`000002o`000003ooooool0003o
000000;ooooo0_l000000ooooooo0000o`00000Yooooo`?o00000_ooool2o`0001Oooooo0_l00006
ooooo`;o00001?ooool2o`00057ooooo000Looooo`03o`000?oooooooooo047ooooo0_l00007oooo
o`;o000000?oooooo`000?l000003Oooool4o`0000Kooooo0ol00003ooooo`;o000000?oooooo`00
0?l000001_oooolKo`000003ooooool0003o000000;o00001?ooool3o`0000_ooooo0_l000001?oo
oooo0000o`000?l00005ooooo`;o00006Oooool2o`00023ooooo0_l00003ooooo`;o0000DOooool0
01cooooo00?o0000ooooooooool0B?ooool2o`0001;ooooo1_l00004ooooo`?o00003_ooool2o`00
0003ooooool0003o000000;o000000?oooooo`000?l000004?l00004ooooo`;o00000oooool3o`00
00Oooooo0_l00003ooooo`Ko000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l00007oooo
o`;o000000?oooooo`000?l000008_ooool2o`0000Gooooo0_l0001Fooooo`007?ooool00ol0003o
ooooooooo`18ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Gooooo0_l00008ooooo`;o
00006Oooool3o`000003ooooool0003o0000013o00002Oooool2o`0000Sooooo0_l00005ooooo`Co
000000Coooooo`000?l0003o00001oooool2o`0000Oooooo0_l000000ooooooo0000o`000004oooo
o`Co00004Oooool2o`0000Oooooo0_l0000>ooooo`;o0000COooool001cooooo00?o0000oooooooo
ool0Boooool2o`0000;ooooo0_l00005ooooo`;o00003Oooool2o`0000Gooooo0ol0000<ooooo`Co
000000?oooooo`000?l000002?l00002ooooo`?o000000Coooooo`000?l0003o00006oooool2o`00
0003ooooool0003o000000oooooo0ol000000ooooooo0000o`000004ooooo`Co00000_ooool2o`00
00Cooooo0_l00007ooooo`;o00005oooool2o`0004gooooo000Looooo`;o0000Eoooool2o`0000go
oooo0_l00005ooooo`?o00001?ooool2o`0000Sooooo0_l000000ooooooo0000o`000008o`0000?o
oooo1_l00003ooooo`;o00005_ooool2o`0001;ooooo0_l00002ooooo`;o00002_ooool2o`0000Co
oooo0_l0000Cooooo`;o00002Oooool3o`0004kooooo000Looooo`03o`000?oooooooooo04[ooooo
0_l0000Nooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000008ooooo`;o
00000_ooool7o`0000Kooooo1Ol00003ooooo`;o00002?ooool4o`0000;ooooo0_l0000]ooooo`;o
00005_ooool3o`0000Sooooo0ol0001>ooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o0000
00?oooooo`000?l000006oooool2o`0000Cooooo0_l0000;ooooo`?o000000?oooooo`000?l00000
1Ol00004ooooo`Co000000?oooooo`000?l000001Oooool2o`0000Kooooo1Ol000000ooooooo0000
o`000009ooooo`Go00000oooool2o`0000gooooo0_l0000:ooooo`?o00003?ooool2o`0000Wooooo
0_l00003ooooo`?o000000Coooooo`000?l0003o0000Coooool001cooooo00?o0000ooooooooool0
COooool3o`0000Gooooo1?l00002ooooo`;o00003_ooool2o`0000Cooooo0_l00004ooooo`;o0000
1?ooool3o`000003ooooool0003o000000So000000?oooooo`000?l000000_l00007ooooo`?o0000
1Oooool2o`0000;ooooo0_l00009ooooo`;o000000?oooooo`000?l000002?l0000=ooooo`;o0000
2_ooool2o`000004ooooool0003o0000ooooo`?o00001_ooool2o`0000Gooooo1_l00003ooooo`?o
000000Coooooo`000?l0003o0000Coooool001cooooo00?o0000ooooooooool0C_ooool2o`0000Go
oooo1?l00002ooooo`;o00002?ooool2o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`0000Co
oooo3_l00006ooooo`;o00001?ooool3o`000003ooooool0003o000000;ooooo1?l0000;ooooo`_o
00002_ooool2o`0001;ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00002_ooool6o`00
05Wooooo000Looooo`03o`000?oooooooooo06?ooooo1?l000001?oooooo0000o`000?l0000:oooo
o`;o00002?ooool2o`0000Gooooo0_l000000ooooooo0000o`000003o`0000?ooooo0_l00004oooo
o`?o000000Goooooo`000?l0003o0000ooooo`04o`0000cooooo2ol00009ooooo`;o00002oooool2
o`0000?ooooo1?l00005ooooo`;o00002_ooool2o`0000Sooooo0_l0001Cooooo`007?ooool00ol0
003oooooooooo`1:ooooo`;o00005oooool2o`0000;ooooo1_l000000ooooooo0000o`000005oooo
o`;o00005?ooool3o`0000Wooooo0ol000001Ooooooo0000o`000?l0003ooooo00;o00002oooool2
o`000003ooooool0003o000000Wo00003?ooool2o`0000Sooooo0_l00003ooooo`;o000000?ooooo
o`000?l000000ol000000ooooooo0000o`00000:ooooo`;o00002?ooool2o`0005?ooooo000Loooo
o`03o`000?oooooooooo03Sooooo0_l0000@ooooo`;o00001?ooool2o`00017ooooo0_l00002oooo
o`?o000000Coooooo`000?l0003ooooo0_l00006ooooo`;o00002_ooool4o`0000;ooooo0_l00003
ooooo`;o00002?ooool2o`0001?ooooo4?l0000:ooooo`;o00004?ooool5o`000003ooooool0003o
000000[ooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00005_ooool2o`00
01Kooooo0_l00002ooooo`;o00002?ooool2o`0000[ooooo1Ol000000ooooooo0000o`000003oooo
o`;o00003_ooool2o`0000Gooooo0_l000000ooooooo0000o`000005oooooa7o00001_ooool3o`00
01Gooooo0_l0000;ooooo`Co00000_ooool2o`0005Oooooo000Looooo`03o`000?oooooooooo06co
oooo0_l00005ooooo`;o00004?ooool2o`0001?ooooo1Ol000000ooooooo0000o`000002ooooo`;o
000000?oooooo`000?l000000_l00003oooooa7o00001_ooool3o`0001Gooooo0_l00009ooooo`;o
00000_ooool2o`0000;ooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`1`ooooo`;o0000
00?oooooo`000?l000003Oooool2o`0000;ooooo0_l0000>ooooo`;o00000_ooool4o`0000;ooooo
0_l00007ooooo`;o00000_ooool>o`0000[ooooo0_l0000Qooooo`;o0000Goooool001cooooo00?o
0000ooooooooool0Eoooool3o`0001;ooooo0_l00002ooooo`;o00001?ooool3o`0000Gooooo0_l0
0002ooooo`;o00000_ooool2o`0000kooooo0_l0000Eooooo`oo00002Oooool2o`0001Kooooo0_l0
0004ooooo`;o00001_ooool2o`0005cooooo000Looooo`03o`000?oooooooooo05Oooooo0ol00006
ooooo`;o00002_ooool3o`000003ooooool0003o000000Cooooo0ol00005ooooo`;o000000?ooooo
o`000?l000000_l0000Zooooo`go00007oooool4o`0000Cooooo0_l00006ooooo`Co0000F_ooool0
01cooooo00?o0000ooooooooool0Foooool2o`0000?ooooo0_l0000;ooooo`;o00004_ooool4o`00
00Wooooo0_l0000Oooooo`go00007oooool2o`00013ooooo0_l0001Jooooo`007?ooool00ol0003o
ooooooooo`1Kooooo`;o00004Oooool2o`00017ooooo0_l000000ooooooo0000o`000008ooooo`;o
00001Oooool2o`0001Sooooo2ol00009ooooo`;o00006Oooool2o`0000;ooooo0_l00007ooooo`;o
0000G?ooool001cooooo00?o0000ooooooooool0K_ooool2o`0000Cooooo0_l00005ooooo`;o0000
1oooool3o`0000kooooo0_l0000:ooooo`Co00002oooool8o`0000_ooooo0_l0000Cooooo`;o0000
1?ooool2o`0000;ooooo0_l00007ooooo`;o0000G?ooool001cooooo0_l0001Qooooo`;o00003ooo
ool2o`000003ooooool0003o000000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000Gooooo
0ol0000Eooooo`?o000000?oooooo`000?l000000_l0000:ooooo`;o00000oooool4o`0000_ooooo
0ol0000Booooo`;o00000oooool3o`0000;ooooo0_l0001Uooooo`007?ooool00ol0003ooooooooo
o`1Pooooo`;o00002?ooool2o`0000Gooooo0_l00005ooooo`;o00000oooool3o`0000?ooooo0_l0
00000ooooooo0000o`000002o`0000Cooooo0_l0000=ooooo`?o00002?ooool2o`0000Gooooo0_l0
00000ooooooo0000o`000003o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`;o00005ooo
ool4o`000003ooooool0003o000006Gooooo000Looooo`03o`000?oooooooooo047ooooo0_l0000O
ooooo`;o00001_ooool2o`00017ooooo0_l00004ooooo`;o00000_ooool3o`0000?ooooo0ol0000E
ooooo`;o000000?oooooo`000?l000000_l00006ooooo`;o000000Coooooo`000?l0003ooooo0_l0
00001?oooooo0000o`000?ooool2o`0000;ooooo0_l0000Iooooo`Co00001?ooool2o`0006;ooooo
000Looooo`03o`000?oooooooooo047ooooo0_l0000Oooooo`;o0000:Oooool3o`0001Gooooo0_l0
0003ooooo`;o00003?ooool2o`0000Sooooo0_l00008ooooo`;o00000oooool2o`0000[ooooo0_l0
0006ooooo`;o0000H_ooool001cooooo00?o0000ooooooooool0X_ooool2o`0000;ooooo0_l00007
ooooo`;o00002?ooool2o`0000Kooooo0ol00006ooooo`Co00000oooool4o`0000Oooooo0_l00002
ooooo`Co0000IOooool001cooooo00?o0000ooooooooool0O?ooool2o`00027ooooo0_l000000ooo
oooo0000o`000002ooooo`Co000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l00003oooo
o`;o00001_ooool2o`0000Oooooo0ol00006ooooo`;o00001oooool2o`0000;ooooo1?l0001Uoooo
o`007?ooool00ol0003oooooooooo`1Wooooo`;o00004oooool2o`0000?ooooo0_l0000:ooooo`;o
000000?oooooo`000?l000000_ooool2o`0000Gooooo0_l000001Ooooooo0000o`000?l0003ooooo
00;o00000oooool6o`0000;ooooo0_l00003ooooo`;o00006Oooool3o`0000Kooooo0_l00007oooo
o`;o0000I_ooool001cooooo00?o0000ooooooooool0Ioooool2o`000004ooooool0003o0000oooo
o`;o00004?ooool4o`0000Kooooo0ol000000ooooooo0000o`000003o`0000;ooooo0_l00005oooo
o`;o000000?oooooo`000?l000000_ooool3o`0000;ooooo1ol000000ooooooo0000o`000002oooo
o`;o000000?oooooo`000?l000005oooool3o`0000Gooooo0ol00008ooooo`;o0000IOooool001co
oooo00?o0000ooooooooool0J_ooool2o`000003ooooool0003o000000?ooooo0_l00004ooooo`;o
00001Oooool2o`0000Sooooo1?l000000ooooooo0000o`00000;ooooo`;o000000?oooooo`000?l0
00000oooool2o`0000;ooooo1ol00003ooooo`Oo00001oooool2o`0000Sooooo0_l000001?oooooo
0000o`000?ooool2o`0000Gooooo0ol00009ooooo`;o0000IOooool001cooooo00?o0000oooooooo
ool0I_ooool2o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`0000oooooo1?l0000>ooooo`;o
00001?ooool2o`0000Kooooo0ol00005ooooo`;o000000?oooooo`000?l000000_l000000ooooooo
0000o`000002ooooo`So000000?oooooo`000?l000000ol000001?oooooo0000o`000?ooool2o`00
00Cooooo1?l0001`ooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00006oooool2o`0000;o
oooo1?l00003ooooo`;o00003_ooool3o`0001gooooo0_l0000Cooooo`;o000000?oooooo`000?l0
00002_l000000ooooooo0000o`000002o`0000_ooooo0_l0001booooo`007?ooool00ol0003ooooo
ooooo`19ooooo`;o00007oooool2o`0000Gooooo0_l0000>ooooo`?o00001?ooool3o`0001Kooooo
0_l0000Hooooo`;o00000_ooool2o`0000?ooooo1_l00005ooooo`;o0000N?ooool001cooooo00?o
0000ooooooooool0OOooool2o`0000Wooooo0ol00005ooooo`;o00003oooool3o`0000Sooooo0_l0
000Fooooo`Co00001oooool2o`0007Sooooo000Looooo`03o`000?oooooooooo06kooooo0_l0000=
ooooo`;o00000oooool2o`000003ooooool0003o000000Wooooo0_l00004ooooo`;o00002_ooool2
o`0000Sooooo0_l0002Kooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0K_ooool2o`0000oooooo
0_l000001?oooooo0000o`000?ooool2o`0000Cooooo0ol000000ooooooo0000o`000005ooooo`Co
00003_ooool2o`0000[ooooo0_l00002ooooo`;o00001_ooool2o`000003ooooool0003o000008Co
oooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B401_ooool00ol0003oooooooooo`1oooooo`;o00000_ooool4o`000004ooooool0003o
0000ooooo`?o000000?oooooo`000?l000001oooool2o`000003ooooool0003o000000_ooooo0_l0
0002ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo0_l00006ooooo`;o000000?o
ooooo`000?l000000ol00002ooooo`;o00002?ooool2o`0000Cooooo0_l0001]ooooo`0000?ooooo
oa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`1dooooo`;o00003Oooool4o`000004ooooool0003o0000ooooo`;o0000
3_ooool9o`000003ooooool0003o000000?ooooo1?l00003ooooo`;o00004?ooool:o`0000Gooooo
2_l0001]ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nH
V9SooooooiRHV?lb<S801_ooool3o`0005;ooooo0_l0000Pooooo`;o00003?ooool2o`0000kooooo
0_l00002ooooo`;o00001?ooool8o`000003ooooool0003o000000?ooooo0ol00002ooooo`;o0000
2oooool3o`0000Cooooo1?l000000ooooooo0000o`000003o`0000Gooooo0_l000000ooooooo0000
o`000003o`0006oooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go
c<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo05;ooooo0_l0000^ooooo`;o0000
2?ooool2o`0000Cooooo0_l00002ooooo`;o00002Oooool2o`0000Gooooo0_l00005ooooo`;o0000
2?ooool2o`000004ooooool0003o0000o`0000Cooooo1_l000000ooooooo0000o`00001mooooo`00
00?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@
41001_ooool00ol0003oooooooooo`1gooooo`;o00004_ooool3o`0000Oooooo0_l000000ooooooo
0000o`000007ooooo`Co00000_ooool3o`0000Kooooo1?l00005ooooo`;o00002_ooool4o`000003
ooooool0003o000007gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj
^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo073ooooo0_l00005ooooo`;o00004_ooool2
o`000004ooooool0003o0000o`0000Cooooo0_l000000ooooooo0000o`000008ooooo`?o00000_oo
ool2o`0000Oooooo1?l0002Eooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`1Fooooo`;o00006?ooool4o`0000Oo
oooo0_l0000Aooooo`?o000000?oooooo`000?l000001?ooool2o`0000Sooooo0_l0000=ooooo`;o
00005_ooool2o`0007kooooo000Looooo`03o`000?oooooooooo05Kooooo0_l000000ooooooo0000
o`00000Gooooo`;o00001oooool2o`0000;ooooo0_l0000Aooooo`;o00002Oooool2o`0000;ooooo
0ol00008ooooo`;o00004?ooool2o`0000Wooooo0_l0001nooooo`007?ooool00ol0003ooooooooo
o`1Iooooo`;o00009?ooool2o`0001cooooo0_l00002ooooo`?o00002?ooool2o`0000cooooo0_l0
0002ooooo`;o0000ROooool001cooooo00?o0000ooooooooool0GOooool2o`0001Gooooo0_l0000>
ooooo`;o00005?ooool2o`0001?ooooo1?l00007ooooo`;o00000oooool2o`0008Sooooo000Loooo
o`03o`000?oooooooooo05gooooo0_l0000Eooooo`;o00003_ooool2o`0001Cooooo0_l0000Coooo
o`Co00003?ooool2o`0008Sooooo000Looooo`03o`000?oooooooooo0:cooooo0_l00005ooooo`;o
0000U?ooool001cooooo00?o0000ooooooooool0W?ooool2o`0000Oooooo0_l00005ooooo`;o0000
1Oooool2o`0009Cooooo000Looooo`03o`000?oooooooooo09cooooo1?l00005ooooo`;o00002ooo
ool2o`0009Gooooo000Looooo`03o`000?oooooooooo09kooooo0_l0000Booooo`;o0000UOooool0
01cooooo00?o0000ooooooooool0Ooooool2o`0001Cooooo0_l0000Iooooo`;o0000Uoooool001co
oooo00?o0000ooooooooool0Ooooool2o`0001Cooooo0_l0000Iooooo`;o00002Oooool5o`0008Wo
oooo000Looooo`03o`000?oooooooooo06Kooooo0_l0001Cooooo`Go0000ROooool001cooooo0_l0
001Wooooo`;o0000hOooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`2aooooo`;o0000U_ooool001cooooo00?o0000ooooooooool0/Oooool2o`0009Ko
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`00
0?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom:
ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool001Co
oooo00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o0000ooooooooool0
oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooo
oooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`004_ooool00omEEEGo
IVIVo`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Uoooo
o`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05Oooool01Oo^k^ko<S8bo`000?l@
413oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oa0@4?o<
c<`0T?ooool00:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00002Oooool01OmEEEGo
MgMgoooooonHV9So8B4Q00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05oeEEEOmgMgOo
oooooiRHV?lQ8B40T?ooool00:Kooooo00Go0000ooooooooooooooooo`00000Hooooo`05o`000?oo
ooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go0000oooooooo
ooooooooo`00002@ooooo`00Y_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l00009oooo
o`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000oiRHV?ooooooV9RHob4Q8@2@ooooo`00Y_ooool01Ol0003oQhN7oooooonYZJWo000001Sooooo
00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003oEEEEo`000?l@413oc<c<093ooooo002Uooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHoooo
ooooool05_ooool00omEEEGoQhN7ooooo`05ooooo`05oa0@4?ooooooooooooooool@41000oooool0
0omEEEGoQhN7ooooo`2Booooo`00`oooool00ooMgMgo410@oiRHV005ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool00ooMgMgo410@oiRHV02Booooo`00a?ooool01?o<c<coA4A4o`000?l@4103
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool01?o<c<coA4A4o`000?l@412@ooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(612) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.41845 .67663 Mdot
.38978 .62196 Mdot
.65073 .46881 Mdot
.4127 .43977 Mdot
.60162 .33896 Mdot
.63992 .4287 Mdot
.63645 .56823 Mdot
.67968 .58382 Mdot
.63595 .41867 Mdot
.20454 .55707 Mdot
.66992 .5862 Mdot
.37745 .52477 Mdot
.64498 .58327 Mdot
.37862 .45471 Mdot
.55514 .68281 Mdot
.31763 .44323 Mdot
.40358 .60751 Mdot
.5382 .29261 Mdot
.31735 .44849 Mdot
.63846 .46667 Mdot
.48167 .4926 Mdot
.37923 .445 Mdot
.40304 .61099 Mdot
.37846 .4512 Mdot
.41692 .40925 Mdot
.40171 .62943 Mdot
.4055 .68216 Mdot
.39107 .40756 Mdot
.36678 .41032 Mdot
.66382 .59528 Mdot
.64395 .26453 Mdot
.52273 .8466 Mdot
.33777 .47777 Mdot
.33675 .56121 Mdot
.67816 .57092 Mdot
.80958 .47647 Mdot
.62554 .40597 Mdot
.67375 .59834 Mdot
.65618 .54565 Mdot
.64906 .53954 Mdot
.62738 .5782 Mdot
.39444 .63303 Mdot
.61853 .56433 Mdot
.62391 .36852 Mdot
.41241 .47311 Mdot
.46737 .79439 Mdot
.64847 .23575 Mdot
.38817 .40945 Mdot
.42824 .6598 Mdot
.63696 .46067 Mdot
.29861 .30326 Mdot
.66545 .60956 Mdot
.55662 .74757 Mdot
.11865 .61334 Mdot
.65914 .59189 Mdot
.40374 .42815 Mdot
.62268 .44211 Mdot
.40332 .45146 Mdot
.3814 .42145 Mdot
.31177 .51972 Mdot
.36262 .42705 Mdot
.5628 .30931 Mdot
.3994 .68756 Mdot
.61506 .45938 Mdot
.63389 .42284 Mdot
.64019 .60104 Mdot
.37023 .6454 Mdot
.63675 .58566 Mdot
.42238 .49995 Mdot
.64997 .46285 Mdot
.39116 .41383 Mdot
.67099 .58977 Mdot
.3802 .62212 Mdot
.43578 .43011 Mdot
.49282 .76328 Mdot
.70299 .57033 Mdot
.54234 .33373 Mdot
.30285 .65033 Mdot
.19322 .4071 Mdot
.70862 .46428 Mdot
.36865 .45774 Mdot
.17926 .38568 Mdot
.55958 .67378 Mdot
.37982 .6335 Mdot
.37734 .56172 Mdot
.74446 .65832 Mdot
.3656 .40758 Mdot
.51654 .39024 Mdot
.34568 .40924 Mdot
.49966 .59098 Mdot
.62974 .4163 Mdot
.4082 .62371 Mdot
.41391 .47253 Mdot
.38921 .3922 Mdot
.24528 .44314 Mdot
.36774 .49448 Mdot
.41376 .46298 Mdot
.41073 .5819 Mdot
.66224 .57143 Mdot
.45551 .47598 Mdot
.65282 .36574 Mdot
.52628 .74322 Mdot
.42149 .43951 Mdot
.65891 .43244 Mdot
.43303 .6682 Mdot
.42029 .46207 Mdot
.64774 .60013 Mdot
.36697 .44282 Mdot
.68648 .56394 Mdot
.42066 .62494 Mdot
.38159 .39486 Mdot
.56112 .32802 Mdot
.5061 .66882 Mdot
.41342 .66659 Mdot
.22958 .65771 Mdot
.36575 .42778 Mdot
.38011 .43245 Mdot
.38358 .63097 Mdot
.61238 .43952 Mdot
.52979 .4354 Mdot
.3929 .6106 Mdot
.6522 .54286 Mdot
.42773 .63115 Mdot
.37439 .38881 Mdot
.61469 .44587 Mdot
.52515 .73284 Mdot
.52819 .75161 Mdot
.54913 .21954 Mdot
.43344 .41802 Mdot
.52716 .69919 Mdot
.64704 .44026 Mdot
.3914 .62909 Mdot
.64172 .59006 Mdot
.34375 .44021 Mdot
.38986 .66617 Mdot
.65769 .55132 Mdot
.58414 .30553 Mdot
.60709 .33151 Mdot
.3951 .67634 Mdot
.40593 .33717 Mdot
.68412 .59863 Mdot
.64425 .53959 Mdot
.31575 .29667 Mdot
.37857 .6403 Mdot
.57201 .28364 Mdot
.645 .55076 Mdot
.44947 .26441 Mdot
.34834 .4547 Mdot
.40294 .23252 Mdot
.21269 .32351 Mdot
.30611 .29996 Mdot
.3741 .76337 Mdot
.54799 .30311 Mdot
.64161 .55054 Mdot
.40954 .42085 Mdot
.3925 .65441 Mdot
.38784 .65002 Mdot
.40004 .38892 Mdot
.40778 .39846 Mdot
.38588 .47407 Mdot
.34743 .43454 Mdot
.77682 .35991 Mdot
.37861 .47344 Mdot
.56775 .60536 Mdot
.39691 .66892 Mdot
.42265 .40799 Mdot
.66103 .41615 Mdot
.44239 .42896 Mdot
.67387 .59749 Mdot
.38864 .42647 Mdot
.40871 .40231 Mdot
.40315 .49334 Mdot
.62807 .55417 Mdot
.62306 .79087 Mdot
.17292 .47589 Mdot
.78415 .5652 Mdot
.42904 .73823 Mdot
.63722 .44456 Mdot
.36126 .46025 Mdot
.5551 .28498 Mdot
.4395 .51636 Mdot
.37657 .42285 Mdot
.27962 .31417 Mdot
.39327 .40055 Mdot
.32237 .70308 Mdot
.46149 .40518 Mdot
.77564 .63638 Mdot
.58483 .64304 Mdot
.36026 .42348 Mdot
.21069 .47564 Mdot
.4308 .21174 Mdot
.60495 .22986 Mdot
.65166 .59564 Mdot
.65498 .40453 Mdot
.61433 .42151 Mdot
.63837 .53587 Mdot
.45838 .4243 Mdot
.2116 .5775 Mdot
.43536 .48895 Mdot
.52841 .73135 Mdot
.38167 .6962 Mdot
.54438 .29856 Mdot
.39775 .67729 Mdot
.15219 .42989 Mdot
.5118 .44927 Mdot
.6722 .52345 Mdot
.53807 .30514 Mdot
.66763 .4454 Mdot
.53982 .7269 Mdot
.56195 .27943 Mdot
.41258 .45521 Mdot
.42714 .64093 Mdot
.42656 .2123 Mdot
.34237 .39035 Mdot
.83784 .37869 Mdot
.3735 .64667 Mdot
.5329 .5537 Mdot
.65166 .59231 Mdot
.60501 .4389 Mdot
.36757 .40689 Mdot
.39396 .46406 Mdot
.40362 .68613 Mdot
.38204 .40893 Mdot
.48325 .52864 Mdot
.40409 .403 Mdot
.59606 .42534 Mdot
.53497 .26305 Mdot
.65219 .52975 Mdot
.53899 .21907 Mdot
.38306 .61617 Mdot
.57103 .53177 Mdot
.66131 .42663 Mdot
.45454 .63991 Mdot
.66753 .59678 Mdot
.58148 .31541 Mdot
.63969 .40429 Mdot
.58609 .32338 Mdot
.42567 .46398 Mdot
.62656 .40885 Mdot
.5747 .31087 Mdot
.6238 .49779 Mdot
.41558 .46163 Mdot
.40754 .25629 Mdot
.63995 .55618 Mdot
.40478 .68097 Mdot
.36279 .42443 Mdot
.5186 .73853 Mdot
.41522 .38776 Mdot
.53622 .69271 Mdot
.5252 .72485 Mdot
.5532 .73338 Mdot
.68659 .52422 Mdot
.56325 .27361 Mdot
.45194 .76198 Mdot
.52905 .45881 Mdot
.40157 .6069 Mdot
.40204 .48447 Mdot
.68298 .76635 Mdot
.63594 .55658 Mdot
.41177 .45252 Mdot
.75146 .64458 Mdot
.64394 .5513 Mdot
.39652 .44569 Mdot
.62604 .576 Mdot
.38898 .6541 Mdot
.5652 .48696 Mdot
.42552 .61797 Mdot
.40979 .44001 Mdot
.65062 .56763 Mdot
.64736 .40204 Mdot
.40198 .63057 Mdot
.36864 .43826 Mdot
.36935 .46323 Mdot
.53505 .73041 Mdot
.42233 .4038 Mdot
.71924 .73242 Mdot
.39096 .41022 Mdot
.66838 .44588 Mdot
.3621 .49162 Mdot
.4049 .2167 Mdot
.60935 .31978 Mdot
.36718 .65631 Mdot
.53252 .72228 Mdot
.62323 .42031 Mdot
.57766 .46391 Mdot
.59678 .25898 Mdot
.3696 .4516 Mdot
.53537 .74627 Mdot
.53765 .55162 Mdot
.64625 .60322 Mdot
.33679 .43896 Mdot
.50335 .49132 Mdot
.64024 .41185 Mdot
.5347 .72802 Mdot
.43425 .38269 Mdot
.43558 .65225 Mdot
.40492 .42632 Mdot
.63106 .40287 Mdot
.43307 .65397 Mdot
.34283 .43871 Mdot
.73258 .30871 Mdot
.52064 .74149 Mdot
.63717 .55979 Mdot
.29785 .40518 Mdot
.37952 .47805 Mdot
.61257 .42057 Mdot
.38634 .66199 Mdot
.66116 .58261 Mdot
.42298 .64354 Mdot
.46384 .19933 Mdot
.45668 .71695 Mdot
.76548 .41199 Mdot
.54341 .27379 Mdot
.37221 .80312 Mdot
.7952 .53899 Mdot
.47116 .70657 Mdot
.51451 .2728 Mdot
.8251 .55448 Mdot
.65442 .41095 Mdot
.28891 .36569 Mdot
.61997 .43036 Mdot
.41674 .42952 Mdot
.63898 .426 Mdot
.74785 .71091 Mdot
.39394 .40461 Mdot
.63222 .44617 Mdot
.7636 .36344 Mdot
.38622 .39937 Mdot
.39993 .67148 Mdot
.51854 .82885 Mdot
.25719 .67963 Mdot
.46975 .37353 Mdot
.63056 .4489 Mdot
.25371 .39292 Mdot
.38018 .40526 Mdot
.32161 .4185 Mdot
.39653 .64883 Mdot
.35251 .40033 Mdot
.54797 .31519 Mdot
.57806 .33023 Mdot
.31632 .30745 Mdot
.28199 .70763 Mdot
.31891 .39778 Mdot
.39742 .63557 Mdot
.19738 .39553 Mdot
.49498 .76781 Mdot
.52651 .75343 Mdot
.66654 .55548 Mdot
.62122 .78936 Mdot
.40925 .36701 Mdot
.36119 .34425 Mdot
.49372 .54033 Mdot
.40598 .61985 Mdot
.78118 .48825 Mdot
.65665 .57884 Mdot
.19786 .4749 Mdot
.23955 .58542 Mdot
.39183 .47572 Mdot
.63041 .60111 Mdot
.41628 .51356 Mdot
.48737 .5383 Mdot
.40179 .24802 Mdot
.73125 .40931 Mdot
.41576 .45009 Mdot
.46124 .76472 Mdot
.38103 .42647 Mdot
.428 .21801 Mdot
.41039 .44506 Mdot
.42165 .65031 Mdot
.36853 .35789 Mdot
.55476 .4047 Mdot
.17534 .54687 Mdot
.50851 .45968 Mdot
.55419 .27675 Mdot
.38163 .45748 Mdot
.39525 .47087 Mdot
.56668 .31475 Mdot
.41289 .63549 Mdot
.3878 .48669 Mdot
.65243 .23419 Mdot
.38448 .47769 Mdot
.6634 .60882 Mdot
.561 .46188 Mdot
.32529 .72229 Mdot
.37254 .40062 Mdot
.43343 .65999 Mdot
.63822 .5962 Mdot
.67225 .56638 Mdot
.34094 .37711 Mdot
.63185 .55894 Mdot
.40269 .41866 Mdot
.56054 .46726 Mdot
.4079 .61287 Mdot
.42614 .51913 Mdot
.41397 .64144 Mdot
.23515 .34135 Mdot
.62469 .55892 Mdot
.54482 .74926 Mdot
.30162 .35484 Mdot
.64452 .57201 Mdot
.437 .58076 Mdot
.42363 .36652 Mdot
.44496 .44194 Mdot
.4343 .71681 Mdot
.62437 .39823 Mdot
.54996 .73927 Mdot
.66168 .58926 Mdot
.38242 .47589 Mdot
.42433 .45369 Mdot
.64472 .60991 Mdot
.27241 .48246 Mdot
.64842 .27 Mdot
.40599 .438 Mdot
.42048 .64519 Mdot
.39267 .62961 Mdot
.35768 .47138 Mdot
.37333 .42339 Mdot
.66988 .43249 Mdot
.53659 .74755 Mdot
.54707 .72759 Mdot
.53294 .7526 Mdot
.61589 .39579 Mdot
.34777 .78969 Mdot
.64417 .53981 Mdot
.41482 .80339 Mdot
.7009 .69754 Mdot
.33117 .38908 Mdot
.61631 .40986 Mdot
.39466 .45404 Mdot
.42518 .43968 Mdot
.65479 .56947 Mdot
.2688 .7153 Mdot
.36365 .50877 Mdot
.3896 .67923 Mdot
.65505 .61032 Mdot
.41307 .53244 Mdot
.70512 .59119 Mdot
.56162 .32382 Mdot
.50398 .44025 Mdot
.63224 .60395 Mdot
.4239 .63608 Mdot
.63859 .60877 Mdot
.39239 .47255 Mdot
.44848 .41911 Mdot
.40149 .61614 Mdot
.57117 .2725 Mdot
.41832 .47092 Mdot
.39517 .44361 Mdot
.45216 .17436 Mdot
.48961 .76286 Mdot
.65884 .49691 Mdot
.42218 .42176 Mdot
.42545 .48407 Mdot
.57432 .27147 Mdot
.38219 .48165 Mdot
.36229 .41295 Mdot
.50689 .65836 Mdot
.65789 .5352 Mdot
.56112 .3386 Mdot
.18895 .4897 Mdot
.37383 .65582 Mdot
.73149 .71233 Mdot
.52444 .74103 Mdot
.66589 .53915 Mdot
.56525 .49334 Mdot
.54661 .73785 Mdot
.72896 .6503 Mdot
.76777 .58911 Mdot
.54393 .74711 Mdot
.65026 .47794 Mdot
.47632 .46867 Mdot
.34779 .4251 Mdot
.39204 .43237 Mdot
.56894 .27601 Mdot
.37915 .65311 Mdot
.5711 .62294 Mdot
.62454 .52262 Mdot
.37914 .43981 Mdot
.3987 .5953 Mdot
.75983 .64719 Mdot
.53997 .7291 Mdot
.55054 .29294 Mdot
.55236 .27215 Mdot
.38182 .42907 Mdot
.48385 .6469 Mdot
.39831 .63226 Mdot
.36879 .43833 Mdot
.34966 .44693 Mdot
.61837 .44452 Mdot
.42721 .64961 Mdot
.66327 .42992 Mdot
.52299 .72483 Mdot
.84345 .48149 Mdot
.47493 .16606 Mdot
.65091 .55761 Mdot
.79052 .52455 Mdot
.63886 .61602 Mdot
.73129 .43604 Mdot
.53939 .74878 Mdot
.3732 .4402 Mdot
.37556 .62154 Mdot
.36675 .44063 Mdot
.3952 .48047 Mdot
.40787 .47293 Mdot
.31484 .40449 Mdot
.28652 .30649 Mdot
.55733 .29232 Mdot
.39677 .50633 Mdot
.67193 .41957 Mdot
.7702 .63744 Mdot
.54883 .8152 Mdot
.38537 .4636 Mdot
.38233 .43487 Mdot
.37123 .66005 Mdot
.43275 .45222 Mdot
.65506 .60204 Mdot
.37593 .64243 Mdot
.42189 .4471 Mdot
.61879 .33575 Mdot
.3745 .48081 Mdot
.79647 .51401 Mdot
.63813 .60889 Mdot
.50032 .43929 Mdot
.43828 .47038 Mdot
.54258 .74918 Mdot
.54953 .74016 Mdot
.51704 .74107 Mdot
.6377 .60343 Mdot
.61675 .44069 Mdot
.68198 .42216 Mdot
.44235 .39103 Mdot
.40781 .41844 Mdot
.44489 .44671 Mdot
.61948 .39076 Mdot
.53966 .43187 Mdot
.39849 .76005 Mdot
.45821 .39614 Mdot
.64796 .39572 Mdot
.39826 .5845 Mdot
.18596 .60511 Mdot
.37639 .65548 Mdot
.52656 .29674 Mdot
.67327 .59425 Mdot
.55228 .32033 Mdot
.25946 .34477 Mdot
.40792 .61501 Mdot
.39886 .68523 Mdot
.63525 .44601 Mdot
.53956 .60276 Mdot
.19586 .73567 Mdot
.6552 .43598 Mdot
.52667 .26083 Mdot
.39813 .64361 Mdot
.34953 .49652 Mdot
.53962 .55343 Mdot
.53061 .59476 Mdot
.628 .43708 Mdot
.36771 .45947 Mdot
.44828 .59058 Mdot
.66947 .43414 Mdot
.33559 .45347 Mdot
.63343 .45135 Mdot
.62654 .56467 Mdot
.6465 .44393 Mdot
.36949 .61601 Mdot
.42732 .45882 Mdot
.13318 .64684 Mdot
.55698 .66368 Mdot
.36206 .43328 Mdot
.6564 .61114 Mdot
.75309 .31656 Mdot
.40206 .4709 Mdot
.54449 .31176 Mdot
.64455 .3928 Mdot
.72892 .347 Mdot
.37231 .41084 Mdot
.63321 .43102 Mdot
.35823 .64845 Mdot
.66708 .38123 Mdot
.69272 .46829 Mdot
.5494 .73205 Mdot
.38974 .65802 Mdot
.52873 .70658 Mdot
.67612 .56579 Mdot
.41097 .48399 Mdot
.35729 .46085 Mdot
.40908 .66492 Mdot
.714 .59112 Mdot
.36315 .49896 Mdot
.36892 .4578 Mdot
.6672 .43721 Mdot
.65941 .39548 Mdot
.58461 .72008 Mdot
.65706 .41174 Mdot
.42283 .48717 Mdot
.41262 .6629 Mdot
.41289 .43113 Mdot
.39309 .67197 Mdot
.405 .4824 Mdot
.37856 .73011 Mdot
.37738 .65549 Mdot
.4562 .69596 Mdot
.41571 .39614 Mdot
.30015 .45765 Mdot
.39229 .48247 Mdot
.41365 .459 Mdot
.63669 .39049 Mdot
.56846 .29489 Mdot
.3321 .44073 Mdot
.57582 .51135 Mdot
.58646 .28891 Mdot
.33656 .61695 Mdot
.61276 .43876 Mdot
.58133 .28551 Mdot
.40966 .28976 Mdot
.53291 .72231 Mdot
.55944 .30323 Mdot
.58351 .76958 Mdot
.65072 .5593 Mdot
.41419 .61149 Mdot
.3922 .39753 Mdot
.83575 .5383 Mdot
.64414 .26536 Mdot
.53756 .73354 Mdot
.36548 .42427 Mdot
.39845 .45679 Mdot
.4353 .64385 Mdot
.16591 .408 Mdot
.59978 .43448 Mdot
.4181 .4485 Mdot
.39537 .61125 Mdot
.20248 .34874 Mdot
.63978 .45317 Mdot
.55477 .30228 Mdot
.62595 .60168 Mdot
.38945 .7052 Mdot
.55148 .73696 Mdot
.62346 .56028 Mdot
.60543 .47063 Mdot
.25791 .32947 Mdot
.37449 .41129 Mdot
.62744 .39928 Mdot
.3043 .30063 Mdot
.46325 .43238 Mdot
.631 .61671 Mdot
.36396 .71314 Mdot
.40551 .62081 Mdot
.64721 .61012 Mdot
.55249 .27665 Mdot
.41088 .61246 Mdot
.41357 .63466 Mdot
.6793 .58296 Mdot
.59579 .6293 Mdot
.53348 .55803 Mdot
.66555 .60419 Mdot
.51552 .61886 Mdot
.32516 .29331 Mdot
.5335 .74842 Mdot
.55004 .29299 Mdot
.46939 .19316 Mdot
.39667 .63084 Mdot
.62224 .78928 Mdot
.28636 .30993 Mdot
.41387 .46252 Mdot
.57854 .29828 Mdot
.7297 .66431 Mdot
.61961 .51899 Mdot
.65623 .55147 Mdot
.53014 .40092 Mdot
.54295 .2942 Mdot
.35535 .46375 Mdot
.31841 .716 Mdot
.39201 .39476 Mdot
.63928 .55268 Mdot
.48012 .54865 Mdot
.42588 .65363 Mdot
.67365 .56122 Mdot
.48612 .51901 Mdot
.42498 .43625 Mdot
.35578 .43408 Mdot
.48402 .21607 Mdot
.42858 .64792 Mdot
.55245 .73809 Mdot
.36475 .44785 Mdot
.40287 .44874 Mdot
.40093 .49128 Mdot
.31521 .34465 Mdot
.48696 .6805 Mdot
.4193 .45169 Mdot
.60302 .41998 Mdot
.44546 .43109 Mdot
.3581 .42284 Mdot
.43115 .62351 Mdot
.37947 .22581 Mdot
.52041 .7269 Mdot
.39526 .43534 Mdot
.40525 .43795 Mdot
.65654 .54433 Mdot
.53567 .55529 Mdot
.52899 .59826 Mdot
.65791 .45575 Mdot
.50261 .28588 Mdot
.44246 .47677 Mdot
.39419 .66429 Mdot
.55358 .32443 Mdot
.41552 .48839 Mdot
.37661 .66336 Mdot
.45459 .43297 Mdot
.67149 .43277 Mdot
.53739 .74545 Mdot
.36308 .34906 Mdot
.56371 .30513 Mdot
.68996 .57982 Mdot
.45178 .81995 Mdot
.66313 .41638 Mdot
.41169 .41299 Mdot
.64975 .37951 Mdot
.65316 .42152 Mdot
.53374 .732 Mdot
.39987 .37602 Mdot
.39014 .64734 Mdot
.42542 .64902 Mdot
.36177 .26883 Mdot
.60283 .40657 Mdot
.32354 .22286 Mdot
.62702 .56348 Mdot
.34111 .42856 Mdot
.54172 .80303 Mdot
.42295 .65772 Mdot
.47471 .20475 Mdot
.58031 .28285 Mdot
.65642 .55188 Mdot
.53802 .71808 Mdot
.37889 .66555 Mdot
.4185 .66725 Mdot
.41009 .4751 Mdot
.38641 .45579 Mdot
.52128 .25968 Mdot
.41633 .22296 Mdot
.62642 .57507 Mdot
.55305 .30737 Mdot
.65006 .4594 Mdot
.42223 .42882 Mdot
.38861 .62071 Mdot
.3145 .6948 Mdot
.37509 .47495 Mdot
.66956 .43777 Mdot
.40013 .61993 Mdot
.55975 .31551 Mdot
.58172 .30651 Mdot
.41307 .46215 Mdot
.32018 .61901 Mdot
.64088 .57125 Mdot
.40827 .66911 Mdot
.39862 .56947 Mdot
.36709 .49607 Mdot
.38469 .45977 Mdot
.39456 .5274 Mdot
.62607 .55248 Mdot
.3717 .34747 Mdot
.56201 .2643 Mdot
.38372 .64783 Mdot
.36283 .43807 Mdot
.56244 .30918 Mdot
.32116 .35683 Mdot
.54362 .74179 Mdot
.63725 .45146 Mdot
.54534 .31089 Mdot
.57416 .30176 Mdot
.58794 .30138 Mdot
.611 .79265 Mdot
.43667 .66228 Mdot
.18319 .48683 Mdot
.40352 .47944 Mdot
.33259 .29078 Mdot
.43499 .41413 Mdot
.62333 .57959 Mdot
.64938 .40076 Mdot
.39312 .47902 Mdot
.40913 .47652 Mdot
.33434 .72157 Mdot
.38855 .54074 Mdot
.47748 .49471 Mdot
.42427 .63065 Mdot
.28945 .41301 Mdot
.61163 .41696 Mdot
.20583 .31858 Mdot
.59987 .82857 Mdot
.42901 .494 Mdot
.54255 .59409 Mdot
.37694 .63943 Mdot
.64929 .54734 Mdot
.52379 .58481 Mdot
.64798 .5218 Mdot
.3831 .64144 Mdot
.41981 .43104 Mdot
.41898 .80153 Mdot
.58714 .3177 Mdot
.38517 .47264 Mdot
.64315 .59365 Mdot
.38549 .47332 Mdot
.63117 .59634 Mdot
.41097 .70202 Mdot
.53177 .6249 Mdot
.39268 .40134 Mdot
.38025 .50073 Mdot
.41665 .35367 Mdot
.38643 .46148 Mdot
.72555 .53128 Mdot
.40768 .64155 Mdot
.45527 .6876 Mdot
.362 .47752 Mdot
.30893 .60036 Mdot
.36407 .4705 Mdot
.71656 .59969 Mdot
.3544 .45356 Mdot
.4603 .34643 Mdot
.35207 .45994 Mdot
.35989 .45857 Mdot
.65657 .57576 Mdot
.65395 .54477 Mdot
.35933 .65448 Mdot
.55114 .7459 Mdot
.77481 .63629 Mdot
.38899 .44046 Mdot
.63578 .38855 Mdot
.56306 .77173 Mdot
.57226 .29735 Mdot
.38562 .6403 Mdot
.28866 .21666 Mdot
.63145 .58874 Mdot
.61828 .46336 Mdot
.69707 .51027 Mdot
.61223 .45034 Mdot
.59274 .41465 Mdot
.31321 .48508 Mdot
.55013 .30538 Mdot
.3586 .46589 Mdot
.33626 .58389 Mdot
.47511 .76554 Mdot
.33989 .4618 Mdot
.6762 .4001 Mdot
.4095 .53827 Mdot
.32638 .29001 Mdot
.59206 .31312 Mdot
.54591 .29722 Mdot
.6605 .58564 Mdot
.64015 .46977 Mdot
.45713 .46677 Mdot
.5824 .28801 Mdot
.65637 .40471 Mdot
.53833 .75732 Mdot
.56774 .24028 Mdot
.3947 .63489 Mdot
.462 .36706 Mdot
.50104 .80176 Mdot
.62832 .58222 Mdot
.57426 .50567 Mdot
.433 .6131 Mdot
.39942 .69483 Mdot
.54432 .75236 Mdot
.66913 .41071 Mdot
.40186 .60581 Mdot
.42086 .46677 Mdot
.34395 .389 Mdot
.37964 .4272 Mdot
.57813 .28497 Mdot
.35021 .43789 Mdot
.66841 .41375 Mdot
.6317 .5711 Mdot
.63158 .41452 Mdot
.63973 .56762 Mdot
.40551 .78438 Mdot
.37354 .41947 Mdot
.3833 .45638 Mdot
.55621 .48872 Mdot
.40693 .67567 Mdot
.31925 .53824 Mdot
.66887 .40885 Mdot
.6205 .4385 Mdot
.41482 .43296 Mdot
.36927 .67208 Mdot
.54538 .32748 Mdot
.54501 .55979 Mdot
.35246 .45212 Mdot
.40754 .64291 Mdot
.4087 .42983 Mdot
.74089 .38905 Mdot
.5391 .65427 Mdot
.42379 .64689 Mdot
.17521 .55692 Mdot
.42559 .4063 Mdot
.41311 .54444 Mdot
.32346 .47121 Mdot
.49199 .32775 Mdot
.33429 .45982 Mdot
.3743 .64171 Mdot
.38573 .42351 Mdot
.39562 .66037 Mdot
.65529 .41812 Mdot
.6431 .54265 Mdot
.39483 .65574 Mdot
.39681 .39202 Mdot
.57074 .83322 Mdot
.63321 .58714 Mdot
.37591 .46296 Mdot
.66741 .58635 Mdot
.41261 .60678 Mdot
.42004 .6708 Mdot
.59226 .74812 Mdot
.67611 .52269 Mdot
.63878 .59356 Mdot
.40465 .41773 Mdot
.52596 .78171 Mdot
.41237 .43046 Mdot
.52194 .2535 Mdot
.35185 .47016 Mdot
.35643 .48773 Mdot
.38689 .81231 Mdot
.6644 .52468 Mdot
.30369 .2252 Mdot
.60809 .54819 Mdot
.59895 .79704 Mdot
.44419 .66369 Mdot
.59194 .31405 Mdot
.78463 .53062 Mdot
.5221 .72836 Mdot
.60528 .41955 Mdot
.39211 .47938 Mdot
.35795 .73014 Mdot
.66007 .60784 Mdot
.566 .28986 Mdot
.39339 .40088 Mdot
.66553 .45937 Mdot
.5732 .7814 Mdot
.64393 .54975 Mdot
.393 .63443 Mdot
.40089 .67791 Mdot
.18302 .42805 Mdot
.36362 .43426 Mdot
.38261 .44969 Mdot
.67319 .59666 Mdot
.46028 .44898 Mdot
.58383 .31765 Mdot
.76079 .38517 Mdot
.64789 .59589 Mdot
.54971 .66823 Mdot
.42254 .62667 Mdot
.39688 .45594 Mdot
.56125 .4575 Mdot
.65264 .73995 Mdot
.21678 .49848 Mdot
.56392 .27703 Mdot
.50089 .24206 Mdot
.37416 .64231 Mdot
.64387 .59172 Mdot
.34771 .29736 Mdot
.38641 .38898 Mdot
.40052 .45562 Mdot
.49785 .23348 Mdot
.54113 .56564 Mdot
.58358 .25916 Mdot
.33846 .48804 Mdot
.53747 .52974 Mdot
.41638 .43392 Mdot
.42457 .45308 Mdot
.42749 .49667 Mdot
.35641 .42118 Mdot
.40491 .64975 Mdot
.26971 .67903 Mdot
.64187 .43394 Mdot
.23412 .43181 Mdot
.52718 .38681 Mdot
.37416 .40475 Mdot
.42238 .43396 Mdot
.23297 .64089 Mdot
.56558 .75155 Mdot
.40501 .639 Mdot
.40821 .57564 Mdot
.64505 .53823 Mdot
.38539 .5394 Mdot
.6074 .40127 Mdot
.46815 .50158 Mdot
.64386 .41895 Mdot
.40807 .64404 Mdot
.61519 .4353 Mdot
.65701 .53896 Mdot
.62784 .39935 Mdot
.61255 .39907 Mdot
.61796 .57122 Mdot
.431 .64827 Mdot
.36417 .46464 Mdot
.62462 .56104 Mdot
.49427 .2114 Mdot
.57873 .28607 Mdot
.59059 .75098 Mdot
.35295 .50028 Mdot
.41918 .54517 Mdot
.7313 .30766 Mdot
.62242 .4144 Mdot
.51911 .67183 Mdot
.37761 .6558 Mdot
.54799 .32317 Mdot
.402 .65445 Mdot
.26033 .36341 Mdot
.57 .3098 Mdot
.58985 .75473 Mdot
.36458 .2894 Mdot
.60292 .49518 Mdot
.42277 .39277 Mdot
.43413 .70983 Mdot
.64408 .41692 Mdot
.66345 .6092 Mdot
.74216 .65406 Mdot
.43345 .42276 Mdot
.46891 .71592 Mdot
.42435 .68596 Mdot
.53788 .72277 Mdot
.64027 .5883 Mdot
.60779 .59808 Mdot
.36573 .43086 Mdot
.59414 .48944 Mdot
.34894 .47638 Mdot
.29501 .35917 Mdot
.50777 .27114 Mdot
.36643 .70847 Mdot
.4036 .42461 Mdot
.66352 .44652 Mdot
.40725 .42689 Mdot
.47137 .4097 Mdot
.31287 .30084 Mdot
.39673 .50368 Mdot
.45231 .71481 Mdot
.73014 .33522 Mdot
.39708 .61729 Mdot
.41742 .49352 Mdot
.53202 .74037 Mdot
.42526 .41838 Mdot
.87312 .51002 Mdot
.56104 .30059 Mdot
.63032 .48661 Mdot
.40255 .39075 Mdot
.36558 .44467 Mdot
.31821 .66006 Mdot
.44246 .69249 Mdot
.53273 .71864 Mdot
.40436 .45818 Mdot
.49066 .2564 Mdot
.66117 .57986 Mdot
.34214 .44251 Mdot
.38716 .42734 Mdot
.51373 .18579 Mdot
.66322 .57916 Mdot
.61959 .41267 Mdot
.5299 .72308 Mdot
.65257 .45683 Mdot
.58808 .32735 Mdot
.512 .58559 Mdot
.45393 .20755 Mdot
.53875 .65688 Mdot
.5415 .30397 Mdot
.36085 .40834 Mdot
.38286 .5695 Mdot
.35809 .44323 Mdot
.54675 .29047 Mdot
.66421 .59504 Mdot
.40274 .64897 Mdot
.43002 .34547 Mdot
.5288 .73202 Mdot
.34125 .46819 Mdot
.5921 .29697 Mdot
.39267 .65167 Mdot
.61396 .71765 Mdot
.37953 .64429 Mdot
.64803 .57217 Mdot
.64568 .53516 Mdot
.56938 .30381 Mdot
.40408 .65257 Mdot
.63141 .45544 Mdot
.60762 .55311 Mdot
.35059 .47187 Mdot
.62253 .52773 Mdot
.36383 .63514 Mdot
.40329 .68284 Mdot
.36996 .63192 Mdot
.37292 .41636 Mdot
.54094 .57627 Mdot
.40603 .38641 Mdot
.64389 .5996 Mdot
.6099 .43796 Mdot
.39602 .23846 Mdot
.33225 .58452 Mdot
.55006 .6661 Mdot
.33173 .44603 Mdot
.35506 .43042 Mdot
.38164 .42929 Mdot
.4019 .43014 Mdot
.76021 .39433 Mdot
.37474 .41965 Mdot
.64636 .5654 Mdot
.65036 .4269 Mdot
.36379 .42647 Mdot
.53288 .74312 Mdot
.53166 .45052 Mdot
.55203 .32268 Mdot
.47568 .35138 Mdot
.6051 .81544 Mdot
.39411 .65074 Mdot
.64047 .40224 Mdot
.61802 .44818 Mdot
.5841 .30585 Mdot
.6283 .55728 Mdot
.37976 .65206 Mdot
.46261 .3217 Mdot
.58718 .2883 Mdot
.39623 .43622 Mdot
.55946 .47439 Mdot
.17893 .57827 Mdot
.36347 .40408 Mdot
.4085 .4691 Mdot
.55026 .72835 Mdot
.60872 .44892 Mdot
.84225 .57979 Mdot
.58614 .63062 Mdot
.56877 .29729 Mdot
.55937 .31918 Mdot
.37375 .62999 Mdot
.33799 .43835 Mdot
.63734 .57204 Mdot
.53922 .54077 Mdot
.73134 .29397 Mdot
.7385 .68433 Mdot
.72857 .44481 Mdot
.37712 .48228 Mdot
.27927 .65337 Mdot
.38407 .49234 Mdot
.43359 .66735 Mdot
.36849 .64577 Mdot
.40128 .63657 Mdot
.65651 .57732 Mdot
.23697 .34354 Mdot
.64447 .56374 Mdot
.6062 .81649 Mdot
.39632 .61306 Mdot
.57333 .40919 Mdot
.62364 .44409 Mdot
.42243 .38119 Mdot
.54964 .30256 Mdot
.68699 .40406 Mdot
.42604 .48613 Mdot
.48043 .65242 Mdot
.61637 .40991 Mdot
.42445 .66855 Mdot
.43476 .37425 Mdot
.78751 .62319 Mdot
.53873 .60961 Mdot
.66523 .25072 Mdot
.26852 .42528 Mdot
.56696 .31403 Mdot
.19963 .52661 Mdot
.58649 .31489 Mdot
.65193 .54978 Mdot
.4334 .42072 Mdot
.41558 .3944 Mdot
.41605 .44702 Mdot
.37762 .41603 Mdot
.66231 .58979 Mdot
.36952 .48561 Mdot
.4028 .2183 Mdot
.52413 .74564 Mdot
.5807 .39088 Mdot
.57582 .3165 Mdot
.62233 .58377 Mdot
.65276 .42445 Mdot
.54906 .75013 Mdot
.53463 .21689 Mdot
.37503 .48584 Mdot
.39174 .48138 Mdot
.52914 .75341 Mdot
.45937 .43962 Mdot
.41075 .36807 Mdot
.63825 .43091 Mdot
.50341 .51912 Mdot
.55068 .2756 Mdot
.55339 .32095 Mdot
.63723 .60725 Mdot
.40225 .65451 Mdot
.5732 .27672 Mdot
.64708 .46977 Mdot
.34319 .43613 Mdot
.38433 .50227 Mdot
.36358 .63533 Mdot
.28653 .30964 Mdot
.57693 .3338 Mdot
.44269 .3716 Mdot
.38429 .66347 Mdot
.43034 .67919 Mdot
.40363 .4604 Mdot
.32634 .43556 Mdot
.41796 .68081 Mdot
.57218 .32169 Mdot
.62184 .58519 Mdot
.57074 .44444 Mdot
.63236 .56306 Mdot
.38563 .65648 Mdot
.43505 .39697 Mdot
.4284 .63857 Mdot
.4251 .40738 Mdot
.1269 .40607 Mdot
.35287 .42926 Mdot
.45141 .62047 Mdot
.50054 .3285 Mdot
.63581 .45294 Mdot
.64363 .45479 Mdot
.53563 .74468 Mdot
.37558 .65798 Mdot
.42144 .48128 Mdot
.55247 .31391 Mdot
.59048 .79709 Mdot
.35027 .6412 Mdot
.62826 .39407 Mdot
.60003 .42803 Mdot
.66284 .59478 Mdot
.35828 .464 Mdot
.39347 .45142 Mdot
.62588 .40109 Mdot
.75714 .33112 Mdot
.40187 .66167 Mdot
.38233 .44959 Mdot
.35818 .42143 Mdot
.64484 .43317 Mdot
.60339 .56824 Mdot
.44614 .63321 Mdot
.35619 .42243 Mdot
.38002 .28109 Mdot
.63119 .59415 Mdot
.39627 .41149 Mdot
.37602 .48856 Mdot
.57375 .29238 Mdot
.61348 .32559 Mdot
.32063 .29507 Mdot
.62246 .55836 Mdot
.55035 .73241 Mdot
.4343 .41696 Mdot
.62746 .44467 Mdot
.35262 .49822 Mdot
.80907 .50967 Mdot
.52231 .73654 Mdot
.37205 .43325 Mdot
.44487 .46919 Mdot
.40049 .67347 Mdot
.37005 .43732 Mdot
.37351 .72434 Mdot
.65982 .44585 Mdot
.37148 .43217 Mdot
.32131 .61014 Mdot
.66062 .59599 Mdot
.42876 .48255 Mdot
.54846 .31293 Mdot
.50334 .33421 Mdot
.4757 .81551 Mdot
.62886 .38786 Mdot
.58053 .30765 Mdot
.34969 .44006 Mdot
.66608 .44772 Mdot
.6262 .60236 Mdot
.47252 .68502 Mdot
.35304 .41405 Mdot
.62888 .56674 Mdot
.63117 .57592 Mdot
.5668 .30075 Mdot
.26531 .25091 Mdot
.44505 .47028 Mdot
.3814 .46632 Mdot
.69111 .23967 Mdot
.42752 .61229 Mdot
.37767 .46777 Mdot
.359 .46374 Mdot
.64092 .55642 Mdot
.33739 .31904 Mdot
.45512 .5355 Mdot
.7639 .36365 Mdot
.62956 .59364 Mdot
.67366 .46408 Mdot
.66547 .43217 Mdot
.57859 .31137 Mdot
.39537 .61977 Mdot
.54282 .28755 Mdot
.64187 .44338 Mdot
.41403 .45732 Mdot
.66521 .56318 Mdot
.24604 .49605 Mdot
.66352 .61085 Mdot
.66496 .45706 Mdot
.42149 .68279 Mdot
.52342 .81629 Mdot
.76168 .27444 Mdot
.48542 .79899 Mdot
.62043 .55939 Mdot
.57237 .29703 Mdot
.5755 .61922 Mdot
.35482 .43247 Mdot
.19088 .50883 Mdot
.38267 .47013 Mdot
.26377 .40505 Mdot
.65148 .40141 Mdot
.53982 .7549 Mdot
.43397 .42485 Mdot
.49863 .24654 Mdot
.62025 .56476 Mdot
.65524 .60111 Mdot
.39762 .43155 Mdot
.64576 .57108 Mdot
.38806 .44869 Mdot
.65033 .43225 Mdot
.27137 .24952 Mdot
.35586 .45152 Mdot
.43029 .4737 Mdot
.65977 .53545 Mdot
.58993 .75271 Mdot
.67835 .44795 Mdot
.28608 .65742 Mdot
.79788 .61586 Mdot
.64367 .5736 Mdot
.31138 .43017 Mdot
.62783 .40682 Mdot
.5531 .7328 Mdot
.59319 .44293 Mdot
.3914 .46874 Mdot
.38497 .48527 Mdot
.41635 .43911 Mdot
.35659 .42962 Mdot
.19098 .52955 Mdot
.42074 .37452 Mdot
.25538 .5954 Mdot
.39494 .48117 Mdot
.43565 .59365 Mdot
.65121 .56669 Mdot
.42827 .54155 Mdot
.59075 .26801 Mdot
.38363 .48646 Mdot
.44633 .6862 Mdot
.6217 .57654 Mdot
.62251 .8026 Mdot
.66429 .58526 Mdot
.62596 .4188 Mdot
.66106 .55162 Mdot
.42118 .40209 Mdot
.39449 .6284 Mdot
.65922 .43622 Mdot
.40321 .76319 Mdot
.60764 .41477 Mdot
.36228 .4331 Mdot
.61068 .51991 Mdot
.63164 .45251 Mdot
.49737 .37829 Mdot
.39335 .62691 Mdot
.47965 .25141 Mdot
.43173 .61731 Mdot
.37179 .44349 Mdot
.37269 .45079 Mdot
.54961 .75138 Mdot
.64277 .55 Mdot
.40186 .60892 Mdot
.44628 .17642 Mdot
.58786 .27999 Mdot
.40698 .63038 Mdot
.33084 .4157 Mdot
.54491 .5867 Mdot
.41517 .66405 Mdot
.48889 .29343 Mdot
.63797 .5529 Mdot
.38224 .61976 Mdot
.37992 .38072 Mdot
.35928 .34083 Mdot
.57581 .32802 Mdot
.67229 .43354 Mdot
.54156 .50853 Mdot
.66489 .43609 Mdot
.68589 .59087 Mdot
.59683 .41651 Mdot
.65851 .5741 Mdot
.40467 .73131 Mdot
.47827 .54334 Mdot
.68487 .58276 Mdot
.66167 .54065 Mdot
.63554 .4396 Mdot
.40298 .43293 Mdot
.55069 .41157 Mdot
.33224 .41864 Mdot
.44559 .4122 Mdot
.62643 .58502 Mdot
.37471 .63717 Mdot
.42227 .62248 Mdot
.45369 .66117 Mdot
.4172 .67086 Mdot
.65874 .42903 Mdot
.53177 .65385 Mdot
.25782 .38724 Mdot
.66831 .59392 Mdot
.65879 .5152 Mdot
.41336 .42874 Mdot
.63242 .44407 Mdot
.65703 .41725 Mdot
.63509 .56732 Mdot
.2205 .46537 Mdot
.43908 .46221 Mdot
.43364 .62935 Mdot
.39812 .61178 Mdot
.41824 .65928 Mdot
.3681 .66308 Mdot
.21939 .36719 Mdot
.66338 .6093 Mdot
.37478 .6441 Mdot
.38691 .41788 Mdot
.38295 .48044 Mdot
.54119 .72592 Mdot
.56749 .32127 Mdot
.43929 .43015 Mdot
.44033 .44293 Mdot
.40255 .46057 Mdot
.63414 .45199 Mdot
.44313 .50201 Mdot
.52339 .73411 Mdot
.59678 .42194 Mdot
.61074 .39861 Mdot
.5459 .74799 Mdot
.35147 .62478 Mdot
.78611 .64794 Mdot
.41777 .44745 Mdot
.34604 .5302 Mdot
.62727 .44132 Mdot
.49427 .60997 Mdot
.35598 .35554 Mdot
.40191 .41787 Mdot
.57745 .37551 Mdot
.65399 .43334 Mdot
.38259 .69511 Mdot
.38745 .46554 Mdot
.53539 .75138 Mdot
.55967 .3276 Mdot
.3505 .39841 Mdot
.5505 .72827 Mdot
.40934 .64567 Mdot
.71086 .31125 Mdot
.41701 .60442 Mdot
.63266 .45405 Mdot
.42077 .49078 Mdot
.16762 .70351 Mdot
.64394 .41578 Mdot
.65139 .7685 Mdot
.48141 .53407 Mdot
.35341 .44361 Mdot
.66267 .42889 Mdot
.39067 .69649 Mdot
.6308 .59327 Mdot
.55168 .4969 Mdot
.38898 .62066 Mdot
.5473 .75151 Mdot
.5485 .73364 Mdot
.64247 .4331 Mdot
.41518 .62319 Mdot
.35755 .47613 Mdot
.38608 .67138 Mdot
.67597 .57568 Mdot
.40982 .40224 Mdot
.77593 .63563 Mdot
.34345 .38893 Mdot
.38262 .66393 Mdot
.64802 .47108 Mdot
.57204 .27154 Mdot
.38996 .40228 Mdot
.71065 .73225 Mdot
.35544 .46017 Mdot
.66676 .59033 Mdot
.47656 .59188 Mdot
.2421 .50716 Mdot
.4092 .44307 Mdot
.41877 .43212 Mdot
.62953 .60241 Mdot
.41188 .44665 Mdot
.35124 .41993 Mdot
.62334 .61474 Mdot
.4121 .66918 Mdot
.37761 .43163 Mdot
.66623 .42173 Mdot
.29438 .48091 Mdot
.43466 .43763 Mdot
.40466 .74525 Mdot
.48935 .24587 Mdot
.46813 .57351 Mdot
.41869 .48579 Mdot
.49803 .20642 Mdot
.37565 .4548 Mdot
.38057 .40864 Mdot
.41198 .43773 Mdot
.27309 .65712 Mdot
.63836 .44288 Mdot
.65538 .40006 Mdot
.56385 .3306 Mdot
.49313 .25129 Mdot
.57749 .29318 Mdot
.62126 .5872 Mdot
.69147 .53317 Mdot
.52495 .74578 Mdot
.40006 .65673 Mdot
.42655 .45831 Mdot
.60659 .41234 Mdot
.39662 .45932 Mdot
.42346 .41729 Mdot
.65253 .43989 Mdot
.657 .42208 Mdot
.61148 .39355 Mdot
.58977 .30484 Mdot
.40053 .64455 Mdot
.41422 .46658 Mdot
.58579 .28676 Mdot
.35488 .46936 Mdot
.54975 .58959 Mdot
.40216 .64173 Mdot
.38722 .67202 Mdot
.42327 .61793 Mdot
.40132 .48105 Mdot
.40966 .39639 Mdot
.64343 .56326 Mdot
.36526 .62929 Mdot
.66716 .59962 Mdot
.66286 .43086 Mdot
.64447 .45335 Mdot
.39144 .46922 Mdot
.44565 .37538 Mdot
.56587 .31886 Mdot
.62309 .41799 Mdot
.51759 .735 Mdot
.5622 .33051 Mdot
.36597 .42337 Mdot
.66361 .43492 Mdot
.54893 .31744 Mdot
.2409 .45384 Mdot
.80858 .59217 Mdot
.58433 .28009 Mdot
.3967 .43084 Mdot
.32076 .64394 Mdot
.3598 .28439 Mdot
.58318 .27236 Mdot
.66717 .57734 Mdot
.36701 .47023 Mdot
.77291 .33707 Mdot
.54907 .27499 Mdot
.28948 .30859 Mdot
.64994 .44386 Mdot
.28965 .38855 Mdot
.35241 .39589 Mdot
.20347 .46311 Mdot
.5468 .2768 Mdot
.38226 .65204 Mdot
.37898 .61631 Mdot
.39977 .43799 Mdot
.58693 .27031 Mdot
.68063 .59923 Mdot
.6182 .44877 Mdot
.61628 .39757 Mdot
.41909 .62722 Mdot
.54405 .66349 Mdot
.66621 .42449 Mdot
.4001 .50661 Mdot
.62689 .47716 Mdot
.36816 .52919 Mdot
.19215 .41589 Mdot
.39663 .77252 Mdot
.39802 .49704 Mdot
.57279 .27065 Mdot
.61705 .57415 Mdot
.64339 .56642 Mdot
.65441 .57731 Mdot
.65214 .45265 Mdot
.53065 .56976 Mdot
.632 .39621 Mdot
.47124 .72635 Mdot
.56152 .30924 Mdot
.46033 .2671 Mdot
.42867 .46553 Mdot
.3538 .44217 Mdot
.34247 .43553 Mdot
.41778 .44033 Mdot
.37689 .45439 Mdot
.62766 .58015 Mdot
.62908 .45872 Mdot
.73725 .35058 Mdot
.41962 .64839 Mdot
.60781 .70464 Mdot
.62288 .44382 Mdot
.53889 .72144 Mdot
.55935 .28867 Mdot
.45294 .21174 Mdot
.6556 .48935 Mdot
.61602 .43603 Mdot
.35339 .4109 Mdot
.37116 .6456 Mdot
.32298 .34038 Mdot
.36893 .45803 Mdot
.62247 .41699 Mdot
.62311 .46889 Mdot
.20494 .51835 Mdot
.37953 .51992 Mdot
.53169 .31455 Mdot
.5435 .58761 Mdot
.55536 .26586 Mdot
.33038 .4559 Mdot
.4974 .61595 Mdot
.64122 .44121 Mdot
.63022 .42145 Mdot
.58595 .27956 Mdot
.45463 .50888 Mdot
.40486 .61786 Mdot
.53753 .75535 Mdot
.66329 .5722 Mdot
.36255 .45248 Mdot
.65578 .4507 Mdot
.37126 .54828 Mdot
.56197 .47977 Mdot
.65443 .59167 Mdot
.5976 .42603 Mdot
.36618 .47226 Mdot
.40448 .44126 Mdot
.56981 .31222 Mdot
.62074 .26185 Mdot
.33693 .41214 Mdot
.59955 .79684 Mdot
.52317 .61426 Mdot
.51016 .46511 Mdot
.40018 .45519 Mdot
.42734 .64609 Mdot
.53991 .74903 Mdot
.55011 .29075 Mdot
.35679 .46912 Mdot
.8058 .62244 Mdot
.38453 .59902 Mdot
.63487 .58749 Mdot
.53938 .75052 Mdot
.52992 .5579 Mdot
.35328 .45708 Mdot
.38288 .46995 Mdot
.37476 .4164 Mdot
.81288 .61679 Mdot
.65582 .4027 Mdot
.36604 .63853 Mdot
.56619 .27698 Mdot
.39237 .67688 Mdot
.64179 .39248 Mdot
.52048 .43741 Mdot
.3656 .41973 Mdot
.43204 .63044 Mdot
.38122 .64762 Mdot
.66184 .59618 Mdot
.62316 .56335 Mdot
.66797 .40245 Mdot
.35158 .43633 Mdot
.52853 .75068 Mdot
.38171 .62347 Mdot
.62722 .46266 Mdot
.56894 .31162 Mdot
.63266 .54222 Mdot
.39662 .48123 Mdot
.64051 .43583 Mdot
.37791 .49446 Mdot
.39862 .67005 Mdot
.61735 .43802 Mdot
.54176 .72047 Mdot
.56386 .32059 Mdot
.38981 .48446 Mdot
.72467 .31379 Mdot
.54061 .75224 Mdot
.39316 .39397 Mdot
.33607 .63293 Mdot
.59976 .30036 Mdot
.39799 .76326 Mdot
.64574 .40153 Mdot
.52668 .7419 Mdot
.36795 .64219 Mdot
.34202 .34371 Mdot
.63599 .42125 Mdot
.33058 .69868 Mdot
.56757 .404 Mdot
.41619 .45694 Mdot
.40921 .62665 Mdot
.54562 .26058 Mdot
.62332 .79287 Mdot
.3883 .2671 Mdot
.38108 .44335 Mdot
.6652 .43615 Mdot
.55375 .32175 Mdot
.66414 .60005 Mdot
.40912 .7434 Mdot
.19357 .4304 Mdot
.59806 .4193 Mdot
.41623 .46892 Mdot
.37838 .62734 Mdot
.6344 .57191 Mdot
.40959 .79616 Mdot
.65191 .46834 Mdot
.65884 .40998 Mdot
.37359 .41068 Mdot
.56251 .27635 Mdot
.77568 .35556 Mdot
.66036 .40504 Mdot
.64948 .45776 Mdot
.59621 .71329 Mdot
.58542 .32489 Mdot
.38842 .42124 Mdot
.4536 .66319 Mdot
.34384 .438 Mdot
.60812 .7818 Mdot
.52675 .7445 Mdot
.41823 .6512 Mdot
.3847 .47596 Mdot
.73085 .33814 Mdot
.64571 .42069 Mdot
.54129 .59361 Mdot
.63486 .63257 Mdot
.62637 .55916 Mdot
.65658 .44815 Mdot
.39107 .46052 Mdot
.64516 .53402 Mdot
.56882 .31758 Mdot
.35598 .42265 Mdot
.4186 .40093 Mdot
.40528 .69551 Mdot
.67125 .56989 Mdot
.30249 .48958 Mdot
.6752 .56887 Mdot
.64047 .60916 Mdot
.43209 .67725 Mdot
.39841 .43753 Mdot
.62008 .42465 Mdot
.67026 .45055 Mdot
.36541 .48465 Mdot
.49475 .60774 Mdot
.40602 .61973 Mdot
.58891 .45161 Mdot
.84035 .57429 Mdot
.43715 .487 Mdot
.51856 .73053 Mdot
.2774 .40669 Mdot
.6444 .60451 Mdot
.41227 .45855 Mdot
.39574 .66234 Mdot
.63857 .46123 Mdot
.66882 .42819 Mdot
.35969 .40086 Mdot
.63316 .56761 Mdot
.54496 .31585 Mdot
.65429 .41142 Mdot
.56379 .48539 Mdot
.3691 .43238 Mdot
.46768 .71692 Mdot
.64821 .40748 Mdot
.53199 .83613 Mdot
.7331 .34365 Mdot
.42266 .64171 Mdot
.41971 .42072 Mdot
.38055 .67775 Mdot
.56963 .2784 Mdot
.59221 .43553 Mdot
.63312 .56474 Mdot
.46778 .3791 Mdot
.50244 .17747 Mdot
.63549 .4462 Mdot
.40561 .64796 Mdot
.40956 .47258 Mdot
.41146 .35891 Mdot
.35392 .45351 Mdot
.35922 .31516 Mdot
.53213 .25886 Mdot
.65659 .5378 Mdot
.65766 .60263 Mdot
.42464 .43593 Mdot
.58704 .31073 Mdot
.67542 .43305 Mdot
.65068 .44095 Mdot
.20637 .30954 Mdot
.5493 .72573 Mdot
.51901 .27816 Mdot
.39916 .48164 Mdot
.62225 .45875 Mdot
.33235 .57744 Mdot
.67316 .59641 Mdot
.34258 .45831 Mdot
.60627 .44009 Mdot
.64733 .7334 Mdot
.54649 .57874 Mdot
.37436 .43596 Mdot
.46064 .44931 Mdot
.66636 .58199 Mdot
.57613 .6206 Mdot
.62843 .3979 Mdot
.34669 .45891 Mdot
.66964 .62336 Mdot
.58597 .73911 Mdot
.47391 .18028 Mdot
.40047 .64406 Mdot
.64012 .47303 Mdot
.62593 .56423 Mdot
.43685 .50295 Mdot
.57359 .31925 Mdot
.65296 .46031 Mdot
.60675 .43189 Mdot
.41367 .40743 Mdot
.43793 .43878 Mdot
.41086 .51334 Mdot
.41244 .63623 Mdot
.64679 .55782 Mdot
.42996 .43685 Mdot
.54858 .64489 Mdot
.42012 .44967 Mdot
.64295 .5581 Mdot
.10135 .56522 Mdot
.36918 .3987 Mdot
.37114 .46645 Mdot
.49459 .34768 Mdot
.41254 .6152 Mdot
.40727 .67382 Mdot
.53554 .63928 Mdot
.39805 .48222 Mdot
.58638 .47226 Mdot
.39942 .64799 Mdot
.40403 .62089 Mdot
.57654 .44876 Mdot
.40602 .40379 Mdot
.69333 .59489 Mdot
.6368 .56955 Mdot
.62543 .56031 Mdot
.39775 .67337 Mdot
.41723 .37968 Mdot
.62271 .5972 Mdot
.19057 .55229 Mdot
.61801 .44195 Mdot
.49746 .61658 Mdot
.38424 .66905 Mdot
.56069 .44249 Mdot
.64464 .55023 Mdot
.55952 .85236 Mdot
.39666 .3305 Mdot
.35788 .48474 Mdot
.40519 .4399 Mdot
.57534 .29761 Mdot
.35437 .36851 Mdot
.54889 .72983 Mdot
.64754 .57063 Mdot
.75722 .41139 Mdot
.4013 .63569 Mdot
.36588 .46402 Mdot
.40555 .23179 Mdot
.42708 .79382 Mdot
.4609 .69138 Mdot
.39266 .62034 Mdot
.40009 .62949 Mdot
.61476 .41062 Mdot
.6185 .44594 Mdot
.38084 .4213 Mdot
.65427 .57304 Mdot
.38554 .61399 Mdot
.65687 .55905 Mdot
.64223 .44243 Mdot
.61848 .43637 Mdot
.52291 .73071 Mdot
.44408 .3964 Mdot
.64807 .44945 Mdot
.60148 .72983 Mdot
.5485 .64086 Mdot
.38058 .6916 Mdot
.74875 .26672 Mdot
.4044 .79662 Mdot
.49191 .34315 Mdot
.56088 .32825 Mdot
.54826 .76946 Mdot
.64853 .54611 Mdot
.42353 .43654 Mdot
.39684 .47281 Mdot
.54081 .72948 Mdot
.63217 .55201 Mdot
.56516 .28614 Mdot
.64508 .54921 Mdot
.55109 .29763 Mdot
.66423 .40524 Mdot
.43547 .43471 Mdot
.3478 .44094 Mdot
.64285 .59661 Mdot
.61896 .41134 Mdot
.63339 .45364 Mdot
.57162 .3271 Mdot
.4564 .21669 Mdot
.64321 .43449 Mdot
.38438 .66943 Mdot
.28489 .49054 Mdot
.54747 .73251 Mdot
.38698 .46486 Mdot
.43467 .21411 Mdot
.20175 .50502 Mdot
.41704 .45919 Mdot
.53939 .75111 Mdot
.22201 .28508 Mdot
.43459 .42362 Mdot
.19286 .36131 Mdot
.52494 .73355 Mdot
.42765 .63451 Mdot
.6322 .40494 Mdot
.5529 .73789 Mdot
.44382 .49987 Mdot
.54523 .24696 Mdot
.40218 .50089 Mdot
.39632 .6145 Mdot
.4327 .64314 Mdot
.48684 .53788 Mdot
.61224 .7792 Mdot
.55713 .27617 Mdot
.56338 .29266 Mdot
.63832 .42302 Mdot
.70847 .60197 Mdot
.35454 .49085 Mdot
.566 .2923 Mdot
.78258 .42455 Mdot
.41166 .42753 Mdot
.51757 .25359 Mdot
.56937 .38528 Mdot
.4261 .63998 Mdot
.44012 .53453 Mdot
.6415 .42106 Mdot
.40539 .64742 Mdot
.52317 .47127 Mdot
.34251 .43831 Mdot
.40227 .6392 Mdot
.64418 .55565 Mdot
.73398 .60436 Mdot
.41317 .67505 Mdot
.55355 .49365 Mdot
.63757 .5738 Mdot
.5984 .29055 Mdot
.42594 .29266 Mdot
.87959 .55493 Mdot
.64924 .57027 Mdot
.62563 .41012 Mdot
.64412 .45209 Mdot
.64706 .43248 Mdot
.39076 .61884 Mdot
.65417 .41816 Mdot
.41599 .64621 Mdot
.62413 .52145 Mdot
.48434 .20799 Mdot
.56849 .30669 Mdot
.65286 .50446 Mdot
.38668 .64313 Mdot
.48496 .72426 Mdot
.68765 .22285 Mdot
.39401 .42513 Mdot
.68402 .59093 Mdot
.57508 .27031 Mdot
.53427 .68382 Mdot
.57407 .29189 Mdot
.6282 .406 Mdot
.4978 .61863 Mdot
.3874 .44734 Mdot
.35143 .72073 Mdot
.54897 .31121 Mdot
.3908 .62037 Mdot
.36938 .40549 Mdot
.67536 .40811 Mdot
.58069 .30134 Mdot
.56142 .32721 Mdot
.37852 .45653 Mdot
.42796 .66188 Mdot
.61771 .43016 Mdot
.65123 .54332 Mdot
.56071 .25632 Mdot
.46111 .41803 Mdot
.40643 .43673 Mdot
.34712 .41197 Mdot
.53533 .60121 Mdot
.77805 .35048 Mdot
.64287 .57524 Mdot
.35688 .28205 Mdot
.63679 .45029 Mdot
.38625 .27254 Mdot
.49724 .77005 Mdot
.66444 .48927 Mdot
.52564 .74305 Mdot
.52724 .74588 Mdot
.37575 .44237 Mdot
.79421 .38285 Mdot
.45923 .66091 Mdot
.6573 .61777 Mdot
.54735 .73757 Mdot
.63248 .45346 Mdot
.37153 .61555 Mdot
.47784 .48949 Mdot
.43622 .41033 Mdot
.62451 .55651 Mdot
.64592 .4393 Mdot
.8097 .50814 Mdot
.56155 .30725 Mdot
.51818 .66125 Mdot
.36304 .42591 Mdot
.38347 .45315 Mdot
.64326 .58656 Mdot
.64292 .56404 Mdot
.45254 .72536 Mdot
.49359 .55432 Mdot
.75158 .65221 Mdot
.69153 .58109 Mdot
.81438 .49101 Mdot
.44889 .66165 Mdot
.38804 .66484 Mdot
.52465 .72484 Mdot
.62447 .59737 Mdot
.37828 .46981 Mdot
.4262 .62965 Mdot
.46284 .68 Mdot
.41074 .69708 Mdot
.5108 .26022 Mdot
.57022 .44969 Mdot
.35996 .42662 Mdot
.36963 .65156 Mdot
.40499 .64505 Mdot
.37348 .67164 Mdot
.54561 .74719 Mdot
.40283 .45595 Mdot
.40155 .43088 Mdot
.43279 .4188 Mdot
.41788 .36216 Mdot
.36942 .43667 Mdot
.50301 .77232 Mdot
.55506 .66569 Mdot
.65119 .34063 Mdot
.41178 .47455 Mdot
.62999 .55963 Mdot
.42573 .46046 Mdot
.58535 .31254 Mdot
.41233 .47594 Mdot
.53027 .24512 Mdot
.65264 .58175 Mdot
.47508 .47193 Mdot
.58555 .42975 Mdot
.36351 .42248 Mdot
.54198 .30633 Mdot
.78052 .35534 Mdot
.38647 .24286 Mdot
.5974 .7163 Mdot
.38488 .66976 Mdot
.65988 .3951 Mdot
.67786 .59805 Mdot
.62105 .42534 Mdot
.34819 .47054 Mdot
.51946 .73452 Mdot
.35906 .79776 Mdot
.55091 .44018 Mdot
.37943 .47185 Mdot
.43387 .38095 Mdot
.4251 .65371 Mdot
.6475 .41942 Mdot
.42886 .69203 Mdot
.37733 .41143 Mdot
.57441 .27896 Mdot
.58127 .28281 Mdot
.5044 .48565 Mdot
.79068 .50049 Mdot
.3415 .33627 Mdot
.64326 .58424 Mdot
.66975 .43159 Mdot
.54587 .27875 Mdot
.43889 .71233 Mdot
.67676 .60365 Mdot
.64458 .60441 Mdot
.67009 .56872 Mdot
.35805 .43656 Mdot
.5287 .72576 Mdot
.7864 .45907 Mdot
.54992 .74837 Mdot
.36708 .41331 Mdot
.60675 .42571 Mdot
.55356 .73903 Mdot
.57691 .29638 Mdot
.63868 .6075 Mdot
.63013 .44933 Mdot
.37125 .44722 Mdot
.3951 .64807 Mdot
.36613 .26788 Mdot
.64006 .2284 Mdot
.62236 .48765 Mdot
.62384 .48928 Mdot
.4202 .61163 Mdot
.70216 .75067 Mdot
.6182 .53351 Mdot
.21787 .46866 Mdot
.53558 .27026 Mdot
.36458 .4847 Mdot
.28737 .25356 Mdot
.63353 .3968 Mdot
.65973 .43357 Mdot
.37387 .43071 Mdot
.64077 .46839 Mdot
.36141 .46161 Mdot
.62214 .39972 Mdot
.67202 .74284 Mdot
.42508 .3956 Mdot
.65887 .43109 Mdot
.34545 .48226 Mdot
.38715 .40104 Mdot
.42651 .65385 Mdot
.64841 .46165 Mdot
.36056 .48747 Mdot
.33499 .79567 Mdot
.65571 .59769 Mdot
.54716 .74574 Mdot
.67419 .5195 Mdot
.66119 .55363 Mdot
.41533 .63227 Mdot
.4368 .42708 Mdot
.56777 .31603 Mdot
.38593 .65316 Mdot
.66319 .39241 Mdot
.54633 .3034 Mdot
.53328 .65427 Mdot
.39111 .67018 Mdot
.54087 .72719 Mdot
.56142 .31924 Mdot
.40389 .50078 Mdot
.65674 .43907 Mdot
.70821 .2722 Mdot
.54993 .74698 Mdot
.39282 .452 Mdot
.6564 .47246 Mdot
.64635 .54917 Mdot
.38472 .42716 Mdot
.66588 .44065 Mdot
.54334 .74958 Mdot
.39471 .39466 Mdot
.39049 .39491 Mdot
.48809 .46302 Mdot
.47211 .60607 Mdot
.57163 .30829 Mdot
.43136 .67652 Mdot
.38453 .41648 Mdot
.58673 .31305 Mdot
.71767 .47661 Mdot
.41559 .48333 Mdot
.39029 .68003 Mdot
.45541 .36926 Mdot
.61507 .44331 Mdot
.66548 .60086 Mdot
.66542 .45732 Mdot
.55708 .32709 Mdot
.49289 .15058 Mdot
.5359 .72249 Mdot
.44361 .39067 Mdot
.342 .43518 Mdot
.59634 .43393 Mdot
.4065 .64057 Mdot
.73625 .66881 Mdot
.39332 .48379 Mdot
.39441 .37504 Mdot
.38236 .4619 Mdot
.72868 .34373 Mdot
.40389 .61908 Mdot
.38451 .46433 Mdot
.44991 .38507 Mdot
.39194 .50431 Mdot
.54076 .30596 Mdot
.45512 .27714 Mdot
.42523 .45761 Mdot
.25768 .79627 Mdot
.52719 .75236 Mdot
.65225 .43791 Mdot
.55492 .53693 Mdot
.72284 .40238 Mdot
.19287 .40194 Mdot
.41491 .64088 Mdot
.29607 .43292 Mdot
.61904 .42833 Mdot
.35793 .25716 Mdot
.66392 .78279 Mdot
.38307 .4019 Mdot
.36994 .47445 Mdot
.62821 .40604 Mdot
.62663 .46113 Mdot
.52183 .74329 Mdot
.39111 .49001 Mdot
.39986 .37594 Mdot
.62611 .46627 Mdot
.36573 .44534 Mdot
.22742 .60858 Mdot
.66874 .55442 Mdot
.40291 .67378 Mdot
.66444 .59978 Mdot
.64212 .60195 Mdot
.23994 .40814 Mdot
.52249 .61388 Mdot
.64264 .55985 Mdot
.62943 .61472 Mdot
.54214 .23253 Mdot
.47274 .38018 Mdot
.54179 .29178 Mdot
.77888 .5576 Mdot
.64157 .42718 Mdot
.40419 .45685 Mdot
.38178 .62732 Mdot
.20818 .43146 Mdot
.72393 .63477 Mdot
.50137 .6387 Mdot
.39649 .42482 Mdot
.64698 .42362 Mdot
.5453 .75018 Mdot
.42989 .39986 Mdot
.37302 .28055 Mdot
.38273 .4477 Mdot
.62121 .45149 Mdot
.24683 .39807 Mdot
.36976 .71823 Mdot
.69115 .58596 Mdot
.35803 .66837 Mdot
.43067 .45142 Mdot
.40424 .66454 Mdot
.62838 .56456 Mdot
.58937 .30607 Mdot
.57145 .29754 Mdot
.35637 .4271 Mdot
.47829 .5442 Mdot
.58771 .24784 Mdot
.38537 .40233 Mdot
.41183 .4054 Mdot
.52541 .73916 Mdot
.4116 .40455 Mdot
.34489 .45194 Mdot
.42786 .44458 Mdot
.3968 .49259 Mdot
.63703 .60828 Mdot
.33502 .65924 Mdot
.4184 .47296 Mdot
.43867 .48661 Mdot
.64238 .53759 Mdot
.39103 .5303 Mdot
.66347 .58348 Mdot
.77782 .61376 Mdot
.66038 .57139 Mdot
.57097 .29962 Mdot
.67457 .45056 Mdot
.30017 .45746 Mdot
.38708 .613 Mdot
.62272 .56805 Mdot
.55464 .29787 Mdot
.65148 .57316 Mdot
.66775 .41631 Mdot
.72596 .26137 Mdot
.43958 .6552 Mdot
.55165 .58781 Mdot
.47573 .34516 Mdot
.46656 .71758 Mdot
.61274 .43681 Mdot
.4188 .62782 Mdot
.3738 .72364 Mdot
.42633 .43565 Mdot
.5723 .3141 Mdot
.37683 .44387 Mdot
.64443 .60896 Mdot
.64578 .42571 Mdot
.61118 .52229 Mdot
.57262 .30735 Mdot
.55864 .17003 Mdot
.60805 .41144 Mdot
.45328 .42892 Mdot
.64525 .53627 Mdot
.73108 .25517 Mdot
.66282 .57608 Mdot
.47886 .20779 Mdot
.39837 .5814 Mdot
.25005 .37652 Mdot
.39437 .63215 Mdot
.43106 .72858 Mdot
.7537 .72343 Mdot
.669 .76993 Mdot
.38956 .65717 Mdot
.58421 .44232 Mdot
.36345 .43509 Mdot
.42031 .44394 Mdot
.40877 .50661 Mdot
.37253 .68834 Mdot
.37827 .41691 Mdot
.54702 .72852 Mdot
.53025 .61335 Mdot
.77224 .38273 Mdot
.67115 .40899 Mdot
.35935 .46063 Mdot
.62688 .58502 Mdot
.65463 .61182 Mdot
.55314 .74388 Mdot
.67156 .56592 Mdot
.39505 .40118 Mdot
.38838 .63984 Mdot
.54659 .4199 Mdot
.57448 .2833 Mdot
.55785 .79162 Mdot
.54231 .27064 Mdot
.66779 .47864 Mdot
.42686 .49617 Mdot
.61811 .43657 Mdot
.39099 .1786 Mdot
.42072 .43652 Mdot
.40036 .64988 Mdot
.36546 .41075 Mdot
.42916 .44552 Mdot
.41993 .46445 Mdot
.66758 .43823 Mdot
.55541 .543 Mdot
.36647 .44831 Mdot
.63463 .5597 Mdot
.57559 .42708 Mdot
.44041 .43053 Mdot
.75743 .4367 Mdot
.50357 .27265 Mdot
.47353 .71478 Mdot
.37437 .68594 Mdot
.63082 .41255 Mdot
.40016 .63343 Mdot
.35522 .67238 Mdot
.4155 .63245 Mdot
.76606 .42885 Mdot
.29808 .36403 Mdot
.17718 .38941 Mdot
.31915 .56513 Mdot
.21532 .4401 Mdot
.43157 .62455 Mdot
.73181 .49527 Mdot
.3918 .66302 Mdot
.41588 .6371 Mdot
.11041 .45476 Mdot
.37691 .65865 Mdot
.39291 .4688 Mdot
.40248 .3881 Mdot
.47587 .80601 Mdot
.53561 .2323 Mdot
.41283 .47445 Mdot
.3798 .41836 Mdot
.56922 .27258 Mdot
.45683 .38291 Mdot
.54981 .75651 Mdot
.51819 .63939 Mdot
.51808 .7574 Mdot
.3782 .45546 Mdot
.374 .42481 Mdot
.34438 .41046 Mdot
.75323 .72936 Mdot
.20231 .42783 Mdot
.42861 .62919 Mdot
.42817 .52081 Mdot
.5866 .77161 Mdot
.34925 .42139 Mdot
.35361 .41848 Mdot
.42427 .40549 Mdot
.61957 .42581 Mdot
.37727 .60923 Mdot
.36874 .38124 Mdot
.46305 .76518 Mdot
.36489 .42495 Mdot
.68556 .45072 Mdot
.59018 .34914 Mdot
.39174 .46153 Mdot
.38674 .67702 Mdot
.41026 .43204 Mdot
.37296 .66255 Mdot
.40226 .67271 Mdot
.4404 .3912 Mdot
.78845 .47081 Mdot
.36276 .6278 Mdot
.37977 .40111 Mdot
.61965 .41362 Mdot
.62589 .78957 Mdot
.3937 .45435 Mdot
.55762 .27756 Mdot
.41308 .45769 Mdot
.543 .31236 Mdot
.41416 .40069 Mdot
.54799 .75059 Mdot
.23597 .51735 Mdot
.63163 .4222 Mdot
.55696 .25605 Mdot
.62588 .46373 Mdot
.50242 .43782 Mdot
.42396 .67304 Mdot
.54643 .759 Mdot
.18215 .45385 Mdot
.52548 .73735 Mdot
.33924 .2879 Mdot
.71705 .59113 Mdot
.64207 .59921 Mdot
.36772 .66137 Mdot
.28752 .36378 Mdot
.77199 .47576 Mdot
.60883 .39752 Mdot
.61012 .3987 Mdot
.41549 .17988 Mdot
.26726 .25203 Mdot
.3664 .45326 Mdot
.76873 .31884 Mdot
.25561 .57793 Mdot
.37336 .50222 Mdot
.32819 .46737 Mdot
.60774 .4382 Mdot
.43128 .45235 Mdot
.54534 .49302 Mdot
.63587 .44049 Mdot
.55802 .2976 Mdot
.41687 .65356 Mdot
.56534 .32471 Mdot
.75439 .61381 Mdot
.55828 .65135 Mdot
.6412 .44798 Mdot
.40774 .4877 Mdot
.35878 .45112 Mdot
.36656 .65139 Mdot
.34371 .72618 Mdot
.41145 .67025 Mdot
.54946 .28035 Mdot
.63039 .43209 Mdot
.20093 .45902 Mdot
.40997 .46632 Mdot
.38113 .6437 Mdot
.59386 .40326 Mdot
.4055 .44238 Mdot
.63636 .59168 Mdot
.39713 .42458 Mdot
.37998 .65694 Mdot
.41206 .40423 Mdot
.39031 .63829 Mdot
.62252 .40325 Mdot
.35104 .45631 Mdot
.37594 .42468 Mdot
.31965 .29557 Mdot
.56558 .28527 Mdot
.4283 .66755 Mdot
.54444 .49987 Mdot
.34446 .43633 Mdot
.37393 .28198 Mdot
.43571 .43069 Mdot
.31416 .46925 Mdot
.3267 .43696 Mdot
.54302 .72592 Mdot
.33914 .4536 Mdot
.39251 .45362 Mdot
.31921 .68563 Mdot
.32719 .60708 Mdot
.45794 .5185 Mdot
.62114 .5671 Mdot
.3895 .67726 Mdot
.64833 .452 Mdot
.63578 .45952 Mdot
.64976 .41237 Mdot
.52499 .22827 Mdot
.46335 .42281 Mdot
.38816 .44573 Mdot
.65754 .53754 Mdot
.5643 .29525 Mdot
.38571 .62765 Mdot
.56692 .30125 Mdot
.51613 .63494 Mdot
.54611 .28907 Mdot
.54552 .72598 Mdot
.73379 .34342 Mdot
.20247 .57462 Mdot
.55001 .2871 Mdot
.40956 .67131 Mdot
.57719 .46328 Mdot
.36519 .48637 Mdot
.62534 .7385 Mdot
.57391 .27829 Mdot
.44383 .17559 Mdot
.40079 .3917 Mdot
.54976 .50459 Mdot
.66257 .58874 Mdot
.56319 .32384 Mdot
.67371 .57442 Mdot
.41361 .43386 Mdot
.39498 .76249 Mdot
.40365 .65211 Mdot
.67914 .57086 Mdot
.34397 .46994 Mdot
.56499 .32441 Mdot
.64594 .448 Mdot
.41929 .33955 Mdot
.6301 .55091 Mdot
.36781 .26071 Mdot
.38787 .26744 Mdot
.63087 .43426 Mdot
.18283 .58276 Mdot
.67141 .57938 Mdot
.39727 .4961 Mdot
.30342 .37313 Mdot
.4042 .42641 Mdot
.63998 .45596 Mdot
.66059 .42834 Mdot
.52754 .79906 Mdot
.35757 .42748 Mdot
.41821 .39484 Mdot
.39555 .60207 Mdot
.63249 .44571 Mdot
.41357 .62686 Mdot
.36737 .6325 Mdot
.62528 .40739 Mdot
.42249 .6393 Mdot
.54945 .31246 Mdot
.51752 .60531 Mdot
.67014 .57771 Mdot
.63034 .57695 Mdot
.64644 .44998 Mdot
.67127 .41862 Mdot
.61923 .43922 Mdot
.39483 .41884 Mdot
.40931 .61643 Mdot
.41477 .41803 Mdot
.42449 .46142 Mdot
.41338 .58168 Mdot
.40932 .60952 Mdot
.41295 .42313 Mdot
.5773 .38837 Mdot
.55572 .33395 Mdot
.65824 .42951 Mdot
.65421 .55754 Mdot
.31226 .29514 Mdot
.67259 .56017 Mdot
.35362 .42332 Mdot
.64385 .73712 Mdot
.3923 .61837 Mdot
.57484 .2938 Mdot
.59785 .31337 Mdot
.57461 .30393 Mdot
.67938 .57126 Mdot
.36383 .64197 Mdot
.53532 .65278 Mdot
.35089 .43502 Mdot
.53404 .60125 Mdot
.32946 .30228 Mdot
.48999 .76942 Mdot
.64466 .55688 Mdot
.39202 .4237 Mdot
.5257 .73379 Mdot
.20369 .52713 Mdot
.38301 .44076 Mdot
.34342 .46167 Mdot
.66755 .29769 Mdot
.43827 .48671 Mdot
.39567 .69544 Mdot
.48809 .51637 Mdot
.35789 .46953 Mdot
.47322 .49947 Mdot
.16535 .35084 Mdot
.39681 .3923 Mdot
.37029 .42256 Mdot
.40189 .46688 Mdot
.4218 .43325 Mdot
.39127 .68364 Mdot
.64202 .26331 Mdot
.6241 .57907 Mdot
.51824 .6021 Mdot
.66954 .57041 Mdot
.66006 .43995 Mdot
.53999 .4718 Mdot
.37552 .67061 Mdot
.57518 .30325 Mdot
.75933 .29181 Mdot
.50343 .61031 Mdot
.61372 .41277 Mdot
.21338 .38951 Mdot
.57665 .28319 Mdot
.36728 .48654 Mdot
.56489 .33118 Mdot
.61319 .45175 Mdot
.63454 .56643 Mdot
.35655 .40845 Mdot
.39127 .61508 Mdot
.40962 .67641 Mdot
.38996 .41932 Mdot
.59215 .79498 Mdot
.65674 .55008 Mdot
.68941 .39193 Mdot
.35855 .43269 Mdot
.34399 .46216 Mdot
.41681 .66246 Mdot
.64872 .42103 Mdot
.7107 .57931 Mdot
.5584 .28746 Mdot
.34546 .47683 Mdot
.41316 .43516 Mdot
.51806 .62456 Mdot
.62458 .59478 Mdot
.54079 .74144 Mdot
.35819 .42963 Mdot
.52528 .61732 Mdot
.36128 .419 Mdot
.3811 .36811 Mdot
.61547 .42547 Mdot
.44335 .40414 Mdot
.3755 .48078 Mdot
.35774 .54814 Mdot
.6731 .58406 Mdot
.40288 .64365 Mdot
.40253 .58596 Mdot
.53477 .75164 Mdot
.64786 .5963 Mdot
.40981 .42341 Mdot
.65479 .60697 Mdot
.42183 .45585 Mdot
.36866 .44625 Mdot
.64436 .55661 Mdot
.41552 .62802 Mdot
.73633 .65857 Mdot
.33642 .67968 Mdot
.42692 .42121 Mdot
.41442 .45137 Mdot
.52496 .23553 Mdot
.16939 .52742 Mdot
.37975 .48366 Mdot
.40617 .61322 Mdot
.40337 .44089 Mdot
.62803 .57663 Mdot
.54797 .28242 Mdot
.39565 .65206 Mdot
.6686 .41262 Mdot
.62951 .39896 Mdot
.58435 .42134 Mdot
.53976 .72313 Mdot
.38481 .48829 Mdot
.43528 .67173 Mdot
.41176 .60819 Mdot
.53471 .69146 Mdot
.65322 .43784 Mdot
.54327 .29539 Mdot
.42584 .40373 Mdot
.40286 .33673 Mdot
.63397 .59697 Mdot
.26536 .8011 Mdot
.53848 .65636 Mdot
.53751 .30295 Mdot
.46631 .56903 Mdot
.52967 .73115 Mdot
.37502 .47219 Mdot
.58363 .31703 Mdot
.64981 .40467 Mdot
.4187 .44017 Mdot
.44945 .48292 Mdot
.77128 .48993 Mdot
.66097 .40034 Mdot
.66069 .60472 Mdot
.65396 .40349 Mdot
.54519 .31925 Mdot
.54726 .72768 Mdot
.42565 .66328 Mdot
.38912 .45472 Mdot
.39067 .54016 Mdot
.64992 .43174 Mdot
.54328 .7545 Mdot
.36088 .42291 Mdot
.39628 .6789 Mdot
.65653 .4217 Mdot
.37701 .46043 Mdot
.21398 .48071 Mdot
.42345 .58221 Mdot
.63649 .42915 Mdot
.34392 .4227 Mdot
.49349 .40549 Mdot
.64765 .39414 Mdot
.60541 .43048 Mdot
.37788 .41741 Mdot
.5578 .3186 Mdot
.35732 .46297 Mdot
.65966 .57581 Mdot
.55559 .54278 Mdot
.6403 .59304 Mdot
.35483 .28602 Mdot
.39591 .38603 Mdot
.46637 .68564 Mdot
.37184 .63863 Mdot
.59372 .31654 Mdot
.31181 .67577 Mdot
.34913 .46737 Mdot
.77128 .6508 Mdot
.56175 .44781 Mdot
.56351 .67673 Mdot
.82812 .57244 Mdot
.55311 .28812 Mdot
.65481 .57765 Mdot
.37109 .42112 Mdot
.61763 .5498 Mdot
.55042 .30332 Mdot
.34949 .28819 Mdot
.34198 .43237 Mdot
.40259 .62034 Mdot
.36297 .43067 Mdot
.38318 .66939 Mdot
.40985 .44858 Mdot
.4604 .47749 Mdot
.53104 .31074 Mdot
.47493 .2081 Mdot
.37308 .48963 Mdot
.7621 .28869 Mdot
.47597 .36459 Mdot
.56632 .27745 Mdot
.42291 .41316 Mdot
.53855 .73346 Mdot
.6412 .55032 Mdot
.74476 .31533 Mdot
.61839 .43234 Mdot
.64753 .56168 Mdot
.41946 .65532 Mdot
.66024 .4666 Mdot
.53423 .75327 Mdot
.29248 .38512 Mdot
.56834 .32462 Mdot
.65348 .59744 Mdot
.3924 .45664 Mdot
.3555 .41855 Mdot
.72806 .33665 Mdot
.20407 .64657 Mdot
.38472 .61112 Mdot
.51815 .17156 Mdot
.42562 .68258 Mdot
.56478 .28928 Mdot
.6152 .42931 Mdot
.38607 .47529 Mdot
.38008 .43328 Mdot
.65194 .45444 Mdot
.41492 .61694 Mdot
.63067 .47806 Mdot
.23037 .39652 Mdot
.63143 .63002 Mdot
.46909 .24297 Mdot
.39483 .65616 Mdot
.46798 .23976 Mdot
.53874 .3071 Mdot
.80323 .51227 Mdot
.46697 .31962 Mdot
.6512 .60166 Mdot
.46954 .24686 Mdot
.38216 .6321 Mdot
.36705 .45671 Mdot
.54179 .7282 Mdot
.52266 .73625 Mdot
.40917 .66361 Mdot
.62921 .40776 Mdot
.57258 .31999 Mdot
.3683 .42976 Mdot
.49002 .69772 Mdot
.42927 .80813 Mdot
.66995 .43489 Mdot
.42703 .37371 Mdot
.66203 .55588 Mdot
.40872 .44301 Mdot
.57612 .27578 Mdot
.64288 .56954 Mdot
.54648 .72259 Mdot
.50856 .59647 Mdot
.42713 .40493 Mdot
.5046 .47696 Mdot
.65534 .59365 Mdot
.16591 .54397 Mdot
.37766 .42591 Mdot
.67159 .57975 Mdot
.34403 .50705 Mdot
.41737 .75935 Mdot
.56012 .39924 Mdot
.68711 .75604 Mdot
.63483 .38581 Mdot
.63346 .39862 Mdot
.29865 .75583 Mdot
.53471 .27108 Mdot
.62395 .56838 Mdot
.551 .73316 Mdot
.45933 .29254 Mdot
.67602 .5844 Mdot
.36504 .40378 Mdot
.43558 .42621 Mdot
.23533 .4113 Mdot
.50023 .38715 Mdot
.5306 .75659 Mdot
.30851 .39277 Mdot
.40145 .4069 Mdot
.41742 .49198 Mdot
.38921 .42856 Mdot
.43221 .64111 Mdot
.67694 .59099 Mdot
.82521 .34403 Mdot
.66793 .60583 Mdot
.49578 .68351 Mdot
.64189 .42696 Mdot
.66819 .44754 Mdot
.39051 .46166 Mdot
.46127 .64646 Mdot
.79043 .36256 Mdot
.41244 .4673 Mdot
.59945 .31155 Mdot
.38724 .26558 Mdot
.44056 .44023 Mdot
.38972 .59687 Mdot
.39079 .37438 Mdot
.40801 .68778 Mdot
.64017 .56838 Mdot
.55207 .28989 Mdot
.55764 .3364 Mdot
.65935 .58269 Mdot
.38911 .44314 Mdot
.58618 .34571 Mdot
.3839 .45642 Mdot
.36088 .45036 Mdot
.51633 .64918 Mdot
.57114 .26643 Mdot
.61929 .44092 Mdot
.5723 .30021 Mdot
.41401 .63559 Mdot
.09448 .49599 Mdot
.56456 .30945 Mdot
.4698 .37602 Mdot
.55217 .47458 Mdot
.4664 .24689 Mdot
.41221 .6748 Mdot
.55612 .27584 Mdot
.66974 .59882 Mdot
.55785 .68199 Mdot
.18142 .5656 Mdot
.68042 .57737 Mdot
.37723 .43236 Mdot
.37436 .66853 Mdot
.42151 .61418 Mdot
.67728 .60792 Mdot
.42701 .64178 Mdot
.44233 .46494 Mdot
.37664 .40126 Mdot
.62408 .57083 Mdot
.47291 .81429 Mdot
.67672 .59264 Mdot
.42548 .34375 Mdot
.41392 .39758 Mdot
.39805 .65076 Mdot
.31103 .4374 Mdot
.44796 .64877 Mdot
.52174 .73186 Mdot
.41625 .47299 Mdot
.5761 .30883 Mdot
.53118 .56907 Mdot
.63641 .42774 Mdot
.64938 .73468 Mdot
.38585 .67122 Mdot
.68541 .57868 Mdot
.42608 .65592 Mdot
.39622 .60849 Mdot
.68049 .58597 Mdot
.41039 .64266 Mdot
.36931 .42477 Mdot
.59211 .63159 Mdot
.38416 .66708 Mdot
.64694 .58712 Mdot
.57799 .31007 Mdot
.42093 .63394 Mdot
.615 .46804 Mdot
.36288 .45736 Mdot
.61129 .43753 Mdot
.57384 .26317 Mdot
.37288 .66864 Mdot
.55153 .27975 Mdot
.65226 .43402 Mdot
.57669 .31899 Mdot
.60798 .54733 Mdot
.63469 .52778 Mdot
.49947 .64774 Mdot
.3577 .70902 Mdot
.382 .62551 Mdot
.61937 .38864 Mdot
.38188 .47952 Mdot
.35532 .43992 Mdot
.55858 .3294 Mdot
.42236 .61326 Mdot
.62222 .78735 Mdot
.30531 .44555 Mdot
.54364 .78792 Mdot
.61906 .58325 Mdot
.43864 .19563 Mdot
.54344 .66371 Mdot
.57603 .68618 Mdot
.3333 .4692 Mdot
.53104 .73012 Mdot
.38252 .46278 Mdot
.38751 .24159 Mdot
.54836 .27971 Mdot
.72044 .5438 Mdot
.35638 .49251 Mdot
.62622 .43948 Mdot
.41003 .45795 Mdot
.76309 .31607 Mdot
.34511 .38684 Mdot
.56427 .27306 Mdot
.63698 .53535 Mdot
.3869 .61308 Mdot
.57464 .2826 Mdot
.62478 .40014 Mdot
.48416 .27305 Mdot
.35123 .40818 Mdot
.39734 .40394 Mdot
.60449 .40468 Mdot
.40963 .62167 Mdot
.65874 .43946 Mdot
.67031 .57758 Mdot
.56503 .30567 Mdot
.42356 .43157 Mdot
.44515 .44096 Mdot
.59806 .43427 Mdot
.66023 .60984 Mdot
.67209 .42959 Mdot
.6501 .60686 Mdot
.53303 .72867 Mdot
.38394 .48947 Mdot
.59863 .42626 Mdot
.35127 .49803 Mdot
.33742 .58045 Mdot
.51023 .63798 Mdot
.30295 .6528 Mdot
.61932 .442 Mdot
.49969 .24926 Mdot
.65497 .58466 Mdot
.66496 .59583 Mdot
.25711 .38959 Mdot
.79082 .37145 Mdot
.58473 .47058 Mdot
.71574 .25733 Mdot
.66975 .57678 Mdot
.6478 .59286 Mdot
.64833 .40541 Mdot
.41412 .64703 Mdot
.36355 .61711 Mdot
.62769 .46931 Mdot
.43419 .21461 Mdot
.38523 .62841 Mdot
.75541 .68425 Mdot
.62155 .39593 Mdot
.32817 .44537 Mdot
.52367 .75533 Mdot
.56919 .27475 Mdot
.39711 .23868 Mdot
.72761 .27215 Mdot
.38516 .47154 Mdot
.21802 .33154 Mdot
.62889 .41539 Mdot
.67926 .63614 Mdot
.78805 .55773 Mdot
.34052 .44504 Mdot
.40749 .45941 Mdot
.39194 .4405 Mdot
.5861 .27787 Mdot
.32691 .66768 Mdot
.38266 .47172 Mdot
.48566 .21058 Mdot
.41959 .39094 Mdot
.71258 .28189 Mdot
.57203 .30044 Mdot
.3417 .31785 Mdot
.64169 .3841 Mdot
.47464 .75681 Mdot
.41159 .50356 Mdot
.66832 .579 Mdot
.76245 .55252 Mdot
.63852 .55733 Mdot
.8049 .45001 Mdot
.46371 .31752 Mdot
.43262 .64025 Mdot
.39598 .4235 Mdot
.60579 .4065 Mdot
.37306 .66605 Mdot
.7134 .58071 Mdot
.10713 .452 Mdot
.63752 .6096 Mdot
.32495 .18957 Mdot
.66183 .59954 Mdot
.52224 .74027 Mdot
.41312 .66374 Mdot
.44357 .54519 Mdot
.53139 .59883 Mdot
.41443 .62825 Mdot
.65234 .35492 Mdot
.397 .58947 Mdot
.48795 .23819 Mdot
.43115 .61462 Mdot
.64905 .58262 Mdot
.64444 .53076 Mdot
.4061 .52078 Mdot
.38204 .48274 Mdot
.53618 .61346 Mdot
.35566 .50785 Mdot
.39827 .48234 Mdot
.6357 .4405 Mdot
.38462 .73754 Mdot
.68079 .62779 Mdot
.39721 .66254 Mdot
.63042 .59635 Mdot
.40827 .46017 Mdot
.42632 .42002 Mdot
.38538 .5032 Mdot
.35869 .26317 Mdot
.75796 .6779 Mdot
.36791 .44952 Mdot
.41443 .38047 Mdot
.61586 .412 Mdot
.72489 .31868 Mdot
.57992 .19877 Mdot
.46521 .29944 Mdot
.35585 .42568 Mdot
.56893 .28785 Mdot
.56074 .27021 Mdot
.45092 .44055 Mdot
.47723 .67938 Mdot
.61987 .4797 Mdot
.39266 .4566 Mdot
.49922 .33549 Mdot
.59583 .4449 Mdot
.54814 .75184 Mdot
.64989 .43239 Mdot
.37512 .6722 Mdot
.52437 .73938 Mdot
.66652 .43645 Mdot
.4356 .58181 Mdot
.53499 .75086 Mdot
.43167 .76191 Mdot
.54977 .27988 Mdot
.38502 .42763 Mdot
.43076 .6949 Mdot
.65101 .45379 Mdot
.657 .59559 Mdot
.39057 .64472 Mdot
.61646 .57409 Mdot
.72838 .32084 Mdot
.40924 .23546 Mdot
.53551 .72277 Mdot
.66588 .57673 Mdot
.49667 .53676 Mdot
.57014 .29064 Mdot
.67707 .5756 Mdot
.46141 .67935 Mdot
.43928 .43448 Mdot
.82103 .4395 Mdot
.39116 .40609 Mdot
.5713 .80506 Mdot
.66548 .5928 Mdot
.52393 .72321 Mdot
.38753 .45298 Mdot
.60945 .41004 Mdot
.38338 .52796 Mdot
.38253 .45484 Mdot
.65773 .40419 Mdot
.36725 .45415 Mdot
.58534 .28526 Mdot
.39349 .68834 Mdot
.55735 .44133 Mdot
.37578 .2325 Mdot
.58136 .31053 Mdot
.56112 .75199 Mdot
.38684 .48599 Mdot
.62262 .3007 Mdot
.40681 .62533 Mdot
.34288 .45677 Mdot
.24643 .34123 Mdot
.4106 .65757 Mdot
.39987 .63196 Mdot
.41284 .40878 Mdot
.67918 .57358 Mdot
.63377 .45299 Mdot
.57173 .29316 Mdot
.71035 .60507 Mdot
.3761 .46215 Mdot
.38949 .4224 Mdot
.57664 .28374 Mdot
.64485 .59383 Mdot
.42187 .4286 Mdot
.69052 .68184 Mdot
.52652 .6873 Mdot
.64053 .60158 Mdot
.43971 .43634 Mdot
.84092 .46225 Mdot
.3565 .63119 Mdot
.20395 .34706 Mdot
.53839 .26691 Mdot
.62389 .41147 Mdot
.44761 .39205 Mdot
.21895 .76016 Mdot
.56407 .27587 Mdot
.48611 .75928 Mdot
.36329 .44539 Mdot
.39889 .4777 Mdot
.42689 .66655 Mdot
.4104 .41877 Mdot
.37823 .65744 Mdot
.38301 .22376 Mdot
.7434 .25203 Mdot
.4259 .65207 Mdot
.37962 .66283 Mdot
.43216 .54239 Mdot
.34695 .27498 Mdot
.41837 .6528 Mdot
.35011 .4087 Mdot
.65405 .3473 Mdot
.46164 .43136 Mdot
.54151 .2778 Mdot
.58952 .32977 Mdot
.41136 .60003 Mdot
.2348 .66595 Mdot
.362 .52497 Mdot
.48081 .46554 Mdot
.58774 .25134 Mdot
.65803 .56691 Mdot
.43292 .42595 Mdot
.54355 .72416 Mdot
.65683 .41763 Mdot
.37226 .3758 Mdot
.38442 .43075 Mdot
.37692 .66592 Mdot
.58977 .28397 Mdot
.67507 .574 Mdot
.37861 .41939 Mdot
.66787 .47066 Mdot
.5571 .29373 Mdot
.38502 .66631 Mdot
.46666 .373 Mdot
.54085 .29137 Mdot
.43969 .46183 Mdot
.39967 .48074 Mdot
.36135 .42105 Mdot
.40307 .50959 Mdot
.66066 .58495 Mdot
.64332 .47333 Mdot
.4555 .42376 Mdot
.52316 .63792 Mdot
.53713 .55394 Mdot
.45432 .42305 Mdot
.4101 .61566 Mdot
.62314 .5647 Mdot
.53722 .74781 Mdot
.46018 .26751 Mdot
.40331 .39287 Mdot
.76564 .66262 Mdot
.21226 .40408 Mdot
.53122 .74475 Mdot
.43724 .65256 Mdot
.57489 .29792 Mdot
.40386 .40174 Mdot
.61278 .33251 Mdot
.37009 .40281 Mdot
.4069 .35396 Mdot
.62545 .41363 Mdot
.65832 .56286 Mdot
.51686 .69855 Mdot
.65769 .41806 Mdot
.4001 .63292 Mdot
.60292 .81825 Mdot
.38319 .59501 Mdot
.37487 .61773 Mdot
.79204 .46949 Mdot
.63992 .56445 Mdot
.24344 .78404 Mdot
.16788 .52851 Mdot
.3821 .39557 Mdot
.62948 .56659 Mdot
.40646 .66844 Mdot
.39196 .41402 Mdot
.38251 .62705 Mdot
.36787 .6185 Mdot
.42589 .46176 Mdot
.39165 .48206 Mdot
.46384 .21173 Mdot
.74885 .70579 Mdot
.57109 .31452 Mdot
.42698 .63259 Mdot
.22754 .42994 Mdot
.3809 .47269 Mdot
.35064 .43656 Mdot
.77308 .51718 Mdot
.56004 .27468 Mdot
.22626 .59505 Mdot
.35752 .43794 Mdot
.25023 .33504 Mdot
.40112 .48227 Mdot
.36886 .69936 Mdot
.68541 .60252 Mdot
.47949 .68875 Mdot
.63706 .45577 Mdot
.36885 .67108 Mdot
.54716 .31668 Mdot
.36723 .6715 Mdot
.25378 .40009 Mdot
.63766 .56653 Mdot
.37988 .65684 Mdot
.67402 .44606 Mdot
.63686 .58094 Mdot
.65135 .60236 Mdot
.57705 .43823 Mdot
.66435 .46122 Mdot
.58772 .28419 Mdot
.64628 .55182 Mdot
.22012 .46505 Mdot
.64661 .57945 Mdot
.23458 .42661 Mdot
.35959 .46931 Mdot
.47336 .21979 Mdot
.51025 .6943 Mdot
.40242 .51554 Mdot
.6781 .58702 Mdot
.56034 .31543 Mdot
.40542 .42373 Mdot
.42604 .63698 Mdot
.56087 .31001 Mdot
.6173 .60654 Mdot
.67567 .4285 Mdot
.41342 .60525 Mdot
.64988 .53651 Mdot
.37638 .64927 Mdot
.38772 .25453 Mdot
.65923 .48924 Mdot
.57569 .3746 Mdot
.53533 .59434 Mdot
.39225 .49901 Mdot
.47008 .50315 Mdot
.34459 .43061 Mdot
.38336 .43552 Mdot
.6374 .42915 Mdot
.52317 .22852 Mdot
.42048 .63219 Mdot
.4866 .83405 Mdot
.66683 .58288 Mdot
.48596 .52251 Mdot
.37526 .34832 Mdot
.42091 .45273 Mdot
.39203 .66667 Mdot
.36922 .61936 Mdot
.32675 .60804 Mdot
.65346 .45432 Mdot
.4585 .45718 Mdot
.43207 .49118 Mdot
.46471 .42606 Mdot
.65868 .60123 Mdot
.70907 .66838 Mdot
.66281 .45173 Mdot
.24103 .25651 Mdot
.65874 .42929 Mdot
.64037 .2878 Mdot
.41041 .64387 Mdot
.54451 .2981 Mdot
.35035 .44263 Mdot
.34363 .62861 Mdot
.40099 .68452 Mdot
.59103 .45169 Mdot
.57669 .29783 Mdot
.72547 .66211 Mdot
.64346 .56161 Mdot
.34966 .45897 Mdot
.42838 .45864 Mdot
.41774 .41633 Mdot
.37566 .40816 Mdot
.62264 .58169 Mdot
.36274 .40591 Mdot
.61801 .5625 Mdot
.20308 .49965 Mdot
.25207 .3399 Mdot
.60257 .42326 Mdot
.7129 .28995 Mdot
.39997 .60895 Mdot
.24074 .45912 Mdot
.22205 .59828 Mdot
.5099 .64167 Mdot
.60862 .53053 Mdot
.36871 .47966 Mdot
.63123 .40672 Mdot
.77237 .32233 Mdot
.60113 .41995 Mdot
.77698 .26456 Mdot
.29553 .35832 Mdot
.67329 .77289 Mdot
.38917 .40965 Mdot
.62355 .46866 Mdot
.25686 .66469 Mdot
.44671 .43049 Mdot
.58161 .3434 Mdot
.40705 .34423 Mdot
.47208 .79746 Mdot
.54291 .2943 Mdot
.36551 .45959 Mdot
.39857 .60557 Mdot
.36844 .42574 Mdot
.3544 .45351 Mdot
.41244 .46559 Mdot
.6515 .61628 Mdot
.4347 .44647 Mdot
.35684 .46209 Mdot
.18716 .62179 Mdot
.51426 .25727 Mdot
.61266 .41209 Mdot
.31128 .62738 Mdot
.56401 .29551 Mdot
.37163 .66274 Mdot
.56131 .4576 Mdot
.65587 .57052 Mdot
.3297 .59547 Mdot
.38998 .40819 Mdot
.51608 .77927 Mdot
.66653 .54834 Mdot
.55299 .30343 Mdot
.53921 .75018 Mdot
.76212 .62754 Mdot
.62129 .45402 Mdot
.52239 .74617 Mdot
.63586 .42677 Mdot
.29152 .6855 Mdot
.38087 .66756 Mdot
.39661 .49937 Mdot
.66685 .56347 Mdot
.60748 .43541 Mdot
.55078 .22175 Mdot
.39632 .43846 Mdot
.62029 .44361 Mdot
.39572 .49759 Mdot
.54159 .55674 Mdot
.55849 .47967 Mdot
.61739 .45676 Mdot
.6443 .53156 Mdot
.63464 .58199 Mdot
.54729 .3092 Mdot
.36862 .65712 Mdot
.39941 .6143 Mdot
.64097 .57289 Mdot
.23935 .27822 Mdot
.37748 .46325 Mdot
.40447 .47812 Mdot
.52767 .64266 Mdot
.38265 .41061 Mdot
.49599 .27011 Mdot
.55419 .75154 Mdot
.37859 .62775 Mdot
.3753 .41079 Mdot
.42251 .42829 Mdot
.42837 .40777 Mdot
.41063 .23675 Mdot
.65089 .42933 Mdot
.40208 .40608 Mdot
.57746 .32269 Mdot
.44882 .72645 Mdot
.3778 .47748 Mdot
.44161 .4514 Mdot
.37781 .65065 Mdot
.47059 .17947 Mdot
.66192 .59346 Mdot
.63297 .44771 Mdot
.62401 .39459 Mdot
.38366 .29038 Mdot
.36862 .68084 Mdot
.54586 .75793 Mdot
.7343 .42465 Mdot
.5505 .74131 Mdot
.56665 .27881 Mdot
.57441 .39906 Mdot
.66772 .47312 Mdot
.62393 .39872 Mdot
.63247 .53021 Mdot
.37158 .41295 Mdot
.40146 .48166 Mdot
.48543 .75372 Mdot
.41495 .46927 Mdot
.57817 .30426 Mdot
.64798 .53811 Mdot
.37895 .65103 Mdot
.58016 .28056 Mdot
.66755 .59537 Mdot
.4098 .62118 Mdot
.44111 .42354 Mdot
.39025 .50541 Mdot
.39288 .63888 Mdot
.39296 .67463 Mdot
.39579 .4657 Mdot
.25698 .70755 Mdot
.38154 .62177 Mdot
.38736 .65874 Mdot
.51642 .72745 Mdot
.61794 .45181 Mdot
.31969 .40663 Mdot
.63105 .56576 Mdot
.35963 .42697 Mdot
.60235 .42523 Mdot
.55017 .28494 Mdot
.39144 .6312 Mdot
.42818 .41347 Mdot
.37363 .45314 Mdot
.57021 .28831 Mdot
.55918 .26648 Mdot
.58108 .30277 Mdot
.63278 .61028 Mdot
.38121 .40141 Mdot
.42032 .64923 Mdot
.6408 .5607 Mdot
.55864 .27112 Mdot
.57674 .3305 Mdot
.18374 .60754 Mdot
.38582 .47007 Mdot
.59894 .34181 Mdot
.10054 .55051 Mdot
.48297 .28206 Mdot
.52662 .7486 Mdot
.6079 .45082 Mdot
.48299 .21951 Mdot
.55689 .25476 Mdot
.62887 .56105 Mdot
.50597 .35088 Mdot
.59472 .30086 Mdot
.42516 .45829 Mdot
.40885 .43997 Mdot
.3315 .4508 Mdot
.55952 .30056 Mdot
.39707 .24835 Mdot
.41855 .61352 Mdot
.25492 .54446 Mdot
.56396 .2957 Mdot
.6186 .45781 Mdot
.60042 .43524 Mdot
.65992 .43048 Mdot
.36483 .47813 Mdot
.31742 .6395 Mdot
.22064 .44664 Mdot
.23499 .59555 Mdot
.64698 .56211 Mdot
.37473 .61249 Mdot
.61092 .52226 Mdot
.39973 .63107 Mdot
.64855 .41371 Mdot
.55596 .29964 Mdot
.4315 .65747 Mdot
.64041 .59662 Mdot
.63685 .58949 Mdot
.67228 .41775 Mdot
.65007 .43696 Mdot
.64319 .4482 Mdot
.36856 .66826 Mdot
.41056 .64287 Mdot
.42613 .42846 Mdot
.38538 .64061 Mdot
.19042 .43428 Mdot
.54149 .27574 Mdot
.60821 .39945 Mdot
.65585 .59095 Mdot
.39123 .66999 Mdot
.38233 .42623 Mdot
.6846 .31072 Mdot
.58816 .44007 Mdot
.58426 .30492 Mdot
.56921 .59733 Mdot
.66598 .18289 Mdot
.42758 .46636 Mdot
.64636 .60832 Mdot
.47199 .68277 Mdot
.39786 .44512 Mdot
.61868 .42442 Mdot
.28492 .34865 Mdot
.54715 .75013 Mdot
.36491 .46923 Mdot
.34833 .47279 Mdot
.67979 .58377 Mdot
.56038 .46632 Mdot
.41913 .46354 Mdot
.52149 .47434 Mdot
.65029 .61271 Mdot
.66384 .45055 Mdot
.32818 .79372 Mdot
.62858 .62653 Mdot
.4822 .20097 Mdot
.52922 .74854 Mdot
.4287 .45384 Mdot
.63549 .43755 Mdot
.58539 .31003 Mdot
.64157 .43655 Mdot
.43601 .62911 Mdot
.61513 .44329 Mdot
.3971 .43323 Mdot
.41976 .64581 Mdot
.64954 .59643 Mdot
.4922 .5015 Mdot
.21336 .6515 Mdot
.61052 .40945 Mdot
.55384 .72966 Mdot
.37344 .47236 Mdot
.20825 .52495 Mdot
.4089 .52146 Mdot
.37745 .48179 Mdot
.64002 .55612 Mdot
.39434 .66553 Mdot
.61845 .57803 Mdot
.43348 .46255 Mdot
.26647 .42477 Mdot
.66522 .5817 Mdot
.43879 .7841 Mdot
.57499 .28125 Mdot
.43116 .21621 Mdot
.38088 .4418 Mdot
.66651 .56372 Mdot
.38261 .40051 Mdot
.42692 .63082 Mdot
.51838 .56406 Mdot
.45195 .71604 Mdot
.66062 .55463 Mdot
.58503 .81116 Mdot
.54387 .50177 Mdot
.33485 .39024 Mdot
.67162 .57581 Mdot
.31204 .66924 Mdot
.53941 .73659 Mdot
.55895 .28568 Mdot
.56195 .26802 Mdot
.56267 .32651 Mdot
.41404 .47074 Mdot
.46803 .41507 Mdot
.58637 .32259 Mdot
.62753 .60444 Mdot
.58872 .31047 Mdot
.36269 .2691 Mdot
.60289 .7941 Mdot
.58258 .29925 Mdot
.37723 .44015 Mdot
.44238 .44541 Mdot
.51644 .25449 Mdot
.65975 .45947 Mdot
.77206 .64026 Mdot
.17892 .5256 Mdot
.38794 .47572 Mdot
.30002 .36476 Mdot
.42606 .61307 Mdot
.46891 .60832 Mdot
.29912 .4209 Mdot
.57266 .45798 Mdot
.38708 .66315 Mdot
.54988 .56514 Mdot
.37456 .63377 Mdot
.41234 .49117 Mdot
.36822 .44509 Mdot
.39927 .6865 Mdot
.63998 .72958 Mdot
.3774 .77598 Mdot
.55982 .79249 Mdot
.40332 .61294 Mdot
.67329 .58403 Mdot
.64521 .61012 Mdot
.64609 .55739 Mdot
.64612 .45329 Mdot
.39226 .67685 Mdot
.39855 .39745 Mdot
.6256 .40227 Mdot
.35281 .43893 Mdot
.63406 .57314 Mdot
.52664 .68848 Mdot
.37864 .65268 Mdot
.3921 .45417 Mdot
.18493 .57303 Mdot
.64067 .42165 Mdot
.56827 .28954 Mdot
.57683 .62255 Mdot
.60424 .44794 Mdot
.67103 .60332 Mdot
.35662 .6655 Mdot
.62199 .37653 Mdot
.64272 .26137 Mdot
.34369 .41199 Mdot
.35526 .40408 Mdot
.68492 .52787 Mdot
.20389 .62453 Mdot
.41638 .45847 Mdot
.62592 .3992 Mdot
.61968 .45637 Mdot
.38026 .39906 Mdot
.42244 .66662 Mdot
.5932 .30767 Mdot
.55652 .32763 Mdot
.37397 .49359 Mdot
.5376 .60344 Mdot
.47166 .21537 Mdot
.4149 .42471 Mdot
.38816 .35705 Mdot
.67309 .4454 Mdot
.53338 .75277 Mdot
.52159 .6127 Mdot
.55177 .31862 Mdot
.36178 .44515 Mdot
.394 .78338 Mdot
.38141 .6604 Mdot
.62829 .45022 Mdot
.62884 .58646 Mdot
.57742 .34513 Mdot
.63887 .39022 Mdot
.38053 .39898 Mdot
.42203 .42834 Mdot
.67242 .56701 Mdot
.37197 .70221 Mdot
.55766 .30213 Mdot
.62235 .4051 Mdot
.54443 .29938 Mdot
.41128 .63587 Mdot
.38445 .656 Mdot
.43572 .48704 Mdot
.39975 .51862 Mdot
.6202 .39778 Mdot
.33845 .46218 Mdot
.66239 .42584 Mdot
.72769 .33322 Mdot
.63301 .59634 Mdot
.34075 .4511 Mdot
.40517 .69855 Mdot
.6352 .57247 Mdot
.39794 .47387 Mdot
.68425 .52857 Mdot
.41934 .43704 Mdot
.62632 .46948 Mdot
.25825 .37149 Mdot
.54961 .3032 Mdot
.46886 .50123 Mdot
.40045 .55176 Mdot
.38352 .41129 Mdot
.65054 .46869 Mdot
.46953 .45283 Mdot
.66251 .58044 Mdot
.4063 .65458 Mdot
.38953 .18045 Mdot
.646 .58431 Mdot
.36696 .43282 Mdot
.56384 .30797 Mdot
.38336 .61424 Mdot
.53125 .72573 Mdot
.53939 .64162 Mdot
.35794 .38079 Mdot
.32411 .44818 Mdot
.36837 .41833 Mdot
.7159 .25623 Mdot
.63964 .44426 Mdot
.39833 .67024 Mdot
.63839 .60585 Mdot
.64713 .56922 Mdot
.64836 .42066 Mdot
.49983 .80121 Mdot
.65964 .74136 Mdot
.11192 .59687 Mdot
.63417 .39255 Mdot
.58166 .32336 Mdot
.53168 .54798 Mdot
.65916 .41858 Mdot
.63174 .44142 Mdot
.67641 .42373 Mdot
.49846 .75329 Mdot
.41216 .61987 Mdot
.37271 .45444 Mdot
.37373 .68554 Mdot
.4269 .45737 Mdot
.53444 .21202 Mdot
.64073 .5702 Mdot
.40752 .65237 Mdot
.6729 .49009 Mdot
.33668 .49791 Mdot
.40533 .45217 Mdot
.61371 .34377 Mdot
.36359 .38267 Mdot
.46688 .25567 Mdot
.39803 .50578 Mdot
.64493 .43127 Mdot
.28915 .41104 Mdot
.43697 .38478 Mdot
.18371 .54828 Mdot
.6421 .59527 Mdot
.52752 .72458 Mdot
.43967 .41437 Mdot
.37188 .36742 Mdot
.37854 .61777 Mdot
.43117 .65907 Mdot
.58781 .32106 Mdot
.58925 .63705 Mdot
.64517 .59667 Mdot
.71045 .71321 Mdot
.38384 .48417 Mdot
.697 .62048 Mdot
.25553 .37138 Mdot
.39974 .47013 Mdot
.58152 .39351 Mdot
.32913 .5983 Mdot
.42005 .45018 Mdot
.24369 .59316 Mdot
.65312 .58806 Mdot
.24908 .33728 Mdot
.35561 .48831 Mdot
.61925 .42535 Mdot
.41273 .6482 Mdot
.41395 .60589 Mdot
.58533 .29819 Mdot
.17755 .47376 Mdot
.65749 .52576 Mdot
.41022 .64671 Mdot
.39245 .43831 Mdot
.65934 .59374 Mdot
.52491 .7274 Mdot
.32491 .42105 Mdot
.79303 .41512 Mdot
.3826 .64421 Mdot
.45391 .40857 Mdot
.5514 .79245 Mdot
.55303 .51154 Mdot
.75678 .69606 Mdot
.65101 .55617 Mdot
.55234 .32019 Mdot
.3798 .50904 Mdot
.73304 .42581 Mdot
.36202 .49443 Mdot
.51062 .20564 Mdot
.44973 .64712 Mdot
.54769 .28287 Mdot
.39568 .44721 Mdot
.41921 .46245 Mdot
.53131 .57983 Mdot
.55256 .27013 Mdot
.42006 .46266 Mdot
.45345 .45972 Mdot
.40613 .62005 Mdot
.55583 .74858 Mdot
.37983 .64478 Mdot
.37723 .43098 Mdot
.31956 .33623 Mdot
.42936 .65807 Mdot
.75569 .64856 Mdot
.52883 .27441 Mdot
.65668 .57075 Mdot
.40944 .36511 Mdot
.36609 .47525 Mdot
.85276 .54825 Mdot
.52158 .73284 Mdot
.5308 .18121 Mdot
.61628 .46072 Mdot
.4404 .83494 Mdot
.60214 .44714 Mdot
.64639 .79523 Mdot
.49219 .51936 Mdot
.33505 .44041 Mdot
.48538 .33625 Mdot
.23648 .58654 Mdot
.62216 .54527 Mdot
.22344 .48979 Mdot
.38187 .4826 Mdot
.37061 .46543 Mdot
.64036 .40223 Mdot
.51833 .79973 Mdot
.47372 .69094 Mdot
.52469 .60494 Mdot
.55323 .2977 Mdot
.40601 .64039 Mdot
.40138 .43679 Mdot
.61232 .70379 Mdot
.60861 .42013 Mdot
.45616 .35161 Mdot
.38952 .45263 Mdot
.49065 .68263 Mdot
.47322 .78211 Mdot
.65588 .59743 Mdot
.62461 .46563 Mdot
.64743 .47222 Mdot
.43518 .42977 Mdot
.62551 .57004 Mdot
.4255 .43925 Mdot
.54136 .50522 Mdot
.40968 .38004 Mdot
.55681 .27895 Mdot
.34894 .44019 Mdot
.49793 .35973 Mdot
.63878 .81515 Mdot
.41188 .37475 Mdot
.36914 .63583 Mdot
.65151 .44981 Mdot
.65415 .42656 Mdot
.39919 .61398 Mdot
.65411 .42519 Mdot
.25743 .55501 Mdot
.25182 .41733 Mdot
.56324 .2773 Mdot
.21891 .60465 Mdot
.55057 .29702 Mdot
.52903 .72375 Mdot
.3896 .46979 Mdot
.7459 .43536 Mdot
.63369 .39219 Mdot
.3193 .29259 Mdot
.646 .57592 Mdot
.52159 .73487 Mdot
.40594 .39029 Mdot
.60698 .32293 Mdot
.64134 .40894 Mdot
.75578 .58514 Mdot
.42933 .41066 Mdot
.42136 .62496 Mdot
.42019 .454 Mdot
.37882 .38469 Mdot
.52491 .74874 Mdot
.36841 .41723 Mdot
.6677 .59524 Mdot
.3915 .67743 Mdot
.65133 .78759 Mdot
.64915 .45395 Mdot
.36453 .46506 Mdot
.39329 .43973 Mdot
.43214 .66032 Mdot
.40567 .38897 Mdot
.62998 .56134 Mdot
.30499 .8345 Mdot
.57259 .2799 Mdot
.53558 .75352 Mdot
.75433 .61384 Mdot
.40129 .42974 Mdot
.41011 .42581 Mdot
.70022 .56332 Mdot
.36566 .75388 Mdot
.66871 .58542 Mdot
.41629 .38752 Mdot
.61369 .41681 Mdot
.55802 .3082 Mdot
.64038 .55023 Mdot
.37685 .40197 Mdot
.37229 .46642 Mdot
.56165 .27589 Mdot
.61434 .3398 Mdot
.62091 .47395 Mdot
.64609 .56011 Mdot
.30771 .36267 Mdot
.69222 .31666 Mdot
.38141 .46027 Mdot
.57649 .77728 Mdot
.39069 .65751 Mdot
.66845 .57181 Mdot
.32828 .67523 Mdot
.40135 .49589 Mdot
.67372 .59854 Mdot
.64781 .59634 Mdot
.41592 .39369 Mdot
.36622 .67945 Mdot
.36067 .64689 Mdot
.38975 .65947 Mdot
.26538 .33361 Mdot
.6209 .2208 Mdot
.64196 .4493 Mdot
.65125 .59139 Mdot
.60029 .42538 Mdot
.58895 .32437 Mdot
.53744 .55641 Mdot
.61769 .45547 Mdot
.40084 .60822 Mdot
.60089 .41257 Mdot
.42311 .43697 Mdot
.6344 .59002 Mdot
.6302 .39549 Mdot
.39733 .41672 Mdot
.40339 .35873 Mdot
.49438 .35405 Mdot
.59258 .29588 Mdot
.54902 .56942 Mdot
.37101 .43146 Mdot
.53626 .74918 Mdot
.39429 .46288 Mdot
.62403 .57011 Mdot
.50997 .37196 Mdot
.39716 .40845 Mdot
.62929 .39205 Mdot
.65235 .26071 Mdot
.64707 .46736 Mdot
.38946 .38488 Mdot
.37644 .43162 Mdot
.38027 .46265 Mdot
.41571 .47244 Mdot
.4544 .79214 Mdot
.61795 .5606 Mdot
.43383 .36815 Mdot
.65419 .39543 Mdot
.39601 .63129 Mdot
.43064 .63993 Mdot
.58941 .47676 Mdot
.51863 .73774 Mdot
.62703 .56924 Mdot
.37872 .46224 Mdot
.75586 .58396 Mdot
.55419 .67212 Mdot
.5663 .79455 Mdot
.58351 .45627 Mdot
.62685 .39785 Mdot
.36673 .64085 Mdot
.66339 .41346 Mdot
.37332 .4014 Mdot
.39511 .50668 Mdot
.66766 .77561 Mdot
.6413 .61752 Mdot
.55706 .30027 Mdot
.35247 .43717 Mdot
.45495 .20761 Mdot
.61593 .4119 Mdot
.67153 .45003 Mdot
.42706 .43658 Mdot
.3684 .61315 Mdot
.72004 .75926 Mdot
.62541 .57873 Mdot
.20858 .51482 Mdot
.43258 .70407 Mdot
.38114 .34448 Mdot
.65832 .58072 Mdot
.56933 .38561 Mdot
.65625 .45918 Mdot
.17833 .50851 Mdot
.39144 .63796 Mdot
.55821 .29636 Mdot
.45296 .44849 Mdot
.39993 .60813 Mdot
.59685 .42727 Mdot
.37187 .65114 Mdot
.39996 .49892 Mdot
.62537 .59951 Mdot
.6575 .42514 Mdot
.62614 .54723 Mdot
.39597 .68522 Mdot
.55011 .29991 Mdot
.33205 .29156 Mdot
.20637 .50898 Mdot
.32933 .59821 Mdot
.40232 .40561 Mdot
.7656 .4557 Mdot
.39998 .39633 Mdot
.37006 .6218 Mdot
.38025 .44132 Mdot
.48235 .48774 Mdot
.66865 .44666 Mdot
.44828 .39985 Mdot
.34951 .45036 Mdot
.1893 .51511 Mdot
.40518 .4621 Mdot
.3991 .39087 Mdot
.36047 .48642 Mdot
.39689 .71377 Mdot
.4509 .40955 Mdot
.42171 .62652 Mdot
.49154 .76389 Mdot
.63042 .43936 Mdot
.56914 .33366 Mdot
.54423 .31634 Mdot
.50438 .20332 Mdot
.43875 .2134 Mdot
.50417 .79772 Mdot
.38867 .62543 Mdot
.67103 .59698 Mdot
.42518 .43667 Mdot
.30748 .68363 Mdot
.4018 .32069 Mdot
.65914 .45597 Mdot
.61223 .40227 Mdot
.43458 .492 Mdot
.7728 .29968 Mdot
.45177 .40806 Mdot
.53655 .65381 Mdot
.42112 .46509 Mdot
.34253 .45848 Mdot
.67185 .45248 Mdot
.38812 .25045 Mdot
.40188 .40603 Mdot
.37882 .61783 Mdot
.56036 .29003 Mdot
.2957 .3802 Mdot
.37444 .31541 Mdot
.39178 .33419 Mdot
.44843 .61416 Mdot
.37809 .40478 Mdot
.62193 .40895 Mdot
.3937 .61069 Mdot
.52362 .63052 Mdot
.64058 .55903 Mdot
.53716 .62292 Mdot
.2091 .48204 Mdot
.61696 .62194 Mdot
.55715 .29428 Mdot
.59648 .46823 Mdot
.39641 .43211 Mdot
.64528 .45278 Mdot
.42214 .47866 Mdot
.55841 .67143 Mdot
.5499 .28308 Mdot
.3737 .67749 Mdot
.67326 .58515 Mdot
.41449 .61499 Mdot
.30425 .65026 Mdot
.38841 .32117 Mdot
.44077 .83568 Mdot
.62448 .45615 Mdot
.30477 .49182 Mdot
.41073 .66177 Mdot
.41625 .39753 Mdot
.11063 .58727 Mdot
.39391 .65558 Mdot
.41572 .61774 Mdot
.5698 .45354 Mdot
.35481 .28585 Mdot
.44436 .38887 Mdot
.37457 .63724 Mdot
.63489 .38279 Mdot
.57326 .30513 Mdot
.40372 .41875 Mdot
.37864 .4929 Mdot
.42912 .66262 Mdot
.64352 .41151 Mdot
.4567 .20345 Mdot
.64819 .43401 Mdot
.41657 .6262 Mdot
.63184 .42189 Mdot
.74638 .65121 Mdot
.61008 .43034 Mdot
.34931 .45194 Mdot
.37895 .46122 Mdot
.76765 .3915 Mdot
.38445 .65592 Mdot
.40736 .42489 Mdot
.36558 .45058 Mdot
.41786 .65511 Mdot
.67417 .46617 Mdot
.34331 .59466 Mdot
.39362 .4184 Mdot
.37525 .45875 Mdot
.54627 .28257 Mdot
.55101 .5399 Mdot
.58957 .71193 Mdot
.40495 .42096 Mdot
.56773 .3271 Mdot
.36792 .66685 Mdot
.39605 .46323 Mdot
.38798 .24826 Mdot
.59566 .44213 Mdot
.36173 .40924 Mdot
.53602 .7243 Mdot
.4138 .46356 Mdot
.71259 .765 Mdot
.36986 .46846 Mdot
.41137 .66618 Mdot
.41189 .65501 Mdot
.60556 .46472 Mdot
.39968 .63516 Mdot
.52478 .74481 Mdot
.63479 .57809 Mdot
.55959 .81395 Mdot
.52363 .73988 Mdot
.3448 .45661 Mdot
.16764 .52777 Mdot
.38031 .49512 Mdot
.44615 .42236 Mdot
.33659 .28228 Mdot
.52744 .74567 Mdot
.39775 .66585 Mdot
.64183 .7253 Mdot
.33903 .4317 Mdot
.62503 .5754 Mdot
.44616 .43475 Mdot
.36071 .40967 Mdot
.50073 .39858 Mdot
.26316 .40344 Mdot
.64428 .53752 Mdot
.32178 .4048 Mdot
.40497 .41916 Mdot
.35614 .74294 Mdot
.3917 .43251 Mdot
.58333 .29716 Mdot
.38739 .6225 Mdot
.66716 .41832 Mdot
.5719 .28395 Mdot
.39977 .43197 Mdot
.56116 .29842 Mdot
.63883 .44947 Mdot
.65297 .55223 Mdot
.35012 .43538 Mdot
.5402 .28206 Mdot
.55559 .30249 Mdot
.4213 .40912 Mdot
.41022 .64944 Mdot
.41274 .52331 Mdot
.39744 .46459 Mdot
.38688 .39654 Mdot
.39917 .61441 Mdot
.16049 .41605 Mdot
.43148 .45147 Mdot
.573 .38458 Mdot
.42578 .68004 Mdot
.53989 .7576 Mdot
.65575 .40654 Mdot
.35304 .49791 Mdot
.64338 .56633 Mdot
.63785 .57411 Mdot
.66902 .40621 Mdot
.41181 .67944 Mdot
.65609 .42132 Mdot
.33127 .40074 Mdot
.43168 .49516 Mdot
.45206 .45457 Mdot
.39213 .17969 Mdot
.76287 .62372 Mdot
.40712 .67346 Mdot
.65423 .46287 Mdot
.53434 .6101 Mdot
.62803 .57486 Mdot
.67841 .41771 Mdot
.41924 .69145 Mdot
.38051 .67194 Mdot
.39227 .61376 Mdot
.55973 .32167 Mdot
.65492 .43688 Mdot
.44738 .64397 Mdot
.35843 .64925 Mdot
.42813 .42376 Mdot
.40535 .41827 Mdot
.40909 .59396 Mdot
.51213 .26875 Mdot
.55121 .28631 Mdot
.62038 .41527 Mdot
.8447 .61232 Mdot
.62526 .57956 Mdot
.1886 .51725 Mdot
.39662 .41697 Mdot
.1104 .40888 Mdot
.45223 .41422 Mdot
.39236 .43661 Mdot
.37527 .67246 Mdot
.5421 .31865 Mdot
.57045 .30461 Mdot
.41134 .66065 Mdot
.35691 .63796 Mdot
.57003 .32244 Mdot
.57439 .42664 Mdot
.56586 .82696 Mdot
.52748 .62412 Mdot
.41749 .66095 Mdot
.20279 .53331 Mdot
.64465 .54969 Mdot
.40387 .69096 Mdot
.6332 .54056 Mdot
.63029 .44149 Mdot
.60747 .41062 Mdot
.67047 .56329 Mdot
.417 .39631 Mdot
.61888 .44589 Mdot
.38381 .37319 Mdot
.71842 .72466 Mdot
.81202 .47503 Mdot
.3312 .75394 Mdot
.38979 .48761 Mdot
.47783 .68323 Mdot
.46049 .74544 Mdot
.37618 .4166 Mdot
.31018 .44749 Mdot
.55834 .29959 Mdot
.41074 .68854 Mdot
.62884 .55354 Mdot
.77814 .64544 Mdot
.38068 .46099 Mdot
.42019 .63159 Mdot
.62993 .58314 Mdot
.74113 .65083 Mdot
.52315 .47096 Mdot
.42877 .44595 Mdot
.13896 .66112 Mdot
.39232 .68396 Mdot
.6673 .41905 Mdot
.20197 .59895 Mdot
.38005 .69042 Mdot
.68354 .3004 Mdot
.64614 .47446 Mdot
.56461 .71413 Mdot
.37544 .6668 Mdot
.65314 .48287 Mdot
.40901 .63388 Mdot
.58416 .28395 Mdot
.35675 .66751 Mdot
.6403 .41674 Mdot
.40042 .45301 Mdot
.64335 .41943 Mdot
.56708 .27347 Mdot
.62979 .45477 Mdot
.62984 .553 Mdot
.53132 .74932 Mdot
.6336 .58454 Mdot
.53779 .55057 Mdot
.3089 .51841 Mdot
.65792 .56255 Mdot
.7667 .56089 Mdot
.41602 .45396 Mdot
.36685 .69711 Mdot
.66895 .41822 Mdot
.62139 .3901 Mdot
.54361 .58945 Mdot
.41546 .62976 Mdot
.63331 .41509 Mdot
.21261 .48305 Mdot
.21622 .29887 Mdot
.41647 .37056 Mdot
.63292 .22654 Mdot
.41853 .6557 Mdot
.66986 .44607 Mdot
.5294 .64453 Mdot
.42482 .61686 Mdot
.6245 .39601 Mdot
.67305 .57742 Mdot
.65056 .57037 Mdot
.43037 .40851 Mdot
.68217 .6045 Mdot
.65303 .46835 Mdot
.38695 .77654 Mdot
.38991 .61906 Mdot
.74436 .62714 Mdot
.58146 .30906 Mdot
.63365 .44513 Mdot
.44484 .39147 Mdot
.43915 .60778 Mdot
.61688 .39611 Mdot
.79338 .38859 Mdot
.85717 .57505 Mdot
.6321 .41524 Mdot
.38642 .62366 Mdot
.39377 .62851 Mdot
.41639 .37599 Mdot
.53317 .59766 Mdot
.63853 .41067 Mdot
.74646 .43118 Mdot
.51521 .21013 Mdot
.5327 .72861 Mdot
.17682 .57728 Mdot
.40068 .40573 Mdot
.37495 .40494 Mdot
.63386 .55915 Mdot
.40774 .45151 Mdot
.36499 .62301 Mdot
.45329 .42877 Mdot
.64263 .61094 Mdot
.66188 .45222 Mdot
.3854 .46674 Mdot
.56229 .31633 Mdot
.63065 .55813 Mdot
.67165 .60637 Mdot
.62906 .42905 Mdot
.38163 .62536 Mdot
.62505 .73733 Mdot
.64946 .43476 Mdot
.38255 .40245 Mdot
.5323 .74032 Mdot
.38497 .50303 Mdot
.7653 .40659 Mdot
.41644 .61211 Mdot
.66435 .41546 Mdot
.43676 .65794 Mdot
.64615 .5905 Mdot
.65002 .38821 Mdot
.38798 .42557 Mdot
.61823 .40125 Mdot
.5689 .37617 Mdot
.63984 .32502 Mdot
.35797 .64359 Mdot
.59716 .28555 Mdot
.43193 .65857 Mdot
.53262 .72815 Mdot
.42048 .28569 Mdot
.55707 .28478 Mdot
.61302 .43356 Mdot
.76448 .64304 Mdot
.66779 .41069 Mdot
.40466 .4653 Mdot
.39559 .48081 Mdot
.64376 .40305 Mdot
.55258 .31455 Mdot
.40941 .21352 Mdot
.58057 .24076 Mdot
.3829 .6675 Mdot
.47884 .54737 Mdot
.81751 .65387 Mdot
.6645 .38608 Mdot
.67474 .59286 Mdot
.33513 .3788 Mdot
.41684 .43884 Mdot
.67996 .58623 Mdot
.63048 .59566 Mdot
.56038 .27086 Mdot
.64128 .45286 Mdot
.44139 .6609 Mdot
.65399 .54847 Mdot
.37251 .5522 Mdot
.41545 .22363 Mdot
.36601 .38427 Mdot
.46555 .44817 Mdot
.35778 .46938 Mdot
.55336 .51387 Mdot
.62386 .59355 Mdot
.37089 .43746 Mdot
.42187 .50243 Mdot
.66769 .57403 Mdot
.57244 .27425 Mdot
.39031 .57458 Mdot
.62462 .42134 Mdot
.16933 .33879 Mdot
.34961 .43685 Mdot
.40039 .45783 Mdot
.64714 .56235 Mdot
.21835 .64671 Mdot
.41654 .6668 Mdot
.37957 .62969 Mdot
.64023 .44514 Mdot
.55008 .59846 Mdot
.39217 .38982 Mdot
.37359 .42112 Mdot
.61674 .43692 Mdot
.53537 .74826 Mdot
.30828 .75799 Mdot
.37436 .45118 Mdot
.65666 .58649 Mdot
.76052 .55608 Mdot
.6211 .58799 Mdot
.42679 .46835 Mdot
.40395 .46917 Mdot
.34621 .43888 Mdot
.41161 .47879 Mdot
.66369 .55415 Mdot
.37722 .41886 Mdot
.37661 .52459 Mdot
.39336 .66365 Mdot
.38912 .40566 Mdot
.49355 .20817 Mdot
.3784 .45367 Mdot
.56213 .31537 Mdot
.59578 .71987 Mdot
.36337 .46136 Mdot
.38612 .4049 Mdot
.58616 .24498 Mdot
.3917 .44362 Mdot
.64385 .60056 Mdot
.39121 .63474 Mdot
.64929 .59267 Mdot
.66012 .60016 Mdot
.60638 .40479 Mdot
.5727 .26936 Mdot
.35047 .48628 Mdot
.57215 .32336 Mdot
.40997 .37839 Mdot
.40404 .49596 Mdot
.54517 .54872 Mdot
.53746 .6547 Mdot
.56226 .25402 Mdot
.38239 .42372 Mdot
.6366 .44088 Mdot
.65886 .40719 Mdot
.5051 .34584 Mdot
.38868 .37437 Mdot
.64121 .54912 Mdot
.6669 .56424 Mdot
.49493 .27631 Mdot
.51453 .43313 Mdot
.55693 .31096 Mdot
.5059 .58734 Mdot
.37382 .4879 Mdot
.36434 .45518 Mdot
.44351 .44254 Mdot
.60785 .44634 Mdot
.53327 .75137 Mdot
.65987 .45304 Mdot
.52895 .71527 Mdot
.61801 .56966 Mdot
.3888 .48743 Mdot
.80952 .5089 Mdot
.41731 .67336 Mdot
.39008 .63616 Mdot
.64774 .61196 Mdot
.64824 .46761 Mdot
.39801 .37606 Mdot
.41943 .15924 Mdot
.39677 .59903 Mdot
.56255 .33127 Mdot
.37046 .42561 Mdot
.63031 .43291 Mdot
.39526 .67938 Mdot
.57056 .26391 Mdot
.38249 .48675 Mdot
.68092 .42993 Mdot
.38017 .44684 Mdot
.24662 .61326 Mdot
.40036 .6614 Mdot
.52921 .68784 Mdot
.37733 .5999 Mdot
.67823 .58814 Mdot
.66709 .59129 Mdot
.39926 .47318 Mdot
.30946 .21296 Mdot
.39304 .58437 Mdot
.67956 .57169 Mdot
.58811 .28831 Mdot
.53872 .75242 Mdot
.58201 .27609 Mdot
.66183 .42265 Mdot
.55864 .29052 Mdot
.62473 .39411 Mdot
.50534 .29438 Mdot
.43068 .60994 Mdot
.57136 .28087 Mdot
.22249 .6573 Mdot
.38843 .50542 Mdot
.55489 .27222 Mdot
.43751 .48894 Mdot
.42359 .54479 Mdot
.61911 .4378 Mdot
.55683 .31704 Mdot
.42723 .41215 Mdot
.78716 .58866 Mdot
.6647 .59631 Mdot
.63748 .54978 Mdot
.35818 .49244 Mdot
.67534 .43512 Mdot
.35644 .6511 Mdot
.55517 .45053 Mdot
.54328 .75708 Mdot
.37406 .4216 Mdot
.38008 .48807 Mdot
.41932 .67941 Mdot
.3788 .61397 Mdot
.40247 .47262 Mdot
.21927 .47393 Mdot
.39583 .43054 Mdot
.6541 .57277 Mdot
.38878 .67472 Mdot
.39057 .63228 Mdot
.63297 .46905 Mdot
.41254 .67888 Mdot
.46266 .43051 Mdot
.63459 .52476 Mdot
.43958 .47593 Mdot
.6448 .58716 Mdot
.51497 .37034 Mdot
.643 .4549 Mdot
.77478 .63693 Mdot
.40194 .68125 Mdot
.37363 .41075 Mdot
.43077 .64443 Mdot
.58072 .30281 Mdot
.38385 .65439 Mdot
.42389 .60869 Mdot
.38602 .48281 Mdot
.42886 .45206 Mdot
.53429 .74524 Mdot
.53708 .59904 Mdot
.40223 .65511 Mdot
.3905 .42004 Mdot
.35522 .48605 Mdot
.43539 .43812 Mdot
.54512 .50066 Mdot
.37155 .6668 Mdot
.23854 .40987 Mdot
.78891 .43278 Mdot
.40756 .6498 Mdot
.78455 .66743 Mdot
.55054 .7342 Mdot
.51816 .73744 Mdot
.67977 .568 Mdot
.37339 .45554 Mdot
.65357 .42092 Mdot
.36669 .40636 Mdot
.37608 .37454 Mdot
.36201 .46212 Mdot
.5574 .27604 Mdot
.33438 .42498 Mdot
.5454 .73289 Mdot
.64788 .42958 Mdot
.39663 .42439 Mdot
.38089 .46774 Mdot
.51848 .73248 Mdot
.38194 .59506 Mdot
.37999 .67039 Mdot
.58134 .7667 Mdot
.57635 .27902 Mdot
.63982 .55706 Mdot
.37071 .40419 Mdot
.6384 .44254 Mdot
.64921 .42206 Mdot
.41531 .6163 Mdot
.62082 .42128 Mdot
.62396 .56607 Mdot
.39624 .43687 Mdot
.67929 .58334 Mdot
.55807 .27583 Mdot
.38792 .62195 Mdot
.37304 .40236 Mdot
.42878 .42222 Mdot
.41166 .65536 Mdot
.41626 .45707 Mdot
.54581 .28429 Mdot
.60605 .43251 Mdot
.38895 .6714 Mdot
.63554 .57745 Mdot
.62538 .46538 Mdot
.42272 .43282 Mdot
.85987 .47132 Mdot
.40846 .45085 Mdot
.35821 .42467 Mdot
.59631 .81456 Mdot
.40201 .50481 Mdot
.66964 .43493 Mdot
.43187 .6435 Mdot
.43307 .45674 Mdot
.53636 .21506 Mdot
.70218 .43052 Mdot
.68276 .43014 Mdot
.3684 .4245 Mdot
.76495 .67491 Mdot
.37687 .41027 Mdot
.73519 .66887 Mdot
.54438 .55106 Mdot
.73057 .27975 Mdot
.46181 .46698 Mdot
.6811 .57737 Mdot
.53307 .74706 Mdot
.67147 .42029 Mdot
.27921 .6533 Mdot
.41251 .4549 Mdot
.31955 .66361 Mdot
.36234 .40634 Mdot
.65709 .57862 Mdot
.30828 .43379 Mdot
.62044 .41663 Mdot
.17741 .53451 Mdot
.39364 .39791 Mdot
.37517 .67022 Mdot
.62396 .38634 Mdot
.54519 .75007 Mdot
.42788 .4116 Mdot
.58023 .31605 Mdot
.6768 .48047 Mdot
.45775 .46384 Mdot
.64241 .58598 Mdot
.36326 .44894 Mdot
.34093 .38042 Mdot
.24509 .27634 Mdot
.39135 .66533 Mdot
.675 .58931 Mdot
.46286 .61861 Mdot
.40923 .47598 Mdot
.37886 .66908 Mdot
.39324 .63531 Mdot
.58691 .30366 Mdot
.55975 .65525 Mdot
.6941 .39081 Mdot
.82214 .45489 Mdot
.3194 .61631 Mdot
.61559 .45876 Mdot
.39622 .76035 Mdot
.40495 .41209 Mdot
.37685 .32117 Mdot
.65244 .60067 Mdot
.39955 .45472 Mdot
.31955 .56472 Mdot
.38758 .65948 Mdot
.37535 .44477 Mdot
.55243 .28439 Mdot
.50358 .72544 Mdot
.36453 .33982 Mdot
.84696 .53411 Mdot
.65847 .38988 Mdot
.44716 .44286 Mdot
.44111 .49489 Mdot
.53834 .75732 Mdot
.42311 .47293 Mdot
.67031 .42195 Mdot
.77131 .46423 Mdot
.54948 .30932 Mdot
.4119 .67679 Mdot
.55143 .73799 Mdot
.35146 .41374 Mdot
.38329 .49933 Mdot
.57086 .3332 Mdot
.40979 .39602 Mdot
.19173 .57162 Mdot
.51841 .75698 Mdot
.60951 .43106 Mdot
.37192 .64618 Mdot
.35937 .47193 Mdot
.53532 .75074 Mdot
.38926 .48277 Mdot
.43518 .5454 Mdot
.36259 .42746 Mdot
.5173 .81419 Mdot
.41296 .64678 Mdot
.6394 .58709 Mdot
.32837 .4452 Mdot
.38546 .45655 Mdot
.69438 .32077 Mdot
.37161 .37555 Mdot
.37062 .46836 Mdot
.39191 .60754 Mdot
.42507 .66494 Mdot
.41551 .62054 Mdot
.61097 .438 Mdot
.5254 .6173 Mdot
.65055 .57767 Mdot
.44057 .40373 Mdot
.64803 .54848 Mdot
.46004 .4984 Mdot
.57323 .33037 Mdot
.80273 .60761 Mdot
.40698 .44009 Mdot
.40468 .6158 Mdot
.40676 .78229 Mdot
.36779 .66709 Mdot
.69022 .60327 Mdot
.64422 .59662 Mdot
.39628 .65454 Mdot
.38704 .4385 Mdot
.5248 .60247 Mdot
.84974 .48917 Mdot
.629 .57416 Mdot
.43301 .4726 Mdot
.64819 .38442 Mdot
.63362 .38936 Mdot
.76033 .71736 Mdot
.66114 .60216 Mdot
.45697 .74538 Mdot
.387 .41443 Mdot
.42144 .67131 Mdot
.65245 .55883 Mdot
.64391 .60198 Mdot
.61674 .43199 Mdot
.42924 .44082 Mdot
.38372 .454 Mdot
.53842 .7243 Mdot
.65427 .55151 Mdot
.32132 .45857 Mdot
.42427 .45431 Mdot
.64962 .79139 Mdot
.42744 .68536 Mdot
.15024 .43393 Mdot
.33031 .39968 Mdot
.32448 .56343 Mdot
.52778 .43932 Mdot
.4011 .67578 Mdot
.39647 .39285 Mdot
.43642 .39829 Mdot
.62113 .46427 Mdot
.40083 .441 Mdot
.64343 .46224 Mdot
.67306 .59636 Mdot
.80827 .60799 Mdot
.7443 .59236 Mdot
.608 .53047 Mdot
.40708 .45623 Mdot
.39456 .3412 Mdot
.57729 .29233 Mdot
.62823 .61011 Mdot
.4256 .6408 Mdot
.36174 .47787 Mdot
.6382 .47565 Mdot
.61216 .42853 Mdot
.39167 .64362 Mdot
.46616 .76128 Mdot
.7551 .64964 Mdot
.40891 .48168 Mdot
.65999 .41335 Mdot
.73785 .60799 Mdot
.23483 .46781 Mdot
.68324 .58888 Mdot
.54845 .30482 Mdot
.66411 .44581 Mdot
.6561 .6158 Mdot
.4446 .53285 Mdot
.39847 .64425 Mdot
.4086 .68402 Mdot
.72013 .36176 Mdot
.64049 .41341 Mdot
.57251 .29106 Mdot
.5139 .45783 Mdot
.49979 .48686 Mdot
.55057 .28322 Mdot
.66044 .455 Mdot
.41415 .67373 Mdot
.41891 .62954 Mdot
.39265 .63295 Mdot
.18367 .54949 Mdot
.41642 .60942 Mdot
.21543 .38629 Mdot
.39235 .49356 Mdot
.20899 .52875 Mdot
.37323 .41395 Mdot
.65262 .54387 Mdot
.40205 .66072 Mdot
.53634 .5634 Mdot
.35095 .47254 Mdot
.84607 .52049 Mdot
.37069 .4301 Mdot
.65121 .51385 Mdot
.37392 .45749 Mdot
.21204 .5995 Mdot
.42432 .68156 Mdot
.383 .42245 Mdot
.65494 .53589 Mdot
.55962 .3055 Mdot
.38363 .58894 Mdot
.36779 .46353 Mdot
.53093 .78686 Mdot
.4275 .49725 Mdot
.74301 .69076 Mdot
.64126 .26281 Mdot
.55406 .33054 Mdot
.4479 .46564 Mdot
.59972 .40868 Mdot
.42227 .57968 Mdot
.20901 .55338 Mdot
.62944 .57414 Mdot
.26959 .38596 Mdot
.61452 .43795 Mdot
.31053 .44511 Mdot
.36163 .39438 Mdot
.55265 .3179 Mdot
.39456 .58111 Mdot
.6562 .57324 Mdot
.41437 .4521 Mdot
.40144 .39143 Mdot
.77642 .36215 Mdot
.20681 .56082 Mdot
.3232 .46029 Mdot
.59014 .32027 Mdot
.24357 .41315 Mdot
.35994 .4558 Mdot
.6822 .43355 Mdot
.43115 .63322 Mdot
.4563 .40544 Mdot
.23386 .41304 Mdot
.39343 .4238 Mdot
.39389 .65245 Mdot
.40446 .6814 Mdot
.46124 .81503 Mdot
.5698 .32963 Mdot
.36244 .42782 Mdot
.70587 .32083 Mdot
.38018 .40223 Mdot
.65258 .57576 Mdot
.42808 .46806 Mdot
.62711 .44406 Mdot
.52963 .6512 Mdot
.61143 .44115 Mdot
.43447 .42337 Mdot
.40652 .62523 Mdot
.65447 .56838 Mdot
.73575 .37817 Mdot
.5771 .48211 Mdot
.2195 .38064 Mdot
.68079 .47611 Mdot
.56473 .32051 Mdot
.57329 .26742 Mdot
.64443 .52352 Mdot
.37781 .42825 Mdot
.55675 .48789 Mdot
.43869 .39324 Mdot
.37159 .4603 Mdot
.35067 .44251 Mdot
.61062 .59492 Mdot
.64174 .59406 Mdot
.63493 .41953 Mdot
.40397 .47167 Mdot
.38947 .41944 Mdot
.40649 .64537 Mdot
.55537 .30325 Mdot
.607 .42453 Mdot
.57865 .28376 Mdot
.64358 .4327 Mdot
.72881 .74861 Mdot
.43235 .46379 Mdot
.56058 .30648 Mdot
.62178 .59189 Mdot
.40538 .6137 Mdot
.5213 .73058 Mdot
.66147 .42359 Mdot
.62267 .41447 Mdot
.37632 .41804 Mdot
.37904 .63712 Mdot
.37633 .65593 Mdot
.56812 .3223 Mdot
.66235 .56137 Mdot
.43002 .40579 Mdot
.4263 .45481 Mdot
.71683 .29126 Mdot
.61665 .45708 Mdot
.22217 .45521 Mdot
.47133 .80247 Mdot
.37866 .42753 Mdot
.37589 .66093 Mdot
.38909 .4651 Mdot
.79154 .53126 Mdot
.39781 .60909 Mdot
.35035 .47802 Mdot
.49958 .40514 Mdot
.60583 .44147 Mdot
.46002 .82944 Mdot
.33484 .46009 Mdot
.70537 .57852 Mdot
.41439 .40818 Mdot
.52978 .86328 Mdot
.37155 .75059 Mdot
.35758 .4084 Mdot
.40667 .48188 Mdot
.82448 .42882 Mdot
.38435 .41081 Mdot
.54516 .72963 Mdot
.34085 .39118 Mdot
.37939 .67095 Mdot
.53544 .44186 Mdot
.5528 .55495 Mdot
.58328 .32253 Mdot
.64 .44586 Mdot
.38547 .27431 Mdot
.57915 .27844 Mdot
.41392 .66282 Mdot
.36926 .49118 Mdot
.35795 .55675 Mdot
.59612 .45149 Mdot
.39232 .38144 Mdot
.65411 .57661 Mdot
.55203 .55892 Mdot
.65532 .45485 Mdot
.63461 .58002 Mdot
.35171 .42045 Mdot
.52758 .18724 Mdot
.59124 .4943 Mdot
.50931 .83357 Mdot
.64608 .56037 Mdot
.65401 .59706 Mdot
.51681 .63154 Mdot
.5834 .32221 Mdot
.76185 .33794 Mdot
.31914 .36493 Mdot
.62596 .57773 Mdot
.4616 .26899 Mdot
.66168 .46627 Mdot
.5537 .65813 Mdot
.41048 .68931 Mdot
.43555 .45721 Mdot
.38657 .44258 Mdot
.66578 .56796 Mdot
.33705 .68183 Mdot
.44752 .56357 Mdot
.6315 .58137 Mdot
.42146 .51121 Mdot
.55743 .66538 Mdot
.52974 .74266 Mdot
.54587 .72657 Mdot
.59044 .30136 Mdot
.63608 .34547 Mdot
.41482 .63703 Mdot
.54533 .31094 Mdot
.56154 .72969 Mdot
.36088 .43176 Mdot
.65372 .55049 Mdot
.52686 .72362 Mdot
.64007 .57455 Mdot
.56773 .30844 Mdot
.56509 .33114 Mdot
.39295 .66402 Mdot
.41822 .66531 Mdot
.26943 .42661 Mdot
.49307 .25186 Mdot
.3851 .40761 Mdot
.33916 .60221 Mdot
.40406 .61062 Mdot
.25596 .66834 Mdot
.57391 .3249 Mdot
.55239 .29824 Mdot
.23903 .55353 Mdot
.42628 .43056 Mdot
.7498 .57154 Mdot
.36391 .4608 Mdot
.42992 .29185 Mdot
.34046 .43108 Mdot
.61789 .42869 Mdot
.39544 .40165 Mdot
.61984 .71851 Mdot
.40465 .4281 Mdot
.35472 .45582 Mdot
.65885 .43287 Mdot
.32719 .44482 Mdot
.62429 .44396 Mdot
.4295 .45566 Mdot
.55647 .33703 Mdot
.63871 .44253 Mdot
.5614 .22865 Mdot
.56617 .39217 Mdot
.54134 .74654 Mdot
.58739 .28831 Mdot
.57756 .31755 Mdot
.48789 .20396 Mdot
.42647 .64935 Mdot
.4542 .52326 Mdot
.377 .42954 Mdot
.67257 .44648 Mdot
.63645 .55517 Mdot
.39234 .42359 Mdot
.45248 .41966 Mdot
.3371 .46695 Mdot
.39258 .65924 Mdot
.66302 .45358 Mdot
.56395 .30092 Mdot
.6523 .40219 Mdot
.60003 .34572 Mdot
.64897 .39431 Mdot
.37056 .3585 Mdot
.32315 .41572 Mdot
.41402 .53325 Mdot
.3351 .58688 Mdot
.17722 .50156 Mdot
.39633 .64123 Mdot
.53697 .73557 Mdot
.57736 .3295 Mdot
.47687 .54599 Mdot
.40659 .61885 Mdot
.62647 .41124 Mdot
.38025 .44673 Mdot
.41823 .51441 Mdot
.35668 .347 Mdot
.44787 .63504 Mdot
.52105 .22893 Mdot
.65386 .44549 Mdot
.52687 .73415 Mdot
.53065 .63218 Mdot
.41112 .70998 Mdot
.53576 .55622 Mdot
.38692 .46119 Mdot
.57718 .32002 Mdot
.39538 .67939 Mdot
.7628 .37939 Mdot
.67071 .57375 Mdot
.53499 .59893 Mdot
.40696 .45394 Mdot
.41848 .76143 Mdot
.40627 .62541 Mdot
.55027 .29466 Mdot
.66585 .56855 Mdot
.57261 .32775 Mdot
.55277 .74036 Mdot
.59335 .74414 Mdot
.41882 .40173 Mdot
.37097 .46972 Mdot
.62028 .56516 Mdot
.41389 .63454 Mdot
.62047 .47793 Mdot
.78122 .38905 Mdot
.65743 .4111 Mdot
.56113 .50594 Mdot
.39272 .67769 Mdot
.382 .73552 Mdot
.6225 .39912 Mdot
.63058 .60719 Mdot
.554 .49554 Mdot
.64485 .61062 Mdot
.35607 .45368 Mdot
.3867 .62951 Mdot
.66143 .60231 Mdot
.7293 .34876 Mdot
.71425 .74776 Mdot
.39954 .57451 Mdot
.41233 .46742 Mdot
.80641 .6048 Mdot
.63542 .78196 Mdot
.34508 .62314 Mdot
.65889 .55091 Mdot
.39695 .47032 Mdot
.40593 .48428 Mdot
.39308 .39861 Mdot
.67105 .59158 Mdot
.60662 .4906 Mdot
.61789 .41353 Mdot
.36831 .43712 Mdot
.5811 .30886 Mdot
.62484 .43698 Mdot
.6056 .40092 Mdot
.67088 .41735 Mdot
.39622 .60863 Mdot
.38329 .4936 Mdot
.50995 .69374 Mdot
.56155 .85282 Mdot
.64495 .59358 Mdot
.5417 .74634 Mdot
.34803 .43753 Mdot
.25806 .32935 Mdot
.41362 .61929 Mdot
.65533 .40997 Mdot
.39944 .45667 Mdot
.65837 .28654 Mdot
.54219 .77557 Mdot
.65171 .43821 Mdot
.42521 .64236 Mdot
.34779 .617 Mdot
.40049 .44004 Mdot
.41589 .41068 Mdot
.41898 .64586 Mdot
.56759 .7899 Mdot
.5372 .64846 Mdot
.38646 .46534 Mdot
.63728 .58551 Mdot
.23437 .27648 Mdot
.37486 .49844 Mdot
.44876 .63234 Mdot
.53636 .75321 Mdot
.51331 .80672 Mdot
.22731 .44976 Mdot
.41013 .36596 Mdot
.81427 .56565 Mdot
.36666 .26786 Mdot
.8014 .62341 Mdot
.37498 .29732 Mdot
.72735 .62092 Mdot
.65984 .81378 Mdot
.6671 .54731 Mdot
.21936 .60735 Mdot
.77914 .32828 Mdot
.4778 .742 Mdot
.62112 .26482 Mdot
.73152 .44955 Mdot
.66015 .27749 Mdot
.23748 .69452 Mdot
.64181 .39255 Mdot
.41793 .30857 Mdot
.41448 .39385 Mdot
.63004 .7783 Mdot
.19859 .51268 Mdot
.17464 .47908 Mdot
.79549 .61334 Mdot
.69437 .30838 Mdot
.84929 .44246 Mdot
.7717 .63302 Mdot
.28187 .44274 Mdot
.45253 .35144 Mdot
.64859 .35829 Mdot
.50814 .46918 Mdot
.37454 .27752 Mdot
.47004 .43421 Mdot
.61812 .70256 Mdot
.61426 .53028 Mdot
.279 .48351 Mdot
.22094 .30567 Mdot
.6676 .43279 Mdot
.43071 .63008 Mdot
.7564 .32329 Mdot
.44037 .60445 Mdot
.67297 .54186 Mdot
.81476 .56504 Mdot
.64827 .79549 Mdot
.2097 .5943 Mdot
.5502 .70459 Mdot
.25426 .60427 Mdot
.40376 .21111 Mdot
.43514 .33818 Mdot
.36461 .66898 Mdot
.72127 .52366 Mdot
.49983 .48577 Mdot
.61843 .3571 Mdot
.22204 .6288 Mdot
.56638 .26227 Mdot
.55481 .22495 Mdot
.42286 .63657 Mdot
.2407 .46271 Mdot
.51867 .74411 Mdot
.54175 .7076 Mdot
.6556 .47783 Mdot
.79291 .51438 Mdot
.52496 .77372 Mdot
.51161 .76956 Mdot
.36934 .77742 Mdot
.86256 .50975 Mdot
.43043 .23751 Mdot
.76647 .44409 Mdot
.69861 .572 Mdot
.38078 .25734 Mdot
.50502 .67586 Mdot
.47617 .23955 Mdot
.4943 .47227 Mdot
.81345 .33377 Mdot
.58261 .8004 Mdot
.84563 .40672 Mdot
.35875 .67895 Mdot
.36945 .50503 Mdot
.78312 .45985 Mdot
.31169 .63013 Mdot
.53766 .31352 Mdot
.85681 .52166 Mdot
.55137 .32313 Mdot
.44249 .65485 Mdot
.47341 .74411 Mdot
.19034 .55337 Mdot
.62822 .48673 Mdot
.53314 .26302 Mdot
.45854 .42148 Mdot
.79083 .28029 Mdot
.82204 .54859 Mdot
.47573 .81378 Mdot
.64064 .79643 Mdot
.67097 .39134 Mdot
.59124 .42991 Mdot
.67107 .59967 Mdot
.68067 .78574 Mdot
.39752 .62292 Mdot
.56877 .8548 Mdot
.67671 .78324 Mdot
.45871 .6572 Mdot
.7783 .25871 Mdot
.30109 .7448 Mdot
.20963 .51552 Mdot
.29018 .34574 Mdot
.59868 .21179 Mdot
.50676 .64681 Mdot
.38872 .73754 Mdot
.64563 .37942 Mdot
.55556 .81203 Mdot
.73965 .73074 Mdot
.46494 .27904 Mdot
.60821 .61398 Mdot
.48298 .7083 Mdot
.51074 .36255 Mdot
.42829 .60002 Mdot
.60142 .24368 Mdot
.50216 .35363 Mdot
.84985 .42531 Mdot
.25711 .39663 Mdot
.34961 .18965 Mdot
.38934 .29202 Mdot
.21329 .63857 Mdot
.76175 .61159 Mdot
.52231 .30843 Mdot
.4402 .54926 Mdot
.49804 .77335 Mdot
.43083 .48325 Mdot
.50573 .59647 Mdot
.34211 .50937 Mdot
.59488 .33536 Mdot
.52172 .62456 Mdot
.7032 .70615 Mdot
.40847 .28474 Mdot
.81205 .45412 Mdot
.46297 .36504 Mdot
.37172 .63768 Mdot
.46877 .2301 Mdot
.43823 .25757 Mdot
.66995 .77214 Mdot
.46395 .62177 Mdot
.52344 .82757 Mdot
.45799 .60306 Mdot
.44283 .39677 Mdot
.22555 .61611 Mdot
.46951 .45957 Mdot
.46122 .25509 Mdot
.33389 .44734 Mdot
.3804 .7825 Mdot
.60322 .81175 Mdot
.31445 .53449 Mdot
.40242 .26709 Mdot
.33764 .57084 Mdot
.56198 .81389 Mdot
.78742 .45981 Mdot
.40776 .74596 Mdot
.35928 .7262 Mdot
.79845 .29677 Mdot
.62622 .42602 Mdot
.47091 .26795 Mdot
.61175 .58538 Mdot
.73161 .36935 Mdot
.7651 .30392 Mdot
.44895 .58126 Mdot
.59544 .81942 Mdot
.49379 .74943 Mdot
.59813 .46416 Mdot
.58712 .65881 Mdot
.63758 .63047 Mdot
.33997 .55098 Mdot
.35205 .48939 Mdot
.39152 .54894 Mdot
.54375 .28857 Mdot
.29625 .6306 Mdot
.7814 .43158 Mdot
.68862 .49478 Mdot
.40857 .36271 Mdot
.696 .51249 Mdot
.52876 .72924 Mdot
.54288 .60809 Mdot
.75144 .73098 Mdot
.35558 .37614 Mdot
.28215 .72471 Mdot
.58105 .79351 Mdot
.55473 .51542 Mdot
.61535 .33716 Mdot
.44386 .7878 Mdot
.8361 .37391 Mdot
.6332 .81709 Mdot
.66686 .74798 Mdot
.80937 .59794 Mdot
.37453 .83094 Mdot
.72987 .26261 Mdot
.30496 .68891 Mdot
.61054 .57756 Mdot
.27703 .80784 Mdot
.63477 .39819 Mdot
.27295 .36217 Mdot
.31174 .62513 Mdot
.65996 .29592 Mdot
.42698 .58737 Mdot
.45809 .37294 Mdot
.69186 .42316 Mdot
.39969 .59141 Mdot
.45542 .41529 Mdot
.85146 .5682 Mdot
.81739 .33537 Mdot
.85726 .55088 Mdot
.59528 .74647 Mdot
.81033 .62041 Mdot
.81595 .37895 Mdot
.21082 .39292 Mdot
.77212 .3457 Mdot
.42773 .46807 Mdot
.48593 .29054 Mdot
.30997 .74601 Mdot
.64748 .48377 Mdot
.52561 .69828 Mdot
.39767 .69876 Mdot
.80553 .33483 Mdot
.75881 .72574 Mdot
.25522 .55682 Mdot
.25709 .45767 Mdot
.55612 .38603 Mdot
.48103 .25039 Mdot
.3387 .52355 Mdot
.62353 .69291 Mdot
.71461 .7314 Mdot
.81055 .36747 Mdot
.43142 .26773 Mdot
.7249 .47075 Mdot
.67256 .73441 Mdot
.30806 .72731 Mdot
.78131 .59711 Mdot
.75309 .31507 Mdot
.45586 .6236 Mdot
.37657 .71437 Mdot
.4465 .56678 Mdot
.60955 .68811 Mdot
.77418 .51072 Mdot
.41176 .24306 Mdot
.62977 .45571 Mdot
.47206 .28045 Mdot
.5228 .52063 Mdot
.77091 .34021 Mdot
.39909 .23944 Mdot
.46071 .28407 Mdot
.6888 .73073 Mdot
.83983 .58319 Mdot
.55704 .79009 Mdot
.56066 .19206 Mdot
.69532 .64772 Mdot
.32898 .49686 Mdot
.34524 .49285 Mdot
.58193 .81668 Mdot
.8314 .62071 Mdot
.60362 .82016 Mdot
.41238 .76196 Mdot
.71962 .34772 Mdot
.67841 .60727 Mdot
.3902 .23746 Mdot
.68297 .51775 Mdot
.72258 .72746 Mdot
.48764 .55515 Mdot
.68695 .60112 Mdot
.49546 .72221 Mdot
.27425 .42446 Mdot
.32844 .29156 Mdot
.26479 .4903 Mdot
.38896 .3767 Mdot
.22308 .48987 Mdot
.43194 .66568 Mdot
.40769 .75816 Mdot
.47553 .24523 Mdot
.6282 .42935 Mdot
.69572 .26314 Mdot
.37112 .54756 Mdot
.39506 .50764 Mdot
.77038 .47482 Mdot
.42393 .59574 Mdot
.33245 .58419 Mdot
.59239 .41501 Mdot
.6844 .79259 Mdot
.34819 .75501 Mdot
.33672 .5273 Mdot
.44775 .22885 Mdot
.7173 .2983 Mdot
.54319 .64308 Mdot
.6175 .55699 Mdot
.78844 .61794 Mdot
.56105 .40976 Mdot
.46091 .23285 Mdot
.22282 .48114 Mdot
.77904 .40167 Mdot
.44376 .40463 Mdot
.44605 .80265 Mdot
.23347 .36463 Mdot
.54583 .60607 Mdot
.44012 .67874 Mdot
.4035 .6003 Mdot
.17764 .63127 Mdot
.6322 .71962 Mdot
.45897 .69245 Mdot
.78906 .60055 Mdot
.66094 .60709 Mdot
.37412 .6223 Mdot
.46423 .29173 Mdot
.64633 .3289 Mdot
.2548 .42143 Mdot
.779 .51538 Mdot
.29004 .4485 Mdot
.70571 .56844 Mdot
.80601 .59466 Mdot
.83806 .49785 Mdot
.25869 .25918 Mdot
.37741 .60235 Mdot
.75902 .40543 Mdot
.75841 .39637 Mdot
.3655 .66806 Mdot
.44831 .63501 Mdot
.38422 .33942 Mdot
.79664 .64675 Mdot
.49382 .53432 Mdot
.60923 .67671 Mdot
.55497 .49636 Mdot
.62402 .27705 Mdot
.77071 .37746 Mdot
.38901 .25926 Mdot
.78813 .58229 Mdot
.25347 .48246 Mdot
.62728 .20816 Mdot
.40413 .53506 Mdot
.26197 .37111 Mdot
.39011 .23726 Mdot
.4727 .35395 Mdot
.22796 .6363 Mdot
.72262 .68915 Mdot
.38156 .40359 Mdot
.86494 .52377 Mdot
.67006 .76604 Mdot
.50126 .5997 Mdot
.62897 .3645 Mdot
.41312 .42519 Mdot
.38698 .49434 Mdot
.34187 .7048 Mdot
.49268 .80624 Mdot
.67383 .21667 Mdot
.40648 .29435 Mdot
.32359 .49243 Mdot
.21915 .48253 Mdot
.2826 .72466 Mdot
.78681 .47984 Mdot
.75455 .66637 Mdot
.51376 .53891 Mdot
.31685 .7486 Mdot
.59343 .63765 Mdot
.59199 .67442 Mdot
.71251 .64035 Mdot
.81959 .38755 Mdot
.34689 .36089 Mdot
.49268 .792 Mdot
.75649 .33842 Mdot
.34892 .43675 Mdot
.46611 .76188 Mdot
.77335 .61217 Mdot
.37129 .19448 Mdot
.49806 .67529 Mdot
.8483 .59658 Mdot
.40254 .54138 Mdot
.50344 .78857 Mdot
.77023 .30207 Mdot
.47541 .14618 Mdot
.61036 .70166 Mdot
.85146 .4398 Mdot
.57753 .64607 Mdot
.79149 .59375 Mdot
.68169 .58014 Mdot
.52252 .48025 Mdot
.32714 .63838 Mdot
.79289 .65214 Mdot
.68009 .35491 Mdot
.79871 .53301 Mdot
.33732 .70671 Mdot
.81353 .63122 Mdot
.4886 .47661 Mdot
.17586 .62002 Mdot
.67984 .45556 Mdot
.33758 .78141 Mdot
.31596 .70901 Mdot
.33556 .51298 Mdot
.45462 .27203 Mdot
.1716 .58714 Mdot
.19353 .43207 Mdot
.31121 .6853 Mdot
.47106 .3175 Mdot
.45607 .7936 Mdot
.44188 .22595 Mdot
.7207 .73351 Mdot
.22129 .67754 Mdot
.7662 .39004 Mdot
.45748 .72325 Mdot
.57918 .77664 Mdot
.49193 .81011 Mdot
.69202 .68336 Mdot
.77673 .4693 Mdot
.57589 .69706 Mdot
.28746 .43709 Mdot
.12117 .42 Mdot
.57231 .58365 Mdot
.36935 .34325 Mdot
.83206 .37627 Mdot
.70847 .737 Mdot
.48063 .55249 Mdot
.21556 .62204 Mdot
.29217 .30705 Mdot
.5072 .29791 Mdot
.36269 .46252 Mdot
.81608 .6261 Mdot
.52011 .27943 Mdot
.85316 .48481 Mdot
.52763 .83978 Mdot
.23346 .49479 Mdot
.35627 .36806 Mdot
.63967 .37972 Mdot
.39732 .33025 Mdot
.46551 .32235 Mdot
.83286 .39695 Mdot
.2672 .36786 Mdot
.5667 .4724 Mdot
.72273 .58832 Mdot
.75949 .5748 Mdot
.30422 .44268 Mdot
.31484 .75454 Mdot
.47557 .79836 Mdot
.39016 .28198 Mdot
.66032 .74086 Mdot
.46832 .26025 Mdot
.22494 .45396 Mdot
.4025 .23088 Mdot
.48459 .60596 Mdot
.6781 .38626 Mdot
.63308 .47067 Mdot
.81922 .42862 Mdot
.75822 .63702 Mdot
.38649 .78361 Mdot
.57207 .19786 Mdot
.49409 .77272 Mdot
.42719 .31585 Mdot
.79856 .43693 Mdot
.50193 .64901 Mdot
.68413 .36968 Mdot
.3168 .3028 Mdot
.26185 .39315 Mdot
.737 .67726 Mdot
.47217 .38924 Mdot
.7418 .73108 Mdot
.40767 .24664 Mdot
.79746 .39413 Mdot
.55161 .39256 Mdot
.30632 .59933 Mdot
.2233 .57044 Mdot
.6151 .21955 Mdot
.54696 .5969 Mdot
.79261 .28485 Mdot
.37237 .67895 Mdot
.86227 .50631 Mdot
.63806 .55807 Mdot
.27682 .26002 Mdot
.72937 .70305 Mdot
.5218 .5522 Mdot
.54483 .48184 Mdot
.44708 .80581 Mdot
.5307 .78079 Mdot
.57295 .7939 Mdot
.4457 .5741 Mdot
.6714 .41328 Mdot
.57476 .47261 Mdot
.61591 .6797 Mdot
.81949 .46977 Mdot
.43772 .43879 Mdot
.61469 .47984 Mdot
.46169 .34752 Mdot
.68689 .62425 Mdot
.5858 .81146 Mdot
.73182 .66384 Mdot
.46712 .44932 Mdot
.4836 .24824 Mdot
.81572 .36613 Mdot
.6824 .7727 Mdot
.45441 .55651 Mdot
.34596 .51213 Mdot
.64824 .51642 Mdot
.71959 .27095 Mdot
.81981 .5367 Mdot
.74699 .58518 Mdot
.54619 .66236 Mdot
.42991 .24034 Mdot
.87688 .56269 Mdot
.81523 .33411 Mdot
.59212 .19442 Mdot
.5568 .49254 Mdot
.36479 .69589 Mdot
.25884 .33232 Mdot
.79864 .39868 Mdot
.34872 .79092 Mdot
.6695 .75661 Mdot
.46745 .26606 Mdot
.41098 .1802 Mdot
.1864 .48151 Mdot
.56955 .44461 Mdot
.22451 .57224 Mdot
.32467 .60808 Mdot
.68256 .61188 Mdot
.50662 .31354 Mdot
.55702 .43858 Mdot
.66348 .53224 Mdot
.45989 .79479 Mdot
.50924 .76318 Mdot
.79666 .38998 Mdot
.24213 .39219 Mdot
.35149 .51747 Mdot
.81336 .48992 Mdot
.44124 .62333 Mdot
.76064 .38204 Mdot
.72433 .30414 Mdot
.56361 .44619 Mdot
.64675 .39823 Mdot
.46179 .40305 Mdot
.55039 .62299 Mdot
.57921 .63619 Mdot
.48771 .17943 Mdot
.53926 .30564 Mdot
.36351 .6801 Mdot
.17525 .51989 Mdot
.36966 .61267 Mdot
.82443 .64567 Mdot
.62587 .69261 Mdot
.21807 .49498 Mdot
.59251 .62303 Mdot
.72641 .49318 Mdot
.48748 .16561 Mdot
.27924 .43741 Mdot
.5791 .23829 Mdot
.38206 .70695 Mdot
.43029 .66657 Mdot
.60985 .63088 Mdot
.52592 .7602 Mdot
.249 .4602 Mdot
.26006 .709 Mdot
.71481 .29361 Mdot
.36021 .62963 Mdot
.58077 .46194 Mdot
.37904 .57185 Mdot
.7426 .73863 Mdot
.65865 .40572 Mdot
.80543 .30757 Mdot
.3233 .41275 Mdot
.70657 .2529 Mdot
.58709 .81503 Mdot
.52656 .65338 Mdot
.55996 .49037 Mdot
.73098 .42165 Mdot
.44826 .42431 Mdot
.33287 .50512 Mdot
.42357 .65544 Mdot
.77727 .35699 Mdot
.55615 .29313 Mdot
.5093 .23213 Mdot
.62355 .54102 Mdot
.25234 .68082 Mdot
.32945 .75849 Mdot
.43464 .65973 Mdot
.58211 .37534 Mdot
.75272 .40847 Mdot
.49821 .39263 Mdot
.46592 .34943 Mdot
.82199 .42406 Mdot
.26421 .44692 Mdot
.37005 .67385 Mdot
.59115 .19632 Mdot
.50237 .35138 Mdot
.64406 .81859 Mdot
.46599 .49552 Mdot
.42552 .33719 Mdot
.47405 .37056 Mdot
.43947 .79455 Mdot
.22923 .44542 Mdot
.74588 .6885 Mdot
.47217 .23276 Mdot
.51061 .44973 Mdot
.46351 .28504 Mdot
.468 .43538 Mdot
.7247 .60515 Mdot
.32148 .76987 Mdot
.42111 .17799 Mdot
.24951 .61169 Mdot
.50608 .68581 Mdot
.44945 .65705 Mdot
.28809 .72901 Mdot
.36637 .67789 Mdot
.60734 .32729 Mdot
.28415 .48992 Mdot
.7279 .70551 Mdot
.6924 .77749 Mdot
.669 .77243 Mdot
.38244 .32808 Mdot
.75396 .58317 Mdot
.30415 .32505 Mdot
.41482 .54689 Mdot
.53002 .55051 Mdot
.45075 .42575 Mdot
.3073 .44854 Mdot
.47503 .57134 Mdot
.40423 .78311 Mdot
.32549 .38596 Mdot
.78769 .6523 Mdot
.64242 .81735 Mdot
.82721 .59185 Mdot
.77292 .50619 Mdot
.41651 .60467 Mdot
.83014 .36172 Mdot
.21007 .44462 Mdot
.70979 .74502 Mdot
.31235 .70553 Mdot
.19443 .659 Mdot
.77628 .3154 Mdot
.71034 .7029 Mdot
.43797 .71614 Mdot
.46724 .83281 Mdot
.59151 .80174 Mdot
.17811 .62337 Mdot
.29038 .36855 Mdot
.57945 .81241 Mdot
.78485 .27628 Mdot
.29028 .68375 Mdot
.52253 .77878 Mdot
.21778 .56796 Mdot
.28075 .37905 Mdot
.23007 .68089 Mdot
.40672 .49613 Mdot
.61891 .39435 Mdot
.63754 .26704 Mdot
.45687 .26587 Mdot
.4634 .39804 Mdot
.21591 .66362 Mdot
.46406 .32455 Mdot
.41522 .31046 Mdot
.73108 .37951 Mdot
.77889 .32578 Mdot
.23619 .445 Mdot
.4382 .49801 Mdot
.41029 .69744 Mdot
.57678 .27295 Mdot
.35271 .2971 Mdot
.41852 .43733 Mdot
.54745 .56347 Mdot
.34592 .35563 Mdot
.85132 .57567 Mdot
.63728 .30393 Mdot
.61224 .52342 Mdot
.39604 .59622 Mdot
.47882 .80601 Mdot
.80027 .49166 Mdot
.47623 .74216 Mdot
.19996 .63755 Mdot
.26415 .42458 Mdot
.81031 .58417 Mdot
.49897 .7624 Mdot
.41592 .26158 Mdot
.43962 .19447 Mdot
.65325 .54115 Mdot
.32144 .6402 Mdot
.83032 .39913 Mdot
.4772 .76879 Mdot
.44544 .63984 Mdot
.67922 .71613 Mdot
.7284 .5976 Mdot
.4704 .7795 Mdot
.58033 .79282 Mdot
.77356 .4146 Mdot
.22905 .52913 Mdot
.83411 .50254 Mdot
.63524 .38248 Mdot
.4356 .27153 Mdot
.65173 .71927 Mdot
.23057 .68415 Mdot
.49775 .39422 Mdot
.75861 .70346 Mdot
.52975 .54205 Mdot
.54852 .2325 Mdot
.4206 .40697 Mdot
.23572 .40901 Mdot
.41757 .78451 Mdot
.66201 .73353 Mdot
.46409 .65758 Mdot
.43791 .62892 Mdot
.36373 .7707 Mdot
.62078 .36224 Mdot
.51459 .29153 Mdot
.30688 .33997 Mdot
.37297 .73425 Mdot
.60334 .30903 Mdot
.51707 .7186 Mdot
.31977 .42752 Mdot
.55848 .22009 Mdot
.77138 .54682 Mdot
.32126 .66075 Mdot
.3021 .68755 Mdot
.8212 .43292 Mdot
.78128 .5031 Mdot
.37909 .78716 Mdot
.32351 .70227 Mdot
.52456 .81254 Mdot
.19487 .46527 Mdot
.47323 .70796 Mdot
.34156 .47246 Mdot
.60722 .32741 Mdot
.36564 .65848 Mdot
.82266 .47212 Mdot
.40729 .56053 Mdot
.55626 .2315 Mdot
.50803 .57271 Mdot
.78082 .45879 Mdot
.54094 .39115 Mdot
.58974 .81067 Mdot
.46722 .833 Mdot
.47554 .24405 Mdot
.6345 .53185 Mdot
.58336 .65068 Mdot
.49558 .66944 Mdot
.76797 .67624 Mdot
.46564 .578 Mdot
.35651 .55682 Mdot
.49766 .70702 Mdot
.32243 .55975 Mdot
.55114 .83055 Mdot
.49732 .25125 Mdot
.53101 .55766 Mdot
.34548 .53368 Mdot
.53852 .70257 Mdot
.52037 .73215 Mdot
.65635 .30181 Mdot
.21916 .42799 Mdot
.59464 .59334 Mdot
.57759 .49147 Mdot
.31994 .45279 Mdot
.25524 .33596 Mdot
.82774 .50506 Mdot
.47552 .54826 Mdot
.5247 .54096 Mdot
.75444 .34037 Mdot
.51966 .26663 Mdot
.20145 .30698 Mdot
.86579 .53962 Mdot
.42133 .40853 Mdot
.54264 .46679 Mdot
.50685 .2387 Mdot
.64549 .46162 Mdot
.26472 .48322 Mdot
.82393 .44435 Mdot
.64135 .59834 Mdot
.72564 .35439 Mdot
.5125 .74913 Mdot
.43621 .80139 Mdot
.63635 .22414 Mdot
.68075 .60808 Mdot
.8313 .63781 Mdot
.66305 .75887 Mdot
.4186 .77726 Mdot
.15937 .35327 Mdot
.39423 .77229 Mdot
.47589 .4983 Mdot
.72565 .38591 Mdot
.8394 .59025 Mdot
.55778 .49992 Mdot
.72104 .36241 Mdot
.29575 .679 Mdot
.47401 .23973 Mdot
.42223 .29187 Mdot
.45629 .72567 Mdot
.37596 .76445 Mdot
.1654 .60281 Mdot
.72738 .4906 Mdot
.51537 .17052 Mdot
.24192 .47452 Mdot
.84194 .50832 Mdot
.61044 .69993 Mdot
.39951 .1853 Mdot
.6826 .78349 Mdot
.48172 .30009 Mdot
.22435 .66635 Mdot
.64892 .34426 Mdot
.51447 .21162 Mdot
.24526 .3396 Mdot
.5898 .71857 Mdot
.26834 .44726 Mdot
.71244 .49584 Mdot
.47004 .66891 Mdot
.46798 .2824 Mdot
.32501 .58222 Mdot
.53235 .55457 Mdot
.84008 .43727 Mdot
.1808 .59241 Mdot
.44609 .23407 Mdot
.74403 .35488 Mdot
.52562 .21521 Mdot
.81664 .50855 Mdot
.77983 .5621 Mdot
.50108 .385 Mdot
.7256 .23657 Mdot
.84965 .42592 Mdot
.47894 .70641 Mdot
.39096 .49451 Mdot
.65258 .81737 Mdot
.51981 .39386 Mdot
.30484 .684 Mdot
.60764 .78195 Mdot
.40062 .29588 Mdot
.33068 .36853 Mdot
.36697 .49644 Mdot
.29049 .33925 Mdot
.43734 .71328 Mdot
.32663 .58743 Mdot
.6705 .25058 Mdot
.45102 .23115 Mdot
.18536 .5974 Mdot
.63739 .21661 Mdot
.47209 .48718 Mdot
.38264 .67604 Mdot
.84447 .58395 Mdot
.30642 .49425 Mdot
.38063 .54051 Mdot
.21356 .53276 Mdot
.45767 .5712 Mdot
.70503 .40771 Mdot
.34449 .50994 Mdot
.54325 .64004 Mdot
.45241 .27125 Mdot
.80215 .41372 Mdot
.32826 .64322 Mdot
.78073 .25827 Mdot
.5876 .81923 Mdot
.35749 .63443 Mdot
.29888 .66233 Mdot
.56379 .43584 Mdot
.83006 .58162 Mdot
.71976 .47315 Mdot
.71957 .3002 Mdot
.16735 .51882 Mdot
.48547 .2136 Mdot
.35235 .40676 Mdot
.59535 .74964 Mdot
.71278 .7569 Mdot
.16252 .54655 Mdot
.74228 .72987 Mdot
.34667 .37141 Mdot
.35648 .50331 Mdot
.41207 .14649 Mdot
.79764 .59384 Mdot
.39809 .36668 Mdot
.44991 .69832 Mdot
.45367 .67761 Mdot
.43293 .41493 Mdot
.53408 .76786 Mdot
.36101 .27982 Mdot
.42356 .29745 Mdot
.79512 .64667 Mdot
.389 .60271 Mdot
.55724 .51838 Mdot
.63118 .61485 Mdot
.54841 .51165 Mdot
.45501 .48575 Mdot
.65067 .60678 Mdot
.42743 .30352 Mdot
.52865 .41514 Mdot
.66919 .49278 Mdot
.28425 .41284 Mdot
.55554 .68363 Mdot
.28976 .42458 Mdot
.41756 .3274 Mdot
.36616 .71766 Mdot
.19328 .43091 Mdot
.46314 .32312 Mdot
.49116 .33951 Mdot
.57982 .80692 Mdot
.34202 .80723 Mdot
.55637 .55453 Mdot
.34304 .67012 Mdot
.47148 .49703 Mdot
.21891 .44086 Mdot
.221 .52984 Mdot
.66758 .48381 Mdot
.52336 .73925 Mdot
.32638 .38813 Mdot
.33861 .52911 Mdot
.66252 .61111 Mdot
.8657 .57697 Mdot
.37926 .5035 Mdot
.25347 .50828 Mdot
.75342 .69283 Mdot
.76387 .37955 Mdot
.31491 .35496 Mdot
.45122 .42998 Mdot
.49156 .49144 Mdot
.52782 .408 Mdot
.36538 .57374 Mdot
.7722 .37072 Mdot
.82635 .54742 Mdot
.33755 .32985 Mdot
.24363 .50359 Mdot
.37181 .4286 Mdot
.5668 .3388 Mdot
.53854 .61978 Mdot
.48803 .18714 Mdot
.5541 .24502 Mdot
.68287 .76877 Mdot
.43174 .32539 Mdot
.40561 .29412 Mdot
.20329 .55379 Mdot
.85638 .49841 Mdot
.49433 .68451 Mdot
.22993 .49708 Mdot
.48937 .59038 Mdot
.6948 .68717 Mdot
.46897 .31617 Mdot
.62388 .62867 Mdot
.30921 .41572 Mdot
.4389 .70768 Mdot
.79132 .6777 Mdot
.28097 .443 Mdot
.61058 .55168 Mdot
.73887 .67701 Mdot
.1968 .46839 Mdot
.54404 .48199 Mdot
.13406 .39029 Mdot
.72528 .45398 Mdot
.83395 .63026 Mdot
.78897 .41081 Mdot
.48667 .39079 Mdot
.45398 .79079 Mdot
.44284 .38326 Mdot
.65523 .42683 Mdot
.82909 .56899 Mdot
.39176 .5596 Mdot
.46905 .71199 Mdot
.42389 .47604 Mdot
.49197 .51173 Mdot
.36852 .55903 Mdot
.74995 .6065 Mdot
.63203 .38963 Mdot
.45378 .56065 Mdot
.78081 .5722 Mdot
.52765 .40532 Mdot
.21868 .69284 Mdot
.83391 .3979 Mdot
.78712 .62125 Mdot
.76396 .56234 Mdot
.28307 .24845 Mdot
.39189 .70612 Mdot
.39376 .56334 Mdot
.64837 .53223 Mdot
.29842 .33049 Mdot
.47214 .77457 Mdot
.7965 .40276 Mdot
.5076 .81957 Mdot
.49729 .38908 Mdot
.10357 .45988 Mdot
.47382 .29674 Mdot
.4756 .53509 Mdot
.45369 .76815 Mdot
.78199 .66127 Mdot
.71258 .31534 Mdot
.50851 .83358 Mdot
.62248 .70656 Mdot
.46686 .43886 Mdot
.23616 .36829 Mdot
.60081 .20373 Mdot
.73831 .58247 Mdot
.50603 .16727 Mdot
.75852 .61541 Mdot
.37578 .27716 Mdot
.65734 .7327 Mdot
.37336 .60623 Mdot
.41923 .57609 Mdot
.62741 .6873 Mdot
.52209 .69746 Mdot
.33915 .6914 Mdot
.81847 .55698 Mdot
.37194 .23146 Mdot
.74192 .3188 Mdot
.81215 .60059 Mdot
.70152 .61448 Mdot
.45002 .66309 Mdot
.45776 .32434 Mdot
.5674 .25399 Mdot
.62791 .4607 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo08;ooooo0_l0000Cooooo`;o0000/?ooool001cooooo00?o0000ooooooooool0
P_ooool2o`0001?ooooo0_l00003ooooo`;o0000Zoooool001cooooo0_l0002Mooooo`;o0000Zooo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`25oooo
o`;o0000`_ooool001cooooo00?o0000ooooooooool0QOooool2o`000<;ooooo000Looooo`03o`00
0?oooooooooo09Oooooo0_l00002ooooo`;o0000[?ooool001cooooo00?o0000ooooooooool0Uooo
ool2o`0000;ooooo0_l00004ooooo`;o0000Y_ooool001cooooo00?o0000ooooooooool0XOooool2
o`000004ooooool0003o0000o`0000_ooooo0_l0002Eooooo`007?ooool00ol0003oooooooooo`2?
ooooo`;o00004oooool3o`0000_ooooo0_l0002Eooooo`007?ooool00ol0003oooooooooo`25oooo
o`;o00001Oooool5o`0000kooooo0_l0002Xooooo`007?ooool00ol0003oooooooooo`1kooooo`?o
00001?ooool5o`0000Gooooo0ol00006ooooo`?o00000oooool2o`0000;ooooo0_l00008ooooo`;o
0000W_ooool001cooooo00?o0000ooooooooool0Noooool3o`0000Cooooo0ol0000@ooooo`?o0000
0oooool2o`0000cooooo0_l0000Zooooo`;o0000L_ooool001cooooo00?o0000ooooooooool0O_oo
ool2o`0001_ooooo0_l00006ooooo`;o00000oooool2o`0002_ooooo0_l0001booooo`007?ooool0
0ol0003oooooooooo`1Vooooo`;o00001_ooool2o`0000kooooo0_l0000Kooooo`;o00001_ooool2
o`0000?ooooo0_l0002Oooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?oo
ool5o`0000Kooooo00?o0000ooooooooool0I_ooool2o`0000Kooooo0_l0000Uooooo`;o00006ooo
ool2o`0009Gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1eooooo`;o00005?ooool2o`0000So
oooo0_l0000Kooooo`;o00002?ooool3o`0008[ooooo00000ooooooo410@ooooo`02ooooo`03oa0@
4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`1eooooo`;o0000
5?ooool2o`0000Kooooo0_l0000Qooooo`;o000000Coooooo`000?l0003ooooo0ol0002:ooooo`00
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo
0ol0002Cooooo`;o00001?ooool2o`0001_ooooo0_l000000ooooooo0000o`00002>ooooo`0000?o
ooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00Gooooo00?o
0000ooooooooool0TOooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`0000?ooooo1?l0
000Kooooo`;o0000R?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool03Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo093ooooo0ol00003ooooo`ko00006oooool2
o`0000Oooooo0_l0001oooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj
^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`1oooooo`;o00001_ooool3o`0000Gooooo
0ol000000ooooooo0000o`000002ooooo`Go000000Coooooo`000?l0003o00000oooool3o`0000Co
oooo0_l0000Cooooo`;o00001oooool2o`0007oooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^
kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo067ooooo0_l0000L
ooooo`Co00001?ooool6o`0000;ooooo0_l00002ooooo`Co00000oooool2o`000003ooooool0003o
000000Cooooo0ol000001?oooooo0000o`000?ooool2o`0001?ooooo0_l00028ooooo`007?ooool0
0ol0003oooooooooo`1Jooooo`;o00001Oooool2o`0001cooooo1?l00004ooooo`Ko00001?ooool2
o`0000;ooooo0_l00002ooooo`?o00002oooool2o`000003ooooool0003o000001oooooo0_l0000:
ooooo`;o0000L?ooool001cooooo00?o0000ooooooooool0F_ooool2o`0002?ooooo0ol00005oooo
o`?o00001oooool2o`0000?ooooo0_l000000ooooooo0000o`00000?ooooo`?o00000_ooool2o`00
0003ooooool0003o0000013ooooo1?l00003ooooo`;o00002_ooool2o`00073ooooo000Looooo`03
o`000?oooooooooo06Gooooo0_l0000Booooo`;o00002?ooool2o`00017ooooo0_l000000ooooooo
0000o`00000@ooooo`;o00000_ooool2o`000003ooooool0003o0000013ooooo1?l00003ooooo`;o
00003oooool2o`0006_ooooo000Looooo`03o`000?oooooooooo05oooooo0_l00004ooooo`;o0000
4Oooool3o`0000Sooooo0_l00007ooooo`;o00008Oooool3o`0001Sooooo0ol0000?ooooo`;o0000
Joooool001cooooo00?o0000ooooooooool0Goooool2o`0001Oooooo0_l0000Booooo`Co00001Ooo
ool2o`0000kooooo1?l00007ooooo`;o000000?oooooo`000?l000003?ooool2o`0000Oooooo1?l0
001kooooo`007?ooool00ol0003oooooooooo`1eooooo`?o00001oooool3o`0000cooooo0ol00000
1?oooooo0000o`000?ooool3o`0000Kooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l0
00000ooooooo0000o`000004o`000003ooooool0003o000000;o00003?ooool2o`0000Wooooo0_l0
001kooooo`007?ooool00ol0003oooooooooo`1eooooo`?o00001oooool5o`0000Wooooo1?l00000
0ooooooo0000o`000002ooooo`;o00001_ooool2o`0000;ooooo0_l00003ooooo`;o000000?ooooo
o`000?l000001?l000000ooooooo0000o`00000Looooo`?o00005_ooool2o`0005oooooo000Loooo
o`03o`000?oooooooooo07_ooooo1Ol000001?oooooo0000o`000?l00004ooooo`;o00000oooool2
o`0000Gooooo1Ol00002ooooo`;o00001?ooool2o`0000Cooooo0_l0000?ooooo`;o00005Oooool3
o`0000_ooooo0_l00009ooooo`;o0000Goooool001cooooo00?o0000ooooooooool0N_ooool6o`00
00;ooooo0_l00004ooooo`;o00002_ooool5o`0000;ooooo0_l00002ooooo`Co00004_ooool2o`00
0004ooooool0003o0000o`0002;ooooo0_l0001Zooooo`007?ooool00ol0003oooooooooo`1joooo
o`;o00001_ooool2o`0000Cooooo0_l0000;ooooo`Co00000_ooool2o`0000;ooooo0_l00007oooo
o`;o00001_ooool2o`0000?ooooo0_l00002ooooo`Co00000oooool2o`0008Oooooo000Looooo`03
o`000?oooooooooo05Sooooo0_l0000Pooooo`;o000000?oooooo`000?l000001?l0000Aooooo`Wo
000000Coooooo`000?l0003o00001oooool2o`0000?ooooo0_l000000ooooooo0000o`000009oooo
o`;o00000oooool2o`0008Oooooo000Looooo`;o0000Doooool4o`0000;ooooo0_l0000Pooooo`;o
000000?oooooo`000?l000001?l0000Aooooo`?o000000Goooooo`000?l0003o0000ooooo`05o`00
00cooooo0_l0000<ooooo`;o00005oooool4o`0001Kooooo0_l0001Iooooo`007?ooool00ol0003o
ooooooooo`1Booooo`Co00001?ooool2o`0001kooooo0_l0000Fooooo`;o00001?ooool2o`0000;o
oooo1?l00004ooooo`Co00002Oooool6o`0000Cooooo0_l0000Gooooo`Co00002_ooool2o`0000Ko
oooo0_l00002ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0Boooool2o`0000gooooo
0_l0000Eooooo`;o00001Oooool4o`0000Gooooo0_l00008ooooo`;o00001Oooool4o`0000Kooooo
0_l00005ooooo`Go00002Oooool6o`0002_ooooo0_l000000ooooooo0000o`000003ooooo`;o0000
3_ooool2o`0004gooooo000Looooo`03o`000?oooooooooo04_ooooo0_l00003ooooo`;o00001?oo
ool2o`0001Wooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000001?oo
ool4o`0000Kooooo0_l00007ooooo`;o00001_ooool2o`0000Cooooo0ol000000ooooooo0000o`00
0003o`0000;ooooo0_l00002ooooo`?o00001_ooool2o`0000;ooooo0_l0000=ooooo`;o000000?o
ooooo`000?l000004oooool2o`000003ooooool0003o000000oooooo0ol0001=ooooo`007?ooool0
0ol0003oooooooooo`1@ooooo`;o00001?ooool2o`0001Wooooo0_l000000ooooooo0000o`000005
ooooo`;o00001_ooool2o`0000Wooooo0_l00004ooooo`;o00003?ooool2o`0000;ooooo1_l00000
0ooooooo0000o`000004ooooo`Ko000000?oooooo`000?l000000_ooool2o`0000Kooooo0_l00005
ooooo`;o000000?oooooo`000?l000003?ooool2o`0000Sooooo0ol0000>ooooo`;o0000C_ooool0
01cooooo00?o0000ooooooooool0LOooool2o`0000Oooooo0_l00003ooooo`;o00001oooool2o`00
00Cooooo0_l000000ooooooo0000o`000003o`0000oooooo0_l00002ooooo`Co00001?ooool8o`00
00gooooo0_l00003ooooo`Co00003oooool2o`0000Wooooo0_l00004ooooo`;o00002?ooool2o`00
04kooooo000Looooo`03o`000?oooooooooo07;ooooo0ol00005ooooo`;o00000oooool2o`0000Oo
oooo0_l00007ooooo`Ko00001_ooool2o`0000Cooooo1?l00003ooooo`Co00000_ooool5o`000004
ooooool0003o0000o`0000;ooooo0ol00008ooooo`;o00000oooool6o`0001kooooo0_l0001Hoooo
o`007?ooool00ol0003oooooooooo`1booooo`?o00001Oooool2o`0000kooooo0_l00003ooooo`Go
000000?oooooo`000?l000000oooool2o`000004ooooool0003o0000ooooo`Go00001Oooool5o`00
0003ooooool0003o000000co00004Oooool2o`00017ooooo0_l00002ooooo`;o000000?oooooo`00
0?l00000G_ooool001cooooo00?o0000ooooooooool0B?ooool2o`0000;ooooo0_l0000Oooooo`;o
00002_ooool3o`0000kooooo0_l00003ooooo`?o00002?ooool2o`000004ooooool0003o0000oooo
o`Go00000ooooolDo`0000_ooooo0_l0000Iooooo`;o00000_ooool2o`000003ooooool0003o0000
00Wooooo0_l00005ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0B?ooool6o`0001oo
oooo0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o000001Gooooo0_l000000ooooooo
0000o`000008ooooo`;o00001_ooool2o`000003ooooool0003o000000;ooooo4Ol0000:ooooo`;o
00002_ooool2o`0001Gooooo0_l00008ooooo`;o00001Oooool2o`0004cooooo000Looooo`03o`00
0?oooooooooo04[ooooo0_l0000Nooooo`;o00001?ooool4o`000003ooooool0003o000000?o0000
00?oooooo`000?l000004oooool2o`000003ooooool0003o000000?o000000?oooooo`000?l00000
2_ooool2o`0000Gooooo4Ol0000Fooooo`;o00003oooool2o`0000Cooooo0_l0000Aooooo`;o0000
B_ooool001cooooo00?o0000ooooooooool0A?ooool2o`0002Cooooo0_l00004ooooo`?o00000_oo
ool5o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o00002oooool6o`000003ooooool0
003o000000Gooooo0_l0000:oooooaCo00009?ooool2o`0001Oooooo0ol00019ooooo`007?ooool0
0ol0003oooooooooo`14ooooo`;o00009?ooool2o`0000;ooooo1Ol0000>ooooo`;o00000_ooool2
o`0000_ooooo0ol0000;ooooo`;o00002ooooolCo`0000cooooo0_l00004ooooo`;o00008?ooool2
o`0000Sooooo0_l00019ooooo`007?ooool00ol0003oooooooooo`1Vooooo`Ko00000_ooool2o`00
00?ooooo0_l00004ooooo`Co00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000009oooo
o`;o00001Oooool2o`0000Oooooo0_l00007oooooa7o00000_ooool2o`0000_ooooo0_l00004oooo
o`;o00004?ooool3o`0000cooooo0ol0001Cooooo`007?ooool00ol0003oooooooooo`1Rooooo`So
00002Oooool2o`0000Cooooo1?l00003ooooo`?o00000_ooool5o`0000Oooooo1?l00005ooooo`?o
00000oooool2o`000003ooooool0003o000000Kooooo3ol00005ooooo`;o00008oooool3o`0000?o
oooo0_l00007ooooo`;o0000E?ooool001cooooo00?o0000ooooooooool0H_ooool6o`0000Gooooo
1?l00005ooooo`;o00001_ooool4o`0000Cooooo0ol00008ooooo`;o00000oooool2o`0000?ooooo
0_l00003ooooo`?o00001?ooool2o`0000;ooooo4Ol000000ooooooo0000o`00000Dooooo`Co0000
3Oooool3o`0000?ooooo0_l0000Dooooo`;o0000Aoooool001cooooo0_l00014ooooo`;o00006_oo
ool7o`0000Oooooo1?l00005ooooo`;o00001_ooool2o`0000Kooooo0_l0000;ooooo`;o000000Co
ooooo`000?l0003ooooo0_l00006ooooo`;o00001?ooool2o`0000Cooooo5?l00005ooooo`;o0000
2oooool4o`0000?ooooo0_l00009ooooo`?o00003oooool2o`0000Oooooo0_l00017ooooo`007?oo
ool00ol0003oooooooooo`13ooooo`;o00006?ooool8o`0000;ooooo0_l0000Nooooo`;o00002_oo
ool2o`0000Cooooo0_l0000@oooooaKo00001Oooool2o`0000?ooooo0_l00004ooooo`;o00001ooo
ool2o`0000[ooooo0ol0000<ooooo`Co0000D?ooool001cooooo00?o0000ooooooooool0?_ooool2
o`0000Cooooo0_l0000Cooooo`Ko00001?ooool2o`0000;ooooo0_l0000Nooooo`;o00008_oooolD
o`0000cooooo0_l00004ooooo`;o00005?ooool2o`000003ooooool0003o000000Wooooo0ol0000:
ooooo`;o0000AOooool001cooooo00?o0000ooooooooool0?_ooool3o`0000?ooooo0_l0000Coooo
o`Co00001_ooool2o`0001kooooo0ol0000Pooooo`;o000000?oooooo`000?l000005?l000000ooo
oooo0000o`00000Iooooo`;o000000?oooooo`000?l000002_ooool2o`0001Kooooo0_l00015oooo
o`007?ooool00ol0003oooooooooo`0oooooo`;o00006?ooool3o`0002Oooooo0ol0000Kooooo`;o
00000oooool2o`000003ooooool0003o000001Oo00006Oooool2o`000003ooooool0003o000000?o
oooo0_l00003ooooo`Co0000GOooool001cooooo00?o0000ooooooooool0Eoooool2o`0001Sooooo
0_l00003ooooo`;o00003oooool2o`0000cooooo0_l0000:ooooo`;o00001_oooolHo`0001cooooo
0_l00004ooooo`?o00000_ooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0000;o
oooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00005_ooool2o`00017ooooo
0ol00004ooooo`;o00000oooool2o`0000oooooo0_l0000:ooooo`Co00004_ooool2o`000003oooo
ool0003o0000017o00000oooool2o`0001Wooooo0_l00005ooooo`;o00000_ooool2o`0000?ooooo
0ol000001?oooooo0000o`000?ooool6o`0004oooooo000Looooo`03o`000?oooooooooo03oooooo
0_l0000Yooooo`?o00002_ooool2o`000003ooooool0003o000000?ooooo0_l0000Booooo`Co0000
5OoooolBo`0000?ooooo0ol0000Jooooo`;o000000?oooooo`000?l000001Oooool3o`0000;ooooo
0_l00007ooooo`?o0000D?ooool001cooooo00?o0000ooooooooool0@Oooool2o`0001cooooo0_l0
000Fooooo`;o000000?oooooo`000?l000000oooool2o`0000Oooooo0_l00007ooooo`Co00006Ooo
ool@o`0000?ooooo1?l00007ooooo`;o00004?ooool2o`000003ooooool0003o000000Kooooo0_l0
0007ooooo`;o00000oooool4o`0004kooooo000Looooo`03o`000?oooooooooo047ooooo0_l0000=
ooooo`;o00003Oooool2o`0001Oooooo0_l0000:ooooo`;o00000_ooool2o`0000Oooooo1?l00007
ooooo`;o000000?oooooo`000?l000003?ooool2o`000003ooooool0003o000000co00000oooool4
o`0000Oooooo1?l0000Rooooo`;o00001Oooool2o`0004kooooo000Looooo`03o`000?oooooooooo
04?ooooo0_l0000;ooooo`;o00002oooool2o`0000_ooooo0_l0000<ooooo`;o00000oooool2o`00
00Gooooo0_l0000Fooooo`;o000000?oooooo`000?l000003?ooool2o`000003ooooool0003o0000
00So000000Coooooo`000?l0003o00000oooool3o`0000[ooooo0_l0000Rooooo`;o00001Oooool2
o`0004kooooo000Looooo`03o`000?oooooooooo04?ooooo0_l00009ooooo`Ko00002Oooool2o`00
00_ooooo0_l0000@ooooo`?o00007oooool4o`0000[ooooo0_l00002ooooo`[o00000_ooool3o`00
00;ooooo1?l0000Tooooo`;o00001oooool2o`0000kooooo1_l00011ooooo`007?ooool00ol0003o
ooooooooo`1=ooooo`Co000000?oooooo`000?l000004?ooool2o`0000Gooooo0_l0000?ooooo`;o
000000Coooooo`000?l0003o00001?ooool2o`0000;ooooo0_l0000>ooooo`;o00000_ooool4o`00
00[ooooo0_l00003ooooo`?o000000?oooooo`000?l000000ol00003ooooo`;o00001?ooool4o`00
02;ooooo0ol00006ooooo`Co000000?oooooo`000?l000002Oooool6o`00047ooooo000Looooo`03
o`000?oooooooooo03?ooooo0_l0000Dooooo`;o000000?oooooo`000?l000000ol0000:ooooo`;o
00000oooool2o`0000;ooooo0ol00004ooooo`;o00001?ooool4o`0000Cooooo0_l000001?oooooo
0000o`000?ooool3o`0000;ooooo1?l00002ooooo`;o00003_ooool4o`0001?ooooo1Ol0000:oooo
o`;o00000_ooool3o`0000Wooooo0_l0000Gooooo`?o00001Oooool5o`000003ooooool0003o0000
053ooooo000Looooo`03o`000?oooooooooo03?ooooo0_l0000Dooooo`;o000000?oooooo`000?l0
00000_l000000ooooooo0000o`000008ooooo`;o00000oooool2o`000003ooooool0003o000000;o
00001?ooool2o`0000Cooooo1Ol00002ooooo`?o000000?oooooo`000?l000000_ooool2o`0000;o
oooo1?l0000Dooooo`;o00005_ooool2o`0000?ooooo0_l00004ooooo`?o00000_ooool2o`0000Wo
oooo0ol0000Gooooo`Co00001?ooool2o`0000Cooooo0_l0000?ooooo`;o0000?oooool001cooooo
00?o0000ooooooooool0?oooool2o`0000Sooooo0_l00006ooooo`;o00002?ooool2o`0000Kooooo
0_l00006ooooo`;o00000oooool7o`000003ooooool0003o000000Kooooo0_l00004ooooo`Co0000
2?ooool2o`0000?ooooo0_l00003ooooo`?o000000?oooooo`000?l000005_ooool5o`0000;ooooo
0_l00003ooooo`;o00001Oooool2o`0000;ooooo1?l0000Cooooo`;o000000?oooooo`000?l00000
0_l0000:ooooo`;o00003oooool2o`0003oooooo000Looooo`;o0000<oooool2o`0000[ooooo0ol0
000Hooooo`Co00004oooool4o`000004ooooool0003o0000o`00013ooooo0_l00008ooooo`Co0000
00?oooooo`000?l000001?ooool2o`000004ooooool0003o0000o`0001Gooooo0_l000001Ooooooo
0000o`000?l0003ooooo00;o00002_ooool2o`0000Cooooo0_l0000Cooooo`;o000000Coooooo`00
0?l0003ooooo0_l00009ooooo`Co0000C_ooool001cooooo00?o0000ooooooooool0<?ooool4o`00
00[ooooo0_l0000Iooooo`;o00005oooool2o`0000;ooooo0_l00008ooooo`;o00000_ooool2o`00
00Wooooo0ol00002ooooo`Go00001?ooool6o`0001Wooooo0_l0000[ooooo`;o000000?oooooo`00
0?l000002oooool2o`0004kooooo000Looooo`03o`000?oooooooooo033ooooo0_l0000/ooooo`;o
00000oooool4o`0000Kooooo0_l000000ooooooo0000o`000008ooooo`;o00001?ooool2o`0000;o
oooo0_l00009ooooo`?o00001?ooool3o`0000Cooooo1?l0000Tooooo`;o00002Oooool2o`0000Oo
oooo0_l0000=ooooo`;o00001?ooool2o`0000Sooooo1?l0001=ooooo`007?ooool00ol0003ooooo
ooooo`1Looooo`Co00000oooool4o`0000Kooooo0_l000000ooooooo0000o`000002ooooo`?o0000
0oooool2o`0000?ooooo0_l000000ooooooo0000o`00000Jooooo`;o00009Oooool2o`0000Sooooo
0ol00007ooooo`;o00003Oooool2o`0000Cooooo0_l00008ooooo`Co0000COooool001cooooo00?o
0000ooooooooool0>oooool2o`0001Sooooo0_l00005ooooo`;o00000_ooool2o`0000_ooooo0_l0
0005ooooo`?o00002?ooool7o`0001Sooooo0_l00002ooooo`;o00008_ooool2o`0000Oooooo0_l0
000Eooooo`;o00004?ooool3o`0000;ooooo0_l0000;ooooo`;o0000?Oooool001cooooo00?o0000
ooooooooool0>oooool2o`0000_ooooo0_l00007ooooo`;o00000_ooool2o`0000?ooooo0_l00000
0ooooooo0000o`000003o`0000;ooooo0_l00007ooooo`;o00004_ooool2o`000003ooooool0003o
000000gooooo0_l00002ooooo`;o00002Oooool2o`0002;ooooo0_l000000ooooooo0000o`000005
ooooo`;o00005?ooool2o`0000cooooo0_l00002ooooo`;o00000oooool2o`0000Kooooo0_l00003
ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0A?ooool2o`0000;ooooo0ol00006oooo
o`Co00001Oooool6o`0000Cooooo0_l00002ooooo`;o00001Oooool3o`0000?ooooo0_l000000ooo
oooo0000o`000004ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`000003ooooool0003o
000000Gooooo1Ol00002ooooo`;o0000;_ooool4o`0000Gooooo0_l0000Hooooo`;o00002?ooool2
o`0000gooooo1?l00012ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00000oooool2o`00
00Cooooo1_l00006ooooo`;o00002oooool2o`0000?ooooo1Ol00003ooooo`;o000000?oooooo`00
0?l000001?ooool2o`000003ooooool0003o000000Go000000Coooooo`000?l0003ooooo0_l00002
ooooo`Co00000_ooool2o`0000[ooooo1?l0000Qooooo`;o00004Oooool2o`0000kooooo0_l0000;
ooooo`;o00001?ooool2o`0000Cooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`1?oooo
o`Co00003?ooool2o`0000cooooo0_l00006ooooo`?o000000?oooooo`000?l000000ol00004oooo
o`Wo000000Coooooo`000?l0003o00000_ooool2o`000003ooooool0003o000000;o00002_ooool4
o`00017ooooo1?l0000Oooooo`;o00006oooool2o`0000Cooooo0_l0000=ooooo`;o0000>oooool0
01cooooo00?o0000ooooooooool0C_ooool2o`0000oooooo0_l0000:ooooo`;o00000oooool2o`00
00?ooooo0ol000000ooooooo0000o`000005o`000003ooooool0003o000000So00000_ooool2o`00
00;ooooo0_l000001?oooooo0000o`000?l00007ooooo`;o00005Oooool6o`0000_ooooo0_l0000S
ooooo`;o00002_ooool2o`00017ooooo1?l0000kooooo`007?ooool00ol0003oooooooooo`14oooo
o`;o00002?ooool2o`0000Oooooo0_l00003ooooo`;o00002oooool4o`0000?ooooo0ol000001Ooo
oooo0000o`000?l0003ooooo00;o000000?oooooo`000?l000000ol000000ooooooo0000o`000004
o`0000;ooooo0_l00009ooooo`Co00001_ooool2o`0001Gooooo0_l0000?ooooo`;o00001?ooool5
o`0000Cooooo0_l0000Cooooo`?o00001oooool2o`000003ooooool0003o000000cooooo0_l00003
ooooo`Co0000>oooool001cooooo00?o0000ooooooooool0A?ooool2o`00017ooooo0_l00003oooo
o`;o00002oooool4o`0000Cooooo1Ol000001?oooooo0000o`000?l00002ooooo`;o00000oooool6
o`0000;ooooo1Ol00003ooooo`;o000000?oooooo`000?l000000_l0000Nooooo`;o00004_ooool7
o`0000Cooooo0_l0000Cooooo`;o00001oooool3o`000003ooooool0003o000000Gooooo0_l00005
ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0=oooool2o`0000Wooooo0_l0000<oooo
o`;o00000_ooool2o`0000Gooooo0_l00009ooooo`;o00001?ooool2o`0000Cooooo0ol00002oooo
o`;o00000_ooool4o`000004ooooool0003o0000ooooo`;o00001?ooool7o`000003ooooool0003o
000000cooooo0_l00006ooooo`;o00002?ooool2o`0000;ooooo0ol0000?ooooo`[o00000oooool2
o`0000;ooooo0_l0000>ooooo`;o00002Oooool2o`0000;ooooo0_l00005ooooo`;o00001_ooool2
o`00047ooooo000Looooo`03o`000?oooooooooo02Sooooo0_l0000<ooooo`?o00002Oooool2o`00
00cooooo0_l00002ooooo`;o00001?ooool3o`0000Wooooo2?l00008ooooo`;o00000_ooool8o`00
0003ooooool0003o000000;o00001Oooool4o`0000Kooooo0_l00002ooooo`;o00000_ooool3o`00
00?ooooo0_l000000ooooooo0000o`000008ooooo`;o00000_ooool2o`000004ooooool0003o0000
o`0000[ooooo2Ol000001?oooooo0000o`000?ooool4o`0000;ooooo0_l00004ooooo`;o00002?oo
ool2o`0000?ooooo0_l00004ooooo`Co00000oooool2o`0000;ooooo0ol00005ooooo`;o0000@Ooo
ool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413ooooo
ooooo`04ooooo`03o`000?oooooooooo02Sooooo0_l0000<ooooo`;o00002Oooool3o`0000Oooooo
0_l00002ooooo`Co00001oooool2o`0000Cooooo0_l00004ooooo`So00002?ooool2o`0000;ooooo
2?l000000ooooooo0000o`000003o`0000?ooooo1Ol00006ooooo`;o00000_ooool2o`0000;ooooo
0_l00004ooooo`?o00001Oooool2o`000003ooooool0003o000000?ooooo0_l00002ooooo`?o0000
2?ooool>o`000003ooooool0003o000000Co00001?ooool4o`0000gooooo0_l00006ooooo`?o0000
0_ooool2o`0000;ooooo0ol00018ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o
8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03cooooo0_l00003ooooo`;o
00001?ooool2o`0000;ooooo0_l00002ooooo`Co00003Oooool2o`0000Wooooo0_l00002ooooo`;o
000000?oooooo`000?l000001?ooool@o`0000;ooooo1_l000000ooooooo0000o`00000;ooooo`;o
00001Oooool2o`0000Gooooo0_l000000ooooooo0000o`000003ooooo`;o00000oooool2o`0000So
oooo2Ol000000ooooooo0000o`000009o`0000Cooooo0_l0000Eooooo`;o000000?oooooo`000?l0
00001oooool2o`0000[ooooo0_l0000looooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooo
ooooo`09ooooo`Go00001_ooool00ol0003oooooooooo`0looooo`;o00002Oooool2o`0000?ooooo
0_l000001?oooooo0000o`000?l0000Booooo`;o00000_ooool2o`0000Cooooo0ol000000ooooooo
0000o`000002o`0000;ooooo2?l000000ooooooo0000o`00000=o`000003ooooool0003o000000;o
00002Oooool3o`00017ooooo0_l00003ooooo`;o00002Oooool:o`0000;ooooo1ol00003ooooo`;o
00006Oooool2o`0000[ooooo0ol00008ooooo`?o0000??ooool00003ooooool0003ooooo00;ooooo
00?o0000ooooooooool02Oooool01?m4A4CogMgMooooool00007ooooo`?o0000>oooool2o`0000oo
oooo0_l000000ooooooo0000o`00000Cooooo`;o00000_ooool2o`0000Cooooo1Ol000000ooooooo
0000o`00000Ao`000003ooooool0003o000000;o00000_ooool2o`0000;ooooo0ol0000:ooooo`;o
00001oooool2o`0000Sooooo0_l00003ooooo`;o00001?ooool2o`0000;ooooo5_l000000ooooooo
0000o`00000=ooooo`;o00004?ooool2o`0000Cooooo0ol00008ooooo`?o0000??ooool00003oooo
ool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?oMgMgoEEEEooooool00007ooooo`03
o`000?oooooooooo02Kooooo0_l0000Cooooo`;o00001?ooool2o`0000oooooo0_l00009ooooo`;o
00001?ooool4o`000003ooooool0003o000000Gooooo6ol000001?oooooo0000o`000?l00002oooo
o`Co00002Oooool4o`0000Oooooo0_l00006ooooo`;o00000oooool2o`0000Kooooo0_l00002oooo
oaOo00000oooool2o`0000[ooooo0_l0000:ooooo`;o00001?ooool2o`0000Cooooo0_l00018oooo
o`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oo
oooo00?o0000ooooooooool08?ooool2o`0000Cooooo0_l0000:ooooo`;o00001oooool2o`0000Co
oooo0_l00006ooooo`?o00001_ooool2o`0000;ooooo0_l00005ooooo`;o00001?ooool4o`0000Ko
oooo7Ol000001Ooooooo0000o`000?l0003ooooo00Go00002Oooool4o`0000Oooooo0_l00006oooo
o`;o00000oooool3o`0000Oooooo1_l000000ooooooo0000o`00000Bo`000003ooooool0003o0000
00Cooooo0_l00007ooooo`;o00001Oooool6o`0001Sooooo0_l0000hooooo`0000KoooooogMgMonH
V9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool08?ooool2
o`00013ooooo0_l00007ooooo`;o00003?ooool3o`0000[ooooo0_l00002ooooo`;o00002?ooool2
o`0000Cooooo8_l000000ooooooo0000o`000003o`0000?ooooo0_l0000Aooooo`;o00001Oooool2
o`000003ooooool0003o000000;ooooo0_l00007ooooo`co000000?oooooo`000?l000001_l00000
0ooooooo0000o`000003o`0000Oooooo0_l00007ooooo`;o00001Oooool3o`000003ooooool0003o
000000Gooooo0_l0000Aooooo`;o0000>?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Ooo
ool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo04Sooooo1Ol0000<ooooo`?o00002Ooo
ool2o`0000?ooooo5Ol000000ooooooo0000o`000003o`000003ooooool0003o000000[o00000_oo
ool3o`00017ooooo0_l00005ooooo`;o000000?oooooo`000?l000002OoooolKo`0001[ooooo0_l0
00000ooooooo0000o`000002o`0000?ooooo1?l000000ooooooo0000o`000016ooooo`007?ooool0
0ol0003oooooooooo`0`ooooo`;o00002Oooool2o`0000_ooooo0_l000001?oooooo0000o`000?oo
ool2o`0000Wooooo0ol00005ooooo`;o00000_ooool2o`000003ooooool0003o000000Cooooo7ol0
0002ooooo`Oo00004_ooool2o`0001?ooooo0ol00002oooooaWo00007?ooool2o`0000Gooooo0_l0
00000ooooooo0000o`000016ooooo`007?ooool00ol0003oooooooooo`0Tooooo`;o00002_ooool2
o`0000Wooooo0_l0000Aooooo`?o00003?ooool2o`0000;ooooo0_l00002ooooo`Go00001?oooolM
o`0000?ooooo1_l0000Jooooo`;o00002_ooool2o`0000;ooooo7Ol0000?ooooo`;o0000GOooool0
01cooooo00?o0000ooooooooool09?ooool2o`0002Wooooo0_l000000ooooooo0000o`000003o`00
00?ooooo0_l000000ooooooo0000o`000007ooooo`;o00001?oooolOo`000003ooooool0003o0000
00Oo00006Oooool2o`0000[ooooo0_l00002oooooako000000?oooooo`000?l000002oooool3o`00
00gooooo0_l0000;ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0?_ooool2o`0000?o
oooo0_l00003ooooo`;o00002?ooool5o`0000?ooooo0_l00008ooooo`;o00000oooool2o`000003
ooooool0003o000001Oo00000_ooool>o`0002;ooooo0_l00005ooooo`Go000000?oooooo`000?l0
00005_l000000ooooooo0000o`00000;ooooo`?o00003Oooool2o`0000_ooooo0_l00007ooooo`;o
0000=oooool001cooooo00?o0000ooooooooool0;_ooool2o`0000Sooooo0_l000001?oooooo0000
o`000?ooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`0000[ooooo0_l0000;ooooo`;o
000000?oooooo`000?l000000ooooolXo`0000;ooooo0_l0000Rooooo`;o000000?oooooo`000?l0
00008?l00004ooooo`;o00002?ooool2o`0000Wooooo0_l0000?ooooo`Co00001_ooool2o`0003Oo
oooo000Looooo`03o`000?oooooooooo02gooooo0ol00008ooooo`;o000000?oooooo`000?l00000
0oooool2o`0000Cooooo1?l0000Booooo`;o00000_ooool3o`0000Oooooo1?l000000ooooooo0000
o`00000Ho`000003ooooool0003o000000Wo00003_ooool2o`0000Oooooo0_l0000<ooooob;o0000
1?ooool2o`0000gooooo0_l00004ooooo`;o00000oooool4o`0000Sooooo1?l0000oooooo`007?oo
ool00ol0003oooooooooo`0]ooooo`;o00002oooool3o`0000?ooooo0_l00006ooooo`;o00004?oo
ool4o`0000;ooooo0_l00004ooooo`;o00000_oooolUo`000003ooooool0003o000000Go00003?oo
ool2o`0000?ooooo0_l00002ooooo`;o00001Oooool2o`0000Sooooo3_l000000ooooooo0000o`00
000>o`0000kooooo0_l00002ooooo`?o000000?oooooo`000?l000001_ooool4o`0000;ooooo0_l0
0005ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0>_ooool2o`0000Kooooo0_l0000C
ooooo`;o000000?oooooo`000?l000001Oooool2o`0000?ooooo0_l00002ooooobGo00000_ooool2
o`000004ooooool0003o0000o`0000Sooooo0ol00003ooooo`;o000000?oooooo`000?l000001Ooo
ool6o`0000?ooooo0_l000000ooooooo0000o`00000Mo`00013ooooo0_l00002ooooo`;o00000_oo
ool2o`0000cooooo0_l00005ooooo`;o00001?ooool2o`0000;ooooo0_l0000fooooo`007?ooool0
0ol0003oooooooooo`12ooooo`?o00001oooool2o`0000Wooooo0ol00005ooooo`Ko00000oooool[
o`000003ooooool0003o000000Wooooo0ol00003ooooo`;o000000?oooooo`000?l000000_l00003
ooooo`Go00001?ooool8o`000003ooooool0003o000001Go0000;oooool2o`0000Cooooo0_l00000
1?oooooo0000o`000?l0000fooooo`007?ooool00ol0003oooooooooo`11ooooo`Co00000_ooool4
o`000003ooooool0003o000000[ooooo0_l00005ooooo`Ko00000_oooolZo`0001Wooooo0_l00005
ooooo`Oo00000_ooool2o`000005ooooool0003o0000o`000?ooool06?l0000@ooooo`;o00002_oo
ool2o`00017ooooo0_l00006ooooo`;o0000=oooool001cooooo00?o0000ooooooooool0@Oooool2
o`000004ooooool0003o0000ooooo`Co00001oooool3o`0000Gooooo0_l00003ooooo`Ko000000?o
ooooo`000?l000001Ol000001Ooooooo0000o`000?l0003ooooo01Wo000000?oooooo`000?l00000
0ol000000ooooooo0000o`000002o`0000cooooo0_l0000?ooooo`Oo00001?oooolMo`0000kooooo
0ol00009ooooo`;o00004Oooool2o`0003oooooo000Looooo`;o00008?ooool2o`0002?ooooo1?l0
000:ooooo`?o00001Oooool2o`0000Cooooo1Ol000000ooooooo0000o`00000Oo`000005ooooool0
003o0000o`000?ooool01Ol000000ooooooo0000o`000002o`0000cooooo0_l00005ooooo`;o0000
1_ooool6o`000003ooooool0003o000000;ooooo8Ol0000=ooooo`;o00005_ooool2o`0004Gooooo
000Looooo`03o`000?oooooooooo01oooooo0ol0000Eooooo`;o00002oooool4o`0000?ooooo0_l0
000Gooooo`;o00000_oooolSo`000004ooooool0003o0000ooooo`;o00001?ooool2o`0000_ooooo
0_l00005ooooo`;o00001_ooool2o`0000;ooooo0_l00005ooooo`Co00000_oooolKo`0000_ooooo
0_l0000;ooooo`;o00002oooool4o`000003ooooool0003o0000043ooooo000Looooo`03o`000?oo
oooooooo023ooooo0_l0000Eooooo`;o00002oooool3o`0000Cooooo0_l00003ooooo`;o00003?oo
ool2o`0000Cooooo0ol000000ooooooo0000o`00000Ro`0000?ooooo1?l00002ooooo`;o00003?oo
ool2o`0000kooooo1Ol00002ooooo`;o00002?oooolBo`0000?ooooo0_l0000=ooooo`;o00002ooo
ool2o`0000?ooooo0_l00008ooooo`;o000000?oooooo`000?l00000@?ooool001cooooo00?o0000
ooooooooool07_ooool2o`0001kooooo0_l0000:ooooo`;o000000Coooooo`000?l0003ooooo0_l0
000<ooooo`;o00001Oooool2o`000003ooooool0003o000002?o00000oooool3o`0000;ooooo0_l0
000:ooooo`Co00000oooool2o`0000Sooooo0ol000000ooooooo0000o`000002ooooo`;o00002?oo
oolBo`0002Cooooo1?l0001;ooooo`007?ooool00ol0003oooooooooo`0Nooooo`;o00007_ooool2
o`0000[ooooo0_l000000ooooooo0000o`00000Fooooo`;o00000_oooolUo`0000;ooooo0ol00002
ooooo`;o00001?ooool2o`0000Cooooo0_l00005ooooo`;o00002?ooool2o`0000Cooooo0ol00004
ooooo`Co000000?oooooo`000?l000001?l000000ooooooo0000o`000009o`000003ooooool0003o
000000Wooooo0_l0000Cooooo`;o00000_ooool3o`0000oooooo0_l0000jooooo`007?ooool00ol0
003oooooooooo`0looooo`Co00001?ooool2o`0000?ooooo0ol0000Kooooo`;o000000?oooooo`00
0?l000009?l000001?oooooo0000o`000?l00004ooooo`;o000000?oooooo`000?l000001Oooool2
o`0000Sooooo0_l00004ooooo`;o00001?ooool3o`0000Cooooo1?l000000ooooooo0000o`000004
o`0000;ooooo2Ol00002ooooo`;o00002Oooool2o`0001?ooooo0_l0000Dooooo`;o0000>_ooool0
01cooooo00?o0000ooooooooool0??ooool2o`0000Gooooo0ol00003ooooo`;o00005oooool2o`00
00?ooooo8_l00002ooooo`Go000000Coooooo`000?l0003o00000oooool3o`0000Oooooo0ol00002
ooooo`;o00001?ooool2o`0000Cooooo0_l00006ooooo`;o00000_ooool2o`000004ooooool0003o
0000ooooo`;o000000?oooooo`000?l000002Ol000000ooooooo0000o`000004o`0000Cooooo0_l0
0009ooooo`;o00003_ooool2o`0000;ooooo0ol00007ooooo`;o0000@Oooool001cooooo00?o0000
ooooooooool0=_ooool2o`0000Cooooo0_l00005ooooo`?o00007?ooool2o`000003ooooool0003o
000000;ooooo9_l00008ooooo`;o00001?ooool2o`0000;ooooo0_l00003ooooo`;o00001?ooool2
o`0000Kooooo0_l000001?oooooo0000o`000?ooool3o`000004ooooool0003o0000ooooo`;o0000
0oooool=o`0000;ooooo0_l00006ooooo`;o00001oooool4o`0000kooooo0_l00002ooooo`?o0000
1oooool3o`0000[ooooo0_l0000dooooo`007?ooool00ol0003oooooooooo`0dooooo`Co00001Ooo
ool2o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`;o00006?ooool2o`0000Cooooo8ol0
0002ooooo`;o00001Oooool2o`0000;ooooo1?l000000ooooooo0000o`000004ooooo`;o00001?oo
ool2o`0000;ooooo1_l000000ooooooo0000o`000002ooooo`?o00002?ooool4o`0000;ooooo1ol0
0002ooooo`;o00000_ooool2o`0000[ooooo0ol0000>ooooo`?o00002_ooool3o`000003ooooool0
003o000000[ooooo0_l0000dooooo`007?ooool00ol0003oooooooooo`0dooooo`?o00001_ooool2
o`0000;ooooo0_l00008ooooo`;o00007OoooolJo`000004ooooool0003o0000o`0000?ooooo0ol0
0002ooooo`Co00001oooool2o`0000?ooooo0_l00004ooooo`;o00002?ooool5o`0000Oooooo0_l0
0006ooooo`Oo000000?oooooo`000?l000001Ol00002ooooo`;o00000_ooool2o`0000[ooooo0_l0
000?ooooo`?o00000oooool2o`0000Gooooo0ol00013ooooo`007?ooool00ol0003oooooooooo`0e
ooooo`;o00000_ooool2o`0000Gooooo1ol00008ooooo`;o000000Coooooo`000?l0003ooooo0_l0
0005ooooo`;o00003?ooool6o`0000;ooooo5Ol000000ooooooo0000o`000004ooooo`;o00000_oo
ool2o`0001;ooooo0_l00005ooooo`;o00000oooool3o`0000?ooooo0_l0000:ooooo`Co000000?o
ooooo`000?l000001?ooool4o`0000;ooooo0_l000000ooooooo0000o`00000Rooooo`;o00004?oo
ool2o`0003Wooooo000Looooo`03o`000?oooooooooo03Wooooo0_l00005ooooo`Oo00002?ooool2
o`000004ooooool0003o0000ooooo`Co00000oooool2o`0000Cooooo0_l00008oooooako00001?oo
ool4o`0000gooooo0ol0000;ooooo`;o00001?ooool2o`0000?ooooo0_l0000Eooooo`?o00000ooo
ool2o`000003ooooool0003o000003Cooooo0_l000000ooooooo0000o`00000fooooo`007?ooool0
0ol0003oooooooooo`0hooooo`;o00007Oooool2o`0000Kooooo0_l000000ooooooo0000o`000006
ooooo`;o00000_ooool@o`000003ooooool0003o000000So000000Coooooo`000?l0003o00000ooo
ool2o`0000Cooooo1Ol00004ooooo`?o00003oooool5o`0000Oooooo0_l00007ooooo`Go00001?oo
ool8o`0002?ooooo0_l0000Dooooo`?o0000=_ooool001cooooo00?o0000ooooooooool0>?ooool4
o`0000Wooooo0_l0000;ooooo`;o00001Oooool2o`0000Cooooo0_l00004ooooo`;o00000oooool2
o`0000?ooooo4Ol000000ooooooo0000o`000005o`000003ooooool0003o000000;o00002Oooool5
o`000004ooooool0003o0000ooooo`?o00003oooool5o`0000;ooooo0_l00003ooooo`;o00000_oo
ool2o`0000?ooooo1Ol00006ooooo`Go000000?oooooo`000?l000003oooool2o`0000gooooo0_l0
00000ooooooo0000o`000004ooooo`;o00000_ooool3o`0000Wooooo0_l0000gooooo`007?ooool0
0ol0003oooooooooo`0jooooo`;o00001oooool4o`000003ooooool0003o000000Sooooo0_l00005
ooooo`;o00001?ooool3o`0000?ooooo0_l00005ooooo`;o000000?oooooo`000?l000004?l00000
0ooooooo0000o`000003o`000005ooooool0003o0000o`000?ooool00_l00006ooooo`;o000000?o
ooooo`000?l000000_l000000ooooooo0000o`000002ooooo`;o00002oooool2o`000003ooooool0
003o000000Co00000_ooool2o`0000;ooooo0_l00002ooooo`?o00004oooool3o`0000?ooooo0_l0
000:ooooo`Co00002oooool2o`0000Oooooo0_l00002ooooo`?o0000@_ooool001cooooo00?o0000
ooooooooool06oooool2o`0002Kooooo0_l00002ooooo`?o00000_ooool2o`0001;ooooo0_l00005
ooooo`;o000000?oooooo`000?l000001Ol000000ooooooo0000o`00000>o`0000;ooooo0_l00000
1Ooooooo0000o`000?l0003ooooo00?o00001?ooool7o`0001Cooooo1_l000000ooooooo0000o`00
0006ooooo`;o00000_ooool2o`0000Gooooo0_l00009ooooo`;o00000_ooool2o`0000Cooooo0_l0
0006ooooo`;o00000_ooool4o`00023ooooo0_l00004ooooo`;o0000=Oooool001cooooo0_l0000L
ooooo`;o00006Oooool2o`0000Kooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l0000I
ooooo`;o000000?oooooo`000?l000000_ooool3o`000003ooooool0003o000000Oo000000?ooooo
o`000?l000001?l00003ooooo`Co00000_ooool3o`0000Cooooo1ol00003ooooo`;o00003oooool6
o`0001Cooooo0_l00009ooooo`;o00004?ooool2o`0001Oooooo0_l0000=ooooo`;o00001?ooool2
o`0003Gooooo000Looooo`03o`000?oooooooooo03Kooooo0_l00006ooooo`;o00002oooool2o`00
02;ooooo1Ol00002ooooo`Go000000?oooooo`000?l000000ol000001?oooooo0000o`000?ooool2
o`0000?ooooo1?l00006ooooo`Co00001?ooool2o`0000oooooo1_l0000Mooooo`;o0000:?ooool2
o`000003ooooool0003o000000cooooo0_l0000looooo`007?ooool00ol0003oooooooooo`0noooo
o`;o00002oooool2o`0001_ooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo4?l000000ooo
oooo0000o`000003ooooo`Co00001oooool2o`0001Gooooo0_l000000ooooooo0000o`000002oooo
o`;o00000_ooool2o`0001Oooooo0_l0000Uooooo`;o000000?oooooo`000?l000003Oooool4o`00
00Oooooo0_l0000cooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00000_ooool2o`0000;o
oooo0ol0000:ooooo`;o00000_ooool2o`0001Oooooo0_l000001?oooooo0000o`000?l00002oooo
o`Ko00000_ooool;o`0000gooooo0_l0000Jooooo`;o00001Oooool2o`0000;ooooo0_l0000Voooo
o`;o00005_ooool3o`0000Wooooo1?l00002ooooo`;o00000oooool2o`0000Cooooo0_l00002oooo
o`;o0000;oooool001cooooo00?o0000ooooooooool0=_ooool2o`0000;ooooo0_l000000ooooooo
0000o`000002o`0000kooooo0_l0000Hooooo`Ko00000oooool2o`0000Cooooo0_l00005ooooo`;o
000000?oooooo`000?l000000ol00009ooooo`;o00002_ooool2o`0000kooooo1_l00005ooooo`;o
00005oooool2o`0000cooooo0ol0000Gooooo`;o00001Oooool8o`0000Oooooo0_l00004ooooo`;o
00000_ooool2o`0002oooooo000Looooo`03o`000?oooooooooo03[ooooo0_l000001?oooooo0000
o`000?ooool2o`0002Oooooo0_l00002ooooo`;o00004?ooool2o`000003ooooool0003o000000?o
00001?ooool2o`0000kooooo0ol0000@ooooo`Co00001Oooool2o`0001Kooooo1Ol0000:ooooo`;o
00005oooool4o`0000?ooooo1Ol00016ooooo`007?ooool00ol0003oooooooooo`0cooooo`Co0000
0oooool2o`0000?ooooo0ol00007ooooo`;o00005_ooool3o`0000[ooooo0_l00008ooooo`;o0000
1?ooool3o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o00001?ooool2o`0000Oooooo
1?l00002ooooo`;o00003_ooool3o`00013ooooo1?l00008ooooo`;o000000?oooooo`000?l00000
0oooool2o`000003ooooool0003o000001_ooooo1?l00003ooooo`;o0000BOooool001cooooo00?o
0000ooooooooool0<oooool4o`0000Sooooo0_l00008ooooo`;o00005_ooool3o`0000[ooooo0_l0
0008ooooo`;o00001?ooool6o`0000?ooooo0_l00007ooooo`?o00001oooool4o`0000;ooooo0_l0
0004ooooo`;o00002Oooool2o`00013ooooo1_l00006ooooo`;o00001_ooool5o`0003?ooooo0_l0
00000ooooooo0000o`00000eooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00002?ooool2
o`0002Sooooo0_l00006ooooo`;o00000oooool2o`0000Oooooo1?l00003ooooo`;o00001oooool2
o`0000Sooooo0_l0000:ooooo`;o00006oooool2o`0000;ooooo0_l000000ooooooo0000o`000002
ooooo`?o000000?oooooo`000?l000000_l000001Ooooooo0000o`000?l0003ooooo00;o00002Ooo
ool2o`0001Gooooo0_l0000@ooooo`;o000000Coooooo`000?l0003ooooo0_l0000booooo`007?oo
ool00ol0003oooooooooo`0cooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0
003o000000?o00001Oooool2o`00027ooooo0_l00006ooooo`Co000000?oooooo`000?l000000_l0
00000ooooooo0000o`00000Kooooo`;o0000:oooool2o`0000;ooooo0_l00002ooooo`;o00000_oo
ool4o`0000Cooooo0ol00009ooooo`;o00005Oooool2o`0001Kooooo0_l0000booooo`007?ooool0
0ol0003oooooooooo`0cooooo`;o00001Oooool2o`000003ooooool0003o000000?o00000_ooool2
o`000003ooooool0003o0000027ooooo0_l000000ooooooo0000o`000005ooooo`;o00000oooool5
o`0000Cooooo0_l0000Eooooo`;o00004?ooool2o`0000Wooooo0_l0000:ooooo`Ko00000_ooool2
o`0000;ooooo1?l00002ooooo`;o00001?ooool3o`0000_ooooo0_l0000Aooooo`Co0000B_ooool0
01cooooo00?o0000ooooooooool0=_ooool2o`0000Kooooo0_l00002ooooo`Co00007?ooool2o`00
00Sooooo0ol0000<ooooo`;o00000oooool5o`0000Kooooo1?l000000ooooooo0000o`000005oooo
o`Co00000_ooool2o`0000cooooo0_l00009ooooo`;o00002_ooool5o`0000?ooooo0ol000000ooo
oooo0000o`000006o`0000Oooooo0_l00009ooooo`;o00004Oooool4o`000003ooooool0003o0000
00gooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00001_ooool2o`0000;o
oooo0_l0000Nooooo`Co00001_ooool2o`0001;ooooo1Ol00006ooooo`Co000000?oooooo`000?l0
00001Oooool9o`00013ooooo0_l0000Cooooo`;o00001?ooool:o`0000Sooooo0_l0000Qooooo`;o
00001?ooool2o`0000Cooooo0_l000000ooooooo0000o`00000hooooo`007?ooool00ol0003ooooo
ooooo`1Tooooo`;o00004_ooool5o`0000;ooooo1?l00004ooooo`;o00004Oooool6o`0000?ooooo
0_l00002ooooo`;o00000_ooool2o`0000;ooooo0ol0000Eooooo`;o000000?oooooo`000?l00000
3Ol0000Uooooo`;o00001_ooool2o`0000Cooooo0_l00007ooooo`;o0000<_ooool001cooooo00?o
0000ooooooooool0<_ooool2o`0001_ooooo0_l0000Wooooo`Go00000_ooool2o`000003ooooool0
003o000000;ooooo1Ol0000=ooooo`;o00000oooool2o`0000Cooooo0_l00002ooooo`?o000000?o
ooooo`000?l000000_ooool4o`0001Cooooo0_l000001?oooooo0000o`000?ooool<o`0000gooooo
0_l0000Fooooo`;o00005Oooool2o`0003;ooooo000Looooo`03o`000?oooooooooo037ooooo0ol0
00000ooooooo0000o`00000Hooooo`;o00009?ooool2o`0000_ooooo1_l000000ooooooo0000o`00
0003o`0000Wooooo0ol0000>ooooo`?o00001_ooool2o`0000oooooo0_l00002ooooo`Ko000000?o
ooooo`000?l000001?l00002ooooo`;o00003oooool2o`0000oooooo0_l0000@ooooo`;o0000?_oo
ool001cooooo0_l0000Nooooo`;o00004_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000a
ooooo`;o00000oooool2o`0000?ooooo0_l00004ooooo`;o00001_ooool3o`0000Cooooo1?l00009
ooooo`?o00003_ooool7o`0001?ooooo0_l000000ooooooo0000o`00000=o`000003ooooool0003o
0000023ooooo0_l0000>ooooo`Co00001_ooool4o`0003Cooooo000Looooo`03o`000?oooooooooo
01gooooo0_l0000Iooooo`Co00000_ooool4o`0000Sooooo0_l0000Oooooo`;o00000oooool2o`00
00?ooooo0_l00004ooooo`;o000000?oooooo`000?l000002oooool2o`0000[ooooo0ol0000<oooo
o`Wo00004oooool5o`000003ooooool0003o000000go00007Oooool2o`00017ooooo0_l00008oooo
o`Co0000=?ooool001cooooo00?o0000ooooooooool0=Oooool2o`0000?ooooo0_l00002ooooo`Co
00002?ooool2o`0000?ooooo0ol0000Nooooo`?o00000_ooool2o`0000Oooooo0_l0000@ooooo`;o
00001_ooool2o`000003ooooool0003o000000;o00001oooool2o`000003ooooool0003o000000?o
00000_ooool3o`0000oooooo5Ol0000Looooo`?o00004?ooool4o`00013ooooo0_l0000]ooooo`00
7?ooool00ol0003oooooooooo`0eooooo`;o00002?ooool2o`0000kooooo0ol0000Cooooo`;o0000
2Oooool3o`000003ooooool0003o000000Kooooo0_l0000Booooo`;o00002Oooool4o`0000Wooooo
1ol000001?oooooo0000o`000?l0000BoooooaCo00006_ooool2o`0000Cooooo0_l000000ooooooo
0000o`000008ooooo`Co00004?ooool2o`0002gooooo000Looooo`03o`000?oooooooooo03oooooo
0_l0000Tooooo`?o00000_ooool2o`0000Sooooo0_l000000ooooooo0000o`000003ooooo`;o0000
0oooool2o`0000gooooo0_l0000Fooooo`Co000000?oooooo`000?l000000ol0000CoooooaCo0000
1oooool2o`0001;ooooo0ol00002ooooo`;o000000?oooooo`000?l000006oooool2o`0002kooooo
000Looooo`03o`000?oooooooooo01gooooo0_l0000Hooooo`;o00001_ooool2o`0002?ooooo1?l0
0002ooooo`;o00002oooool2o`0000?ooooo0_l00003ooooo`;o00002oooool4o`0001?ooooo0_l0
0003ooooo`Oo00005?ooool<o`000003ooooool0003o000000Ko000000?oooooo`000?l000000ooo
ool2o`0001;ooooo0ol00002ooooo`Co00002?ooool2o`0001;ooooo0_l0000^ooooo`007?ooool0
0ol0003oooooooooo`0Mooooo`;o00006?ooool2o`0000[ooooo0_l0000Oooooo`;o00004oooool2
o`0000?ooooo0_l0000=ooooo`?o00001?ooool2o`0000oooooo0_l00002ooooo`;o000000Cooooo
o`000?l0003ooooo0_l0000?ooooo`;o00000ooooolHo`0000Cooooo0_l0000Hooooo`;o00002?oo
ool2o`0000;ooooo0_l00006ooooo`;o0000=_ooool001cooooo00?o0000ooooooooool0>oooool2
o`0000Kooooo1?l0000Sooooo`;o00002oooool4o`0000?ooooo0_l0000=ooooo`;o00000_ooool2
o`000004ooooool0003o0000ooooo`;o00002?ooool2o`0000Kooooo0_l00004ooooo`;o00003ooo
ool2o`0000?ooooo5_l00004ooooo`Co00003Oooool2o`0000Sooooo0_l0000=ooooo`;o00001_oo
ool2o`0003Kooooo000Looooo`03o`000?oooooooooo03Sooooo0_l000001?oooooo0000o`000?oo
ool2o`0000Gooooo0_l0000Sooooo`;o00001oooool2o`0000;ooooo0_l00002ooooo`;o000000Co
ooooo`000?l0003ooooo0_l0000:ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o
00002?ooool2o`0000Kooooo0_l0000IoooooaOo00001?ooool4o`0000gooooo0_l000000ooooooo
0000o`000005ooooo`;o00003Oooool2o`0000;ooooo0_l00002ooooo`Co0000=?ooool001cooooo
00?o0000ooooooooool0=_ooool4o`0000Cooooo0_l000000ooooooo0000o`00000<ooooo`;o0000
5oooool2o`0000Wooooo0_l00006ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo
0000o`000007ooooo`;o00001Oooool2o`0001Kooooo1?l0000Coooooa[o00001?ooool2o`00013o
oooo0_l0000Hooooo`;o00000_ooool6o`0003;ooooo000Looooo`03o`000?oooooooooo03Kooooo
0_l00009ooooo`;o00003?ooool2o`0001Oooooo1?l0000@ooooo`Co00000_ooool5o`0000?ooooo
0_l00002ooooo`;o00001?ooool2o`0001?ooooo0_l000000ooooooo0000o`000002o`0001?ooooo
2_l000000ooooooo0000o`00000?o`0000;ooooo1Ol0000Tooooo`;o00000_ooool2o`0000Gooooo
0_l0000booooo`007?ooool00ol0003oooooooooo`0hooooo`;o0000;?ooool6o`00013ooooo1?l0
0002ooooo`Ko00000_ooool2o`0000;ooooo0_l0000Fooooo`;o000000?oooooo`000?l000002ooo
ool2o`0000gooooo6_l00004ooooo`?o00001_ooool2o`0000?ooooo0ol00008ooooo`;o00001Ooo
ool2o`0000Gooooo0_l000001?oooooo0000o`000?l0000iooooo`007?ooool00ol0003ooooooooo
o`0Pooooo`;o00004_ooool2o`0000;ooooo0_l0000?ooooo`?o00006_ooool6o`00013ooooo1Ol0
0005ooooo`?o00006?ooool4o`000003ooooool0003o000000Gooooo1?l00005ooooo`;o00002ooo
oolLo`0000gooooo0_l000000ooooooo0000o`000003o`0000Sooooo0_l00005ooooo`;o00002?oo
ool3o`0003Wooooo000Looooo`03o`000?oooooooooo023ooooo0_l0000Booooo`;o00004oooool3
o`0001[ooooo0_l000000ooooooo0000o`00000>ooooo`;o00000_ooool4o`0000Kooooo0_l00005
ooooo`;o00002oooool2o`0000;ooooo1_l00008ooooo`Co00004_ooool2o`000003ooooool0003o
000001Oo00000_ooool2o`000003ooooool0003o000000?o00001_ooool2o`000003ooooool0003o
000000;ooooo0_l00004ooooo`;o00003oooool2o`0003[ooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003ooooo
ooooo`0gooooo`;o00001oooool2o`0000Wooooo0_l0000/ooooo`;o00000_ooool3o`000003oooo
ool0003o000000Oooooo0_l00002ooooo`;o00001oooool2o`0000;ooooo0_l00002ooooo`;o0000
2Oooool7o`0000cooooo0_l00007oooooaOo00001?ooool2o`000003ooooool0003o000000?o0000
1Oooool2o`0000Kooooo0_l00004ooooo`Go00000_ooool2o`0000Cooooo0_l00002ooooo`;o0000
>_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMgMooo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo027ooooo0_l0000Dooooo`Co00001Oooool2o`00
00Cooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l0000Fooooo`;o00000oooool2o`00
00[ooooo2?l000000ooooooo0000o`000003ooooo`;o00000_ooool2o`0000_ooooo0_l00008oooo
o`;o00001_ooool7o`0000Gooooo0_l00006ooooo`;o00001?ooool2o`000003ooooool0003o0000
01;o00000oooool2o`0000oooooo0_l0000:ooooo`;o000000?oooooo`000?l000000_l000001?oo
oooo0000o`000?l00004ooooo`;o00001Oooool2o`0003Oooooo00000ooooooo410@ooooo`02oooo
o`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo027ooooo0_l0000Fooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`Co000000?o
ooooo`000?l000001?ooool2o`0000oooooo0ol00004ooooo`;o00000oooool2o`0000Wooooo2_l0
00000ooooooo0000o`000002ooooo`?o00005_ooool4o`0000Gooooo1Ol000001?oooooo0000o`00
0?l00004ooooo`;o00002oooool3o`000003ooooool0003o000001Co000000?oooooo`000?l00000
1_ooool2o`0000;ooooo0_l0000?ooooo`;o00001_ooool3o`0000_ooooo0_l0000gooooo`0000?o
ooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B40
1_ooool3o`0003;ooooo0_l0000:ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Jooooo`?o
00001?ooool2o`000003ooooool0003o000000_ooooo2_l000000ooooooo0000o`000003ooooo`;o
00002?ooool2o`0000cooooo0_l00004ooooo`So00000_ooool2o`00017ooooo0_l00003oooooaOo
00001?ooool2o`000003ooooool0003o000000;ooooo0_l0000Aooooo`;o00001Oooool3o`0004?o
oooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oeEEEOl0003o
410@olc<c006ooooo`03o`000?oooooooooo03;ooooo0_l00005ooooo`;o00002?ooool2o`0000[o
oooo0_l0000Iooooo`;o00002_ooool3o`0000;ooooo1_l00002ooooo`?o00001Oooool2o`0000Co
oooo0_l00003ooooo`;o00000_ooool2o`0000Sooooo1Ol000001Ooooooo0000o`000?l0003ooooo
00;o00001Oooool2o`0000kooooo0_l000000ooooooo0000o`00000Do`0000Cooooo0ol00003oooo
o`;o000000?oooooo`000?l000000oooool2o`0000[ooooo0_l00004ooooo`Co0000@oooool00003
ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03
o`000?oooooooooo03Sooooo0ol00008ooooo`Go00001oooool2o`0001Gooooo0ol0000=ooooo`?o
00000oooool<o`0000?ooooo0_l00008ooooo`?o00000_ooool2o`000003ooooool0003o000000Go
oooo0_l000000ooooooo0000o`000002ooooo`Go00001Oooool2o`0000kooooo0_l000000ooooooo
0000o`00000Bo`0000Oooooo0_l00003ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`00
00oooooo1?l00014ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413o
V9RH00Sooooo00?o0000ooooooooool0>?ooool2o`0000[ooooo1?l00005ooooo`;o00005_ooool4
o`0000_ooooo1ol000000ooooooo0000o`00000<o`000003ooooool0003o000000Sooooo0_l00006
ooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo1Ol0000Iooooo`ko00000_ooool4
o`00013ooooo0_l00006ooooo`;o000000?oooooo`000?l000002?ooool4o`0000[ooooo0_l0000h
ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo
00?o0000ooooooooool08oooool2o`0002Oooooo0ol0000Fooooo`;o00003OoooolGo`0000?ooooo
0_l0000=ooooo`;o000000?oooooo`000?l000001?ooool6o`0001Kooooo0_l00003ooooo`Go0000
00?oooooo`000?l000001ol00004ooooo`;o00001?ooool2o`0000oooooo1Ol000000ooooooo0000
o`000002o`0000Cooooo0_l0000>ooooo`;o0000>?ooool001cooooo00?o0000ooooooooool08ooo
ool2o`00027ooooo0_l00004ooooo`;o00005_ooool2o`0000Cooooo0_l000000ooooooo0000o`00
0003oooooaWo00000oooool2o`0000?ooooo0_l00009ooooo`;o00001?ooool8o`0001Kooooo0_l0
0003ooooo`Co000000Goooooo`000?l0003o0000ooooo`04o`0000cooooo0_l0000?ooooo`Co0000
1?ooool2o`000004ooooool0003o0000ooooo`;o00000oooool2o`0004?ooooo000Looooo`03o`00
0?oooooooooo03Gooooo0_l00002ooooo`;o00001oooool2o`0000;ooooo0_l0000Looooo`;o0000
1?ooool2o`000003ooooool0003o000000?ooooo4ol000000ooooooo0000o`000002o`0000Gooooo
0_l00002ooooo`;o00002Oooool2o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o0000
2_ooool2o`0000cooooo0_l00002ooooo`;o000000Goooooo`000?l0003o0000ooooo`04o`0000_o
oooo0_l00007ooooo`;o00004_ooool2o`0000Gooooo0ol00004ooooo`;o0000?Oooool001cooooo
00?o0000ooooooooool0=Oooool3o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000
o`00000Nooooo`Co00001_ooool4o`0000?ooooo5?l000000ooooooo0000o`000002ooooo`;o0000
00Goooooo`000?l0003o0000ooooo`02o`00013ooooo2?l00002ooooo`;o00001Oooool4o`0000?o
oooo0_l00006ooooo`;o00003oooool2o`0000?ooooo0_l00002ooooo`;o00001oooool2o`0000[o
oooo0_l00006ooooo`;o00000_ooool5o`0000Gooooo0_l0000mooooo`007?ooool00ol0003ooooo
ooooo`0fooooo`;o00001oooool2o`00023ooooo0ol00008ooooo`Co00000_ooool3o`000003oooo
ool0003o000000Oo000000?oooooo`000?l000002?l00002ooooo`;o00000_ooool2o`0001?ooooo
2?l00002ooooo`;o00001Oooool4o`0000?ooooo0_l00009ooooo`;o00003?ooool2o`000003oooo
ool0003o000000;o00004Oooool2o`0000Cooooo0_l00006ooooo`;o00000_ooool4o`000003oooo
ool0003o000004;ooooo000Looooo`03o`000?oooooooooo03Kooooo0_l0000<ooooo`;o00005ooo
ool2o`0000;ooooo0ol00008ooooo`;o00000_ooool5o`000003ooooool0003o000001Co00006_oo
ool2o`0001?ooooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool6o`0000cooooo0_l0
000Cooooo`;o00001?ooool2o`0000kooooo0ol00004ooooo`;o0000??ooool001cooooo00?o0000
ooooooooool0=_ooool2o`0000cooooo0_l0000Gooooo`;o00000oooool2o`0000Gooooo0_l00000
0ooooooo0000o`000002oooooaco000000Coooooo`000?l0003o00005?ooool4o`000003ooooool0
003o0000013ooooo1Ol00002ooooo`;o00000oooool6o`0002[ooooo0_l0000;ooooo`;o00001Ooo
ool2o`0003cooooo000Looooo`03o`000?oooooooooo04Kooooo0_l0000Qooooo`;o00001Oooool:
o`000003ooooool0003o000000go00000oooool3o`0001Cooooo0_l00003ooooo`;o00003Oooool2
o`0000;ooooo0ol0000;ooooo`;o00003Oooool2o`0000cooooo0_l00009ooooo`;o00000_ooool4
o`0004oooooo000Looooo`03o`000?oooooooooo03gooooo0_l00003ooooo`;o00000_ooool2o`00
01_ooooo1_l00007ooooo`Wo000000?oooooo`000?l000003ol00002ooooo`Go00003Oooool2o`00
0003ooooool0003o000000Co00000_ooool2o`000003ooooool0003o000000Wooooo0_l00002oooo
o`?o00006_ooool2o`0000Wooooo0_l000000ooooooo0000o`000009ooooo`;o00000_ooool4o`00
013ooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00000oooool2o`0000Co
oooo0_l0000Iooooo`Ko00001OoooolMo`0000;ooooo0_l000000ooooooo0000o`00000=ooooo`;o
000000Coooooo`000?l0003ooooo2ol0000:ooooo`;o000000?oooooo`000?l000009Oooool2o`00
00oooooo1?l0000Aooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0?oooool2o`0000;o
oooo0_l00003ooooo`;o00006_ooool2o`000003ooooool0003o000000Gooooo0_l000000ooooooo
0000o`00000Io`0000;ooooo0_l00002ooooo`;o00003_ooool2o`0000Cooooo0_l000000ooooooo
0000o`000003o`0000Sooooo1?l0000dooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o
00002?ooool2o`0003oooooo000Looooo`03o`000?oooooooooo02Sooooo0_l0000Eooooo`;o0000
0_ooool2o`0001oooooo0_l0000;ooooo`;o000000?oooooo`000?l000005_l00002ooooo`;o0000
0_ooool2o`0000Gooooo0_l00003ooooo`Go000000?oooooo`000?l000000_ooool2o`000004oooo
ool0003o0000ooooo`;o00002?ooool2o`0002Cooooo0_l0000@ooooo`Go00001?ooool2o`000003
ooooool0003o000000?o00001oooool2o`0003oooooo000Looooo`;o0000:Oooool2o`0001Sooooo
0_l0000Kooooo`;o00003ooooolLo`0000;ooooo0_l00008ooooo`?o00000oooool5o`000003oooo
ool0003o000000;ooooo1Ol00005ooooo`;o00001_ooool2o`0002;ooooo0_l00009ooooo`;o0000
0_ooool8o`0000;ooooo0_l00003ooooo`Go0000B?ooool001cooooo00?o0000ooooooooool0@_oo
ool2o`0001?ooooo0_l00006ooooo`;o00003ooooolNo`0000[ooooo0_l0000=ooooo`Ko00001Ooo
ool2o`0000Kooooo0_l0000]ooooo`;o00000_ooool5o`0000Gooooo0_l00003ooooo`Co00001_oo
ool2o`00047ooooo000Looooo`03o`000?oooooooooo03_ooooo0_l00008ooooo`Co00003?ooool6
o`0001Kooooo7ol000000ooooooo0000o`000002o`0000cooooo0_l00004ooooo`Ko00000oooool4
o`0000Oooooo0_l0000^ooooo`Go00005_ooool2o`00047ooooo000Looooo`03o`000?oooooooooo
02Wooooo0_l0000@ooooo`;o00002?ooool4o`0000cooooo0_l00002ooooo`;o00002Oooool3o`00
00;ooooo0_l00008ooooo`ko000000?oooooo`000?l000004Ol0000<ooooo`;o00000_ooool2o`00
00Cooooo0_l00003ooooo`;o00002Oooool2o`0002_ooooo0_l000001?oooooo0000o`000?ooool2
o`0000[ooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`0Yooooo`;o00005oooool2o`00
00cooooo0_l0000;ooooo`;o00001Oooool3o`0000;ooooo0_l00009oooooaoo00004_ooool2o`00
00Kooooo0ol000000ooooooo0000o`00000eooooo`Co00002Oooool2o`0000?ooooo0_l0001=oooo
o`007?ooool00ol0003oooooooooo`12ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Go
oooo0_l0000;ooooo`;o00001Oooool4o`0000Sooooo0_l000000ooooooo0000o`00000:o`000003
ooooool0003o000000[o000000?oooooo`000?l000000ol0000Kooooo`Ko0000=_ooool3o`0000Go
oooo0_l00002ooooo`;o00001?ooool2o`0004cooooo000Looooo`03o`000?oooooooooo04Gooooo
0_l00002ooooo`;o00001?ooool2o`00017ooooo0_l00002ooooo`;o00001?ooool2o`0000;ooooo
6ol0000:ooooo`;o00001_ooool2o`0000;ooooo0_l0000<ooooo`Co0000<?ooool2o`0000Kooooo
0_l00004ooooo`;o00002?ooool2o`0004cooooo000Looooo`03o`000?oooooooooo04oooooo0_l0
000Aooooo`;o00002?ooool2o`0000;ooooo6?l00002ooooo`;o00002Oooool2o`0000Kooooo0_l0
0002ooooo`;o00000_ooool2o`0000Wooooo1?l00009ooooo`;o00009?ooool2o`0000Kooooo0_l0
001Looooo`007?ooool00ol0003oooooooooo`1Rooooo`;o00000oooool2o`0000Oooooo0_l00002
oooooaSo00004_ooool4o`0000?ooooo0_l00009ooooo`Go00002?ooool2o`0000?ooooo0_l0000X
ooooo`;o00001oooool3o`00057ooooo000Looooo`03o`000?oooooooooo04Cooooo0_l0000:oooo
o`;o00000_ooool2o`0000Kooooo0_l00004ooooo`;o00000oooool2o`000003ooooool0003o0000
00Gooooo5Ol000000ooooooo0000o`000004o`0000?ooooo1Ol00002ooooo`;o000000?oooooo`00
0?l000000_ooool4o`00017ooooo0_l0000=ooooo`Co00009_ooool2o`0000Cooooo0_l000001?oo
oooo0000o`000?l00005ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0A?ooool2o`00
0003ooooool0003o000000Gooooo1?l00002ooooo`;o00001_ooool2o`0000;ooooo0_l00008oooo
o`;o00001Oooool6o`000004ooooool0003o0000ooooo`oo000000?oooooo`000?l000000oooool5
o`000005ooooool0003o0000o`000?ooool01Ol0000Booooo`;o00004Oooool2o`0001Oooooo0_l0
000Cooooo`;o00002Oooool2o`0004[ooooo000Looooo`03o`000?oooooooooo04Oooooo0_l00005
ooooo`;o00002oooool2o`0000;ooooo1?l000000ooooooo0000o`000004ooooo`;o00002?ooool4
o`0000?ooooo2?l000000ooooooo0000o`000003o`0000Cooooo0_l00005ooooo`Go00000oooool3
o`0000;ooooo0_l00007ooooo`;o00001Oooool2o`0000Cooooo0_l0000Tooooo`;o00003Oooool2
o`0000Cooooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`17ooooo`;o00004_ooool2o`00
0003ooooool0003o000000?o000000?oooooo`000?l000003oooool3o`0000Cooooo2?l00002oooo
o`?o00001?ooool2o`000003ooooool0003o000000;ooooo1_l00003ooooo`;o00000_ooool2o`00
00Cooooo1Ol0000;ooooo`;o00002Oooool2o`0000Cooooo0_l0000Dooooo`;o00001oooool2o`00
00?ooooo1?l00002ooooo`;o0000EOooool001cooooo00?o0000ooooooooool0@oooool2o`0001Wo
oooo0ol00009ooooo`;o00002Oooool2o`000003ooooool0003o000000;ooooo2_l00002ooooo`;o
00000_ooool2o`0000;ooooo1?l00002ooooo`Co00003Oooool5o`0001Kooooo0_l00003ooooo`?o
00005?ooool2o`0000Oooooo0_l00005ooooo`;o000000?oooooo`000?l00000E_ooool001cooooo
00?o0000ooooooooool0@oooool2o`0000Cooooo0_l0000Gooooo`;o00001_ooool2o`0000Oooooo
0_l00003ooooo`?o00000_ooool5o`0000;ooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo
1?l00002ooooo`;o00002_ooool2o`0000Kooooo0_l0000Kooooo`?o00009?ooool2o`000003oooo
ool0003o000005Kooooo000Looooo`03o`000?oooooooooo04Wooooo0_l0000Gooooo`;o00001?oo
ool2o`0000Wooooo0_l00003ooooo`co00001?ooool2o`0000Cooooo1?l00009ooooo`;o00001Ooo
ool7o`0000kooooo0_l0000Wooooo`;o00004?ooool2o`0005Gooooo000Looooo`;o0000JOooool2
o`0000Wooooo0ol00002ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000002
o`0000[ooooo0_l0000;ooooo`;o00001oooool5o`0000kooooo0_l00009ooooo`?o00006oooool2
o`00013ooooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`0cooooo`;o0000<?ooool2o`00
00Cooooo0_l00007ooooo`?o00001?ooool2o`0000Gooooo0_l00005ooooo`;o00007?ooool2o`00
00;ooooo0_l00002ooooo`;o00004Oooool5o`0001cooooo0_l00004ooooo`;o00002?ooool2o`00
05Cooooo000Looooo`03o`000?oooooooooo03?ooooo0_l0000Kooooo`;o00001_ooool2o`0000So
oooo0_l000000ooooooo0000o`000003ooooo`?o00002?ooool2o`000004ooooool0003o0000oooo
o`?o00002oooool4o`0000Sooooo1_l00003ooooo`;o00002?ooool2o`000005ooooool0003o0000
o`000?ooool00_l0000Aooooo`Ko00006Oooool4o`0000Cooooo0_l00004ooooo`;o00000_ooool2
o`0005Cooooo000Looooo`03o`000?oooooooooo053ooooo0ol00005ooooo`;o00002?ooool3o`00
00Gooooo0_l00004ooooo`;o000000?oooooo`000?l000000oooool2o`0000;ooooo0_l00004oooo
o`;o00001Oooool4o`0000Sooooo1_l00003ooooo`;o00002?ooool2o`0000;ooooo0_l0000Hoooo
o`;o00006Oooool2o`0000Kooooo0_l00004ooooo`;o0000F?ooool001cooooo00?o0000oooooooo
ool0DOooool2o`00013ooooo0_l0000;ooooo`Go00000_ooool2o`0000Cooooo0_l00003ooooo`;o
00001Oooool4o`0000Sooooo0_l0000Mooooo`;o00001_ooool4o`0002?ooooo0_l00005ooooo`;o
00000oooool2o`0005Sooooo000Looooo`03o`000?oooooooooo05Cooooo0_l0000>ooooo`;o0000
3?ooool2o`0000?ooooo0_l00004ooooo`;o00002_ooool4o`0000;ooooo1?l000000ooooooo0000
o`000002o`00013ooooo0_l0000:ooooo`;o00001_ooool4o`0001Wooooo0_l00008ooooo`;o0000
1Oooool2o`0000Oooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o00003_oo
ool2o`0000gooooo0ol0000Cooooo`Co00000_ooool4o`000003ooooool0003o000000;o00003?oo
ool2o`0000;ooooo1_l0000<ooooo`Ko00001?ooool4o`0000;ooooo0_l00004ooooo`;o00001ooo
ool2o`0001Sooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`1Vooooo`;o000000?ooooo
o`000?l000000oooool2o`0000?ooooo1Ol0000Iooooo`;o000000?oooooo`000?l000001oooool2
o`0000Gooooo3?l0000:ooooo`Ko00001?ooool4o`0000;ooooo0_l00004ooooo`;o00007oooool2
o`0005Kooooo000Looooo`03o`000?oooooooooo05Sooooo0_l0000<ooooo`;o000000Coooooo`00
0?l0003ooooo1?l000000ooooooo0000o`000003ooooo`;o00005_ooool5o`0000;ooooo0_l00003
ooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`_o00007?ooool2o`0001Oooooo0_l0
0009ooooo`Co0000E?ooool001cooooo00?o0000ooooooooool0F?ooool4o`0000Cooooo0_l0000:
ooooo`;o00000oooool2o`0000?ooooo0_l0000@ooooo`;o00001?ooool4o`0000?ooooo0_l00003
ooooo`;o00001?ooool2o`0000;ooooo3_l000000ooooooo0000o`00000;ooooo`;o00002_ooool3
o`0001Oooooo0ol00004ooooo`;o00000_ooool4o`0005Cooooo000Looooo`03o`000?oooooooooo
05[ooooo0_l00004ooooo`;o00003oooool2o`0000Cooooo0_l00007ooooo`;o00001_ooool2o`00
01[ooooo3_l000000ooooooo0000o`00000;ooooo`;o00002_ooool2o`0000Cooooo0_l00008oooo
o`;o00001Oooool6o`0000?ooooo0ol000001?oooooo0000o`000?l0001Fooooo`007?ooool00ol0
003oooooooooo`0looooo`;o0000<oooool2o`0000;ooooo1Ol00006ooooo`;o00008_ooool>o`00
01cooooo0ol000001?oooooo0000o`000?l00002ooooo`;o00000oooool2o`0000Gooooo1Ol00004
ooooo`?o000000?oooooo`000?l00000Eoooool001cooooo00?o0000ooooooooool0??ooool2o`00
03Oooooo0_l000000ooooooo0000o`000003o`0000_ooooo0_l0000Jooooo`Go00000_ooool2o`00
0003ooooool0003o000000;o00002Oooool2o`0000[ooooo0_l00004ooooo`Co00000_ooool2o`00
00;ooooo0_l00009ooooo`;o00000_ooool2o`0000Gooooo0_l0001Jooooo`007?ooool00ol0003o
ooooooooo`1iooooo`Co00002oooool2o`0000gooooo0_l0000;ooooo`ko00002Oooool2o`0000[o
oooo0_l00004ooooo`;o000000?oooooo`000?l000000ol0000=ooooo`;o00002Oooool2o`0005[o
oooo000Looooo`03o`000?oooooooooo05kooooo0_l0000@ooooo`;o00003_ooool3o`0001?ooooo
0ol0000;ooooo`ko00002oooool2o`00017ooooo1Ol000000ooooooo0000o`00000;ooooo`;o0000
I?ooool001cooooo00?o0000ooooooooool0G_ooool2o`000003ooooool0003o000000gooooo0_l0
000>ooooo`?o00003_ooool3o`0000;ooooo0_l0000=ooooo`ko00002_ooool3o`0001Gooooo0ol0
000;ooooo`?o0000Hoooool001cooooo0_l0001Rooooo`Co00004?ooool2o`0000[ooooo0_l0000>
ooooo`?o00002Oooool2o`0000Cooooo0_l000000ooooooo0000o`00000;o`0000Wooooo1?l0000E
ooooo`;o00002Oooool2o`0000;ooooo0_l00003ooooo`;o0000G_ooool001cooooo00?o0000oooo
ooooool0Hoooool2o`0000?ooooo0_l00009ooooo`Co00008oooool2o`000004ooooool0003o0000
o`0000?ooooo0_l00002ooooo`oo00001_ooool4o`00023ooooo0_l00007ooooo`;o0000G_ooool0
01cooooo00?o0000ooooooooool0GOooool2o`0000Cooooo0_l00003ooooo`;o00000oooool2o`00
00Cooooo0_l0000Qooooo`;o00000_ooool2o`0000;ooooo0_l00005oooooa7o00001_ooool2o`00
01Sooooo0_l00003ooooo`;o00001oooool2o`0006?ooooo000Looooo`03o`000?oooooooooo04?o
oooo0_l0000Hooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00001?ooool2o`00
00kooooo0ol000001?oooooo0000o`000?ooool2o`00013ooooo0_l00002ooooo`;o00002Oooool<
o`0000_ooooo0_l0000Fooooo`Co00000oooool2o`0000Oooooo1?l0001Qooooo`007?ooool00ol0
003oooooooooo`13ooooo`;o00006oooool2o`0000Gooooo0_l0000=ooooo`;o00001Oooool9o`00
00;ooooo0_l00005ooooo`;o00000oooool2o`0000Cooooo1_l00002ooooo`;o00000oooool2o`00
00Gooooo0_l0000Tooooo`;o00004?ooool2o`00067ooooo000Looooo`03o`000?oooooooooo07Ko
oooo0_l00005ooooo`Co000000?oooooo`000?l000000_l00002ooooo`;o00001Oooool2o`000003
ooooool0003o000000;o000000?oooooo`000?l000000_ooool5o`0000;ooooo0_l0000Eooooo`;o
00006oooool2o`0000;ooooo0_l00008ooooo`;o0000Hoooool001cooooo00?o0000ooooooooool0
IOooool2o`0000oooooo0_l0000Hooooo`Go00000_ooool2o`0000;ooooo1?l00003ooooo`;o0000
1_ooool2o`0000;ooooo0_l00009ooooo`?o00005?ooool2o`0000Cooooo0_l00002ooooo`;o0000
2?ooool2o`0006?ooooo000Looooo`03o`000?oooooooooo06Gooooo0_l0000;ooooo`;o00002?oo
ool3o`00017ooooo0_l00005ooooo`;o00000_ooool9o`0000Kooooo0_l00002ooooo`;o00000ooo
ool2o`0000Gooooo0ol0000Cooooo`;o00001?ooool3o`000003ooooool0003o000006gooooo000L
ooooo`03o`000?oooooooooo07;ooooo0_l00003ooooo`;o00000oooool3o`0001Oooooo0_l00005
ooooo`Go00001Oooool2o`0000?ooooo0_l00005ooooo`;o00001_ooool2o`0001Sooooo1?l00000
0ooooooo0000o`00001]ooooo`007?ooool00ol0003oooooooooo`1dooooo`;o000000Coooooo`00
0?l0003ooooo0_l00008ooooo`;o00004?ooool2o`0000Kooooo0_l00006ooooo`?o00000oooool2
o`0000Wooooo0ol0000?ooooo`;o00002_ooool2o`0000Kooooo0_l0001Zooooo`007?ooool00ol0
003oooooooooo`1Zooooo`;o00002?ooool2o`0000Cooooo0_l00008ooooo`;o00003oooool3o`00
00cooooo1ol0000;ooooo`Co00002?ooool3o`0000Cooooo1?l0000@ooooo`;o0000J_ooool001co
oooo00?o0000ooooooooool0Boooool2o`0001gooooo0_l0000<ooooo`Ko00000_ooool2o`0000;o
oooo0_l00005ooooo`;o00002?ooool3o`0000cooooo0_l000000ooooooo0000o`000002o`0000_o
oooo0_l0000:ooooo`?o00001_ooool2o`0000Oooooo0_l00002ooooo`Co0000KOooool001cooooo
00?o0000ooooooooool0Boooool2o`0002[ooooo1ol00002ooooo`;o00000_ooool2o`0000Gooooo
0ol0000Kooooo`;o00000_ooool2o`0001Oooooo0_l00008ooooo`;o00000_ooool2o`0000;ooooo
1?l0001]ooooo`007?ooool00ol0003oooooooooo`1]ooooo`?o00001oooool2o`0001?ooooo0_l0
0002ooooo`;o00003_ooool2o`0000Oooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo0_l0
000?ooooo`Co00001Oooool3o`0000Oooooo0_l0001^ooooo`0000Koooooonk^k_lb<S;o0000oc8b
<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000oooooooo
ool0Ioooool2o`0000Cooooo0ol0000Gooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o
00001_ooool2o`0000;ooooo0_l0000=ooooo`Wo000000?oooooo`000?l000001Oooool2o`000004
ooooool0003o0000ooooo`Co00001Oooool2o`0000[ooooo0_l0001/ooooo`0000KoooooogMgMonH
V9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o
0000ooooooooool0D?ooool2o`0001Gooooo1?l0000Eooooo`?o00001?ooool2o`0000;ooooo0_l0
0003ooooo`So00001?ooool2o`00017ooooo2Ol000001?oooooo0000o`000?ooool6o`000003oooo
ool0003o000000;ooooo0_l00003ooooo`Go00002_ooool2o`0006cooooo00000ooooooo410@oooo
o`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo053ooooo0_l0000Gooooo`;o00001_ooool2o`0000gooooo0ol0000?ooooo`;o0000
0_ooool3o`000003ooooool0003o000000Cooooo0_l00003ooooo`;o000000?oooooo`000?l00000
3oooool2o`000003ooooool0003o000000?o00002oooool5o`0007Sooooo00000ooooooo0000oooo
o`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000
D_ooool2o`0001gooooo0_l00002ooooo`;o00003?ooool3o`0000Cooooo0_l000000ooooooo0000
o`000006ooooo`Co000000?oooooo`000?l000000oooool3o`0000?ooooo0_l000000ooooooo0000
o`000002ooooo`;o00002oooool2o`000003ooooool0003o000000Sooooo0_l00021ooooo`0000?o
ooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<c<`0
1_ooool00ol0003oooooooooo`1Booooo`;o00008Oooool2o`0000cooooo0ol00004ooooo`;o0000
00?oooooo`000?l000001_ooool5o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o0000
1oooool2o`0000Sooooo0_l00004ooooo`;o00002?ooool2o`00087ooooo00000ooooooo410@oooo
o`02ooooo`03oa0@4?oooooooooo00Wooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`00
0?oooooooooo05Kooooo0_l0000Cooooo`;o00006oooool2o`0000?ooooo0_l00008ooooo`?o0000
0_ooool2o`0000Gooooo0_l0000Aooooo`;o000000?oooooo`000?l00000S_ooool00006oooooomg
MgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000oooo
ooooool0E_ooool2o`0001?ooooo0_l0000=ooooo`;o00003?ooool2o`0001;ooooo0_l00009oooo
o`;o00002?ooool2o`0000Gooooo1_l00002ooooo`;o0000Qoooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0N_oo
ool2o`0001Kooooo0_l00002ooooo`?o00000oooool2o`0000Kooooo0_l000000ooooooo0000o`00
0006ooooo`Ko00000oooool;o`0000Wooooo0_l00005ooooo`;o0000M?ooool001cooooo00?o0000
ooooooooool0T_ooool2o`0000;ooooo0ol0000;ooooo`Co00001oooool2o`000004ooooool0003o
0000o`0000Cooooo1?l000000ooooooo0000o`000003o`0000Oooooo1Ol000001?oooooo0000o`00
0?ooool2o`0007Cooooo000Looooo`03o`000?oooooooooo08oooooo0_l0000@ooooo`;o00000ooo
ool2o`00017ooooo1?l000000ooooooo0000o`000003o`0000Oooooo0_l000001?oooooo0000o`00
0?ooool2o`0007Oooooo000Looooo`03o`000?oooooooooo08oooooo0_l0000@ooooo`;o00006?oo
ool2o`000003ooooool0003o000000;o0000Qoooool001cooooo00?o0000ooooooooool0Y_ooool2
o`0000cooooo0_l0002Cooooo`007?ooool00ol0003oooooooooo`1fooooo`;o00006_ooool2o`00
017ooooo0ol00007ooooo`;o00000oooool2o`0000Wooooo0_l00028ooooo`007?ooool00ol0003o
ooooooooo`1Oooooo`;o00005Oooool2o`0001[ooooo1?l00004ooooo`;o00001Oooool3o`000003
ooooool0003o000000Sooooo0_l00005ooooo`;o00001oooool2o`0008Sooooo000Looooo`03o`00
0?oooooooooo05oooooo0_l0000Zooooo`;o00001oooool2o`0000Cooooo0_l00005ooooo`?o0000
1Oooool2o`0000_ooooo0_l0002Aooooo`007?ooool00ol0003oooooooooo`2;ooooo`;o00006ooo
ool3o`0009kooooo000Looooo`03o`000?oooooooooo0:Sooooo0_l0002Oooooo`007?ooool00ol0
003oooooooooo`2Vooooo`;o0000XOooool001cooooo00?o0000ooooooooool0Y_ooool2o`000:7o
oooo000Looooo`;o0000/oooool3o`0009Cooooo000Looooo`03o`000?oooooooooo0;;ooooo1Ol0
002Booooo`007?ooool00ol0003oooooooooo`2eooooo`;o0000T_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Xooooo`;o0000Woooool001cooooo
00?o0000ooooooooool0Z?ooool2o`0009oooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0
003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Booooo`Co000000?o410@ooooooooool00ooo
ool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`?o0000oooooom:oooo
o`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?oooooo
D_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3o
oooooe;ooooo000Booooo`03oeEEEOmVIVKo00000?ooooooE?ooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00:Gooooo00Co410@o`000?l0003ooooo0_l000000ol@413ooooooooo
o`0Eooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01?ooool4o`000003oa0@4?oooooooooo00Go0000
T?ooool00:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00002Oooool01OmEEEGoMgMg
oooooonHV9So8B4Q00Kooooo00?o0000ooooooooool00_ooool01OnHV9So8B4Qonk^k_ooooooA4A4
093ooooo002Vooooo`05o`000?ooooooooooooooool000006?ooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool00oooool00onHV9So8B4Qonk^kP2Aooooo`00Y_ooool01Ol0
003ooooooooooooooooo000000Wooooo1_l00009ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_oo
ool00ol0003oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^093ooooo002Vooooo`05o`000?n7QhOo
ooooojVYZOl000006?ooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0
1Oooool00omgMgOoIVIVooooo`2?ooooo`00YOooool00ol@413o0000ogMgM`02o`000003oiRHV?oo
oooooooo01Kooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo08kooooo0033ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool00_ooool0
1Ol0003o^[ZjoooooonHV9So410@093ooooo0034ooooo`04olc<c?m4A4Co0000oa0@40Cooooo00?o
EEEEofIVI_l000001?ooool01OnHV9So410@o`000?lQ8B7oc<c<093ooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(618) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.37099 .66461 Mdot
.3888 .60257 Mdot
.6359 .4928 Mdot
.41594 .44454 Mdot
.62105 .36287 Mdot
.6512 .45656 Mdot
.62973 .58251 Mdot
.65036 .62788 Mdot
.65609 .44747 Mdot
.19857 .52768 Mdot
.63825 .62267 Mdot
.3555 .49018 Mdot
.62368 .59782 Mdot
.38552 .42188 Mdot
.53191 .69621 Mdot
.33794 .38776 Mdot
.40448 .60305 Mdot
.57779 .28581 Mdot
.33459 .39222 Mdot
.62541 .48098 Mdot
.47263 .50276 Mdot
.39368 .41783 Mdot
.40248 .60605 Mdot
.3883 .42007 Mdot
.44321 .42432 Mdot
.39118 .61977 Mdot
.3579 .65874 Mdot
.43007 .40629 Mdot
.41457 .38715 Mdot
.62615 .62166 Mdot
.67445 .29268 Mdot
.49282 .84705 Mdot
.33848 .41811 Mdot
.32689 .52264 Mdot
.65843 .61847 Mdot
.81032 .50662 Mdot
.65599 .43018 Mdot
.63409 .63153 Mdot
.65503 .58676 Mdot
.65262 .57343 Mdot
.61714 .57811 Mdot
.38506 .61481 Mdot
.61759 .56429 Mdot
.65835 .3946 Mdot
.39082 .46337 Mdot
.43282 .78536 Mdot
.67905 .25933 Mdot
.42726 .40548 Mdot
.38731 .66039 Mdot
.62693 .47405 Mdot
.32928 .27726 Mdot
.62104 .63246 Mdot
.52047 .76517 Mdot
.11063 .59585 Mdot
.62537 .61563 Mdot
.42002 .43037 Mdot
.62961 .44945 Mdot
.40057 .44314 Mdot
.41412 .4076 Mdot
.30354 .47452 Mdot
.40083 .39345 Mdot
.58649 .3147 Mdot
.35182 .65986 Mdot
.61126 .45889 Mdot
.65164 .44817 Mdot
.60822 .6042 Mdot
.36128 .60258 Mdot
.61732 .59084 Mdot
.39538 .49233 Mdot
.63596 .4866 Mdot
.42497 .41104 Mdot
.63651 .62516 Mdot
.38204 .59316 Mdot
.43981 .45125 Mdot
.45775 .75393 Mdot
.68704 .61715 Mdot
.55989 .32718 Mdot
.28709 .60955 Mdot
.20605 .37645 Mdot
.70613 .50849 Mdot
.37791 .41454 Mdot
.19291 .35807 Mdot
.53529 .68699 Mdot
.37597 .60136 Mdot
.36699 .53408 Mdot
.72173 .68509 Mdot
.41525 .38415 Mdot
.53447 .3975 Mdot
.39326 .37058 Mdot
.48588 .59468 Mdot
.6532 .44073 Mdot
.39875 .62196 Mdot
.39233 .46432 Mdot
.43766 .38882 Mdot
.25472 .40534 Mdot
.35078 .44478 Mdot
.39767 .45836 Mdot
.41011 .57522 Mdot
.64344 .60982 Mdot
.44063 .48904 Mdot
.68479 .40176 Mdot
.49649 .74076 Mdot
.42177 .45056 Mdot
.66005 .4748 Mdot
.39016 .66866 Mdot
.40324 .46335 Mdot
.61295 .60942 Mdot
.38987 .40545 Mdot
.67176 .61392 Mdot
.40509 .63263 Mdot
.43198 .38606 Mdot
.575 .32842 Mdot
.48246 .67359 Mdot
.37078 .65298 Mdot
.21456 .62861 Mdot
.40204 .39662 Mdot
.40426 .41246 Mdot
.38026 .60264 Mdot
.62366 .44078 Mdot
.53918 .44117 Mdot
.39584 .59652 Mdot
.65352 .57993 Mdot
.40603 .64164 Mdot
.42819 .37439 Mdot
.62063 .44686 Mdot
.50079 .73313 Mdot
.49254 .74886 Mdot
.58967 .2287 Mdot
.44813 .43922 Mdot
.50849 .70614 Mdot
.64664 .46885 Mdot
.38589 .60923 Mdot
.61673 .59757 Mdot
.37425 .38779 Mdot
.35752 .63207 Mdot
.65327 .59349 Mdot
.60446 .33234 Mdot
.62881 .35921 Mdot
.35356 .64479 Mdot
.44865 .32915 Mdot
.64723 .63801 Mdot
.64925 .56918 Mdot
.34809 .27254 Mdot
.37091 .60532 Mdot
.60965 .30839 Mdot
.64557 .58062 Mdot
.48351 .25572 Mdot
.36624 .39911 Mdot
.436 .22039 Mdot
.23251 .29758 Mdot
.33753 .27478 Mdot
.34012 .74211 Mdot
.58169 .29858 Mdot
.64358 .5772 Mdot
.42943 .42973 Mdot
.3681 .62653 Mdot
.36956 .61943 Mdot
.44566 .39231 Mdot
.44544 .4089 Mdot
.37363 .43872 Mdot
.38237 .38626 Mdot
.79122 .38977 Mdot
.37031 .43205 Mdot
.54778 .61063 Mdot
.35923 .64028 Mdot
.44798 .42545 Mdot
.67458 .46408 Mdot
.44719 .45149 Mdot
.63471 .63116 Mdot
.41293 .41698 Mdot
.44331 .41328 Mdot
.37537 .47086 Mdot
.63141 .56604 Mdot
.5958 .80684 Mdot
.1769 .44601 Mdot
.77544 .59665 Mdot
.39001 .72552 Mdot
.6373 .46267 Mdot
.37176 .40943 Mdot
.59821 .29335 Mdot
.42033 .51577 Mdot
.41096 .40403 Mdot
.30808 .28672 Mdot
.43617 .40172 Mdot
.29436 .66745 Mdot
.48033 .42628 Mdot
.75742 .66516 Mdot
.55764 .65338 Mdot
.40189 .38945 Mdot
.21443 .44216 Mdot
.46332 .20295 Mdot
.64183 .25093 Mdot
.61818 .61003 Mdot
.67843 .4505 Mdot
.63814 .43119 Mdot
.64503 .5603 Mdot
.46656 .44844 Mdot
.20393 .5479 Mdot
.41201 .49183 Mdot
.50452 .73462 Mdot
.33855 .66119 Mdot
.58106 .2933 Mdot
.35454 .64778 Mdot
.15989 .40437 Mdot
.51669 .45913 Mdot
.6714 .56526 Mdot
.57129 .29454 Mdot
.65949 .48863 Mdot
.51636 .74054 Mdot
.60628 .29627 Mdot
.40261 .45293 Mdot
.39883 .64814 Mdot
.45902 .20306 Mdot
.3898 .35608 Mdot
.84796 .40387 Mdot
.36306 .60587 Mdot
.52293 .55732 Mdot
.62058 .60834 Mdot
.61717 .43734 Mdot
.41705 .38539 Mdot
.38537 .44063 Mdot
.35543 .66144 Mdot
.42499 .40015 Mdot
.4721 .53382 Mdot
.44017 .41122 Mdot
.61662 .42399 Mdot
.58037 .26422 Mdot
.65615 .56414 Mdot
.57883 .22591 Mdot
.38593 .59133 Mdot
.56358 .536 Mdot
.66664 .47209 Mdot
.42988 .6534 Mdot
.62845 .62574 Mdot
.59675 .3359 Mdot
.66759 .44056 Mdot
.5993 .34473 Mdot
.40717 .46868 Mdot
.65523 .43307 Mdot
.59276 .32716 Mdot
.61515 .50894 Mdot
.39982 .4591 Mdot
.441 .24502 Mdot
.6398 .58019 Mdot
.35772 .65701 Mdot
.4029 .39221 Mdot
.49168 .73283 Mdot
.45542 .39851 Mdot
.51648 .70256 Mdot
.50463 .72787 Mdot
.52402 .75319 Mdot
.68293 .56857 Mdot
.60979 .29218 Mdot
.41666 .7506 Mdot
.53256 .46491 Mdot
.40362 .60105 Mdot
.37685 .46165 Mdot
.65825 .78569 Mdot
.6367 .5761 Mdot
.40446 .45079 Mdot
.73045 .67265 Mdot
.64466 .58007 Mdot
.40163 .4343 Mdot
.61743 .57585 Mdot
.36679 .62312 Mdot
.56198 .49084 Mdot
.41346 .62954 Mdot
.41405 .44224 Mdot
.63847 .59708 Mdot
.67442 .4437 Mdot
.39045 .6207 Mdot
.39454 .40467 Mdot
.37368 .41806 Mdot
.51072 .73947 Mdot
.45073 .42091 Mdot
.69507 .75348 Mdot
.42787 .40821 Mdot
.66014 .48936 Mdot
.3487 .43885 Mdot
.43725 .20495 Mdot
.63255 .3514 Mdot
.35139 .6094 Mdot
.51243 .7312 Mdot
.64587 .43768 Mdot
.57861 .46372 Mdot
.63645 .28894 Mdot
.38369 .41223 Mdot
.50134 .75035 Mdot
.52801 .55578 Mdot
.61026 .61097 Mdot
.36704 .38428 Mdot
.49772 .50039 Mdot
.66367 .44666 Mdot
.51155 .73736 Mdot
.46985 .39631 Mdot
.3998 .65983 Mdot
.42219 .4302 Mdot
.66186 .4326 Mdot
.39574 .65972 Mdot
.37439 .38646 Mdot
.75437 .33603 Mdot
.49247 .73578 Mdot
.63565 .57933 Mdot
.32447 .36199 Mdot
.36733 .43589 Mdot
.63732 .42933 Mdot
.35914 .62605 Mdot
.63387 .61385 Mdot
.39334 .64715 Mdot
.4972 .19483 Mdot
.41985 .71085 Mdot
.77365 .44595 Mdot
.59063 .27574 Mdot
.34187 .78582 Mdot
.78906 .5696 Mdot
.43824 .70422 Mdot
.55205 .26739 Mdot
.81858 .58202 Mdot
.67386 .4559 Mdot
.31778 .33129 Mdot
.63645 .44067 Mdot
.42689 .44057 Mdot
.65267 .45427 Mdot
.72481 .73433 Mdot
.43374 .40602 Mdot
.63277 .45955 Mdot
.77834 .39403 Mdot
.4327 .39471 Mdot
.35925 .64484 Mdot
.4856 .8285 Mdot
.23892 .6484 Mdot
.4977 .38314 Mdot
.62957 .45976 Mdot
.27339 .35673 Mdot
.42628 .39543 Mdot
.35515 .36963 Mdot
.37426 .6267 Mdot
.40404 .36881 Mdot
.57296 .30784 Mdot
.58785 .34335 Mdot
.34885 .28257 Mdot
.25921 .67621 Mdot
.35514 .35572 Mdot
.38467 .6193 Mdot
.21169 .36502 Mdot
.45926 .75893 Mdot
.4902 .74937 Mdot
.65785 .60197 Mdot
.59389 .80532 Mdot
.45539 .36717 Mdot
.40502 .32323 Mdot
.48279 .54494 Mdot
.39982 .61693 Mdot
.77999 .52063 Mdot
.6339 .60801 Mdot
.20201 .44218 Mdot
.23102 .55371 Mdot
.37551 .44522 Mdot
.60224 .59827 Mdot
.39147 .50152 Mdot
.4761 .54287 Mdot
.43497 .23586 Mdot
.74185 .44832 Mdot
.40882 .45284 Mdot
.42631 .75387 Mdot
.40968 .41015 Mdot
.46066 .20888 Mdot
.41008 .44554 Mdot
.38747 .64999 Mdot
.41623 .33906 Mdot
.57115 .40775 Mdot
.17114 .51861 Mdot
.5103 .46995 Mdot
.60189 .28678 Mdot
.38469 .42594 Mdot
.38081 .44554 Mdot
.58465 .32147 Mdot
.39246 .63387 Mdot
.3664 .45035 Mdot
.68248 .25755 Mdot
.37027 .43995 Mdot
.61933 .6302 Mdot
.56405 .46304 Mdot
.29549 .69069 Mdot
.42368 .38449 Mdot
.39337 .66371 Mdot
.61026 .59863 Mdot
.65591 .61299 Mdot
.38648 .34549 Mdot
.63233 .57317 Mdot
.42697 .4235 Mdot
.56227 .46912 Mdot
.40446 .6116 Mdot
.40471 .51266 Mdot
.38854 .63861 Mdot
.2572 .31181 Mdot
.62681 .56584 Mdot
.50674 .75954 Mdot
.33373 .32266 Mdot
.63179 .59279 Mdot
.43045 .5834 Mdot
.46563 .37115 Mdot
.44016 .4631 Mdot
.39219 .70641 Mdot
.65852 .42336 Mdot
.51768 .7563 Mdot
.62904 .61693 Mdot
.37051 .43693 Mdot
.41161 .46171 Mdot
.60526 .61648 Mdot
.27376 .44033 Mdot
.67804 .29865 Mdot
.41345 .43791 Mdot
.39024 .64616 Mdot
.3863 .61086 Mdot
.35962 .41574 Mdot
.40917 .40132 Mdot
.66947 .48097 Mdot
.50138 .75216 Mdot
.5218 .74543 Mdot
.49539 .75281 Mdot
.65116 .41462 Mdot
.31864 .76928 Mdot
.64915 .56934 Mdot
.382 .78963 Mdot
.67457 .71945 Mdot
.37348 .35152 Mdot
.64648 .42501 Mdot
.39387 .43654 Mdot
.42431 .45273 Mdot
.63977 .60199 Mdot
.24691 .68611 Mdot
.34386 .46266 Mdot
.34876 .64347 Mdot
.61155 .62432 Mdot
.39409 .51944 Mdot
.68114 .6345 Mdot
.57697 .32454 Mdot
.51075 .45225 Mdot
.60169 .60264 Mdot
.39934 .64307 Mdot
.60254 .61156 Mdot
.37805 .44372 Mdot
.46036 .44339 Mdot
.39897 .60977 Mdot
.61524 .29737 Mdot
.39679 .46708 Mdot
.40261 .43198 Mdot
.48224 .16919 Mdot
.45475 .7535 Mdot
.6523 .5281 Mdot
.43683 .4378 Mdot
.39954 .48195 Mdot
.61769 .29836 Mdot
.36627 .44099 Mdot
.40992 .38494 Mdot
.48374 .66346 Mdot
.65982 .57606 Mdot
.57105 .33983 Mdot
.19131 .45826 Mdot
.35704 .61237 Mdot
.70762 .7348 Mdot
.49632 .73773 Mdot
.6645 .58381 Mdot
.56079 .49783 Mdot
.51553 .75349 Mdot
.70459 .67762 Mdot
.75529 .62126 Mdot
.50739 .75755 Mdot
.63552 .50167 Mdot
.47023 .48355 Mdot
.38913 .381 Mdot
.40991 .42315 Mdot
.61223 .29926 Mdot
.36255 .61427 Mdot
.54792 .63 Mdot
.6253 .53594 Mdot
.39782 .41524 Mdot
.40216 .58509 Mdot
.73921 .67517 Mdot
.51549 .7426 Mdot
.58985 .29408 Mdot
.60109 .28123 Mdot
.40779 .41226 Mdot
.46111 .65436 Mdot
.38751 .61815 Mdot
.39455 .40484 Mdot
.37455 .39482 Mdot
.62471 .44756 Mdot
.39277 .65363 Mdot
.66564 .47545 Mdot
.50247 .72639 Mdot
.84426 .50799 Mdot
.50472 .16383 Mdot
.64542 .5917 Mdot
.78564 .55573 Mdot
.59868 .62017 Mdot
.73599 .47711 Mdot
.50265 .75512 Mdot
.39495 .40987 Mdot
.37722 .58946 Mdot
.39163 .40415 Mdot
.37415 .45166 Mdot
.38743 .45915 Mdot
.34826 .36017 Mdot
.31578 .27982 Mdot
.59536 .29989 Mdot
.36898 .47907 Mdot
.68017 .47269 Mdot
.75148 .66616 Mdot
.51463 .81972 Mdot
.38147 .43225 Mdot
.40318 .41574 Mdot
.35182 .61437 Mdot
.42067 .46571 Mdot
.61597 .61755 Mdot
.36746 .60485 Mdot
.41529 .45601 Mdot
.64481 .36455 Mdot
.36257 .43376 Mdot
.79282 .5449 Mdot
.6022 .61148 Mdot
.50708 .45226 Mdot
.41828 .48031 Mdot
.50495 .75781 Mdot
.51675 .75671 Mdot
.48894 .73398 Mdot
.60528 .60513 Mdot
.62644 .44407 Mdot
.68816 .47585 Mdot
.47216 .40898 Mdot
.43029 .42681 Mdot
.43701 .4669 Mdot
.65562 .41299 Mdot
.55028 .43571 Mdot
.36275 .74259 Mdot
.48176 .41512 Mdot
.67786 .43787 Mdot
.39989 .57148 Mdot
.17621 .57792 Mdot
.35901 .61378 Mdot
.56175 .28625 Mdot
.63584 .62901 Mdot
.57236 .31416 Mdot
.28468 .31419 Mdot
.40342 .61375 Mdot
.35191 .65673 Mdot
.63488 .46189 Mdot
.52193 .6088 Mdot
.18004 .71557 Mdot
.65493 .47382 Mdot
.56921 .26023 Mdot
.379 .62492 Mdot
.3381 .44186 Mdot
.52968 .55773 Mdot
.5153 .59929 Mdot
.63702 .45099 Mdot
.37595 .41459 Mdot
.43882 .59777 Mdot
.66798 .48189 Mdot
.35416 .39472 Mdot
.62968 .46359 Mdot
.62481 .5706 Mdot
.64373 .47042 Mdot
.37118 .58135 Mdot
.41137 .46675 Mdot
.12294 .62864 Mdot
.53294 .67575 Mdot
.39553 .39614 Mdot
.61233 .62621 Mdot
.77293 .34417 Mdot
.38464 .45233 Mdot
.57274 .30323 Mdot
.67642 .43274 Mdot
.74778 .3776 Mdot
.41805 .39255 Mdot
.64512 .45209 Mdot
.34707 .60055 Mdot
.69533 .42452 Mdot
.68671 .51285 Mdot
.52135 .75043 Mdot
.36395 .62636 Mdot
.51084 .71398 Mdot
.65998 .61371 Mdot
.38437 .46975 Mdot
.36834 .40735 Mdot
.3688 .64806 Mdot
.69297 .63248 Mdot
.34592 .44879 Mdot
.37801 .41481 Mdot
.6638 .48275 Mdot
.68621 .44263 Mdot
.55799 .74021 Mdot
.67508 .45814 Mdot
.39623 .48245 Mdot
.37227 .64978 Mdot
.42316 .43919 Mdot
.35514 .63935 Mdot
.37995 .46285 Mdot
.33931 .7055 Mdot
.3596 .61452 Mdot
.41933 .69438 Mdot
.45159 .40989 Mdot
.30933 .40606 Mdot
.37128 .45055 Mdot
.40002 .45588 Mdot
.67117 .42554 Mdot
.59998 .31263 Mdot
.35939 .38493 Mdot
.56937 .51621 Mdot
.61668 .32183 Mdot
.32875 .57447 Mdot
.62455 .44048 Mdot
.6146 .3165 Mdot
.44544 .27872 Mdot
.51274 .73151 Mdot
.58921 .30806 Mdot
.55221 .78552 Mdot
.64425 .59266 Mdot
.40905 .6152 Mdot
.43693 .39735 Mdot
.83086 .56508 Mdot
.67456 .29362 Mdot
.51115 .74399 Mdot
.40461 .39456 Mdot
.39352 .44139 Mdot
.40513 .65395 Mdot
.17663 .38106 Mdot
.61484 .43202 Mdot
.41153 .45395 Mdot
.39763 .59964 Mdot
.22033 .32131 Mdot
.63291 .47023 Mdot
.58724 .30314 Mdot
.599 .59664 Mdot
.3439 .67722 Mdot
.52048 .75527 Mdot
.62521 .56544 Mdot
.60023 .47011 Mdot
.2837 .30074 Mdot
.41908 .39489 Mdot
.66078 .42683 Mdot
.33553 .27525 Mdot
.46739 .45549 Mdot
.59381 .61803 Mdot
.32608 .68083 Mdot
.39903 .61743 Mdot
.60648 .6182 Mdot
.60048 .28515 Mdot
.40649 .61354 Mdot
.39349 .63392 Mdot
.65057 .62721 Mdot
.56759 .63552 Mdot
.52283 .56154 Mdot
.62301 .62858 Mdot
.49695 .62373 Mdot
.35827 .27031 Mdot
.49854 .75032 Mdot
.5894 .29368 Mdot
.50247 .18966 Mdot
.38768 .61566 Mdot
.59498 .8053 Mdot
.31564 .28294 Mdot
.39802 .45817 Mdot
.60381 .32407 Mdot
.70504 .68992 Mdot
.61818 .52969 Mdot
.65224 .59218 Mdot
.54622 .40677 Mdot
.5821 .28947 Mdot
.36422 .4084 Mdot
.29 .6833 Mdot
.43812 .39392 Mdot
.64119 .57684 Mdot
.46811 .55244 Mdot
.38865 .65506 Mdot
.66071 .60921 Mdot
.47572 .52533 Mdot
.42702 .45013 Mdot
.39062 .39131 Mdot
.51927 .21414 Mdot
.39531 .65339 Mdot
.52078 .75653 Mdot
.38439 .40605 Mdot
.40263 .44129 Mdot
.37396 .46687 Mdot
.35001 .31527 Mdot
.46004 .68403 Mdot
.40946 .45673 Mdot
.62843 .42289 Mdot
.44875 .45385 Mdot
.40063 .38729 Mdot
.41429 .63638 Mdot
.41151 .2105 Mdot
.49882 .72615 Mdot
.40929 .42754 Mdot
.41305 .43727 Mdot
.65583 .58576 Mdot
.52544 .55913 Mdot
.51331 .60285 Mdot
.64537 .4882 Mdot
.53658 .27872 Mdot
.42253 .48653 Mdot
.36106 .63451 Mdot
.57096 .31897 Mdot
.38804 .47747 Mdot
.35276 .6202 Mdot
.45709 .45689 Mdot
.67074 .48206 Mdot
.50336 .75143 Mdot
.40817 .32841 Mdot
.59007 .31328 Mdot
.66626 .62753 Mdot
.41932 .81026 Mdot
.67592 .46536 Mdot
.43703 .42472 Mdot
.68296 .4188 Mdot
.66511 .46337 Mdot
.50885 .73951 Mdot
.44862 .37518 Mdot
.37269 .61974 Mdot
.39155 .65205 Mdot
.39591 .25041 Mdot
.63247 .41404 Mdot
.35041 .20554 Mdot
.6259 .57051 Mdot
.37903 .37969 Mdot
.50504 .80678 Mdot
.38315 .65522 Mdot
.50895 .20176 Mdot
.61552 .31367 Mdot
.65215 .59272 Mdot
.51871 .73107 Mdot
.35239 .62337 Mdot
.37458 .65786 Mdot
.38785 .46256 Mdot
.38836 .42962 Mdot
.562 .25813 Mdot
.44911 .21257 Mdot
.61835 .57554 Mdot
.58223 .30515 Mdot
.63693 .48371 Mdot
.43109 .44318 Mdot
.38868 .60045 Mdot
.28883 .65813 Mdot
.36733 .43011 Mdot
.66571 .48445 Mdot
.39624 .61177 Mdot
.58031 .31585 Mdot
.60151 .33112 Mdot
.39763 .45726 Mdot
.3099 .57666 Mdot
.63035 .58859 Mdot
.36585 .65031 Mdot
.39379 .55352 Mdot
.34965 .44656 Mdot
.38427 .42982 Mdot
.37212 .50282 Mdot
.62989 .56276 Mdot
.41724 .32979 Mdot
.61107 .2815 Mdot
.36925 .61439 Mdot
.39183 .39933 Mdot
.58639 .31428 Mdot
.35809 .32587 Mdot
.51057 .75402 Mdot
.63228 .46693 Mdot
.57401 .30295 Mdot
.5984 .32191 Mdot
.61076 .33208 Mdot
.58292 .8078 Mdot
.3969 .66667 Mdot
.18598 .45581 Mdot
.38035 .45923 Mdot
.36622 .26865 Mdot
.45245 .43573 Mdot
.61266 .57665 Mdot
.6766 .44381 Mdot
.37395 .44868 Mdot
.38629 .46259 Mdot
.30293 .68977 Mdot
.37093 .51539 Mdot
.46708 .50436 Mdot
.40355 .63935 Mdot
.312 .3695 Mdot
.63871 .42632 Mdot
.22507 .29359 Mdot
.57113 .83992 Mdot
.40365 .49192 Mdot
.52615 .59972 Mdot
.37013 .60354 Mdot
.64977 .58157 Mdot
.51015 .58833 Mdot
.65121 .55105 Mdot
.37342 .60958 Mdot
.42764 .4435 Mdot
.38593 .78807 Mdot
.60203 .34193 Mdot
.37434 .4372 Mdot
.6148 .60081 Mdot
.37398 .43791 Mdot
.60596 .5944 Mdot
.36225 .68367 Mdot
.51141 .63172 Mdot
.43542 .40215 Mdot
.3564 .45973 Mdot
.46016 .35205 Mdot
.3837 .43226 Mdot
.71878 .57155 Mdot
.385 .63281 Mdot
.41847 .68826 Mdot
.35774 .42278 Mdot
.29983 .55952 Mdot
.36493 .41774 Mdot
.69381 .63871 Mdot
.37256 .40145 Mdot
.49344 .34742 Mdot
.3648 .40421 Mdot
.37233 .40752 Mdot
.63623 .60669 Mdot
.65387 .58359 Mdot
.34488 .60561 Mdot
.51491 .7615 Mdot
.75654 .66508 Mdot
.40194 .42472 Mdot
.67075 .42277 Mdot
.52592 .78444 Mdot
.60038 .31772 Mdot
.37569 .61096 Mdot
.31214 .199 Mdot
.61183 .58866 Mdot
.61221 .46463 Mdot
.69274 .55242 Mdot
.61531 .4499 Mdot
.61655 .41571 Mdot
.31234 .43231 Mdot
.58174 .30161 Mdot
.36499 .41136 Mdot
.32855 .54568 Mdot
.44026 .75562 Mdot
.35229 .4017 Mdot
.69609 .45068 Mdot
.39235 .52383 Mdot
.35956 .2673 Mdot
.61002 .34201 Mdot
.58324 .29341 Mdot
.63102 .61437 Mdot
.62596 .48534 Mdot
.44486 .48258 Mdot
.61384 .31913 Mdot
.67929 .45137 Mdot
.4965 .76013 Mdot
.61332 .25629 Mdot
.3839 .61622 Mdot
.49296 .37473 Mdot
.46494 .79786 Mdot
.61499 .58151 Mdot
.56812 .51058 Mdot
.42178 .62576 Mdot
.35107 .66881 Mdot
.50442 .76111 Mdot
.6843 .46265 Mdot
.40429 .60019 Mdot
.40121 .46665 Mdot
.39198 .35582 Mdot
.40849 .40927 Mdot
.61268 .31397 Mdot
.38269 .38976 Mdot
.68163 .46576 Mdot
.62462 .57882 Mdot
.65566 .44114 Mdot
.63221 .58577 Mdot
.37134 .76915 Mdot
.41258 .39931 Mdot
.38639 .42699 Mdot
.55322 .49277 Mdot
.36156 .65428 Mdot
.30941 .49574 Mdot
.68534 .46048 Mdot
.6309 .44555 Mdot
.42286 .4418 Mdot
.3413 .62517 Mdot
.56403 .31913 Mdot
.53393 .56448 Mdot
.37226 .39952 Mdot
.38388 .63351 Mdot
.42165 .43529 Mdot
.75412 .42374 Mdot
.51603 .66298 Mdot
.39165 .64965 Mdot
.17004 .52895 Mdot
.45125 .42463 Mdot
.39864 .53225 Mdot
.32832 .41318 Mdot
.52106 .32419 Mdot
.34745 .39979 Mdot
.36664 .60312 Mdot
.41417 .41271 Mdot
.36474 .63316 Mdot
.66917 .4623 Mdot
.64755 .57123 Mdot
.36806 .6295 Mdot
.44228 .39403 Mdot
.54041 .84039 Mdot
.61415 .58883 Mdot
.37732 .42363 Mdot
.63582 .62079 Mdot
.41019 .60889 Mdot
.37467 .66162 Mdot
.56291 .7674 Mdot
.67437 .56554 Mdot
.61253 .59721 Mdot
.42892 .42415 Mdot
.48473 .78084 Mdot
.42338 .43837 Mdot
.56269 .25315 Mdot
.35603 .41268 Mdot
.34698 .43232 Mdot
.35652 .7969 Mdot
.66548 .56431 Mdot
.32912 .20722 Mdot
.60678 .54935 Mdot
.5698 .81084 Mdot
.40682 .67037 Mdot
.60949 .34255 Mdot
.77908 .56219 Mdot
.49988 .72815 Mdot
.63108 .42388 Mdot
.37313 .44799 Mdot
.32224 .70175 Mdot
.61653 .6265 Mdot
.60216 .30717 Mdot
.43607 .40218 Mdot
.65242 .4971 Mdot
.53973 .79402 Mdot
.64535 .57869 Mdot
.38338 .61426 Mdot
.35626 .65101 Mdot
.19259 .3977 Mdot
.39551 .39808 Mdot
.39148 .42321 Mdot
.63438 .63023 Mdot
.45518 .47 Mdot
.5984 .33922 Mdot
.77314 .4175 Mdot
.61583 .60646 Mdot
.52607 .67929 Mdot
.40516 .63519 Mdot
.39343 .43952 Mdot
.56551 .45823 Mdot
.62631 .75882 Mdot
.21675 .46568 Mdot
.60872 .296 Mdot
.5382 .24079 Mdot
.36616 .60343 Mdot
.61661 .60039 Mdot
.38234 .2768 Mdot
.43752 .38307 Mdot
.39553 .44279 Mdot
.53462 .23251 Mdot
.52918 .56998 Mdot
.62744 .28703 Mdot
.33344 .43062 Mdot
.53044 .53424 Mdot
.42306 .4435 Mdot
.41226 .46151 Mdot
.40167 .49303 Mdot
.40027 .385 Mdot
.37735 .63514 Mdot
.25076 .64587 Mdot
.64834 .46101 Mdot
.24544 .39565 Mdot
.545 .3925 Mdot
.42279 .38952 Mdot
.42705 .44701 Mdot
.21935 .61101 Mdot
.53094 .7707 Mdot
.3856 .62869 Mdot
.40578 .5661 Mdot
.65011 .56836 Mdot
.36728 .51222 Mdot
.63993 .41306 Mdot
.45502 .50947 Mdot
.6612 .45433 Mdot
.38328 .6347 Mdot
.62913 .43983 Mdot
.65816 .58028 Mdot
.66108 .42723 Mdot
.64679 .41476 Mdot
.61223 .56888 Mdot
.39756 .65489 Mdot
.36973 .41431 Mdot
.62562 .56694 Mdot
.52978 .21131 Mdot
.61237 .31531 Mdot
.56093 .77002 Mdot
.33889 .4477 Mdot
.40544 .53586 Mdot
.75323 .33493 Mdot
.64904 .43328 Mdot
.49623 .67751 Mdot
.35949 .6149 Mdot
.56776 .3149 Mdot
.37234 .63528 Mdot
.28432 .33022 Mdot
.59008 .32198 Mdot
.55993 .77331 Mdot
.39928 .2714 Mdot
.59559 .50032 Mdot
.45797 .40808 Mdot
.39082 .70029 Mdot
.66284 .45318 Mdot
.61924 .63054 Mdot
.7195 .68114 Mdot
.44405 .44384 Mdot
.43502 .7115 Mdot
.37537 .67632 Mdot
.51659 .73541 Mdot
.61728 .59534 Mdot
.58677 .59143 Mdot
.39944 .3982 Mdot
.58786 .49326 Mdot
.34899 .41769 Mdot
.32555 .32592 Mdot
.54419 .26588 Mdot
.32777 .67483 Mdot
.42277 .42815 Mdot
.65455 .48687 Mdot
.42315 .4323 Mdot
.48719 .42974 Mdot
.34496 .27615 Mdot
.36871 .47596 Mdot
.41435 .70847 Mdot
.75 .36452 Mdot
.39564 .60636 Mdot
.38993 .48336 Mdot
.50278 .74365 Mdot
.44172 .43665 Mdot
.8715 .53274 Mdot
.59202 .3082 Mdot
.61841 .49865 Mdot
.44631 .39625 Mdot
.38757 .40515 Mdot
.29979 .61715 Mdot
.40036 .68916 Mdot
.51428 .72834 Mdot
.39547 .44747 Mdot
.526 .25228 Mdot
.63614 .61275 Mdot
.37062 .38856 Mdot
.41152 .41616 Mdot
.54728 .18908 Mdot
.63824 .61422 Mdot
.64787 .42969 Mdot
.50983 .72992 Mdot
.64016 .48411 Mdot
.60114 .34877 Mdot
.49864 .58883 Mdot
.48723 .20139 Mdot
.51559 .66557 Mdot
.57535 .29528 Mdot
.41122 .3806 Mdot
.37618 .54466 Mdot
.38467 .398 Mdot
.58805 .2895 Mdot
.6266 .6219 Mdot
.3769 .63264 Mdot
.46984 .34411 Mdot
.50455 .73538 Mdot
.34874 .40745 Mdot
.61756 .33098 Mdot
.37037 .6249 Mdot
.58621 .73672 Mdot
.36909 .60872 Mdot
.63366 .59659 Mdot
.65105 .5654 Mdot
.5941 .31827 Mdot
.37479 .63606 Mdot
.62554 .46469 Mdot
.60549 .55251 Mdot
.35369 .4139 Mdot
.6246 .53953 Mdot
.36047 .59128 Mdot
.35595 .65764 Mdot
.36778 .59313 Mdot
.41468 .39685 Mdot
.52731 .5806 Mdot
.45035 .39228 Mdot
.61118 .60567 Mdot
.62248 .43856 Mdot
.42918 .22527 Mdot
.32439 .54569 Mdot
.52643 .67714 Mdot
.35503 .3888 Mdot
.39282 .38887 Mdot
.40754 .41221 Mdot
.41732 .43007 Mdot
.77129 .42744 Mdot
.41294 .40053 Mdot
.63753 .59182 Mdot
.65904 .46461 Mdot
.40195 .3942 Mdot
.50158 .74622 Mdot
.5374 .45602 Mdot
.57077 .31621 Mdot
.50524 .35373 Mdot
.57611 .82852 Mdot
.37172 .62566 Mdot
.66925 .43942 Mdot
.62155 .44994 Mdot
.60424 .33251 Mdot
.63044 .56844 Mdot
.36374 .61402 Mdot
.49598 .31746 Mdot
.61765 .32167 Mdot
.40914 .42885 Mdot
.55949 .47716 Mdot
.17173 .55073 Mdot
.41532 .37967 Mdot
.39014 .45736 Mdot
.52403 .74753 Mdot
.61344 .44743 Mdot
.83332 .60554 Mdot
.55972 .6379 Mdot
.59843 .31425 Mdot
.57749 .31802 Mdot
.37233 .5944 Mdot
.36897 .38429 Mdot
.62775 .58523 Mdot
.53138 .54526 Mdot
.75394 .32029 Mdot
.71439 .70873 Mdot
.73135 .48655 Mdot
.36308 .4373 Mdot
.26357 .61673 Mdot
.36158 .45295 Mdot
.39116 .66842 Mdot
.35969 .60159 Mdot
.38567 .62361 Mdot
.63498 .60729 Mdot
.25914 .31366 Mdot
.63761 .58909 Mdot
.57733 .82958 Mdot
.39732 .60208 Mdot
.59172 .41063 Mdot
.62873 .45139 Mdot
.46266 .39164 Mdot
.58346 .29926 Mdot
.70286 .45477 Mdot
.40021 .48396 Mdot
.45645 .66018 Mdot
.64652 .4251 Mdot
.3801 .66339 Mdot
.4727 .38405 Mdot
.77169 .65218 Mdot
.51989 .61612 Mdot
.69387 .27597 Mdot
.28358 .38382 Mdot
.58529 .32131 Mdot
.19689 .49639 Mdot
.60238 .3397 Mdot
.65046 .58657 Mdot
.4458 .44187 Mdot
.45251 .40767 Mdot
.41164 .45139 Mdot
.41715 .40088 Mdot
.62909 .61775 Mdot
.3566 .43492 Mdot
.43524 .20625 Mdot
.49315 .74123 Mdot
.60234 .39727 Mdot
.59069 .33152 Mdot
.609 .57928 Mdot
.66249 .46511 Mdot
.51043 .76298 Mdot
.57381 .22286 Mdot
.35959 .43883 Mdot
.37165 .44917 Mdot
.49213 .75097 Mdot
.45855 .46273 Mdot
.45647 .36922 Mdot
.64848 .45633 Mdot
.49481 .5256 Mdot
.59893 .28271 Mdot
.57268 .31533 Mdot
.60267 .60917 Mdot
.37242 .63554 Mdot
.61458 .30334 Mdot
.63221 .49071 Mdot
.37658 .38512 Mdot
.35887 .46455 Mdot
.36011 .59132 Mdot
.31582 .28268 Mdot
.586 .34533 Mdot
.47854 .38093 Mdot
.35694 .62539 Mdot
.38301 .67435 Mdot
.39322 .4479 Mdot
.35436 .38115 Mdot
.36906 .66747 Mdot
.58549 .33179 Mdot
.60747 .58029 Mdot
.57932 .4427 Mdot
.63007 .57575 Mdot
.36329 .62177 Mdot
.464 .41636 Mdot
.40163 .64727 Mdot
.45013 .42563 Mdot
.13562 .38544 Mdot
.39163 .38668 Mdot
.43439 .63454 Mdot
.52825 .3242 Mdot
.63028 .46671 Mdot
.6346 .47466 Mdot
.50258 .74952 Mdot
.35648 .61511 Mdot
.39476 .47666 Mdot
.57701 .30942 Mdot
.56035 .80984 Mdot
.34068 .59344 Mdot
.66319 .42294 Mdot
.61945 .42728 Mdot
.62579 .6205 Mdot
.36638 .40993 Mdot
.39541 .4342 Mdot
.65863 .42689 Mdot
.77533 .35979 Mdot
.36685 .63959 Mdot
.39142 .4229 Mdot
.40168 .38658 Mdot
.65073 .46317 Mdot
.59602 .56244 Mdot
.42309 .64811 Mdot
.39931 .38551 Mdot
.41454 .26575 Mdot
.60756 .59269 Mdot
.42937 .41319 Mdot
.35861 .44252 Mdot
.60478 .31627 Mdot
.63777 .35599 Mdot
.35338 .27151 Mdot
.625 .56323 Mdot
.52198 .75114 Mdot
.44969 .43841 Mdot
.63081 .45485 Mdot
.33949 .44479 Mdot
.80618 .53954 Mdot
.49636 .73346 Mdot
.40029 .4053 Mdot
.4274 .48225 Mdot
.35841 .64691 Mdot
.39598 .40549 Mdot
.33425 .69739 Mdot
.65145 .48352 Mdot
.40095 .40423 Mdot
.31197 .56854 Mdot
.6234 .61904 Mdot
.40375 .48312 Mdot
.57493 .30623 Mdot
.52973 .33104 Mdot
.44188 .80865 Mdot
.66498 .41728 Mdot
.59971 .33074 Mdot
.38045 .3907 Mdot
.65679 .48934 Mdot
.59876 .59755 Mdot
.44179 .68754 Mdot
.40079 .37817 Mdot
.62526 .57393 Mdot
.62133 .58039 Mdot
.5949 .31408 Mdot
.28926 .23032 Mdot
.42736 .48304 Mdot
.37736 .43018 Mdot
.71721 .26249 Mdot
.41803 .62392 Mdot
.37431 .42783 Mdot
.36718 .41007 Mdot
.64024 .58129 Mdot
.37318 .2955 Mdot
.44166 .53686 Mdot
.7786 .39423 Mdot
.6069 .59127 Mdot
.66218 .50518 Mdot
.66582 .47828 Mdot
.59587 .33106 Mdot
.3934 .60667 Mdot
.58584 .2849 Mdot
.64119 .46593 Mdot
.40161 .45528 Mdot
.65183 .60744 Mdot
.24545 .46014 Mdot
.61879 .63196 Mdot
.65233 .49503 Mdot
.37219 .67173 Mdot
.48854 .81661 Mdot
.78239 .2981 Mdot
.4501 .79253 Mdot
.62281 .56191 Mdot
.60068 .31765 Mdot
.55232 .62511 Mdot
.39105 .38977 Mdot
.19087 .47803 Mdot
.37495 .43342 Mdot
.28269 .36658 Mdot
.67776 .44557 Mdot
.49892 .75942 Mdot
.4427 .44594 Mdot
.53542 .24438 Mdot
.6195 .56518 Mdot
.61665 .61703 Mdot
.41367 .42741 Mdot
.63314 .59373 Mdot
.39492 .42783 Mdot
.65479 .4675 Mdot
.29585 .22913 Mdot
.3756 .40115 Mdot
.40704 .4779 Mdot
.66106 .57718 Mdot
.56011 .77156 Mdot
.67099 .49591 Mdot
.26955 .61985 Mdot
.78334 .64456 Mdot
.63018 .59253 Mdot
.33578 .37878 Mdot
.65728 .43271 Mdot
.52423 .75266 Mdot
.60279 .43768 Mdot
.38041 .44059 Mdot
.36554 .44652 Mdot
.41866 .44717 Mdot
.39472 .38962 Mdot
.18827 .49973 Mdot
.46318 .38168 Mdot
.24567 .56211 Mdot
.37357 .45197 Mdot
.42934 .60079 Mdot
.63949 .59715 Mdot
.41389 .53581 Mdot
.63001 .30085 Mdot
.36413 .44653 Mdot
.4058 .68575 Mdot
.61299 .57388 Mdot
.59489 .81783 Mdot
.63407 .61775 Mdot
.64886 .43909 Mdot
.6555 .59643 Mdot
.45114 .41868 Mdot
.38806 .61191 Mdot
.65733 .47745 Mdot
.36764 .74679 Mdot
.63564 .42211 Mdot
.3958 .39624 Mdot
.60766 .52761 Mdot
.62761 .46281 Mdot
.51926 .38642 Mdot
.38831 .60977 Mdot
.51446 .2465 Mdot
.41868 .63036 Mdot
.39158 .41018 Mdot
.38591 .4146 Mdot
.51047 .76414 Mdot
.64453 .57782 Mdot
.40281 .60321 Mdot
.47638 .17058 Mdot
.62298 .31443 Mdot
.39309 .6253 Mdot
.36994 .36866 Mdot
.52942 .59192 Mdot
.37339 .65276 Mdot
.52135 .28685 Mdot
.6402 .57574 Mdot
.38448 .5934 Mdot
.43294 .36917 Mdot
.40215 .31945 Mdot
.58616 .33988 Mdot
.67096 .48304 Mdot
.53607 .51277 Mdot
.66243 .48068 Mdot
.65382 .63438 Mdot
.62172 .41792 Mdot
.63882 .60774 Mdot
.36371 .71336 Mdot
.46637 .54706 Mdot
.65765 .62903 Mdot
.66095 .58451 Mdot
.64002 .45854 Mdot
.41573 .43253 Mdot
.56593 .41444 Mdot
.37128 .37076 Mdot
.46263 .43557 Mdot
.61135 .58248 Mdot
.36952 .60026 Mdot
.40795 .63182 Mdot
.42093 .66998 Mdot
.37201 .65934 Mdot
.6627 .47232 Mdot
.50877 .66125 Mdot
.27892 .35134 Mdot
.63091 .62497 Mdot
.65952 .55013 Mdot
.4254 .43784 Mdot
.63454 .45853 Mdot
.67099 .4627 Mdot
.62934 .58064 Mdot
.22583 .43085 Mdot
.42265 .47535 Mdot
.41257 .64252 Mdot
.39916 .60287 Mdot
.37839 .65232 Mdot
.34709 .6157 Mdot
.23806 .3364 Mdot
.61914 .63056 Mdot
.36555 .60511 Mdot
.41954 .41019 Mdot
.36749 .44063 Mdot
.51789 .74049 Mdot
.5821 .32718 Mdot
.44308 .4521 Mdot
.43405 .46307 Mdot
.3925 .44701 Mdot
.62972 .46461 Mdot
.4228 .50514 Mdot
.49851 .73269 Mdot
.61988 .42157 Mdot
.64487 .41321 Mdot
.50853 .75952 Mdot
.34681 .58134 Mdot
.76715 .6759 Mdot
.41225 .45309 Mdot
.33117 .4878 Mdot
.63327 .45276 Mdot
.47783 .61498 Mdot
.40136 .33212 Mdot
.42715 .42234 Mdot
.5966 .38455 Mdot
.65613 .47132 Mdot
.33925 .66 Mdot
.38092 .43516 Mdot
.49799 .75382 Mdot
.57408 .32675 Mdot
.40134 .36615 Mdot
.52426 .74756 Mdot
.38275 .63684 Mdot
.73386 .33895 Mdot
.41396 .60963 Mdot
.62732 .46477 Mdot
.39373 .48376 Mdot
.15388 .68411 Mdot
.66355 .4523 Mdot
.62535 .78587 Mdot
.46992 .53855 Mdot
.38077 .39498 Mdot
.66594 .47439 Mdot
.34468 .66597 Mdot
.60796 .59176 Mdot
.54722 .50122 Mdot
.38895 .60079 Mdot
.50784 .76268 Mdot
.51967 .75136 Mdot
.64935 .46108 Mdot
.40304 .62704 Mdot
.35565 .42005 Mdot
.35179 .63333 Mdot
.65268 .62105 Mdot
.444 .41386 Mdot
.75782 .66446 Mdot
.39126 .35554 Mdot
.35572 .62454 Mdot
.63301 .49277 Mdot
.61619 .29694 Mdot
.43338 .40097 Mdot
.6862 .75297 Mdot
.36743 .40597 Mdot
.63214 .62203 Mdot
.46337 .59751 Mdot
.24001 .4725 Mdot
.41109 .44345 Mdot
.42608 .44366 Mdot
.60089 .59934 Mdot
.40956 .44767 Mdot
.39595 .38041 Mdot
.59031 .61355 Mdot
.36856 .65372 Mdot
.40393 .4097 Mdot
.67423 .47127 Mdot
.29565 .43302 Mdot
.43307 .4565 Mdot
.36674 .72818 Mdot
.52515 .2427 Mdot
.45645 .57784 Mdot
.39154 .47802 Mdot
.53337 .20714 Mdot
.38402 .41922 Mdot
.42439 .39857 Mdot
.41724 .44273 Mdot
.257 .62176 Mdot
.63933 .46264 Mdot
.68135 .44637 Mdot
.57601 .33324 Mdot
.52901 .24796 Mdot
.60667 .31982 Mdot
.60544 .5818 Mdot
.68615 .57894 Mdot
.49374 .74185 Mdot
.36963 .63489 Mdot
.41088 .46592 Mdot
.63522 .4199 Mdot
.39052 .44085 Mdot
.44138 .43489 Mdot
.65036 .47355 Mdot
.66714 .46639 Mdot
.64649 .4098 Mdot
.61097 .33535 Mdot
.37932 .62778 Mdot
.39598 .46093 Mdot
.6174 .31964 Mdot
.35906 .41297 Mdot
.53348 .59512 Mdot
.38222 .6276 Mdot
.35199 .63479 Mdot
.4118 .62863 Mdot
.37782 .45816 Mdot
.44779 .40743 Mdot
.63734 .58778 Mdot
.36383 .5882 Mdot
.62642 .62694 Mdot
.66459 .47588 Mdot
.63606 .47435 Mdot
.38005 .44088 Mdot
.47993 .38634 Mdot
.58188 .3236 Mdot
.64733 .43617 Mdot
.49207 .73007 Mdot
.57485 .3319 Mdot
.40559 .39452 Mdot
.66218 .47914 Mdot
.57208 .31016 Mdot
.24811 .41697 Mdot
.79781 .62083 Mdot
.62022 .31308 Mdot
.4137 .42625 Mdot
.30625 .60006 Mdot
.3942 .26565 Mdot
.62321 .30428 Mdot
.64298 .61648 Mdot
.36674 .42009 Mdot
.78968 .36578 Mdot
.59721 .28089 Mdot
.31913 .28178 Mdot
.646 .47348 Mdot
.31642 .34989 Mdot
.40388 .36537 Mdot
.20924 .42976 Mdot
.59443 .28049 Mdot
.36515 .61603 Mdot
.38219 .58773 Mdot
.40977 .4328 Mdot
.6266 .30307 Mdot
.6421 .63655 Mdot
.62124 .45049 Mdot
.65116 .41633 Mdot
.40245 .63308 Mdot
.52074 .67332 Mdot
.67215 .47328 Mdot
.37214 .48201 Mdot
.61423 .4846 Mdot
.34874 .49214 Mdot
.20381 .38494 Mdot
.36204 .75548 Mdot
.37044 .46994 Mdot
.61703 .29643 Mdot
.60937 .57061 Mdot
.63514 .5892 Mdot
.63366 .60521 Mdot
.64195 .48084 Mdot
.5185 .57316 Mdot
.66573 .42798 Mdot
.43754 .72011 Mdot
.58585 .31342 Mdot
.49425 .25949 Mdot
.40944 .47172 Mdot
.38239 .39436 Mdot
.37614 .38444 Mdot
.41847 .44898 Mdot
.38496 .42014 Mdot
.61612 .57952 Mdot
.62204 .46542 Mdot
.75499 .38133 Mdot
.38731 .64728 Mdot
.58048 .72302 Mdot
.62843 .45061 Mdot
.518 .73483 Mdot
.59896 .29973 Mdot
.48629 .20532 Mdot
.64551 .51784 Mdot
.62933 .44082 Mdot
.40257 .37645 Mdot
.36189 .6034 Mdot
.35901 .31243 Mdot
.37781 .41493 Mdot
.64751 .435 Mdot
.61365 .47287 Mdot
.20305 .48747 Mdot
.35614 .48474 Mdot
.55966 .30244 Mdot
.52798 .59282 Mdot
.60478 .2781 Mdot
.3458 .39671 Mdot
.47988 .62106 Mdot
.64237 .4642 Mdot
.65012 .44428 Mdot
.62172 .3133 Mdot
.43827 .51357 Mdot
.4001 .61406 Mdot
.49696 .75813 Mdot
.64371 .61106 Mdot
.37913 .40666 Mdot
.64578 .48291 Mdot
.35654 .51643 Mdot
.5605 .48301 Mdot
.62267 .61081 Mdot
.61803 .42493 Mdot
.36467 .42064 Mdot
.4099 .43852 Mdot
.58833 .32308 Mdot
.65467 .29135 Mdot
.37993 .36826 Mdot
.57047 .81073 Mdot
.50485 .61951 Mdot
.51072 .47476 Mdot
.3957 .44227 Mdot
.39542 .6515 Mdot
.50287 .75569 Mdot
.59079 .29242 Mdot
.36077 .41338 Mdot
.79066 .65054 Mdot
.38868 .577 Mdot
.61487 .59036 Mdot
.50149 .75623 Mdot
.51932 .561 Mdot
.36843 .40293 Mdot
.3752 .43349 Mdot
.41559 .39855 Mdot
.79883 .64468 Mdot
.68017 .44918 Mdot
.36136 .59491 Mdot
.61009 .29786 Mdot
.35177 .6433 Mdot
.67448 .43088 Mdot
.52906 .44526 Mdot
.40804 .39218 Mdot
.41037 .64293 Mdot
.36787 .61226 Mdot
.62413 .62029 Mdot
.62308 .56665 Mdot
.68876 .4528 Mdot
.38522 .38965 Mdot
.49336 .74829 Mdot
.38275 .59555 Mdot
.61903 .46792 Mdot
.58817 .3219 Mdot
.63866 .56128 Mdot
.37453 .45361 Mdot
.64606 .46082 Mdot
.35686 .45058 Mdot
.3594 .6426 Mdot
.62896 .44286 Mdot
.52075 .73565 Mdot
.5798 .32337 Mdot
.36875 .45005 Mdot
.7466 .34151 Mdot
.50132 .75827 Mdot
.43917 .39381 Mdot
.3256 .58763 Mdot
.62489 .33605 Mdot
.3626 .7459 Mdot
.67353 .44226 Mdot
.49768 .74014 Mdot
.36125 .59876 Mdot
.38243 .31803 Mdot
.65426 .44905 Mdot
.30173 .66142 Mdot
.58552 .40658 Mdot
.40315 .45693 Mdot
.3971 .62488 Mdot
.59446 .26726 Mdot
.59602 .80874 Mdot
.42218 .25315 Mdot
.39586 .41875 Mdot
.66267 .4809 Mdot
.57243 .31627 Mdot
.62349 .62452 Mdot
.37081 .72715 Mdot
.20345 .39859 Mdot
.62261 .42015 Mdot
.39623 .46409 Mdot
.37811 .59576 Mdot
.62602 .58199 Mdot
.37627 .78172 Mdot
.63713 .49335 Mdot
.6775 .45757 Mdot
.41895 .39362 Mdot
.60819 .29416 Mdot
.79057 .38523 Mdot
.68187 .45376 Mdot
.63717 .48194 Mdot
.5694 .73211 Mdot
.59819 .34521 Mdot
.41731 .41371 Mdot
.4203 .67131 Mdot
.37598 .38653 Mdot
.58002 .79765 Mdot
.49601 .7421 Mdot
.38437 .64767 Mdot
.37164 .43894 Mdot
.75038 .36771 Mdot
.66109 .45699 Mdot
.52508 .59909 Mdot
.59475 .64305 Mdot
.62805 .56767 Mdot
.64785 .48203 Mdot
.38676 .43617 Mdot
.65056 .56363 Mdot
.58458 .32541 Mdot
.39899 .38546 Mdot
.45027 .41648 Mdot
.35605 .67333 Mdot
.65244 .61492 Mdot
.30114 .44071 Mdot
.65693 .61589 Mdot
.60337 .61298 Mdot
.38591 .67397 Mdot
.40934 .4314 Mdot
.64053 .43752 Mdot
.6604 .49358 Mdot
.3547 .43167 Mdot
.47868 .61256 Mdot
.39991 .61685 Mdot
.59387 .44801 Mdot
.83205 .60027 Mdot
.4145 .49136 Mdot
.49513 .72754 Mdot
.29852 .36621 Mdot
.60842 .61082 Mdot
.39957 .45445 Mdot
.36326 .63456 Mdot
.62783 .47588 Mdot
.67156 .47735 Mdot
.41263 .37424 Mdot
.6278 .57874 Mdot
.57029 .30692 Mdot
.67345 .45622 Mdot
.56101 .48912 Mdot
.39972 .40212 Mdot
.43347 .71219 Mdot
.67191 .44898 Mdot
.50048 .83791 Mdot
.75189 .37377 Mdot
.39435 .64587 Mdot
.43604 .43571 Mdot
.34449 .63614 Mdot
.61143 .3021 Mdot
.60572 .43135 Mdot
.62956 .57735 Mdot
.49489 .3907 Mdot
.53469 .17909 Mdot
.63488 .46219 Mdot
.37907 .63472 Mdot
.38892 .46049 Mdot
.45673 .35719 Mdot
.37222 .40115 Mdot
.39693 .29536 Mdot
.57647 .26011 Mdot
.6582 .57843 Mdot
.61719 .62035 Mdot
.42703 .4497 Mdot
.60486 .33754 Mdot
.67418 .48443 Mdot
.64846 .47249 Mdot
.22586 .28539 Mdot
.52448 .74464 Mdot
.55705 .27163 Mdot
.37599 .45645 Mdot
.61692 .46035 Mdot
.3241 .53878 Mdot
.63448 .63008 Mdot
.35767 .3998 Mdot
.61759 .43869 Mdot
.62065 .75241 Mdot
.53216 .5834 Mdot
.39899 .40883 Mdot
.45552 .47023 Mdot
.63851 .61803 Mdot
.55269 .62667 Mdot
.66219 .42653 Mdot
.36095 .40159 Mdot
.62432 .6473 Mdot
.55706 .75962 Mdot
.50593 .17773 Mdot
.37968 .62742 Mdot
.62562 .48877 Mdot
.62462 .56978 Mdot
.41449 .5034 Mdot
.58757 .33123 Mdot
.63927 .48707 Mdot
.62374 .43284 Mdot
.44249 .42092 Mdot
.43477 .45911 Mdot
.38513 .49764 Mdot
.39162 .63396 Mdot
.64287 .58787 Mdot
.43014 .45336 Mdot
.52582 .65462 Mdot
.4117 .4563 Mdot
.64049 .58439 Mdot
.09704 .54898 Mdot
.42198 .37997 Mdot
.37198 .4214 Mdot
.52087 .34862 Mdot
.40625 .61775 Mdot
.36272 .65309 Mdot
.51366 .6472 Mdot
.37498 .45583 Mdot
.5838 .47305 Mdot
.37616 .62889 Mdot
.39808 .61624 Mdot
.58338 .44655 Mdot
.44064 .4131 Mdot
.66279 .63784 Mdot
.62909 .5835 Mdot
.62669 .56738 Mdot
.35687 .64449 Mdot
.45995 .38787 Mdot
.59957 .59121 Mdot
.18542 .52333 Mdot
.62644 .44569 Mdot
.47983 .62172 Mdot
.35256 .63 Mdot
.56979 .44238 Mdot
.64558 .57979 Mdot
.53188 .85761 Mdot
.43877 .31927 Mdot
.34975 .42918 Mdot
.41144 .43834 Mdot
.60208 .32082 Mdot
.4023 .34335 Mdot
.52212 .74831 Mdot
.63449 .59542 Mdot
.76581 .44622 Mdot
.38634 .6231 Mdot
.37117 .41546 Mdot
.43858 .22004 Mdot
.39344 .78095 Mdot
.426 .69164 Mdot
.39143 .60432 Mdot
.39036 .61822 Mdot
.64471 .4243 Mdot
.6237 .44857 Mdot
.41402 .40702 Mdot
.63679 .60326 Mdot
.38854 .59196 Mdot
.64823 .59838 Mdot
.6421 .46574 Mdot
.63106 .44278 Mdot
.49961 .7302 Mdot
.47085 .41624 Mdot
.641 .47505 Mdot
.57353 .74927 Mdot
.52601 .65031 Mdot
.33841 .65404 Mdot
.77051 .29035 Mdot
.37125 .78168 Mdot
.51922 .34299 Mdot
.57473 .32846 Mdot
.50613 .7775 Mdot
.6498 .57965 Mdot
.42575 .44952 Mdot
.38025 .44823 Mdot
.51593 .7435 Mdot
.63582 .56874 Mdot
.60414 .30398 Mdot
.6463 .57929 Mdot
.58758 .29726 Mdot
.6844 .4552 Mdot
.4359 .45482 Mdot
.37784 .39022 Mdot
.61256 .60242 Mdot
.64806 .42825 Mdot
.62811 .46511 Mdot
.58294 .33569 Mdot
.49007 .21052 Mdot
.64872 .46245 Mdot
.35234 .63043 Mdot
.28411 .44618 Mdot
.51946 .74987 Mdot
.38123 .43437 Mdot
.46735 .20569 Mdot
.20187 .47346 Mdot
.40224 .45891 Mdot
.5011 .75662 Mdot
.24305 .26238 Mdot
.44427 .44497 Mdot
.20923 .33387 Mdot
.50025 .73342 Mdot
.40366 .64409 Mdot
.66163 .43507 Mdot
.52133 .75658 Mdot
.42337 .50359 Mdot
.59141 .25436 Mdot
.37367 .47737 Mdot
.39657 .60327 Mdot
.40281 .65239 Mdot
.47555 .54244 Mdot
.58451 .79545 Mdot
.60451 .28904 Mdot
.59884 .30619 Mdot
.65449 .45203 Mdot
.68238 .64177 Mdot
.34413 .43573 Mdot
.60048 .30863 Mdot
.78878 .45711 Mdot
.42534 .43584 Mdot
.55728 .25251 Mdot
.58784 .39107 Mdot
.39855 .64694 Mdot
.42512 .53284 Mdot
.65808 .4536 Mdot
.37937 .63419 Mdot
.52326 .47825 Mdot
.37431 .38608 Mdot
.38417 .62615 Mdot
.64261 .58384 Mdot
.71483 .63946 Mdot
.36696 .65908 Mdot
.54966 .49793 Mdot
.62664 .58625 Mdot
.62719 .32745 Mdot
.46151 .28347 Mdot
.87407 .57634 Mdot
.63575 .59701 Mdot
.65383 .43316 Mdot
.63659 .47317 Mdot
.65261 .46475 Mdot
.39094 .60117 Mdot
.66841 .46158 Mdot
.38648 .64296 Mdot
.62442 .53456 Mdot
.51916 .20646 Mdot
.59149 .31886 Mdot
.64926 .53329 Mdot
.37426 .61381 Mdot
.45437 .7188 Mdot
.71345 .24419 Mdot
.41674 .42085 Mdot
.65114 .63375 Mdot
.61864 .29751 Mdot
.513 .69246 Mdot
.60532 .31621 Mdot
.65801 .43245 Mdot
.47983 .62381 Mdot
.39568 .42656 Mdot
.31666 .68938 Mdot
.57652 .30523 Mdot
.39025 .60242 Mdot
.41909 .38588 Mdot
.69085 .46058 Mdot
.60358 .32752 Mdot
.57552 .32784 Mdot
.38398 .42264 Mdot
.3863 .66152 Mdot
.63483 .43873 Mdot
.65269 .57946 Mdot
.6104 .27197 Mdot
.47319 .44136 Mdot
.41474 .43754 Mdot
.39434 .37303 Mdot
.51844 .60669 Mdot
.79332 .37978 Mdot
.62856 .59234 Mdot
.39119 .26289 Mdot
.63275 .46576 Mdot
.42038 .25829 Mdot
.46119 .76157 Mdot
.65556 .5231 Mdot
.49611 .74009 Mdot
.49548 .74352 Mdot
.39427 .41332 Mdot
.80535 .41297 Mdot
.42866 .66983 Mdot
.61174 .6339 Mdot
.51635 .75369 Mdot
.62756 .46419 Mdot
.37364 .58225 Mdot
.46829 .50014 Mdot
.45624 .43201 Mdot
.62741 .56405 Mdot
.64667 .46735 Mdot
.807 .53796 Mdot
.58734 .31232 Mdot
.49512 .6668 Mdot
.40197 .39322 Mdot
.38908 .42566 Mdot
.62023 .59748 Mdot
.63651 .5876 Mdot
.41504 .71716 Mdot
.48173 .55814 Mdot
.72989 .6797 Mdot
.66759 .62844 Mdot
.81363 .52051 Mdot
.41407 .67008 Mdot
.35766 .62952 Mdot
.50411 .72749 Mdot
.60075 .59199 Mdot
.37299 .42954 Mdot
.40584 .63963 Mdot
.42954 .68341 Mdot
.36147 .67839 Mdot
.54897 .25714 Mdot
.57675 .4486 Mdot
.39945 .39087 Mdot
.35691 .60667 Mdot
.38099 .63237 Mdot
.34438 .62652 Mdot
.50878 .75882 Mdot
.3965 .44502 Mdot
.41651 .43021 Mdot
.44696 .43981 Mdot
.46181 .36347 Mdot
.39625 .40458 Mdot
.46617 .76459 Mdot
.53111 .67757 Mdot
.68005 .37284 Mdot
.38949 .46372 Mdot
.63053 .57162 Mdot
.40895 .46662 Mdot
.60215 .33743 Mdot
.38911 .46509 Mdot
.57257 .24797 Mdot
.62916 .6051 Mdot
.46782 .48623 Mdot
.60107 .42661 Mdot
.40474 .3918 Mdot
.57441 .29733 Mdot
.79521 .3848 Mdot
.41972 .22804 Mdot
.57037 .73531 Mdot
.35234 .63106 Mdot
.68669 .44232 Mdot
.63917 .63424 Mdot
.64075 .43874 Mdot
.3528 .4118 Mdot
.49434 .73059 Mdot
.32941 .779 Mdot
.56029 .44178 Mdot
.37196 .43171 Mdot
.47024 .39368 Mdot
.38786 .65456 Mdot
.6632 .45763 Mdot
.38167 .68372 Mdot
.42065 .39766 Mdot
.6141 .30631 Mdot
.61626 .3141 Mdot
.49995 .49499 Mdot
.78842 .53192 Mdot
.38055 .31143 Mdot
.62201 .59648 Mdot
.66997 .48027 Mdot
.5932 .2812 Mdot
.39724 .7037 Mdot
.6356 .63677 Mdot
.60858 .61084 Mdot
.6522 .61355 Mdot
.39046 .39434 Mdot
.50746 .73099 Mdot
.78881 .49148 Mdot
.51223 .76244 Mdot
.41303 .38945 Mdot
.62819 .42873 Mdot
.52135 .75771 Mdot
.60401 .32152 Mdot
.60336 .61017 Mdot
.62896 .45966 Mdot
.38822 .41152 Mdot
.37425 .62486 Mdot
.40027 .25012 Mdot
.6714 .25085 Mdot
.61157 .49603 Mdot
.61303 .4987 Mdot
.41296 .62041 Mdot
.67766 .77081 Mdot
.62104 .54215 Mdot
.22268 .43447 Mdot
.58051 .26937 Mdot
.35416 .43134 Mdot
.31369 .23311 Mdot
.66665 .42965 Mdot
.65982 .47606 Mdot
.40319 .40573 Mdot
.62675 .48441 Mdot
.37072 .4103 Mdot
.65606 .42269 Mdot
.64684 .7625 Mdot
.45795 .4123 Mdot
.6611 .47385 Mdot
.34251 .42286 Mdot
.43241 .39728 Mdot
.38908 .65562 Mdot
.63482 .48417 Mdot
.34991 .43311 Mdot
.30765 .77543 Mdot
.61919 .61528 Mdot
.51116 .75896 Mdot
.67286 .5608 Mdot
.65451 .59822 Mdot
.39636 .63381 Mdot
.44326 .44878 Mdot
.58463 .32332 Mdot
.36611 .61984 Mdot
.68997 .43942 Mdot
.58009 .29772 Mdot
.51025 .66194 Mdot
.35527 .63621 Mdot
.51707 .74148 Mdot
.57862 .3198 Mdot
.37533 .47867 Mdot
.65362 .47686 Mdot
.733 .29694 Mdot
.513 .76159 Mdot
.39461 .43386 Mdot
.64184 .50106 Mdot
.64711 .58047 Mdot
.41063 .41386 Mdot
.66024 .4844 Mdot
.50532 .75863 Mdot
.43976 .39578 Mdot
.43714 .39295 Mdot
.48624 .47725 Mdot
.45719 .61388 Mdot
.59218 .32281 Mdot
.38524 .6731 Mdot
.4197 .4072 Mdot
.60348 .33875 Mdot
.715 .5184 Mdot
.38872 .47328 Mdot
.34867 .64477 Mdot
.4878 .37792 Mdot
.62295 .44494 Mdot
.62426 .62623 Mdot
.65279 .49553 Mdot
.57242 .32427 Mdot
.52033 .15072 Mdot
.51509 .73377 Mdot
.47322 .40847 Mdot
.37583 .38401 Mdot
.6114 .43061 Mdot
.38513 .63109 Mdot
.7122 .69429 Mdot
.37111 .45262 Mdot
.44442 .3709 Mdot
.38143 .42864 Mdot
.74788 .37394 Mdot
.39893 .61447 Mdot
.38046 .43179 Mdot
.47987 .40035 Mdot
.36449 .47292 Mdot
.57353 .29633 Mdot
.48878 .26913 Mdot
.40998 .4646 Mdot
.23836 .77707 Mdot
.49135 .74887 Mdot
.65164 .47224 Mdot
.54713 .54167 Mdot
.73547 .44247 Mdot
.20623 .3716 Mdot
.38951 .63913 Mdot
.31433 .38445 Mdot
.63715 .43877 Mdot
.39145 .2385 Mdot
.63824 .80037 Mdot
.4297 .39474 Mdot
.36496 .4253 Mdot
.658 .43248 Mdot
.61917 .46573 Mdot
.49264 .73783 Mdot
.36717 .4566 Mdot
.44861 .37506 Mdot
.61678 .47128 Mdot
.38707 .40561 Mdot
.21662 .57832 Mdot
.66026 .60152 Mdot
.35974 .64922 Mdot
.62389 .62463 Mdot
.60875 .60661 Mdot
.25575 .37192 Mdot
.5043 .61904 Mdot
.63926 .58526 Mdot
.59396 .61492 Mdot
.58464 .2397 Mdot
.4984 .39164 Mdot
.58229 .28708 Mdot
.77082 .58972 Mdot
.65339 .45712 Mdot
.3965 .44666 Mdot
.38108 .59833 Mdot
.21876 .3981 Mdot
.69897 .6649 Mdot
.48023 .64416 Mdot
.41839 .42271 Mdot
.65958 .45979 Mdot
.50655 .76046 Mdot
.45864 .41868 Mdot
.40747 .264 Mdot
.39313 .42237 Mdot
.62145 .45381 Mdot
.26492 .36194 Mdot
.33067 .68875 Mdot
.66425 .63185 Mdot
.33501 .61839 Mdot
.41911 .46411 Mdot
.36614 .64357 Mdot
.62624 .5724 Mdot
.60991 .33594 Mdot
.59977 .31703 Mdot
.39631 .38813 Mdot
.46638 .5479 Mdot
.6304 .272 Mdot
.43077 .39712 Mdot
.44287 .41795 Mdot
.4981 .73728 Mdot
.44335 .41703 Mdot
.36553 .39584 Mdot
.42218 .45773 Mdot
.37048 .46433 Mdot
.60194 .61024 Mdot
.31661 .61229 Mdot
.39568 .46842 Mdot
.41659 .49184 Mdot
.64836 .56542 Mdot
.36959 .50425 Mdot
.63487 .61629 Mdot
.76288 .64359 Mdot
.64208 .60819 Mdot
.59801 .31768 Mdot
.66564 .4958 Mdot
.30942 .40586 Mdot
.39014 .59267 Mdot
.6198 .56864 Mdot
.59019 .30048 Mdot
.63497 .60053 Mdot
.67929 .46786 Mdot
.74965 .28506 Mdot
.40327 .66351 Mdot
.53558 .59316 Mdot
.50579 .34578 Mdot
.43206 .71261 Mdot
.62592 .43922 Mdot
.40183 .63328 Mdot
.33439 .6966 Mdot
.42847 .45045 Mdot
.58901 .32662 Mdot
.39351 .41506 Mdot
.60568 .61532 Mdot
.65715 .45991 Mdot
.60873 .52981 Mdot
.59348 .3233 Mdot
.58931 .1784 Mdot
.63719 .42023 Mdot
.45831 .45321 Mdot
.65068 .56634 Mdot
.75438 .2783 Mdot
.64035 .6125 Mdot
.51342 .20536 Mdot
.39878 .56776 Mdot
.27145 .34227 Mdot
.3856 .61418 Mdot
.39058 .7164 Mdot
.73112 .74633 Mdot
.64357 .78818 Mdot
.36456 .62565 Mdot
.59399 .43817 Mdot
.39471 .39836 Mdot
.41695 .45297 Mdot
.38113 .48887 Mdot
.33448 .64667 Mdot
.41668 .40201 Mdot
.52128 .74624 Mdot
.51149 .6193 Mdot
.78413 .41418 Mdot
.68697 .46111 Mdot
.37015 .40833 Mdot
.61169 .58273 Mdot
.61076 .62548 Mdot
.5183 .76095 Mdot
.65561 .61242 Mdot
.43678 .40374 Mdot
.37744 .61318 Mdot
.56036 .42289 Mdot
.61138 .3101 Mdot
.52159 .79963 Mdot
.58955 .27276 Mdot
.65619 .5145 Mdot
.40091 .49224 Mdot
.63062 .44261 Mdot
.41796 .16719 Mdot
.42378 .44799 Mdot
.3751 .63095 Mdot
.41343 .38625 Mdot
.42242 .45914 Mdot
.40167 .46447 Mdot
.66349 .48367 Mdot
.54681 .54774 Mdot
.38492 .40777 Mdot
.63388 .57653 Mdot
.59054 .42512 Mdot
.44389 .45264 Mdot
.76212 .4728 Mdot
.53918 .26713 Mdot
.44079 .71089 Mdot
.33643 .64377 Mdot
.6563 .43921 Mdot
.3875 .62063 Mdot
.33019 .62333 Mdot
.39633 .63408 Mdot
.77189 .46356 Mdot
.32905 .33003 Mdot
.19035 .36183 Mdot
.31041 .52502 Mdot
.22494 .4058 Mdot
.41395 .63747 Mdot
.72819 .53442 Mdot
.36091 .6315 Mdot
.39299 .63757 Mdot
.11458 .43601 Mdot
.35679 .61647 Mdot
.38113 .44208 Mdot
.44748 .39268 Mdot
.4414 .79865 Mdot
.57718 .23777 Mdot
.39037 .46458 Mdot
.4161 .4043 Mdot
.61396 .296 Mdot
.48553 .39698 Mdot
.50906 .76779 Mdot
.49667 .6451 Mdot
.48158 .74969 Mdot
.38471 .42185 Mdot
.40824 .40273 Mdot
.39109 .37057 Mdot
.73067 .75187 Mdot
.21306 .3952 Mdot
.40819 .64044 Mdot
.40753 .51519 Mdot
.55582 .78743 Mdot
.39289 .37987 Mdot
.3992 .38125 Mdot
.4509 .42336 Mdot
.63931 .43777 Mdot
.38117 .58066 Mdot
.42191 .36275 Mdot
.42815 .75444 Mdot
.40375 .39439 Mdot
.67939 .49951 Mdot
.60599 .36617 Mdot
.38628 .43729 Mdot
.34847 .63927 Mdot
.42081 .4379 Mdot
.35102 .61751 Mdot
.35995 .64782 Mdot
.47069 .40919 Mdot
.78947 .50292 Mdot
.36149 .5856 Mdot
.4282 .39117 Mdot
.64741 .43038 Mdot
.59884 .80573 Mdot
.39313 .43578 Mdot
.60429 .29066 Mdot
.40075 .45468 Mdot
.57116 .30295 Mdot
.44766 .41442 Mdot
.50904 .76255 Mdot
.23285 .48397 Mdot
.65056 .4459 Mdot
.60682 .26949 Mdot
.61764 .4682 Mdot
.50976 .45028 Mdot
.37792 .6661 Mdot
.50463 .76753 Mdot
.1888 .42286 Mdot
.49899 .73622 Mdot
.37317 .26658 Mdot
.69689 .63177 Mdot
.61042 .60384 Mdot
.3481 .61396 Mdot
.31625 .32971 Mdot
.77193 .5094 Mdot
.64281 .41121 Mdot
.64411 .41287 Mdot
.44424 .17082 Mdot
.29145 .23136 Mdot
.38055 .41033 Mdot
.78727 .34635 Mdot
.24742 .54424 Mdot
.35155 .45774 Mdot
.33543 .40812 Mdot
.62026 .43788 Mdot
.41912 .46504 Mdot
.54199 .49708 Mdot
.63954 .4593 Mdot
.59253 .30357 Mdot
.38172 .64786 Mdot
.57929 .32861 Mdot
.73727 .64522 Mdot
.5345 .66268 Mdot
.6374 .46799 Mdot
.38058 .46998 Mdot
.3781 .40292 Mdot
.35431 .60513 Mdot
.31057 .69563 Mdot
.36755 .65394 Mdot
.59652 .28543 Mdot
.64245 .45029 Mdot
.20727 .42582 Mdot
.39289 .45701 Mdot
.37061 .60956 Mdot
.62115 .40837 Mdot
.40953 .43999 Mdot
.61254 .59429 Mdot
.41895 .42308 Mdot
.36001 .61741 Mdot
.44387 .41697 Mdot
.37942 .61405 Mdot
.65489 .42559 Mdot
.36719 .40139 Mdot
.40915 .40447 Mdot
.35233 .27188 Mdot
.60492 .30382 Mdot
.38469 .6654 Mdot
.5399 .50393 Mdot
.37787 .38584 Mdot
.40844 .26559 Mdot
.43927 .45176 Mdot
.31954 .4136 Mdot
.35412 .38211 Mdot
.51936 .74165 Mdot
.35825 .39531 Mdot
.39313 .43433 Mdot
.29453 .64666 Mdot
.31857 .5658 Mdot
.44282 .52186 Mdot
.61882 .56717 Mdot
.3499 .64147 Mdot
.63959 .47691 Mdot
.62661 .472 Mdot
.66977 .45406 Mdot
.56464 .23169 Mdot
.4728 .44601 Mdot
.39736 .4265 Mdot
.65893 .57895 Mdot
.59753 .30861 Mdot
.38332 .6025 Mdot
.5946 .31447 Mdot
.49519 .64048 Mdot
.58826 .28817 Mdot
.52136 .74312 Mdot
.75255 .3735 Mdot
.19505 .5456 Mdot
.59289 .29012 Mdot
.36562 .65309 Mdot
.57837 .46301 Mdot
.35352 .43358 Mdot
.5976 .75708 Mdot
.61419 .30536 Mdot
.47368 .16953 Mdot
.44481 .39634 Mdot
.54443 .50896 Mdot
.63007 .61755 Mdot
.5781 .32595 Mdot
.65139 .61907 Mdot
.42137 .44158 Mdot
.35965 .74454 Mdot
.37493 .63539 Mdot
.65945 .61874 Mdot
.34977 .40976 Mdot
.57916 .32803 Mdot
.64055 .47224 Mdot
.46064 .33494 Mdot
.63426 .56571 Mdot
.40174 .24318 Mdot
.42177 .25342 Mdot
.64112 .45184 Mdot
.17512 .55506 Mdot
.64525 .6205 Mdot
.37 .4683 Mdot
.33531 .33742 Mdot
.42169 .42972 Mdot
.63137 .47247 Mdot
.66468 .4729 Mdot
.48979 .79991 Mdot
.39701 .38932 Mdot
.45391 .40927 Mdot
.3996 .59066 Mdot
.63331 .45951 Mdot
.39941 .62846 Mdot
.36495 .59177 Mdot
.65504 .43095 Mdot
.39591 .64428 Mdot
.57597 .30648 Mdot
.50124 .6095 Mdot
.64536 .61879 Mdot
.62014 .57999 Mdot
.63952 .47387 Mdot
.68032 .47157 Mdot
.62948 .4449 Mdot
.42245 .41762 Mdot
.40358 .6163 Mdot
.435 .43083 Mdot
.4073 .46629 Mdot
.41229 .57639 Mdot
.40692 .60928 Mdot
.42971 .43354 Mdot
.59768 .39482 Mdot
.5689 .33137 Mdot
.66194 .47236 Mdot
.64748 .59482 Mdot
.34426 .27082 Mdot
.66042 .60803 Mdot
.39639 .38397 Mdot
.61697 .75578 Mdot
.39212 .60235 Mdot
.60446 .31812 Mdot
.61778 .34467 Mdot
.59718 .32347 Mdot
.65942 .61915 Mdot
.35722 .59657 Mdot
.51236 .6608 Mdot
.38556 .38848 Mdot
.51728 .60661 Mdot
.36309 .27925 Mdot
.45452 .76065 Mdot
.64223 .58522 Mdot
.41688 .41836 Mdot
.50085 .73415 Mdot
.20071 .49677 Mdot
.39883 .41929 Mdot
.35567 .40269 Mdot
.69427 .32707 Mdot
.41603 .49173 Mdot
.34827 .66737 Mdot
.47809 .52306 Mdot
.3613 .4141 Mdot
.46135 .50807 Mdot
.17982 .32748 Mdot
.44213 .39438 Mdot
.40857 .39802 Mdot
.38735 .44979 Mdot
.42722 .44618 Mdot
.34753 .64951 Mdot
.67283 .29136 Mdot
.61371 .57672 Mdot
.50253 .60611 Mdot
.65045 .61435 Mdot
.65525 .48026 Mdot
.54125 .47596 Mdot
.34642 .62639 Mdot
.59802 .32367 Mdot
.77999 .31712 Mdot
.48677 .61458 Mdot
.64271 .42502 Mdot
.22949 .35753 Mdot
.61284 .31147 Mdot
.3547 .43476 Mdot
.57654 .33458 Mdot
.61507 .45146 Mdot
.62951 .57965 Mdot
.40721 .37725 Mdot
.39298 .59861 Mdot
.36343 .65717 Mdot
.41967 .4138 Mdot
.56226 .80815 Mdot
.65329 .59146 Mdot
.70917 .43801 Mdot
.39379 .3928 Mdot
.35579 .40329 Mdot
.37546 .65311 Mdot
.66275 .45969 Mdot
.69291 .62337 Mdot
.59904 .29805 Mdot
.34601 .41703 Mdot
.42004 .44214 Mdot
.49853 .62986 Mdot
.60261 .58977 Mdot
.50852 .75169 Mdot
.39593 .39093 Mdot
.50627 .623 Mdot
.40568 .38783 Mdot
.43211 .35532 Mdot
.63629 .43436 Mdot
.46592 .42604 Mdot
.36316 .43461 Mdot
.34396 .5121 Mdot
.64309 .62397 Mdot
.38107 .62947 Mdot
.40428 .57577 Mdot
.49737 .75354 Mdot
.61552 .60668 Mdot
.42752 .43171 Mdot
.61276 .62102 Mdot
.40797 .46106 Mdot
.38776 .40869 Mdot
.6422 .58474 Mdot
.3997 .63085 Mdot
.71271 .685 Mdot
.31082 .63595 Mdot
.44051 .43989 Mdot
.40696 .4524 Mdot
.56541 .23844 Mdot
.16763 .4989 Mdot
.36362 .44064 Mdot
.40323 .61059 Mdot
.40956 .43739 Mdot
.61864 .57768 Mdot
.59391 .28552 Mdot
.37134 .62793 Mdot
.68258 .46461 Mdot
.66258 .42829 Mdot
.60364 .41936 Mdot
.51795 .73698 Mdot
.36382 .44931 Mdot
.39186 .67209 Mdot
.40903 .60975 Mdot
.51482 .70072 Mdot
.65231 .47306 Mdot
.58175 .29047 Mdot
.45321 .42189 Mdot
.44579 .32787 Mdot
.60722 .59658 Mdot
.24559 .78213 Mdot
.51533 .66499 Mdot
.57183 .29266 Mdot
.45475 .57287 Mdot
.50573 .7355 Mdot
.36943 .42822 Mdot
.59842 .33867 Mdot
.67472 .44759 Mdot
.41923 .44945 Mdot
.43159 .49298 Mdot
.76961 .5234 Mdot
.68516 .44888 Mdot
.61838 .62461 Mdot
.67838 .44895 Mdot
.56819 .31005 Mdot
.5219 .74561 Mdot
.38323 .66081 Mdot
.39055 .43166 Mdot
.37288 .5158 Mdot
.65494 .46686 Mdot
.50238 .76175 Mdot
.40274 .38968 Mdot
.35275 .64807 Mdot
.66714 .46582 Mdot
.37998 .42324 Mdot
.21679 .44722 Mdot
.42036 .58212 Mdot
.64869 .45387 Mdot
.38581 .37757 Mdot
.50943 .41868 Mdot
.67832 .43603 Mdot
.62339 .43127 Mdot
.4161 .40197 Mdot
.577 .31639 Mdot
.36651 .40879 Mdot
.63824 .60959 Mdot
.54702 .54752 Mdot
.61376 .59806 Mdot
.3892 .26657 Mdot
.44454 .38594 Mdot
.4338 .68782 Mdot
.36633 .59917 Mdot
.61106 .34503 Mdot
.29011 .636 Mdot
.35602 .40929 Mdot
.75098 .67871 Mdot
.56908 .44789 Mdot
.53899 .69075 Mdot
.81968 .59938 Mdot
.59488 .2934 Mdot
.63365 .60574 Mdot
.41011 .39797 Mdot
.6202 .55392 Mdot
.58357 .30031 Mdot
.38379 .26804 Mdot
.37761 .38237 Mdot
.3975 .61448 Mdot
.39816 .39562 Mdot
.35176 .62955 Mdot
.40675 .44703 Mdot
.44718 .49061 Mdot
.56106 .2983 Mdot
.50934 .20501 Mdot
.35634 .44175 Mdot
.78259 .31361 Mdot
.50392 .37085 Mdot
.60995 .2984 Mdot
.44426 .43079 Mdot
.51195 .74473 Mdot
.64343 .57663 Mdot
.7653 .34296 Mdot
.63385 .44048 Mdot
.64079 .59097 Mdot
.38218 .65104 Mdot
.64607 .49898 Mdot
.49591 .75428 Mdot
.32033 .34695 Mdot
.58145 .33094 Mdot
.61803 .61292 Mdot
.3906 .43563 Mdot
.40097 .38276 Mdot
.74797 .36611 Mdot
.19063 .61916 Mdot
.38834 .58871 Mdot
.54956 .17525 Mdot
.37694 .67423 Mdot
.60186 .30557 Mdot
.63337 .43636 Mdot
.37283 .4397 Mdot
.40355 .41285 Mdot
.64074 .48181 Mdot
.40696 .62163 Mdot
.61751 .48792 Mdot
.24722 .36209 Mdot
.59245 .6384 Mdot
.50383 .23692 Mdot
.36773 .62976 Mdot
.50268 .23377 Mdot
.57089 .29636 Mdot
.79993 .54267 Mdot
.49979 .31524 Mdot
.6139 .6137 Mdot
.50418 .24072 Mdot
.37867 .60216 Mdot
.37794 .41263 Mdot
.51735 .743 Mdot
.49682 .73352 Mdot
.36967 .64727 Mdot
.65784 .43456 Mdot
.58642 .3308 Mdot
.40156 .40002 Mdot
.46232 .69811 Mdot
.39654 .79576 Mdot
.66791 .48268 Mdot
.4675 .38199 Mdot
.65385 .60045 Mdot
.41086 .44301 Mdot
.61693 .30435 Mdot
.63266 .59 Mdot
.52353 .74021 Mdot
.4941 .59984 Mdot
.45329 .42362 Mdot
.50184 .48688 Mdot
.62179 .61268 Mdot
.1622 .51634 Mdot
.40879 .40673 Mdot
.64513 .62081 Mdot
.33088 .45625 Mdot
.38116 .74513 Mdot
.57765 .40272 Mdot
.66251 .77579 Mdot
.67042 .41911 Mdot
.66582 .43123 Mdot
.27298 .73014 Mdot
.57921 .2696 Mdot
.62062 .56981 Mdot
.52215 .75207 Mdot
.49274 .28542 Mdot
.64585 .62603 Mdot
.41666 .38077 Mdot
.44292 .44764 Mdot
.25029 .37541 Mdot
.52 .39629 Mdot
.49125 .75453 Mdot
.34078 .35205 Mdot
.43573 .41298 Mdot
.38997 .48206 Mdot
.41147 .41864 Mdot
.40365 .65083 Mdot
.6422 .62986 Mdot
.83848 .36869 Mdot
.62483 .63173 Mdot
.47018 .68655 Mdot
.65376 .45727 Mdot
.65925 .4904 Mdot
.38555 .43618 Mdot
.43556 .65818 Mdot
.80397 .39192 Mdot
.3942 .45981 Mdot
.6206 .34402 Mdot
.42109 .25141 Mdot
.43629 .46109 Mdot
.39361 .57901 Mdot
.44146 .36799 Mdot
.35887 .66659 Mdot
.63196 .58658 Mdot
.59294 .29355 Mdot
.56932 .33522 Mdot
.63259 .61213 Mdot
.3999 .42613 Mdot
.5997 .3616 Mdot
.38664 .42757 Mdot
.38005 .40417 Mdot
.49394 .65467 Mdot
.61737 .29037 Mdot
.62822 .44596 Mdot
.59837 .31929 Mdot
.39304 .63492 Mdot
.0952 .47992 Mdot
.58733 .31646 Mdot
.4972 .38645 Mdot
.55241 .4779 Mdot
.50096 .24032 Mdot
.36625 .65807 Mdot
.60383 .2878 Mdot
.62949 .6287 Mdot
.53424 .69578 Mdot
.17529 .53737 Mdot
.65607 .62419 Mdot
.40317 .40972 Mdot
.34724 .62379 Mdot
.41269 .62403 Mdot
.63497 .63976 Mdot
.39812 .64858 Mdot
.42555 .47855 Mdot
.42612 .38859 Mdot
.61914 .5713 Mdot
.43913 .80699 Mdot
.64076 .63056 Mdot
.46614 .34118 Mdot
.44959 .41091 Mdot
.37339 .62934 Mdot
.33207 .38439 Mdot
.41752 .66097 Mdot
.49791 .73017 Mdot
.39395 .46661 Mdot
.59512 .3274 Mdot
.5191 .57251 Mdot
.6497 .45304 Mdot
.62284 .7537 Mdot
.35177 .63303 Mdot
.66113 .62629 Mdot
.38714 .65656 Mdot
.39933 .59813 Mdot
.64988 .62942 Mdot
.38556 .63607 Mdot
.40629 .39832 Mdot
.56434 .6388 Mdot
.35402 .62826 Mdot
.62179 .6014 Mdot
.59605 .3298 Mdot
.3986 .63954 Mdot
.6081 .46947 Mdot
.3751 .40937 Mdot
.62408 .43891 Mdot
.62001 .28798 Mdot
.3462 .62321 Mdot
.59858 .28679 Mdot
.65457 .47016 Mdot
.59041 .33399 Mdot
.60672 .54873 Mdot
.63979 .54856 Mdot
.47731 .6532 Mdot
.32149 .67454 Mdot
.38215 .59729 Mdot
.65568 .41103 Mdot
.36756 .439 Mdot
.38561 .39405 Mdot
.57261 .32788 Mdot
.41375 .62345 Mdot
.59502 .80347 Mdot
.32074 .39281 Mdot
.50363 .7927 Mdot
.60625 .57762 Mdot
.47048 .18816 Mdot
.52015 .67343 Mdot
.5508 .70215 Mdot
.33965 .40906 Mdot
.50743 .7359 Mdot
.38078 .42923 Mdot
.42073 .22695 Mdot
.59571 .28402 Mdot
.71205 .58538 Mdot
.34455 .43835 Mdot
.63399 .45083 Mdot
.39883 .45223 Mdot
.78224 .34348 Mdot
.39349 .35475 Mdot
.61066 .29249 Mdot
.64371 .55864 Mdot
.38996 .59256 Mdot
.61193 .30963 Mdot
.65822 .42525 Mdot
.518 .26724 Mdot
.40089 .37332 Mdot
.4359 .40778 Mdot
.63516 .4137 Mdot
.40102 .62161 Mdot
.65466 .47885 Mdot
.64562 .61883 Mdot
.59037 .31489 Mdot
.4298 .4459 Mdot
.44107 .46232 Mdot
.61311 .4313 Mdot
.61599 .62834 Mdot
.67342 .48015 Mdot
.61013 .61734 Mdot
.50983 .73647 Mdot
.3627 .44977 Mdot
.61908 .42545 Mdot
.33868 .44425 Mdot
.32951 .54253 Mdot
.48906 .64327 Mdot
.28672 .61212 Mdot
.62741 .44663 Mdot
.53648 .24683 Mdot
.6283 .60852 Mdot
.62664 .62299 Mdot
.27777 .35349 Mdot
.80341 .40125 Mdot
.58287 .47113 Mdot
.74026 .28077 Mdot
.64574 .61804 Mdot
.61796 .60477 Mdot
.67321 .44725 Mdot
.38466 .64184 Mdot
.364 .57864 Mdot
.6167 .47572 Mdot
.46687 .20613 Mdot
.38262 .60254 Mdot
.73257 .70969 Mdot
.65668 .4191 Mdot
.35071 .38826 Mdot
.48696 .74974 Mdot
.613 .29825 Mdot
.43027 .22567 Mdot
.75098 .29672 Mdot
.37516 .43649 Mdot
.2382 .30435 Mdot
.65316 .43942 Mdot
.63972 .66247 Mdot
.7802 .58893 Mdot
.36692 .38945 Mdot
.39616 .45082 Mdot
.40341 .42744 Mdot
.6227 .31165 Mdot
.30597 .62365 Mdot
.37375 .43442 Mdot
.52069 .20916 Mdot
.45683 .40474 Mdot
.73684 .30734 Mdot
.59804 .31915 Mdot
.3779 .29503 Mdot
.67619 .42106 Mdot
.44024 .74708 Mdot
.38369 .48782 Mdot
.64267 .61815 Mdot
.75461 .58632 Mdot
.63816 .57945 Mdot
.80839 .48053 Mdot
.49695 .3128 Mdot
.40464 .65043 Mdot
.41915 .42155 Mdot
.63619 .4156 Mdot
.34829 .6208 Mdot
.69574 .62385 Mdot
.11149 .43379 Mdot
.60144 .61199 Mdot
.34836 .17452 Mdot
.62186 .6221 Mdot
.49459 .73585 Mdot
.3721 .65078 Mdot
.43098 .54432 Mdot
.51537 .60371 Mdot
.39888 .63015 Mdot
.68288 .38855 Mdot
.40006 .57651 Mdot
.52383 .23546 Mdot
.41966 .62726 Mdot
.62641 .60175 Mdot
.6497 .55922 Mdot
.38205 .50246 Mdot
.36547 .44178 Mdot
.51684 .62006 Mdot
.33876 .45908 Mdot
.37507 .45616 Mdot
.63943 .45917 Mdot
.34604 .71544 Mdot
.6399 .65612 Mdot
.36384 .63599 Mdot
.60549 .59395 Mdot
.39597 .45188 Mdot
.4411 .43858 Mdot
.35952 .46648 Mdot
.39259 .24443 Mdot
.73532 .70388 Mdot
.38463 .40965 Mdot
.45795 .3879 Mdot
.64512 .42612 Mdot
.74648 .34673 Mdot
.61511 .21184 Mdot
.49833 .29292 Mdot
.39683 .38697 Mdot
.60515 .30881 Mdot
.60913 .28666 Mdot
.44806 .46268 Mdot
.44834 .68317 Mdot
.60878 .48516 Mdot
.39077 .43586 Mdot
.52619 .33311 Mdot
.60441 .43964 Mdot
.50863 .76346 Mdot
.6544 .46718 Mdot
.345 .62781 Mdot
.49704 .73664 Mdot
.66366 .48185 Mdot
.4294 .58451 Mdot
.49804 .75316 Mdot
.39584 .74928 Mdot
.59699 .28535 Mdot
.41036 .41439 Mdot
.38437 .68683 Mdot
.64044 .48053 Mdot
.62137 .6153 Mdot
.37491 .61844 Mdot
.60874 .57036 Mdot
.7496 .34901 Mdot
.44224 .2243 Mdot
.51465 .73371 Mdot
.64234 .61524 Mdot
.48624 .54167 Mdot
.60392 .31176 Mdot
.65386 .62158 Mdot
.42763 .68286 Mdot
.43953 .45597 Mdot
.82564 .46818 Mdot
.43128 .40524 Mdot
.53859 .81397 Mdot
.62921 .622 Mdot
.5042 .7259 Mdot
.39119 .42936 Mdot
.63926 .4202 Mdot
.36152 .49721 Mdot
.38727 .42557 Mdot
.68057 .45158 Mdot
.38023 .41151 Mdot
.61793 .31812 Mdot
.34751 .65678 Mdot
.56673 .44177 Mdot
.40816 .21643 Mdot
.599 .333 Mdot
.52485 .76994 Mdot
.36622 .44886 Mdot
.65059 .3348 Mdot
.39679 .62195 Mdot
.35926 .39877 Mdot
.27002 .31129 Mdot
.37476 .64478 Mdot
.38846 .61948 Mdot
.44096 .42166 Mdot
.65755 .62088 Mdot
.62881 .46498 Mdot
.60306 .31482 Mdot
.68424 .64368 Mdot
.37808 .42336 Mdot
.41678 .41539 Mdot
.61248 .31192 Mdot
.61558 .60234 Mdot
.43102 .44282 Mdot
.66197 .70438 Mdot
.50582 .69402 Mdot
.60809 .60503 Mdot
.43845 .4577 Mdot
.84329 .48909 Mdot
.35215 .58692 Mdot
.222 .31962 Mdot
.58472 .26816 Mdot
.65179 .43259 Mdot
.47552 .41029 Mdot
.20166 .74003 Mdot
.60938 .29509 Mdot
.45181 .74983 Mdot
.38578 .40348 Mdot
.37808 .45339 Mdot
.38342 .66382 Mdot
.43164 .42876 Mdot
.35858 .61644 Mdot
.41509 .20899 Mdot
.76562 .27457 Mdot
.3898 .65415 Mdot
.35505 .62151 Mdot
.41831 .53803 Mdot
.38086 .25471 Mdot
.38329 .6487 Mdot
.39929 .3729 Mdot
.68347 .38032 Mdot
.46606 .45482 Mdot
.58793 .27732 Mdot
.60284 .3513 Mdot
.41197 .60041 Mdot
.21886 .63662 Mdot
.34305 .48464 Mdot
.47696 .48064 Mdot
.63056 .27684 Mdot
.64369 .60374 Mdot
.44092 .44659 Mdot
.52054 .74026 Mdot
.67057 .46288 Mdot
.4248 .35902 Mdot
.40747 .41552 Mdot
.35089 .62259 Mdot
.62234 .31893 Mdot
.65308 .61952 Mdot
.41473 .40386 Mdot
.655 .50763 Mdot
.59437 .30048 Mdot
.35505 .62824 Mdot
.49549 .38262 Mdot
.58154 .28622 Mdot
.4235 .47541 Mdot
.37679 .45627 Mdot
.40439 .38907 Mdot
.37563 .48773 Mdot
.63168 .61426 Mdot
.62851 .49149 Mdot
.46389 .44822 Mdot
.50165 .64415 Mdot
.52711 .55798 Mdot
.46317 .44757 Mdot
.40446 .61619 Mdot
.62224 .56729 Mdot
.50167 .75282 Mdot
.49408 .25987 Mdot
.44579 .3995 Mdot
.74402 .68976 Mdot
.22666 .37127 Mdot
.49927 .7459 Mdot
.40162 .66078 Mdot
.60156 .32058 Mdot
.44099 .40996 Mdot
.63676 .36103 Mdot
.42086 .38428 Mdot
.45234 .34945 Mdot
.6517 .43537 Mdot
.64667 .60192 Mdot
.49662 .70207 Mdot
.67082 .46373 Mdot
.38785 .62027 Mdot
.57383 .83084 Mdot
.38621 .57171 Mdot
.37732 .58607 Mdot
.79329 .50132 Mdot
.63449 .58452 Mdot
.22486 .76434 Mdot
.16602 .50017 Mdot
.43197 .38723 Mdot
.62579 .57447 Mdot
.36505 .64826 Mdot
.42518 .41181 Mdot
.38168 .59888 Mdot
.36904 .58223 Mdot
.40848 .46751 Mdot
.37118 .44965 Mdot
.4978 .20678 Mdot
.72581 .72955 Mdot
.58786 .32566 Mdot
.40438 .64235 Mdot
.23905 .39455 Mdot
.3721 .43352 Mdot
.38412 .38924 Mdot
.76867 .54999 Mdot
.6073 .29045 Mdot
.21688 .56457 Mdot
.38895 .3946 Mdot
.2747 .30577 Mdot
.37708 .45892 Mdot
.3299 .66216 Mdot
.64778 .64077 Mdot
.4502 .69062 Mdot
.62946 .46989 Mdot
.34172 .62394 Mdot
.57134 .30869 Mdot
.3403 .62375 Mdot
.27225 .36319 Mdot
.63163 .58304 Mdot
.36002 .61727 Mdot
.66649 .49244 Mdot
.621 .58869 Mdot
.61356 .61441 Mdot
.58818 .43523 Mdot
.6509 .49771 Mdot
.62049 .31829 Mdot
.64588 .58279 Mdot
.22551 .43055 Mdot
.62748 .59795 Mdot
.24684 .3904 Mdot
.36283 .4144 Mdot
.50822 .21597 Mdot
.48778 .69686 Mdot
.37638 .49407 Mdot
.64632 .62862 Mdot
.58069 .31629 Mdot
.42457 .4289 Mdot
.40054 .64497 Mdot
.58492 .31323 Mdot
.59022 .6015 Mdot
.6773 .48134 Mdot
.41137 .60783 Mdot
.65388 .57063 Mdot
.36337 .60975 Mdot
.42127 .24011 Mdot
.64963 .52005 Mdot
.59423 .38331 Mdot
.51961 .59931 Mdot
.36547 .46705 Mdot
.45737 .51089 Mdot
.38185 .38254 Mdot
.4031 .41703 Mdot
.64927 .45466 Mdot
.56262 .23159 Mdot
.39962 .6379 Mdot
.45469 .82942 Mdot
.63818 .61881 Mdot
.47536 .52848 Mdot
.4212 .33187 Mdot
.40955 .45864 Mdot
.35824 .63432 Mdot
.37056 .58372 Mdot
.31801 .56664 Mdot
.64195 .48312 Mdot
.44968 .47591 Mdot
.40763 .49163 Mdot
.47249 .44907 Mdot
.61865 .62029 Mdot
.68166 .693 Mdot
.65149 .48968 Mdot
.26301 .23562 Mdot
.66249 .47251 Mdot
.66911 .31884 Mdot
.38468 .6368 Mdot
.58143 .29309 Mdot
.37899 .39252 Mdot
.33558 .58345 Mdot
.35368 .65758 Mdot
.59583 .4478 Mdot
.60284 .32219 Mdot
.70026 .68779 Mdot
.63851 .587 Mdot
.36356 .40264 Mdot
.41251 .46735 Mdot
.43831 .43111 Mdot
.4218 .39365 Mdot
.61069 .57782 Mdot
.4139 .38045 Mdot
.61821 .56281 Mdot
.20379 .46768 Mdot
.27654 .31004 Mdot
.62562 .42488 Mdot
.73689 .31602 Mdot
.40173 .6019 Mdot
.24688 .42242 Mdot
.21239 .56818 Mdot
.48836 .64694 Mdot
.60711 .53608 Mdot
.36021 .42812 Mdot
.65994 .43553 Mdot
.79037 .35001 Mdot
.62632 .42182 Mdot
.79647 .28666 Mdot
.32623 .32524 Mdot
.64803 .79136 Mdot
.42753 .40639 Mdot
.61405 .47277 Mdot
.24037 .63248 Mdot
.45049 .45352 Mdot
.59326 .3572 Mdot
.45087 .33754 Mdot
.43741 .78913 Mdot
.58201 .2895 Mdot
.37467 .41273 Mdot
.40198 .59747 Mdot
.40506 .39803 Mdot
.37261 .40141 Mdot
.39519 .45877 Mdot
.60739 .62814 Mdot
.42636 .46282 Mdot
.36688 .40796 Mdot
.17598 .59515 Mdot
.55319 .25507 Mdot
.64199 .42376 Mdot
.29951 .5852 Mdot
.5972 .30847 Mdot
.34996 .61699 Mdot
.56553 .45832 Mdot
.63971 .60353 Mdot
.32183 .55559 Mdot
.42908 .40593 Mdot
.47652 .77535 Mdot
.66139 .5947 Mdot
.58521 .30238 Mdot
.50158 .75588 Mdot
.74413 .65707 Mdot
.61958 .45585 Mdot
.49137 .74063 Mdot
.65006 .45204 Mdot
.26995 .6498 Mdot
.35193 .62636 Mdot
.36886 .47111 Mdot
.65306 .60852 Mdot
.62195 .43573 Mdot
.59185 .23132 Mdot
.40739 .43016 Mdot
.62686 .44835 Mdot
.3685 .46849 Mdot
.53109 .56119 Mdot
.55729 .48303 Mdot
.61474 .45713 Mdot
.64969 .56007 Mdot
.61895 .58692 Mdot
.57677 .30262 Mdot
.35206 .61064 Mdot
.39867 .60629 Mdot
.62923 .58939 Mdot
.26181 .2556 Mdot
.37789 .42514 Mdot
.38182 .45927 Mdot
.50565 .64946 Mdot
.42392 .40181 Mdot
.53088 .26485 Mdot
.51592 .76677 Mdot
.3781 .59621 Mdot
.4199 .39528 Mdot
.43171 .44294 Mdot
.45218 .4271 Mdot
.44363 .2258 Mdot
.65743 .46642 Mdot
.43672 .41267 Mdot
.5898 .33733 Mdot
.41069 .71753 Mdot
.36683 .43409 Mdot
.4304 .46941 Mdot
.36341 .61168 Mdot
.50234 .17648 Mdot
.62608 .61901 Mdot
.63206 .46102 Mdot
.65924 .41993 Mdot
.41893 .2755 Mdot
.3353 .63513 Mdot
.50414 .76625 Mdot
.74152 .46441 Mdot
.51702 .75798 Mdot
.60941 .29988 Mdot
.59451 .40295 Mdot
.65501 .50957 Mdot
.65797 .42339 Mdot
.63775 .54942 Mdot
.41619 .39333 Mdot
.37762 .45877 Mdot
.45189 .7443 Mdot
.39503 .46321 Mdot
.59968 .32689 Mdot
.6522 .5708 Mdot
.36394 .61276 Mdot
.61687 .31163 Mdot
.62932 .62504 Mdot
.40146 .62138 Mdot
.45016 .44634 Mdot
.36307 .47292 Mdot
.38026 .61692 Mdot
.35339 .64161 Mdot
.38501 .44321 Mdot
.23648 .67872 Mdot
.38323 .59418 Mdot
.36225 .62476 Mdot
.494 .72453 Mdot
.61873 .45298 Mdot
.35501 .36173 Mdot
.62744 .57568 Mdot
.39896 .39077 Mdot
.62396 .42616 Mdot
.59435 .28892 Mdot
.38464 .61066 Mdot
.44779 .43298 Mdot
.38441 .41659 Mdot
.60556 .3103 Mdot
.60846 .28169 Mdot
.60304 .32863 Mdot
.59834 .61051 Mdot
.42889 .39267 Mdot
.38721 .64832 Mdot
.63757 .58378 Mdot
.60724 .28579 Mdot
.58629 .34251 Mdot
.17385 .58065 Mdot
.3766 .43618 Mdot
.61748 .36401 Mdot
.09739 .53408 Mdot
.5162 .27576 Mdot
.49324 .74531 Mdot
.61147 .44889 Mdot
.51838 .21726 Mdot
.6066 .26803 Mdot
.6288 .57119 Mdot
.52974 .35207 Mdot
.61867 .33492 Mdot
.40955 .46494 Mdot
.41353 .44143 Mdot
.35124 .39243 Mdot
.59125 .30667 Mdot
.43033 .23543 Mdot
.411 .62112 Mdot
.24906 .50969 Mdot
.59704 .30852 Mdot
.61489 .45837 Mdot
.61502 .43285 Mdot
.6624 .47405 Mdot
.35912 .42458 Mdot
.30378 .59619 Mdot
.22925 .41176 Mdot
.22543 .56441 Mdot
.64018 .59068 Mdot
.3778 .58181 Mdot
.60841 .52971 Mdot
.38905 .61881 Mdot
.66807 .45428 Mdot
.58992 .30275 Mdot
.39194 .66114 Mdot
.6112 .6004 Mdot
.61449 .5932 Mdot
.68175 .47103 Mdot
.65098 .46979 Mdot
.63856 .46984 Mdot
.34352 .62092 Mdot
.3855 .63634 Mdot
.43406 .44504 Mdot
.37535 .61096 Mdot
.19964 .40271 Mdot
.58809 .27585 Mdot
.64156 .41226 Mdot
.62404 .61189 Mdot
.35546 .63617 Mdot
.41042 .41119 Mdot
.70973 .33965 Mdot
.59904 .43553 Mdot
.60493 .33207 Mdot
.55077 .60143 Mdot
.69049 .19989 Mdot
.40788 .4715 Mdot
.60712 .61587 Mdot
.44134 .68579 Mdot
.40283 .43516 Mdot
.6396 .43625 Mdot
.31403 .31705 Mdot
.5084 .76171 Mdot
.3664 .41766 Mdot
.3512 .41402 Mdot
.65052 .62792 Mdot
.56236 .46808 Mdot
.40155 .46325 Mdot
.52068 .48151 Mdot
.6073 .62311 Mdot
.65309 .4897 Mdot
.30138 .773 Mdot
.59094 .63235 Mdot
.51654 .19937 Mdot
.49525 .74707 Mdot
.4156 .46463 Mdot
.64159 .45741 Mdot
.60341 .33593 Mdot
.64614 .4621 Mdot
.41493 .64307 Mdot
.62302 .44496 Mdot
.41202 .42792 Mdot
.38926 .64595 Mdot
.6164 .60842 Mdot
.48382 .51016 Mdot
.19928 .62353 Mdot
.64068 .42049 Mdot
.52648 .75013 Mdot
.36846 .42698 Mdot
.20535 .49426 Mdot
.3854 .50502 Mdot
.36359 .43715 Mdot
.63988 .58021 Mdot
.36025 .63552 Mdot
.60865 .57372 Mdot
.41608 .47284 Mdot
.28139 .38372 Mdot
.63779 .61698 Mdot
.40458 .77203 Mdot
.61304 .30873 Mdot
.46381 .20741 Mdot
.397 .41782 Mdot
.65258 .60853 Mdot
.43014 .39295 Mdot
.40558 .64095 Mdot
.50696 .56685 Mdot
.41394 .7094 Mdot
.65346 .59867 Mdot
.554 .82166 Mdot
.53914 .50585 Mdot
.3788 .35331 Mdot
.64828 .61869 Mdot
.2918 .62847 Mdot
.51062 .74757 Mdot
.60052 .29749 Mdot
.61053 .28538 Mdot
.5767 .32817 Mdot
.39347 .46332 Mdot
.48163 .43678 Mdot
.59977 .34443 Mdot
.59843 .60082 Mdot
.60696 .33845 Mdot
.39685 .25081 Mdot
.5742 .80854 Mdot
.60661 .32755 Mdot
.39674 .41362 Mdot
.43478 .4654 Mdot
.55591 .25309 Mdot
.64616 .4926 Mdot
.75308 .66882 Mdot
.1772 .4961 Mdot
.3735 .44167 Mdot
.33141 .33069 Mdot
.41659 .62453 Mdot
.4538 .61709 Mdot
.3225 .37396 Mdot
.57594 .4574 Mdot
.35856 .6275 Mdot
.53778 .56989 Mdot
.37123 .59772 Mdot
.38453 .47717 Mdot
.38854 .40772 Mdot
.3519 .65849 Mdot
.61289 .74856 Mdot
.34425 .75631 Mdot
.52416 .80079 Mdot
.40167 .60813 Mdot
.6433 .62407 Mdot
.6054 .61699 Mdot
.64274 .58693 Mdot
.63724 .47574 Mdot
.35173 .64319 Mdot
.4407 .40202 Mdot
.65782 .42751 Mdot
.3843 .39187 Mdot
.62501 .58219 Mdot
.50617 .69524 Mdot
.36257 .61359 Mdot
.39248 .4342 Mdot
.17803 .54484 Mdot
.65709 .45324 Mdot
.60362 .30924 Mdot
.55304 .62891 Mdot
.61033 .44491 Mdot
.62895 .63247 Mdot
.33547 .61527 Mdot
.65817 .40153 Mdot
.67361 .28909 Mdot
.38973 .37107 Mdot
.40692 .37333 Mdot
.68105 .57321 Mdot
.1922 .59654 Mdot
.40216 .45793 Mdot
.65955 .42548 Mdot
.61671 .45736 Mdot
.42944 .3895 Mdot
.37869 .66059 Mdot
.61381 .33892 Mdot
.57182 .32449 Mdot
.35494 .44708 Mdot
.52004 .60933 Mdot
.50621 .21146 Mdot
.42965 .43591 Mdot
.43628 .34613 Mdot
.66567 .49152 Mdot
.49561 .75328 Mdot
.50369 .61769 Mdot
.5732 .31256 Mdot
.38516 .40209 Mdot
.36024 .76654 Mdot
.35798 .62088 Mdot
.62707 .4587 Mdot
.6119 .58516 Mdot
.5882 .35644 Mdot
.67299 .42665 Mdot
.42962 .38963 Mdot
.43134 .44271 Mdot
.65561 .61354 Mdot
.33173 .66706 Mdot
.58903 .30577 Mdot
.65386 .42678 Mdot
.58067 .29386 Mdot
.39125 .63267 Mdot
.36309 .62045 Mdot
.41259 .49064 Mdot
.37446 .49575 Mdot
.65495 .41956 Mdot
.35039 .40193 Mdot
.66813 .4721 Mdot
.74794 .36237 Mdot
.60709 .59551 Mdot
.36217 .39388 Mdot
.35611 .67673 Mdot
.62615 .58311 Mdot
.38014 .45001 Mdot
.68038 .57414 Mdot
.42239 .44758 Mdot
.61568 .47511 Mdot
.28123 .33738 Mdot
.58301 .29968 Mdot
.45591 .50924 Mdot
.38805 .5342 Mdot
.42372 .40298 Mdot
.63571 .49253 Mdot
.46581 .47195 Mdot
.63665 .61418 Mdot
.37449 .63924 Mdot
.41664 .16882 Mdot
.62344 .59929 Mdot
.39838 .40036 Mdot
.58804 .31494 Mdot
.38658 .59005 Mdot
.50972 .73289 Mdot
.51724 .65012 Mdot
.40966 .35609 Mdot
.34353 .39079 Mdot
.41069 .39385 Mdot
.74041 .27958 Mdot
.63914 .46448 Mdot
.35912 .6425 Mdot
.60419 .60818 Mdot
.63526 .59439 Mdot
.6628 .45915 Mdot
.46375 .79708 Mdot
.63377 .7605 Mdot
.10514 .57982 Mdot
.66861 .42598 Mdot
.59408 .34126 Mdot
.52261 .55177 Mdot
.67141 .46502 Mdot
.63614 .45647 Mdot
.68117 .47758 Mdot
.46546 .74293 Mdot
.40366 .62221 Mdot
.38286 .41642 Mdot
.33623 .64305 Mdot
.41172 .4656 Mdot
.57285 .21803 Mdot
.631 .58797 Mdot
.37682 .63904 Mdot
.66566 .52744 Mdot
.32797 .44401 Mdot
.40111 .44519 Mdot
.63914 .3698 Mdot
.41652 .361 Mdot
.50115 .24897 Mdot
.37007 .47942 Mdot
.65228 .46224 Mdot
.31207 .36795 Mdot
.47094 .39968 Mdot
.17917 .51946 Mdot
.61308 .6009 Mdot
.50697 .7293 Mdot
.45606 .43703 Mdot
.42236 .35016 Mdot
.38145 .58856 Mdot
.39095 .66188 Mdot
.60182 .34453 Mdot
.5615 .6459 Mdot
.6138 .60446 Mdot
.68561 .73464 Mdot
.36552 .4445 Mdot
.66285 .65453 Mdot
.27815 .33742 Mdot
.38378 .44956 Mdot
.6037 .39938 Mdot
.32117 .5581 Mdot
.4112 .45653 Mdot
.23428 .56126 Mdot
.62459 .60796 Mdot
.27327 .30777 Mdot
.34611 .43282 Mdot
.6394 .43724 Mdot
.38295 .64128 Mdot
.41141 .60895 Mdot
.60991 .32847 Mdot
.18191 .44318 Mdot
.66017 .56317 Mdot
.38249 .63824 Mdot
.40541 .42672 Mdot
.62413 .61667 Mdot
.50313 .72939 Mdot
.3593 .3714 Mdot
.80014 .44648 Mdot
.3712 .61106 Mdot
.47196 .43129 Mdot
.51382 .79892 Mdot
.54679 .51614 Mdot
.73413 .72079 Mdot
.64636 .5908 Mdot
.57249 .31409 Mdot
.35498 .47034 Mdot
.74002 .46597 Mdot
.34723 .44241 Mdot
.54656 .20819 Mdot
.42069 .65963 Mdot
.59338 .28557 Mdot
.39996 .43429 Mdot
.4022 .46266 Mdot
.51785 .5836 Mdot
.60147 .27968 Mdot
.40274 .46351 Mdot
.44202 .47733 Mdot
.39982 .61726 Mdot
.51911 .76549 Mdot
.369 .60928 Mdot
.40433 .40902 Mdot
.35451 .30847 Mdot
.38926 .66008 Mdot
.73464 .67639 Mdot
.5707 .27012 Mdot
.64006 .60441 Mdot
.45557 .36463 Mdot
.3622 .42257 Mdot
.8473 .57317 Mdot
.49731 .73068 Mdot
.56395 .18675 Mdot
.61166 .46083 Mdot
.41041 .82507 Mdot
.60904 .44335 Mdot
.6204 .81191 Mdot
.48242 .52578 Mdot
.36369 .385 Mdot
.51453 .33472 Mdot
.22787 .5551 Mdot
.62619 .55406 Mdot
.22441 .45605 Mdot
.36547 .44152 Mdot
.37254 .42038 Mdot
.66918 .43933 Mdot
.48104 .79877 Mdot
.4427 .69216 Mdot
.50806 .60962 Mdot
.58921 .29915 Mdot
.38503 .6305 Mdot
.41168 .43343 Mdot
.58476 .72235 Mdot
.63405 .42632 Mdot
.49008 .35407 Mdot
.39245 .43107 Mdot
.46422 .68577 Mdot
.43808 .77307 Mdot
.61947 .61528 Mdot
.61597 .46969 Mdot
.63242 .49346 Mdot
.43957 .45078 Mdot
.62078 .5721 Mdot
.42491 .45259 Mdot
.53626 .50939 Mdot
.45515 .38529 Mdot
.60307 .29103 Mdot
.37963 .39034 Mdot
.52214 .36368 Mdot
.61262 .83023 Mdot
.4571 .37892 Mdot
.36539 .59526 Mdot
.64321 .47845 Mdot
.66163 .46756 Mdot
.39869 .6058 Mdot
.66272 .46662 Mdot
.25078 .52033 Mdot
.26668 .3792 Mdot
.60817 .29565 Mdot
.20865 .57492 Mdot
.58752 .29647 Mdot
.50872 .72979 Mdot
.37869 .43945 Mdot
.75083 .47342 Mdot
.66831 .42527 Mdot
.35194 .26905 Mdot
.62976 .59592 Mdot
.49641 .73195 Mdot
.44856 .39748 Mdot
.6291 .35329 Mdot
.66619 .44536 Mdot
.74298 .61902 Mdot
.45076 .43047 Mdot
.40554 .63316 Mdot
.40797 .45875 Mdot
.43219 .37297 Mdot
.49183 .74438 Mdot
.41145 .39321 Mdot
.62954 .6251 Mdot
.35095 .64316 Mdot
.62543 .80465 Mdot
.63898 .47892 Mdot
.36958 .41486 Mdot
.40473 .42823 Mdot
.39164 .66325 Mdot
.44899 .39556 Mdot
.62943 .57246 Mdot
.28437 .81814 Mdot
.61241 .30596 Mdot
.49673 .75545 Mdot
.73719 .64525 Mdot
.41727 .42935 Mdot
.42578 .43359 Mdot
.68679 .61086 Mdot
.33134 .73053 Mdot
.63776 .6214 Mdot
.4562 .3986 Mdot
.64067 .42776 Mdot
.58467 .30959 Mdot
.64299 .57582 Mdot
.42591 .38943 Mdot
.37261 .42237 Mdot
.60783 .29298 Mdot
.63932 .36684 Mdot
.61024 .47823 Mdot
.641 .5887 Mdot
.34116 .32944 Mdot
.71645 .34557 Mdot
.3823 .427 Mdot
.54368 .79109 Mdot
.3648 .62687 Mdot
.64843 .61449 Mdot
.305 .63221 Mdot
.37339 .47173 Mdot
.63395 .63163 Mdot
.61546 .60665 Mdot
.45312 .40692 Mdot
.33449 .6327 Mdot
.35081 .59971 Mdot
.36277 .62732 Mdot
.29196 .30431 Mdot
.65436 .24122 Mdot
.63698 .46948 Mdot
.62102 .60751 Mdot
.62161 .4254 Mdot
.60275 .3474 Mdot
.52702 .5604 Mdot
.61587 .45608 Mdot
.40258 .60182 Mdot
.6282 .41692 Mdot
.42509 .4496 Mdot
.61264 .59176 Mdot
.66451 .42587 Mdot
.42557 .41802 Mdot
.45026 .35416 Mdot
.51995 .35669 Mdot
.61865 .33035 Mdot
.53618 .5741 Mdot
.40135 .40343 Mdot
.50007 .75299 Mdot
.38647 .44035 Mdot
.61959 .57081 Mdot
.53097 .37763 Mdot
.43228 .41137 Mdot
.6646 .42183 Mdot
.68216 .28795 Mdot
.63246 .48834 Mdot
.44083 .38032 Mdot
.40348 .40861 Mdot
.37978 .42721 Mdot
.39382 .46581 Mdot
.4202 .78161 Mdot
.61929 .56147 Mdot
.47269 .37528 Mdot
.68256 .44076 Mdot
.38703 .61528 Mdot
.40287 .64932 Mdot
.58508 .4784 Mdot
.49205 .73232 Mdot
.62238 .57323 Mdot
.37934 .42567 Mdot
.74324 .6179 Mdot
.53026 .68421 Mdot
.53219 .80381 Mdot
.58664 .45406 Mdot
.66083 .42514 Mdot
.36087 .59698 Mdot
.67824 .46298 Mdot
.42384 .38584 Mdot
.36749 .47817 Mdot
.64212 .79359 Mdot
.59993 .62344 Mdot
.59008 .30415 Mdot
.38544 .39066 Mdot
.48831 .20159 Mdot
.64522 .4261 Mdot
.66211 .49387 Mdot
.42825 .45154 Mdot
.37012 .57854 Mdot
.69617 .77956 Mdot
.61512 .57718 Mdot
.20696 .48354 Mdot
.38782 .69481 Mdot
.42644 .3299 Mdot
.6335 .61039 Mdot
.5878 .39134 Mdot
.64279 .48923 Mdot
.17871 .47841 Mdot
.38019 .61494 Mdot
.59347 .30307 Mdot
.44609 .46905 Mdot
.40211 .6011 Mdot
.61628 .42567 Mdot
.35897 .60766 Mdot
.37165 .47351 Mdot
.59996 .5942 Mdot
.665 .46888 Mdot
.63054 .55901 Mdot
.34988 .65464 Mdot
.58547 .29787 Mdot
.36566 .26935 Mdot
.20566 .47743 Mdot
.3214 .55804 Mdot
.43721 .4124 Mdot
.76788 .49049 Mdot
.44211 .40165 Mdot
.37099 .58603 Mdot
.39709 .41701 Mdot
.47428 .49876 Mdot
.66013 .49004 Mdot
.47225 .42065 Mdot
.37133 .39686 Mdot
.18852 .48467 Mdot
.39275 .45019 Mdot
.44418 .39415 Mdot
.35046 .43182 Mdot
.35153 .69122 Mdot
.4688 .43262 Mdot
.40466 .63456 Mdot
.45646 .75459 Mdot
.63686 .45423 Mdot
.57868 .33985 Mdot
.56941 .30705 Mdot
.53977 .20513 Mdot
.47154 .2054 Mdot
.46757 .79392 Mdot
.38634 .60397 Mdot
.63176 .62879 Mdot
.42682 .45055 Mdot
.28461 .64571 Mdot
.44189 .30979 Mdot
.64647 .48946 Mdot
.64524 .41678 Mdot
.41084 .49363 Mdot
.79207 .32524 Mdot
.47041 .43081 Mdot
.51351 .66206 Mdot
.40235 .46584 Mdot
.35748 .3999 Mdot
.66172 .49576 Mdot
.42157 .23599 Mdot
.43665 .4125 Mdot
.38174 .58882 Mdot
.59881 .30157 Mdot
.32483 .34289 Mdot
.41336 .29848 Mdot
.43481 .32206 Mdot
.43397 .62791 Mdot
.42528 .39311 Mdot
.65165 .42915 Mdot
.39651 .59744 Mdot
.50301 .6366 Mdot
.6385 .58267 Mdot
.51664 .63026 Mdot
.21187 .44887 Mdot
.58391 .62386 Mdot
.59407 .30084 Mdot
.59361 .46696 Mdot
.41252 .42673 Mdot
.63697 .47465 Mdot
.39594 .47518 Mdot
.53415 .68423 Mdot
.59527 .28752 Mdot
.34052 .63284 Mdot
.64234 .62462 Mdot
.40761 .6192 Mdot
.28846 .60925 Mdot
.42891 .30735 Mdot
.41088 .82589 Mdot
.62007 .45915 Mdot
.30262 .4427 Mdot
.37181 .64742 Mdot
.45108 .41176 Mdot
.10456 .57013 Mdot
.36779 .62855 Mdot
.40702 .6231 Mdot
.5749 .45288 Mdot
.38917 .26639 Mdot
.47453 .40592 Mdot
.36935 .6002 Mdot
.67079 .41572 Mdot
.59544 .32279 Mdot
.42752 .42429 Mdot
.35796 .44924 Mdot
.38739 .66275 Mdot
.66612 .44891 Mdot
.49 .1978 Mdot
.6521 .46656 Mdot
.40167 .63034 Mdot
.65093 .4459 Mdot
.72434 .67866 Mdot
.62807 .43363 Mdot
.36966 .39779 Mdot
.3803 .42533 Mdot
.77866 .42383 Mdot
.36316 .6204 Mdot
.42483 .43105 Mdot
.38245 .40822 Mdot
.38124 .64959 Mdot
.66288 .50705 Mdot
.33691 .55656 Mdot
.42222 .41629 Mdot
.38048 .42083 Mdot
.59228 .28421 Mdot
.54304 .54464 Mdot
.56326 .7308 Mdot
.4265 .42674 Mdot
.58009 .33275 Mdot
.34408 .61924 Mdot
.38708 .4422 Mdot
.42139 .23373 Mdot
.60582 .437 Mdot
.41142 .38195 Mdot
.51437 .73538 Mdot
.39737 .45873 Mdot
.68862 .78501 Mdot
.36968 .42149 Mdot
.36958 .65093 Mdot
.37746 .64441 Mdot
.60214 .46268 Mdot
.386 .62121 Mdot
.49423 .74093 Mdot
.62198 .58523 Mdot
.52615 .82011 Mdot
.49611 .73642 Mdot
.36121 .39928 Mdot
.16588 .49942 Mdot
.35814 .45301 Mdot
.45587 .44605 Mdot
.37028 .26081 Mdot
.49577 .74353 Mdot
.36175 .63876 Mdot
.61482 .74456 Mdot
.37449 .38063 Mdot
.61694 .57481 Mdot
.44679 .45716 Mdot
.4104 .38138 Mdot
.51803 .40923 Mdot
.28229 .36522 Mdot
.64973 .56692 Mdot
.35849 .36066 Mdot
.42795 .42548 Mdot
.32184 .71695 Mdot
.40962 .42294 Mdot
.60865 .3266 Mdot
.38702 .60053 Mdot
.67741 .4692 Mdot
.60939 .30854 Mdot
.41458 .42941 Mdot
.59366 .30718 Mdot
.63473 .46694 Mdot
.64979 .58963 Mdot
.38451 .38826 Mdot
.5857 .27949 Mdot
.58758 .304 Mdot
.44622 .42613 Mdot
.38052 .63978 Mdot
.39037 .5094 Mdot
.38671 .44421 Mdot
.43431 .39208 Mdot
.39845 .60613 Mdot
.17007 .38963 Mdot
.41987 .46456 Mdot
.5921 .39107 Mdot
.37737 .67227 Mdot
.49789 .76153 Mdot
.67766 .45276 Mdot
.33989 .44448 Mdot
.6352 .58916 Mdot
.62659 .58669 Mdot
.68721 .45746 Mdot
.36414 .66143 Mdot
.66716 .46524 Mdot
.37328 .3594 Mdot
.40696 .49437 Mdot
.44216 .47352 Mdot
.41932 .16833 Mdot
.74548 .65358 Mdot
.3628 .65268 Mdot
.6401 .49047 Mdot
.51583 .61623 Mdot
.61973 .57676 Mdot
.68734 .47161 Mdot
.36981 .67808 Mdot
.34841 .63019 Mdot
.39426 .59855 Mdot
.57642 .32056 Mdot
.65409 .47406 Mdot
.41926 .65709 Mdot
.34685 .60124 Mdot
.43922 .4426 Mdot
.42891 .42506 Mdot
.40999 .59035 Mdot
.54969 .26411 Mdot
.59441 .29064 Mdot
.64702 .43209 Mdot
.83253 .63717 Mdot
.61445 .57765 Mdot
.18757 .48693 Mdot
.42499 .41766 Mdot
.11822 .39073 Mdot
.46703 .43804 Mdot
.40671 .42572 Mdot
.34491 .62814 Mdot
.5663 .30835 Mdot
.59412 .31975 Mdot
.37294 .64725 Mdot
.35051 .59205 Mdot
.58355 .33046 Mdot
.5893 .42487 Mdot
.53452 .8336 Mdot
.50747 .63038 Mdot
.37681 .6527 Mdot
.19913 .50327 Mdot
.64583 .57931 Mdot
.355 .66711 Mdot
.63958 .56044 Mdot
.63514 .45534 Mdot
.6368 .41932 Mdot
.65647 .61001 Mdot
.45229 .4106 Mdot
.62404 .44876 Mdot
.43548 .36257 Mdot
.6942 .74594 Mdot
.81294 .50495 Mdot
.30139 .72837 Mdot
.36712 .45296 Mdot
.44869 .68622 Mdot
.42509 .7356 Mdot
.41607 .39994 Mdot
.32587 .39314 Mdot
.59131 .305 Mdot
.36132 .66941 Mdot
.63232 .56639 Mdot
.75892 .67368 Mdot
.38136 .4267 Mdot
.39988 .63724 Mdot
.61531 .5834 Mdot
.71857 .67821 Mdot
.52332 .47796 Mdot
.42172 .45924 Mdot
.12782 .64288 Mdot
.34801 .65061 Mdot
.677 .46985 Mdot
.19246 .57033 Mdot
.33827 .65211 Mdot
.70923 .32872 Mdot
.63117 .49481 Mdot
.54064 .7346 Mdot
.34927 .62262 Mdot
.64013 .50914 Mdot
.39152 .62934 Mdot
.61779 .31643 Mdot
.33436 .61749 Mdot
.66043 .44997 Mdot
.39763 .44145 Mdot
.66052 .4542 Mdot
.61223 .29517 Mdot
.62477 .46276 Mdot
.63339 .56703 Mdot
.49632 .74923 Mdot
.61641 .5874 Mdot
.52833 .55476 Mdot
.30122 .47326 Mdot
.64661 .60137 Mdot
.75793 .59408 Mdot
.40563 .45517 Mdot
.32885 .65835 Mdot
.67882 .4701 Mdot
.65764 .41382 Mdot
.52781 .5948 Mdot
.39836 .63208 Mdot
.65657 .44298 Mdot
.21508 .44973 Mdot
.23684 .27524 Mdot
.46044 .37478 Mdot
.66508 .2485 Mdot
.38126 .6505 Mdot
.66173 .49028 Mdot
.5072 .65158 Mdot
.41361 .62822 Mdot
.6593 .42158 Mdot
.64838 .6205 Mdot
.63647 .5984 Mdot
.45311 .4285 Mdot
.64255 .64041 Mdot
.6383 .49434 Mdot
.35314 .7582 Mdot
.3903 .60049 Mdot
.7242 .65742 Mdot
.59987 .33227 Mdot
.63452 .46011 Mdot
.47377 .40954 Mdot
.42835 .62004 Mdot
.65212 .41562 Mdot
.80383 .41906 Mdot
.8491 .59936 Mdot
.65559 .44205 Mdot
.38584 .6004 Mdot
.3876 .61125 Mdot
.46015 .38235 Mdot
.51718 .60265 Mdot
.66316 .44449 Mdot
.75215 .46901 Mdot
.55194 .21307 Mdot
.50959 .73616 Mdot
.16978 .54989 Mdot
.43622 .41151 Mdot
.42322 .3904 Mdot
.63367 .57541 Mdot
.40305 .44685 Mdot
.36496 .5837 Mdot
.45841 .45309 Mdot
.6035 .61626 Mdot
.65034 .48924 Mdot
.37896 .43388 Mdot
.5811 .31858 Mdot
.63188 .57143 Mdot
.62871 .63496 Mdot
.64382 .44757 Mdot
.38198 .59682 Mdot
.59728 .75594 Mdot
.65229 .46807 Mdot
.42913 .39484 Mdot
.50302 .74386 Mdot
.35924 .46596 Mdot
.77427 .44019 Mdot
.41023 .61775 Mdot
.67748 .46521 Mdot
.39843 .66402 Mdot
.61879 .60204 Mdot
.68191 .43023 Mdot
.4134 .41589 Mdot
.65179 .4206 Mdot
.58662 .38313 Mdot
.66777 .35659 Mdot
.34931 .59661 Mdot
.62814 .32233 Mdot
.392 .66206 Mdot
.50973 .73576 Mdot
.4558 .27573 Mdot
.59974 .29511 Mdot
.62846 .43741 Mdot
.74464 .67134 Mdot
.68332 .46222 Mdot
.3901 .45151 Mdot
.37416 .45229 Mdot
.67124 .44232 Mdot
.57662 .30996 Mdot
.44162 .20236 Mdot
.62425 .26096 Mdot
.35305 .6277 Mdot
.46686 .55107 Mdot
.8005 .67922 Mdot
.69267 .43111 Mdot
.63835 .62934 Mdot
.37863 .34511 Mdot
.4192 .44732 Mdot
.64903 .6293 Mdot
.60602 .59344 Mdot
.60871 .28703 Mdot
.63415 .47128 Mdot
.4037 .66773 Mdot
.65241 .58744 Mdot
.35891 .52141 Mdot
.44826 .21313 Mdot
.41935 .36407 Mdot
.46241 .46877 Mdot
.36134 .41393 Mdot
.54684 .51851 Mdot
.60293 .58842 Mdot
.39624 .40634 Mdot
.39521 .49431 Mdot
.64604 .61523 Mdot
.61528 .30021 Mdot
.38677 .55438 Mdot
.64615 .43945 Mdot
.18467 .31581 Mdot
.38288 .38882 Mdot
.39363 .44371 Mdot
.64011 .59096 Mdot
.20457 .61823 Mdot
.37305 .65586 Mdot
.37793 .59836 Mdot
.63886 .46547 Mdot
.5323 .6047 Mdot
.44056 .38812 Mdot
.41121 .4003 Mdot
.62929 .44182 Mdot
.50002 .75168 Mdot
.28148 .73256 Mdot
.3864 .41629 Mdot
.62792 .61089 Mdot
.75218 .59009 Mdot
.60473 .58242 Mdot
.40603 .47216 Mdot
.38699 .45311 Mdot
.37787 .3882 Mdot
.38689 .46629 Mdot
.65623 .59981 Mdot
.41461 .40228 Mdot
.35476 .48957 Mdot
.36113 .63332 Mdot
.43073 .40338 Mdot
.5288 .20813 Mdot
.38627 .42118 Mdot
.5817 .31781 Mdot
.56864 .73922 Mdot
.37202 .41182 Mdot
.42977 .40028 Mdot
.62907 .26784 Mdot
.40082 .4288 Mdot
.61055 .60651 Mdot
.38223 .61268 Mdot
.61895 .60615 Mdot
.62021 .62089 Mdot
.63745 .41482 Mdot
.61748 .29489 Mdot
.34371 .42886 Mdot
.58485 .3331 Mdot
.4556 .38313 Mdot
.37569 .47417 Mdot
.53596 .55348 Mdot
.51438 .66312 Mdot
.61153 .27013 Mdot
.41258 .40983 Mdot
.63971 .46011 Mdot
.67937 .455 Mdot
.52962 .3457 Mdot
.43969 .36677 Mdot
.64398 .57562 Mdot
.65257 .60906 Mdot
.52915 .27044 Mdot
.52388 .44234 Mdot
.582 .31052 Mdot
.49245 .59068 Mdot
.35774 .44022 Mdot
.37776 .40953 Mdot
.43803 .46342 Mdot
.61454 .44477 Mdot
.49644 .7522 Mdot
.64808 .48806 Mdot
.51173 .7227 Mdot
.6133 .56781 Mdot
.36657 .45191 Mdot
.80673 .53873 Mdot
.37117 .66126 Mdot
.38073 .61247 Mdot
.60574 .6204 Mdot
.63357 .48957 Mdot
.44723 .37424 Mdot
.44543 .15144 Mdot
.40071 .58822 Mdot
.57481 .33296 Mdot
.40608 .39985 Mdot
.64178 .45066 Mdot
.3519 .64777 Mdot
.61758 .28691 Mdot
.36332 .44585 Mdot
.68206 .48314 Mdot
.39263 .41958 Mdot
.23507 .58136 Mdot
.36625 .63806 Mdot
.5087 .69529 Mdot
.38094 .57249 Mdot
.6457 .62926 Mdot
.63169 .62273 Mdot
.38139 .45094 Mdot
.33419 .19601 Mdot
.39393 .56743 Mdot
.65931 .61957 Mdot
.61844 .32218 Mdot
.49974 .75698 Mdot
.6207 .308 Mdot
.67018 .46955 Mdot
.59735 .30014 Mdot
.66 .42009 Mdot
.53813 .28617 Mdot
.42135 .62147 Mdot
.61105 .30572 Mdot
.20768 .62881 Mdot
.36166 .4716 Mdot
.6037 .28348 Mdot
.41487 .49294 Mdot
.40998 .53739 Mdot
.63047 .44403 Mdot
.57753 .3146 Mdot
.44813 .43131 Mdot
.77592 .61892 Mdot
.62612 .62299 Mdot
.64123 .57268 Mdot
.34576 .43871 Mdot
.67291 .4858 Mdot
.34353 .60245 Mdot
.56168 .4518 Mdot
.50156 .76369 Mdot
.411 .401 Mdot
.36122 .44515 Mdot
.37073 .66737 Mdot
.3823 .58567 Mdot
.38372 .45379 Mdot
.22311 .43986 Mdot
.41344 .42537 Mdot
.63689 .60296 Mdot
.35106 .63849 Mdot
.38349 .61048 Mdot
.62053 .47922 Mdot
.36497 .66158 Mdot
.46774 .4538 Mdot
.63862 .54514 Mdot
.41867 .48471 Mdot
.62061 .59926 Mdot
.53545 .37531 Mdot
.6341 .4742 Mdot
.75643 .66569 Mdot
.35539 .65493 Mdot
.41893 .3937 Mdot
.4 .65226 Mdot
.60267 .32838 Mdot
.36408 .61889 Mdot
.41686 .61854 Mdot
.36757 .44523 Mdot
.41692 .4636 Mdot
.50123 .7488 Mdot
.52042 .60452 Mdot
.37195 .63589 Mdot
.4193 .41475 Mdot
.34709 .42995 Mdot
.43326 .45725 Mdot
.54047 .50476 Mdot
.34672 .62072 Mdot
.25395 .37369 Mdot
.79418 .46477 Mdot
.37872 .63761 Mdot
.76402 .69403 Mdot
.52116 .75271 Mdot
.49166 .73193 Mdot
.66198 .61664 Mdot
.38226 .41758 Mdot
.66586 .46326 Mdot
.4167 .38423 Mdot
.42849 .3598 Mdot
.37063 .41107 Mdot
.60476 .28918 Mdot
.37179 .37512 Mdot
.51755 .74907 Mdot
.65539 .4639 Mdot
.41881 .42258 Mdot
.37596 .43054 Mdot
.49417 .72879 Mdot
.38485 .57081 Mdot
.3493 .62841 Mdot
.54969 .78303 Mdot
.61529 .30767 Mdot
.63924 .58071 Mdot
.42067 .38597 Mdot
.63961 .46248 Mdot
.66223 .46074 Mdot
.40754 .62131 Mdot
.64344 .43618 Mdot
.62202 .56873 Mdot
.40862 .42922 Mdot
.65028 .6274 Mdot
.60535 .28962 Mdot
.38763 .60066 Mdot
.42319 .38644 Mdot
.44096 .44161 Mdot
.37706 .64441 Mdot
.40308 .45706 Mdot
.59083 .28491 Mdot
.62257 .43303 Mdot
.35332 .6356 Mdot
.62288 .58574 Mdot
.61662 .46979 Mdot
.42821 .44637 Mdot
.8617 .49573 Mdot
.40401 .44709 Mdot
.39943 .38837 Mdot
.56647 .82655 Mdot
.37376 .48148 Mdot
.66759 .48254 Mdot
.40173 .65221 Mdot
.41838 .46886 Mdot
.57537 .22142 Mdot
.70662 .4803 Mdot
.68418 .48309 Mdot
.40608 .39733 Mdot
.74281 .70124 Mdot
.42117 .39638 Mdot
.71103 .69429 Mdot
.5348 .55578 Mdot
.75356 .30493 Mdot
.45125 .48308 Mdot
.65685 .62438 Mdot
.49912 .74903 Mdot
.6793 .47312 Mdot
.26352 .61666 Mdot
.40284 .4527 Mdot
.30016 .62078 Mdot
.41339 .38043 Mdot
.63435 .60836 Mdot
.32993 .38218 Mdot
.64627 .43303 Mdot
.1746 .5056 Mdot
.4376 .39889 Mdot
.34649 .62585 Mdot
.66044 .41215 Mdot
.50653 .76032 Mdot
.44902 .43097 Mdot
.59512 .33524 Mdot
.66791 .52002 Mdot
.44658 .48055 Mdot
.62022 .59639 Mdot
.38261 .40539 Mdot
.38693 .34809 Mdot
.26806 .25376 Mdot
.35888 .63275 Mdot
.64119 .62778 Mdot
.44586 .63017 Mdot
.38668 .46234 Mdot
.34962 .62656 Mdot
.38289 .61505 Mdot
.6084 .33299 Mdot
.5357 .66715 Mdot
.71321 .43549 Mdot
.82512 .48372 Mdot
.30939 .57424 Mdot
.61205 .45846 Mdot
.36062 .74249 Mdot
.43364 .41964 Mdot
.41708 .30471 Mdot
.61524 .61404 Mdot
.39577 .44146 Mdot
.31078 .52459 Mdot
.36175 .62544 Mdot
.39212 .41411 Mdot
.59658 .29052 Mdot
.47798 .71943 Mdot
.40783 .31996 Mdot
.84257 .55975 Mdot
.68752 .43531 Mdot
.44219 .46407 Mdot
.41939 .49873 Mdot
.49651 .76014 Mdot
.39986 .47224 Mdot
.67721 .47372 Mdot
.77269 .49815 Mdot
.57828 .30411 Mdot
.36521 .65936 Mdot
.51985 .75601 Mdot
.39918 .37687 Mdot
.35885 .46022 Mdot
.58009 .34049 Mdot
.44808 .40705 Mdot
.1848 .54306 Mdot
.48204 .74934 Mdot
.62701 .43375 Mdot
.36214 .60436 Mdot
.36048 .41672 Mdot
.49837 .75333 Mdot
.36941 .44807 Mdot
.42232 .54213 Mdot
.40049 .39364 Mdot
.48212 .8134 Mdot
.3841 .6407 Mdot
.61772 .59396 Mdot
.3511 .38813 Mdot
.38728 .42908 Mdot
.71823 .34994 Mdot
.42407 .3584 Mdot
.37016 .42208 Mdot
.39563 .59266 Mdot
.38205 .66145 Mdot
.40511 .62537 Mdot
.62346 .43904 Mdot
.50638 .62299 Mdot
.63105 .6014 Mdot
.46399 .42542 Mdot
.64848 .58144 Mdot
.44473 .506 Mdot
.58294 .33963 Mdot
.78959 .63634 Mdot
.41234 .43994 Mdot
.40104 .61193 Mdot
.37244 .76716 Mdot
.34381 .61942 Mdot
.65484 .64264 Mdot
.61331 .60362 Mdot
.36965 .63007 Mdot
.40251 .42194 Mdot
.50865 .60697 Mdot
.8499 .51491 Mdot
.62084 .57742 Mdot
.41076 .47894 Mdot
.68118 .42459 Mdot
.66881 .4222 Mdot
.7382 .74079 Mdot
.61994 .62319 Mdot
.42117 .73527 Mdot
.42254 .40799 Mdot
.3759 .66307 Mdot
.64558 .59399 Mdot
.60972 .60794 Mdot
.63276 .43903 Mdot
.4264 .45581 Mdot
.38852 .42628 Mdot
.51636 .73718 Mdot
.65098 .59028 Mdot
.33323 .40057 Mdot
.41113 .46203 Mdot
.62371 .80832 Mdot
.37918 .67761 Mdot
.15744 .40864 Mdot
.37196 .35848 Mdot
.31551 .52345 Mdot
.53618 .44556 Mdot
.3575 .64934 Mdot
.44168 .39482 Mdot
.46423 .41822 Mdot
.61398 .46652 Mdot
.40797 .43536 Mdot
.63074 .48063 Mdot
.63438 .62998 Mdot
.79528 .63643 Mdot
.72913 .62744 Mdot
.60627 .53582 Mdot
.39864 .44884 Mdot
.43889 .33055 Mdot
.60712 .31907 Mdot
.59572 .60833 Mdot
.39753 .64714 Mdot
.3573 .42304 Mdot
.62398 .49036 Mdot
.63128 .4338 Mdot
.37622 .61876 Mdot
.43131 .75083 Mdot
.7339 .67739 Mdot
.38335 .46596 Mdot
.67591 .4612 Mdot
.71883 .64195 Mdot
.23933 .43216 Mdot
.65141 .63227 Mdot
.58092 .30007 Mdot
.65546 .48683 Mdot
.61099 .63082 Mdot
.42976 .5325 Mdot
.37866 .62564 Mdot
.36001 .66312 Mdot
.73866 .39488 Mdot
.66283 .44796 Mdot
.60498 .31426 Mdot
.51664 .46704 Mdot
.49458 .49667 Mdot
.59575 .28819 Mdot
.64798 .48994 Mdot
.36828 .6589 Mdot
.40062 .63465 Mdot
.38417 .61298 Mdot
.17901 .5207 Mdot
.41142 .61477 Mdot
.23208 .3543 Mdot
.36693 .46135 Mdot
.20563 .49819 Mdot
.41654 .39556 Mdot
.65338 .58137 Mdot
.36764 .63914 Mdot
.52487 .56725 Mdot
.35345 .41465 Mdot
.84288 .54634 Mdot
.40236 .40243 Mdot
.65177 .54349 Mdot
.38086 .41903 Mdot
.20236 .57015 Mdot
.37548 .67258 Mdot
.41393 .40964 Mdot
.65761 .5745 Mdot
.58761 .30949 Mdot
.38494 .56575 Mdot
.3726 .41686 Mdot
.4903 .78783 Mdot
.40166 .49347 Mdot
.71931 .71505 Mdot
.6722 .29083 Mdot
.56901 .32647 Mdot
.43256 .48071 Mdot
.62785 .41383 Mdot
.41909 .57841 Mdot
.20332 .52362 Mdot
.62117 .57785 Mdot
.29267 .34937 Mdot
.62669 .44098 Mdot
.32754 .39095 Mdot
.41503 .3703 Mdot
.57428 .31252 Mdot
.39435 .56469 Mdot
.63791 .60519 Mdot
.4063 .45276 Mdot
.44533 .39641 Mdot
.79058 .39216 Mdot
.20053 .53135 Mdot
.33431 .40186 Mdot
.60507 .34549 Mdot
.2587 .37625 Mdot
.37477 .40614 Mdot
.68144 .4862 Mdot
.40774 .64475 Mdot
.47571 .42729 Mdot
.24844 .37725 Mdot
.41751 .41962 Mdot
.37027 .62655 Mdot
.35732 .65715 Mdot
.42801 .80623 Mdot
.58062 .33655 Mdot
.40012 .39369 Mdot
.72868 .34944 Mdot
.42789 .39261 Mdot
.63371 .60275 Mdot
.40752 .4729 Mdot
.63105 .45421 Mdot
.50687 .65826 Mdot
.62154 .44162 Mdot
.44437 .4447 Mdot
.39671 .62164 Mdot
.64034 .60112 Mdot
.75076 .41211 Mdot
.5735 .48522 Mdot
.23711 .34865 Mdot
.67228 .51795 Mdot
.58044 .32407 Mdot
.61848 .29292 Mdot
.64832 .55062 Mdot
.40687 .40813 Mdot
.5539 .49189 Mdot
.46852 .41189 Mdot
.37728 .41841 Mdot
.37938 .39265 Mdot
.59099 .58757 Mdot
.61376 .59987 Mdot
.65479 .44713 Mdot
.38531 .45465 Mdot
.41934 .41346 Mdot
.38148 .634 Mdot
.58689 .30424 Mdot
.62928 .42811 Mdot
.61379 .31331 Mdot
.65034 .46183 Mdot
.7051 .76953 Mdot
.41428 .47295 Mdot
.5874 .31095 Mdot
.60248 .58614 Mdot
.40252 .61044 Mdot
.49805 .72907 Mdot
.66917 .47003 Mdot
.64918 .43355 Mdot
.41493 .40096 Mdot
.37319 .60341 Mdot
.35861 .61406 Mdot
.58217 .32866 Mdot
.65064 .60456 Mdot
.45476 .42544 Mdot
.41267 .46369 Mdot
.7405 .3174 Mdot
.61397 .45722 Mdot
.22926 .42028 Mdot
.43689 .7943 Mdot
.40782 .40854 Mdot
.35429 .61768 Mdot
.38209 .43651 Mdot
.78603 .56228 Mdot
.40038 .60031 Mdot
.34886 .41971 Mdot
.51535 .41678 Mdot
.61626 .43962 Mdot
.42827 .82135 Mdot
.34788 .39999 Mdot
.68657 .62416 Mdot
.44238 .42202 Mdot
.50321 .86471 Mdot
.33623 .72764 Mdot
.40827 .37801 Mdot
.38149 .46402 Mdot
.83015 .45699 Mdot
.42448 .40337 Mdot
.51921 .74623 Mdot
.38762 .35601 Mdot
.34853 .6286 Mdot
.54352 .44645 Mdot
.54247 .55976 Mdot
.59615 .34197 Mdot
.63817 .46571 Mdot
.41969 .25991 Mdot
.61743 .30901 Mdot
.37319 .65084 Mdot
.35329 .44141 Mdot
.34603 .52192 Mdot
.60075 .44687 Mdot
.44313 .37791 Mdot
.63401 .60464 Mdot
.54104 .5637 Mdot
.64336 .48522 Mdot
.62044 .58594 Mdot
.39614 .38103 Mdot
.56171 .19243 Mdot
.58489 .49898 Mdot
.47705 .83184 Mdot
.64083 .58884 Mdot
.61861 .61323 Mdot
.49635 .63699 Mdot
.59638 .34185 Mdot
.77912 .36702 Mdot
.35591 .33209 Mdot
.61624 .57689 Mdot
.49542 .2615 Mdot
.64764 .49985 Mdot
.52998 .66941 Mdot
.36102 .67004 Mdot
.42083 .47041 Mdot
.3991 .42348 Mdot
.64888 .6106 Mdot
.31072 .63863 Mdot
.43745 .56462 Mdot
.61767 .58352 Mdot
.39699 .50257 Mdot
.53332 .67762 Mdot
.49954 .74324 Mdot
.52134 .74384 Mdot
.6135 .33341 Mdot
.66613 .37586 Mdot
.39241 .63658 Mdot
.57397 .30298 Mdot
.53358 .7523 Mdot
.39607 .3943 Mdot
.65118 .58889 Mdot
.50684 .72815 Mdot
.62754 .58913 Mdot
.58979 .31903 Mdot
.5767 .33469 Mdot
.36065 .6332 Mdot
.37513 .65627 Mdot
.2843 .38484 Mdot
.52891 .24846 Mdot
.42745 .4018 Mdot
.33245 .56252 Mdot
.40325 .60644 Mdot
.23907 .63651 Mdot
.5857 .33587 Mdot
.58824 .29873 Mdot
.23295 .52104 Mdot
.4325 .44668 Mdot
.73877 .60685 Mdot
.37278 .41199 Mdot
.46523 .28295 Mdot
.37668 .38087 Mdot
.63601 .43804 Mdot
.43668 .4045 Mdot
.59199 .73764 Mdot
.42061 .43107 Mdot
.37078 .40293 Mdot
.65966 .47506 Mdot
.34978 .38788 Mdot
.62926 .45185 Mdot
.41529 .46622 Mdot
.56829 .33539 Mdot
.63982 .46273 Mdot
.60425 .24131 Mdot
.58439 .39662 Mdot
.50566 .75524 Mdot
.61783 .32178 Mdot
.59183 .33383 Mdot
.52262 .20321 Mdot
.39228 .65297 Mdot
.43903 .52559 Mdot
.40545 .40807 Mdot
.66467 .49198 Mdot
.63789 .57575 Mdot
.41713 .41857 Mdot
.46364 .44414 Mdot
.34529 .40629 Mdot
.36425 .62969 Mdot
.65104 .49109 Mdot
.59328 .31131 Mdot
.67793 .44676 Mdot
.61984 .36734 Mdot
.67921 .43689 Mdot
.41861 .34048 Mdot
.35825 .3679 Mdot
.39545 .5208 Mdot
.32752 .54837 Mdot
.17841 .47142 Mdot
.38002 .62173 Mdot
.50949 .74485 Mdot
.58724 .34226 Mdot
.4649 .54955 Mdot
.40068 .61646 Mdot
.65384 .43464 Mdot
.39276 .41961 Mdot
.39402 .50367 Mdot
.40042 .32448 Mdot
.42419 .64968 Mdot
.56028 .23159 Mdot
.64759 .47799 Mdot
.50177 .73528 Mdot
.50956 .63923 Mdot
.36422 .69238 Mdot
.52538 .56004 Mdot
.38417 .43258 Mdot
.59043 .33513 Mdot
.35197 .64786 Mdot
.77578 .41116 Mdot
.64904 .61699 Mdot
.51857 .60419 Mdot
.40053 .44751 Mdot
.3825 .74743 Mdot
.39644 .62154 Mdot
.58863 .29486 Mdot
.64851 .61099 Mdot
.58346 .33701 Mdot
.51983 .75833 Mdot
.56434 .76371 Mdot
.44985 .41742 Mdot
.36926 .42319 Mdot
.61924 .56546 Mdot
.39377 .63412 Mdot
.60917 .48308 Mdot
.79192 .42035 Mdot
.67577 .45778 Mdot
.55515 .51079 Mdot
.35147 .64432 Mdot
.34328 .71256 Mdot
.65659 .42252 Mdot
.59877 .60573 Mdot
.5497 .4999 Mdot
.6049 .61729 Mdot
.37382 .40247 Mdot
.38292 .60478 Mdot
.62012 .62355 Mdot
.74795 .37955 Mdot
.68997 .76826 Mdot
.39707 .56009 Mdot
.39405 .45979 Mdot
.79384 .63342 Mdot
.60902 .79874 Mdot
.33839 .57923 Mdot
.65427 .59433 Mdot
.38213 .4469 Mdot
.38001 .4653 Mdot
.43696 .3993 Mdot
.63525 .62607 Mdot
.59885 .49538 Mdot
.64603 .42884 Mdot
.39535 .40379 Mdot
.59963 .33187 Mdot
.63498 .44832 Mdot
.63782 .41179 Mdot
.68091 .47023 Mdot
.39929 .59826 Mdot
.36064 .45372 Mdot
.48737 .69633 Mdot
.53408 .85832 Mdot
.61582 .60228 Mdot
.50608 .75538 Mdot
.38082 .38831 Mdot
.28388 .30063 Mdot
.40485 .62285 Mdot
.67512 .45562 Mdot
.39411 .44226 Mdot
.68612 .31597 Mdot
.49908 .78022 Mdot
.65109 .47192 Mdot
.3961 .64787 Mdot
.34281 .57506 Mdot
.40855 .43455 Mdot
.44147 .42513 Mdot
.38868 .64534 Mdot
.53338 .80014 Mdot
.51457 .65675 Mdot
.38058 .43411 Mdot
.61773 .59122 Mdot
.25633 .25412 Mdot
.35351 .45363 Mdot
.42641 .6472 Mdot
.4975 .7558 Mdot
.47721 .80504 Mdot
.23533 .4143 Mdot
.45606 .36607 Mdot
.80633 .59398 Mdot
.40081 .25019 Mdot
.78597 .65171 Mdot
.41084 .28086 Mdot
.70417 .65368 Mdot
.63518 .82994 Mdot
.66228 .59372 Mdot
.20884 .57766 Mdot
.79624 .3561 Mdot
.4447 .73329 Mdot
.65462 .29503 Mdot
.73353 .49054 Mdot
.6883 .30615 Mdot
.21903 .66666 Mdot
.67448 .43098 Mdot
.45532 .29945 Mdot
.45213 .40654 Mdot
.60344 .7951 Mdot
.19779 .48175 Mdot
.17831 .44894 Mdot
.78124 .64223 Mdot
.71886 .33648 Mdot
.85341 .46802 Mdot
.75371 .66201 Mdot
.29393 .39687 Mdot
.48731 .35375 Mdot
.68013 .39172 Mdot
.5075 .47897 Mdot
.40892 .26123 Mdot
.47445 .45597 Mdot
.59028 .72138 Mdot
.61463 .53784 Mdot
.28004 .43993 Mdot
.24201 .28118 Mdot
.66724 .47991 Mdot
.40941 .64208 Mdot
.7754 .35137 Mdot
.43022 .61584 Mdot
.66889 .5891 Mdot
.8069 .59333 Mdot
.62236 .81223 Mdot
.20051 .56505 Mdot
.52983 .72063 Mdot
.24364 .57126 Mdot
.43565 .19932 Mdot
.47343 .33562 Mdot
.34009 .62019 Mdot
.71523 .56446 Mdot
.49484 .49568 Mdot
.6483 .38199 Mdot
.20958 .59957 Mdot
.61475 .28224 Mdot
.59671 .23561 Mdot
.39811 .64278 Mdot
.24612 .42614 Mdot
.48917 .73696 Mdot
.52321 .72133 Mdot
.64151 .50564 Mdot
.78914 .5455 Mdot
.48389 .77108 Mdot
.47365 .76225 Mdot
.33699 .75701 Mdot
.86081 .53393 Mdot
.46351 .22839 Mdot
.77031 .47893 Mdot
.68125 .61975 Mdot
.41454 .24179 Mdot
.48096 .68031 Mdot
.51123 .23482 Mdot
.4912 .48419 Mdot
.82799 .35901 Mdot
.55139 .81168 Mdot
.85304 .43187 Mdot
.3294 .63143 Mdot
.34836 .45969 Mdot
.7854 .49256 Mdot
.29951 .58783 Mdot
.56586 .3018 Mdot
.85372 .54638 Mdot
.5701 .31638 Mdot
.40733 .66432 Mdot
.43959 .73505 Mdot
.1851 .52443 Mdot
.61656 .49757 Mdot
.57785 .26356 Mdot
.46847 .44552 Mdot
.80893 .30313 Mdot
.81599 .57652 Mdot
.44179 .80683 Mdot
.61439 .81285 Mdot
.6957 .43878 Mdot
.60778 .42673 Mdot
.63039 .63025 Mdot
.65573 .80419 Mdot
.39306 .61132 Mdot
.542 .86118 Mdot
.65154 .80158 Mdot
.42887 .66719 Mdot
.79768 .28021 Mdot
.27496 .71756 Mdot
.20785 .48424 Mdot
.32035 .31463 Mdot
.63416 .22889 Mdot
.48472 .65202 Mdot
.34984 .71636 Mdot
.67976 .41698 Mdot
.52153 .81776 Mdot
.71625 .7528 Mdot
.49829 .27183 Mdot
.58024 .61276 Mdot
.4529 .70622 Mdot
.53248 .36638 Mdot
.42321 .60809 Mdot
.64022 .26833 Mdot
.52632 .3558 Mdot
.85558 .4504 Mdot
.27659 .35978 Mdot
.37482 .17533 Mdot
.42497 .27802 Mdot
.20029 .61023 Mdot
.74586 .64266 Mdot
.55285 .29659 Mdot
.42833 .54768 Mdot
.46167 .76547 Mdot
.40637 .48502 Mdot
.49133 .5999 Mdot
.32904 .45944 Mdot
.61067 .35781 Mdot
.502 .63019 Mdot
.67756 .72765 Mdot
.44378 .27353 Mdot
.81511 .48397 Mdot
.494 .37192 Mdot
.36671 .59841 Mdot
.50348 .22491 Mdot
.47206 .24827 Mdot
.64454 .79039 Mdot
.44598 .63336 Mdot
.49036 .828 Mdot
.44516 .61258 Mdot
.46973 .41672 Mdot
.21408 .58621 Mdot
.46364 .47722 Mdot
.49546 .24771 Mdot
.35694 .3899 Mdot
.34747 .76382 Mdot
.57403 .82493 Mdot
.30514 .49161 Mdot
.43629 .25524 Mdot
.3288 .53292 Mdot
.52874 .8204 Mdot
.78976 .49212 Mdot
.36992 .72955 Mdot
.32302 .69708 Mdot
.81554 .32059 Mdot
.64407 .44352 Mdot
.50468 .26145 Mdot
.59774 .57722 Mdot
.74796 .40261 Mdot
.78484 .33017 Mdot
.43975 .58585 Mdot
.56568 .83088 Mdot
.46147 .73922 Mdot
.59624 .46149 Mdot
.55943 .67229 Mdot
.59648 .64088 Mdot
.32848 .51173 Mdot
.34316 .43313 Mdot
.37723 .52628 Mdot
.5862 .28619 Mdot
.28372 .59045 Mdot
.78685 .46441 Mdot
.68355 .53594 Mdot
.45494 .36102 Mdot
.69173 .55479 Mdot
.50584 .73347 Mdot
.52394 .61483 Mdot
.72876 .75336 Mdot
.40561 .35072 Mdot
.25847 .69559 Mdot
.54958 .8054 Mdot
.54798 .52013 Mdot
.64043 .36502 Mdot
.40977 .77618 Mdot
.8467 .39906 Mdot
.60667 .83177 Mdot
.64145 .76711 Mdot
.79787 .62651 Mdot
.34774 .81639 Mdot
.75321 .28638 Mdot
.28144 .65212 Mdot
.60028 .57066 Mdot
.25659 .78928 Mdot
.667 .43182 Mdot
.29911 .32864 Mdot
.3003 .583 Mdot
.68714 .32577 Mdot
.4231 .59034 Mdot
.48916 .383 Mdot
.69831 .47588 Mdot
.40281 .58088 Mdot
.46929 .43905 Mdot
.84407 .59316 Mdot
.83162 .3603 Mdot
.85161 .57526 Mdot
.56623 .76577 Mdot
.79567 .64832 Mdot
.82672 .40658 Mdot
.22636 .36099 Mdot
.78814 .37495 Mdot
.40716 .47266 Mdot
.51863 .28406 Mdot
.28271 .71889 Mdot
.63398 .50614 Mdot
.50673 .70468 Mdot
.34965 .67272 Mdot
.82047 .36096 Mdot
.73663 .74858 Mdot
.24851 .52249 Mdot
.26376 .41813 Mdot
.57335 .39046 Mdot
.51596 .24572 Mdot
.32518 .47857 Mdot
.59512 .71163 Mdot
.69029 .7523 Mdot
.82266 .39511 Mdot
.46561 .25796 Mdot
.72344 .51196 Mdot
.64722 .75444 Mdot
.28099 .69722 Mdot
.7687 .62745 Mdot
.77305 .34256 Mdot
.4375 .63713 Mdot
.33545 .68521 Mdot
.43682 .56826 Mdot
.58176 .70547 Mdot
.77043 .54347 Mdot
.44478 .23235 Mdot
.62417 .46344 Mdot
.50524 .27377 Mdot
.51604 .52557 Mdot
.7875 .36919 Mdot
.43224 .22676 Mdot
.49399 .27658 Mdot
.6637 .75107 Mdot
.83041 .60912 Mdot
.52032 .79814 Mdot
.59566 .20179 Mdot
.66308 .67486 Mdot
.32236 .44335 Mdot
.33674 .43651 Mdot
.55072 .82619 Mdot
.81799 .64687 Mdot
.5747 .83267 Mdot
.37651 .74706 Mdot
.73941 .37871 Mdot
.63659 .64006 Mdot
.42333 .22331 Mdot
.6799 .5607 Mdot
.69852 .74883 Mdot
.47542 .55906 Mdot
.6505 .64051 Mdot
.46785 .71679 Mdot
.29046 .38201 Mdot
.36179 .26898 Mdot
.26468 .45048 Mdot
.4401 .36984 Mdot
.22405 .45617 Mdot
.38969 .66643 Mdot
.37147 .74232 Mdot
.51044 .24003 Mdot
.64303 .44702 Mdot
.7215 .28763 Mdot
.35621 .51555 Mdot
.3676 .47931 Mdot
.77038 .50866 Mdot
.4211 .60168 Mdot
.32459 .5454 Mdot
.61598 .41588 Mdot
.65991 .81076 Mdot
.31618 .7303 Mdot
.32368 .48327 Mdot
.48122 .22123 Mdot
.74065 .32497 Mdot
.5208 .6521 Mdot
.61913 .55882 Mdot
.77335 .64701 Mdot
.57743 .41179 Mdot
.49521 .22638 Mdot
.22526 .44707 Mdot
.78812 .43376 Mdot
.46595 .42664 Mdot
.41252 .79155 Mdot
.25382 .33277 Mdot
.52701 .6128 Mdot
.39642 .67863 Mdot
.40606 .59489 Mdot
.16613 .60604 Mdot
.60468 .73894 Mdot
.42331 .6922 Mdot
.77641 .63016 Mdot
.61758 .62664 Mdot
.37541 .58907 Mdot
.4974 .28481 Mdot
.67438 .36051 Mdot
.26907 .38261 Mdot
.77486 .54753 Mdot
.30133 .40016 Mdot
.69093 .61452 Mdot
.7949 .62348 Mdot
.83708 .52482 Mdot
.28235 .23785 Mdot
.38137 .57475 Mdot
.76845 .43956 Mdot
.76929 .4298 Mdot
.34144 .61949 Mdot
.4247 .64965 Mdot
.42844 .32552 Mdot
.77848 .67432 Mdot
.4833 .53939 Mdot
.58057 .69312 Mdot
.55044 .50079 Mdot
.6554 .30948 Mdot
.78339 .40865 Mdot
.42265 .24522 Mdot
.77769 .61277 Mdot
.25507 .4444 Mdot
.65887 .22711 Mdot
.38523 .51743 Mdot
.28554 .33686 Mdot
.42323 .2231 Mdot
.50272 .35704 Mdot
.2148 .6068 Mdot
.69754 .71243 Mdot
.42799 .39512 Mdot
.86182 .54751 Mdot
.64472 .78451 Mdot
.48648 .60348 Mdot
.66291 .39269 Mdot
.42814 .43514 Mdot
.36286 .45758 Mdot
.30999 .66852 Mdot
.45742 .80129 Mdot
.70062 .23758 Mdot
.44273 .28295 Mdot
.31949 .43844 Mdot
.22145 .44882 Mdot
.25887 .6955 Mdot
.78672 .51195 Mdot
.73209 .693 Mdot
.50481 .54331 Mdot
.28873 .72192 Mdot
.56481 .64659 Mdot
.56465 .6899 Mdot
.68445 .66963 Mdot
.82933 .4152 Mdot
.3915 .33406 Mdot
.45656 .78592 Mdot
.77401 .36766 Mdot
.38228 .38836 Mdot
.43126 .75141 Mdot
.75839 .64238 Mdot
.39886 .18073 Mdot
.47324 .67956 Mdot
.83759 .62147 Mdot
.386 .52357 Mdot
.46619 .7836 Mdot
.78962 .32796 Mdot
.50161 .1442 Mdot
.58289 .71998 Mdot
.85581 .46504 Mdot
.55139 .65713 Mdot
.77986 .62348 Mdot
.65546 .6266 Mdot
.52056 .48701 Mdot
.31417 .59368 Mdot
.77403 .67955 Mdot
.70578 .39012 Mdot
.79313 .56342 Mdot
.30617 .67114 Mdot
.79786 .65837 Mdot
.48361 .48883 Mdot
.16525 .59447 Mdot
.67102 .50185 Mdot
.3089 .75952 Mdot
.28834 .675 Mdot
.32361 .46445 Mdot
.48845 .2639 Mdot
.1639 .56058 Mdot
.20319 .40019 Mdot
.28758 .64724 Mdot
.50342 .31297 Mdot
.42187 .78329 Mdot
.47502 .21797 Mdot
.69658 .7546 Mdot
.20483 .65004 Mdot
.77751 .42237 Mdot
.42091 .71607 Mdot
.54699 .7909 Mdot
.45703 .80521 Mdot
.66378 .70587 Mdot
.77765 .50249 Mdot
.55107 .71426 Mdot
.30229 .3902 Mdot
.12847 .39988 Mdot
.55683 .5858 Mdot
.41378 .3248 Mdot
.8426 .40202 Mdot
.684 .75752 Mdot
.46851 .55623 Mdot
.20379 .59309 Mdot
.32214 .28044 Mdot
.53948 .28909 Mdot
.37068 .41187 Mdot
.80115 .65331 Mdot
.5583 .27258 Mdot
.85379 .51016 Mdot
.49659 .84092 Mdot
.23341 .46039 Mdot
.40454 .34371 Mdot
.67508 .41471 Mdot
.43936 .31917 Mdot
.49849 .31827 Mdot
.8413 .42345 Mdot
.29191 .33378 Mdot
.56646 .47451 Mdot
.7048 .62804 Mdot
.74844 .60863 Mdot
.32069 .39057 Mdot
.28715 .7287 Mdot
.44076 .79054 Mdot
.42484 .2683 Mdot
.63449 .76006 Mdot
.50244 .25361 Mdot
.23221 .41877 Mdot
.43556 .21867 Mdot
.46906 .61185 Mdot
.70209 .43182 Mdot
.62 .48097 Mdot
.82498 .45735 Mdot
.73859 .66569 Mdot
.35317 .76576 Mdot
.60764 .20967 Mdot
.45808 .76454 Mdot
.46465 .30867 Mdot
.80338 .46788 Mdot
.47965 .65433 Mdot
.70876 .40846 Mdot
.34928 .27834 Mdot
.28259 .35629 Mdot
.71279 .70207 Mdot
.49538 .40371 Mdot
.71852 .7532 Mdot
.44078 .23537 Mdot
.80711 .42446 Mdot
.56864 .39657 Mdot
.29718 .55862 Mdot
.21627 .53994 Mdot
.64928 .23938 Mdot
.52969 .60296 Mdot
.81046 .30801 Mdot
.33876 .63408 Mdot
.86088 .53055 Mdot
.63736 .57936 Mdot
.30237 .23877 Mdot
.70516 .72587 Mdot
.51187 .55524 Mdot
.5438 .48583 Mdot
.41369 .79492 Mdot
.48876 .78133 Mdot
.54004 .80442 Mdot
.4368 .57683 Mdot
.68426 .46612 Mdot
.57356 .47429 Mdot
.58697 .69687 Mdot
.82099 .49896 Mdot
.43459 .459 Mdot
.60488 .4841 Mdot
.4945 .34884 Mdot
.64801 .65537 Mdot
.55485 .82206 Mdot
.70744 .68957 Mdot
.46398 .46947 Mdot
.51883 .24406 Mdot
.82771 .39314 Mdot
.65757 .79181 Mdot
.44326 .55776 Mdot
.33135 .46354 Mdot
.64987 .54471 Mdot
.74362 .29546 Mdot
.81473 .56509 Mdot
.73345 .62032 Mdot
.5228 .67256 Mdot
.46303 .23115 Mdot
.87058 .58439 Mdot
.82965 .35919 Mdot
.62556 .20865 Mdot
.55297 .49683 Mdot
.32767 .65631 Mdot
.28462 .30325 Mdot
.8077 .42906 Mdot
.31958 .77072 Mdot
.64423 .77545 Mdot
.50134 .25922 Mdot
.43949 .17067 Mdot
.18979 .45008 Mdot
.57804 .44311 Mdot
.21733 .54165 Mdot
.31573 .56664 Mdot
.64133 .64509 Mdot
.53595 .30533 Mdot
.56714 .43907 Mdot
.66434 .57404 Mdot
.42562 .78492 Mdot
.47246 .75421 Mdot
.80684 .42021 Mdot
.26072 .35697 Mdot
.33475 .47186 Mdot
.81271 .51953 Mdot
.42313 .63813 Mdot
.77343 .41413 Mdot
.74689 .3312 Mdot
.57148 .44585 Mdot
.67585 .4397 Mdot
.48158 .42359 Mdot
.52897 .63113 Mdot
.55335 .64512 Mdot
.52002 .17891 Mdot
.57226 .29534 Mdot
.33227 .6332 Mdot
.17431 .49052 Mdot
.37169 .57891 Mdot
.80849 .67092 Mdot
.59734 .71148 Mdot
.21846 .46192 Mdot
.56602 .62746 Mdot
.72274 .53307 Mdot
.51753 .16508 Mdot
.29253 .39255 Mdot
.62258 .25746 Mdot
.33865 .67674 Mdot
.38742 .66599 Mdot
.57781 .63726 Mdot
.48596 .75532 Mdot
.25502 .42213 Mdot
.23924 .67999 Mdot
.73853 .31994 Mdot
.35767 .58625 Mdot
.58198 .46098 Mdot
.37277 .54546 Mdot
.71943 .76039 Mdot
.68022 .45353 Mdot
.82173 .33169 Mdot
.3592 .36599 Mdot
.73171 .27617 Mdot
.55631 .82551 Mdot
.50365 .65995 Mdot
.55644 .49456 Mdot
.73893 .46205 Mdot
.45645 .44824 Mdot
.32303 .45392 Mdot
.38531 .6544 Mdot
.79194 .38668 Mdot
.59407 .2992 Mdot
.54733 .23276 Mdot
.62824 .5522 Mdot
.2342 .65034 Mdot
.30012 .73354 Mdot
.39504 .6641 Mdot
.60253 .3856 Mdot
.76203 .44363 Mdot
.51705 .40298 Mdot
.49773 .35128 Mdot
.82817 .45244 Mdot
.27351 .4054 Mdot
.34059 .62737 Mdot
.62499 .21064 Mdot
.52676 .35293 Mdot
.61855 .83365 Mdot
.45251 .50442 Mdot
.46549 .3332 Mdot
.50149 .37889 Mdot
.40574 .7827 Mdot
.23805 .40977 Mdot
.72237 .71311 Mdot
.50705 .22789 Mdot
.51527 .45986 Mdot
.4967 .27778 Mdot
.47146 .45741 Mdot
.70321 .6415 Mdot
.29369 .74618 Mdot
.44995 .16957 Mdot
.23811 .57941 Mdot
.48227 .68901 Mdot
.41618 .6671 Mdot
.26362 .70009 Mdot
.33552 .63066 Mdot
.62934 .35634 Mdot
.28353 .44568 Mdot
.7037 .72813 Mdot
.66805 .79681 Mdot
.64354 .7906 Mdot
.42427 .31305 Mdot
.74132 .61742 Mdot
.33594 .29742 Mdot
.40143 .53572 Mdot
.52055 .55403 Mdot
.45787 .44997 Mdot
.32176 .39494 Mdot
.46293 .57552 Mdot
.37001 .76767 Mdot
.36534 .34824 Mdot
.76841 .67992 Mdot
.61669 .83242 Mdot
.8165 .61894 Mdot
.76961 .53916 Mdot
.41354 .60954 Mdot
.84197 .38689 Mdot
.21878 .4107 Mdot
.68539 .76543 Mdot
.28558 .67106 Mdot
.18049 .63316 Mdot
.79445 .34237 Mdot
.68505 .72487 Mdot
.39659 .7067 Mdot
.43568 .82581 Mdot
.56139 .81417 Mdot
.16714 .59773 Mdot
.31932 .33365 Mdot
.54786 .82186 Mdot
.80352 .29907 Mdot
.26909 .648 Mdot
.48168 .77647 Mdot
.21094 .53784 Mdot
.3067 .34268 Mdot
.21293 .65278 Mdot
.37843 .47673 Mdot
.65449 .41568 Mdot
.66856 .29596 Mdot
.49086 .25788 Mdot
.48517 .41677 Mdot
.20075 .63587 Mdot
.49718 .32082 Mdot
.45303 .30112 Mdot
.74638 .41419 Mdot
.79618 .35344 Mdot
.2451 .40864 Mdot
.4154 .49986 Mdot
.36105 .67851 Mdot
.61866 .30169 Mdot
.38755 .27718 Mdot
.4216 .4473 Mdot
.53569 .56822 Mdot
.38933 .32919 Mdot
.84308 .60059 Mdot
.66514 .33598 Mdot
.61028 .53114 Mdot
.39976 .58395 Mdot
.44422 .79906 Mdot
.79927 .52249 Mdot
.4429 .7334 Mdot
.18733 .61023 Mdot
.27881 .38395 Mdot
.80048 .61269 Mdot
.4637 .75287 Mdot
.44973 .25114 Mdot
.4714 .18716 Mdot
.65487 .57912 Mdot
.30778 .59629 Mdot
.83863 .426 Mdot
.44223 .75917 Mdot
.41903 .65374 Mdot
.65316 .73672 Mdot
.70941 .63477 Mdot
.4354 .77001 Mdot
.54873 .80469 Mdot
.78106 .4478 Mdot
.22499 .49711 Mdot
.83252 .52989 Mdot
.67113 .41558 Mdot
.46984 .26206 Mdot
.62509 .73912 Mdot
.21315 .65621 Mdot
.51627 .40489 Mdot
.73618 .72778 Mdot
.52157 .54602 Mdot
.5917 .24154 Mdot
.44732 .42367 Mdot
.2511 .37318 Mdot
.38335 .77067 Mdot
.63622 .7532 Mdot
.43587 .6671 Mdot
.41685 .64325 Mdot
.33136 .74902 Mdot
.65276 .38734 Mdot
.54893 .28254 Mdot
.33991 .31057 Mdot
.33517 .70916 Mdot
.62654 .343 Mdot
.49799 .71864 Mdot
.34895 .37571 Mdot
.59931 .23148 Mdot
.76429 .57975 Mdot
.30255 .61726 Mdot
.27913 .65086 Mdot
.82649 .46149 Mdot
.7785 .53518 Mdot
.34662 .76879 Mdot
.29543 .66639 Mdot
.48907 .813 Mdot
.20032 .43266 Mdot
.44076 .70546 Mdot
.34589 .41156 Mdot
.62917 .3564 Mdot
.3485 .61062 Mdot
.82398 .50097 Mdot
.39904 .54768 Mdot
.59972 .24285 Mdot
.49586 .57582 Mdot
.78322 .49172 Mdot
.55797 .39574 Mdot
.55921 .82197 Mdot
.4357 .82601 Mdot
.51051 .23892 Mdot
.64064 .55287 Mdot
.55609 .66274 Mdot
.47101 .67418 Mdot
.74599 .7025 Mdot
.45415 .58276 Mdot
.3447 .52164 Mdot
.47143 .7054 Mdot
.31332 .51948 Mdot
.51946 .83512 Mdot
.5337 .24833 Mdot
.52044 .56089 Mdot
.33102 .49209 Mdot
.51982 .71425 Mdot
.49642 .72946 Mdot
.68354 .33223 Mdot
.23077 .39357 Mdot
.57634 .58934 Mdot
.57261 .49573 Mdot
.33521 .39555 Mdot
.28036 .30653 Mdot
.82572 .53308 Mdot
.46351 .55168 Mdot
.51655 .54481 Mdot
.7719 .36979 Mdot
.55932 .26314 Mdot
.22048 .28337 Mdot
.86125 .56309 Mdot
.44667 .42554 Mdot
.5449 .47061 Mdot
.54492 .23851 Mdot
.63246 .4817 Mdot
.26601 .44291 Mdot
.828 .47282 Mdot
.61058 .6025 Mdot
.74415 .38603 Mdot
.48066 .73966 Mdot
.40285 .78939 Mdot
.66795 .24585 Mdot
.63959 .64187 Mdot
.81647 .66291 Mdot
.63739 .77718 Mdot
.3839 .76347 Mdot
.17324 .33048 Mdot
.35974 .75483 Mdot
.46475 .50725 Mdot
.74078 .42248 Mdot
.82912 .61619 Mdot
.55259 .50458 Mdot
.73939 .39557 Mdot
.27486 .64194 Mdot
.50897 .23464 Mdot
.45793 .28232 Mdot
.41956 .71795 Mdot
.34194 .74352 Mdot
.15663 .57755 Mdot
.72398 .53046 Mdot
.5466 .17382 Mdot
.24509 .43822 Mdot
.83991 .53475 Mdot
.58296 .71815 Mdot
.42798 .17434 Mdot
.65776 .80213 Mdot
.5139 .29372 Mdot
.20868 .63802 Mdot
.67838 .37643 Mdot
.55133 .21436 Mdot
.26879 .30988 Mdot
.56305 .73813 Mdot
.2778 .40475 Mdot
.70816 .53697 Mdot
.44107 .67514 Mdot
.50114 .27541 Mdot
.31681 .54246 Mdot
.52225 .5581 Mdot
.84472 .46392 Mdot
.17232 .56521 Mdot
.47962 .22606 Mdot
.76083 .38577 Mdot
.56384 .21954 Mdot
.81402 .53772 Mdot
.7713 .59404 Mdot
.52118 .39369 Mdot
.74902 .25812 Mdot
.85532 .45105 Mdot
.44797 .70457 Mdot
.36566 .46115 Mdot
.62765 .83294 Mdot
.5371 .401 Mdot
.28218 .64645 Mdot
.57949 .79777 Mdot
.43703 .28362 Mdot
.37157 .33632 Mdot
.34941 .44698 Mdot
.32072 .30909 Mdot
.3954 .70412 Mdot
.31855 .54767 Mdot
.69856 .27556 Mdot
.48472 .22368 Mdot
.1763 .56998 Mdot
.66843 .23726 Mdot
.4613 .49826 Mdot
.34681 .6357 Mdot
.83508 .60947 Mdot
.30346 .44512 Mdot
.36308 .51129 Mdot
.20963 .5021 Mdot
.44707 .57463 Mdot
.71768 .454 Mdot
.33066 .46035 Mdot
.52108 .64895 Mdot
.4863 .26291 Mdot
.8094 .44411 Mdot
.31423 .59804 Mdot
.7999 .2796 Mdot
.55707 .8295 Mdot
.35248 .58948 Mdot
.28097 .623 Mdot
.57489 .43525 Mdot
.82058 .60835 Mdot
.7177 .51497 Mdot
.74266 .327 Mdot
.16669 .49021 Mdot
.52067 .21202 Mdot
.4027 .37313 Mdot
.56615 .76867 Mdot
.68858 .77716 Mdot
.15862 .51929 Mdot
.71902 .75206 Mdot
.39316 .34292 Mdot
.34023 .45282 Mdot
.43557 .13851 Mdot
.7863 .6232 Mdot
.44702 .36193 Mdot
.41074 .69504 Mdot
.41674 .68095 Mdot
.45022 .43596 Mdot
.49176 .76827 Mdot
.39533 .26128 Mdot
.45959 .2883 Mdot
.77688 .67435 Mdot
.3932 .58482 Mdot
.55016 .52317 Mdot
.5949 .61559 Mdot
.54234 .51608 Mdot
.43889 .49596 Mdot
.61051 .61771 Mdot
.46365 .29514 Mdot
.54233 .42124 Mdot
.66222 .52866 Mdot
.30555 .37024 Mdot
.53233 .6972 Mdot
.30924 .37891 Mdot
.45744 .32034 Mdot
.32789 .68722 Mdot
.20307 .39912 Mdot
.49643 .3191 Mdot
.51902 .33848 Mdot
.54823 .81704 Mdot
.31494 .78865 Mdot
.54607 .55928 Mdot
.32032 .62247 Mdot
.45933 .50599 Mdot
.22848 .40621 Mdot
.2171 .49869 Mdot
.65742 .51928 Mdot
.49613 .73584 Mdot
.3666 .34988 Mdot
.32521 .48564 Mdot
.61773 .63135 Mdot
.85762 .60025 Mdot
.35514 .46269 Mdot
.25086 .4719 Mdot
.7305 .71761 Mdot
.77676 .41127 Mdot
.35007 .32373 Mdot
.4555 .4538 Mdot
.48431 .5014 Mdot
.5427 .41422 Mdot
.35787 .54185 Mdot
.7856 .40141 Mdot
.82052 .57498 Mdot
.37489 .30515 Mdot
.24198 .4685 Mdot
.40412 .40269 Mdot
.57613 .34362 Mdot
.51818 .62706 Mdot
.5212 .18663 Mdot
.60114 .25617 Mdot
.65811 .78803 Mdot
.46959 .31984 Mdot
.44183 .28258 Mdot
.19762 .52441 Mdot
.85571 .52339 Mdot
.46843 .68735 Mdot
.22961 .46312 Mdot
.47571 .59481 Mdot
.66719 .70954 Mdot
.5016 .31144 Mdot
.58761 .63473 Mdot
.33783 .36847 Mdot
.39665 .69978 Mdot
.77116 .70316 Mdot
.29281 .39737 Mdot
.60988 .55262 Mdot
.71481 .70194 Mdot
.20185 .43563 Mdot
.54301 .48601 Mdot
.14433 .36916 Mdot
.72627 .49611 Mdot
.8199 .65556 Mdot
.79666 .44243 Mdot
.50719 .40293 Mdot
.41975 .78018 Mdot
.47553 .39775 Mdot
.6621 .46852 Mdot
.82108 .59591 Mdot
.38188 .53847 Mdot
.43536 .70838 Mdot
.39889 .47479 Mdot
.48275 .51904 Mdot
.35689 .52753 Mdot
.73323 .63921 Mdot
.6674 .42135 Mdot
.44303 .56208 Mdot
.77116 .6038 Mdot
.54298 .41155 Mdot
.20155 .66672 Mdot
.84225 .42431 Mdot
.77154 .6503 Mdot
.7549 .5958 Mdot
.30862 .22838 Mdot
.34592 .67948 Mdot
.3857 .54375 Mdot
.65312 .56411 Mdot
.32967 .30178 Mdot
.43715 .76494 Mdot
.80508 .43348 Mdot
.47321 .81729 Mdot
.51698 .399 Mdot
.10719 .4422 Mdot
.50648 .29041 Mdot
.46365 .5389 Mdot
.41876 .75681 Mdot
.76153 .6884 Mdot
.73519 .34332 Mdot
.47625 .83172 Mdot
.59458 .72574 Mdot
.46835 .46073 Mdot
.25655 .33585 Mdot
.63487 .22002 Mdot
.72429 .61944 Mdot
.53664 .16928 Mdot
.74173 .64634 Mdot
.41015 .26109 Mdot
.63127 .75219 Mdot
.37661 .57586 Mdot
.41564 .57242 Mdot
.59839 .70599 Mdot
.50265 .70268 Mdot
.30997 .65096 Mdot
.81149 .58507 Mdot
.40398 .21508 Mdot
.76239 .3467 Mdot
.80032 .62892 Mdot
.67003 .65079 Mdot
.41529 .6711 Mdot
.4918 .32035 Mdot
.61577 .2728 Mdot
.62029 .46635 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0R_ooool2o`000;gooooo000Looooo`03o`000?oooooooooo08[ooooo0_l0000Coooo
o`;o0000Z?ooool001cooooo00?o0000ooooooooool0Woooool2o`000:Sooooo000Looooo`03o`00
0?oooooooooo0:Gooooo0_l0002Rooooo`007?ooool2o`0008kooooo0_l0000Fooooo`;o0000X_oo
ool001cooooo00?o0000ooooooooool0SOooool2o`000;[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`2Pooooo`;o00000_ooool2o`000:?ooooo000Looooo`03o`000?oooooooooo08Cooooo0_l0
000Cooooo`;o00001Oooool2o`0000;ooooo0_l0002Sooooo`007?ooool00ol0003oooooooooo`24
ooooo`;o00001Oooool5o`0000Kooooo1Ol0000@ooooo`;o0000W?ooool001cooooo00?o0000oooo
ooooool0KOooool2o`0000Oooooo0_l0000?ooooo`;o00000_ooool5o`0000Kooooo0ol0000Boooo
o`;o000000Coooooo`000?l0003o0000V?ooool001cooooo00?o0000ooooooooool0KOooool2o`00
00Oooooo0_l0000?ooooo`;o00005_ooool4o`0000_ooooo0ol0000;ooooo`;o0000Roooool001co
oooo00?o0000ooooooooool0O_ooool2o`0001oooooo1?l00002ooooo`;o00000oooool2o`00013o
oooo0_l0002;ooooo`007?ooool00ol0003oooooooooo`1nooooo`;o00009Oooool2o`0000?ooooo
0_l0002Mooooo`007?ooool00ol0003oooooooooo`2Eooooo`;o00003oooool2o`0000_ooooo0_l0
002Dooooo`007?ooool00ol0003oooooooooo`2Eooooo`;o00002?ooool2o`0000Gooooo0_l00006
ooooo`;o00000oooool2o`0009Cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ
8B44ooooo`Go00001_ooool00ol0003oooooooooo`2Eooooo`;o00002?ooool2o`0000gooooo0_l0
0003ooooo`;o0000U?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo
00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo06Wooooo0_l0000cooooo`;o
00004oooool2o`0009Cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo
00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`1Rooooo`;o00001Oooool2o`0001oooooo
0_l0000?ooooo`;o000000?oooooo`000?l000001?ooool2o`0003Kooooo0_l0001[ooooo`0000?o
ooooo`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0
001Rooooo`;o00009_ooool4o`0000?ooooo1?l00006ooooo`;o00001Oooool4o`0001Sooooo0_l0
000Looooo`;o0000Joooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool0
0omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo06kooooo0_l0000Jooooo`Co00000oooool6
o`0000?ooooo0ol00005ooooo`?o000000?oooooo`000?l000001?ooool2o`00013ooooo0_l00029
ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0Ioooool2o`0000Gooooo0_l0000Cooooo`;o00001Oooool2o`00
00Kooooo1Ol00003ooooo`;o00000_ooool2o`0000;ooooo2Ol000000ooooooo0000o`000002o`00
01Oooooo0_l00020ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`1Wooooo`;o00006Oooool3o`0000Gooooo0_l0
0006ooooo`?o00001_ooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`000004oooo
ool0003o0000o`0000?ooooo0_l0000Booooo`Co000000?oooooo`000?l00000P?ooool00006oooo
ooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000
ooooooooool0Ooooool2o`000003ooooool0003o000000[ooooo0_l0000;ooooo`;o00001?ooool2
o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`?o00004?ooool4o`000003ooooool0003o
0000083ooooo000Looooo`03o`000?oooooooooo07oooooo1?l0000;ooooo`;o00001oooool2o`00
00Sooooo0_l00002ooooo`;o00002?ooool3o`0000Cooooo0_l0002Aooooo`007?ooool00ol0003o
ooooooooo`21ooooo`;o00001oooool3o`0000[ooooo1?l00006ooooo`;o00000_ooool2o`0000co
oooo0_l000001?oooooo0000o`000?l0000Aooooo`;o0000OOooool001cooooo00?o0000oooooooo
ool0Q_ooool2o`0000;ooooo1?l0000;ooooo`?o00005oooool2o`0000;ooooo0_l0000Aooooo`;o
0000OOooool001cooooo00?o0000ooooooooool0QOooool6o`000003ooooool0003o000000[ooooo
1?l000001?oooooo0000o`000?ooool2o`0001Gooooo0ol0000Hooooo`;o0000MOooool001cooooo
00?o0000ooooooooool0F_ooool4o`0000?ooooo0_l0000Rooooo`;o000000Goooooo`000?l0003o
0000ooooo`02o`0000Gooooo0_l00003ooooo`;o00000oooool2o`000004ooooool0003o0000o`00
01Gooooo0_l00002ooooo`;o00003?ooool2o`0000Kooooo0_l0001eooooo`007?ooool00ol0003o
ooooooooo`1Jooooo`Co00000oooool3o`00027ooooo0_l00006ooooo`;o00001?ooool2o`0000_o
oooo0ol00007ooooo`;o00000_ooool2o`0000;ooooo1?l00006ooooo`;o000000?oooooo`000?l0
00002Oooool2o`0007gooooo000Looooo`03o`000?oooooooooo05;ooooo0_l00007ooooo`;o0000
1Oooool2o`00027ooooo0_l000000ooooooo0000o`000005o`0000Cooooo0_l0000;ooooo`Co0000
0_ooool2o`0000;ooooo0_l00002ooooo`;o00000_ooool4o`0000Kooooo1Ol00028ooooo`007?oo
ool00ol0003oooooooooo`1Booooo`;o00001?ooool2o`0000Cooooo0_l0000Kooooo`;o00002?oo
ool2o`000003ooooool0003o000000?o00004oooool4o`0000;ooooo0_l00005ooooo`;o00001Ooo
ool2o`0000;ooooo1?l00002ooooo`;o00003oooool2o`0000Cooooo0_l00009ooooo`;o0000Iooo
ool001cooooo00?o0000ooooooooool0F?ooool2o`0000Cooooo0_l0000Kooooo`;o00001_ooool4
o`0001Sooooo1Ol00003ooooo`;o00000_ooool4o`0000Gooooo0_l00002ooooo`Ko000000Cooooo
o`000?l0003o00003Oooool4o`0000;ooooo0_l00009ooooo`;o0000Ioooool001cooooo00?o0000
ooooooooool0O?ooool2o`000003ooooool0003o000000;ooooo1Ol00004ooooo`;o00004Oooool3
o`0000;ooooo1Ol000001?oooooo0000o`000?l0000?ooooo`;o000000Coooooo`000?l0003o0000
3oooool2o`0000;ooooo0_l0000=ooooo`;o0000Hoooool001cooooo00?o0000ooooooooool0O?oo
ool2o`000003ooooool0003o000000Gooooo0_l00004ooooo`;o00002?ooool2o`0000Gooooo1?l0
0002ooooo`Co000000?oooooo`000?l000000_l0000:ooooo`;o00007?ooool3o`0000gooooo0_l0
001Sooooo`007?ooool2o`0007kooooo0ol00005ooooo`;o00001oooool2o`0000Kooooo0_l00005
ooooo`Co00000_ooool2o`0000;ooooo1Ol0000:ooooo`;o00005Oooool2o`0000Gooooo1?l0001a
ooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o000000?oooooo`000?l000008oooool2o`00
00?ooooo0ol00005ooooo`;o00000oooool2o`0000;ooooo0_l0000?ooooo`;o00001_ooool2o`00
00Oooooo1Ol00007ooooo`;o00003oooool2o`0000Oooooo0_l0001aooooo`007?ooool00ol0003o
ooooooooo`1@ooooo`Go00008oooool2o`0000_ooooo0_l00003ooooo`;o00001oooool2o`0000Co
oooo0_l000001?oooooo0000o`000?ooool2o`0000kooooo1_l00007ooooo`;o000000?oooooo`00
0?l000000_ooool2o`000003ooooool0003o000001;ooooo0_l0000Cooooo`;o0000F?ooool001co
oooo00?o0000ooooooooool0DOooool2o`0002;ooooo0_l00006ooooo`;o00000_ooool2o`0000;o
oooo0_l0000<ooooo`;o00001?ooool2o`000003ooooool0003o000000Co00003Oooool2o`0000;o
oooo1_l00006ooooo`;o00000_ooool2o`000004ooooool0003o0000o`00013ooooo0ol0000Coooo
o`;o0000F?ooool001cooooo00?o0000ooooooooool0Boooool2o`0002Sooooo0_l00004ooooo`Co
00000_ooool2o`0000;ooooo0_l0000>ooooo`;o00000oooool8o`0000gooooo0_l000001?oooooo
0000o`000?ooool6o`0000cooooo0_l0000@ooooo`;o00002_ooool2o`0006;ooooo000Looooo`03
o`000?oooooooooo04_ooooo0_l0000Tooooo`;o00000_ooool2o`0000Cooooo0ol00003ooooo`Co
00004?ooool2o`0000?ooooo0ol00007ooooo`;o00000oooool;o`0000Cooooo0ol00002ooooo`;o
00009_ooool2o`0006;ooooo000Looooo`03o`000?oooooooooo06cooooo0_l000000ooooooo0000
o`000006o`0000;ooooo1Ol00003ooooo`Co000000?oooooo`000?l000004oooool2o`0000Oooooo
0_l00002ooooo`Oo000000?oooooo`000?l000001?ooool6o`000003ooooool0003o000000;ooooo
1?l00004ooooo`;o000000?oooooo`000?l00000Noooool001cooooo00?o0000ooooooooool0K?oo
ool9o`0000Cooooo0_l00003ooooo`;o00001_ooool2o`0000Cooooo0_l0000=ooooo`;o000000?o
ooooo`000?l000000_l00006ooooo`;o00001oooool3o`0000;ooooo2?l00003ooooo`Go00000ooo
ool2o`000003ooooool0003o000007_ooooo000Looooo`03o`000?oooooooooo04Wooooo0_l0000N
ooooo`So00001oooool2o`0000Cooooo0_l00004ooooo`;o00001_ooool2o`0000;ooooo0_l0000;
ooooo`Go00000_ooool2o`0000_ooooo0ol00007ooooo`?o00001?ooool4o`0000?ooooo0_l0000C
ooooo`?o00002Oooool2o`0000Wooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`19oooo
o`;o00006?ooool2o`0000;ooooo2Ol00002ooooo`;o00001?ooool4o`0000Sooooo1?l00005oooo
o`;o000000?oooooo`000?l000002oooool4o`0000?ooooo0_l00005ooooo`;o00003Oooool4o`00
00;ooooo0ol00006ooooo`;o00004oooool3o`0000Wooooo0_l000000ooooooo0000o`000002oooo
o`;o00000_ooool2o`0000Wooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o
00005_ooool6o`0000Gooooo0_l00002ooooo`;o00001_ooool2o`0000Kooooo0_l00002ooooo`;o
00001?ooool3o`0000;ooooo1?l00009ooooo`;o00002oooool2o`0000;ooooo0_l00009ooooo`co
00009oooool2o`0000;ooooo0_l0000<ooooo`?o0000Aoooool001cooooo00?o0000ooooooooool0
A?ooool4o`0000?ooooo0_l0000Fooooo`Co00001oooool2o`0001;ooooo0_l00006ooooo`Co0000
0oooool4o`0000Oooooo1?l00005ooooo`;o00001?ooool2o`0000;ooooo0_l00002ooooo`;o0000
0oooool>o`0002Oooooo0_l000000ooooooo0000o`00000=ooooo`;o0000B?ooool001cooooo00?o
0000ooooooooool0A?ooool4o`0001Sooooo0_l0000Xooooo`;o00001_ooool2o`0000Sooooo1?l0
0005ooooo`?o00000oooool2o`0000Kooooo0_l00003oooooa;o000000?oooooo`000?l000002_oo
ool2o`000003ooooool0003o000000_ooooo0_l00007ooooo`?o00003?ooool2o`0004Sooooo000L
ooooo`03o`000?oooooooooo063ooooo0_l0000`ooooo`;o00003Oooool2o`0000?ooooo0_l00003
ooooo`;o00003?ooool;o`000003ooooool0003o000000?o000000?oooooo`000?l000001?ooool2
o`0000Cooooo0_l000000ooooooo0000o`00000;ooooo`;o00002?ooool2o`0000?ooooo0_l00007
ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0AOooool2o`0002kooooo1?l00004oooo
o`;o00005?ooool2o`0000Wooooo0_l000000ooooooo0000o`000002o`00017ooooo4Ol0000:oooo
o`;o00001?ooool2o`0001Gooooo0_l00006ooooo`;o0000DOooool001cooooo00?o0000oooooooo
ool0AOooool2o`000003ooooool0003o000001oooooo0_l0000:ooooo`Co00001?ooool2o`0000Co
oooo0_l0000>ooooo`;o00002Oooool2o`0000?ooooo0_l0000;ooooo`Co00000_oooolAo`0000[o
oooo0_l00002ooooo`Co00004Oooool2o`0000;ooooo1?l00008ooooo`;o0000COooool001cooooo
0_l00019ooooo`;o00003_ooool2o`0000oooooo0_l0000Hooooo`;o00002_ooool3o`0001kooooo
1?l00002oooooa7o00000_ooool2o`0000[ooooo0_l000000ooooooo0000o`00000@ooooo`;o0000
1?ooool2o`0000Sooooo0_l00005ooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0B_oo
ool2o`0000cooooo1Ol0000:ooooo`;o00006oooool2o`0000Wooooo0ol0000PoooooaWo00003Ooo
ool2o`0002Oooooo1?l00014ooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o00002Oooool8
o`0000[ooooo0_l0000=ooooo`;o00003?ooool2o`0000;ooooo0_l0000Pooooo`;o00001_oooolH
o`0001;ooooo0_l0000>ooooo`;o00000oooool2o`00013ooooo0_l00014ooooo`007?ooool00ol0
003oooooooooo`1Dooooo`Go00002oooool2o`0000Gooooo0_l00002ooooo`;o00001Oooool2o`00
013ooooo0_l00002ooooo`;o00001Oooool2o`0001Gooooo0_l00008oooooaCo00002Oooool2o`00
00Wooooo0_l0000>ooooo`;o00000oooool2o`00013ooooo0_l00014ooooo`007?ooool00ol0003o
ooooooooo`1@ooooo`;o00000_ooool4o`0000cooooo0_l00005ooooo`;o00000_ooool4o`0000Go
oooo0_l0000<ooooo`;o00001?ooool2o`0000Gooooo0_l00009ooooo`Co00004_oooolDo`0000Wo
oooo0_l0000Wooooo`;o00001oooool2o`0004Cooooo000Looooo`03o`000?oooooooooo03Sooooo
0_l0000Fooooo`;o00000_ooool2o`0000?ooooo0_l00007ooooo`Co00002?ooool2o`000003oooo
ool0003o000000Gooooo0_l0000<ooooo`;o00005_ooool4o`0001?ooooo5?l0000Booooo`;o0000
3oooool2o`0000cooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00002_oo
ool2o`0001?ooooo0_l00007ooooo`Co00002?ooool2o`0000Sooooo0_l00005ooooo`Co00002?oo
ool2o`0000Sooooo0_l00006ooooo`Co00004_oooolFo`0000gooooo0_l00003ooooo`;o00003ooo
ool3o`0000_ooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00008oooool2
o`0000gooooo0_l00005ooooo`Co00001_ooool4o`0000Cooooo0_l00002ooooo`;o00001Oooool4
o`0001?ooooo0_l000000ooooooo0000o`00000;o`000003ooooool0003o000000Co00003?ooool2
o`0001Cooooo0ol00002ooooo`;o00001oooool2o`0000Wooooo0_l00012ooooo`007?ooool00ol0
003oooooooooo`14ooooo`;o00008?ooool2o`000003ooooool0003o000000?ooooo0_l000000ooo
oooo0000o`00000;ooooo`Co000000?oooooo`000?l000000_ooool4o`0000Kooooo0_l00009oooo
o`Co00001Oooool2o`000003ooooool0003o000000cooooo3?l00003ooooo`;o000000?oooooo`00
0?l000004Oooool2o`00013ooooo0_l00002ooooo`;o00002_ooool2o`0000Kooooo0_l00012oooo
o`007?ooool00ol0003oooooooooo`0gooooo`;o00009?ooool2o`0000Oooooo0_l00006ooooo`;o
000000?oooooo`000?l000002?ooool2o`000004ooooool0003o0000ooooo`Co00000_ooool2o`00
00Cooooo0ol0000Eooooo`;o000000?oooooo`000?l000002?ooool2o`000003ooooool0003o0000
00go00001?ooool2o`00017ooooo0_l000000ooooooo0000o`000003ooooo`;o00002?ooool2o`00
00kooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`0eooooo`Co00008?ooool2o`0000;o
oooo0_l00004ooooo`?o000000Goooooo`000?l0003o0000ooooo`02o`0000?ooooo0_l00009oooo
o`;o00000_ooool4o`000003ooooool0003o000000?o00000_ooool5o`0001Sooooo0_l00008oooo
o`;o000000?oooooo`000?l000004?l000000ooooooo0000o`00000@ooooo`;o00000_ooool2o`00
00?ooooo0_l00008ooooo`Co00002_ooool4o`0000Sooooo0_l00010ooooo`007?ooool00ol0003o
ooooooooo`0eooooo`;o00002Oooool2o`0000gooooo0_l00008ooooo`Co00001_ooool3o`000005
ooooool0003o0000o`000?ooool00_l00003ooooo`;o00002Oooool2o`0000;ooooo0_l00003oooo
o`Go00000_ooool2o`0000Gooooo0ol0000>ooooo`;o00000_ooool3o`0000_ooooo4_l00009oooo
o`;o00002?ooool2o`0001?ooooo1?l00008ooooo`;o00002_ooool2o`00043ooooo000Looooo`03
o`000?oooooooooo043ooooo0_l00008ooooo`;o00000oooool3o`0000Gooooo1_l00007ooooo`;o
00000oooool2o`0000[ooooo0_l00004ooooo`;o00004_ooool2o`000005ooooool0003o0000o`00
0?ooool00_l0000;ooooo`Ko00003?oooolDo`0000Oooooo0_l00002ooooo`;o00004?ooool2o`00
00Wooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o00001?ooool2o`0000Go
oooo1?l0000>ooooo`;o00002_ooool2o`0000cooooo0ol00009ooooo`;o00000oooool4o`0000go
oooo0_l0000?oooooa3o000000?oooooo`000?l000002oooool2o`0000gooooo0_l000000ooooooo
0000o`000003ooooo`;o00000_ooool4o`0005Kooooo000Looooo`03o`000?oooooooooo05Cooooo
0_l0000:ooooo`;o00001?ooool2o`0001Cooooo0_l000001Ooooooo0000o`000?l0003ooooo00?o
00003_ooool3o`0000kooooo0_l0000?oooooaCo00006Oooool2o`0000Kooooo0_l00002ooooo`;o
00001?ooool4o`000003ooooool0003o000000;ooooo0_l00019ooooo`007?ooool00ol0003ooooo
ooooo`1Dooooo`;o00002_ooool2o`0000;ooooo1?l0000?ooooo`;o000000?oooooo`000?l00000
0_l000001?oooooo0000o`000?l00008ooooo`;o00002Oooool2o`0000Kooooo0_l00002ooooo`;o
00000_ooool2o`000003ooooool0003o000000gooooo0_l00002ooooo`;o000000?oooooo`000?l0
00002_l0000Kooooo`;o00001?ooool2o`0000;ooooo0_l00003ooooo`Go000000?oooooo`000?l0
00001?l00019ooooo`007?ooool2o`0004[ooooo0_l0000@ooooo`;o00001_ooool3o`0000gooooo
0_l00002ooooo`;o000000?oooooo`000?l000001?ooool2o`0000?ooooo0_l00003ooooo`;o0000
0oooool2o`0000cooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o0000017ooooo
0_l00002ooooo`Ko00008?ooool3o`000003ooooool0003o000000Cooooo0ol00002ooooo`;o0000
1_ooool3o`0004[ooooo000Looooo`03o`000?oooooooooo04Wooooo0_l0000<ooooo`;o00000_oo
ool2o`0000Kooooo0_l00006ooooo`;o00001_ooool2o`000005ooooool0003o0000o`000?ooool0
0_l00004ooooo`;o00000oooool2o`0000Sooooo0_l000000ooooooo0000o`000007ooooo`Oo0000
0oooool5o`0001Gooooo0ol00007ooooo`?o00006_ooool2o`000003ooooool0003o000000Gooooo
0_l00006ooooo`;o00000oooool4o`0004Sooooo000Looooo`03o`000?oooooooooo04Sooooo0_l0
0007ooooo`;o00000_ooool5o`00017ooooo0_l00003ooooo`;o00001?ooool3o`000003ooooool0
003o000000;o00000oooool2o`0000Kooooo0_l00004ooooo`;o000000?oooooo`000?l000001ooo
ool2o`000003ooooool0003o000000;o00000oooool5o`00017ooooo0_l00003ooooo`;o00001ooo
ool4o`0000Sooooo0_l0000Qooooo`;o00001Oooool2o`0004Sooooo000Looooo`03o`000?oooooo
oooo03_ooooo0_l0000:ooooo`?o00001oooool2o`0000;ooooo1Ol0000Cooooo`;o000000?ooooo
o`000?l000000oooool3o`0000;ooooo1?l00003ooooo`;o00000oooool5o`0000Cooooo1?l0000=
ooooo`;o00000oooool4o`0001;ooooo1?l00004ooooo`;o00000oooool5o`0000Sooooo0_l0000Q
ooooo`;o00001Oooool2o`0000Sooooo0ol0000mooooo`007?ooool00ol0003oooooooooo`0joooo
o`?o00002Oooool3o`0000Cooooo0_l00003ooooo`;o000000Coooooo`000?l0003o00003_ooool2
o`0000Gooooo0_l000001?oooooo0000o`000?l00002ooooo`?o00003?ooool5o`000004ooooool0
003o0000ooooo`;o000000Coooooo`000?l0003o0000:_ooool4o`0000;ooooo0_l000000ooooooo
0000o`000002o`000003ooooool0003o000000[ooooo0_l0000Fooooo`;o00001oooool2o`0000go
oooo1Ol0000mooooo`007?ooool00ol0003oooooooooo`0jooooo`;o00001Oooool2o`0000?ooooo
0_l00005ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`;o00000oooool2o`0000Oo
oooo0_l00008ooooo`?o00003?ooool2o`0000?ooooo0ol00003ooooo`;o000000Coooooo`000?l0
003ooooo1?l0000Booooo`;o000000?oooooo`000?l000005?ooool4o`0000;ooooo0ol00003oooo
o`Go00001oooool2o`0001Kooooo0ol0000;ooooo`;o00002?ooool2o`000003ooooool0003o0000
03gooooo000Looooo`03o`000?oooooooooo02_ooooo0_l0000Dooooo`;o00005Oooool2o`0000?o
oooo0_l00003ooooo`;o00001_ooool2o`0000Gooooo0_l000000ooooooo0000o`000002ooooo`;o
00001Oooool3o`0000;ooooo0_l00003ooooo`Go00000_ooool4o`0001;ooooo0_l000000ooooooo
0000o`00000Fooooo`;o00000_ooool3o`0000Cooooo1?l0000Oooooo`?o00001_ooool3o`000004
ooooool0003o0000o`0000kooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o
00004_ooool2o`0000Gooooo0_l00007ooooo`;o00001oooool2o`0000Kooooo1?l00006ooooo`;o
00001?ooool3o`000005ooooool0003o0000o`000?ooool00_l000001?oooooo0000o`000?l00002
ooooo`;o000000?oooooo`000?l000001?ooool6o`000003ooooool0003o000000?o00002?ooool2
o`000003ooooool0003o000002Cooooo0_l00004ooooo`;o00008_ooool2o`0000Gooooo1?l00000
0ooooooo0000o`00000?ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0?oooool2o`00
00Gooooo0_l00006ooooo`?o00003oooool4o`000003ooooool0003o000000Wooooo0ol00002oooo
o`;o00001?ooool:o`0000;ooooo2Ol00002ooooo`?o000000?oooooo`000?l000001?ooool3o`00
0003ooooool0003o000000Sooooo0_l0000Pooooo`;o00002oooool2o`0001Cooooo1?l00004oooo
o`;o00000oooool2o`0004_ooooo000Looooo`03o`000?oooooooooo03oooooo0_l0000<ooooo`Go
00004oooool2o`0000Oooooo0_l00005ooooo`;o00000oooool:o`0000?ooooo1?l000000ooooooo
0000o`000002o`0000;ooooo0_l00002ooooo`;o00000oooool3o`0000_ooooo0ol0000Yooooo`;o
00000_ooool2o`00017ooooo0_l000000ooooooo0000o`000002o`0000Wooooo0_l0001;ooooo`00
7?ooool00ol0003oooooooooo`0fooooo`;o00001oooool2o`0000cooooo0_l000001?oooooo0000
o`000?ooool2o`0000cooooo0_l00006ooooo`;o00000oooool3o`0000Gooooo0ol000000ooooooo
0000o`00000;o`0000Cooooo0ol00003ooooo`Co00000oooool2o`000003ooooool0003o000000;o
oooo0_l00008ooooo`;o0000:_ooool2o`0000;ooooo0ol0000@ooooo`;o000000?oooooo`000?l0
00000_l0000;ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0=_ooool2o`0001_ooooo
0ol000000ooooooo0000o`000004o`0000Cooooo0ol00003ooooo`Co00001?ooool2o`0000;ooooo
1ol000000ooooooo0000o`000004o`000003ooooool0003o000000Co00000_ooool3o`0000?ooooo
2_l000000ooooooo0000o`000004o`0001[ooooo1Ol0000?ooooo`;o00002Oooool2o`0001?ooooo
1?l0000;ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0:?ooool2o`0001Gooooo0_l0
000Cooooo`;o000000?oooooo`000?l000001?l00005ooooo`;o00000oooool5o`0000;ooooo3?l0
00000ooooooo0000o`00000;o`000005ooooool0003o0000o`000?ooool00_l000000ooooooo0000
o`000008o`000003ooooool0003o000000?o00001Oooool2o`0001Cooooo1ol0000=ooooo`?o0000
7?ooool2o`0000?ooooo0_l00008ooooo`?o00003_ooool2o`0003Wooooo000Looooo`03o`000?oo
oooooooo02?ooooo0_l00003ooooo`;o00002_ooool2o`0000Wooooo0_l0000;ooooo`;o00004?oo
ool2o`0000Cooooo0_l000001?oooooo0000o`000?oooolUo`000003ooooool0003o000000;o0000
1?ooool2o`0000?ooooo0ol00005ooooo`;o00003oooool2o`0000Sooooo0_l0000>ooooo`;o0000
2?ooool2o`0000Gooooo0_l0000;ooooo`;o00000oooool2o`0000Sooooo0_l0000?ooooo`;o0000
>Oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413o
ooooooooo`04ooooo`03o`000?oooooooooo02?ooooo0_l0000?ooooo`;o00004Oooool2o`0000?o
oooo0_l0000=ooooo`;o000000?oooooo`000?l000001?ooool7o`000003ooooool0003o000002?o
00000_ooool4o`0000Kooooo0ol00006ooooo`;o00001Oooool2o`0000Oooooo0_l00003ooooo`Co
00005Oooool2o`0000?ooooo0ol00005ooooo`;o00005_ooool2o`0000;ooooo0_l00002ooooo`;o
00001_ooool2o`0003kooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0@_ooool2o`0000?ooooo0_l000000ooo
oooo0000o`000002o`0000gooooo0ol00006ooooo`Co000000?oooooo`000?l000000_oooolTo`00
00;ooooo1?l00003ooooo`;o00000_ooool2o`0000Gooooo0ol00005ooooo`;o00000_ooool2o`00
00;ooooo0_l00003ooooo`Ko00004_ooool4o`0000?ooooo0_l0000Aooooo`;o00002oooool2o`00
00;ooooo0_l00002ooooo`;o00001?ooool4o`0003kooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00Wooooo1Ol00006ooooo`03o`000?oooooooooo02Kooooo0_l0000Cooooo`;o
000000?oooooo`000?l000000_ooool3o`0000Gooooo1?l0000=ooooo`Go00001Oooool2o`0000;o
oooo0_l00002ooooobGo00000oooool4o`000003ooooool0003o000000Sooooo0ol00003ooooo`;o
00001Oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool4o`00013ooooo0_l0000Hooooo`;o
00002oooool2o`0000cooooo0_l00006ooooo`;o0000>?ooool00003ooooool0003ooooo00;ooooo
00?o0000ooooooooool02Oooool01?m4A4CogMgMooooool00007ooooo`?o00009_ooool2o`0001?o
oooo1Ol00003ooooo`;o00005_ooool2o`000003ooooool0003o000000Wooooo0_l00002ooooo`ko
000000?oooooo`000?l000005?l00003ooooo`Go00001oooool2o`000003ooooool0003o000000Co
oooo0ol0000;ooooo`;o00000oooool2o`000003ooooool0003o0000013ooooo0_l00007ooooo`;o
00004_ooool2o`0000[ooooo0_l00004ooooo`;o00002oooool3o`0003Sooooo00000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003o
ooooooooo`0`ooooo`;o00002oooool2o`0000Kooooo1?l00006ooooo`;o00001?ooool4o`0000So
oooo0_l00006ooooo`;o000000?oooooo`000?l000008?l00003ooooo`;o00000oooool4o`0000?o
oooo0_l00002ooooo`;o000000?oooooo`000?l000001Oooool2o`0000_ooooo0_l00003ooooo`;o
00004oooool2o`0000Oooooo0_l0000Booooo`;o00002_ooool2o`0000Cooooo0_l0000;ooooo`Co
0000=oooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00omgMgOoc<c<
o`000007ooooo`03o`000?oooooooooo02oooooo0ol0000Cooooo`Co00000oooool2o`000003oooo
ool0003o000000Cooooo1?l00008ooooo`;o00001_ooool9o`000003ooooool0003o000001Oo0000
00?oooooo`000?l000001?l00002ooooo`?o00001Oooool2o`0000Gooooo0ol00007ooooo`;o0000
1_ooool2o`0000;ooooo0_l0000:ooooo`;o00006_ooool2o`0001Oooooo0_l0000<ooooo`;o0000
1Oooool2o`0003Oooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l0
00001oooool00ol0003oooooooooo`0_ooooo`;o00004_ooool2o`0000;ooooo0_l000000ooooooo
0000o`000002o`0001_ooooo2Ol000000ooooooo0000o`00000No`000003ooooool0003o000000?o
00003?ooool2o`0000Kooooo0ol00006ooooo`So00002?ooool2o`0000?ooooo1Ol000000ooooooo
0000o`000002o`0000gooooo0_l0000<ooooo`;o00001_ooool5o`0000cooooo0_l0000nooooo`00
00Koooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000oooo
ooooool0@oooool2o`0000;ooooo1Ol0000Hooooo`;o000000?oooooo`000?l000001?oooolVo`00
0003ooooool0003o000000Go00004_ooool2o`0000Gooooo0_l00002ooooo`;o00000_ooool2o`00
00[ooooo3Ol000001?oooooo0000o`000?l0000Fooooo`?o00001Oooool6o`0000Gooooo0_l00006
ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0BOooool2o`0000;ooooo0_l00003oooo
o`;o00004?ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l00000:?l00002
ooooo`?o00001_ooool4o`0000Oooooo0_l00005ooooo`;o00003_oooolGo`0001Cooooo0_l00006
ooooo`;o00000_ooool2o`0000Gooooo0_l00006ooooo`;o0000?Oooool001cooooo00?o0000oooo
ooooool0Aoooool3o`0000?ooooo0_l00003ooooo`;o00005_ooool2o`000003ooooool0003o0000
01;o000000?oooooo`000?l000001?l000000ooooooo0000o`00000=o`0000;ooooo0_l00006oooo
o`Co00001_ooool2o`0001;ooooo0_l00002ooooo`Ko000000?oooooo`000?l000003ol0000Koooo
o`;o00001?ooool2o`0000;ooooo0ol00015ooooo`007?ooool00ol0003oooooooooo`0jooooo`;o
00002oooool3o`0000;ooooo0_l000000ooooooo0000o`00000KoooooaOo000000Coooooo`000?l0
003ooooo2_l00005ooooo`;o000000?oooooo`000?l000004Oooool2o`0000Cooooo0_l00008oooo
o`;o00000_ooool2o`0000?ooooo5ol00002ooooo`;o00003Oooool2o`0000;ooooo0_l00006oooo
o`;o00000_ooool2o`0000;ooooo0ol00009ooooo`?o0000>Oooool001cooooo00?o0000oooooooo
ool0>_ooool2o`0000Cooooo0_l0000:ooooo`;o000000?oooooo`000?l000006oooool2o`0000;o
oooo5_l000000ooooooo0000o`000009o`000005ooooool0003o0000o`000?ooool01?l0000Goooo
o`;o00002?ooool2o`000004ooooool0003o0000ooooo`ko000000?oooooo`000?l000002?l00003
ooooo`;o00003Oooool2o`0000;ooooo0_l00004ooooo`Co00001oooool2o`0000Wooooo0ol0000i
ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00001?ooool2o`0000Cooooo0_l0000Koooo
o`;o000000?oooooo`000?l000000_l000000ooooooo0000o`00000Oo`000003ooooool0003o0000
00Oo00008?ooool2o`000004ooooool0003o0000oooooaOo000000?oooooo`000?l000006_ooool3
o`0000[ooooo0_l00008ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool08Oooool2o`00
01[ooooo0_l000000ooooooo0000o`000004ooooo`;o00000_ooool2o`00013ooooo0_l00004oooo
o`;o00001Oooool2o`000003ooooool0003o000002Co00000oooool3o`0000;ooooo0_l0000Uoooo
oa_o000000Coooooo`000?l0003ooooo0_l0000Dooooo`;o00001?ooool2o`0000Cooooo0ol0000<
ooooo`;o0000=_ooool001cooooo00?o0000ooooooooool08Oooool3o`0001Wooooo0ol00005oooo
o`;o00000oooool2o`00013ooooo0_l00004ooooo`;o00001_oooolXo`000003ooooool0003o0000
00?o000000?oooooo`000?l000005?ooool2o`0000Kooooo0_l00002ooooo`;o00000_oooolHo`00
0005ooooool0003o0000o`000?ooool00ol000000ooooooo0000o`000002ooooo`;o00005_ooool2
o`0000Cooooo0_l0000=ooooo`;o0000=_ooool001cooooo00?o0000ooooooooool08_ooool2o`00
01[ooooo0_l00005ooooo`;o00001Oooool2o`0000Wooooo0_l0000;ooooo`;o00001?oooolXo`00
0003ooooool0003o000000;o00000_ooool2o`0001Cooooo0_l00003ooooo`;o000000?oooooo`00
0?l000000_ooool8o`000003ooooool0003o000000oo000000?oooooo`000?l000000ol000000ooo
oooo0000o`000002o`0000?ooooo0ol0000@ooooo`Co0000Coooool001cooooo00?o0000oooooooo
ool07oooool2o`0001Kooooo0_l00005ooooo`;o00000_ooool2o`000003ooooool0003o000000Go
oooo0_l00005ooooo`Ko00001Oooool3o`0000?ooooo0ol00003ooooobKo00000_ooool6o`0000ko
oooo0_l00003ooooo`;o00001Oooool5o`000003ooooool0003o000000?ooooo0_l000000ooooooo
0000o`00000Ao`0000;ooooo2ol00003ooooo`;o00001_ooool2o`0000Wooooo1?l00005ooooo`;o
0000B?ooool001cooooo00?o0000ooooooooool07oooool2o`0001Gooooo0ol00005ooooo`;o0000
0_ooool2o`0000_ooooo0_l00002ooooo`Co000000Coooooo`000?l0003o00000oooool3o`0000Co
oooo1?l000000ooooooo0000o`00000/o`0000kooooo2Ol00003ooooo`So00002?oooolAo`000003
ooooool0003o000000Oo00003_ooool2o`0000Oooooo1Ol00006ooooo`?o000000?oooooo`000?l0
0000A?ooool001cooooo00?o0000ooooooooool0=_ooool2o`0000Wooooo1_l00008ooooo`;o0000
1oooool3o`0000Cooooo0_l00006ooooo`;o000000?oooooo`000?l00000;?l0000@ooooo`Co0000
00?oooooo`000?l000001_ooool7o`000003ooooool0003o000000;o000000?oooooo`000?l00000
2?l000000ooooooo0000o`000004o`000003ooooool0003o000000Oo00004?ooool2o`0000Gooooo
1Ol000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l00000A?ooool001cooooo0_l0
000gooooo`;o00000_ooool2o`0000Gooooo1_l0000;ooooo`;o00005_ooool2o`000003ooooool0
003o0000027o000000?oooooo`000?l000001Ol00009ooooo`?o00003oooool4o`000003ooooool0
003o000000;o000000?oooooo`000?l000000_l00002oooooa[o000000?oooooo`000?l000003Ooo
ool2o`0000_ooooo0_l0000=ooooo`;o00001oooool2o`0003Gooooo000Looooo`03o`000?oooooo
oooo03[ooooo0_l00006ooooo`;o00003_ooool2o`00017ooooo0_l00004ooooo`;o00000_oooolT
o`000003ooooool0003o000000_ooooo0ol0000?ooooo`;o00000_ooool2o`0000;ooooo0_l00007
oooooaco000000?oooooo`000?l000000_ooool2o`0002;ooooo0_l00007ooooo`;o0000=Oooool0
01cooooo00?o0000ooooooooool0>Oooool3o`0000Wooooo0_l0000Nooooo`;o000000Coooooo`00
0?l0003ooooo0_l000000ooooooo0000o`00000So`000003ooooool0003o000000;o00004oooool2
o`0000Oooooo0_l000000ooooooo0000o`000002ooooo`;o00001_oooolKo`0000?ooooo0_l00002
ooooo`;o00005Oooool2o`0000[ooooo1?l0000mooooo`007?ooool00ol0003oooooooooo`0ioooo
o`?o00002Oooool2o`000003ooooool0003o000000;ooooo0_l0000Iooooo`Go000000?oooooo`00
0?l000008?l00002ooooo`;o000000?oooooo`000?l000000_l0000<ooooo`;o00001Oooool2o`00
00Oooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l00003oooooaOo000000?oooooo`00
0?l000000_l0000Mooooo`;o00002_ooool4o`0003gooooo000Looooo`03o`000?oooooooooo04?o
oooo0_l00002ooooo`?o00000_ooool2o`0001Oooooo2_l000000ooooooo0000o`00000No`000004
ooooool0003o0000ooooo`;o00003_ooool2o`0000?ooooo0_l00008ooooo`;o00000oooool3o`00
00?ooooo1?l000000ooooooo0000o`00000Jo`0000gooooo0ol00008ooooo`;o00000oooool4o`00
00Wooooo0_l00004ooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0?_ooool2o`0000?o
oooo0_l00002ooooo`;o00007?ooool2o`000003ooooool0003o000000;ooooo0_l00002ooooob3o
000000?oooooo`000?l000004Oooool2o`0000?ooooo0_l00008ooooo`;o00000oooool2o`0000?o
oooo0_l000001?oooooo0000o`000?oooolIo`00013ooooo0ol00008ooooo`;o00000oooool4o`00
0003ooooool0003o000000cooooo1Ol0000eooooo`007?ooool00ol0003oooooooooo`0nooooo`;o
00000oooool2o`0000Kooooo0_l0000SoooooaOo000000?oooooo`000?l000000_l000001?oooooo
0000o`000?ooool5o`0000gooooo1?l00007ooooo`;o00001?ooool2o`0000Sooooo1?l000000ooo
oooo0000o`00000Ho`00017ooooo0_l00002ooooo`;o00003_ooool2o`0000Gooooo0_l00007oooo
o`?o0000=Oooool001cooooo00?o0000ooooooooool0=_ooool2o`0000Kooooo0_l0000:ooooo`?o
000000?oooooo`000?l000003_ooool2o`0000Wooooo0_l00005oooooaOo000000?oooooo`000?l0
00000_ooool3o`000003ooooool0003o000000Co00003?ooool2o`0000Wooooo0_l00004ooooo`;o
00001Oooool2o`0000?ooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000001?o
00004oooool3o`000003ooooool0003o000001;ooooo0ol0000nooooo`007?ooool00ol0003ooooo
ooooo`0fooooo`;o00001_ooool2o`0000[ooooo0_l00002ooooo`;o00003_ooool3o`0000Sooooo
0_l00007oooooa?o000000?oooooo`000?l000001?ooool4o`0000?ooooo0ol00004ooooo`;o0000
1_ooool2o`0000Sooooo0_l00004ooooo`Co000000Coooooo`000?l0003ooooo0_l00008ooooo`?o
000000?oooooo`000?l000005?l000000ooooooo0000o`00000:ooooo`;o00000oooool2o`0000;o
oooo0_l0000Cooooo`;o0000?_ooool001cooooo00?o0000ooooooooool06oooool2o`0001Wooooo
0_l00002ooooo`;o00000oooool2o`0001kooooo0_l00005ooooo`;o00003?oooolDo`0000Cooooo
1?l00003ooooo`;o00001Oooool2o`0000Gooooo0ol00002ooooo`;o00001?ooool2o`0000;ooooo
1_l000001?oooooo0000o`000?ooool2o`0000Kooooo6Ol000001?oooooo0000o`000?ooool2o`00
0003ooooool0003o000000Oooooo0_l00009ooooo`;o0000DOooool001cooooo00?o0000oooooooo
ool06oooool2o`0001Wooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l0000Tooooo`?o
00003?ooool4o`0000;ooooo4Ol000000ooooooo0000o`000003o`0000Kooooo0_l00008ooooo`;o
00000_ooool3o`0000Sooooo1?l00006ooooo`;o00001_ooool2o`0000;ooooo5_l00006ooooo`;o
00004_ooool2o`0000_ooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0jooooo`;o0000
00Coooooo`000?l0003ooooo0_l00006ooooo`;o00006oooool3o`0000Cooooo0_l00002ooooo`;o
00000oooool3o`0000?ooooo1ol00002ooooo`;o000000?oooooo`000?l000000_l00002ooooo`Co
00000oooool5o`0000?ooooo0_l00007ooooo`;o00001_ooool2o`0000;ooooo0ol00003ooooo`;o
00002?oooolAo`000003ooooool0003o000000Oo00009oooool4o`000003ooooool0003o000003oo
oooo000Looooo`03o`000?oooooooooo03Wooooo0ol00002ooooo`Co00001_ooool2o`0001cooooo
1?l00002ooooo`;o00000_ooool2o`0000Cooooo1Ol000000ooooooo0000o`000004o`0000;ooooo
1?l00003ooooo`;o00001oooool3o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000Co
oooo0_l00006ooooo`;o00000oooool2o`0000?ooooo0_l00008oooooaGo000000Coooooo`000?l0
003ooooo0_l0000>ooooo`;o00006Oooool2o`000003ooooool0003o000000Cooooo0_l0000ioooo
o`007?ooool00ol0003oooooooooo`0booooo`;o000000?oooooo`000?l000000_ooool2o`0000?o
oooo0_l0000Oooooo`;o00001oooool2o`0000Cooooo1?l00004ooooo`Go00000_ooool;o`0000?o
oooo0_l000000ooooooo0000o`000009ooooo`;o00001?ooool2o`0000Cooooo0_l00009ooooo`Go
00004?oooolBo`0001?ooooo0_l0000:ooooo`;o00000oooool4o`0000oooooo0_l0000iooooo`00
7?ooool00ol0003oooooooooo`0booooo`;o000000?oooooo`000?l000002?ooool2o`0001kooooo
1?l00005ooooo`;o00001?ooool4o`0000Cooooo0ol00004ooooo`Wo00000_ooool2o`0000Cooooo
0_l0000=ooooo`Co00003oooool5o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o0000
1_ooool@o`0001?ooooo0_l0000:ooooo`;o00000oooool4o`0001Gooooo0_l0000cooooo`007?oo
ool00ol0003oooooooooo`0fooooo`;o00001?ooool5o`0000;ooooo1?l0000Jooooo`;o00003ooo
ool2o`0000;ooooo1Ol00002ooooo`Wo00000_ooool2o`000003ooooool0003o000000Gooooo0_l0
0002ooooo`;o00001Oooool4o`0000_ooooo0_l000000ooooooo0000o`000003o`0000;ooooo0_l0
0003ooooo`;o00000_ooool2o`0000;ooooo1?l00002ooooo`Go00000_ooool2o`000003ooooool0
003o000000?o00004?ooool2o`0000gooooo0_l0000Kooooo`;o0000<oooool001cooooo0_l0000c
ooooo`?o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000003o`0000;ooooo1?l0
000[ooooo`;o00001Oooool4o`0000Kooooo0ol00005ooooo`;o00001Oooool6o`0000;ooooo0_l0
00001?oooooo0000o`000?l0000<ooooo`So00001_ooool2o`0000;ooooo0_l00003ooooo`Co0000
1?ooool7o`0000;ooooo1?l000000ooooooo0000o`00000=ooooo`;o00003Oooool2o`0000Gooooo
0_l00007ooooo`?o0000?oooool001cooooo00?o0000ooooooooool0<_ooool3o`0000Cooooo0_l0
0002ooooo`;o000000?oooooo`000?l00000<_ooool3o`000004ooooool0003o0000ooooo`Co0000
1?ooool2o`000003ooooool0003o000000Oooooo0_l00003ooooo`Co00000_ooool2o`0000;ooooo
0_l0000<ooooo`Ko00002?ooool2o`0000;ooooo0_l0000;ooooo`Ko00001Oooool2o`000003oooo
ool0003o000001kooooo0_l00002ooooo`?o00001?ooool2o`000004ooooool0003o0000o`0003oo
oooo000Looooo`03o`000?oooooooooo03Gooooo0_l00006ooooo`;o000000?oooooo`000?l00000
<_ooool3o`000005ooooool0003o0000o`000?ooool00ol00004ooooo`;o000000?oooooo`000?l0
00001Oooool;o`0001?ooooo0ol00002ooooo`;o00006?ooool2o`000003ooooool0003o000000;o
oooo1Ol0000Sooooo`;o00000_ooool2o`0000Cooooo0ol00008ooooo`;o0000>Oooool001cooooo
00?o0000ooooooooool0=Oooool2o`0001Kooooo0_l0000Zooooo`Co00002Oooool2o`0000Gooooo
0_l000000ooooooo0000o`000003o`0000Cooooo0_l0000?ooooo`Go00000_ooool2o`0000;ooooo
0_l0000=ooooo`;o00001?ooool5o`0000;ooooo1Ol0000<ooooo`;o00004_ooool3o`0000[ooooo
0_l00009ooooo`;o00000_ooool2o`0003Gooooo000Looooo`03o`000?oooooooooo04gooooo0_l0
000Hooooo`;o00000oooool2o`0000Cooooo1?l00005ooooo`;o00000oooool2o`0000Wooooo0_l0
0003ooooo`?o00001_ooool2o`0000oooooo0_l000000ooooooo0000o`000002ooooo`;o00000_oo
ool2o`0000gooooo0_l00006ooooo`;o00000oooool2o`0000Sooooo0_l00005ooooo`;o00000ooo
ool2o`0000gooooo0ol00003ooooo`;o00005?ooool2o`0003Gooooo000Looooo`03o`000?oooooo
oooo037ooooo0_l0000dooooo`;o00000oooool2o`0000;ooooo1ol00009ooooo`?o00000_ooool2
o`0000Cooooo0_l0000Mooooo`Ko00001Oooool2o`0001[ooooo0_l00008ooooo`;o00002?ooool4
o`0001?ooooo0_l0000Booooo`;o0000=oooool001cooooo00?o0000ooooooooool0<?ooool3o`00
0004ooooool0003o0000ooooo`;o00005Oooool2o`0001;ooooo0_l0000<ooooo`;o00000oooool2
o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o00000_ooool2o`0001;ooooo0_l0000A
ooooo`Co00001Oooool2o`0001Oooooo1_l000000ooooooo0000o`000002o`0000_ooooo0ol0000M
ooooo`;o00002_ooool2o`0003Oooooo000Looooo`03o`000?oooooooooo033ooooo0_l00002oooo
o`Oo00003Oooool2o`0000?ooooo0ol0000Booooo`?o000000?oooooo`000?l000001?ooool3o`00
00;ooooo0_l00006ooooo`;o000000Coooooo`000?l0003o00003Oooool2o`0000[ooooo0ol0000C
ooooo`?o00007Oooool6o`000003ooooool0003o000000;o00002oooool2o`00013ooooo0_l00002
ooooo`;o00001?ooool2o`0000;ooooo0_l0000<ooooo`;o0000=Oooool001cooooo00?o0000oooo
ooooool0=_ooool5o`000003ooooool0003o000000;o00002?ooool2o`0000?ooooo0_l0000Boooo
o`Co000000?oooooo`000?l000001?ooool3o`0000;ooooo0_l00004ooooo`;o000000?oooooo`00
0?l000000ol0000<ooooo`?o00002Oooool4o`0000;ooooo0_l00005ooooo`;o00002Oooool2o`00
023ooooo0_l0000Sooooo`;o00000_ooool2o`0000Cooooo0_l00002ooooo`;o00001_ooool2o`00
00Cooooo0_l0000eooooo`007?ooool00ol0003oooooooooo`0dooooo`;o00000_ooool2o`0000;o
oooo1?l0000Qooooo`;o00003Oooool2o`0000Gooooo0_l000000ooooooo0000o`000002o`0000go
oooo0_l0000:ooooo`Co00000_ooool2o`0000Gooooo0_l0000Looooo`;o00003?ooool2o`000004
ooooool0003o0000o`0003Kooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0dooooo`;o
00001oooool2o`00037ooooo0_l0000<ooooo`;o00002?ooool2o`0000gooooo0_l0000Yooooo`;o
000000?oooooo`000?l000002Oooool2o`000004ooooool0003o0000o`00017ooooo0_l0000Coooo
o`;o00003Oooool2o`0000Oooooo0_l0000cooooo`007?ooool00ol0003oooooooooo`0Looooo`;o
00007oooool2o`0002Sooooo0_l0000:ooooo`;o00001Oooool2o`0000;ooooo0ol00002ooooo`;o
000000?oooooo`000?l000000_l0000<ooooo`;o00004Oooool2o`0001Oooooo0_l000000ooooooo
0000o`000002o`0000Kooooo0_l0000Fooooo`Co00003_ooool2o`000003ooooool0003o000000[o
oooo0_l000000ooooooo0000o`000002o`0000Gooooo0_l000000ooooooo0000o`00000`ooooo`00
7?ooool00ol0003oooooooooo`0Looooo`;o00005oooool2o`0000[ooooo0_l0000Sooooo`?o0000
2_ooool2o`0000?ooooo1?l00003ooooo`Wo00001?ooool2o`0000Oooooo0ol0000Aooooo`;o0000
2?ooool2o`0000cooooo0_l000001?oooooo0000o`000?ooool2o`0000Kooooo0_l00009ooooo`;o
00001_ooool2o`0000?ooooo1?l0000>ooooo`;o00001oooool2o`000004ooooool0003o0000oooo
o`;o00000oooool2o`0000Gooooo0_l000000ooooooo0000o`00000`ooooo`007?ooool00ol0003o
ooooooooo`0eooooo`;o00002_ooool4o`00027ooooo0_l00009ooooo`;o00001Oooool2o`0000Ko
oooo0ol000000ooooooo0000o`000006ooooo`;o00001Oooool4o`0000;ooooo0ol0000Booooo`;o
00000oooool2o`0000cooooo0_l000001?oooooo0000o`000?ooool2o`00017ooooo0_l00006oooo
o`;o00004_ooool2o`0000[ooooo0_l000000ooooooo0000o`000012ooooo`007?ooool00ol0003o
ooooooooo`0fooooo`Co00002Oooool2o`0000Sooooo0_l0000Dooooo`;o00000_ooool2o`0000So
oooo0_l00003ooooo`;o00000_ooool2o`0000Wooooo0_l000000ooooooo0000o`000009ooooo`;o
00000_ooool5o`0000Cooooo0_l00002ooooo`;o00001oooool3o`0001Kooooo0ol00006ooooo`?o
00009?ooool2o`0000Kooooo1_l00015ooooo`007?ooool00ol0003oooooooooo`0fooooo`Co0000
0_ooool2o`000003ooooool0003o000000cooooo0_l0000Dooooo`Ko00003?ooool3o`0000;ooooo
0_l00002ooooo`;o00001Oooool5o`0000[ooooo0_l000000ooooooo0000o`000002o`0000Gooooo
0_l00002ooooo`Co000000?oooooo`000?l000000_ooool3o`0001Kooooo0_l00004ooooo`;o0000
00Coooooo`000?l0003o00009?ooool4o`0000?ooooo1Ol0000<ooooo`;o000000Coooooo`000?l0
003ooooo0_l0000cooooo`007?ooool2o`0001gooooo0_l0000Eooooo`?o00001_ooool2o`000003
ooooool0003o000002?ooooo1Ol0000<ooooo`;o00001oooool2o`0000Oooooo0_l0000:ooooo`?o
00004?ooool2o`000003ooooool0003o000000?ooooo0_l0000Aooooo`;o00002?ooool3o`000003
ooooool0003o000000?o00008_ooool4o`0000?ooooo0_l0000?ooooo`;o000000Coooooo`000?l0
003ooooo0_l0000cooooo`007?ooool00ol0003oooooooooo`0Looooo`;o00005Oooool3o`00017o
oooo0_l0000Nooooo`;o00004oooool2o`0001Gooooo0ol0000?ooooo`?o00000_ooool2o`0001Go
oooo0ol00002ooooo`Co000000Goooooo`000?l0003o0000ooooo`05o`0000Wooooo0_l0000Goooo
o`;o0000DOooool001cooooo00?o0000ooooooooool0=Oooool2o`0000oooooo0ol0000Looooo`;o
00000oooool2o`0000kooooo1?l0000Eooooo`?o00003Oooool9o`0001Gooooo0ol00002ooooo`Co
00000_ooool2o`0000oooooo0_l0000Looooo`;o0000C?ooool001cooooo00?o0000ooooooooool0
=Oooool2o`0000oooooo0_l0000Eooooo`?o00001Oooool2o`0000?ooooo0_l0000>ooooo`;o0000
00?oooooo`000?l000003Oooool2o`0000Kooooo0_l000000ooooooo0000o`000002o`0000Sooooo
0_l000000ooooooo0000o`000008o`0001Gooooo0_l00002ooooo`;o000000?oooooo`000?l00000
0ol0000<ooooo`;o00007?ooool2o`00017ooooo0_l0000iooooo`007?ooool00ol0003ooooooooo
o`0booooo`;o00005?ooool2o`0000;ooooo0_l0000?ooooo`?o00001Oooool2o`000003ooooool0
003o000001?ooooo0_l0000=ooooo`;o00002Oooool4o`0000[ooooo1_l000000ooooooo0000o`00
0002o`0000kooooo0_l00005ooooo`Ko000000?oooooo`000?l000000ol00002ooooo`;o00000_oo
ool4o`0001kooooo0_l000000ooooooo0000o`000002o`0000kooooo0_l00004ooooo`;o0000<ooo
ool001cooooo00?o0000ooooooooool0<_ooool4o`0000Oooooo0_l00004ooooo`;o000000?ooooo
o`000?l000000_l00002ooooo`;o00005_ooool2o`0000;ooooo0_l0000?ooooo`;o000000?ooooo
o`000?l000000_ooool2o`0000Sooooo1?l0000Gooooo`?o000000?oooooo`000?l000000ol0000@
ooooo`;o00001Oooool9o`000003ooooool0003o000000[o00002_ooool2o`0001;ooooo0_l00000
0ooooooo0000o`000002o`0000Gooooo0_l00003ooooo`;o00002?ooool2o`0003?ooooo000Loooo
o`03o`000?oooooooooo03Cooooo0_l00007ooooo`;o00000_ooool4o`000003ooooool0003o0000
01[ooooo1?l0000Cooooo`;o000000?oooooo`000?l000001?l00008ooooo`;o00005Oooool2o`00
00Cooooo0_l000000ooooooo0000o`000002o`0001Gooooo2_l00002ooooo`Co000000?oooooo`00
0?l000000ol000000ooooooo0000o`000009ooooo`;o00005Oooool2o`0000Oooooo0_l00003oooo
o`;o0000?Oooool001cooooo00?o0000ooooooooool07_ooool2o`0001Kooooo0_l00003ooooo`;o
000000Coooooo`000?l0003ooooo0_l00008ooooo`;o00005Oooool4o`0001;ooooo2?l00003oooo
o`;o00001Oooool2o`0001Gooooo0_l00002ooooo`So00004_ooool2o`000003ooooool0003o0000
00oo00001oooool2o`0000[ooooo0_l0000Dooooo`;o0000Boooool001cooooo00?o0000oooooooo
ool07_ooool2o`0001Kooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l00009ooooo`;o
00005?ooool2o`0000Cooooo0_l00003ooooo`;o00002Oooool5o`0000;ooooo1ol00008ooooo`;o
000000Coooooo`000?l0003ooooo0_l00008ooooo`;o00001_ooool2o`000003ooooool0003o0000
00?o00004_ooool2o`000003ooooool0003o000001;o00000oooool2o`0000_ooooo0_l0000Ooooo
o`;o00001_ooool4o`0003Kooooo000Looooo`03o`000?oooooooooo02oooooo0_l00005ooooo`;o
00002?ooool2o`000003ooooool0003o000001cooooo0_l00004ooooo`;o00000oooool2o`0000Go
oooo1ol000001?oooooo0000o`000?ooool8o`0000Cooooo0_l000001?oooooo0000o`000?ooool5
o`0000Sooooo0_l00006ooooo`;o00000oooool2o`0001;ooooo0_l000000ooooooo0000o`00000C
o`0000?ooooo1?l0000Xooooo`Co00001_ooool4o`0000Gooooo0_l0000_ooooo`007?ooool00ol0
003oooooooooo`0Nooooo`;o00003oooool2o`0000Cooooo0ol00008ooooo`;o000000?oooooo`00
0?l000001?ooool3o`0001Gooooo0_l00007ooooo`;o000000?oooooo`000?l000001?ooool7o`00
0003ooooool0003o000000Co000000?oooooo`000?l000000_l00004ooooo`;o00001Oooool2o`00
01Gooooo0_l0000Dooooo`;o000000?oooooo`000?l000004_l00006ooooo`;o00005oooool2o`00
00oooooo0ol0000@ooooo`;o0000;oooool001cooooo00?o0000ooooooooool07_ooool2o`0001Go
oooo0_l0000Booooo`?o00004_ooool2o`0000Wooooo0ol000000ooooooo0000o`000004ooooo`Oo
00000_ooool5o`0000Cooooo0_l000000ooooooo0000o`000006ooooo`;o00004_ooool2o`0000;o
oooo0ol0000FoooooaGo00007_ooool2o`0000kooooo1?l0000?ooooo`;o0000<?ooool001cooooo
00?o0000ooooooooool0@_ooool2o`0001[ooooo0_l00006ooooo`;o000000?oooooo`000?l00000
1?ooool;o`0000;ooooo1Ol00004ooooo`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o
00004_ooool2o`0000?ooooo0_l00006ooooo`;o00002Oooool2o`0000;ooooo5_l0000=ooooo`;o
00003?ooool2o`00017ooooo0_l0000Aooooo`;o0000<?ooool001cooooo00?o0000ooooooooool0
@_ooool2o`0001Cooooo0_l00004ooooo`;o00001_ooool2o`0000Oooooo1Ol000000ooooooo0000
o`000005o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o00000oooool2o`0000oooooo
1?l00002ooooo`;o00003Oooool2o`0000Cooooo0_l00003ooooo`;o000000Goooooo`000?l0003o
0000ooooo`0@o`0000;ooooo0_l0000<ooooo`;o00003?ooool2o`0000Cooooo0_l000000ooooooo
0000o`00001=ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^
k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0?_ooool2o`0001Sooooo0_l00008
ooooo`;o00001oooool2o`000003ooooool0003o0000013o000000?oooooo`000?l000000oooool2
o`0001Cooooo1?l00002ooooo`;o00001?ooool4o`0000_ooooo0_l00002ooooo`;o00000_oooolH
o`0001[ooooo0ol00003ooooo`;o000000?oooooo`000?l000001_ooool2o`0000[ooooo0_l0000i
ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooo
oonHV9So8B4Q00Kooooo00?o0000ooooooooool08?ooool2o`00013ooooo0_l000000ooooooo0000
o`000004ooooo`;o000000?oooooo`000?l000007oooool5o`0000Oooooo0_l000000ooooooo0000
o`00000?o`000003ooooool0003o000001Gooooo0_l000000ooooooo0000o`00000<ooooo`Co0000
3oooool2o`0000;ooooo5_l0000Looooo`?o00000oooool3o`0000Sooooo0_l00003ooooo`;o0000
1Oooool2o`0003Wooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo023ooooo0_l0000@ooooo`Go0000
1?ooool2o`0000?ooooo0_l0000Mooooo`Go00002_oooolFo`0000Oooooo0_l00006ooooo`;o0000
0_ooool2o`000003ooooool0003o000000?o00001Oooool8o`0001?ooooo3ol000000ooooooo0000
o`000004o`0001cooooo0_l00005ooooo`;o00003?ooool3o`000003ooooool0003o000000Cooooo
0_l000000ooooooo0000o`00000dooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooooooo
o`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0003?ooooo0_l0000;ooooo`;o0000
7_ooool4o`0000Sooooo1?l000000ooooooo0000o`00000Ao`000004ooooool0003o0000ooooo`;o
000000?oooooo`000?l000001_ooool2o`0000Gooooo1Ol00004ooooo`Oo00001Oooool2o`0000_o
oooo0_l000000ooooooo0000o`00000Do`00037ooooo0_l00002ooooo`;o00000_ooool4o`000003
ooooool0003o000003Cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo
00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo03;ooooo0_l0000hoooooaKo
00000oooool2o`000003ooooool0003o0000013ooooo0_l00003ooooo`;o00000_ooool4o`000004
ooooool0003o0000o`0000Cooooo0_l0000;ooooo`;o000000?oooooo`000?l000005?l0000Roooo
o`;o00004_ooool2o`000003ooooool0003o000003Wooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`0booooo`;o
00003_ooool2o`0001Kooooo0_l0000@ooooo`co000000?oooooo`000?l000002_l000000ooooooo
0000o`00000Gooooo`Co000000?oooooo`000?l000000_l000000ooooooo0000o`00000Coooooa7o
000000Coooooo`000?l0003ooooo0_l0000Gooooo`;o000000?oooooo`000?l000001_ooool2o`00
00kooooo0_l000001?oooooo0000o`000?l0000looooo`0000KoooooogMgMonHV9SooooooiRHV?mg
MgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0>Oooool2o`0000;ooooo0_l0
0003ooooo`Co00004oooool3o`0000Oooooo0_l00008oooooaSo000000?oooooo`000?l000001Ooo
ool2o`0000Kooooo0_l000000ooooooo0000o`000005ooooo`Co00000_ooool4o`0000Gooooo0_l0
0009ooooo`;o00000ooooolGo`0000Kooooo0_l0000?ooooo`;o000000?oooooo`000?l000002?oo
ool2o`0000Gooooo0_l00005ooooo`;o000000Coooooo`000?l0003o0000??ooool00006ooooooo^
k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo
03Wooooo0_l00002ooooo`;o00001Oooool2o`0001?ooooo0_l00008ooooo`;o00001?ooool2o`00
00;ooooo5ol00004ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`Oo00002_ooool3o`00
00Gooooo0_l00009ooooo`;o000000?oooooo`000?l000005ol000000ooooooo0000o`000003oooo
o`Co00006_ooool2o`0000Gooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`0oooooo`;o
00004Oooool2o`0000[ooooo0ol00008ooooo`;o00000_oooolIo`0000;ooooo0_l00006ooooo`?o
00001?ooool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`Co00005?ooool3o`000003
ooooool0003o000001?o000000?oooooo`000?l000000oooool4o`0000kooooo0ol00008ooooo`;o
00002oooool2o`0000;ooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0jooooo`;o0000
0oooool2o`0000oooooo1_l00008ooooo`?o00002?oooolPo`0000Oooooo0_l00006ooooo`;o0000
1_ooool7o`0001Kooooo6?l00004ooooo`Co00002_ooool2o`000004ooooool0003o0000ooooo`?o
00000_ooool2o`0000Cooooo0_l00005ooooo`;o00001?ooool2o`0000;ooooo0_l000000ooooooo
0000o`00000kooooo`007?ooool00ol0003oooooooooo`0jooooo`;o000000?oooooo`000?l00000
4Oooool2o`0000;ooooo0_l00002ooooo`;o00001?ooool4o`0000;ooooo0_l00002ooooo`;o0000
00?oooooo`000?l000007?l0000?ooooo`;o00001?ooool8o`0000[ooooo0_l00008ooooo`;o0000
0ooooolEo`0000Gooooo1ol00007ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo
0_l00006ooooo`Oo00002oooool2o`0003_ooooo000Looooo`03o`000?oooooooooo03gooooo0_l0
000Iooooo`;o00001_ooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000006_l0
0002ooooo`;o00003Oooool2o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o00002Ooo
ool2o`0000;ooooo0_l00004ooooo`;o00000ooooolHo`0000Cooooo1Ol000000ooooooo0000o`00
0006ooooo`;o00002oooool2o`0000;ooooo1ol00018ooooo`007?ooool00ol0003oooooooooo`0T
ooooo`;o00006_ooool4o`0001Oooooo0_l0000<oooooako00000_ooool2o`0000;ooooo0_l0000?
ooooo`Go000000Goooooo`000?l0003o0000ooooo`02o`0000Cooooo1?l00002ooooo`;o00003?oo
oolEo`0000[ooooo0_l00006ooooo`;o00002oooool4o`0000Gooooo0ol00017ooooo`007?ooool0
0ol0003oooooooooo`0Tooooo`;o00004Oooool2o`0000Oooooo1?l00006ooooo`;o00003oooool2
o`0000;ooooo0_l00006oooooaoo00001oooool2o`0000oooooo2?l00002ooooo`;o00001?ooool4
o`0000[ooooo0_l00005oooooaCo00001_ooool4o`0001Oooooo0_l00004ooooo`Co0000Aoooool0
01cooooo00?o0000ooooooooool0=oooool2o`0000Gooooo0_l00003ooooo`;o00001Oooool2o`00
00oooooo0_l00002ooooo`Co00001?oooolNo`0000Cooooo0ol000000ooooooo0000o`00000>oooo
o`;o000000?oooooo`000?l000000_l0000Aooooo`;o000000Coooooo`000?l0003ooooo0ol00005
ooooo`co000000Goooooo`000?l0003o0000ooooo`02o`0000?ooooo0_l00002ooooo`Co00000_oo
ool2o`0001Sooooo1?l0000:ooooo`;o0000??ooool001cooooo00?o0000ooooooooool0?_ooool4
o`000003ooooool0003o000000Gooooo0_l0000?ooooo`;o00001?ooool2o`0000Kooooo0_l00000
0ooooooo0000o`00000Go`000004ooooool0003o0000ooooo`?o00004Oooool2o`000003ooooool0
003o000000;o00003_ooool5o`000004ooooool0003o0000ooooo`Co00002Oooool:o`0000;ooooo
0_l00003ooooo`;o00000oooool2o`0000?ooooo0ol00004ooooo`;o00004Oooool4o`0000[ooooo
0_l0000looooo`007?ooool00ol0003oooooooooo`0Vooooo`;o00006?ooool2o`0001Cooooo0_l0
0009ooooo`;o00001_ooool2o`0000;ooooo6ol0000Cooooo`Co00000oooool2o`0000kooooo1?l0
0007ooooo`?o00002_ooool9o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o000000Co
ooooo`000?l0003ooooo1?l00002ooooo`;o00000_ooool2o`0000?ooooo0ol00004ooooo`;o0000
COooool001cooooo00?o0000ooooooooool09_ooool2o`0002Kooooo0_l00006ooooo`Go000000?o
ooooo`000?l000002oooool3o`0000;ooooo1ol000000ooooooo0000o`00000>o`0001;ooooo0_l0
00001?oooooo0000o`000?ooool3o`0000oooooo0_l000001?oooooo0000o`000?l00007ooooo`?o
00003?ooool7o`0000Oooooo0_l00005ooooo`;o00000oooool2o`0000Cooooo1?l00003ooooo`?o
00001?ooool3o`0000?ooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o0000
0_ooool2o`0000Cooooo0_l00002ooooo`Ko00002oooool3o`000003ooooool0003o000001Co0000
0oooool3o`0000oooooo0_l000001?oooooo0000o`000?ooool4o`000003ooooool0003o000000;o
00002Oooool2o`000004ooooool0003o0000o`00017ooooo0_l00004ooooo`;o00002oooool2o`00
013ooooo0ol00008ooooo`;o00000_ooool2o`0000;ooooo0ol00004ooooo`;o0000@Oooool001co
oooo0_l00010ooooo`Co00001Oooool4o`0000Sooooo0_l000000ooooooo0000o`000003o`0000Go
oooo0_l00007ooooo`;o000000?oooooo`000?l000004ol00004ooooo`?o00004Oooool3o`0000?o
oooo2Ol0000Nooooo`;o00003Oooool2o`0001oooooo0_l00002ooooo`Ko00001Oooool2o`00047o
oooo000Looooo`03o`000?oooooooooo03oooooo1?l00005ooooo`;o00002_ooool2o`000004oooo
ool0003o0000o`0000Oooooo0_l00007ooooo`;o000000?oooooo`000?l000004ol00002ooooo`;o
00000_ooool2o`0000Sooooo0_l00003ooooo`Go000000?oooooo`000?l000000_ooool2o`000003
ooooool0003o000000?o00002?ooool2o`0001cooooo0_l00003ooooo`Co00002Oooool2o`0000_o
oooo0_l00007ooooo`;o00000_ooool4o`000003ooooool0003o000000Gooooo0_l00010ooooo`00
7?ooool00ol0003oooooooooo`12ooooo`;o00005_ooool2o`0000_ooooo0_l000001?oooooo0000
o`000?ooool;o`000003ooooool0003o000000Co000000?oooooo`000?l000000_ooool2o`0000;o
oooo1?l00006ooooo`;o00000oooool3o`0000?ooooo0_l00002ooooo`Co00000_ooool2o`0000Ko
oooo1?l0000Iooooo`;o000000?oooooo`000?l000000oooool2o`0000_ooooo0_l00004ooooo`;o
00001Oooool2o`0000oooooo0ol00005ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0
@_ooool2o`0001Kooooo0_l00002ooooo`;o00001oooool2o`000004ooooool0003o0000oooooaCo
00000oooool3o`0000?ooooo0_l00005ooooo`;o00003Oooool5o`0000[ooooo0_l0000Kooooo`;o
00006Oooool2o`0000Gooooo0_l000000ooooooo0000o`00000<ooooo`;o0000B?ooool001cooooo
00?o0000ooooooooool0G_ooool2o`0000Oooooo0_l000000ooooooo0000o`000003oooooaCo0000
00Coooooo`000?l0003o00002_ooool2o`0000Kooooo0_l00005ooooo`Ko00001?ooool2o`0000Go
oooo0_l0000Iooooo`;o00004Oooool2o`00013ooooo0ol0000Aooooo`;o0000@_ooool001cooooo
00?o0000ooooooooool0?_ooool2o`0000?ooooo0_l0000Gooooo`;o00002Oooool3o`0000;ooooo
0ol000001Ooooooo0000o`000?l0003ooooo017o00000oooool4o`0000gooooo0_l00002ooooo`;o
00001?ooool3o`0000Cooooo0_l00005ooooo`;o00006Oooool2o`00017ooooo0_l0000;ooooo`;o
00000_ooool4o`00017ooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`0nooooo`;o0000
0oooool2o`0001Cooooo0_l000000ooooooo0000o`000002ooooo`?o00001Oooool2o`0000;ooooo
5_l000000ooooooo0000o`000007o`00017ooooo0_l00005ooooo`;o00000_ooool4o`0002oooooo
0_l0000?ooooo`So00003oooool2o`0004Cooooo000Looooo`03o`000?oooooooooo05Wooooo0_l0
0005ooooo`?o00002oooool6o`000003ooooool0003o000000Oo00000_ooool2o`000003ooooool0
003o000000Co00003?ooool2o`0000;ooooo0_l0000:ooooo`Go00002?ooool2o`0002Oooooo0_l0
000<ooooo`;o00000oooool2o`000003ooooool0003o000000;o00001?ooool2o`0000Sooooo0_l0
0014ooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00002?ooool2o`0000Wooooo1?l00000
0ooooooo0000o`000006o`0000?ooooo2Ol0000>ooooo`;o00001oooool2o`0000;ooooo0_l00002
ooooo`;o00001_ooool6o`0000Oooooo0_l0000Pooooo`;o00004oooool5o`0000Gooooo1?l00002
ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0BOooool3o`0000Cooooo0_l00008oooo
o`;o00002Oooool4o`000003ooooool0003o000000?o000000?oooooo`000?l000001ol00004oooo
o`;o00003Oooool2o`0000Sooooo1?l00003ooooo`;o00002?ooool4o`0002Wooooo0_l0000;oooo
o`;o00000oooool8o`0000;ooooo0_l00003ooooo`Go00001_ooool2o`0004Oooooo000Looooo`03
o`000?oooooooooo04Wooooo0ol0000>ooooo`;o00002_ooool2o`0000Gooooo0_l00003ooooo`Co
000000?oooooo`000?l000001?ooool2o`0000Gooooo0_l000001?oooooo0000o`000?l00004oooo
o`;o00001_ooool4o`0000gooooo1?l0000fooooo`;o00000oooool5o`0000Gooooo0_l00004oooo
o`Co00001_ooool2o`0004Oooooo000Looooo`03o`000?oooooooooo02kooooo0_l0000Looooo`;o
00003?ooool2o`0000[ooooo0_l000000ooooooo0000o`000007ooooo`;o00001?ooool2o`0000Ko
oooo0_l00002ooooo`;o000000Coooooo`000?l0003o00000_ooool4o`0000;ooooo1Ol0000Aoooo
o`Co0000>?ooool5o`00063ooooo000Looooo`03o`000?oooooooooo02kooooo0_l0000Looooo`;o
00004Oooool2o`0000;ooooo0_l00002ooooo`Co00003Oooool3o`0000?ooooo1?l00002ooooo`;o
00000oooool2o`000003ooooool0003o000000;o00000_ooool5o`0000;ooooo0_l0000=ooooo`Co
0000=?ooool6o`000003ooooool0003o000000Gooooo0_l00004ooooo`;o0000Doooool001cooooo
00?o0000ooooooooool0G?ooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`?o0000
1?ooool2o`0000?ooooo0_l00004ooooo`;o00000oooool2o`0000Cooooo1ol000000ooooooo0000
o`000002o`0000Cooooo0_l00003ooooo`;o00002?ooool2o`0000Gooooo0ol00007ooooo`;o0000
:_ooool4o`0000[ooooo0_l00004ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0D?oo
ool2o`0000[ooooo0_l00003ooooo`;o00002oooool2o`0000?ooooo0_l00005ooooo`;o00001_oo
ool7o`0000?ooooo1?l0000Aooooo`Co00001Oooool3o`0000Oooooo0_l00003ooooo`;o00007ooo
ool2o`0000Gooooo1Ol00004ooooo`;o00002?ooool2o`0005?ooooo000Looooo`03o`000?oooooo
oooo053ooooo0_l00006ooooo`;o00001oooool2o`0000;ooooo0_l00002ooooo`;o00003oooool2
o`0000Kooooo1?l0000<ooooo`;o00001oooool2o`0000Cooooo0_l00006ooooo`?o00003Oooool4
o`0001gooooo0_l00007ooooo`?o00001?ooool2o`0000Sooooo0_l0001Cooooo`007?ooool2o`00
05?ooooo0_l00004ooooo`;o00002oooool2o`0000;ooooo0_l0000@ooooo`Co00004oooool2o`00
00Oooooo0_l000000ooooooo0000o`000003ooooo`;o00001?ooool2o`0000Cooooo0_l0000:oooo
o`;o00009oooool2o`0000Oooooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`1Booooo`;o
00004Oooool2o`0001Cooooo1?l0000<ooooo`;o000000?oooooo`000?l000003_ooool8o`0000Wo
oooo0_l0000Rooooo`;o00003oooool2o`0000Gooooo1_l00006ooooo`;o0000D?ooool001cooooo
00?o0000ooooooooool0J_ooool2o`00013ooooo0ol0000<ooooo`;o000000Coooooo`000?l0003o
00001?ooool2o`0000Wooooo0ol000000ooooooo0000o`00000Cooooo`;o00001?ooool2o`0001;o
oooo0ol0000Eooooo`;o00000_ooool2o`0000Kooooo0_l0001@ooooo`007?ooool00ol0003ooooo
ooooo`1Yooooo`?o00004?ooool3o`0000Cooooo1?l00003ooooo`?o00000_ooool2o`0000Cooooo
0_l0000:ooooo`;o00005_ooool2o`0000Cooooo0_l0000Cooooo`?o00003Oooool2o`0000Cooooo
0_l0001Mooooo`007?ooool00ol0003oooooooooo`1Yooooo`;o000000?oooooo`000?l000001?oo
ool2o`0000oooooo1?l00002ooooo`Co00005Oooool2o`000003ooooool0003o000000Sooooo0_l0
000=ooooo`;o00005Oooool2o`0000Sooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo
0_l0001Mooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00007Oooool2o`0000gooooo0_l0
0005ooooo`Co00000_ooool2o`0000Oooooo0_l00005ooooo`Go00000_ooool3o`0000Sooooo0_l0
000<ooooo`;o000000?oooooo`000?l000002?ooool2o`0000gooooo0_l0000Oooooo`;o00001Ooo
ool3o`00063ooooo000Looooo`03o`000?oooooooooo03Oooooo0_l0000Mooooo`Co00002oooool2
o`0000Kooooo0ol0000;ooooo`;o00001Oooool5o`0000?ooooo0_l00004ooooo`;o00000_ooool2
o`0000;ooooo0_l00004ooooo`;o00002?ooool2o`00013ooooo0_l0000Kooooo`;o00003Oooool2
o`000003ooooool0003o000005kooooo000Looooo`03o`000?oooooooooo05Sooooo1?l0000Yoooo
o`;o00000oooool2o`0000Cooooo0_l00006ooooo`;o00001?ooool2o`0000;ooooo0_l00002oooo
o`Co00003oooool5o`0001Wooooo0_l0000@ooooo`Co0000G?ooool001cooooo00?o0000oooooooo
ool0F_ooool2o`0001oooooo0_l0000Pooooo`Oo00000_ooool2o`00017ooooo1_l0000Looooo`;o
00001?ooool2o`0000Sooooo0_l0001Looooo`007?ooool00ol0003oooooooooo`1Jooooo`;o0000
0_ooool2o`0000Wooooo0_l00008ooooo`Co00001?ooool2o`00023ooooo2?l0000Hooooo`;o0000
6Oooool2o`000003ooooool0003o000000Cooooo0_l00005ooooo`;o000000?oooooo`000?l00000
G?ooool001cooooo00?o0000ooooooooool0EOooool2o`000003ooooool0003o000000;o00000_oo
ool2o`0000?ooooo0_l00003ooooo`?o00002?ooool4o`0002Gooooo2ol0000<ooooo`Co00008Ooo
ool2o`0000Oooooo0_l00005ooooo`;o000000?oooooo`000?l00000G?ooool001cooooo00?o0000
ooooooooool0EOooool2o`000003ooooool0003o000000Cooooo0_l00003ooooo`;o00000oooool2
o`0001_ooooo0ol00003ooooo`Co00003?ooool<o`0000Gooooo0_l00005ooooo`Go00008oooool2
o`0000Gooooo0_l00004ooooo`;o0000Goooool001cooooo00?o0000ooooooooool0G_ooool2o`00
02Gooooo0ol00003ooooo`Co00003?ooool<o`0000Gooooo0_l00005ooooo`;o000000?oooooo`00
0?l000000oooool4o`0000;ooooo0_l00004ooooo`;o00001oooool2o`0000Wooooo0_l00005oooo
o`;o00001?ooool2o`0005oooooo000Looooo`03o`000?oooooooooo03kooooo0_l0000[ooooo`;o
00009Oooool2o`0000Cooooo0_l000000ooooooo0000o`000003o`0000;ooooo1_l00009ooooo`Ko
00001?ooool4o`0000;ooooo0_l00004ooooo`;o00001oooool2o`0001[ooooo0_l0001Kooooo`00
7?ooool00ol0003oooooooooo`0nooooo`;o0000:oooool2o`0000Cooooo0ol000001?oooooo0000
o`000?ooool2o`0001Gooooo0_l000001?oooooo0000o`000?l00003ooooo`;o00000_ooool=o`00
00Sooooo0_l00002ooooo`;o00003Oooool2o`0002Kooooo0_l0001Kooooo`007?ooool00ol0003o
ooooooooo`1Looooo`;o00003Oooool2o`0000Cooooo2_l0000@ooooo`;o00000_ooool2o`0000;o
oooo0_l00007ooooo`go00006oooool2o`0001Sooooo0_l0000:ooooo`;o0000GOooool001cooooo
0_l0001Mooooo`;o00002_ooool2o`0000Sooooo1?l000000ooooooo0000o`000002o`0000;ooooo
0_l00005ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo0_l00008oooooa3o0000
3_ooool2o`0000[ooooo0_l0000?ooooo`;o00002?ooool3o`0000Wooooo0ol0001Looooo`007?oo
ool00ol0003oooooooooo`1Xooooo`;o00004oooool2o`0000Gooooo0_l000001?oooooo0000o`00
0?l00005ooooo`Ko000000Coooooo`000?l0003ooooo4?l000000ooooooo0000o`00000;ooooo`;o
00002_ooool2o`000003ooooool0003o000000Go000000?oooooo`000?l000001?ooool2o`0000Go
oooo1_l00004ooooo`?o000000?oooooo`000?l000000_l0001Looooo`007?ooool00ol0003ooooo
ooooo`1Zooooo`Co00000oooool3o`00013ooooo0_l000000ooooooo0000o`000002ooooo`;o0000
0oooool5o`000003ooooool0003o000000;ooooo3ol000000ooooooo0000o`00000Booooo`;o0000
1Oooool8o`000003ooooool0003o000000[ooooo1_l00005ooooo`?o000000Coooooo`000?l0003o
0000GOooool001cooooo00?o0000ooooooooool0HOooool2o`0000Oooooo1?l000000ooooooo0000
o`000003o`00013ooooo0_l00005ooooo`?o00000_ooool3o`0000Oooooo3_l00009ooooo`;o0000
2oooool2o`0000Gooooo0_l000000ooooooo0000o`000002o`0000kooooo0_l00002ooooo`;o0000
1_ooool2o`00067ooooo000Looooo`03o`000?oooooooooo067ooooo0_l0000<ooooo`;o00002?oo
ool2o`00017ooooo0_l00002ooooo`Co00000_ooool2o`0000Kooooo2_l00009ooooo`;o000000?o
ooooo`000?l000004_ooool4o`0000;ooooo0_l0000Fooooo`;o0000HOooool001cooooo00?o0000
ooooooooool0AOooool2o`0002Kooooo1_l00006ooooo`;o00003oooool2o`0000Gooooo1ol00006
ooooo`Wo00003Oooool2o`0001Sooooo0_l0000;ooooo`;o0000K?ooool001cooooo00?o0000oooo
ooooool0AOooool2o`0001gooooo0_l00007ooooo`Ko000000Coooooo`000?l0003o00004oooool2
o`0000Gooooo1Ol00006ooooo`;o00000_ooool7o`0000cooooo0ol0000Gooooo`;o00003?ooool3
o`0000?ooooo0_l0001Vooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o00001?ooool2o`00
00Oooooo0_l00005ooooo`?o00000_ooool2o`0000Gooooo0_l00008ooooo`;o00003Oooool2o`00
0003ooooool0003o000000;ooooo1?l00003ooooo`Co00001oooool4o`0001Oooooo0_l00009oooo
o`;o00000_ooool2o`0000?ooooo0_l0001Vooooo`007?ooool00ol0003oooooooooo`1Nooooo`Co
00000_ooool2o`0001?ooooo0_l00005ooooo`;o00002?ooool3o`0000[ooooo1?l0000<ooooo`Co
00001oooool2o`0001Wooooo0_l00004ooooo`;o00000oooool2o`0006oooooo000Looooo`03o`00
0?oooooooooo04[ooooo0_l0000Dooooo`;o00001Oooool2o`0001Sooooo0_l00008ooooo`;o0000
2_ooool4o`0000Kooooo0_l0000?ooooo`;o00005oooool4o`0000Cooooo0_l00007ooooo`;o0000
Joooool001cooooo00?o0000ooooooooool0B_ooool4o`0001Wooooo0_l0000<ooooo`?o00001?oo
ool2o`0000?ooooo0_l00002ooooo`;o00004_ooool4o`000004ooooool0003o0000ooooo`;o0000
:?ooool2o`0000oooooo1?l0001Yooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00009ooo
ool3o`0000Cooooo0_l00002ooooo`;o00000oooool4o`0000_ooooo0_l00004ooooo`?o000000?o
ooooo`000?l000001oooool2o`0000Kooooo0_l0000Mooooo`;o00003?ooool4o`0006Wooooo000L
ooooo`03o`000?oooooooooo06_ooooo0_l0000=ooooo`;o00001?ooool2o`0000?ooooo1_l00006
ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Wooooo0_l00006ooooo`Co00005?ooool2
o`0000Cooooo0ol00002ooooo`;o00002?ooool2o`0006_ooooo000Looooo`03o`000?oooooooooo
053ooooo0_l0000Aooooo`;o00001_ooool2o`0000_ooooo1?l00003ooooo`;o00002?ooool4o`00
00Cooooo0_l00009ooooo`;o00003oooool6o`0001Cooooo0_l00004ooooo`Co000000?oooooo`00
0?l00000MOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<
ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo053ooooo0_l0000Aooooo`;o00004ooo
ool2o`0000Gooooo0_l000000ooooooo0000o`000006ooooo`?o000000?oooooo`000?l000001?oo
ool2o`0000[ooooo0_l0000:ooooo`Co00007Oooool4o`000003ooooool0003o000007Gooooo0000
1_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ
8B401_ooool00ol0003oooooooooo`1`ooooo`;o00002oooool2o`0000?ooooo0ol00005ooooo`;o
00000_ooool2o`0000?ooooo0ol0000:ooooo`;o00002_ooool2o`0000_ooooo0ol00004ooooo`;o
00002oooool2o`0000?ooooo0_l000000ooooooo0000o`00001booooo`0000?ooooooa0@4?ooool0
0_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`1`ooooo`;o00002oooool2o`0000Cooooo0_l00007ooooo`?o00001?ooool2o`0000Co
oooo1?l00006ooooo`Go000000?oooooo`000?l000003Oooool4o`0000Cooooo1?l00008ooooo`;o
00001oooool2o`0007;ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo
00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000S?ooool3o`0000;ooooo1?l00004ooooo`Co
00001_ooool5o`000003ooooool0003o000000gooooo0_l00004ooooo`;o00000_ooool2o`0000So
oooo0_l00002ooooo`Co0000MOooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
2Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0Qoooool2o`0000?o
oooo0_l00003ooooo`;o00001?ooool2o`0000Oooooo0_l00004ooooo`;o000000Coooooo`000?l0
003ooooo1Ol0000<ooooo`Co00001_ooool2o`0000Oooooo1?l0001eooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0
003oooooooooo`27ooooo`;o00000_ooool3o`0000?ooooo0_l00004ooooo`;o00001oooool2o`00
00[ooooo1Ol000001?oooooo0000o`000?l00002ooooo`;o000000Coooooo`000?l0003ooooo1?l0
0006ooooo`;o00002?ooool2o`0007Kooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo
00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo08Cooooo0_l00005ooooo`?o
00003Oooool2o`0001;ooooo0_l000000ooooooo0000o`000005o`000003ooooool0003o000000;o
oooo0_l00004ooooo`Go00002_ooool2o`0007Cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^
kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo08Cooooo0_l0000C
ooooo`Co00003_ooool2o`0000;ooooo0_l00002ooooo`Go00003?ooool4o`0000_ooooo0_l0001d
ooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o00004_ooool2o`0002Oooooo0_l000000ooo
oooo0000o`000002o`0000Wooooo0_l00003ooooo`;o000000?oooooo`000?l000000oooool2o`00
00Sooooo0_l0002:ooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o00004_ooool2o`0001So
oooo0_l0000=ooooo`;o00000oooool2o`0000Kooooo0_l000000ooooooo0000o`000002o`0000Co
oooo1_l00009ooooo`;o0000R_ooool001cooooo00?o0000ooooooooool0P_ooool2o`0000?ooooo
0_l0000Jooooo`;o00000_ooool3o`0000Cooooo1_l00003ooooo`;o0000T?ooool001cooooo00?o
0000ooooooooool0P_ooool2o`0000Kooooo0_l0000@ooooo`;o00004Oooool4o`000004ooooool0
003o0000ooooo`;o0000T?ooool001cooooo00?o0000ooooooooool0P_ooool2o`0000Kooooo0_l0
0004ooooo`;o00002?ooool4o`00017ooooo1?l000001?oooooo0000o`000?ooool3o`0000Wooooo
0_l00006ooooo`;o0000O?ooool001cooooo00?o0000ooooooooool0T?ooool2o`0000Gooooo0_l0
00000ooooooo0000o`00000>ooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`?o0000
1oooool6o`000004ooooool0003o0000ooooo`;o0000O?ooool001cooooo00?o0000ooooooooool0
Uoooool2o`0000cooooo0_l00003ooooo`;o00002oooool2o`0000Sooooo0_l00002ooooo`;o0000
00?oooooo`000?l00000Ooooool001cooooo00?o0000ooooooooool0Woooool2o`0000Cooooo0_l0
0005ooooo`;o00002?ooool2o`00097ooooo000Looooo`03o`000?oooooooooo09kooooo0ol0000;
ooooo`;o00002?ooool2o`00097ooooo000Looooo`03o`000?oooooooooo09kooooo0_l0002Yoooo
o`007?ooool00ol0003oooooooooo`2Looooo`;o0000Zoooool001cooooo0_l0002Mooooo`;o0000
Zoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Y
ooooo`?o0000WOooool001cooooo00?o0000ooooooooool0ZOooool5o`0009_ooooo000Looooo`03
o`000?oooooooooo0:3ooooo0_l0000:ooooo`;o0000Voooool001cooooo00?o0000ooooooooool0
X?ooool2o`000:Oooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Booooo`Co000000?o410@ooooooooool00oooool00ol0003ooooooooo
o`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom:
ooooo`005?ooool00ol0003oooooooooo`05ooooo`?o0000oooooom:ooooo`005?ooool00ol0003o
ooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o
0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Boooo
o`03oeEEEOmVIVKo00000?ooooooE?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00:Gooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0Eooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`01?ooool4o`000008oa0@4?ooooooooooolc<c?lQ8B7o0000ob4Q8Oo<c<b@
ooooo`00Y_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l00009ooooo`05oeEEEOmgMgOo
oooooiRHV?lQ8B401_ooool00ol0003oooooooooo`02ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40
T?ooool00:Kooooo00Go0000ooooooooooooooooo`00000Hooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000T?ooool00:Ko
oooo00Go0000ooooooooooooooooo`000009ooooo`Ko00002Oooool01Ol0003oV9RHoooooonHV9So
8B4Q00Kooooo00?o0000ooooooooool00_ooool01Olb<S;oV9RHoooooonHV9So<S8b093ooooo002V
ooooo`05o`000?n7QhOoooooojVYZOl000006?ooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo
00?o0000ooooooooool00_ooool01Oo<c<co0000o`000?l0003oc<c<093ooooo002Uooooo`03oa0@
4?l0003oMgMg00;o000000?oV9RHooooooooool05_ooool00omEEEGoQhN7ooooo`08ooooo`03o`00
0?oooooooooo00;ooooo00Go410@okZj^_oooooo^[Zjoa0@402@ooooo`00`oooool00ooMgMgo410@
oiRHV008ooooo`03o`000?oooooooooo00;ooooo00Go0000okZj^_oooooo^[Zjo`00002@ooooo`00
a?ooool01?o<c<coA4A4o`000?l@4104ooooo`03oeEEEOmVIVKo000000Cooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@2@ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(624) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.33017 .62862 Mdot
.38429 .59936 Mdot
.62256 .50016 Mdot
.40599 .43341 Mdot
.63682 .38696 Mdot
.65484 .4861 Mdot
.62017 .60649 Mdot
.60528 .65317 Mdot
.66425 .48502 Mdot
.19686 .49825 Mdot
.5961 .63859 Mdot
.34591 .44236 Mdot
.6064 .60949 Mdot
.41012 .39388 Mdot
.50698 .7062 Mdot
.37916 .34554 Mdot
.39268 .61056 Mdot
.62444 .29504 Mdot
.37298 .34778 Mdot
.62104 .48086 Mdot
.4591 .50774 Mdot
.41739 .39884 Mdot
.38908 .61216 Mdot
.413 .39533 Mdot
.44118 .44093 Mdot
.37208 .61387 Mdot
.32538 .61449 Mdot
.44543 .42131 Mdot
.45449 .39744 Mdot
.58965 .62658 Mdot
.70082 .32575 Mdot
.4628 .844 Mdot
.3694 .36465 Mdot
.32348 .48143 Mdot
.61786 .65326 Mdot
.80722 .53692 Mdot
.67597 .47142 Mdot
.58865 .64139 Mdot
.6317 .63029 Mdot
.63906 .61739 Mdot
.61647 .59081 Mdot
.37303 .60539 Mdot
.62098 .57929 Mdot
.68776 .43124 Mdot
.37873 .42337 Mdot
.3992 .77116 Mdot
.70753 .28697 Mdot
.44453 .41901 Mdot
.34311 .63711 Mdot
.62634 .47646 Mdot
.36286 .25523 Mdot
.58012 .63318 Mdot
.4796 .7722 Mdot
.10408 .57883 Mdot
.5931 .6213 Mdot
.41909 .42871 Mdot
.64602 .46242 Mdot
.39897 .41902 Mdot
.43588 .41062 Mdot
.3062 .42789 Mdot
.44238 .39169 Mdot
.6159 .32208 Mdot
.32098 .61342 Mdot
.62246 .45742 Mdot
.66113 .48173 Mdot
.59397 .60006 Mdot
.36744 .57464 Mdot
.60824 .59931 Mdot
.37381 .46114 Mdot
.62569 .49396 Mdot
.43797 .42063 Mdot
.59357 .63857 Mdot
.38474 .58385 Mdot
.42129 .45628 Mdot
.42569 .73912 Mdot
.65915 .65645 Mdot
.5869 .31943 Mdot
.27944 .56668 Mdot
.22201 .34667 Mdot
.6943 .55092 Mdot
.41314 .38363 Mdot
.20905 .33093 Mdot
.50962 .69622 Mdot
.37737 .58715 Mdot
.35946 .50305 Mdot
.69661 .70996 Mdot
.4573 .39531 Mdot
.5508 .40827 Mdot
.44871 .36492 Mdot
.47092 .59566 Mdot
.66723 .47789 Mdot
.37465 .62152 Mdot
.37898 .42545 Mdot
.46706 .41112 Mdot
.26981 .36942 Mdot
.36617 .38662 Mdot
.38603 .4258 Mdot
.40714 .57583 Mdot
.60722 .63625 Mdot
.4183 .48663 Mdot
.70693 .44543 Mdot
.4717 .73712 Mdot
.40592 .44227 Mdot
.6478 .50448 Mdot
.34348 .64726 Mdot
.38606 .43456 Mdot
.59204 .60731 Mdot
.42697 .38918 Mdot
.63814 .65485 Mdot
.37181 .63292 Mdot
.4657 .40611 Mdot
.59878 .32465 Mdot
.45786 .67304 Mdot
.33652 .61677 Mdot
.20278 .59836 Mdot
.44025 .39454 Mdot
.42701 .4051 Mdot
.37932 .59242 Mdot
.64676 .45276 Mdot
.54724 .44882 Mdot
.39144 .59858 Mdot
.6352 .62425 Mdot
.3672 .63932 Mdot
.47105 .38987 Mdot
.63984 .45429 Mdot
.47841 .73454 Mdot
.46326 .74004 Mdot
.62884 .24377 Mdot
.43692 .45349 Mdot
.48853 .71159 Mdot
.64318 .48806 Mdot
.37791 .60241 Mdot
.60356 .6029 Mdot
.42751 .36533 Mdot
.34521 .5915 Mdot
.62576 .6341 Mdot
.61586 .35077 Mdot
.64641 .3869 Mdot
.33246 .59807 Mdot
.4891 .3315 Mdot
.59958 .65826 Mdot
.63948 .61139 Mdot
.38311 .25282 Mdot
.37218 .58568 Mdot
.63326 .33912 Mdot
.62929 .6201 Mdot
.51806 .25285 Mdot
.41473 .36615 Mdot
.46965 .21315 Mdot
.25429 .27264 Mdot
.37179 .25372 Mdot
.30872 .71672 Mdot
.62443 .30797 Mdot
.63057 .61609 Mdot
.426 .4355 Mdot
.35575 .59694 Mdot
.36201 .59421 Mdot
.46993 .41667 Mdot
.45553 .43077 Mdot
.38926 .39316 Mdot
.43541 .37104 Mdot
.80207 .42023 Mdot
.39318 .38695 Mdot
.52821 .61125 Mdot
.33956 .59771 Mdot
.44521 .44381 Mdot
.66591 .50941 Mdot
.42936 .46089 Mdot
.58925 .64157 Mdot
.42651 .41482 Mdot
.44994 .43292 Mdot
.36533 .42157 Mdot
.63023 .59449 Mdot
.56827 .81906 Mdot
.18433 .41664 Mdot
.76274 .62687 Mdot
.35278 .70645 Mdot
.64173 .47633 Mdot
.41346 .37595 Mdot
.63724 .31891 Mdot
.40303 .50464 Mdot
.43784 .40616 Mdot
.3396 .26251 Mdot
.45414 .42162 Mdot
.27244 .62721 Mdot
.48225 .44962 Mdot
.7366 .69262 Mdot
.52947 .65866 Mdot
.44634 .39013 Mdot
.22261 .40958 Mdot
.49624 .199 Mdot
.67652 .27779 Mdot
.59426 .61157 Mdot
.67776 .50263 Mdot
.66395 .45818 Mdot
.64103 .59899 Mdot
.4553 .46628 Mdot
.20044 .51795 Mdot
.38784 .47232 Mdot
.48103 .73884 Mdot
.31136 .61238 Mdot
.62616 .30334 Mdot
.33077 .60143 Mdot
.17001 .37908 Mdot
.5177 .4694 Mdot
.65809 .61208 Mdot
.61518 .29711 Mdot
.64155 .51473 Mdot
.4867 .7521 Mdot
.63995 .32777 Mdot
.39265 .42672 Mdot
.35774 .63786 Mdot
.49193 .19861 Mdot
.44415 .34588 Mdot
.85569 .42895 Mdot
.36722 .57889 Mdot
.51298 .55879 Mdot
.59681 .61242 Mdot
.64232 .44601 Mdot
.45727 .39756 Mdot
.39349 .40393 Mdot
.32236 .61674 Mdot
.44845 .41425 Mdot
.45974 .53568 Mdot
.44871 .43011 Mdot
.64522 .43677 Mdot
.62684 .27723 Mdot
.64661 .60835 Mdot
.61757 .23855 Mdot
.3878 .58468 Mdot
.55657 .53945 Mdot
.65446 .50867 Mdot
.39575 .65652 Mdot
.58851 .63201 Mdot
.60776 .34639 Mdot
.67661 .48791 Mdot
.60817 .35732 Mdot
.38629 .44284 Mdot
.67364 .47336 Mdot
.61032 .33623 Mdot
.60604 .51332 Mdot
.38671 .42826 Mdot
.47503 .23921 Mdot
.62636 .61513 Mdot
.32635 .61246 Mdot
.44446 .39263 Mdot
.46976 .72773 Mdot
.47289 .4246 Mdot
.49471 .71029 Mdot
.48346 .73286 Mdot
.48667 .76569 Mdot
.66755 .61455 Mdot
.64478 .32669 Mdot
.3828 .7343 Mdot
.53471 .472 Mdot
.39353 .60841 Mdot
.37186 .41273 Mdot
.63267 .80242 Mdot
.62784 .6091 Mdot
.39522 .427 Mdot
.7068 .69892 Mdot
.62914 .61908 Mdot
.40651 .41493 Mdot
.61781 .58932 Mdot
.35782 .59385 Mdot
.55984 .49454 Mdot
.38225 .63556 Mdot
.40663 .43033 Mdot
.61302 .62433 Mdot
.67926 .49494 Mdot
.37098 .61383 Mdot
.42988 .39272 Mdot
.40762 .38189 Mdot
.48314 .74751 Mdot
.4512 .44175 Mdot
.66948 .77251 Mdot
.44217 .4211 Mdot
.64186 .51602 Mdot
.36874 .38128 Mdot
.4704 .19762 Mdot
.65032 .38188 Mdot
.35555 .57229 Mdot
.4886 .74182 Mdot
.66498 .46956 Mdot
.58382 .4641 Mdot
.6668 .32857 Mdot
.41804 .38734 Mdot
.469 .74705 Mdot
.5184 .55783 Mdot
.58908 .60675 Mdot
.42113 .35734 Mdot
.48876 .50718 Mdot
.66976 .48974 Mdot
.48502 .74665 Mdot
.4879 .42152 Mdot
.35414 .6468 Mdot
.42069 .43027 Mdot
.67819 .4775 Mdot
.35043 .64354 Mdot
.4282 .36452 Mdot
.77274 .36479 Mdot
.46952 .73045 Mdot
.62512 .61038 Mdot
.36147 .32659 Mdot
.38782 .38714 Mdot
.66436 .45609 Mdot
.35103 .58924 Mdot
.59889 .62874 Mdot
.35384 .63227 Mdot
.53033 .19514 Mdot
.38301 .69804 Mdot
.77718 .48051 Mdot
.63846 .29524 Mdot
.31266 .76553 Mdot
.77874 .59958 Mdot
.40504 .69583 Mdot
.59132 .27084 Mdot
.80884 .60922 Mdot
.67063 .50351 Mdot
.35247 .30184 Mdot
.65705 .46315 Mdot
.416 .44047 Mdot
.6574 .48628 Mdot
.70012 .75617 Mdot
.4482 .42327 Mdot
.64089 .47097 Mdot
.78937 .42527 Mdot
.45849 .4147 Mdot
.33592 .60125 Mdot
.45239 .82378 Mdot
.22416 .61543 Mdot
.51931 .39917 Mdot
.63839 .46872 Mdot
.2981 .32311 Mdot
.45379 .41165 Mdot
.4058 .33911 Mdot
.3585 .60258 Mdot
.45691 .36994 Mdot
.6109 .30724 Mdot
.59941 .34803 Mdot
.38443 .26245 Mdot
.23988 .64255 Mdot
.40372 .32819 Mdot
.36925 .60786 Mdot
.22909 .33541 Mdot
.42631 .74407 Mdot
.46097 .73888 Mdot
.62489 .64259 Mdot
.56626 .81751 Mdot
.49122 .38349 Mdot
.45104 .31425 Mdot
.47076 .54727 Mdot
.37899 .61888 Mdot
.77396 .55307 Mdot
.60294 .6256 Mdot
.21019 .41036 Mdot
.22739 .52133 Mdot
.38451 .39872 Mdot
.59301 .59235 Mdot
.37197 .47127 Mdot
.4639 .54474 Mdot
.46886 .22893 Mdot
.74569 .48885 Mdot
.39618 .43215 Mdot
.39285 .73814 Mdot
.43151 .40839 Mdot
.49366 .20472 Mdot
.40206 .42876 Mdot
.34838 .62901 Mdot
.46391 .33678 Mdot
.58758 .4147 Mdot
.17059 .4905 Mdot
.50767 .47975 Mdot
.6431 .31553 Mdot
.40606 .39534 Mdot
.38715 .40262 Mdot
.60995 .32497 Mdot
.36233 .62316 Mdot
.37455 .39718 Mdot
.71057 .28475 Mdot
.38615 .39159 Mdot
.58046 .62987 Mdot
.56904 .46546 Mdot
.26997 .65504 Mdot
.46183 .4005 Mdot
.34719 .645 Mdot
.59935 .59754 Mdot
.61695 .64829 Mdot
.43828 .33219 Mdot
.62744 .60218 Mdot
.42915 .42963 Mdot
.56559 .47191 Mdot
.38624 .61786 Mdot
.38652 .49334 Mdot
.35653 .62237 Mdot
.28215 .28406 Mdot
.62752 .58959 Mdot
.4664 .75704 Mdot
.3713 .29657 Mdot
.6134 .61496 Mdot
.42031 .58957 Mdot
.49734 .38866 Mdot
.41788 .46487 Mdot
.35124 .68693 Mdot
.68178 .46692 Mdot
.47809 .76356 Mdot
.59416 .62564 Mdot
.38896 .38992 Mdot
.39243 .44068 Mdot
.58108 .60856 Mdot
.28333 .39963 Mdot
.70335 .33181 Mdot
.40968 .42731 Mdot
.35236 .62878 Mdot
.37681 .60385 Mdot
.39797 .37026 Mdot
.43962 .40327 Mdot
.65246 .5171 Mdot
.46778 .7483 Mdot
.48836 .75902 Mdot
.46295 .74485 Mdot
.68089 .45287 Mdot
.29095 .74608 Mdot
.63932 .61154 Mdot
.35036 .77192 Mdot
.64609 .73876 Mdot
.42583 .33227 Mdot
.67283 .45979 Mdot
.40094 .4093 Mdot
.40648 .44577 Mdot
.61014 .62841 Mdot
.2277 .65515 Mdot
.34711 .40509 Mdot
.33025 .59452 Mdot
.57928 .61922 Mdot
.37907 .49634 Mdot
.64768 .66884 Mdot
.60299 .3217 Mdot
.51207 .46462 Mdot
.58971 .5955 Mdot
.36035 .63487 Mdot
.58312 .60325 Mdot
.38727 .3995 Mdot
.44917 .46125 Mdot
.38418 .61265 Mdot
.645 .33463 Mdot
.38002 .43194 Mdot
.40887 .41447 Mdot
.51209 .16782 Mdot
.42258 .7388 Mdot
.64235 .55747 Mdot
.42627 .44596 Mdot
.37685 .45041 Mdot
.6462 .33661 Mdot
.3826 .38988 Mdot
.45389 .39253 Mdot
.45942 .66333 Mdot
.64246 .62303 Mdot
.58877 .33576 Mdot
.19762 .42749 Mdot
.35908 .57865 Mdot
.68201 .75539 Mdot
.47264 .73473 Mdot
.64222 .6314 Mdot
.55698 .50187 Mdot
.4773 .75999 Mdot
.67727 .70245 Mdot
.73894 .65158 Mdot
.46822 .75623 Mdot
.62134 .51122 Mdot
.45552 .49194 Mdot
.4428 .37252 Mdot
.4196 .41576 Mdot
.64161 .33443 Mdot
.36184 .58448 Mdot
.52429 .63194 Mdot
.62242 .55224 Mdot
.42161 .40105 Mdot
.4002 .58783 Mdot
.71603 .70153 Mdot
.48467 .75285 Mdot
.632 .31202 Mdot
.64522 .30901 Mdot
.42871 .40798 Mdot
.43547 .65587 Mdot
.37154 .60964 Mdot
.42973 .39281 Mdot
.4247 .37025 Mdot
.64312 .45757 Mdot
.35033 .63647 Mdot
.65172 .51 Mdot
.48218 .72999 Mdot
.84205 .53458 Mdot
.53421 .16523 Mdot
.62096 .62741 Mdot
.7763 .58646 Mdot
.57329 .61014 Mdot
.73274 .51884 Mdot
.46664 .75122 Mdot
.42538 .39572 Mdot
.3832 .57633 Mdot
.42895 .38999 Mdot
.37815 .40285 Mdot
.37973 .41711 Mdot
.39505 .32948 Mdot
.34792 .25657 Mdot
.63134 .32146 Mdot
.35749 .42883 Mdot
.66624 .51888 Mdot
.73012 .69345 Mdot
.48033 .8197 Mdot
.39902 .39594 Mdot
.42349 .40595 Mdot
.35353 .57611 Mdot
.39724 .45205 Mdot
.58677 .6154 Mdot
.37039 .58209 Mdot
.3982 .43997 Mdot
.66763 .39595 Mdot
.38634 .38269 Mdot
.78486 .57551 Mdot
.58293 .60304 Mdot
.50761 .4654 Mdot
.39269 .46377 Mdot
.46638 .75465 Mdot
.47693 .76311 Mdot
.46634 .72693 Mdot
.59104 .59908 Mdot
.64698 .45681 Mdot
.67418 .52457 Mdot
.48239 .43486 Mdot
.42887 .43427 Mdot
.41371 .46574 Mdot
.68461 .45375 Mdot
.56079 .44175 Mdot
.32941 .72037 Mdot
.48948 .439 Mdot
.68621 .49013 Mdot
.39998 .56779 Mdot
.16984 .55048 Mdot
.35975 .5812 Mdot
.60398 .28729 Mdot
.59097 .64078 Mdot
.60605 .31118 Mdot
.3136 .28636 Mdot
.38383 .61896 Mdot
.32295 .6098 Mdot
.64063 .47404 Mdot
.50339 .61089 Mdot
.16526 .69528 Mdot
.64513 .49893 Mdot
.61244 .2693 Mdot
.36212 .60594 Mdot
.35484 .38345 Mdot
.51978 .55987 Mdot
.49943 .60042 Mdot
.65019 .4697 Mdot
.41201 .38201 Mdot
.42392 .60645 Mdot
.65083 .51661 Mdot
.40196 .35549 Mdot
.63564 .47134 Mdot
.62457 .59213 Mdot
.64021 .48603 Mdot
.37868 .56176 Mdot
.38999 .44474 Mdot
.11413 .61089 Mdot
.50729 .68326 Mdot
.43748 .38889 Mdot
.57861 .6218 Mdot
.78957 .37283 Mdot
.38345 .41003 Mdot
.61403 .30397 Mdot
.68837 .48458 Mdot
.76229 .4094 Mdot
.45176 .40429 Mdot
.65433 .47783 Mdot
.35368 .56273 Mdot
.7084 .47568 Mdot
.67172 .55365 Mdot
.48491 .76221 Mdot
.35372 .59327 Mdot
.49156 .72183 Mdot
.62162 .65124 Mdot
.37138 .42528 Mdot
.41212 .37219 Mdot
.33874 .61105 Mdot
.66428 .66704 Mdot
.35829 .39003 Mdot
.41296 .38384 Mdot
.64693 .51367 Mdot
.69076 .49585 Mdot
.52855 .75612 Mdot
.67004 .50591 Mdot
.3745 .44856 Mdot
.33947 .61531 Mdot
.41398 .43661 Mdot
.33784 .59426 Mdot
.37293 .41553 Mdot
.30467 .67419 Mdot
.35973 .58217 Mdot
.38081 .68398 Mdot
.4604 .43411 Mdot
.33299 .35969 Mdot
.37737 .40027 Mdot
.3891 .42632 Mdot
.6889 .47526 Mdot
.62427 .33357 Mdot
.41158 .35245 Mdot
.56311 .52021 Mdot
.6316 .35336 Mdot
.32919 .53536 Mdot
.64777 .45325 Mdot
.63195 .34834 Mdot
.4821 .27378 Mdot
.48871 .74233 Mdot
.62214 .3207 Mdot
.52024 .79589 Mdot
.61951 .62704 Mdot
.38722 .62323 Mdot
.45892 .41888 Mdot
.82285 .59173 Mdot
.70079 .32678 Mdot
.48043 .75064 Mdot
.44325 .39544 Mdot
.39676 .41167 Mdot
.3621 .64664 Mdot
.18982 .35437 Mdot
.64103 .44118 Mdot
.39701 .43528 Mdot
.39093 .60365 Mdot
.24047 .29476 Mdot
.63315 .47801 Mdot
.62457 .31597 Mdot
.59048 .59004 Mdot
.30904 .6358 Mdot
.48163 .7649 Mdot
.62657 .58757 Mdot
.60457 .46687 Mdot
.31265 .27459 Mdot
.45018 .40678 Mdot
.68117 .47168 Mdot
.36964 .25395 Mdot
.4544 .47136 Mdot
.57071 .60788 Mdot
.29595 .64044 Mdot
.37816 .61862 Mdot
.5805 .61061 Mdot
.64304 .31279 Mdot
.38626 .62062 Mdot
.36291 .6241 Mdot
.60573 .6529 Mdot
.54058 .63517 Mdot
.51218 .56284 Mdot
.58362 .63058 Mdot
.47713 .62479 Mdot
.39386 .25196 Mdot
.467 .74507 Mdot
.63195 .31129 Mdot
.5353 .19077 Mdot
.37363 .60819 Mdot
.56742 .81755 Mdot
.34792 .25941 Mdot
.38635 .426 Mdot
.61916 .34436 Mdot
.67784 .71328 Mdot
.61311 .54049 Mdot
.62573 .63257 Mdot
.56132 .41564 Mdot
.6281 .30121 Mdot
.40746 .36963 Mdot
.26608 .6467 Mdot
.46296 .41655 Mdot
.62947 .61403 Mdot
.45542 .55374 Mdot
.34649 .63393 Mdot
.62448 .64884 Mdot
.46347 .5282 Mdot
.41022 .44637 Mdot
.43897 .38207 Mdot
.55419 .21767 Mdot
.35254 .63849 Mdot
.48158 .76597 Mdot
.42375 .38486 Mdot
.40147 .41976 Mdot
.36672 .41634 Mdot
.38963 .29282 Mdot
.43225 .68135 Mdot
.39398 .43527 Mdot
.65909 .44403 Mdot
.43041 .46327 Mdot
.44754 .38773 Mdot
.37886 .64074 Mdot
.44418 .19941 Mdot
.47911 .72727 Mdot
.4157 .41773 Mdot
.40998 .4266 Mdot
.63302 .63 Mdot
.51527 .56075 Mdot
.49682 .60403 Mdot
.63088 .50152 Mdot
.57234 .27903 Mdot
.39724 .4738 Mdot
.34542 .59563 Mdot
.60168 .31427 Mdot
.37031 .43665 Mdot
.35066 .58069 Mdot
.44031 .46906 Mdot
.65325 .51897 Mdot
.46966 .74926 Mdot
.455 .32115 Mdot
.6188 .32455 Mdot
.62654 .66232 Mdot
.38732 .79614 Mdot
.66629 .51117 Mdot
.43517 .43799 Mdot
.70108 .46961 Mdot
.65914 .5021 Mdot
.48179 .74619 Mdot
.48354 .39467 Mdot
.36331 .59725 Mdot
.35011 .63423 Mdot
.43151 .23694 Mdot
.66494 .43957 Mdot
.37795 .19101 Mdot
.62525 .59316 Mdot
.43459 .36281 Mdot
.4678 .80512 Mdot
.34266 .62924 Mdot
.54296 .20386 Mdot
.63434 .34708 Mdot
.62529 .63288 Mdot
.49348 .7456 Mdot
.34818 .58238 Mdot
.3358 .62415 Mdot
.37765 .4204 Mdot
.40437 .40059 Mdot
.60321 .26542 Mdot
.4823 .20711 Mdot
.61865 .58997 Mdot
.62014 .31262 Mdot
.62784 .49174 Mdot
.418 .4452 Mdot
.38532 .59709 Mdot
.26953 .61736 Mdot
.39291 .38369 Mdot
.64804 .51678 Mdot
.38116 .61211 Mdot
.61136 .31744 Mdot
.61375 .34709 Mdot
.38681 .42506 Mdot
.30798 .53507 Mdot
.61596 .61096 Mdot
.33548 .6105 Mdot
.39124 .53896 Mdot
.36364 .38808 Mdot
.4024 .39709 Mdot
.35753 .46392 Mdot
.63039 .58953 Mdot
.46327 .32572 Mdot
.65123 .315 Mdot
.36544 .59072 Mdot
.43308 .38763 Mdot
.61614 .32175 Mdot
.4011 .30384 Mdot
.4729 .75647 Mdot
.63508 .47541 Mdot
.61548 .30462 Mdot
.61704 .33789 Mdot
.62171 .35618 Mdot
.55463 .81915 Mdot
.35002 .6504 Mdot
.19252 .42549 Mdot
.37568 .41245 Mdot
.40211 .25137 Mdot
.44374 .45288 Mdot
.61372 .58541 Mdot
.68099 .49578 Mdot
.38055 .40038 Mdot
.37675 .41929 Mdot
.27625 .65328 Mdot
.35847 .48072 Mdot
.45254 .5082 Mdot
.36568 .63595 Mdot
.34407 .33181 Mdot
.66679 .45482 Mdot
.24607 .26938 Mdot
.54283 .84786 Mdot
.38043 .4664 Mdot
.50931 .60154 Mdot
.37267 .58348 Mdot
.63134 .6235 Mdot
.49606 .58893 Mdot
.64677 .58898 Mdot
.37103 .59133 Mdot
.41483 .44283 Mdot
.35404 .77051 Mdot
.61124 .35684 Mdot
.39102 .3928 Mdot
.60022 .60303 Mdot
.39019 .39295 Mdot
.59887 .59127 Mdot
.3203 .64966 Mdot
.48979 .63424 Mdot
.45317 .42154 Mdot
.35935 .40231 Mdot
.49769 .36217 Mdot
.4 .39791 Mdot
.70433 .6102 Mdot
.35888 .6158 Mdot
.37907 .67864 Mdot
.39121 .37296 Mdot
.29798 .51824 Mdot
.40162 .37496 Mdot
.66459 .67163 Mdot
.41951 .37251 Mdot
.52383 .35458 Mdot
.41048 .36785 Mdot
.41535 .37547 Mdot
.60507 .6273 Mdot
.63287 .62736 Mdot
.35005 .56513 Mdot
.47379 .76542 Mdot
.73568 .69253 Mdot
.41465 .4098 Mdot
.69021 .47203 Mdot
.4867 .78993 Mdot
.62093 .33705 Mdot
.37137 .59446 Mdot
.33614 .18316 Mdot
.60615 .59283 Mdot
.61988 .4626 Mdot
.68009 .59479 Mdot
.63239 .4529 Mdot
.64626 .43093 Mdot
.3285 .38115 Mdot
.62242 .31002 Mdot
.40617 .37173 Mdot
.32631 .50738 Mdot
.40721 .74075 Mdot
.39666 .3585 Mdot
.69582 .50477 Mdot
.37899 .501 Mdot
.3951 .24921 Mdot
.61906 .36337 Mdot
.62792 .30538 Mdot
.59695 .62609 Mdot
.61941 .48604 Mdot
.42232 .48282 Mdot
.62982 .34959 Mdot
.67794 .50368 Mdot
.45916 .75108 Mdot
.65542 .28139 Mdot
.37133 .60525 Mdot
.51792 .38973 Mdot
.42923 .78799 Mdot
.61283 .59115 Mdot
.56252 .51451 Mdot
.39398 .63579 Mdot
.31625 .62497 Mdot
.46412 .75683 Mdot
.67589 .51403 Mdot
.39461 .60791 Mdot
.3831 .43559 Mdot
.44624 .34685 Mdot
.43182 .40693 Mdot
.6316 .3453 Mdot
.43414 .37396 Mdot
.6712 .51518 Mdot
.62028 .59874 Mdot
.66841 .48009 Mdot
.61886 .61108 Mdot
.33887 .74982 Mdot
.44294 .40495 Mdot
.40586 .3974 Mdot
.55065 .49673 Mdot
.33039 .61156 Mdot
.30842 .45104 Mdot
.67838 .51252 Mdot
.64965 .46123 Mdot
.41205 .43793 Mdot
.33771 .5765 Mdot
.59485 .31251 Mdot
.52286 .56667 Mdot
.42038 .3712 Mdot
.35777 .61515 Mdot
.41614 .43302 Mdot
.76212 .45931 Mdot
.4918 .66701 Mdot
.35138 .63256 Mdot
.16841 .50106 Mdot
.44915 .44461 Mdot
.38783 .51444 Mdot
.35681 .36175 Mdot
.55106 .32441 Mdot
.3906 .3553 Mdot
.37076 .57991 Mdot
.43109 .41343 Mdot
.34856 .59782 Mdot
.66284 .50436 Mdot
.63715 .61298 Mdot
.35328 .59858 Mdot
.46588 .41787 Mdot
.51037 .84383 Mdot
.60754 .59508 Mdot
.40478 .38778 Mdot
.59568 .63493 Mdot
.39276 .6182 Mdot
.33377 .62781 Mdot
.53207 .78097 Mdot
.66065 .61212 Mdot
.60151 .59876 Mdot
.42996 .43152 Mdot
.44547 .77122 Mdot
.41476 .43631 Mdot
.6035 .26117 Mdot
.39584 .36645 Mdot
.3717 .37598 Mdot
.32713 .77838 Mdot
.6533 .61105 Mdot
.35526 .19156 Mdot
.60714 .55659 Mdot
.54053 .82062 Mdot
.36182 .65995 Mdot
.6185 .36343 Mdot
.76897 .59318 Mdot
.47938 .7297 Mdot
.66141 .44681 Mdot
.38066 .39934 Mdot
.29111 .66797 Mdot
.58103 .62447 Mdot
.62952 .33212 Mdot
.45361 .42188 Mdot
.63416 .51701 Mdot
.50591 .80122 Mdot
.63058 .61844 Mdot
.37266 .60357 Mdot
.32951 .60547 Mdot
.20539 .36799 Mdot
.43589 .38997 Mdot
.41149 .39982 Mdot
.58937 .64051 Mdot
.43571 .47744 Mdot
.60824 .35097 Mdot
.78126 .45051 Mdot
.59608 .60739 Mdot
.50107 .68595 Mdot
.37 .63458 Mdot
.39825 .41055 Mdot
.57191 .46043 Mdot
.59861 .77422 Mdot
.22129 .43352 Mdot
.64161 .32932 Mdot
.57511 .2459 Mdot
.37032 .57972 Mdot
.60135 .60445 Mdot
.41916 .2617 Mdot
.47148 .40418 Mdot
.3966 .41426 Mdot
.57097 .23772 Mdot
.51704 .5716 Mdot
.66013 .3262 Mdot
.35587 .37439 Mdot
.5234 .53727 Mdot
.41116 .4391 Mdot
.39296 .4411 Mdot
.37892 .4664 Mdot
.44924 .38588 Mdot
.35324 .61005 Mdot
.23595 .61063 Mdot
.64985 .48569 Mdot
.26164 .36112 Mdot
.56205 .40163 Mdot
.45714 .40477 Mdot
.41217 .44448 Mdot
.20947 .57995 Mdot
.49237 .78048 Mdot
.36235 .61405 Mdot
.40389 .56165 Mdot
.64051 .61082 Mdot
.355 .47516 Mdot
.67224 .44363 Mdot
.43887 .50993 Mdot
.66277 .49343 Mdot
.35656 .61526 Mdot
.6521 .45645 Mdot
.63851 .62644 Mdot
.68111 .47222 Mdot
.67754 .45009 Mdot
.61464 .57857 Mdot
.35399 .64147 Mdot
.4082 .37674 Mdot
.62642 .58949 Mdot
.56486 .21665 Mdot
.63054 .34599 Mdot
.52984 .78319 Mdot
.35193 .38888 Mdot
.39541 .52193 Mdot
.77175 .36365 Mdot
.66975 .46878 Mdot
.47227 .67833 Mdot
.35938 .58235 Mdot
.60103 .31011 Mdot
.35065 .60562 Mdot
.31268 .30011 Mdot
.61254 .33014 Mdot
.5287 .78601 Mdot
.43557 .25905 Mdot
.58974 .50147 Mdot
.46808 .43357 Mdot
.34833 .68018 Mdot
.6647 .49379 Mdot
.5802 .63019 Mdot
.69431 .70622 Mdot
.42995 .45432 Mdot
.4013 .70137 Mdot
.33038 .64577 Mdot
.48984 .74842 Mdot
.60538 .60204 Mdot
.57864 .58313 Mdot
.43771 .39333 Mdot
.58413 .49436 Mdot
.38402 .36635 Mdot
.36171 .29821 Mdot
.58178 .26857 Mdot
.29843 .63198 Mdot
.42273 .42939 Mdot
.63813 .50826 Mdot
.41961 .43236 Mdot
.48933 .45103 Mdot
.37991 .25587 Mdot
.35867 .4245 Mdot
.37626 .69473 Mdot
.76584 .39512 Mdot
.385 .60749 Mdot
.37001 .44546 Mdot
.47475 .74395 Mdot
.43146 .44854 Mdot
.86754 .55562 Mdot
.62355 .32344 Mdot
.60839 .50034 Mdot
.46711 .42093 Mdot
.42611 .3871 Mdot
.29126 .57183 Mdot
.35616 .67279 Mdot
.49094 .74002 Mdot
.3929 .41692 Mdot
.56147 .25475 Mdot
.60086 .63048 Mdot
.42356 .36297 Mdot
.42666 .41321 Mdot
.58032 .19679 Mdot
.6011 .63343 Mdot
.6712 .46489 Mdot
.48693 .73864 Mdot
.62977 .49413 Mdot
.6094 .36275 Mdot
.48458 .58936 Mdot
.52056 .20031 Mdot
.49132 .66958 Mdot
.61973 .30034 Mdot
.45798 .38968 Mdot
.37155 .51963 Mdot
.43045 .38087 Mdot
.6329 .30648 Mdot
.58977 .62717 Mdot
.35501 .60824 Mdot
.50549 .35165 Mdot
.48078 .73953 Mdot
.38912 .36013 Mdot
.62967 .3603 Mdot
.35814 .59807 Mdot
.5565 .75184 Mdot
.36909 .58659 Mdot
.61128 .6191 Mdot
.64272 .60782 Mdot
.6172 .33139 Mdot
.35124 .60827 Mdot
.63179 .46906 Mdot
.60646 .55899 Mdot
.39222 .36594 Mdot
.62324 .55639 Mdot
.36886 .56365 Mdot
.32486 .61246 Mdot
.37483 .57175 Mdot
.44616 .40498 Mdot
.51334 .58192 Mdot
.47357 .41736 Mdot
.59438 .60322 Mdot
.64714 .4505 Mdot
.46311 .21688 Mdot
.32235 .50659 Mdot
.50133 .68364 Mdot
.40476 .35242 Mdot
.44223 .38247 Mdot
.42865 .40773 Mdot
.41783 .42622 Mdot
.77786 .46128 Mdot
.44201 .40595 Mdot
.6166 .62022 Mdot
.65404 .49784 Mdot
.44229 .39304 Mdot
.47209 .74459 Mdot
.54208 .46297 Mdot
.60324 .31207 Mdot
.53261 .36139 Mdot
.54751 .8378 Mdot
.35816 .5997 Mdot
.67849 .48816 Mdot
.63862 .45683 Mdot
.61561 .3507 Mdot
.62873 .5959 Mdot
.36265 .5854 Mdot
.52906 .31868 Mdot
.63276 .35383 Mdot
.41459 .41835 Mdot
.56079 .48043 Mdot
.16799 .52312 Mdot
.4608 .39112 Mdot
.38256 .41825 Mdot
.48937 .76173 Mdot
.63184 .45046 Mdot
.8217 .63104 Mdot
.53329 .63923 Mdot
.62229 .33308 Mdot
.60782 .31682 Mdot
.37813 .57718 Mdot
.4233 .35876 Mdot
.61734 .60624 Mdot
.52327 .54802 Mdot
.77352 .34812 Mdot
.68823 .73123 Mdot
.7258 .52855 Mdot
.38364 .38541 Mdot
.25373 .57796 Mdot
.36934 .39643 Mdot
.3444 .64776 Mdot
.36661 .57243 Mdot
.36633 .61131 Mdot
.60401 .62633 Mdot
.28432 .28562 Mdot
.61873 .61855 Mdot
.54885 .83894 Mdot
.38904 .60541 Mdot
.61107 .41899 Mdot
.64397 .46285 Mdot
.48431 .41694 Mdot
.62515 .31007 Mdot
.70146 .50762 Mdot
.37703 .4534 Mdot
.42933 .66128 Mdot
.6728 .4599 Mdot
.33647 .63391 Mdot
.49726 .40547 Mdot
.75308 .68001 Mdot
.49987 .61852 Mdot
.71998 .30478 Mdot
.30573 .34559 Mdot
.61042 .32541 Mdot
.19844 .46648 Mdot
.61188 .355 Mdot
.62819 .62753 Mdot
.43291 .45404 Mdot
.463 .43245 Mdot
.39879 .43375 Mdot
.4436 .40938 Mdot
.59367 .62627 Mdot
.38023 .3805 Mdot
.46846 .19864 Mdot
.46827 .7349 Mdot
.62327 .411 Mdot
.60608 .33771 Mdot
.60983 .58408 Mdot
.65601 .50115 Mdot
.46905 .76328 Mdot
.61201 .23449 Mdot
.37975 .38451 Mdot
.37876 .39938 Mdot
.46157 .7414 Mdot
.44131 .47363 Mdot
.49131 .38642 Mdot
.65331 .48336 Mdot
.48455 .52964 Mdot
.64315 .30902 Mdot
.60557 .31221 Mdot
.58531 .60125 Mdot
.35048 .60584 Mdot
.64041 .33909 Mdot
.62119 .4958 Mdot
.43067 .36528 Mdot
.35805 .40802 Mdot
.36855 .56339 Mdot
.34812 .25918 Mdot
.59772 .3494 Mdot
.50356 .40027 Mdot
.34997 .58717 Mdot
.33659 .64821 Mdot
.39137 .41515 Mdot
.40497 .34709 Mdot
.32781 .63077 Mdot
.60299 .33419 Mdot
.60827 .58344 Mdot
.59201 .44448 Mdot
.62481 .60198 Mdot
.35699 .59001 Mdot
.4687 .44116 Mdot
.36078 .63957 Mdot
.44731 .44485 Mdot
.1459 .3646 Mdot
.44279 .37987 Mdot
.40602 .64296 Mdot
.55767 .32301 Mdot
.63382 .47384 Mdot
.63125 .48209 Mdot
.47046 .74745 Mdot
.35683 .58016 Mdot
.37507 .44053 Mdot
.61335 .31097 Mdot
.53013 .81845 Mdot
.34648 .55355 Mdot
.68509 .46909 Mdot
.64802 .44074 Mdot
.59014 .62528 Mdot
.40852 .37198 Mdot
.40363 .40939 Mdot
.67975 .47032 Mdot
.79019 .38934 Mdot
.34432 .60342 Mdot
.41175 .3996 Mdot
.44861 .388 Mdot
.64981 .48909 Mdot
.5962 .56352 Mdot
.38737 .65171 Mdot
.44837 .38553 Mdot
.45022 .25624 Mdot
.60098 .59146 Mdot
.43861 .42511 Mdot
.37574 .3868 Mdot
.62452 .34016 Mdot
.65771 .38691 Mdot
.38874 .25249 Mdot
.62703 .58514 Mdot
.48523 .76308 Mdot
.43914 .45357 Mdot
.64303 .46658 Mdot
.35448 .3861 Mdot
.7993 .56936 Mdot
.47421 .73149 Mdot
.43196 .39789 Mdot
.40181 .4726 Mdot
.33379 .60255 Mdot
.42982 .39436 Mdot
.30049 .66324 Mdot
.63716 .50236 Mdot
.43324 .39789 Mdot
.3103 .52772 Mdot
.58971 .62203 Mdot
.37991 .45522 Mdot
.61393 .3074 Mdot
.55756 .33077 Mdot
.40838 .79688 Mdot
.68909 .46329 Mdot
.61241 .34511 Mdot
.43186 .37263 Mdot
.63918 .51277 Mdot
.58967 .59068 Mdot
.40978 .68296 Mdot
.45261 .37935 Mdot
.62332 .59552 Mdot
.61769 .59647 Mdot
.62061 .32961 Mdot
.31426 .21146 Mdot
.40185 .47338 Mdot
.3989 .39133 Mdot
.7416 .28788 Mdot
.39076 .63324 Mdot
.39936 .38759 Mdot
.40915 .37266 Mdot
.62575 .61626 Mdot
.41203 .27854 Mdot
.42916 .53405 Mdot
.7896 .42548 Mdot
.60135 .58999 Mdot
.64352 .53456 Mdot
.65047 .51209 Mdot
.60938 .34173 Mdot
.38361 .60605 Mdot
.63247 .30049 Mdot
.64184 .48137 Mdot
.3904 .42735 Mdot
.6156 .64213 Mdot
.25063 .42512 Mdot
.57909 .63149 Mdot
.63431 .51453 Mdot
.32882 .63813 Mdot
.45337 .81193 Mdot
.801 .32269 Mdot
.41552 .78045 Mdot
.6255 .58173 Mdot
.62115 .33728 Mdot
.52943 .62576 Mdot
.4405 .38153 Mdot
.19491 .44779 Mdot
.39471 .39117 Mdot
.30766 .33118 Mdot
.68071 .4978 Mdot
.46127 .75181 Mdot
.42734 .45483 Mdot
.57199 .24873 Mdot
.62256 .58179 Mdot
.58759 .61541 Mdot
.41804 .42148 Mdot
.61324 .61691 Mdot
.40884 .40544 Mdot
.64934 .49527 Mdot
.32138 .21058 Mdot
.42224 .3749 Mdot
.38338 .45206 Mdot
.64278 .62457 Mdot
.52891 .78449 Mdot
.65107 .53092 Mdot
.25935 .57995 Mdot
.76599 .67224 Mdot
.61294 .61312 Mdot
.37715 .33943 Mdot
.67516 .47452 Mdot
.48712 .76545 Mdot
.62334 .44027 Mdot
.39119 .39945 Mdot
.37729 .39359 Mdot
.40589 .43745 Mdot
.44258 .38447 Mdot
.18965 .47022 Mdot
.49069 .40369 Mdot
.24143 .52799 Mdot
.37755 .40276 Mdot
.41408 .61179 Mdot
.61346 .62542 Mdot
.40318 .52514 Mdot
.65593 .34162 Mdot
.37638 .39275 Mdot
.36218 .67195 Mdot
.61479 .58342 Mdot
.5673 .82941 Mdot
.59651 .63122 Mdot
.66581 .47312 Mdot
.62592 .63744 Mdot
.45327 .44033 Mdot
.37684 .606 Mdot
.64441 .50352 Mdot
.33422 .7257 Mdot
.66619 .44897 Mdot
.43752 .38916 Mdot
.60244 .53392 Mdot
.63469 .46931 Mdot
.53827 .39888 Mdot
.37866 .60462 Mdot
.5493 .24784 Mdot
.38762 .63835 Mdot
.42356 .39301 Mdot
.41697 .3904 Mdot
.46891 .76439 Mdot
.6307 .61721 Mdot
.39142 .60994 Mdot
.50629 .16853 Mdot
.64174 .35178 Mdot
.36889 .61879 Mdot
.42491 .34663 Mdot
.51364 .5936 Mdot
.3382 .61875 Mdot
.55509 .2864 Mdot
.62973 .61238 Mdot
.38603 .5859 Mdot
.47592 .38362 Mdot
.44753 .30933 Mdot
.59883 .34275 Mdot
.65315 .51992 Mdot
.52999 .51637 Mdot
.64659 .51078 Mdot
.60771 .66018 Mdot
.65265 .43566 Mdot
.6057 .63053 Mdot
.32616 .68768 Mdot
.45383 .5481 Mdot
.61384 .65921 Mdot
.63827 .63114 Mdot
.64654 .4765 Mdot
.41508 .42624 Mdot
.58163 .42105 Mdot
.42678 .34938 Mdot
.45564 .45643 Mdot
.60971 .58841 Mdot
.37397 .58013 Mdot
.37499 .63428 Mdot
.38158 .66586 Mdot
.3334 .62362 Mdot
.65123 .50547 Mdot
.48466 .66395 Mdot
.30507 .3183 Mdot
.59042 .63353 Mdot
.65231 .59116 Mdot
.41658 .43767 Mdot
.64292 .47173 Mdot
.66391 .50595 Mdot
.62139 .60489 Mdot
.23568 .39734 Mdot
.39743 .46254 Mdot
.37462 .64391 Mdot
.38944 .60741 Mdot
.34139 .62269 Mdot
.3487 .57351 Mdot
.25981 .307 Mdot
.58013 .63016 Mdot
.3691 .58054 Mdot
.43598 .41622 Mdot
.38375 .39033 Mdot
.48794 .75313 Mdot
.60432 .3276 Mdot
.42422 .4589 Mdot
.41091 .46066 Mdot
.39168 .41396 Mdot
.63493 .47205 Mdot
.40217 .494 Mdot
.47656 .73245 Mdot
.64984 .43711 Mdot
.67649 .44712 Mdot
.46782 .75847 Mdot
.35269 .54651 Mdot
.74581 .70274 Mdot
.398 .43537 Mdot
.32797 .43915 Mdot
.64636 .4674 Mdot
.45926 .61675 Mdot
.44958 .3232 Mdot
.43015 .42902 Mdot
.61299 .39752 Mdot
.64757 .49867 Mdot
.31248 .61074 Mdot
.3962 .39701 Mdot
.46424 .74714 Mdot
.59925 .32252 Mdot
.45567 .36498 Mdot
.48961 .76187 Mdot
.35464 .616 Mdot
.75301 .36857 Mdot
.3954 .62024 Mdot
.63306 .47041 Mdot
.37256 .4485 Mdot
.14134 .66484 Mdot
.6658 .49368 Mdot
.59851 .79995 Mdot
.4576 .53985 Mdot
.4299 .37575 Mdot
.65253 .50954 Mdot
.31338 .61955 Mdot
.60178 .59125 Mdot
.54308 .50502 Mdot
.38532 .59768 Mdot
.46657 .76092 Mdot
.48258 .76175 Mdot
.65044 .48669 Mdot
.3741 .62795 Mdot
.39083 .37028 Mdot
.3405 .58789 Mdot
.6099 .65083 Mdot
.45013 .43363 Mdot
.73712 .69195 Mdot
.44548 .34609 Mdot
.34974 .58569 Mdot
.62074 .49844 Mdot
.64598 .33464 Mdot
.45291 .41967 Mdot
.66031 .77147 Mdot
.4121 .37077 Mdot
.59282 .63227 Mdot
.44762 .60124 Mdot
.24347 .43854 Mdot
.40416 .42842 Mdot
.41344 .44169 Mdot
.59096 .59268 Mdot
.40023 .42958 Mdot
.44855 .37798 Mdot
.5706 .60314 Mdot
.33477 .61569 Mdot
.42945 .40333 Mdot
.66143 .51381 Mdot
.30895 .38686 Mdot
.41157 .45494 Mdot
.33152 .70514 Mdot
.5608 .24584 Mdot
.44353 .58114 Mdot
.37248 .43975 Mdot
.56821 .2131 Mdot
.41188 .39118 Mdot
.44965 .41285 Mdot
.40798 .43348 Mdot
.24619 .58431 Mdot
.64312 .47799 Mdot
.68356 .49903 Mdot
.59627 .33003 Mdot
.56485 .25116 Mdot
.62342 .34422 Mdot
.60593 .58265 Mdot
.66788 .62469 Mdot
.46856 .73578 Mdot
.34962 .60301 Mdot
.39 .44359 Mdot
.66676 .44684 Mdot
.39574 .40868 Mdot
.43215 .44725 Mdot
.64238 .49431 Mdot
.65848 .50549 Mdot
.6782 .44436 Mdot
.621 .35876 Mdot
.36001 .6078 Mdot
.38327 .42605 Mdot
.63329 .3523 Mdot
.39917 .36845 Mdot
.51709 .59685 Mdot
.36153 .61035 Mdot
.33952 .58889 Mdot
.38112 .63408 Mdot
.37502 .41019 Mdot
.45888 .4308 Mdot
.61959 .61744 Mdot
.37198 .56333 Mdot
.58659 .63144 Mdot
.65064 .50936 Mdot
.63246 .48289 Mdot
.39077 .39931 Mdot
.50233 .40704 Mdot
.6068 .32436 Mdot
.66685 .46967 Mdot
.47115 .72593 Mdot
.59634 .32815 Mdot
.44376 .39623 Mdot
.64708 .50939 Mdot
.60846 .30828 Mdot
.26084 .38154 Mdot
.78387 .6487 Mdot
.63937 .34948 Mdot
.41897 .42084 Mdot
.30197 .55566 Mdot
.43018 .2523 Mdot
.64737 .34368 Mdot
.60287 .63948 Mdot
.4011 .37758 Mdot
.80323 .39514 Mdot
.64279 .30578 Mdot
.35179 .25857 Mdot
.63958 .4899 Mdot
.35086 .31687 Mdot
.45755 .36544 Mdot
.21918 .39741 Mdot
.64077 .30319 Mdot
.36214 .58804 Mdot
.38703 .57798 Mdot
.41181 .42116 Mdot
.65145 .34322 Mdot
.59444 .65278 Mdot
.63798 .45694 Mdot
.68029 .45476 Mdot
.36938 .63118 Mdot
.49607 .67853 Mdot
.65848 .51369 Mdot
.35862 .43416 Mdot
.61031 .48294 Mdot
.34105 .44426 Mdot
.21878 .35485 Mdot
.32942 .73423 Mdot
.36281 .41784 Mdot
.64694 .33453 Mdot
.61138 .57753 Mdot
.61754 .61619 Mdot
.60485 .62384 Mdot
.63263 .49223 Mdot
.50599 .57405 Mdot
.68368 .4755 Mdot
.40459 .70896 Mdot
.61643 .32077 Mdot
.52865 .25783 Mdot
.38686 .44777 Mdot
.43143 .37678 Mdot
.43048 .3644 Mdot
.40465 .43839 Mdot
.41147 .39247 Mdot
.61495 .59088 Mdot
.62864 .467 Mdot
.76851 .41311 Mdot
.34985 .62689 Mdot
.55112 .73758 Mdot
.64427 .46216 Mdot
.49122 .74876 Mdot
.63337 .32457 Mdot
.51968 .20401 Mdot
.63204 .53927 Mdot
.65158 .45719 Mdot
.45419 .37857 Mdot
.36757 .57585 Mdot
.39951 .2919 Mdot
.41274 .38374 Mdot
.66773 .46892 Mdot
.61598 .47067 Mdot
.20558 .45703 Mdot
.34721 .43476 Mdot
.59854 .29786 Mdot
.51213 .5945 Mdot
.64876 .30749 Mdot
.38918 .35292 Mdot
.46032 .62254 Mdot
.64384 .48163 Mdot
.66294 .47781 Mdot
.64088 .35038 Mdot
.42113 .50904 Mdot
.38145 .61689 Mdot
.46073 .74979 Mdot
.60664 .63719 Mdot
.42055 .38073 Mdot
.63396 .49703 Mdot
.3472 .47808 Mdot
.56032 .48644 Mdot
.5957 .61583 Mdot
.64678 .43826 Mdot
.39899 .37641 Mdot
.40737 .42454 Mdot
.61081 .3294 Mdot
.68279 .32742 Mdot
.43632 .3529 Mdot
.54126 .8206 Mdot
.48535 .62093 Mdot
.50719 .48377 Mdot
.39711 .41413 Mdot
.3534 .63723 Mdot
.46641 .75176 Mdot
.63347 .31152 Mdot
.40069 .36981 Mdot
.77296 .67771 Mdot
.39204 .5684 Mdot
.60703 .59671 Mdot
.4651 .75117 Mdot
.50865 .56203 Mdot
.41482 .36996 Mdot
.39478 .3914 Mdot
.44505 .40679 Mdot
.78226 .67177 Mdot
.68039 .50169 Mdot
.36919 .56785 Mdot
.64118 .33181 Mdot
.33246 .59576 Mdot
.68804 .48204 Mdot
.53498 .45464 Mdot
.44695 .39659 Mdot
.37175 .64303 Mdot
.36612 .58799 Mdot
.58933 .6237 Mdot
.62485 .58664 Mdot
.68688 .50601 Mdot
.43619 .37618 Mdot
.46432 .74017 Mdot
.38404 .58696 Mdot
.62444 .46691 Mdot
.61157 .32838 Mdot
.63664 .59706 Mdot
.37675 .40464 Mdot
.64856 .48342 Mdot
.36734 .39286 Mdot
.33779 .59952 Mdot
.64989 .45809 Mdot
.49301 .75097 Mdot
.60576 .32238 Mdot
.37626 .39835 Mdot
.76488 .37079 Mdot
.46365 .75248 Mdot
.46378 .41683 Mdot
.32608 .54578 Mdot
.6386 .36766 Mdot
.32948 .72394 Mdot
.67959 .49321 Mdot
.47307 .73762 Mdot
.36851 .57133 Mdot
.42695 .30242 Mdot
.66207 .48464 Mdot
.28045 .61879 Mdot
.60344 .4147 Mdot
.39014 .42982 Mdot
.37162 .62188 Mdot
.64168 .28779 Mdot
.56848 .82088 Mdot
.4571 .24461 Mdot
.41745 .40124 Mdot
.6467 .51116 Mdot
.60473 .31282 Mdot
.58639 .6271 Mdot
.33509 .70471 Mdot
.2169 .36769 Mdot
.65334 .43792 Mdot
.38142 .42879 Mdot
.38129 .58369 Mdot
.61883 .60237 Mdot
.34434 .76328 Mdot
.62325 .50152 Mdot
.67225 .50729 Mdot
.45128 .40575 Mdot
.64253 .32736 Mdot
.80197 .41553 Mdot
.6789 .5062 Mdot
.62891 .49015 Mdot
.54034 .74711 Mdot
.60706 .35689 Mdot
.43159 .41645 Mdot
.3807 .66661 Mdot
.42964 .36587 Mdot
.55157 .80938 Mdot
.47057 .73768 Mdot
.34785 .6245 Mdot
.38787 .39191 Mdot
.76583 .39855 Mdot
.66083 .4951 Mdot
.50844 .60085 Mdot
.55937 .64197 Mdot
.62759 .59265 Mdot
.63569 .49795 Mdot
.39796 .40275 Mdot
.64319 .60542 Mdot
.60704 .32808 Mdot
.44826 .38526 Mdot
.45407 .43836 Mdot
.31773 .63282 Mdot
.61211 .64714 Mdot
.31287 .39261 Mdot
.61698 .65073 Mdot
.58257 .60481 Mdot
.33912 .64978 Mdot
.41269 .41999 Mdot
.66185 .46476 Mdot
.64111 .52031 Mdot
.38098 .3775 Mdot
.4606 .61422 Mdot
.3791 .61889 Mdot
.60725 .44756 Mdot
.82095 .62597 Mdot
.39012 .47352 Mdot
.47519 .72595 Mdot
.32712 .32995 Mdot
.58806 .60549 Mdot
.38988 .42497 Mdot
.34661 .59743 Mdot
.62575 .47833 Mdot
.6559 .51611 Mdot
.46159 .38259 Mdot
.62186 .60194 Mdot
.60892 .30503 Mdot
.67011 .50343 Mdot
.5593 .49282 Mdot
.43454 .39574 Mdot
.39944 .7017 Mdot
.67389 .49718 Mdot
.46886 .83581 Mdot
.76654 .40503 Mdot
.3553 .63229 Mdot
.42682 .44414 Mdot
.33263 .58635 Mdot
.63905 .33598 Mdot
.62858 .4368 Mdot
.62361 .60272 Mdot
.51405 .40884 Mdot
.56663 .18485 Mdot
.64041 .47424 Mdot
.3544 .61139 Mdot
.37962 .41939 Mdot
.49455 .36907 Mdot
.41938 .37206 Mdot
.43678 .28294 Mdot
.62128 .27181 Mdot
.63976 .62467 Mdot
.58528 .61843 Mdot
.4105 .44612 Mdot
.61472 .35532 Mdot
.65576 .52337 Mdot
.64185 .49179 Mdot
.24698 .26197 Mdot
.49151 .75978 Mdot
.59788 .2752 Mdot
.37529 .40777 Mdot
.6277 .46014 Mdot
.32177 .49914 Mdot
.58951 .64048 Mdot
.40468 .36045 Mdot
.64218 .44717 Mdot
.59248 .76781 Mdot
.51767 .5849 Mdot
.42812 .39863 Mdot
.43612 .47774 Mdot
.59893 .63591 Mdot
.52944 .62745 Mdot
.68227 .47222 Mdot
.40785 .36356 Mdot
.57923 .65382 Mdot
.52586 .77427 Mdot
.53765 .17934 Mdot
.36046 .60792 Mdot
.6176 .48991 Mdot
.62478 .59117 Mdot
.39305 .48748 Mdot
.60454 .33516 Mdot
.62762 .49644 Mdot
.65103 .44765 Mdot
.44309 .43809 Mdot
.4122 .45802 Mdot
.36655 .46246 Mdot
.36178 .62247 Mdot
.62221 .6228 Mdot
.4109 .45079 Mdot
.50153 .65971 Mdot
.39568 .43697 Mdot
.62356 .61842 Mdot
.09423 .53308 Mdot
.46431 .39501 Mdot
.40366 .38231 Mdot
.54651 .3536 Mdot
.38309 .62369 Mdot
.33184 .61102 Mdot
.49036 .65046 Mdot
.37518 .40666 Mdot
.58596 .47282 Mdot
.35764 .6055 Mdot
.37861 .61694 Mdot
.59536 .4474 Mdot
.44755 .43164 Mdot
.61985 .66754 Mdot
.61917 .60649 Mdot
.62689 .59098 Mdot
.33476 .59958 Mdot
.48437 .41247 Mdot
.59452 .58591 Mdot
.18423 .4944 Mdot
.64589 .45777 Mdot
.46017 .62319 Mdot
.34356 .5865 Mdot
.58117 .44526 Mdot
.62991 .61948 Mdot
.5044 .85985 Mdot
.48019 .31802 Mdot
.37743 .37423 Mdot
.40831 .42579 Mdot
.6199 .34061 Mdot
.45284 .3368 Mdot
.4869 .76128 Mdot
.61252 .61929 Mdot
.76953 .48189 Mdot
.36706 .61162 Mdot
.40826 .3785 Mdot
.47215 .21323 Mdot
.36103 .76364 Mdot
.38922 .68342 Mdot
.3844 .60277 Mdot
.37291 .61214 Mdot
.67196 .45781 Mdot
.6415 .4575 Mdot
.43639 .41022 Mdot
.60777 .62603 Mdot
.38904 .58733 Mdot
.6183 .63384 Mdot
.64254 .48215 Mdot
.65162 .45976 Mdot
.47842 .73122 Mdot
.47647 .44154 Mdot
.63537 .48677 Mdot
.5436 .76421 Mdot
.50197 .65508 Mdot
.31521 .60324 Mdot
.79022 .31515 Mdot
.33951 .76286 Mdot
.54614 .34675 Mdot
.59855 .32457 Mdot
.46273 .77495 Mdot
.63279 .62198 Mdot
.40958 .44497 Mdot
.38457 .40393 Mdot
.48444 .75376 Mdot
.63164 .60179 Mdot
.63303 .3317 Mdot
.63074 .61955 Mdot
.62885 .31241 Mdot
.68065 .5078 Mdot
.41526 .45589 Mdot
.4298 .37005 Mdot
.59794 .60196 Mdot
.67211 .4638 Mdot
.63339 .47121 Mdot
.59893 .33638 Mdot
.52372 .2095 Mdot
.64906 .4868 Mdot
.34309 .58659 Mdot
.29297 .4029 Mdot
.48327 .7606 Mdot
.39704 .39687 Mdot
.50034 .20221 Mdot
.20622 .44248 Mdot
.38825 .43033 Mdot
.46458 .75117 Mdot
.2655 .24065 Mdot
.42957 .45514 Mdot
.22796 .30711 Mdot
.47786 .73437 Mdot
.36393 .6391 Mdot
.67638 .47942 Mdot
.48224 .76634 Mdot
.40231 .49259 Mdot
.63617 .27191 Mdot
.36118 .42864 Mdot
.38779 .60578 Mdot
.36015 .64389 Mdot
.46335 .54427 Mdot
.55638 .80763 Mdot
.6434 .31977 Mdot
.62845 .32862 Mdot
.66014 .48676 Mdot
.64882 .67393 Mdot
.36583 .3782 Mdot
.62748 .3316 Mdot
.79074 .49016 Mdot
.41818 .43637 Mdot
.59706 .25934 Mdot
.60474 .40143 Mdot
.35793 .63681 Mdot
.41266 .5257 Mdot
.66121 .49074 Mdot
.35497 .61135 Mdot
.52113 .48524 Mdot
.42826 .36418 Mdot
.36361 .61134 Mdot
.62511 .61997 Mdot
.69125 .67094 Mdot
.33057 .61977 Mdot
.54601 .5018 Mdot
.61614 .6057 Mdot
.64298 .36265 Mdot
.49758 .28042 Mdot
.86648 .59792 Mdot
.61187 .62149 Mdot
.67272 .47239 Mdot
.63361 .48245 Mdot
.64988 .49172 Mdot
.38633 .59978 Mdot
.66278 .50334 Mdot
.35219 .62319 Mdot
.62108 .54993 Mdot
.55364 .21015 Mdot
.61544 .32929 Mdot
.64187 .56295 Mdot
.36855 .59501 Mdot
.42495 .70941 Mdot
.7381 .26799 Mdot
.42479 .42011 Mdot
.60467 .65781 Mdot
.64747 .33623 Mdot
.49053 .6975 Mdot
.62489 .34063 Mdot
.6758 .47481 Mdot
.45982 .62524 Mdot
.41028 .40542 Mdot
.2874 .65214 Mdot
.61591 .308 Mdot
.38522 .60043 Mdot
.45801 .39925 Mdot
.68475 .51309 Mdot
.6172 .34647 Mdot
.59957 .32429 Mdot
.40875 .39296 Mdot
.3419 .63729 Mdot
.65714 .46055 Mdot
.63494 .6234 Mdot
.65358 .30191 Mdot
.46668 .46161 Mdot
.41063 .42823 Mdot
.44894 .36839 Mdot
.50066 .60846 Mdot
.80521 .40971 Mdot
.61244 .61129 Mdot
.42711 .24899 Mdot
.63626 .47498 Mdot
.45558 .24962 Mdot
.42772 .74665 Mdot
.64318 .55256 Mdot
.4716 .73635 Mdot
.46925 .73825 Mdot
.42187 .39694 Mdot
.81293 .44341 Mdot
.39258 .66778 Mdot
.57373 .63074 Mdot
.47793 .76077 Mdot
.63366 .4702 Mdot
.38091 .56491 Mdot
.45365 .50473 Mdot
.45003 .45186 Mdot
.6284 .58836 Mdot
.64427 .48732 Mdot
.80031 .56774 Mdot
.61804 .3215 Mdot
.47105 .66752 Mdot
.44314 .39248 Mdot
.40823 .39905 Mdot
.60527 .60599 Mdot
.61936 .61652 Mdot
.37806 .70275 Mdot
.46901 .55981 Mdot
.70571 .70538 Mdot
.62836 .66325 Mdot
.80909 .5501 Mdot
.37168 .66334 Mdot
.3473 .59014 Mdot
.48317 .73215 Mdot
.59539 .58687 Mdot
.39706 .38751 Mdot
.36766 .63791 Mdot
.39357 .67767 Mdot
.32026 .6419 Mdot
.5875 .26188 Mdot
.58697 .4501 Mdot
.44392 .38903 Mdot
.36231 .57429 Mdot
.35719 .61182 Mdot
.33998 .57853 Mdot
.46835 .75813 Mdot
.39535 .41643 Mdot
.4173 .4256 Mdot
.43528 .45331 Mdot
.4967 .37812 Mdot
.43075 .39412 Mdot
.43195 .74961 Mdot
.50563 .68497 Mdot
.70315 .40891 Mdot
.37778 .42264 Mdot
.62728 .59893 Mdot
.38838 .44252 Mdot
.61217 .35276 Mdot
.37668 .42358 Mdot
.61435 .25895 Mdot
.60296 .61907 Mdot
.45247 .49355 Mdot
.62285 .43233 Mdot
.4457 .39388 Mdot
.6183 .30111 Mdot
.80646 .41483 Mdot
.45394 .21789 Mdot
.54112 .75039 Mdot
.3426 .58697 Mdot
.69141 .4956 Mdot
.59205 .64809 Mdot
.66119 .46576 Mdot
.39224 .36438 Mdot
.47332 .72781 Mdot
.301 .75742 Mdot
.57067 .44587 Mdot
.39451 .38796 Mdot
.48984 .41823 Mdot
.34618 .63285 Mdot
.66184 .49701 Mdot
.33548 .65814 Mdot
.44843 .40984 Mdot
.63799 .34088 Mdot
.6348 .34784 Mdot
.49176 .5024 Mdot
.78163 .56321 Mdot
.42326 .29552 Mdot
.60677 .60709 Mdot
.65312 .51695 Mdot
.63958 .30294 Mdot
.35598 .68569 Mdot
.58855 .64768 Mdot
.58815 .6056 Mdot
.61248 .64618 Mdot
.43634 .38368 Mdot
.48469 .73792 Mdot
.78677 .52426 Mdot
.4709 .76418 Mdot
.45176 .3983 Mdot
.65691 .44817 Mdot
.48194 .76716 Mdot
.62064 .34286 Mdot
.58499 .60239 Mdot
.63801 .4682 Mdot
.4208 .39082 Mdot
.35996 .60157 Mdot
.43579 .23737 Mdot
.70099 .27747 Mdot
.60406 .49636 Mdot
.60429 .49973 Mdot
.38758 .6288 Mdot
.65204 .78862 Mdot
.62103 .55724 Mdot
.23199 .40124 Mdot
.62819 .28221 Mdot
.38066 .37709 Mdot
.34129 .21501 Mdot
.68325 .47767 Mdot
.64694 .50507 Mdot
.43287 .40058 Mdot
.62041 .48553 Mdot
.41199 .37554 Mdot
.68051 .4646 Mdot
.6204 .77915 Mdot
.46492 .43728 Mdot
.64911 .50489 Mdot
.3723 .36844 Mdot
.45585 .41654 Mdot
.34651 .63475 Mdot
.62617 .49081 Mdot
.37447 .37721 Mdot
.28145 .75284 Mdot
.59038 .61592 Mdot
.47038 .76022 Mdot
.66091 .60645 Mdot
.62383 .63805 Mdot
.36476 .62652 Mdot
.42632 .45693 Mdot
.60859 .32641 Mdot
.35998 .59135 Mdot
.69617 .49305 Mdot
.62373 .30588 Mdot
.48612 .66491 Mdot
.34049 .59224 Mdot
.48666 .75322 Mdot
.60747 .31873 Mdot
.36167 .43116 Mdot
.64236 .49955 Mdot
.75508 .32392 Mdot
.47176 .764 Mdot
.40355 .40849 Mdot
.62589 .51414 Mdot
.63039 .62099 Mdot
.42843 .4112 Mdot
.64348 .51173 Mdot
.46607 .75546 Mdot
.46241 .41887 Mdot
.46316 .41524 Mdot
.47689 .48842 Mdot
.43795 .61931 Mdot
.61307 .33266 Mdot
.33863 .64837 Mdot
.43885 .41473 Mdot
.61314 .35514 Mdot
.70399 .55914 Mdot
.37224 .43212 Mdot
.32916 .59577 Mdot
.51256 .39465 Mdot
.6433 .45474 Mdot
.58578 .62926 Mdot
.6346 .5155 Mdot
.5997 .31923 Mdot
.54767 .15389 Mdot
.48951 .74602 Mdot
.4838 .43419 Mdot
.43032 .36381 Mdot
.63663 .43856 Mdot
.36027 .61496 Mdot
.6858 .71772 Mdot
.37554 .40183 Mdot
.48261 .38816 Mdot
.4022 .39397 Mdot
.76281 .40539 Mdot
.38049 .61626 Mdot
.39898 .39481 Mdot
.49521 .424 Mdot
.35738 .41929 Mdot
.6175 .29977 Mdot
.52305 .26707 Mdot
.38994 .44163 Mdot
.21953 .75706 Mdot
.46227 .73924 Mdot
.64408 .4948 Mdot
.53922 .5452 Mdot
.74076 .48418 Mdot
.22263 .34211 Mdot
.3567 .62357 Mdot
.34493 .34261 Mdot
.65877 .46259 Mdot
.42626 .2244 Mdot
.61205 .81501 Mdot
.45654 .41308 Mdot
.39535 .37924 Mdot
.67577 .47482 Mdot
.6261 .46529 Mdot
.46897 .73208 Mdot
.36983 .4027 Mdot
.48359 .39451 Mdot
.61997 .4694 Mdot
.42545 .38691 Mdot
.20999 .54729 Mdot
.62769 .64372 Mdot
.33288 .60547 Mdot
.58655 .6275 Mdot
.59207 .60232 Mdot
.27619 .33764 Mdot
.4849 .6204 Mdot
.62234 .61773 Mdot
.573 .60458 Mdot
.62592 .25414 Mdot
.51701 .40911 Mdot
.62879 .29943 Mdot
.75847 .62055 Mdot
.6558 .48849 Mdot
.39407 .41737 Mdot
.38185 .58867 Mdot
.23327 .36589 Mdot
.67031 .69183 Mdot
.45729 .64493 Mdot
.42427 .42257 Mdot
.65779 .49579 Mdot
.46589 .75771 Mdot
.46095 .44277 Mdot
.44316 .25309 Mdot
.41296 .40083 Mdot
.63602 .45907 Mdot
.28782 .32802 Mdot
.29814 .65144 Mdot
.62265 .66421 Mdot
.33369 .57022 Mdot
.39654 .44928 Mdot
.34073 .60545 Mdot
.62457 .59518 Mdot
.61985 .35834 Mdot
.62105 .33604 Mdot
.44467 .38486 Mdot
.45382 .54897 Mdot
.66705 .30618 Mdot
.45494 .41551 Mdot
.44579 .43609 Mdot
.47448 .73576 Mdot
.44698 .43563 Mdot
.4154 .36366 Mdot
.40181 .44715 Mdot
.36612 .41172 Mdot
.58378 .60187 Mdot
.31191 .56477 Mdot
.37862 .43216 Mdot
.3922 .47555 Mdot
.64096 .60672 Mdot
.35578 .46501 Mdot
.59786 .63116 Mdot
.74484 .67205 Mdot
.60736 .63404 Mdot
.61965 .33477 Mdot
.64562 .5269 Mdot
.33316 .35952 Mdot
.38967 .58938 Mdot
.62219 .58527 Mdot
.62813 .31703 Mdot
.60887 .62266 Mdot
.66783 .51512 Mdot
.77114 .31044 Mdot
.35722 .65223 Mdot
.51953 .59474 Mdot
.53426 .35148 Mdot
.39775 .70183 Mdot
.64978 .45353 Mdot
.36875 .63083 Mdot
.30059 .66222 Mdot
.41125 .4477 Mdot
.60865 .33262 Mdot
.41991 .3972 Mdot
.58233 .6078 Mdot
.65617 .49358 Mdot
.60395 .53684 Mdot
.61343 .33418 Mdot
.61967 .19006 Mdot
.66827 .44858 Mdot
.4429 .46705 Mdot
.64199 .60877 Mdot
.77575 .30295 Mdot
.60348 .63464 Mdot
.54772 .20811 Mdot
.39896 .56164 Mdot
.29724 .31053 Mdot
.3738 .60545 Mdot
.35171 .69695 Mdot
.70713 .76781 Mdot
.61736 .80352 Mdot
.35464 .59338 Mdot
.61123 .43975 Mdot
.43528 .38947 Mdot
.4012 .43952 Mdot
.36343 .44811 Mdot
.31622 .59456 Mdot
.44231 .40966 Mdot
.48735 .75931 Mdot
.49155 .62125 Mdot
.79224 .44629 Mdot
.67991 .5132 Mdot
.41296 .37412 Mdot
.60979 .58889 Mdot
.57805 .62013 Mdot
.47769 .76751 Mdot
.6169 .64774 Mdot
.45263 .42331 Mdot
.37068 .59755 Mdot
.57433 .42904 Mdot
.63325 .34166 Mdot
.48466 .80208 Mdot
.63759 .29119 Mdot
.64045 .54172 Mdot
.37817 .4648 Mdot
.6514 .4593 Mdot
.44475 .15882 Mdot
.40897 .44241 Mdot
.35549 .60567 Mdot
.45464 .39594 Mdot
.40111 .44826 Mdot
.38447 .43409 Mdot
.64639 .51417 Mdot
.53826 .55127 Mdot
.42251 .38616 Mdot
.62626 .60656 Mdot
.60886 .42994 Mdot
.42488 .45974 Mdot
.76153 .50959 Mdot
.57582 .26915 Mdot
.4083 .70174 Mdot
.3198 .59148 Mdot
.67014 .4791 Mdot
.36957 .61121 Mdot
.32514 .57304 Mdot
.36453 .62666 Mdot
.77294 .49888 Mdot
.36616 .30206 Mdot
.20605 .33468 Mdot
.30846 .4835 Mdot
.23874 .37275 Mdot
.37797 .64129 Mdot
.71722 .57295 Mdot
.34782 .59373 Mdot
.35993 .62577 Mdot
.12039 .41715 Mdot
.35617 .58134 Mdot
.39026 .40093 Mdot
.47102 .41738 Mdot
.40756 .78609 Mdot
.61771 .25021 Mdot
.3777 .42408 Mdot
.43989 .41041 Mdot
.64498 .33279 Mdot
.50251 .41852 Mdot
.46693 .76681 Mdot
.47389 .64632 Mdot
.45246 .7352 Mdot
.4098 .39317 Mdot
.43788 .40325 Mdot
.44697 .36333 Mdot
.70678 .77297 Mdot
.22755 .36362 Mdot
.36999 .64004 Mdot
.39005 .49788 Mdot
.52444 .79797 Mdot
.44629 .37478 Mdot
.45074 .38163 Mdot
.44965 .44356 Mdot
.66089 .46385 Mdot
.38682 .56843 Mdot
.47008 .37061 Mdot
.39474 .73884 Mdot
.44299 .39463 Mdot
.66093 .53906 Mdot
.61846 .38313 Mdot
.39678 .40293 Mdot
.33339 .59053 Mdot
.41351 .43381 Mdot
.35093 .5776 Mdot
.33402 .60422 Mdot
.48072 .43521 Mdot
.78604 .53528 Mdot
.37003 .55885 Mdot
.45892 .40925 Mdot
.67052 .46513 Mdot
.57149 .81818 Mdot
.40124 .40822 Mdot
.64235 .32121 Mdot
.39037 .42619 Mdot
.61259 .30282 Mdot
.45316 .43571 Mdot
.46777 .76178 Mdot
.23505 .45107 Mdot
.66207 .47927 Mdot
.65127 .29688 Mdot
.6229 .46669 Mdot
.51133 .46314 Mdot
.33409 .6351 Mdot
.463 .76361 Mdot
.19889 .39261 Mdot
.47573 .73564 Mdot
.40919 .25021 Mdot
.66961 .66625 Mdot
.5956 .6013 Mdot
.35037 .5731 Mdot
.35061 .3004 Mdot
.76672 .54319 Mdot
.67497 .44363 Mdot
.67592 .44626 Mdot
.47299 .1653 Mdot
.31673 .21249 Mdot
.41819 .38375 Mdot
.80284 .3746 Mdot
.24489 .50995 Mdot
.3567 .39984 Mdot
.36932 .35786 Mdot
.64545 .44837 Mdot
.39623 .45009 Mdot
.5386 .50089 Mdot
.64569 .47645 Mdot
.62716 .32113 Mdot
.34618 .62224 Mdot
.60161 .32707 Mdot
.71682 .67445 Mdot
.50913 .66925 Mdot
.63784 .47968 Mdot
.36899 .42329 Mdot
.42288 .37793 Mdot
.36035 .57115 Mdot
.28205 .66024 Mdot
.33406 .61514 Mdot
.64044 .30998 Mdot
.65402 .4743 Mdot
.21768 .39364 Mdot
.38436 .42057 Mdot
.36944 .58864 Mdot
.65143 .42748 Mdot
.40603 .42505 Mdot
.60322 .59699 Mdot
.42431 .42325 Mdot
.35808 .5845 Mdot
.44752 .43581 Mdot
.37096 .59988 Mdot
.67808 .46653 Mdot
.41455 .36816 Mdot
.43663 .40492 Mdot
.38763 .25272 Mdot
.63363 .33219 Mdot
.33945 .63973 Mdot
.53525 .50766 Mdot
.43163 .36689 Mdot
.44419 .25491 Mdot
.42046 .45622 Mdot
.34431 .36343 Mdot
.40449 .3476 Mdot
.48842 .75494 Mdot
.4073 .35817 Mdot
.40245 .40743 Mdot
.27777 .60339 Mdot
.31712 .52573 Mdot
.42775 .5186 Mdot
.62175 .58301 Mdot
.33266 .59316 Mdot
.63328 .4872 Mdot
.62749 .47482 Mdot
.66894 .49928 Mdot
.60351 .24152 Mdot
.46449 .46501 Mdot
.41105 .40686 Mdot
.63999 .62548 Mdot
.62599 .32887 Mdot
.38115 .59475 Mdot
.62018 .32956 Mdot
.47285 .64168 Mdot
.63356 .30548 Mdot
.48933 .75708 Mdot
.76718 .40472 Mdot
.19168 .51623 Mdot
.63591 .31132 Mdot
.33348 .61294 Mdot
.58381 .4634 Mdot
.37811 .3785 Mdot
.56843 .77158 Mdot
.63872 .34026 Mdot
.50335 .1672 Mdot
.46583 .42072 Mdot
.53913 .51264 Mdot
.59433 .62704 Mdot
.60272 .32376 Mdot
.60923 .64861 Mdot
.41117 .43649 Mdot
.32668 .72199 Mdot
.35185 .60802 Mdot
.61909 .654 Mdot
.38938 .36184 Mdot
.60194 .32643 Mdot
.63694 .48454 Mdot
.49888 .33966 Mdot
.63211 .59715 Mdot
.43695 .23049 Mdot
.45671 .24482 Mdot
.6521 .47394 Mdot
.17091 .52723 Mdot
.60251 .644 Mdot
.36343 .41571 Mdot
.37448 .30907 Mdot
.42075 .42957 Mdot
.63053 .47842 Mdot
.6524 .50754 Mdot
.45186 .79453 Mdot
.44401 .38614 Mdot
.46311 .4341 Mdot
.3963 .59448 Mdot
.64131 .47135 Mdot
.37051 .62596 Mdot
.37262 .56789 Mdot
.67488 .4714 Mdot
.35726 .63262 Mdot
.61459 .30835 Mdot
.48393 .61033 Mdot
.60339 .64312 Mdot
.61734 .595 Mdot
.63515 .48492 Mdot
.66689 .51822 Mdot
.64894 .4597 Mdot
.43077 .42252 Mdot
.38197 .62105 Mdot
.42916 .44043 Mdot
.38739 .44076 Mdot
.40863 .57803 Mdot
.38986 .61717 Mdot
.42318 .4382 Mdot
.61681 .40753 Mdot
.59213 .32582 Mdot
.65064 .50479 Mdot
.62016 .63102 Mdot
.3789 .25076 Mdot
.62464 .64797 Mdot
.44775 .38199 Mdot
.58868 .77082 Mdot
.3862 .60177 Mdot
.6231 .34106 Mdot
.62891 .37057 Mdot
.61533 .33778 Mdot
.61889 .65424 Mdot
.36535 .56599 Mdot
.48822 .66412 Mdot
.43706 .37566 Mdot
.49961 .60828 Mdot
.3994 .26127 Mdot
.42122 .74589 Mdot
.62385 .62052 Mdot
.427 .41873 Mdot
.47811 .73544 Mdot
.20211 .46673 Mdot
.4182 .4041 Mdot
.40072 .36088 Mdot
.71628 .35946 Mdot
.39165 .47503 Mdot
.31507 .62218 Mdot
.46607 .5264 Mdot
.40073 .37055 Mdot
.44612 .51022 Mdot
.19598 .30424 Mdot
.46546 .41818 Mdot
.44218 .40082 Mdot
.38686 .41096 Mdot
.41283 .44412 Mdot
.32484 .60027 Mdot
.69952 .32448 Mdot
.61454 .58646 Mdot
.4859 .60684 Mdot
.61035 .64519 Mdot
.6414 .50341 Mdot
.54218 .48104 Mdot
.34174 .57968 Mdot
.61567 .33871 Mdot
.79808 .34342 Mdot
.46854 .61552 Mdot
.67023 .45687 Mdot
.24895 .32678 Mdot
.63344 .34368 Mdot
.3784 .37973 Mdot
.59576 .33164 Mdot
.63113 .45377 Mdot
.62213 .60438 Mdot
.4572 .38291 Mdot
.38872 .59861 Mdot
.32965 .61569 Mdot
.43266 .4183 Mdot
.53223 .8172 Mdot
.62707 .63272 Mdot
.7158 .48762 Mdot
.4394 .38553 Mdot
.40058 .36127 Mdot
.33918 .62083 Mdot
.66007 .49805 Mdot
.66581 .66031 Mdot
.63459 .32341 Mdot
.38039 .36518 Mdot
.40997 .43564 Mdot
.47772 .63114 Mdot
.59892 .58573 Mdot
.47307 .75342 Mdot
.44209 .38623 Mdot
.48618 .62467 Mdot
.44946 .39177 Mdot
.47768 .36289 Mdot
.66089 .45889 Mdot
.46488 .44923 Mdot
.38606 .3836 Mdot
.33709 .47005 Mdot
.59913 .64409 Mdot
.35951 .61032 Mdot
.40319 .57517 Mdot
.46397 .74654 Mdot
.59575 .60729 Mdot
.4231 .43534 Mdot
.5822 .61642 Mdot
.3904 .43697 Mdot
.42311 .38902 Mdot
.6242 .62019 Mdot
.36897 .62765 Mdot
.68655 .70934 Mdot
.2973 .58761 Mdot
.42841 .44976 Mdot
.39542 .43021 Mdot
.60513 .24817 Mdot
.16944 .47073 Mdot
.38109 .38809 Mdot
.38615 .61631 Mdot
.40809 .4236 Mdot
.61776 .59193 Mdot
.63863 .30784 Mdot
.35615 .60061 Mdot
.67286 .51484 Mdot
.68142 .47412 Mdot
.62783 .42818 Mdot
.49004 .75058 Mdot
.3738 .39477 Mdot
.34474 .65188 Mdot
.39117 .61854 Mdot
.4931 .70752 Mdot
.64396 .49593 Mdot
.62753 .30172 Mdot
.453 .44352 Mdot
.48669 .3296 Mdot
.59849 .59374 Mdot
.22628 .76228 Mdot
.49108 .66894 Mdot
.61618 .29613 Mdot
.44228 .57556 Mdot
.48171 .74063 Mdot
.39597 .38411 Mdot
.60838 .35046 Mdot
.6768 .49815 Mdot
.40486 .43935 Mdot
.40863 .4859 Mdot
.76273 .55675 Mdot
.68566 .50182 Mdot
.58331 .62353 Mdot
.67882 .50117 Mdot
.6046 .3064 Mdot
.48835 .75921 Mdot
.33977 .63402 Mdot
.40357 .40366 Mdot
.36011 .48209 Mdot
.64988 .49507 Mdot
.46238 .75599 Mdot
.44655 .39092 Mdot
.32941 .60092 Mdot
.65887 .50512 Mdot
.40645 .38982 Mdot
.22413 .41459 Mdot
.4129 .58784 Mdot
.65522 .48221 Mdot
.44088 .36631 Mdot
.51917 .43472 Mdot
.68778 .48834 Mdot
.65128 .4463 Mdot
.44208 .40919 Mdot
.60852 .31545 Mdot
.40945 .37151 Mdot
.60414 .63092 Mdot
.5385 .55104 Mdot
.60175 .60041 Mdot
.42528 .25243 Mdot
.47409 .40906 Mdot
.39934 .68194 Mdot
.37229 .57624 Mdot
.62025 .36662 Mdot
.2764 .5927 Mdot
.39779 .36464 Mdot
.72824 .70519 Mdot
.57868 .45041 Mdot
.51294 .701 Mdot
.80828 .62596 Mdot
.63532 .31596 Mdot
.60446 .62411 Mdot
.44296 .40208 Mdot
.62358 .57081 Mdot
.62449 .31087 Mdot
.41996 .25315 Mdot
.43247 .36391 Mdot
.3797 .61515 Mdot
.43921 .39077 Mdot
.34336 .58561 Mdot
.39918 .42668 Mdot
.42659 .49073 Mdot
.60116 .29529 Mdot
.54351 .20708 Mdot
.37427 .3854 Mdot
.80063 .33944 Mdot
.52818 .38309 Mdot
.64069 .33215 Mdot
.43769 .44607 Mdot
.48052 .75169 Mdot
.63089 .61555 Mdot
.78248 .37179 Mdot
.65529 .46078 Mdot
.61876 .62289 Mdot
.34446 .62505 Mdot
.62908 .51429 Mdot
.46239 .74626 Mdot
.35585 .31485 Mdot
.60129 .33078 Mdot
.59175 .61345 Mdot
.40019 .40589 Mdot
.45123 .38465 Mdot
.76377 .39691 Mdot
.18015 .59112 Mdot
.39035 .58345 Mdot
.5807 .18277 Mdot
.33178 .64409 Mdot
.63056 .33083 Mdot
.65754 .45776 Mdot
.38791 .3932 Mdot
.42634 .40471 Mdot
.63135 .49232 Mdot
.38113 .62673 Mdot
.61168 .48726 Mdot
.26811 .32938 Mdot
.55884 .63545 Mdot
.53866 .23682 Mdot
.3529 .59844 Mdot
.53746 .23363 Mdot
.61435 .29816 Mdot
.79247 .57289 Mdot
.53259 .31616 Mdot
.58885 .61123 Mdot
.53906 .2405 Mdot
.37862 .5905 Mdot
.41483 .38268 Mdot
.48591 .75441 Mdot
.47464 .73187 Mdot
.3398 .61117 Mdot
.67428 .47645 Mdot
.6042 .33395 Mdot
.43721 .39614 Mdot
.43463 .69332 Mdot
.36476 .77923 Mdot
.65051 .51719 Mdot
.49402 .40349 Mdot
.6218 .63915 Mdot
.40437 .42796 Mdot
.64162 .34125 Mdot
.61587 .61421 Mdot
.49307 .75602 Mdot
.47875 .60034 Mdot
.45194 .44475 Mdot
.49502 .49534 Mdot
.59378 .61626 Mdot
.16198 .48886 Mdot
.43435 .40582 Mdot
.60227 .64408 Mdot
.33829 .39996 Mdot
.34687 .72597 Mdot
.59465 .4105 Mdot
.63691 .79295 Mdot
.69194 .46766 Mdot
.68168 .47876 Mdot
.24928 .70238 Mdot
.62667 .28175 Mdot
.62239 .58718 Mdot
.48499 .76379 Mdot
.52655 .28419 Mdot
.60099 .64803 Mdot
.46073 .39298 Mdot
.42661 .45602 Mdot
.26972 .34134 Mdot
.53668 .40951 Mdot
.45867 .74369 Mdot
.38331 .32141 Mdot
.44337 .4291 Mdot
.37031 .44379 Mdot
.42433 .41455 Mdot
.36161 .64348 Mdot
.59611 .64729 Mdot
.84954 .3933 Mdot
.58279 .63484 Mdot
.44408 .68402 Mdot
.65593 .48892 Mdot
.6409 .51617 Mdot
.39741 .40168 Mdot
.40272 .66029 Mdot
.81417 .42156 Mdot
.38304 .42361 Mdot
.63278 .37149 Mdot
.45596 .24261 Mdot
.41364 .46066 Mdot
.3958 .57474 Mdot
.48169 .38353 Mdot
.32189 .62454 Mdot
.61814 .61135 Mdot
.63414 .31439 Mdot
.59015 .33025 Mdot
.59935 .62648 Mdot
.41249 .40885 Mdot
.60976 .37504 Mdot
.40545 .39795 Mdot
.42312 .38022 Mdot
.47025 .65543 Mdot
.65086 .32831 Mdot
.64722 .4593 Mdot
.61875 .33613 Mdot
.36191 .62428 Mdot
.09738 .46387 Mdot
.61506 .32389 Mdot
.51776 .40331 Mdot
.55329 .48187 Mdot
.53582 .23958 Mdot
.33074 .61826 Mdot
.6437 .31801 Mdot
.58733 .63533 Mdot
.50896 .70606 Mdot
.17276 .5092 Mdot
.61307 .65519 Mdot
.42911 .40269 Mdot
.34409 .57872 Mdot
.38503 .63124 Mdot
.58773 .65052 Mdot
.35695 .63755 Mdot
.39994 .46769 Mdot
.45994 .40584 Mdot
.62095 .58708 Mdot
.4057 .79475 Mdot
.59452 .64649 Mdot
.50291 .34774 Mdot
.45774 .43408 Mdot
.35598 .60324 Mdot
.37077 .34256 Mdot
.3764 .65824 Mdot
.4769 .72997 Mdot
.37862 .429 Mdot
.61145 .33852 Mdot
.50667 .57343 Mdot
.65644 .48272 Mdot
.59482 .76915 Mdot
.34072 .5877 Mdot
.61933 .65942 Mdot
.34465 .63383 Mdot
.39278 .60342 Mdot
.60422 .65379 Mdot
.35676 .61817 Mdot
.44084 .3991 Mdot
.53699 .63969 Mdot
.34587 .5866 Mdot
.60284 .60971 Mdot
.61029 .34102 Mdot
.36189 .6319 Mdot
.61268 .46692 Mdot
.4159 .37866 Mdot
.6484 .45193 Mdot
.65402 .32647 Mdot
.34365 .57759 Mdot
.64106 .31301 Mdot
.64736 .49648 Mdot
.60417 .33949 Mdot
.6069 .55593 Mdot
.63863 .58031 Mdot
.45338 .65363 Mdot
.29379 .63203 Mdot
.38291 .58838 Mdot
.6852 .45135 Mdot
.38525 .38921 Mdot
.43391 .37943 Mdot
.59734 .32309 Mdot
.3865 .63127 Mdot
.56747 .81581 Mdot
.35208 .34812 Mdot
.4631 .79024 Mdot
.60753 .58029 Mdot
.5024 .18518 Mdot
.49551 .67853 Mdot
.52366 .71473 Mdot
.37522 .35892 Mdot
.48283 .7424 Mdot
.40139 .39372 Mdot
.4549 .21696 Mdot
.64045 .30784 Mdot
.69524 .62454 Mdot
.36447 .38038 Mdot
.64828 .46691 Mdot
.39108 .42287 Mdot
.79838 .37175 Mdot
.44743 .34642 Mdot
.64513 .32749 Mdot
.6407 .59626 Mdot
.38961 .58911 Mdot
.634 .34172 Mdot
.68048 .46851 Mdot
.55236 .26797 Mdot
.45372 .37349 Mdot
.44814 .42564 Mdot
.66768 .44105 Mdot
.37642 .62296 Mdot
.64179 .50186 Mdot
.6036 .64339 Mdot
.61776 .32578 Mdot
.41519 .44593 Mdot
.41908 .46484 Mdot
.63885 .43982 Mdot
.57958 .62616 Mdot
.65638 .51952 Mdot
.58355 .61178 Mdot
.48427 .74469 Mdot
.3727 .39447 Mdot
.64796 .43927 Mdot
.35392 .38565 Mdot
.32697 .50415 Mdot
.46642 .64408 Mdot
.27855 .56923 Mdot
.64607 .45906 Mdot
.57313 .25104 Mdot
.59993 .62007 Mdot
.58915 .62813 Mdot
.30349 .32017 Mdot
.81252 .43134 Mdot
.5857 .471 Mdot
.76263 .30617 Mdot
.60407 .64307 Mdot
.59849 .60808 Mdot
.67595 .49683 Mdot
.35195 .62079 Mdot
.37163 .55326 Mdot
.61699 .47366 Mdot
.49986 .20261 Mdot
.38073 .59422 Mdot
.70779 .73354 Mdot
.68283 .4614 Mdot
.39866 .34996 Mdot
.45782 .7373 Mdot
.64282 .33417 Mdot
.46418 .2175 Mdot
.77184 .32296 Mdot
.39212 .39301 Mdot
.2606 .27839 Mdot
.6681 .47688 Mdot
.5955 .67884 Mdot
.76827 .61905 Mdot
.41934 .36074 Mdot
.39072 .41959 Mdot
.413 .4126 Mdot
.64279 .34962 Mdot
.29615 .57667 Mdot
.39314 .3908 Mdot
.55536 .21304 Mdot
.46944 .43048 Mdot
.75815 .33486 Mdot
.61867 .33573 Mdot
.41694 .27895 Mdot
.69499 .47153 Mdot
.40763 .73258 Mdot
.36525 .44793 Mdot
.60168 .64013 Mdot
.74171 .6187 Mdot
.62616 .61298 Mdot
.80805 .51136 Mdot
.53014 .31355 Mdot
.3628 .64395 Mdot
.42564 .42244 Mdot
.6685 .4436 Mdot
.34677 .57766 Mdot
.66945 .66036 Mdot
.11739 .41543 Mdot
.58188 .60318 Mdot
.3718 .16163 Mdot
.58696 .62358 Mdot
.47162 .73202 Mdot
.33873 .616 Mdot
.4205 .54024 Mdot
.49852 .6051 Mdot
.36894 .62655 Mdot
.70607 .42775 Mdot
.40035 .57521 Mdot
.55941 .23887 Mdot
.39062 .63634 Mdot
.60443 .61443 Mdot
.64434 .59946 Mdot
.36479 .46771 Mdot
.38137 .38999 Mdot
.49636 .62247 Mdot
.34451 .40116 Mdot
.37498 .40699 Mdot
.64572 .47628 Mdot
.31127 .68709 Mdot
.59361 .67184 Mdot
.34572 .59873 Mdot
.59879 .59061 Mdot
.38981 .42007 Mdot
.42974 .44935 Mdot
.35726 .41029 Mdot
.4279 .23042 Mdot
.71064 .72826 Mdot
.42074 .38685 Mdot
.48275 .4126 Mdot
.67132 .45971 Mdot
.7643 .37631 Mdot
.64953 .22913 Mdot
.53198 .29223 Mdot
.44593 .38457 Mdot
.63008 .33569 Mdot
.64749 .32009 Mdot
.42768 .46907 Mdot
.41813 .68004 Mdot
.60555 .48312 Mdot
.40008 .40616 Mdot
.55399 .33387 Mdot
.62514 .44196 Mdot
.46722 .76232 Mdot
.64931 .49473 Mdot
.33958 .5798 Mdot
.47371 .73445 Mdot
.64711 .51281 Mdot
.41916 .59115 Mdot
.46471 .74671 Mdot
.36162 .73168 Mdot
.64078 .3103 Mdot
.42782 .41128 Mdot
.33856 .66307 Mdot
.6318 .49088 Mdot
.59144 .61758 Mdot
.36535 .59847 Mdot
.61071 .57679 Mdot
.76705 .37861 Mdot
.4758 .21818 Mdot
.4892 .74568 Mdot
.60314 .63814 Mdot
.47459 .54434 Mdot
.62717 .33654 Mdot
.61109 .65203 Mdot
.39097 .67679 Mdot
.41843 .45913 Mdot
.82686 .49711 Mdot
.44725 .42138 Mdot
.50584 .81847 Mdot
.59119 .62963 Mdot
.48378 .73074 Mdot
.40586 .40296 Mdot
.66998 .45012 Mdot
.34955 .45299 Mdot
.40752 .3974 Mdot
.67909 .50404 Mdot
.41703 .38406 Mdot
.63455 .35158 Mdot
.32006 .60832 Mdot
.57791 .44507 Mdot
.44126 .20471 Mdot
.61077 .34613 Mdot
.48437 .77784 Mdot
.3757 .39585 Mdot
.67178 .37046 Mdot
.37346 .6199 Mdot
.40715 .36082 Mdot
.29685 .28354 Mdot
.34437 .61375 Mdot
.37096 .61131 Mdot
.44101 .43798 Mdot
.61588 .65414 Mdot
.634 .47164 Mdot
.6245 .33769 Mdot
.65134 .67537 Mdot
.4054 .38828 Mdot
.42975 .41698 Mdot
.63283 .34374 Mdot
.59934 .60462 Mdot
.41816 .44493 Mdot
.63072 .72374 Mdot
.48429 .69716 Mdot
.59311 .60063 Mdot
.41667 .45961 Mdot
.84267 .51603 Mdot
.36026 .55404 Mdot
.24235 .2931 Mdot
.63249 .28332 Mdot
.67184 .47038 Mdot
.48518 .43563 Mdot
.18521 .71946 Mdot
.64265 .32902 Mdot
.41996 .73534 Mdot
.42658 .38474 Mdot
.37902 .40651 Mdot
.3389 .63708 Mdot
.42831 .43655 Mdot
.3576 .58272 Mdot
.44782 .19839 Mdot
.78615 .29832 Mdot
.34779 .63427 Mdot
.35146 .58329 Mdot
.40782 .52936 Mdot
.41652 .23928 Mdot
.34656 .62428 Mdot
.45265 .3718 Mdot
.70631 .41769 Mdot
.45277 .47062 Mdot
.63591 .29505 Mdot
.61134 .36641 Mdot
.39994 .61004 Mdot
.20607 .60608 Mdot
.33802 .43364 Mdot
.46446 .49049 Mdot
.6661 .31292 Mdot
.61134 .63318 Mdot
.42512 .45411 Mdot
.4903 .75462 Mdot
.66347 .50575 Mdot
.47255 .36605 Mdot
.42553 .40949 Mdot
.34764 .58075 Mdot
.63924 .35452 Mdot
.6109 .65023 Mdot
.43967 .40912 Mdot
.63735 .53213 Mdot
.63039 .32092 Mdot
.34657 .58739 Mdot
.51751 .399 Mdot
.62828 .29813 Mdot
.39828 .46328 Mdot
.37591 .40808 Mdot
.44783 .39173 Mdot
.35989 .44393 Mdot
.59739 .6267 Mdot
.61837 .49442 Mdot
.45184 .46558 Mdot
.4789 .64586 Mdot
.51715 .55983 Mdot
.45111 .46495 Mdot
.38272 .62152 Mdot
.62413 .58642 Mdot
.46753 .74895 Mdot
.52849 .2582 Mdot
.46384 .42388 Mdot
.72016 .71537 Mdot
.24469 .33975 Mdot
.47066 .7426 Mdot
.35578 .64888 Mdot
.61973 .33997 Mdot
.45053 .42958 Mdot
.65729 .39092 Mdot
.46032 .39874 Mdot
.49211 .3582 Mdot
.66999 .47259 Mdot
.61468 .6348 Mdot
.47649 .70264 Mdot
.66308 .50649 Mdot
.37002 .6113 Mdot
.5451 .83968 Mdot
.38998 .55939 Mdot
.3838 .57249 Mdot
.79021 .53341 Mdot
.62077 .61254 Mdot
.2069 .74395 Mdot
.16769 .47216 Mdot
.46474 .4074 Mdot
.62335 .59653 Mdot
.33653 .60814 Mdot
.43735 .42122 Mdot
.38195 .58972 Mdot
.37677 .56108 Mdot
.38768 .44291 Mdot
.37808 .39949 Mdot
.53163 .20694 Mdot
.70106 .75172 Mdot
.6087 .33093 Mdot
.36522 .63856 Mdot
.25514 .36072 Mdot
.39296 .38909 Mdot
.43556 .37489 Mdot
.75918 .58221 Mdot
.64429 .32321 Mdot
.21181 .53348 Mdot
.43533 .38259 Mdot
.30236 .27879 Mdot
.37399 .41041 Mdot
.30433 .61429 Mdot
.59988 .66104 Mdot
.42015 .68625 Mdot
.63098 .47538 Mdot
.33901 .57564 Mdot
.60875 .30685 Mdot
.33749 .57515 Mdot
.29595 .3288 Mdot
.62062 .60874 Mdot
.35819 .58441 Mdot
.64659 .52436 Mdot
.61185 .60138 Mdot
.58804 .61157 Mdot
.60431 .43756 Mdot
.63291 .5165 Mdot
.63733 .35316 Mdot
.62785 .62182 Mdot
.23542 .39705 Mdot
.60777 .61341 Mdot
.26389 .35587 Mdot
.40201 .37178 Mdot
.54284 .21754 Mdot
.46549 .69527 Mdot
.36002 .45332 Mdot
.60065 .65023 Mdot
.61131 .31803 Mdot
.42333 .43126 Mdot
.36051 .63718 Mdot
.616 .31987 Mdot
.57812 .59123 Mdot
.65992 .52302 Mdot
.39449 .61759 Mdot
.64162 .61489 Mdot
.36513 .58206 Mdot
.45576 .23084 Mdot
.63646 .54493 Mdot
.61001 .39552 Mdot
.50337 .60076 Mdot
.36124 .41193 Mdot
.44182 .5118 Mdot
.43625 .36753 Mdot
.42226 .40657 Mdot
.65501 .48321 Mdot
.60132 .24105 Mdot
.36378 .63179 Mdot
.42264 .82063 Mdot
.59827 .63605 Mdot
.46314 .53109 Mdot
.46695 .32947 Mdot
.39288 .43665 Mdot
.3439 .59332 Mdot
.37816 .56407 Mdot
.31655 .52647 Mdot
.63146 .4944 Mdot
.42775 .4794 Mdot
.38383 .46893 Mdot
.46309 .46725 Mdot
.58618 .61932 Mdot
.65139 .71481 Mdot
.63484 .50808 Mdot
.28599 .21599 Mdot
.65096 .50538 Mdot
.69214 .35377 Mdot
.35572 .61776 Mdot
.62655 .30351 Mdot
.4297 .3726 Mdot
.33896 .54417 Mdot
.32351 .61147 Mdot
.6098 .44736 Mdot
.61951 .34221 Mdot
.67236 .71111 Mdot
.62071 .61809 Mdot
.41015 .36605 Mdot
.39059 .4463 Mdot
.43165 .44297 Mdot
.45282 .40763 Mdot
.6117 .5845 Mdot
.45951 .39117 Mdot
.62174 .57846 Mdot
.20874 .43632 Mdot
.30437 .28255 Mdot
.6556 .44343 Mdot
.75773 .34412 Mdot
.39165 .60829 Mdot
.25855 .38696 Mdot
.20688 .53746 Mdot
.46536 .64759 Mdot
.6039 .54332 Mdot
.38928 .3777 Mdot
.67494 .4787 Mdot
.80542 .37834 Mdot
.65704 .4417 Mdot
.81433 .30936 Mdot
.3625 .29772 Mdot
.62204 .80703 Mdot
.44378 .41976 Mdot
.61641 .47061 Mdot
.22788 .59851 Mdot
.4327 .46395 Mdot
.60209 .36671 Mdot
.49124 .34206 Mdot
.40362 .77557 Mdot
.628 .30115 Mdot
.4128 .38001 Mdot
.39481 .60421 Mdot
.4405 .39789 Mdot
.41957 .37253 Mdot
.38435 .42382 Mdot
.57431 .62183 Mdot
.40304 .45448 Mdot
.41039 .37138 Mdot
.16797 .56821 Mdot
.59239 .2608 Mdot
.67033 .45523 Mdot
.29619 .54272 Mdot
.62593 .32847 Mdot
.35039 .57646 Mdot
.5719 .46052 Mdot
.60904 .62918 Mdot
.3202 .51619 Mdot
.44517 .42046 Mdot
.43948 .76274 Mdot
.63277 .63941 Mdot
.62393 .31366 Mdot
.4654 .75099 Mdot
.72323 .68492 Mdot
.63305 .45895 Mdot
.46668 .73325 Mdot
.65739 .4825 Mdot
.25363 .61135 Mdot
.34575 .58384 Mdot
.36119 .41833 Mdot
.61617 .64368 Mdot
.6481 .44823 Mdot
.63144 .24705 Mdot
.41267 .41758 Mdot
.64446 .45963 Mdot
.36238 .41508 Mdot
.52059 .56331 Mdot
.55706 .48669 Mdot
.62732 .45722 Mdot
.6441 .60059 Mdot
.61179 .59836 Mdot
.618 .30655 Mdot
.35563 .57365 Mdot
.38665 .60971 Mdot
.61491 .61027 Mdot
.28574 .23434 Mdot
.40371 .38905 Mdot
.3765 .41339 Mdot
.48234 .65163 Mdot
.44623 .41458 Mdot
.56645 .26654 Mdot
.47406 .77056 Mdot
.38108 .58415 Mdot
.45024 .40765 Mdot
.4187 .44549 Mdot
.44854 .44674 Mdot
.47718 .21993 Mdot
.65176 .49724 Mdot
.44444 .42943 Mdot
.60207 .3422 Mdot
.37314 .70228 Mdot
.38908 .38572 Mdot
.40614 .46324 Mdot
.364 .5835 Mdot
.53379 .17758 Mdot
.59122 .62434 Mdot
.63928 .47141 Mdot
.68415 .46385 Mdot
.45558 .26674 Mdot
.32415 .58354 Mdot
.46278 .76193 Mdot
.74161 .50528 Mdot
.4768 .76424 Mdot
.63931 .33293 Mdot
.61396 .41338 Mdot
.63786 .5346 Mdot
.6814 .46657 Mdot
.63713 .57984 Mdot
.45009 .40358 Mdot
.37442 .41058 Mdot
.42066 .73029 Mdot
.38126 .42697 Mdot
.6145 .34243 Mdot
.64041 .61439 Mdot
.36359 .58471 Mdot
.63682 .34651 Mdot
.58945 .63221 Mdot
.37689 .62312 Mdot
.4355 .45907 Mdot
.35641 .41902 Mdot
.36904 .60238 Mdot
.33489 .59509 Mdot
.39114 .40505 Mdot
.21862 .64838 Mdot
.38495 .58583 Mdot
.35403 .59093 Mdot
.47518 .72283 Mdot
.63402 .45669 Mdot
.40473 .33299 Mdot
.62351 .5992 Mdot
.44375 .38858 Mdot
.65343 .44314 Mdot
.6374 .31147 Mdot
.37615 .60237 Mdot
.44013 .44907 Mdot
.41446 .39016 Mdot
.62924 .337 Mdot
.64955 .3138 Mdot
.61622 .34674 Mdot
.5804 .60082 Mdot
.45797 .41093 Mdot
.34918 .62755 Mdot
.62269 .61514 Mdot
.64683 .31807 Mdot
.59846 .34609 Mdot
.16726 .55353 Mdot
.39318 .39394 Mdot
.63234 .38646 Mdot
.09573 .51793 Mdot
.55019 .27587 Mdot
.46619 .73788 Mdot
.62861 .45058 Mdot
.55344 .22056 Mdot
.65119 .29481 Mdot
.62653 .59674 Mdot
.5534 .3568 Mdot
.6301 .36376 Mdot
.3895 .44156 Mdot
.40697 .4294 Mdot
.39831 .35267 Mdot
.62425 .32181 Mdot
.46436 .22766 Mdot
.38519 .62847 Mdot
.24913 .47494 Mdot
.62581 .32835 Mdot
.62674 .45808 Mdot
.64108 .44181 Mdot
.64997 .50622 Mdot
.39113 .37487 Mdot
.29964 .55242 Mdot
.24227 .37821 Mdot
.22048 .53257 Mdot
.61866 .62212 Mdot
.38433 .56756 Mdot
.60362 .5366 Mdot
.37178 .61139 Mdot
.66758 .49822 Mdot
.62635 .31818 Mdot
.3467 .64158 Mdot
.5989 .59948 Mdot
.60505 .59812 Mdot
.66864 .51871 Mdot
.64532 .4928 Mdot
.63727 .48165 Mdot
.34286 .57422 Mdot
.35651 .61827 Mdot
.41955 .44845 Mdot
.37118 .59414 Mdot
.21239 .37195 Mdot
.6362 .29362 Mdot
.67377 .44391 Mdot
.59542 .61772 Mdot
.34065 .59235 Mdot
.43085 .40956 Mdot
.73024 .37107 Mdot
.6185 .43822 Mdot
.61639 .351 Mdot
.53356 .60117 Mdot
.7149 .21896 Mdot
.38581 .44621 Mdot
.58282 .60901 Mdot
.40925 .68151 Mdot
.40641 .41646 Mdot
.66205 .4631 Mdot
.34767 .28956 Mdot
.46728 .76044 Mdot
.40285 .37601 Mdot
.38901 .3648 Mdot
.60545 .65332 Mdot
.56596 .47084 Mdot
.38501 .43292 Mdot
.51758 .48842 Mdot
.57731 .61559 Mdot
.6361 .50959 Mdot
.27577 .75006 Mdot
.56049 .62678 Mdot
.55059 .2028 Mdot
.46671 .74052 Mdot
.39382 .44657 Mdot
.64831 .47739 Mdot
.61375 .35264 Mdot
.64769 .48415 Mdot
.37755 .64532 Mdot
.64335 .4548 Mdot
.4168 .42033 Mdot
.35188 .62774 Mdot
.59473 .60912 Mdot
.47255 .51558 Mdot
.18824 .59475 Mdot
.67097 .45142 Mdot
.4909 .7647 Mdot
.39639 .38272 Mdot
.20697 .46389 Mdot
.36777 .47289 Mdot
.38414 .3856 Mdot
.62638 .61523 Mdot
.34412 .59558 Mdot
.61035 .57937 Mdot
.3917 .45456 Mdot
.30312 .34576 Mdot
.59914 .63456 Mdot
.37172 .75522 Mdot
.63547 .34188 Mdot
.4968 .20357 Mdot
.41882 .40173 Mdot
.61569 .64334 Mdot
.4585 .41184 Mdot
.3669 .63857 Mdot
.49521 .56714 Mdot
.37589 .69547 Mdot
.62254 .63772 Mdot
.52338 .82818 Mdot
.53414 .50958 Mdot
.4323 .33669 Mdot
.60619 .64572 Mdot
.28007 .58447 Mdot
.47753 .75249 Mdot
.63579 .32431 Mdot
.64902 .3194 Mdot
.6002 .32516 Mdot
.38027 .42562 Mdot
.47947 .45823 Mdot
.60867 .3574 Mdot
.58744 .59304 Mdot
.61654 .3579 Mdot
.43244 .23751 Mdot
.54528 .819 Mdot
.61964 .34931 Mdot
.42266 .39923 Mdot
.4114 .46306 Mdot
.59548 .25958 Mdot
.62999 .5067 Mdot
.73152 .69597 Mdot
.17928 .46698 Mdot
.38652 .39497 Mdot
.36909 .30295 Mdot
.38882 .6332 Mdot
.43365 .62339 Mdot
.35805 .33509 Mdot
.58311 .45826 Mdot
.3495 .58964 Mdot
.52579 .57195 Mdot
.37615 .57935 Mdot
.36815 .43411 Mdot
.42434 .38919 Mdot
.32184 .61182 Mdot
.58422 .7638 Mdot
.31318 .73287 Mdot
.48782 .80377 Mdot
.387 .61335 Mdot
.59929 .64436 Mdot
.58076 .60905 Mdot
.62285 .62206 Mdot
.63238 .4847 Mdot
.33252 .59564 Mdot
.45733 .424 Mdot
.67884 .47032 Mdot
.43429 .37686 Mdot
.6182 .60146 Mdot
.48479 .69855 Mdot
.36228 .58404 Mdot
.40227 .40677 Mdot
.17471 .51658 Mdot
.66085 .48973 Mdot
.62885 .33468 Mdot
.52929 .62992 Mdot
.62971 .4475 Mdot
.58477 .63823 Mdot
.33556 .56805 Mdot
.6881 .44022 Mdot
.70054 .3218 Mdot
.44568 .36284 Mdot
.45786 .37757 Mdot
.66426 .61992 Mdot
.18389 .56798 Mdot
.38889 .42961 Mdot
.68119 .46963 Mdot
.62927 .45821 Mdot
.46122 .40842 Mdot
.33683 .63005 Mdot
.6234 .36366 Mdot
.59903 .31925 Mdot
.36847 .3893 Mdot
.50153 .61134 Mdot
.54056 .21282 Mdot
.42131 .43968 Mdot
.48028 .35131 Mdot
.64605 .52288 Mdot
.46281 .74533 Mdot
.4846 .61895 Mdot
.60789 .31055 Mdot
.42742 .38351 Mdot
.32819 .74587 Mdot
.35406 .58521 Mdot
.63731 .46616 Mdot
.60838 .59066 Mdot
.59778 .36396 Mdot
.68952 .47704 Mdot
.46122 .40864 Mdot
.41851 .44509 Mdot
.61636 .64841 Mdot
.30377 .62093 Mdot
.62368 .31919 Mdot
.67674 .46687 Mdot
.62564 .30343 Mdot
.36251 .6214 Mdot
.35788 .58903 Mdot
.38816 .4713 Mdot
.35875 .45484 Mdot
.68144 .46076 Mdot
.39388 .35777 Mdot
.65565 .50985 Mdot
.76415 .39288 Mdot
.59906 .59287 Mdot
.41246 .35997 Mdot
.31705 .63775 Mdot
.61813 .60325 Mdot
.38302 .40507 Mdot
.66326 .62104 Mdot
.40819 .44098 Mdot
.61645 .47299 Mdot
.30879 .30625 Mdot
.62461 .30996 Mdot
.43988 .50994 Mdot
.37871 .51188 Mdot
.44497 .41516 Mdot
.62258 .49978 Mdot
.44974 .48228 Mdot
.60022 .63179 Mdot
.34853 .60985 Mdot
.4436 .16025 Mdot
.60516 .6101 Mdot
.43541 .39366 Mdot
.61654 .32365 Mdot
.38874 .58371 Mdot
.48586 .74149 Mdot
.49363 .65394 Mdot
.46136 .35624 Mdot
.38718 .34871 Mdot
.44682 .3998 Mdot
.76282 .30487 Mdot
.64162 .47879 Mdot
.33771 .59926 Mdot
.58745 .60103 Mdot
.61365 .61948 Mdot
.66049 .49773 Mdot
.42812 .78696 Mdot
.60659 .77635 Mdot
.09984 .56323 Mdot
.68686 .47475 Mdot
.60434 .3495 Mdot
.51349 .55359 Mdot
.66276 .50773 Mdot
.64557 .47193 Mdot
.66525 .52284 Mdot
.43626 .72858 Mdot
.37798 .62513 Mdot
.41392 .38874 Mdot
.32007 .59074 Mdot
.39072 .44403 Mdot
.61037 .2295 Mdot
.61669 .61127 Mdot
.34987 .61186 Mdot
.65363 .56309 Mdot
.34173 .38755 Mdot
.39765 .42068 Mdot
.66212 .39929 Mdot
.46687 .36589 Mdot
.53577 .24821 Mdot
.35803 .42968 Mdot
.65145 .4901 Mdot
.34434 .33065 Mdot
.48683 .42527 Mdot
.17846 .49079 Mdot
.59942 .60147 Mdot
.48487 .73595 Mdot
.44715 .45524 Mdot
.47022 .35328 Mdot
.38634 .57841 Mdot
.34557 .64139 Mdot
.61068 .3592 Mdot
.53366 .64904 Mdot
.59679 .60438 Mdot
.659 .7538 Mdot
.37905 .39203 Mdot
.62167 .68002 Mdot
.30521 .30629 Mdot
.38528 .40762 Mdot
.62552 .41315 Mdot
.31961 .51858 Mdot
.39522 .43668 Mdot
.22988 .52849 Mdot
.59883 .61601 Mdot
.30067 .28051 Mdot
.37027 .37625 Mdot
.66128 .46359 Mdot
.35141 .61885 Mdot
.39373 .61868 Mdot
.62215 .35289 Mdot
.18973 .41328 Mdot
.64967 .60878 Mdot
.35345 .61658 Mdot
.41453 .41391 Mdot
.5917 .62089 Mdot
.48171 .73315 Mdot
.41162 .34247 Mdot
.80346 .47828 Mdot
.36879 .59027 Mdot
.46953 .45383 Mdot
.47563 .79945 Mdot
.54036 .51982 Mdot
.7097 .74403 Mdot
.62225 .62755 Mdot
.60623 .31118 Mdot
.35175 .41511 Mdot
.73967 .50711 Mdot
.36435 .38411 Mdot
.58187 .21592 Mdot
.38113 .65853 Mdot
.63825 .30745 Mdot
.40571 .4135 Mdot
.38574 .43303 Mdot
.50391 .58453 Mdot
.64614 .30752 Mdot
.38565 .43424 Mdot
.41803 .47688 Mdot
.37872 .61913 Mdot
.47794 .77162 Mdot
.36871 .58693 Mdot
.43026 .4033 Mdot
.39369 .28742 Mdot
.34481 .63847 Mdot
.71104 .7025 Mdot
.616 .27824 Mdot
.60862 .63002 Mdot
.49197 .37978 Mdot
.39539 .37575 Mdot
.83912 .59807 Mdot
.47615 .72997 Mdot
.59655 .19632 Mdot
.6218 .45899 Mdot
.38055 .81152 Mdot
.62907 .44597 Mdot
.59419 .82531 Mdot
.47083 .52943 Mdot
.41703 .35539 Mdot
.54349 .33737 Mdot
.22404 .52304 Mdot
.6284 .57595 Mdot
.23027 .42308 Mdot
.3816 .3898 Mdot
.40492 .38219 Mdot
.6785 .48804 Mdot
.44379 .79149 Mdot
.41081 .68678 Mdot
.49044 .61081 Mdot
.62854 .31525 Mdot
.36067 .61454 Mdot
.4123 .4232 Mdot
.5552 .73702 Mdot
.66317 .45109 Mdot
.5203 .36327 Mdot
.40494 .40502 Mdot
.43714 .68302 Mdot
.40434 .75842 Mdot
.59052 .61611 Mdot
.62025 .46781 Mdot
.62003 .49882 Mdot
.42134 .45581 Mdot
.62168 .58938 Mdot
.40702 .44619 Mdot
.53061 .5131 Mdot
.48225 .40923 Mdot
.64142 .32063 Mdot
.43135 .37167 Mdot
.54499 .37197 Mdot
.58663 .84214 Mdot
.48751 .40027 Mdot
.37246 .57169 Mdot
.63476 .49107 Mdot
.65367 .50179 Mdot
.38703 .60935 Mdot
.6551 .50219 Mdot
.25005 .48543 Mdot
.28709 .34328 Mdot
.64152 .32865 Mdot
.2024 .54455 Mdot
.62928 .31176 Mdot
.48609 .73769 Mdot
.39134 .39742 Mdot
.7495 .51227 Mdot
.6871 .47388 Mdot
.3871 .24997 Mdot
.6102 .61463 Mdot
.47481 .73034 Mdot
.46787 .42258 Mdot
.64578 .38227 Mdot
.67238 .49055 Mdot
.7259 .65046 Mdot
.44492 .44854 Mdot
.37182 .63357 Mdot
.3918 .43533 Mdot
.47409 .38902 Mdot
.4654 .73624 Mdot
.44775 .39995 Mdot
.58954 .63245 Mdot
.33201 .59523 Mdot
.59918 .81845 Mdot
.6317 .48846 Mdot
.40763 .37692 Mdot
.41296 .41418 Mdot
.3458 .64319 Mdot
.46983 .42071 Mdot
.62627 .59855 Mdot
.2638 .80062 Mdot
.637 .33942 Mdot
.46225 .74761 Mdot
.71673 .67449 Mdot
.41837 .42577 Mdot
.42036 .43522 Mdot
.66023 .65174 Mdot
.30003 .70309 Mdot
.59651 .63727 Mdot
.47354 .42474 Mdot
.66753 .45758 Mdot
.61841 .31751 Mdot
.63123 .61461 Mdot
.45907 .40649 Mdot
.40322 .38332 Mdot
.64307 .32603 Mdot
.66171 .39672 Mdot
.60974 .47559 Mdot
.62058 .62165 Mdot
.381 .30352 Mdot
.73611 .37678 Mdot
.40405 .39384 Mdot
.51049 .79947 Mdot
.35379 .59426 Mdot
.60833 .64352 Mdot
.29248 .58537 Mdot
.36366 .42151 Mdot
.58851 .64135 Mdot
.59574 .60723 Mdot
.46418 .43193 Mdot
.3248 .58138 Mdot
.3581 .56441 Mdot
.35229 .59283 Mdot
.32202 .27797 Mdot
.68641 .26614 Mdot
.63647 .48034 Mdot
.59766 .61236 Mdot
.65098 .44092 Mdot
.6112 .36267 Mdot
.51664 .56215 Mdot
.62916 .45702 Mdot
.39227 .60865 Mdot
.6601 .43916 Mdot
.40901 .44448 Mdot
.60479 .59552 Mdot
.68419 .47276 Mdot
.4324 .4251 Mdot
.4904 .36437 Mdot
.54427 .36374 Mdot
.6312 .36047 Mdot
.52341 .57582 Mdot
.43414 .39781 Mdot
.4663 .74792 Mdot
.39425 .40476 Mdot
.62142 .58706 Mdot
.55067 .38734 Mdot
.44212 .42598 Mdot
.68666 .46852 Mdot
.70845 .31949 Mdot
.62249 .49349 Mdot
.4755 .40117 Mdot
.43028 .40235 Mdot
.40276 .39177 Mdot
.379 .42813 Mdot
.38706 .76615 Mdot
.62281 .57813 Mdot
.50119 .39362 Mdot
.68855 .4936 Mdot
.37361 .60739 Mdot
.36133 .64188 Mdot
.58531 .47816 Mdot
.47032 .7276 Mdot
.62214 .592 Mdot
.40394 .39056 Mdot
.7263 .6494 Mdot
.5051 .69227 Mdot
.49767 .80825 Mdot
.59631 .45355 Mdot
.68224 .47013 Mdot
.36853 .56936 Mdot
.66958 .51131 Mdot
.46085 .40193 Mdot
.35691 .42715 Mdot
.61591 .80866 Mdot
.57204 .61392 Mdot
.62544 .3192 Mdot
.43581 .37708 Mdot
.52167 .20063 Mdot
.6714 .45978 Mdot
.64245 .52207 Mdot
.41038 .44821 Mdot
.37757 .5575 Mdot
.67137 .79792 Mdot
.61546 .58818 Mdot
.20983 .45277 Mdot
.34382 .67336 Mdot
.47102 .32836 Mdot
.60105 .62648 Mdot
.60475 .40169 Mdot
.6287 .50069 Mdot
.18287 .44875 Mdot
.37061 .60112 Mdot
.62802 .32169 Mdot
.42425 .4727 Mdot
.39248 .60781 Mdot
.64439 .43772 Mdot
.36363 .57665 Mdot
.36171 .42271 Mdot
.59311 .58837 Mdot
.65518 .50538 Mdot
.63189 .58608 Mdot
.32297 .6067 Mdot
.62728 .31092 Mdot
.40155 .25199 Mdot
.20934 .44645 Mdot
.31984 .51855 Mdot
.44511 .42949 Mdot
.76489 .52569 Mdot
.45887 .42435 Mdot
.37845 .56708 Mdot
.41962 .40137 Mdot
.46094 .5045 Mdot
.6417 .51667 Mdot
.47544 .44534 Mdot
.42076 .36884 Mdot
.19178 .4547 Mdot
.38935 .41609 Mdot
.46724 .41839 Mdot
.37614 .37637 Mdot
.31303 .65735 Mdot
.46492 .45467 Mdot
.37003 .63383 Mdot
.42421 .73984 Mdot
.64771 .47136 Mdot
.59382 .33798 Mdot
.60794 .3046 Mdot
.57457 .21202 Mdot
.50455 .20237 Mdot
.4314 .78387 Mdot
.38204 .59862 Mdot
.58863 .63728 Mdot
.40981 .44647 Mdot
.26856 .6043 Mdot
.48189 .30746 Mdot
.63114 .50362 Mdot
.67572 .45114 Mdot
.38708 .47368 Mdot
.80883 .3515 Mdot
.46785 .45335 Mdot
.48934 .66561 Mdot
.38425 .43591 Mdot
.40439 .3604 Mdot
.64189 .52367 Mdot
.45595 .22658 Mdot
.44454 .42927 Mdot
.38646 .57892 Mdot
.63191 .32564 Mdot
.36151 .31207 Mdot
.45392 .28952 Mdot
.47715 .32055 Mdot
.40803 .63747 Mdot
.45537 .40924 Mdot
.67396 .46737 Mdot
.39145 .60028 Mdot
.48104 .63844 Mdot
.62394 .61537 Mdot
.49489 .63316 Mdot
.21903 .41655 Mdot
.55879 .61571 Mdot
.62996 .32087 Mdot
.59886 .46454 Mdot
.41799 .42008 Mdot
.63288 .48372 Mdot
.37629 .43975 Mdot
.50855 .69294 Mdot
.63864 .31094 Mdot
.33131 .58252 Mdot
.59819 .64379 Mdot
.38332 .62544 Mdot
.28096 .56619 Mdot
.47009 .30232 Mdot
.38108 .81247 Mdot
.63147 .46121 Mdot
.31388 .39413 Mdot
.34084 .61308 Mdot
.45844 .43536 Mdot
.10003 .55341 Mdot
.35393 .5978 Mdot
.38019 .62777 Mdot
.58346 .45425 Mdot
.42524 .25225 Mdot
.48667 .43131 Mdot
.3739 .57993 Mdot
.69362 .4634 Mdot
.61484 .33568 Mdot
.42891 .43055 Mdot
.36949 .3919 Mdot
.34236 .63932 Mdot
.6699 .49306 Mdot
.52315 .19711 Mdot
.64828 .49217 Mdot
.37077 .62889 Mdot
.66229 .47959 Mdot
.69976 .70418 Mdot
.65474 .45153 Mdot
.41873 .36805 Mdot
.40469 .3912 Mdot
.78552 .45677 Mdot
.35796 .58906 Mdot
.42177 .43285 Mdot
.42093 .38429 Mdot
.34478 .62308 Mdot
.64464 .53723 Mdot
.3361 .52033 Mdot
.43175 .42157 Mdot
.40886 .38901 Mdot
.63803 .30521 Mdot
.53475 .54815 Mdot
.53453 .74596 Mdot
.42634 .43134 Mdot
.59927 .33161 Mdot
.34428 .57359 Mdot
.39297 .40634 Mdot
.45572 .22418 Mdot
.62767 .44058 Mdot
.45704 .39101 Mdot
.48817 .74694 Mdot
.38559 .42578 Mdot
.66378 .80297 Mdot
.40201 .38058 Mdot
.33713 .614 Mdot
.34612 .6159 Mdot
.61041 .45977 Mdot
.36838 .61021 Mdot
.46945 .73552 Mdot
.6147 .60019 Mdot
.49265 .82196 Mdot
.47291 .73358 Mdot
.40926 .36243 Mdot
.16764 .47141 Mdot
.3664 .39544 Mdot
.44249 .46125 Mdot
.40598 .24413 Mdot
.46951 .73847 Mdot
.34225 .59873 Mdot
.58614 .7601 Mdot
.43013 .36017 Mdot
.61786 .58799 Mdot
.42697 .46445 Mdot
.45697 .38986 Mdot
.53111 .4232 Mdot
.30739 .33005 Mdot
.6411 .60907 Mdot
.40934 .33353 Mdot
.42829 .43164 Mdot
.29108 .68658 Mdot
.41965 .41539 Mdot
.62173 .3505 Mdot
.3843 .59579 Mdot
.66544 .51467 Mdot
.63298 .33901 Mdot
.41694 .42343 Mdot
.62514 .3244 Mdot
.63678 .47715 Mdot
.62555 .62923 Mdot
.43631 .37451 Mdot
.63361 .29556 Mdot
.62414 .3168 Mdot
.4429 .44356 Mdot
.35119 .61566 Mdot
.37287 .48132 Mdot
.39111 .40714 Mdot
.46202 .41329 Mdot
.38666 .60942 Mdot
.18209 .36341 Mdot
.39696 .45035 Mdot
.60944 .40252 Mdot
.33234 .64194 Mdot
.45934 .75303 Mdot
.67553 .50406 Mdot
.35512 .3858 Mdot
.6176 .61622 Mdot
.6158 .60591 Mdot
.68236 .51008 Mdot
.32762 .62079 Mdot
.6593 .50477 Mdot
.42762 .33997 Mdot
.38369 .4719 Mdot
.41876 .47401 Mdot
.44636 .16005 Mdot
.72509 .68176 Mdot
.33215 .61065 Mdot
.62638 .50021 Mdot
.49614 .61835 Mdot
.61903 .59227 Mdot
.67488 .52132 Mdot
.32612 .64509 Mdot
.34057 .58345 Mdot
.38954 .59965 Mdot
.60535 .31777 Mdot
.64444 .49825 Mdot
.37952 .65635 Mdot
.3533 .56312 Mdot
.42574 .45051 Mdot
.42926 .4321 Mdot
.40334 .59694 Mdot
.58841 .2678 Mdot
.63659 .31313 Mdot
.66927 .46621 Mdot
.81824 .66179 Mdot
.61474 .58791 Mdot
.19057 .45706 Mdot
.43232 .42445 Mdot
.12734 .37219 Mdot
.46008 .45874 Mdot
.41597 .41446 Mdot
.33926 .58001 Mdot
.6036 .30447 Mdot
.61618 .33237 Mdot
.34161 .61395 Mdot
.35828 .55767 Mdot
.60282 .3317 Mdot
.60733 .42968 Mdot
.50337 .8364 Mdot
.48625 .63245 Mdot
.34022 .62165 Mdot
.19977 .47348 Mdot
.63042 .61925 Mdot
.31933 .62386 Mdot
.63756 .59683 Mdot
.64574 .47045 Mdot
.66827 .44749 Mdot
.61904 .64686 Mdot
.46051 .43489 Mdot
.64169 .45784 Mdot
.47896 .37423 Mdot
.6684 .76515 Mdot
.81008 .53503 Mdot
.27414 .69978 Mdot
.37282 .39974 Mdot
.41845 .68255 Mdot
.39087 .72095 Mdot
.44399 .40804 Mdot
.35959 .34811 Mdot
.62549 .32087 Mdot
.32227 .62931 Mdot
.63066 .5958 Mdot
.73722 .70064 Mdot
.40391 .39286 Mdot
.36443 .63161 Mdot
.61178 .59269 Mdot
.69338 .70353 Mdot
.52125 .48497 Mdot
.40055 .44774 Mdot
.11802 .62505 Mdot
.32443 .60163 Mdot
.66472 .51481 Mdot
.18666 .54126 Mdot
.31625 .60093 Mdot
.7306 .35966 Mdot
.6186 .49951 Mdot
.51182 .75259 Mdot
.3464 .57953 Mdot
.62494 .52399 Mdot
.36508 .61974 Mdot
.63516 .35034 Mdot
.33322 .56945 Mdot
.66529 .48991 Mdot
.39875 .41541 Mdot
.66239 .49289 Mdot
.6444 .33107 Mdot
.6326 .46717 Mdot
.63105 .59758 Mdot
.46607 .74279 Mdot
.60987 .59629 Mdot
.51887 .5569 Mdot
.3043 .427 Mdot
.615 .63443 Mdot
.74451 .62575 Mdot
.39277 .43085 Mdot
.30517 .60938 Mdot
.66625 .51623 Mdot
.68575 .45583 Mdot
.51166 .59652 Mdot
.36724 .62724 Mdot
.66768 .48212 Mdot
.22205 .41724 Mdot
.25904 .2525 Mdot
.492 .39421 Mdot
.69557 .27483 Mdot
.34421 .62378 Mdot
.64299 .51837 Mdot
.48368 .65397 Mdot
.3833 .63466 Mdot
.6833 .46564 Mdot
.60549 .64685 Mdot
.61113 .62302 Mdot
.44864 .44812 Mdot
.59444 .65684 Mdot
.62384 .50336 Mdot
.32134 .736 Mdot
.38627 .5985 Mdot
.70094 .68537 Mdot
.61182 .34641 Mdot
.64172 .47263 Mdot
.48374 .43519 Mdot
.40458 .63136 Mdot
.68125 .45462 Mdot
.81065 .44989 Mdot
.83863 .62367 Mdot
.66774 .4807 Mdot
.38366 .59468 Mdot
.37713 .60517 Mdot
.48786 .40504 Mdot
.50041 .60409 Mdot
.67092 .48781 Mdot
.75175 .50772 Mdot
.58803 .22145 Mdot
.48426 .74427 Mdot
.16616 .52242 Mdot
.44505 .42835 Mdot
.45661 .40578 Mdot
.62689 .60548 Mdot
.3974 .42335 Mdot
.37312 .5595 Mdot
.44307 .467 Mdot
.57996 .60768 Mdot
.63408 .50662 Mdot
.39643 .39461 Mdot
.61 .31981 Mdot
.62812 .60018 Mdot
.58342 .64048 Mdot
.65681 .474 Mdot
.38302 .58774 Mdot
.56807 .77049 Mdot
.64735 .49316 Mdot
.45609 .41284 Mdot
.47477 .74427 Mdot
.35738 .40967 Mdot
.77864 .47442 Mdot
.38661 .62571 Mdot
.6677 .51217 Mdot
.35182 .64919 Mdot
.60104 .6073 Mdot
.69437 .48259 Mdot
.42773 .41459 Mdot
.67876 .45959 Mdot
.602 .39323 Mdot
.69063 .39102 Mdot
.3566 .56086 Mdot
.64537 .3593 Mdot
.34645 .64242 Mdot
.48457 .74404 Mdot
.49188 .27178 Mdot
.63695 .32174 Mdot
.65305 .45438 Mdot
.7222 .69812 Mdot
.67502 .51345 Mdot
.38693 .41451 Mdot
.37763 .40336 Mdot
.67793 .49178 Mdot
.61266 .31104 Mdot
.47456 .19564 Mdot
.66363 .28986 Mdot
.3456 .58551 Mdot
.45423 .55226 Mdot
.7815 .70406 Mdot
.70295 .48414 Mdot
.59277 .64323 Mdot
.42994 .32821 Mdot
.40615 .43803 Mdot
.60333 .65301 Mdot
.59952 .5906 Mdot
.64704 .32028 Mdot
.63326 .47954 Mdot
.3576 .65596 Mdot
.62909 .62934 Mdot
.34977 .48503 Mdot
.48147 .20757 Mdot
.46815 .37159 Mdot
.44557 .47913 Mdot
.40089 .37049 Mdot
.54012 .52218 Mdot
.60016 .58478 Mdot
.42918 .39501 Mdot
.37392 .46373 Mdot
.60583 .64176 Mdot
.64312 .33719 Mdot
.38543 .53654 Mdot
.66397 .47106 Mdot
.20158 .29299 Mdot
.43474 .37344 Mdot
.39491 .41308 Mdot
.61842 .62224 Mdot
.19403 .58886 Mdot
.33608 .62115 Mdot
.38004 .58623 Mdot
.64068 .47913 Mdot
.51404 .60677 Mdot
.46958 .41107 Mdot
.44145 .4044 Mdot
.65087 .45775 Mdot
.46716 .74699 Mdot
.25674 .70482 Mdot
.41564 .39169 Mdot
.59791 .62098 Mdot
.73881 .62247 Mdot
.60502 .58242 Mdot
.38427 .44525 Mdot
.38404 .41268 Mdot
.43067 .36863 Mdot
.37472 .42319 Mdot
.62453 .64017 Mdot
.44111 .40819 Mdot
.34548 .44142 Mdot
.34645 .59498 Mdot
.44875 .41981 Mdot
.5636 .21337 Mdot
.41109 .39416 Mdot
.61092 .31979 Mdot
.53924 .75437 Mdot
.41177 .37736 Mdot
.45119 .41723 Mdot
.66657 .30018 Mdot
.41065 .41114 Mdot
.59327 .60342 Mdot
.37339 .60158 Mdot
.59784 .60972 Mdot
.58673 .62106 Mdot
.66978 .44374 Mdot
.64823 .33327 Mdot
.37024 .37289 Mdot
.60173 .33504 Mdot
.48394 .4063 Mdot
.36391 .42568 Mdot
.52665 .55638 Mdot
.49018 .66685 Mdot
.6545 .29977 Mdot
.43309 .41059 Mdot
.64521 .47702 Mdot
.67545 .5067 Mdot
.5545 .34869 Mdot
.48081 .38144 Mdot
.63196 .61508 Mdot
.61536 .64367 Mdot
.5643 .27145 Mdot
.52975 .45303 Mdot
.61611 .3157 Mdot
.47806 .59136 Mdot
.37692 .38469 Mdot
.41731 .38099 Mdot
.41534 .46371 Mdot
.63483 .44929 Mdot
.46416 .745 Mdot
.63281 .50351 Mdot
.49063 .73229 Mdot
.61591 .5786 Mdot
.37337 .39856 Mdot
.79995 .56851 Mdot
.33186 .62503 Mdot
.37284 .6001 Mdot
.57827 .6121 Mdot
.62263 .49546 Mdot
.48304 .39321 Mdot
.47112 .14655 Mdot
.39801 .59176 Mdot
.59562 .32923 Mdot
.43946 .39984 Mdot
.65335 .47388 Mdot
.32907 .60021 Mdot
.65284 .32428 Mdot
.37645 .39174 Mdot
.66457 .52731 Mdot
.41531 .39886 Mdot
.22834 .54825 Mdot
.34527 .60198 Mdot
.48709 .69934 Mdot
.38608 .5572 Mdot
.59982 .65011 Mdot
.59217 .63243 Mdot
.38292 .40658 Mdot
.35939 .18128 Mdot
.39533 .55814 Mdot
.61859 .65443 Mdot
.63346 .35465 Mdot
.4634 .75049 Mdot
.64254 .34614 Mdot
.65896 .50976 Mdot
.63221 .3234 Mdot
.68457 .46447 Mdot
.57351 .28529 Mdot
.39577 .63233 Mdot
.63618 .33828 Mdot
.19595 .59933 Mdot
.35609 .4171 Mdot
.64581 .31332 Mdot
.39076 .47563 Mdot
.40009 .52558 Mdot
.65033 .45999 Mdot
.61013 .31468 Mdot
.44154 .44804 Mdot
.76116 .64801 Mdot
.58885 .6277 Mdot
.63233 .61071 Mdot
.36558 .38071 Mdot
.65413 .52353 Mdot
.34928 .56199 Mdot
.56957 .45498 Mdot
.46109 .75735 Mdot
.44072 .40461 Mdot
.37562 .39001 Mdot
.3289 .63173 Mdot
.38745 .5756 Mdot
.38181 .41027 Mdot
.23157 .40668 Mdot
.41953 .42009 Mdot
.60803 .62598 Mdot
.33591 .59112 Mdot
.37575 .60129 Mdot
.61814 .47724 Mdot
.32803 .62142 Mdot
.45529 .47024 Mdot
.63697 .57417 Mdot
.39313 .46891 Mdot
.60403 .60739 Mdot
.55504 .38416 Mdot
.6312 .48143 Mdot
.73548 .6931 Mdot
.32628 .60926 Mdot
.45119 .4058 Mdot
.35726 .64163 Mdot
.61605 .34622 Mdot
.35959 .58891 Mdot
.39263 .62884 Mdot
.37971 .39383 Mdot
.39517 .44687 Mdot
.47002 .74594 Mdot
.50295 .60629 Mdot
.34997 .60563 Mdot
.43158 .41855 Mdot
.37365 .37423 Mdot
.41129 .45556 Mdot
.53572 .50847 Mdot
.34556 .57644 Mdot
.27396 .33942 Mdot
.79532 .49723 Mdot
.35197 .61273 Mdot
.74137 .71954 Mdot
.48354 .7636 Mdot
.47006 .72705 Mdot
.62327 .654 Mdot
.4126 .38883 Mdot
.65976 .50257 Mdot
.45802 .39629 Mdot
.47491 .36823 Mdot
.41137 .37584 Mdot
.64347 .3201 Mdot
.42759 .35354 Mdot
.48209 .75869 Mdot
.65224 .49395 Mdot
.42463 .42282 Mdot
.39785 .39038 Mdot
.4738 .7263 Mdot
.38884 .55732 Mdot
.34245 .58306 Mdot
.51722 .79348 Mdot
.63796 .3427 Mdot
.62572 .61489 Mdot
.45885 .40025 Mdot
.64341 .47816 Mdot
.65895 .49835 Mdot
.38186 .62682 Mdot
.66454 .46638 Mdot
.62359 .58758 Mdot
.41404 .41811 Mdot
.60533 .65279 Mdot
.64357 .32099 Mdot
.38459 .59643 Mdot
.45998 .40213 Mdot
.42792 .45109 Mdot
.3459 .61552 Mdot
.39001 .42985 Mdot
.6367 .30469 Mdot
.64987 .44687 Mdot
.33974 .59039 Mdot
.6148 .60143 Mdot
.62081 .46796 Mdot
.41354 .445 Mdot
.8609 .52024 Mdot
.39772 .42434 Mdot
.44605 .38751 Mdot
.5371 .83472 Mdot
.35981 .43416 Mdot
.65026 .51681 Mdot
.35906 .64295 Mdot
.39455 .45285 Mdot
.6134 .23333 Mdot
.69756 .52842 Mdot
.66717 .5283 Mdot
.44158 .39832 Mdot
.71857 .72612 Mdot
.44992 .40928 Mdot
.68451 .71764 Mdot
.52518 .55851 Mdot
.77388 .33169 Mdot
.43056 .48594 Mdot
.61403 .65581 Mdot
.46833 .74459 Mdot
.66521 .51857 Mdot
.25369 .5779 Mdot
.39294 .42678 Mdot
.29074 .57517 Mdot
.45925 .39083 Mdot
.60292 .62626 Mdot
.36793 .3409 Mdot
.66823 .46634 Mdot
.17554 .47699 Mdot
.45793 .42034 Mdot
.34215 .57941 Mdot
.68813 .45509 Mdot
.46592 .75757 Mdot
.44272 .44816 Mdot
.60672 .34433 Mdot
.6533 .555 Mdot
.42412 .48182 Mdot
.60608 .60533 Mdot
.42343 .38302 Mdot
.43941 .33524 Mdot
.29252 .23267 Mdot
.34557 .59289 Mdot
.59587 .64481 Mdot
.4215 .63747 Mdot
.37714 .41935 Mdot
.34396 .58219 Mdot
.3718 .60363 Mdot
.61925 .35482 Mdot
.51005 .67424 Mdot
.72073 .48346 Mdot
.82472 .51274 Mdot
.3075 .53284 Mdot
.62358 .45726 Mdot
.32743 .71991 Mdot
.43647 .43222 Mdot
.45874 .29694 Mdot
.58932 .61231 Mdot
.39781 .41374 Mdot
.30881 .48304 Mdot
.35318 .59093 Mdot
.4202 .39549 Mdot
.63793 .31492 Mdot
.45532 .71176 Mdot
.45297 .31148 Mdot
.83527 .58538 Mdot
.69626 .48855 Mdot
.4202 .46685 Mdot
.39675 .48509 Mdot
.45916 .7511 Mdot
.37987 .43984 Mdot
.66297 .51756 Mdot
.76897 .5324 Mdot
.61812 .30868 Mdot
.32938 .61904 Mdot
.48062 .76501 Mdot
.45167 .37647 Mdot
.36106 .40296 Mdot
.5944 .33947 Mdot
.45945 .43067 Mdot
.1816 .51428 Mdot
.4531 .73503 Mdot
.65376 .45077 Mdot
.3674 .57685 Mdot
.39821 .37135 Mdot
.46484 .74704 Mdot
.37834 .39715 Mdot
.41241 .53553 Mdot
.44206 .39153 Mdot
.44672 .80744 Mdot
.35247 .61955 Mdot
.60654 .6016 Mdot
.39926 .35006 Mdot
.40438 .39934 Mdot
.73744 .38131 Mdot
.47209 .36496 Mdot
.40183 .38128 Mdot
.39299 .59372 Mdot
.33863 .63362 Mdot
.37702 .62814 Mdot
.64774 .45156 Mdot
.48629 .62467 Mdot
.60656 .61904 Mdot
.46291 .44859 Mdot
.63057 .62258 Mdot
.42653 .50374 Mdot
.5966 .34036 Mdot
.77353 .66414 Mdot
.40751 .42749 Mdot
.38369 .61592 Mdot
.33984 .74788 Mdot
.34395 .5735 Mdot
.60868 .66718 Mdot
.59727 .6034 Mdot
.35359 .60029 Mdot
.41739 .40872 Mdot
.49157 .60806 Mdot
.84718 .54072 Mdot
.61931 .59388 Mdot
.38621 .45625 Mdot
.69689 .47633 Mdot
.68922 .47066 Mdot
.7146 .76292 Mdot
.58515 .62307 Mdot
.38655 .72022 Mdot
.43955 .41722 Mdot
.33383 .63019 Mdot
.61941 .629 Mdot
.59146 .604 Mdot
.65544 .45897 Mdot
.40623 .44942 Mdot
.40743 .39889 Mdot
.48871 .74967 Mdot
.62603 .63044 Mdot
.36873 .35286 Mdot
.39195 .44051 Mdot
.59751 .82199 Mdot
.33313 .64951 Mdot
.16704 .38356 Mdot
.42584 .33831 Mdot
.31326 .48182 Mdot
.54295 .45348 Mdot
.33144 .60442 Mdot
.46472 .41852 Mdot
.46768 .44274 Mdot
.62042 .46459 Mdot
.40887 .42105 Mdot
.62507 .48438 Mdot
.58949 .64032 Mdot
.77947 .66402 Mdot
.70949 .65933 Mdot
.60296 .54267 Mdot
.39354 .42061 Mdot
.48131 .3318 Mdot
.62418 .34415 Mdot
.57966 .59814 Mdot
.35703 .63605 Mdot
.39057 .37284 Mdot
.61572 .49122 Mdot
.65735 .45425 Mdot
.36571 .59984 Mdot
.39804 .73553 Mdot
.71017 .7034 Mdot
.37291 .42056 Mdot
.66874 .50853 Mdot
.69587 .67268 Mdot
.24898 .39754 Mdot
.60535 .65698 Mdot
.62304 .30833 Mdot
.63891 .50915 Mdot
.57502 .62655 Mdot
.41694 .52667 Mdot
.36139 .60602 Mdot
.32429 .62058 Mdot
.75204 .42954 Mdot
.6683 .49009 Mdot
.62605 .33907 Mdot
.51583 .47629 Mdot
.48534 .50399 Mdot
.63862 .31199 Mdot
.63206 .50529 Mdot
.33146 .62052 Mdot
.36685 .63069 Mdot
.37407 .60346 Mdot
.17817 .49205 Mdot
.38963 .62391 Mdot
.25205 .32361 Mdot
.36606 .40683 Mdot
.20677 .4679 Mdot
.44826 .40548 Mdot
.63408 .62533 Mdot
.3451 .60382 Mdot
.51324 .56863 Mdot
.39151 .36623 Mdot
.83677 .57224 Mdot
.4355 .39814 Mdot
.64648 .57847 Mdot
.41067 .3884 Mdot
.19661 .54026 Mdot
.33093 .64113 Mdot
.43387 .41156 Mdot
.64183 .62048 Mdot
.62019 .32009 Mdot
.38768 .5506 Mdot
.40798 .38039 Mdot
.45024 .78099 Mdot
.37897 .46698 Mdot
.69368 .73756 Mdot
.69902 .32396 Mdot
.59534 .32039 Mdot
.4072 .47438 Mdot
.65986 .43624 Mdot
.41307 .58241 Mdot
.20197 .49392 Mdot
.61922 .59454 Mdot
.32154 .3164 Mdot
.64926 .45519 Mdot
.36261 .34662 Mdot
.46403 .37846 Mdot
.60889 .31116 Mdot
.39506 .55452 Mdot
.60698 .62822 Mdot
.3948 .42986 Mdot
.46619 .4209 Mdot
.80118 .42275 Mdot
.19849 .5018 Mdot
.36995 .35377 Mdot
.61375 .36268 Mdot
.27875 .34134 Mdot
.41823 .37678 Mdot
.66355 .52929 Mdot
.36814 .64245 Mdot
.4761 .45091 Mdot
.26747 .34322 Mdot
.42618 .41995 Mdot
.35677 .59889 Mdot
.32601 .61246 Mdot
.39521 .79265 Mdot
.59706 .33575 Mdot
.44183 .39126 Mdot
.74723 .38 Mdot
.4574 .41033 Mdot
.60667 .62256 Mdot
.38508 .44727 Mdot
.64368 .4664 Mdot
.48278 .6606 Mdot
.64432 .45166 Mdot
.42983 .45504 Mdot
.37363 .61966 Mdot
.61106 .62849 Mdot
.76081 .44706 Mdot
.5723 .48732 Mdot
.25808 .31807 Mdot
.65705 .55447 Mdot
.60563 .32351 Mdot
.65018 .3315 Mdot
.64492 .58717 Mdot
.4322 .40496 Mdot
.55154 .49584 Mdot
.47668 .43757 Mdot
.40942 .38505 Mdot
.42997 .37301 Mdot
.58584 .58112 Mdot
.60053 .60151 Mdot
.6637 .48373 Mdot
.38197 .41215 Mdot
.43281 .41786 Mdot
.35618 .61319 Mdot
.62356 .31631 Mdot
.65817 .44858 Mdot
.633 .34564 Mdot
.65051 .48802 Mdot
.68026 .78864 Mdot
.39025 .45315 Mdot
.61904 .32076 Mdot
.6012 .58284 Mdot
.38579 .61573 Mdot
.47741 .72917 Mdot
.65782 .50935 Mdot
.66966 .46911 Mdot
.4425 .40775 Mdot
.3746 .58628 Mdot
.35923 .58109 Mdot
.6033 .32907 Mdot
.61632 .63947 Mdot
.45231 .44665 Mdot
.39218 .44322 Mdot
.76105 .34546 Mdot
.62643 .45699 Mdot
.24084 .38653 Mdot
.40322 .78099 Mdot
.43222 .40598 Mdot
.35343 .58022 Mdot
.39555 .39877 Mdot
.77614 .59275 Mdot
.39195 .60624 Mdot
.38266 .36758 Mdot
.52617 .43127 Mdot
.64021 .44698 Mdot
.3967 .80912 Mdot
.39116 .35558 Mdot
.65709 .66154 Mdot
.44214 .43885 Mdot
.47661 .86337 Mdot
.30408 .7002 Mdot
.45757 .38461 Mdot
.37307 .4176 Mdot
.8326 .48537 Mdot
.44501 .41589 Mdot
.48543 .75794 Mdot
.44197 .34452 Mdot
.34177 .58259 Mdot
.5509 .45296 Mdot
.53232 .56305 Mdot
.60588 .35188 Mdot
.64004 .4788 Mdot
.45497 .25119 Mdot
.63894 .34499 Mdot
.33933 .61699 Mdot
.37151 .38428 Mdot
.33949 .48283 Mdot
.61653 .44694 Mdot
.47852 .39805 Mdot
.60544 .62388 Mdot
.53018 .56651 Mdot
.63122 .49735 Mdot
.61338 .59912 Mdot
.44852 .37879 Mdot
.59522 .20197 Mdot
.58009 .50119 Mdot
.44457 .82595 Mdot
.62039 .62156 Mdot
.5918 .61407 Mdot
.47446 .63828 Mdot
.60609 .35194 Mdot
.793 .39691 Mdot
.39971 .30875 Mdot
.61642 .58901 Mdot
.52976 .26 Mdot
.63022 .51655 Mdot
.50477 .67597 Mdot
.32184 .63002 Mdot
.39629 .45643 Mdot
.41447 .40666 Mdot
.61102 .64171 Mdot
.29622 .59045 Mdot
.42782 .56541 Mdot
.61324 .59498 Mdot
.37672 .47591 Mdot
.50764 .6854 Mdot
.47275 .74112 Mdot
.48888 .7576 Mdot
.62419 .35932 Mdot
.69117 .41088 Mdot
.36031 .62469 Mdot
.61543 .30461 Mdot
.49886 .76808 Mdot
.43928 .38828 Mdot
.62716 .62959 Mdot
.48515 .73475 Mdot
.61442 .60835 Mdot
.61445 .32781 Mdot
.5958 .33181 Mdot
.34628 .59452 Mdot
.3371 .62325 Mdot
.3064 .34637 Mdot
.56474 .2516 Mdot
.44829 .41677 Mdot
.33217 .52525 Mdot
.38933 .61289 Mdot
.22599 .60292 Mdot
.60034 .33821 Mdot
.6283 .31408 Mdot
.23208 .48843 Mdot
.4171 .4484 Mdot
.72261 .63964 Mdot
.41216 .37807 Mdot
.50098 .2801 Mdot
.43208 .36199 Mdot
.65845 .46113 Mdot
.45185 .42379 Mdot
.56235 .75286 Mdot
.41891 .42961 Mdot
.41702 .37183 Mdot
.64738 .50426 Mdot
.39734 .34931 Mdot
.64406 .46355 Mdot
.39302 .44771 Mdot
.58927 .33025 Mdot
.64336 .47848 Mdot
.64501 .26101 Mdot
.6018 .406 Mdot
.4686 .75343 Mdot
.63292 .35402 Mdot
.60507 .34038 Mdot
.55697 .20754 Mdot
.35018 .63556 Mdot
.42461 .52152 Mdot
.43164 .40374 Mdot
.64508 .52246 Mdot
.62863 .61004 Mdot
.42691 .41905 Mdot
.45304 .46269 Mdot
.38469 .35846 Mdot
.35118 .59541 Mdot
.63409 .50913 Mdot
.62186 .32645 Mdot
.68001 .49898 Mdot
.63653 .39044 Mdot
.68798 .48938 Mdot
.46609 .3393 Mdot
.40999 .33921 Mdot
.38078 .49873 Mdot
.32551 .50999 Mdot
.18331 .44178 Mdot
.36512 .60507 Mdot
.4786 .74994 Mdot
.59919 .34635 Mdot
.45235 .55054 Mdot
.37989 .61917 Mdot
.67177 .47364 Mdot
.41534 .39899 Mdot
.37448 .47563 Mdot
.44697 .31423 Mdot
.38855 .65302 Mdot
.5988 .24062 Mdot
.63778 .49444 Mdot
.47848 .73711 Mdot
.48703 .64185 Mdot
.3225 .66209 Mdot
.51504 .56161 Mdot
.39993 .39851 Mdot
.60344 .34047 Mdot
.32905 .60033 Mdot
.78472 .44358 Mdot
.60775 .64542 Mdot
.50134 .60583 Mdot
.39556 .42152 Mdot
.34837 .72855 Mdot
.37353 .61938 Mdot
.63083 .31152 Mdot
.61048 .6416 Mdot
.59836 .33799 Mdot
.47993 .76666 Mdot
.53372 .77771 Mdot
.45295 .43885 Mdot
.40028 .38118 Mdot
.62232 .58182 Mdot
.36294 .62446 Mdot
.60661 .48067 Mdot
.79883 .45229 Mdot
.6708 .50617 Mdot
.54951 .51477 Mdot
.33145 .5966 Mdot
.3086 .68327 Mdot
.68097 .46479 Mdot
.58464 .5969 Mdot
.54571 .50376 Mdot
.58016 .60911 Mdot
.41999 .3741 Mdot
.37961 .59657 Mdot
.58502 .62356 Mdot
.76221 .41153 Mdot
.66451 .78666 Mdot
.396 .54965 Mdot
.38297 .42345 Mdot
.77833 .66117 Mdot
.58216 .81194 Mdot
.34195 .54132 Mdot
.62612 .63527 Mdot
.38665 .40455 Mdot
.37139 .41797 Mdot
.45707 .42033 Mdot
.59226 .63806 Mdot
.59385 .49523 Mdot
.67046 .46273 Mdot
.43103 .39295 Mdot
.61178 .34586 Mdot
.65077 .46633 Mdot
.67033 .44095 Mdot
.66817 .5177 Mdot
.39268 .60353 Mdot
.36797 .39669 Mdot
.46494 .69469 Mdot
.50678 .86086 Mdot
.59949 .60481 Mdot
.46879 .75383 Mdot
.43322 .37122 Mdot
.31286 .2745 Mdot
.37853 .62629 Mdot
.67174 .50423 Mdot
.39634 .4127 Mdot
.70913 .34894 Mdot
.45646 .77489 Mdot
.64394 .49406 Mdot
.35557 .63528 Mdot
.3464 .53926 Mdot
.40981 .4211 Mdot
.43879 .44079 Mdot
.35191 .62679 Mdot
.49873 .80521 Mdot
.49052 .66038 Mdot
.39697 .39615 Mdot
.60824 .59993 Mdot
.27966 .23299 Mdot
.36166 .39553 Mdot
.39227 .65185 Mdot
.46259 .74831 Mdot
.441 .79781 Mdot
.24809 .38022 Mdot
.49197 .38188 Mdot
.79502 .62168 Mdot
.43632 .23753 Mdot
.7679 .67902 Mdot
.44809 .27071 Mdot
.67699 .68285 Mdot
.61057 .84342 Mdot
.63429 .63902 Mdot
.20229 .5473 Mdot
.81038 .38447 Mdot
.41301 .72084 Mdot
.68194 .33161 Mdot
.72756 .53175 Mdot
.71222 .33853 Mdot
.20309 .63768 Mdot
.68798 .48214 Mdot
.49286 .29733 Mdot
.46356 .43139 Mdot
.57631 .80821 Mdot
.20126 .45134 Mdot
.18548 .41938 Mdot
.76409 .67005 Mdot
.73913 .3669 Mdot
.85482 .49367 Mdot
.73302 .68961 Mdot
.31565 .35512 Mdot
.51815 .36313 Mdot
.70398 .43176 Mdot
.50272 .48784 Mdot
.44449 .25052 Mdot
.46398 .47236 Mdot
.56053 .7363 Mdot
.61253 .54874 Mdot
.29013 .39771 Mdot
.26486 .25776 Mdot
.65086 .51443 Mdot
.37089 .64187 Mdot
.79117 .38037 Mdot
.4085 .62756 Mdot
.64443 .63615 Mdot
.79565 .621 Mdot
.59622 .82572 Mdot
.19528 .53527 Mdot
.50515 .73597 Mdot
.23831 .53729 Mdot
.46817 .19187 Mdot
.50897 .34078 Mdot
.33955 .57235 Mdot
.70132 .60396 Mdot
.48572 .50312 Mdot
.67544 .41356 Mdot
.20086 .56942 Mdot
.65324 .31744 Mdot
.63691 .25283 Mdot
.35959 .6336 Mdot
.25707 .39069 Mdot
.46558 .72921 Mdot
.49977 .73574 Mdot
.62567 .52009 Mdot
.78097 .57632 Mdot
.44607 .75832 Mdot
.43948 .74709 Mdot
.3067 .73307 Mdot
.85644 .55827 Mdot
.49694 .2246 Mdot
.76916 .51435 Mdot
.6505 .65889 Mdot
.44936 .23132 Mdot
.4561 .67934 Mdot
.54618 .23608 Mdot
.48244 .49373 Mdot
.84025 .38438 Mdot
.52012 .81865 Mdot
.858 .45708 Mdot
.31994 .57936 Mdot
.3526 .40186 Mdot
.78312 .52564 Mdot
.29594 .54515 Mdot
.60704 .29921 Mdot
.84791 .57119 Mdot
.60247 .31198 Mdot
.36218 .6555 Mdot
.40713 .72196 Mdot
.1838 .49553 Mdot
.60727 .49878 Mdot
.62367 .27549 Mdot
.45887 .46439 Mdot
.82527 .32634 Mdot
.80658 .60411 Mdot
.40819 .79491 Mdot
.58793 .82588 Mdot
.70179 .49254 Mdot
.63236 .4345 Mdot
.58695 .63736 Mdot
.63037 .82002 Mdot
.37984 .60936 Mdot
.51547 .86476 Mdot
.62589 .81722 Mdot
.39296 .66599 Mdot
.81559 .30225 Mdot
.25123 .688 Mdot
.21061 .45345 Mdot
.35498 .288 Mdot
.66849 .25063 Mdot
.46119 .65238 Mdot
.31465 .68875 Mdot
.69941 .46702 Mdot
.48733 .81897 Mdot
.69147 .77318 Mdot
.53222 .27069 Mdot
.56092 .60393 Mdot
.42305 .69921 Mdot
.55355 .37397 Mdot
.40467 .62022 Mdot
.67475 .30092 Mdot
.5498 .36195 Mdot
.85875 .4756 Mdot
.30142 .32565 Mdot
.40002 .16362 Mdot
.46187 .27023 Mdot
.19063 .58114 Mdot
.72665 .67185 Mdot
.59034 .29296 Mdot
.41859 .54385 Mdot
.42751 .7507 Mdot
.38212 .45967 Mdot
.47593 .60046 Mdot
.33489 .40414 Mdot
.62152 .37742 Mdot
.48104 .63174 Mdot
.64998 .74668 Mdot
.48008 .2683 Mdot
.81452 .51408 Mdot
.51959 .386 Mdot
.37279 .57588 Mdot
.53815 .22533 Mdot
.50644 .24458 Mdot
.61839 .80576 Mdot
.42071 .64034 Mdot
.45704 .82405 Mdot
.42563 .62108 Mdot
.47492 .44186 Mdot
.20662 .55545 Mdot
.44656 .48555 Mdot
.53011 .24613 Mdot
.40716 .35412 Mdot
.31638 .74152 Mdot
.54522 .83421 Mdot
.30505 .44685 Mdot
.4711 .249 Mdot
.32562 .49341 Mdot
.49552 .82268 Mdot
.78767 .5248 Mdot
.33461 .70723 Mdot
.29188 .66204 Mdot
.83068 .34468 Mdot
.65986 .47175 Mdot
.53892 .2611 Mdot
.59776 .57463 Mdot
.75948 .43702 Mdot
.80187 .3573 Mdot
.42742 .59184 Mdot
.53631 .83863 Mdot
.43216 .72579 Mdot
.60431 .45859 Mdot
.53053 .68125 Mdot
.56073 .63871 Mdot
.32444 .46872 Mdot
.36652 .37608 Mdot
.36627 .49749 Mdot
.63248 .30193 Mdot
.27879 .54894 Mdot
.78795 .49772 Mdot
.67165 .57682 Mdot
.49242 .3745 Mdot
.67883 .59755 Mdot
.48251 .73891 Mdot
.50389 .61733 Mdot
.70476 .7743 Mdot
.45717 .34746 Mdot
.23753 .66443 Mdot
.51792 .81282 Mdot
.54117 .52383 Mdot
.66267 .3954 Mdot
.37688 .75979 Mdot
.85494 .42411 Mdot
.58036 .84319 Mdot
.61492 .78319 Mdot
.78331 .65425 Mdot
.32139 .79939 Mdot
.77437 .31174 Mdot
.26403 .61189 Mdot
.60141 .57041 Mdot
.23656 .7697 Mdot
.68208 .48 Mdot
.3301 .29889 Mdot
.29723 .54062 Mdot
.70943 .35881 Mdot
.41246 .59956 Mdot
.51182 .40079 Mdot
.68775 .52549 Mdot
.40222 .58214 Mdot
.46254 .45965 Mdot
.83404 .6181 Mdot
.84362 .38532 Mdot
.84337 .59966 Mdot
.53572 .77961 Mdot
.77851 .67538 Mdot
.83467 .43439 Mdot
.24526 .33024 Mdot
.80079 .40492 Mdot
.3849 .44673 Mdot
.5524 .28379 Mdot
.258 .68918 Mdot
.62029 .51645 Mdot
.48677 .70921 Mdot
.31391 .63014 Mdot
.83289 .38732 Mdot
.71313 .77011 Mdot
.24761 .48791 Mdot
.27722 .38023 Mdot
.58973 .39839 Mdot
.5509 .24732 Mdot
.32488 .42834 Mdot
.56486 .72637 Mdot
.66452 .77106 Mdot
.832 .42297 Mdot
.50051 .25389 Mdot
.71391 .55265 Mdot
.62046 .77146 Mdot
.25733 .66417 Mdot
.75261 .65645 Mdot
.78984 .37112 Mdot
.40936 .64479 Mdot
.3019 .64683 Mdot
.42714 .56998 Mdot
.55211 .71884 Mdot
.76162 .57581 Mdot
.47845 .22676 Mdot
.63165 .46719 Mdot
.53908 .2732 Mdot
.50836 .52898 Mdot
.80079 .39886 Mdot
.46611 .219 Mdot
.52784 .27513 Mdot
.63709 .76874 Mdot
.8183 .63477 Mdot
.4829 .80039 Mdot
.62993 .21571 Mdot
.62659 .69713 Mdot
.33573 .38853 Mdot
.35655 .37891 Mdot
.52003 .83188 Mdot
.80235 .67253 Mdot
.54607 .84149 Mdot
.34262 .72734 Mdot
.75456 .41112 Mdot
.58903 .652 Mdot
.4573 .21376 Mdot
.66694 .60592 Mdot
.67294 .76822 Mdot
.46257 .56062 Mdot
.60297 .66263 Mdot
.44173 .70854 Mdot
.31449 .34331 Mdot
.39751 .25113 Mdot
.27174 .41178 Mdot
.48022 .3861 Mdot
.22989 .42323 Mdot
.34342 .64471 Mdot
.33747 .72149 Mdot
.54538 .24091 Mdot
.65673 .47292 Mdot
.74472 .31473 Mdot
.34683 .47686 Mdot
.35649 .42874 Mdot
.76517 .54266 Mdot
.40614 .61314 Mdot
.32252 .50632 Mdot
.64553 .43075 Mdot
.63509 .82651 Mdot
.2869 .70213 Mdot
.32267 .43434 Mdot
.51473 .21894 Mdot
.76062 .35349 Mdot
.49694 .65649 Mdot
.62297 .57546 Mdot
.75537 .67494 Mdot
.59435 .41855 Mdot
.52958 .22544 Mdot
.23255 .41389 Mdot
.7932 .46646 Mdot
.46457 .44971 Mdot
.37988 .77587 Mdot
.27766 .30274 Mdot
.50721 .61527 Mdot
.34978 .66097 Mdot
.39889 .60233 Mdot
.15726 .58057 Mdot
.5754 .75438 Mdot
.38577 .68321 Mdot
.76047 .65865 Mdot
.58157 .6252 Mdot
.38189 .57443 Mdot
.53104 .28377 Mdot
.69724 .39526 Mdot
.28917 .34611 Mdot
.76587 .57935 Mdot
.32418 .3565 Mdot
.66493 .6539 Mdot
.78058 .65145 Mdot
.83292 .55184 Mdot
.3072 .2182 Mdot
.38659 .5605 Mdot
.77315 .47452 Mdot
.77556 .46403 Mdot
.34159 .57214 Mdot
.38928 .65312 Mdot
.47214 .32342 Mdot
.75804 .70094 Mdot
.47158 .54205 Mdot
.55033 .70528 Mdot
.54632 .50467 Mdot
.67955 .34674 Mdot
.79229 .44049 Mdot
.4572 .23646 Mdot
.76366 .64207 Mdot
.26293 .40754 Mdot
.68958 .24976 Mdot
.37064 .48945 Mdot
.31385 .30581 Mdot
.45719 .21353 Mdot
.53 .36575 Mdot
.20536 .57619 Mdot
.67031 .73349 Mdot
.4551 .41244 Mdot
.85614 .57146 Mdot
.61855 .80008 Mdot
.4703 .60436 Mdot
.69109 .43007 Mdot
.42075 .43805 Mdot
.36636 .40098 Mdot
.28585 .6259 Mdot
.42247 .79087 Mdot
.72644 .26124 Mdot
.47982 .27778 Mdot
.33466 .38456 Mdot
.22849 .41592 Mdot
.2379 .66429 Mdot
.78204 .54419 Mdot
.70741 .71792 Mdot
.49504 .54548 Mdot
.26317 .6925 Mdot
.53632 .64961 Mdot
.53575 .70129 Mdot
.6524 .69514 Mdot
.83619 .44302 Mdot
.44045 .3217 Mdot
.42128 .77377 Mdot
.78806 .39779 Mdot
.43442 .37255 Mdot
.39798 .73607 Mdot
.74021 .6711 Mdot
.42644 .1701 Mdot
.44752 .67816 Mdot
.8246 .64619 Mdot
.37315 .49771 Mdot
.42992 .77191 Mdot
.80643 .35462 Mdot
.52756 .14505 Mdot
.55346 .73445 Mdot
.85751 .49039 Mdot
.52393 .66346 Mdot
.76486 .65214 Mdot
.61164 .65629 Mdot
.51652 .49328 Mdot
.31195 .55001 Mdot
.75292 .70599 Mdot
.7243 .42852 Mdot
.78348 .59336 Mdot
.28197 .62979 Mdot
.77983 .68477 Mdot
.47285 .49758 Mdot
.15747 .56872 Mdot
.6517 .53675 Mdot
.28185 .73493 Mdot
.2658 .637 Mdot
.32779 .41139 Mdot
.52288 .26164 Mdot
.15943 .5339 Mdot
.21644 .36923 Mdot
.27102 .60542 Mdot
.53604 .31356 Mdot
.38869 .76804 Mdot
.50826 .21516 Mdot
.67105 .77369 Mdot
.19095 .62167 Mdot
.78465 .45531 Mdot
.38473 .70287 Mdot
.51444 .79985 Mdot
.42231 .79508 Mdot
.6329 .72529 Mdot
.77368 .53598 Mdot
.52396 .72845 Mdot
.32774 .34841 Mdot
.13735 .37956 Mdot
.54361 .58472 Mdot
.45936 .31861 Mdot
.85066 .4277 Mdot
.65815 .7758 Mdot
.45572 .55764 Mdot
.19573 .56341 Mdot
.35508 .25758 Mdot
.57477 .28764 Mdot
.41081 .37627 Mdot
.78384 .67983 Mdot
.5996 .27622 Mdot
.85163 .53559 Mdot
.46545 .83827 Mdot
.23855 .42686 Mdot
.45487 .33815 Mdot
.69694 .46318 Mdot
.48069 .31801 Mdot
.53125 .31951 Mdot
.84711 .45002 Mdot
.32144 .30319 Mdot
.56825 .47686 Mdot
.68038 .6626 Mdot
.7329 .6403 Mdot
.35256 .34658 Mdot
.26174 .70031 Mdot
.4068 .77738 Mdot
.4607 .26054 Mdot
.60734 .77599 Mdot
.53692 .25302 Mdot
.2441 .38483 Mdot
.46916 .21133 Mdot
.45072 .61483 Mdot
.71143 .48269 Mdot
.61672 .47897 Mdot
.82739 .48631 Mdot
.71627 .69274 Mdot
.32167 .74426 Mdot
.64243 .22578 Mdot
.42418 .74982 Mdot
.50165 .30853 Mdot
.80431 .49928 Mdot
.45576 .65457 Mdot
.72436 .45121 Mdot
.38465 .25849 Mdot
.30885 .32244 Mdot
.68641 .72491 Mdot
.50922 .42345 Mdot
.69386 .77368 Mdot
.47455 .22932 Mdot
.81323 .45512 Mdot
.58534 .40427 Mdot
.29524 .51759 Mdot
.21379 .50911 Mdot
.68212 .26376 Mdot
.51193 .60499 Mdot
.82649 .3315 Mdot
.32856 .58321 Mdot
.85686 .55493 Mdot
.62587 .61212 Mdot
.32927 .21967 Mdot
.67907 .7467 Mdot
.50155 .55619 Mdot
.54273 .49024 Mdot
.38114 .77949 Mdot
.44855 .77286 Mdot
.50694 .81033 Mdot
.42673 .58083 Mdot
.67395 .51652 Mdot
.57526 .47574 Mdot
.55638 .70976 Mdot
.81896 .52832 Mdot
.41202 .45781 Mdot
.60263 .4815 Mdot
.5245 .35626 Mdot
.60245 .67492 Mdot
.52433 .8287 Mdot
.68055 .71312 Mdot
.44757 .48007 Mdot
.55397 .24618 Mdot
.83707 .42029 Mdot
.63203 .80831 Mdot
.43272 .55757 Mdot
.33525 .40839 Mdot
.64527 .57937 Mdot
.76508 .32185 Mdot
.80605 .59323 Mdot
.71523 .65254 Mdot
.49802 .67812 Mdot
.49658 .2273 Mdot
.86218 .60628 Mdot
.84183 .38437 Mdot
.6584 .22663 Mdot
.54949 .50076 Mdot
.30513 .60695 Mdot
.3137 .27684 Mdot
.81324 .45978 Mdot
.29185 .74773 Mdot
.61798 .79132 Mdot
.53566 .25847 Mdot
.468 .16463 Mdot
.19698 .41934 Mdot
.59037 .44499 Mdot
.21472 .51072 Mdot
.31419 .52627 Mdot
.59311 .66088 Mdot
.56874 .30205 Mdot
.57916 .44255 Mdot
.64753 .62204 Mdot
.39231 .77006 Mdot
.44105 .73883 Mdot
.81349 .45077 Mdot
.2837 .3238 Mdot
.33503 .418 Mdot
.80826 .54923 Mdot
.38988 .64515 Mdot
.78205 .4469 Mdot
.76604 .35989 Mdot
.58196 .44823 Mdot
.68329 .49154 Mdot
.48504 .44693 Mdot
.50631 .63452 Mdot
.5268 .64881 Mdot
.55208 .18255 Mdot
.6162 .29825 Mdot
.3221 .58136 Mdot
.17708 .46152 Mdot
.37902 .55917 Mdot
.79057 .69574 Mdot
.56693 .72637 Mdot
.22347 .42952 Mdot
.54158 .62542 Mdot
.71149 .57227 Mdot
.54739 .16816 Mdot
.31487 .35175 Mdot
.6624 .28477 Mdot
.30563 .63461 Mdot
.34154 .64251 Mdot
.54839 .63567 Mdot
.45383 .74174 Mdot
.26711 .38566 Mdot
.22109 .6494 Mdot
.75902 .34823 Mdot
.36649 .55667 Mdot
.58853 .4606 Mdot
.36858 .51919 Mdot
.695 .78055 Mdot
.6773 .50581 Mdot
.83602 .35597 Mdot
.41108 .33819 Mdot
.7548 .30166 Mdot
.52607 .83217 Mdot
.47953 .66176 Mdot
.55343 .4985 Mdot
.73947 .50349 Mdot
.44225 .46295 Mdot
.33157 .39956 Mdot
.34453 .63049 Mdot
.80311 .41698 Mdot
.63114 .31979 Mdot
.58483 .23969 Mdot
.6298 .57529 Mdot
.21936 .61828 Mdot
.27312 .7057 Mdot
.3486 .64668 Mdot
.62039 .40064 Mdot
.76629 .47969 Mdot
.53188 .41698 Mdot
.52681 .35902 Mdot
.83111 .48102 Mdot
.2901 .36635 Mdot
.33535 .57807 Mdot
.65816 .22883 Mdot
.55071 .35829 Mdot
.59319 .84577 Mdot
.43514 .50461 Mdot
.50271 .33767 Mdot
.52401 .3933 Mdot
.3731 .76622 Mdot
.25171 .37557 Mdot
.69692 .73599 Mdot
.54186 .22876 Mdot
.51581 .47031 Mdot
.53044 .27653 Mdot
.45957 .47318 Mdot
.67665 .67335 Mdot
.26771 .72005 Mdot
.47874 .1647 Mdot
.23167 .54595 Mdot
.45821 .68719 Mdot
.3746 .66207 Mdot
.24186 .669 Mdot
.32721 .57993 Mdot
.64657 .38473 Mdot
.29248 .40255 Mdot
.67765 .74874 Mdot
.64308 .81375 Mdot
.61735 .80587 Mdot
.46676 .30793 Mdot
.72426 .64914 Mdot
.37152 .27455 Mdot
.39169 .52001 Mdot
.51097 .55557 Mdot
.44341 .46469 Mdot
.35308 .34954 Mdot
.44958 .57825 Mdot
.3375 .74815 Mdot
.41517 .32566 Mdot
.74684 .70645 Mdot
.59111 .84448 Mdot
.80304 .64553 Mdot
.76116 .57176 Mdot
.39511 .62 Mdot
.85142 .41195 Mdot
.2316 .37791 Mdot
.65975 .78365 Mdot
.26397 .63273 Mdot
.169 .60683 Mdot
.80989 .36995 Mdot
.6578 .74448 Mdot
.35594 .68848 Mdot
.40409 .81478 Mdot
.53135 .8225 Mdot
.15901 .57185 Mdot
.35437 .30394 Mdot
.51664 .82732 Mdot
.82042 .32232 Mdot
.25316 .60955 Mdot
.44361 .7649 Mdot
.20853 .50744 Mdot
.33896 .31079 Mdot
.19848 .62364 Mdot
.36441 .43021 Mdot
.6829 .45629 Mdot
.69486 .33015 Mdot
.52535 .2558 Mdot
.49257 .43974 Mdot
.18839 .6073 Mdot
.5299 .32241 Mdot
.49092 .29893 Mdot
.7565 .45015 Mdot
.81056 .38164 Mdot
.25922 .37377 Mdot
.39299 .4839 Mdot
.31996 .64192 Mdot
.6448 .34003 Mdot
.42443 .26288 Mdot
.40777 .44013 Mdot
.52396 .5703 Mdot
.43701 .31568 Mdot
.83228 .62548 Mdot
.68726 .37077 Mdot
.60577 .53901 Mdot
.39913 .58571 Mdot
.4102 .78685 Mdot
.79403 .55335 Mdot
.41093 .72081 Mdot
.17776 .58235 Mdot
.30005 .34626 Mdot
.78738 .64051 Mdot
.43223 .73771 Mdot
.48431 .24625 Mdot
.50326 .1843 Mdot
.63678 .62401 Mdot
.3043 .55238 Mdot
.8442 .45296 Mdot
.409 .74431 Mdot
.38012 .65406 Mdot
.62528 .75434 Mdot
.68514 .66756 Mdot
.40179 .75501 Mdot
.51694 .81207 Mdot
.7842 .48152 Mdot
.226 .4654 Mdot
.82764 .5573 Mdot
.69391 .4633 Mdot
.50481 .25815 Mdot
.59668 .75538 Mdot
.19837 .62725 Mdot
.53053 .41912 Mdot
.7121 .75068 Mdot
.51328 .54816 Mdot
.63342 .25804 Mdot
.44576 .44225 Mdot
.27092 .33921 Mdot
.35067 .7525 Mdot
.60895 .76961 Mdot
.40269 .66681 Mdot
.38001 .64634 Mdot
.30128 .7238 Mdot
.68136 .42079 Mdot
.58713 .2826 Mdot
.37733 .28694 Mdot
.30163 .67823 Mdot
.64106 .37353 Mdot
.48054 .72009 Mdot
.39714 .34095 Mdot
.63854 .24883 Mdot
.75248 .61146 Mdot
.29418 .57143 Mdot
.26213 .61091 Mdot
.82845 .4903 Mdot
.7709 .56712 Mdot
.31583 .74695 Mdot
.27361 .62579 Mdot
.4533 .80825 Mdot
.20969 .40098 Mdot
.40817 .69724 Mdot
.38299 .36181 Mdot
.64634 .38472 Mdot
.35214 .5711 Mdot
.82183 .52996 Mdot
.39384 .53386 Mdot
.64132 .26167 Mdot
.48298 .57657 Mdot
.78097 .52503 Mdot
.57462 .40375 Mdot
.52911 .82935 Mdot
.40412 .81499 Mdot
.54544 .23986 Mdot
.63975 .58709 Mdot
.52776 .66995 Mdot
.44527 .67315 Mdot
.72194 .72737 Mdot
.44078 .58668 Mdot
.33838 .48223 Mdot
.4459 .69999 Mdot
.31115 .47747 Mdot
.48777 .83576 Mdot
.57002 .25204 Mdot
.50983 .562 Mdot
.3273 .44459 Mdot
.4984 .72581 Mdot
.47572 .72837 Mdot
.70555 .36567 Mdot
.2466 .36055 Mdot
.56616 .58315 Mdot
.56897 .49876 Mdot
.37312 .3499 Mdot
.30881 .27959 Mdot
.82023 .56118 Mdot
.45099 .55264 Mdot
.50793 .54693 Mdot
.78582 .40014 Mdot
.60028 .26883 Mdot
.24102 .26036 Mdot
.85419 .58673 Mdot
.44379 .44332 Mdot
.5471 .4756 Mdot
.58253 .24476 Mdot
.62578 .48671 Mdot
.27462 .40385 Mdot
.82874 .50152 Mdot
.5969 .60041 Mdot
.75802 .419 Mdot
.45501 .72704 Mdot
.3705 .77294 Mdot
.69804 .27168 Mdot
.59154 .65619 Mdot
.79968 .68767 Mdot
.6108 .79241 Mdot
.35085 .74523 Mdot
.18872 .30771 Mdot
.32727 .73321 Mdot
.45003 .51026 Mdot
.74993 .46058 Mdot
.81623 .64181 Mdot
.54787 .5085 Mdot
.75261 .43024 Mdot
.25999 .60199 Mdot
.54387 .23552 Mdot
.4942 .27888 Mdot
.38333 .70429 Mdot
.31046 .71845 Mdot
.15067 .55242 Mdot
.713 .56968 Mdot
.57757 .18092 Mdot
.25384 .40284 Mdot
.83482 .56124 Mdot
.55353 .73252 Mdot
.45644 .16683 Mdot
.63245 .8182 Mdot
.54712 .29317 Mdot
.1959 .60867 Mdot
.7019 .41289 Mdot
.58754 .22264 Mdot
.29548 .28229 Mdot
.53382 .75353 Mdot
.29501 .36494 Mdot
.69597 .57725 Mdot
.40932 .67327 Mdot
.53491 .27449 Mdot
.3149 .50229 Mdot
.51215 .55946 Mdot
.8465 .49063 Mdot
.16722 .53785 Mdot
.51326 .22344 Mdot
.77352 .41757 Mdot
.60123 .22952 Mdot
.80763 .56685 Mdot
.75863 .62468 Mdot
.53848 .40655 Mdot
.77101 .28124 Mdot
.85843 .47629 Mdot
.41702 .69742 Mdot
.36543 .4059 Mdot
.60284 .84575 Mdot
.55281 .41135 Mdot
.26605 .60554 Mdot
.551 .80945 Mdot
.47438 .27768 Mdot
.4195 .31685 Mdot
.36307 .38847 Mdot
.35512 .28326 Mdot
.35406 .68554 Mdot
.31672 .50783 Mdot
.72419 .30387 Mdot
.51848 .22165 Mdot
.17067 .54234 Mdot
.69834 .26164 Mdot
.44496 .50145 Mdot
.33498 .58682 Mdot
.82311 .63474 Mdot
.31402 .39632 Mdot
.35158 .4727 Mdot
.21028 .47165 Mdot
.43529 .57786 Mdot
.71883 .50173 Mdot
.33601 .40478 Mdot
.49741 .6532 Mdot
.52082 .2604 Mdot
.81313 .47487 Mdot
.31166 .55361 Mdot
.81764 .30144 Mdot
.52703 .83601 Mdot
.36072 .55649 Mdot
.27038 .58104 Mdot
.5887 .43848 Mdot
.80825 .63473 Mdot
.70721 .55584 Mdot
.76237 .35558 Mdot
.1695 .46199 Mdot
.55551 .21583 Mdot
.45503 .37452 Mdot
.53559 .78223 Mdot
.66336 .79532 Mdot
.15807 .49226 Mdot
.69436 .77263 Mdot
.44428 .33237 Mdot
.34998 .39403 Mdot
.45869 .1329 Mdot
.77171 .65158 Mdot
.48675 .37516 Mdot
.37003 .682 Mdot
.37592 .67223 Mdot
.4411 .45213 Mdot
.45263 .75726 Mdot
.43116 .24801 Mdot
.49608 .28554 Mdot
.75634 .70104 Mdot
.39484 .58232 Mdot
.54326 .5269 Mdot
.57336 .60533 Mdot
.53591 .51963 Mdot
.41762 .49211 Mdot
.58348 .61227 Mdot
.50013 .29329 Mdot
.55469 .42999 Mdot
.65102 .56318 Mdot
.33558 .33269 Mdot
.50739 .70746 Mdot
.33915 .33897 Mdot
.49606 .32157 Mdot
.29629 .64924 Mdot
.21643 .36823 Mdot
.52938 .32047 Mdot
.54679 .34119 Mdot
.51675 .82288 Mdot
.28873 .76785 Mdot
.53618 .56266 Mdot
.31343 .57237 Mdot
.44349 .50786 Mdot
.24238 .37289 Mdot
.21799 .46777 Mdot
.64332 .5486 Mdot
.47314 .73316 Mdot
.41713 .32766 Mdot
.32352 .43708 Mdot
.57882 .63033 Mdot
.84739 .62353 Mdot
.35629 .40571 Mdot
.25443 .43626 Mdot
.70574 .74082 Mdot
.78564 .44363 Mdot
.39108 .30034 Mdot
.43904 .46634 Mdot
.47321 .50802 Mdot
.55638 .42343 Mdot
.35324 .50959 Mdot
.79534 .43272 Mdot
.81147 .60226 Mdot
.41573 .28821 Mdot
.24595 .43416 Mdot
.43608 .39976 Mdot
.59098 .34176 Mdot
.49673 .62993 Mdot
.55405 .1906 Mdot
.64565 .27764 Mdot
.63255 .80468 Mdot
.50629 .32144 Mdot
.47892 .27728 Mdot
.1962 .49503 Mdot
.8523 .54843 Mdot
.44205 .68459 Mdot
.23438 .42991 Mdot
.46046 .59678 Mdot
.63708 .72898 Mdot
.53446 .31195 Mdot
.55697 .63059 Mdot
.38053 .33286 Mdot
.35441 .68163 Mdot
.74912 .7277 Mdot
.31416 .35572 Mdot
.61189 .56194 Mdot
.68861 .72495 Mdot
.21087 .40382 Mdot
.5419 .49044 Mdot
.1562 .34777 Mdot
.71879 .53809 Mdot
.8038 .68054 Mdot
.80047 .47458 Mdot
.52175 .41926 Mdot
.3866 .76462 Mdot
.49242 .42204 Mdot
.65333 .50274 Mdot
.81009 .62249 Mdot
.37456 .51442 Mdot
.4016 .6988 Mdot
.37837 .44172 Mdot
.47126 .52326 Mdot
.34911 .49227 Mdot
.71282 .66941 Mdot
.68877 .46919 Mdot
.43257 .56263 Mdot
.75757 .63399 Mdot
.55714 .42082 Mdot
.18659 .63984 Mdot
.84797 .45077 Mdot
.75313 .67819 Mdot
.74114 .62763 Mdot
.33527 .21045 Mdot
.30991 .63945 Mdot
.38024 .52264 Mdot
.64466 .60708 Mdot
.36488 .27774 Mdot
.40364 .74983 Mdot
.81007 .46461 Mdot
.43874 .81014 Mdot
.53294 .41291 Mdot
.11233 .42437 Mdot
.53991 .28982 Mdot
.45119 .5394 Mdot
.38522 .74059 Mdot
.73891 .71435 Mdot
.75389 .37315 Mdot
.44377 .82572 Mdot
.56481 .74105 Mdot
.45472 .47513 Mdot
.28063 .3053 Mdot
.66808 .24043 Mdot
.70491 .6528 Mdot
.56705 .17498 Mdot
.72169 .67531 Mdot
.44568 .25061 Mdot
.6037 .7683 Mdot
.38305 .55888 Mdot
.41089 .57329 Mdot
.56746 .72053 Mdot
.48269 .70543 Mdot
.29113 .60453 Mdot
.80114 .6127 Mdot
.43673 .20296 Mdot
.77936 .37581 Mdot
.78557 .6565 Mdot
.63135 .679 Mdot
.37346 .6646 Mdot
.52522 .32199 Mdot
.65707 .30497 Mdot
.62665 .46636 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`2Aooooo`;o0000]_ooool001cooooo00?o0000ooooooooool0TOooool2o`000;Kooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`2Eooooo`;o00004Oooool2o`0009oooooo000Looooo`03o`00
0?oooooooooo09Gooooo0_l0000Aooooo`;o0000Woooool001cooooo0_l0003ooooood_ooooo000L
ooooo`03o`000?oooooooooo0:kooooo0_l0002Iooooo`007?ooool00ol0003oooooooooo`2=oooo
o`;o00007oooool2o`0009Wooooo000Looooo`03o`000?oooooooooo07Gooooo0_l0000Eooooo`?o
0000^_ooool001cooooo00?o0000ooooooooool0MOooool2o`0000Oooooo0_l0000<ooooo`?o0000
1Oooool6o`00013ooooo0_l0002Mooooo`007?ooool00ol0003oooooooooo`1nooooo`;o00004Ooo
ool2o`000003ooooool0003o000000Co00001_ooool5o`0000Gooooo0_l00002ooooo`;o0000VOoo
ool001cooooo00?o0000ooooooooool0Qoooool2o`0000Sooooo0_l0000=ooooo`Go00002Oooool2
o`0009Wooooo000Looooo`03o`000?oooooooooo08Oooooo0_l0000[ooooo`;o0000Toooool001co
oooo00?o0000ooooooooool0Z_ooool2o`0000Sooooo0_l0002Cooooo`007?ooool00ol0003ooooo
ooooo`1aooooo`;o0000=oooool3o`0000_ooooo0_l0002?ooooo`007?ooool00ol0003ooooooooo
o`1Yooooo`;o00001_ooool2o`0002gooooo0_l00009ooooo`;o00000oooool2o`0000Kooooo0ol0
002>ooooo`007?ooool00ol0003oooooooooo`1Yooooo`;o0000=?ooool3o`0000kooooo0_l00002
ooooo`;o00000oooool2o`0008kooooo000Looooo`03o`000?oooooooooo09oooooo0_l00009oooo
o`;o00001?ooool2o`0000;ooooo0_l0000@ooooo`;o0000POooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo073ooooo0_l00005
ooooo`;o00006oooool2o`0001Cooooo0_l00004ooooo`;o00005?ooool2o`00087ooooo00001_oo
ooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1_ooool00ol0003oooooooooo`1`ooooo`;o00001Oooool2o`0001_ooooo1?l0000Aooooo`;o0000
3_ooool2o`0000?ooooo0_l00029ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0SOooool3o`0000Cooooo1?l0
0004ooooo`?o00001oooool2o`000003ooooool0003o000000kooooo0_l00003ooooo`;o0000ROoo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06
ooooo`?o0000R_ooool2o`000004ooooool0003o0000o`0000Cooooo0ol00005ooooo`Ko00000ooo
ool3o`0000Oooooo0_l0000=ooooo`;o0000ROooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo08[ooooo1?l0000?
ooooo`Go00000oooool3o`0000Gooooo1?l0000=ooooo`;o0000ROooool00003ooooool@413ooooo
00;ooooo00?o410@ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
08cooooo0_l0000;ooooo`;o00000_ooool3o`0000Gooooo0_l00002ooooo`;o00000_ooool3o`00
0003ooooool0003o000009Kooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000
okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo06;ooooo0_l000000ooooooo0000o`00
0002ooooo`;o0000:_ooool2o`0000;ooooo0_l0000;ooooo`;o000000?oooooo`000?l000000_oo
ool6o`0000Cooooo0_l0002@ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Rooooo`Go00000_ooool4o`0002Co
oooo0_l00002ooooo`?o00002Oooool2o`0000?ooooo0_l00004ooooo`;o00000_ooool9o`00093o
oooo000Looooo`03o`000?oooooooooo05Wooooo0_l00005ooooo`;o000000?oooooo`000?l00000
1_ooool2o`0002?ooooo2Ol00008ooooo`;o00002Oooool3o`000003ooooool0003o000000Go0000
0_ooool2o`0000kooooo0_l0001nooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o00001Ooo
ool2o`0000Gooooo0_l0000Wooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000[ooooo
0_l00008ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000?ooooo1?l0000<ooooo`;o
00006Oooool2o`0006?ooooo000Looooo`03o`000?oooooooooo06Oooooo0_l0000Nooooo`;o0000
1oooool2o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`;o00000oooool4o`0000Wooooo
0_l00009ooooo`;o00009oooool2o`0006?ooooo000Looooo`03o`000?oooooooooo08Oooooo0_l0
0007ooooo`;o000000?oooooo`000?l000000oooool2o`0000Cooooo0_l00003ooooo`Co000000Co
ooooo`000?l0003ooooo0_l0000>ooooo`;o00004?ooool2o`0000?ooooo0_l0001eooooo`007?oo
ool00ol0003oooooooooo`27ooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0
003o000000Go00001?ooool2o`0000Sooooo0_l000001?oooooo0000o`000?l0000Booooo`Co0000
2Oooool4o`000003ooooool0003o000007Gooooo000Looooo`03o`000?oooooooooo05Oooooo0_l0
0002ooooo`;o0000:_ooool2o`000003ooooool0003o000000;ooooo1?l00003ooooo`?o00004ooo
ool3o`0001;ooooo1Ol0000:ooooo`;o000000?oooooo`000?l00000MOooool001cooooo00?o0000
ooooooooool0Eoooool6o`0002_ooooo0_l00004ooooo`;o000000?oooooo`000?l000006?ooool5
o`0001?ooooo0_l00024ooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o0000:Oooool2o`00
00;ooooo1?l00005ooooo`;o00001?ooool2o`00017ooooo1_l00002ooooo`;o00000_ooool2o`00
00;ooooo0_l00007ooooo`Co0000P_ooool001cooooo00?o0000ooooooooool0Doooool2o`0002oo
oooo0_l00003ooooo`?o00001?ooool2o`0000Gooooo0_l0000Aooooo`Go00000oooool2o`0000;o
oooo0_l00002ooooo`;o00000oooool3o`0000?ooooo0_l0000>ooooo`;o0000L_ooool001cooooo
00?o0000ooooooooool0Doooool2o`0002_ooooo0_l0000>ooooo`?o00001oooool2o`0000Gooooo
0_l00005ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000002o`0000?ooooo
1?l00004ooooo`?o00001_ooool2o`0000_ooooo0_l0001booooo`007?ooool00ol0003ooooooooo
o`1mooooo`;o000000?oooooo`000?l000001Oooool3o`0000Oooooo0_l00002ooooo`;o00000ooo
ool2o`0000Gooooo0_l00005ooooo`Co00000oooool5o`0000;ooooo1Ol00006ooooo`;o00001Ooo
ool3o`000003ooooool0003o000007_ooooo000Looooo`;o0000N?ooool2o`000003ooooool0003o
000000Oo00000oooool4o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`;o00004oooool2
o`0000?ooooo0_l00003ooooo`Co00002Oooool2o`0000;ooooo0_l00002ooooo`;o000000?ooooo
o`000?l000001oooool2o`0000Gooooo0_l0001[ooooo`007?ooool00ol0003oooooooooo`1@oooo
o`;o00008?oooolAo`0000;ooooo1Ol00002ooooo`?o000000?oooooo`000?l000003Oooool2o`00
00Cooooo0_l00004ooooo`;o00001_ooool5o`0000gooooo0_l000001?oooooo0000o`000?ooool2
o`0000Sooooo0_l00005ooooo`;o0000Joooool001cooooo00?o0000ooooooooool0D?ooool4o`00
01Wooooo2_l000000ooooooo0000o`000003o`0000Sooooo0ol00004ooooo`Co00003oooool3o`00
00?ooooo2?l00006ooooo`;o00004oooool5o`0007cooooo000Looooo`03o`000?oooooooooo04_o
oooo0_l00005ooooo`;o00006Oooool5o`0000Kooooo0ol00003ooooo`;o00002_ooool2o`0000;o
oooo0_l00002ooooo`;o00003?ooool2o`0000?ooooo2?l0000@ooooo`Go00000_ooool2o`0000Co
oooo0_l00002ooooo`;o00003oooool2o`0000Oooooo0_l0001Oooooo`007?ooool00ol0003ooooo
ooooo`1;ooooo`Co00007?ooool4o`0000[ooooo0_l00003ooooo`;o00001?ooool4o`0000;ooooo
0_l00006ooooo`;o00004Oooool5o`000003ooooool0003o000000kooooo1ol00002ooooo`;o0000
1oooool3o`0000[ooooo0_l00003ooooo`;o00001oooool2o`0005oooooo000Looooo`03o`000?oo
oooooooo04gooooo0_l0000Looooo`;o00003?ooool2o`0000Wooooo1?l00008ooooo`;o00005?oo
ool2o`0000cooooo0_l00005ooooo`;o00000oooool2o`0000_ooooo0_l0000;ooooo`?o0000K?oo
ool001cooooo00?o0000ooooooooool0C?ooool2o`00043ooooo1_l00004ooooo`;o00003?ooool2
o`000003ooooool0003o000000Gooooo0_l00002ooooo`;o000000?oooooo`000?l000001Ol00000
1Ooooooo0000o`000?l0003ooooo00;o00005_ooool2o`0000oooooo0_l0001Kooooo`007?ooool0
0ol0003oooooooooo`1<ooooo`;o000000?oooooo`000?l00000?Oooool2o`0000;ooooo0_l00004
ooooo`?o000000?oooooo`000?l000002oooool4o`0000?ooooo0_l00002ooooo`;o000000?ooooo
o`000?l000000_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l000000ooooooo0000o`00
0003ooooo`;o00004_ooool2o`0000_ooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`1?
ooooo`;o00004Oooool2o`00017ooooo0_l0000Rooooo`;o000000?oooooo`000?l000002_ooool5
o`0000;ooooo0_l00003ooooo`;o00002?ooool3o`0000Gooooo0ol00002ooooo`;o00004Oooool3
o`0006Sooooo000Looooo`03o`000?oooooooooo057ooooo0_l0000;ooooo`;o000000Goooooo`00
0?l0003o0000ooooo`02o`0000cooooo1?l0000;ooooo`Co00004?ooool4o`0000?ooooo1?l00007
ooooo`Co00000oooool2o`0000Gooooo0_l00006ooooo`?o00000oooool2o`000004ooooool0003o
0000o`0000Cooooo0_l00008ooooo`;o00001?ooool4o`0006Oooooo000Looooo`03o`000?oooooo
oooo057ooooo0_l00009ooooo`Oo00000_ooool2o`0000cooooo0_l0000=ooooo`Co00001?ooool2
o`0000[ooooo1?l00003ooooo`Co00005Oooool2o`0000?ooooo0_l00007ooooo`;o00000_ooool2
o`0000Cooooo0_l000000ooooooo0000o`000005ooooo`;o00001_ooool2o`0001Gooooo0_l0001@
ooooo`007?ooool00ol0003oooooooooo`1Hooooo`?o000000?oooooo`000?l000000ol0000?oooo
o`;o00006?ooool2o`00017ooooo0ol00007ooooo`Co00001Oooool2o`0000Gooooo0_l00002oooo
o`;o00002oooool4o`0000Gooooo1?l0000>ooooo`;o00004_ooool2o`00053ooooo000Looooo`03
o`000?oooooooooo05Sooooo0ol00002ooooo`;o00000oooool2o`0000cooooo0_l00005ooooo`;o
00000oooool2o`0000Gooooo0_l0000Hooooo`;o00002?ooool4o`0000Gooooo0ol00004ooooo`;o
00001oooool2o`0000Sooooo0_l000000ooooooo0000o`000004ooooo`;o00003Oooool3o`0000So
oooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`1Rooooo`;o00002Oooool2o`000003oooo
ool0003o000000Gooooo0_l00003ooooo`Co00000oooool2o`0000_ooooo0_l0000Gooooo`;o0000
00?oooooo`000?l000000oooool2o`0000Cooooo0_l00007ooooo`;o00002Oooool4o`0000Gooooo
0_l0000<ooooo`;o00002Oooool2o`0005[ooooo000Looooo`03o`000?oooooooooo03kooooo0_l0
000:ooooo`?o00008?ooool2o`0000cooooo0_l000000ooooooo0000o`000006ooooo`;o00002?oo
ool2o`0000gooooo0_l00008ooooo`;o000000?oooooo`000?l000000_l0000<ooooo`;o000000?o
ooooo`000?l000001_ooool2o`0000;ooooo0ol00002ooooo`;o00000_ooool2o`0007?ooooo000L
ooooo`03o`000?oooooooooo03kooooo0_l0000:ooooo`?o00009Oooool2o`000003ooooool0003o
000000Cooooo0_l00009ooooo`;o00002Oooool2o`0000Wooooo0_l000000ooooooo0000o`00000=
ooooo`;o00003?ooool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000005
o`0000;ooooo0_l0000Zooooo`;o0000Boooool001cooooo0_l0001Sooooo`;o00001?ooool2o`00
00Cooooo0_l00002ooooo`;o000000?oooooo`000?l000001?ooool2o`0001Cooooo0_l00009oooo
o`;o00008Oooool4o`000003ooooool0003o000000Ko00001?ooool3o`0000;ooooo1?l0000Hoooo
o`;o00002Oooool2o`0000Sooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0looooo`;o
00006?ooool2o`0000[ooooo0_l000001?oooooo0000o`000?ooool2o`0000Cooooo0ol00002oooo
o`?o00000_ooool2o`000003ooooool0003o000000;ooooo0_l00006ooooo`;o00003?ooool2o`00
00Gooooo0_l0000Gooooo`;o00002Oooool>o`0000?ooooo0_l00002ooooo`Co00003Oooool3o`00
00Sooooo0_l00005ooooo`;o00002oooool3o`00047ooooo000Looooo`03o`000?oooooooooo03[o
oooo1?l00008ooooo`;o00002Oooool2o`0000?ooooo0ol00006ooooo`Go000000?oooooo`000?l0
00002?ooool2o`0000;ooooo0ol00002ooooo`;o00001Oooool2o`0000Kooooo0_l0000<ooooo`;o
00000_ooool2o`0001[ooooo0_l00009oooooaCo000000?oooooo`000?l000003oooool3o`0000_o
oooo0_l00002ooooo`;o00002oooool2o`0004;ooooo000Looooo`03o`000?oooooooooo03[ooooo
0_l0000:ooooo`;o00002Oooool2o`0000Cooooo0_l00004ooooo`Oo00001_ooool2o`0000[ooooo
0_l00006ooooo`;o00003_ooool2o`0000Cooooo0_l00003ooooo`;o00001?ooool2o`0001kooooo
4_l000001?oooooo0000o`000?ooool2o`0001gooooo0_l000000ooooooo0000o`00000<ooooo`;o
0000@_ooool001cooooo00?o0000ooooooooool0GOooool2o`0000_ooooo0_l00006ooooo`;o0000
0_ooool2o`0000Kooooo0_l0000>ooooo`?o00000oooool2o`0000Wooooo0_l00007ooooo`Co0000
4OoooolDo`0000Cooooo0_l0000Pooooo`?o00002oooool2o`0004;ooooo000Looooo`03o`000?oo
oooooooo06Gooooo0_l00007ooooo`Ko00004Oooool2o`0000?ooooo0_l000000ooooooo0000o`00
0002o`0001Oooooo1?l0000Aooooo`;o000000?oooooo`000?l000004?l00003ooooo`;o00005ooo
ool2o`0000Sooooo0_l00003ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0D?ooool2
o`0000gooooo0_l00004ooooo`;o00001oooool4o`0001?ooooo0_l00003ooooo`;o000000?ooooo
o`000?l000001?l00005ooooo`;o00003_ooool3o`00013ooooo0_l00002oooooa?o00004?ooool2
o`0000[ooooo0_l0000=ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0D?ooool2o`00
00_ooooo1_l0000Fooooo`;o00004?ooool2o`000003ooooool0003o000000?o00001?ooool3o`00
00?ooooo0_l00002ooooo`;o00001?ooool4o`0000Kooooo0_l00008ooooo`;o000000?oooooo`00
0?l000004_l0000>ooooo`Co00004Oooool4o`0000Oooooo0_l00005ooooo`;o0000@?ooool001co
oooo00?o0000ooooooooool0C_ooool2o`0000Sooooo0_l00003ooooo`?o000000?oooooo`000?l0
00005_ooool2o`0000Sooooo0_l00006ooooo`;o000000?oooooo`000?l000000_l000001?oooooo
0000o`000?ooool3o`0000Cooooo0_l00002ooooo`;o00001?ooool3o`0000Gooooo1?l0000:oooo
oaGo000000?oooooo`000?l000002_ooool3o`0000oooooo0_l00002ooooo`Co00001oooool2o`00
00Gooooo0ol0000oooooo`007?ooool00ol0003oooooooooo`1=ooooo`?o00000oooool2o`0000?o
oooo2?l0000Booooo`;o00002oooool2o`0000;ooooo0ol00002ooooo`;o00002Oooool5o`0001Oo
oooo0_l0000<oooooa[o00000oooool2o`0000?ooooo0ol0000?ooooo`;o00005Oooool2o`0003oo
oooo000Looooo`03o`000?oooooooooo043ooooo0_l0000:ooooo`?o00001?ooool2o`0000Gooooo
1?l00002ooooo`;o00001Oooool2o`0000?ooooo0_l00004ooooo`;o00002Oooool4o`0000?ooooo
0_l000001Ooooooo0000o`000?l0003ooooo00Co00001Oooool3o`0000;ooooo1?l0000Dooooo`;o
00002OoooolGo`0000;ooooo0_l00003ooooo`;o00000_ooool5o`0001Gooooo0_l0000?ooooo`;o
0000?_ooool001cooooo00?o0000ooooooooool0?oooool3o`0000Gooooo0_l00003ooooo`;o0000
4_ooool2o`0000Gooooo1?l000000ooooooo0000o`000003ooooo`;o00001Oooool2o`0000?ooooo
0_l000001?oooooo0000o`000?l00004ooooo`;o00000_ooool4o`0000Gooooo0_l00003ooooo`Co
00004oooool3o`0000Wooooo5Ol00009ooooo`;o00000_ooool2o`000003ooooool0003o000000oo
oooo0_l00004ooooo`;o00003oooool2o`0003kooooo000Looooo`03o`000?oooooooooo03oooooo
0_l00006ooooo`;o00003Oooool2o`00017ooooo0_l00006ooooo`;o00001Oooool2o`0000Kooooo
1?l00003ooooo`Ko00000_ooool3o`000003ooooool0003o000000_ooooo0_l0000;ooooo`;o0000
00?oooooo`000?l000002OoooolFo`0001?ooooo0_l0000<ooooo`;o0000EOooool001cooooo00?o
0000ooooooooool0C?ooool2o`0000Kooooo1Ol0000Aooooo`;o00002?ooool2o`000003ooooool0
003o000000Cooooo0_l000000ooooooo0000o`000002o`0000?ooooo1?l00004ooooo`?o000000Co
ooooo`000?l0003o00002?ooool6o`0000Wooooo0ol0000;oooooaSo00004Oooool2o`0001[ooooo
0_l00017ooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00001Oooool2o`0000Gooooo1_l0
00000ooooooo0000o`000006ooooo`;o00001_ooool4o`0000Kooooo1Ol00004ooooo`;o000000?o
ooooo`000?l000000_l00003ooooo`;o00000oooool2o`0000Kooooo0_l00006ooooo`Co00000_oo
ool2o`0000[ooooo0_l0000<oooooaOo00007oooool2o`0000_ooooo0ol00008ooooo`;o0000?Ooo
ool001cooooo00?o0000ooooooooool0;oooool2o`0001?ooooo0ol0000<ooooo`;o00001Oooool2
o`0000;ooooo1_l00008ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00
0002o`0000Oooooo1?l00002ooooo`;o00001?ooool4o`000003ooooool0003o000000Wooooo0_l0
0002ooooo`;o00003?ooool2o`0000cooooo0_l000000ooooooo0000o`00000Ao`0000Oooooo0_l0
000Gooooo`?o00002_ooool2o`0000Wooooo0_l0000mooooo`007?ooool2o`00033ooooo0_l0000C
ooooo`;o00005?ooool2o`0000;ooooo1?l00005ooooo`;o00001_ooool5o`000003ooooool0003o
000000;o000000Coooooo`000?l0003ooooo1Ol00004ooooo`?o00001?ooool3o`000003ooooool0
003o000000gooooo0_l0000<ooooo`Co00003?ooool:o`000003ooooool0003o000000Co00002_oo
ool2o`0000Sooooo0_l0000>ooooo`;o00000_ooool2o`00053ooooo000Looooo`03o`000?oooooo
oooo06?ooooo0_l00002ooooo`;o00001_ooool4o`000004ooooool0003o0000o`0000?ooooo2_l0
0003ooooo`;o000000?oooooo`000?l000002Oooool2o`000003ooooool0003o000000Kooooo0_l0
0008ooooo`;o00000_ooool4o`0000cooooo2_l000000ooooooo0000o`000004o`0000kooooo0_l0
0004ooooo`;o00003_ooool2o`0000;ooooo0_l0000:ooooo`;o0000A?ooool001cooooo00?o0000
ooooooooool0>_ooool2o`0000Oooooo0_l0000=ooooo`;o00003_ooool3o`000003ooooool0003o
000000cooooo0_l00005ooooo`;o000000?oooooo`000?l000001_l000001?oooooo0000o`000?oo
ool2o`0000Kooooo0_l000001?oooooo0000o`000?ooool2o`0000Kooooo0_l00004ooooo`?o0000
00?oooooo`000?l000000_ooool4o`0000oooooo1ol000000ooooooo0000o`000004o`0000kooooo
0_l0000Dooooo`?o00003?ooool3o`0000Oooooo0_l0000kooooo`007?ooool00ol0003ooooooooo
o`0jooooo`;o00001oooool2o`0000gooooo0_l0000>ooooo`?o000000?oooooo`000?l000000_l0
000:ooooo`Co000000?oooooo`000?l000003ol00008ooooo`;o00002?ooool2o`0000Sooooo0ol0
0006ooooo`?o00003oooool8o`000003ooooool0003o000000Co00004oooool4o`0000?ooooo0_l0
0008ooooo`?o00002_ooool3o`0000Sooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`1<
ooooo`;o000000?oooooo`000?l000000_l0000Eooooo`;o00001_ooool2o`0000;ooooo1?l00000
0ooooooo0000o`00000@o`0000;ooooo0_l00008ooooo`;o00000oooool4o`0000Gooooo1_l00004
ooooo`;o00004Oooool9o`0000;ooooo0ol0000Cooooo`Co00000oooool2o`0000Wooooo0_l0000:
ooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0;?ooool2o`0000Wooooo0_l0000=oooo
o`Co00000_ooool2o`000003ooooool0003o000000;o00002?ooool3o`0000kooooo0_l00002oooo
o`;o00000_ooool2o`0000;ooooo6ol000000ooooooo0000o`000003o`0000?ooooo1?l00005oooo
o`;o000000Coooooo`000?l0003o00000_ooool4o`0000gooooo0_l00002ooooo`Wo00000_ooool2
o`0001;ooooo0_l0000Dooooo`;o0000D?ooool001cooooo00?o0000ooooooooool0;?ooool2o`00
00Wooooo0_l00006ooooo`;o00000_ooool2o`000003ooooool0003o000000;o00002_ooool2o`00
00Gooooo0ol0000>ooooo`;o00001_ooool3o`000003ooooool0003o000000Ko000000?oooooo`00
0?l000004?l000000ooooooo0000o`000003o`0000?ooooo0ol00009ooooo`;o00000oooool2o`00
00oooooo1?l000000ooooooo0000o`000006o`000003ooooool0003o000001?ooooo0_l00009oooo
o`;o00000oooool2o`0000Cooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`0Vooooo`;o
00005oooool6o`0000oooooo0_l0000Oooooo`;o00000_oooolJo`000003ooooool0003o000000?o
00001?ooool2o`0000kooooo0_l0000Aooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooo
oooo0000o`000003o`0000Sooooo0_l00003ooooo`;o00003?ooool2o`000003ooooool0003o0000
00?ooooo0_l00002ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`;o000000?ooooo
o`000?l00000A?ooool001cooooo00?o0000ooooooooool09_ooool2o`0001Wooooo0_l00007oooo
o`?o000000?oooooo`000?l000000_l0000Nooooo`;o00000oooool4o`0000;ooooo0_l000000ooo
oooo0000o`00000Co`000005ooooool0003o0000o`000?ooool01_l0000?ooooo`;o000000?ooooo
o`000?l000004?ooool2o`0000Gooooo1Ol00008ooooo`;o00000oooool2o`0000cooooo0_l00006
ooooo`;o00000_ooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool5o`0004Cooooo000L
ooooo`03o`000?oooooooooo04Sooooo1Ol000000ooooooo0000o`000002o`0001kooooo0_l00000
0ooooooo0000o`000005o`000003ooooool0003o000000oo000000?oooooo`000?l000001_l00003
ooooo`So00004?ooool2o`00013ooooo0_l00002ooooo`;o00001?ooool2o`0001gooooo0_l00004
ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0000;ooooo0_l00002ooooo`?o0000AOoo
ool001cooooo00?o0000ooooooooool0:Oooool2o`0000Wooooo0_l0000Booooo`;o000000?ooooo
o`000?l000000_l00002ooooo`;o00000oooool2o`0000oooooo0_l00007ooooo`;o000000?ooooo
o`000?l000001Ol000000ooooooo0000o`00000Ho`0000?ooooo0_l00002ooooo`Co00009_ooool2
o`0002?ooooo0ol000000ooooooo0000o`000003ooooo`?o00000_ooool2o`0000;ooooo0_l00003
ooooo`?o0000A?ooool001cooooo00?o0000ooooooooool0:Oooool2o`0000Sooooo0ol0000Foooo
o`?o00000_ooool2o`0000?ooooo0_l0000?ooooo`Co00001Oooool2o`000003ooooool0003o0000
01oo00000oooool4o`000003ooooool0003o000000[ooooo0_l00007ooooo`;o00004_ooool2o`00
00Oooooo0ol0000Kooooo`;o000000?oooooo`000?l000003?ooool2o`0000Cooooo0_l00008oooo
o`?o0000>Oooool001cooooo00?o0000ooooooooool0<oooool2o`0001Kooooo0ol00002ooooo`;o
000000?oooooo`000?l000003?ooool2o`0000Kooooo1?l00002ooooo`?o000000?oooooo`000?l0
00007ol00003ooooo`Co000000?oooooo`000?l000001oooool2o`000003ooooool0003o000000Go
oooo1?l0000Booooo`;o00000oooool3o`000005ooooool0003o0000o`000?ooool00_l0000_oooo
o`;o00001_ooool5o`0003Wooooo000Looooo`03o`000?oooooooooo04_ooooo0_l00003ooooo`;o
000000?oooooo`000?l000003?ooool2o`0000Kooooo1?l00002ooooob7o000000?oooooo`000?l0
00000_ooool6o`000003ooooool0003o000000;o00001?ooool3o`0000Sooooo0_l0000Iooooo`?o
000000?oooooo`000?l000000_ooool2o`0000Wooooo0_l0000Nooooo`;o00003?ooool2o`000003
ooooool0003o000003Wooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0mooooo`;o00001?ooool2o`00
00_ooooo0_l0000@ooooo`;o00001Oooool2o`0000?ooooo9_l000001Ooooooo0000o`000?l0003o
oooo00;o00000oooool3o`0000?ooooo1?l0000Hooooo`;o00002Oooool2o`0000Gooooo0_l00009
ooooo`;o00005Oooool2o`0000Oooooo0_l0000Aooooo`;o0000=oooool00006oooooomgMgOoV9RH
oooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0mooooo`;o00001?ooool2o`0000Cooooo0_l0000Gooooo`;o00002_ooool2o`0000;ooooo8ol0
0004ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o000000?oooooo`000?l00000
6?ooool4o`0000oooooo1?l00008ooooo`;o00004oooool3o`0000Oooooo0_l000000ooooooo0000
o`00000=ooooo`;o0000=oooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Ooo
ool5o`0000Kooooo00?o0000ooooooooool0@oooool2o`0000Cooooo0_l00002ooooo`;o00002Ooo
ool2o`000003ooooool0003o000000Gooooo0_l00004ooooo`Co00001?oooolUo`0000?ooooo1_l0
0002ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o00003oooool2o`0000Cooooo0ol0
000>ooooo`Co00002?ooool2o`0001?ooooo0ol00004ooooo`So0000A_ooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool02Oooool01?m4A4CogMgMooooool00007ooooo`?o0000@?oo
ool2o`000003ooooool0003o000000?ooooo0ol00002ooooo`Co00001oooool2o`000003ooooool0
003o000000_ooooo1_l000000ooooooo0000o`00000So`0000?ooooo0ol000000ooooooo0000o`00
0003ooooo`Oo00001?ooool2o`0000Kooooo0_l00007ooooo`;o00000oooool4o`000003ooooool0
003o000000_ooooo0_l0000Pooooo`;o00001?ooool3o`0000;ooooo0_l00017ooooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o
0000ooooooooool0@?ooool3o`0000Gooooo0_l00005ooooo`;o00001?ooool2o`0000Cooooo0_l0
000<ooooo`;o000000?oooooo`000?l00000<_l00002ooooo`Co00003Oooool2o`0000;ooooo0_l0
00000ooooooo0000o`000004ooooo`Co00000_ooool2o`0002cooooo0ol00009ooooo`;o0000Aooo
ool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00omgMgOoc<c<o`000007
ooooo`03o`000?oooooooooo047ooooo0_l00005ooooo`;o00002?ooool2o`000003ooooool0003o
000001;ooooo0_l00002ooooo`;o000000?oooooo`000?l000000ol000000ooooooo0000o`00000P
o`000003ooooool0003o000000Ko00000_ooool3o`0000Gooooo0_l00002ooooo`;o00001_ooool2
o`000003ooooool0003o000000Cooooo0_l00003ooooo`;o00006_ooool2o`00017ooooo0ol00009
ooooo`;o0000Aoooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`00
0007ooooo`03o`000?oooooooooo047ooooo0_l00002ooooo`;o000000?oooooo`000?l000002?oo
ool2o`000003ooooool0003o0000013ooooo1?l00005ooooo`Go000000?oooooo`000?l000002Ol0
00000ooooooo0000o`00000Do`000004ooooool0003o0000o`0000?ooooo0_l00002ooooo`?o0000
1Oooool2o`0000;ooooo0ol0000;ooooo`;o00001_ooool4o`0001Cooooo0_l00002ooooo`;o0000
3_ooool2o`000003ooooool0003o000000cooooo0_l0000=ooooo`;o0000=_ooool00006ooooooo^
k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo02;o
oooo0_l0000Fooooo`;o00001Oooool2o`0000;ooooo0_l000000ooooooo0000o`00000;ooooo`;o
00004?ooool2o`0000Kooooo:?l00002ooooo`?o00003Oooool2o`0000Gooooo0_l000000ooooooo
0000o`000006ooooo`Co000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000oo
oooo0_l00003ooooo`;o000000?oooooo`000?l000003oooool2o`000003ooooool0003o000000;o
00002Oooool3o`0000gooooo0_l0000fooooo`007?ooool00ol0003oooooooooo`0Rooooo`?o0000
4oooool4o`0000Oooooo1ol0000Oooooo`;o00001?oooolYo`000003ooooool0003o000000;o0000
0_ooool2o`0000Sooooo0_l00008ooooo`;o00001_ooool4o`000003ooooool0003o000000;ooooo
0_l000000ooooooo0000o`00000?ooooo`;o00001_ooool4o`0001;ooooo0ol00008ooooo`?o0000
AOooool001cooooo00?o0000ooooooooool08oooool2o`0001?ooooo0ol000000ooooooo0000o`00
0005ooooo`?o000000?oooooo`000?l000008?ooool2o`0000Gooooo:?l00002ooooo`?o00000_oo
ool2o`0000Gooooo0_l000000ooooooo0000o`000006ooooo`;o00001_ooool2o`0000;ooooo0_l0
0004ooooo`;o00005Oooool2o`0000Kooooo0_l0000>ooooo`;o00000oooool2o`0000Sooooo0_l0
0002ooooo`;o00001Oooool2o`0003_ooooo000Looooo`03o`000?oooooooooo027ooooo0_l0000F
ooooo`;o000000?oooooo`000?l000002Oooool2o`0002Oooooo:?l00003ooooo`Co00000oooool2
o`0000;ooooo0_l000000ooooooo0000o`000006ooooo`;o00001_ooool2o`0000Sooooo0_l0000E
ooooo`;o00005_ooool2o`0000cooooo0ol00002ooooo`;o00000oooool4o`0000Cooooo0_l0000e
ooooo`007?ooool00ol0003oooooooooo`0Qooooo`;o00006?ooool3o`0000Wooooo0_l000000ooo
oooo0000o`000002ooooo`;o00003oooool3o`0000kooooo:?l00002ooooo`Go00000oooool2o`00
00Gooooo0_l00006ooooo`;o00007Oooool2o`00013ooooo0_l0000Iooooo`;o000000?oooooo`00
0?l000002?ooool2o`0000Cooooo1?l0000eooooo`007?ooool00ol0003oooooooooo`0kooooo`?o
00001oooool2o`000003ooooool0003o000000;o00000_ooool2o`0000oooooo0ol00004ooooo`;o
00002?oooolSo`0000;ooooo0_l00003ooooo`;o00005?ooool2o`0000Gooooo0_l00008ooooo`?o
00001?ooool2o`0000Cooooo1?l0000;ooooo`;o00000oooool2o`0000?ooooo0_l00007ooooo`?o
00002_ooool2o`00017ooooo1?l0000eooooo`007?ooool00ol0003oooooooooo`14ooooo`?o0000
00?oooooo`000?l000000_ooool2o`0001Sooooo0_l00002ooooo`;o00001?oooolWo`0000?ooooo
0_l0000;ooooo`;o00001oooool2o`0000Gooooo0_l00008ooooo`?o00000oooool3o`0000Cooooo
0_l0000<ooooo`?o00000_ooool2o`0000Cooooo0_l00007ooooo`?o00003?ooool2o`0000?ooooo
0_l0000<ooooo`;o0000=Oooool001cooooo00?o0000ooooooooool0@?ooool2o`0000;ooooo0_l0
0006ooooo`;o000000?oooooo`000?l000005?ooool2o`0000?ooooo0_l000000ooooooo0000o`00
0002oooooa_o000000?oooooo`000?l000001ol00002ooooo`Co00002Oooool4o`0001kooooo1Ol0
0002ooooo`Co000000?oooooo`000?l000001oooool2o`0000?ooooo0_l0000@ooooo`;o00002_oo
ool2o`0000?ooooo0_l00005ooooo`;o0000??ooool001cooooo00?o0000ooooooooool0@?ooool2
o`0000Wooooo0_l00002ooooo`;o00005?ooool4o`0000Cooooo0_l00006ooooob3o00000_ooool7
o`0000Oooooo0_l0000Dooooo`;o00001?oooolAo`000004ooooool0003o0000o`0000Kooooo0_l0
000Eooooo`;o00005_ooool2o`0003cooooo000Looooo`03o`000?oooooooooo03Sooooo0_l00005
ooooo`;o00002_ooool2o`0001[ooooo0_l00003ooooo`?o00001_oooolQo`000003ooooool0003o
000000;ooooo0ol0000Dooooo`;o00001?ooool2o`000003ooooool0003o000000Cooooo2Ol00000
0ooooooo0000o`00000;o`0000Cooooo0_l0000Pooooo`;o00003?ooool2o`0003_ooooo000Loooo
o`03o`000?oooooooooo03Sooooo0_l00005ooooo`?o00009Oooool2o`0000;ooooo1?l00002oooo
o`;o000000?oooooo`000?l000002?l00002ooooo`Ko000000?oooooo`000?l000002?l000000ooo
oooo0000o`000002o`000003ooooool0003o000001Wooooo0_l00002ooooo`Go000000Coooooo`00
0?l0003o00002?ooool4o`000003ooooool0003o000000Ko000000?oooooo`000?l000001?l00007
ooooo`;o00005oooool2o`000003ooooool0003o000000Cooooo0_l00006ooooo`;o0000>oooool0
01cooooo00?o0000ooooooooool0>?ooool2o`0000;ooooo0_l00002ooooo`;o00007Oooool2o`00
00Kooooo0_l00002ooooo`;o00001?ooool7o`000003ooooool0003o000001Ko00000_ooool2o`00
00;ooooo0_l000000ooooooo0000o`00000Booooo`;o00001_ooool5o`000003ooooool0003o0000
00;o000000?oooooo`000?l000000ol00003oooooa;o00001oooool2o`0000oooooo0_l00005oooo
o`?o000000?oooooo`000?l000001?ooool2o`0004?ooooo000Looooo`;o0000>Oooool2o`0000;o
oooo1?l00009ooooo`;o00005?ooool3o`00013ooooo7ol00002ooooo`;o00000_ooool6o`00017o
oooo0_l00008ooooo`Go000000Coooooo`000?l0003ooooo1Ol00002oooooa;o000000?oooooo`00
0?l000002_ooool2o`0000Wooooo0ol00005ooooo`;o00001?ooool2o`0000;ooooo0_l00009oooo
o`?o0000=oooool001cooooo00?o0000ooooooooool0>oooool2o`000003ooooool0003o000000?o
00001_ooool2o`0001Gooooo0_l0000<ooooo`;o000000?oooooo`000?l000001?ooool:o`000003
ooooool0003o000000;ooooo2_l00003ooooo`[o00002oooool4o`000003ooooool0003o000000;o
00001?ooool2o`000003ooooool0003o000000?o000000?oooooo`000?l000002?oooolFo`0000Wo
oooo0_l00009ooooo`;o00001_ooool3o`0000?ooooo0_l00002ooooo`;o00002?ooool4o`0003Oo
oooo000Looooo`03o`000?oooooooooo03[ooooo0ol00002ooooo`Co0000:oooool2o`000003oooo
ool0003o000000Cooooo2_l000000ooooooo0000o`00000;o`000003ooooool0003o000000Go0000
00?oooooo`000?l000003_ooool4o`000003ooooool0003o000000;o00001?ooool2o`0000?ooooo
0_l00002ooooo`;o000000?oooooo`000?l000000ooooolBo`000003ooooool0003o000000?o0000
7Oooool2o`0000Oooooo0_l00008ooooo`;o00000oooool2o`0003Cooooo000Looooo`03o`000?oo
oooooooo03Kooooo0_l00002ooooo`;o00000oooool2o`0003Gooooo1_l000000ooooooo0000o`00
0003oooooaCo00000_ooool2o`0001cooooo0_l00002ooooo`?o00001?ooool3o`0000;ooooo5ol0
000Cooooo`;o00000_ooool2o`0000?ooooo1?l00007ooooo`;o00003Oooool2o`0003Cooooo000L
ooooo`03o`000?oooooooooo01cooooo0_l0000Eooooo`;o000000?oooooo`000?l000002?ooool2
o`0002kooooo0_l000001?oooooo0000o`000?ooool4o`0000;ooooo6_l0000<ooooo`?o00001ooo
ool2o`0000Sooooo0_l00002ooooo`?o00000_ooool2o`000003ooooool0003o000000;ooooo3ol0
00000ooooooo0000o`000009o`0000oooooo0_l00002ooooo`;o00000_ooool3o`0000Sooooo0ol0
0013ooooo`007?ooool00ol0003oooooooooo`0Looooo`;o00005Oooool2o`0000;ooooo0_l00004
ooooo`Go000000Coooooo`000?l0003ooooo0_l0000Xooooo`;o000000Coooooo`000?l0003ooooo
1?l00002oooooa;o000000?oooooo`000?l000001?l0000<ooooo`Co00001oooool2o`0000Oooooo
0_l00003ooooo`;o00000oooool6o`000003ooooool0003o000001Wo00005oooool2o`0000Cooooo
0_l00003ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0<oooool2o`0000;ooooo0_l0
00001?oooooo0000o`000?ooool4o`0000;ooooo0_l000000ooooooo0000o`00000Nooooo`;o0000
0_ooool2o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`Co000000?oooooo`000?l00000
0_l00003ooooo`Ko00000_ooool3o`000005ooooool0003o0000o`000?ooool00_l0000<ooooo`;o
000000?oooooo`000?l000003_ooool3o`0000?ooooo0_l00005oooooa7o000000?oooooo`000?l0
00003Ol0000Looooo`;o0000BOooool001cooooo00?o0000ooooooooool0<oooool2o`0000Gooooo
0_l000000ooooooo0000o`000002ooooo`;o00008oooool2o`0000;ooooo0_l00002ooooo`;o0000
1?ooool3o`0000;ooooo2?l00003ooooo`Go00000_ooool3o`000003ooooool0003o000000Co0000
3oooool2o`0000Cooooo0_l00008ooooo`;o00001?ooool3o`0000Oooooo1?l000000ooooooo0000
o`00000Go`0006Oooooo000Looooo`03o`000?oooooooooo03?ooooo1?l00006ooooo`;o00000_oo
ool2o`0000[ooooo0_l0000Nooooo`Go00000_ooool?o`000003ooooool0003o000000;o00001?oo
ool2o`0000;ooooo1Ol0000?ooooo`;o00001?ooool2o`0000;ooooo0_l00004ooooo`Go00000_oo
ool2o`0000Gooooo1Ol000000ooooooo0000o`00000Go`000003ooooool0003o000001?ooooo1?l0
0005ooooo`;o00000_ooool2o`0000gooooo0_l0000dooooo`007?ooool00ol0003oooooooooo`0e
ooooo`;o00005_ooool2o`0001;ooooo0_l0000:ooooo`;o000000?oooooo`000?l000001?ooool3
o`0000;ooooo0ol00003ooooo`;o000000Coooooo`000?l0003ooooo0_l000001?oooooo0000o`00
0?ooool5o`0000oooooo0_l000000ooooooo0000o`000008ooooo`;o00001Oooool4o`000003oooo
ool0003o000000Kooooo0_l000000ooooooo0000o`00000Go`000004ooooool0003o0000ooooo`;o
00004Oooool6o`0000Gooooo0ol000000ooooooo0000o`00000=ooooo`;o0000=?ooool001cooooo
00?o0000ooooooooool0HOooool3o`000003ooooool0003o000000?ooooo1Ol00002ooooo`;o0000
0_ooool2o`0000kooooo1?l000001?oooooo0000o`000?ooool3o`00017ooooo0_l00009ooooo`;o
00000_ooool4o`0000Kooooo0_l00004ooooo`Co000000?oooooo`000?l000006Ol00003ooooo`;o
00004?ooool3o`000003ooooool0003o000000;o00001?ooool2o`0000Oooooo0_l0000mooooo`00
7?ooool00ol0003oooooooooo`1>ooooo`;o00004?ooool4o`000003ooooool0003o000000?ooooo
0ol000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00005ooooo`?o00000_ooool2o`0000;o
oooo1Ol00003ooooo`?o00004Oooool2o`0000?ooooo0_l00004ooooo`;o00000_ooool4o`0000co
oooo1?l000000ooooooo0000o`00000@o`0000Gooooo1?l000000ooooooo0000o`000002o`000003
ooooool0003o000000Gooooo0_l00007ooooo`;o000000?oooooo`000?l000000_l0000<ooooo`Co
0000??ooool001cooooo00?o0000ooooooooool0<Oooool2o`0001Gooooo0_l00003ooooo`?o0000
4?ooool2o`0000cooooo0_l00005ooooo`;o00001Oooool3o`0000;ooooo0_l000000ooooooo0000
o`000002ooooo`;o00000oooool2o`0000Sooooo0_l00007ooooo`?o000000?oooooo`000?l00000
0_l00009ooooo`?o00000_ooool2o`0000_ooooo6?l000000ooooooo0000o`000002o`000003oooo
ool0003o000000;ooooo0ol00005ooooo`?o00006Oooool4o`0003cooooo000Looooo`03o`000?oo
oooooooo033ooooo0ol000000ooooooo0000o`000002o`00013ooooo0_l00003ooooo`;o00007ooo
ool2o`0000Gooooo0_l00005ooooo`;o000000?oooooo`000?l000000oooool2o`000003ooooool0
003o000000Oooooo0_l000000ooooooo0000o`000002ooooo`;o00001oooool2o`0000;ooooo0_l0
0006ooooo`?o00000_ooool2o`0000?ooooo0_l0000;oooooaoo00000oooool2o`0000Oooooo0_l0
000=ooooo`;o00002_ooool2o`0000Cooooo0_l00002ooooo`;o0000=?ooool001cooooo00?o0000
ooooooooool0<?ooool2o`0000;ooooo1_l00002ooooo`Co00009_ooool2o`0000Kooooo0_l0000:
ooooo`;o00000oooool2o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`?o000000?ooooo
o`000?l000001?ooool2o`0000;ooooo0_l00005ooooo`;o00001_ooool3o`0000?ooooo0_l00006
ooooo`;o000000?oooooo`000?l000001OoooolNo`0001_ooooo0_l0000:ooooo`;o00001?ooool2
o`000004ooooool0003o0000o`0003Cooooo000Looooo`03o`000?oooooooooo03Sooooo0_l00002
ooooo`Co00009_ooool2o`0000_ooooo2_l00002ooooo`;o00003_ooool2o`0000Gooooo0_l00000
0ooooooo0000o`000002ooooo`;o00001Oooool2o`0000Wooooo1Ol000000ooooooo0000o`000003
ooooo`;o000000Coooooo`000?l0003ooooo0ol00002oooooaKo000000?oooooo`000?l000000_l0
000Looooo`;o000000?oooooo`000?l000002?ooool2o`0000Oooooo0_l0000eooooo`007?ooool2
o`0003Cooooo0_l00007ooooo`?o00009_ooool2o`0000cooooo1ol000000ooooooo0000o`00000@
ooooo`;o00001oooool2o`0001?ooooo0_l000000ooooooo0000o`000003o`0000;ooooo0_l00002
ooooo`;o000000?oooooo`000?l000000_ooool4o`000003ooooool0003o000001So00001oooool2
o`0000oooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l00006ooooo`;o0000?_ooool0
01cooooo00?o0000ooooooooool0<oooool2o`0000Sooooo0_l0000Tooooo`Go00002Oooool2o`00
00Cooooo0_l00006ooooo`;o00001_ooool2o`000004ooooool0003o0000ooooo`;o000000?ooooo
o`000?l000000_l00006ooooo`Co00003Oooool8o`0000Kooooo0_l000000ooooooo0000o`000003
ooooo`?o000000?oooooo`000?l000005_l000000ooooooo0000o`000006ooooo`;o00001?ooool2
o`0000Wooooo0_l00008ooooo`;o00001_ooool2o`0003kooooo000Looooo`03o`000?oooooooooo
043ooooo0_l0000Qooooo`Go00002Oooool2o`0000cooooo0_l00006ooooo`;o000000?oooooo`00
0?l000000_l00002ooooo`Co00000_ooool2o`0000;ooooo1?l0000<ooooo`;o000000Coooooo`00
0?l0003o00005ooooolFo`000003ooooool0003o000000;o00002_ooool3o`000003ooooool0003o
000005Oooooo000Looooo`03o`000?oooooooooo03Cooooo0_l0000:ooooo`Co00002?ooool2o`00
01Gooooo1Ol00007ooooo`;o00005?ooool2o`0000Cooooo2?l00003ooooo`;o00000oooool2o`00
00gooooo0_l000001?oooooo0000o`000?l0000IoooooaCo00000oooool2o`0000[ooooo0ol00000
0ooooooo0000o`000002ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0=?ooool2o`00
00cooooo0_l00008ooooo`;o00006?ooool2o`0000Oooooo0_l00006ooooo`;o00003?ooool2o`00
00Cooooo1_l0000Hooooo`Co000000?oooooo`000?l000004Oooool2o`0000?ooooo5ol0000Coooo
o`;o00000_ooool2o`0000gooooo1?l000000ooooooo0000o`00000oooooo`007?ooool00ol0003o
ooooooooo`0eooooo`Co00000_ooool2o`0002Oooooo0_l0000@ooooo`?o000000?oooooo`000?l0
00004?ooool2o`0000Sooooo0_l0000@ooooo`Go00000_ooool2o`0000;ooooo0_l0000<ooooo`;o
00000ooooolGo`0001?ooooo0_l00004ooooo`;o00002oooool4o`000003ooooool0003o000000Co
oooo0_l0000iooooo`007?ooool00ol0003oooooooooo`0Kooooo`;o00006?ooool4o`0000;ooooo
1?l0000Mooooo`?o00001Oooool2o`0000?ooooo0_l00009ooooo`Co00000_ooool3o`0000[ooooo
0_l0000=ooooo`;o00004?ooool6o`000003ooooool0003o000000;ooooo0_l0000Aooooo`go0000
00?oooooo`000?l000000ol0000Aooooo`;o00002_ooool2o`0001Kooooo0_l00004ooooo`;o0000
<oooool001cooooo00?o0000ooooooooool06oooool2o`0001Gooooo0ol00008ooooo`;o00001_oo
ool3o`0001Cooooo0ol00005ooooo`;o00000oooool2o`0000Wooooo0ol000001?oooooo0000o`00
0?ooool4o`0000Oooooo0ol0000<ooooo`;o00004oooool4o`0000Gooooo0_l0000Booooo`;o0000
0oooool=o`00017ooooo0_l0000Xooooo`;o0000<oooool001cooooo00?o0000ooooooooool0<_oo
ool3o`00013ooooo0ol0000Jooooo`?o00000oooool2o`0000kooooo0_l00003ooooo`Co000000?o
ooooo`000?l000000_ooool2o`0000cooooo0ol0000Eooooo`;o00006Oooool2o`0000Cooooo0ol0
00000ooooooo0000o`000003o`000003ooooool0003o000000?ooooo0_l0000Gooooo`;o00000ooo
ool4o`0004_ooooo000Looooo`03o`000?oooooooooo03Cooooo0_l0000Aooooo`;o00000_ooool2
o`0001Cooooo1?l00003ooooo`;o00005?ooool8o`0000gooooo1?l00003ooooo`;o00001Oooool2
o`0000Wooooo0ol0000Hooooo`;o00001?ooool3o`000004ooooool0003o0000ooooo`Go00000ooo
ool2o`000003ooooool0003o000000Oooooo0_l0000;ooooo`;o00000oooool4o`0000Sooooo0_l0
0011ooooo`007?ooool00ol0003oooooooooo`0dooooo`;o00003_ooool2o`000003ooooool0003o
000000;ooooo0_l0000Dooooo`;o00007_ooool2o`000003ooooool0003o000000gooooo1?l00003
ooooo`;o00001Oooool2o`0000[ooooo0_l0000Looooo`;o000000?oooooo`000?l000000_l00002
ooooo`?o00002?ooool2o`0000Oooooo0ol0000;ooooo`;o00003_ooool3o`00043ooooo000Loooo
o`03o`000?oooooooooo01_ooooo0_l0000Cooooo`;o00002_ooool2o`0000?ooooo0_l000000ooo
oooo0000o`00000Jooooo`;o00001Oooool2o`0001?ooooo0_l00004ooooo`;o00001?ooool2o`00
00Sooooo0ol0000[ooooo`;o00002Oooool4o`000003ooooool0003o000001Oooooo0_l0000;oooo
o`;o00001?ooool3o`0000Cooooo0_l00002ooooo`;o00001Oooool2o`000003ooooool0003o0000
03Kooooo000Looooo`03o`000?oooooooooo01_ooooo0_l0000Cooooo`;o000000?oooooo`000?l0
00001oooool2o`0000;ooooo0ol00007ooooo`;o00005?ooool2o`0000Gooooo0_l0000@ooooo`;o
000000?oooooo`000?l000001?ooool2o`0000Cooooo0_l00008ooooo`;o00004_ooool2o`0001So
oooo0_l00009ooooo`Oo00005?ooool2o`00013ooooo0_l00002ooooo`?o00000oooool3o`0000Wo
oooo0_l000000ooooooo0000o`00000fooooo`007?ooool00ol0003oooooooooo`0cooooo`;o0000
1?ooool2o`000003ooooool0003o000000;ooooo0_l00008ooooo`;o00004Oooool2o`0000cooooo
1?l0000:ooooo`Co00002?ooool2o`0000Sooooo1?l0000Cooooo`;o00002Oooool2o`0000gooooo
1Ol00005ooooo`So000000?oooooo`000?l000004Oooool2o`00013ooooo0_l00008ooooo`;o0000
2oooool2o`0003Sooooo000Looooo`03o`000?oooooooooo03Cooooo0_l00003ooooo`;o000000?o
ooooo`000?l000000_l0000Looooo`?o00002oooool5o`0000cooooo0_l00007ooooo`?o00002?oo
ool9o`0001Wooooo0_l0000=ooooo`Go00001Oooool4o`0000Gooooo0_l0000Pooooo`;o00000ooo
ool2o`0001?ooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0dooooo`;o00002?ooool2
o`000003ooooool0003o000000Gooooo0_l0000Booooo`;o00002?ooool2o`0000;ooooo0_l00003
ooooo`;o00004oooool2o`0000[ooooo0_l000000ooooooo0000o`000003o`0000Gooooo0_l00002
ooooo`;o00000oooool2o`0000?ooooo0_l0000Cooooo`;o00002Oooool2o`0002Sooooo0_l00003
ooooo`;o0000COooool001cooooo0_l0000dooooo`;o00002Oooool2o`000003ooooool0003o0000
00?ooooo1?l0000=ooooo`;o00000oooool2o`0000Cooooo0_l00002ooooo`;o00001oooool2o`00
00Wooooo0_l000000ooooooo0000o`00000@ooooo`?o00000oooool2o`0000Kooooo0_l00002oooo
o`Co000000?oooooo`000?l000000_ooool3o`0001Kooooo0_l000000ooooooo0000o`000005oooo
o`;o00003oooool2o`0002?ooooo0_l0000<ooooo`;o0000=_ooool001cooooo00?o0000oooooooo
ool07Oooool2o`0000kooooo0_l00004ooooo`;o00004Oooool2o`0000oooooo0_l00005ooooo`?o
000000?oooooo`000?l000002Oooool2o`0000;ooooo0_l00002ooooo`;o00000oooool2o`000003
ooooool0003o0000013ooooo0ol0000Aooooo`;o00001Oooool3o`0001Kooooo0_l000000ooooooo
0000o`000005ooooo`;o00001oooool2o`0000Kooooo0_l00004ooooo`;o00004_ooool2o`0000Co
oooo0_l00003ooooo`;o00001_ooool2o`0000Cooooo0_l0000fooooo`007?ooool00ol0003ooooo
ooooo`0Mooooo`;o00003_ooool2o`0000Cooooo0_l0000:ooooo`;o00007Oooool3o`000003oooo
ool0003o000000Wooooo0_l00002ooooo`Ko00000oooool5o`00013ooooo0ol0000=ooooo`;o0000
00?oooooo`000?l000001Ol00002ooooo`;o00005?ooool2o`0000?ooooo0ol00004ooooo`;o0000
00?oooooo`000?l000000_l00002ooooo`;o00002_ooool4o`0000kooooo0_l00002ooooo`;o0000
1?ooool2o`0000Wooooo1?l00006ooooo`;o000000?oooooo`000?l00000<Oooool001cooooo00?o
0000ooooooooool0?oooool2o`0001gooooo0_l0000Aooooo`ko00002_ooool2o`0000Gooooo0_l0
0003ooooo`;o00002?ooool2o`000003ooooool0003o000000Go00006?ooool2o`0000?ooooo0ol0
0004ooooo`;o000000?oooooo`000?l000000_l0000=ooooo`?o00004?ooool2o`0001?ooooo0_l0
0007ooooo`?o000000?oooooo`000?l00000<Oooool001cooooo00?o0000ooooooooool07Oooool2
o`0001gooooo0_l0000`ooooo`Go000000?oooooo`000?l000002ol00008ooooo`;o00001Oooool2
o`000003ooooool0003o000000;o00002_ooool;o`0001;ooooo0_l000000ooooooo0000o`000002
o`0000Sooooo0_l000001?oooooo0000o`000?l0000>ooooo`;o00005oooool2o`0000_ooooo0_l0
0002ooooo`;o00001Oooool2o`0003Gooooo000Looooo`03o`000?oooooooooo01gooooo0_l0000M
ooooo`;o00006_ooool2o`0000Sooooo0_l0000:ooooo`ko00000_ooool3o`0000Kooooo1?l00008
ooooo`;o00003?ooool6o`000003ooooool0003o000000;o00004_ooool2o`0000?ooooo0_l00008
ooooo`;o000000Coooooo`000?l0003o00009oooool2o`0000_ooooo0_l00002ooooo`;o0000??oo
ool001cooooo00?o0000ooooooooool0;oooool2o`0000;ooooo0_l00003ooooo`;o00001?ooool2
o`0001Oooooo0ol00008ooooo`;o00001Oooool2o`0000?ooooo0_l000000ooooooo0000o`00000=
o`0000Oooooo0_l0000Dooooo`;o00001?ooool2o`000003ooooool0003o000000;o0000>_ooool2
o`00017ooooo0_l00007ooooo`;o000000?oooooo`000?l00000A?ooool001cooooo00?o0000oooo
ooooool0;oooool3o`000003ooooool0003o000000?ooooo0_l00004ooooo`;o00005oooool2o`00
00;ooooo0ol00004ooooo`;o00001Oooool4o`0000;ooooo4Ol00007ooooo`;o00005?ooool2o`00
00Cooooo1_l0000Gooooo`;o00001Oooool2o`0001[ooooo0ol0000=ooooo`;o00000_ooool2o`00
00Oooooo0_l000000ooooooo0000o`000007ooooo`;o00000_ooool4o`0003Gooooo000Looooo`03
o`000?oooooooooo033ooooo0_l0000Yooooo`?o00001?ooool2o`0000;ooooo0_l000000ooooooo
0000o`00000Ao`000003ooooool0003o000000Go00000oooool2o`0000?ooooo0_l0000Cooooo`;o
000000?oooooo`000?l000000ol0000Eooooo`Co00001Oooool6o`0001Kooooo1?l0000<ooooo`?o
00001Oooool2o`000003ooooool0003o000000cooooo0_l00002ooooo`Co0000=Oooool001cooooo
00?o0000ooooooooool07_ooool2o`0001oooooo0_l0000>ooooo`;o00002_ooool3o`0000Sooooo
0_l000000ooooooo0000o`00000Ao`000003ooooool0003o000000Go00001_ooool6o`0000Wooooo
0_l00006ooooo`;o00000oooool2o`0001Kooooo0_l00003ooooo`[o000000?oooooo`000?l00000
1_ooool2o`0000Kooooo0_l00005ooooo`;o00003Oooool2o`0000Cooooo0ol000000ooooooo0000
o`000019ooooo`007?ooool00ol0003oooooooooo`0Nooooo`;o00003oooool2o`0000Wooooo0_l0
0003ooooo`?o00003Oooool4o`000003ooooool0003o000000Kooooo0_l00006oooooaSo00001Ooo
ool2o`0000Cooooo0_l000000ooooooo0000o`000004o`0000Wooooo0_l00008ooooo`;o00005_oo
ool2o`0000Gooooo2?l000000ooooooo0000o`000003o`0000Kooooo0_l00006ooooo`;o00005Ooo
ool2o`0000?ooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00001Oooool2
o`0000;ooooo0_l00004ooooo`;o00002_ooool2o`0000?ooooo0_l000001?oooooo0000o`000?oo
ool2o`0000_ooooo7Ol000000ooooooo0000o`000003ooooo`;o00000oooool2o`0001;ooooo0_l0
00001?oooooo0000o`000?l00007ooooo`;o00001Oooool2o`0000;ooooo0_l000000ooooooo0000
o`000002ooooo`[o00000_ooool5o`0002?ooooo1?l0001Booooo`007?ooool00ol0003ooooooooo
o`0fooooo`;o00005?ooool2o`0000Wooooo0_l00002ooooo`Co00001ooooolKo`000003ooooool0
003o000000Oooooo0_l0000Cooooo`;o00000_ooool2o`0000Oooooo0_l00005ooooo`;o00000_oo
ool2o`0000?ooooo3_l000000ooooooo0000o`000002o`0002?ooooo0_l00003ooooo`;o00004Ooo
ool2o`0000Gooooo0_l0000eooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00000_ooool2
o`0001kooooo1?l00005ooooo`;o00000_oooolEo`000003ooooool0003o000000;ooooo1Ol00004
ooooo`;o00003Oooool2o`000003ooooool0003o000001Wooooo0_l00002ooooo`oo000000?ooooo
o`000?l000001?l0000Vooooo`;o00004Oooool2o`0000Gooooo0_l0000eooooo`0000Koooooonk^
k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo
00?o0000ooooooooool0=oooool2o`0000;ooooo0_l0000Iooooo`;o00001Oooool2o`0000Gooooo
0_l00002oooooaSo00001?ooool5o`0000oooooo1?l000000ooooooo0000o`000004ooooo`;o0000
4oooool2o`000003ooooool0003o000000ko00000oooool4o`0002Cooooo1?l000000ooooooo0000
o`000005ooooo`;o00000oooool2o`00043ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0ioooo
o`;o00006oooool2o`0000_ooooo0ol000000ooooooo0000o`00000Bo`000003ooooool0003o0000
00?o00001_ooool2o`0000Wooooo0_l000001?oooooo0000o`000?ooool2o`0000Sooooo1Ol0000C
oooooaCo00002oooool2o`0001_ooooo1?l000000ooooooo0000o`000005ooooo`;o00000oooool2
o`00043ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo03Wooooo0_l000000ooooooo0000o`000002
o`0000Kooooo0_l0000Kooooo`;o000000?oooooo`000?l000003ol000000ooooooo0000o`000007
o`000003ooooool0003o000000kooooo0_l000000ooooooo0000o`000003o`0000Cooooo0_l00002
ooooo`Go00004_oooolGo`0000Wooooo0_l0000Nooooo`;o00004_ooool3o`0000Kooooo0_l0000a
ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9Sooooo
oiRHV?lQ8B401_ooool3o`0003cooooo1?l00006ooooo`;o00002Oooool2o`0000Cooooo0_l0000:
ooooo`;o000000?oooooo`000?l000006?l00002ooooo`;o00002_ooool2o`0000Oooooo0ol00004
ooooo`Ko00001_ooool2o`0000[ooooo0_l000000ooooooo0000o`00000@o`000003ooooool0003o
000000;o00002Oooool2o`0001kooooo0_l00009ooooo`;o00001oooool3o`0000Kooooo0_l0000a
ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?mEEEGo0000
oa0@4?o<c<`01_ooool00ol0003oooooooooo`0oooooo`;o00001Oooool2o`0000Wooooo1Ol00000
0ooooooo0000o`000002ooooo`;o00001_ooool2o`000003ooooool0003o000001So00001_ooool2
o`0000Kooooo0_l00005ooooo`;o00001oooool7o`0000Gooooo0_l00006ooooo`;o00000_ooool2
o`000003ooooool0003o0000013o00000_ooool2o`0000Cooooo1?l00009ooooo`;o00008?ooool4
o`0000kooooo0_l0000cooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09oooo
o`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0<oooool2o`0000Cooooo0_l000001?oo
oooo0000o`000?ooool2o`0000kooooo0_l00002ooooo`?o00001Oooool2o`0000;ooooo0_l00003
oooooa_o00001oooool2o`0000gooooo0_l00003ooooo`So000000?oooooo`000?l000003Oooool2
o`0000;ooooo0_l000000ooooooo0000o`000008o`000003ooooool0003o000000Co00000_ooool5
o`0000;ooooo1?l00009ooooo`;o00008?ooool3o`0000oooooo0_l0000cooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool08Ooo
ool2o`00013ooooo0_l00004ooooo`;o000000?oooooo`000?l000002oooool2o`0000Cooooo1Ol0
000;ooooob7o00000oooool2o`0001Cooooo1Ol000001Ooooooo0000o`000?l0003ooooo00;o0000
0oooool2o`0000cooooo7ol0000<ooooo`;o00003_ooool2o`0000gooooo0_l000000ooooooo0000
o`000014ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co0000oa0@
40Kooooo00?o0000ooooooooool08Oooool2o`0002;ooooo0_l00002ooooo`;o00001?ooool5o`00
00_ooooo1Ol000000ooooooo0000o`00000@o`000003ooooool0003o000000So000000?oooooo`00
0?l000002_ooool2o`000003ooooool0003o000000;o00000oooool2o`000004ooooool0003o0000
ooooo`Co00001Oooool2o`0000Sooooo0_l00002ooooo`[o000000?oooooo`000?l000003?l00000
0ooooooo0000o`000005o`0000[ooooo0_l0000>ooooo`;o00003Oooool2o`0004Oooooo000Loooo
o`03o`000?oooooooooo04Cooooo0ol0000=ooooo`;o000000?oooooo`000?l000001_ooool2o`00
00Cooooo6Ol00002ooooo`;o00003Oooool7o`0000Cooooo0_l000000ooooooo0000o`000004o`00
00oooooo0_l00002oooooaWo00001_ooool2o`0001Kooooo0_l0000Looooo`;o0000??ooool001co
oooo00?o0000ooooooooool0>_ooool2o`0000Sooooo0_l0000>ooooo`;o000000?oooooo`000?l0
00001_ooool2o`000004ooooool0003o0000ooooo`So000000?oooooo`000?l000003ol000000ooo
oooo0000o`000005ooooo`;o00000_ooool2o`0000Cooooo0_l00007ooooo`So00005OoooolJo`00
00?ooooo0_l0000Gooooo`;o00001?ooool2o`000003ooooool0003o000000Kooooo0ol0000:oooo
o`;o0000??ooool001cooooo00?o0000ooooooooool08oooool2o`0001Gooooo0_l000000ooooooo
0000o`00000Pooooo`;o000000?oooooo`000?l000006ol000000ooooooo0000o`000005ooooo`Ko
00001Oooool2o`0000?ooooo0_l000000ooooooo0000o`000003o`0001Sooooo6_l00003ooooo`?o
00001oooool2o`0000cooooo0_l00005ooooo`;o000000?oooooo`000?l000001_ooool3o`0000;o
oooo0_l00008ooooo`Co0000>?ooool001cooooo00?o0000ooooooooool08oooool2o`0001Sooooo
0_l0000Fooooo`;o00000_ooool2o`0000Sooooo1?l000000ooooooo0000o`00000Co`0000Cooooo
0_l00006ooooo`;o00001oooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0000Wo
oooo0_l00002ooooo`;o00001?ooool2o`0000?ooooo6?l00006ooooo`;o00001oooool2o`0000co
oooo1?l00003ooooo`?o00003Oooool2o`0000;ooooo0_l00002ooooo`Ko0000>?ooool001cooooo
00?o0000ooooooooool0?Oooool2o`0001Kooooo0_l000001?oooooo0000o`000?l00007ooooo`;o
000000?oooooo`000?l000005ol00003ooooo`;o00003oooool2o`0000?ooooo0_l00005ooooo`;o
00002?ooool2o`0000;ooooo0_l00003ooooo`?o00000ooooolGo`0001oooooo0ol00004ooooo`;o
00003Oooool2o`0000;ooooo0_l00002ooooo`;o0000??ooool001cooooo00?o0000ooooooooool0
D_ooool2o`0000Cooooo0_l00002ooooo`?o00000ooooolMo`000003ooooool0003o000001Gooooo
2Ol00007ooooo`?o00001oooool2o`0000Cooooo6?l0000Sooooo`;o00004oooool2o`00043ooooo
000Looooo`03o`000?oooooooooo05;ooooo0ol00007ooooo`?o000000?oooooo`000?l000000ol0
0002oooooaSo000000?oooooo`000?l000005oooool6o`0000;ooooo0_l00004ooooo`;o00000ooo
ool4o`0000;ooooo0_l00004oooooa;o00000oooool3o`0002;ooooo0_l0000?ooooo`;o000000?o
ooooo`000?l000000_l0000oooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00000oooool2
o`0001?ooooo0_l00007ooooo`;o00000_ooool5o`0000;ooooo3ol00002ooooo`Ko00000oooool2
o`0000;ooooo0_l0000?ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Kooooo1ol00002
ooooo`;o00001_ooool9o`000003ooooool0003o000000Ko00000_ooool2o`0001Oooooo0_l00000
0ooooooo0000o`00000@ooooo`;o00001Oooool2o`000003ooooool0003o000000;o0000?oooool0
01cooooo00?o0000ooooooooool0>Oooool2o`0000?ooooo0_l0000:ooooo`;o00004?ooool2o`00
00?ooooo1Ol000001Ooooooo0000o`000?l0003ooooo00ko000000?oooooo`000?l000001?ooool3
o`0000;ooooo0_l0000?ooooo`;o000000Coooooo`000?l0003o00003Oooool4o`0000Gooooo0_l0
0006ooooo`oo000000?oooooo`000?l000006oooool2o`000003ooooool0003o000000Sooooo0_l0
0006ooooo`;o00001oooool2o`0004;ooooo000Looooo`03o`000?oooooooooo04[ooooo0_l00007
ooooo`;o00003oooool6o`000003ooooool0003o000000go000000?oooooo`000?l000000oooool3
o`0000kooooo0_l000000ooooooo0000o`000006o`0001Kooooo0_l00007ooooo`_o000000Cooooo
o`000?l0003o0000:_ooool2o`0000_ooooo0_l00002ooooo`;o000000?oooooo`000?l00000?ooo
ool001cooooo00?o0000ooooooooool0@oooool3o`0000gooooo0_l00008ooooo`?o00001?ooool@
o`0000;ooooo1?l000000ooooooo0000o`000004ooooo`;o00003_ooool9o`0000gooooo0_l00000
0ooooooo0000o`00000?ooooo`oo00007Oooool3o`0000Wooooo0_l00006ooooo`;o00001?ooool2
o`0000Gooooo0_l0000oooooo`007?ooool2o`0004Cooooo0ol0000Dooooo`;o000000Coooooo`00
0?l0003o00001?ooool2o`0000;ooooo2_l00008ooooo`Co00005?ooool3o`0000Cooooo0_l00000
0ooooooo0000o`000009ooooo`;o000000?oooooo`000?l000003oooool>o`0000[ooooo0_l0000<
ooooo`;o00000_ooool5o`0000;ooooo0_l00005ooooo`Ko000000Coooooo`000?l0003o0000C?oo
ool001cooooo00?o0000ooooooooool0A_ooool2o`0000cooooo1?l00002ooooo`;o000000?ooooo
o`000?l000003Oooool8o`0000Cooooo1_l0000<ooooo`;o00001?ooool4o`000003ooooool0003o
000000;ooooo0_l000000ooooooo0000o`000003o`0001Oooooo0_l000000ooooooo0000o`00000<
o`0000?ooooo0_l00005ooooo`?o00002oooool2o`0000;ooooo0_l000000ooooooo0000o`000002
ooooo`;o00001oooool4o`000004ooooool0003o0000o`0004cooooo000Looooo`03o`000?oooooo
oooo04Kooooo0_l0000<ooooo`Co00002_ooool2o`0000Gooooo0_l00005ooooo`Co00000oooool8
o`0000_ooooo0_l00004ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`Co00001oooool2
o`0000kooooo0_l00002ooooo`go00000oooool2o`0000;ooooo1_l0000Kooooo`Co00001_ooool2
o`0004cooooo000Looooo`03o`000?oooooooooo05Sooooo0_l000000ooooooo0000o`000005oooo
o`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo1_l00002ooooo`Co00000oooool4o`00
00Oooooo0_l0000>ooooo`?o000000?oooooo`000?l000000ol00007ooooo`;o00004_ooool;o`00
00Wooooo2?l0000;ooooo`;o00003?ooool4o`0000Cooooo1?l00009ooooo`;o0000@Oooool001co
oooo00?o0000ooooooooool0:_ooool2o`0001gooooo0ol00004ooooo`;o00001_ooool2o`000004
ooooool0003o0000ooooo`;o00001Oooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`00
0004ooooool0003o0000o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Gooooo1_l00000
0ooooooo0000o`000005ooooo`;o00005Oooool=o`0000Sooooo1_l000000ooooooo0000o`000008
ooooo`;o00004_ooool4o`0000_ooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0Zoooo
o`;o00007Oooool3o`0000Cooooo0_l00009ooooo`;o000000?oooooo`000?l000002_ooool2o`00
00Wooooo1Ol00002ooooo`;o000000?oooooo`000?l000004?ooool2o`0000;ooooo0_l00003oooo
o`Co00002?ooool2o`0001Sooooo1?l00002ooooo`Co00002_ooool4o`000003ooooool0003o0000
00;o00006_ooool4o`0004kooooo000Looooo`03o`000?oooooooooo04_ooooo0_l0000>ooooo`;o
00006oooool2o`0000;ooooo0_l000000ooooooo0000o`00000Dooooo`;o00001?ooool3o`0000Co
oooo0_l00004ooooo`;o00006?ooool2o`0000;ooooo0_l00007ooooo`;o00000oooool4o`0000?o
oooo1?l00005ooooo`;o00001oooool2o`0000Gooooo0_l0001Cooooo`007?ooool00ol0003ooooo
ooooo`1;ooooo`;o00004_ooool2o`0000_ooooo0_l00002ooooo`Co00000_ooool2o`0000Wooooo
0_l0000:ooooo`;o00000_ooool2o`0000Wooooo0_l00004ooooo`;o00001?ooool2o`0001?ooooo
0_l0000@ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`?o00001?ooool2o`0000;ooooo
0_l00003ooooo`?o00001?ooool3o`0000?ooooo0_l00005ooooo`;o0000A_ooool001cooooo00?o
0000ooooooooool0Goooool2o`0000_ooooo0_l00002ooooo`Co00000_ooool2o`0000?ooooo0_l0
0004ooooo`;o00002_ooool2o`0000;ooooo0_l0000=ooooo`Co00006Oooool2o`000003ooooool0
003o000000gooooo0ol00002ooooo`;o00000_ooool2o`0000Cooooo0_l00005ooooo`Go00001?oo
ool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`?o00001Oooool2o`0004Kooooo000L
ooooo`03o`000?oooooooooo05kooooo0_l0000=ooooo`;o00002?ooool2o`0000;ooooo0ol00006
ooooo`;o00002?ooool4o`0000Cooooo0_l00005ooooo`Go00007?ooool4o`0000Cooooo0_l00000
0ooooooo0000o`000005ooooo`;o00004oooool4o`0000Sooooo0ol00002ooooo`Oo00001?ooool2
o`0004Kooooo000Looooo`03o`000?oooooooooo05kooooo0_l000000ooooooo0000o`00000:oooo
o`Co00000oooool2o`000004ooooool0003o0000ooooo`Ko000000Coooooo`000?l0003ooooo0_l0
0003ooooo`?o00000_ooool4o`0000Cooooo0_l00005ooooo`Ko00001_ooool2o`0001?ooooo0_l0
0006ooooo`;o000000?oooooo`000?l000003Oooool2o`0000kooooo0_l00007ooooo`;o00000ooo
ool3o`0000;ooooo0_l00004ooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0Foooool2
o`0000Cooooo0_l0000<ooooo`?o00000_ooool2o`0000;ooooo1Ol000001?oooooo0000o`000?oo
ool2o`000004ooooool0003o0000o`0000;ooooo1_l0000@ooooo`Co00001_ooool2o`0002gooooo
0_l00006ooooo`;o00001Oooool3o`0000oooooo0_l0001>ooooo`007?ooool00ol0003ooooooooo
o`1>ooooo`Co00002Oooool2o`0000Cooooo0ol00002ooooo`;o00001_ooool4o`0000Kooooo0_l0
0008ooooo`;o000000?oooooo`000?l000001Oooool3o`0000;ooooo0_l0000<ooooo`Co0000?Ooo
ool2o`0000Gooooo0_l000000ooooooo0000o`00000=ooooo`;o00001Oooool2o`0004Oooooo000L
ooooo`03o`000?oooooooooo04kooooo1_l0000=ooooo`?o00000_ooool2o`0000Kooooo1?l0000@
ooooo`;o00003Oooool2o`0000gooooo0_l0000dooooo`;o00003Oooool2o`0000?ooooo1?l0000B
ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0<_ooool2o`0001kooooo0_l0000Roooo
o`;o00002?ooool2o`0000Oooooo0_l00008ooooo`;o00002oooool3o`0002gooooo0_l00004oooo
o`;o00003Oooool2o`0000;ooooo1Ol0000?ooooo`;o0000B_ooool001cooooo00?o0000oooooooo
ool0<_ooool2o`0003_ooooo0_l00005ooooo`;o000000?oooooo`000?l000001?ooool4o`000003
ooooool0003o000000?ooooo0_l00008ooooo`;o00001Oooool4o`0000?ooooo0ol0000Tooooo`;o
00001_ooool2o`00013ooooo0_l00003ooooo`Ko00004?ooool2o`0004[ooooo000Looooo`;o0000
D_ooool2o`0000;ooooo0_l00002ooooo`;o00001?ooool2o`0000kooooo0_l00008ooooo`;o0000
0_ooool6o`000003ooooool0003o000000;o00001Oooool2o`0000_ooooo1?l00004ooooo`?o0000
1Oooool2o`0001cooooo0_l0000Hooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o0000
1?ooool2o`0005Gooooo000Looooo`03o`000?oooooooooo04gooooo0_l000001?oooooo0000o`00
0?l00002ooooo`;o00000_ooool2o`0000?ooooo0ol00007ooooo`?o00002_ooool6o`0000;ooooo
1_l00003ooooo`;o00001Oooool2o`0000Sooooo0_l000000ooooooo0000o`000007ooooo`;o0000
1Oooool2o`0002cooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo1?l00002ooooo`;o
000000?oooooo`000?l000000_l00002ooooo`;o00001_ooool2o`0004gooooo000Looooo`03o`00
0?oooooooooo04gooooo0_l000000ooooooo0000o`000003ooooo`;o00001oooool2o`0000Sooooo
0ol00004ooooo`;o00001?ooool6o`0001cooooo1?l000000ooooooo0000o`000003ooooo`?o0000
2oooool2o`0002Oooooo0_l00003ooooo`So00001?ooool2o`0000?ooooo1Ol00007ooooo`;o0000
COooool001cooooo00?o0000ooooooooool0EOooool2o`0001;ooooo0_l00004ooooo`;o00003ooo
ool2o`0000Cooooo0_l00004ooooo`;o00002oooool6o`0000;ooooo0ol0000;ooooo`Co00009?oo
ool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000cooooo1?l0001Fooooo`007?oo
ool00ol0003oooooooooo`20ooooo`;o00001?ooool2o`0000Cooooo0_l00002ooooo`;o00002?oo
ool5o`0001;ooooo0_l0000Tooooo`Ko000000?oooooo`000?l000003?ooool2o`0005_ooooo000L
ooooo`03o`000?oooooooooo067ooooo0_l0000]ooooo`;o00002Oooool2o`0000Wooooo0_l0000X
ooooo`;o00001_ooool3o`0000_ooooo0_l00004ooooo`;o0000Foooool001cooooo00?o0000oooo
ooooool0>?ooool2o`0001Wooooo0_l0000<ooooo`;o00001?ooool2o`00017ooooo0_l0000Loooo
o`;o00003?ooool2o`0000Sooooo0_l00003ooooo`;o00006Oooool2o`0000Wooooo0_l00005oooo
o`;o00000_ooool2o`0000Gooooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`0hooooo`;o
00006Oooool2o`0000cooooo0_l00003ooooo`?o000000?oooooo`000?l000003_ooool3o`0000Co
oooo0ol0000Cooooo`?o00000_ooool2o`0001;ooooo0_l00003ooooo`;o00009?ooool2o`0000Go
oooo0_l00009ooooo`;o0000F_ooool001cooooo00?o0000ooooooooool0G_ooool2o`0000Kooooo
1_l000000ooooooo0000o`00000<ooooo`;o00001?ooool3o`0000Gooooo0_l0000:ooooo`Co0000
0oooool4o`0001Cooooo0_l0000Cooooo`?o00003oooool3o`0000Sooooo0_l0001Qooooo`007?oo
ool00ol0003oooooooooo`1Nooooo`;o00001oooool4o`000004ooooool0003o0000o`0001[ooooo
0ol00004ooooo`;o000000?oooooo`000?l000001Ol00004ooooo`;o00001_ooool2o`0000cooooo
0_l0000Cooooo`Co00003_ooool3o`0000Gooooo0_l000001?oooooo0000o`000?l00007ooooo`;o
0000Eoooool001cooooo00?o0000ooooooooool0H_ooool2o`0000Sooooo0ol00003ooooo`;o0000
3Oooool2o`0000;ooooo0_l00003ooooo`;o00001?ooool2o`000003ooooool0003o000000Ko0000
00?oooooo`000?l000002?ooool2o`0000Sooooo0_l0000Iooooo`;o00003oooool2o`0000Gooooo
0_l00002ooooo`;o00001oooool2o`0005Oooooo000Looooo`03o`000?oooooooooo05Sooooo0_l0
0006ooooo`Co000000?oooooo`000?l000000_l00009ooooo`;o00001Oooool2o`0000?ooooo0_l0
00000ooooooo0000o`000002ooooo`;o00002?ooool2o`0000?ooooo2_l000001?oooooo0000o`00
0?l0000>ooooo`;o00009?ooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0006Go
oooo000Looooo`03o`000?oooooooooo05Sooooo0_l00006ooooo`;o00000oooool4o`00013ooooo
0_l000000ooooooo0000o`000002o`0000Gooooo1_l000001?oooooo0000o`000?ooool=o`0000?o
oooo0ol0000=ooooo`Go00006_ooool2o`0000Kooooo0_l00006ooooo`?o000000?oooooo`000?l0
0000IOooool001cooooo00?o0000ooooooooool0Hoooool2o`0001Cooooo0_l000000ooooooo0000
o`000002o`000003ooooool0003o000000?ooooo1Ol000000ooooooo0000o`000002ooooo`ko0000
4Oooool7o`0001Sooooo0_l0000>ooooo`;o000000?oooooo`000?l00000I_ooool001cooooo00?o
0000ooooooooool0@?ooool2o`00027ooooo1?l00007ooooo`;o00002Oooool2o`0000Kooooo0_l0
0003ooooo`?o00001oooool>o`0001Kooooo0_l0000Looooo`;o00003Oooool4o`0006Cooooo000L
ooooo`03o`000?oooooooooo043ooooo0_l0000Iooooo`;o00001_ooool6o`000005ooooool0003o
0000o`000?ooool00_l0000Aooooo`;o00000_ooool4o`0000;ooooo0_l00004ooooo`Oo000000?o
ooooo`000?l000001?l0000;ooooo`Co00008Oooool2o`000003ooooool0003o000000Gooooo0_l0
0008ooooo`;o0000I?ooool001cooooo0_l0001Gooooo`;o00000oooool2o`0000Kooooo0_l00002
ooooo`;o000000Coooooo`000?l0003o00004_ooool2o`0000Cooooo2?l00004ooooo`Ko000000?o
ooooo`000?l000001Ol0000;ooooo`Co00008Oooool2o`0000Oooooo0ol00009ooooo`;o0000Hooo
ool001cooooo00?o0000ooooooooool0E_ooool4o`00013ooooo0_l00002ooooo`;o00003oooool2
o`0000Gooooo1Ol00006ooooo`go00001?ooool2o`0000Kooooo1?l00003ooooo`Co00000_ooool2
o`0000kooooo0_l00009ooooo`;o00001?ooool2o`0000Kooooo0_l00002ooooo`;o0000Hoooool0
01cooooo00?o0000ooooooooool0A?ooool2o`0001;ooooo0_l00004ooooo`;o00003_ooool2o`00
00Gooooo0_l00008ooooo`;o00003_ooool?o`0000Cooooo0_l00004ooooo`Go00001?ooool4o`00
00;ooooo0_l00005ooooo`;o00001oooool2o`0000Wooooo0_l00006ooooo`;o00001?ooool2o`00
06Oooooo000Looooo`03o`000?oooooooooo04Cooooo0_l0000Hooooo`;o00005Oooool4o`0000Ko
oooo0ol0000;ooooo`Co000000?oooooo`000?l000002_l0000:ooooo`;o00004Oooool2o`000003
ooooool0003o000001[ooooo0_l00004ooooo`;o0000Ioooool001cooooo00?o0000ooooooooool0
A_ooool2o`0002?ooooo0ol00004ooooo`;o00000oooool2o`0000Oooooo0_l00009ooooo`Co0000
1?ooool;o`0001gooooo0_l0000Wooooo`;o0000Hoooool001cooooo00?o0000ooooooooool0A_oo
ool2o`0001[ooooo0_l00007ooooo`?o00001?ooool2o`000003ooooool0003o000000?ooooo0_l0
000?ooooo`?o00001Oooool;o`0000oooooo0_l0000;ooooo`;o00006Oooool2o`0000gooooo0_l0
001Sooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00003oooool2o`0000Kooooo0_l0000A
ooooo`;o00000oooool3o`0000oooooo0_l00006ooooo`co00003Oooool2o`0000_ooooo0_l00000
1?oooooo0000o`000?ooool4o`0000Oooooo0_l00008ooooo`Co00002Oooool2o`0006Gooooo000L
ooooo`03o`000?oooooooooo04Wooooo0_l0000?ooooo`;o00004_ooool3o`0000Cooooo0_l00004
ooooo`Go00002?ooool2o`0000?ooooo0ol00006ooooo`Go00000oooool2o`0001Gooooo0_l00004
ooooo`Co000000?oooooo`000?l000000_l00002ooooo`;o00000oooool2o`0000Kooooo1_l00005
ooooo`;o00000_ooool4o`0006?ooooo000Looooo`03o`000?oooooooooo06kooooo0ol00004oooo
o`;o000000?oooooo`000?l000000_ooool5o`0000Cooooo0_l000000ooooooo0000o`000003oooo
o`?o000000?oooooo`000?l000000_l000000ooooooo0000o`000002o`0000gooooo0_l0000<oooo
o`;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00002_ooool6o`00
00Gooooo0ol000000ooooooo0000o`000003o`0006?ooooo000Looooo`03o`000?oooooooooo06Oo
oooo0_l0000?ooooo`;o00001Oooool3o`0000?ooooo0_l0000:ooooo`Co00001Oooool2o`0000_o
oooo0_l000000ooooooo0000o`00000Cooooo`Go00000_ooool2o`0000[ooooo0_l00002ooooo`;o
00001Oooool3o`000003ooooool0003o000006Kooooo000Looooo`03o`000?oooooooooo06Oooooo
0_l0000:ooooo`;o00000oooool2o`0000Gooooo0ol000000ooooooo0000o`00000:ooooo`;o0000
2Oooool4o`0000_ooooo0ol0000Eooooo`;o00000oooool2o`0001Kooooo0_l0001Yooooo`007?oo
ool00ol0003oooooooooo`1cooooo`;o00000oooool2o`0000Gooooo0_l00002ooooo`;o00000ooo
ool2o`0000Gooooo0_l0000;ooooo`;o00002_ooool4o`0001Sooooo0_l0000=ooooo`;o00002Ooo
ool2o`0006Wooooo000Looooo`03o`000?oooooooooo087ooooo0ol00003ooooo`?o00007_ooool2
o`0001[ooooo0_l0000=ooooo`?o0000Loooool001cooooo00?o0000ooooooooool0POooool3o`00
0003ooooool0003o000000?o00000_ooool2o`0000Gooooo0_l00005ooooo`;o00003?ooool2o`00
01_ooooo0_l00009ooooo`;o00000_ooool2o`0000?ooooo0_l0001^ooooo`0000Koooooonk^k_lb
<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o
0000ooooooooool0OOooool2o`0000Kooooo0_l00005ooooo`;o000000?oooooo`000?l000000_oo
ool2o`0000Gooooo0_l00008ooooo`;o00007Oooool4o`0000Cooooo0_l00003ooooo`;o00001ooo
ool2o`0006kooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q
8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1jooooo`;o000000Coooooo`000?l0
003ooooo0ol00002ooooo`;o00002?ooool2o`0001?ooooo0ol0000Looooo`;o00001_ooool2o`00
00Oooooo0_l0001cooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`1Booooo`;o00004Oooool2o`00
01?ooooo0_l00004ooooo`?o00000_ooool2o`0000Gooooo0_l00009ooooo`Co00001oooool7o`00
01Kooooo0_l00004ooooo`;o00003Oooool4o`00077ooooo00000ooooooo0000ooooo`02ooooo`03
o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000D_ooool2o`00
017ooooo0_l0000Uooooo`;o00002Oooool6o`0000Cooooo1?l00002ooooo`;o00005_ooool2o`00
00Cooooo0_l00003ooooo`;o00002?ooool4o`00077ooooo00000ooooooo0000ooooo`02ooooo`03
o`000?oooooooooo00Wooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo
09Cooooo0_l00004ooooo`?o000000Coooooo`000?l0003ooooo0_l0000Rooooo`;o00000oooool2
o`0000Sooooo0_l0001cooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09oooo
o`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`1mooooo`;o00003_ooool4
o`0000?ooooo0_l00008ooooo`;o00003oooool4o`0000Cooooo0_l0000;ooooo`Co00000_ooool2
o`0007gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zj
o`000006ooooo`03o`000?oooooooooo07Sooooo0_l00003ooooo`;o00003?ooool7o`0000cooooo
0_l000001?oooooo0000o`000?ooool2o`0000Wooooo1?l00004ooooo`Co00002Oooool4o`0000;o
oooo0_l0001mooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000
oa0@4?nYZJT01_ooool00ol0003oooooooooo`1hooooo`;o00001_ooool2o`0000Wooooo0_l00003
ooooo`;o00003oooool2o`000003ooooool0003o000000oooooo0_l00002ooooo`;o00002?ooool2
o`0000Sooooo0_l0001jooooo`007?ooool00ol0003oooooooooo`20ooooo`;o00006Oooool2o`00
00Cooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`000003ooooool0003o
000000;ooooo1?l00007ooooo`;o00000_ooool2o`0000?ooooo1?l000000ooooooo0000o`00001j
ooooo`007?ooool00ol0003oooooooooo`26ooooo`;o00004?ooool2o`000004ooooool0003o0000
o`0000?ooooo0_l00002ooooo`;o000000Goooooo`000?l0003o0000ooooo`03o`000003ooooool0
003o000000;ooooo1?l00006ooooo`?o00001oooool4o`0007gooooo000Looooo`03o`000?oooooo
oooo08Kooooo0_l00007ooooo`Co00001Oooool2o`0000;ooooo0ol00005ooooo`;o00000oooool2
o`000003ooooool0003o000000Oooooo0_l00006ooooo`?o00002Oooool2o`0007kooooo000Loooo
o`03o`000?oooooooooo08cooooo1ol0000:ooooo`;o00001Oooool4o`000003ooooool0003o0000
013ooooo1Ol0000;ooooo`;o0000O?ooool001cooooo00?o0000ooooooooool0S?ooool3o`0001Go
oooo1_l0000;ooooo`;o00001?ooool2o`000003ooooool0003o000000_ooooo0_l0001looooo`00
7?ooool00ol0003oooooooooo`2Uooooo`Go00000oooool2o`0000Kooooo0_l0002Booooo`007?oo
ool00ol0003oooooooooo`2Eooooo`;o00001?ooool2o`0000?ooooo0_l00003ooooo`Co00000_oo
ool4o`0009[ooooo000Looooo`03o`000?oooooooooo09?ooooo1?l00004ooooo`;o00000oooool2
o`0000Gooooo0_l000000ooooooo0000o`000005o`0009Sooooo000Looooo`03o`000?oooooooooo
09?ooooo0_l0000=ooooo`;o00001_ooool2o`000003ooooool0003o000000;o00002?ooool4o`00
00Kooooo0_l00024ooooo`007?ooool00ol0003oooooooooo`2Cooooo`;o00003Oooool2o`0000[o
oooo0_l00009ooooo`Ko000000Coooooo`000?l0003ooooo0_l00024ooooo`007?ooool00ol0003o
ooooooooo`2Cooooo`;o00006?ooool2o`0000gooooo0ol000000ooooooo0000o`000027ooooo`00
7?ooool2o`000:kooooo0_l0002Jooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0X?ooool3o`00
0:Kooooo000Looooo`03o`000?oooooooooo09Oooooo0_l00007ooooo`?o000000?oooooo`000?l0
0000Xoooool001cooooo00?o0000ooooooooool0Uoooool2o`0000_ooooo0_l0002Sooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`004_oo
ool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000oooo
ooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`00
5?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_oo
ool001Cooooo00?o0000ooooooooool0oooooomBooooo`004_ooool00omEEEGoIVIVo`00003ooooo
oeCooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Uooooo`04oa0@4?l0003o
0000ooooo`;o000000?o410@ooooooooool05Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo
1Ol00005ooooo`;o000000?o410@ooooooooool0S_ooool00:Kooooo00Go0000oooooooooooooooo
o`000009ooooo`Ko00002Oooool01OmEEEGoMgMgoooooonHV9So8B4Q00?ooooo00GoV9RHob4Q8Oo^
k^koooooodA4A006ooooo`03o`000?oooooooooo08oooooo002Vooooo`05o`000?oooooooooooooo
ool000006?ooool01Ol0003ooooooooooooooooo000000Cooooo00?oV9RHob4Q8Oo^k^h01?ooool5
o`00093ooooo002Vooooo`05o`000?ooooooooooooooool000002Oooool6o`0000Wooooo00Go0000
oiRHV?ooooooV9RHob4Q8@05ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00CoA4A4omgMgOoooooo0000
TOooool00:Kooooo00Go0000ohN7QoooooooZJVYo`00000Hooooo`05o`000?mEEEGo0000oa0@4?o<
c<`01_ooool00omgMgOoIVIVooooo`02ooooo`04omgMgOmEEEGoooooo`00097ooooo002Uooooo`03
oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool05_ooool00omEEEGoQhN7ooooo`09ooooo`03
o`000?oooooooooo00;ooooo00?oMgMgolc<c?l00000TOooool00<?ooooo00?ogMgMoa0@4?nHV9P0
1Oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?ok^k^odA4A?l00000TOooool00<Cooooo
00Coc<c<odA4A?l0003o410@0oooool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo00?oMgMgo`00
0?ooool0T?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(630) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.31101 .57844 Mdot
.36348 .60013 Mdot
.62145 .49761 Mdot
.40605 .40061 Mdot
.64889 .41174 Mdot
.65167 .51262 Mdot
.5974 .63482 Mdot
.5589 .65603 Mdot
.65771 .5204 Mdot
.19942 .46874 Mdot
.56149 .63391 Mdot
.35573 .38822 Mdot
.59009 .62371 Mdot
.44304 .3835 Mdot
.48076 .71335 Mdot
.43378 .32394 Mdot
.36298 .6124 Mdot
.66889 .32227 Mdot
.42598 .32268 Mdot
.63233 .4823 Mdot
.44413 .50692 Mdot
.4423 .39151 Mdot
.3584 .61145 Mdot
.44321 .38648 Mdot
.42333 .43481 Mdot
.34528 .59877 Mdot
.31818 .56301 Mdot
.43914 .42533 Mdot
.46563 .42099 Mdot
.56817 .62 Mdot
.72172 .36247 Mdot
.43259 .83754 Mdot
.42239 .33347 Mdot
.3278 .43797 Mdot
.56835 .6664 Mdot
.80035 .56736 Mdot
.67484 .51905 Mdot
.55524 .63185 Mdot
.58825 .65905 Mdot
.60275 .65533 Mdot
.60781 .61956 Mdot
.35219 .59474 Mdot
.61614 .61043 Mdot
.70566 .47671 Mdot
.39865 .37402 Mdot
.36721 .75213 Mdot
.73301 .31817 Mdot
.44001 .42322 Mdot
.31307 .59281 Mdot
.6399 .48242 Mdot
.39868 .23773 Mdot
.55602 .62042 Mdot
.43694 .76765 Mdot
.09889 .56218 Mdot
.57458 .61861 Mdot
.41679 .40848 Mdot
.66344 .48965 Mdot
.41444 .38624 Mdot
.44159 .41203 Mdot
.31968 .38294 Mdot
.46288 .4097 Mdot
.64917 .33838 Mdot
.31465 .56122 Mdot
.64515 .46785 Mdot
.65809 .51547 Mdot
.59127 .60655 Mdot
.3709 .56545 Mdot
.59881 .61914 Mdot
.3697 .4124 Mdot
.62761 .49502 Mdot
.43418 .41862 Mdot
.56019 .63224 Mdot
.37525 .58721 Mdot
.40203 .43251 Mdot
.39651 .72096 Mdot
.62276 .68626 Mdot
.62415 .319 Mdot
.2807 .52363 Mdot
.24094 .31809 Mdot
.67403 .58995 Mdot
.45384 .38192 Mdot
.22747 .30463 Mdot
.483 .70136 Mdot
.3684 .58542 Mdot
.3566 .46805 Mdot
.66951 .73229 Mdot
.47 .4208 Mdot
.56487 .42168 Mdot
.48797 .38767 Mdot
.45523 .59354 Mdot
.66465 .51724 Mdot
.34107 .60562 Mdot
.39706 .3756 Mdot
.46618 .43485 Mdot
.2899 .33587 Mdot
.41241 .34544 Mdot
.40123 .38061 Mdot
.39638 .58248 Mdot
.56873 .64077 Mdot
.39909 .46693 Mdot
.71672 .49398 Mdot
.44769 .73428 Mdot
.39919 .40687 Mdot
.63577 .51905 Mdot
.30755 .60522 Mdot
.39397 .3869 Mdot
.58453 .6093 Mdot
.4563 .39581 Mdot
.59202 .68054 Mdot
.33259 .61139 Mdot
.46867 .43106 Mdot
.63494 .32713 Mdot
.43319 .66722 Mdot
.32448 .5711 Mdot
.19443 .56723 Mdot
.45895 .40938 Mdot
.44166 .40219 Mdot
.36557 .59102 Mdot
.66963 .48319 Mdot
.5534 .45817 Mdot
.36974 .60341 Mdot
.59496 .65742 Mdot
.32616 .61287 Mdot
.48724 .41939 Mdot
.6639 .47863 Mdot
.45383 .73775 Mdot
.43953 .72962 Mdot
.66593 .26416 Mdot
.41594 .44203 Mdot
.46676 .71595 Mdot
.64418 .50295 Mdot
.35716 .59719 Mdot
.59417 .61702 Mdot
.47454 .37858 Mdot
.34865 .56009 Mdot
.58114 .65693 Mdot
.62834 .35894 Mdot
.66048 .41567 Mdot
.33507 .55476 Mdot
.52518 .34305 Mdot
.55309 .65771 Mdot
.60674 .65168 Mdot
.42015 .23813 Mdot
.36678 .58025 Mdot
.6454 .36506 Mdot
.59194 .65066 Mdot
.55257 .25578 Mdot
.46629 .37032 Mdot
.50377 .21091 Mdot
.27765 .2492 Mdot
.40822 .2374 Mdot
.28047 .68795 Mdot
.66343 .3357 Mdot
.5957 .64909 Mdot
.41604 .41869 Mdot
.35022 .57367 Mdot
.35535 .57803 Mdot
.46545 .43957 Mdot
.44089 .43913 Mdot
.43134 .36549 Mdot
.47608 .38959 Mdot
.80922 .45084 Mdot
.43886 .36573 Mdot
.51015 .60775 Mdot
.34108 .55902 Mdot
.42606 .44048 Mdot
.64435 .54011 Mdot
.40744 .44316 Mdot
.55547 .63233 Mdot
.43268 .40653 Mdot
.43485 .43609 Mdot
.38808 .36699 Mdot
.61227 .63351 Mdot
.54075 .82766 Mdot
.19503 .38796 Mdot
.74631 .65569 Mdot
.31858 .68167 Mdot
.6515 .49435 Mdot
.45923 .37696 Mdot
.66258 .35496 Mdot
.39107 .48421 Mdot
.44681 .41192 Mdot
.37345 .24226 Mdot
.44578 .43288 Mdot
.25823 .58356 Mdot
.46861 .46505 Mdot
.71341 .71822 Mdot
.50136 .65835 Mdot
.46682 .4113 Mdot
.23486 .37814 Mdot
.52926 .19999 Mdot
.70767 .30984 Mdot
.58251 .61377 Mdot
.65689 .54384 Mdot
.67752 .50093 Mdot
.61674 .64276 Mdot
.43336 .46678 Mdot
.20123 .48769 Mdot
.37582 .43249 Mdot
.45369 .74388 Mdot
.3048 .5597 Mdot
.66698 .3327 Mdot
.3314 .55616 Mdot
.1825 .35411 Mdot
.51452 .47891 Mdot
.62904 .65526 Mdot
.66098 .31788 Mdot
.62635 .5233 Mdot
.44976 .75655 Mdot
.65758 .36286 Mdot
.40434 .38584 Mdot
.32095 .60392 Mdot
.52498 .19905 Mdot
.49088 .35939 Mdot
.86099 .454 Mdot
.36839 .56993 Mdot
.5033 .55827 Mdot
.58322 .61655 Mdot
.66873 .47379 Mdot
.46782 .42238 Mdot
.425 .37399 Mdot
.31363 .56448 Mdot
.44651 .42436 Mdot
.44737 .53463 Mdot
.43577 .43338 Mdot
.67331 .46725 Mdot
.67021 .3016 Mdot
.61652 .65188 Mdot
.65454 .25651 Mdot
.3768 .58913 Mdot
.55039 .54199 Mdot
.63713 .52858 Mdot
.3568 .64657 Mdot
.56274 .62369 Mdot
.62634 .34984 Mdot
.6639 .53154 Mdot
.61987 .36187 Mdot
.38774 .3938 Mdot
.67196 .51871 Mdot
.6351 .34257 Mdot
.60125 .5112 Mdot
.39955 .38279 Mdot
.50943 .23908 Mdot
.59336 .64537 Mdot
.32051 .56153 Mdot
.4633 .41171 Mdot
.45018 .72448 Mdot
.4642 .4457 Mdot
.47121 .7162 Mdot
.45825 .73969 Mdot
.44515 .76666 Mdot
.64006 .65607 Mdot
.66209 .36532 Mdot
.35077 .71371 Mdot
.53498 .47964 Mdot
.36531 .61129 Mdot
.40168 .36354 Mdot
.60657 .81628 Mdot
.59913 .64267 Mdot
.40554 .38795 Mdot
.68096 .72272 Mdot
.59249 .64994 Mdot
.42183 .39022 Mdot
.60931 .61935 Mdot
.35354 .57382 Mdot
.5584 .49874 Mdot
.34077 .62223 Mdot
.40885 .39918 Mdot
.58027 .63844 Mdot
.66185 .53875 Mdot
.34469 .59774 Mdot
.45466 .39971 Mdot
.45167 .37577 Mdot
.44978 .75101 Mdot
.43235 .44342 Mdot
.64288 .78917 Mdot
.43681 .42239 Mdot
.62604 .52494 Mdot
.41801 .34382 Mdot
.5038 .19496 Mdot
.66376 .4124 Mdot
.36551 .55402 Mdot
.45768 .75039 Mdot
.66948 .50965 Mdot
.59244 .46759 Mdot
.68486 .3718 Mdot
.45314 .38758 Mdot
.44032 .73905 Mdot
.50907 .5581 Mdot
.58328 .60639 Mdot
.47416 .36559 Mdot
.4775 .51098 Mdot
.65803 .5282 Mdot
.4518 .75182 Mdot
.48588 .44578 Mdot
.31425 .61063 Mdot
.41647 .4108 Mdot
.67172 .52493 Mdot
.31343 .60447 Mdot
.47537 .37811 Mdot
.78745 .39454 Mdot
.44881 .72672 Mdot
.59653 .64138 Mdot
.40628 .30156 Mdot
.43491 .36134 Mdot
.67927 .49961 Mdot
.35333 .56427 Mdot
.5711 .62848 Mdot
.32238 .59579 Mdot
.56319 .20025 Mdot
.34735 .67878 Mdot
.77605 .51537 Mdot
.67811 .33047 Mdot
.28508 .74268 Mdot
.7644 .62874 Mdot
.37275 .68174 Mdot
.63057 .28243 Mdot
.79587 .63609 Mdot
.65074 .53938 Mdot
.39179 .27872 Mdot
.66949 .49933 Mdot
.40628 .41389 Mdot
.65292 .51521 Mdot
.67421 .77602 Mdot
.44 .42887 Mdot
.65471 .49033 Mdot
.79625 .4569 Mdot
.45383 .43299 Mdot
.33559 .55933 Mdot
.41902 .8148 Mdot
.21337 .58135 Mdot
.53372 .41893 Mdot
.65464 .48673 Mdot
.32702 .29296 Mdot
.45247 .42776 Mdot
.46216 .33285 Mdot
.34727 .57956 Mdot
.4905 .3958 Mdot
.65446 .32343 Mdot
.61966 .34777 Mdot
.42225 .24774 Mdot
.22462 .60722 Mdot
.45758 .31908 Mdot
.34834 .59267 Mdot
.24924 .30718 Mdot
.39651 .72513 Mdot
.43785 .72714 Mdot
.57688 .66281 Mdot
.53864 .82602 Mdot
.51169 .40902 Mdot
.49565 .31757 Mdot
.45834 .54701 Mdot
.34554 .60789 Mdot
.76313 .58527 Mdot
.57543 .62977 Mdot
.22218 .37951 Mdot
.22891 .48862 Mdot
.42359 .36436 Mdot
.59332 .59928 Mdot
.36583 .42653 Mdot
.45144 .54417 Mdot
.50329 .22734 Mdot
.74233 .52992 Mdot
.40173 .39213 Mdot
.36127 .7182 Mdot
.44118 .40743 Mdot
.52684 .20554 Mdot
.40771 .39437 Mdot
.32183 .58877 Mdot
.50527 .34927 Mdot
.60305 .42542 Mdot
.17368 .46245 Mdot
.50072 .48774 Mdot
.669 .35538 Mdot
.4396 .38069 Mdot
.4222 .36833 Mdot
.64332 .33514 Mdot
.33312 .59557 Mdot
.4166 .35616 Mdot
.73588 .3153 Mdot
.43029 .36218 Mdot
.55901 .61743 Mdot
.57507 .47026 Mdot
.24986 .61627 Mdot
.4694 .42613 Mdot
.31078 .60413 Mdot
.59621 .60946 Mdot
.56851 .661 Mdot
.48722 .33812 Mdot
.6046 .63782 Mdot
.42219 .4173 Mdot
.56978 .47647 Mdot
.35159 .61325 Mdot
.37555 .4624 Mdot
.33093 .59004 Mdot
.3095 .25871 Mdot
.61411 .62708 Mdot
.43181 .74419 Mdot
.41297 .27793 Mdot
.58792 .63342 Mdot
.40301 .59601 Mdot
.5151 .41329 Mdot
.39729 .43923 Mdot
.3142 .65907 Mdot
.68297 .51795 Mdot
.43645 .75827 Mdot
.57141 .62262 Mdot
.43362 .36366 Mdot
.39288 .39615 Mdot
.57606 .60188 Mdot
.30008 .36155 Mdot
.72315 .3683 Mdot
.41289 .39983 Mdot
.32404 .59161 Mdot
.35544 .5972 Mdot
.45289 .35952 Mdot
.45052 .41231 Mdot
.63221 .53484 Mdot
.43862 .73884 Mdot
.4479 .76244 Mdot
.43695 .73271 Mdot
.69257 .50421 Mdot
.26519 .72056 Mdot
.60649 .65169 Mdot
.3203 .75069 Mdot
.61597 .75495 Mdot
.47788 .33386 Mdot
.68197 .5084 Mdot
.42409 .38273 Mdot
.39719 .41044 Mdot
.57588 .63812 Mdot
.21166 .62299 Mdot
.37697 .35256 Mdot
.33516 .55088 Mdot
.56575 .60894 Mdot
.37046 .46422 Mdot
.60749 .6936 Mdot
.6408 .32784 Mdot
.50792 .47562 Mdot
.58963 .59914 Mdot
.32426 .60327 Mdot
.58193 .59928 Mdot
.42493 .3669 Mdot
.42603 .45819 Mdot
.35382 .60853 Mdot
.65777 .37087 Mdot
.39244 .38088 Mdot
.4234 .3919 Mdot
.54183 .1702 Mdot
.39304 .72067 Mdot
.62886 .5869 Mdot
.4099 .42687 Mdot
.37678 .39872 Mdot
.6581 .37308 Mdot
.42891 .35845 Mdot
.46987 .41721 Mdot
.43467 .65785 Mdot
.60373 .66073 Mdot
.61735 .3333 Mdot
.20773 .39743 Mdot
.36438 .56343 Mdot
.6551 .77366 Mdot
.44942 .73298 Mdot
.59995 .66602 Mdot
.55399 .50582 Mdot
.43713 .75443 Mdot
.64754 .72407 Mdot
.71917 .67973 Mdot
.43357 .74481 Mdot
.61477 .50946 Mdot
.43726 .49064 Mdot
.47953 .39485 Mdot
.42798 .4014 Mdot
.65475 .36842 Mdot
.36223 .57104 Mdot
.50121 .62889 Mdot
.6141 .56872 Mdot
.44248 .39587 Mdot
.38412 .59557 Mdot
.69071 .72561 Mdot
.44748 .7556 Mdot
.6649 .3456 Mdot
.67506 .34968 Mdot
.44001 .40495 Mdot
.4084 .65103 Mdot
.34814 .59584 Mdot
.45449 .39962 Mdot
.47009 .38172 Mdot
.66466 .48385 Mdot
.31763 .59691 Mdot
.63479 .52713 Mdot
.45842 .73556 Mdot
.83687 .56133 Mdot
.56356 .17018 Mdot
.58168 .64791 Mdot
.76269 .61651 Mdot
.56569 .60019 Mdot
.72099 .55993 Mdot
.43585 .73985 Mdot
.44942 .397 Mdot
.379 .57832 Mdot
.45665 .39783 Mdot
.41552 .36161 Mdot
.40476 .37057 Mdot
.4488 .31663 Mdot
.38224 .23747 Mdot
.65736 .35192 Mdot
.37503 .37184 Mdot
.64143 .54878 Mdot
.70638 .71875 Mdot
.44589 .81539 Mdot
.43522 .37497 Mdot
.43894 .39965 Mdot
.36266 .55625 Mdot
.38835 .41068 Mdot
.57525 .61004 Mdot
.36824 .57583 Mdot
.39667 .39953 Mdot
.68619 .43055 Mdot
.43678 .35774 Mdot
.77267 .60576 Mdot
.58185 .599 Mdot
.50208 .4766 Mdot
.38077 .42246 Mdot
.43336 .74227 Mdot
.43558 .7569 Mdot
.44769 .72146 Mdot
.58986 .60318 Mdot
.66775 .48658 Mdot
.64864 .56014 Mdot
.47271 .45535 Mdot
.4188 .42017 Mdot
.39404 .43751 Mdot
.69483 .50593 Mdot
.57042 .45036 Mdot
.29907 .69408 Mdot
.48136 .45842 Mdot
.67078 .5387 Mdot
.39381 .57154 Mdot
.16682 .5227 Mdot
.36322 .56645 Mdot
.64894 .30124 Mdot
.55703 .63257 Mdot
.64874 .32256 Mdot
.34562 .26217 Mdot
.34882 .61204 Mdot
.31934 .55814 Mdot
.65248 .49196 Mdot
.48485 .60892 Mdot
.15162 .67509 Mdot
.63785 .51219 Mdot
.65451 .2873 Mdot
.34638 .58487 Mdot
.3974 .33901 Mdot
.51026 .56021 Mdot
.48361 .59815 Mdot
.66069 .49791 Mdot
.45433 .37991 Mdot
.40139 .61153 Mdot
.63138 .53285 Mdot
.45927 .34864 Mdot
.6511 .48591 Mdot
.61076 .62779 Mdot
.64398 .49898 Mdot
.38308 .55711 Mdot
.38865 .39825 Mdot
.10661 .59355 Mdot
.48097 .6861 Mdot
.46255 .4045 Mdot
.56326 .61051 Mdot
.80284 .40218 Mdot
.41345 .36925 Mdot
.65819 .32325 Mdot
.67622 .53504 Mdot
.77227 .44193 Mdot
.45708 .42311 Mdot
.65707 .5067 Mdot
.36627 .54142 Mdot
.70435 .52841 Mdot
.65098 .59051 Mdot
.44365 .76251 Mdot
.35191 .5695 Mdot
.46778 .73006 Mdot
.57209 .66753 Mdot
.39093 .37183 Mdot
.46083 .37295 Mdot
.33029 .56834 Mdot
.62995 .69459 Mdot
.40003 .34403 Mdot
.45356 .38186 Mdot
.63015 .52634 Mdot
.67294 .54482 Mdot
.49687 .76657 Mdot
.64911 .54078 Mdot
.37615 .39592 Mdot
.32755 .57185 Mdot
.40797 .40947 Mdot
.34227 .55537 Mdot
.40039 .36582 Mdot
.27621 .63721 Mdot
.36262 .56733 Mdot
.3428 .66491 Mdot
.44406 .44484 Mdot
.36843 .32174 Mdot
.41687 .35974 Mdot
.40262 .38308 Mdot
.68312 .52721 Mdot
.64445 .35291 Mdot
.46755 .35258 Mdot
.55767 .52366 Mdot
.6386 .37514 Mdot
.33554 .49966 Mdot
.67013 .48443 Mdot
.64038 .37106 Mdot
.51889 .27533 Mdot
.45749 .75083 Mdot
.65352 .34324 Mdot
.48826 .80104 Mdot
.58108 .6463 Mdot
.34964 .61751 Mdot
.45135 .43532 Mdot
.81176 .61838 Mdot
.72149 .36354 Mdot
.44566 .7509 Mdot
.45996 .41228 Mdot
.41982 .38055 Mdot
.31994 .61621 Mdot
.20533 .32815 Mdot
.6689 .46855 Mdot
.39969 .39508 Mdot
.36604 .60671 Mdot
.26255 .2695 Mdot
.64485 .48806 Mdot
.65825 .34227 Mdot
.59148 .59526 Mdot
.28927 .58509 Mdot
.43981 .76231 Mdot
.61478 .62419 Mdot
.61773 .46901 Mdot
.34421 .25172 Mdot
.45389 .42275 Mdot
.67851 .52202 Mdot
.40593 .23734 Mdot
.43276 .47084 Mdot
.56404 .59763 Mdot
.27595 .59352 Mdot
.34525 .607 Mdot
.57368 .60318 Mdot
.67092 .35281 Mdot
.34979 .61502 Mdot
.33275 .59676 Mdot
.5593 .65609 Mdot
.51647 .62897 Mdot
.50189 .56195 Mdot
.56074 .61965 Mdot
.45677 .6217 Mdot
.43127 .23888 Mdot
.44012 .73609 Mdot
.66538 .34488 Mdot
.56781 .19645 Mdot
.35038 .59692 Mdot
.53985 .82615 Mdot
.38252 .24007 Mdot
.40126 .38097 Mdot
.63448 .35628 Mdot
.64862 .73369 Mdot
.60448 .54746 Mdot
.58195 .65582 Mdot
.57505 .42734 Mdot
.66922 .33179 Mdot
.45954 .36703 Mdot
.24782 .60706 Mdot
.45708 .4366 Mdot
.59635 .64702 Mdot
.44277 .5529 Mdot
.3172 .59163 Mdot
.57534 .66769 Mdot
.45084 .52774 Mdot
.39897 .41386 Mdot
.46946 .40134 Mdot
.58851 .22637 Mdot
.31758 .6005 Mdot
.43964 .76323 Mdot
.45846 .39134 Mdot
.41506 .38868 Mdot
.39365 .36367 Mdot
.43252 .27862 Mdot
.40463 .67293 Mdot
.39797 .39295 Mdot
.6825 .48467 Mdot
.408 .44644 Mdot
.4698 .41026 Mdot
.3357 .62353 Mdot
.47727 .19277 Mdot
.45727 .73055 Mdot
.42409 .39926 Mdot
.41364 .39965 Mdot
.58962 .65984 Mdot
.50542 .56039 Mdot
.48027 .60164 Mdot
.62687 .50443 Mdot
.6084 .28651 Mdot
.38202 .43908 Mdot
.34591 .56291 Mdot
.64331 .32163 Mdot
.38085 .38172 Mdot
.35862 .55768 Mdot
.41729 .45972 Mdot
.63203 .5376 Mdot
.43925 .74105 Mdot
.49924 .32703 Mdot
.64884 .34244 Mdot
.5779 .68095 Mdot
.35617 .77783 Mdot
.64382 .54188 Mdot
.42064 .42779 Mdot
.69927 .5244 Mdot
.6436 .52806 Mdot
.44961 .74917 Mdot
.49684 .42282 Mdot
.35364 .58096 Mdot
.31903 .59467 Mdot
.46783 .22887 Mdot
.68826 .48272 Mdot
.40593 .17941 Mdot
.61037 .62921 Mdot
.48019 .37981 Mdot
.43046 .79795 Mdot
.31857 .58486 Mdot
.57655 .21074 Mdot
.6427 .37213 Mdot
.58146 .65566 Mdot
.46007 .75535 Mdot
.35609 .55659 Mdot
.31837 .57639 Mdot
.40032 .37138 Mdot
.4339 .38149 Mdot
.64362 .2805 Mdot
.51587 .20654 Mdot
.6093 .62084 Mdot
.65822 .33583 Mdot
.63074 .49474 Mdot
.40469 .41944 Mdot
.36586 .59905 Mdot
.25815 .57371 Mdot
.44105 .36376 Mdot
.62962 .53065 Mdot
.35207 .60576 Mdot
.64991 .33154 Mdot
.62958 .35423 Mdot
.40235 .38064 Mdot
.31326 .4953 Mdot
.59215 .63362 Mdot
.32847 .5659 Mdot
.39053 .52667 Mdot
.40841 .34493 Mdot
.4361 .37834 Mdot
.35772 .41412 Mdot
.61577 .62855 Mdot
.5054 .33448 Mdot
.67567 .35784 Mdot
.3597 .57869 Mdot
.46114 .40031 Mdot
.64957 .33841 Mdot
.44749 .2926 Mdot
.43656 .74854 Mdot
.64806 .48793 Mdot
.65922 .32502 Mdot
.63767 .34918 Mdot
.62997 .36908 Mdot
.52653 .82658 Mdot
.31038 .61266 Mdot
.20277 .39582 Mdot
.40552 .36532 Mdot
.43963 .23951 Mdot
.42227 .44692 Mdot
.60947 .61116 Mdot
.66279 .54054 Mdot
.41942 .36214 Mdot
.40054 .37018 Mdot
.25556 .61316 Mdot
.35521 .43768 Mdot
.43695 .50558 Mdot
.32685 .60866 Mdot
.3839 .3021 Mdot
.68172 .50031 Mdot
.26849 .24641 Mdot
.51514 .85261 Mdot
.37231 .4214 Mdot
.49286 .5997 Mdot
.36859 .57895 Mdot
.59156 .65439 Mdot
.48201 .58662 Mdot
.6275 .6335 Mdot
.36203 .58351 Mdot
.40401 .41474 Mdot
.32377 .74933 Mdot
.62208 .36244 Mdot
.43281 .36678 Mdot
.59253 .61396 Mdot
.43214 .36616 Mdot
.59896 .60346 Mdot
.29161 .60278 Mdot
.46769 .63216 Mdot
.44505 .43204 Mdot
.39538 .35171 Mdot
.52622 .38108 Mdot
.43403 .37666 Mdot
.68319 .64556 Mdot
.33715 .5877 Mdot
.33987 .65926 Mdot
.44574 .3556 Mdot
.30316 .47742 Mdot
.45251 .36587 Mdot
.63042 .6981 Mdot
.46544 .37971 Mdot
.55062 .367 Mdot
.46257 .36822 Mdot
.46078 .37834 Mdot
.57487 .63274 Mdot
.59084 .65797 Mdot
.36315 .54157 Mdot
.43239 .75668 Mdot
.71243 .71811 Mdot
.43064 .39418 Mdot
.68677 .52476 Mdot
.44633 .7882 Mdot
.64026 .35213 Mdot
.35982 .58605 Mdot
.36041 .16927 Mdot
.60217 .61167 Mdot
.63975 .4699 Mdot
.65846 .63515 Mdot
.65765 .47145 Mdot
.67393 .4616 Mdot
.35902 .3372 Mdot
.66107 .3357 Mdot
.4574 .3675 Mdot
.32961 .46852 Mdot
.37619 .72168 Mdot
.45425 .34762 Mdot
.67643 .55271 Mdot
.3712 .47066 Mdot
.43235 .23634 Mdot
.62668 .37521 Mdot
.66685 .33604 Mdot
.5724 .6251 Mdot
.62738 .4853 Mdot
.40178 .46415 Mdot
.63835 .37025 Mdot
.65656 .54479 Mdot
.42995 .73508 Mdot
.69165 .31487 Mdot
.35143 .59308 Mdot
.53569 .40946 Mdot
.39445 .7723 Mdot
.60601 .61637 Mdot
.5577 .51814 Mdot
.35414 .63001 Mdot
.302 .57203 Mdot
.43031 .74263 Mdot
.65143 .55166 Mdot
.36671 .61144 Mdot
.39137 .38559 Mdot
.49215 .36129 Mdot
.44269 .40706 Mdot
.64133 .36826 Mdot
.47332 .39176 Mdot
.64665 .5493 Mdot
.60376 .62996 Mdot
.66378 .51975 Mdot
.59307 .63638 Mdot
.30855 .72699 Mdot
.45105 .41581 Mdot
.4376 .38138 Mdot
.54834 .50088 Mdot
.32411 .56338 Mdot
.31742 .4062 Mdot
.6542 .55208 Mdot
.66649 .492 Mdot
.40589 .40876 Mdot
.35015 .5424 Mdot
.63566 .31656 Mdot
.51226 .56677 Mdot
.46682 .37934 Mdot
.33713 .5863 Mdot
.41188 .40884 Mdot
.76486 .49554 Mdot
.46702 .66601 Mdot
.32085 .59408 Mdot
.17039 .47312 Mdot
.42962 .44417 Mdot
.38146 .49175 Mdot
.40364 .32603 Mdot
.58153 .32894 Mdot
.44876 .33989 Mdot
.36973 .57392 Mdot
.43644 .40951 Mdot
.34599 .56729 Mdot
.6447 .53336 Mdot
.60356 .6513 Mdot
.3478 .57229 Mdot
.45961 .43867 Mdot
.48074 .84375 Mdot
.60144 .61505 Mdot
.4455 .37637 Mdot
.56429 .63078 Mdot
.35757 .61772 Mdot
.31414 .57897 Mdot
.50049 .78895 Mdot
.63222 .65514 Mdot
.59658 .6124 Mdot
.42144 .41922 Mdot
.40969 .75243 Mdot
.40864 .40992 Mdot
.64326 .27647 Mdot
.45217 .35444 Mdot
.42348 .34236 Mdot
.29913 .75706 Mdot
.62341 .6545 Mdot
.38181 .1784 Mdot
.6035 .56732 Mdot
.51162 .82641 Mdot
.31862 .63106 Mdot
.62624 .37487 Mdot
.75445 .62322 Mdot
.45653 .73343 Mdot
.68304 .48918 Mdot
.42031 .3617 Mdot
.26581 .62982 Mdot
.56355 .61348 Mdot
.64812 .35696 Mdot
.44519 .4326 Mdot
.62066 .52094 Mdot
.47205 .80323 Mdot
.59408 .6506 Mdot
.35342 .59331 Mdot
.32768 .55833 Mdot
.22119 .33918 Mdot
.46063 .40369 Mdot
.43829 .38704 Mdot
.5563 .63135 Mdot
.41352 .46551 Mdot
.62358 .35471 Mdot
.78506 .48387 Mdot
.5867 .61294 Mdot
.47553 .68821 Mdot
.33053 .6112 Mdot
.42159 .38118 Mdot
.57954 .46542 Mdot
.56998 .78596 Mdot
.23041 .40225 Mdot
.65778 .36505 Mdot
.61101 .25684 Mdot
.36959 .57335 Mdot
.59195 .61587 Mdot
.45721 .25265 Mdot
.47649 .43207 Mdot
.41743 .3818 Mdot
.60636 .24863 Mdot
.50545 .57076 Mdot
.67796 .36976 Mdot
.40111 .33383 Mdot
.51662 .5389 Mdot
.40448 .40882 Mdot
.39289 .3969 Mdot
.37135 .42107 Mdot
.4726 .40978 Mdot
.33898 .57904 Mdot
.22594 .57388 Mdot
.64931 .50763 Mdot
.28217 .32883 Mdot
.5776 .41357 Mdot
.46089 .42688 Mdot
.40132 .41385 Mdot
.20363 .54787 Mdot
.451 .78155 Mdot
.34016 .58985 Mdot
.39885 .56368 Mdot
.60817 .65176 Mdot
.35336 .42976 Mdot
.69171 .49088 Mdot
.42362 .50323 Mdot
.65106 .52533 Mdot
.33647 .58531 Mdot
.6712 .49055 Mdot
.59723 .66099 Mdot
.678 .52248 Mdot
.69183 .50021 Mdot
.61258 .60374 Mdot
.31661 .60455 Mdot
.45538 .37285 Mdot
.61356 .62637 Mdot
.59919 .22713 Mdot
.64029 .36788 Mdot
.49821 .79079 Mdot
.39119 .34176 Mdot
.38959 .50438 Mdot
.78662 .39341 Mdot
.67302 .51266 Mdot
.4481 .67422 Mdot
.36233 .56722 Mdot
.64362 .31823 Mdot
.34121 .57398 Mdot
.34463 .27394 Mdot
.64102 .3404 Mdot
.49713 .79324 Mdot
.47275 .25278 Mdot
.58803 .50078 Mdot
.45321 .44936 Mdot
.31048 .65029 Mdot
.65204 .52726 Mdot
.55856 .61757 Mdot
.66704 .72868 Mdot
.40964 .43736 Mdot
.36866 .68581 Mdot
.30006 .59881 Mdot
.45494 .75597 Mdot
.59559 .61824 Mdot
.58125 .58239 Mdot
.45858 .40668 Mdot
.58399 .4951 Mdot
.44037 .34443 Mdot
.40219 .27731 Mdot
.61917 .2785 Mdot
.28163 .5826 Mdot
.4183 .41189 Mdot
.62777 .51524 Mdot
.41429 .41129 Mdot
.47847 .46679 Mdot
.41702 .24061 Mdot
.3792 .36806 Mdot
.33962 .67401 Mdot
.77735 .42652 Mdot
.35835 .60575 Mdot
.37469 .39125 Mdot
.44623 .74205 Mdot
.41273 .43329 Mdot
.86127 .57879 Mdot
.65203 .34615 Mdot
.60755 .49712 Mdot
.45887 .44114 Mdot
.45773 .39424 Mdot
.29351 .52734 Mdot
.31569 .64379 Mdot
.46069 .75003 Mdot
.41307 .38024 Mdot
.59639 .26348 Mdot
.57054 .63126 Mdot
.47341 .37364 Mdot
.43419 .40584 Mdot
.61282 .20871 Mdot
.56819 .63358 Mdot
.67694 .51112 Mdot
.45812 .74718 Mdot
.63066 .49773 Mdot
.61979 .36949 Mdot
.4704 .5869 Mdot
.55364 .20418 Mdot
.46652 .66858 Mdot
.66418 .32466 Mdot
.47571 .41676 Mdot
.36978 .49318 Mdot
.46573 .39483 Mdot
.66898 .34081 Mdot
.56772 .62055 Mdot
.34122 .57961 Mdot
.53543 .36632 Mdot
.4531 .74418 Mdot
.44678 .34329 Mdot
.63571 .38031 Mdot
.35055 .57662 Mdot
.52531 .7625 Mdot
.36455 .57854 Mdot
.5838 .63371 Mdot
.61243 .65059 Mdot
.64269 .34505 Mdot
.33943 .57613 Mdot
.6492 .48142 Mdot
.60368 .57021 Mdot
.44897 .35093 Mdot
.61604 .57566 Mdot
.37636 .55335 Mdot
.3192 .56104 Mdot
.37646 .56785 Mdot
.453 .4186 Mdot
.50007 .58033 Mdot
.46947 .44147 Mdot
.58901 .60888 Mdot
.67089 .48159 Mdot
.49759 .21357 Mdot
.32614 .46709 Mdot
.4757 .68562 Mdot
.46191 .34737 Mdot
.47107 .40354 Mdot
.44019 .40479 Mdot
.41807 .40588 Mdot
.78 .49542 Mdot
.44956 .41541 Mdot
.58482 .63939 Mdot
.64335 .51995 Mdot
.46158 .41038 Mdot
.44405 .74016 Mdot
.54507 .4711 Mdot
.64555 .32115 Mdot
.55681 .3737 Mdot
.51914 .84358 Mdot
.34932 .57759 Mdot
.66506 .53301 Mdot
.66171 .47944 Mdot
.62824 .3587 Mdot
.61032 .63383 Mdot
.36205 .57246 Mdot
.56128 .32523 Mdot
.63941 .37653 Mdot
.42295 .39868 Mdot
.56275 .48494 Mdot
.16778 .49531 Mdot
.47679 .419 Mdot
.40572 .37315 Mdot
.4488 .76521 Mdot
.65773 .46919 Mdot
.80749 .65632 Mdot
.50823 .63489 Mdot
.64387 .35073 Mdot
.64786 .32811 Mdot
.37532 .57688 Mdot
.47518 .36878 Mdot
.5966 .63212 Mdot
.51539 .5493 Mdot
.78979 .37707 Mdot
.66049 .75121 Mdot
.71156 .56932 Mdot
.43281 .35698 Mdot
.25071 .53802 Mdot
.41135 .3525 Mdot
.30793 .60631 Mdot
.37172 .56243 Mdot
.3442 .59194 Mdot
.57524 .63118 Mdot
.31201 .26009 Mdot
.58692 .64047 Mdot
.52063 .84482 Mdot
.36319 .60687 Mdot
.62903 .43369 Mdot
.6619 .48812 Mdot
.48354 .44266 Mdot
.66251 .33812 Mdot
.68338 .5552 Mdot
.3753 .40259 Mdot
.40099 .65554 Mdot
.68187 .50848 Mdot
.31133 .58635 Mdot
.50593 .43043 Mdot
.73191 .70622 Mdot
.47964 .61656 Mdot
.74265 .3366 Mdot
.33393 .3118 Mdot
.64329 .33579 Mdot
.20411 .4369 Mdot
.62322 .36058 Mdot
.5867 .65443 Mdot
.41228 .4394 Mdot
.44756 .44564 Mdot
.4019 .39514 Mdot
.44743 .41815 Mdot
.57064 .62268 Mdot
.43215 .35138 Mdot
.502 .19569 Mdot
.44591 .72952 Mdot
.64163 .43057 Mdot
.63126 .34072 Mdot
.60793 .60597 Mdot
.64233 .52426 Mdot
.42987 .75135 Mdot
.64862 .25131 Mdot
.42973 .35332 Mdot
.41872 .36032 Mdot
.43741 .72934 Mdot
.41878 .4651 Mdot
.51016 .41228 Mdot
.65273 .50934 Mdot
.47329 .53115 Mdot
.67362 .34902 Mdot
.648 .32294 Mdot
.58452 .59981 Mdot
.34096 .57395 Mdot
.65128 .37082 Mdot
.62291 .49357 Mdot
.47651 .3805 Mdot
.39005 .35516 Mdot
.37621 .55275 Mdot
.38271 .23988 Mdot
.61759 .34883 Mdot
.51589 .42387 Mdot
.35413 .56182 Mdot
.30288 .60382 Mdot
.41379 .37807 Mdot
.46262 .34156 Mdot
.30768 .58008 Mdot
.63149 .33643 Mdot
.6072 .6038 Mdot
.60637 .45144 Mdot
.60326 .63581 Mdot
.35593 .57067 Mdot
.45163 .45467 Mdot
.32171 .60784 Mdot
.42779 .44297 Mdot
.15783 .3436 Mdot
.47373 .40185 Mdot
.37014 .63965 Mdot
.58854 .32628 Mdot
.64815 .48592 Mdot
.64029 .48969 Mdot
.44103 .74054 Mdot
.36237 .56309 Mdot
.38172 .38669 Mdot
.65491 .32845 Mdot
.5002 .82283 Mdot
.35855 .52571 Mdot
.68423 .52075 Mdot
.67499 .47324 Mdot
.56959 .61934 Mdot
.45867 .36967 Mdot
.42537 .38498 Mdot
.67835 .52045 Mdot
.80144 .41946 Mdot
.33975 .56673 Mdot
.43863 .38716 Mdot
.47026 .41109 Mdot
.64695 .50984 Mdot
.59593 .57084 Mdot
.34505 .63868 Mdot
.47232 .40909 Mdot
.48657 .25266 Mdot
.60029 .60555 Mdot
.43163 .42204 Mdot
.42415 .35163 Mdot
.63996 .35777 Mdot
.67385 .41938 Mdot
.42601 .23864 Mdot
.61639 .62152 Mdot
.4439 .76348 Mdot
.41787 .4439 Mdot
.65888 .4896 Mdot
.396 .34051 Mdot
.78857 .59899 Mdot
.45198 .73129 Mdot
.45107 .40352 Mdot
.38512 .43969 Mdot
.33302 .55893 Mdot
.45312 .4003 Mdot
.27389 .62311 Mdot
.63068 .50941 Mdot
.4518 .40465 Mdot
.31531 .48827 Mdot
.57201 .61661 Mdot
.37627 .40547 Mdot
.65688 .32606 Mdot
.58661 .33417 Mdot
.37565 .78035 Mdot
.69204 .51672 Mdot
.63013 .35152 Mdot
.47291 .3891 Mdot
.62581 .51983 Mdot
.5906 .59517 Mdot
.37778 .67161 Mdot
.4806 .40593 Mdot
.60764 .62996 Mdot
.60455 .62586 Mdot
.64578 .34705 Mdot
.33996 .19459 Mdot
.38511 .44081 Mdot
.43907 .37282 Mdot
.76381 .31536 Mdot
.35086 .62651 Mdot
.44238 .37143 Mdot
.45862 .37071 Mdot
.59217 .6455 Mdot
.45273 .26895 Mdot
.41855 .52879 Mdot
.79644 .4571 Mdot
.60106 .60445 Mdot
.62402 .55184 Mdot
.63303 .52789 Mdot
.63057 .34642 Mdot
.3583 .6039 Mdot
.67221 .33403 Mdot
.64806 .49756 Mdot
.4025 .3847 Mdot
.57042 .6541 Mdot
.26114 .39162 Mdot
.55654 .61849 Mdot
.62189 .51854 Mdot
.30325 .58865 Mdot
.41814 .80224 Mdot
.81729 .34795 Mdot
.38228 .76286 Mdot
.61739 .61634 Mdot
.64021 .3525 Mdot
.50788 .62151 Mdot
.47083 .40193 Mdot
.20288 .41807 Mdot
.4366 .36913 Mdot
.3377 .29998 Mdot
.66161 .54194 Mdot
.43136 .73672 Mdot
.40726 .43581 Mdot
.60771 .2591 Mdot
.6158 .61475 Mdot
.57583 .61057 Mdot
.42207 .40322 Mdot
.58626 .63434 Mdot
.43169 .38733 Mdot
.64252 .51357 Mdot
.3476 .19417 Mdot
.46575 .38416 Mdot
.38018 .40225 Mdot
.60341 .66186 Mdot
.49727 .79188 Mdot
.62893 .55138 Mdot
.25657 .53884 Mdot
.746 .6985 Mdot
.58928 .63198 Mdot
.42997 .31779 Mdot
.67203 .52064 Mdot
.44569 .76676 Mdot
.64819 .45614 Mdot
.42752 .37001 Mdot
.42165 .3563 Mdot
.40282 .40322 Mdot
.46953 .4052 Mdot
.19501 .44101 Mdot
.49927 .4302 Mdot
.24295 .49347 Mdot
.41507 .36114 Mdot
.3876 .61774 Mdot
.57956 .63949 Mdot
.39646 .51129 Mdot
.66745 .38142 Mdot
.42126 .35521 Mdot
.32095 .64524 Mdot
.61093 .6099 Mdot
.53979 .8375 Mdot
.56785 .62848 Mdot
.66729 .51272 Mdot
.57969 .65959 Mdot
.43472 .44384 Mdot
.35386 .59848 Mdot
.6345 .51542 Mdot
.30358 .70064 Mdot
.68495 .49418 Mdot
.46233 .40468 Mdot
.59618 .53623 Mdot
.6516 .48387 Mdot
.55374 .4146 Mdot
.35595 .59925 Mdot
.58361 .25518 Mdot
.34566 .62803 Mdot
.45094 .39443 Mdot
.4498 .38789 Mdot
.42928 .75236 Mdot
.59504 .64989 Mdot
.3622 .61127 Mdot
.53614 .17028 Mdot
.64877 .38149 Mdot
.33982 .59873 Mdot
.47786 .35302 Mdot
.49852 .59184 Mdot
.32407 .57357 Mdot
.58905 .29234 Mdot
.59781 .64615 Mdot
.37468 .58964 Mdot
.49663 .41216 Mdot
.49213 .31087 Mdot
.6226 .34145 Mdot
.63164 .53857 Mdot
.52358 .51898 Mdot
.63132 .52329 Mdot
.55928 .6659 Mdot
.67979 .47095 Mdot
.57248 .63543 Mdot
.2936 .65548 Mdot
.44149 .54683 Mdot
.56454 .66933 Mdot
.59474 .664 Mdot
.65396 .49879 Mdot
.4166 .40363 Mdot
.59656 .43113 Mdot
.47894 .35779 Mdot
.43313 .45824 Mdot
.60604 .61061 Mdot
.37136 .57684 Mdot
.33435 .61525 Mdot
.34018 .64809 Mdot
.31722 .57468 Mdot
.63701 .52293 Mdot
.46008 .66161 Mdot
.33546 .28909 Mdot
.5626 .62613 Mdot
.63168 .63605 Mdot
.40869 .4124 Mdot
.65533 .49263 Mdot
.64464 .53557 Mdot
.59923 .63486 Mdot
.24981 .36531 Mdot
.38406 .42353 Mdot
.33109 .62301 Mdot
.36216 .60844 Mdot
.32291 .57866 Mdot
.35998 .54921 Mdot
.28413 .27959 Mdot
.55853 .61751 Mdot
.36846 .57321 Mdot
.43664 .4147 Mdot
.42944 .3596 Mdot
.45024 .75807 Mdot
.63727 .33279 Mdot
.40359 .43736 Mdot
.39313 .42943 Mdot
.41504 .37768 Mdot
.65011 .48575 Mdot
.38762 .46959 Mdot
.45331 .73409 Mdot
.67724 .47072 Mdot
.69277 .49648 Mdot
.43185 .74632 Mdot
.36275 .52068 Mdot
.72242 .72792 Mdot
.40017 .39583 Mdot
.3394 .38887 Mdot
.66022 .49308 Mdot
.43929 .61449 Mdot
.49512 .32867 Mdot
.42328 .41772 Mdot
.62659 .41309 Mdot
.63935 .51423 Mdot
.307 .5583 Mdot
.43265 .37307 Mdot
.43673 .73519 Mdot
.63701 .3259 Mdot
.49252 .38905 Mdot
.44907 .76547 Mdot
.33501 .58408 Mdot
.76802 .39957 Mdot
.36002 .62046 Mdot
.64963 .48319 Mdot
.37481 .39546 Mdot
.13 .6459 Mdot
.65283 .5281 Mdot
.57116 .81068 Mdot
.44547 .53854 Mdot
.46958 .39068 Mdot
.63551 .52749 Mdot
.30262 .56643 Mdot
.6008 .60607 Mdot
.53907 .50875 Mdot
.36541 .59953 Mdot
.42946 .74746 Mdot
.4412 .76027 Mdot
.64893 .50885 Mdot
.33678 .60963 Mdot
.44637 .35326 Mdot
.3481 .55327 Mdot
.56287 .65732 Mdot
.43453 .43669 Mdot
.71403 .71761 Mdot
.49172 .36 Mdot
.35498 .56058 Mdot
.62087 .49561 Mdot
.65867 .37158 Mdot
.44605 .4308 Mdot
.63342 .78744 Mdot
.46173 .37185 Mdot
.565 .62676 Mdot
.4292 .60182 Mdot
.25213 .40554 Mdot
.40909 .39592 Mdot
.40392 .41267 Mdot
.59137 .59786 Mdot
.40607 .39336 Mdot
.47903 .4028 Mdot
.56604 .59433 Mdot
.32412 .56921 Mdot
.44465 .4035 Mdot
.63914 .53975 Mdot
.33229 .345 Mdot
.39575 .42362 Mdot
.29987 .67702 Mdot
.59563 .25496 Mdot
.42853 .58296 Mdot
.3803 .38535 Mdot
.60233 .22408 Mdot
.44643 .38392 Mdot
.44849 .42477 Mdot
.40705 .40232 Mdot
.24143 .54549 Mdot
.65109 .49661 Mdot
.66371 .54451 Mdot
.62867 .32981 Mdot
.60003 .2605 Mdot
.63684 .36004 Mdot
.60576 .60077 Mdot
.63813 .66394 Mdot
.44577 .73047 Mdot
.34269 .57145 Mdot
.38944 .39716 Mdot
.6865 .4922 Mdot
.42198 .37818 Mdot
.41376 .4327 Mdot
.63943 .50633 Mdot
.64132 .53002 Mdot
.69539 .49356 Mdot
.62883 .37125 Mdot
.34393 .58398 Mdot
.39933 .37888 Mdot
.6402 .3756 Mdot
.45459 .35911 Mdot
.50152 .59502 Mdot
.34266 .5869 Mdot
.34683 .55306 Mdot
.34008 .62029 Mdot
.40681 .36356 Mdot
.44398 .4417 Mdot
.58812 .64067 Mdot
.37846 .55524 Mdot
.56203 .62204 Mdot
.63447 .52557 Mdot
.64068 .49109 Mdot
.42738 .3696 Mdot
.51113 .43069 Mdot
.64155 .33243 Mdot
.67056 .51112 Mdot
.45201 .72377 Mdot
.63004 .32844 Mdot
.45954 .41305 Mdot
.63235 .52247 Mdot
.65181 .32228 Mdot
.27845 .34811 Mdot
.76706 .67565 Mdot
.64664 .37807 Mdot
.42313 .40361 Mdot
.30718 .51364 Mdot
.46726 .24474 Mdot
.657 .37893 Mdot
.56441 .63976 Mdot
.45057 .36719 Mdot
.8133 .42483 Mdot
.67541 .34527 Mdot
.38678 .23964 Mdot
.64088 .50099 Mdot
.39139 .29125 Mdot
.49358 .38991 Mdot
.23292 .36624 Mdot
.67567 .34155 Mdot
.35999 .57414 Mdot
.38068 .58155 Mdot
.4191 .39796 Mdot
.66158 .38116 Mdot
.55268 .64851 Mdot
.66114 .47896 Mdot
.69091 .50614 Mdot
.33187 .6079 Mdot
.47076 .67879 Mdot
.63725 .53687 Mdot
.37261 .37724 Mdot
.61871 .48118 Mdot
.35052 .39133 Mdot
.23675 .32588 Mdot
.29938 .70938 Mdot
.38839 .36341 Mdot
.65962 .37216 Mdot
.61047 .59938 Mdot
.58839 .63801 Mdot
.57764 .63042 Mdot
.6341 .49817 Mdot
.49392 .57223 Mdot
.67776 .52606 Mdot
.37293 .69308 Mdot
.65049 .33809 Mdot
.56292 .26209 Mdot
.38484 .39914 Mdot
.46965 .39266 Mdot
.47684 .37939 Mdot
.40139 .4028 Mdot
.44505 .38408 Mdot
.6071 .61815 Mdot
.64725 .47787 Mdot
.77768 .44546 Mdot
.3242 .5881 Mdot
.52021 .74796 Mdot
.66255 .48795 Mdot
.45607 .7569 Mdot
.65596 .35558 Mdot
.55284 .20769 Mdot
.6174 .55297 Mdot
.6704 .49068 Mdot
.48235 .40579 Mdot
.37028 .56688 Mdot
.44282 .28001 Mdot
.45352 .38162 Mdot
.67167 .51127 Mdot
.63114 .47341 Mdot
.21233 .42704 Mdot
.3606 .37938 Mdot
.64335 .30782 Mdot
.49685 .59273 Mdot
.67848 .34931 Mdot
.44703 .33669 Mdot
.43949 .61977 Mdot
.64894 .49953 Mdot
.66204 .51395 Mdot
.64811 .37981 Mdot
.40741 .49625 Mdot
.34866 .60885 Mdot
.43215 .73484 Mdot
.56784 .64103 Mdot
.46042 .38691 Mdot
.6318 .50262 Mdot
.34718 .43352 Mdot
.56082 .49087 Mdot
.58006 .6175 Mdot
.67442 .46983 Mdot
.44999 .36463 Mdot
.41396 .39625 Mdot
.6405 .33858 Mdot
.7029 .36767 Mdot
.48489 .36736 Mdot
.5124 .82648 Mdot
.46543 .61821 Mdot
.49983 .49111 Mdot
.41782 .38214 Mdot
.31887 .59993 Mdot
.43532 .74004 Mdot
.66604 .34624 Mdot
.45531 .36157 Mdot
.75278 .70363 Mdot
.38853 .57014 Mdot
.60017 .61596 Mdot
.43478 .73866 Mdot
.49836 .5607 Mdot
.46398 .37354 Mdot
.43646 .3693 Mdot
.45068 .41837 Mdot
.76322 .69783 Mdot
.65954 .54481 Mdot
.37553 .55918 Mdot
.65586 .3664 Mdot
.33659 .55307 Mdot
.6775 .53282 Mdot
.53793 .46484 Mdot
.46114 .41582 Mdot
.32876 .61995 Mdot
.36204 .57725 Mdot
.57043 .61758 Mdot
.61437 .6221 Mdot
.66516 .55131 Mdot
.47285 .39507 Mdot
.44043 .73049 Mdot
.37253 .58974 Mdot
.64283 .47516 Mdot
.64175 .33855 Mdot
.61467 .63915 Mdot
.4129 .36158 Mdot
.6502 .50496 Mdot
.41087 .34951 Mdot
.33832 .55926 Mdot
.66875 .48997 Mdot
.45661 .75937 Mdot
.64231 .33038 Mdot
.41732 .35796 Mdot
.77919 .40118 Mdot
.43279 .73877 Mdot
.45784 .43714 Mdot
.33427 .50928 Mdot
.64532 .39369 Mdot
.29926 .69808 Mdot
.66302 .53763 Mdot
.44852 .73592 Mdot
.37332 .56261 Mdot
.47262 .29795 Mdot
.65664 .51836 Mdot
.26888 .57259 Mdot
.61982 .42787 Mdot
.40026 .38629 Mdot
.33903 .60312 Mdot
.68169 .32122 Mdot
.54099 .82942 Mdot
.49245 .24184 Mdot
.44011 .39253 Mdot
.63119 .52373 Mdot
.64696 .32276 Mdot
.56565 .61833 Mdot
.30289 .67702 Mdot
.23357 .33793 Mdot
.68002 .474 Mdot
.39588 .37952 Mdot
.37307 .58554 Mdot
.60032 .63103 Mdot
.31421 .74135 Mdot
.62128 .4992 Mdot
.65024 .54359 Mdot
.4555 .42327 Mdot
.65985 .36435 Mdot
.80969 .44602 Mdot
.65655 .54742 Mdot
.63264 .49425 Mdot
.50941 .75742 Mdot
.61927 .36091 Mdot
.43404 .41139 Mdot
.33928 .64837 Mdot
.47556 .3805 Mdot
.52307 .81708 Mdot
.44656 .73375 Mdot
.32501 .58468 Mdot
.43135 .36374 Mdot
.77693 .43014 Mdot
.64883 .52469 Mdot
.49217 .59899 Mdot
.53172 .63112 Mdot
.61202 .63019 Mdot
.6324 .50453 Mdot
.42855 .37711 Mdot
.61442 .649 Mdot
.63889 .33501 Mdot
.47248 .40882 Mdot
.43607 .44297 Mdot
.29829 .58069 Mdot
.56604 .65557 Mdot
.33592 .34903 Mdot
.56792 .66327 Mdot
.58075 .59977 Mdot
.30387 .60674 Mdot
.42054 .39801 Mdot
.6712 .50404 Mdot
.62427 .52981 Mdot
.43403 .35006 Mdot
.44119 .61199 Mdot
.34561 .608 Mdot
.62561 .45537 Mdot
.80718 .65147 Mdot
.37728 .4352 Mdot
.45496 .7265 Mdot
.36199 .29942 Mdot
.58364 .60477 Mdot
.40426 .38271 Mdot
.34529 .56518 Mdot
.63824 .48336 Mdot
.63467 .53683 Mdot
.48462 .41141 Mdot
.60186 .63345 Mdot
.65311 .32011 Mdot
.65039 .53891 Mdot
.55824 .4971 Mdot
.45451 .40494 Mdot
.36652 .68573 Mdot
.65646 .53697 Mdot
.43715 .82993 Mdot
.77681 .43699 Mdot
.32314 .59697 Mdot
.41121 .42579 Mdot
.34178 .54635 Mdot
.65163 .36766 Mdot
.65489 .45636 Mdot
.60206 .63534 Mdot
.52408 .42953 Mdot
.59816 .19459 Mdot
.65223 .49187 Mdot
.33848 .58093 Mdot
.40271 .37191 Mdot
.52134 .39063 Mdot
.46564 .37922 Mdot
.47733 .27854 Mdot
.66404 .29322 Mdot
.59961 .66049 Mdot
.57171 .61128 Mdot
.39928 .41385 Mdot
.62499 .36246 Mdot
.63253 .54487 Mdot
.64093 .50409 Mdot
.26938 .23972 Mdot
.45151 .7651 Mdot
.63909 .28812 Mdot
.40905 .36233 Mdot
.64996 .47302 Mdot
.32565 .45854 Mdot
.55641 .6314 Mdot
.46113 .35634 Mdot
.66828 .47471 Mdot
.56323 .7794 Mdot
.50394 .58341 Mdot
.44822 .40043 Mdot
.41395 .46608 Mdot
.56515 .6337 Mdot
.50746 .62328 Mdot
.67911 .52277 Mdot
.46324 .36243 Mdot
.54258 .64508 Mdot
.49351 .78241 Mdot
.56904 .18506 Mdot
.34405 .58447 Mdot
.62295 .48781 Mdot
.61154 .62701 Mdot
.37949 .45669 Mdot
.63193 .33807 Mdot
.62754 .49805 Mdot
.67495 .48212 Mdot
.42613 .43417 Mdot
.39492 .42739 Mdot
.36459 .4127 Mdot
.33335 .5946 Mdot
.58544 .64618 Mdot
.39714 .41875 Mdot
.47659 .65977 Mdot
.39759 .39544 Mdot
.58929 .64482 Mdot
.09283 .51731 Mdot
.47661 .42314 Mdot
.44898 .37242 Mdot
.57093 .36229 Mdot
.34557 .61458 Mdot
.32552 .56391 Mdot
.46652 .64879 Mdot
.40984 .36166 Mdot
.59242 .47474 Mdot
.3446 .58045 Mdot
.34679 .60642 Mdot
.61003 .45391 Mdot
.43383 .43343 Mdot
.57089 .68225 Mdot
.59703 .63393 Mdot
.6128 .62813 Mdot
.33589 .55733 Mdot
.48628 .43897 Mdot
.5962 .59472 Mdot
.18699 .46546 Mdot
.66645 .48637 Mdot
.43924 .62039 Mdot
.3509 .55519 Mdot
.59347 .45205 Mdot
.5928 .65081 Mdot
.47709 .85917 Mdot
.51906 .3262 Mdot
.43105 .3451 Mdot
.41342 .39778 Mdot
.63732 .35385 Mdot
.4975 .34779 Mdot
.44591 .76324 Mdot
.58409 .635 Mdot
.76817 .51795 Mdot
.34432 .5928 Mdot
.45433 .37416 Mdot
.50618 .21143 Mdot
.33036 .74247 Mdot
.35246 .667 Mdot
.36123 .60235 Mdot
.34702 .59853 Mdot
.6829 .50611 Mdot
.66358 .48242 Mdot
.44224 .4123 Mdot
.57693 .63448 Mdot
.37583 .59214 Mdot
.57622 .64983 Mdot
.6479 .49868 Mdot
.66874 .49264 Mdot
.45521 .73435 Mdot
.46221 .45795 Mdot
.64007 .4959 Mdot
.51237 .77404 Mdot
.47732 .65486 Mdot
.3147 .55173 Mdot
.80764 .3408 Mdot
.3096 .74069 Mdot
.57213 .35428 Mdot
.63479 .32694 Mdot
.42242 .7615 Mdot
.59378 .65439 Mdot
.39942 .41207 Mdot
.41934 .36699 Mdot
.44669 .75602 Mdot
.60758 .64029 Mdot
.6503 .35989 Mdot
.59345 .65143 Mdot
.66295 .34329 Mdot
.65784 .54973 Mdot
.39778 .42736 Mdot
.47337 .38514 Mdot
.59204 .61127 Mdot
.67835 .51106 Mdot
.64941 .48395 Mdot
.62681 .33577 Mdot
.5571 .21355 Mdot
.64813 .50761 Mdot
.35054 .55481 Mdot
.31032 .36261 Mdot
.44205 .75983 Mdot
.43327 .3737 Mdot
.53339 .20374 Mdot
.21464 .4122 Mdot
.39874 .38534 Mdot
.43439 .73833 Mdot
.28896 .22027 Mdot
.40909 .43784 Mdot
.24876 .28146 Mdot
.45349 .73709 Mdot
.32407 .61003 Mdot
.66923 .52504 Mdot
.44031 .76407 Mdot
.38741 .46771 Mdot
.67702 .29827 Mdot
.37887 .3721 Mdot
.36185 .60641 Mdot
.31925 .61176 Mdot
.45092 .54365 Mdot
.52806 .81582 Mdot
.66604 .35928 Mdot
.65027 .3538 Mdot
.65406 .5182 Mdot
.60968 .69774 Mdot
.41501 .34031 Mdot
.64749 .35472 Mdot
.78843 .52344 Mdot
.41056 .41283 Mdot
.63592 .27317 Mdot
.61925 .41491 Mdot
.32173 .60311 Mdot
.40417 .51474 Mdot
.65196 .522 Mdot
.33877 .58144 Mdot
.51673 .49166 Mdot
.47559 .37777 Mdot
.34287 .58941 Mdot
.58903 .64707 Mdot
.66418 .6983 Mdot
.31824 .56978 Mdot
.54264 .50569 Mdot
.59662 .6307 Mdot
.65002 .3915 Mdot
.53347 .28369 Mdot
.85678 .61986 Mdot
.5821 .63566 Mdot
.67212 .51736 Mdot
.64194 .4915 Mdot
.6452 .51168 Mdot
.36476 .60164 Mdot
.64517 .53252 Mdot
.3282 .58705 Mdot
.61238 .56446 Mdot
.58763 .21874 Mdot
.6434 .34221 Mdot
.62935 .59539 Mdot
.35797 .58416 Mdot
.39695 .69625 Mdot
.76116 .29384 Mdot
.42703 .40789 Mdot
.55685 .66069 Mdot
.6595 .3737 Mdot
.46732 .69886 Mdot
.63985 .35849 Mdot
.6722 .52129 Mdot
.43858 .62234 Mdot
.43246 .38849 Mdot
.26533 .61004 Mdot
.65808 .32829 Mdot
.36344 .60141 Mdot
.46685 .42385 Mdot
.66116 .5559 Mdot
.63198 .35633 Mdot
.63596 .32733 Mdot
.44318 .38199 Mdot
.31225 .59233 Mdot
.6715 .49759 Mdot
.59515 .6567 Mdot
.685 .34383 Mdot
.44674 .46886 Mdot
.41265 .40119 Mdot
.48611 .39221 Mdot
.48285 .60634 Mdot
.81354 .43981 Mdot
.59064 .63051 Mdot
.46413 .24079 Mdot
.64918 .48867 Mdot
.4913 .24676 Mdot
.39766 .72733 Mdot
.62813 .57968 Mdot
.44795 .73353 Mdot
.44528 .73308 Mdot
.44641 .3945 Mdot
.81698 .47391 Mdot
.35417 .65459 Mdot
.55224 .61696 Mdot
.43719 .75558 Mdot
.65024 .48356 Mdot
.38344 .56238 Mdot
.43756 .50239 Mdot
.42858 .45071 Mdot
.61537 .62621 Mdot
.64525 .50348 Mdot
.7898 .59737 Mdot
.6508 .33997 Mdot
.4466 .66315 Mdot
.46262 .4107 Mdot
.43731 .38404 Mdot
.59244 .62054 Mdot
.58877 .63992 Mdot
.34264 .68224 Mdot
.45584 .55917 Mdot
.67953 .72868 Mdot
.58027 .68272 Mdot
.80086 .57974 Mdot
.32862 .64031 Mdot
.35069 .56121 Mdot
.45832 .73867 Mdot
.5968 .5963 Mdot
.44096 .36937 Mdot
.32723 .61201 Mdot
.35698 .66334 Mdot
.29497 .5919 Mdot
.62545 .2735 Mdot
.59941 .45591 Mdot
.46627 .40907 Mdot
.36845 .56128 Mdot
.33945 .58377 Mdot
.35168 .54595 Mdot
.43243 .74642 Mdot
.41483 .38193 Mdot
.41829 .40506 Mdot
.41455 .44059 Mdot
.51962 .4014 Mdot
.45386 .40101 Mdot
.40176 .72969 Mdot
.47953 .68783 Mdot
.71911 .44774 Mdot
.39855 .37296 Mdot
.6071 .6354 Mdot
.38921 .39499 Mdot
.62483 .35847 Mdot
.39687 .37301 Mdot
.65433 .27718 Mdot
.58083 .62584 Mdot
.43414 .49099 Mdot
.64676 .44958 Mdot
.46291 .41331 Mdot
.66273 .32421 Mdot
.81417 .445 Mdot
.48879 .21287 Mdot
.51004 .76071 Mdot
.35001 .5546 Mdot
.67382 .54479 Mdot
.5535 .64159 Mdot
.67001 .50423 Mdot
.44934 .3496 Mdot
.45286 .72708 Mdot
.2743 .73346 Mdot
.58114 .45298 Mdot
.43896 .36737 Mdot
.49 .443 Mdot
.31781 .59041 Mdot
.64824 .52701 Mdot
.29933 .61765 Mdot
.45008 .42249 Mdot
.64824 .37034 Mdot
.64282 .37315 Mdot
.48088 .5068 Mdot
.77035 .59429 Mdot
.46749 .28955 Mdot
.59219 .62266 Mdot
.63267 .53525 Mdot
.67509 .34072 Mdot
.31819 .65893 Mdot
.5515 .63929 Mdot
.58361 .60491 Mdot
.56675 .65498 Mdot
.46654 .40068 Mdot
.45681 .74546 Mdot
.7803 .55719 Mdot
.43075 .75349 Mdot
.46271 .42005 Mdot
.6792 .48723 Mdot
.4399 .76457 Mdot
.63627 .3564 Mdot
.58386 .60029 Mdot
.65472 .48607 Mdot
.45145 .39126 Mdot
.34874 .58034 Mdot
.472 .23003 Mdot
.72795 .30774 Mdot
.60491 .49343 Mdot
.60376 .49647 Mdot
.34845 .62146 Mdot
.62567 .80386 Mdot
.61475 .57582 Mdot
.24554 .36941 Mdot
.67194 .30823 Mdot
.43382 .34953 Mdot
.36978 .19956 Mdot
.67565 .52771 Mdot
.63492 .51877 Mdot
.44911 .40538 Mdot
.62865 .48546 Mdot
.45855 .37533 Mdot
.68374 .51562 Mdot
.5931 .79266 Mdot
.44803 .44992 Mdot
.63621 .52052 Mdot
.42604 .33767 Mdot
.45048 .43168 Mdot
.31666 .59242 Mdot
.63003 .493 Mdot
.42664 .34497 Mdot
.25689 .72829 Mdot
.57717 .61296 Mdot
.43241 .74943 Mdot
.6346 .65027 Mdot
.57779 .65826 Mdot
.33201 .60016 Mdot
.40587 .43705 Mdot
.64126 .33505 Mdot
.3565 .57445 Mdot
.68084 .54346 Mdot
.66418 .33318 Mdot
.46151 .66285 Mdot
.34556 .55605 Mdot
.44899 .75727 Mdot
.64647 .32915 Mdot
.37752 .37466 Mdot
.6358 .51041 Mdot
.77406 .35269 Mdot
.43142 .75389 Mdot
.42615 .38446 Mdot
.61673 .51372 Mdot
.59222 .6521 Mdot
.43697 .40629 Mdot
.62896 .52173 Mdot
.43261 .7427 Mdot
.45477 .43762 Mdot
.45834 .43587 Mdot
.46237 .49349 Mdot
.41464 .61998 Mdot
.63945 .34236 Mdot
.30411 .60464 Mdot
.43952 .41622 Mdot
.62399 .36137 Mdot
.68507 .59759 Mdot
.38604 .3779 Mdot
.3335 .55111 Mdot
.52831 .41591 Mdot
.66618 .48189 Mdot
.56338 .61972 Mdot
.62156 .5196 Mdot
.63966 .32383 Mdot
.575 .16006 Mdot
.45608 .754 Mdot
.47496 .45512 Mdot
.47704 .37863 Mdot
.66483 .46309 Mdot
.33847 .58847 Mdot
.65761 .73843 Mdot
.41401 .35928 Mdot
.50025 .41615 Mdot
.43877 .37685 Mdot
.77324 .4376 Mdot
.34846 .60767 Mdot
.43617 .37445 Mdot
.49447 .44689 Mdot
.38139 .36347 Mdot
.66247 .32232 Mdot
.55722 .27099 Mdot
.39075 .39526 Mdot
.20149 .73651 Mdot
.43892 .72831 Mdot
.64004 .50818 Mdot
.53179 .54744 Mdot
.73826 .52655 Mdot
.24191 .31383 Mdot
.33009 .59104 Mdot
.3856 .31034 Mdot
.67097 .50027 Mdot
.46193 .21515 Mdot
.58561 .82664 Mdot
.45348 .43066 Mdot
.44581 .36335 Mdot
.67217 .52128 Mdot
.64549 .47514 Mdot
.44767 .72772 Mdot
.4076 .35626 Mdot
.49701 .42264 Mdot
.63654 .47436 Mdot
.45754 .3936 Mdot
.20779 .51561 Mdot
.57942 .66591 Mdot
.33021 .5605 Mdot
.56541 .61876 Mdot
.58839 .6063 Mdot
.30063 .3061 Mdot
.4651 .61765 Mdot
.58912 .64335 Mdot
.56866 .59612 Mdot
.66474 .27499 Mdot
.52737 .42909 Mdot
.67046 .33028 Mdot
.74213 .64992 Mdot
.65056 .51519 Mdot
.4133 .38142 Mdot
.36982 .59 Mdot
.25138 .33524 Mdot
.63859 .71467 Mdot
.43338 .64065 Mdot
.42462 .40888 Mdot
.6467 .52218 Mdot
.43101 .74442 Mdot
.44217 .45126 Mdot
.47968 .24801 Mdot
.43813 .38867 Mdot
.65847 .47876 Mdot
.31477 .2972 Mdot
.2744 .60751 Mdot
.57361 .68057 Mdot
.34726 .53445 Mdot
.38955 .40728 Mdot
.33594 .56552 Mdot
.60854 .63058 Mdot
.62796 .3697 Mdot
.64106 .35155 Mdot
.47051 .40658 Mdot
.44144 .54775 Mdot
.6942 .34855 Mdot
.45051 .43045 Mdot
.42949 .43492 Mdot
.45037 .73551 Mdot
.43071 .43554 Mdot
.46818 .36867 Mdot
.39377 .40851 Mdot
.39659 .36041 Mdot
.58298 .59895 Mdot
.31942 .52221 Mdot
.39121 .38037 Mdot
.37856 .4391 Mdot
.61134 .64905 Mdot
.35608 .41575 Mdot
.56856 .62945 Mdot
.72401 .69873 Mdot
.5703 .63922 Mdot
.64131 .3494 Mdot
.62532 .54187 Mdot
.36868 .32162 Mdot
.37484 .59435 Mdot
.61377 .61884 Mdot
.65924 .34624 Mdot
.58008 .63352 Mdot
.64366 .54657 Mdot
.79015 .33713 Mdot
.31531 .61923 Mdot
.50431 .59296 Mdot
.56045 .36177 Mdot
.36456 .68549 Mdot
.67146 .48631 Mdot
.33167 .60706 Mdot
.27412 .62175 Mdot
.39887 .41594 Mdot
.63665 .33906 Mdot
.44513 .39296 Mdot
.57801 .60186 Mdot
.64731 .51905 Mdot
.5973 .54017 Mdot
.6385 .34361 Mdot
.64947 .20489 Mdot
.68652 .49489 Mdot
.41982 .4595 Mdot
.61108 .65094 Mdot
.79493 .32875 Mdot
.56823 .63636 Mdot
.58157 .21571 Mdot
.39549 .56309 Mdot
.32659 .28207 Mdot
.35256 .59547 Mdot
.31625 .67076 Mdot
.68208 .78751 Mdot
.59074 .81591 Mdot
.35229 .57046 Mdot
.63164 .45084 Mdot
.46073 .40296 Mdot
.39866 .40121 Mdot
.36846 .39319 Mdot
.32011 .54475 Mdot
.44636 .41714 Mdot
.44665 .76198 Mdot
.47125 .61892 Mdot
.79625 .47862 Mdot
.65563 .55365 Mdot
.4601 .37514 Mdot
.60583 .61118 Mdot
.56386 .60912 Mdot
.43564 .7618 Mdot
.56865 .66045 Mdot
.4435 .4326 Mdot
.35708 .58768 Mdot
.58794 .43826 Mdot
.64405 .36689 Mdot
.44718 .7991 Mdot
.67861 .32452 Mdot
.62319 .5614 Mdot
.37135 .4186 Mdot
.6689 .49211 Mdot
.47135 .15344 Mdot
.4008 .40943 Mdot
.34345 .57854 Mdot
.4672 .42005 Mdot
.3927 .40916 Mdot
.39341 .38546 Mdot
.6296 .52636 Mdot
.53047 .55331 Mdot
.45661 .39085 Mdot
.60029 .63983 Mdot
.62785 .44247 Mdot
.40392 .43868 Mdot
.75542 .54646 Mdot
.61226 .27814 Mdot
.37691 .68742 Mdot
.32577 .54304 Mdot
.66557 .52028 Mdot
.34591 .59491 Mdot
.33643 .53245 Mdot
.3318 .60006 Mdot
.76905 .53445 Mdot
.40796 .28172 Mdot
.22403 .30831 Mdot
.31403 .44115 Mdot
.25635 .34137 Mdot
.33473 .62329 Mdot
.6992 .6096 Mdot
.34848 .56403 Mdot
.33003 .59539 Mdot
.12794 .39805 Mdot
.36131 .56355 Mdot
.42567 .36996 Mdot
.46629 .44046 Mdot
.37482 .76847 Mdot
.65622 .26884 Mdot
.39726 .37391 Mdot
.44412 .41536 Mdot
.65871 .36962 Mdot
.50607 .44108 Mdot
.42698 .75365 Mdot
.45059 .64277 Mdot
.42973 .72044 Mdot
.44353 .38295 Mdot
.44951 .4108 Mdot
.48775 .3852 Mdot
.68193 .79232 Mdot
.24544 .33345 Mdot
.32805 .61578 Mdot
.37911 .4701 Mdot
.49307 .80354 Mdot
.48008 .39871 Mdot
.47737 .40701 Mdot
.43038 .4437 Mdot
.6713 .50272 Mdot
.38527 .56873 Mdot
.5001 .3967 Mdot
.36323 .71901 Mdot
.46054 .41171 Mdot
.63761 .56903 Mdot
.628 .39888 Mdot
.42774 .37621 Mdot
.34038 .54988 Mdot
.40983 .40719 Mdot
.36026 .55524 Mdot
.33198 .56031 Mdot
.47021 .4552 Mdot
.77814 .56771 Mdot
.37761 .54724 Mdot
.45861 .43043 Mdot
.67633 .51077 Mdot
.54411 .82704 Mdot
.42521 .38243 Mdot
.66418 .3599 Mdot
.40348 .38387 Mdot
.65724 .32112 Mdot
.43609 .44038 Mdot
.42977 .74905 Mdot
.24225 .41901 Mdot
.66044 .51437 Mdot
.68563 .33653 Mdot
.64119 .4742 Mdot
.50714 .47455 Mdot
.30888 .58683 Mdot
.42554 .7483 Mdot
.21233 .3632 Mdot
.45136 .73651 Mdot
.44668 .23936 Mdot
.637 .69438 Mdot
.59124 .60877 Mdot
.36147 .55035 Mdot
.38944 .27718 Mdot
.75641 .57665 Mdot
.69354 .49178 Mdot
.69284 .4953 Mdot
.50178 .16327 Mdot
.34272 .19567 Mdot
.45646 .38629 Mdot
.81523 .40327 Mdot
.24812 .47552 Mdot
.39325 .34945 Mdot
.42217 .3286 Mdot
.67042 .47835 Mdot
.3889 .40793 Mdot
.53485 .50479 Mdot
.65354 .49799 Mdot
.65557 .34804 Mdot
.32591 .5817 Mdot
.63557 .33061 Mdot
.69352 .70099 Mdot
.48306 .67072 Mdot
.64695 .49293 Mdot
.39029 .3695 Mdot
.46393 .38704 Mdot
.36898 .5565 Mdot
.25935 .62093 Mdot
.32405 .56835 Mdot
.67116 .34889 Mdot
.65939 .50418 Mdot
.23179 .36263 Mdot
.40478 .37591 Mdot
.36323 .58032 Mdot
.67828 .46059 Mdot
.41284 .39544 Mdot
.59852 .61266 Mdot
.42408 .40932 Mdot
.36033 .568 Mdot
.43101 .43608 Mdot
.35542 .58948 Mdot
.68014 .51657 Mdot
.46494 .37186 Mdot
.44725 .41038 Mdot
.42487 .2387 Mdot
.65027 .36073 Mdot
.30915 .59389 Mdot
.53016 .5111 Mdot
.47628 .3829 Mdot
.48076 .2501 Mdot
.40143 .43181 Mdot
.38457 .32471 Mdot
.46218 .34182 Mdot
.44952 .75961 Mdot
.4635 .35596 Mdot
.42658 .38305 Mdot
.27089 .5577 Mdot
.32196 .48709 Mdot
.41515 .51003 Mdot
.61473 .61575 Mdot
.33818 .55136 Mdot
.63814 .49486 Mdot
.64198 .48198 Mdot
.65164 .5348 Mdot
.64087 .25703 Mdot
.4443 .47066 Mdot
.43151 .38978 Mdot
.59945 .66115 Mdot
.64889 .35165 Mdot
.36487 .59432 Mdot
.64561 .34661 Mdot
.44995 .63818 Mdot
.66997 .34022 Mdot
.44952 .76169 Mdot
.77745 .43662 Mdot
.1924 .48659 Mdot
.66753 .34765 Mdot
.32528 .56639 Mdot
.59263 .46701 Mdot
.43059 .34846 Mdot
.53826 .78182 Mdot
.64915 .37042 Mdot
.533 .16863 Mdot
.45742 .44047 Mdot
.53364 .51588 Mdot
.5703 .62378 Mdot
.639 .32903 Mdot
.56356 .65453 Mdot
.40648 .40702 Mdot
.2967 .69554 Mdot
.33992 .57654 Mdot
.56945 .66812 Mdot
.44678 .34499 Mdot
.63631 .33038 Mdot
.64289 .49538 Mdot
.53208 .35247 Mdot
.61148 .63684 Mdot
.47287 .22293 Mdot
.49209 .24199 Mdot
.65866 .50223 Mdot
.17027 .49917 Mdot
.56192 .64412 Mdot
.39064 .36214 Mdot
.41901 .29012 Mdot
.41703 .4104 Mdot
.64244 .48643 Mdot
.6365 .52569 Mdot
.41433 .78253 Mdot
.46895 .40717 Mdot
.44703 .44673 Mdot
.37653 .6017 Mdot
.65469 .49095 Mdot
.33564 .60492 Mdot
.37736 .5617 Mdot
.67419 .51825 Mdot
.32397 .5988 Mdot
.65696 .32742 Mdot
.46629 .60749 Mdot
.56289 .64399 Mdot
.60545 .62431 Mdot
.64129 .49437 Mdot
.64212 .54868 Mdot
.66711 .49034 Mdot
.42841 .41404 Mdot
.34604 .61184 Mdot
.41487 .42468 Mdot
.38989 .39269 Mdot
.39682 .58501 Mdot
.35533 .61535 Mdot
.41236 .4183 Mdot
.63306 .42471 Mdot
.62718 .32502 Mdot
.63708 .52184 Mdot
.5789 .64961 Mdot
.41556 .23553 Mdot
.57561 .66706 Mdot
.47502 .40593 Mdot
.55938 .78198 Mdot
.36331 .60285 Mdot
.63868 .35719 Mdot
.63555 .39065 Mdot
.63683 .34765 Mdot
.56925 .66819 Mdot
.37365 .55391 Mdot
.46358 .6624 Mdot
.47375 .39513 Mdot
.4819 .60612 Mdot
.43756 .249 Mdot
.39071 .72688 Mdot
.58792 .64629 Mdot
.42948 .40893 Mdot
.45323 .73839 Mdot
.20775 .43699 Mdot
.43784 .39438 Mdot
.45775 .35343 Mdot
.73281 .394 Mdot
.37822 .43809 Mdot
.30265 .56915 Mdot
.45347 .52634 Mdot
.45486 .36213 Mdot
.43067 .50581 Mdot
.21367 .28142 Mdot
.45886 .4387 Mdot
.45435 .41355 Mdot
.41482 .37233 Mdot
.40196 .41411 Mdot
.32714 .55167 Mdot
.72067 .36137 Mdot
.60936 .6131 Mdot
.46902 .60401 Mdot
.56594 .65209 Mdot
.63278 .51309 Mdot
.54226 .48694 Mdot
.35266 .54847 Mdot
.63635 .34864 Mdot
.8134 .37039 Mdot
.44949 .61266 Mdot
.68247 .50428 Mdot
.27132 .29784 Mdot
.64335 .36864 Mdot
.43054 .34949 Mdot
.6271 .33078 Mdot
.65611 .47114 Mdot
.59997 .63519 Mdot
.4809 .41078 Mdot
.36744 .60214 Mdot
.32066 .56587 Mdot
.43297 .41315 Mdot
.50248 .82199 Mdot
.58289 .65708 Mdot
.70822 .53713 Mdot
.46665 .40395 Mdot
.45756 .3537 Mdot
.32306 .57574 Mdot
.64654 .52603 Mdot
.63196 .68968 Mdot
.65753 .35588 Mdot
.43656 .3407 Mdot
.40647 .40545 Mdot
.45643 .62809 Mdot
.60035 .59805 Mdot
.43875 .74664 Mdot
.46766 .40608 Mdot
.46565 .62208 Mdot
.46737 .41431 Mdot
.50975 .38553 Mdot
.67506 .49922 Mdot
.44509 .45838 Mdot
.43601 .35801 Mdot
.34056 .42332 Mdot
.55986 .64154 Mdot
.34173 .58501 Mdot
.39332 .58173 Mdot
.43686 .73459 Mdot
.5866 .61258 Mdot
.41424 .41621 Mdot
.57066 .60823 Mdot
.39456 .39174 Mdot
.45433 .3925 Mdot
.58835 .6464 Mdot
.33366 .60477 Mdot
.65838 .73088 Mdot
.29777 .53959 Mdot
.40988 .43196 Mdot
.40293 .39023 Mdot
.64324 .26403 Mdot
.17476 .44276 Mdot
.42895 .35633 Mdot
.35269 .61223 Mdot
.41512 .39629 Mdot
.60769 .62191 Mdot
.67149 .34573 Mdot
.34767 .57621 Mdot
.64833 .55023 Mdot
.67674 .52413 Mdot
.65233 .44838 Mdot
.45382 .75769 Mdot
.41735 .35442 Mdot
.30656 .61193 Mdot
.35563 .61706 Mdot
.46991 .71218 Mdot
.6392 .50888 Mdot
.66864 .33195 Mdot
.43371 .44617 Mdot
.52342 .34072 Mdot
.59762 .6054 Mdot
.20773 .7418 Mdot
.4663 .66787 Mdot
.66202 .3176 Mdot
.4282 .57719 Mdot
.45307 .74556 Mdot
.44281 .36664 Mdot
.62401 .35427 Mdot
.65821 .53966 Mdot
.40075 .40368 Mdot
.39097 .46132 Mdot
.75069 .58956 Mdot
.66484 .54767 Mdot
.56619 .61387 Mdot
.65844 .54337 Mdot
.64847 .31791 Mdot
.44786 .76258 Mdot
.31335 .58777 Mdot
.43064 .38219 Mdot
.35634 .43965 Mdot
.64294 .51396 Mdot
.42955 .74091 Mdot
.46621 .41198 Mdot
.33065 .55492 Mdot
.64176 .53012 Mdot
.44479 .37877 Mdot
.23568 .38307 Mdot
.39631 .59551 Mdot
.65452 .51038 Mdot
.48232 .38703 Mdot
.52211 .45104 Mdot
.67344 .53786 Mdot
.67567 .48104 Mdot
.44664 .41675 Mdot
.64906 .32773 Mdot
.45956 .37012 Mdot
.57154 .63434 Mdot
.53074 .5531 Mdot
.5954 .61374 Mdot
.46256 .24408 Mdot
.47588 .43633 Mdot
.36477 .66855 Mdot
.37259 .571 Mdot
.62722 .38014 Mdot
.27227 .54783 Mdot
.45442 .35454 Mdot
.70345 .72965 Mdot
.58955 .4564 Mdot
.4858 .7075 Mdot
.79387 .65209 Mdot
.66375 .3514 Mdot
.57726 .63022 Mdot
.45368 .4147 Mdot
.61893 .5989 Mdot
.66165 .3382 Mdot
.45747 .24397 Mdot
.47832 .37996 Mdot
.34878 .60635 Mdot
.46183 .40685 Mdot
.35121 .55437 Mdot
.40796 .39078 Mdot
.40735 .47608 Mdot
.64657 .30698 Mdot
.57726 .214 Mdot
.42311 .34979 Mdot
.81601 .36591 Mdot
.54767 .39973 Mdot
.65523 .36629 Mdot
.41864 .43619 Mdot
.44502 .75163 Mdot
.59636 .64896 Mdot
.7961 .40139 Mdot
.67019 .49629 Mdot
.5836 .64303 Mdot
.3228 .58263 Mdot
.61876 .51521 Mdot
.4357 .73327 Mdot
.39734 .29052 Mdot
.63262 .33296 Mdot
.57976 .61262 Mdot
.42683 .38044 Mdot
.47507 .40975 Mdot
.77517 .42852 Mdot
.17274 .56256 Mdot
.37949 .58844 Mdot
.61145 .19397 Mdot
.30181 .59692 Mdot
.6496 .3571 Mdot
.67376 .49584 Mdot
.43039 .36439 Mdot
.44164 .40144 Mdot
.63306 .49741 Mdot
.34261 .61505 Mdot
.61783 .48517 Mdot
.29243 .29912 Mdot
.53446 .62363 Mdot
.57312 .24247 Mdot
.34772 .57184 Mdot
.57188 .23911 Mdot
.66006 .31831 Mdot
.781 .60282 Mdot
.56484 .32231 Mdot
.57983 .60881 Mdot
.57348 .24618 Mdot
.36661 .58898 Mdot
.45558 .38294 Mdot
.44749 .75755 Mdot
.45214 .732 Mdot
.33093 .56908 Mdot
.67006 .52137 Mdot
.63253 .33704 Mdot
.4557 .40742 Mdot
.40781 .68348 Mdot
.33426 .75886 Mdot
.63099 .53322 Mdot
.50324 .42932 Mdot
.57573 .65733 Mdot
.40958 .39582 Mdot
.65163 .37321 Mdot
.58942 .63533 Mdot
.45426 .76323 Mdot
.46299 .59756 Mdot
.43233 .44637 Mdot
.48464 .50071 Mdot
.57875 .616 Mdot
.16519 .46148 Mdot
.44512 .40876 Mdot
.56174 .644 Mdot
.36698 .34951 Mdot
.31515 .70251 Mdot
.61013 .42203 Mdot
.61063 .80727 Mdot
.69152 .52135 Mdot
.67343 .52791 Mdot
.22807 .67305 Mdot
.6707 .30698 Mdot
.61276 .62113 Mdot
.44356 .76389 Mdot
.56027 .28904 Mdot
.55894 .64721 Mdot
.47509 .42041 Mdot
.40635 .43639 Mdot
.29309 .3098 Mdot
.54932 .42528 Mdot
.4335 .72925 Mdot
.43266 .30408 Mdot
.43232 .42848 Mdot
.37595 .38941 Mdot
.43171 .40463 Mdot
.32039 .61243 Mdot
.55639 .643 Mdot
.85835 .41779 Mdot
.55662 .62301 Mdot
.41828 .67628 Mdot
.65033 .51561 Mdot
.62537 .52442 Mdot
.42921 .37616 Mdot
.36678 .65186 Mdot
.82092 .45137 Mdot
.40129 .37705 Mdot
.63955 .39394 Mdot
.49125 .23956 Mdot
.39497 .43132 Mdot
.38821 .57962 Mdot
.50232 .41123 Mdot
.3075 .5721 Mdot
.5926 .63586 Mdot
.66429 .34929 Mdot
.62207 .32848 Mdot
.57322 .62726 Mdot
.43039 .39192 Mdot
.61897 .38583 Mdot
.43689 .38126 Mdot
.46229 .38881 Mdot
.44615 .65119 Mdot
.66679 .36949 Mdot
.6663 .48859 Mdot
.63984 .3495 Mdot
.3321 .59599 Mdot
.10105 .44762 Mdot
.64732 .3387 Mdot
.53042 .42338 Mdot
.55425 .48694 Mdot
.57029 .24471 Mdot
.31952 .56853 Mdot
.6676 .35785 Mdot
.55925 .62574 Mdot
.48239 .71338 Mdot
.1739 .48092 Mdot
.56398 .66434 Mdot
.44504 .40293 Mdot
.35476 .54978 Mdot
.34496 .6213 Mdot
.54965 .64257 Mdot
.3207 .60302 Mdot
.38428 .43186 Mdot
.46267 .42876 Mdot
.6121 .61993 Mdot
.37313 .77776 Mdot
.55583 .64096 Mdot
.53402 .36191 Mdot
.44135 .44282 Mdot
.34556 .57758 Mdot
.42202 .31762 Mdot
.33289 .63797 Mdot
.45457 .73185 Mdot
.3938 .37795 Mdot
.63407 .34509 Mdot
.49469 .57166 Mdot
.65483 .51188 Mdot
.56574 .78084 Mdot
.34835 .55335 Mdot
.56966 .67364 Mdot
.31627 .59033 Mdot
.36786 .60742 Mdot
.55796 .65586 Mdot
.3343 .58733 Mdot
.45511 .41174 Mdot
.51161 .63466 Mdot
.35224 .55745 Mdot
.58846 .62042 Mdot
.63164 .34637 Mdot
.32694 .602 Mdot
.6285 .46996 Mdot
.45909 .38128 Mdot
.67122 .48384 Mdot
.67106 .36893 Mdot
.3548 .54841 Mdot
.66941 .35216 Mdot
.64066 .51247 Mdot
.62868 .34092 Mdot
.60311 .56629 Mdot
.62541 .6206 Mdot
.42868 .64873 Mdot
.27724 .58384 Mdot
.37073 .59037 Mdot
.69667 .50333 Mdot
.4314 .36027 Mdot
.46887 .39635 Mdot
.63472 .3252 Mdot
.3465 .62239 Mdot
.53988 .82448 Mdot
.39597 .31554 Mdot
.42296 .78026 Mdot
.60737 .59951 Mdot
.53437 .18666 Mdot
.47025 .67868 Mdot
.49495 .72398 Mdot
.4305 .33252 Mdot
.45278 .74749 Mdot
.43852 .37604 Mdot
.48967 .2121 Mdot
.67262 .34672 Mdot
.67162 .65948 Mdot
.41251 .3409 Mdot
.66163 .4945 Mdot
.40678 .38228 Mdot
.81134 .40057 Mdot
.49296 .36091 Mdot
.66178 .36615 Mdot
.61828 .63997 Mdot
.37499 .59407 Mdot
.64459 .36762 Mdot
.68051 .51904 Mdot
.58645 .27493 Mdot
.4859 .39982 Mdot
.43833 .43021 Mdot
.68971 .48586 Mdot
.34115 .6082 Mdot
.634 .512 Mdot
.56287 .64445 Mdot
.64734 .3422 Mdot
.40245 .41769 Mdot
.39825 .44005 Mdot
.66717 .46577 Mdot
.56106 .61411 Mdot
.63372 .54082 Mdot
.57569 .6055 Mdot
.45244 .75001 Mdot
.41628 .35357 Mdot
.67528 .47172 Mdot
.39533 .34013 Mdot
.33009 .46488 Mdot
.44311 .64002 Mdot
.27933 .52607 Mdot
.66574 .48745 Mdot
.60902 .26142 Mdot
.57882 .62363 Mdot
.5665 .6209 Mdot
.33355 .29063 Mdot
.81811 .46151 Mdot
.59265 .47324 Mdot
.78251 .33312 Mdot
.56332 .64453 Mdot
.58751 .6155 Mdot
.65824 .53806 Mdot
.32996 .5851 Mdot
.37899 .53995 Mdot
.63111 .47571 Mdot
.53291 .20408 Mdot
.36501 .59357 Mdot
.68151 .75527 Mdot
.6882 .51326 Mdot
.45692 .34036 Mdot
.43518 .72423 Mdot
.656 .36905 Mdot
.49863 .21442 Mdot
.78991 .3505 Mdot
.43339 .36779 Mdot
.2848 .25418 Mdot
.66593 .51715 Mdot
.55111 .68446 Mdot
.75254 .64798 Mdot
.47206 .36861 Mdot
.40947 .38001 Mdot
.4272 .39427 Mdot
.65046 .38042 Mdot
.29857 .53095 Mdot
.43588 .36761 Mdot
.58951 .22194 Mdot
.45634 .44813 Mdot
.77615 .36405 Mdot
.64009 .34915 Mdot
.45762 .27036 Mdot
.69174 .5256 Mdot
.3769 .71428 Mdot
.36987 .39333 Mdot
.56338 .63932 Mdot
.72431 .6491 Mdot
.59493 .64387 Mdot
.80385 .54236 Mdot
.56275 .31971 Mdot
.3211 .61387 Mdot
.4255 .40989 Mdot
.68925 .48931 Mdot
.35714 .55131 Mdot
.63684 .6899 Mdot
.12497 .39681 Mdot
.5809 .59825 Mdot
.3952 .1509 Mdot
.56893 .61596 Mdot
.4498 .72972 Mdot
.32653 .57189 Mdot
.41219 .53513 Mdot
.48164 .60282 Mdot
.33434 .60391 Mdot
.72 .47084 Mdot
.39113 .58147 Mdot
.59413 .24813 Mdot
.34982 .6285 Mdot
.58525 .62463 Mdot
.61956 .64397 Mdot
.36202 .41975 Mdot
.42786 .35753 Mdot
.47558 .62045 Mdot
.37521 .34983 Mdot
.40939 .36171 Mdot
.65368 .49791 Mdot
.28143 .65363 Mdot
.54908 .67437 Mdot
.34391 .56513 Mdot
.59904 .60275 Mdot
.4085 .37961 Mdot
.41107 .43264 Mdot
.38752 .35652 Mdot
.464 .22152 Mdot
.68441 .75051 Mdot
.45503 .38966 Mdot
.48416 .43931 Mdot
.68107 .50747 Mdot
.77802 .40695 Mdot
.68252 .25025 Mdot
.5655 .29749 Mdot
.47157 .40702 Mdot
.64578 .35977 Mdot
.66901 .36137 Mdot
.40526 .451 Mdot
.38784 .67042 Mdot
.61275 .48138 Mdot
.42652 .38047 Mdot
.58244 .33813 Mdot
.65043 .45839 Mdot
.42912 .74918 Mdot
.64287 .51318 Mdot
.35098 .54665 Mdot
.45035 .73364 Mdot
.63065 .52565 Mdot
.40122 .59798 Mdot
.43737 .73527 Mdot
.32955 .70977 Mdot
.67116 .34935 Mdot
.43656 .40583 Mdot
.30092 .62542 Mdot
.63439 .49665 Mdot
.5765 .61486 Mdot
.35369 .58356 Mdot
.61006 .59778 Mdot
.7804 .40919 Mdot
.50972 .21723 Mdot
.456 .75358 Mdot
.56533 .63873 Mdot
.46258 .54431 Mdot
.64371 .35761 Mdot
.56301 .65948 Mdot
.35357 .66179 Mdot
.39886 .43317 Mdot
.8247 .52625 Mdot
.44051 .42695 Mdot
.47333 .81869 Mdot
.56637 .6235 Mdot
.45929 .73743 Mdot
.43246 .38376 Mdot
.68678 .4974 Mdot
.35488 .40052 Mdot
.43846 .38276 Mdot
.65736 .54585 Mdot
.45556 .38544 Mdot
.64141 .37603 Mdot
.31733 .55638 Mdot
.58971 .45195 Mdot
.47498 .19751 Mdot
.62842 .3514 Mdot
.44131 .77559 Mdot
.41863 .35629 Mdot
.68698 .40659 Mdot
.34155 .60354 Mdot
.46314 .35889 Mdot
.32638 .25855 Mdot
.3317 .57414 Mdot
.34655 .59627 Mdot
.42467 .43245 Mdot
.5665 .66563 Mdot
.64964 .48471 Mdot
.6416 .35592 Mdot
.61315 .69929 Mdot
.44547 .37716 Mdot
.43255 .41021 Mdot
.64287 .36814 Mdot
.59074 .61417 Mdot
.40494 .41934 Mdot
.59753 .73926 Mdot
.46215 .69679 Mdot
.59032 .60616 Mdot
.39741 .43232 Mdot
.83911 .54315 Mdot
.37098 .53431 Mdot
.26462 .26792 Mdot
.67538 .3116 Mdot
.67307 .51531 Mdot
.47636 .45619 Mdot
.16981 .69876 Mdot
.65881 .36555 Mdot
.39046 .71765 Mdot
.46013 .39365 Mdot
.41323 .36416 Mdot
.31058 .59071 Mdot
.41688 .42128 Mdot
.3612 .56605 Mdot
.4809 .19229 Mdot
.80478 .32292 Mdot
.3177 .59294 Mdot
.35745 .56048 Mdot
.40099 .51829 Mdot
.45325 .2292 Mdot
.32452 .58356 Mdot
.48632 .39753 Mdot
.72126 .45812 Mdot
.43087 .46924 Mdot
.6766 .32895 Mdot
.62061 .37505 Mdot
.37087 .61536 Mdot
.19668 .57458 Mdot
.35179 .38026 Mdot
.44751 .49248 Mdot
.69052 .35656 Mdot
.57283 .64238 Mdot
.40572 .43341 Mdot
.45159 .76067 Mdot
.64443 .53503 Mdot
.50438 .39046 Mdot
.43689 .40308 Mdot
.35655 .55481 Mdot
.64524 .38218 Mdot
.56377 .65754 Mdot
.44518 .41466 Mdot
.61986 .54454 Mdot
.6573 .35079 Mdot
.35211 .55866 Mdot
.53185 .41917 Mdot
.67067 .32841 Mdot
.38431 .42497 Mdot
.40936 .3629 Mdot
.4663 .4133 Mdot
.36792 .38776 Mdot
.5721 .62587 Mdot
.62094 .49186 Mdot
.42938 .46404 Mdot
.4557 .64283 Mdot
.50753 .5598 Mdot
.42851 .46299 Mdot
.34633 .61279 Mdot
.61411 .6214 Mdot
.438 .73906 Mdot
.56275 .26245 Mdot
.45298 .44126 Mdot
.69443 .73889 Mdot
.26593 .31002 Mdot
.44434 .73765 Mdot
.3147 .61422 Mdot
.63764 .35318 Mdot
.43757 .43451 Mdot
.67429 .42308 Mdot
.46945 .42447 Mdot
.52279 .37677 Mdot
.67028 .51548 Mdot
.57362 .6469 Mdot
.45609 .7006 Mdot
.64379 .53524 Mdot
.34607 .59539 Mdot
.51673 .84507 Mdot
.39037 .55711 Mdot
.38139 .57333 Mdot
.7828 .56557 Mdot
.59262 .63896 Mdot
.18981 .72317 Mdot
.17281 .44436 Mdot
.46656 .43151 Mdot
.60688 .63079 Mdot
.33094 .56485 Mdot
.4334 .41851 Mdot
.36912 .5909 Mdot
.38191 .55517 Mdot
.38853 .39487 Mdot
.41806 .35986 Mdot
.56514 .21204 Mdot
.67505 .77189 Mdot
.63792 .33803 Mdot
.32523 .61061 Mdot
.27531 .32896 Mdot
.43707 .36661 Mdot
.47345 .39348 Mdot
.74479 .61355 Mdot
.66422 .36244 Mdot
.21128 .5019 Mdot
.46692 .39932 Mdot
.33262 .25473 Mdot
.40568 .36314 Mdot
.29621 .56161 Mdot
.5532 .66166 Mdot
.39051 .67592 Mdot
.64485 .4847 Mdot
.35151 .5427 Mdot
.65247 .32141 Mdot
.35025 .54112 Mdot
.32403 .29781 Mdot
.59571 .63662 Mdot
.36044 .56803 Mdot
.62655 .53914 Mdot
.59865 .62397 Mdot
.57912 .60833 Mdot
.62261 .44755 Mdot
.62001 .51952 Mdot
.64356 .37967 Mdot
.58982 .65051 Mdot
.24958 .36504 Mdot
.58727 .62723 Mdot
.28517 .3237 Mdot
.45485 .36404 Mdot
.57709 .2242 Mdot
.44372 .68984 Mdot
.36363 .39942 Mdot
.55762 .64938 Mdot
.64948 .33189 Mdot
.41729 .41362 Mdot
.32298 .60546 Mdot
.65097 .33717 Mdot
.57886 .58823 Mdot
.63559 .54798 Mdot
.35985 .61827 Mdot
.60699 .65504 Mdot
.36545 .5715 Mdot
.49089 .22688 Mdot
.62141 .56442 Mdot
.62324 .41003 Mdot
.48732 .5987 Mdot
.39104 .35882 Mdot
.42676 .50623 Mdot
.47878 .38624 Mdot
.4377 .39891 Mdot
.65373 .51085 Mdot
.63859 .25617 Mdot
.32808 .60351 Mdot
.3907 .80761 Mdot
.56471 .63335 Mdot
.4506 .53054 Mdot
.50803 .33979 Mdot
.39625 .39324 Mdot
.34671 .56001 Mdot
.3823 .56037 Mdot
.32144 .48778 Mdot
.63175 .49901 Mdot
.40615 .46302 Mdot
.37388 .42608 Mdot
.44276 .47187 Mdot
.57172 .61242 Mdot
.61887 .73297 Mdot
.62577 .51302 Mdot
.30962 .19787 Mdot
.63691 .52261 Mdot
.70866 .39077 Mdot
.33413 .58617 Mdot
.6671 .33314 Mdot
.47168 .38765 Mdot
.34836 .51182 Mdot
.31864 .55982 Mdot
.62908 .4558 Mdot
.63609 .35484 Mdot
.64227 .7313 Mdot
.58806 .64208 Mdot
.46348 .36653 Mdot
.38795 .40016 Mdot
.41523 .42866 Mdot
.45497 .4253 Mdot
.6088 .60819 Mdot
.47563 .41859 Mdot
.61683 .60974 Mdot
.21777 .40579 Mdot
.335 .25818 Mdot
.68011 .48151 Mdot
.77501 .37379 Mdot
.36356 .61029 Mdot
.2751 .35345 Mdot
.20574 .50623 Mdot
.44175 .64331 Mdot
.59829 .54842 Mdot
.44202 .35723 Mdot
.66885 .52349 Mdot
.81727 .40704 Mdot
.68184 .48074 Mdot
.8304 .33241 Mdot
.40304 .27704 Mdot
.59564 .81981 Mdot
.43891 .42296 Mdot
.63171 .47353 Mdot
.21991 .56328 Mdot
.40994 .44881 Mdot
.61413 .3723 Mdot
.5254 .35612 Mdot
.37134 .75699 Mdot
.66919 .33167 Mdot
.45624 .37936 Mdot
.36925 .60892 Mdot
.45601 .41098 Mdot
.46547 .37978 Mdot
.40192 .3781 Mdot
.55901 .60888 Mdot
.39063 .41715 Mdot
.46025 .37082 Mdot
.16306 .54088 Mdot
.63088 .27349 Mdot
.68368 .50279 Mdot
.30101 .50141 Mdot
.64917 .35136 Mdot
.3603 .55364 Mdot
.57951 .4655 Mdot
.57484 .63754 Mdot
.32448 .4774 Mdot
.4395 .4246 Mdot
.40634 .74232 Mdot
.58569 .66617 Mdot
.65953 .33996 Mdot
.43513 .73871 Mdot
.69976 .71057 Mdot
.65591 .47625 Mdot
.44528 .72695 Mdot
.65548 .51263 Mdot
.24361 .57087 Mdot
.35371 .55535 Mdot
.38633 .36324 Mdot
.57009 .65606 Mdot
.6725 .48032 Mdot
.66877 .26827 Mdot
.42259 .3967 Mdot
.66437 .48646 Mdot
.38996 .36137 Mdot
.51049 .56346 Mdot
.55726 .49131 Mdot
.65087 .47083 Mdot
.61859 .64499 Mdot
.60086 .62174 Mdot
.66024 .32889 Mdot
.36504 .55554 Mdot
.35807 .60829 Mdot
.59236 .63225 Mdot
.31073 .21476 Mdot
.44383 .376 Mdot
.40544 .36634 Mdot
.45858 .64894 Mdot
.44461 .42257 Mdot
.60174 .27483 Mdot
.43197 .76232 Mdot
.37261 .58581 Mdot
.45318 .42315 Mdot
.40498 .42028 Mdot
.42847 .44545 Mdot
.51106 .21929 Mdot
.64252 .5173 Mdot
.43291 .42955 Mdot
.62535 .34236 Mdot
.33749 .68081 Mdot
.43688 .36165 Mdot
.38925 .42954 Mdot
.36397 .57192 Mdot
.565 .18276 Mdot
.57103 .61939 Mdot
.65347 .48914 Mdot
.68744 .51586 Mdot
.49273 .26458 Mdot
.33336 .5397 Mdot
.42623 .74647 Mdot
.734 .54618 Mdot
.43516 .75789 Mdot
.65358 .36581 Mdot
.63128 .42946 Mdot
.62039 .54869 Mdot
.68291 .51756 Mdot
.62471 .61924 Mdot
.45665 .42142 Mdot
.40594 .36348 Mdot
.3917 .71337 Mdot
.3973 .37813 Mdot
.63321 .35075 Mdot
.6059 .65417 Mdot
.36298 .57263 Mdot
.64511 .37378 Mdot
.56314 .62444 Mdot
.34134 .60875 Mdot
.41319 .44594 Mdot
.38043 .3632 Mdot
.35249 .58929 Mdot
.33921 .55408 Mdot
.42264 .37265 Mdot
.20376 .617 Mdot
.37397 .58916 Mdot
.35373 .56833 Mdot
.4562 .72326 Mdot
.65784 .4755 Mdot
.45971 .32505 Mdot
.60486 .63292 Mdot
.46658 .40867 Mdot
.6785 .47958 Mdot
.66825 .34873 Mdot
.35622 .59568 Mdot
.41998 .44082 Mdot
.4487 .38567 Mdot
.64444 .35989 Mdot
.67506 .35622 Mdot
.63125 .35577 Mdot
.57996 .59586 Mdot
.45624 .43082 Mdot
.32335 .58815 Mdot
.59134 .64217 Mdot
.66996 .35923 Mdot
.62016 .34521 Mdot
.16392 .52609 Mdot
.43333 .36912 Mdot
.64347 .40922 Mdot
.09556 .50182 Mdot
.58403 .28226 Mdot
.44291 .73024 Mdot
.65409 .46696 Mdot
.5878 .22911 Mdot
.68638 .33361 Mdot
.60839 .63316 Mdot
.57636 .36484 Mdot
.636 .38433 Mdot
.39055 .39489 Mdot
.40978 .39887 Mdot
.45632 .3429 Mdot
.65366 .34584 Mdot
.499 .22515 Mdot
.34592 .61953 Mdot
.25497 .44072 Mdot
.64921 .35118 Mdot
.64989 .47102 Mdot
.6688 .46915 Mdot
.63584 .52235 Mdot
.44492 .3569 Mdot
.30451 .51046 Mdot
.25932 .34631 Mdot
.22032 .50027 Mdot
.5841 .64249 Mdot
.38417 .56689 Mdot
.59705 .5398 Mdot
.34693 .59708 Mdot
.65131 .53292 Mdot
.6575 .34542 Mdot
.31237 .59984 Mdot
.5946 .61053 Mdot
.59848 .6153 Mdot
.64364 .55056 Mdot
.64206 .50804 Mdot
.6452 .49373 Mdot
.35501 .54468 Mdot
.33411 .58718 Mdot
.40401 .42361 Mdot
.35997 .58566 Mdot
.22836 .34226 Mdot
.67723 .32718 Mdot
.6926 .49173 Mdot
.57851 .6183 Mdot
.34558 .55628 Mdot
.43977 .40745 Mdot
.74561 .40423 Mdot
.64158 .45228 Mdot
.62849 .3595 Mdot
.51868 .59744 Mdot
.73881 .23979 Mdot
.3852 .39677 Mdot
.57741 .60304 Mdot
.37705 .67033 Mdot
.42043 .39095 Mdot
.67262 .50305 Mdot
.38498 .26731 Mdot
.43022 .74753 Mdot
.4526 .36764 Mdot
.44589 .34726 Mdot
.55893 .65632 Mdot
.57042 .47545 Mdot
.3947 .38499 Mdot
.51205 .49446 Mdot
.56628 .60568 Mdot
.62572 .51518 Mdot
.25179 .7253 Mdot
.541 .61358 Mdot
.58419 .21089 Mdot
.44227 .7327 Mdot
.38962 .40262 Mdot
.65425 .50094 Mdot
.62585 .35925 Mdot
.64924 .50462 Mdot
.3337 .62653 Mdot
.66619 .48197 Mdot
.4224 .40156 Mdot
.32458 .59038 Mdot
.58463 .61276 Mdot
.45984 .51688 Mdot
.18038 .56527 Mdot
.68661 .49923 Mdot
.45031 .76844 Mdot
.44409 .36624 Mdot
.2129 .43394 Mdot
.36281 .42784 Mdot
.43314 .3575 Mdot
.5933 .64545 Mdot
.34527 .56162 Mdot
.60948 .60086 Mdot
.38386 .41004 Mdot
.33072 .31202 Mdot
.56636 .63288 Mdot
.34064 .73428 Mdot
.64568 .36904 Mdot
.52991 .20472 Mdot
.44038 .39386 Mdot
.56994 .65531 Mdot
.45598 .43161 Mdot
.32635 .61198 Mdot
.48354 .56524 Mdot
.33934 .67465 Mdot
.57697 .65686 Mdot
.49312 .83078 Mdot
.52872 .51286 Mdot
.48331 .34224 Mdot
.5632 .64905 Mdot
.27815 .5396 Mdot
.44236 .74971 Mdot
.65753 .35742 Mdot
.67078 .36132 Mdot
.63587 .32832 Mdot
.39781 .37652 Mdot
.46383 .47046 Mdot
.62018 .36217 Mdot
.58804 .59535 Mdot
.62552 .36657 Mdot
.46876 .22962 Mdot
.5167 .82547 Mdot
.63143 .36074 Mdot
.44471 .39603 Mdot
.39272 .43263 Mdot
.6342 .27303 Mdot
.62333 .50863 Mdot
.70765 .72117 Mdot
.18517 .4381 Mdot
.42798 .36411 Mdot
.41153 .28322 Mdot
.34861 .62525 Mdot
.40897 .6242 Mdot
.40298 .30734 Mdot
.59325 .46275 Mdot
.35222 .56303 Mdot
.51443 .57176 Mdot
.37301 .57778 Mdot
.381 .37883 Mdot
.45485 .39359 Mdot
.3167 .55985 Mdot
.5544 .77505 Mdot
.28474 .70634 Mdot
.45105 .80153 Mdot
.35566 .61091 Mdot
.55981 .64195 Mdot
.57529 .60212 Mdot
.58628 .64633 Mdot
.63926 .49241 Mdot
.33672 .55302 Mdot
.44683 .43675 Mdot
.6776 .5201 Mdot
.47121 .39451 Mdot
.60084 .6299 Mdot
.46275 .69847 Mdot
.36274 .57101 Mdot
.42709 .38258 Mdot
.17511 .48815 Mdot
.65243 .52096 Mdot
.6459 .35796 Mdot
.50669 .62589 Mdot
.65587 .46541 Mdot
.55525 .62706 Mdot
.34945 .53375 Mdot
.70394 .48951 Mdot
.72218 .35841 Mdot
.48715 .38423 Mdot
.4858 .40551 Mdot
.63451 .66094 Mdot
.17913 .53885 Mdot
.39971 .38526 Mdot
.68024 .5202 Mdot
.65255 .47287 Mdot
.4618 .43084 Mdot
.31446 .58249 Mdot
.63025 .37914 Mdot
.63895 .32346 Mdot
.41417 .34824 Mdot
.48297 .60931 Mdot
.57455 .21916 Mdot
.41015 .41781 Mdot
.5152 .36916 Mdot
.62662 .53679 Mdot
.43657 .73293 Mdot
.46511 .61618 Mdot
.65065 .32355 Mdot
.46173 .39379 Mdot
.29841 .72188 Mdot
.35768 .5645 Mdot
.65551 .48421 Mdot
.60429 .61165 Mdot
.61151 .36706 Mdot
.68249 .5289 Mdot
.46162 .43097 Mdot
.40508 .41977 Mdot
.56802 .66059 Mdot
.29229 .56857 Mdot
.65544 .3437 Mdot
.67884 .51634 Mdot
.66664 .33244 Mdot
.3345 .59453 Mdot
.35709 .57094 Mdot
.37617 .43112 Mdot
.36189 .40158 Mdot
.68754 .51235 Mdot
.45174 .34472 Mdot
.63726 .53073 Mdot
.77599 .42427 Mdot
.59842 .60512 Mdot
.46768 .36259 Mdot
.29476 .58671 Mdot
.59935 .63094 Mdot
.4173 .3664 Mdot
.6329 .66183 Mdot
.40137 .40765 Mdot
.63073 .47507 Mdot
.34007 .27897 Mdot
.66229 .33755 Mdot
.42456 .50357 Mdot
.37349 .48524 Mdot
.44323 .42172 Mdot
.62168 .49732 Mdot
.42881 .47862 Mdot
.56917 .6317 Mdot
.33693 .57471 Mdot
.47036 .1547 Mdot
.58914 .62286 Mdot
.45693 .40486 Mdot
.64831 .33987 Mdot
.37816 .58833 Mdot
.45564 .74878 Mdot
.46941 .65277 Mdot
.50011 .37695 Mdot
.4442 .33149 Mdot
.45811 .41715 Mdot
.78278 .33172 Mdot
.64972 .49576 Mdot
.33845 .55901 Mdot
.58644 .60149 Mdot
.58433 .63617 Mdot
.64699 .52622 Mdot
.39348 .77103 Mdot
.57848 .78871 Mdot
.09594 .54693 Mdot
.68148 .52624 Mdot
.62204 .3515 Mdot
.50443 .55357 Mdot
.64291 .53591 Mdot
.65664 .49513 Mdot
.64013 .55217 Mdot
.41045 .71262 Mdot
.3409 .61116 Mdot
.4497 .38467 Mdot
.32636 .54262 Mdot
.38955 .39808 Mdot
.6464 .24586 Mdot
.59215 .63447 Mdot
.33599 .57721 Mdot
.6374 .59917 Mdot
.37633 .34051 Mdot
.41231 .38608 Mdot
.68138 .43272 Mdot
.50011 .39057 Mdot
.57007 .25337 Mdot
.37503 .37267 Mdot
.64714 .51209 Mdot
.38419 .30126 Mdot
.48279 .44868 Mdot
.18156 .46214 Mdot
.59331 .61228 Mdot
.45796 .74378 Mdot
.42488 .45145 Mdot
.50723 .37253 Mdot
.37998 .58193 Mdot
.31183 .59898 Mdot
.62115 .36525 Mdot
.5066 .6463 Mdot
.58946 .61174 Mdot
.63112 .77024 Mdot
.42439 .35679 Mdot
.57632 .69534 Mdot
.33592 .27879 Mdot
.41675 .36938 Mdot
.64504 .43353 Mdot
.32401 .4799 Mdot
.39756 .39491 Mdot
.23073 .49526 Mdot
.58159 .62037 Mdot
.33073 .25612 Mdot
.42152 .34166 Mdot
.67176 .50283 Mdot
.33122 .58328 Mdot
.35844 .61858 Mdot
.63136 .36621 Mdot
.20099 .38408 Mdot
.61998 .65251 Mdot
.33399 .58345 Mdot
.42682 .39623 Mdot
.57412 .61724 Mdot
.45686 .73884 Mdot
.46818 .34042 Mdot
.80287 .51026 Mdot
.36169 .58098 Mdot
.45023 .46402 Mdot
.43693 .79404 Mdot
.53399 .52274 Mdot
.68392 .7653 Mdot
.58243 .64921 Mdot
.64892 .3227 Mdot
.3772 .36014 Mdot
.73136 .54824 Mdot
.41103 .34302 Mdot
.61625 .2287 Mdot
.33839 .64108 Mdot
.67151 .34507 Mdot
.4227 .3888 Mdot
.39505 .38558 Mdot
.49041 .58251 Mdot
.67665 .34842 Mdot
.394 .38639 Mdot
.39723 .45429 Mdot
.3452 .6078 Mdot
.43544 .76601 Mdot
.36412 .57849 Mdot
.44514 .40419 Mdot
.43569 .27418 Mdot
.31314 .59524 Mdot
.68534 .72627 Mdot
.66033 .29812 Mdot
.574 .63769 Mdot
.51443 .40456 Mdot
.44805 .3612 Mdot
.82823 .623 Mdot
.45402 .73127 Mdot
.62847 .20978 Mdot
.64384 .46849 Mdot
.3511 .7944 Mdot
.65531 .46381 Mdot
.56786 .83539 Mdot
.45855 .52984 Mdot
.47147 .36009 Mdot
.57177 .34379 Mdot
.22523 .49062 Mdot
.62119 .6094 Mdot
.24062 .39126 Mdot
.42818 .35761 Mdot
.44981 .37349 Mdot
.66514 .53293 Mdot
.40715 .7778 Mdot
.37925 .67498 Mdot
.47255 .60823 Mdot
.66078 .34529 Mdot
.33898 .58859 Mdot
.41764 .39952 Mdot
.52414 .74755 Mdot
.6818 .49451 Mdot
.54544 .37807 Mdot
.43008 .38395 Mdot
.41034 .67478 Mdot
.37256 .73906 Mdot
.5771 .6132 Mdot
.63763 .47349 Mdot
.61996 .49591 Mdot
.40224 .4321 Mdot
.6111 .62304 Mdot
.39723 .41123 Mdot
.52455 .516 Mdot
.48563 .43654 Mdot
.66394 .35896 Mdot
.47326 .38783 Mdot
.56561 .3841 Mdot
.56098 .85097 Mdot
.49766 .42759 Mdot
.37521 .56597 Mdot
.63649 .4987 Mdot
.64059 .52246 Mdot
.35866 .6083 Mdot
.64118 .52416 Mdot
.25516 .45086 Mdot
.31226 .31057 Mdot
.65818 .36453 Mdot
.20034 .51363 Mdot
.66364 .34313 Mdot
.45799 .74595 Mdot
.42932 .3692 Mdot
.74149 .55103 Mdot
.68237 .52554 Mdot
.42412 .23593 Mdot
.58707 .63021 Mdot
.4529 .73064 Mdot
.45872 .44248 Mdot
.65827 .41091 Mdot
.65929 .53068 Mdot
.70514 .67926 Mdot
.42455 .44418 Mdot
.3323 .61194 Mdot
.39668 .39147 Mdot
.49089 .41829 Mdot
.44291 .72835 Mdot
.45852 .41802 Mdot
.56299 .62469 Mdot
.33647 .55243 Mdot
.5727 .82902 Mdot
.63601 .49479 Mdot
.45492 .37248 Mdot
.42576 .39509 Mdot
.31096 .60124 Mdot
.46244 .4421 Mdot
.60684 .6344 Mdot
.24362 .7821 Mdot
.648 .36845 Mdot
.43476 .73417 Mdot
.69342 .70102 Mdot
.41871 .40604 Mdot
.41263 .41386 Mdot
.62439 .68307 Mdot
.27244 .67224 Mdot
.56279 .63314 Mdot
.465 .44603 Mdot
.68025 .50318 Mdot
.654 .33781 Mdot
.59732 .64859 Mdot
.46122 .42879 Mdot
.448 .37263 Mdot
.66122 .36383 Mdot
.68034 .42996 Mdot
.62117 .47547 Mdot
.58535 .644 Mdot
.42539 .28677 Mdot
.75076 .40955 Mdot
.43991 .37838 Mdot
.47726 .80252 Mdot
.3512 .57016 Mdot
.56558 .64867 Mdot
.29255 .53848 Mdot
.38646 .36639 Mdot
.55518 .63174 Mdot
.58664 .61254 Mdot
.44916 .44608 Mdot
.33472 .53849 Mdot
.36924 .54667 Mdot
.35147 .56781 Mdot
.35491 .25533 Mdot
.71614 .29499 Mdot
.64559 .49222 Mdot
.58374 .61728 Mdot
.67732 .47556 Mdot
.62105 .37004 Mdot
.50661 .56188 Mdot
.65294 .47199 Mdot
.3639 .61086 Mdot
.68489 .4798 Mdot
.39941 .41117 Mdot
.60005 .61285 Mdot
.68047 .52377 Mdot
.42748 .41699 Mdot
.51953 .38534 Mdot
.56671 .37461 Mdot
.63696 .38167 Mdot
.51121 .57514 Mdot
.45239 .40541 Mdot
.43782 .73734 Mdot
.42469 .375 Mdot
.61234 .62028 Mdot
.56831 .40029 Mdot
.43349 .42546 Mdot
.68609 .52066 Mdot
.73017 .35464 Mdot
.62536 .49268 Mdot
.48311 .43029 Mdot
.44602 .40382 Mdot
.44099 .37638 Mdot
.39481 .3775 Mdot
.35554 .74625 Mdot
.61752 .60988 Mdot
.51664 .41763 Mdot
.67145 .54234 Mdot
.35098 .59644 Mdot
.32095 .61059 Mdot
.59009 .47943 Mdot
.45067 .72475 Mdot
.60963 .62601 Mdot
.44271 .37689 Mdot
.70565 .67828 Mdot
.47913 .69615 Mdot
.46312 .80792 Mdot
.61032 .45873 Mdot
.6808 .52089 Mdot
.37442 .56044 Mdot
.64637 .54473 Mdot
.46712 .42668 Mdot
.37551 .3703 Mdot
.58935 .82079 Mdot
.56168 .60245 Mdot
.65628 .34527 Mdot
.47191 .39562 Mdot
.55477 .20464 Mdot
.68107 .50758 Mdot
.62468 .53317 Mdot
.39807 .41573 Mdot
.38263 .55003 Mdot
.64594 .81411 Mdot
.60892 .61589 Mdot
.21703 .42255 Mdot
.30558 .64056 Mdot
.51119 .3387 Mdot
.57394 .6287 Mdot
.61929 .41518 Mdot
.62578 .50217 Mdot
.19072 .4197 Mdot
.35427 .58995 Mdot
.65553 .34917 Mdot
.40231 .45301 Mdot
.36468 .61037 Mdot
.67244 .46762 Mdot
.36777 .56474 Mdot
.38359 .36702 Mdot
.5943 .59586 Mdot
.63939 .52669 Mdot
.61866 .62503 Mdot
.32164 .5553 Mdot
.66311 .34074 Mdot
.43911 .24004 Mdot
.21727 .41613 Mdot
.32423 .47991 Mdot
.43338 .43013 Mdot
.75665 .56076 Mdot
.44786 .43813 Mdot
.38093 .5645 Mdot
.44113 .39437 Mdot
.44569 .50426 Mdot
.62571 .52558 Mdot
.45978 .46019 Mdot
.46844 .37745 Mdot
.19894 .42521 Mdot
.41179 .37701 Mdot
.46088 .43956 Mdot
.42894 .34557 Mdot
.28412 .61437 Mdot
.4443 .46244 Mdot
.33091 .6106 Mdot
.39474 .72156 Mdot
.6582 .4967 Mdot
.62113 .33572 Mdot
.65226 .31903 Mdot
.6086 .22388 Mdot
.53759 .20437 Mdot
.39644 .76769 Mdot
.36246 .59801 Mdot
.55843 .62816 Mdot
.39866 .41361 Mdot
.26086 .56063 Mdot
.5204 .31352 Mdot
.62584 .50654 Mdot
.68995 .50085 Mdot
.37522 .43422 Mdot
.82293 .37818 Mdot
.44808 .4629 Mdot
.46466 .66413 Mdot
.3918 .38664 Mdot
.46089 .35604 Mdot
.62397 .53502 Mdot
.49102 .22234 Mdot
.43309 .42953 Mdot
.37977 .58258 Mdot
.65434 .35504 Mdot
.40393 .2894 Mdot
.4946 .28892 Mdot
.51648 .32914 Mdot
.37327 .63619 Mdot
.45548 .42806 Mdot
.67668 .51481 Mdot
.36868 .60462 Mdot
.45863 .63569 Mdot
.59174 .64344 Mdot
.47268 .6314 Mdot
.23027 .38523 Mdot
.54446 .60401 Mdot
.65712 .3504 Mdot
.61094 .46709 Mdot
.42326 .40239 Mdot
.64039 .49199 Mdot
.38323 .38607 Mdot
.48209 .69743 Mdot
.66937 .34891 Mdot
.34194 .54275 Mdot
.55944 .64054 Mdot
.34506 .61598 Mdot
.28248 .52306 Mdot
.51035 .30609 Mdot
.35168 .79548 Mdot
.65315 .47645 Mdot
.33682 .35008 Mdot
.33013 .57116 Mdot
.44159 .44418 Mdot
.09697 .53692 Mdot
.34869 .57244 Mdot
.34134 .61501 Mdot
.59449 .45943 Mdot
.46251 .24388 Mdot
.48003 .45312 Mdot
.37143 .57656 Mdot
.69587 .51808 Mdot
.63812 .34577 Mdot
.42139 .41772 Mdot
.41401 .35025 Mdot
.31115 .59483 Mdot
.65596 .53087 Mdot
.5561 .20133 Mdot
.64405 .51045 Mdot
.33401 .60731 Mdot
.66033 .51478 Mdot
.67312 .72719 Mdot
.6759 .48859 Mdot
.46765 .37517 Mdot
.44259 .37782 Mdot
.78822 .49006 Mdot
.35712 .57104 Mdot
.41519 .41341 Mdot
.45745 .38878 Mdot
.32452 .58131 Mdot
.62514 .55668 Mdot
.33977 .48504 Mdot
.42972 .41423 Mdot
.44685 .38053 Mdot
.67275 .34242 Mdot
.52708 .55009 Mdot
.50364 .75652 Mdot
.41909 .41612 Mdot
.63035 .3324 Mdot
.35633 .54532 Mdot
.42258 .37475 Mdot
.49077 .21971 Mdot
.6538 .45884 Mdot
.47376 .41745 Mdot
.45432 .754 Mdot
.40098 .38029 Mdot
.6384 .81862 Mdot
.4492 .36994 Mdot
.32697 .56949 Mdot
.33091 .57701 Mdot
.62845 .46464 Mdot
.34607 .59321 Mdot
.44659 .73099 Mdot
.6006 .62584 Mdot
.45932 .81971 Mdot
.45011 .73217 Mdot
.46468 .36257 Mdot
.17285 .44362 Mdot
.4083 .35041 Mdot
.41921 .45337 Mdot
.44305 .23276 Mdot
.44539 .73348 Mdot
.34214 .5618 Mdot
.55626 .77166 Mdot
.47874 .37435 Mdot
.61011 .61801 Mdot
.40489 .44527 Mdot
.47474 .41649 Mdot
.53944 .4388 Mdot
.33747 .29905 Mdot
.60997 .65076 Mdot
.46416 .32803 Mdot
.42022 .41793 Mdot
.26481 .65273 Mdot
.42834 .40125 Mdot
.63209 .36365 Mdot
.36613 .59735 Mdot
.64173 .54411 Mdot
.64526 .36473 Mdot
.41987 .40346 Mdot
.65202 .34819 Mdot
.64804 .49045 Mdot
.58359 .65333 Mdot
.47418 .39358 Mdot
.67501 .32847 Mdot
.65745 .34249 Mdot
.42398 .43842 Mdot
.33364 .58091 Mdot
.3652 .44133 Mdot
.42078 .37366 Mdot
.45861 .43417 Mdot
.35829 .6081 Mdot
.1965 .33762 Mdot
.38915 .40867 Mdot
.62408 .41717 Mdot
.30329 .59426 Mdot
.42895 .73676 Mdot
.65437 .54347 Mdot
.39706 .34051 Mdot
.58839 .63808 Mdot
.59634 .63053 Mdot
.659 .55244 Mdot
.31518 .56962 Mdot
.64221 .53027 Mdot
.48015 .34488 Mdot
.37319 .43041 Mdot
.39769 .45112 Mdot
.47323 .15482 Mdot
.70206 .70772 Mdot
.326 .56384 Mdot
.62433 .50009 Mdot
.47618 .61622 Mdot
.60801 .62346 Mdot
.64938 .55743 Mdot
.29758 .59682 Mdot
.35026 .55024 Mdot
.36745 .60328 Mdot
.64535 .32691 Mdot
.6379 .51105 Mdot
.3362 .63814 Mdot
.36593 .54163 Mdot
.40753 .43051 Mdot
.42057 .41904 Mdot
.38174 .60542 Mdot
.62691 .27901 Mdot
.6666 .34973 Mdot
.67471 .51056 Mdot
.80183 .68603 Mdot
.60872 .61491 Mdot
.19745 .42765 Mdot
.42791 .4165 Mdot
.13786 .35338 Mdot
.43834 .46303 Mdot
.42711 .39771 Mdot
.35065 .54654 Mdot
.64792 .31576 Mdot
.64141 .34475 Mdot
.32993 .57231 Mdot
.36995 .53797 Mdot
.63311 .33461 Mdot
.62589 .44184 Mdot
.47254 .83541 Mdot
.46456 .63005 Mdot
.32306 .57703 Mdot
.20467 .44393 Mdot
.59338 .65103 Mdot
.30569 .57105 Mdot
.61552 .63928 Mdot
.65776 .49438 Mdot
.68712 .49369 Mdot
.57056 .66152 Mdot
.44389 .44542 Mdot
.66352 .48282 Mdot
.50545 .40046 Mdot
.6415 .78194 Mdot
.80353 .56523 Mdot
.25012 .66881 Mdot
.41293 .35641 Mdot
.38833 .67255 Mdot
.35831 .70172 Mdot
.44888 .41794 Mdot
.40694 .31747 Mdot
.655 .34638 Mdot
.30438 .57728 Mdot
.61155 .63488 Mdot
.71336 .72578 Mdot
.44071 .37785 Mdot
.32857 .6039 Mdot
.60465 .61686 Mdot
.66605 .72617 Mdot
.51691 .49143 Mdot
.39271 .40825 Mdot
.10949 .60766 Mdot
.32603 .55236 Mdot
.64109 .5436 Mdot
.18466 .51171 Mdot
.31721 .54983 Mdot
.74716 .39257 Mdot
.61809 .49658 Mdot
.47828 .76477 Mdot
.35622 .55264 Mdot
.61313 .52624 Mdot
.33705 .59578 Mdot
.64225 .37549 Mdot
.34676 .53354 Mdot
.65495 .52491 Mdot
.41752 .38414 Mdot
.65118 .52459 Mdot
.65916 .36806 Mdot
.65094 .48092 Mdot
.61045 .63665 Mdot
.44066 .73378 Mdot
.60155 .61827 Mdot
.50968 .55729 Mdot
.31783 .38254 Mdot
.57402 .64694 Mdot
.72687 .65547 Mdot
.40091 .38885 Mdot
.29951 .55674 Mdot
.64202 .54627 Mdot
.69441 .5085 Mdot
.49606 .59474 Mdot
.33294 .60292 Mdot
.6619 .52074 Mdot
.23321 .3858 Mdot
.28242 .23108 Mdot
.50638 .42053 Mdot
.72348 .30501 Mdot
.32365 .58146 Mdot
.62598 .52858 Mdot
.45969 .65144 Mdot
.34215 .62237 Mdot
.68531 .51722 Mdot
.56221 .64963 Mdot
.58061 .63587 Mdot
.42821 .44665 Mdot
.55078 .65359 Mdot
.62076 .50137 Mdot
.29204 .71047 Mdot
.36557 .60071 Mdot
.67512 .71043 Mdot
.62888 .35231 Mdot
.65405 .4921 Mdot
.4745 .45577 Mdot
.3697 .63139 Mdot
.69173 .50619 Mdot
.81389 .48079 Mdot
.82579 .64791 Mdot
.66294 .51971 Mdot
.36654 .59605 Mdot
.35464 .59826 Mdot
.49509 .43191 Mdot
.48369 .60191 Mdot
.66007 .5275 Mdot
.74486 .54648 Mdot
.62298 .23484 Mdot
.4527 .74973 Mdot
.16602 .49477 Mdot
.4341 .42935 Mdot
.45948 .42723 Mdot
.60156 .63957 Mdot
.40986 .3874 Mdot
.37963 .55041 Mdot
.41999 .45958 Mdot
.57559 .60074 Mdot
.62611 .51121 Mdot
.43484 .37219 Mdot
.64737 .33194 Mdot
.6066 .63693 Mdot
.55258 .62886 Mdot
.66112 .50645 Mdot
.37127 .5899 Mdot
.53783 .78076 Mdot
.64289 .51021 Mdot
.4533 .43018 Mdot
.44603 .74226 Mdot
.38811 .35612 Mdot
.77848 .50893 Mdot
.34827 .61872 Mdot
.64442 .54389 Mdot
.31192 .61218 Mdot
.58951 .61732 Mdot
.68417 .53461 Mdot
.43356 .4074 Mdot
.68631 .51055 Mdot
.61541 .40558 Mdot
.70758 .42788 Mdot
.36859 .54108 Mdot
.6526 .3899 Mdot
.31177 .60069 Mdot
.45307 .74981 Mdot
.52798 .27401 Mdot
.66023 .35665 Mdot
.67311 .48965 Mdot
.6975 .72273 Mdot
.65067 .55058 Mdot
.4118 .37422 Mdot
.41468 .36151 Mdot
.66253 .5354 Mdot
.65438 .32793 Mdot
.50769 .1936 Mdot
.69659 .32707 Mdot
.35278 .55643 Mdot
.4417 .55128 Mdot
.7607 .72794 Mdot
.69342 .53696 Mdot
.55648 .63617 Mdot
.4805 .32996 Mdot
.4025 .40383 Mdot
.55781 .65436 Mdot
.59972 .60341 Mdot
.6685 .36136 Mdot
.64381 .48919 Mdot
.31527 .62397 Mdot
.58642 .65636 Mdot
.34849 .44298 Mdot
.51508 .2069 Mdot
.49799 .39809 Mdot
.42377 .47318 Mdot
.455 .36221 Mdot
.53365 .52503 Mdot
.60145 .59809 Mdot
.45216 .39999 Mdot
.36896 .41612 Mdot
.56497 .64472 Mdot
.65482 .37131 Mdot
.38582 .52123 Mdot
.66771 .50992 Mdot
.21991 .27067 Mdot
.47404 .3916 Mdot
.41759 .3798 Mdot
.58391 .64232 Mdot
.18692 .55869 Mdot
.32087 .57408 Mdot
.37049 .58681 Mdot
.64898 .49512 Mdot
.49632 .60483 Mdot
.46915 .43584 Mdot
.45063 .41432 Mdot
.66958 .49051 Mdot
.43904 .73746 Mdot
.2346 .67533 Mdot
.44792 .38726 Mdot
.57715 .62239 Mdot
.72093 .65279 Mdot
.60519 .59973 Mdot
.3849 .39472 Mdot
.41152 .37114 Mdot
.47477 .38423 Mdot
.39557 .37175 Mdot
.57733 .66053 Mdot
.44693 .41553 Mdot
.35573 .38722 Mdot
.3469 .56349 Mdot
.4427 .42735 Mdot
.59775 .22364 Mdot
.44329 .38442 Mdot
.64797 .3327 Mdot
.508 .76465 Mdot
.45724 .37647 Mdot
.44638 .42811 Mdot
.69604 .34088 Mdot
.42732 .39159 Mdot
.58822 .60802 Mdot
.35536 .59273 Mdot
.58586 .6159 Mdot
.57077 .61397 Mdot
.69003 .49002 Mdot
.66141 .37219 Mdot
.42226 .33946 Mdot
.62995 .33627 Mdot
.48957 .43369 Mdot
.3836 .36998 Mdot
.51788 .55768 Mdot
.46546 .66556 Mdot
.6867 .34102 Mdot
.44007 .40973 Mdot
.65289 .49791 Mdot
.65317 .54547 Mdot
.57933 .35494 Mdot
.50282 .40902 Mdot
.59757 .6494 Mdot
.5696 .65531 Mdot
.59932 .27914 Mdot
.5318 .46422 Mdot
.65397 .33449 Mdot
.46328 .5891 Mdot
.4265 .35127 Mdot
.45836 .38424 Mdot
.39551 .43609 Mdot
.6611 .47059 Mdot
.4379 .73372 Mdot
.62706 .50755 Mdot
.46388 .74267 Mdot
.61347 .60498 Mdot
.41435 .35614 Mdot
.78934 .59814 Mdot
.31504 .57534 Mdot
.35622 .5913 Mdot
.56996 .60349 Mdot
.62427 .49421 Mdot
.49729 .42141 Mdot
.49676 .14447 Mdot
.37983 .59924 Mdot
.62859 .32892 Mdot
.45359 .41085 Mdot
.65934 .50332 Mdot
.33085 .55419 Mdot
.67101 .36683 Mdot
.42193 .35475 Mdot
.63952 .55679 Mdot
.44118 .38979 Mdot
.22677 .51447 Mdot
.34131 .56669 Mdot
.46473 .70001 Mdot
.38802 .55249 Mdot
.55719 .64865 Mdot
.56452 .62641 Mdot
.41599 .36709 Mdot
.38483 .16891 Mdot
.39382 .5569 Mdot
.56896 .66813 Mdot
.63977 .37784 Mdot
.43392 .73704 Mdot
.65117 .37753 Mdot
.63939 .5339 Mdot
.65627 .35387 Mdot
.68732 .51653 Mdot
.60981 .29186 Mdot
.35746 .62857 Mdot
.648 .367 Mdot
.18749 .569 Mdot
.38133 .36168 Mdot
.67256 .35436 Mdot
.37758 .43858 Mdot
.39417 .51089 Mdot
.66778 .49174 Mdot
.65064 .32853 Mdot
.42155 .44108 Mdot
.74317 .67558 Mdot
.5667 .62036 Mdot
.60104 .64687 Mdot
.41393 .3417 Mdot
.6314 .54377 Mdot
.36287 .53736 Mdot
.57812 .46087 Mdot
.42771 .74146 Mdot
.44997 .41378 Mdot
.42213 .35326 Mdot
.30779 .58142 Mdot
.38219 .5785 Mdot
.41214 .3682 Mdot
.24436 .37487 Mdot
.42409 .40366 Mdot
.57707 .63469 Mdot
.34246 .55186 Mdot
.35684 .59461 Mdot
.63094 .47846 Mdot
.31503 .57037 Mdot
.43369 .47033 Mdot
.62631 .61087 Mdot
.37981 .42995 Mdot
.59081 .62018 Mdot
.57294 .39612 Mdot
.64075 .48917 Mdot
.71217 .71864 Mdot
.32264 .55907 Mdot
.45541 .42322 Mdot
.31849 .60723 Mdot
.6315 .35519 Mdot
.35808 .57257 Mdot
.35432 .62469 Mdot
.42371 .35819 Mdot
.3902 .40383 Mdot
.44177 .7392 Mdot
.48557 .60426 Mdot
.34087 .57334 Mdot
.43217 .41243 Mdot
.42649 .34247 Mdot
.39532 .42408 Mdot
.53057 .51186 Mdot
.35665 .54911 Mdot
.29796 .30782 Mdot
.79225 .5299 Mdot
.33631 .57961 Mdot
.7169 .74343 Mdot
.44202 .76264 Mdot
.45071 .72408 Mdot
.57368 .67129 Mdot
.44894 .3836 Mdot
.64371 .52904 Mdot
.46968 .42181 Mdot
.5052 .39316 Mdot
.45794 .375 Mdot
.66584 .3596 Mdot
.47914 .36409 Mdot
.4415 .75732 Mdot
.64495 .51549 Mdot
.42461 .40931 Mdot
.4392 .37146 Mdot
.45383 .72592 Mdot
.38976 .55357 Mdot
.35183 .55168 Mdot
.48463 .79843 Mdot
.6475 .37169 Mdot
.59313 .64471 Mdot
.4667 .42486 Mdot
.65112 .49699 Mdot
.64572 .52513 Mdot
.34321 .61573 Mdot
.67163 .50714 Mdot
.61316 .62236 Mdot
.42286 .3981 Mdot
.55912 .65567 Mdot
.66525 .36039 Mdot
.36585 .59806 Mdot
.46604 .4265 Mdot
.409 .43279 Mdot
.33109 .57657 Mdot
.40017 .38622 Mdot
.67228 .3411 Mdot
.67437 .48046 Mdot
.34617 .5542 Mdot
.59965 .62674 Mdot
.63818 .4739 Mdot
.40191 .41549 Mdot
.85746 .54496 Mdot
.40918 .38823 Mdot
.46902 .40926 Mdot
.50798 .83915 Mdot
.37377 .37729 Mdot
.63097 .53257 Mdot
.31899 .60997 Mdot
.3864 .40987 Mdot
.64984 .25032 Mdot
.67652 .57076 Mdot
.64186 .55968 Mdot
.45627 .41206 Mdot
.69272 .74896 Mdot
.45158 .42352 Mdot
.65618 .73823 Mdot
.51609 .5596 Mdot
.79124 .35967 Mdot
.40991 .47228 Mdot
.56477 .66581 Mdot
.44143 .7369 Mdot
.64056 .5476 Mdot
.25068 .53797 Mdot
.40445 .3861 Mdot
.29246 .5302 Mdot
.47572 .41821 Mdot
.57487 .63018 Mdot
.41782 .31519 Mdot
.67396 .50988 Mdot
.18022 .44853 Mdot
.4496 .43526 Mdot
.35306 .54861 Mdot
.69673 .50831 Mdot
.43113 .74432 Mdot
.42259 .44214 Mdot
.62706 .34721 Mdot
.63594 .58746 Mdot
.40317 .46386 Mdot
.5933 .62093 Mdot
.45996 .3903 Mdot
.48826 .3426 Mdot
.31806 .21341 Mdot
.34789 .56133 Mdot
.5575 .64002 Mdot
.39174 .63681 Mdot
.4008 .37043 Mdot
.35331 .55245 Mdot
.35292 .59257 Mdot
.62841 .36534 Mdot
.4836 .67628 Mdot
.71588 .53221 Mdot
.8209 .54188 Mdot
.31267 .49306 Mdot
.64655 .46844 Mdot
.29729 .6933 Mdot
.42542 .42498 Mdot
.50012 .29813 Mdot
.57929 .60984 Mdot
.41852 .3825 Mdot
.31438 .44063 Mdot
.35329 .56749 Mdot
.44685 .39254 Mdot
.66604 .3522 Mdot
.4347 .70253 Mdot
.49691 .31458 Mdot
.82511 .61111 Mdot
.68321 .53978 Mdot
.39898 .44326 Mdot
.38186 .45493 Mdot
.42994 .7351 Mdot
.38592 .38716 Mdot
.63893 .54467 Mdot
.76013 .56648 Mdot
.65924 .33081 Mdot
.31791 .5686 Mdot
.43872 .76163 Mdot
.4823 .40268 Mdot
.39715 .35274 Mdot
.62078 .33711 Mdot
.44461 .44205 Mdot
.18225 .4853 Mdot
.43056 .72056 Mdot
.6757 .48718 Mdot
.36961 .56783 Mdot
.4526 .36056 Mdot
.43728 .73558 Mdot
.42005 .35888 Mdot
.40544 .52764 Mdot
.46284 .40938 Mdot
.41137 .79623 Mdot
.33118 .58462 Mdot
.59639 .61907 Mdot
.45749 .3409 Mdot
.43505 .38096 Mdot
.75159 .41417 Mdot
.50453 .38902 Mdot
.44861 .3702 Mdot
.37429 .59986 Mdot
.31293 .58691 Mdot
.3387 .61244 Mdot
.67092 .483 Mdot
.46575 .62209 Mdot
.58218 .6292 Mdot
.44296 .45679 Mdot
.59142 .6532 Mdot
.41077 .4916 Mdot
.62226 .33825 Mdot
.75478 .69069 Mdot
.41161 .39814 Mdot
.35103 .61009 Mdot
.30941 .72503 Mdot
.35608 .54497 Mdot
.56044 .67527 Mdot
.59051 .61157 Mdot
.34667 .5736 Mdot
.43309 .39591 Mdot
.47429 .60547 Mdot
.84161 .56671 Mdot
.60704 .62521 Mdot
.37972 .40881 Mdot
.69066 .53007 Mdot
.68684 .52329 Mdot
.68994 .78333 Mdot
.56801 .61452 Mdot
.35359 .70046 Mdot
.43769 .41792 Mdot
.31237 .58145 Mdot
.57974 .64751 Mdot
.58673 .6068 Mdot
.6716 .49512 Mdot
.39491 .41381 Mdot
.43704 .38331 Mdot
.45312 .75626 Mdot
.58329 .6546 Mdot
.42072 .32461 Mdot
.39273 .39567 Mdot
.57115 .83236 Mdot
.30021 .60464 Mdot
.17902 .35877 Mdot
.47876 .34189 Mdot
.31869 .43895 Mdot
.5476 .46274 Mdot
.32989 .5588 Mdot
.4577 .43861 Mdot
.45002 .45526 Mdot
.63939 .47148 Mdot
.41766 .39548 Mdot
.63345 .4875 Mdot
.55651 .63124 Mdot
.76106 .69052 Mdot
.68614 .6878 Mdot
.59741 .54735 Mdot
.41014 .3828 Mdot
.51893 .34351 Mdot
.63728 .36068 Mdot
.57953 .5937 Mdot
.32167 .6017 Mdot
.44514 .35495 Mdot
.62004 .48885 Mdot
.676 .49295 Mdot
.35281 .58472 Mdot
.36661 .71613 Mdot
.68438 .72707 Mdot
.39615 .36908 Mdot
.6469 .54179 Mdot
.66963 .69964 Mdot
.26331 .36454 Mdot
.55746 .66022 Mdot
.66242 .3348 Mdot
.62773 .51648 Mdot
.55649 .61306 Mdot
.40776 .51713 Mdot
.34597 .58423 Mdot
.31252 .56853 Mdot
.76008 .465 Mdot
.65683 .52741 Mdot
.64144 .35836 Mdot
.51124 .48452 Mdot
.47351 .50794 Mdot
.6686 .34993 Mdot
.62552 .50868 Mdot
.31833 .57086 Mdot
.33055 .60527 Mdot
.35425 .59451 Mdot
.18112 .46341 Mdot
.35209 .61967 Mdot
.27493 .2948 Mdot
.40035 .35715 Mdot
.21228 .43796 Mdot
.45382 .42061 Mdot
.5932 .65744 Mdot
.33986 .56767 Mdot
.50206 .56758 Mdot
.44818 .35055 Mdot
.8277 .59832 Mdot
.45285 .40674 Mdot
.63117 .62034 Mdot
.44833 .38181 Mdot
.19492 .50988 Mdot
.30282 .59282 Mdot
.43964 .41082 Mdot
.60415 .65881 Mdot
.65303 .34109 Mdot
.38943 .54284 Mdot
.45293 .37518 Mdot
.41235 .76589 Mdot
.37123 .42193 Mdot
.66657 .75774 Mdot
.72027 .36093 Mdot
.63455 .32215 Mdot
.38886 .44498 Mdot
.68537 .47606 Mdot
.39893 .58936 Mdot
.20502 .46418 Mdot
.60656 .62572 Mdot
.35516 .28824 Mdot
.67019 .48724 Mdot
.41119 .31748 Mdot
.49 .4069 Mdot
.65125 .32484 Mdot
.39385 .55127 Mdot
.57484 .63504 Mdot
.40288 .38955 Mdot
.45773 .44074 Mdot
.80804 .45351 Mdot
.20076 .47215 Mdot
.42254 .32584 Mdot
.62285 .3711 Mdot
.30308 .30927 Mdot
.46183 .38198 Mdot
.63861 .55839 Mdot
.32575 .61655 Mdot
.45956 .46427 Mdot
.29042 .31166 Mdot
.42794 .40891 Mdot
.34926 .57579 Mdot
.32022 .56141 Mdot
.36335 .7746 Mdot
.62559 .33446 Mdot
.46294 .40906 Mdot
.76119 .41192 Mdot
.45622 .43013 Mdot
.57936 .63138 Mdot
.38408 .39735 Mdot
.65937 .49007 Mdot
.45824 .65789 Mdot
.66828 .48026 Mdot
.40934 .43794 Mdot
.34184 .60355 Mdot
.57616 .63904 Mdot
.76568 .48267 Mdot
.57321 .4902 Mdot
.2819 .28952 Mdot
.63875 .58793 Mdot
.64134 .33103 Mdot
.66435 .37178 Mdot
.62675 .63122 Mdot
.4447 .40656 Mdot
.54944 .50005 Mdot
.46366 .45539 Mdot
.45045 .37922 Mdot
.47157 .38823 Mdot
.58889 .58468 Mdot
.59391 .61329 Mdot
.65827 .519 Mdot
.4106 .36936 Mdot
.43345 .41305 Mdot
.3379 .58366 Mdot
.65749 .34161 Mdot
.67993 .4886 Mdot
.6422 .36978 Mdot
.64806 .5098 Mdot
.65465 .80569 Mdot
.38373 .40741 Mdot
.65191 .34044 Mdot
.60254 .59695 Mdot
.35282 .61161 Mdot
.45528 .73141 Mdot
.63889 .53244 Mdot
.67271 .51282 Mdot
.44822 .41654 Mdot
.36758 .58258 Mdot
.36303 .56594 Mdot
.63539 .33313 Mdot
.57205 .65238 Mdot
.43221 .44815 Mdot
.39096 .39833 Mdot
.77807 .37499 Mdot
.64995 .47007 Mdot
.25663 .35433 Mdot
.37084 .7627 Mdot
.44378 .407 Mdot
.3605 .56 Mdot
.43076 .37331 Mdot
.76206 .62244 Mdot
.36524 .60901 Mdot
.43864 .34427 Mdot
.53142 .44683 Mdot
.66673 .47297 Mdot
.36557 .79288 Mdot
.44932 .34057 Mdot
.61994 .68968 Mdot
.42498 .43396 Mdot
.44995 .85931 Mdot
.27586 .66898 Mdot
.47976 .41237 Mdot
.39878 .36721 Mdot
.83185 .51392 Mdot
.44268 .42209 Mdot
.44485 .75951 Mdot
.48956 .35683 Mdot
.35151 .55071 Mdot
.55701 .46117 Mdot
.52307 .56406 Mdot
.62152 .35478 Mdot
.64888 .49431 Mdot
.49082 .24828 Mdot
.64766 .3742 Mdot
.32617 .57298 Mdot
.42029 .3473 Mdot
.34098 .43945 Mdot
.63841 .45766 Mdot
.48875 .42707 Mdot
.57782 .631 Mdot
.52017 .56704 Mdot
.62964 .50101 Mdot
.60093 .62382 Mdot
.47833 .40355 Mdot
.62791 .21561 Mdot
.57808 .50268 Mdot
.41188 .81592 Mdot
.58531 .64377 Mdot
.57933 .61301 Mdot
.45205 .63497 Mdot
.62161 .35492 Mdot
.80322 .42729 Mdot
.44738 .29717 Mdot
.60886 .61767 Mdot
.56393 .26445 Mdot
.61834 .51805 Mdot
.47882 .67755 Mdot
.30355 .57801 Mdot
.38574 .41521 Mdot
.43347 .39248 Mdot
.56799 .64939 Mdot
.29574 .5421 Mdot
.41678 .56707 Mdot
.60377 .62033 Mdot
.36817 .43444 Mdot
.48129 .68861 Mdot
.44673 .73855 Mdot
.44885 .76176 Mdot
.63135 .37474 Mdot
.70908 .45011 Mdot
.33099 .59489 Mdot
.65919 .32496 Mdot
.46028 .7745 Mdot
.46412 .40552 Mdot
.58462 .65498 Mdot
.45873 .74275 Mdot
.5938 .6307 Mdot
.64394 .3405 Mdot
.62702 .33093 Mdot
.34713 .56304 Mdot
.31988 .57637 Mdot
.33466 .31242 Mdot
.59991 .2609 Mdot
.44449 .42539 Mdot
.33671 .48969 Mdot
.35808 .61209 Mdot
.21725 .56812 Mdot
.62676 .33781 Mdot
.66148 .34417 Mdot
.23639 .45599 Mdot
.40243 .42154 Mdot
.70217 .66962 Mdot
.45704 .37735 Mdot
.53656 .28353 Mdot
.47903 .37752 Mdot
.67188 .499 Mdot
.44255 .43222 Mdot
.53122 .76371 Mdot
.416 .40891 Mdot
.46422 .37693 Mdot
.63569 .51852 Mdot
.45554 .33879 Mdot
.66149 .48863 Mdot
.38845 .40325 Mdot
.62108 .32844 Mdot
.65088 .49714 Mdot
.68246 .28683 Mdot
.61695 .41889 Mdot
.4357 .74301 Mdot
.63949 .37683 Mdot
.62868 .34231 Mdot
.5908 .21667 Mdot
.31818 .59596 Mdot
.41306 .51274 Mdot
.4455 .40557 Mdot
.62615 .53554 Mdot
.59887 .64387 Mdot
.42915 .40903 Mdot
.43049 .46212 Mdot
.44215 .33841 Mdot
.34905 .56834 Mdot
.6247 .5135 Mdot
.64887 .34636 Mdot
.66041 .54244 Mdot
.64979 .41511 Mdot
.67307 .53876 Mdot
.50655 .3529 Mdot
.46608 .33541 Mdot
.37214 .46805 Mdot
.329 .47138 Mdot
.19185 .41275 Mdot
.34848 .58718 Mdot
.44482 .74898 Mdot
.62055 .34575 Mdot
.43996 .54934 Mdot
.34586 .60886 Mdot
.6706 .51754 Mdot
.44108 .38986 Mdot
.36671 .43347 Mdot
.49234 .3167 Mdot
.34675 .64041 Mdot
.63595 .25531 Mdot
.63628 .5032 Mdot
.45281 .74039 Mdot
.46401 .63971 Mdot
.2901 .62127 Mdot
.50505 .56117 Mdot
.43346 .37686 Mdot
.62748 .34143 Mdot
.33075 .55427 Mdot
.7894 .47636 Mdot
.56427 .65007 Mdot
.48414 .60371 Mdot
.41046 .38491 Mdot
.31672 .70542 Mdot
.34199 .6033 Mdot
.66464 .34424 Mdot
.56773 .64877 Mdot
.62528 .33673 Mdot
.43785 .76264 Mdot
.50208 .7861 Mdot
.43483 .44248 Mdot
.44774 .36878 Mdot
.61566 .61464 Mdot
.33251 .59705 Mdot
.61525 .47924 Mdot
.80179 .48434 Mdot
.64958 .54158 Mdot
.54412 .51819 Mdot
.33516 .55305 Mdot
.27918 .64879 Mdot
.68397 .5159 Mdot
.58473 .59612 Mdot
.54201 .50757 Mdot
.5746 .60191 Mdot
.46476 .38145 Mdot
.36259 .59446 Mdot
.56753 .61481 Mdot
.77194 .44422 Mdot
.63823 .80269 Mdot
.39471 .54411 Mdot
.40138 .3769 Mdot
.76016 .6878 Mdot
.55505 .82167 Mdot
.35044 .50993 Mdot
.58083 .65811 Mdot
.42025 .36888 Mdot
.39691 .36666 Mdot
.44892 .43457 Mdot
.55989 .631 Mdot
.59431 .49375 Mdot
.67817 .50911 Mdot
.45509 .40079 Mdot
.62923 .35179 Mdot
.66343 .4963 Mdot
.69158 .48683 Mdot
.64338 .54923 Mdot
.36771 .60745 Mdot
.40956 .35187 Mdot
.44302 .68915 Mdot
.47967 .86052 Mdot
.59068 .61441 Mdot
.43556 .74344 Mdot
.47468 .3885 Mdot
.34443 .25165 Mdot
.34068 .61247 Mdot
.65125 .54081 Mdot
.41868 .38075 Mdot
.72657 .38441 Mdot
.41768 .75931 Mdot
.64047 .50755 Mdot
.32131 .59982 Mdot
.35415 .5093 Mdot
.41811 .39628 Mdot
.42156 .43273 Mdot
.32531 .58964 Mdot
.46399 .80535 Mdot
.46589 .65892 Mdot
.43384 .37333 Mdot
.59836 .61962 Mdot
.30395 .21339 Mdot
.40215 .34847 Mdot
.35145 .64136 Mdot
.43464 .73488 Mdot
.40525 .78461 Mdot
.26513 .34788 Mdot
.5133 .40698 Mdot
.78037 .64872 Mdot
.47251 .23029 Mdot
.74736 .70497 Mdot
.4861 .26751 Mdot
.64655 .70776 Mdot
.58619 .85415 Mdot
.5875 .66691 Mdot
.19991 .51637 Mdot
.82133 .41313 Mdot
.38312 .70453 Mdot
.70097 .37186 Mdot
.71326 .57184 Mdot
.73102 .37379 Mdot
.18992 .6079 Mdot
.67736 .53289 Mdot
.52961 .30228 Mdot
.44868 .44536 Mdot
.54882 .81766 Mdot
.20874 .42141 Mdot
.19601 .39049 Mdot
.74424 .69642 Mdot
.75475 .39904 Mdot
.85351 .51949 Mdot
.70987 .71527 Mdot
.34533 .31896 Mdot
.54357 .37831 Mdot
.71776 .47633 Mdot
.49412 .49461 Mdot
.48081 .24558 Mdot
.44426 .47652 Mdot
.52926 .74706 Mdot
.60565 .55885 Mdot
.30811 .35847 Mdot
.28906 .23585 Mdot
.63226 .53058 Mdot
.32828 .61819 Mdot
.80351 .41 Mdot
.37594 .62956 Mdot
.60186 .66998 Mdot
.78108 .64804 Mdot
.56996 .83593 Mdot
.1941 .50506 Mdot
.47516 .74994 Mdot
.23863 .50272 Mdot
.50084 .18889 Mdot
.54043 .3527 Mdot
.35272 .54029 Mdot
.6803 .6403 Mdot
.47391 .50719 Mdot
.6965 .4516 Mdot
.19596 .53856 Mdot
.6758 .36074 Mdot
.67447 .2758 Mdot
.32458 .6015 Mdot
.27289 .35715 Mdot
.44602 .72288 Mdot
.47018 .74913 Mdot
.61411 .52058 Mdot
.76847 .60673 Mdot
.41405 .73762 Mdot
.41076 .72695 Mdot
.27897 .70615 Mdot
.84949 .58276 Mdot
.53043 .22616 Mdot
.76288 .54985 Mdot
.61037 .68677 Mdot
.48482 .22613 Mdot
.43141 .67317 Mdot
.5806 .24312 Mdot
.46968 .49873 Mdot
.85011 .40972 Mdot
.48914 .82136 Mdot
.86045 .48234 Mdot
.32928 .53469 Mdot
.38639 .35009 Mdot
.77627 .55885 Mdot
.30069 .50369 Mdot
.65277 .31408 Mdot
.83943 .59617 Mdot
.64473 .32055 Mdot
.31903 .62622 Mdot
.37633 .70481 Mdot
.18644 .46659 Mdot
.60714 .49567 Mdot
.66714 .29837 Mdot
.43738 .4672 Mdot
.83974 .34966 Mdot
.79384 .63138 Mdot
.37543 .77815 Mdot
.5614 .83551 Mdot
.68812 .54364 Mdot
.65936 .45661 Mdot
.55737 .6272 Mdot
.60481 .83319 Mdot
.35321 .60306 Mdot
.48923 .86559 Mdot
.59995 .83011 Mdot
.35437 .65321 Mdot
.83189 .3246 Mdot
.2305 .65672 Mdot
.21772 .42322 Mdot
.39325 .26693 Mdot
.70078 .27646 Mdot
.43708 .64762 Mdot
.28428 .65585 Mdot
.69903 .52219 Mdot
.45311 .81592 Mdot
.66569 .79154 Mdot
.56593 .27556 Mdot
.55267 .59375 Mdot
.39435 .68738 Mdot
.57305 .38504 Mdot
.37216 .62415 Mdot
.70264 .3405 Mdot
.57206 .37159 Mdot
.85931 .50087 Mdot
.33074 .29524 Mdot
.42512 .15455 Mdot
.49926 .26919 Mdot
.18445 .55133 Mdot
.70455 .6987 Mdot
.63207 .30076 Mdot
.41102 .53951 Mdot
.39674 .73108 Mdot
.37555 .41208 Mdot
.46001 .5978 Mdot
.36074 .35346 Mdot
.62956 .39379 Mdot
.45961 .62893 Mdot
.62094 .76278 Mdot
.51662 .26939 Mdot
.81025 .54431 Mdot
.53858 .40498 Mdot
.37306 .57099 Mdot
.57245 .23106 Mdot
.54088 .24663 Mdot
.59185 .8182 Mdot
.39035 .63897 Mdot
.42353 .81583 Mdot
.39957 .62374 Mdot
.45993 .45767 Mdot
.20339 .524 Mdot
.42605 .48035 Mdot
.56452 .25044 Mdot
.46372 .35113 Mdot
.28763 .71622 Mdot
.51661 .83989 Mdot
.31473 .40247 Mdot
.50628 .2486 Mdot
.32894 .45215 Mdot
.46253 .8209 Mdot
.78117 .55761 Mdot
.30271 .67985 Mdot
.26718 .62224 Mdot
.84378 .36879 Mdot
.66462 .50734 Mdot
.57288 .26673 Mdot
.6007 .58503 Mdot
.76596 .47207 Mdot
.81602 .38496 Mdot
.40964 .59685 Mdot
.50728 .84273 Mdot
.40568 .71021 Mdot
.62034 .46299 Mdot
.50108 .68521 Mdot
.53462 .62692 Mdot
.32985 .42308 Mdot
.41653 .33938 Mdot
.36115 .46214 Mdot
.6714 .33566 Mdot
.28191 .50757 Mdot
.78464 .53123 Mdot
.65227 .6173 Mdot
.51731 .39793 Mdot
.65672 .63811 Mdot
.45469 .74501 Mdot
.48375 .61546 Mdot
.67982 .79345 Mdot
.49936 .36402 Mdot
.2198 .63181 Mdot
.48643 .81576 Mdot
.53466 .52669 Mdot
.68101 .42885 Mdot
.34571 .73918 Mdot
.86075 .4491 Mdot
.55447 .85147 Mdot
.58753 .79601 Mdot
.76602 .68107 Mdot
.29579 .78014 Mdot
.79306 .33831 Mdot
.25407 .56929 Mdot
.60287 .58208 Mdot
.21724 .74937 Mdot
.67294 .52905 Mdot
.3651 .27389 Mdot
.30216 .49945 Mdot
.72595 .39407 Mdot
.39061 .60754 Mdot
.52492 .42231 Mdot
.66391 .56678 Mdot
.38912 .58968 Mdot
.44139 .46519 Mdot
.82149 .64293 Mdot
.85328 .41025 Mdot
.83252 .62412 Mdot
.50433 .78802 Mdot
.75889 .70131 Mdot
.83962 .46222 Mdot
.26707 .30124 Mdot
.80979 .43518 Mdot
.38432 .39666 Mdot
.58623 .28985 Mdot
.23648 .65752 Mdot
.61159 .51522 Mdot
.46529 .71234 Mdot
.29665 .57771 Mdot
.84273 .41374 Mdot
.68868 .78996 Mdot
.25247 .45359 Mdot
.29654 .34492 Mdot
.60477 .40916 Mdot
.58524 .25493 Mdot
.3397 .37839 Mdot
.53303 .73677 Mdot
.63773 .78736 Mdot
.83833 .45082 Mdot
.53552 .25571 Mdot
.69629 .59133 Mdot
.59271 .78524 Mdot
.23771 .62892 Mdot
.73342 .68372 Mdot
.80328 .40039 Mdot
.37494 .64167 Mdot
.27878 .60072 Mdot
.41525 .57266 Mdot
.52103 .72809 Mdot
.74785 .60735 Mdot
.51245 .22656 Mdot
.65008 .48019 Mdot
.57267 .27873 Mdot
.50026 .53063 Mdot
.81051 .42888 Mdot
.50051 .21635 Mdot
.56156 .27973 Mdot
.60942 .78345 Mdot
.80359 .66008 Mdot
.44488 .79699 Mdot
.66302 .23341 Mdot
.58728 .7133 Mdot
.36725 .34156 Mdot
.4013 .3368 Mdot
.48971 .83368 Mdot
.78459 .69759 Mdot
.51795 .84692 Mdot
.3113 .70351 Mdot
.7648 .44436 Mdot
.54978 .64512 Mdot
.49186 .20927 Mdot
.64173 .64869 Mdot
.64629 .78529 Mdot
.44926 .56014 Mdot
.55564 .66587 Mdot
.41703 .69718 Mdot
.34505 .30979 Mdot
.43494 .23859 Mdot
.28515 .37517 Mdot
.49913 .41437 Mdot
.24022 .39142 Mdot
.30874 .60192 Mdot
.30632 .69644 Mdot
.57977 .24773 Mdot
.66186 .50564 Mdot
.76493 .34396 Mdot
.34705 .43186 Mdot
.37401 .37177 Mdot
.75477 .5763 Mdot
.37667 .61912 Mdot
.32629 .46681 Mdot
.67319 .46098 Mdot
.61025 .83972 Mdot
.26112 .67117 Mdot
.33549 .38518 Mdot
.54811 .22182 Mdot
.77696 .38341 Mdot
.47243 .65584 Mdot
.61848 .60603 Mdot
.73472 .70128 Mdot
.61022 .42966 Mdot
.5637 .22984 Mdot
.24426 .382 Mdot
.79422 .49936 Mdot
.44461 .45856 Mdot
.34862 .75593 Mdot
.3044 .27518 Mdot
.48747 .61339 Mdot
.30899 .6264 Mdot
.37434 .60911 Mdot
.15109 .55489 Mdot
.54479 .7657 Mdot
.34833 .66576 Mdot
.74156 .68559 Mdot
.56346 .61429 Mdot
.37916 .57541 Mdot
.56456 .2888 Mdot
.71384 .43246 Mdot
.3143 .31293 Mdot
.75212 .61036 Mdot
.35658 .31966 Mdot
.6309 .68493 Mdot
.76343 .67842 Mdot
.8256 .57901 Mdot
.33288 .20052 Mdot
.38816 .55773 Mdot
.77301 .50985 Mdot
.77724 .49861 Mdot
.35449 .54178 Mdot
.34772 .64087 Mdot
.51233 .33244 Mdot
.73553 .72618 Mdot
.45948 .54202 Mdot
.51878 .71286 Mdot
.54248 .50844 Mdot
.69568 .38566 Mdot
.7971 .47257 Mdot
.49232 .23321 Mdot
.74632 .66994 Mdot
.27641 .37254 Mdot
.7187 .27561 Mdot
.36356 .45227 Mdot
.34596 .27888 Mdot
.49174 .20902 Mdot
.55346 .37931 Mdot
.19981 .54474 Mdot
.64147 .75175 Mdot
.45285 .42919 Mdot
.84798 .59556 Mdot
.59189 .81267 Mdot
.45337 .60184 Mdot
.70823 .47515 Mdot
.4109 .41618 Mdot
.40494 .35361 Mdot
.27188 .57892 Mdot
.38841 .77496 Mdot
.7508 .28719 Mdot
.51702 .27929 Mdot
.36683 .33886 Mdot
.23987 .38421 Mdot
.22016 .63161 Mdot
.77278 .5764 Mdot
.68097 .74056 Mdot
.48501 .54551 Mdot
.24085 .66096 Mdot
.50886 .64654 Mdot
.50576 .70842 Mdot
.61719 .71572 Mdot
.84008 .47088 Mdot
.48806 .3245 Mdot
.38789 .75561 Mdot
.79833 .4284 Mdot
.47446 .39053 Mdot
.36656 .71664 Mdot
.7192 .69791 Mdot
.45392 .1626 Mdot
.42201 .67125 Mdot
.80933 .67064 Mdot
.36628 .46442 Mdot
.3959 .7534 Mdot
.82048 .38173 Mdot
.55346 .14872 Mdot
.52247 .74483 Mdot
.85656 .51588 Mdot
.49631 .66453 Mdot
.74679 .67936 Mdot
.5627 .66438 Mdot
.51026 .49855 Mdot
.31853 .50986 Mdot
.72988 .73092 Mdot
.73524 .46881 Mdot
.7698 .62264 Mdot
.26676 .58418 Mdot
.75959 .71011 Mdot
.45854 .50051 Mdot
.15253 .54278 Mdot
.62999 .5603 Mdot
.25698 .70808 Mdot
.2495 .59594 Mdot
.34893 .36141 Mdot
.55722 .26532 Mdot
.15816 .50705 Mdot
.23294 .3394 Mdot
.26314 .56119 Mdot
.56834 .31939 Mdot
.3571 .74829 Mdot
.54148 .21754 Mdot
.64454 .79045 Mdot
.17986 .59266 Mdot
.78761 .48861 Mdot
.34983 .68369 Mdot
.48183 .80355 Mdot
.38835 .77962 Mdot
.60014 .74096 Mdot
.76476 .56939 Mdot
.4944 .73949 Mdot
.36204 .31362 Mdot
.14787 .35909 Mdot
.53327 .58199 Mdot
.5026 .32452 Mdot
.85617 .45335 Mdot
.63137 .79153 Mdot
.44287 .55702 Mdot
.19145 .53307 Mdot
.39034 .23905 Mdot
.61136 .29392 Mdot
.45731 .37481 Mdot
.76422 .70537 Mdot
.6414 .28957 Mdot
.84668 .56119 Mdot
.43419 .83197 Mdot
.24846 .3945 Mdot
.4988 .35006 Mdot
.69895 .51863 Mdot
.51947 .3262 Mdot
.56321 .32597 Mdot
.85021 .47662 Mdot
.35494 .27708 Mdot
.5715 .48067 Mdot
.65106 .69183 Mdot
.71338 .66961 Mdot
.39656 .31455 Mdot
.23921 .66994 Mdot
.37431 .75909 Mdot
.49696 .25891 Mdot
.57926 .78844 Mdot
.57111 .25838 Mdot
.26026 .35251 Mdot
.50327 .20891 Mdot
.43016 .61379 Mdot
.70473 .53399 Mdot
.62853 .47901 Mdot
.82642 .51548 Mdot
.69155 .71747 Mdot
.2924 .71961 Mdot
.67584 .24579 Mdot
.39333 .73045 Mdot
.53724 .31528 Mdot
.80126 .5309 Mdot
.43119 .64959 Mdot
.73048 .49631 Mdot
.42218 .2439 Mdot
.33975 .29277 Mdot
.65837 .74513 Mdot
.51266 .44372 Mdot
.66822 .79219 Mdot
.50874 .22868 Mdot
.81579 .48592 Mdot
.60067 .41497 Mdot
.30036 .47688 Mdot
.21598 .47812 Mdot
.71258 .29224 Mdot
.49462 .60313 Mdot
.8406 .35509 Mdot
.33856 .54178 Mdot
.85025 .57946 Mdot
.59549 .64309 Mdot
.35712 .20306 Mdot
.65156 .76505 Mdot
.49143 .55492 Mdot
.54123 .49513 Mdot
.34985 .75975 Mdot
.41187 .7549 Mdot
.47395 .8116 Mdot
.41233 .58537 Mdot
.64909 .55248 Mdot
.57926 .47886 Mdot
.52443 .71811 Mdot
.81342 .55773 Mdot
.39488 .42703 Mdot
.60992 .47995 Mdot
.55084 .3689 Mdot
.55572 .68182 Mdot
.49417 .83142 Mdot
.65168 .73377 Mdot
.426 .47521 Mdot
.58842 .2543 Mdot
.84363 .44744 Mdot
.60605 .82202 Mdot
.42216 .55734 Mdot
.35947 .35689 Mdot
.63007 .62144 Mdot
.78365 .34975 Mdot
.79398 .62115 Mdot
.69311 .68158 Mdot
.47258 .67874 Mdot
.53021 .22885 Mdot
.85168 .62844 Mdot
.85163 .4095 Mdot
.69001 .24808 Mdot
.54642 .50471 Mdot
.30065 .55449 Mdot
.34549 .25381 Mdot
.81521 .49065 Mdot
.26601 .72243 Mdot
.59109 .8041 Mdot
.56974 .26367 Mdot
.49651 .162 Mdot
.20789 .38934 Mdot
.60431 .45177 Mdot
.21679 .4796 Mdot
.3191 .48729 Mdot
.54865 .65843 Mdot
.60376 .3058 Mdot
.59165 .44982 Mdot
.61088 .66189 Mdot
.36058 .7506 Mdot
.41455 .72055 Mdot
.81661 .48143 Mdot
.31044 .29356 Mdot
.35512 .36531 Mdot
.80008 .579 Mdot
.34764 .63459 Mdot
.78635 .48004 Mdot
.78152 .38979 Mdot
.59384 .4545 Mdot
.66706 .53852 Mdot
.47312 .4637 Mdot
.48328 .63303 Mdot
.50052 .64705 Mdot
.58371 .19034 Mdot
.6617 .31981 Mdot
.33148 .53712 Mdot
.18359 .43273 Mdot
.38349 .55324 Mdot
.77075 .71977 Mdot
.53498 .7369 Mdot
.23302 .39805 Mdot
.52085 .61792 Mdot
.69293 .60944 Mdot
.57705 .17481 Mdot
.3447 .3164 Mdot
.69634 .31994 Mdot
.28695 .5842 Mdot
.30882 .59829 Mdot
.52395 .62721 Mdot
.42908 .72571 Mdot
.28455 .35129 Mdot
.20601 .61774 Mdot
.77589 .37801 Mdot
.37536 .5417 Mdot
.59914 .46432 Mdot
.36728 .49164 Mdot
.66974 .79878 Mdot
.65514 .54609 Mdot
.8482 .38024 Mdot
.46685 .33476 Mdot
.77546 .32892 Mdot
.49614 .83494 Mdot
.45498 .65854 Mdot
.55089 .50254 Mdot
.73194 .54505 Mdot
.41892 .45489 Mdot
.35804 .3505 Mdot
.31867 .58723 Mdot
.81064 .44743 Mdot
.65858 .35069 Mdot
.62116 .25228 Mdot
.62213 .6091 Mdot
.20818 .58512 Mdot
.24906 .67561 Mdot
.31094 .60713 Mdot
.63515 .41905 Mdot
.76529 .51621 Mdot
.54195 .43312 Mdot
.55223 .37181 Mdot
.8308 .50978 Mdot
.31294 .33059 Mdot
.34753 .54194 Mdot
.69003 .25059 Mdot
.57364 .36712 Mdot
.56823 .85498 Mdot
.41898 .49583 Mdot
.53565 .34966 Mdot
.54069 .41184 Mdot
.34206 .74563 Mdot
.26966 .34325 Mdot
.66999 .7566 Mdot
.57623 .2351 Mdot
.51198 .47976 Mdot
.56401 .28135 Mdot
.43896 .47518 Mdot
.64604 .70017 Mdot
.2441 .69197 Mdot
.5076 .16338 Mdot
.23059 .51181 Mdot
.43442 .68082 Mdot
.33144 .64061 Mdot
.22336 .63637 Mdot
.33801 .53864 Mdot
.66002 .41365 Mdot
.30983 .3624 Mdot
.65021 .76689 Mdot
.61778 .82815 Mdot
.59078 .8182 Mdot
.5079 .3125 Mdot
.70342 .67812 Mdot
.40998 .25731 Mdot
.3861 .50052 Mdot
.50156 .55508 Mdot
.42013 .45749 Mdot
.39748 .31674 Mdot
.43497 .5792 Mdot
.30721 .72512 Mdot
.4678 .321 Mdot
.72333 .73136 Mdot
.56592 .85357 Mdot
.78691 .67147 Mdot
.74767 .60362 Mdot
.35971 .62016 Mdot
.8585 .43695 Mdot
.24816 .34662 Mdot
.63327 .79939 Mdot
.24873 .5915 Mdot
.16004 .5802 Mdot
.82235 .39786 Mdot
.62909 .76125 Mdot
.31866 .66211 Mdot
.37285 .79971 Mdot
.50162 .82679 Mdot
.15372 .54573 Mdot
.39427 .28087 Mdot
.48584 .82887 Mdot
.83542 .34582 Mdot
.24354 .56913 Mdot
.40958 .74475 Mdot
.21066 .4769 Mdot
.3763 .28459 Mdot
.18696 .59376 Mdot
.38068 .37427 Mdot
.69189 .50828 Mdot
.71485 .36797 Mdot
.55972 .25962 Mdot
.48552 .45879 Mdot
.179 .57805 Mdot
.56154 .32927 Mdot
.52795 .30399 Mdot
.761 .48662 Mdot
.8218 .41016 Mdot
.2779 .34097 Mdot
.37906 .45156 Mdot
.29475 .5919 Mdot
.65529 .37449 Mdot
.46237 .25478 Mdot
.40174 .40663 Mdot
.51277 .57015 Mdot
.48438 .31611 Mdot
.81905 .65023 Mdot
.70331 .4072 Mdot
.59895 .54339 Mdot
.38459 .59297 Mdot
.37725 .76949 Mdot
.78454 .58409 Mdot
.3807 .70427 Mdot
.17138 .554 Mdot
.32693 .31254 Mdot
.7713 .66748 Mdot
.40429 .7197 Mdot
.51912 .24712 Mdot
.53516 .18586 Mdot
.59667 .6583 Mdot
.30987 .511 Mdot
.84698 .47998 Mdot
.37793 .72511 Mdot
.33656 .63642 Mdot
.5961 .76867 Mdot
.65688 .69571 Mdot
.37018 .73543 Mdot
.4853 .81491 Mdot
.78297 .51551 Mdot
.23192 .43418 Mdot
.8195 .58484 Mdot
.69619 .51806 Mdot
.53986 .26019 Mdot
.56698 .76782 Mdot
.18645 .59757 Mdot
.5398 .43533 Mdot
.68675 .77172 Mdot
.50483 .54856 Mdot
.67225 .28111 Mdot
.42699 .43963 Mdot
.29463 .30781 Mdot
.32 .73055 Mdot
.5806 .78247 Mdot
.36747 .65703 Mdot
.33614 .62929 Mdot
.27403 .6955 Mdot
.7017 .46174 Mdot
.62673 .29148 Mdot
.41804 .27023 Mdot
.27365 .64232 Mdot
.64977 .40045 Mdot
.4609 .72323 Mdot
.454 .32992 Mdot
.67533 .27149 Mdot
.73626 .64165 Mdot
.29694 .5268 Mdot
.25239 .56868 Mdot
.82707 .51932 Mdot
.75855 .5986 Mdot
.28722 .72221 Mdot
.25979 .58175 Mdot
.41752 .79827 Mdot
.22275 .3703 Mdot
.37655 .68352 Mdot
.44001 .33995 Mdot
.65973 .41354 Mdot
.36344 .54987 Mdot
.81624 .55901 Mdot
.39134 .52025 Mdot
.67956 .28699 Mdot
.47 .57464 Mdot
.77407 .55849 Mdot
.59011 .4145 Mdot
.49933 .83282 Mdot
.37291 .79995 Mdot
.57985 .24671 Mdot
.62296 .62972 Mdot
.49918 .67193 Mdot
.41952 .66646 Mdot
.6963 .75031 Mdot
.42472 .58888 Mdot
.3401 .4387 Mdot
.42152 .69056 Mdot
.31698 .4343 Mdot
.45622 .83264 Mdot
.60565 .26196 Mdot
.49959 .56083 Mdot
.33717 .395 Mdot
.47181 .73721 Mdot
.45437 .72933 Mdot
.72167 .40121 Mdot
.26623 .32941 Mdot
.56386 .57981 Mdot
.56695 .50176 Mdot
.42651 .3244 Mdot
.34002 .2559 Mdot
.81136 .58932 Mdot
.43857 .55154 Mdot
.49928 .54699 Mdot
.79588 .43094 Mdot
.64081 .28291 Mdot
.26274 .23837 Mdot
.84473 .61049 Mdot
.42487 .43894 Mdot
.54868 .48167 Mdot
.61897 .25677 Mdot
.63245 .4897 Mdot
.28962 .36712 Mdot
.82616 .5304 Mdot
.59269 .60936 Mdot
.76703 .45265 Mdot
.43539 .71536 Mdot
.33961 .75248 Mdot
.72573 .30111 Mdot
.5494 .65165 Mdot
.78101 .71181 Mdot
.58358 .80442 Mdot
.31994 .72308 Mdot
.20567 .28523 Mdot
.2974 .70801 Mdot
.43465 .50698 Mdot
.75278 .4995 Mdot
.80084 .667 Mdot
.54346 .51214 Mdot
.7605 .46568 Mdot
.25245 .56012 Mdot
.57829 .24213 Mdot
.53035 .28178 Mdot
.34847 .68477 Mdot
.28208 .69001 Mdot
.14753 .52715 Mdot
.69469 .60693 Mdot
.6082 .19171 Mdot
.26751 .36926 Mdot
.82665 .58791 Mdot
.52254 .74281 Mdot
.48486 .16266 Mdot
.6069 .83163 Mdot
.58064 .29859 Mdot
.18626 .57854 Mdot
.71794 .4525 Mdot
.62259 .23595 Mdot
.32479 .25738 Mdot
.50248 .76398 Mdot
.3188 .32876 Mdot
.67623 .61533 Mdot
.37656 .66366 Mdot
.56845 .27964 Mdot
.31945 .46168 Mdot
.50236 .55876 Mdot
.84541 .51749 Mdot
.16552 .51019 Mdot
.5468 .22611 Mdot
.78187 .44983 Mdot
.63727 .24456 Mdot
.79762 .59594 Mdot
.74205 .6538 Mdot
.55204 .42212 Mdot
.79129 .30558 Mdot
.85891 .50161 Mdot
.38712 .68504 Mdot
.40028 .35632 Mdot
.57835 .85578 Mdot
.56647 .42436 Mdot
.25788 .56243 Mdot
.52247 .81709 Mdot
.51193 .27858 Mdot
.46945 .31235 Mdot
.40747 .34491 Mdot
.39291 .2627 Mdot
.31646 .65822 Mdot
.32115 .46786 Mdot
.74662 .33498 Mdot
.55207 .22482 Mdot
.16849 .51436 Mdot
.72634 .28928 Mdot
.42786 .49603 Mdot
.34398 .5482 Mdot
.80864 .65979 Mdot
.33651 .35187 Mdot
.35126 .42636 Mdot
.21542 .44152 Mdot
.42126 .58085 Mdot
.70749 .54828 Mdot
.36197 .35374 Mdot
.47312 .65244 Mdot
.55526 .26379 Mdot
.81317 .5058 Mdot
.31849 .51302 Mdot
.83382 .32352 Mdot
.49728 .83867 Mdot
.3716 .53787 Mdot
.26836 .53802 Mdot
.60341 .4465 Mdot
.79307 .66057 Mdot
.68869 .59449 Mdot
.77844 .38549 Mdot
.17579 .434 Mdot
.58977 .22477 Mdot
.48605 .40132 Mdot
.50436 .79043 Mdot
.63743 .81115 Mdot
.1609 .46524 Mdot
.66871 .79122 Mdot
.49155 .3399 Mdot
.38626 .34474 Mdot
.48151 .12958 Mdot
.7541 .67873 Mdot
.51194 .39999 Mdot
.33086 .65932 Mdot
.33504 .65165 Mdot
.42004 .44422 Mdot
.42057 .73824 Mdot
.46797 .24043 Mdot
.53221 .2893 Mdot
.73372 .72629 Mdot
.38346 .58829 Mdot
.53666 .52977 Mdot
.56879 .59676 Mdot
.52943 .52233 Mdot
.39984 .47369 Mdot
.57522 .60582 Mdot
.53599 .29809 Mdot
.56532 .44085 Mdot
.6355 .5987 Mdot
.3728 .30193 Mdot
.48109 .71496 Mdot
.37761 .30701 Mdot
.53184 .33069 Mdot
.27346 .60489 Mdot
.23302 .33846 Mdot
.56133 .32717 Mdot
.57401 .34761 Mdot
.48568 .82473 Mdot
.26381 .74515 Mdot
.52733 .56385 Mdot
.32124 .52816 Mdot
.42764 .50245 Mdot
.26018 .3413 Mdot
.22353 .43728 Mdot
.62704 .57367 Mdot
.45046 .73197 Mdot
.46994 .32433 Mdot
.33553 .38781 Mdot
.55726 .61728 Mdot
.83495 .64688 Mdot
.38926 .35319 Mdot
.26374 .40206 Mdot
.67959 .76197 Mdot
.79027 .47635 Mdot
.43584 .28637 Mdot
.41575 .45596 Mdot
.45991 .51006 Mdot
.56837 .43485 Mdot
.35259 .47544 Mdot
.80108 .46424 Mdot
.79914 .62931 Mdot
.45832 .27994 Mdot
.25521 .40095 Mdot
.45168 .40788 Mdot
.6163 .33885 Mdot
.47487 .62816 Mdot
.58663 .19898 Mdot
.6848 .30807 Mdot
.6065 .8185 Mdot
.54062 .32994 Mdot
.51615 .27867 Mdot
.19904 .46561 Mdot
.84616 .57364 Mdot
.41602 .6766 Mdot
.24382 .39784 Mdot
.44389 .59565 Mdot
.60517 .74489 Mdot
.56693 .31782 Mdot
.53505 .61853 Mdot
.43246 .31343 Mdot
.31602 .65377 Mdot
.72553 .75085 Mdot
.34338 .3195 Mdot
.60888 .57734 Mdot
.66076 .74539 Mdot
.22365 .373 Mdot
.54031 .49534 Mdot
.16964 .32631 Mdot
.70246 .57821 Mdot
.78576 .70496 Mdot
.80028 .5069 Mdot
.52941 .43732 Mdot
.35511 .74464 Mdot
.4916 .44568 Mdot
.63984 .52285 Mdot
.79607 .64866 Mdot
.37084 .48729 Mdot
.36884 .68363 Mdot
.38335 .38861 Mdot
.45887 .52394 Mdot
.34774 .45251 Mdot
.68936 .69654 Mdot
.68751 .52184 Mdot
.42149 .56336 Mdot
.74034 .66259 Mdot
.56964 .43246 Mdot
.17401 .61248 Mdot
.85099 .47727 Mdot
.73212 .70445 Mdot
.7231 .65741 Mdot
.36267 .19496 Mdot
.28812 .5896 Mdot
.3777 .50005 Mdot
.61503 .65055 Mdot
.40317 .2592 Mdot
.3722 .73026 Mdot
.81138 .49583 Mdot
.40435 .79803 Mdot
.54427 .42918 Mdot
.11906 .40629 Mdot
.57333 .29523 Mdot
.43914 .5373 Mdot
.35355 .72004 Mdot
.71438 .73859 Mdot
.76836 .40427 Mdot
.4111 .81556 Mdot
.5335 .75207 Mdot
.43345 .47441 Mdot
.30773 .27738 Mdot
.69969 .2645 Mdot
.6812 .68235 Mdot
.59728 .18429 Mdot
.69887 .70178 Mdot
.48195 .24591 Mdot
.57503 .78075 Mdot
.38602 .5541 Mdot
.40051 .57873 Mdot
.53513 .73063 Mdot
.46176 .70614 Mdot
.28535 .55554 Mdot
.78745 .63981 Mdot
.47003 .19522 Mdot
.79263 .4057 Mdot
.76818 .68319 Mdot
.58785 .69765 Mdot
.33072 .64258 Mdot
.55733 .32918 Mdot
.68615 .34809 Mdot
.64551 .47616 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0VOooool2o`000:kooooo000Looooo`03o`00
0?oooooooooo09Wooooo0_l0002^ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0W_ooool2o`00
0:Wooooo000Looooo`03o`000?oooooooooo09kooooo0_l0002Yooooo`007?ooool00ol0003ooooo
ooooo`2`ooooo`;o0000Uoooool001cooooo0_l0001nooooo`;o00005_ooool2o`0001Wooooo0_l0
002Gooooo`007?ooool00ol0003oooooooooo`1mooooo`;o00001oooool2o`0000gooooo0ol0002a
ooooo`007?ooool00ol0003oooooooooo`26ooooo`;o00003Oooool3o`000;7ooooo000Looooo`03
o`000?oooooooooo093ooooo0_l00008ooooo`;o00000_ooool2o`0001Oooooo0_l0002@ooooo`00
7?ooool00ol0003oooooooooo`2@ooooo`;o00002?ooool2o`0000;ooooo1Ol0000Dooooo`;o0000
T?ooool001cooooo00?o0000ooooooooool0NOooool2o`0002Cooooo1?l00006ooooo`;o0000W_oo
ool001cooooo00?o0000ooooooooool0LOooool2o`0000Kooooo0_l0000^ooooo`Go00001Oooool2
o`0009Cooooo000Looooo`03o`000?oooooooooo077ooooo0_l0000gooooo`Co00001Oooool2o`00
00?ooooo0_l0002?ooooo`007?ooool00ol0003oooooooooo`1hooooo`;o0000?_ooool2o`0008oo
oooo000Looooo`03o`000?oooooooooo07Sooooo0_l00006ooooo`;o0000aoooool001cooooo00?o
0000ooooooooool0P?ooool2o`0003;ooooo0_l00008ooooo`;o0000ROooool001cooooo00?o0000
ooooooooool0Z_ooool2o`0000Sooooo0ol00007ooooo`;o0000ROooool001cooooo00?o0000oooo
ooooool0Woooool2o`0000Wooooo0_l00009ooooo`;o00000oooool2o`0008gooooo00001_oooooo
k^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`2G
ooooo`?o00001Oooool4o`0001Oooooo0_l00006ooooo`;o0000QOooool00006oooooomgMgOoV9RH
oooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`00
0?oooooooooo06_ooooo1?l00003ooooo`;o00008Oooool5o`0000Gooooo1?l0000Booooo`;o0000
2?ooool2o`000004ooooool0003o0000o`0008Cooooo00000ooooooo410@ooooo`02ooooo`03oa0@
4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`1Qooooo`;o0000
2?ooool4o`0000?ooooo1?l0000Oooooo`Co00001_ooool3o`0000Gooooo0ol0000;ooooo`;o0000
1?ooool2o`0000;ooooo0_l00002ooooo`;o0000Q?ooool00003ooooool0003ooooo00;ooooo00?o
0000ooooooooool02oooool00onHV9So8B4Qonk^kP06ooooo`?o0000HOooool2o`0000Gooooo0_l0
0006ooooo`;o00000_ooool2o`00027ooooo0_l0000>ooooo`?o00001oooool4o`0000Kooooo0_l0
002<ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKo
oooo00Gooooo00?o0000ooooooooool0J?ooool2o`0000Kooooo0_l0000eooooo`Ko00000oooool5
o`0001[ooooo0_l0001hooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0=oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0W?ooool2o`0000;ooooo0_l00002oooo
o`;o000000?oooooo`000?l000001?l00003ooooo`;o00004Oooool2o`0000[ooooo0_l0001hoooo
o`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_oo
ool00ol0003oooooooooo`2Kooooo`?o00000_ooool3o`000003ooooool0003o000000[ooooo0_l0
0002ooooo`;o00000_ooool4o`0000Oooooo0_l00003ooooo`;o0000Ooooool00006ooooooo^k^ko
<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000oooooooo
ool0Goooool4o`000003ooooool0003o000002cooooo0_l00007ooooo`;o000000?oooooo`000?l0
00000ol0000>ooooo`;o000000?oooooo`000?l000000_ooool4o`0000cooooo0_l0001oooooo`00
7?ooool00ol0003oooooooooo`1Oooooo`Co000000?oooooo`000?l00000;?ooool2o`0000Oooooo
0_l000001Ooooooo0000o`000?l0003ooooo00;o00002?ooool2o`0000?ooooo0_l00005ooooo`?o
000000?oooooo`000?l000002_ooool2o`0007oooooo000Looooo`03o`000?oooooooooo05[ooooo
0_l0000gooooo`;o00001oooool2o`000004ooooool0003o0000ooooo`;o00002?ooool2o`0000Wo
oooo1ol0000:ooooo`;o0000Ooooool001cooooo00?o0000ooooooooool0F_ooool2o`0003Oooooo
0_l000000ooooooo0000o`000004ooooo`;o00001?ooool2o`0000[ooooo0_l00007ooooo`?o0000
00?oooooo`000?l000001ol00025ooooo`007?ooool00ol0003oooooooooo`2Fooooo`;o00000_oo
ool8o`000003ooooool0003o000000Cooooo0_l00003ooooo`Co00001_ooool2o`000003ooooool0
003o000000Oo0000QOooool001cooooo00?o0000ooooooooool0Soooool2o`0000?ooooo1?l00002
ooooo`_o00000oooool3o`0000?ooooo1?l000000ooooooo0000o`000006ooooo`?o000000?ooooo
o`000?l000000oooool2o`0008?ooooo000Looooo`03o`000?oooooooooo05Sooooo0_l0000boooo
o`;o000000?oooooo`000?l000000oooool4o`0000Cooooo0_l00003ooooo`;o00001Oooool2o`00
00Wooooo0_l000000ooooooo0000o`000003ooooo`;o00001oooool2o`0000kooooo0_l0001coooo
o`007?ooool00ol0003oooooooooo`1Hooooo`Co00009oooool2o`000004ooooool0003o0000oooo
o`;o000000?oooooo`000?l000003_ooool2o`0001Sooooo0ol0000=ooooo`?o00002oooool2o`00
07?ooooo000Looooo`03o`000?oooooooooo05;ooooo1?l00004ooooo`;o00007?ooool5o`000003
ooooool0003o000000oo00003Oooool2o`0000Cooooo0_l0000Booooo`?o00003Oooool3o`0002?o
oooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`1Booooo`Co00008?ooool7o`000003oooo
ool0003o000000?o000000?oooooo`000?l000002Ol00004ooooo`?o00001_ooool2o`0000Cooooo
0_l0000Booooo`Go0000<Oooool2o`0005_ooooo000Looooo`03o`000?oooooooooo07Kooooo0_l0
000<ooooo`?o00002_ooool5o`0000;ooooo0ol000000ooooooo0000o`00000Gooooo`Ko00004?oo
ool2o`000003ooooool0003o000000Sooooo0_l0001_ooooo`007?ooool00ol0003oooooooooo`1D
ooooo`Co0000;Oooool2o`0000?ooooo0_l00005ooooo`Go00000_ooool3o`000003ooooool0003o
000000?ooooo0_l00002ooooo`;o00001Oooool2o`0000Oooooo1_l00002ooooo`;o00000_ooool2
o`0000Sooooo0_l000000ooooooo0000o`000008ooooo`;o00000_ooool2o`0006_ooooo000Loooo
o`;o0000EOooool4o`0001Cooooo0_l0000Gooooo`;o00000oooool2o`0000cooooo0_l00002oooo
o`;o00000oooool2o`0000;ooooo0_l00005ooooo`;o00001_ooool2o`0000?ooooo0_l00002oooo
o`;o00000_ooool2o`0000?ooooo0_l00007ooooo`;o00002Oooool4o`0006_ooooo000Looooo`03
o`000?oooooooooo05Wooooo0_l0000=ooooo`;o00000_ooool2o`0000;ooooo0_l0000Oooooo`?o
00000_ooool6o`0001Sooooo0ol00003ooooo`?o000000?oooooo`000?l000001_ooool2o`0000?o
oooo0_l00002ooooo`;o00002Oooool4o`0006_ooooo000Looooo`03o`000?oooooooooo05Wooooo
0_l0000;ooooo`So00000_ooool2o`0000oooooo0_l0000>ooooo`?o00000_ooool2o`0000;ooooo
0_l0000>ooooo`;o00001?ooool2o`0000?ooooo0ol00002ooooo`?o000000?oooooo`000?l00000
0oooool4o`0000Cooooo0ol00003ooooo`;o0000M_ooool001cooooo00?o0000ooooooooool0HOoo
ool3o`0000;ooooo1ol0000Booooo`Co00006oooool2o`0000[ooooo1?l00002ooooo`Co00000_oo
ool2o`0000Oooooo0_l000000ooooooo0000o`000003o`0000Gooooo0_l00003ooooo`;o0000M_oo
ool001cooooo00?o0000ooooooooool0HOooool3o`0000Wooooo0_l0000=ooooo`;o000000?ooooo
o`000?l000006oooool4o`0000cooooo0_l00003ooooo`Ko00001oooool6o`0000Wooooo0_l00006
ooooo`;o00002?ooool2o`0006Sooooo000Looooo`03o`000?oooooooooo06gooooo0_l0000:oooo
o`;o000000?oooooo`000?l000007?ooool4o`0001?ooooo1ol00006ooooo`;o000000?oooooo`00
0?l000002_ooool2o`0000Kooooo0_l00008ooooo`;o0000J?ooool001cooooo00?o0000oooooooo
ool0A?ooool2o`0000cooooo0_l0000Uooooo`;o000000?oooooo`000?l000001_ooool2o`0000Wo
oooo1?l00007ooooo`;o00000_ooool2o`0000Cooooo0_l0000;ooooo`;o00000oooool2o`0001Wo
oooo0_l00002ooooo`;o0000L_ooool001cooooo00?o0000ooooooooool0A?ooool2o`0000cooooo
0_l0000Hooooo`;o00001Oooool2o`0000oooooo0_l00009ooooo`Co00002oooool2o`0000Cooooo
0_l0000;ooooo`;o00005?ooool6o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l00000
Koooool001cooooo00?o0000ooooooooool0Goooool2o`0000_ooooo0_l00005ooooo`;o00002_oo
ool2o`0000Wooooo0_l0000Iooooo`;o000000?oooooo`000?l000001oooool2o`000003ooooool0
003o000000Gooooo0_l00003ooooo`;o00001Oooool8o`0000Gooooo0_l000001?oooooo0000o`00
0?l00006ooooo`;o00001?ooool2o`00067ooooo000Looooo`03o`000?oooooooooo05Wooooo0_l0
0004ooooo`?o00001oooool6o`000003ooooool0003o000000Wooooo0ol000001?oooooo0000o`00
0?ooool2o`0000Gooooo1Ol00003ooooo`;o00001?ooool2o`0000[ooooo1?l000000ooooooo0000
o`000009ooooo`Go00000oooool2o`0000;ooooo0ol000000ooooooo0000o`000002o`000003oooo
ool0003o000000?ooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l00007ooooo`;o
00001?ooool2o`00067ooooo000Looooo`03o`000?oooooooooo04;ooooo0_l00009ooooo`;o0000
2_ooool2o`0000Gooooo0_l00004ooooo`;o000000?oooooo`000?l000001?l000000ooooooo0000
o`000009ooooo`?o000000?oooooo`000?l000000ol00005ooooo`;o000000?oooooo`000?l00000
0oooool2o`0000Cooooo0_l0000:ooooo`?o00000oooool2o`0000Sooooo1Ol00002ooooo`;o0000
0oooool2o`0000;ooooo1?l000001Ooooooo0000o`000?l0003ooooo00?o00000_ooool2o`0000Co
oooo0_l0001`ooooo`007?ooool00ol0003oooooooooo`0oooooo`;o000000?oooooo`000?l00000
2Oooool2o`0001Oooooo0_l0000>ooooo`;o00001?ooool2o`0000?ooooo0ol0000Uooooo`Co0000
1_ooool2o`0000Gooooo0_l0000=ooooo`;o000000Coooooo`000?l0003o00002?ooool2o`00073o
oooo000Looooo`03o`000?oooooooooo03oooooo0_l0000Xooooo`;o00001Oooool2o`0000Cooooo
0_l0000>ooooo`;o00000_ooool2o`00017ooooo0_l0000:ooooo`Co00001Oooool4o`0000cooooo
0_l00008ooooo`;o00000oooool2o`0000Kooooo0ol0000<ooooo`;o00001_ooool2o`0005Oooooo
000Looooo`03o`000?oooooooooo05Sooooo0_l0000?ooooo`;o00001Oooool2o`0000Wooooo1_l0
0003ooooo`Co00000_ooool2o`0000Sooooo0_l00007ooooo`;o00002_ooool2o`0000Oooooo1?l0
0005ooooo`?o00001?ooool2o`0000Cooooo0_l00002ooooo`?o00000_ooool2o`0000Kooooo0ol0
0008ooooo`;o00000_ooool2o`0000Kooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`1F
ooooo`Co00001oooool2o`0000Cooooo1_l0000>ooooo`Ko00000oooool2o`0000Sooooo0_l00004
ooooo`;o00008?ooool2o`0000?ooooo0ol00004ooooo`?o00000oooool2o`0000?ooooo0_l00005
ooooo`;o00003_ooool3o`0000cooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`1Doooo
o`Co00002Oooool4o`000003ooooool0003o000000;o000000?oooooo`000?l000008Oooool2o`00
00Kooooo0_l00007ooooo`;o00002Oooool2o`0000Sooooo1?l000000ooooooo0000o`000008oooo
o`;o00003_ooool4o`000003ooooool0003o000000_ooooo0_l0000<ooooo`;o0000E?ooool001co
oooo0_l0001Dooooo`?o00001Oooool2o`0000Kooooo0_l000000ooooooo0000o`000002ooooo`;o
00001_ooool2o`0000Gooooo0_l00005ooooo`;o00003?ooool2o`0000Kooooo0_l00007ooooo`;o
00002Oooool2o`0000Sooooo0_l00003ooooo`;o00003oooool2o`0000?ooooo0_l00002ooooo`Oo
00003_ooool2o`0005oooooo000Looooo`03o`000?oooooooooo04Kooooo0_l0000;ooooo`;o0000
1_ooool2o`0000gooooo0_l00006ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Gooooo
0_l00007ooooo`;o00007Oooool2o`00023ooooo0_l00003ooooo`;o00001Oooool2o`00013ooooo
0_l0001Oooooo`007?ooool00ol0003oooooooooo`16ooooo`;o00001Oooool2o`0000gooooo1?l0
000Eooooo`Ko00001?ooool2o`0000Sooooo0_l0000Gooooo`;o00001?ooool2o`0001Kooooo0_l0
000;ooooo`?o00001_ooool2o`0000oooooo1?l0000Booooo`;o0000B_ooool001cooooo00?o0000
ooooooooool0AOooool2o`0000Kooooo0_l00004ooooo`;o00001_ooool6o`000003ooooool0003o
000000Sooooo0_l00009ooooo`;o000000?oooooo`000?l000000oooool2o`0001_ooooo0_l00004
ooooo`;o00007?ooool2o`0000_ooooo0ol00006ooooo`;o00000oooool2o`0000Gooooo0_l00003
ooooo`Co00004_ooool2o`0004[ooooo000Looooo`03o`000?oooooooooo04Gooooo0_l00004oooo
o`;o00001_ooool2o`0000Kooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool5o`00
0003ooooool0003o000000Cooooo0_l00006ooooo`;o00003Oooool2o`0000[ooooo0_l00005oooo
o`;o00000oooool2o`0000;ooooo0_l0000_ooooo`Co000000?oooooo`000?l000001Oooool2o`00
06Gooooo000Looooo`03o`000?oooooooooo04_ooooo0_l0000>ooooo`;o00001Oooool2o`0000;o
oooo1Ol000000ooooooo0000o`000004ooooo`;o00002Oooool2o`0000Gooooo0_l00003ooooo`;o
00000oooool2o`0000Gooooo0_l00003ooooo`Ko000000?oooooo`000?l000000_ooool2o`0000Co
oooo0_l0000Nooooo`;o00000_ooool3o`0000Kooooo0_l00003ooooo`;o00003?ooool2o`0000Oo
oooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o00007oooool2o`0000;ooooo
0_l0000;ooooo`;o000000?oooooo`000?l000001Ol000000ooooooo0000o`000004ooooo`;o0000
00?oooooo`000?l000001oooool6o`0000_ooooo0_l00006ooooo`Co00004?ooool2o`0000;ooooo
1ol000000ooooooo0000o`000008ooooo`?o00002_ooool3o`0000Oooooo0_l0001Cooooo`007?oo
ool00ol0003oooooooooo`1;ooooo`;o00007oooool2o`0000;ooooo0_l00002ooooo`;o00002_oo
ool4o`000003ooooool0003o000000?o00001oooool2o`000003ooooool0003o000000Oooooo0_l0
000Dooooo`Co00004?ooool2o`000004ooooool0003o0000ooooo`[o00000oooool2o`0000;ooooo
0_l0000:ooooo`;o00005_ooool2o`0004Gooooo000Looooo`03o`000?oooooooooo03?ooooo0_l0
000Dooooo`;o00003_ooool2o`0001Wooooo0_l00003ooooo`;o00001?ooool2o`0000Cooooo1_l0
0007ooooo`Go00001?ooool2o`0000;ooooo0_l00004ooooo`;o00003?ooool3o`0000Gooooo0_l0
000;ooooo`oo00000_ooool3o`0002Kooooo0_l00006ooooo`?o0000??ooool001cooooo00?o0000
ooooooooool0<oooool2o`0000[ooooo0_l00008ooooo`;o00002?ooool2o`000003ooooool0003o
000000?o00002Oooool2o`0001?ooooo0_l00004ooooo`;o00001?ooool6o`0000Oooooo1Ol00004
ooooo`Ko00000oooool3o`0000[ooooo1?l00004ooooo`Co00002OoooolEo`0000?ooooo0_l0000H
ooooo`;o00001?ooool2o`0000[ooooo0ol0000looooo`007?ooool00ol0003oooooooooo`0ooooo
o`;o00004_ooool2o`000003ooooool0003o000000;o00002?ooool4o`0001oooooo0_l00006oooo
o`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00000oooool3o`0000?ooooo0ol00003
ooooo`;o000000?oooooo`000?l000000oooool4o`0000Cooooo0_l0000;oooooaCo00001?ooool2
o`0001Sooooo1?l00002ooooo`;o00002_ooool2o`0003gooooo000Looooo`03o`000?oooooooooo
04cooooo1?l0000Booooo`;o00006oooool2o`0000Cooooo0_l000000ooooooo0000o`000003oooo
o`;o000000?oooooo`000?l000001?l000001?oooooo0000o`000?l00006ooooo`;o000000?ooooo
o`000?l000001?ooool2o`000003ooooool0003o000000gooooo0_l00008oooooaGo000000?ooooo
o`000?l000004_ooool2o`0000Wooooo0_l0000>ooooo`;o0000?Oooool001cooooo00?o0000oooo
ooooool0??ooool2o`0000[ooooo0_l00002ooooo`Co00002_ooool2o`0001Gooooo0_l0000<oooo
o`;o00001?ooool5o`0000;ooooo0ol00003ooooo`Co000000?oooooo`000?l000000_ooool2o`00
00?ooooo0_l0000Gooooo`Co00002?oooolDo`0000;ooooo0_l0000@ooooo`Co00002Oooool2o`00
0004ooooool0003o0000o`0004Wooooo000Looooo`03o`000?oooooooooo03cooooo0_l00006oooo
o`;o00000_ooool2o`0000Kooooo0ol00004ooooo`;o000000?oooooo`000?l000005Oooool5o`00
0003ooooool0003o000000Cooooo1?l000000ooooooo0000o`000005o`000003ooooool0003o0000
00[o00001Oooool3o`0000?ooooo0ol00002ooooo`;o00004Oooool2o`0000Wooooo5_l000001?oo
oooo0000o`000?ooool4o`0000_ooooo0_l0000>ooooo`?o00000oooool2o`0004Cooooo000Loooo
o`03o`000?oooooooooo033ooooo0_l0000Booooo`Ko00001_ooool3o`000004ooooool0003o0000
ooooo`;o00006_ooool3o`000004ooooool0003o0000ooooo`Ko00000_ooool7o`000003ooooool0
003o000000[o00000_ooool6o`0000?ooooo0ol000000ooooooo0000o`000002o`0000gooooo0_l0
000<oooooaKo000000Coooooo`000?l0003ooooo1?l0000Cooooo`;o00003?ooool2o`0004Cooooo
000Looooo`03o`000?oooooooooo033ooooo0_l0000Dooooo`;o00001Oooool2o`0000;ooooo1Ol0
0007ooooo`;o00002Oooool2o`00013ooooo0ol000001?oooooo0000o`000?ooool9o`000003oooo
ool0003o000000Oo00001?ooool5o`000003ooooool0003o000000Gooooo1?l0000=ooooo`?o0000
3OoooolDo`000003ooooool0003o000001Sooooo0_l0000Eooooo`;o0000>oooool001cooooo0_l0
001>ooooo`;o00000_ooool3o`0000?ooooo0_l00004ooooo`;o00002Oooool4o`0000Gooooo1?l0
00000ooooooo0000o`000002ooooo`Co000000?oooooo`000?l000002_l00002ooooo`Oo00001?oo
ool2o`0000Cooooo1?l00008ooooo`;o00002oooool2o`0000cooooo6?l000000ooooooo0000o`00
000Kooooo`Co00001oooool2o`0000Cooooo0ol0000jooooo`007?ooool00ol0003oooooooooo`0Y
ooooo`;o00009_ooool2o`0000?ooooo1Ol0000>ooooo`?o00001Oooool4o`000005ooooool0003o
0000o`000?ooool04Ol00002ooooo`?o000000?oooooo`000?l000000ol000000ooooooo0000o`00
0005ooooo`Go00001_ooool5o`0001Oooooo6?l000000ooooooo0000o`00000Hooooo`;o000000?o
ooooo`000?l000000_l00007ooooo`;o00001Oooool2o`0003[ooooo000Looooo`03o`000?oooooo
oooo02Wooooo0_l0000=ooooo`;o00005_ooool3o`0000;ooooo0ol000000ooooooo0000o`00000?
ooooo`;o00001Oooool3o`0000?ooooo0_l000000ooooooo0000o`00000?o`0000;ooooo2Ol00000
0ooooooo0000o`000002ooooo`;o00001?ooool2o`0000Cooooo1?l000000ooooooo0000o`000008
ooooo`Co00003?oooolCo`0000Cooooo0_l0000:ooooo`;o00003Oooool2o`0001?ooooo0_l0000j
ooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00002?ooool4o`0001Kooooo0_l00003oooo
o`;o00002Oooool2o`0000oooooo0_l00004ooooo`;o000000Goooooo`000?l0003o0000ooooo`02
o`000003ooooool0003o000001Co000000Coooooo`000?l0003ooooo0ol00009ooooo`;o00003Ooo
ool4o`0000cooooo5?l00003ooooo`;o00002?ooool4o`0001;ooooo0_l0000>ooooo`;o0000>_oo
ool001cooooo00?o0000ooooooooool0;?ooool2o`0000Sooooo0_l00009ooooo`;o00001Oooool2
o`0001Cooooo1Ol0000;ooooo`;o00001oooool8o`000003ooooool0003o0000013o000000?ooooo
o`000?l000000_l000000ooooooo0000o`000002ooooo`;o00003?ooool2o`0000Kooooo0_l00002
ooooo`;o00003Oooool<o`000003ooooool0003o000000Ko00003?ooool3o`0001Cooooo0_l0001:
ooooo`007?ooool00ol0003oooooooooo`11ooooo`;o00001Oooool2o`0000?ooooo0_l00003oooo
o`;o00002_ooool2o`000003ooooool0003o000000_ooooo1?l00006oooooa[o000000?oooooo`00
0?l000001Ol00002ooooo`Co00002_ooool2o`0000Kooooo0_l00002ooooo`?o00003?ooool8o`00
0003ooooool0003o000000[o00003?ooool3o`0000oooooo0_l0000;ooooo`;o0000@_ooool001co
oooo00?o0000ooooooooool0B?ooool2o`0000;ooooo0ol00003ooooo`?o00001Oooool2o`0001Co
oooo0_l00005ooooobGo00000_ooool2o`0000Cooooo0_l00004ooooo`;o00000oooool2o`0000Ko
oooo0_l0000:ooooo`;o000000?oooooo`000?l000003Ol000000ooooooo0000o`000009ooooo`;o
000000Coooooo`000?l0003ooooo0_l0000?ooooo`;o00002oooool2o`0000Oooooo0_l0000ioooo
o`007?ooool00ol0003oooooooooo`15ooooo`;o00001Oooool2o`0000Gooooo0_l000000ooooooo
0000o`000002ooooo`;o00006_oooolSo`000003ooooool0003o000000Gooooo0_l000000ooooooo
0000o`000009ooooo`?o00001?ooool3o`0000[ooooo2?l000000ooooooo0000o`00000<o`000003
ooooool0003o000000?ooooo0ol000001?oooooo0000o`000?ooool2o`0001_ooooo0_l00008oooo
o`;o0000>Oooool001cooooo00?o0000ooooooooool0AOooool2o`0000Gooooo0_l00008ooooo`;o
000000?oooooo`000?l000006ooooolTo`0000Oooooo0_l0000=ooooo`?o000000?oooooo`000?l0
00000_l0000<ooooo`Oo000000?oooooo`000?l000002Ol000001?oooooo0000o`000?ooool2o`00
00?ooooo0_l00008ooooo`;o00003?ooool3o`0000Wooooo0_l00013ooooo`007?ooool00ol0003o
ooooooooo`15ooooo`;o00000_ooool2o`000003ooooool0003o000000_ooooo0_l0000@ooooo`;o
00002?oooolUo`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000;ooooo0_l000000ooooooo
0000o`00000@ooooo`Go000000?oooooo`000?l000001_l0000Fooooo`;o00003?ooool3o`0000;o
oooo0_l00008ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0A?ooool2o`0000?ooooo
0_l0000Pooooo`;o00000_ooool4o`0000;ooooo9Ol00005ooooo`;o00001Oooool3o`0000Cooooo
0_l000000ooooooo0000o`00000Fooooo`oo00008Oooool2o`0000?ooooo0_l00008ooooo`;o0000
1oooool2o`0003Oooooo000Looooo`03o`000?oooooooooo03kooooo0_l00004ooooo`;o00000ooo
ool5o`0001Kooooo0_l00009ooooo`Co00001Oooool2o`000003ooooool0003o000001oo00002ooo
ool2o`0000Oooooo0_l00002ooooo`;o00004_ooool9o`000003ooooool0003o000000?o00004Ooo
ool2o`0000oooooo0_l0000<ooooo`;o00001oooool2o`0003Oooooo000Looooo`03o`000?oooooo
oooo03kooooo0_l00007ooooo`Oo00005_ooool2o`0000?ooooo0_l00005ooooo`;o00000_ooool2
o`0000;ooooo9Ol00005ooooo`;o000000?oooooo`000?l000003Oooool4o`0000gooooo0_l00004
ooooo`;o000000?oooooo`000?l000003_ooool2o`0000Sooooo0_l0000?ooooo`;o00002_ooool2
o`0004;ooooo000Looooo`03o`000?oooooooooo03cooooo0_l00002ooooo`;o00001Oooool3o`00
01oooooo1?l00003ooooo`;o00000_ooool`o`000004ooooool0003o0000o`0000kooooo0_l0000=
ooooo`;o00001?ooool2o`0000?ooooo0_l0000<ooooo`;o00000_ooool2o`0001Gooooo0ol00009
ooooo`;o0000@_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l0
00000ol@413oooooooooo`04ooooo`03o`000?oooooooooo03cooooo0_l00002ooooo`;o00002?oo
ool2o`0000Gooooo0_l0000Hooooo`;o000000?oooooo`000?l000000_l00002ooooo`Co000000?o
ooooo`000?l000006Ol000000ooooooo0000o`000002o`000003ooooool0003o000000Ko00001?oo
ool2o`00027ooooo2Ol0000@ooooo`;o00001?ooool4o`0000?ooooo0_l00009ooooo`Co0000Booo
ool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Uooooo`;o00005oooool2o`0000[ooooo0_l000000ooooooo0000
o`000002ooooo`;o00005oooool2o`0000;ooooo0_l00004ooooo`Co000000?oooooo`000?l00000
8ol000001?oooooo0000o`000?l0000Dooooo`;o00004Oooool2o`000003ooooool0003o000000?o
00005oooool4o`0000?ooooo0_l0000;ooooo`;o0000Boooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool02Oooool5o`0000Kooooo00?o0000ooooooooool09Oooool3o`0001Kooooo
1?l00006ooooo`;o000000?oooooo`000?l000000_l0000Kooooo`;o00001_ooool2o`0000;ooooo
7Ol000000ooooooo0000o`00000;o`0000;ooooo0ol00008ooooo`;o00001_ooool2o`00013ooooo
0_l0000Wooooo`;o00000oooool2o`0000Cooooo0_l00009ooooo`;o0000@?ooool00003ooooool0
003ooooo00;ooooo00?o0000ooooooooool02Oooool01?m4A4CogMgMooooool00007ooooo`?o0000
9_ooool2o`0001Sooooo0_l00005ooooo`?o000000?oooooo`000?l000000_ooool2o`000003oooo
ool0003o000000oooooo0_l0000;ooooo`Co00000_oooolCo`000003ooooool0003o0000013o0000
0_ooool4o`000003ooooool0003o000000;o00001oooool2o`0000Gooooo0_l0000Aooooo`;o0000
1Oooool2o`0001Kooooo0_l00008ooooo`;o00000oooool2o`000003ooooool0003o000000Cooooo
1?l000000ooooooo0000o`000003o`00043ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oo
oooooooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`0Sooooo`;o0000
7_ooool2o`0000;ooooo0_l00005ooooo`?o000000?oooooo`000?l000003oooool2o`0000_ooooo
1?l00002ooooo`Oo000000?oooooo`000?l000007?l00004ooooo`;o000000?oooooo`000?l00000
0_l00004ooooo`;o00002?ooool2o`0000gooooo0_l00009ooooo`;o00005_ooool2o`0000Gooooo
0_l00006ooooo`;o000000?oooooo`000?l000000oooool5o`000004ooooool0003o0000o`0004;o
oooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oMgMgolc<c?l00000
1oooool00ol0003oooooooooo`0Sooooo`;o00007_ooool2o`0000Wooooo0_l0000Cooooo`;o0000
4OoooolWo`0000?ooooo1Ol00005ooooo`?o00005?ooool2o`000003ooooool0003o000000Oooooo
0_l0000<ooooo`;o00001?ooool2o`0000_ooooo0_l00006ooooo`;o000000Coooooo`000?l0003o
00000_ooool2o`0000Kooooo0_l00009ooooo`;o0000=_ooool00006oooooomgMgOoV9RHoooooonH
V9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo04;ooooo0_l0000`oooo
obWo000000?oooooo`000?l000001Ol00005ooooo`Co00004oooool2o`0000Cooooo0_l00004oooo
o`Co000000?oooooo`000?l000000_l00005ooooo`;o00001?ooool2o`0000gooooo0_l000000ooo
oooo0000o`000004ooooo`?o00001Oooool2o`0000?ooooo0ol00007ooooo`?o0000=_ooool00006
ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooo
oooo03_ooooo0_l00005ooooo`;o0000;?ooool2o`000003ooooool0003o000000?o000000Gooooo
o`000?l0003o0000ooooo`0Oo`0000;ooooo0ol000000ooooooo0000o`000002o`0000Kooooo0_l0
0002ooooo`;o00001_ooool2o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`Go00001Ooo
ool2o`000003ooooool0003o000000;o00006_ooool2o`000003ooooool0003o000000cooooo0_l0
0004ooooo`;o00001Oooool5o`0003Kooooo000Looooo`03o`000?oooooooooo03_ooooo0_l00000
0ooooooo0000o`000003ooooo`;o0000:oooool2o`000003ooooool0003o000000;o00000ooooolO
o`0000?ooooo1Ol00003ooooo`;o00000_ooool2o`0000Kooooo0_l00006ooooo`;o00000_ooool2
o`000003ooooool0003o000000Cooooo1Ol00005ooooo`;o00000_ooool2o`0001_ooooo0_l0000E
ooooo`;o00001Oooool2o`0000?ooooo0_l0000dooooo`007?ooool00ol0003oooooooooo`0joooo
o`;o00000_ooool4o`000003ooooool0003o000000Kooooo0_l0000Sooooo`Oo00001?oooolNo`00
00;ooooo2?l000000ooooooo0000o`000002ooooo`Co00002?ooool2o`0000oooooo1?l00002oooo
o`;o00002_ooool2o`0002Sooooo0_l0000@ooooo`;o0000=?ooool001cooooo00?o0000oooooooo
ool0>_ooool2o`0000Cooooo0_l000000ooooooo0000o`000006ooooo`;o00006_ooool2o`0000;o
oooo0_l00005ooooo`;o000000Coooooo`000?l0003ooooo0ol00002ooooo`Go000000?oooooo`00
0?l000000_l000000ooooooo0000o`00000?o`0000;ooooo0_l000001?oooooo0000o`000?ooool2
o`000004ooooool0003o0000ooooo`Go00001?ooool2o`0000;ooooo0_l0000<ooooo`;o000000?o
ooooo`000?l000000oooool3o`0000[ooooo0_l0000Oooooo`;o00001oooool2o`000003ooooool0
003o000004?ooooo000Looooo`03o`000?oooooooooo03cooooo0ol00002ooooo`Co00008_ooool2
o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`Wo00000_oooolLo`0000;ooooo0_l00000
0ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000000_l00004ooooo`?o00000_ooool2
o`000003ooooool0003o000000Oooooo1?l00002ooooo`;o00000_ooool2o`0000_ooooo0_l00009
ooooo`;o00005?ooool3o`0000Kooooo0_l000000ooooooo0000o`000013ooooo`007?ooool00ol0
003oooooooooo`0looooo`?o00000_ooool2o`0002_ooooo0ol000000ooooooo0000o`00000;o`00
00;ooooo1ol000000ooooooo0000o`00000<o`0000;ooooo1?l000000ooooooo0000o`000004o`00
00;ooooo1?l00003ooooo`Co00001_ooool2o`0000Oooooo1?l00002ooooo`;o000000?oooooo`00
0?l000000_ooool2o`0000[ooooo1?l00005ooooo`;o00005?ooool3o`0000Cooooo1_l00014oooo
o`007?ooool00ol0003oooooooooo`0eooooo`;o000000?oooooo`000?l000001oooool2o`0002[o
oooo1?l00002oooooaGo000000?oooooo`000?l000002ol000000ooooooo0000o`00000;o`0000;o
oooo1?l00002ooooo`?o00001_ooool2o`0000Oooooo0_l00002ooooo`;o00001Oooool2o`0000;o
oooo0ol00009ooooo`Co00001oooool2o`0001;ooooo0ol00004ooooo`?o000000?oooooo`000?l0
0000A?ooool001cooooo00?o0000ooooooooool0=Oooool2o`000003ooooool0003o000000Gooooo
1?l00005ooooo`;o00006Oooool2o`0000Sooooo0_l00004ooooo`So000000?oooooo`000?l00000
5Ol000000ooooooo0000o`000003o`000003ooooool0003o000000?o00003Oooool2o`0000Oooooo
0_l00007ooooo`;o00002Oooool2o`0000?ooooo0_l0000:ooooo`;o00002?ooool2o`0001?ooooo
0_l00008ooooo`;o00003_ooool2o`0003Cooooo000Looooo`03o`000?oooooooooo03Sooooo0_l0
0005ooooo`Co00000_ooool2o`000003ooooool0003o000001Wooooo0ol000000ooooooo0000o`00
0002ooooo`;o00000oooool2o`0000;ooooo1ol000000ooooooo0000o`00000Ko`000003ooooool0
003o000000cooooo0_l000001?oooooo0000o`000?l00007ooooo`;o00001?ooool2o`0003[ooooo
1?l00008ooooo`?o00003Oooool2o`0003Cooooo000Looooo`03o`000?oooooooooo03Gooooo0_l0
00000ooooooo0000o`000002ooooo`;o00000oooool3o`000003ooooool0003o000000Sooooo0_l0
000Aooooo`Co000000?oooooo`000?l000000_ooool4o`000004ooooool0003o0000ooooo`;o0000
0_ooool4o`000003ooooool0003o000001Wo00000_ooool4o`0000Cooooo0_l00005ooooo`;o0000
00?oooooo`000?l000001oooool2o`0000Gooooo0_l0000;ooooo`;o0000;Oooool2o`0000_ooooo
0_l00013ooooo`007?ooool00ol0003oooooooooo`0dooooo`?o00001Oooool2o`000004ooooool0
003o0000ooooo`;o00002oooool2o`00017ooooo0_l00009ooooo`;o00001?ooool2o`0000Cooooo
1?l000000ooooooo0000o`00000Go`0000;ooooo1Ol00003ooooo`Co00003oooool2o`0001;ooooo
0_l0000[ooooo`Ko00002?ooool4o`0004;ooooo000Looooo`03o`000?oooooooooo01gooooo0_l0
000Eooooo`;o000000?oooooo`000?l000001_ooool2o`0003[ooooo0_l00003ooooo`_o000000?o
ooooo`000?l000001?l000000ooooooo0000o`000004ooooo`Ko00001?ooool2o`0000Cooooo0_l0
000Eooooo`;o00001?ooool2o`0000Sooooo0_l0000Dooooo`;o00003Oooool6o`0000Sooooo1?l0
0007ooooo`;o00001?ooool2o`0003?ooooo000Looooo`;o00007_ooool2o`0001Sooooo0_l0000F
ooooo`;o00005_ooool2o`0000Cooooo0_l00003ooooo`;o00000oooool2o`0000Cooooo0_l00000
1?oooooo0000o`000?l00002ooooo`Ko000000?oooooo`000?l000001?l00007ooooo`;o00000_oo
ool2o`0000Oooooo0_l000000ooooooo0000o`00000;ooooo`;o00001?ooool3o`000004ooooool0
003o0000o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`Go00003?ooool2o`0000?ooooo
1Ol0000Booooo`;o00001oooool2o`0000;ooooo0_l00003ooooo`Co00001?ooool2o`0003?ooooo
000Looooo`03o`000?oooooooooo04kooooo0ol0000Fooooo`;o00001?ooool2o`0000?ooooo0_l0
0003ooooo`?o00000oooool5o`0000;ooooo1Ol00003ooooo`Go00000_ooool7o`0000cooooo0_l0
000>ooooo`;o000000Coooooo`000?l0003ooooo0ol00002ooooo`?o00000oooool4o`0000;ooooo
0ol0000>ooooo`;o00000oooool4o`0000kooooo0_l00003ooooo`;o00001oooool2o`0000;ooooo
0_l00003ooooo`;o00001?ooool4o`0003?ooooo000Looooo`03o`000?oooooooooo04Wooooo0_l0
0003ooooo`;o00005_ooool2o`00013ooooo0_l00003ooooo`Co00000_ooool8o`000003ooooool0
003o000000?o000000?oooooo`000?l000002?l0000Dooooo`;o00001oooool2o`000003ooooool0
003o000000?o000000?oooooo`000?l000000oooool4o`000004ooooool0003o0000ooooo`Go0000
4_ooool2o`0000gooooo0_l00008ooooo`;o00000_ooool2o`0000gooooo1?l0000cooooo`007?oo
ool00ol0003oooooooooo`0booooo`;o00005Oooool2o`0001Wooooo1?l0000@ooooo`;o000000?o
ooooo`000?l000001_ooool8o`000004ooooool0003o0000o`0000?ooooo0_l00002ooooo`Ko0000
5?ooool3o`0000Gooooo0_l00002ooooo`Go000000?oooooo`000?l000001Oooool2o`000004oooo
ool0003o0000ooooo`Go00000oooool4o`0000Gooooo0_l00004ooooo`;o00005oooool2o`0000Go
oooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0booooo`;o000000?oooooo`000?l00000
0_l00006ooooo`;o00008oooool2o`000003ooooool0003o000000Wooooo1_l00003ooooo`;o0000
0_ooool3o`0000;ooooo1_l000000ooooooo0000o`000003o`0000;ooooo0_l00002ooooo`;o0000
4Oooool4o`000004ooooool0003o0000ooooo`;o00001Oooool2o`0000?ooooo1?l00005ooooo`Co
00001oooool2o`000004ooooool0003o0000ooooo`Co00001Oooool2o`0001kooooo0_l00004oooo
o`;o00001Oooool2o`0003[ooooo000Looooo`03o`000?oooooooooo037ooooo0_l00002ooooo`Ko
00000_ooool4o`0002Cooooo1?l00009ooooo`Ko00000_ooool2o`0000;ooooo1?l000001Ooooooo
0000o`000?l0003ooooo00Wo00000_ooool8o`0000oooooo1?l000000ooooooo0000o`000008oooo
o`;o00000oooool4o`0000;ooooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l000001?oo
oooo0000o`000?ooool5o`0001[ooooo0_l0000;ooooo`;o00002oooool2o`0003[ooooo000Loooo
o`03o`000?oooooooooo037ooooo0_l00006ooooo`;o00000_ooool2o`0002Kooooo1?l00007oooo
o`;o00000oooool4o`000003ooooool0003o000000;ooooo0_l00003ooooo`?o00000_ooool7o`00
00Cooooo0ol00002ooooo`;o00004oooool2o`0000Sooooo0ol00003ooooo`;o00001?ooool4o`00
0003ooooool0003o000000;ooooo3ol0000;ooooo`;o00000oooool2o`0000Kooooo0_l0000Hoooo
o`;o0000>_ooool001cooooo00?o0000ooooooooool0=?ooool2o`0000Oooooo0ol0000Wooooo`;o
00001oooool2o`0000?ooooo1?l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l0
00000oooool5o`000004ooooool0003o0000o`0000Cooooo0_l0000Hooooo`;o00002?ooool2o`00
00Cooooo0_l00006ooooo`;o000000?oooooo`000?l000004Ol0000;ooooo`;o00000oooool2o`00
00Sooooo0_l00008ooooo`;o00001Oooool2o`0000Gooooo0_l0000jooooo`007?ooool00ol0003o
ooooooooo`0dooooo`;o00002?ooool2o`000003ooooool0003o000000[ooooo0_l0000?ooooo`;o
00001oooool2o`0000Kooooo0_l0000=ooooo`;o000000?oooooo`000?l000000oooool9o`00013o
oooo1?l0000Booooo`?o00001Oooool2o`0000Oooooo0_l000000ooooooo0000o`000009o`000003
ooooool0003o000000Ko00001?ooool3o`000003ooooool0003o000000kooooo0_l00006ooooo`Co
00001Oooool2o`0000Sooooo0ol0000fooooo`007?ooool00ol0003oooooooooo`11ooooo`Co0000
2?ooool2o`0000oooooo0ol00005ooooo`;o00001oooool2o`00013ooooo0_l00004ooooo`So0000
4?ooool6o`0000Gooooo0_l00009ooooo`Go00000_ooool3o`0000?ooooo6ol00004ooooo`?o0000
00?oooooo`000?l000005Oooool5o`0000kooooo1?l0000fooooo`007?ooool00ol0003ooooooooo
o`0eooooo`;o00002oooool3o`0001[ooooo0_l00005ooooo`;o00007oooool3o`0001Wooooo0_l0
0005ooooo`;o00000_ooool2o`0000Kooooo1?l00002ooooo`;o00001?ooool5o`000003ooooool0
003o000001Co00005oooool2o`0000Gooooo0_l000000ooooooo0000o`000004ooooo`;o00002?oo
ool2o`0000?ooooo0_l0000cooooo`007?ooool00ol0003oooooooooo`0eooooo`;o000000?ooooo
o`000?l00000<Oooool2o`0000Wooooo0_l00003ooooo`;o00009Oooool2o`0000[ooooo0_l00003
ooooo`;o000000?oooooo`000?l000002oooool4o`000003ooooool0003o000000Wo000000?ooooo
o`000?l000002?l0000Gooooo`;o00001?ooool2o`0000Cooooo0_l00002ooooo`;o00003Oooool2
o`0003?ooooo000Looooo`03o`000?oooooooooo03Gooooo0_l000001?oooooo0000o`000?ooool2
o`000003ooooool0003o000000Oooooo0_l0000Jooooo`Co00001?ooool2o`0000Sooooo0ol00003
ooooo`;o00008_ooool2o`000003ooooool0003o000000Sooooo0_l00002ooooo`;o000000?ooooo
o`000?l000004?oooolJo`0000;ooooo0_l0000@ooooo`;o00001_ooool3o`0000?ooooo0_l00002
ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0=Oooool2o`0000Cooooo0_l000000ooo
oooo0000o`000005ooooo`Co00006_ooool4o`0000?ooooo0_l00008ooooo`?o000000?oooooo`00
0?l000002?ooool2o`0000Gooooo0ol00002ooooo`;o00003oooool2o`0000?ooooo0_l00006oooo
o`;o00000_ooool4o`0000;ooooo0_l0000>ooooo`?o000000?oooooo`000?l000004ol00002oooo
o`;o00004?ooool2o`0000Oooooo0_l00007ooooo`;o0000@_ooool001cooooo00?o0000oooooooo
ool0<_ooool3o`00013ooooo1?l00002ooooo`;o00005Oooool2o`0000Kooooo0_l00008ooooo`;o
00000_ooool2o`0000Sooooo0_l00005ooooo`?o00000_ooool2o`0000;ooooo0_l00009ooooo`Co
00000_ooool3o`0000Kooooo0_l00003ooooo`?o00000_ooool2o`0000;ooooo0_l000000ooooooo
0000o`000002ooooo`;o00000ooooolJo`0000Gooooo0_l0000>ooooo`;o00000oooool4o`0000Oo
oooo0_l00012ooooo`007?ooool00ol0003oooooooooo`0booooo`?o00004_ooool2o`0000;ooooo
0_l0000Eooooo`;o00004?ooool2o`0000_ooooo0_l000001?oooooo0000o`000?ooool2o`0000Wo
oooo0_l000000ooooooo0000o`000006ooooo`;o00000oooool3o`0000Oooooo0_l00004ooooo`;o
00001_ooool2o`000004ooooool0003o0000ooooo`Co000000?oooooo`000?l000006Ol00005oooo
o`;o00000_ooool2o`0000[ooooo0_l00002ooooo`?o00002?ooool2o`0004?ooooo000Looooo`;o
00007?ooool2o`0001Oooooo0_l0000;ooooo`;o000000?oooooo`000?l000006?ooool2o`0000Wo
oooo0_l0000<ooooo`;o000000?oooooo`000?l000001Oooool2o`000004ooooool0003o0000oooo
o`;o00002?ooool2o`0000;ooooo0_l00003ooooo`;o00001_ooool2o`0000[ooooo0ol000000ooo
oooo0000o`000002o`0000Gooooo0_l00003ooooo`Co000000?oooooo`000?l000006?l0000:oooo
o`;o00001_ooool2o`0000Kooooo0_l00003ooooo`;o00001?ooool2o`0000gooooo0_l0000doooo
o`007?ooool00ol0003oooooooooo`0Kooooo`;o00005oooool2o`0000_ooooo0_l000000ooooooo
0000o`000004ooooo`;o00004_ooool2o`0000Wooooo0_l0000<ooooo`;o000000Coooooo`000?l0
003o00002Oooool3o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000Oooooo0_l0000>
ooooo`;o00000_ooool3o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000002Oooool>
o`0000;ooooo2ol0000@ooooo`;o00002oooool2o`0001?ooooo0_l0000dooooo`007?ooool00ol0
003oooooooooo`0`ooooo`;o00002Oooool2o`0000;ooooo0_l00009ooooo`;o00003?ooool2o`00
00Cooooo0_l0000Kooooo`;o00002Oooool6o`000003ooooool0003o000000Oooooo1?l0000@oooo
o`So00001_ooool2o`0000gooooo2_l000000ooooooo0000o`000008o`000003ooooool0003o0000
00;o00007oooool2o`0000;ooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`0`ooooo`Co
00001oooool3o`000003ooooool0003o000001Oooooo0_l00005ooooo`Co000000?oooooo`000?l0
00000oooool2o`0000?ooooo0ol0000;ooooo`;o00001Oooool2o`0000;ooooo1Ol000000ooooooo
0000o`000003ooooo`;o00000_ooool4o`0000kooooo0_l000001?oooooo0000o`000?l00002oooo
o`;o00004_ooool2o`000003ooooool0003o000001So00005_ooool4o`0000Gooooo0ol000000ooo
oooo0000o`000004ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0<_ooool2o`0000Co
oooo0_l00002ooooo`?o00002?ooool2o`0001Kooooo1?l000000ooooooo0000o`000003ooooo`;o
00000_ooool4o`0000_ooooo0ol00003ooooo`?o00003Oooool2o`0000?ooooo0_l0000?ooooo`Oo
00004Oooool2o`0000;ooooo7Ol0000Fooooo`Co00001_ooool2o`0000Oooooo0_l0000mooooo`00
7?ooool00ol0003oooooooooo`0Jooooo`;o00005oooool2o`0000?ooooo0_l00003ooooo`;o0000
00?oooooo`000?l000001?ooool3o`0001Oooooo0_l00002ooooo`;o00001oooool2o`0000kooooo
0_l000000ooooooo0000o`000002o`0000kooooo0_l0000Cooooo`Go000000?oooooo`000?l00000
4Oooool2o`000003ooooool0003o000001[o00005_ooool2o`000004ooooool0003o0000ooooo`;o
00003?ooool3o`0000Kooooo0_l0000eooooo`007?ooool00ol0003oooooooooo`0Jooooo`;o0000
5oooool2o`0000Sooooo0_l000000ooooooo0000o`000004ooooo`;o0000<oooool2o`0000;ooooo
1?l0000?ooooo`;o00004_ooool3o`000004ooooool0003o0000ooooo`;o00000_ooool2o`00013o
oooo7_l0000Dooooo`Go000000?oooooo`000?l000003?ooool2o`0000Cooooo1Ol0000eooooo`00
7?ooool00ol0003oooooooooo`0booooo`;o00009?ooool2o`0000[ooooo0_l0000<ooooo`;o0000
1_ooool3o`0000;ooooo0_l0000Uooooo`Ko000000?oooooo`000?l000000_ooool2o`00017ooooo
7Ol0000Eooooo`;o00001?ooool2o`0000_ooooo0_l00004ooooo`Co0000=_ooool001cooooo00?o
0000ooooooooool0<_ooool2o`0000[ooooo0_l0000Gooooo`?o00002_ooool2o`0000_ooooo0ol0
0006ooooo`;o00005?ooool3o`0001Gooooo1?l00005ooooo`;o00004?oooolNo`0000_ooooo0_l0
000>ooooo`;o00002_ooool2o`0003oooooo000Looooo`03o`000?oooooooooo02cooooo0_l00004
ooooo`;o00002_ooool2o`0001Oooooo0_l00003ooooo`?o00001_ooool2o`0000[ooooo0_l00008
ooooo`;o00000oooool2o`0000;ooooo0_l00009ooooo`Co00005oooool2o`0000Gooooo0_l0000@
ooooo`;o00000_ooool>o`000003ooooool0003o000000_o00002Oooool2o`0001[ooooo0_l0000o
ooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o0000;Oooool4o`0000Kooooo0_l00003oooo
o`;o00003oooool2o`0000?ooooo0_l00002ooooo`;o00002Oooool4o`0000?ooooo0_l00007oooo
o`;o00002Oooool3o`0001[ooooo3ol000000ooooooo0000o`000003o`000003ooooool0003o0000
00;ooooo0_l00002ooooo`;o00001_ooool2o`0000cooooo0_l000000ooooooo0000o`000002o`00
00Oooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0jooooo`;o00007oooool4o`0000So
oooo0_l000001?oooooo0000o`000?ooool3o`0000Gooooo0_l0000;ooooo`;o00002_ooool5o`00
00?ooooo0_l00007ooooo`;o00002_ooool2o`0001[ooooo3ol00002ooooo`Co000000?oooooo`00
0?l000000_ooool2o`0000;ooooo0_l00006ooooo`;o00001oooool2o`0000?ooooo0_l000000ooo
oooo0000o`000002o`0000Oooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0Looooo`;o
00006?ooool2o`0000;ooooo1?l0000@ooooo`Co000000?oooooo`000?l000001_ooool2o`0000[o
oooo1Ol000001?oooooo0000o`000?l00002ooooo`Go00002oooool2o`0000Oooooo1Ol0000^oooo
o`;o00001ooooolEo`000003ooooool0003o000000;ooooo0ol0000Booooo`;o0000DOooool001co
oooo00?o0000ooooooooool07?ooool2o`0001?ooooo0_l00003ooooo`;o00001?ooool2o`00013o
oooo1?l000000ooooooo0000o`000002ooooo`;o00000_ooool4o`0000Wooooo1?l000000ooooooo
0000o`000002o`000003ooooool0003o000000Go00002Oooool2o`0000Oooooo1?l0000Eooooo`;o
00006?ooool2o`0000Oooooo4_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l0000Soooo
o`;o0000@?ooool001cooooo00?o0000ooooooooool0;_ooool2o`000003ooooool0003o000000[o
oooo0_l0000Hooooo`;o00000oooool3o`0000Gooooo1?l000000ooooooo0000o`00000>o`0000;o
oooo0ol00004ooooo`;o00002oooool2o`000004ooooool0003o0000o`0000oooooo0_l00009oooo
o`;o00003Oooool3o`0000Gooooo6?l0000<ooooo`;o00005Oooool4o`0000;ooooo0_l00004oooo
o`;o00001?ooool2o`0003Cooooo000Looooo`03o`000?oooooooooo01_ooooo0_l0000Aooooo`;o
00003Oooool3o`0000_ooooo0_l00008ooooo`;o00001Oooool2o`0000Kooooo1?l00003ooooo`;o
000000?oooooo`000?l000000_l00002ooooo`;o000000?oooooo`000?l000000_ooool3o`0000ko
oooo0_l000000ooooooo0000o`000004o`0000Gooooo0_l00002ooooo`;o00002Oooool2o`0000Co
oooo0_l0000=ooooo`Go00000oooool2o`000003ooooool0003o0000013o000000?oooooo`000?l0
00003?ooool3o`000003ooooool0003o000000;ooooo0_l0000=ooooo`Co00002?ooool2o`0000Co
oooo0_l0000dooooo`007?ooool2o`0001cooooo0_l0000Aooooo`;o00003_ooool2o`0000_ooooo
0_l00008ooooo`;o00003?ooool2o`0000Cooooo3Ol000000ooooooo0000o`000002o`00013ooooo
0ol00003ooooo`;o00001oooool2o`0000;ooooo1?l00002ooooo`;o000000?oooooo`000?l00000
0_l0000Cooooo`Go00000oooool2o`0000?ooooo2ol0000<ooooo`;o00001_ooool6o`0000;ooooo
1?l0001Cooooo`007?ooool00ol0003oooooooooo`0dooooo`;o00000_ooool2o`0002Wooooo0_l0
00000ooooooo0000o`00000=o`000003ooooool0003o000000Ko00003Oooool3o`0001;ooooo0_l0
0002ooooo`;o000000?oooooo`000?l000000_l0000Dooooo`;o00001?ooool6o`000003ooooool0
003o000000So00000_ooool2o`0000Sooooo0_l00006ooooo`;o000000?oooooo`000?l000001Ooo
ool2o`0005?ooooo000Looooo`03o`000?oooooooooo02gooooo0_l00005ooooo`;o00000_ooool2
o`0001oooooo0_l00003ooooo`;o00000ooooolKo`0000Oooooo0_l00004ooooo`?o00003_ooool2
o`000003ooooool0003o000000?o00001Oooool2o`0001[ooooo1_l000001?oooooo0000o`000?oo
ool7o`0000;ooooo1?l0000Nooooo`;o0000COooool001cooooo00?o0000ooooooooool0;Oooool2
o`0000[ooooo0_l0000Cooooo`;o00001?ooool2o`0000?ooooo0_l00003ooooo`Co000000?ooooo
o`000?l000006Ol00007ooooo`;o00001Oooool6o`0000[ooooo0_l000000ooooooo0000o`000005
o`0001_ooooo0_l00004ooooo`Co000000?oooooo`000?l000000ol00002ooooo`;o00001Oooool2
o`0000[ooooo0_l0000@ooooo`Co00002?ooool3o`0004;ooooo000Looooo`03o`000?oooooooooo
01cooooo0_l0000Fooooo`;o00000oooool2o`0000Wooooo0_l00008ooooo`So00001_ooool2o`00
0003ooooool0003o000001_o000000?oooooo`000?l000001_ooool2o`0000Oooooo1?l0000<oooo
o`So00006oooool2o`0000Cooooo1?l000000ooooooo0000o`000003o`0001Gooooo0_l0000:oooo
o`;o00001?ooool4o`0000Sooooo0ol00005ooooo`;o000000?oooooo`000?l00000>?ooool001co
oooo00?o0000ooooooooool07?ooool2o`0001Kooooo0_l000000ooooooo0000o`00000;ooooo`;o
00002_ooool4o`0000Sooooo0_l000001?oooooo0000o`000?oooolIo`0000;ooooo0ol00005oooo
o`;o00004_ooool2o`0000?ooooo1_l00002ooooo`Co00005_ooool2o`000004ooooool0003o0000
ooooo`?o0000:Oooool3o`0000Gooooo0_l00005ooooo`;o00002Oooool2o`000003ooooool0003o
000003Sooooo000Looooo`03o`000?oooooooooo03Oooooo1_l00006ooooo`;o00001_ooool2o`00
0004ooooool0003o0000o`0000[ooooo0_l00002ooooo`;o000000?oooooo`000?l000005ol00003
ooooo`;o00001?ooool2o`0001?ooooo0_l00004ooooo`;o00000_ooool7o`0001Kooooo0_l00000
0ooooooo0000o`000003o`0000?ooooo0_l00007ooooo`;o00003Oooool2o`0000kooooo1?l00002
ooooo`?o00001?ooool3o`0000_ooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`0ioooo
o`Co00001_ooool2o`0000Kooooo0_l000001?oooooo0000o`000?l00003ooooo`;o00001Oooool2
o`000003ooooool0003o000000[o000000?oooooo`000?l000004Ol00005ooooo`?o00005oooool5
o`000003ooooool0003o000000;o00005oooool4o`0000;ooooo0_l00005ooooo`;o00001oooool2
o`0000;ooooo0_l00009ooooo`?o00003oooool2o`0000;ooooo0_l00005ooooo`;o00003?ooool2
o`0003Wooooo000Looooo`03o`000?oooooooooo03cooooo0_l00008ooooo`;o00000oooool2o`00
00?ooooo0_l00002ooooo`;o00002?ooool4o`000003ooooool0003o000001Wo00001Oooool2o`00
013ooooo0_l00006ooooo`;o000000?oooooo`000?l000000ol0000Iooooo`Co00000_ooool2o`00
00;ooooo0_l0000>ooooo`;o00002_ooool2o`0002Wooooo0_l0000hooooo`007?ooool00ol0003o
ooooooooo`0fooooo`;o000000Coooooo`000?l0003ooooo0_l00008ooooo`;o00002?ooool2o`00
00?ooooo0_l00006oooooago00001?ooool2o`0000Oooooo0_l0000<ooooo`;o00002oooool2o`00
01kooooo1?l00002ooooo`;o00005_ooool2o`0000oooooo0ol00003ooooo`;o00005_ooool2o`00
00?ooooo0_l0000cooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00001?ooool2o`000003
ooooool0003o000000Oooooo0_l0000=ooooo`;o00000_ooool2o`0000Kooooo8ol00005ooooo`Co
000000?oooooo`000?l000004oooool2o`0000Sooooo0_l00008ooooo`;o00003Oooool2o`0000Co
oooo0_l0000Fooooo`;o00003oooool3o`0000?ooooo0_l00007ooooo`;o00001_ooool2o`0000Ko
oooo0_l00002ooooo`;o0000<oooool001cooooo00?o0000ooooooooool0<?ooool2o`00013ooooo
0_l0000<ooooo`Go000000?oooooo`000?l000001?l000001?oooooo0000o`000?oooolFo`0000;o
oooo1ol00006ooooo`Co000000?oooooo`000?l000004?ooool2o`000004ooooool0003o0000o`00
00Oooooo0_l00008ooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`?o00001_ooool2
o`00037ooooo0_l00003ooooo`;o00001?ooool4o`0000Kooooo0_l0000gooooo`007?ooool00ol0
003oooooooooo`10ooooo`;o00003_ooool2o`000004ooooool0003o0000ooooo`So00000ooooolI
o`0000?ooooo0_l00003ooooo`;o00000oooool2o`0000cooooo0_l00002ooooo`;o000000?ooooo
o`000?l000000_ooool2o`0001Oooooo0_l000001?oooooo0000o`000?ooool3o`0000Kooooo0_l0
00001?oooooo0000o`000?l0000Vooooo`;o00001Oooool2o`0000Wooooo0_l000000ooooooo0000
o`000005ooooo`;o0000=oooool001cooooo00?o0000ooooooooool0@?ooool2o`0001Sooooo1?l0
00000ooooooo0000o`00000Lo`000003ooooool0003o000000;ooooo0_l00002ooooo`;o00002ooo
ool4o`0000;ooooo0_l0000Mooooo`;o00003_ooool2o`000004ooooool0003o0000o`0000;ooooo
0_l00005ooooo`;o00005oooool2o`0000;ooooo0_l0000>ooooo`;o00000oooool2o`0003kooooo
00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@
4?o<c<`01_ooool00ol0003oooooooooo`0Oooooo`;o00005_ooool4o`0001;ooooo0_l00007oooo
o`;o00000_ooool4o`000003ooooool0003o0000017o000000?oooooo`000?l000002?l000000ooo
oooo0000o`000006ooooo`;o00002?ooool2o`000003ooooool0003o000000Wooooo1?l0000>oooo
o`;o00000_ooool2o`0000;ooooo0_l0000Fooooo`;o00001Oooool2o`0000Gooooo0_l0000@oooo
o`;o00001?ooool2o`0000cooooo0_l00013ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5
ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool07ooo
ool2o`0001Kooooo1?l0000Booooo`;o00001oooool2o`0000Cooooo6Ol000001?oooooo0000o`00
0?ooool2o`0000;ooooo1_l00009ooooo`;o00000_ooool2o`0000_ooooo1Ol0000>ooooo`;o0000
0_ooool3o`000003ooooool0003o000000So00001oooool2o`00017ooooo1?l0000Fooooo`;o0000
1Oooool4o`0000cooooo0_l000000ooooooo0000o`00000gooooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`0iooooo`;o00004_ooool2o`0000kooooo0ol000000ooooooo0000o`00000Bo`000003oooo
ool0003o000000?o00000_ooool6o`0000Wooooo0_l00004ooooo`?o00001?ooool8o`0000Cooooo
0_l0000<ooooo`Co00000_ooool>o`0000;ooooo1?l0000>ooooo`?o00005Oooool2o`0000Oooooo
1Ol00008ooooo`;o00000_ooool2o`000003ooooool0003o000003Oooooo00000ooooooo0000oooo
o`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000
>Oooool2o`0001cooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo6Ol00005ooooo`;o
00001oooool2o`0000Kooooo1Ol00003ooooo`Oo00001_ooool2o`0000cooooo5?l00004ooooo`;o
00003_ooool2o`0001Kooooo0_l00005ooooo`Go00002_ooool2o`0003kooooo00000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03
o`000?oooooooooo05Gooooo1?l00002ooooo`;o000000?oooooo`000?l000005_l000001?oooooo
0000o`000?l0000>ooooo`;o00001_ooool2o`0000?ooooo1ol000000ooooooo0000o`00000>oooo
o`;o00001?oooolDo`0002Sooooo0_l00006ooooo`;o000000?oooooo`000?l00000COooool00003
ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03
o`000?oooooooooo023ooooo0_l0000Hooooo`;o00002Oooool2o`0000Kooooo0_l00006ooooo`;o
00001ooooolLo`000003ooooool0003o000001Oooooo1?l000001Ooooooo0000o`000?l0003ooooo
00;o00000oooool2o`0000Wooooo0_l00003oooooaKo00005Oooool4o`0000kooooo0_l00005oooo
o`?o0000D?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008
ooooo`03o`000?oooooooooo023ooooo0_l0000Cooooo`;o00000oooool2o`0000Wooooo0_l00006
ooooo`;o00000oooool2o`000003ooooool0003o000000Sooooo6Ol00003ooooo`;o00000_ooool2
o`0000_ooooo1?l00004ooooo`Co000000Coooooo`000?l0003o00001_ooool2o`0000kooooo6?l0
000Cooooo`Co00003_ooool4o`0000?ooooo0_l0000@ooooo`;o00001Oooool2o`0003Sooooo0000
1_ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003o
ooooooooo`0eooooo`;o00006?ooool2o`000003ooooool0003o000000Gooooo0_l00005oooooaOo
00002?ooool2o`0000Oooooo0_l000000ooooooo0000o`000003o`0000Wooooo1?l0000?ooooo`;o
00000ooooolFo`000003ooooool0003o000000kooooo0_l0000Dooooo`;o000000?oooooo`000?l0
00005Oooool2o`0000Gooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0nooooo`?o0000
3?ooool4o`0000Sooooo0_l00003ooooo`;o00000oooool@o`0000;ooooo0_l00003ooooo`;o0000
3?ooool2o`000003ooooool0003o000000Kooooo2_l00008ooooo`;o00000oooool4o`0000;ooooo
5ol00009ooooo`;o00001_ooool2o`0001Cooooo0_l00004ooooo`;o00003_ooool2o`0004?ooooo
000Looooo`03o`000?oooooooooo03kooooo0ol0000<ooooo`;o00000_ooool2o`0000;ooooo0_l0
0004ooooo`;o000000?oooooo`000?l000000oooool6o`0000;ooooo2?l00004ooooo`;o000000?o
ooooo`000?l000001oooool2o`0000Kooooo0_l00004ooooo`Wo00001oooool2o`0000;ooooo0_l0
0003ooooo`;o00001?oooolKo`0000Gooooo0_l0000Rooooo`;o00002?ooool2o`0000Cooooo0_l0
000<ooooo`;o0000=Oooool001cooooo00?o0000ooooooooool0@Oooool2o`0000kooooo1_l00004
ooooo`;o00001_ooool2o`0000;ooooo3?l00002ooooo`Co00001Oooool2o`000003ooooool0003o
000000;o00001_ooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0000Sooooo0_l0
0007ooooo`;o00001OoooolJo`0002Kooooo0_l000000ooooooo0000o`000002o`0000Kooooo0_l0
0009ooooo`Co00001Oooool2o`0003Gooooo000Looooo`03o`000?oooooooooo047ooooo0_l0000@
ooooo`Co00001oooool2o`000003ooooool0003o000000?o00000_ooool9o`0000Cooooo0_l00007
ooooo`;o000000?oooooo`000?l000002?ooool2o`0000Cooooo0_l000000ooooooo0000o`000002
o`0000Wooooo0_l00003ooooo`;o00000_ooool2o`0000Gooooo5_l0000Zooooo`;o000000?ooooo
o`000?l000000_l0000Aooooo`Co0000??ooool001cooooo00?o0000ooooooooool0B_ooool2o`00
00Oooooo0_l00009ooooo`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00000_ooool5
o`0000Cooooo0_l0000Iooooo`Co000000?oooooo`000?l000001oooool4o`000003ooooool0003o
000000;o000000Coooooo`000?l0003o00001?oooolFo`000004ooooool0003o0000o`0002[ooooo
0_l0000:ooooo`;o00003oooool2o`0003Kooooo000Looooo`03o`000?oooooooooo04Cooooo0_l0
0004ooooo`;o00001oooool2o`0000oooooo0_l00003ooooo`;o00000oooool4o`0000;ooooo1?l0
000Jooooo`Ko000000?oooooo`000?l000001?ooool2o`0000?ooooo0_l00003ooooo`;o00001Ooo
oolFo`000004ooooool0003o0000o`0002[ooooo0_l00008ooooo`Co00003oooool2o`0003Kooooo
000Looooo`03o`000?oooooooooo04Cooooo0ol0000?ooooo`;o00004_ooool2o`000003ooooool0
003o000000Gooooo1?l00004ooooo`;o00004Oooool4o`000003ooooool0003o000000;o000000?o
ooooo`000?l000001_ooool3o`0000gooooo5?l00003ooooo`?o00001oooool2o`0002[ooooo0ol0
0018ooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00003oooool2o`0000oooooo2?l00005
ooooo`Co00000oooool3o`0000kooooo2Ol0000<ooooo`?o00002ooooolHo`0000;ooooo0_l00007
ooooo`;o00001Oooool2o`00027ooooo0_l000000ooooooo0000o`000018ooooo`007?ooool00ol0
003oooooooooo`1Eooooo`;o00002Oooool2o`0000Gooooo2Ol00004ooooo`Co00000oooool2o`00
00cooooo0_l000000ooooooo0000o`000004o`000003ooooool0003o000001[ooooo6?l0000;oooo
o`;o00001Oooool2o`00013ooooo0_l0000?ooooo`;o00002Oooool2o`00043ooooo000Looooo`03
o`000?oooooooooo02Oooooo0_l0000/ooooo`;o00002Oooool2o`000003ooooool0003o000000;o
000000?oooooo`000?l000000_l000000ooooooo0000o`000003o`0000Cooooo0_l0000Aooooo`;o
000000Coooooo`000?l0003ooooo0ol0000?ooooo`?o00002?ooool2o`000003ooooool0003o0000
00Oo000000?oooooo`000?l000001_l00004ooooo`;o00004oooool2o`0000oooooo0_l0000Joooo
o`;o0000@?ooool001cooooo00?o0000ooooooooool09oooool2o`0002kooooo0_l0000:ooooo`Co
00000oooool3o`0000?ooooo0_l0000Fooooo`Co00001Oooool2o`000003ooooool0003o000000Wo
oooo1Ol00008ooooo`;o000000?oooooo`000?l000004?l00002ooooo`Co00001_ooool2o`0000_o
oooo0_l0000;ooooo`;o00002?ooool2o`0000Oooooo0_l00003ooooo`;o00001oooool2o`000003
ooooool0003o000003cooooo000Looooo`;o0000Doooool2o`0000?ooooo0_l00008ooooo`;o0000
1_ooool4o`0000Kooooo0_l0000<ooooo`;o00001Oooool4o`000003ooooool0003o000000;ooooo
1ol00007ooooo`;o00003_ooool<o`000003ooooool0003o000000[o00000_ooool2o`000003oooo
ool0003o000001Oooooo0ol00004ooooo`;o00000_ooool2o`0000Oooooo0_l00002ooooo`?o0000
00?oooooo`000?l000000_ooool4o`000003ooooool0003o000003cooooo000Looooo`03o`000?oo
oooooooo05;ooooo0_l00004ooooo`?o000000?oooooo`000?l000000oooool4o`0000Cooooo0_l0
0004ooooo`;o00000_ooool2o`0000[ooooo1?l0000:ooooo`;o00000oooool2o`000003ooooool0
003o000000;o00005_oooolMo`0001[ooooo1?l00003ooooo`Co00003Oooool2o`0000;ooooo0_l0
0002ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0Aoooool4o`0000gooooo0ol00000
0ooooooo0000o`000005ooooo`?o00002Oooool2o`0000?ooooo0_l00009ooooo`;o00002?ooool2
o`0000Gooooo0ol000000ooooooo0000o`000003o`0000Kooooo0_l0000=oooooaGo00001?ooool7
o`0001Wooooo0ol00003ooooo`Co00004Oooool2o`0004Gooooo000Looooo`03o`000?oooooooooo
04Oooooo1_l0000Eooooo`Co00000_ooool2o`000003ooooool0003o000000;ooooo0_l00003oooo
o`;o00004oooool2o`0000Gooooo1_l000000ooooooo0000o`000006ooooo`;o00003OoooolDo`00
0003ooooool0003o000000Gooooo1?l00008ooooo`;o00003oooool2o`0001Gooooo0_l000000ooo
oooo0000o`000002o`0004Cooooo000Looooo`03o`000?oooooooooo04_ooooo0_l0000Eooooo`Co
00000_ooool2o`000005ooooool0003o0000o`000?ooool00ol00005ooooo`;o00005?ooool2o`00
00?ooooo0ol00002ooooo`;o00001?ooool2o`00017ooooo4_l000000ooooooo0000o`000005oooo
o`?o00002Oooool2o`0001Gooooo0_l0000?ooooo`;o000000?oooooo`000?l000000_l00014oooo
o`007?ooool00ol0003oooooooooo`1/ooooo`Ko00001Oooool2o`0000cooooo0_l00002ooooo`;o
00000_ooool2o`0000?ooooo1?l00007ooooo`;o00004_ooool@o`0000[ooooo0_l0000Pooooo`;o
00002?ooool2o`0000Oooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o0000
0_ooool2o`000003ooooool0003o000000?ooooo0_l0000;ooooo`;o00002?ooool4o`0000;ooooo
0_l00002ooooo`;o000000?oooooo`000?l000002Oooool2o`0000;ooooo0_l00008ooooo`?o0000
0oooool2o`0001Kooooo3?l00002ooooo`?o00007_ooool2o`0000;ooooo0_l00009ooooo`;o0000
1_ooool2o`0000Oooooo0_l000000ooooooo0000o`000014ooooo`007?ooool00ol0003ooooooooo
o`16ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`?o00002ooo
ool2o`0000Kooooo0_l00006ooooo`;o00000_ooool2o`000003ooooool0003o000000Cooooo0_l0
0003ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Cooooo0_l00003ooooo`;o00000ooo
ool2o`0000oooooo0_l00003ooooo`Go00001oooool2o`0001kooooo0_l00002ooooo`;o00002Ooo
ool2o`0000_ooooo0_l00005ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0;_ooool2
o`0001Kooooo1?l00003ooooo`;o00001_ooool2o`0000Oooooo0ol0000:ooooo`;o00002_ooool2
o`000004ooooool0003o0000o`0000?ooooo1_l00002ooooo`;o00001?ooool2o`0000Wooooo0_l0
0003ooooo`;o00003oooool2o`000004ooooool0003o0000ooooo`;o0000=oooool2o`0000Gooooo
0_l00005ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0;_ooool2o`0001Sooooo0_l0
0003ooooo`;o00003oooool3o`0000[ooooo1?l00008ooooo`;o00000_ooool2o`0000Gooooo1?l0
000?ooooo`Ko00005oooool2o`0000?ooooo0_l00004ooooo`;o00008_ooool2o`0000?ooooo0_l0
0006ooooo`Go000000Coooooo`000?l0003o0000D_ooool001cooooo00?o0000ooooooooool0Gooo
ool2o`0000?ooooo0_l00004ooooo`Go00001Oooool5o`0000Sooooo0_l00006ooooo`;o00002_oo
ool5o`0001Oooooo0_l00003ooooo`Go00000_ooool2o`0000Sooooo0_l0000@ooooo`;o00000_oo
ool2o`0000;ooooo0_l00003ooooo`;o00001oooool4o`000003ooooool0003o000000;o0000DOoo
ool001cooooo00?o0000ooooooooool0I?ooool2o`0000Cooooo1_l00003ooooo`Ko000000?ooooo
o`000?l000001Oooool2o`0000Kooooo0_l0000<ooooo`?o00001Oooool2o`0000kooooo1?l00003
ooooo`Go00003?ooool4o`0000kooooo0_l00002ooooo`;o00002oooool2o`000003ooooool0003o
000000Kooooo0ol00009ooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0Eoooool2o`00
01Cooooo0ol00003ooooo`?o000000Coooooo`000?l0003ooooo1?l0000>ooooo`;o00002Oooool4
o`0000Cooooo0_l0000>ooooo`;o00004Oooool2o`0000;ooooo1Ol0000@ooooo`;o00003Oooool2
o`000003ooooool0003o000000Cooooo0_l0000<ooooo`;o0000A_ooool001cooooo00?o0000oooo
ooooool0C?ooool2o`0000Wooooo0ol0000Mooooo`;o00000oooool2o`0000Oooooo0_l00005oooo
o`;o00002Oooool4o`0002Oooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l00003oooo
o`;o00002Oooool2o`0001Cooooo1?l0001Dooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o
00001oooool2o`000003ooooool0003o000000?ooooo0_l0000Fooooo`;o00003_ooool2o`0000Go
oooo0_l0000Yooooo`;o00002Oooool2o`0000Gooooo1?l00003ooooo`Co00007Oooool4o`0005Co
oooo000Looooo`03o`000?oooooooooo03?ooooo0_l0000Pooooo`;o00001_ooool2o`000003oooo
ool0003o000001?ooooo0_l00006ooooo`;o00001Oooool2o`0000cooooo1?l00002ooooo`?o0000
7?ooool2o`0000;ooooo0_l00005ooooo`;o00001Oooool4o`0000Gooooo1?l00006ooooo`;o0000
0oooool2o`0000?ooooo0ol00005ooooo`?o00000oooool2o`0000Gooooo0_l0001<ooooo`007?oo
ool2o`0003Cooooo0_l0000Xooooo`Go00003Oooool4o`0000[ooooo0_l00005ooooo`;o00002_oo
ool6o`0000;ooooo0ol0000Pooooo`;o00001Oooool3o`0000Cooooo0_l00003ooooo`;o00001?oo
ool4o`0000Cooooo1ol00003ooooo`?o00000_ooool2o`000004ooooool0003o0000o`0000;ooooo
0ol00005ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0Goooool6o`0000[ooooo1?l0
0004ooooo`Co00003_ooool2o`0000Gooooo0_l000000ooooooo0000o`000004ooooo`;o0000:?oo
ool2o`0000Wooooo0_l00006ooooo`;o00001Oooool4o`0000Wooooo0ol00002ooooo`Ko00001_oo
ool2o`0004cooooo000Looooo`03o`000?oooooooooo053ooooo0_l00005ooooo`Co00000_ooool2
o`0000;ooooo1?l0000Booooo`Co00003_ooool2o`0000Oooooo0_l00006ooooo`;o0000<_ooool2
o`00013ooooo0_l00008ooooo`;o00000oooool4o`000003ooooool0003o000000Gooooo0_l0001<
ooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00001Oooool9o`0000?ooooo0_l00002oooo
o`;o00005oooool2o`00013ooooo0_l00006ooooo`;o00001Oooool2o`0002_ooooo0_l00008oooo
o`;o00001_ooool2o`0000Sooooo0_l00007ooooo`?o0000Doooool001cooooo00?o0000oooooooo
ool0Foooool2o`000003ooooool0003o000000Oooooo0_l00005ooooo`;o00001oooool2o`0000;o
oooo0_l00003ooooo`Co00003oooool4o`000004ooooool0003o0000o`0000Kooooo0_l00002oooo
o`;o00005?ooool2o`0001_ooooo0_l00006ooooo`;o00004Oooool2o`0000Gooooo0_l0001=oooo
o`007?ooool00ol0003oooooooooo`1Jooooo`;o00004_ooool2o`0000?ooooo0_l00002ooooo`;o
00000_ooool2o`0000Gooooo0_l00006ooooo`;o00001oooool4o`000004ooooool0003o0000o`00
00[ooooo0_l0000Dooooo`;o00002?ooool2o`0000Gooooo0_l0000?ooooo`;o00001?ooool2o`00
01Gooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`1Booooo`;o00001_ooool3o`0001;o
oooo0_l000001?oooooo0000o`000?l00006ooooo`;o00000oooool2o`000003ooooool0003o0000
00?ooooo1?l00008ooooo`?o00000_ooool2o`0000cooooo0_l0000Looooo`;o00001Oooool2o`00
00oooooo0_l00003ooooo`Co00004Oooool2o`00053ooooo000Looooo`03o`000?oooooooooo03[o
oooo0_l0000Fooooo`?o00001Oooool5o`0000Gooooo0_l00009ooooo`;o000000?oooooo`000?l0
00000_ooool2o`0000?ooooo1?l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l00003oooo
o`Oo00004oooool2o`00033ooooo0_l00004ooooo`;o000000?oooooo`000?l000000_l0000Aoooo
o`;o0000D?ooool001cooooo00?o0000ooooooooool0>_ooool2o`0001;ooooo0_l00003ooooo`;o
00001Oooool2o`000004ooooool0003o0000ooooo`?o000000?oooooo`000?l000004?ooool3o`00
00?ooooo0ol00009ooooo`Co000000?oooooo`000?l000001Ol00009ooooo`;o0000<?ooool2o`00
00Cooooo0_l00002ooooo`So000000?oooooo`000?l000000_l00005ooooo`;o0000G?ooool001co
oooo00?o0000ooooooooool0C_ooool4o`0000kooooo0ol0000Dooooo`;o00000_ooool6o`000003
ooooool0003o000000Cooooo2_l0000;ooooo`;o00001_ooool2o`0002Sooooo0_l00004ooooo`[o
00000_ooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000Kooooo0_l0001Doooo
o`007?ooool00ol0003oooooooooo`1@ooooo`;o00003oooool2o`000003ooooool0003o000000oo
oooo0_l00004ooooo`Ko000000?oooooo`000?l000001Oooool:o`000003ooooool0003o000000oo
oooo0_l00003ooooo`;o00008Oooool2o`0000?ooooo0_l000000ooooooo0000o`000006o`0000Co
oooo0_l00004ooooo`Co00002?ooool2o`0005Cooooo000Looooo`03o`000?oooooooooo05Gooooo
0_l0000=ooooo`;o00001Oooool2o`0000Sooooo0_l00005ooooo`?o00002Oooool;o`000003oooo
ool0003o000001Cooooo0_l0000Iooooo`;o00001_ooool7o`0000;ooooo0_l0000?ooooo`Co0000
G_ooool001cooooo00?o0000ooooooooool0?_ooool2o`0001Gooooo0_l0000Dooooo`;o00002?oo
ool2o`0000cooooo1?l000000ooooooo0000o`000009o`0000?ooooo0_l0000Aooooo`?o00006Ooo
ool2o`0000Sooooo1Ol0000:ooooo`;o00001?ooool2o`0006?ooooo000Looooo`03o`000?oooooo
oooo03kooooo1?l0000Oooooo`?o00002Oooool2o`0000Kooooo0_l0000<oooooa3o00000oooool2
o`0000Gooooo0_l0000:ooooo`?o00004_ooool3o`00013ooooo0ol00005ooooo`;o00000oooool2
o`0000Cooooo0_l0001Sooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00004?ooool2o`00
00Gooooo0_l00006ooooo`?o00001?ooool2o`0000?ooooo0_l000000ooooooo0000o`00000>oooo
o`?o00001?ooool>o`0000Sooooo0_l00007ooooo`;o00005_ooool5o`0000oooooo0_l00005oooo
o`;o00002_ooool2o`0006;ooooo000Looooo`03o`000?oooooooooo05;ooooo0_l00005ooooo`;o
00003Oooool2o`000003ooooool0003o000000?ooooo0_l0000>ooooo`?o00000oooool?o`00013o
oooo1Ol0000Gooooo`;o00003oooool3o`00013ooooo0_l0001Rooooo`007?ooool2o`0004Cooooo
0_l0000Oooooo`?o00001?ooool2o`0000?ooooo0ol0000Cooooo`ko000000?oooooo`000?l00000
0_l0000<ooooo`Go0000:Oooool2o`0000Kooooo1Ol00008ooooo`;o0000Goooool001cooooo00?o
0000ooooooooool0@oooool2o`0001oooooo0ol00004ooooo`;o00001?ooool2o`000003ooooool0
003o000000Oooooo0_l00002ooooo`;o00001?ooool=o`000003ooooool0003o000000;o00004Ooo
ool2o`00027ooooo0_l00004ooooo`;o00001_ooool5o`0000Sooooo0_l0001Oooooo`007?ooool0
0ol0003oooooooooo`1Mooooo`;o00003?ooool2o`000003ooooool0003o000000Cooooo0ol00003
ooooo`;o000000?oooooo`000?l000000_ooool3o`0000?ooooo3Ol0000<ooooo`Co00001_ooool2
o`0001Sooooo0_l00007ooooo`;o00001oooool2o`0000;ooooo0_l0001]ooooo`007?ooool00ol0
003oooooooooo`1Mooooo`;o00002_ooool2o`0000?ooooo0_l00005ooooo`?o00000_ooool2o`00
00Kooooo1?l00003ooooo`_o00003?ooool4o`00023ooooo0_l0000?ooooo`?o00000_ooool2o`00
06gooooo000Looooo`03o`000?oooooooooo06Wooooo0_l00003ooooo`;o00001Oooool5o`0000[o
oooo0ol00002ooooo`[o00003oooool2o`0000?ooooo1?l0000Kooooo`;o000000?oooooo`000?l0
00002_ooool2o`0000;ooooo0_l0001^ooooo`007?ooool00ol0003oooooooooo`1eooooo`;o0000
00?oooooo`000?l000002?ooool2o`000003ooooool0003o000000;ooooo2Ol00006ooooo`;o0000
1?ooool6o`0000?ooooo1?l00002ooooo`;o00005oooool2o`000003ooooool0003o000000Gooooo
0_l00007ooooo`?o0000KOooool001cooooo00?o0000ooooooooool0M_ooool3o`0000Cooooo0_l0
0003ooooo`;o00001_ooool7o`0000Oooooo0_l00004ooooo`Go00002_ooool2o`0000Gooooo0_l0
0008ooooo`;o00003oooool3o`0000Sooooo0_l0001]ooooo`007?ooool00ol0003oooooooooo`1f
ooooo`?o00000oooool3o`0000_ooooo0_l00003ooooo`;o00008?ooool2o`000003ooooool0003o
000000Sooooo0_l00009ooooo`;o00001?ooool2o`0000Kooooo0_l00002ooooo`;o0000K?ooool0
01cooooo00?o0000ooooooooool0L_ooool2o`0000Kooooo1?l0000>ooooo`;o00001?ooool2o`00
00oooooo0_l0000;ooooo`?o00005_ooool2o`0000Kooooo0_l00004ooooo`;o00000_ooool2o`00
06cooooo000Looooo`03o`000?oooooooooo073ooooo1?l000001?oooooo0000o`000?l00002oooo
o`;o00001Oooool2o`0000Wooooo0_l00004ooooo`;o00003oooool2o`0000_ooooo0_l0000Ooooo
o`;o00001?ooool2o`00073ooooo000Looooo`03o`000?oooooooooo04_ooooo0_l0000?ooooo`;o
00004_ooool2o`0000?ooooo0ol00002ooooo`;o00001Oooool2o`0000?ooooo0_l00007ooooo`;o
00006_ooool2o`0000Gooooo1?l000000ooooooo0000o`00000Dooooo`;o0000N_ooool001cooooo
00?o0000ooooooooool0Boooool2o`0000oooooo0_l0000Hooooo`;o00000_ooool2o`0000Cooooo
0_l000001?oooooo0000o`000?ooool2o`0000Oooooo0_l0000<ooooo`;o00003?ooool2o`0000Go
oooo1?l000000ooooooo0000o`000002o`0000;ooooo0_l00003ooooo`;o00002Oooool3o`0000co
oooo0_l0001[ooooo`007?ooool00ol0003oooooooooo`20ooooo`;o000000?oooooo`000?l00000
2?ooool2o`0000kooooo1Ol0000Cooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o0000
1_ooool3o`000003ooooool0003o000000[ooooo1?l0001[ooooo`007?ooool00ol0003ooooooooo
o`2=ooooo`;o00003oooool4o`0001?ooooo0_l000000ooooooo0000o`00000@ooooo`Ko00001Ooo
ool2o`0000?ooooo1?l0001[ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q
1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0K_ooool2o`0000?o
oooo0_l0000Eooooo`;o00004_ooool4o`0001Kooooo0_l00003ooooo`;o00002_ooool2o`0000;o
oooo0ol00004ooooo`?o00000_ooool5o`0006_ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMg
M`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1^
ooooo`?o00000_ooool2o`0000gooooo0_l00006ooooo`;o000000?oooooo`000?l000003oooool2
o`0001_ooooo1?l0000:ooooo`;o00002Oooool3o`0000;ooooo0ol0001]ooooo`0000?ooooooa0@
4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`1_ooooo`;o00001?ooool2o`0000Wooooo1_l00002ooooo`;o00000oooool3
o`0000[ooooo0_l0000Oooooo`;o00003Oooool2o`0000[ooooo0_l0001aooooo`0000?oooooo`00
0?ooool00_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3
o`0007Gooooo0_l00009ooooo`;o00000_ooool2o`0000;ooooo0_l00004ooooo`?o00001Oooool8
o`0002cooooo1?l00008ooooo`;o0000LOooool00003ooooool0003ooooo00;ooooo00?o0000oooo
ooooool02Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0Q?ooool2
o`0000Wooooo0_l00002ooooo`;o000000?oooooo`000?l000001_l0000Looooo`Co00002Oooool2
o`0000?ooooo0_l00003ooooo`;o0000M_ooool00003ooooool@413ooooo00;ooooo00?o410@oooo
ooooool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0Noooool2
o`0001Kooooo0_l0000Uooooo`Co00001Oooool2o`0000;ooooo0_l00008ooooo`;o0000M_ooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo
00?o0000ooooooooool0Noooool2o`0001Kooooo0_l000000ooooooo0000o`00000Nooooo`;o0000
1?ooool2o`0000Gooooo0_l00006ooooo`;o0000O?ooool00006ooooooo^k^ko<S8bo`000?lb<S;o
k^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0P_ooool6o`00
00Gooooo1?l00005ooooo`;o00000_ooool2o`0000cooooo0_l0000<ooooo`;o00001?ooool2o`00
00gooooo0_l000000ooooooo0000o`00001iooooo`007?ooool00ol0003oooooooooo`22ooooo`Ko
00001Oooool4o`0000Gooooo0_l00002ooooo`;o00002_ooool4o`0000Gooooo0_l0000;ooooo`;o
00000oooool2o`0000Wooooo1?l0001iooooo`007?ooool00ol0003oooooooooo`2Aooooo`?o0000
0_ooool2o`0000?ooooo0_l00002ooooo`;o00001Oooool2o`0000Oooooo1?l00009ooooo`Co0000
00?oooooo`000?l000002Oooool2o`0007_ooooo000Looooo`03o`000?oooooooooo097ooooo0ol0
0006ooooo`?o00000_ooool2o`0000_ooooo0_l00003ooooo`;o00002Oooool4o`000003ooooool0
003o000008Kooooo000Looooo`03o`000?oooooooooo09[ooooo0_l00003ooooo`;o000000?ooooo
o`000?l000000_l000000ooooooo0000o`000002ooooo`Co00002oooool2o`0000Wooooo0_l00022
ooooo`007?ooool00ol0003oooooooooo`2:ooooo`;o00003_ooool7o`000003ooooool0003o0000
00;o000000?oooooo`000?l000000_ooool4o`0000Oooooo0_l00002ooooo`;o00000oooool2o`00
00Cooooo0_l00022ooooo`007?ooool00ol0003oooooooooo`29ooooo`?o00001?ooool2o`0000So
oooo1_l0000<ooooo`;o00002?ooool2o`0000Oooooo1?l00026ooooo`007?ooool00ol0003ooooo
ooooo`29ooooo`;o00001Oooool2o`0000Cooooo0_l00003ooooo`Go00003?ooool2o`0000Gooooo
1Ol00009ooooo`;o0000Q_ooool001cooooo00?o0000ooooooooool0ROooool2o`0000_ooooo0_l0
0005ooooo`?o000000Coooooo`000?l0003ooooo0_l00006ooooo`;o00001Oooool4o`0000_ooooo
0_l00025ooooo`007?ooool00ol0003oooooooooo`2Hooooo`;o00001?ooool2o`000004ooooool0
003o0000ooooo`?o00006oooool2o`0008Gooooo000Looooo`03o`000?oooooooooo09Sooooo0_l0
0007ooooo`;o000000Coooooo`000?l0003o0000X_ooool001cooooo00?o0000ooooooooool0Y?oo
ool3o`000:;ooooo000Looooo`;o0000YOooool2o`0000[ooooo1?l0002Eooooo`007?ooool00ol0
003oooooooooo`2Tooooo`;o00002_ooool7o`000004ooooool0003o0000ooooo`;o0000S?ooool0
01cooooo00?o0000ooooooooool0Uoooool2o`0001_ooooo0ol000001?oooooo0000o`000?ooool2
o`0008cooooo000Looooo`03o`000?oooooooooo08kooooo0_l00007ooooo`?o0000[oooool001co
oooo00?o0000ooooooooool0S_ooool2o`0000Sooooo0_l0002_ooooo`007?ooool00ol0003ooooo
ooooo`2Kooooo`;o0000[?ooool001cooooo00?o0000ooooooooool0Voooool2o`000:cooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooo
oom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o
0000ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Co
oooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo
000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomB
ooooo`004_ooool00omEEEGoIVIVo`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo002Uooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05Ooo
ool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h0T?ooool00:Kooooo00Go0000ooooooooooooooooo`000009oooo
o`Ko00002Oooool01OmEEEGoMgMgoooooonHV9So8B4Q00?ooooo00Go410@okZj^_ooooooMgMgoc8b
<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0T?ooool00:Kooooo00Go0000oooooooooooooooo
o`00000Hooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool0S_ooool00:Kooooo00Go0000ooooooooooooooooo`000009oooo
o`Ko00002Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?oZJVYoa0@4?ooool00_ooool0
1Ol0003ooooooooooooooooo0000093ooooo002Vooooo`05o`000?n7QhOoooooojVYZOl000006?oo
ool01Ol0003oEEEEo`000?l@413oc<c<00Gooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooo
oooooooooooo0000093ooooo002Uooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool0
5_ooool00omEEEGoQhN7ooooo`08ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooo
oooooa0@402@ooooo`00`oooool00ooMgMgo410@oiRHV005ooooo`05oa0@4?nHV9SooooookZj^_l0
00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg093ooooo0034ooooo`04olc<c?m4A4Co0000oa0@
40?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0T?oo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(636) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.31677 .53028 Mdot
.33029 .58638 Mdot
.63464 .50189 Mdot
.43147 .3644 Mdot
.6576 .43697 Mdot
.64585 .53467 Mdot
.56126 .65311 Mdot
.52607 .64122 Mdot
.64294 .54548 Mdot
.20626 .43919 Mdot
.54584 .62256 Mdot
.38634 .33976 Mdot
.56782 .64043 Mdot
.46849 .38939 Mdot
.45311 .71817 Mdot
.48989 .32711 Mdot
.32434 .59513 Mdot
.70078 .36384 Mdot
.48321 .32137 Mdot
.65204 .49815 Mdot
.43091 .50109 Mdot
.46142 .39208 Mdot
.32096 .59035 Mdot
.46608 .39083 Mdot
.41759 .40112 Mdot
.32123 .5692 Mdot
.33235 .52214 Mdot
.4335 .40571 Mdot
.45176 .42853 Mdot
.56171 .61825 Mdot
.73594 .40154 Mdot
.40241 .82788 Mdot
.48085 .33207 Mdot
.34116 .39398 Mdot
.52501 .65767 Mdot
.78966 .59764 Mdot
.6543 .55818 Mdot
.54228 .61782 Mdot
.53991 .66275 Mdot
.55266 .67159 Mdot
.57981 .65236 Mdot
.32758 .57291 Mdot
.59273 .64874 Mdot
.70949 .52735 Mdot
.44706 .34512 Mdot
.33744 .72893 Mdot
.75465 .35222 Mdot
.43556 .40492 Mdot
.30777 .54252 Mdot
.65953 .50421 Mdot
.43608 .22529 Mdot
.55019 .6107 Mdot
.39645 .75165 Mdot
.09501 .54581 Mdot
.56627 .62346 Mdot
.4318 .37711 Mdot
.6697 .5292 Mdot
.44923 .36452 Mdot
.44491 .40026 Mdot
.34279 .34233 Mdot
.45697 .41994 Mdot
.67891 .3666 Mdot
.32947 .51877 Mdot
.66793 .49597 Mdot
.64663 .54219 Mdot
.5822 .62902 Mdot
.36027 .56488 Mdot
.57522 .64558 Mdot
.39157 .35949 Mdot
.64245 .50346 Mdot
.43552 .39735 Mdot
.54636 .62062 Mdot
.34815 .58503 Mdot
.40469 .3871 Mdot
.37027 .70019 Mdot
.58078 .70651 Mdot
.66662 .3323 Mdot
.29112 .48248 Mdot
.26239 .29116 Mdot
.64719 .6249 Mdot
.47542 .39847 Mdot
.2479 .27956 Mdot
.4559 .70276 Mdot
.34341 .57971 Mdot
.36112 .42883 Mdot
.64103 .75155 Mdot
.45571 .43203 Mdot
.57621 .43684 Mdot
.49866 .4194 Mdot
.43941 .58819 Mdot
.64874 .54899 Mdot
.31407 .57027 Mdot
.4446 .34471 Mdot
.44446 .43802 Mdot
.31415 .30543 Mdot
.47178 .33744 Mdot
.44481 .35072 Mdot
.37406 .58625 Mdot
.54425 .63189 Mdot
.39066 .43197 Mdot
.71273 .54417 Mdot
.4214 .73085 Mdot
.42177 .3633 Mdot
.63294 .52669 Mdot
.2935 .55137 Mdot
.43409 .34828 Mdot
.57747 .6261 Mdot
.46499 .40714 Mdot
.54152 .68882 Mdot
.30541 .56887 Mdot
.44875 .43751 Mdot
.67637 .34545 Mdot
.40896 .65638 Mdot
.33297 .53258 Mdot
.18981 .53535 Mdot
.45491 .41623 Mdot
.45247 .39589 Mdot
.33785 .58174 Mdot
.6781 .5293 Mdot
.55731 .46879 Mdot
.33365 .59367 Mdot
.54542 .66693 Mdot
.3006 .56617 Mdot
.47624 .44097 Mdot
.67771 .52077 Mdot
.42343 .73858 Mdot
.41867 .72093 Mdot
.70005 .28904 Mdot
.40875 .40457 Mdot
.44233 .71994 Mdot
.64964 .52167 Mdot
.32842 .57894 Mdot
.57526 .64026 Mdot
.49224 .4092 Mdot
.35328 .54428 Mdot
.53662 .65466 Mdot
.65108 .36408 Mdot
.6708 .44561 Mdot
.34932 .52775 Mdot
.55517 .36203 Mdot
.52068 .64214 Mdot
.55791 .67205 Mdot
.45859 .22888 Mdot
.3457 .57484 Mdot
.65646 .38156 Mdot
.54646 .65868 Mdot
.58658 .26432 Mdot
.49289 .39866 Mdot
.5382 .21377 Mdot
.30214 .22768 Mdot
.4462 .22633 Mdot
.25602 .65645 Mdot
.68836 .37542 Mdot
.54955 .66089 Mdot
.42343 .38292 Mdot
.34342 .55629 Mdot
.34199 .56396 Mdot
.44277 .44105 Mdot
.42579 .41873 Mdot
.47611 .36999 Mdot
.48385 .41812 Mdot
.81257 .48151 Mdot
.48035 .37656 Mdot
.49473 .60124 Mdot
.35087 .53669 Mdot
.4161 .40835 Mdot
.62385 .55311 Mdot
.40251 .40142 Mdot
.54208 .61829 Mdot
.44394 .38952 Mdot
.42393 .41094 Mdot
.43968 .33332 Mdot
.57198 .66471 Mdot
.51325 .83266 Mdot
.20896 .35997 Mdot
.72654 .6828 Mdot
.28849 .65214 Mdot
.65967 .5226 Mdot
.48258 .40034 Mdot
.67308 .38817 Mdot
.38585 .4558 Mdot
.44749 .40538 Mdot
.40895 .22657 Mdot
.43225 .41747 Mdot
.25308 .53804 Mdot
.44686 .46575 Mdot
.68829 .74151 Mdot
.4745 .65223 Mdot
.45883 .42399 Mdot
.25091 .34818 Mdot
.56226 .20581 Mdot
.73386 .34651 Mdot
.57346 .62776 Mdot
.62935 .56709 Mdot
.66931 .54797 Mdot
.5722 .67302 Mdot
.41423 .44647 Mdot
.2064 .45714 Mdot
.3856 .3815 Mdot
.42022 .74315 Mdot
.31822 .51389 Mdot
.6929 .37447 Mdot
.34607 .52611 Mdot
.19733 .32958 Mdot
.50743 .48631 Mdot
.58689 .68567 Mdot
.69797 .355 Mdot
.62416 .52382 Mdot
.41031 .74972 Mdot
.66464 .38992 Mdot
.44302 .35586 Mdot
.30427 .55512 Mdot
.55817 .20432 Mdot
.51978 .38877 Mdot
.86379 .4789 Mdot
.355 .5676 Mdot
.49442 .55584 Mdot
.57161 .63032 Mdot
.68347 .51931 Mdot
.45289 .43127 Mdot
.46567 .36857 Mdot
.32707 .52072 Mdot
.43815 .41146 Mdot
.43581 .53124 Mdot
.42609 .40933 Mdot
.68926 .51323 Mdot
.70672 .33549 Mdot
.56931 .67867 Mdot
.68906 .27903 Mdot
.34852 .58725 Mdot
.54503 .5439 Mdot
.62697 .53625 Mdot
.31824 .62396 Mdot
.55558 .61627 Mdot
.65574 .3562 Mdot
.63927 .56006 Mdot
.64254 .36371 Mdot
.42292 .34842 Mdot
.65247 .55581 Mdot
.66794 .35677 Mdot
.60391 .50886 Mdot
.44186 .35044 Mdot
.54381 .24465 Mdot
.55127 .65615 Mdot
.33503 .52261 Mdot
.4557 .4213 Mdot
.42847 .72338 Mdot
.44109 .44543 Mdot
.44555 .72102 Mdot
.42583 .74322 Mdot
.40284 .7557 Mdot
.60293 .68771 Mdot
.66721 .39554 Mdot
.32129 .68941 Mdot
.53306 .48723 Mdot
.32679 .5962 Mdot
.45573 .34167 Mdot
.58028 .8273 Mdot
.55603 .65964 Mdot
.44208 .35785 Mdot
.65353 .74354 Mdot
.5473 .65864 Mdot
.4505 .37265 Mdot
.58102 .65309 Mdot
.34458 .5593 Mdot
.55729 .50389 Mdot
.30451 .58549 Mdot
.43448 .36589 Mdot
.55135 .63931 Mdot
.63426 .56535 Mdot
.32179 .56802 Mdot
.46079 .40756 Mdot
.47951 .39352 Mdot
.41334 .74556 Mdot
.4185 .41588 Mdot
.61563 .80318 Mdot
.43426 .4018 Mdot
.6229 .52515 Mdot
.47729 .34056 Mdot
.53752 .197 Mdot
.67323 .44322 Mdot
.36563 .55026 Mdot
.42025 .75078 Mdot
.65729 .54769 Mdot
.60235 .47518 Mdot
.69041 .41192 Mdot
.47028 .40048 Mdot
.4138 .72906 Mdot
.50055 .55655 Mdot
.57859 .62233 Mdot
.5023 .39685 Mdot
.46532 .51093 Mdot
.63793 .55216 Mdot
.41446 .74769 Mdot
.46828 .45791 Mdot
.29441 .55901 Mdot
.42975 .37817 Mdot
.64847 .56039 Mdot
.29859 .55207 Mdot
.4934 .40906 Mdot
.79828 .42503 Mdot
.4264 .72468 Mdot
.55576 .65635 Mdot
.45582 .28919 Mdot
.48139 .37069 Mdot
.67146 .54842 Mdot
.35195 .55193 Mdot
.55644 .6257 Mdot
.31225 .54935 Mdot
.59566 .20986 Mdot
.31444 .65374 Mdot
.77015 .55021 Mdot
.70242 .37644 Mdot
.25953 .71774 Mdot
.74623 .65685 Mdot
.34235 .66217 Mdot
.66822 .30097 Mdot
.77987 .66248 Mdot
.62759 .55721 Mdot
.4343 .26296 Mdot
.66556 .54075 Mdot
.42067 .37307 Mdot
.64447 .53756 Mdot
.64748 .7935 Mdot
.43152 .4091 Mdot
.66427 .52263 Mdot
.79904 .48856 Mdot
.43698 .42524 Mdot
.34762 .53223 Mdot
.38567 .80162 Mdot
.2069 .54627 Mdot
.54059 .4392 Mdot
.66675 .51995 Mdot
.35909 .26713 Mdot
.43924 .42003 Mdot
.51029 .34997 Mdot
.3376 .55806 Mdot
.49568 .42598 Mdot
.69133 .35775 Mdot
.65106 .35149 Mdot
.46163 .23884 Mdot
.21392 .57079 Mdot
.50783 .32924 Mdot
.32745 .56808 Mdot
.27176 .28078 Mdot
.36991 .70364 Mdot
.41864 .71772 Mdot
.5313 .65795 Mdot
.51105 .8309 Mdot
.516 .43459 Mdot
.53588 .33207 Mdot
.44631 .54449 Mdot
.31488 .5758 Mdot
.74763 .61683 Mdot
.55703 .63024 Mdot
.23777 .34991 Mdot
.23577 .45588 Mdot
.47231 .36269 Mdot
.5873 .62281 Mdot
.37994 .37504 Mdot
.43955 .54142 Mdot
.53786 .23126 Mdot
.73164 .57031 Mdot
.43604 .35677 Mdot
.33208 .69462 Mdot
.44821 .39773 Mdot
.56 .21133 Mdot
.43795 .36266 Mdot
.31815 .54349 Mdot
.53606 .373 Mdot
.6165 .43912 Mdot
.18037 .43427 Mdot
.49016 .49262 Mdot
.67776 .39346 Mdot
.46903 .38496 Mdot
.46847 .36349 Mdot
.67812 .35902 Mdot
.31839 .55669 Mdot
.47119 .34987 Mdot
.75764 .34851 Mdot
.47803 .36731 Mdot
.55505 .61005 Mdot
.58117 .47751 Mdot
.23603 .57537 Mdot
.45223 .43491 Mdot
.29691 .55089 Mdot
.58222 .63577 Mdot
.52789 .65068 Mdot
.52569 .35996 Mdot
.56284 .66142 Mdot
.42868 .38663 Mdot
.57411 .48318 Mdot
.31559 .58559 Mdot
.37533 .42184 Mdot
.32197 .55117 Mdot
.33853 .23629 Mdot
.57857 .66126 Mdot
.40432 .72665 Mdot
.45718 .26776 Mdot
.55855 .64345 Mdot
.37746 .5968 Mdot
.51867 .43752 Mdot
.39753 .39353 Mdot
.28331 .62425 Mdot
.66159 .56284 Mdot
.39988 .74163 Mdot
.56173 .62277 Mdot
.47886 .37093 Mdot
.42598 .35253 Mdot
.57633 .61164 Mdot
.32282 .32719 Mdot
.73636 .40678 Mdot
.43648 .36944 Mdot
.31708 .54706 Mdot
.32747 .57739 Mdot
.49282 .38188 Mdot
.44891 .40923 Mdot
.62024 .53863 Mdot
.41268 .72759 Mdot
.40593 .75325 Mdot
.41491 .72158 Mdot
.68072 .55656 Mdot
.24183 .69323 Mdot
.55765 .67187 Mdot
.29229 .72642 Mdot
.58471 .76755 Mdot
.52034 .35373 Mdot
.66716 .55575 Mdot
.45815 .37151 Mdot
.41747 .36469 Mdot
.54983 .63559 Mdot
.19909 .59008 Mdot
.42684 .31833 Mdot
.351 .52422 Mdot
.56522 .60859 Mdot
.37148 .42419 Mdot
.56299 .70817 Mdot
.68069 .35093 Mdot
.49898 .48338 Mdot
.58535 .61957 Mdot
.30692 .5564 Mdot
.5813 .61381 Mdot
.4712 .36517 Mdot
.40972 .43036 Mdot
.31941 .58382 Mdot
.66101 .397 Mdot
.43692 .344 Mdot
.45007 .37477 Mdot
.57166 .17627 Mdot
.3663 .69971 Mdot
.61017 .61872 Mdot
.41359 .38613 Mdot
.40791 .34736 Mdot
.66045 .39933 Mdot
.47931 .36306 Mdot
.45766 .42975 Mdot
.41042 .64748 Mdot
.55247 .67676 Mdot
.65534 .33986 Mdot
.22148 .36829 Mdot
.35754 .55999 Mdot
.62734 .78926 Mdot
.42327 .73092 Mdot
.54801 .6789 Mdot
.5514 .51029 Mdot
.40242 .73862 Mdot
.61604 .74199 Mdot
.69642 .7054 Mdot
.40539 .72835 Mdot
.62095 .50805 Mdot
.42155 .47993 Mdot
.48271 .42315 Mdot
.445 .383 Mdot
.66003 .39229 Mdot
.3504 .56457 Mdot
.4798 .62123 Mdot
.6011 .58264 Mdot
.45794 .39405 Mdot
.35276 .5954 Mdot
.66378 .74697 Mdot
.4091 .74725 Mdot
.68132 .384 Mdot
.68651 .39281 Mdot
.44949 .39549 Mdot
.38122 .63997 Mdot
.32485 .56994 Mdot
.46078 .40735 Mdot
.48574 .40978 Mdot
.67465 .52578 Mdot
.30785 .54784 Mdot
.62666 .53332 Mdot
.42793 .73973 Mdot
.82877 .58817 Mdot
.59284 .17868 Mdot
.54415 .64776 Mdot
.74491 .64559 Mdot
.56907 .60179 Mdot
.7005 .59889 Mdot
.41 .7263 Mdot
.46054 .40119 Mdot
.35636 .58021 Mdot
.46344 .40845 Mdot
.46785 .35309 Mdot
.45421 .34851 Mdot
.50092 .32338 Mdot
.41808 .22305 Mdot
.67186 .38205 Mdot
.41976 .32951 Mdot
.61822 .562 Mdot
.68073 .74159 Mdot
.4116 .80694 Mdot
.47104 .37819 Mdot
.453 .39221 Mdot
.36236 .55135 Mdot
.41036 .36089 Mdot
.57139 .61775 Mdot
.35019 .5723 Mdot
.42617 .35687 Mdot
.69896 .46811 Mdot
.48485 .3693 Mdot
.75641 .63533 Mdot
.58139 .61343 Mdot
.49148 .48361 Mdot
.39576 .37035 Mdot
.40669 .72626 Mdot
.4 .73984 Mdot
.42841 .71892 Mdot
.58359 .62439 Mdot
.67449 .53039 Mdot
.62089 .58306 Mdot
.45019 .45901 Mdot
.42419 .38577 Mdot
.3962 .39078 Mdot
.68204 .55843 Mdot
.57872 .46092 Mdot
.27231 .66452 Mdot
.46202 .46551 Mdot
.64129 .57173 Mdot
.37642 .57657 Mdot
.16725 .49451 Mdot
.35451 .56174 Mdot
.69071 .32727 Mdot
.54327 .61925 Mdot
.6883 .35265 Mdot
.37994 .24222 Mdot
.31442 .58208 Mdot
.33519 .51917 Mdot
.66192 .52188 Mdot
.4673 .6031 Mdot
.13921 .65524 Mdot
.63937 .52257 Mdot
.69306 .31299 Mdot
.33293 .56108 Mdot
.45517 .31977 Mdot
.50158 .5587 Mdot
.46849 .59265 Mdot
.66155 .53279 Mdot
.47738 .398 Mdot
.37261 .6085 Mdot
.62102 .53624 Mdot
.50305 .37174 Mdot
.66526 .51638 Mdot
.57513 .65981 Mdot
.65243 .51897 Mdot
.37475 .56206 Mdot
.42042 .35163 Mdot
.10032 .57668 Mdot
.45457 .68412 Mdot
.46132 .41684 Mdot
.56269 .6077 Mdot
.81236 .43198 Mdot
.46169 .35576 Mdot
.69366 .35991 Mdot
.64723 .57181 Mdot
.77737 .47467 Mdot
.44474 .42164 Mdot
.65278 .53545 Mdot
.37354 .53518 Mdot
.68328 .57661 Mdot
.62597 .62545 Mdot
.40276 .75031 Mdot
.34734 .55467 Mdot
.43825 .73744 Mdot
.52707 .66142 Mdot
.44069 .33801 Mdot
.48701 .39839 Mdot
.33863 .53505 Mdot
.59145 .71494 Mdot
.45846 .32585 Mdot
.47532 .3982 Mdot
.6245 .52936 Mdot
.64197 .57896 Mdot
.46399 .77081 Mdot
.62601 .55754 Mdot
.40892 .34527 Mdot
.33447 .5355 Mdot
.42523 .37106 Mdot
.3535 .53449 Mdot
.45345 .34196 Mdot
.25503 .59604 Mdot
.35348 .56204 Mdot
.30795 .63812 Mdot
.42504 .42723 Mdot
.41251 .29454 Mdot
.46982 .35299 Mdot
.444 .35311 Mdot
.65677 .56966 Mdot
.66504 .37119 Mdot
.50618 .37925 Mdot
.55331 .52675 Mdot
.64676 .3855 Mdot
.3458 .46632 Mdot
.67748 .53064 Mdot
.64994 .38276 Mdot
.55495 .28329 Mdot
.41987 .75097 Mdot
.67701 .37342 Mdot
.45645 .80114 Mdot
.54521 .64599 Mdot
.31235 .58769 Mdot
.43414 .42472 Mdot
.79767 .64484 Mdot
.7355 .40257 Mdot
.41039 .74223 Mdot
.45306 .41855 Mdot
.45726 .36674 Mdot
.29439 .56676 Mdot
.22303 .30277 Mdot
.68591 .51297 Mdot
.43217 .35662 Mdot
.32901 .59328 Mdot
.2861 .24603 Mdot
.6601 .5125 Mdot
.68013 .37681 Mdot
.58777 .61592 Mdot
.28827 .53254 Mdot
.40011 .74744 Mdot
.58143 .6596 Mdot
.63557 .48067 Mdot
.37766 .2327 Mdot
.44303 .41807 Mdot
.65525 .56296 Mdot
.44376 .22594 Mdot
.41405 .45174 Mdot
.56718 .5981 Mdot
.2687 .54308 Mdot
.31528 .57485 Mdot
.57388 .61071 Mdot
.68059 .39322 Mdot
.31359 .58557 Mdot
.31719 .5572 Mdot
.5263 .6414 Mdot
.49672 .61821 Mdot
.49248 .55902 Mdot
.55597 .61239 Mdot
.43664 .61444 Mdot
.46983 .23142 Mdot
.41539 .7266 Mdot
.6822 .38384 Mdot
.60002 .20655 Mdot
.32508 .57266 Mdot
.5123 .83113 Mdot
.41871 .22548 Mdot
.44456 .35092 Mdot
.65725 .36554 Mdot
.61791 .75064 Mdot
.59688 .54725 Mdot
.53786 .65435 Mdot
.58691 .44088 Mdot
.695 .37469 Mdot
.49108 .39262 Mdot
.23618 .56542 Mdot
.43686 .43103 Mdot
.55135 .66001 Mdot
.43019 .55031 Mdot
.31204 .54357 Mdot
.52905 .66353 Mdot
.43917 .52434 Mdot
.41599 .36829 Mdot
.4687 .42078 Mdot
.62181 .23996 Mdot
.30479 .5506 Mdot
.39962 .74829 Mdot
.47 .40683 Mdot
.44755 .36611 Mdot
.44769 .33524 Mdot
.47703 .27359 Mdot
.37817 .65918 Mdot
.4327 .35426 Mdot
.68577 .53631 Mdot
.40139 .40557 Mdot
.46217 .42571 Mdot
.30079 .58371 Mdot
.51054 .19063 Mdot
.42981 .73373 Mdot
.44425 .37861 Mdot
.43712 .36996 Mdot
.54073 .66474 Mdot
.49643 .55808 Mdot
.46449 .59584 Mdot
.63603 .50991 Mdot
.64364 .30057 Mdot
.38698 .38997 Mdot
.35012 .54418 Mdot
.68511 .34747 Mdot
.4234 .3376 Mdot
.35904 .55086 Mdot
.40358 .42804 Mdot
.61853 .54134 Mdot
.41189 .72975 Mdot
.53735 .34459 Mdot
.67551 .36881 Mdot
.52875 .68256 Mdot
.32635 .75563 Mdot
.62273 .55492 Mdot
.42011 .39304 Mdot
.67749 .57349 Mdot
.63072 .54027 Mdot
.41422 .74406 Mdot
.48895 .44482 Mdot
.33895 .56469 Mdot
.31086 .54675 Mdot
.50476 .22632 Mdot
.69167 .53544 Mdot
.43418 .17079 Mdot
.57365 .66058 Mdot
.49646 .41183 Mdot
.39317 .78522 Mdot
.31894 .53872 Mdot
.60955 .22223 Mdot
.65076 .38579 Mdot
.53778 .65384 Mdot
.41997 .7561 Mdot
.35882 .5477 Mdot
.32538 .53195 Mdot
.45014 .34508 Mdot
.46511 .37992 Mdot
.68135 .30242 Mdot
.54958 .21106 Mdot
.57977 .65415 Mdot
.6853 .37228 Mdot
.64582 .50528 Mdot
.41543 .37634 Mdot
.33274 .58758 Mdot
.25596 .5287 Mdot
.48311 .3772 Mdot
.62141 .533 Mdot
.31991 .58013 Mdot
.68411 .36219 Mdot
.6554 .36104 Mdot
.44561 .35169 Mdot
.3247 .45751 Mdot
.56005 .64751 Mdot
.33897 .5318 Mdot
.39068 .51788 Mdot
.46772 .33361 Mdot
.46891 .38056 Mdot
.37805 .3626 Mdot
.57897 .66325 Mdot
.54059 .3539 Mdot
.68245 .39948 Mdot
.34324 .56822 Mdot
.46399 .41351 Mdot
.67907 .36695 Mdot
.49426 .29326 Mdot
.40543 .73334 Mdot
.6622 .51525 Mdot
.69322 .3625 Mdot
.66467 .36294 Mdot
.64501 .37502 Mdot
.49853 .83032 Mdot
.29018 .56059 Mdot
.21648 .36702 Mdot
.45796 .34619 Mdot
.47812 .23336 Mdot
.41065 .41345 Mdot
.58774 .64649 Mdot
.6343 .56794 Mdot
.47051 .35711 Mdot
.45103 .34459 Mdot
.24199 .57056 Mdot
.36589 .3895 Mdot
.42425 .4978 Mdot
.30407 .56265 Mdot
.4293 .28211 Mdot
.67296 .5502 Mdot
.29191 .22508 Mdot
.48797 .85409 Mdot
.38881 .36869 Mdot
.4776 .59455 Mdot
.34788 .57504 Mdot
.54395 .66123 Mdot
.46899 .58142 Mdot
.58989 .6712 Mdot
.34055 .57375 Mdot
.41858 .37221 Mdot
.29557 .72501 Mdot
.64387 .36506 Mdot
.47599 .37194 Mdot
.57721 .63665 Mdot
.47607 .37103 Mdot
.58762 .63216 Mdot
.28019 .54902 Mdot
.446 .62554 Mdot
.43231 .41607 Mdot
.45234 .32846 Mdot
.54458 .405 Mdot
.469 .37789 Mdot
.65662 .67629 Mdot
.32667 .55493 Mdot
.30427 .63095 Mdot
.49132 .37353 Mdot
.31478 .43803 Mdot
.48792 .38742 Mdot
.59253 .7179 Mdot
.48412 .40598 Mdot
.57287 .38381 Mdot
.49209 .39514 Mdot
.48228 .40228 Mdot
.55416 .6315 Mdot
.54216 .6639 Mdot
.37171 .53385 Mdot
.39782 .73754 Mdot
.68725 .74135 Mdot
.45264 .38225 Mdot
.66177 .56967 Mdot
.40544 .77933 Mdot
.66374 .367 Mdot
.33758 .57379 Mdot
.38467 .15743 Mdot
.58314 .64253 Mdot
.6626 .49386 Mdot
.62861 .67016 Mdot
.67745 .5089 Mdot
.69135 .5058 Mdot
.4001 .30417 Mdot
.68693 .37413 Mdot
.48945 .39176 Mdot
.33925 .42892 Mdot
.34764 .69924 Mdot
.5005 .36838 Mdot
.64475 .58817 Mdot
.37154 .43321 Mdot
.47073 .22903 Mdot
.63885 .38099 Mdot
.69026 .37754 Mdot
.55995 .62498 Mdot
.64546 .49687 Mdot
.39267 .42844 Mdot
.64933 .38046 Mdot
.62889 .56796 Mdot
.40754 .71857 Mdot
.72004 .35553 Mdot
.32848 .57114 Mdot
.54584 .43066 Mdot
.36164 .75053 Mdot
.58134 .64889 Mdot
.55358 .52166 Mdot
.31316 .60445 Mdot
.31029 .52215 Mdot
.40394 .72443 Mdot
.62381 .57286 Mdot
.32821 .59737 Mdot
.43255 .34579 Mdot
.51984 .39104 Mdot
.44925 .39905 Mdot
.65224 .38102 Mdot
.47927 .41862 Mdot
.62118 .56632 Mdot
.56845 .65599 Mdot
.64656 .5501 Mdot
.55815 .64996 Mdot
.28088 .70126 Mdot
.44647 .41136 Mdot
.46734 .38336 Mdot
.54598 .50563 Mdot
.33704 .52659 Mdot
.33621 .36382 Mdot
.62566 .57527 Mdot
.66964 .53333 Mdot
.4245 .36913 Mdot
.3639 .52725 Mdot
.6794 .33686 Mdot
.5028 .56489 Mdot
.48543 .40644 Mdot
.32781 .55396 Mdot
.42825 .37351 Mdot
.76223 .53185 Mdot
.44234 .6599 Mdot
.31272 .5472 Mdot
.17591 .44503 Mdot
.41649 .41471 Mdot
.38015 .46454 Mdot
.46032 .31187 Mdot
.61214 .33831 Mdot
.50001 .35549 Mdot
.3527 .57167 Mdot
.44403 .39424 Mdot
.34685 .54771 Mdot
.62779 .54602 Mdot
.5548 .66926 Mdot
.34361 .55311 Mdot
.4374 .43503 Mdot
.45149 .8402 Mdot
.57996 .64478 Mdot
.47575 .38833 Mdot
.55068 .62208 Mdot
.31797 .59485 Mdot
.31957 .53196 Mdot
.46881 .79174 Mdot
.59164 .68631 Mdot
.5801 .63866 Mdot
.4267 .38712 Mdot
.37924 .7275 Mdot
.42529 .37183 Mdot
.68036 .29811 Mdot
.49568 .37591 Mdot
.48218 .34336 Mdot
.27291 .73336 Mdot
.57844 .68346 Mdot
.40856 .16785 Mdot
.59513 .57688 Mdot
.48288 .82839 Mdot
.28746 .58646 Mdot
.63874 .38046 Mdot
.73578 .65203 Mdot
.42776 .73618 Mdot
.68285 .54081 Mdot
.4714 .35764 Mdot
.24752 .5884 Mdot
.56154 .60994 Mdot
.6635 .37716 Mdot
.43206 .41668 Mdot
.62152 .51805 Mdot
.43849 .80021 Mdot
.54762 .66053 Mdot
.32924 .57308 Mdot
.34232 .52516 Mdot
.23975 .31159 Mdot
.46072 .41487 Mdot
.46298 .3864 Mdot
.54364 .61802 Mdot
.40034 .43464 Mdot
.6502 .35853 Mdot
.78433 .51719 Mdot
.57579 .63099 Mdot
.44994 .68576 Mdot
.30439 .56729 Mdot
.45785 .36861 Mdot
.58726 .47329 Mdot
.54072 .79395 Mdot
.24361 .37211 Mdot
.66365 .39189 Mdot
.64543 .27321 Mdot
.35308 .57111 Mdot
.57539 .63757 Mdot
.49598 .25013 Mdot
.4572 .44373 Mdot
.45477 .36518 Mdot
.64033 .26473 Mdot
.49478 .56771 Mdot
.68166 .40935 Mdot
.45903 .31752 Mdot
.50998 .53933 Mdot
.42357 .36823 Mdot
.42538 .35299 Mdot
.38808 .36838 Mdot
.465 .42755 Mdot
.33462 .55038 Mdot
.22129 .53609 Mdot
.6486 .52923 Mdot
.30631 .29938 Mdot
.59103 .42772 Mdot
.44495 .42791 Mdot
.41755 .36977 Mdot
.202 .515 Mdot
.40891 .77421 Mdot
.32623 .55894 Mdot
.38568 .56817 Mdot
.55944 .67317 Mdot
.36711 .38038 Mdot
.6891 .54435 Mdot
.41244 .49115 Mdot
.63625 .5438 Mdot
.32833 .55271 Mdot
.67351 .53602 Mdot
.54642 .67214 Mdot
.65459 .56295 Mdot
.68279 .55299 Mdot
.59494 .63986 Mdot
.30076 .55354 Mdot
.48394 .39474 Mdot
.57867 .66045 Mdot
.63238 .24237 Mdot
.652 .37983 Mdot
.46649 .79317 Mdot
.44752 .31814 Mdot
.38784 .48435 Mdot
.7976 .42392 Mdot
.65738 .55235 Mdot
.42444 .66537 Mdot
.35341 .56177 Mdot
.68647 .34433 Mdot
.33983 .54848 Mdot
.37935 .25245 Mdot
.67322 .36049 Mdot
.4655 .79533 Mdot
.51025 .25302 Mdot
.59072 .50207 Mdot
.43063 .43995 Mdot
.28028 .61229 Mdot
.63543 .54626 Mdot
.55445 .60995 Mdot
.63832 .74798 Mdot
.407 .39629 Mdot
.33811 .66508 Mdot
.29154 .54431 Mdot
.41486 .75306 Mdot
.57472 .64225 Mdot
.58206 .59122 Mdot
.4569 .41464 Mdot
.58699 .49799 Mdot
.49312 .35718 Mdot
.44558 .26422 Mdot
.65517 .29481 Mdot
.28016 .53118 Mdot
.43016 .38026 Mdot
.63008 .51823 Mdot
.4279 .37681 Mdot
.45956 .47131 Mdot
.45563 .2308 Mdot
.42733 .32871 Mdot
.30628 .64708 Mdot
.78437 .45836 Mdot
.32368 .5859 Mdot
.40987 .34177 Mdot
.41587 .7362 Mdot
.41144 .3939 Mdot
.8527 .60234 Mdot
.67393 .37387 Mdot
.61679 .49792 Mdot
.43622 .43663 Mdot
.46712 .40761 Mdot
.30586 .48623 Mdot
.28415 .60421 Mdot
.42327 .75237 Mdot
.45331 .36069 Mdot
.63001 .27782 Mdot
.55364 .62698 Mdot
.49547 .4046 Mdot
.44544 .39054 Mdot
.64442 .22467 Mdot
.55036 .62669 Mdot
.66135 .55411 Mdot
.42224 .74867 Mdot
.64412 .50727 Mdot
.63761 .37261 Mdot
.45683 .58156 Mdot
.58628 .21271 Mdot
.44183 .66255 Mdot
.69645 .36459 Mdot
.46368 .43363 Mdot
.37192 .46434 Mdot
.47161 .41436 Mdot
.6879 .38289 Mdot
.56114 .61817 Mdot
.33516 .55272 Mdot
.55823 .38638 Mdot
.41961 .74295 Mdot
.49757 .35904 Mdot
.64322 .39045 Mdot
.34121 .55875 Mdot
.49317 .76844 Mdot
.34575 .57195 Mdot
.55677 .6398 Mdot
.56462 .67527 Mdot
.67055 .36479 Mdot
.33724 .54858 Mdot
.66689 .51142 Mdot
.59539 .58166 Mdot
.49574 .36994 Mdot
.60276 .59562 Mdot
.37239 .55496 Mdot
.33407 .52133 Mdot
.36244 .56954 Mdot
.44521 .41456 Mdot
.4878 .57629 Mdot
.44712 .44581 Mdot
.57965 .62941 Mdot
.68002 .52905 Mdot
.53244 .21551 Mdot
.33629 .42716 Mdot
.45003 .68271 Mdot
.50527 .37094 Mdot
.46814 .42318 Mdot
.44972 .3956 Mdot
.43475 .37676 Mdot
.77749 .52955 Mdot
.4461 .40971 Mdot
.55234 .64415 Mdot
.63655 .53297 Mdot
.45557 .41912 Mdot
.41563 .73298 Mdot
.54602 .47995 Mdot
.68692 .34885 Mdot
.57712 .38989 Mdot
.49139 .84584 Mdot
.33996 .5584 Mdot
.63915 .56229 Mdot
.67588 .51982 Mdot
.65119 .36382 Mdot
.57001 .66354 Mdot
.34922 .56549 Mdot
.59195 .33701 Mdot
.64677 .38773 Mdot
.444 .37737 Mdot
.5646 .49119 Mdot
.17107 .46716 Mdot
.46357 .43566 Mdot
.45323 .35074 Mdot
.40612 .75669 Mdot
.67829 .50655 Mdot
.79079 .6812 Mdot
.48587 .62579 Mdot
.66653 .3693 Mdot
.68499 .35744 Mdot
.35443 .57723 Mdot
.50074 .40044 Mdot
.56313 .6508 Mdot
.50798 .54918 Mdot
.80257 .40688 Mdot
.63163 .76826 Mdot
.68841 .60717 Mdot
.48272 .36521 Mdot
.25531 .49785 Mdot
.46895 .34255 Mdot
.29295 .55263 Mdot
.36309 .56257 Mdot
.32626 .56389 Mdot
.5557 .6309 Mdot
.34146 .23754 Mdot
.55231 .64683 Mdot
.49306 .84723 Mdot
.3266 .59104 Mdot
.64393 .45342 Mdot
.66998 .52688 Mdot
.46527 .45484 Mdot
.68584 .37697 Mdot
.65241 .59287 Mdot
.40374 .35035 Mdot
.37278 .64345 Mdot
.66701 .55575 Mdot
.31145 .53664 Mdot
.49958 .45067 Mdot
.70851 .73043 Mdot
.46021 .61039 Mdot
.76113 .37077 Mdot
.36673 .28334 Mdot
.67767 .35945 Mdot
.21393 .40766 Mdot
.64605 .36345 Mdot
.54105 .65708 Mdot
.40766 .39983 Mdot
.42703 .43113 Mdot
.43356 .35837 Mdot
.44306 .40886 Mdot
.56137 .62209 Mdot
.4848 .35913 Mdot
.53586 .19747 Mdot
.42299 .72534 Mdot
.65623 .45481 Mdot
.6665 .35268 Mdot
.59065 .64041 Mdot
.63284 .536 Mdot
.39873 .73119 Mdot
.68303 .27261 Mdot
.48217 .35892 Mdot
.47093 .35512 Mdot
.41725 .71921 Mdot
.40392 .4364 Mdot
.51237 .43729 Mdot
.64882 .53339 Mdot
.46203 .52977 Mdot
.68556 .39172 Mdot
.68765 .35247 Mdot
.58239 .61637 Mdot
.33976 .54824 Mdot
.65679 .39173 Mdot
.63752 .5 Mdot
.49241 .41131 Mdot
.44512 .32719 Mdot
.37268 .55416 Mdot
.4189 .22532 Mdot
.64819 .35173 Mdot
.51557 .44537 Mdot
.35413 .55066 Mdot
.29051 .54952 Mdot
.4555 .36034 Mdot
.50812 .36281 Mdot
.31243 .5302 Mdot
.66946 .34992 Mdot
.59174 .63769 Mdot
.62086 .46404 Mdot
.56353 .65903 Mdot
.34796 .55908 Mdot
.4288 .44433 Mdot
.30155 .55896 Mdot
.41588 .4121 Mdot
.17141 .32259 Mdot
.47149 .42434 Mdot
.33202 .62332 Mdot
.62023 .33487 Mdot
.66347 .51388 Mdot
.65623 .5096 Mdot
.41342 .73079 Mdot
.35666 .55851 Mdot
.42137 .34113 Mdot
.68875 .36329 Mdot
.47054 .82334 Mdot
.3706 .50766 Mdot
.66105 .56554 Mdot
.6877 .52155 Mdot
.56294 .61913 Mdot
.48845 .39442 Mdot
.45709 .3736 Mdot
.65609 .56166 Mdot
.80877 .4499 Mdot
.34487 .54171 Mdot
.46307 .38677 Mdot
.46201 .42651 Mdot
.64584 .52862 Mdot
.59044 .58017 Mdot
.30568 .60887 Mdot
.46519 .42697 Mdot
.52297 .25544 Mdot
.58686 .63544 Mdot
.43132 .39736 Mdot
.47887 .35259 Mdot
.65913 .37081 Mdot
.68553 .45376 Mdot
.46456 .23034 Mdot
.58484 .65848 Mdot
.40261 .75148 Mdot
.40912 .40765 Mdot
.66713 .52555 Mdot
.45357 .32014 Mdot
.77407 .6283 Mdot
.42588 .73111 Mdot
.45604 .40576 Mdot
.38883 .39139 Mdot
.34605 .52977 Mdot
.45957 .40632 Mdot
.2559 .57867 Mdot
.63595 .5159 Mdot
.45548 .40699 Mdot
.32635 .45015 Mdot
.56585 .61956 Mdot
.40299 .35291 Mdot
.69128 .36212 Mdot
.61697 .34214 Mdot
.34421 .75917 Mdot
.67189 .5663 Mdot
.65766 .35948 Mdot
.48136 .41647 Mdot
.6261 .52018 Mdot
.58732 .61512 Mdot
.34717 .65408 Mdot
.47524 .43079 Mdot
.57103 .65909 Mdot
.57233 .65423 Mdot
.67038 .36879 Mdot
.366 .17994 Mdot
.38831 .3928 Mdot
.47501 .38064 Mdot
.78349 .34451 Mdot
.31062 .59806 Mdot
.47801 .38286 Mdot
.48755 .39525 Mdot
.55064 .65518 Mdot
.49398 .26727 Mdot
.41026 .52301 Mdot
.79921 .48874 Mdot
.58797 .63487 Mdot
.60796 .55755 Mdot
.62514 .5328 Mdot
.66169 .35614 Mdot
.32465 .58449 Mdot
.69554 .37811 Mdot
.65558 .52164 Mdot
.44265 .35378 Mdot
.53409 .64458 Mdot
.27651 .35999 Mdot
.55165 .60966 Mdot
.62377 .51687 Mdot
.30269 .53487 Mdot
.38302 .78761 Mdot
.83122 .37363 Mdot
.3513 .74022 Mdot
.58946 .65478 Mdot
.66342 .3672 Mdot
.48894 .61321 Mdot
.46916 .42219 Mdot
.21469 .38894 Mdot
.47641 .37648 Mdot
.37159 .27398 Mdot
.63308 .56859 Mdot
.40795 .72072 Mdot
.40627 .39341 Mdot
.642 .27498 Mdot
.58936 .65277 Mdot
.57151 .61872 Mdot
.4396 .37881 Mdot
.55712 .6424 Mdot
.45895 .3803 Mdot
.641 .52722 Mdot
.37418 .18011 Mdot
.4804 .40895 Mdot
.40924 .351 Mdot
.552 .67751 Mdot
.46556 .79407 Mdot
.61074 .55885 Mdot
.26198 .49773 Mdot
.72364 .72299 Mdot
.56031 .64395 Mdot
.48547 .31754 Mdot
.65127 .55727 Mdot
.40327 .75618 Mdot
.67095 .48585 Mdot
.47032 .36894 Mdot
.4749 .3545 Mdot
.42719 .36344 Mdot
.46566 .42284 Mdot
.20438 .41207 Mdot
.49008 .45009 Mdot
.25053 .45897 Mdot
.46776 .35234 Mdot
.35305 .61175 Mdot
.55018 .63943 Mdot
.39357 .49572 Mdot
.66933 .41332 Mdot
.47512 .35323 Mdot
.28782 .60721 Mdot
.58962 .64605 Mdot
.51245 .84208 Mdot
.55493 .62305 Mdot
.65355 .548 Mdot
.53409 .65599 Mdot
.41979 .4183 Mdot
.32569 .5768 Mdot
.6348 .52277 Mdot
.27632 .67237 Mdot
.68067 .54605 Mdot
.46101 .41676 Mdot
.5918 .53399 Mdot
.66683 .51528 Mdot
.56505 .43198 Mdot
.32632 .57917 Mdot
.6169 .26805 Mdot
.30634 .59598 Mdot
.46341 .40153 Mdot
.4683 .39759 Mdot
.3977 .73171 Mdot
.54863 .66087 Mdot
.32409 .59357 Mdot
.56611 .17573 Mdot
.6519 .40135 Mdot
.3188 .56435 Mdot
.51293 .3812 Mdot
.48467 .58715 Mdot
.3312 .53402 Mdot
.62233 .30444 Mdot
.55277 .66073 Mdot
.34626 .58649 Mdot
.49373 .43796 Mdot
.53347 .32331 Mdot
.65825 .34804 Mdot
.61782 .54229 Mdot
.51707 .52049 Mdot
.62725 .52737 Mdot
.51981 .65347 Mdot
.69199 .51997 Mdot
.55074 .63118 Mdot
.26735 .61803 Mdot
.42966 .54394 Mdot
.5218 .66032 Mdot
.54394 .67321 Mdot
.65753 .52764 Mdot
.43563 .37437 Mdot
.61005 .4442 Mdot
.51108 .38774 Mdot
.41445 .43478 Mdot
.5861 .64413 Mdot
.35148 .57504 Mdot
.30403 .57381 Mdot
.30263 .61795 Mdot
.32535 .53008 Mdot
.63086 .53108 Mdot
.43573 .65427 Mdot
.36899 .26452 Mdot
.5537 .61779 Mdot
.59472 .67355 Mdot
.42334 .37354 Mdot
.6629 .52477 Mdot
.62645 .54826 Mdot
.56206 .65484 Mdot
.26769 .33514 Mdot
.39761 .37228 Mdot
.29805 .58028 Mdot
.32512 .59132 Mdot
.32693 .53674 Mdot
.36625 .54222 Mdot
.31045 .25477 Mdot
.55443 .6099 Mdot
.35242 .57035 Mdot
.44009 .3971 Mdot
.47909 .3646 Mdot
.40984 .75125 Mdot
.67577 .35191 Mdot
.40286 .393 Mdot
.4004 .38119 Mdot
.45658 .36126 Mdot
.66477 .51543 Mdot
.38301 .43359 Mdot
.42518 .73472 Mdot
.69038 .51907 Mdot
.68624 .54984 Mdot
.40315 .72833 Mdot
.37243 .50147 Mdot
.69736 .75102 Mdot
.43185 .35738 Mdot
.36524 .34345 Mdot
.66518 .52909 Mdot
.41878 .60792 Mdot
.5339 .34681 Mdot
.42909 .3878 Mdot
.63715 .43044 Mdot
.63877 .52525 Mdot
.3214 .51349 Mdot
.47101 .37496 Mdot
.4133 .72336 Mdot
.67855 .3461 Mdot
.50287 .42087 Mdot
.40635 .75715 Mdot
.32867 .55059 Mdot
.77852 .43154 Mdot
.31936 .59927 Mdot
.66605 .51311 Mdot
.40758 .34465 Mdot
.11985 .62747 Mdot
.63527 .54764 Mdot
.54362 .8181 Mdot
.434 .53527 Mdot
.4775 .41534 Mdot
.62682 .53415 Mdot
.31329 .51823 Mdot
.58675 .63637 Mdot
.53468 .51257 Mdot
.33207 .58756 Mdot
.40054 .72768 Mdot
.40204 .74641 Mdot
.64749 .52971 Mdot
.30897 .57021 Mdot
.49301 .3713 Mdot
.35787 .53769 Mdot
.52752 .64415 Mdot
.42339 .4112 Mdot
.68899 .74097 Mdot
.52017 .38945 Mdot
.3554 .55037 Mdot
.63454 .50028 Mdot
.66145 .39839 Mdot
.43364 .41596 Mdot
.60586 .80062 Mdot
.48852 .39797 Mdot
.55502 .61975 Mdot
.40861 .59806 Mdot
.2656 .3741 Mdot
.43747 .36452 Mdot
.42015 .37063 Mdot
.58682 .61938 Mdot
.43778 .36087 Mdot
.47558 .42837 Mdot
.56886 .5962 Mdot
.33391 .53096 Mdot
.45298 .39937 Mdot
.62132 .54894 Mdot
.36345 .30964 Mdot
.40625 .3755 Mdot
.27266 .64474 Mdot
.62924 .26958 Mdot
.41127 .58177 Mdot
.42055 .33964 Mdot
.63532 .23962 Mdot
.4699 .39274 Mdot
.43884 .41372 Mdot
.43063 .36611 Mdot
.24353 .50591 Mdot
.65782 .5237 Mdot
.63402 .57294 Mdot
.66956 .34296 Mdot
.63388 .27541 Mdot
.65578 .37025 Mdot
.59292 .63347 Mdot
.60007 .69313 Mdot
.42236 .72609 Mdot
.34237 .54791 Mdot
.42199 .35136 Mdot
.68357 .54451 Mdot
.46048 .36766 Mdot
.41248 .39388 Mdot
.64472 .51971 Mdot
.62821 .54035 Mdot
.69063 .54772 Mdot
.64276 .37692 Mdot
.33267 .55827 Mdot
.44454 .34828 Mdot
.64764 .38732 Mdot
.4941 .38238 Mdot
.48728 .59026 Mdot
.32973 .55915 Mdot
.35733 .53637 Mdot
.30493 .58284 Mdot
.4599 .34626 Mdot
.42629 .42385 Mdot
.55264 .64808 Mdot
.37245 .55833 Mdot
.556 .61473 Mdot
.62754 .53168 Mdot
.6557 .51089 Mdot
.47055 .36862 Mdot
.50677 .45063 Mdot
.67877 .35536 Mdot
.65688 .54949 Mdot
.42997 .72365 Mdot
.6713 .34288 Mdot
.45228 .41848 Mdot
.62844 .52735 Mdot
.69033 .35467 Mdot
.30023 .31741 Mdot
.7476 .70142 Mdot
.65123 .39565 Mdot
.43998 .37991 Mdot
.32005 .47556 Mdot
.50469 .24334 Mdot
.65825 .40439 Mdot
.54275 .62831 Mdot
.48586 .38701 Mdot
.81974 .45472 Mdot
.68982 .38941 Mdot
.42336 .22556 Mdot
.64933 .51757 Mdot
.43604 .27445 Mdot
.50352 .42156 Mdot
.25023 .3366 Mdot
.69268 .38646 Mdot
.34694 .56509 Mdot
.35629 .58338 Mdot
.44211 .37373 Mdot
.66262 .40965 Mdot
.52698 .63167 Mdot
.67583 .51894 Mdot
.67759 .55783 Mdot
.30753 .56525 Mdot
.44559 .6741 Mdot
.6218 .54429 Mdot
.41427 .33211 Mdot
.63589 .48979 Mdot
.37853 .34325 Mdot
.25741 .29848 Mdot
.27247 .68168 Mdot
.44123 .33141 Mdot
.66206 .39967 Mdot
.59633 .6336 Mdot
.55487 .64653 Mdot
.55735 .63254 Mdot
.64683 .51006 Mdot
.48276 .56801 Mdot
.65235 .56551 Mdot
.34341 .67259 Mdot
.67976 .36755 Mdot
.5964 .27207 Mdot
.41604 .35055 Mdot
.47594 .41641 Mdot
.49365 .41054 Mdot
.42662 .36213 Mdot
.46905 .39152 Mdot
.58052 .65088 Mdot
.66743 .50692 Mdot
.7821 .47792 Mdot
.32031 .54437 Mdot
.48796 .75368 Mdot
.6705 .52727 Mdot
.41536 .75457 Mdot
.66823 .3832 Mdot
.58557 .21613 Mdot
.60378 .55747 Mdot
.67293 .53548 Mdot
.47766 .43122 Mdot
.35873 .56588 Mdot
.48707 .27763 Mdot
.47551 .39805 Mdot
.65752 .55041 Mdot
.65283 .49078 Mdot
.22326 .39769 Mdot
.39619 .33274 Mdot
.68658 .33227 Mdot
.48285 .58793 Mdot
.69036 .39354 Mdot
.49973 .35034 Mdot
.41831 .61252 Mdot
.65459 .52366 Mdot
.64958 .5445 Mdot
.65178 .39882 Mdot
.39927 .47709 Mdot
.31612 .57935 Mdot
.40972 .7198 Mdot
.54357 .63147 Mdot
.47483 .40629 Mdot
.64167 .51155 Mdot
.36007 .38582 Mdot
.56135 .49672 Mdot
.5696 .62794 Mdot
.68897 .51702 Mdot
.48751 .38459 Mdot
.44029 .36864 Mdot
.67427 .35886 Mdot
.71372 .40893 Mdot
.50996 .39937 Mdot
.48371 .82856 Mdot
.44598 .61145 Mdot
.48923 .49533 Mdot
.45473 .36567 Mdot
.30621 .55073 Mdot
.40948 .72606 Mdot
.6815 .38527 Mdot
.49278 .38518 Mdot
.73044 .72795 Mdot
.37166 .5751 Mdot
.57859 .64446 Mdot
.40979 .72461 Mdot
.48888 .55747 Mdot
.48857 .4005 Mdot
.47619 .37644 Mdot
.44436 .41217 Mdot
.74194 .72254 Mdot
.63084 .57026 Mdot
.3679 .56139 Mdot
.66165 .39138 Mdot
.35107 .52743 Mdot
.64901 .57073 Mdot
.5378 .47522 Mdot
.45137 .4214 Mdot
.29777 .57511 Mdot
.34546 .56907 Mdot
.56433 .61874 Mdot
.58268 .65789 Mdot
.63402 .5814 Mdot
.47611 .42021 Mdot
.41881 .72229 Mdot
.34423 .58539 Mdot
.66459 .50099 Mdot
.67496 .35996 Mdot
.57132 .66956 Mdot
.46582 .35058 Mdot
.65106 .52827 Mdot
.46972 .33983 Mdot
.34932 .53448 Mdot
.67251 .53364 Mdot
.41447 .75686 Mdot
.6804 .35442 Mdot
.47094 .35196 Mdot
.78934 .43232 Mdot
.40813 .72323 Mdot
.43701 .43215 Mdot
.3466 .4772 Mdot
.6494 .41393 Mdot
.27249 .66907 Mdot
.63552 .56512 Mdot
.42098 .73293 Mdot
.36404 .56347 Mdot
.51677 .30481 Mdot
.64385 .54306 Mdot
.26874 .52534 Mdot
.63319 .44457 Mdot
.43979 .35275 Mdot
.31492 .56674 Mdot
.71023 .36512 Mdot
.51353 .83438 Mdot
.52785 .24504 Mdot
.45943 .3904 Mdot
.62687 .52768 Mdot
.68712 .35152 Mdot
.56078 .61489 Mdot
.27517 .64497 Mdot
.25317 .30968 Mdot
.69066 .52394 Mdot
.44105 .34589 Mdot
.34716 .58261 Mdot
.56569 .65362 Mdot
.28641 .71648 Mdot
.63388 .50286 Mdot
.62527 .5617 Mdot
.4437 .42012 Mdot
.6656 .393 Mdot
.81363 .4766 Mdot
.62823 .5711 Mdot
.64783 .50633 Mdot
.47713 .7627 Mdot
.64267 .36248 Mdot
.44103 .39314 Mdot
.30192 .61791 Mdot
.49152 .41104 Mdot
.4948 .82085 Mdot
.42098 .72953 Mdot
.32345 .54262 Mdot
.47747 .36906 Mdot
.78347 .46209 Mdot
.63564 .54143 Mdot
.47701 .59385 Mdot
.51444 .61616 Mdot
.57433 .66224 Mdot
.64077 .51337 Mdot
.46536 .37314 Mdot
.5674 .67552 Mdot
.67562 .35497 Mdot
.46552 .42695 Mdot
.421 .41851 Mdot
.30198 .5279 Mdot
.53073 .64353 Mdot
.36778 .31251 Mdot
.5262 .65321 Mdot
.58051 .6135 Mdot
.28924 .55271 Mdot
.44299 .37498 Mdot
.66281 .54521 Mdot
.61864 .5289 Mdot
.48669 .35924 Mdot
.42127 .60561 Mdot
.31485 .57593 Mdot
.64491 .47301 Mdot
.79082 .6766 Mdot
.38533 .38477 Mdot
.4304 .72809 Mdot
.40176 .27595 Mdot
.57957 .62096 Mdot
.44542 .3543 Mdot
.34819 .54544 Mdot
.65763 .50347 Mdot
.62041 .54238 Mdot
.47702 .43537 Mdot
.56459 .65639 Mdot
.69228 .35328 Mdot
.62765 .55642 Mdot
.55739 .50239 Mdot
.45649 .40982 Mdot
.33571 .66457 Mdot
.63193 .55917 Mdot
.40551 .82047 Mdot
.78242 .46917 Mdot
.31172 .55068 Mdot
.41518 .38589 Mdot
.35714 .52501 Mdot
.65843 .38903 Mdot
.67706 .48995 Mdot
.5632 .65767 Mdot
.52482 .44888 Mdot
.62932 .20818 Mdot
.66185 .5216 Mdot
.33284 .55133 Mdot
.45174 .34744 Mdot
.5359 .41628 Mdot
.48469 .40574 Mdot
.51755 .28256 Mdot
.70185 .32268 Mdot
.54854 .67352 Mdot
.5683 .61542 Mdot
.41621 .36846 Mdot
.64607 .36615 Mdot
.61542 .55151 Mdot
.64711 .51958 Mdot
.29263 .21904 Mdot
.40874 .75852 Mdot
.67835 .30906 Mdot
.46234 .34751 Mdot
.6712 .50464 Mdot
.33645 .41739 Mdot
.5437 .61811 Mdot
.49989 .38226 Mdot
.68268 .52009 Mdot
.53328 .78703 Mdot
.49127 .57947 Mdot
.45715 .40151 Mdot
.40063 .43567 Mdot
.54851 .62467 Mdot
.48803 .61486 Mdot
.65526 .56393 Mdot
.49698 .38974 Mdot
.51973 .62726 Mdot
.46077 .78469 Mdot
.60007 .19484 Mdot
.33231 .55872 Mdot
.63929 .49622 Mdot
.57645 .65971 Mdot
.37908 .41369 Mdot
.66887 .35141 Mdot
.64093 .50556 Mdot
.6821 .53176 Mdot
.41972 .40226 Mdot
.40301 .37929 Mdot
.38598 .36019 Mdot
.31932 .55623 Mdot
.54713 .64968 Mdot
.41087 .37134 Mdot
.45179 .65456 Mdot
.43037 .35524 Mdot
.54989 .65212 Mdot
.0928 .50146 Mdot
.4613 .43807 Mdot
.48084 .38924 Mdot
.5937 .37443 Mdot
.31118 .58156 Mdot
.33788 .52804 Mdot
.44301 .64225 Mdot
.46334 .3478 Mdot
.60119 .4809 Mdot
.33585 .55634 Mdot
.31651 .57579 Mdot
.62537 .46685 Mdot
.42492 .40779 Mdot
.52367 .68153 Mdot
.56183 .65225 Mdot
.57661 .66125 Mdot
.34876 .53073 Mdot
.46928 .45331 Mdot
.59054 .61891 Mdot
.19374 .43655 Mdot
.6739 .52919 Mdot
.41794 .61307 Mdot
.35775 .54186 Mdot
.60563 .46268 Mdot
.54675 .65953 Mdot
.45003 .8556 Mdot
.5535 .34261 Mdot
.48662 .35186 Mdot
.43861 .36891 Mdot
.66081 .36586 Mdot
.53014 .37243 Mdot
.40417 .75264 Mdot
.55574 .64073 Mdot
.76164 .55383 Mdot
.3256 .56455 Mdot
.48227 .39489 Mdot
.54048 .21474 Mdot
.30192 .71798 Mdot
.31803 .64318 Mdot
.32741 .58601 Mdot
.32224 .57064 Mdot
.66961 .55476 Mdot
.67503 .52378 Mdot
.44502 .40102 Mdot
.55348 .63423 Mdot
.34589 .58895 Mdot
.54021 .64494 Mdot
.65468 .52221 Mdot
.67046 .53557 Mdot
.42634 .73621 Mdot
.43808 .45512 Mdot
.65247 .51355 Mdot
.48033 .77866 Mdot
.45287 .64946 Mdot
.33172 .51152 Mdot
.82266 .36705 Mdot
.28202 .71569 Mdot
.59693 .36534 Mdot
.67631 .34517 Mdot
.38783 .73835 Mdot
.54555 .66323 Mdot
.41773 .36721 Mdot
.46762 .36022 Mdot
.40827 .74696 Mdot
.56358 .66533 Mdot
.66229 .38118 Mdot
.54675 .66058 Mdot
.68195 .38109 Mdot
.62862 .57483 Mdot
.40507 .38012 Mdot
.48539 .4137 Mdot
.57915 .634 Mdot
.66244 .55507 Mdot
.66545 .51351 Mdot
.66562 .3462 Mdot
.59002 .22246 Mdot
.64807 .52818 Mdot
.35788 .5412 Mdot
.33475 .32663 Mdot
.40288 .74665 Mdot
.47088 .37582 Mdot
.56627 .21016 Mdot
.22716 .38276 Mdot
.43932 .35107 Mdot
.40966 .72406 Mdot
.313 .20157 Mdot
.40636 .39648 Mdot
.27125 .25736 Mdot
.42358 .7377 Mdot
.30136 .56227 Mdot
.64668 .55863 Mdot
.39979 .74958 Mdot
.383 .4308 Mdot
.7117 .33207 Mdot
.4253 .33099 Mdot
.32579 .58952 Mdot
.29701 .5616 Mdot
.43907 .54088 Mdot
.49991 .82011 Mdot
.6733 .39389 Mdot
.66696 .37696 Mdot
.64279 .54073 Mdot
.56676 .71263 Mdot
.47445 .3344 Mdot
.66497 .37507 Mdot
.78181 .5566 Mdot
.42422 .37511 Mdot
.67259 .29304 Mdot
.63094 .4305 Mdot
.30545 .55485 Mdot
.39909 .50227 Mdot
.63902 .54184 Mdot
.33255 .55194 Mdot
.51001 .49668 Mdot
.49388 .40885 Mdot
.32775 .56103 Mdot
.54798 .6535 Mdot
.63459 .72128 Mdot
.32918 .52713 Mdot
.53905 .50996 Mdot
.56434 .65003 Mdot
.65319 .41404 Mdot
.56832 .29321 Mdot
.845 .64209 Mdot
.55444 .63934 Mdot
.65352 .55497 Mdot
.65624 .51228 Mdot
.64365 .52831 Mdot
.33026 .5885 Mdot
.62855 .54556 Mdot
.32315 .54687 Mdot
.60011 .5748 Mdot
.62074 .23206 Mdot
.67311 .36375 Mdot
.60933 .63199 Mdot
.33821 .57079 Mdot
.37089 .6791 Mdot
.78228 .32122 Mdot
.43915 .38544 Mdot
.52122 .64632 Mdot
.66136 .401 Mdot
.44376 .69688 Mdot
.65854 .3713 Mdot
.651 .55791 Mdot
.41695 .6148 Mdot
.45844 .38151 Mdot
.25197 .56464 Mdot
.69066 .3653 Mdot
.32946 .58724 Mdot
.45125 .43138 Mdot
.6303 .58442 Mdot
.65559 .36397 Mdot
.67714 .34644 Mdot
.46984 .38887 Mdot
.30749 .54177 Mdot
.66817 .54113 Mdot
.54576 .66643 Mdot
.70083 .39041 Mdot
.42504 .45764 Mdot
.43515 .36993 Mdot
.49301 .42243 Mdot
.46595 .60053 Mdot
.81818 .47006 Mdot
.56209 .64444 Mdot
.50154 .23853 Mdot
.66236 .51673 Mdot
.52705 .25003 Mdot
.37099 .70551 Mdot
.60985 .60661 Mdot
.422 .73038 Mdot
.42055 .728 Mdot
.46109 .39726 Mdot
.8173 .50443 Mdot
.31737 .63116 Mdot
.54718 .60669 Mdot
.40184 .73968 Mdot
.6662 .5139 Mdot
.37177 .56727 Mdot
.42429 .49422 Mdot
.41342 .42204 Mdot
.58038 .66135 Mdot
.64981 .52293 Mdot
.77551 .6267 Mdot
.67843 .36907 Mdot
.42243 .65379 Mdot
.45597 .42021 Mdot
.46495 .38421 Mdot
.57148 .64089 Mdot
.55348 .64815 Mdot
.31024 .65639 Mdot
.44291 .55629 Mdot
.65187 .74905 Mdot
.53115 .68576 Mdot
.78893 .60926 Mdot
.29333 .60269 Mdot
.35325 .54705 Mdot
.42634 .74248 Mdot
.59039 .62174 Mdot
.47878 .38046 Mdot
.30185 .56601 Mdot
.32223 .64097 Mdot
.29075 .53828 Mdot
.66159 .29125 Mdot
.61239 .46667 Mdot
.46005 .42235 Mdot
.3618 .56002 Mdot
.33094 .55418 Mdot
.36366 .53299 Mdot
.40355 .72881 Mdot
.45305 .36296 Mdot
.43555 .3765 Mdot
.40856 .40229 Mdot
.5295 .42684 Mdot
.45934 .40738 Mdot
.37543 .70755 Mdot
.45333 .68597 Mdot
.72726 .48836 Mdot
.44765 .34447 Mdot
.56638 .662 Mdot
.42344 .34991 Mdot
.64882 .36199 Mdot
.44605 .34315 Mdot
.69109 .30155 Mdot
.56264 .63307 Mdot
.41891 .47914 Mdot
.66781 .47777 Mdot
.45428 .42176 Mdot
.69581 .36344 Mdot
.81816 .47526 Mdot
.52405 .21311 Mdot
.47779 .76585 Mdot
.35781 .54055 Mdot
.64277 .5794 Mdot
.53298 .62497 Mdot
.66191 .54443 Mdot
.49662 .36849 Mdot
.42876 .72748 Mdot
.24977 .70761 Mdot
.59107 .4629 Mdot
.47915 .37759 Mdot
.47422 .45722 Mdot
.31356 .54288 Mdot
.63372 .54292 Mdot
.27869 .5665 Mdot
.44118 .41388 Mdot
.65508 .38874 Mdot
.65038 .38697 Mdot
.46862 .5074 Mdot
.75474 .62474 Mdot
.51095 .29397 Mdot
.56951 .64177 Mdot
.62023 .53932 Mdot
.6928 .38551 Mdot
.28634 .62467 Mdot
.53293 .62244 Mdot
.57949 .62108 Mdot
.53158 .64327 Mdot
.46726 .41808 Mdot
.42194 .74652 Mdot
.76942 .58988 Mdot
.39825 .73359 Mdot
.44998 .42531 Mdot
.68119 .53823 Mdot
.39933 .74987 Mdot
.65822 .3669 Mdot
.58183 .61639 Mdot
.66724 .51952 Mdot
.46632 .40061 Mdot
.33753 .55994 Mdot
.50871 .22827 Mdot
.75142 .34098 Mdot
.61401 .49518 Mdot
.61173 .49731 Mdot
.30992 .59057 Mdot
.59889 .81635 Mdot
.60206 .59544 Mdot
.26286 .33932 Mdot
.7075 .34544 Mdot
.48676 .35851 Mdot
.3988 .18698 Mdot
.64982 .56542 Mdot
.63263 .52583 Mdot
.45364 .40466 Mdot
.64689 .49775 Mdot
.4836 .39874 Mdot
.66377 .56168 Mdot
.56529 .80275 Mdot
.42634 .43627 Mdot
.63213 .52832 Mdot
.48424 .33968 Mdot
.43574 .42095 Mdot
.31094 .54394 Mdot
.64586 .50362 Mdot
.48355 .34833 Mdot
.23436 .70225 Mdot
.57115 .62191 Mdot
.4018 .73121 Mdot
.59566 .68327 Mdot
.53411 .65327 Mdot
.31386 .55908 Mdot
.4046 .3939 Mdot
.67706 .3571 Mdot
.34527 .56231 Mdot
.64963 .5817 Mdot
.69075 .3736 Mdot
.43707 .65575 Mdot
.35485 .53798 Mdot
.40932 .74969 Mdot
.68355 .35712 Mdot
.42233 .33204 Mdot
.6392 .5199 Mdot
.78967 .38284 Mdot
.39856 .73435 Mdot
.45799 .37409 Mdot
.62104 .51173 Mdot
.54557 .65998 Mdot
.44679 .39324 Mdot
.62686 .52423 Mdot
.40583 .72607 Mdot
.43487 .42972 Mdot
.43809 .43168 Mdot
.44657 .49144 Mdot
.38862 .61428 Mdot
.67085 .36028 Mdot
.29101 .55041 Mdot
.44065 .40034 Mdot
.64608 .3646 Mdot
.6591 .63234 Mdot
.43187 .33811 Mdot
.34964 .52316 Mdot
.53465 .43757 Mdot
.67696 .52545 Mdot
.55847 .61399 Mdot
.623 .51738 Mdot
.68153 .34646 Mdot
.60238 .16923 Mdot
.41696 .75235 Mdot
.45304 .45998 Mdot
.49448 .40997 Mdot
.68462 .50388 Mdot
.32662 .55657 Mdot
.62812 .75597 Mdot
.46787 .35003 Mdot
.49683 .44102 Mdot
.47166 .38236 Mdot
.77888 .47006 Mdot
.31667 .57825 Mdot
.47201 .3788 Mdot
.48032 .46077 Mdot
.43171 .32711 Mdot
.69678 .36117 Mdot
.59058 .28076 Mdot
.4247 .35087 Mdot
.18449 .71569 Mdot
.41894 .71942 Mdot
.64376 .5214 Mdot
.52526 .54876 Mdot
.72755 .56832 Mdot
.26361 .28721 Mdot
.32078 .55112 Mdot
.43316 .28975 Mdot
.66571 .54254 Mdot
.49808 .21116 Mdot
.55912 .83519 Mdot
.43813 .42315 Mdot
.48612 .3806 Mdot
.65099 .55788 Mdot
.66691 .50312 Mdot
.42514 .7249 Mdot
.46407 .34201 Mdot
.48927 .44473 Mdot
.6587 .49531 Mdot
.46756 .40715 Mdot
.21021 .48337 Mdot
.53211 .66374 Mdot
.34327 .52887 Mdot
.56042 .61496 Mdot
.58106 .62639 Mdot
.32828 .27807 Mdot
.44577 .61088 Mdot
.55099 .65092 Mdot
.57167 .59981 Mdot
.70005 .30115 Mdot
.52928 .44817 Mdot
.69691 .37359 Mdot
.72219 .67746 Mdot
.64342 .53549 Mdot
.4525 .36142 Mdot
.3418 .58388 Mdot
.27257 .30657 Mdot
.60462 .73294 Mdot
.40954 .63133 Mdot
.43677 .38393 Mdot
.63649 .53757 Mdot
.40354 .72628 Mdot
.42196 .43298 Mdot
.51636 .2492 Mdot
.46153 .38692 Mdot
.67433 .51669 Mdot
.34478 .27017 Mdot
.26129 .55912 Mdot
.52535 .68034 Mdot
.36332 .51442 Mdot
.41401 .35859 Mdot
.344 .53749 Mdot
.57119 .66017 Mdot
.64322 .37492 Mdot
.66458 .36729 Mdot
.46542 .4243 Mdot
.42951 .54491 Mdot
.7088 .39423 Mdot
.43648 .42002 Mdot
.42136 .40551 Mdot
.42242 .73391 Mdot
.42174 .40703 Mdot
.49556 .39785 Mdot
.41644 .36147 Mdot
.4522 .33552 Mdot
.58198 .61421 Mdot
.33458 .48689 Mdot
.43598 .34287 Mdot
.38435 .38963 Mdot
.56381 .67355 Mdot
.37558 .36455 Mdot
.55438 .62424 Mdot
.70076 .72321 Mdot
.54639 .63196 Mdot
.66643 .36618 Mdot
.61259 .54352 Mdot
.41284 .29449 Mdot
.3436 .59007 Mdot
.58475 .65512 Mdot
.67743 .38004 Mdot
.55559 .63636 Mdot
.62034 .56063 Mdot
.80648 .3648 Mdot
.28938 .56955 Mdot
.49049 .58836 Mdot
.58377 .3761 Mdot
.33353 .66396 Mdot
.67684 .53311 Mdot
.30804 .56438 Mdot
.25643 .5769 Mdot
.41428 .36983 Mdot
.67159 .35583 Mdot
.4617 .39539 Mdot
.57778 .61337 Mdot
.63906 .53549 Mdot
.59196 .53802 Mdot
.66932 .36023 Mdot
.67839 .22267 Mdot
.68154 .54705 Mdot
.40529 .42889 Mdot
.56292 .67464 Mdot
.81172 .35537 Mdot
.54786 .62857 Mdot
.61473 .22803 Mdot
.38275 .56786 Mdot
.3587 .25766 Mdot
.32721 .57371 Mdot
.28564 .63893 Mdot
.65635 .80512 Mdot
.56393 .82515 Mdot
.34673 .55573 Mdot
.65116 .47144 Mdot
.46143 .41457 Mdot
.42617 .35919 Mdot
.40079 .34274 Mdot
.33844 .50856 Mdot
.44332 .40734 Mdot
.40511 .7519 Mdot
.45151 .61242 Mdot
.7961 .51087 Mdot
.62645 .57824 Mdot
.48464 .39969 Mdot
.58553 .64451 Mdot
.56376 .60722 Mdot
.3975 .74444 Mdot
.52834 .65009 Mdot
.43105 .41513 Mdot
.33514 .57255 Mdot
.60043 .45045 Mdot
.65452 .38204 Mdot
.40951 .79082 Mdot
.70626 .36942 Mdot
.60614 .57295 Mdot
.38955 .36571 Mdot
.67096 .53533 Mdot
.49786 .15101 Mdot
.42074 .36618 Mdot
.33696 .5539 Mdot
.45358 .4293 Mdot
.41508 .36146 Mdot
.4346 .34713 Mdot
.62415 .52899 Mdot
.52374 .55445 Mdot
.46937 .40504 Mdot
.5587 .65883 Mdot
.64469 .4618 Mdot
.40235 .39459 Mdot
.74358 .58286 Mdot
.64747 .29337 Mdot
.34748 .66815 Mdot
.34455 .51029 Mdot
.64727 .55197 Mdot
.32461 .56734 Mdot
.354 .50512 Mdot
.31384 .55884 Mdot
.7602 .56971 Mdot
.45265 .27014 Mdot
.24404 .2831 Mdot
.32759 .39923 Mdot
.27734 .31209 Mdot
.30028 .58281 Mdot
.67466 .64312 Mdot
.3503 .54739 Mdot
.31706 .55411 Mdot
.13732 .37861 Mdot
.35571 .55823 Mdot
.46925 .3673 Mdot
.44359 .44251 Mdot
.34389 .74611 Mdot
.69181 .29277 Mdot
.44588 .34395 Mdot
.44362 .40431 Mdot
.66222 .39662 Mdot
.49761 .45819 Mdot
.3952 .73149 Mdot
.42763 .63447 Mdot
.41171 .70683 Mdot
.46921 .38961 Mdot
.44961 .40755 Mdot
.50022 .41744 Mdot
.65647 .80963 Mdot
.2663 .30511 Mdot
.29974 .57023 Mdot
.3772 .43301 Mdot
.46179 .80427 Mdot
.48006 .42606 Mdot
.47112 .42954 Mdot
.41716 .41471 Mdot
.66395 .54441 Mdot
.36928 .57339 Mdot
.50726 .42655 Mdot
.33411 .69556 Mdot
.45384 .41883 Mdot
.61443 .59191 Mdot
.63619 .41343 Mdot
.46558 .37202 Mdot
.35497 .52756 Mdot
.4283 .371 Mdot
.36183 .54907 Mdot
.34465 .5301 Mdot
.44718 .45754 Mdot
.76587 .59983 Mdot
.37691 .54822 Mdot
.44147 .42807 Mdot
.66115 .55345 Mdot
.51672 .83232 Mdot
.45908 .37241 Mdot
.67142 .39288 Mdot
.44398 .3542 Mdot
.6942 .35688 Mdot
.42224 .41586 Mdot
.39993 .72917 Mdot
.25432 .38804 Mdot
.64849 .54343 Mdot
.70555 .38344 Mdot
.6634 .49886 Mdot
.49797 .48252 Mdot
.30896 .53591 Mdot
.39671 .72606 Mdot
.22885 .33486 Mdot
.4225 .73555 Mdot
.48495 .23428 Mdot
.60054 .71597 Mdot
.58065 .63109 Mdot
.36617 .54416 Mdot
.43139 .26101 Mdot
.74089 .6095 Mdot
.69012 .54563 Mdot
.68708 .5488 Mdot
.53074 .16467 Mdot
.3691 .18115 Mdot
.47313 .40275 Mdot
.82426 .43231 Mdot
.25721 .4415 Mdot
.44998 .32522 Mdot
.4804 .32623 Mdot
.68188 .52549 Mdot
.41295 .35882 Mdot
.53047 .50868 Mdot
.65796 .52676 Mdot
.67406 .3781 Mdot
.32624 .5413 Mdot
.67554 .34876 Mdot
.6679 .72443 Mdot
.45709 .66694 Mdot
.65826 .51765 Mdot
.44123 .33624 Mdot
.4769 .40903 Mdot
.36578 .55486 Mdot
.24364 .57887 Mdot
.3344 .53028 Mdot
.68347 .39044 Mdot
.65576 .53585 Mdot
.24939 .33315 Mdot
.45073 .35137 Mdot
.34362 .57232 Mdot
.69451 .50551 Mdot
.44028 .36735 Mdot
.58067 .64045 Mdot
.43607 .38372 Mdot
.35179 .56089 Mdot
.4216 .40773 Mdot
.33304 .57232 Mdot
.65998 .5601 Mdot
.49068 .39947 Mdot
.44888 .40511 Mdot
.46342 .23021 Mdot
.66168 .38182 Mdot
.30379 .54148 Mdot
.52466 .51404 Mdot
.49008 .41306 Mdot
.51747 .25165 Mdot
.40472 .38608 Mdot
.43519 .30137 Mdot
.50776 .36308 Mdot
.40844 .75192 Mdot
.50162 .38266 Mdot
.45941 .37389 Mdot
.2754 .51216 Mdot
.33231 .44967 Mdot
.40691 .49801 Mdot
.58782 .65312 Mdot
.35291 .52713 Mdot
.65189 .51118 Mdot
.66145 .50569 Mdot
.63055 .55304 Mdot
.67609 .27752 Mdot
.42328 .4584 Mdot
.4568 .38117 Mdot
.54831 .67401 Mdot
.66805 .37436 Mdot
.33516 .58357 Mdot
.67066 .36838 Mdot
.42747 .62999 Mdot
.6891 .3829 Mdot
.40751 .75374 Mdot
.7831 .46875 Mdot
.19726 .45667 Mdot
.68145 .38732 Mdot
.33645 .52974 Mdot
.60267 .47471 Mdot
.4849 .35491 Mdot
.50762 .78769 Mdot
.65562 .38959 Mdot
.56277 .17368 Mdot
.43529 .43462 Mdot
.52797 .5186 Mdot
.56028 .62235 Mdot
.67886 .35039 Mdot
.53013 .6413 Mdot
.42629 .36841 Mdot
.27024 .66598 Mdot
.33713 .5493 Mdot
.52523 .66076 Mdot
.49696 .36125 Mdot
.6762 .3492 Mdot
.65435 .51569 Mdot
.55905 .37162 Mdot
.56925 .66612 Mdot
.50944 .22071 Mdot
.52753 .24513 Mdot
.65697 .53397 Mdot
.1732 .47073 Mdot
.53758 .63005 Mdot
.44451 .33216 Mdot
.46648 .28206 Mdot
.43044 .37838 Mdot
.65945 .50926 Mdot
.62861 .53321 Mdot
.37807 .76382 Mdot
.46368 .42342 Mdot
.42634 .43185 Mdot
.34133 .59651 Mdot
.66382 .52306 Mdot
.3118 .56547 Mdot
.36746 .56451 Mdot
.65437 .55713 Mdot
.31064 .55255 Mdot
.69053 .36363 Mdot
.44913 .60089 Mdot
.53829 .63053 Mdot
.5742 .65397 Mdot
.65409 .51362 Mdot
.61865 .56234 Mdot
.67127 .53262 Mdot
.4353 .38997 Mdot
.31291 .57953 Mdot
.41838 .38705 Mdot
.42589 .34885 Mdot
.37363 .58825 Mdot
.3172 .59079 Mdot
.42129 .38032 Mdot
.6458 .44524 Mdot
.66893 .33846 Mdot
.63169 .53015 Mdot
.54156 .64683 Mdot
.45364 .22562 Mdot
.52939 .66284 Mdot
.46973 .42731 Mdot
.52947 .7892 Mdot
.32857 .58818 Mdot
.65892 .36935 Mdot
.64114 .40453 Mdot
.66529 .36129 Mdot
.52509 .66076 Mdot
.37038 .55424 Mdot
.4391 .65562 Mdot
.47667 .42096 Mdot
.46506 .60026 Mdot
.47695 .2429 Mdot
.36317 .70488 Mdot
.54811 .65194 Mdot
.43997 .38805 Mdot
.42265 .7387 Mdot
.21757 .40765 Mdot
.45666 .38901 Mdot
.49958 .37731 Mdot
.74326 .4299 Mdot
.38459 .38837 Mdot
.31228 .52024 Mdot
.44174 .52321 Mdot
.49211 .38545 Mdot
.41865 .49639 Mdot
.2327 .25937 Mdot
.43685 .43434 Mdot
.44966 .41359 Mdot
.46056 .35864 Mdot
.41776 .37037 Mdot
.34424 .51905 Mdot
.73504 .40069 Mdot
.58615 .64817 Mdot
.45268 .59753 Mdot
.53347 .63984 Mdot
.63516 .51989 Mdot
.54105 .4934 Mdot
.36314 .53679 Mdot
.66426 .36158 Mdot
.82584 .39782 Mdot
.43042 .60585 Mdot
.6706 .5533 Mdot
.29602 .2713 Mdot
.65307 .38303 Mdot
.48443 .3559 Mdot
.66771 .34261 Mdot
.67656 .50746 Mdot
.56213 .65571 Mdot
.47249 .43364 Mdot
.33218 .59099 Mdot
.33312 .52597 Mdot
.43898 .39323 Mdot
.47297 .82292 Mdot
.53726 .65614 Mdot
.68642 .58261 Mdot
.46458 .4199 Mdot
.49931 .37757 Mdot
.32914 .53478 Mdot
.63361 .54074 Mdot
.59342 .71142 Mdot
.66889 .38476 Mdot
.49198 .3504 Mdot
.4276 .36746 Mdot
.4354 .62067 Mdot
.5916 .62712 Mdot
.40812 .7335 Mdot
.46352 .42185 Mdot
.44543 .61527 Mdot
.4572 .42613 Mdot
.52523 .41425 Mdot
.66907 .54497 Mdot
.42321 .44363 Mdot
.48421 .36889 Mdot
.3569 .37566 Mdot
.53831 .62692 Mdot
.3309 .55703 Mdot
.37067 .58565 Mdot
.41375 .72299 Mdot
.57601 .63062 Mdot
.42409 .37999 Mdot
.56909 .61217 Mdot
.43087 .35123 Mdot
.46676 .40381 Mdot
.54821 .65241 Mdot
.31092 .56389 Mdot
.62875 .74912 Mdot
.31105 .49705 Mdot
.41029 .39097 Mdot
.43843 .35682 Mdot
.67897 .28516 Mdot
.18375 .41484 Mdot
.48025 .36108 Mdot
.3168 .58574 Mdot
.441 .36962 Mdot
.5777 .65392 Mdot
.68594 .38817 Mdot
.34043 .55592 Mdot
.62203 .56877 Mdot
.65266 .56333 Mdot
.67308 .4792 Mdot
.41285 .7536 Mdot
.47255 .34911 Mdot
.28781 .55923 Mdot
.31674 .59255 Mdot
.44492 .71534 Mdot
.64275 .52116 Mdot
.69451 .37455 Mdot
.41823 .42009 Mdot
.55418 .35955 Mdot
.58573 .63304 Mdot
.19019 .72098 Mdot
.44162 .66177 Mdot
.69871 .35507 Mdot
.41205 .57643 Mdot
.41888 .74393 Mdot
.48194 .38044 Mdot
.65084 .35839 Mdot
.63152 .56341 Mdot
.42547 .36223 Mdot
.38602 .42216 Mdot
.73351 .62141 Mdot
.6343 .57717 Mdot
.56321 .61241 Mdot
.63048 .56776 Mdot
.69002 .34741 Mdot
.40585 .75337 Mdot
.31205 .53869 Mdot
.46258 .37721 Mdot
.36618 .39175 Mdot
.64089 .52788 Mdot
.40418 .72264 Mdot
.45783 .4239 Mdot
.34596 .52444 Mdot
.62836 .54074 Mdot
.47339 .3889 Mdot
.25115 .35299 Mdot
.36879 .59662 Mdot
.64882 .53564 Mdot
.49281 .41772 Mdot
.51838 .46512 Mdot
.64385 .57265 Mdot
.68338 .53093 Mdot
.44375 .40744 Mdot
.6859 .35806 Mdot
.4886 .39533 Mdot
.55129 .62974 Mdot
.52403 .55425 Mdot
.57851 .63878 Mdot
.50027 .2418 Mdot
.4554 .44629 Mdot
.33173 .64825 Mdot
.3571 .57069 Mdot
.63752 .38767 Mdot
.27885 .50363 Mdot
.49694 .37718 Mdot
.677 .75166 Mdot
.60059 .46606 Mdot
.45776 .71075 Mdot
.77666 .6776 Mdot
.67632 .38677 Mdot
.55737 .6321 Mdot
.44848 .41345 Mdot
.60135 .63539 Mdot
.68528 .37648 Mdot
.49551 .24083 Mdot
.49456 .41143 Mdot
.31767 .57756 Mdot
.45876 .41753 Mdot
.35849 .54139 Mdot
.44121 .36117 Mdot
.39637 .44775 Mdot
.68925 .33303 Mdot
.61042 .22564 Mdot
.47897 .35009 Mdot
.82866 .39281 Mdot
.56166 .41896 Mdot
.66128 .39074 Mdot
.41375 .39992 Mdot
.40953 .74228 Mdot
.55006 .66138 Mdot
.80591 .43156 Mdot
.66842 .53922 Mdot
.54893 .64569 Mdot
.32396 .5394 Mdot
.62252 .51322 Mdot
.41359 .72112 Mdot
.44276 .27547 Mdot
.67212 .34821 Mdot
.57294 .62421 Mdot
.46167 .37302 Mdot
.46727 .42931 Mdot
.78197 .46054 Mdot
.16848 .5335 Mdot
.35149 .58811 Mdot
.64173 .20875 Mdot
.29479 .54246 Mdot
.66408 .37856 Mdot
.67093 .54168 Mdot
.47639 .36859 Mdot
.45303 .39555 Mdot
.64645 .50877 Mdot
.30913 .57958 Mdot
.63362 .49203 Mdot
.31947 .27199 Mdot
.52129 .60947 Mdot
.60668 .25355 Mdot
.34394 .55269 Mdot
.60552 .24994 Mdot
.69723 .35518 Mdot
.76562 .63226 Mdot
.59587 .33372 Mdot
.57522 .62121 Mdot
.60698 .25737 Mdot
.3399 .58104 Mdot
.47547 .40043 Mdot
.40801 .74876 Mdot
.42559 .7319 Mdot
.33847 .53612 Mdot
.64947 .55634 Mdot
.66998 .35115 Mdot
.45504 .41213 Mdot
.38243 .66909 Mdot
.30557 .73514 Mdot
.62057 .53631 Mdot
.49611 .44992 Mdot
.53396 .65097 Mdot
.43787 .36486 Mdot
.65612 .3944 Mdot
.55752 .64592 Mdot
.4115 .7587 Mdot
.44739 .59147 Mdot
.4173 .41927 Mdot
.47227 .50216 Mdot
.57009 .62571 Mdot
.17178 .43408 Mdot
.44911 .40225 Mdot
.53757 .62985 Mdot
.41172 .31365 Mdot
.28676 .67553 Mdot
.62326 .43635 Mdot
.58397 .81869 Mdot
.66881 .56933 Mdot
.648 .56404 Mdot
.2098 .64271 Mdot
.70674 .34333 Mdot
.58209 .65639 Mdot
.40223 .75166 Mdot
.59312 .29979 Mdot
.53306 .63171 Mdot
.46104 .43538 Mdot
.40531 .39349 Mdot
.31962 .28154 Mdot
.55765 .44215 Mdot
.41387 .71644 Mdot
.48389 .30211 Mdot
.42719 .40256 Mdot
.41262 .34076 Mdot
.4448 .38777 Mdot
.29729 .56271 Mdot
.53436 .62698 Mdot
.86479 .4421 Mdot
.54954 .61271 Mdot
.39368 .6636 Mdot
.643 .53559 Mdot
.62281 .52418 Mdot
.4665 .37331 Mdot
.33084 .63333 Mdot
.82408 .48113 Mdot
.44731 .34894 Mdot
.64438 .41079 Mdot
.52662 .24241 Mdot
.40053 .3838 Mdot
.36553 .58358 Mdot
.50214 .43738 Mdot
.31651 .52412 Mdot
.55838 .64922 Mdot
.67811 .38587 Mdot
.66214 .33831 Mdot
.55839 .62687 Mdot
.45435 .38106 Mdot
.63071 .39332 Mdot
.46705 .38263 Mdot
.47441 .40865 Mdot
.42251 .64211 Mdot
.66988 .40244 Mdot
.67214 .53071 Mdot
.66562 .36494 Mdot
.31755 .55615 Mdot
.1063 .43095 Mdot
.67779 .36513 Mdot
.53494 .44328 Mdot
.55463 .49332 Mdot
.60388 .25537 Mdot
.33096 .52709 Mdot
.67534 .39409 Mdot
.55076 .61573 Mdot
.45443 .71825 Mdot
.17868 .45238 Mdot
.52339 .653 Mdot
.45362 .39949 Mdot
.36344 .53982 Mdot
.30763 .58763 Mdot
.52866 .62516 Mdot
.30486 .55421 Mdot
.39257 .38188 Mdot
.44512 .43083 Mdot
.58255 .65517 Mdot
.34195 .75617 Mdot
.53551 .62499 Mdot
.55818 .38179 Mdot
.42422 .42277 Mdot
.33856 .55507 Mdot
.47806 .31344 Mdot
.29646 .60131 Mdot
.42729 .73331 Mdot
.44011 .34344 Mdot
.66533 .35757 Mdot
.48361 .56753 Mdot
.64782 .53692 Mdot
.53598 .78864 Mdot
.35796 .53798 Mdot
.52386 .66889 Mdot
.31235 .54212 Mdot
.33051 .59521 Mdot
.52553 .64083 Mdot
.3257 .55222 Mdot
.45139 .41351 Mdot
.48955 .62482 Mdot
.35663 .54508 Mdot
.57017 .63727 Mdot
.66254 .35682 Mdot
.30957 .55703 Mdot
.64979 .4864 Mdot
.47879 .40256 Mdot
.67856 .53106 Mdot
.67416 .40488 Mdot
.36434 .53832 Mdot
.67987 .39166 Mdot
.64096 .5248 Mdot
.66424 .3511 Mdot
.59482 .5751 Mdot
.59411 .66119 Mdot
.40418 .63855 Mdot
.27446 .53339 Mdot
.34233 .58472 Mdot
.68568 .55665 Mdot
.48001 .36697 Mdot
.4724 .4177 Mdot
.67677 .3437 Mdot
.30825 .58998 Mdot
.51231 .82951 Mdot
.44772 .29815 Mdot
.38492 .76229 Mdot
.59456 .63259 Mdot
.56626 .19253 Mdot
.44513 .6739 Mdot
.46449 .72987 Mdot
.48773 .33639 Mdot
.41764 .74515 Mdot
.47215 .38173 Mdot
.52486 .21247 Mdot
.68624 .38946 Mdot
.64283 .68896 Mdot
.47204 .33306 Mdot
.66489 .53122 Mdot
.44753 .3562 Mdot
.82083 .42981 Mdot
.52073 .39044 Mdot
.6666 .39599 Mdot
.5751 .67207 Mdot
.34391 .58994 Mdot
.65437 .38314 Mdot
.65872 .56207 Mdot
.61949 .28771 Mdot
.4868 .42788 Mdot
.42965 .40882 Mdot
.69076 .53893 Mdot
.31226 .57234 Mdot
.63678 .51988 Mdot
.53791 .63089 Mdot
.67501 .36732 Mdot
.41529 .37347 Mdot
.39775 .39469 Mdot
.68578 .50853 Mdot
.55918 .60861 Mdot
.61791 .54667 Mdot
.57411 .61445 Mdot
.41599 .74678 Mdot
.47215 .34751 Mdot
.68864 .51972 Mdot
.45276 .31939 Mdot
.33988 .42467 Mdot
.42009 .63117 Mdot
.28941 .4846 Mdot
.67269 .52944 Mdot
.64343 .27731 Mdot
.56379 .63011 Mdot
.56017 .61728 Mdot
.36673 .26565 Mdot
.81998 .49172 Mdot
.6017 .47969 Mdot
.79965 .36125 Mdot
.53811 .63122 Mdot
.57404 .63353 Mdot
.6323 .56177 Mdot
.32552 .54701 Mdot
.3814 .53882 Mdot
.65251 .49257 Mdot
.56581 .21047 Mdot
.33577 .58315 Mdot
.65419 .77447 Mdot
.66979 .56227 Mdot
.50496 .35936 Mdot
.41716 .71344 Mdot
.66054 .39387 Mdot
.53344 .2166 Mdot
.80496 .37902 Mdot
.47554 .37296 Mdot
.3103 .23218 Mdot
.64958 .54997 Mdot
.5102 .67998 Mdot
.73328 .6754 Mdot
.49846 .39925 Mdot
.45117 .35747 Mdot
.45044 .37918 Mdot
.65326 .4013 Mdot
.3118 .49 Mdot
.47716 .37504 Mdot
.62266 .23561 Mdot
.43343 .44125 Mdot
.79059 .39448 Mdot
.66603 .36495 Mdot
.49868 .26983 Mdot
.66729 .5723 Mdot
.34844 .69254 Mdot
.40253 .34284 Mdot
.54245 .62742 Mdot
.7029 .67703 Mdot
.55313 .65654 Mdot
.79586 .57329 Mdot
.59416 .33125 Mdot
.29672 .56458 Mdot
.43657 .38523 Mdot
.68803 .54224 Mdot
.36335 .543 Mdot
.59987 .71239 Mdot
.1343 .37781 Mdot
.58119 .61184 Mdot
.41842 .14234 Mdot
.56409 .61624 Mdot
.42536 .72814 Mdot
.33384 .53472 Mdot
.40506 .53122 Mdot
.4656 .59705 Mdot
.31196 .56374 Mdot
.7238 .51621 Mdot
.36815 .58531 Mdot
.62766 .26272 Mdot
.30964 .59959 Mdot
.56532 .6365 Mdot
.5754 .67524 Mdot
.37972 .36786 Mdot
.47891 .3612 Mdot
.45533 .61412 Mdot
.42438 .31603 Mdot
.46295 .34742 Mdot
.65808 .52683 Mdot
.25764 .61598 Mdot
.51052 .66468 Mdot
.3477 .54418 Mdot
.58815 .63152 Mdot
.45081 .35643 Mdot
.41068 .39231 Mdot
.44157 .32649 Mdot
.50083 .21793 Mdot
.65706 .7702 Mdot
.46952 .4031 Mdot
.4663 .45274 Mdot
.66703 .5546 Mdot
.7875 .43831 Mdot
.71343 .27463 Mdot
.59811 .30861 Mdot
.466 .42533 Mdot
.66035 .37735 Mdot
.67483 .39766 Mdot
.39781 .41037 Mdot
.35871 .65485 Mdot
.62779 .48783 Mdot
.46146 .37276 Mdot
.61154 .34663 Mdot
.67318 .48966 Mdot
.3993 .72889 Mdot
.64146 .52726 Mdot
.36299 .53333 Mdot
.42349 .73217 Mdot
.62525 .52907 Mdot
.37438 .59855 Mdot
.41376 .72389 Mdot
.30041 .68425 Mdot
.68314 .39079 Mdot
.4469 .39267 Mdot
.27684 .57716 Mdot
.64803 .50927 Mdot
.56967 .62268 Mdot
.33689 .56667 Mdot
.5969 .63117 Mdot
.78955 .44047 Mdot
.54385 .22153 Mdot
.41712 .75198 Mdot
.54419 .62821 Mdot
.45075 .54209 Mdot
.66101 .3739 Mdot
.52596 .64665 Mdot
.31829 .63829 Mdot
.40211 .3868 Mdot
.81913 .55549 Mdot
.43312 .40802 Mdot
.44126 .81487 Mdot
.55856 .61869 Mdot
.42767 .7421 Mdot
.46239 .37953 Mdot
.67987 .5494 Mdot
.38067 .35009 Mdot
.46666 .38476 Mdot
.62914 .56982 Mdot
.47336 .40161 Mdot
.64831 .38888 Mdot
.3338 .51654 Mdot
.60125 .46232 Mdot
.50899 .195 Mdot
.6564 .35843 Mdot
.39936 .76322 Mdot
.47266 .35176 Mdot
.6963 .44283 Mdot
.31583 .56911 Mdot
.4995 .386 Mdot
.35788 .23704 Mdot
.33498 .54059 Mdot
.3238 .56877 Mdot
.41982 .3997 Mdot
.52423 .65577 Mdot
.66512 .51426 Mdot
.66134 .37083 Mdot
.57131 .71498 Mdot
.47507 .38871 Mdot
.44099 .39128 Mdot
.65311 .38218 Mdot
.57637 .63537 Mdot
.41567 .37643 Mdot
.56299 .75033 Mdot
.43951 .69327 Mdot
.58201 .62783 Mdot
.40163 .38552 Mdot
.8326 .5704 Mdot
.37764 .52604 Mdot
.28834 .24457 Mdot
.70909 .35103 Mdot
.65559 .55425 Mdot
.45493 .46153 Mdot
.15559 .67821 Mdot
.66424 .39319 Mdot
.36348 .69694 Mdot
.46901 .40934 Mdot
.46469 .35259 Mdot
.30739 .53973 Mdot
.4221 .3854 Mdot
.3537 .56011 Mdot
.51418 .19069 Mdot
.82135 .34806 Mdot
.31133 .54481 Mdot
.35643 .55252 Mdot
.39707 .50688 Mdot
.49081 .22459 Mdot
.32409 .54144 Mdot
.48911 .42634 Mdot
.72777 .50036 Mdot
.41251 .44844 Mdot
.70217 .37433 Mdot
.63497 .37929 Mdot
.33189 .60313 Mdot
.19099 .54243 Mdot
.38371 .33421 Mdot
.43122 .48586 Mdot
.70143 .40124 Mdot
.54485 .63613 Mdot
.40663 .39007 Mdot
.40958 .75433 Mdot
.62665 .54752 Mdot
.51636 .42024 Mdot
.44918 .39175 Mdot
.36039 .54637 Mdot
.64934 .39955 Mdot
.52787 .64477 Mdot
.44464 .40503 Mdot
.60802 .54574 Mdot
.67273 .38128 Mdot
.35569 .54607 Mdot
.5381 .43969 Mdot
.69831 .37166 Mdot
.39684 .37395 Mdot
.46228 .34816 Mdot
.45697 .42469 Mdot
.40281 .33868 Mdot
.55916 .62511 Mdot
.63566 .49788 Mdot
.41133 .44031 Mdot
.43283 .63512 Mdot
.49873 .55787 Mdot
.41073 .43834 Mdot
.31255 .58059 Mdot
.58299 .65726 Mdot
.4121 .72728 Mdot
.59622 .27242 Mdot
.43204 .43136 Mdot
.66734 .75985 Mdot
.28983 .28264 Mdot
.41729 .73115 Mdot
.29215 .56323 Mdot
.66152 .36564 Mdot
.42648 .4118 Mdot
.68682 .45783 Mdot
.45322 .4339 Mdot
.5426 .40124 Mdot
.65353 .55225 Mdot
.54146 .64045 Mdot
.43515 .69616 Mdot
.62619 .54724 Mdot
.32429 .56779 Mdot
.48899 .84697 Mdot
.38113 .56196 Mdot
.36226 .57662 Mdot
.77116 .59749 Mdot
.55588 .65113 Mdot
.17384 .70227 Mdot
.18156 .41659 Mdot
.44665 .43607 Mdot
.56985 .65899 Mdot
.34132 .53288 Mdot
.43511 .39664 Mdot
.34066 .58408 Mdot
.37498 .55952 Mdot
.42288 .34948 Mdot
.47066 .35417 Mdot
.59811 .22196 Mdot
.64817 .78963 Mdot
.6731 .35625 Mdot
.30166 .56343 Mdot
.29889 .29982 Mdot
.47863 .37555 Mdot
.47782 .41984 Mdot
.7257 .64343 Mdot
.67023 .39484 Mdot
.21542 .46995 Mdot
.46865 .41767 Mdot
.36481 .23421 Mdot
.45924 .34497 Mdot
.3067 .51325 Mdot
.51816 .64684 Mdot
.3622 .66014 Mdot
.6621 .51017 Mdot
.36465 .52865 Mdot
.6912 .35427 Mdot
.36431 .52561 Mdot
.35547 .27112 Mdot
.55909 .65258 Mdot
.35181 .56101 Mdot
.6145 .54015 Mdot
.57091 .64816 Mdot
.57498 .62011 Mdot
.63967 .46486 Mdot
.62163 .51676 Mdot
.6487 .39506 Mdot
.54558 .6567 Mdot
.26748 .33489 Mdot
.56374 .63968 Mdot
.30999 .29448 Mdot
.49066 .3872 Mdot
.61051 .23583 Mdot
.42228 .68095 Mdot
.3917 .34787 Mdot
.53032 .63358 Mdot
.68364 .36209 Mdot
.42814 .3805 Mdot
.30429 .55757 Mdot
.68071 .36735 Mdot
.58092 .59763 Mdot
.6156 .55754 Mdot
.3198 .59727 Mdot
.55711 .67463 Mdot
.35188 .56711 Mdot
.52632 .22852 Mdot
.60509 .57762 Mdot
.63374 .42598 Mdot
.47212 .59337 Mdot
.44594 .33033 Mdot
.41538 .49585 Mdot
.48963 .41633 Mdot
.45291 .39073 Mdot
.64811 .53527 Mdot
.67379 .27628 Mdot
.30895 .55901 Mdot
.35907 .79053 Mdot
.54857 .62413 Mdot
.43895 .52724 Mdot
.54129 .36046 Mdot
.43111 .35315 Mdot
.35257 .5425 Mdot
.37206 .56523 Mdot
.33187 .45037 Mdot
.6443 .50892 Mdot
.39568 .428 Mdot
.38753 .37389 Mdot
.42222 .45902 Mdot
.56773 .61627 Mdot
.58464 .74691 Mdot
.62979 .51544 Mdot
.33352 .1815 Mdot
.63104 .53072 Mdot
.71819 .42859 Mdot
.32657 .55129 Mdot
.69266 .37497 Mdot
.48167 .41481 Mdot
.35947 .48436 Mdot
.33402 .52002 Mdot
.64923 .47489 Mdot
.65933 .36564 Mdot
.61056 .74783 Mdot
.55153 .64904 Mdot
.49403 .3939 Mdot
.41829 .35257 Mdot
.41598 .39086 Mdot
.4422 .42092 Mdot
.58958 .64321 Mdot
.4626 .43464 Mdot
.59368 .64834 Mdot
.23086 .37618 Mdot
.36773 .23751 Mdot
.68615 .53269 Mdot
.78853 .40464 Mdot
.32559 .59397 Mdot
.29586 .32253 Mdot
.20913 .47456 Mdot
.41837 .63413 Mdot
.59179 .54859 Mdot
.48824 .37284 Mdot
.64737 .55709 Mdot
.82577 .43602 Mdot
.68802 .53212 Mdot
.84466 .35561 Mdot
.44645 .26419 Mdot
.56915 .82958 Mdot
.4351 .40387 Mdot
.65348 .49125 Mdot
.21692 .52695 Mdot
.40174 .40954 Mdot
.6315 .37541 Mdot
.55174 .37718 Mdot
.34123 .73396 Mdot
.69507 .37454 Mdot
.47889 .39928 Mdot
.33148 .59735 Mdot
.45238 .41406 Mdot
.48408 .40604 Mdot
.44711 .35003 Mdot
.55955 .60389 Mdot
.40721 .36741 Mdot
.48843 .39631 Mdot
.16131 .51308 Mdot
.6674 .2923 Mdot
.67281 .55285 Mdot
.31293 .46252 Mdot
.66841 .37443 Mdot
.3631 .5473 Mdot
.58721 .47336 Mdot
.54989 .6344 Mdot
.33449 .43893 Mdot
.43424 .40547 Mdot
.37836 .71794 Mdot
.53646 .66872 Mdot
.68267 .37644 Mdot
.41004 .72491 Mdot
.67418 .73353 Mdot
.67414 .51241 Mdot
.42404 .72261 Mdot
.64756 .538 Mdot
.24075 .52907 Mdot
.35879 .54447 Mdot
.4386 .32996 Mdot
.53237 .64637 Mdot
.68189 .52883 Mdot
.70292 .29413 Mdot
.44547 .37617 Mdot
.67263 .5276 Mdot
.44387 .33123 Mdot
.50137 .56168 Mdot
.55729 .4972 Mdot
.67247 .50318 Mdot
.57387 .67538 Mdot
.57385 .64887 Mdot
.69154 .36734 Mdot
.36423 .55176 Mdot
.3222 .58757 Mdot
.56128 .64695 Mdot
.33632 .19717 Mdot
.47515 .38662 Mdot
.4573 .34672 Mdot
.43522 .6415 Mdot
.43849 .40845 Mdot
.63575 .2891 Mdot
.39472 .74285 Mdot
.34661 .58255 Mdot
.44238 .41758 Mdot
.415 .37723 Mdot
.41525 .41544 Mdot
.54511 .22394 Mdot
.63814 .5301 Mdot
.42683 .40386 Mdot
.66012 .35028 Mdot
.3052 .65399 Mdot
.48229 .37246 Mdot
.39755 .38038 Mdot
.35069 .56645 Mdot
.59587 .19199 Mdot
.56385 .62053 Mdot
.66442 .52074 Mdot
.6673 .56379 Mdot
.5297 .26925 Mdot
.35199 .51158 Mdot
.39824 .72498 Mdot
.71849 .58599 Mdot
.39919 .74048 Mdot
.66055 .38896 Mdot
.64522 .44974 Mdot
.60694 .5519 Mdot
.66179 .56253 Mdot
.59415 .65992 Mdot
.44542 .42009 Mdot
.45926 .34542 Mdot
.36507 .69338 Mdot
.4432 .34626 Mdot
.66053 .36083 Mdot
.55625 .67319 Mdot
.34957 .5663 Mdot
.65158 .38957 Mdot
.5554 .61701 Mdot
.31197 .57293 Mdot
.4051 .40767 Mdot
.43044 .3264 Mdot
.3319 .5696 Mdot
.35239 .53061 Mdot
.46529 .36584 Mdot
.19223 .58502 Mdot
.34589 .58574 Mdot
.34894 .55542 Mdot
.43282 .72528 Mdot
.67578 .5132 Mdot
.50933 .33825 Mdot
.56674 .65869 Mdot
.46061 .42238 Mdot
.68634 .53024 Mdot
.68127 .38856 Mdot
.32893 .57712 Mdot
.41204 .40528 Mdot
.4696 .3956 Mdot
.65965 .37633 Mdot
.68269 .39797 Mdot
.65553 .36311 Mdot
.58141 .60822 Mdot
.43976 .42602 Mdot
.31973 .54387 Mdot
.55283 .65209 Mdot
.67658 .39681 Mdot
.65325 .34971 Mdot
.16392 .49822 Mdot
.47448 .3736 Mdot
.65154 .43185 Mdot
.09685 .48553 Mdot
.61696 .29453 Mdot
.42063 .72385 Mdot
.67574 .50144 Mdot
.62118 .24261 Mdot
.70789 .38018 Mdot
.56908 .66163 Mdot
.59828 .37599 Mdot
.64255 .39606 Mdot
.4248 .35054 Mdot
.43533 .36647 Mdot
.5037 .36271 Mdot
.67495 .37511 Mdot
.53386 .22817 Mdot
.30893 .58644 Mdot
.26638 .40758 Mdot
.66858 .37436 Mdot
.67161 .50262 Mdot
.6856 .51366 Mdot
.6306 .52972 Mdot
.49007 .37437 Mdot
.31696 .47201 Mdot
.27994 .31661 Mdot
.22518 .46763 Mdot
.54958 .64573 Mdot
.36947 .5715 Mdot
.5918 .53766 Mdot
.32333 .56963 Mdot
.63148 .55089 Mdot
.67718 .37811 Mdot
.30151 .54759 Mdot
.58073 .63542 Mdot
.57845 .64253 Mdot
.619 .56595 Mdot
.64491 .52304 Mdot
.65675 .51663 Mdot
.36611 .53381 Mdot
.32574 .55196 Mdot
.41196 .37958 Mdot
.33794 .57364 Mdot
.24729 .31398 Mdot
.70371 .37246 Mdot
.68932 .54537 Mdot
.56827 .62701 Mdot
.35472 .5382 Mdot
.44747 .39637 Mdot
.75539 .43854 Mdot
.66306 .47795 Mdot
.65078 .36469 Mdot
.50679 .59163 Mdot
.76176 .26202 Mdot
.41815 .34914 Mdot
.57669 .61388 Mdot
.34618 .65277 Mdot
.44899 .37173 Mdot
.66449 .54564 Mdot
.42488 .25109 Mdot
.40116 .72819 Mdot
.48661 .3889 Mdot
.49559 .36372 Mdot
.52587 .64155 Mdot
.57501 .48226 Mdot
.43617 .34777 Mdot
.50418 .49878 Mdot
.56716 .60662 Mdot
.62853 .51691 Mdot
.22986 .69913 Mdot
.53379 .60164 Mdot
.61707 .22351 Mdot
.41879 .72546 Mdot
.41783 .3551 Mdot
.65601 .52928 Mdot
.64904 .36313 Mdot
.65087 .5272 Mdot
.29851 .58619 Mdot
.67691 .52553 Mdot
.4412 .37827 Mdot
.31854 .54642 Mdot
.57507 .629 Mdot
.44747 .51446 Mdot
.17588 .53525 Mdot
.67833 .55101 Mdot
.40762 .76097 Mdot
.48299 .3813 Mdot
.22308 .40449 Mdot
.37656 .37689 Mdot
.48268 .366 Mdot
.55119 .65615 Mdot
.35081 .54255 Mdot
.59492 .63511 Mdot
.407 .35875 Mdot
.36284 .28338 Mdot
.54998 .62493 Mdot
.31193 .70983 Mdot
.65418 .38536 Mdot
.56293 .21082 Mdot
.45848 .3912 Mdot
.53289 .64552 Mdot
.43913 .42633 Mdot
.30136 .56544 Mdot
.47265 .56056 Mdot
.3061 .64771 Mdot
.53487 .65147 Mdot
.46332 .82966 Mdot
.52296 .51549 Mdot
.52154 .36599 Mdot
.53437 .63534 Mdot
.28688 .49622 Mdot
.40874 .73866 Mdot
.66787 .38581 Mdot
.67643 .39892 Mdot
.6767 .34718 Mdot
.4447 .3458 Mdot
.4426 .46879 Mdot
.64259 .36413 Mdot
.58588 .61341 Mdot
.64362 .37072 Mdot
.50565 .22727 Mdot
.48825 .82815 Mdot
.65195 .36741 Mdot
.45896 .39626 Mdot
.39815 .38478 Mdot
.67082 .29254 Mdot
.63028 .51084 Mdot
.68193 .74394 Mdot
.19478 .40963 Mdot
.47518 .36641 Mdot
.45678 .27268 Mdot
.30898 .59487 Mdot
.38122 .61781 Mdot
.4537 .29349 Mdot
.60408 .47136 Mdot
.35249 .54995 Mdot
.50451 .56958 Mdot
.35194 .57674 Mdot
.42531 .33585 Mdot
.4661 .40478 Mdot
.33211 .51886 Mdot
.52383 .78214 Mdot
.25948 .67725 Mdot
.41436 .7942 Mdot
.3194 .58741 Mdot
.53794 .62719 Mdot
.57564 .61118 Mdot
.54736 .6505 Mdot
.65403 .51052 Mdot
.35118 .52749 Mdot
.43064 .42178 Mdot
.65572 .56088 Mdot
.47547 .41862 Mdot
.56689 .65346 Mdot
.44017 .69538 Mdot
.3507 .56491 Mdot
.4601 .37415 Mdot
.17917 .4594 Mdot
.64001 .54142 Mdot
.66174 .37601 Mdot
.4865 .61742 Mdot
.67742 .50099 Mdot
.54564 .61467 Mdot
.36498 .51486 Mdot
.70158 .54313 Mdot
.73724 .39763 Mdot
.50029 .41658 Mdot
.4826 .43166 Mdot
.59477 .69058 Mdot
.17806 .50914 Mdot
.44017 .3518 Mdot
.65774 .56274 Mdot
.67334 .50651 Mdot
.44331 .43141 Mdot
.31721 .53494 Mdot
.63983 .38712 Mdot
.6811 .34556 Mdot
.47303 .34148 Mdot
.46533 .60341 Mdot
.60789 .23039 Mdot
.42022 .37856 Mdot
.53776 .39484 Mdot
.61586 .5375 Mdot
.41448 .72149 Mdot
.44608 .60943 Mdot
.68895 .35509 Mdot
.4699 .41066 Mdot
.27138 .69529 Mdot
.35341 .55603 Mdot
.66897 .51877 Mdot
.58427 .64399 Mdot
.63187 .36939 Mdot
.65536 .57059 Mdot
.4431 .43133 Mdot
.41544 .37686 Mdot
.52792 .64994 Mdot
.29947 .51859 Mdot
.67753 .37537 Mdot
.65917 .55902 Mdot
.69287 .37403 Mdot
.31988 .55717 Mdot
.34822 .56026 Mdot
.38667 .37985 Mdot
.3886 .34992 Mdot
.66971 .56133 Mdot
.50018 .36337 Mdot
.6256 .53827 Mdot
.78335 .45613 Mdot
.58628 .63342 Mdot
.49984 .39149 Mdot
.29402 .5335 Mdot
.5653 .65269 Mdot
.46645 .35789 Mdot
.59248 .69101 Mdot
.42255 .3653 Mdot
.65215 .49182 Mdot
.37425 .2563 Mdot
.68617 .37636 Mdot
.41324 .49185 Mdot
.37356 .45397 Mdot
.43844 .40665 Mdot
.635 .50182 Mdot
.41215 .46037 Mdot
.55257 .62619 Mdot
.33719 .54538 Mdot
.49705 .15214 Mdot
.56823 .63914 Mdot
.45763 .41219 Mdot
.67734 .36679 Mdot
.35025 .58737 Mdot
.41933 .74813 Mdot
.44548 .64659 Mdot
.51903 .40797 Mdot
.49829 .34204 Mdot
.4487 .41903 Mdot
.80004 .35973 Mdot
.65775 .52195 Mdot
.34953 .53438 Mdot
.58256 .6197 Mdot
.55482 .64162 Mdot
.63368 .54124 Mdot
.36087 .7491 Mdot
.54978 .79744 Mdot
.09336 .53079 Mdot
.65557 .56802 Mdot
.6509 .35538 Mdot
.49614 .5517 Mdot
.62534 .54729 Mdot
.66166 .5276 Mdot
.61654 .56594 Mdot
.38744 .69492 Mdot
.31028 .57469 Mdot
.47095 .39607 Mdot
.34516 .51023 Mdot
.42138 .35199 Mdot
.68038 .26651 Mdot
.55935 .64799 Mdot
.33471 .54646 Mdot
.6143 .63717 Mdot
.42603 .31012 Mdot
.44801 .36262 Mdot
.69512 .46985 Mdot
.51101 .42122 Mdot
.60356 .26412 Mdot
.41946 .32999 Mdot
.64421 .53031 Mdot
.42949 .28146 Mdot
.46384 .45881 Mdot
.1885 .43352 Mdot
.57887 .63589 Mdot
.42373 .74601 Mdot
.41079 .42074 Mdot
.52862 .40103 Mdot
.35536 .58346 Mdot
.3018 .54666 Mdot
.64128 .36805 Mdot
.48157 .63761 Mdot
.57778 .63235 Mdot
.6023 .78364 Mdot
.4767 .35741 Mdot
.53105 .70001 Mdot
.36944 .25568 Mdot
.46406 .359 Mdot
.6608 .45943 Mdot
.33404 .44176 Mdot
.43081 .35494 Mdot
.23707 .46191 Mdot
.56778 .63098 Mdot
.36273 .23527 Mdot
.48059 .34109 Mdot
.66414 .54483 Mdot
.32756 .54681 Mdot
.3185 .59634 Mdot
.64794 .37272 Mdot
.21547 .35572 Mdot
.5738 .68089 Mdot
.32873 .54928 Mdot
.44858 .37969 Mdot
.5669 .62205 Mdot
.42512 .74164 Mdot
.51203 .36211 Mdot
.79831 .54214 Mdot
.34231 .57161 Mdot
.42733 .45393 Mdot
.39809 .78261 Mdot
.52796 .52505 Mdot
.65722 .78423 Mdot
.54341 .64941 Mdot
.68833 .35291 Mdot
.42637 .32316 Mdot
.71493 .58812 Mdot
.47061 .33403 Mdot
.64932 .24586 Mdot
.30048 .60829 Mdot
.68643 .38765 Mdot
.45225 .37282 Mdot
.43606 .34833 Mdot
.47811 .57772 Mdot
.68896 .39234 Mdot
.43448 .34803 Mdot
.39157 .41314 Mdot
.31474 .57543 Mdot
.39582 .74891 Mdot
.34555 .57159 Mdot
.45268 .40016 Mdot
.47912 .26951 Mdot
.30585 .54441 Mdot
.65811 .74721 Mdot
.69962 .32788 Mdot
.5494 .63381 Mdot
.52175 .43057 Mdot
.48888 .38039 Mdot
.81469 .64794 Mdot
.42724 .73238 Mdot
.65938 .22691 Mdot
.66667 .49565 Mdot
.32244 .77395 Mdot
.67717 .49882 Mdot
.54159 .84228 Mdot
.44675 .5274 Mdot
.50423 .38989 Mdot
.59902 .35448 Mdot
.23159 .45808 Mdot
.59698 .64938 Mdot
.2552 .36087 Mdot
.47912 .36158 Mdot
.48042 .39061 Mdot
.63925 .56227 Mdot
.37235 .75718 Mdot
.34918 .65741 Mdot
.45526 .60184 Mdot
.67907 .38067 Mdot
.32675 .55709 Mdot
.43981 .37321 Mdot
.49179 .75344 Mdot
.67759 .54567 Mdot
.56476 .39693 Mdot
.4608 .37741 Mdot
.38472 .66141 Mdot
.34331 .71578 Mdot
.57098 .62202 Mdot
.65993 .4954 Mdot
.63339 .49998 Mdot
.40509 .38676 Mdot
.57931 .65673 Mdot
.41687 .3653 Mdot
.51827 .51794 Mdot
.46867 .4514 Mdot
.67176 .39201 Mdot
.48284 .41568 Mdot
.58331 .39942 Mdot
.53561 .85675 Mdot
.48848 .44808 Mdot
.36292 .5673 Mdot
.64831 .51232 Mdot
.63325 .53316 Mdot
.3226 .58812 Mdot
.63231 .53508 Mdot
.26598 .41723 Mdot
.34122 .28183 Mdot
.66418 .39179 Mdot
.20261 .4822 Mdot
.68251 .38142 Mdot
.42272 .74766 Mdot
.47204 .37014 Mdot
.72673 .58885 Mdot
.65676 .568 Mdot
.46244 .22735 Mdot
.56103 .64101 Mdot
.42685 .73106 Mdot
.43595 .4378 Mdot
.66685 .43975 Mdot
.63704 .55546 Mdot
.68135 .70501 Mdot
.4133 .4115 Mdot
.30486 .56916 Mdot
.43287 .35258 Mdot
.48215 .44091 Mdot
.42171 .72224 Mdot
.44843 .41994 Mdot
.5551 .61709 Mdot
.35126 .52674 Mdot
.54618 .83637 Mdot
.65041 .50933 Mdot
.48399 .39415 Mdot
.44886 .37824 Mdot
.29937 .54813 Mdot
.43955 .44076 Mdot
.56693 .66117 Mdot
.2241 .7628 Mdot
.65586 .38675 Mdot
.4123 .72114 Mdot
.66779 .72445 Mdot
.43505 .37738 Mdot
.42482 .3773 Mdot
.5824 .70439 Mdot
.24923 .63872 Mdot
.54747 .62278 Mdot
.44193 .44634 Mdot
.66954 .55133 Mdot
.68164 .37044 Mdot
.55092 .66197 Mdot
.44408 .42949 Mdot
.48014 .38852 Mdot
.66704 .39362 Mdot
.69378 .46653 Mdot
.64016 .48691 Mdot
.54886 .64796 Mdot
.47199 .28046 Mdot
.76001 .44326 Mdot
.47109 .38417 Mdot
.44432 .80051 Mdot
.34656 .55455 Mdot
.5361 .63613 Mdot
.30465 .49552 Mdot
.43785 .33194 Mdot
.5423 .61772 Mdot
.57606 .63062 Mdot
.428 .433 Mdot
.35313 .51107 Mdot
.37271 .54358 Mdot
.3485 .553 Mdot
.38989 .23705 Mdot
.74254 .32713 Mdot
.65795 .51597 Mdot
.57121 .63124 Mdot
.68797 .52523 Mdot
.63818 .3736 Mdot
.49747 .55963 Mdot
.67388 .50592 Mdot
.32567 .5947 Mdot
.69094 .53162 Mdot
.41844 .36653 Mdot
.58116 .64188 Mdot
.65576 .56556 Mdot
.43245 .39089 Mdot
.53598 .41136 Mdot
.58652 .389 Mdot
.64378 .39289 Mdot
.5004 .57231 Mdot
.45514 .40793 Mdot
.41292 .72583 Mdot
.46467 .36873 Mdot
.58246 .65555 Mdot
.58308 .41576 Mdot
.43 .40123 Mdot
.66296 .56648 Mdot
.74622 .39239 Mdot
.6407 .50067 Mdot
.46652 .44623 Mdot
.4534 .40087 Mdot
.4733 .38421 Mdot
.44133 .34398 Mdot
.32624 .7226 Mdot
.59406 .64876 Mdot
.51892 .4407 Mdot
.641 .57568 Mdot
.32572 .57289 Mdot
.29898 .56112 Mdot
.59757 .48465 Mdot
.42863 .72392 Mdot
.57571 .65788 Mdot
.47383 .38605 Mdot
.68193 .70411 Mdot
.45298 .69584 Mdot
.42895 .80293 Mdot
.6259 .47079 Mdot
.65781 .56361 Mdot
.36631 .56208 Mdot
.62267 .56027 Mdot
.44987 .43341 Mdot
.42106 .32876 Mdot
.5627 .8298 Mdot
.56513 .60079 Mdot
.67667 .37702 Mdot
.47503 .41975 Mdot
.58742 .21328 Mdot
.66695 .55467 Mdot
.61681 .53276 Mdot
.41388 .36924 Mdot
.3787 .55292 Mdot
.62016 .82796 Mdot
.58359 .65026 Mdot
.22849 .3931 Mdot
.27721 .59853 Mdot
.54415 .35871 Mdot
.55739 .62832 Mdot
.63101 .43081 Mdot
.63655 .50759 Mdot
.20218 .391 Mdot
.33216 .57163 Mdot
.67312 .37875 Mdot
.39521 .41227 Mdot
.32651 .59498 Mdot
.68855 .51337 Mdot
.3587 .56279 Mdot
.43378 .33051 Mdot
.58912 .61902 Mdot
.62953 .53607 Mdot
.58427 .66222 Mdot
.33815 .51846 Mdot
.68411 .37937 Mdot
.47764 .23383 Mdot
.22939 .38663 Mdot
.33423 .44179 Mdot
.42674 .4047 Mdot
.74296 .5954 Mdot
.43046 .42392 Mdot
.36816 .56853 Mdot
.45846 .39214 Mdot
.43206 .49858 Mdot
.62228 .52552 Mdot
.4356 .45581 Mdot
.4883 .4058 Mdot
.20999 .39609 Mdot
.45499 .3581 Mdot
.43821 .43703 Mdot
.48492 .35071 Mdot
.26757 .56493 Mdot
.42233 .44797 Mdot
.30504 .56698 Mdot
.36818 .70057 Mdot
.66118 .52996 Mdot
.65956 .34302 Mdot
.69215 .35147 Mdot
.64146 .24014 Mdot
.57038 .21125 Mdot
.36387 .74518 Mdot
.33106 .5841 Mdot
.54817 .61694 Mdot
.41598 .36792 Mdot
.2627 .51635 Mdot
.55623 .32727 Mdot
.63376 .51084 Mdot
.68043 .55314 Mdot
.38414 .3836 Mdot
.83425 .4051 Mdot
.42539 .45113 Mdot
.44009 .65756 Mdot
.43222 .34664 Mdot
.49993 .38181 Mdot
.61521 .53455 Mdot
.52646 .22358 Mdot
.42695 .40399 Mdot
.35481 .58389 Mdot
.66784 .3814 Mdot
.44995 .27644 Mdot
.5341 .29675 Mdot
.5508 .3464 Mdot
.33533 .62156 Mdot
.44091 .42334 Mdot
.65859 .55646 Mdot
.33222 .59375 Mdot
.43667 .62837 Mdot
.55205 .65334 Mdot
.45088 .62505 Mdot
.24537 .35524 Mdot
.54143 .59527 Mdot
.67295 .38088 Mdot
.62647 .47717 Mdot
.44108 .37942 Mdot
.65502 .51124 Mdot
.42355 .34142 Mdot
.45536 .69779 Mdot
.68199 .38943 Mdot
.35835 .52107 Mdot
.53879 .62599 Mdot
.31019 .58243 Mdot
.29319 .48201 Mdot
.54811 .31828 Mdot
.32302 .77517 Mdot
.67221 .51041 Mdot
.36888 .31326 Mdot
.33643 .53706 Mdot
.4238 .42443 Mdot
.09528 .52049 Mdot
.34382 .55402 Mdot
.3084 .57857 Mdot
.60608 .46886 Mdot
.50021 .24158 Mdot
.45985 .46087 Mdot
.35177 .57484 Mdot
.67575 .56844 Mdot
.66747 .36123 Mdot
.42782 .3862 Mdot
.47203 .34298 Mdot
.30465 .54314 Mdot
.63515 .55277 Mdot
.58864 .21012 Mdot
.64406 .52644 Mdot
.30915 .56627 Mdot
.64814 .54363 Mdot
.64495 .74714 Mdot
.67776 .53824 Mdot
.48973 .40357 Mdot
.47301 .38641 Mdot
.78649 .52328 Mdot
.34816 .56036 Mdot
.42688 .37881 Mdot
.47158 .40475 Mdot
.32584 .53989 Mdot
.60746 .56552 Mdot
.34776 .44955 Mdot
.43602 .39115 Mdot
.47298 .39161 Mdot
.6895 .38605 Mdot
.52016 .55118 Mdot
.4712 .76171 Mdot
.42747 .38339 Mdot
.67033 .34611 Mdot
.36665 .53553 Mdot
.46357 .3667 Mdot
.52622 .22067 Mdot
.67626 .49224 Mdot
.46134 .43268 Mdot
.41541 .7511 Mdot
.44487 .35036 Mdot
.61273 .83187 Mdot
.48298 .38793 Mdot
.33567 .53332 Mdot
.33235 .54206 Mdot
.64946 .48202 Mdot
.32603 .56639 Mdot
.42259 .72713 Mdot
.57018 .65092 Mdot
.42637 .81351 Mdot
.42418 .73065 Mdot
.49781 .39046 Mdot
.18167 .41585 Mdot
.46683 .33824 Mdot
.40647 .42023 Mdot
.48105 .22691 Mdot
.42039 .72843 Mdot
.34942 .53993 Mdot
.52551 .779 Mdot
.49944 .40687 Mdot
.58268 .65256 Mdot
.39981 .40277 Mdot
.46286 .43281 Mdot
.54282 .45453 Mdot
.37132 .27317 Mdot
.56173 .67375 Mdot
.51231 .34339 Mdot
.42686 .38535 Mdot
.24381 .61613 Mdot
.44536 .38324 Mdot
.65028 .37057 Mdot
.33409 .58664 Mdot
.62057 .55628 Mdot
.65663 .38117 Mdot
.43793 .37703 Mdot
.67227 .37508 Mdot
.66052 .51695 Mdot
.54057 .65364 Mdot
.47832 .42036 Mdot
.70126 .37336 Mdot
.67955 .37629 Mdot
.41595 .40504 Mdot
.33061 .54718 Mdot
.37278 .39318 Mdot
.46333 .3646 Mdot
.43926 .43071 Mdot
.32244 .58762 Mdot
.21315 .31252 Mdot
.41258 .35952 Mdot
.63562 .43435 Mdot
.29833 .54 Mdot
.40571 .71919 Mdot
.62782 .56467 Mdot
.45485 .32083 Mdot
.55481 .64658 Mdot
.56437 .64966 Mdot
.62903 .57895 Mdot
.32627 .5253 Mdot
.62848 .54119 Mdot
.51826 .36984 Mdot
.38447 .37907 Mdot
.39282 .40882 Mdot
.50002 .15258 Mdot
.67685 .73103 Mdot
.33829 .52834 Mdot
.63657 .5052 Mdot
.45692 .60994 Mdot
.57661 .65517 Mdot
.62163 .57954 Mdot
.2903 .54262 Mdot
.36085 .53673 Mdot
.33167 .59182 Mdot
.68407 .35413 Mdot
.64026 .52173 Mdot
.29886 .60329 Mdot
.3733 .53532 Mdot
.40965 .38823 Mdot
.42625 .38628 Mdot
.34698 .60158 Mdot
.66376 .29684 Mdot
.67943 .38796 Mdot
.66016 .55214 Mdot
.78337 .70967 Mdot
.58428 .64938 Mdot
.20823 .39857 Mdot
.4331 .39096 Mdot
.14985 .3343 Mdot
.41783 .44457 Mdot
.44752 .38059 Mdot
.36282 .53292 Mdot
.69013 .34453 Mdot
.67016 .36345 Mdot
.33546 .53777 Mdot
.37634 .53151 Mdot
.67178 .34983 Mdot
.64235 .46049 Mdot
.44217 .83091 Mdot
.44324 .6232 Mdot
.3282 .5357 Mdot
.21379 .41463 Mdot
.54693 .66021 Mdot
.31493 .5227 Mdot
.5722 .67015 Mdot
.66283 .52801 Mdot
.68299 .54607 Mdot
.52859 .65245 Mdot
.42473 .42771 Mdot
.67471 .52405 Mdot
.51208 .42873 Mdot
.61384 .79599 Mdot
.79324 .59532 Mdot
.2299 .63609 Mdot
.46834 .34688 Mdot
.35946 .65681 Mdot
.32822 .67841 Mdot
.44388 .4102 Mdot
.46158 .30527 Mdot
.67514 .37659 Mdot
.31059 .52683 Mdot
.57044 .66505 Mdot
.68777 .7486 Mdot
.47196 .38466 Mdot
.3089 .55964 Mdot
.58013 .64835 Mdot
.63722 .7456 Mdot
.51023 .49651 Mdot
.41583 .36073 Mdot
.10213 .5908 Mdot
.34304 .5189 Mdot
.62049 .55519 Mdot
.18659 .48172 Mdot
.33483 .51127 Mdot
.75835 .42678 Mdot
.63093 .49955 Mdot
.44221 .76872 Mdot
.36193 .54384 Mdot
.61097 .52317 Mdot
.31997 .56014 Mdot
.64906 .38901 Mdot
.36289 .51289 Mdot
.63848 .54674 Mdot
.45292 .36627 Mdot
.63682 .54329 Mdot
.66333 .39561 Mdot
.66836 .51249 Mdot
.56843 .66526 Mdot
.4171 .72515 Mdot
.57725 .64714 Mdot
.50127 .55589 Mdot
.34067 .34234 Mdot
.54161 .6408 Mdot
.70554 .6828 Mdot
.43819 .35451 Mdot
.31193 .51026 Mdot
.61966 .55917 Mdot
.6799 .56045 Mdot
.48174 .58982 Mdot
.31206 .56191 Mdot
.64484 .54931 Mdot
.24829 .35572 Mdot
.30656 .21137 Mdot
.50344 .44366 Mdot
.7478 .33834 Mdot
.32527 .5393 Mdot
.62056 .52854 Mdot
.43614 .64413 Mdot
.30538 .58671 Mdot
.6643 .56365 Mdot
.53331 .63543 Mdot
.55372 .63816 Mdot
.41461 .41672 Mdot
.52177 .63683 Mdot
.63222 .5041 Mdot
.26587 .68234 Mdot
.33141 .5885 Mdot
.6473 .73206 Mdot
.65614 .35932 Mdot
.66263 .52331 Mdot
.45247 .46027 Mdot
.32989 .61577 Mdot
.67846 .55803 Mdot
.81338 .51167 Mdot
.81063 .6721 Mdot
.64609 .54937 Mdot
.33529 .586 Mdot
.32628 .57736 Mdot
.48336 .45056 Mdot
.46785 .59629 Mdot
.63946 .55333 Mdot
.73148 .58443 Mdot
.65644 .25272 Mdot
.41636 .74675 Mdot
.16936 .4668 Mdot
.42768 .40466 Mdot
.44384 .42676 Mdot
.55967 .65981 Mdot
.44533 .36116 Mdot
.3762 .55306 Mdot
.40539 .42908 Mdot
.57662 .61021 Mdot
.63112 .51436 Mdot
.47299 .37648 Mdot
.68241 .36028 Mdot
.56485 .66258 Mdot
.54174 .6145 Mdot
.65483 .53879 Mdot
.34307 .58472 Mdot
.50707 .78664 Mdot
.6437 .52523 Mdot
.43831 .42262 Mdot
.41561 .7362 Mdot
.4424 .3266 Mdot
.77367 .54347 Mdot
.31088 .58765 Mdot
.62208 .55785 Mdot
.29164 .56029 Mdot
.57325 .63645 Mdot
.655 .57586 Mdot
.44384 .39071 Mdot
.6697 .5595 Mdot
.62694 .41863 Mdot
.71786 .46633 Mdot
.37497 .53583 Mdot
.65524 .41371 Mdot
.3004 .54798 Mdot
.41663 .74707 Mdot
.56331 .28238 Mdot
.67021 .38751 Mdot
.67531 .53685 Mdot
.67105 .74472 Mdot
.6235 .57089 Mdot
.45702 .35678 Mdot
.46724 .35222 Mdot
.63618 .56254 Mdot
.68876 .36238 Mdot
.54114 .19619 Mdot
.72012 .37096 Mdot
.35759 .54461 Mdot
.42935 .54863 Mdot
.73832 .75051 Mdot
.66573 .58085 Mdot
.53986 .62152 Mdot
.52303 .34836 Mdot
.42646 .36356 Mdot
.52658 .63904 Mdot
.58801 .63275 Mdot
.67439 .39728 Mdot
.65876 .51237 Mdot
.28726 .57599 Mdot
.53952 .65844 Mdot
.3585 .39702 Mdot
.54883 .21133 Mdot
.5037 .42799 Mdot
.40759 .45032 Mdot
.49212 .38561 Mdot
.52756 .52722 Mdot
.59213 .62783 Mdot
.45937 .40523 Mdot
.38864 .36324 Mdot
.53896 .63236 Mdot
.65888 .39507 Mdot
.38741 .50864 Mdot
.65592 .54649 Mdot
.23942 .24917 Mdot
.48003 .41885 Mdot
.45649 .36446 Mdot
.54964 .64543 Mdot
.18344 .52785 Mdot
.32876 .53195 Mdot
.34424 .58203 Mdot
.65781 .52088 Mdot
.48016 .59941 Mdot
.44739 .44116 Mdot
.44741 .41026 Mdot
.67258 .53471 Mdot
.41377 .72684 Mdot
.21554 .64465 Mdot
.46786 .39559 Mdot
.56419 .62797 Mdot
.69913 .68049 Mdot
.59327 .63196 Mdot
.41934 .34769 Mdot
.45898 .35496 Mdot
.48746 .41355 Mdot
.44552 .34143 Mdot
.53245 .65537 Mdot
.44481 .40717 Mdot
.3867 .33898 Mdot
.35008 .54555 Mdot
.43408 .41019 Mdot
.6308 .23859 Mdot
.46784 .39002 Mdot
.68226 .36141 Mdot
.47576 .76947 Mdot
.4819 .39858 Mdot
.43555 .41412 Mdot
.71394 .38676 Mdot
.45276 .37813 Mdot
.57991 .62797 Mdot
.33059 .57444 Mdot
.57312 .63232 Mdot
.56632 .61653 Mdot
.68821 .54312 Mdot
.66379 .40096 Mdot
.48117 .33912 Mdot
.6683 .34866 Mdot
.47479 .45074 Mdot
.43263 .33221 Mdot
.50991 .55758 Mdot
.44083 .65918 Mdot
.70407 .38808 Mdot
.44591 .39769 Mdot
.65772 .52612 Mdot
.62646 .56619 Mdot
.60385 .36428 Mdot
.50398 .43568 Mdot
.55064 .66276 Mdot
.53273 .64531 Mdot
.63319 .29287 Mdot
.52999 .47492 Mdot
.68422 .36809 Mdot
.44882 .58376 Mdot
.48071 .3542 Mdot
.47589 .40335 Mdot
.39804 .38944 Mdot
.68008 .5105 Mdot
.41508 .72307 Mdot
.63416 .51231 Mdot
.42964 .74842 Mdot
.59463 .64165 Mdot
.46955 .34792 Mdot
.77496 .62745 Mdot
.32283 .52948 Mdot
.33206 .57426 Mdot
.57097 .60784 Mdot
.63894 .50113 Mdot
.49016 .44399 Mdot
.52246 .14515 Mdot
.34573 .59648 Mdot
.66967 .34225 Mdot
.45142 .41161 Mdot
.65641 .53526 Mdot
.34639 .52394 Mdot
.67474 .40321 Mdot
.47584 .35344 Mdot
.61548 .57276 Mdot
.46226 .3903 Mdot
.23071 .48016 Mdot
.34551 .54307 Mdot
.44186 .69766 Mdot
.38159 .55597 Mdot
.53055 .63273 Mdot
.55499 .61921 Mdot
.46503 .35701 Mdot
.41035 .15896 Mdot
.38425 .56143 Mdot
.52492 .66053 Mdot
.64659 .3896 Mdot
.40998 .72274 Mdot
.65447 .39861 Mdot
.62467 .54259 Mdot
.66973 .38235 Mdot
.66677 .5642 Mdot
.64566 .3056 Mdot
.31628 .60536 Mdot
.65664 .38542 Mdot
.18253 .53806 Mdot
.43212 .32603 Mdot
.68121 .39535 Mdot
.38383 .38898 Mdot
.39196 .49466 Mdot
.67059 .53417 Mdot
.68631 .36005 Mdot
.41292 .4064 Mdot
.72227 .70129 Mdot
.56056 .61712 Mdot
.55463 .66409 Mdot
.47341 .33499 Mdot
.6153 .54935 Mdot
.37243 .52722 Mdot
.58635 .46944 Mdot
.40218 .72196 Mdot
.44753 .40936 Mdot
.47668 .35235 Mdot
.31171 .53125 Mdot
.35941 .58147 Mdot
.4614 .35393 Mdot
.26103 .34474 Mdot
.44058 .38075 Mdot
.55335 .63447 Mdot
.35536 .53134 Mdot
.33 .57699 Mdot
.65179 .49452 Mdot
.32572 .52577 Mdot
.4147 .45155 Mdot
.60041 .65175 Mdot
.3904 .37863 Mdot
.57122 .63925 Mdot
.58836 .4108 Mdot
.65682 .50965 Mdot
.68692 .74184 Mdot
.33777 .52219 Mdot
.44367 .41998 Mdot
.29992 .55679 Mdot
.65612 .36284 Mdot
.34737 .56229 Mdot
.31362 .59869 Mdot
.47559 .35803 Mdot
.41734 .35626 Mdot
.41469 .73034 Mdot
.46919 .59866 Mdot
.34021 .5477 Mdot
.43901 .39217 Mdot
.48445 .34575 Mdot
.40561 .37584 Mdot
.52504 .51475 Mdot
.36477 .54032 Mdot
.32517 .27965 Mdot
.78502 .56247 Mdot
.33291 .5485 Mdot
.69111 .76524 Mdot
.40154 .74927 Mdot
.42901 .72326 Mdot
.52706 .66757 Mdot
.47146 .3949 Mdot
.63008 .5412 Mdot
.45488 .43241 Mdot
.51585 .42254 Mdot
.48355 .39808 Mdot
.67296 .39396 Mdot
.50718 .39568 Mdot
.4039 .74416 Mdot
.64065 .53076 Mdot
.43642 .38416 Mdot
.47614 .38007 Mdot
.42998 .72685 Mdot
.38245 .55732 Mdot
.3608 .53953 Mdot
.45229 .79811 Mdot
.65401 .38946 Mdot
.55169 .65548 Mdot
.45054 .43189 Mdot
.65756 .52397 Mdot
.63387 .53933 Mdot
.30917 .58072 Mdot
.66065 .5476 Mdot
.58144 .65748 Mdot
.44443 .37702 Mdot
.52649 .64088 Mdot
.67207 .39407 Mdot
.3334 .5869 Mdot
.44906 .43237 Mdot
.40921 .39131 Mdot
.33278 .54189 Mdot
.43978 .35263 Mdot
.69016 .38473 Mdot
.68294 .52984 Mdot
.35628 .53684 Mdot
.56894 .65061 Mdot
.66045 .49619 Mdot
.41665 .37138 Mdot
.85144 .56985 Mdot
.44419 .36098 Mdot
.46221 .42459 Mdot
.47929 .83993 Mdot
.41596 .33238 Mdot
.62097 .5357 Mdot
.29817 .55962 Mdot
.40932 .3595 Mdot
.68409 .2717 Mdot
.64727 .60578 Mdot
.61659 .57866 Mdot
.45165 .41481 Mdot
.66569 .76934 Mdot
.44127 .41614 Mdot
.62654 .75563 Mdot
.50784 .55913 Mdot
.8054 .38857 Mdot
.39794 .44305 Mdot
.52313 .65529 Mdot
.41582 .72825 Mdot
.61825 .55989 Mdot
.25528 .49781 Mdot
.4429 .35607 Mdot
.30462 .48859 Mdot
.4629 .43448 Mdot
.55644 .63 Mdot
.47297 .3085 Mdot
.66017 .55114 Mdot
.18867 .42019 Mdot
.43313 .42304 Mdot
.36328 .53726 Mdot
.68265 .56074 Mdot
.40369 .72628 Mdot
.41307 .40813 Mdot
.65816 .35471 Mdot
.61471 .6205 Mdot
.39362 .42837 Mdot
.57145 .64186 Mdot
.47172 .40757 Mdot
.52497 .36629 Mdot
.34423 .19624 Mdot
.35206 .54464 Mdot
.53766 .62475 Mdot
.35968 .62689 Mdot
.4511 .34496 Mdot
.36084 .54146 Mdot
.32956 .57215 Mdot
.64655 .37052 Mdot
.45722 .6731 Mdot
.69813 .57825 Mdot
.81362 .5711 Mdot
.32402 .45504 Mdot
.66912 .49755 Mdot
.27075 .66349 Mdot
.42516 .39425 Mdot
.53956 .30804 Mdot
.57428 .62154 Mdot
.45488 .36644 Mdot
.328 .39863 Mdot
.34944 .55439 Mdot
.46292 .39686 Mdot
.67741 .38908 Mdot
.41614 .69188 Mdot
.53712 .32828 Mdot
.81214 .63685 Mdot
.65259 .57958 Mdot
.39677 .3988 Mdot
.38117 .41121 Mdot
.40752 .71857 Mdot
.42579 .34343 Mdot
.61885 .55514 Mdot
.74622 .60012 Mdot
.6896 .36855 Mdot
.3295 .52608 Mdot
.39967 .7461 Mdot
.47991 .42912 Mdot
.45425 .33055 Mdot
.65874 .34387 Mdot
.4265 .42475 Mdot
.1868 .45605 Mdot
.41266 .70738 Mdot
.67871 .53697 Mdot
.3575 .56643 Mdot
.49191 .38273 Mdot
.41351 .72406 Mdot
.47258 .35519 Mdot
.40032 .52094 Mdot
.45722 .41973 Mdot
.3764 .77971 Mdot
.32648 .54771 Mdot
.5743 .64346 Mdot
.50513 .36033 Mdot
.46623 .38076 Mdot
.76032 .44783 Mdot
.51737 .41885 Mdot
.48245 .38759 Mdot
.33963 .59384 Mdot
.31238 .53781 Mdot
.30824 .57416 Mdot
.679 .53017 Mdot
.44552 .61528 Mdot
.56018 .63601 Mdot
.42174 .44017 Mdot
.54441 .66012 Mdot
.40098 .47166 Mdot
.65995 .34541 Mdot
.73353 .71571 Mdot
.43714 .3676 Mdot
.31683 .58248 Mdot
.28168 .69924 Mdot
.36664 .5349 Mdot
.51757 .66785 Mdot
.57832 .63303 Mdot
.34215 .55308 Mdot
.45269 .38522 Mdot
.45766 .59919 Mdot
.83326 .59287 Mdot
.5745 .65565 Mdot
.40422 .35645 Mdot
.66423 .57504 Mdot
.66248 .56866 Mdot
.66457 .80171 Mdot
.56415 .61443 Mdot
.32324 .67658 Mdot
.43822 .39982 Mdot
.31612 .53318 Mdot
.54366 .64578 Mdot
.58003 .62556 Mdot
.6702 .53952 Mdot
.4131 .36619 Mdot
.46541 .38364 Mdot
.41306 .752 Mdot
.53942 .65439 Mdot
.47888 .32079 Mdot
.42622 .35216 Mdot
.54477 .83956 Mdot
.28744 .55037 Mdot
.19336 .33435 Mdot
.51848 .36551 Mdot
.33239 .39626 Mdot
.54977 .47297 Mdot
.34385 .52721 Mdot
.4361 .43316 Mdot
.42743 .44375 Mdot
.66205 .49501 Mdot
.44334 .37137 Mdot
.65143 .50245 Mdot
.54393 .61805 Mdot
.7402 .71562 Mdot
.65993 .71248 Mdot
.59118 .54724 Mdot
.44936 .35931 Mdot
.54943 .36366 Mdot
.65558 .37115 Mdot
.58153 .60513 Mdot
.30661 .55365 Mdot
.49138 .37245 Mdot
.63542 .49544 Mdot
.67453 .54146 Mdot
.33562 .56671 Mdot
.33752 .69314 Mdot
.65707 .74789 Mdot
.44769 .34035 Mdot
.62437 .55709 Mdot
.64099 .72252 Mdot
.28174 .3337 Mdot
.52196 .64586 Mdot
.68846 .3741 Mdot
.62934 .51908 Mdot
.55416 .60588 Mdot
.40188 .50633 Mdot
.33328 .56027 Mdot
.32403 .52323 Mdot
.76272 .50059 Mdot
.6378 .55042 Mdot
.65939 .37256 Mdot
.50322 .4907 Mdot
.4607 .50757 Mdot
.68072 .38962 Mdot
.63215 .51219 Mdot
.32864 .52796 Mdot
.30887 .56209 Mdot
.32874 .5746 Mdot
.18791 .43477 Mdot
.31307 .59174 Mdot
.30005 .26847 Mdot
.45714 .33635 Mdot
.22201 .40848 Mdot
.44427 .41659 Mdot
.54406 .6654 Mdot
.3442 .54254 Mdot
.49175 .56435 Mdot
.49548 .36905 Mdot
.8158 .62445 Mdot
.45431 .40899 Mdot
.60057 .66118 Mdot
.47266 .39354 Mdot
.19741 .47904 Mdot
.29897 .53863 Mdot
.44486 .39776 Mdot
.55326 .67547 Mdot
.67855 .37171 Mdot
.38734 .54294 Mdot
.48067 .39431 Mdot
.37812 .74265 Mdot
.38748 .36933 Mdot
.6384 .77515 Mdot
.73471 .40034 Mdot
.67728 .34106 Mdot
.38915 .39897 Mdot
.69345 .52736 Mdot
.37462 .59173 Mdot
.21247 .4345 Mdot
.57374 .65565 Mdot
.3925 .26591 Mdot
.67541 .53278 Mdot
.46657 .30755 Mdot
.4875 .43335 Mdot
.68868 .35689 Mdot
.38686 .55399 Mdot
.55209 .63289 Mdot
.43898 .35645 Mdot
.43547 .43517 Mdot
.81108 .48429 Mdot
.20737 .44236 Mdot
.48058 .32323 Mdot
.63878 .37532 Mdot
.33085 .28085 Mdot
.47979 .40502 Mdot
.61484 .57489 Mdot
.29781 .56963 Mdot
.43625 .4601 Mdot
.31654 .28329 Mdot
.43896 .38675 Mdot
.34137 .55702 Mdot
.33484 .52231 Mdot
.333 .75232 Mdot
.66485 .34456 Mdot
.45756 .41966 Mdot
.7702 .44465 Mdot
.44015 .42553 Mdot
.5572 .63457 Mdot
.4166 .34903 Mdot
.66706 .52629 Mdot
.4342 .6503 Mdot
.67937 .52583 Mdot
.40647 .39672 Mdot
.31596 .56936 Mdot
.54916 .63636 Mdot
.76538 .51842 Mdot
.5754 .495 Mdot
.30792 .26362 Mdot
.61658 .62151 Mdot
.67946 .35408 Mdot
.66676 .40268 Mdot
.58996 .66944 Mdot
.45062 .40082 Mdot
.5473 .50489 Mdot
.43979 .45372 Mdot
.47595 .39425 Mdot
.48104 .41518 Mdot
.58729 .59841 Mdot
.5783 .63723 Mdot
.64419 .54491 Mdot
.45949 .35316 Mdot
.43936 .39357 Mdot
.33032 .55279 Mdot
.68029 .37579 Mdot
.68068 .53974 Mdot
.65173 .38311 Mdot
.64637 .52957 Mdot
.62864 .82038 Mdot
.40884 .35644 Mdot
.67857 .37033 Mdot
.59329 .62689 Mdot
.31719 .58535 Mdot
.42801 .73331 Mdot
.62532 .54086 Mdot
.65704 .55224 Mdot
.44463 .4089 Mdot
.34454 .57715 Mdot
.35479 .56122 Mdot
.67424 .35056 Mdot
.53624 .64402 Mdot
.41659 .42133 Mdot
.42247 .35287 Mdot
.7914 .40561 Mdot
.67181 .5017 Mdot
.27605 .32429 Mdot
.34044 .73988 Mdot
.44983 .40011 Mdot
.35816 .55445 Mdot
.46967 .37337 Mdot
.74396 .65109 Mdot
.32748 .5944 Mdot
.49202 .35588 Mdot
.53109 .46139 Mdot
.68267 .51713 Mdot
.33531 .77273 Mdot
.50013 .35665 Mdot
.57771 .70853 Mdot
.41912 .40131 Mdot
.4233 .85264 Mdot
.25226 .63482 Mdot
.47023 .43394 Mdot
.45125 .34143 Mdot
.82785 .54262 Mdot
.43788 .4064 Mdot
.40505 .74843 Mdot
.51999 .38563 Mdot
.36128 .53829 Mdot
.56138 .47104 Mdot
.51494 .56397 Mdot
.64838 .35776 Mdot
.65833 .52026 Mdot
.52668 .25155 Mdot
.65313 .39217 Mdot
.33286 .53523 Mdot
.47811 .3457 Mdot
.35288 .39376 Mdot
.66069 .48157 Mdot
.47542 .44615 Mdot
.55691 .63301 Mdot
.51144 .56616 Mdot
.64093 .50902 Mdot
.5721 .65007 Mdot
.47427 .42844 Mdot
.65945 .23311 Mdot
.57856 .50551 Mdot
.37929 .80186 Mdot
.54903 .64776 Mdot
.57243 .62409 Mdot
.43004 .62707 Mdot
.64837 .35791 Mdot
.80955 .4579 Mdot
.49524 .29856 Mdot
.5821 .65157 Mdot
.59729 .27464 Mdot
.62058 .51546 Mdot
.4529 .674 Mdot
.30935 .52705 Mdot
.40478 .36403 Mdot
.45572 .38412 Mdot
.53676 .63838 Mdot
.30845 .49872 Mdot
.40258 .56847 Mdot
.57663 .65021 Mdot
.3781 .38436 Mdot
.45481 .68715 Mdot
.41827 .73378 Mdot
.40692 .7533 Mdot
.64218 .38159 Mdot
.71851 .49215 Mdot
.31799 .55448 Mdot
.69323 .36241 Mdot
.41925 .77191 Mdot
.46149 .41869 Mdot
.5397 .6558 Mdot
.42486 .74575 Mdot
.56316 .64743 Mdot
.6747 .36321 Mdot
.66759 .34267 Mdot
.3505 .54538 Mdot
.32673 .53281 Mdot
.36761 .28387 Mdot
.63375 .27578 Mdot
.43641 .41031 Mdot
.34553 .45475 Mdot
.32049 .59058 Mdot
.21326 .53221 Mdot
.6646 .3477 Mdot
.68039 .38052 Mdot
.24589 .42414 Mdot
.4124 .37669 Mdot
.67825 .69633 Mdot
.48104 .39891 Mdot
.57113 .29313 Mdot
.49721 .40962 Mdot
.66728 .54239 Mdot
.43077 .41399 Mdot
.49924 .76992 Mdot
.43093 .37672 Mdot
.48575 .40333 Mdot
.63328 .52616 Mdot
.50463 .35665 Mdot
.66937 .52694 Mdot
.41627 .35505 Mdot
.66094 .33778 Mdot
.65733 .52385 Mdot
.71558 .31781 Mdot
.62933 .43431 Mdot
.40809 .72854 Mdot
.64672 .38815 Mdot
.66317 .35211 Mdot
.62376 .23044 Mdot
.30909 .54736 Mdot
.40555 .50124 Mdot
.45178 .40116 Mdot
.61633 .53595 Mdot
.55503 .66019 Mdot
.43968 .38783 Mdot
.41218 .43829 Mdot
.49622 .35058 Mdot
.34719 .55125 Mdot
.62865 .51511 Mdot
.67234 .37116 Mdot
.63209 .56825 Mdot
.6596 .44108 Mdot
.64324 .57324 Mdot
.53588 .37736 Mdot
.51221 .35439 Mdot
.37237 .42963 Mdot
.33859 .43223 Mdot
.20391 .38416 Mdot
.3319 .56457 Mdot
.41088 .74013 Mdot
.65326 .35031 Mdot
.42794 .54663 Mdot
.31448 .57686 Mdot
.65235 .55395 Mdot
.46214 .39023 Mdot
.37734 .38327 Mdot
.5334 .33077 Mdot
.30718 .61188 Mdot
.67111 .27501 Mdot
.64484 .51514 Mdot
.42128 .74004 Mdot
.44146 .63286 Mdot
.26982 .57289 Mdot
.49593 .55874 Mdot
.46851 .37745 Mdot
.66275 .35079 Mdot
.34628 .52393 Mdot
.78969 .5091 Mdot
.53418 .63687 Mdot
.46789 .59805 Mdot
.44783 .36052 Mdot
.28828 .67883 Mdot
.31623 .5693 Mdot
.68225 .38286 Mdot
.53714 .63763 Mdot
.66363 .34608 Mdot
.39865 .74663 Mdot
.47031 .78922 Mdot
.42044 .41692 Mdot
.4831 .38595 Mdot
.58933 .65262 Mdot
.31682 .55721 Mdot
.63173 .48717 Mdot
.80075 .51626 Mdot
.62588 .55884 Mdot
.53885 .52156 Mdot
.35007 .52625 Mdot
.25616 .61014 Mdot
.66382 .562 Mdot
.58387 .61198 Mdot
.53808 .51167 Mdot
.57524 .61039 Mdot
.48209 .40673 Mdot
.33352 .58185 Mdot
.56369 .6142 Mdot
.77675 .47711 Mdot
.61151 .81614 Mdot
.39046 .54449 Mdot
.44748 .34894 Mdot
.73948 .71304 Mdot
.52785 .82785 Mdot
.36071 .48253 Mdot
.53555 .65542 Mdot
.46686 .36202 Mdot
.44985 .33955 Mdot
.43313 .42183 Mdot
.54723 .61958 Mdot
.59979 .49542 Mdot
.66368 .55366 Mdot
.46009 .4085 Mdot
.65677 .35915 Mdot
.66446 .53389 Mdot
.69167 .54027 Mdot
.61921 .56393 Mdot
.33035 .59511 Mdot
.4677 .34053 Mdot
.42144 .68006 Mdot
.45277 .8573 Mdot
.57614 .63549 Mdot
.40773 .72875 Mdot
.48353 .41674 Mdot
.37791 .23266 Mdot
.30941 .57571 Mdot
.62714 .55921 Mdot
.45639 .36583 Mdot
.73774 .4214 Mdot
.38458 .73501 Mdot
.64443 .52137 Mdot
.308 .55188 Mdot
.3636 .48279 Mdot
.44293 .37212 Mdot
.41768 .39813 Mdot
.31962 .54634 Mdot
.4296 .80067 Mdot
.44158 .65242 Mdot
.47151 .37616 Mdot
.57461 .64551 Mdot
.32878 .19564 Mdot
.46063 .33125 Mdot
.3116 .61562 Mdot
.41179 .72161 Mdot
.37057 .76544 Mdot
.28592 .31786 Mdot
.51914 .43276 Mdot
.7626 .6749 Mdot
.50919 .22864 Mdot
.72465 .7292 Mdot
.52392 .2715 Mdot
.61375 .72805 Mdot
.56196 .86233 Mdot
.53763 .67093 Mdot
.20184 .4849 Mdot
.82898 .44191 Mdot
.35523 .68459 Mdot
.71081 .4126 Mdot
.69045 .60922 Mdot
.74391 .41091 Mdot
.17975 .57762 Mdot
.64888 .5707 Mdot
.56454 .31394 Mdot
.42786 .4318 Mdot
.52134 .82356 Mdot
.22027 .39215 Mdot
.20983 .36232 Mdot
.72194 .721 Mdot
.76535 .43228 Mdot
.84949 .54548 Mdot
.68471 .73853 Mdot
.38119 .2897 Mdot
.56284 .3976 Mdot
.72013 .52357 Mdot
.48262 .49772 Mdot
.51728 .24681 Mdot
.42454 .46565 Mdot
.49677 .7532 Mdot
.59598 .56358 Mdot
.33266 .32341 Mdot
.31412 .21584 Mdot
.62295 .53474 Mdot
.29843 .5729 Mdot
.81201 .43999 Mdot
.33766 .61696 Mdot
.54982 .68366 Mdot
.76338 .67422 Mdot
.54376 .84299 Mdot
.1971 .47442 Mdot
.43967 .75659 Mdot
.24498 .46803 Mdot
.53383 .19036 Mdot
.56689 .37016 Mdot
.36605 .52623 Mdot
.6534 .672 Mdot
.46106 .5069 Mdot
.70829 .49488 Mdot
.1952 .50694 Mdot
.68135 .40176 Mdot
.70844 .30362 Mdot
.30863 .5551 Mdot
.29294 .32609 Mdot
.42677 .71937 Mdot
.43404 .75552 Mdot
.61482 .5173 Mdot
.7518 .63637 Mdot
.38861 .7145 Mdot
.38692 .70604 Mdot
.25437 .67684 Mdot
.84 .6075 Mdot
.56383 .23301 Mdot
.75149 .5849 Mdot
.56462 .70298 Mdot
.52068 .22647 Mdot
.40754 .66205 Mdot
.61404 .25549 Mdot
.4555 .49812 Mdot
.8575 .43491 Mdot
.45851 .82008 Mdot
.86026 .50762 Mdot
.3475 .50375 Mdot
.44066 .32143 Mdot
.76488 .5918 Mdot
.3127 .46476 Mdot
.69398 .34562 Mdot
.82828 .62139 Mdot
.68663 .34764 Mdot
.28899 .57971 Mdot
.34769 .68387 Mdot
.19306 .43766 Mdot
.61657 .49688 Mdot
.70455 .33023 Mdot
.41726 .44953 Mdot
.85223 .37301 Mdot
.77794 .65818 Mdot
.34405 .7567 Mdot
.53499 .84187 Mdot
.65785 .5845 Mdot
.68088 .4928 Mdot
.54775 .61581 Mdot
.57918 .84363 Mdot
.32223 .57925 Mdot
.46323 .86371 Mdot
.57397 .84016 Mdot
.31724 .62979 Mdot
.84653 .34701 Mdot
.21324 .62427 Mdot
.22911 .39374 Mdot
.43404 .25224 Mdot
.7302 .30577 Mdot
.41319 .63789 Mdot
.25985 .61862 Mdot
.67797 .57192 Mdot
.41925 .80879 Mdot
.63928 .80758 Mdot
.59882 .28631 Mdot
.55292 .58994 Mdot
.3674 .67091 Mdot
.59041 .39905 Mdot
.33214 .6107 Mdot
.7212 .38476 Mdot
.5924 .38453 Mdot
.85721 .5262 Mdot
.36336 .26935 Mdot
.45015 .14811 Mdot
.53628 .27503 Mdot
.18194 .52088 Mdot
.68005 .7228 Mdot
.67377 .31934 Mdot
.40389 .53715 Mdot
.36949 .70862 Mdot
.39786 .35913 Mdot
.44414 .59178 Mdot
.40192 .31536 Mdot
.63692 .40718 Mdot
.43852 .62171 Mdot
.59084 .77557 Mdot
.55259 .27683 Mdot
.80234 .57452 Mdot
.55041 .42596 Mdot
.35747 .57089 Mdot
.60605 .24191 Mdot
.57492 .25429 Mdot
.56516 .82754 Mdot
.35811 .62841 Mdot
.39001 .80342 Mdot
.36904 .61738 Mdot
.43577 .45335 Mdot
.2046 .49192 Mdot
.4103 .46147 Mdot
.59821 .26034 Mdot
.5045 .37656 Mdot
.26179 .68849 Mdot
.48843 .84191 Mdot
.33382 .3609 Mdot
.54141 .25411 Mdot
.34008 .40993 Mdot
.42991 .81517 Mdot
.77031 .59019 Mdot
.27516 .64835 Mdot
.25031 .5789 Mdot
.85472 .3928 Mdot
.65606 .5423 Mdot
.60587 .27806 Mdot
.59482 .60634 Mdot
.76738 .50731 Mdot
.82708 .413 Mdot
.38572 .59667 Mdot
.47888 .84335 Mdot
.38159 .6923 Mdot
.63882 .47708 Mdot
.47173 .68385 Mdot
.52016 .61203 Mdot
.34618 .37768 Mdot
.47587 .33459 Mdot
.36503 .42099 Mdot
.69371 .37935 Mdot
.29291 .46795 Mdot
.77692 .56458 Mdot
.62432 .6553 Mdot
.52822 .42429 Mdot
.62623 .67292 Mdot
.42046 .74466 Mdot
.46456 .6094 Mdot
.65428 .81054 Mdot
.52483 .39308 Mdot
.20577 .59835 Mdot
.45526 .81441 Mdot
.52857 .52888 Mdot
.69418 .46539 Mdot
.31685 .71501 Mdot
.86404 .47392 Mdot
.52888 .85665 Mdot
.55974 .80543 Mdot
.74617 .70663 Mdot
.27131 .75889 Mdot
.80911 .3658 Mdot
.25272 .52544 Mdot
.596 .60214 Mdot
.19892 .72857 Mdot
.64697 .56463 Mdot
.40304 .25452 Mdot
.314 .46068 Mdot
.73614 .43057 Mdot
.35851 .60511 Mdot
.52809 .44318 Mdot
.63387 .59849 Mdot
.36204 .59158 Mdot
.42018 .44953 Mdot
.80643 .66764 Mdot
.86057 .43502 Mdot
.81912 .64864 Mdot
.47282 .79132 Mdot
.73707 .7258 Mdot
.84154 .49009 Mdot
.29129 .27453 Mdot
.81506 .46559 Mdot
.41734 .34869 Mdot
.61931 .30193 Mdot
.21861 .62452 Mdot
.61445 .51271 Mdot
.44154 .71463 Mdot
.30146 .52554 Mdot
.84984 .44006 Mdot
.66362 .80785 Mdot
.26298 .42014 Mdot
.32075 .31304 Mdot
.61776 .42213 Mdot
.61856 .26806 Mdot
.36821 .3348 Mdot
.50013 .7428 Mdot
.61027 .80093 Mdot
.84165 .4787 Mdot
.5701 .26321 Mdot
.67122 .62654 Mdot
.56424 .79547 Mdot
.22273 .59221 Mdot
.71139 .70894 Mdot
.81303 .4301 Mdot
.33859 .62681 Mdot
.26846 .54976 Mdot
.3993 .57442 Mdot
.48875 .73296 Mdot
.72932 .63763 Mdot
.54649 .23182 Mdot
.66821 .5112 Mdot
.60533 .29011 Mdot
.49225 .53029 Mdot
.81651 .45908 Mdot
.53523 .21898 Mdot
.59448 .29022 Mdot
.58107 .79497 Mdot
.78638 .68492 Mdot
.40649 .78803 Mdot
.69444 .25446 Mdot
.54664 .72259 Mdot
.41236 .30843 Mdot
.45966 .32035 Mdot
.45988 .83182 Mdot
.76485 .72174 Mdot
.49042 .84893 Mdot
.2833 .67628 Mdot
.76992 .47791 Mdot
.52694 .62765 Mdot
.52686 .20991 Mdot
.60597 .68251 Mdot
.61892 .79972 Mdot
.43589 .55751 Mdot
.51752 .65273 Mdot
.39433 .68265 Mdot
.38073 .28253 Mdot
.47345 .2317 Mdot
.3041 .3414 Mdot
.49613 .43979 Mdot
.25476 .36104 Mdot
.29707 .54819 Mdot
.27869 .66788 Mdot
.61314 .25998 Mdot
.65587 .53891 Mdot
.78174 .37482 Mdot
.36048 .38392 Mdot
.41829 .32913 Mdot
.73908 .60931 Mdot
.33826 .60895 Mdot
.33643 .42685 Mdot
.69095 .50473 Mdot
.58547 .85038 Mdot
.23943 .63806 Mdot
.36135 .34116 Mdot
.58121 .22983 Mdot
.78934 .41432 Mdot
.44813 .65005 Mdot
.59713 .64461 Mdot
.71172 .72563 Mdot
.62384 .44427 Mdot
.59722 .23943 Mdot
.26008 .35175 Mdot
.79102 .53218 Mdot
.42282 .44348 Mdot
.31929 .73228 Mdot
.33329 .25075 Mdot
.46883 .60743 Mdot
.28218 .57875 Mdot
.33728 .60053 Mdot
.1476 .52897 Mdot
.51328 .77252 Mdot
.31351 .64066 Mdot
.7199 .71069 Mdot
.56111 .61041 Mdot
.35874 .57762 Mdot
.5973 .29974 Mdot
.72348 .47132 Mdot
.34341 .28385 Mdot
.73383 .64021 Mdot
.39621 .29122 Mdot
.59144 .70745 Mdot
.74364 .70411 Mdot
.81529 .60621 Mdot
.359 .18506 Mdot
.37886 .56287 Mdot
.76793 .54516 Mdot
.77416 .53321 Mdot
.3667 .52948 Mdot
.30808 .61298 Mdot
.54666 .35079 Mdot
.71136 .74952 Mdot
.44774 .53977 Mdot
.48652 .71605 Mdot
.53847 .51249 Mdot
.70395 .42433 Mdot
.79779 .50458 Mdot
.52761 .23569 Mdot
.72595 .69606 Mdot
.29478 .34012 Mdot
.74549 .30413 Mdot
.36843 .40771 Mdot
.3811 .25692 Mdot
.52673 .20962 Mdot
.57241 .39659 Mdot
.19839 .51253 Mdot
.61147 .76676 Mdot
.43862 .42144 Mdot
.83731 .61999 Mdot
.565 .82211 Mdot
.43639 .59567 Mdot
.71231 .52462 Mdot
.42193 .37782 Mdot
.46262 .33771 Mdot
.27013 .53024 Mdot
.35602 .75357 Mdot
.77318 .31489 Mdot
.55335 .28751 Mdot
.41166 .3065 Mdot
.2553 .35402 Mdot
.20613 .59807 Mdot
.75905 .60819 Mdot
.6533 .76044 Mdot
.47518 .54307 Mdot
.22226 .62795 Mdot
.48372 .63737 Mdot
.47506 .71141 Mdot
.57959 .73072 Mdot
.8409 .49877 Mdot
.5293 .34104 Mdot
.3573 .73233 Mdot
.80461 .45936 Mdot
.48143 .41821 Mdot
.33748 .69362 Mdot
.69576 .72243 Mdot
.48131 .15818 Mdot
.39743 .65924 Mdot
.79185 .69468 Mdot
.36847 .42428 Mdot
.36531 .7294 Mdot
.83163 .40912 Mdot
.57952 .1552 Mdot
.49018 .75059 Mdot
.85294 .54151 Mdot
.46923 .65974 Mdot
.72592 .70486 Mdot
.52263 .65252 Mdot
.50198 .50209 Mdot
.33117 .47387 Mdot
.70524 .75393 Mdot
.7384 .5099 Mdot
.75229 .65105 Mdot
.26221 .53648 Mdot
.73736 .73402 Mdot
.44426 .49761 Mdot
.15046 .51652 Mdot
.60992 .57386 Mdot
.23477 .6795 Mdot
.24053 .55291 Mdot
.38397 .32071 Mdot
.59079 .27479 Mdot
.16017 .47985 Mdot
.2524 .31107 Mdot
.26529 .51644 Mdot
.59976 .33054 Mdot
.3277 .72474 Mdot
.57445 .22503 Mdot
.61739 .80459 Mdot
.17169 .5633 Mdot
.78611 .52185 Mdot
.31763 .65922 Mdot
.44952 .80231 Mdot
.35574 .75887 Mdot
.56598 .75233 Mdot
.75105 .60234 Mdot
.46249 .74647 Mdot
.40307 .28723 Mdot
.16013 .3385 Mdot
.52648 .57908 Mdot
.54037 .34123 Mdot
.85906 .47895 Mdot
.604 .80447 Mdot
.42982 .55463 Mdot
.19124 .50206 Mdot
.42721 .22544 Mdot
.64769 .30766 Mdot
.48335 .3975 Mdot
.74257 .72956 Mdot
.68104 .31132 Mdot
.83907 .587 Mdot
.40298 .8222 Mdot
.26292 .36373 Mdot
.53034 .37522 Mdot
.67946 .56931 Mdot
.55384 .34258 Mdot
.59376 .33758 Mdot
.85047 .50325 Mdot
.39148 .25634 Mdot
.57531 .48673 Mdot
.61829 .71543 Mdot
.6905 .69611 Mdot
.44816 .2975 Mdot
.22007 .63821 Mdot
.34397 .73616 Mdot
.53312 .26371 Mdot
.55058 .79726 Mdot
.60444 .26936 Mdot
.28011 .32242 Mdot
.5377 .21157 Mdot
.40825 .60803 Mdot
.68222 .58048 Mdot
.64887 .49335 Mdot
.82207 .54475 Mdot
.66501 .73937 Mdot
.26598 .69249 Mdot
.70723 .26919 Mdot
.36575 .70804 Mdot
.57063 .32839 Mdot
.79431 .56247 Mdot
.40687 .63946 Mdot
.72662 .54192 Mdot
.46116 .23493 Mdot
.37407 .2681 Mdot
.62916 .7623 Mdot
.50642 .45992 Mdot
.64196 .80842 Mdot
.54299 .23355 Mdot
.81465 .51669 Mdot
.61403 .42821 Mdot
.31208 .43744 Mdot
.22286 .44708 Mdot
.73975 .32411 Mdot
.47875 .59785 Mdot
.85266 .37867 Mdot
.35628 .51739 Mdot
.8411 .60424 Mdot
.55399 .65653 Mdot
.38554 .18919 Mdot
.62312 .78057 Mdot
.48183 .55165 Mdot
.53896 .50035 Mdot
.32039 .73625 Mdot
.38066 .73011 Mdot
.44134 .80836 Mdot
.39229 .58668 Mdot
.62208 .57236 Mdot
.58456 .48469 Mdot
.49167 .72211 Mdot
.8044 .58713 Mdot
.40322 .37886 Mdot
.62422 .48622 Mdot
.57257 .38583 Mdot
.51316 .6768 Mdot
.46446 .83043 Mdot
.62135 .75104 Mdot
.40943 .45427 Mdot
.6218 .26792 Mdot
.84726 .47457 Mdot
.57998 .83286 Mdot
.41017 .55711 Mdot
.39964 .31752 Mdot
.59881 .66212 Mdot
.79909 .3788 Mdot
.77857 .64864 Mdot
.66792 .70705 Mdot
.44723 .67435 Mdot
.5637 .23574 Mdot
.83907 .65086 Mdot
.85902 .43447 Mdot
.71974 .27244 Mdot
.54331 .50912 Mdot
.31368 .50894 Mdot
.37925 .23472 Mdot
.81347 .52151 Mdot
.24252 .69532 Mdot
.56381 .81368 Mdot
.60292 .27456 Mdot
.52517 .16273 Mdot
.22228 .36031 Mdot
.61841 .46399 Mdot
.2236 .44843 Mdot
.32977 .4495 Mdot
.5169 .64233 Mdot
.63942 .31707 Mdot
.6037 .46059 Mdot
.5606 .68236 Mdot
.33101 .72721 Mdot
.39251 .70174 Mdot
.81601 .5121 Mdot
.33998 .26693 Mdot
.39193 .32313 Mdot
.78818 .60863 Mdot
.3077 .6054 Mdot
.78617 .51314 Mdot
.79304 .42053 Mdot
.60585 .46478 Mdot
.63826 .56901 Mdot
.45207 .46656 Mdot
.46086 .62685 Mdot
.47554 .63971 Mdot
.61502 .20206 Mdot
.69757 .35777 Mdot
.35002 .5076 Mdot
.19372 .40438 Mdot
.37748 .55719 Mdot
.74926 .74268 Mdot
.50195 .74304 Mdot
.24665 .36782 Mdot
.50524 .60778 Mdot
.66774 .64321 Mdot
.60661 .18499 Mdot
.38034 .28766 Mdot
.72235 .36182 Mdot
.2859 .53197 Mdot
.30011 .5447 Mdot
.50633 .61474 Mdot
.41026 .7109 Mdot
.30653 .31982 Mdot
.19433 .58543 Mdot
.78893 .40889 Mdot
.37878 .54037 Mdot
.61119 .47321 Mdot
.36988 .46178 Mdot
.64396 .81483 Mdot
.6276 .5684 Mdot
.85818 .40432 Mdot
.51286 .35358 Mdot
.79337 .3575 Mdot
.46671 .83407 Mdot
.43093 .65046 Mdot
.54851 .50721 Mdot
.71619 .58541 Mdot
.40587 .42216 Mdot
.39818 .31322 Mdot
.31699 .5407 Mdot
.81439 .47796 Mdot
.67351 .38228 Mdot
.65579 .26999 Mdot
.59789 .64923 Mdot
.20101 .55118 Mdot
.22851 .64384 Mdot
.29464 .55416 Mdot
.64638 .43976 Mdot
.75895 .55251 Mdot
.54701 .4497 Mdot
.57315 .38873 Mdot
.82722 .53866 Mdot
.34075 .29909 Mdot
.36237 .52461 Mdot
.71993 .27534 Mdot
.59505 .37918 Mdot
.5434 .86134 Mdot
.40771 .48006 Mdot
.56313 .36775 Mdot
.55091 .43183 Mdot
.31319 .72151 Mdot
.29136 .31337 Mdot
.64198 .77445 Mdot
.60981 .24663 Mdot
.50419 .48687 Mdot
.59684 .29207 Mdot
.41972 .46109 Mdot
.61257 .72177 Mdot
.22337 .66248 Mdot
.53663 .16547 Mdot
.23521 .47725 Mdot
.4113 .67004 Mdot
.29536 .60428 Mdot
.20859 .6028 Mdot
.35604 .51342 Mdot
.66964 .44329 Mdot
.3342 .32652 Mdot
.62186 .78221 Mdot
.59239 .83985 Mdot
.56406 .82741 Mdot
.54598 .32604 Mdot
.67951 .70398 Mdot
.45046 .24628 Mdot
.38476 .47809 Mdot
.4929 .55274 Mdot
.40598 .42629 Mdot
.44998 .2999 Mdot
.41896 .57742 Mdot
.2796 .69922 Mdot
.51511 .33398 Mdot
.69819 .75423 Mdot
.5409 .85975 Mdot
.76825 .69659 Mdot
.72932 .63424 Mdot
.31915 .59874 Mdot
.86303 .46177 Mdot
.26803 .31724 Mdot
.60633 .81245 Mdot
.24092 .54846 Mdot
.15366 .55332 Mdot
.83175 .42598 Mdot
.59927 .77477 Mdot
.2869 .62875 Mdot
.34227 .78072 Mdot
.47221 .8273 Mdot
.15131 .51931 Mdot
.43744 .26557 Mdot
.45547 .82664 Mdot
.84841 .36942 Mdot
.2411 .52741 Mdot
.38135 .72011 Mdot
.21735 .44627 Mdot
.4174 .26523 Mdot
.17854 .56341 Mdot
.42701 .33302 Mdot
.6772 .55979 Mdot
.72747 .40761 Mdot
.59343 .26911 Mdot
.46771 .46725 Mdot
.1727 .54837 Mdot
.59165 .34114 Mdot
.56304 .31592 Mdot
.76001 .52321 Mdot
.82979 .43879 Mdot
.30051 .31088 Mdot
.38007 .40643 Mdot
.29048 .5383 Mdot
.6581 .39856 Mdot
.50088 .25331 Mdot
.42362 .36485 Mdot
.50288 .56798 Mdot
.52739 .32942 Mdot
.8034 .67479 Mdot
.71296 .4445 Mdot
.593 .5419 Mdot
.35472 .59351 Mdot
.34611 .74728 Mdot
.77105 .6146 Mdot
.35249 .68401 Mdot
.16822 .52513 Mdot
.35829 .28368 Mdot
.75239 .69337 Mdot
.3796 .6998 Mdot
.55377 .25377 Mdot
.56697 .19178 Mdot
.54654 .66919 Mdot
.32257 .47337 Mdot
.84683 .50704 Mdot
.34937 .70256 Mdot
.29916 .60118 Mdot
.56597 .77942 Mdot
.62567 .71885 Mdot
.34104 .71213 Mdot
.45398 .81344 Mdot
.77723 .54944 Mdot
.2426 .40373 Mdot
.80829 .61237 Mdot
.67616 .56848 Mdot
.57433 .2681 Mdot
.53623 .77608 Mdot
.17755 .56741 Mdot
.54392 .45173 Mdot
.66053 .79054 Mdot
.49714 .54716 Mdot
.70705 .30963 Mdot
.41713 .40807 Mdot
.32145 .27971 Mdot
.29188 .70545 Mdot
.55155 .79166 Mdot
.33277 .63836 Mdot
.29941 .59134 Mdot
.25019 .66492 Mdot
.71104 .5081 Mdot
.66556 .30872 Mdot
.46076 .26122 Mdot
.25223 .60269 Mdot
.65481 .4245 Mdot
.43592 .72748 Mdot
.50528 .34355 Mdot
.70883 .29868 Mdot
.71604 .66985 Mdot
.30978 .48615 Mdot
.25101 .52521 Mdot
.82232 .54843 Mdot
.74157 .62918 Mdot
.2613 .69516 Mdot
.25531 .53591 Mdot
.38193 .78298 Mdot
.23923 .34098 Mdot
.34679 .66455 Mdot
.49451 .35155 Mdot
.66931 .44308 Mdot
.36753 .54453 Mdot
.80724 .58806 Mdot
.39092 .50809 Mdot
.71332 .31778 Mdot
.45745 .5701 Mdot
.76255 .59167 Mdot
.60385 .42765 Mdot
.46998 .8326 Mdot
.34234 .78099 Mdot
.61324 .25896 Mdot
.58597 .66736 Mdot
.47107 .66823 Mdot
.39447 .65451 Mdot
.66946 .77085 Mdot
.40583 .58754 Mdot
.35231 .39299 Mdot
.39856 .67735 Mdot
.33137 .39161 Mdot
.42504 .82595 Mdot
.63985 .27744 Mdot
.49018 .55771 Mdot
.36099 .34922 Mdot
.43948 .74575 Mdot
.42852 .73064 Mdot
.73137 .43789 Mdot
.2891 .30062 Mdot
.56517 .58123 Mdot
.5663 .50596 Mdot
.48386 .32374 Mdot
.37328 .23602 Mdot
.79921 .61741 Mdot
.42639 .54903 Mdot
.49122 .54525 Mdot
.8019 .46212 Mdot
.67901 .30415 Mdot
.28525 .21779 Mdot
.83279 .63456 Mdot
.4162 .40605 Mdot
.54907 .48876 Mdot
.65376 .27412 Mdot
.64965 .50314 Mdot
.31012 .3335 Mdot
.82021 .55939 Mdot
.58084 .63284 Mdot
.77103 .48654 Mdot
.41779 .7049 Mdot
.31071 .72851 Mdot
.75022 .33346 Mdot
.52195 .63448 Mdot
.76063 .73503 Mdot
.55603 .81315 Mdot
.29174 .69773 Mdot
.22392 .26338 Mdot
.27072 .68001 Mdot
.42237 .49885 Mdot
.74915 .53853 Mdot
.78304 .69163 Mdot
.53899 .51594 Mdot
.76304 .50125 Mdot
.25325 .51734 Mdot
.61177 .25409 Mdot
.5655 .29099 Mdot
.31634 .66005 Mdot
.25742 .65882 Mdot
.14722 .50157 Mdot
.66967 .64084 Mdot
.63843 .20603 Mdot
.2856 .33792 Mdot
.8156 .61462 Mdot
.49025 .74854 Mdot
.51331 .16182 Mdot
.58126 .8423 Mdot
.6134 .31001 Mdot
.1799 .54788 Mdot
.72568 .49416 Mdot
.65614 .25381 Mdot
.35598 .23587 Mdot
.47002 .76861 Mdot
.34776 .29723 Mdot
.6497 .64975 Mdot
.34477 .64671 Mdot
.60119 .29067 Mdot
.33076 .42102 Mdot
.49336 .55617 Mdot
.84143 .54457 Mdot
.16728 .48216 Mdot
.58004 .23402 Mdot
.78566 .48221 Mdot
.67148 .26411 Mdot
.78398 .6248 Mdot
.72202 .6811 Mdot
.56157 .43897 Mdot
.80965 .33074 Mdot
.85674 .52699 Mdot
.35895 .66778 Mdot
.45725 .33569 Mdot
.55401 .86316 Mdot
.57762 .43906 Mdot
.25881 .51847 Mdot
.49418 .8208 Mdot
.54868 .28633 Mdot
.51617 .32255 Mdot
.46671 .33277 Mdot
.43307 .24816 Mdot
.28498 .62348 Mdot
.33189 .42791 Mdot
.76513 .36827 Mdot
.58529 .23313 Mdot
.16984 .486 Mdot
.75166 .31954 Mdot
.41459 .48318 Mdot
.35791 .52891 Mdot
.79175 .68446 Mdot
.36832 .31466 Mdot
.36637 .37685 Mdot
.22486 .41185 Mdot
.40357 .58119 Mdot
.68389 .59066 Mdot
.40376 .31566 Mdot
.44906 .6466 Mdot
.58897 .27299 Mdot
.8095 .53669 Mdot
.3317 .47715 Mdot
.84838 .34563 Mdot
.46806 .83777 Mdot
.37731 .53215 Mdot
.2757 .49569 Mdot
.6173 .45917 Mdot
.77525 .68572 Mdot
.66294 .62942 Mdot
.79054 .41634 Mdot
.18568 .40615 Mdot
.623 .23854 Mdot
.48594 .42892 Mdot
.47303 .79364 Mdot
.61114 .82448 Mdot
.16702 .43814 Mdot
.64242 .80753 Mdot
.52833 .36227 Mdot
.4408 .31764 Mdot
.50419 .12849 Mdot
.73377 .70436 Mdot
.52079 .42727 Mdot
.2965 .62817 Mdot
.29898 .62025 Mdot
.41039 .40908 Mdot
.39624 .71598 Mdot
.50511 .23881 Mdot
.56712 .29936 Mdot
.70944 .74963 Mdot
.35583 .58952 Mdot
.53057 .53198 Mdot
.57186 .60058 Mdot
.5232 .52425 Mdot
.39114 .44215 Mdot
.57359 .61429 Mdot
.57036 .30915 Mdot
.57393 .45351 Mdot
.61295 .63661 Mdot
.41555 .27951 Mdot
.45325 .72028 Mdot
.42236 .28471 Mdot
.56381 .34658 Mdot
.26139 .55627 Mdot
.25255 .3102 Mdot
.59174 .33901 Mdot
.60037 .35796 Mdot
.45501 .82268 Mdot
.24058 .72098 Mdot
.51982 .56404 Mdot
.33782 .49349 Mdot
.41556 .49131 Mdot
.28145 .3119 Mdot
.23366 .40723 Mdot
.60871 .59596 Mdot
.42451 .73071 Mdot
.51643 .33908 Mdot
.3608 .34336 Mdot
.55303 .60917 Mdot
.82037 .67023 Mdot
.4443 .32535 Mdot
.27826 .3696 Mdot
.65247 .78066 Mdot
.79054 .50901 Mdot
.48208 .283 Mdot
.40351 .42212 Mdot
.44678 .5076 Mdot
.57833 .44817 Mdot
.35776 .43842 Mdot
.80286 .49572 Mdot
.78374 .65598 Mdot
.50101 .28092 Mdot
.26929 .36946 Mdot
.45288 .40836 Mdot
.65284 .34341 Mdot
.45339 .62186 Mdot
.61868 .21148 Mdot
.71651 .34637 Mdot
.58029 .82947 Mdot
.57184 .34457 Mdot
.55253 .28675 Mdot
.20614 .43621 Mdot
.83737 .59907 Mdot
.39117 .66366 Mdot
.25774 .36715 Mdot
.42656 .59092 Mdot
.57187 .75675 Mdot
.59854 .32907 Mdot
.52382 .60571 Mdot
.48647 .31339 Mdot
.28444 .61767 Mdot
.70072 .77222 Mdot
.37862 .28999 Mdot
.59898 .59602 Mdot
.63173 .76281 Mdot
.23991 .34355 Mdot
.5379 .50049 Mdot
.18466 .30497 Mdot
.67771 .61485 Mdot
.76592 .7285 Mdot
.79609 .53909 Mdot
.53 .45432 Mdot
.32587 .72094 Mdot
.47627 .45945 Mdot
.63254 .53297 Mdot
.77925 .67429 Mdot
.37188 .45641 Mdot
.33812 .6631 Mdot
.42197 .3431 Mdot
.447 .52145 Mdot
.35589 .409 Mdot
.66343 .72029 Mdot
.66393 .56797 Mdot
.40825 .56375 Mdot
.71987 .68928 Mdot
.58013 .44596 Mdot
.16396 .58492 Mdot
.85119 .50381 Mdot
.70884 .72872 Mdot
.7014 .68465 Mdot
.3905 .18206 Mdot
.28428 .53666 Mdot
.37869 .47555 Mdot
.56776 .67691 Mdot
.44362 .24678 Mdot
.34327 .70711 Mdot
.8089 .52704 Mdot
.37043 .78092 Mdot
.5507 .44616 Mdot
.12751 .38778 Mdot
.60589 .30653 Mdot
.42812 .53366 Mdot
.32442 .69588 Mdot
.68839 .76063 Mdot
.77828 .4363 Mdot
.37851 .80136 Mdot
.50108 .75859 Mdot
.41506 .457 Mdot
.33711 .2527 Mdot
.72894 .29172 Mdot
.65425 .70769 Mdot
.62725 .1971 Mdot
.67373 .72541 Mdot
.51834 .24739 Mdot
.54564 .78945 Mdot
.37906 .55828 Mdot
.38028 .58289 Mdot
.50171 .73618 Mdot
.43941 .70515 Mdot
.29373 .50892 Mdot
.77061 .66627 Mdot
.50355 .19208 Mdot
.80194 .43618 Mdot
.74828 .70863 Mdot
.5426 .70602 Mdot
.29485 .60668 Mdot
.58757 .34155 Mdot
.69988 .39398 Mdot
.66667 .50405 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0:3ooooo0_l0002Wooooo`007?ooool00ol0003oooooooooo`2Pooooo`;o0000Yoooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0Q?ooool2o`00
0<?ooooo000Looooo`03o`000?oooooooooo08Cooooo0_l0000Pooooo`;o0000XOooool001cooooo
00?o0000ooooooooool0S_ooool2o`0001Kooooo0_l0002Qooooo`007?ooool2o`0008oooooo0_l0
000>ooooo`?o0000Z?ooool001cooooo00?o0000ooooooooool0W_ooool3o`0001Oooooo0_l0002?
ooooo`007?ooool00ol0003oooooooooo`1iooooo`;o00001oooool2o`0001Gooooo0_l0000Moooo
o`;o0000Soooool001cooooo00?o0000ooooooooool0NOooool2o`0000Oooooo0_l0000Eooooo`;o
00002?ooool2o`0000;ooooo0_l0002Pooooo`007?ooool00ol0003oooooooooo`2Sooooo`;o0000
0_ooool6o`0009cooooo000Looooo`03o`000?oooooooooo087ooooo0_l0000Vooooo`Co00004ooo
ool2o`0008Oooooo000Looooo`03o`000?oooooooooo087ooooo0_l00006ooooo`;o0000=Oooool2
o`0008Oooooo000Looooo`03o`000?oooooooooo08Wooooo0_l0000Xooooo`;o0000U?ooool001co
oooo00?o0000ooooooooool0/oooool5o`00097ooooo000Looooo`03o`000?oooooooooo06Wooooo
0_l00008ooooo`Go0000??ooool4o`0000Gooooo0_l0002:ooooo`007?ooool00ol0003ooooooooo
o`1Yooooo`;o00002?ooool5o`0000?ooooo0_l00010ooooo`;o0000R_ooool001cooooo00?o0000
ooooooooool0LOooool2o`0000Sooooo0_l000000ooooooo0000o`000011ooooo`;o0000Q_ooool0
01cooooo00?o0000ooooooooool0LOooool2o`0000Kooooo0_l00003ooooo`;o00008_ooool3o`00
00Gooooo0_l0000Eooooo`;o0000Q_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2
ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo07Wooooo0_l0000Uooooo`Go00001Oooool2
o`0000Sooooo0_l00008ooooo`;o0000ROooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Ooo
ool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo06Oooooo
0_l00003ooooo`;o0000<_ooool4o`0000Sooooo0_l00006ooooo`;o00002?ooool3o`0008Sooooo
00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00ol0003oooooooooo`1Wooooo`;o000000?oooooo`000?l000000_l0000dooooo`;o00001_oo
ool4o`00017ooooo0_l00007ooooo`;o0000Ooooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool02oooool00onHV9So8B4Qonk^kP06ooooo`?o0000H_ooool2o`0000Kooooo0_l0000n
ooooo`?o00005oooool2o`0000;ooooo0_l0001oooooo`0000?oooooo`000?ooool00_ooool00ol0
003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0H_ooool2o`00
04kooooo0ol0000?ooooo`;o00001_ooool2o`0007_ooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2booooo`?o
00002_ooool2o`0000Sooooo0_l000001?oooooo0000o`000?l0001jooooo`0000KoooooogMgMonH
V9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003ooooooooo
o`1Pooooo`;o0000??ooool2o`0000Oooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0
003o000000Co00000oooool2o`000004ooooool0003o0000o`0000Cooooo0_l00002ooooo`;o0000
0_ooool2o`0007[ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c006ooooo`03o`000?oooooooooo063ooooo0_l0000looooo`;o00001_ooool3o`00
00;ooooo0ol000001?oooooo0000o`000?ooool6o`0000?ooooo0_l000000ooooooo0000o`000005
ooooo`;o0000P_ooool001cooooo00?o0000ooooooooool0FOooool2o`0000Oooooo0_l0000koooo
o`;o00001Oooool8o`0000cooooo0ol0002<ooooo`007?ooool00ol0003oooooooooo`1Iooooo`Co
00001Oooool2o`0003_ooooo0_l000000ooooooo0000o`000003ooooo`Go000000?oooooo`000?l0
00002oooool2o`0008gooooo000Looooo`03o`000?oooooooooo05_ooooo0_l0000Wooooo`;o0000
5_ooool2o`0000Cooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l0000=ooooo`;o
000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000007ooooo`;o00002Oooool2o`00
06kooooo000Looooo`03o`000?oooooooooo05_ooooo0_l000000ooooooo0000o`00000Qooooo`;o
000000?oooooo`000?l000000ol000000ooooooo0000o`000003o`000003ooooool0003o000000;o
00001Oooool2o`000003ooooool0003o000000;ooooo0_l00003ooooo`Co00001?ooool2o`0000So
oooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo1Ol00007ooooo`;o00000_ooool2o`00
00Gooooo0_l0001^ooooo`007?ooool00ol0003oooooooooo`1Kooooo`;o000000?oooooo`000?l0
00008Oooool2o`000003ooooool0003o000000?o000000?oooooo`000?l000000ol000000ooooooo
0000o`000005o`0000;ooooo0_l00005ooooo`Co000000?oooooo`000?l000000_l000000ooooooo
0000o`00000;ooooo`Co00001oooool4o`000003ooooool0003o000000Wooooo0_l0001eooooo`00
7?ooool00ol0003oooooooooo`1Qooooo`;o00005?ooool2o`0001Oooooo2_l00007ooooo`?o0000
0oooool2o`000003ooooool0003o000000Co00000oooool2o`0000Cooooo0ol00006ooooo`Oo0000
2Oooool2o`0007Gooooo000Looooo`03o`000?oooooooooo067ooooo0_l00007ooooo`;o00001?oo
ool5o`000004ooooool0003o0000o`0001Wooooo0_l000000ooooooo0000o`000005o`0000cooooo
0_l000000ooooooo0000o`000003o`0000?ooooo0_l00004ooooo`?o00001oooool2o`000003oooo
ool0003o000000[ooooo0_l0001eooooo`007?ooool00ol0003oooooooooo`1Zooooo`?o00000ooo
ool9o`0000;ooooo0_l0000Eooooo`;o00001_ooool2o`0000?ooooo0ol00006ooooo`;o00002Ooo
ool2o`0000Cooooo0_l00003ooooo`;o00000oooool2o`000003ooooool0003o000000Go0000O?oo
ool001cooooo00?o0000ooooooooool0Joooool2o`0000Cooooo0_l000000ooooooo0000o`000002
ooooo`;o000000?oooooo`000?l000005Oooool2o`0000?ooooo0_l00004ooooo`Go00001Oooool2
o`0001Gooooo0_l000000ooooooo0000o`000003ooooo`Wo0000N_ooool001cooooo00?o0000oooo
ooooool0FOooool3o`0001cooooo0_l0000Mooooo`;o00001?ooool5o`0000Gooooo0ol00003oooo
o`;o00004_ooool2o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l0001hoooo
o`007?ooool00ol0003oooooooooo`1:ooooo`;o00003Oooool3o`0002gooooo0_l000001?oooooo
0000o`000?ooool2o`0000oooooo0_l00002ooooo`?o000000?oooooo`000?l000000oooool2o`00
01?ooooo0_l0000;ooooo`;o0000N?ooool001cooooo0_l0001;ooooo`;o00007Oooool2o`0001_o
oooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000cooooo0_l00005oooo
o`Go00006?ooool3o`0008Gooooo000Looooo`03o`000?oooooooooo067ooooo0_l00006ooooo`?o
00002oooool2o`0000Kooooo0_l00005ooooo`;o000000?oooooo`000?l000004_ooool4o`000003
ooooool0003o000000Go00000oooool2o`0000;ooooo0_l00005ooooo`;o00001oooool6o`0000_o
oooo0_l0000;ooooo`;o0000JOooool001cooooo00?o0000ooooooooool0E?ooool2o`0000_ooooo
0_l00007ooooo`;o00001Oooool2o`000003ooooool0003o000000Co000000?oooooo`000?l00000
0_ooool2o`0001kooooo0_l000000ooooooo0000o`000002ooooo`;o00001?ooool2o`0000;ooooo
0_l00005ooooo`;o00001oooool6o`0000_ooooo0_l0000;ooooo`;o0000JOooool001cooooo00?o
0000ooooooooool0B?ooool2o`0000[ooooo0_l0000Kooooo`;o000000?oooooo`000?l000001?l0
00000ooooooo0000o`00000;ooooo`;o00002?ooool2o`0002_ooooo1_l00024ooooo`007?ooool0
0ol0003oooooooooo`15ooooo`;o000000?oooooo`000?l000005_ooool2o`0001;ooooo0_l0000B
ooooo`?o00000_ooool2o`0000?ooooo0_l0000Eooooo`;o00002_ooool2o`0000Cooooo0_l00002
ooooo`?o000000?oooooo`000?l000000oooool2o`0000;ooooo0_l00008ooooo`;o00007?ooool2
o`0005?ooooo000Looooo`03o`000?oooooooooo04Gooooo0_l0000Iooooo`;o00002Oooool2o`00
00Cooooo1Ol00006ooooo`;o00001_ooool2o`0000?ooooo0ol000000ooooooo0000o`000002oooo
o`;o00002_ooool2o`0000[ooooo0_l0000:ooooo`;o00001?ooool2o`0000?ooooo0_l00006oooo
o`;o00000_ooool2o`0000Sooooo0_l000000ooooooo0000o`00000Iooooo`;o0000Doooool001co
oooo00?o0000ooooooooool0G_ooool2o`0000_ooooo0ol00003ooooo`Co000000?oooooo`000?l0
00001?ooool2o`0000Kooooo0_l00004ooooo`;o00000oooool4o`0000Gooooo0_l00003ooooo`?o
00002?ooool2o`0000gooooo0_l00004ooooo`;o00000_ooool2o`0000;ooooo0ol000000ooooooo
0000o`000006ooooo`;o00001_ooool2o`0000Oooooo0_l0001Uooooo`007?ooool00ol0003ooooo
ooooo`1Looooo`Co00001?ooool2o`0000Kooooo0_l00002ooooo`Co000000Coooooo`000?l0003o
00005oooool4o`0000Cooooo0ol00004ooooo`;o00001_ooool4o`0000gooooo0_l00003ooooo`Co
000000?oooooo`000?l000000_ooool3o`000003ooooool0003o000000?ooooo0_l000000ooooooo
0000o`000007ooooo`;o00001_ooool2o`0000;ooooo0_l0001Qooooo`007?ooool00ol0003ooooo
ooooo`1Kooooo`?o00001_ooool2o`0000[ooooo0_l00003ooooo`;o00002?ooool2o`0000Wooooo
1_l000000ooooooo0000o`000004ooooo`;o00003Oooool2o`0000;ooooo0_l00004ooooo`;o0000
2_ooool6o`0000Sooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00000oooool3o`000003
ooooool0003o000000Sooooo1?l0001Qooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o0000
3?ooool2o`0000Sooooo1?l0000Fooooo`;o00000_ooool2o`0000Gooooo1_l0000:ooooo`;o0000
3_ooool2o`0000Cooooo0_l0000:ooooo`Oo00001_ooool6o`0000;ooooo0_l00003ooooo`Co0000
0_ooool2o`0000Kooooo1?l0001Qooooo`007?ooool00ol0003oooooooooo`1<ooooo`?o00001_oo
ool2o`0000?ooooo0_l00008ooooo`Ko000000?oooooo`000?l000002oooool2o`0000Wooooo0_l0
0003ooooo`;o00002_ooool4o`000004ooooool0003o0000o`0000?ooooo0_l00003ooooo`;o0000
3Oooool2o`0000Oooooo0_l00003ooooo`;o00001_ooool2o`000004ooooool0003o0000o`0000Wo
oooo0_l00002ooooo`;o0000Joooool001cooooo00?o0000ooooooooool0C?ooool2o`0000Oooooo
0_l00003ooooo`;o00001oooool3o`0000;ooooo0_l000001?oooooo0000o`000?l00003ooooo`Go
00000_ooool2o`0000_ooooo0_l000000ooooooo0000o`00000:ooooo`Co000000?oooooo`000?l0
00001?ooool2o`0000?ooooo0_l0000:ooooo`;o000000?oooooo`000?l000001oooool2o`0001_o
oooo0_l0001^ooooo`007?ooool00ol0003oooooooooo`1Booooo`;o00003oooool2o`0000Oooooo
0_l00003ooooo`Go00000_ooool2o`0000Gooooo0_l00004ooooo`;o00002Oooool2o`0001cooooo
1?l0000=ooooo`;o00001?ooool2o`0000Cooooo0_l0000<ooooo`;o00001Oooool2o`0006Oooooo
000Looooo`03o`000?oooooooooo05;ooooo0_l0000Sooooo`?o00000oooool4o`0000Sooooo0_l0
0005ooooo`;o00007?ooool4o`0000;ooooo0_l00007ooooo`Ko00000_ooool2o`0000Cooooo0_l0
0006ooooo`Co00002Oooool2o`0000Oooooo0_l0001Nooooo`007?ooool00ol0003oooooooooo`1B
ooooo`;o00003Oooool2o`0001Cooooo0ol00003ooooo`;o00000oooool2o`0000Gooooo0_l00005
ooooo`;o00002oooool2o`0000?ooooo0_l0000@ooooo`Co00001Oooool6o`0000;ooooo0_l00003
ooooo`;o00000oooool:o`0000Cooooo0_l00002ooooo`;o00001_ooool2o`0005kooooo000Loooo
o`03o`000?oooooooooo053ooooo0_l0000?ooooo`;o00002_ooool2o`0001?ooooo0_l0000:oooo
o`Co00002oooool2o`0000?ooooo0_l00006ooooo`;o00002Oooool3o`0000gooooo0_l00003oooo
o`;o00000oooool4o`000003ooooool0003o000000Go00000_ooool2o`0000;ooooo0_l0001Voooo
o`007?ooool2o`00057ooooo0_l00008ooooo`;o000000Coooooo`000?l0003ooooo0_l00009oooo
o`Co00006oooool2o`0000;ooooo0_l0000=ooooo`;o00002oooool2o`0000Sooooo0_l00007oooo
o`?o00003Oooool2o`0000Gooooo0ol00002ooooo`;o00000_ooool2o`000003ooooool0003o0000
00;o0000IOooool001cooooo00?o0000ooooooooool0AOooool2o`0001?ooooo0_l000001?oooooo
0000o`000?ooool2o`0000Wooooo0_l0000Aooooo`;o00002_ooool2o`0000;ooooo0_l00009oooo
o`;o00006Oooool2o`0000Oooooo0ol00005ooooo`?o00001Oooool2o`0000Kooooo0_l00002oooo
o`?o000000Coooooo`000?l0003ooooo1?l0000:ooooo`;o0000FOooool001cooooo00?o0000oooo
ooooool0>?ooool2o`0000_ooooo0_l0000<ooooo`Co00002oooool2o`0001[ooooo0_l00002oooo
o`;o00003_ooool4o`0000?ooooo0_l00009ooooo`;o00006oooool2o`0000;ooooo0ol00006oooo
o`?o00002?ooool3o`0000Kooooo0_l00005ooooo`;o00000oooool2o`0005Wooooo000Looooo`03
o`000?oooooooooo03Sooooo0_l0000Dooooo`?o00000_ooool4o`0000Oooooo0_l00002ooooo`;o
00003_ooool2o`0000kooooo0_l00003ooooo`;o00002Oooool6o`0000cooooo0_l00005ooooo`;o
00002?ooool2o`0000Sooooo1_l00009ooooo`?o00000oooool2o`0000?ooooo0_l00007ooooo`;o
00001Oooool2o`0005kooooo000Looooo`03o`000?oooooooooo04;ooooo0_l00006ooooo`;o0000
00?oooooo`000?l000000_l00005ooooo`Co000000Coooooo`000?l0003ooooo0_l00004ooooo`;o
00003?ooool4o`0000Sooooo0_l00002ooooo`;o00000oooool2o`0000Wooooo0_l00002ooooo`Ko
00003oooool2o`0000Oooooo0ol00008ooooo`;o00000_ooool2o`0000oooooo0_l00003ooooo`;o
00000_ooool2o`0000?ooooo0_l0001Uooooo`007?ooool00ol0003oooooooooo`12ooooo`;o0000
1_ooool2o`000004ooooool0003o0000o`0000Kooooo1?l000000ooooooo0000o`000007ooooo`;o
00003_ooool2o`0000Sooooo0ol000000ooooooo0000o`000002ooooo`;o00002_ooool2o`0000Co
oooo1?l0000Gooooo`?o00005_ooool2o`0000_ooooo0_l00002ooooo`;o00006?ooool2o`00053o
oooo000Looooo`03o`000?oooooooooo05?ooooo0_l00002ooooo`Co00000oooool4o`0001;ooooo
0_l00008ooooo`?o00001Oooool3o`0000;ooooo0_l000000ooooooo0000o`000003o`0000Oooooo
0_l0000Booooo`;o00000oooool2o`0001Oooooo0_l00009ooooo`;o00002oooool3o`0000Wooooo
0_l00005ooooo`;o0000D?ooool001cooooo00?o0000ooooooooool0=?ooool2o`0001gooooo0_l0
0002ooooo`Co000000?oooooo`000?l000001?l0000Gooooo`;o000000?oooooo`000?l000000_l0
0007ooooo`;o00000_ooool2o`000003ooooool0003o000000Co00001?ooool4o`0000Sooooo0_l0
0008ooooo`;o00009oooool2o`0000Oooooo0_l00002ooooo`?o00002Oooool2o`0000Sooooo0_l0
001=ooooo`007?ooool00ol0003oooooooooo`0dooooo`;o00008?ooool3o`0000;ooooo0ol0000:
ooooo`;o00003oooool2o`000003ooooool0003o000000Wooooo3Ol00004ooooo`?o00001?ooool2
o`0000?ooooo0_l00004ooooo`;o00000_ooool2o`00033ooooo0_l0000:ooooo`;o00003?ooool2
o`0004gooooo000Looooo`03o`000?oooooooooo05Kooooo0_l00003ooooo`;o00002?ooool2o`00
0004ooooool0003o0000o`0001Wooooo1ol000000ooooooo0000o`000005o`0000Gooooo1Ol00002
ooooo`Co00001Oooool5o`000004ooooool0003o0000ooooo`;o00000oooool2o`0000Oooooo0_l0
000Looooo`Co00002oooool3o`0005[ooooo000Looooo`03o`000?oooooooooo03cooooo0_l0000W
ooooo`;o00000_ooool2o`0001Sooooo4Ol00004ooooo`;o000000?oooooo`000?l000001?ooool2
o`0000Gooooo1Ol00004ooooo`;o00000oooool2o`0000Gooooo1?l0000Dooooo`;o00001?ooool:
o`0000Sooooo0_l0000Dooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0;Oooool2o`00
00cooooo0ol00009ooooo`;o00001?ooool2o`0000Cooooo0_l00003ooooo`;o00001oooool2o`00
017ooooo0_l00003ooooo`;o00000_ooool2o`0000Cooooo5ol0000:ooooo`;o00000oooool3o`00
017ooooo1?l00005ooooo`;o00003Oooool2o`0000Cooooo0ol00003ooooo`Co00002oooool2o`00
017ooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o000000?oooooo`000?l0
00002Oooool2o`0000[ooooo0_l00004ooooo`?o00000oooool2o`0000?ooooo0ol00006ooooo`;o
00004Oooool2o`0000?ooooo0_l00002ooooo`;o00001ooooolCo`0000;ooooo0_l00005ooooo`Co
00005oooool3o`0000?ooooo0_l000000ooooooo0000o`00000;ooooo`Co00000_ooool2o`000003
ooooool0003o000000Cooooo0_l0000;ooooo`?o0000Eoooool001cooooo00?o0000ooooooooool0
<?ooool2o`0001Sooooo0_l00002ooooo`;o00000_ooool2o`0000Gooooo0_l000001?oooooo0000
o`000?ooool2o`00017ooooo0_l00006ooooo`;o00000oooool2o`000004ooooool0003o0000oooo
o`?o000000?oooooo`000?l000004_l00005ooooo`Co00000_ooool2o`0000;ooooo0_l0000=oooo
o`Co00001?ooool2o`0000cooooo1_l000001?oooooo0000o`000?l0000Dooooo`?o0000Eoooool0
01cooooo00?o0000ooooooooool0B_ooool2o`0000Gooooo0ol00008ooooo`;o000000?oooooo`00
0?l000002_ooool3o`0000?ooooo1?l00002ooooo`;o000000?oooooo`000?l000000_ooool6o`00
0003ooooool0003o000000;o000000?oooooo`000?l000001_l000000ooooooo0000o`000007o`00
00;ooooo1?l000001?oooooo0000o`000?l00002ooooo`;o000000Coooooo`000?l0003o00000_oo
ool2o`0000Cooooo0_l00003ooooo`?o00001oooool2o`0000Wooooo2_l000001?oooooo0000o`00
0?l00004ooooo`;o00003?ooool2o`0000Wooooo0_l0001<ooooo`007?ooool00ol0003ooooooooo
o`1:ooooo`;o00001Oooool2o`0001Sooooo0ol00003ooooo`Co00000_ooool2o`0000;ooooo0_l0
00000ooooooo0000o`000003o`000003ooooool0003o000001Ko00000_ooool4o`000003ooooool0
003o000000Gooooo0ol00002ooooo`?o000000Coooooo`000?l0003ooooo0_l0000;ooooo`Co0000
2Oooool@o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`;o00003_ooool2o`0001;ooooo
0ol0000gooooo`007?ooool2o`0004_ooooo0_l00002ooooo`;o00008_ooool2o`0000Cooooo1Ol0
0002ooooob;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00002ooooo`?o00000_oo
ool2o`0000kooooo0_l0000;oooooa3o00000_ooool2o`000003ooooool0003o000000Cooooo0_l0
0005ooooo`;o00004oooool2o`0000Kooooo0ol0000gooooo`007?ooool00ol0003oooooooooo`1:
ooooo`;o00000_ooool5o`0001oooooo0_l00004ooooo`Co00000ooooolRo`000003ooooool0003o
000000Co00001?ooool4o`0001oooooo4?l00004ooooo`;o00003?ooool3o`0001?ooooo0_l00010
ooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00002?ooool7o`0002cooooo8ol000000ooo
oooo0000o`000002o`0000Gooooo0_l0000Aooooo`;o00003_oooolBo`0000;ooooo0_l000000ooo
oooo0000o`000009ooooo`;o00004Oooool2o`0000Wooooo0_l0000hooooo`007?ooool00ol0003o
ooooooooo`10ooooo`Co00002?ooool3o`0000Oooooo0_l0000Rooooo`Go000000?oooooo`000?l0
00001?l000000ooooooo0000o`00000Io`000003ooooool0003o000000;ooooo0_l00004ooooo`;o
000000?oooooo`000?l000003Oooool2o`0000kooooo4_l00005ooooo`;o00005_ooool4o`0000;o
oooo0_l00009ooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0@?ooool2o`0000;ooooo
0_l00009ooooo`;o00001Oooool2o`00017ooooo0_l0000<ooooo`;o000000?oooooo`000?l00000
0ol000000ooooooo0000o`00000So`0000;ooooo0ol00002ooooo`?o000000Coooooo`000?l0003o
00003?ooool2o`0000cooooo5?l00006ooooo`;o00005Oooool4o`0004Oooooo000Looooo`03o`00
0?oooooooooo043ooooo0_l00002ooooo`;o00002Oooool2o`000003ooooool0003o000001Gooooo
0_l0000;ooooo`?o00000_ooool2o`0000?ooooo6ol00002ooooo`go00000_ooool2o`000003oooo
ool0003o000000;o00002oooool4o`0000_ooooo5Ol000000ooooooo0000o`000002ooooo`;o0000
5oooool5o`0004Cooooo000Looooo`03o`000?oooooooooo04?ooooo0ol00006ooooo`;o00000_oo
ool6o`0001?ooooo0_l0000;ooooo`Oo00000oooool=o`000003ooooool0003o000000co000000?o
ooooo`000?l000000_l00004ooooo`Co00001_ooool2o`0000;ooooo0_l00009ooooo`Co00001ooo
ool2o`0000;ooooo6?l0000@ooooo`;o00002oooool3o`0000;ooooo0_l00007ooooo`;o0000=ooo
ool001cooooo00?o0000ooooooooool0@oooool3o`0000Gooooo0ol00002ooooo`;o00000_ooool2
o`000003ooooool0003o000001oooooo1ol00002ooooo`So000000?oooooo`000?l000005_l00003
ooooo`;o000000?oooooo`000?l000002?ooool4o`0001?ooooo0_l00002oooooaOo00000_ooool2
o`0000_ooooo1?l0000@ooooo`;o00001oooool2o`0003Oooooo000Looooo`03o`000?oooooooooo
04_ooooo0_l00006ooooo`;o00000_ooool2o`0001oooooo1?l000001?oooooo0000o`000?ooool9
o`000003ooooool0003o000001?o000000?oooooo`000?l000000oooool2o`000003ooooool0003o
000000;o00001_ooool4o`0000Oooooo0_l0000:oooooa[o00000oooool2o`0000_ooooo0_l00005
ooooo`;o00003_ooool2o`0000Gooooo0_l0000fooooo`007?ooool00ol0003oooooooooo`0Xoooo
o`?o00007?ooool2o`0000[ooooo0_l0000Hooooo`;o000000Coooooo`000?l0003ooooo0_l00002
ooooo`So000000?oooooo`000?l000008?l00007ooooo`?o00000oooool2o`0000Wooooo0_l00000
0ooooooo0000o`000002o`0000Sooooo2?l000000ooooooo0000o`00000>o`0001Sooooo0_l0000>
ooooo`;o00001Oooool2o`0003Kooooo000Looooo`03o`000?oooooooooo02Sooooo0ol0000Loooo
o`;o00009?ooool2o`000004ooooool0003o0000ooooo`?o000000?oooooo`000?l00000;?l00005
ooooo`;o00000oooool2o`000003ooooool0003o000000Kooooo0_l00002ooooo`?o00002OoooolJ
o`0001cooooo1?l0000=ooooo`;o0000=_ooool001cooooo00?o0000ooooooooool0?oooool2o`00
00Gooooo0_l0000Yooooo`;o000000Coooooo`000?l0003ooooo3Ol000000ooooooo0000o`00000N
o`0000gooooo0_l00002ooooo`;o00001Oooool3o`0000[ooooo5_l000001?oooooo0000o`000?l0
0002ooooo`;o00005Oooool2o`000003ooooool0003o000000;o0000AOooool001cooooo00?o0000
ooooooooool09_ooool2o`0001Oooooo0_l00005ooooo`?o0000:?ooool2o`0000Cooooo1?l00000
0ooooooo0000o`000004o`000003ooooool0003o000001co000000Coooooo`000?l0003ooooo0_l0
000;ooooo`;o00000_ooool2o`0000Gooooo0_l0000<oooooaCo00000_ooool2o`000003ooooool0
003o000000;o00005Oooool2o`0004[ooooo000Looooo`03o`000?oooooooooo02Kooooo0_l0000F
ooooo`;o00000_ooool2o`0000?ooooo0_l00006ooooo`;o00008?ooool4o`0000Cooooo0ol00000
0ooooooo0000o`00000Uo`000003ooooool0003o000000_ooooo0_l00002ooooo`Co000000?ooooo
o`000?l000003_oooolDo`000005ooooool0003o0000o`000?ooool00_l0000Looooo`;o0000AOoo
ool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413ooooo
ooooo`04ooooo`03o`000?oooooooooo03kooooo0_l00002ooooo`Co000000?oooooo`000?l00000
1_ooool2o`0001Oooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool4o`0000;ooooo
3_l00002oooooaWo00000oooool4o`0000gooooo1?l000000ooooooo0000o`00000<ooooo`;o0000
0_oooolAo`0000;ooooo0ol0000<ooooo`;o00004Oooool2o`0000Gooooo0_l00007ooooo`;o0000
=Oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`11ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Ooooo
o`;o000000?oooooo`000?l000000_ooool8o`0000?ooooo2_l000001?oooooo0000o`000?l00002
oooooaWo00000_ooool4o`0000;ooooo0_l00007ooooo`Co00004Oooool2o`0000;ooooo4Ol00002
ooooo`Co00002oooool2o`0000cooooo0_l0000:ooooo`;o00001oooool2o`0003Gooooo00000ooo
oooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006ooooo`03o`000?oooooooooo
043ooooo0ol00002ooooo`;o00008?ooool3o`0000Oooooo0_l00008ooooobWo00001oooool2o`00
00Kooooo1Ol00002ooooo`Co00003oooool?o`0000Kooooo0_l00008ooooo`;o00003oooool2o`00
00Wooooo0_l0000oooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04
odA4A?oMgMgoooooo`0000Oooooo0ol00010ooooo`;o00000oooool2o`00023ooooo0_l0000Boooo
obKo000000?oooooo`000?l000001?ooool2o`0000;ooooo0_l00005ooooo`;o00001Oooool4o`00
017ooooo3Ol00004ooooo`;o00002Oooool3o`0001[ooooo0_l0000oooooo`0000?oooooo`000?oo
ool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000oooo
ooooool0>Oooool4o`0000Sooooo0_l00004ooooo`;o0000:oooool2o`0000Cooooo8ol00007oooo
o`;o00000_ooool3o`0001gooooo0_l00002ooooo`Wo000000?oooooo`000?l000001?ooool2o`00
00Wooooo0_l0000?ooooo`?o00003?ooool2o`0000Kooooo0_l0000dooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooooooo
ool0>Oooool4o`0000Gooooo1Ol000001?oooooo0000o`000?ooool2o`0000Kooooo0_l0000Koooo
o`;o00000_ooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000007ol00005oooo
o`;o00001_ooool2o`0001cooooo0ol00004ooooo`;o00000oooool2o`000003ooooool0003o0000
00Sooooo0_l00002ooooo`;o000000?oooooo`000?l000003oooool3o`0000;ooooo0_l00007oooo
o`?o00001_ooool2o`0003Cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^
odA4A?l000001oooool00ol0003oooooooooo`0looooo`;o000000Coooooo`000?l0003ooooo1Ol0
00000ooooooo0000o`000009ooooo`;o00005_ooool2o`0000?ooooo0_l00002ooooo`;o00000_oo
ool2o`0000;ooooo9?l00005ooooo`;o00000oooool2o`0000oooooo0_l0000>ooooo`;o000000?o
ooooo`000?l000000oooool2o`0000Gooooo1?l00006ooooo`;o00000_ooool2o`000004ooooool0
003o0000ooooo`;o00003?ooool2o`0000?ooooo0_l00007ooooo`;o0000?Oooool00006ooooooo^
k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo03So
oooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00000Toooo
o`;o00002_ooool3o`000003ooooool0003o000000Co000000?oooooo`000?l000007?l00007oooo
o`;o000000?oooooo`000?l000003oooool2o`0000kooooo0_l000000ooooooo0000o`000005o`00
0003ooooool0003o000000Cooooo0_l00005ooooo`;o00002Oooool2o`0000gooooo0_l0000:oooo
o`;o0000?_ooool001cooooo00?o0000ooooooooool0=oooool3o`0000Sooooo0_l0000?ooooo`;o
00005Oooool2o`0000_ooooo0_l00002ooooo`;o00001OoooolLo`000003ooooool0003o000000Ko
oooo0_l000000ooooooo0000o`00000>ooooo`;o00003?ooool2o`000003ooooool0003o000000;o
oooo1?l00003ooooo`;o00002oooool2o`0001Sooooo0_l0000:ooooo`;o0000?_ooool001cooooo
00?o0000ooooooooool0=oooool2o`000003ooooool0003o000001Kooooo0ol0000Cooooo`Co0000
1oooool2o`000003ooooool0003o000000Sooooo9_l00004ooooo`;o00001oooool2o`0000Gooooo
0_l0000<ooooo`;o00008_ooool2o`0000oooooo0ol00019ooooo`007?ooool00ol0003ooooooooo
o`0jooooo`;o00004?ooool2o`0000Cooooo0_l0000Dooooo`;o000000?oooooo`000?l000001_oo
ool5o`0000;ooooo0_l00003oooooaco000000?oooooo`000?l000002?l00002ooooo`;o00002Ooo
ool2o`00013ooooo0_l0000:ooooo`;o00003_ooool2o`0000Wooooo0_l0000@ooooo`?o0000B?oo
ool001cooooo00?o0000ooooooooool0C?ooool2o`0001[ooooo1Ol00007ooooo`?o00000oooool2
o`000003ooooool0003o000000?o000000Coooooo`000?l0003ooooo2_l000000ooooooo0000o`00
0004o`000003ooooool0003o000000Go000000Goooooo`000?l0003o0000ooooo`03o`000003oooo
ool0003o000000Gooooo0_l0000;ooooo`;o00000_ooool2o`0000?ooooo0_l00003ooooo`;o0000
1Oooool2o`0000kooooo0_l0000@ooooo`;o00002_ooool2o`0000Wooooo0_l0000mooooo`007?oo
ool00ol0003oooooooooo`0Oooooo`;o0000Aoooool4o`0000Kooooo0_l000000ooooooo0000o`00
0002ooooo`;o000000?oooooo`000?l000001Ol00003ooooo`;o00000_oooolEo`000003ooooool0
003o000000So00001?ooool3o`0000_ooooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo1?l0
000Hooooo`;o00001?ooool2o`000003ooooool0003o000000?ooooo0_l0000:ooooo`;o00000ooo
ool2o`000004ooooool0003o0000ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool07ooo
ool2o`0001?ooooo0_l00004ooooo`;o0000;_ooool2o`0000Kooooo0_l000000ooooooo0000o`00
0007o`000003ooooool0003o000000;o00000_oooolHo`0000Kooooo1Ol00006ooooo`?o00000ooo
ool2o`0000kooooo0_l00003ooooo`Co00000oooool2o`0001?ooooo0_l00004ooooo`;o000000?o
ooooo`000?l000001Oooool2o`0000;ooooo0_l00002ooooo`;o00000oooool4o`000004ooooool0
003o0000o`0003oooooo000Looooo`03o`000?oooooooooo03Cooooo0_l000000ooooooo0000o`00
0004o`0000;ooooo1?l0000Wooooo`;o00002Oooool8o`000004ooooool0003o0000o`0000;ooooo
6_l00003ooooo`;o00000_ooool3o`0000Sooooo0_l00003ooooo`;o000000?oooooo`000?l00000
3_ooool6o`0000?ooooo1?l0000Qooooo`;o00000_ooool2o`0000;ooooo0_l00002ooooo`Go0000
0_ooool2o`0000Wooooo0ol0000cooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00000_oo
ool6o`0000;ooooo1?l0000Oooooo`?o00001?ooool2o`0000Gooooo0_l0000<ooooo`?o000000?o
ooooo`000?l000003Ol000001?oooooo0000o`000?l00002ooooo`;o00001?ooool5o`000003oooo
ool0003o000000;o00000oooool4o`0000Gooooo0_l00002ooooo`?o00002_ooool2o`000003oooo
ool0003o000000Co000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000001?ooooo
0_l00006ooooo`;o00001Oooool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000
o`000002ooooo`Co00001?ooool2o`000004ooooool0003o0000o`0003?ooooo000Looooo`03o`00
0?oooooooooo03?ooooo0_l00006ooooo`;o00000_ooool3o`0000kooooo0_l0000@ooooo`?o0000
1?ooool2o`0000Gooooo0_l00009ooooo`;o000000?oooooo`000?l000000_ooool2o`000004oooo
ool0003o0000ooooo`So00000_ooool2o`0000?ooooo1?l00002ooooo`Co00000_ooool4o`000003
ooooool0003o000000Co00000oooool4o`0000?ooooo0_l000000ooooooo0000o`000007ooooo`;o
00002?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000Gooooo0_l0000:ooooo`;o
00001_ooool3o`0000Oooooo0ol00005ooooo`;o00000oooool3o`0000Cooooo0_l00003ooooo`;o
0000<_ooool001cooooo00?o0000ooooooooool0=Oooool2o`0000Wooooo0_l000000ooooooo0000
o`00000;ooooo`;o00005oooool2o`00013ooooo0_l000000ooooooo0000o`000003oooooa3o0000
00Coooooo`000?l0003ooooo1_l000000ooooooo0000o`000002o`0000;ooooo0ol000000ooooooo
0000o`000002o`0000?ooooo1?l00006ooooo`Co00001Oooool2o`0000?ooooo0_l000000ooooooo
0000o`000002ooooo`;o00000_ooool2o`0000;ooooo0ol00005ooooo`;o00001?ooool2o`0000go
oooo0_l000000ooooooo0000o`000005ooooo`;o00002_ooool2o`0000[ooooo0_l0000booooo`00
7?ooool00ol0003oooooooooo`0eooooo`;o00003?ooool4o`00023ooooo0_l00004ooooo`;o0000
3_ooool2o`0000?ooooo2?l00002ooooo`?o000000Goooooo`000?l0003o0000ooooo`02o`000003
ooooool0003o000000;ooooo0_l00003ooooo`;o00000_ooool2o`000004ooooool0003o0000o`00
00Gooooo0_l00007ooooo`?o00001oooool2o`0000?ooooo0_l000000ooooooo0000o`000002oooo
o`;o00001_ooool2o`0000cooooo0_l0000=ooooo`;o000000?oooooo`000?l00000DOooool001co
oooo0_l0000gooooo`;o00003Oooool2o`0001oooooo1?l00003ooooo`;o00003_ooool2o`0000;o
oooo1ol0000<ooooo`Co000000?oooooo`000?l000002?l00004ooooo`?o00000oooool3o`0000So
oooo0_l00005ooooo`;o00003Oooool2o`0002?ooooo0_l0000>ooooo`;o0000A?ooool001cooooo
00?o0000ooooooooool0=_ooool2o`0002kooooo1?l00003ooooo`;o00001oooool2o`0000Wooooo
1?l000001Ooooooo0000o`000?l0003ooooo00?o00001_ooool5o`000003ooooool0003o000000So
00001Oooool2o`0000?ooooo0ol00007ooooo`;o00001_ooool2o`0000cooooo0ol000000ooooooo
0000o`000008ooooo`;o00009_ooool2o`000003ooooool0003o0000047ooooo000Looooo`03o`00
0?oooooooooo03Wooooo0_l000001?oooooo0000o`000?ooool2o`0000Oooooo0ol0000Kooooo`;o
00001Oooool2o`0000Kooooo0ol00002ooooo`;o00001Oooool4o`000005ooooool0003o0000o`00
0?ooool00ol000000ooooooo0000o`000003ooooo`Go00001_ooool2o`0000Sooooo0_l00003oooo
o`;o00002?ooool2o`0001Cooooo0_l00002ooooo`;o00002?ooool2o`0001kooooo0_l00006oooo
o`;o000000?oooooo`000?l00000@Oooool001cooooo00?o0000ooooooooool0=oooool4o`000004
ooooool0003o0000ooooo`;o00001oooool3o`0000?ooooo0_l0000Booooo`;o00000_ooool2o`00
00cooooo0ol00003ooooo`;o00001_ooool6o`0000;ooooo0_l00002ooooo`co00001?ooool2o`00
0003ooooool0003o000000Kooooo0_l0000=ooooo`;o00001_ooool2o`0000?ooooo0_l00006oooo
o`?o00000oooool2o`0000Kooooo0_l0000Mooooo`?o00001Oooool5o`0000kooooo0_l0000boooo
o`007?ooool00ol0003oooooooooo`0gooooo`;o00004?ooool2o`0000?ooooo0_l0000Booooo`;o
00004?ooool3o`000003ooooool0003o000000Sooooo0_l000000ooooooo0000o`000003ooooo`;o
00000_ooool7o`0000;ooooo0ol00007ooooo`;o00001_ooool2o`0000gooooo0_l00002ooooo`;o
00000_ooool3o`0000;ooooo0ol00004ooooo`Co00000oooool2o`0002Gooooo0ol00004ooooo`?o
000000?oooooo`000?l000003_ooool2o`0003;ooooo000Looooo`03o`000?oooooooooo03?ooooo
0ol0000?ooooo`;o00000_ooool2o`000003ooooool0003o000000gooooo0_l00005ooooo`;o0000
2Oooool2o`0000Kooooo0_l000000ooooooo0000o`00000<ooooo`;o00001Oooool4o`000003oooo
ool0003o000000;o00003oooool2o`0001Gooooo0_l000000ooooooo0000o`000008o`0000?ooooo
0_l0000@ooooo`;o00001Oooool2o`0001Cooooo0_l00004ooooo`;o00000_ooool2o`0004;ooooo
000Looooo`03o`000?oooooooooo03?ooooo1?l0000;ooooo`;o000000?oooooo`000?l000001Ooo
ool2o`0000gooooo0_l0000@ooooo`;o00005oooool2o`0000Cooooo1Ol000000ooooooo0000o`00
0002o`0000oooooo0_l0000:ooooo`Co00001_ooool2o`0000;ooooo1_l00002ooooo`?o00005?oo
ool3o`0000Cooooo0_l0000Booooo`Co00002?ooool3o`00047ooooo000Looooo`03o`000?oooooo
oooo03Gooooo0_l0000;ooooo`;o00007oooool4o`000003ooooool0003o000001Gooooo0_l0000;
ooooo`;o00001?ooool2o`0001_ooooo1_l00006ooooo`;o00000oooool5o`0000?ooooo0_l00004
ooooo`Co00003?ooool3o`0000Kooooo0_l0000@ooooo`Co00002Oooool2o`0000gooooo0_l0000b
ooooo`007?ooool00ol0003oooooooooo`0looooo`;o00000_ooool2o`0000Oooooo0_l0000Hoooo
o`Co000000?oooooo`000?l000000oooool2o`0000Sooooo0_l00005ooooo`?o00004Oooool2o`00
01Cooooo0_l000000ooooooo0000o`000002ooooo`;o00002_ooool2o`0000?ooooo0_l000000ooo
oooo0000o`000003ooooo`;o00000_ooool6o`0001Gooooo0_l0000?ooooo`?o00002Oooool4o`00
00Oooooo0_l00004ooooo`;o0000<_ooool001cooooo00?o0000ooooooooool0<?ooool2o`0000[o
oooo0_l00002ooooo`;o00001Oooool4o`0001Wooooo0_l00002ooooo`;o00000oooool2o`0000So
oooo1?l00003ooooo`;o000000Coooooo`000?l0003ooooo0ol0000Qooooo`;o000000Coooooo`00
0?l0003ooooo0_l00009ooooo`;o00001Oooool2o`0000Kooooo0_l00002ooooo`;o000000?ooooo
o`000?l000000oooool5o`0001gooooo1_l00008ooooo`Co00001_ooool3o`0000;ooooo1?l0000b
ooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o000000?oooooo`000?l000001?ooool2o`00
0003ooooool0003o000000;o000000?oooooo`000?l000001?ooool2o`0001;ooooo0ol0000Coooo
o`?o00001Oooool2o`0000Kooooo1_l0000Gooooo`;o00003_ooool2o`0000Oooooo1?l00005oooo
o`;o00002Oooool2o`0000;ooooo0_l00002ooooo`Ko00007Oooool2o`0000;ooooo0ol00007oooo
o`?o000000?oooooo`000?l000001?ooool2o`0000?ooooo1?l0000booooo`007?ooool00ol0003o
ooooooooo`0Looooo`;o00005Oooool2o`0000Cooooo0_l00003ooooo`;o000000?oooooo`000?l0
00005oooool4o`0000;ooooo0ol0000>ooooo`?o00001_ooool2o`0000Oooooo0_l00003ooooo`;o
00004_ooool4o`000003ooooool0003o000001Cooooo0_l000000ooooooo0000o`000002ooooo`Co
00001Oooool2o`0000;ooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o000002?o
oooo0_l00007ooooo`;o00000_ooool2o`0003oooooo000Looooo`03o`000?oooooooooo01cooooo
0_l0000Eooooo`;o00002Oooool2o`0001[ooooo0_l00003ooooo`Co00001_ooool2o`0000Kooooo
0_l00007ooooo`;o00003?ooool2o`0001;ooooo0_l00002ooooo`?o00001_ooool2o`0000Cooooo
0_l00006ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Oooooo1?l000001?oooooo0000
o`000?ooool2o`0000Gooooo0_l0000@ooooo`;o00003Oooool2o`0000Oooooo0_l00002ooooo`;o
0000@oooool001cooooo00?o0000ooooooooool0?oooool2o`0001kooooo0_l000000ooooooo0000
o`000005ooooo`;o00005oooool3o`0000Sooooo0_l0000<ooooo`;o00000oooool2o`0000Oooooo
0_l00004ooooo`;o00000oooool2o`000003ooooool0003o000000oooooo1_l00002ooooo`;o0000
1Oooool3o`0000cooooo1?l0000=ooooo`;o00001oooool2o`0000Gooooo0_l00005ooooo`;o0000
>Oooool001cooooo00?o0000ooooooooool0<oooool2o`0000[ooooo0_l0000Eooooo`;o00001ooo
ool2o`000003ooooool0003o000000Kooooo0_l0000@ooooo`;o00001?ooool3o`000003ooooool0
003o000000Gooooo0_l0000<ooooo`;o00000oooool2o`0000[ooooo0_l00002ooooo`;o00000_oo
ool2o`000003ooooool0003o000000Kooooo0_l00003ooooo`;o00001?ooool3o`0000;ooooo3?l0
0007ooooo`;o00000_ooool4o`0001Oooooo0_l00004ooooo`;o00001Oooool2o`0003Wooooo000L
ooooo`03o`000?oooooooooo03;ooooo0ol0000Jooooo`Co00000oooool2o`000003ooooool0003o
000000Cooooo1?l00007ooooo`;o00004?ooool2o`0000;ooooo0_l000000ooooooo0000o`000003
o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000007ooooo`Co00000oooool4
o`0000Sooooo0_l00002ooooo`Go00000_ooool2o`0000;ooooo0_l00002ooooo`;o00000_ooool4
o`0000Cooooo4?l00007ooooo`;o00001?ooool2o`0001Oooooo0_l0000:ooooo`;o0000>_ooool0
01cooooo0_l0000Kooooo`;o00004?ooool2o`0000Cooooo0_l0000Kooooo`Co00001_ooool2o`00
00Gooooo0ol0000Booooo`;o00002Oooool2o`000003ooooool0003o000000Ko00000_ooool2o`00
0003ooooool0003o000000Oooooo0_l00005ooooo`Co00001oooool2o`0000Cooooo1?l00006oooo
o`;o00001_ooool4o`0000;ooooo2Ol000000ooooooo0000o`000005o`0000oooooo0_l00009oooo
o`;o00005oooool2o`0003[ooooo000Looooo`03o`000?oooooooooo01[ooooo0_l0000@ooooo`;o
00003?ooool2o`0001_ooooo0_l0000Dooooo`;o00001_ooool2o`0000Oooooo1?l00006ooooo`;o
00003?ooool2o`0000Oooooo0_l0000:ooooo`;o000000Coooooo`000?l0003ooooo0_l00009oooo
o`;o00002ooooolAo`000003ooooool0003o000000;o00002_ooool2o`0000Wooooo0_l00009oooo
o`;o00001Oooool2o`0000Sooooo0ol0000fooooo`007?ooool00ol0003oooooooooo`0jooooo`Co
00003Oooool2o`0000[ooooo0_l0000Dooooo`Co00001?ooool2o`0000Cooooo1_l0000<ooooo`;o
00000oooool6o`0000Oooooo0_l0000=ooooo`;o000000Coooooo`000?l0003ooooo0_l00002oooo
o`;o00000_ooool2o`0000Sooooo0_l00002oooooaKo00005Oooool2o`0000Sooooo0_l00005oooo
o`;o00001oooool4o`000003ooooool0003o000003?ooooo000Looooo`03o`000?oooooooooo03Ko
oooo0_l00004ooooo`;o00003Oooool2o`0000oooooo0_l00004ooooo`;o00001_ooool7o`0000Co
oooo0_l00003ooooo`Oo00003?ooool2o`0000?ooooo1?l0000Cooooo`So00000oooool2o`0000;o
oooo0_l00006ooooo`;o00001?ooool2o`000003ooooool0003o000001Go00000oooool2o`0000Oo
oooo0_l00007ooooo`;o00001_ooool4o`0000kooooo0_l00003ooooo`;o0000<oooool001cooooo
00?o0000ooooooooool0<Oooool2o`0000?ooooo0_l00005ooooo`;o00005oooool2o`0000Cooooo
0_l00002ooooo`Oo000000?oooooo`000?l000001?l000000ooooooo0000o`000003o`0000Kooooo
0_l0000Gooooo`;o00004_ooool:o`0000oooooo0_l00002ooooo`Co000000?oooooo`000?l00000
4ol00005ooooo`;o00001oooool2o`0000kooooo1Ol00003ooooo`?o0000@_ooool001cooooo00?o
0000ooooooooool0;Oooool2o`0000;ooooo0_l0000:ooooo`?o00004_ooool2o`0000;ooooo0_l0
0008ooooo`;o00000_ooool3o`000004ooooool0003o0000o`0000Cooooo1_l0000Iooooo`;o0000
5_ooool3o`000004ooooool0003o0000o`0001Oooooo6_l00009ooooo`;o00004_ooool3o`0000;o
oooo0_l00002ooooo`?o0000@_ooool001cooooo00?o0000ooooooooool0;Oooool2o`0000oooooo
0_l0000?ooooo`Go00002_ooool2o`0000;ooooo0_l00003ooooo`Oo00000_ooool5o`0000Kooooo
0_l0000Aooooo`;o00005Oooool5o`000003ooooool0003o000001Oooooo6ol00008ooooo`;o0000
3?ooool2o`0000Cooooo0_l00003ooooo`;o00000oooool2o`0004;ooooo000Looooo`03o`000?oo
oooooooo01_ooooo0_l0000@ooooo`;o00002?ooool2o`0001Kooooo0ol0000<ooooo`;o000000?o
ooooo`000?l000000_l000000ooooooo0000o`00000;o`0000Sooooo0_l000000ooooooo0000o`00
0002ooooo`;o00002?ooool3o`0001Gooooo0ol000001?oooooo0000o`000?ooool2o`0000?ooooo
0_l0000Aooooo`;o000000?oooooo`000?l000005ol0000Dooooo`Co00001Oooool2o`0000Kooooo
0_l00013ooooo`007?ooool00ol0003oooooooooo`0Kooooo`;o00005_ooool2o`0000;ooooo0_l0
000Eooooo`;o00001?ooool2o`0000Sooooo0_l000000ooooooo0000o`000002o`000003ooooool0
003o000000go00000_ooool2o`0000Gooooo0_l00002ooooo`;o00001oooool4o`0001Gooooo1_l0
00000ooooooo0000o`000003ooooo`;o00004Oooool2o`000003ooooool0003o000001Oo00001Ooo
ool4o`0000_ooooo0_l00007ooooo`;o00001_ooool2o`0000gooooo0_l0000dooooo`007?ooool0
0ol0003oooooooooo`0/ooooo`;o00001Oooool2o`0000?ooooo0_l00009ooooo`;o00001Oooool3
o`000004ooooool0003o0000o`0000?ooooo0_l00008ooooo`;o000000?oooooo`000?l000005_l0
000Booooo`Co00005oooool4o`0000Kooooo0_l0000Coooooa[o00001?ooool5o`00017ooooo0_l0
0008ooooo`;o00003Oooool3o`0003Cooooo000Looooo`03o`000?oooooooooo01_ooooo0_l0000?
ooooo`;o00002_ooool2o`0000Sooooo0ol00005ooooo`?o00000_ooool2o`0000?ooooo0_l00000
0ooooooo0000o`000003o`0000;ooooo0_l000000ooooooo0000o`00000Fo`0000Oooooo0_l00008
ooooo`Go00000oooool2o`0000Sooooo0_l0000:ooooo`?o00001Oooool2o`0001?ooooo6_l00004
ooooo`;o00003oooool2o`0000?ooooo0_l00002ooooo`;o00001?ooool2o`0000gooooo0_l0000e
ooooo`007?ooool00ol0003oooooooooo`0Kooooo`;o00005_ooool4o`0000?ooooo0_l00006oooo
o`;o00004?ooool:o`000004ooooool0003o0000oooooaOo00001oooool2o`0000Gooooo1Ol00006
ooooo`;o00002?ooool2o`0000_ooooo0_l0000Aooooo`;o00001_oooolKo`0001Gooooo0_l00002
ooooo`;o00000oooool2o`0004[ooooo000Looooo`03o`000?oooooooooo03?ooooo1?l000000ooo
oooo0000o`000002o`0000Sooooo0_l00008ooooo`Go00000_ooool2o`0000;ooooo8Ol00005oooo
o`;o00001_ooool4o`00037ooooo0ol00005oooooa_o00004Oooool2o`0000Kooooo0_l00009oooo
o`;o00001?ooool2o`0003kooooo000Looooo`03o`000?oooooooooo03Sooooo0_l0000:ooooo`;o
00002?ooool5o`0000Kooooo7?l000000ooooooo0000o`000002o`0000Gooooo0_l0000:ooooo`;o
000000?oooooo`000?l000004_ooool2o`0001Sooooo0ol00005ooooo`oo000000?oooooo`000?l0
00002Ol00009ooooo`;o00001_ooool2o`0000gooooo0_l00002ooooo`;o00001?ooool2o`0000Ko
oooo0_l0000fooooo`007?ooool00ol0003oooooooooo`0jooooo`;o00006?ooool2o`0000Gooooo
4?l000000ooooooo0000o`00000;o`000004ooooool0003o0000o`0000_ooooo0_l000000ooooooo
0000o`000004o`0000Kooooo0_l00009ooooo`;o00002Oooool2o`0000kooooo0_l00004oooooaco
000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l0000=ooooo`;o00001_ooool2o`0000Ko
oooo1?l00002ooooo`;o00000_ooool2o`0003Kooooo000Looooo`03o`000?oooooooooo01_ooooo
0_l0000Jooooo`;o000000?oooooo`000?l000001?ooool2o`0001;ooooo0_l00005oooooaco0000
0oooool3o`0000[ooooo0ol00003ooooo`Co00001_ooool2o`0000?ooooo1?l0000=ooooo`;o0000
3Oooool4o`0000;ooooo7Ol000000ooooooo0000o`000002ooooo`;o00004?ooool3o`0000Kooooo
0_l00006ooooo`Co00000_ooool2o`000003ooooool0003o000003Oooooo000Looooo`;o00007?oo
ool2o`0001Oooooo0_l000000ooooooo0000o`000005ooooo`Co00002Oooool2o`0000Kooooo0_l0
0002ooooo`;o000000?oooooo`000?l000006Ol00002ooooo`;o00003_ooool3o`0001;ooooo1?l0
00000ooooooo0000o`000002ooooo`Co00004oooool4o`0000;ooooo7Ol0000Gooooo`;o000000?o
ooooo`000?l000003?ooool2o`0000Oooooo0_l0000gooooo`007?ooool00ol0003oooooooooo`0^
ooooo`;o00001?ooool2o`0000Sooooo0_l0000:ooooo`?o00001_ooool2o`0000;ooooo0_l00000
0ooooooo0000o`00000Mo`000003ooooool0003o000000_ooooo0ol0000?ooooo`;o000000Cooooo
o`000?l0003o00000_ooool2o`0000;ooooo1?l0000Cooooo`;o00000oooool2o`000003ooooool0
003o000001Oo00005_ooool5o`000003ooooool0003o000000cooooo0_l00010ooooo`007?ooool0
0ol0003oooooooooo`0^ooooo`;o00006_ooool2o`0000Gooooo0_l00007ooooob;o00001Oooool2
o`0000Gooooo0_l00002ooooo`;o00002oooool2o`000003ooooool0003o000000?o00001Oooool2
o`0001Wooooo0_l000000ooooooo0000o`00000Go`0001Kooooo0ol00004ooooo`;o00002_ooool2
o`00047ooooo000Looooo`03o`000?oooooooooo057ooooo0_l00007ooooob3o00001oooool2o`00
00Gooooo1_l0000=ooooo`Wo00000_ooool2o`0001Sooooo7Ol0000Mooooo`;o00002_ooool3o`00
043ooooo000Looooo`03o`000?oooooooooo03Cooooo1?l0000Iooooo`;o00001ooooolQo`0000oo
oooo0_l0000:ooooo`;o00000oooool9o`0001cooooo7?l0000Oooooo`;o000000?oooooo`000?l0
00001oooool2o`00043ooooo000Looooo`03o`000?oooooooooo03Cooooo1?l0000Aooooo`;o0000
0oooool2o`0000?ooooo0_l00002ooooo`;o00000_oooolPo`0000Kooooo0_l0000Cooooo`;o0000
1?ooool2o`000003ooooool0003o000000Ko00005oooool2o`0000;ooooo5_l00002ooooo`;o0000
7Oooool4o`000003ooooool0003o000004Wooooo000Looooo`03o`000?oooooooooo03Kooooo0_l0
000Aooooo`;o00000oooool2o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000006ol0
0002ooooo`?o00000oooool4o`0001Kooooo0_l000001Ooooooo0000o`000?l0003ooooo00Oo0000
5oooool2o`0000;ooooo6Ol0000>ooooo`;o00003_ooool2o`0004kooooo000Looooo`03o`000?oo
oooooooo03Kooooo0_l0000:ooooo`;o00001oooool2o`0000gooooo7Ol00002ooooo`?o00000ooo
ool2o`00013ooooo0_l00006ooooo`;o00000_ooool5o`0002;ooooo4ol000001?oooooo0000o`00
0?l0000>ooooo`?o00001oooool2o`0000oooooo0_l00005ooooo`;o00001?ooool2o`0003Kooooo
000Looooo`03o`000?oooooooooo04;ooooo0_l00005ooooo`Co00001oooool2o`0000Oooooo5Ol0
0002ooooo`?o00001oooool2o`00017ooooo0_l0000<ooooo`;o00007?oooolFo`000005ooooool0
003o0000o`000?ooool00_l0000@ooooo`;o00001oooool2o`0000[ooooo1?l000000ooooooo0000
o`000005ooooo`;o00001?ooool2o`0003Kooooo000Looooo`03o`000?oooooooooo01gooooo0_l0
000Hooooo`;o00004?ooool4o`000003ooooool0003o000000;o00000_ooool8o`000003ooooool0
003o000000Ko000000?oooooo`000?l000004Ol00005ooooo`;o00000_ooool4o`0001;ooooo0_l0
00000ooooooo0000o`00000Poooooa;o00000_ooool2o`000003ooooool0003o000000;ooooo1?l0
0003ooooo`;o00007_ooool4o`0004Kooooo000Looooo`03o`000?oooooooooo01gooooo0_l0000H
ooooo`;o00004_ooool2o`000003ooooool0003o000000;o00001?ooool6o`000004ooooool0003o
0000ooooo`ko000000?oooooo`000?l000000ol00003ooooo`;o00001_ooool2o`000003ooooool0
003o000000;o00002oooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool3o`0000Wooooo
0_l0000;ooooo`;o00001_ooool4o`000003ooooool0003o000000;ooooo1ol000000ooooooo0000
o`000003o`0000;ooooo0_l00004ooooo`;o00000oooool2o`0006Sooooo000Looooo`03o`000?oo
oooooooo03;ooooo0_l00007ooooo`;o00007Oooool2o`000003ooooool0003o0000013o000000?o
ooooo`000?l000000ol00003ooooo`;o00001Oooool2o`000003ooooool0003o000000[ooooo0_l0
00000ooooooo0000o`000002ooooo`;o00001Oooool2o`0000Wooooo0_l0000;ooooo`;o00001_oo
ool5o`0000Gooooo0_l000001Ooooooo0000o`000?l0003ooooo00Wo00001?ooool3o`0000gooooo
0_l00002ooooo`Co0000Eoooool001cooooo00?o0000ooooooooool0<_ooool2o`0000Oooooo0_l0
000Mooooo`;o000000?oooooo`000?l000004ol000000ooooooo0000o`000005o`0000;ooooo0_l0
0002ooooo`;o00003?ooool2o`0000Wooooo0ol0000Sooooo`;o00001Oooool2o`000003ooooool0
003o000000?ooooo0_l00002ooooo`;o00001oooool2o`0000Oooooo1?l00002ooooo`;o00000_oo
ool4o`0000oooooo0ol00005ooooo`;o00000_ooool2o`0003[ooooo000Looooo`03o`000?oooooo
oooo01gooooo0_l0000Looooo`Co00003_ooool2o`0000_ooooo0_l000000ooooooo0000o`00000<
o`000003ooooool0003o000000Co00000_ooool4o`0000Cooooo0_l00002ooooo`;o00001Oooool2
o`0000;ooooo0_l0000<ooooo`Go00004_ooool2o`0000Oooooo0_l0000Cooooo`;o00002_ooool2
o`0000Sooooo1_l0000<ooooo`;o00002Oooool3o`0000Gooooo0_l00002ooooo`;o0000>_ooool0
0006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@
olc<c006ooooo`03o`000?oooooooooo01gooooo0_l0000Nooooo`;o00001_ooool2o`0000Kooooo
0_l0000?oooooaKo00000_ooool2o`0000oooooo0_l00002ooooo`Go00001?ooool:o`0000?ooooo
0_l0000=ooooo`;o00001oooool2o`0000Wooooo0_l0000:ooooo`;o00002?ooool2o`0000cooooo
0_l0000:ooooo`Co00004oooool2o`0003cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`15oooo
o`;o00002?ooool2o`0000gooooo4ol000000ooooooo0000o`000005o`000003ooooool0003o0000
00kooooo0_l000001?oooooo0000o`000?l00003ooooo`Ko00002?ooool2o`0000Wooooo0_l00007
ooooo`;o00002?ooool7o`0000[ooooo0_l0000Looooo`;o00001?ooool3o`0000Oooooo0_l0000;
ooooo`;o0000??ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0?oooool2o`0000kooooo0_l00005
ooooo`;o00002?ooool:o`000003ooooool0003o000000Co00000oooool5o`000003ooooool0003o
000000Gooooo0_l00007ooooo`;o00000oooool;o`0001;ooooo0_l00006ooooo`Co000000?ooooo
o`000?l000000_l00002ooooo`Go00001_ooool2o`0001Cooooo0_l0000<ooooo`?o00001?ooool4
o`0000Cooooo0ol0000<ooooo`;o0000>oooool00003ooooool0003ooooo00;ooooo00?o0000oooo
ooooool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0000oooooo`?o00003?ooool2
o`0000Kooooo0_l00004ooooo`?o00000_ooool5o`0000;ooooo1?l000000ooooooo0000o`000007
ooooo`;o00002Oooool2o`0000_ooooo2Ol000000ooooooo0000o`000003ooooo`;o00002oooool2
o`0000Sooooo1?l000000ooooooo0000o`000002o`000003ooooool0003o000000[ooooo0_l0000D
ooooo`;o00003Oooool3o`0000?ooooo1?l00004ooooo`;o00003Oooool2o`0000?ooooo0_l0000f
ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?mEEEGo0000
oa0@4?o<c<`01_ooool00ol0003oooooooooo`10ooooo`;o00003?ooool2o`0000Wooooo0_l00000
1Ooooooo0000o`000?l0003ooooo00Go00000oooool4o`000003ooooool0003o000000;ooooo0_l0
000Booooo`;o000000?oooooo`000?l000001?ooool4o`000004ooooool0003o0000o`0000Oooooo
0_l00007ooooo`;o00000_ooool2o`0000Cooooo2?l000000ooooooo0000o`000002ooooo`?o0000
0_ooool2o`0000[ooooo0_l0000Pooooo`;o00004oooool2o`0000Kooooo0_l00002ooooo`;o0000
=_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7oooo
o`08ooooo`03o`000?oooooooooo05Wooooo3?l00005ooooo`;o00001Oooool2o`0000;ooooo0_l0
000:ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000?ooooo0_l00004ooooo`Co0000
2Oooool2o`0000Cooooo0_l00006ooooo`[o000000?oooooo`000?l000000_ooool2o`0000?ooooo
0_l0000:ooooo`;o00003?ooool2o`0000kooooo0ol00004ooooo`;o00001oooool2o`0000Oooooo
0_l00006ooooo`;o0000>_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo
410@oiRHV008ooooo`03o`000?oooooooooo04oooooo0_l00006ooooo`;o000000?oooooo`000?l0
00001_l00006ooooo`Co00000oooool2o`0000Cooooo0_l0000:ooooo`;o000000?oooooo`000?l0
00001oooool:o`0000Wooooo0_l00003ooooo`?o00001_ooool>o`00023ooooo0_l0000>ooooo`?o
00001?ooool2o`0000Oooooo0_l00005ooooo`;o00002?ooool2o`0003[ooooo00001_ooooook^k^
oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`1?
ooooo`;o00001_ooool2o`0000Oooooo0ol00004ooooo`?o00001Oooool2o`0000Wooooo0_l00008
ooooo`;o00001?ooool2o`000003ooooool0003o000000Go00001oooool2o`0000Cooooo0_l00002
ooooo`;o00001OoooolAo`0001_ooooo0_l0000Mooooo`;o00002_ooool4o`0004;ooooo000Loooo
o`03o`000?oooooooooo04_ooooo0_l00003ooooo`Go00001?ooool2o`0000?ooooo1Ol00004oooo
o`;o000000?oooooo`000?l000002?ooool2o`0000;ooooo1?l00008ooooo`;o00001?ooool2o`00
0004ooooool0003o0000ooooo`;o00002?ooool3o`000004ooooool0003o0000ooooo`Co00001ooo
oolBo`0000Cooooo0_l0000Dooooo`;o00005Oooool2o`0000Kooooo0_l00007ooooo`;o00000ooo
ool2o`0004;ooooo000Looooo`03o`000?oooooooooo04_ooooo0_l00003ooooo`Go00001?ooool2
o`0000;ooooo1?l00008ooooo`?o00002?ooool2o`0000;ooooo0_l0000@ooooo`?o00000oooool2
o`0000Kooooo1?l00002ooooo`;o00000oooool2o`0000Oooooo4_l00004ooooo`Go00008oooool2
o`0000?ooooo0_l0000?ooooo`;o00001oooool2o`000003ooooool0003o000003_ooooo000Loooo
o`03o`000?oooooooooo04;ooooo0ol0000Cooooo`?o00000_ooool2o`0000Gooooo0_l00002oooo
o`?o00007oooool4o`000004ooooool0003o0000o`0000Kooooo0_l000000ooooooo0000o`00000<
oooooaGo00001_ooool3o`0000Oooooo0_l0000Jooooo`;o00001Oooool2o`0000Sooooo0_l00008
ooooo`;o00000_ooool2o`000003ooooool0003o000003_ooooo000Looooo`03o`000?oooooooooo
02?ooooo0_l0000Mooooo`Co00004_ooool3o`0000;ooooo0_l00005ooooo`;o00000_ooool4o`00
00Gooooo0_l0000Eooooo`;o00000_ooool5o`000003ooooool0003o000000Kooooo0ol00008oooo
oa[o00002Oooool2o`0000Cooooo0_l00006ooooo`;o00006Oooool2o`0000Gooooo0_l000000ooo
oooo0000o`000008ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool08oooool2o`0001oo
oooo0_l0000Cooooo`;o00000_ooool4o`0000;ooooo0_l00005ooooo`;o00001Oooool2o`0001;o
oooo1ol000000ooooooo0000o`000003ooooo`;o00001_ooool2o`0000Wooooo5_l000000ooooooo
0000o`000002o`0000Sooooo0_l0000:ooooo`Co00005Oooool2o`0000Wooooo0_l0001?ooooo`00
7?ooool00ol0003oooooooooo`1Iooooo`;o00001?ooool2o`0000;ooooo0_l00003ooooo`;o0000
1oooool2o`0000kooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000;o0000
6OoooolIo`0000;ooooo0_l0000>ooooo`Co00004oooool2o`0000;ooooo0_l00006ooooo`;o0000
00?oooooo`000?l00000Coooool001cooooo00?o0000ooooooooool0Aoooool2o`0000Gooooo0_l0
000Hooooo`;o00005oooool2o`000004ooooool0003o0000ooooo`Co000000?oooooo`000?l00000
2oooool2o`0000_ooooo8?l0000<ooooo`;o00005Oooool2o`0000Gooooo1?l000000ooooooo0000
o`00000=ooooo`;o00001Oooool2o`0003cooooo000Looooo`03o`000?oooooooooo04Cooooo0_l0
00001?oooooo0000o`000?ooool2o`000004ooooool0003o0000o`0000Wooooo0_l00005ooooo`;o
00000_ooool2o`0000;ooooo0_l0000>ooooo`;o00001_ooool4o`0000?ooooo1?l0000<ooooo`Co
00002ooooolIo`000004ooooool0003o0000ooooo`?o00008oooool4o`0000?ooooo1?l0000@oooo
o`;o00001Oooool2o`0003cooooo000Looooo`03o`000?oooooooooo043ooooo0_l00002ooooo`;o
00001?ooool2o`000003ooooool0003o000000[ooooo0_l00005ooooo`Oo000000?oooooo`000?l0
00002oooool2o`000003ooooool0003o000000Kooooo1?l00002ooooo`;o00000_ooool4o`0000Wo
oooo1?l00009ooooo`[o000000?oooooo`000?l000003_l0000Fooooo`Co00003oooool5o`0002;o
oooo0_l0000hooooo`007?ooool00ol0003oooooooooo`10ooooo`Co00000oooool2o`0000cooooo
0ol0000:ooooo`Go00001Oooool2o`0000Oooooo0_l0000?ooooo`;o00000_ooool6o`0001Cooooo
7?l0000Eooooo`Co00003oooool2o`0000Cooooo0_l0000?ooooo`;o00003_ooool2o`0003Sooooo
000Looooo`03o`000?oooooooooo04;ooooo0_l00003ooooo`;o00003?ooool3o`0000Sooooo0_l0
0006ooooo`;o00000_ooool2o`0001Cooooo0_l00006ooooo`;o000000?oooooo`000?l000000_l0
000Doooooa_o00003oooool2o`0001gooooo0_l00009ooooo`;o00001?ooool2o`0000Cooooo0ol0
0011ooooo`007?ooool2o`0005Oooooo0_l00002ooooo`;o00001?ooool2o`0000Kooooo0_l00003
ooooo`;o00004oooool2o`0000Cooooo0ol000000ooooooo0000o`000003o`0000Gooooo0_l0000<
oooooago00003_ooool2o`0001[ooooo0_l000001?oooooo0000o`000?ooool2o`0000Kooooo0_l0
000:ooooo`?o00001Oooool2o`0003[ooooo000Looooo`03o`000?oooooooooo02[ooooo0_l0000^
ooooo`;o00000oooool2o`000003ooooool0003o000000Wooooo0_l00002ooooo`;o00002Oooool2
o`0000Oooooo0_l000000ooooooo0000o`000007o`0000Gooooo0_l0000<oooooa[o000000?ooooo
o`000?l000001_ooool2o`0002;ooooo0_l000001?oooooo0000o`000?ooool2o`0001[ooooo0_l0
000jooooo`007?ooool00ol0003oooooooooo`0Zooooo`;o00008oooool3o`0000gooooo1Ol00009
ooooo`?o000000?oooooo`000?l000002Oooool2o`0000?ooooo0_l00002ooooo`;o00000oooool3
o`0000;ooooo0_l0000DoooooaWo00002Oooool2o`0002Kooooo0_l00008ooooo`Co0000C?ooool0
01cooooo00?o0000ooooooooool0Coooool3o`0000oooooo1?l00009ooooo`;o000000Coooooo`00
0?l0003o00000oooool4o`0000;ooooo0_l00002ooooo`;o00002?ooool3o`0000Oooooo0_l0000?
oooooaKo000000?oooooo`000?l000000_l0000^ooooo`;o00002?ooool4o`0004cooooo000Loooo
o`03o`000?oooooooooo04Gooooo0_l00007ooooo`;o00001?ooool3o`0000cooooo0_l00004oooo
o`Ko00000oooool2o`0000?ooooo2?l00002ooooo`;o00002?ooool3o`0000Oooooo0_l0000;oooo
o`;o00000_ooool5o`000003ooooool0003o000000ko000000?oooooo`000?l000000_l0000ioooo
o`;o0000COooool001cooooo00?o0000ooooooooool0AOooool2o`0000Oooooo0_l00004ooooo`Go
00004?ooool6o`0000;ooooo0_l00008ooooo`?o00002?ooool2o`0000Cooooo0_l00003ooooo`;o
00000_ooool2o`0000_ooooo1?l000000ooooooo0000o`000002o`000003ooooool0003o000000Co
000000?oooooo`000?l000002?l00002ooooo`;o0000=_ooool2o`000003ooooool0003o000000Ko
oooo0_l00015ooooo`007?ooool00ol0003oooooooooo`1Dooooo`Go00005?ooool2o`0000;ooooo
0_l000000ooooooo0000o`000002ooooo`;o00002?ooool2o`0000;ooooo0_l00009ooooo`;o0000
0_ooool2o`0000gooooo1Ol000000ooooooo0000o`000006o`000003ooooool0003o000000?o0000
0oooool3o`0000[ooooo0_l0000Kooooo`;o00004?ooool2o`0000Wooooo0_l00003ooooo`;o0000
@?ooool001cooooo00?o0000ooooooooool0EOooool3o`0001Cooooo0_l00006ooooo`;o00000_oo
ool2o`0000Sooooo0_l00009ooooo`Ko00004oooool2o`0000;ooooo2ol000001?oooooo0000o`00
0?l00003ooooo`?o00002Oooool2o`0000Kooooo0_l0000Cooooo`;o00003Oooool2o`0000?ooooo
0_l00008ooooo`;o00000_ooool2o`00043ooooo000Looooo`03o`000?oooooooooo04oooooo1?l0
0003ooooo`Go00002_ooool2o`0000Gooooo0_l0000@ooooo`;o00003Oooool6o`00013ooooo0_l0
0008ooooo`co00001?ooool2o`0000Wooooo0_l00006ooooo`?o00003_ooool2o`0000Cooooo0_l0
00000ooooooo0000o`000008ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`Co0000A?oo
ool001cooooo00?o0000ooooooooool0;oooool2o`0001Sooooo0_l00004ooooo`Co000000?ooooo
o`000?l000000_ooool4o`0000Wooooo1?l0000<ooooo`;o00001oooool2o`0000Gooooo0_l0000K
ooooo`?o00000_ooool2o`0000Gooooo2ol0000Hooooo`;o00003?ooool4o`0000Cooooo0_l00000
0ooooooo0000o`000008ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o0000A_ooool0
01cooooo00?o0000ooooooooool0;oooool2o`0001Sooooo0_l00008ooooo`Co00000oooool2o`00
00_ooooo0_l0000<ooooo`;o00001Oooool2o`0000Oooooo0_l00007ooooo`;o00004_ooool2o`00
00;ooooo1?l00004ooooo`?o000000Coooooo`000?l0003ooooo1Ol00004ooooo`;o000000?ooooo
o`000?l000007?ooool4o`0000Cooooo0ol0000>ooooo`;o00000oooool2o`0004[ooooo000Loooo
o`03o`000?oooooooooo05?ooooo1?l00007ooooo`;o00003Oooool5o`0000[ooooo0_l00007oooo
o`;o00001oooool4o`0000?ooooo0_l0000?ooooo`Go00001?ooool2o`000003ooooool0003o0000
00?ooooo0ol000000ooooooo0000o`000003o`000003ooooool0003o000001gooooo0ol00004oooo
o`?o00003_ooool2o`0000;ooooo0ol0001:ooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o
00002oooool2o`0000Gooooo0_l00006ooooo`Go00007?ooool4o`0000?ooooo0_l0000Booooo`;o
000000?oooooo`000?l000003Oooool3o`0000;ooooo0_l0000;ooooo`;o00004Oooool2o`0000Co
oooo0_l0000@ooooo`;o00000_ooool3o`0004[ooooo000Looooo`03o`000?oooooooooo057ooooo
1?l0000@ooooo`;o00001_ooool2o`0000Wooooo0_l00009ooooo`;o00002oooool2o`0001[ooooo
0_l0000?ooooo`;o000000?oooooo`000?l000002oooool2o`0001Oooooo0_l0000Cooooo`;o0000
C?ooool001cooooo00?o0000ooooooooool0Boooool2o`0000Cooooo1Ol0000@ooooo`Ko000000?o
ooooo`000?l000001?ooool2o`0000?ooooo1?l00007ooooo`;o00001_ooool2o`0000;ooooo0_l0
000/ooooo`Co0000<?ooool2o`0000Sooooo1?l0001:ooooo`007?ooool00ol0003oooooooooo`1;
ooooo`;o00001?ooool2o`000003ooooool0003o000000Gooooo0_l00009ooooo`Ko00001_ooool3
o`0000Gooooo0_l0000>ooooo`Co000000Coooooo`000?l0003o0000;Oooool2o`0001Sooooo0_l0
00000ooooooo0000o`00000:ooooo`;o00001oooool2o`0000?ooooo0_l00005ooooo`;o0000B_oo
ool001cooooo0_l00018ooooo`;o00003_ooool3o`000003ooooool0003o0000013ooooo0_l00003
ooooo`Go000000?oooooo`000?l000000_ooool2o`0000cooooo1?l00002ooooo`;o00005oooool2
o`0002kooooo0_l000000ooooooo0000o`000009ooooo`?o00001Oooool2o`0000Gooooo0_l0001A
ooooo`007?ooool00ol0003oooooooooo`0eooooo`;o00004?ooool3o`0000gooooo0ol0000Coooo
o`?o00000_ooool5o`000003ooooool0003o000000;ooooo0_l00006ooooo`;o00001Oooool2o`00
00?ooooo0_l0000Gooooo`;o00002Oooool2o`0000?ooooo0_l0000Nooooo`?o00002oooool3o`00
0004ooooool0003o0000ooooo`?o0000F?ooool001cooooo00?o0000ooooooooool0=Oooool2o`00
017ooooo0_l00003ooooo`;o00003?ooool2o`0000oooooo1?l00002ooooo`Ko00000_ooool2o`00
00Kooooo1?l00005ooooo`;o00000oooool2o`0001[ooooo0_l00005ooooo`?o00000oooool2o`00
0003ooooool0003o000001?ooooo0_l00002ooooo`;o00000_ooool3o`0000;ooooo0_l00008oooo
o`;o000000Coooooo`000?l0003ooooo0ol0001Hooooo`007?ooool00ol0003oooooooooo`1=oooo
o`;o00003?ooool2o`0000Gooooo0_l00008ooooo`;o00001Oooool5o`0000;ooooo0_l00006oooo
o`;o00003Oooool2o`0001Wooooo0_l00005ooooo`;o00000oooool3o`000003ooooool0003o0000
01?ooooo0_l00002ooooo`;o00001oooool2o`0000?ooooo0_l000000ooooooo0000o`000007oooo
o`;o00002_ooool2o`0004cooooo000Looooo`03o`000?oooooooooo06;ooooo0_l00007ooooo`;o
00001oooool2o`0000cooooo1?l0000;ooooo`;o00001?ooool2o`0001_ooooo0_l00002ooooo`;o
00000oooool4o`0001;ooooo0_l0000>ooooo`;o000000?oooooo`000?l000001?ooool2o`000003
ooooool0003o000000[ooooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o0000
7_ooool3o`0000Sooooo0_l00006ooooo`?o00003?ooool2o`000003ooooool0003o000000Cooooo
0ol00006ooooo`?o00002?ooool2o`000003ooooool0003o000001Sooooo1?l00004ooooo`Go0000
1?ooool2o`0000cooooo0_l0000Eooooo`Go0000F_ooool001cooooo00?o0000ooooooooool0>?oo
ool2o`0001Oooooo0_l00005ooooo`?o00000oooool2o`0000?ooooo0_l00007ooooo`;o00002Ooo
ool5o`000004ooooool0003o0000ooooo`Ko000000?oooooo`000?l000000oooool6o`0000Sooooo
0_l0000Jooooo`;o00001?ooool5o`0000Cooooo1?l0000;ooooo`;o00005?ooool2o`000003oooo
ool0003o000005[ooooo000Looooo`03o`000?oooooooooo03[ooooo0_l0000>ooooo`;o00001Ooo
ool2o`0000_ooooo0_l00002ooooo`;o00000_ooool2o`0000oooooo0ol00005ooooo`_o00000_oo
ool6o`0000[ooooo0_l0000@ooooo`;o00003Oooool2o`0000Cooooo0_l00002ooooo`;o000000?o
ooooo`000?l000000_l00006ooooo`;o00000oooool2o`0000?ooooo1?l00005ooooo`;o00001?oo
ool2o`0000Kooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`0jooooo`;o00003_ooool2
o`0000oooooo0ol00004ooooo`;o00000_ooool3o`0001Cooooo3_l00002ooooo`;o00003Oooool2
o`00013ooooo0_l0000Cooooo`;o00001Oooool4o`0000Oooooo1_l00003ooooo`Co000000?ooooo
o`000?l000000_ooool2o`0000?ooooo0ol00006ooooo`;o0000D_ooool001cooooo00?o0000oooo
ooooool0?Oooool2o`0001cooooo0ol00003ooooo`;o00001?ooool5o`0000Oooooo0_l00002oooo
o`;o00001?ooool?o`0000Oooooo0_l0000_ooooo`;o00003oooool4o`0000Wooooo0ol00003oooo
o`?o000000Coooooo`000?l0003o00001_ooool2o`0005;ooooo000Looooo`03o`000?oooooooooo
03gooooo0_l0000Rooooo`;o000000?oooooo`000?l000000_ooool4o`0000Cooooo0_l000000ooo
oooo0000o`000002ooooo`?o00000oooool?o`0000Oooooo0_l00006ooooo`;o00006oooool2o`00
00Oooooo0_l000000ooooooo0000o`000008ooooo`;o00002?ooool2o`0000Sooooo0_l00004oooo
o`?o00000_ooool2o`0000Kooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`1Eooooo`;o
00002Oooool2o`0000;ooooo0_l00005ooooo`;o00000oooool2o`0000Kooooo0ol00002ooooo`go
00004Oooool2o`0001_ooooo0_l00007ooooo`;o00002oooool2o`0000Oooooo0ol00008ooooo`;o
00002?ooool2o`0000Gooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`1Eooooo`;o0000
2Oooool2o`0000;ooooo0_l00005ooooo`?o00002oooool3o`000003ooooool0003o000000_o0000
00?oooooo`000?l000004_ooool2o`0003Kooooo0_l00002ooooo`;o00003oooool2o`0000Gooooo
0_l0001Dooooo`007?ooool00ol0003oooooooooo`1Tooooo`;o00001Oooool5o`0000[ooooo0_l0
00000ooooooo0000o`00000:o`0000;ooooo0_l0000Booooo`;o00008oooool2o`0000kooooo0_l0
0003ooooo`Go0000Joooool001cooooo00?o0000ooooooooool0Joooool2o`000003ooooool0003o
000000;ooooo0_l00003ooooo`;o00000oooool=o`0001Kooooo0_l0000Sooooo`;o00002_ooool2
o`0000;ooooo1?l000000ooooooo0000o`000003o`0001;ooooo0_l0001Gooooo`007?ooool00ol0
003oooooooooo`1/ooooo`?o00000oooool2o`0000?ooooo0_l00003ooooo`go00000_ooool2o`00
00Gooooo0_l0000;ooooo`;o00006Oooool2o`0000Oooooo0_l00006ooooo`go00000_ooool2o`00
01Cooooo0_l0001Gooooo`007?ooool2o`0006gooooo0ol00002ooooo`?o00002Oooool=o`000003
ooooool0003o000000Gooooo0_l00007ooooo`;o00005_ooool2o`0000Gooooo0_l00007ooooo`Oo
000000?oooooo`000?l000002Ol00006ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Oo
oooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`1Xooooo`;o00001_ooool4o`0000Wooooo
3Ol0000Aooooo`Go00004oooool3o`0000oooooo1Ol00002ooooo`;o00000_ooool2o`0000Kooooo
0_l00002ooooo`;o000000?oooooo`000?l000001?l00007ooooo`;o0000Foooool001cooooo00?o
0000ooooooooool0I_ooool4o`000004ooooool0003o0000o`0000;ooooo0_l00003ooooo`;o0000
1_ooool;o`000003ooooool0003o000000;o00003_ooool5o`0001Cooooo1?l0000@ooooo`;o0000
0_ooool2o`0000[ooooo0_l00005ooooo`Co0000I_ooool001cooooo00?o0000ooooooooool0E?oo
ool2o`00013ooooo0_l00003ooooo`?o00000_ooool2o`0000?ooooo0_l00008ooooo`So00000_oo
ool4o`0001;ooooo0_l0000Eooooo`;o00004?ooool2o`0000Kooooo0_l00003ooooo`;o00001Ooo
ool2o`0006_ooooo000Looooo`03o`000?oooooooooo04Gooooo0_l0000=ooooo`;o00005_ooool2
o`0000;ooooo0_l00007ooooo`;o00000oooool2o`000004ooooool0003o0000o`00017ooooo1?l0
0006ooooo`;o0000:?ooool2o`0000Gooooo0_l00003ooooo`;o00001Oooool2o`0006_ooooo000L
ooooo`03o`000?oooooooooo04Gooooo0_l0000^ooooo`Ko00000oooool2o`000003ooooool0003o
000001;ooooo1?l0000Zooooo`;o00001?ooool2o`0001;ooooo0_l0001Zooooo`007?ooool00ol0
003oooooooooo`1eooooo`Co00004oooool2o`0000Oooooo1?l00003ooooo`Co00006_ooool2o`00
00Oooooo0_l00004ooooo`;o00002Oooool2o`0000Oooooo0_l0001Zooooo`007?ooool00ol0003o
ooooooooo`1Yooooo`;o00006Oooool2o`0000Kooooo0_l00005ooooo`Ko00000oooool4o`0000?o
oooo0_l0000Eooooo`;o00003Oooool2o`0000Oooooo1_l00008ooooo`;o0000Ioooool001cooooo
00?o0000ooooooooool0IOooool2o`0000;ooooo0_l0000Fooooo`;o000000?oooooo`000?l00000
3Oooool2o`0000kooooo0_l00005ooooo`;o00004?ooool2o`000003ooooool0003o000000_ooooo
0ol00002ooooo`?o00000_ooool2o`0000Sooooo0_l0001Wooooo`007?ooool00ol0003ooooooooo
o`1Uooooo`;o00006_ooool2o`0001Gooooo0_l0000=ooooo`;o000000?oooooo`000?l000004?oo
ool2o`000003ooooool0003o000000_ooooo0ol00002ooooo`;o0000M_ooool001cooooo00?o0000
ooooooooool0Joooool2o`0000Sooooo1?l00007ooooo`;o00005_ooool2o`0000cooooo0ol0000;
ooooo`;o00004?ooool3o`0000Oooooo0_l0001gooooo`007?ooool00ol0003oooooooooo`1[oooo
o`;o00002?ooool5o`0000;ooooo1_l0000@ooooo`;o00004_ooool2o`0000cooooo0_l0000:oooo
o`;o00001?ooool3o`0000Oooooo1?l0001eooooo`007?ooool00ol0003oooooooooo`1hooooo`?o
000000?oooooo`000?l000001?l0000@ooooo`;o00003Oooool2o`0000Kooooo0_l0000Eooooo`;o
00004?ooool2o`0007Gooooo000Looooo`03o`000?oooooooooo077ooooo0_l00006ooooo`;o0000
1Oooool3o`0001;ooooo0ol00009ooooo`;o00001Oooool4o`000003ooooool0003o000001Wooooo
0_l00005ooooo`;o00000_ooool2o`0007Cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGo
oooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1aoooo
o`;o00003_ooool4o`0000kooooo1Ol0000@ooooo`Wo00005oooool2o`0000Gooooo0_l00002oooo
o`;o0000M?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4Q
oiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo08?ooooo0_l0000>ooooo`Go00005?oo
ool2o`000003ooooool0003o000000?ooooo0_l00003ooooo`;o00002Oooool2o`0000Wooooo0_l0
001hooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`28ooooo`;o000000?oooooo`000?l000001?l0
0002ooooo`;o00006_ooool2o`0000?ooooo0_l00003ooooo`;o00001_ooool2o`000004ooooool0
003o0000o`0008;ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go
<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000Moooool2o`000004ooooool0003o0000o`0000_o
oooo0_l000000ooooooo0000o`000006o`00027ooooo0_l0000;ooooo`Ko00003Oooool2o`0007?o
oooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Goc<c<o`000?l0003o
0000olc<c006ooooo`03o`000?oooooooooo07Oooooo0_l000001?oooooo0000o`000?l0000;oooo
o`;o00001?ooool2o`000004ooooool0003o0000o`0001kooooo1?l0000:ooooo`Oo00002_ooool2
o`000003ooooool0003o000007?ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo
00Wooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo08;ooooo1?l00006
ooooo`;o00001?ooool2o`0001kooooo0_l0000<ooooo`;o00000oooool2o`0000Gooooo0ol00002
ooooo`;o000000?oooooo`000?l00000Loooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2ooo
ool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0P_ooool4o`0000Kooooo
0_l0000cooooo`;o00002Oooool3o`0000;ooooo0_l000000ooooooo0000o`00001cooooo`0000Ko
ooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0
003oooooooooo`27ooooo`?o00000_ooool2o`0000;ooooo0_l0000Oooooo`Co00003?ooool2o`00
00[ooooo0_l00002ooooo`;o0000M_ooool001cooooo00?o0000ooooooooool0Qoooool3o`0000;o
oooo0_l00002ooooo`;o00006oooool2o`0000;ooooo1?l00005ooooo`;o00000oooool2o`0000;o
oooo0_l00008ooooo`;o0000N_ooool001cooooo00?o0000ooooooooool0Ooooool3o`0000oooooo
0_l0000:ooooo`Co00003?ooool2o`0000Gooooo0_l00004ooooo`;o00000oooool2o`0000;ooooo
0_l00003ooooo`;o0000Ooooool001cooooo00?o0000ooooooooool0Ooooool3o`0000kooooo0ol0
0002ooooo`?o00001Oooool4o`0000Gooooo0_l0000;ooooo`?o00003Oooool2o`0000?ooooo0_l0
001oooooo`007?ooool00ol0003oooooooooo`1oooooo`;o00001Oooool2o`0000Sooooo0_l00003
ooooo`?o000000?oooooo`000?l000000_l00009ooooo`Co00002Oooool3o`0000?ooooo0_l00008
ooooo`;o000000?oooooo`000?l00000POooool001cooooo00?o0000ooooooooool0Ooooool2o`00
00Gooooo0_l00004ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o000000?ooooo
o`000?l000000_l000000ooooooo0000o`000002ooooo`?o00000oooool2o`0000Wooooo1?l00002
ooooo`;o00002oooool2o`00087ooooo000Looooo`03o`000?oooooooooo08cooooo0_l00004oooo
o`Go00000_ooool2o`0000?ooooo0_l00002ooooo`Co00003Oooool4o`0000;ooooo0_l00008oooo
o`;o0000Q?ooool001cooooo00?o0000ooooooooool0T_ooool5o`0000cooooo0ol00008ooooo`;o
00000_ooool2o`0000Gooooo0_l00008ooooo`;o0000Q?ooool001cooooo00?o0000ooooooooool0
Soooool2o`0000?ooooo0_l00002ooooo`;o00004oooool3o`0000;ooooo0_l00003ooooo`;o0000
1?ooool2o`0008[ooooo000Looooo`03o`000?oooooooooo08oooooo0_l00003ooooo`;o00000_oo
ool2o`000003ooooool0003o000000Kooooo0_l00005ooooo`Go00002?ooool4o`0000;ooooo0_l0
002:ooooo`007?ooool00ol0003oooooooooo`2Hooooo`;o000000Coooooo`000?l0003o00001Ooo
ool2o`0000Gooooo1Ol00009ooooo`?o0000S_ooool001cooooo00?o0000ooooooooool0Voooool3
o`000:_ooooo000Looooo`;o0000Qoooool2o`0001?ooooo0ol0000Looooo`;o0000SOooool001co
oooo00?o0000ooooooooool0Q_ooool2o`0000Kooooo0_l0000;ooooo`;o00007Oooool2o`0008go
oooo000Looooo`03o`000?oooooooooo08kooooo0ol0000:ooooo`;o00002oooool4o`0009gooooo
000Looooo`03o`000?oooooooooo08oooooo0_l0000Gooooo`Oo00001?ooool2o`0009Cooooo000L
ooooo`03o`000?oooooooooo09?ooooo0_l0000Gooooo`?o000000Coooooo`000?l0003ooooo0_l0
002Dooooo`007?ooool00ol0003oooooooooo`2Cooooo`;o00006oooool2o`0009Oooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Boooo
o`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003ooooo
ooooo`05ooooo`?o0000oooooom:ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000D
ooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBoooo
o`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Booooo`03oeEEEOmVIVKo00000?oooooo
E?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Gooooo00Co410@o`000?l0
003ooooo0_l000000ol@413oooooooooo`0Eooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool0
1OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o410@olc<c02@ooooo`00Y_oo
ool01Ol0003ooooooooooooooooo000000Wooooo1_l00009ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoEEEEogMgMoooooooV9RHob4Q8@2@
ooooo`00Y_ooool01Ol0003ooooooooooooooooo000001Sooooo00Go0000ooooooooooooooooo`00
0007ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`2>ooooo`00Y_oo
ool01Ol0003ooooooooooooooooo000000Wooooo1_l00009ooooo`05o`000?nHV9SooooooiRHV?lQ
8B401_ooool00onYZJWo410@ooooo`02ooooo`05o`000?nHV9SooooooiRHV?lQ8B40T?ooool00:Ko
oooo00Go0000ohN7QoooooooZJVYo`00000Hooooo`05o`000?mEEEGo0000oa0@4?o<c<`01Oooool0
0ol@413o0000okZj^P03ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0T?ooool00:Gooooo00?o410@
o`000?mgMgL00_l000000onHV9Soooooooooo`0Fooooo`03oeEEEOn7QhOooooo00Sooooo00?o^[Zj
ob4Q8Oooool00_ooool00omEEEGoQhN7ooooo`2Booooo`00`oooool00ooMgMgo410@oiRHV005oooo
o`05oa0@4?nHV9SooooookZj^_l000000oooool00ooMgMgo410@oiRHV02Booooo`00a?ooool01?o<
c<coA4A4o`000?l@4103ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01?ooool01?o<c<coA4A4o`00
0?l@412@ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(642) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.33765 .49784 Mdot
.30128 .55087 Mdot
.65221 .52207 Mdot
.47688 .34874 Mdot
.66287 .46229 Mdot
.64064 .55517 Mdot
.5238 .6534 Mdot
.51229 .62253 Mdot
.63051 .561 Mdot
.21743 .40963 Mdot
.54354 .6216 Mdot
.43255 .30663 Mdot
.53772 .6524 Mdot
.47816 .39833 Mdot
.42346 .7214 Mdot
.53467 .35253 Mdot
.29329 .55576 Mdot
.71477 .41146 Mdot
.53142 .34345 Mdot
.66806 .53259 Mdot
.42156 .49211 Mdot
.47307 .39286 Mdot
.29412 .54773 Mdot
.47599 .39675 Mdot
.44169 .36039 Mdot
.31123 .52963 Mdot
.35216 .50076 Mdot
.44964 .37476 Mdot
.43923 .40613 Mdot
.55403 .63267 Mdot
.74277 .44153 Mdot
.3724 .81512 Mdot
.52711 .35828 Mdot
.3644 .35263 Mdot
.49806 .63573 Mdot
.77535 .62755 Mdot
.62704 .58081 Mdot
.54228 .6149 Mdot
.5047 .64561 Mdot
.50673 .66275 Mdot
.53476 .66975 Mdot
.31077 .53732 Mdot
.54919 .677 Mdot
.69766 .57827 Mdot
.49925 .35176 Mdot
.31056 .70231 Mdot
.77163 .38847 Mdot
.45144 .37593 Mdot
.32403 .50195 Mdot
.67025 .54397 Mdot
.47446 .21821 Mdot
.5504 .61477 Mdot
.36246 .72613 Mdot
.09233 .52966 Mdot
.55157 .64051 Mdot
.46847 .35583 Mdot
.65724 .57115 Mdot
.48791 .36606 Mdot
.45945 .38162 Mdot
.37359 .30809 Mdot
.44782 .40413 Mdot
.6973 .40192 Mdot
.35125 .495 Mdot
.67933 .53994 Mdot
.63496 .56123 Mdot
.5541 .65724 Mdot
.3337 .55681 Mdot
.53652 .66179 Mdot
.43702 .32077 Mdot
.65876 .52987 Mdot
.45692 .37137 Mdot
.54474 .62058 Mdot
.31337 .56401 Mdot
.43907 .34432 Mdot
.34704 .67711 Mdot
.53549 .71675 Mdot
.70694 .35966 Mdot
.30972 .44467 Mdot
.28593 .26632 Mdot
.61488 .65501 Mdot
.47377 .40935 Mdot
.27006 .25609 Mdot
.42865 .70071 Mdot
.31257 .55596 Mdot
.37573 .38663 Mdot
.61172 .76735 Mdot
.43914 .41323 Mdot
.58447 .453 Mdot
.48414 .43781 Mdot
.42425 .57966 Mdot
.63068 .56837 Mdot
.30658 .52507 Mdot
.49799 .34941 Mdot
.43012 .41096 Mdot
.3416 .27876 Mdot
.51901 .36174 Mdot
.49432 .35355 Mdot
.34159 .57818 Mdot
.53499 .62672 Mdot
.3997 .38635 Mdot
.69494 .59214 Mdot
.39166 .72491 Mdot
.47059 .33918 Mdot
.63913 .53952 Mdot
.30451 .50049 Mdot
.48912 .34234 Mdot
.55411 .65145 Mdot
.46198 .40418 Mdot
.4952 .6807 Mdot
.30284 .51777 Mdot
.43254 .41344 Mdot
.71104 .38106 Mdot
.38616 .64109 Mdot
.34727 .51214 Mdot
.18916 .50289 Mdot
.45018 .40002 Mdot
.46619 .38619 Mdot
.30806 .55303 Mdot
.66286 .5767 Mdot
.55898 .48023 Mdot
.2997 .56112 Mdot
.50472 .65289 Mdot
.3014 .51332 Mdot
.45245 .43845 Mdot
.66926 .57059 Mdot
.38724 .73235 Mdot
.39642 .71472 Mdot
.73049 .31756 Mdot
.43122 .35895 Mdot
.41353 .72376 Mdot
.653 .55023 Mdot
.30601 .54266 Mdot
.54101 .65892 Mdot
.48023 .42821 Mdot
.34708 .53701 Mdot
.50988 .63726 Mdot
.68358 .37777 Mdot
.67696 .47676 Mdot
.35918 .51952 Mdot
.57788 .38615 Mdot
.50545 .62206 Mdot
.50979 .66669 Mdot
.49794 .22543 Mdot
.31729 .55397 Mdot
.67485 .39422 Mdot
.51206 .64564 Mdot
.61934 .27834 Mdot
.48731 .42278 Mdot
.57272 .22174 Mdot
.3273 .20843 Mdot
.48515 .2208 Mdot
.2358 .62322 Mdot
.69598 .41504 Mdot
.51157 .64931 Mdot
.4586 .35238 Mdot
.33166 .53839 Mdot
.32411 .5427 Mdot
.42764 .41367 Mdot
.43443 .37867 Mdot
.498 .39334 Mdot
.46643 .4273 Mdot
.81186 .51208 Mdot
.49492 .40092 Mdot
.48292 .59254 Mdot
.35247 .52876 Mdot
.43521 .36493 Mdot
.61444 .55516 Mdot
.42729 .35434 Mdot
.54204 .61512 Mdot
.46717 .37434 Mdot
.43931 .37153 Mdot
.4982 .33434 Mdot
.52306 .67133 Mdot
.48582 .83416 Mdot
.22601 .33289 Mdot
.7037 .7078 Mdot
.26358 .61911 Mdot
.65708 .55958 Mdot
.47659 .41643 Mdot
.67764 .41265 Mdot
.38935 .42005 Mdot
.45648 .38698 Mdot
.4455 .21579 Mdot
.4392 .38203 Mdot
.25807 .49243 Mdot
.42904 .45028 Mdot
.6617 .76207 Mdot
.44975 .64045 Mdot
.44552 .40888 Mdot
.27045 .32005 Mdot
.59506 .21653 Mdot
.7536 .38689 Mdot
.5509 .64959 Mdot
.60813 .57448 Mdot
.64281 .58414 Mdot
.51933 .67845 Mdot
.4099 .40857 Mdot
.21602 .42644 Mdot
.4199 .33576 Mdot
.38212 .73347 Mdot
.34178 .48276 Mdot
.69972 .41777 Mdot
.35842 .51529 Mdot
.21441 .30566 Mdot
.49714 .49046 Mdot
.53729 .70015 Mdot
.71855 .40211 Mdot
.63407 .53152 Mdot
.37272 .73163 Mdot
.67222 .40724 Mdot
.48989 .35507 Mdot
.31259 .50818 Mdot
.59116 .21452 Mdot
.52674 .42086 Mdot
.86398 .50375 Mdot
.32829 .55524 Mdot
.48668 .55193 Mdot
.54794 .6498 Mdot
.67505 .57192 Mdot
.43804 .40988 Mdot
.49383 .38359 Mdot
.34902 .49562 Mdot
.4475 .38203 Mdot
.42565 .52634 Mdot
.44203 .3718 Mdot
.6848 .56595 Mdot
.73446 .37675 Mdot
.51601 .68174 Mdot
.72036 .30519 Mdot
.31288 .5662 Mdot
.54042 .54597 Mdot
.62904 .54206 Mdot
.28595 .59076 Mdot
.55237 .62512 Mdot
.69226 .37505 Mdot
.6178 .57157 Mdot
.67518 .37353 Mdot
.47913 .33133 Mdot
.62764 .57723 Mdot
.70011 .38565 Mdot
.61316 .51312 Mdot
.49266 .3507 Mdot
.57778 .25582 Mdot
.51669 .64722 Mdot
.35363 .50315 Mdot
.44623 .40389 Mdot
.40144 .72276 Mdot
.4254 .41875 Mdot
.4159 .72502 Mdot
.38636 .73793 Mdot
.36529 .73361 Mdot
.55988 .7082 Mdot
.67013 .41467 Mdot
.29508 .66187 Mdot
.52877 .49416 Mdot
.29422 .55875 Mdot
.50682 .35636 Mdot
.55389 .83534 Mdot
.5156 .65281 Mdot
.48803 .35539 Mdot
.62498 .761 Mdot
.51252 .64614 Mdot
.48281 .37158 Mdot
.53534 .67123 Mdot
.3294 .54142 Mdot
.55592 .51008 Mdot
.28866 .53327 Mdot
.47788 .35239 Mdot
.53223 .63754 Mdot
.61182 .57483 Mdot
.31254 .52922 Mdot
.45979 .40048 Mdot
.47995 .41032 Mdot
.37671 .72992 Mdot
.43173 .37188 Mdot
.588 .81441 Mdot
.45299 .37299 Mdot
.63223 .53163 Mdot
.52086 .36779 Mdot
.57166 .20375 Mdot
.67852 .47475 Mdot
.34971 .54893 Mdot
.37958 .7402 Mdot
.63602 .5742 Mdot
.61224 .48719 Mdot
.68736 .44583 Mdot
.46988 .40568 Mdot
.38852 .71759 Mdot
.49317 .55363 Mdot
.55772 .64907 Mdot
.49933 .4263 Mdot
.45371 .5073 Mdot
.62278 .56303 Mdot
.37628 .73281 Mdot
.44637 .45138 Mdot
.30032 .50631 Mdot
.46636 .35458 Mdot
.62242 .57855 Mdot
.30981 .50287 Mdot
.48173 .42885 Mdot
.805 .45599 Mdot
.39923 .72287 Mdot
.5185 .65076 Mdot
.50631 .29076 Mdot
.50038 .39781 Mdot
.64407 .5861 Mdot
.33979 .54152 Mdot
.54563 .6332 Mdot
.32296 .50974 Mdot
.62746 .22385 Mdot
.28616 .62404 Mdot
.7595 .58453 Mdot
.70838 .4223 Mdot
.23651 .69121 Mdot
.72448 .68351 Mdot
.31498 .63772 Mdot
.70248 .32534 Mdot
.76102 .68819 Mdot
.61364 .56114 Mdot
.47843 .2552 Mdot
.64556 .57583 Mdot
.46315 .34408 Mdot
.63763 .55602 Mdot
.62031 .80834 Mdot
.44576 .3754 Mdot
.6596 .56282 Mdot
.79757 .52007 Mdot
.43524 .39166 Mdot
.35476 .52241 Mdot
.35264 .78447 Mdot
.20516 .51066 Mdot
.54054 .45744 Mdot
.66329 .56258 Mdot
.39336 .24618 Mdot
.44073 .38852 Mdot
.54001 .38252 Mdot
.32768 .53496 Mdot
.47806 .44016 Mdot
.71165 .40268 Mdot
.68964 .36828 Mdot
.50179 .23613 Mdot
.20811 .53364 Mdot
.54705 .35537 Mdot
.31488 .53365 Mdot
.29623 .25665 Mdot
.34652 .68 Mdot
.39758 .71105 Mdot
.50292 .638 Mdot
.48351 .83227 Mdot
.50666 .45254 Mdot
.56904 .35549 Mdot
.43494 .53996 Mdot
.30236 .52964 Mdot
.72759 .64723 Mdot
.54216 .63677 Mdot
.25666 .32183 Mdot
.24817 .42348 Mdot
.50179 .38553 Mdot
.5624 .65424 Mdot
.41552 .33053 Mdot
.42836 .537 Mdot
.57204 .24071 Mdot
.7135 .60892 Mdot
.48486 .34898 Mdot
.30598 .66789 Mdot
.46285 .38321 Mdot
.59302 .22219 Mdot
.48229 .35407 Mdot
.33135 .50981 Mdot
.55342 .40235 Mdot
.62715 .45487 Mdot
.19085 .40598 Mdot
.47748 .49291 Mdot
.67701 .4209 Mdot
.48206 .39647 Mdot
.49917 .38287 Mdot
.70326 .39599 Mdot
.32086 .51906 Mdot
.511 .37435 Mdot
.77513 .38375 Mdot
.5012 .39304 Mdot
.55443 .61812 Mdot
.58666 .48734 Mdot
.22928 .53319 Mdot
.43572 .41321 Mdot
.30878 .50135 Mdot
.54844 .66207 Mdot
.50635 .63059 Mdot
.54893 .39125 Mdot
.51821 .66026 Mdot
.45985 .35892 Mdot
.57768 .49209 Mdot
.29485 .53901 Mdot
.39059 .37588 Mdot
.32749 .51809 Mdot
.36855 .21728 Mdot
.5293 .67448 Mdot
.38322 .70839 Mdot
.50217 .2667 Mdot
.53153 .64591 Mdot
.346 .58677 Mdot
.51023 .45499 Mdot
.42727 .3467 Mdot
.25997 .58427 Mdot
.62903 .59063 Mdot
.3708 .71694 Mdot
.55032 .63604 Mdot
.49872 .3961 Mdot
.48012 .3369 Mdot
.56458 .63564 Mdot
.35037 .29731 Mdot
.74239 .44605 Mdot
.47678 .35613 Mdot
.32813 .51161 Mdot
.3069 .54064 Mdot
.49942 .41282 Mdot
.45384 .39045 Mdot
.62305 .53915 Mdot
.38882 .7156 Mdot
.36834 .73242 Mdot
.39357 .71242 Mdot
.64817 .59819 Mdot
.2213 .66466 Mdot
.50971 .6663 Mdot
.26686 .69964 Mdot
.55268 .7764 Mdot
.547 .38538 Mdot
.63654 .58856 Mdot
.48777 .37842 Mdot
.46596 .33651 Mdot
.53467 .63381 Mdot
.19034 .55681 Mdot
.48578 .30897 Mdot
.36222 .51671 Mdot
.56144 .62413 Mdot
.38625 .37937 Mdot
.51693 .71222 Mdot
.71052 .38998 Mdot
.48656 .48635 Mdot
.56359 .65039 Mdot
.31365 .51074 Mdot
.56542 .64194 Mdot
.49927 .38621 Mdot
.41505 .38517 Mdot
.29808 .53967 Mdot
.66589 .41102 Mdot
.49329 .34196 Mdot
.48108 .37225 Mdot
.60157 .18595 Mdot
.34246 .6762 Mdot
.58243 .65302 Mdot
.44849 .3476 Mdot
.46232 .31945 Mdot
.66439 .41329 Mdot
.50543 .39063 Mdot
.44149 .41287 Mdot
.38742 .63243 Mdot
.50426 .66885 Mdot
.6961 .36104 Mdot
.23867 .34029 Mdot
.33549 .55126 Mdot
.5991 .80199 Mdot
.39282 .72629 Mdot
.50055 .66928 Mdot
.54861 .5155 Mdot
.37468 .71576 Mdot
.58354 .75582 Mdot
.6712 .72816 Mdot
.38316 .71042 Mdot
.63595 .51798 Mdot
.41262 .46197 Mdot
.46365 .42966 Mdot
.47244 .37162 Mdot
.66827 .40543 Mdot
.32759 .54967 Mdot
.46117 .60978 Mdot
.58622 .59151 Mdot
.47003 .39052 Mdot
.31532 .576 Mdot
.63576 .76512 Mdot
.37325 .72826 Mdot
.68525 .41576 Mdot
.68457 .42648 Mdot
.4652 .38311 Mdot
.35511 .62321 Mdot
.3122 .53291 Mdot
.45997 .40036 Mdot
.47241 .42403 Mdot
.66329 .57203 Mdot
.3206 .50579 Mdot
.63048 .53983 Mdot
.38978 .73643 Mdot
.8177 .61502 Mdot
.62208 .19065 Mdot
.52107 .63696 Mdot
.72329 .67324 Mdot
.56559 .61656 Mdot
.67153 .63393 Mdot
.38777 .71246 Mdot
.46523 .39699 Mdot
.32249 .56553 Mdot
.46015 .40341 Mdot
.50681 .37491 Mdot
.50171 .36041 Mdot
.54324 .34779 Mdot
.45484 .21354 Mdot
.68135 .40664 Mdot
.47929 .31425 Mdot
.60498 .56331 Mdot
.65369 .76156 Mdot
.37804 .79444 Mdot
.48867 .39433 Mdot
.46941 .38461 Mdot
.34624 .548 Mdot
.46047 .32942 Mdot
.55826 .63951 Mdot
.32193 .55541 Mdot
.478 .33962 Mdot
.70454 .50826 Mdot
.50382 .39872 Mdot
.73628 .66384 Mdot
.56572 .64149 Mdot
.47752 .48493 Mdot
.43855 .32919 Mdot
.38534 .70986 Mdot
.37208 .7153 Mdot
.40372 .7183 Mdot
.55874 .65397 Mdot
.65944 .57516 Mdot
.59664 .5958 Mdot
.43077 .4428 Mdot
.45727 .35479 Mdot
.42751 .34428 Mdot
.64895 .60021 Mdot
.58521 .47337 Mdot
.24979 .63266 Mdot
.44185 .45702 Mdot
.61196 .58659 Mdot
.34684 .57187 Mdot
.17119 .46576 Mdot
.33223 .55049 Mdot
.72474 .36312 Mdot
.54276 .61684 Mdot
.71365 .39588 Mdot
.41579 .22704 Mdot
.29699 .53455 Mdot
.35511 .49917 Mdot
.65894 .5607 Mdot
.45147 .59389 Mdot
.12808 .63594 Mdot
.64654 .54163 Mdot
.72594 .34459 Mdot
.32316 .53326 Mdot
.51243 .32997 Mdot
.4941 .55582 Mdot
.45495 .58416 Mdot
.6496 .56729 Mdot
.47504 .41089 Mdot
.34029 .59472 Mdot
.62482 .53802 Mdot
.51778 .40657 Mdot
.66533 .55873 Mdot
.52732 .67035 Mdot
.65656 .55099 Mdot
.3502 .56136 Mdot
.47534 .33115 Mdot
.0952 .5603 Mdot
.42858 .67718 Mdot
.45206 .40622 Mdot
.56044 .62134 Mdot
.81819 .46213 Mdot
.50142 .3722 Mdot
.71158 .4058 Mdot
.61553 .59028 Mdot
.77754 .50736 Mdot
.44171 .39378 Mdot
.6433 .56163 Mdot
.36804 .53722 Mdot
.64772 .61426 Mdot
.59467 .65812 Mdot
.36761 .72741 Mdot
.33497 .54022 Mdot
.40139 .73952 Mdot
.49671 .63997 Mdot
.49805 .34011 Mdot
.48206 .41852 Mdot
.34854 .51855 Mdot
.55035 .72787 Mdot
.51392 .33987 Mdot
.47394 .40913 Mdot
.63109 .53564 Mdot
.60987 .59699 Mdot
.43077 .76904 Mdot
.61255 .56066 Mdot
.46423 .31865 Mdot
.34615 .51592 Mdot
.46798 .34666 Mdot
.35551 .52871 Mdot
.5052 .35479 Mdot
.24215 .55173 Mdot
.33139 .54999 Mdot
.27909 .60511 Mdot
.42753 .38582 Mdot
.46165 .27943 Mdot
.50798 .37622 Mdot
.49229 .3543 Mdot
.62283 .59408 Mdot
.6876 .39319 Mdot
.51589 .41326 Mdot
.54962 .53015 Mdot
.66482 .39284 Mdot
.35919 .43373 Mdot
.66137 .57726 Mdot
.66948 .39162 Mdot
.5893 .29764 Mdot
.3792 .74009 Mdot
.69059 .40495 Mdot
.42498 .7967 Mdot
.52328 .63669 Mdot
.29164 .53947 Mdot
.43424 .38931 Mdot
.78076 .67102 Mdot
.74209 .44249 Mdot
.37709 .72462 Mdot
.44752 .39969 Mdot
.49078 .37494 Mdot
.29444 .5128 Mdot
.24268 .27852 Mdot
.68206 .56553 Mdot
.48238 .34518 Mdot
.2969 .55706 Mdot
.31069 .22477 Mdot
.66542 .5521 Mdot
.68953 .4097 Mdot
.56768 .64721 Mdot
.30618 .48614 Mdot
.36735 .72291 Mdot
.53234 .67572 Mdot
.65274 .50284 Mdot
.41238 .218 Mdot
.44413 .39003 Mdot
.62484 .58612 Mdot
.48258 .22004 Mdot
.40825 .41675 Mdot
.56566 .60994 Mdot
.27592 .49359 Mdot
.30335 .52924 Mdot
.56411 .63272 Mdot
.6788 .42271 Mdot
.29386 .53778 Mdot
.31969 .51853 Mdot
.51239 .62274 Mdot
.48249 .60536 Mdot
.48439 .55449 Mdot
.55437 .62149 Mdot
.41766 .60338 Mdot
.50909 .22989 Mdot
.39114 .71705 Mdot
.68602 .41631 Mdot
.63153 .22082 Mdot
.30995 .53509 Mdot
.4848 .83259 Mdot
.45588 .21593 Mdot
.49404 .35345 Mdot
.6878 .38282 Mdot
.5864 .76377 Mdot
.59522 .54337 Mdot
.51104 .6376 Mdot
.59624 .45604 Mdot
.70131 .4191 Mdot
.49009 .41802 Mdot
.23194 .52273 Mdot
.43087 .39766 Mdot
.51318 .64979 Mdot
.41793 .54576 Mdot
.32682 .5055 Mdot
.49658 .64281 Mdot
.42938 .51919 Mdot
.46232 .33765 Mdot
.4527 .41548 Mdot
.65377 .25797 Mdot
.31616 .50567 Mdot
.36653 .72361 Mdot
.46453 .40864 Mdot
.48579 .36529 Mdot
.50414 .34334 Mdot
.52129 .2782 Mdot
.35362 .64062 Mdot
.48424 .34437 Mdot
.66439 .58573 Mdot
.42349 .35765 Mdot
.44617 .41348 Mdot
.28732 .53025 Mdot
.54406 .19299 Mdot
.39572 .73254 Mdot
.47507 .36854 Mdot
.47684 .35702 Mdot
.50358 .64804 Mdot
.48866 .55433 Mdot
.45006 .58697 Mdot
.65126 .52966 Mdot
.6768 .32049 Mdot
.41708 .34271 Mdot
.34576 .5346 Mdot
.71522 .38839 Mdot
.48264 .32377 Mdot
.34457 .54554 Mdot
.41189 .38134 Mdot
.61975 .54088 Mdot
.38689 .71654 Mdot
.56655 .37043 Mdot
.6939 .40062 Mdot
.48721 .6693 Mdot
.2985 .72986 Mdot
.61244 .55655 Mdot
.44942 .35641 Mdot
.6407 .6095 Mdot
.62827 .54797 Mdot
.37808 .72931 Mdot
.46788 .45032 Mdot
.32225 .54073 Mdot
.32379 .507 Mdot
.54185 .22955 Mdot
.67158 .58672 Mdot
.4626 .16518 Mdot
.52597 .66957 Mdot
.4842 .43226 Mdot
.35685 .76719 Mdot
.33494 .50672 Mdot
.64162 .23807 Mdot
.6676 .39465 Mdot
.51147 .63715 Mdot
.37815 .74481 Mdot
.34708 .54321 Mdot
.34292 .50577 Mdot
.5012 .35438 Mdot
.48464 .38985 Mdot
.71497 .32977 Mdot
.58323 .22062 Mdot
.53368 .67079 Mdot
.69623 .41061 Mdot
.66062 .53442 Mdot
.45654 .34227 Mdot
.30185 .5541 Mdot
.26386 .48401 Mdot
.49609 .40331 Mdot
.62673 .53609 Mdot
.30125 .5367 Mdot
.70364 .40268 Mdot
.68922 .37838 Mdot
.49421 .3549 Mdot
.3412 .42164 Mdot
.52844 .64934 Mdot
.35108 .51586 Mdot
.38937 .51387 Mdot
.51808 .35494 Mdot
.48571 .39382 Mdot
.41728 .3214 Mdot
.52885 .6763 Mdot
.56614 .38064 Mdot
.67845 .42967 Mdot
.321 .54686 Mdot
.45603 .40669 Mdot
.69707 .4023 Mdot
.53853 .30598 Mdot
.38024 .71398 Mdot
.66454 .55579 Mdot
.70911 .40805 Mdot
.69391 .38728 Mdot
.67152 .38284 Mdot
.47069 .83051 Mdot
.29427 .50687 Mdot
.23359 .33924 Mdot
.50555 .36179 Mdot
.51711 .23319 Mdot
.42678 .36705 Mdot
.54535 .67247 Mdot
.61018 .57801 Mdot
.50526 .38015 Mdot
.50207 .3548 Mdot
.23657 .52663 Mdot
.39272 .34395 Mdot
.41583 .48693 Mdot
.30695 .51269 Mdot
.47743 .27318 Mdot
.64419 .58849 Mdot
.31593 .20575 Mdot
.46118 .85251 Mdot
.43007 .32659 Mdot
.46421 .58636 Mdot
.31856 .5558 Mdot
.50833 .64629 Mdot
.45751 .57363 Mdot
.53948 .69004 Mdot
.31531 .5489 Mdot
.46198 .34198 Mdot
.27001 .69809 Mdot
.67582 .37508 Mdot
.49634 .39451 Mdot
.54503 .65848 Mdot
.49713 .39398 Mdot
.55519 .66286 Mdot
.28855 .49668 Mdot
.42548 .61468 Mdot
.44041 .38101 Mdot
.50904 .33921 Mdot
.55237 .42967 Mdot
.48801 .3923 Mdot
.62594 .70153 Mdot
.32623 .52421 Mdot
.27554 .59556 Mdot
.50499 .40549 Mdot
.33278 .40013 Mdot
.49143 .41276 Mdot
.55223 .7308 Mdot
.4733 .42074 Mdot
.59004 .40394 Mdot
.48909 .4202 Mdot
.47477 .41725 Mdot
.53994 .63497 Mdot
.50507 .64789 Mdot
.36764 .53511 Mdot
.37149 .71254 Mdot
.66061 .76185 Mdot
.47723 .37867 Mdot
.62645 .59735 Mdot
.36607 .76351 Mdot
.6904 .38924 Mdot
.31403 .54639 Mdot
.40873 .14771 Mdot
.54388 .66685 Mdot
.67656 .5342 Mdot
.59273 .69708 Mdot
.67802 .56022 Mdot
.6911 .55728 Mdot
.44806 .28372 Mdot
.69586 .41309 Mdot
.48935 .41638 Mdot
.35637 .38921 Mdot
.322 .67373 Mdot
.51777 .40321 Mdot
.61048 .61114 Mdot
.38352 .39031 Mdot
.50979 .22756 Mdot
.66156 .38624 Mdot
.6959 .41788 Mdot
.54776 .63593 Mdot
.6634 .5263 Mdot
.40293 .3816 Mdot
.67093 .38927 Mdot
.60734 .57537 Mdot
.38918 .70413 Mdot
.73797 .4016 Mdot
.31263 .53673 Mdot
.54855 .45047 Mdot
.33195 .72352 Mdot
.53819 .66902 Mdot
.55011 .52567 Mdot
.28328 .56212 Mdot
.33366 .48664 Mdot
.3839 .70644 Mdot
.60171 .57982 Mdot
.29468 .56116 Mdot
.48899 .33907 Mdot
.52576 .42274 Mdot
.46227 .38496 Mdot
.67259 .39124 Mdot
.46195 .42365 Mdot
.60413 .57008 Mdot
.52478 .66142 Mdot
.62872 .56759 Mdot
.52541 .6491 Mdot
.25641 .67332 Mdot
.4511 .38939 Mdot
.48271 .39394 Mdot
.54299 .51107 Mdot
.35302 .5091 Mdot
.36343 .32644 Mdot
.60162 .58418 Mdot
.6538 .5739 Mdot
.46875 .34492 Mdot
.36723 .52515 Mdot
.71623 .3722 Mdot
.49488 .56169 Mdot
.47423 .422 Mdot
.32756 .52445 Mdot
.4685 .35065 Mdot
.75431 .56768 Mdot
.41856 .64898 Mdot
.32496 .5086 Mdot
.18515 .41659 Mdot
.43093 .37008 Mdot
.38476 .43269 Mdot
.51566 .32197 Mdot
.64246 .35292 Mdot
.52728 .39011 Mdot
.32412 .55672 Mdot
.4637 .37722 Mdot
.34114 .53483 Mdot
.62216 .55066 Mdot
.50916 .6615 Mdot
.33468 .53632 Mdot
.4285 .40268 Mdot
.42258 .83347 Mdot
.53996 .66554 Mdot
.48217 .40446 Mdot
.54609 .62553 Mdot
.28987 .5513 Mdot
.33896 .50135 Mdot
.43728 .78963 Mdot
.54379 .70297 Mdot
.54469 .66224 Mdot
.45817 .35761 Mdot
.3548 .69972 Mdot
.46749 .34718 Mdot
.71356 .3248 Mdot
.50697 .40892 Mdot
.52227 .3728 Mdot
.24891 .70777 Mdot
.52652 .6933 Mdot
.43534 .15995 Mdot
.58385 .58075 Mdot
.45448 .8268 Mdot
.27515 .53193 Mdot
.66185 .38566 Mdot
.71324 .67909 Mdot
.39227 .73346 Mdot
.65825 .58784 Mdot
.50534 .38124 Mdot
.23714 .5448 Mdot
.55915 .6236 Mdot
.6819 .39613 Mdot
.43976 .3813 Mdot
.63488 .52565 Mdot
.40542 .79256 Mdot
.51095 .64772 Mdot
.31129 .53882 Mdot
.35676 .51136 Mdot
.26072 .28561 Mdot
.4535 .40453 Mdot
.47838 .3913 Mdot
.54329 .61613 Mdot
.4062 .38911 Mdot
.68623 .37315 Mdot
.7791 .55017 Mdot
.54919 .65371 Mdot
.42466 .67878 Mdot
.30349 .51594 Mdot
.48973 .37654 Mdot
.59428 .48406 Mdot
.51103 .79799 Mdot
.26077 .34344 Mdot
.67039 .40817 Mdot
.67761 .29431 Mdot
.32471 .55657 Mdot
.5434 .65746 Mdot
.53471 .25431 Mdot
.43593 .42744 Mdot
.49056 .37174 Mdot
.67228 .28546 Mdot
.48602 .56292 Mdot
.67741 .43933 Mdot
.51525 .3291 Mdot
.50397 .53864 Mdot
.46867 .34357 Mdot
.47938 .33659 Mdot
.42921 .32625 Mdot
.44715 .41768 Mdot
.33359 .52736 Mdot
.22246 .4977 Mdot
.64637 .55406 Mdot
.3333 .27339 Mdot
.60168 .44354 Mdot
.43679 .39975 Mdot
.46272 .33971 Mdot
.20488 .48142 Mdot
.36809 .75883 Mdot
.32251 .52651 Mdot
.36212 .56742 Mdot
.51023 .66893 Mdot
.39733 .33558 Mdot
.66342 .59264 Mdot
.40711 .47617 Mdot
.62841 .55491 Mdot
.32888 .52402 Mdot
.65426 .57855 Mdot
.5025 .65978 Mdot
.62442 .58563 Mdot
.65186 .59662 Mdot
.5566 .67195 Mdot
.31092 .50496 Mdot
.48243 .41417 Mdot
.52968 .67397 Mdot
.66404 .26195 Mdot
.67341 .39008 Mdot
.43499 .7907 Mdot
.50642 .32309 Mdot
.39017 .4627 Mdot
.80447 .45492 Mdot
.63269 .57809 Mdot
.40163 .65209 Mdot
.33158 .54974 Mdot
.71762 .38513 Mdot
.33745 .53016 Mdot
.41594 .23621 Mdot
.69987 .39305 Mdot
.43411 .79266 Mdot
.54741 .25991 Mdot
.59612 .50749 Mdot
.42222 .40458 Mdot
.25956 .56808 Mdot
.62604 .55635 Mdot
.55398 .6175 Mdot
.60871 .76371 Mdot
.43529 .35196 Mdot
.31076 .63974 Mdot
.3063 .49505 Mdot
.37464 .73835 Mdot
.5391 .65953 Mdot
.57494 .60457 Mdot
.45227 .40092 Mdot
.59178 .50448 Mdot
.5203 .39094 Mdot
.4901 .25962 Mdot
.68862 .31657 Mdot
.295 .48418 Mdot
.4652 .35617 Mdot
.64258 .53141 Mdot
.46598 .35226 Mdot
.44095 .46284 Mdot
.49519 .22688 Mdot
.48812 .31957 Mdot
.27833 .61528 Mdot
.78672 .49046 Mdot
.29842 .54492 Mdot
.4662 .31682 Mdot
.38445 .72453 Mdot
.44127 .3521 Mdot
.84186 .62607 Mdot
.68891 .40263 Mdot
.63168 .50851 Mdot
.42697 .40393 Mdot
.46253 .4064 Mdot
.32559 .45034 Mdot
.26458 .55644 Mdot
.38213 .74365 Mdot
.49306 .36787 Mdot
.66172 .29718 Mdot
.54338 .63152 Mdot
.48661 .42766 Mdot
.46722 .37635 Mdot
.67484 .24429 Mdot
.54222 .62838 Mdot
.63358 .58273 Mdot
.38192 .73978 Mdot
.6585 .5346 Mdot
.66523 .37864 Mdot
.44444 .5735 Mdot
.61841 .22591 Mdot
.41793 .65167 Mdot
.71012 .41109 Mdot
.44382 .42199 Mdot
.37896 .43217 Mdot
.4589 .41406 Mdot
.69095 .41989 Mdot
.55385 .63212 Mdot
.33166 .52938 Mdot
.57323 .40965 Mdot
.38183 .73281 Mdot
.52256 .39375 Mdot
.65842 .39704 Mdot
.32847 .53836 Mdot
.46059 .76939 Mdot
.31939 .55174 Mdot
.53409 .64247 Mdot
.51267 .6747 Mdot
.69517 .39366 Mdot
.33631 .52819 Mdot
.67004 .55567 Mdot
.58318 .58921 Mdot
.512 .40362 Mdot
.58458 .61633 Mdot
.35213 .55522 Mdot
.35358 .501 Mdot
.33345 .56141 Mdot
.44793 .39004 Mdot
.47754 .57002 Mdot
.42889 .42313 Mdot
.55237 .65568 Mdot
.66444 .57772 Mdot
.56741 .2226 Mdot
.35394 .38748 Mdot
.4248 .67507 Mdot
.52066 .40611 Mdot
.4512 .41688 Mdot
.46521 .38338 Mdot
.47067 .35834 Mdot
.77027 .56342 Mdot
.45235 .38812 Mdot
.52835 .6412 Mdot
.63713 .54659 Mdot
.44798 .40236 Mdot
.3867 .72195 Mdot
.54461 .489 Mdot
.71538 .39084 Mdot
.59294 .40909 Mdot
.46402 .84477 Mdot
.32829 .53711 Mdot
.6163 .57401 Mdot
.66882 .56871 Mdot
.68384 .37764 Mdot
.52217 .66867 Mdot
.32623 .54947 Mdot
.62075 .35329 Mdot
.6631 .39498 Mdot
.47579 .36764 Mdot
.5657 .49911 Mdot
.17794 .43856 Mdot
.44295 .42381 Mdot
.49968 .36113 Mdot
.36717 .73644 Mdot
.68034 .55766 Mdot
.77174 .7055 Mdot
.46723 .61291 Mdot
.68979 .39321 Mdot
.70805 .39897 Mdot
.32252 .562 Mdot
.49509 .42835 Mdot
.52666 .65377 Mdot
.50155 .54783 Mdot
.81161 .43729 Mdot
.60219 .78207 Mdot
.6571 .64026 Mdot
.50585 .39421 Mdot
.26815 .45854 Mdot
.51447 .3658 Mdot
.30302 .50121 Mdot
.33739 .55677 Mdot
.31813 .52981 Mdot
.54106 .63599 Mdot
.37195 .21855 Mdot
.52584 .64269 Mdot
.46585 .84633 Mdot
.29642 .55258 Mdot
.65448 .47704 Mdot
.65938 .56969 Mdot
.44316 .44626 Mdot
.69322 .41417 Mdot
.61673 .61954 Mdot
.45593 .31904 Mdot
.34597 .62536 Mdot
.63644 .58845 Mdot
.33029 .49974 Mdot
.48256 .45954 Mdot
.68333 .75229 Mdot
.44249 .60045 Mdot
.77468 .40677 Mdot
.40283 .26104 Mdot
.7027 .39599 Mdot
.22779 .37895 Mdot
.679 .37484 Mdot
.51053 .64136 Mdot
.43348 .35484 Mdot
.42583 .3912 Mdot
.4822 .3475 Mdot
.45181 .38485 Mdot
.55075 .63524 Mdot
.51249 .38984 Mdot
.57011 .20398 Mdot
.39656 .72161 Mdot
.66635 .48291 Mdot
.70148 .38092 Mdot
.55182 .67063 Mdot
.63273 .54614 Mdot
.37588 .708 Mdot
.71454 .29756 Mdot
.5108 .3886 Mdot
.50701 .37883 Mdot
.39609 .71178 Mdot
.4078 .39197 Mdot
.50085 .45369 Mdot
.6431 .55691 Mdot
.45148 .52588 Mdot
.68408 .42497 Mdot
.7134 .39535 Mdot
.56422 .64564 Mdot
.33765 .52993 Mdot
.66683 .40269 Mdot
.6555 .52276 Mdot
.47927 .42952 Mdot
.50371 .33213 Mdot
.35311 .55466 Mdot
.45606 .2158 Mdot
.68667 .36682 Mdot
.50505 .45982 Mdot
.34206 .5421 Mdot
.30195 .49851 Mdot
.49456 .36969 Mdot
.52958 .39756 Mdot
.334 .49495 Mdot
.70474 .38083 Mdot
.55468 .66909 Mdot
.63309 .48111 Mdot
.51983 .65887 Mdot
.3312 .54382 Mdot
.41915 .40974 Mdot
.30784 .50873 Mdot
.43232 .36774 Mdot
.18665 .30169 Mdot
.45341 .42083 Mdot
.29781 .59502 Mdot
.65227 .34968 Mdot
.66631 .55554 Mdot
.66535 .54691 Mdot
.38707 .71854 Mdot
.33636 .54957 Mdot
.47994 .32478 Mdot
.70534 .40654 Mdot
.44119 .82008 Mdot
.37889 .49689 Mdot
.62754 .59282 Mdot
.67736 .57457 Mdot
.55383 .63446 Mdot
.48645 .41722 Mdot
.48572 .37853 Mdot
.62601 .58546 Mdot
.8121 .48052 Mdot
.34566 .52871 Mdot
.47811 .39159 Mdot
.44565 .41402 Mdot
.64552 .55124 Mdot
.58054 .58613 Mdot
.27765 .56556 Mdot
.44752 .41736 Mdot
.55887 .26475 Mdot
.55196 .66508 Mdot
.45429 .36787 Mdot
.51367 .3812 Mdot
.6852 .38793 Mdot
.69198 .48954 Mdot
.50391 .22792 Mdot
.53611 .67772 Mdot
.36695 .72866 Mdot
.42942 .36157 Mdot
.65873 .56683 Mdot
.51126 .32956 Mdot
.75603 .65693 Mdot
.39448 .7282 Mdot
.45953 .39514 Mdot
.41849 .34397 Mdot
.35607 .51909 Mdot
.46038 .3987 Mdot
.24801 .53151 Mdot
.64853 .53416 Mdot
.45826 .39529 Mdot
.3428 .41339 Mdot
.55463 .63717 Mdot
.45423 .32033 Mdot
.708 .40684 Mdot
.64761 .35574 Mdot
.31478 .73363 Mdot
.63623 .60058 Mdot
.69195 .37898 Mdot
.46463 .42417 Mdot
.63801 .53019 Mdot
.56795 .64614 Mdot
.31928 .63092 Mdot
.45418 .42903 Mdot
.52483 .66602 Mdot
.52842 .66399 Mdot
.6918 .39619 Mdot
.39205 .16766 Mdot
.4171 .3451 Mdot
.48849 .39924 Mdot
.80023 .37477 Mdot
.28423 .55165 Mdot
.48818 .40302 Mdot
.48502 .41707 Mdot
.5173 .64618 Mdot
.53473 .27388 Mdot
.40357 .51868 Mdot
.79771 .52025 Mdot
.55327 .6653 Mdot
.60059 .55484 Mdot
.62966 .53845 Mdot
.69662 .37971 Mdot
.29992 .54435 Mdot
.69951 .42208 Mdot
.65594 .55546 Mdot
.491 .35346 Mdot
.51691 .62848 Mdot
.29613 .33084 Mdot
.55186 .61488 Mdot
.63747 .52622 Mdot
.32297 .49326 Mdot
.34867 .76807 Mdot
.84267 .39951 Mdot
.32335 .71329 Mdot
.54254 .67875 Mdot
.6901 .3891 Mdot
.47357 .60231 Mdot
.45237 .41702 Mdot
.23024 .3606 Mdot
.4928 .39779 Mdot
.4082 .25383 Mdot
.60913 .57816 Mdot
.38879 .70634 Mdot
.43652 .34957 Mdot
.67413 .29569 Mdot
.54348 .67743 Mdot
.55756 .6406 Mdot
.47224 .36409 Mdot
.53191 .64416 Mdot
.48172 .38397 Mdot
.64411 .54608 Mdot
.40082 .16852 Mdot
.46805 .41914 Mdot
.46285 .32258 Mdot
.50364 .66954 Mdot
.43408 .79143 Mdot
.6019 .55699 Mdot
.27616 .45808 Mdot
.69931 .74538 Mdot
.53177 .64766 Mdot
.53335 .3382 Mdot
.62601 .57766 Mdot
.3654 .73439 Mdot
.68376 .52785 Mdot
.49586 .38789 Mdot
.50979 .38077 Mdot
.47451 .34424 Mdot
.44977 .41433 Mdot
.21769 .38347 Mdot
.46979 .4553 Mdot
.26438 .42523 Mdot
.50729 .37421 Mdot
.31696 .59128 Mdot
.53159 .63661 Mdot
.39412 .48023 Mdot
.66753 .43728 Mdot
.5109 .37973 Mdot
.26634 .5607 Mdot
.5475 .6734 Mdot
.48543 .84328 Mdot
.54715 .63002 Mdot
.63388 .57141 Mdot
.50675 .63739 Mdot
.43095 .37441 Mdot
.30664 .53873 Mdot
.64321 .53807 Mdot
.25306 .64174 Mdot
.65309 .59054 Mdot
.45201 .40589 Mdot
.59313 .5321 Mdot
.66708 .55891 Mdot
.5719 .44977 Mdot
.30492 .54111 Mdot
.64844 .286 Mdot
.283 .54706 Mdot
.46609 .39987 Mdot
.47135 .40243 Mdot
.37458 .7079 Mdot
.51114 .64867 Mdot
.29384 .5537 Mdot
.59623 .1848 Mdot
.65816 .4125 Mdot
.31425 .52451 Mdot
.52239 .4153 Mdot
.47286 .58 Mdot
.3453 .51211 Mdot
.654 .32213 Mdot
.51322 .65132 Mdot
.31132 .56394 Mdot
.47358 .44724 Mdot
.56878 .345 Mdot
.69739 .37011 Mdot
.61828 .54172 Mdot
.51057 .52109 Mdot
.6344 .5361 Mdot
.49637 .63108 Mdot
.68276 .57313 Mdot
.53877 .63169 Mdot
.24829 .57671 Mdot
.41831 .53958 Mdot
.49321 .63817 Mdot
.50043 .65987 Mdot
.65189 .56077 Mdot
.47288 .35788 Mdot
.62091 .45954 Mdot
.51639 .42052 Mdot
.41572 .39161 Mdot
.54523 .66998 Mdot
.32132 .55837 Mdot
.29761 .52134 Mdot
.27433 .57803 Mdot
.3439 .50399 Mdot
.63481 .54117 Mdot
.41256 .64236 Mdot
.40475 .24526 Mdot
.55048 .62482 Mdot
.5463 .69454 Mdot
.46487 .34658 Mdot
.65698 .56334 Mdot
.61971 .55162 Mdot
.52255 .655 Mdot
.28893 .30734 Mdot
.43988 .33109 Mdot
.28753 .52617 Mdot
.29544 .55174 Mdot
.34106 .51122 Mdot
.35676 .54304 Mdot
.33815 .233 Mdot
.55399 .61743 Mdot
.32472 .55553 Mdot
.45963 .37528 Mdot
.50402 .39172 Mdot
.37173 .73291 Mdot
.70735 .38771 Mdot
.43334 .34797 Mdot
.43827 .33834 Mdot
.49448 .37122 Mdot
.66581 .55764 Mdot
.39288 .38923 Mdot
.39133 .73062 Mdot
.68182 .57217 Mdot
.65729 .59572 Mdot
.38131 .70879 Mdot
.38036 .48712 Mdot
.67101 .77163 Mdot
.48167 .3453 Mdot
.40257 .30763 Mdot
.65459 .56783 Mdot
.39841 .59701 Mdot
.5626 .37378 Mdot
.45934 .36001 Mdot
.64474 .44822 Mdot
.64427 .54286 Mdot
.34474 .48411 Mdot
.49135 .3923 Mdot
.39163 .71275 Mdot
.71202 .3832 Mdot
.48958 .44073 Mdot
.36722 .7371 Mdot
.33092 .52286 Mdot
.78439 .46412 Mdot
.28855 .55783 Mdot
.66833 .55661 Mdot
.46259 .31746 Mdot
.11092 .6097 Mdot
.62488 .55738 Mdot
.51595 .82209 Mdot
.42355 .53056 Mdot
.46191 .42 Mdot
.63014 .5405 Mdot
.337 .48451 Mdot
.55121 .66559 Mdot
.52988 .51626 Mdot
.30145 .5535 Mdot
.37931 .70656 Mdot
.36929 .72287 Mdot
.64545 .55339 Mdot
.30382 .5213 Mdot
.5084 .40405 Mdot
.35479 .53493 Mdot
.51147 .62523 Mdot
.43873 .37136 Mdot
.66247 .76161 Mdot
.52693 .42136 Mdot
.34298 .54276 Mdot
.65245 .52071 Mdot
.66543 .41302 Mdot
.44126 .38182 Mdot
.57794 .81086 Mdot
.48375 .41934 Mdot
.54988 .62778 Mdot
.3869 .58921 Mdot
.28347 .34462 Mdot
.48074 .35457 Mdot
.4644 .34214 Mdot
.56465 .65074 Mdot
.48336 .35295 Mdot
.45535 .42744 Mdot
.56693 .60772 Mdot
.34877 .51126 Mdot
.46362 .38868 Mdot
.61592 .54979 Mdot
.40014 .28204 Mdot
.44809 .33652 Mdot
.25054 .6096 Mdot
.66098 .28906 Mdot
.39206 .57617 Mdot
.47945 .32297 Mdot
.66682 .25944 Mdot
.47595 .40147 Mdot
.44599 .38395 Mdot
.47515 .34886 Mdot
.25315 .46649 Mdot
.65528 .55867 Mdot
.60728 .58441 Mdot
.70765 .3736 Mdot
.66574 .29526 Mdot
.68357 .38505 Mdot
.55871 .66621 Mdot
.55685 .71174 Mdot
.39565 .72186 Mdot
.33905 .53169 Mdot
.477 .33239 Mdot
.65691 .59084 Mdot
.49182 .37845 Mdot
.44226 .35256 Mdot
.65186 .54453 Mdot
.62684 .54618 Mdot
.66375 .59546 Mdot
.66819 .38352 Mdot
.32561 .53114 Mdot
.49572 .35176 Mdot
.66408 .39485 Mdot
.5002 .41372 Mdot
.47527 .58291 Mdot
.32368 .5294 Mdot
.35567 .53331 Mdot
.29089 .53051 Mdot
.50675 .36346 Mdot
.43074 .38342 Mdot
.52482 .64365 Mdot
.34934 .55794 Mdot
.55341 .62397 Mdot
.63206 .5393 Mdot
.6642 .54764 Mdot
.49623 .38788 Mdot
.49244 .46173 Mdot
.70642 .39325 Mdot
.63447 .57531 Mdot
.40235 .72359 Mdot
.70886 .37472 Mdot
.44728 .39893 Mdot
.63533 .53689 Mdot
.71339 .39902 Mdot
.32537 .28999 Mdot
.72573 .72564 Mdot
.66053 .40466 Mdot
.47171 .36504 Mdot
.33802 .44142 Mdot
.54215 .24821 Mdot
.66076 .41856 Mdot
.53728 .62302 Mdot
.49015 .41105 Mdot
.82246 .48474 Mdot
.68917 .42607 Mdot
.4609 .21663 Mdot
.656 .54725 Mdot
.48277 .26749 Mdot
.49033 .44139 Mdot
.27072 .3089 Mdot
.69296 .42584 Mdot
.32537 .54744 Mdot
.32116 .56801 Mdot
.47725 .36385 Mdot
.66219 .42832 Mdot
.52027 .61578 Mdot
.66946 .56801 Mdot
.6446 .59728 Mdot
.30703 .51686 Mdot
.42116 .66482 Mdot
.62006 .54504 Mdot
.47234 .3125 Mdot
.65418 .51194 Mdot
.42114 .308 Mdot
.28028 .27306 Mdot
.24927 .6519 Mdot
.49985 .33366 Mdot
.66513 .41503 Mdot
.56184 .66746 Mdot
.52721 .64457 Mdot
.54041 .63855 Mdot
.65905 .53934 Mdot
.47322 .56148 Mdot
.62178 .58668 Mdot
.31679 .64795 Mdot
.69688 .40326 Mdot
.62852 .28731 Mdot
.4712 .32683 Mdot
.46011 .41921 Mdot
.48125 .42984 Mdot
.47497 .343 Mdot
.47662 .40002 Mdot
.53619 .66949 Mdot
.67341 .55177 Mdot
.78182 .51034 Mdot
.33204 .51211 Mdot
.45499 .75439 Mdot
.65938 .5703 Mdot
.37469 .7402 Mdot
.67891 .40466 Mdot
.61779 .22936 Mdot
.59749 .55395 Mdot
.65429 .57777 Mdot
.45613 .43125 Mdot
.33198 .55652 Mdot
.53043 .28512 Mdot
.47414 .40922 Mdot
.63414 .57658 Mdot
.67008 .52468 Mdot
.23822 .36911 Mdot
.44646 .30409 Mdot
.72166 .36875 Mdot
.47084 .58059 Mdot
.68821 .42955 Mdot
.53062 .38407 Mdot
.39749 .60101 Mdot
.65378 .55584 Mdot
.6346 .56538 Mdot
.65919 .40897 Mdot
.39754 .45319 Mdot
.30005 .53325 Mdot
.39055 .70682 Mdot
.53494 .62591 Mdot
.4673 .41277 Mdot
.65475 .53585 Mdot
.38725 .34156 Mdot
.56134 .50393 Mdot
.54915 .64655 Mdot
.68191 .57004 Mdot
.49328 .4108 Mdot
.47974 .3594 Mdot
.70164 .39276 Mdot
.71531 .44843 Mdot
.50857 .42891 Mdot
.45536 .82708 Mdot
.42784 .60089 Mdot
.47687 .49523 Mdot
.49019 .37197 Mdot
.31724 .50667 Mdot
.38753 .71187 Mdot
.68459 .41688 Mdot
.4969 .41489 Mdot
.70626 .75033 Mdot
.34138 .56939 Mdot
.53929 .66419 Mdot
.38854 .71099 Mdot
.48066 .55247 Mdot
.48179 .42087 Mdot
.49271 .39759 Mdot
.44961 .38791 Mdot
.71876 .74557 Mdot
.60693 .57925 Mdot
.34266 .55834 Mdot
.66972 .40602 Mdot
.36023 .52045 Mdot
.61717 .59017 Mdot
.53457 .48471 Mdot
.44446 .39992 Mdot
.29117 .52111 Mdot
.32144 .54928 Mdot
.5547 .63525 Mdot
.5343 .67563 Mdot
.60453 .59737 Mdot
.45865 .42186 Mdot
.39587 .7162 Mdot
.31019 .56142 Mdot
.67515 .54383 Mdot
.70108 .39417 Mdot
.5203 .67481 Mdot
.50743 .37137 Mdot
.64833 .55559 Mdot
.51649 .36341 Mdot
.35364 .52565 Mdot
.65544 .57621 Mdot
.37339 .74186 Mdot
.70794 .39349 Mdot
.50935 .37612 Mdot
.79504 .46402 Mdot
.38792 .70858 Mdot
.43017 .39903 Mdot
.36076 .44766 Mdot
.65292 .4296 Mdot
.24979 .63783 Mdot
.61262 .57523 Mdot
.38985 .72621 Mdot
.33776 .55796 Mdot
.55668 .32267 Mdot
.6329 .55976 Mdot
.28095 .47998 Mdot
.64289 .46381 Mdot
.48989 .3502 Mdot
.31003 .52325 Mdot
.72362 .41376 Mdot
.48616 .83587 Mdot
.56302 .25417 Mdot
.47362 .38998 Mdot
.63392 .53606 Mdot
.71373 .39399 Mdot
.55601 .62868 Mdot
.25261 .60991 Mdot
.27526 .28341 Mdot
.67857 .57689 Mdot
.49507 .34713 Mdot
.31362 .56123 Mdot
.52513 .6575 Mdot
.26141 .68929 Mdot
.65126 .52229 Mdot
.60937 .56556 Mdot
.44263 .39183 Mdot
.67069 .41082 Mdot
.81353 .5071 Mdot
.60506 .57917 Mdot
.66166 .53716 Mdot
.44419 .76247 Mdot
.67601 .37265 Mdot
.46299 .37378 Mdot
.27384 .57782 Mdot
.47833 .42881 Mdot
.46666 .82094 Mdot
.39236 .72359 Mdot
.33505 .51321 Mdot
.49948 .39378 Mdot
.78533 .49426 Mdot
.62997 .55253 Mdot
.46372 .58568 Mdot
.50775 .6034 Mdot
.52577 .67148 Mdot
.65323 .53643 Mdot
.49016 .38608 Mdot
.51452 .67697 Mdot
.7052 .39058 Mdot
.44777 .41764 Mdot
.43163 .37529 Mdot
.32409 .4875 Mdot
.51498 .62602 Mdot
.40585 .28455 Mdot
.50272 .63218 Mdot
.56524 .64104 Mdot
.29825 .50072 Mdot
.47688 .36539 Mdot
.64077 .57689 Mdot
.62651 .53155 Mdot
.51374 .3907 Mdot
.40154 .59501 Mdot
.30223 .52971 Mdot
.66061 .49953 Mdot
.77203 .70118 Mdot
.41787 .33837 Mdot
.39998 .72775 Mdot
.44488 .26028 Mdot
.55927 .64859 Mdot
.49241 .35636 Mdot
.34379 .53412 Mdot
.66947 .54199 Mdot
.62061 .54247 Mdot
.4541 .43398 Mdot
.52218 .65803 Mdot
.71572 .39833 Mdot
.61425 .56032 Mdot
.5562 .50877 Mdot
.45621 .39779 Mdot
.30824 .6388 Mdot
.61462 .56592 Mdot
.37417 .80763 Mdot
.78331 .50145 Mdot
.32151 .51028 Mdot
.45004 .34841 Mdot
.365 .52085 Mdot
.66984 .40149 Mdot
.68723 .5353 Mdot
.5205 .65755 Mdot
.51775 .46368 Mdot
.65971 .22541 Mdot
.65914 .56045 Mdot
.33199 .52661 Mdot
.50077 .35747 Mdot
.53882 .44027 Mdot
.474 .42107 Mdot
.55612 .29526 Mdot
.73277 .35853 Mdot
.50324 .66265 Mdot
.55874 .63475 Mdot
.4624 .33792 Mdot
.67747 .37681 Mdot
.60949 .55082 Mdot
.65331 .5466 Mdot
.31636 .20023 Mdot
.36865 .74014 Mdot
.71334 .33659 Mdot
.50746 .36632 Mdot
.67712 .55199 Mdot
.35557 .37696 Mdot
.54331 .61625 Mdot
.50643 .41499 Mdot
.6737 .57244 Mdot
.50287 .79056 Mdot
.48092 .57346 Mdot
.46361 .3939 Mdot
.40592 .39048 Mdot
.54305 .62539 Mdot
.47212 .6037 Mdot
.62438 .5871 Mdot
.49749 .42021 Mdot
.51292 .61115 Mdot
.42825 .78155 Mdot
.63078 .20848 Mdot
.32506 .53116 Mdot
.65765 .52065 Mdot
.52833 .67148 Mdot
.39734 .36604 Mdot
.70366 .38179 Mdot
.65686 .53032 Mdot
.66411 .58081 Mdot
.44262 .36248 Mdot
.44228 .33793 Mdot
.42907 .32031 Mdot
.32183 .51943 Mdot
.5208 .6403 Mdot
.4554 .33625 Mdot
.42794 .64432 Mdot
.48198 .34269 Mdot
.51981 .64382 Mdot
.09408 .48535 Mdot
.44037 .42427 Mdot
.48458 .40881 Mdot
.61439 .3897 Mdot
.29572 .53203 Mdot
.35276 .51128 Mdot
.42057 .63106 Mdot
.50785 .36726 Mdot
.61067 .49163 Mdot
.3286 .53237 Mdot
.3032 .53084 Mdot
.63849 .48523 Mdot
.44239 .3699 Mdot
.48407 .66753 Mdot
.52482 .65343 Mdot
.52781 .67276 Mdot
.35651 .52186 Mdot
.44682 .44693 Mdot
.56743 .65145 Mdot
.20451 .40755 Mdot
.66 .57391 Mdot
.39702 .60149 Mdot
.35119 .53853 Mdot
.61622 .47673 Mdot
.51143 .64644 Mdot
.42322 .84919 Mdot
.5821 .36524 Mdot
.5195 .38344 Mdot
.4785 .35792 Mdot
.68985 .38589 Mdot
.54721 .4034 Mdot
.36744 .73077 Mdot
.53287 .64212 Mdot
.74996 .58909 Mdot
.31728 .52975 Mdot
.48095 .41305 Mdot
.57483 .22316 Mdot
.27629 .69074 Mdot
.28844 .61326 Mdot
.30015 .54812 Mdot
.31045 .53139 Mdot
.63893 .58959 Mdot
.66515 .57092 Mdot
.4589 .38217 Mdot
.53744 .63612 Mdot
.31015 .56589 Mdot
.52116 .6325 Mdot
.65503 .55502 Mdot
.65256 .57605 Mdot
.39112 .73256 Mdot
.4221 .43127 Mdot
.66065 .54727 Mdot
.44803 .77823 Mdot
.42941 .63908 Mdot
.35357 .4876 Mdot
.83513 .39362 Mdot
.25724 .6885 Mdot
.62006 .37983 Mdot
.71113 .38071 Mdot
.36117 .71001 Mdot
.50753 .64901 Mdot
.46462 .33824 Mdot
.50127 .38013 Mdot
.37292 .72738 Mdot
.51681 .66449 Mdot
.67801 .3983 Mdot
.51046 .64722 Mdot
.68764 .41405 Mdot
.60343 .58471 Mdot
.44396 .33935 Mdot
.46994 .42593 Mdot
.5482 .65849 Mdot
.63366 .5844 Mdot
.6677 .55655 Mdot
.70372 .37406 Mdot
.62222 .2361 Mdot
.64698 .55293 Mdot
.35181 .53813 Mdot
.36467 .29604 Mdot
.36972 .72356 Mdot
.49058 .39273 Mdot
.59899 .22151 Mdot
.24348 .35441 Mdot
.49067 .34875 Mdot
.3887 .71044 Mdot
.33723 .18482 Mdot
.43451 .35185 Mdot
.29503 .23522 Mdot
.38798 .73179 Mdot
.3053 .51065 Mdot
.62266 .57549 Mdot
.36597 .72509 Mdot
.3939 .3857 Mdot
.73885 .37176 Mdot
.48576 .31989 Mdot
.29696 .55031 Mdot
.30128 .50888 Mdot
.42795 .53646 Mdot
.47188 .82075 Mdot
.67436 .41791 Mdot
.6835 .3988 Mdot
.63422 .55712 Mdot
.52219 .71828 Mdot
.52208 .35912 Mdot
.6843 .39582 Mdot
.77088 .58946 Mdot
.46445 .34824 Mdot
.70589 .31792 Mdot
.6396 .44725 Mdot
.31366 .50879 Mdot
.39744 .49035 Mdot
.63142 .55527 Mdot
.33132 .5268 Mdot
.50138 .49956 Mdot
.48244 .42903 Mdot
.32124 .52908 Mdot
.51762 .64319 Mdot
.60329 .73947 Mdot
.34788 .50389 Mdot
.53485 .51446 Mdot
.52785 .65439 Mdot
.65544 .43084 Mdot
.60127 .30857 Mdot
.83117 .66462 Mdot
.5336 .64024 Mdot
.62878 .57728 Mdot
.6635 .54922 Mdot
.64466 .54911 Mdot
.29989 .55295 Mdot
.62293 .55082 Mdot
.33168 .51606 Mdot
.58758 .57785 Mdot
.65269 .24965 Mdot
.69713 .39516 Mdot
.57607 .66787 Mdot
.31669 .54462 Mdot
.34722 .65827 Mdot
.80107 .34959 Mdot
.46737 .36742 Mdot
.50307 .62539 Mdot
.66413 .41612 Mdot
.4196 .69231 Mdot
.68449 .38781 Mdot
.62544 .57806 Mdot
.39573 .60298 Mdot
.48051 .38411 Mdot
.24867 .51766 Mdot
.70495 .40929 Mdot
.3003 .55105 Mdot
.43718 .40853 Mdot
.60157 .6009 Mdot
.68753 .38052 Mdot
.71103 .38269 Mdot
.47914 .39938 Mdot
.32423 .50122 Mdot
.64688 .57817 Mdot
.50526 .6525 Mdot
.70045 .43278 Mdot
.4138 .42914 Mdot
.4756 .35511 Mdot
.47557 .4365 Mdot
.45061 .59143 Mdot
.81891 .50027 Mdot
.53201 .64947 Mdot
.5391 .24233 Mdot
.66345 .55707 Mdot
.56241 .25948 Mdot
.34768 .68168 Mdot
.58612 .6359 Mdot
.39239 .72497 Mdot
.39319 .72212 Mdot
.4687 .39538 Mdot
.81384 .53477 Mdot
.28623 .59924 Mdot
.54911 .60871 Mdot
.37353 .71629 Mdot
.66781 .55736 Mdot
.34467 .56396 Mdot
.4157 .48227 Mdot
.42311 .37591 Mdot
.53069 .67608 Mdot
.65205 .55117 Mdot
.7577 .65538 Mdot
.69499 .4032 Mdot
.39958 .63997 Mdot
.44722 .40339 Mdot
.48101 .39207 Mdot
.53883 .65591 Mdot
.52511 .64437 Mdot
.28251 .62632 Mdot
.43052 .55098 Mdot
.62323 .76607 Mdot
.48823 .67433 Mdot
.77353 .63843 Mdot
.27164 .55408 Mdot
.34469 .53897 Mdot
.38708 .73766 Mdot
.56533 .65437 Mdot
.49071 .40217 Mdot
.3027 .51356 Mdot
.29199 .61181 Mdot
.30796 .49069 Mdot
.6949 .31412 Mdot
.62398 .48147 Mdot
.44716 .40872 Mdot
.3381 .55406 Mdot
.32865 .52704 Mdot
.36258 .53207 Mdot
.3814 .70941 Mdot
.49123 .3689 Mdot
.47136 .35896 Mdot
.43263 .3571 Mdot
.52756 .44831 Mdot
.45938 .39906 Mdot
.35286 .68384 Mdot
.42747 .67937 Mdot
.72759 .52946 Mdot
.50001 .3518 Mdot
.52032 .66411 Mdot
.47905 .3328 Mdot
.68271 .37504 Mdot
.49984 .34952 Mdot
.72337 .33071 Mdot
.54213 .64369 Mdot
.41075 .46023 Mdot
.68123 .51554 Mdot
.44531 .4029 Mdot
.71046 .40987 Mdot
.81821 .50547 Mdot
.55951 .21852 Mdot
.44498 .76556 Mdot
.35234 .53753 Mdot
.61024 .59801 Mdot
.53007 .61477 Mdot
.64085 .57556 Mdot
.51404 .40248 Mdot
.3991 .72649 Mdot
.22786 .68042 Mdot
.59958 .47536 Mdot
.49336 .40066 Mdot
.45224 .45378 Mdot
.32846 .50603 Mdot
.62777 .55237 Mdot
.27764 .51149 Mdot
.44693 .38596 Mdot
.66813 .39925 Mdot
.6664 .39551 Mdot
.45672 .50406 Mdot
.735 .65422 Mdot
.55162 .30866 Mdot
.53724 .65464 Mdot
.62269 .53963 Mdot
.69351 .42524 Mdot
.26217 .58502 Mdot
.53101 .613 Mdot
.55914 .64864 Mdot
.51593 .62623 Mdot
.45359 .41226 Mdot
.38208 .73774 Mdot
.75428 .62191 Mdot
.37411 .7096 Mdot
.44079 .40157 Mdot
.65849 .58507 Mdot
.36549 .72522 Mdot
.68754 .3845 Mdot
.56391 .64539 Mdot
.66393 .56259 Mdot
.46807 .40211 Mdot
.32593 .5362 Mdot
.54554 .23229 Mdot
.77062 .37647 Mdot
.62788 .50538 Mdot
.62487 .50626 Mdot
.28836 .54165 Mdot
.5719 .82597 Mdot
.58426 .61589 Mdot
.28363 .31147 Mdot
.73149 .3909 Mdot
.51438 .39005 Mdot
.42804 .17752 Mdot
.62019 .58475 Mdot
.63948 .53869 Mdot
.45954 .3923 Mdot
.66427 .52831 Mdot
.4788 .41629 Mdot
.63111 .59113 Mdot
.53708 .80945 Mdot
.42222 .39699 Mdot
.63747 .54011 Mdot
.52594 .36911 Mdot
.43816 .38705 Mdot
.32571 .50503 Mdot
.66138 .53302 Mdot
.51988 .37867 Mdot
.21424 .67523 Mdot
.55484 .64327 Mdot
.37862 .70991 Mdot
.54881 .70233 Mdot
.50925 .63512 Mdot
.31604 .51737 Mdot
.4345 .34929 Mdot
.7043 .39355 Mdot
.32699 .5441 Mdot
.61426 .60427 Mdot
.69877 .41562 Mdot
.41379 .64405 Mdot
.35316 .5329 Mdot
.37212 .73092 Mdot
.70751 .39784 Mdot
.48241 .31834 Mdot
.64834 .53971 Mdot
.80156 .41408 Mdot
.374 .71032 Mdot
.48584 .37966 Mdot
.63564 .52071 Mdot
.51038 .64606 Mdot
.46577 .37922 Mdot
.63604 .53361 Mdot
.38475 .70906 Mdot
.4308 .39484 Mdot
.431 .39916 Mdot
.43359 .48317 Mdot
.36145 .60184 Mdot
.69897 .39086 Mdot
.30201 .49926 Mdot
.45751 .37771 Mdot
.67836 .37569 Mdot
.62723 .66206 Mdot
.49054 .33194 Mdot
.36197 .51437 Mdot
.53269 .45612 Mdot
.66509 .57332 Mdot
.55531 .62558 Mdot
.63654 .5261 Mdot
.71363 .38541 Mdot
.62984 .18136 Mdot
.37652 .73924 Mdot
.43313 .44552 Mdot
.48257 .43003 Mdot
.68701 .5546 Mdot
.32477 .52525 Mdot
.59792 .76996 Mdot
.50897 .37226 Mdot
.47811 .45111 Mdot
.4854 .39737 Mdot
.77965 .50254 Mdot
.30123 .53281 Mdot
.48861 .39556 Mdot
.45955 .46037 Mdot
.49276 .32158 Mdot
.71302 .40811 Mdot
.62254 .29591 Mdot
.47974 .33461 Mdot
.16871 .69491 Mdot
.39718 .71323 Mdot
.65007 .54479 Mdot
.51957 .54973 Mdot
.70872 .60793 Mdot
.28733 .26269 Mdot
.327 .51715 Mdot
.48389 .28243 Mdot
.64436 .57726 Mdot
.53452 .2125 Mdot
.53261 .84069 Mdot
.43751 .39048 Mdot
.49538 .4075 Mdot
.62545 .57802 Mdot
.67548 .54759 Mdot
.39824 .72243 Mdot
.51176 .36239 Mdot
.46827 .45042 Mdot
.67357 .53375 Mdot
.46313 .40656 Mdot
.21746 .45074 Mdot
.49861 .64398 Mdot
.35524 .51616 Mdot
.5558 .62843 Mdot
.55563 .65429 Mdot
.3583 .25415 Mdot
.42773 .60032 Mdot
.52146 .64395 Mdot
.56761 .6149 Mdot
.73095 .33154 Mdot
.52393 .46348 Mdot
.70392 .41891 Mdot
.69902 .70275 Mdot
.6388 .55364 Mdot
.49206 .36753 Mdot
.30924 .55818 Mdot
.29636 .28036 Mdot
.56921 .74632 Mdot
.38662 .61724 Mdot
.46696 .3643 Mdot
.63351 .55005 Mdot
.3827 .70755 Mdot
.42181 .39048 Mdot
.55277 .25676 Mdot
.47735 .39015 Mdot
.67034 .5652 Mdot
.377 .24768 Mdot
.26056 .50958 Mdot
.48556 .6658 Mdot
.37291 .50632 Mdot
.46567 .33036 Mdot
.34882 .52447 Mdot
.52441 .66696 Mdot
.66992 .38206 Mdot
.69054 .39018 Mdot
.44886 .4153 Mdot
.41802 .54052 Mdot
.71025 .43657 Mdot
.43933 .38676 Mdot
.44151 .36588 Mdot
.39007 .72801 Mdot
.4407 .36721 Mdot
.4906 .42409 Mdot
.4668 .33382 Mdot
.50735 .34752 Mdot
.56551 .64279 Mdot
.35258 .45772 Mdot
.49289 .3401 Mdot
.41413 .34234 Mdot
.51294 .67242 Mdot
.41326 .32272 Mdot
.54594 .63033 Mdot
.67554 .74513 Mdot
.53611 .62847 Mdot
.69226 .39102 Mdot
.61252 .54163 Mdot
.46204 .2795 Mdot
.30802 .56524 Mdot
.53757 .67549 Mdot
.68547 .40976 Mdot
.53657 .63938 Mdot
.60714 .5621 Mdot
.81993 .39317 Mdot
.28727 .51443 Mdot
.47908 .58142 Mdot
.60371 .39384 Mdot
.30593 .6378 Mdot
.65896 .57863 Mdot
.30807 .51664 Mdot
.24913 .52942 Mdot
.45974 .33739 Mdot
.70262 .38802 Mdot
.47046 .39494 Mdot
.56409 .63893 Mdot
.63656 .55031 Mdot
.5925 .53534 Mdot
.69828 .38949 Mdot
.70608 .24319 Mdot
.6534 .59174 Mdot
.41269 .38265 Mdot
.5118 .67285 Mdot
.82598 .38252 Mdot
.53964 .62743 Mdot
.64685 .24467 Mdot
.3583 .56705 Mdot
.39265 .2378 Mdot
.30995 .53761 Mdot
.26113 .60298 Mdot
.63034 .82038 Mdot
.53704 .83131 Mdot
.33371 .54052 Mdot
.66626 .50063 Mdot
.45404 .40499 Mdot
.47656 .34095 Mdot
.45319 .31265 Mdot
.35882 .48733 Mdot
.45316 .38423 Mdot
.36842 .73043 Mdot
.43326 .60208 Mdot
.79175 .54291 Mdot
.60105 .58935 Mdot
.4789 .4176 Mdot
.54444 .66983 Mdot
.56116 .62133 Mdot
.36707 .71871 Mdot
.50728 .63025 Mdot
.44046 .37948 Mdot
.31404 .54334 Mdot
.61074 .46497 Mdot
.67328 .39339 Mdot
.37258 .77743 Mdot
.71701 .41709 Mdot
.59198 .57569 Mdot
.43217 .32466 Mdot
.65309 .57624 Mdot
.52437 .15146 Mdot
.46791 .33995 Mdot
.33128 .53161 Mdot
.4396 .40857 Mdot
.46539 .33286 Mdot
.49012 .34206 Mdot
.63104 .53515 Mdot
.51809 .55521 Mdot
.46573 .40715 Mdot
.51747 .65445 Mdot
.6573 .48678 Mdot
.43171 .34901 Mdot
.72619 .61791 Mdot
.68038 .31408 Mdot
.32088 .64442 Mdot
.36306 .49291 Mdot
.62767 .56976 Mdot
.3144 .5309 Mdot
.36938 .48907 Mdot
.31624 .51719 Mdot
.74638 .6042 Mdot
.49837 .26804 Mdot
.26579 .25941 Mdot
.34922 .3598 Mdot
.30108 .28542 Mdot
.28758 .52917 Mdot
.64456 .67207 Mdot
.34297 .53711 Mdot
.3224 .51636 Mdot
.14862 .3587 Mdot
.33608 .54873 Mdot
.49661 .38595 Mdot
.4276 .41621 Mdot
.31553 .7196 Mdot
.72343 .32086 Mdot
.49924 .34994 Mdot
.4557 .38277 Mdot
.66677 .41164 Mdot
.48053 .46472 Mdot
.37206 .70666 Mdot
.40589 .62168 Mdot
.39608 .69517 Mdot
.47827 .39916 Mdot
.45554 .39016 Mdot
.48695 .43754 Mdot
.63078 .82467 Mdot
.28966 .27905 Mdot
.29703 .51686 Mdot
.38837 .38918 Mdot
.43083 .80064 Mdot
.46014 .4295 Mdot
.45118 .42467 Mdot
.4315 .37034 Mdot
.64201 .57722 Mdot
.33919 .56733 Mdot
.49481 .44561 Mdot
.30804 .66898 Mdot
.44758 .40059 Mdot
.59143 .61065 Mdot
.64424 .42547 Mdot
.49114 .3856 Mdot
.3619 .52289 Mdot
.47022 .34932 Mdot
.34778 .54609 Mdot
.35514 .51839 Mdot
.42831 .43928 Mdot
.74938 .63126 Mdot
.36207 .55049 Mdot
.43514 .39737 Mdot
.63393 .58202 Mdot
.48937 .83411 Mdot
.48761 .3798 Mdot
.67391 .41549 Mdot
.49156 .35496 Mdot
.71434 .40293 Mdot
.43444 .37407 Mdot
.37803 .70722 Mdot
.27079 .35859 Mdot
.6349 .56366 Mdot
.70892 .42819 Mdot
.6753 .54066 Mdot
.48521 .48536 Mdot
.32852 .49761 Mdot
.37607 .70325 Mdot
.24821 .3079 Mdot
.38888 .72933 Mdot
.52359 .23517 Mdot
.56163 .73092 Mdot
.55148 .65766 Mdot
.35516 .54453 Mdot
.47505 .2525 Mdot
.72046 .641 Mdot
.66405 .59385 Mdot
.6588 .59526 Mdot
.55996 .16937 Mdot
.39552 .16906 Mdot
.46934 .40942 Mdot
.82986 .46143 Mdot
.27215 .40857 Mdot
.50785 .33367 Mdot
.52862 .34996 Mdot
.66871 .57624 Mdot
.46441 .32977 Mdot
.52547 .51228 Mdot
.65281 .56061 Mdot
.68542 .40561 Mdot
.33757 .51437 Mdot
.70898 .38426 Mdot
.64058 .74439 Mdot
.43183 .65775 Mdot
.66051 .55504 Mdot
.4988 .33873 Mdot
.46612 .41605 Mdot
.34591 .5524 Mdot
.23591 .53514 Mdot
.34946 .51096 Mdot
.68294 .42245 Mdot
.64438 .56439 Mdot
.27007 .30559 Mdot
.49766 .3593 Mdot
.31793 .55033 Mdot
.69375 .55706 Mdot
.48063 .35874 Mdot
.54365 .66373 Mdot
.46668 .36351 Mdot
.33148 .54793 Mdot
.44007 .36763 Mdot
.31342 .54141 Mdot
.62918 .58687 Mdot
.48457 .42174 Mdot
.45726 .38811 Mdot
.50279 .22759 Mdot
.67722 .39835 Mdot
.32099 .49882 Mdot
.51892 .51627 Mdot
.47555 .42904 Mdot
.55381 .25966 Mdot
.43977 .34359 Mdot
.49017 .29586 Mdot
.52902 .39789 Mdot
.37054 .73265 Mdot
.50818 .41548 Mdot
.48672 .38093 Mdot
.29151 .46973 Mdot
.34804 .41308 Mdot
.40311 .48497 Mdot
.54168 .67658 Mdot
.36128 .52132 Mdot
.6618 .54486 Mdot
.67063 .54668 Mdot
.61829 .55871 Mdot
.70836 .3021 Mdot
.41265 .42974 Mdot
.48009 .38226 Mdot
.50287 .66313 Mdot
.68616 .39791 Mdot
.30551 .55232 Mdot
.69226 .39616 Mdot
.40612 .61733 Mdot
.69188 .42076 Mdot
.3692 .73399 Mdot
.78405 .50099 Mdot
.20634 .42656 Mdot
.6832 .41844 Mdot
.35096 .51196 Mdot
.61264 .48686 Mdot
.51595 .38594 Mdot
.47678 .78925 Mdot
.66779 .40024 Mdot
.59275 .18228 Mdot
.42772 .40083 Mdot
.52237 .52072 Mdot
.55008 .63443 Mdot
.70993 .38828 Mdot
.51624 .6241 Mdot
.47055 .34612 Mdot
.24793 .63423 Mdot
.3356 .5286 Mdot
.49575 .63892 Mdot
.5203 .39578 Mdot
.70917 .38523 Mdot
.66008 .55052 Mdot
.57881 .39501 Mdot
.5204 .67017 Mdot
.54617 .22409 Mdot
.56273 .25422 Mdot
.64646 .56419 Mdot
.17975 .44181 Mdot
.53141 .62099 Mdot
.50223 .33713 Mdot
.51384 .28556 Mdot
.46669 .35531 Mdot
.66734 .54882 Mdot
.63195 .54108 Mdot
.34454 .7379 Mdot
.44827 .41295 Mdot
.42498 .39158 Mdot
.30445 .56988 Mdot
.65898 .56282 Mdot
.30935 .52012 Mdot
.34088 .56032 Mdot
.62778 .57991 Mdot
.31924 .5108 Mdot
.70623 .4078 Mdot
.43301 .59096 Mdot
.53164 .62174 Mdot
.52982 .6656 Mdot
.66144 .54868 Mdot
.60504 .56388 Mdot
.65542 .57462 Mdot
.4619 .36667 Mdot
.2983 .53108 Mdot
.45198 .35125 Mdot
.4817 .3345 Mdot
.34098 .57954 Mdot
.29199 .54591 Mdot
.45871 .34904 Mdot
.65437 .46829 Mdot
.70858 .36816 Mdot
.63598 .54109 Mdot
.52037 .63458 Mdot
.49267 .22131 Mdot
.49733 .64216 Mdot
.45089 .42167 Mdot
.49916 .79232 Mdot
.29924 .55124 Mdot
.68621 .38675 Mdot
.65004 .4139 Mdot
.69548 .38669 Mdot
.49564 .63891 Mdot
.35071 .55393 Mdot
.41575 .6442 Mdot
.4589 .4229 Mdot
.44974 .59113 Mdot
.5167 .24313 Mdot
.3387 .68036 Mdot
.51914 .64237 Mdot
.46603 .36971 Mdot
.38664 .73184 Mdot
.23152 .37888 Mdot
.4736 .38645 Mdot
.50984 .41089 Mdot
.74717 .46636 Mdot
.41507 .34129 Mdot
.33593 .48593 Mdot
.43181 .51809 Mdot
.49617 .41458 Mdot
.41161 .4843 Mdot
.25282 .2384 Mdot
.42865 .40149 Mdot
.45043 .3936 Mdot
.49865 .37321 Mdot
.4625 .34024 Mdot
.36051 .505 Mdot
.74188 .4409 Mdot
.54275 .6724 Mdot
.43731 .58803 Mdot
.52018 .62493 Mdot
.64553 .53637 Mdot
.53834 .49994 Mdot
.35893 .53653 Mdot
.69476 .38597 Mdot
.83518 .4255 Mdot
.41205 .59522 Mdot
.64051 .58915 Mdot
.3225 .24766 Mdot
.67149 .39341 Mdot
.51486 .38671 Mdot
.70653 .37198 Mdot
.67846 .55832 Mdot
.52178 .65554 Mdot
.4508 .42915 Mdot
.2999 .5571 Mdot
.35096 .50555 Mdot
.4618 .37194 Mdot
.44378 .82007 Mdot
.50894 .63877 Mdot
.65201 .61976 Mdot
.4509 .41103 Mdot
.50937 .41105 Mdot
.34363 .51122 Mdot
.62944 .55048 Mdot
.55197 .72529 Mdot
.67799 .40644 Mdot
.52446 .38344 Mdot
.47212 .34679 Mdot
.41549 .6092 Mdot
.56225 .65998 Mdot
.38195 .71618 Mdot
.44915 .41155 Mdot
.4266 .6046 Mdot
.44343 .40915 Mdot
.52473 .43958 Mdot
.64472 .58169 Mdot
.41642 .40629 Mdot
.50372 .39805 Mdot
.38632 .33312 Mdot
.53475 .61916 Mdot
.32605 .52891 Mdot
.33705 .57677 Mdot
.39211 .71279 Mdot
.54962 .65362 Mdot
.46105 .35104 Mdot
.5612 .63137 Mdot
.48495 .34094 Mdot
.4656 .40412 Mdot
.51875 .64272 Mdot
.31019 .51841 Mdot
.59829 .76368 Mdot
.33257 .46256 Mdot
.44215 .34947 Mdot
.48637 .35131 Mdot
.71144 .31061 Mdot
.19619 .3871 Mdot
.5077 .38955 Mdot
.29534 .53988 Mdot
.47949 .3606 Mdot
.53228 .66879 Mdot
.68633 .42241 Mdot
.33075 .53578 Mdot
.60315 .57369 Mdot
.62304 .58462 Mdot
.68536 .51931 Mdot
.37294 .73742 Mdot
.51234 .37439 Mdot
.29243 .50538 Mdot
.29062 .54773 Mdot
.41703 .71824 Mdot
.64962 .54372 Mdot
.70096 .41878 Mdot
.42835 .37531 Mdot
.57769 .38379 Mdot
.55305 .66261 Mdot
.17387 .70012 Mdot
.41778 .65083 Mdot
.71908 .40239 Mdot
.39399 .57169 Mdot
.38082 .73305 Mdot
.49268 .40448 Mdot
.68688 .37345 Mdot
.61165 .5709 Mdot
.47409 .34197 Mdot
.40005 .3747 Mdot
.71136 .65162 Mdot
.6059 .59089 Mdot
.55861 .62775 Mdot
.6083 .57588 Mdot
.71812 .39063 Mdot
.36825 .7325 Mdot
.32976 .50179 Mdot
.48574 .38584 Mdot
.39225 .34603 Mdot
.64356 .5464 Mdot
.38487 .70522 Mdot
.44517 .40786 Mdot
.35922 .51323 Mdot
.62661 .54662 Mdot
.48056 .40279 Mdot
.27019 .3247 Mdot
.33445 .58439 Mdot
.64126 .55838 Mdot
.47691 .43353 Mdot
.50909 .47495 Mdot
.61311 .58932 Mdot
.66592 .5808 Mdot
.45325 .38468 Mdot
.70807 .4001 Mdot
.48586 .41786 Mdot
.54016 .63124 Mdot
.5184 .55504 Mdot
.54382 .66091 Mdot
.53809 .24573 Mdot
.43435 .42938 Mdot
.30235 .6218 Mdot
.32819 .55892 Mdot
.65572 .39301 Mdot
.29626 .46286 Mdot
.50721 .41027 Mdot
.64941 .77078 Mdot
.61041 .479 Mdot
.42886 .71115 Mdot
.75681 .70229 Mdot
.68018 .41404 Mdot
.54079 .63828 Mdot
.45011 .39243 Mdot
.56581 .67052 Mdot
.69317 .4134 Mdot
.53369 .24386 Mdot
.48195 .4309 Mdot
.30231 .53303 Mdot
.45052 .4043 Mdot
.35193 .53874 Mdot
.48534 .35646 Mdot
.39815 .40789 Mdot
.72325 .3708 Mdot
.64257 .24165 Mdot
.51557 .37872 Mdot
.83837 .41993 Mdot
.56986 .43892 Mdot
.66998 .40516 Mdot
.43916 .35753 Mdot
.37658 .72398 Mdot
.51139 .65007 Mdot
.81174 .46209 Mdot
.64843 .57701 Mdot
.52544 .63935 Mdot
.33758 .51112 Mdot
.63716 .52269 Mdot
.39285 .71097 Mdot
.48988 .27072 Mdot
.70718 .38112 Mdot
.55367 .64649 Mdot
.48849 .38258 Mdot
.44821 .42123 Mdot
.78405 .49278 Mdot
.16748 .50401 Mdot
.31528 .56895 Mdot
.67124 .22689 Mdot
.31126 .49488 Mdot
.68096 .39766 Mdot
.64828 .58068 Mdot
.49928 .39263 Mdot
.46671 .38653 Mdot
.65948 .53795 Mdot
.29612 .52899 Mdot
.65194 .51265 Mdot
.34853 .24853 Mdot
.51889 .59954 Mdot
.63898 .26962 Mdot
.33521 .53628 Mdot
.63793 .26572 Mdot
.71785 .4021 Mdot
.74656 .66086 Mdot
.62523 .34978 Mdot
.55714 .64571 Mdot
.63916 .27361 Mdot
.30952 .55419 Mdot
.47226 .41037 Mdot
.37176 .72902 Mdot
.39369 .72865 Mdot
.3476 .51936 Mdot
.62568 .5754 Mdot
.70448 .38247 Mdot
.4537 .39775 Mdot
.35914 .65043 Mdot
.27929 .70857 Mdot
.62444 .53777 Mdot
.4777 .45769 Mdot
.51123 .6332 Mdot
.48076 .35513 Mdot
.66453 .40493 Mdot
.52885 .6464 Mdot
.37071 .74201 Mdot
.43267 .58242 Mdot
.42823 .37425 Mdot
.45998 .49924 Mdot
.55123 .64538 Mdot
.18189 .40643 Mdot
.45968 .3867 Mdot
.53157 .62083 Mdot
.46576 .29601 Mdot
.2623 .64584 Mdot
.63314 .45288 Mdot
.55723 .82708 Mdot
.63238 .60138 Mdot
.61986 .58199 Mdot
.19471 .61178 Mdot
.73188 .38808 Mdot
.53448 .67417 Mdot
.36661 .72866 Mdot
.62421 .31594 Mdot
.52607 .61931 Mdot
.44124 .4214 Mdot
.43549 .34926 Mdot
.34855 .25709 Mdot
.56178 .45882 Mdot
.39475 .70639 Mdot
.53168 .31615 Mdot
.44787 .36793 Mdot
.47017 .31777 Mdot
.46893 .37411 Mdot
.30071 .50985 Mdot
.53055 .61691 Mdot
.86878 .4663 Mdot
.54929 .61619 Mdot
.37072 .64656 Mdot
.63851 .55336 Mdot
.63272 .5309 Mdot
.49057 .38722 Mdot
.29885 .60583 Mdot
.82347 .51082 Mdot
.49702 .35461 Mdot
.65 .42363 Mdot
.56186 .25109 Mdot
.43681 .3403 Mdot
.33084 .57325 Mdot
.48579 .45077 Mdot
.33949 .49201 Mdot
.52619 .64888 Mdot
.68174 .41476 Mdot
.70298 .3636 Mdot
.54551 .63578 Mdot
.47899 .37974 Mdot
.64621 .39903 Mdot
.48319 .39325 Mdot
.46516 .4136 Mdot
.39998 .62843 Mdot
.6687 .42433 Mdot
.65756 .57385 Mdot
.69289 .38949 Mdot
.32085 .51809 Mdot
.11317 .41364 Mdot
.69802 .40001 Mdot
.53232 .46027 Mdot
.55395 .5007 Mdot
.63626 .27105 Mdot
.34905 .50516 Mdot
.67536 .41966 Mdot
.54936 .62012 Mdot
.42463 .72134 Mdot
.18728 .42352 Mdot
.50023 .6313 Mdot
.46379 .38936 Mdot
.35641 .5401 Mdot
.28904 .53706 Mdot
.52513 .61261 Mdot
.31367 .50801 Mdot
.4285 .33677 Mdot
.43476 .40296 Mdot
.53546 .67377 Mdot
.31291 .73036 Mdot
.53286 .61619 Mdot
.57455 .40525 Mdot
.43037 .38109 Mdot
.33081 .53368 Mdot
.52848 .33085 Mdot
.27427 .55218 Mdot
.39396 .73086 Mdot
.49596 .34466 Mdot
.69803 .38399 Mdot
.47418 .56109 Mdot
.63975 .55838 Mdot
.50576 .79238 Mdot
.35458 .53527 Mdot
.48929 .64888 Mdot
.32801 .50464 Mdot
.29702 .56038 Mdot
.512 .62209 Mdot
.3282 .52166 Mdot
.45114 .39516 Mdot
.47186 .6115 Mdot
.34804 .53995 Mdot
.54138 .65275 Mdot
.6968 .38098 Mdot
.31506 .51294 Mdot
.66737 .51756 Mdot
.4722 .41442 Mdot
.66182 .57823 Mdot
.67149 .4301 Mdot
.35845 .53868 Mdot
.67915 .42087 Mdot
.64592 .54448 Mdot
.70074 .37756 Mdot
.58411 .57819 Mdot
.54611 .68572 Mdot
.38079 .62358 Mdot
.2865 .48554 Mdot
.30919 .55935 Mdot
.65376 .60054 Mdot
.5026 .39418 Mdot
.45673 .4167 Mdot
.71208 .37927 Mdot
.28781 .5402 Mdot
.48476 .83101 Mdot
.50151 .29805 Mdot
.35032 .7362 Mdot
.5608 .66607 Mdot
.5983 .20276 Mdot
.42075 .66454 Mdot
.43228 .73178 Mdot
.53005 .3653 Mdot
.37947 .7331 Mdot
.48615 .39744 Mdot
.56024 .21799 Mdot
.68588 .42364 Mdot
.61056 .71226 Mdot
.52104 .35638 Mdot
.65267 .56895 Mdot
.49252 .35953 Mdot
.82685 .45923 Mdot
.52719 .42208 Mdot
.66953 .41463 Mdot
.52199 .6799 Mdot
.3083 .56535 Mdot
.67225 .39423 Mdot
.62746 .58782 Mdot
.65071 .30576 Mdot
.46645 .43588 Mdot
.44486 .37381 Mdot
.66837 .58916 Mdot
.30389 .52521 Mdot
.64671 .53765 Mdot
.53098 .62177 Mdot
.69496 .39918 Mdot
.4583 .34038 Mdot
.42676 .34763 Mdot
.68493 .56029 Mdot
.55814 .62015 Mdot
.6149 .54644 Mdot
.56177 .63764 Mdot
.37767 .73323 Mdot
.51319 .37261 Mdot
.67966 .57279 Mdot
.51067 .3281 Mdot
.3576 .38444 Mdot
.39812 .61775 Mdot
.30795 .44655 Mdot
.65898 .5733 Mdot
.67563 .2981 Mdot
.54506 .64289 Mdot
.5541 .63044 Mdot
.40218 .24593 Mdot
.81794 .52179 Mdot
.61136 .49077 Mdot
.81385 .3902 Mdot
.53088 .62213 Mdot
.54625 .65387 Mdot
.61312 .56932 Mdot
.33264 .51797 Mdot
.37219 .54319 Mdot
.66974 .52657 Mdot
.59856 .2218 Mdot
.30609 .55246 Mdot
.62619 .7907 Mdot
.63567 .59585 Mdot
.52904 .39413 Mdot
.39813 .7052 Mdot
.66749 .40736 Mdot
.56833 .22395 Mdot
.81679 .40832 Mdot
.49527 .39483 Mdot
.3366 .21277 Mdot
.63036 .56986 Mdot
.47498 .66619 Mdot
.71082 .70094 Mdot
.49285 .4267 Mdot
.49401 .36378 Mdot
.47819 .3749 Mdot
.65904 .41283 Mdot
.33208 .45543 Mdot
.49441 .39745 Mdot
.65457 .2536 Mdot
.42296 .40817 Mdot
.80115 .42587 Mdot
.69307 .38984 Mdot
.53901 .2777 Mdot
.63009 .60322 Mdot
.32279 .66757 Mdot
.4557 .31353 Mdot
.53792 .62214 Mdot
.67802 .70195 Mdot
.51719 .64882 Mdot
.78411 .6039 Mdot
.62376 .34753 Mdot
.29864 .5113 Mdot
.46595 .36487 Mdot
.66321 .59081 Mdot
.35382 .54255 Mdot
.56018 .72773 Mdot
.14547 .35832 Mdot
.56667 .63933 Mdot
.44149 .13589 Mdot
.5565 .63268 Mdot
.3962 .72535 Mdot
.34634 .51475 Mdot
.39712 .52894 Mdot
.45097 .58816 Mdot
.31092 .51907 Mdot
.71749 .56185 Mdot
.3338 .57566 Mdot
.65941 .28208 Mdot
.28296 .55339 Mdot
.54016 .64804 Mdot
.52198 .68294 Mdot
.41794 .32524 Mdot
.50677 .38889 Mdot
.43675 .60387 Mdot
.48226 .30499 Mdot
.50787 .36667 Mdot
.65281 .56075 Mdot
.24048 .57534 Mdot
.48054 .64495 Mdot
.34471 .53279 Mdot
.55611 .66258 Mdot
.49449 .36276 Mdot
.44162 .35062 Mdot
.50114 .32869 Mdot
.5379 .21991 Mdot
.62899 .78688 Mdot
.4674 .4063 Mdot
.44389 .44451 Mdot
.6371 .58754 Mdot
.79241 .47018 Mdot
.74161 .30161 Mdot
.62902 .32507 Mdot
.44875 .4167 Mdot
.68041 .3937 Mdot
.67335 .42274 Mdot
.41712 .36151 Mdot
.33182 .63391 Mdot
.645 .50546 Mdot
.48858 .38222 Mdot
.64057 .36002 Mdot
.68463 .53389 Mdot
.37755 .70665 Mdot
.64432 .54651 Mdot
.36184 .53231 Mdot
.39206 .72742 Mdot
.63185 .53594 Mdot
.34185 .58733 Mdot
.39167 .71356 Mdot
.2749 .65585 Mdot
.68246 .4225 Mdot
.46628 .37899 Mdot
.26978 .52356 Mdot
.6603 .53979 Mdot
.55358 .64272 Mdot
.31972 .54044 Mdot
.56388 .66551 Mdot
.79416 .47219 Mdot
.57783 .231 Mdot
.37673 .739 Mdot
.53824 .62405 Mdot
.43974 .5377 Mdot
.68362 .39166 Mdot
.50787 .62674 Mdot
.28804 .6078 Mdot
.43656 .34314 Mdot
.81015 .58465 Mdot
.44759 .37592 Mdot
.40973 .8071 Mdot
.55229 .63017 Mdot
.3885 .73821 Mdot
.48381 .38697 Mdot
.65051 .59247 Mdot
.42349 .31291 Mdot
.48126 .39406 Mdot
.60631 .5779 Mdot
.47036 .40905 Mdot
.66336 .39654 Mdot
.35479 .49504 Mdot
.6113 .4758 Mdot
.54325 .19721 Mdot
.69163 .37724 Mdot
.36075 .74126 Mdot
.5105 .37698 Mdot
.69997 .47926 Mdot
.3085 .52557 Mdot
.50324 .41784 Mdot
.39053 .21937 Mdot
.34246 .52056 Mdot
.31278 .53129 Mdot
.44454 .36071 Mdot
.49884 .63389 Mdot
.66693 .55694 Mdot
.68628 .38979 Mdot
.52769 .72208 Mdot
.48149 .40413 Mdot
.4643 .37261 Mdot
.67223 .39272 Mdot
.54574 .65697 Mdot
.45668 .34249 Mdot
.52746 .75659 Mdot
.41631 .68706 Mdot
.55499 .65611 Mdot
.43687 .34201 Mdot
.82306 .59767 Mdot
.3767 .52672 Mdot
.31307 .22346 Mdot
.73007 .39809 Mdot
.6304 .57828 Mdot
.43489 .44848 Mdot
.14267 .65806 Mdot
.66986 .40986 Mdot
.33925 .67339 Mdot
.46193 .40903 Mdot
.5054 .37233 Mdot
.32527 .49965 Mdot
.45596 .35292 Mdot
.33322 .5487 Mdot
.54772 .19357 Mdot
.83573 .37348 Mdot
.32544 .50593 Mdot
.34167 .54499 Mdot
.39576 .49717 Mdot
.52871 .22573 Mdot
.33627 .51283 Mdot
.46959 .43645 Mdot
.72582 .54303 Mdot
.40818 .41119 Mdot
.70939 .42053 Mdot
.65868 .38419 Mdot
.29553 .57063 Mdot
.18924 .50968 Mdot
.42875 .30231 Mdot
.42045 .47281 Mdot
.69957 .44105 Mdot
.53158 .63014 Mdot
.43915 .34724 Mdot
.37034 .73603 Mdot
.62039 .55112 Mdot
.51023 .44331 Mdot
.46806 .38062 Mdot
.34903 .54336 Mdot
.65727 .40927 Mdot
.5113 .62583 Mdot
.45556 .38413 Mdot
.60692 .54272 Mdot
.68232 .40676 Mdot
.34675 .53998 Mdot
.53714 .4578 Mdot
.70669 .41768 Mdot
.43811 .33202 Mdot
.50701 .36684 Mdot
.44424 .40769 Mdot
.45631 .31081 Mdot
.5473 .6353 Mdot
.65393 .51947 Mdot
.41073 .39883 Mdot
.4112 .62291 Mdot
.49113 .55454 Mdot
.41132 .3959 Mdot
.29723 .53188 Mdot
.53487 .67548 Mdot
.38864 .71491 Mdot
.62834 .28766 Mdot
.42826 .39485 Mdot
.63937 .77783 Mdot
.31584 .25806 Mdot
.38898 .72196 Mdot
.29463 .5094 Mdot
.69037 .38636 Mdot
.4404 .37384 Mdot
.6937 .4945 Mdot
.43677 .41295 Mdot
.55093 .42687 Mdot
.63073 .57493 Mdot
.52575 .63057 Mdot
.41322 .68987 Mdot
.62035 .55055 Mdot
.31387 .53098 Mdot
.46164 .84559 Mdot
.35818 .56268 Mdot
.32991 .56638 Mdot
.75542 .62879 Mdot
.52338 .64793 Mdot
.15912 .68153 Mdot
.19375 .38893 Mdot
.43226 .41013 Mdot
.52407 .66487 Mdot
.35147 .51857 Mdot
.45717 .37059 Mdot
.30838 .55745 Mdot
.35141 .55967 Mdot
.4787 .33199 Mdot
.50758 .37784 Mdot
.63024 .23641 Mdot
.62081 .80469 Mdot
.70304 .38966 Mdot
.30467 .51158 Mdot
.32522 .27388 Mdot
.4948 .39894 Mdot
.46025 .42315 Mdot
.70225 .67125 Mdot
.67216 .41641 Mdot
.22441 .43778 Mdot
.45461 .41326 Mdot
.39815 .21768 Mdot
.50709 .36183 Mdot
.32998 .47684 Mdot
.49916 .62534 Mdot
.33617 .63947 Mdot
.66817 .55131 Mdot
.36666 .52703 Mdot
.71428 .39894 Mdot
.36867 .52325 Mdot
.38925 .24925 Mdot
.5234 .65128 Mdot
.33139 .54803 Mdot
.61653 .53881 Mdot
.53223 .6593 Mdot
.55793 .64457 Mdot
.6532 .48817 Mdot
.63538 .52477 Mdot
.65918 .40324 Mdot
.51342 .64369 Mdot
.28874 .30709 Mdot
.53683 .64836 Mdot
.33752 .26885 Mdot
.49376 .41457 Mdot
.64284 .25203 Mdot
.40125 .66857 Mdot
.43957 .31317 Mdot
.52223 .61889 Mdot
.70347 .4023 Mdot
.46363 .35465 Mdot
.31086 .50969 Mdot
.69753 .40386 Mdot
.57313 .61604 Mdot
.60591 .55711 Mdot
.28969 .55548 Mdot
.50808 .669 Mdot
.32652 .55268 Mdot
.56161 .23576 Mdot
.5896 .58271 Mdot
.64183 .442 Mdot
.45863 .585 Mdot
.50372 .33629 Mdot
.40924 .48312 Mdot
.4735 .43061 Mdot
.47057 .38368 Mdot
.64123 .55753 Mdot
.70611 .30053 Mdot
.31305 .51378 Mdot
.3282 .76946 Mdot
.54351 .62507 Mdot
.42894 .52222 Mdot
.56424 .3878 Mdot
.48386 .34224 Mdot
.34832 .53512 Mdot
.34583 .56264 Mdot
.34762 .41387 Mdot
.65791 .53614 Mdot
.40566 .38082 Mdot
.42607 .33019 Mdot
.41193 .43039 Mdot
.55792 .63532 Mdot
.54919 .75636 Mdot
.64372 .52913 Mdot
.35733 .16703 Mdot
.63516 .54103 Mdot
.72068 .46627 Mdot
.3294 .52171 Mdot
.69925 .41792 Mdot
.46569 .42347 Mdot
.37115 .45925 Mdot
.35409 .49946 Mdot
.66534 .5038 Mdot
.68916 .38451 Mdot
.57791 .76038 Mdot
.52345 .64331 Mdot
.49177 .42082 Mdot
.47275 .32992 Mdot
.44752 .35218 Mdot
.44131 .39124 Mdot
.54909 .67167 Mdot
.44265 .42203 Mdot
.5505 .67726 Mdot
.2477 .34781 Mdot
.40173 .22103 Mdot
.66735 .58319 Mdot
.79789 .4364 Mdot
.29452 .55523 Mdot
.3201 .29478 Mdot
.21721 .44259 Mdot
.3961 .62043 Mdot
.58931 .54565 Mdot
.50314 .4035 Mdot
.62406 .57451 Mdot
.83085 .46507 Mdot
.66977 .58328 Mdot
.85708 .37869 Mdot
.49094 .25982 Mdot
.54258 .83633 Mdot
.45197 .37492 Mdot
.67059 .52564 Mdot
.21936 .48997 Mdot
.42133 .36138 Mdot
.65672 .38088 Mdot
.56899 .40232 Mdot
.31397 .70732 Mdot
.70148 .41901 Mdot
.47475 .41287 Mdot
.2969 .56353 Mdot
.45105 .39639 Mdot
.47322 .42074 Mdot
.4962 .35516 Mdot
.55995 .61444 Mdot
.45373 .33168 Mdot
.48495 .41831 Mdot
.16284 .48477 Mdot
.70074 .31621 Mdot
.6425 .59038 Mdot
.33069 .42621 Mdot
.68624 .39827 Mdot
.35016 .54553 Mdot
.59422 .48411 Mdot
.53571 .63307 Mdot
.35082 .4008 Mdot
.45027 .3752 Mdot
.35542 .6922 Mdot
.49804 .65107 Mdot
.69146 .41135 Mdot
.38858 .71143 Mdot
.64708 .75337 Mdot
.6735 .56149 Mdot
.399 .71991 Mdot
.63875 .55888 Mdot
.24586 .48691 Mdot
.34966 .54102 Mdot
.49801 .32996 Mdot
.51399 .62892 Mdot
.66618 .57857 Mdot
.73309 .32358 Mdot
.47748 .36845 Mdot
.66048 .57195 Mdot
.50193 .33559 Mdot
.49362 .55856 Mdot
.55664 .50421 Mdot
.67881 .55132 Mdot
.52046 .6819 Mdot
.53312 .66232 Mdot
.70395 .41141 Mdot
.34731 .54933 Mdot
.29657 .54552 Mdot
.52944 .65009 Mdot
.36206 .18182 Mdot
.48335 .40297 Mdot
.5048 .36165 Mdot
.41295 .62944 Mdot
.45015 .38051 Mdot
.66775 .30863 Mdot
.36562 .71614 Mdot
.31323 .56078 Mdot
.44431 .38914 Mdot
.45555 .34256 Mdot
.42935 .37021 Mdot
.57895 .23377 Mdot
.64027 .54564 Mdot
.4467 .3685 Mdot
.69823 .37346 Mdot
.27781 .62295 Mdot
.49948 .39962 Mdot
.43549 .3368 Mdot
.3263 .5513 Mdot
.62651 .20507 Mdot
.55303 .63631 Mdot
.66132 .56157 Mdot
.63301 .59548 Mdot
.56573 .28096 Mdot
.3676 .49841 Mdot
.37815 .70325 Mdot
.69502 .62306 Mdot
.37098 .71554 Mdot
.67095 .40306 Mdot
.65484 .47327 Mdot
.60261 .54878 Mdot
.62931 .59048 Mdot
.54639 .68493 Mdot
.44329 .39341 Mdot
.50684 .36224 Mdot
.34107 .67043 Mdot
.49616 .34927 Mdot
.6931 .38222 Mdot
.50822 .66686 Mdot
.32578 .55035 Mdot
.66517 .39836 Mdot
.55184 .62567 Mdot
.30325 .52542 Mdot
.42563 .36032 Mdot
.4915 .31992 Mdot
.31527 .53841 Mdot
.35823 .52434 Mdot
.49571 .38163 Mdot
.18421 .55266 Mdot
.3113 .56302 Mdot
.33508 .54192 Mdot
.40356 .72618 Mdot
.67389 .56328 Mdot
.54527 .36743 Mdot
.52211 .66171 Mdot
.44739 .40926 Mdot
.66941 .58135 Mdot
.6822 .41929 Mdot
.30775 .54165 Mdot
.43377 .36081 Mdot
.4735 .40263 Mdot
.68094 .39239 Mdot
.67901 .4284 Mdot
.68801 .37989 Mdot
.56899 .63426 Mdot
.43595 .39414 Mdot
.33209 .5113 Mdot
.52118 .64607 Mdot
.67473 .42317 Mdot
.69239 .36812 Mdot
.16735 .46981 Mdot
.49418 .39439 Mdot
.65647 .45414 Mdot
.0996 .46882 Mdot
.64811 .3122 Mdot
.39612 .71891 Mdot
.68196 .55071 Mdot
.65315 .26062 Mdot
.71323 .42607 Mdot
.52233 .66626 Mdot
.61874 .39004 Mdot
.6544 .40281 Mdot
.47998 .3345 Mdot
.47805 .35351 Mdot
.52533 .39779 Mdot
.68825 .40433 Mdot
.56846 .23671 Mdot
.29067 .53621 Mdot
.283 .37607 Mdot
.68637 .39836 Mdot
.67864 .55016 Mdot
.68129 .56632 Mdot
.63547 .54004 Mdot
.50325 .40566 Mdot
.33488 .43699 Mdot
.30347 .28957 Mdot
.23543 .43488 Mdot
.5257 .63988 Mdot
.34024 .56604 Mdot
.59239 .53507 Mdot
.31183 .53152 Mdot
.6204 .55745 Mdot
.68688 .40822 Mdot
.31535 .50168 Mdot
.54783 .66072 Mdot
.54071 .66301 Mdot
.60309 .56888 Mdot
.64939 .54687 Mdot
.66058 .55316 Mdot
.36362 .53366 Mdot
.32845 .52151 Mdot
.4512 .34229 Mdot
.3143 .54658 Mdot
.26878 .28754 Mdot
.71233 .41921 Mdot
.66319 .59343 Mdot
.54941 .64479 Mdot
.35292 .533 Mdot
.46359 .38171 Mdot
.75933 .47343 Mdot
.67754 .5137 Mdot
.68293 .37803 Mdot
.49829 .58497 Mdot
.78333 .28522 Mdot
.47395 .32765 Mdot
.56326 .63878 Mdot
.31806 .62946 Mdot
.48261 .36962 Mdot
.64144 .57858 Mdot
.46633 .24135 Mdot
.37961 .70733 Mdot
.48926 .41269 Mdot
.51707 .39777 Mdot
.51181 .62274 Mdot
.57883 .49129 Mdot
.49076 .34388 Mdot
.49458 .50062 Mdot
.56312 .62261 Mdot
.64192 .52935 Mdot
.21032 .67206 Mdot
.53628 .59783 Mdot
.64899 .24033 Mdot
.39395 .71885 Mdot
.47124 .33107 Mdot
.64984 .56048 Mdot
.68222 .37599 Mdot
.64912 .55476 Mdot
.28392 .53258 Mdot
.66499 .57334 Mdot
.47355 .36538 Mdot
.32953 .51224 Mdot
.55057 .65175 Mdot
.43688 .50901 Mdot
.17481 .50476 Mdot
.64825 .59269 Mdot
.36716 .74226 Mdot
.49269 .4057 Mdot
.23744 .37575 Mdot
.41041 .3319 Mdot
.50515 .39485 Mdot
.51665 .64716 Mdot
.34749 .53384 Mdot
.55948 .66831 Mdot
.45742 .32612 Mdot
.39814 .26059 Mdot
.54348 .62686 Mdot
.28626 .68249 Mdot
.6703 .39596 Mdot
.59581 .22191 Mdot
.47257 .38947 Mdot
.51517 .62854 Mdot
.43541 .39405 Mdot
.30275 .51292 Mdot
.46303 .55409 Mdot
.27822 .61596 Mdot
.5115 .63399 Mdot
.43388 .82495 Mdot
.51703 .51733 Mdot
.54132 .39885 Mdot
.5243 .6226 Mdot
.30573 .45694 Mdot
.37866 .72051 Mdot
.67673 .40646 Mdot
.67398 .42514 Mdot
.71042 .38327 Mdot
.49737 .35023 Mdot
.42629 .45272 Mdot
.67499 .37387 Mdot
.5682 .6434 Mdot
.67248 .37916 Mdot
.5427 .23072 Mdot
.46006 .82724 Mdot
.68233 .38065 Mdot
.46865 .39275 Mdot
.4335 .34027 Mdot
.70413 .31707 Mdot
.64583 .52595 Mdot
.65485 .76389 Mdot
.20812 .38134 Mdot
.50038 .39024 Mdot
.50289 .27203 Mdot
.28513 .54669 Mdot
.35246 .60404 Mdot
.50567 .29511 Mdot
.61436 .48424 Mdot
.34182 .54047 Mdot
.49639 .56613 Mdot
.32073 .55996 Mdot
.4848 .32397 Mdot
.46448 .40401 Mdot
.35317 .4968 Mdot
.49285 .78497 Mdot
.23782 .64646 Mdot
.37825 .78206 Mdot
.29535 .54333 Mdot
.53416 .61915 Mdot
.56457 .63454 Mdot
.52013 .64096 Mdot
.66348 .54605 Mdot
.36023 .52059 Mdot
.43477 .38445 Mdot
.6262 .58442 Mdot
.45873 .42019 Mdot
.52578 .65845 Mdot
.41687 .68989 Mdot
.32749 .55015 Mdot
.48688 .38174 Mdot
.18708 .43029 Mdot
.63226 .55563 Mdot
.68214 .39385 Mdot
.46977 .60591 Mdot
.68338 .55053 Mdot
.5457 .61487 Mdot
.37371 .50739 Mdot
.68023 .59324 Mdot
.74493 .43791 Mdot
.48734 .4371 Mdot
.46068 .43545 Mdot
.54903 .70784 Mdot
.18068 .4788 Mdot
.49074 .34997 Mdot
.62653 .58775 Mdot
.67715 .55532 Mdot
.43356 .40227 Mdot
.33572 .50223 Mdot
.6581 .39278 Mdot
.7138 .38409 Mdot
.51759 .36687 Mdot
.44932 .59409 Mdot
.64018 .24613 Mdot
.45906 .34709 Mdot
.54702 .42238 Mdot
.61918 .53701 Mdot
.39331 .712 Mdot
.42831 .59892 Mdot
.71223 .39876 Mdot
.46123 .41054 Mdot
.24774 .66671 Mdot
.33684 .54553 Mdot
.66553 .56318 Mdot
.54378 .66856 Mdot
.65974 .37598 Mdot
.62154 .59418 Mdot
.43353 .40203 Mdot
.45619 .3426 Mdot
.50701 .62999 Mdot
.32201 .47878 Mdot
.68926 .40666 Mdot
.6293 .58529 Mdot
.69998 .41746 Mdot
.32134 .52047 Mdot
.33023 .54487 Mdot
.42214 .33455 Mdot
.43484 .31392 Mdot
.63592 .595 Mdot
.52143 .3985 Mdot
.62692 .54255 Mdot
.786 .48829 Mdot
.55313 .66323 Mdot
.49958 .42218 Mdot
.31341 .48841 Mdot
.52582 .65666 Mdot
.50246 .37766 Mdot
.546 .70722 Mdot
.46988 .34102 Mdot
.66947 .52545 Mdot
.41039 .23882 Mdot
.69386 .41401 Mdot
.40769 .4773 Mdot
.38093 .41763 Mdot
.45155 .3794 Mdot
.65258 .52229 Mdot
.40571 .43002 Mdot
.54357 .63003 Mdot
.33921 .52588 Mdot
.52372 .1525 Mdot
.53899 .65207 Mdot
.45464 .40017 Mdot
.69642 .40077 Mdot
.31433 .56748 Mdot
.37939 .73715 Mdot
.42255 .63564 Mdot
.51819 .43563 Mdot
.53461 .37352 Mdot
.44544 .39589 Mdot
.81441 .38854 Mdot
.65671 .55755 Mdot
.35382 .5257 Mdot
.56183 .64923 Mdot
.53168 .64184 Mdot
.62908 .55096 Mdot
.33143 .72203 Mdot
.52069 .80244 Mdot
.092 .5147 Mdot
.62274 .59156 Mdot
.68823 .37122 Mdot
.48883 .54841 Mdot
.61985 .55 Mdot
.65388 .56419 Mdot
.60164 .56819 Mdot
.36721 .67532 Mdot
.30089 .52538 Mdot
.47369 .40411 Mdot
.36347 .49312 Mdot
.47612 .33224 Mdot
.71176 .29076 Mdot
.52771 .64902 Mdot
.33717 .52471 Mdot
.57974 .67199 Mdot
.48266 .30017 Mdot
.48858 .36387 Mdot
.70136 .51024 Mdot
.50174 .44307 Mdot
.63567 .28004 Mdot
.47892 .31444 Mdot
.64336 .55089 Mdot
.47748 .27258 Mdot
.44229 .44998 Mdot
.19935 .40487 Mdot
.54644 .65949 Mdot
.38384 .73864 Mdot
.42193 .37406 Mdot
.53333 .42928 Mdot
.32028 .56747 Mdot
.31616 .50123 Mdot
.67152 .37622 Mdot
.45967 .62436 Mdot
.54896 .65624 Mdot
.57292 .79377 Mdot
.50858 .38441 Mdot
.48857 .69478 Mdot
.40487 .23754 Mdot
.50031 .37643 Mdot
.67163 .48987 Mdot
.35014 .40404 Mdot
.48248 .34294 Mdot
.24918 .42887 Mdot
.54584 .64696 Mdot
.39589 .21836 Mdot
.52264 .36972 Mdot
.64182 .57769 Mdot
.33372 .5194 Mdot
.28941 .55352 Mdot
.67564 .38235 Mdot
.23311 .32846 Mdot
.52097 .68747 Mdot
.33209 .522 Mdot
.47679 .37334 Mdot
.55297 .63997 Mdot
.38639 .73608 Mdot
.53393 .39635 Mdot
.7898 .57373 Mdot
.31786 .5487 Mdot
.41574 .42418 Mdot
.36046 .76528 Mdot
.52227 .52689 Mdot
.62994 .80046 Mdot
.51913 .63742 Mdot
.71349 .39618 Mdot
.48639 .31355 Mdot
.69025 .62498 Mdot
.51975 .35697 Mdot
.68061 .26705 Mdot
.27456 .56332 Mdot
.68702 .42237 Mdot
.48366 .3734 Mdot
.49034 .34413 Mdot
.46726 .57065 Mdot
.68721 .42773 Mdot
.48953 .34254 Mdot
.40955 .36409 Mdot
.30259 .52927 Mdot
.36329 .7229 Mdot
.31953 .5513 Mdot
.46285 .38885 Mdot
.52239 .27385 Mdot
.32112 .50213 Mdot
.62982 .76486 Mdot
.73095 .36569 Mdot
.53598 .63226 Mdot
.51601 .45083 Mdot
.49746 .40938 Mdot
.79868 .67277 Mdot
.3946 .73002 Mdot
.68896 .24741 Mdot
.67862 .53877 Mdot
.29505 .75029 Mdot
.68435 .54762 Mdot
.51547 .8459 Mdot
.43632 .52268 Mdot
.50641 .42135 Mdot
.62492 .36895 Mdot
.24338 .42576 Mdot
.55393 .67946 Mdot
.27356 .33229 Mdot
.50658 .38932 Mdot
.48312 .4093 Mdot
.61636 .57405 Mdot
.34067 .73001 Mdot
.3218 .63451 Mdot
.43921 .59211 Mdot
.68596 .41155 Mdot
.32436 .5257 Mdot
.47626 .36131 Mdot
.45874 .75439 Mdot
.65061 .58828 Mdot
.57765 .41832 Mdot
.48479 .38421 Mdot
.36095 .64345 Mdot
.31712 .68943 Mdot
.55468 .64323 Mdot
.67439 .53461 Mdot
.65133 .51963 Mdot
.43972 .34422 Mdot
.53193 .67201 Mdot
.46501 .33645 Mdot
.51184 .51891 Mdot
.44599 .44447 Mdot
.67457 .41495 Mdot
.46641 .42498 Mdot
.59727 .41732 Mdot
.51029 .85957 Mdot
.4676 .45284 Mdot
.33492 .5601 Mdot
.65882 .5425 Mdot
.63504 .54433 Mdot
.29639 .54641 Mdot
.6331 .54507 Mdot
.28225 .38512 Mdot
.37291 .25779 Mdot
.67073 .40852 Mdot
.20947 .45034 Mdot
.6878 .41473 Mdot
.38257 .73927 Mdot
.49577 .3901 Mdot
.70513 .62458 Mdot
.62353 .59234 Mdot
.50159 .2245 Mdot
.53467 .64671 Mdot
.39525 .72866 Mdot
.42612 .40522 Mdot
.6719 .46866 Mdot
.61986 .56541 Mdot
.65516 .72736 Mdot
.4305 .36626 Mdot
.30228 .51756 Mdot
.48547 .3436 Mdot
.45908 .44266 Mdot
.39776 .71814 Mdot
.44456 .39617 Mdot
.55163 .62546 Mdot
.36087 .5199 Mdot
.51971 .84048 Mdot
.66186 .54198 Mdot
.48296 .41386 Mdot
.47796 .37286 Mdot
.31311 .50077 Mdot
.42621 .41124 Mdot
.52105 .6639 Mdot
.20552 .74293 Mdot
.67022 .39806 Mdot
.39192 .70998 Mdot
.64046 .7444 Mdot
.47043 .35897 Mdot
.4634 .35002 Mdot
.53677 .71532 Mdot
.2308 .60346 Mdot
.54411 .62318 Mdot
.42566 .42058 Mdot
.64087 .58686 Mdot
.69549 .40663 Mdot
.51134 .65118 Mdot
.43527 .40077 Mdot
.48468 .40792 Mdot
.67112 .41264 Mdot
.70022 .50598 Mdot
.65828 .5118 Mdot
.52325 .64062 Mdot
.51826 .28514 Mdot
.76363 .47754 Mdot
.48359 .39794 Mdot
.41184 .79387 Mdot
.33471 .53955 Mdot
.52507 .62426 Mdot
.32557 .45933 Mdot
.49693 .33129 Mdot
.54232 .61484 Mdot
.54963 .65366 Mdot
.42511 .39407 Mdot
.36837 .49809 Mdot
.36139 .54564 Mdot
.33707 .53988 Mdot
.4262 .22359 Mdot
.7648 .36178 Mdot
.66171 .55352 Mdot
.54699 .65007 Mdot
.67484 .5778 Mdot
.66541 .37947 Mdot
.48965 .55595 Mdot
.67788 .5551 Mdot
.29424 .55616 Mdot
.67336 .58354 Mdot
.46572 .33833 Mdot
.54292 .66492 Mdot
.62393 .58913 Mdot
.45945 .36478 Mdot
.54019 .43642 Mdot
.60311 .40637 Mdot
.65719 .39966 Mdot
.49157 .56798 Mdot
.45733 .3955 Mdot
.39005 .71445 Mdot
.4932 .38281 Mdot
.5352 .67394 Mdot
.59426 .43307 Mdot
.45074 .36923 Mdot
.62858 .59502 Mdot
.75561 .43161 Mdot
.65834 .52592 Mdot
.44333 .43732 Mdot
.46258 .38994 Mdot
.48455 .39995 Mdot
.49645 .34616 Mdot
.29981 .69576 Mdot
.5507 .67773 Mdot
.51025 .4572 Mdot
.61028 .59184 Mdot
.31002 .53579 Mdot
.30384 .50895 Mdot
.6059 .49403 Mdot
.40122 .72331 Mdot
.52871 .66955 Mdot
.4832 .40152 Mdot
.65577 .72656 Mdot
.42681 .69178 Mdot
.39542 .79349 Mdot
.63985 .48921 Mdot
.62617 .58865 Mdot
.34069 .5581 Mdot
.60877 .5625 Mdot
.43532 .40958 Mdot
.48086 .31458 Mdot
.53598 .83577 Mdot
.56382 .613 Mdot
.68751 .40706 Mdot
.4579 .42054 Mdot
.61954 .22661 Mdot
.637 .58754 Mdot
.6226 .53351 Mdot
.45974 .33674 Mdot
.36056 .55493 Mdot
.59436 .83929 Mdot
.5392 .67162 Mdot
.24398 .36458 Mdot
.26089 .54973 Mdot
.56784 .38522 Mdot
.54388 .63583 Mdot
.63967 .44763 Mdot
.65254 .52823 Mdot
.21719 .36296 Mdot
.31366 .54016 Mdot
.68448 .40526 Mdot
.41354 .36321 Mdot
.29461 .55709 Mdot
.68409 .56608 Mdot
.33392 .55418 Mdot
.49377 .32643 Mdot
.5664 .65117 Mdot
.63075 .54377 Mdot
.53401 .67983 Mdot
.35716 .5002 Mdot
.69033 .41449 Mdot
.51668 .2336 Mdot
.24543 .3582 Mdot
.3503 .40408 Mdot
.44603 .36897 Mdot
.72406 .6287 Mdot
.43298 .38618 Mdot
.33998 .56344 Mdot
.4718 .38997 Mdot
.42231 .48915 Mdot
.6315 .53149 Mdot
.42054 .43104 Mdot
.47769 .42373 Mdot
.22479 .36765 Mdot
.49589 .36779 Mdot
.42767 .40564 Mdot
.51912 .38169 Mdot
.26549 .5134 Mdot
.41412 .41274 Mdot
.30413 .51621 Mdot
.3446 .67718 Mdot
.65169 .56523 Mdot
.69989 .36644 Mdot
.71688 .39625 Mdot
.67277 .26055 Mdot
.60295 .223 Mdot
.33495 .71757 Mdot
.30319 .54932 Mdot
.54705 .61896 Mdot
.46255 .33741 Mdot
.275 .47344 Mdot
.58775 .34738 Mdot
.649 .52857 Mdot
.64931 .59551 Mdot
.41699 .33738 Mdot
.84264 .43211 Mdot
.41514 .41892 Mdot
.41658 .64633 Mdot
.48839 .33937 Mdot
.50682 .41464 Mdot
.61993 .53451 Mdot
.56183 .23033 Mdot
.4467 .36867 Mdot
.31965 .56747 Mdot
.68014 .40289 Mdot
.49718 .27408 Mdot
.57083 .31262 Mdot
.57851 .37 Mdot
.30061 .59434 Mdot
.43867 .39238 Mdot
.63049 .58258 Mdot
.29871 .56008 Mdot
.41586 .61673 Mdot
.51968 .64615 Mdot
.43031 .61444 Mdot
.26399 .32689 Mdot
.5443 .59452 Mdot
.68271 .40664 Mdot
.6418 .4954 Mdot
.47268 .36586 Mdot
.66359 .54742 Mdot
.48195 .32694 Mdot
.42864 .69432 Mdot
.68229 .42054 Mdot
.36783 .5158 Mdot
.53587 .61877 Mdot
.29445 .53243 Mdot
.31192 .44438 Mdot
.5818 .33767 Mdot
.2956 .75166 Mdot
.6738 .55831 Mdot
.40734 .28521 Mdot
.34597 .51871 Mdot
.42887 .38231 Mdot
.09487 .504 Mdot
.33392 .53712 Mdot
.29652 .52767 Mdot
.61672 .48238 Mdot
.53802 .24548 Mdot
.43897 .45026 Mdot
.32166 .55842 Mdot
.63954 .60455 Mdot
.6966 .38856 Mdot
.45956 .35793 Mdot
.51605 .36795 Mdot
.32086 .5005 Mdot
.62088 .56162 Mdot
.62063 .22345 Mdot
.64634 .54829 Mdot
.30714 .51872 Mdot
.63456 .56353 Mdot
.61586 .76362 Mdot
.65568 .583 Mdot
.48076 .42341 Mdot
.48251 .40101 Mdot
.78035 .55615 Mdot
.33012 .54489 Mdot
.46387 .35261 Mdot
.46699 .40902 Mdot
.3384 .51299 Mdot
.59631 .56501 Mdot
.36111 .41312 Mdot
.46152 .36802 Mdot
.47816 .40378 Mdot
.69046 .42334 Mdot
.5142 .55157 Mdot
.43801 .76111 Mdot
.46121 .35587 Mdot
.70702 .37757 Mdot
.3626 .5359 Mdot
.49416 .38065 Mdot
.56166 .22706 Mdot
.68611 .5383 Mdot
.4425 .41906 Mdot
.37556 .73687 Mdot
.49459 .35337 Mdot
.58703 .84262 Mdot
.48727 .40953 Mdot
.34829 .51484 Mdot
.34001 .51967 Mdot
.6667 .51224 Mdot
.31581 .53136 Mdot
.39508 .72288 Mdot
.52947 .6601 Mdot
.39405 .80353 Mdot
.39361 .72673 Mdot
.49787 .42104 Mdot
.19393 .38822 Mdot
.51551 .36007 Mdot
.41878 .37277 Mdot
.51954 .22686 Mdot
.39278 .72233 Mdot
.34914 .53061 Mdot
.4943 .78205 Mdot
.49026 .4313 Mdot
.5371 .67228 Mdot
.42374 .3548 Mdot
.44354 .42051 Mdot
.54158 .46896 Mdot
.40784 .2531 Mdot
.51144 .67111 Mdot
.54523 .37381 Mdot
.45949 .35658 Mdot
.22852 .5776 Mdot
.47247 .37211 Mdot
.67896 .38201 Mdot
.30315 .5543 Mdot
.61009 .55722 Mdot
.67527 .39401 Mdot
.47246 .36151 Mdot
.6872 .40201 Mdot
.66226 .55603 Mdot
.51353 .6384 Mdot
.4605 .42395 Mdot
.70891 .41963 Mdot
.68961 .40889 Mdot
.43746 .36237 Mdot
.33475 .52201 Mdot
.39916 .34624 Mdot
.49562 .37919 Mdot
.43223 .39881 Mdot
.29665 .54575 Mdot
.23185 .28838 Mdot
.46368 .32996 Mdot
.64386 .45262 Mdot
.31653 .49476 Mdot
.38745 .70344 Mdot
.60885 .57061 Mdot
.51208 .33117 Mdot
.52714 .64454 Mdot
.52819 .65421 Mdot
.6023 .59149 Mdot
.34685 .49994 Mdot
.62632 .5471 Mdot
.53539 .40357 Mdot
.4197 .3338 Mdot
.41304 .3597 Mdot
.52682 .15329 Mdot
.65001 .75125 Mdot
.35282 .5119 Mdot
.65331 .52629 Mdot
.43924 .59987 Mdot
.53078 .66857 Mdot
.59799 .58988 Mdot
.30555 .49356 Mdot
.35733 .53575 Mdot
.29921 .55758 Mdot
.71014 .39529 Mdot
.64769 .54187 Mdot
.27513 .55539 Mdot
.36775 .53734 Mdot
.44336 .34719 Mdot
.45842 .3567 Mdot
.30898 .57837 Mdot
.69754 .32015 Mdot
.68115 .41744 Mdot
.63429 .58015 Mdot
.76304 .7325 Mdot
.54037 .67165 Mdot
.22278 .3701 Mdot
.45983 .36538 Mdot
.16339 .31503 Mdot
.4128 .40643 Mdot
.47557 .37277 Mdot
.36208 .53177 Mdot
.7198 .38708 Mdot
.69609 .39242 Mdot
.34498 .5186 Mdot
.3726 .53332 Mdot
.70622 .38257 Mdot
.65467 .48445 Mdot
.41219 .82297 Mdot
.4231 .61221 Mdot
.3425 .51131 Mdot
.22708 .38578 Mdot
.51089 .64704 Mdot
.33821 .48972 Mdot
.52067 .67602 Mdot
.65416 .56534 Mdot
.65541 .59176 Mdot
.50547 .63229 Mdot
.42702 .38612 Mdot
.66472 .57089 Mdot
.50171 .44799 Mdot
.58577 .80711 Mdot
.77938 .62507 Mdot
.21379 .60227 Mdot
.51137 .36974 Mdot
.33285 .6359 Mdot
.30146 .65142 Mdot
.45105 .38635 Mdot
.51531 .31346 Mdot
.68713 .4055 Mdot
.33328 .49099 Mdot
.52178 .6703 Mdot
.66086 .76874 Mdot
.48355 .39902 Mdot
.31249 .51415 Mdot
.53754 .66772 Mdot
.60743 .7614 Mdot
.50164 .49943 Mdot
.46656 .33294 Mdot
.0959 .57453 Mdot
.35986 .50399 Mdot
.61077 .55607 Mdot
.19258 .45126 Mdot
.35601 .48898 Mdot
.76392 .46193 Mdot
.64879 .51757 Mdot
.40486 .7648 Mdot
.35209 .54249 Mdot
.62058 .52456 Mdot
.31871 .52253 Mdot
.66382 .39693 Mdot
.37317 .50377 Mdot
.62725 .55886 Mdot
.48874 .37057 Mdot
.62911 .55489 Mdot
.66796 .41153 Mdot
.67008 .55761 Mdot
.52021 .66873 Mdot
.39311 .71726 Mdot
.53649 .66448 Mdot
.494 .55313 Mdot
.37093 .30828 Mdot
.52555 .6309 Mdot
.68098 .7073 Mdot
.48772 .34977 Mdot
.33535 .47609 Mdot
.60763 .55995 Mdot
.64592 .60064 Mdot
.46937 .58225 Mdot
.31254 .51792 Mdot
.62846 .56559 Mdot
.26695 .32734 Mdot
.33106 .19366 Mdot
.48778 .45578 Mdot
.76778 .3741 Mdot
.33843 .51205 Mdot
.62841 .53247 Mdot
.41361 .63215 Mdot
.28833 .53505 Mdot
.63067 .59331 Mdot
.52335 .62198 Mdot
.53427 .63885 Mdot
.42788 .37107 Mdot
.51048 .61828 Mdot
.64934 .52207 Mdot
.24327 .65233 Mdot
.30056 .55388 Mdot
.61816 .74986 Mdot
.69089 .37771 Mdot
.65809 .56219 Mdot
.4327 .44561 Mdot
.29449 .58512 Mdot
.64533 .59797 Mdot
.80908 .54237 Mdot
.79329 .69604 Mdot
.62905 .56661 Mdot
.30418 .55471 Mdot
.30641 .53963 Mdot
.46164 .45236 Mdot
.45351 .58755 Mdot
.62268 .56513 Mdot
.71149 .62054 Mdot
.68786 .27459 Mdot
.37792 .7335 Mdot
.17621 .4384 Mdot
.44669 .36965 Mdot
.43718 .39773 Mdot
.51716 .65593 Mdot
.48793 .36045 Mdot
.35773 .55461 Mdot
.41266 .38289 Mdot
.5656 .63392 Mdot
.64534 .52928 Mdot
.49105 .39495 Mdot
.70435 .40006 Mdot
.51903 .66319 Mdot
.54264 .61182 Mdot
.6416 .56558 Mdot
.30968 .55992 Mdot
.47612 .78818 Mdot
.64707 .54719 Mdot
.43804 .39013 Mdot
.38431 .72431 Mdot
.50175 .32942 Mdot
.76419 .57762 Mdot
.29088 .53864 Mdot
.61 .55937 Mdot
.29617 .50687 Mdot
.54337 .65499 Mdot
.61948 .59989 Mdot
.46624 .37495 Mdot
.63668 .59346 Mdot
.63643 .43234 Mdot
.72099 .5059 Mdot
.36867 .5384 Mdot
.65682 .43098 Mdot
.31414 .50127 Mdot
.37794 .73402 Mdot
.59702 .29673 Mdot
.67662 .40976 Mdot
.65484 .5804 Mdot
.6434 .76365 Mdot
.60269 .57706 Mdot
.49801 .36881 Mdot
.5071 .37376 Mdot
.61464 .57253 Mdot
.70613 .40577 Mdot
.57501 .20344 Mdot
.73182 .41774 Mdot
.34891 .54029 Mdot
.41731 .54417 Mdot
.71463 .77148 Mdot
.62765 .61076 Mdot
.53928 .61604 Mdot
.55216 .37803 Mdot
.47392 .34363 Mdot
.51451 .62104 Mdot
.55499 .66357 Mdot
.67328 .42203 Mdot
.66478 .55108 Mdot
.28106 .52004 Mdot
.50833 .64167 Mdot
.38212 .35256 Mdot
.58254 .22081 Mdot
.48921 .44528 Mdot
.40464 .41293 Mdot
.49608 .41467 Mdot
.52182 .52894 Mdot
.56215 .66087 Mdot
.46125 .39795 Mdot
.43181 .3228 Mdot
.53065 .62344 Mdot
.6658 .40719 Mdot
.38914 .49984 Mdot
.63622 .57213 Mdot
.25988 .22884 Mdot
.4625 .42449 Mdot
.49205 .37294 Mdot
.526 .63976 Mdot
.18374 .49645 Mdot
.34507 .50833 Mdot
.31179 .55852 Mdot
.65763 .55696 Mdot
.4661 .59094 Mdot
.43027 .417 Mdot
.45239 .38964 Mdot
.65466 .57699 Mdot
.38997 .71592 Mdot
.1998 .61329 Mdot
.47278 .40101 Mdot
.54701 .64186 Mdot
.67396 .70506 Mdot
.56003 .66509 Mdot
.47576 .32768 Mdot
.50043 .36929 Mdot
.47227 .42743 Mdot
.50053 .34781 Mdot
.50608 .63618 Mdot
.45391 .3855 Mdot
.43308 .30617 Mdot
.34452 .5356 Mdot
.44637 .37806 Mdot
.66243 .25781 Mdot
.47737 .39804 Mdot
.70332 .40087 Mdot
.44304 .76887 Mdot
.47752 .41492 Mdot
.44389 .38176 Mdot
.71892 .43168 Mdot
.48019 .37665 Mdot
.55369 .65483 Mdot
.31067 .54097 Mdot
.54688 .65234 Mdot
.55718 .63462 Mdot
.66297 .59149 Mdot
.66554 .418 Mdot
.52421 .36765 Mdot
.70458 .37865 Mdot
.45208 .44748 Mdot
.49241 .32708 Mdot
.50313 .55617 Mdot
.41719 .64807 Mdot
.70554 .4314 Mdot
.46187 .38103 Mdot
.65322 .56002 Mdot
.60715 .57198 Mdot
.62782 .37707 Mdot
.48858 .45033 Mdot
.51057 .65172 Mdot
.51521 .6283 Mdot
.66511 .31198 Mdot
.52457 .48383 Mdot
.6988 .40701 Mdot
.43541 .57546 Mdot
.51362 .38358 Mdot
.47017 .41222 Mdot
.43044 .34376 Mdot
.67885 .56256 Mdot
.39297 .71391 Mdot
.64876 .53003 Mdot
.38945 .74427 Mdot
.55523 .67312 Mdot
.51138 .37146 Mdot
.75706 .65611 Mdot
.34245 .50154 Mdot
.3114 .54205 Mdot
.56441 .6268 Mdot
.65663 .52484 Mdot
.46934 .45026 Mdot
.5483 .14849 Mdot
.30824 .57279 Mdot
.70801 .37291 Mdot
.45278 .3941 Mdot
.64516 .56455 Mdot
.35972 .51296 Mdot
.67206 .42858 Mdot
.51116 .38033 Mdot
.59732 .57728 Mdot
.47487 .3927 Mdot
.24046 .44573 Mdot
.34476 .53029 Mdot
.41819 .69306 Mdot
.36166 .55809 Mdot
.52308 .61847 Mdot
.55026 .62729 Mdot
.50235 .37593 Mdot
.43579 .15144 Mdot
.36243 .56253 Mdot
.49567 .63863 Mdot
.66154 .39689 Mdot
.38957 .70961 Mdot
.66103 .40947 Mdot
.62311 .54544 Mdot
.68021 .40517 Mdot
.63243 .59549 Mdot
.67958 .32559 Mdot
.28477 .56484 Mdot
.67176 .39747 Mdot
.18122 .50663 Mdot
.49316 .32085 Mdot
.6784 .42505 Mdot
.41384 .34177 Mdot
.3931 .4785 Mdot
.65376 .57518 Mdot
.70669 .40227 Mdot
.43378 .36202 Mdot
.6988 .72483 Mdot
.55439 .63066 Mdot
.51172 .65577 Mdot
.52116 .35947 Mdot
.61082 .54852 Mdot
.37263 .52703 Mdot
.59351 .48076 Mdot
.38323 .70336 Mdot
.4532 .38925 Mdot
.51249 .37977 Mdot
.33298 .49541 Mdot
.32474 .56841 Mdot
.50255 .37064 Mdot
.28128 .31674 Mdot
.47147 .36609 Mdot
.53718 .63616 Mdot
.35898 .52715 Mdot
.30831 .54245 Mdot
.66882 .52836 Mdot
.34628 .50003 Mdot
.40868 .41661 Mdot
.5573 .68239 Mdot
.42763 .33392 Mdot
.54012 .65477 Mdot
.6006 .4276 Mdot
.66566 .54737 Mdot
.66024 .76228 Mdot
.35548 .50456 Mdot
.44273 .39172 Mdot
.30803 .50644 Mdot
.68863 .38016 Mdot
.328 .54569 Mdot
.28562 .5541 Mdot
.5074 .38432 Mdot
.47029 .33135 Mdot
.38811 .71925 Mdot
.45443 .58982 Mdot
.33834 .52991 Mdot
.46258 .37133 Mdot
.52223 .37623 Mdot
.44719 .3365 Mdot
.51932 .51694 Mdot
.35704 .54104 Mdot
.35479 .2555 Mdot
.77363 .5947 Mdot
.33458 .52473 Mdot
.66434 .78461 Mdot
.36734 .72565 Mdot
.40189 .72287 Mdot
.49242 .64733 Mdot
.47485 .404 Mdot
.62718 .54829 Mdot
.43846 .41284 Mdot
.50889 .44468 Mdot
.47932 .41585 Mdot
.67414 .41772 Mdot
.50668 .42601 Mdot
.37195 .72171 Mdot
.64121 .54804 Mdot
.4666 .36411 Mdot
.48957 .39984 Mdot
.40043 .72647 Mdot
.36175 .55937 Mdot
.35478 .53863 Mdot
.42022 .79303 Mdot
.66688 .39932 Mdot
.51751 .64714 Mdot
.43653 .40848 Mdot
.65494 .55861 Mdot
.6307 .54952 Mdot
.29522 .53013 Mdot
.63783 .57692 Mdot
.53338 .67433 Mdot
.47629 .36788 Mdot
.51302 .62238 Mdot
.67359 .41712 Mdot
.3026 .55398 Mdot
.43556 .40777 Mdot
.44088 .34922 Mdot
.34036 .51987 Mdot
.48995 .35011 Mdot
.69174 .42285 Mdot
.66635 .57981 Mdot
.35479 .53294 Mdot
.52921 .65881 Mdot
.67443 .53581 Mdot
.46084 .34006 Mdot
.84286 .59497 Mdot
.48733 .35925 Mdot
.44679 .41254 Mdot
.45106 .8373 Mdot
.47452 .31388 Mdot
.62504 .53762 Mdot
.30412 .50763 Mdot
.45994 .32792 Mdot
.71546 .29667 Mdot
.61377 .63419 Mdot
.59557 .58703 Mdot
.45014 .39614 Mdot
.63789 .78687 Mdot
.44508 .38733 Mdot
.5962 .76944 Mdot
.50082 .55732 Mdot
.81623 .41818 Mdot
.40083 .40092 Mdot
.49821 .63323 Mdot
.39026 .71862 Mdot
.60628 .56045 Mdot
.26811 .45851 Mdot
.48968 .35509 Mdot
.32459 .45246 Mdot
.44292 .42213 Mdot
.54211 .63607 Mdot
.52455 .32228 Mdot
.635 .57933 Mdot
.20085 .39201 Mdot
.43509 .38715 Mdot
.35861 .53714 Mdot
.64892 .60219 Mdot
.38284 .70766 Mdot
.43269 .36344 Mdot
.69481 .37572 Mdot
.58574 .65452 Mdot
.40375 .38142 Mdot
.53799 .65641 Mdot
.46473 .4106 Mdot
.54482 .39832 Mdot
.37058 .18141 Mdot
.34621 .53638 Mdot
.53534 .61724 Mdot
.32815 .60777 Mdot
.50189 .35512 Mdot
.3532 .54029 Mdot
.3122 .53838 Mdot
.67551 .38016 Mdot
.43151 .66475 Mdot
.66803 .61804 Mdot
.80305 .60017 Mdot
.34063 .41879 Mdot
.67953 .54266 Mdot
.24847 .63141 Mdot
.45226 .36102 Mdot
.57531 .32602 Mdot
.55647 .64534 Mdot
.4897 .37254 Mdot
.34973 .35917 Mdot
.33627 .54154 Mdot
.46976 .39694 Mdot
.67924 .4168 Mdot
.39779 .67964 Mdot
.57093 .35072 Mdot
.79649 .66248 Mdot
.6167 .60302 Mdot
.42306 .35086 Mdot
.40039 .36307 Mdot
.38916 .70412 Mdot
.48352 .33057 Mdot
.60966 .55555 Mdot
.72737 .63258 Mdot
.70164 .41129 Mdot
.34861 .50305 Mdot
.3678 .72133 Mdot
.45893 .43156 Mdot
.5101 .34308 Mdot
.69891 .36668 Mdot
.43017 .38436 Mdot
.19541 .42658 Mdot
.39684 .69619 Mdot
.65739 .58262 Mdot
.33076 .55609 Mdot
.498 .41288 Mdot
.39141 .71351 Mdot
.50788 .38006 Mdot
.39567 .51715 Mdot
.4481 .40423 Mdot
.34251 .75792 Mdot
.33246 .51919 Mdot
.53788 .65982 Mdot
.5285 .39517 Mdot
.4844 .3914 Mdot
.76343 .48196 Mdot
.51217 .44258 Mdot
.48716 .40896 Mdot
.30382 .56599 Mdot
.33048 .50129 Mdot
.30022 .52357 Mdot
.66284 .57787 Mdot
.4267 .60462 Mdot
.5387 .64323 Mdot
.41732 .40066 Mdot
.5096 .64557 Mdot
.39852 .44511 Mdot
.69967 .36893 Mdot
.71015 .73885 Mdot
.47844 .35583 Mdot
.29787 .5366 Mdot
.25722 .6712 Mdot
.36312 .53512 Mdot
.48498 .64782 Mdot
.54863 .65715 Mdot
.33409 .53518 Mdot
.47497 .38035 Mdot
.44221 .58979 Mdot
.8221 .61907 Mdot
.52903 .66694 Mdot
.45472 .32319 Mdot
.62669 .60416 Mdot
.62734 .5968 Mdot
.63885 .81784 Mdot
.55778 .63078 Mdot
.29634 .64897 Mdot
.45671 .37519 Mdot
.33579 .49995 Mdot
.52257 .63544 Mdot
.55575 .65293 Mdot
.64934 .57856 Mdot
.46073 .33437 Mdot
.48167 .39223 Mdot
.37353 .7359 Mdot
.51208 .63838 Mdot
.52858 .3417 Mdot
.48051 .33692 Mdot
.5185 .84352 Mdot
.29737 .49872 Mdot
.20996 .31046 Mdot
.53833 .39895 Mdot
.35474 .35622 Mdot
.54945 .48341 Mdot
.35654 .51483 Mdot
.42905 .39961 Mdot
.41869 .40819 Mdot
.67588 .53532 Mdot
.47962 .36384 Mdot
.66586 .5365 Mdot
.54351 .61639 Mdot
.71726 .73902 Mdot
.63165 .73303 Mdot
.5891 .54431 Mdot
.49167 .36323 Mdot
.57137 .3892 Mdot
.68277 .38558 Mdot
.57069 .62951 Mdot
.31541 .5088 Mdot
.50597 .40455 Mdot
.65383 .51706 Mdot
.65093 .58316 Mdot
.31919 .53941 Mdot
.31142 .66693 Mdot
.62872 .76542 Mdot
.50246 .34874 Mdot
.61191 .55948 Mdot
.61074 .74095 Mdot
.30374 .30558 Mdot
.50421 .62517 Mdot
.6969 .41423 Mdot
.64148 .53153 Mdot
.55509 .61282 Mdot
.39899 .49643 Mdot
.32402 .53299 Mdot
.34601 .49623 Mdot
.76001 .53586 Mdot
.62404 .56143 Mdot
.68397 .38938 Mdot
.49254 .49354 Mdot
.44895 .50327 Mdot
.68111 .41976 Mdot
.64708 .52839 Mdot
.34713 .50434 Mdot
.31044 .51574 Mdot
.3098 .53956 Mdot
.19862 .40611 Mdot
.28927 .54478 Mdot
.32691 .24512 Mdot
.51029 .352 Mdot
.23604 .37962 Mdot
.44587 .39034 Mdot
.50499 .65047 Mdot
.34467 .52889 Mdot
.48316 .55926 Mdot
.51251 .40274 Mdot
.80115 .65054 Mdot
.4561 .39531 Mdot
.55526 .68878 Mdot
.47645 .40444 Mdot
.20426 .4478 Mdot
.31779 .49411 Mdot
.46135 .3801 Mdot
.50532 .66768 Mdot
.6928 .40507 Mdot
.37607 .54656 Mdot
.48014 .4116 Mdot
.34962 .71332 Mdot
.428 .32684 Mdot
.60966 .78952 Mdot
.74155 .44064 Mdot
.71349 .3764 Mdot
.41457 .35042 Mdot
.67919 .58002 Mdot
.34226 .58237 Mdot
.22429 .40498 Mdot
.52853 .66622 Mdot
.43242 .25015 Mdot
.65818 .57749 Mdot
.51957 .31854 Mdot
.4656 .44003 Mdot
.71066 .40045 Mdot
.36947 .55651 Mdot
.53796 .634 Mdot
.48697 .35162 Mdot
.42747 .40164 Mdot
.81004 .51497 Mdot
.21835 .41257 Mdot
.5294 .34568 Mdot
.66525 .3809 Mdot
.36114 .25667 Mdot
.4708 .41657 Mdot
.5959 .58018 Mdot
.2956 .51604 Mdot
.42087 .43767 Mdot
.34508 .25863 Mdot
.46634 .36801 Mdot
.33012 .53728 Mdot
.35364 .50266 Mdot
.30479 .72623 Mdot
.70376 .37183 Mdot
.44828 .4045 Mdot
.7741 .47794 Mdot
.43653 .3939 Mdot
.5387 .63971 Mdot
.47233 .32631 Mdot
.65806 .56731 Mdot
.41125 .63808 Mdot
.66642 .57514 Mdot
.43446 .35206 Mdot
.30836 .52584 Mdot
.53369 .63375 Mdot
.75988 .5537 Mdot
.57792 .5022 Mdot
.3356 .24087 Mdot
.58706 .65538 Mdot
.70769 .39255 Mdot
.66654 .42235 Mdot
.5397 .68882 Mdot
.46146 .38728 Mdot
.54456 .51047 Mdot
.42322 .43007 Mdot
.47731 .40778 Mdot
.46494 .42312 Mdot
.57609 .6192 Mdot
.54504 .65979 Mdot
.63159 .56148 Mdot
.50198 .36845 Mdot
.46178 .3725 Mdot
.32964 .52562 Mdot
.69044 .40913 Mdot
.65691 .58592 Mdot
.67052 .39275 Mdot
.64502 .55232 Mdot
.60249 .83255 Mdot
.46047 .32575 Mdot
.69398 .40416 Mdot
.56378 .6603 Mdot
.29583 .53973 Mdot
.39454 .73124 Mdot
.62483 .54447 Mdot
.63259 .57772 Mdot
.45242 .38632 Mdot
.3149 .5549 Mdot
.33283 .55029 Mdot
.70733 .38524 Mdot
.51903 .62937 Mdot
.42613 .37596 Mdot
.47677 .33376 Mdot
.80067 .43705 Mdot
.67934 .54931 Mdot
.29861 .29677 Mdot
.31273 .71322 Mdot
.46169 .38613 Mdot
.34095 .54754 Mdot
.49201 .39013 Mdot
.72212 .67825 Mdot
.29543 .55711 Mdot
.52048 .38929 Mdot
.52576 .47349 Mdot
.676 .5698 Mdot
.30647 .74891 Mdot
.52652 .39141 Mdot
.53257 .71762 Mdot
.44282 .36142 Mdot
.39669 .84338 Mdot
.23376 .59865 Mdot
.44882 .42764 Mdot
.50413 .35265 Mdot
.82058 .57132 Mdot
.45147 .37878 Mdot
.37013 .72668 Mdot
.52859 .41809 Mdot
.35622 .53759 Mdot
.56375 .48202 Mdot
.50853 .56276 Mdot
.68478 .37159 Mdot
.6584 .55702 Mdot
.56211 .26107 Mdot
.66417 .40133 Mdot
.34546 .51447 Mdot
.51808 .37375 Mdot
.37699 .35044 Mdot
.67603 .51742 Mdot
.45222 .44319 Mdot
.53985 .63846 Mdot
.50452 .56413 Mdot
.65542 .53317 Mdot
.53117 .66139 Mdot
.45421 .42641 Mdot
.68947 .25413 Mdot
.5806 .51075 Mdot
.347 .78395 Mdot
.52352 .64063 Mdot
.55356 .646 Mdot
.40912 .61481 Mdot
.6847 .3717 Mdot
.81184 .48859 Mdot
.53978 .31311 Mdot
.53714 .67121 Mdot
.62924 .29009 Mdot
.63461 .52313 Mdot
.42764 .66545 Mdot
.33201 .4905 Mdot
.45245 .32832 Mdot
.47719 .3828 Mdot
.52384 .62615 Mdot
.33014 .46354 Mdot
.38405 .56644 Mdot
.53391 .66562 Mdot
.40916 .33786 Mdot
.42866 .68096 Mdot
.38761 .7247 Mdot
.36898 .73311 Mdot
.66412 .38758 Mdot
.7188 .53559 Mdot
.32261 .51729 Mdot
.70919 .40798 Mdot
.37753 .76052 Mdot
.45055 .40747 Mdot
.51092 .63963 Mdot
.38494 .73924 Mdot
.52973 .65198 Mdot
.69827 .39617 Mdot
.70643 .37196 Mdot
.34486 .53578 Mdot
.34328 .50758 Mdot
.4039 .26159 Mdot
.66561 .2956 Mdot
.44754 .37994 Mdot
.35902 .41945 Mdot
.29374 .54766 Mdot
.21448 .49566 Mdot
.70243 .3747 Mdot
.68692 .41246 Mdot
.26046 .39323 Mdot
.45347 .34066 Mdot
.65155 .71929 Mdot
.47653 .41446 Mdot
.60384 .30848 Mdot
.48616 .43148 Mdot
.64544 .57838 Mdot
.44123 .37843 Mdot
.46678 .77129 Mdot
.46815 .35482 Mdot
.47687 .42057 Mdot
.63974 .53938 Mdot
.53065 .39112 Mdot
.65894 .56932 Mdot
.46967 .32976 Mdot
.70189 .36231 Mdot
.65493 .55833 Mdot
.74336 .35267 Mdot
.63841 .4515 Mdot
.38514 .71261 Mdot
.66273 .39541 Mdot
.69957 .37756 Mdot
.65554 .24838 Mdot
.32195 .50625 Mdot
.40203 .48941 Mdot
.46167 .38857 Mdot
.62044 .53587 Mdot
.5147 .65239 Mdot
.46602 .36931 Mdot
.41228 .3961 Mdot
.52763 .3842 Mdot
.33802 .53768 Mdot
.64282 .52807 Mdot
.69059 .39946 Mdot
.60883 .57727 Mdot
.66575 .46786 Mdot
.61252 .58976 Mdot
.55133 .40675 Mdot
.5391 .38764 Mdot
.38529 .38576 Mdot
.35531 .39296 Mdot
.21946 .35629 Mdot
.31963 .5348 Mdot
.37883 .72332 Mdot
.69221 .36862 Mdot
.4162 .54229 Mdot
.30128 .53012 Mdot
.62889 .57547 Mdot
.47488 .39255 Mdot
.4087 .33698 Mdot
.56723 .35421 Mdot
.27795 .57062 Mdot
.70345 .29889 Mdot
.65488 .54143 Mdot
.38474 .73177 Mdot
.42014 .62161 Mdot
.26441 .5211 Mdot
.48808 .55485 Mdot
.48815 .39158 Mdot
.69987 .37605 Mdot
.35966 .51286 Mdot
.78558 .54158 Mdot
.52294 .6235 Mdot
.45318 .5892 Mdot
.48993 .36249 Mdot
.26367 .64957 Mdot
.30854 .526 Mdot
.68666 .4156 Mdot
.52474 .6259 Mdot
.7023 .37235 Mdot
.36672 .72145 Mdot
.43863 .78736 Mdot
.43246 .37368 Mdot
.48898 .40846 Mdot
.54353 .67732 Mdot
.31946 .51827 Mdot
.64945 .50695 Mdot
.79566 .548 Mdot
.61157 .56213 Mdot
.53387 .52497 Mdot
.36058 .51854 Mdot
.24018 .56845 Mdot
.63099 .59146 Mdot
.568 .64073 Mdot
.53364 .51588 Mdot
.56489 .63322 Mdot
.47101 .41946 Mdot
.30598 .54941 Mdot
.55775 .6302 Mdot
.77662 .50992 Mdot
.58458 .82686 Mdot
.3786 .54744 Mdot
.49712 .35475 Mdot
.71662 .73656 Mdot
.50055 .83056 Mdot
.37179 .45682 Mdot
.50838 .63745 Mdot
.49946 .38064 Mdot
.50422 .34989 Mdot
.43607 .3861 Mdot
.54567 .62048 Mdot
.60823 .50287 Mdot
.63528 .58419 Mdot
.45871 .40036 Mdot
.69148 .37805 Mdot
.65026 .57033 Mdot
.6687 .59034 Mdot
.60442 .56621 Mdot
.29694 .56015 Mdot
.51484 .36303 Mdot
.40039 .66745 Mdot
.42615 .85128 Mdot
.54553 .65685 Mdot
.38474 .71249 Mdot
.46663 .42619 Mdot
.41265 .218 Mdot
.29956 .52558 Mdot
.61202 .56323 Mdot
.49098 .37362 Mdot
.74197 .45903 Mdot
.35891 .7065 Mdot
.65046 .54536 Mdot
.31776 .50859 Mdot
.37376 .45751 Mdot
.47885 .36382 Mdot
.4439 .35829 Mdot
.33022 .513 Mdot
.39576 .79144 Mdot
.41834 .64122 Mdot
.4906 .39348 Mdot
.53625 .66121 Mdot
.35373 .17999 Mdot
.51435 .34829 Mdot
.28061 .57745 Mdot
.39136 .71001 Mdot
.33802 .74015 Mdot
.30979 .29067 Mdot
.5117 .45189 Mdot
.74194 .69995 Mdot
.54599 .23278 Mdot
.7001 .75136 Mdot
.56076 .2829 Mdot
.57944 .74333 Mdot
.53798 .8679 Mdot
.49747 .65424 Mdot
.20835 .45297 Mdot
.83325 .47076 Mdot
.33003 .66112 Mdot
.71166 .45117 Mdot
.65977 .64214 Mdot
.75015 .44888 Mdot
.17279 .5471 Mdot
.61709 .59005 Mdot
.59671 .33161 Mdot
.42581 .39252 Mdot
.49373 .82588 Mdot
.23567 .3637 Mdot
.22683 .33507 Mdot
.69761 .74341 Mdot
.77057 .46633 Mdot
.84272 .57164 Mdot
.65805 .75898 Mdot
.42118 .26827 Mdot
.57534 .41933 Mdot
.71116 .57087 Mdot
.47005 .49641 Mdot
.55353 .25429 Mdot
.41333 .44136 Mdot
.46362 .75447 Mdot
.58844 .56196 Mdot
.36231 .29351 Mdot
.33961 .19808 Mdot
.62701 .53829 Mdot
.29354 .51917 Mdot
.81672 .47027 Mdot
.30188 .59016 Mdot
.50071 .67658 Mdot
.74278 .6993 Mdot
.5177 .84681 Mdot
.20441 .44344 Mdot
.4005 .75436 Mdot
.2577 .43378 Mdot
.56721 .19624 Mdot
.58766 .39169 Mdot
.36928 .52439 Mdot
.62204 .69789 Mdot
.44925 .50263 Mdot
.70947 .54107 Mdot
.1987 .47467 Mdot
.67719 .43129 Mdot
.73793 .33507 Mdot
.31586 .51108 Mdot
.31657 .29812 Mdot
.40244 .71806 Mdot
.39335 .75181 Mdot
.62758 .52135 Mdot
.73116 .66483 Mdot
.36895 .69163 Mdot
.36727 .68469 Mdot
.23328 .64597 Mdot
.82805 .63241 Mdot
.59658 .24508 Mdot
.73503 .6189 Mdot
.51689 .70703 Mdot
.55652 .23244 Mdot
.38494 .6466 Mdot
.64598 .2728 Mdot
.44293 .4924 Mdot
.86233 .46006 Mdot
.4282 .81494 Mdot
.85734 .53297 Mdot
.36511 .48463 Mdot
.5011 .32247 Mdot
.74913 .62402 Mdot
.33054 .42861 Mdot
.72163 .39001 Mdot
.8146 .64668 Mdot
.716 .3893 Mdot
.28031 .52398 Mdot
.32183 .65936 Mdot
.20369 .40864 Mdot
.63136 .50762 Mdot
.73405 .36925 Mdot
.41066 .414 Mdot
.86278 .39623 Mdot
.75911 .68425 Mdot
.3148 .73092 Mdot
.50869 .84492 Mdot
.62071 .61138 Mdot
.68912 .53969 Mdot
.54704 .61759 Mdot
.55378 .85134 Mdot
.30304 .53785 Mdot
.43736 .85915 Mdot
.54812 .84737 Mdot
.28594 .59759 Mdot
.85948 .36921 Mdot
.19969 .59113 Mdot
.24456 .3652 Mdot
.47627 .24431 Mdot
.756 .33761 Mdot
.39044 .62358 Mdot
.24197 .57829 Mdot
.64146 .60846 Mdot
.38612 .79761 Mdot
.61256 .82107 Mdot
.63011 .30237 Mdot
.55472 .59318 Mdot
.3428 .65022 Mdot
.60485 .41569 Mdot
.29576 .58004 Mdot
.72848 .42947 Mdot
.61035 .40042 Mdot
.85242 .55164 Mdot
.39838 .24867 Mdot
.47513 .14424 Mdot
.57203 .28782 Mdot
.1832 .48981 Mdot
.65372 .74381 Mdot
.71125 .34719 Mdot
.39451 .53631 Mdot
.34574 .68414 Mdot
.44566 .32216 Mdot
.42905 .58271 Mdot
.45262 .29331 Mdot
.64632 .41672 Mdot
.41856 .61043 Mdot
.56016 .7848 Mdot
.58718 .29051 Mdot
.79089 .60446 Mdot
.55513 .44625 Mdot
.32839 .55931 Mdot
.63846 .25759 Mdot
.60796 .26731 Mdot
.5384 .83383 Mdot
.32673 .6088 Mdot
.35683 .78714 Mdot
.33725 .60148 Mdot
.4209 .42746 Mdot
.21053 .45929 Mdot
.4045 .43129 Mdot
.63069 .27535 Mdot
.51586 .41083 Mdot
.23929 .65902 Mdot
.46065 .84051 Mdot
.3609 .32432 Mdot
.57584 .2657 Mdot
.36034 .36873 Mdot
.39791 .80571 Mdot
.75522 .62213 Mdot
.25254 .61393 Mdot
.24243 .53336 Mdot
.86344 .41671 Mdot
.63948 .5691 Mdot
.63733 .29464 Mdot
.57715 .63475 Mdot
.76362 .54215 Mdot
.83493 .44121 Mdot
.35715 .588 Mdot
.45088 .84061 Mdot
.36004 .67188 Mdot
.65546 .5009 Mdot
.44308 .67697 Mdot
.51683 .60111 Mdot
.37317 .33668 Mdot
.52292 .35991 Mdot
.38135 .37679 Mdot
.69739 .42161 Mdot
.31103 .43082 Mdot
.76484 .5975 Mdot
.58803 .6857 Mdot
.52634 .44651 Mdot
.58977 .6993 Mdot
.38156 .73496 Mdot
.44719 .59965 Mdot
.62852 .82534 Mdot
.53132 .42351 Mdot
.19571 .56442 Mdot
.42446 .80904 Mdot
.52287 .53066 Mdot
.70046 .50467 Mdot
.29089 .68784 Mdot
.86474 .49866 Mdot
.50341 .8588 Mdot
.53158 .81145 Mdot
.72402 .73062 Mdot
.2483 .73593 Mdot
.82232 .39392 Mdot
.26074 .48177 Mdot
.57945 .62763 Mdot
.1818 .70761 Mdot
.61893 .58189 Mdot
.44294 .24132 Mdot
.33164 .42429 Mdot
.73946 .46759 Mdot
.32216 .58734 Mdot
.5229 .45986 Mdot
.60301 .62377 Mdot
.32604 .5778 Mdot
.41241 .41462 Mdot
.78906 .69209 Mdot
.86536 .45971 Mdot
.80332 .6731 Mdot
.4414 .78977 Mdot
.71341 .74849 Mdot
.84023 .51797 Mdot
.31737 .25062 Mdot
.81637 .49599 Mdot
.47324 .32669 Mdot
.65071 .31952 Mdot
.20469 .5907 Mdot
.62745 .51799 Mdot
.41455 .71694 Mdot
.3238 .48533 Mdot
.85412 .46637 Mdot
.63829 .82357 Mdot
.27894 .38811 Mdot
.3487 .28526 Mdot
.62862 .43622 Mdot
.6501 .28623 Mdot
.40694 .30127 Mdot
.46657 .74391 Mdot
.58244 .81162 Mdot
.84174 .50661 Mdot
.60346 .27641 Mdot
.63978 .65679 Mdot
.53542 .80221 Mdot
.21295 .55462 Mdot
.68699 .73173 Mdot
.81912 .46019 Mdot
.30506 .60133 Mdot
.27301 .49918 Mdot
.37843 .57154 Mdot
.45576 .73326 Mdot
.70626 .66601 Mdot
.58006 .2424 Mdot
.67094 .55635 Mdot
.63639 .30683 Mdot
.48433 .52797 Mdot
.81867 .48938 Mdot
.56995 .22686 Mdot
.62575 .30611 Mdot
.55237 .80322 Mdot
.76684 .70908 Mdot
.36898 .77366 Mdot
.72368 .27833 Mdot
.50567 .72461 Mdot
.46526 .29182 Mdot
.51559 .33335 Mdot
.43043 .82649 Mdot
.74337 .74469 Mdot
.46328 .84769 Mdot
.25919 .6465 Mdot
.76983 .51139 Mdot
.52218 .6133 Mdot
.562 .21565 Mdot
.56337 .70495 Mdot
.59115 .81133 Mdot
.42294 .55248 Mdot
.49444 .63047 Mdot
.37356 .66518 Mdot
.4199 .26238 Mdot
.51258 .23075 Mdot
.3276 .3112 Mdot
.47699 .44984 Mdot
.27309 .33246 Mdot
.3107 .49967 Mdot
.25527 .63682 Mdot
.64498 .27727 Mdot
.64201 .56654 Mdot
.79467 .40699 Mdot
.3883 .33975 Mdot
.47736 .3129 Mdot
.71839 .64091 Mdot
.30109 .58136 Mdot
.35411 .38711 Mdot
.69138 .55594 Mdot
.56089 .8585 Mdot
.22216 .60357 Mdot
.39748 .30603 Mdot
.61355 .24282 Mdot
.79753 .44601 Mdot
.42482 .63941 Mdot
.55645 .6762 Mdot
.68681 .74767 Mdot
.63413 .4616 Mdot
.62973 .25384 Mdot
.2796 .3235 Mdot
.78361 .56465 Mdot
.41626 .40593 Mdot
.29254 .70544 Mdot
.3636 .22994 Mdot
.45211 .59796 Mdot
.2745 .52371 Mdot
.30022 .57126 Mdot
.14682 .50275 Mdot
.48125 .77476 Mdot
.28416 .60939 Mdot
.69591 .73356 Mdot
.5587 .62388 Mdot
.32602 .56507 Mdot
.62827 .31604 Mdot
.72593 .51081 Mdot
.37542 .25962 Mdot
.71123 .66832 Mdot
.44061 .27221 Mdot
.54868 .72122 Mdot
.72148 .72818 Mdot
.80198 .63335 Mdot
.38519 .17193 Mdot
.35493 .56303 Mdot
.75797 .57989 Mdot
.7663 .56748 Mdot
.36737 .52851 Mdot
.27831 .57257 Mdot
.57317 .37577 Mdot
.68585 .77066 Mdot
.43669 .53538 Mdot
.45399 .71493 Mdot
.53401 .51667 Mdot
.70482 .46117 Mdot
.79427 .5364 Mdot
.56266 .24393 Mdot
.7029 .72009 Mdot
.31726 .31085 Mdot
.76925 .33456 Mdot
.38897 .36156 Mdot
.41828 .24045 Mdot
.56188 .21532 Mdot
.58619 .41649 Mdot
.20131 .47964 Mdot
.58083 .7783 Mdot
.4392 .38932 Mdot
.82425 .64455 Mdot
.53801 .82842 Mdot
.41991 .5863 Mdot
.7021 .57464 Mdot
.46088 .34799 Mdot
.51315 .35716 Mdot
.28159 .48354 Mdot
.32625 .72717 Mdot
.79318 .34373 Mdot
.58779 .30225 Mdot
.46382 .28984 Mdot
.27439 .3257 Mdot
.1961 .56406 Mdot
.74102 .63915 Mdot
.62482 .7771 Mdot
.46635 .53874 Mdot
.2077 .59402 Mdot
.46207 .62367 Mdot
.44401 .7104 Mdot
.54042 .73981 Mdot
.8385 .52665 Mdot
.56078 .3676 Mdot
.33019 .70528 Mdot
.8067 .49034 Mdot
.46403 .42532 Mdot
.31139 .66738 Mdot
.67033 .74422 Mdot
.50872 .15682 Mdot
.3744 .64275 Mdot
.7723 .71811 Mdot
.38348 .38002 Mdot
.33884 .70204 Mdot
.83971 .43662 Mdot
.60591 .1644 Mdot
.45715 .75141 Mdot
.84662 .56728 Mdot
.44366 .64936 Mdot
.70257 .72831 Mdot
.49986 .63073 Mdot
.49233 .50322 Mdot
.34772 .44133 Mdot
.67938 .77467 Mdot
.73404 .55075 Mdot
.73122 .67819 Mdot
.26965 .48946 Mdot
.71344 .75618 Mdot
.43257 .48992 Mdot
.15129 .48984 Mdot
.59373 .57765 Mdot
.21556 .64976 Mdot
.23986 .50913 Mdot
.42852 .29272 Mdot
.62305 .28962 Mdot
.1655 .45216 Mdot
.27436 .28471 Mdot
.27825 .47336 Mdot
.62966 .34654 Mdot
.30115 .69795 Mdot
.60691 .23749 Mdot
.58987 .81598 Mdot
.16669 .53367 Mdot
.78019 .55474 Mdot
.28959 .63035 Mdot
.41763 .79652 Mdot
.32539 .73304 Mdot
.53089 .75903 Mdot
.73265 .63428 Mdot
.42874 .74751 Mdot
.44852 .27034 Mdot
.17415 .31787 Mdot
.52294 .57706 Mdot
.57044 .3659 Mdot
.8592 .50452 Mdot
.57628 .81452 Mdot
.41691 .55001 Mdot
.19517 .47043 Mdot
.46503 .21705 Mdot
.68214 .32787 Mdot
.47964 .41537 Mdot
.71918 .75211 Mdot
.71601 .33985 Mdot
.82871 .61292 Mdot
.37202 .80913 Mdot
.28139 .33491 Mdot
.54608 .40618 Mdot
.64355 .60715 Mdot
.58243 .36515 Mdot
.62252 .35366 Mdot
.84778 .52989 Mdot
.43011 .24148 Mdot
.5787 .49512 Mdot
.58346 .7332 Mdot
.66483 .71937 Mdot
.50172 .29748 Mdot
.20458 .60566 Mdot
.31651 .70949 Mdot
.56854 .27523 Mdot
.5215 .80236 Mdot
.63631 .28555 Mdot
.3031 .29496 Mdot
.57222 .2193 Mdot
.38574 .59718 Mdot
.6464 .61694 Mdot
.66664 .525 Mdot
.81433 .57397 Mdot
.63719 .75802 Mdot
.24291 .66352 Mdot
.73598 .29526 Mdot
.34147 .68335 Mdot
.60084 .34681 Mdot
.78347 .59379 Mdot
.38368 .62459 Mdot
.71295 .5861 Mdot
.501 .23205 Mdot
.41084 .24916 Mdot
.59933 .77609 Mdot
.49259 .46873 Mdot
.6154 .82213 Mdot
.57677 .24386 Mdot
.80979 .5473 Mdot
.62491 .44299 Mdot
.33018 .39965 Mdot
.23464 .41623 Mdot
.76274 .35856 Mdot
.46485 .58945 Mdot
.8627 .40213 Mdot
.36793 .50926 Mdot
.82947 .62919 Mdot
.51758 .64948 Mdot
.41425 .17826 Mdot
.59409 .79299 Mdot
.4734 .54649 Mdot
.53557 .50576 Mdot
.29341 .70949 Mdot
.35584 .70189 Mdot
.40932 .80084 Mdot
.36666 .58096 Mdot
.60108 .57858 Mdot
.59003 .49349 Mdot
.45844 .72162 Mdot
.79198 .61624 Mdot
.44277 .3377 Mdot
.64034 .50238 Mdot
.58915 .40599 Mdot
.47807 .66119 Mdot
.43511 .82588 Mdot
.59024 .76455 Mdot
.40499 .41965 Mdot
.65338 .28652 Mdot
.84784 .5017 Mdot
.55384 .84086 Mdot
.39564 .55533 Mdot
.44987 .29418 Mdot
.5526 .68877 Mdot
.81118 .40874 Mdot
.76011 .67547 Mdot
.64042 .72857 Mdot
.42261 .66529 Mdot
.5965 .2479 Mdot
.82444 .67346 Mdot
.86388 .45938 Mdot
.747 .29913 Mdot
.53963 .51412 Mdot
.33708 .47552 Mdot
.41432 .22006 Mdot
.80802 .55216 Mdot
.22182 .66698 Mdot
.53634 .81997 Mdot
.63463 .29069 Mdot
.55403 .16669 Mdot
.23998 .33249 Mdot
.63044 .48037 Mdot
.23535 .41742 Mdot
.34584 .4128 Mdot
.50058 .62177 Mdot
.67412 .33538 Mdot
.61408 .47461 Mdot
.50871 .68035 Mdot
.30429 .70049 Mdot
.37434 .68259 Mdot
.8117 .5426 Mdot
.37152 .24457 Mdot
.43983 .2962 Mdot
.77278 .6379 Mdot
.27979 .56118 Mdot
.78153 .54594 Mdot
.80039 .45188 Mdot
.61646 .47866 Mdot
.61152 .58134 Mdot
.43338 .45366 Mdot
.43986 .61634 Mdot
.45291 .62744 Mdot
.64573 .21759 Mdot
.71626 .40494 Mdot
.36679 .49142 Mdot
.20748 .37624 Mdot
.35589 .55849 Mdot
.72636 .76419 Mdot
.4683 .74425 Mdot
.26415 .33914 Mdot
.49568 .59731 Mdot
.63693 .67211 Mdot
.63592 .19859 Mdot
.41989 .2665 Mdot
.73781 .40806 Mdot
.30306 .48532 Mdot
.31583 .49893 Mdot
.49606 .60206 Mdot
.39413 .69859 Mdot
.33219 .2919 Mdot
.18625 .55275 Mdot
.79779 .44061 Mdot
.36892 .54414 Mdot
.62294 .48708 Mdot
.37758 .42857 Mdot
.61796 .8285 Mdot
.60638 .57537 Mdot
.86587 .42827 Mdot
.54017 .3866 Mdot
.80829 .38704 Mdot
.43768 .82973 Mdot
.40803 .63778 Mdot
.54568 .51262 Mdot
.69209 .6228 Mdot
.41709 .37482 Mdot
.4471 .29037 Mdot
.33241 .50684 Mdot
.81411 .50841 Mdot
.68191 .40817 Mdot
.68804 .29213 Mdot
.55511 .67973 Mdot
.19816 .51681 Mdot
.21176 .61105 Mdot
.30405 .50272 Mdot
.65375 .46211 Mdot
.74726 .5883 Mdot
.54736 .46517 Mdot
.58898 .40872 Mdot
.82033 .56755 Mdot
.37229 .27273 Mdot
.36822 .52162 Mdot
.74726 .30247 Mdot
.61452 .39421 Mdot
.5188 .86494 Mdot
.40332 .45923 Mdot
.58441 .39013 Mdot
.55475 .45097 Mdot
.2871 .69443 Mdot
.31608 .28647 Mdot
.61339 .78928 Mdot
.64211 .26298 Mdot
.49325 .49041 Mdot
.62797 .30818 Mdot
.41023 .43298 Mdot
.57724 .73785 Mdot
.20578 .6321 Mdot
.56596 .1709 Mdot
.24581 .44272 Mdot
.38938 .65516 Mdot
.27248 .55666 Mdot
.19781 .56867 Mdot
.36921 .5029 Mdot
.67533 .47369 Mdot
.36402 .29598 Mdot
.59292 .79446 Mdot
.56702 .8489 Mdot
.53727 .83356 Mdot
.57897 .34706 Mdot
.65313 .72633 Mdot
.4919 .24173 Mdot
.38784 .4531 Mdot
.48528 .54885 Mdot
.41468 .37962 Mdot
.50418 .30116 Mdot
.40195 .57178 Mdot
.25525 .67113 Mdot
.55137 .36089 Mdot
.67185 .77468 Mdot
.516 .86309 Mdot
.74728 .72059 Mdot
.7063 .66299 Mdot
.28863 .55701 Mdot
.86495 .48648 Mdot
.29071 .29024 Mdot
.57911 .8227 Mdot
.24143 .50474 Mdot
.14998 .52641 Mdot
.83793 .45413 Mdot
.56888 .7848 Mdot
.26232 .59035 Mdot
.31279 .75799 Mdot
.44315 .82413 Mdot
.1518 .49247 Mdot
.48218 .25872 Mdot
.42547 .82075 Mdot
.85945 .39292 Mdot
.24663 .48536 Mdot
.35889 .69417 Mdot
.2287 .41579 Mdot
.4608 .25346 Mdot
.17347 .53275 Mdot
.48705 .32304 Mdot
.64345 .59853 Mdot
.73186 .44728 Mdot
.62582 .28389 Mdot
.44768 .46154 Mdot
.16968 .51832 Mdot
.61975 .35734 Mdot
.59517 .33392 Mdot
.75357 .55943 Mdot
.83443 .46748 Mdot
.32623 .28403 Mdot
.40136 .35814 Mdot
.3076 .49063 Mdot
.66337 .41084 Mdot
.5392 .25865 Mdot
.47097 .34175 Mdot
.4947 .56446 Mdot
.56256 .35328 Mdot
.7855 .69903 Mdot
.71615 .48204 Mdot
.59288 .5384 Mdot
.3176 .57547 Mdot
.31755 .72078 Mdot
.75364 .64444 Mdot
.32703 .66019 Mdot
.16839 .49576 Mdot
.39274 .26036 Mdot
.73091 .71787 Mdot
.35806 .6781 Mdot
.58761 .26623 Mdot
.59891 .20204 Mdot
.50397 .65612 Mdot
.34006 .43938 Mdot
.84366 .5341 Mdot
.32381 .677 Mdot
.27611 .5522 Mdot
.53528 .78634 Mdot
.59269 .73679 Mdot
.31493 .68574 Mdot
.42306 .80789 Mdot
.767 .58305 Mdot
.25786 .37437 Mdot
.79401 .63977 Mdot
.63995 .60482 Mdot
.60753 .28157 Mdot
.50493 .78012 Mdot
.17197 .53699 Mdot
.54323 .4668 Mdot
.6338 .80687 Mdot
.49025 .54436 Mdot
.73689 .34213 Mdot
.43631 .3652 Mdot
.35063 .25548 Mdot
.2669 .67784 Mdot
.52197 .79696 Mdot
.30182 .61187 Mdot
.28144 .53898 Mdot
.23014 .63279 Mdot
.70766 .55678 Mdot
.70122 .3329 Mdot
.50411 .26037 Mdot
.23818 .56027 Mdot
.65749 .44577 Mdot
.40488 .72926 Mdot
.53934 .37494 Mdot
.73817 .32927 Mdot
.69224 .69557 Mdot
.32952 .45101 Mdot
.25877 .48184 Mdot
.81421 .57751 Mdot
.72017 .65839 Mdot
.23857 .66638 Mdot
.26121 .49016 Mdot
.34734 .76243 Mdot
.25888 .31323 Mdot
.31989 .64086 Mdot
.5256 .38517 Mdot
.67498 .47334 Mdot
.35603 .54528 Mdot
.79492 .61686 Mdot
.39156 .49898 Mdot
.74162 .35259 Mdot
.44583 .563 Mdot
.74657 .62406 Mdot
.6149 .44272 Mdot
.44104 .82885 Mdot
.31286 .7583 Mdot
.6451 .27624 Mdot
.53467 .68467 Mdot
.44421 .65858 Mdot
.37097 .63788 Mdot
.64185 .78864 Mdot
.3845 .58112 Mdot
.37657 .34979 Mdot
.37741 .66066 Mdot
.35432 .35193 Mdot
.39422 .81585 Mdot
.67193 .29785 Mdot
.48203 .55291 Mdot
.39632 .31206 Mdot
.40158 .7462 Mdot
.39683 .72915 Mdot
.73425 .47483 Mdot
.31461 .27473 Mdot
.56366 .58514 Mdot
.56614 .51175 Mdot
.53144 .34698 Mdot
.40783 .22043 Mdot
.78388 .64523 Mdot
.41425 .54478 Mdot
.48399 .5418 Mdot
.80365 .49328 Mdot
.71316 .33122 Mdot
.30818 .19895 Mdot
.81854 .6587 Mdot
.43695 .36324 Mdot
.5478 .49653 Mdot
.68616 .29605 Mdot
.6643 .53574 Mdot
.33512 .30371 Mdot
.81092 .58832 Mdot
.55012 .65902 Mdot
.76991 .52026 Mdot
.40101 .69561 Mdot
.28442 .7016 Mdot
.77075 .36804 Mdot
.51227 .61656 Mdot
.73877 .75705 Mdot
.5283 .81856 Mdot
.26684 .66982 Mdot
.24329 .24245 Mdot
.24776 .64997 Mdot
.41442 .48805 Mdot
.73915 .57688 Mdot
.76298 .71549 Mdot
.5343 .51985 Mdot
.76022 .53651 Mdot
.26306 .47494 Mdot
.64383 .27099 Mdot
.59877 .30614 Mdot
.28846 .63105 Mdot
.23694 .62585 Mdot
.1498 .47555 Mdot
.63894 .66998 Mdot
.66796 .22374 Mdot
.30747 .3094 Mdot
.80164 .64128 Mdot
.45721 .74934 Mdot
.54191 .16425 Mdot
.55582 .85027 Mdot
.64467 .32695 Mdot
.17702 .5168 Mdot
.72511 .53641 Mdot
.68762 .2757 Mdot
.38827 .21812 Mdot
.43708 .76753 Mdot
.38052 .27121 Mdot
.61743 .67851 Mdot
.31572 .62331 Mdot
.63226 .30705 Mdot
.34958 .38136 Mdot
.48553 .55205 Mdot
.83448 .5718 Mdot
.17253 .45362 Mdot
.61244 .24697 Mdot
.78486 .51449 Mdot
.7032 .28751 Mdot
.76702 .65318 Mdot
.69886 .70613 Mdot
.56687 .45595 Mdot
.82596 .3563 Mdot
.85185 .55248 Mdot
.33326 .64608 Mdot
.51062 .35132 Mdot
.52993 .86789 Mdot
.58587 .45485 Mdot
.26968 .47537 Mdot
.46602 .82084 Mdot
.58357 .30087 Mdot
.55493 .34569 Mdot
.51775 .35336 Mdot
.47453 .24002 Mdot
.26129 .58333 Mdot
.34978 .38862 Mdot
.77909 .40328 Mdot
.61765 .24644 Mdot
.17475 .45709 Mdot
.77369 .35169 Mdot
.40819 .46525 Mdot
.3623 .52574 Mdot
.77261 .70854 Mdot
.40669 .28624 Mdot
.39758 .33274 Mdot
.23874 .3828 Mdot
.38237 .57638 Mdot
.64955 .62567 Mdot
.45524 .29425 Mdot
.42601 .63592 Mdot
.62141 .28757 Mdot
.80203 .56735 Mdot
.34854 .44533 Mdot
.86132 .36749 Mdot
.43928 .83349 Mdot
.37289 .53437 Mdot
.29254 .45599 Mdot
.62886 .4755 Mdot
.75496 .70999 Mdot
.63112 .65927 Mdot
.79846 .44792 Mdot
.19894 .37854 Mdot
.65492 .25667 Mdot
.46514 .43597 Mdot
.44181 .79209 Mdot
.58482 .83515 Mdot
.17649 .41088 Mdot
.61583 .82132 Mdot
.55039 .3931 Mdot
.50032 .31794 Mdot
.5269 .12955 Mdot
.711 .72813 Mdot
.51531 .44853 Mdot
.26955 .59071 Mdot
.27162 .58055 Mdot
.42959 .36319 Mdot
.37843 .69557 Mdot
.54235 .24326 Mdot
.5999 .31533 Mdot
.68383 .77074 Mdot
.31931 .57277 Mdot
.52493 .53383 Mdot
.56746 .61623 Mdot
.51722 .52553 Mdot
.39612 .40009 Mdot
.56167 .63709 Mdot
.60237 .32603 Mdot
.58018 .46728 Mdot
.57838 .67168 Mdot
.46168 .26648 Mdot
.42312 .72361 Mdot
.47056 .27345 Mdot
.59095 .36769 Mdot
.26171 .50686 Mdot
.27456 .2839 Mdot
.62021 .35526 Mdot
.62559 .37193 Mdot
.42467 .81682 Mdot
.21943 .69577 Mdot
.51406 .56356 Mdot
.3566 .46691 Mdot
.40932 .47695 Mdot
.30552 .28521 Mdot
.24821 .37816 Mdot
.58772 .61754 Mdot
.39379 .72701 Mdot
.55066 .36744 Mdot
.39659 .30769 Mdot
.55312 .61549 Mdot
.80375 .69348 Mdot
.50344 .32945 Mdot
.29738 .33961 Mdot
.62476 .79649 Mdot
.78644 .54143 Mdot
.52727 .29085 Mdot
.41524 .37438 Mdot
.43592 .5015 Mdot
.58588 .46265 Mdot
.37086 .39883 Mdot
.80049 .52704 Mdot
.76547 .68206 Mdot
.54232 .29153 Mdot
.28773 .34009 Mdot
.45611 .39363 Mdot
.69307 .36263 Mdot
.43328 .61138 Mdot
.64999 .22797 Mdot
.73837 .39101 Mdot
.55401 .83751 Mdot
.59921 .36394 Mdot
.58706 .30141 Mdot
.21754 .40681 Mdot
.82595 .62459 Mdot
.36806 .64632 Mdot
.27564 .33828 Mdot
.40927 .58256 Mdot
.53776 .76425 Mdot
.62853 .3452 Mdot
.52274 .59767 Mdot
.53424 .33242 Mdot
.26159 .57547 Mdot
.67503 .79147 Mdot
.41794 .26811 Mdot
.58256 .61655 Mdot
.60209 .77689 Mdot
.25941 .31566 Mdot
.53434 .50578 Mdot
.20122 .28395 Mdot
.64574 .64628 Mdot
.7445 .75089 Mdot
.78788 .57097 Mdot
.5244 .46804 Mdot
.29952 .69408 Mdot
.45468 .45707 Mdot
.63472 .54368 Mdot
.75976 .69917 Mdot
.37943 .4211 Mdot
.31062 .63781 Mdot
.47998 .32675 Mdot
.43675 .51653 Mdot
.37604 .36534 Mdot
.63572 .74028 Mdot
.62872 .59708 Mdot
.39189 .5617 Mdot
.69648 .71364 Mdot
.58815 .46071 Mdot
.15654 .5573 Mdot
.84846 .53035 Mdot
.68373 .75062 Mdot
.67648 .70892 Mdot
.41847 .17199 Mdot
.29947 .48845 Mdot
.38373 .44872 Mdot
.51439 .67863 Mdot
.48518 .24079 Mdot
.31733 .6809 Mdot
.8026 .55798 Mdot
.33752 .75893 Mdot
.55246 .46231 Mdot
.13775 .36871 Mdot
.6369 .32326 Mdot
.41809 .52879 Mdot
.29839 .66859 Mdot
.66133 .78012 Mdot
.78355 .46889 Mdot
.34626 .78331 Mdot
.46803 .76034 Mdot
.40792 .42539 Mdot
.36797 .23182 Mdot
.75519 .32124 Mdot
.62498 .72854 Mdot
.65673 .21327 Mdot
.64684 .74575 Mdot
.5545 .25511 Mdot
.5157 .79413 Mdot
.35692 .55974 Mdot
.35027 .57729 Mdot
.46781 .73691 Mdot
.41559 .70295 Mdot
.31466 .46903 Mdot
.75082 .69183 Mdot
.53731 .19352 Mdot
.80709 .467 Mdot
.72615 .73254 Mdot
.49835 .70427 Mdot
.27134 .56028 Mdot
.61549 .35827 Mdot
.6984 .43533 Mdot
.67481 .54842 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0Yoooool2o`000:3ooooo000Looooo`03o`00
0?oooooooooo0:Oooooo0_l0002Pooooo`007?ooool00ol0003oooooooooo`2<ooooo`;o0000^ooo
ool001cooooo00?o0000ooooooooool0S?ooool2o`000;_ooooo000Looooo`03o`000?oooooooooo
09Oooooo0_l0002`ooooo`007?ooool00ol0003oooooooooo`2Gooooo`;o0000/?ooool001cooooo
00?o0000ooooooooool0POooool2o`0002_ooooo0_l0002Iooooo`007?ooool2o`0008;ooooo0_l0
0007ooooo`;o00006_ooool3o`0000Gooooo0_l0002Iooooo`007?ooool00ol0003oooooooooo`2:
ooooo`;o00005Oooool2o`0000?ooooo0ol0002Pooooo`007?ooool00ol0003oooooooooo`2:oooo
o`;o00005Oooool2o`000:Kooooo000Looooo`03o`000?oooooooooo08[ooooo0_l0002mooooo`00
7?ooool00ol0003oooooooooo`2Cooooo`;o00005oooool2o`0001?ooooo0_l00026ooooo`007?oo
ool00ol0003oooooooooo`1`ooooo`;o00002_ooool4o`0001?ooooo0_l0000Gooooo`;o00000_oo
ool2o`0000oooooo0_l00026ooooo`007?ooool00ol0003oooooooooo`1`ooooo`;o00001oooool2
o`000003ooooool0003o000000;o00001?ooool2o`0002[ooooo1_l0002Cooooo`007?ooool00ol0
003oooooooooo`1iooooo`;o00002Oooool2o`0002cooooo1?l0002Cooooo`007?ooool00ol0003o
ooooooooo`23ooooo`;o00000_ooool2o`000<3ooooo000Looooo`03o`000?oooooooooo06oooooo
0_l00004ooooo`;o00003?ooool2o`0000;ooooo0_l00010ooooo`;o0000O_ooool001cooooo00?o
0000ooooooooool0Koooool2o`000004ooooool0003o0000ooooo`;o0000A_ooool2o`0000[ooooo
0_l0001nooooo`007?ooool00ol0003oooooooooo`1Zooooo`;o00001_ooool2o`0004Wooooo1Ol0
0027ooooo`007?ooool00ol0003oooooooooo`1Zooooo`;o0000D_ooool4o`0000Cooooo0_l00021
ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o
0000ooooooooool0J?ooool2o`00047ooooo1Ol0000Fooooo`;o0000POooool00006oooooomgMgOo
V9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03
o`000?oooooooooo06Sooooo0_l00011ooooo`Go00001?ooool2o`0009?ooooo00000ooooooo410@
ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003ooooo
ooooo`1Pooooo`;o00002Oooool2o`00043ooooo0_l00005ooooo`;o00005Oooool2o`0007cooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_oo
ool3o`00063ooooo0_l000000ooooooo0000o`000006ooooo`;o0000@?ooool2o`00013ooooo0_l0
000:ooooo`;o0000O?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool0
0omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo06?ooooo0_l0001@ooooo`Co00001_ooool2
o`0000Oooooo0_l0001oooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0=oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Hoooool2o`0000;ooooo0_l0001<oooo
o`Co00003oooool3o`0007kooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000
okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo06Oooooo0_l0001Pooooo`;o0000O_oo
ool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Ko
oooo00?o0000ooooooooool0J_ooool2o`0002Cooooo0_l0000Hooooo`;o00001oooool2o`0000Oo
oooo0_l0000Dooooo`;o0000MOooool001cooooo00?o0000ooooooooool0J_ooool2o`0000Sooooo
0_l00004ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0000Wooooo0_l000000ooooooo
0000o`000003o`000003ooooool0003o000001;ooooo0_l00006ooooo`?o00001oooool4o`0000ko
oooo0_l00002ooooo`;o0000MOooool001cooooo00?o0000ooooooooool0M?ooool3o`0000?ooooo
2ol00008ooooo`;o000000?oooooo`000?l000000ol000001?oooooo0000o`000?ooool5o`0000go
oooo0_l00005ooooo`?o000000Coooooo`000?l0003ooooo0ol00002ooooo`?o00002?ooool2o`00
00?ooooo0_l0001iooooo`007?ooool00ol0003oooooooooo`1Rooooo`;o00004Oooool2o`0000Co
oooo0_l00002ooooo`Ko00000_ooool2o`00013ooooo1Ol000000ooooooo0000o`00000:ooooo`;o
000000?oooooo`000?l000001Oooool7o`000003ooooool0003o000000?o00001?ooool5o`0000[o
oooo0_l0001booooo`007?ooool00ol0003oooooooooo`1Qooooo`?o00007oooool2o`0000;ooooo
0_l0000Dooooo`Oo000000Coooooo`000?l0003ooooo0_l00004ooooo`;o00000oooool6o`0000Co
oooo1Ol00003ooooo`Go00002Oooool5o`00077ooooo000Looooo`03o`000?oooooooooo057ooooo
0_l0000>ooooo`;o00003oooool2o`0000oooooo0_l0000Hooooo`[o000000?oooooo`000?l00000
0_ooool3o`0000Cooooo1?l0000>ooooo`;o00002?ooool2o`0000;ooooo0_l000000ooooooo0000
o`00001aooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o00005oooool2o`0000Kooooo1?l0
000Yooooo`Oo00001_ooool4o`000003ooooool0003o000000;o00000oooool2o`0000_ooooo0_l0
0008ooooo`;o0000N?ooool001cooooo00?o0000ooooooooool0G?ooool2o`0000cooooo0_l00008
ooooo`;o00003Oooool2o`0001[ooooo0_l00003ooooo`Co00001Oooool3o`000003ooooool0003o
000000Co000000?oooooo`000?l000003?ooool2o`000003ooooool0003o000007kooooo000Loooo
o`03o`000?oooooooooo04kooooo0_l0000<ooooo`;o00007_ooool2o`0000;ooooo1Ol0000Aoooo
o`;o00001oooool2o`0000Gooooo0_l0000;ooooo`Co00002_ooool2o`0000?ooooo0_l000000ooo
oooo0000o`000002ooooo`;o0000N_ooool001cooooo00?o0000ooooooooool0Boooool2o`000003
ooooool0003o000001Wooooo0_l0000Aooooo`;o00000_ooool6o`0000;ooooo0_l00002ooooo`;o
00001_ooool4o`0000;ooooo1?l00006ooooo`;o00001Oooool2o`0000Wooooo0_l000000ooooooo
0000o`000006ooooo`;o000000?oooooo`000?l000001oooool4o`0007Sooooo000Looooo`03o`00
0?oooooooooo04_ooooo0_l0000Iooooo`;o000000?oooooo`000?l000002_ooool2o`0000Gooooo
0_l000001?oooooo0000o`000?l00002ooooo`;o00000_ooool2o`0000;ooooo0_l00006ooooo`;o
000000Coooooo`000?l0003ooooo1?l00006ooooo`;o00001?ooool4o`0000Gooooo0_l000000ooo
oooo0000o`000003o`0000?ooooo0_l00004ooooo`;o00001_ooool5o`0000Kooooo0_l00009oooo
o`;o0000IOooool001cooooo00?o0000ooooooooool0IOooool3o`0000Gooooo0_l00006ooooo`Co
00000_ooool9o`0001?ooooo0_l0000Aooooo`Co00001Oooool2o`0000?ooooo0_l00004ooooo`;o
00000oooool4o`0000Gooooo1?l000000ooooooo0000o`000004ooooo`;o00000oooool2o`0000Co
oooo0_l0001Uooooo`007?ooool2o`0006Cooooo1?l00006ooooo`;o00002?ooool2o`0000;ooooo
0_l000000ooooooo0000o`000002ooooo`;o00001Oooool2o`00027ooooo0_l00005ooooo`;o0000
2Oooool2o`0000?ooooo1?l00006ooooo`;o000000Coooooo`000?l0003o00002Oooool2o`0006_o
oooo000Looooo`03o`000?oooooooooo06?ooooo0_l00009ooooo`;o000000?oooooo`000?l00000
3_ooool2o`0000Kooooo0_l00007ooooo`;o00000oooool3o`00013ooooo0_l00004ooooo`;o0000
00?oooooo`000?l000005?ooool2o`0000;ooooo0_l000001?oooooo0000o`000?l00009ooooo`;o
0000Joooool001cooooo00?o0000ooooooooool0E?ooool2o`0000Oooooo0_l00004ooooo`;o0000
2?ooool7o`000003ooooool0003o000000[ooooo0_l0000?ooooo`;o00000oooool3o`00013ooooo
0_l00004ooooo`;o000000?oooooo`000?l000000oooool2o`0000oooooo0_l000000ooooooo0000
o`000003ooooo`Co00001oooool2o`0006_ooooo000Looooo`03o`000?oooooooooo05?ooooo0ol0
0007ooooo`;o00001?ooool2o`0000Oooooo0ol000000ooooooo0000o`000002o`000004ooooool0
003o0000o`0000Cooooo1Ol0000<ooooo`;o00002_ooool5o`0000;ooooo0_l00009ooooo`;o0000
00?oooooo`000?l000000_l000000ooooooo0000o`000003ooooo`;o00004_ooool2o`0000;ooooo
2Ol0001`ooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00001Oooool2o`00013ooooo0_l0
0008ooooo`;o00001?ooool5o`0000Cooooo0_l00006ooooo`;o00002_ooool5o`0000;ooooo0_l0
0009ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`00000Hooooo`;o000000?o
ooooo`000?l000000_ooool5o`00073ooooo000Looooo`03o`000?oooooooooo05Wooooo0ol0000Y
ooooo`;o00002oooool2o`0000Gooooo0_l00004ooooo`;o00004Oooool2o`0000?ooooo0_l00002
ooooo`;o00001Oooool2o`0000Oooooo1?l00005ooooo`;o00000oooool2o`0006kooooo000Loooo
o`03o`000?oooooooooo05Wooooo0_l0000?ooooo`;o00006?ooool3o`0000Oooooo0_l00002oooo
o`;o00001Oooool4o`000004ooooool0003o0000o`00017ooooo0_l00003ooooo`;o00000_ooool2
o`0000Gooooo0_l00007ooooo`?o00002oooool2o`0006kooooo000Looooo`03o`000?oooooooooo
05Oooooo0_l0000=ooooo`;o000000Coooooo`000?l0003o00002Oooool2o`000003ooooool0003o
000000[ooooo0ol00004ooooo`;o000000?oooooo`000?l000001Oooool4o`0000;ooooo0_l00000
0ooooooo0000o`000002o`0000Cooooo0_l00002ooooo`;o00007oooool5o`0007Wooooo000Loooo
o`03o`000?oooooooooo05Oooooo0_l00009ooooo`;o00000_ooool2o`000003ooooool0003o0000
00[ooooo0_l000000ooooooo0000o`00000Aooooo`;o00002?ooool4o`0000Gooooo1?l00004oooo
o`;o00000_ooool2o`0000Wooooo0_l00009ooooo`;o00001oooool7o`0000cooooo0_l0001[oooo
o`007?ooool00ol0003oooooooooo`1;ooooo`;o00003Oooool2o`0000Kooooo0_l00007ooooo`;o
00009Oooool2o`0000[ooooo0_l00006ooooo`;o00000oooool2o`0000Sooooo0_l00009ooooo`;o
00000oooool2o`0000;ooooo1?l000000ooooooo0000o`00000<ooooo`;o00002Oooool2o`00063o
oooo000Looooo`03o`000?oooooooooo04_ooooo0_l0000=ooooo`;o000000?oooooo`000?l00000
3?ooool2o`00017ooooo0_l0000Booooo`;o00001Oooool2o`0000_ooooo0_l00003ooooo`;o0000
1Oooool4o`0000cooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l00000
0_ooool2o`0001?ooooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00004Ooo
ool2o`0000;ooooo0ol00005ooooo`Go00001?ooool2o`0000Kooooo0_l0000>ooooo`Go00002ooo
ool2o`0000Wooooo0_l00008ooooo`Co00000_ooool2o`0000Oooooo1?l0000<ooooo`;o00001?oo
ool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000003ooooo`;o00008_oo
ool2o`0004cooooo000Looooo`03o`000?oooooooooo03kooooo0_l00008ooooo`;o00001oooool2
o`000003ooooool0003o000000;o00001_ooool4o`000004ooooool0003o0000ooooo`;o00001_oo
ool2o`00013ooooo0ol0000;ooooo`;o00004oooool4o`0000;ooooo0_l0000;ooooo`;o00003_oo
ool4o`000003ooooool0003o000000;ooooo0ol000000ooooooo0000o`000002ooooo`;o00002?oo
ool2o`0001Sooooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`18ooooo`;o00002_ooool2
o`0000Gooooo0_l00002ooooo`Ko000000?oooooo`000?l000000_l0000Sooooo`;o00001?ooool2
o`0000cooooo0_l00005ooooo`;o00000_ooool2o`0000Sooooo0_l00003ooooo`;o00002Oooool6
o`0000Cooooo0_l000000ooooooo0000o`000007ooooo`;o00000oooool4o`0006Cooooo000Loooo
o`03o`000?oooooooooo05_ooooo0_l00002ooooo`Co000000?oooooo`000?l000001?l00008oooo
o`;o00004oooool2o`0000Cooooo1Ol000000ooooooo0000o`00000;ooooo`?o00001Oooool2o`00
00;ooooo0_l00003ooooo`;o00002?ooool2o`0000[ooooo1_l00007ooooo`;o00000_ooool2o`00
00;ooooo0_l00005ooooo`;o00001_ooool2o`0005cooooo000Looooo`03o`000?oooooooooo05go
oooo1?l00002ooooo`?o00002?ooool2o`0000;ooooo0ol0000Booooo`;o00000_ooool2o`000003
ooooool0003o000000;o00000_ooool2o`0000Gooooo0_l00002ooooo`?o00003oooool2o`0000Wo
oooo1?l00006ooooo`;o00000oooool2o`0000Kooooo1ol000000ooooooo0000o`000007ooooo`?o
00001?ooool2o`0005cooooo000Looooo`;o0000>_ooool2o`0002;ooooo0_l00004ooooo`;o0000
2Oooool2o`0000?ooooo0_l0000;ooooo`;o00002Oooool2o`0000Oooooo0_l00003ooooo`Co0000
0_ooool3o`0001Sooooo1_l00006ooooo`;o00002oooool7o`000003ooooool0003o000000Cooooo
1_l00006ooooo`Co0000F?ooool001cooooo00?o0000ooooooooool0>Oooool2o`0002kooooo0_l0
000Eooooo`;o00001_ooool2o`0000?ooooo0_l0000:ooooo`;o00001Oooool2o`0001Sooooo0ol0
000<ooooo`;o00005_ooool3o`0000Wooooo1?l0001Hooooo`007?ooool00ol0003oooooooooo`12
ooooo`;o00004?ooool2o`0000Cooooo0_l00003ooooo`;o00002?ooool2o`0001;ooooo1?l00007
ooooo`?o00000_ooool2o`0000[ooooo0_l0000@ooooo`;o00003_ooool2o`0000;ooooo0_l00006
ooooo`Ko00000oooool2o`00013ooooo0_l00002ooooo`;o00001oooool2o`0005Sooooo000Loooo
o`03o`000?oooooooooo043ooooo1?l00009ooooo`;o00001Oooool2o`0000Cooooo0_l00003oooo
o`?o000000?oooooo`000?l000004?ooool3o`0000Gooooo1?l00004ooooo`;o00000_ooool2o`00
00Gooooo0_l00007ooooo`?o00003oooool2o`0000;ooooo0_l0000>ooooo`?o00001Oooool6o`00
00?ooooo0_l00003ooooo`;o00003?ooool2o`000003ooooool0003o0000067ooooo000Looooo`03
o`000?oooooooooo043ooooo0_l0000;ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;o
oooo0_l00006ooooo`;o000000?oooooo`000?l000000_ooool2o`0000cooooo0ol00005ooooo`;o
00001_ooool3o`0000;ooooo0ol00002ooooo`?o00001?ooool3o`000003ooooool0003o000000So
oooo0_l00006ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Sooooo0_l00006ooooo`;o
00001Oooool2o`0000?ooooo0ol0000<ooooo`;o0000I?ooool001cooooo00?o0000ooooooooool0
<Oooool2o`0001gooooo0ol00005ooooo`;o00003Oooool2o`0001Cooooo0_l00007ooooo`;o0000
0_ooool3o`0000;ooooo0ol00002ooooo`So00002?ooool2o`0000?ooooo0_l000000ooooooo0000
o`000008ooooo`;o00001oooool2o`0000Kooooo0ol00005ooooo`;o00000oooool2o`0000?ooooo
0_l000000ooooooo0000o`000005o`0006Kooooo000Looooo`03o`000?oooooooooo037ooooo0_l0
0002ooooo`;o00006_ooool2o`000003ooooool0003o000000;ooooo0_l0000fooooo`Oo000000?o
ooooo`000?l000001?l000000ooooooo0000o`000004ooooo`;o00000_ooool2o`0001Cooooo0_l0
0006ooooo`?o00001_ooool2o`0000Oooooo0_l000000ooooooo0000o`000005o`0000Kooooo0_l0
001Nooooo`007?ooool00ol0003oooooooooo`0eooooo`;o00006Oooool2o`0000;ooooo0_l0000/
ooooo`Co00000_ooool4o`000004ooooool0003o0000ooooo`Oo000000?oooooo`000?l000001?l0
00000ooooooo0000o`000002o`000003ooooool0003o000000?o00002?ooool2o`0001Sooooo0_l0
0003ooooo`?o00001Oooool2o`0000Gooooo1?l00004ooooo`Co00001_ooool2o`0005Kooooo000L
ooooo`03o`000?oooooooooo053ooooo0_l00002ooooo`Go00006?ooool2o`0000oooooo1?l00002
ooooo`Co000000Coooooo`000?l0003ooooo1Ol000000ooooooo0000o`000006o`000003ooooool0
003o000000;o000000Coooooo`000?l0003ooooo0_l00008ooooo`;o00001?ooool2o`0000Oooooo
0_l00007ooooo`Co00001?ooool2o`0000Gooooo0ol00005ooooo`;o00000_ooool2o`000004oooo
ool0003o0000ooooo`;o00001Oooool2o`0005Kooooo000Looooo`03o`000?oooooooooo04Sooooo
0_l00008ooooo`Oo00006?ooool3o`00013ooooo0_l000000ooooooo0000o`000004o`0000;ooooo
1Ol000000ooooooo0000o`00000:o`000003ooooool0003o000000;o00004Oooool2o`0000Oooooo
0_l00007ooooo`;o00000oooool2o`0000Wooooo0ol00004ooooo`;o00000_ooool2o`0000Cooooo
1?l0001Kooooo`007?ooool00ol0003oooooooooo`18ooooo`Co00001_ooool5o`0000Gooooo0_l0
000Dooooo`;o00003_ooool3o`0000;ooooo0ol000000ooooooo0000o`000002ooooo`co000000?o
ooooo`000?l000002?l00002ooooo`Co00004_ooool2o`0000kooooo0_l0000:ooooo`;o00002?oo
ool2o`000004ooooool0003o0000ooooo`Co0000Foooool001cooooo00?o0000ooooooooool0A_oo
ool2o`0000;ooooo0_l00009ooooo`;o000000?oooooo`000?l000000_ooool2o`0001cooooo0_l0
00000ooooooo0000o`000003ooooo`Oo00000_ooool2o`0000?ooooo2ol000000ooooooo0000o`00
0008o`0000;ooooo1?l0000Booooo`;o00005oooool2o`0000Oooooo0_l00002ooooo`;o000000Co
ooooo`000?l0003ooooo1?l00008ooooo`;o0000DOooool001cooooo00?o0000ooooooooool0A_oo
ool2o`0000kooooo1?l0000Kooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo0_l0
00000ooooooo0000o`000003o`000003ooooool0003o000000[o000000?oooooo`000?l000000_l0
0003ooooo`Go000000?oooooo`000?l000000oooool2o`0000kooooo0_l00003ooooo`;o00005ooo
ool2o`0000Oooooo0_l00002ooooo`;o00001_ooool2o`0000Cooooo0_l00002ooooo`;o0000DOoo
ool001cooooo00?o0000ooooooooool0B?ooool4o`0000Kooooo0_l00002ooooo`;o00000_ooool2
o`000003ooooool0003o000001Kooooo0_l00003ooooo`;o00001OoooolTo`0000?ooooo0ol0000>
ooooo`;o0000:Oooool3o`0000_ooooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`18oooo
o`Co00001Oooool3o`0000Cooooo1?l000000ooooooo0000o`00000Kooooo`Co00001Oooool3o`00
0003ooooool0003o000000Go000000?oooooo`000?l000005?l00003ooooo`?o0000>_ooool2o`00
0003ooooool0003o000000;ooooo0_l0000@ooooo`;o0000BOooool001cooooo00?o0000oooooooo
ool0COooool2o`0000;ooooo0_l00005ooooo`;o00008_ooool4o`0000?ooooo0ol000000ooooooo
0000o`00000Ko`0000Cooooo0ol00002ooooo`;o000000?oooooo`000?l000000oooool2o`000004
ooooool0003o0000ooooo`;o00000_ooool2o`0000Kooooo1?l0000Hooooo`;o00000oooool2o`00
00;ooooo0_l0000@ooooo`;o0000BOooool001cooooo0_l0001>ooooo`;o0000:?ooool2o`0000?o
oooo1?l00003ooooo`go000000?oooooo`000?l000004_l00003ooooo`?o00000_ooool2o`000003
ooooool0003o000000?ooooo1Ol000000ooooooo0000o`000002ooooo`;o00001_ooool4o`0000Go
oooo0_l0000Aooooo`;o00006oooool2o`0004Oooooo000Looooo`03o`000?oooooooooo06oooooo
0_l00002ooooo`;o00000_ooool3o`0000Wooooo0_l000000ooooooo0000o`00000No`0000;ooooo
1?l00007ooooo`;o000000?oooooo`000?l000003_ooool3o`0000Cooooo0_l000000ooooooo0000
o`00000Kooooo`?o00002?ooool2o`0000Kooooo0_l00017ooooo`007?ooool00ol0003ooooooooo
o`14ooooo`;o00001Oooool2o`0002;ooooo0ol000000ooooooo0000o`000003ooooo`;o00003?oo
ool@o`000003ooooool0003o000000ko00000oooool2o`0000;ooooo0_l00003ooooo`Co00003ooo
ool2o`0000Gooooo1?l0000Looooo`?o00002?ooool2o`0000kooooo0_l0000oooooo`007?ooool0
0ol0003oooooooooo`0/ooooo`?o00005Oooool2o`0000Gooooo0ol00006ooooo`;o00006?ooool4
o`0000gooooo0_l000000ooooooo0000o`000002ooooo`[o000000?oooooo`000?l000005_l00005
ooooo`;o00001?ooool3o`0000gooooo1?l00004ooooo`;o000000?oooooo`000?l000004Oooool2
o`0000Kooooo0_l00008ooooo`;o00004_ooool2o`0003oooooo000Looooo`03o`000?oooooooooo
02cooooo0ol0000Dooooo`;o00000_ooool2o`0000?ooooo0_l00006ooooo`;o00006?ooool2o`00
00_ooooo0_l000001Ooooooo0000o`000?l0003ooooo01;o000000?oooooo`000?l000000ol00000
0ooooooo0000o`00000<o`0000Kooooo0_l0000Cooooo`Co00001?ooool2o`0000oooooo1ol00004
ooooo`Co00002?ooool3o`0005;ooooo000Looooo`03o`000?oooooooooo04?ooooo0_l00002oooo
o`Co000000?oooooo`000?l00000:?ooool2o`0000?ooooo1Ol000000ooooooo0000o`00000To`00
0003ooooool0003o000000Gooooo0_l00005ooooo`;o000000?oooooo`000?l000001?ooool2o`00
01cooooo1_l00005ooooo`Co00002Oooool2o`0005;ooooo000Looooo`03o`000?oooooooooo02Wo
oooo0_l0000Jooooo`;o00000_ooool5o`0002?ooooo0_l00003ooooo`;o00001Oooool2o`0000;o
oooo0_l00004ooooob?o00000oooool4o`000003ooooool0003o000000;ooooo0_l000001?oooooo
0000o`000?ooool2o`000003ooooool0003o000000Kooooo0_l0000Booooo`Wo00000oooool2o`00
0004ooooool0003o0000o`0000[ooooo0_l0000Jooooo`?o0000<oooool001cooooo00?o0000oooo
ooooool0:Oooool2o`0001[ooooo0_l00003ooooo`;o00009Oooool2o`0001Cooooo8_l00004oooo
o`Co000000?oooooo`000?l000000_l00002ooooo`;o00000_ooool2o`0000Wooooo0_l0000Boooo
o`Wo000000?oooooo`000?l000000_l00002ooooo`?o00002Oooool2o`0001[ooooo0ol0000coooo
o`007?ooool00ol0003oooooooooo`15ooooo`;o00002Oooool2o`0002cooooo0_l00003ooooobGo
00000_ooool5o`0000Cooooo0ol00002ooooo`;o00003Oooool2o`0000kooooo3Ol000000ooooooo
0000o`000002o`0000?ooooo0_l00008ooooo`;o00002?ooool2o`0000[ooooo0_l0000kooooo`00
7?ooool00ol0003oooooooooo`0mooooo`;o000000?oooooo`000?l000001oooool2o`0000;ooooo
0_l000000ooooooo0000o`000006ooooo`;o00005_ooool2o`0000Kooooo0_l000001?oooooo0000
o`000?ooool2o`0000?ooooo9Ol00002ooooo`Go000000Coooooo`000?l0003ooooo0_l000000ooo
oooo0000o`00000@ooooo`;o00002OoooolCo`0000Gooooo0_l00009ooooo`?o00001oooool2o`00
00[ooooo0_l00005ooooo`;o0000=?ooool001cooooo00?o0000ooooooooool0?Oooool2o`000003
ooooool0003o000000Cooooo1Ol00002ooooo`;o00002Oooool2o`0001Cooooo1?l00006ooooo`Go
00000_ooool6o`000003ooooool0003o000000ko000000?oooooo`000?l000003ol00008ooooo`;o
00000_ooool4o`0000kooooo1?l00008oooooaCo00001Oooool2o`0000[ooooo0_l0000Jooooo`;o
0000=?ooool001cooooo00?o0000ooooooooool0@?ooool2o`000004ooooool0003o0000ooooo`Ko
00008_ooool4o`0000Oooooo0ol00003ooooo`Ko00000ooooolSo`000003ooooool0003o000000Ko
oooo0_l00002ooooo`;o00003?ooool2o`0000[ooooo5?l0000Booooo`;o00003_ooool2o`0003oo
oooo000Looooo`03o`000?oooooooooo03cooooo0_l00005ooooo`;o000000?oooooo`000?l00000
0_ooool2o`0000cooooo0_l0000Eooooo`?o00001?ooool2o`000004ooooool0003o0000ooooo`Co
00000_ooool3o`0000;ooooo:Ol00004ooooo`?o000000?oooooo`000?l000006?oooolFo`0000Wo
oooo0_l00005ooooo`;o00002Oooool2o`0000?ooooo0_l0000oooooo`007?ooool00ol0003ooooo
ooooo`0kooooo`?o00002?ooool2o`0000oooooo0ol0000Dooooo`Co00001?ooool2o`000003oooo
ool0003o000000Oo000000?oooooo`000?l000009Ol000000ooooooo0000o`000003o`0000Cooooo
2?l00008ooooo`?o00003?ooool6o`000003ooooool0003o000000go000000?oooooo`000?l00000
0_l00003ooooo`;o00001?ooool2o`0000[ooooo1?l00012ooooo`0000Koooooonk^k_lb<S;o0000
oc8b<_o^k^h5ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000oooooooo
ool0>oooool2o`000003ooooool0003o0000017ooooo0_l00004ooooo`;o00005Oooool4o`0000Oo
oooo1Ol00002ooooob_o00001?ooool2o`0000Gooooo0_l00002ooooo`?o00000oooool2o`0000;o
oooo0ol0000:oooooaSo000000?oooooo`000?l000000_l00009ooooo`;o00003?ooool4o`0000;o
oooo0_l00006ooooo`;o0000=?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q
8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0nooooo`;o00004Oooool2o`00
01gooooo0_l0000?ooooob;o00000_ooool7o`0000?ooooo0_l00007ooooo`;o000000?oooooo`00
0?l000000oooool2o`0000;ooooo0_l0000;oooooaKo00008?ooool2o`0000;ooooo0_l00006oooo
o`?o0000<oooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool5o`0000Ko
oooo00?o0000ooooooooool0J?ooool2o`0000_ooooo0_l00006ooooo`;o00000oooool2o`000003
ooooool0003o000000Go000000?oooooo`000?l000005?l000000ooooooo0000o`000009o`0000Wo
oooo0_l0000:ooooo`;o00002?ooool2o`0000;ooooo5Ol00002ooooo`;o00008oooool2o`0000Co
oooo0_l0000cooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04odA4
A?oMgMgoooooo`0000Oooooo0ol0001Xooooo`;o00001?ooool2o`0000Gooooo0_l00006ooooo`?o
00000_ooool4o`000003ooooool0003o000001Wo000000?oooooo`000?l000001Ol000000ooooooo
0000o`000002o`000003ooooool0003o000000?ooooo0_l0000;ooooo`;o00002_ooool2o`000003
ooooool0003o000001Go000000Coooooo`000?l0003ooooo0_l0000;ooooo`;o00004oooool2o`00
00Cooooo0_l0000cooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04
omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0=oooool2o`000004ooooool0003o0000
ooooo`;o00001_ooool2o`0002Oooooo0_l0000>ooooo`;o00000_oooolMo`000003ooooool0003o
000000Go00000oooool2o`0000;ooooo1?l00003ooooo`Co00000oooool2o`0000;ooooo1?l0000=
ooooo`Oo000000?oooooo`000?l000003Ol00004ooooo`;o00002oooool2o`0001Wooooo0_l0000c
ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co0000
00Oooooo00?o0000ooooooooool0=oooool2o`000004ooooool0003o0000ooooo`Co00000_ooool4
o`0000kooooo0_l0000Gooooo`;o00003_ooool2o`000003ooooool0003o000000Ko000000?ooooo
o`000?l000006ol00003ooooo`;o00000_ooool3o`0000Kooooo0_l00003ooooo`?o000000?ooooo
o`000?l000004?oooolEo`0000Gooooo0_l0000:ooooo`;o00001?ooool2o`0000Cooooo0ol00012
ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o
0000ooooooooool0=_ooool2o`0000Kooooo0ol00002ooooo`;o00004?ooool2o`0002Oooooo0_l0
00001?oooooo0000o`000?oooolLo`000003ooooool0003o000000?o00002Oooool2o`0000Gooooo
0_l00004ooooo`?o00004ooooolDo`0000Kooooo0_l0000:ooooo`;o00001?ooool2o`0000Cooooo
0ol00012ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Ko
oooo00?o0000ooooooooool08Oooool2o`0001?ooooo0_l0000;ooooo`;o00009oooool3o`0000?o
oooo0_l0000<ooooo`Ko000000?oooooo`000?l000007ol0000>ooooo`;o00005oooool2o`000003
ooooool0003o000001;o000000?oooooo`000?l000006?ooool2o`0004Kooooo000Looooo`03o`00
0?oooooooooo027ooooo0_l0000Eooooo`;o00003Oooool4o`00027ooooo0ol00003ooooo`;o0000
1?ooool2o`0000Kooooo1Ol000000ooooooo0000o`00000Ko`000003ooooool0003o000000Co0000
3_ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000002oooool3o`000003
ooooool0003o0000013o000000?oooooo`000?l000000_l000000ooooooo0000o`00000Eooooo`;o
00000_ooool2o`0000kooooo0_l0000booooo`007?ooool00ol0003oooooooooo`0hooooo`;o0000
3Oooool4o`00023ooooo0_l00004ooooo`;o00001Oooool2o`000003ooooool0003o000000?ooooo
1Ol000000ooooooo0000o`000002o`0000;ooooo5ol000001?oooooo0000o`000?ooool3o`0000go
oooo0ol000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000_ooooo0_l00003oooo
o`?o000000?oooooo`000?l000003_l00003ooooo`;o00006Oooool2o`0000Kooooo0_l00006oooo
o`;o0000<_ooool001cooooo00?o0000ooooooooool0>Oooool2o`0001;ooooo0_l0000Iooooo`;o
000000?oooooo`000?l000001?ooool2o`0000Gooooo0_l000000ooooooo0000o`000003ooooo`;o
000000?oooooo`000?l000000_ooool3o`000003ooooool0003o000001Ko000000Coooooo`000?l0
003ooooo1?l00003ooooo`;o00001oooool2o`0001Kooooo0_l00004oooooa7o00009oooool2o`00
03[ooooo000Looooo`03o`000?oooooooooo03Wooooo0_l000001?oooooo0000o`000?ooool2o`00
0003ooooool0003o000000Oooooo1?l00003ooooo`;o00005?ooool2o`0001Oooooo1_l000000ooo
oooo0000o`00000Io`0000Cooooo1?l00003ooooo`?o00003_ooool2o`0000cooooo1?l00004oooo
o`co000000?oooooo`000?l000000_l0000Jooooo`;o00002Oooool2o`0003cooooo000Looooo`03
o`000?oooooooooo03Wooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o0000
00Oooooo1?l00003ooooo`;o00003Oooool2o`0000Gooooo0_l0000=ooooo`;o00001oooool8o`00
0004ooooool0003o0000o`0000;ooooo4_l000000ooooooo0000o`000006ooooo`;o00001?ooool3
o`0000gooooo0_l0000<ooooo`;o000000?oooooo`000?l000000ol000000ooooooo0000o`000007
o`0000?ooooo1?l00003ooooo`;o00005Oooool2o`0000Wooooo0_l00008ooooo`;o0000<_ooool0
01cooooo00?o0000ooooooooool0>Oooool2o`0001;ooooo0_l000000ooooooo0000o`00000?oooo
o`;o00001Oooool2o`0000Oooooo0_l00004ooooo`Co00001Oooool8o`000003ooooool0003o0000
00Cooooo1_l000000ooooooo0000o`000007o`0000;ooooo0_l00006ooooo`;o00001Oooool2o`00
00_ooooo0_l0000<ooooo`;o00000oooool5o`000003ooooool0003o000000?o000000?oooooo`00
0?l000000_ooool4o`0000;ooooo0_l000000ooooooo0000o`000007ooooo`;o00006_ooool2o`00
00Gooooo0_l0000booooo`007?ooool00ol0003oooooooooo`19ooooo`;o00001Oooool2o`0001Oo
oooo0_l00006ooooo`;o00001?ooool4o`0000Gooooo1?l000000ooooooo0000o`000009ooooo`Wo
000000Coooooo`000?l0003o00002?ooool2o`0000Gooooo0_l0000?ooooo`;o00002Oooool2o`00
0003ooooool0003o000000_ooooo0_l00005ooooo`Ko000000?oooooo`000?l000002_ooool2o`00
00_ooooo0ol0000;ooooo`?o0000>Oooool001cooooo00?o0000ooooooooool0=_ooool2o`0000go
oooo0_l00002ooooo`;o00007_ooool4o`0001Sooooo1?l00003ooooo`;o000000Coooooo`000?l0
003ooooo2ol00008ooooo`Co00000_ooool3o`0000Oooooo0_l0000Aooooo`;o00002oooool2o`00
0003ooooool0003o000000Gooooo0_l00002ooooo`;o00002Oooool2o`0000oooooo0ol00002oooo
o`;o00001oooool2o`0003[ooooo000Looooo`03o`000?oooooooooo03Kooooo0ol0000:ooooo`Co
00001Oooool2o`0001cooooo1Ol0000Dooooo`Oo00000_ooool2o`000003ooooool0003o000000Co
00000oooool6o`000004ooooool0003o0000ooooo`?o00000_ooool2o`0000;ooooo0_l00008oooo
o`;o00003Oooool2o`000003ooooool0003o000000Cooooo0_l00006ooooo`;o000000?oooooo`00
0?l000001Oooool2o`0000cooooo0ol0000?ooooo`;o00000oooool2o`0000Gooooo0_l0000loooo
o`007?ooool00ol0003oooooooooo`0gooooo`;o00001_ooool2o`0000;ooooo0_l00005ooooo`Co
00004oooool3o`0000Kooooo0_l000000ooooooo0000o`00000?ooooo`;o00000oooool2o`0000?o
oooo0ol000000ooooooo0000o`000005o`0000Sooooo1_l000001?oooooo0000o`000?l0000<oooo
o`;o00003Oooool2o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`;o00000oooool2o`00
00Oooooo0_l00002ooooo`;o00003?ooool2o`00013ooooo0_l0000:ooooo`;o0000??ooool001co
oooo00?o0000ooooooooool0?oooool2o`0000Wooooo0_l0000Dooooo`Co00002Oooool2o`0000;o
oooo0_l00006ooooo`;o00000oooool2o`0000Wooooo2?l00005ooooo`;o00000oooool6o`000003
ooooool0003o000000;o000000Coooooo`000?l0003o00001oooool2o`0000gooooo0_l0000:oooo
o`Co00000_ooool2o`0000Oooooo0_l00008ooooo`;o00000oooool2o`000004ooooool0003o0000
ooooo`;o00003Oooool3o`0004Oooooo000Looooo`;o0000<oooool2o`0000Oooooo0_l00002oooo
o`?o000000?oooooo`000?l000006oooool2o`0000Cooooo0ol00008ooooo`;o00001_ooool2o`00
00gooooo2Ol000000ooooooo0000o`000009o`0000;ooooo1ol000001?oooooo0000o`000?l00004
ooooo`Co00001?ooool2o`0001Cooooo1?l0000Cooooo`Co00000oooool2o`0000Cooooo0_l0000>
ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0<_ooool4o`0000Gooooo0_l00003oooo
o`;o000000?oooooo`000?l000008Oooool4o`00013ooooo0_l000000ooooooo0000o`000008oooo
o`[o000000?oooooo`000?l000002Ol00002ooooo`Oo00002?ooool4o`0000Cooooo0_l00002oooo
o`?o00002oooool7o`0000;ooooo0_l0000@ooooo`;o00006oooool3o`0000Wooooo0_l0000koooo
o`007?ooool00ol0003oooooooooo`0dooooo`?o00002Oooool2o`00017ooooo0_l000000ooooooo
0000o`000003ooooo`;o00000oooool2o`0000Kooooo0_l00005ooooo`;o00001?ooool3o`0000;o
oooo0_l000000ooooooo0000o`000008ooooo`Co000000Coooooo`000?l0003ooooo0ol00002oooo
o`Go00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`Go00001_ooool2o`00
00Cooooo0ol000000ooooooo0000o`000008ooooo`Co00001Oooool2o`0002kooooo0ol00008oooo
o`;o0000>oooool001cooooo00?o0000ooooooooool0=Oooool2o`0000[ooooo0_l0000@ooooo`;o
000000?oooooo`000?l000000oooool2o`0000?ooooo0_l00004ooooo`;o00001oooool2o`0000Co
oooo0ol00007ooooo`;o000000?oooooo`000?l000002?ooool8o`0000?ooooo1ol00002ooooo`Co
00000_ooool2o`000003ooooool0003o000000?o00001Oooool3o`0000Gooooo0_l000000ooooooo
0000o`000006ooooo`;o00000_ooool2o`0001Gooooo0_l0000:ooooo`;o00004oooool2o`0000;o
oooo0_l000001?oooooo0000o`000?l00008ooooo`?o0000<_ooool001cooooo00?o0000oooooooo
ool0@Oooool2o`0001[ooooo0_l00007ooooo`Co00002oooool2o`0000Cooooo0_l00002ooooo`;o
000000?oooooo`000?l000001oooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`?o
000000?oooooo`000?l000000_ooool2o`0000;ooooo1?l000000ooooooo0000o`000005ooooo`;o
000000?oooooo`000?l000001_ooool2o`0000Wooooo0_l00002ooooo`;o000000?oooooo`000?l0
00000_ooool2o`000003ooooool0003o000000_ooooo0_l0000:ooooo`;o00001Oooool2o`0000Go
oooo0_l000000ooooooo0000o`000004ooooo`Co000000Coooooo`000?l0003o00002?ooool3o`00
03;ooooo000Looooo`03o`000?oooooooooo03Cooooo0_l0000Iooooo`;o00003?ooool2o`0000Wo
oooo0_l00006ooooo`;o00002Oooool2o`0000Cooooo0ol00007ooooo`;o00002oooool2o`0000[o
oooo1Ol00004ooooo`Go00001oooool4o`0000Kooooo0_l00008ooooo`;o00000_ooool2o`000003
ooooool0003o0000013ooooo0_l00004ooooo`;o000000?oooooo`000?l000000oooool4o`0000?o
oooo0_l000000ooooooo0000o`000002ooooo`Ko00000_ooool3o`0000Gooooo0_l00002ooooo`;o
0000<Oooool001cooooo00?o0000ooooooooool07Oooool2o`0001Cooooo0ol00006ooooo`;o0000
4Oooool2o`0000[ooooo0_l00005ooooo`;o00003?ooool2o`0000oooooo0_l0000Iooooo`;o0000
2Oooool2o`0000?ooooo1?l00009ooooo`;o00002?ooool2o`0000cooooo0_l000000ooooooo0000
o`000002o`0000kooooo0_l00004ooooo`;o000000?oooooo`000?l000001Oooool2o`0000?ooooo
0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000oooool3o`0000Gooooo
0_l00002ooooo`;o0000<Oooool001cooooo00?o0000ooooooooool07Oooool2o`0001Cooooo0_l0
0007ooooo`;o00006?ooool3o`0000;ooooo0_l00005ooooo`;o00008Oooool2o`0001Gooooo0_l0
0009ooooo`;o00000oooool2o`0000cooooo0_l0000Eooooo`;o00000oooool4o`0001Wooooo0_l0
0006ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Cooooo0_l0000looooo`007?ooool0
0ol0003oooooooooo`0]ooooo`;o00003_ooool2o`0001?ooooo1ol0000>ooooo`Go00005Oooool2
o`0000;ooooo0_l0000Kooooo`;o00000oooool2o`00017ooooo0_l00003ooooo`;o00000_ooool3
o`0000;ooooo0_l00007ooooo`;o00001?ooool4o`00013ooooo0_l00006ooooo`;o00002Oooool2
o`0004Wooooo000Looooo`03o`000?oooooooooo02gooooo0_l00008ooooo`;o00001?ooool3o`00
01;ooooo1?l00002ooooo`;o00002oooool7o`00013ooooo0_l00003ooooo`;o00007oooool2o`00
00kooooo0_l0000;ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00001oooool2o`00
00Gooooo0ol00005ooooo`;o00002Oooool2o`0000Oooooo0_l00002ooooo`;o0000Coooool001co
oooo00?o0000ooooooooool0=oooool2o`0000Gooooo0ol0000?ooooo`?o00001Oooool2o`0000_o
oooo0_l00004ooooo`;o00003oooool2o`0000?ooooo1?l00004ooooo`;o00009?ooool2o`000004
ooooool0003o0000o`0000Sooooo0_l00003ooooo`[o00002Oooool2o`0000Wooooo0_l00003oooo
o`;o00003Oooool2o`0000;ooooo0_l0000:ooooo`;o0000@oooool001cooooo00?o0000oooooooo
ool06oooool2o`0001Cooooo0_l0000<ooooo`;o00002oooool2o`0000;ooooo1?l00004ooooo`?o
000000Coooooo`000?l0003ooooo0ol00003ooooo`;o00000_ooool5o`0000Gooooo0_l0000:oooo
o`Ko00001?ooool2o`0000cooooo0_l000000ooooooo0000o`00000;ooooo`;o000000?oooooo`00
0?l000000oooool2o`0000;ooooo0_l00008ooooo`;o00001Oooool:o`0000?ooooo0_l00002oooo
o`;o00003_ooool2o`0000gooooo0_l0000>ooooo`;o000000?oooooo`000?l000003?ooool2o`00
03;ooooo000Looooo`03o`000?oooooooooo01_ooooo0_l0000Dooooo`;o00006Oooool2o`0000Co
oooo1?l00002ooooo`?o000000?oooooo`000?l000001_l000001Ooooooo0000o`000?l0003ooooo
00Go000000?oooooo`000?l000001Ol00002ooooo`;o00001Oooool2o`000003ooooool0003o0000
00?o00004?ooool2o`000003ooooool0003o000000_ooooo0_l000001?oooooo0000o`000?ooool2
o`0000cooooo1?l00004ooooo`?o000000?oooooo`000?l000000oooool2o`0000;ooooo1?l00009
ooooo`;o00007Oooool2o`0000Kooooo1Ol0000<ooooo`;o0000<_ooool001cooooo00?o0000oooo
ooooool0;Oooool3o`0000Sooooo0_l0000:ooooo`;o00001_ooool2o`0000;ooooo0ol000000ooo
oooo0000o`000008ooooo`Ko00000_ooool7o`0000;ooooo1ol00002ooooo`;o00000oooool4o`00
00;ooooo1?l00002ooooo`;o000000?oooooo`000?l000003_ooool4o`0000gooooo0_l00009oooo
o`;o000000?oooooo`000?l000001_ooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool4o`00
00;ooooo0_l00005ooooo`;o00007Oooool2o`0000Cooooo1_l00011ooooo`007?ooool00ol0003o
ooooooooo`0]ooooo`?o00000oooool2o`0000?ooooo0_l00008ooooo`Co00002_ooool3o`0000?o
oooo0_l00008ooooo`Oo000000?oooooo`000?l000000ol000000ooooooo0000o`000005o`0000So
oooo0_l00006ooooo`;o00000_ooool2o`000003ooooool0003o000000Wooooo0_l00003ooooo`Co
00002?ooool2o`0000kooooo0_l00002ooooo`;o00000oooool4o`0000Sooooo0_l00007ooooo`;o
00001_ooool2o`0001_ooooo0ol00003ooooo`?o0000AOooool001cooooo00?o0000ooooooooool0
<oooool2o`0000?ooooo0_l00008ooooo`;o000000?oooooo`000?l000003oooool2o`0000;ooooo
0_l000000ooooooo0000o`00000=o`000003ooooool0003o000000Oo000000?oooooo`000?l00000
1?ooool3o`0001Gooooo1?l00003ooooo`;o00002_ooool2o`0000Cooooo0_l00008ooooo`;o0000
0_ooool2o`0000?ooooo0_l0000:ooooo`;o00003oooool2o`0001_ooooo0_l00004ooooo`;o0000
0_ooool2o`0000kooooo0_l0000booooo`007?ooool2o`0003Wooooo0_l0000;ooooo`;o00003_oo
ool2o`0000?ooooo0_l000000ooooooo0000o`00000Co`0000;ooooo0_l000000ooooooo0000o`00
0002ooooo`Go00002_ooool2o`0000Kooooo0_l000000ooooooo0000o`000006ooooo`Co00002_oo
ool2o`000003ooooool0003o000000;o00000_ooool2o`0001_ooooo1_l0000Tooooo`;o00002?oo
ool3o`0000Sooooo0_l00003ooooo`;o0000<_ooool001cooooo00?o0000ooooooooool06oooool2
o`0000oooooo0_l00005ooooo`Co00000oooool2o`0000oooooo0_l00008ooooo`;o00001_oooolF
o`000004ooooool0003o0000o`0000Cooooo0_l0000=ooooo`;o00000_ooool2o`000004ooooool0
003o0000o`0000Sooooo1Ol0000:ooooo`;o00000oooool6o`0000;ooooo0_l00002ooooo`;o0000
1?ooool2o`0000Sooooo0_l00002ooooo`Oo00002Oooool2o`0001Oooooo1?l00009ooooo`;o0000
2?ooool2o`000003ooooool0003o000000;o0000<_ooool001cooooo00?o0000ooooooooool06ooo
ool2o`0000oooooo0_l00005ooooo`Ko000000?oooooo`000?l000003oooool2o`0000Cooooo0_l0
0008oooooa3o000000?oooooo`000?l000001Ol000000ooooooo0000o`000002o`0001Kooooo1Ol0
0009ooooo`;o00003?ooool2o`0000Gooooo1?l00003ooooo`;o00000_ooool4o`0000;ooooo0_l0
0003ooooo`Co000000?oooooo`000?l000001?l00002ooooo`;o00002_ooool2o`0000Cooooo0_l0
000Aooooo`;o00002Oooool4o`0000Kooooo0_l00003ooooo`Co0000<_ooool001cooooo00?o0000
ooooooooool0=oooool2o`000003ooooool0003o000000?ooooo0_l00009ooooo`;o00001Oooool2
o`0000Sooooo5_l00003ooooo`Co00004_ooool2o`0000Cooooo0_l0000Hooooo`;o000000?ooooo
o`000?l000000_ooool2o`0000Kooooo0_l00003ooooo`;o00001oooool4o`0000?ooooo0ol0000?
ooooo`?o00000oooool4o`0000kooooo1?l00008ooooo`Ko00001?ooool2o`0003Wooooo000Loooo
o`03o`000?oooooooooo03[ooooo0_l00003ooooo`;o00002Oooool2o`0000Gooooo1?l000000ooo
oooo0000o`000004oooooaOo000000?oooooo`000?l000001Oooool2o`0000gooooo0_l0000Koooo
o`;o00000oooool3o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o00002?ooool2o`00
00Cooooo0_l00005ooooo`Co000000Coooooo`000?l0003ooooo0_l00006ooooo`?o00001Oooool2
o`0000cooooo1_l00008ooooo`?o000000?oooooo`000?l00000?oooool001cooooo00?o0000oooo
ooooool06_ooool2o`0001[ooooo0_l00005ooooo`;o00005?ooool2o`000003ooooool0003o0000
00;ooooo7?l00005ooooo`Co00002oooool2o`0001Sooooo3?l00004ooooo`;o00003Oooool2o`00
00_ooooo1?l000001?oooooo0000o`000?ooool3o`0001_ooooo0_l00003ooooo`;o00001_ooool3
o`0004?ooooo000Looooo`03o`000?oooooooooo01[ooooo0_l0000Gooooo`;o000000?oooooo`00
0?l000001Oooool2o`0000kooooo0_l00009oooooako00001oooool4o`0000Oooooo1?l0000Foooo
o`Go000000?oooooo`000?l000000_l00002ooooo`;o00006?ooool2o`000003ooooool0003o0000
00;ooooo1?l00002ooooo`;o000000?oooooo`000?l000000ol0000Iooooo`;o00000oooool2o`00
00;ooooo0_l00002ooooo`;o00002?ooool2o`0003[ooooo000Looooo`03o`000?oooooooooo03?o
oooo0_l0000Cooooo`;o00000oooool2o`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l0
00006Ol00009ooooo`;o00001oooool4o`0001Kooooo0_l00002ooooo`;o00000_ooool2o`0001co
oooo1Ol00002ooooo`Go000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00000Ioooo
o`;o00001oooool2o`0000Gooooo0_l00005ooooo`;o0000>_ooool001cooooo00?o0000oooooooo
ool0;Oooool2o`0001Wooooo0_l00008ooooo`Oo000000?oooooo`000?l000006_l0000Aooooo`Go
00000oooool2o`00017ooooo1_l00002ooooo`;o00000oooool2o`0001Gooooo1ol000000ooooooo
0000o`000008o`0002kooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o0000
6_ooool2o`0000;ooooo0_l00005ooooo`Go000000?oooooo`000?l000002?l000000ooooooo0000
o`00000Bo`0000Cooooo0_l00005ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Wooooo
0_l00008ooooo`Co00000_ooool2o`0000?ooooo0_l0000Eooooo`;o00000_ooool>o`0000;ooooo
0_l0000=ooooo`;o00005Oooool2o`0000_ooooo0_l0000jooooo`007?ooool00ol0003ooooooooo
o`0Jooooo`;o0000;Oooool2o`0000;ooooo0_l00007ooooo`;o000000?oooooo`000?l000007_l0
0004ooooo`;o00001Oooool4o`0001;ooooo0_l0000:ooooo`;o00001oooool2o`0000cooooo0_l0
0009ooooo`oo00000oooool2o`0000gooooo0_l0000Eooooo`;o00002oooool2o`000003ooooool0
003o000003Oooooo000Looooo`03o`000?oooooooooo01[ooooo0_l0000Fooooo`;o000000?ooooo
o`000?l000002Oooool2o`0000Gooooo2?l00007ooooo`;o000000?oooooo`000?l000007?l0000?
ooooo`;o00000_ooool2o`0001[ooooo0ol00006ooooo`;o00003?ooool2o`0000Oooooo5?l00000
0ooooooo0000o`000009ooooo`;o00007Oooool2o`0000Oooooo1?l000000ooooooo0000o`00000d
ooooo`007?ooool00ol0003oooooooooo`0booooo`Go00002Oooool2o`0000Gooooo1_l0000=oooo
oago00001Oooool2o`0000Wooooo0_l000001?oooooo0000o`000?l00007ooooo`;o00002_ooool2
o`0000Gooooo0_l0000Dooooo`;o00001OoooolBo`000003ooooool0003o000000Co00002Oooool4
o`0000Wooooo0_l00009ooooo`;o00001Oooool2o`0000Oooooo0_l00003ooooo`;o0000=?ooool0
01cooooo00?o0000ooooooooool0=?ooool2o`0002;ooooo7_l00006ooooo`;o00001_ooool2o`00
0004ooooool0003o0000ooooo`?o00001oooool2o`0000?ooooo0_l00005ooooo`;o00006oooool2
o`0000Cooooo4ol00002ooooo`Ko00001Oooool2o`0000?ooooo0_l00009ooooo`;o00001_ooool5
o`0004Wooooo000Looooo`03o`000?oooooooooo04Wooooo0_l0000=oooooa[o00000_ooool3o`00
00cooooo0ol00004ooooo`;o00003Oooool4o`0001oooooo1?l000000ooooooo0000o`00000Bo`00
0003ooooool0003o000000?o000000?oooooo`000?l000001Oooool2o`0000?ooooo0_l0000:oooo
o`;o00001Oooool4o`0000Cooooo0ol00013ooooo`007?ooool00ol0003oooooooooo`0dooooo`;o
00004oooool2o`0000gooooo8Ol0000:ooooo`?o00004?ooool2o`0000?ooooo0_l00002ooooo`;o
00002oooool2o`0000kooooo1?l000001?oooooo0000o`000?oooolIo`0000_ooooo0_l0000:oooo
o`;o00001?ooool2o`000003ooooool0003o000000;o00000_ooool3o`0004?ooooo000Looooo`;o
0000=Oooool2o`0001_ooooo0_l00005oooooaco00000_ooool3o`0000_ooooo0_l00002ooooo`;o
00003?ooool2o`0000;ooooo0ol00002ooooo`;o00001?ooool2o`0000Gooooo0_l0000>ooooo`;o
00000_oooolMo`0000kooooo0_l0000<ooooo`?o00000oooool2o`0000;ooooo0_l00014ooooo`00
7?ooool00ol0003oooooooooo`0hooooo`?o00004?ooool2o`0000Cooooo0_l00002oooooaOo0000
00Coooooo`000?l0003o00000_ooool2o`00013ooooo1_l00009ooooo`;o00000oooool7o`0000Co
oooo1?l0000Goooooako00003oooool2o`0000Kooooo0_l00004ooooo`;o00002?ooool2o`0000co
oooo0_l0000fooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00001oooool4o`0000Gooooo
0_l00008ooooo`;o00001Oooool2o`000003ooooool0003o000001Go000000?oooooo`000?l00000
1?l000000ooooooo0000o`000007ooooo`;o00001oooool2o`0000_ooooo0_l00003ooooo`[o0000
00?oooooo`000?l000000_l0000Gooooob;o00000_ooool2o`0000oooooo0_l00005ooooo`;o0000
1oooool2o`0000cooooo0_l0000fooooo`007?ooool00ol0003oooooooooo`0Kooooo`;o00004_oo
ool2o`0000Wooooo0_l00005ooooo`;o00001oooool2o`0000Kooooo1_l00002oooooaco00001ooo
ool2o`0001[ooooo2Ol00003ooooo`;o00006?oooolQo`0000;ooooo0_l0000=ooooo`;o00001ooo
ool2o`0000Gooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`0Kooooo`;o0000;Oooool2
o`0000Oooooo8Ol00008ooooo`;o00003oooool2o`0000Oooooo0_l000001Ooooooo0000o`000?l0
003ooooo00;o00000_ooool2o`0001Sooooo0_l00004oooooaco00002?ooool2o`0000[ooooo0_l0
0003ooooo`;o00002Oooool2o`0004Kooooo000Looooo`03o`000?oooooooooo03cooooo0_l0000E
ooooo`So000000?oooooo`000?l000001_l000000ooooooo0000o`00000=o`0000Gooooo0_l00000
0ooooooo0000o`00000?ooooo`;o00001oooool2o`0000;ooooo0_l000001?oooooo0000o`000?oo
ool5o`0001Kooooo0_l000001?oooooo0000o`000?ooool;o`000003ooooool0003o000000ko0000
2?ooool2o`0000oooooo0_l00003ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0??oo
ool3o`0000_ooooo0_l00005ooooo`;o00000oooool2o`000003ooooool0003o000000Cooooo2_l0
00000ooooooo0000o`000002o`0000?ooooo0ol00005ooooo`;o00008Oooool3o`000004ooooool0
003o0000ooooo`;o00006OoooolFo`000004ooooool0003o0000o`0000;ooooo0ol0000Dooooo`;o
00000_ooool2o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`0000Kooooo0_l0000hooooo`00
7?ooool00ol0003oooooooooo`0mooooo`;o00002oooool2o`0000Gooooo0_l00004ooooo`;o0000
0oooool5o`000003ooooool0003o000000Co00000_ooool5o`0000;ooooo0ol00003ooooo`;o0000
0oooool2o`000003ooooool0003o000001?ooooo0_l000000ooooooo0000o`000003ooooo`;o0000
8_ooool7o`000003ooooool0003o000000Co000000?oooooo`000?l000002ol00007ooooo`;o0000
3?ooool2o`0000;ooooo0_l00005ooooo`;o00000oooool2o`0000Cooooo0_l00002ooooo`;o0000
00Coooooo`000?l0003o0000>?ooool001cooooo00?o0000ooooooooool06oooool2o`0002gooooo
0_l00005ooooo`;o00001?ooool2o`0000?ooooo1_l000001?oooooo0000o`000?l00002ooooo`?o
00000_ooool2o`0000Sooooo0_l00003ooooo`;o000000?oooooo`000?l000002Oooool2o`000003
ooooool0003o000000;ooooo0_l000001?oooooo0000o`000?ooool3o`0002?ooooo0_l000000ooo
oooo0000o`00000Jo`0000Cooooo0_l000000ooooooo0000o`00000Gooooo`?o00001_ooool4o`00
00;ooooo0_l000000ooooooo0000o`00000iooooo`007?ooool00ol0003oooooooooo`0Kooooo`;o
0000:_ooool2o`000003ooooool0003o000000?o00000_ooool2o`0000;ooooo1?l00007ooooo`Go
000000?oooooo`000?l000001Ol000000ooooooo0000o`000008ooooo`;o00000_ooool2o`0000co
oooo0_l000000ooooooo0000o`000002ooooo`;o00001Oooool2o`0000cooooo0_l0000Booooob;o
00000oooool3o`0000[ooooo0_l00006ooooo`;o00001oooool2o`0000Kooooo0_l00012ooooo`00
7?ooool00ol0003oooooooooo`17ooooo`;o00000_ooool4o`0000Kooooo1?l00003ooooo`Co0000
00?oooooo`000?l000000_l000000ooooooo0000o`000002ooooo`?o000000?oooooo`000?l00000
0oooool2o`0000?ooooo0ol000000ooooooo0000o`000008ooooo`;o00003Oooool5o`0000cooooo
0_l0000Booooob7o00001?ooool2o`0000_ooooo0_l00004ooooo`Co00003oooool2o`0004;ooooo
000Looooo`03o`000?oooooooooo057ooooo0_l00002ooooo`;o00001Oooool4o`0000Wooooo1?l0
0006ooooo`;o00001?ooool2o`0000Kooooo0_l00003ooooo`Go00001Oooool3o`0000;ooooo1Ol0
0004ooooo`;o00006_oooolQo`0001Oooooo1Ol0000<ooooo`;o0000A?ooool001cooooo00?o0000
ooooooooool0DOooool2o`0000Wooooo0_l00007ooooo`;o00000_ooool6o`000003ooooool0003o
000000oooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l00002ooooo`_o00001Oooool2
o`0001?ooooo0_l00004ooooo`;o000000?oooooo`000?l000001ol000000ooooooo0000o`000007
o`000003ooooool0003o000000Oo00002oooool2o`0000gooooo1?l0000<ooooo`;o0000A?ooool0
01cooooo00?o0000ooooooooool0?Oooool4o`00013ooooo0_l000000ooooooo0000o`000003oooo
o`;o000000?oooooo`000?l000000_l00005ooooo`;o00001?ooool4o`000003ooooool0003o0000
00Sooooo0_l00009ooooo`;o00000_ooool9o`000004ooooool0003o0000o`0001gooooo0_l00004
ooooo`?o00000_oooolAo`000003ooooool0003o000000Ko00003?ooool2o`0000Wooooo0ol00005
ooooo`;o00002oooool2o`0004?ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ
8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0mooooo`Go0000
3oooool2o`000003ooooool0003o000000?ooooo0_l00003ooooo`;o00000oooool2o`0001Gooooo
0_l0000=ooooo`Wo000000Coooooo`000?l0003o00000oooool2o`0001Gooooo0_l00008ooooo`?o
000000?oooooo`000?l000005ol00002ooooo`;o00000oooool2o`0000oooooo0ol00005ooooo`;o
00000_ooool2o`0000Oooooo0_l00013ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5oooo
o`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0@?ooool2
o`0001Cooooo0_l00005ooooo`?o00000oooool2o`0000Kooooo0_l0000=ooooo`;o00000_ooool3
o`000003ooooool0003o000000Oooooo0_l000001?oooooo0000o`000?l00008ooooo`;o00000_oo
ool2o`0000kooooo0_l000000ooooooo0000o`000009ooooo`;o000000?oooooo`000?l000001?l0
0002ooooo`Oo000000?oooooo`000?l000001_l00003ooooo`;o00000oooool2o`0001Oooooo0_l0
0002ooooo`;o00004Oooool2o`0003Wooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooo
oooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo04Sooooo0_l0
000<ooooo`;o000000?oooooo`000?l000000_ooool2o`0000cooooo0_l0000=ooooo`;o00000_oo
ool3o`000003ooooool0003o000000?ooooo0_l00002ooooo`Ko00003?ooool2o`0000Kooooo0ol0
0002ooooo`;o000000?oooooo`000?l000003oooool2o`000005ooooool0003o0000o`000?ooool0
0_l000000ooooooo0000o`00000<o`0001oooooo1?l00008ooooo`;o00001Oooool2o`0000Cooooo
0_l0000iooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?nH
V9SooooooiRHV?lQ8B401_ooool3o`0004;ooooo1?l000001?oooooo0000o`000?l00007ooooo`;o
00001_ooool2o`0000Cooooo0_l00009ooooo`;o00001_ooool2o`0000Wooooo0_l00005ooooo`;o
000000?oooooo`000?l000002?l00005ooooo`;o00001Oooool2o`0000;ooooo0_l000000ooooooo
0000o`000002o`0000;ooooo0_l0000Dooooo`Co000000?oooooo`000?l000000_ooool:o`0002;o
oooo0_l0000:ooooo`;o00001Oooool2o`0003oooooo00000ooooooo0000ooooo`02ooooo`03o`00
0?oooooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo03oo
oooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000Sooooo0_l00004ooooo`;o
00001?ooool4o`0000Wooooo0_l00003ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Go
oooo0_l000000ooooooo0000o`000003o`0000Wooooo0ol000000ooooooo0000o`000002ooooo`;o
00000_ooool2o`000003ooooool0003o0000017ooooo0_l00007ooooo`;o00000_ooool3o`000003
ooooool0003o000000Wo00007?ooool2o`0000[ooooo1?l0001:ooooo`0000?ooooooa0@4?ooool0
0_ooool00ol@413oooooooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0
8?ooool2o`0001gooooo0_l0000=ooooo`;o00001oooool5o`000003ooooool0003o000000Oooooo
0ol00006ooooo`;o00004_ooool2o`0000;ooooo0_l000000ooooooo0000o`000009ooooo`?o0000
00?oooooo`000?l000005?ooool2o`0000?ooooo0_l000000ooooooo0000o`00000;ooooo`;o0000
0_ooool2o`0000;ooooo0ol0000Cooooo`Co00002Oooool2o`0000[ooooo1?l0001:ooooo`0000Ko
ooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000oooooooo
ool08?ooool2o`0001[ooooo0_l00003ooooo`;o00002oooool2o`0000Wooooo1?l000000ooooooo
0000o`000006ooooo`?o00006_ooool5o`000003ooooool0003o000000Oooooo0_l00002ooooo`;o
00002oooool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l000000ooooooo
0000o`000006ooooo`;o00001Oooool2o`000003ooooool0003o000000;o00000_ooool3o`0001?o
oooo1?l0001Sooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co0000
oa0@40Kooooo00?o0000ooooooooool0??ooool3o`0000;ooooo0_l0000;ooooo`;o00001oooool2
o`000005ooooool0003o0000o`000?ooool00_l0000Qooooo`;o000000?oooooo`000?l000001Ol0
0007ooooo`Ko00002oooool8o`000003ooooool0003o000000Wo00000oooool4o`0000Gooooo0_l0
00000ooooooo0000o`000002o`0000Gooooo0_l0000eooooo`;o000000?oooooo`000?l00000?_oo
ool001cooooo00?o0000ooooooooool0?Oooool2o`0000oooooo0_l00007ooooo`;o000000?ooooo
o`000?l000007_ooool2o`0000;ooooo1ol000000ooooooo0000o`000002o`000003ooooool0003o
000000Oooooo0_l0000<oooooaKo000000?oooooo`000?l000000_l0000Aooooo`?o00001?ooool2
o`00017ooooo0_l000000ooooooo0000o`00000@ooooo`?o00001_ooool2o`000003ooooool0003o
000003kooooo000Looooo`03o`000?oooooooooo05;ooooo0_l00003ooooo`;o00001Oooool2o`00
01[ooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000;o00001?ooool2o`00
01;ooooo1_l000000ooooooo0000o`00000Eo`0000Sooooo0_l00007ooooo`Co00000oooool2o`00
00cooooo0_l00003ooooo`;o000000?oooooo`000?l000001?ooool2o`0000[ooooo0ol00007oooo
o`;o0000@?ooool001cooooo00?o0000ooooooooool0BOooool2o`0000Oooooo0_l00003ooooo`Co
00000oooool2o`0000?ooooo0_l0000;ooooo`;o00001_ooool7o`000003ooooool0003o000000;o
000000?oooooo`000?l000002oooool2o`0000_ooooo5_l00002ooooo`;o00001oooool2o`0000?o
oooo0_l00009ooooo`;o00002_ooool4o`000003ooooool0003o000000;o00002_ooool5o`0000Go
oooo0_l0000<ooooo`?o0000?oooool001cooooo00?o0000ooooooooool0BOooool2o`0000cooooo
1?l00008ooooo`;o00002?ooool2o`000003ooooool0003o000000Kooooo1Ol00005ooooo`;o0000
2oooool2o`000003ooooool0003o000000[ooooo6?l00002ooooo`;o00001_ooool2o`0000gooooo
0_l0000;ooooo`Co000000?oooooo`000?l000003?ooool5o`0000Cooooo0ol0000=ooooo`;o0000
1?ooool2o`0003Wooooo000Looooo`03o`000?oooooooooo04Wooooo0_l0000=ooooo`Co00002?oo
ool2o`0000Oooooo0_l0000?ooooo`;o00000_ooool2o`000003ooooool0003o000000Sooooo0_l0
000<oooooago00005Oooool2o`0001Kooooo0_l00007ooooo`Co00001?ooool2o`00013ooooo0_l0
0002ooooo`;o0000>Oooool001cooooo00?o0000ooooooooool0?oooool2o`0000Kooooo0_l00004
ooooo`;o00002oooool2o`0000Sooooo0_l00002ooooo`;o00004?ooool2o`0000;ooooo0_l00002
ooooo`Go00005_oooolKo`0000cooooo0_l0000@ooooo`;o00003oooool5o`0000Cooooo1?l0000=
ooooo`;o00001_ooool3o`0003gooooo000Looooo`03o`000?oooooooooo02Kooooo0_l0000Goooo
o`;o00001_ooool2o`0000Cooooo1?l0000Dooooo`;o000000?oooooo`000?l000004?ooool2o`00
00Oooooo0_l000001?oooooo0000o`000?l0000Eooooo`Ko000000Goooooo`000?l0003o0000oooo
o`0>o`000004ooooool0003o0000ooooo`;o00001oooool2o`00013ooooo0_l0000@ooooo`Co0000
5Oooool2o`0000Kooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0Vooooo`;o00009Ooo
ool4o`0000oooooo1ol000001?oooooo0000o`000?l0000:ooooo`;o00001oooool2o`000004oooo
ool0003o0000o`0000;ooooo1?l00004ooooo`;o00003?oooolJo`0000;ooooo0_l000000ooooooo
0000o`00000Eooooo`;o00006Oooool2o`0000Sooooo0_l00005ooooo`;o0000BOooool001cooooo
00?o0000ooooooooool0COooool3o`00013ooooo1_l00003ooooo`;o00001?ooool2o`000004oooo
ool0003o0000ooooo`?o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000007o`0000Co
oooo0_l0000<oooooa_o00006oooool3o`00017ooooo0_l00005ooooo`;o00002?ooool2o`0000Go
oooo0_l000000ooooooo0000o`000016ooooo`007?ooool00ol0003oooooooooo`18ooooo`Co0000
0_ooool5o`00017ooooo0ol00002ooooo`;o00001?ooool2o`000003ooooool0003o000000Co0000
00Coooooo`000?l0003o00001_ooool4o`000003ooooool0003o000000oooooo0_l00004oooooaWo
00005oooool2o`0000?ooooo0_l0000Aooooo`;o00002Oooool2o`0000Sooooo0_l00004ooooo`;o
00000_ooool2o`000003ooooool0003o000003oooooo000Looooo`03o`000?oooooooooo04;ooooo
0_l00004ooooo`Co00001?ooool4o`0000Wooooo0_l00004ooooo`Co00000_ooool2o`0000Wooooo
0ol00002ooooo`;o00002?ooool3o`000003ooooool0003o000000?ooooo0_l0000:oooooaoo0000
5oooool2o`0001Wooooo0_l00006ooooo`;o00002?ooool2o`0000Sooooo0_l000000ooooooo0000
o`00000oooooo`007?ooool2o`0004?ooooo0_l00007ooooo`Co00000oooool2o`0000Wooooo0ol0
0003ooooo`;o00001oooool2o`0000?ooooo0_l0000<ooooo`;o00000oooool2o`0000Kooooo0_l0
000<oooooago0000;?ooool2o`0000Cooooo0_l0000Eooooo`;o0000Aoooool001cooooo00?o0000
ooooooooool0Boooool4o`0000Oooooo0_l00006ooooo`;o00003?ooool2o`0000?ooooo0_l00008
ooooo`;o00000_ooool2o`0000?ooooo0_l0000Hooooo`co000000?oooooo`000?l000002_l00002
ooooo`Co00001oooool2o`0001gooooo0_l00006ooooo`;o00001Oooool2o`000003ooooool0003o
000000Wooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o00007Oooool2o`00
00[ooooo0_l0000Eooooo`;o00003?ooool2o`0000cooooo0_l00002ooooo`;o00003oooool<o`00
0003ooooool0003o000000Wo00000oooool6o`0000Gooooo0_l00006ooooo`;o00006?ooool2o`00
00?ooooo0_l00005ooooo`;o000000?oooooo`000?l000003oooool2o`00047ooooo000Looooo`03
o`000?oooooooooo02_ooooo0_l0000Mooooo`;o00004?ooool2o`0000Oooooo1?l00004ooooo`;o
00002?ooool2o`00013ooooo0_l00002ooooo`;o00002Oooool2o`0000Gooooo1Ol000000ooooooo
0000o`00000>o`0000Sooooo0_l00009ooooo`?o000000?oooooo`000?l000006?ooool2o`0000Oo
oooo0_l000000ooooooo0000o`00000Booooo`;o0000@Oooool001cooooo00?o0000ooooooooool0
A?ooool2o`0000Gooooo0_l0000?ooooo`;o00001oooool4o`0000gooooo0ol0000<ooooo`;o0000
00?oooooo`000?l000003_ooool2o`0000Gooooo5_l0000Cooooo`?o00005oooool2o`0000Kooooo
0ol00002ooooo`;o00003_ooool2o`0000Wooooo0_l0000mooooo`007?ooool00ol0003ooooooooo
o`14ooooo`;o00001?ooool5o`00017ooooo0ol00002ooooo`;o00003oooool2o`0000Kooooo0_l0
0005ooooo`Go00003Oooool5o`0000Cooooo5Ol00002ooooo`;o0000:Oooool2o`0000Kooooo0ol0
000Booooo`;o00002Oooool2o`0003gooooo000Looooo`03o`000?oooooooooo04Cooooo0_l00004
ooooo`;o000000?oooooo`000?l000000ol000000ooooooo0000o`000008ooooo`;o000000Cooooo
o`000?l0003o00000_ooool2o`0000Cooooo0_l0000Aooooo`?o00001Oooool3o`0000kooooo1_l0
0002ooooo`Go000000?oooooo`000?l000003ol000000ooooooo0000o`00000Cooooo`;o00004_oo
ool5o`0001Gooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`11ooooo`;o00003?ooool3
o`000003ooooool0003o000000Sooooo0_l000000ooooooo0000o`000003ooooo`;o00000oooool3
o`0000Cooooo0_l0000<ooooo`;o00006_ooool2o`0000;ooooo5ol00002ooooo`?o00004?ooool5
o`00013ooooo0_l000000ooooooo0000o`000002ooooo`;o00004Oooool2o`0000Cooooo0ol00005
ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0@Oooool3o`0000cooooo0_l0000Coooo
o`;o00000oooool5o`0000;ooooo0_l000000ooooooo0000o`00000@ooooo`?o00000oooool2o`00
00gooooo0_l00002ooooo`;o000000?oooooo`000?l000003ol00005ooooo`?o00004?ooool2o`00
0003ooooool0003o000001Oooooo0_l0000:ooooo`;o00002oooool3o`0000Gooooo0_l0000ooooo
o`007?ooool00ol0003oooooooooo`12ooooo`;o00000_ooool2o`0000_ooooo0_l0000@ooooo`;o
00000oooool5o`0000;ooooo0_l000000ooooooo0000o`000007ooooo`;o00001oooool3o`0000?o
oooo0_l0000AoooooaCo00004_ooool2o`0001gooooo0_l000001?oooooo0000o`000?ooool2o`00
00Oooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00005?ooool2o`0000_o
oooo0_l00004ooooo`;o00002?ooool2o`0000Gooooo1Ol00002ooooo`;o00000oooool2o`0000Go
oooo0_l00007ooooo`?o00005?ooool2o`0000;ooooo1ol00002ooooo`Co000000?oooooo`000?l0
00000_l0000Booooo`;o00007Oooool2o`000003ooooool0003o000000?o00002Oooool2o`0005;o
oooo000Looooo`03o`000?oooooooooo033ooooo0_l0000Wooooo`;o00002?ooool2o`0000Kooooo
1_l00003ooooo`Co00003oooool2o`0001Cooooo0_l00005ooooo`Co00000_ooool2o`0000;ooooo
0_l000000ooooooo0000o`000008ooooo`;o0000:oooool2o`0000Wooooo1?l0001Booooo`007?oo
ool00ol0003oooooooooo`1@ooooo`?o00002?ooool2o`0000Kooooo0_l00008ooooo`Co00000ooo
ool2o`0000gooooo0_l0000Pooooo`;o00000oooool9o`0000Sooooo0_l0000fooooo`;o0000E?oo
ool001cooooo00?o0000ooooooooool0BOooool2o`0000Gooooo0ol00003ooooo`;o00000oooool2
o`0000Kooooo0_l0000;ooooo`;o00000_ooool2o`0000cooooo1ol0000Looooo`;o00001?ooool3
o`0000;ooooo0ol0000mooooo`;o000000?oooooo`000?l000001oooool2o`0004_ooooo000Loooo
o`03o`000?oooooooooo03?ooooo0_l0000?ooooo`;o00000oooool2o`0000_ooooo0_l00002oooo
o`;o00000_ooool2o`00013ooooo0ol000001?oooooo0000o`000?ooool2o`0000Cooooo1?l00000
0ooooooo0000o`000005o`0001;ooooo0_l0000:ooooo`;o00000_ooool2o`000003ooooool0003o
000002gooooo0_l0000Aooooo`;o00002_ooool2o`0000?ooooo0_l00016ooooo`007?ooool00ol0
003oooooooooo`0cooooo`;o00003oooool2o`0000kooooo0_l00004ooooo`;o00000_ooool2o`00
017ooooo0_l00004ooooo`;o00000oooool5o`0000?ooooo0_l000000ooooooo0000o`00000Boooo
o`;o00002_ooool2o`0000Gooooo0_l0000=ooooo`;o00001oooool2o`0001Gooooo0_l0000Loooo
o`;o000000Coooooo`000?l0003ooooo0_l00016ooooo`007?ooool2o`0003Kooooo0_l0000Loooo
o`?o00000oooool2o`0000?ooooo0ol00009ooooo`;o00001?ooool2o`0000[ooooo0ol00008oooo
o`;o00008_ooool2o`0000oooooo0ol00007ooooo`Co00003_ooool2o`0000Wooooo0_l00008oooo
o`;o00001?ooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l00000BOooool001co
oooo00?o0000ooooooooool0=Oooool2o`0001cooooo0_l00004ooooo`;o00001?ooool4o`0000Oo
oooo0_l00004ooooo`;o00001?ooool7o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o
00005Oooool2o`0000_ooooo1_l00002ooooo`;o00001oooool2o`0000[ooooo0_l0000=ooooo`?o
00001Oooool2o`0000;ooooo0_l00008ooooo`;o00000oooool3o`0000;ooooo0_l0001@ooooo`00
7?ooool00ol0003oooooooooo`0gooooo`;o00005?ooool2o`0000cooooo0_l00004ooooo`?o0000
1?ooool2o`0000Oooooo0_l00002ooooo`_o00000oooool2o`0001Wooooo0_l00004ooooo`;o0000
1oooool4o`000004ooooool0003o0000o`0002;ooooo1?l00004ooooo`Co00003oooool2o`0000?o
oooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00005?ooool2o`0000Sooooo
0_l00002ooooo`?o00001?ooool3o`0000?ooooo0_l00007ooooo`?o000000?oooooo`000?l00000
2?l00009ooooo`;o00000_ooool2o`0001Kooooo0_l00008ooooo`?o000000?oooooo`000?l00000
9?ooool3o`0000Cooooo1?l0000>ooooo`;o00000_ooool4o`00053ooooo000Looooo`03o`000?oo
oooooooo05Oooooo0_l00003ooooo`;o00001?ooool5o`0000Oooooo0_l00002ooooo`;o000000?o
ooooo`000?l000002?l00009ooooo`;o00000_ooool2o`0001Kooooo0_l0000;ooooo`;o00004?oo
ool2o`0001?ooooo0_l00004ooooo`;o00004Oooool2o`0000;ooooo1?l0001@ooooo`007?ooool0
0ol0003oooooooooo`1Rooooo`;o000000?oooooo`000?l000001oooool2o`0000?ooooo3?l00004
ooooo`;o00002oooool2o`0001;ooooo0_l00004ooooo`?o00001?ooool2o`00013ooooo0_l0000I
ooooo`;o00005?ooool2o`0005?ooooo000Looooo`03o`000?oooooooooo06?ooooo0_l00004oooo
o`;o00002?ooool>o`0000;ooooo0ol0000:ooooo`;o00005?ooool2o`000003ooooool0003o0000
00;o00008oooool2o`0000;ooooo0_l0000;ooooo`;o00001oooool2o`0000?ooooo0_l00003oooo
o`;o000000?oooooo`000?l00000D?ooool001cooooo00?o0000ooooooooool0Hoooool2o`0000?o
oooo0ol00007ooooo`Oo000000?oooooo`000?l000001Ol00003ooooo`Co00002Oooool2o`0001?o
oooo1Ol00003ooooo`;o00008?ooool2o`0000;ooooo0_l0000;ooooo`;o00001oooool2o`0000?o
oooo0_l00006ooooo`;o0000D?ooool001cooooo00?o0000ooooooooool0Goooool2o`0000;ooooo
0_l00003ooooo`;o00002?ooool?o`0000;ooooo0_l000000ooooooo0000o`000009ooooo`;o0000
3Oooool2o`0000Kooooo0_l00004ooooo`Co00007_ooool3o`0000cooooo0_l00007ooooo`;o0000
Goooool001cooooo00?o0000ooooooooool0GOooool4o`0000Gooooo0_l0000:oooooa3o000000?o
ooooo`000?l000006oooool2o`0000gooooo1Ol0000Cooooo`;o00000oooool2o`0000;ooooo0ol0
0003ooooo`;o00001oooool3o`000003ooooool0003o000000;ooooo0ol0001Oooooo`007?ooool0
0ol0003oooooooooo`1Mooooo`;o00000oooool3o`000003ooooool0003o000000?ooooo0_l00006
ooooo`oo00001oooool2o`0002Cooooo1_l0000Booooo`;o00000oooool2o`0000?ooooo0_l00003
ooooo`;o00000oooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`?o00002_ooool2
o`0005?ooooo000Looooo`03o`000?oooooooooo04gooooo0_l0000Cooooo`?o000000?oooooo`00
0?l000000oooool2o`0000Kooooo3?l0000:ooooo`;o00001Oooool2o`0001kooooo0_l000000ooo
oooo0000o`000005ooooo`;o00003Oooool2o`00013ooooo0_l000000ooooooo0000o`000007oooo
o`?o00002_ooool2o`0005?ooooo000Looooo`03o`000?oooooooooo04gooooo0_l0000Dooooo`;o
000000?oooooo`000?l000001?ooool4o`0000?ooooo2ol0000Booooo`;o00000_ooool2o`0002;o
oooo1?l000000ooooooo0000o`00000:ooooo`;o00004oooool2o`0000?ooooo1?l0001Rooooo`00
7?ooool00ol0003oooooooooo`1Zooooo`Ko000000Coooooo`000?l0003ooooo2Ol00002ooooo`;o
00004oooool2o`0001Kooooo0_l0000:ooooo`;o00000oooool2o`000004ooooool0003o0000oooo
o`;o00001_ooool2o`0001Kooooo1?l0001Rooooo`007?ooool00ol0003oooooooooo`0oooooo`;o
0000:Oooool2o`0000Gooooo0_l000000ooooooo0000o`000007o`0000;ooooo0_l0000Cooooo`;o
00005_ooool2o`0000[ooooo0_l00006ooooo`;o000000?oooooo`000?l000001_ooool3o`0000?o
oooo0_l00003ooooo`Co00001Oooool2o`0000gooooo0_l0001Iooooo`007?ooool00ol0003ooooo
ooooo`0oooooo`;o0000<oooool2o`000005ooooool0003o0000o`000?ooool00_l00002ooooo`;o
00001oooool2o`0000[ooooo0_l0000Oooooo`;o000000?oooooo`000?l000004_ooool4o`000003
ooooool0003o000000?ooooo1?l000000ooooooo0000o`000002ooooo`;o00001Oooool2o`0000Ko
oooo0_l0001Iooooo`007?ooool2o`0005gooooo0_l00002ooooo`;o00007Oooool2o`0000Oooooo
0_l00007ooooo`;o00008_ooool2o`0000kooooo0_l00007ooooo`?o00002Oooool3o`0000;ooooo
2Ol00006ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0G?ooool2o`0000;ooooo0_l0
000Jooooo`Co00004?ooool5o`00033ooooo0_l00007ooooo`?o00002Oooool2o`0000Cooooo2?l0
0006ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0G?ooool2o`0001kooooo1?l0000@
ooooo`Go00004oooool2o`0000Gooooo0_l00009ooooo`;o00004_ooool2o`0000[ooooo0_l00008
ooooo`Co00001?ooool2o`0005_ooooo000Looooo`03o`000?oooooooooo06;ooooo0_l00006oooo
o`Co00001_ooool2o`000003ooooool0003o000001_ooooo0_l0000Booooo`?o00001?ooool2o`00
00Oooooo1?l0000?ooooo`;o00001Oooool2o`00013ooooo0_l00006ooooo`;o0000Foooool001co
oooo00?o0000ooooooooool0H_ooool2o`0000Kooooo1Ol00004ooooo`?o000000?oooooo`000?l0
00004_ooool4o`0000Gooooo0_l0000Cooooo`;o00003Oooool2o`0000Gooooo0_l000000ooooooo
0000o`000002o`000003ooooool0003o000000;ooooo1?l00002ooooo`Co0000M?ooool001cooooo
00?o0000ooooooooool0KOooool2o`0000;ooooo1?l0000;ooooo`;o00002Oooool4o`0001cooooo
0_l0000>ooooo`?o000000Coooooo`000?l0003ooooo1?l000000ooooooo0000o`000006o`0000;o
oooo1?l0000Cooooo`;o0000Goooool001cooooo00?o0000ooooooooool0Ioooool2o`0000Gooooo
1Ol0000=ooooo`;o00001_ooool7o`0000?ooooo0_l0000Gooooo`;o00003_ooool5o`0000?ooooo
0_l00002ooooo`Ko00001?ooool4o`0001?ooooo0_l0001Oooooo`007?ooool00ol0003ooooooooo
o`1Wooooo`;o00001Oooool4o`0001Kooooo1_l00004ooooo`Co0000:?ooool2o`0000?ooooo0_l0
000:ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo0ol00007ooooo`;o0000Hooo
ool001cooooo00?o0000ooooooooool0M?ooool2o`0001kooooo0_l00003ooooo`;o00008oooool2
o`0000oooooo0_l00005ooooo`;o000000?oooooo`000?l000000_l00007ooooo`;o0000Hoooool0
01cooooo00?o0000ooooooooool0M?ooool3o`0001Oooooo0_l00009ooooo`;o00005Oooool2o`00
00Oooooo0_l00004ooooo`?o00001Oooool2o`0000?ooooo0_l00008ooooo`;o000000?oooooo`00
0?l00000K_ooool001cooooo00?o0000ooooooooool0MOooool4o`0000kooooo0_l00005ooooo`;o
00003Oooool2o`000003ooooool0003o000000kooooo0_l00007ooooo`;o00001?ooool3o`0000Go
oooo0_l00003ooooo`;o00001Oooool2o`0007Cooooo000Looooo`03o`000?oooooooooo06gooooo
1?l00006ooooo`;o00003_ooool2o`0001?ooooo0ol000000ooooooo0000o`00000@ooooo`;o0000
00?oooooo`000?l000002Oooool2o`00017ooooo0ol0001cooooo`007?ooool00ol0003ooooooooo
o`1]ooooo`Go00006Oooool2o`0000[ooooo0_l00003ooooo`;o00003?ooool2o`0000Kooooo0_l0
00000ooooooo0000o`00000Booooo`Co00001oooool2o`0007?ooooo000Looooo`03o`000?oooooo
oooo073ooooo0_l0000;ooooo`;o00002_ooool5o`0000Wooooo0_l00007ooooo`;o00002?ooool2
o`0001Kooooo0ol00003ooooo`Oo00002?ooool2o`00073ooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`1gooooo`;o00001?ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l00000
0_ooool5o`0000Wooooo0_l00005ooooo`Go000000?oooooo`000?l000004?ooool2o`0000Gooooo
0_l00003ooooo`?o00000oooool2o`0000?ooooo0_l00008ooooo`;o0000L?ooool00006oooooomg
MgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06oooo
o`03o`000?oooooooooo07Oooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o
000000Ko000000Coooooo`000?l0003ooooo0_l0000@ooooo`;o000000Coooooo`000?l0003ooooo
1?l0000>ooooo`;o00001Oooool2o`0000Sooooo0_l00020ooooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`1jooooo`;o00002?ooool6o`0001Sooooo0_l00002ooooo`;o00007oooool4o`0007kooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RH
oc8b<P06ooooo`?o0000O?ooool2o`0000?ooooo0_l00005ooooo`;o00006?ooool2o`000004oooo
ool0003o0000o`0000;ooooo0_l00004ooooo`;o00003Oooool2o`0000Sooooo0_l0001nooooo`00
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<
c<`01_ooool00ol0003oooooooooo`1looooo`Co000000?oooooo`000?l000008_ooool3o`0000;o
oooo0_l00004ooooo`;o00003Oooool2o`0000Gooooo0_l00002ooooo`;o0000OOooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00Ko
oooo00?o0000ooooooooool0MOooool3o`0000Kooooo0_l000000ooooooo0000o`000003ooooo`;o
00008oooool2o`0000gooooo0_l0000:ooooo`;o00000_ooool2o`0007gooooo00001_ooooooMgMg
oiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooo
oooo07Gooooo0ol00009ooooo`;o00000oooool2o`00027ooooo1?l0000;ooooo`Ko00002?ooool2
o`00087ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@06ooooo`03o`000?oooooooooo07Gooooo0_l00005ooooo`;o00002Oooool2o`00023ooooo
0_l0000<ooooo`Oo0000Roooool001cooooo00?o0000ooooooooool0MOooool2o`0000Gooooo0_l0
0008ooooo`?o00007oooool2o`0000gooooo0_l00002ooooo`?o00003_ooool2o`0007_ooooo000L
ooooo`03o`000?oooooooooo08Kooooo0_l00004ooooo`;o00001_ooool4o`0000cooooo0_l00002
ooooo`Co00005oooool3o`0000?ooooo0_l000000ooooooo0000o`00001kooooo`007?ooool00ol0
003oooooooooo`22ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o00001_ooool4
o`0000cooooo0_l00004ooooo`;o00003?ooool2o`0000Wooooo0ol00002ooooo`?o000000?ooooo
o`000?l00000Noooool001cooooo00?o0000ooooooooool0P_ooool2o`0000Cooooo1_l00002oooo
o`Co00002Oooool2o`0000cooooo0_l00004ooooo`;o00000oooool6o`0000cooooo0ol000000ooo
oooo0000o`00001kooooo`007?ooool00ol0003oooooooooo`28ooooo`Ko00000_ooool4o`000003
ooooool0003o000000?ooooo0_l000000ooooooo0000o`000002o`0000[ooooo0_l00004ooooo`;o
00000oooool2o`0000;ooooo0_l00009ooooo`;o0000P_ooool001cooooo00?o0000ooooooooool0
Q_ooool2o`0000;ooooo1?l00007ooooo`;o00000_ooool4o`0000;ooooo0_l0000:ooooo`;o0000
4oooool2o`0000?ooooo0_l00022ooooo`007?ooool00ol0003oooooooooo`26ooooo`;o00000ooo
ool2o`0000;ooooo0_l00008ooooo`Co00003Oooool4o`0000;ooooo0_l00008ooooo`;o00001?oo
ool2o`0008Oooooo000Looooo`03o`000?oooooooooo08oooooo0_l000000ooooooo0000o`000006
ooooo`;o00002Oooool2o`0000;ooooo1Ol00002ooooo`;o00002?ooool2o`000003ooooool0003o
000008[ooooo000Looooo`03o`000?oooooooooo07gooooo0_l0000@ooooo`;o000000?oooooo`00
0?l000001_ooool2o`0000Wooooo0_l00002ooooo`;o00001Oooool2o`0000Wooooo1?l0002:oooo
o`007?ooool00ol0003oooooooooo`1mooooo`;o00004oooool4o`0000Cooooo0_l00005ooooo`;o
000000Coooooo`000?l0003o00002Oooool2o`0000Wooooo0_l0002<ooooo`007?ooool00ol0003o
ooooooooo`26ooooo`;o00002_ooool4o`0000_ooooo0_l000000ooooooo0000o`000008ooooo`;o
00001?ooool2o`0009?ooooo000Looooo`;o0000Qoooool3o`0000Wooooo0ol0000Iooooo`Go0000
00?oooooo`000?l00000Toooool001cooooo00?o0000ooooooooool0Qoooool2o`0000Wooooo0_l0
000Looooo`?o0000U_ooool001cooooo00?o0000ooooooooool0R_ooool2o`0001Cooooo0_l0000@
ooooo`;o0000UOooool001cooooo00?o0000ooooooooool0R_ooool2o`0001Cooooo1?l0000>oooo
o`;o0000UOooool001cooooo00?o0000ooooooooool0X_ooool5o`000:;ooooo000Looooo`03o`00
0?oooooooooo0:Cooooo0ol000001?oooooo0000o`000?ooool2o`0009cooooo000Looooo`03o`00
0?oooooooooo0:Sooooo0_l000000ooooooo0000o`00002Looooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0
003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001;ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo
B_ooool001Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood[ooooo000D
ooooo`03o`000?oooooooooo00Gooooo0ol0003ooooood[ooooo000Dooooo`03o`000?oooooooooo
0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003ooooo
ooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001;ooooo00?oEEEE
ofIVI_l00000oooooomDooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00YOoo
ool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo01Gooooo00Gok^k^oc8b<_l0003o
410@olc<c005ooooo`;o000000Co410@oooooooooooooooo1Ol0002@ooooo`00Y_ooool01Ol0003o
oooooooooooooooo000000Wooooo1_l00009ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool0
0ol0003oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0T?ooool00:Kooooo00Go0000
ooooooooooooooooo`00000Hooooo`05o`000?ooooooooooooooool000000oooool5o`0000Cooooo
00?oV9RHob4Q8Oo^k^h0TOooool00:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko0000
2Oooool01Ol0003oV9RHoooooonHV9So8B4Q00?ooooo00CoA4A4omgMgOoooooo00001_ooool00onH
V9So8B4Qonk^kP2@ooooo`00Y_ooool01Ol0003oQhN7oooooonYZJWo000001Sooooo00Go0000oeEE
EOl0003o410@olc<c003ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?oMgMgofIVI_ooool0Sooo
ool00:Gooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Fooooo`03oeEEEOn7QhOo
oooo00Kooooo00?oMgMgolc<c?l000002?ooool00ol0003oooooooooo`2>ooooo`00`oooool00ooM
gMgo410@oiRHV006ooooo`03onk^k_m4A4Co000000Cooooo00Go0000okZj^_ooooooV9RHoa0@402@
ooooo`00a?ooool01?o<c<coA4A4o`000?l@4105ooooo`03ogMgMol0003ooooo00?ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c02@ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(648) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.35617 .48473 Mdot
.29287 .50161 Mdot
.66179 .55982 Mdot
.5196 .36236 Mdot
.6646 .48739 Mdot
.6346 .57853 Mdot
.49743 .64142 Mdot
.51265 .61516 Mdot
.6248 .57508 Mdot
.23291 .38038 Mdot
.5339 .63689 Mdot
.48722 .29255 Mdot
.50402 .65348 Mdot
.47933 .39518 Mdot
.39056 .72064 Mdot
.559 .39017 Mdot
.28337 .50354 Mdot
.71106 .45405 Mdot
.56085 .38039 Mdot
.66694 .57942 Mdot
.41626 .48206 Mdot
.48222 .38802 Mdot
.29111 .49588 Mdot
.47988 .39247 Mdot
.49082 .34014 Mdot
.31786 .49179 Mdot
.36301 .496 Mdot
.48724 .35678 Mdot
.45472 .36708 Mdot
.52886 .65401 Mdot
.74132 .48094 Mdot
.34296 .79953 Mdot
.5477 .39716 Mdot
.39671 .31741 Mdot
.4895 .61537 Mdot
.75757 .65662 Mdot
.60663 .5896 Mdot
.53837 .62834 Mdot
.49035 .6241 Mdot
.47796 .63764 Mdot
.48972 .66241 Mdot
.31067 .49658 Mdot
.49593 .68129 Mdot
.6706 .62358 Mdot
.52922 .38287 Mdot
.28721 .67295 Mdot
.7833 .42623 Mdot
.48733 .35913 Mdot
.34608 .48087 Mdot
.66045 .59192 Mdot
.51326 .21662 Mdot
.54224 .63133 Mdot
.33755 .69479 Mdot
.09081 .51369 Mdot
.52046 .65835 Mdot
.51042 .35972 Mdot
.6294 .60325 Mdot
.51161 .38406 Mdot
.48646 .37012 Mdot
.40977 .28141 Mdot
.46085 .3721 Mdot
.70375 .43634 Mdot
.36562 .48725 Mdot
.67021 .5914 Mdot
.62687 .57861 Mdot
.50909 .67099 Mdot
.30586 .52773 Mdot
.49546 .65752 Mdot
.49477 .30723 Mdot
.66247 .57302 Mdot
.49368 .36083 Mdot
.53535 .63649 Mdot
.28888 .52165 Mdot
.49464 .32689 Mdot
.32707 .65171 Mdot
.48972 .71711 Mdot
.73795 .39765 Mdot
.33421 .41121 Mdot
.31116 .24394 Mdot
.57784 .67915 Mdot
.46826 .39711 Mdot
.29357 .23455 Mdot
.4008 .69631 Mdot
.29417 .51245 Mdot
.40267 .34584 Mdot
.58197 .77937 Mdot
.44822 .37267 Mdot
.58902 .46972 Mdot
.46168 .43126 Mdot
.41029 .56791 Mdot
.61892 .5808 Mdot
.3192 .48522 Mdot
.5303 .38003 Mdot
.4441 .36721 Mdot
.37143 .25636 Mdot
.53688 .39968 Mdot
.52492 .38091 Mdot
.30765 .55353 Mdot
.52553 .63501 Mdot
.43073 .34171 Mdot
.66379 .63318 Mdot
.35835 .71282 Mdot
.52272 .34958 Mdot
.64553 .56636 Mdot
.33203 .46543 Mdot
.53048 .36782 Mdot
.5128 .66731 Mdot
.46733 .38325 Mdot
.45852 .65924 Mdot
.32224 .47729 Mdot
.44362 .37045 Mdot
.72981 .42752 Mdot
.36528 .62178 Mdot
.35132 .50504 Mdot
.1927 .46994 Mdot
.46578 .3714 Mdot
.48549 .37884 Mdot
.29451 .50702 Mdot
.62906 .61145 Mdot
.558 .49183 Mdot
.28286 .51166 Mdot
.48444 .6291 Mdot
.32385 .47302 Mdot
.44002 .41047 Mdot
.63834 .61128 Mdot
.35092 .71559 Mdot
.36886 .70737 Mdot
.75656 .34849 Mdot
.48117 .33146 Mdot
.37938 .72211 Mdot
.64468 .58561 Mdot
.30358 .49675 Mdot
.49974 .66001 Mdot
.46072 .41817 Mdot
.32911 .52362 Mdot
.50155 .62222 Mdot
.71674 .40708 Mdot
.6785 .50889 Mdot
.35157 .51889 Mdot
.59267 .41248 Mdot
.50519 .61022 Mdot
.47703 .64281 Mdot
.53758 .22784 Mdot
.29823 .51362 Mdot
.70011 .41378 Mdot
.49694 .62832 Mdot
.65025 .2972 Mdot
.46775 .41955 Mdot
.60693 .23478 Mdot
.35276 .19172 Mdot
.52456 .22088 Mdot
.22017 .58909 Mdot
.69279 .44507 Mdot
.49339 .6302 Mdot
.5074 .34853 Mdot
.31892 .51284 Mdot
.31135 .50992 Mdot
.44006 .36948 Mdot
.47405 .34665 Mdot
.49351 .40922 Mdot
.45251 .40494 Mdot
.80704 .54256 Mdot
.48623 .41108 Mdot
.47477 .58273 Mdot
.33995 .52164 Mdot
.4827 .33823 Mdot
.61836 .55981 Mdot
.47816 .32587 Mdot
.53812 .62855 Mdot
.49571 .37192 Mdot
.4824 .34586 Mdot
.54105 .36548 Mdot
.482 .65448 Mdot
.45845 .83242 Mdot
.24597 .30699 Mdot
.67822 .73027 Mdot
.2446 .5838 Mdot
.63904 .59513 Mdot
.46446 .40433 Mdot
.68572 .42837 Mdot
.40477 .37915 Mdot
.48053 .37045 Mdot
.48262 .21029 Mdot
.47551 .35235 Mdot
.27394 .44912 Mdot
.42348 .42214 Mdot
.63409 .77956 Mdot
.42811 .62422 Mdot
.45543 .37365 Mdot
.293 .29419 Mdot
.62748 .23194 Mdot
.76565 .4297 Mdot
.51213 .66369 Mdot
.59968 .57388 Mdot
.61207 .60284 Mdot
.47575 .66022 Mdot
.4291 .36165 Mdot
.2302 .39587 Mdot
.47231 .30918 Mdot
.34695 .71282 Mdot
.36402 .46606 Mdot
.69383 .45011 Mdot
.35489 .51448 Mdot
.23358 .28257 Mdot
.48548 .49015 Mdot
.48628 .69858 Mdot
.71929 .44956 Mdot
.64618 .55512 Mdot
.34216 .70509 Mdot
.68718 .42113 Mdot
.52141 .37839 Mdot
.33522 .47745 Mdot
.62389 .22937 Mdot
.515 .44233 Mdot
.86142 .5287 Mdot
.30349 .52257 Mdot
.48051 .54682 Mdot
.51037 .66132 Mdot
.64318 .61529 Mdot
.45053 .36935 Mdot
.49919 .40024 Mdot
.36398 .48734 Mdot
.48039 .35948 Mdot
.41685 .52014 Mdot
.48424 .34828 Mdot
.65795 .61469 Mdot
.75109 .42371 Mdot
.47209 .66307 Mdot
.74776 .33408 Mdot
.28727 .52397 Mdot
.53623 .54867 Mdot
.6371 .56002 Mdot
.26374 .55025 Mdot
.53504 .64568 Mdot
.7236 .41071 Mdot
.60859 .57603 Mdot
.71138 .39757 Mdot
.53163 .34937 Mdot
.60993 .58649 Mdot
.71963 .42616 Mdot
.62493 .52597 Mdot
.52621 .37747 Mdot
.61059 .27275 Mdot
.49892 .63261 Mdot
.3624 .49984 Mdot
.46031 .37076 Mdot
.367 .71778 Mdot
.43449 .37478 Mdot
.38167 .72336 Mdot
.34761 .71983 Mdot
.3356 .70295 Mdot
.51399 .71778 Mdot
.67926 .42663 Mdot
.27297 .63173 Mdot
.52284 .49958 Mdot
.28145 .50711 Mdot
.53079 .39059 Mdot
.52752 .84043 Mdot
.49319 .63501 Mdot
.52023 .377 Mdot
.5958 .77474 Mdot
.49687 .62893 Mdot
.50474 .38347 Mdot
.48919 .66422 Mdot
.31499 .51301 Mdot
.55383 .51726 Mdot
.29881 .48144 Mdot
.51752 .36582 Mdot
.51572 .64071 Mdot
.60202 .576 Mdot
.31888 .49248 Mdot
.46977 .37958 Mdot
.47066 .40368 Mdot
.34592 .70598 Mdot
.47554 .34039 Mdot
.56033 .82266 Mdot
.49043 .35852 Mdot
.64479 .55377 Mdot
.53394 .405 Mdot
.60552 .2151 Mdot
.67943 .50681 Mdot
.32236 .53324 Mdot
.34161 .71751 Mdot
.61664 .58936 Mdot
.62013 .5027 Mdot
.68043 .47309 Mdot
.46944 .3913 Mdot
.36177 .70465 Mdot
.4873 .5498 Mdot
.51688 .66845 Mdot
.47874 .43248 Mdot
.44418 .50075 Mdot
.61911 .57084 Mdot
.34374 .70833 Mdot
.43395 .42772 Mdot
.32616 .46716 Mdot
.51017 .35696 Mdot
.60595 .58471 Mdot
.33581 .47107 Mdot
.46177 .42022 Mdot
.8074 .48733 Mdot
.36505 .71652 Mdot
.49701 .63576 Mdot
.55337 .30617 Mdot
.49177 .41371 Mdot
.61143 .60557 Mdot
.32054 .52101 Mdot
.52465 .6488 Mdot
.34032 .48688 Mdot
.65835 .24199 Mdot
.26371 .59093 Mdot
.74429 .61789 Mdot
.70051 .45898 Mdot
.21641 .66358 Mdot
.69956 .70832 Mdot
.29172 .60919 Mdot
.73204 .35417 Mdot
.73958 .71288 Mdot
.61396 .56451 Mdot
.52285 .25571 Mdot
.61982 .59769 Mdot
.51556 .34653 Mdot
.63242 .57684 Mdot
.59293 .82031 Mdot
.48433 .35383 Mdot
.63759 .59935 Mdot
.79168 .55136 Mdot
.46522 .35509 Mdot
.34648 .51853 Mdot
.32053 .76383 Mdot
.20852 .47459 Mdot
.53452 .47172 Mdot
.64 .60197 Mdot
.42896 .2305 Mdot
.47137 .35737 Mdot
.54762 .41751 Mdot
.3203 .50765 Mdot
.45625 .42916 Mdot
.71296 .44623 Mdot
.7244 .40129 Mdot
.54207 .23976 Mdot
.20749 .49611 Mdot
.57057 .39011 Mdot
.3159 .49718 Mdot
.32215 .23514 Mdot
.32655 .65425 Mdot
.37218 .70461 Mdot
.49437 .61845 Mdot
.45605 .83035 Mdot
.48933 .45834 Mdot
.59339 .38445 Mdot
.42475 .53329 Mdot
.31316 .48533 Mdot
.70337 .67581 Mdot
.52004 .64869 Mdot
.2785 .29562 Mdot
.26618 .39207 Mdot
.50265 .40719 Mdot
.51745 .67507 Mdot
.46647 .30371 Mdot
.41816 .53043 Mdot
.60562 .25558 Mdot
.68813 .64443 Mdot
.52347 .36975 Mdot
.28363 .63848 Mdot
.48661 .37421 Mdot
.62547 .2378 Mdot
.51843 .37098 Mdot
.34486 .49338 Mdot
.5572 .43096 Mdot
.63407 .47234 Mdot
.20496 .37765 Mdot
.46523 .48843 Mdot
.67869 .43645 Mdot
.48265 .39755 Mdot
.50291 .40379 Mdot
.71258 .43596 Mdot
.33192 .49205 Mdot
.51861 .40656 Mdot
.78781 .42032 Mdot
.49599 .41149 Mdot
.54177 .63783 Mdot
.5907 .4993 Mdot
.23015 .4903 Mdot
.44597 .3713 Mdot
.33552 .46906 Mdot
.5026 .66933 Mdot
.50294 .61608 Mdot
.55518 .42293 Mdot
.488 .6415 Mdot
.5039 .35439 Mdot
.57999 .50276 Mdot
.29972 .48822 Mdot
.42363 .33394 Mdot
.33603 .49666 Mdot
.39901 .20198 Mdot
.48386 .66234 Mdot
.36465 .69339 Mdot
.54625 .27489 Mdot
.5078 .64462 Mdot
.31347 .56404 Mdot
.49418 .46173 Mdot
.4804 .32077 Mdot
.24501 .54126 Mdot
.59967 .60059 Mdot
.35012 .69173 Mdot
.52401 .65429 Mdot
.4919 .41139 Mdot
.52926 .35599 Mdot
.53218 .66267 Mdot
.38141 .27251 Mdot
.74048 .48477 Mdot
.51428 .36738 Mdot
.34176 .49248 Mdot
.30588 .49598 Mdot
.48167 .42229 Mdot
.47624 .3698 Mdot
.63421 .55315 Mdot
.36342 .70323 Mdot
.33858 .70335 Mdot
.36866 .70357 Mdot
.60767 .62074 Mdot
.20393 .63537 Mdot
.47727 .64239 Mdot
.24448 .67086 Mdot
.52043 .78124 Mdot
.55538 .41848 Mdot
.60541 .60293 Mdot
.50107 .39209 Mdot
.52094 .34269 Mdot
.51973 .64021 Mdot
.18547 .52335 Mdot
.54079 .32492 Mdot
.35651 .51728 Mdot
.54031 .64889 Mdot
.41709 .33744 Mdot
.47237 .7059 Mdot
.72188 .43611 Mdot
.4732 .48362 Mdot
.52082 .67308 Mdot
.33415 .48023 Mdot
.52798 .66804 Mdot
.50006 .40598 Mdot
.45022 .34143 Mdot
.30176 .48993 Mdot
.67938 .4215 Mdot
.53307 .37041 Mdot
.50344 .38247 Mdot
.63152 .19921 Mdot
.32188 .6502 Mdot
.5412 .68062 Mdot
.50265 .3365 Mdot
.52285 .32302 Mdot
.67649 .42301 Mdot
.50159 .41272 Mdot
.44991 .37369 Mdot
.36639 .61332 Mdot
.47158 .64363 Mdot
.73052 .39569 Mdot
.25915 .3137 Mdot
.31061 .52456 Mdot
.57066 .81155 Mdot
.3583 .71474 Mdot
.46844 .64378 Mdot
.54527 .52152 Mdot
.35406 .69334 Mdot
.5506 .76516 Mdot
.64404 .74767 Mdot
.36353 .69508 Mdot
.65086 .54286 Mdot
.41196 .43903 Mdot
.44986 .40571 Mdot
.50017 .37452 Mdot
.68582 .41784 Mdot
.30714 .51755 Mdot
.44593 .59575 Mdot
.57256 .59347 Mdot
.48312 .38424 Mdot
.28564 .53768 Mdot
.60702 .7798 Mdot
.34477 .70238 Mdot
.68681 .43701 Mdot
.67973 .44706 Mdot
.48772 .37629 Mdot
.33123 .60122 Mdot
.31544 .49471 Mdot
.46995 .37968 Mdot
.4574 .40638 Mdot
.63244 .60842 Mdot
.34177 .48183 Mdot
.63957 .55948 Mdot
.35099 .72087 Mdot
.80385 .6417 Mdot
.65115 .20598 Mdot
.51016 .63087 Mdot
.69813 .69894 Mdot
.54866 .63954 Mdot
.63507 .66268 Mdot
.3651 .69995 Mdot
.47523 .38292 Mdot
.29352 .52861 Mdot
.46724 .38123 Mdot
.51511 .40405 Mdot
.52372 .39113 Mdot
.57009 .3828 Mdot
.49207 .20928 Mdot
.69279 .42702 Mdot
.53636 .32876 Mdot
.6053 .56234 Mdot
.62569 .77827 Mdot
.34539 .77829 Mdot
.48764 .40198 Mdot
.48816 .38075 Mdot
.32005 .53013 Mdot
.51905 .33137 Mdot
.52466 .66228 Mdot
.29963 .51816 Mdot
.52645 .35669 Mdot
.70229 .54983 Mdot
.49403 .41677 Mdot
.71263 .69072 Mdot
.52856 .66784 Mdot
.46394 .48009 Mdot
.4969 .3152 Mdot
.36534 .69611 Mdot
.35207 .69126 Mdot
.37177 .71496 Mdot
.51445 .67248 Mdot
.62766 .60785 Mdot
.57712 .59901 Mdot
.42589 .41066 Mdot
.50502 .34915 Mdot
.4813 .31929 Mdot
.60751 .62336 Mdot
.58932 .48714 Mdot
.23206 .59931 Mdot
.43073 .43518 Mdot
.59309 .58878 Mdot
.31281 .5501 Mdot
.1787 .43644 Mdot
.30919 .52157 Mdot
.74899 .40572 Mdot
.53737 .63107 Mdot
.71925 .44268 Mdot
.45267 .21702 Mdot
.3055 .48541 Mdot
.36567 .49468 Mdot
.63905 .59738 Mdot
.43798 .58178 Mdot
.11828 .61734 Mdot
.64795 .57424 Mdot
.75231 .38009 Mdot
.31986 .50305 Mdot
.55263 .36415 Mdot
.4882 .55208 Mdot
.44375 .57331 Mdot
.62881 .59434 Mdot
.46777 .3993 Mdot
.30923 .57009 Mdot
.63617 .55359 Mdot
.50572 .42963 Mdot
.64456 .60081 Mdot
.48502 .6566 Mdot
.64589 .58907 Mdot
.31755 .54265 Mdot
.52942 .34597 Mdot
.0912 .5444 Mdot
.40365 .66591 Mdot
.46096 .37662 Mdot
.54212 .64508 Mdot
.82006 .49259 Mdot
.51375 .39854 Mdot
.71101 .44833 Mdot
.59241 .59444 Mdot
.77275 .53976 Mdot
.46727 .36118 Mdot
.63063 .58518 Mdot
.34706 .53523 Mdot
.60558 .63829 Mdot
.55519 .68412 Mdot
.3412 .69838 Mdot
.31895 .51651 Mdot
.36042 .73029 Mdot
.48523 .61749 Mdot
.5372 .37165 Mdot
.46564 .41084 Mdot
.3463 .51148 Mdot
.50825 .73337 Mdot
.54814 .37693 Mdot
.46852 .39713 Mdot
.64229 .55649 Mdot
.58448 .60181 Mdot
.39762 .76169 Mdot
.61349 .56354 Mdot
.52449 .32353 Mdot
.34735 .50773 Mdot
.51636 .35278 Mdot
.34219 .52328 Mdot
.53087 .38854 Mdot
.23844 .50556 Mdot
.30907 .52059 Mdot
.2579 .56788 Mdot
.46302 .34694 Mdot
.512 .27722 Mdot
.51494 .40563 Mdot
.52321 .37994 Mdot
.59372 .60145 Mdot
.70739 .42271 Mdot
.50131 .43303 Mdot
.54609 .53437 Mdot
.69294 .40683 Mdot
.37699 .40108 Mdot
.62758 .61081 Mdot
.69791 .40846 Mdot
.62103 .31782 Mdot
.34139 .71717 Mdot
.6982 .43327 Mdot
.39388 .78792 Mdot
.5118 .63254 Mdot
.29664 .48751 Mdot
.46633 .35298 Mdot
.7613 .69659 Mdot
.74044 .48179 Mdot
.34988 .70186 Mdot
.46482 .36908 Mdot
.50545 .39225 Mdot
.31744 .46849 Mdot
.26402 .25572 Mdot
.65475 .61396 Mdot
.52495 .3648 Mdot
.2845 .50626 Mdot
.33589 .20599 Mdot
.65018 .59633 Mdot
.69367 .43581 Mdot
.52675 .67285 Mdot
.33596 .45345 Mdot
.34381 .69442 Mdot
.48492 .6659 Mdot
.66359 .53464 Mdot
.44779 .20796 Mdot
.47185 .36109 Mdot
.60106 .59371 Mdot
.52185 .21969 Mdot
.42239 .37144 Mdot
.55278 .62847 Mdot
.2975 .44989 Mdot
.31404 .48577 Mdot
.53449 .65956 Mdot
.67846 .43932 Mdot
.3 .48682 Mdot
.33174 .49073 Mdot
.51268 .61537 Mdot
.47416 .59244 Mdot
.47792 .54873 Mdot
.53907 .64229 Mdot
.40029 .58885 Mdot
.54843 .23437 Mdot
.36377 .70601 Mdot
.68678 .43813 Mdot
.66218 .2391 Mdot
.31241 .49449 Mdot
.45736 .83078 Mdot
.49353 .21173 Mdot
.52484 .38064 Mdot
.71574 .41474 Mdot
.55453 .77293 Mdot
.60194 .54426 Mdot
.5022 .62328 Mdot
.60251 .47234 Mdot
.69448 .45233 Mdot
.47114 .41795 Mdot
.23581 .4797 Mdot
.45663 .35656 Mdot
.49417 .63156 Mdot
.4057 .53906 Mdot
.34543 .48625 Mdot
.48314 .61929 Mdot
.42118 .51277 Mdot
.51785 .34037 Mdot
.45335 .38403 Mdot
.68386 .28006 Mdot
.33918 .47825 Mdot
.3427 .69456 Mdot
.46457 .3879 Mdot
.51123 .38169 Mdot
.53879 .37763 Mdot
.56339 .29254 Mdot
.33178 .61785 Mdot
.52649 .36572 Mdot
.62556 .61948 Mdot
.47246 .32576 Mdot
.45175 .37771 Mdot
.29967 .47861 Mdot
.57771 .1998 Mdot
.3578 .72161 Mdot
.50381 .37457 Mdot
.51366 .36802 Mdot
.48728 .62522 Mdot
.48247 .54948 Mdot
.43787 .57546 Mdot
.6582 .56788 Mdot
.70671 .34531 Mdot
.46764 .31261 Mdot
.33035 .52126 Mdot
.72672 .43634 Mdot
.53667 .34327 Mdot
.32043 .52722 Mdot
.44849 .33791 Mdot
.63066 .55198 Mdot
.36159 .70262 Mdot
.58539 .40021 Mdot
.70339 .43286 Mdot
.45702 .64502 Mdot
.27322 .70102 Mdot
.61582 .56005 Mdot
.49882 .34367 Mdot
.59958 .63011 Mdot
.6331 .56376 Mdot
.34719 .70639 Mdot
.44838 .43579 Mdot
.31235 .5072 Mdot
.34273 .48532 Mdot
.57874 .23851 Mdot
.63219 .62432 Mdot
.49107 .16262 Mdot
.48479 .65486 Mdot
.46301 .42577 Mdot
.32222 .74405 Mdot
.34911 .49301 Mdot
.67237 .25796 Mdot
.69434 .40955 Mdot
.50284 .62337 Mdot
.33903 .72201 Mdot
.32384 .5275 Mdot
.35427 .49679 Mdot
.52838 .3862 Mdot
.48969 .3961 Mdot
.74322 .36098 Mdot
.61654 .23502 Mdot
.4885 .66241 Mdot
.69607 .44187 Mdot
.66086 .57885 Mdot
.51168 .33916 Mdot
.29016 .50505 Mdot
.28261 .44229 Mdot
.4853 .4135 Mdot
.63862 .55345 Mdot
.30679 .48923 Mdot
.70721 .44111 Mdot
.71976 .41187 Mdot
.52379 .38186 Mdot
.36282 .38726 Mdot
.50333 .64352 Mdot
.35015 .51059 Mdot
.38366 .51319 Mdot
.54117 .39369 Mdot
.4866 .39917 Mdot
.46909 .29783 Mdot
.48259 .66384 Mdot
.58094 .41004 Mdot
.67458 .44792 Mdot
.30613 .51064 Mdot
.46239 .37979 Mdot
.70331 .43645 Mdot
.57717 .33031 Mdot
.35934 .69583 Mdot
.6465 .5983 Mdot
.7076 .44844 Mdot
.71522 .42302 Mdot
.70459 .40309 Mdot
.44306 .8273 Mdot
.31949 .4642 Mdot
.25388 .31277 Mdot
.52525 .39425 Mdot
.55604 .23908 Mdot
.47296 .33394 Mdot
.49458 .67411 Mdot
.59868 .57806 Mdot
.50978 .40616 Mdot
.52863 .38702 Mdot
.23997 .4822 Mdot
.43361 .30918 Mdot
.41236 .47562 Mdot
.32843 .47653 Mdot
.52562 .2757 Mdot
.60995 .60797 Mdot
.34021 .18862 Mdot
.43463 .84794 Mdot
.48643 .30803 Mdot
.45358 .57608 Mdot
.29747 .51613 Mdot
.49326 .62639 Mdot
.44794 .56368 Mdot
.48737 .68776 Mdot
.30171 .50812 Mdot
.5161 .34383 Mdot
.24758 .66911 Mdot
.71158 .39935 Mdot
.49169 .40853 Mdot
.50241 .66368 Mdot
.49253 .40887 Mdot
.50696 .67578 Mdot
.31471 .45455 Mdot
.40693 .6002 Mdot
.47707 .35276 Mdot
.54507 .37507 Mdot
.55068 .45144 Mdot
.48897 .40028 Mdot
.5924 .72067 Mdot
.32991 .49979 Mdot
.25562 .55561 Mdot
.49074 .42181 Mdot
.3568 .36468 Mdot
.47526 .41549 Mdot
.51104 .7367 Mdot
.45972 .40414 Mdot
.60175 .42627 Mdot
.46973 .41884 Mdot
.46294 .40312 Mdot
.52085 .6456 Mdot
.48888 .62578 Mdot
.3482 .53351 Mdot
.35293 .68875 Mdot
.63294 .77925 Mdot
.49641 .3837 Mdot
.59402 .60747 Mdot
.32903 .74124 Mdot
.71197 .42191 Mdot
.30343 .50526 Mdot
.43249 .14009 Mdot
.49692 .66854 Mdot
.67179 .58429 Mdot
.5531 .71494 Mdot
.65389 .6088 Mdot
.67099 .60829 Mdot
.49889 .27679 Mdot
.69398 .44345 Mdot
.47132 .41601 Mdot
.38178 .35149 Mdot
.2998 .64557 Mdot
.50684 .42754 Mdot
.57901 .62625 Mdot
.4101 .34781 Mdot
.54894 .23201 Mdot
.6926 .40059 Mdot
.69122 .44734 Mdot
.52301 .65238 Mdot
.6673 .57037 Mdot
.43698 .3378 Mdot
.70067 .40756 Mdot
.59848 .57442 Mdot
.37087 .69315 Mdot
.7434 .44953 Mdot
.31202 .49755 Mdot
.54484 .46711 Mdot
.30645 .69225 Mdot
.4921 .66483 Mdot
.54674 .53049 Mdot
.27163 .50907 Mdot
.35799 .46825 Mdot
.36608 .6921 Mdot
.59115 .57762 Mdot
.27983 .50997 Mdot
.53271 .36484 Mdot
.51353 .44332 Mdot
.48488 .37469 Mdot
.70068 .41009 Mdot
.45208 .39766 Mdot
.59975 .56811 Mdot
.49048 .64686 Mdot
.61854 .57877 Mdot
.50225 .64071 Mdot
.23566 .64375 Mdot
.47587 .36682 Mdot
.4852 .39674 Mdot
.53903 .51706 Mdot
.35714 .50554 Mdot
.39722 .29609 Mdot
.58799 .58316 Mdot
.6254 .60257 Mdot
.51795 .35224 Mdot
.35492 .52574 Mdot
.73926 .41806 Mdot
.48884 .55781 Mdot
.45946 .40613 Mdot
.3303 .501 Mdot
.51393 .35607 Mdot
.74123 .60263 Mdot
.39652 .63366 Mdot
.34228 .48757 Mdot
.19804 .38809 Mdot
.47576 .33863 Mdot
.39741 .39682 Mdot
.55805 .3532 Mdot
.67202 .37265 Mdot
.52611 .42217 Mdot
.29994 .52087 Mdot
.49189 .37093 Mdot
.32724 .51807 Mdot
.62728 .56096 Mdot
.48076 .63773 Mdot
.3224 .51396 Mdot
.45031 .35921 Mdot
.39402 .82367 Mdot
.49521 .66382 Mdot
.47629 .40224 Mdot
.53176 .64244 Mdot
.28501 .4978 Mdot
.35491 .4897 Mdot
.40593 .78294 Mdot
.49354 .70509 Mdot
.50011 .66597 Mdot
.50376 .35199 Mdot
.33652 .67224 Mdot
.51576 .35271 Mdot
.74183 .3552 Mdot
.49137 .4253 Mdot
.53172 .40908 Mdot
.22753 .68069 Mdot
.4772 .684 Mdot
.46202 .15476 Mdot
.57593 .5778 Mdot
.42642 .82177 Mdot
.28489 .47782 Mdot
.69313 .40033 Mdot
.68723 .70383 Mdot
.35427 .7201 Mdot
.61967 .61724 Mdot
.50896 .40688 Mdot
.23534 .49974 Mdot
.53956 .6472 Mdot
.70237 .42035 Mdot
.47643 .35238 Mdot
.64869 .55 Mdot
.37296 .78061 Mdot
.49426 .62883 Mdot
.30949 .49795 Mdot
.35733 .5098 Mdot
.28374 .26158 Mdot
.46317 .37655 Mdot
.48574 .39176 Mdot
.53808 .63039 Mdot
.43725 .34381 Mdot
.72048 .40441 Mdot
.7694 .58255 Mdot
.50809 .66457 Mdot
.40029 .66777 Mdot
.32394 .47639 Mdot
.50357 .39246 Mdot
.59971 .49695 Mdot
.48108 .79828 Mdot
.28143 .31664 Mdot
.68509 .42087 Mdot
.70691 .31941 Mdot
.3004 .52115 Mdot
.50207 .66144 Mdot
.57257 .26504 Mdot
.43525 .38861 Mdot
.5081 .39 Mdot
.70158 .31017 Mdot
.47912 .55687 Mdot
.6721 .46081 Mdot
.55501 .36318 Mdot
.49869 .53742 Mdot
.51883 .3512 Mdot
.52904 .35504 Mdot
.4853 .3073 Mdot
.44874 .38193 Mdot
.33036 .50766 Mdot
.23015 .45916 Mdot
.63827 .58255 Mdot
.36232 .2513 Mdot
.60889 .46074 Mdot
.45905 .36122 Mdot
.51756 .34259 Mdot
.21276 .44731 Mdot
.33014 .73587 Mdot
.32604 .4983 Mdot
.33039 .55382 Mdot
.47572 .64531 Mdot
.44055 .30332 Mdot
.62196 .62459 Mdot
.40718 .46006 Mdot
.62848 .56896 Mdot
.33132 .50178 Mdot
.62228 .60651 Mdot
.47687 .63357 Mdot
.60123 .59299 Mdot
.61098 .62129 Mdot
.50439 .68353 Mdot
.33578 .47363 Mdot
.46904 .40839 Mdot
.48437 .66212 Mdot
.69361 .28539 Mdot
.70208 .40976 Mdot
.40368 .78363 Mdot
.55154 .35351 Mdot
.39704 .43973 Mdot
.80702 .48631 Mdot
.61178 .59051 Mdot
.38052 .63481 Mdot
.30937 .52053 Mdot
.73142 .4336 Mdot
.32955 .51244 Mdot
.45371 .22553 Mdot
.71309 .43168 Mdot
.40295 .78545 Mdot
.5836 .27348 Mdot
.60272 .51721 Mdot
.44358 .35875 Mdot
.24934 .52007 Mdot
.62615 .56817 Mdot
.54204 .63677 Mdot
.57864 .77558 Mdot
.48819 .32952 Mdot
.28768 .61057 Mdot
.33489 .46179 Mdot
.33932 .71276 Mdot
.49824 .65849 Mdot
.56041 .61795 Mdot
.46594 .37356 Mdot
.59715 .51431 Mdot
.51591 .42134 Mdot
.5343 .26362 Mdot
.71824 .34286 Mdot
.32345 .44695 Mdot
.50853 .35706 Mdot
.65189 .56211 Mdot
.51153 .35496 Mdot
.43025 .44381 Mdot
.53507 .22888 Mdot
.54127 .34124 Mdot
.25703 .58004 Mdot
.78425 .52259 Mdot
.29687 .4948 Mdot
.52609 .32282 Mdot
.35432 .70712 Mdot
.49423 .33399 Mdot
.82877 .65006 Mdot
.69955 .43032 Mdot
.64586 .53007 Mdot
.44796 .35968 Mdot
.46561 .38486 Mdot
.34929 .41936 Mdot
.25917 .50396 Mdot
.34219 .72291 Mdot
.51261 .38951 Mdot
.69076 .32089 Mdot
.52527 .64579 Mdot
.4661 .42343 Mdot
.4941 .37343 Mdot
.70363 .26729 Mdot
.52754 .64233 Mdot
.60849 .59545 Mdot
.34348 .71864 Mdot
.65939 .57825 Mdot
.69965 .3968 Mdot
.4336 .56301 Mdot
.64966 .2435 Mdot
.39576 .63641 Mdot
.70673 .45122 Mdot
.44358 .38363 Mdot
.39306 .39698 Mdot
.45753 .38712 Mdot
.68698 .44524 Mdot
.5293 .65342 Mdot
.32753 .50738 Mdot
.58036 .43375 Mdot
.34716 .71201 Mdot
.51712 .42377 Mdot
.68395 .40708 Mdot
.31739 .51034 Mdot
.42789 .76558 Mdot
.30107 .51324 Mdot
.51196 .64518 Mdot
.47359 .65294 Mdot
.71026 .42882 Mdot
.33086 .51033 Mdot
.65057 .60155 Mdot
.57149 .59039 Mdot
.49965 .4248 Mdot
.56061 .6388 Mdot
.32194 .53929 Mdot
.36373 .49687 Mdot
.30303 .53163 Mdot
.47376 .36438 Mdot
.4697 .56221 Mdot
.43366 .38125 Mdot
.50883 .66851 Mdot
.62963 .61329 Mdot
.60207 .23488 Mdot
.37963 .35004 Mdot
.40062 .66327 Mdot
.50959 .43074 Mdot
.45148 .38415 Mdot
.48749 .37646 Mdot
.50983 .36341 Mdot
.75859 .59642 Mdot
.47759 .36729 Mdot
.51097 .63946 Mdot
.6394 .56986 Mdot
.46257 .37109 Mdot
.35751 .70679 Mdot
.54108 .49773 Mdot
.72484 .43876 Mdot
.60386 .43043 Mdot
.43678 .84046 Mdot
.31849 .50943 Mdot
.60569 .57748 Mdot
.63937 .60973 Mdot
.71697 .40715 Mdot
.48332 .65123 Mdot
.30654 .5164 Mdot
.64722 .37339 Mdot
.69003 .40749 Mdot
.50485 .37455 Mdot
.5657 .50823 Mdot
.18853 .40954 Mdot
.44171 .38537 Mdot
.52181 .39033 Mdot
.33537 .7067 Mdot
.65802 .6076 Mdot
.75062 .72897 Mdot
.45279 .59795 Mdot
.70833 .42444 Mdot
.71312 .4413 Mdot
.29535 .52478 Mdot
.47391 .43094 Mdot
.49841 .64409 Mdot
.49632 .54602 Mdot
.81673 .46827 Mdot
.57261 .79234 Mdot
.61968 .66656 Mdot
.49925 .41524 Mdot
.28929 .4218 Mdot
.52913 .40149 Mdot
.33042 .46503 Mdot
.30841 .53035 Mdot
.32095 .49701 Mdot
.52035 .64725 Mdot
.40293 .20335 Mdot
.50844 .63801 Mdot
.43879 .84226 Mdot
.28819 .50153 Mdot
.66018 .50324 Mdot
.6317 .60391 Mdot
.43256 .41874 Mdot
.69187 .44219 Mdot
.58142 .63922 Mdot
.51615 .3179 Mdot
.32177 .60208 Mdot
.60543 .60276 Mdot
.35094 .48272 Mdot
.46294 .45398 Mdot
.65672 .77143 Mdot
.42679 .58741 Mdot
.78268 .44397 Mdot
.44101 .24523 Mdot
.71224 .43561 Mdot
.2456 .35106 Mdot
.71438 .40111 Mdot
.49916 .62485 Mdot
.48516 .33023 Mdot
.45752 .34979 Mdot
.52321 .3663 Mdot
.48018 .36502 Mdot
.52494 .65398 Mdot
.50862 .41653 Mdot
.60408 .21513 Mdot
.36388 .71367 Mdot
.67103 .51369 Mdot
.72437 .42278 Mdot
.50036 .67844 Mdot
.6371 .56599 Mdot
.35875 .68801 Mdot
.74248 .32534 Mdot
.50794 .41477 Mdot
.51216 .40654 Mdot
.37072 .70447 Mdot
.43757 .34617 Mdot
.48234 .45679 Mdot
.63439 .58171 Mdot
.4424 .5199 Mdot
.68006 .44498 Mdot
.71948 .44213 Mdot
.52436 .67017 Mdot
.32986 .51246 Mdot
.68706 .41508 Mdot
.66372 .56272 Mdot
.45968 .41862 Mdot
.54575 .36524 Mdot
.32316 .53951 Mdot
.4937 .21164 Mdot
.72239 .39781 Mdot
.48852 .46394 Mdot
.3214 .52308 Mdot
.3301 .4621 Mdot
.51185 .39186 Mdot
.52536 .42758 Mdot
.35566 .47927 Mdot
.72624 .42435 Mdot
.50333 .6798 Mdot
.64147 .50193 Mdot
.49028 .64163 Mdot
.31379 .51596 Mdot
.43695 .36315 Mdot
.33144 .47426 Mdot
.47845 .33802 Mdot
.20353 .28104 Mdot
.44948 .38912 Mdot
.2724 .55781 Mdot
.68381 .37042 Mdot
.64791 .59929 Mdot
.65442 .59241 Mdot
.36023 .70436 Mdot
.31231 .52391 Mdot
.53463 .34262 Mdot
.70531 .44506 Mdot
.41218 .8133 Mdot
.38213 .49327 Mdot
.59726 .6022 Mdot
.64425 .61817 Mdot
.52712 .65534 Mdot
.46898 .41398 Mdot
.5001 .39046 Mdot
.60224 .5937 Mdot
.81123 .51132 Mdot
.33536 .51763 Mdot
.48538 .39169 Mdot
.45103 .37778 Mdot
.64011 .57997 Mdot
.57086 .58617 Mdot
.26512 .51412 Mdot
.4492 .38192 Mdot
.59358 .28067 Mdot
.50351 .67456 Mdot
.49488 .35611 Mdot
.5157 .41223 Mdot
.71057 .41689 Mdot
.69251 .52669 Mdot
.54345 .23146 Mdot
.48594 .67075 Mdot
.33988 .69913 Mdot
.47817 .332 Mdot
.63371 .60139 Mdot
.55201 .36341 Mdot
.73475 .68443 Mdot
.35854 .7174 Mdot
.47458 .37702 Mdot
.4694 .31401 Mdot
.35012 .51656 Mdot
.47165 .37932 Mdot
.25169 .48354 Mdot
.65404 .56986 Mdot
.47388 .37596 Mdot
.36504 .37807 Mdot
.52499 .65802 Mdot
.51454 .31808 Mdot
.70731 .44693 Mdot
.67851 .37527 Mdot
.2882 .70427 Mdot
.59866 .61687 Mdot
.72087 .41444 Mdot
.4532 .40014 Mdot
.64944 .55703 Mdot
.52767 .67217 Mdot
.29541 .60302 Mdot
.44489 .39882 Mdot
.48669 .6507 Mdot
.49004 .65173 Mdot
.70653 .42813 Mdot
.41786 .15781 Mdot
.46724 .31422 Mdot
.48373 .40466 Mdot
.8138 .40575 Mdot
.28077 .49618 Mdot
.48074 .40665 Mdot
.4683 .41261 Mdot
.5002 .63259 Mdot
.57369 .2888 Mdot
.3961 .51482 Mdot
.7918 .55153 Mdot
.50435 .67585 Mdot
.60479 .55396 Mdot
.63975 .55772 Mdot
.72278 .41852 Mdot
.29853 .49479 Mdot
.69208 .45366 Mdot
.64192 .59148 Mdot
.52322 .37825 Mdot
.51374 .62259 Mdot
.31937 .30461 Mdot
.54287 .63209 Mdot
.65041 .55258 Mdot
.349 .47083 Mdot
.31581 .74397 Mdot
.85161 .42556 Mdot
.29914 .68332 Mdot
.48953 .67701 Mdot
.71195 .42157 Mdot
.46262 .58981 Mdot
.45195 .38508 Mdot
.24938 .33333 Mdot
.48724 .40746 Mdot
.44659 .23995 Mdot
.59785 .57779 Mdot
.36967 .69522 Mdot
.49032 .32876 Mdot
.70341 .3205 Mdot
.49057 .67649 Mdot
.52331 .6626 Mdot
.50615 .36886 Mdot
.5096 .64409 Mdot
.49364 .3904 Mdot
.6434 .57529 Mdot
.42729 .15947 Mdot
.45814 .39806 Mdot
.52308 .32686 Mdot
.47064 .6444 Mdot
.40282 .78422 Mdot
.60543 .55604 Mdot
.29887 .42165 Mdot
.67331 .76537 Mdot
.50624 .6457 Mdot
.56519 .37384 Mdot
.6087 .58593 Mdot
.33524 .70378 Mdot
.68079 .57717 Mdot
.49655 .4044 Mdot
.51282 .40952 Mdot
.52147 .35697 Mdot
.45281 .38099 Mdot
.23491 .35547 Mdot
.45055 .44307 Mdot
.28441 .39312 Mdot
.51602 .40395 Mdot
.2869 .55805 Mdot
.51616 .63956 Mdot
.39773 .46593 Mdot
.66612 .45472 Mdot
.51448 .40964 Mdot
.25858 .5088 Mdot
.49553 .67675 Mdot
.45849 .84137 Mdot
.5282 .64729 Mdot
.61797 .58553 Mdot
.49893 .62006 Mdot
.47336 .34151 Mdot
.30757 .49448 Mdot
.64866 .56867 Mdot
.23437 .60958 Mdot
.61467 .61611 Mdot
.46124 .37636 Mdot
.59996 .53579 Mdot
.64565 .60207 Mdot
.5742 .46713 Mdot
.30459 .49485 Mdot
.67771 .3084 Mdot
.28366 .49104 Mdot
.47295 .38498 Mdot
.47286 .39096 Mdot
.35769 .68707 Mdot
.49359 .62955 Mdot
.28552 .50167 Mdot
.6264 .19747 Mdot
.6723 .42018 Mdot
.3239 .49055 Mdot
.50964 .43731 Mdot
.46387 .57116 Mdot
.35027 .5039 Mdot
.68322 .34473 Mdot
.49284 .63254 Mdot
.28775 .52048 Mdot
.45265 .43505 Mdot
.59612 .37313 Mdot
.72914 .40803 Mdot
.62893 .55157 Mdot
.50426 .52061 Mdot
.64441 .55956 Mdot
.48966 .61198 Mdot
.65143 .61932 Mdot
.52323 .64212 Mdot
.23697 .53321 Mdot
.40704 .5334 Mdot
.48162 .61523 Mdot
.47499 .63324 Mdot
.6354 .59167 Mdot
.5112 .36502 Mdot
.62837 .47677 Mdot
.50066 .43813 Mdot
.44707 .34632 Mdot
.49598 .67213 Mdot
.29706 .52037 Mdot
.31603 .47629 Mdot
.25749 .53212 Mdot
.3561 .49546 Mdot
.64183 .56402 Mdot
.39121 .62616 Mdot
.44186 .23168 Mdot
.53444 .6443 Mdot
.49408 .6973 Mdot
.51479 .34989 Mdot
.63576 .59759 Mdot
.62499 .55982 Mdot
.4953 .64129 Mdot
.31293 .2823 Mdot
.49841 .31759 Mdot
.3028 .47531 Mdot
.28833 .50036 Mdot
.34878 .50076 Mdot
.33172 .53385 Mdot
.36663 .21463 Mdot
.5421 .63668 Mdot
.30112 .52024 Mdot
.49172 .36596 Mdot
.4995 .41253 Mdot
.34068 .70564 Mdot
.7219 .43236 Mdot
.48729 .32548 Mdot
.49532 .32201 Mdot
.51051 .39277 Mdot
.6458 .60039 Mdot
.42127 .34501 Mdot
.35472 .71717 Mdot
.65072 .61837 Mdot
.61555 .62373 Mdot
.36299 .69238 Mdot
.38711 .47751 Mdot
.64372 .78942 Mdot
.5245 .36424 Mdot
.44707 .28357 Mdot
.63078 .59876 Mdot
.379 .58214 Mdot
.57955 .40447 Mdot
.50293 .35474 Mdot
.64907 .4661 Mdot
.64586 .57318 Mdot
.36577 .46899 Mdot
.49065 .4031 Mdot
.36722 .70269 Mdot
.72872 .43013 Mdot
.46665 .43822 Mdot
.33502 .70743 Mdot
.33333 .50265 Mdot
.78519 .49712 Mdot
.27864 .50415 Mdot
.64849 .60122 Mdot
.52269 .32088 Mdot
.10317 .59266 Mdot
.62478 .56803 Mdot
.48819 .82286 Mdot
.4141 .52432 Mdot
.45436 .39397 Mdot
.63889 .55972 Mdot
.36063 .46677 Mdot
.50268 .67428 Mdot
.52471 .51948 Mdot
.29049 .50429 Mdot
.36232 .68907 Mdot
.34557 .69539 Mdot
.63835 .58134 Mdot
.32045 .48055 Mdot
.49523 .42307 Mdot
.33651 .52724 Mdot
.51077 .61646 Mdot
.48202 .3453 Mdot
.63491 .77919 Mdot
.51524 .44271 Mdot
.32145 .5242 Mdot
.6624 .55826 Mdot
.67744 .42315 Mdot
.47699 .35395 Mdot
.54997 .81799 Mdot
.46612 .41307 Mdot
.53148 .647 Mdot
.3649 .57501 Mdot
.30513 .31763 Mdot
.5173 .36991 Mdot
.51751 .34624 Mdot
.5216 .67394 Mdot
.51979 .37118 Mdot
.44634 .39759 Mdot
.5546 .62452 Mdot
.35291 .50511 Mdot
.48219 .37778 Mdot
.62248 .55623 Mdot
.44037 .26266 Mdot
.50567 .32774 Mdot
.2342 .57279 Mdot
.69014 .31283 Mdot
.37181 .56529 Mdot
.53484 .34009 Mdot
.69629 .28299 Mdot
.47565 .39471 Mdot
.47801 .35928 Mdot
.51862 .36084 Mdot
.27062 .42843 Mdot
.63888 .59306 Mdot
.5918 .58459 Mdot
.7331 .41713 Mdot
.69488 .31936 Mdot
.71188 .41332 Mdot
.50818 .68098 Mdot
.51143 .72001 Mdot
.36307 .71326 Mdot
.32892 .51461 Mdot
.52988 .34869 Mdot
.61732 .61898 Mdot
.50285 .39536 Mdot
.495 .33508 Mdot
.64852 .58079 Mdot
.6331 .56133 Mdot
.62171 .62716 Mdot
.70088 .4018 Mdot
.32303 .50367 Mdot
.52712 .38053 Mdot
.69101 .4079 Mdot
.48212 .42357 Mdot
.46626 .57415 Mdot
.32383 .50107 Mdot
.33857 .52657 Mdot
.30314 .47983 Mdot
.52468 .39614 Mdot
.46772 .34704 Mdot
.50705 .63759 Mdot
.31802 .5395 Mdot
.53655 .64492 Mdot
.64105 .56033 Mdot
.65301 .59236 Mdot
.49675 .4047 Mdot
.47399 .46052 Mdot
.71675 .43608 Mdot
.61497 .58922 Mdot
.36751 .7189 Mdot
.73307 .41901 Mdot
.46541 .36849 Mdot
.64465 .56102 Mdot
.71681 .44474 Mdot
.35311 .26636 Mdot
.7018 .74804 Mdot
.68004 .41422 Mdot
.50516 .36908 Mdot
.35935 .4102 Mdot
.57898 .25925 Mdot
.6702 .427 Mdot
.52967 .6337 Mdot
.47577 .41331 Mdot
.82123 .51482 Mdot
.68324 .45015 Mdot
.4989 .21311 Mdot
.64858 .58615 Mdot
.52929 .27079 Mdot
.46762 .4394 Mdot
.29391 .2835 Mdot
.6862 .4527 Mdot
.30772 .51424 Mdot
.29158 .53065 Mdot
.50851 .37313 Mdot
.66549 .44006 Mdot
.52221 .61477 Mdot
.64046 .60963 Mdot
.60558 .61763 Mdot
.32566 .47966 Mdot
.39802 .65092 Mdot
.62865 .5553 Mdot
.53091 .32178 Mdot
.66532 .54744 Mdot
.47261 .28894 Mdot
.30499 .25002 Mdot
.23024 .62071 Mdot
.54245 .36557 Mdot
.67566 .42499 Mdot
.51109 .68414 Mdot
.50738 .64009 Mdot
.51779 .64844 Mdot
.65635 .58317 Mdot
.46579 .55357 Mdot
.59887 .59274 Mdot
.29403 .61977 Mdot
.70238 .43703 Mdot
.65852 .30744 Mdot
.52805 .33793 Mdot
.45411 .39209 Mdot
.46115 .42078 Mdot
.52256 .35649 Mdot
.47718 .39459 Mdot
.49068 .66343 Mdot
.65655 .60011 Mdot
.77673 .54242 Mdot
.34339 .4958 Mdot
.42181 .74996 Mdot
.6312 .60434 Mdot
.33827 .71467 Mdot
.69349 .42377 Mdot
.64904 .24701 Mdot
.60154 .55259 Mdot
.62285 .60592 Mdot
.44493 .40289 Mdot
.30496 .52627 Mdot
.57098 .30259 Mdot
.46855 .39739 Mdot
.61375 .5901 Mdot
.67241 .57066 Mdot
.25707 .3417 Mdot
.50296 .29701 Mdot
.74464 .41401 Mdot
.46161 .57148 Mdot
.68142 .4533 Mdot
.53443 .41873 Mdot
.37777 .58543 Mdot
.64051 .58995 Mdot
.62329 .58145 Mdot
.6756 .41749 Mdot
.40304 .42528 Mdot
.30897 .48612 Mdot
.37058 .69675 Mdot
.52615 .6343 Mdot
.46245 .39292 Mdot
.6564 .57673 Mdot
.42664 .30731 Mdot
.56034 .51226 Mdot
.51383 .66048 Mdot
.65199 .61696 Mdot
.47792 .41582 Mdot
.51318 .37228 Mdot
.71436 .4326 Mdot
.70881 .48448 Mdot
.48939 .4403 Mdot
.42733 .82215 Mdot
.41136 .58713 Mdot
.46502 .49074 Mdot
.50773 .38984 Mdot
.33917 .4799 Mdot
.3654 .6993 Mdot
.68565 .43745 Mdot
.47848 .42162 Mdot
.68054 .77046 Mdot
.3076 .54459 Mdot
.49562 .66214 Mdot
.36663 .69921 Mdot
.47409 .54626 Mdot
.46425 .41251 Mdot
.48733 .40727 Mdot
.47645 .36471 Mdot
.69398 .76662 Mdot
.59551 .57814 Mdot
.31155 .53533 Mdot
.68644 .41894 Mdot
.35159 .52019 Mdot
.59345 .59478 Mdot
.52872 .49256 Mdot
.46311 .36689 Mdot
.31 .47276 Mdot
.30415 .51278 Mdot
.52681 .65655 Mdot
.48608 .66736 Mdot
.58113 .60162 Mdot
.45141 .39355 Mdot
.36743 .70835 Mdot
.2887 .51691 Mdot
.66424 .59359 Mdot
.71279 .43329 Mdot
.47826 .65645 Mdot
.51845 .40223 Mdot
.638 .58523 Mdot
.53311 .40025 Mdot
.34324 .52015 Mdot
.62462 .60558 Mdot
.33673 .71583 Mdot
.71748 .43726 Mdot
.51603 .4065 Mdot
.79604 .49603 Mdot
.36784 .69674 Mdot
.45486 .35719 Mdot
.37723 .41894 Mdot
.65829 .44074 Mdot
.23171 .60512 Mdot
.60228 .57675 Mdot
.35632 .71253 Mdot
.30801 .5316 Mdot
.58977 .34973 Mdot
.62704 .57596 Mdot
.30517 .44032 Mdot
.64821 .48478 Mdot
.52515 .37484 Mdot
.32265 .48647 Mdot
.72035 .45882 Mdot
.45886 .83413 Mdot
.59722 .26926 Mdot
.48502 .38706 Mdot
.6441 .55913 Mdot
.72083 .44116 Mdot
.53355 .6514 Mdot
.23592 .57307 Mdot
.29942 .25948 Mdot
.64441 .62034 Mdot
.53032 .37616 Mdot
.29078 .51858 Mdot
.49425 .64477 Mdot
.23974 .66029 Mdot
.66108 .55943 Mdot
.60707 .56648 Mdot
.46949 .36085 Mdot
.68301 .42308 Mdot
.80934 .53754 Mdot
.59418 .57755 Mdot
.65964 .58208 Mdot
.41127 .75684 Mdot
.71228 .39725 Mdot
.49439 .36785 Mdot
.25721 .53183 Mdot
.45913 .41698 Mdot
.43876 .81756 Mdot
.35971 .71227 Mdot
.34396 .49883 Mdot
.49405 .41068 Mdot
.78235 .52637 Mdot
.63105 .56845 Mdot
.45313 .57543 Mdot
.50986 .59736 Mdot
.48343 .6566 Mdot
.65519 .57591 Mdot
.4954 .39859 Mdot
.4735 .65629 Mdot
.71827 .43325 Mdot
.44909 .38234 Mdot
.47348 .34254 Mdot
.35102 .46456 Mdot
.51401 .6196 Mdot
.44789 .2658 Mdot
.49804 .61481 Mdot
.52843 .66731 Mdot
.32588 .46166 Mdot
.50712 .3739 Mdot
.61669 .59495 Mdot
.63998 .54928 Mdot
.50924 .41778 Mdot
.38284 .58061 Mdot
.31302 .48529 Mdot
.66928 .53322 Mdot
.75107 .72494 Mdot
.4693 .30998 Mdot
.36366 .72065 Mdot
.48969 .25307 Mdot
.51832 .66922 Mdot
.52167 .38147 Mdot
.32948 .5196 Mdot
.66144 .58977 Mdot
.63045 .55383 Mdot
.44264 .40525 Mdot
.49232 .64278 Mdot
.719 .4457 Mdot
.61513 .56405 Mdot
.5542 .51613 Mdot
.47066 .37529 Mdot
.28514 .60923 Mdot
.61078 .56937 Mdot
.3436 .79164 Mdot
.77937 .53352 Mdot
.33912 .48613 Mdot
.50372 .33833 Mdot
.35561 .5219 Mdot
.69048 .41575 Mdot
.6802 .58607 Mdot
.49188 .64125 Mdot
.50522 .4715 Mdot
.689 .24599 Mdot
.63936 .59738 Mdot
.33032 .50591 Mdot
.52556 .38835 Mdot
.53196 .45846 Mdot
.4599 .4051 Mdot
.59159 .31614 Mdot
.75595 .39878 Mdot
.47526 .63656 Mdot
.5293 .65871 Mdot
.51784 .34069 Mdot
.71253 .40194 Mdot
.61544 .5544 Mdot
.64768 .58342 Mdot
.34023 .18354 Mdot
.33433 .71139 Mdot
.7422 .36865 Mdot
.52274 .39867 Mdot
.65951 .60162 Mdot
.38314 .33979 Mdot
.53802 .63056 Mdot
.48872 .42901 Mdot
.64143 .61501 Mdot
.47216 .79002 Mdot
.47306 .56591 Mdot
.47741 .38011 Mdot
.43616 .34496 Mdot
.53045 .64028 Mdot
.46055 .59084 Mdot
.6 .59448 Mdot
.47768 .42611 Mdot
.51507 .60617 Mdot
.39606 .77344 Mdot
.66086 .22588 Mdot
.32276 .50325 Mdot
.66589 .561 Mdot
.48498 .65853 Mdot
.43535 .32579 Mdot
.72483 .42481 Mdot
.66105 .57266 Mdot
.62756 .61538 Mdot
.49031 .3424 Mdot
.49965 .32448 Mdot
.48487 .30253 Mdot
.3321 .49309 Mdot
.50739 .63251 Mdot
.51247 .33322 Mdot
.40597 .62957 Mdot
.52645 .36253 Mdot
.50391 .63347 Mdot
.09665 .46886 Mdot
.4399 .3852 Mdot
.47425 .40703 Mdot
.63267 .40759 Mdot
.30647 .48294 Mdot
.35513 .50741 Mdot
.40011 .61585 Mdot
.52222 .39961 Mdot
.61863 .50649 Mdot
.32322 .5068 Mdot
.31268 .48675 Mdot
.64739 .5079 Mdot
.4857 .34733 Mdot
.455 .64344 Mdot
.4979 .6423 Mdot
.48394 .65942 Mdot
.34803 .51915 Mdot
.43471 .42096 Mdot
.52397 .67589 Mdot
.21928 .3787 Mdot
.62886 .60735 Mdot
.3772 .5858 Mdot
.33069 .52733 Mdot
.62406 .49354 Mdot
.49576 .62838 Mdot
.39641 .84004 Mdot
.60385 .39154 Mdot
.52017 .41616 Mdot
.51375 .37015 Mdot
.71443 .41884 Mdot
.54836 .43238 Mdot
.33893 .70133 Mdot
.51185 .64391 Mdot
.73341 .62315 Mdot
.32064 .49635 Mdot
.46912 .40631 Mdot
.60879 .23665 Mdot
.25408 .66137 Mdot
.26552 .5788 Mdot
.29486 .49842 Mdot
.31593 .4924 Mdot
.60609 .60555 Mdot
.63465 .60893 Mdot
.48576 .36997 Mdot
.51892 .64426 Mdot
.28585 .52219 Mdot
.51382 .62833 Mdot
.64182 .59045 Mdot
.6231 .60327 Mdot
.35369 .71859 Mdot
.42484 .39111 Mdot
.65101 .58992 Mdot
.41587 .77305 Mdot
.40795 .62436 Mdot
.37062 .47679 Mdot
.84503 .42041 Mdot
.23579 .65962 Mdot
.64146 .39723 Mdot
.73015 .42717 Mdot
.34264 .68191 Mdot
.49021 .62774 Mdot
.5194 .34304 Mdot
.50681 .4035 Mdot
.34515 .70142 Mdot
.48338 .6442 Mdot
.69858 .41889 Mdot
.49431 .62821 Mdot
.6893 .43761 Mdot
.58892 .58411 Mdot
.50098 .32682 Mdot
.4551 .40623 Mdot
.50439 .66666 Mdot
.60719 .59712 Mdot
.64806 .60081 Mdot
.73057 .41606 Mdot
.65331 .25423 Mdot
.63948 .58232 Mdot
.3315 .52749 Mdot
.39845 .27148 Mdot
.34546 .6962 Mdot
.4899 .40269 Mdot
.63108 .23756 Mdot
.26339 .32748 Mdot
.52664 .37432 Mdot
.36712 .69885 Mdot
.36136 .17024 Mdot
.48737 .32891 Mdot
.31969 .21535 Mdot
.35174 .71568 Mdot
.32838 .47383 Mdot
.60869 .58194 Mdot
.34136 .69548 Mdot
.42395 .34174 Mdot
.75696 .4161 Mdot
.53971 .34025 Mdot
.29063 .49949 Mdot
.32599 .46972 Mdot
.4178 .5299 Mdot
.44402 .81789 Mdot
.67933 .4319 Mdot
.70073 .42343 Mdot
.62983 .57504 Mdot
.47804 .71477 Mdot
.54194 .39813 Mdot
.7037 .422 Mdot
.75584 .62145 Mdot
.51343 .35071 Mdot
.73467 .34659 Mdot
.64521 .46427 Mdot
.33549 .47875 Mdot
.39804 .48063 Mdot
.62981 .57156 Mdot
.32983 .5055 Mdot
.49185 .4996 Mdot
.46229 .42104 Mdot
.32302 .49892 Mdot
.50286 .6314 Mdot
.57104 .75271 Mdot
.35851 .4977 Mdot
.53007 .51876 Mdot
.49833 .64545 Mdot
.65973 .44228 Mdot
.63138 .32931 Mdot
.81541 .68728 Mdot
.51386 .64357 Mdot
.61048 .58726 Mdot
.65123 .59312 Mdot
.64134 .57781 Mdot
.29009 .50308 Mdot
.62776 .56166 Mdot
.3398 .49853 Mdot
.58018 .57462 Mdot
.68297 .27121 Mdot
.70979 .43134 Mdot
.52957 .69064 Mdot
.30627 .50591 Mdot
.32651 .63414 Mdot
.81725 .37837 Mdot
.50138 .36705 Mdot
.50167 .61085 Mdot
.67415 .42572 Mdot
.3948 .68546 Mdot
.71033 .41625 Mdot
.60805 .58596 Mdot
.37565 .58697 Mdot
.49301 .38951 Mdot
.25677 .47106 Mdot
.70314 .44686 Mdot
.29213 .50137 Mdot
.45119 .36783 Mdot
.57775 .60776 Mdot
.71738 .4126 Mdot
.72848 .42922 Mdot
.4788 .39659 Mdot
.34664 .48031 Mdot
.6186 .60059 Mdot
.48526 .62906 Mdot
.69065 .46439 Mdot
.42008 .38818 Mdot
.51447 .3656 Mdot
.45529 .42308 Mdot
.43756 .57951 Mdot
.81565 .53047 Mdot
.50463 .6468 Mdot
.57632 .25224 Mdot
.6447 .59842 Mdot
.59667 .27513 Mdot
.32792 .65593 Mdot
.55193 .66542 Mdot
.35881 .71339 Mdot
.3613 .71168 Mdot
.47814 .3853 Mdot
.80652 .56487 Mdot
.26368 .56138 Mdot
.54456 .62177 Mdot
.35282 .69298 Mdot
.64745 .60146 Mdot
.31146 .54145 Mdot
.41268 .46922 Mdot
.46456 .33794 Mdot
.48378 .66504 Mdot
.64344 .58543 Mdot
.73665 .683 Mdot
.70154 .43553 Mdot
.37857 .62209 Mdot
.46125 .37118 Mdot
.48616 .39433 Mdot
.50116 .65622 Mdot
.50657 .63817 Mdot
.26051 .59317 Mdot
.41921 .54321 Mdot
.59407 .77943 Mdot
.45566 .65119 Mdot
.75487 .6668 Mdot
.26693 .50039 Mdot
.3258 .5231 Mdot
.34829 .72009 Mdot
.52022 .67685 Mdot
.48284 .4083 Mdot
.32482 .47407 Mdot
.26849 .57764 Mdot
.3372 .45871 Mdot
.7243 .34115 Mdot
.63219 .49995 Mdot
.45638 .37476 Mdot
.31044 .52865 Mdot
.32836 .50352 Mdot
.34524 .52937 Mdot
.36274 .69297 Mdot
.51082 .3887 Mdot
.50973 .36444 Mdot
.48344 .33116 Mdot
.51657 .46218 Mdot
.47089 .37859 Mdot
.33408 .65871 Mdot
.40256 .66854 Mdot
.72022 .57003 Mdot
.52965 .3834 Mdot
.48585 .64578 Mdot
.53087 .35086 Mdot
.71728 .40383 Mdot
.53132 .38135 Mdot
.75033 .36298 Mdot
.51371 .65292 Mdot
.41085 .43628 Mdot
.68307 .56065 Mdot
.46078 .36943 Mdot
.70776 .45052 Mdot
.81428 .53563 Mdot
.59492 .2291 Mdot
.41222 .76 Mdot
.3324 .52745 Mdot
.58419 .60356 Mdot
.53028 .61997 Mdot
.61781 .59393 Mdot
.50257 .42515 Mdot
.36332 .71918 Mdot
.20891 .65235 Mdot
.60583 .48979 Mdot
.48548 .40962 Mdot
.43764 .43345 Mdot
.34598 .48789 Mdot
.62991 .5666 Mdot
.2965 .46269 Mdot
.47681 .36126 Mdot
.69111 .41318 Mdot
.69264 .40955 Mdot
.44685 .49756 Mdot
.71145 .68206 Mdot
.58725 .33289 Mdot
.50177 .65413 Mdot
.63367 .55326 Mdot
.68676 .45248 Mdot
.24664 .54205 Mdot
.53137 .61858 Mdot
.51819 .66917 Mdot
.51476 .62045 Mdot
.45642 .38208 Mdot
.34459 .71677 Mdot
.73507 .65275 Mdot
.35659 .68814 Mdot
.45974 .36517 Mdot
.62125 .61503 Mdot
.34087 .69534 Mdot
.71434 .41594 Mdot
.52428 .6698 Mdot
.6404 .60243 Mdot
.47176 .38781 Mdot
.31829 .50704 Mdot
.58217 .24205 Mdot
.78496 .41349 Mdot
.64102 .52499 Mdot
.63765 .52453 Mdot
.29207 .48827 Mdot
.54493 .83265 Mdot
.56062 .63808 Mdot
.30723 .28624 Mdot
.74108 .44045 Mdot
.51028 .41777 Mdot
.4574 .17114 Mdot
.59954 .58992 Mdot
.64627 .56599 Mdot
.47716 .37578 Mdot
.66683 .57307 Mdot
.46565 .40633 Mdot
.60051 .60231 Mdot
.50874 .81273 Mdot
.44984 .35232 Mdot
.64422 .56542 Mdot
.5387 .40704 Mdot
.47101 .35445 Mdot
.34513 .48501 Mdot
.66228 .57758 Mdot
.52425 .41291 Mdot
.19687 .64767 Mdot
.51953 .66258 Mdot
.36029 .69146 Mdot
.49887 .70699 Mdot
.50258 .62061 Mdot
.33073 .487 Mdot
.48821 .32716 Mdot
.71524 .4349 Mdot
.31139 .51301 Mdot
.58387 .61489 Mdot
.69423 .44767 Mdot
.39228 .62803 Mdot
.33701 .52491 Mdot
.34224 .70407 Mdot
.71366 .44013 Mdot
.53794 .33623 Mdot
.65031 .5744 Mdot
.8095 .44619 Mdot
.35619 .68864 Mdot
.49917 .39125 Mdot
.65042 .54553 Mdot
.49524 .62746 Mdot
.49116 .37422 Mdot
.64673 .5587 Mdot
.36539 .69503 Mdot
.4591 .35458 Mdot
.45539 .35768 Mdot
.42605 .47156 Mdot
.33457 .58242 Mdot
.71459 .42942 Mdot
.33001 .46277 Mdot
.48877 .36575 Mdot
.7136 .4015 Mdot
.59082 .68526 Mdot
.5378 .35826 Mdot
.35845 .51463 Mdot
.52397 .46915 Mdot
.63283 .61057 Mdot
.53601 .64774 Mdot
.64977 .55174 Mdot
.728 .43293 Mdot
.65723 .19637 Mdot
.33999 .71473 Mdot
.42666 .41542 Mdot
.46217 .42216 Mdot
.6677 .60605 Mdot
.32826 .4993 Mdot
.56745 .78016 Mdot
.51876 .40391 Mdot
.45708 .4423 Mdot
.4835 .40091 Mdot
.77548 .53482 Mdot
.30998 .48666 Mdot
.48662 .40262 Mdot
.44321 .44557 Mdot
.54364 .34663 Mdot
.71111 .45074 Mdot
.65227 .31603 Mdot
.53035 .35337 Mdot
.15431 .6744 Mdot
.3704 .70649 Mdot
.6474 .57944 Mdot
.51478 .55065 Mdot
.68194 .64396 Mdot
.31266 .24063 Mdot
.33658 .49559 Mdot
.5337 .28882 Mdot
.61811 .59793 Mdot
.57103 .21915 Mdot
.5062 .84314 Mdot
.46782 .35589 Mdot
.48181 .41551 Mdot
.60809 .58593 Mdot
.66158 .5971 Mdot
.36454 .71549 Mdot
.52967 .3977 Mdot
.44868 .43613 Mdot
.66997 .58268 Mdot
.46573 .3855 Mdot
.22974 .41805 Mdot
.48484 .62068 Mdot
.35227 .51336 Mdot
.53368 .65103 Mdot
.51196 .67035 Mdot
.38985 .23467 Mdot
.41134 .58659 Mdot
.50484 .63489 Mdot
.55095 .63702 Mdot
.75669 .36452 Mdot
.5131 .47307 Mdot
.6969 .45378 Mdot
.67302 .72532 Mdot
.63489 .57607 Mdot
.51239 .38847 Mdot
.29057 .51282 Mdot
.32222 .25704 Mdot
.53325 .75462 Mdot
.36531 .59888 Mdot
.50373 .36441 Mdot
.63481 .56945 Mdot
.36467 .69229 Mdot
.45426 .3475 Mdot
.58817 .27064 Mdot
.48635 .39029 Mdot
.64321 .6083 Mdot
.41058 .23001 Mdot
.27374 .46229 Mdot
.45722 .64105 Mdot
.37321 .50585 Mdot
.52272 .33662 Mdot
.34109 .51654 Mdot
.48577 .65126 Mdot
.70332 .40161 Mdot
.71126 .42275 Mdot
.45155 .38113 Mdot
.40655 .53432 Mdot
.7013 .47204 Mdot
.47203 .3552 Mdot
.48751 .34387 Mdot
.35531 .71413 Mdot
.48609 .34409 Mdot
.47041 .42363 Mdot
.52245 .34094 Mdot
.53801 .38296 Mdot
.52749 .6687 Mdot
.37115 .43205 Mdot
.53417 .36849 Mdot
.46348 .31137 Mdot
.47515 .65021 Mdot
.46339 .29746 Mdot
.5274 .64669 Mdot
.64875 .76411 Mdot
.52464 .63732 Mdot
.7113 .42471 Mdot
.62318 .54828 Mdot
.5124 .27744 Mdot
.28503 .5204 Mdot
.48803 .66987 Mdot
.69182 .43255 Mdot
.5157 .64568 Mdot
.60798 .56227 Mdot
.83041 .42195 Mdot
.3084 .46666 Mdot
.47054 .57323 Mdot
.61978 .41412 Mdot
.28281 .60786 Mdot
.6251 .6101 Mdot
.32648 .48028 Mdot
.25368 .48131 Mdot
.51587 .33782 Mdot
.71901 .42965 Mdot
.47926 .38668 Mdot
.52909 .66517 Mdot
.6363 .57204 Mdot
.59917 .53813 Mdot
.71545 .42793 Mdot
.73214 .2661 Mdot
.61431 .61745 Mdot
.44878 .33904 Mdot
.47415 .65042 Mdot
.83762 .40988 Mdot
.52714 .63942 Mdot
.67744 .26533 Mdot
.32574 .55179 Mdot
.42768 .22286 Mdot
.31004 .49617 Mdot
.24347 .56456 Mdot
.60427 .83304 Mdot
.51018 .83439 Mdot
.31798 .51572 Mdot
.67348 .53638 Mdot
.463 .37724 Mdot
.5248 .35641 Mdot
.51199 .30934 Mdot
.37383 .47719 Mdot
.48135 .36591 Mdot
.33989 .70153 Mdot
.41678 .58852 Mdot
.78316 .57445 Mdot
.58397 .59012 Mdot
.46473 .40728 Mdot
.49553 .67128 Mdot
.5425 .64535 Mdot
.3458 .69103 Mdot
.50403 .61653 Mdot
.47815 .35188 Mdot
.30635 .50309 Mdot
.61815 .48133 Mdot
.69968 .41212 Mdot
.33702 .75915 Mdot
.71136 .4592 Mdot
.58504 .57275 Mdot
.4892 .30769 Mdot
.62325 .60383 Mdot
.55096 .15471 Mdot
.52075 .34774 Mdot
.32521 .50845 Mdot
.45271 .36913 Mdot
.52169 .33874 Mdot
.53121 .36834 Mdot
.64248 .55602 Mdot
.5136 .55583 Mdot
.46636 .3882 Mdot
.49296 .63722 Mdot
.66452 .51597 Mdot
.48508 .32512 Mdot
.70335 .65085 Mdot
.70996 .33933 Mdot
.29802 .6169 Mdot
.37382 .48609 Mdot
.61622 .57987 Mdot
.31828 .49499 Mdot
.37944 .48054 Mdot
.33097 .48703 Mdot
.72784 .63729 Mdot
.54321 .27562 Mdot
.28895 .23759 Mdot
.37836 .32501 Mdot
.32704 .26181 Mdot
.30075 .47778 Mdot
.61007 .69522 Mdot
.32636 .52075 Mdot
.33487 .49134 Mdot
.16187 .33831 Mdot
.31275 .52308 Mdot
.49851 .40392 Mdot
.43795 .37228 Mdot
.29048 .68966 Mdot
.75038 .35178 Mdot
.53064 .38131 Mdot
.48379 .3674 Mdot
.67952 .42238 Mdot
.46211 .45887 Mdot
.35575 .68443 Mdot
.38601 .60505 Mdot
.37762 .68506 Mdot
.47863 .39568 Mdot
.47729 .37119 Mdot
.46423 .4331 Mdot
.60512 .83719 Mdot
.31503 .2557 Mdot
.31829 .47274 Mdot
.41604 .34577 Mdot
.40023 .79288 Mdot
.44798 .40316 Mdot
.44561 .39157 Mdot
.47618 .33919 Mdot
.61702 .59614 Mdot
.30591 .54121 Mdot
.47351 .44629 Mdot
.28567 .63972 Mdot
.46403 .36968 Mdot
.56759 .62742 Mdot
.65299 .4363 Mdot
.49625 .39914 Mdot
.35134 .52256 Mdot
.51574 .35668 Mdot
.3224 .52993 Mdot
.35021 .51534 Mdot
.4255 .40468 Mdot
.72893 .66141 Mdot
.33431 .54185 Mdot
.46005 .35871 Mdot
.60923 .59501 Mdot
.46205 .83266 Mdot
.49981 .39279 Mdot
.68099 .42904 Mdot
.52234 .37977 Mdot
.71498 .44803 Mdot
.4768 .34371 Mdot
.36092 .68878 Mdot
.29133 .33118 Mdot
.62484 .58038 Mdot
.69993 .46418 Mdot
.6667 .59063 Mdot
.47163 .48231 Mdot
.35109 .47925 Mdot
.36045 .68398 Mdot
.27007 .28266 Mdot
.35373 .71432 Mdot
.56209 .24213 Mdot
.52174 .73906 Mdot
.50707 .669 Mdot
.32948 .53385 Mdot
.51913 .25197 Mdot
.69535 .67034 Mdot
.62229 .62595 Mdot
.61696 .62422 Mdot
.5894 .17726 Mdot
.42174 .15947 Mdot
.4661 .39288 Mdot
.83175 .49074 Mdot
.2927 .3775 Mdot
.54764 .36808 Mdot
.5545 .38828 Mdot
.6342 .61494 Mdot
.52195 .33497 Mdot
.51985 .51512 Mdot
.63599 .59232 Mdot
.69544 .42959 Mdot
.34416 .50142 Mdot
.72584 .42998 Mdot
.612 .76061 Mdot
.40826 .64369 Mdot
.64464 .59494 Mdot
.5386 .37062 Mdot
.45934 .39396 Mdot
.31726 .53305 Mdot
.23684 .49043 Mdot
.35355 .50523 Mdot
.6808 .44141 Mdot
.62882 .58805 Mdot
.29337 .28032 Mdot
.52217 .38762 Mdot
.30159 .51108 Mdot
.67441 .60783 Mdot
.51409 .37264 Mdot
.49861 .66605 Mdot
.50424 .36359 Mdot
.31065 .51908 Mdot
.48537 .34385 Mdot
.30794 .50128 Mdot
.6028 .59688 Mdot
.46577 .41602 Mdot
.4799 .37174 Mdot
.54237 .23093 Mdot
.69813 .41833 Mdot
.34593 .47566 Mdot
.5129 .51757 Mdot
.45712 .4146 Mdot
.5891 .27415 Mdot
.4956 .32686 Mdot
.54215 .30824 Mdot
.5244 .42769 Mdot
.34004 .70471 Mdot
.49072 .43044 Mdot
.49844 .39272 Mdot
.31777 .43349 Mdot
.36979 .37746 Mdot
.4032 .47272 Mdot
.48986 .67426 Mdot
.35189 .52121 Mdot
.65371 .58897 Mdot
.65852 .59451 Mdot
.61965 .56454 Mdot
.7368 .32985 Mdot
.41897 .38919 Mdot
.49445 .38811 Mdot
.47459 .63699 Mdot
.70269 .4249 Mdot
.29386 .50497 Mdot
.70674 .42846 Mdot
.3866 .60094 Mdot
.68716 .4468 Mdot
.33824 .70531 Mdot
.78018 .53303 Mdot
.21971 .39641 Mdot
.68381 .4377 Mdot
.35352 .507 Mdot
.62057 .50247 Mdot
.51449 .4163 Mdot
.44591 .78656 Mdot
.68998 .41373 Mdot
.62282 .19441 Mdot
.45136 .35738 Mdot
.51673 .52228 Mdot
.52539 .65291 Mdot
.72296 .43424 Mdot
.51631 .61925 Mdot
.5181 .3547 Mdot
.2303 .60106 Mdot
.33013 .51002 Mdot
.48463 .61652 Mdot
.51303 .42433 Mdot
.72513 .43101 Mdot
.64809 .59165 Mdot
.59096 .42026 Mdot
.48126 .65154 Mdot
.58261 .23317 Mdot
.59696 .26927 Mdot
.62994 .58958 Mdot
.19013 .41249 Mdot
.52838 .62749 Mdot
.54182 .37053 Mdot
.55839 .30085 Mdot
.50986 .35777 Mdot
.65426 .59492 Mdot
.63985 .56162 Mdot
.3156 .70571 Mdot
.45324 .37882 Mdot
.45644 .34966 Mdot
.28044 .52477 Mdot
.63727 .59884 Mdot
.32483 .48377 Mdot
.30911 .53573 Mdot
.60777 .58912 Mdot
.33747 .48473 Mdot
.7052 .44654 Mdot
.41861 .57808 Mdot
.52789 .62831 Mdot
.48953 .65431 Mdot
.65036 .59142 Mdot
.60493 .56289 Mdot
.62573 .60436 Mdot
.49968 .36177 Mdot
.30937 .48361 Mdot
.50386 .342 Mdot
.53148 .35484 Mdot
.30705 .55458 Mdot
.29131 .49333 Mdot
.50966 .34618 Mdot
.65862 .49267 Mdot
.73651 .41024 Mdot
.64266 .56492 Mdot
.51157 .62893 Mdot
.53208 .22265 Mdot
.48452 .6191 Mdot
.44754 .38822 Mdot
.46861 .7914 Mdot
.29127 .50118 Mdot
.71201 .41676 Mdot
.66365 .42096 Mdot
.71645 .42372 Mdot
.48448 .61648 Mdot
.32098 .53747 Mdot
.39418 .62842 Mdot
.45086 .39475 Mdot
.43666 .57919 Mdot
.55625 .24998 Mdot
.31771 .65348 Mdot
.50462 .63222 Mdot
.49898 .36757 Mdot
.35081 .71471 Mdot
.24945 .35103 Mdot
.48815 .3852 Mdot
.49409 .42834 Mdot
.74435 .50263 Mdot
.46498 .31096 Mdot
.35968 .46833 Mdot
.42353 .5116 Mdot
.47786 .42077 Mdot
.40952 .47196 Mdot
.27379 .21878 Mdot
.45153 .35828 Mdot
.47178 .36838 Mdot
.51116 .3972 Mdot
.51722 .34284 Mdot
.36521 .5034 Mdot
.74032 .48047 Mdot
.49292 .67171 Mdot
.42379 .57564 Mdot
.5194 .62284 Mdot
.65103 .56924 Mdot
.53416 .50624 Mdot
.33844 .53067 Mdot
.7167 .42259 Mdot
.84145 .45351 Mdot
.39502 .58127 Mdot
.60731 .60614 Mdot
.3502 .22731 Mdot
.69838 .41096 Mdot
.51297 .41609 Mdot
.73339 .41455 Mdot
.65571 .60747 Mdot
.49442 .641 Mdot
.44288 .39671 Mdot
.2863 .50733 Mdot
.35898 .50112 Mdot
.49537 .3655 Mdot
.4149 .81371 Mdot
.49981 .6223 Mdot
.61024 .64556 Mdot
.45617 .37923 Mdot
.49344 .42818 Mdot
.35014 .50217 Mdot
.63218 .56655 Mdot
.50941 .73135 Mdot
.69144 .42424 Mdot
.52672 .41707 Mdot
.51849 .3566 Mdot
.39736 .59412 Mdot
.51422 .67906 Mdot
.35897 .69877 Mdot
.45487 .37836 Mdot
.40948 .59056 Mdot
.45415 .37231 Mdot
.51214 .45492 Mdot
.6148 .60193 Mdot
.43711 .35929 Mdot
.49443 .4163 Mdot
.42606 .30099 Mdot
.53153 .62824 Mdot
.32538 .50264 Mdot
.30329 .54969 Mdot
.36749 .70304 Mdot
.50841 .66489 Mdot
.5097 .34969 Mdot
.53378 .65704 Mdot
.52922 .36343 Mdot
.46892 .38653 Mdot
.50405 .63208 Mdot
.32655 .48317 Mdot
.56747 .77433 Mdot
.35638 .43535 Mdot
.49609 .33281 Mdot
.52251 .37271 Mdot
.73966 .33933 Mdot
.21221 .35953 Mdot
.50446 .41346 Mdot
.29935 .48913 Mdot
.51211 .37287 Mdot
.48885 .65937 Mdot
.68282 .44409 Mdot
.32096 .51056 Mdot
.59635 .57155 Mdot
.60128 .59124 Mdot
.68534 .5656 Mdot
.33875 .7108 Mdot
.51969 .40732 Mdot
.31777 .46228 Mdot
.28867 .49454 Mdot
.38474 .71762 Mdot
.64801 .57835 Mdot
.69433 .45182 Mdot
.47037 .34037 Mdot
.59321 .41037 Mdot
.50556 .67374 Mdot
.15893 .67947 Mdot
.39566 .6355 Mdot
.71975 .44984 Mdot
.37453 .56191 Mdot
.3464 .71151 Mdot
.48233 .41137 Mdot
.72088 .40518 Mdot
.60475 .57241 Mdot
.52281 .35494 Mdot
.43616 .3324 Mdot
.68459 .67929 Mdot
.58612 .59281 Mdot
.53568 .65182 Mdot
.59883 .57527 Mdot
.72748 .43915 Mdot
.33846 .70338 Mdot
.34942 .48458 Mdot
.49371 .39476 Mdot
.43275 .31072 Mdot
.64288 .57505 Mdot
.36735 .6916 Mdot
.45618 .37267 Mdot
.35721 .5129 Mdot
.63269 .56147 Mdot
.47675 .39979 Mdot
.2924 .29863 Mdot
.30131 .55662 Mdot
.63233 .58125 Mdot
.45695 .42078 Mdot
.49616 .47872 Mdot
.5917 .59251 Mdot
.62912 .61655 Mdot
.48101 .36624 Mdot
.71225 .44212 Mdot
.46821 .4139 Mdot
.5242 .64297 Mdot
.51391 .55571 Mdot
.50029 .66416 Mdot
.57542 .25589 Mdot
.43318 .39098 Mdot
.27829 .59056 Mdot
.30087 .52568 Mdot
.68297 .40345 Mdot
.32247 .4279 Mdot
.49114 .42633 Mdot
.62107 .78667 Mdot
.61782 .49472 Mdot
.39865 .70863 Mdot
.73464 .72587 Mdot
.68584 .43134 Mdot
.51817 .64857 Mdot
.47268 .36751 Mdot
.51547 .68859 Mdot
.69244 .44156 Mdot
.5715 .25318 Mdot
.46147 .42248 Mdot
.31036 .48758 Mdot
.46198 .37419 Mdot
.33105 .52795 Mdot
.51809 .37535 Mdot
.41811 .36247 Mdot
.74491 .41689 Mdot
.67332 .26174 Mdot
.51928 .41173 Mdot
.84518 .44737 Mdot
.57225 .45825 Mdot
.68737 .41847 Mdot
.49004 .33614 Mdot
.35001 .701 Mdot
.49257 .63059 Mdot
.81344 .49296 Mdot
.62028 .60083 Mdot
.51095 .63591 Mdot
.34705 .4987 Mdot
.65111 .54868 Mdot
.36925 .70185 Mdot
.53628 .27658 Mdot
.72739 .42589 Mdot
.51623 .6638 Mdot
.49775 .39516 Mdot
.44645 .38589 Mdot
.78125 .52498 Mdot
.16989 .47408 Mdot
.28752 .52864 Mdot
.69959 .24812 Mdot
.33942 .4648 Mdot
.70061 .42067 Mdot
.61742 .60373 Mdot
.49477 .40987 Mdot
.48539 .37946 Mdot
.65763 .5821 Mdot
.30927 .4809 Mdot
.66367 .54721 Mdot
.37889 .22913 Mdot
.52266 .59835 Mdot
.66941 .29016 Mdot
.32271 .51435 Mdot
.66857 .28593 Mdot
.71853 .4494 Mdot
.72412 .68808 Mdot
.65254 .36996 Mdot
.51897 .66579 Mdot
.66939 .29437 Mdot
.29418 .50894 Mdot
.46671 .39625 Mdot
.34325 .70213 Mdot
.35768 .71722 Mdot
.34505 .51165 Mdot
.61046 .58361 Mdot
.72472 .42592 Mdot
.46953 .37316 Mdot
.3385 .62806 Mdot
.25595 .67964 Mdot
.63598 .5531 Mdot
.4579 .44966 Mdot
.50555 .62103 Mdot
.51689 .37032 Mdot
.68324 .41584 Mdot
.5063 .64245 Mdot
.3348 .71453 Mdot
.41951 .57043 Mdot
.47086 .3396 Mdot
.44938 .49259 Mdot
.51585 .66132 Mdot
.19544 .37869 Mdot
.48222 .37324 Mdot
.52858 .62747 Mdot
.5211 .29781 Mdot
.24243 .61437 Mdot
.63956 .47053 Mdot
.53041 .8324 Mdot
.59589 .61593 Mdot
.60162 .58687 Mdot
.18304 .58081 Mdot
.74294 .4375 Mdot
.48702 .66616 Mdot
.33961 .69895 Mdot
.65289 .33694 Mdot
.52627 .62212 Mdot
.44254 .38184 Mdot
.48932 .32782 Mdot
.37909 .23686 Mdot
.56157 .47453 Mdot
.37349 .69862 Mdot
.57097 .34463 Mdot
.49079 .35067 Mdot
.52958 .32706 Mdot
.49665 .37329 Mdot
.32502 .47003 Mdot
.53016 .62272 Mdot
.87029 .49048 Mdot
.5408 .6329 Mdot
.3501 .62563 Mdot
.63496 .57567 Mdot
.64545 .55347 Mdot
.49458 .39959 Mdot
.2739 .57171 Mdot
.81895 .54048 Mdot
.52561 .38369 Mdot
.65864 .4331 Mdot
.59622 .26564 Mdot
.4933 .32247 Mdot
.29794 .54233 Mdot
.46457 .44631 Mdot
.36044 .47834 Mdot
.5028 .64129 Mdot
.68597 .43327 Mdot
.73458 .4019 Mdot
.52223 .65062 Mdot
.49621 .38578 Mdot
.66778 .4077 Mdot
.48604 .39676 Mdot
.46078 .39137 Mdot
.3794 .6108 Mdot
.67165 .43746 Mdot
.62749 .60544 Mdot
.71291 .42402 Mdot
.33269 .49135 Mdot
.1217 .39553 Mdot
.70584 .43547 Mdot
.52376 .47232 Mdot
.55198 .50875 Mdot
.66676 .29129 Mdot
.35826 .49971 Mdot
.67862 .43432 Mdot
.53789 .63822 Mdot
.39181 .72052 Mdot
.19968 .39452 Mdot
.49516 .61331 Mdot
.48165 .37825 Mdot
.33334 .53167 Mdot
.29636 .48462 Mdot
.52667 .61446 Mdot
.33603 .47816 Mdot
.48384 .31469 Mdot
.4547 .36233 Mdot
.4878 .6666 Mdot
.28675 .70086 Mdot
.53201 .62357 Mdot
.58304 .42983 Mdot
.46897 .34533 Mdot
.323 .50933 Mdot
.56429 .36519 Mdot
.27071 .49791 Mdot
.35695 .71912 Mdot
.53266 .37454 Mdot
.72 .42329 Mdot
.46681 .55333 Mdot
.63159 .5801 Mdot
.47521 .79211 Mdot
.33606 .52736 Mdot
.47065 .62299 Mdot
.34667 .48628 Mdot
.28181 .50989 Mdot
.51244 .61462 Mdot
.33317 .49968 Mdot
.4707 .36976 Mdot
.45904 .5967 Mdot
.32716 .52608 Mdot
.50503 .65703 Mdot
.72188 .41984 Mdot
.33343 .48299 Mdot
.67307 .56019 Mdot
.46368 .39877 Mdot
.62731 .61186 Mdot
.67024 .44592 Mdot
.33619 .53195 Mdot
.67992 .43725 Mdot
.6455 .57572 Mdot
.72647 .41874 Mdot
.57707 .57501 Mdot
.49327 .68774 Mdot
.35919 .60421 Mdot
.31246 .4457 Mdot
.28962 .51402 Mdot
.61141 .62631 Mdot
.49632 .41315 Mdot
.45437 .38778 Mdot
.7319 .42582 Mdot
.29279 .48683 Mdot
.45727 .82922 Mdot
.55076 .31528 Mdot
.32136 .70372 Mdot
.51031 .68245 Mdot
.63005 .21725 Mdot
.39767 .65059 Mdot
.39866 .72862 Mdot
.54598 .40378 Mdot
.34555 .71064 Mdot
.48385 .4016 Mdot
.59559 .22864 Mdot
.68191 .445 Mdot
.57608 .72914 Mdot
.54287 .39547 Mdot
.6289 .59802 Mdot
.51921 .38369 Mdot
.82907 .48882 Mdot
.51559 .44327 Mdot
.67891 .42635 Mdot
.47659 .66342 Mdot
.28512 .52067 Mdot
.69834 .41203 Mdot
.6011 .5969 Mdot
.67947 .32837 Mdot
.44913 .41553 Mdot
.48484 .35203 Mdot
.62804 .6245 Mdot
.3175 .48338 Mdot
.65083 .57132 Mdot
.52753 .62785 Mdot
.70513 .43264 Mdot
.51378 .33916 Mdot
.4795 .32108 Mdot
.6615 .61055 Mdot
.54196 .6424 Mdot
.6232 .55314 Mdot
.52846 .66295 Mdot
.34436 .70957 Mdot
.522 .40638 Mdot
.64775 .61806 Mdot
.55226 .36129 Mdot
.38395 .34663 Mdot
.37788 .60047 Mdot
.33263 .413 Mdot
.62868 .60614 Mdot
.70492 .32303 Mdot
.51555 .65491 Mdot
.53099 .65201 Mdot
.43898 .23179 Mdot
.81203 .5517 Mdot
.61935 .50584 Mdot
.82495 .41968 Mdot
.52719 .62807 Mdot
.50619 .6621 Mdot
.60701 .57171 Mdot
.33857 .50066 Mdot
.34944 .54052 Mdot
.67126 .57288 Mdot
.63067 .23784 Mdot
.29404 .5054 Mdot
.59794 .80375 Mdot
.60049 .61064 Mdot
.5262 .42522 Mdot
.37629 .69905 Mdot
.6836 .41893 Mdot
.60287 .23653 Mdot
.82525 .43816 Mdot
.49084 .40782 Mdot
.36327 .19623 Mdot
.61755 .58178 Mdot
.447 .64445 Mdot
.68555 .72414 Mdot
.47201 .42777 Mdot
.51648 .38765 Mdot
.50001 .38188 Mdot
.67282 .42069 Mdot
.35525 .42643 Mdot
.48842 .40861 Mdot
.6847 .27558 Mdot
.44117 .36246 Mdot
.80762 .45799 Mdot
.71269 .42443 Mdot
.57731 .29401 Mdot
.5937 .61743 Mdot
.30058 .63978 Mdot
.51482 .31181 Mdot
.53072 .63343 Mdot
.65026 .72339 Mdot
.49788 .63377 Mdot
.76873 .63391 Mdot
.65114 .36794 Mdot
.32237 .46979 Mdot
.50283 .36396 Mdot
.62244 .62294 Mdot
.32949 .53167 Mdot
.51934 .73583 Mdot
.15852 .33831 Mdot
.53096 .66659 Mdot
.46434 .13155 Mdot
.53008 .65548 Mdot
.36133 .71642 Mdot
.3485 .50682 Mdot
.38646 .52662 Mdot
.43864 .5766 Mdot
.32653 .48422 Mdot
.70129 .60585 Mdot
.30043 .5467 Mdot
.68869 .30574 Mdot
.27819 .49819 Mdot
.50895 .65355 Mdot
.47523 .66724 Mdot
.47009 .30089 Mdot
.50415 .41247 Mdot
.4201 .59037 Mdot
.53771 .31761 Mdot
.52275 .39917 Mdot
.63586 .59242 Mdot
.23037 .53299 Mdot
.46197 .62075 Mdot
.33123 .51945 Mdot
.50781 .67633 Mdot
.51756 .38739 Mdot
.49513 .33322 Mdot
.54582 .35994 Mdot
.57483 .22748 Mdot
.60064 .80033 Mdot
.46781 .38931 Mdot
.43328 .41618 Mdot
.60647 .60229 Mdot
.79255 .50235 Mdot
.76649 .33048 Mdot
.65751 .34625 Mdot
.45037 .38224 Mdot
.70377 .41745 Mdot
.67539 .43728 Mdot
.46306 .32539 Mdot
.30827 .60829 Mdot
.6574 .53379 Mdot
.4981 .39502 Mdot
.66946 .37847 Mdot
.67858 .58476 Mdot
.36073 .68798 Mdot
.64319 .57578 Mdot
.34433 .52922 Mdot
.35708 .7151 Mdot
.64269 .55736 Mdot
.30918 .56296 Mdot
.36666 .70342 Mdot
.25374 .62524 Mdot
.68051 .44108 Mdot
.49157 .37451 Mdot
.28197 .4717 Mdot
.65679 .58421 Mdot
.51939 .6613 Mdot
.31153 .50517 Mdot
.51401 .68394 Mdot
.79406 .5042 Mdot
.61124 .24565 Mdot
.34027 .71461 Mdot
.52928 .63537 Mdot
.42999 .53111 Mdot
.70688 .41849 Mdot
.50632 .61487 Mdot
.26511 .57229 Mdot
.49226 .32431 Mdot
.79786 .61356 Mdot
.48515 .35575 Mdot
.37883 .79564 Mdot
.53037 .65073 Mdot
.34919 .72156 Mdot
.49189 .3938 Mdot
.61191 .61627 Mdot
.47658 .29385 Mdot
.48448 .3956 Mdot
.59597 .57661 Mdot
.46687 .39364 Mdot
.68918 .40878 Mdot
.36769 .48835 Mdot
.61875 .49185 Mdot
.57759 .2041 Mdot
.72187 .41249 Mdot
.32817 .7103 Mdot
.51624 .40777 Mdot
.69817 .51552 Mdot
.31991 .48698 Mdot
.48436 .42884 Mdot
.42376 .2059 Mdot
.34113 .50959 Mdot
.31718 .49405 Mdot
.4928 .34275 Mdot
.49173 .61448 Mdot
.64716 .60063 Mdot
.70961 .41915 Mdot
.48385 .72072 Mdot
.47619 .40144 Mdot
.4959 .36818 Mdot
.69945 .41093 Mdot
.50378 .66341 Mdot
.51173 .33946 Mdot
.49143 .75791 Mdot
.39322 .67783 Mdot
.51036 .67097 Mdot
.4929 .32372 Mdot
.81067 .62487 Mdot
.36421 .52768 Mdot
.33839 .20486 Mdot
.73559 .44691 Mdot
.61047 .5892 Mdot
.42726 .42049 Mdot
.13115 .6385 Mdot
.6833 .42189 Mdot
.3183 .6472 Mdot
.46307 .38568 Mdot
.51632 .40138 Mdot
.34815 .47943 Mdot
.50542 .34665 Mdot
.31109 .52096 Mdot
.58138 .20092 Mdot
.84787 .39884 Mdot
.34438 .48561 Mdot
.31887 .52468 Mdot
.39499 .4906 Mdot
.56645 .23266 Mdot
.3449 .49932 Mdot
.45109 .41852 Mdot
.71551 .58473 Mdot
.42576 .36473 Mdot
.70199 .45804 Mdot
.68997 .39808 Mdot
.27466 .523 Mdot
.1917 .47649 Mdot
.48133 .28713 Mdot
.41657 .45579 Mdot
.69045 .47252 Mdot
.5212 .63498 Mdot
.49383 .32902 Mdot
.33784 .70796 Mdot
.62576 .55996 Mdot
.4926 .45232 Mdot
.491 .37725 Mdot
.32519 .52897 Mdot
.67363 .41727 Mdot
.51032 .61674 Mdot
.48257 .36806 Mdot
.61626 .5471 Mdot
.69309 .42788 Mdot
.32624 .52519 Mdot
.53001 .47133 Mdot
.70023 .45434 Mdot
.49619 .31716 Mdot
.52196 .3988 Mdot
.45587 .37187 Mdot
.51499 .3093 Mdot
.52341 .65159 Mdot
.66377 .55753 Mdot
.43666 .35193 Mdot
.39147 .60687 Mdot
.48508 .55021 Mdot
.43923 .34946 Mdot
.30788 .48359 Mdot
.4865 .66769 Mdot
.36383 .70254 Mdot
.65832 .30779 Mdot
.45694 .35334 Mdot
.61087 .79252 Mdot
.34335 .23672 Mdot
.3588 .70852 Mdot
.31902 .4662 Mdot
.7143 .41961 Mdot
.48176 .34824 Mdot
.69409 .5329 Mdot
.44691 .37144 Mdot
.54897 .44934 Mdot
.61346 .58638 Mdot
.51807 .63081 Mdot
.39052 .6815 Mdot
.62602 .55952 Mdot
.31797 .49464 Mdot
.43444 .84099 Mdot
.32595 .54823 Mdot
.29836 .53425 Mdot
.73582 .65892 Mdot
.5024 .63835 Mdot
.14581 .6612 Mdot
.20948 .36138 Mdot
.44635 .36715 Mdot
.48719 .64914 Mdot
.34794 .51326 Mdot
.49442 .3605 Mdot
.29068 .51156 Mdot
.31943 .54208 Mdot
.53107 .34971 Mdot
.51338 .40633 Mdot
.66121 .25518 Mdot
.59322 .81679 Mdot
.71785 .43115 Mdot
.32737 .47406 Mdot
.35352 .25159 Mdot
.48756 .40981 Mdot
.45145 .39592 Mdot
.67486 .69624 Mdot
.67915 .42933 Mdot
.23851 .40582 Mdot
.45608 .38356 Mdot
.43206 .20539 Mdot
.52638 .39506 Mdot
.35602 .45329 Mdot
.49631 .6092 Mdot
.31335 .6145 Mdot
.65281 .5973 Mdot
.35303 .52708 Mdot
.71751 .44525 Mdot
.35767 .5244 Mdot
.42448 .23267 Mdot
.49923 .64003 Mdot
.31052 .51909 Mdot
.62873 .54819 Mdot
.49558 .65175 Mdot
.52035 .66554 Mdot
.6613 .51633 Mdot
.64928 .54949 Mdot
.67991 .41258 Mdot
.49951 .62829 Mdot
.31274 .28206 Mdot
.50744 .65065 Mdot
.36697 .24721 Mdot
.4756 .41868 Mdot
.67358 .27241 Mdot
.38106 .65291 Mdot
.49674 .30184 Mdot
.52337 .61905 Mdot
.70741 .44071 Mdot
.5087 .35459 Mdot
.33305 .47727 Mdot
.7022 .43794 Mdot
.55357 .63909 Mdot
.60933 .55776 Mdot
.28133 .50185 Mdot
.47422 .64471 Mdot
.30429 .51918 Mdot
.59652 .2485 Mdot
.57958 .58034 Mdot
.64739 .45784 Mdot
.44764 .57438 Mdot
.54332 .37025 Mdot
.40793 .47023 Mdot
.45527 .41453 Mdot
.48942 .38123 Mdot
.633 .58062 Mdot
.73471 .328 Mdot
.3316 .48203 Mdot
.29863 .74468 Mdot
.53093 .6403 Mdot
.42053 .516 Mdot
.57594 .41688 Mdot
.52776 .36368 Mdot
.33162 .5233 Mdot
.31283 .541 Mdot
.36932 .37837 Mdot
.65795 .57951 Mdot
.44083 .33716 Mdot
.48108 .30852 Mdot
.41817 .39021 Mdot
.52833 .65869 Mdot
.51331 .76108 Mdot
.65352 .56072 Mdot
.38081 .15464 Mdot
.64215 .5642 Mdot
.71638 .50276 Mdot
.33368 .50067 Mdot
.69343 .44989 Mdot
.45417 .40019 Mdot
.3842 .43483 Mdot
.3649 .49479 Mdot
.67301 .54039 Mdot
.71517 .41719 Mdot
.5449 .76871 Mdot
.50661 .63625 Mdot
.47203 .42179 Mdot
.52816 .34249 Mdot
.49981 .339 Mdot
.46932 .35943 Mdot
.4977 .67685 Mdot
.44289 .38312 Mdot
.49729 .68266 Mdot
.26804 .321 Mdot
.43648 .20903 Mdot
.62941 .61926 Mdot
.80297 .46873 Mdot
.28459 .50348 Mdot
.34702 .27071 Mdot
.23015 .41064 Mdot
.37559 .60275 Mdot
.59346 .54584 Mdot
.49018 .41927 Mdot
.61032 .58185 Mdot
.83225 .4943 Mdot
.63168 .62074 Mdot
.86765 .40149 Mdot
.5351 .26408 Mdot
.51605 .84009 Mdot
.4884 .35893 Mdot
.6723 .57205 Mdot
.22777 .45285 Mdot
.46859 .32699 Mdot
.68873 .3952 Mdot
.57693 .42835 Mdot
.29025 .67781 Mdot
.69465 .45236 Mdot
.46615 .40027 Mdot
.27952 .51364 Mdot
.46954 .37028 Mdot
.45968 .40405 Mdot
.5247 .38353 Mdot
.54699 .63493 Mdot
.51236 .32805 Mdot
.4674 .41338 Mdot
.16781 .45593 Mdot
.72987 .34409 Mdot
.60778 .60877 Mdot
.35323 .39235 Mdot
.7024 .42521 Mdot
.32465 .53121 Mdot
.59964 .497 Mdot
.52077 .64054 Mdot
.3742 .36401 Mdot
.48726 .35762 Mdot
.3374 .66628 Mdot
.4791 .62542 Mdot
.69323 .43862 Mdot
.36633 .6996 Mdot
.61888 .76976 Mdot
.64872 .60758 Mdot
.3668 .71388 Mdot
.63068 .57972 Mdot
.25966 .44583 Mdot
.3274 .52788 Mdot
.54327 .36007 Mdot
.51102 .62064 Mdot
.63054 .61504 Mdot
.75869 .35546 Mdot
.50492 .37662 Mdot
.63062 .60632 Mdot
.54262 .36872 Mdot
.48758 .55456 Mdot
.5549 .51212 Mdot
.66148 .60163 Mdot
.47473 .66503 Mdot
.49346 .65459 Mdot
.70086 .44784 Mdot
.32007 .53183 Mdot
.29494 .49471 Mdot
.50305 .64477 Mdot
.38762 .16895 Mdot
.47807 .40242 Mdot
.52482 .39374 Mdot
.39266 .61344 Mdot
.48301 .36095 Mdot
.69693 .33271 Mdot
.34541 .68839 Mdot
.29085 .51784 Mdot
.47271 .36076 Mdot
.51077 .33854 Mdot
.47413 .33765 Mdot
.61214 .24879 Mdot
.64177 .57173 Mdot
.48962 .35007 Mdot
.72784 .41261 Mdot
.25646 .58898 Mdot
.4899 .41406 Mdot
.49257 .31904 Mdot
.3052 .5179 Mdot
.6566 .22192 Mdot
.52501 .65632 Mdot
.63963 .59984 Mdot
.59904 .60861 Mdot
.59989 .29956 Mdot
.374 .49498 Mdot
.36235 .68528 Mdot
.66362 .65556 Mdot
.35095 .69076 Mdot
.68992 .41749 Mdot
.65984 .49879 Mdot
.60896 .55023 Mdot
.59994 .60059 Mdot
.49349 .68709 Mdot
.46841 .36228 Mdot
.52583 .39525 Mdot
.32027 .64472 Mdot
.52932 .37871 Mdot
.71898 .41823 Mdot
.47583 .64231 Mdot
.30562 .51676 Mdot
.68941 .41097 Mdot
.5343 .64596 Mdot
.31695 .48306 Mdot
.47424 .32881 Mdot
.54334 .34373 Mdot
.31157 .5006 Mdot
.34746 .52177 Mdot
.5019 .40047 Mdot
.17991 .5202 Mdot
.28832 .51938 Mdot
.31753 .51765 Mdot
.36784 .72133 Mdot
.64778 .60895 Mdot
.56246 .40292 Mdot
.48886 .64518 Mdot
.45601 .37532 Mdot
.63213 .61908 Mdot
.68267 .43765 Mdot
.3053 .49731 Mdot
.48324 .33444 Mdot
.47361 .39304 Mdot
.70506 .41692 Mdot
.67541 .44646 Mdot
.71813 .41242 Mdot
.53693 .66253 Mdot
.46352 .35715 Mdot
.34407 .49517 Mdot
.50284 .63565 Mdot
.67589 .43833 Mdot
.72645 .40273 Mdot
.17427 .44083 Mdot
.49056 .40666 Mdot
.65855 .4755 Mdot
.10378 .45154 Mdot
.67683 .33454 Mdot
.36558 .71097 Mdot
.66485 .60205 Mdot
.68321 .28276 Mdot
.70517 .46426 Mdot
.48518 .64909 Mdot
.63748 .40674 Mdot
.6752 .41123 Mdot
.53054 .35346 Mdot
.51679 .36674 Mdot
.51907 .42696 Mdot
.69778 .43097 Mdot
.60257 .25063 Mdot
.29851 .48445 Mdot
.30434 .34686 Mdot
.70236 .42537 Mdot
.66222 .60052 Mdot
.65335 .61428 Mdot
.64298 .5637 Mdot
.48887 .4207 Mdot
.35674 .40478 Mdot
.32935 .2657 Mdot
.25107 .40265 Mdot
.51067 .63643 Mdot
.307 .5406 Mdot
.59902 .53793 Mdot
.31651 .4935 Mdot
.62225 .56459 Mdot
.69376 .43259 Mdot
.34071 .47422 Mdot
.50289 .66783 Mdot
.49719 .66266 Mdot
.59976 .56659 Mdot
.64546 .58029 Mdot
.64623 .59379 Mdot
.34502 .53097 Mdot
.33342 .49978 Mdot
.50705 .33468 Mdot
.30338 .5056 Mdot
.29242 .26331 Mdot
.70557 .45847 Mdot
.62152 .62512 Mdot
.51556 .65957 Mdot
.33674 .52485 Mdot
.4882 .37397 Mdot
.75714 .50837 Mdot
.68072 .55804 Mdot
.7162 .40685 Mdot
.49397 .57926 Mdot
.80317 .30896 Mdot
.52969 .34102 Mdot
.52859 .66464 Mdot
.29409 .60131 Mdot
.50626 .38192 Mdot
.61565 .59687 Mdot
.50836 .23841 Mdot
.36226 .68995 Mdot
.47399 .41356 Mdot
.50832 .42388 Mdot
.51205 .61496 Mdot
.58136 .50215 Mdot
.53026 .37043 Mdot
.48455 .49933 Mdot
.54257 .64757 Mdot
.65228 .55944 Mdot
.19349 .64452 Mdot
.53853 .60261 Mdot
.67946 .26106 Mdot
.36418 .70948 Mdot
.52671 .34235 Mdot
.63467 .58975 Mdot
.71663 .40442 Mdot
.63907 .58534 Mdot
.29453 .47954 Mdot
.63274 .61051 Mdot
.50569 .37093 Mdot
.34197 .49403 Mdot
.51031 .66462 Mdot
.42865 .50184 Mdot
.17738 .47383 Mdot
.61025 .61502 Mdot
.33232 .71335 Mdot
.48143 .41213 Mdot
.25581 .34807 Mdot
.45909 .3031 Mdot
.49809 .41523 Mdot
.49894 .63255 Mdot
.33217 .52196 Mdot
.5083 .68306 Mdot
.51742 .32604 Mdot
.43547 .24401 Mdot
.52941 .64194 Mdot
.26425 .65282 Mdot
.69551 .41208 Mdot
.62808 .23774 Mdot
.48506 .38591 Mdot
.51228 .62129 Mdot
.46324 .35674 Mdot
.32516 .47365 Mdot
.45515 .54576 Mdot
.25692 .58083 Mdot
.50517 .62167 Mdot
.40484 .81679 Mdot
.51092 .5182 Mdot
.54168 .42974 Mdot
.5234 .62385 Mdot
.33159 .42351 Mdot
.35392 .69972 Mdot
.69074 .42336 Mdot
.67415 .44044 Mdot
.72761 .42956 Mdot
.52929 .38033 Mdot
.4215 .42546 Mdot
.71114 .39777 Mdot
.52963 .67026 Mdot
.70717 .40082 Mdot
.57954 .23991 Mdot
.4322 .82293 Mdot
.71425 .40874 Mdot
.48052 .38406 Mdot
.48966 .32024 Mdot
.73302 .34545 Mdot
.65614 .55911 Mdot
.62685 .78062 Mdot
.22514 .35355 Mdot
.49751 .40925 Mdot
.54774 .28142 Mdot
.28557 .49149 Mdot
.32468 .5826 Mdot
.55339 .31206 Mdot
.62238 .50033 Mdot
.32265 .52189 Mdot
.49061 .56219 Mdot
.29558 .52155 Mdot
.53798 .34488 Mdot
.46855 .38546 Mdot
.36577 .49053 Mdot
.46162 .78356 Mdot
.22028 .61464 Mdot
.34334 .76535 Mdot
.29617 .49222 Mdot
.53122 .62779 Mdot
.53315 .66164 Mdot
.50643 .6323 Mdot
.65385 .5908 Mdot
.3515 .52028 Mdot
.47043 .35042 Mdot
.6032 .59276 Mdot
.45267 .39204 Mdot
.49367 .64582 Mdot
.39318 .68186 Mdot
.30673 .51785 Mdot
.49779 .39333 Mdot
.19886 .40097 Mdot
.62998 .57246 Mdot
.70441 .41891 Mdot
.45715 .59249 Mdot
.66645 .60212 Mdot
.53998 .6296 Mdot
.37316 .50717 Mdot
.64222 .63222 Mdot
.74423 .47774 Mdot
.46467 .43296 Mdot
.44583 .41118 Mdot
.50099 .7129 Mdot
.18719 .44788 Mdot
.52576 .37535 Mdot
.60065 .59631 Mdot
.65687 .6045 Mdot
.45449 .36121 Mdot
.35252 .48882 Mdot
.68598 .40381 Mdot
.72924 .43163 Mdot
.53128 .40338 Mdot
.43556 .58185 Mdot
.67105 .26605 Mdot
.51117 .34506 Mdot
.54405 .4461 Mdot
.6318 .54852 Mdot
.3688 .70304 Mdot
.41218 .58532 Mdot
.71617 .44382 Mdot
.46149 .38608 Mdot
.22783 .6368 Mdot
.31556 .52138 Mdot
.64099 .60395 Mdot
.49586 .66972 Mdot
.69393 .39258 Mdot
.59292 .60102 Mdot
.4547 .36101 Mdot
.51129 .33912 Mdot
.5039 .6162 Mdot
.35006 .4527 Mdot
.69614 .4334 Mdot
.60417 .59537 Mdot
.69414 .45005 Mdot
.33096 .49341 Mdot
.31241 .51596 Mdot
.47547 .30949 Mdot
.49132 .30006 Mdot
.60111 .60977 Mdot
.51323 .42635 Mdot
.63523 .55871 Mdot
.7838 .52052 Mdot
.50531 .67424 Mdot
.47962 .42939 Mdot
.34254 .45957 Mdot
.49535 .64482 Mdot
.50979 .40274 Mdot
.49738 .71085 Mdot
.52123 .35045 Mdot
.67165 .57143 Mdot
.44774 .2269 Mdot
.6923 .44258 Mdot
.40745 .46173 Mdot
.39829 .37803 Mdot
.48461 .36151 Mdot
.66197 .56035 Mdot
.41388 .39023 Mdot
.52668 .64474 Mdot
.33443 .51122 Mdot
.55048 .15569 Mdot
.50478 .6545 Mdot
.46773 .37508 Mdot
.70437 .43487 Mdot
.28759 .52633 Mdot
.34309 .71437 Mdot
.4016 .62056 Mdot
.50277 .44958 Mdot
.54596 .41084 Mdot
.46729 .36539 Mdot
.82572 .41786 Mdot
.64057 .59348 Mdot
.34332 .52029 Mdot
.52002 .67124 Mdot
.51168 .64272 Mdot
.63165 .5666 Mdot
.30618 .69088 Mdot
.49136 .80387 Mdot
.09182 .49862 Mdot
.5955 .59842 Mdot
.72264 .40373 Mdot
.48296 .54398 Mdot
.62591 .55875 Mdot
.63349 .59564 Mdot
.59896 .56558 Mdot
.34976 .65394 Mdot
.31554 .48136 Mdot
.47244 .39401 Mdot
.37397 .48645 Mdot
.52942 .34777 Mdot
.73981 .31783 Mdot
.50333 .64271 Mdot
.33456 .50885 Mdot
.5344 .69442 Mdot
.53725 .31111 Mdot
.51371 .38319 Mdot
.69923 .55266 Mdot
.4816 .448 Mdot
.66573 .30062 Mdot
.53608 .32876 Mdot
.63931 .57791 Mdot
.52554 .27503 Mdot
.43154 .42438 Mdot
.21403 .37629 Mdot
.50268 .66569 Mdot
.34543 .71883 Mdot
.46423 .33604 Mdot
.52422 .44948 Mdot
.29125 .52953 Mdot
.34153 .47445 Mdot
.70718 .39788 Mdot
.44178 .60783 Mdot
.50626 .6659 Mdot
.54343 .80045 Mdot
.50909 .41089 Mdot
.45079 .68005 Mdot
.44144 .22469 Mdot
.50938 .40046 Mdot
.67628 .52386 Mdot
.37302 .36749 Mdot
.52654 .36314 Mdot
.26716 .39682 Mdot
.51209 .65795 Mdot
.42963 .20569 Mdot
.53448 .40684 Mdot
.61655 .59639 Mdot
.33781 .50255 Mdot
.2828 .49981 Mdot
.70854 .40528 Mdot
.25365 .30255 Mdot
.47333 .6729 Mdot
.33467 .50302 Mdot
.50068 .37955 Mdot
.52157 .65901 Mdot
.34845 .7182 Mdot
.53223 .42756 Mdot
.77741 .60479 Mdot
.30304 .50979 Mdot
.42408 .38079 Mdot
.32486 .74226 Mdot
.51668 .52839 Mdot
.6024 .81373 Mdot
.50841 .62956 Mdot
.7189 .44279 Mdot
.5411 .3318 Mdot
.65752 .65693 Mdot
.54118 .39592 Mdot
.70957 .29181 Mdot
.26389 .51131 Mdot
.68328 .44459 Mdot
.5036 .38543 Mdot
.52986 .37031 Mdot
.45882 .56145 Mdot
.6812 .4505 Mdot
.53056 .36832 Mdot
.4522 .32514 Mdot
.31359 .48525 Mdot
.33999 .69253 Mdot
.30148 .51298 Mdot
.48171 .37718 Mdot
.56388 .28719 Mdot
.34436 .479 Mdot
.60089 .77895 Mdot
.75272 .40916 Mdot
.52154 .64017 Mdot
.50127 .46046 Mdot
.4818 .41842 Mdot
.78036 .69725 Mdot
.35786 .7189 Mdot
.71676 .27091 Mdot
.67043 .58995 Mdot
.26946 .72385 Mdot
.66956 .5995 Mdot
.48933 .84645 Mdot
.42752 .51654 Mdot
.48757 .43353 Mdot
.64944 .38692 Mdot
.26068 .39425 Mdot
.501 .68763 Mdot
.29533 .30597 Mdot
.50364 .41261 Mdot
.47308 .40601 Mdot
.6057 .57755 Mdot
.31393 .6976 Mdot
.29823 .60712 Mdot
.42505 .5795 Mdot
.69051 .43425 Mdot
.32766 .49926 Mdot
.51011 .37045 Mdot
.42549 .75027 Mdot
.61416 .61226 Mdot
.58399 .44043 Mdot
.49473 .39304 Mdot
.33976 .62144 Mdot
.29454 .66045 Mdot
.51948 .66244 Mdot
.67002 .58395 Mdot
.66198 .55615 Mdot
.49536 .32728 Mdot
.48679 .66201 Mdot
.52025 .34175 Mdot
.50547 .51875 Mdot
.43457 .41677 Mdot
.68186 .42872 Mdot
.4537 .40234 Mdot
.60705 .43719 Mdot
.48504 .85952 Mdot
.44844 .43891 Mdot
.30473 .53142 Mdot
.65375 .58533 Mdot
.63978 .56653 Mdot
.29394 .49549 Mdot
.63808 .5655 Mdot
.30352 .35528 Mdot
.40638 .23876 Mdot
.68504 .4213 Mdot
.221 .4183 Mdot
.68884 .43828 Mdot
.3442 .71858 Mdot
.49473 .40557 Mdot
.67682 .65691 Mdot
.59532 .59962 Mdot
.541 .22748 Mdot
.5082 .64785 Mdot
.35899 .71829 Mdot
.44615 .36045 Mdot
.67292 .49754 Mdot
.61509 .57142 Mdot
.62712 .74594 Mdot
.47735 .3358 Mdot
.32198 .47675 Mdot
.52768 .36604 Mdot
.44294 .42029 Mdot
.36726 .7114 Mdot
.4666 .36481 Mdot
.5344 .64562 Mdot
.35251 .52004 Mdot
.49323 .84142 Mdot
.65609 .58676 Mdot
.46956 .40868 Mdot
.50158 .38022 Mdot
.33936 .47172 Mdot
.44106 .36651 Mdot
.48641 .64614 Mdot
.18807 .7227 Mdot
.69376 .41351 Mdot
.36937 .70043 Mdot
.61186 .76061 Mdot
.50928 .36364 Mdot
.51168 .35104 Mdot
.49049 .71593 Mdot
.21746 .56743 Mdot
.53282 .63885 Mdot
.43331 .3771 Mdot
.60906 .60406 Mdot
.69892 .43837 Mdot
.49153 .6313 Mdot
.45709 .36105 Mdot
.47498 .40657 Mdot
.68167 .42497 Mdot
.69877 .54744 Mdot
.66815 .54906 Mdot
.50869 .63473 Mdot
.5617 .30109 Mdot
.7614 .51186 Mdot
.48211 .39967 Mdot
.37986 .78292 Mdot
.3194 .51591 Mdot
.52254 .62567 Mdot
.35023 .42992 Mdot
.54194 .36115 Mdot
.53842 .62827 Mdot
.50839 .66493 Mdot
.45472 .35139 Mdot
.37466 .49455 Mdot
.3351 .53833 Mdot
.32043 .51791 Mdot
.46345 .21539 Mdot
.78242 .39801 Mdot
.64659 .59487 Mdot
.50967 .66065 Mdot
.63963 .61928 Mdot
.69956 .39752 Mdot
.48344 .55121 Mdot
.65771 .60457 Mdot
.28361 .50432 Mdot
.63552 .6227 Mdot
.52011 .34416 Mdot
.49745 .6662 Mdot
.59809 .59635 Mdot
.49986 .35829 Mdot
.53391 .45592 Mdot
.61591 .42598 Mdot
.68073 .40893 Mdot
.48519 .56282 Mdot
.47327 .37524 Mdot
.36502 .70309 Mdot
.49959 .39925 Mdot
.48756 .66654 Mdot
.60143 .45172 Mdot
.49178 .354 Mdot
.59655 .60548 Mdot
.75766 .47128 Mdot
.6643 .56817 Mdot
.4351 .40479 Mdot
.48062 .37743 Mdot
.48104 .40168 Mdot
.53185 .3762 Mdot
.27682 .66632 Mdot
.49749 .68327 Mdot
.49452 .46358 Mdot
.58815 .59494 Mdot
.31178 .49501 Mdot
.32807 .47156 Mdot
.61326 .50771 Mdot
.36656 .71807 Mdot
.4863 .65691 Mdot
.47911 .40143 Mdot
.62772 .74523 Mdot
.40063 .68454 Mdot
.36267 .78 Mdot
.64948 .51274 Mdot
.59972 .59703 Mdot
.31002 .53376 Mdot
.60898 .56341 Mdot
.44899 .36785 Mdot
.53743 .33023 Mdot
.50933 .83868 Mdot
.54998 .63355 Mdot
.69504 .43226 Mdot
.45199 .39183 Mdot
.65074 .24429 Mdot
.60642 .60222 Mdot
.63583 .54813 Mdot
.51606 .33725 Mdot
.33107 .54403 Mdot
.56862 .84803 Mdot
.49118 .66793 Mdot
.26332 .33741 Mdot
.25883 .4974 Mdot
.58126 .41376 Mdot
.52155 .64941 Mdot
.64524 .46475 Mdot
.65968 .56749 Mdot
.23567 .3356 Mdot
.30923 .50059 Mdot
.69536 .42859 Mdot
.45779 .32538 Mdot
.28305 .50546 Mdot
.65694 .6147 Mdot
.30772 .52572 Mdot
.54235 .35347 Mdot
.52305 .67521 Mdot
.63732 .56265 Mdot
.48361 .67123 Mdot
.36639 .49674 Mdot
.69023 .44013 Mdot
.55566 .23946 Mdot
.26519 .33121 Mdot
.37317 .36752 Mdot
.48885 .34982 Mdot
.70014 .65993 Mdot
.46781 .35019 Mdot
.30737 .53796 Mdot
.48431 .38551 Mdot
.41708 .47848 Mdot
.6443 .55307 Mdot
.42397 .39054 Mdot
.46056 .41118 Mdot
.24328 .34008 Mdot
.51416 .39168 Mdot
.44698 .36139 Mdot
.52098 .41487 Mdot
.27941 .46455 Mdot
.43022 .36617 Mdot
.3242 .47704 Mdot
.32431 .6514 Mdot
.63155 .59457 Mdot
.73188 .40451 Mdot
.72173 .4442 Mdot
.70198 .28463 Mdot
.63483 .23942 Mdot
.31059 .6864 Mdot
.2955 .50092 Mdot
.53776 .6357 Mdot
.5181 .34036 Mdot
.29748 .43446 Mdot
.61395 .37199 Mdot
.6572 .56469 Mdot
.60962 .61859 Mdot
.46813 .30897 Mdot
.84809 .45933 Mdot
.42682 .37357 Mdot
.39482 .63069 Mdot
.53217 .36471 Mdot
.48929 .42903 Mdot
.63313 .54699 Mdot
.59688 .2425 Mdot
.48952 .35018 Mdot
.29085 .52918 Mdot
.69567 .42355 Mdot
.54325 .28251 Mdot
.60324 .33578 Mdot
.59859 .39707 Mdot
.27445 .55748 Mdot
.46689 .35789 Mdot
.60701 .59343 Mdot
.28305 .51012 Mdot
.39693 .60139 Mdot
.50186 .63446 Mdot
.41181 .60023 Mdot
.28579 .30058 Mdot
.54418 .59971 Mdot
.69337 .42812 Mdot
.65264 .52041 Mdot
.50493 .37053 Mdot
.65278 .59185 Mdot
.53516 .34662 Mdot
.40175 .68782 Mdot
.6818 .43893 Mdot
.36231 .51675 Mdot
.53241 .62868 Mdot
.30501 .4827 Mdot
.33633 .41109 Mdot
.61009 .36261 Mdot
.26994 .72536 Mdot
.65151 .60543 Mdot
.44989 .26667 Mdot
.34473 .51008 Mdot
.46669 .3453 Mdot
.09571 .48737 Mdot
.32127 .51385 Mdot
.31062 .48017 Mdot
.62482 .49905 Mdot
.57536 .25559 Mdot
.42949 .42408 Mdot
.29723 .52064 Mdot
.59943 .62352 Mdot
.71544 .42606 Mdot
.50437 .35342 Mdot
.5288 .4038 Mdot
.34515 .47729 Mdot
.61912 .56847 Mdot
.65178 .24108 Mdot
.64283 .57868 Mdot
.32445 .48109 Mdot
.62478 .58004 Mdot
.58623 .77628 Mdot
.62043 .61124 Mdot
.46257 .4139 Mdot
.47914 .40053 Mdot
.76986 .58837 Mdot
.31233 .51589 Mdot
.5102 .35333 Mdot
.46535 .39042 Mdot
.34582 .50077 Mdot
.59563 .56199 Mdot
.38156 .37634 Mdot
.49843 .36242 Mdot
.47476 .39806 Mdot
.68519 .44829 Mdot
.50935 .55164 Mdot
.40477 .75489 Mdot
.50661 .35335 Mdot
.73 .42174 Mdot
.34221 .53215 Mdot
.502 .39863 Mdot
.59678 .23888 Mdot
.67747 .58987 Mdot
.44516 .3798 Mdot
.34079 .71181 Mdot
.52521 .38097 Mdot
.56147 .8507 Mdot
.47521 .40985 Mdot
.3495 .50803 Mdot
.34064 .50741 Mdot
.67369 .55253 Mdot
.31848 .49633 Mdot
.362 .71365 Mdot
.49375 .64982 Mdot
.36252 .78986 Mdot
.35864 .71564 Mdot
.47798 .42708 Mdot
.20972 .3607 Mdot
.53494 .39726 Mdot
.46102 .33382 Mdot
.55799 .23269 Mdot
.36088 .71156 Mdot
.33607 .521 Mdot
.4628 .78079 Mdot
.46862 .42979 Mdot
.48959 .66665 Mdot
.47362 .32403 Mdot
.44456 .38189 Mdot
.53638 .48091 Mdot
.44609 .23925 Mdot
.47504 .64824 Mdot
.55901 .40896 Mdot
.50518 .35237 Mdot
.21912 .5381 Mdot
.4998 .3749 Mdot
.7112 .40735 Mdot
.29071 .50581 Mdot
.61331 .55957 Mdot
.70056 .41391 Mdot
.50831 .36718 Mdot
.6994 .42853 Mdot
.64484 .59689 Mdot
.50351 .62565 Mdot
.45113 .39697 Mdot
.70171 .45706 Mdot
.6944 .43529 Mdot
.48616 .33815 Mdot
.33592 .50515 Mdot
.44202 .31114 Mdot
.50411 .39879 Mdot
.45667 .35801 Mdot
.29477 .49496 Mdot
.25243 .26545 Mdot
.52133 .33453 Mdot
.64841 .47151 Mdot
.34389 .4683 Mdot
.36986 .69136 Mdot
.60293 .57078 Mdot
.55182 .36576 Mdot
.50737 .64002 Mdot
.49864 .64567 Mdot
.58339 .59315 Mdot
.36037 .49231 Mdot
.63221 .56159 Mdot
.53165 .43254 Mdot
.47213 .30772 Mdot
.45818 .32281 Mdot
.55371 .15685 Mdot
.622 .76806 Mdot
.35462 .50801 Mdot
.66091 .56579 Mdot
.42347 .58673 Mdot
.48809 .65781 Mdot
.58149 .59074 Mdot
.33446 .46 Mdot
.33783 .52922 Mdot
.28546 .50761 Mdot
.71742 .43999 Mdot
.64837 .57539 Mdot
.26932 .50143 Mdot
.34663 .53522 Mdot
.49805 .3321 Mdot
.50448 .35155 Mdot
.28074 .53819 Mdot
.72708 .34784 Mdot
.68356 .43507 Mdot
.61089 .59347 Mdot
.74105 .75428 Mdot
.49184 .66896 Mdot
.24103 .34246 Mdot
.49965 .35904 Mdot
.17849 .29563 Mdot
.43345 .3593 Mdot
.5006 .37807 Mdot
.34499 .52894 Mdot
.73178 .43593 Mdot
.71179 .42858 Mdot
.34428 .5094 Mdot
.35536 .53322 Mdot
.72564 .4269 Mdot
.66182 .51228 Mdot
.38262 .81165 Mdot
.40485 .59762 Mdot
.34945 .50162 Mdot
.24445 .35767 Mdot
.49481 .62838 Mdot
.36042 .47463 Mdot
.47785 .6581 Mdot
.63266 .59668 Mdot
.61579 .61882 Mdot
.50119 .61639 Mdot
.46234 .34686 Mdot
.63433 .60863 Mdot
.48242 .45226 Mdot
.55759 .81511 Mdot
.76207 .65403 Mdot
.20194 .56803 Mdot
.52288 .40336 Mdot
.30954 .61044 Mdot
.27894 .62133 Mdot
.4785 .36516 Mdot
.55986 .34074 Mdot
.69626 .43087 Mdot
.35677 .4739 Mdot
.48195 .65252 Mdot
.63305 .78585 Mdot
.48124 .40027 Mdot
.33099 .48186 Mdot
.49248 .66316 Mdot
.57718 .77325 Mdot
.49212 .49953 Mdot
.52255 .33988 Mdot
.0908 .55887 Mdot
.36555 .50217 Mdot
.61444 .55897 Mdot
.20271 .42044 Mdot
.37156 .47941 Mdot
.7634 .49734 Mdot
.6607 .55167 Mdot
.36735 .75385 Mdot
.32814 .53049 Mdot
.63464 .53914 Mdot
.32786 .49269 Mdot
.68934 .40926 Mdot
.37491 .50287 Mdot
.62487 .57098 Mdot
.50824 .38774 Mdot
.62887 .5695 Mdot
.68047 .42271 Mdot
.64901 .60295 Mdot
.48218 .64998 Mdot
.36484 .70753 Mdot
.49379 .65953 Mdot
.4882 .54951 Mdot
.40646 .28151 Mdot
.51771 .63087 Mdot
.65373 .7285 Mdot
.52435 .37275 Mdot
.35995 .45418 Mdot
.60992 .56058 Mdot
.60507 .62217 Mdot
.45983 .57286 Mdot
.32831 .48465 Mdot
.62002 .57702 Mdot
.28882 .30108 Mdot
.35557 .1782 Mdot
.4676 .45249 Mdot
.78277 .41152 Mdot
.34667 .49999 Mdot
.64144 .55156 Mdot
.39309 .61618 Mdot
.29722 .48277 Mdot
.59883 .60457 Mdot
.52337 .62273 Mdot
.51538 .64336 Mdot
.4722 .33727 Mdot
.51135 .61059 Mdot
.65983 .55762 Mdot
.22475 .6211 Mdot
.28961 .50429 Mdot
.58818 .76351 Mdot
.72115 .41242 Mdot
.63734 .59769 Mdot
.42639 .41548 Mdot
.27018 .54383 Mdot
.60578 .61883 Mdot
.8009 .57283 Mdot
.77398 .71949 Mdot
.6195 .57823 Mdot
.2909 .50668 Mdot
.30663 .49492 Mdot
.44395 .43549 Mdot
.44156 .57625 Mdot
.61723 .57267 Mdot
.68497 .65362 Mdot
.71668 .29988 Mdot
.34434 .70998 Mdot
.18674 .40953 Mdot
.48887 .35084 Mdot
.4611 .36021 Mdot
.49136 .638 Mdot
.51617 .38036 Mdot
.32806 .54224 Mdot
.44862 .33921 Mdot
.53452 .66127 Mdot
.65452 .56226 Mdot
.48841 .40435 Mdot
.70976 .43966 Mdot
.48589 .64424 Mdot
.54003 .62421 Mdot
.62653 .58676 Mdot
.28943 .51491 Mdot
.44512 .78545 Mdot
.64403 .57855 Mdot
.46844 .35611 Mdot
.3544 .70685 Mdot
.54585 .3611 Mdot
.75021 .61087 Mdot
.2967 .48655 Mdot
.61231 .56118 Mdot
.32166 .46516 Mdot
.50378 .65999 Mdot
.58875 .60865 Mdot
.49483 .37156 Mdot
.60241 .60841 Mdot
.64463 .44568 Mdot
.71708 .54545 Mdot
.34689 .53633 Mdot
.66073 .44237 Mdot
.33999 .47294 Mdot
.34402 .71046 Mdot
.62827 .31661 Mdot
.68773 .42553 Mdot
.62142 .60842 Mdot
.61491 .77917 Mdot
.5937 .57492 Mdot
.51452 .39392 Mdot
.51627 .40352 Mdot
.60565 .57534 Mdot
.7065 .44499 Mdot
.60863 .21523 Mdot
.73036 .46218 Mdot
.32748 .52691 Mdot
.40522 .5377 Mdot
.68989 .79056 Mdot
.58986 .62751 Mdot
.53611 .62822 Mdot
.56539 .41109 Mdot
.52158 .356 Mdot
.51545 .61559 Mdot
.50647 .67612 Mdot
.6758 .43638 Mdot
.65058 .59522 Mdot
.29832 .46923 Mdot
.49708 .62356 Mdot
.41854 .31606 Mdot
.6159 .23513 Mdot
.46715 .44264 Mdot
.42147 .36731 Mdot
.47773 .42076 Mdot
.51623 .53035 Mdot
.51373 .67963 Mdot
.4727 .37978 Mdot
.4886 .30597 Mdot
.52602 .629 Mdot
.68239 .4182 Mdot
.38902 .49584 Mdot
.61847 .58783 Mdot
.28103 .20991 Mdot
.45189 .39894 Mdot
.50779 .39196 Mdot
.51092 .63663 Mdot
.188 .46451 Mdot
.35342 .50042 Mdot
.29169 .5146 Mdot
.64154 .59384 Mdot
.45497 .58014 Mdot
.4391 .37391 Mdot
.47627 .3681 Mdot
.62361 .60559 Mdot
.36389 .70426 Mdot
.18765 .58175 Mdot
.4747 .39157 Mdot
.51726 .6558 Mdot
.64603 .72609 Mdot
.50984 .68123 Mdot
.53091 .34253 Mdot
.51554 .39601 Mdot
.45574 .4099 Mdot
.53309 .38018 Mdot
.49921 .61894 Mdot
.48061 .3673 Mdot
.48778 .29237 Mdot
.32866 .52099 Mdot
.48285 .35606 Mdot
.6921 .28088 Mdot
.47927 .39433 Mdot
.70844 .43957 Mdot
.41041 .76306 Mdot
.46604 .40424 Mdot
.4786 .35618 Mdot
.71159 .47091 Mdot
.49938 .38478 Mdot
.51026 .6691 Mdot
.3072 .49897 Mdot
.50773 .66179 Mdot
.52862 .6576 Mdot
.62193 .62337 Mdot
.67374 .42835 Mdot
.5378 .40555 Mdot
.72783 .42185 Mdot
.43795 .42389 Mdot
.54125 .35355 Mdot
.49791 .55441 Mdot
.39528 .63255 Mdot
.69572 .46554 Mdot
.488 .37195 Mdot
.63669 .59227 Mdot
.60071 .57118 Mdot
.65124 .39329 Mdot
.46742 .44739 Mdot
.49045 .63122 Mdot
.5125 .62118 Mdot
.69429 .33577 Mdot
.51639 .48998 Mdot
.70014 .4412 Mdot
.42318 .5645 Mdot
.51397 .41356 Mdot
.46424 .39534 Mdot
.48504 .32073 Mdot
.65309 .61076 Mdot
.36722 .70454 Mdot
.65646 .56607 Mdot
.3477 .72794 Mdot
.50273 .68329 Mdot
.52134 .40472 Mdot
.73592 .68367 Mdot
.35682 .49182 Mdot
.30647 .50027 Mdot
.53988 .65304 Mdot
.66361 .56596 Mdot
.44948 .43651 Mdot
.57434 .15439 Mdot
.28153 .5303 Mdot
.73373 .41638 Mdot
.47245 .37063 Mdot
.62904 .58879 Mdot
.35785 .51274 Mdot
.67115 .44408 Mdot
.51426 .41015 Mdot
.58894 .57471 Mdot
.48308 .38952 Mdot
.25626 .41194 Mdot
.33342 .518 Mdot
.39363 .68641 Mdot
.3313 .54669 Mdot
.52408 .61919 Mdot
.5321 .64676 Mdot
.51121 .40155 Mdot
.46111 .14639 Mdot
.33106 .55019 Mdot
.48467 .61633 Mdot
.68723 .40818 Mdot
.36823 .6987 Mdot
.67677 .41853 Mdot
.63075 .55792 Mdot
.69363 .42512 Mdot
.59867 .60827 Mdot
.71013 .35082 Mdot
.27088 .51287 Mdot
.69539 .41404 Mdot
.18375 .47475 Mdot
.54416 .34584 Mdot
.67664 .44197 Mdot
.46315 .31089 Mdot
.3973 .46338 Mdot
.62438 .60351 Mdot
.70966 .44278 Mdot
.4827 .33524 Mdot
.67318 .74586 Mdot
.53093 .65238 Mdot
.48775 .63467 Mdot
.54076 .39836 Mdot
.61788 .55312 Mdot
.35951 .52783 Mdot
.59884 .494 Mdot
.36671 .68866 Mdot
.477 .36862 Mdot
.51574 .41068 Mdot
.35481 .47927 Mdot
.29381 .5332 Mdot
.51581 .39834 Mdot
.30449 .29132 Mdot
.50422 .36964 Mdot
.51879 .64407 Mdot
.34594 .5241 Mdot
.30476 .49829 Mdot
.66976 .57473 Mdot
.35997 .4921 Mdot
.42284 .3712 Mdot
.50508 .69292 Mdot
.4829 .31214 Mdot
.50268 .65688 Mdot
.60909 .44605 Mdot
.65425 .59293 Mdot
.63255 .77963 Mdot
.36233 .50202 Mdot
.46964 .36087 Mdot
.33281 .47266 Mdot
.71827 .41312 Mdot
.31054 .5149 Mdot
.27972 .49922 Mdot
.50819 .41008 Mdot
.52591 .34177 Mdot
.36032 .70569 Mdot
.44213 .57836 Mdot
.33021 .51299 Mdot
.4962 .36574 Mdot
.52906 .41159 Mdot
.5048 .32705 Mdot
.51337 .51824 Mdot
.33317 .53268 Mdot
.38598 .2357 Mdot
.75823 .62615 Mdot
.3333 .50679 Mdot
.63693 .80128 Mdot
.34213 .69669 Mdot
.36735 .71812 Mdot
.47525 .6216 Mdot
.47305 .39503 Mdot
.63218 .56313 Mdot
.44812 .37205 Mdot
.49103 .45285 Mdot
.46622 .40655 Mdot
.67934 .43159 Mdot
.48739 .43713 Mdot
.3484 .6961 Mdot
.64046 .57419 Mdot
.50372 .36395 Mdot
.48388 .40594 Mdot
.36459 .71994 Mdot
.33097 .54761 Mdot
.33333 .52968 Mdot
.38864 .78346 Mdot
.69003 .41257 Mdot
.49955 .63321 Mdot
.45081 .36748 Mdot
.63877 .59273 Mdot
.63358 .56685 Mdot
.30754 .48132 Mdot
.61525 .59293 Mdot
.4863 .6654 Mdot
.50486 .37516 Mdot
.51349 .61557 Mdot
.67946 .43069 Mdot
.2907 .50525 Mdot
.45082 .36642 Mdot
.49494 .33167 Mdot
.34063 .50779 Mdot
.52525 .37483 Mdot
.68627 .44876 Mdot
.62996 .61606 Mdot
.3382 .52583 Mdot
.49481 .64886 Mdot
.66931 .5853 Mdot
.51599 .34115 Mdot
.83165 .62028 Mdot
.51685 .37902 Mdot
.45286 .37742 Mdot
.42317 .83144 Mdot
.5328 .32499 Mdot
.63653 .55343 Mdot
.32901 .47077 Mdot
.5191 .32959 Mdot
.74332 .32442 Mdot
.5779 .65809 Mdot
.58152 .58674 Mdot
.46933 .36939 Mdot
.60973 .80128 Mdot
.47466 .36042 Mdot
.56557 .77946 Mdot
.4954 .55504 Mdot
.82346 .44837 Mdot
.42454 .35456 Mdot
.49118 .61388 Mdot
.36206 .70671 Mdot
.60846 .56038 Mdot
.28925 .42178 Mdot
.52129 .37822 Mdot
.34865 .42167 Mdot
.44297 .38336 Mdot
.52066 .64817 Mdot
.5642 .35375 Mdot
.61191 .59318 Mdot
.21671 .36404 Mdot
.46871 .35223 Mdot
.33767 .53092 Mdot
.60713 .6255 Mdot
.36474 .69249 Mdot
.48091 .33542 Mdot
.72465 .41316 Mdot
.54495 .68191 Mdot
.43811 .33765 Mdot
.50039 .65568 Mdot
.46302 .38918 Mdot
.54669 .42893 Mdot
.39675 .16916 Mdot
.32908 .52264 Mdot
.53309 .62661 Mdot
.30031 .58048 Mdot
.52825 .38718 Mdot
.33065 .52977 Mdot
.31029 .49833 Mdot
.70957 .4035 Mdot
.40725 .65123 Mdot
.6278 .6483 Mdot
.78917 .62891 Mdot
.36255 .38408 Mdot
.66848 .59411 Mdot
.23097 .59789 Mdot
.49801 .34947 Mdot
.60578 .35065 Mdot
.5188 .66508 Mdot
.50702 .38982 Mdot
.379 .3244 Mdot
.31854 .51832 Mdot
.47715 .38696 Mdot
.68309 .43298 Mdot
.37944 .66547 Mdot
.59668 .37889 Mdot
.77836 .68773 Mdot
.58584 .61312 Mdot
.47387 .32102 Mdot
.44024 .32357 Mdot
.37087 .69313 Mdot
.53449 .35193 Mdot
.61358 .55811 Mdot
.70381 .66313 Mdot
.69887 .44635 Mdot
.35951 .49717 Mdot
.3451 .69342 Mdot
.44638 .40502 Mdot
.54317 .37967 Mdot
.73119 .40436 Mdot
.46652 .34736 Mdot
.20797 .39694 Mdot
.37793 .68673 Mdot
.62171 .61218 Mdot
.30447 .52506 Mdot
.48031 .42114 Mdot
.36654 .7032 Mdot
.51184 .40787 Mdot
.38862 .51526 Mdot
.46089 .37236 Mdot
.31079 .73088 Mdot
.3374 .50139 Mdot
.49744 .65744 Mdot
.52493 .4258 Mdot
.48821 .39676 Mdot
.76074 .51604 Mdot
.49509 .45255 Mdot
.47558 .4094 Mdot
.28213 .51941 Mdot
.35012 .48451 Mdot
.31648 .4796 Mdot
.6283 .6123 Mdot
.40958 .59058 Mdot
.51289 .64967 Mdot
.44237 .354 Mdot
.49499 .62667 Mdot
.40484 .41307 Mdot
.73104 .4077 Mdot
.68496 .75979 Mdot
.51528 .36868 Mdot
.30444 .48737 Mdot
.23652 .64152 Mdot
.34336 .53181 Mdot
.4661 .62251 Mdot
.50545 .66617 Mdot
.32318 .51281 Mdot
.49405 .38292 Mdot
.42876 .57751 Mdot
.80826 .64519 Mdot
.48821 .65478 Mdot
.51539 .32134 Mdot
.59126 .6175 Mdot
.59482 .60713 Mdot
.61304 .83146 Mdot
.53251 .65444 Mdot
.27393 .61842 Mdot
.49046 .3633 Mdot
.35394 .48629 Mdot
.51237 .63122 Mdot
.5129 .66952 Mdot
.6195 .60278 Mdot
.51764 .33602 Mdot
.4863 .39495 Mdot
.34004 .70967 Mdot
.50244 .62449 Mdot
.55927 .3787 Mdot
.52947 .35633 Mdot
.49222 .84435 Mdot
.32535 .45962 Mdot
.22869 .2873 Mdot
.53753 .43003 Mdot
.38501 .32136 Mdot
.5466 .49355 Mdot
.3542 .51291 Mdot
.45348 .35707 Mdot
.43775 .36146 Mdot
.67065 .58529 Mdot
.50957 .37524 Mdot
.66293 .5829 Mdot
.53802 .63082 Mdot
.69254 .76039 Mdot
.6019 .7492 Mdot
.59351 .54479 Mdot
.51575 .38537 Mdot
.58404 .41656 Mdot
.71108 .41312 Mdot
.54222 .6575 Mdot
.33656 .48013 Mdot
.4923 .42187 Mdot
.66433 .55424 Mdot
.61735 .60787 Mdot
.31229 .50411 Mdot
.28902 .63797 Mdot
.59976 .77938 Mdot
.53368 .38193 Mdot
.61389 .56216 Mdot
.57944 .75471 Mdot
.3286 .28064 Mdot
.50299 .61145 Mdot
.69379 .44514 Mdot
.65114 .56128 Mdot
.54568 .63031 Mdot
.39762 .489 Mdot
.32051 .50356 Mdot
.36191 .48691 Mdot
.75202 .5703 Mdot
.62112 .57046 Mdot
.70884 .41705 Mdot
.48099 .49209 Mdot
.43968 .49604 Mdot
.68177 .43717 Mdot
.65601 .56281 Mdot
.35775 .49773 Mdot
.3286 .48143 Mdot
.30816 .49736 Mdot
.21315 .37747 Mdot
.29029 .49129 Mdot
.35491 .22513 Mdot
.53687 .38834 Mdot
.25409 .35177 Mdot
.47248 .36275 Mdot
.48667 .62752 Mdot
.3346 .51707 Mdot
.47631 .5529 Mdot
.50063 .42452 Mdot
.78392 .67629 Mdot
.47289 .37408 Mdot
.50337 .69734 Mdot
.47342 .3968 Mdot
.2156 .41632 Mdot
.34501 .46844 Mdot
.48855 .37087 Mdot
.47315 .64248 Mdot
.69904 .43511 Mdot
.35383 .54345 Mdot
.46979 .40465 Mdot
.32777 .68239 Mdot
.48369 .30709 Mdot
.58073 .80054 Mdot
.73996 .48028 Mdot
.73486 .42273 Mdot
.46258 .31699 Mdot
.64374 .62276 Mdot
.3087 .55802 Mdot
.24052 .37597 Mdot
.48844 .65368 Mdot
.4739 .24131 Mdot
.62532 .60864 Mdot
.56177 .34851 Mdot
.44759 .42042 Mdot
.71382 .44403 Mdot
.342 .54855 Mdot
.52094 .64317 Mdot
.52258 .37344 Mdot
.45043 .35795 Mdot
.80486 .54554 Mdot
.2337 .38306 Mdot
.55775 .38327 Mdot
.69878 .3985 Mdot
.39309 .23709 Mdot
.46137 .3988 Mdot
.58614 .57757 Mdot
.31724 .47136 Mdot
.42155 .40081 Mdot
.37527 .23811 Mdot
.50047 .3666 Mdot
.31921 .51097 Mdot
.36274 .4992 Mdot
.27937 .69682 Mdot
.73185 .41325 Mdot
.46073 .37267 Mdot
.77267 .51137 Mdot
.46413 .35738 Mdot
.51615 .64772 Mdot
.52901 .3383 Mdot
.63297 .60117 Mdot
.39025 .62175 Mdot
.63285 .61273 Mdot
.48723 .32902 Mdot
.31961 .48707 Mdot
.51935 .63935 Mdot
.74933 .58813 Mdot
.58007 .51134 Mdot
.36426 .22163 Mdot
.54638 .68252 Mdot
.71808 .43641 Mdot
.67161 .43413 Mdot
.48748 .68647 Mdot
.4825 .37516 Mdot
.54084 .51665 Mdot
.42612 .3896 Mdot
.47127 .39961 Mdot
.45398 .39928 Mdot
.55345 .64431 Mdot
.50164 .66455 Mdot
.62496 .57626 Mdot
.51725 .39655 Mdot
.49491 .36587 Mdot
.33016 .50341 Mdot
.69456 .43613 Mdot
.61975 .61465 Mdot
.69805 .4099 Mdot
.639 .58026 Mdot
.57634 .84212 Mdot
.52022 .32802 Mdot
.70031 .43541 Mdot
.51566 .68017 Mdot
.29988 .48918 Mdot
.3573 .7198 Mdot
.63258 .55852 Mdot
.61204 .59011 Mdot
.47919 .36638 Mdot
.29628 .51287 Mdot
.3097 .52187 Mdot
.72401 .4301 Mdot
.51474 .62477 Mdot
.46774 .33953 Mdot
.52909 .34993 Mdot
.8057 .46909 Mdot
.66345 .6 Mdot
.32366 .27232 Mdot
.28839 .68353 Mdot
.48362 .37479 Mdot
.31654 .52588 Mdot
.49275 .40244 Mdot
.69687 .70345 Mdot
.28355 .5058 Mdot
.51724 .42035 Mdot
.5165 .48147 Mdot
.64551 .6143 Mdot
.27966 .72171 Mdot
.52424 .42292 Mdot
.48725 .71714 Mdot
.49108 .34182 Mdot
.37019 .83156 Mdot
.22062 .5616 Mdot
.44249 .39342 Mdot
.53181 .38623 Mdot
.81006 .59992 Mdot
.48507 .36104 Mdot
.34366 .69909 Mdot
.51802 .44094 Mdot
.33535 .52988 Mdot
.56368 .4936 Mdot
.50388 .56154 Mdot
.71988 .40178 Mdot
.64188 .5945 Mdot
.59641 .27689 Mdot
.68599 .41283 Mdot
.34827 .50607 Mdot
.52611 .40886 Mdot
.41235 .31466 Mdot
.67884 .56307 Mdot
.43862 .41738 Mdot
.51768 .64791 Mdot
.49964 .56212 Mdot
.65854 .57495 Mdot
.49333 .65215 Mdot
.44625 .39562 Mdot
.71749 .27823 Mdot
.58326 .51867 Mdot
.31558 .76256 Mdot
.50884 .63496 Mdot
.51658 .6634 Mdot
.39004 .59885 Mdot
.71979 .40185 Mdot
.80995 .51935 Mdot
.57744 .3398 Mdot
.49023 .66576 Mdot
.65901 .31041 Mdot
.64902 .54724 Mdot
.40373 .65196 Mdot
.35605 .47261 Mdot
.51221 .32428 Mdot
.49279 .3861 Mdot
.52047 .62625 Mdot
.35454 .43604 Mdot
.36134 .55773 Mdot
.49164 .65803 Mdot
.45694 .30687 Mdot
.40342 .67049 Mdot
.356 .70965 Mdot
.33862 .70434 Mdot
.69489 .40272 Mdot
.7102 .5788 Mdot
.33424 .49219 Mdot
.70771 .44844 Mdot
.33784 .74094 Mdot
.45912 .37638 Mdot
.5007 .62426 Mdot
.34594 .72012 Mdot
.50138 .64596 Mdot
.70946 .43286 Mdot
.73334 .41448 Mdot
.32872 .52134 Mdot
.35308 .49876 Mdot
.44234 .24592 Mdot
.69475 .31969 Mdot
.48214 .35826 Mdot
.37861 .38383 Mdot
.29092 .49566 Mdot
.2213 .45884 Mdot
.72943 .41622 Mdot
.69023 .43576 Mdot
.27994 .36393 Mdot
.50961 .33528 Mdot
.62276 .73813 Mdot
.46588 .40299 Mdot
.63381 .32915 Mdot
.46488 .42665 Mdot
.61773 .59967 Mdot
.47936 .35187 Mdot
.43418 .76803 Mdot
.51094 .35872 Mdot
.4617 .40743 Mdot
.64595 .56676 Mdot
.53018 .42349 Mdot
.63178 .6033 Mdot
.52596 .3396 Mdot
.73422 .39972 Mdot
.63899 .59254 Mdot
.76529 .3901 Mdot
.64412 .46935 Mdot
.36344 .69824 Mdot
.68938 .40764 Mdot
.72585 .41808 Mdot
.68567 .27021 Mdot
.3422 .48326 Mdot
.40158 .479 Mdot
.48145 .37598 Mdot
.63329 .5485 Mdot
.49295 .63417 Mdot
.49929 .36726 Mdot
.44019 .34966 Mdot
.53039 .41822 Mdot
.32295 .51735 Mdot
.65336 .55887 Mdot
.70306 .42946 Mdot
.59825 .5768 Mdot
.66785 .49499 Mdot
.59102 .59287 Mdot
.55309 .43446 Mdot
.54368 .42167 Mdot
.41374 .34324 Mdot
.38001 .35541 Mdot
.23834 .32924 Mdot
.31685 .50142 Mdot
.35197 .70199 Mdot
.72621 .40324 Mdot
.40427 .53608 Mdot
.31215 .48489 Mdot
.61207 .58567 Mdot
.48322 .38945 Mdot
.45634 .30615 Mdot
.59196 .3835 Mdot
.26292 .52131 Mdot
.73221 .32606 Mdot
.65251 .58126 Mdot
.34961 .71322 Mdot
.4007 .60654 Mdot
.27567 .4707 Mdot
.48182 .54984 Mdot
.48966 .4 Mdot
.72709 .41659 Mdot
.35789 .51262 Mdot
.77704 .57347 Mdot
.52201 .62364 Mdot
.44088 .57771 Mdot
.51549 .38343 Mdot
.24353 .61846 Mdot
.31959 .48731 Mdot
.68761 .43805 Mdot
.52112 .62669 Mdot
.73074 .41326 Mdot
.34403 .69297 Mdot
.40711 .78088 Mdot
.47522 .34207 Mdot
.47703 .41068 Mdot
.49064 .67642 Mdot
.33182 .49036 Mdot
.66139 .5383 Mdot
.78654 .57929 Mdot
.61149 .56442 Mdot
.52894 .52833 Mdot
.35343 .51868 Mdot
.23175 .52496 Mdot
.60022 .60261 Mdot
.53112 .66821 Mdot
.52876 .51983 Mdot
.53462 .66032 Mdot
.45939 .40096 Mdot
.2969 .5024 Mdot
.53302 .65386 Mdot
.77153 .54238 Mdot
.55762 .83478 Mdot
.35716 .5443 Mdot
.52556 .38388 Mdot
.69194 .75803 Mdot
.47318 .82999 Mdot
.38478 .4314 Mdot
.50027 .62119 Mdot
.50506 .40259 Mdot
.53403 .38382 Mdot
.47026 .35232 Mdot
.53587 .63686 Mdot
.61708 .51585 Mdot
.60818 .59794 Mdot
.4694 .37857 Mdot
.72128 .41321 Mdot
.62658 .5971 Mdot
.62809 .62558 Mdot
.60273 .56469 Mdot
.28195 .5096 Mdot
.53183 .39944 Mdot
.38022 .6515 Mdot
.39958 .84256 Mdot
.50373 .66313 Mdot
.36329 .69787 Mdot
.45319 .40386 Mdot
.44808 .20799 Mdot
.31455 .48055 Mdot
.61096 .56564 Mdot
.5067 .39155 Mdot
.73899 .4962 Mdot
.34076 .67853 Mdot
.64716 .58016 Mdot
.33815 .48182 Mdot
.38612 .43237 Mdot
.50924 .37454 Mdot
.49371 .34044 Mdot
.34171 .49516 Mdot
.36277 .778 Mdot
.39694 .62573 Mdot
.48932 .40313 Mdot
.49573 .65681 Mdot
.37846 .16668 Mdot
.54274 .38643 Mdot
.26211 .53119 Mdot
.36902 .70014 Mdot
.30906 .70894 Mdot
.33609 .26682 Mdot
.49566 .45977 Mdot
.71872 .72353 Mdot
.58258 .24266 Mdot
.67403 .77114 Mdot
.59552 .30166 Mdot
.54442 .75337 Mdot
.51426 .87092 Mdot
.47624 .6279 Mdot
.21955 .4208 Mdot
.83388 .4998 Mdot
.30815 .63455 Mdot
.70519 .48638 Mdot
.62291 .66866 Mdot
.74921 .48674 Mdot
.16924 .51644 Mdot
.5935 .59461 Mdot
.625 .35419 Mdot
.4565 .35068 Mdot
.46607 .82485 Mdot
.2548 .33642 Mdot
.24681 .309 Mdot
.67158 .76339 Mdot
.77019 .50069 Mdot
.83311 .59793 Mdot
.63033 .77626 Mdot
.46389 .25531 Mdot
.58104 .44156 Mdot
.69113 .61543 Mdot
.45845 .49078 Mdot
.58884 .26794 Mdot
.41538 .40693 Mdot
.43025 .75073 Mdot
.58856 .5587 Mdot
.39553 .26933 Mdot
.36519 .18283 Mdot
.63779 .55551 Mdot
.31358 .47248 Mdot
.81737 .50081 Mdot
.27516 .55227 Mdot
.46445 .65308 Mdot
.71964 .72294 Mdot
.49164 .84757 Mdot
.21616 .41225 Mdot
.35993 .7432 Mdot
.27683 .40086 Mdot
.60069 .20644 Mdot
.60231 .41563 Mdot
.35756 .52542 Mdot
.5876 .71726 Mdot
.43993 .49536 Mdot
.69925 .58766 Mdot
.20678 .44188 Mdot
.67335 .44964 Mdot
.76239 .36893 Mdot
.33527 .48224 Mdot
.34293 .27374 Mdot
.37086 .71408 Mdot
.35114 .73783 Mdot
.64263 .5407 Mdot
.70691 .69154 Mdot
.35397 .66982 Mdot
.3513 .66296 Mdot
.2162 .61415 Mdot
.81366 .65735 Mdot
.62833 .26222 Mdot
.71367 .65118 Mdot
.47133 .69937 Mdot
.59209 .24396 Mdot
.36431 .62721 Mdot
.67592 .2945 Mdot
.43382 .48329 Mdot
.86453 .4852 Mdot
.39836 .80621 Mdot
.85164 .55847 Mdot
.37824 .47318 Mdot
.54843 .35146 Mdot
.72921 .65493 Mdot
.35305 .39501 Mdot
.73149 .43888 Mdot
.7985 .67179 Mdot
.72663 .43743 Mdot
.29564 .47197 Mdot
.29946 .63174 Mdot
.21832 .37974 Mdot
.64536 .52897 Mdot
.75384 .41371 Mdot
.42622 .3678 Mdot
.87134 .41924 Mdot
.73757 .70928 Mdot
.2885 .70137 Mdot
.48242 .84485 Mdot
.58523 .62718 Mdot
.6796 .59091 Mdot
.53879 .63388 Mdot
.52847 .85624 Mdot
.3067 .49127 Mdot
.41168 .852 Mdot
.52241 .8517 Mdot
.26348 .55921 Mdot
.87075 .391 Mdot
.19006 .55781 Mdot
.26388 .33802 Mdot
.51888 .24345 Mdot
.77766 .37103 Mdot
.36948 .60512 Mdot
.23108 .53622 Mdot
.6003 .62919 Mdot
.35376 .78275 Mdot
.58583 .83187 Mdot
.65908 .32326 Mdot
.55126 .59875 Mdot
.32121 .62581 Mdot
.61574 .43439 Mdot
.27159 .53682 Mdot
.72398 .47077 Mdot
.62542 .41875 Mdot
.84482 .57721 Mdot
.43482 .23355 Mdot
.50011 .14287 Mdot
.6055 .30735 Mdot
.18842 .45817 Mdot
.62596 .76137 Mdot
.74135 .3816 Mdot
.38117 .534 Mdot
.32568 .6578 Mdot
.50507 .31394 Mdot
.41546 .57056 Mdot
.50669 .28864 Mdot
.65849 .42485 Mdot
.40041 .59554 Mdot
.52922 .79035 Mdot
.61942 .3101 Mdot
.77596 .63391 Mdot
.55347 .46422 Mdot
.30071 .52615 Mdot
.6693 .27755 Mdot
.63945 .28544 Mdot
.51169 .83706 Mdot
.29917 .58124 Mdot
.32453 .76736 Mdot
.30777 .57618 Mdot
.42601 .38532 Mdot
.22132 .42643 Mdot
.41253 .39216 Mdot
.66126 .29513 Mdot
.50187 .43142 Mdot
.22062 .62847 Mdot
.43306 .83581 Mdot
.39413 .29447 Mdot
.60891 .28325 Mdot
.38977 .33171 Mdot
.36666 .79258 Mdot
.73609 .65289 Mdot
.23562 .57777 Mdot
.24462 .48694 Mdot
.86994 .44047 Mdot
.62257 .58784 Mdot
.66646 .31588 Mdot
.54381 .66425 Mdot
.75485 .57605 Mdot
.83944 .46963 Mdot
.32668 .56909 Mdot
.42308 .83461 Mdot
.34138 .64915 Mdot
.66554 .53326 Mdot
.41605 .66512 Mdot
.52074 .59918 Mdot
.40887 .30386 Mdot
.54223 .39892 Mdot
.412 .33598 Mdot
.69072 .45175 Mdot
.33478 .39697 Mdot
.74852 .62945 Mdot
.54604 .70541 Mdot
.51482 .46055 Mdot
.54973 .71649 Mdot
.34573 .7138 Mdot
.43201 .58684 Mdot
.60278 .8376 Mdot
.52155 .44509 Mdot
.18971 .53026 Mdot
.39417 .79992 Mdot
.51733 .53222 Mdot
.69907 .54578 Mdot
.26852 .65827 Mdot
.86274 .5235 Mdot
.47805 .85804 Mdot
.5033 .81406 Mdot
.69994 .75274 Mdot
.22708 .71156 Mdot
.83263 .42242 Mdot
.27885 .44058 Mdot
.55049 .65598 Mdot
.16612 .68676 Mdot
.60114 .58634 Mdot
.48389 .23466 Mdot
.35415 .39024 Mdot
.73586 .50414 Mdot
.29056 .55492 Mdot
.51134 .46987 Mdot
.57088 .64657 Mdot
.29354 .54494 Mdot
.42736 .36839 Mdot
.76957 .71599 Mdot
.86759 .48437 Mdot
.7853 .69727 Mdot
.41013 .78374 Mdot
.68819 .76909 Mdot
.83562 .54593 Mdot
.34472 .22987 Mdot
.81362 .52641 Mdot
.5295 .33941 Mdot
.67968 .34195 Mdot
.1949 .55662 Mdot
.64263 .53747 Mdot
.38289 .71592 Mdot
.35116 .46172 Mdot
.85551 .49276 Mdot
.61301 .83683 Mdot
.29993 .35825 Mdot
.37944 .26217 Mdot
.63674 .45133 Mdot
.67933 .30885 Mdot
.45214 .27962 Mdot
.43279 .73995 Mdot
.55454 .81924 Mdot
.83852 .53459 Mdot
.6351 .29487 Mdot
.60355 .68078 Mdot
.50635 .80538 Mdot
.20849 .51647 Mdot
.66066 .75174 Mdot
.82128 .49057 Mdot
.27857 .56747 Mdot
.29285 .45374 Mdot
.35329 .56098 Mdot
.42249 .7287 Mdot
.67911 .69172 Mdot
.61288 .25833 Mdot
.65069 .60255 Mdot
.66501 .32822 Mdot
.47729 .52373 Mdot
.81679 .51973 Mdot
.60426 .23999 Mdot
.65472 .3269 Mdot
.52354 .80803 Mdot
.74523 .73232 Mdot
.33306 .75412 Mdot
.75026 .30439 Mdot
.46533 .71953 Mdot
.51929 .29269 Mdot
.55321 .36892 Mdot
.40138 .81775 Mdot
.72041 .76618 Mdot
.4363 .84332 Mdot
.2396 .61502 Mdot
.76454 .54438 Mdot
.52414 .61345 Mdot
.5972 .22639 Mdot
.5174 .71597 Mdot
.5633 .81995 Mdot
.41062 .54466 Mdot
.48717 .61097 Mdot
.35493 .64496 Mdot
.46138 .24988 Mdot
.55172 .23582 Mdot
.35471 .28516 Mdot
.45587 .4402 Mdot
.29483 .30612 Mdot
.33777 .46898 Mdot
.23663 .60408 Mdot
.67475 .29901 Mdot
.62591 .58779 Mdot
.80362 .44009 Mdot
.42822 .30594 Mdot
.53492 .32559 Mdot
.69289 .67025 Mdot
.27497 .5398 Mdot
.37987 .34965 Mdot
.67214 .60708 Mdot
.53645 .86403 Mdot
.20957 .5685 Mdot
.44015 .28156 Mdot
.64475 .26049 Mdot
.80121 .47813 Mdot
.40344 .62447 Mdot
.50372 .68681 Mdot
.66036 .76704 Mdot
.64057 .48061 Mdot
.66079 .27277 Mdot
.30231 .29777 Mdot
.77207 .59646 Mdot
.43723 .35891 Mdot
.26901 .67604 Mdot
.39474 .21312 Mdot
.43782 .58546 Mdot
.28822 .47135 Mdot
.27725 .52506 Mdot
.14877 .47614 Mdot
.44901 .77244 Mdot
.26192 .57368 Mdot
.67001 .75391 Mdot
.53911 .64733 Mdot
.296 .53025 Mdot
.65686 .33716 Mdot
.72132 .55013 Mdot
.4093 .24055 Mdot
.68473 .69399 Mdot
.48776 .26334 Mdot
.50472 .72636 Mdot
.6973 .75034 Mdot
.78585 .66014 Mdot
.41116 .16128 Mdot
.32227 .54672 Mdot
.74327 .61373 Mdot
.75391 .60081 Mdot
.35274 .5284 Mdot
.26235 .52409 Mdot
.59078 .40389 Mdot
.65932 .78929 Mdot
.42697 .52887 Mdot
.42155 .70929 Mdot
.52915 .52061 Mdot
.69982 .4957 Mdot
.78648 .56783 Mdot
.59716 .25777 Mdot
.67759 .74168 Mdot
.34304 .28526 Mdot
.78959 .36611 Mdot
.42555 .32264 Mdot
.45672 .2299 Mdot
.59707 .22601 Mdot
.59435 .4379 Mdot
.20905 .44615 Mdot
.55 .78601 Mdot
.46982 .35657 Mdot
.80887 .66912 Mdot
.51103 .83165 Mdot
.4048 .57359 Mdot
.67804 .6204 Mdot
.51164 .34733 Mdot
.53517 .39399 Mdot
.30594 .44316 Mdot
.30008 .69656 Mdot
.81042 .37312 Mdot
.61933 .32294 Mdot
.51726 .28977 Mdot
.2967 .29971 Mdot
.19015 .52982 Mdot
.71898 .66866 Mdot
.59598 .79029 Mdot
.45862 .53203 Mdot
.19732 .55979 Mdot
.44473 .60693 Mdot
.41288 .70541 Mdot
.50064 .74277 Mdot
.83281 .55454 Mdot
.58005 .39884 Mdot
.30727 .67564 Mdot
.80451 .52139 Mdot
.45223 .40093 Mdot
.28899 .63842 Mdot
.64337 .76298 Mdot
.53618 .15844 Mdot
.35355 .62224 Mdot
.75091 .74071 Mdot
.41357 .33842 Mdot
.3169 .67264 Mdot
.84473 .46435 Mdot
.63254 .17629 Mdot
.42387 .74713 Mdot
.8375 .5932 Mdot
.4206 .63416 Mdot
.67716 .74934 Mdot
.49496 .61283 Mdot
.48247 .50137 Mdot
.36723 .41064 Mdot
.6526 .79283 Mdot
.7225 .59046 Mdot
.70689 .70361 Mdot
.28955 .44653 Mdot
.68814 .77629 Mdot
.42529 .47989 Mdot
.15508 .46264 Mdot
.5856 .57485 Mdot
.19969 .61947 Mdot
.24835 .46568 Mdot
.47856 .27854 Mdot
.65318 .30941 Mdot
.17416 .424 Mdot
.29844 .26068 Mdot
.30159 .43469 Mdot
.65757 .36689 Mdot
.27803 .66853 Mdot
.63837 .25473 Mdot
.56231 .82444 Mdot
.16491 .50383 Mdot
.76989 .58699 Mdot
.26694 .59819 Mdot
.38619 .78649 Mdot
.29833 .70285 Mdot
.49531 .76096 Mdot
.7098 .6645 Mdot
.39389 .74217 Mdot
.49601 .26366 Mdot
.18994 .29728 Mdot
.52168 .57701 Mdot
.59129 .39479 Mdot
.85647 .53018 Mdot
.54858 .82147 Mdot
.40414 .54282 Mdot
.20346 .43831 Mdot
.50327 .2141 Mdot
.71296 .35355 Mdot
.46674 .40654 Mdot
.69432 .77272 Mdot
.74453 .37307 Mdot
.8157 .63883 Mdot
.34177 .79302 Mdot
.3034 .30857 Mdot
.54602 .4345 Mdot
.60214 .62856 Mdot
.60422 .39138 Mdot
.64913 .37362 Mdot
.84207 .55664 Mdot
.47 .23292 Mdot
.58112 .50542 Mdot
.54763 .74487 Mdot
.637 .73903 Mdot
.55084 .31451 Mdot
.19293 .57282 Mdot
.2926 .67987 Mdot
.60232 .29325 Mdot
.49218 .80389 Mdot
.66601 .30642 Mdot
.32859 .27069 Mdot
.60655 .23202 Mdot
.36368 .58142 Mdot
.60451 .6409 Mdot
.67002 .56988 Mdot
.8032 .603 Mdot
.60849 .77312 Mdot
.22358 .63338 Mdot
.76156 .32335 Mdot
.32079 .65652 Mdot
.62708 .36929 Mdot
.76886 .62452 Mdot
.36232 .60543 Mdot
.68992 .62701 Mdot
.54103 .23533 Mdot
.44915 .23638 Mdot
.56928 .78616 Mdot
.47582 .46764 Mdot
.58884 .8332 Mdot
.60981 .2596 Mdot
.80113 .57764 Mdot
.63258 .45914 Mdot
.35422 .36441 Mdot
.25125 .38597 Mdot
.78111 .39462 Mdot
.4538 .57881 Mdot
.87067 .42543 Mdot
.36749 .50896 Mdot
.8154 .65418 Mdot
.49757 .6344 Mdot
.44308 .17028 Mdot
.56497 .80202 Mdot
.46655 .5399 Mdot
.53095 .51103 Mdot
.26958 .68011 Mdot
.33769 .67418 Mdot
.37788 .78939 Mdot
.3375 .56581 Mdot
.59141 .57627 Mdot
.59463 .5049 Mdot
.42523 .71647 Mdot
.77629 .64482 Mdot
.50019 .32467 Mdot
.65286 .52769 Mdot
.60018 .42826 Mdot
.45201 .63763 Mdot
.40617 .81791 Mdot
.55879 .77413 Mdot
.41803 .37578 Mdot
.68256 .30952 Mdot
.84524 .52891 Mdot
.52782 .84592 Mdot
.37846 .5493 Mdot
.50391 .28831 Mdot
.50044 .69557 Mdot
.81968 .43938 Mdot
.73884 .70124 Mdot
.61129 .74586 Mdot
.39928 .65155 Mdot
.62823 .26519 Mdot
.80788 .6961 Mdot
.86616 .48427 Mdot
.77121 .32745 Mdot
.53524 .51933 Mdot
.36115 .45393 Mdot
.4502 .21022 Mdot
.79878 .58258 Mdot
.20426 .6379 Mdot
.50893 .82305 Mdot
.66409 .31154 Mdot
.58313 .1738 Mdot
.26076 .30616 Mdot
.63865 .50047 Mdot
.25199 .38702 Mdot
.36785 .37727 Mdot
.4995 .60728 Mdot
.70604 .35996 Mdot
.62178 .49112 Mdot
.46813 .65923 Mdot
.28101 .6711 Mdot
.35887 .66303 Mdot
.80357 .57282 Mdot
.40431 .22682 Mdot
.49318 .28588 Mdot
.7541 .66635 Mdot
.26953 .50796 Mdot
.7724 .57811 Mdot
.80327 .48361 Mdot
.62438 .49545 Mdot
.59703 .58224 Mdot
.42574 .42835 Mdot
.42127 .6022 Mdot
.43358 .61146 Mdot
.6755 .23666 Mdot
.71561 .45045 Mdot
.37682 .48404 Mdot
.22478 .34866 Mdot
.32466 .54387 Mdot
.70232 .78401 Mdot
.43444 .74038 Mdot
.28511 .31244 Mdot
.49275 .58864 Mdot
.60179 .69486 Mdot
.66482 .2155 Mdot
.46202 .25348 Mdot
.7412 .45491 Mdot
.33269 .4512 Mdot
.34217 .47203 Mdot
.49416 .5925 Mdot
.37562 .68887 Mdot
.36059 .26807 Mdot
.18196 .51992 Mdot
.80227 .47286 Mdot
.34488 .54026 Mdot
.63169 .50526 Mdot
.39269 .39243 Mdot
.59197 .83962 Mdot
.59776 .57408 Mdot
.87128 .45204 Mdot
.54569 .42068 Mdot
.81996 .41727 Mdot
.40906 .82213 Mdot
.38708 .62103 Mdot
.54204 .51869 Mdot
.65976 .65526 Mdot
.45812 .33461 Mdot
.49972 .28315 Mdot
.34763 .49143 Mdot
.80977 .53879 Mdot
.69166 .42851 Mdot
.71722 .31798 Mdot
.50228 .68883 Mdot
.19989 .48193 Mdot
.19904 .57785 Mdot
.33082 .46691 Mdot
.65718 .48505 Mdot
.73054 .62277 Mdot
.5435 .47854 Mdot
.59931 .43071 Mdot
.81014 .59632 Mdot
.40634 .25188 Mdot
.35827 .52296 Mdot
.7714 .33124 Mdot
.63164 .41176 Mdot
.49437 .86586 Mdot
.40614 .4345 Mdot
.59898 .41483 Mdot
.55284 .46789 Mdot
.26441 .66496 Mdot
.34314 .26306 Mdot
.5846 .80078 Mdot
.67265 .28365 Mdot
.48119 .4892 Mdot
.65678 .32913 Mdot
.41595 .3942 Mdot
.54113 .74812 Mdot
.19167 .60137 Mdot
.5955 .17952 Mdot
.2627 .40902 Mdot
.36918 .63659 Mdot
.26609 .50323 Mdot
.19118 .53432 Mdot
.3727 .50154 Mdot
.67666 .50466 Mdot
.39766 .27142 Mdot
.56389 .80333 Mdot
.54181 .85518 Mdot
.51052 .83666 Mdot
.60546 .37325 Mdot
.62491 .74482 Mdot
.53346 .24394 Mdot
.39631 .42558 Mdot
.47922 .54368 Mdot
.45283 .3373 Mdot
.5529 .32055 Mdot
.38453 .56182 Mdot
.23465 .64146 Mdot
.57263 .39465 Mdot
.64464 .79237 Mdot
.49129 .86369 Mdot
.72428 .74321 Mdot
.67904 .68904 Mdot
.27937 .50316 Mdot
.86421 .51129 Mdot
.31568 .26608 Mdot
.5519 .83003 Mdot
.25118 .46157 Mdot
.14899 .4994 Mdot
.84072 .4825 Mdot
.53822 .79117 Mdot
.24585 .54884 Mdot
.28507 .73176 Mdot
.41446 .81752 Mdot
.15526 .46513 Mdot
.52693 .26054 Mdot
.39587 .81132 Mdot
.86846 .41625 Mdot
.26079 .44443 Mdot
.34168 .66875 Mdot
.24473 .38573 Mdot
.50514 .24967 Mdot
.17192 .50185 Mdot
.53967 .34512 Mdot
.60426 .61838 Mdot
.72788 .48541 Mdot
.65616 .3036 Mdot
.43475 .44335 Mdot
.17007 .48796 Mdot
.64554 .37716 Mdot
.62325 .35678 Mdot
.7418 .59481 Mdot
.83548 .49639 Mdot
.35433 .26095 Mdot
.44277 .31994 Mdot
.33687 .45846 Mdot
.6776 .42049 Mdot
.57657 .27076 Mdot
.52133 .35196 Mdot
.48867 .5603 Mdot
.58754 .3836 Mdot
.76558 .72266 Mdot
.7131 .51913 Mdot
.59974 .54039 Mdot
.28734 .53802 Mdot
.29233 .69077 Mdot
.73274 .67315 Mdot
.30493 .63325 Mdot
.17205 .46591 Mdot
.42917 .24295 Mdot
.70721 .74064 Mdot
.33977 .65463 Mdot
.61999 .28422 Mdot
.63057 .21652 Mdot
.48115 .63122 Mdot
.36105 .4079 Mdot
.83736 .56123 Mdot
.30168 .64885 Mdot
.2725 .49767 Mdot
.5042 .78941 Mdot
.55872 .74917 Mdot
.29245 .65673 Mdot
.39265 .79858 Mdot
.75248 .61574 Mdot
.27741 .34658 Mdot
.77686 .66673 Mdot
.59966 .62403 Mdot
.63885 .30029 Mdot
.47326 .77989 Mdot
.16981 .50635 Mdot
.53837 .47945 Mdot
.60684 .82041 Mdot
.48464 .54046 Mdot
.7611 .37738 Mdot
.48354 .33925 Mdot
.38137 .23549 Mdot
.24556 .64831 Mdot
.49213 .79858 Mdot
.27691 .57932 Mdot
.28812 .48374 Mdot
.21429 .59983 Mdot
.69147 .60421 Mdot
.73166 .36228 Mdot
.54686 .26772 Mdot
.23198 .51605 Mdot
.65883 .46431 Mdot
.36815 .72416 Mdot
.55097 .41129 Mdot
.76284 .36216 Mdot
.66535 .71823 Mdot
.35272 .42072 Mdot
.27632 .44067 Mdot
.80276 .60641 Mdot
.69469 .68549 Mdot
.21944 .63653 Mdot
.27841 .44718 Mdot
.31458 .73686 Mdot
.28124 .28746 Mdot
.29682 .61317 Mdot
.52706 .41847 Mdot
.67631 .50413 Mdot
.32986 .53491 Mdot
.7794 .64517 Mdot
.3912 .49405 Mdot
.76385 .39018 Mdot
.43616 .55367 Mdot
.72635 .6551 Mdot
.62311 .45921 Mdot
.41248 .82178 Mdot
.28513 .73211 Mdot
.67492 .29797 Mdot
.48305 .67766 Mdot
.41967 .64386 Mdot
.34972 .61707 Mdot
.61384 .80342 Mdot
.36163 .56859 Mdot
.4119 .31416 Mdot
.35817 .64086 Mdot
.38493 .3177 Mdot
.36409 .8025 Mdot
.70117 .32245 Mdot
.47552 .54686 Mdot
.43913 .28599 Mdot
.35979 .73612 Mdot
.36018 .71974 Mdot
.73045 .51121 Mdot
.34204 .25219 Mdot
.5583 .58764 Mdot
.56575 .5192 Mdot
.55894 .3845 Mdot
.44316 .20949 Mdot
.76562 .67247 Mdot
.40178 .53842 Mdot
.47819 .5369 Mdot
.80106 .52449 Mdot
.74174 .36235 Mdot
.33122 .18207 Mdot
.80207 .68278 Mdot
.48521 .33838 Mdot
.54503 .50443 Mdot
.71541 .32183 Mdot
.66239 .58152 Mdot
.36351 .27838 Mdot
.79839 .617 Mdot
.50536 .66871 Mdot
.76373 .55335 Mdot
.38092 .68742 Mdot
.26133 .67227 Mdot
.78676 .40405 Mdot
.51355 .61031 Mdot
.71568 .77759 Mdot
.50058 .82068 Mdot
.2458 .64001 Mdot
.26353 .22271 Mdot
.22901 .61857 Mdot
.41119 .4771 Mdot
.72307 .61382 Mdot
.74091 .73831 Mdot
.52942 .5236 Mdot
.75215 .57092 Mdot
.2824 .43512 Mdot
.67396 .2923 Mdot
.62923 .32676 Mdot
.26592 .59885 Mdot
.22101 .59195 Mdot
.15529 .44894 Mdot
.60379 .69301 Mdot
.69641 .24454 Mdot
.33241 .28417 Mdot
.78498 .66761 Mdot
.42389 .74505 Mdot
.57069 .16983 Mdot
.5305 .8554 Mdot
.67368 .34875 Mdot
.17782 .48537 Mdot
.7163 .57797 Mdot
.71649 .30103 Mdot
.42108 .20451 Mdot
.40418 .761 Mdot
.41577 .2511 Mdot
.58086 .70008 Mdot
.29121 .59454 Mdot
.66097 .3282 Mdot
.37609 .3446 Mdot
.47929 .54669 Mdot
.82454 .59899 Mdot
.18136 .42455 Mdot
.64364 .26468 Mdot
.77934 .54639 Mdot
.73174 .314 Mdot
.74697 .68071 Mdot
.67297 .72846 Mdot
.56784 .47223 Mdot
.8401 .38187 Mdot
.84416 .5781 Mdot
.31085 .62048 Mdot
.53763 .38787 Mdot
.50607 .87003 Mdot
.59058 .4713 Mdot
.29071 .43564 Mdot
.43811 .81739 Mdot
.61553 .32157 Mdot
.58248 .37718 Mdot
.54202 .39215 Mdot
.51644 .23858 Mdot
.24626 .53994 Mdot
.37521 .35163 Mdot
.78796 .43953 Mdot
.64875 .26439 Mdot
.18332 .42765 Mdot
.79195 .38495 Mdot
.40884 .44386 Mdot
.34967 .52476 Mdot
.75146 .73181 Mdot
.44924 .26739 Mdot
.44106 .3013 Mdot
.25674 .35482 Mdot
.35882 .56494 Mdot
.60887 .65103 Mdot
.50979 .29087 Mdot
.40496 .62107 Mdot
.65175 .3071 Mdot
.79089 .59768 Mdot
.36783 .41565 Mdot
.8726 .38891 Mdot
.41091 .82607 Mdot
.35501 .53412 Mdot
.31757 .4209 Mdot
.6365 .49496 Mdot
.73248 .73308 Mdot
.59478 .68273 Mdot
.80188 .4799 Mdot
.21569 .35126 Mdot
.68498 .27886 Mdot
.44825 .41475 Mdot
.41076 .78613 Mdot
.5584 .84312 Mdot
.18937 .38331 Mdot
.58921 .83245 Mdot
.55632 .42419 Mdot
.54941 .34477 Mdot
.54975 .1327 Mdot
.68616 .74971 Mdot
.50008 .45843 Mdot
.2515 .54916 Mdot
.25486 .5357 Mdot
.47772 .33318 Mdot
.36386 .67761 Mdot
.57922 .25376 Mdot
.62956 .33661 Mdot
.6572 .78931 Mdot
.28899 .53546 Mdot
.51948 .53562 Mdot
.54999 .63921 Mdot
.51144 .52621 Mdot
.41995 .35456 Mdot
.5289 .66242 Mdot
.63105 .34788 Mdot
.58366 .48177 Mdot
.53248 .69397 Mdot
.50889 .26335 Mdot
.38984 .72247 Mdot
.51922 .27373 Mdot
.61253 .39207 Mdot
.27597 .46002 Mdot
.29867 .25993 Mdot
.64636 .37522 Mdot
.64966 .38936 Mdot
.39482 .80742 Mdot
.20073 .66993 Mdot
.51 .56314 Mdot
.37424 .44539 Mdot
.40862 .46129 Mdot
.33183 .26171 Mdot
.267 .35037 Mdot
.56213 .64029 Mdot
.35863 .71599 Mdot
.56867 .40143 Mdot
.43915 .28271 Mdot
.54305 .6335 Mdot
.78524 .71642 Mdot
.5469 .36161 Mdot
.32043 .31259 Mdot
.5968 .80925 Mdot
.77794 .57327 Mdot
.56884 .30974 Mdot
.45599 .33366 Mdot
.42804 .49351 Mdot
.59038 .478 Mdot
.39413 .35903 Mdot
.79386 .55816 Mdot
.74458 .70722 Mdot
.58046 .31152 Mdot
.30991 .31336 Mdot
.47442 .37333 Mdot
.72805 .39632 Mdot
.41525 .5974 Mdot
.68008 .2481 Mdot
.74822 .43919 Mdot
.52777 .84262 Mdot
.62214 .3866 Mdot
.61871 .32204 Mdot
.2332 .37777 Mdot
.81197 .65012 Mdot
.34737 .62509 Mdot
.2971 .3117 Mdot
.39278 .57042 Mdot
.50308 .76732 Mdot
.65643 .36567 Mdot
.52592 .59767 Mdot
.56837 .36646 Mdot
.2485 .52955 Mdot
.64878 .80832 Mdot
.45995 .25445 Mdot
.55915 .6395 Mdot
.57222 .78729 Mdot
.28169 .28976 Mdot
.52957 .51084 Mdot
.21924 .26345 Mdot
.60849 .67105 Mdot
.72175 .77187 Mdot
.77572 .60228 Mdot
.5142 .47684 Mdot
.27663 .66462 Mdot
.43944 .43919 Mdot
.64005 .5658 Mdot
.7379 .723 Mdot
.39602 .38262 Mdot
.28742 .60858 Mdot
.53408 .34496 Mdot
.42822 .50997 Mdot
.40852 .32694 Mdot
.60668 .75629 Mdot
.59552 .60822 Mdot
.3725 .5544 Mdot
.67062 .73531 Mdot
.59307 .47637 Mdot
.15182 .52981 Mdot
.84272 .55701 Mdot
.65715 .76982 Mdot
.64895 .72979 Mdot
.4465 .16471 Mdot
.32882 .4523 Mdot
.39389 .41945 Mdot
.47259 .65847 Mdot
.52696 .24148 Mdot
.29499 .6521 Mdot
.7925 .58866 Mdot
.30655 .73217 Mdot
.54987 .4767 Mdot
.14982 .34902 Mdot
.66547 .34468 Mdot
.40877 .52309 Mdot
.27622 .63872 Mdot
.63358 .79677 Mdot
.78374 .50183 Mdot
.31488 .76172 Mdot
.43473 .75717 Mdot
.41747 .38337 Mdot
.39971 .21508 Mdot
.77787 .35226 Mdot
.59416 .74457 Mdot
.68543 .23262 Mdot
.61868 .76253 Mdot
.58969 .26904 Mdot
.48542 .79499 Mdot
.32532 .54534 Mdot
.31683 .55687 Mdot
.43382 .7325 Mdot
.38974 .69992 Mdot
.34218 .43847 Mdot
.72839 .71616 Mdot
.57121 .19943 Mdot
.80796 .49813 Mdot
.70215 .75463 Mdot
.45749 .69326 Mdot
.26297 .50775 Mdot
.64074 .37849 Mdot
.68885 .46588 Mdot
.66038 .59759 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0Toooool2o`000;Cooooo000Looooo`03o`00
0?oooooooooo09?ooooo0_l0000Jooooo`;o0000V?ooool001cooooo00?o0000ooooooooool0[ooo
ool2o`0009Sooooo000Looooo`03o`000?oooooooooo08Wooooo0_l0002nooooo`007?ooool00ol0
003oooooooooo`29ooooo`;o00005?ooool2o`000:Sooooo000Looooo`03o`000?oooooooooo09;o
oooo0_l0000;ooooo`;o0000Z?ooool001cooooo00?o0000ooooooooool0T_ooool2o`000;Gooooo
000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`1hooooo`;o00006?ooool2
o`0001_ooooo0ol00005ooooo`;o0000T?ooool001cooooo00?o0000ooooooooool0N?ooool2o`00
00[ooooo1Ol00009ooooo`;o00005_ooool2o`0000?ooooo0ol00005ooooo`;o0000T?ooool001co
oooo00?o0000ooooooooool0P_ooool7o`0001?ooooo0_l0000<ooooo`;o0000WOooool001cooooo
00?o0000ooooooooool0P_ooool2o`0000Wooooo0_l0000=ooooo`;o0000Zoooool001cooooo00?o
0000ooooooooool0Moooool2o`000004ooooool0003o0000ooooo`;o00003_ooool2o`000;[ooooo
000Looooo`03o`000?oooooooooo07;ooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo
0_l0000=ooooo`;o00000oooool2o`0002?ooooo0_l0002Aooooo`007?ooool00ol0003ooooooooo
o`1booooo`;o00006?ooool2o`0000?ooooo0_l0000Sooooo`;o00000_ooool2o`0008gooooo000L
ooooo`03o`000?oooooooooo073ooooo0_l00018ooooo`Co00003?ooool2o`0007gooooo000Loooo
o`03o`000?oooooooooo073ooooo0_l0001:ooooo`Co00002_ooool2o`0007gooooo000Looooo`03
o`000?oooooooooo06Sooooo0_l000000ooooooo0000o`000006ooooo`;o0000BOooool2o`0008Wo
oooo000Looooo`03o`000?oooooooooo06Sooooo0_l000000ooooooo0000o`000006ooooo`;o0000
e?ooool001cooooo00?o0000ooooooooool0Joooool2o`000=cooooo00001_ooooook^k^oc8b<_l0
003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`1[ooooo`;o0000
0_ooool2o`000=Sooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1_ooooo`;o000000?oooooo`00
0?l00000Doooool2o`0000Wooooo0_l0001eooooo`0000?ooooooa0@4?ooool00_ooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0L_ooool2o`0004;o
oooo1?l0000=ooooo`Co00001oooool2o`0007Gooooo00000ooooooo0000ooooo`02ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0007kooooo0_l0000fooooo`Go0000
3Oooool3o`0007kooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?o
MgMgofIVI_ooool01Oooool00ol0003oooooooooo`1Yooooo`?o00004_ooool3o`0000Cooooo1_l0
000]ooooo`?o00005Oooool2o`0007Oooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooo
oooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Yooooo`?o00004oooool2
o`0000Cooooo1ol00002ooooo`;o00003?ooool2o`0001[ooooo0_l00005ooooo`;o00003oooool2
o`0007Oooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RH
oa0@4006ooooo`03o`000?oooooooooo05Sooooo0_l0000`ooooo`Ko00002Oooool2o`000004oooo
ool0003o0000o`00023ooooo0_l00028ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Hooooo`;o00002_ooool2
o`0000gooooo0_l00007ooooo`Co00003?ooool4o`0000?ooooo0_l00004ooooo`;o00000_ooool5
o`0001kooooo1?l00025ooooo`007?ooool00ol0003oooooooooo`1Tooooo`;o00003Oooool2o`00
00Oooooo1?l0000?ooooo`;o00000_ooool2o`0000Wooooo1?l000000ooooooo0000o`00000Koooo
o`Co00001Oooool2o`0000Wooooo0_l0001cooooo`007?ooool00ol0003oooooooooo`1Eooooo`;o
0000>?ooool2o`0001;ooooo0_l000001?oooooo0000o`000?l0000=ooooo`;o00004Oooool2o`00
00Wooooo0_l0001cooooo`007?ooool00ol0003oooooooooo`1Booooo`;o000000?oooooo`000?l0
00007?ooool2o`0001;ooooo0_l00003ooooo`;o00006?ooool5o`0000_ooooo0_l0000Iooooo`;o
0000M_ooool001cooooo00?o0000ooooooooool0D_ooool2o`0001[ooooo1?l000000ooooooo0000
o`00000;ooooo`;o00001Oooool2o`0000?ooooo1_l0000Gooooo`;o000000?oooooo`000?l00000
2Oooool2o`0000Gooooo0_l0000Aooooo`Co0000M?ooool001cooooo00?o0000ooooooooool0K?oo
ool6o`0000Gooooo0_l00007ooooo`Co00001?ooool2o`0000Cooooo1Ol0000Gooooo`Co00002Ooo
ool2o`0000Cooooo0ol00007ooooo`;o00002_ooool2o`0007Cooooo000Looooo`03o`000?oooooo
oooo06cooooo0_l00009ooooo`;o00002Oooool2o`0000;ooooo2?l00003ooooo`;o00000_ooool2
o`0001?ooooo2Ol000000ooooooo0000o`000003ooooo`;o00000_ooool3o`000003ooooool0003o
000000Cooooo0ol0000Aooooo`;o0000K?ooool001cooooo00?o0000ooooooooool0G?ooool2o`00
00Oooooo0_l00005ooooo`;o00002Oooool6o`0000Wooooo0_l000000ooooooo0000o`000005o`00
00Gooooo0_l00002ooooo`;o00004Oooool7o`000003ooooool0003o000000?ooooo0_l00005oooo
o`Ko00000_ooool2o`0000kooooo0_l000000ooooooo0000o`00001/ooooo`007?ooool00ol0003o
ooooooooo`1Jooooo`Co00001oooool2o`0000Gooooo0_l00008ooooo`So00000_ooool2o`0000_o
oooo0ol00009ooooo`;o00001_ooool2o`000003ooooool0003o000000Kooooo1ol00005ooooo`;o
00001?ooool8o`000003ooooool0003o000000?o00001oooool2o`0000?ooooo0_l0001_ooooo`00
7?ooool00ol0003oooooooooo`1Jooooo`;o00001_ooool2o`0001;ooooo0_l00004ooooo`;o0000
0_ooool3o`0000Gooooo0_l00003ooooo`;o00001oooool2o`0000Wooooo0_l000001?oooooo0000
o`000?ooool2o`0000?ooooo0_l00003ooooo`Co00000oooool3o`0000?ooooo0_l000000ooooooo
0000o`000004ooooo`Go00001?ooool5o`0007Cooooo000Looooo`03o`000?oooooooooo067ooooo
0ol0000Mooooo`;o00001Oooool6o`0000Sooooo0_l0000=ooooo`Co000000?oooooo`000?l00000
1oooool2o`0000Cooooo0_l00002ooooo`?o00000oooool2o`0000[ooooo1Ol00008ooooo`Co0000
JOooool001cooooo00?o0000ooooooooool0HOooool2o`00013ooooo0_l0000Eooooo`Co00005ooo
ool2o`0000?ooooo0_l0000Aooooo`?o00000oooool2o`0000[ooooo0ol00007ooooo`;o000000?o
ooooo`000?l000000ol0001Xooooo`007?ooool2o`00063ooooo0_l0000:ooooo`;o00000_ooool2
o`000004ooooool0003o0000o`0000_ooooo0_l000000ooooooo0000o`00000=ooooo`;o00003?oo
ool2o`0000?ooooo0_l0000:ooooo`;o00001?ooool2o`0000Gooooo1?l000000ooooooo0000o`00
000:ooooo`;o00002?ooool2o`0000Cooooo0_l0001Xooooo`007?ooool00ol0003oooooooooo`1O
ooooo`;o00002_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000<ooooo`;o000000?ooooo
o`000?l000003Oooool3o`0000Kooooo0_l00003ooooo`;o00000oooool2o`0000[ooooo0_l00003
ooooo`Co00001_ooool2o`0000[ooooo0_l00002ooooo`;o000000?oooooo`000?l00000M?ooool0
01cooooo00?o0000ooooooooool0D_ooool2o`0000oooooo1?l0000>ooooo`;o00006oooool3o`00
00Kooooo0_l00009ooooo`;o00003_ooool4o`0000Cooooo0_l000000ooooooo0000o`000002o`00
00Oooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`00073ooooo000Looooo`03
o`000?oooooooooo05;ooooo0_l00004ooooo`;o00000oooool3o`0000?ooooo1?l00008ooooo`;o
00001?ooool2o`0002oooooo0ol0000>ooooo`?o00001?ooool2o`000003ooooool0003o000000;o
00002Oooool2o`0000Oooooo1?l0001^ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o0000
4_ooool2o`000003ooooool0003o000000?o00001oooool3o`0000;ooooo0_l000000ooooooo0000
o`000007ooooo`;o00004Oooool2o`0000kooooo1?l00003ooooo`;o00000oooool2o`000003oooo
ool0003o000000cooooo0_l00008ooooo`;o00001?ooool2o`0000?ooooo1?l00006ooooo`Co0000
K_ooool001cooooo00?o0000ooooooooool0A?ooool2o`0000Sooooo0_l0000;ooooo`;o00001_oo
ool2o`0000;ooooo1?l000001?oooooo0000o`000?ooool2o`0000Oooooo0_l0000Aooooo`;o0000
00?oooooo`000?l000002oooool4o`0000?ooooo0_l00006ooooo`;o00000_ooool2o`0000Kooooo
0_l00006ooooo`;o00002?ooool2o`0000?ooooo1?l00005ooooo`Co00001oooool2o`0000Oooooo
0_l0001Mooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o00004oooool2o`0000;ooooo1?l0
0002ooooo`Ko00002_ooool2o`0000oooooo0_l0000Hooooo`;o00001?ooool2o`0000Kooooo1?l0
00000ooooooo0000o`000003o`0000Sooooo0_l0000<ooooo`Co000000?oooooo`000?l000001?oo
ool2o`0000Oooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1Uooooo`Co00000oooool3
o`0000;ooooo0_l00005ooooo`;o00000oooool3o`0002Gooooo0_l000000ooooooo0000o`00000>
ooooo`So00000oooool2o`0000kooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00002?oo
ool2o`0006;ooooo000Looooo`03o`000?oooooooooo06Gooooo0_l00005ooooo`;o00002_ooool2
o`0000?ooooo0ol0000Nooooo`;o00001Oooool4o`000004ooooool0003o0000ooooo`?o00002_oo
ool6o`0000?ooooo0_l0000>ooooo`;o00000_ooool2o`000004ooooool0003o0000o`0000Sooooo
0_l0001Rooooo`007?ooool00ol0003oooooooooo`1booooo`;o00006oooool2o`0000Oooooo0_l0
0004ooooo`;o00000oooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool3o`0000cooooo
1?l0000Fooooo`;o00000_ooool3o`0000Sooooo0_l0001Rooooo`007?ooool00ol0003ooooooooo
o`0nooooo`;o00002?ooool2o`0000[ooooo0_l00006ooooo`;o00001?ooool2o`0000?ooooo0_l0
0009ooooo`;o00003?ooool3o`0000Sooooo0_l00002ooooo`;o00001oooool2o`0000Gooooo0_l0
0002ooooo`;o00002?ooool3o`0000gooooo0_l0000Gooooo`;o00000_ooool6o`0000Gooooo0_l0
001Rooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00002?ooool2o`0000[ooooo0_l00006
ooooo`;o00000_ooool4o`0000?ooooo0ol00002ooooo`;o000000?oooooo`000?l000003oooool3
o`0000Sooooo1?l0000=ooooo`;o000000?oooooo`000?l000003?ooool3o`0000gooooo0_l00003
ooooo`;o00000_ooool2o`0000Cooooo0_l00007ooooo`Co000000Coooooo`000?l0003ooooo1Ol0
001Wooooo`007?ooool00ol0003oooooooooo`17ooooo`;o00003oooool2o`0000;ooooo0_l00002
ooooo`;o00001_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000Jooooo`Co00001oooool2
o`000004ooooool0003o0000ooooo`;o00000_ooool3o`0000Oooooo0_l00007ooooo`;o00000_oo
ool2o`0000Wooooo0_l00002ooooo`;o00001?ooool2o`0000Oooooo1?l00005ooooo`Co0000Iooo
ool001cooooo00?o0000ooooooooool0Aoooool2o`0000oooooo0_l00005ooooo`;o0000=Oooool2
o`000003ooooool0003o000000;o00000oooool6o`0000Cooooo0_l00007ooooo`;o00000_ooool2
o`0001cooooo1?l0000:ooooo`;o0000I?ooool001cooooo00?o0000ooooooooool0F?ooool2o`00
0003ooooool0003o000000;ooooo0_l0000Kooooo`;o00006Oooool2o`0000;ooooo0_l00005oooo
o`Go00003?ooool2o`0000?ooooo0_l00006ooooo`;o00002Oooool2o`0000Kooooo1ol00009oooo
o`;o0000I?ooool001cooooo00?o0000ooooooooool0=_ooool2o`0000;ooooo0_l0000Kooooo`;o
00000_ooool2o`000003ooooool0003o000001cooooo0ol0000Dooooo`Ko00000_ooool2o`0000?o
oooo0_l00003ooooo`?o00002oooool2o`0000?ooooo0_l00006ooooo`;o00002Oooool2o`0000;o
oooo0_l00002ooooo`;o000000?oooooo`000?l000000_l0001_ooooo`007?ooool2o`0003Oooooo
0_l00002ooooo`;o00006oooool9o`0001gooooo0_l00008ooooo`;o00000oooool2o`0000Gooooo
1?l00005ooooo`;o00000_ooool2o`0000Cooooo0_l0000:ooooo`?o00002Oooool3o`0000_ooooo
0_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000003?ooool2o`0006;ooooo
000Looooo`03o`000?oooooooooo04oooooo0_l00008ooooo`Ko00001Oooool2o`0001_ooooo0_l0
0004ooooo`;o00000_ooool3o`0000?ooooo0_l000001?oooooo0000o`000?l00003ooooo`Ko0000
4_ooool3o`000003ooooool0003o000000Kooooo0ol0000;ooooo`;o00000oooool2o`000004oooo
ool0003o0000ooooo`;o00003?ooool2o`0000Wooooo0_l0001Gooooo`007?ooool00ol0003ooooo
ooooo`1<ooooo`;o000000?oooooo`000?l000000_l00009ooooo`;o00001_ooool2o`0001_ooooo
0_l00004ooooo`;o00000_ooool2o`0000?ooooo0ol000000ooooooo0000o`000002o`000003oooo
ool0003o000000Go00004?ooool2o`0000Cooooo0_l00009ooooo`;o00003Oooool4o`000003oooo
ool0003o000000Gooooo0_l0000Booooo`;o0000Eoooool001cooooo00?o0000ooooooooool0C?oo
ool2o`0000?ooooo0_l00009ooooo`;o000000?oooooo`000?l000009_ooool4o`0000Gooooo3ol0
0004ooooo`?o00001_ooool2o`0000;ooooo0_l00003ooooo`;o00002_ooool2o`0000;ooooo0_l0
0009ooooo`Co000000Coooooo`000?l0003ooooo1_l00002ooooo`;o00007oooool2o`0004Kooooo
000Looooo`03o`000?oooooooooo04cooooo0_l000001?oooooo0000o`000?l00007ooooo`;o0000
0_ooool6o`000003ooooool0003o000002?ooooo0_l000000ooooooo0000o`000005ooooo`Wo0000
1?ooool2o`000004ooooool0003o0000o`0000Gooooo0ol00002ooooo`;o00000oooool2o`0000;o
oooo0_l0000:ooooo`;o00002Oooool6o`0000;ooooo1_l00002ooooo`;o00002?ooool2o`0001Go
oooo0_l00016ooooo`007?ooool00ol0003oooooooooo`1?ooooo`?o00001_ooool3o`0000;ooooo
0_l00002ooooo`;o000000?oooooo`000?l000007?ooool4o`0000Kooooo0_l00005ooooo`Co0000
0_ooool2o`0000?ooooo1?l000000ooooooo0000o`000006ooooo`;o00000_ooool3o`0000Oooooo
0_l000000ooooooo0000o`00000:ooooo`;o00001_ooool2o`0000;ooooo0ol00005ooooo`;o0000
3?ooool2o`0005gooooo000Looooo`03o`000?oooooooooo05Sooooo0_l00005ooooo`;o00006?oo
ool2o`0000;ooooo0_l00003ooooo`Co00001_ooool2o`0000Gooooo0ol00003ooooo`;o000000?o
ooooo`000?l000000_l00003ooooo`?o00001Oooool2o`0000;ooooo0_l0000;ooooo`;o00002?oo
ool4o`0000Kooooo0_l00003ooooo`;o00001oooool2o`0000;ooooo0_l000000ooooooo0000o`00
0006ooooo`;o0000F_ooool001cooooo00?o0000ooooooooool0Doooool2o`0000[ooooo0_l0000H
ooooo`;o00000_ooool2o`0000Oooooo0_l00004ooooo`;o00000oooool2o`0000?ooooo2_l00003
ooooo`[o00000oooool2o`0001;ooooo1?l0000:ooooo`;o00002Oooool7o`000003ooooool0003o
000000Kooooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00008_ooool4o`00
00_ooooo0_l00002ooooo`?o00000_ooool6o`000003ooooool0003o000000Wo00000_ooool;o`00
00;ooooo0_l0000Booooo`?o00002oooool2o`0000Wooooo0_l000001?oooooo0000o`000?l00002
ooooo`;o00000oooool2o`000004ooooool0003o0000o`0000Cooooo0_l0001Cooooo`007?ooool0
0ol0003oooooooooo`1:ooooo`;o00001_ooool2o`0002?ooooo0_l00008ooooo`;o00001oooool3
o`0000;ooooo4ol000000ooooooo0000o`000009o`0001_ooooo0ol00005ooooo`Go00000oooool2
o`0000oooooo1_l00004ooooo`;o000000?oooooo`000?l00000D?ooool001cooooo00?o0000oooo
ooooool0B_ooool2o`0000Kooooo0_l00007ooooo`;o00007_ooool2o`0000Cooooo0_l00007oooo
o`;o00002?ooool>o`000003ooooool0003o000000Wo00002_ooool2o`0000oooooo0ol00005oooo
o`Go00000oooool2o`00013ooooo0ol00007ooooo`Co0000D?ooool001cooooo00?o0000oooooooo
ool0COooool2o`0000?ooooo0_l00007ooooo`;o00007_ooool2o`0000Wooooo0_l00002ooooo`;o
00001?ooool4o`0000;ooooo2_l000000ooooooo0000o`000005o`0000?ooooo0ol0000:ooooo`;o
000000?oooooo`000?l000006oooool2o`0000Gooooo0_l0000;ooooo`;o000000?oooooo`000?l0
00001?ooool4o`00053ooooo000Looooo`03o`000?oooooooooo033ooooo0ol0000Fooooo`;o0000
0_ooool4o`000003ooooool0003o000002kooooo1_l00002ooooo`?o000000?oooooo`000?l00000
1Ol000000ooooooo0000o`000007o`000003ooooool0003o000000So000000?oooooo`000?l00000
3_ooool2o`0000?ooooo0_l00007ooooo`;o00001Oooool4o`0000Cooooo0_l00004ooooo`?o0000
3_ooool2o`0005Sooooo000Looooo`03o`000?oooooooooo033ooooo0ol0000Fooooo`Co00000_oo
ool5o`0002Gooooo0_l00007ooooo`_o000000Coooooo`000?l0003o00000_oooolKo`0000Cooooo
0_l00004ooooo`;o00001_ooool2o`0000Oooooo0_l00005ooooo`Co00002_ooool2o`0000?ooooo
0_l00002ooooo`;o00000oooool2o`0005_ooooo000Looooo`03o`000?oooooooooo04_ooooo0_l0
0003ooooo`;o00009?ooool2o`000003ooooool0003o000000Sooooo0_l000000ooooooo0000o`00
0004o`0000;ooooo0_l00004oooooago000000?oooooo`000?l000000_ooool4o`0001[ooooo0_l0
0003ooooo`?o00001oooool2o`000003ooooool0003o000000?o000000?oooooo`000?l00000Fooo
ool001cooooo00?o0000ooooooooool0Boooool2o`0000Wooooo0_l00007ooooo`;o00005Oooool2
o`000003ooooool0003o000000Cooooo2?l00003ooooo`;o000000Coooooo`000?l0003ooooo8Ol0
0005ooooo`;o00004Oooool2o`0000Oooooo1?l00003ooooo`?o00001_ooool2o`0000;ooooo1ol0
001Looooo`007?ooool2o`0002kooooo0_l0000Fooooo`;o00002?ooool2o`0000;ooooo0_l00000
0ooooooo0000o`000007ooooo`;o00005oooool3o`0000Cooooo2?l00003ooooo`Go000000?ooooo
o`000?l000001_l000000ooooooo0000o`00000Do`0000Cooooo0_l00007ooooo`;o00000oooool2
o`0000Kooooo0_l00007ooooo`;o00000oooool2o`0000Wooooo0ol00003ooooo`Go00001Oooool2
o`0005Gooooo000Looooo`03o`000?oooooooooo02gooooo0_l0000Cooooo`;o000000?oooooo`00
0?l000001Oooool5o`0000;ooooo0_l0000Qooooo`Co00004?ooool9o`000003ooooool0003o0000
01_o000000Coooooo`000?l0003o00001oooool2o`0000?ooooo0_l0000Dooooo`;o00002_ooool3
o`0000[ooooo1?l00005ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0@_ooool2o`00
0003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000004o`0000gooooo0_l0000Eoooo
o`Co00002oooool3o`0000;ooooo5Ol000000ooooooo0000o`00000?o`000004ooooool0003o0000
o`0001;ooooo0_l0000Kooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`;o000000?o
ooooo`000?l000001?ooool2o`0004kooooo000Looooo`03o`000?oooooooooo047ooooo0_l00006
ooooo`;o000000?oooooo`000?l000000_ooool2o`0000cooooo0ol0000Gooooo`;o00000_ooool2
o`0000Oooooo0ol000000ooooooo0000o`00000Uo`0001Oooooo0_l0000Iooooo`;o00001_ooool2
o`000003ooooool0003o000000Cooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`10oooo
o`?o00002Oooool2o`00013ooooo0_l0000Looooo`;o00001_ooool2o`0000;ooooo6Ol000001?oo
oooo0000o`000?ooool4o`0000;ooooo2?l0000?ooooo`;o00007_ooool2o`0000Kooooo0_l00000
0ooooooo0000o`000003o`0000;ooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`10oooo
o`;o000000?oooooo`000?l000004_ooool2o`0001Kooooo0ol00004ooooo`;o00003?ooool2o`00
0003ooooool0003o000000Ko000000?oooooo`000?l000006Ol000000ooooooo0000o`000005o`00
0003ooooool0003o000000cooooo0_l0000=ooooo`;o00005oooool2o`000003ooooool0003o0000
00Oo00001oooool2o`0004[ooooo000Looooo`03o`000?oooooooooo04?ooooo0_l0000Booooo`;o
00005_ooool3o`0000?ooooo0ol0000=ooooo`Go00000_oooolVo`0000;ooooo0ol0000Aooooo`;o
00001_ooool4o`0001Wooooo0_l00003ooooo`Co00001oooool2o`0004[ooooo000Looooo`03o`00
0?oooooooooo07Gooooo0_l0000>ooooo`Co00000_oooolWo`0000?ooooo0_l0000=ooooo`;o0000
0_ooool2o`0000Kooooo1?l00006ooooo`;o00004Oooool2o`0000Gooooo0_l00003ooooo`;o0000
C_ooool001cooooo00?o0000ooooooooool0QOoooolZo`0000Gooooo0_l00008ooooo`;o000000Co
ooooo`000?l0003ooooo0_l00008ooooo`Co00001?ooool2o`000004ooooool0003o0000o`0001;o
oooo0_l00009ooooo`;o00002?ooool2o`0004Cooooo000Looooo`03o`000?oooooooooo03cooooo
0_l000001?oooooo0000o`000?ooool4o`0000;ooooo1?l0000?ooooo`;o00005_ooool3o`0000;o
oooo0_l00004ooooo`;o00001?ooool2o`000003ooooool0003o000000Co000000?oooooo`000?l0
00008?l00002ooooo`Co00000oooool2o`0000?ooooo0_l000000ooooooo0000o`000009ooooo`Go
00001Oooool2o`000003ooooool0003o000001?ooooo0_l00003ooooo`;o00003_ooool2o`000003
ooooool0003o0000047ooooo000Looooo`03o`000?oooooooooo03cooooo0_l000001?oooooo0000
o`000?ooool4o`0000;ooooo1?l0000?ooooo`;o00005_ooool3o`0000;ooooo0_l00004ooooo`Co
00000_ooool4o`000003ooooool0003o000000;ooooo4Ol000000ooooooo0000o`00000?o`0000;o
oooo0_l00005ooooo`;o00000oooool2o`0000cooooo1?l00006ooooo`;o00005Oooool2o`0000;o
oooo1?l0000Aooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0>_ooool2o`0000Oooooo
0_l00003ooooo`;o0000:?ooool2o`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l00000
0_ooool4o`000004ooooool0003o0000ooooob?o00000_ooool3o`000003ooooool0003o000000Co
oooo1Ol0000]ooooo`;o00000_ooool2o`0001[ooooo0_l0000jooooo`007?ooool00ol0003ooooo
ooooo`0jooooo`;o00003?ooool2o`0000;ooooo1?l0000Rooooo`;o00000oooool2o`0000Cooooo
0_l00005ooooo`;o000000?oooooo`000?l000000_oooolTo`0000;ooooo0ol000000ooooooo0000
o`000004ooooo`Co00001oooool2o`0000Oooooo0_l0000/ooooo`;o00003_ooool2o`0003[ooooo
000Looooo`03o`000?oooooooooo03gooooo0_l0000=ooooo`Co00007oooool2o`000003ooooool0
003o000000oooooo;?l000000ooooooo0000o`000002o`0000;ooooo0_l0000>ooooo`;o00001ooo
ool2o`0002?ooooo0ol00006ooooo`;o00006?ooool3o`0002oooooo00001_ooooook^k^oc8b<_l0
003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003ooooo
ooooo`0mooooo`;o00005?ooool2o`0000Cooooo0_l0000Dooooo`;o00002oooool2o`0000Cooooo
8ol000000ooooooo0000o`000006o`0000;ooooo1?l00002ooooo`;o00002?ooool2o`000003oooo
ool0003o000000[ooooo0ol0000<ooooo`;o00005?ooool3o`00023ooooo0ol0000_ooooo`0000Ko
ooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo02Cooooo0_l0000Gooooo`;o000000?oooooo`000?l000000_ooool2o`000003
ooooool0003o000000Sooooo1?l00004ooooo`;o00003_ooool2o`0000Cooooo0_l0000;ooooo`?o
00000oooool3o`000003ooooool0003o000000Cooooo7Ol000000ooooooo0000o`000004o`0000Ko
oooo0_l00004ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000_ooooo0_l0000:oooo
o`Go00002?ooool2o`0000oooooo0_l0001=ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413o
ooooooooo`09ooooo`Go00001_ooool00ol0003oooooooooo`0Tooooo`;o00005oooool2o`000003
ooooool0003o000000;ooooo0_l000000ooooooo0000o`000008ooooo`Co00005?ooool2o`0000Co
oooo0_l0000;ooooo`?o00001?ooool2o`0000Oooooo9?l00006ooooo`;o000000?oooooo`000?l0
00000ol000000ooooooo0000o`00000<ooooo`;o00003Oooool2o`000004ooooool0003o0000oooo
o`Co000000?oooooo`000?l000001Ol00004ooooo`;o00001_ooool2o`0001Cooooo0_l0000goooo
o`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`00
00Oooooo0ol0000mooooo`;o00003oooool2o`0000Kooooo0_l0000Oooooo`;o00003?ooool2o`00
00Kooooo8Ol00005ooooo`Co00000_ooool3o`00017ooooo0_l0000=ooooo`ko000000Coooooo`00
0?l0003o00001?ooool2o`0000Kooooo0_l0000Dooooo`;o00001?ooool2o`00037ooooo00000ooo
oooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo00001oooool0
0ol0003oooooooooo`0mooooo`;o00002oooool2o`0000;ooooo0_l00006ooooo`;o00006?ooool2
o`0000Gooooo0_l0000<ooooo`?o00000_oooolSo`000003ooooool0003o000000?ooooo1?l00000
0ooooooo0000o`000002ooooo`;o00007?oooolCo`0000;ooooo0_l0000;ooooo`;o00001oooool2
o`0000oooooo0_l0000aooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:oooo
o`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0B_ooool2o`0000Kooooo0_l0000Loooo
o`Co00003oooool2o`000003ooooool0003o000000;ooooo8ol000000ooooooo0000o`000002oooo
o`;o00001?ooool2o`0000;ooooo0_l0000<ooooo`?o00002?ooool2o`0000;ooooo4ol00003oooo
o`Co00002Oooool2o`0000Oooooo0_l00012ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<
ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0>Oooool3o`0000Oooooo0_l00002
ooooo`;o00001oooool4o`0001Gooooo0ol00005ooooo`Go00003Oooool2o`0000;ooooo0_l00002
ooooo`Co000000?oooooo`000?l000006ol000001Ooooooo0000o`000?l0003ooooo00Co00000ooo
ool2o`0000;ooooo0_l0000:ooooo`Co00002?ooool2o`000003ooooool0003o000000So000000?o
ooooo`000?l000002?l00004ooooo`;o00001oooool2o`00013ooooo0_l0000kooooo`0000Kooooo
onk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0
>Oooool3o`0000Oooooo0_l00002ooooo`;o00001oooool2o`0001Kooooo1?l00005ooooo`;o0000
00?oooooo`000?l000002_ooool2o`0000Gooooo0_l00002oooooaoo00001?ooool3o`0000?ooooo
0_l00003ooooo`;o00000_ooool5o`0000Cooooo0_l000000ooooooo0000o`00000=ooooo`[o0000
00?oooooo`000?l000002?l000001?oooooo0000o`000?ooool2o`0000Oooooo0ol0000?ooooo`;o
0000>oooool001cooooo00?o0000ooooooooool0@_ooool4o`000003ooooool0003o000001oooooo
0_l0000:ooooo`;o00002_ooool2o`0000Gooooo1_l000000ooooooo0000o`00000Lo`0000;ooooo
0_l000000ooooooo0000o`000004ooooo`Go00000oooool3o`0000Cooooo0ol0000>oooooaWo0000
00Coooooo`000?l0003o00001oooool2o`0000[ooooo0ol0000<ooooo`;o0000<Oooool001cooooo
00?o0000ooooooooool0?_ooool2o`0000;ooooo1?l000000ooooooo0000o`00000Aooooo`;o0000
00?oooooo`000?l000001?ooool2o`0000Wooooo0ol00006ooooo`;o00000oooool2o`0000Wooooo
6?l00002ooooo`_o000000Goooooo`000?l0003o0000ooooo`02o`0000Cooooo0_l000000ooooooo
0000o`000002o`0000Wooooo0_l0000;ooooo`;o000000?oooooo`000?l000001Ol000000ooooooo
0000o`00000?o`0000;ooooo0_l00008ooooo`;o00002Oooool3o`0000Gooooo0_l00005ooooo`?o
0000<?ooool001cooooo00?o0000ooooooooool0=Oooool4o`0000Gooooo0_l00004ooooo`;o0000
5?ooool2o`000003ooooool0003o000000Cooooo0_l00003ooooo`;o00001?ooool3o`0000Kooooo
0_l00003ooooo`;o00002?oooolPo`000004ooooool0003o0000o`0000?ooooo0_l00002ooooo`;o
00002Oooool2o`0001Cooooo1?l000000ooooooo0000o`00000Do`0000?ooooo0_l0000:ooooo`;o
00002_ooool5o`0000;ooooo0_l00006ooooo`;o0000<?ooool001cooooo00?o0000ooooooooool0
=Oooool5o`0000[ooooo0_l0000Oooooo`;o000000?oooooo`000?l000001_ooool2o`0000_ooooo
1?l00004ooooo`So00000oooool;o`000003ooooool0003o000000go00001_ooool2o`0000gooooo
0_l00002ooooo`;o00003?ooool2o`0000;ooooo5ol00003ooooo`;o00002Oooool2o`0000gooooo
0ol00004ooooo`;o00001?ooool2o`00033ooooo000Looooo`03o`000?oooooooooo03Sooooo0_l0
000:ooooo`;o00003_ooool2o`0000oooooo0_l00007ooooo`Co00002oooool4o`0000Cooooo1_l0
0005ooooo`;o000000?oooooo`000?l000006ol000000ooooooo0000o`000005ooooo`Co00000ooo
ool3o`0000;ooooo0_l0000@oooooaKo00002Oooool2o`0000Cooooo0_l0000Dooooo`;o00001?oo
ool2o`00033ooooo000Looooo`03o`000?oooooooooo05Cooooo0_l0000=ooooo`;o00002Oooool2
o`0000Gooooo0_l00002ooooo`?o00002oooool2o`000003ooooool0003o000000Cooooo5?l00005
ooooo`Oo000000?oooooo`000?l000001Oooool4o`0000?ooooo0ol0000@ooooo`;o00000_oooolF
o`0000Wooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`0fooooo`;o00008?ooool2o`00
0003ooooool0003o000000?o00000oooool2o`0000[ooooo0ol00003ooooo`;o00000_ooool3o`00
00Cooooo1?l00004ooooo`Wo000000Coooooo`000?l0003o00000oooool2o`000003ooooool0003o
000000;ooooo0_l00008ooooo`;o00000oooool4o`0000Oooooo0_l00006ooooo`;o000000?ooooo
o`000?l000002_ooool4o`0000;ooooo5_l0001Mooooo`007?ooool00ol0003oooooooooo`0foooo
o`;o00001_ooool2o`0001Sooooo0_l000000ooooooo0000o`000004o`0000[ooooo0_l00002oooo
o`?o00001oooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l000000ooo
oooo0000o`000005o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`000003ooooool0003o0000
00[ooooo1?l0000;ooooo`;o00000_ooool2o`000003ooooool0003o000000[ooooo0_l00002oooo
oaSo00000_ooool3o`0000_ooooo0_l00003ooooo`;o00000oooool4o`0003oooooo000Looooo`03
o`000?oooooooooo03Gooooo0_l00007ooooo`?o00005Oooool4o`0000Gooooo0ol00009ooooo`;o
00004?ooool2o`0000?ooooo0_l00005ooooo`Co000000?oooooo`000?l000000ol000000ooooooo
0000o`000005ooooo`;o00000_ooool2o`000003ooooool0003o000000?o00004_ooool3o`000003
ooooool0003o000001?ooooo6_l000000ooooooo0000o`000002o`0000_ooooo0_l00003ooooo`;o
00000oooool4o`0000gooooo0_l0000`ooooo`007?ooool00ol0003oooooooooo`0eooooo`;o0000
2?ooool3o`0000oooooo0_l00003ooooo`Co00001_ooool4o`0001;ooooo0_l00009ooooo`;o0000
1Oooool3o`000004ooooool0003o0000ooooo`Wo00002oooool5o`0000Gooooo0_l0000:ooooo`?o
00001_ooool2o`0000[ooooo0_l00002ooooo`?o000000?oooooo`000?l000004Ol00004ooooo`;o
00002oooool2o`0000Oooooo0_l0000Booooo`;o0000<?ooool001cooooo00?o0000ooooooooool0
;oooool2o`0000Sooooo0_l00005ooooo`?o00003_ooool2o`0000;ooooo1?l000000ooooooo0000
o`000006ooooo`;o000000?oooooo`000?l000003oooool2o`0000Wooooo0_l00005ooooo`;o0000
0_ooool2o`0000Gooooo1Ol000000ooooooo0000o`00000;ooooo`?o00001?ooool4o`00017ooooo
0_l0000:ooooo`;o00001_oooolCo`0000;ooooo0_l000000ooooooo0000o`00000:ooooo`;o0000
1oooool2o`0000?ooooo0_l00005ooooo`;o0000>?ooool001cooooo0_l0000Oooooo`;o00003ooo
ool2o`0000Sooooo0_l00006ooooo`;o00004_ooool4o`000004ooooool0003o0000ooooo`;o0000
1_ooool5o`0002Oooooo0_l000000ooooooo0000o`000003ooooo`;o000000Goooooo`000?l0003o
0000ooooo`02o`0000Gooooo0_l00006ooooo`;o00003oooool2o`0000Wooooo0_l0000:oooooa7o
00000oooool2o`000003ooooool0003o000001Sooooo0_l00005ooooo`;o00001_ooool2o`00033o
oooo000Looooo`03o`000?oooooooooo01kooooo0_l0000Vooooo`;o00004oooool4o`0000Cooooo
0_l00002ooooo`Co00000oooool6o`0001gooooo1Ol00003ooooo`;o000000Goooooo`000?l0003o
0000ooooo`02o`000003ooooool0003o000000[ooooo0_l0000?ooooo`;o00002Oooool2o`0000So
oooo4ol00005ooooo`;o00007oooool2o`0000Oooooo0_l0000`ooooo`007?ooool00ol0003ooooo
ooooo`0cooooo`;o00001Oooool2o`0000[ooooo0_l0000Cooooo`;o00001_ooool2o`0000Cooooo
0ol00002ooooo`Ko00004?ooool2o`0000gooooo0_l00004ooooo`Go000000?oooooo`000?l00000
0_ooool2o`0000Cooooo0ol0000:ooooo`;o00005oooool2o`0000Cooooo0_l00003ooooo`_o0000
2?ooool2o`0001Cooooo0_l00009ooooo`;o0000>Oooool001cooooo00?o0000ooooooooool0<ooo
ool2o`0000Gooooo0_l00008ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Kooooo0_l0
000>ooooo`;o000000?oooooo`000?l000001Ol0000Aooooo`;o000000?oooooo`000?l000003?oo
ool2o`0000;ooooo0_l000000ooooooo0000o`000006o`0000;ooooo0_l00004ooooo`?o00002_oo
ool2o`0000[ooooo0_l00003ooooo`;o000000?oooooo`000?l000000oooool2o`0000Kooooo0_l0
0007ooooo`Go000000?oooooo`000?l000006oooool2o`0000_ooooo0_l0000gooooo`007?ooool0
0ol0003oooooooooo`0_ooooo`;o00002?ooool2o`0000Wooooo0_l000000ooooooo0000o`000005
ooooo`;o00001Oooool4o`0000Cooooo0_l00004ooooo`go00003Oooool2o`0000;ooooo0_l0000?
ooooo`;o00000_ooool2o`0000?ooooo1_l00002ooooo`?o00002_ooool2o`00013ooooo0_l00003
ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00003ooooo`;o00001?ooool2
o`000003ooooool0003o000000?o000000Coooooo`000?l0003ooooo0_l0000Tooooo`?o0000=ooo
ool001cooooo00?o0000ooooooooool0;oooool2o`0000?ooooo0_l00003ooooo`;o00004_ooool2
o`0000Kooooo1?l00004ooooo`;o000000Coooooo`000?l0003ooooo1ol000001?oooooo0000o`00
0?ooool2o`000003ooooool0003o000000;o00002?ooool2o`0001Sooooo0_l00002ooooo`Co0000
1Oooool2o`0000Oooooo0_l000000ooooooo0000o`000005ooooo`;o00005Oooool3o`000003oooo
ool0003o000000Sooooo1ol00006ooooo`;o00009?ooool2o`0003Sooooo000Looooo`03o`000?oo
oooooooo01cooooo0_l0000Aooooo`;o00000oooool2o`0000Gooooo0_l0000@ooooo`;o000000?o
ooooo`000?l000001?ooool2o`0000Gooooo0_l000001?oooooo0000o`000?ooool=o`000003oooo
ool0003o000000;o00002?ooool2o`0000;ooooo0ol0000Cooooo`;o00002Oooool2o`0000;ooooo
0_l00005ooooo`;o000000?oooooo`000?l000001Oooool2o`0000?ooooo0_l0000>ooooo`Go0000
2oooool4o`0000?ooooo0_l00002ooooo`;o00006?ooool3o`000003ooooool0003o000000Kooooo
0_l0000jooooo`007?ooool00ol0003oooooooooo`0Looooo`;o00005Oooool2o`000003ooooool0
003o000000?ooooo0_l0000Cooooo`;o00001?ooool9o`0000;ooooo5?l00002ooooo`;o00001_oo
ool5o`0000?ooooo0_l0000Gooooo`Go000000?oooooo`000?l000001?l00009ooooo`;o00001Ooo
ool2o`0000;ooooo0_l00008ooooo`Oo00002?ooool2o`000003ooooool0003o000000;ooooo0_l0
00000ooooooo0000o`000002ooooo`;o00002Oooool2o`0000gooooo0ol000000ooooooo0000o`00
0006ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0;Oooool2o`0000Cooooo0_l00000
0ooooooo0000o`000002o`000003ooooool0003o000000?ooooo0_l0000Fooooo`Ko000000?ooooo
o`000?l000003_l000001?oooooo0000o`000?l00002ooooo`Co00001_ooool5o`0000?ooooo0_l0
000Gooooo`;o000000Coooooo`000?l0003ooooo1_l00003ooooo`;o00000_ooool4o`0000Gooooo
0ol000000ooooooo0000o`000006ooooo`Co00000oooool2o`000003ooooool0003o000000Gooooo
0_l000000ooooooo0000o`000002ooooo`;o00004?ooool2o`0000gooooo0_l00016ooooo`007?oo
ool00ol0003oooooooooo`0]ooooo`;o00002Oooool2o`000003ooooool0003o000000?ooooo0_l0
0007ooooo`;o00003_ooool2o`000003ooooool0003o000001Go00000_ooool3o`0000;ooooo0_l0
0003ooooo`;o000000?oooooo`000?l000001?l0000;ooooo`;o00002?ooool2o`0000Cooooo0_l0
0006ooooo`Ko00000_ooool2o`0000Oooooo0ol00009ooooo`;o00002?ooool2o`0001Wooooo0ol0
000@ooooo`?o0000A_ooool001cooooo00?o0000ooooooooool0?Oooool2o`0000[ooooo0ol00003
ooooo`;o00002?ooool2o`000003ooooool0003o000001Go00000_ooool2o`000003ooooool0003o
000000;o00000_ooool3o`0000;ooooo1Ol000000ooooooo0000o`000008ooooo`Co00001_ooool2
o`0000Gooooo0_l00004ooooo`Go00002oooool4o`0000Oooooo0_l00005ooooo`;o00007oooool3
o`00013ooooo0ol0000:ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0=_ooool2o`00
00Gooooo0_l0000;ooooo`;o00000_ooool3o`0000Wooooo0_l000000ooooooo0000o`00000Co`00
00Cooooo1?l00004ooooo`;o00000oooool2o`0000Cooooo0_l0000:ooooo`?o00003?ooool2o`00
00Cooooo0_l0000>ooooo`;o00002Oooool2o`0000Gooooo0_l000001?oooooo0000o`000?ooool2
o`0000gooooo0ol00005ooooo`;o00000_ooool2o`0001;ooooo0ol00009ooooo`;o00001_ooool3
o`00037ooooo000Looooo`03o`000?oooooooooo01_ooooo0_l0000Gooooo`Co00005?ooool4o`00
00[ooooo7ol00004ooooo`;o00005?ooool2o`000004ooooool0003o0000ooooo`;o00008Oooool2
o`00017ooooo0_l000000ooooooo0000o`000002o`0000_ooooo0ol00005ooooo`;o00000_ooool2
o`000003ooooool0003o000000oooooo0ol00005ooooo`;o00002_ooool3o`00037ooooo000Loooo
o`03o`000?oooooooooo01_ooooo0_l0000Gooooo`;o00004Oooool4o`000003ooooool0003o0000
00[ooooo7_l00007ooooo`;o00003oooool2o`000003ooooool0003o000000;o00000oooool4o`00
00Sooooo0_l00002ooooo`;o00001oooool2o`0000Wooooo0_l00003ooooo`;o00000_ooool3o`00
00[ooooo1?l0000Jooooo`;o00004?ooool2o`0000?ooooo1Ol0000;ooooo`;o0000<?ooool001co
oooo00?o0000ooooooooool0Aoooool4o`0000gooooo7Ol000000ooooooo0000o`000002o`000003
ooooool0003o000000;o00002?ooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool4o`00
00?ooooo1?l00008ooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`000002o`00
00[ooooo1?l00002ooooo`Co00000_ooool2o`0000Gooooo0_l000000ooooooo0000o`000009oooo
o`;o00008_ooool2o`000004ooooool0003o0000ooooo`?o00001Oooool2o`0000?ooooo0_l0000`
ooooo`007?ooool00ol0003oooooooooo`0Jooooo`;o00009?ooool2o`0000kooooo0_l00002oooo
ob7o000000?oooooo`000?l000000_l000000ooooooo0000o`00000:ooooo`;o00000_ooool4o`00
01gooooo1?l00003ooooo`;o00002_ooool2o`0000Cooooo1?l00002ooooo`;o00001_ooool6o`00
00Oooooo0_l0000:ooooo`;o00001_ooool2o`0000Gooooo0_l00002ooooo`;o00000_ooool3o`00
00Gooooo0ol00004ooooo`;o0000=Oooool001cooooo0_l0000Kooooo`;o00004Oooool2o`0000Go
oooo0_l0000:ooooo`;o00001oooool2o`0000Gooooo0_l000000ooooooo0000o`000009o`000003
ooooool0003o000001Ko00001?ooool2o`0000[ooooo0_l00002ooooo`Co00002_ooool5o`0000So
oooo0_l00004ooooo`;o00003_ooool2o`000003ooooool0003o000000Gooooo0ol000000ooooooo
0000o`000003o`0000Cooooo0_l00002ooooo`;o00004oooool2o`0000Kooooo1?l00003ooooo`;o
00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`?o0000>oooool001cooooo
00?o0000ooooooooool0;Oooool2o`0000?ooooo1?l0000Cooooo`;o00001Oooool2o`000005oooo
ool0003o0000o`000?ooool02?l000000ooooooo0000o`00000Fo`0000oooooo0_l00004ooooo`;o
00002_ooool5o`0000Sooooo0_l00005ooooo`;o00002_ooool2o`000004ooooool0003o0000o`00
00Oooooo0ol000000ooooooo0000o`000003o`0000Cooooo0_l00003ooooo`;o00002oooool2o`00
00Cooooo0_l000000ooooooo0000o`000006ooooo`;o00000oooool2o`000003ooooool0003o0000
00Kooooo0_l00003ooooo`;o0000??ooool001cooooo00?o0000ooooooooool0<_ooool3o`0001Go
oooo0_l00004ooooo`Ko000000?oooooo`000?l000007ol0000booooo`;o000000?oooooo`000?l0
00002_ooool2o`0000;ooooo0_l00004ooooo`Go000000?oooooo`000?l000001?ooool2o`0000;o
oooo0_l00003ooooo`?o00002_ooool2o`0000Cooooo0_l000000ooooooo0000o`00000>ooooo`;o
0000BOooool001cooooo00?o0000ooooooooool0<oooool2o`0001Gooooo0_l00004ooooob;o0000
0_ooool3o`00013ooooo0_l0000Oooooo`Co00001?ooool2o`0000;ooooo0_l00003ooooo`;o0000
2?ooool4o`0000;ooooo0_l00004ooooo`;o00002?ooool2o`0001Oooooo0_l0001Eooooo`007?oo
ool00ol0003oooooooooo`0Jooooo`;o0000=?oooolSo`000003ooooool0003o000000?ooooo0_l0
000:ooooo`Co00007oooool3o`0000Gooooo1_l00003ooooo`;o00005?ooool2o`0000;ooooo0_l0
00001?oooooo0000o`000?ooool2o`0000kooooo0_l00007ooooo`Co000000?oooooo`000?l00000
2oooool2o`0000oooooo0_l0000booooo`007?ooool00ol0003oooooooooo`0Jooooo`;o00005ooo
ool2o`0000_ooooo0_l00006ooooo`;o00002?ooool4o`000003ooooool0003o000001_o00001Ooo
ool3o`000003ooooool0003o000000Kooooo1?l0000Looooo`;o00001?ooool3o`0000;ooooo1?l0
0005ooooo`;o00000oooool4o`0000?ooooo0_l00008ooooo`;o00000_ooool5o`0000Oooooo0_l0
0008ooooo`;o00002?ooool3o`000003ooooool0003o000000_ooooo0_l000000ooooooo0000o`00
000<ooooo`;o0000<_ooool001cooooo00?o0000ooooooooool0<oooool2o`0000;ooooo0_l00007
ooooo`;o00001_ooool2o`0000?ooooo0_l00009oooooaco00001_ooool2o`000003ooooool0003o
000000Gooooo1Ol00003ooooo`;o00004_ooool>o`0000;ooooo0_l00002ooooo`;o00001?ooool2
o`0000;ooooo1?l00003ooooo`;o00002Oooool2o`000004ooooool0003o0000o`0000Wooooo0_l0
0003ooooo`;o00003Oooool2o`0000kooooo1_l00010ooooo`007?ooool00ol0003oooooooooo`0g
ooooo`Co00004_ooool2o`0000?ooooo0_l00002oooooago00003_ooool2o`000003ooooool0003o
000000Kooooo0_l0000Booooo`Ko000000?oooooo`000?l000001_l00005ooooo`;o00001?ooool2
o`0001Cooooo0_l0000Booooo`;o00005Oooool2o`0000Gooooo1Ol00012ooooo`007?ooool00ol0
003oooooooooo`0iooooo`;o00003Oooool2o`0000Sooooo0_l00002oooooago00003_ooool4o`00
01;ooooo0_l00007ooooo`Ko00000_ooool2o`0000?ooooo0_l0000Hooooo`;o00000_ooool3o`00
00[ooooo0_l0000Pooooo`?o00000oooool6o`0000kooooo0_l0000cooooo`007?ooool00ol0003o
ooooooooo`18ooooo`;o00000oooool2o`0000?ooooo0_l00002ooooo`?o000000?oooooo`000?l0
00006Ol00005ooooo`;o00001oooool2o`0000;ooooo0_l0000>ooooo`;o00002Oooool4o`0000;o
oooo0_l0000Mooooo`;o00000_ooool7o`0000Kooooo0_l00003ooooo`;o00006oooool2o`0000Co
oooo0_l00002ooooo`;o00002Oooool2o`0000?ooooo0_l0000cooooo`007?ooool00ol0003ooooo
ooooo`0^ooooo`;o00002_ooool2o`00017ooooo0_l000001?oooooo0000o`000?l00005ooooo`Ko
000000?oooooo`000?l000000_l000000ooooooo0000o`000008o`000003ooooool0003o000000Co
00001Oooool2o`0000Sooooo0_l000001?oooooo0000o`000?l00007ooooo`;o00004Oooool2o`00
00;ooooo0_l00004ooooo`;o00007_ooool4o`0000_ooooo0_l0000Vooooo`;o00002?ooool2o`00
0003ooooool0003o000000;o0000<oooool001cooooo00?o0000ooooooooool0;_ooool2o`0000[o
oooo0_l0000;ooooo`Co00001?ooool4o`0000Gooooo5ol000000ooooooo0000o`000006ooooo`;o
00001_ooool2o`0000;ooooo1_l00007ooooo`;o00004Oooool3o`0000Oooooo0_l0000?ooooo`;o
00003Oooool2o`0000;ooooo1_l00006ooooo`;o00006?ooool4o`0000Wooooo0_l00006ooooo`;o
00000oooool2o`0003Gooooo000Looooo`03o`000?oooooooooo03[ooooo0_l00007ooooo`;o0000
0_ooool4o`0000Cooooo0_l00004ooooo`[o000000?oooooo`000?l000002Ol00002ooooo`;o0000
00?oooooo`000?l000001_ooool2o`0000Gooooo0ol00004ooooo`;o00004?ooool2o`0000Cooooo
0_l00005ooooo`;o00001oooool2o`0000oooooo0_l0000<ooooo`;o00000oooool7o`0000Gooooo
0_l0000Hooooo`Co00001oooool4o`0000Kooooo0_l0000jooooo`007?ooool00ol0003ooooooooo
o`13ooooo`;o00000_ooool2o`0000?ooooo0_l00007ooooo`Oo00001?ooool7o`0000;ooooo0_l0
00000ooooooo0000o`000002o`0000oooooo0ol0000Booooo`;o00000_ooool4o`0000;ooooo0_l0
000Oooooo`;o00002Oooool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o00007_oo
ool2o`0000[ooooo0_l000000ooooooo0000o`000011ooooo`007?ooool00ol0003oooooooooo`0J
ooooo`;o0000<?ooool2o`0000Kooooo1?l00004ooooo`?o000000?oooooo`000?l000002Ol00000
0ooooooo0000o`000004o`0000kooooo1_l0000>ooooo`;o00000_ooool4o`00027ooooo1Ol00008
ooooo`;o000000Coooooo`000?l0003ooooo0_l00005ooooo`;o00007?ooool5o`0000Sooooo0_l0
0002ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool06_ooool2o`00033ooooo0_l00006
ooooo`;o00001_ooool6o`000003ooooool0003o000000Go00001Oooool3o`0000kooooo1_l0000:
ooooo`;o00001?ooool5o`0000;ooooo0_l0000Nooooo`;o000000?oooooo`000?l000000_ooool2
o`0000Cooooo0ol00002ooooo`?o00000_ooool2o`0000Wooooo0_l00004ooooo`;o00003_ooool6
o`0000Oooooo0_l00008ooooo`;o0000>oooool001cooooo0_l0001=ooooo`Co00000_ooool2o`00
00[ooooo0ol000001?oooooo0000o`000?ooool5o`000003ooooool0003o000000[ooooo0_l0000G
ooooo`;o00001?ooool9o`0000Cooooo0_l00005ooooo`;o00004Oooool2o`0000?ooooo1?l00000
0ooooooo0000o`000005o`000004ooooool0003o0000o`0000;ooooo0ol00008ooooo`?o00000ooo
ool4o`00013ooooo0_l00007ooooo`;o00002?ooool2o`0003_ooooo000Looooo`03o`000?oooooo
oooo04cooooo1?l00002ooooo`;o00000_ooool2o`0000Oooooo1Ol00002ooooo`Co000000?ooooo
o`000?l000002_ooool2o`00017ooooo0_l00008ooooo`;o000000?oooooo`000?l000001?l00005
ooooo`?o00001Oooool2o`0001Cooooo1?l000000ooooooo0000o`00000;o`000003ooooool0003o
000000Co00001_ooool3o`0000Gooooo0_l0000;ooooo`;o00001oooool2o`0000Gooooo0_l00013
ooooo`007?ooool00ol0003oooooooooo`0looooo`;o00004Oooool2o`0000Gooooo0_l00003oooo
o`;o000000?oooooo`000?l000000_l000001?oooooo0000o`000?ooool4o`0000_ooooo0_l0000C
ooooo`;o00002?ooool2o`000005ooooool0003o0000o`000?ooool01Ol00002ooooo`?o00006ooo
ool3o`000003ooooool0003o000000_o00000_ooool3o`000003ooooool0003o000000Kooooo0_l0
000Cooooo`;o00001oooool2o`0000Gooooo0_l00005ooooo`;o000000?oooooo`000?l00000>Ooo
ool001cooooo00?o0000ooooooooool06_ooool2o`0001kooooo1?l0000Aooooo`;o000000Cooooo
o`000?l0003ooooo0_l00002ooooo`Co000000?oooooo`000?l000001Ol0000=ooooo`;o000000?o
ooooo`000?l000008Oooool2o`000003ooooool0003o000000?o00000oooool2o`0001Kooooo0_l0
0004oooooaGo000000?oooooo`000?l000000_l0000Sooooo`;o00002oooool2o`000004ooooool0
003o0000ooooo`;o0000=_ooool001cooooo00?o0000ooooooooool06_ooool2o`0001kooooo1?l0
0006ooooo`;o00003?ooool2o`000003ooooool0003o000000;ooooo0_l00006ooooo`;o00003?oo
ool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`00000>ooooo`;o00001_oo
ool2o`0000;ooooo0_l00003ooooo`Co000000?oooooo`000?l000000ol0000Gooooo`;o000000Co
ooooo`000?l0003ooooo6ol0000Rooooo`;o00003?ooool2o`0000?ooooo0_l0000fooooo`007?oo
ool00ol0003oooooooooo`14ooooo`;o00001Oooool2o`0000Gooooo0_l0000=ooooo`?o00001_oo
ool2o`0000?ooooo1?l00002ooooo`?o000000?oooooo`000?l000002oooool2o`000003ooooool0
003o000000?ooooo0_l000000ooooooo0000o`000002ooooo`?o00000_ooool4o`000003ooooool0
003o000000?o00006_oooolIo`0000;ooooo1?l0000Uooooo`;o00002?ooool2o`0003_ooooo000L
ooooo`03o`000?oooooooooo03kooooo1?l000000ooooooo0000o`000006ooooo`;o00000oooool2
o`0000Gooooo0_l00009ooooo`;o00000_ooool2o`0000;ooooo0_l00005ooooo`?o000000?ooooo
o`000?l000002oooool2o`0000;ooooo0_l00006ooooo`;o00001_ooool2o`0002Oooooo5ol00005
ooooo`;o00007oooool2o`0000Cooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`0noooo
o`Co000000?oooooo`000?l000002oooool4o`000003ooooool0003o000000;o00002?ooool2o`00
00?ooooo0_l0000:ooooo`;o00002?ooool2o`0000Cooooo1Ol0000;ooooo`?o00009Oooool2o`00
00;ooooo6ol0000=ooooo`;o00002?ooool3o`0000Wooooo0_l0001;ooooo`007?ooool00ol0003o
ooooooooo`0kooooo`;o00002oooool3o`0000Kooooo0ol000000ooooooo0000o`00000:ooooo`;o
00004?ooool2o`0000Oooooo0_l00002ooooo`;o000000?oooooo`000?l000000ol00002ooooo`Oo
000000?oooooo`000?l000000ol0000Qooooo`_o000000?oooooo`000?l000004ol0000=ooooo`;o
00002?ooool3o`0000Kooooo1?l00003ooooo`?o0000A_ooool001cooooo00?o0000ooooooooool0
>oooool4o`0000Wooooo0ol00006ooooo`Go00002_ooool2o`00017ooooo0_l0000;ooooo`;o0000
0_oooolCo`0000oooooo0_l0000?ooooo`go000000?oooooo`000?l000004Ol000000ooooooo0000
o`000008ooooo`Co00002_ooool2o`0000Cooooo1_l00003ooooo`?o00002oooool3o`0003Sooooo
000Looooo`03o`000?oooooooooo03Sooooo0ol00002ooooo`;o00002_ooool2o`0000Gooooo0_l0
00000ooooooo0000o`000003o`0000Gooooo1Ol0000@ooooo`;o00001Oooool2o`0000;ooooo0_l0
0005ooooo`[o00000_ooool2o`0000_ooooo0_l00007ooooo`;o00003oooool3o`000003ooooool0
003o000001[o00000_ooool2o`0000Sooooo1?l0000:ooooo`;o00001?ooool2o`0000?ooooo0_l0
0002ooooo`;o00003?ooool3o`0003Sooooo000Looooo`03o`000?oooooooooo03Sooooo0ol0000A
ooooo`;o00000_ooool2o`0000Cooooo0_l00005ooooo`?o00001_ooool2o`000003ooooool0003o
000000Oooooo0_l00003ooooo`Co00000_ooool2o`0000Oooooo0_l00002ooooo`?o00000oooool2
o`0000Cooooo0_l00005ooooo`;o00006Oooool2o`000003ooooool0003o000000?o000000?ooooo
o`000?l000005Ol000000ooooooo0000o`00000:ooooo`;o00003oooool2o`0000Cooooo0_l00002
ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0C?ooool2o`0001Sooooo0_l000000ooo
oooo0000o`00000;ooooo`?o00002Oooool2o`0000;ooooo1_l0000:ooooo`;o00006_ooool2o`00
00;ooooo0_l000000ooooooo0000o`00000Mo`000003ooooool0003o000000Cooooo0_l00004oooo
o`;o00002Oooool2o`0000Cooooo0_l00008ooooo`;o0000Aoooool001cooooo00?o0000oooooooo
ool0A?ooool2o`0000[ooooo1?l00003ooooo`;o00007Oooool3o`0000Gooooo0_l000000ooooooo
0000o`000009o`0000Kooooo0ol00007ooooo`;o00005?ooool2o`0000;ooooo0_l000001Ooooooo
0000o`000?l0003ooooo01ko00001?ooool2o`0000Kooooo0_l00007ooooo`;o00001?ooool2o`00
00Kooooo0_l00019ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool0
1Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool07_ooool2o`0002Cooooo0_l0
000:ooooo`Co00000oooool2o`0002Cooooo0ol000001?oooooo0000o`000?ooool3o`0000[ooooo
1?l000000ooooooo0000o`000004ooooo`?o00005oooool2o`000003ooooool0003o000000co0000
00?oooooo`000?l000004Ol0000<ooooo`;o00003Oooool2o`0000Kooooo0_l0000<ooooo`;o0000
>oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMgMooo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo01kooooo0_l0000Tooooo`;o00002oooool2o`00
00Sooooo0_l0000Pooooo`?o00000oooool2o`0000Sooooo0_l00002ooooo`;o00000oooool2o`00
00Gooooo0_l00003ooooo`;o00004_ooool2o`0000;ooooo3Ol000000ooooooo0000o`00000>o`00
01Gooooo0_l00004ooooo`;o00000_ooool2o`0000[ooooo0_l00007ooooo`;o0000>oooool00003
ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool0@_ooool2o`0000?ooooo0ol00009ooooo`;o00001_ooool2o`00
01Kooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000Go00002?ooool6o`00
00oooooo0_l000000ooooooo0000o`000002o`0000Cooooo1?l00007ooooo`;o000000?oooooo`00
0?l000006ol0000Eooooo`;o00001?ooool2o`0000;ooooo0_l00004ooooo`;o00001?ooool2o`00
00?ooooo0_l000000ooooooo0000o`00000looooo`0000?oooooo`000?ooool00_ooool00ol0003o
ooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0003_ooooo0_l00005oooo
o`;o00000oooool3o`0000Wooooo0_l00007ooooo`;o00001oooool2o`000003ooooool0003o0000
00Wooooo0_l000001Ooooooo0000o`000?l0003ooooo00Go000000?oooooo`000?l000000_l00000
0ooooooo0000o`000008ooooo`;o00005?ooool4o`0000;ooooo1_l00007ooooo`Co000000?ooooo
o`000?l000006Ol0000Eooooo`;o00000_ooool2o`0000Gooooo0_l00003ooooo`;o00000_ooool4
o`0000?ooooo0_l000000ooooooo0000o`00000looooo`0000?oooooo`000?ooool00_ooool00ol0
003oooooooooo`09ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0k
ooooo`;o00002_ooool4o`00017ooooo0_l00007ooooo`;o000000?oooooo`000?l000001oooool7
o`0000;ooooo0_l000001?oooooo0000o`000?l00005ooooo`;o00007Oooool2o`0000Gooooo0_l0
000<ooooo`?o000000?oooooo`000?l000006?l00006ooooo`;o000000?oooooo`000?l000002ooo
ool2o`0000;ooooo0_l00005ooooo`?o00001_ooool2o`0004Kooooo00000ooooooo410@ooooo`02
ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`18
ooooo`?o00003Oooool7o`000003ooooool0003o000000oooooo1Ol00004ooooo`?o000000?ooooo
o`000?l000003?ooool3o`0000kooooo0ol00004ooooo`;o00004_ooool2o`000003ooooool0003o
000001Oo000000?oooooo`000?l000000_l00004ooooo`;o000000?oooooo`000?l000005oooool2
o`0000Kooooo0_l00016ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@
413oV9RH00Sooooo00?o0000ooooooooool0B?ooool2o`0000kooooo1ol000001?oooooo0000o`00
0?l0000Eooooo`;o000000?oooooo`000?l000003?ooool2o`000004ooooool0003o0000o`0000_o
oooo2ol0000Cooooo`;o000000?oooooo`000?l000006?l000001?oooooo0000o`000?l0000Goooo
o`;o0000Eoooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@
4106ooooo`03o`000?oooooooooo04?ooooo0ol00004ooooo`?o00003Oooool2o`000003ooooool0
003o000000;ooooo0ol0000?ooooo`;o00000oooool2o`0000;ooooo1?l00009ooooo`;o00003_oo
ool@o`00017ooooo0ol00002ooooo`;o000000?oooooo`000?l000004Ol00008ooooo`;o00002?oo
ool2o`0000Gooooo1Ol0000<ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool08oooool2
o`0001kooooo0ol000001?oooooo0000o`000?ooool3o`0000Sooooo0_l00006ooooo`;o00000ooo
ool2o`0000Cooooo0_l00004ooooo`;o00000oooool2o`0000Oooooo1?l0000Ioooooa;o00001ooo
ool2o`0000Kooooo4_l000000ooooooo0000o`000005o`0000Wooooo0_l00008ooooo`;o00001Ooo
ool2o`000003ooooool0003o000000cooooo0ol00017ooooo`007?ooool00ol0003oooooooooo`0S
ooooo`;o00006?ooool2o`0000Kooooo1?l00002ooooo`;o00002?ooool4o`0000?ooooo0ol00002
ooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`;o00000oooool2o`0000Gooooo1?l0
00001?oooooo0000o`000?l0000@ooooo`;o00000oooool5o`000003ooooool0003o000000co0000
0_ooool2o`0000?ooooo0_l00008oooooaKo00001_ooool2o`0001Cooooo0_l00002ooooo`;o0000
3?ooool2o`0000Sooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00001_oo
ool4o`0000kooooo0_l00003ooooo`;o00000oooool2o`0000Sooooo1_l00002ooooo`;o00000_oo
ool2o`000004ooooool0003o0000o`0000;ooooo1?l00004ooooo`;o00002OoooolIo`000005oooo
ool0003o0000o`000?ooool00_l0000=oooooa?o00001?ooool4o`0000oooooo0ol00006ooooo`;o
00000_ooool2o`0000cooooo0_l00004ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0
Coooool2o`0001Cooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o0000
0_ooool2o`0000;ooooo2?l00004ooooo`;o00002oooool>o`000003ooooool0003o000000Wo0000
0_ooool2o`0000?ooooo0_l000000ooooooo0000o`000004o`000003ooooool0003o000000ko0000
1oooool2o`0000Cooooo0_l0000;ooooo`?o00001_ooool2o`0000;ooooo0_l0000<ooooo`;o0000
@oooool001cooooo00?o0000ooooooooool0A?ooool2o`0000Wooooo0_l0000Dooooo`;o00000ooo
ool2o`0000;ooooo0_l00003ooooo`;o00001_ooool4o`000003ooooool0003o000001Gooooo6?l0
00000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000001?l000000ooooooo0000o`00
0004o`000003ooooool0003o000000;o00004_ooool2o`00017ooooo0_l000000ooooooo0000o`00
0009ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0A?ooool3o`0000kooooo0_l00007
ooooo`?o00001Oooool2o`0001Cooooo0ol000000ooooooo0000o`000003ooooo`;o00004?oooolK
o`0000gooooo0ol0000;ooooo`;o00001Oooool2o`0001Wooooo0_l00005ooooo`Co00000oooool2
o`0004[ooooo000Looooo`03o`000?oooooooooo03oooooo0_l00003ooooo`Co00003Oooool2o`00
00Oooooo1?l00004ooooo`;o00003?ooool2o`0000;ooooo0_l00003ooooo`;o00001_ooool2o`00
00oooooo0ol00002ooooo`Wo00000_ooool;o`0001cooooo0_l00005ooooo`;o00004oooool2o`00
00_ooooo1?l0001?ooooo`007?ooool00ol0003oooooooooo`0Wooooo`;o00005_ooool2o`0000?o
oooo1?l00004ooooo`;o00002?ooool6o`0000;ooooo1?l0000Booooo`;o00000_ooool2o`0000?o
oooo0_l0000@ooooo`;o00001Oooool4o`000003ooooool0003o000001So00001?ooool2o`0000Ko
oooo0_l0000Vooooo`;o00006_ooool2o`0004;ooooo000Looooo`03o`000?oooooooooo02Oooooo
0_l0000Fooooo`;o00002?ooool2o`000003ooooool0003o000000Sooooo1_l00002ooooo`;o0000
4Oooool2o`0001cooooo1?l00002ooooo`Go000000?oooooo`000?l000006?l00004ooooo`;o0000
1_ooool2o`0003kooooo0_l00002ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0>ooo
ool2o`0000cooooo0_l0000Cooooo`;o00001?ooool2o`0000[ooooo0ol0000>ooooo`;o00000_oo
ool2o`0000Kooooo0_l000001Ooooooo0000o`000?l0003ooooo01[o00000_ooool2o`0000Cooooo
0_l00009ooooo`?o00005_ooool4o`0001[ooooo0ol00006ooooo`Co0000A?ooool001cooooo00?o
0000ooooooooool0>oooool3o`0000_ooooo0_l000000ooooooo0000o`00000@ooooo`;o00001?oo
ool2o`0000Gooooo0_l00003ooooo`;o00003oooool2o`0000;ooooo0_l00006ooooo`;o00000_oo
ool2o`000003ooooool0003o000001So00000_ooool2o`0000Cooooo0_l0000:ooooo`;o00001?oo
ool2o`00013ooooo1?l0000Jooooo`?o00002?ooool2o`0004Cooooo000Looooo`;o0000?Oooool2
o`0000;ooooo0_l0000:ooooo`;o00001?ooool2o`0000Sooooo1?l00004ooooo`Go00000_ooool2
o`0000_ooooo0_l00003ooooo`Ko00003Oooool2o`0000Cooooo2Ol000000ooooooo0000o`00000<
o`0001Cooooo0_l00004ooooo`;o00005oooool2o`000003ooooool0003o000000Gooooo0_l0000G
ooooo`;o00000oooool2o`0003kooooo000Looooo`03o`000?oooooooooo043ooooo0_l0000@oooo
o`;o00002?ooool2o`0000Gooooo1_l00002ooooo`;o000000?oooooo`000?l000002?ooool2o`00
00?ooooo1_l0000=ooooo`;o000000Coooooo`000?l0003ooooo6?l0000Dooooo`;o00003oooool3
o`0000Gooooo0_l00004ooooo`;o000000?oooooo`000?l000000_ooool5o`0000Oooooo0_l0000>
ooooo`?o00000_ooool2o`0003kooooo000Looooo`03o`000?oooooooooo05Cooooo0_l00005oooo
o`;o00001_ooool:o`000003ooooool0003o000000Sooooo0_l0000Iooooo`;o000000?oooooo`00
0?l000005_l000000ooooooo0000o`000007ooooo`;o00006?ooool4o`0000;ooooo0_l000000ooo
oooo0000o`00000;ooooo`Go00001Oooool4o`0000kooooo0ol00012ooooo`007?ooool00ol0003o
ooooooooo`0/ooooo`;o00006oooool3o`0000?ooooo0_l00003ooooo`;o00001Oooool3o`0000Ko
oooo1?l000000ooooooo0000o`00000Vooooo`;o000000?oooooo`000?l000006?l000000ooooooo
0000o`000007ooooo`;o00006?ooool2o`0000Cooooo0_l00006ooooo`;o00001oooool4o`0000Go
oooo0_l00007ooooo`;o00001oooool2o`0004?ooooo000Looooo`03o`000?oooooooooo02cooooo
0_l0000Eooooo`;o00001?ooool3o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o0000
1?ooool2o`00013ooooo0_l000000ooooooo0000o`00000;ooooo`;o00000oooool2o`0000cooooo
0_l000000ooooooo0000o`00000Io`0001cooooo0_l0000Cooooo`Go00001?ooool2o`00013ooooo
0_l0001<ooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00003Oooool2o`0000;ooooo0_l0
000Booooo`;o00000_ooool2o`000003ooooool0003o000000Gooooo0_l00004ooooo`?o00000_oo
ool2o`00017ooooo6Ol000000ooooooo0000o`00000Dooooo`;o00000oooool2o`0001Cooooo1?l0
000<ooooo`;o00001_ooool4o`0004cooooo000Looooo`03o`000?oooooooooo03kooooo0_l0000<
ooooo`?o00001oooool4o`00013ooooo0ol00002ooooo`;o00001oooool2o`0000Cooooo0ol0000F
oooooaCo00001Oooool2o`00013ooooo0_l00002ooooo`?o00005?ooool3o`0000Kooooo0_l00009
ooooo`;o00001_ooool4o`0000Kooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0^oooo
o`;o00003_ooool2o`0000cooooo0ol00002ooooo`;o00001?ooool5o`0000Oooooo0_l00005oooo
o`?o00000_ooool2o`0000kooooo0_l0000Eooooo`;o000000?oooooo`000?l000003ol0000Hoooo
o`;o00000oooool2o`0001Cooooo0ol00006ooooo`;o00000_ooool2o`0000Wooooo0_l00009oooo
o`;o000000?oooooo`000?l00000A?ooool001cooooo00?o0000ooooooooool0;_ooool2o`00027o
oooo0_l000000ooooooo0000o`000004ooooo`;o00001?ooool2o`000003ooooool0003o000000Go
oooo0_l0000Zooooo`;o00000oooool?o`0003Oooooo0_l00007ooooo`;o00002Oooool2o`0000Co
oooo0_l00003ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0<?ooool2o`0001gooooo
0_l00003ooooo`;o00001Oooool2o`0000?ooooo0_l00009ooooo`;o00001Oooool2o`0000Sooooo
0_l0000Aooooo`;o00002?ooool?o`00013ooooo0_l0000Qooooo`;o00001?ooool2o`0001Sooooo
0_l0001<ooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00005?ooool2o`0000Oooooo0_l0
0003ooooo`;o00001?ooool5o`0000Sooooo0_l00002ooooo`?o00001?ooool2o`0000Oooooo0ol0
000Aooooo`;o00002?ooool2o`0000;ooooo2Ol00006ooooo`Co00002?ooool2o`0000?ooooo0_l0
00000ooooooo0000o`00000Iooooo`;o00001_ooool2o`0000Kooooo0_l00002ooooo`;o00004?oo
ool2o`0004Kooooo000Looooo`03o`000?oooooooooo04Kooooo0_l0000Booooo`;o000000?ooooo
o`000?l000000_ooool2o`0000Cooooo0_l00003ooooo`;o00000_ooool4o`0000?ooooo0_l00002
ooooo`Go00005oooool2o`0000;ooooo2_l00007ooooo`Co000000?oooooo`000?l000002Oooool3
o`000003ooooool0003o000001cooooo0_l00003ooooo`;o00001_ooool2o`0000;ooooo0_l0000@
ooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0<_ooool2o`0002Oooooo0_l00004oooo
o`;o00002Oooool2o`000003ooooool0003o000000Co000000?oooooo`000?l000000_l00002oooo
o`Go00005_ooool2o`0000;ooooo2ol0000;ooooo`;o00002Oooool2o`0001_ooooo0_l00003oooo
o`;o00001oooool2o`0000;ooooo0_l0000<ooooo`;o00002_ooool2o`0004;ooooo000Looooo`03
o`000?oooooooooo03;ooooo0_l0000Wooooo`;o00000oooool2o`0000Wooooo3ol00005ooooo`;o
00006_ooool7o`0000;ooooo0_l00002ooooo`;o0000;oooool2o`0000Oooooo1?l000000ooooooo
0000o`00000@ooooo`;o00002_ooool2o`0004;ooooo000Looooo`03o`000?oooooooooo05_ooooo
0_l00003ooooo`;o00002?ooool=o`0001[ooooo0_l0000<ooooo`?o00001_ooool4o`0001Cooooo
1?l0000Eooooo`Co00001Oooool4o`0006?ooooo000Looooo`03o`000?oooooooooo05Oooooo0_l0
0005ooooo`;o00000_ooool2o`0000Kooooo3_l00006ooooo`;o00004Oooool2o`0000Oooooo0_l0
00000ooooooo0000o`000003o`0000Oooooo0ol0000Dooooo`Co00004oooool2o`0000;ooooo0_l0
0002ooooo`;o00004_ooool2o`0000Gooooo0ol00006ooooo`;o0000A?ooool001cooooo0_l0001F
ooooo`Oo00000_ooool2o`0000;ooooo0_l00006ooooo`ko00000oooool2o`000003ooooool0003o
000001Gooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Gooooo`;o00007?oo
ool2o`0000Kooooo0_l0000;ooooo`;o00001Oooool2o`0000Gooooo0ol00006ooooo`;o0000A?oo
ool001cooooo00?o0000ooooooooool0EOooool2o`0000;ooooo0ol000000ooooooo0000o`000006
ooooo`;o00000_ooool>o`0000Cooooo0_l0000Hooooo`;o00001_ooool2o`0001[ooooo0_l0000P
ooooo`;o00000_ooool2o`000003ooooool0003o000000Sooooo0_l0001Kooooo`007?ooool00ol0
003oooooooooo`1Jooooo`;o000000?oooooo`000?l000001?ooool4o`0000;ooooo3_l0000;oooo
o`;o00004_ooool2o`0000Gooooo0ol0000>ooooo`;o0000:oooool2o`0000;ooooo0_l000000ooo
oooo0000o`00000:ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0HOooool4o`0000;o
oooo4?l00007ooooo`;o00000_ooool2o`000003ooooool0003o000000oooooo0_l00006ooooo`;o
00003_ooool2o`0002oooooo0_l0000;ooooo`Co0000FOooool001cooooo00?o0000ooooooooool0
A_ooool2o`0001Wooooo0_l00004oooooa3o00001oooool2o`0000Gooooo0_l0000Gooooo`?o0000
?_ooool2o`0000_ooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`16ooooo`;o00008?oo
ool?o`0000;ooooo0_l0000;ooooo`;o00004?ooool2o`000005ooooool0003o0000o`000?ooool0
0_l00003ooooo`;o00002Oooool3o`0000Wooooo0_l0000/ooooo`;o000000?oooooo`000?l00000
2?ooool2o`0000?ooooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`1Yooooo`ko00000_oo
ool5o`0000Sooooo0_l0000;ooooo`;o00000oooool2o`000004ooooool0003o0000o`0000Cooooo
1?l00009ooooo`?o00002Oooool2o`0001Oooooo0_l0000Cooooo`;o00002oooool4o`000003oooo
ool0003o000004cooooo000Looooo`03o`000?oooooooooo03Wooooo0_l0000Looooo`;o00004Ooo
ool<o`000003ooooool0003o000000Go00005Oooool2o`0000Cooooo0_l00007ooooo`?o00006?oo
ool2o`00013ooooo0_l00003ooooo`;o00004?ooool2o`0000Cooooo0_l00007ooooo`;o000000?o
ooooo`000?l00000Coooool001cooooo00?o0000ooooooooool0>Oooool2o`0001Wooooo0_l00000
0ooooooo0000o`00000Aooooo`?o000000?oooooo`000?l000001_l000001Ooooooo0000o`000?l0
003ooooo00;o00007?ooool2o`0000Gooooo0_l0000Kooooo`;o00003oooool3o`0000Kooooo0_l0
0002ooooo`;o00002Oooool2o`0000?ooooo0ol00002ooooo`;o00000oooool2o`0005;ooooo000L
ooooo`03o`000?oooooooooo05Cooooo0_l0000Gooooo`;o00001Oooool2o`0000Sooooo0_l00005
ooooo`;o00006Oooool2o`0001Gooooo0_l0000Eooooo`Go00001?ooool2o`0000;ooooo0_l0000>
ooooo`;o00000oooool2o`0005Oooooo000Looooo`03o`000?oooooooooo05Wooooo0_l00005oooo
o`?o00002_ooool2o`0000;ooooo0_l0000;ooooo`;o00001Oooool2o`0000;ooooo0_l0000Goooo
o`;o00004oooool2o`0001Kooooo1?l00004ooooo`Co00004oooool4o`0005Oooooo000Looooo`03
o`000?oooooooooo05Wooooo0_l00005ooooo`?o00001Oooool2o`0000Oooooo0_l0000Fooooo`;o
00005_ooool3o`000003ooooool0003o000002oooooo0_l000000ooooooo0000o`00000?ooooo`;o
00000_ooool4o`0005Oooooo000Looooo`03o`000?oooooooooo06;ooooo0_l00004ooooo`;o0000
1?ooool2o`000003ooooool0003o000002kooooo0ol000001?oooooo0000o`000?l0000Oooooo`;o
00000_ooool2o`0000Wooooo0_l0000Booooo`;o000000?oooooo`000?l00000F_ooool001cooooo
00?o0000ooooooooool0H_ooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o0000
00?oooooo`000?l000002Oooool2o`0000_ooooo0_l0000Gooooo`;o00000_ooool2o`0001oooooo
0_l00002ooooo`;o00002oooool2o`0000Sooooo0_l00009ooooo`;o000000?oooooo`000?l00000
Eoooool001cooooo00?o0000ooooooooool0GOooool2o`0000Cooooo1_l000000ooooooo0000o`00
0005ooooo`;o00002Oooool2o`0000Sooooo0_l000000ooooooo0000o`00000Dooooo`;o00003Ooo
ool2o`0000gooooo0_l00008ooooo`?o00003_ooool2o`0000Sooooo0_l00003ooooo`;o00001ooo
ool2o`0005Oooooo000Looooo`03o`000?oooooooooo05gooooo0_l00004ooooo`Go00002Oooool2
o`0001?ooooo0_l0000Gooooo`;o00002oooool4o`0000gooooo0_l00004ooooo`;o00000_ooool3
o`0000?ooooo0_l00008ooooo`;o00001oooool2o`0000Gooooo0_l0001Pooooo`007?ooool2o`00
08Kooooo1Ol0000Rooooo`;o00001?ooool2o`0000cooooo0_l000000ooooooo0000o`000003oooo
o`;o00000oooool2o`0000Sooooo0ol000000ooooooo0000o`000002ooooo`?o0000Ioooool001co
oooo00?o0000ooooooooool0J?ooool2o`0000[ooooo0_l0000?ooooo`Go00008oooool2o`0000?o
oooo0_l00002ooooo`;o00002?ooool2o`00017ooooo0_l000000ooooooo0000o`000002o`000003
ooooool0003o000000;ooooo0ol0000;ooooo`;o0000F_ooool001cooooo00?o0000ooooooooool0
J?ooool2o`0000[ooooo0_l0000:ooooo`Co00001Oooool2o`0001kooooo0_l00002ooooo`;o0000
1oooool4o`0000Oooooo0_l0000@ooooo`;o000000?oooooo`000?l000002?ooool2o`0000_ooooo
0_l0001Jooooo`007?ooool00ol0003oooooooooo`1Zooooo`;o00005?ooool4o`0000Gooooo0_l0
000Aooooo`;o00002oooool2o`0000gooooo0_l00007ooooo`Co00005_ooool4o`000003ooooool0
003o000006Oooooo000Looooo`03o`000?oooooooooo06?ooooo0_l00005ooooo`;o00004Oooool2
o`000003ooooool0003o000000;o00006?ooool3o`0000Cooooo0_l0000Fooooo`;o00001_ooool4
o`000003ooooool0003o000000?ooooo0_l00007ooooo`;o00000oooool4o`0006[ooooo000Loooo
o`03o`000?oooooooooo06?ooooo0ol00006ooooo`;o00003oooool2o`000003ooooool0003o0000
00;o00000oooool2o`0001Cooooo0_l00004ooooo`;o00002_ooool2o`0000[ooooo0_l00008oooo
o`;o000000?oooooo`000?l000000oooool4o`0000Gooooo0ol00005ooooo`;o00001_ooool2o`00
067ooooo000Looooo`03o`000?oooooooooo06Cooooo1?l00004ooooo`;o00006Oooool4o`0001Go
oooo0_l0000;ooooo`Co00005?ooool3o`0000Oooooo0_l000001?oooooo0000o`000?l00002oooo
o`;o00000oooool4o`0000Kooooo0_l0001Qooooo`007?ooool00ol0003oooooooooo`1Vooooo`;o
00008Oooool2o`0000?ooooo0_l0000@ooooo`;o00002oooool2o`000003ooooool0003o000001?o
oooo0ol0000:ooooo`?o00000_ooool4o`000003ooooool0003o000000;o00001oooool2o`00063o
oooo000Looooo`03o`000?oooooooooo07gooooo0_l00004ooooo`;o00002Oooool2o`00023ooooo
1?l000001?oooooo0000o`000?ooool2o`0000Cooooo0_l00002ooooo`;o00003_ooool2o`0000?o
oooo1?l00003ooooo`;o00001oooool2o`00063ooooo000Looooo`03o`000?oooooooooo06cooooo
0_l00004ooooo`;o00002Oooool2o`0000Cooooo0_l0000]ooooo`;o000000Coooooo`000?l0003o
oooo0_l000001?oooooo0000o`000?ooool3o`000003ooooool0003o000000?ooooo1?l0000Aoooo
o`;o00001oooool2o`0006;ooooo000Looooo`03o`000?oooooooooo06cooooo0_l00004ooooo`;o
000000?oooooo`000?l000002_ooool2o`00013ooooo0_l000000ooooooo0000o`00000=ooooo`;o
00003Oooool3o`0000;ooooo2_l000001?oooooo0000o`000?ooool5o`00013ooooo0_l00007oooo
o`;o0000H_ooool001cooooo00?o0000ooooooooool0Koooool2o`000004ooooool0003o0000oooo
o`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`Co00003oooool3o`000003ooooool0003o
000000gooooo0_l0000=ooooo`?o00000_ooool2o`0000;ooooo1_l000000ooooooo0000o`000002
ooooo`Co00005?ooool2o`0006Oooooo000Looooo`03o`000?oooooooooo06oooooo0_l00007oooo
o`Ko000000?oooooo`000?l000000ol00009ooooo`;o00000oooool2o`0001_ooooo0_l00004oooo
o`?o00003_ooool2o`0000;ooooo0_l0000Dooooo`;o0000Ioooool001cooooo00?o0000oooooooo
ool0L_ooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`000004ooooool0003o0000oooo
o`;o00002Oooool2o`0000Gooooo1?l00008ooooo`;o00001_ooool2o`000003ooooool0003o0000
00;ooooo0_l00004ooooo`?o00001_ooool2o`0000Kooooo0_l00002ooooo`;o000000?oooooo`00
0?l000000oooool2o`0000Sooooo0_l0001[ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5
ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0Jooo
ool3o`0000Cooooo0ol00002ooooo`;o00001Oooool2o`0001Cooooo1Ol00007ooooo`;o00001_oo
ool2o`000003ooooool0003o000000Wooooo0_l00006ooooo`;o00000oooool2o`0000Sooooo1ol0
0008ooooo`;o0000Joooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo
00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo06_ooooo0ol00005ooooo`;o
00000_ooool2o`0000Gooooo0_l0000Gooooo`;o000000?oooooo`000?l000006_ooool2o`0000_o
oooo0_l00005ooooo`;o00000_ooool4o`0007Oooooo00000ooooooo410@ooooo`02ooooo`03oa0@
4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo06co
oooo0_l00009ooooo`;o00000oooool2o`0001_ooooo1Ol0000?ooooo`;o00002_ooool2o`0000Co
oooo0_l00009ooooo`;o0000OOooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
2Oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0001/ooooo`;o00001Oooool2o`0000Oo
oooo0_l0000Kooooo`;o000000?oooooo`000?l000003oooool2o`0000Cooooo0ol00003ooooo`?o
00000_ooool3o`000003ooooool0003o000000;o00001Oooool2o`0007cooooo00000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03
o`000?oooooooooo07?ooooo0_l00009ooooo`;o00007?ooool2o`0000?ooooo0_l0000@ooooo`?o
00001?ooool2o`0000;ooooo0_l00002ooooo`Co00001Oooool2o`0007cooooo00000ooooooo410@
ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03
o`000?oooooooooo07gooooo0ol0000Looooo`;o00000oooool2o`0000?ooooo0_l0000Fooooo`;o
00003oooool2o`0007Sooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj
^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo07Wooooo0_l00002ooooo`;o00008_ooool2
o`0000?ooooo0_l0000>ooooo`;o00001_ooool2o`0000oooooo0_l0001hooooo`0000Koooooonk^
k_lb<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003ooooo
ooooo`1iooooo`;o00000_ooool2o`0000?ooooo0ol0000Kooooo`?o00003_ooool2o`0000?ooooo
0_l00008ooooo`;o0000Qoooool001cooooo00?o0000ooooooooool0Ooooool6o`0000Kooooo0ol0
000Booooo`;o00003Oooool4o`0000[ooooo0_l000000ooooooo0000o`000027ooooo`007?ooool0
0ol0003oooooooooo`1oooooo`Ko00000_ooool2o`0000;ooooo0ol0000Aooooo`;o00003Oooool4
o`000003ooooool0003o000000Sooooo0_l00002ooooo`;o0000Q_ooool001cooooo00?o0000oooo
ooooool0O?ooool2o`0000?ooooo0ol00003ooooo`Co00002Oooool2o`0000Gooooo0_l00002oooo
o`;o000000?oooooo`000?l000002_ooool7o`0000Sooooo0_l00002ooooo`;o0000Q_ooool001co
oooo00?o0000ooooooooool0O?ooool2o`0000Cooooo0_l00005ooooo`;o000000?oooooo`000?l0
00001_ooool2o`0000Gooooo0_l00005ooooo`;o00003_ooool3o`0009Cooooo000Looooo`03o`00
0?oooooooooo08;ooooo0_l00002ooooo`;o00001?ooool2o`0000;ooooo0ol00003ooooo`;o0000
6?ooool2o`00017ooooo0_l00024ooooo`007?ooool00ol0003oooooooooo`1eooooo`;o00003ooo
ool2o`0000Sooooo1?l00002ooooo`;o00002_ooool2o`0000Gooooo0_l00002ooooo`;o000000?o
ooooo`000?l000002Oooool3o`0000?ooooo1?l00024ooooo`007?ooool00ol0003oooooooooo`1e
ooooo`;o00003oooool2o`000003ooooool0003o000000Kooooo0ol0000>ooooo`;o00001Oooool2
o`0000;ooooo0_l00002ooooo`;o00002?ooool3o`0000;ooooo1Ol00024ooooo`007?ooool00ol0
003oooooooooo`1mooooo`;o00002_ooool3o`0001Kooooo1?l00002ooooo`;o00001oooool2o`00
00[ooooo0_l000000ooooooo0000o`000003o`0008Cooooo000Looooo`03o`000?oooooooooo07go
oooo0ol00009ooooo`Co00001?ooool2o`0000Wooooo0_l00003ooooo`Go00000_ooool2o`0000So
oooo0_l00003ooooo`;o00001?ooool2o`0008[ooooo000Looooo`03o`000?oooooooooo07kooooo
0_l00009ooooo`Co00001?ooool2o`0000Kooooo1Ol00003ooooo`;o00001Oooool2o`0000Sooooo
0_l00003ooooo`;o0000T?ooool001cooooo00?o0000ooooooooool0ROooool2o`0000kooooo1Ol0
000:ooooo`;o00002oooool2o`0009;ooooo000Looooo`;o0000Poooool2o`0000Gooooo0_l0000A
ooooo`;o00002?ooool2o`0000_ooooo1?l0002Booooo`007?ooool00ol0003oooooooooo`22oooo
o`;o00008_ooool2o`000004ooooool0003o0000ooooo`;o00001Oooool2o`0009Cooooo000Loooo
o`03o`000?oooooooooo09Sooooo0_l0000>ooooo`?o000000?oooooo`000?l00000Voooool001co
oooo00?o0000ooooooooool0V?ooool4o`0000cooooo0_l0002Oooooo`007?ooool00ol0003ooooo
ooooo`2Jooooo`Co00003?ooool2o`0009gooooo000Looooo`03o`000?oooooooooo09cooooo0ol0
000;ooooo`;o0000WOooool001cooooo00?o0000ooooooooool0WOooool2o`0000;ooooo1?l0002T
ooooo`007?ooool00ol0003oooooooooo`2Qooooo`Co0000Y?ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`004_ooool4o`000003oa0@4?oooooo
oooo00?ooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool3o`000?oo
ooooB_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003ooooooooo
o`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000oooo
ooooool0oooooomBooooo`004_ooool00omEEEGoIVIVo`00003ooooooeCooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo002Uooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@
ooooooooool05Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00Gooooo0_l000002Ol@413ooooooooo
ooooooooc<c<ob4Q8Ol0003o8B4Qolc<c02@ooooo`00Y_ooool01Ol0003ooooooooooooooooo0000
00Wooooo1_l00009ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`02
ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40T?ooool00:Kooooo00Go0000ooooooooooooooooo`00
000Hooooo`05o`000?ooooooooooooooool000000oooool5o`0000?ooooo00Go0000oooooooooooo
ooooo`00002@ooooo`00Y_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l00009ooooo`05
o`000?nHV9SooooooiRHV?lQ8B400oooool01?m4A4CogMgMooooool00004ooooo`05oc8b<_nHV9So
oooooiRHV?lb<S80T?ooool00:Kooooo00Go0000ohN7QoooooooZJVYo`00000Hooooo`05o`000?mE
EEGo0000oa0@4?o<c<`00oooool01?oMgMgoEEEEooooool00004ooooo`05olc<c?l0003o0000o`00
0?o<c<`0T?ooool00:Gooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Fooooo`03
oeEEEOn7QhOooooo00Kooooo00?oMgMgolc<c?l000001?ooool01Ol@413o^[Zjoooooonj^[[o410@
093ooooo0033ooooo`03omgMgOl@413oV9RH00Kooooo00?ok^k^odA4A?l000001?ooool01Ol0003o
^[Zjoooooonj^[[o0000093ooooo0034ooooo`04olc<c?m4A4Co0000oa0@40Gooooo00?oMgMgo`00
0?ooool00oooool01OnYZJWo410@o`000?l@413oZJVY093ooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(654) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.36073 .48327 Mdot
.30964 .45488 Mdot
.65274 .60752 Mdot
.53951 .39203 Mdot
.66238 .51183 Mdot
.62286 .60618 Mdot
.483 .63084 Mdot
.5106 .623 Mdot
.62104 .59597 Mdot
.25268 .3519 Mdot
.50509 .6552 Mdot
.5425 .29766 Mdot
.47539 .64325 Mdot
.48916 .37804 Mdot
.35501 .7126 Mdot
.56022 .42602 Mdot
.29889 .45234 Mdot
.69724 .48381 Mdot
.56732 .41862 Mdot
.64279 .62676 Mdot
.41428 .473 Mdot
.49681 .37703 Mdot
.31264 .45021 Mdot
.49182 .37717 Mdot
.5405 .35445 Mdot
.33408 .46531 Mdot
.35676 .49554 Mdot
.52654 .36488 Mdot
.5006 .34227 Mdot
.48594 .66469 Mdot
.73151 .51814 Mdot
.3143 .78128 Mdot
.54125 .42912 Mdot
.43575 .2908 Mdot
.49149 .60657 Mdot
.73664 .68448 Mdot
.59796 .59465 Mdot
.51611 .6483 Mdot
.49017 .61403 Mdot
.47087 .61478 Mdot
.46064 .6382 Mdot
.32602 .46332 Mdot
.45041 .66139 Mdot
.63037 .65832 Mdot
.52868 .41141 Mdot
.26789 .64143 Mdot
.78927 .46514 Mdot
.52472 .36657 Mdot
.35748 .47476 Mdot
.62756 .6336 Mdot
.552 .22074 Mdot
.51623 .65257 Mdot
.32124 .66495 Mdot
.09045 .49788 Mdot
.47727 .66061 Mdot
.53702 .38385 Mdot
.59821 .62003 Mdot
.51548 .39938 Mdot
.51471 .37167 Mdot
.44941 .26281 Mdot
.50093 .35008 Mdot
.70373 .4637 Mdot
.36679 .48639 Mdot
.63895 .63664 Mdot
.61925 .60031 Mdot
.4636 .66031 Mdot
.29394 .48072 Mdot
.46819 .63889 Mdot
.55116 .32005 Mdot
.64346 .6198 Mdot
.5267 .37242 Mdot
.50646 .65549 Mdot
.2871 .46863 Mdot
.54871 .34392 Mdot
.31089 .62428 Mdot
.44571 .70824 Mdot
.75714 .44272 Mdot
.36248 .38196 Mdot
.33759 .22436 Mdot
.53662 .69504 Mdot
.48291 .36988 Mdot
.31809 .21521 Mdot
.37177 .68879 Mdot
.30006 .4631 Mdot
.4414 .31298 Mdot
.55201 .78738 Mdot
.49077 .34043 Mdot
.58975 .48647 Mdot
.45394 .40203 Mdot
.39787 .55357 Mdot
.61307 .59622 Mdot
.34049 .46139 Mdot
.53157 .41046 Mdot
.49034 .33473 Mdot
.40275 .23847 Mdot
.52589 .42652 Mdot
.52677 .40731 Mdot
.28306 .51364 Mdot
.50165 .64945 Mdot
.48124 .31311 Mdot
.62123 .6634 Mdot
.32541 .69234 Mdot
.55261 .38393 Mdot
.63808 .60442 Mdot
.35986 .44932 Mdot
.54119 .40285 Mdot
.46783 .66041 Mdot
.49474 .36133 Mdot
.43477 .62906 Mdot
.34796 .45657 Mdot
.48767 .33634 Mdot
.72943 .47386 Mdot
.34711 .59898 Mdot
.33973 .49754 Mdot
.20057 .43663 Mdot
.50412 .35422 Mdot
.50645 .37533 Mdot
.30582 .45928 Mdot
.5913 .62638 Mdot
.55458 .50286 Mdot
.29116 .45832 Mdot
.48263 .61244 Mdot
.35127 .45322 Mdot
.45434 .36807 Mdot
.59734 .63272 Mdot
.31896 .6889 Mdot
.33652 .69565 Mdot
.77786 .38092 Mdot
.53748 .33808 Mdot
.34082 .71142 Mdot
.62133 .61891 Mdot
.32169 .45841 Mdot
.46778 .64359 Mdot
.46145 .38287 Mdot
.31026 .49342 Mdot
.50065 .62238 Mdot
.73738 .45017 Mdot
.67503 .54134 Mdot
.32997 .50721 Mdot
.59936 .43901 Mdot
.50684 .61225 Mdot
.46656 .61789 Mdot
.57686 .23607 Mdot
.30209 .4655 Mdot
.72316 .44638 Mdot
.49289 .62248 Mdot
.67869 .32047 Mdot
.46386 .38847 Mdot
.64029 .25272 Mdot
.3782 .17769 Mdot
.56377 .22679 Mdot
.20945 .5546 Mdot
.6907 .4638 Mdot
.48923 .62053 Mdot
.5448 .37344 Mdot
.31456 .47919 Mdot
.31339 .47199 Mdot
.48421 .33388 Mdot
.52675 .34625 Mdot
.48453 .39902 Mdot
.46751 .36538 Mdot
.79806 .57296 Mdot
.47872 .39393 Mdot
.47071 .57375 Mdot
.31852 .50074 Mdot
.53645 .3463 Mdot
.62651 .57853 Mdot
.53667 .32981 Mdot
.51577 .64849 Mdot
.51798 .38008 Mdot
.53175 .35254 Mdot
.5525 .40532 Mdot
.46233 .62816 Mdot
.43119 .82752 Mdot
.26855 .28258 Mdot
.65055 .74986 Mdot
.2318 .54726 Mdot
.61008 .62145 Mdot
.47496 .37181 Mdot
.70159 .4462 Mdot
.43536 .34018 Mdot
.51157 .36692 Mdot
.51998 .21011 Mdot
.52341 .35159 Mdot
.30095 .41087 Mdot
.43399 .38533 Mdot
.60571 .79378 Mdot
.41044 .60472 Mdot
.49617 .3462 Mdot
.318 .271 Mdot
.65905 .25173 Mdot
.76891 .47385 Mdot
.46959 .65674 Mdot
.60384 .57846 Mdot
.58956 .60866 Mdot
.45201 .63019 Mdot
.4735 .32525 Mdot
.24895 .36596 Mdot
.53097 .30778 Mdot
.31836 .68387 Mdot
.37938 .45923 Mdot
.68785 .4695 Mdot
.3363 .50607 Mdot
.25466 .26056 Mdot
.47445 .48513 Mdot
.44121 .68259 Mdot
.70615 .48526 Mdot
.64678 .59378 Mdot
.32057 .67476 Mdot
.70882 .44235 Mdot
.5263 .40338 Mdot
.35406 .46517 Mdot
.65583 .24866 Mdot
.49454 .44546 Mdot
.85602 .55394 Mdot
.29689 .47479 Mdot
.47614 .54114 Mdot
.47055 .6533 Mdot
.59865 .63941 Mdot
.49531 .34025 Mdot
.49428 .3982 Mdot
.36523 .48646 Mdot
.52078 .36095 Mdot
.40862 .51263 Mdot
.53105 .35591 Mdot
.61373 .64752 Mdot
.75472 .47199 Mdot
.44634 .63239 Mdot
.77075 .36481 Mdot
.28391 .47018 Mdot
.53226 .55202 Mdot
.63875 .5934 Mdot
.25263 .50547 Mdot
.49733 .66281 Mdot
.73875 .45679 Mdot
.6101 .5856 Mdot
.73947 .43651 Mdot
.55829 .3883 Mdot
.60263 .5945 Mdot
.72165 .46874 Mdot
.63343 .54732 Mdot
.53046 .40611 Mdot
.64152 .29497 Mdot
.49059 .62682 Mdot
.35265 .49895 Mdot
.5017 .34893 Mdot
.32947 .70209 Mdot
.47408 .33516 Mdot
.34347 .71308 Mdot
.31394 .69037 Mdot
.31564 .66998 Mdot
.4685 .71678 Mdot
.69808 .44141 Mdot
.25552 .59964 Mdot
.51572 .50291 Mdot
.29398 .4543 Mdot
.52473 .41714 Mdot
.5013 .84252 Mdot
.48543 .62331 Mdot
.52676 .4017 Mdot
.5662 .78454 Mdot
.49236 .6228 Mdot
.51231 .39359 Mdot
.45874 .63927 Mdot
.31233 .47642 Mdot
.55071 .52515 Mdot
.32885 .44409 Mdot
.53525 .3928 Mdot
.49151 .64617 Mdot
.60512 .58142 Mdot
.33392 .46655 Mdot
.49899 .36173 Mdot
.47814 .37617 Mdot
.32271 .67793 Mdot
.53098 .34227 Mdot
.53269 .82778 Mdot
.52691 .36854 Mdot
.64679 .59143 Mdot
.52051 .42806 Mdot
.63908 .23085 Mdot
.67557 .53889 Mdot
.2999 .4962 Mdot
.3115 .68505 Mdot
.6044 .60114 Mdot
.62459 .52116 Mdot
.67282 .49488 Mdot
.48854 .36742 Mdot
.33336 .68902 Mdot
.48296 .54561 Mdot
.46949 .66519 Mdot
.46353 .41224 Mdot
.43708 .49241 Mdot
.62101 .58815 Mdot
.31943 .67821 Mdot
.43892 .39223 Mdot
.35544 .44799 Mdot
.53933 .38181 Mdot
.60157 .59057 Mdot
.35927 .45866 Mdot
.46037 .38589 Mdot
.8053 .51906 Mdot
.32837 .69994 Mdot
.48702 .62709 Mdot
.59294 .33428 Mdot
.48029 .4007 Mdot
.58665 .61079 Mdot
.30778 .48521 Mdot
.48762 .65837 Mdot
.34892 .47735 Mdot
.68784 .26398 Mdot
.2477 .55557 Mdot
.72478 .64969 Mdot
.68788 .4833 Mdot
.19947 .63519 Mdot
.67193 .73073 Mdot
.27346 .57757 Mdot
.75585 .38597 Mdot
.71597 .73618 Mdot
.62044 .57957 Mdot
.5663 .26452 Mdot
.59859 .60928 Mdot
.55104 .37699 Mdot
.62328 .60323 Mdot
.56561 .82924 Mdot
.52711 .36031 Mdot
.60566 .62324 Mdot
.78135 .58213 Mdot
.51591 .34432 Mdot
.32578 .50368 Mdot
.28995 .73987 Mdot
.21717 .43813 Mdot
.52427 .4806 Mdot
.60488 .62681 Mdot
.46523 .2202 Mdot
.5176 .35136 Mdot
.53598 .44237 Mdot
.32033 .4772 Mdot
.45182 .39749 Mdot
.70282 .47822 Mdot
.74614 .44611 Mdot
.58175 .24971 Mdot
.21222 .45839 Mdot
.57698 .42437 Mdot
.3282 .46757 Mdot
.34902 .21657 Mdot
.31044 .62659 Mdot
.34098 .69517 Mdot
.49574 .61299 Mdot
.42872 .82524 Mdot
.4725 .45027 Mdot
.60823 .41527 Mdot
.41603 .52448 Mdot
.33733 .45696 Mdot
.67542 .70183 Mdot
.48557 .65457 Mdot
.30282 .27172 Mdot
.28963 .36258 Mdot
.49185 .40549 Mdot
.46607 .67137 Mdot
.52379 .29875 Mdot
.40894 .52187 Mdot
.63777 .27556 Mdot
.65606 .6754 Mdot
.53519 .39939 Mdot
.26574 .60696 Mdot
.51114 .3739 Mdot
.65697 .25792 Mdot
.5311 .39669 Mdot
.34586 .48486 Mdot
.54919 .4534 Mdot
.6372 .49054 Mdot
.22274 .34955 Mdot
.45552 .47983 Mdot
.68974 .44795 Mdot
.48852 .38218 Mdot
.49432 .40357 Mdot
.709 .47027 Mdot
.33997 .47613 Mdot
.50385 .41804 Mdot
.79539 .45792 Mdot
.4846 .40274 Mdot
.50984 .65923 Mdot
.59263 .51275 Mdot
.23891 .44737 Mdot
.48953 .33819 Mdot
.3603 .45607 Mdot
.46126 .6531 Mdot
.50364 .61721 Mdot
.54667 .44738 Mdot
.47777 .62295 Mdot
.53803 .37549 Mdot
.58048 .51465 Mdot
.3259 .44979 Mdot
.47135 .30576 Mdot
.33761 .4822 Mdot
.42956 .19044 Mdot
.45708 .63452 Mdot
.34343 .6806 Mdot
.58749 .29226 Mdot
.48482 .64159 Mdot
.28742 .52966 Mdot
.47759 .45625 Mdot
.53971 .32626 Mdot
.23916 .49678 Mdot
.58393 .60034 Mdot
.33464 .66998 Mdot
.48232 .66109 Mdot
.48198 .39912 Mdot
.55104 .39289 Mdot
.4839 .67304 Mdot
.41476 .25313 Mdot
.7306 .52144 Mdot
.5321 .39149 Mdot
.34472 .48253 Mdot
.32382 .45948 Mdot
.46917 .40119 Mdot
.51023 .36291 Mdot
.6411 .58432 Mdot
.33543 .68916 Mdot
.31836 .67154 Mdot
.33881 .69257 Mdot
.57252 .62599 Mdot
.19006 .60572 Mdot
.46712 .6177 Mdot
.22558 .64062 Mdot
.48831 .78202 Mdot
.54735 .44436 Mdot
.58554 .60523 Mdot
.50235 .39535 Mdot
.55713 .37657 Mdot
.49368 .64925 Mdot
.18456 .48998 Mdot
.58024 .36111 Mdot
.33587 .50886 Mdot
.4991 .66786 Mdot
.46192 .30715 Mdot
.43152 .69067 Mdot
.71528 .47701 Mdot
.46222 .4758 Mdot
.46934 .67249 Mdot
.35136 .46747 Mdot
.47754 .67413 Mdot
.49096 .40255 Mdot
.50766 .32255 Mdot
.32611 .45239 Mdot
.70213 .438 Mdot
.5409 .40616 Mdot
.51253 .392 Mdot
.66123 .21576 Mdot
.30515 .6221 Mdot
.49014 .69198 Mdot
.55021 .35951 Mdot
.56959 .35442 Mdot
.69811 .43769 Mdot
.48742 .40824 Mdot
.49155 .34213 Mdot
.34802 .59065 Mdot
.45999 .61607 Mdot
.75274 .4394 Mdot
.28251 .28897 Mdot
.29931 .48045 Mdot
.54232 .81786 Mdot
.32417 .69377 Mdot
.45603 .61547 Mdot
.54109 .52799 Mdot
.33675 .67408 Mdot
.5176 .76987 Mdot
.61537 .76369 Mdot
.34151 .68168 Mdot
.65478 .58095 Mdot
.41952 .41215 Mdot
.46499 .36512 Mdot
.51808 .38504 Mdot
.71025 .43932 Mdot
.30375 .47327 Mdot
.43488 .57996 Mdot
.56442 .59066 Mdot
.50057 .37596 Mdot
.27329 .48698 Mdot
.57787 .79079 Mdot
.32439 .67451 Mdot
.69422 .45321 Mdot
.68154 .45834 Mdot
.50982 .37591 Mdot
.31097 .5748 Mdot
.33024 .46554 Mdot
.49898 .36195 Mdot
.46952 .36874 Mdot
.59553 .62607 Mdot
.35415 .47346 Mdot
.64041 .59447 Mdot
.3155 .69356 Mdot
.78729 .66798 Mdot
.67979 .22448 Mdot
.4976 .63501 Mdot
.66993 .72208 Mdot
.51451 .66219 Mdot
.59354 .68304 Mdot
.33899 .68729 Mdot
.49834 .36832 Mdot
.28486 .47722 Mdot
.49648 .36023 Mdot
.50283 .41367 Mdot
.51797 .41276 Mdot
.57935 .41892 Mdot
.52941 .21033 Mdot
.70726 .44983 Mdot
.57575 .36592 Mdot
.61356 .5727 Mdot
.59696 .7916 Mdot
.31406 .75869 Mdot
.48684 .38897 Mdot
.506 .37859 Mdot
.30024 .49162 Mdot
.56365 .36354 Mdot
.47807 .66713 Mdot
.2985 .4695 Mdot
.54865 .39195 Mdot
.69191 .5917 Mdot
.4797 .40488 Mdot
.68594 .71545 Mdot
.47816 .67438 Mdot
.45376 .46994 Mdot
.55288 .33154 Mdot
.34194 .68364 Mdot
.33634 .67085 Mdot
.33541 .70272 Mdot
.4658 .66644 Mdot
.59319 .62226 Mdot
.56595 .5958 Mdot
.44202 .36926 Mdot
.54293 .37228 Mdot
.54053 .32527 Mdot
.57115 .62986 Mdot
.59059 .50176 Mdot
.21936 .56524 Mdot
.43354 .40431 Mdot
.5876 .5881 Mdot
.28705 .51087 Mdot
.18993 .4066 Mdot
.30111 .47725 Mdot
.7621 .45256 Mdot
.51297 .65103 Mdot
.70928 .47989 Mdot
.48988 .21227 Mdot
.33206 .45156 Mdot
.36069 .49431 Mdot
.60808 .62299 Mdot
.42745 .56771 Mdot
.10987 .59955 Mdot
.63281 .61269 Mdot
.77175 .41773 Mdot
.32452 .4742 Mdot
.56605 .40625 Mdot
.48385 .54805 Mdot
.43524 .56059 Mdot
.60612 .61333 Mdot
.48077 .37087 Mdot
.28475 .53612 Mdot
.64222 .58615 Mdot
.48522 .42674 Mdot
.60863 .62933 Mdot
.46293 .63122 Mdot
.61896 .62228 Mdot
.29218 .50329 Mdot
.5596 .384 Mdot
.08834 .52901 Mdot
.38059 .65025 Mdot
.49734 .35236 Mdot
.5037 .66558 Mdot
.81772 .52336 Mdot
.50532 .40927 Mdot
.70013 .47856 Mdot
.58274 .59253 Mdot
.76295 .5715 Mdot
.51275 .35011 Mdot
.61538 .60814 Mdot
.31839 .51613 Mdot
.56448 .65138 Mdot
.50929 .69819 Mdot
.32347 .66942 Mdot
.31106 .48132 Mdot
.31971 .70969 Mdot
.48662 .60517 Mdot
.54372 .40878 Mdot
.46989 .37821 Mdot
.33087 .49907 Mdot
.46661 .7315 Mdot
.55263 .41543 Mdot
.483 .3701 Mdot
.64383 .59297 Mdot
.57099 .59808 Mdot
.36523 .74935 Mdot
.6205 .57848 Mdot
.5704 .35556 Mdot
.33445 .49731 Mdot
.54632 .38288 Mdot
.31908 .50362 Mdot
.52615 .41593 Mdot
.24412 .45918 Mdot
.30193 .47649 Mdot
.2447 .52823 Mdot
.5191 .33671 Mdot
.56045 .28778 Mdot
.50168 .41449 Mdot
.52632 .40554 Mdot
.57872 .59896 Mdot
.7185 .45811 Mdot
.48087 .42716 Mdot
.54214 .5396 Mdot
.72214 .4355 Mdot
.4009 .36871 Mdot
.59085 .62478 Mdot
.72498 .44025 Mdot
.64912 .34308 Mdot
.31157 .68462 Mdot
.70401 .45753 Mdot
.36331 .77523 Mdot
.49697 .63751 Mdot
.3236 .44738 Mdot
.51803 .34393 Mdot
.73959 .72114 Mdot
.73049 .5188 Mdot
.32838 .67781 Mdot
.50547 .35221 Mdot
.50463 .39896 Mdot
.34914 .44399 Mdot
.28675 .23466 Mdot
.61016 .64529 Mdot
.54043 .39723 Mdot
.29762 .45476 Mdot
.36135 .18988 Mdot
.61591 .63024 Mdot
.69916 .45639 Mdot
.47386 .67698 Mdot
.36567 .43461 Mdot
.3278 .66799 Mdot
.4547 .63833 Mdot
.66479 .57312 Mdot
.48351 .2027 Mdot
.51519 .35427 Mdot
.59046 .59521 Mdot
.56099 .22515 Mdot
.46014 .3314 Mdot
.52748 .64849 Mdot
.33031 .41657 Mdot
.33744 .45797 Mdot
.48729 .67237 Mdot
.68706 .4503 Mdot
.32698 .44893 Mdot
.3411 .47508 Mdot
.51052 .62327 Mdot
.47128 .5815 Mdot
.47336 .54243 Mdot
.50342 .66216 Mdot
.38517 .57138 Mdot
.58725 .24476 Mdot
.33364 .69147 Mdot
.6932 .45412 Mdot
.69149 .26111 Mdot
.32887 .46315 Mdot
.43004 .82579 Mdot
.53128 .21299 Mdot
.52692 .40709 Mdot
.73034 .45723 Mdot
.52266 .77766 Mdot
.61174 .55578 Mdot
.5001 .62362 Mdot
.6052 .48948 Mdot
.68699 .47232 Mdot
.4667 .38932 Mdot
.24823 .43702 Mdot
.50933 .33783 Mdot
.48864 .62205 Mdot
.39397 .52917 Mdot
.35257 .47945 Mdot
.48418 .60504 Mdot
.41416 .50523 Mdot
.55719 .37268 Mdot
.48625 .35021 Mdot
.7115 .30559 Mdot
.35551 .46829 Mdot
.32667 .66744 Mdot
.48941 .36133 Mdot
.51743 .39778 Mdot
.54086 .41371 Mdot
.60121 .31611 Mdot
.31351 .59152 Mdot
.54053 .39886 Mdot
.58433 .63266 Mdot
.53209 .32508 Mdot
.49004 .34556 Mdot
.33079 .44232 Mdot
.61113 .2109 Mdot
.32002 .69909 Mdot
.52001 .38793 Mdot
.53119 .39145 Mdot
.48683 .61226 Mdot
.47806 .54413 Mdot
.42825 .56206 Mdot
.6443 .61314 Mdot
.73237 .37412 Mdot
.52638 .30824 Mdot
.31287 .49281 Mdot
.71994 .47935 Mdot
.56657 .38418 Mdot
.30265 .48958 Mdot
.50609 .31881 Mdot
.63891 .58034 Mdot
.33477 .68738 Mdot
.59338 .43 Mdot
.70683 .46124 Mdot
.44021 .61669 Mdot
.25121 .66965 Mdot
.6243 .57702 Mdot
.54317 .36333 Mdot
.56259 .6393 Mdot
.63368 .59327 Mdot
.32327 .67912 Mdot
.44456 .40586 Mdot
.31659 .47115 Mdot
.35176 .47723 Mdot
.61487 .25305 Mdot
.58666 .64182 Mdot
.51957 .16308 Mdot
.46424 .62993 Mdot
.45728 .39414 Mdot
.29053 .71597 Mdot
.34896 .48677 Mdot
.70124 .28149 Mdot
.72183 .43874 Mdot
.50032 .62413 Mdot
.30699 .68894 Mdot
.30437 .4923 Mdot
.34906 .49254 Mdot
.52563 .41285 Mdot
.49308 .38767 Mdot
.76546 .39454 Mdot
.64891 .25417 Mdot
.45994 .63739 Mdot
.69497 .46278 Mdot
.63751 .62413 Mdot
.55439 .36786 Mdot
.30405 .45592 Mdot
.31163 .40657 Mdot
.4765 .39522 Mdot
.64368 .58753 Mdot
.33024 .45533 Mdot
.70193 .46975 Mdot
.7353 .45646 Mdot
.52519 .40709 Mdot
.39004 .35504 Mdot
.48414 .63707 Mdot
.33476 .50083 Mdot
.37153 .51016 Mdot
.53358 .42525 Mdot
.48886 .38651 Mdot
.52536 .29423 Mdot
.45485 .63531 Mdot
.58497 .43812 Mdot
.67682 .45907 Mdot
.3099 .46866 Mdot
.49546 .35516 Mdot
.70341 .46343 Mdot
.60701 .36373 Mdot
.33843 .67983 Mdot
.6118 .62902 Mdot
.69756 .4762 Mdot
.72188 .46399 Mdot
.7323 .43926 Mdot
.41569 .8209 Mdot
.35212 .44044 Mdot
.277 .28803 Mdot
.51709 .41575 Mdot
.59427 .25101 Mdot
.5305 .33364 Mdot
.45382 .65192 Mdot
.60128 .58122 Mdot
.49753 .41062 Mdot
.52525 .41352 Mdot
.25285 .43826 Mdot
.48356 .28982 Mdot
.41246 .46525 Mdot
.35149 .46001 Mdot
.57118 .28955 Mdot
.58362 .61225 Mdot
.36445 .17385 Mdot
.40814 .84052 Mdot
.54418 .31582 Mdot
.44602 .56412 Mdot
.29888 .46714 Mdot
.49176 .61808 Mdot
.44097 .55228 Mdot
.44311 .66673 Mdot
.3099 .46411 Mdot
.55344 .37485 Mdot
.22871 .63858 Mdot
.73886 .43881 Mdot
.48383 .39691 Mdot
.46559 .64827 Mdot
.48414 .39791 Mdot
.45966 .66309 Mdot
.34891 .42725 Mdot
.39091 .5827 Mdot
.52395 .35325 Mdot
.55013 .41335 Mdot
.54138 .46775 Mdot
.48896 .38918 Mdot
.55697 .73343 Mdot
.33197 .47966 Mdot
.2447 .51305 Mdot
.47466 .40683 Mdot
.38666 .33301 Mdot
.47042 .38983 Mdot
.47027 .73565 Mdot
.47296 .36801 Mdot
.60751 .44935 Mdot
.46535 .3892 Mdot
.47533 .36973 Mdot
.48892 .65343 Mdot
.48815 .61394 Mdot
.32002 .51559 Mdot
.33803 .66902 Mdot
.60452 .79335 Mdot
.50757 .38705 Mdot
.57368 .60633 Mdot
.29573 .713 Mdot
.72137 .46104 Mdot
.31361 .46365 Mdot
.45586 .1346 Mdot
.45914 .64813 Mdot
.64502 .63155 Mdot
.51175 .72375 Mdot
.61159 .6411 Mdot
.63292 .64837 Mdot
.54938 .28309 Mdot
.6926 .463 Mdot
.46824 .38749 Mdot
.41528 .3192 Mdot
.28179 .61525 Mdot
.48649 .42546 Mdot
.55022 .63627 Mdot
.45086 .31421 Mdot
.58762 .24227 Mdot
.72455 .42976 Mdot
.68808 .46505 Mdot
.48336 .65915 Mdot
.64985 .61875 Mdot
.4906 .31265 Mdot
.72732 .44126 Mdot
.60244 .5783 Mdot
.34774 .6832 Mdot
.73532 .49373 Mdot
.32587 .46498 Mdot
.53608 .47948 Mdot
.28596 .65882 Mdot
.4598 .6417 Mdot
.54285 .53617 Mdot
.28125 .45475 Mdot
.37399 .46229 Mdot
.34524 .68004 Mdot
.59325 .57818 Mdot
.28993 .45592 Mdot
.54559 .40163 Mdot
.49314 .44564 Mdot
.50987 .37269 Mdot
.72591 .44362 Mdot
.47353 .35904 Mdot
.60607 .57407 Mdot
.47506 .62837 Mdot
.61458 .59437 Mdot
.48596 .63452 Mdot
.219 .61307 Mdot
.51267 .36118 Mdot
.49042 .38403 Mdot
.53423 .52292 Mdot
.34444 .5007 Mdot
.43541 .27366 Mdot
.58724 .58142 Mdot
.59686 .6167 Mdot
.54765 .38344 Mdot
.32964 .51397 Mdot
.74495 .46829 Mdot
.48442 .55378 Mdot
.47104 .36951 Mdot
.33103 .4807 Mdot
.54218 .38384 Mdot
.72337 .63595 Mdot
.37699 .61447 Mdot
.34948 .4789 Mdot
.21462 .35956 Mdot
.53156 .34071 Mdot
.42129 .35976 Mdot
.57957 .39535 Mdot
.70011 .39756 Mdot
.5069 .43486 Mdot
.29608 .47181 Mdot
.5168 .3765 Mdot
.31394 .48841 Mdot
.63226 .58632 Mdot
.4742 .61594 Mdot
.31528 .48238 Mdot
.50166 .33451 Mdot
.36583 .81101 Mdot
.46226 .64304 Mdot
.48164 .3795 Mdot
.49822 .65859 Mdot
.30511 .44878 Mdot
.3557 .48707 Mdot
.37508 .77222 Mdot
.44654 .69433 Mdot
.46275 .6482 Mdot
.53993 .3736 Mdot
.32333 .64558 Mdot
.54606 .38243 Mdot
.76445 .3879 Mdot
.47376 .41116 Mdot
.51638 .42937 Mdot
.20906 .65255 Mdot
.43793 .65886 Mdot
.48867 .15223 Mdot
.57588 .57505 Mdot
.39867 .8135 Mdot
.31476 .43499 Mdot
.72513 .42982 Mdot
.65825 .72567 Mdot
.31813 .69512 Mdot
.58181 .62664 Mdot
.49645 .4104 Mdot
.24239 .45449 Mdot
.49972 .66622 Mdot
.71849 .4528 Mdot
.52388 .35242 Mdot
.65094 .5892 Mdot
.3415 .76474 Mdot
.49084 .62045 Mdot
.3241 .4634 Mdot
.34188 .50379 Mdot
.30842 .23983 Mdot
.49856 .3543 Mdot
.49512 .38201 Mdot
.51408 .65058 Mdot
.49046 .31688 Mdot
.74165 .44893 Mdot
.75547 .61386 Mdot
.46719 .6537 Mdot
.37754 .65273 Mdot
.34939 .45685 Mdot
.5034 .39756 Mdot
.60273 .51167 Mdot
.45108 .79489 Mdot
.30518 .29222 Mdot
.7074 .44087 Mdot
.73256 .34777 Mdot
.29613 .47225 Mdot
.46739 .64638 Mdot
.60869 .28252 Mdot
.46569 .34574 Mdot
.50816 .39986 Mdot
.72756 .33818 Mdot
.47426 .55053 Mdot
.66883 .47639 Mdot
.5696 .40518 Mdot
.4941 .5359 Mdot
.54902 .38311 Mdot
.55173 .39199 Mdot
.54312 .31423 Mdot
.48403 .34626 Mdot
.32491 .48474 Mdot
.24484 .42093 Mdot
.62098 .61197 Mdot
.39267 .23339 Mdot
.61224 .47884 Mdot
.50809 .34271 Mdot
.55525 .37459 Mdot
.2257 .41297 Mdot
.29701 .70573 Mdot
.33164 .47583 Mdot
.30061 .52398 Mdot
.46335 .61907 Mdot
.49158 .28712 Mdot
.57966 .63708 Mdot
.41191 .44441 Mdot
.62749 .59392 Mdot
.33077 .48194 Mdot
.59165 .61774 Mdot
.47156 .61168 Mdot
.59118 .5947 Mdot
.5743 .62789 Mdot
.45438 .66977 Mdot
.35733 .46142 Mdot
.47341 .37868 Mdot
.45763 .6346 Mdot
.72052 .31216 Mdot
.72696 .44429 Mdot
.37288 .77255 Mdot
.57244 .39617 Mdot
.40872 .41545 Mdot
.80506 .51811 Mdot
.60046 .59867 Mdot
.36181 .61404 Mdot
.30214 .47667 Mdot
.72675 .47905 Mdot
.32018 .48691 Mdot
.49211 .2206 Mdot
.71282 .46795 Mdot
.37227 .77428 Mdot
.61777 .29361 Mdot
.60803 .53136 Mdot
.49416 .32963 Mdot
.25052 .47071 Mdot
.62678 .59144 Mdot
.51106 .6583 Mdot
.54838 .78328 Mdot
.54317 .34174 Mdot
.26966 .57853 Mdot
.36298 .44604 Mdot
.31295 .67957 Mdot
.46855 .64156 Mdot
.54084 .62955 Mdot
.50241 .35537 Mdot
.60146 .52733 Mdot
.49597 .42653 Mdot
.57693 .27637 Mdot
.7433 .37254 Mdot
.35597 .42185 Mdot
.53834 .38071 Mdot
.645 .60428 Mdot
.54182 .38132 Mdot
.43058 .41788 Mdot
.57459 .23677 Mdot
.57156 .38283 Mdot
.24272 .54286 Mdot
.77684 .55448 Mdot
.3187 .45263 Mdot
.57166 .35506 Mdot
.32712 .68503 Mdot
.54579 .35115 Mdot
.81354 .67406 Mdot
.7075 .45674 Mdot
.65244 .56081 Mdot
.49891 .33308 Mdot
.49258 .3606 Mdot
.37522 .39178 Mdot
.26944 .45169 Mdot
.30871 .69114 Mdot
.51127 .4032 Mdot
.71647 .34824 Mdot
.49094 .65695 Mdot
.4603 .39209 Mdot
.51575 .37961 Mdot
.73024 .29314 Mdot
.49567 .65612 Mdot
.59432 .6003 Mdot
.31202 .68705 Mdot
.63684 .62286 Mdot
.73144 .42971 Mdot
.4249 .55071 Mdot
.67952 .26515 Mdot
.37603 .61722 Mdot
.69548 .47829 Mdot
.47783 .34485 Mdot
.41696 .36097 Mdot
.48661 .35487 Mdot
.68728 .4606 Mdot
.4867 .66462 Mdot
.32386 .48244 Mdot
.57998 .45641 Mdot
.31908 .68339 Mdot
.497 .42962 Mdot
.71415 .43018 Mdot
.31616 .47663 Mdot
.39545 .75724 Mdot
.30461 .46658 Mdot
.48581 .64553 Mdot
.45551 .62378 Mdot
.71389 .46406 Mdot
.32271 .48669 Mdot
.61258 .63402 Mdot
.56493 .58759 Mdot
.48017 .41696 Mdot
.52705 .66049 Mdot
.29641 .50189 Mdot
.35669 .4965 Mdot
.28918 .48359 Mdot
.51366 .35799 Mdot
.46429 .55368 Mdot
.46881 .33955 Mdot
.46488 .65778 Mdot
.59043 .62851 Mdot
.63595 .25219 Mdot
.41302 .31809 Mdot
.37832 .6472 Mdot
.48871 .43058 Mdot
.48461 .3492 Mdot
.50955 .3758 Mdot
.53337 .38578 Mdot
.74261 .6283 Mdot
.51302 .36288 Mdot
.49079 .64141 Mdot
.63217 .60318 Mdot
.50269 .35112 Mdot
.32922 .68732 Mdot
.53573 .5054 Mdot
.71631 .4804 Mdot
.60928 .45261 Mdot
.4097 .83318 Mdot
.31763 .47691 Mdot
.60714 .58492 Mdot
.599 .63216 Mdot
.73746 .45035 Mdot
.46617 .62667 Mdot
.30452 .47216 Mdot
.67118 .39671 Mdot
.71945 .43417 Mdot
.52058 .38874 Mdot
.56406 .51833 Mdot
.20281 .38027 Mdot
.47474 .34519 Mdot
.51696 .4109 Mdot
.31332 .67288 Mdot
.61645 .64265 Mdot
.72775 .7513 Mdot
.44343 .5822 Mdot
.71724 .45989 Mdot
.70563 .4744 Mdot
.2892 .47388 Mdot
.4611 .40732 Mdot
.48142 .63322 Mdot
.4921 .54409 Mdot
.81773 .49978 Mdot
.54296 .79887 Mdot
.57854 .68472 Mdot
.48417 .40807 Mdot
.31791 .38964 Mdot
.51632 .42294 Mdot
.35901 .44789 Mdot
.29345 .48461 Mdot
.33065 .4712 Mdot
.48709 .65401 Mdot
.43401 .19206 Mdot
.49087 .63832 Mdot
.41177 .83521 Mdot
.3055 .45259 Mdot
.66034 .53092 Mdot
.59878 .62215 Mdot
.44284 .379 Mdot
.6925 .46066 Mdot
.54608 .65524 Mdot
.56672 .3452 Mdot
.30167 .57449 Mdot
.58572 .60507 Mdot
.35894 .47935 Mdot
.45078 .43603 Mdot
.62904 .78761 Mdot
.41385 .57195 Mdot
.78472 .48214 Mdot
.48031 .23607 Mdot
.70908 .46978 Mdot
.26718 .32445 Mdot
.73985 .44235 Mdot
.49715 .62232 Mdot
.54075 .34003 Mdot
.51306 .33412 Mdot
.53807 .39701 Mdot
.51616 .36395 Mdot
.48315 .66168 Mdot
.48987 .41637 Mdot
.63778 .23071 Mdot
.32881 .69706 Mdot
.66967 .54597 Mdot
.72861 .46805 Mdot
.45441 .66063 Mdot
.6341 .59828 Mdot
.34262 .67176 Mdot
.76631 .35518 Mdot
.49048 .41465 Mdot
.49901 .41279 Mdot
.33984 .69435 Mdot
.49045 .31855 Mdot
.4662 .44573 Mdot
.62005 .60843 Mdot
.43502 .51218 Mdot
.6835 .4564 Mdot
.70973 .47965 Mdot
.47349 .67299 Mdot
.32032 .48716 Mdot
.71303 .43815 Mdot
.65225 .6108 Mdot
.46051 .38317 Mdot
.55759 .40641 Mdot
.29713 .50292 Mdot
.53144 .21292 Mdot
.74656 .44094 Mdot
.47276 .45664 Mdot
.30647 .48723 Mdot
.35982 .44389 Mdot
.50888 .40391 Mdot
.50545 .4386 Mdot
.36477 .47695 Mdot
.7288 .47004 Mdot
.45535 .6644 Mdot
.64442 .52527 Mdot
.47905 .62485 Mdot
.30886 .47725 Mdot
.48361 .32874 Mdot
.35467 .45957 Mdot
.53371 .34243 Mdot
.22194 .26084 Mdot
.47885 .35143 Mdot
.2577 .51518 Mdot
.71311 .39725 Mdot
.6121 .63067 Mdot
.62205 .63033 Mdot
.33262 .68768 Mdot
.30079 .48119 Mdot
.56566 .38285 Mdot
.69804 .4715 Mdot
.38349 .80328 Mdot
.3786 .49272 Mdot
.58066 .60111 Mdot
.59819 .6426 Mdot
.48372 .66429 Mdot
.46878 .38375 Mdot
.5033 .3937 Mdot
.59138 .59571 Mdot
.80603 .54227 Mdot
.31874 .49451 Mdot
.49502 .38165 Mdot
.48941 .34507 Mdot
.62403 .61146 Mdot
.56652 .58328 Mdot
.27026 .46053 Mdot
.48444 .34651 Mdot
.62598 .30285 Mdot
.4584 .65897 Mdot
.53139 .37023 Mdot
.49801 .41915 Mdot
.72557 .45616 Mdot
.68668 .56461 Mdot
.58254 .24083 Mdot
.45146 .64372 Mdot
.32189 .66921 Mdot
.53505 .33608 Mdot
.60198 .62182 Mdot
.56585 .4056 Mdot
.71067 .71028 Mdot
.32268 .696 Mdot
.50322 .36489 Mdot
.52849 .31082 Mdot
.33039 .50478 Mdot
.5 .36333 Mdot
.26756 .43714 Mdot
.64013 .61257 Mdot
.50385 .36374 Mdot
.39343 .34544 Mdot
.48055 .66431 Mdot
.56553 .34475 Mdot
.69829 .47463 Mdot
.70813 .40093 Mdot
.26525 .67177 Mdot
.56917 .61866 Mdot
.73375 .45933 Mdot
.47218 .36147 Mdot
.64725 .59768 Mdot
.475 .67711 Mdot
.27671 .57157 Mdot
.46698 .35702 Mdot
.46923 .62832 Mdot
.47055 .63125 Mdot
.71282 .46076 Mdot
.44325 .15044 Mdot
.52615 .30958 Mdot
.48263 .3871 Mdot
.82398 .43688 Mdot
.30137 .44633 Mdot
.47965 .38611 Mdot
.46958 .3819 Mdot
.49134 .62791 Mdot
.6093 .3117 Mdot
.38637 .50973 Mdot
.78147 .58229 Mdot
.45814 .66098 Mdot
.61536 .56547 Mdot
.64172 .5928 Mdot
.73134 .4638 Mdot
.3201 .45364 Mdot
.68483 .47249 Mdot
.61476 .6211 Mdot
.52772 .40452 Mdot
.5061 .63108 Mdot
.34546 .28187 Mdot
.51603 .65356 Mdot
.65054 .59332 Mdot
.36666 .46401 Mdot
.2854 .7156 Mdot
.85802 .4516 Mdot
.27941 .65114 Mdot
.44919 .65268 Mdot
.7217 .46078 Mdot
.45604 .57703 Mdot
.48426 .35006 Mdot
.27181 .30758 Mdot
.48205 .39213 Mdot
.48597 .23249 Mdot
.60049 .5807 Mdot
.34551 .68485 Mdot
.54496 .34268 Mdot
.72908 .34869 Mdot
.45008 .65263 Mdot
.47693 .66626 Mdot
.52651 .38642 Mdot
.48596 .64286 Mdot
.50005 .38824 Mdot
.62956 .61037 Mdot
.4534 .15302 Mdot
.4773 .36263 Mdot
.56827 .35961 Mdot
.4584 .61633 Mdot
.37205 .773 Mdot
.61577 .56758 Mdot
.32857 .39047 Mdot
.64606 .7827 Mdot
.48328 .64083 Mdot
.57664 .41272 Mdot
.60232 .59326 Mdot
.31483 .67047 Mdot
.65954 .62585 Mdot
.48981 .39848 Mdot
.49752 .41513 Mdot
.54543 .38939 Mdot
.4883 .34806 Mdot
.25586 .32848 Mdot
.44362 .41775 Mdot
.31022 .36375 Mdot
.50356 .41435 Mdot
.26816 .51597 Mdot
.49281 .64583 Mdot
.40364 .45401 Mdot
.66669 .46736 Mdot
.4987 .41655 Mdot
.2661 .45622 Mdot
.45259 .65546 Mdot
.43154 .83638 Mdot
.49111 .66 Mdot
.60843 .59919 Mdot
.49976 .61855 Mdot
.52906 .34143 Mdot
.32617 .45965 Mdot
.63792 .60839 Mdot
.22051 .57654 Mdot
.57943 .62273 Mdot
.4977 .35248 Mdot
.60861 .5477 Mdot
.6085 .63098 Mdot
.57216 .48337 Mdot
.32407 .45781 Mdot
.70398 .33463 Mdot
.30764 .44378 Mdot
.49558 .36726 Mdot
.49025 .37023 Mdot
.3422 .6701 Mdot
.48986 .62031 Mdot
.30265 .45171 Mdot
.65639 .21343 Mdot
.69561 .43413 Mdot
.33787 .46898 Mdot
.48801 .43699 Mdot
.45791 .56089 Mdot
.33982 .49614 Mdot
.70917 .37159 Mdot
.48709 .6215 Mdot
.28725 .46716 Mdot
.4473 .40573 Mdot
.6146 .40434 Mdot
.74448 .45569 Mdot
.63768 .57858 Mdot
.49849 .51896 Mdot
.64283 .59737 Mdot
.49243 .60392 Mdot
.60518 .64756 Mdot
.49347 .65316 Mdot
.23395 .48907 Mdot
.39625 .52437 Mdot
.48311 .60116 Mdot
.46931 .61072 Mdot
.61157 .61636 Mdot
.53264 .38778 Mdot
.63169 .49514 Mdot
.47981 .43225 Mdot
.50267 .32409 Mdot
.45594 .65074 Mdot
.2944 .47043 Mdot
.34483 .45111 Mdot
.25339 .48294 Mdot
.35153 .4924 Mdot
.63804 .60007 Mdot
.37244 .60633 Mdot
.47975 .2238 Mdot
.49815 .66146 Mdot
.44648 .6835 Mdot
.54787 .37947 Mdot
.60637 .62069 Mdot
.63137 .58354 Mdot
.48199 .62895 Mdot
.33912 .26047 Mdot
.55372 .33558 Mdot
.33465 .44144 Mdot
.30659 .45188 Mdot
.34153 .49291 Mdot
.30596 .50375 Mdot
.3955 .19979 Mdot
.5112 .65823 Mdot
.29748 .47173 Mdot
.52114 .37372 Mdot
.48617 .4064 Mdot
.31898 .67426 Mdot
.71803 .47439 Mdot
.54363 .33668 Mdot
.55049 .3388 Mdot
.5073 .40333 Mdot
.60977 .62992 Mdot
.46693 .3129 Mdot
.32035 .69304 Mdot
.60461 .64643 Mdot
.57601 .63316 Mdot
.34309 .67877 Mdot
.39109 .47243 Mdot
.61578 .8042 Mdot
.54064 .39657 Mdot
.49538 .27234 Mdot
.60295 .61783 Mdot
.36125 .56336 Mdot
.58469 .434 Mdot
.53718 .37506 Mdot
.65057 .48315 Mdot
.6326 .61042 Mdot
.37893 .46328 Mdot
.48741 .39238 Mdot
.3384 .69099 Mdot
.72642 .47541 Mdot
.45446 .4143 Mdot
.31257 .67338 Mdot
.33089 .48398 Mdot
.78076 .53021 Mdot
.29345 .45125 Mdot
.6112 .63237 Mdot
.57026 .35149 Mdot
.09666 .57644 Mdot
.62612 .59024 Mdot
.46048 .82047 Mdot
.40509 .51652 Mdot
.47842 .35755 Mdot
.63989 .5943 Mdot
.37666 .46036 Mdot
.45808 .65801 Mdot
.51916 .52216 Mdot
.30505 .45554 Mdot
.34464 .675 Mdot
.32889 .66986 Mdot
.62208 .61114 Mdot
.3449 .45838 Mdot
.47717 .41151 Mdot
.31275 .50196 Mdot
.50886 .62314 Mdot
.53195 .3518 Mdot
.60657 .7935 Mdot
.4949 .446 Mdot
.30557 .48805 Mdot
.65429 .60592 Mdot
.69897 .43821 Mdot
.52303 .35403 Mdot
.52212 .82182 Mdot
.46826 .38067 Mdot
.49346 .66193 Mdot
.34375 .5553 Mdot
.32998 .29369 Mdot
.53144 .39523 Mdot
.55238 .37793 Mdot
.46941 .67385 Mdot
.53168 .39777 Mdot
.46916 .35654 Mdot
.53192 .64237 Mdot
.34099 .49838 Mdot
.50586 .37197 Mdot
.63107 .57837 Mdot
.48256 .25165 Mdot
.5563 .35202 Mdot
.22391 .53533 Mdot
.71611 .34013 Mdot
.35137 .54848 Mdot
.56771 .38012 Mdot
.72314 .30982 Mdot
.48808 .37463 Mdot
.51967 .35868 Mdot
.54036 .39038 Mdot
.29608 .39372 Mdot
.61188 .61991 Mdot
.58973 .58409 Mdot
.74003 .46694 Mdot
.72065 .347 Mdot
.72955 .45384 Mdot
.45757 .66945 Mdot
.46661 .71838 Mdot
.32838 .69619 Mdot
.31794 .48768 Mdot
.55772 .38687 Mdot
.57941 .62766 Mdot
.50033 .39856 Mdot
.54584 .35282 Mdot
.62755 .61814 Mdot
.63553 .59127 Mdot
.57823 .64026 Mdot
.73044 .43571 Mdot
.32531 .47691 Mdot
.52874 .40859 Mdot
.72009 .43514 Mdot
.46876 .40295 Mdot
.46051 .56409 Mdot
.3281 .47594 Mdot
.31453 .50313 Mdot
.33335 .44552 Mdot
.51529 .41651 Mdot
.5227 .341 Mdot
.49059 .63685 Mdot
.29376 .49973 Mdot
.49914 .66301 Mdot
.64052 .59616 Mdot
.62101 .62939 Mdot
.48973 .39885 Mdot
.45994 .44763 Mdot
.71158 .47349 Mdot
.60349 .59989 Mdot
.32937 .70323 Mdot
.73851 .46867 Mdot
.50625 .35245 Mdot
.64189 .59894 Mdot
.70645 .47976 Mdot
.38264 .24691 Mdot
.6762 .7683 Mdot
.70751 .43323 Mdot
.52578 .38581 Mdot
.38426 .38096 Mdot
.61429 .2764 Mdot
.68842 .43837 Mdot
.50538 .65057 Mdot
.47231 .38815 Mdot
.81586 .54511 Mdot
.68132 .46313 Mdot
.53693 .21511 Mdot
.62303 .62208 Mdot
.5736 .28417 Mdot
.45483 .41643 Mdot
.31933 .26079 Mdot
.68159 .46786 Mdot
.30724 .47181 Mdot
.28203 .47886 Mdot
.52384 .39076 Mdot
.67468 .4496 Mdot
.5165 .62859 Mdot
.59981 .63285 Mdot
.57291 .62082 Mdot
.34788 .46127 Mdot
.37702 .63291 Mdot
.63609 .58217 Mdot
.57506 .35485 Mdot
.66255 .59211 Mdot
.52705 .28669 Mdot
.33108 .22972 Mdot
.2157 .58869 Mdot
.55388 .40576 Mdot
.69578 .43869 Mdot
.45878 .67577 Mdot
.48873 .63865 Mdot
.48495 .65245 Mdot
.63063 .62503 Mdot
.46054 .54454 Mdot
.58946 .59358 Mdot
.27589 .58883 Mdot
.70244 .46309 Mdot
.68579 .33169 Mdot
.56499 .37513 Mdot
.47992 .35602 Mdot
.45962 .38646 Mdot
.54649 .38965 Mdot
.48881 .37588 Mdot
.46025 .63963 Mdot
.61878 .63676 Mdot
.76683 .57394 Mdot
.34264 .48604 Mdot
.38893 .74054 Mdot
.59815 .6221 Mdot
.31084 .68106 Mdot
.7107 .44832 Mdot
.67882 .26877 Mdot
.6119 .5626 Mdot
.59247 .61763 Mdot
.46367 .36099 Mdot
.29457 .4789 Mdot
.60645 .32921 Mdot
.48279 .37029 Mdot
.60201 .5997 Mdot
.65465 .6197 Mdot
.27947 .31596 Mdot
.55663 .31085 Mdot
.75348 .46292 Mdot
.45537 .56086 Mdot
.67816 .46635 Mdot
.51757 .4374 Mdot
.35987 .56604 Mdot
.61543 .61897 Mdot
.61508 .59977 Mdot
.70117 .43345 Mdot
.41695 .39368 Mdot
.33407 .45453 Mdot
.3451 .68685 Mdot
.50267 .64923 Mdot
.484 .36255 Mdot
.63598 .61992 Mdot
.47416 .28657 Mdot
.55793 .52149 Mdot
.47248 .6558 Mdot
.60637 .64603 Mdot
.4714 .39205 Mdot
.52706 .39375 Mdot
.71273 .46946 Mdot
.69668 .51625 Mdot
.47026 .42821 Mdot
.39962 .81399 Mdot
.39718 .57068 Mdot
.45551 .48234 Mdot
.50809 .39947 Mdot
.35423 .47009 Mdot
.33966 .68681 Mdot
.69316 .45287 Mdot
.46783 .39832 Mdot
.65362 .7881 Mdot
.28504 .50128 Mdot
.46394 .64206 Mdot
.34055 .68742 Mdot
.46946 .53926 Mdot
.46789 .37869 Mdot
.48225 .39209 Mdot
.51474 .3606 Mdot
.66791 .7854 Mdot
.59783 .58013 Mdot
.29189 .49148 Mdot
.70992 .44045 Mdot
.329 .50811 Mdot
.58336 .59321 Mdot
.52117 .4978 Mdot
.50626 .34951 Mdot
.34175 .44356 Mdot
.30677 .46846 Mdot
.48271 .66483 Mdot
.45424 .64026 Mdot
.56816 .59804 Mdot
.47668 .35558 Mdot
.33475 .69559 Mdot
.29126 .46449 Mdot
.63054 .63651 Mdot
.71126 .4687 Mdot
.45747 .62775 Mdot
.50638 .41528 Mdot
.61851 .61372 Mdot
.52134 .42461 Mdot
.32196 .50235 Mdot
.59368 .61848 Mdot
.30884 .68174 Mdot
.71124 .4748 Mdot
.50194 .41591 Mdot
.79221 .52828 Mdot
.34315 .6856 Mdot
.50731 .33678 Mdot
.39788 .39004 Mdot
.66747 .45034 Mdot
.21851 .57167 Mdot
.605 .58217 Mdot
.32438 .69057 Mdot
.29231 .48571 Mdot
.61405 .38272 Mdot
.62144 .59839 Mdot
.33745 .40963 Mdot
.64901 .50628 Mdot
.53181 .40379 Mdot
.34094 .46498 Mdot
.70537 .49377 Mdot
.43165 .82925 Mdot
.62962 .2901 Mdot
.49893 .37905 Mdot
.64297 .59675 Mdot
.71122 .47987 Mdot
.49146 .66616 Mdot
.22538 .53548 Mdot
.32524 .23823 Mdot
.59773 .64457 Mdot
.53442 .40815 Mdot
.29133 .46665 Mdot
.47879 .63011 Mdot
.22174 .62995 Mdot
.65247 .60687 Mdot
.61337 .57705 Mdot
.51415 .35195 Mdot
.70398 .44105 Mdot
.801 .56795 Mdot
.5966 .57919 Mdot
.63386 .62627 Mdot
.37884 .74632 Mdot
.7402 .43653 Mdot
.5209 .37684 Mdot
.25324 .48265 Mdot
.46152 .38089 Mdot
.4109 .8107 Mdot
.32664 .69299 Mdot
.34011 .48878 Mdot
.48388 .40051 Mdot
.77441 .55817 Mdot
.62918 .59552 Mdot
.44557 .56348 Mdot
.5128 .59939 Mdot
.46169 .63036 Mdot
.63585 .61854 Mdot
.49356 .39394 Mdot
.45284 .62652 Mdot
.7145 .47278 Mdot
.48401 .34672 Mdot
.52886 .3425 Mdot
.3717 .45596 Mdot
.50863 .62878 Mdot
.49202 .25644 Mdot
.50033 .61275 Mdot
.47834 .67389 Mdot
.35717 .44101 Mdot
.52239 .39015 Mdot
.59945 .60523 Mdot
.64619 .58343 Mdot
.48991 .4179 Mdot
.36577 .56251 Mdot
.33729 .45683 Mdot
.66882 .57187 Mdot
.7283 .74756 Mdot
.52788 .30667 Mdot
.3251 .70217 Mdot
.53497 .25444 Mdot
.46991 .66713 Mdot
.52393 .40541 Mdot
.31379 .49107 Mdot
.62999 .6326 Mdot
.63804 .5821 Mdot
.46007 .36289 Mdot
.47932 .62728 Mdot
.7076 .48198 Mdot
.62169 .57991 Mdot
.5511 .52419 Mdot
.5031 .3605 Mdot
.26723 .57685 Mdot
.61536 .58158 Mdot
.31402 .77275 Mdot
.77045 .56515 Mdot
.3489 .47606 Mdot
.54988 .362 Mdot
.33191 .51164 Mdot
.71523 .44091 Mdot
.6543 .63363 Mdot
.4802 .62599 Mdot
.49043 .47097 Mdot
.71666 .26959 Mdot
.60823 .62322 Mdot
.3265 .48368 Mdot
.52165 .41227 Mdot
.5184 .46829 Mdot
.47222 .36886 Mdot
.62213 .34412 Mdot
.77081 .44205 Mdot
.46812 .61302 Mdot
.48339 .66818 Mdot
.55693 .37298 Mdot
.73815 .44234 Mdot
.6259 .57181 Mdot
.62486 .61946 Mdot
.364 .16909 Mdot
.30954 .67673 Mdot
.76439 .40346 Mdot
.51192 .41658 Mdot
.62092 .63948 Mdot
.41824 .30905 Mdot
.51388 .65073 Mdot
.47093 .41379 Mdot
.59738 .63801 Mdot
.44141 .78566 Mdot
.46775 .5579 Mdot
.50171 .36893 Mdot
.48873 .31717 Mdot
.49952 .65626 Mdot
.45344 .57757 Mdot
.58901 .5954 Mdot
.46517 .40324 Mdot
.51504 .61316 Mdot
.36458 .7609 Mdot
.68997 .24679 Mdot
.32559 .47647 Mdot
.6553 .60945 Mdot
.46117 .63246 Mdot
.48796 .30323 Mdot
.72722 .46981 Mdot
.64258 .6189 Mdot
.58783 .62924 Mdot
.53867 .35591 Mdot
.55312 .34464 Mdot
.5423 .30842 Mdot
.3391 .47695 Mdot
.49491 .63396 Mdot
.55845 .36213 Mdot
.38666 .61099 Mdot
.54336 .39651 Mdot
.49249 .63164 Mdot
.1005 .45191 Mdot
.47308 .34431 Mdot
.47672 .38157 Mdot
.64837 .42747 Mdot
.33427 .45025 Mdot
.34143 .50107 Mdot
.38228 .59719 Mdot
.51085 .41674 Mdot
.62345 .52467 Mdot
.32246 .47888 Mdot
.33589 .45771 Mdot
.65019 .53351 Mdot
.53255 .35633 Mdot
.43826 .61561 Mdot
.48257 .63175 Mdot
.45962 .63248 Mdot
.32663 .50512 Mdot
.4432 .38194 Mdot
.47002 .67734 Mdot
.23804 .35031 Mdot
.59426 .62265 Mdot
.35921 .56629 Mdot
.3088 .49745 Mdot
.62775 .51251 Mdot
.49213 .62149 Mdot
.36979 .82832 Mdot
.61838 .41945 Mdot
.5012 .42577 Mdot
.52931 .39284 Mdot
.72566 .46017 Mdot
.53657 .45284 Mdot
.31985 .6703 Mdot
.48696 .64473 Mdot
.71229 .65535 Mdot
.33113 .47052 Mdot
.47522 .37704 Mdot
.64185 .25503 Mdot
.23572 .63034 Mdot
.24997 .54155 Mdot
.31421 .45384 Mdot
.33259 .4643 Mdot
.58354 .60809 Mdot
.59656 .62813 Mdot
.51449 .37102 Mdot
.48938 .65102 Mdot
.28433 .46803 Mdot
.50144 .63576 Mdot
.61562 .6203 Mdot
.59505 .61568 Mdot
.31874 .69343 Mdot
.45255 .34806 Mdot
.62146 .62644 Mdot
.38425 .76347 Mdot
.38921 .60599 Mdot
.37802 .47401 Mdot
.8523 .44723 Mdot
.21797 .6295 Mdot
.6612 .41719 Mdot
.73001 .47373 Mdot
.33069 .65675 Mdot
.48843 .61631 Mdot
.55595 .37607 Mdot
.4972 .40657 Mdot
.32528 .67408 Mdot
.47214 .62181 Mdot
.71796 .44895 Mdot
.49136 .62011 Mdot
.69509 .45521 Mdot
.5874 .58258 Mdot
.55332 .34816 Mdot
.46817 .36755 Mdot
.46404 .65231 Mdot
.59208 .60088 Mdot
.61115 .6318 Mdot
.73901 .46496 Mdot
.68271 .27639 Mdot
.62171 .6127 Mdot
.30923 .49819 Mdot
.43473 .25332 Mdot
.32839 .67042 Mdot
.48735 .39144 Mdot
.66218 .25803 Mdot
.28656 .30244 Mdot
.53323 .40452 Mdot
.34114 .68732 Mdot
.38518 .15792 Mdot
.54274 .34042 Mdot
.34489 .19797 Mdot
.31941 .68957 Mdot
.35339 .45715 Mdot
.60562 .5903 Mdot
.32491 .66738 Mdot
.47131 .31123 Mdot
.76465 .46309 Mdot
.57105 .38148 Mdot
.30952 .45234 Mdot
.35421 .45093 Mdot
.40859 .52141 Mdot
.41619 .81157 Mdot
.69406 .44499 Mdot
.71474 .45348 Mdot
.62349 .59983 Mdot
.43617 .70284 Mdot
.53272 .42827 Mdot
.71749 .45484 Mdot
.73697 .65217 Mdot
.54645 .37928 Mdot
.75836 .37792 Mdot
.64768 .48105 Mdot
.35319 .46674 Mdot
.39903 .4741 Mdot
.6262 .59706 Mdot
.32666 .48307 Mdot
.48261 .49633 Mdot
.46005 .38717 Mdot
.32976 .47399 Mdot
.49369 .62949 Mdot
.53844 .76082 Mdot
.35126 .49551 Mdot
.5248 .52262 Mdot
.48026 .63394 Mdot
.66804 .45206 Mdot
.65789 .35453 Mdot
.79787 .70982 Mdot
.48806 .64625 Mdot
.60233 .59542 Mdot
.6191 .62875 Mdot
.62643 .61077 Mdot
.30581 .45452 Mdot
.63208 .58729 Mdot
.3377 .48624 Mdot
.58175 .57231 Mdot
.711 .29618 Mdot
.71129 .46524 Mdot
.47744 .69506 Mdot
.31458 .46604 Mdot
.30939 .60718 Mdot
.83058 .40704 Mdot
.52552 .38177 Mdot
.50417 .61094 Mdot
.69369 .43859 Mdot
.36976 .67653 Mdot
.72606 .45546 Mdot
.60188 .59286 Mdot
.35743 .56714 Mdot
.50054 .38723 Mdot
.27712 .42723 Mdot
.69555 .47169 Mdot
.30923 .45433 Mdot
.49707 .33991 Mdot
.56057 .60733 Mdot
.73324 .45607 Mdot
.72686 .47463 Mdot
.48769 .37829 Mdot
.35825 .47446 Mdot
.59522 .61067 Mdot
.48339 .61306 Mdot
.68031 .4857 Mdot
.44893 .34569 Mdot
.53382 .3905 Mdot
.45475 .38827 Mdot
.42731 .56566 Mdot
.80833 .56069 Mdot
.48171 .64005 Mdot
.61223 .26801 Mdot
.61046 .62781 Mdot
.62889 .29671 Mdot
.31206 .62839 Mdot
.50507 .68345 Mdot
.32535 .69313 Mdot
.3281 .69375 Mdot
.49744 .37208 Mdot
.79536 .59476 Mdot
.25036 .51992 Mdot
.52603 .64008 Mdot
.33602 .6729 Mdot
.61026 .63182 Mdot
.28874 .49876 Mdot
.41415 .45687 Mdot
.52262 .33033 Mdot
.45466 .63698 Mdot
.62084 .61788 Mdot
.7128 .70899 Mdot
.70341 .46147 Mdot
.36018 .60072 Mdot
.50189 .34997 Mdot
.49302 .38366 Mdot
.47185 .64244 Mdot
.4899 .63678 Mdot
.2448 .55803 Mdot
.40913 .53312 Mdot
.56455 .78891 Mdot
.43548 .62222 Mdot
.73327 .69393 Mdot
.28126 .44776 Mdot
.30888 .49055 Mdot
.31422 .69103 Mdot
.46681 .67523 Mdot
.47922 .38901 Mdot
.35122 .45503 Mdot
.25254 .54027 Mdot
.36534 .44266 Mdot
.74894 .37122 Mdot
.63577 .521 Mdot
.49597 .34753 Mdot
.29589 .48397 Mdot
.32782 .48079 Mdot
.31853 .51039 Mdot
.34252 .67919 Mdot
.51087 .40132 Mdot
.53238 .38635 Mdot
.53922 .33962 Mdot
.50086 .46599 Mdot
.50032 .36229 Mdot
.31919 .63228 Mdot
.37934 .65356 Mdot
.70572 .60909 Mdot
.52864 .41202 Mdot
.47283 .62441 Mdot
.55655 .38923 Mdot
.74002 .44683 Mdot
.53146 .41192 Mdot
.77148 .39715 Mdot
.47924 .65135 Mdot
.4195 .40822 Mdot
.6705 .60885 Mdot
.50303 .34867 Mdot
.69656 .47828 Mdot
.80631 .56578 Mdot
.62969 .24485 Mdot
.37995 .7496 Mdot
.30985 .49887 Mdot
.56936 .60039 Mdot
.5179 .63642 Mdot
.60102 .60526 Mdot
.48281 .41973 Mdot
.32555 .70077 Mdot
.19327 .62375 Mdot
.60902 .50595 Mdot
.47942 .39214 Mdot
.4389 .40096 Mdot
.35149 .48104 Mdot
.62992 .5931 Mdot
.3303 .42754 Mdot
.51759 .35888 Mdot
.71738 .43943 Mdot
.72053 .43759 Mdot
.4396 .48891 Mdot
.68457 .70765 Mdot
.61556 .36455 Mdot
.47398 .64174 Mdot
.64068 .58404 Mdot
.68207 .46793 Mdot
.24035 .49746 Mdot
.51969 .63466 Mdot
.46987 .66696 Mdot
.50831 .63004 Mdot
.49011 .35129 Mdot
.31404 .68582 Mdot
.71223 .68176 Mdot
.34095 .67056 Mdot
.50567 .34553 Mdot
.58414 .62503 Mdot
.3245 .667 Mdot
.72843 .45755 Mdot
.47363 .67264 Mdot
.60481 .62743 Mdot
.49258 .36762 Mdot
.31989 .47539 Mdot
.61782 .25739 Mdot
.79408 .45149 Mdot
.64798 .5524 Mdot
.6452 .55062 Mdot
.31858 .4455 Mdot
.51803 .83632 Mdot
.52755 .65966 Mdot
.3331 .26407 Mdot
.73424 .48714 Mdot
.49092 .41877 Mdot
.48687 .16794 Mdot
.59235 .5915 Mdot
.63877 .60452 Mdot
.50539 .36661 Mdot
.64739 .62118 Mdot
.47375 .37432 Mdot
.58291 .60241 Mdot
.48048 .81259 Mdot
.50397 .32994 Mdot
.63813 .60277 Mdot
.52584 .43206 Mdot
.51948 .34905 Mdot
.35347 .47825 Mdot
.63971 .62368 Mdot
.50648 .42669 Mdot
.18251 .6199 Mdot
.47439 .66292 Mdot
.34194 .67627 Mdot
.45091 .69859 Mdot
.50215 .62169 Mdot
.34402 .47143 Mdot
.54384 .33923 Mdot
.71144 .47158 Mdot
.3104 .47377 Mdot
.56049 .61642 Mdot
.68966 .46719 Mdot
.37335 .60834 Mdot
.31446 .50062 Mdot
.32124 .6741 Mdot
.70673 .47394 Mdot
.57253 .37611 Mdot
.63406 .61432 Mdot
.81316 .47908 Mdot
.34046 .67084 Mdot
.50207 .39338 Mdot
.65367 .58437 Mdot
.49255 .62046 Mdot
.51345 .37765 Mdot
.64467 .59785 Mdot
.34275 .6826 Mdot
.51237 .33864 Mdot
.50757 .33751 Mdot
.42396 .45873 Mdot
.31073 .55614 Mdot
.71558 .46771 Mdot
.35955 .44473 Mdot
.51975 .37128 Mdot
.73911 .44239 Mdot
.55121 .70069 Mdot
.55551 .39849 Mdot
.3397 .50778 Mdot
.51097 .47517 Mdot
.59421 .62813 Mdot
.49634 .66485 Mdot
.65063 .59192 Mdot
.72367 .47726 Mdot
.6844 .21414 Mdot
.31219 .68163 Mdot
.44 .37537 Mdot
.45919 .3887 Mdot
.62892 .64595 Mdot
.33169 .47812 Mdot
.53696 .78625 Mdot
.50561 .41655 Mdot
.44777 .41797 Mdot
.48585 .38466 Mdot
.76625 .56656 Mdot
.33437 .45569 Mdot
.48579 .38845 Mdot
.43861 .42022 Mdot
.56968 .38898 Mdot
.69898 .4808 Mdot
.6791 .34041 Mdot
.55408 .39118 Mdot
.14138 .65436 Mdot
.33833 .69581 Mdot
.62808 .61635 Mdot
.51066 .55193 Mdot
.64774 .67462 Mdot
.33909 .22135 Mdot
.33884 .48192 Mdot
.57871 .3085 Mdot
.59743 .6083 Mdot
.60724 .23104 Mdot
.47987 .84259 Mdot
.51675 .34719 Mdot
.47339 .39447 Mdot
.60193 .59286 Mdot
.62556 .63761 Mdot
.32845 .69884 Mdot
.51905 .42089 Mdot
.4446 .40647 Mdot
.6439 .63003 Mdot
.49207 .36103 Mdot
.24734 .38588 Mdot
.4857 .60724 Mdot
.33466 .50388 Mdot
.49182 .66599 Mdot
.46561 .66226 Mdot
.42227 .21985 Mdot
.39722 .57019 Mdot
.49177 .6333 Mdot
.51894 .65931 Mdot
.77684 .39903 Mdot
.49936 .47517 Mdot
.68781 .47535 Mdot
.64465 .74473 Mdot
.62505 .60454 Mdot
.51199 .40245 Mdot
.29671 .46204 Mdot
.34955 .23699 Mdot
.49738 .75752 Mdot
.34641 .57657 Mdot
.52917 .38194 Mdot
.63028 .59926 Mdot
.34421 .67953 Mdot
.51065 .32986 Mdot
.62173 .29074 Mdot
.49671 .38181 Mdot
.60272 .63377 Mdot
.44485 .21739 Mdot
.30095 .42107 Mdot
.44226 .61356 Mdot
.36166 .50465 Mdot
.56273 .37136 Mdot
.32321 .49843 Mdot
.46808 .62812 Mdot
.73219 .43694 Mdot
.72023 .4611 Mdot
.48719 .3473 Mdot
.39556 .52517 Mdot
.68818 .4997 Mdot
.51949 .35047 Mdot
.53601 .35498 Mdot
.32267 .69103 Mdot
.53503 .35408 Mdot
.46241 .3952 Mdot
.5594 .37568 Mdot
.53621 .41717 Mdot
.47677 .67428 Mdot
.39107 .40776 Mdot
.54345 .40521 Mdot
.5216 .30436 Mdot
.45921 .62215 Mdot
.51871 .29099 Mdot
.49124 .65904 Mdot
.62078 .77998 Mdot
.49897 .65066 Mdot
.71834 .46233 Mdot
.63377 .57102 Mdot
.56081 .28818 Mdot
.2852 .46608 Mdot
.45339 .64381 Mdot
.70132 .45281 Mdot
.48677 .64903 Mdot
.61609 .57419 Mdot
.83783 .45107 Mdot
.34252 .43673 Mdot
.46529 .56414 Mdot
.63161 .43604 Mdot
.26502 .57518 Mdot
.58995 .62246 Mdot
.34776 .46242 Mdot
.27087 .43519 Mdot
.55784 .36899 Mdot
.71791 .47106 Mdot
.4967 .37375 Mdot
.48004 .67274 Mdot
.62895 .60248 Mdot
.60807 .54946 Mdot
.71732 .46746 Mdot
.7562 .29104 Mdot
.57838 .62419 Mdot
.50633 .31987 Mdot
.45801 .62194 Mdot
.84657 .43726 Mdot
.49832 .65379 Mdot
.70598 .28956 Mdot
.29649 .51908 Mdot
.46312 .213 Mdot
.32604 .46258 Mdot
.23305 .52481 Mdot
.5782 .84305 Mdot
.48341 .83436 Mdot
.31132 .48017 Mdot
.67127 .57687 Mdot
.4979 .35448 Mdot
.54787 .39085 Mdot
.5643 .33157 Mdot
.38028 .47459 Mdot
.51593 .36537 Mdot
.32066 .67092 Mdot
.40282 .57232 Mdot
.77043 .60519 Mdot
.57836 .58612 Mdot
.47253 .37437 Mdot
.45635 .64964 Mdot
.50385 .66594 Mdot
.33116 .66649 Mdot
.50429 .61842 Mdot
.52517 .35356 Mdot
.31735 .46442 Mdot
.6221 .49912 Mdot
.72399 .4447 Mdot
.3035 .73654 Mdot
.69648 .4892 Mdot
.58785 .57243 Mdot
.54658 .31728 Mdot
.59461 .61622 Mdot
.57767 .16068 Mdot
.55297 .38119 Mdot
.3218 .48131 Mdot
.49743 .34173 Mdot
.56062 .3731 Mdot
.54125 .40365 Mdot
.64422 .59259 Mdot
.50988 .55693 Mdot
.48995 .36304 Mdot
.48366 .62447 Mdot
.6649 .54767 Mdot
.54209 .33453 Mdot
.6756 .68076 Mdot
.73527 .36819 Mdot
.2797 .5864 Mdot
.37499 .48526 Mdot
.61218 .59369 Mdot
.33136 .46786 Mdot
.38304 .47866 Mdot
.3441 .47163 Mdot
.70496 .66832 Mdot
.58512 .29279 Mdot
.31316 .2179 Mdot
.41354 .29685 Mdot
.35461 .24162 Mdot
.33204 .44228 Mdot
.57259 .71156 Mdot
.31112 .48939 Mdot
.34192 .47774 Mdot
.17707 .31747 Mdot
.30176 .48095 Mdot
.49139 .3999 Mdot
.47987 .33477 Mdot
.26947 .65726 Mdot
.77218 .38449 Mdot
.53093 .41144 Mdot
.51579 .36812 Mdot
.70157 .43868 Mdot
.45052 .44253 Mdot
.3416 .66615 Mdot
.36872 .58506 Mdot
.35684 .6756 Mdot
.48843 .37767 Mdot
.50948 .3645 Mdot
.45465 .40568 Mdot
.57951 .84714 Mdot
.34186 .23542 Mdot
.34794 .44908 Mdot
.4594 .31293 Mdot
.36997 .78128 Mdot
.46575 .36207 Mdot
.47355 .35143 Mdot
.53175 .34164 Mdot
.59852 .60629 Mdot
.28518 .49607 Mdot
.45833 .42867 Mdot
.26772 .60834 Mdot
.50458 .35177 Mdot
.54044 .64289 Mdot
.66383 .44657 Mdot
.49349 .39497 Mdot
.3273 .50963 Mdot
.54264 .38553 Mdot
.3018 .49319 Mdot
.33137 .50403 Mdot
.4451 .36209 Mdot
.70493 .68962 Mdot
.30463 .51312 Mdot
.51051 .34207 Mdot
.59516 .60039 Mdot
.43479 .82806 Mdot
.50099 .39473 Mdot
.69763 .44396 Mdot
.52583 .40484 Mdot
.70338 .48112 Mdot
.53027 .34633 Mdot
.34381 .67388 Mdot
.31538 .30638 Mdot
.6168 .60012 Mdot
.68694 .48946 Mdot
.63512 .63529 Mdot
.46068 .47396 Mdot
.36172 .47554 Mdot
.3454 .6683 Mdot
.29408 .25946 Mdot
.32158 .68999 Mdot
.59974 .25514 Mdot
.48203 .74047 Mdot
.4636 .65664 Mdot
.30434 .50203 Mdot
.56254 .25943 Mdot
.66597 .69665 Mdot
.57921 .63896 Mdot
.57666 .63443 Mdot
.61889 .18827 Mdot
.44757 .15244 Mdot
.4857 .36547 Mdot
.82989 .52036 Mdot
.31833 .34935 Mdot
.55768 .409 Mdot
.55471 .42442 Mdot
.59232 .63308 Mdot
.56338 .36916 Mdot
.51383 .51695 Mdot
.61124 .61725 Mdot
.70621 .45327 Mdot
.33773 .49095 Mdot
.72376 .47417 Mdot
.58265 .77286 Mdot
.38725 .62514 Mdot
.61322 .62548 Mdot
.54598 .40845 Mdot
.48157 .36078 Mdot
.2967 .49238 Mdot
.24675 .44585 Mdot
.34147 .49878 Mdot
.68691 .45347 Mdot
.61196 .60888 Mdot
.31884 .25773 Mdot
.51937 .40949 Mdot
.30702 .4657 Mdot
.63801 .64858 Mdot
.52722 .39463 Mdot
.46198 .64721 Mdot
.53017 .38182 Mdot
.30419 .47673 Mdot
.53479 .35332 Mdot
.32002 .46444 Mdot
.58923 .59852 Mdot
.46574 .38333 Mdot
.51013 .36704 Mdot
.58151 .2401 Mdot
.71821 .44822 Mdot
.36134 .46881 Mdot
.50694 .51783 Mdot
.46228 .37741 Mdot
.62239 .29491 Mdot
.54944 .34455 Mdot
.58497 .33672 Mdot
.50434 .43808 Mdot
.31897 .67324 Mdot
.47211 .4168 Mdot
.50034 .39355 Mdot
.34923 .40511 Mdot
.39823 .34446 Mdot
.40587 .46263 Mdot
.45115 .6496 Mdot
.32861 .509 Mdot
.62417 .62751 Mdot
.62421 .63419 Mdot
.62511 .58338 Mdot
.76093 .35993 Mdot
.44717 .34679 Mdot
.50248 .38776 Mdot
.46708 .61302 Mdot
.71422 .45586 Mdot
.30734 .4576 Mdot
.7126 .46112 Mdot
.36958 .58122 Mdot
.68609 .46212 Mdot
.31694 .67277 Mdot
.77136 .56464 Mdot
.23742 .36664 Mdot
.69186 .45196 Mdot
.34026 .50001 Mdot
.62499 .52102 Mdot
.49541 .4211 Mdot
.41518 .77981 Mdot
.71614 .43909 Mdot
.65276 .20979 Mdot
.50361 .33419 Mdot
.51113 .52332 Mdot
.48423 .66143 Mdot
.71765 .47625 Mdot
.51005 .6301 Mdot
.54562 .38556 Mdot
.21762 .56722 Mdot
.32265 .48595 Mdot
.48612 .60404 Mdot
.49282 .42703 Mdot
.72227 .47468 Mdot
.61806 .62567 Mdot
.59532 .44535 Mdot
.46414 .62578 Mdot
.61847 .24767 Mdot
.62939 .29009 Mdot
.61106 .61083 Mdot
.20426 .38291 Mdot
.5102 .6443 Mdot
.54955 .40927 Mdot
.59709 .32697 Mdot
.53844 .38213 Mdot
.62021 .63189 Mdot
.63893 .59667 Mdot
.29287 .66957 Mdot
.49037 .34723 Mdot
.5121 .33316 Mdot
.2777 .47009 Mdot
.60594 .62266 Mdot
.34421 .4644 Mdot
.29017 .49073 Mdot
.5991 .59498 Mdot
.34926 .47388 Mdot
.6971 .47279 Mdot
.40619 .56301 Mdot
.50917 .64489 Mdot
.46797 .63255 Mdot
.61983 .62702 Mdot
.61297 .57293 Mdot
.59535 .61823 Mdot
.52923 .3774 Mdot
.33601 .45282 Mdot
.54757 .36547 Mdot
.55357 .393 Mdot
.2826 .5149 Mdot
.31454 .4486 Mdot
.54793 .37293 Mdot
.65814 .51755 Mdot
.74836 .45933 Mdot
.63772 .60137 Mdot
.49988 .63457 Mdot
.57123 .22977 Mdot
.48565 .60587 Mdot
.47793 .34988 Mdot
.43805 .78669 Mdot
.30866 .45376 Mdot
.72642 .45691 Mdot
.68419 .43294 Mdot
.72185 .46526 Mdot
.48597 .60391 Mdot
.29667 .49931 Mdot
.37516 .60893 Mdot
.47518 .35624 Mdot
.42633 .56531 Mdot
.5946 .26318 Mdot
.3007 .62463 Mdot
.49385 .63147 Mdot
.52371 .38025 Mdot
.3195 .6881 Mdot
.2712 .32455 Mdot
.50201 .38088 Mdot
.47502 .41658 Mdot
.73473 .53778 Mdot
.52322 .30491 Mdot
.37507 .4625 Mdot
.41669 .50393 Mdot
.46802 .39697 Mdot
.41107 .46085 Mdot
.29534 .20071 Mdot
.50338 .33486 Mdot
.5095 .35824 Mdot
.50442 .40637 Mdot
.55485 .37462 Mdot
.35364 .50219 Mdot
.73033 .51763 Mdot
.45466 .64842 Mdot
.41227 .56119 Mdot
.50868 .63544 Mdot
.63882 .61028 Mdot
.52855 .51176 Mdot
.31231 .50621 Mdot
.72317 .46449 Mdot
.84451 .48182 Mdot
.37981 .56418 Mdot
.58373 .60925 Mdot
.37859 .21046 Mdot
.72392 .44281 Mdot
.49397 .41966 Mdot
.74238 .4642 Mdot
.61412 .64123 Mdot
.48174 .62802 Mdot
.46708 .35448 Mdot
.29829 .45623 Mdot
.34874 .4985 Mdot
.52354 .37634 Mdot
.38634 .80408 Mdot
.49965 .62125 Mdot
.56762 .66098 Mdot
.49225 .34962 Mdot
.4745 .41592 Mdot
.34119 .49474 Mdot
.63118 .59485 Mdot
.46731 .72968 Mdot
.70905 .44716 Mdot
.50831 .43142 Mdot
.54414 .38726 Mdot
.38157 .576 Mdot
.46197 .6723 Mdot
.3361 .68229 Mdot
.49199 .3482 Mdot
.39476 .57373 Mdot
.49624 .34452 Mdot
.49419 .45695 Mdot
.59192 .60948 Mdot
.48564 .32645 Mdot
.48029 .40486 Mdot
.47255 .28138 Mdot
.51159 .64624 Mdot
.32731 .47803 Mdot
.28078 .50685 Mdot
.33833 .69145 Mdot
.46709 .65424 Mdot
.54521 .37596 Mdot
.48801 .67011 Mdot
.54433 .39877 Mdot
.49253 .36443 Mdot
.4937 .63091 Mdot
.34545 .46514 Mdot
.53657 .78063 Mdot
.38009 .41253 Mdot
.54759 .35132 Mdot
.53202 .4006 Mdot
.76318 .37033 Mdot
.23169 .33247 Mdot
.48889 .41104 Mdot
.32492 .45021 Mdot
.52596 .39332 Mdot
.46292 .63542 Mdot
.68586 .45717 Mdot
.31781 .47935 Mdot
.60123 .57518 Mdot
.59267 .59329 Mdot
.67045 .61375 Mdot
.3138 .67756 Mdot
.50417 .41939 Mdot
.35143 .43728 Mdot
.31106 .44817 Mdot
.34888 .70948 Mdot
.62937 .61591 Mdot
.68717 .47166 Mdot
.52703 .3377 Mdot
.60061 .43726 Mdot
.46003 .65987 Mdot
.14552 .65923 Mdot
.37602 .61627 Mdot
.70647 .48579 Mdot
.3546 .54622 Mdot
.31895 .68245 Mdot
.47662 .39117 Mdot
.74133 .44993 Mdot
.60885 .58032 Mdot
.54802 .38856 Mdot
.48937 .30841 Mdot
.65368 .70344 Mdot
.5785 .589 Mdot
.49296 .66766 Mdot
.60248 .57912 Mdot
.71893 .48178 Mdot
.31823 .6715 Mdot
.35646 .48012 Mdot
.49621 .3905 Mdot
.48264 .29081 Mdot
.62951 .60981 Mdot
.34639 .6801 Mdot
.49744 .34634 Mdot
.33969 .50596 Mdot
.63519 .59106 Mdot
.484 .37829 Mdot
.31717 .27522 Mdot
.27846 .5161 Mdot
.61955 .6065 Mdot
.45728 .38548 Mdot
.48287 .4757 Mdot
.58356 .59067 Mdot
.58816 .63148 Mdot
.51548 .36524 Mdot
.70453 .47439 Mdot
.4685 .38307 Mdot
.49313 .65441 Mdot
.51018 .55686 Mdot
.46434 .64688 Mdot
.61131 .27207 Mdot
.46184 .3477 Mdot
.26065 .55603 Mdot
.29242 .47664 Mdot
.71432 .42675 Mdot
.35282 .39965 Mdot
.47327 .41218 Mdot
.59221 .7992 Mdot
.62191 .51262 Mdot
.36667 .70196 Mdot
.71051 .74799 Mdot
.69891 .44839 Mdot
.48496 .65286 Mdot
.51064 .35863 Mdot
.4627 .68443 Mdot
.69333 .46043 Mdot
.60795 .26851 Mdot
.45859 .38894 Mdot
.33387 .45665 Mdot
.49987 .3521 Mdot
.30867 .49822 Mdot
.52695 .39918 Mdot
.45801 .3247 Mdot
.75188 .4661 Mdot
.70212 .28549 Mdot
.50168 .42186 Mdot
.84895 .47504 Mdot
.56932 .47586 Mdot
.711 .44072 Mdot
.54204 .35008 Mdot
.3291 .67727 Mdot
.48842 .62006 Mdot
.81077 .52413 Mdot
.59587 .61193 Mdot
.49375 .63912 Mdot
.3423 .49031 Mdot
.65296 .58895 Mdot
.34046 .69139 Mdot
.5797 .29291 Mdot
.72855 .47166 Mdot
.47174 .66075 Mdot
.49781 .3942 Mdot
.47881 .34773 Mdot
.77341 .55689 Mdot
.17579 .44379 Mdot
.2805 .47516 Mdot
.72633 .27213 Mdot
.36463 .45242 Mdot
.71737 .45168 Mdot
.59167 .61253 Mdot
.48491 .40057 Mdot
.50586 .37557 Mdot
.63244 .62498 Mdot
.33757 .4505 Mdot
.66148 .59171 Mdot
.40999 .21393 Mdot
.52259 .60425 Mdot
.69729 .3147 Mdot
.31507 .48283 Mdot
.69675 .31014 Mdot
.70558 .48463 Mdot
.69881 .71342 Mdot
.67739 .39366 Mdot
.47222 .6649 Mdot
.697 .31915 Mdot
.30362 .46044 Mdot
.48299 .3681 Mdot
.32328 .67334 Mdot
.32218 .69523 Mdot
.32977 .49833 Mdot
.60535 .59271 Mdot
.72622 .4706 Mdot
.50447 .35847 Mdot
.32118 .60254 Mdot
.23605 .64889 Mdot
.64229 .58547 Mdot
.44747 .42903 Mdot
.50345 .62413 Mdot
.53084 .39519 Mdot
.70942 .43632 Mdot
.48626 .63906 Mdot
.30805 .67996 Mdot
.40814 .55629 Mdot
.52761 .33741 Mdot
.44191 .48347 Mdot
.4729 .65839 Mdot
.21246 .35093 Mdot
.50989 .36974 Mdot
.51035 .64436 Mdot
.57026 .31827 Mdot
.22748 .5817 Mdot
.64234 .48859 Mdot
.50368 .83466 Mdot
.56809 .61734 Mdot
.59669 .58982 Mdot
.17496 .55004 Mdot
.73788 .48504 Mdot
.45585 .63953 Mdot
.32168 .66894 Mdot
.6784 .362 Mdot
.51342 .63809 Mdot
.47821 .34313 Mdot
.54448 .34084 Mdot
.41055 .22104 Mdot
.55747 .48857 Mdot
.34599 .69011 Mdot
.59689 .38258 Mdot
.53317 .36304 Mdot
.57214 .36186 Mdot
.51727 .38156 Mdot
.35347 .45068 Mdot
.51548 .63979 Mdot
.86926 .51481 Mdot
.51369 .65413 Mdot
.33249 .6014 Mdot
.62542 .60429 Mdot
.64732 .59146 Mdot
.49226 .39375 Mdot
.25729 .5333 Mdot
.81058 .57017 Mdot
.52519 .40945 Mdot
.6719 .44274 Mdot
.62891 .2859 Mdot
.54889 .33797 Mdot
.27947 .49512 Mdot
.45206 .42562 Mdot
.36902 .47619 Mdot
.48574 .63533 Mdot
.69719 .44987 Mdot
.75267 .44863 Mdot
.4847 .65749 Mdot
.50554 .388 Mdot
.69483 .42427 Mdot
.49079 .38478 Mdot
.48459 .36019 Mdot
.36145 .58972 Mdot
.68255 .44685 Mdot
.59522 .62024 Mdot
.71974 .46315 Mdot
.34095 .47622 Mdot
.13192 .37651 Mdot
.70559 .46476 Mdot
.51142 .47796 Mdot
.5484 .51722 Mdot
.69474 .31559 Mdot
.34927 .49705 Mdot
.69151 .44631 Mdot
.50651 .65815 Mdot
.35653 .71253 Mdot
.2159 .3655 Mdot
.49786 .60905 Mdot
.5052 .37174 Mdot
.30814 .50303 Mdot
.32491 .44507 Mdot
.51955 .62864 Mdot
.35392 .46643 Mdot
.54251 .32182 Mdot
.50401 .33965 Mdot
.45592 .64039 Mdot
.26427 .6684 Mdot
.516 .64126 Mdot
.58377 .45326 Mdot
.52436 .34079 Mdot
.31998 .48017 Mdot
.58002 .40554 Mdot
.28769 .44573 Mdot
.32059 .69625 Mdot
.53732 .40876 Mdot
.72462 .46669 Mdot
.4616 .54453 Mdot
.62022 .60508 Mdot
.44463 .78807 Mdot
.31239 .50169 Mdot
.46677 .6024 Mdot
.35331 .4801 Mdot
.29183 .45656 Mdot
.51072 .62221 Mdot
.33354 .48201 Mdot
.50786 .35792 Mdot
.45155 .58181 Mdot
.30736 .49372 Mdot
.47249 .64613 Mdot
.72945 .46459 Mdot
.34872 .46974 Mdot
.66195 .60871 Mdot
.47944 .36729 Mdot
.58996 .62557 Mdot
.67478 .4566 Mdot
.31009 .5055 Mdot
.68991 .44924 Mdot
.63025 .61218 Mdot
.7338 .46558 Mdot
.57789 .57275 Mdot
.44665 .66915 Mdot
.34024 .58093 Mdot
.34586 .41707 Mdot
.29476 .46259 Mdot
.5721 .63537 Mdot
.48369 .40418 Mdot
.48382 .35325 Mdot
.73258 .47342 Mdot
.32011 .44481 Mdot
.4299 .82423 Mdot
.5899 .34725 Mdot
.29989 .66764 Mdot
.4585 .67301 Mdot
.66134 .23571 Mdot
.37673 .63253 Mdot
.3641 .71927 Mdot
.53655 .43312 Mdot
.31903 .68117 Mdot
.48539 .38535 Mdot
.6303 .24444 Mdot
.68457 .45749 Mdot
.54035 .73953 Mdot
.53509 .42696 Mdot
.60275 .61594 Mdot
.52026 .40505 Mdot
.82744 .51875 Mdot
.49541 .44676 Mdot
.69797 .44105 Mdot
.45025 .63327 Mdot
.28504 .46637 Mdot
.72319 .44367 Mdot
.58794 .59781 Mdot
.705 .35489 Mdot
.45663 .37657 Mdot
.5287 .35933 Mdot
.58371 .63991 Mdot
.34117 .45858 Mdot
.63695 .61205 Mdot
.50934 .6443 Mdot
.70786 .46245 Mdot
.55564 .36909 Mdot
.53895 .3259 Mdot
.6194 .64638 Mdot
.50575 .66342 Mdot
.63266 .57594 Mdot
.48064 .67062 Mdot
.31899 .67953 Mdot
.50668 .42068 Mdot
.60158 .64455 Mdot
.5677 .40363 Mdot
.41845 .31482 Mdot
.36008 .57966 Mdot
.36107 .38389 Mdot
.5952 .62159 Mdot
.73051 .35131 Mdot
.47803 .65407 Mdot
.489 .6649 Mdot
.47654 .22328 Mdot
.80223 .58146 Mdot
.62408 .52418 Mdot
.83281 .44957 Mdot
.50892 .64438 Mdot
.46837 .6502 Mdot
.61108 .58113 Mdot
.33515 .48671 Mdot
.31998 .52161 Mdot
.65197 .62171 Mdot
.66178 .25829 Mdot
.30706 .45796 Mdot
.56957 .81338 Mdot
.57547 .61121 Mdot
.50671 .43729 Mdot
.34794 .69166 Mdot
.70767 .43869 Mdot
.63658 .25411 Mdot
.83024 .4686 Mdot
.48382 .39566 Mdot
.38997 .18263 Mdot
.61136 .59606 Mdot
.42799 .61832 Mdot
.65792 .74462 Mdot
.46126 .40178 Mdot
.5152 .40527 Mdot
.51121 .38897 Mdot
.69585 .43466 Mdot
.37965 .40073 Mdot
.48181 .39401 Mdot
.71247 .30095 Mdot
.48951 .33021 Mdot
.80958 .49085 Mdot
.71925 .46323 Mdot
.61199 .31829 Mdot
.56547 .61941 Mdot
.28257 .60964 Mdot
.56629 .33614 Mdot
.50631 .65077 Mdot
.62015 .74093 Mdot
.48905 .62663 Mdot
.75002 .66287 Mdot
.6759 .39183 Mdot
.35195 .44862 Mdot
.52906 .38101 Mdot
.58075 .63523 Mdot
.30552 .50013 Mdot
.47868 .73674 Mdot
.17345 .3178 Mdot
.48092 .67512 Mdot
.48706 .12926 Mdot
.48593 .66653 Mdot
.32536 .69729 Mdot
.33608 .49736 Mdot
.37144 .52018 Mdot
.42896 .56314 Mdot
.34459 .46606 Mdot
.67601 .64567 Mdot
.27961 .5018 Mdot
.71495 .3329 Mdot
.29717 .44695 Mdot
.47701 .64753 Mdot
.44611 .63712 Mdot
.52734 .29794 Mdot
.48933 .41014 Mdot
.4061 .57424 Mdot
.58068 .35005 Mdot
.5116 .41688 Mdot
.6111 .61723 Mdot
.22763 .49033 Mdot
.45462 .59895 Mdot
.31486 .49235 Mdot
.45983 .66434 Mdot
.51609 .40598 Mdot
.54676 .35105 Mdot
.56167 .40217 Mdot
.61118 .24055 Mdot
.57208 .81029 Mdot
.48961 .36491 Mdot
.445 .37537 Mdot
.5868 .60514 Mdot
.78782 .53466 Mdot
.78764 .36045 Mdot
.68292 .37134 Mdot
.48522 .34737 Mdot
.72183 .45187 Mdot
.68623 .44743 Mdot
.52291 .31752 Mdot
.28921 .579 Mdot
.6606 .57087 Mdot
.4981 .39444 Mdot
.69769 .40237 Mdot
.65297 .6325 Mdot
.34408 .67293 Mdot
.62904 .61059 Mdot
.31775 .50962 Mdot
.32314 .69312 Mdot
.64347 .59411 Mdot
.28404 .52696 Mdot
.33748 .69128 Mdot
.2374 .59317 Mdot
.68701 .45297 Mdot
.51341 .37814 Mdot
.31174 .42961 Mdot
.63009 .6261 Mdot
.47499 .66178 Mdot
.31818 .46937 Mdot
.46101 .67788 Mdot
.78917 .53634 Mdot
.64345 .2652 Mdot
.31247 .68166 Mdot
.50357 .65175 Mdot
.4218 .52257 Mdot
.72232 .4549 Mdot
.50636 .61817 Mdot
.25014 .53365 Mdot
.54763 .33931 Mdot
.78235 .64192 Mdot
.52616 .36247 Mdot
.34863 .78069 Mdot
.4895 .66366 Mdot
.31394 .69309 Mdot
.49619 .38843 Mdot
.57762 .62151 Mdot
.53247 .29381 Mdot
.49111 .38282 Mdot
.59889 .57908 Mdot
.48537 .36656 Mdot
.71817 .43469 Mdot
.36785 .48759 Mdot
.62274 .50986 Mdot
.61162 .21551 Mdot
.73614 .4579 Mdot
.30441 .6742 Mdot
.50127 .41685 Mdot
.69127 .55113 Mdot
.33929 .46328 Mdot
.46804 .41082 Mdot
.45713 .19679 Mdot
.32863 .49422 Mdot
.33169 .46638 Mdot
.53995 .35809 Mdot
.49401 .60746 Mdot
.6106 .63105 Mdot
.72295 .45735 Mdot
.44151 .71141 Mdot
.48231 .37887 Mdot
.52145 .3782 Mdot
.72464 .44352 Mdot
.46635 .64919 Mdot
.5542 .36819 Mdot
.45546 .75429 Mdot
.37021 .66632 Mdot
.46434 .66142 Mdot
.54827 .33913 Mdot
.79541 .65176 Mdot
.34067 .51933 Mdot
.36393 .18896 Mdot
.72573 .49013 Mdot
.60073 .59684 Mdot
.43769 .38239 Mdot
.1211 .61964 Mdot
.70512 .44046 Mdot
.30122 .6188 Mdot
.4907 .3588 Mdot
.50533 .41303 Mdot
.35981 .47431 Mdot
.54512 .37055 Mdot
.3027 .47825 Mdot
.61477 .21255 Mdot
.85776 .4239 Mdot
.35249 .47836 Mdot
.30374 .48649 Mdot
.39283 .48654 Mdot
.60366 .24526 Mdot
.34025 .48968 Mdot
.45555 .38096 Mdot
.69754 .62428 Mdot
.46758 .32662 Mdot
.6892 .48292 Mdot
.72285 .42592 Mdot
.27365 .46883 Mdot
.19845 .44295 Mdot
.53562 .28856 Mdot
.41938 .437 Mdot
.68009 .49672 Mdot
.49932 .64661 Mdot
.54748 .34569 Mdot
.31491 .67477 Mdot
.63187 .58427 Mdot
.47437 .44449 Mdot
.51062 .37913 Mdot
.30421 .4945 Mdot
.69901 .43255 Mdot
.50847 .62313 Mdot
.51463 .36744 Mdot
.62769 .56544 Mdot
.7066 .45058 Mdot
.30747 .49236 Mdot
.51868 .47897 Mdot
.6896 .47776 Mdot
.55213 .33356 Mdot
.51117 .41606 Mdot
.49786 .34569 Mdot
.56647 .33267 Mdot
.4843 .65903 Mdot
.65586 .60531 Mdot
.48748 .32177 Mdot
.37435 .58749 Mdot
.4807 .54547 Mdot
.49173 .32144 Mdot
.33499 .45175 Mdot
.45424 .64075 Mdot
.3362 .68886 Mdot
.68558 .33204 Mdot
.51109 .33604 Mdot
.58199 .80371 Mdot
.37179 .21889 Mdot
.32869 .68957 Mdot
.35114 .44244 Mdot
.72482 .46076 Mdot
.52973 .35387 Mdot
.68761 .57225 Mdot
.49037 .33889 Mdot
.53888 .46579 Mdot
.60492 .59677 Mdot
.50144 .64096 Mdot
.36737 .67148 Mdot
.63226 .58408 Mdot
.33152 .46738 Mdot
.40736 .83344 Mdot
.29669 .51485 Mdot
.28425 .48503 Mdot
.71276 .68728 Mdot
.48785 .63325 Mdot
.13401 .64143 Mdot
.22866 .33428 Mdot
.49287 .33613 Mdot
.47097 .62757 Mdot
.33093 .50126 Mdot
.52741 .37277 Mdot
.29804 .46113 Mdot
.29359 .50358 Mdot
.55763 .38833 Mdot
.50006 .41364 Mdot
.6904 .27781 Mdot
.56568 .82582 Mdot
.71593 .47117 Mdot
.35269 .45675 Mdot
.38314 .23325 Mdot
.48038 .39408 Mdot
.47459 .35742 Mdot
.64401 .71763 Mdot
.69599 .44313 Mdot
.25775 .37474 Mdot
.48863 .35183 Mdot
.4662 .19752 Mdot
.51755 .41704 Mdot
.37822 .43911 Mdot
.50023 .60613 Mdot
.29466 .58603 Mdot
.61739 .63256 Mdot
.32719 .51385 Mdot
.70671 .48063 Mdot
.33314 .51447 Mdot
.46044 .22151 Mdot
.48502 .63153 Mdot
.30411 .47664 Mdot
.63851 .57482 Mdot
.47353 .63542 Mdot
.47324 .66596 Mdot
.6625 .54752 Mdot
.65153 .58891 Mdot
.70818 .43197 Mdot
.49447 .62472 Mdot
.33893 .26024 Mdot
.47916 .64463 Mdot
.39766 .22985 Mdot
.46827 .39324 Mdot
.70211 .29653 Mdot
.36245 .63415 Mdot
.55227 .31427 Mdot
.51415 .63394 Mdot
.70231 .46959 Mdot
.54058 .37905 Mdot
.35313 .46368 Mdot
.70151 .46355 Mdot
.51982 .66149 Mdot
.61927 .57121 Mdot
.29809 .45046 Mdot
.46218 .61798 Mdot
.3006 .47228 Mdot
.63019 .26657 Mdot
.57967 .57674 Mdot
.65063 .47299 Mdot
.4395 .56191 Mdot
.55145 .40942 Mdot
.41026 .45877 Mdot
.46121 .37685 Mdot
.50618 .37991 Mdot
.62038 .60655 Mdot
.75905 .35787 Mdot
.34866 .46758 Mdot
.27108 .71651 Mdot
.4998 .65653 Mdot
.41309 .50843 Mdot
.57663 .44361 Mdot
.54314 .39814 Mdot
.31202 .49517 Mdot
.2898 .49883 Mdot
.39761 .34539 Mdot
.63476 .62316 Mdot
.49597 .31399 Mdot
.53952 .31292 Mdot
.44576 .34792 Mdot
.48264 .66744 Mdot
.47765 .76091 Mdot
.64697 .60395 Mdot
.40376 .14442 Mdot
.63805 .60042 Mdot
.70658 .53722 Mdot
.33287 .48302 Mdot
.68774 .46902 Mdot
.47281 .36197 Mdot
.40032 .41028 Mdot
.3598 .49442 Mdot
.67028 .58249 Mdot
.72768 .45911 Mdot
.51188 .77249 Mdot
.49147 .63565 Mdot
.46434 .39409 Mdot
.56161 .38001 Mdot
.54694 .36002 Mdot
.51509 .3509 Mdot
.45376 .65692 Mdot
.47756 .34418 Mdot
.45057 .6639 Mdot
.29149 .29623 Mdot
.47143 .20166 Mdot
.58694 .63458 Mdot
.80332 .50166 Mdot
.30017 .45272 Mdot
.3759 .25067 Mdot
.24815 .37927 Mdot
.35756 .58152 Mdot
.6018 .55373 Mdot
.47569 .40393 Mdot
.60674 .5913 Mdot
.82989 .52385 Mdot
.58777 .63757 Mdot
.87637 .42374 Mdot
.57764 .27707 Mdot
.48968 .84082 Mdot
.52546 .36728 Mdot
.65361 .62102 Mdot
.24266 .41597 Mdot
.52848 .32326 Mdot
.72183 .4226 Mdot
.57612 .45225 Mdot
.2706 .64606 Mdot
.68709 .47245 Mdot
.47923 .37022 Mdot
.28629 .45882 Mdot
.50689 .35712 Mdot
.473 .36792 Mdot
.52461 .40873 Mdot
.51703 .65702 Mdot
.56077 .35616 Mdot
.46856 .38194 Mdot
.17613 .4266 Mdot
.75405 .37483 Mdot
.58162 .61203 Mdot
.38051 .36118 Mdot
.71378 .45583 Mdot
.30255 .49605 Mdot
.60265 .5117 Mdot
.49383 .65029 Mdot
.40498 .33115 Mdot
.52589 .3655 Mdot
.32376 .64032 Mdot
.47794 .60695 Mdot
.69632 .45838 Mdot
.34006 .68764 Mdot
.58993 .78256 Mdot
.60753 .63699 Mdot
.33123 .69915 Mdot
.62014 .60409 Mdot
.28264 .40747 Mdot
.30633 .49532 Mdot
.55905 .40172 Mdot
.50636 .62756 Mdot
.58994 .63086 Mdot
.77928 .38872 Mdot
.51872 .38996 Mdot
.59613 .62312 Mdot
.55176 .40812 Mdot
.48316 .5503 Mdot
.55179 .52067 Mdot
.62308 .6405 Mdot
.44733 .63462 Mdot
.4699 .63557 Mdot
.69351 .47123 Mdot
.29918 .49315 Mdot
.31707 .45144 Mdot
.48293 .63755 Mdot
.41282 .15859 Mdot
.48218 .38097 Mdot
.51708 .41514 Mdot
.37502 .594 Mdot
.52102 .36416 Mdot
.72241 .36055 Mdot
.33185 .66402 Mdot
.29207 .46606 Mdot
.51588 .35484 Mdot
.55427 .36671 Mdot
.53054 .33833 Mdot
.64404 .26874 Mdot
.63175 .60643 Mdot
.5329 .36165 Mdot
.74001 .46048 Mdot
.24154 .55325 Mdot
.47883 .39934 Mdot
.54917 .33352 Mdot
.30235 .47204 Mdot
.68588 .24229 Mdot
.48161 .66319 Mdot
.60633 .62505 Mdot
.57624 .60853 Mdot
.63081 .32454 Mdot
.36903 .49476 Mdot
.34638 .67082 Mdot
.62507 .68137 Mdot
.3357 .66966 Mdot
.71363 .44176 Mdot
.65966 .52538 Mdot
.62004 .56441 Mdot
.58413 .60044 Mdot
.44691 .66831 Mdot
.51254 .3518 Mdot
.51692 .41678 Mdot
.30327 .61672 Mdot
.53177 .40901 Mdot
.72895 .46197 Mdot
.46556 .61705 Mdot
.30368 .47171 Mdot
.71722 .43658 Mdot
.49652 .66264 Mdot
.34116 .45792 Mdot
.53277 .32958 Mdot
.57154 .38573 Mdot
.32272 .46662 Mdot
.32425 .5065 Mdot
.49585 .40069 Mdot
.17938 .4878 Mdot
.28867 .46641 Mdot
.30924 .48096 Mdot
.32848 .7053 Mdot
.60592 .63738 Mdot
.56098 .43458 Mdot
.47545 .62605 Mdot
.49527 .3475 Mdot
.58885 .63604 Mdot
.69123 .45123 Mdot
.32223 .45998 Mdot
.53817 .34288 Mdot
.48872 .37199 Mdot
.72293 .45241 Mdot
.67858 .4574 Mdot
.73384 .45624 Mdot
.48828 .67605 Mdot
.51355 .34416 Mdot
.34368 .48589 Mdot
.49021 .63203 Mdot
.68576 .44852 Mdot
.74661 .44849 Mdot
.18478 .4113 Mdot
.48455 .39462 Mdot
.65757 .49562 Mdot
.10938 .43355 Mdot
.70234 .3609 Mdot
.33169 .69631 Mdot
.6268 .64234 Mdot
.71075 .30839 Mdot
.69096 .49184 Mdot
.46951 .62628 Mdot
.6544 .42573 Mdot
.70354 .4288 Mdot
.55413 .39135 Mdot
.53402 .39287 Mdot
.49862 .43385 Mdot
.70603 .4558 Mdot
.63538 .26973 Mdot
.32695 .44622 Mdot
.32975 .32075 Mdot
.71361 .4559 Mdot
.62443 .64015 Mdot
.60853 .64475 Mdot
.6389 .60046 Mdot
.47408 .40434 Mdot
.38255 .37474 Mdot
.35697 .24533 Mdot
.27223 .37176 Mdot
.49318 .63924 Mdot
.28614 .49569 Mdot
.60786 .54923 Mdot
.33186 .46549 Mdot
.62681 .58542 Mdot
.70236 .45404 Mdot
.35948 .46464 Mdot
.46251 .65202 Mdot
.46422 .64355 Mdot
.60665 .5729 Mdot
.62632 .61561 Mdot
.61514 .62583 Mdot
.31766 .51144 Mdot
.33357 .48227 Mdot
.55412 .36046 Mdot
.31325 .46381 Mdot
.3178 .2416 Mdot
.69174 .48528 Mdot
.57911 .63754 Mdot
.47385 .65676 Mdot
.31433 .50036 Mdot
.51215 .3751 Mdot
.74879 .54261 Mdot
.66951 .60609 Mdot
.73726 .44969 Mdot
.49285 .5756 Mdot
.82098 .33282 Mdot
.56368 .37927 Mdot
.47989 .67197 Mdot
.27539 .56956 Mdot
.51455 .39395 Mdot
.59711 .6059 Mdot
.55029 .24228 Mdot
.34412 .67588 Mdot
.47133 .3871 Mdot
.48832 .42299 Mdot
.51032 .62233 Mdot
.58205 .51426 Mdot
.53878 .40462 Mdot
.47509 .49461 Mdot
.50229 .66768 Mdot
.64721 .60196 Mdot
.17962 .61685 Mdot
.53211 .61091 Mdot
.70798 .28527 Mdot
.33155 .69426 Mdot
.56082 .37919 Mdot
.613 .61447 Mdot
.73924 .44721 Mdot
.61887 .6146 Mdot
.32542 .44028 Mdot
.59419 .62802 Mdot
.52437 .38732 Mdot
.3434 .48388 Mdot
.46813 .65581 Mdot
.42262 .49389 Mdot
.18368 .44251 Mdot
.57754 .61933 Mdot
.3066 .67818 Mdot
.47565 .39116 Mdot
.27795 .32197 Mdot
.51498 .29427 Mdot
.48343 .40712 Mdot
.49065 .62681 Mdot
.31334 .4947 Mdot
.45699 .67214 Mdot
.56496 .35623 Mdot
.47386 .23378 Mdot
.49719 .65694 Mdot
.24637 .62138 Mdot
.72127 .44166 Mdot
.65938 .25803 Mdot
.49996 .37851 Mdot
.50644 .62898 Mdot
.51366 .34363 Mdot
.35166 .45482 Mdot
.44935 .53617 Mdot
.24256 .54379 Mdot
.50276 .62438 Mdot
.37614 .80562 Mdot
.50499 .51802 Mdot
.52715 .44878 Mdot
.51015 .63869 Mdot
.3605 .39562 Mdot
.33244 .67928 Mdot
.70941 .44612 Mdot
.6824 .4503 Mdot
.72577 .47455 Mdot
.53057 .40995 Mdot
.431 .39039 Mdot
.73923 .43664 Mdot
.47781 .67699 Mdot
.73519 .43824 Mdot
.61555 .25469 Mdot
.40462 .81534 Mdot
.73463 .45063 Mdot
.49957 .37359 Mdot
.54682 .33288 Mdot
.7569 .37655 Mdot
.64961 .60391 Mdot
.59817 .794 Mdot
.24571 .3266 Mdot
.48712 .40251 Mdot
.58899 .30075 Mdot
.30959 .4448 Mdot
.30093 .55429 Mdot
.59224 .34265 Mdot
.62653 .51923 Mdot
.30815 .48735 Mdot
.48636 .55849 Mdot
.29222 .47093 Mdot
.56628 .3863 Mdot
.49332 .36354 Mdot
.36432 .48988 Mdot
.43039 .77809 Mdot
.20708 .58232 Mdot
.31011 .74452 Mdot
.31988 .45046 Mdot
.51178 .64568 Mdot
.48522 .67294 Mdot
.49464 .63303 Mdot
.62287 .62886 Mdot
.32885 .50812 Mdot
.52208 .34577 Mdot
.59288 .59538 Mdot
.47893 .35516 Mdot
.47766 .63026 Mdot
.36937 .67181 Mdot
.30324 .47313 Mdot
.49947 .39331 Mdot
.21453 .37157 Mdot
.6256 .59792 Mdot
.7208 .45337 Mdot
.44919 .57846 Mdot
.62881 .64298 Mdot
.51607 .65023 Mdot
.36096 .50569 Mdot
.59494 .65474 Mdot
.73493 .51566 Mdot
.45496 .40563 Mdot
.4578 .37033 Mdot
.45426 .70651 Mdot
.19774 .41646 Mdot
.53181 .40453 Mdot
.58806 .59715 Mdot
.61681 .63988 Mdot
.50466 .33885 Mdot
.35487 .48512 Mdot
.71717 .42872 Mdot
.72583 .47675 Mdot
.51794 .42546 Mdot
.42468 .56759 Mdot
.69984 .28974 Mdot
.54968 .37296 Mdot
.53201 .46208 Mdot
.64092 .57742 Mdot
.33927 .69222 Mdot
.39829 .56908 Mdot
.70645 .47859 Mdot
.4896 .35763 Mdot
.21205 .60599 Mdot
.30479 .48185 Mdot
.60409 .62895 Mdot
.45771 .64843 Mdot
.72707 .42242 Mdot
.57846 .59826 Mdot
.50497 .33891 Mdot
.55418 .3676 Mdot
.50429 .61799 Mdot
.37468 .43721 Mdot
.70283 .45617 Mdot
.59143 .59795 Mdot
.68809 .46961 Mdot
.33831 .47631 Mdot
.30812 .47623 Mdot
.53415 .31019 Mdot
.54774 .30928 Mdot
.5766 .61035 Mdot
.49276 .42904 Mdot
.63858 .59068 Mdot
.77663 .55252 Mdot
.4596 .66016 Mdot
.46498 .40864 Mdot
.36829 .44589 Mdot
.4793 .63109 Mdot
.4998 .40854 Mdot
.45064 .7028 Mdot
.551 .38391 Mdot
.65338 .62037 Mdot
.48575 .22065 Mdot
.69241 .46125 Mdot
.41178 .44683 Mdot
.42829 .34055 Mdot
.52135 .36576 Mdot
.65251 .60811 Mdot
.44106 .34885 Mdot
.49276 .65728 Mdot
.3237 .48996 Mdot
.57735 .16164 Mdot
.47472 .64447 Mdot
.502 .35771 Mdot
.70537 .46323 Mdot
.28225 .47265 Mdot
.31464 .68281 Mdot
.38325 .6019 Mdot
.48341 .44652 Mdot
.53479 .43762 Mdot
.50965 .35255 Mdot
.83384 .44755 Mdot
.61229 .62145 Mdot
.32192 .5025 Mdot
.46982 .6703 Mdot
.48801 .6439 Mdot
.63085 .59447 Mdot
.28593 .65764 Mdot
.462 .80172 Mdot
.09281 .4825 Mdot
.58237 .59698 Mdot
.74349 .44881 Mdot
.47878 .53895 Mdot
.63255 .5833 Mdot
.60706 .61767 Mdot
.60626 .57168 Mdot
.33511 .631 Mdot
.34159 .45543 Mdot
.48739 .3715 Mdot
.37489 .48565 Mdot
.55816 .38575 Mdot
.76411 .34705 Mdot
.48481 .63661 Mdot
.32583 .48865 Mdot
.48372 .70056 Mdot
.58145 .34039 Mdot
.5174 .40057 Mdot
.68851 .59565 Mdot
.4644 .43441 Mdot
.69314 .32529 Mdot
.57557 .36586 Mdot
.62544 .60931 Mdot
.57104 .28867 Mdot
.43888 .38746 Mdot
.23256 .3481 Mdot
.46406 .65006 Mdot
.31319 .68818 Mdot
.52266 .32829 Mdot
.50695 .45735 Mdot
.28258 .47748 Mdot
.35976 .46528 Mdot
.73648 .43484 Mdot
.42849 .5897 Mdot
.46541 .65325 Mdot
.51399 .80349 Mdot
.49388 .41303 Mdot
.41914 .65721 Mdot
.47855 .21725 Mdot
.50096 .40683 Mdot
.67398 .56023 Mdot
.4032 .33451 Mdot
.54285 .39703 Mdot
.29085 .36679 Mdot
.47402 .65268 Mdot
.46356 .19743 Mdot
.52057 .42953 Mdot
.59804 .60615 Mdot
.33307 .48732 Mdot
.30122 .44949 Mdot
.73354 .44383 Mdot
.27678 .27833 Mdot
.44077 .6436 Mdot
.33117 .48522 Mdot
.51374 .38823 Mdot
.47761 .66208 Mdot
.31554 .68934 Mdot
.51391 .44258 Mdot
.76136 .63493 Mdot
.30907 .46599 Mdot
.45751 .33883 Mdot
.29261 .71385 Mdot
.51128 .52963 Mdot
.57483 .8239 Mdot
.49787 .63274 Mdot
.70897 .47973 Mdot
.57737 .37079 Mdot
.61777 .68154 Mdot
.53263 .42662 Mdot
.73561 .31946 Mdot
.2707 .45794 Mdot
.68571 .4579 Mdot
.50988 .39376 Mdot
.53863 .40425 Mdot
.45285 .55118 Mdot
.67981 .46254 Mdot
.5408 .40327 Mdot
.51043 .31038 Mdot
.33762 .45721 Mdot
.32474 .66437 Mdot
.30512 .46668 Mdot
.50618 .37126 Mdot
.60168 .30929 Mdot
.3579 .47175 Mdot
.57158 .78923 Mdot
.76373 .45615 Mdot
.49457 .65064 Mdot
.48417 .45794 Mdot
.47154 .39725 Mdot
.76001 .72104 Mdot
.32137 .69672 Mdot
.74233 .297 Mdot
.64007 .6356 Mdot
.24623 .69493 Mdot
.63394 .64229 Mdot
.46321 .84399 Mdot
.42018 .50878 Mdot
.46941 .41868 Mdot
.67252 .40816 Mdot
.28336 .36444 Mdot
.45128 .67302 Mdot
.31991 .28239 Mdot
.48889 .40983 Mdot
.47711 .37987 Mdot
.6071 .58498 Mdot
.29315 .66273 Mdot
.27956 .57632 Mdot
.41314 .56471 Mdot
.69892 .45331 Mdot
.33146 .47765 Mdot
.52714 .39036 Mdot
.39252 .7412 Mdot
.58212 .61844 Mdot
.58387 .46167 Mdot
.49823 .39051 Mdot
.32191 .59597 Mdot
.27619 .6295 Mdot
.47444 .66275 Mdot
.64316 .63102 Mdot
.65534 .60342 Mdot
.54915 .34486 Mdot
.45932 .63595 Mdot
.55748 .37532 Mdot
.49946 .51741 Mdot
.44569 .37603 Mdot
.69851 .44426 Mdot
.4706 .36356 Mdot
.61197 .45805 Mdot
.45986 .85669 Mdot
.44344 .41079 Mdot
.29042 .48405 Mdot
.62702 .62501 Mdot
.63499 .60081 Mdot
.3156 .45143 Mdot
.63497 .59865 Mdot
.32912 .32854 Mdot
.44088 .22495 Mdot
.70701 .44112 Mdot
.23751 .3865 Mdot
.69423 .45549 Mdot
.31255 .68734 Mdot
.48784 .39763 Mdot
.64219 .68414 Mdot
.58137 .59788 Mdot
.58002 .23623 Mdot
.48199 .64374 Mdot
.32253 .69704 Mdot
.49647 .33229 Mdot
.66968 .52607 Mdot
.61772 .58599 Mdot
.59775 .76048 Mdot
.53342 .33923 Mdot
.34816 .45586 Mdot
.54097 .39985 Mdot
.44945 .38128 Mdot
.33285 .6977 Mdot
.50973 .35161 Mdot
.4969 .66243 Mdot
.32997 .50856 Mdot
.46677 .83933 Mdot
.62764 .62747 Mdot
.47338 .37935 Mdot
.5136 .38931 Mdot
.36066 .46123 Mdot
.48725 .33255 Mdot
.47297 .625 Mdot
.17189 .70231 Mdot
.71906 .44152 Mdot
.3416 .69009 Mdot
.58251 .77284 Mdot
.53287 .38553 Mdot
.54521 .37838 Mdot
.44613 .707 Mdot
.2094 .53119 Mdot
.50244 .65638 Mdot
.47107 .33649 Mdot
.5867 .60812 Mdot
.6995 .46152 Mdot
.48723 .61959 Mdot
.50681 .34092 Mdot
.4774 .38175 Mdot
.70138 .44159 Mdot
.68929 .58958 Mdot
.66388 .59446 Mdot
.49368 .63647 Mdot
.59953 .32733 Mdot
.75329 .5456 Mdot
.48635 .38276 Mdot
.34877 .76796 Mdot
.31188 .4813 Mdot
.5081 .63992 Mdot
.37572 .40499 Mdot
.55693 .40218 Mdot
.51621 .64822 Mdot
.46705 .65426 Mdot
.50979 .33293 Mdot
.37002 .4943 Mdot
.30651 .51027 Mdot
.31055 .48323 Mdot
.50105 .21253 Mdot
.79502 .43494 Mdot
.61453 .62681 Mdot
.47083 .65221 Mdot
.59386 .64076 Mdot
.73117 .43045 Mdot
.47898 .54603 Mdot
.61758 .64043 Mdot
.29844 .45301 Mdot
.58953 .64183 Mdot
.55548 .37753 Mdot
.4613 .64652 Mdot
.58599 .59624 Mdot
.5324 .37536 Mdot
.52039 .46673 Mdot
.62447 .4473 Mdot
.71042 .42973 Mdot
.48051 .55766 Mdot
.50423 .36285 Mdot
.33658 .69004 Mdot
.49523 .39798 Mdot
.45583 .64019 Mdot
.60415 .47098 Mdot
.53125 .36637 Mdot
.57721 .60439 Mdot
.75159 .51009 Mdot
.64868 .61605 Mdot
.45409 .36139 Mdot
.50544 .37044 Mdot
.48403 .38287 Mdot
.5355 .40921 Mdot
.25792 .63491 Mdot
.45043 .66485 Mdot
.47828 .45852 Mdot
.57881 .59141 Mdot
.32805 .46305 Mdot
.35456 .45441 Mdot
.61801 .52466 Mdot
.3289 .70204 Mdot
.46353 .63221 Mdot
.48347 .38116 Mdot
.59833 .75986 Mdot
.37473 .67469 Mdot
.33104 .76276 Mdot
.6526 .53983 Mdot
.58679 .59736 Mdot
.29201 .48901 Mdot
.61648 .5757 Mdot
.49502 .33832 Mdot
.57572 .36819 Mdot
.48276 .83852 Mdot
.52094 .65531 Mdot
.70337 .45467 Mdot
.47862 .35462 Mdot
.68053 .26602 Mdot
.58683 .60505 Mdot
.64389 .57959 Mdot
.55834 .36851 Mdot
.30137 .51323 Mdot
.5431 .85404 Mdot
.45669 .64372 Mdot
.28615 .31209 Mdot
.27211 .4464 Mdot
.58444 .44093 Mdot
.48555 .65623 Mdot
.64763 .48162 Mdot
.64555 .61363 Mdot
.25734 .30944 Mdot
.32144 .46493 Mdot
.70714 .45261 Mdot
.517 .31395 Mdot
.29691 .45366 Mdot
.6125 .64701 Mdot
.2967 .47974 Mdot
.56329 .3958 Mdot
.46973 .67605 Mdot
.6368 .59573 Mdot
.44956 .64344 Mdot
.35961 .49652 Mdot
.69335 .45787 Mdot
.59394 .25139 Mdot
.2883 .30614 Mdot
.40334 .33452 Mdot
.53262 .36083 Mdot
.67163 .68813 Mdot
.52078 .34333 Mdot
.28774 .49257 Mdot
.49998 .37765 Mdot
.4157 .4683 Mdot
.64691 .59032 Mdot
.45192 .34758 Mdot
.46728 .37468 Mdot
.26519 .31381 Mdot
.51053 .40567 Mdot
.49692 .33338 Mdot
.50242 .42549 Mdot
.30861 .42369 Mdot
.47309 .32842 Mdot
.34913 .4577 Mdot
.30785 .62357 Mdot
.60716 .6155 Mdot
.74902 .45178 Mdot
.7105 .48266 Mdot
.7285 .31179 Mdot
.6656 .26021 Mdot
.29161 .65364 Mdot
.31247 .45584 Mdot
.50886 .65578 Mdot
.55734 .37281 Mdot
.32838 .40232 Mdot
.63435 .39935 Mdot
.64615 .60979 Mdot
.57482 .62353 Mdot
.52646 .30492 Mdot
.8505 .48678 Mdot
.46487 .33308 Mdot
.3756 .61128 Mdot
.54528 .40129 Mdot
.47132 .41417 Mdot
.64234 .57655 Mdot
.63089 .25993 Mdot
.53275 .36165 Mdot
.28254 .47694 Mdot
.71213 .44977 Mdot
.58555 .30168 Mdot
.62997 .36464 Mdot
.61071 .42529 Mdot
.25925 .51476 Mdot
.51485 .34768 Mdot
.59501 .59788 Mdot
.29274 .45719 Mdot
.38047 .58286 Mdot
.49069 .63046 Mdot
.39592 .58305 Mdot
.31022 .27675 Mdot
.53725 .60558 Mdot
.70653 .45092 Mdot
.65623 .55043 Mdot
.52433 .38649 Mdot
.62124 .6289 Mdot
.56286 .38733 Mdot
.3749 .67864 Mdot
.68959 .45179 Mdot
.34232 .51099 Mdot
.51178 .64697 Mdot
.33325 .44907 Mdot
.3644 .38189 Mdot
.63212 .39106 Mdot
.24659 .69658 Mdot
.61118 .63729 Mdot
.49454 .25778 Mdot
.33065 .49713 Mdot
.52256 .33869 Mdot
.0978 .47053 Mdot
.31482 .48148 Mdot
.33902 .45082 Mdot
.62875 .51843 Mdot
.61127 .27173 Mdot
.43752 .38729 Mdot
.29427 .47072 Mdot
.56592 .62884 Mdot
.71893 .46635 Mdot
.5391 .3751 Mdot
.51492 .42411 Mdot
.35965 .47023 Mdot
.62251 .5862 Mdot
.6816 .26273 Mdot
.62639 .61251 Mdot
.34621 .46175 Mdot
.61706 .59981 Mdot
.55632 .78492 Mdot
.58641 .62067 Mdot
.466 .37872 Mdot
.4843 .38064 Mdot
.75523 .61954 Mdot
.30814 .47613 Mdot
.5425 .37919 Mdot
.48753 .36342 Mdot
.33948 .49135 Mdot
.60408 .56736 Mdot
.41043 .34202 Mdot
.52795 .37688 Mdot
.48476 .37571 Mdot
.68383 .46241 Mdot
.50538 .55213 Mdot
.37214 .74361 Mdot
.54045 .37666 Mdot
.73402 .46957 Mdot
.31463 .51028 Mdot
.4972 .3997 Mdot
.63102 .25588 Mdot
.64903 .6364 Mdot
.4824 .34294 Mdot
.31475 .67937 Mdot
.52695 .40755 Mdot
.53607 .85607 Mdot
.47479 .38464 Mdot
.33602 .49875 Mdot
.33016 .49249 Mdot
.66646 .59919 Mdot
.3302 .46891 Mdot
.32737 .6957 Mdot
.47432 .6328 Mdot
.33196 .77287 Mdot
.32382 .69471 Mdot
.46491 .40467 Mdot
.22896 .33363 Mdot
.52484 .42391 Mdot
.52023 .32368 Mdot
.59592 .24426 Mdot
.32789 .69335 Mdot
.31651 .49717 Mdot
.43127 .77538 Mdot
.45847 .40262 Mdot
.45688 .64153 Mdot
.53346 .32426 Mdot
.48016 .3441 Mdot
.52806 .48921 Mdot
.48534 .23173 Mdot
.46052 .62076 Mdot
.55456 .43863 Mdot
.54043 .3749 Mdot
.21571 .49841 Mdot
.51753 .38495 Mdot
.73401 .44762 Mdot
.30381 .4567 Mdot
.62232 .57507 Mdot
.72328 .44681 Mdot
.52917 .38702 Mdot
.70918 .45556 Mdot
.61178 .6269 Mdot
.49879 .62631 Mdot
.47343 .35806 Mdot
.6894 .48165 Mdot
.70006 .45642 Mdot
.53866 .34898 Mdot
.32981 .48748 Mdot
.49495 .29406 Mdot
.49849 .40153 Mdot
.50854 .33874 Mdot
.31673 .45152 Mdot
.27461 .24403 Mdot
.56329 .36835 Mdot
.64948 .48997 Mdot
.36556 .45907 Mdot
.34821 .68088 Mdot
.60789 .57798 Mdot
.56395 .40769 Mdot
.48878 .63861 Mdot
.48023 .63432 Mdot
.57568 .58911 Mdot
.3575 .49163 Mdot
.63482 .59078 Mdot
.51327 .44609 Mdot
.53062 .30615 Mdot
.51719 .31186 Mdot
.58072 .16321 Mdot
.59315 .7813 Mdot
.34057 .50125 Mdot
.64771 .61277 Mdot
.41031 .57112 Mdot
.46386 .63394 Mdot
.57541 .58671 Mdot
.36331 .44334 Mdot
.31255 .50454 Mdot
.29727 .45614 Mdot
.7093 .47659 Mdot
.63208 .61387 Mdot
.2837 .44833 Mdot
.31791 .51585 Mdot
.54924 .35192 Mdot
.54071 .37378 Mdot
.2694 .48779 Mdot
.75145 .37863 Mdot
.69408 .44976 Mdot
.59749 .60024 Mdot
.7177 .77476 Mdot
.45621 .64508 Mdot
.26276 .31602 Mdot
.53163 .3757 Mdot
.19511 .27621 Mdot
.48054 .32504 Mdot
.51506 .38735 Mdot
.31848 .50988 Mdot
.72565 .48091 Mdot
.71484 .46508 Mdot
.33086 .49639 Mdot
.32852 .51945 Mdot
.7262 .47171 Mdot
.6625 .54244 Mdot
.35352 .79742 Mdot
.38908 .58007 Mdot
.3412 .49395 Mdot
.26574 .33077 Mdot
.49154 .62066 Mdot
.37154 .47112 Mdot
.45574 .62887 Mdot
.60574 .61777 Mdot
.57855 .6267 Mdot
.50233 .6164 Mdot
.51855 .33604 Mdot
.59657 .62765 Mdot
.46558 .44013 Mdot
.52949 .81984 Mdot
.74166 .68185 Mdot
.19464 .53384 Mdot
.5092 .41954 Mdot
.2906 .5814 Mdot
.26134 .58908 Mdot
.51528 .3626 Mdot
.588 .38116 Mdot
.70537 .45465 Mdot
.36941 .4699 Mdot
.46393 .62681 Mdot
.60461 .79972 Mdot
.48541 .38228 Mdot
.34852 .46701 Mdot
.46149 .6406 Mdot
.54672 .78087 Mdot
.48287 .49632 Mdot
.56029 .3747 Mdot
.08681 .54384 Mdot
.35466 .50137 Mdot
.62359 .57524 Mdot
.21719 .38946 Mdot
.37723 .47763 Mdot
.75664 .53238 Mdot
.65709 .59771 Mdot
.33067 .73698 Mdot
.30527 .49808 Mdot
.64487 .56787 Mdot
.33763 .47348 Mdot
.71807 .43518 Mdot
.36504 .50229 Mdot
.62413 .59272 Mdot
.5103 .39873 Mdot
.62728 .59465 Mdot
.70216 .43939 Mdot
.61054 .63392 Mdot
.46624 .62521 Mdot
.3333 .69334 Mdot
.46545 .63898 Mdot
.48388 .54554 Mdot
.4454 .26253 Mdot
.50121 .64073 Mdot
.62431 .74605 Mdot
.53315 .40189 Mdot
.38043 .44078 Mdot
.61869 .57393 Mdot
.57022 .62746 Mdot
.45332 .56191 Mdot
.34499 .4677 Mdot
.617 .59392 Mdot
.31334 .27738 Mdot
.37987 .16512 Mdot
.45411 .43513 Mdot
.79235 .44993 Mdot
.3408 .49117 Mdot
.6462 .58698 Mdot
.3752 .59672 Mdot
.32668 .44418 Mdot
.57966 .60409 Mdot
.51106 .63763 Mdot
.48885 .64743 Mdot
.52915 .3363 Mdot
.51112 .61648 Mdot
.65277 .60453 Mdot
.21058 .5892 Mdot
.30426 .45514 Mdot
.55771 .77291 Mdot
.73573 .45755 Mdot
.60701 .62193 Mdot
.43975 .3755 Mdot
.2594 .49645 Mdot
.57234 .6226 Mdot
.7889 .60289 Mdot
.75296 .74214 Mdot
.61565 .59457 Mdot
.30309 .45743 Mdot
.32522 .45929 Mdot
.44212 .40432 Mdot
.43233 .56304 Mdot
.61844 .58844 Mdot
.65244 .68231 Mdot
.74235 .32797 Mdot
.31868 .67983 Mdot
.2009 .38044 Mdot
.5319 .36164 Mdot
.5101 .34394 Mdot
.48221 .62357 Mdot
.52131 .40087 Mdot
.29962 .50929 Mdot
.50612 .3199 Mdot
.48655 .67362 Mdot
.64639 .60599 Mdot
.48523 .39114 Mdot
.70454 .47064 Mdot
.47416 .62335 Mdot
.52074 .64345 Mdot
.6121 .60621 Mdot
.29376 .4632 Mdot
.41427 .77863 Mdot
.62709 .61329 Mdot
.51692 .34789 Mdot
.32737 .68489 Mdot
.56083 .40315 Mdot
.73201 .64274 Mdot
.32418 .4467 Mdot
.6206 .57582 Mdot
.35331 .44284 Mdot
.46934 .64682 Mdot
.56882 .60739 Mdot
.51783 .37918 Mdot
.57863 .60939 Mdot
.65141 .45926 Mdot
.70659 .58415 Mdot
.31797 .51687 Mdot
.66888 .45221 Mdot
.36006 .46291 Mdot
.3181 .68002 Mdot
.65615 .34132 Mdot
.7055 .44551 Mdot
.58946 .6188 Mdot
.5859 .79116 Mdot
.59699 .57697 Mdot
.50907 .40723 Mdot
.504 .41429 Mdot
.60831 .58317 Mdot
.69888 .47232 Mdot
.64192 .23138 Mdot
.71686 .50049 Mdot
.30702 .49461 Mdot
.39357 .52802 Mdot
.66437 .80754 Mdot
.55738 .63588 Mdot
.5147 .64765 Mdot
.56316 .44003 Mdot
.54637 .38869 Mdot
.51203 .62555 Mdot
.45919 .66301 Mdot
.6874 .44675 Mdot
.61701 .62975 Mdot
.33197 .43382 Mdot
.49662 .61961 Mdot
.46421 .2917 Mdot
.64833 .25422 Mdot
.45409 .42106 Mdot
.46079 .32822 Mdot
.46796 .39687 Mdot
.5109 .53157 Mdot
.46142 .67247 Mdot
.50004 .36452 Mdot
.5459 .31481 Mdot
.50738 .64468 Mdot
.70723 .43745 Mdot
.38452 .4939 Mdot
.60681 .60124 Mdot
.30262 .19259 Mdot
.47228 .35992 Mdot
.50624 .40068 Mdot
.49313 .63957 Mdot
.19639 .43213 Mdot
.34512 .49509 Mdot
.29589 .46381 Mdot
.61245 .62244 Mdot
.44726 .56797 Mdot
.48022 .33626 Mdot
.51173 .36213 Mdot
.59316 .61785 Mdot
.33496 .6903 Mdot
.17926 .55038 Mdot
.49047 .37216 Mdot
.47776 .6561 Mdot
.61592 .74312 Mdot
.45852 .67112 Mdot
.56327 .38142 Mdot
.50827 .40925 Mdot
.46539 .3715 Mdot
.53369 .41241 Mdot
.50025 .61766 Mdot
.51438 .36543 Mdot
.54297 .29773 Mdot
.31217 .49133 Mdot
.52465 .36067 Mdot
.71924 .30725 Mdot
.4899 .37756 Mdot
.70376 .46955 Mdot
.37836 .75244 Mdot
.47572 .37297 Mdot
.52224 .35702 Mdot
.69705 .50199 Mdot
.50818 .39003 Mdot
.46535 .6596 Mdot
.32184 .46243 Mdot
.4692 .65129 Mdot
.48346 .66691 Mdot
.58022 .63551 Mdot
.69143 .44025 Mdot
.52511 .43063 Mdot
.73216 .46876 Mdot
.44391 .38592 Mdot
.56221 .39569 Mdot
.49396 .55275 Mdot
.37589 .61322 Mdot
.6839 .48946 Mdot
.51386 .37388 Mdot
.61161 .61774 Mdot
.60577 .57698 Mdot
.67408 .41314 Mdot
.45396 .42801 Mdot
.48657 .61861 Mdot
.50663 .62904 Mdot
.71978 .36343 Mdot
.50678 .49238 Mdot
.69771 .46459 Mdot
.41289 .55137 Mdot
.49579 .4186 Mdot
.4827 .36556 Mdot
.54326 .32981 Mdot
.60978 .64205 Mdot
.33709 .69251 Mdot
.64464 .61058 Mdot
.31055 .69992 Mdot
.45345 .66824 Mdot
.50709 .41915 Mdot
.71198 .70959 Mdot
.35519 .48978 Mdot
.3202 .46277 Mdot
.49589 .67083 Mdot
.64976 .61385 Mdot
.44493 .40724 Mdot
.60065 .16288 Mdot
.27472 .47707 Mdot
.74114 .46629 Mdot
.50791 .35993 Mdot
.61139 .60958 Mdot
.34042 .50612 Mdot
.67687 .45448 Mdot
.49819 .41669 Mdot
.59171 .57519 Mdot
.49588 .37854 Mdot
.27827 .37972 Mdot
.31733 .49319 Mdot
.36852 .67788 Mdot
.30134 .51635 Mdot
.5145 .63433 Mdot
.49415 .66207 Mdot
.50156 .40899 Mdot
.48636 .14378 Mdot
.30108 .52017 Mdot
.4862 .60392 Mdot
.7167 .43299 Mdot
.34201 .68778 Mdot
.70181 .43467 Mdot
.63638 .58635 Mdot
.70954 .44925 Mdot
.57628 .60807 Mdot
.73592 .38018 Mdot
.27739 .4586 Mdot
.71987 .44309 Mdot
.19029 .44247 Mdot
.57072 .38813 Mdot
.68334 .45239 Mdot
.52118 .3037 Mdot
.40398 .45038 Mdot
.59547 .61668 Mdot
.7024 .47295 Mdot
.53755 .34328 Mdot
.64582 .76406 Mdot
.48869 .66509 Mdot
.48243 .6184 Mdot
.53106 .42791 Mdot
.62837 .57217 Mdot
.33443 .51782 Mdot
.60164 .50884 Mdot
.34781 .67669 Mdot
.51159 .36302 Mdot
.49898 .41822 Mdot
.36417 .47678 Mdot
.28182 .4825 Mdot
.5069 .41082 Mdot
.3301 .26885 Mdot
.52477 .38542 Mdot
.48952 .65079 Mdot
.32163 .50703 Mdot
.32101 .46026 Mdot
.64911 .6232 Mdot
.35731 .49139 Mdot
.46082 .33122 Mdot
.45428 .68285 Mdot
.54145 .31822 Mdot
.4718 .64408 Mdot
.61331 .46556 Mdot
.6215 .63058 Mdot
.60411 .79367 Mdot
.35135 .50047 Mdot
.51421 .3521 Mdot
.35658 .45866 Mdot
.73332 .45698 Mdot
.30814 .47425 Mdot
.29828 .44808 Mdot
.49377 .41181 Mdot
.56079 .37824 Mdot
.33168 .68871 Mdot
.43267 .56496 Mdot
.32003 .48774 Mdot
.52379 .37712 Mdot
.51237 .42925 Mdot
.55595 .35073 Mdot
.50749 .51856 Mdot
.30754 .50379 Mdot
.41807 .22049 Mdot
.73917 .65634 Mdot
.32709 .48647 Mdot
.60919 .81498 Mdot
.32512 .66872 Mdot
.32963 .70256 Mdot
.47356 .60305 Mdot
.48674 .37259 Mdot
.63366 .59202 Mdot
.49112 .34002 Mdot
.47306 .44443 Mdot
.4738 .37495 Mdot
.69432 .44478 Mdot
.46895 .42313 Mdot
.33094 .67236 Mdot
.6291 .60737 Mdot
.52956 .38166 Mdot
.48158 .38805 Mdot
.3262 .7022 Mdot
.30098 .51717 Mdot
.30922 .5014 Mdot
.35774 .76984 Mdot
.71687 .43824 Mdot
.49048 .62772 Mdot
.49698 .33943 Mdot
.61213 .61959 Mdot
.63169 .59621 Mdot
.33603 .44964 Mdot
.60051 .60279 Mdot
.45605 .63844 Mdot
.52003 .3891 Mdot
.51093 .62411 Mdot
.69514 .44422 Mdot
.30436 .45629 Mdot
.4978 .33885 Mdot
.54728 .34934 Mdot
.32984 .49272 Mdot
.53188 .40386 Mdot
.68412 .46352 Mdot
.58896 .63151 Mdot
.31469 .50227 Mdot
.47569 .63305 Mdot
.64153 .63189 Mdot
.55549 .37233 Mdot
.81789 .64563 Mdot
.52291 .40055 Mdot
.49116 .34622 Mdot
.39574 .82264 Mdot
.57506 .35983 Mdot
.64252 .58622 Mdot
.35556 .45412 Mdot
.56453 .36141 Mdot
.7671 .35418 Mdot
.5379 .67651 Mdot
.57826 .58264 Mdot
.50753 .35649 Mdot
.58133 .8123 Mdot
.51712 .35639 Mdot
.53495 .78531 Mdot
.49134 .55274 Mdot
.82707 .47913 Mdot
.46938 .31975 Mdot
.49358 .60655 Mdot
.33203 .69073 Mdot
.61742 .57293 Mdot
.31785 .38961 Mdot
.52636 .40319 Mdot
.37462 .39455 Mdot
.47746 .34438 Mdot
.48634 .65479 Mdot
.58597 .39467 Mdot
.59836 .60068 Mdot
.23626 .33663 Mdot
.51982 .34551 Mdot
.31163 .5058 Mdot
.56982 .63298 Mdot
.34411 .67975 Mdot
.53621 .34194 Mdot
.73742 .45963 Mdot
.49534 .69427 Mdot
.49218 .31307 Mdot
.47206 .64149 Mdot
.48757 .36071 Mdot
.53418 .44994 Mdot
.42258 .15948 Mdot
.31105 .49274 Mdot
.51409 .64499 Mdot
.27899 .54698 Mdot
.52482 .41336 Mdot
.30737 .49941 Mdot
.3242 .46424 Mdot
.73529 .44253 Mdot
.38541 .6332 Mdot
.58306 .66714 Mdot
.77223 .65692 Mdot
.3902 .35174 Mdot
.63529 .63827 Mdot
.21853 .5637 Mdot
.53845 .3675 Mdot
.62996 .37992 Mdot
.47252 .66418 Mdot
.50773 .39889 Mdot
.41431 .29634 Mdot
.30915 .4821 Mdot
.49555 .37201 Mdot
.69567 .44794 Mdot
.36148 .64917 Mdot
.61363 .40956 Mdot
.75804 .71225 Mdot
.56319 .61371 Mdot
.53382 .32134 Mdot
.49444 .30336 Mdot
.34774 .68318 Mdot
.55813 .39187 Mdot
.62316 .57398 Mdot
.67602 .69096 Mdot
.69332 .4686 Mdot
.35245 .49559 Mdot
.32949 .66801 Mdot
.46303 .36355 Mdot
.54473 .41619 Mdot
.74864 .45147 Mdot
.52165 .34017 Mdot
.22462 .36743 Mdot
.35635 .67791 Mdot
.5864 .62234 Mdot
.29531 .47754 Mdot
.46906 .39899 Mdot
.33755 .69102 Mdot
.49789 .41332 Mdot
.37712 .51126 Mdot
.50074 .35024 Mdot
.28239 .69896 Mdot
.33393 .48628 Mdot
.46917 .6403 Mdot
.50518 .43694 Mdot
.49179 .3867 Mdot
.75226 .5495 Mdot
.4767 .44594 Mdot
.47531 .38454 Mdot
.28371 .46419 Mdot
.35696 .48042 Mdot
.34335 .4546 Mdot
.59025 .62666 Mdot
.39485 .57376 Mdot
.48198 .64884 Mdot
.49436 .32604 Mdot
.49299 .61976 Mdot
.42254 .37703 Mdot
.74605 .45567 Mdot
.65835 .77827 Mdot
.53144 .39303 Mdot
.32998 .45234 Mdot
.21999 .61071 Mdot
.31577 .51087 Mdot
.4604 .6006 Mdot
.46486 .65279 Mdot
.31677 .48229 Mdot
.50703 .38468 Mdot
.41759 .56322 Mdot
.79185 .67098 Mdot
.46668 .63202 Mdot
.56526 .34937 Mdot
.5638 .61953 Mdot
.57455 .60602 Mdot
.58728 .84246 Mdot
.48852 .66751 Mdot
.25657 .58574 Mdot
.52281 .37132 Mdot
.35791 .4838 Mdot
.49835 .63693 Mdot
.46662 .66242 Mdot
.59368 .613 Mdot
.56012 .36807 Mdot
.49253 .3841 Mdot
.31567 .67711 Mdot
.49923 .62471 Mdot
.56597 .41757 Mdot
.55088 .39327 Mdot
.46595 .84218 Mdot
.35743 .43814 Mdot
.24938 .26512 Mdot
.52129 .44706 Mdot
.42152 .29378 Mdot
.54163 .50261 Mdot
.33676 .5046 Mdot
.50599 .33561 Mdot
.48552 .32802 Mdot
.64307 .63216 Mdot
.52246 .39282 Mdot
.63619 .62836 Mdot
.51364 .651 Mdot
.66641 .77944 Mdot
.57127 .76078 Mdot
.60178 .55292 Mdot
.51664 .40342 Mdot
.58732 .44288 Mdot
.72929 .45316 Mdot
.49593 .67507 Mdot
.35265 .46886 Mdot
.47564 .40802 Mdot
.65833 .60128 Mdot
.58781 .61605 Mdot
.31965 .46928 Mdot
.27101 .60679 Mdot
.57043 .78952 Mdot
.53298 .41384 Mdot
.62155 .57758 Mdot
.54775 .7636 Mdot
.35565 .2593 Mdot
.50494 .61232 Mdot
.69121 .46446 Mdot
.64521 .60305 Mdot
.51992 .65152 Mdot
.3959 .48411 Mdot
.32432 .47499 Mdot
.3637 .48598 Mdot
.73903 .60354 Mdot
.62245 .58936 Mdot
.7246 .45513 Mdot
.47046 .48635 Mdot
.43319 .48719 Mdot
.69111 .45032 Mdot
.64684 .60741 Mdot
.35068 .49514 Mdot
.34778 .46497 Mdot
.32389 .46203 Mdot
.23154 .34921 Mdot
.31486 .44671 Mdot
.38354 .20871 Mdot
.53183 .41969 Mdot
.27604 .32542 Mdot
.51428 .35587 Mdot
.48534 .61324 Mdot
.31879 .49358 Mdot
.4715 .54611 Mdot
.4811 .41747 Mdot
.76435 .70137 Mdot
.50508 .36196 Mdot
.4532 .68782 Mdot
.48533 .3739 Mdot
.23162 .38496 Mdot
.36609 .45966 Mdot
.5151 .37376 Mdot
.46247 .61598 Mdot
.70262 .45929 Mdot
.32508 .52616 Mdot
.47694 .37625 Mdot
.31289 .65176 Mdot
.54168 .31296 Mdot
.5517 .80804 Mdot
.72989 .51741 Mdot
.73735 .47229 Mdot
.52139 .30917 Mdot
.59674 .64642 Mdot
.28362 .52018 Mdot
.26107 .3479 Mdot
.4678 .63144 Mdot
.51605 .23961 Mdot
.59127 .62136 Mdot
.58603 .38973 Mdot
.45213 .38264 Mdot
.70463 .47707 Mdot
.31141 .52461 Mdot
.49135 .652 Mdot
.53141 .40111 Mdot
.50235 .33385 Mdot
.79549 .57597 Mdot
.25343 .35436 Mdot
.56159 .42117 Mdot
.73028 .43111 Mdot
.42597 .22231 Mdot
.47836 .36548 Mdot
.58773 .57642 Mdot
.34787 .44693 Mdot
.44354 .3584 Mdot
.40643 .22194 Mdot
.52541 .38082 Mdot
.31651 .47832 Mdot
.35355 .49847 Mdot
.25751 .66487 Mdot
.74228 .46242 Mdot
.5004 .35025 Mdot
.76567 .54449 Mdot
.51374 .34485 Mdot
.485 .65058 Mdot
.5653 .37592 Mdot
.60181 .62113 Mdot
.37184 .60183 Mdot
.5928 .6301 Mdot
.54261 .34043 Mdot
.33907 .46312 Mdot
.49435 .64839 Mdot
.73404 .6212 Mdot
.58096 .5223 Mdot
.39349 .20607 Mdot
.49739 .69514 Mdot
.71222 .47467 Mdot
.68521 .44387 Mdot
.44356 .66484 Mdot
.50831 .37093 Mdot
.53614 .52293 Mdot
.45487 .34655 Mdot
.48197 .37383 Mdot
.47349 .36116 Mdot
.51598 .66673 Mdot
.46456 .64831 Mdot
.6202 .59702 Mdot
.5091 .41095 Mdot
.52295 .37619 Mdot
.32873 .48206 Mdot
.69932 .45716 Mdot
.58346 .62368 Mdot
.72429 .44164 Mdot
.62329 .61084 Mdot
.55037 .84887 Mdot
.56599 .36006 Mdot
.70294 .46043 Mdot
.46249 .67469 Mdot
.32532 .45058 Mdot
.32047 .69707 Mdot
.63712 .58836 Mdot
.60095 .59855 Mdot
.51453 .36379 Mdot
.30134 .4642 Mdot
.30113 .47783 Mdot
.72195 .47353 Mdot
.50482 .63359 Mdot
.52502 .33458 Mdot
.55618 .38757 Mdot
.80613 .50172 Mdot
.62605 .64041 Mdot
.35068 .2513 Mdot
.2681 .65148 Mdot
.50917 .37169 Mdot
.30146 .48568 Mdot
.48904 .39384 Mdot
.66876 .72608 Mdot
.29711 .45408 Mdot
.49742 .4267 Mdot
.50509 .48427 Mdot
.60102 .64008 Mdot
.25554 .69162 Mdot
.50471 .43419 Mdot
.44369 .70765 Mdot
.53953 .35602 Mdot
.34388 .81736 Mdot
.21317 .52429 Mdot
.46934 .3517 Mdot
.52857 .41514 Mdot
.79625 .62822 Mdot
.52199 .36589 Mdot
.32545 .67141 Mdot
.49763 .4458 Mdot
.31051 .50313 Mdot
.56123 .50512 Mdot
.50068 .5611 Mdot
.74295 .44559 Mdot
.61203 .62315 Mdot
.6286 .29869 Mdot
.71344 .43581 Mdot
.33651 .4967 Mdot
.5099 .4254 Mdot
.45588 .28977 Mdot
.6654 .61177 Mdot
.4485 .37664 Mdot
.48541 .65205 Mdot
.4963 .56078 Mdot
.63897 .61952 Mdot
.47206 .63393 Mdot
.47079 .35486 Mdot
.74306 .305 Mdot
.58536 .52911 Mdot
.28567 .73809 Mdot
.49355 .63674 Mdot
.47216 .66076 Mdot
.37341 .57967 Mdot
.74286 .44563 Mdot
.80375 .55021 Mdot
.60472 .37503 Mdot
.45798 .64122 Mdot
.68601 .33484 Mdot
.65231 .58589 Mdot
.38209 .63411 Mdot
.36981 .46804 Mdot
.56213 .35157 Mdot
.50346 .38531 Mdot
.50645 .63911 Mdot
.37876 .41337 Mdot
.3365 .54035 Mdot
.46579 .63644 Mdot
.51317 .29666 Mdot
.37977 .65596 Mdot
.32622 .68818 Mdot
.31785 .67225 Mdot
.72558 .43305 Mdot
.69293 .62012 Mdot
.34086 .47794 Mdot
.69764 .47627 Mdot
.30195 .71421 Mdot
.49648 .35063 Mdot
.4986 .62329 Mdot
.3127 .68973 Mdot
.48122 .63679 Mdot
.7098 .46591 Mdot
.7424 .46411 Mdot
.31192 .4916 Mdot
.34642 .49353 Mdot
.48193 .237 Mdot
.7205 .34732 Mdot
.52262 .36162 Mdot
.4058 .34987 Mdot
.31259 .44997 Mdot
.23426 .42195 Mdot
.73807 .46461 Mdot
.69732 .4543 Mdot
.30395 .33697 Mdot
.55545 .36263 Mdot
.59251 .75252 Mdot
.47673 .37195 Mdot
.66026 .35422 Mdot
.45784 .39621 Mdot
.5956 .60939 Mdot
.52583 .35461 Mdot
.40186 .76026 Mdot
.53818 .38354 Mdot
.47106 .37213 Mdot
.63798 .60505 Mdot
.51165 .43842 Mdot
.59934 .62177 Mdot
.5625 .37608 Mdot
.75358 .44557 Mdot
.6124 .61963 Mdot
.78101 .42893 Mdot
.64616 .48723 Mdot
.33915 .68467 Mdot
.71882 .43388 Mdot
.73393 .46472 Mdot
.71355 .29536 Mdot
.35322 .47508 Mdot
.40258 .47123 Mdot
.50711 .37044 Mdot
.64201 .57841 Mdot
.48592 .62259 Mdot
.52416 .38031 Mdot
.49295 .32207 Mdot
.5125 .43468 Mdot
.31241 .48476 Mdot
.6482 .60201 Mdot
.70994 .45891 Mdot
.6013 .58006 Mdot
.6655 .52199 Mdot
.58272 .5907 Mdot
.54333 .45523 Mdot
.52998 .44391 Mdot
.45657 .31097 Mdot
.41266 .32283 Mdot
.26032 .30345 Mdot
.32467 .471 Mdot
.32959 .67949 Mdot
.7461 .44908 Mdot
.39265 .52667 Mdot
.33702 .45586 Mdot
.60465 .59531 Mdot
.496 .37864 Mdot
.51229 .29574 Mdot
.60684 .41474 Mdot
.26373 .46833 Mdot
.75678 .35572 Mdot
.62959 .62115 Mdot
.31978 .68604 Mdot
.38385 .58823 Mdot
.30332 .42748 Mdot
.47737 .54433 Mdot
.48954 .38964 Mdot
.73611 .46392 Mdot
.34054 .50606 Mdot
.76429 .60453 Mdot
.50947 .63782 Mdot
.43134 .56429 Mdot
.51815 .40213 Mdot
.22822 .58613 Mdot
.33884 .46329 Mdot
.69374 .45456 Mdot
.50643 .63994 Mdot
.74146 .46217 Mdot
.32865 .66698 Mdot
.37611 .77028 Mdot
.53018 .34357 Mdot
.4749 .38672 Mdot
.45017 .65259 Mdot
.34147 .47486 Mdot
.66269 .5783 Mdot
.77341 .60979 Mdot
.61829 .57801 Mdot
.52374 .53171 Mdot
.33184 .50818 Mdot
.23116 .48117 Mdot
.58244 .60258 Mdot
.48023 .67646 Mdot
.52344 .52337 Mdot
.48703 .673 Mdot
.47551 .36547 Mdot
.31219 .4576 Mdot
.48929 .66748 Mdot
.76147 .57413 Mdot
.53069 .83973 Mdot
.32935 .52831 Mdot
.52501 .40953 Mdot
.66579 .77716 Mdot
.44583 .82626 Mdot
.40142 .40545 Mdot
.50043 .6206 Mdot
.4966 .4046 Mdot
.53208 .41517 Mdot
.52062 .34692 Mdot
.50645 .65604 Mdot
.62328 .53387 Mdot
.59194 .60211 Mdot
.49971 .36091 Mdot
.73513 .45835 Mdot
.6025 .61364 Mdot
.58323 .64122 Mdot
.61016 .57311 Mdot
.29223 .45638 Mdot
.52031 .42334 Mdot
.36169 .63245 Mdot
.37308 .83125 Mdot
.46656 .64895 Mdot
.33932 .68421 Mdot
.46892 .36465 Mdot
.48383 .20279 Mdot
.34152 .45402 Mdot
.61723 .57869 Mdot
.50596 .39958 Mdot
.72907 .53165 Mdot
.32873 .65284 Mdot
.62734 .61672 Mdot
.35211 .47148 Mdot
.40224 .40661 Mdot
.52293 .39216 Mdot
.54208 .35687 Mdot
.34217 .48465 Mdot
.33086 .76074 Mdot
.37811 .60652 Mdot
.48669 .39119 Mdot
.46899 .63862 Mdot
.40282 .15573 Mdot
.53988 .42082 Mdot
.25809 .48062 Mdot
.34154 .68964 Mdot
.28523 .67367 Mdot
.36414 .24665 Mdot
.47864 .45464 Mdot
.69338 .74533 Mdot
.61816 .25813 Mdot
.64683 .78833 Mdot
.62678 .32711 Mdot
.50928 .75796 Mdot
.4907 .87145 Mdot
.47319 .60762 Mdot
.23573 .38883 Mdot
.83082 .52911 Mdot
.29024 .60535 Mdot
.69373 .51773 Mdot
.58213 .68724 Mdot
.74074 .52344 Mdot
.16907 .48575 Mdot
.58353 .59309 Mdot
.64894 .38047 Mdot
.51175 .33389 Mdot
.43847 .82064 Mdot
.27732 .31079 Mdot
.26947 .28445 Mdot
.64427 .78068 Mdot
.76394 .53484 Mdot
.82069 .62425 Mdot
.6018 .79019 Mdot
.50815 .25093 Mdot
.58023 .46259 Mdot
.66083 .65422 Mdot
.44975 .48191 Mdot
.62242 .28769 Mdot
.43452 .36678 Mdot
.39712 .74207 Mdot
.59625 .5626 Mdot
.4311 .25123 Mdot
.3906 .17023 Mdot
.64208 .5893 Mdot
.34473 .44564 Mdot
.81374 .53158 Mdot
.26076 .5077 Mdot
.44511 .62296 Mdot
.69434 .7448 Mdot
.46559 .84536 Mdot
.23251 .38123 Mdot
.3202 .72363 Mdot
.30214 .37057 Mdot
.63383 .22082 Mdot
.61041 .44039 Mdot
.33271 .51513 Mdot
.55119 .72982 Mdot
.43345 .48642 Mdot
.67783 .63122 Mdot
.21966 .40874 Mdot
.67463 .46104 Mdot
.78141 .40391 Mdot
.35026 .47017 Mdot
.37133 .2533 Mdot
.33493 .70162 Mdot
.31187 .71419 Mdot
.65008 .5738 Mdot
.67953 .71595 Mdot
.34132 .64904 Mdot
.33807 .64094 Mdot
.20334 .58197 Mdot
.797 .68205 Mdot
.65837 .28405 Mdot
.68789 .6809 Mdot
.43108 .68138 Mdot
.62655 .26088 Mdot
.34634 .60446 Mdot
.70312 .32008 Mdot
.42897 .47303 Mdot
.86403 .51045 Mdot
.36884 .79425 Mdot
.84309 .5842 Mdot
.38583 .46832 Mdot
.5707 .39413 Mdot
.70556 .68386 Mdot
.38012 .36406 Mdot
.72365 .48299 Mdot
.78016 .69648 Mdot
.71905 .48015 Mdot
.32864 .43479 Mdot
.28137 .60157 Mdot
.23694 .35128 Mdot
.65192 .55916 Mdot
.76264 .46124 Mdot
.46695 .32879 Mdot
.87796 .44193 Mdot
.71379 .73283 Mdot
.26591 .66877 Mdot
.45618 .84172 Mdot
.55432 .636 Mdot
.65129 .63734 Mdot
.51132 .6544 Mdot
.50322 .85833 Mdot
.32849 .45675 Mdot
.38606 .84236 Mdot
.4968 .85314 Mdot
.25054 .51714 Mdot
.88031 .41214 Mdot
.18443 .52471 Mdot
.28672 .31269 Mdot
.56109 .2497 Mdot
.79472 .40507 Mdot
.35105 .58301 Mdot
.22749 .49377 Mdot
.56353 .63785 Mdot
.32268 .76444 Mdot
.55912 .83973 Mdot
.68508 .34821 Mdot
.54342 .60179 Mdot
.30342 .59827 Mdot
.62267 .45474 Mdot
.2631 .48685 Mdot
.7099 .50617 Mdot
.63716 .43875 Mdot
.83428 .60297 Mdot
.47207 .22406 Mdot
.52517 .14395 Mdot
.63547 .33289 Mdot
.19773 .42606 Mdot
.5972 .77529 Mdot
.76311 .41992 Mdot
.3635 .52577 Mdot
.30964 .62976 Mdot
.55903 .33455 Mdot
.40354 .55617 Mdot
.55817 .30104 Mdot
.67552 .43614 Mdot
.38469 .57766 Mdot
.49842 .79209 Mdot
.64832 .33492 Mdot
.75783 .66243 Mdot
.5465 .47865 Mdot
.29192 .47704 Mdot
.69785 .30143 Mdot
.66862 .30818 Mdot
.48508 .83722 Mdot
.27814 .54771 Mdot
.29372 .7443 Mdot
.28453 .54319 Mdot
.45721 .34269 Mdot
.23734 .39376 Mdot
.43871 .35112 Mdot
.68933 .31902 Mdot
.48153 .42582 Mdot
.20607 .59728 Mdot
.40586 .82816 Mdot
.43151 .27212 Mdot
.63969 .30635 Mdot
.42671 .30219 Mdot
.33627 .77614 Mdot
.71335 .68186 Mdot
.2246 .54087 Mdot
.25744 .44113 Mdot
.87422 .46411 Mdot
.60917 .60408 Mdot
.69267 .34115 Mdot
.49503 .68059 Mdot
.74129 .60884 Mdot
.84054 .49835 Mdot
.29955 .5399 Mdot
.39578 .82578 Mdot
.32596 .62441 Mdot
.66623 .57141 Mdot
.39149 .64805 Mdot
.52108 .60543 Mdot
.45069 .28093 Mdot
.53281 .42887 Mdot
.45496 .30565 Mdot
.68497 .46947 Mdot
.36296 .36672 Mdot
.72836 .65995 Mdot
.50123 .71409 Mdot
.49846 .46371 Mdot
.50811 .72458 Mdot
.31687 .68379 Mdot
.41984 .57178 Mdot
.57708 .84728 Mdot
.50278 .45192 Mdot
.18781 .49624 Mdot
.36424 .78731 Mdot
.51203 .53368 Mdot
.68992 .58756 Mdot
.25022 .62683 Mdot
.8579 .54863 Mdot
.45279 .85452 Mdot
.4751 .81331 Mdot
.67427 .77269 Mdot
.20794 .68608 Mdot
.83993 .45121 Mdot
.30689 .40451 Mdot
.5062 .67628 Mdot
.15198 .66621 Mdot
.59675 .58917 Mdot
.52528 .23468 Mdot
.38156 .35886 Mdot
.72586 .53917 Mdot
.27113 .5119 Mdot
.49663 .47146 Mdot
.53363 .66675 Mdot
.27562 .49798 Mdot
.4682 .32927 Mdot
.74826 .73902 Mdot
.86723 .50912 Mdot
.76529 .72084 Mdot
.37927 .77365 Mdot
.66173 .78733 Mdot
.82755 .5739 Mdot
.37286 .21257 Mdot
.8067 .55687 Mdot
.56479 .37739 Mdot
.70542 .36853 Mdot
.18932 .52274 Mdot
.65049 .56945 Mdot
.34727 .70776 Mdot
.37282 .45162 Mdot
.85391 .51938 Mdot
.58782 .84761 Mdot
.32534 .33139 Mdot
.41194 .24403 Mdot
.64249 .46719 Mdot
.70554 .33523 Mdot
.50052 .27032 Mdot
.39921 .73094 Mdot
.52674 .82364 Mdot
.83184 .56264 Mdot
.66415 .31796 Mdot
.56416 .69727 Mdot
.47731 .80498 Mdot
.20938 .47828 Mdot
.63279 .76867 Mdot
.81927 .52128 Mdot
.26121 .52816 Mdot
.32529 .41861 Mdot
.32655 .54059 Mdot
.38936 .71913 Mdot
.64835 .71392 Mdot
.64411 .27928 Mdot
.61212 .63478 Mdot
.69064 .35367 Mdot
.47168 .51792 Mdot
.81072 .55018 Mdot
.63761 .25811 Mdot
.68065 .35179 Mdot
.49483 .80938 Mdot
.72188 .7543 Mdot
.29955 .72992 Mdot
.77362 .3321 Mdot
.42661 .70773 Mdot
.56837 .3107 Mdot
.56361 .4103 Mdot
.37271 .80607 Mdot
.69626 .78594 Mdot
.40935 .83599 Mdot
.22484 .58243 Mdot
.75411 .57648 Mdot
.51854 .62708 Mdot
.63176 .24219 Mdot
.47139 .71598 Mdot
.5355 .82541 Mdot
.39918 .53402 Mdot
.48996 .60148 Mdot
.33878 .62228 Mdot
.50426 .2452 Mdot
.59029 .24683 Mdot
.38433 .26372 Mdot
.44742 .41449 Mdot
.31938 .28251 Mdot
.36165 .4572 Mdot
.22301 .57047 Mdot
.70171 .32469 Mdot
.61087 .60651 Mdot
.808 .47411 Mdot
.47604 .28585 Mdot
.57616 .36112 Mdot
.66304 .6964 Mdot
.26428 .49059 Mdot
.41335 .31773 Mdot
.63489 .64776 Mdot
.5123 .86693 Mdot
.20182 .53337 Mdot
.48649 .26848 Mdot
.6742 .28252 Mdot
.80017 .51071 Mdot
.38467 .60586 Mdot
.4532 .67368 Mdot
.63272 .7835 Mdot
.6427 .50046 Mdot
.68974 .29572 Mdot
.32757 .27495 Mdot
.75657 .62728 Mdot
.48594 .32627 Mdot
.24923 .64457 Mdot
.42608 .20038 Mdot
.4267 .57094 Mdot
.31978 .43138 Mdot
.27456 .47088 Mdot
.15347 .44915 Mdot
.41691 .76575 Mdot
.24739 .53527 Mdot
.64259 .77144 Mdot
.49923 .66611 Mdot
.28543 .47986 Mdot
.68232 .3623 Mdot
.71007 .58846 Mdot
.44428 .22684 Mdot
.65482 .71647 Mdot
.53547 .26475 Mdot
.46144 .72313 Mdot
.67148 .77024 Mdot
.76713 .68625 Mdot
.4367 .15318 Mdot
.29417 .51093 Mdot
.72412 .64597 Mdot
.73719 .63291 Mdot
.32648 .51463 Mdot
.26175 .47154 Mdot
.59928 .43225 Mdot
.63203 .80516 Mdot
.41866 .52055 Mdot
.38949 .69917 Mdot
.52386 .52422 Mdot
.69083 .52781 Mdot
.77448 .59852 Mdot
.63015 .2771 Mdot
.65039 .76051 Mdot
.37123 .26377 Mdot
.80604 .39801 Mdot
.47415 .29812 Mdot
.49594 .22531 Mdot
.63164 .24176 Mdot
.59678 .4595 Mdot
.2217 .41235 Mdot
.51921 .78982 Mdot
.51734 .34942 Mdot
.79135 .6934 Mdot
.48413 .83173 Mdot
.39125 .55817 Mdot
.6414 .65738 Mdot
.54818 .37525 Mdot
.52678 .42206 Mdot
.33867 .41262 Mdot
.27833 .66319 Mdot
.82466 .40247 Mdot
.64694 .34868 Mdot
.56648 .3061 Mdot
.32161 .2765 Mdot
.18833 .49571 Mdot
.69339 .69603 Mdot
.56683 .79977 Mdot
.45252 .5238 Mdot
.19127 .52572 Mdot
.43222 .58888 Mdot
.38146 .69657 Mdot
.46124 .7397 Mdot
.82365 .58245 Mdot
.58695 .42962 Mdot
.2889 .64418 Mdot
.79793 .55252 Mdot
.4708 .36169 Mdot
.27098 .60725 Mdot
.61522 .77852 Mdot
.56371 .16291 Mdot
.33566 .59829 Mdot
.72802 .76217 Mdot
.45691 .30752 Mdot
.29989 .64202 Mdot
.84652 .4923 Mdot
.65934 .19072 Mdot
.39084 .73782 Mdot
.82557 .6192 Mdot
.40093 .61488 Mdot
.65008 .76769 Mdot
.49779 .60847 Mdot
.47335 .49639 Mdot
.39087 .38095 Mdot
.62517 .80811 Mdot
.70433 .62792 Mdot
.6798 .72681 Mdot
.32048 .4116 Mdot
.66178 .79411 Mdot
.42224 .4693 Mdot
.16184 .4348 Mdot
.5879 .57419 Mdot
.18747 .58896 Mdot
.26679 .42385 Mdot
.53055 .27807 Mdot
.68055 .33345 Mdot
.18632 .39532 Mdot
.3242 .23931 Mdot
.33288 .40331 Mdot
.68307 .39101 Mdot
.25894 .63708 Mdot
.66824 .27637 Mdot
.53477 .8298 Mdot
.16644 .47386 Mdot
.75542 .61819 Mdot
.25032 .56376 Mdot
.35547 .77248 Mdot
.27544 .6693 Mdot
.45979 .75813 Mdot
.683 .69226 Mdot
.35889 .73057 Mdot
.54363 .26726 Mdot
.20745 .27688 Mdot
.52046 .57913 Mdot
.60258 .42466 Mdot
.85079 .55606 Mdot
.52096 .82522 Mdot
.39169 .5323 Mdot
.21638 .40583 Mdot
.54151 .21673 Mdot
.73873 .38337 Mdot
.47402 .37535 Mdot
.66833 .79113 Mdot
.7661 .40889 Mdot
.80013 .66452 Mdot
.31247 .77409 Mdot
.32832 .2852 Mdot
.53339 .45377 Mdot
.56506 .63703 Mdot
.61884 .41924 Mdot
.67334 .3969 Mdot
.83325 .58356 Mdot
.51061 .23068 Mdot
.58191 .51715 Mdot
.51136 .75049 Mdot
.60751 .75474 Mdot
.59011 .34617 Mdot
.18537 .54017 Mdot
.27287 .64799 Mdot
.63332 .31735 Mdot
.46283 .80184 Mdot
.69295 .33135 Mdot
.35598 .24995 Mdot
.64008 .24964 Mdot
.34301 .56058 Mdot
.56344 .65469 Mdot
.65282 .61871 Mdot
.78874 .6316 Mdot
.57926 .78448 Mdot
.20838 .60245 Mdot
.78352 .35275 Mdot
.30413 .62785 Mdot
.64911 .39458 Mdot
.75078 .65419 Mdot
.34358 .58247 Mdot
.65837 .66253 Mdot
.58056 .24461 Mdot
.48843 .22975 Mdot
.53922 .79239 Mdot
.46239 .45719 Mdot
.56229 .84138 Mdot
.64128 .28043 Mdot
.78872 .60756 Mdot
.637 .4761 Mdot
.38394 .33297 Mdot
.27271 .35707 Mdot
.79445 .43136 Mdot
.44602 .56661 Mdot
.87662 .44848 Mdot
.35315 .50672 Mdot
.79902 .67895 Mdot
.48839 .62674 Mdot
.47184 .16532 Mdot
.53589 .80755 Mdot
.46144 .53173 Mdot
.52533 .51553 Mdot
.24942 .64859 Mdot
.32485 .64774 Mdot
.34726 .77423 Mdot
.30946 .53991 Mdot
.59397 .57723 Mdot
.59757 .51833 Mdot
.39251 .70631 Mdot
.75758 .67253 Mdot
.55348 .34523 Mdot
.65726 .56035 Mdot
.60526 .45118 Mdot
.43643 .61151 Mdot
.37759 .8069 Mdot
.52733 .77933 Mdot
.45265 .33494 Mdot
.70869 .33621 Mdot
.83939 .55631 Mdot
.50193 .848 Mdot
.35913 .53684 Mdot
.55592 .29962 Mdot
.45084 .68382 Mdot
.8245 .47066 Mdot
.71518 .72554 Mdot
.58098 .75867 Mdot
.37811 .63364 Mdot
.6582 .2872 Mdot
.78958 .71852 Mdot
.86579 .50925 Mdot
.79195 .35674 Mdot
.53027 .52425 Mdot
.38127 .44037 Mdot
.48637 .20529 Mdot
.78582 .61241 Mdot
.19014 .60845 Mdot
.48156 .82291 Mdot
.69073 .33646 Mdot
.61232 .18392 Mdot
.28427 .28172 Mdot
.64185 .52303 Mdot
.27353 .358 Mdot
.39633 .34443 Mdot
.50358 .60607 Mdot
.73308 .3896 Mdot
.62555 .5096 Mdot
.44513 .62846 Mdot
.26174 .6396 Mdot
.34493 .64285 Mdot
.79166 .60275 Mdot
.43768 .21391 Mdot
.54639 .29225 Mdot
.73245 .69355 Mdot
.2796 .45396 Mdot
.75906 .60933 Mdot
.80154 .51577 Mdot
.62813 .51456 Mdot
.59661 .58412 Mdot
.43279 .39416 Mdot
.40561 .58522 Mdot
.41826 .5931 Mdot
.704 .25905 Mdot
.70272 .48361 Mdot
.37887 .48312 Mdot
.24551 .32193 Mdot
.29654 .50881 Mdot
.67742 .80194 Mdot
.40076 .73147 Mdot
.30907 .28821 Mdot
.49372 .58414 Mdot
.56372 .71046 Mdot
.69303 .23552 Mdot
.5057 .24874 Mdot
.73173 .49737 Mdot
.36346 .43037 Mdot
.36195 .46291 Mdot
.49654 .58847 Mdot
.35367 .6799 Mdot
.39089 .24868 Mdot
.18152 .48717 Mdot
.80203 .50563 Mdot
.31477 .51868 Mdot
.63588 .52665 Mdot
.41796 .3561 Mdot
.5661 .84802 Mdot
.60181 .57773 Mdot
.87437 .47575 Mdot
.53286 .44393 Mdot
.8283 .44784 Mdot
.38083 .81143 Mdot
.36873 .60072 Mdot
.53746 .52502 Mdot
.62017 .6805 Mdot
.51717 .3223 Mdot
.55145 .29135 Mdot
.34941 .48473 Mdot
.80129 .56913 Mdot
.70519 .45 Mdot
.74267 .3468 Mdot
.45197 .67547 Mdot
.20636 .44671 Mdot
.1906 .54474 Mdot
.35851 .45054 Mdot
.65648 .50777 Mdot
.70909 .65529 Mdot
.5361 .48891 Mdot
.60382 .45331 Mdot
.79661 .62479 Mdot
.44194 .23679 Mdot
.33429 .51378 Mdot
.79198 .36098 Mdot
.64615 .43124 Mdot
.46996 .86415 Mdot
.41657 .40638 Mdot
.6066 .44019 Mdot
.54614 .48156 Mdot
.24566 .63365 Mdot
.37187 .24347 Mdot
.55568 .80877 Mdot
.70073 .30818 Mdot
.47021 .48333 Mdot
.68253 .35414 Mdot
.44141 .35241 Mdot
.50478 .75257 Mdot
.18124 .57069 Mdot
.62508 .19134 Mdot
.28589 .37726 Mdot
.35132 .61479 Mdot
.27848 .45021 Mdot
.1887 .50015 Mdot
.3631 .50123 Mdot
.67326 .53567 Mdot
.43379 .2532 Mdot
.5349 .80874 Mdot
.51667 .85871 Mdot
.48387 .83667 Mdot
.62485 .40231 Mdot
.59536 .75918 Mdot
.57435 .25301 Mdot
.41167 .39546 Mdot
.47491 .53784 Mdot
.51135 .32095 Mdot
.59005 .35486 Mdot
.36741 .54718 Mdot
.21819 .61071 Mdot
.57825 .4275 Mdot
.6168 .8071 Mdot
.46657 .8616 Mdot
.69964 .76415 Mdot
.64803 .71153 Mdot
.295 .45075 Mdot
.86071 .53639 Mdot
.3424 .24512 Mdot
.52475 .83434 Mdot
.27095 .42036 Mdot
.15075 .47223 Mdot
.84013 .51112 Mdot
.50766 .79374 Mdot
.23797 .50572 Mdot
.25978 .70247 Mdot
.38611 .80772 Mdot
.16169 .43719 Mdot
.57041 .27115 Mdot
.36669 .79893 Mdot
.87551 .43924 Mdot
.28409 .40633 Mdot
.32898 .64393 Mdot
.26545 .35681 Mdot
.5493 .25397 Mdot
.17394 .47082 Mdot
.56738 .38696 Mdot
.57165 .62158 Mdot
.71622 .52063 Mdot
.68389 .32748 Mdot
.43359 .41696 Mdot
.17398 .45733 Mdot
.66891 .40007 Mdot
.6468 .38322 Mdot
.7251 .62859 Mdot
.8329 .52559 Mdot
.38402 .24199 Mdot
.49743 .30151 Mdot
.36521 .44216 Mdot
.7012 .43645 Mdot
.61194 .28971 Mdot
.54977 .38525 Mdot
.4842 .55615 Mdot
.60151 .41584 Mdot
.74394 .74537 Mdot
.70438 .55522 Mdot
.60896 .5516 Mdot
.27432 .48753 Mdot
.27122 .65824 Mdot
.70868 .70009 Mdot
.28692 .60369 Mdot
.17925 .43561 Mdot
.46664 .23162 Mdot
.68171 .76138 Mdot
.32492 .62956 Mdot
.65002 .30741 Mdot
.66178 .23493 Mdot
.47828 .61167 Mdot
.38595 .37816 Mdot
.82783 .58842 Mdot
.2837 .61859 Mdot
.29018 .4457 Mdot
.47315 .78861 Mdot
.52437 .75601 Mdot
.27414 .62575 Mdot
.36264 .78572 Mdot
.73388 .64712 Mdot
.3009 .32103 Mdot
.75711 .69286 Mdot
.56581 .62965 Mdot
.66751 .32353 Mdot
.44141 .77551 Mdot
.17113 .4756 Mdot
.53018 .48843 Mdot
.57987 .83099 Mdot
.48041 .53586 Mdot
.77938 .4139 Mdot
.53656 .34798 Mdot
.413 .21995 Mdot
.22831 .61741 Mdot
.46222 .79649 Mdot
.25948 .54286 Mdot
.31659 .44044 Mdot
.20286 .56664 Mdot
.66319 .6461 Mdot
.75568 .39517 Mdot
.58758 .28333 Mdot
.23396 .47157 Mdot
.65901 .48035 Mdot
.32783 .70789 Mdot
.5421 .43889 Mdot
.7824 .3962 Mdot
.63586 .73734 Mdot
.37794 .39351 Mdot
.30373 .40426 Mdot
.78804 .63485 Mdot
.66562 .70974 Mdot
.20427 .60601 Mdot
.30665 .40988 Mdot
.2849 .70645 Mdot
.3059 .26406 Mdot
.27843 .5824 Mdot
.50846 .43268 Mdot
.67293 .53494 Mdot
.30412 .50332 Mdot
.76093 .67267 Mdot
.38764 .49134 Mdot
.77977 .42927 Mdot
.42816 .54264 Mdot
.70233 .68406 Mdot
.62749 .47683 Mdot
.38433 .81159 Mdot
.25981 .70286 Mdot
.70194 .32361 Mdot
.44486 .65107 Mdot
.39842 .62446 Mdot
.33152 .59265 Mdot
.58564 .8149 Mdot
.33866 .54923 Mdot
.45527 .28933 Mdot
.34137 .61825 Mdot
.42141 .29079 Mdot
.33461 .78619 Mdot
.72682 .35052 Mdot
.47093 .54014 Mdot
.4862 .2721 Mdot
.319 .71585 Mdot
.32264 .69905 Mdot
.72048 .54627 Mdot
.37081 .23331 Mdot
.55275 .58702 Mdot
.56452 .52797 Mdot
.56269 .42192 Mdot
.47872 .2033 Mdot
.7447 .69869 Mdot
.38934 .52865 Mdot
.47352 .53097 Mdot
.794 .55569 Mdot
.76416 .39605 Mdot
.35414 .16726 Mdot
.78359 .70654 Mdot
.53797 .34846 Mdot
.5404 .5123 Mdot
.74083 .35066 Mdot
.63666 .62709 Mdot
.3943 .25785 Mdot
.78269 .64514 Mdot
.46299 .65492 Mdot
.7526 .58547 Mdot
.35813 .6793 Mdot
.24195 .6411 Mdot
.79793 .44071 Mdot
.51276 .61759 Mdot
.69165 .7964 Mdot
.47296 .81961 Mdot
.22908 .60886 Mdot
.28443 .20439 Mdot
.21477 .58638 Mdot
.41114 .46734 Mdot
.70137 .64838 Mdot
.71719 .75981 Mdot
.52419 .52718 Mdot
.7391 .60413 Mdot
.31086 .40043 Mdot
.70142 .31751 Mdot
.65606 .352 Mdot
.24937 .56446 Mdot
.20996 .55765 Mdot
.16377 .42161 Mdot
.56563 .70891 Mdot
.72334 .26817 Mdot
.35962 .26268 Mdot
.76585 .69325 Mdot
.3908 .73569 Mdot
.59955 .17844 Mdot
.50523 .85771 Mdot
.69966 .37482 Mdot
.1824 .45363 Mdot
.69988 .61777 Mdot
.74216 .32917 Mdot
.454 .19513 Mdot
.372 .74953 Mdot
.4525 .23705 Mdot
.54156 .71356 Mdot
.27237 .56178 Mdot
.68667 .35337 Mdot
.40966 .31351 Mdot
.47488 .54076 Mdot
.81164 .62616 Mdot
.19393 .39509 Mdot
.67303 .28682 Mdot
.76915 .57773 Mdot
.75663 .34291 Mdot
.72419 .70685 Mdot
.64483 .7477 Mdot
.56481 .48717 Mdot
.85193 .4071 Mdot
.83351 .6039 Mdot
.29256 .59174 Mdot
.53282 .41989 Mdot
.48231 .86966 Mdot
.59161 .48795 Mdot
.32078 .40221 Mdot
.41024 .81046 Mdot
.64348 .34754 Mdot
.59742 .4115 Mdot
.53549 .42458 Mdot
.55807 .2438 Mdot
.2406 .49499 Mdot
.40785 .3198 Mdot
.79139 .47686 Mdot
.67802 .28663 Mdot
.19571 .39782 Mdot
.80604 .41853 Mdot
.41619 .41991 Mdot
.32466 .51008 Mdot
.72863 .75394 Mdot
.49395 .25825 Mdot
.49181 .28561 Mdot
.27877 .32838 Mdot
.33437 .54552 Mdot
.56663 .66726 Mdot
.56094 .3051 Mdot
.38655 .60266 Mdot
.67938 .33096 Mdot
.7761 .62727 Mdot
.3907 .38693 Mdot
.88226 .40963 Mdot
.38297 .81561 Mdot
.32794 .51991 Mdot
.34758 .39153 Mdot
.63946 .51639 Mdot
.70818 .75467 Mdot
.55525 .69856 Mdot
.80063 .51233 Mdot
.23577 .32461 Mdot
.71261 .30443 Mdot
.45669 .37533 Mdot
.38007 .77617 Mdot
.53219 .84819 Mdot
.20562 .35566 Mdot
.56262 .84069 Mdot
.54828 .44846 Mdot
.57621 .38701 Mdot
.5729 .13791 Mdot
.65966 .7688 Mdot
.48259 .45513 Mdot
.24267 .50546 Mdot
.24954 .48809 Mdot
.53439 .3369 Mdot
.34917 .66193 Mdot
.61471 .27011 Mdot
.65539 .36227 Mdot
.62982 .80505 Mdot
.27698 .48416 Mdot
.51421 .53752 Mdot
.51612 .66181 Mdot
.506 .52637 Mdot
.46287 .31921 Mdot
.48124 .67055 Mdot
.65583 .3736 Mdot
.58393 .4966 Mdot
.48133 .69936 Mdot
.55532 .27027 Mdot
.35384 .71399 Mdot
.56582 .28547 Mdot
.62826 .41819 Mdot
.30397 .41964 Mdot
.32444 .23862 Mdot
.67003 .39835 Mdot
.67252 .41012 Mdot
.36535 .79489 Mdot
.18467 .64375 Mdot
.50709 .56359 Mdot
.39146 .42667 Mdot
.41271 .44606 Mdot
.35974 .24172 Mdot
.28976 .32447 Mdot
.52762 .66193 Mdot
.32359 .69497 Mdot
.57032 .43293 Mdot
.48552 .26924 Mdot
.51491 .65519 Mdot
.76508 .73876 Mdot
.56152 .40376 Mdot
.34662 .28911 Mdot
.56879 .81875 Mdot
.76522 .60428 Mdot
.60402 .33867 Mdot
.51513 .32003 Mdot
.42295 .4848 Mdot
.59156 .49381 Mdot
.42834 .32444 Mdot
.78295 .58872 Mdot
.72146 .73108 Mdot
.61315 .33994 Mdot
.3352 .28982 Mdot
.50638 .36299 Mdot
.75085 .43992 Mdot
.39993 .58053 Mdot
.70854 .27155 Mdot
.7441 .48566 Mdot
.50168 .84472 Mdot
.6405 .41129 Mdot
.64646 .34777 Mdot
.25311 .34951 Mdot
.79556 .67536 Mdot
.32977 .60054 Mdot
.32154 .28792 Mdot
.3775 .5548 Mdot
.46846 .76585 Mdot
.6818 .38987 Mdot
.52499 .60332 Mdot
.5844 .40577 Mdot
.24602 .48206 Mdot
.62221 .82255 Mdot
.50357 .24914 Mdot
.5251 .66148 Mdot
.5423 .79387 Mdot
.30632 .26625 Mdot
.52383 .51504 Mdot
.23856 .24368 Mdot
.56816 .68813 Mdot
.69794 .79121 Mdot
.7598 .63264 Mdot
.50148 .47914 Mdot
.25785 .63322 Mdot
.43783 .41007 Mdot
.6357 .60041 Mdot
.71406 .74545 Mdot
.42435 .34539 Mdot
.26938 .57641 Mdot
.5634 .38519 Mdot
.42146 .50221 Mdot
.45089 .29877 Mdot
.57693 .76805 Mdot
.57411 .60748 Mdot
.35138 .5401 Mdot
.64272 .75394 Mdot
.59462 .49257 Mdot
.14985 .50254 Mdot
.83389 .58384 Mdot
.62947 .78605 Mdot
.61934 .74688 Mdot
.47437 .16031 Mdot
.36055 .43034 Mdot
.4114 .3878 Mdot
.45024 .62823 Mdot
.56825 .24898 Mdot
.27682 .62129 Mdot
.77865 .61855 Mdot
.27865 .70099 Mdot
.54352 .48848 Mdot
.16373 .32871 Mdot
.69103 .37022 Mdot
.39949 .51554 Mdot
.25857 .60692 Mdot
.60538 .81032 Mdot
.77874 .53479 Mdot
.28501 .73708 Mdot
.40173 .74912 Mdot
.44834 .34158 Mdot
.43166 .20263 Mdot
.79656 .38402 Mdot
.56232 .75566 Mdot
.7129 .25487 Mdot
.58964 .77555 Mdot
.6231 .28905 Mdot
.45505 .79207 Mdot
.29664 .51098 Mdot
.28963 .52152 Mdot
.40007 .723 Mdot
.35982 .69485 Mdot
.36999 .41537 Mdot
.70374 .73883 Mdot
.6049 .20972 Mdot
.80435 .52951 Mdot
.67661 .77461 Mdot
.42162 .6736 Mdot
.27191 .45459 Mdot
.66319 .40144 Mdot
.6789 .48695 Mdot
.62402 .63731 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0V_ooool2o`000:gooooo000Looooo`03o`00
0?oooooooooo093ooooo0_l00008ooooo`;o0000[Oooool001cooooo00?o0000ooooooooool0T?oo
ool2o`0002Cooooo0_l0002Aooooo`007?ooool00ol0003oooooooooo`2fooooo`;o0000TOooool0
01cooooo00?o0000ooooooooool0Ooooool2o`0001Wooooo0_l0000;ooooo`;o0000X?ooool001co
oooo00?o0000ooooooooool0Ooooool2o`0001Wooooo0_l0000;ooooo`;o0000X?ooool001cooooo
00?o0000ooooooooool0S?ooool2o`000;_ooooo000Looooo`;o0000Roooool8o`0000Wooooo0_l0
002/ooooo`007?ooool00ol0003oooooooooo`1oooooo`;o00002Oooool2o`0000;ooooo1?l00009
ooooo`;o0000[?ooool001cooooo00?o0000ooooooooool0NOooool2o`0000Cooooo0_l000000ooo
oooo0000o`000002ooooo`;o0000`Oooool001cooooo00?o0000ooooooooool0NOooool2o`0000Oo
oooo0_l00002ooooo`;o00003_ooool2o`0000gooooo0_l0000<ooooo`;o00000oooool2o`0000Go
oooo0_l00028ooooo`007?ooool00ol0003oooooooooo`1hooooo`;o00007?ooool2o`0000gooooo
0_l0000<ooooo`;o00000oooool3o`0000Cooooo0_l00028ooooo`007?ooool00ol0003ooooooooo
o`1_ooooo`;o00000_ooool2o`0000?ooooo0_l0000Looooo`;o00000_ooool2o`0001gooooo0_l0
002>ooooo`007?ooool00ol0003oooooooooo`1_ooooo`;o00000_ooool2o`0000Kooooo0_l0000M
ooooo`;o0000[Oooool001cooooo00?o0000ooooooooool0Loooool2o`0000Kooooo0_l0003<oooo
o`007?ooool00ol0003oooooooooo`1cooooo`;o00000_ooool2o`0004Kooooo0_l00028ooooo`00
7?ooool00ol0003oooooooooo`1gooooo`;o0000A_ooool2o`0008Sooooo000Looooo`03o`000?oo
oooooooo07_ooooo0_l00016ooooo`;o0000Q?ooool001cooooo00?o0000ooooooooool0Noooool2
o`0004Kooooo0_l00024ooooo`007?ooool00ol0003oooooooooo`1booooo`;o00005?ooool2o`00
03_ooooo0_l0000;ooooo`;o0000MOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2
ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo05oooooo0_l0000Aooooo`;o00005?ooool3
o`0003[ooooo1?l00009ooooo`;o0000MOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Ooo
ool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo05oooooo
0_l0000Xooooo`;o00001Oooool3o`0003Cooooo0_l00020ooooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0K?oo
ool2o`0000oooooo0_l0000Aooooo`Ko0000/oooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool02oooool00onHV9So8B4Qonk^kP06ooooo`?o0000G?ooool2o`0000kooooo0_l0000?
ooooo`;o00002?ooool3o`0000Wooooo1?l00002ooooo`;o0000[_ooool00003ooooool0003ooooo
00;ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo
05Wooooo0_l000000ooooooo0000o`00000Nooooo`;o00002Oooool3o`0000_ooooo0_l000000ooo
oooo0000o`000002o`000:gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Iooooo`;o00007_ooool2o`000003
ooooool0003o000001[ooooo1?l0002]ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;oooo
o`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`1gooooo`Co00008?ooool2
o`0000Sooooo0_l000000ooooooo0000o`00000Gooooo`Co00002oooool2o`0007Oooooo00001_oo
ooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`00
0?oooooooooo06Cooooo0_l0000?ooooo`Co00002?ooool2o`0000Oooooo0_l00007ooooo`;o0000
1_ooool2o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l000000ol0000Dooooo`Go0000
2_ooool3o`0000Sooooo0_l0001/ooooo`007?ooool00ol0003oooooooooo`1Rooooo`Co00002?oo
ool2o`0000Gooooo0_l0000:ooooo`;o00001oooool2o`000003ooooool0003o000000Cooooo0_l0
0003ooooo`;o00001Oooool2o`0000Sooooo1Ol0000Eooooo`?o00002oooool4o`0000Kooooo0_l0
001/ooooo`007?ooool00ol0003oooooooooo`1Rooooo`;o00001_ooool2o`0000;ooooo0_l00005
ooooo`;o00002oooool5o`0000Kooooo0_l00003ooooo`?o00000oooool6o`0000kooooo0_l00002
ooooo`;o00004Oooool2o`0000Gooooo0_l00007ooooo`;o0000M?ooool001cooooo00?o0000oooo
ooooool0J_ooool2o`0000Wooooo0_l00009ooooo`Wo00002Oooool3o`000003ooooool0003o0000
00Ko00004_ooool2o`0001Sooooo0_l0000=ooooo`;o0000K_ooool001cooooo00?o0000oooooooo
ool0J_ooool2o`0001Cooooo0_l00005ooooo`;o00000_ooool4o`0000Oooooo1?l00003ooooo`;o
00004oooool3o`0002Cooooo0_l0001^ooooo`007?ooool00ol0003oooooooooo`1Xooooo`;o0000
4oooool2o`0000cooooo1?l0000<ooooo`Co00000oooool2o`0000kooooo0ol000000ooooooo0000
o`00000Cooooo`?o0000Noooool001cooooo00?o0000ooooooooool0J?ooool2o`0000_ooooo0_l0
0002ooooo`;o000000Coooooo`000?l0003o00005Oooool4o`0000;ooooo0ol00005ooooo`;o0000
4_ooool2o`0000Wooooo0_l00008ooooo`Co0000N_ooool001cooooo00?o0000ooooooooool0FOoo
ool2o`00013ooooo0_l000000ooooooo0000o`000005ooooo`;o00000_ooool2o`000003ooooool0
003o000000kooooo0_l00006ooooo`So00002oooool2o`0000kooooo1?l00006ooooo`;o00002_oo
ool2o`0000Cooooo0_l00008ooooo`;o0000J_ooool001cooooo00?o0000ooooooooool0FOooool2
o`0000Gooooo0_l00004ooooo`;o00000oooool2o`000003ooooool0003o000000oooooo0_l0000;
ooooo`;o000000?oooooo`000?l000001oooool3o`0000Wooooo0_l000000ooooooo0000o`00000>
ooooo`Co00006?ooool2o`0000Sooooo0_l0001Zooooo`007?ooool00ol0003oooooooooo`1Poooo
o`;o00000_ooool4o`0000Oooooo1?l00006ooooo`;o00001?ooool2o`0000kooooo0_l0000Coooo
o`;o00002Oooool2o`0000Sooooo1?l00006ooooo`;o00001?ooool2o`00013ooooo0_l0001/oooo
o`007?ooool00ol0003oooooooooo`1:ooooo`;o00002Oooool2o`0000gooooo0_l00005ooooo`;o
00000_ooool4o`0000;ooooo0_l00002ooooo`;o00001oooool2o`0001cooooo0_l0000=ooooo`;o
000000?oooooo`000?l000001Oooool4o`000003ooooool0003o000000;o000000?oooooo`000?l0
00001?ooool2o`00013ooooo0_l0001/ooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o0000
2Oooool2o`0001Cooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l00002ooooo`Co0000
1Oooool2o`0001cooooo0ol0000?ooooo`;o000000?oooooo`000?l000000_ooool9o`0000?ooooo
0_l00002ooooo`;o00001_ooool2o`0000Wooooo0_l0001[ooooo`007?ooool2o`0006oooooo1?l0
00001?oooooo0000o`000?ooool2o`000003ooooool0003o000000;o00002oooool2o`0000oooooo
0_l00005ooooo`?o00003oooool2o`000003ooooool0003o000000;ooooo0_l000001?oooooo0000
o`000?l00006ooooo`;o00001?ooool3o`0000?ooooo0ol00008ooooo`;o0000Joooool001cooooo
00?o0000ooooooooool0K_ooool4o`0000?ooooo0ol0000;ooooo`;o00000oooool3o`0000kooooo
0_l00006ooooo`;o00001oooool2o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`Co0000
0_ooool4o`0000?ooooo0_l00005ooooo`Ko000000?oooooo`000?l000004?ooool2o`0006?ooooo
000Looooo`03o`000?oooooooooo06Cooooo0_l0000?ooooo`;o00001Oooool2o`0000Gooooo0_l0
0004ooooo`;o00004Oooool3o`0000_ooooo0_l00003ooooo`;o00001_ooool2o`0000Kooooo0_l0
0003ooooo`?o00000_ooool8o`000004ooooool0003o0000o`0000oooooo0_l0001Sooooo`007?oo
ool00ol0003oooooooooo`14ooooo`;o00002Oooool2o`0000_ooooo0_l00006ooooo`;o00001?oo
ool2o`0000Cooooo0_l0000:ooooo`;o00007_ooool3o`0001Cooooo0_l0000@ooooo`;o000000?o
ooooo`000?l000000ol00005ooooo`Co00001oooool2o`0000;ooooo0_l0001Vooooo`007?ooool0
0ol0003oooooooooo`14ooooo`;o00002Oooool2o`0000_ooooo0_l00002ooooo`;o00000_ooool2
o`0000;ooooo1?l00004ooooo`?o00000_ooool2o`0000;ooooo0_l0000Booooo`?o00008oooool3
o`0000Oooooo0_l00009ooooo`?o00002Oooool2o`0000Cooooo1Ol00002ooooo`;o0000I_ooool0
01cooooo00?o0000ooooooooool0COooool2o`00017ooooo0_l00006ooooo`;o00001oooool2o`00
00;ooooo0_l00002ooooo`;o00004_ooool3o`0001[ooooo0_l000000ooooooo0000o`000005oooo
o`;o00001oooool2o`0000[ooooo0_l00002ooooo`;o00002_ooool5o`0006_ooooo000Looooo`03
o`000?oooooooooo04gooooo0_l0000Aooooo`;o00001_ooool2o`00033ooooo0_l00003ooooo`;o
00002Oooool2o`000003ooooool0003o000000;ooooo0_l0000?ooooo`Co00000oooool6o`0000[o
oooo0_l0000:ooooo`Co0000H?ooool001cooooo00?o0000ooooooooool0Goooool2o`0000?ooooo
0_l00002ooooo`;o00007_ooool4o`0000kooooo0_l000000ooooooo0000o`000002o`00013ooooo
0_l00003ooooo`;o00002_ooool4o`0000Gooooo1?l0000:ooooo`;o00001oooool2o`000003oooo
ool0003o000000?o0000Goooool001cooooo00?o0000ooooooooool0??ooool2o`0000;ooooo0_l0
000Mooooo`[o00007oooool4o`0000kooooo0_l000000ooooooo0000o`00000Gooooo`Co00002Ooo
ool3o`0000Gooooo0_l00008ooooo`;o00000oooool2o`0000Kooooo0_l00004ooooo`;o0000Gooo
ool001cooooo00?o0000ooooooooool0??ooool2o`0000;ooooo0_l0000Dooooo`;o00002Oooool8
o`00043ooooo0_l0000=ooooo`;o00002_ooool2o`0000?ooooo1_l00006ooooo`;o00000oooool4
o`0006_ooooo000Looooo`03o`000?oooooooooo05Cooooo1?l000000ooooooo0000o`000007oooo
o`Co00001_ooool2o`00027ooooo0_l00005ooooo`;o00004Oooool2o`0000Cooooo0_l00007oooo
o`;o00002?ooool2o`0000Gooooo0_l00002ooooo`;o00002?ooool2o`0000?ooooo0_l00002oooo
o`;o0000Ioooool001cooooo00?o0000ooooooooool0E?ooool2o`0000?ooooo0_l00009ooooo`;o
000000?oooooo`000?l000000oooool2o`00027ooooo0_l00005ooooo`?o00000oooool2o`00017o
oooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Gooooo0_l00005ooooo`;o
00000_ooool2o`0000?ooooo0_l00003ooooo`;o00001oooool4o`0006Gooooo000Looooo`03o`00
0?oooooooooo05Cooooo1_l00007ooooo`;o00000_ooool4o`0000Cooooo0_l0000Qooooo`;o0000
1?ooool3o`0000?ooooo0_l00009ooooo`;o000000?oooooo`000?l000001_ooool7o`0000;ooooo
0_l00009ooooo`Go00001oooool2o`0000?ooooo0ol00006ooooo`Co0000IOooool001cooooo00?o
0000ooooooooool0E_ooool4o`0000Gooooo1?l00002ooooo`;o00000_ooool2o`0000;ooooo0_l0
000Fooooo`;o00000oooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`000004oooo
ool0003o0000ooooo`;o00001oooool4o`000003ooooool0003o000000;ooooo0ol000000ooooooo
0000o`000002ooooo`;o00000oooool2o`0000Kooooo0_l000000ooooooo0000o`000003o`0000Oo
oooo0_l00003ooooo`?o00001_ooool4o`0000kooooo0_l0001Eooooo`007?ooool00ol0003ooooo
ooooo`1Oooooo`;o00001_ooool4o`0001[ooooo0_l00003ooooo`;o00001?ooool2o`000003oooo
ool0003o000000Cooooo0_l00002ooooo`;o00001Oooool7o`0000?ooooo0ol00005ooooo`;o0000
00?oooooo`000?l000000_l00006ooooo`Go000000?oooooo`000?l000000_ooool2o`00017ooooo
1_l00003ooooo`;o00001oooool2o`0005Gooooo000Looooo`03o`000?oooooooooo05_ooooo0_l0
000:ooooo`;o00006_ooool4o`0000oooooo0_l00005ooooo`;o00001?ooool3o`000003ooooool0
003o000000;o000000Coooooo`000?l0003o00002_ooool3o`0000Wooooo1Ol00003ooooo`;o0000
3Oooool2o`0000;ooooo0_l000001?oooooo0000o`000?l00003ooooo`;o00000_ooool2o`0005[o
oooo000Looooo`;o0000G?ooool2o`0002Kooooo0_l0000:ooooo`;o00001Oooool2o`0000Kooooo
0_l00003ooooo`;o000000?oooooo`000?l000000_l00002ooooo`?o00000_ooool3o`0000Kooooo
1?l0000:ooooo`;o00004_ooool2o`000005ooooool0003o0000o`000?ooool00ol00007ooooo`;o
0000F_ooool001cooooo00?o0000ooooooooool0DOooool2o`0000Kooooo0_l0000/ooooo`;o0000
1_ooool2o`0000[ooooo1Ol00006ooooo`;o00002Oooool3o`0000Kooooo1?l0000:ooooo`;o0000
5Oooool2o`0000?ooooo0_l0001Sooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o00000_oo
ool2o`0000;ooooo0ol00007ooooo`;o00008_ooool2o`0000Oooooo1?l000000ooooooo0000o`00
0004ooooo`Co00001oooool5o`0000Oooooo1?l0000Booooo`;o00000_ooool2o`000003ooooool0
003o000001;ooooo1Ol00006ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0D?ooool2
o`0000?ooooo0ol00002ooooo`;o00001oooool2o`0001oooooo0_l0000:ooooo`Co000000?ooooo
o`000?l000001?ooool2o`0000Gooooo0_l00002ooooo`[o000000?oooooo`000?l000001?l00000
0ooooooo0000o`000006ooooo`;o00002_ooool2o`000003ooooool0003o000000Cooooo0_l00008
ooooo`?o000000Coooooo`000?l0003ooooo0ol00005ooooo`;o0000FOooool001cooooo00?o0000
ooooooooool0D?ooool4o`0000;ooooo0_l000000ooooooo0000o`00000Vooooo`;o000000?ooooo
o`000?l000001_ooool2o`0000?ooooo0_l000001?oooooo0000o`000?l00002ooooo`Ko00000ooo
ool>o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000006ooooo`Co00004Ooo
ool2o`0000Sooooo0ol000001?oooooo0000o`000?ooool5o`0005kooooo000Looooo`03o`000?oo
oooooooo05;ooooo0_l00003ooooo`Co00009_ooool2o`000003ooooool0003o000000Kooooo0_l0
00000ooooooo0000o`000002o`000004ooooool0003o0000o`0000;ooooo0_l000001?oooooo0000
o`000?l00005ooooo`;o00001Oooool7o`0000kooooo1?l0000Jooooo`?o00001Oooool2o`000003
ooooool0003o000005kooooo000Looooo`03o`000?oooooooooo03Gooooo0ol0000Jooooo`;o0000
0oooool2o`0002Sooooo1Ol00009ooooo`;o00000_ooool4o`0000Cooooo0ol00003ooooo`;o0000
00?oooooo`000?l000000_l00004ooooo`Ko00000oooool2o`0000Wooooo0_l000000ooooooo0000
o`000005ooooo`;o00002?ooool2o`0000Kooooo1ol00008ooooo`;o0000G?ooool001cooooo00?o
0000ooooooooool0=Oooool3o`0001Cooooo0_l00009ooooo`;o00001Oooool2o`0000Oooooo0_l0
000Hooooo`Co00003_ooool4o`0000Cooooo0ol00003oooooa3o00001?ooool2o`0000cooooo0_l0
0005ooooo`;o00002?ooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool4o`0000Sooooo
0_l0001Looooo`007?ooool00ol0003oooooooooo`19ooooo`;o000000?oooooo`000?l000001Ooo
ool6o`000003ooooool0003o000000;ooooo0_l00007ooooo`;o00006Oooool2o`0000?ooooo0_l0
0008ooooo`;o00000oooool9o`000003ooooool0003o000000Go000000?oooooo`000?l000001?l0
000Kooooo`;o00002_ooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l00000Iooo
ool001cooooo00?o0000ooooooooool0<Oooool2o`0001Kooooo0_l000001?oooooo0000o`000?oo
ool2o`0000;ooooo1_l000000ooooooo0000o`00000;ooooo`;o00007_ooool2o`0000Sooooo2ol0
00001?oooooo0000o`000?ooool2o`0000?ooooo0ol000000ooooooo0000o`000003o`00013ooooo
1Ol00005ooooo`?o00002_ooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0000_o
oooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00005Oooool2o`0000;ooooo
0_l000000ooooooo0000o`000002ooooo`;o00000_ooool2o`0000gooooo0ol0000Gooooo`;o0000
4?ooool6o`000003ooooool0003o000000Wo00000_ooool2o`000003ooooool0003o000000Co0000
00?oooooo`000?l000000_ooool2o`0000Sooooo1Ol00005ooooo`;o00003oooool6o`0000kooooo
0_l00008ooooo`;o0000D?ooool001cooooo00?o0000ooooooooool0Aoooool3o`0000Wooooo0_l0
000Aooooo`;o00004Oooool3o`0000?ooooo0ol0000=ooooo`;o000000Goooooo`000?l0003o0000
ooooo`0?o`000003ooooool0003o000000ko00001oooool2o`0000cooooo0_l00002ooooo`;o0000
2?ooool6o`0000;ooooo0_l000000ooooooo0000o`00000Aooooo`;o00003_ooool2o`00043ooooo
000Looooo`03o`000?oooooooooo04Oooooo1?l0000Dooooo`;o00006?ooool3o`0000?ooooo0_l0
000>ooooo`;o00000_oooolSo`0000Cooooo0_l000000ooooooo0000o`00000<ooooo`;o00000_oo
ool2o`0000Sooooo1_l00002ooooo`Go00000oooool2o`0001cooooo0_l00010ooooo`007?ooool0
0ol0003oooooooooo`19ooooo`;o00005?ooool2o`0002Kooooo0_l000000ooooooo0000o`000002
ooooo`;o000000?oooooo`000?l000000_ooool2o`000004ooooool0003o0000oooooaKo00000ooo
ool2o`0000?ooooo0ol00004ooooo`;o000000?oooooo`000?l000003?ooool2o`0000Kooooo0_l0
0002ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo0_l0001Nooooo`007?ooool0
0ol0003oooooooooo`1mooooo`?o00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000002
ooooo`;o000000?oooooo`000?l000000_ooool6o`000003ooooool0003o000001Co00000_ooool2
o`0000?ooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00
0007ooooo`Co00001_ooool2o`0000;ooooo0_l00006ooooo`;o00002oooool2o`0005Gooooo000L
ooooo`03o`000?oooooooooo057ooooo0_l0000Yooooo`Co00000_ooool2o`0000;ooooo0_l00006
ooooobCo00000_ooool2o`0000Kooooo0ol00007ooooo`;o00001Oooool4o`0001Gooooo0_l00002
ooooo`;o000000?oooooo`000?l000000oooool4o`0005?ooooo000Looooo`;o0000@_ooool2o`00
00;ooooo0_l000000ooooooo0000o`000002o`0000?ooooo1?l0000Aooooo`;o00005_ooool3o`00
0003ooooool0003o000000Cooooo0_l00004ooooobOo000000?oooooo`000?l000000oooool2o`00
0003ooooool0003o000000oooooo0ol0000;ooooo`;o00002?ooool7o`000003ooooool0003o0000
00Gooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`11ooooo`;o00000_ooool2o`000003
ooooool0003o000000;o00000_ooool3o`0001?ooooo0_l0000Eooooo`;o00000oooool2o`0000Wo
oooo1_l00004ooooob;o00000_ooool2o`0001?ooooo0_l000000ooooooo0000o`000006ooooo`Ko
00001_ooool2o`000004ooooool0003o0000o`0000;ooooo0_l0000<ooooo`;o0000C?ooool001co
oooo00?o0000ooooooooool0?oooool2o`0000Sooooo0_l00003ooooo`?o00000_ooool4o`0002Co
oooo0_l00007ooooo`;o00001Oooool3o`0000Kooooo9Ol00003ooooo`;o00004oooool4o`0000Co
oooo1_l00002ooooo`;o00001_ooool2o`0000Oooooo0_l000000ooooooo0000o`000004ooooo`Co
0000B_ooool001cooooo00?o0000ooooooooool0?oooool2o`000003ooooool0003o000000_ooooo
0_l00002ooooo`Co00008Oooool2o`000003ooooool0003o000000Oooooo0ol00005ooooo`;o0000
1_oooolMo`000003ooooool0003o000000Go00000oooool2o`0001Cooooo0ol00005ooooo`;o0000
1Oooool2o`0000oooooo1Ol00006ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0@_oo
ool2o`00017ooooo0_l00003ooooo`;o00007?ooool2o`0000[ooooo0ol00005ooooo`?o000000?o
ooooo`000?l000006Ol000000ooooooo0000o`00000=o`0001Kooooo0_l00006ooooo`?o00001?oo
ool2o`0000Gooooo0_l0000:ooooo`;o00001oooool3o`0004[ooooo000Looooo`03o`000?oooooo
oooo04;ooooo0_l00009ooooo`;o00002Oooool4o`0000Gooooo0_l0000Eooooo`;o00002_ooool2
o`0000Oooooo0_l000000ooooooo0000o`00000Io`0000;ooooo3_l00006ooooo`;o000000?ooooo
o`000?l000000oooool2o`0000Kooooo0_l00006ooooo`?o00001?ooool2o`0000Cooooo0ol0000>
ooooo`;o00000oooool3o`0004[ooooo000Looooo`03o`000?oooooooooo04;ooooo0_l000000ooo
oooo0000o`000002ooooo`;o00000_ooool2o`0000Wooooo0_l000000ooooooo0000o`000004oooo
o`;o00003oooool2o`0000Cooooo0_l00004ooooo`;o00002Oooool2o`000003ooooool0003o0000
00;ooooo0_l000000ooooooo0000o`00000Po`0000;ooooo0_l00008ooooo`;o000000?oooooo`00
0?l000000oooool2o`0001Kooooo0_l00003ooooo`;o00000oooool2o`0000[ooooo0_l0001@oooo
o`007?ooool00ol0003oooooooooo`12ooooo`;o000000?oooooo`000?l000000_ooool2o`0000[o
oooo0_l00004ooooo`;o000000?oooooo`000?l000004_ooool2o`0000[ooooo0_l00009ooooo`;o
000000?oooooo`000?l000000_oooolOo`000003ooooool0003o000000?o00000_ooool3o`00023o
oooo0_l000000ooooooo0000o`000002ooooo`Co00001_ooool2o`000004ooooool0003o0000o`00
00?ooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00003?ooool2o`0000?o
oooo0_l00007ooooo`;o00006Oooool2o`00013ooooo1?l00002ooooobGo00000_ooool2o`0000Oo
oooo0_l0000>ooooo`;o00001oooool2o`000003ooooool0003o000000;o00000_ooool2o`0000Go
oooo0_l00002ooooo`Go000000?oooooo`000?l00000Doooool001cooooo00?o0000ooooooooool0
9oooool2o`0002Oooooo0_l00007ooooo`;o00007_ooool3o`0000[ooooo0_l00003ooooo`Go0000
00?oooooo`000?l000009Ol00009ooooo`;o00003_ooool2o`0000cooooo0_l00009ooooo`;o0000
1?ooool5o`0005Cooooo000Looooo`03o`000?oooooooooo02Oooooo0_l0000Eooooo`;o00002?oo
ool2o`0000?ooooo0_l00008ooooo`Co00007_ooool4o`0000Wooooo0_l00004ooooobco00000ooo
ool2o`0000cooooo0_l00004ooooo`;o00006_ooool2o`0000?ooooo1Ol00004ooooo`;o0000C_oo
ool001cooooo00?o0000ooooooooool0?_ooool3o`0000Oooooo0_l00003ooooo`;o00002?ooool2
o`0001Wooooo0ol00004ooooo`Co00003OoooolPo`000003ooooool0003o000000_o00000oooool2
o`000003ooooool0003o000000Cooooo0_l00003ooooo`;o00000oooool3o`0001[ooooo0ol00009
ooooo`Co00001?ooool2o`0004Sooooo000Looooo`03o`000?oooooooooo03oooooo0_l00007oooo
o`?o00000_ooool2o`0002?ooooo0ol00006ooooo`;o00001Oooool2o`0000Gooooo1Ol000000ooo
oooo0000o`00000Bo`000003ooooool0003o000001?o00001Oooool2o`0000Cooooo0_l00008oooo
o`;o00007?ooool2o`0000Cooooo0_l000000ooooooo0000o`000002o`0000Kooooo0_l00018oooo
o`007?ooool00ol0003oooooooooo`13ooooo`;o00000oooool3o`0000;ooooo0_l0000Eooooo`;o
000000?oooooo`000?l000004_ooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`Ko
00000_oooolYo`0000;ooooo0_l0000Mooooo`;o00003_ooool2o`0000Kooooo0_l000000ooooooo
0000o`000002ooooo`;o0000C_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q
8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo04?ooooo0_l00004oooo
o`;o00004Oooool2o`0000Kooooo0_l000000ooooooo0000o`000004ooooo`;o00001oooool3o`00
00Gooooo0_l00004ooooo`;o00000_ooool2o`000003ooooool0003o000000?ooooo9?l000001?oo
oooo0000o`000?l00003ooooo`;o00003Oooool2o`0000cooooo1?l0000>ooooo`;o00003Oooool2
o`0004kooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0>Oooool4o`0000cooooo0_l0000Aooooo`;o00003ooo
ool2o`0000;ooooo0_l00003ooooo`?o00002Oooool4o`0000?ooooo1?l00004oooooaCo000000?o
ooooo`000?l000003Ol000000ooooooo0000o`000002o`000003ooooool0003o000000gooooo0_l0
0003ooooo`;o00001Oooool4o`0001Sooooo1ol000000ooooooo0000o`00001=ooooo`0000?ooooo
oa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`Go00001_ooool00ol0003oooooooooo`0i
ooooo`Go0000<Oooool4o`0000?ooooo0_l0000:ooooo`;o00001Oooool2o`0000Cooooo5ol00000
0ooooooo0000o`000006o`0000;ooooo1?l000000ooooooo0000o`000002o`000003ooooool0003o
000000gooooo0_l00003ooooo`;o00001?ooool4o`0000Oooooo0_l00002ooooo`;o00003?ooool:
o`0000Kooooo0_l00015ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09oooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0000looooo`;o00008oooool2o`000004ooooool0003o
0000ooooo`?o00001Oooool2o`0000Oooooo0_l0000Aooooo`;o00000_ooool8o`000003ooooool0
003o000001Go00000_ooool4o`0001;ooooo0_l000000ooooooo0000o`000008ooooo`Co00001ooo
ool7o`0001?ooooo0_l00007ooooo`;o00001?ooool2o`0003oooooo00000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003ooooooooo
o`13ooooo`;o00005?ooool2o`0000Cooooo1?l000001?oooooo0000o`000?ooool3o`0000Cooooo
0_l00006ooooo`Co00001Oooool2o`0000?ooooo0_l00003ooooobKo000000?oooooo`000?l00000
1Ol00002ooooo`?o00002?ooool2o`000003ooooool0003o000000_ooooo0_l00009ooooo`;o0000
00?oooooo`000?l000004?ooool2o`0000Cooooo0_l00002ooooo`;o00002?ooool2o`0003oooooo
00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oMgMgolc<c?l000001ooo
ool00ol0003oooooooooo`0jooooo`;o00001oooool3o`0001;ooooo0ol00004ooooo`Go00002_oo
ool2o`0000Kooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0ol00002ooooo`;o000000?o
ooooo`000?l000001ol000000ooooooo0000o`00000Oo`0000;ooooo0ol00008ooooo`;o00004Ooo
ool2o`0001_ooooo0ol00003ooooo`;o00000_ooool2o`0000[ooooo0_l00005ooooo`;o0000=_oo
ool00006oooooomgMgOoV9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`00
0?oooooooooo03Sooooo1?l00008ooooo`;o00004_ooool2o`0000Cooooo2?l00004ooooo`;o0000
3?ooool2o`000004ooooool0003o0000ooooo`?o00001?ooool2o`0000?ooooo1Ol00003ooooob?o
00002Oooool2o`0000Cooooo0_l00006ooooo`;o00002Oooool2o`0001cooooo0_l0000Cooooo`;o
00001Oooool2o`0000Oooooo0ol0000/ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h=oooo
o`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0>?ooool2o`0000[ooooo1?l0000Foooo
o`Co00000_ooool2o`0000Cooooo0_l00008ooooo`;o000000Coooooo`000?l0003o00001?ooool2
o`000003ooooool0003o000000;ooooo0_l00003ooooo`So000000?oooooo`000?l000001?l00002
oooooa?o000000Goooooo`000?l0003o0000ooooo`02o`0000?ooooo0_l00004ooooo`;o000000?o
ooooo`000?l000000ol00006ooooo`;o00002Oooool2o`00023ooooo0_l0000Oooooo`?o0000;?oo
ool001cooooo00?o0000ooooooooool0?Oooool2o`0000Oooooo0_l00003ooooo`;o00006Oooool6
o`000003ooooool0003o000000Gooooo0_l000000ooooooo0000o`000008ooooo`;o00001Oooool3
o`000003ooooool0003o000000Co00000ooooolAo`000003ooooool0003o000000Wo00000_ooool3
o`000003ooooool0003o000000Kooooo1?l00004ooooo`;o00002Oooool2o`0000;ooooo0_l0000N
ooooo`Co00001oooool2o`0004Gooooo000Looooo`03o`000?oooooooooo03;ooooo0_l00009oooo
o`;o00003?ooool3o`0000Kooooo0_l00008ooooo`?o00001Oooool4o`0000?ooooo0_l0000Doooo
o`;o00000oooool:o`0000?ooooo6_l00004ooooo`Co000000?oooooo`000?l000001_ooool2o`00
00?ooooo0_l000000ooooooo0000o`000009ooooo`;o00007oooool2o`000003ooooool0003o0000
00Wooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`0booooo`;o00005?ooool2o`0000;o
oooo0_l00005ooooo`?o00002?ooool5o`0000gooooo0_l0000Aooooo`;o00001_ooool2o`0000?o
oooo0_l00003ooooo`;o00000_oooolEo`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o
00001_ooool2o`0000?ooooo0_l0000Gooooo`;o00001oooool3o`0000[ooooo0_l0000Mooooo`;o
00001?ooool2o`0002kooooo000Looooo`03o`000?oooooooooo03Kooooo0_l00005ooooo`;o0000
2Oooool2o`0000Wooooo0_l000000ooooooo0000o`000007ooooo`Co00001Oooool2o`0000Cooooo
1?l00009ooooo`;o00004_ooool2o`0000Cooooo0_l000000ooooooo0000o`00000Bo`0000Cooooo
1Ol00003ooooo`;o00001_ooool2o`000003ooooool0003o000000[ooooo1?l0000;ooooo`;o0000
1?ooool2o`000004ooooool0003o0000o`0002Wooooo0_l00004ooooo`;o0000;_ooool001cooooo
00?o0000ooooooooool0=_ooool2o`0000Gooooo0_l0000Gooooo`;o00001oooool2o`000003oooo
ool0003o000000Cooooo0_l00004ooooo`;o000000Coooooo`000?l0003o00001oooool2o`00017o
oooo1Ol00002ooooo`;o000000?oooooo`000?l000005?l00004ooooo`;o00001?ooool2o`000003
ooooool0003o000000;o00001?ooool2o`0000[ooooo1?l0000>ooooo`_o00003Oooool3o`0004go
oooo000Looooo`03o`000?oooooooooo023ooooo0_l0000Jooooo`;o00009?ooool4o`0000;ooooo
0_l00007ooooo`?o00006_ooool5o`0000;ooooo0_l000001?oooooo0000o`000?ooool5o`000003
ooooool0003o000000_o00001oooool2o`0000?ooooo1ol0000=ooooo`;o00002_ooool2o`0000;o
oooo3_l0000=ooooo`?o00000_ooool2o`0004Wooooo000Looooo`03o`000?oooooooooo023ooooo
0_l0000?ooooo`;o00001?ooool2o`0000?ooooo0ol0000>ooooo`;o00001?ooool3o`0000gooooo
0ol000001?oooooo0000o`000?l00002ooooo`;o00001Oooool2o`000003ooooool0003o000000co
oooo0_l00009ooooo`?o000000?oooooo`000?l000000oooool2o`000004ooooool0003o0000oooo
o`Oo00000_ooool2o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l000000oooool2o`00
00?ooooo0_l00008ooooo`;o00000oooool2o`0000Sooooo1?l00002oooooa7o00003oooool2o`00
00Sooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00001?ooool2o`0000Co
oooo0_l00004ooooo`;o00002?ooool3o`0000?ooooo0ol0000=ooooo`;o000000Coooooo`000?l0
003o00000oooool6o`000004ooooool0003o0000ooooo`?o00002oooool2o`0000Wooooo0ol00000
0ooooooo0000o`000006ooooo`;o00000oooool6o`0000Cooooo1?l00002ooooo`Go00001Oooool2
o`0000?ooooo1?l00006ooooo`Co00002oooool2o`0000;ooooo4ol000001?oooooo0000o`000?l0
000;ooooo`;o00002?ooool2o`0000Gooooo0_l00008ooooo`;o0000;_ooool001cooooo00?o0000
ooooooooool0>?ooool4o`000003ooooool0003o000000Cooooo0_l00009ooooo`Co00004Oooool2
o`000003ooooool0003o000000?o00000oooool7o`0000;ooooo0ol0000Eooooo`;o00000_ooool2
o`0000_ooooo1_l00004ooooo`Co00000_ooool2o`000003ooooool0003o000000Gooooo0ol00002
ooooo`Go00001oooool2o`0000Wooooo0_l00004oooooaSo00000oooool2o`0000Kooooo0_l0000>
ooooo`;o00002?ooool2o`0002kooooo000Looooo`03o`000?oooooooooo03Gooooo0_l000000ooo
oooo0000o`000002o`000003ooooool0003o000000gooooo0_l00002ooooo`;o00000oooool2o`00
00?ooooo0ol000000ooooooo0000o`00000Fo`0000;ooooo0_l00008ooooo`;o00002oooool2o`00
00?ooooo1Ol00003ooooo`Co00000oooool2o`0000?ooooo1?l00002ooooo`;o00002?ooool5o`00
0003ooooool0003o000000;ooooo0_l0000Booooo`;o00000ooooolIo`0000?ooooo0_l00006oooo
o`;o00006?ooool2o`0002kooooo000Looooo`03o`000?oooooooooo02kooooo0_l00005ooooo`;o
00002?ooool2o`0000Wooooo1?l00007ooooo`;o000000?oooooo`000?l000007?l0000<ooooo`;o
00003_ooool9o`000003ooooool0003o000000;o00000oooool2o`000003ooooool0003o000000?o
00000oooool2o`0000Sooooo0_l00004ooooo`;o00000_ooool2o`0000?ooooo0_l0000;ooooo`;o
00001?oooolIo`0001Kooooo1?l00004ooooo`;o00001_ooool2o`0002kooooo000Looooo`;o0000
7_ooool2o`0000oooooo0_l0000?ooooo`;o00002Oooool2o`0000Sooooo0_l000001?oooooo0000
o`000?l00002oooooa_o00002?ooool2o`000003ooooool0003o000000kooooo0_l00002ooooo`;o
000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000Cooooo0ol000000ooooooo
0000o`000002ooooo`;o00001oooool2o`0000Sooooo0ol00003ooooo`;o00002oooool5o`000003
ooooool0003o000000go00000_ooool8o`000003ooooool0003o000000Sooooo0_l00009ooooo`Ko
00000_ooool4o`0000Cooooo0_l0000^ooooo`007?ooool00ol0003oooooooooo`0Mooooo`;o0000
6Oooool2o`00017ooooo0_l00007ooooo`Ko00000_oooolKo`0000Sooooo0_l0000Eooooo`Go0000
1Oooool2o`0000Oooooo2?l00006ooooo`;o000000?oooooo`000?l000001?ooool4o`0000;ooooo
0_l0000=oooooaco00000oooool2o`0000Sooooo0_l0000;ooooo`Co00001?ooool2o`0003Cooooo
000Looooo`03o`000?oooooooooo03Gooooo0_l000000ooooooo0000o`000007ooooo`;o00002?oo
ool2o`0000Kooooo8Ol000000ooooooo0000o`000008ooooo`;o000000Goooooo`000?l0003o0000
ooooo`02o`0000[ooooo0_l00002ooooo`Ko000000?oooooo`000?l000000_ooool2o`0000Kooooo
2?l00008ooooo`?o00001?ooool2o`000004ooooool0003o0000ooooo`;o00003ooooolJo`0000?o
oooo0_l00009ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0=Oooool2o`0000[ooooo
0_l00009ooooo`;o00001Oooool5o`000003ooooool0003o000000Wo000000?oooooo`000?l00000
4_l00009ooooo`?o000000?oooooo`000?l000002_ooool2o`0000;ooooo1_l000000ooooooo0000
o`000002ooooo`;o00005_ooool3o`0000;ooooo0_l00003ooooo`;o00002oooool2o`0000Gooooo
6_l00003ooooo`;o00002Oooool2o`0004Sooooo000Looooo`03o`000?oooooooooo04cooooo0_l0
0006ooooo`;o00000_oooolMo`000004ooooool0003o0000o`0000Oooooo1?l0000Jooooo`;o0000
2Oooool2o`0000kooooo0ol00002ooooo`;o00004?ooool2o`0000Gooooo7?l000001?oooooo0000
o`000?l0000Qooooo`;o0000;oooool001cooooo00?o0000ooooooooool0F?oooolQo`0000Oooooo
1?l0000Jooooo`?o00001?ooool2o`0000;ooooo1Ol0000;ooooo`;o00002?ooool2o`0000Sooooo
0_l00006ooooo`;o000000?oooooo`000?l000005Ol000001?oooooo0000o`000?l00002ooooo`;o
00001_ooool2o`0001Wooooo0_l0000_ooooo`007?ooool00ol0003oooooooooo`0Looooo`;o0000
5oooool2o`0001Oooooo0_l00002ooooo`;o000000Goooooo`000?l0003o0000ooooo`0No`0000?o
oooo0_l00006ooooo`Go00002Oooool2o`0000[ooooo0_l000000ooooooo0000o`000004ooooo`;o
00001?ooool3o`0001;ooooo0_l000000ooooooo0000o`000008ooooo`;o00001_ooool2o`000003
ooooool0003o000000Go000000?oooooo`000?l000004?l0000;ooooo`;o00002Oooool4o`0003go
oooo000Looooo`03o`000?oooooooooo01cooooo0_l0000?ooooo`;o00000oooool2o`000003oooo
ool0003o0000017ooooo0_l00004ooooo`;o000000Goooooo`000?l0003o0000ooooo`0To`000005
ooooool0003o0000o`000?ooool00ol00002ooooo`Co000000?oooooo`000?l000001_ooool4o`00
00Sooooo1?l00005ooooo`;o00006Oooool2o`0000kooooo0_l00009oooooaGo000000?oooooo`00
0?l000000oooool2o`0000_ooooo0_l00003ooooo`Co0000?Oooool001cooooo00?o0000oooooooo
ool0;Oooool2o`0000?ooooo1?l0000Booooo`;o00001oooool2o`0000?ooooo8?l000001Ooooooo
0000o`000?l0003ooooo00;o000000Coooooo`000?l0003o00000_ooool2o`0000?ooooo0_l00008
ooooo`;o00001Oooool2o`0000?ooooo0_l00002ooooo`;o00004Oooool2o`00017ooooo0_l00000
0ooooooo0000o`000003ooooo`;o00000oooool2o`0000Cooooo4ol00003ooooo`;o00000oooool2
o`0000Gooooo0_l00004ooooo`;o00002oooool2o`0000Kooooo0_l0000_ooooo`007?ooool00ol0
003oooooooooo`0dooooo`;o00002_ooool2o`0001Cooooo5ol000000ooooooo0000o`000006o`00
0003ooooool0003o000000;o00005Oooool4o`0000Gooooo0_l00003ooooo`?o000000Coooooo`00
0?l0003ooooo0_l00003ooooo`;o00000_ooool2o`0000Gooooo0_l0000<ooooo`;o00000oooool2
o`000003ooooool0003o000000Gooooo0_l000000ooooooo0000o`000005ooooo`ko00004oooool2
o`0000Gooooo0_l00003ooooo`;o00001Oooool2o`0000Kooooo0_l0000_ooooo`007?ooool00ol0
003oooooooooo`0Jooooo`;o00009?ooool2o`0000Gooooo0_l00003ooooo`;o000000Coooooo`00
0?l0003o00001_ooool3o`000003ooooool0003o000001Go00001?ooool4o`0001?ooooo1?l00003
ooooo`;o00002?ooool2o`000004ooooool0003o0000ooooo`Co000000?oooooo`000?l000000_oo
ool2o`0000Kooooo0_l0000;ooooo`;o00002_ooool5o`0000Sooooo3_l0000Aooooo`;o00001ooo
ool2o`0000?ooooo0_l00003ooooo`;o0000>Oooool001cooooo00?o0000ooooooooool06_ooool2
o`0001Oooooo0_l0000Booooo`;o00000oooool2o`000004ooooool0003o0000o`0000Cooooo7ol0
00001?oooooo0000o`000?l00004ooooo`;o00001oooool2o`000004ooooool0003o0000ooooo`Ko
00000oooool3o`0000Sooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00004ooooo`;o
00004Oooool3o`0000Oooooo0_l000000ooooooo0000o`00000<o`0000;ooooo1?l0000;ooooo`;o
00004Oooool2o`0003Wooooo000Looooo`03o`000?oooooooooo03?ooooo0_l00002ooooo`;o0000
3oooool2o`0000?ooooo0_l00003ooooo`Ko000000?oooooo`000?l000007Ol00004ooooo`?o0000
1oooool2o`000003ooooool0003o000000?o00001oooool3o`0000Sooooo0_l00006ooooo`Co0000
00?oooooo`000?l000000_ooool2o`000003ooooool0003o000000Kooooo0_l00003ooooo`;o0000
2_ooool3o`0000Wooooo2ol00007ooooo`Go00008?ooool2o`0003Oooooo000Looooo`03o`000?oo
oooooooo03Oooooo0ol0000<ooooo`Co00000oooool2o`0000?ooooo1Ol00003oooooa?o000000?o
ooooo`000?l000000_l000001?oooooo0000o`000?l00004ooooo`Co00002oooool4o`0001Cooooo
0_l00005ooooo`Co000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000Kooooo
0ol00002ooooo`;o00002?ooool6o`0000Sooooo1ol00008ooooo`;o000000?oooooo`000?l00000
5_ooool2o`0000[ooooo0ol0000gooooo`007?ooool00ol0003oooooooooo`0hooooo`?o00002ooo
ool2o`0000;ooooo0_l00006ooooo`;o00000ooooolOo`000003ooooool0003o000000?o00002_oo
ool2o`0000;ooooo0_l0000;ooooo`;o00002?ooool2o`0001Wooooo0ol0000:ooooo`Co00000_oo
ool2o`000003ooooool0003o000000?ooooo0_l00004ooooo`;o00000_ooool2o`0000Gooooo0_l0
00000ooooooo0000o`00000Fooooo`;o00002_ooool2o`0003Sooooo000Looooo`03o`000?oooooo
oooo01[ooooo0_l0000Mooooo`;o00001oooool2o`0000;ooooo0_l00002ooooo`;o00001Oooool2
o`0000?ooooo1_l000000ooooooo0000o`00000Do`000004ooooool0003o0000ooooo`Co00002ooo
ool2o`0000kooooo1Ol0000;ooooo`;o00004_ooool4o`0000_ooooo0_l00007ooooo`;o00000ooo
ool4o`0000Kooooo0_l00007ooooo`?o00008?ooool2o`0003[ooooo000Looooo`;o00006oooool2
o`0001gooooo0ol00006ooooo`;o00001_ooool2o`0000Gooooo0_l00003oooooako00008_ooool2
o`000003ooooool0003o000000_ooooo0_l0000Booooo`Co00002?ooool2o`0000Gooooo0_l0000:
ooooo`;o000000?oooooo`000?l000001oooool2o`0000?ooooo0_l0000Eooooo`?o00000_ooool2
o`0000Gooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o00002oooool2o`00
01_ooooo6_l000001?oooooo0000o`000?l0000?ooooo`?o00007Oooool2o`0000Kooooo0_l00002
ooooo`;o00002_ooool2o`0000Sooooo0_l00005ooooo`;o00003Oooool2o`000003ooooool0003o
000000Cooooo0_l0000Jooooo`?o00000_ooool2o`00047ooooo000Looooo`03o`000?oooooooooo
02gooooo0_l0000Kooooo`?o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o00000_oooolB
o`0000;ooooo0_l000001?oooooo0000o`000?l0000>ooooo`Co00007Oooool2o`0000Cooooo1?l0
0002ooooo`;o000000?oooooo`000?l000003Oooool2o`0000_ooooo1?l0000<ooooo`;o00000_oo
ool2o`0001cooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`1:ooooo`?o000000Cooooo
o`000?l0003ooooo0_l00004ooooo`;o000000?oooooo`000?l000004Ol00002ooooo`;o000000Co
ooooo`000?l0003ooooo0_l00003ooooo`;o00001_ooool5o`0002?ooooo0_l00007ooooo`;o0000
2oooool4o`0000?ooooo0_l00006ooooo`Co00004?ooool2o`0000_ooooo0_l0000>ooooo`?o0000
2_ooool2o`0000Kooooo0ol0000aooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00001_oo
ool2o`0000;ooooo5Ol00008ooooo`Co000000?oooooo`000?l000001Oooool3o`000003ooooool0
003o000000?ooooo0_l0000Looooo`;o00000_ooool2o`0000oooooo0_l000000ooooooo0000o`00
0004ooooo`Co00002Oooool2o`0001_ooooo0_l0000>ooooo`;o00002oooool2o`0000Kooooo0ol0
000aooooo`007?ooool00ol0003oooooooooo`1<ooooo`[o000000Coooooo`000?l0003o00000ooo
ool4o`0000;ooooo2?l0000<ooooo`;o00001Oooool5o`0000Oooooo0_l0000Gooooo`;o000000?o
ooooo`000?l000000_l00002ooooo`Co00002Oooool2o`0000;ooooo0_l000000ooooooo0000o`00
0004ooooo`Co00000_ooool2o`0000Gooooo0_l0000:ooooo`;o00002_ooool2o`0001?ooooo0ol0
000Dooooo`;o0000<?ooool001cooooo00?o0000ooooooooool0C_ooool7o`0000;ooooo0ol00003
ooooo`?o00000oooool:o`0000Sooooo0_l00007ooooo`Co00004oooool2o`0000Oooooo1ol00000
1?oooooo0000o`000?l00005ooooo`;o00000oooool2o`0000Cooooo0_l00003ooooo`;o00002?oo
ool2o`0000;ooooo0_l00004ooooo`;o00002_ooool3o`0000Sooooo1?l0000Dooooo`?o00001Ooo
ool3o`0000Kooooo0_l00003ooooo`;o0000<?ooool001cooooo00?o0000ooooooooool0>_ooool2
o`0001;ooooo0_l00008ooooo`Co000000Coooooo`000?l0003o00000oooool3o`000003ooooool0
003o000000Co00002?ooool2o`0000[ooooo0_l000001?oooooo0000o`000?l0000>ooooo`;o0000
1oooool6o`000003ooooool0003o000000;o000000?oooooo`000?l000000oooool6o`0000Cooooo
0_l00003ooooo`;o00001oooool3o`000003ooooool0003o000000;o00000oooool4o`0000Sooooo
0_l00005ooooo`;o00000_ooool3o`000003ooooool0003o000001?ooooo0_l00002ooooo`;o0000
00Coooooo`000?l0003o00001_ooool2o`0003Gooooo000Looooo`03o`000?oooooooooo03Sooooo
1?l00006ooooo`;o00001?ooool2o`00013ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o
oooo1?l0000:ooooo`;o00002Oooool2o`0000;ooooo1_l00008ooooo`;o00004?ooool3o`000003
ooooool0003o000000Ko00000_ooool4o`0000Kooooo0_l0000:ooooo`Co00000_ooool5o`0000;o
oooo1_l0000=ooooo`;o00000oooool2o`000003ooooool0003o000001Gooooo1?l00002ooooo`?o
0000??ooool001cooooo00?o0000ooooooooool06Oooool2o`0001gooooo1?l00006ooooo`;o0000
1?ooool2o`0000;ooooo0_l00003ooooo`;o00001_ooool2o`0000?ooooo0_l000000ooooooo0000
o`000003ooooo`?o00002Oooool2o`0000Oooooo1?l00004ooooo`;o00002_ooool2o`00013ooooo
0ol00002ooooo`Co000000Goooooo`000?l0003o0000ooooo`02o`0000?ooooo0_l00004ooooo`;o
00001?ooool2o`0000?ooooo1?l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;o
oooo0_l00005ooooo`;o00007oooool2o`000004ooooool0003o0000ooooo`;o00001?ooool3o`00
03cooooo000Looooo`03o`000?oooooooooo01Wooooo0_l0000Uooooo`;o00002_ooool2o`0000?o
oooo0_l00006ooooo`?o00002oooool2o`0001;ooooo0ol0000Dooooo`;o00000_ooool2o`0000[o
oooo0_l00002ooooo`?o00000oooool2o`0000Kooooo0_l00004ooooo`;o00001?ooool4o`0000Oo
oooo0_l00006ooooo`;o00002?ooool2o`0000[ooooo0_l00007ooooo`;o00001_ooool2o`0000;o
oooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool2o`0003gooooo000Looooo`03o`00
0?oooooooooo03cooooo1_l00003ooooo`?o00001Oooool5o`0000Sooooo0_l0000Oooooo`;o0000
00Coooooo`000?l0003ooooo0_l0000?ooooo`;o00000_ooool2o`0000[ooooo0ol000000ooooooo
0000o`00000Jooooo`;o00000oooool2o`0000Kooooo0_l00002ooooo`;o00000_ooool2o`00013o
oooo0_l00007ooooo`Co00000oooool5o`0000Oooooo0_l00012ooooo`007?ooool00ol0003ooooo
ooooo`0looooo`Co00001Oooool3o`0000Gooooo1Ol00007ooooo`;o00005_ooool2o`0000_ooooo
0_l000000ooooooo0000o`00000;ooooo`;o00001oooool3o`0000?ooooo0_l00004ooooo`;o0000
2?ooool2o`0001Sooooo0_l00006ooooo`;o00001_ooool3o`0000Sooooo0_l00007ooooo`;o0000
1oooool2o`0000?ooooo0_l000001?oooooo0000o`000?l0000Eooooo`;o0000<oooool001cooooo
00?o0000ooooooooool0>Oooool2o`0000[ooooo0_l00006ooooo`?o00002Oooool2o`0000?ooooo
0_l000000ooooooo0000o`000003ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000
o`00000Kooooo`;o00001Oooool5o`0000?ooooo0_l00004ooooo`;o00001oooool3o`00027ooooo
0_l00005ooooo`?o00002?ooool2o`0000Cooooo0_l000000ooooooo0000o`00000@ooooo`;o0000
5Oooool2o`0003?ooooo000Looooo`03o`000?oooooooooo01Wooooo0_l0000Nooooo`?o00002Ooo
ool2o`0000Cooooo1Ol000000ooooooo0000o`000006ooooo`;o00000oooool2o`000003ooooool0
003o000000?ooooo0_l00002ooooo`;o00000_ooool2o`0001Oooooo0_l00009ooooo`;o000000?o
ooooo`000?l000000ol00002ooooo`;o00003_ooool2o`0002;ooooo0_l000000ooooooo0000o`00
0002ooooo`;o00003oooool2o`0000Gooooo0_l00004ooooo`;o00002oooool2o`0004Gooooo000L
ooooo`03o`000?oooooooooo01Wooooo0_l0000Oooooo`;o00003?ooool2o`000003ooooool0003o
000000Cooooo0_l00004ooooo`Co00003_ooool2o`0000Cooooo0_l00003ooooo`;o00004Oooool2
o`0000Wooooo0_l000000ooooooo0000o`000004o`000003ooooool0003o000002Cooooo0_l00006
ooooo`;o00001oooool5o`0000kooooo0_l00007ooooo`Co00000_ooool2o`0000_ooooo0_l00000
0ooooooo0000o`000012ooooo`007?ooool2o`0003Kooooo1?l0000?ooooo`;o00003Oooool2o`00
013ooooo0ol00002ooooo`?o00000oooool2o`00013ooooo0_l00007ooooo`;o00001?ooool6o`00
02Oooooo0_l00006ooooo`;o00000_ooool2o`000003ooooool0003o000000Go00001Oooool2o`00
00Oooooo0_l00009ooooo`;o00003_ooool2o`000004ooooool0003o0000o`0000cooooo0_l0000d
ooooo`007?ooool00ol0003oooooooooo`0eooooo`Co00004_ooool2o`00017ooooo0_l0000:oooo
o`;o00000_ooool2o`0000kooooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo0_l00002oooo
o`;o00000_ooool2o`000004ooooool0003o0000ooooo`Ko000000?oooooo`000?l000000_l00005
ooooo`;o00005Oooool4o`0000[ooooo1Ol0000:ooooo`;o00004_ooool2o`0000Gooooo0_l00005
ooooo`Co000000?oooooo`000?l000003?ooool3o`0003Cooooo000Looooo`03o`000?oooooooooo
043ooooo0_l00009ooooo`Co00000_ooool2o`0000_ooooo0_l000000ooooooo0000o`000009oooo
o`;o00002Oooool2o`0000Gooooo1_l00007ooooo`;o00001_ooool2o`0000Gooooo1Ol000000ooo
oooo0000o`000002o`0000Gooooo0_l0000Eooooo`Go00002_ooool2o`00013ooooo0_l0000Doooo
o`Co00000oooool3o`000003ooooool0003o000000Wooooo0_l00002ooooo`?o0000=Oooool001co
oooo00?o0000ooooooooool0@?ooool2o`0000[ooooo0ol00002ooooo`;o00003_ooool2o`0000Wo
oooo0_l00009ooooo`;o00000_ooool2o`0000;ooooo1?l0000Aooooo`;o00000_ooool4o`0000Ko
oooo0_l0000Oooooo`;o00002oooool4o`0000?ooooo0_l00008ooooo`;o00005?ooool4o`0000?o
oooo0_l00002ooooo`;o00002Oooool2o`0000;ooooo0_l0000fooooo`007?ooool00ol0003ooooo
ooooo`10ooooo`;o00002_ooool2o`0000Oooooo0_l0000Eooooo`;o00001?ooool3o`0000Kooooo
0_l00003ooooo`Ko000000?oooooo`000?l000001_l000001Ooooooo0000o`000?l0003ooooo00;o
00000_ooool4o`000003ooooool0003o000000;o00007Oooool2o`0000?ooooo0_l0000;ooooo`Co
00000oooool2o`0001oooooo0_l00009ooooo`;o00001Oooool2o`0003gooooo000Looooo`03o`00
0?oooooooooo04?ooooo0ol00007ooooo`?o00001Oooool2o`0001Gooooo0_l00003ooooo`Co0000
0oooool2o`0000Kooooo1_l000000ooooooo0000o`000006o`000003ooooool0003o000000?o0000
2?ooool6o`0001_ooooo0_l00003ooooo`Oo00001_ooool2o`0000Wooooo0_l0000Hooooo`Co0000
2Oooool3o`0000Gooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00000ooo
ool3o`0000Oooooo0ol00006ooooo`;o00006?ooool3o`0000Gooooo0_l00004ooooo`;o00000_oo
ool2o`0000;ooooo1Ol00002ooooo`?o00000_ooool3o`0000cooooo0_l0000Mooooo`;o00000_oo
ool6o`0000Cooooo1?l00009ooooo`;o00006?ooool4o`0000Oooooo1?l00015ooooo`007?ooool0
0ol0003oooooooooo`0gooooo`;o00001Oooool2o`0000?ooooo1?l0000?ooooo`;o00006?ooool2
o`0000Oooooo0_l00002ooooo`Co000000?oooooo`000?l000001Ol00005ooooo`;o0000:?ooool5
o`0000?ooooo0ol000001Ooooooo0000o`000?l0003ooooo00Co00000_ooool4o`000003ooooool0
003o000000;o00001Oooool2o`0001Kooooo0_l0000:ooooo`;o000000?oooooo`000?l00000A?oo
ool001cooooo00?o0000ooooooooool0=oooool2o`0000[ooooo1?l0000;ooooo`;o00000_ooool2
o`0000Kooooo0_l000000ooooooo0000o`00000Fooooo`;o000000?oooooo`000?l000002ol0000<
ooooo`;o00001Oooool2o`0001Wooooo1ol00002ooooo`ko000000?oooooo`000?l000000_ooool4
o`0000Gooooo0_l0000Fooooo`?o00002?ooool2o`0000;ooooo0_l00004ooooo`;o0000?_ooool0
01cooooo00?o0000ooooooooool07?ooool2o`0002Kooooo0_l0000<ooooo`Oo00001Oooool2o`00
0003ooooool0003o000000[ooooo0_l00009ooooo`?o000000Goooooo`000?l0003o0000ooooo`02
o`0000cooooo1?l00003ooooo`;o00001Oooool2o`0001Wooooo6_l00002ooooo`Go00006Oooool2
o`000003ooooool0003o000000;o00001oooool2o`0000Sooooo0_l0000nooooo`007?ooool00ol0
003oooooooooo`0Looooo`;o00008?ooool2o`0000Cooooo1?l0000;ooooo`Ko000000Coooooo`00
0?l0003o00003_ooool4o`000005ooooool0003o0000o`000?ooool02Ol000000ooooooo0000o`00
000:ooooo`;o00000_ooool4o`0000?ooooo0_l0000>ooooo`;o00004_oooolFo`0000;ooooo1?l0
00000ooooooo0000o`00000Iooooo`;o00000oooool2o`0000Oooooo1?l00016ooooo`007?ooool0
0ol0003oooooooooo`0nooooo`Co00000oooool3o`0000oooooo0_l000001?oooooo0000o`000?l0
000>ooooo`So000000?oooooo`000?l000001?l000000ooooooo0000o`000003o`0000[ooooo1?l0
00000ooooooo0000o`000004ooooo`;o00001_ooool2o`0000Kooooo0_l0000=ooooo`;o00000_oo
ool2o`000003ooooool0003o000001?o000000?oooooo`000?l000000oooool2o`0000[ooooo0_l0
000Fooooo`;o00001Oooool2o`0000Gooooo0_l000001?oooooo0000o`000?ooool2o`0003Wooooo
000Looooo`03o`000?oooooooooo043ooooo1?l000001?oooooo0000o`000?l00008ooooo`;o0000
1Oooool2o`0000?ooooo0_l0000>ooooo`Co00001?ooool6o`000003ooooool0003o000000;o0000
00?oooooo`000?l000002_ooool2o`0000oooooo0_l0000Aooooo`;o00000_ooool2o`000005oooo
ool0003o0000o`000?ooool01Ol000001Ooooooo0000o`000?l0003ooooo00ko00000oooool2o`00
00Cooooo0_l00004ooooo`;o00003Oooool2o`0000Oooooo0_l0000<ooooo`;o000000Coooooo`00
0?l0003ooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00001_ooool3o`00
00;ooooo0_l00008ooooo`?o00000oooool3o`0000?ooooo0_l0000?ooooo`;o00000oooool2o`00
00;ooooo0_l000000ooooooo0000o`000005ooooo`;o00001Oooool4o`0001?ooooo0_l0000@oooo
o`;o00000_ooool2o`000003ooooool0003o000000Co000000?oooooo`000?l000001?l000000ooo
oooo0000o`00000;o`0000[ooooo0_l00005ooooo`;o00003?ooool2o`0000Sooooo0_l0000<oooo
o`;o0000?_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo03Wooooo0_l00006ooooo`?o00001Ooo
ool2o`0000Kooooo0_l00003ooooo`;o00000oooool2o`0000Gooooo0_l00004ooooo`;o00000ooo
ool2o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000002Oooool2o`000003ooooool0
003o000000;o00004oooool2o`0001Cooooo0_l000000ooooooo0000o`00000Io`000003ooooool0
003o000000Oooooo0ol00004ooooo`;o00005_ooool2o`0000cooooo0_l0000nooooo`0000Kooooo
ogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Ko
oooo00?o0000ooooooooool0?oooool2o`0000Sooooo0_l0000@ooooo`;o00001Oooool2o`000004
ooooool0003o0000ooooo`;o00003?ooool4o`0000[ooooo0_l0000^ooooo`;o00000_oooolJo`00
0004ooooool0003o0000o`0000Kooooo0ol0000Pooooo`;o0000B?ooool00003ooooool@413ooooo
00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool08?ooool2o`0001gooooo0_l0000>ooooo`;o00003_ooool2o`0000Cooooo0_l00002
ooooo`;o00000_ooool2o`0000Oooooo1?l0000Fooooo`;o00004Oooool2o`0000oooooo7?l00002
ooooo`Go00001Oooool2o`0001[ooooo0_l00005ooooo`;o0000B?ooool00003ooooool0003ooooo
00;ooooo00?o0000ooooooooool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0000P
ooooo`;o00007_ooool2o`0000gooooo0_l00007ooooo`;o00001Oooool2o`0000Cooooo1_l00002
ooooo`;o00000_ooool2o`000004ooooool0003o0000o`0000;ooooo0ol0000Dooooo`So000000?o
ooooo`000?l000000_l00006ooooo`;o00000_ooool2o`0000Cooooo0_l00006oooooaoo000000?o
ooooo`000?l000005Oooool2o`0000[ooooo0_l00002ooooo`?o00003?ooool2o`0003cooooo0000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<
c006ooooo`03o`000?oooooooooo03[ooooo0_l00003ooooo`Co00005Oooool5o`0000Sooooo1Ol0
0003ooooo`;o00000_ooool2o`000003ooooool0003o000000Oo00001Oooool2o`0000kooooo1_l0
00000ooooooo0000o`000007o`0000?ooooo1?l00002ooooo`Co00002?oooolMo`0000;ooooo0_l0
000Dooooo`;o00001_ooool4o`0000Cooooo0ol0000<ooooo`;o0000??ooool00003ooooool@413o
oooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooo
oooo03[ooooo0_l00003ooooo`Co00001?ooool2o`0000Oooooo0_l000001?oooooo0000o`000?l0
0002ooooo`Go00001?ooool2o`0000[ooooo0_l00006ooooo`So00001Oooool2o`0001;ooooo0ol0
00000ooooooo0000o`000006o`0000?ooooo0ol00003ooooo`;o00001Oooool2o`000003ooooool0
003o000000[o000000?oooooo`000?l000004Ol000000ooooooo0000o`000009ooooo`;o00002Ooo
ool3o`0000Cooooo1Ol00004ooooo`;o00003Oooool2o`0003cooooo00001_ooooooMgMgoiRHV?oo
ooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0jooooo`;o0000
1oooool3o`000003ooooool0003o000000Oooooo0_l000001?oooooo0000o`000?l00002ooooo`;o
00001oooool2o`0001?ooooo0_l00002ooooo`;o00003_ooool2o`0000Wooooo1ol000000ooooooo
0000o`000004o`0000Kooooo0_l00007ooooo`;o000000?oooooo`000?l000002_l00002oooooaGo
00002Oooool2o`0000[ooooo0_l00004ooooo`;o00000_ooool2o`0000;ooooo0ol0001;ooooo`00
00Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000
ooooooooool0@oooool3o`0001;ooooo0_l0000Dooooo`;o00000_ooool2o`0000;ooooo0ol00000
0ooooooo0000o`000002ooooo`;o00002_ooool4o`0000;ooooo0_l00002ooooo`?o000000?ooooo
o`000?l000002Ol000000ooooooo0000o`000003ooooo`;o00002?ooool2o`0000;ooooo6ol00002
ooooo`Co00006_ooool2o`0000?ooooo0_l00002ooooo`;o0000C?ooool001cooooo00?o0000oooo
ooooool0=oooool2o`0000[ooooo0_l000000ooooooo0000o`00000@ooooo`;o00001?ooool3o`00
00[ooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool3o`0000Gooooo0_l00007oooo
o`;o00000_ooool3o`0000;ooooo2?l000000ooooooo0000o`00000;o`0000cooooo1Ol00002oooo
oaWo00001?ooool2o`0000Sooooo0_l0000@ooooo`;o00001Oooool2o`0004kooooo000Looooo`03
o`000?oooooooooo02Cooooo0_l0000Aooooo`?o00003?ooool2o`0000Cooooo0_l00008ooooo`Co
00001?ooool3o`0000[ooooo0_l00009ooooo`;o00003oooool2o`0000;ooooo0_l00004ooooo`Oo
000000?oooooo`000?l000002_l0000=ooooob7o00002_ooool2o`000003ooooool0003o000000Wo
oooo0_l00005ooooo`;o00001Oooool2o`0000gooooo0_l0000oooooo`007?ooool00ol0003ooooo
ooooo`0Tooooo`;o00004_ooool2o`000003ooooool0003o000000oooooo0_l00008ooooo`;o0000
1_ooool5o`0000?ooooo0_l00002ooooo`;o00003_ooool2o`0000;ooooo0_l0000:ooooo`;o0000
00Coooooo`000?l0003ooooo1Ol000000ooooooo0000o`00000<o`0000oooooo8?l0000:ooooo`Co
00002_ooool2o`0000Gooooo0_l0000;ooooo`;o00001_ooool3o`0003oooooo000Looooo`03o`00
0?oooooooooo03_ooooo0_l0000Aooooo`;o00001Oooool2o`0000Oooooo1Ol00003ooooo`;o0000
0_ooool2o`0000kooooo0_l00002ooooo`;o00002_ooool2o`000003ooooool0003o000001So0000
3_oooolLo`000003ooooool0003o000000_ooooo1?l0000?ooooo`;o00001?ooool2o`0000Gooooo
0_l00003ooooo`;o000000?oooooo`000?l00000@?ooool001cooooo00?o0000ooooooooool0@ooo
ool3o`0000?ooooo0_l00003ooooo`;o00001Oooool3o`0000Oooooo1Ol00002ooooo`;o000000?o
ooooo`000?l000007_ooool2o`0000;ooooo4ol000000ooooooo0000o`000004o`0000Gooooo0_l0
0006oooooa_o00000oooool2o`0000Cooooo0_l00007ooooo`;o00001Oooool2o`0000?ooooo0_l0
0003ooooo`;o00001?ooool2o`0000Gooooo0_l00003ooooo`;o0000@oooool001cooooo00?o0000
ooooooooool0@oooool3o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o00001?ooool2
o`0000Wooooo1ol000000ooooooo0000o`000007ooooo`;o00000oooool4o`0000kooooo0_l00002
oooooa[o00001Oooool2o`0000Kooooo1Ol000000ooooooo0000o`00000Go`0000Gooooo0_l0000>
ooooo`;o00000_ooool3o`0000Cooooo0_l00007ooooo`;o0000Boooool001cooooo00?o0000oooo
ooooool0?Oooool2o`0000gooooo0_l00002ooooo`;o00004_ooool2o`0000cooooo0_l00003oooo
o`Co00004_oooolJo`0000Sooooo1?l000000ooooooo0000o`00000Mo`0001Cooooo0_l00003oooo
o`;o00001Oooool3o`0000Kooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`0mooooo`;o
00002?ooool2o`0000Oooooo0ol0000Booooo`;o00009_ooool;o`000003ooooool0003o000000ko
00001_ooool>o`000003ooooool0003o000000ko000000Coooooo`000?l0003o00005Oooool2o`00
00_ooooo0_l00006ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0:?ooool2o`0001co
oooo0ol00002ooooo`;o00001?ooool4o`0000Wooooo0_l00005ooooo`;o00000oooool4o`0001go
oooo0_l000000ooooooo0000o`00000Ko`000003ooooool0003o000000Gooooo0_l00003ooooo`Wo
000000?oooooo`000?l000002Ol0000Mooooo`;o00003_ooool2o`0004gooooo000Looooo`03o`00
0?oooooooooo02Sooooo0_l0000>ooooo`;o00003?ooool2o`0000?ooooo1?l00004ooooo`?o0000
1?ooool2o`0000;ooooo0_l00005ooooo`Co000000?oooooo`000?l000000_l0000Mooooo`;o0000
00?oooooo`000?l000005ol00002ooooo`;o000000?oooooo`000?l000003?ooool=o`000003oooo
ool0003o000000;o00002?ooool2o`0000;ooooo0_l0000=ooooo`;o000000?oooooo`000?l00000
3_ooool2o`0000[ooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00003ooo
ool2o`0000;ooooo0_l00005ooooo`?o00000oooool2o`0000Wooooo1?l00002ooooo`;o00001Ooo
ool2o`0000?ooooo0_l00002ooooo`;o00004_oooolGo`0000;ooooo0_l0000Dooooo`Wo00000_oo
ool4o`0000Oooooo0_l00002ooooo`;o00001_ooool2o`0000Gooooo0ol000000ooooooo0000o`00
000=ooooo`;o00002_ooool2o`00047ooooo000Looooo`;o0000@Oooool2o`0000Oooooo0_l00002
ooooo`;o00001?ooool6o`0000Wooooo0_l00002ooooo`?o00000_ooool2o`0000Gooooo0_l00003
ooooo`?o000000?oooooo`000?l000004?oooolJo`000003ooooool0003o000000[ooooo0_l0000;
ooooo`Go00001?ooool3o`0001?ooooo0_l00006ooooo`;o000000Coooooo`000?l0003o00004Ooo
ool2o`0004Sooooo000Looooo`03o`000?oooooooooo02[ooooo0_l0000Dooooo`;o00004Oooool2
o`0000;ooooo0_l00002ooooo`;o00001Oooool2o`0000?ooooo0_l0000>ooooo`?o00004ooooolJ
o`0000Oooooo0_l00003ooooo`?o00001oooool2o`0001Cooooo0_l0000>ooooo`?o00001_ooool2
o`0000;ooooo0_l0000=ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0:_ooool2o`00
02Sooooo0_l00003ooooo`Co00002oooool2o`0000gooooo0ol0000:ooooo`;o00001Oooool2o`00
00;ooooo6?l00007ooooo`;o00000oooool2o`0000Sooooo0_l0000:ooooo`;o00000_ooool2o`00
00Cooooo0_l0000>ooooo`?o00001_ooool2o`0000;ooooo0_l00005ooooo`;o0000D?ooool001co
oooo00?o0000ooooooooool0;?ooool2o`0002Kooooo0_l00003ooooo`;o00003Oooool2o`0000Co
oooo0_l00008ooooo`;o00002_ooool2o`0000Gooooo0_l00002oooooa_o00002oooool2o`0001;o
oooo0_l00002ooooo`;o00006_ooool2o`000003ooooool0003o000000Wooooo0_l0001@ooooo`00
7?ooool00ol0003oooooooooo`0/ooooo`;o00008_ooool2o`0000Gooooo0_l00003ooooo`;o0000
1oooool5o`0000Cooooo0_l0000Looooo`;o000000?oooooo`000?l000006Ol0000;ooooo`;o0000
3oooool2o`0000[ooooo0_l0000Eooooo`;o00001Oooool4o`0000cooooo0_l00017ooooo`007?oo
ool00ol0003oooooooooo`0^ooooo`;o00008?ooool2o`0000Gooooo0_l00003ooooo`Co00001Ooo
ool5o`000003ooooool0003o000000Sooooo0_l0000Eooooo`;o000000?oooooo`000?l000005Ol0
0004ooooo`;o00002?ooool2o`0000Cooooo0_l0000:ooooo`;o00002_ooool2o`0001cooooo1?l0
0008ooooo`;o00000_ooool2o`0004Oooooo000Looooo`03o`000?oooooooooo02kooooo0_l0000N
ooooo`;o00000_ooool3o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000003
ooooo`co00001_ooool2o`0001Gooooo0ol000001Ooooooo0000o`000?l0003ooooo00ko00000_oo
ool2o`0000Cooooo0_l00008ooooo`;o00001?ooool2o`0002Gooooo0_l0000Iooooo`?o0000B_oo
ool001cooooo00?o0000ooooooooool0C_ooool2o`0000;ooooo0ol000001?oooooo0000o`000?oo
ool4o`0000;ooooo0_l000000ooooooo0000o`00000;o`0000Gooooo0_l0000?ooooo`;o00001_oo
oolBo`0004;ooooo0_l0000?ooooo`?o00002?ooool2o`0000Gooooo0_l00013ooooo`007?ooool0
0ol0003oooooooooo`1Booooo`;o00001Oooool2o`0000Cooooo4?l000000ooooooo0000o`000002
ooooo`Co00003Oooool2o`0000Sooooo4?l00002ooooo`;o00002?ooool2o`0002;ooooo1?l0000O
ooooo`?o00002_ooool2o`0000?ooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`1Poooo
oa?o000000?oooooo`000?l000000_l0000Gooooo`_o000000?oooooo`000?l000000_l00002oooo
o`;o00002?ooool2o`0001Wooooo0_l00007ooooo`Co0000;?ooool3o`0004Oooooo000Looooo`03
o`000?oooooooooo063ooooo4ol000000ooooooo0000o`000002o`00013ooooo0_l00002ooooo`?o
000000?oooooo`000?l000000_l00009ooooo`;o000000?oooooo`000?l000006oooool2o`0000Ko
oooo1?l00007ooooo`;o00001_ooool2o`0000;ooooo0_l00006ooooo`;o00001oooool2o`00013o
oooo0ol00017ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00007oooool5o`000003oooo
ool0003o000000Ko00006Oooool2o`0000;ooooo1_l000000ooooooo0000o`00000;ooooo`;o0000
5_ooool2o`0000?ooooo0_l00006ooooo`Co00001?ooool2o`000003ooooool0003o000000Kooooo
0_l00002ooooo`;o00000_ooool3o`000003ooooool0003o000000Gooooo1?l00006ooooo`;o0000
2?ooool2o`0004Sooooo000Looooo`03o`000?oooooooooo043ooooo0_l0000Nooooo`oo00001_oo
ool2o`0001Sooooo0_l00002ooooo`;o00008?ooool2o`000004ooooool0003o0000o`0001;ooooo
0_l00007ooooo`;o00002?ooool3o`000003ooooool0003o000000Gooooo0_l00008ooooo`;o0000
D_ooool001cooooo00?o0000ooooooooool0Coooool2o`0000oooooo3ol00006ooooo`;o00004Ooo
ool2o`0000Gooooo0_l0000:ooooo`;o00006?ooool2o`0000;ooooo0_l0000Kooooo`Ko00001Ooo
ool2o`000003ooooool0003o000000cooooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`1<
ooooo`;o000000?oooooo`000?l000004?ooool>o`0000;ooooo0_l0000Eooooo`;o00000oooool2
o`0000Sooooo0_l00002ooooo`Go00002oooool2o`0002_ooooo1?l0000>ooooo`;o00001_ooool2
o`000003ooooool0003o000000Kooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`1<oooo
o`;o00002_ooool2o`0000Sooooo2ol00004ooooo`;o00001Oooool2o`0001?ooooo1?l00006oooo
o`;o00001?ooool3o`0000;ooooo0_l00007ooooo`;o00001?ooool4o`0001oooooo0ol00006oooo
o`;o00002oooool2o`0000;ooooo0_l00005ooooo`;o00000oooool2o`000003ooooool0003o0000
04[ooooo000Looooo`;o0000COooool2o`0000Wooooo0ol00007ooooo`;o000000?oooooo`000?l0
00001Ol00008ooooo`;o00000oooool2o`000003ooooool0003o000001;ooooo0_l00008ooooo`;o
00001oooool2o`0000_ooooo1_l0000Oooooo`?o000000?oooooo`000?l000000oooool2o`0000?o
oooo0_l0000:ooooo`;o00001?ooool2o`0000Cooooo0_l0001=ooooo`007?ooool00ol0003ooooo
ooooo`0dooooo`;o00006oooool2o`0000Cooooo0_l00008ooooo`;o000000?oooooo`000?l00000
1Ol00008ooooo`;o00001_ooool2o`0000gooooo0_l00003ooooo`;o00002?ooool2o`0001Cooooo
0_l0000Pooooo`;o00001Oooool2o`0000Sooooo0_l0000@ooooo`;o0000Doooool001cooooo00?o
0000ooooooooool0=?ooool2o`0001_ooooo0_l00006ooooo`;o00000_ooool2o`0000Oooooo1Ol0
0002ooooo`;o00003Oooool2o`0000Wooooo0_l000000ooooooo0000o`000006o`0003oooooo0_l0
0008ooooo`;o00002_ooool2o`0001;ooooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`1I
ooooo`;o00000_ooool2o`0000Gooooo0_l000000ooooooo0000o`000004ooooo`?o00003?ooool2
o`0000Wooooo0_l00003ooooo`?o000000?oooooo`000?l000008Oooool3o`0001kooooo0_l00005
ooooo`;o00001_ooool3o`000003ooooool0003o000001;ooooo0_l00002ooooo`;o0000B?ooool0
01cooooo00?o0000ooooooooool0Foooool5o`0000;ooooo1?l00005ooooo`Oo00006_ooool2o`00
017ooooo0_l0000;ooooo`;o00001Oooool5o`0001Oooooo0_l00003ooooo`;o00002Oooool2o`00
00;ooooo0ol0000<ooooo`;o00002oooool2o`0004Sooooo000Looooo`03o`000?oooooooooo05Co
oooo0_l00003ooooo`Oo00000_ooool4o`0000Gooooo0ol000001?oooooo0000o`000?l0000Joooo
o`;o00001_ooool3o`0000Sooooo0_l0000;ooooo`;o00002?ooool2o`0001Oooooo1?l00006oooo
o`Co00000_ooool2o`00017ooooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o
00000oooool4o`0000Oooooo0_l0000=ooooo`;o00001_ooool2o`0001Oooooo0ol0000fooooo`;o
00000_ooool2o`0000Kooooo1?l0000Pooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0
I?ooool2o`0000gooooo0_l00006ooooo`;o000000?oooooo`000?l000004_ooool4o`0003Oooooo
0_l00007ooooo`;o00005?ooool2o`0000Gooooo1?l00006ooooo`;o0000B_ooool001cooooo00?o
0000ooooooooool0I?ooool2o`0001Sooooo0_l0000Booooo`;o00003Oooool3o`0002kooooo0_l0
00001?oooooo0000o`000?l0000=ooooo`;o00001Oooool2o`0000Gooooo1?l0001Booooo`007?oo
ool00ol0003oooooooooo`2Dooooo`;o00002oooool3o`0000_ooooo0_l0000Qooooo`;o000000?o
ooooo`000?l000000_ooool2o`0000[ooooo0_l0001Rooooo`007?ooool00ol0003oooooooooo`1N
ooooo`;o00004Oooool2o`0000_ooooo0_l0000Dooooo`;o00006Oooool2o`0002Gooooo0_l00000
0ooooooo0000o`000009ooooo`;o000000?oooooo`000?l00000H?ooool001cooooo00?o0000oooo
ooooool0G_ooool2o`00017ooooo0_l00008ooooo`;o000000?oooooo`000?l000005?ooool3o`00
01[ooooo0_l0000Sooooo`;o00003?ooool2o`000003ooooool0003o0000063ooooo000Looooo`03
o`000?oooooooooo05Wooooo0_l00004ooooo`;o00001oooool2o`00017ooooo0_l0000Hooooo`;o
000000?oooooo`000?l000005oooool2o`0001Sooooo0_l0000Dooooo`;o00000_ooool2o`0000So
oooo0_l00004ooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0FOooool3o`0000?ooooo
0_l00007ooooo`;o00004Oooool4o`0001?ooooo0_l00004ooooo`?o00004Oooool2o`0001Sooooo
0_l00003ooooo`;o00005?ooool2o`0000;ooooo0_l00008ooooo`Co00000_ooool2o`0005;ooooo
000Looooo`03o`000?oooooooooo05[ooooo1?l00003ooooo`;o00004_ooool2o`0000Cooooo1?l0
000Cooooo`;o00001Oooool2o`00017ooooo0_l0000Fooooo`Co00001_ooool2o`0000;ooooo0_l0
000:ooooo`;o00004Oooool2o`0005Kooooo000Looooo`03o`000?oooooooooo05cooooo0_l00003
ooooo`;o00004_ooool4o`0004_ooooo1Ol00005ooooo`;o00000_ooool2o`0000Wooooo0ol00003
ooooo`?o00000oooool2o`0000?ooooo0_l0001Iooooo`007?ooool2o`0007Cooooo1ol00005oooo
o`;o00008Oooool2o`00027ooooo1?l00005ooooo`Co00002oooool2o`0000Cooooo0ol00003oooo
o`;o00000oooool2o`0005Wooooo000Looooo`03o`000?oooooooooo07?ooooo1ol00005ooooo`;o
00003oooool2o`0000kooooo1?l0000Iooooo`;o00003_ooool2o`000003ooooool0003o000001Go
oooo1?l0001Nooooo`007?ooool00ol0003oooooooooo`1gooooo`;o00001?ooool2o`00017ooooo
0_l0000<ooooo`Co00001Oooool2o`0000[ooooo0_l00008ooooo`;o00000oooool2o`0000Wooooo
0_l0000Cooooo`;o00000oooool4o`0005kooooo000Looooo`03o`000?oooooooooo06;ooooo0_l0
000Iooooo`Co00004Oooool2o`0000[ooooo0_l00002ooooo`;o00000oooool2o`0000[ooooo0_l0
0004ooooo`;o00000oooool3o`000003ooooool0003o000000_ooooo0_l0000Aooooo`;o000000?o
ooooo`000?l00000H_ooool001cooooo00?o0000ooooooooool0H_ooool2o`0000Cooooo0_l00009
ooooo`;o00001?ooool2o`0000Cooooo0_l0000Aooooo`;o00000oooool2o`0000Wooooo0_l00007
ooooo`;o000000?oooooo`000?l000001_ooool2o`000003ooooool0003o000000?ooooo0ol00003
ooooo`;o00002Oooool2o`0000Wooooo0_l00009ooooo`;o00000_ooool2o`0005kooooo000Loooo
o`03o`000?oooooooooo06Gooooo0_l000001?oooooo0000o`000?ooool2o`0000Kooooo0_l00004
ooooo`;o00002Oooool2o`0000kooooo0_l000000ooooooo0000o`00000Booooo`;o000000?ooooo
o`000?l000001_ooool2o`0000cooooo0_l00008ooooo`;o00002_ooool2o`0000?ooooo0_l00008
ooooo`;o0000G_ooool001cooooo00?o0000ooooooooool0IOooool2o`0000Cooooo0_l000000ooo
oooo0000o`000002o`0001;ooooo0_l0000>ooooo`;o00003_ooool2o`0001;ooooo0_l0000@oooo
o`;o00000_ooool3o`000003ooooool0003o000000Cooooo0_l00005ooooo`;o0000J?ooool001co
oooo00?o0000ooooooooool0H_ooool2o`0000Cooooo0_l00004ooooo`Co00000oooool3o`0002_o
oooo0ol0000;ooooo`;o00001Oooool3o`0000oooooo0_l000000ooooooo0000o`000002o`000003
ooooool0003o000000;ooooo1?l0001_ooooo`007?ooool00ol0003oooooooooo`1Rooooo`;o0000
1?ooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000;o0000
3oooool2o`0000;ooooo0_l0000Eooooo`;o00003?ooool2o`0000Kooooo0_l000000ooooooo0000
o`000002o`0000gooooo0_l00007ooooo`Co00002oooool2o`0006;ooooo000Looooo`03o`000?oo
oooooooo06;ooooo0_l00006ooooo`;o000000?oooooo`000?l000000oooool2o`000003ooooool0
003o000000?o00002Oooool2o`0000?ooooo0_l00002ooooo`;o00006?ooool2o`0001Cooooo1?l0
0004ooooo`;o00003?ooool4o`0000;ooooo0_l0000;ooooo`;o0000H_ooool001cooooo00?o0000
ooooooooool0H_ooool2o`0000Kooooo0_l00002ooooo`;o00001?ooool2o`0000;ooooo0_l00009
ooooo`;o00000oooool2o`00017ooooo0_l00009ooooo`Co000000Coooooo`000?l0003ooooo0_l0
000=ooooo`;o00001Oooool4o`0000Gooooo0_l00003ooooo`Go0000L_ooool001cooooo00?o0000
ooooooooool0H_ooool2o`0000[ooooo0_l00004ooooo`;o00003Oooool2o`0001Kooooo0_l0000;
ooooo`Go000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000002ooooo`;o00000_oo
ool3o`0000Oooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00001Oooool2o`0007;ooooo
000Looooo`03o`000?oooooooooo06Wooooo0_l00007ooooo`?o00005_ooool4o`0001_ooooo0ol0
00000ooooooo0000o`000003o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o00002ooo
ool3o`0000;ooooo0_l000000ooooooo0000o`000004o`0000Oooooo0_l0001Yooooo`007?ooool0
0ol0003oooooooooo`1Yooooo`;o00001oooool3o`0001Kooooo1?l00007ooooo`;o00003Oooool2
o`0000Cooooo0_l00003ooooo`;o00000_ooool6o`000003ooooool0003o000000?ooooo0_l00007
ooooo`;o00000oooool2o`000003ooooool0003o000000Co00001oooool3o`0006Sooooo00001_oo
ooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0
1_ooool00ol0003oooooooooo`1dooooo`;o00006_ooool2o`0000Cooooo0_l00006ooooo`;o0000
00?oooooo`000?l000000_ooool2o`0000Cooooo0ol00006ooooo`Ko000000Coooooo`000?l0003o
oooo1Ol0000@ooooo`Co00002?ooool2o`0006Sooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMg
M`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1_
ooooo`;o00000_ooool3o`0001Wooooo1Ol0000:ooooo`;o000000?oooooo`000?l000002?ooool3
o`00013ooooo1Ol0000@ooooo`;o00002?ooool2o`0006[ooooo00000ooooooo410@ooooo`02oooo
o`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo06oooooo0_l00002ooooo`;o00006_ooool2o`000003ooooool0003o000001Wooooo0_l00005
ooooo`;o00001oooool2o`0000;ooooo0_l0000Jooooo`;o0000J_ooool00003ooooool0003ooooo
00;ooooo00?o0000ooooooooool02Oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0001c
ooooo`;o00001?ooool2o`0001Oooooo0ol0000>ooooo`;o00002?ooool2o`0000Gooooo0_l00003
ooooo`;o00000_ooool2o`0000;ooooo0_l0000Eooooo`;o0000Koooool00003ooooool0003ooooo
00;ooooo00?o0000ooooooooool02Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000
ooooooooool0MOooool3o`000004ooooool0003o0000o`0001Kooooo0ol00002ooooo`;o00002_oo
ool2o`0001Cooooo0_l00009ooooo`;o00000oooool3o`0000cooooo0_l0001_ooooo`0000?ooooo
oa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_oo
ool00ol0003oooooooooo`1eooooo`Co000000?oooooo`000?l000006oooool2o`0000Cooooo0_l0
000;ooooo`;o00000oooool4o`00017ooooo2?l00008ooooo`;o0000Loooool00006oooooomgMgOo
V9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000oooooooo
ool0Loooool2o`0000;ooooo1Ol00006ooooo`?o00004oooool2o`0000?ooooo0_l0000;ooooo`;o
00000oooool4o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`;o00000_ooool4o`0000_o
oooo0_l0001cooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000
oa0@4?nYZJT01_ooool00ol0003oooooooooo`1cooooo`;o00000oooool3o`0000?ooooo1ol0000B
ooooo`?o00006oooool3o`000004ooooool0003o0000o`0000Gooooo0ol00025ooooo`007?ooool0
0ol0003oooooooooo`1/ooooo`;o00002oooool2o`0000?ooooo1?l0000Eooooo`;o00004oooool2
o`0000Oooooo0_l00003ooooo`;o00001_ooool2o`0008Gooooo000Looooo`03o`000?oooooooooo
06cooooo0_l0000Eooooo`;o00001_ooool2o`0000Gooooo0_l00002ooooo`;o00003_ooool4o`00
00;ooooo0_l00007ooooo`;o0000T_ooool001cooooo00?o0000ooooooooool0OOooool2o`0000Co
oooo0_l00003ooooo`;o000000?oooooo`000?l000001Oooool2o`0000;ooooo0_l000000ooooooo
0000o`00000:ooooo`Go00003Oooool2o`0000gooooo0_l00021ooooo`007?ooool00ol0003ooooo
ooooo`1dooooo`;o00001oooool2o`000003ooooool0003o000000Kooooo0ol00002ooooo`;o0000
2_ooool2o`0000[ooooo1ol00008ooooo`;o000000?oooooo`000?l000003Oooool2o`00087ooooo
000Looooo`03o`000?oooooooooo07Cooooo0ol00006ooooo`;o000000?oooooo`000?l000001_oo
ool3o`0000;ooooo0_l0000Jooooo`?o00002?ooool2o`0000?ooooo0_l0002>ooooo`007?ooool0
0ol0003oooooooooo`1eooooo`;o00002_ooool2o`0000Gooooo0_l0000?ooooo`?o00002oooool2
o`000003ooooool0003o000000Sooooo0_l00003ooooo`;o0000S_ooool001cooooo00?o0000oooo
ooooool0POooool3o`0000Cooooo0_l0000?ooooo`?o00001?ooool2o`0000?ooooo1?l0002Poooo
o`007?ooool00ol0003oooooooooo`21ooooo`?o00001?ooool2o`0000[ooooo0_l00003ooooo`?o
00001?ooool2o`0000?ooooo0_l00002ooooo`;o00001oooool3o`0009Cooooo000Looooo`03o`00
0?oooooooooo07[ooooo0_l00005ooooo`;o00003Oooool2o`0000;ooooo0_l00002ooooo`Go0000
0_ooool2o`0000Sooooo0_l00007ooooo`?o00000oooool2o`000003ooooool0003o000008cooooo
000Looooo`03o`000?oooooooooo07[ooooo0_l0000Dooooo`;o000000Coooooo`000?l0003o0000
0_ooool2o`000003ooooool0003o000000;ooooo0_l0000Booooo`;o00000oooool2o`000003oooo
ool0003o000008cooooo000Looooo`03o`000?oooooooooo09?ooooo0_l0000:ooooo`;o00002?oo
ool2o`0000Cooooo0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o000008cooooo000L
ooooo`;o0000X?ooool2o`0000Sooooo0_l00004ooooo`;o00000oooool2o`0000;ooooo0_l00000
0ooooooo0000o`00002<ooooo`007?ooool00ol0003oooooooooo`2?ooooo`;o00003Oooool2o`00
00[ooooo0_l000000ooooooo0000o`00002Jooooo`007?ooool00ol0003oooooooooo`2?ooooo`;o
000000?oooooo`000?l000002_ooool4o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l0
0000V_ooool001cooooo00?o0000ooooooooool0T_ooool4o`0000[ooooo0_l00002ooooo`;o0000
Xoooool001cooooo00?o0000ooooooooool0U?ooool3o`000;;ooooo000Looooo`03o`000?oooooo
oooo09Gooooo0_l0000<ooooo`;o0000Y?ooool001cooooo00?o0000ooooooooool0VOooool2o`00
0003ooooool0003o000000Gooooo0_l0002Tooooo`007?ooool00ol0003oooooooooo`2Iooooo`;o
000000?oooooo`000?l00000Zoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooo
ooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB_ooool001Cooooo00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o
0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Doooo
o`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`00
4_ooool00omEEEGoIVIVo`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo002Uooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05Oooool01Oo^
k^ko<S8bo`000?l@413oc<c<00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`;o000000?o
410@ooooooooool0S_ooool00:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00002Ooo
ool01OmEEEGoMgMgoooooonHV9So8B4Q00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`2?ooooo`00Y_ooool01Ol0003ooooooooooooooooo000001Sooooo00Go0000oooooooooooo
ooooo`000008ooooo`03o`000?oooooooooo00Go0000T?ooool00:Kooooo00Go0000oooooooooooo
ooooo`000009ooooo`Ko00002Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Oooooo00SoMgMgoc8b
<_ooooooooooodA4A?oMgMgoooooo`00097ooooo002Vooooo`05o`000?n7QhOoooooojVYZOl00000
6?ooool01Ol0003oEEEEo`000?l@413oc<c<00Cooooo00Go0000ob4Q8Ol0003o<S8bolc<c002oooo
o`04omgMgOmEEEGoooooo`00097ooooo002Uooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHoooo
ooooool05_ooool00omEEEGoQhN7ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?oMgMgolc<
c?l00000TOooool00<?ooooo00?ogMgMoa0@4?nHV9P01_ooool00ol0003oooooooooo`05ooooo`03
onk^k_m4A4Co0000097ooooo0034ooooo`04olc<c?m4A4Co0000oa0@40Cooooo1?l00005ooooo`03
ogMgMol0003ooooo093ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(660) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.348 .47733 Mdot
.34083 .42579 Mdot
.62189 .65027 Mdot
.53442 .41243 Mdot
.65621 .53526 Mdot
.60065 .63304 Mdot
.47009 .62842 Mdot
.49237 .63737 Mdot
.60916 .62454 Mdot
.27659 .32484 Mdot
.45878 .66003 Mdot
.59155 .3203 Mdot
.45533 .62943 Mdot
.51855 .3622 Mdot
.31811 .69662 Mdot
.54363 .44757 Mdot
.33352 .41677 Mdot
.68531 .50142 Mdot
.55365 .44515 Mdot
.59991 .65948 Mdot
.41403 .46507 Mdot
.52276 .36833 Mdot
.34608 .42439 Mdot
.52051 .36402 Mdot
.56628 .39116 Mdot
.34671 .44957 Mdot
.33808 .48367 Mdot
.5481 .38807 Mdot
.5535 .35261 Mdot
.44055 .65189 Mdot
.71451 .55162 Mdot
.28686 .76076 Mdot
.51976 .44021 Mdot
.47885 .27413 Mdot
.49153 .61083 Mdot
.713 .71054 Mdot
.59622 .60812 Mdot
.47457 .66138 Mdot
.48719 .61871 Mdot
.47303 .60648 Mdot
.45191 .61494 Mdot
.34446 .4429 Mdot
.42416 .6277 Mdot
.58144 .67804 Mdot
.51325 .41571 Mdot
.25328 .60836 Mdot
.78919 .50464 Mdot
.54552 .38755 Mdot
.35232 .46961 Mdot
.58201 .65538 Mdot
.59014 .2305 Mdot
.47165 .66461 Mdot
.31108 .63931 Mdot
.0913 .48217 Mdot
.43995 .64153 Mdot
.53916 .40618 Mdot
.5741 .62576 Mdot
.51368 .39634 Mdot
.53552 .38169 Mdot
.49082 .25234 Mdot
.54762 .35784 Mdot
.70522 .48572 Mdot
.35359 .48159 Mdot
.59183 .66452 Mdot
.60421 .62649 Mdot
.434 .63149 Mdot
.30817 .43108 Mdot
.4562 .62091 Mdot
.59406 .35515 Mdot
.60395 .65508 Mdot
.54183 .39219 Mdot
.45985 .66115 Mdot
.311 .42046 Mdot
.58028 .38501 Mdot
.29884 .59537 Mdot
.40522 .69161 Mdot
.76329 .49154 Mdot
.39365 .35644 Mdot
.3648 .20781 Mdot
.4925 .70111 Mdot
.5228 .35256 Mdot
.34329 .19825 Mdot
.34162 .67774 Mdot
.32794 .42438 Mdot
.48844 .29273 Mdot
.52197 .79133 Mdot
.54847 .34209 Mdot
.58648 .50263 Mdot
.47265 .36317 Mdot
.38731 .53688 Mdot
.60422 .61943 Mdot
.35403 .45054 Mdot
.51585 .41739 Mdot
.54945 .3365 Mdot
.43487 .22527 Mdot
.50568 .42679 Mdot
.51492 .4114 Mdot
.27481 .46384 Mdot
.46149 .654 Mdot
.54061 .30879 Mdot
.57211 .67932 Mdot
.29711 .66319 Mdot
.55219 .41693 Mdot
.61146 .64146 Mdot
.37703 .44577 Mdot
.52791 .42014 Mdot
.43607 .63408 Mdot
.53569 .35845 Mdot
.42548 .59966 Mdot
.36283 .45042 Mdot
.5466 .3354 Mdot
.71354 .51084 Mdot
.3324 .57321 Mdot
.32088 .4745 Mdot
.2128 .40312 Mdot
.5459 .36324 Mdot
.52848 .37615 Mdot
.33517 .42612 Mdot
.56383 .6274 Mdot
.54881 .5129 Mdot
.32248 .41609 Mdot
.48308 .61249 Mdot
.36797 .44819 Mdot
.4984 .33394 Mdot
.56141 .63586 Mdot
.29548 .65613 Mdot
.30237 .67408 Mdot
.79412 .41407 Mdot
.57646 .37466 Mdot
.3017 .69089 Mdot
.58778 .64085 Mdot
.3466 .43666 Mdot
.45174 .62338 Mdot
.49573 .34679 Mdot
.30746 .44992 Mdot
.48617 .63354 Mdot
.73853 .49861 Mdot
.66625 .57346 Mdot
.3085 .4753 Mdot
.59826 .46411 Mdot
.4988 .6241 Mdot
.46834 .60591 Mdot
.61526 .25002 Mdot
.32761 .42718 Mdot
.73234 .48818 Mdot
.48253 .62888 Mdot
.70388 .34735 Mdot
.49303 .35192 Mdot
.67205 .27524 Mdot
.40346 .16633 Mdot
.60219 .23827 Mdot
.20361 .52021 Mdot
.69618 .47886 Mdot
.48276 .62501 Mdot
.5543 .40593 Mdot
.32295 .44373 Mdot
.32933 .43881 Mdot
.54402 .3301 Mdot
.56398 .37623 Mdot
.4972 .3711 Mdot
.51507 .33837 Mdot
.7848 .60288 Mdot
.49869 .36346 Mdot
.46988 .56673 Mdot
.30574 .46142 Mdot
.56977 .38205 Mdot
.62555 .61271 Mdot
.58094 .36442 Mdot
.47405 .6614 Mdot
.53032 .3886 Mdot
.56181 .38442 Mdot
.53803 .42942 Mdot
.46059 .61002 Mdot
.40406 .81964 Mdot
.29348 .26005 Mdot
.62112 .76625 Mdot
.2251 .51043 Mdot
.57926 .63463 Mdot
.51635 .34729 Mdot
.71965 .47402 Mdot
.48016 .31226 Mdot
.53823 .37657 Mdot
.55734 .21521 Mdot
.55766 .37767 Mdot
.33699 .38093 Mdot
.46369 .34752 Mdot
.57677 .80456 Mdot
.39722 .58305 Mdot
.54822 .35119 Mdot
.34499 .25089 Mdot
.68905 .27568 Mdot
.7624 .51742 Mdot
.44027 .63297 Mdot
.60949 .5984 Mdot
.57912 .61214 Mdot
.44799 .60498 Mdot
.53326 .31485 Mdot
.27232 .33741 Mdot
.58323 .33054 Mdot
.29859 .65198 Mdot
.38508 .45908 Mdot
.68907 .48222 Mdot
.31377 .47867 Mdot
.27738 .23993 Mdot
.46598 .47652 Mdot
.40479 .65508 Mdot
.69029 .50686 Mdot
.62737 .63738 Mdot
.3058 .64703 Mdot
.7272 .47647 Mdot
.51746 .40842 Mdot
.3583 .46123 Mdot
.68631 .27215 Mdot
.47952 .43036 Mdot
.84777 .57955 Mdot
.31585 .42902 Mdot
.47324 .53541 Mdot
.44393 .63143 Mdot
.55712 .64303 Mdot
.55179 .34628 Mdot
.50314 .37767 Mdot
.35166 .4812 Mdot
.54802 .38142 Mdot
.40118 .50312 Mdot
.55856 .38622 Mdot
.56463 .65945 Mdot
.74427 .51735 Mdot
.44036 .60306 Mdot
.78904 .39668 Mdot
.30614 .42028 Mdot
.52826 .55635 Mdot
.62192 .6333 Mdot
.25225 .45877 Mdot
.4489 .65977 Mdot
.7339 .50407 Mdot
.61026 .60909 Mdot
.75207 .48452 Mdot
.55389 .42297 Mdot
.59935 .6112 Mdot
.71058 .50235 Mdot
.63488 .57479 Mdot
.51823 .41363 Mdot
.66945 .32207 Mdot
.47738 .63114 Mdot
.3319 .4839 Mdot
.54889 .35781 Mdot
.29345 .67476 Mdot
.53337 .32295 Mdot
.30455 .6936 Mdot
.29068 .65483 Mdot
.3037 .64025 Mdot
.42518 .70636 Mdot
.72079 .46832 Mdot
.2432 .56635 Mdot
.50814 .50394 Mdot
.3278 .41507 Mdot
.50688 .41655 Mdot
.47522 .84154 Mdot
.47855 .62509 Mdot
.51894 .40769 Mdot
.53635 .79032 Mdot
.482 .62882 Mdot
.51656 .39055 Mdot
.4494 .61438 Mdot
.32441 .44051 Mdot
.54638 .53332 Mdot
.36118 .42823 Mdot
.53103 .40938 Mdot
.45927 .64434 Mdot
.60906 .60198 Mdot
.34537 .45031 Mdot
.53738 .36263 Mdot
.51474 .35214 Mdot
.30569 .65082 Mdot
.56945 .37542 Mdot
.50509 .82966 Mdot
.54523 .39034 Mdot
.62936 .63529 Mdot
.50088 .42397 Mdot
.67164 .25077 Mdot
.6667 .57042 Mdot
.29874 .44605 Mdot
.29217 .6491 Mdot
.59489 .61714 Mdot
.6244 .54131 Mdot
.66499 .5129 Mdot
.52772 .35604 Mdot
.30448 .66663 Mdot
.47995 .54174 Mdot
.43263 .63969 Mdot
.47267 .37632 Mdot
.43235 .4831 Mdot
.61539 .61857 Mdot
.30295 .64876 Mdot
.46515 .35357 Mdot
.37525 .44334 Mdot
.54279 .40676 Mdot
.60146 .60737 Mdot
.36813 .45678 Mdot
.4923 .34855 Mdot
.79847 .55107 Mdot
.29385 .67187 Mdot
.47553 .62897 Mdot
.62139 .37195 Mdot
.49341 .36915 Mdot
.57522 .61206 Mdot
.31355 .4426 Mdot
.44629 .6484 Mdot
.34375 .46665 Mdot
.7154 .28944 Mdot
.23826 .51918 Mdot
.70155 .6793 Mdot
.67981 .4974 Mdot
.18593 .60637 Mdot
.64215 .75024 Mdot
.26099 .54396 Mdot
.77369 .41961 Mdot
.69064 .75766 Mdot
.62102 .61066 Mdot
.60757 .28124 Mdot
.5842 .61865 Mdot
.55647 .41213 Mdot
.6037 .63122 Mdot
.53818 .83492 Mdot
.55236 .38598 Mdot
.57518 .63284 Mdot
.7668 .6122 Mdot
.55969 .36678 Mdot
.30773 .46907 Mdot
.26163 .71329 Mdot
.23128 .4019 Mdot
.5122 .48358 Mdot
.57134 .63503 Mdot
.50159 .21529 Mdot
.55474 .37304 Mdot
.51529 .44928 Mdot
.32793 .44688 Mdot
.47428 .35814 Mdot
.69213 .49701 Mdot
.75066 .49517 Mdot
.61999 .26579 Mdot
.22237 .42097 Mdot
.56818 .45143 Mdot
.34145 .44708 Mdot
.37641 .20112 Mdot
.29857 .59757 Mdot
.3063 .67679 Mdot
.49119 .62105 Mdot
.40152 .81714 Mdot
.4642 .43139 Mdot
.61374 .44524 Mdot
.40869 .51383 Mdot
.3565 .44503 Mdot
.64437 .72443 Mdot
.4489 .64444 Mdot
.32921 .25055 Mdot
.31814 .3362 Mdot
.49583 .38129 Mdot
.42618 .64457 Mdot
.57789 .3149 Mdot
.4008 .51114 Mdot
.66757 .30039 Mdot
.618 .69992 Mdot
.52612 .41316 Mdot
.25281 .57395 Mdot
.53184 .37965 Mdot
.68669 .28228 Mdot
.52539 .40817 Mdot
.33448 .47013 Mdot
.53344 .4659 Mdot
.63641 .50874 Mdot
.24413 .32207 Mdot
.44971 .46897 Mdot
.709 .46731 Mdot
.51445 .36388 Mdot
.49872 .38151 Mdot
.70198 .49385 Mdot
.33891 .46064 Mdot
.49405 .4003 Mdot
.79759 .49593 Mdot
.49401 .37388 Mdot
.46162 .66573 Mdot
.59156 .52726 Mdot
.25579 .40581 Mdot
.54789 .33886 Mdot
.37141 .45391 Mdot
.43928 .62466 Mdot
.49276 .62979 Mdot
.52914 .45954 Mdot
.47495 .61909 Mdot
.54724 .40245 Mdot
.57848 .52731 Mdot
.35574 .43228 Mdot
.52698 .29678 Mdot
.33182 .46265 Mdot
.45982 .18271 Mdot
.45096 .61063 Mdot
.31744 .6669 Mdot
.62417 .31841 Mdot
.46055 .63643 Mdot
.27277 .48709 Mdot
.46743 .4406 Mdot
.58446 .361 Mdot
.24233 .45208 Mdot
.58277 .60265 Mdot
.31873 .65196 Mdot
.44161 .64587 Mdot
.49574 .36928 Mdot
.5437 .42091 Mdot
.43493 .65849 Mdot
.44943 .23929 Mdot
.71385 .55468 Mdot
.52999 .4061 Mdot
.3357 .46784 Mdot
.34687 .43884 Mdot
.48536 .36486 Mdot
.54116 .37341 Mdot
.63093 .62649 Mdot
.30572 .66827 Mdot
.30546 .64314 Mdot
.3059 .67335 Mdot
.55041 .62228 Mdot
.17982 .57598 Mdot
.46886 .60617 Mdot
.21051 .60928 Mdot
.45661 .77865 Mdot
.52934 .45712 Mdot
.57955 .60709 Mdot
.50983 .38273 Mdot
.56227 .41513 Mdot
.45748 .6478 Mdot
.18773 .4569 Mdot
.59758 .40569 Mdot
.31245 .48092 Mdot
.44853 .66531 Mdot
.51506 .29377 Mdot
.39578 .66782 Mdot
.70042 .50388 Mdot
.45545 .46403 Mdot
.42712 .64773 Mdot
.35456 .46125 Mdot
.43029 .65497 Mdot
.49768 .37834 Mdot
.56563 .33783 Mdot
.35405 .43474 Mdot
.72605 .46852 Mdot
.5257 .42204 Mdot
.51794 .38993 Mdot
.69033 .23544 Mdot
.29279 .59234 Mdot
.43838 .68443 Mdot
.57012 .39957 Mdot
.59107 .39926 Mdot
.72325 .46559 Mdot
.49121 .38048 Mdot
.54846 .34428 Mdot
.33314 .56487 Mdot
.46336 .59998 Mdot
.76128 .48835 Mdot
.30841 .26654 Mdot
.31291 .43367 Mdot
.51395 .82071 Mdot
.29529 .6635 Mdot
.45861 .59742 Mdot
.53598 .53469 Mdot
.31758 .65722 Mdot
.48473 .76982 Mdot
.58552 .77592 Mdot
.31523 .66692 Mdot
.64316 .62546 Mdot
.4366 .383 Mdot
.51268 .33671 Mdot
.52644 .39118 Mdot
.73051 .475 Mdot
.32221 .43262 Mdot
.42852 .56376 Mdot
.56453 .58921 Mdot
.52534 .37114 Mdot
.28219 .43304 Mdot
.5484 .79789 Mdot
.30894 .64948 Mdot
.7089 .47323 Mdot
.69307 .47083 Mdot
.52945 .37947 Mdot
.29562 .5447 Mdot
.34449 .44721 Mdot
.53719 .36273 Mdot
.51434 .34176 Mdot
.56668 .62922 Mdot
.35111 .46688 Mdot
.62201 .63511 Mdot
.28965 .65869 Mdot
.76827 .6935 Mdot
.70757 .24593 Mdot
.47248 .64201 Mdot
.63931 .74208 Mdot
.4658 .6703 Mdot
.54977 .69376 Mdot
.30941 .66957 Mdot
.53124 .36531 Mdot
.30196 .42559 Mdot
.5374 .35948 Mdot
.49611 .39564 Mdot
.50572 .40765 Mdot
.57229 .4484 Mdot
.56662 .21665 Mdot
.71992 .48049 Mdot
.58966 .41083 Mdot
.61901 .59919 Mdot
.56778 .80129 Mdot
.2846 .73627 Mdot
.50745 .36631 Mdot
.52537 .37738 Mdot
.30332 .44192 Mdot
.57894 .40753 Mdot
.43492 .6477 Mdot
.32168 .42702 Mdot
.54228 .41879 Mdot
.67357 .6321 Mdot
.48941 .37221 Mdot
.65677 .73741 Mdot
.43055 .65571 Mdot
.44889 .45717 Mdot
.59062 .37179 Mdot
.31413 .66873 Mdot
.31934 .65373 Mdot
.29813 .67931 Mdot
.42983 .63869 Mdot
.56899 .62477 Mdot
.56482 .59338 Mdot
.4816 .3333 Mdot
.55375 .40402 Mdot
.58539 .35997 Mdot
.54558 .62733 Mdot
.58857 .51673 Mdot
.21179 .53097 Mdot
.45263 .36907 Mdot
.59127 .59607 Mdot
.27923 .46 Mdot
.20483 .37645 Mdot
.31696 .43304 Mdot
.76293 .50077 Mdot
.46914 .66204 Mdot
.69469 .50234 Mdot
.5272 .21271 Mdot
.35856 .43754 Mdot
.34297 .48469 Mdot
.57674 .63432 Mdot
.42028 .55236 Mdot
.10287 .58251 Mdot
.60048 .64414 Mdot
.7842 .45614 Mdot
.33298 .44822 Mdot
.55469 .4369 Mdot
.48079 .54442 Mdot
.42987 .5471 Mdot
.58486 .62645 Mdot
.52081 .35133 Mdot
.27016 .49588 Mdot
.63028 .62872 Mdot
.47829 .39928 Mdot
.57103 .63928 Mdot
.45915 .6123 Mdot
.5834 .64146 Mdot
.2874 .45168 Mdot
.55872 .42104 Mdot
.0867 .51404 Mdot
.35994 .63058 Mdot
.54396 .35584 Mdot
.45346 .66665 Mdot
.811 .55451 Mdot
.50046 .39378 Mdot
.69027 .49619 Mdot
.58512 .59633 Mdot
.74834 .6022 Mdot
.55339 .36825 Mdot
.59467 .62934 Mdot
.29676 .47714 Mdot
.52605 .65746 Mdot
.46059 .6986 Mdot
.31106 .64473 Mdot
.319 .44251 Mdot
.28449 .67889 Mdot
.48893 .60664 Mdot
.52711 .42594 Mdot
.5071 .34773 Mdot
.31402 .46896 Mdot
.42647 .72264 Mdot
.53488 .4363 Mdot
.52266 .35276 Mdot
.62576 .63555 Mdot
.56999 .59638 Mdot
.33398 .7326 Mdot
.62165 .60956 Mdot
.59111 .40045 Mdot
.31758 .47033 Mdot
.54766 .41213 Mdot
.30384 .46429 Mdot
.50849 .41679 Mdot
.25967 .41445 Mdot
.31817 .43317 Mdot
.23944 .48745 Mdot
.56694 .36271 Mdot
.60421 .31045 Mdot
.49493 .3956 Mdot
.51591 .40986 Mdot
.57856 .59913 Mdot
.71798 .49357 Mdot
.47537 .39874 Mdot
.53767 .54571 Mdot
.74071 .47824 Mdot
.4324 .33896 Mdot
.56511 .62575 Mdot
.73901 .48432 Mdot
.6727 .37232 Mdot
.2925 .64879 Mdot
.71112 .48245 Mdot
.33361 .75904 Mdot
.4698 .64328 Mdot
.35564 .42863 Mdot
.56109 .3681 Mdot
.71602 .74423 Mdot
.71348 .5521 Mdot
.30964 .65485 Mdot
.54816 .36324 Mdot
.50808 .38663 Mdot
.37449 .43672 Mdot
.31056 .21561 Mdot
.56293 .65534 Mdot
.53122 .41609 Mdot
.33112 .41761 Mdot
.3868 .17654 Mdot
.57486 .64481 Mdot
.70952 .4783 Mdot
.42697 .65616 Mdot
.38912 .42503 Mdot
.31504 .64623 Mdot
.44616 .61137 Mdot
.6541 .6158 Mdot
.51939 .20215 Mdot
.55104 .37294 Mdot
.59049 .60334 Mdot
.59935 .2362 Mdot
.51522 .31181 Mdot
.4877 .66379 Mdot
.36631 .39494 Mdot
.35561 .44596 Mdot
.43763 .66043 Mdot
.7047 .4674 Mdot
.35705 .43211 Mdot
.34072 .46057 Mdot
.49204 .63766 Mdot
.47216 .5746 Mdot
.47048 .53601 Mdot
.45436 .66381 Mdot
.37271 .55138 Mdot
.6248 .261 Mdot
.30296 .66867 Mdot
.70733 .47314 Mdot
.71894 .28645 Mdot
.34611 .4447 Mdot
.40285 .81781 Mdot
.56886 .21967 Mdot
.51518 .41138 Mdot
.72704 .49977 Mdot
.49093 .77796 Mdot
.61867 .57807 Mdot
.48472 .63431 Mdot
.60391 .50683 Mdot
.68619 .48436 Mdot
.4946 .35377 Mdot
.26941 .39625 Mdot
.56091 .35628 Mdot
.48109 .62595 Mdot
.38258 .51594 Mdot
.34433 .4702 Mdot
.48736 .60528 Mdot
.40781 .49662 Mdot
.56555 .41242 Mdot
.53962 .34433 Mdot
.73604 .33412 Mdot
.35661 .46412 Mdot
.31444 .64499 Mdot
.53301 .3536 Mdot
.51603 .39715 Mdot
.52239 .42728 Mdot
.63232 .34806 Mdot
.29971 .56234 Mdot
.53013 .41714 Mdot
.55327 .63108 Mdot
.58023 .35589 Mdot
.54535 .34515 Mdot
.36337 .42722 Mdot
.64406 .22609 Mdot
.28904 .66614 Mdot
.52529 .39428 Mdot
.52944 .40533 Mdot
.48587 .61471 Mdot
.47515 .53898 Mdot
.42171 .54754 Mdot
.60899 .651 Mdot
.75272 .40568 Mdot
.58006 .32906 Mdot
.30938 .45137 Mdot
.70264 .50927 Mdot
.567 .42343 Mdot
.30673 .4418 Mdot
.56524 .33207 Mdot
.63245 .62146 Mdot
.30657 .66648 Mdot
.59132 .45701 Mdot
.70912 .4866 Mdot
.4363 .59162 Mdot
.23308 .63641 Mdot
.6249 .60994 Mdot
.5613 .39892 Mdot
.53051 .64154 Mdot
.61892 .63027 Mdot
.30537 .65207 Mdot
.46151 .36881 Mdot
.33192 .44072 Mdot
.34588 .46817 Mdot
.64944 .27283 Mdot
.54779 .64253 Mdot
.54816 .16656 Mdot
.46091 .61253 Mdot
.4824 .35486 Mdot
.26263 .68344 Mdot
.33538 .4734 Mdot
.72765 .30819 Mdot
.73815 .48124 Mdot
.48436 .63487 Mdot
.28566 .65086 Mdot
.30528 .4449 Mdot
.3318 .47744 Mdot
.51026 .4142 Mdot
.5116 .37067 Mdot
.78158 .42921 Mdot
.67966 .27764 Mdot
.45194 .61402 Mdot
.70054 .47976 Mdot
.59612 .65478 Mdot
.56692 .40772 Mdot
.3358 .42265 Mdot
.34768 .37938 Mdot
.49609 .36306 Mdot
.63019 .63055 Mdot
.35411 .43961 Mdot
.69852 .48826 Mdot
.73144 .50198 Mdot
.51405 .40995 Mdot
.42323 .32706 Mdot
.46455 .63318 Mdot
.31522 .47316 Mdot
.35306 .4991 Mdot
.51281 .43144 Mdot
.51065 .36653 Mdot
.57868 .30954 Mdot
.44816 .60972 Mdot
.57889 .46221 Mdot
.6876 .46982 Mdot
.3304 .43442 Mdot
.5408 .35567 Mdot
.70531 .48532 Mdot
.62571 .40149 Mdot
.31448 .6634 Mdot
.57311 .64107 Mdot
.69033 .49263 Mdot
.71474 .49944 Mdot
.74463 .48653 Mdot
.38845 .81141 Mdot
.37807 .43251 Mdot
.30264 .26543 Mdot
.50316 .40902 Mdot
.63102 .26871 Mdot
.57518 .36616 Mdot
.43489 .62006 Mdot
.60624 .59918 Mdot
.49521 .38949 Mdot
.50955 .41435 Mdot
.27535 .39675 Mdot
.53712 .28714 Mdot
.41448 .45707 Mdot
.36149 .45572 Mdot
.61198 .31415 Mdot
.57161 .61183 Mdot
.38845 .16152 Mdot
.38181 .83051 Mdot
.59083 .34725 Mdot
.44191 .5519 Mdot
.32387 .42592 Mdot
.48588 .62419 Mdot
.43686 .54005 Mdot
.41456 .63256 Mdot
.33437 .43189 Mdot
.56027 .41234 Mdot
.21378 .60693 Mdot
.74995 .48722 Mdot
.49873 .36918 Mdot
.44623 .62454 Mdot
.49799 .37006 Mdot
.4293 .63213 Mdot
.38032 .4126 Mdot
.37791 .56265 Mdot
.55655 .37922 Mdot
.53248 .43341 Mdot
.52769 .47661 Mdot
.50829 .36813 Mdot
.5206 .73967 Mdot
.3313 .45692 Mdot
.24276 .46927 Mdot
.48438 .37228 Mdot
.42158 .307 Mdot
.49701 .35586 Mdot
.43074 .72792 Mdot
.51781 .34365 Mdot
.60721 .4721 Mdot
.49362 .35308 Mdot
.51826 .3464 Mdot
.45141 .64649 Mdot
.48595 .61736 Mdot
.2981 .47744 Mdot
.32151 .65264 Mdot
.57554 .804 Mdot
.51925 .38305 Mdot
.56758 .60379 Mdot
.26712 .67922 Mdot
.71692 .49723 Mdot
.33719 .4343 Mdot
.47875 .13122 Mdot
.44229 .62005 Mdot
.60037 .66392 Mdot
.47018 .72397 Mdot
.56565 .65166 Mdot
.58375 .67044 Mdot
.59589 .30193 Mdot
.69845 .47899 Mdot
.49748 .35314 Mdot
.45526 .29542 Mdot
.26852 .58324 Mdot
.47965 .39799 Mdot
.52075 .64296 Mdot
.50125 .29573 Mdot
.62511 .25831 Mdot
.74565 .47262 Mdot
.69296 .47881 Mdot
.44381 .64545 Mdot
.61145 .65729 Mdot
.55103 .31434 Mdot
.73964 .48647 Mdot
.60848 .5973 Mdot
.31926 .67097 Mdot
.71558 .52978 Mdot
.3428 .44388 Mdot
.52461 .48619 Mdot
.27107 .6242 Mdot
.44849 .61642 Mdot
.53822 .54263 Mdot
.3115 .40945 Mdot
.37811 .46264 Mdot
.31931 .66707 Mdot
.60096 .59141 Mdot
.32239 .41396 Mdot
.53246 .4226 Mdot
.47856 .42997 Mdot
.53234 .37791 Mdot
.73666 .48759 Mdot
.52481 .33866 Mdot
.61267 .59551 Mdot
.46888 .62033 Mdot
.60662 .61905 Mdot
.46777 .63306 Mdot
.20666 .58166 Mdot
.54378 .37472 Mdot
.51362 .36647 Mdot
.52869 .52852 Mdot
.32295 .4801 Mdot
.47609 .2595 Mdot
.59393 .59064 Mdot
.57653 .62253 Mdot
.54831 .41334 Mdot
.30586 .48183 Mdot
.7332 .51396 Mdot
.48136 .55037 Mdot
.51503 .34324 Mdot
.32982 .45685 Mdot
.54338 .4098 Mdot
.7013 .66707 Mdot
.36073 .59202 Mdot
.34262 .46807 Mdot
.23484 .33144 Mdot
.57098 .37434 Mdot
.45776 .32773 Mdot
.57858 .43402 Mdot
.72482 .42783 Mdot
.48934 .42197 Mdot
.31768 .42687 Mdot
.53251 .38586 Mdot
.31392 .44915 Mdot
.62371 .62337 Mdot
.47529 .61003 Mdot
.32026 .44621 Mdot
.5582 .34658 Mdot
.33815 .79575 Mdot
.44904 .61893 Mdot
.51375 .35672 Mdot
.45123 .6571 Mdot
.34074 .41828 Mdot
.34117 .47736 Mdot
.34498 .75776 Mdot
.40596 .67286 Mdot
.44463 .62249 Mdot
.55029 .40274 Mdot
.31426 .62001 Mdot
.54782 .4117 Mdot
.78127 .42186 Mdot
.48041 .37709 Mdot
.49733 .42188 Mdot
.19381 .62368 Mdot
.41467 .62408 Mdot
.51526 .1523 Mdot
.58305 .57975 Mdot
.37125 .80231 Mdot
.35328 .41095 Mdot
.746 .47288 Mdot
.62686 .74406 Mdot
.29044 .66135 Mdot
.55726 .62381 Mdot
.49476 .38859 Mdot
.25866 .41097 Mdot
.44963 .66441 Mdot
.7232 .49018 Mdot
.55721 .37859 Mdot
.63448 .63428 Mdot
.31143 .74546 Mdot
.48353 .62591 Mdot
.34338 .44165 Mdot
.31926 .48075 Mdot
.33436 .22069 Mdot
.54305 .35809 Mdot
.51752 .36943 Mdot
.47063 .66225 Mdot
.55173 .31884 Mdot
.74383 .49778 Mdot
.73759 .64372 Mdot
.44196 .62918 Mdot
.35686 .63395 Mdot
.36336 .45139 Mdot
.50857 .38481 Mdot
.60232 .52771 Mdot
.42131 .78796 Mdot
.33153 .27067 Mdot
.72755 .4744 Mdot
.75395 .37859 Mdot
.31735 .42715 Mdot
.44893 .62473 Mdot
.64197 .30652 Mdot
.52124 .32487 Mdot
.50925 .39018 Mdot
.74957 .36877 Mdot
.47134 .54445 Mdot
.66814 .48831 Mdot
.56032 .43736 Mdot
.49021 .53411 Mdot
.54974 .41409 Mdot
.54505 .42084 Mdot
.59045 .34462 Mdot
.54056 .33976 Mdot
.32291 .45477 Mdot
.2667 .38405 Mdot
.59408 .63585 Mdot
.42371 .21982 Mdot
.61132 .49722 Mdot
.55685 .35916 Mdot
.56213 .41298 Mdot
.24395 .37892 Mdot
.26961 .66916 Mdot
.33488 .45439 Mdot
.2827 .48089 Mdot
.46534 .60454 Mdot
.54519 .28781 Mdot
.54592 .63587 Mdot
.4208 .43021 Mdot
.61467 .62714 Mdot
.32853 .45741 Mdot
.57244 .62015 Mdot
.47487 .60428 Mdot
.59132 .60344 Mdot
.55009 .62467 Mdot
.42062 .63815 Mdot
.36389 .45944 Mdot
.50939 .35019 Mdot
.45148 .61101 Mdot
.74412 .34171 Mdot
.73673 .48869 Mdot
.34286 .75777 Mdot
.56794 .4327 Mdot
.42637 .39021 Mdot
.79834 .55018 Mdot
.59473 .6128 Mdot
.34627 .59029 Mdot
.31816 .43341 Mdot
.70873 .51334 Mdot
.31854 .45267 Mdot
.53063 .22137 Mdot
.70616 .49525 Mdot
.34236 .75945 Mdot
.64857 .32002 Mdot
.60987 .54861 Mdot
.55379 .33489 Mdot
.26371 .42294 Mdot
.61635 .62474 Mdot
.46322 .66581 Mdot
.51804 .78685 Mdot
.5777 .38082 Mdot
.25744 .54464 Mdot
.38182 .44208 Mdot
.29673 .64562 Mdot
.45396 .62278 Mdot
.51591 .63877 Mdot
.54413 .3623 Mdot
.60275 .54285 Mdot
.48498 .40484 Mdot
.61659 .29732 Mdot
.76297 .4045 Mdot
.38574 .4058 Mdot
.54298 .40548 Mdot
.61669 .64508 Mdot
.54525 .40821 Mdot
.44335 .38794 Mdot
.61322 .25045 Mdot
.57396 .42421 Mdot
.23535 .50482 Mdot
.76442 .58575 Mdot
.34893 .43028 Mdot
.59264 .39989 Mdot
.30364 .65905 Mdot
.5729 .39068 Mdot
.79629 .6978 Mdot
.71372 .4846 Mdot
.64861 .59752 Mdot
.55676 .34263 Mdot
.53519 .35607 Mdot
.40379 .36679 Mdot
.2956 .40556 Mdot
.28594 .65334 Mdot
.50839 .39503 Mdot
.73807 .37847 Mdot
.4491 .65019 Mdot
.48691 .35344 Mdot
.52942 .38646 Mdot
.75416 .32137 Mdot
.45202 .65348 Mdot
.58941 .60973 Mdot
.29132 .65102 Mdot
.5962 .65352 Mdot
.75032 .47459 Mdot
.41872 .53721 Mdot
.70744 .29051 Mdot
.35954 .59474 Mdot
.68755 .49414 Mdot
.53525 .33312 Mdot
.45213 .32934 Mdot
.53627 .34738 Mdot
.69629 .47494 Mdot
.44099 .65247 Mdot
.32458 .45258 Mdot
.57242 .47554 Mdot
.29946 .65212 Mdot
.48436 .40938 Mdot
.73854 .46831 Mdot
.32631 .44345 Mdot
.36384 .74467 Mdot
.32868 .42953 Mdot
.45729 .63942 Mdot
.45527 .60296 Mdot
.71016 .49359 Mdot
.32 .45436 Mdot
.56994 .64558 Mdot
.56613 .58705 Mdot
.48066 .38521 Mdot
.48174 .67299 Mdot
.2914 .45115 Mdot
.3375 .4843 Mdot
.30118 .43176 Mdot
.54704 .37389 Mdot
.46143 .54503 Mdot
.52647 .32262 Mdot
.43704 .63022 Mdot
.56121 .62896 Mdot
.66823 .27419 Mdot
.45256 .29437 Mdot
.35846 .62723 Mdot
.47894 .40611 Mdot
.53949 .34222 Mdot
.52943 .37918 Mdot
.53523 .40421 Mdot
.72283 .65841 Mdot
.54246 .37586 Mdot
.46327 .64105 Mdot
.60891 .63693 Mdot
.54766 .36007 Mdot
.30316 .66225 Mdot
.52888 .51157 Mdot
.69937 .50764 Mdot
.60903 .4747 Mdot
.38298 .82317 Mdot
.32682 .44471 Mdot
.60866 .60644 Mdot
.56293 .63607 Mdot
.73843 .49879 Mdot
.46427 .61203 Mdot
.3237 .43253 Mdot
.69257 .4231 Mdot
.73997 .47557 Mdot
.525 .39517 Mdot
.56055 .52874 Mdot
.22082 .35103 Mdot
.53199 .33076 Mdot
.50639 .40546 Mdot
.30023 .64103 Mdot
.56865 .65604 Mdot
.70354 .77213 Mdot
.43932 .56688 Mdot
.71567 .49363 Mdot
.69663 .49464 Mdot
.3093 .42466 Mdot
.47452 .36981 Mdot
.46712 .62859 Mdot
.48859 .54239 Mdot
.81441 .53191 Mdot
.5134 .80147 Mdot
.53603 .69402 Mdot
.48947 .37799 Mdot
.35196 .36358 Mdot
.49886 .41459 Mdot
.37766 .44389 Mdot
.30422 .43376 Mdot
.33902 .45095 Mdot
.45007 .64535 Mdot
.46478 .18468 Mdot
.46614 .6393 Mdot
.38514 .82546 Mdot
.33895 .42135 Mdot
.65476 .55891 Mdot
.57241 .62775 Mdot
.47748 .34093 Mdot
.70063 .4771 Mdot
.50654 .66714 Mdot
.59407 .38926 Mdot
.2869 .54346 Mdot
.57981 .60709 Mdot
.34921 .47364 Mdot
.45194 .41043 Mdot
.6005 .80071 Mdot
.4041 .55466 Mdot
.78031 .52072 Mdot
.52011 .23343 Mdot
.70246 .49358 Mdot
.2922 .29971 Mdot
.74792 .49118 Mdot
.48459 .63135 Mdot
.57721 .37813 Mdot
.56508 .35554 Mdot
.52977 .41407 Mdot
.543 .37914 Mdot
.44147 .64701 Mdot
.48689 .38977 Mdot
.67047 .25049 Mdot
.29597 .66957 Mdot
.66199 .579 Mdot
.71653 .50629 Mdot
.42777 .62804 Mdot
.61464 .63453 Mdot
.32302 .65782 Mdot
.78573 .3863 Mdot
.48839 .3885 Mdot
.49456 .39236 Mdot
.30569 .67544 Mdot
.55209 .32069 Mdot
.46062 .42384 Mdot
.59695 .63274 Mdot
.42952 .50302 Mdot
.69649 .47019 Mdot
.6951 .50236 Mdot
.42888 .65098 Mdot
.31838 .45293 Mdot
.73308 .47569 Mdot
.61903 .65248 Mdot
.49465 .34656 Mdot
.54365 .43299 Mdot
.29113 .45249 Mdot
.56901 .21962 Mdot
.75499 .48985 Mdot
.46398 .44034 Mdot
.31097 .44294 Mdot
.38127 .43908 Mdot
.50649 .39333 Mdot
.48761 .42608 Mdot
.35711 .47414 Mdot
.71539 .50777 Mdot
.42531 .63214 Mdot
.64164 .54973 Mdot
.47417 .62148 Mdot
.32164 .43849 Mdot
.54468 .32524 Mdot
.36388 .45659 Mdot
.57095 .37704 Mdot
.24174 .24128 Mdot
.53366 .33831 Mdot
.25356 .46957 Mdot
.73726 .42951 Mdot
.57196 .64253 Mdot
.57939 .64922 Mdot
.30499 .6651 Mdot
.3132 .43513 Mdot
.56687 .42225 Mdot
.69444 .48815 Mdot
.35539 .7903 Mdot
.36679 .4877 Mdot
.57966 .6013 Mdot
.55548 .64667 Mdot
.43969 .64966 Mdot
.50135 .35078 Mdot
.51167 .3827 Mdot
.5909 .60436 Mdot
.79637 .57327 Mdot
.31108 .45687 Mdot
.5178 .36916 Mdot
.54532 .34426 Mdot
.59628 .63756 Mdot
.56962 .58416 Mdot
.29376 .41144 Mdot
.5408 .34033 Mdot
.65483 .33084 Mdot
.43208 .6278 Mdot
.54682 .39471 Mdot
.48997 .39771 Mdot
.72464 .49638 Mdot
.67413 .60249 Mdot
.62055 .25605 Mdot
.43953 .61251 Mdot
.30985 .64351 Mdot
.57633 .37129 Mdot
.57452 .62946 Mdot
.55461 .43644 Mdot
.6843 .73393 Mdot
.29283 .66465 Mdot
.53636 .36805 Mdot
.58132 .33374 Mdot
.30987 .47333 Mdot
.5364 .36435 Mdot
.29598 .3957 Mdot
.60582 .64842 Mdot
.53766 .36806 Mdot
.42803 .31789 Mdot
.43821 .64712 Mdot
.59331 .38877 Mdot
.692 .49129 Mdot
.73334 .43273 Mdot
.24674 .63717 Mdot
.55367 .61387 Mdot
.72781 .50309 Mdot
.52201 .33915 Mdot
.62438 .64085 Mdot
.42761 .65705 Mdot
.264 .53783 Mdot
.51901 .33293 Mdot
.46543 .61552 Mdot
.46403 .61835 Mdot
.71262 .49083 Mdot
.46823 .14555 Mdot
.57983 .33085 Mdot
.50713 .36186 Mdot
.83062 .46797 Mdot
.33854 .414 Mdot
.50659 .35889 Mdot
.50359 .34999 Mdot
.47665 .63251 Mdot
.63963 .34195 Mdot
.37385 .50052 Mdot
.76691 .61236 Mdot
.43014 .62952 Mdot
.62183 .59179 Mdot
.62437 .63444 Mdot
.72219 .50482 Mdot
.34922 .43203 Mdot
.6845 .48362 Mdot
.58213 .63767 Mdot
.51756 .41034 Mdot
.48125 .64384 Mdot
.37374 .26298 Mdot
.47087 .66517 Mdot
.63089 .63819 Mdot
.37015 .46307 Mdot
.25856 .68321 Mdot
.86192 .47756 Mdot
.26463 .61754 Mdot
.43024 .61913 Mdot
.71739 .49728 Mdot
.4542 .5656 Mdot
.53864 .34238 Mdot
.29723 .28387 Mdot
.50215 .36465 Mdot
.52579 .23137 Mdot
.60593 .59818 Mdot
.31622 .67153 Mdot
.57833 .38247 Mdot
.75048 .37942 Mdot
.43108 .61936 Mdot
.43507 .64598 Mdot
.53046 .39892 Mdot
.45982 .63805 Mdot
.51443 .37699 Mdot
.6006 .6404 Mdot
.47915 .14909 Mdot
.5251 .34377 Mdot
.58632 .40455 Mdot
.4615 .59928 Mdot
.34208 .7581 Mdot
.62186 .5946 Mdot
.36252 .36554 Mdot
.61776 .79716 Mdot
.46065 .63475 Mdot
.56907 .44383 Mdot
.60009 .61004 Mdot
.30274 .64014 Mdot
.62118 .66485 Mdot
.50051 .37462 Mdot
.49215 .39356 Mdot
.54145 .41513 Mdot
.5424 .345 Mdot
.28029 .30299 Mdot
.45386 .38505 Mdot
.34096 .33842 Mdot
.49611 .39676 Mdot
.26201 .46904 Mdot
.4602 .64514 Mdot
.41065 .44522 Mdot
.67074 .47869 Mdot
.49192 .39561 Mdot
.28945 .40856 Mdot
.43083 .62274 Mdot
.40479 .82847 Mdot
.44643 .65219 Mdot
.59895 .6185 Mdot
.48927 .62962 Mdot
.56902 .3735 Mdot
.34797 .44048 Mdot
.6077 .64425 Mdot
.21164 .54314 Mdot
.55932 .61916 Mdot
.54405 .35624 Mdot
.61407 .56694 Mdot
.56941 .64044 Mdot
.56607 .49768 Mdot
.34849 .43777 Mdot
.72655 .36394 Mdot
.34526 .41585 Mdot
.53105 .36228 Mdot
.52612 .35902 Mdot
.32374 .65587 Mdot
.48324 .6252 Mdot
.33709 .41879 Mdot
.68579 .23257 Mdot
.72213 .46113 Mdot
.34493 .45448 Mdot
.47647 .4151 Mdot
.45474 .55102 Mdot
.32193 .47358 Mdot
.73073 .40183 Mdot
.48096 .62455 Mdot
.31219 .41962 Mdot
.46399 .36816 Mdot
.6243 .43555 Mdot
.74095 .50426 Mdot
.63272 .61877 Mdot
.49339 .51641 Mdot
.62112 .63869 Mdot
.49341 .60816 Mdot
.55828 .6555 Mdot
.45373 .64995 Mdot
.23934 .44518 Mdot
.38544 .51225 Mdot
.48813 .60047 Mdot
.47331 .60189 Mdot
.58483 .63225 Mdot
.53321 .40462 Mdot
.63085 .5137 Mdot
.47274 .40592 Mdot
.56174 .3359 Mdot
.43762 .61998 Mdot
.31723 .42512 Mdot
.36623 .44343 Mdot
.26221 .43371 Mdot
.33426 .47881 Mdot
.61542 .63826 Mdot
.35694 .58343 Mdot
.51778 .22167 Mdot
.45001 .65932 Mdot
.40809 .65647 Mdot
.55181 .41135 Mdot
.57796 .63153 Mdot
.62524 .6203 Mdot
.47151 .62643 Mdot
.36693 .24222 Mdot
.58912 .37713 Mdot
.36642 .42801 Mdot
.34024 .42155 Mdot
.32538 .47259 Mdot
.29631 .45611 Mdot
.42442 .1886 Mdot
.46339 .66583 Mdot
.31895 .42766 Mdot
.53736 .3882 Mdot
.49192 .378 Mdot
.30467 .64562 Mdot
.7039 .50372 Mdot
.58142 .37565 Mdot
.58492 .38022 Mdot
.50603 .39153 Mdot
.5711 .64045 Mdot
.52257 .30076 Mdot
.29341 .66052 Mdot
.55836 .65395 Mdot
.5466 .63116 Mdot
.31851 .66493 Mdot
.39047 .46961 Mdot
.58744 .81582 Mdot
.53185 .41586 Mdot
.54493 .27383 Mdot
.57884 .62725 Mdot
.34594 .54077 Mdot
.57877 .45929 Mdot
.54696 .40161 Mdot
.64966 .49923 Mdot
.60243 .64239 Mdot
.38222 .46351 Mdot
.50466 .36879 Mdot
.30657 .67186 Mdot
.70999 .51025 Mdot
.46447 .37859 Mdot
.29932 .64093 Mdot
.3267 .45877 Mdot
.77076 .56295 Mdot
.32834 .41278 Mdot
.57009 .6433 Mdot
.59353 .39612 Mdot
.09144 .56095 Mdot
.61694 .62339 Mdot
.43292 .81497 Mdot
.39688 .50636 Mdot
.52957 .34159 Mdot
.62182 .63469 Mdot
.3817 .461 Mdot
.43273 .62687 Mdot
.51341 .52451 Mdot
.33684 .42308 Mdot
.32233 .66177 Mdot
.31486 .64867 Mdot
.59548 .63602 Mdot
.35936 .45046 Mdot
.48247 .37818 Mdot
.30158 .45838 Mdot
.49092 .63717 Mdot
.56254 .38404 Mdot
.57765 .80439 Mdot
.47974 .43128 Mdot
.30974 .44284 Mdot
.62469 .64954 Mdot
.72367 .46656 Mdot
.55535 .37904 Mdot
.49436 .82232 Mdot
.50357 .34848 Mdot
.44651 .65578 Mdot
.32513 .52984 Mdot
.35741 .27337 Mdot
.52671 .40761 Mdot
.55682 .41354 Mdot
.42626 .64943 Mdot
.52499 .40931 Mdot
.52158 .33408 Mdot
.49735 .65739 Mdot
.32135 .47602 Mdot
.53122 .37394 Mdot
.62855 .61492 Mdot
.52577 .24893 Mdot
.58082 .39534 Mdot
.21975 .49768 Mdot
.73816 .37032 Mdot
.33238 .52528 Mdot
.57117 .42116 Mdot
.74675 .33928 Mdot
.52119 .35947 Mdot
.54941 .37929 Mdot
.53633 .41215 Mdot
.32874 .36433 Mdot
.58165 .63484 Mdot
.595 .59425 Mdot
.72828 .5114 Mdot
.74227 .37743 Mdot
.72962 .49701 Mdot
.42285 .63864 Mdot
.42387 .70779 Mdot
.29631 .66855 Mdot
.31667 .45155 Mdot
.55441 .42183 Mdot
.55451 .6245 Mdot
.50613 .38262 Mdot
.5717 .39216 Mdot
.59236 .64454 Mdot
.62175 .62963 Mdot
.54236 .64004 Mdot
.74597 .48184 Mdot
.33068 .45036 Mdot
.51529 .41387 Mdot
.73967 .47686 Mdot
.48351 .36661 Mdot
.45763 .55465 Mdot
.33302 .45184 Mdot
.30169 .46072 Mdot
.36354 .43227 Mdot
.5016 .40801 Mdot
.56587 .36926 Mdot
.46745 .63814 Mdot
.29116 .44819 Mdot
.45028 .66136 Mdot
.62058 .63653 Mdot
.57922 .64782 Mdot
.50014 .37481 Mdot
.45593 .42643 Mdot
.70078 .49824 Mdot
.59548 .6157 Mdot
.29298 .6759 Mdot
.72581 .51178 Mdot
.54835 .36408 Mdot
.619 .6395 Mdot
.69315 .50055 Mdot
.41324 .23188 Mdot
.6493 .78616 Mdot
.73241 .46764 Mdot
.53051 .39801 Mdot
.41379 .3537 Mdot
.64715 .29947 Mdot
.71294 .46036 Mdot
.4629 .65733 Mdot
.49998 .35564 Mdot
.80637 .57547 Mdot
.6889 .47462 Mdot
.57469 .22264 Mdot
.58614 .64417 Mdot
.614 .3072 Mdot
.46342 .38146 Mdot
.34652 .24114 Mdot
.68546 .47852 Mdot
.32584 .43422 Mdot
.29765 .42621 Mdot
.52537 .39892 Mdot
.69054 .46272 Mdot
.49198 .64425 Mdot
.56276 .63702 Mdot
.55545 .61615 Mdot
.35823 .45475 Mdot
.35902 .61126 Mdot
.62927 .62164 Mdot
.59604 .39959 Mdot
.64255 .63879 Mdot
.57887 .30053 Mdot
.35812 .2124 Mdot
.20585 .55628 Mdot
.5395 .43051 Mdot
.7206 .46482 Mdot
.41935 .64719 Mdot
.46492 .63782 Mdot
.45058 .64268 Mdot
.58974 .6512 Mdot
.45768 .53496 Mdot
.59052 .60141 Mdot
.26312 .55604 Mdot
.70512 .48439 Mdot
.70954 .35947 Mdot
.57175 .41674 Mdot
.53163 .34199 Mdot
.49115 .3487 Mdot
.54218 .416 Mdot
.52038 .36076 Mdot
.45052 .61551 Mdot
.57295 .652 Mdot
.75222 .60446 Mdot
.33128 .46876 Mdot
.35692 .72651 Mdot
.57209 .62736 Mdot
.29391 .64568 Mdot
.72318 .48204 Mdot
.70653 .29426 Mdot
.61921 .58632 Mdot
.57306 .62056 Mdot
.51349 .3334 Mdot
.31031 .43021 Mdot
.63439 .36324 Mdot
.5224 .35268 Mdot
.59477 .61457 Mdot
.61693 .65942 Mdot
.30512 .29247 Mdot
.59969 .34268 Mdot
.74681 .51054 Mdot
.45202 .55052 Mdot
.68346 .47628 Mdot
.49666 .43217 Mdot
.3446 .54296 Mdot
.58445 .6367 Mdot
.60234 .62333 Mdot
.72741 .46393 Mdot
.4418 .36103 Mdot
.357 .44117 Mdot
.31457 .67304 Mdot
.46235 .65459 Mdot
.52923 .34942 Mdot
.59729 .65097 Mdot
.52542 .28023 Mdot
.55406 .53086 Mdot
.44242 .63455 Mdot
.55981 .65431 Mdot
.49559 .35803 Mdot
.52503 .40315 Mdot
.70476 .49617 Mdot
.68225 .54406 Mdot
.46808 .39877 Mdot
.37223 .8029 Mdot
.38568 .55196 Mdot
.44956 .47193 Mdot
.50953 .38992 Mdot
.35418 .46462 Mdot
.31019 .66971 Mdot
.70835 .47235 Mdot
.487 .36172 Mdot
.62579 .80307 Mdot
.28362 .44771 Mdot
.45103 .61953 Mdot
.31043 .67074 Mdot
.46653 .53184 Mdot
.50498 .34698 Mdot
.50229 .36478 Mdot
.54525 .37621 Mdot
.64091 .80175 Mdot
.60415 .59594 Mdot
.29663 .43969 Mdot
.72945 .47574 Mdot
.30739 .47547 Mdot
.5854 .5972 Mdot
.51297 .50012 Mdot
.5507 .36222 Mdot
.37005 .43361 Mdot
.32852 .43208 Mdot
.43881 .6493 Mdot
.44448 .6122 Mdot
.56672 .59561 Mdot
.52957 .33894 Mdot
.30114 .67272 Mdot
.31856 .41992 Mdot
.58333 .65945 Mdot
.70463 .49455 Mdot
.4556 .6067 Mdot
.49716 .3996 Mdot
.59105 .63534 Mdot
.50227 .42099 Mdot
.30641 .46519 Mdot
.57297 .62191 Mdot
.29156 .64539 Mdot
.69951 .49898 Mdot
.49422 .39708 Mdot
.7833 .56053 Mdot
.31373 .67096 Mdot
.56041 .35357 Mdot
.42452 .36169 Mdot
.68067 .46308 Mdot
.21029 .53798 Mdot
.60861 .60256 Mdot
.29778 .66105 Mdot
.30219 .43439 Mdot
.62863 .41735 Mdot
.6072 .62657 Mdot
.37174 .38796 Mdot
.64541 .52738 Mdot
.52083 .41323 Mdot
.35071 .4535 Mdot
.68754 .51735 Mdot
.4046 .8214 Mdot
.65914 .31636 Mdot
.52183 .37126 Mdot
.62179 .63824 Mdot
.69592 .50358 Mdot
.44315 .6578 Mdot
.22104 .49773 Mdot
.35224 .22 Mdot
.55427 .6489 Mdot
.51949 .41816 Mdot
.31703 .42125 Mdot
.46895 .62451 Mdot
.20776 .59871 Mdot
.62205 .64973 Mdot
.61742 .60369 Mdot
.55253 .37059 Mdot
.72527 .47223 Mdot
.78834 .59798 Mdot
.60354 .59432 Mdot
.59177 .65407 Mdot
.34738 .7313 Mdot
.75263 .4846 Mdot
.53468 .3895 Mdot
.26217 .43345 Mdot
.49743 .34542 Mdot
.38335 .80078 Mdot
.29739 .66461 Mdot
.32752 .46875 Mdot
.49554 .37167 Mdot
.76152 .58929 Mdot
.61424 .62941 Mdot
.44145 .55122 Mdot
.50971 .60596 Mdot
.45862 .61091 Mdot
.59817 .64995 Mdot
.50639 .37454 Mdot
.45074 .6032 Mdot
.70307 .49992 Mdot
.54035 .34005 Mdot
.56807 .3743 Mdot
.38069 .45538 Mdot
.48532 .64271 Mdot
.53719 .25633 Mdot
.49402 .62366 Mdot
.43085 .65523 Mdot
.38105 .43442 Mdot
.52498 .39741 Mdot
.5883 .61651 Mdot
.63527 .62717 Mdot
.48594 .39133 Mdot
.351 .54078 Mdot
.35659 .4449 Mdot
.65778 .61371 Mdot
.70411 .76868 Mdot
.58114 .32755 Mdot
.29055 .67224 Mdot
.57916 .26413 Mdot
.43126 .64197 Mdot
.51446 .40777 Mdot
.31143 .45084 Mdot
.58475 .65618 Mdot
.63058 .62268 Mdot
.50841 .33255 Mdot
.47193 .62321 Mdot
.69256 .50368 Mdot
.62164 .61166 Mdot
.54675 .53248 Mdot
.54021 .36578 Mdot
.2552 .54268 Mdot
.61635 .60931 Mdot
.28588 .75144 Mdot
.75674 .596 Mdot
.345 .46574 Mdot
.56784 .40135 Mdot
.30839 .48094 Mdot
.73231 .47946 Mdot
.61196 .66887 Mdot
.47361 .62314 Mdot
.47816 .46243 Mdot
.74221 .29582 Mdot
.5766 .63458 Mdot
.32471 .4553 Mdot
.5082 .41048 Mdot
.50316 .46841 Mdot
.51653 .34364 Mdot
.64585 .37724 Mdot
.77704 .48646 Mdot
.4714 .60301 Mdot
.43695 .65303 Mdot
.56506 .41254 Mdot
.74648 .49101 Mdot
.6282 .60469 Mdot
.58943 .64365 Mdot
.38748 .15696 Mdot
.29486 .64182 Mdot
.77984 .43954 Mdot
.49953 .40512 Mdot
.57338 .65574 Mdot
.45887 .28726 Mdot
.47032 .66226 Mdot
.47666 .37975 Mdot
.55695 .64087 Mdot
.41094 .77753 Mdot
.46484 .55024 Mdot
.53213 .36867 Mdot
.55 .31797 Mdot
.4538 .65661 Mdot
.45114 .56543 Mdot
.58929 .60248 Mdot
.48069 .3661 Mdot
.50406 .62533 Mdot
.33416 .74443 Mdot
.71764 .27087 Mdot
.33126 .45031 Mdot
.62345 .65236 Mdot
.45668 .61187 Mdot
.54609 .30282 Mdot
.7141 .5067 Mdot
.6037 .654 Mdot
.55884 .62856 Mdot
.56379 .39126 Mdot
.58316 .38733 Mdot
.59074 .33581 Mdot
.33762 .46054 Mdot
.47225 .63938 Mdot
.57523 .40477 Mdot
.37068 .58929 Mdot
.53403 .41787 Mdot
.47346 .63602 Mdot
.10565 .43446 Mdot
.5305 .32881 Mdot
.50911 .35409 Mdot
.66147 .44879 Mdot
.36102 .43763 Mdot
.32014 .47827 Mdot
.36763 .57567 Mdot
.4988 .40433 Mdot
.62365 .54496 Mdot
.32734 .44942 Mdot
.35501 .44487 Mdot
.64668 .56052 Mdot
.55918 .38756 Mdot
.43351 .59079 Mdot
.46903 .62864 Mdot
.45511 .61091 Mdot
.30732 .47097 Mdot
.47615 .34341 Mdot
.42463 .65434 Mdot
.26071 .32292 Mdot
.56925 .62566 Mdot
.34387 .54307 Mdot
.30312 .45175 Mdot
.6269 .53238 Mdot
.48313 .62757 Mdot
.34341 .81424 Mdot
.62578 .44732 Mdot
.48841 .40686 Mdot
.52716 .40452 Mdot
.72083 .49917 Mdot
.51847 .45997 Mdot
.3075 .64308 Mdot
.45852 .6399 Mdot
.68713 .68493 Mdot
.33995 .4509 Mdot
.51208 .35051 Mdot
.67325 .27793 Mdot
.22166 .59818 Mdot
.24179 .50304 Mdot
.34493 .42826 Mdot
.34693 .44792 Mdot
.57537 .60837 Mdot
.56532 .63147 Mdot
.53599 .38118 Mdot
.45381 .64545 Mdot
.30818 .419 Mdot
.47381 .6452 Mdot
.58332 .63774 Mdot
.57642 .6207 Mdot
.29204 .66001 Mdot
.503 .32035 Mdot
.58172 .64604 Mdot
.35335 .74997 Mdot
.3738 .58465 Mdot
.37462 .47326 Mdot
.85692 .47389 Mdot
.20414 .59857 Mdot
.67969 .43973 Mdot
.71418 .51107 Mdot
.32054 .63504 Mdot
.48505 .62017 Mdot
.56156 .4143 Mdot
.49798 .38587 Mdot
.30988 .6498 Mdot
.4713 .61338 Mdot
.72668 .48722 Mdot
.48407 .62593 Mdot
.70783 .47494 Mdot
.59355 .59166 Mdot
.58098 .39083 Mdot
.51406 .34015 Mdot
.44161 .62601 Mdot
.58747 .60859 Mdot
.57047 .64281 Mdot
.72836 .5096 Mdot
.70982 .30223 Mdot
.5938 .63686 Mdot
.30272 .45264 Mdot
.47234 .24153 Mdot
.31422 .64886 Mdot
.50546 .36817 Mdot
.69153 .28262 Mdot
.31261 .27984 Mdot
.52129 .41485 Mdot
.31097 .67103 Mdot
.40853 .14796 Mdot
.57832 .37931 Mdot
.37032 .18324 Mdot
.2953 .65694 Mdot
.36548 .45336 Mdot
.60421 .60989 Mdot
.31313 .64384 Mdot
.52802 .30148 Mdot
.76077 .50982 Mdot
.57419 .42316 Mdot
.34234 .42389 Mdot
.3719 .44649 Mdot
.40043 .51072 Mdot
.38859 .80212 Mdot
.71495 .46801 Mdot
.7205 .4882 Mdot
.60705 .62896 Mdot
.39793 .68403 Mdot
.51142 .43362 Mdot
.72059 .49093 Mdot
.71472 .68101 Mdot
.55079 .41028 Mdot
.77653 .41087 Mdot
.64743 .49726 Mdot
.3564 .46179 Mdot
.3986 .46939 Mdot
.6111 .62869 Mdot
.32536 .45504 Mdot
.47469 .48975 Mdot
.49093 .3494 Mdot
.33578 .45192 Mdot
.47615 .63528 Mdot
.50557 .76378 Mdot
.33235 .48076 Mdot
.51895 .52624 Mdot
.46594 .62807 Mdot
.68068 .46428 Mdot
.68012 .38325 Mdot
.77875 .73193 Mdot
.45761 .64165 Mdot
.59848 .61171 Mdot
.57823 .64601 Mdot
.59834 .63865 Mdot
.33805 .4229 Mdot
.62288 .62416 Mdot
.32828 .46526 Mdot
.5896 .57994 Mdot
.7362 .32409 Mdot
.70774 .49236 Mdot
.42774 .68238 Mdot
.33572 .43638 Mdot
.29663 .57797 Mdot
.84085 .43525 Mdot
.53359 .39578 Mdot
.49775 .62223 Mdot
.71851 .46346 Mdot
.34366 .6651 Mdot
.72565 .49618 Mdot
.60009 .60942 Mdot
.34196 .54353 Mdot
.51549 .37691 Mdot
.30977 .3896 Mdot
.69261 .48729 Mdot
.34084 .42511 Mdot
.55304 .34762 Mdot
.55294 .60318 Mdot
.73025 .50058 Mdot
.71075 .50992 Mdot
.51768 .36107 Mdot
.35314 .46983 Mdot
.58088 .61734 Mdot
.4833 .61359 Mdot
.67329 .49943 Mdot
.49847 .31786 Mdot
.53186 .40698 Mdot
.48473 .34908 Mdot
.4203 .55057 Mdot
.79681 .59077 Mdot
.46077 .63298 Mdot
.64606 .28948 Mdot
.57346 .63932 Mdot
.65794 .32387 Mdot
.30039 .59964 Mdot
.45179 .68286 Mdot
.29649 .66376 Mdot
.29779 .66632 Mdot
.5275 .36637 Mdot
.78037 .62403 Mdot
.24591 .47665 Mdot
.49222 .65624 Mdot
.31788 .65567 Mdot
.56987 .64224 Mdot
.28818 .44596 Mdot
.41879 .44617 Mdot
.57239 .35765 Mdot
.44693 .61057 Mdot
.58845 .63982 Mdot
.68666 .73283 Mdot
.70716 .48417 Mdot
.34519 .57635 Mdot
.54817 .35864 Mdot
.51512 .36849 Mdot
.45464 .62601 Mdot
.46722 .63757 Mdot
.23541 .52199 Mdot
.40072 .52072 Mdot
.53485 .79441 Mdot
.42852 .59504 Mdot
.70918 .71928 Mdot
.31382 .40508 Mdot
.30929 .44693 Mdot
.29043 .65558 Mdot
.42407 .64983 Mdot
.50358 .36049 Mdot
.36621 .4502 Mdot
.24413 .50147 Mdot
.3856 .43753 Mdot
.76832 .40333 Mdot
.63413 .54326 Mdot
.54706 .35178 Mdot
.30695 .43422 Mdot
.32812 .45452 Mdot
.29917 .47062 Mdot
.31779 .66509 Mdot
.5096 .39344 Mdot
.53416 .40369 Mdot
.57649 .37705 Mdot
.48621 .45958 Mdot
.53746 .36413 Mdot
.30823 .605 Mdot
.35825 .63473 Mdot
.6849 .64556 Mdot
.51279 .41609 Mdot
.47046 .6159 Mdot
.5516 .42238 Mdot
.74404 .49575 Mdot
.51472 .41828 Mdot
.78666 .43209 Mdot
.44927 .63728 Mdot
.43818 .37783 Mdot
.64277 .65306 Mdot
.54975 .35885 Mdot
.68824 .49455 Mdot
.79412 .5957 Mdot
.66314 .2654 Mdot
.34864 .73483 Mdot
.30248 .45362 Mdot
.56735 .59767 Mdot
.48659 .65208 Mdot
.58924 .61759 Mdot
.48046 .38918 Mdot
.29157 .67098 Mdot
.18103 .59493 Mdot
.60854 .52302 Mdot
.50075 .36273 Mdot
.45957 .36371 Mdot
.342 .47074 Mdot
.61682 .62797 Mdot
.36671 .40862 Mdot
.54817 .37769 Mdot
.73482 .47943 Mdot
.73816 .47945 Mdot
.435 .47926 Mdot
.65501 .73035 Mdot
.63471 .39997 Mdot
.45615 .6274 Mdot
.63085 .62602 Mdot
.6858 .47876 Mdot
.2433 .45253 Mdot
.4897 .65086 Mdot
.43136 .64175 Mdot
.48391 .64373 Mdot
.54094 .34852 Mdot
.29384 .65098 Mdot
.68623 .70836 Mdot
.3226 .6558 Mdot
.5535 .3591 Mdot
.56049 .62304 Mdot
.31296 .64322 Mdot
.72534 .49893 Mdot
.42915 .65064 Mdot
.57071 .63546 Mdot
.52947 .35977 Mdot
.3295 .44552 Mdot
.65179 .27793 Mdot
.79774 .48978 Mdot
.64611 .58494 Mdot
.64404 .58205 Mdot
.35313 .42388 Mdot
.49121 .83692 Mdot
.48261 .67247 Mdot
.36071 .24536 Mdot
.71466 .52383 Mdot
.48596 .39285 Mdot
.51631 .16787 Mdot
.5939 .60176 Mdot
.61181 .64196 Mdot
.53578 .37087 Mdot
.6075 .65787 Mdot
.51329 .34793 Mdot
.58032 .60336 Mdot
.45241 .80905 Mdot
.56124 .34353 Mdot
.61301 .6403 Mdot
.50449 .43238 Mdot
.55766 .37296 Mdot
.34615 .46984 Mdot
.59829 .65576 Mdot
.49119 .41124 Mdot
.17128 .59207 Mdot
.43671 .64101 Mdot
.31945 .66194 Mdot
.40882 .67952 Mdot
.48768 .63366 Mdot
.34618 .45975 Mdot
.5799 .37849 Mdot
.70226 .4967 Mdot
.32588 .43761 Mdot
.54643 .61282 Mdot
.69236 .48109 Mdot
.35767 .58554 Mdot
.30358 .45842 Mdot
.30673 .64699 Mdot
.69762 .49493 Mdot
.57932 .41998 Mdot
.60001 .64601 Mdot
.81249 .5127 Mdot
.32209 .65588 Mdot
.51129 .38144 Mdot
.64018 .62941 Mdot
.48427 .62694 Mdot
.52973 .38354 Mdot
.62209 .63994 Mdot
.31549 .66838 Mdot
.56203 .3595 Mdot
.56014 .35449 Mdot
.42653 .44649 Mdot
.29261 .52409 Mdot
.70791 .49719 Mdot
.38053 .44015 Mdot
.53857 .38585 Mdot
.74725 .49115 Mdot
.5097 .70763 Mdot
.54449 .42696 Mdot
.31589 .48263 Mdot
.49748 .47329 Mdot
.5639 .6304 Mdot
.44737 .66068 Mdot
.63209 .6369 Mdot
.7067 .51 Mdot
.71097 .23442 Mdot
.29486 .64676 Mdot
.47597 .33809 Mdot
.48879 .35035 Mdot
.5793 .66623 Mdot
.33263 .45579 Mdot
.50651 .78828 Mdot
.49595 .40016 Mdot
.45698 .38472 Mdot
.51095 .36303 Mdot
.75219 .59742 Mdot
.35607 .44229 Mdot
.50742 .36517 Mdot
.44872 .38931 Mdot
.56788 .42746 Mdot
.68811 .49836 Mdot
.7023 .36827 Mdot
.54785 .42189 Mdot
.13003 .63489 Mdot
.30367 .6755 Mdot
.59419 .64369 Mdot
.5067 .55394 Mdot
.60698 .69769 Mdot
.36623 .20508 Mdot
.33272 .46338 Mdot
.61556 .34022 Mdot
.58433 .61723 Mdot
.64253 .24799 Mdot
.4536 .83905 Mdot
.5578 .36952 Mdot
.49471 .36086 Mdot
.60012 .60945 Mdot
.57829 .6572 Mdot
.29457 .67089 Mdot
.5014 .41495 Mdot
.46117 .36958 Mdot
.59974 .66231 Mdot
.53459 .35584 Mdot
.27031 .35507 Mdot
.48739 .6085 Mdot
.31344 .4756 Mdot
.44349 .65794 Mdot
.43331 .63435 Mdot
.455 .20963 Mdot
.38577 .55151 Mdot
.47147 .63667 Mdot
.47171 .67034 Mdot
.79128 .434 Mdot
.4866 .46982 Mdot
.68449 .48771 Mdot
.61438 .76066 Mdot
.60345 .63331 Mdot
.50937 .39519 Mdot
.32587 .42154 Mdot
.37788 .22042 Mdot
.462 .75503 Mdot
.33083 .5507 Mdot
.5357 .3989 Mdot
.61145 .6329 Mdot
.31882 .66618 Mdot
.56561 .34897 Mdot
.65224 .31676 Mdot
.51838 .37073 Mdot
.56354 .63937 Mdot
.47932 .20973 Mdot
.33892 .39071 Mdot
.4396 .58979 Mdot
.34018 .49232 Mdot
.57215 .41331 Mdot
.31018 .46293 Mdot
.46474 .61446 Mdot
.74633 .48382 Mdot
.71612 .49653 Mdot
.54235 .34352 Mdot
.38458 .51283 Mdot
.67506 .52081 Mdot
.55646 .37397 Mdot
.56266 .38902 Mdot
.29635 .6602 Mdot
.56271 .38775 Mdot
.48575 .35706 Mdot
.56531 .41534 Mdot
.51683 .42627 Mdot
.42981 .65461 Mdot
.41396 .38399 Mdot
.52856 .42336 Mdot
.57661 .32156 Mdot
.46051 .60398 Mdot
.57276 .30292 Mdot
.44733 .6517 Mdot
.59189 .79247 Mdot
.45874 .6528 Mdot
.71403 .49588 Mdot
.63396 .60764 Mdot
.60447 .31104 Mdot
.3106 .41805 Mdot
.4412 .61375 Mdot
.71396 .47789 Mdot
.45448 .64219 Mdot
.62051 .60254 Mdot
.84214 .48018 Mdot
.37334 .42462 Mdot
.46252 .55588 Mdot
.63887 .45878 Mdot
.25317 .54079 Mdot
.56683 .62322 Mdot
.35705 .45561 Mdot
.30091 .39461 Mdot
.56918 .40988 Mdot
.70647 .50122 Mdot
.52568 .36654 Mdot
.43236 .65509 Mdot
.60765 .63438 Mdot
.61397 .56879 Mdot
.7091 .49832 Mdot
.77788 .31763 Mdot
.55705 .62044 Mdot
.56531 .33361 Mdot
.45911 .60314 Mdot
.85275 .46436 Mdot
.45552 .65417 Mdot
.73181 .31682 Mdot
.28135 .47312 Mdot
.49862 .20815 Mdot
.34517 .44243 Mdot
.22964 .48485 Mdot
.55226 .85025 Mdot
.45677 .83125 Mdot
.32024 .44197 Mdot
.65824 .61987 Mdot
.54258 .35757 Mdot
.54245 .41763 Mdot
.59897 .37262 Mdot
.37682 .47398 Mdot
.54166 .37964 Mdot
.30789 .6441 Mdot
.39162 .554 Mdot
.75373 .63476 Mdot
.5835 .58929 Mdot
.51232 .34714 Mdot
.43891 .61934 Mdot
.45349 .66703 Mdot
.31806 .64652 Mdot
.49215 .63126 Mdot
.55698 .38033 Mdot
.3388 .43747 Mdot
.62181 .51752 Mdot
.73444 .48737 Mdot
.27271 .71022 Mdot
.68256 .50822 Mdot
.59644 .58309 Mdot
.59194 .35 Mdot
.57567 .6208 Mdot
.60449 .16931 Mdot
.55466 .41572 Mdot
.32464 .45037 Mdot
.55224 .34944 Mdot
.56863 .41394 Mdot
.52743 .4207 Mdot
.62639 .63537 Mdot
.50628 .55893 Mdot
.53197 .35502 Mdot
.47665 .62481 Mdot
.65825 .58091 Mdot
.58173 .37259 Mdot
.64348 .7065 Mdot
.75562 .39961 Mdot
.26681 .55388 Mdot
.36459 .48197 Mdot
.60575 .61695 Mdot
.34274 .44946 Mdot
.37757 .47745 Mdot
.34604 .45993 Mdot
.67831 .69654 Mdot
.6223 .31909 Mdot
.3381 .20057 Mdot
.4528 .27666 Mdot
.38326 .22509 Mdot
.36427 .42783 Mdot
.53338 .72042 Mdot
.31154 .44776 Mdot
.33856 .4629 Mdot
.19413 .29633 Mdot
.314 .43566 Mdot
.50013 .37671 Mdot
.53969 .32713 Mdot
.25311 .62309 Mdot
.7886 .41813 Mdot
.51471 .41754 Mdot
.53918 .38088 Mdot
.72526 .46868 Mdot
.45011 .42003 Mdot
.32542 .65113 Mdot
.35458 .56209 Mdot
.33218 .665 Mdot
.51856 .36138 Mdot
.53942 .37352 Mdot
.47047 .36744 Mdot
.55406 .85439 Mdot
.36972 .21846 Mdot
.36983 .44244 Mdot
.51258 .29742 Mdot
.34047 .76628 Mdot
.51524 .33529 Mdot
.52852 .33391 Mdot
.57037 .3753 Mdot
.58678 .61661 Mdot
.28744 .44235 Mdot
.45988 .39861 Mdot
.2547 .57543 Mdot
.54807 .36218 Mdot
.50673 .65536 Mdot
.67721 .46085 Mdot
.50547 .3751 Mdot
.30553 .4758 Mdot
.5423 .41102 Mdot
.30296 .44387 Mdot
.31094 .47335 Mdot
.48875 .32816 Mdot
.67792 .71526 Mdot
.28932 .467 Mdot
.55857 .36072 Mdot
.58986 .61037 Mdot
.40766 .82049 Mdot
.50962 .38119 Mdot
.71862 .46972 Mdot
.51609 .40899 Mdot
.69052 .50052 Mdot
.56593 .37854 Mdot
.32246 .66037 Mdot
.34232 .28482 Mdot
.60301 .62473 Mdot
.67626 .50557 Mdot
.58823 .66133 Mdot
.45423 .46178 Mdot
.35516 .47219 Mdot
.32706 .655 Mdot
.31983 .23865 Mdot
.29643 .6586 Mdot
.63579 .27381 Mdot
.44323 .73537 Mdot
.4374 .62863 Mdot
.29665 .45353 Mdot
.60402 .27446 Mdot
.633 .71895 Mdot
.54392 .63821 Mdot
.54597 .63271 Mdot
.64828 .20228 Mdot
.47301 .14793 Mdot
.52785 .35253 Mdot
.82416 .5505 Mdot
.34829 .32512 Mdot
.54283 .43468 Mdot
.53631 .44391 Mdot
.55804 .63401 Mdot
.57449 .41181 Mdot
.50793 .51785 Mdot
.58382 .63261 Mdot
.71622 .48172 Mdot
.32447 .4684 Mdot
.70835 .50762 Mdot
.55271 .78102 Mdot
.36965 .60302 Mdot
.57725 .63957 Mdot
.52959 .42733 Mdot
.52924 .34625 Mdot
.29976 .44172 Mdot
.26597 .40322 Mdot
.3215 .47664 Mdot
.70219 .46944 Mdot
.59216 .62751 Mdot
.346 .23815 Mdot
.50879 .40659 Mdot
.33108 .43074 Mdot
.58984 .67319 Mdot
.52446 .40376 Mdot
.44504 .62134 Mdot
.53641 .39967 Mdot
.31935 .43488 Mdot
.56315 .38703 Mdot
.34025 .43941 Mdot
.58758 .60498 Mdot
.49912 .34905 Mdot
.53746 .37535 Mdot
.61961 .25511 Mdot
.72753 .48686 Mdot
.36103 .46652 Mdot
.50131 .51706 Mdot
.50087 .34341 Mdot
.65243 .32165 Mdot
.5804 .3859 Mdot
.61377 .3767 Mdot
.48695 .42475 Mdot
.30518 .64482 Mdot
.47542 .38371 Mdot
.51024 .38 Mdot
.38115 .38349 Mdot
.4334 .31679 Mdot
.40928 .45563 Mdot
.43466 .61693 Mdot
.30673 .47606 Mdot
.58295 .64867 Mdot
.57882 .65359 Mdot
.6214 .61671 Mdot
.7804 .39148 Mdot
.49576 .31824 Mdot
.51604 .37891 Mdot
.4705 .6023 Mdot
.71795 .48914 Mdot
.33739 .42607 Mdot
.71217 .49088 Mdot
.35563 .55853 Mdot
.69391 .4757 Mdot
.30355 .64321 Mdot
.75774 .59551 Mdot
.2595 .33783 Mdot
.708 .47104 Mdot
.31972 .47663 Mdot
.62474 .54123 Mdot
.48729 .39812 Mdot
.38495 .76927 Mdot
.73431 .47841 Mdot
.68219 .22828 Mdot
.55953 .34787 Mdot
.50577 .52391 Mdot
.44215 .64771 Mdot
.70257 .50497 Mdot
.4852 .64439 Mdot
.54483 .4131 Mdot
.20994 .53322 Mdot
.32064 .45384 Mdot
.48911 .60511 Mdot
.48285 .40364 Mdot
.70685 .50702 Mdot
.57998 .64312 Mdot
.59227 .4686 Mdot
.46318 .60988 Mdot
.65294 .2673 Mdot
.65895 .31634 Mdot
.58986 .62821 Mdot
.22222 .35336 Mdot
.47253 .65603 Mdot
.53312 .43025 Mdot
.62676 .36205 Mdot
.54179 .4063 Mdot
.57687 .64909 Mdot
.6191 .63603 Mdot
.2775 .633 Mdot
.54424 .34642 Mdot
.565 .35378 Mdot
.29862 .41881 Mdot
.57588 .63262 Mdot
.35311 .45497 Mdot
.29582 .43855 Mdot
.59675 .60917 Mdot
.34732 .46442 Mdot
.69272 .48897 Mdot
.39623 .54595 Mdot
.47118 .65583 Mdot
.46151 .61701 Mdot
.58009 .64531 Mdot
.61848 .59903 Mdot
.57418 .62273 Mdot
.53938 .39674 Mdot
.35974 .44082 Mdot
.56306 .40278 Mdot
.54596 .4226 Mdot
.27383 .46566 Mdot
.34843 .42423 Mdot
.55725 .40777 Mdot
.65276 .54212 Mdot
.7426 .50759 Mdot
.61403 .63903 Mdot
.47401 .64334 Mdot
.60958 .24241 Mdot
.48797 .60694 Mdot
.53347 .33654 Mdot
.40778 .77826 Mdot
.34075 .42431 Mdot
.72451 .49737 Mdot
.70942 .45459 Mdot
.71362 .50023 Mdot
.48907 .60488 Mdot
.29362 .44849 Mdot
.35942 .58632 Mdot
.52787 .33818 Mdot
.41919 .55013 Mdot
.63101 .28259 Mdot
.28819 .59424 Mdot
.47425 .63684 Mdot
.5337 .39351 Mdot
.29647 .65577 Mdot
.2964 .30007 Mdot
.52155 .37495 Mdot
.47751 .38395 Mdot
.71915 .57078 Mdot
.57783 .32302 Mdot
.37898 .46297 Mdot
.41068 .49538 Mdot
.4884 .36061 Mdot
.41469 .4521 Mdot
.31725 .18437 Mdot
.55913 .34839 Mdot
.54494 .3704 Mdot
.50208 .39093 Mdot
.56173 .41282 Mdot
.3314 .48677 Mdot
.71318 .55094 Mdot
.43861 .61757 Mdot
.40334 .54501 Mdot
.47928 .64847 Mdot
.60672 .64611 Mdot
.52208 .51617 Mdot
.29812 .46215 Mdot
.71519 .5006 Mdot
.84435 .51048 Mdot
.36695 .54419 Mdot
.57444 .60941 Mdot
.40729 .19723 Mdot
.73608 .48582 Mdot
.48722 .39568 Mdot
.73233 .51052 Mdot
.56746 .65328 Mdot
.47231 .62565 Mdot
.52009 .33141 Mdot
.33086 .41899 Mdot
.32823 .48131 Mdot
.53672 .39146 Mdot
.35833 .79146 Mdot
.48673 .63196 Mdot
.52611 .66858 Mdot
.54344 .34954 Mdot
.47761 .38304 Mdot
.32387 .47362 Mdot
.61602 .63013 Mdot
.42677 .72078 Mdot
.72327 .48009 Mdot
.491 .41841 Mdot
.54213 .41303 Mdot
.36865 .55524 Mdot
.42337 .64369 Mdot
.31117 .66373 Mdot
.54442 .34848 Mdot
.38282 .55454 Mdot
.54953 .35018 Mdot
.47974 .44589 Mdot
.57987 .6143 Mdot
.54717 .3249 Mdot
.4898 .37249 Mdot
.5222 .27475 Mdot
.472 .65809 Mdot
.33056 .4525 Mdot
.27665 .45461 Mdot
.30621 .67215 Mdot
.44141 .62945 Mdot
.55254 .4076 Mdot
.43903 .65876 Mdot
.53319 .41993 Mdot
.53213 .35808 Mdot
.47474 .63633 Mdot
.35308 .45625 Mdot
.50571 .7827 Mdot
.4042 .39195 Mdot
.57419 .39158 Mdot
.52317 .41132 Mdot
.7816 .40274 Mdot
.25443 .30631 Mdot
.48997 .38402 Mdot
.35479 .43208 Mdot
.52467 .402 Mdot
.45597 .61483 Mdot
.6981 .47171 Mdot
.32452 .44624 Mdot
.60855 .59346 Mdot
.59324 .60338 Mdot
.6407 .6569 Mdot
.29852 .64467 Mdot
.49342 .40177 Mdot
.37882 .42773 Mdot
.346 .4217 Mdot
.31061 .6923 Mdot
.59542 .64421 Mdot
.68683 .48382 Mdot
.57064 .36872 Mdot
.60011 .46278 Mdot
.4324 .62917 Mdot
.13368 .6395 Mdot
.35961 .59378 Mdot
.69033 .50767 Mdot
.33571 .52402 Mdot
.29998 .6514 Mdot
.49998 .36023 Mdot
.74261 .49875 Mdot
.6125 .60362 Mdot
.5444 .41641 Mdot
.54882 .30904 Mdot
.61928 .72314 Mdot
.58248 .59148 Mdot
.44371 .66037 Mdot
.60816 .5981 Mdot
.70099 .51085 Mdot
.30537 .64303 Mdot
.34659 .47283 Mdot
.51066 .37482 Mdot
.53637 .28771 Mdot
.60108 .63997 Mdot
.32022 .66756 Mdot
.54875 .3524 Mdot
.31644 .48101 Mdot
.62172 .62925 Mdot
.51598 .35802 Mdot
.34403 .25489 Mdot
.27002 .46786 Mdot
.59851 .63104 Mdot
.4896 .34721 Mdot
.47235 .46646 Mdot
.5866 .59549 Mdot
.55691 .63084 Mdot
.54155 .37919 Mdot
.69601 .49397 Mdot
.5017 .35019 Mdot
.4524 .65043 Mdot
.50657 .5589 Mdot
.44683 .62276 Mdot
.64495 .29417 Mdot
.51575 .3239 Mdot
.24989 .51972 Mdot
.31023 .42781 Mdot
.73973 .46449 Mdot
.38421 .37695 Mdot
.47936 .37823 Mdot
.56311 .80812 Mdot
.6217 .53167 Mdot
.33311 .6895 Mdot
.68485 .76827 Mdot
.71622 .47347 Mdot
.45021 .64292 Mdot
.5451 .37162 Mdot
.41781 .66126 Mdot
.70153 .47725 Mdot
.64232 .28976 Mdot
.48802 .35035 Mdot
.35488 .4428 Mdot
.54548 .35805 Mdot
.30238 .45225 Mdot
.52088 .40623 Mdot
.51207 .30596 Mdot
.7432 .51291 Mdot
.72833 .31237 Mdot
.49058 .40267 Mdot
.84973 .503 Mdot
.56174 .49056 Mdot
.72988 .47665 Mdot
.57079 .38823 Mdot
.31046 .65498 Mdot
.48284 .62411 Mdot
.80356 .55561 Mdot
.5802 .61863 Mdot
.46674 .64195 Mdot
.32774 .47138 Mdot
.63631 .63443 Mdot
.30786 .67364 Mdot
.61812 .31921 Mdot
.71407 .50876 Mdot
.4375 .63732 Mdot
.50839 .37815 Mdot
.53522 .33591 Mdot
.76058 .5881 Mdot
.18522 .41317 Mdot
.29863 .42306 Mdot
.75096 .29845 Mdot
.378 .45002 Mdot
.72368 .48873 Mdot
.57704 .61628 Mdot
.49604 .37248 Mdot
.52801 .37573 Mdot
.59126 .65232 Mdot
.36283 .43965 Mdot
.64176 .63834 Mdot
.44132 .20297 Mdot
.5144 .6126 Mdot
.72199 .34255 Mdot
.31972 .44634 Mdot
.72184 .33767 Mdot
.69011 .50577 Mdot
.67111 .73628 Mdot
.69959 .42084 Mdot
.43408 .64125 Mdot
.72132 .34722 Mdot
.33266 .42532 Mdot
.52432 .35167 Mdot
.30883 .64782 Mdot
.29304 .66361 Mdot
.31392 .46759 Mdot
.60235 .61163 Mdot
.7127 .50663 Mdot
.54252 .36594 Mdot
.30791 .57444 Mdot
.22008 .61682 Mdot
.63087 .6281 Mdot
.45177 .40063 Mdot
.48617 .63646 Mdot
.52635 .4071 Mdot
.73202 .47178 Mdot
.46351 .63612 Mdot
.29176 .64367 Mdot
.39889 .54032 Mdot
.57116 .36876 Mdot
.4377 .47322 Mdot
.44021 .63655 Mdot
.23286 .32359 Mdot
.53498 .37647 Mdot
.4726 .65615 Mdot
.60757 .35395 Mdot
.21762 .54847 Mdot
.64136 .50637 Mdot
.4771 .83377 Mdot
.5536 .61258 Mdot
.59837 .60339 Mdot
.17057 .51967 Mdot
.7192 .52351 Mdot
.44647 .61278 Mdot
.30978 .64314 Mdot
.70017 .39039 Mdot
.48102 .65231 Mdot
.53611 .3322 Mdot
.57926 .38043 Mdot
.4424 .20966 Mdot
.5502 .50003 Mdot
.31355 .67593 Mdot
.60763 .42187 Mdot
.55407 .39199 Mdot
.58856 .40697 Mdot
.52873 .38874 Mdot
.37166 .44599 Mdot
.48148 .65429 Mdot
.86567 .5395 Mdot
.46798 .66441 Mdot
.31862 .57436 Mdot
.6039 .63338 Mdot
.62975 .63549 Mdot
.50589 .37341 Mdot
.24906 .4927 Mdot
.79817 .59966 Mdot
.51237 .41153 Mdot
.68956 .45787 Mdot
.6589 .31153 Mdot
.58429 .3788 Mdot
.28316 .44057 Mdot
.45644 .39497 Mdot
.36268 .47406 Mdot
.46689 .6334 Mdot
.71389 .47318 Mdot
.7552 .49791 Mdot
.44587 .6455 Mdot
.51743 .38173 Mdot
.72296 .4522 Mdot
.51311 .36718 Mdot
.53135 .34862 Mdot
.34682 .56563 Mdot
.70184 .46325 Mdot
.57215 .62423 Mdot
.7141 .49742 Mdot
.33947 .46128 Mdot
.14379 .35657 Mdot
.70519 .48773 Mdot
.4986 .47659 Mdot
.54339 .52563 Mdot
.71952 .34327 Mdot
.32953 .48064 Mdot
.71175 .46729 Mdot
.45866 .66295 Mdot
.32003 .6969 Mdot
.23593 .33686 Mdot
.49447 .61756 Mdot
.53114 .37323 Mdot
.29815 .45638 Mdot
.35784 .42706 Mdot
.49452 .64484 Mdot
.35715 .46199 Mdot
.58795 .35564 Mdot
.55706 .35356 Mdot
.44593 .61333 Mdot
.24621 .63395 Mdot
.48071 .65564 Mdot
.57709 .47356 Mdot
.56693 .37007 Mdot
.32485 .44834 Mdot
.5761 .44032 Mdot
.32306 .40625 Mdot
.29132 .66358 Mdot
.52126 .42088 Mdot
.71434 .50295 Mdot
.45878 .53512 Mdot
.60023 .63049 Mdot
.41431 .78033 Mdot
.30159 .45787 Mdot
.47178 .59299 Mdot
.34423 .47108 Mdot
.32427 .41533 Mdot
.49321 .63651 Mdot
.32989 .45952 Mdot
.54448 .36875 Mdot
.44931 .5687 Mdot
.30563 .44804 Mdot
.45149 .62865 Mdot
.71996 .50433 Mdot
.35081 .46129 Mdot
.63182 .65328 Mdot
.52295 .34821 Mdot
.56378 .62602 Mdot
.68689 .46755 Mdot
.2974 .46014 Mdot
.70827 .46822 Mdot
.59933 .64214 Mdot
.723 .50734 Mdot
.58524 .57854 Mdot
.41579 .63566 Mdot
.32496 .55415 Mdot
.37858 .39823 Mdot
.32353 .42072 Mdot
.54147 .63433 Mdot
.49228 .37431 Mdot
.53598 .34385 Mdot
.71692 .51224 Mdot
.35461 .4241 Mdot
.40265 .81624 Mdot
.61407 .38849 Mdot
.28683 .63231 Mdot
.4209 .64339 Mdot
.69156 .25796 Mdot
.35879 .61085 Mdot
.3297 .70394 Mdot
.51437 .44064 Mdot
.30089 .65057 Mdot
.51008 .36305 Mdot
.66371 .26502 Mdot
.69662 .47143 Mdot
.50409 .74339 Mdot
.51392 .4341 Mdot
.58055 .62586 Mdot
.51244 .40437 Mdot
.82185 .54923 Mdot
.48007 .43259 Mdot
.72096 .46799 Mdot
.44437 .60578 Mdot
.3102 .41818 Mdot
.73484 .48611 Mdot
.58715 .60356 Mdot
.72645 .38453 Mdot
.49563 .34049 Mdot
.55418 .38663 Mdot
.54649 .63969 Mdot
.35709 .44857 Mdot
.60396 .64618 Mdot
.47184 .65554 Mdot
.70851 .48808 Mdot
.56704 .40915 Mdot
.58415 .36018 Mdot
.56952 .66127 Mdot
.45621 .66631 Mdot
.63101 .61309 Mdot
.43395 .6533 Mdot
.30187 .64941 Mdot
.49407 .40466 Mdot
.557 .65042 Mdot
.55794 .43588 Mdot
.45914 .29203 Mdot
.34549 .55566 Mdot
.39223 .35865 Mdot
.57084 .62533 Mdot
.75175 .38212 Mdot
.44628 .63791 Mdot
.44213 .65464 Mdot
.5142 .22047 Mdot
.78835 .61087 Mdot
.62417 .54454 Mdot
.83738 .47952 Mdot
.47143 .65536 Mdot
.44582 .62782 Mdot
.6137 .60592 Mdot
.3265 .46367 Mdot
.29635 .48471 Mdot
.61265 .66008 Mdot
.69114 .28289 Mdot
.33695 .42612 Mdot
.5411 .81952 Mdot
.56518 .60846 Mdot
.48874 .42506 Mdot
.31477 .67791 Mdot
.72939 .47283 Mdot
.66863 .27638 Mdot
.83173 .49947 Mdot
.49986 .36833 Mdot
.41653 .17205 Mdot
.60334 .61817 Mdot
.41808 .592 Mdot
.62844 .76206 Mdot
.47905 .36358 Mdot
.50925 .40001 Mdot
.51965 .38722 Mdot
.7222 .46171 Mdot
.40602 .37688 Mdot
.5003 .36573 Mdot
.73727 .32924 Mdot
.54985 .33161 Mdot
.80699 .52439 Mdot
.71376 .4971 Mdot
.64102 .34957 Mdot
.54956 .61496 Mdot
.26934 .57778 Mdot
.59849 .37847 Mdot
.46337 .6581 Mdot
.5882 .75408 Mdot
.47689 .63002 Mdot
.72834 .69034 Mdot
.69787 .41904 Mdot
.37257 .4432 Mdot
.53638 .39836 Mdot
.54838 .63366 Mdot
.29895 .45195 Mdot
.43906 .73077 Mdot
.19019 .29694 Mdot
.43204 .65852 Mdot
.50966 .12897 Mdot
.43938 .65356 Mdot
.29362 .66747 Mdot
.31862 .47159 Mdot
.35288 .50621 Mdot
.42244 .54858 Mdot
.35169 .45639 Mdot
.64259 .67943 Mdot
.27871 .44831 Mdot
.73744 .36295 Mdot
.33412 .41196 Mdot
.45198 .63321 Mdot
.43776 .60603 Mdot
.5805 .31524 Mdot
.49089 .38351 Mdot
.39501 .55603 Mdot
.60407 .39378 Mdot
.49913 .40505 Mdot
.58376 .63249 Mdot
.23233 .44798 Mdot
.45641 .58401 Mdot
.31084 .45248 Mdot
.42834 .63341 Mdot
.50929 .40129 Mdot
.57373 .39099 Mdot
.54993 .43259 Mdot
.64641 .25882 Mdot
.54345 .81671 Mdot
.5303 .3557 Mdot
.48221 .338 Mdot
.58043 .60787 Mdot
.778 .56673 Mdot
.80479 .39104 Mdot
.70471 .39984 Mdot
.54104 .34166 Mdot
.72625 .49137 Mdot
.70568 .46514 Mdot
.57687 .34063 Mdot
.27569 .54707 Mdot
.65168 .61285 Mdot
.50835 .37853 Mdot
.72331 .43219 Mdot
.61036 .6677 Mdot
.3233 .6595 Mdot
.60007 .64023 Mdot
.29918 .46932 Mdot
.29512 .66231 Mdot
.6245 .63633 Mdot
.27081 .48314 Mdot
.30572 .67139 Mdot
.2261 .56016 Mdot
.70271 .46913 Mdot
.52931 .38373 Mdot
.35065 .40366 Mdot
.58866 .65159 Mdot
.43795 .64056 Mdot
.33449 .44089 Mdot
.4194 .65083 Mdot
.77925 .56827 Mdot
.67369 .28924 Mdot
.2951 .64692 Mdot
.46061 .65679 Mdot
.41525 .51251 Mdot
.72361 .49373 Mdot
.4938 .63145 Mdot
.24304 .49358 Mdot
.58256 .3799 Mdot
.76382 .66939 Mdot
.54994 .38643 Mdot
.3194 .76269 Mdot
.44313 .65394 Mdot
.28883 .65749 Mdot
.51241 .37372 Mdot
.5589 .61755 Mdot
.58413 .31164 Mdot
.51503 .36639 Mdot
.60546 .59567 Mdot
.52679 .35286 Mdot
.73879 .47539 Mdot
.35441 .48268 Mdot
.6224 .52886 Mdot
.64507 .2312 Mdot
.73092 .50342 Mdot
.2902 .63821 Mdot
.49327 .39752 Mdot
.67916 .5859 Mdot
.3515 .4513 Mdot
.47675 .37549 Mdot
.49024 .19192 Mdot
.31659 .46382 Mdot
.3444 .44873 Mdot
.56298 .39357 Mdot
.49276 .61332 Mdot
.57069 .64185 Mdot
.72166 .49573 Mdot
.40208 .69513 Mdot
.51464 .35695 Mdot
.53393 .39061 Mdot
.73592 .48679 Mdot
.44575 .62569 Mdot
.56648 .40788 Mdot
.42019 .74581 Mdot
.34759 .65257 Mdot
.4334 .63289 Mdot
.58313 .37992 Mdot
.77752 .67803 Mdot
.31444 .49384 Mdot
.38945 .17586 Mdot
.70527 .52282 Mdot
.5964 .61167 Mdot
.46946 .34419 Mdot
.11256 .60151 Mdot
.72647 .47259 Mdot
.28859 .58862 Mdot
.53558 .35335 Mdot
.49795 .39688 Mdot
.35443 .47057 Mdot
.55694 .4045 Mdot
.31705 .43472 Mdot
.64763 .22826 Mdot
.86523 .44841 Mdot
.34533 .46938 Mdot
.31011 .44052 Mdot
.38677 .48234 Mdot
.63958 .26329 Mdot
.32692 .46946 Mdot
.49128 .34334 Mdot
.67278 .66038 Mdot
.52547 .31231 Mdot
.68084 .49741 Mdot
.74626 .46721 Mdot
.29409 .41755 Mdot
.2095 .40931 Mdot
.58606 .30566 Mdot
.42856 .41773 Mdot
.66985 .51555 Mdot
.46272 .65057 Mdot
.57811 .38631 Mdot
.30079 .6434 Mdot
.625 .62124 Mdot
.46621 .42337 Mdot
.52706 .38178 Mdot
.30321 .44629 Mdot
.72581 .46181 Mdot
.49064 .63707 Mdot
.53921 .37953 Mdot
.63085 .5973 Mdot
.71889 .48046 Mdot
.30691 .44718 Mdot
.50614 .48014 Mdot
.68407 .49117 Mdot
.58905 .37435 Mdot
.49942 .40406 Mdot
.54947 .35235 Mdot
.60018 .37403 Mdot
.44432 .64613 Mdot
.6268 .64953 Mdot
.5496 .32197 Mdot
.36034 .56522 Mdot
.47776 .54103 Mdot
.55366 .32481 Mdot
.36019 .43936 Mdot
.44412 .61248 Mdot
.30644 .66863 Mdot
.7093 .35982 Mdot
.56291 .356 Mdot
.55303 .8113 Mdot
.4007 .20473 Mdot
.30117 .66351 Mdot
.37655 .43516 Mdot
.71969 .4991 Mdot
.55945 .38387 Mdot
.67381 .61151 Mdot
.5485 .34032 Mdot
.52438 .47377 Mdot
.59894 .61444 Mdot
.46909 .64859 Mdot
.34336 .65959 Mdot
.6254 .62128 Mdot
.34331 .44928 Mdot
.38069 .82319 Mdot
.28338 .46734 Mdot
.29524 .43183 Mdot
.68674 .7133 Mdot
.4698 .63373 Mdot
.12373 .62229 Mdot
.25109 .30799 Mdot
.55114 .34007 Mdot
.46711 .61647 Mdot
.31251 .47073 Mdot
.54198 .39294 Mdot
.32765 .42188 Mdot
.28818 .45237 Mdot
.55327 .42257 Mdot
.49458 .39379 Mdot
.71726 .30394 Mdot
.53801 .83151 Mdot
.70522 .49982 Mdot
.36543 .45266 Mdot
.41347 .21906 Mdot
.49949 .36471 Mdot
.52667 .33846 Mdot
.61032 .73468 Mdot
.71785 .46804 Mdot
.28221 .34542 Mdot
.5397 .34747 Mdot
.50012 .19402 Mdot
.50256 .41035 Mdot
.39609 .4311 Mdot
.49748 .61506 Mdot
.28112 .55501 Mdot
.57431 .64761 Mdot
.304 .48012 Mdot
.69274 .50165 Mdot
.30861 .48457 Mdot
.49654 .21567 Mdot
.47028 .63044 Mdot
.31939 .43478 Mdot
.6355 .6149 Mdot
.46165 .62329 Mdot
.43367 .643 Mdot
.65643 .58053 Mdot
.63519 .63412 Mdot
.73351 .46678 Mdot
.48112 .63175 Mdot
.36674 .24198 Mdot
.45551 .63338 Mdot
.42896 .21685 Mdot
.49216 .35752 Mdot
.72785 .3238 Mdot
.34613 .61254 Mdot
.59629 .3469 Mdot
.48529 .64892 Mdot
.69888 .48836 Mdot
.5462 .40616 Mdot
.35895 .45973 Mdot
.70421 .48396 Mdot
.47217 .67214 Mdot
.62366 .60076 Mdot
.33367 .41497 Mdot
.46468 .60288 Mdot
.32088 .42997 Mdot
.66181 .28959 Mdot
.58764 .58267 Mdot
.65225 .4877 Mdot
.43471 .54884 Mdot
.53523 .4315 Mdot
.4147 .44964 Mdot
.50026 .34252 Mdot
.52428 .3782 Mdot
.59893 .63164 Mdot
.7788 .38929 Mdot
.35272 .4598 Mdot
.24631 .68551 Mdot
.45369 .657 Mdot
.40638 .49948 Mdot
.56742 .46491 Mdot
.53265 .41869 Mdot
.30686 .45245 Mdot
.28893 .4463 Mdot
.4326 .31766 Mdot
.59428 .65246 Mdot
.55655 .31924 Mdot
.58837 .34154 Mdot
.49352 .31872 Mdot
.43699 .6517 Mdot
.44269 .75582 Mdot
.61867 .6457 Mdot
.42621 .13636 Mdot
.6151 .63854 Mdot
.69216 .56942 Mdot
.3286 .45964 Mdot
.68938 .48178 Mdot
.52219 .33992 Mdot
.42095 .38542 Mdot
.34191 .48436 Mdot
.65515 .62721 Mdot
.7233 .49958 Mdot
.47911 .77165 Mdot
.46902 .63801 Mdot
.48831 .35674 Mdot
.56422 .41908 Mdot
.56702 .39851 Mdot
.55388 .37067 Mdot
.43047 .62444 Mdot
.53517 .33241 Mdot
.42232 .63038 Mdot
.31766 .27401 Mdot
.50646 .19891 Mdot
.55323 .63376 Mdot
.79881 .53512 Mdot
.33448 .41785 Mdot
.40594 .23496 Mdot
.27126 .34928 Mdot
.34283 .55709 Mdot
.60899 .57101 Mdot
.48754 .36974 Mdot
.60424 .61146 Mdot
.8237 .55387 Mdot
.55102 .63731 Mdot
.88323 .4454 Mdot
.61715 .29828 Mdot
.46339 .83849 Mdot
.54539 .38851 Mdot
.61504 .66005 Mdot
.26419 .38023 Mdot
.57877 .35154 Mdot
.74635 .46249 Mdot
.56719 .47155 Mdot
.25569 .61276 Mdot
.68615 .48453 Mdot
.52045 .34972 Mdot
.31647 .41402 Mdot
.54473 .36742 Mdot
.51791 .34363 Mdot
.51252 .41056 Mdot
.4703 .66796 Mdot
.58177 .40036 Mdot
.50271 .34948 Mdot
.1879 .39677 Mdot
.7728 .40739 Mdot
.57016 .6109 Mdot
.41285 .33371 Mdot
.71776 .48879 Mdot
.30074 .44673 Mdot
.60224 .52772 Mdot
.4566 .64853 Mdot
.4424 .30508 Mdot
.54717 .38789 Mdot
.31406 .61446 Mdot
.48225 .60422 Mdot
.7058 .47753 Mdot
.30989 .67062 Mdot
.56046 .79149 Mdot
.56458 .64509 Mdot
.29635 .67313 Mdot
.60113 .62974 Mdot
.3146 .37442 Mdot
.30364 .44842 Mdot
.54693 .43093 Mdot
.48483 .64076 Mdot
.55865 .63097 Mdot
.79465 .4225 Mdot
.52292 .39424 Mdot
.5699 .62709 Mdot
.53609 .43084 Mdot
.48013 .54654 Mdot
.54729 .52931 Mdot
.57479 .658 Mdot
.44046 .60489 Mdot
.45991 .62035 Mdot
.69163 .48605 Mdot
.30104 .44298 Mdot
.34856 .42824 Mdot
.46361 .63249 Mdot
.43756 .15082 Mdot
.51266 .35798 Mdot
.50357 .40857 Mdot
.36055 .57163 Mdot
.54536 .38332 Mdot
.74341 .39122 Mdot
.31951 .64408 Mdot
.31825 .42129 Mdot
.55088 .37386 Mdot
.56774 .40682 Mdot
.57213 .37136 Mdot
.67386 .29318 Mdot
.60561 .63899 Mdot
.55503 .39101 Mdot
.732 .50725 Mdot
.233 .5167 Mdot
.49374 .36731 Mdot
.58707 .37348 Mdot
.32231 .43102 Mdot
.71385 .26588 Mdot
.43955 .64699 Mdot
.57381 .63462 Mdot
.5682 .60643 Mdot
.65708 .35478 Mdot
.35303 .48786 Mdot
.32635 .6581 Mdot
.58113 .69817 Mdot
.3196 .65215 Mdot
.73063 .47916 Mdot
.65412 .55198 Mdot
.62547 .59267 Mdot
.58281 .60285 Mdot
.41654 .63461 Mdot
.55186 .36918 Mdot
.50237 .40962 Mdot
.29068 .58681 Mdot
.51702 .41659 Mdot
.72181 .50225 Mdot
.46777 .60451 Mdot
.32352 .43171 Mdot
.73682 .47667 Mdot
.44832 .65897 Mdot
.35771 .44799 Mdot
.57865 .36224 Mdot
.57209 .42608 Mdot
.33954 .44259 Mdot
.30501 .4706 Mdot
.5019 .38047 Mdot
.18268 .45561 Mdot
.31433 .4198 Mdot
.31833 .44097 Mdot
.29174 .6777 Mdot
.56323 .64459 Mdot
.54513 .45425 Mdot
.47116 .61923 Mdot
.54671 .35112 Mdot
.55309 .63587 Mdot
.70802 .47022 Mdot
.34559 .43814 Mdot
.57342 .37979 Mdot
.52387 .35863 Mdot
.72644 .49235 Mdot
.69085 .46896 Mdot
.73055 .50103 Mdot
.43693 .66492 Mdot
.55861 .36477 Mdot
.3321 .46938 Mdot
.47204 .63467 Mdot
.70451 .46562 Mdot
.74921 .49752 Mdot
.19883 .38139 Mdot
.50117 .36817 Mdot
.65342 .51403 Mdot
.11636 .41486 Mdot
.72379 .39048 Mdot
.29846 .67104 Mdot
.57753 .66192 Mdot
.73513 .33703 Mdot
.67827 .51009 Mdot
.46691 .61444 Mdot
.6696 .4467 Mdot
.73052 .46089 Mdot
.54776 .42202 Mdot
.53017 .40842 Mdot
.48398 .41588 Mdot
.71381 .483 Mdot
.66603 .29365 Mdot
.35864 .42939 Mdot
.35851 .29852 Mdot
.7176 .48871 Mdot
.57611 .65855 Mdot
.56195 .65394 Mdot
.61559 .63906 Mdot
.48606 .36959 Mdot
.41312 .34736 Mdot
.38573 .22873 Mdot
.29882 .34329 Mdot
.46636 .64161 Mdot
.2885 .44222 Mdot
.61372 .56843 Mdot
.34537 .44826 Mdot
.62099 .61952 Mdot
.71341 .47934 Mdot
.36291 .46266 Mdot
.44097 .6248 Mdot
.44985 .62064 Mdot
.61341 .59467 Mdot
.59375 .64201 Mdot
.578 .64116 Mdot
.29802 .47117 Mdot
.32967 .4597 Mdot
.57271 .4019 Mdot
.33682 .43414 Mdot
.34451 .22273 Mdot
.6811 .5013 Mdot
.54509 .63646 Mdot
.4421 .63626 Mdot
.3037 .45809 Mdot
.53125 .38114 Mdot
.7344 .57544 Mdot
.64276 .65098 Mdot
.73887 .49816 Mdot
.4926 .57503 Mdot
.83655 .35652 Mdot
.56718 .41922 Mdot
.43273 .65414 Mdot
.2628 .53555 Mdot
.51749 .39268 Mdot
.58622 .6154 Mdot
.59135 .25304 Mdot
.32133 .66248 Mdot
.50023 .35439 Mdot
.48193 .39577 Mdot
.49278 .6366 Mdot
.58016 .52717 Mdot
.52505 .41935 Mdot
.46752 .48693 Mdot
.45139 .66736 Mdot
.62066 .64423 Mdot
.16885 .58919 Mdot
.51987 .61807 Mdot
.73385 .31243 Mdot
.29971 .66928 Mdot
.56396 .41828 Mdot
.5874 .63199 Mdot
.74296 .49606 Mdot
.59041 .6362 Mdot
.36046 .42213 Mdot
.56399 .6303 Mdot
.52844 .3976 Mdot
.3336 .46786 Mdot
.44047 .63125 Mdot
.41822 .48528 Mdot
.19374 .4109 Mdot
.56055 .61569 Mdot
.29108 .64179 Mdot
.49936 .35963 Mdot
.30349 .29809 Mdot
.57016 .30547 Mdot
.4898 .37664 Mdot
.47742 .63117 Mdot
.30799 .45309 Mdot
.4206 .64188 Mdot
.58555 .40089 Mdot
.51273 .22981 Mdot
.452 .65519 Mdot
.23319 .58872 Mdot
.7354 .4835 Mdot
.68892 .28252 Mdot
.52276 .37189 Mdot
.4835 .6421 Mdot
.55906 .36447 Mdot
.36668 .45012 Mdot
.44569 .52597 Mdot
.23508 .5059 Mdot
.48552 .63636 Mdot
.34807 .7916 Mdot
.49942 .51677 Mdot
.50722 .45109 Mdot
.4776 .65163 Mdot
.39085 .37209 Mdot
.31114 .65887 Mdot
.72437 .47962 Mdot
.6996 .46552 Mdot
.70984 .50919 Mdot
.51554 .41625 Mdot
.4578 .35345 Mdot
.75179 .48466 Mdot
.42936 .65866 Mdot
.74751 .48605 Mdot
.64995 .2747 Mdot
.37727 .80476 Mdot
.73611 .49753 Mdot
.52704 .36905 Mdot
.58583 .37208 Mdot
.7753 .40934 Mdot
.62122 .64666 Mdot
.56905 .80381 Mdot
.2696 .30093 Mdot
.49559 .37553 Mdot
.62451 .32944 Mdot
.34662 .41798 Mdot
.28388 .52056 Mdot
.61801 .38239 Mdot
.626 .53955 Mdot
.31179 .44422 Mdot
.48329 .55562 Mdot
.31468 .42427 Mdot
.56512 .42471 Mdot
.53323 .35833 Mdot
.34916 .48317 Mdot
.39953 .76862 Mdot
.19843 .54975 Mdot
.27925 .72032 Mdot
.3512 .42921 Mdot
.47271 .65773 Mdot
.43589 .65938 Mdot
.47305 .63852 Mdot
.58102 .64873 Mdot
.30727 .47538 Mdot
.56176 .37253 Mdot
.59217 .60515 Mdot
.53155 .34061 Mdot
.46828 .62366 Mdot
.34503 .65961 Mdot
.32197 .43221 Mdot
.50999 .37911 Mdot
.23409 .34245 Mdot
.60998 .62894 Mdot
.72407 .49187 Mdot
.44611 .56515 Mdot
.5795 .66364 Mdot
.47302 .66283 Mdot
.33913 .4928 Mdot
.54806 .66122 Mdot
.71801 .54977 Mdot
.47078 .36736 Mdot
.5013 .33665 Mdot
.41171 .69072 Mdot
.2123 .38481 Mdot
.52031 .4137 Mdot
.58763 .60315 Mdot
.56996 .65355 Mdot
.55783 .35334 Mdot
.34158 .47554 Mdot
.74134 .46829 Mdot
.70886 .51095 Mdot
.49937 .41884 Mdot
.41705 .55191 Mdot
.726 .31664 Mdot
.55865 .40897 Mdot
.51566 .46725 Mdot
.63557 .61888 Mdot
.30645 .67342 Mdot
.38702 .55059 Mdot
.69398 .49933 Mdot
.53586 .35169 Mdot
.20059 .57468 Mdot
.31498 .43835 Mdot
.56887 .63619 Mdot
.44095 .61937 Mdot
.75008 .46364 Mdot
.57854 .59852 Mdot
.55796 .35365 Mdot
.56694 .40744 Mdot
.49253 .63079 Mdot
.39423 .42865 Mdot
.71174 .48086 Mdot
.58945 .60608 Mdot
.68915 .48241 Mdot
.33783 .45957 Mdot
.32217 .43737 Mdot
.58517 .33538 Mdot
.59413 .3385 Mdot
.56697 .60808 Mdot
.48199 .40621 Mdot
.62412 .63086 Mdot
.76437 .58391 Mdot
.43185 .62927 Mdot
.47626 .37223 Mdot
.38556 .44207 Mdot
.46824 .62553 Mdot
.49797 .38921 Mdot
.40873 .68526 Mdot
.5508 .41585 Mdot
.61501 .65954 Mdot
.52383 .22004 Mdot
.69998 .47753 Mdot
.42 .43361 Mdot
.47044 .31239 Mdot
.54417 .38442 Mdot
.62124 .65062 Mdot
.48673 .31871 Mdot
.44963 .65184 Mdot
.31758 .45725 Mdot
.60433 .17028 Mdot
.45395 .62955 Mdot
.54203 .36324 Mdot
.70651 .48666 Mdot
.3024 .42161 Mdot
.29632 .64898 Mdot
.36815 .58031 Mdot
.47193 .42793 Mdot
.51285 .44378 Mdot
.54987 .36713 Mdot
.83874 .47723 Mdot
.58046 .63618 Mdot
.30627 .46529 Mdot
.42883 .64538 Mdot
.45974 .64029 Mdot
.61617 .62964 Mdot
.27117 .62321 Mdot
.43284 .79604 Mdot
.09501 .46629 Mdot
.58306 .59923 Mdot
.74581 .4977 Mdot
.47581 .5338 Mdot
.62617 .62072 Mdot
.5812 .62997 Mdot
.61339 .59312 Mdot
.32298 .6065 Mdot
.36035 .44607 Mdot
.52367 .35725 Mdot
.36432 .48224 Mdot
.55569 .42148 Mdot
.7842 .37765 Mdot
.46528 .63344 Mdot
.31983 .45795 Mdot
.43447 .69179 Mdot
.60931 .38212 Mdot
.51392 .39884 Mdot
.66887 .63695 Mdot
.46215 .40694 Mdot
.71711 .35331 Mdot
.58951 .41077 Mdot
.59914 .63697 Mdot
.61192 .31294 Mdot
.46799 .34872 Mdot
.25483 .32079 Mdot
.4437 .62457 Mdot
.29154 .65255 Mdot
.57331 .35508 Mdot
.48999 .45119 Mdot
.29928 .42527 Mdot
.3626 .46327 Mdot
.75086 .48213 Mdot
.42018 .57083 Mdot
.44152 .62755 Mdot
.48471 .80284 Mdot
.49145 .38924 Mdot
.3958 .62797 Mdot
.51571 .21515 Mdot
.49985 .38859 Mdot
.66438 .59769 Mdot
.44005 .30798 Mdot
.53323 .41781 Mdot
.31986 .34004 Mdot
.44596 .63382 Mdot
.49727 .1935 Mdot
.50062 .42563 Mdot
.58659 .61619 Mdot
.32485 .46251 Mdot
.33712 .41626 Mdot
.74151 .4916 Mdot
.30218 .25622 Mdot
.42741 .61008 Mdot
.32572 .45976 Mdot
.52158 .38906 Mdot
.43878 .6429 Mdot
.29262 .65471 Mdot
.49353 .43626 Mdot
.74191 .66368 Mdot
.33222 .43237 Mdot
.51145 .31588 Mdot
.26456 .68052 Mdot
.50612 .53075 Mdot
.54709 .83077 Mdot
.47483 .64059 Mdot
.69462 .502 Mdot
.58843 .41529 Mdot
.57317 .6966 Mdot
.51167 .43201 Mdot
.75818 .3495 Mdot
.29539 .40971 Mdot
.69734 .47219 Mdot
.51512 .38851 Mdot
.52519 .419 Mdot
.44953 .54056 Mdot
.68805 .47352 Mdot
.52735 .42011 Mdot
.56854 .32387 Mdot
.35642 .44541 Mdot
.31425 .64085 Mdot
.32895 .42995 Mdot
.53198 .37388 Mdot
.63365 .33958 Mdot
.35529 .46778 Mdot
.542 .79558 Mdot
.76289 .50384 Mdot
.45664 .64931 Mdot
.4722 .44413 Mdot
.49075 .36218 Mdot
.73793 .74378 Mdot
.2915 .66451 Mdot
.76517 .32519 Mdot
.59335 .66437 Mdot
.22602 .664 Mdot
.58517 .66599 Mdot
.4371 .83845 Mdot
.4141 .49979 Mdot
.4724 .38563 Mdot
.6944 .43294 Mdot
.31118 .33748 Mdot
.41645 .64165 Mdot
.34672 .262 Mdot
.49087 .38293 Mdot
.51087 .35343 Mdot
.6086 .60647 Mdot
.27922 .62767 Mdot
.26665 .54319 Mdot
.40404 .54818 Mdot
.71215 .47642 Mdot
.33299 .45533 Mdot
.52771 .40143 Mdot
.36036 .72754 Mdot
.56506 .61633 Mdot
.57758 .48044 Mdot
.51165 .37657 Mdot
.30817 .56769 Mdot
.26258 .59701 Mdot
.43688 .6409 Mdot
.59848 .66264 Mdot
.6275 .64802 Mdot
.57997 .3861 Mdot
.45233 .6128 Mdot
.56367 .41438 Mdot
.49407 .51499 Mdot
.48267 .33853 Mdot
.7191 .47054 Mdot
.51916 .33929 Mdot
.61181 .47913 Mdot
.43475 .8511 Mdot
.45757 .37545 Mdot
.30195 .43247 Mdot
.58687 .64884 Mdot
.61284 .63697 Mdot
.34752 .42728 Mdot
.61483 .63534 Mdot
.35832 .30573 Mdot
.47576 .21633 Mdot
.72711 .47432 Mdot
.259 .35559 Mdot
.70693 .47456 Mdot
.29157 .65153 Mdot
.50021 .37262 Mdot
.60214 .70454 Mdot
.58186 .59922 Mdot
.61815 .25065 Mdot
.45743 .63526 Mdot
.29202 .66553 Mdot
.55499 .33956 Mdot
.66194 .55386 Mdot
.61491 .61463 Mdot
.56737 .7708 Mdot
.57319 .37383 Mdot
.36363 .44979 Mdot
.52973 .41807 Mdot
.48397 .34276 Mdot
.29848 .67305 Mdot
.55069 .36661 Mdot
.44869 .6591 Mdot
.30792 .47657 Mdot
.44037 .83419 Mdot
.58574 .65097 Mdot
.5088 .35055 Mdot
.52066 .38949 Mdot
.36682 .45988 Mdot
.54715 .33167 Mdot
.4702 .61643 Mdot
.15704 .68197 Mdot
.73415 .48219 Mdot
.30958 .67339 Mdot
.55256 .78098 Mdot
.53512 .40369 Mdot
.55051 .40893 Mdot
.40549 .69008 Mdot
.20656 .49515 Mdot
.4557 .65893 Mdot
.52979 .32178 Mdot
.57771 .60998 Mdot
.70499 .48136 Mdot
.4826 .62292 Mdot
.55756 .35681 Mdot
.50935 .3547 Mdot
.72317 .47079 Mdot
.67138 .63055 Mdot
.64248 .6411 Mdot
.46919 .64021 Mdot
.62874 .3621 Mdot
.73935 .57809 Mdot
.51293 .36239 Mdot
.31886 .74962 Mdot
.31947 .44309 Mdot
.47476 .65177 Mdot
.40209 .38262 Mdot
.54436 .43 Mdot
.47473 .66136 Mdot
.44138 .62944 Mdot
.56375 .35169 Mdot
.35452 .48778 Mdot
.29211 .46407 Mdot
.31692 .44334 Mdot
.53879 .215 Mdot
.80245 .47181 Mdot
.57676 .6414 Mdot
.44507 .63096 Mdot
.55323 .64281 Mdot
.74978 .4755 Mdot
.47606 .54115 Mdot
.57033 .65454 Mdot
.33278 .41694 Mdot
.5498 .64318 Mdot
.55987 .4151 Mdot
.44523 .62044 Mdot
.58645 .60107 Mdot
.54318 .39823 Mdot
.50473 .46748 Mdot
.62819 .46923 Mdot
.736 .46576 Mdot
.47751 .55331 Mdot
.53861 .36797 Mdot
.3059 .6698 Mdot
.50385 .37826 Mdot
.44599 .61316 Mdot
.60213 .4901 Mdot
.54995 .39248 Mdot
.57288 .60318 Mdot
.73705 .54675 Mdot
.61177 .65495 Mdot
.50126 .32949 Mdot
.53239 .37281 Mdot
.51175 .36055 Mdot
.51949 .41972 Mdot
.24361 .60201 Mdot
.42149 .63137 Mdot
.46791 .44383 Mdot
.58183 .59338 Mdot
.34578 .44409 Mdot
.36889 .45062 Mdot
.61879 .54382 Mdot
.29308 .67437 Mdot
.45889 .61334 Mdot
.51309 .35914 Mdot
.56791 .77026 Mdot
.34898 .66184 Mdot
.30105 .74228 Mdot
.64888 .56885 Mdot
.58655 .60243 Mdot
.2989 .43736 Mdot
.62033 .60449 Mdot
.5523 .34419 Mdot
.58816 .41298 Mdot
.4563 .83534 Mdot
.47578 .66816 Mdot
.71339 .48042 Mdot
.5317 .34002 Mdot
.70835 .29144 Mdot
.58053 .60783 Mdot
.63634 .62225 Mdot
.57004 .40971 Mdot
.28726 .46617 Mdot
.51767 .85727 Mdot
.44418 .61572 Mdot
.31213 .28919 Mdot
.30095 .40222 Mdot
.57806 .46418 Mdot
.44737 .64542 Mdot
.64727 .49792 Mdot
.60994 .65191 Mdot
.28199 .28491 Mdot
.34053 .44071 Mdot
.71733 .48203 Mdot
.57331 .3323 Mdot
.33101 .41642 Mdot
.56393 .6583 Mdot
.31147 .43176 Mdot
.55508 .42958 Mdot
.42519 .65249 Mdot
.61863 .63406 Mdot
.43784 .61151 Mdot
.34068 .48571 Mdot
.70404 .47551 Mdot
.63072 .26908 Mdot
.31438 .28354 Mdot
.44022 .30799 Mdot
.55551 .39035 Mdot
.63912 .71233 Mdot
.56301 .36973 Mdot
.29225 .43968 Mdot
.52355 .37146 Mdot
.41664 .4597 Mdot
.63035 .6343 Mdot
.50223 .31988 Mdot
.5077 .34405 Mdot
.29022 .28941 Mdot
.50614 .39603 Mdot
.55508 .34107 Mdot
.48925 .40725 Mdot
.3474 .39606 Mdot
.53294 .31713 Mdot
.36239 .45214 Mdot
.29566 .59418 Mdot
.58334 .6286 Mdot
.74914 .50082 Mdot
.6942 .50616 Mdot
.75173 .34146 Mdot
.6946 .28505 Mdot
.2782 .62002 Mdot
.34238 .42848 Mdot
.46208 .66284 Mdot
.56559 .41257 Mdot
.36327 .37824 Mdot
.64903 .42782 Mdot
.61335 .64958 Mdot
.55474 .61935 Mdot
.58019 .32445 Mdot
.84986 .51453 Mdot
.52186 .31555 Mdot
.35965 .58871 Mdot
.53236 .42217 Mdot
.47666 .38029 Mdot
.63703 .61813 Mdot
.66306 .28219 Mdot
.55492 .3909 Mdot
.29963 .42486 Mdot
.72267 .48402 Mdot
.62174 .33077 Mdot
.65004 .3968 Mdot
.61495 .45287 Mdot
.25507 .46877 Mdot
.55644 .36831 Mdot
.59187 .6085 Mdot
.32488 .41623 Mdot
.36707 .5616 Mdot
.47382 .63392 Mdot
.38316 .56338 Mdot
.33681 .25586 Mdot
.52778 .60886 Mdot
.71856 .48061 Mdot
.6519 .58354 Mdot
.52908 .39715 Mdot
.57973 .64762 Mdot
.56011 .42423 Mdot
.34786 .66644 Mdot
.70612 .46964 Mdot
.31745 .48721 Mdot
.4715 .65869 Mdot
.36123 .43592 Mdot
.3954 .35626 Mdot
.64787 .42094 Mdot
.2262 .66576 Mdot
.56706 .64763 Mdot
.54016 .25843 Mdot
.3154 .46738 Mdot
.56754 .36706 Mdot
.10117 .45346 Mdot
.32088 .44532 Mdot
.36334 .44068 Mdot
.62791 .53906 Mdot
.64494 .29376 Mdot
.46657 .34872 Mdot
.31687 .42523 Mdot
.54189 .62665 Mdot
.71097 .49881 Mdot
.54839 .403 Mdot
.49748 .41462 Mdot
.35799 .46751 Mdot
.6178 .61788 Mdot
.70955 .28802 Mdot
.59669 .63986 Mdot
.35684 .45414 Mdot
.60344 .62468 Mdot
.52625 .78946 Mdot
.56634 .61991 Mdot
.50333 .34601 Mdot
.51394 .35954 Mdot
.73681 .64922 Mdot
.32228 .43733 Mdot
.54763 .40752 Mdot
.53045 .35304 Mdot
.32517 .46999 Mdot
.61217 .58705 Mdot
.44755 .31419 Mdot
.53901 .39542 Mdot
.51867 .35726 Mdot
.6917 .47503 Mdot
.50168 .55343 Mdot
.34047 .72768 Mdot
.54811 .40478 Mdot
.72077 .51018 Mdot
.29695 .46812 Mdot
.50346 .38079 Mdot
.66355 .27771 Mdot
.60441 .66895 Mdot
.54027 .3358 Mdot
.29841 .64654 Mdot
.51487 .41171 Mdot
.51076 .85867 Mdot
.505 .3547 Mdot
.31753 .47252 Mdot
.31881 .46375 Mdot
.64253 .64548 Mdot
.34111 .4493 Mdot
.29599 .66741 Mdot
.4644 .62239 Mdot
.30277 .75294 Mdot
.29442 .66414 Mdot
.47931 .3676 Mdot
.25144 .30739 Mdot
.50533 .42328 Mdot
.57368 .34765 Mdot
.63257 .26145 Mdot
.29793 .66584 Mdot
.30757 .4572 Mdot
.40011 .76589 Mdot
.47617 .36399 Mdot
.44596 .61457 Mdot
.58139 .35544 Mdot
.53785 .33459 Mdot
.51816 .4934 Mdot
.52498 .23049 Mdot
.46245 .60381 Mdot
.5372 .45507 Mdot
.54959 .40382 Mdot
.21827 .45907 Mdot
.5262 .39067 Mdot
.73833 .495 Mdot
.33514 .42301 Mdot
.62462 .60682 Mdot
.73203 .48856 Mdot
.53161 .40142 Mdot
.71571 .48521 Mdot
.57507 .63955 Mdot
.48157 .63578 Mdot
.52525 .33798 Mdot
.68166 .49586 Mdot
.71002 .47896 Mdot
.56919 .38565 Mdot
.32298 .46018 Mdot
.55097 .29653 Mdot
.50263 .38291 Mdot
.55991 .35644 Mdot
.34827 .42808 Mdot
.29811 .22438 Mdot
.57501 .41116 Mdot
.64736 .50737 Mdot
.37304 .45817 Mdot
.32122 .669 Mdot
.61279 .60072 Mdot
.55125 .43695 Mdot
.46499 .63784 Mdot
.46557 .62828 Mdot
.57905 .59074 Mdot
.34082 .48133 Mdot
.62174 .6288 Mdot
.4935 .44025 Mdot
.58308 .32807 Mdot
.57353 .32952 Mdot
.60783 .17226 Mdot
.56374 .79071 Mdot
.31932 .4778 Mdot
.61268 .65233 Mdot
.40012 .55359 Mdot
.45785 .61461 Mdot
.57974 .58881 Mdot
.3839 .43849 Mdot
.2995 .4606 Mdot
.32999 .41827 Mdot
.69703 .49914 Mdot
.59897 .6445 Mdot
.31703 .40641 Mdot
.29655 .47654 Mdot
.57508 .39273 Mdot
.55075 .40337 Mdot
.27739 .43481 Mdot
.77016 .4114 Mdot
.71155 .47104 Mdot
.59147 .61186 Mdot
.69337 .79367 Mdot
.44267 .61628 Mdot
.28765 .29137 Mdot
.54235 .39781 Mdot
.21317 .25691 Mdot
.54204 .31969 Mdot
.52297 .38977 Mdot
.29946 .47007 Mdot
.707 .51428 Mdot
.70979 .49496 Mdot
.31612 .46701 Mdot
.30349 .48698 Mdot
.71194 .50739 Mdot
.6565 .57383 Mdot
.32519 .78052 Mdot
.37625 .55997 Mdot
.32443 .47307 Mdot
.29067 .30567 Mdot
.48364 .62651 Mdot
.36962 .46992 Mdot
.45301 .60637 Mdot
.5804 .62911 Mdot
.55474 .62332 Mdot
.49258 .62856 Mdot
.56705 .36161 Mdot
.56579 .63106 Mdot
.46126 .41555 Mdot
.50147 .82114 Mdot
.71852 .70799 Mdot
.19186 .5 Mdot
.49614 .40538 Mdot
.27709 .54976 Mdot
.24918 .55536 Mdot
.54376 .37771 Mdot
.59658 .42263 Mdot
.7145 .48187 Mdot
.36833 .46857 Mdot
.4625 .61039 Mdot
.57575 .81025 Mdot
.51293 .36135 Mdot
.35313 .45934 Mdot
.45072 .6169 Mdot
.5162 .78427 Mdot
.47493 .48978 Mdot
.56702 .41496 Mdot
.08399 .52937 Mdot
.3328 .48671 Mdot
.62536 .60764 Mdot
.23596 .35865 Mdot
.37115 .47631 Mdot
.74351 .56607 Mdot
.63347 .6437 Mdot
.29631 .71498 Mdot
.30061 .44985 Mdot
.64242 .60676 Mdot
.3402 .45736 Mdot
.73837 .4758 Mdot
.34494 .49186 Mdot
.61369 .62412 Mdot
.51133 .39146 Mdot
.61391 .62758 Mdot
.72522 .46967 Mdot
.56857 .64416 Mdot
.46507 .61111 Mdot
.3015 .66986 Mdot
.45472 .61878 Mdot
.48082 .5419 Mdot
.48609 .25139 Mdot
.46915 .6483 Mdot
.59313 .75954 Mdot
.52304 .41308 Mdot
.39713 .43323 Mdot
.62247 .60368 Mdot
.54701 .6243 Mdot
.44981 .55117 Mdot
.35032 .45778 Mdot
.60843 .62033 Mdot
.34002 .25669 Mdot
.40383 .15446 Mdot
.45463 .40872 Mdot
.79634 .48866 Mdot
.32611 .47087 Mdot
.63251 .63083 Mdot
.36051 .5743 Mdot
.35958 .42712 Mdot
.57572 .60357 Mdot
.47934 .65111 Mdot
.45688 .64296 Mdot
.57277 .36845 Mdot
.49871 .62974 Mdot
.62398 .64813 Mdot
.20097 .55696 Mdot
.33644 .42227 Mdot
.5269 .77787 Mdot
.73087 .50295 Mdot
.57715 .63284 Mdot
.47558 .3382 Mdot
.26246 .44664 Mdot
.55348 .6181 Mdot
.77316 .63218 Mdot
.73057 .76366 Mdot
.6071 .61992 Mdot
.33413 .423 Mdot
.34779 .43961 Mdot
.46038 .36727 Mdot
.42634 .54893 Mdot
.61358 .61709 Mdot
.61455 .70493 Mdot
.76433 .35823 Mdot
.30145 .64942 Mdot
.21874 .35131 Mdot
.55435 .39028 Mdot
.55696 .36174 Mdot
.47691 .62316 Mdot
.51606 .40251 Mdot
.28845 .46067 Mdot
.56515 .3335 Mdot
.43659 .66113 Mdot
.61649 .64695 Mdot
.50468 .36636 Mdot
.69919 .49064 Mdot
.47205 .61625 Mdot
.48364 .65877 Mdot
.59471 .62578 Mdot
.32211 .4205 Mdot
.38396 .76801 Mdot
.59637 .64088 Mdot
.55732 .37015 Mdot
.30389 .65914 Mdot
.54854 .43276 Mdot
.7101 .67262 Mdot
.35642 .42829 Mdot
.62315 .60683 Mdot
.37772 .43628 Mdot
.44947 .62651 Mdot
.56187 .60327 Mdot
.53095 .38803 Mdot
.56978 .60779 Mdot
.65731 .47378 Mdot
.68995 .62109 Mdot
.2962 .4778 Mdot
.6817 .46427 Mdot
.3649 .46126 Mdot
.30086 .64917 Mdot
.67989 .36987 Mdot
.72264 .47646 Mdot
.57007 .6198 Mdot
.55651 .79931 Mdot
.60467 .59249 Mdot
.50415 .39578 Mdot
.49641 .39701 Mdot
.61052 .60575 Mdot
.69429 .48925 Mdot
.67419 .25162 Mdot
.69677 .5297 Mdot
.30465 .44841 Mdot
.38208 .51496 Mdot
.6383 .82227 Mdot
.52806 .63894 Mdot
.47373 .66033 Mdot
.54862 .4592 Mdot
.54286 .41537 Mdot
.49105 .64038 Mdot
.42907 .63188 Mdot
.70739 .46527 Mdot
.57601 .64525 Mdot
.36734 .41724 Mdot
.48686 .62868 Mdot
.51476 .28129 Mdot
.67913 .27765 Mdot
.46014 .38814 Mdot
.51609 .30979 Mdot
.48845 .36051 Mdot
.50583 .53278 Mdot
.42296 .64366 Mdot
.53536 .36496 Mdot
.59212 .34619 Mdot
.46993 .65467 Mdot
.72985 .47143 Mdot
.37444 .48896 Mdot
.59619 .61883 Mdot
.32442 .177 Mdot
.52314 .33829 Mdot
.50754 .38896 Mdot
.46602 .64177 Mdot
.20884 .39954 Mdot
.32675 .47664 Mdot
.32376 .42211 Mdot
.57965 .63696 Mdot
.44325 .55562 Mdot
.53975 .32861 Mdot
.54252 .37435 Mdot
.57327 .62113 Mdot
.3046 .66877 Mdot
.17473 .51933 Mdot
.52449 .36022 Mdot
.44431 .63897 Mdot
.58407 .75576 Mdot
.42224 .64101 Mdot
.56511 .42051 Mdot
.50221 .39646 Mdot
.50847 .34096 Mdot
.51622 .42046 Mdot
.49027 .62904 Mdot
.54085 .37832 Mdot
.59187 .32051 Mdot
.31035 .44985 Mdot
.55052 .38432 Mdot
.74321 .33642 Mdot
.51931 .36258 Mdot
.69973 .48925 Mdot
.34722 .73758 Mdot
.5159 .34851 Mdot
.55229 .38037 Mdot
.68112 .52594 Mdot
.51719 .3851 Mdot
.43558 .63191 Mdot
.34309 .43948 Mdot
.4452 .62913 Mdot
.43777 .65185 Mdot
.54775 .63396 Mdot
.71541 .4633 Mdot
.50417 .43038 Mdot
.71946 .50868 Mdot
.4745 .34689 Mdot
.55369 .42905 Mdot
.49064 .55166 Mdot
.35976 .59068 Mdot
.6742 .50501 Mdot
.53316 .38204 Mdot
.58355 .63319 Mdot
.61153 .59828 Mdot
.69659 .43721 Mdot
.45692 .39824 Mdot
.48283 .62148 Mdot
.48359 .64223 Mdot
.74084 .39405 Mdot
.49709 .4906 Mdot
.70083 .48222 Mdot
.40472 .53657 Mdot
.48897 .3958 Mdot
.52619 .34998 Mdot
.58516 .36724 Mdot
.56396 .65166 Mdot
.30463 .67204 Mdot
.6113 .64941 Mdot
.28213 .66339 Mdot
.42112 .63601 Mdot
.4952 .40352 Mdot
.68575 .73335 Mdot
.33932 .47895 Mdot
.3419 .43853 Mdot
.44481 .6655 Mdot
.61425 .65387 Mdot
.46097 .37053 Mdot
.62705 .17379 Mdot
.29034 .42392 Mdot
.72981 .51146 Mdot
.54276 .36986 Mdot
.5912 .62759 Mdot
.31703 .48167 Mdot
.69074 .46643 Mdot
.49153 .39543 Mdot
.60021 .58775 Mdot
.52099 .3683 Mdot
.30631 .35054 Mdot
.31145 .45491 Mdot
.34194 .66697 Mdot
.28557 .47032 Mdot
.48526 .64935 Mdot
.44686 .6565 Mdot
.49862 .39077 Mdot
.51151 .14354 Mdot
.2839 .47557 Mdot
.48922 .60501 Mdot
.73879 .47276 Mdot
.31139 .6719 Mdot
.72755 .46545 Mdot
.62629 .62577 Mdot
.72171 .48183 Mdot
.56865 .60605 Mdot
.75602 .41238 Mdot
.30472 .41068 Mdot
.73323 .48388 Mdot
.20074 .41 Mdot
.56974 .42726 Mdot
.69927 .46731 Mdot
.57625 .32048 Mdot
.41233 .44047 Mdot
.57573 .62168 Mdot
.69592 .49138 Mdot
.57273 .37984 Mdot
.61698 .77924 Mdot
.44183 .65455 Mdot
.48037 .61865 Mdot
.50996 .43209 Mdot
.62986 .60638 Mdot
.30895 .48873 Mdot
.60102 .52483 Mdot
.3237 .66455 Mdot
.54168 .37466 Mdot
.49111 .39739 Mdot
.3566 .47386 Mdot
.2947 .42915 Mdot
.50028 .39633 Mdot
.35758 .24981 Mdot
.5302 .39697 Mdot
.45407 .64542 Mdot
.3031 .46931 Mdot
.34469 .43753 Mdot
.60862 .65996 Mdot
.34074 .48107 Mdot
.51619 .31201 Mdot
.41319 .65644 Mdot
.58848 .35004 Mdot
.4531 .6269 Mdot
.6129 .48545 Mdot
.57878 .64902 Mdot
.57512 .80427 Mdot
.32972 .48425 Mdot
.55243 .37074 Mdot
.36609 .45615 Mdot
.72948 .50125 Mdot
.3241 .43623 Mdot
.33483 .41342 Mdot
.49225 .38805 Mdot
.56471 .41761 Mdot
.30365 .66514 Mdot
.42661 .55068 Mdot
.3177 .4531 Mdot
.53625 .39204 Mdot
.49434 .4186 Mdot
.58141 .39404 Mdot
.50194 .51794 Mdot
.29722 .45693 Mdot
.45049 .20982 Mdot
.71684 .68474 Mdot
.32247 .4575 Mdot
.58104 .82566 Mdot
.31272 .64523 Mdot
.29341 .67535 Mdot
.47934 .59772 Mdot
.5224 .35727 Mdot
.61998 .6292 Mdot
.54891 .34211 Mdot
.46536 .42307 Mdot
.51281 .34833 Mdot
.71531 .46804 Mdot
.46953 .39144 Mdot
.31488 .65224 Mdot
.60313 .63797 Mdot
.53617 .39909 Mdot
.50573 .36162 Mdot
.29123 .67288 Mdot
.28493 .47133 Mdot
.30002 .45529 Mdot
.32787 .75271 Mdot
.73539 .47803 Mdot
.47645 .63178 Mdot
.5532 .34711 Mdot
.58208 .6348 Mdot
.61509 .63148 Mdot
.36262 .43805 Mdot
.59111 .6156 Mdot
.44743 .61227 Mdot
.52437 .39489 Mdot
.49156 .63864 Mdot
.71638 .46822 Mdot
.33582 .42312 Mdot
.55396 .34734 Mdot
.57539 .38969 Mdot
.31845 .46367 Mdot
.52084 .41332 Mdot
.691 .47604 Mdot
.5574 .63119 Mdot
.30244 .46006 Mdot
.46477 .6237 Mdot
.59625 .66246 Mdot
.56423 .41148 Mdot
.8017 .67078 Mdot
.51729 .40369 Mdot
.5455 .34657 Mdot
.36857 .81095 Mdot
.59293 .40484 Mdot
.63044 .6289 Mdot
.36982 .45057 Mdot
.58139 .40591 Mdot
.78653 .38521 Mdot
.49277 .68581 Mdot
.58481 .58667 Mdot
.54556 .36764 Mdot
.55278 .81991 Mdot
.55014 .37584 Mdot
.50438 .7871 Mdot
.48808 .551 Mdot
.82693 .51047 Mdot
.52714 .30777 Mdot
.49291 .61197 Mdot
.30241 .66689 Mdot
.62187 .60185 Mdot
.35191 .36355 Mdot
.51763 .40835 Mdot
.40284 .37005 Mdot
.53501 .33247 Mdot
.44902 .6452 Mdot
.58819 .43292 Mdot
.59162 .61275 Mdot
.25925 .31021 Mdot
.56077 .37068 Mdot
.29804 .46131 Mdot
.54168 .63146 Mdot
.31858 .66637 Mdot
.57288 .37787 Mdot
.73052 .50529 Mdot
.44415 .68949 Mdot
.55267 .31577 Mdot
.45558 .62563 Mdot
.53253 .3516 Mdot
.51505 .45593 Mdot
.44794 .15248 Mdot
.30849 .45002 Mdot
.4756 .65797 Mdot
.2655 .50968 Mdot
.50939 .41388 Mdot
.30064 .45222 Mdot
.34264 .44226 Mdot
.744 .49075 Mdot
.36684 .6113 Mdot
.53883 .67498 Mdot
.75244 .68386 Mdot
.4238 .32393 Mdot
.58738 .66365 Mdot
.21117 .52934 Mdot
.55423 .39824 Mdot
.64737 .41137 Mdot
.43481 .64076 Mdot
.50981 .3893 Mdot
.45368 .27629 Mdot
.31721 .44162 Mdot
.52677 .36463 Mdot
.71418 .47096 Mdot
.34436 .63074 Mdot
.62193 .43999 Mdot
.73584 .73564 Mdot
.55125 .60933 Mdot
.58272 .35152 Mdot
.55297 .30634 Mdot
.31928 .67095 Mdot
.55122 .42481 Mdot
.62561 .60598 Mdot
.64456 .71508 Mdot
.69382 .48368 Mdot
.33349 .48149 Mdot
.31622 .64722 Mdot
.51143 .33458 Mdot
.52567 .43198 Mdot
.74898 .5005 Mdot
.56599 .36787 Mdot
.24535 .33849 Mdot
.33047 .66752 Mdot
.56467 .62144 Mdot
.31215 .42973 Mdot
.48728 .36278 Mdot
.30594 .67126 Mdot
.49356 .39213 Mdot
.3609 .50072 Mdot
.5474 .35777 Mdot
.2588 .66285 Mdot
.32622 .46249 Mdot
.45539 .62255 Mdot
.48775 .4237 Mdot
.51185 .36907 Mdot
.73808 .58169 Mdot
.46753 .42587 Mdot
.50545 .35496 Mdot
.31 .41628 Mdot
.34669 .47332 Mdot
.36215 .44626 Mdot
.5629 .62716 Mdot
.38293 .55457 Mdot
.45267 .6381 Mdot
.55484 .33147 Mdot
.4851 .6266 Mdot
.45408 .34238 Mdot
.74275 .5043 Mdot
.63066 .79413 Mdot
.52839 .40639 Mdot
.35661 .43702 Mdot
.20783 .5792 Mdot
.29726 .46943 Mdot
.46436 .58786 Mdot
.44164 .62688 Mdot
.32112 .44723 Mdot
.52085 .38136 Mdot
.40929 .54734 Mdot
.77308 .6961 Mdot
.46114 .61567 Mdot
.5903 .39378 Mdot
.54782 .61533 Mdot
.56872 .60379 Mdot
.5616 .85068 Mdot
.44042 .65666 Mdot
.24477 .55188 Mdot
.54034 .38844 Mdot
.34511 .47622 Mdot
.47103 .64388 Mdot
.43369 .63507 Mdot
.5779 .6179 Mdot
.57208 .41001 Mdot
.51451 .3683 Mdot
.30033 .64556 Mdot
.4833 .63469 Mdot
.5518 .44398 Mdot
.54325 .42102 Mdot
.43972 .83693 Mdot
.38234 .43017 Mdot
.2718 .2442 Mdot
.50102 .44596 Mdot
.46204 .27485 Mdot
.53475 .51029 Mdot
.31475 .47773 Mdot
.56028 .3513 Mdot
.54666 .32619 Mdot
.59789 .6634 Mdot
.5229 .39885 Mdot
.59259 .65694 Mdot
.46988 .66233 Mdot
.63923 .796 Mdot
.53993 .7677 Mdot
.6088 .57009 Mdot
.51144 .40005 Mdot
.58185 .46593 Mdot
.73006 .4964 Mdot
.44325 .66935 Mdot
.3542 .46291 Mdot
.48408 .37381 Mdot
.63211 .64707 Mdot
.57133 .6168 Mdot
.33536 .44191 Mdot
.25795 .57405 Mdot
.54084 .79572 Mdot
.51499 .42095 Mdot
.62281 .60915 Mdot
.5156 .76762 Mdot
.38418 .24191 Mdot
.4974 .62416 Mdot
.69599 .47957 Mdot
.61798 .64423 Mdot
.47653 .66515 Mdot
.39104 .47982 Mdot
.33209 .44852 Mdot
.35006 .48035 Mdot
.72153 .635 Mdot
.61536 .62044 Mdot
.72495 .49515 Mdot
.46257 .4774 Mdot
.42906 .47787 Mdot
.70858 .46958 Mdot
.61586 .64813 Mdot
.33197 .48017 Mdot
.35457 .45751 Mdot
.34454 .44061 Mdot
.25367 .3218 Mdot
.34972 .42278 Mdot
.41244 .19598 Mdot
.51218 .42492 Mdot
.3015 .30123 Mdot
.5492 .37317 Mdot
.48447 .61491 Mdot
.3119 .45623 Mdot
.46863 .53925 Mdot
.48089 .38603 Mdot
.74276 .72539 Mdot
.53976 .3683 Mdot
.41129 .66408 Mdot
.52058 .35676 Mdot
.25237 .35426 Mdot
.37296 .45897 Mdot
.5339 .38307 Mdot
.4655 .60154 Mdot
.70875 .48239 Mdot
.29992 .49296 Mdot
.51391 .35129 Mdot
.30351 .62268 Mdot
.58975 .34231 Mdot
.52277 .81189 Mdot
.7127 .55066 Mdot
.72255 .51372 Mdot
.57658 .32804 Mdot
.55275 .65086 Mdot
.27229 .47326 Mdot
.2857 .32151 Mdot
.46227 .61624 Mdot
.55816 .24502 Mdot
.56871 .62297 Mdot
.59019 .42937 Mdot
.48611 .344 Mdot
.69401 .4967 Mdot
.28977 .48499 Mdot
.45379 .6476 Mdot
.52242 .41115 Mdot
.55889 .34646 Mdot
.78189 .60586 Mdot
.27738 .32708 Mdot
.54542 .44469 Mdot
.74883 .47613 Mdot
.45923 .2123 Mdot
.52369 .34632 Mdot
.59601 .58666 Mdot
.3717 .44001 Mdot
.48787 .32549 Mdot
.438 .21015 Mdot
.53428 .39522 Mdot
.32485 .44467 Mdot
.3331 .48407 Mdot
.23984 .631 Mdot
.73328 .50931 Mdot
.54722 .35748 Mdot
.75322 .57681 Mdot
.55818 .36544 Mdot
.45231 .64164 Mdot
.57151 .4174 Mdot
.57508 .62883 Mdot
.35671 .57889 Mdot
.56117 .63148 Mdot
.57822 .37927 Mdot
.35155 .45105 Mdot
.45861 .64781 Mdot
.7145 .65238 Mdot
.57989 .53447 Mdot
.4229 .1943 Mdot
.4465 .69134 Mdot
.70018 .49963 Mdot
.70649 .46239 Mdot
.41613 .63026 Mdot
.53321 .37565 Mdot
.53066 .52891 Mdot
.50662 .32006 Mdot
.51892 .35395 Mdot
.52335 .33992 Mdot
.46614 .67417 Mdot
.44565 .6238 Mdot
.60774 .62476 Mdot
.50158 .39845 Mdot
.53647 .39089 Mdot
.32736 .45598 Mdot
.70892 .47884 Mdot
.56134 .6215 Mdot
.73735 .48507 Mdot
.59645 .63663 Mdot
.52451 .8528 Mdot
.58382 .40479 Mdot
.70787 .48323 Mdot
.42212 .64707 Mdot
.35482 .43266 Mdot
.29068 .66434 Mdot
.62517 .62802 Mdot
.59513 .61305 Mdot
.54236 .37765 Mdot
.32805 .42591 Mdot
.31646 .43338 Mdot
.70723 .50591 Mdot
.47804 .6453 Mdot
.57149 .36412 Mdot
.55249 .42122 Mdot
.80179 .53491 Mdot
.57748 .6598 Mdot
.37903 .23399 Mdot
.25242 .61778 Mdot
.53292 .37679 Mdot
.30954 .4384 Mdot
.50417 .37097 Mdot
.63833 .74565 Mdot
.33099 .41683 Mdot
.48577 .40587 Mdot
.49373 .48155 Mdot
.55845 .64487 Mdot
.23495 .65911 Mdot
.48796 .41976 Mdot
.40363 .69067 Mdot
.56431 .39185 Mdot
.31797 .80095 Mdot
.21122 .48717 Mdot
.52369 .33116 Mdot
.51068 .41823 Mdot
.77937 .65592 Mdot
.54444 .38501 Mdot
.31156 .64776 Mdot
.48159 .43222 Mdot
.29943 .45788 Mdot
.55627 .5161 Mdot
.49781 .56188 Mdot
.74806 .49451 Mdot
.57877 .63716 Mdot
.65751 .32612 Mdot
.735 .47378 Mdot
.31938 .47144 Mdot
.49379 .41211 Mdot
.50402 .27716 Mdot
.63472 .65582 Mdot
.48579 .33906 Mdot
.45114 .64283 Mdot
.49333 .56045 Mdot
.59998 .65247 Mdot
.46235 .62118 Mdot
.52408 .33414 Mdot
.76563 .33383 Mdot
.58558 .54157 Mdot
.25799 .71098 Mdot
.46887 .64029 Mdot
.43768 .63764 Mdot
.35978 .55759 Mdot
.74793 .49455 Mdot
.79313 .58096 Mdot
.61966 .41306 Mdot
.44721 .61505 Mdot
.70942 .36278 Mdot
.63807 .63096 Mdot
.36359 .61242 Mdot
.37017 .467 Mdot
.58612 .39597 Mdot
.51851 .37852 Mdot
.4742 .65038 Mdot
.40305 .39322 Mdot
.3136 .51311 Mdot
.45714 .61751 Mdot
.56904 .30767 Mdot
.35814 .63761 Mdot
.3007 .66063 Mdot
.30464 .64337 Mdot
.74457 .47707 Mdot
.66785 .65787 Mdot
.33768 .46236 Mdot
.69033 .49273 Mdot
.27168 .6809 Mdot
.54488 .35405 Mdot
.48434 .63307 Mdot
.29015 .65363 Mdot
.46363 .6306 Mdot
.70632 .49163 Mdot
.73239 .51047 Mdot
.30997 .44986 Mdot
.32879 .47645 Mdot
.52201 .23469 Mdot
.74211 .37775 Mdot
.5485 .38323 Mdot
.44111 .32113 Mdot
.34617 .42416 Mdot
.25343 .38572 Mdot
.72764 .5089 Mdot
.71023 .47587 Mdot
.33195 .31322 Mdot
.57212 .40412 Mdot
.56123 .76226 Mdot
.51739 .34873 Mdot
.68255 .38277 Mdot
.48107 .35706 Mdot
.58224 .61674 Mdot
.55647 .38151 Mdot
.37018 .74841 Mdot
.54035 .40687 Mdot
.51301 .34483 Mdot
.61082 .64186 Mdot
.49204 .42952 Mdot
.5731 .62779 Mdot
.56833 .41662 Mdot
.75818 .49495 Mdot
.58219 .63502 Mdot
.79034 .46808 Mdot
.64489 .50444 Mdot
.31136 .66773 Mdot
.73975 .47493 Mdot
.72366 .50684 Mdot
.73861 .32339 Mdot
.34896 .46748 Mdot
.40323 .46566 Mdot
.53312 .37432 Mdot
.63574 .62037 Mdot
.47944 .62477 Mdot
.53392 .39391 Mdot
.55465 .32639 Mdot
.49339 .42541 Mdot
.31648 .44563 Mdot
.62152 .64465 Mdot
.71289 .48762 Mdot
.60686 .59818 Mdot
.65868 .54843 Mdot
.58583 .595 Mdot
.52691 .46533 Mdot
.50905 .44746 Mdot
.50858 .29483 Mdot
.45197 .29827 Mdot
.28513 .27934 Mdot
.33623 .44649 Mdot
.30926 .657 Mdot
.74823 .49807 Mdot
.38094 .51378 Mdot
.35738 .44394 Mdot
.59996 .61318 Mdot
.52095 .36845 Mdot
.56811 .30614 Mdot
.61206 .44499 Mdot
.28124 .418 Mdot
.77683 .38702 Mdot
.59147 .6479 Mdot
.29821 .65437 Mdot
.37012 .5672 Mdot
.3422 .39779 Mdot
.47446 .539 Mdot
.50816 .36885 Mdot
.72621 .50745 Mdot
.31716 .4817 Mdot
.74745 .63428 Mdot
.47779 .6507 Mdot
.4251 .5499 Mdot
.51328 .40055 Mdot
.21789 .55318 Mdot
.35125 .45104 Mdot
.7074 .47372 Mdot
.47343 .65101 Mdot
.73253 .50887 Mdot
.31608 .6457 Mdot
.34587 .75592 Mdot
.56799 .37606 Mdot
.50314 .35612 Mdot
.43119 .61935 Mdot
.34118 .46064 Mdot
.65035 .62285 Mdot
.75649 .63918 Mdot
.62049 .60794 Mdot
.51808 .53523 Mdot
.30948 .47751 Mdot
.23864 .43785 Mdot
.57979 .60326 Mdot
.43108 .65963 Mdot
.5176 .52671 Mdot
.43719 .66086 Mdot
.52171 .34409 Mdot
.34097 .4295 Mdot
.44101 .65726 Mdot
.74661 .60476 Mdot
.50387 .84167 Mdot
.30392 .49743 Mdot
.5122 .41142 Mdot
.63854 .79379 Mdot
.41858 .8196 Mdot
.42331 .379 Mdot
.48772 .63188 Mdot
.49915 .38388 Mdot
.51369 .42126 Mdot
.56003 .3723 Mdot
.45958 .6615 Mdot
.62453 .55539 Mdot
.58631 .60933 Mdot
.53838 .36287 Mdot
.72974 .50317 Mdot
.58261 .62417 Mdot
.54559 .64144 Mdot
.61618 .59727 Mdot
.32481 .41543 Mdot
.50169 .4187 Mdot
.34555 .61056 Mdot
.34686 .81759 Mdot
.44609 .62569 Mdot
.31182 .6675 Mdot
.51687 .33884 Mdot
.51973 .20229 Mdot
.36168 .44479 Mdot
.61942 .60802 Mdot
.50829 .38812 Mdot
.713 .56456 Mdot
.31928 .62983 Mdot
.59339 .64346 Mdot
.35149 .46438 Mdot
.42366 .38027 Mdot
.5237 .39889 Mdot
.5656 .39378 Mdot
.33215 .46752 Mdot
.30067 .74015 Mdot
.36256 .58424 Mdot
.50536 .3675 Mdot
.4568 .6214 Mdot
.4267 .14726 Mdot
.51963 .4322 Mdot
.26859 .43015 Mdot
.30982 .67302 Mdot
.2676 .63671 Mdot
.39335 .23045 Mdot
.46818 .43854 Mdot
.66635 .76497 Mdot
.65204 .27878 Mdot
.61868 .80269 Mdot
.65301 .35802 Mdot
.47443 .75711 Mdot
.46714 .86948 Mdot
.47796 .60178 Mdot
.2569 .35763 Mdot
.82397 .55884 Mdot
.27708 .57423 Mdot
.68008 .54555 Mdot
.53968 .69696 Mdot
.72516 .55773 Mdot
.17236 .45515 Mdot
.58559 .59722 Mdot
.66822 .40912 Mdot
.56445 .35433 Mdot
.41094 .81336 Mdot
.30294 .28733 Mdot
.29453 .26182 Mdot
.61585 .79502 Mdot
.7518 .56809 Mdot
.80546 .65037 Mdot
.57272 .80056 Mdot
.55264 .25514 Mdot
.57322 .48071 Mdot
.62143 .68449 Mdot
.44466 .47142 Mdot
.65311 .31323 Mdot
.47274 .3317 Mdot
.36476 .7289 Mdot
.60481 .5778 Mdot
.4679 .23923 Mdot
.41571 .16026 Mdot
.62758 .63152 Mdot
.37075 .43738 Mdot
.8057 .5626 Mdot
.25896 .45966 Mdot
.44244 .59686 Mdot
.66736 .76452 Mdot
.43957 .84011 Mdot
.25351 .35093 Mdot
.28418 .69718 Mdot
.33285 .34422 Mdot
.66621 .23913 Mdot
.61192 .46484 Mdot
.3081 .48498 Mdot
.51389 .73543 Mdot
.4294 .47704 Mdot
.64626 .66886 Mdot
.23736 .37576 Mdot
.68353 .4713 Mdot
.79483 .43915 Mdot
.35143 .46245 Mdot
.40103 .23711 Mdot
.29814 .67796 Mdot
.27862 .68265 Mdot
.64362 .61555 Mdot
.64962 .73741 Mdot
.32916 .62899 Mdot
.32636 .61826 Mdot
.19492 .54958 Mdot
.77826 .7062 Mdot
.68587 .31017 Mdot
.65831 .7072 Mdot
.3976 .65477 Mdot
.65918 .28277 Mdot
.33176 .57881 Mdot
.72699 .34877 Mdot
.4276 .46278 Mdot
.86081 .53603 Mdot
.34002 .77921 Mdot
.8316 .6103 Mdot
.38678 .46677 Mdot
.56635 .43095 Mdot
.6787 .71017 Mdot
.41215 .33662 Mdot
.70466 .515 Mdot
.75984 .72039 Mdot
.70161 .50936 Mdot
.36464 .41716 Mdot
.26821 .56959 Mdot
.25948 .32379 Mdot
.64845 .59507 Mdot
.75906 .50885 Mdot
.52471 .31361 Mdot
.88265 .46426 Mdot
.68819 .75449 Mdot
.24782 .63417 Mdot
.42989 .83553 Mdot
.52493 .64058 Mdot
.60739 .67039 Mdot
.46535 .66333 Mdot
.47802 .85757 Mdot
.35184 .4397 Mdot
.36054 .83038 Mdot
.47129 .85166 Mdot
.24676 .47317 Mdot
.88817 .43252 Mdot
.18291 .49194 Mdot
.31272 .2898 Mdot
.60192 .26282 Mdot
.80695 .43913 Mdot
.33601 .55762 Mdot
.23128 .45156 Mdot
.53228 .63921 Mdot
.29321 .74318 Mdot
.53243 .84461 Mdot
.70738 .37657 Mdot
.53602 .60219 Mdot
.29023 .56835 Mdot
.62494 .47575 Mdot
.27108 .43528 Mdot
.69146 .53415 Mdot
.6452 .45998 Mdot
.82089 .62885 Mdot
.50943 .22024 Mdot
.55031 .14745 Mdot
.66052 .36325 Mdot
.21117 .39372 Mdot
.56775 .78538 Mdot
.77685 .46005 Mdot
.34285 .50865 Mdot
.29799 .60052 Mdot
.59359 .37652 Mdot
.39364 .53973 Mdot
.60198 .32868 Mdot
.69709 .45412 Mdot
.37186 .55719 Mdot
.46789 .78989 Mdot
.6729 .36398 Mdot
.73682 .68965 Mdot
.53589 .48846 Mdot
.30942 .42782 Mdot
.72351 .32859 Mdot
.69473 .33493 Mdot
.45858 .83432 Mdot
.26482 .51054 Mdot
.26509 .71868 Mdot
.26986 .50517 Mdot
.51061 .31835 Mdot
.25859 .36189 Mdot
.48296 .32019 Mdot
.71413 .34644 Mdot
.47638 .39699 Mdot
.19581 .56573 Mdot
.37891 .81761 Mdot
.47129 .25761 Mdot
.66696 .33443 Mdot
.46891 .2824 Mdot
.30714 .75675 Mdot
.68748 .70845 Mdot
.21957 .50375 Mdot
.28112 .39849 Mdot
.8763 .48774 Mdot
.59502 .62235 Mdot
.71517 .36974 Mdot
.44083 .67414 Mdot
.72338 .63985 Mdot
.83813 .52741 Mdot
.28114 .50263 Mdot
.36874 .8141 Mdot
.31402 .59811 Mdot
.6558 .61337 Mdot
.3703 .62638 Mdot
.5126 .61453 Mdot
.49584 .26842 Mdot
.51139 .43425 Mdot
.50569 .2901 Mdot
.68692 .48109 Mdot
.39498 .34049 Mdot
.70478 .68839 Mdot
.45619 .71223 Mdot
.48384 .45613 Mdot
.46643 .72413 Mdot
.29749 .65098 Mdot
.41099 .55504 Mdot
.55157 .85424 Mdot
.48575 .44256 Mdot
.19014 .4626 Mdot
.33506 .77152 Mdot
.50697 .53525 Mdot
.67256 .62828 Mdot
.23659 .5941 Mdot
.85022 .57417 Mdot
.42759 .84824 Mdot
.44706 .8092 Mdot
.64742 .79023 Mdot
.19111 .65979 Mdot
.84419 .47998 Mdot
.34232 .37624 Mdot
.45217 .67658 Mdot
.13943 .64607 Mdot
.59876 .60291 Mdot
.56628 .24145 Mdot
.41414 .33134 Mdot
.71008 .57197 Mdot
.26598 .46321 Mdot
.48357 .46476 Mdot
.48878 .67801 Mdot
.27733 .44466 Mdot
.52645 .31473 Mdot
.72549 .76084 Mdot
.86426 .53419 Mdot
.74359 .74346 Mdot
.34917 .75987 Mdot
.63436 .80307 Mdot
.81601 .60213 Mdot
.40135 .19881 Mdot
.79551 .5872 Mdot
.56984 .41828 Mdot
.72699 .39847 Mdot
.18802 .48922 Mdot
.64551 .60963 Mdot
.3088 .69023 Mdot
.38482 .44964 Mdot
.84922 .54635 Mdot
.56281 .8557 Mdot
.35446 .30836 Mdot
.44537 .231 Mdot
.6454 .4837 Mdot
.72802 .36468 Mdot
.54974 .27343 Mdot
.36643 .71716 Mdot
.499 .82473 Mdot
.8216 .59096 Mdot
.68984 .34516 Mdot
.52299 .70556 Mdot
.44851 .80102 Mdot
.21567 .44031 Mdot
.60367 .78236 Mdot
.81293 .55243 Mdot
.25326 .48581 Mdot
.3622 .396 Mdot
.3036 .51016 Mdot
.35691 .70467 Mdot
.61459 .73184 Mdot
.67295 .30482 Mdot
.56917 .64596 Mdot
.71242 .38243 Mdot
.46741 .51084 Mdot
.80046 .5806 Mdot
.66917 .2809 Mdot
.70283 .3801 Mdot
.46632 .80716 Mdot
.69719 .77471 Mdot
.2691 .70172 Mdot
.79356 .3609 Mdot
.39028 .69017 Mdot
.60769 .34335 Mdot
.55006 .43843 Mdot
.34463 .79158 Mdot
.67125 .80372 Mdot
.38278 .826 Mdot
.21507 .54935 Mdot
.73884 .60729 Mdot
.495 .64295 Mdot
.6651 .26268 Mdot
.42757 .70616 Mdot
.50771 .82756 Mdot
.38895 .52051 Mdot
.4929 .60399 Mdot
.32551 .59736 Mdot
.54756 .24831 Mdot
.62753 .26364 Mdot
.41561 .24715 Mdot
.45869 .37991 Mdot
.34617 .26208 Mdot
.37148 .45539 Mdot
.21463 .53649 Mdot
.72524 .35346 Mdot
.59377 .62515 Mdot
.80781 .50886 Mdot
.52741 .28026 Mdot
.59323 .40607 Mdot
.6295 .71836 Mdot
.27032 .43903 Mdot
.45296 .2941 Mdot
.58607 .67097 Mdot
.48823 .86723 Mdot
.199 .49853 Mdot
.53431 .26674 Mdot
.7012 .30841 Mdot
.79407 .54365 Mdot
.36918 .58425 Mdot
.41727 .64289 Mdot
.60411 .7969 Mdot
.64053 .52019 Mdot
.71594 .32222 Mdot
.35486 .25549 Mdot
.73751 .65661 Mdot
.54751 .325 Mdot
.23378 .6116 Mdot
.45741 .19177 Mdot
.4191 .55503 Mdot
.35787 .40918 Mdot
.29399 .41917 Mdot
.16093 .42177 Mdot
.38533 .75499 Mdot
.24051 .49568 Mdot
.61389 .78593 Mdot
.44926 .66396 Mdot
.30046 .42779 Mdot
.70405 .3908 Mdot
.69288 .62489 Mdot
.47966 .21847 Mdot
.62213 .73508 Mdot
.58173 .27609 Mdot
.42023 .71222 Mdot
.64441 .78768 Mdot
.74611 .71127 Mdot
.46181 .14759 Mdot
.2839 .46161 Mdot
.70116 .676 Mdot
.71665 .66316 Mdot
.30319 .4805 Mdot
.27717 .42116 Mdot
.5992 .45902 Mdot
.60427 .81806 Mdot
.4118 .51051 Mdot
.35809 .68474 Mdot
.51804 .52766 Mdot
.6785 .55773 Mdot
.75843 .62821 Mdot
.66076 .30157 Mdot
.62166 .77637 Mdot
.40103 .24673 Mdot
.81845 .42976 Mdot
.52853 .29103 Mdot
.53541 .2267 Mdot
.665 .2622 Mdot
.59337 .48 Mdot
.2394 .37873 Mdot
.48861 .78962 Mdot
.55625 .37152 Mdot
.77189 .71708 Mdot
.45738 .8287 Mdot
.37971 .54021 Mdot
.59489 .68171 Mdot
.55555 .40924 Mdot
.50731 .42304 Mdot
.3729 .39171 Mdot
.26189 .62815 Mdot
.83565 .43143 Mdot
.66978 .37827 Mdot
.60702 .3368 Mdot
.34862 .25649 Mdot
.19076 .46198 Mdot
.6648 .72051 Mdot
.53762 .80544 Mdot
.44845 .51476 Mdot
.18958 .49201 Mdot
.42506 .57066 Mdot
.35038 .68337 Mdot
.42305 .73072 Mdot
.81106 .61047 Mdot
.58232 .45638 Mdot
.27563 .61161 Mdot
.78679 .58335 Mdot
.52063 .33829 Mdot
.25791 .57451 Mdot
.58619 .79052 Mdot
.59133 .17027 Mdot
.32147 .57142 Mdot
.704 .78221 Mdot
.50857 .2922 Mdot
.28807 .61072 Mdot
.84508 .52059 Mdot
.68601 .20754 Mdot
.35867 .72387 Mdot
.81082 .64513 Mdot
.38539 .59261 Mdot
.62165 .78314 Mdot
.49471 .61679 Mdot
.46611 .48865 Mdot
.42002 .35289 Mdot
.59733 .82046 Mdot
.68036 .66228 Mdot
.65049 .74728 Mdot
.35706 .3868 Mdot
.6346 .80947 Mdot
.4224 .45952 Mdot
.17156 .40659 Mdot
.59642 .58474 Mdot
.17903 .55844 Mdot
.29553 .386 Mdot
.58017 .29081 Mdot
.70439 .36102 Mdot
.20186 .36635 Mdot
.35119 .22096 Mdot
.36742 .38002 Mdot
.70573 .41897 Mdot
.24447 .60413 Mdot
.69581 .30203 Mdot
.50727 .83195 Mdot
.1713 .44387 Mdot
.73714 .64791 Mdot
.23997 .52831 Mdot
.32575 .75512 Mdot
.25771 .63379 Mdot
.42489 .7505 Mdot
.65285 .71671 Mdot
.32487 .7135 Mdot
.58923 .28066 Mdot
.22654 .25684 Mdot
.51783 .58258 Mdot
.6047 .45302 Mdot
.84211 .58231 Mdot
.49342 .82571 Mdot
.37983 .5183 Mdot
.23387 .37343 Mdot
.57938 .22496 Mdot
.75858 .41604 Mdot
.51265 .34872 Mdot
.64149 .80716 Mdot
.78073 .44593 Mdot
.78218 .68971 Mdot
.28458 .75281 Mdot
.35554 .26531 Mdot
.51507 .45939 Mdot
.53428 .6376 Mdot
.62639 .44707 Mdot
.69507 .42343 Mdot
.82121 .61067 Mdot
.55133 .23485 Mdot
.5803 .52983 Mdot
.47529 .75009 Mdot
.57682 .76627 Mdot
.6147 .38718 Mdot
.18191 .50782 Mdot
.2579 .61458 Mdot
.66018 .34672 Mdot
.43368 .79625 Mdot
.71633 .35963 Mdot
.38463 .23303 Mdot
.67211 .27182 Mdot
.32533 .5347 Mdot
.52355 .66208 Mdot
.61508 .65823 Mdot
.77117 .65945 Mdot
.54964 .79191 Mdot
.19743 .57112 Mdot
.80159 .38285 Mdot
.29197 .59778 Mdot
.66698 .42161 Mdot
.72956 .68234 Mdot
.32841 .55611 Mdot
.61902 .69029 Mdot
.61885 .25998 Mdot
.52805 .22932 Mdot
.50923 .79461 Mdot
.45653 .4398 Mdot
.53579 .84661 Mdot
.67029 .30601 Mdot
.77267 .63668 Mdot
.63803 .49357 Mdot
.41854 .30708 Mdot
.29874 .33033 Mdot
.8026 .46803 Mdot
.44188 .55415 Mdot
.88054 .47129 Mdot
.32966 .48996 Mdot
.78053 .70321 Mdot
.47648 .62964 Mdot
.50036 .16333 Mdot
.50691 .80941 Mdot
.45823 .52289 Mdot
.51913 .51921 Mdot
.23353 .61553 Mdot
.31587 .62285 Mdot
.31773 .75587 Mdot
.28877 .50457 Mdot
.60194 .59096 Mdot
.59752 .53331 Mdot
.36031 .69159 Mdot
.7362 .69894 Mdot
.58305 .38805 Mdot
.65187 .5975 Mdot
.60427 .47361 Mdot
.43117 .58786 Mdot
.3496 .79308 Mdot
.49598 .78016 Mdot
.50464 .31146 Mdot
.73105 .36591 Mdot
.83014 .584 Mdot
.47614 .84709 Mdot
.33934 .51688 Mdot
.60061 .32623 Mdot
.41077 .65754 Mdot
.8256 .50248 Mdot
.68959 .74791 Mdot
.54994 .76684 Mdot
.35995 .61203 Mdot
.68555 .31354 Mdot
.76977 .7404 Mdot
.86276 .53455 Mdot
.80899 .38656 Mdot
.52464 .52901 Mdot
.39793 .43239 Mdot
.52267 .2052 Mdot
.7693 .64143 Mdot
.17962 .57889 Mdot
.45441 .81959 Mdot
.71373 .36477 Mdot
.64143 .19704 Mdot
.31012 .2596 Mdot
.63944 .54676 Mdot
.2997 .33121 Mdot
.43131 .31685 Mdot
.49985 .6152 Mdot
.75379 .42273 Mdot
.62492 .52893 Mdot
.44055 .60012 Mdot
.2471 .60657 Mdot
.33194 .62187 Mdot
.77604 .63194 Mdot
.47123 .20566 Mdot
.5942 .31368 Mdot
.70829 .71895 Mdot
.30948 .4084 Mdot
.74169 .63916 Mdot
.79489 .54821 Mdot
.62726 .53469 Mdot
.60114 .59862 Mdot
.4576 .35721 Mdot
.39327 .56602 Mdot
.40739 .57316 Mdot
.73061 .28435 Mdot
.68873 .50317 Mdot
.37035 .48084 Mdot
.26946 .29649 Mdot
.28672 .45946 Mdot
.65199 .8178 Mdot
.3679 .71781 Mdot
.33548 .26693 Mdot
.49478 .58474 Mdot
.52407 .71829 Mdot
.72009 .25837 Mdot
.54975 .25229 Mdot
.71171 .53188 Mdot
.38933 .41848 Mdot
.36666 .46145 Mdot
.49782 .59097 Mdot
.32682 .66933 Mdot
.4223 .23396 Mdot
.185 .45462 Mdot
.79684 .53887 Mdot
.29344 .47848 Mdot
.63454 .54982 Mdot
.45436 .3252 Mdot
.54034 .85366 Mdot
.60821 .59634 Mdot
.87516 .49954 Mdot
.51217 .44911 Mdot
.83316 .47855 Mdot
.35311 .79804 Mdot
.35368 .57739 Mdot
.5321 .53119 Mdot
.57545 .69613 Mdot
.57212 .34386 Mdot
.59779 .31362 Mdot
.33725 .47225 Mdot
.78852 .5991 Mdot
.71859 .47906 Mdot
.76385 .37774 Mdot
.41544 .64514 Mdot
.21775 .41143 Mdot
.18648 .51194 Mdot
.37508 .44698 Mdot
.6515 .52964 Mdot
.68348 .68503 Mdot
.52671 .49542 Mdot
.60232 .47535 Mdot
.77994 .65267 Mdot
.47828 .22743 Mdot
.30975 .48462 Mdot
.8087 .39123 Mdot
.65797 .45211 Mdot
.44539 .85977 Mdot
.43635 .37624 Mdot
.60718 .46482 Mdot
.53608 .49113 Mdot
.23132 .60098 Mdot
.40158 .22799 Mdot
.52684 .81314 Mdot
.72574 .33594 Mdot
.46221 .47392 Mdot
.7045 .38258 Mdot
.48643 .32122 Mdot
.46875 .75119 Mdot
.17464 .54014 Mdot
.65448 .2061 Mdot
.31502 .34893 Mdot
.33655 .59023 Mdot
.30915 .40577 Mdot
.19046 .46637 Mdot
.3427 .49045 Mdot
.66489 .56617 Mdot
.47125 .2413 Mdot
.50601 .8105 Mdot
.49149 .85943 Mdot
.45734 .83362 Mdot
.63716 .43202 Mdot
.56482 .7692 Mdot
.61365 .26856 Mdot
.43601 .36447 Mdot
.47192 .5317 Mdot
.56856 .3385 Mdot
.61103 .39701 Mdot
.35127 .52762 Mdot
.20609 .57929 Mdot
.56992 .45382 Mdot
.5886 .81873 Mdot
.44173 .8568 Mdot
.67373 .78311 Mdot
.6139 .7296 Mdot
.33029 .41332 Mdot
.85435 .56196 Mdot
.37037 .2276 Mdot
.49766 .83556 Mdot
.30106 .38359 Mdot
.15526 .44492 Mdot
.836 .54011 Mdot
.47731 .79241 Mdot
.23851 .4622 Mdot
.23764 .67049 Mdot
.35829 .79505 Mdot
.17111 .40889 Mdot
.6113 .28997 Mdot
.33815 .78358 Mdot
.88059 .46184 Mdot
.31622 .37366 Mdot
.31913 .61974 Mdot
.29063 .32976 Mdot
.59199 .26589 Mdot
.17956 .43978 Mdot
.56606 .42549 Mdot
.55373 .61691 Mdot
.6996 .55175 Mdot
.70817 .35494 Mdot
.44624 .38593 Mdot
.18145 .4266 Mdot
.68992 .42587 Mdot
.66557 .4118 Mdot
.70403 .66021 Mdot
.82661 .55519 Mdot
.41463 .22737 Mdot
.55558 .30579 Mdot
.38576 .43676 Mdot
.72637 .46661 Mdot
.64405 .31526 Mdot
.54866 .41575 Mdot
.48115 .55272 Mdot
.60498 .44644 Mdot
.72094 .76682 Mdot
.69035 .58989 Mdot
.61529 .57169 Mdot
.28296 .43339 Mdot
.25483 .62394 Mdot
.68201 .72469 Mdot
.27372 .57224 Mdot
.19002 .40491 Mdot
.50456 .22631 Mdot
.65479 .77981 Mdot
.31364 .60335 Mdot
.67673 .33509 Mdot
.69193 .2571 Mdot
.48049 .60924 Mdot
.41583 .35056 Mdot
.81505 .61574 Mdot
.27043 .58667 Mdot
.32637 .4073 Mdot
.44243 .7839 Mdot
.49006 .75732 Mdot
.26063 .59324 Mdot
.33341 .76967 Mdot
.71176 .67652 Mdot
.32779 .29842 Mdot
.7351 .71772 Mdot
.54108 .62773 Mdot
.69269 .35075 Mdot
.40987 .76693 Mdot
.17594 .44488 Mdot
.52026 .49324 Mdot
.55276 .83856 Mdot
.47735 .53093 Mdot
.79158 .45071 Mdot
.56855 .38363 Mdot
.44497 .20885 Mdot
.21544 .58557 Mdot
.43249 .79076 Mdot
.24977 .50435 Mdot
.354 .41778 Mdot
.19609 .53343 Mdot
.62449 .67916 Mdot
.77297 .4299 Mdot
.62482 .30692 Mdot
.24435 .42799 Mdot
.6582 .49457 Mdot
.29061 .68034 Mdot
.52174 .44941 Mdot
.79671 .43049 Mdot
.60427 .75245 Mdot
.40586 .36854 Mdot
.33885 .37531 Mdot
.77024 .66253 Mdot
.63361 .73043 Mdot
.19315 .5751 Mdot
.343 .38147 Mdot
.25947 .67156 Mdot
.33242 .24341 Mdot
.26562 .54956 Mdot
.49086 .42013 Mdot
.66464 .56522 Mdot
.2955 .45488 Mdot
.73982 .69894 Mdot
.37917 .48687 Mdot
.78908 .46874 Mdot
.42266 .53037 Mdot
.67504 .71031 Mdot
.62788 .49498 Mdot
.35665 .79865 Mdot
.23763 .67093 Mdot
.72556 .35235 Mdot
.42728 .61672 Mdot
.3814 .6015 Mdot
.31719 .56517 Mdot
.55722 .82308 Mdot
.31817 .52267 Mdot
.50317 .27665 Mdot
.32763 .59321 Mdot
.46166 .27232 Mdot
.30621 .7672 Mdot
.74816 .3812 Mdot
.46803 .53307 Mdot
.53499 .27032 Mdot
.28327 .68685 Mdot
.29072 .66748 Mdot
.70509 .57936 Mdot
.40036 .21833 Mdot
.55117 .58664 Mdot
.56196 .53764 Mdot
.54689 .44565 Mdot
.51442 .20183 Mdot
.72152 .7234 Mdot
.37686 .51506 Mdot
.47034 .52439 Mdot
.78235 .58648 Mdot
.78031 .43093 Mdot
.37677 .15461 Mdot
.76335 .72961 Mdot
.56913 .3848 Mdot
.53443 .51955 Mdot
.76188 .38169 Mdot
.59377 .65633 Mdot
.42655 .24232 Mdot
.76406 .67239 Mdot
.43862 .62705 Mdot
.73681 .61617 Mdot
.33131 .66935 Mdot
.22679 .60855 Mdot
.8041 .47737 Mdot
.49899 .63117 Mdot
.66697 .81329 Mdot
.44548 .81534 Mdot
.21689 .57686 Mdot
.30576 .18764 Mdot
.20521 .55385 Mdot
.41263 .45969 Mdot
.67485 .67971 Mdot
.69222 .77965 Mdot
.51844 .53073 Mdot
.72154 .63556 Mdot
.34598 .37309 Mdot
.72562 .3459 Mdot
.67855 .38081 Mdot
.23905 .52908 Mdot
.20375 .52342 Mdot
.17519 .39381 Mdot
.52586 .71701 Mdot
.74826 .29416 Mdot
.38841 .24528 Mdot
.74455 .71783 Mdot
.35857 .72164 Mdot
.62836 .19004 Mdot
.47999 .85718 Mdot
.72158 .40448 Mdot
.19081 .42173 Mdot
.67668 .65444 Mdot
.76411 .35949 Mdot
.48663 .18992 Mdot
.34079 .73368 Mdot
.48991 .22908 Mdot
.50088 .71864 Mdot
.26012 .52671 Mdot
.70857 .38195 Mdot
.44864 .29034 Mdot
.47197 .5347 Mdot
.79583 .65299 Mdot
.21014 .36539 Mdot
.69988 .31285 Mdot
.75436 .60809 Mdot
.77742 .3735 Mdot
.69923 .73113 Mdot
.61487 .76354 Mdot
.55822 .50008 Mdot
.86135 .43167 Mdot
.82002 .62981 Mdot
.27923 .56066 Mdot
.51301 .42589 Mdot
.45849 .86675 Mdot
.58871 .50417 Mdot
.35613 .37677 Mdot
.38268 .80048 Mdot
.66645 .37748 Mdot
.60053 .4437 Mdot
.51477 .43223 Mdot
.59867 .25581 Mdot
.24434 .44981 Mdot
.44644 .29552 Mdot
.78901 .5148 Mdot
.70474 .31263 Mdot
.21184 .36776 Mdot
.81586 .45189 Mdot
.431 .3943 Mdot
.3034 .47443 Mdot
.70451 .7746 Mdot
.53964 .25873 Mdot
.54497 .28635 Mdot
.30441 .30421 Mdot
.31265 .51774 Mdot
.5247 .67542 Mdot
.60335 .33494 Mdot
.37142 .58133 Mdot
.70353 .35836 Mdot
.75798 .65581 Mdot
.4186 .35942 Mdot
.89025 .42956 Mdot
.35545 .80249 Mdot
.3029 .48714 Mdot
.37991 .36751 Mdot
.63727 .53864 Mdot
.68246 .7744 Mdot
.51382 .706 Mdot
.79435 .54509 Mdot
.25902 .29897 Mdot
.73716 .33296 Mdot
.49659 .33963 Mdot
.35014 .76258 Mdot
.50612 .85036 Mdot
.22516 .32827 Mdot
.53605 .84597 Mdot
.53131 .46117 Mdot
.57753 .4283 Mdot
.5963 .14513 Mdot
.63188 .78525 Mdot
.47098 .43991 Mdot
.24304 .46093 Mdot
.25595 .44012 Mdot
.57539 .37184 Mdot
.3325 .64759 Mdot
.64804 .29212 Mdot
.67681 .39113 Mdot
.60199 .81781 Mdot
.28827 .42997 Mdot
.50915 .5397 Mdot
.46773 .6708 Mdot
.50097 .5261 Mdot
.51819 .30387 Mdot
.43434 .65372 Mdot
.67631 .40213 Mdot
.58082 .51114 Mdot
.43198 .68935 Mdot
.59922 .28654 Mdot
.31675 .69759 Mdot
.60815 .30806 Mdot
.63817 .44474 Mdot
.34193 .39035 Mdot
.35141 .22032 Mdot
.69124 .42446 Mdot
.69447 .43455 Mdot
.33656 .77934 Mdot
.17138 .61743 Mdot
.5043 .56539 Mdot
.40979 .40974 Mdot
.42098 .43228 Mdot
.3887 .22553 Mdot
.31605 .30118 Mdot
.48215 .67406 Mdot
.2941 .66424 Mdot
.55791 .45584 Mdot
.53346 .26717 Mdot
.46876 .66571 Mdot
.74358 .76017 Mdot
.54925 .43348 Mdot
.37523 .26966 Mdot
.54065 .82483 Mdot
.74843 .63401 Mdot
.62999 .37489 Mdot
.57127 .33959 Mdot
.41972 .4761 Mdot
.58911 .50951 Mdot
.47157 .30028 Mdot
.76797 .61858 Mdot
.69658 .75322 Mdot
.63814 .37445 Mdot
.36291 .27004 Mdot
.53941 .36998 Mdot
.75938 .48895 Mdot
.38763 .56134 Mdot
.73473 .29787 Mdot
.72663 .52606 Mdot
.47571 .84378 Mdot
.65442 .43701 Mdot
.66942 .37739 Mdot
.27708 .32268 Mdot
.77692 .70003 Mdot
.316 .5732 Mdot
.34838 .26742 Mdot
.36396 .53566 Mdot
.43448 .7598 Mdot
.70428 .41772 Mdot
.51697 .61061 Mdot
.58258 .44041 Mdot
.25452 .43483 Mdot
.59547 .8341 Mdot
.54769 .25219 Mdot
.47897 .67331 Mdot
.51244 .79646 Mdot
.33286 .24552 Mdot
.51756 .51835 Mdot
.25903 .22484 Mdot
.52634 .69682 Mdot
.67339 .80867 Mdot
.74044 .66157 Mdot
.48928 .47496 Mdot
.24369 .60036 Mdot
.45331 .37548 Mdot
.61365 .63711 Mdot
.68865 .7661 Mdot
.46456 .31618 Mdot
.25722 .54236 Mdot
.56239 .42303 Mdot
.41599 .4936 Mdot
.49922 .28344 Mdot
.54643 .77553 Mdot
.56702 .6049 Mdot
.33055 .51763 Mdot
.61318 .76927 Mdot
.59244 .50874 Mdot
.1507 .47555 Mdot
.82187 .61087 Mdot
.60088 .79919 Mdot
.58807 .75981 Mdot
.50206 .1587 Mdot
.38745 .41847 Mdot
.43846 .35595 Mdot
.44683 .60278 Mdot
.60814 .26306 Mdot
.26347 .58895 Mdot
.76132 .64749 Mdot
.255 .66597 Mdot
.5346 .49705 Mdot
.17943 .3079 Mdot
.71279 .39918 Mdot
.39016 .50532 Mdot
.24587 .57383 Mdot
.57684 .82073 Mdot
.76816 .5673 Mdot
.25743 .70975 Mdot
.36944 .73676 Mdot
.49819 .31493 Mdot
.46366 .19445 Mdot
.81099 .41593 Mdot
.52997 .76165 Mdot
.73869 .27969 Mdot
.56002 .78462 Mdot
.65357 .31485 Mdot
.42492 .78551 Mdot
.28547 .46222 Mdot
.2761 .47549 Mdot
.36716 .70869 Mdot
.32701 .68327 Mdot
.39628 .39664 Mdot
.67732 .75946 Mdot
.63817 .22416 Mdot
.79609 .56109 Mdot
.64993 .79222 Mdot
.39236 .64665 Mdot
.29826 .40757 Mdot
.6831 .42681 Mdot
.67159 .50128 Mdot
.57707 .65595 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0:;ooooo0_l0002Uooooo`007?ooool00ol0003oooooooooo`2Hooooo`;o00002?ooool2o`000:Go
oooo000Looooo`03o`000?oooooooooo09Sooooo0_l0002_ooooo`007?ooool00ol0003ooooooooo
o`27ooooo`;o0000`?ooool001cooooo00?o0000ooooooooool0Qoooool2o`000<3ooooo000Loooo
o`03o`000?oooooooooo0:;ooooo0_l0002Uooooo`007?ooool00ol0003oooooooooo`27ooooo`;o
00002Oooool4o`0000cooooo0_l0000;ooooo`;o00003Oooool2o`0008Wooooo000Looooo`03o`00
0?oooooooooo087ooooo0_l00004ooooo`;o00002Oooool8o`0001Gooooo0_l0000=ooooo`;o0000
ROooool001cooooo0_l00022ooooo`;o00001oooool2o`0000;ooooo0_l00006ooooo`Co00002_oo
ool2o`000:?ooooo000Looooo`03o`000?oooooooooo07Oooooo0_l00006ooooo`;o00002Oooool2
o`0000;ooooo0_l0000Dooooo`;o0000Xoooool001cooooo00?o0000ooooooooool0Moooool2o`00
0003ooooool0003o000000?ooooo0_l0000Nooooo`;o0000Z?ooool001cooooo00?o0000oooooooo
ool0N_ooool2o`0000Oooooo0_l0000Jooooo`;o0000Z?ooool001cooooo00?o0000ooooooooool0
N_ooool2o`0000Oooooo0_l0000Jooooo`;o0000Z?ooool001cooooo00?o0000ooooooooool0Oooo
ool2o`0001kooooo0_l00003ooooo`;o00002?ooool2o`0009Wooooo000Looooo`03o`000?oooooo
oooo07oooooo0_l00003ooooo`;o00007_ooool2o`0000Sooooo0_l0000<ooooo`;o00000oooool3
o`0008Gooooo000Looooo`03o`000?oooooooooo08Cooooo0_l0000fooooo`;o00000oooool3o`00
00Cooooo0_l0001oooooo`007?ooool00ol0003oooooooooo`1Vooooo`;o00004_ooool3o`0004_o
oooo0_l0001oooooo`007?ooool00ol0003oooooooooo`1Vooooo`;o00004_ooool3o`000<cooooo
000Looooo`03o`000?oooooooooo06?ooooo0_l0000@ooooo`;o00006oooool2o`000;Gooooo000L
ooooo`03o`000?oooooooooo063ooooo0_l000000ooooooo0000o`00000@ooooo`;o00006oooool3
o`000;Cooooo000Looooo`03o`000?oooooooooo063ooooo0_l0000Tooooo`;o00002oooool2o`00
00Gooooo0_l0000/ooooo`;o0000Ooooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2
ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo08Kooooo0_l00009ooooo`;o00001oooool3
o`000003ooooool0003o000002Sooooo0_l0001oooooo`0000KoooooogMgMonHV9SooooooiRHV?mg
MgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0
P_ooool2o`0000;ooooo0_l00009ooooo`Co00001_ooool2o`000004ooooool0003o0000o`000:So
oooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h0
1oooool00ol0003oooooooooo`1/ooooo`;o00004Oooool5o`0000;ooooo0_l0000;ooooo`;o0000
2_ooool4o`0002[ooooo0_l0001jooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooooooo
o`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0001Zooooo`Co00002Oooool2o`0000Kooooo1?l0
0009ooooo`;o00004oooool6o`0002Kooooo1?l0001hooooo`0000?oooooo`000?ooool00_ooool0
0ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0J_ooool2
o`0000Oooooo0_l00002ooooo`;o00001Oooool2o`0000cooooo0_l00007ooooo`;o00003?ooool5
o`0002Oooooo1?l0001fooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0=oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Loooool2o`0000Wooooo0_l0000=oooo
o`;o00001_ooool2o`0000Oooooo0_l00006ooooo`;o0000:Oooool2o`0000Sooooo0_l0001/oooo
o`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_oo
ool00ol0003oooooooooo`1cooooo`;o00005_ooool8o`0000Gooooo0_l00004ooooo`;o0000>ooo
ool2o`0006cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c006ooooo`03o`000?oooooooooo077ooooo0_l0000Hooooo`?o000000?oooooo`000?l0
00000_l00005ooooo`;o00001Oooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o
00001?ooool2o`0009Kooooo000Looooo`03o`000?oooooooooo067ooooo0_l0000>ooooo`;o0000
00?oooooo`000?l000002?ooool2o`0000Sooooo0_l0000=ooooo`?o00001?ooool3o`0000?ooooo
0_l000000ooooooo0000o`000002ooooo`;o00001?ooool2o`000003ooooool0003o000009?ooooo
000Looooo`03o`000?oooooooooo067ooooo0_l00006ooooo`;o00000oooool3o`0000?ooooo0_l0
00000ooooooo0000o`000005ooooo`;o00000oooool2o`000003ooooool0003o000000;o00003Ooo
ool3o`0000Cooooo0_l00002ooooo`?o000000Coooooo`000?l0003ooooo0_l00009ooooo`?o0000
T_ooool001cooooo00?o0000ooooooooool0GOooool2o`0000[ooooo0_l000000ooooooo0000o`00
0003o`0000Kooooo0_l0000:ooooo`;o000000?oooooo`000?l000006_ooool6o`000003ooooool0
003o000000[ooooo1?l0000Cooooo`;o0000Noooool001cooooo00?o0000ooooooooool0D?ooool2
o`0000_ooooo0_l0000=ooooo`;o00001oooool2o`0000;ooooo1?l00006ooooo`;o00001Oooool2
o`0000cooooo0_l00006ooooo`;o00000_ooool2o`0000Cooooo0_l0000;ooooo`?o00004_ooool3
o`0007[ooooo000Looooo`03o`000?oooooooooo053ooooo0_l0000Sooooo`;o00000_ooool5o`00
0003ooooool0003o000000;ooooo0_l00005ooooo`;o00003?ooool2o`000003ooooool0003o0000
00?ooooo0_l000000ooooooo0000o`000002ooooo`Go00003?ooool2o`0000;ooooo0_l0000?oooo
o`Co00002Oooool2o`0006gooooo000Looooo`03o`000?oooooooooo07Wooooo1Ol000001?oooooo
0000o`000?ooool2o`0000Wooooo0_l0000<ooooo`;o00001_ooool7o`0001;ooooo0_l0000@oooo
o`?o00002Oooool3o`0006cooooo000Looooo`03o`000?oooooooooo07Oooooo1?l00005ooooo`Co
000000?oooooo`000?l000001_ooool2o`0001Kooooo1?l00006ooooo`;o00003_ooool2o`0000go
oooo0_l0000;ooooo`?o00001Oooool2o`0006Cooooo000Looooo`03o`000?oooooooooo05Kooooo
0_l0000<ooooo`;o00001oooool2o`0000Sooooo0_l00006ooooo`?o00000oooool2o`0000Oooooo
0_l00004ooooo`;o00004?ooool2o`0000Oooooo0_l0000>ooooo`?o00004oooool2o`0000Gooooo
0_l00005ooooo`;o0000I?ooool001cooooo00?o0000ooooooooool0Boooool2o`0000Wooooo0_l0
000<ooooo`;o00001oooool2o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`0000Kooooo0_l0
0005ooooo`;o00001?ooool4o`0001cooooo0_l0000:ooooo`Co00004Oooool2o`0007;ooooo000L
ooooo`03o`000?oooooooooo04_ooooo0_l00008ooooo`;o00004Oooool2o`0000?ooooo0_l00002
ooooo`Co00001?ooool3o`0000_ooooo0_l0000<ooooo`?o00006_ooool4o`0000cooooo0_l0000N
ooooo`;o0000IOooool001cooooo00?o0000ooooooooool0EOooool2o`00017ooooo0_l00007oooo
o`;o00001oooool2o`0000?ooooo0_l00002ooooo`;o00008_ooool2o`0000Gooooo0_l00002oooo
o`;o00006Oooool2o`0001?ooooo0_l0001Uooooo`007?ooool2o`0006Sooooo0_l00003ooooo`;o
00000_ooool2o`0000gooooo0_l00002ooooo`;o00005Oooool4o`0000Wooooo0_l00005ooooo`?o
00004_ooool4o`0000Kooooo0_l00007ooooo`?o0000L?ooool001cooooo00?o0000ooooooooool0
Ioooool2o`0000?ooooo0_l00002ooooo`;o0000:?ooool4o`00013ooooo1?l0000:ooooo`;o0000
1Oooool4o`0000oooooo0ol0001`ooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00000_oo
ool2o`0001Kooooo0_l0000:ooooo`So00008oooool2o`0001Cooooo0ol00002ooooo`;o00002_oo
ool2o`000003ooooool0003o000000Cooooo1?l0000Dooooo`;o00001oooool2o`00067ooooo000L
ooooo`03o`000?oooooooooo04;ooooo0_l00002ooooo`;o00005?ooool4o`000003ooooool0003o
000000Oooooo0ol000000ooooooo0000o`00000Uooooo`Co00004_ooool3o`00017ooooo0_l00004
ooooo`Co000000?oooooo`000?l000000_ooool2o`0000gooooo0_l00007ooooo`;o0000HOooool0
01cooooo00?o0000ooooooooool0G?ooool2o`0000?ooooo0_l0000:ooooo`;o00001oooool2o`00
01oooooo0_l0000Cooooo`;o00002_ooool2o`0000Kooooo1?l000000ooooooo0000o`000009o`00
00Cooooo0_l0001cooooo`007?ooool00ol0003oooooooooo`1Looooo`;o000000Coooooo`000?l0
003o00001oooool2o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`;o0000<_ooool2o`00
00cooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l00002ooooo`Co00000_ooool2o`00
00;ooooo0_l00002ooooo`;o00003_ooool2o`0006?ooooo000Looooo`03o`000?oooooooooo05oo
oooo0ol00006ooooo`?o00000_ooool2o`000003ooooool0003o000000;o00000_ooool2o`0002Go
oooo0_l0000;ooooo`;o00004Oooool2o`0000Gooooo1?l000000ooooooo0000o`000005ooooo`;o
00000_ooool2o`0000kooooo0ol0001Rooooo`007?ooool00ol0003oooooooooo`1Xooooo`;o0000
1_ooool4o`0000;ooooo0_l0000Jooooo`;o00002Oooool2o`0000_ooooo0_l000000ooooooo0000
o`000002o`0001?ooooo0_l00003ooooo`Co00000_ooool2o`0000Kooooo0_l00002ooooo`;o0000
2?ooool2o`0006;ooooo000Looooo`03o`000?oooooooooo06?ooooo0_l0000;ooooo`;o00007Ooo
ool5o`0000Cooooo0_l00006ooooo`;o00001?ooool2o`0000Gooooo1?l00008ooooo`;o00001Ooo
ool2o`0000Wooooo0_l00002ooooo`;o00001?ooool4o`0000;ooooo0ol0001[ooooo`007?ooool0
0ol0003oooooooooo`1Iooooo`;o00001oooool3o`0002[ooooo1Ol00004ooooo`;o00001_ooool2
o`0000Cooooo0_l0000Aooooo`;o00001Oooool2o`0000gooooo0ol00002ooooo`Oo000000?ooooo
o`000?l000003_ooool2o`0005_ooooo000Looooo`03o`000?oooooooooo05Wooooo0_l00007oooo
o`;o0000<Oooool2o`0000Wooooo0_l000000ooooooo0000o`000002ooooo`?o00004_ooool2o`00
00Cooooo0_l00005ooooo`;o00001Oooool?o`0000gooooo0_l0001Kooooo`007?ooool00ol0003o
ooooooooo`1Hooooo`;o00000oooool2o`0000?ooooo0_l00007ooooo`;o0000:?ooool2o`0000Oo
oooo0_l00003ooooo`;o00000_ooool3o`0001;ooooo0_l00004ooooo`;o00001Oooool2o`0000Oo
oooo1_l00003ooooo`Go00002_ooool2o`0005gooooo000Looooo`03o`000?oooooooooo05Sooooo
0_l00003ooooo`Co000000?oooooo`000?l000001oooool2o`0002Cooooo0_l0000;ooooo`;o0000
2_ooool5o`00013ooooo0_l0000Fooooo`;o00001Oooool2o`0000?ooooo0_l000000ooooooo0000
o`000002ooooo`;o0000GOooool001cooooo00?o0000ooooooooool0F_ooool3o`0000;ooooo0_l0
00000ooooooo0000o`00000Zooooo`;o000000?oooooo`000?l000003_ooool2o`0000Gooooo1ol0
000:ooooo`;o00001?ooool2o`0000;ooooo0_l00008ooooo`Co00000_ooool2o`0000;ooooo0_l0
0009ooooo`Ko0000HOooool001cooooo00?o0000ooooooooool0F_ooool3o`0000;ooooo0_l00000
0ooooooo0000o`00000Yooooo`Ko00002?ooool2o`0000Cooooo0_l000000ooooooo0000o`000002
ooooo`;o00003oooool2o`0000Sooooo0_l00008ooooo`Co00000_ooool6o`0000Wooooo0_l00000
0ooooooo0000o`000008ooooo`;o0000F?ooool001cooooo00?o0000ooooooooool0>_ooool3o`00
01Oooooo0_l00009ooooo`;o00001_ooool2o`0000Sooooo0_l0000Jooooo`Go00002Oooool2o`00
00;ooooo1ol000000ooooooo0000o`000006ooooo`;o00005?ooool2o`0000Oooooo0_l00005oooo
o`Co00002Oooool2o`0000Oooooo1ol0001Gooooo`007?ooool2o`0003_ooooo0ol0000Cooooo`;o
00000_ooool2o`0000Gooooo1_l00002ooooo`;o00000_ooool2o`0000Sooooo0_l0000Looooo`;o
00001?ooool2o`0000Sooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l00005ooooo`;o
00001oooool2o`0000_ooooo0_l00007ooooo`;o00000oooool4o`0001Cooooo1?l000000ooooooo
0000o`00001Gooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00000_ooool2o`000003oooo
ool0003o000000;ooooo1_l00002ooooo`;o0000<?ooool2o`0000kooooo1Ol00004ooooo`;o0000
1_ooool4o`0000Cooooo0_l0000>ooooo`;o00000oooool4o`0000Oooooo0_l00003ooooo`Co0000
H_ooool001cooooo00?o0000ooooooooool0C_ooool3o`0000Kooooo0_l00002ooooo`;o00000_oo
ool2o`00013ooooo0_l0000Aooooo`?o00001Oooool2o`0001Gooooo1_l00005ooooo`Go00000_oo
ool3o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000001?oo
ool2o`0000Oooooo0ol00005ooooo`;o00000oooool4o`0006;ooooo000Looooo`03o`000?oooooo
oooo03Oooooo0_l0000Eooooo`Go00002?ooool2o`0001;ooooo1?l0000Aooooo`?o00001?ooool3
o`0001Gooooo0ol000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000000_l00002
ooooo`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`Ko000000?oooooo`000?l000001?oo
ool2o`0000Oooooo0ol00002ooooo`;o00000oooool2o`0000Oooooo0_l0001Nooooo`007?ooool0
0ol0003oooooooooo`0gooooo`;o00005Oooool2o`000003ooooool0003o000001Gooooo0_l00005
ooooo`;o00006_ooool2o`0000Sooooo0_l000000ooooooo0000o`000006ooooo`;o00000_ooool2
o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000007ooooo`Co000000?ooooo
o`000?l000001_l0000;ooooo`Co00001oooool2o`0000?ooooo0ol00006ooooo`Co0000G?ooool0
01cooooo00?o0000ooooooooool0J?ooool2o`0001kooooo0ol00003ooooo`;o00000oooool4o`00
0003ooooool0003o000000Cooooo3Ol00004ooooo`?o00001_ooool4o`000005ooooool0003o0000
o`000?ooool01?l00008ooooo`;o000000?oooooo`000?l000000_l00007ooooo`;o00000oooool3
o`0000Gooooo1Ol0001Looooo`007?ooool00ol0003oooooooooo`27ooooo`Co00000oooool2o`00
00?ooooo0_l00005ooooo`;o000000?oooooo`000?l000001Ol00002ooooo`Go000000Coooooo`00
0?l0003ooooo1?l00005ooooo`?o00002?ooool6o`0000Cooooo1ol0000Dooooo`Co00003Oooool2
o`0004kooooo000Looooo`03o`000?oooooooooo04cooooo0_l000000ooooooo0000o`000002o`00
00?ooooo0_l000000ooooooo0000o`00000/ooooo`Co000000?oooooo`000?l000002oooool3o`00
0003ooooool0003o000000Go00000oooool4o`000004ooooool0003o0000ooooo`Co00001?ooool3
o`0000;ooooo0_l00007ooooo`Co00001_ooool3o`0000Cooooo0_l0000=ooooo`;o00002_ooool2
o`0000Kooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`18ooooo`;o00000_ooool2o`00
0003ooooool0003o000000;o00000oooool2o`000003ooooool0003o000001;ooooo0_l0000Goooo
o`;o00001?ooool2o`0000;ooooo0_l00007ooooo`Co00000oooool2o`0000;ooooo1ol00002oooo
o`Go00000oooool6o`000004ooooool0003o0000ooooo`;o00003oooool4o`0000;ooooo0_l0000=
ooooo`;o00000_ooool5o`0000?ooooo0_l00002ooooo`;o0000D_ooool001cooooo00?o0000oooo
ooooool0AOooool2o`000003ooooool0003o000000Oooooo0_l00003ooooo`;o00005Oooool2o`00
01Oooooo0_l00007ooooo`Co00002?ooool2o`0000Oooooo1?l000001?oooooo0000o`000?ooool6
o`0000?ooooo0_l000000ooooooo0000o`000002o`0000?ooooo0ol0000@ooooo`;o00004oooool7
o`0000Oooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`15ooooo`;o00000_ooool2o`00
00_ooooo0_l00003ooooo`Go00008oooool2o`000003ooooool0003o000000Oooooo1?l00003oooo
o`;o00000oooool2o`0000;ooooo0_l00004ooooo`?o000000?oooooo`000?l000001ol00002oooo
o`So00001?ooool2o`0000Cooooo0ol00008ooooo`;o00005?ooool2o`0000?ooooo0_l0001Koooo
o`007?ooool00ol0003oooooooooo`19ooooo`;o00004?ooool5o`0002;ooooo0ol0000Aooooo`;o
000000?oooooo`000?l000000ooooolDo`0000;ooooo2?l00004ooooo`;o00001?ooool3o`0000So
oooo0_l00002ooooo`;o000000?oooooo`000?l000001?ooool2o`0000_ooooo0ol00007ooooo`;o
0000D_ooool001cooooo00?o0000ooooooooool0BOooool2o`000003ooooool0003o000000?ooooo
0_l00002ooooo`;o00002_ooool2o`000003ooooool0003o000000Gooooo0_l0000Eooooo`;o0000
4oooool4o`0000?ooooo5?l000000ooooooo0000o`000002o`0000;ooooo1_l000001?oooooo0000
o`000?l0000Booooo`;o000000?oooooo`000?l000001?ooool2o`0000Oooooo0ol000000ooooooo
0000o`000003o`0000Gooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`19ooooo`;o0000
00?oooooo`000?l000000oooool2o`0000;ooooo0_l0000:ooooo`;o000000?oooooo`000?l00000
1Oooool2o`00013ooooo0_l00003ooooo`;o00001Oooool2o`0000cooooo1Ol000000ooooooo0000
o`00000Ko`000003ooooool0003o000000;o00000_ooool2o`000003ooooool0003o000000Cooooo
0_l0000Kooooo`?o000000Coooooo`000?l0003ooooo1?l0001Gooooo`007?ooool00ol0003ooooo
ooooo`18ooooo`;o00004oooool2o`0000Gooooo0_l00002ooooo`;o00004oooool2o`0000[ooooo
0_l00005ooooo`;o00000ooooolPo`000003ooooool0003o000000;o000000Goooooo`000?l0003o
0000ooooo`02o`000003ooooool0003o000000;o00001?ooool4o`0001Sooooo0ol00005ooooo`Co
0000Eoooool001cooooo00?o0000ooooooooool0B?ooool2o`0000kooooo0_l00003ooooo`;o0000
2Oooool2o`0001Sooooo0_l0000<ooooo`;o000000?oooooo`000?l000008?l000001?oooooo0000
o`000?l00003ooooo`Go000000?oooooo`000?l000002?ooool2o`0000Gooooo0_l00007ooooo`;o
00000oooool2o`000003ooooool0003o000000Co0000Goooool001cooooo0_l0001@ooooo`;o0000
0oooool2o`0000;ooooo0_l00006ooooo`;o000000?oooooo`000?l000007Oooool3o`0000kooooo
1Ol00002oooooaco000000?oooooo`000?l000000_ooool5o`0000[ooooo1?l00005ooooo`;o0000
1oooool3o`0000;ooooo0_l000001?oooooo0000o`000?ooool3o`0000Sooooo0_l0001Eooooo`00
7?ooool00ol0003oooooooooo`13ooooo`?o00002Oooool2o`0000?ooooo0_l0000:ooooo`;o0000
00?oooooo`000?l000007_ooool4o`0000[ooooo1Ol00004oooooaco00000_ooool7o`0000?ooooo
0_l00006ooooo`Co00003oooool2o`0000Kooooo0_l000000ooooooo0000o`000008ooooo`;o0000
EOooool001cooooo00?o0000ooooooooool0:oooool2o`0001Kooooo0ol00008ooooo`Co00000_oo
ool2o`0002Kooooo0ol00004ooooo`Co00001?ooool2o`0000Cooooo1?l00004ooooobKo00000ooo
ool2o`0000kooooo0_l0000>ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Rooooo`;o0000
>oooool001cooooo00?o0000ooooooooool0:oooool2o`0001cooooo0_l00003ooooo`Co00000_oo
ool2o`0002Kooooo0ol00005ooooo`;o00001Oooool2o`0000Cooooo0_l00003ooooo`;o000000?o
ooooo`000?l000007Ol000000ooooooo0000o`000004o`00017ooooo1?l0000=ooooo`Ko00003Ooo
ool2o`0001Kooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00001Oooool2
o`0002[ooooo0_l00006ooooo`Co00001?ooool2o`0000?ooooo0_l00003ooooo`;o00000_oooolR
o`0000cooooo1?l00004ooooo`;o000000?oooooo`000?l000003?ooool6o`0000Gooooo0_l00006
ooooo`;o00002?ooool2o`0004Wooooo000Looooo`03o`000?oooooooooo03kooooo0_l000000ooo
oooo0000o`00000=ooooo`;o00005Oooool2o`0000Kooooo0_l000000ooooooo0000o`00000Boooo
o`;o00000_ooool4o`0000Cooooo0_l00002ooooobKo00003?ooool4o`0000Oooooo0_l00002oooo
o`;o00002?ooool5o`0000;ooooo1_l0000@ooooo`;o0000BOooool001cooooo00?o0000oooooooo
ool0?_ooool2o`000003ooooool0003o000002Cooooo0_l00006ooooo`;o000000?oooooo`000?l0
00001?ooool2o`0000Gooooo0ol00008ooooo`;o00000oooool2o`000003ooooool0003o000000So
000000?oooooo`000?l000007Ol0000Kooooo`;o00001oooool2o`0000;ooooo0_l00002ooooo`Co
00001?ooool2o`0005Oooooo000Looooo`03o`000?oooooooooo047ooooo0_l0000eooooo`;o0000
00?oooooo`000?l000000_ooool3o`0000gooooo0_l000000ooooooo0000o`00000Uo`000003oooo
ool0003o000000;o00002?ooool2o`0000oooooo1?l00005ooooo`;o00000oooool2o`0000Gooooo
0_l00002ooooo`;o0000Eoooool001cooooo00?o0000ooooooooool0B?ooool2o`0001Sooooo0ol0
0005ooooo`;o000000?oooooo`000?l000003?ooool2o`0000;ooooo0_l0000>ooooo`Go00000_oo
oolXo`000003ooooool0003o000000Gooooo0_l000001?oooooo0000o`000?ooool2o`0000Wooooo
1?l0000:ooooo`;o00001Oooool2o`0000_ooooo0_l0001>ooooo`007?ooool00ol0003ooooooooo
o`0oooooo`;o00001oooool3o`0001Oooooo0ol00005ooooo`Go000000?oooooo`000?l000000_l0
0005ooooo`;o00001Oooool2o`0000Sooooo0ol00002ooooo`Ko000000?oooooo`000?l00000:Ol0
0003ooooo`;o00000oooool2o`000003ooooool0003o000000;o00001Oooool3o`0000[ooooo0_l0
0008ooooo`?o00000_ooool2o`000003ooooool0003o000000?ooooo1?l0001<ooooo`007?ooool0
0ol0003oooooooooo`0mooooo`Co00002?ooool5o`0000Cooooo0_l0000Fooooo`Go000000?ooooo
o`000?l000001?l00003ooooo`;o00001Oooool2o`0000Cooooo0_l00002ooooo`?o00001?ooool4
o`000003ooooool0003o000002Wo00000oooool2o`0000Sooooo0_l00005ooooo`?o000000?ooooo
o`000?l000001_ooool3o`0000Sooooo1ol000000ooooooo0000o`000005ooooo`;o0000C?ooool0
01cooooo00?o0000ooooooooool0?Oooool2o`0000;ooooo0_l00007ooooo`Co00001?ooool3o`00
00Wooooo0_l0000:ooooo`Go00001Oooool2o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`00
0003ooooool0003o000000;ooooo0_l00005ooooo`Co00000_ooool2o`0000;ooooo8Ol00006oooo
o`;o000000?oooooo`000?l000004_ooool3o`0000Gooooo1Ol00002ooooo`;o00001Oooool3o`00
00;ooooo0_l0000;ooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0@Oooool2o`0000co
oooo0_l00002ooooo`;o00001oooool4o`00013ooooo0_l00006ooooo`;o00001Oooool2o`0000;o
oooo1?l00003ooooo`Go000000Coooooo`000?l0003o00000oooool4o`000003ooooool0003o0000
00[o000000?oooooo`000?l000003Ol000000ooooooo0000o`000002o`0000Kooooo1Ol0000Boooo
o`?o00001Oooool5o`0000;ooooo0_l00006ooooo`;o00001oooool5o`0000?ooooo1?l00014oooo
o`007?ooool00ol0003oooooooooo`1?ooooo`;o00002oooool2o`0000?ooooo0_l00007ooooo`?o
00000oooool2o`0000?ooooo0_l0000>ooooo`Co00000oooool8o`0000;ooooo9_l000000ooooooo
0000o`000005ooooo`;o00006_ooool3o`0000Cooooo0_l0000@ooooo`Go00001Oooool2o`0004Co
oooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@oooo
ooooool01?ooool00ol0003oooooooooo`0eooooo`;o00002_ooool2o`0001kooooo0_l00007oooo
o`?o00002?ooool2o`0000Sooooo0ol00005ooooo`;o00001Oooool2o`0000;ooooo0_l000001?oo
oooo0000o`000?oooolWo`000003ooooool0003o000000;ooooo0_l0000Booooo`;o00001_ooool3
o`0000Cooooo0_l00004ooooo`?o00002Oooool3o`0000Kooooo0ol00014ooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo03Gooooo0_l00002ooooo`;o00001_ooool2o`00017ooooo1?l00004ooooo`Co00003Ooo
ool2o`0000?ooooo1Ol00006ooooo`Go00001_ooool2o`0000Oooooo0_l00002oooooago000000?o
ooooo`000?l000002_l000001?oooooo0000o`000?ooool2o`0000[ooooo0_l00007ooooo`;o0000
4oooool3o`0000[ooooo1?l00004ooooo`?o0000A?ooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02Oooool5o`0000Kooooo00?o0000ooooooooool0>Oooool2o`0000Gooooo0_l0
000Booooo`Ko00000_ooool4o`0000_ooooo1?l00003ooooo`?o00000_ooool2o`0000Cooooo0_l0
0009ooooo`;o00001oooool5o`000003ooooool0003o000001Wo000000?oooooo`000?l000000_l0
0002ooooo`Oo00000oooool2o`0000Gooooo0_l00003ooooo`;o00004?ooool2o`000003ooooool0
003o000000;ooooo0_l00008ooooo`;o00002?ooool2o`0004_ooooo00000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`00043ooooo0ol0
0004ooooo`;o00002_ooool2o`0000?ooooo0_l00004ooooo`;o00002oooool2o`0000[ooooo0_l0
000Fooooo`Oo000000Goooooo`000?l0003o0000ooooo`06o`000003ooooool0003o000000ko0000
00?oooooo`000?l000000ol000000ooooooo0000o`000005o`0000Oooooo0_l000000ooooooo0000
o`00000<ooooo`;o00001oooool2o`000003ooooool0003o000000;ooooo1?l00006ooooo`;o0000
0_ooool2o`0000;ooooo0_l0001=ooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooooooo
o`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0>_ooool2o`0000Gooooo
0_l00004ooooo`;o00001_ooool2o`0000;ooooo0_l00007ooooo`Co000000?oooooo`000?l00000
1?l00007ooooo`;o00002_ooool2o`0001?ooooo0_l00005ooooob[o00001oooool2o`0000oooooo
0_l0000=ooooo`;o000000?oooooo`000?l000001Oooool2o`000003ooooool0003o000000;o0000
0_ooool2o`0004gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?o
MgMgolc<c?l000001oooool00ol0003oooooooooo`0dooooo`;o00001?ooool2o`0000Cooooo0_l0
000=ooooo`;o00002Oooool5o`0000;ooooo1ol00006ooooo`;o000000?oooooo`000?l000000_l0
0005ooooo`;o00005?ooool4o`0000;ooooo:_l0000Eooooo`;o00004?ooool2o`0000Sooooo0_l0
00001?oooooo0000o`000?ooool3o`0004oooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`co
oooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0dooooo`;o00001Oooool2o`000003
ooooool0003o000000;o000000?oooooo`000?l000002oooool2o`0000Sooooo2Ol00003ooooo`;o
000000?oooooo`000?l000001?ooool6o`0000cooooo0_l0000<ooooo`Go00001_oooolPo`000004
ooooool0003o0000o`00013ooooo0_l00004ooooo`?o00006oooool2o`0000;ooooo1?l0001?oooo
o`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000
ooooooooool08_ooool2o`0001Cooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l0
000;ooooo`?o00002Oooool2o`000003ooooool0003o000000;ooooo2Ol00003ooooo`;o00001ooo
ool2o`0000Oooooo0_l0000<ooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo7Ol0
0002ooooo`?o00002?ooool2o`0000Kooooo0_l00004ooooo`;o00007?ooool2o`0000;ooooo1?l0
0004ooooo`;o0000BOooool001cooooo00?o0000ooooooooool08_ooool2o`0001Cooooo0_l0000G
ooooo`;o00001Oooool2o`0000;ooooo0_l00003oooooa3o00000_ooool3o`0000;ooooo1Ol0000:
ooooo`;o00002Oooool2o`0000?ooooo1?l000000ooooooo0000o`00000Jo`0000?ooooo0_l00009
ooooo`Co00005oooool2o`00013ooooo0_l00007ooooo`Co00001?ooool2o`0004?ooooo000Loooo
o`03o`000?oooooooooo037ooooo0_l00007ooooo`;o00002Oooool2o`0000oooooo1?l00002oooo
oaGo00000_ooool3o`0000Cooooo0ol0000:ooooo`;o00001Oooool2o`0000Wooooo8Ol0000>oooo
o`;o00001Oooool2o`0000Cooooo0_l00008ooooo`Co00004?ooool2o`0000?ooooo0_l00002oooo
o`;o00001_ooool2o`0004?ooooo000Looooo`03o`000?oooooooooo037ooooo0_l00007ooooo`;o
00002Oooool2o`0000_ooooo0_l00002ooooo`;o00000ooooolHo`0000?ooooo0_l0000Fooooo`;o
00000_ooool4o`0000Cooooo4Ol000000ooooooo0000o`00000<o`0000Cooooo0_l00002ooooo`;o
00002oooool2o`0000Cooooo0_l00006ooooo`Ko00003_ooool2o`0000Gooooo1?l00002ooooo`;o
0000BOooool001cooooo00?o0000ooooooooool0=oooool2o`0001?ooooo0_l00004ooooo`;o0000
1oooool5o`000003ooooool0003o000001;o000000Coooooo`000?l0003o00000_ooool2o`0001?o
oooo2?l00002oooooa7o00000_ooool<o`0000Gooooo0_l00002ooooo`;o00002oooool2o`0000Wo
oooo1_l00008ooooo`;o00001oooool2o`0000Oooooo0_l00002ooooo`;o0000BOooool001cooooo
00?o0000ooooooooool0=oooool2o`0001?ooooo0_l00006ooooo`;o00001?oooolKo`0000;ooooo
0ol000001?oooooo0000o`000?l00007ooooo`;o00002Oooool2o`0000;ooooo1_l000000ooooooo
0000o`000005o`000003ooooool0003o000000ko000000?oooooo`000?l000001?l00002ooooo`;o
00004Oooool2o`0000Wooooo1?l0000:ooooo`;o00000_ooool2o`0000Wooooo0_l000000ooooooo
0000o`000003ooooo`;o00001Oooool2o`0001Gooooo0_l0000Zooooo`007?ooool00ol0003ooooo
ooooo`1Aooooo`;o000000?oooooo`000?l000000_oooolNo`000004ooooool0003o0000o`0000;o
oooo1?l00005ooooo`;o00003?ooool2o`0000?ooooo0ol000000ooooooo0000o`00000Eo`000005
ooooool0003o0000o`000?ooool00_l000001?oooooo0000o`000?l0000=ooooo`;o00004Oooool2
o`0000Oooooo0_l000000ooooooo0000o`000002o`0000Wooooo0_l000000ooooooo0000o`000005
o`0000Gooooo0_l00004ooooo`;o00001_ooool2o`0000Oooooo0_l0000Zooooo`007?ooool00ol0
003oooooooooo`0Oooooo`;o0000;_ooool4o`000003ooooool0003o000000Co00000_ooool@o`00
0003ooooool0003o000000go000000Coooooo`000?l0003o00001Oooool2o`0000cooooo0_l00003
ooooo`?o00000_ooool?o`000003ooooool0003o000000Co00000_ooool2o`000004ooooool0003o
0000ooooo`;o00002_ooool2o`0000;ooooo0_l00004ooooo`;o00002oooool2o`0000Oooooo0_l0
00000ooooooo0000o`00000@ooooo`?o00003Oooool3o`0000Gooooo0_l00007ooooo`;o0000:_oo
ool001cooooo00?o0000ooooooooool07oooool2o`0001Kooooo0_l00009ooooo`;o00001_ooool2
o`0000?ooooo0_l00003ooooo`Co00000ooooolIo`000003ooooool0003o000000Go00005Oooool2
o`000004ooooool0003o0000o`0000Kooooo0_l00003ooooo`;o000000?oooooo`000?l000000ooo
ool2o`000003ooooool0003o000000Go00000oooool2o`0000gooooo0ol00008ooooo`;o00001_oo
ool2o`0000?ooooo0_l0000Jooooo`;o00000_ooool2o`0000;ooooo0_l00009ooooo`;o0000>_oo
ool001cooooo00?o0000ooooooooool0=oooool2o`0000Wooooo0_l00006ooooo`;o00000oooool2
o`0000?ooooo0_l00002ooooobCo00001_ooool2o`0000gooooo1_l00003ooooo`;o000000?ooooo
o`000?l000001?ooool4o`0000Sooooo0_l000000ooooooo0000o`000003ooooo`Co00002oooool2
o`00017ooooo0_l0000Oooooo`;o00000_ooool2o`0000;ooooo0_l00015ooooo`007?ooool00ol0
003oooooooooo`0_ooooo`;o00000oooool3o`0001?ooooo0_l0000:ooooo`Ko000000?oooooo`00
0?l000004?l000000ooooooo0000o`00000:o`0000Kooooo1?l0000=ooooo`Wo00000oooool2o`00
00;ooooo0_l00005ooooo`;o000000?oooooo`000?l000000ol00003ooooo`;o00000_ooool2o`00
00Cooooo1ol00006ooooo`;o0000;?ooool2o`0001oooooo0_l0000/ooooo`007?ooool00ol0003o
ooooooooo`0_ooooo`;o00000oooool3o`00017ooooo1?l00006ooooo`;o00000_oooolIo`000003
ooooool0003o000000Oo00002Oooool4o`000003ooooool0003o000000_ooooo1_l00005ooooo`;o
000000?oooooo`000?l000001?l00002ooooo`;o000000?oooooo`000?l000000ol00003ooooo`?o
00001oooool7o`000004ooooool0003o0000o`0000;ooooo0_l00005ooooo`;o000000?oooooo`00
0?l000008_ooool2o`0001Wooooo0_l00004ooooo`;o0000;?ooool001cooooo0_l00018ooooo`?o
000000Coooooo`000?l0003o00001?ooool2o`0000?ooooo9?l00008ooooo`;o00000_ooool2o`00
01;ooooo0_l00004ooooo`Oo00001Oooool2o`0000Kooooo0ol0000?ooooo`?o00002?ooool3o`00
0003ooooool0003o000000oooooo0_l0000Dooooo`;o00001_ooool2o`0000kooooo0_l0000boooo
o`007?ooool00ol0003oooooooooo`0Mooooo`;o00005Oooool2o`0000;ooooo0_l0000=ooooo`;o
00000_ooool3o`0000Sooooo0_l00002ooooob7o00001_ooool4o`0001Kooooo0_l00004ooooo`;o
00002?ooool4o`0000Kooooo0_l0000:ooooo`;o000000?oooooo`000?l000003?ooool2o`0000_o
oooo0_l00002ooooo`;o00000_ooool2o`0001Cooooo0_l00006ooooo`;o0000@_ooool001cooooo
00?o0000ooooooooool07Oooool2o`0001Gooooo0_l00002ooooo`?o00004oooool2o`0000Kooooo
0_l00004oooooa_o000000?oooooo`000?l000001oooool4o`0000Wooooo0_l00009ooooo`;o0000
2Oooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00002ooooo`;o0000
0_ooool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000006ooooo`;o0000
3_ooool2o`000003ooooool0003o000000;ooooo0_l0000Fooooo`;o0000C?ooool001cooooo00?o
0000ooooooooool0>Oooool2o`0000Sooooo0_l00006ooooo`;o000000?oooooo`000?l000000_l0
0005ooooo`Go000000?oooooo`000?l000006?l000001?oooooo0000o`000?l00007ooooo`Go0000
1oooool4o`0000Oooooo0ol00008ooooo`?o000000Coooooo`000?l0003o00000oooool2o`000003
ooooool0003o000000Gooooo0ol000001?oooooo0000o`000?ooool2o`0000_ooooo1?l00008oooo
o`;o00000_ooool2o`0000Kooooo0_l000000ooooooo0000o`000002o`0000kooooo1?l0000Moooo
o`;o0000;Oooool001cooooo00?o0000ooooooooool0>_ooool2o`0000Oooooo0_l00005ooooo`?o
00000oooool2o`000004ooooool0003o0000ooooobGo00001oooool7o`0000Oooooo0_l00006oooo
o`Co00002?ooool3o`000004ooooool0003o0000o`0000?ooooo0_l00005ooooo`;o000000?ooooo
o`000?l000001Oooool6o`0000Wooooo0_l00008ooooo`Co000000Coooooo`000?l0003ooooo2ol0
00001?oooooo0000o`000?ooool3o`0000Oooooo0_l0000Fooooo`;o00001oooool3o`0002cooooo
000Looooo`03o`000?oooooooooo01_ooooo0_l0000Mooooo`;o00003_ooool2o`0000Oooooo8Ol0
00000ooooooo0000o`000005o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`0000Oooooo0_l0
0004ooooo`Go00001Oooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000Wooooo
0_l000001?oooooo0000o`000?l00004ooooo`Ko00005?oooolEo`000004ooooool0003o0000o`00
00oooooo0_l00007ooooo`;o00001Oooool2o`0000Sooooo0_l0000/ooooo`007?ooool00ol0003o
ooooooooo`0Kooooo`;o00007Oooool2o`0000oooooo0_l00002ooooo`Co000000Goooooo`000?l0
003o0000ooooo`04o`000003ooooool0003o000000Ko000000?oooooo`000?l000003ol00003oooo
o`?o000000Coooooo`000?l0003o00000_ooool2o`0000Wooooo0_l00006ooooo`;o00000_ooool2
o`0000Cooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l0000=ooooo`;o00000_oo
ool2o`0000Wooooo0_l0000AoooooaKo00003?ooool2o`0000;ooooo0_l00007ooooo`;o0000?Ooo
ool001cooooo00?o0000ooooooooool0Boooool3o`000003ooooool0003o000000;o00000_ooool2
o`000004ooooool0003o0000o`0000;ooooo7?l00002ooooo`;o000000?oooooo`000?l000002_oo
ool2o`000004ooooool0003o0000o`0000;ooooo0_l00006ooooo`;o00000_ooool4o`0000Gooooo
0_l0000;ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00001Oooool2o`0000Sooooo
0_l00006oooooaOo00003?ooool2o`0000;ooooo0_l0000@ooooo`;o00001Oooool2o`0002gooooo
000Looooo`03o`000?oooooooooo02gooooo0_l0000Mooooo`;o00001oooool6o`0000;ooooo5ol0
00000ooooooo0000o`000002o`0000cooooo0_l000000ooooooo0000o`000002o`000004ooooool0
003o0000o`0000;ooooo1?l00005ooooo`;o000000?oooooo`000?l000001oooool3o`0000[ooooo
1_l00006ooooo`Co00000oooool2o`0000Wooooo0_l00006oooooaSo00003oooool2o`0000[ooooo
0_l00004ooooo`;o00001Oooool2o`0002gooooo000Looooo`03o`000?oooooooooo02gooooo0_l0
000Mooooo`;o00002?ooool2o`000004ooooool0003o0000oooooaCo00001Oooool4o`0000;ooooo
0_l00008ooooo`;o000000?oooooo`000?l000000_l00007ooooo`?o00001Oooool2o`000004oooo
ool0003o0000ooooo`;o00001Oooool2o`0000cooooo0_l00005ooooo`;o000000?oooooo`000?l0
00000ol00002ooooo`;o00003Oooool2o`0000;ooooo6?l0000?ooooo`;o00002?ooool5o`0000Co
oooo0_l0000cooooo`007?ooool00ol0003oooooooooo`0Jooooo`;o0000>?ooool2o`0000;ooooo
0_l00002oooooaGo00000_ooool6o`000004ooooool0003o0000o`0000_ooooo1?l00007ooooo`;o
00002?ooool2o`0000;ooooo0_l0000Cooooo`Co00000oooool2o`0000Cooooo0_l0000Aooooo`;o
00000oooool>o`000003ooooool0003o000000Ko00003oooool2o`0000Sooooo1Ol00004ooooo`;o
0000<oooool001cooooo00?o0000ooooooooool06_ooool2o`0002_ooooo0_l00006ooooo`;o0000
0oooool2o`0000;ooooo1?l000000ooooooo0000o`000007o`000003ooooool0003o000000So0000
0_ooool4o`0000?ooooo0_l00008ooooo`;o00000oooool2o`0001;ooooo0_l00004ooooo`;o0000
0_ooool2o`0000gooooo1?l00009ooooo`;o00002Oooool2o`0000_ooooo3_l000000ooooooo0000
o`000002o`000003ooooool0003o000000;o00001_ooool2o`0004kooooo000Looooo`03o`000?oo
oooooooo03Wooooo0_l00006ooooo`;o00001?ooool2o`000003ooooool0003o000000?ooooo0_l0
0004ooooo`;o00000oooool2o`000003ooooool0003o000000Ko00000_ooool7o`000003ooooool0
003o000000;ooooo0_l000001?oooooo0000o`000?l0000;ooooo`;o00003_ooool2o`0000gooooo
0_l00002ooooo`;o000000?oooooo`000?l000005oooool2o`0000Wooooo1?l00003ooooo`;o0000
1?oooolJo`0000Cooooo0_l00004ooooo`;o00006?ooool2o`0002kooooo000Looooo`03o`000?oo
oooooooo03Sooooo1?l00005ooooo`;o00001oooool2o`0000Wooooo0_l00008ooooo`Ko00000_oo
ool3o`000005ooooool0003o0000o`000?ooool00_l00002ooooo`;o000000Coooooo`000?l0003o
00006oooool5o`0000Gooooo0_l0000:ooooo`;o00001oooool2o`0000_ooooo0_l0000>ooooo`;o
00000oooool2o`0000?ooooo7?l00009ooooo`;o00006?ooool2o`0002kooooo000Looooo`03o`00
0?oooooooooo03Sooooo1?l00003ooooo`;o00002Oooool5o`0000oooooo0_l00002ooooo`;o0000
0oooool2o`000003ooooool0003o000000;o00005?ooool3o`00017ooooo0ol00005ooooo`;o0000
1Oooool4o`000003ooooool0003o000000Oooooo0_l0000;ooooo`;o00001_ooool2o`000003oooo
ool0003o000000Gooooo0_l00006oooooa3o00000_ooool:o`0000Wooooo0_l00018ooooo`007?oo
ool00ol0003oooooooooo`0mooooo`Co00000oooool2o`0000Cooooo1Ol00005ooooo`;o00002?oo
ool3o`000003ooooool0003o000000Kooooo0_l0000Eooooo`Co00008?ooool4o`000003ooooool0
003o000000Sooooo0_l0000=ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`?o0000
00?oooooo`000?l000001OoooolKo`0000_ooooo0_l00018ooooo`007?ooool2o`0003cooooo1?l0
0005ooooo`;o00001_ooool2o`0000Kooooo0_l00009ooooo`;o00003_ooool4o`0000?ooooo0_l0
0008ooooo`Go00007_ooool2o`0000Gooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l0
000=ooooo`;o00002Oooool3o`0000Gooooo8?l00009ooooo`;o00002Oooool2o`0000cooooo0_l0
000_ooooo`007?ooool00ol0003oooooooooo`0kooooo`;o00001oooool2o`0000?ooooo1_l00009
ooooo`Co00004oooool4o`0000?ooooo0_l00007ooooo`?o000000?oooooo`000?l000000oooool2
o`0001Oooooo1?l0000:ooooo`;o000000?oooooo`000?l000001oooool2o`00017ooooo0ol00005
oooooaco00000_ooool2o`0000Oooooo0_l00009ooooo`Co00001?ooool2o`0000Kooooo0_l0000_
ooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00002oooool2o`0000?ooooo1_l00005oooo
o`;o00000_ooool4o`0001?ooooo0_l0000:ooooo`Ko00001oooool2o`0001Oooooo0_l0000Hoooo
o`;o00000oooool2o`0000_ooooo0ol00007ooooo`?o00000_oooolCo`0000Gooooo0_l00007oooo
o`;o00002Oooool2o`0000Kooooo0_l0000gooooo`007?ooool00ol0003oooooooooo`0gooooo`;o
00003?ooool2o`0000;ooooo0_l00007ooooo`Co00002Oooool2o`0000_ooooo0_l000000ooooooo
0000o`00000:ooooo`Go00000_ooool2o`00013ooooo0_l0000Dooooo`;o00003Oooool2o`000005
ooooool0003o0000o`000?ooool00_l00009ooooo`Go00002?oooolDo`000003ooooool0003o0000
00;o00000_ooool2o`0000kooooo0_l00004ooooo`;o00000oooool2o`0003Wooooo000Looooo`03
o`000?oooooooooo01Sooooo0_l0000Oooooo`;o00002_ooool2o`0000_ooooo0ol0000:ooooo`;o
000000?oooooo`000?l000002?ooool2o`0000[ooooo0ol00003ooooo`;o000000?oooooo`000?l0
00000_l0000?ooooo`;o00004_ooool4o`0000?ooooo0_l00008ooooo`;o000000Coooooo`000?l0
003o00002_ooool4o`0000?ooooo0_l00002ooooo`;o00000oooool3o`0000Cooooo3?l00002oooo
o`?o00000_ooool2o`0000kooooo0ol00003ooooo`;o00000oooool2o`0003Wooooo000Looooo`03
o`000?oooooooooo01Sooooo0_l0000Oooooo`;o00003Oooool2o`0001Sooooo0_l00007ooooo`;o
00002_ooool4o`0000Kooooo1?l00009ooooo`;o00003Oooool4o`0000Gooooo1?l00005ooooo`Co
00002?ooool2o`0000cooooo0_l00005ooooo`;o00000_ooool4o`0000Wooooo0ol000000ooooooo
0000o`000005o`0000;ooooo0_l0000<ooooo`;o00001_ooool2o`0000[ooooo0_l0000gooooo`00
7?ooool00ol0003oooooooooo`0dooooo`?o00001oooool2o`0000Sooooo1?l000000ooooooo0000
o`00000Cooooo`;o00001?ooool2o`000003ooooool0003o000000[ooooo1?l0000Cooooo`;o0000
3Oooool6o`000003ooooool0003o000000;o00000_ooool2o`0000Gooooo0_l00008ooooo`;o0000
2Oooool2o`0000Cooooo0_l00008ooooo`;o00001?ooool2o`0000?ooooo0ol0000:ooooo`;o0000
1?ooool2o`0000Kooooo0_l0000Booooo`;o0000=oooool001cooooo00?o0000ooooooooool0=?oo
ool3o`0000Oooooo0_l00009ooooo`?o000000?oooooo`000?l000002Oooool2o`0000Sooooo1?l0
0002ooooo`;o00003_ooool2o`000004ooooool0003o0000ooooo`;o00004Oooool2o`0000cooooo
1?l000001?oooooo0000o`000?l00003ooooo`;o00005_ooool2o`0000;ooooo0_l00004ooooo`;o
00002Oooool2o`0000?ooooo0_l00003ooooo`;o00002oooool2o`0000Cooooo0_l00004ooooo`;o
00004oooool2o`0003Sooooo000Looooo`03o`000?oooooooooo03kooooo0_l00009ooooo`;o0000
3Oooool2o`000003ooooool0003o000000Oooooo0_l00002ooooo`?o00004?ooool2o`000003oooo
ool0003o000000gooooo0_l00002ooooo`;o00000_ooool2o`0000Sooooo2?l00006ooooo`;o0000
4?ooool2o`000003ooooool0003o000001?ooooo1?l00006ooooo`;o000000?oooooo`000?l00000
1?l0000@ooooo`;o00001_ooool2o`0000_ooooo0_l0000hooooo`007?ooool00ol0003ooooooooo
o`0Hooooo`;o00009oooool2o`0000Oooooo0_l00005ooooo`;o00002?ooool2o`0000_ooooo0ol0
0003ooooo`;o00007Oooool2o`0000Kooooo0_l00008ooooo`co00000_ooool3o`0000;ooooo0_l0
0004ooooo`?o000000Coooooo`000?l0003ooooo0ol00004ooooo`?o00001Oooool4o`0000Oooooo
0_l00009ooooo`Ko00006?ooool2o`0000Sooooo0_l0000kooooo`007?ooool00ol0003ooooooooo
o`0Hooooo`;o00009oooool2o`0000Oooooo0_l00005ooooo`;o00004oooool2o`0000Kooooo0_l0
000Fooooo`;o00003?ooool5o`0000Sooooo0_l000000ooooooo0000o`000005o`0000?ooooo1_l0
0004ooooo`?o000000?oooooo`000?l000000_ooool2o`0000Cooooo1?l00004ooooo`Co00003Ooo
ool2o`0000;ooooo1?l0000Nooooo`;o00001Oooool2o`0003_ooooo000Looooo`03o`000?oooooo
oooo03cooooo0_l00002ooooo`?o00003oooool2o`0001;ooooo0_l0000:ooooo`;o00004_ooool2
o`0000Wooooo0_l000000ooooooo0000o`000003o`0000;ooooo0_l00004ooooo`;o00000_ooool2
o`0000;ooooo0ol00002ooooo`Co00001oooool2o`0000?ooooo0_l00006ooooo`Co00001oooool2
o`0000[ooooo1?l00002ooooo`Co00006Oooool3o`0000;ooooo0_l0000=ooooo`?o0000<_ooool0
01cooooo00?o0000ooooooooool0??ooool2o`0000;ooooo1?l0000>ooooo`;o00004_ooool2o`00
00[ooooo0_l00006ooooo`;o00001?ooool2o`0000;ooooo0_l0000;ooooo`;o000000?oooooo`00
0?l000000ol00002ooooo`;o00001?ooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`00
00?ooooo0_l00004ooooo`;o00000oooool2o`0000Sooooo0_l000000ooooooo0000o`000004oooo
o`;o00002_ooool2o`00023ooooo1?l0000Aooooo`?o0000<_ooool001cooooo00?o0000oooooooo
ool0=Oooool2o`0000[ooooo0ol0000;ooooo`;o000000?oooooo`000?l000006Oooool3o`0000So
oooo2_l00002ooooo`;o00001?ooool2o`0000;ooooo0_l00004ooooo`Ko00002?ooool2o`0000oo
oooo0_l00005ooooo`;o00002oooool3o`000003ooooool0003o000003;ooooo0_l0000;ooooo`;o
00001_ooool3o`0003;ooooo000Looooo`03o`000?oooooooooo03Gooooo0_l0000:ooooo`;o0000
3?ooool6o`0000Cooooo0_l000000ooooooo0000o`00000=ooooo`Go00000oooool2o`0000?ooooo
0_l00002ooooo`Go00002Oooool2o`0000;ooooo0_l00002ooooo`So000000?oooooo`000?l00000
1Oooool2o`0000Oooooo0_l0000=ooooo`;o00001?ooool2o`0000?ooooo1ol00004ooooo`;o0000
2?ooool2o`0002;ooooo0_l0000<ooooo`;o00001oooool2o`0003;ooooo000Looooo`03o`000?oo
oooooooo047ooooo0_l0000<ooooo`Ko000000Coooooo`000?l0003ooooo0_l000000ooooooo0000
o`00000=ooooo`?o00001Oooool2o`0000Sooooo1_l00002ooooo`;o000000?oooooo`000?l00000
2?ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000003_ooool2o`0001?o
oooo0_l00003ooooo`Co000000?oooooo`000?l000000_l00002ooooo`;o00001oooool3o`00013o
oooo0_l0000@ooooo`;o00004?ooool2o`0003Oooooo000Looooo`;o0000?Oooool3o`0000?ooooo
0ol0000>ooooo`;o000000?oooooo`000?l000004?ooool2o`00013ooooo0_l000001?oooooo0000
o`000?ooool3o`000003ooooool0003o000000Go00000oooool4o`000003ooooool0003o000000?o
oooo1Ol0000>ooooo`;o00005Oooool2o`0000Kooooo1Ol00003ooooo`;o00001Oooool2o`0000Wo
oooo0ol00005ooooo`;o00004?ooool4o`0000Gooooo0ol00006ooooo`;o0000=oooool001cooooo
00?o0000ooooooooool0??ooool5o`000004ooooool0003o0000o`0000Oooooo0_l00005ooooo`;o
000000?oooooo`000?l000003_ooool4o`0000_ooooo0_l00003ooooo`?o000000?oooooo`000?l0
00000_l00002ooooo`Oo000000?oooooo`000?l000001?l000000ooooooo0000o`000002ooooo`Oo
000000?oooooo`000?l000000_l0000Oooooo`;o00001_ooool2o`000003ooooool0003o000000;o
oooo1?l0000:ooooo`;o00000oooool3o`0001Oooooo1?l00002ooooo`;o000000Coooooo`000?l0
003o0000?oooool001cooooo00?o0000ooooooooool0?_ooool3o`0000;ooooo0_l00007ooooo`?o
00000oooool3o`0000?ooooo0_l0000<ooooo`?o00000oooool2o`0000Kooooo0ol00002ooooo`ko
00001Oooool2o`0000?ooooo0ol00003ooooo`Co000000Coooooo`000?l0003ooooo1?l00005oooo
o`;o00007Oooool2o`0000Sooooo1?l0000:ooooo`;o00000oooool2o`0001_ooooo0_l000000ooo
oooo0000o`000002ooooo`?o0000?_ooool001cooooo00?o0000ooooooooool0=_ooool2o`0000Ko
oooo0ol00005ooooo`;o00001Oooool2o`0000?ooooo0_l00004ooooo`;o00003Oooool4o`000003
ooooool0003o000000;ooooo0ol000000ooooooo0000o`000002o`000003ooooool0003o000000;o
oooo0_l000000ooooooo0000o`000004o`0000Kooooo0_l00003ooooo`?o00001Oooool2o`000003
ooooool0003o000000?ooooo0_l00005ooooo`;o00007Oooool2o`0000Sooooo0_l00006ooooo`;o
00002Oooool2o`0000;ooooo0_l0000Gooooo`;o000000?oooooo`000?l000000_ooool3o`0003ko
oooo000Looooo`03o`000?oooooooooo01[ooooo0_l0000Jooooo`;o00003_ooool2o`0000oooooo
0_l00005ooooo`;o00002Oooool2o`0000Cooooo1?l000000ooooooo0000o`000006o`00023ooooo
1?l000000ooooooo0000o`00000[ooooo`;o000000?oooooo`000?l000001_ooool2o`0000gooooo
0_l0000=ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`;o0000
2?ooool2o`0003Gooooo000Looooo`03o`000?oooooooooo01[ooooo0_l0000Pooooo`;o00003Ooo
ool2o`0000[ooooo0_l00005ooooo`;o00000oooool2o`0000?ooooo0_l00003ooooo`Ko000000Co
ooooo`000?l0003ooooo1ol00009ooooo`;o00001?ooool5o`0000cooooo1?l0000/ooooo`;o0000
1?ooool2o`0000kooooo0_l00008ooooo`;o00001oooool2o`0000;ooooo0_l00002ooooo`;o0000
00?oooooo`000?l000003_ooool2o`0003Gooooo000Looooo`03o`000?oooooooooo03cooooo0_l0
000=ooooo`;o00001_ooool2o`0000Kooooo0_l00003ooooo`;o000000?oooooo`000?l000000ooo
ool2o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Wooooo0_l0
0002ooooo`Oo00000oooool2o`0000Wooooo0_l0000Rooooo`;o00002Oooool2o`0000?ooooo0_l0
0007ooooo`;o00001Oooool2o`0000Sooooo1?l00004ooooo`;o000000?oooooo`000?l00000C_oo
ool001cooooo00?o0000ooooooooool0??ooool2o`0001Gooooo1?l00004ooooo`;o00000oooool2
o`0000?ooooo0_l0000:ooooo`;o000000?oooooo`000?l000003oooool3o`0000?ooooo0_l00000
0ooooooo0000o`000005ooooo`;o0000:oooool4o`0000Wooooo0_l00004ooooo`;o00001_ooool2
o`0000Cooooo0_l000000ooooooo0000o`000008ooooo`;o00001?ooool2o`000003ooooool0003o
000004kooooo000Looooo`03o`000?oooooooooo03_ooooo1?l0000=ooooo`Ko00000oooool3o`00
00Sooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000Oooooo0_l000000ooo
oooo0000o`00000;ooooo`;o00000_ooool3o`0000kooooo0_l00004ooooo`;o00009?ooool4o`00
00Cooooo0_l00005ooooo`;o00000_ooool2o`0000cooooo0_l000000ooooooo0000o`000003oooo
o`;o00004_ooool2o`000003ooooool0003o000000cooooo0_l0000gooooo`007?ooool00ol0003o
ooooooooo`0gooooo`;o00000_ooool4o`0000Cooooo0_l00007ooooo`Ko00000_ooool4o`0000Go
oooo0_l000001?oooooo0000o`000?ooool3o`0000;ooooo0_l00002ooooo`;o000000?oooooo`00
0?l000000_l000000ooooooo0000o`00000;ooooo`;o00004oooool2o`0000Cooooo0_l0000Loooo
o`;o00001Oooool2o`0000;ooooo0_l00003ooooo`;o00001Oooool2o`0000;ooooo0_l0000Doooo
o`?o00000oooool2o`0000cooooo0_l000000ooooooo0000o`00000<ooooo`;o0000=oooool001co
oooo00?o0000ooooooooool0=oooool2o`0000Kooooo0ol000000ooooooo0000o`00000?ooooo`;o
00001oooool2o`0000Wooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00000_ooool3o`00
04?ooooo1?l00003ooooo`;o00000_ooool2o`0000[ooooo1?l0000<ooooo`;o00002Oooool2o`00
00?ooooo0_l0000;ooooo`Co00003_ooool2o`0003Oooooo000Looooo`03o`000?oooooooooo01ko
oooo0_l0000Oooooo`?o00004_ooool2o`0001[ooooo2?l00005ooooo`;o00004_ooool2o`0000[o
oooo0_l00005ooooo`;o00003oooool2o`0000?ooooo1_l0000=ooooo`So00003?ooool2o`0000Wo
oooo0_l00006ooooo`;o00001_ooool6o`0000Sooooo0_l00002ooooo`Co0000=oooool001cooooo
00?o0000ooooooooool07_ooool2o`0002;ooooo0_l0000@ooooo`;o00001Oooool2o`0001?ooooo
2?l00005ooooo`;o00002Oooool2o`0000Oooooo1?l00008ooooo`;o00001Oooool2o`0000Wooooo
0_l00003ooooo`?o00000oooool3o`000004ooooool0003o0000o`0000;ooooo1?l00006ooooo`Go
00001oooool2o`0001Sooooo0ol00004ooooo`Co000000?oooooo`000?l000002Oooool2o`0000;o
oooo0_l0000iooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00003Oooool2o`0000Cooooo
0_l00008ooooo`Co00001?ooool3o`0000gooooo0_l000001?oooooo0000o`000?ooool3o`0000;o
oooo0_l0000Aooooo`Go00001_ooool2o`0000Wooooo0_l0000?ooooo`;o00000oooool2o`0000;o
oooo1?l000000ooooooo0000o`000003o`000003ooooool0003o000000;o00004_ooool2o`000003
ooooool0003o000001Gooooo0ol00004ooooo`;o00000oooool2o`0000Kooooo0_l00010ooooo`00
00Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413o
c<c<00Kooooo00?o0000ooooooooool0<oooool3o`0001;ooooo0ol00006ooooo`?o00001_ooool4
o`0000Wooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00002ooooo`;o00000_oo
ool2o`0000Wooooo0_l00003ooooo`Co00002?ooool2o`0000Oooooo0_l0000Dooooo`;o00000_oo
ool4o`000003ooooool0003o000000Ko000000Coooooo`000?l0003o00004oooool2o`0001Kooooo
0_l00009ooooo`;o00001_ooool2o`00043ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0doooo
o`;o000000?oooooo`000?l000004?ooool2o`0000Kooooo0ol00006ooooo`Go00001oooool3o`00
00Sooooo0_l00006ooooo`;o00002Oooool2o`000004ooooool0003o0000ooooo`Co00000oooool2
o`0000;ooooo0_l0000Mooooo`?o00000_oooolBo`0000Cooooo0_l0000Pooooo`?o00002_ooool2
o`0004Wooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo03Oooooo0_l00006ooooo`?o00000_ooool2
o`0000Gooooo0_l00005ooooo`;o00001oooool5o`0000;ooooo0_l00002ooooo`;o00002Oooool2
o`0001?ooooo0ol00002ooooo`?o00000oooool4o`0000?ooooo0_l000000ooooooo0000o`00000G
ooooo`?o000000?oooooo`000?l000001?l000000ooooooo0000o`000007o`000003ooooool0003o
000000Cooooo0ol00002ooooo`;o00006oooool3o`0000Sooooo1Ol00018ooooo`0000?oooooo`00
0?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3
o`00027ooooo0_l0000Looooo`?o00000_ooool2o`000003ooooool0003o000000;ooooo0_l0000>
ooooo`Go00000_ooool2o`00013ooooo0_l00002ooooo`;o00003?ooool2o`0000?ooooo3ol00000
0ooooooo0000o`00000=ooooo`;o00001?ooool2o`000003ooooool0003o000001Co00001_ooool3
o`0000;ooooo0_l000000ooooooo0000o`00000Fooooo`;o00002_ooool3o`000003ooooool0003o
000000Cooooo0_l00012ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09oooo
o`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0Qooooo`;o00005_ooool2
o`0000cooooo0_l00002ooooo`Co00003_ooool2o`000003ooooool0003o000000;o000000?ooooo
o`000?l000003Oooool2o`0000;ooooo0_l0000@oooooaCo00001?ooool2o`0000Kooooo0_l00004
ooooo`;o000000?oooooo`000?l000003?l000000ooooooo0000o`000007o`0000cooooo0_l0000F
ooooo`Co00001oooool3o`0000Sooooo0_l00012ooooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0>Oooool2o`00
00Kooooo0ol00002ooooo`;o00001?ooool5o`0000oooooo0_l00003ooooo`;o00008ooooolEo`00
00?ooooo0_l00004ooooo`;o00001Oooool2o`0000?ooooo6?l000001?oooooo0000o`000?l0000L
ooooo`;o000000?oooooo`000?l000000_l00007ooooo`;o0000COooool00006oooooomgMgOoV9RH
oooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo047ooooo0ol0
0002ooooo`Co00001Oooool2o`0000Gooooo0_l00002ooooo`;o00004Oooool2o`0000;ooooo1?l0
000Booooo`;o000000?oooooo`000?l000002Ol00002ooooo`So00001?ooool3o`0000;ooooo0_l0
0004ooooo`Co00000_oooolEo`000004ooooool0003o0000ooooo`?o00001oooool2o`0001?ooooo
0_l00003ooooo`;o00000_ooool2o`0000Gooooo0_l00006ooooo`;o000000Coooooo`000?l0003o
oooo0_l0000mooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co0000
oa0@40Kooooo00?o0000ooooooooool0B?ooool2o`0000Gooooo0ol00004ooooo`;o00000_ooool2
o`0000Kooooo0_l00009ooooo`;o00000_ooool4o`0001;ooooo0_l000000ooooooo0000o`00000E
o`0000;ooooo0ol00008ooooo`Ko000000?oooooo`000?l000002ol00002ooooo`_o000000?ooooo
o`000?l000000_l00003ooooo`;o00007?ooool2o`0000Gooooo0_l00006ooooo`Go000000?ooooo
o`000?l00000?Oooool001cooooo00?o0000ooooooooool0=?ooool2o`0000kooooo0_l00002oooo
o`;o00001?ooool6o`0000kooooo0_l00002ooooo`;o00007ooooolJo`0000;ooooo1?l00007oooo
oaGo000000?oooooo`000?l000002Ol000000ooooooo0000o`000002o`0001Sooooo0_l00008oooo
o`;o00003Oooool2o`0004;ooooo000Looooo`03o`000?oooooooooo03Cooooo0_l0000>ooooo`;o
00002?ooool2o`0000;ooooo0_l00003ooooo`;o00002Oooool8o`0001gooooo6?l00006ooooo`;o
00002OoooolMo`0000Gooooo0_l00008ooooo`;o00003_ooool2o`0000Sooooo0_l0001Aooooo`00
7?ooool00ol0003oooooooooo`0Uooooo`;o00005?ooool2o`0001;ooooo0_l00003ooooo`;o0000
00?oooooo`000?l000001_ooool2o`000003ooooool0003o000000;o00000_ooool2o`0001Wooooo
0_l00003oooooaSo00003_ooool=o`0000?ooooo3ol00002ooooo`;o000000?oooooo`000?l00000
2?ooool3o`0001_ooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`0Uooooo`;o00005?oo
ool2o`0001;ooooo1?l000001?oooooo0000o`000?ooool2o`0000Kooooo0_l00002ooooo`;o0000
3?ooool2o`0000;ooooo0_l00006ooooo`;o00001?ooool2o`000003ooooool0003o000001Co0000
00?oooooo`000?l000000ol0000:ooooobOo00002_ooool2o`0001Cooooo0_l00005ooooo`;o0000
COooool001cooooo00?o0000ooooooooool0B_ooool2o`0000Gooooo0_l00004ooooo`;o00002ooo
ool2o`000003ooooool0003o000000?ooooo0_l00003ooooo`;o00000_ooool2o`0000Kooooo0_l0
0004ooooo`oo000000?oooooo`000?l000003Ol0000:ooooob?o00000_ooool2o`0000?ooooo0ol0
000Jooooo`;o00004_ooool2o`00043ooooo000Looooo`03o`000?oooooooooo04[ooooo1Ol00000
0ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000002Oooool2o`000003ooooool0003o
000000?ooooo0_l00002ooooo`?o00004?oooolMo`0000cooooo2_l000000ooooooo0000o`00000E
o`0000Sooooo0ol0000Fooooo`;o00001_ooool3o`0000gooooo0_l00010ooooo`007?ooool00ol0
003oooooooooo`0Wooooo`;o00007oooool2o`0000;ooooo0ol000001?oooooo0000o`000?ooool2
o`000004ooooool0003o0000ooooo`;o00002Oooool2o`0000[ooooo0ol0000@oooooaco00003Ooo
oolQo`0000Sooooo1?l0000>ooooo`;o00001_ooool4o`0000Cooooo0ol0001?ooooo`007?ooool0
0ol0003oooooooooo`0Wooooo`?o00007_ooool2o`0000;ooooo0_l00005ooooo`;o00001_ooool2
o`0000;ooooo1?l000000ooooooo0000o`00000;ooooo`;o00004?oooolKo`0000Kooooo0_l00002
ooooo`[o000000?oooooo`000?l000006_l00006ooooo`;o00004?ooool2o`0000Cooooo0_l00002
ooooo`?o00000oooool2o`00053ooooo000Looooo`03o`000?oooooooooo02Sooooo0_l0000aoooo
o`Wo00003Oooool2o`00017ooooo5?l000000ooooooo0000o`000004o`0000Gooooo9ol00002oooo
o`;o00006?ooool2o`0000Cooooo0_l00003ooooo`;o00000_ooool2o`00057ooooo000Looooo`03
o`000?oooooooooo02[ooooo0_l0000_ooooo`_o00005_ooool2o`0000Gooooo7?l00006ooooo`Ko
00000_oooolLo`000004ooooool0003o0000ooooo`;o00003?ooool2o`0000oooooo0_l00008oooo
o`;o00003?ooool2o`0004?ooooo000Looooo`03o`000?oooooooooo02[ooooo0_l0000_ooooo`_o
00000_ooool2o`0001;ooooo0_l00005oooooa7o000000?oooooo`000?l000002?l0000Aoooooaco
000000?oooooo`000?l000003?ooool2o`0000oooooo0_l00005ooooo`;o00003oooool2o`0004?o
oooo000Looooo`;o0000F_oooolAo`0000?ooooo0_l0000EoooooaWo00004ooooolLo`000003oooo
ool0003o000001Gooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o0000
AOooool001cooooo00?o0000ooooooooool0FOooool@o`0000Cooooo0_l0000>ooooo`;o000000?o
ooooo`000?l000000_oooolIo`0000Cooooo0_l0000=oooooaco000000?oooooo`000?l000002Ooo
ool2o`0000[ooooo0_l0000<ooooo`;o00001Oooool3o`0000?ooooo0_l000000ooooooo0000o`00
0015ooooo`007?ooool00ol0003oooooooooo`1Iooooo`Ko00000_ooool8o`0001Cooooo0_l00000
0ooooooo0000o`000002o`0000;ooooo5Ol000000ooooooo0000o`000002o`000003ooooool0003o
000000Cooooo0_l00009oooooaCo00000oooool6o`0000Kooooo0_l000000ooooooo0000o`00000=
ooooo`;o00000oooool2o`0000Cooooo0_l00005ooooo`;o00001?ooool2o`0004Sooooo000Loooo
o`03o`000?oooooooooo03[ooooo0_l0000=ooooo`;o00003oooool>o`0000Cooooo1?l0000Aoooo
o`Go000000?oooooo`000?l000004_l000000ooooooo0000o`000002o`0000Kooooo0ol00005oooo
o`;o00000oooool>o`000003ooooool0003o000000?o00001Oooool2o`0000Oooooo1?l00008oooo
o`;o00001?ooool2o`0000?ooooo0ol00008ooooo`;o0000D?ooool001cooooo00?o0000oooooooo
ool0>_ooool2o`0000[ooooo0_l000000ooooooo0000o`000005ooooo`;o00001_ooool2o`000003
ooooool0003o000000[o000000?oooooo`000?l000000_ooool4o`0001;ooooo1?l00002oooooa7o
00000_ooool2o`0000Wooooo0_l00006ooooo`;o00001?ooool3o`000003ooooool0003o000000Oo
000000?oooooo`000?l000001?l0000?ooooo`Co00001_ooool2o`0000;ooooo0_l00006ooooo`;o
00001oooool3o`00053ooooo000Looooo`03o`000?oooooooooo04Kooooo0_l00007ooooo`?o0000
1_ooool?o`000004ooooool0003o0000ooooo`Co00003_ooool2o`0000?ooooo0_l00006ooooo`;o
000000?oooooo`000?l000002_l00002ooooo`;o00001?ooool2o`0001Gooooo2Ol000000ooooooo
0000o`000002ooooo`;o00004Oooool2o`0000Gooooo0_l00003ooooo`;o00001_ooool2o`0000Oo
oooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`16ooooo`;o000000?oooooo`000?l00000
1?ooool2o`0000?ooooo0_l00004oooooa3o000000?oooooo`000?l000000_l0000>ooooo`;o0000
3Oooool=o`0000Sooooo0_l00004ooooo`;o00003oooool5o`0000Cooooo1?l00009ooooo`;o0000
4?ooool2o`0001;ooooo0_l0000;ooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0BOoo
ool2o`0000Kooooo0_l000000ooooooo0000o`000005ooooo`oo00005_ooool2o`0000Wooooo0ol0
0006ooooo`Oo00003?ooool2o`00017ooooo1?l00003ooooo`Co00002Oooool2o`0001?ooooo0_l0
000?ooooo`;o00002oooool2o`0004Kooooo000Looooo`03o`000?oooooooooo057ooooo0_l00008
ooooo`[o00006oooool2o`0000Wooooo0_l00002ooooo`;o00000oooool7o`0000cooooo0_l00002
ooooo`;o00003oooool2o`0002;ooooo0_l000000ooooooo0000o`00000?ooooo`;o0000Doooool0
01cooooo00?o0000ooooooooool0D_ooool3o`0000Cooooo3?l00006ooooo`;o00005?ooool2o`00
00cooooo0_l0000:ooooo`;o00002_ooool2o`0000;ooooo0_l00009ooooo`;o000000?oooooo`00
0?l000003?ooool2o`0000Cooooo0_l00008ooooo`;o00001oooool2o`000003ooooool0003o0000
01Cooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00007oooool?o`0000Co
oooo0_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000004Oooool2o`0000Co
oooo0_l00006ooooo`;o00002_ooool2o`0001Wooooo0_l000000ooooooo0000o`000002ooooo`;o
00002?ooool2o`0000Cooooo0_l00008ooooo`;o00001oooool2o`0000;ooooo0_l00003ooooo`;o
00003_ooool2o`0004kooooo000Looooo`03o`000?oooooooooo02oooooo0_l0000Kooooo`;o0000
0_ooool4o`000003ooooool0003o000000;o00003Oooool2o`0000Kooooo0_l000000ooooooo0000
o`00000;ooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo0_l00002ooooo`;o0000
2oooool2o`0001oooooo0_l00007ooooo`;o00004_ooool3o`0000Oooooo0ol00002ooooo`;o0000
1_ooool2o`0005Kooooo000Looooo`03o`000?oooooooooo04cooooo0_l0000:ooooo`;o00003_oo
ool2o`0000Oooooo0_l0000;ooooo`;o000000?oooooo`000?l000001_ooool6o`0000gooooo0_l0
000Xooooo`;o00004_ooool3o`0000Cooooo0_l00002ooooo`;o00001Oooool2o`0000?ooooo0_l0
0007ooooo`;o0000COooool001cooooo00?o0000ooooooooool0F?ooool2o`0000Cooooo0_l00000
0ooooooo0000o`000005ooooo`;o00001oooool2o`0000Sooooo0_l00002ooooo`Go00001Oooool2
o`0000;ooooo0_l0000fooooo`;o00006_ooool2o`0000Kooooo0_l000000ooooooo0000o`00000<
ooooo`;o0000COooool001cooooo00?o0000ooooooooool0G_ooool5o`0000kooooo0_l00008oooo
o`;o00000_ooool5o`0000Gooooo0_l00002ooooo`;o00006oooool2o`0000?ooooo0_l0000Doooo
o`;o00008_ooool2o`0000_ooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o
00001?ooool2o`0000;ooooo0ol0000Iooooo`;o00004Oooool2o`0001?ooooo0_l000000ooooooo
0000o`000002o`000003ooooool0003o000000Gooooo1Ol00006ooooo`;o00005_ooool2o`00013o
oooo1?l00007ooooo`?o00001_ooool2o`0004Sooooo000Looooo`;o0000EOooool2o`0000?ooooo
0_l00008ooooo`?o0000;?ooool2o`0000Sooooo0_l00009ooooo`;o00000oooool2o`0000Sooooo
1Ol00006ooooo`;o00000_ooool2o`0001;ooooo0_l0000@ooooo`Co00002?ooool4o`0000Cooooo
0_l00018ooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o00004Oooool2o`0000Oooooo0_l0
000Zooooo`;o00008_ooool2o`0000;ooooo0ol0000booooo`?o0000COooool001cooooo00?o0000
ooooooooool0Ioooool2o`0000Oooooo0_l0000Dooooo`?o00006Oooool3o`000003ooooool0003o
000001Sooooo0_l00002ooooo`;o00001oooool2o`0000?ooooo0_l0000Booooo`;o00004Oooool3
o`0004gooooo000Looooo`03o`000?oooooooooo053ooooo0_l00003ooooo`;o00007Oooool2o`00
013ooooo0ol0000Iooooo`?o000000?oooooo`000?l000009Oooool2o`0000?ooooo0_l00003oooo
o`Oo00001_ooool4o`0000Oooooo0_l00008ooooo`;o0000C_ooool001cooooo00?o0000oooooooo
ool0D?ooool3o`0000;ooooo0_l0000?ooooo`;o00003?ooool2o`0000oooooo0_l00009ooooo`;o
0000>_ooool2o`0000Wooooo1ol00006ooooo`;o00002Oooool2o`0005Sooooo000Looooo`03o`00
0?oooooooooo057ooooo0_l0000:ooooo`;o00001oooool2o`0000_ooooo0_l0000@ooooo`;o0000
2Oooool2o`0001Gooooo0_l0000Sooooo`Ko00001_ooool2o`000003ooooool0003o000001[ooooo
0_l0001@ooooo`007?ooool00ol0003oooooooooo`1Booooo`;o00000oooool2o`0000Cooooo0_l0
000Dooooo`?o0000:Oooool2o`0000Gooooo1Ol0000Nooooo`?o00000_ooool4o`0000;ooooo0_l0
0002ooooo`;o00002?ooool3o`0000Kooooo0_l000000ooooooo0000o`000003ooooo`;o00000_oo
ool2o`00053ooooo000Looooo`03o`000?oooooooooo05;ooooo0_l00003ooooo`;o00006?ooool2
o`000003ooooool0003o0000017ooooo0_l0000Fooooo`;o00001Oooool2o`000003ooooool0003o
000001[ooooo0_l00002ooooo`?o00002?ooool2o`0000cooooo0ol00002ooooo`;o00000_ooool2
o`000003ooooool0003o000000?ooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`1`oooo
o`?o00005?ooool2o`0000_ooooo0ol0000^ooooo`;o00001oooool2o`0000[ooooo0_l0000;oooo
o`;o00001?ooool2o`0005[ooooo000Looooo`03o`000?oooooooooo06_ooooo0_l00003ooooo`Go
00004oooool2o`0000[ooooo0ol0000]ooooo`;o00002?ooool2o`0000[ooooo0_l0000Aooooo`;o
00001Oooool2o`0005?ooooo000Looooo`03o`000?oooooooooo06Wooooo1_l00002ooooo`Co0000
4Oooool4o`000003ooooool0003o000003Oooooo0_l00004ooooo`;o00001Oooool2o`0000Sooooo
0_l00002ooooo`;o00004oooool2o`0000?ooooo0_l0001>ooooo`007?ooool00ol0003ooooooooo
o`1Yooooo`Oo00005_ooool2o`0000?ooooo0ol0000Eooooo`;o00007Oooool6o`0000;ooooo0_l0
0005ooooo`;o00001oooool3o`0000;ooooo0_l0000:ooooo`;o00003?ooool2o`0004kooooo000L
ooooo`03o`000?oooooooooo05Wooooo0_l0000@ooooo`Go00001?ooool2o`0001Kooooo0_l0000E
ooooo`;o00007Oooool2o`0000;ooooo0_l00007ooooo`;o000000?oooooo`000?l000000_ooool2
o`0000;ooooo0ol0000>ooooo`;o0000G?ooool001cooooo00?o0000ooooooooool0FOooool2o`00
00?ooooo0_l0000=ooooo`;o00001Oooool2o`0002oooooo0_l0000Uooooo`;o000000Coooooo`00
0?l0003ooooo0_l00002ooooo`;o00007_ooool2o`00057ooooo000Looooo`03o`000?oooooooooo
05cooooo1?l00009ooooo`;o00001oooool2o`0002cooooo0_l00003ooooo`;o00008Oooool2o`00
00;ooooo0_l0000Gooooo`;o00001Oooool4o`0000Kooooo0_l0001Aooooo`007?ooool00ol0003o
ooooooooo`1Looooo`Co000000?oooooo`000?l000001_ooool2o`0000Oooooo0_l0000Aooooo`;o
00006Oooool2o`0002Kooooo0_l00002ooooo`;o00000_ooool2o`0000[ooooo0_l00007ooooo`;o
00001Oooool4o`0005Wooooo000Looooo`;o0000F_ooool2o`0000Kooooo0_l000000ooooooo0000
o`000009ooooo`;o00001?ooool2o`0000kooooo0ol0000=ooooo`Co0000<oooool3o`000003oooo
ool0003o000000[ooooo0_l0001[ooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o00001?oo
ool2o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`;o00001?ooool2o`0000oooooo0_l0
000=ooooo`Co00008_ooool2o`0000Cooooo0_l0000:ooooo`;o00003Oooool4o`0006Wooooo000L
ooooo`03o`000?oooooooooo05Wooooo0_l00004ooooo`?o000000Coooooo`000?l0003ooooo0ol0
0004ooooo`;o00002_ooool2o`00017ooooo0_l00004ooooo`;o00000_ooool2o`0000?ooooo0_l0
000Mooooo`?o00001?ooool2o`0001Wooooo1?l0001Yooooo`007?ooool00ol0003oooooooooo`1P
ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000005o`0000Wooooo0_l0
000>ooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo0_l00003ooooo`;o00007Ooo
ool5o`0000Gooooo0_l0000Booooo`;o00000oooool2o`0000oooooo0_l0001Iooooo`007?ooool0
0ol0003oooooooooo`1Iooooo`;o00002Oooool2o`0000?ooooo1ol0000Iooooo`;o00007Oooool2
o`0000Wooooo0_l00006ooooo`Co00001Oooool2o`0000;ooooo0_l0000>ooooo`;o00000oooool2
o`0000Wooooo1?l00002ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0FOooool2o`00
00Wooooo0_l00005ooooo`;o000000?oooooo`000?l000003_ooool2o`00023ooooo0_l00006oooo
o`;o00001Oooool2o`0000;ooooo0_l00003ooooo`;o00002_ooool6o`0000_ooooo0_l00005oooo
o`;o00002?ooool6o`0005gooooo000Looooo`03o`000?oooooooooo063ooooo0_l00007ooooo`Co
00003?ooool2o`0000?ooooo0_l000000ooooooo0000o`00000Gooooo`;o00001?ooool2o`0000;o
oooo0_l00006ooooo`;o000000?oooooo`000?l000000oooool2o`0000;ooooo0_l00009ooooo`;o
000000?oooooo`000?l000003Oooool2o`0000Cooooo0ol00003ooooo`;o00000oooool2o`00067o
oooo000Looooo`03o`000?oooooooooo063ooooo0_l00007ooooo`;o00003_ooool2o`0000?ooooo
0_l000000ooooooo0000o`00000Eooooo`Co00002?ooool2o`0000Kooooo0_l00006ooooo`?o0000
3?ooool2o`0001Kooooo0_l00004ooooo`;o0000I_ooool001cooooo00?o0000ooooooooool0JOoo
ool2o`0002gooooo0_l0000Dooooo`;o00001Oooool2o`0000?ooooo0_l0000Nooooo`;o00000ooo
ool4o`0006Kooooo000Looooo`03o`000?oooooooooo087ooooo0ol0000=ooooo`;o00002Oooool2
o`0000Wooooo0_l00005ooooo`;o00002_ooool2o`0000[ooooo0_l0000Booooo`;o00000oooool4
o`0006Kooooo000Looooo`03o`000?oooooooooo06Kooooo0_l00002ooooo`?o00005?ooool4o`00
00cooooo0_l00009ooooo`?o00002?ooool2o`0000Oooooo0_l0000Cooooo`?o00002Oooool2o`00
00[ooooo0_l00002ooooo`;o0000I_ooool001cooooo00?o0000ooooooooool0I_ooool2o`0000;o
oooo0ol0000Fooooo`;o00001oooool2o`0000oooooo0_l00002ooooo`;o000000?oooooo`000?l0
00002_ooool4o`0000cooooo0_l00003ooooo`?o000000?oooooo`000?l000001_ooool2o`0000Co
oooo0_l00004ooooo`;o00000_ooool2o`0006Kooooo000Looooo`03o`000?oooooooooo06[ooooo
0_l0000Iooooo`?o00001?ooool2o`0001;ooooo0ol000001?oooooo0000o`000?l0000;ooooo`;o
000000?oooooo`000?l000002Oooool2o`0000;ooooo1?l000000ooooooo0000o`000003ooooo`?o
00001_ooool2o`00073ooooo000Looooo`03o`000?oooooooooo073ooooo0ol0000Booooo`?o0000
00?oooooo`000?l000002Oooool2o`0000Gooooo0_l00003ooooo`?o00000_ooool4o`000003oooo
ool0003o000000Kooooo1Ol00004ooooo`;o00001oooool2o`0000Sooooo0ol0001hooooo`0000Ko
ooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<
00Kooooo00?o0000ooooooooool0K?ooool7o`0001Kooooo0_l00009ooooo`;o000000?oooooo`00
0?l000000_ooool2o`0000Wooooo0ol000000ooooooo0000o`000003ooooo`;o000000Coooooo`00
0?l0003o00001_ooool3o`0000_ooooo0_l000001?oooooo0000o`000?ooool2o`0000cooooo0_l0
001Zooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RH
oooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0J_ooool6o`000003ooooool0003o000001Ko
oooo0_l0000<ooooo`;o00002Oooool3o`0000Gooooo1?l000000ooooooo0000o`00000;ooooo`;o
00000_ooool2o`0000;ooooo0ol00002ooooo`;o000000Coooooo`000?l0003ooooo0_l0000<oooo
o`;o0000J_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool0J_ooool2o`0000?ooooo1?l00006oooo
o`;o00003_ooool2o`0001Oooooo0ol00007ooooo`Co000000?oooooo`000?l000000oooool2o`00
00Oooooo0ol00002ooooo`?o00001Oooool2o`0007_ooooo00000ooooooo0000ooooo`02ooooo`03
o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000I?ooool2o`00
00Wooooo0ol00003ooooo`;o00000_ooool3o`0001;ooooo0_l0000:ooooo`;o00001oooool2o`00
00Wooooo0_l000000ooooooo0000o`000002ooooo`?o00001oooool2o`0000Cooooo1?l000000ooo
oooo0000o`000002o`0000Sooooo0_l0001aooooo`0000?oooooo`000?ooool00_ooool00ol0003o
ooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`1Toooo
o`;o00002_ooool2o`0000?ooooo1ol0000Booooo`;o00002_ooool2o`0000Oooooo0_l00006oooo
o`;o00002?ooool5o`0000_ooooo1?l000000ooooooo0000o`000002o`0000Sooooo0_l0001aoooo
o`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj
^_l@41001_ooool00ol0003oooooooooo`1gooooo`;o00005?ooool4o`0000?ooooo0_l0000;oooo
o`;o00002?ooool2o`0000Kooooo0_l00002ooooo`?o00004?ooool2o`000003ooooool0003o0000
00Sooooo0_l0001`ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooookZj^_l000001_ooool00ol0003oooooooooo`1dooooo`;o00001?ooool2o`00017ooooo1?l0
0003ooooo`;o00002oooool2o`0000?ooooo0_l00008ooooo`;o000000?oooooo`000?l000000_oo
ool2o`00017ooooo0_l000000ooooooo0000o`000008ooooo`;o0000L?ooool00006ooooooo^k^ko
<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000oooooooo
ool0K?ooool2o`0000Kooooo0_l00004ooooo`;o00001_ooool2o`0000Gooooo0_l00002ooooo`;o
00004_ooool2o`0000?ooooo0ol00007ooooo`;o00001Oooool2o`0000;ooooo0_l0000Hooooo`;o
0000L_ooool001cooooo00?o0000ooooooooool0K?ooool3o`0000Gooooo0_l000000ooooooo0000
o`000006ooooo`;o000000?oooooo`000?l000001Oooool2o`0000;ooooo0_l0000Hooooo`;o0000
1?ooool2o`0000cooooo0_l00003ooooo`?o00003Oooool2o`0000?ooooo0_l0001booooo`007?oo
ool00ol0003oooooooooo`1]ooooo`;o00002?ooool2o`0000Kooooo1?l000000ooooooo0000o`00
000:ooooo`;o00003Oooool2o`0000;ooooo0_l00007ooooo`?o000000?oooooo`000?l000001_oo
ool2o`000004ooooool0003o0000ooooo`Go00002Oooool2o`0000;ooooo0_l0001gooooo`007?oo
ool00ol0003oooooooooo`1hooooo`?o00001Oooool3o`000003ooooool0003o000000[ooooo0_l0
000;ooooo`Co00000_ooool2o`0000Oooooo0_l00002ooooo`?o00001Oooool2o`0000Cooooo0_l0
000<ooooo`;o0000Noooool001cooooo00?o0000ooooooooool0N?ooool3o`0002;ooooo0ol00000
0ooooooo0000o`000009ooooo`;o00000oooool2o`0000Kooooo0_l0002>ooooo`007?ooool00ol0
003oooooooooo`1aooooo`;o00001Oooool3o`0000Gooooo0_l0000?ooooo`;o00002_ooool2o`00
0004ooooool0003o0000o`0000Sooooo0_l000000ooooooo0000o`000009ooooo`;o0000S_ooool0
01cooooo00?o0000ooooooooool0LOooool2o`0000Gooooo0_l00006ooooo`;o00002Oooool2o`00
00Cooooo0_l00004ooooo`;o00001oooool3o`0000Sooooo0_l000000ooooooo0000o`00000>oooo
o`;o0000ROooool001cooooo00?o0000ooooooooool0R?ooool2o`000003ooooool0003o000000?o
oooo0ol00004ooooo`;o00000oooool4o`000003ooooool0003o000000Sooooo0_l0000Aooooo`;o
0000ROooool001cooooo00?o0000ooooooooool0R?ooool5o`0000?ooooo0_l000000ooooooo0000
o`000007ooooo`Co00002oooool2o`0000?ooooo0_l0002Gooooo`007?ooool00ol0003ooooooooo
o`2:ooooo`?o00000oooool2o`000003ooooool0003o000000;ooooo0_l00007ooooo`;o00003_oo
ool2o`0009Oooooo000Looooo`03o`000?oooooooooo09Oooooo0_l00007ooooo`;o00001oooool3
o`0009gooooo000Looooo`03o`000?oooooooooo08Oooooo0_l0000>ooooo`;o00004?ooool3o`00
09gooooo000Looooo`;o0000R?ooool4o`0000[ooooo1?l00008ooooo`;o00001?ooool2o`0000Oo
oooo0_l000000ooooooo0000o`00002Dooooo`007?ooool00ol0003oooooooooo`29ooooo`;o0000
2_ooool2o`0000[ooooo0_l00004ooooo`;o00000oooool2o`000005ooooool0003o0000o`000?oo
ool00_l0002Dooooo`007?ooool00ol0003oooooooooo`2<ooooo`;o00002_ooool2o`0000Sooooo
1?l00006ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0009Cooooo000Looooo`03o`00
0?oooooooooo08cooooo0ol00009ooooo`;o00000_ooool2o`0000Cooooo1?l0002Sooooo`007?oo
ool00ol0003oooooooooo`2=ooooo`;o00003Oooool2o`000:_ooooo000Looooo`03o`000?oooooo
oooo097ooooo0_l00008ooooo`;o0000[?ooool001cooooo00?o0000ooooooooool0TOooool2o`00
0003ooooool0003o000000Gooooo0_l0002/ooooo`007?ooool00ol0003oooooooooo`2Dooooo`;o
0000/oooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?oo
ooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom:oooo
o`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo
00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o0000ooooooooool0oooo
oomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo
0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`004_ooool00omEEEGoIVIV
o`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Uooooo`04
oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05Oooool01Oo^k^ko<S8bo`000?l@413o
c<c<00?ooooo00Gok^k^oc8b<_l0003o410@olc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
T?ooool00:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00002Oooool01OmEEEGoMgMg
oooooonHV9So8B4Q00?ooooo00GoEEEEogMgMoooooooV9RHob4Q8@03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0T?ooool00:Kooooo00Go0000ooooooooooooooooo`00000Hooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go410@oooooooooooo
oooooa0@402@ooooo`00Y_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l00009ooooo`05
o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003oV9RHoooooonHV9So8B4Q00?ooooo00Go0000
ooooooooooooooooo`00002@ooooo`00Y_ooool01Ol0003oQhN7oooooonYZJWo000001Sooooo00Go
0000oeEEEOl0003o410@olc<c003ooooo`05o`000?mEEEGo0000oa0@4?o<c<`00oooool01Ol0003o
oooooooooooooooo0000093ooooo002Uooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHoooooooo
ool05_ooool00omEEEGoQhN7ooooo`05ooooo`03oeEEEOn7QhOooooo00Gooooo00Go410@oooooooo
oooooooooa0@402@ooooo`00`oooool00ooMgMgo410@oiRHV005ooooo`03omgMgOl@413oV9RH00Go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`2@ooooo`00a?ooool01?o<c<coA4A4o`000?l@4104oooo
o`04olc<c?m4A4Co0000oa0@40?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP2@ooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(666) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.3302 .45343 Mdot
.36933 .41617 Mdot
.57542 .67635 Mdot
.52518 .40827 Mdot
.64601 .55715 Mdot
.56982 .65234 Mdot
.4482 .62817 Mdot
.45584 .64559 Mdot
.58366 .65293 Mdot
.30432 .30005 Mdot
.41399 .63998 Mdot
.62868 .35734 Mdot
.44025 .61785 Mdot
.5589 .36569 Mdot
.2824 .67351 Mdot
.52202 .44905 Mdot
.37034 .40308 Mdot
.68062 .51202 Mdot
.53136 .45233 Mdot
.55022 .66947 Mdot
.41343 .45819 Mdot
.55542 .37219 Mdot
.37401 .41769 Mdot
.55821 .36826 Mdot
.56235 .42163 Mdot
.35033 .43428 Mdot
.31886 .45243 Mdot
.55106 .40534 Mdot
.58391 .3902 Mdot
.4111 .62121 Mdot
.69292 .5806 Mdot
.26099 .73834 Mdot
.50281 .42707 Mdot
.52387 .26769 Mdot
.48016 .62118 Mdot
.6872 .73438 Mdot
.58895 .63305 Mdot
.42404 .65301 Mdot
.46967 .62939 Mdot
.46941 .61169 Mdot
.45025 .60579 Mdot
.35548 .42915 Mdot
.42037 .59476 Mdot
.53093 .68086 Mdot
.51092 .39498 Mdot
.24391 .57438 Mdot
.78298 .54412 Mdot
.54997 .40282 Mdot
.33795 .45036 Mdot
.5376 .65551 Mdot
.62724 .24563 Mdot
.42076 .65391 Mdot
.30149 .61763 Mdot
.09342 .46646 Mdot
.42096 .61323 Mdot
.53249 .40838 Mdot
.56015 .63064 Mdot
.52728 .3804 Mdot
.54982 .39024 Mdot
.53265 .24974 Mdot
.57613 .3891 Mdot
.7099 .50946 Mdot
.33399 .46018 Mdot
.54209 .67001 Mdot
.57836 .651 Mdot
.42582 .6034 Mdot
.34304 .39604 Mdot
.44841 .61363 Mdot
.61428 .40248 Mdot
.5556 .66821 Mdot
.54422 .40236 Mdot
.41389 .64178 Mdot
.35143 .39081 Mdot
.57992 .42652 Mdot
.2912 .56539 Mdot
.36941 .66857 Mdot
.75598 .53954 Mdot
.42808 .3351 Mdot
.39252 .19445 Mdot
.44769 .69691 Mdot
.56889 .36445 Mdot
.36887 .18386 Mdot
.31061 .66139 Mdot
.362 .40622 Mdot
.5396 .28691 Mdot
.49188 .79109 Mdot
.58965 .37729 Mdot
.57935 .51755 Mdot
.51832 .33446 Mdot
.37895 .51821 Mdot
.58486 .64675 Mdot
.35451 .43983 Mdot
.51111 .39823 Mdot
.59417 .37176 Mdot
.46725 .21688 Mdot
.49901 .40215 Mdot
.51518 .39249 Mdot
.28454 .41148 Mdot
.42002 .63736 Mdot
.59632 .32977 Mdot
.5234 .68027 Mdot
.27657 .62946 Mdot
.53535 .42634 Mdot
.57074 .66398 Mdot
.38033 .44643 Mdot
.51566 .40839 Mdot
.42516 .60638 Mdot
.5699 .3794 Mdot
.42821 .57697 Mdot
.3621 .44453 Mdot
.59337 .36893 Mdot
.69365 .5329 Mdot
.32198 .545 Mdot
.31243 .43361 Mdot
.22948 .3699 Mdot
.57045 .39042 Mdot
.5512 .38071 Mdot
.36538 .41286 Mdot
.55155 .62599 Mdot
.54129 .52167 Mdot
.36312 .39529 Mdot
.47182 .62261 Mdot
.36927 .44495 Mdot
.55857 .32909 Mdot
.54047 .63093 Mdot
.28051 .6231 Mdot
.27251 .64257 Mdot
.80535 .44747 Mdot
.58338 .41818 Mdot
.2667 .66145 Mdot
.55401 .64834 Mdot
.36289 .42701 Mdot
.44398 .6115 Mdot
.55344 .33687 Mdot
.32719 .40741 Mdot
.45271 .64091 Mdot
.72126 .53908 Mdot
.65204 .60495 Mdot
.30424 .42776 Mdot
.59006 .48564 Mdot
.47529 .63522 Mdot
.46691 .60883 Mdot
.65191 .26941 Mdot
.35967 .40795 Mdot
.72443 .52924 Mdot
.45498 .63596 Mdot
.72496 .37736 Mdot
.54846 .33795 Mdot
.70144 .30185 Mdot
.42838 .15771 Mdot
.63932 .25517 Mdot
.20269 .48625 Mdot
.70916 .49943 Mdot
.45941 .63313 Mdot
.543 .42126 Mdot
.34249 .41436 Mdot
.35065 .41635 Mdot
.59463 .36076 Mdot
.57103 .41134 Mdot
.53897 .35191 Mdot
.57348 .34739 Mdot
.76746 .63212 Mdot
.54585 .3488 Mdot
.46986 .56298 Mdot
.31515 .41452 Mdot
.57172 .41873 Mdot
.60596 .65264 Mdot
.59563 .41169 Mdot
.42362 .65264 Mdot
.54155 .38974 Mdot
.5631 .41436 Mdot
.51901 .42533 Mdot
.45922 .60904 Mdot
.37717 .80899 Mdot
.32041 .23979 Mdot
.59027 .77918 Mdot
.22427 .47387 Mdot
.55441 .63928 Mdot
.56897 .3552 Mdot
.72957 .51284 Mdot
.53377 .30117 Mdot
.55536 .38991 Mdot
.59438 .22542 Mdot
.56479 .40749 Mdot
.37672 .36103 Mdot
.51105 .32223 Mdot
.54741 .81178 Mdot
.38916 .56034 Mdot
.58228 .38529 Mdot
.3735 .23423 Mdot
.71683 .30325 Mdot
.74532 .55812 Mdot
.42911 .6084 Mdot
.60419 .63151 Mdot
.57521 .62459 Mdot
.45334 .59507 Mdot
.59102 .33398 Mdot
.29995 .31113 Mdot
.61863 .3721 Mdot
.28549 .62223 Mdot
.38008 .4572 Mdot
.69897 .49817 Mdot
.30488 .43383 Mdot
.30148 .22093 Mdot
.46141 .46526 Mdot
.37993 .61988 Mdot
.68036 .51923 Mdot
.58836 .67151 Mdot
.29383 .62326 Mdot
.73213 .51898 Mdot
.51891 .39189 Mdot
.34826 .4486 Mdot
.71463 .29925 Mdot
.48089 .40243 Mdot
.83661 .60571 Mdot
.35059 .40018 Mdot
.47143 .52994 Mdot
.43275 .61003 Mdot
.52961 .63581 Mdot
.58813 .38352 Mdot
.53744 .36021 Mdot
.33216 .45874 Mdot
.55609 .40147 Mdot
.39429 .49139 Mdot
.55903 .41307 Mdot
.52219 .65428 Mdot
.72064 .55498 Mdot
.44651 .58765 Mdot
.80252 .42912 Mdot
.34658 .38752 Mdot
.52368 .56194 Mdot
.58581 .66609 Mdot
.26248 .41225 Mdot
.40856 .63295 Mdot
.71365 .54019 Mdot
.59758 .64236 Mdot
.74701 .53343 Mdot
.53461 .43222 Mdot
.58858 .63764 Mdot
.69735 .52329 Mdot
.62814 .6058 Mdot
.51519 .39658 Mdot
.69342 .35344 Mdot
.44926 .6344 Mdot
.31407 .44888 Mdot
.57684 .39009 Mdot
.26648 .63884 Mdot
.59049 .34475 Mdot
.26897 .66565 Mdot
.27789 .61889 Mdot
.29628 .61543 Mdot
.38557 .68829 Mdot
.73485 .50893 Mdot
.23635 .53224 Mdot
.50115 .50244 Mdot
.36754 .39797 Mdot
.50684 .39136 Mdot
.44906 .83738 Mdot
.45656 .63117 Mdot
.52026 .39236 Mdot
.50631 .79193 Mdot
.45467 .63567 Mdot
.53355 .3789 Mdot
.44914 .60335 Mdot
.34632 .41365 Mdot
.54056 .54164 Mdot
.38125 .4267 Mdot
.52546 .40348 Mdot
.427 .629 Mdot
.60167 .635 Mdot
.34874 .43375 Mdot
.56696 .3828 Mdot
.56446 .35667 Mdot
.29117 .62644 Mdot
.57624 .41491 Mdot
.47744 .82824 Mdot
.54765 .4042 Mdot
.59183 .67129 Mdot
.49791 .39672 Mdot
.70251 .27446 Mdot
.65265 .60115 Mdot
.32378 .39999 Mdot
.2825 .61553 Mdot
.58082 .63909 Mdot
.61928 .5618 Mdot
.65674 .52768 Mdot
.56842 .37105 Mdot
.27863 .63725 Mdot
.47759 .53856 Mdot
.41805 .60755 Mdot
.51072 .34394 Mdot
.42929 .47354 Mdot
.59351 .65278 Mdot
.29086 .62284 Mdot
.51152 .32663 Mdot
.38032 .44427 Mdot
.5343 .4118 Mdot
.59287 .63598 Mdot
.36171 .45091 Mdot
.54908 .33531 Mdot
.78667 .58324 Mdot
.26844 .63575 Mdot
.45059 .63194 Mdot
.63606 .41363 Mdot
.53745 .34809 Mdot
.57242 .62194 Mdot
.33794 .40689 Mdot
.41736 .62194 Mdot
.33324 .44257 Mdot
.74037 .31784 Mdot
.23526 .48263 Mdot
.67523 .70614 Mdot
.67867 .50687 Mdot
.17593 .57722 Mdot
.61076 .7665 Mdot
.25465 .5093 Mdot
.78551 .45401 Mdot
.664 .77698 Mdot
.60393 .64906 Mdot
.64516 .30507 Mdot
.57299 .63289 Mdot
.54145 .42696 Mdot
.57365 .65331 Mdot
.51062 .83738 Mdot
.55512 .40776 Mdot
.55368 .6357 Mdot
.74814 .64106 Mdot
.57542 .40332 Mdot
.30917 .42181 Mdot
.23615 .68463 Mdot
.25096 .36652 Mdot
.50116 .48054 Mdot
.54893 .63493 Mdot
.5378 .21556 Mdot
.56665 .40274 Mdot
.49916 .43767 Mdot
.34209 .41966 Mdot
.52261 .33158 Mdot
.68953 .51023 Mdot
.73742 .54156 Mdot
.65585 .28758 Mdot
.2381 .38424 Mdot
.54865 .46639 Mdot
.34946 .42928 Mdot
.40411 .18895 Mdot
.29103 .56762 Mdot
.27366 .64757 Mdot
.47087 .63202 Mdot
.37461 .80623 Mdot
.46887 .40608 Mdot
.61069 .47242 Mdot
.40312 .50143 Mdot
.36123 .43837 Mdot
.61087 .74305 Mdot
.42239 .62128 Mdot
.35724 .23249 Mdot
.35099 .31413 Mdot
.52989 .35691 Mdot
.40831 .6087 Mdot
.62094 .34887 Mdot
.39391 .49815 Mdot
.69423 .32947 Mdot
.57496 .7161 Mdot
.5198 .40172 Mdot
.24533 .54019 Mdot
.54981 .38556 Mdot
.71393 .31027 Mdot
.52319 .39783 Mdot
.32445 .43873 Mdot
.51625 .46626 Mdot
.63163 .52618 Mdot
.26886 .29575 Mdot
.44783 .45745 Mdot
.72677 .50075 Mdot
.55545 .36269 Mdot
.53161 .3591 Mdot
.70025 .51131 Mdot
.33486 .43522 Mdot
.51252 .37005 Mdot
.79434 .53396 Mdot
.5344 .35126 Mdot
.41271 .64768 Mdot
.58702 .54201 Mdot
.28091 .36708 Mdot
.59175 .37366 Mdot
.36792 .45014 Mdot
.43548 .60255 Mdot
.46318 .63985 Mdot
.51111 .45691 Mdot
.46083 .62491 Mdot
.54031 .41306 Mdot
.57352 .54019 Mdot
.37337 .42836 Mdot
.58228 .30786 Mdot
.32892 .43157 Mdot
.48982 .17867 Mdot
.45281 .6019 Mdot
.28781 .64639 Mdot
.65433 .35238 Mdot
.43537 .62554 Mdot
.27048 .44049 Mdot
.46783 .41899 Mdot
.60149 .40942 Mdot
.25405 .40815 Mdot
.58359 .619 Mdot
.29889 .63495 Mdot
.4176 .61705 Mdot
.53926 .34982 Mdot
.52646 .42213 Mdot
.40167 .62501 Mdot
.48473 .23096 Mdot
.69267 .58386 Mdot
.52731 .40053 Mdot
.32695 .43787 Mdot
.36095 .42855 Mdot
.53271 .34064 Mdot
.55936 .39104 Mdot
.59985 .66581 Mdot
.2783 .63947 Mdot
.29597 .61933 Mdot
.2752 .64399 Mdot
.54283 .61791 Mdot
.17336 .54618 Mdot
.46705 .60933 Mdot
.19963 .57724 Mdot
.42551 .77115 Mdot
.51096 .45381 Mdot
.57874 .62068 Mdot
.5367 .36851 Mdot
.54545 .43388 Mdot
.42301 .62988 Mdot
.1949 .42424 Mdot
.59304 .44472 Mdot
.30249 .43545 Mdot
.40486 .63882 Mdot
.56993 .29857 Mdot
.36637 .63909 Mdot
.6899 .51954 Mdot
.45359 .45117 Mdot
.40609 .61175 Mdot
.34542 .44617 Mdot
.40176 .6198 Mdot
.53359 .35638 Mdot
.60267 .38009 Mdot
.36978 .42959 Mdot
.73812 .51204 Mdot
.51323 .40873 Mdot
.53472 .37966 Mdot
.71832 .25785 Mdot
.28507 .56154 Mdot
.39362 .6615 Mdot
.56089 .42954 Mdot
.58609 .43902 Mdot
.73836 .50779 Mdot
.52696 .35359 Mdot
.58797 .37938 Mdot
.32266 .53647 Mdot
.46744 .6005 Mdot
.75524 .53713 Mdot
.33643 .24681 Mdot
.34489 .40099 Mdot
.48556 .82004 Mdot
.27518 .62859 Mdot
.46382 .59512 Mdot
.52996 .54136 Mdot
.29433 .63904 Mdot
.45226 .76497 Mdot
.55473 .78433 Mdot
.286 .64496 Mdot
.61384 .66789 Mdot
.4648 .35484 Mdot
.5721 .34367 Mdot
.53758 .38796 Mdot
.73565 .51994 Mdot
.35189 .40734 Mdot
.42661 .54811 Mdot
.57002 .59667 Mdot
.55414 .37573 Mdot
.31172 .38641 Mdot
.51871 .80112 Mdot
.29417 .62744 Mdot
.72321 .50517 Mdot
.71076 .49273 Mdot
.54882 .38323 Mdot
.28629 .51207 Mdot
.35123 .43146 Mdot
.56679 .38268 Mdot
.57161 .3498 Mdot
.55182 .62858 Mdot
.33861 .44762 Mdot
.58456 .66717 Mdot
.27465 .62133 Mdot
.74706 .71785 Mdot
.73405 .26992 Mdot
.43574 .6374 Mdot
.60686 .75851 Mdot
.41458 .65567 Mdot
.50611 .6947 Mdot
.28001 .64315 Mdot
.56192 .3785 Mdot
.3399 .38855 Mdot
.56975 .38139 Mdot
.51796 .36753 Mdot
.51345 .3829 Mdot
.55343 .46573 Mdot
.6034 .22809 Mdot
.7236 .51728 Mdot
.57981 .44669 Mdot
.61012 .63689 Mdot
.53819 .80737 Mdot
.25748 .71155 Mdot
.54942 .35758 Mdot
.54871 .37857 Mdot
.33098 .39985 Mdot
.56661 .4403 Mdot
.41185 .61487 Mdot
.35601 .4033 Mdot
.52599 .41911 Mdot
.64784 .66868 Mdot
.53165 .3474 Mdot
.62573 .75608 Mdot
.40126 .62062 Mdot
.44934 .4437 Mdot
.60084 .41953 Mdot
.2841 .64566 Mdot
.29806 .63696 Mdot
.26689 .64598 Mdot
.41688 .60537 Mdot
.55814 .62679 Mdot
.57064 .60044 Mdot
.53819 .31823 Mdot
.54383 .41964 Mdot
.60306 .40845 Mdot
.53254 .62148 Mdot
.58305 .5313 Mdot
.20924 .49694 Mdot
.48938 .33837 Mdot
.593 .61862 Mdot
.29205 .40719 Mdot
.22335 .3464 Mdot
.34822 .40359 Mdot
.75082 .54657 Mdot
.41969 .64962 Mdot
.68706 .51622 Mdot
.56426 .21819 Mdot
.37043 .43374 Mdot
.32296 .45659 Mdot
.55316 .63755 Mdot
.41681 .53655 Mdot
.09732 .56613 Mdot
.56007 .65844 Mdot
.79016 .49457 Mdot
.34345 .42395 Mdot
.53161 .44424 Mdot
.47837 .54166 Mdot
.42776 .5335 Mdot
.56591 .63815 Mdot
.56869 .36181 Mdot
.26597 .45281 Mdot
.59755 .66718 Mdot
.50037 .36427 Mdot
.54437 .63751 Mdot
.45658 .60978 Mdot
.55066 .64606 Mdot
.3072 .4006 Mdot
.5397 .43483 Mdot
.08635 .49935 Mdot
.3425 .60723 Mdot
.57605 .38498 Mdot
.40722 .64336 Mdot
.79986 .5858 Mdot
.52235 .36887 Mdot
.68874 .50883 Mdot
.58851 .6147 Mdot
.72921 .63118 Mdot
.57005 .39915 Mdot
.56921 .6465 Mdot
.29457 .42658 Mdot
.48698 .65854 Mdot
.41361 .68651 Mdot
.29863 .62384 Mdot
.34144 .41076 Mdot
.25812 .64046 Mdot
.48083 .61608 Mdot
.51201 .4138 Mdot
.56276 .34726 Mdot
.31296 .42512 Mdot
.38868 .70752 Mdot
.51452 .4302 Mdot
.56867 .36445 Mdot
.58783 .66959 Mdot
.57592 .60572 Mdot
.30443 .71213 Mdot
.6052 .64835 Mdot
.58566 .43985 Mdot
.31385 .42822 Mdot
.53381 .41922 Mdot
.31125 .41573 Mdot
.50753 .3927 Mdot
.28497 .37334 Mdot
.3489 .40458 Mdot
.24158 .44676 Mdot
.58439 .40553 Mdot
.64045 .34339 Mdot
.51714 .3669 Mdot
.51693 .39193 Mdot
.58265 .61309 Mdot
.70929 .52294 Mdot
.49792 .36352 Mdot
.53263 .55246 Mdot
.74037 .52707 Mdot
.47141 .31583 Mdot
.55444 .62537 Mdot
.73312 .53099 Mdot
.691 .40451 Mdot
.28293 .61551 Mdot
.71653 .5122 Mdot
.30522 .73985 Mdot
.43315 .63628 Mdot
.37673 .4253 Mdot
.57528 .40506 Mdot
.69106 .76548 Mdot
.69203 .58098 Mdot
.29063 .63236 Mdot
.57161 .39233 Mdot
.53252 .36961 Mdot
.38479 .43783 Mdot
.33518 .19875 Mdot
.52417 .64958 Mdot
.52052 .40792 Mdot
.36835 .40245 Mdot
.41216 .16601 Mdot
.54199 .64375 Mdot
.7195 .50879 Mdot
.39836 .61984 Mdot
.40688 .42117 Mdot
.3003 .62725 Mdot
.4492 .59862 Mdot
.63126 .65737 Mdot
.55497 .20618 Mdot
.56458 .3996 Mdot
.58856 .625 Mdot
.63649 .25265 Mdot
.57479 .31893 Mdot
.43714 .66298 Mdot
.39948 .38225 Mdot
.35966 .43849 Mdot
.40167 .62798 Mdot
.72327 .49801 Mdot
.37452 .4287 Mdot
.33606 .43643 Mdot
.45524 .64574 Mdot
.47362 .57281 Mdot
.46884 .52993 Mdot
.40915 .64074 Mdot
.36332 .5291 Mdot
.66028 .28262 Mdot
.27624 .63783 Mdot
.72208 .50399 Mdot
.74391 .31463 Mdot
.35474 .43126 Mdot
.37593 .80703 Mdot
.60593 .23161 Mdot
.51534 .39265 Mdot
.71027 .53294 Mdot
.45945 .77381 Mdot
.61665 .60846 Mdot
.45066 .64068 Mdot
.59848 .52381 Mdot
.69414 .49868 Mdot
.54915 .3402 Mdot
.29948 .35972 Mdot
.58539 .39758 Mdot
.45722 .6331 Mdot
.37211 .49899 Mdot
.33119 .44554 Mdot
.48047 .61445 Mdot
.40224 .48639 Mdot
.54996 .43474 Mdot
.58348 .37337 Mdot
.75683 .36498 Mdot
.3449 .44936 Mdot
.30065 .6256 Mdot
.57287 .37436 Mdot
.52772 .38281 Mdot
.50846 .41235 Mdot
.65439 .38622 Mdot
.29099 .53095 Mdot
.51907 .40771 Mdot
.53737 .62517 Mdot
.60104 .40403 Mdot
.58572 .37825 Mdot
.38382 .42612 Mdot
.67599 .24506 Mdot
.26896 .62766 Mdot
.53446 .38893 Mdot
.52757 .39957 Mdot
.47226 .6254 Mdot
.47316 .53428 Mdot
.41859 .53259 Mdot
.5624 .6685 Mdot
.76728 .43907 Mdot
.61709 .37004 Mdot
.32712 .40948 Mdot
.68721 .52574 Mdot
.54742 .44313 Mdot
.33379 .40189 Mdot
.6059 .37231 Mdot
.60537 .66226 Mdot
.28011 .63866 Mdot
.58052 .47875 Mdot
.7113 .51282 Mdot
.44196 .57542 Mdot
.21956 .60187 Mdot
.60745 .64984 Mdot
.55281 .42297 Mdot
.50142 .64022 Mdot
.58581 .66245 Mdot
.29007 .62722 Mdot
.50088 .33754 Mdot
.35025 .41924 Mdot
.33373 .44509 Mdot
.68159 .29739 Mdot
.52067 .63543 Mdot
.57685 .17297 Mdot
.45749 .61133 Mdot
.53444 .33291 Mdot
.23938 .64709 Mdot
.32272 .44185 Mdot
.75093 .33751 Mdot
.73519 .52876 Mdot
.44982 .64085 Mdot
.27574 .61319 Mdot
.33002 .40291 Mdot
.31758 .44272 Mdot
.51049 .3916 Mdot
.54797 .36336 Mdot
.79167 .46423 Mdot
.70801 .30501 Mdot
.45094 .60514 Mdot
.71219 .50292 Mdot
.54856 .6628 Mdot
.55353 .43271 Mdot
.36827 .4103 Mdot
.38569 .36113 Mdot
.54405 .34663 Mdot
.5961 .66845 Mdot
.36496 .43339 Mdot
.70327 .50591 Mdot
.71255 .53725 Mdot
.51591 .3907 Mdot
.46186 .30571 Mdot
.44052 .62681 Mdot
.31004 .42941 Mdot
.33288 .47559 Mdot
.50081 .41206 Mdot
.55115 .36052 Mdot
.62249 .34118 Mdot
.45163 .59901 Mdot
.56484 .47961 Mdot
.70474 .48941 Mdot
.35527 .41466 Mdot
.57466 .38228 Mdot
.71034 .50933 Mdot
.63281 .43862 Mdot
.28772 .64183 Mdot
.54412 .63995 Mdot
.69189 .50596 Mdot
.70219 .52411 Mdot
.73697 .53427 Mdot
.3617 .79917 Mdot
.39169 .4326 Mdot
.3304 .24537 Mdot
.51094 .38218 Mdot
.66538 .2917 Mdot
.58873 .41147 Mdot
.43497 .59656 Mdot
.60161 .63085 Mdot
.52247 .36244 Mdot
.50999 .39124 Mdot
.30754 .36039 Mdot
.58913 .30079 Mdot
.41678 .45028 Mdot
.3557 .44742 Mdot
.64551 .34804 Mdot
.56966 .61945 Mdot
.41212 .15164 Mdot
.35574 .81793 Mdot
.61568 .39364 Mdot
.44137 .54012 Mdot
.35824 .40422 Mdot
.4628 .63358 Mdot
.43547 .52801 Mdot
.4047 .59714 Mdot
.35998 .41612 Mdot
.54482 .43042 Mdot
.20321 .57456 Mdot
.74249 .53538 Mdot
.54158 .35198 Mdot
.44002 .60769 Mdot
.54035 .35192 Mdot
.42178 .6007 Mdot
.40513 .40596 Mdot
.36837 .54055 Mdot
.56272 .40745 Mdot
.51356 .42562 Mdot
.51356 .47701 Mdot
.54846 .35919 Mdot
.48389 .73933 Mdot
.33407 .42768 Mdot
.24913 .42557 Mdot
.52667 .34488 Mdot
.4604 .28807 Mdot
.54978 .34326 Mdot
.39326 .71411 Mdot
.57235 .35404 Mdot
.60113 .49319 Mdot
.54852 .33908 Mdot
.5707 .35629 Mdot
.4215 .62442 Mdot
.46993 .62796 Mdot
.29537 .42702 Mdot
.3005 .63677 Mdot
.54614 .81108 Mdot
.54104 .37639 Mdot
.57049 .61073 Mdot
.2443 .64096 Mdot
.70537 .52431 Mdot
.35939 .41947 Mdot
.50126 .12995 Mdot
.44116 .60163 Mdot
.5497 .67411 Mdot
.42979 .71625 Mdot
.52937 .64608 Mdot
.53394 .67275 Mdot
.63562 .33165 Mdot
.7111 .50101 Mdot
.55201 .34214 Mdot
.49929 .2817 Mdot
.26052 .55027 Mdot
.50263 .36326 Mdot
.48858 .64646 Mdot
.55548 .29424 Mdot
.66063 .27965 Mdot
.74977 .5217 Mdot
.706 .49754 Mdot
.41908 .61828 Mdot
.56201 .67489 Mdot
.60349 .34183 Mdot
.73177 .53253 Mdot
.60412 .62982 Mdot
.28721 .65066 Mdot
.69118 .55588 Mdot
.35349 .42851 Mdot
.51289 .487 Mdot
.26255 .58957 Mdot
.44713 .60407 Mdot
.53291 .54953 Mdot
.35463 .38216 Mdot
.36927 .45855 Mdot
.28923 .64772 Mdot
.60167 .61943 Mdot
.36376 .39324 Mdot
.517 .41413 Mdot
.48034 .40201 Mdot
.55151 .38508 Mdot
.72839 .53143 Mdot
.57946 .35616 Mdot
.60784 .62971 Mdot
.45618 .62273 Mdot
.58686 .64798 Mdot
.44217 .62907 Mdot
.19885 .54983 Mdot
.55949 .39405 Mdot
.55273 .36313 Mdot
.52233 .5338 Mdot
.30984 .44 Mdot
.51782 .25361 Mdot
.59693 .61448 Mdot
.56472 .63026 Mdot
.53367 .42055 Mdot
.29767 .43356 Mdot
.70858 .54733 Mdot
.4789 .54815 Mdot
.571 .3514 Mdot
.33334 .42661 Mdot
.53253 .41413 Mdot
.67578 .69528 Mdot
.34846 .56695 Mdot
.33144 .44284 Mdot
.25846 .3042 Mdot
.57833 .41544 Mdot
.50446 .30759 Mdot
.5611 .45769 Mdot
.74326 .46277 Mdot
.49202 .39192 Mdot
.35348 .40015 Mdot
.54488 .38998 Mdot
.33216 .411 Mdot
.59575 .66063 Mdot
.46831 .61645 Mdot
.33869 .41376 Mdot
.5916 .38734 Mdot
.31127 .77826 Mdot
.44577 .60631 Mdot
.56046 .35832 Mdot
.41198 .63221 Mdot
.37416 .40859 Mdot
.32451 .44901 Mdot
.31615 .74007 Mdot
.37339 .64348 Mdot
.44071 .60509 Mdot
.54222 .41587 Mdot
.30703 .59474 Mdot
.53423 .4191 Mdot
.7923 .45626 Mdot
.51923 .34653 Mdot
.49711 .39332 Mdot
.18197 .59433 Mdot
.40933 .59094 Mdot
.54179 .15494 Mdot
.58899 .59585 Mdot
.34445 .78831 Mdot
.38647 .40415 Mdot
.74988 .522 Mdot
.59362 .75855 Mdot
.27336 .624 Mdot
.54904 .62113 Mdot
.5229 .36151 Mdot
.28406 .3708 Mdot
.406 .63842 Mdot
.71562 .52479 Mdot
.5637 .40764 Mdot
.59836 .67248 Mdot
.28329 .72335 Mdot
.45903 .6341 Mdot
.35605 .42772 Mdot
.30706 .43878 Mdot
.36123 .20433 Mdot
.57362 .3855 Mdot
.55199 .36797 Mdot
.42072 .6509 Mdot
.60323 .34863 Mdot
.72729 .54128 Mdot
.71623 .67154 Mdot
.4336 .60725 Mdot
.33893 .61173 Mdot
.36173 .44539 Mdot
.5343 .36883 Mdot
.59805 .54401 Mdot
.39205 .77754 Mdot
.35994 .25245 Mdot
.73426 .51774 Mdot
.77055 .41114 Mdot
.35305 .40009 Mdot
.44133 .61002 Mdot
.6712 .33644 Mdot
.58096 .33822 Mdot
.5302 .37285 Mdot
.76704 .40121 Mdot
.46959 .53915 Mdot
.67066 .50042 Mdot
.53766 .44892 Mdot
.4869 .53237 Mdot
.5345 .42229 Mdot
.52763 .42321 Mdot
.61681 .39048 Mdot
.58738 .37011 Mdot
.3317 .4205 Mdot
.29574 .35037 Mdot
.56271 .64958 Mdot
.45501 .21077 Mdot
.60604 .51508 Mdot
.58026 .39707 Mdot
.5463 .43239 Mdot
.26754 .34607 Mdot
.25009 .62818 Mdot
.33847 .42871 Mdot
.28151 .42991 Mdot
.46606 .60608 Mdot
.59632 .3044 Mdot
.52461 .62941 Mdot
.433 .41742 Mdot
.58535 .65788 Mdot
.33209 .42602 Mdot
.56464 .62616 Mdot
.4721 .61035 Mdot
.58903 .62566 Mdot
.54048 .61947 Mdot
.40831 .6021 Mdot
.3546 .45088 Mdot
.56247 .3507 Mdot
.45286 .6026 Mdot
.76381 .37333 Mdot
.72747 .5321 Mdot
.31411 .73979 Mdot
.54701 .45054 Mdot
.45153 .36549 Mdot
.78664 .58244 Mdot
.58439 .63577 Mdot
.33463 .56388 Mdot
.34869 .40472 Mdot
.68906 .53307 Mdot
.33148 .41617 Mdot
.56896 .22758 Mdot
.70124 .51524 Mdot
.31368 .74148 Mdot
.67478 .35211 Mdot
.60698 .56741 Mdot
.59755 .37198 Mdot
.28886 .3793 Mdot
.58874 .65746 Mdot
.41385 .64896 Mdot
.4877 .78613 Mdot
.58 .42289 Mdot
.25124 .50992 Mdot
.38817 .44273 Mdot
.28811 .61585 Mdot
.44569 .61298 Mdot
.48457 .64462 Mdot
.5704 .3885 Mdot
.59995 .55969 Mdot
.50176 .37119 Mdot
.65176 .3257 Mdot
.77705 .43786 Mdot
.41187 .3951 Mdot
.53533 .41119 Mdot
.57301 .66966 Mdot
.53492 .41478 Mdot
.46996 .35818 Mdot
.65009 .26967 Mdot
.5558 .4484 Mdot
.23457 .46693 Mdot
.7471 .61591 Mdot
.37058 .42375 Mdot
.58804 .43981 Mdot
.28374 .63102 Mdot
.56877 .42585 Mdot
.77721 .72099 Mdot
.71586 .51521 Mdot
.63339 .63732 Mdot
.59382 .38244 Mdot
.57175 .37769 Mdot
.43622 .34478 Mdot
.33593 .37123 Mdot
.27469 .6153 Mdot
.52572 .37546 Mdot
.75489 .41078 Mdot
.41695 .62522 Mdot
.54055 .33475 Mdot
.54291 .38755 Mdot
.77486 .3515 Mdot
.41537 .6297 Mdot
.58348 .62969 Mdot
.28077 .61642 Mdot
.54931 .66182 Mdot
.75255 .52414 Mdot
.41522 .52308 Mdot
.73271 .31903 Mdot
.34705 .56957 Mdot
.68818 .50613 Mdot
.58829 .35886 Mdot
.49681 .30828 Mdot
.57945 .37298 Mdot
.71187 .49723 Mdot
.41078 .62195 Mdot
.33475 .42044 Mdot
.55927 .48938 Mdot
.28605 .62295 Mdot
.49779 .3759 Mdot
.74695 .51655 Mdot
.3446 .41665 Mdot
.33345 .72844 Mdot
.35847 .41036 Mdot
.43098 .62465 Mdot
.46057 .59936 Mdot
.70504 .51727 Mdot
.33058 .41818 Mdot
.53783 .64187 Mdot
.57168 .59546 Mdot
.51354 .35259 Mdot
.43015 .66792 Mdot
.31211 .40103 Mdot
.31818 .45267 Mdot
.33593 .3921 Mdot
.56172 .39657 Mdot
.46036 .53712 Mdot
.58536 .33952 Mdot
.42913 .60464 Mdot
.54752 .62608 Mdot
.69816 .30037 Mdot
.49599 .28032 Mdot
.34187 .6037 Mdot
.49597 .37122 Mdot
.58502 .37152 Mdot
.54905 .38304 Mdot
.53163 .40386 Mdot
.69974 .68617 Mdot
.55793 .39343 Mdot
.43194 .63003 Mdot
.57241 .65975 Mdot
.57416 .39037 Mdot
.28101 .63298 Mdot
.52137 .51611 Mdot
.68612 .52287 Mdot
.60327 .49543 Mdot
.3565 .81044 Mdot
.34364 .4177 Mdot
.59837 .63911 Mdot
.54154 .63167 Mdot
.72104 .53914 Mdot
.45995 .61273 Mdot
.35287 .40844 Mdot
.7111 .45267 Mdot
.74212 .52447 Mdot
.53357 .38925 Mdot
.55492 .53908 Mdot
.24235 .32231 Mdot
.58732 .35365 Mdot
.51566 .38167 Mdot
.29322 .61408 Mdot
.52794 .65131 Mdot
.67839 .79117 Mdot
.43993 .5537 Mdot
.70799 .52131 Mdot
.69533 .50987 Mdot
.34795 .39258 Mdot
.5171 .3395 Mdot
.4465 .62625 Mdot
.4854 .54122 Mdot
.80672 .56447 Mdot
.48395 .80014 Mdot
.49342 .69436 Mdot
.52737 .35105 Mdot
.38881 .34406 Mdot
.50374 .38497 Mdot
.38236 .44482 Mdot
.33778 .39523 Mdot
.3441 .42968 Mdot
.42201 .62271 Mdot
.49523 .18114 Mdot
.43498 .6312 Mdot
.3587 .813 Mdot
.37117 .41094 Mdot
.64385 .58634 Mdot
.55716 .63078 Mdot
.53178 .32154 Mdot
.71425 .50151 Mdot
.46121 .66978 Mdot
.59503 .43296 Mdot
.27839 .51033 Mdot
.57895 .62084 Mdot
.3331 .45133 Mdot
.46809 .38114 Mdot
.57135 .8105 Mdot
.39764 .53629 Mdot
.76896 .55903 Mdot
.55975 .23725 Mdot
.70079 .5115 Mdot
.32026 .27751 Mdot
.73693 .53828 Mdot
.4538 .63869 Mdot
.5815 .42086 Mdot
.58905 .39882 Mdot
.52119 .40539 Mdot
.55551 .39566 Mdot
.41638 .6178 Mdot
.51558 .35863 Mdot
.70146 .27407 Mdot
.27126 .6345 Mdot
.64802 .61204 Mdot
.69849 .53063 Mdot
.42343 .59713 Mdot
.5788 .66214 Mdot
.29835 .64197 Mdot
.80047 .41822 Mdot
.51793 .35825 Mdot
.51958 .36425 Mdot
.27396 .64589 Mdot
.60291 .35149 Mdot
.46942 .39603 Mdot
.56753 .64979 Mdot
.42577 .49302 Mdot
.71457 .49435 Mdot
.68735 .51638 Mdot
.4044 .61529 Mdot
.33113 .41622 Mdot
.73673 .522 Mdot
.57139 .6761 Mdot
.55233 .33583 Mdot
.52239 .43278 Mdot
.31075 .40195 Mdot
.60606 .23157 Mdot
.74662 .5379 Mdot
.46543 .41888 Mdot
.33587 .40534 Mdot
.38956 .44005 Mdot
.52613 .37287 Mdot
.48842 .39718 Mdot
.34026 .45668 Mdot
.69676 .53113 Mdot
.41839 .59853 Mdot
.63353 .57423 Mdot
.45789 .62631 Mdot
.34656 .41041 Mdot
.59694 .35448 Mdot
.35727 .44912 Mdot
.57633 .41685 Mdot
.26275 .22259 Mdot
.58468 .36336 Mdot
.25969 .4234 Mdot
.75388 .46563 Mdot
.54202 .64042 Mdot
.54118 .64939 Mdot
.28003 .63642 Mdot
.34393 .40211 Mdot
.54755 .44221 Mdot
.69967 .50408 Mdot
.3281 .77462 Mdot
.3484 .47187 Mdot
.58223 .61573 Mdot
.52485 .63955 Mdot
.4128 .61881 Mdot
.55672 .34402 Mdot
.53765 .36998 Mdot
.58815 .62616 Mdot
.78217 .60402 Mdot
.32291 .41405 Mdot
.55237 .3681 Mdot
.58639 .37739 Mdot
.56268 .65194 Mdot
.57546 .59431 Mdot
.3332 .37479 Mdot
.58709 .37082 Mdot
.67862 .36386 Mdot
.42716 .5998 Mdot
.54541 .40813 Mdot
.51156 .36626 Mdot
.71104 .52922 Mdot
.65496 .63888 Mdot
.65663 .27669 Mdot
.44323 .59432 Mdot
.29858 .62197 Mdot
.58585 .4157 Mdot
.55671 .63317 Mdot
.53155 .44374 Mdot
.65617 .7549 Mdot
.27271 .62815 Mdot
.56177 .38426 Mdot
.61564 .37664 Mdot
.30676 .42673 Mdot
.56502 .38268 Mdot
.33563 .36355 Mdot
.56102 .66456 Mdot
.56233 .38543 Mdot
.46769 .29776 Mdot
.4145 .616 Mdot
.5943 .43243 Mdot
.69456 .50554 Mdot
.75095 .46929 Mdot
.23346 .60117 Mdot
.5509 .61278 Mdot
.70883 .53577 Mdot
.57764 .35427 Mdot
.58297 .67193 Mdot
.39804 .62096 Mdot
.25778 .50281 Mdot
.57796 .34529 Mdot
.45802 .61658 Mdot
.45491 .61805 Mdot
.70905 .51757 Mdot
.49275 .14315 Mdot
.61603 .37258 Mdot
.55262 .35509 Mdot
.83357 .49869 Mdot
.37515 .40268 Mdot
.55442 .35306 Mdot
.55888 .34549 Mdot
.44741 .6347 Mdot
.66271 .37802 Mdot
.35886 .48421 Mdot
.74824 .64121 Mdot
.42435 .59961 Mdot
.61571 .62887 Mdot
.58725 .66817 Mdot
.7034 .53337 Mdot
.36909 .42522 Mdot
.69281 .49762 Mdot
.5532 .64286 Mdot
.51741 .39346 Mdot
.44079 .64477 Mdot
.40355 .24839 Mdot
.41997 .65391 Mdot
.59171 .67379 Mdot
.35898 .45606 Mdot
.23598 .6474 Mdot
.86325 .50342 Mdot
.25533 .58312 Mdot
.43063 .59305 Mdot
.70562 .52467 Mdot
.45484 .55699 Mdot
.58447 .37096 Mdot
.32526 .26269 Mdot
.54737 .35225 Mdot
.5654 .23651 Mdot
.60197 .62961 Mdot
.28425 .64925 Mdot
.57949 .42421 Mdot
.76707 .41197 Mdot
.4314 .59372 Mdot
.41364 .61356 Mdot
.53292 .3965 Mdot
.43342 .62584 Mdot
.54389 .36904 Mdot
.56327 .65633 Mdot
.5045 .14774 Mdot
.57635 .36056 Mdot
.57714 .44166 Mdot
.46601 .59875 Mdot
.31337 .74004 Mdot
.61455 .63254 Mdot
.39851 .34657 Mdot
.58874 .80864 Mdot
.43712 .62473 Mdot
.54866 .4604 Mdot
.58995 .63722 Mdot
.2956 .61477 Mdot
.57093 .6867 Mdot
.53851 .35633 Mdot
.51676 .36394 Mdot
.52746 .4158 Mdot
.58435 .37607 Mdot
.30787 .27971 Mdot
.48309 .35249 Mdot
.37545 .3182 Mdot
.51701 .36837 Mdot
.26833 .42067 Mdot
.42667 .63022 Mdot
.41734 .43927 Mdot
.67865 .49203 Mdot
.51486 .36545 Mdot
.3275 .37132 Mdot
.42947 .59571 Mdot
.37825 .81795 Mdot
.41383 .6249 Mdot
.58218 .64274 Mdot
.45993 .63887 Mdot
.57729 .41359 Mdot
.36006 .43027 Mdot
.5656 .66316 Mdot
.20775 .50974 Mdot
.55507 .61827 Mdot
.57575 .3853 Mdot
.61278 .59131 Mdot
.54209 .63749 Mdot
.55642 .50934 Mdot
.36299 .4289 Mdot
.74479 .39567 Mdot
.37851 .40766 Mdot
.5645 .37704 Mdot
.56518 .3712 Mdot
.30027 .64046 Mdot
.45959 .63345 Mdot
.37149 .40721 Mdot
.71412 .25447 Mdot
.7401 .50267 Mdot
.34448 .43577 Mdot
.48754 .38167 Mdot
.45409 .54199 Mdot
.31373 .43335 Mdot
.74689 .4347 Mdot
.45864 .63199 Mdot
.35291 .39099 Mdot
.50443 .33704 Mdot
.62555 .46476 Mdot
.72047 .54413 Mdot
.60766 .66006 Mdot
.4892 .51315 Mdot
.58113 .66868 Mdot
.48356 .61775 Mdot
.52024 .6494 Mdot
.41935 .62848 Mdot
.2528 .40234 Mdot
.37528 .4964 Mdot
.48427 .6085 Mdot
.47278 .60713 Mdot
.56018 .64157 Mdot
.53019 .40238 Mdot
.62591 .53162 Mdot
.49032 .37103 Mdot
.60151 .3765 Mdot
.43756 .59831 Mdot
.3544 .39861 Mdot
.37159 .44111 Mdot
.28386 .38762 Mdot
.31842 .44547 Mdot
.57646 .66474 Mdot
.34548 .55798 Mdot
.55563 .22512 Mdot
.40952 .6333 Mdot
.38216 .62085 Mdot
.53773 .42236 Mdot
.55673 .63659 Mdot
.59968 .65895 Mdot
.45108 .62796 Mdot
.39591 .22782 Mdot
.59582 .42335 Mdot
.38551 .42732 Mdot
.3719 .41189 Mdot
.31661 .43449 Mdot
.31301 .40608 Mdot
.45316 .181 Mdot
.41397 .64911 Mdot
.35375 .40164 Mdot
.54521 .39589 Mdot
.52949 .35242 Mdot
.29401 .62126 Mdot
.69231 .52078 Mdot
.58803 .4203 Mdot
.5889 .42443 Mdot
.52736 .3713 Mdot
.5433 .63835 Mdot
.5792 .31037 Mdot
.2761 .62498 Mdot
.52154 .64766 Mdot
.52993 .62496 Mdot
.28981 .6456 Mdot
.38399 .46464 Mdot
.55862 .82414 Mdot
.52107 .40831 Mdot
.59291 .28732 Mdot
.56153 .63461 Mdot
.33402 .51442 Mdot
.56414 .47713 Mdot
.5407 .41232 Mdot
.6464 .51454 Mdot
.56297 .65867 Mdot
.3745 .4603 Mdot
.54573 .35651 Mdot
.2766 .64313 Mdot
.69155 .53029 Mdot
.49924 .34544 Mdot
.29241 .6134 Mdot
.32977 .42552 Mdot
.75495 .59492 Mdot
.36886 .39594 Mdot
.53997 .64007 Mdot
.591 .43745 Mdot
.08753 .54604 Mdot
.59039 .65694 Mdot
.40553 .80628 Mdot
.38898 .49343 Mdot
.58026 .36279 Mdot
.58469 .66682 Mdot
.37448 .45854 Mdot
.42838 .59963 Mdot
.50774 .52653 Mdot
.36867 .41138 Mdot
.29507 .64525 Mdot
.29859 .62978 Mdot
.56351 .65058 Mdot
.35859 .44323 Mdot
.52052 .34815 Mdot
.31528 .41003 Mdot
.45436 .64513 Mdot
.56402 .41465 Mdot
.5483 .81173 Mdot
.4806 .40379 Mdot
.3351 .40445 Mdot
.57887 .67748 Mdot
.73799 .50894 Mdot
.56204 .40641 Mdot
.46664 .8194 Mdot
.55995 .34462 Mdot
.41067 .62796 Mdot
.31137 .49887 Mdot
.38678 .25713 Mdot
.52435 .39863 Mdot
.54111 .42817 Mdot
.40384 .61296 Mdot
.5221 .3982 Mdot
.57944 .34871 Mdot
.44937 .66137 Mdot
.31162 .43527 Mdot
.55437 .38218 Mdot
.60681 .65552 Mdot
.56891 .25421 Mdot
.57423 .43348 Mdot
.22132 .46055 Mdot
.75561 .40259 Mdot
.31754 .49564 Mdot
.55285 .44453 Mdot
.76651 .37082 Mdot
.56251 .36685 Mdot
.55847 .4015 Mdot
.52652 .40969 Mdot
.36628 .3421 Mdot
.55565 .64093 Mdot
.59645 .61928 Mdot
.7048 .54253 Mdot
.75912 .40983 Mdot
.71447 .53287 Mdot
.41041 .60293 Mdot
.38461 .68985 Mdot
.27216 .63368 Mdot
.33155 .41424 Mdot
.53546 .43179 Mdot
.54536 .62075 Mdot
.53484 .36554 Mdot
.56671 .42593 Mdot
.5539 .65349 Mdot
.58868 .66378 Mdot
.5168 .63374 Mdot
.74256 .53066 Mdot
.34013 .4235 Mdot
.51344 .39479 Mdot
.74066 .52568 Mdot
.52963 .34065 Mdot
.45719 .54645 Mdot
.33992 .42596 Mdot
.31326 .41176 Mdot
.37951 .43095 Mdot
.51095 .38021 Mdot
.5781 .40903 Mdot
.4368 .63152 Mdot
.31426 .39874 Mdot
.40816 .63542 Mdot
.58218 .66711 Mdot
.5423 .64823 Mdot
.53813 .35615 Mdot
.46443 .40079 Mdot
.69507 .5144 Mdot
.58243 .63844 Mdot
.26548 .63992 Mdot
.7025 .54142 Mdot
.57096 .3929 Mdot
.57856 .66782 Mdot
.68734 .51389 Mdot
.44438 .22131 Mdot
.62151 .80142 Mdot
.743 .51442 Mdot
.53372 .39596 Mdot
.4487 .33055 Mdot
.67661 .32799 Mdot
.73339 .49696 Mdot
.41854 .64101 Mdot
.55226 .34557 Mdot
.79258 .6058 Mdot
.70418 .49301 Mdot
.61176 .2355 Mdot
.55009 .64951 Mdot
.64837 .33872 Mdot
.49626 .34795 Mdot
.37495 .22488 Mdot
.69766 .49439 Mdot
.35272 .4111 Mdot
.33475 .38657 Mdot
.53057 .39197 Mdot
.71067 .486 Mdot
.45081 .6504 Mdot
.54044 .63224 Mdot
.55193 .61495 Mdot
.3539 .44489 Mdot
.34487 .58645 Mdot
.6022 .66143 Mdot
.59298 .44035 Mdot
.606 .67768 Mdot
.62354 .32843 Mdot
.38581 .19826 Mdot
.20079 .52373 Mdot
.51984 .42748 Mdot
.73687 .50555 Mdot
.39956 .60928 Mdot
.43591 .62953 Mdot
.42488 .62143 Mdot
.54635 .65636 Mdot
.45662 .52614 Mdot
.58973 .62329 Mdot
.25604 .5221 Mdot
.71112 .50872 Mdot
.72909 .39002 Mdot
.55484 .44199 Mdot
.58115 .36491 Mdot
.54762 .33461 Mdot
.5273 .41694 Mdot
.56104 .36672 Mdot
.44899 .60507 Mdot
.53436 .6487 Mdot
.7332 .63341 Mdot
.32333 .43544 Mdot
.32637 .70837 Mdot
.55737 .63034 Mdot
.28569 .61402 Mdot
.7241 .52015 Mdot
.73151 .32295 Mdot
.61554 .62058 Mdot
.5646 .62681 Mdot
.57323 .34104 Mdot
.3455 .39691 Mdot
.65259 .40163 Mdot
.56861 .36415 Mdot
.58295 .63712 Mdot
.56669 .67996 Mdot
.33358 .27182 Mdot
.62566 .387 Mdot
.72524 .55083 Mdot
.45135 .54089 Mdot
.69654 .49224 Mdot
.49078 .40768 Mdot
.33287 .51631 Mdot
.55555 .64374 Mdot
.57998 .64799 Mdot
.74238 .50843 Mdot
.47887 .33321 Mdot
.36556 .43596 Mdot
.28216 .64941 Mdot
.42014 .63848 Mdot
.57446 .36831 Mdot
.55179 .66057 Mdot
.57649 .288 Mdot
.54838 .54028 Mdot
.42895 .61081 Mdot
.52253 .64803 Mdot
.54712 .34341 Mdot
.52695 .39434 Mdot
.69959 .51473 Mdot
.66587 .56846 Mdot
.4904 .36387 Mdot
.34545 .789 Mdot
.37701 .5316 Mdot
.44734 .46071 Mdot
.53056 .3729 Mdot
.34262 .44811 Mdot
.28048 .64381 Mdot
.72338 .50417 Mdot
.53648 .33969 Mdot
.59733 .8152 Mdot
.30567 .39694 Mdot
.44651 .60837 Mdot
.28004 .64482 Mdot
.46516 .52465 Mdot
.56193 .34497 Mdot
.54737 .35244 Mdot
.55896 .39612 Mdot
.61329 .81551 Mdot
.60207 .62637 Mdot
.3267 .39461 Mdot
.73427 .51982 Mdot
.30342 .42732 Mdot
.58834 .61575 Mdot
.50516 .49946 Mdot
.57389 .39392 Mdot
.38364 .43389 Mdot
.35623 .41185 Mdot
.41262 .61808 Mdot
.44748 .59788 Mdot
.57272 .60333 Mdot
.58198 .36057 Mdot
.27255 .64049 Mdot
.35847 .39579 Mdot
.53588 .65986 Mdot
.70106 .51369 Mdot
.45864 .60272 Mdot
.51536 .37101 Mdot
.56113 .64732 Mdot
.50081 .39314 Mdot
.31196 .41787 Mdot
.56324 .62758 Mdot
.28368 .61229 Mdot
.69346 .51459 Mdot
.51537 .36764 Mdot
.76912 .59239 Mdot
.28249 .64717 Mdot
.58733 .39512 Mdot
.45871 .33663 Mdot
.69736 .48276 Mdot
.20704 .50439 Mdot
.60098 .63535 Mdot
.27859 .62827 Mdot
.33552 .39436 Mdot
.63364 .45048 Mdot
.58041 .65291 Mdot
.40461 .37293 Mdot
.63776 .54758 Mdot
.5169 .39799 Mdot
.34948 .4392 Mdot
.67277 .53205 Mdot
.37775 .81082 Mdot
.68466 .3475 Mdot
.55242 .37266 Mdot
.58209 .66883 Mdot
.68696 .51785 Mdot
.40711 .62795 Mdot
.22252 .46046 Mdot
.38008 .20498 Mdot
.52186 .64209 Mdot
.51253 .40123 Mdot
.35651 .39567 Mdot
.45175 .62525 Mdot
.19801 .56685 Mdot
.57584 .67608 Mdot
.60621 .64071 Mdot
.56744 .39965 Mdot
.73469 .51474 Mdot
.77153 .62743 Mdot
.60232 .62414 Mdot
.54528 .65951 Mdot
.3175 .71233 Mdot
.74758 .53354 Mdot
.54285 .39426 Mdot
.28389 .38743 Mdot
.5557 .33735 Mdot
.35639 .78793 Mdot
.27569 .63079 Mdot
.32092 .43277 Mdot
.5373 .351 Mdot
.7438 .61917 Mdot
.58299 .65897 Mdot
.44086 .53939 Mdot
.50031 .61224 Mdot
.45732 .60832 Mdot
.55326 .66044 Mdot
.5419 .36104 Mdot
.45629 .59572 Mdot
.69505 .51685 Mdot
.58707 .37026 Mdot
.5759 .41332 Mdot
.3772 .45431 Mdot
.44501 .64644 Mdot
.58204 .26504 Mdot
.47094 .63462 Mdot
.40191 .62026 Mdot
.39308 .43445 Mdot
.53168 .39066 Mdot
.57734 .63422 Mdot
.60399 .66757 Mdot
.5135 .35947 Mdot
.33944 .51541 Mdot
.36145 .43833 Mdot
.63594 .65454 Mdot
.67892 .78799 Mdot
.61859 .36789 Mdot
.26599 .6346 Mdot
.621 .28192 Mdot
.41496 .60853 Mdot
.5179 .38926 Mdot
.32897 .4104 Mdot
.53874 .65745 Mdot
.6026 .6627 Mdot
.56876 .336 Mdot
.45478 .62628 Mdot
.68443 .51682 Mdot
.60364 .65025 Mdot
.54088 .54086 Mdot
.56546 .38671 Mdot
.24922 .50779 Mdot
.60163 .64558 Mdot
.25963 .72811 Mdot
.73835 .6254 Mdot
.33478 .44276 Mdot
.55763 .42922 Mdot
.29986 .43335 Mdot
.73271 .52414 Mdot
.56043 .68516 Mdot
.45581 .62723 Mdot
.47192 .44856 Mdot
.76513 .32424 Mdot
.5528 .63764 Mdot
.33213 .42209 Mdot
.5124 .38698 Mdot
.49128 .45962 Mdot
.5716 .35294 Mdot
.66166 .41297 Mdot
.77447 .53071 Mdot
.47082 .60738 Mdot
.40789 .6205 Mdot
.5494 .43444 Mdot
.73535 .53781 Mdot
.6136 .64538 Mdot
.55272 .65116 Mdot
.41055 .14717 Mdot
.28794 .61139 Mdot
.78872 .47588 Mdot
.51226 .37652 Mdot
.53147 .65243 Mdot
.50277 .27537 Mdot
.42048 .65068 Mdot
.51322 .34726 Mdot
.53141 .6338 Mdot
.38112 .76577 Mdot
.46378 .5436 Mdot
.55936 .38073 Mdot
.60241 .34663 Mdot
.41366 .63347 Mdot
.45172 .55584 Mdot
.58824 .62338 Mdot
.5269 .33896 Mdot
.48001 .6355 Mdot
.30531 .72461 Mdot
.74331 .29774 Mdot
.34049 .42388 Mdot
.57621 .67864 Mdot
.45541 .60744 Mdot
.5998 .32392 Mdot
.69651 .52932 Mdot
.55586 .66718 Mdot
.54562 .62501 Mdot
.56004 .41995 Mdot
.58209 .42879 Mdot
.62165 .37905 Mdot
.33418 .43426 Mdot
.43787 .63557 Mdot
.5637 .43619 Mdot
.35878 .56505 Mdot
.52087 .41143 Mdot
.44197 .63457 Mdot
.11209 .41649 Mdot
.58708 .3502 Mdot
.55945 .35266 Mdot
.67233 .47153 Mdot
.37236 .43474 Mdot
.30921 .43672 Mdot
.35686 .55175 Mdot
.51247 .3755 Mdot
.61869 .56591 Mdot
.33931 .42062 Mdot
.36027 .43746 Mdot
.63731 .58798 Mdot
.55858 .41435 Mdot
.43802 .57348 Mdot
.44741 .62758 Mdot
.45517 .60545 Mdot
.30724 .42323 Mdot
.52951 .32257 Mdot
.39818 .61731 Mdot
.28698 .29721 Mdot
.55738 .62752 Mdot
.33213 .51628 Mdot
.32239 .40621 Mdot
.62156 .55207 Mdot
.45687 .63524 Mdot
.31759 .79802 Mdot
.62617 .47375 Mdot
.50283 .37406 Mdot
.52694 .39708 Mdot
.70615 .52828 Mdot
.50256 .4534 Mdot
.29731 .62037 Mdot
.43102 .62584 Mdot
.65879 .71127 Mdot
.34472 .43031 Mdot
.56401 .35329 Mdot
.70219 .3049 Mdot
.21226 .56523 Mdot
.24077 .46438 Mdot
.36992 .42027 Mdot
.35209 .43354 Mdot
.5746 .61906 Mdot
.54831 .62953 Mdot
.55048 .39037 Mdot
.42356 .62557 Mdot
.34913 .38785 Mdot
.43438 .64052 Mdot
.55388 .64364 Mdot
.56643 .62907 Mdot
.27552 .62372 Mdot
.56408 .32029 Mdot
.54553 .64829 Mdot
.32377 .73291 Mdot
.36253 .56093 Mdot
.36156 .46445 Mdot
.85882 .50042 Mdot
.19441 .56705 Mdot
.69714 .46531 Mdot
.69398 .53351 Mdot
.30924 .61594 Mdot
.46638 .63015 Mdot
.54513 .43276 Mdot
.52747 .36144 Mdot
.29454 .6283 Mdot
.46332 .61766 Mdot
.72103 .52529 Mdot
.45945 .63431 Mdot
.72125 .50554 Mdot
.59631 .61538 Mdot
.577 .43062 Mdot
.5722 .34821 Mdot
.43609 .605 Mdot
.58311 .62741 Mdot
.54069 .63986 Mdot
.70577 .54111 Mdot
.73402 .33118 Mdot
.5616 .64993 Mdot
.32127 .40662 Mdot
.51046 .23608 Mdot
.29804 .62969 Mdot
.54671 .35685 Mdot
.71841 .31074 Mdot
.34108 .2602 Mdot
.51594 .39961 Mdot
.28028 .64542 Mdot
.43146 .14029 Mdot
.58183 .42204 Mdot
.39581 .17125 Mdot
.27985 .62356 Mdot
.36207 .44755 Mdot
.59282 .63972 Mdot
.30048 .62375 Mdot
.58437 .31412 Mdot
.74471 .55273 Mdot
.55626 .44784 Mdot
.37177 .41531 Mdot
.37461 .44527 Mdot
.39345 .49773 Mdot
.36157 .78978 Mdot
.73095 .50515 Mdot
.71592 .52192 Mdot
.57812 .65417 Mdot
.3644 .65959 Mdot
.49905 .41422 Mdot
.71327 .52341 Mdot
.68965 .70746 Mdot
.53749 .42082 Mdot
.78917 .4446 Mdot
.6446 .51294 Mdot
.34639 .44771 Mdot
.39484 .46409 Mdot
.58132 .65657 Mdot
.33273 .4224 Mdot
.46901 .48091 Mdot
.54707 .33491 Mdot
.34132 .42792 Mdot
.44418 .63594 Mdot
.47272 .7616 Mdot
.31585 .44601 Mdot
.51286 .52955 Mdot
.44645 .62516 Mdot
.69714 .48356 Mdot
.69754 .4146 Mdot
.75827 .7533 Mdot
.42889 .62612 Mdot
.58763 .63745 Mdot
.54323 .64637 Mdot
.56317 .65388 Mdot
.36959 .41196 Mdot
.59435 .66085 Mdot
.32447 .43081 Mdot
.59484 .59929 Mdot
.75789 .3544 Mdot
.7049 .51479 Mdot
.38657 .65675 Mdot
.35651 .41958 Mdot
.28845 .54712 Mdot
.84791 .46296 Mdot
.53706 .3973 Mdot
.47607 .6333 Mdot
.73612 .50307 Mdot
.31626 .65056 Mdot
.71192 .52977 Mdot
.59043 .63673 Mdot
.33021 .51636 Mdot
.54447 .36987 Mdot
.35151 .36277 Mdot
.69868 .50281 Mdot
.36988 .4156 Mdot
.58776 .38559 Mdot
.55532 .60446 Mdot
.71233 .53552 Mdot
.69227 .5304 Mdot
.55946 .36437 Mdot
.33853 .45105 Mdot
.57224 .62975 Mdot
.47112 .62378 Mdot
.6704 .51034 Mdot
.55818 .31476 Mdot
.52771 .40269 Mdot
.53954 .33063 Mdot
.41687 .53501 Mdot
.78113 .62048 Mdot
.439 .62389 Mdot
.67683 .31615 Mdot
.54595 .63885 Mdot
.68249 .35591 Mdot
.29296 .57004 Mdot
.40303 .66368 Mdot
.27575 .62955 Mdot
.27468 .6325 Mdot
.55931 .3756 Mdot
.76173 .65241 Mdot
.24999 .43307 Mdot
.44317 .65889 Mdot
.29563 .63802 Mdot
.54077 .6391 Mdot
.31247 .39641 Mdot
.42525 .43779 Mdot
.59304 .40353 Mdot
.45023 .59866 Mdot
.55534 .64811 Mdot
.65875 .75404 Mdot
.71253 .51013 Mdot
.33419 .54937 Mdot
.57571 .39 Mdot
.55168 .36541 Mdot
.44325 .61545 Mdot
.43728 .63105 Mdot
.23232 .48586 Mdot
.39407 .5064 Mdot
.50499 .7958 Mdot
.43178 .57474 Mdot
.68312 .74243 Mdot
.35769 .37952 Mdot
.3312 .40667 Mdot
.27722 .61932 Mdot
.40165 .61268 Mdot
.55137 .35129 Mdot
.36573 .44566 Mdot
.24307 .46239 Mdot
.39539 .43734 Mdot
.78223 .43664 Mdot
.62745 .56542 Mdot
.58117 .38483 Mdot
.33981 .39727 Mdot
.33471 .42405 Mdot
.30216 .41938 Mdot
.28916 .64525 Mdot
.52768 .3753 Mdot
.53139 .40264 Mdot
.58155 .41986 Mdot
.47826 .44516 Mdot
.56568 .38353 Mdot
.30078 .57687 Mdot
.34001 .61233 Mdot
.65887 .67822 Mdot
.51038 .395 Mdot
.46089 .61965 Mdot
.53279 .4299 Mdot
.72893 .54009 Mdot
.50985 .3983 Mdot
.79603 .4671 Mdot
.42976 .61737 Mdot
.46859 .34928 Mdot
.60163 .68688 Mdot
.57638 .39138 Mdot
.68843 .50672 Mdot
.77783 .62517 Mdot
.69451 .2903 Mdot
.31886 .71623 Mdot
.3202 .40718 Mdot
.57307 .60551 Mdot
.43997 .6535 Mdot
.57696 .63563 Mdot
.51031 .3557 Mdot
.26745 .63369 Mdot
.17241 .56587 Mdot
.60405 .54005 Mdot
.54788 .35006 Mdot
.50063 .33358 Mdot
.32911 .44438 Mdot
.58621 .65972 Mdot
.39675 .40157 Mdot
.55914 .39954 Mdot
.73445 .52565 Mdot
.73681 .52768 Mdot
.43255 .46951 Mdot
.62332 .74951 Mdot
.64446 .43561 Mdot
.44266 .61742 Mdot
.60014 .66543 Mdot
.69789 .49466 Mdot
.25497 .40835 Mdot
.444 .65406 Mdot
.41523 .60842 Mdot
.44313 .64629 Mdot
.58081 .37766 Mdot
.28268 .61813 Mdot
.65781 .73197 Mdot
.29933 .64002 Mdot
.57824 .39452 Mdot
.55342 .62151 Mdot
.30072 .62297 Mdot
.7096 .53127 Mdot
.40493 .61507 Mdot
.54805 .63487 Mdot
.566 .37454 Mdot
.34426 .42004 Mdot
.68316 .30315 Mdot
.79589 .52789 Mdot
.63466 .6207 Mdot
.63365 .61667 Mdot
.37931 .42033 Mdot
.46439 .83429 Mdot
.4311 .66789 Mdot
.3896 .2304 Mdot
.69032 .54833 Mdot
.51228 .36071 Mdot
.54566 .1709 Mdot
.59182 .62599 Mdot
.57068 .66451 Mdot
.55907 .38497 Mdot
.55795 .67288 Mdot
.56666 .35289 Mdot
.5815 .61798 Mdot
.42451 .80203 Mdot
.59583 .38538 Mdot
.57286 .66431 Mdot
.49539 .40967 Mdot
.56864 .40501 Mdot
.33281 .44649 Mdot
.55006 .66506 Mdot
.50124 .37952 Mdot
.16334 .56428 Mdot
.4195 .61089 Mdot
.29246 .6439 Mdot
.37379 .65254 Mdot
.454 .64158 Mdot
.34055 .43964 Mdot
.58421 .42195 Mdot
.69756 .5137 Mdot
.34979 .41312 Mdot
.54256 .61025 Mdot
.70355 .49861 Mdot
.34603 .56017 Mdot
.31659 .41111 Mdot
.29445 .6238 Mdot
.69585 .51047 Mdot
.56338 .44866 Mdot
.55807 .65923 Mdot
.80739 .54673 Mdot
.29884 .63992 Mdot
.53852 .36893 Mdot
.60802 .67055 Mdot
.4585 .63516 Mdot
.54552 .38598 Mdot
.58124 .67001 Mdot
.28536 .64627 Mdot
.5834 .40073 Mdot
.58637 .39577 Mdot
.43233 .43606 Mdot
.28233 .48826 Mdot
.70039 .51772 Mdot
.38802 .44125 Mdot
.54777 .39555 Mdot
.73615 .5381 Mdot
.46776 .70571 Mdot
.52511 .42804 Mdot
.30383 .43919 Mdot
.48722 .46461 Mdot
.54834 .62814 Mdot
.40702 .63298 Mdot
.59394 .67343 Mdot
.68946 .52832 Mdot
.73656 .2569 Mdot
.28594 .6155 Mdot
.53009 .31899 Mdot
.54406 .33409 Mdot
.53122 .66604 Mdot
.33591 .42796 Mdot
.47621 .78608 Mdot
.51403 .37081 Mdot
.48683 .35151 Mdot
.5541 .35908 Mdot
.73345 .62666 Mdot
.36367 .4363 Mdot
.5503 .357 Mdot
.47518 .35812 Mdot
.54764 .44661 Mdot
.68517 .50998 Mdot
.72109 .39898 Mdot
.52969 .42643 Mdot
.1202 .61599 Mdot
.27259 .64477 Mdot
.55596 .65415 Mdot
.5023 .55695 Mdot
.56138 .71073 Mdot
.39381 .19196 Mdot
.32875 .43268 Mdot
.64086 .38092 Mdot
.57435 .632 Mdot
.67625 .26959 Mdot
.42743 .83251 Mdot
.57174 .40332 Mdot
.54445 .34438 Mdot
.59042 .63677 Mdot
.53356 .65535 Mdot
.2695 .63508 Mdot
.5051 .38619 Mdot
.50005 .33817 Mdot
.54945 .67216 Mdot
.57168 .37706 Mdot
.29852 .32663 Mdot
.47826 .61848 Mdot
.30699 .43069 Mdot
.40716 .62825 Mdot
.42299 .6047 Mdot
.48761 .20396 Mdot
.37711 .5312 Mdot
.44029 .63357 Mdot
.42012 .65967 Mdot
.80005 .46891 Mdot
.47833 .45851 Mdot
.68997 .5004 Mdot
.58257 .7728 Mdot
.57158 .65428 Mdot
.5261 .37631 Mdot
.36254 .40241 Mdot
.40679 .20755 Mdot
.42744 .74729 Mdot
.31965 .52161 Mdot
.53566 .40107 Mdot
.57783 .65917 Mdot
.28933 .64674 Mdot
.59465 .39274 Mdot
.67851 .34818 Mdot
.55126 .36934 Mdot
.53873 .63411 Mdot
.51372 .20689 Mdot
.37939 .37305 Mdot
.44558 .57538 Mdot
.31946 .46254 Mdot
.5566 .43997 Mdot
.31638 .41813 Mdot
.45841 .61524 Mdot
.74123 .53235 Mdot
.70553 .5233 Mdot
.58548 .37481 Mdot
.37427 .49671 Mdot
.66249 .53734 Mdot
.56691 .40462 Mdot
.56059 .41772 Mdot
.27827 .62666 Mdot
.56153 .41698 Mdot
.53765 .33618 Mdot
.54842 .43644 Mdot
.50574 .40793 Mdot
.40174 .61928 Mdot
.44155 .36166 Mdot
.51417 .41203 Mdot
.61793 .35863 Mdot
.46359 .60333 Mdot
.61906 .33095 Mdot
.41471 .6251 Mdot
.56229 .80149 Mdot
.41934 .63433 Mdot
.70497 .52139 Mdot
.61641 .64941 Mdot
.64052 .34419 Mdot
.35183 .3887 Mdot
.44417 .59643 Mdot
.72261 .51181 Mdot
.42703 .62407 Mdot
.60913 .64109 Mdot
.84325 .5092 Mdot
.39373 .42349 Mdot
.46194 .54903 Mdot
.64149 .48167 Mdot
.24741 .50573 Mdot
.5584 .6245 Mdot
.35227 .44459 Mdot
.3418 .36424 Mdot
.55487 .43571 Mdot
.69597 .5198 Mdot
.55834 .37404 Mdot
.40306 .62068 Mdot
.57369 .65755 Mdot
.61291 .59379 Mdot
.7 .51933 Mdot
.79687 .34544 Mdot
.55174 .6186 Mdot
.60508 .37449 Mdot
.46337 .6019 Mdot
.85606 .49112 Mdot
.41656 .63286 Mdot
.75434 .34663 Mdot
.28514 .42079 Mdot
.53389 .20818 Mdot
.3564 .42939 Mdot
.23284 .44534 Mdot
.52629 .85456 Mdot
.43025 .82501 Mdot
.34266 .41136 Mdot
.63401 .66073 Mdot
.57384 .38483 Mdot
.52659 .41834 Mdot
.60989 .41952 Mdot
.36439 .46562 Mdot
.55445 .39472 Mdot
.29701 .62166 Mdot
.38355 .53423 Mdot
.73346 .66274 Mdot
.58921 .60627 Mdot
.56664 .35154 Mdot
.43912 .59871 Mdot
.40706 .64383 Mdot
.30211 .62894 Mdot
.46095 .64094 Mdot
.56216 .40841 Mdot
.35727 .4223 Mdot
.61738 .53563 Mdot
.72683 .53001 Mdot
.24522 .68122 Mdot
.67363 .51953 Mdot
.60053 .60689 Mdot
.61516 .39681 Mdot
.56589 .62864 Mdot
.63137 .18052 Mdot
.5381 .42768 Mdot
.33696 .41924 Mdot
.58585 .38678 Mdot
.55248 .43798 Mdot
.51505 .40859 Mdot
.58861 .6698 Mdot
.50209 .56213 Mdot
.5712 .37431 Mdot
.45575 .63 Mdot
.64483 .61461 Mdot
.59058 .41814 Mdot
.6078 .72727 Mdot
.7704 .43269 Mdot
.25965 .52007 Mdot
.34604 .46647 Mdot
.5881 .64603 Mdot
.34791 .43146 Mdot
.36443 .46818 Mdot
.34029 .43965 Mdot
.64861 .72125 Mdot
.65262 .35347 Mdot
.36352 .18573 Mdot
.49433 .26485 Mdot
.41256 .21244 Mdot
.384 .42687 Mdot
.49351 .72144 Mdot
.33198 .40861 Mdot
.33274 .43643 Mdot
.21292 .27514 Mdot
.34408 .40302 Mdot
.53655 .35722 Mdot
.59334 .35438 Mdot
.24217 .58795 Mdot
.79965 .45205 Mdot
.51038 .39761 Mdot
.55223 .39315 Mdot
.73746 .51172 Mdot
.4621 .39396 Mdot
.30476 .63644 Mdot
.34428 .53654 Mdot
.30351 .65026 Mdot
.55964 .36534 Mdot
.55845 .38951 Mdot
.51331 .33705 Mdot
.52861 .85889 Mdot
.3982 .20499 Mdot
.37579 .4418 Mdot
.56837 .30132 Mdot
.31208 .74831 Mdot
.57445 .34446 Mdot
.58391 .35444 Mdot
.57711 .41551 Mdot
.57635 .63324 Mdot
.31401 .39368 Mdot
.4821 .36506 Mdot
.24712 .54175 Mdot
.5725 .39175 Mdot
.46286 .66054 Mdot
.69291 .48041 Mdot
.54094 .36058 Mdot
.30201 .42661 Mdot
.53096 .41397 Mdot
.32909 .40089 Mdot
.30737 .42731 Mdot
.54794 .31832 Mdot
.64854 .73772 Mdot
.29667 .41471 Mdot
.57998 .39928 Mdot
.58329 .63052 Mdot
.38075 .81012 Mdot
.53789 .36744 Mdot
.73235 .50883 Mdot
.51774 .39137 Mdot
.68535 .51293 Mdot
.57094 .41403 Mdot
.29611 .64411 Mdot
.37163 .2671 Mdot
.57915 .64922 Mdot
.66966 .51714 Mdot
.53962 .66457 Mdot
.45293 .4486 Mdot
.33918 .45406 Mdot
.3039 .64043 Mdot
.34696 .22056 Mdot
.27944 .62557 Mdot
.66925 .29767 Mdot
.40596 .72416 Mdot
.43072 .60387 Mdot
.3156 .40433 Mdot
.64227 .29647 Mdot
.59707 .73634 Mdot
.52022 .6318 Mdot
.52766 .62647 Mdot
.67712 .2191 Mdot
.49802 .14597 Mdot
.57135 .36909 Mdot
.81458 .58112 Mdot
.38157 .30569 Mdot
.52119 .43379 Mdot
.5151 .44011 Mdot
.53922 .62853 Mdot
.55989 .44042 Mdot
.50244 .51789 Mdot
.5592 .6411 Mdot
.72014 .51562 Mdot
.31946 .43043 Mdot
.69209 .5267 Mdot
.52235 .78491 Mdot
.35628 .57797 Mdot
.54827 .64115 Mdot
.51308 .41699 Mdot
.57686 .36608 Mdot
.32816 .39761 Mdot
.29466 .36482 Mdot
.31126 .43592 Mdot
.72005 .49772 Mdot
.56936 .64382 Mdot
.37434 .22192 Mdot
.51595 .38428 Mdot
.35897 .41297 Mdot
.53842 .67846 Mdot
.52619 .39422 Mdot
.44179 .60469 Mdot
.53549 .40214 Mdot
.34826 .40653 Mdot
.56244 .41686 Mdot
.35628 .42437 Mdot
.58561 .62441 Mdot
.55614 .34116 Mdot
.55602 .38859 Mdot
.65581 .27554 Mdot
.722 .5256 Mdot
.34727 .45383 Mdot
.49629 .51542 Mdot
.56001 .33884 Mdot
.6779 .35374 Mdot
.57949 .42715 Mdot
.62569 .42016 Mdot
.48875 .39516 Mdot
.29484 .62083 Mdot
.50906 .35002 Mdot
.53922 .36725 Mdot
.41287 .3667 Mdot
.4739 .2971 Mdot
.41163 .45011 Mdot
.43617 .59432 Mdot
.30253 .42753 Mdot
.54404 .65088 Mdot
.537 .6526 Mdot
.59949 .65442 Mdot
.79494 .42393 Mdot
.55505 .31356 Mdot
.54303 .37139 Mdot
.47077 .60624 Mdot
.71359 .52057 Mdot
.36686 .41428 Mdot
.70877 .51727 Mdot
.3454 .53325 Mdot
.70905 .49623 Mdot
.29469 .61826 Mdot
.73943 .62494 Mdot
.28565 .3107 Mdot
.72397 .503 Mdot
.31014 .43496 Mdot
.61957 .56176 Mdot
.50903 .3656 Mdot
.35562 .75519 Mdot
.73506 .52465 Mdot
.71061 .24954 Mdot
.5914 .38935 Mdot
.50072 .52416 Mdot
.41602 .61875 Mdot
.69039 .52136 Mdot
.44382 .64747 Mdot
.53115 .41738 Mdot
.20724 .49941 Mdot
.33144 .41835 Mdot
.48201 .61418 Mdot
.50101 .36949 Mdot
.69152 .52533 Mdot
.54696 .64521 Mdot
.58258 .48814 Mdot
.46088 .61016 Mdot
.68522 .29161 Mdot
.68448 .34748 Mdot
.56724 .64267 Mdot
.2438 .32436 Mdot
.4259 .64726 Mdot
.51492 .4226 Mdot
.64501 .40223 Mdot
.53398 .41067 Mdot
.53958 .6481 Mdot
.58126 .66589 Mdot
.27 .59759 Mdot
.58417 .37866 Mdot
.59044 .39724 Mdot
.33828 .3821 Mdot
.55435 .63598 Mdot
.34994 .44163 Mdot
.32662 .39351 Mdot
.5885 .63426 Mdot
.33747 .4434 Mdot
.69728 .50408 Mdot
.38904 .52758 Mdot
.42508 .64613 Mdot
.45438 .61521 Mdot
.5451 .64683 Mdot
.60985 .63645 Mdot
.56316 .62886 Mdot
.53926 .40295 Mdot
.36812 .43687 Mdot
.55226 .42673 Mdot
.52785 .42547 Mdot
.2823 .41365 Mdot
.37577 .41871 Mdot
.54441 .42494 Mdot
.64284 .56564 Mdot
.72103 .54721 Mdot
.57469 .66426 Mdot
.43582 .63939 Mdot
.64644 .26042 Mdot
.47983 .6165 Mdot
.58558 .36137 Mdot
.37817 .76626 Mdot
.37038 .41482 Mdot
.71014 .52973 Mdot
.73216 .48917 Mdot
.70086 .52383 Mdot
.48213 .61389 Mdot
.31671 .3997 Mdot
.34767 .56115 Mdot
.58145 .35833 Mdot
.41558 .53447 Mdot
.66442 .30754 Mdot
.28058 .56291 Mdot
.44152 .63556 Mdot
.53903 .39594 Mdot
.28141 .62356 Mdot
.32466 .27824 Mdot
.54906 .37411 Mdot
.5112 .35069 Mdot
.69859 .60097 Mdot
.61818 .36096 Mdot
.37032 .45906 Mdot
.40549 .48539 Mdot
.53866 .33989 Mdot
.41895 .44516 Mdot
.33935 .16988 Mdot
.59075 .38964 Mdot
.56369 .393 Mdot
.52568 .36794 Mdot
.54598 .43197 Mdot
.31262 .45162 Mdot
.69163 .57967 Mdot
.43989 .59727 Mdot
.39711 .52775 Mdot
.436 .64671 Mdot
.5634 .66365 Mdot
.51535 .51955 Mdot
.30924 .41129 Mdot
.70155 .52524 Mdot
.84101 .53942 Mdot
.35697 .5215 Mdot
.57326 .61932 Mdot
.43602 .18773 Mdot
.7295 .53011 Mdot
.511 .36353 Mdot
.70888 .5441 Mdot
.52938 .64818 Mdot
.45236 .62801 Mdot
.57919 .34459 Mdot
.3674 .40366 Mdot
.31271 .44416 Mdot
.54217 .39735 Mdot
.33111 .77613 Mdot
.45494 .63996 Mdot
.48463 .66927 Mdot
.5812 .38036 Mdot
.51196 .35002 Mdot
.31493 .4345 Mdot
.58372 .6605 Mdot
.38869 .70543 Mdot
.72614 .51905 Mdot
.49557 .3878 Mdot
.52941 .41505 Mdot
.35907 .53211 Mdot
.40651 .60717 Mdot
.28512 .63984 Mdot
.58257 .38037 Mdot
.37384 .5336 Mdot
.58382 .38553 Mdot
.47528 .42583 Mdot
.57414 .62679 Mdot
.59851 .35522 Mdot
.53179 .34781 Mdot
.57191 .28065 Mdot
.42407 .64839 Mdot
.33798 .42462 Mdot
.29259 .40259 Mdot
.27617 .64314 Mdot
.43299 .60704 Mdot
.54056 .42074 Mdot
.40395 .6268 Mdot
.51885 .41216 Mdot
.56864 .3761 Mdot
.4423 .63562 Mdot
.34878 .44232 Mdot
.475 .78039 Mdot
.43051 .37328 Mdot
.56946 .42722 Mdot
.51958 .39812 Mdot
.79485 .43583 Mdot
.28026 .28158 Mdot
.523 .35556 Mdot
.37288 .42779 Mdot
.5277 .3933 Mdot
.45276 .60903 Mdot
.71531 .49638 Mdot
.34094 .41687 Mdot
.60606 .62536 Mdot
.59031 .62694 Mdot
.59793 .68899 Mdot
.2901 .61627 Mdot
.51082 .37099 Mdot
.39603 .42669 Mdot
.37577 .41489 Mdot
.27419 .66627 Mdot
.55637 .65525 Mdot
.69525 .49852 Mdot
.58252 .41156 Mdot
.59244 .48494 Mdot
.4264 .60088 Mdot
.12339 .62031 Mdot
.34721 .56861 Mdot
.67979 .52006 Mdot
.32063 .49522 Mdot
.28694 .62277 Mdot
.54918 .34808 Mdot
.72532 .54134 Mdot
.60291 .63827 Mdot
.5288 .41918 Mdot
.60218 .33341 Mdot
.582 .73748 Mdot
.58802 .60797 Mdot
.40526 .63073 Mdot
.60348 .63055 Mdot
.68508 .5269 Mdot
.29597 .61917 Mdot
.33136 .44902 Mdot
.54389 .36472 Mdot
.58861 .30121 Mdot
.56398 .6564 Mdot
.28974 .64864 Mdot
.58152 .38657 Mdot
.30509 .43766 Mdot
.58898 .66352 Mdot
.56085 .36113 Mdot
.37252 .23804 Mdot
.27701 .41717 Mdot
.57017 .6499 Mdot
.54616 .33261 Mdot
.46708 .45359 Mdot
.58991 .61484 Mdot
.54127 .62603 Mdot
.55476 .39437 Mdot
.69549 .5091 Mdot
.5574 .34398 Mdot
.41828 .62781 Mdot
.50237 .56213 Mdot
.44175 .60706 Mdot
.67536 .32166 Mdot
.57644 .33305 Mdot
.24586 .48284 Mdot
.34711 .39531 Mdot
.75059 .51212 Mdot
.41653 .35858 Mdot
.5173 .34695 Mdot
.53368 .81354 Mdot
.61703 .55076 Mdot
.29892 .67035 Mdot
.65803 .78639 Mdot
.72784 .51027 Mdot
.42447 .62129 Mdot
.56271 .39372 Mdot
.3875 .62539 Mdot
.71479 .50226 Mdot
.67355 .31635 Mdot
.54312 .33359 Mdot
.36226 .43604 Mdot
.57486 .38746 Mdot
.32139 .40617 Mdot
.52244 .39268 Mdot
.57013 .31047 Mdot
.71993 .5512 Mdot
.75133 .34189 Mdot
.50789 .37069 Mdot
.84753 .53115 Mdot
.55058 .50141 Mdot
.73371 .52073 Mdot
.56839 .42297 Mdot
.29106 .633 Mdot
.46044 .63247 Mdot
.79168 .5872 Mdot
.57067 .6302 Mdot
.43269 .63315 Mdot
.319 .43495 Mdot
.60045 .67315 Mdot
.27649 .64559 Mdot
.64915 .35411 Mdot
.69525 .53122 Mdot
.4233 .6092 Mdot
.53984 .36471 Mdot
.58693 .3621 Mdot
.74285 .61805 Mdot
.19806 .38255 Mdot
.33704 .385 Mdot
.77299 .3267 Mdot
.37817 .44989 Mdot
.7174 .52431 Mdot
.57076 .62645 Mdot
.53708 .35181 Mdot
.55135 .38012 Mdot
.54641 .658 Mdot
.37193 .43705 Mdot
.60518 .67721 Mdot
.47257 .19621 Mdot
.50214 .61778 Mdot
.7428 .37302 Mdot
.33826 .41344 Mdot
.74318 .36785 Mdot
.68103 .51809 Mdot
.64159 .75615 Mdot
.71825 .45161 Mdot
.41764 .60947 Mdot
.74164 .37794 Mdot
.36437 .41047 Mdot
.57033 .36529 Mdot
.29527 .62586 Mdot
.27361 .62736 Mdot
.31412 .42391 Mdot
.5902 .63997 Mdot
.69564 .52836 Mdot
.56642 .3888 Mdot
.29917 .54427 Mdot
.20847 .5838 Mdot
.59863 .66693 Mdot
.47271 .36948 Mdot
.45017 .64273 Mdot
.52454 .39799 Mdot
.73949 .51841 Mdot
.43701 .62759 Mdot
.28444 .61104 Mdot
.39214 .52302 Mdot
.58295 .41184 Mdot
.43624 .46303 Mdot
.42578 .61048 Mdot
.25642 .2971 Mdot
.55395 .38682 Mdot
.42586 .6474 Mdot
.62819 .39845 Mdot
.2129 .51505 Mdot
.63677 .52345 Mdot
.4505 .82957 Mdot
.55145 .6118 Mdot
.59366 .63055 Mdot
.16993 .48968 Mdot
.69403 .54986 Mdot
.4485 .59987 Mdot
.29873 .62152 Mdot
.71754 .42145 Mdot
.43472 .65054 Mdot
.5892 .35835 Mdot
.58206 .42311 Mdot
.47423 .2027 Mdot
.5407 .50859 Mdot
.27992 .65122 Mdot
.60427 .45576 Mdot
.55205 .41271 Mdot
.57942 .44382 Mdot
.54069 .38841 Mdot
.37477 .44485 Mdot
.43372 .65224 Mdot
.85952 .56466 Mdot
.41788 .65107 Mdot
.30907 .54507 Mdot
.57185 .6546 Mdot
.59213 .6716 Mdot
.54261 .35999 Mdot
.24897 .45154 Mdot
.78184 .62877 Mdot
.51375 .39081 Mdot
.7105 .48212 Mdot
.68511 .34203 Mdot
.58914 .42325 Mdot
.30961 .39165 Mdot
.48057 .36203 Mdot
.34622 .45994 Mdot
.4414 .62861 Mdot
.7266 .50856 Mdot
.7417 .54399 Mdot
.41999 .61975 Mdot
.54129 .37409 Mdot
.74343 .49213 Mdot
.55183 .36301 Mdot
.57612 .36964 Mdot
.33612 .53886 Mdot
.72263 .49291 Mdot
.56052 .62845 Mdot
.7036 .52239 Mdot
.33467 .43601 Mdot
.15728 .33584 Mdot
.70796 .51046 Mdot
.48844 .46885 Mdot
.53692 .53359 Mdot
.74039 .37364 Mdot
.31396 .44423 Mdot
.72892 .5025 Mdot
.41215 .6427 Mdot
.2845 .67436 Mdot
.25952 .30912 Mdot
.47736 .6287 Mdot
.55495 .38179 Mdot
.31446 .40696 Mdot
.37978 .42466 Mdot
.45339 .65147 Mdot
.34681 .44832 Mdot
.60824 .40366 Mdot
.58521 .39324 Mdot
.44778 .59983 Mdot
.2333 .5982 Mdot
.43209 .65276 Mdot
.56451 .48882 Mdot
.57829 .41023 Mdot
.33906 .41826 Mdot
.55763 .46107 Mdot
.36621 .38591 Mdot
.27242 .6264 Mdot
.51152 .40476 Mdot
.69923 .52637 Mdot
.45772 .52646 Mdot
.57188 .65071 Mdot
.38461 .76899 Mdot
.31575 .40967 Mdot
.47415 .59564 Mdot
.33059 .44615 Mdot
.36481 .39585 Mdot
.45743 .64515 Mdot
.33075 .42822 Mdot
.56489 .39182 Mdot
.45056 .55862 Mdot
.32757 .40512 Mdot
.43919 .61437 Mdot
.70205 .53145 Mdot
.34261 .44371 Mdot
.58589 .6835 Mdot
.57209 .36175 Mdot
.55304 .62498 Mdot
.7047 .48767 Mdot
.3104 .40947 Mdot
.72571 .501 Mdot
.5609 .65653 Mdot
.70255 .53593 Mdot
.59087 .59554 Mdot
.40413 .59966 Mdot
.31417 .52437 Mdot
.40808 .38603 Mdot
.36159 .40004 Mdot
.52073 .62866 Mdot
.53262 .35044 Mdot
.58203 .37 Mdot
.69537 .53635 Mdot
.3801 .42108 Mdot
.37569 .80542 Mdot
.62179 .43043 Mdot
.28139 .59908 Mdot
.40428 .60637 Mdot
.7201 .28347 Mdot
.3447 .58602 Mdot
.29624 .6831 Mdot
.49912 .4253 Mdot
.28818 .62279 Mdot
.55355 .35832 Mdot
.69504 .28993 Mdot
.71407 .49523 Mdot
.46786 .74082 Mdot
.50049 .4162 Mdot
.56393 .63489 Mdot
.51972 .3852 Mdot
.81228 .58013 Mdot
.48019 .40574 Mdot
.73521 .50875 Mdot
.4498 .59289 Mdot
.35139 .38854 Mdot
.72827 .52955 Mdot
.58613 .62285 Mdot
.74314 .41655 Mdot
.55481 .3323 Mdot
.55578 .40966 Mdot
.52176 .63285 Mdot
.35846 .44085 Mdot
.561 .66188 Mdot
.42575 .6464 Mdot
.70952 .51311 Mdot
.55295 .43373 Mdot
.60173 .40865 Mdot
.52479 .65718 Mdot
.40905 .64471 Mdot
.61031 .65446 Mdot
.40572 .61959 Mdot
.28969 .6226 Mdot
.50887 .37366 Mdot
.52317 .64373 Mdot
.53505 .44573 Mdot
.5036 .27955 Mdot
.33461 .52887 Mdot
.42644 .3375 Mdot
.55868 .62827 Mdot
.76808 .41472 Mdot
.42775 .61551 Mdot
.40938 .62451 Mdot
.5517 .22314 Mdot
.77064 .63962 Mdot
.61912 .56549 Mdot
.83858 .50932 Mdot
.4256 .64596 Mdot
.43704 .60933 Mdot
.60212 .64104 Mdot
.32492 .42848 Mdot
.28947 .43608 Mdot
.56226 .67788 Mdot
.71802 .31102 Mdot
.36654 .41403 Mdot
.51239 .82205 Mdot
.56602 .61298 Mdot
.4897 .39594 Mdot
.28018 .65371 Mdot
.73687 .51768 Mdot
.69826 .30281 Mdot
.82959 .53058 Mdot
.54308 .35236 Mdot
.44277 .16446 Mdot
.58538 .64537 Mdot
.41703 .56889 Mdot
.5975 .77609 Mdot
.5264 .33663 Mdot
.52185 .37963 Mdot
.53776 .37936 Mdot
.73982 .50329 Mdot
.43605 .35532 Mdot
.54535 .3513 Mdot
.75844 .35988 Mdot
.59726 .36583 Mdot
.79976 .55844 Mdot
.70371 .52195 Mdot
.66246 .38609 Mdot
.54541 .61253 Mdot
.26142 .54483 Mdot
.6062 .42483 Mdot
.41829 .64197 Mdot
.55487 .76256 Mdot
.45023 .6334 Mdot
.7042 .71576 Mdot
.71626 .44959 Mdot
.37782 .44331 Mdot
.53642 .40133 Mdot
.52953 .62716 Mdot
.319 .40421 Mdot
.40131 .71853 Mdot
.2086 .27596 Mdot
.39979 .62403 Mdot
.53217 .13067 Mdot
.40884 .62208 Mdot
.27121 .63122 Mdot
.31335 .42983 Mdot
.33408 .48228 Mdot
.4194 .5336 Mdot
.34763 .44146 Mdot
.60205 .70524 Mdot
.29919 .39723 Mdot
.75551 .39517 Mdot
.37344 .39836 Mdot
.43498 .61723 Mdot
.44336 .58828 Mdot
.62261 .34962 Mdot
.5242 .35563 Mdot
.38727 .53647 Mdot
.60646 .43612 Mdot
.51205 .37628 Mdot
.55929 .64099 Mdot
.24416 .4065 Mdot
.46222 .57838 Mdot
.32703 .41105 Mdot
.42007 .60086 Mdot
.52075 .38061 Mdot
.56938 .42658 Mdot
.52772 .4368 Mdot
.6798 .28191 Mdot
.51456 .81948 Mdot
.56987 .37318 Mdot
.53858 .3218 Mdot
.57897 .62192 Mdot
.76284 .59824 Mdot
.81785 .42175 Mdot
.72201 .43113 Mdot
.58622 .3722 Mdot
.71666 .52741 Mdot
.72517 .49689 Mdot
.60845 .3858 Mdot
.26815 .51355 Mdot
.63005 .65473 Mdot
.53951 .36488 Mdot
.74254 .46756 Mdot
.55868 .68326 Mdot
.29746 .64362 Mdot
.56303 .65589 Mdot
.30335 .41805 Mdot
.27595 .62751 Mdot
.58601 .66936 Mdot
.27023 .43555 Mdot
.2763 .64213 Mdot
.22003 .5268 Mdot
.72065 .49787 Mdot
.54515 .38572 Mdot
.3872 .39342 Mdot
.54529 .65605 Mdot
.42068 .61139 Mdot
.35149 .42116 Mdot
.39669 .61267 Mdot
.76414 .59964 Mdot
.70107 .3173 Mdot
.28605 .61579 Mdot
.41747 .63883 Mdot
.41054 .50088 Mdot
.71256 .52697 Mdot
.46251 .64143 Mdot
.24354 .45334 Mdot
.58632 .4236 Mdot
.74258 .69549 Mdot
.55335 .40596 Mdot
.29159 .74196 Mdot
.41054 .62443 Mdot
.27472 .61996 Mdot
.54571 .36561 Mdot
.55537 .61695 Mdot
.62588 .34466 Mdot
.55349 .36435 Mdot
.60306 .62664 Mdot
.5706 .36833 Mdot
.74125 .52413 Mdot
.33459 .46154 Mdot
.61773 .54779 Mdot
.67743 .25084 Mdot
.71132 .53796 Mdot
.28424 .60561 Mdot
.51428 .36753 Mdot
.66172 .61924 Mdot
.35201 .43854 Mdot
.51619 .34416 Mdot
.5229 .19125 Mdot
.31923 .42234 Mdot
.34968 .43222 Mdot
.55771 .42085 Mdot
.4794 .62406 Mdot
.54172 .6392 Mdot
.70954 .52679 Mdot
.3666 .67304 Mdot
.56083 .35927 Mdot
.54157 .39428 Mdot
.72851 .53055 Mdot
.43881 .608 Mdot
.55302 .4325 Mdot
.38618 .73268 Mdot
.3249 .63658 Mdot
.42422 .60387 Mdot
.58699 .42375 Mdot
.75722 .70331 Mdot
.29825 .45231 Mdot
.41485 .16559 Mdot
.68327 .54352 Mdot
.58634 .63601 Mdot
.51994 .32114 Mdot
.10551 .58404 Mdot
.73518 .51575 Mdot
.2808 .55732 Mdot
.57424 .37642 Mdot
.51818 .36948 Mdot
.33929 .45242 Mdot
.54598 .42268 Mdot
.34691 .40468 Mdot
.67944 .24773 Mdot
.87027 .47245 Mdot
.33248 .4456 Mdot
.33741 .40331 Mdot
.37613 .47365 Mdot
.6734 .28635 Mdot
.31993 .43286 Mdot
.54938 .33108 Mdot
.64231 .69174 Mdot
.58446 .32594 Mdot
.67974 .50674 Mdot
.75394 .51551 Mdot
.33278 .37914 Mdot
.22495 .37588 Mdot
.62811 .33629 Mdot
.44402 .3983 Mdot
.65985 .53063 Mdot
.42331 .63581 Mdot
.57649 .42663 Mdot
.29263 .61665 Mdot
.59868 .65956 Mdot
.47406 .39439 Mdot
.54573 .38243 Mdot
.32722 .40259 Mdot
.74238 .50526 Mdot
.45413 .64499 Mdot
.55336 .3924 Mdot
.61972 .63694 Mdot
.723 .51663 Mdot
.32928 .40532 Mdot
.49526 .47481 Mdot
.68724 .50264 Mdot
.59752 .42127 Mdot
.51311 .37561 Mdot
.58193 .3871 Mdot
.61059 .4206 Mdot
.41864 .61908 Mdot
.58127 .67866 Mdot
.60098 .35225 Mdot
.3502 .54049 Mdot
.47556 .5372 Mdot
.60236 .35808 Mdot
.36994 .43588 Mdot
.44705 .59781 Mdot
.27854 .64027 Mdot
.72882 .39036 Mdot
.58705 .39831 Mdot
.52381 .8153 Mdot
.42989 .19437 Mdot
.27884 .63246 Mdot
.38807 .43594 Mdot
.70549 .52744 Mdot
.56145 .41232 Mdot
.65288 .64877 Mdot
.59102 .37559 Mdot
.50996 .47251 Mdot
.58568 .63982 Mdot
.4288 .63936 Mdot
.31802 .64517 Mdot
.59899 .65976 Mdot
.34845 .43176 Mdot
.35425 .81023 Mdot
.29095 .41464 Mdot
.32936 .38906 Mdot
.65843 .73641 Mdot
.4425 .63083 Mdot
.11503 .60378 Mdot
.27659 .28305 Mdot
.59259 .37682 Mdot
.45834 .61838 Mdot
.31054 .42584 Mdot
.54372 .40294 Mdot
.3635 .40402 Mdot
.30756 .40126 Mdot
.53419 .4314 Mdot
.51839 .36535 Mdot
.74117 .33296 Mdot
.51019 .83388 Mdot
.69646 .51785 Mdot
.36268 .44704 Mdot
.44408 .20919 Mdot
.54556 .35011 Mdot
.58061 .35756 Mdot
.57437 .74664 Mdot
.73309 .507 Mdot
.31153 .31899 Mdot
.58103 .37586 Mdot
.53359 .19473 Mdot
.50951 .38286 Mdot
.40972 .42692 Mdot
.48225 .62565 Mdot
.27318 .52231 Mdot
.53913 .64567 Mdot
.29751 .4309 Mdot
.68616 .51486 Mdot
.29795 .43801 Mdot
.53254 .21503 Mdot
.44617 .6294 Mdot
.34837 .40649 Mdot
.61305 .65703 Mdot
.44934 .61961 Mdot
.41564 .61055 Mdot
.64346 .61417 Mdot
.59929 .6726 Mdot
.74438 .51379 Mdot
.45085 .63707 Mdot
.39571 .22756 Mdot
.4363 .62008 Mdot
.4604 .20836 Mdot
.54434 .34063 Mdot
.75003 .35374 Mdot
.33299 .58822 Mdot
.62065 .3926 Mdot
.4409 .65059 Mdot
.70349 .50616 Mdot
.53702 .41437 Mdot
.35002 .44812 Mdot
.71093 .50782 Mdot
.42049 .66177 Mdot
.61259 .64023 Mdot
.37147 .40132 Mdot
.46684 .60416 Mdot
.35326 .40465 Mdot
.69054 .31702 Mdot
.59307 .60135 Mdot
.65238 .50281 Mdot
.43323 .53591 Mdot
.51618 .42537 Mdot
.41991 .44261 Mdot
.55953 .33761 Mdot
.54749 .37802 Mdot
.5699 .65049 Mdot
.79366 .42169 Mdot
.34531 .44409 Mdot
.22487 .65209 Mdot
.41329 .63373 Mdot
.40049 .4888 Mdot
.55098 .47822 Mdot
.5194 .41081 Mdot
.3244 .40867 Mdot
.3131 .39683 Mdot
.47295 .29779 Mdot
.54837 .65981 Mdot
.60608 .35101 Mdot
.61677 .38679 Mdot
.55251 .31274 Mdot
.40919 .6193 Mdot
.4088 .74594 Mdot
.57457 .67138 Mdot
.44809 .13048 Mdot
.57597 .66469 Mdot
.67392 .59933 Mdot
.32993 .42739 Mdot
.69967 .49796 Mdot
.57736 .35514 Mdot
.44781 .3616 Mdot
.32204 .45561 Mdot
.62741 .66807 Mdot
.70758 .53029 Mdot
.44682 .76618 Mdot
.43768 .63258 Mdot
.54071 .3376 Mdot
.54579 .43804 Mdot
.55838 .42682 Mdot
.56819 .4008 Mdot
.42821 .59657 Mdot
.58856 .35795 Mdot
.4163 .59635 Mdot
.3461 .25482 Mdot
.5411 .20067 Mdot
.53464 .62742 Mdot
.78908 .56896 Mdot
.37034 .40475 Mdot
.43666 .22362 Mdot
.29927 .32163 Mdot
.33196 .52988 Mdot
.60946 .59529 Mdot
.53164 .34482 Mdot
.59163 .64101 Mdot
.81362 .58437 Mdot
.52886 .63044 Mdot
.88815 .46637 Mdot
.6521 .32694 Mdot
.43715 .83305 Mdot
.54914 .40326 Mdot
.56461 .67932 Mdot
.29242 .34726 Mdot
.6028 .39916 Mdot
.75678 .50963 Mdot
.55234 .48419 Mdot
.24604 .57852 Mdot
.69397 .49878 Mdot
.56963 .36044 Mdot
.3585 .38924 Mdot
.56619 .39141 Mdot
.57242 .35412 Mdot
.51461 .39012 Mdot
.41888 .65635 Mdot
.57283 .43713 Mdot
.55866 .34444 Mdot
.20294 .36681 Mdot
.78605 .44094 Mdot
.56896 .61782 Mdot
.45 .31194 Mdot
.71384 .52027 Mdot
.32494 .40145 Mdot
.59797 .54401 Mdot
.42195 .6297 Mdot
.48454 .28798 Mdot
.55064 .40444 Mdot
.30658 .58829 Mdot
.4771 .61314 Mdot
.71779 .50556 Mdot
.27972 .64435 Mdot
.53049 .79654 Mdot
.53423 .6392 Mdot
.26929 .6384 Mdot
.5732 .65087 Mdot
.35348 .34932 Mdot
.32576 .40419 Mdot
.52578 .43328 Mdot
.44582 .64487 Mdot
.5429 .62663 Mdot
.80478 .45641 Mdot
.5334 .38681 Mdot
.5563 .62885 Mdot
.51703 .42527 Mdot
.47777 .54374 Mdot
.5412 .5378 Mdot
.53055 .65501 Mdot
.44633 .58923 Mdot
.45092 .6164 Mdot
.69866 .50163 Mdot
.32826 .39918 Mdot
.37226 .42201 Mdot
.44078 .62576 Mdot
.46184 .14561 Mdot
.55888 .358 Mdot
.51154 .3821 Mdot
.35 .54682 Mdot
.55327 .4002 Mdot
.75921 .4239 Mdot
.30449 .62691 Mdot
.35749 .39659 Mdot
.56369 .39994 Mdot
.55482 .4327 Mdot
.58171 .41412 Mdot
.70069 .32164 Mdot
.56815 .65877 Mdot
.55335 .41294 Mdot
.7102 .54138 Mdot
.23072 .48022 Mdot
.53906 .34729 Mdot
.59587 .4201 Mdot
.3533 .40642 Mdot
.73995 .29228 Mdot
.4154 .61663 Mdot
.55099 .63604 Mdot
.56964 .61316 Mdot
.67737 .38901 Mdot
.33249 .46527 Mdot
.3013 .64311 Mdot
.53477 .70411 Mdot
.29937 .63555 Mdot
.73186 .52292 Mdot
.64359 .57774 Mdot
.61791 .63055 Mdot
.58351 .61921 Mdot
.40579 .59896 Mdot
.56831 .39839 Mdot
.51002 .38211 Mdot
.28281 .55571 Mdot
.51234 .39829 Mdot
.70472 .53115 Mdot
.46756 .60718 Mdot
.35346 .40779 Mdot
.73842 .52494 Mdot
.40893 .63187 Mdot
.35948 .44088 Mdot
.59502 .40936 Mdot
.55313 .4485 Mdot
.35274 .4256 Mdot
.3062 .42167 Mdot
.53437 .36087 Mdot
.18978 .42372 Mdot
.3549 .39263 Mdot
.34243 .40938 Mdot
.26364 .64146 Mdot
.5336 .63831 Mdot
.52418 .4578 Mdot
.45854 .62309 Mdot
.58155 .38409 Mdot
.53242 .62923 Mdot
.72444 .5024 Mdot
.36082 .42726 Mdot
.57647 .42008 Mdot
.56448 .36892 Mdot
.71588 .52808 Mdot
.70899 .49033 Mdot
.7123 .53602 Mdot
.39799 .63296 Mdot
.57647 .40142 Mdot
.32338 .43646 Mdot
.44266 .63287 Mdot
.72395 .49651 Mdot
.73397 .54291 Mdot
.21638 .35146 Mdot
.54407 .3533 Mdot
.64633 .53061 Mdot
.12474 .39551 Mdot
.74034 .42253 Mdot
.27189 .63726 Mdot
.53072 .66021 Mdot
.7557 .36802 Mdot
.66882 .52227 Mdot
.45977 .61635 Mdot
.68354 .46963 Mdot
.74617 .50593 Mdot
.52957 .42646 Mdot
.52569 .40214 Mdot
.49272 .38334 Mdot
.7175 .51448 Mdot
.69371 .32183 Mdot
.37825 .42695 Mdot
.38988 .28086 Mdot
.71384 .52011 Mdot
.53099 .65589 Mdot
.52454 .64791 Mdot
.57598 .66531 Mdot
.53025 .34392 Mdot
.44894 .32458 Mdot
.4152 .21612 Mdot
.33027 .31853 Mdot
.43282 .63266 Mdot
.31542 .39381 Mdot
.61269 .59322 Mdot
.35075 .43264 Mdot
.59683 .6565 Mdot
.72094 .5123 Mdot
.35114 .45238 Mdot
.43668 .60377 Mdot
.44504 .60816 Mdot
.60876 .62905 Mdot
.55708 .65286 Mdot
.54738 .64271 Mdot
.30068 .41995 Mdot
.33046 .42816 Mdot
.56231 .43273 Mdot
.35934 .41913 Mdot
.37214 .20695 Mdot
.67715 .51125 Mdot
.52313 .63003 Mdot
.42716 .6116 Mdot
.31698 .41094 Mdot
.54827 .3859 Mdot
.71466 .60587 Mdot
.6021 .68553 Mdot
.72188 .53898 Mdot
.491 .5776 Mdot
.84977 .37992 Mdot
.54882 .4404 Mdot
.40415 .61991 Mdot
.25679 .50027 Mdot
.53221 .38108 Mdot
.57708 .63199 Mdot
.6306 .27028 Mdot
.29372 .6453 Mdot
.55331 .3451 Mdot
.50638 .36178 Mdot
.45689 .64512 Mdot
.57526 .54027 Mdot
.51466 .40581 Mdot
.46245 .47723 Mdot
.40564 .64298 Mdot
.57727 .67174 Mdot
.16131 .5616 Mdot
.50571 .62114 Mdot
.75656 .34207 Mdot
.27382 .63629 Mdot
.54585 .43731 Mdot
.562 .64313 Mdot
.72749 .53983 Mdot
.55991 .64737 Mdot
.38589 .42056 Mdot
.54853 .62811 Mdot
.53311 .39386 Mdot
.32556 .43641 Mdot
.43076 .60749 Mdot
.41437 .47625 Mdot
.20747 .37931 Mdot
.5583 .61595 Mdot
.2844 .6091 Mdot
.54913 .34725 Mdot
.33202 .27707 Mdot
.61706 .33411 Mdot
.52874 .35031 Mdot
.44926 .63444 Mdot
.32457 .40974 Mdot
.40523 .60507 Mdot
.5776 .4389 Mdot
.55151 .23204 Mdot
.41393 .63108 Mdot
.22503 .55538 Mdot
.73106 .52842 Mdot
.71598 .31058 Mdot
.55229 .37377 Mdot
.44385 .64497 Mdot
.57703 .40162 Mdot
.36629 .44578 Mdot
.44437 .51559 Mdot
.23414 .46815 Mdot
.44962 .64235 Mdot
.32079 .77506 Mdot
.49459 .51472 Mdot
.49333 .4375 Mdot
.43253 .64778 Mdot
.42314 .35224 Mdot
.28855 .63636 Mdot
.72731 .51941 Mdot
.71957 .49312 Mdot
.69208 .52912 Mdot
.51177 .39701 Mdot
.50143 .32603 Mdot
.74659 .53351 Mdot
.39789 .62328 Mdot
.74067 .53422 Mdot
.68186 .29948 Mdot
.35053 .79138 Mdot
.71978 .53705 Mdot
.55675 .37634 Mdot
.59542 .41873 Mdot
.78818 .443 Mdot
.57659 .6736 Mdot
.53954 .81005 Mdot
.29655 .27713 Mdot
.53437 .35326 Mdot
.65195 .36617 Mdot
.37828 .4108 Mdot
.27509 .48353 Mdot
.62866 .42429 Mdot
.62064 .56001 Mdot
.3353 .40667 Mdot
.48067 .55418 Mdot
.35301 .3961 Mdot
.54495 .4426 Mdot
.56891 .37721 Mdot
.32918 .45894 Mdot
.36948 .75552 Mdot
.19432 .51736 Mdot
.25136 .69354 Mdot
.37309 .42399 Mdot
.42481 .64865 Mdot
.40149 .62626 Mdot
.43917 .63565 Mdot
.54271 .64986 Mdot
.30343 .42717 Mdot
.57215 .40782 Mdot
.58845 .62774 Mdot
.58202 .36372 Mdot
.45229 .62435 Mdot
.31974 .64484 Mdot
.3521 .4069 Mdot
.53985 .36655 Mdot
.25733 .3142 Mdot
.58027 .656 Mdot
.71461 .52627 Mdot
.44662 .55403 Mdot
.53191 .66297 Mdot
.42238 .65322 Mdot
.31846 .46245 Mdot
.50747 .65681 Mdot
.69592 .57916 Mdot
.51375 .33705 Mdot
.56132 .33363 Mdot
.37457 .66745 Mdot
.23092 .35339 Mdot
.51626 .39802 Mdot
.5867 .62281 Mdot
.53093 .64925 Mdot
.58587 .39351 Mdot
.32586 .44782 Mdot
.74921 .51668 Mdot
.69038 .53046 Mdot
.50067 .38987 Mdot
.413 .53571 Mdot
.74881 .34625 Mdot
.54501 .4269 Mdot
.50134 .46171 Mdot
.6103 .66082 Mdot
.27555 .64442 Mdot
.37852 .53053 Mdot
.68897 .51301 Mdot
.57577 .37562 Mdot
.19363 .54309 Mdot
.34261 .40538 Mdot
.54602 .63439 Mdot
.44081 .6001 Mdot
.75899 .51123 Mdot
.58293 .61252 Mdot
.58569 .39386 Mdot
.55369 .43255 Mdot
.46184 .64065 Mdot
.40936 .42437 Mdot
.71849 .51187 Mdot
.58607 .62665 Mdot
.6989 .49832 Mdot
.3352 .4338 Mdot
.34784 .41016 Mdot
.61762 .37875 Mdot
.62298 .3824 Mdot
.56775 .61373 Mdot
.49837 .37194 Mdot
.58976 .66589 Mdot
.74715 .61419 Mdot
.4259 .60057 Mdot
.51774 .34172 Mdot
.39226 .44217 Mdot
.45028 .62537 Mdot
.52464 .36385 Mdot
.3728 .66032 Mdot
.5346 .4244 Mdot
.56474 .6789 Mdot
.56173 .22482 Mdot
.71344 .50127 Mdot
.43105 .42202 Mdot
.52075 .29863 Mdot
.55178 .39978 Mdot
.57456 .67618 Mdot
.54378 .30928 Mdot
.41569 .62678 Mdot
.32634 .41825 Mdot
.63135 .18153 Mdot
.43949 .61683 Mdot
.56857 .38713 Mdot
.70974 .5109 Mdot
.34194 .38612 Mdot
.28574 .61829 Mdot
.35697 .55631 Mdot
.47628 .39998 Mdot
.4976 .4291 Mdot
.56905 .39569 Mdot
.84033 .50671 Mdot
.55359 .64096 Mdot
.31178 .41788 Mdot
.40975 .61027 Mdot
.43114 .62697 Mdot
.58426 .66031 Mdot
.26272 .58874 Mdot
.404 .78693 Mdot
.0985 .44992 Mdot
.58574 .61615 Mdot
.72965 .54201 Mdot
.47388 .52881 Mdot
.60012 .65965 Mdot
.56026 .63777 Mdot
.60945 .62714 Mdot
.31367 .58058 Mdot
.36368 .4407 Mdot
.56557 .368 Mdot
.34567 .46654 Mdot
.53672 .43258 Mdot
.79987 .40914 Mdot
.44059 .62747 Mdot
.32689 .42014 Mdot
.39128 .67114 Mdot
.61813 .42602 Mdot
.52524 .38229 Mdot
.6411 .67378 Mdot
.47959 .37401 Mdot
.73698 .38408 Mdot
.5796 .44662 Mdot
.56521 .65347 Mdot
.64574 .34645 Mdot
.51682 .32383 Mdot
.28057 .29495 Mdot
.4386 .60566 Mdot
.28 .61772 Mdot
.59579 .40143 Mdot
.48146 .43426 Mdot
.33699 .38681 Mdot
.35048 .4526 Mdot
.7475 .53134 Mdot
.41701 .55227 Mdot
.43472 .60592 Mdot
.4556 .79838 Mdot
.51981 .36027 Mdot
.38236 .59567 Mdot
.55264 .21824 Mdot
.52637 .36462 Mdot
.64692 .63506 Mdot
.48178 .29018 Mdot
.52042 .41073 Mdot
.35332 .31788 Mdot
.43158 .61293 Mdot
.53051 .19379 Mdot
.49673 .39897 Mdot
.57661 .63282 Mdot
.3251 .42655 Mdot
.37291 .40445 Mdot
.72928 .53643 Mdot
.32945 .23657 Mdot
.42978 .58535 Mdot
.32826 .42543 Mdot
.53712 .38227 Mdot
.41897 .61332 Mdot
.2794 .62006 Mdot
.48709 .41315 Mdot
.71949 .69053 Mdot
.35823 .41481 Mdot
.57205 .32116 Mdot
.24175 .64303 Mdot
.50113 .53191 Mdot
.5192 .8343 Mdot
.43828 .63813 Mdot
.68728 .51585 Mdot
.57679 .44948 Mdot
.5271 .70085 Mdot
.49986 .41217 Mdot
.77678 .38126 Mdot
.33549 .37417 Mdot
.71438 .49618 Mdot
.53454 .3764 Mdot
.51499 .40561 Mdot
.44854 .53044 Mdot
.70369 .49195 Mdot
.51538 .40798 Mdot
.61181 .36098 Mdot
.36081 .43858 Mdot
.30275 .62075 Mdot
.3583 .41084 Mdot
.55478 .38285 Mdot
.65769 .37646 Mdot
.34158 .45099 Mdot
.51223 .79791 Mdot
.74961 .54871 Mdot
.42128 .63026 Mdot
.47028 .42375 Mdot
.5399 .34234 Mdot
.71451 .76508 Mdot
.2719 .62729 Mdot
.78483 .35496 Mdot
.54341 .67064 Mdot
.20933 .63133 Mdot
.53607 .66824 Mdot
.41106 .83013 Mdot
.40908 .48947 Mdot
.50424 .35129 Mdot
.71435 .4622 Mdot
.34349 .31459 Mdot
.4007 .60433 Mdot
.37531 .24525 Mdot
.52465 .3552 Mdot
.56108 .35386 Mdot
.59831 .6391 Mdot
.27256 .59349 Mdot
.25995 .50876 Mdot
.39782 .53061 Mdot
.72281 .50961 Mdot
.33654 .42794 Mdot
.52961 .39563 Mdot
.32966 .70984 Mdot
.56217 .61871 Mdot
.56622 .49522 Mdot
.54288 .3665 Mdot
.29921 .53714 Mdot
.25418 .56364 Mdot
.41971 .61092 Mdot
.54828 .67176 Mdot
.58273 .67806 Mdot
.57882 .42718 Mdot
.45207 .60458 Mdot
.54716 .43454 Mdot
.48964 .51171 Mdot
.53915 .3224 Mdot
.73201 .50976 Mdot
.57588 .3519 Mdot
.60651 .49925 Mdot
.40968 .84282 Mdot
.49247 .34322 Mdot
.33631 .39301 Mdot
.54648 .65311 Mdot
.57536 .66232 Mdot
.37249 .42079 Mdot
.57827 .66271 Mdot
.39033 .28762 Mdot
.51069 .21268 Mdot
.73405 .51742 Mdot
.28536 .32641 Mdot
.72081 .50462 Mdot
.28066 .61698 Mdot
.53993 .35499 Mdot
.55803 .71597 Mdot
.58492 .61534 Mdot
.65451 .27042 Mdot
.43522 .62255 Mdot
.27153 .62849 Mdot
.59509 .37815 Mdot
.64986 .58042 Mdot
.5965 .64952 Mdot
.53616 .77671 Mdot
.58076 .41632 Mdot
.36348 .44441 Mdot
.51816 .40807 Mdot
.54019 .32604 Mdot
.27068 .63937 Mdot
.56994 .39613 Mdot
.40901 .63223 Mdot
.30285 .42866 Mdot
.41409 .82618 Mdot
.54389 .65406 Mdot
.56182 .35039 Mdot
.53634 .38174 Mdot
.35726 .45256 Mdot
.5957 .36448 Mdot
.46032 .62002 Mdot
.14354 .66186 Mdot
.73134 .52693 Mdot
.27792 .64652 Mdot
.52221 .78485 Mdot
.53194 .40345 Mdot
.53811 .41977 Mdot
.36977 .66664 Mdot
.20876 .45967 Mdot
.41298 .63676 Mdot
.58807 .34098 Mdot
.57556 .62189 Mdot
.71384 .50705 Mdot
.46155 .63147 Mdot
.58275 .39603 Mdot
.55916 .35321 Mdot
.73444 .51228 Mdot
.64563 .66775 Mdot
.60497 .67917 Mdot
.43552 .63389 Mdot
.64705 .40179 Mdot
.72009 .60844 Mdot
.5558 .36056 Mdot
.29066 .72832 Mdot
.34117 .41143 Mdot
.4304 .64585 Mdot
.431 .36257 Mdot
.52397 .43061 Mdot
.42417 .65311 Mdot
.43298 .607 Mdot
.59121 .39476 Mdot
.33407 .46598 Mdot
.30187 .41185 Mdot
.33943 .40972 Mdot
.57627 .22262 Mdot
.80463 .50818 Mdot
.54634 .64217 Mdot
.43382 .61059 Mdot
.52598 .63552 Mdot
.75139 .52507 Mdot
.47398 .53687 Mdot
.53036 .65034 Mdot
.36977 .4028 Mdot
.52223 .63591 Mdot
.54316 .43183 Mdot
.44256 .60426 Mdot
.58706 .62012 Mdot
.54054 .40708 Mdot
.49243 .45881 Mdot
.62692 .49097 Mdot
.74692 .5132 Mdot
.47543 .55028 Mdot
.56283 .38625 Mdot
.27743 .64087 Mdot
.53732 .36112 Mdot
.44794 .59976 Mdot
.59546 .50812 Mdot
.549 .4095 Mdot
.57547 .61327 Mdot
.71498 .57926 Mdot
.56317 .67324 Mdot
.56214 .32746 Mdot
.55588 .38275 Mdot
.55647 .35855 Mdot
.5114 .4026 Mdot
.23446 .56813 Mdot
.41454 .59699 Mdot
.46728 .42357 Mdot
.5871 .60955 Mdot
.35513 .4307 Mdot
.36811 .44695 Mdot
.61447 .56373 Mdot
.26647 .63823 Mdot
.45563 .61034 Mdot
.55831 .35902 Mdot
.53664 .77623 Mdot
.32303 .64626 Mdot
.27318 .71916 Mdot
.63868 .59884 Mdot
.58635 .62141 Mdot
.33055 .39431 Mdot
.60771 .64291 Mdot
.59006 .38173 Mdot
.57692 .44789 Mdot
.42996 .82908 Mdot
.4241 .66023 Mdot
.71987 .51288 Mdot
.58249 .36336 Mdot
.73349 .32 Mdot
.57906 .62195 Mdot
.60863 .66395 Mdot
.55586 .43618 Mdot
.29546 .41368 Mdot
.49218 .85763 Mdot
.44503 .60013 Mdot
.34078 .26934 Mdot
.34285 .37077 Mdot
.56413 .48101 Mdot
.42074 .6208 Mdot
.64428 .51365 Mdot
.56282 .66979 Mdot
.30924 .26254 Mdot
.35519 .42527 Mdot
.72046 .51655 Mdot
.61088 .37407 Mdot
.36894 .4012 Mdot
.52257 .65293 Mdot
.34526 .39874 Mdot
.53324 .43813 Mdot
.40024 .61552 Mdot
.58234 .66447 Mdot
.44191 .59247 Mdot
.32066 .45615 Mdot
.71792 .50305 Mdot
.66509 .2921 Mdot
.34297 .26401 Mdot
.48198 .2902 Mdot
.55411 .41296 Mdot
.60336 .73158 Mdot
.57544 .40727 Mdot
.32173 .39305 Mdot
.55303 .37429 Mdot
.41813 .45245 Mdot
.59353 .67113 Mdot
.5631 .31927 Mdot
.56579 .3456 Mdot
.31802 .26742 Mdot
.52367 .37452 Mdot
.59403 .37987 Mdot
.50314 .37466 Mdot
.38558 .38217 Mdot
.59079 .33684 Mdot
.36001 .44554 Mdot
.28798 .56375 Mdot
.5629 .6384 Mdot
.73188 .54508 Mdot
.68365 .51981 Mdot
.77112 .37308 Mdot
.72102 .31335 Mdot
.27123 .58673 Mdot
.36811 .41914 Mdot
.41438 .64508 Mdot
.54992 .43486 Mdot
.39872 .36105 Mdot
.65827 .45622 Mdot
.56734 .67041 Mdot
.54954 .61711 Mdot
.61918 .36329 Mdot
.84621 .54259 Mdot
.58184 .32764 Mdot
.34769 .56356 Mdot
.51716 .41363 Mdot
.51284 .34767 Mdot
.61224 .66039 Mdot
.69261 .30877 Mdot
.55335 .41279 Mdot
.33756 .38672 Mdot
.7217 .52099 Mdot
.64915 .36829 Mdot
.66317 .4302 Mdot
.61172 .47831 Mdot
.26151 .42216 Mdot
.57189 .40162 Mdot
.58591 .63037 Mdot
.36491 .39712 Mdot
.35731 .53796 Mdot
.44436 .63366 Mdot
.37374 .54197 Mdot
.3651 .23825 Mdot
.51989 .60926 Mdot
.72265 .51652 Mdot
.63942 .61841 Mdot
.53379 .39413 Mdot
.54282 .64833 Mdot
.53989 .43827 Mdot
.32036 .651 Mdot
.72323 .50063 Mdot
.30251 .4452 Mdot
.4233 .64849 Mdot
.37418 .43339 Mdot
.42981 .33477 Mdot
.65758 .45084 Mdot
.20928 .63318 Mdot
.53392 .64247 Mdot
.58534 .26823 Mdot
.31517 .42453 Mdot
.5812 .40887 Mdot
.10591 .43607 Mdot
.33987 .41372 Mdot
.37136 .43808 Mdot
.62227 .55971 Mdot
.67539 .32117 Mdot
.51483 .32356 Mdot
.35408 .39841 Mdot
.52847 .62141 Mdot
.70059 .521 Mdot
.54073 .41438 Mdot
.50279 .38468 Mdot
.34406 .45255 Mdot
.59584 .65357 Mdot
.73492 .3164 Mdot
.56095 .65349 Mdot
.35341 .44365 Mdot
.57949 .64946 Mdot
.49608 .78978 Mdot
.56134 .62209 Mdot
.56141 .34293 Mdot
.55853 .36004 Mdot
.71501 .67686 Mdot
.34794 .41023 Mdot
.53706 .41642 Mdot
.57216 .37177 Mdot
.31846 .43215 Mdot
.61052 .61854 Mdot
.4909 .29619 Mdot
.54006 .40185 Mdot
.56303 .36327 Mdot
.70713 .49461 Mdot
.49753 .55572 Mdot
.31054 .70775 Mdot
.53931 .4152 Mdot
.69922 .53686 Mdot
.30252 .41649 Mdot
.53494 .36232 Mdot
.69361 .30384 Mdot
.55227 .68113 Mdot
.58978 .36567 Mdot
.28888 .61778 Mdot
.51491 .3927 Mdot
.48537 .8584 Mdot
.55638 .34935 Mdot
.31193 .43006 Mdot
.32056 .42349 Mdot
.60347 .68197 Mdot
.34704 .43023 Mdot
.27278 .63245 Mdot
.45161 .62112 Mdot
.27535 .73056 Mdot
.27415 .62859 Mdot
.52429 .33948 Mdot
.27697 .2825 Mdot
.50097 .39722 Mdot
.60144 .39392 Mdot
.66718 .28382 Mdot
.27511 .63215 Mdot
.32039 .41237 Mdot
.3698 .75269 Mdot
.52249 .33601 Mdot
.44692 .60073 Mdot
.6024 .40362 Mdot
.58908 .3625 Mdot
.50855 .49329 Mdot
.56443 .23545 Mdot
.46485 .60404 Mdot
.51732 .45478 Mdot
.54101 .41591 Mdot
.22653 .42048 Mdot
.5379 .38741 Mdot
.72374 .53674 Mdot
.3676 .4102 Mdot
.60942 .64681 Mdot
.72382 .52927 Mdot
.53162 .39905 Mdot
.71634 .51697 Mdot
.54682 .63989 Mdot
.44674 .63983 Mdot
.58007 .35588 Mdot
.68165 .50538 Mdot
.71922 .50954 Mdot
.56872 .42035 Mdot
.32636 .42372 Mdot
.60269 .31733 Mdot
.5327 .36299 Mdot
.58454 .39723 Mdot
.37223 .42175 Mdot
.32266 .20672 Mdot
.56075 .4403 Mdot
.64223 .52369 Mdot
.36598 .45369 Mdot
.28997 .65022 Mdot
.60499 .63552 Mdot
.52815 .44178 Mdot
.43594 .62959 Mdot
.44604 .625 Mdot
.58544 .60512 Mdot
.32211 .45212 Mdot
.58938 .66325 Mdot
.48576 .41914 Mdot
.61971 .36864 Mdot
.6125 .37013 Mdot
.63496 .18394 Mdot
.53375 .79625 Mdot
.30903 .43586 Mdot
.56529 .6719 Mdot
.39312 .53486 Mdot
.45404 .61042 Mdot
.58625 .60353 Mdot
.39288 .43881 Mdot
.3118 .41059 Mdot
.36726 .40241 Mdot
.69145 .51392 Mdot
.55865 .65768 Mdot
.36065 .38257 Mdot
.29486 .42587 Mdot
.56961 .42848 Mdot
.54212 .41665 Mdot
.30432 .3871 Mdot
.78314 .44519 Mdot
.72662 .50544 Mdot
.58313 .63282 Mdot
.6684 .81076 Mdot
.44378 .59932 Mdot
.31536 .2691 Mdot
.5403 .40612 Mdot
.2325 .23794 Mdot
.59704 .34553 Mdot
.53716 .38397 Mdot
.30291 .41884 Mdot
.68741 .53334 Mdot
.70352 .51777 Mdot
.31591 .42461 Mdot
.29328 .43987 Mdot
.69461 .52856 Mdot
.64431 .60544 Mdot
.29789 .76118 Mdot
.36681 .53775 Mdot
.31566 .43433 Mdot
.3188 .28311 Mdot
.45847 .6346 Mdot
.35585 .46049 Mdot
.45723 .60041 Mdot
.56064 .63674 Mdot
.54687 .61996 Mdot
.46435 .63874 Mdot
.58543 .40474 Mdot
.54912 .62946 Mdot
.47407 .38501 Mdot
.47345 .81897 Mdot
.69322 .73199 Mdot
.19351 .46662 Mdot
.50974 .37515 Mdot
.26941 .51651 Mdot
.24272 .52094 Mdot
.55704 .39557 Mdot
.58807 .45566 Mdot
.71903 .51443 Mdot
.35462 .45906 Mdot
.4601 .61031 Mdot
.54651 .81729 Mdot
.55658 .36005 Mdot
.34604 .4441 Mdot
.44811 .60622 Mdot
.4857 .78333 Mdot
.46923 .48096 Mdot
.55034 .43748 Mdot
.08241 .51529 Mdot
.3137 .45233 Mdot
.60943 .64781 Mdot
.25893 .32871 Mdot
.35589 .46538 Mdot
.7243 .59752 Mdot
.59199 .67828 Mdot
.26533 .689 Mdot
.32215 .40358 Mdot
.62403 .64898 Mdot
.33863 .43414 Mdot
.74051 .5245 Mdot
.32407 .46472 Mdot
.58733 .65546 Mdot
.53022 .37532 Mdot
.58438 .65768 Mdot
.73667 .51254 Mdot
.53809 .64001 Mdot
.46112 .61226 Mdot
.27454 .63795 Mdot
.44913 .61089 Mdot
.47839 .53896 Mdot
.52728 .24789 Mdot
.42905 .6392 Mdot
.56057 .76877 Mdot
.5182 .39939 Mdot
.40953 .4293 Mdot
.60982 .64293 Mdot
.5373 .61865 Mdot
.44919 .54108 Mdot
.34539 .44133 Mdot
.58699 .64994 Mdot
.36839 .23937 Mdot
.42736 .1462 Mdot
.47149 .37818 Mdot
.79465 .52717 Mdot
.3183 .43345 Mdot
.59842 .66943 Mdot
.34975 .54944 Mdot
.381 .42528 Mdot
.57767 .61528 Mdot
.4342 .6486 Mdot
.4273 .62635 Mdot
.58467 .41229 Mdot
.46953 .6406 Mdot
.57873 .67616 Mdot
.19599 .52471 Mdot
.36893 .41036 Mdot
.49606 .77833 Mdot
.71153 .5376 Mdot
.55491 .63689 Mdot
.52953 .31892 Mdot
.27935 .39824 Mdot
.54864 .61584 Mdot
.75391 .66034 Mdot
.70719 .78372 Mdot
.58642 .64886 Mdot
.36695 .40955 Mdot
.36079 .42964 Mdot
.5002 .33632 Mdot
.42379 .53456 Mdot
.59349 .65069 Mdot
.57224 .7197 Mdot
.7822 .38999 Mdot
.28938 .6223 Mdot
.24005 .32267 Mdot
.55339 .41194 Mdot
.57805 .3986 Mdot
.45768 .62891 Mdot
.52314 .38644 Mdot
.30114 .40832 Mdot
.60504 .37431 Mdot
.40051 .62839 Mdot
.57179 .67074 Mdot
.54767 .35526 Mdot
.70149 .50772 Mdot
.46164 .62086 Mdot
.43273 .65684 Mdot
.57266 .64454 Mdot
.36081 .39885 Mdot
.35456 .75383 Mdot
.55986 .65387 Mdot
.57087 .40327 Mdot
.28382 .63128 Mdot
.5265 .43598 Mdot
.68508 .69992 Mdot
.37762 .42526 Mdot
.60828 .64636 Mdot
.38824 .4372 Mdot
.44011 .61153 Mdot
.56565 .60721 Mdot
.54232 .38993 Mdot
.57028 .61517 Mdot
.66223 .49031 Mdot
.66789 .65522 Mdot
.29364 .42732 Mdot
.69861 .48386 Mdot
.35407 .45254 Mdot
.28911 .62167 Mdot
.6987 .40146 Mdot
.72921 .51624 Mdot
.56362 .62442 Mdot
.52683 .80375 Mdot
.60378 .62239 Mdot
.52278 .37291 Mdot
.51701 .36871 Mdot
.60009 .63934 Mdot
.69851 .50484 Mdot
.70478 .27558 Mdot
.67674 .55079 Mdot
.32652 .40477 Mdot
.37141 .49804 Mdot
.61196 .83463 Mdot
.50019 .63866 Mdot
.42378 .65142 Mdot
.52859 .4649 Mdot
.5282 .41712 Mdot
.45222 .64748 Mdot
.42179 .60039 Mdot
.72656 .49807 Mdot
.54238 .64467 Mdot
.3934 .41393 Mdot
.45874 .63745 Mdot
.56617 .28498 Mdot
.70753 .30499 Mdot
.48854 .3543 Mdot
.57514 .31716 Mdot
.53879 .33986 Mdot
.50088 .53414 Mdot
.40612 .60705 Mdot
.56402 .38203 Mdot
.61737 .39225 Mdot
.42505 .64436 Mdot
.73835 .51683 Mdot
.35862 .47548 Mdot
.58013 .64113 Mdot
.34625 .16323 Mdot
.57869 .35437 Mdot
.53031 .37071 Mdot
.4325 .63252 Mdot
.22548 .36709 Mdot
.31462 .43888 Mdot
.3608 .40129 Mdot
.55231 .64091 Mdot
.44294 .54399 Mdot
.59282 .35637 Mdot
.5592 .39272 Mdot
.56418 .62729 Mdot
.27722 .63907 Mdot
.17411 .48867 Mdot
.5634 .37026 Mdot
.42575 .61468 Mdot
.55099 .76367 Mdot
.40768 .60471 Mdot
.54616 .43969 Mdot
.52112 .37203 Mdot
.56772 .34392 Mdot
.50908 .40126 Mdot
.46155 .63865 Mdot
.55514 .39325 Mdot
.62884 .35765 Mdot
.32921 .40912 Mdot
.55523 .40527 Mdot
.76339 .36772 Mdot
.55892 .36654 Mdot
.7033 .50718 Mdot
.31761 .71898 Mdot
.56783 .35559 Mdot
.55911 .40458 Mdot
.66589 .54406 Mdot
.53836 .37593 Mdot
.42662 .60471 Mdot
.35799 .42632 Mdot
.43553 .60961 Mdot
.40951 .61981 Mdot
.52854 .62745 Mdot
.73391 .50118 Mdot
.49616 .40668 Mdot
.6991 .53468 Mdot
.52641 .3243 Mdot
.53221 .43669 Mdot
.48737 .55153 Mdot
.34763 .56553 Mdot
.66807 .51679 Mdot
.54841 .38824 Mdot
.55846 .64125 Mdot
.60562 .63234 Mdot
.71743 .46674 Mdot
.47926 .36539 Mdot
.46323 .63046 Mdot
.44384 .6451 Mdot
.75656 .42678 Mdot
.48898 .48502 Mdot
.71035 .5044 Mdot
.39884 .52064 Mdot
.51235 .36432 Mdot
.57254 .36593 Mdot
.59796 .41476 Mdot
.52802 .6458 Mdot
.27517 .64198 Mdot
.56551 .66893 Mdot
.26485 .62285 Mdot
.41049 .60056 Mdot
.51064 .37319 Mdot
.65775 .75446 Mdot
.32214 .44906 Mdot
.35815 .42498 Mdot
.4025 .6371 Mdot
.56607 .67405 Mdot
.49931 .33894 Mdot
.65344 .1871 Mdot
.32629 .38203 Mdot
.70612 .54345 Mdot
.56309 .39081 Mdot
.56868 .64322 Mdot
.3051 .43869 Mdot
.70982 .48862 Mdot
.51471 .36513 Mdot
.60229 .61453 Mdot
.55464 .37057 Mdot
.33974 .32591 Mdot
.32512 .41293 Mdot
.3137 .65237 Mdot
.29071 .41805 Mdot
.44059 .65087 Mdot
.41021 .62877 Mdot
.52374 .36542 Mdot
.53657 .14566 Mdot
.28562 .42371 Mdot
.48216 .61405 Mdot
.7436 .52145 Mdot
.28011 .64642 Mdot
.74141 .51009 Mdot
.59597 .66352 Mdot
.72338 .51914 Mdot
.57023 .61312 Mdot
.76996 .44622 Mdot
.34702 .37939 Mdot
.72906 .52735 Mdot
.21521 .37761 Mdot
.54998 .44777 Mdot
.7185 .49418 Mdot
.6181 .35695 Mdot
.42113 .43325 Mdot
.56508 .62922 Mdot
.69794 .50704 Mdot
.57582 .41962 Mdot
.58709 .7912 Mdot
.40929 .62427 Mdot
.46445 .62731 Mdot
.49878 .4114 Mdot
.61386 .6475 Mdot
.29613 .44357 Mdot
.59656 .541 Mdot
.29466 .64804 Mdot
.55855 .39212 Mdot
.51271 .36649 Mdot
.33981 .45616 Mdot
.33003 .38712 Mdot
.52012 .37058 Mdot
.38644 .2345 Mdot
.53446 .39502 Mdot
.4237 .62576 Mdot
.30618 .4195 Mdot
.36085 .42629 Mdot
.55833 .67535 Mdot
.32216 .45184 Mdot
.57581 .31977 Mdot
.38674 .61992 Mdot
.61206 .39721 Mdot
.44164 .6147 Mdot
.60773 .50465 Mdot
.54094 .64895 Mdot
.54572 .81129 Mdot
.3123 .44799 Mdot
.56725 .39965 Mdot
.36007 .44971 Mdot
.71126 .5355 Mdot
.34994 .41096 Mdot
.37312 .40027 Mdot
.52144 .35977 Mdot
.54688 .43746 Mdot
.27914 .63547 Mdot
.42408 .53615 Mdot
.33059 .41584 Mdot
.54147 .3973 Mdot
.49761 .38867 Mdot
.57567 .43286 Mdot
.49695 .51654 Mdot
.31315 .40699 Mdot
.48282 .20366 Mdot
.69184 .71081 Mdot
.32875 .42176 Mdot
.55287 .83319 Mdot
.29939 .62511 Mdot
.26609 .63948 Mdot
.47908 .60514 Mdot
.56494 .36682 Mdot
.58755 .66248 Mdot
.58986 .37758 Mdot
.47354 .39413 Mdot
.56607 .35269 Mdot
.7312 .50541 Mdot
.49695 .35658 Mdot
.29605 .63338 Mdot
.56722 .6566 Mdot
.53578 .40158 Mdot
.55192 .35374 Mdot
.26609 .63567 Mdot
.28943 .41911 Mdot
.31695 .40704 Mdot
.29949 .7325 Mdot
.73615 .52506 Mdot
.44807 .63416 Mdot
.58826 .38517 Mdot
.55595 .64117 Mdot
.58183 .66071 Mdot
.37331 .43563 Mdot
.57983 .63544 Mdot
.44945 .60027 Mdot
.53352 .38851 Mdot
.45399 .64635 Mdot
.73191 .50625 Mdot
.36798 .41075 Mdot
.58852 .38581 Mdot
.57175 .4269 Mdot
.32043 .42323 Mdot
.51683 .39807 Mdot
.70575 .49487 Mdot
.5414 .62642 Mdot
.31435 .41166 Mdot
.45043 .62205 Mdot
.54635 .67029 Mdot
.54906 .43312 Mdot
.7832 .69544 Mdot
.52275 .3882 Mdot
.5847 .37966 Mdot
.34202 .79671 Mdot
.58657 .44323 Mdot
.59759 .66736 Mdot
.36912 .44726 Mdot
.57006 .44063 Mdot
.80134 .41702 Mdot
.44466 .68296 Mdot
.59061 .6042 Mdot
.56639 .39224 Mdot
.52398 .82397 Mdot
.5616 .4003 Mdot
.47398 .78462 Mdot
.48502 .55028 Mdot
.82303 .54215 Mdot
.58503 .32134 Mdot
.48055 .62247 Mdot
.27714 .63598 Mdot
.61056 .64088 Mdot
.38875 .34402 Mdot
.51905 .39196 Mdot
.43463 .34839 Mdot
.58845 .35791 Mdot
.42169 .62185 Mdot
.5748 .46081 Mdot
.58251 .63362 Mdot
.28549 .28536 Mdot
.57287 .40617 Mdot
.30992 .4106 Mdot
.5236 .62597 Mdot
.28903 .64673 Mdot
.57736 .41865 Mdot
.70995 .53907 Mdot
.39801 .67022 Mdot
.60443 .3445 Mdot
.44408 .61601 Mdot
.57429 .37267 Mdot
.49954 .44667 Mdot
.47283 .14809 Mdot
.3278 .40808 Mdot
.4266 .65097 Mdot
.26052 .47066 Mdot
.51028 .39071 Mdot
.32013 .40525 Mdot
.35499 .42754 Mdot
.73268 .53692 Mdot
.35237 .58612 Mdot
.49638 .67413 Mdot
.73018 .70922 Mdot
.46267 .30294 Mdot
.53846 .66673 Mdot
.20884 .49526 Mdot
.54798 .41658 Mdot
.65811 .44305 Mdot
.41857 .60954 Mdot
.53121 .37271 Mdot
.4953 .26467 Mdot
.34116 .40894 Mdot
.56052 .3742 Mdot
.72855 .5071 Mdot
.32873 .61016 Mdot
.622 .46836 Mdot
.71213 .7575 Mdot
.55013 .60883 Mdot
.60615 .39927 Mdot
.6051 .33121 Mdot
.28724 .65066 Mdot
.53162 .4315 Mdot
.61074 .64618 Mdot
.61014 .73481 Mdot
.7029 .50085 Mdot
.31636 .44744 Mdot
.30045 .62884 Mdot
.57129 .34051 Mdot
.50901 .41988 Mdot
.73184 .54483 Mdot
.57929 .40839 Mdot
.26991 .31074 Mdot
.30047 .65207 Mdot
.55889 .62208 Mdot
.3473 .39792 Mdot
.53607 .34049 Mdot
.27654 .64217 Mdot
.51901 .36356 Mdot
.34245 .48025 Mdot
.57608 .38889 Mdot
.24146 .62361 Mdot
.32587 .4275 Mdot
.44666 .61403 Mdot
.48988 .39387 Mdot
.54952 .3628 Mdot
.71872 .61178 Mdot
.47388 .39771 Mdot
.55648 .34989 Mdot
.35164 .3869 Mdot
.33115 .44946 Mdot
.36525 .44145 Mdot
.55104 .62542 Mdot
.37395 .53365 Mdot
.43037 .62041 Mdot
.60017 .368 Mdot
.45955 .6352 Mdot
.49861 .31791 Mdot
.7224 .54501 Mdot
.60213 .80714 Mdot
.5262 .39932 Mdot
.36941 .43255 Mdot
.20029 .54726 Mdot
.30158 .41797 Mdot
.46864 .58605 Mdot
.43537 .60558 Mdot
.33819 .41496 Mdot
.54319 .37673 Mdot
.40401 .53063 Mdot
.75221 .72018 Mdot
.45519 .61391 Mdot
.58771 .43508 Mdot
.54314 .61235 Mdot
.5715 .61136 Mdot
.53594 .85613 Mdot
.40666 .62544 Mdot
.23872 .51719 Mdot
.54649 .39875 Mdot
.32831 .4507 Mdot
.43337 .63758 Mdot
.42269 .60539 Mdot
.56992 .6282 Mdot
.55795 .4377 Mdot
.55154 .36477 Mdot
.29104 .61829 Mdot
.44915 .64014 Mdot
.52938 .44989 Mdot
.52604 .42184 Mdot
.41358 .82885 Mdot
.39752 .42901 Mdot
.29567 .22482 Mdot
.48939 .42882 Mdot
.50469 .26491 Mdot
.52695 .51607 Mdot
.30619 .43343 Mdot
.58911 .39296 Mdot
.59774 .35676 Mdot
.5476 .67219 Mdot
.5295 .38973 Mdot
.54457 .66253 Mdot
.42012 .65043 Mdot
.6113 .80991 Mdot
.50814 .76978 Mdot
.60922 .59398 Mdot
.52293 .38126 Mdot
.5692 .48359 Mdot
.7153 .53276 Mdot
.39974 .64134 Mdot
.34385 .44699 Mdot
.52527 .34579 Mdot
.58878 .67972 Mdot
.56669 .62307 Mdot
.35098 .42231 Mdot
.25032 .54045 Mdot
.51108 .7979 Mdot
.50805 .40095 Mdot
.60639 .64842 Mdot
.48336 .76668 Mdot
.41372 .22871 Mdot
.47386 .63521 Mdot
.70846 .4997 Mdot
.57471 .66999 Mdot
.42494 .65795 Mdot
.38235 .47209 Mdot
.34268 .42349 Mdot
.33081 .45708 Mdot
.70015 .66401 Mdot
.59186 .65408 Mdot
.71229 .5287 Mdot
.45848 .46613 Mdot
.42679 .46855 Mdot
.72523 .50228 Mdot
.57052 .67111 Mdot
.31592 .44522 Mdot
.34875 .44402 Mdot
.35779 .42795 Mdot
.2793 .29583 Mdot
.37772 .41786 Mdot
.4413 .18698 Mdot
.50385 .4035 Mdot
.33003 .27987 Mdot
.56341 .39812 Mdot
.47094 .62538 Mdot
.32406 .41407 Mdot
.46706 .53291 Mdot
.51314 .35332 Mdot
.71949 .74795 Mdot
.56306 .38743 Mdot
.38069 .63022 Mdot
.56443 .3648 Mdot
.27771 .32499 Mdot
.36517 .45422 Mdot
.54789 .38956 Mdot
.46827 .6032 Mdot
.71522 .51041 Mdot
.28859 .44778 Mdot
.56458 .35542 Mdot
.29881 .59553 Mdot
.61747 .38768 Mdot
.49375 .81205 Mdot
.69116 .5793 Mdot
.69884 .54118 Mdot
.61526 .36832 Mdot
.51892 .64431 Mdot
.27629 .42281 Mdot
.31403 .29771 Mdot
.45545 .61517 Mdot
.59961 .25752 Mdot
.55978 .62548 Mdot
.5779 .45896 Mdot
.54268 .32823 Mdot
.69131 .51065 Mdot
.28467 .43592 Mdot
.42152 .62695 Mdot
.5193 .39745 Mdot
.5921 .38759 Mdot
.76422 .63499 Mdot
.30524 .30215 Mdot
.52335 .44671 Mdot
.75003 .52562 Mdot
.4924 .20694 Mdot
.57382 .36113 Mdot
.59956 .61111 Mdot
.37939 .44087 Mdot
.54653 .31566 Mdot
.4696 .20273 Mdot
.53785 .39757 Mdot
.34264 .41625 Mdot
.31488 .44973 Mdot
.22705 .59593 Mdot
.71037 .54368 Mdot
.57625 .38858 Mdot
.73532 .6075 Mdot
.57559 .40144 Mdot
.42665 .62212 Mdot
.55431 .44226 Mdot
.55769 .63311 Mdot
.34558 .55343 Mdot
.54477 .62784 Mdot
.58175 .42198 Mdot
.35226 .43843 Mdot
.42354 .63074 Mdot
.69136 .681 Mdot
.57584 .54741 Mdot
.45217 .18629 Mdot
.40001 .67342 Mdot
.69337 .51539 Mdot
.72709 .4951 Mdot
.40822 .59558 Mdot
.55383 .38477 Mdot
.52432 .53457 Mdot
.56806 .32254 Mdot
.56566 .36162 Mdot
.57799 .35612 Mdot
.41468 .66014 Mdot
.44032 .60677 Mdot
.58245 .65218 Mdot
.51907 .37299 Mdot
.54253 .39677 Mdot
.33288 .42436 Mdot
.71864 .50864 Mdot
.556 .62065 Mdot
.73116 .53044 Mdot
.56361 .65153 Mdot
.4986 .85381 Mdot
.57363 .44096 Mdot
.71386 .51018 Mdot
.40232 .60976 Mdot
.37234 .42827 Mdot
.27142 .62675 Mdot
.59303 .66468 Mdot
.58445 .63624 Mdot
.55641 .39426 Mdot
.36092 .4074 Mdot
.34762 .40342 Mdot
.69259 .52445 Mdot
.43729 .64365 Mdot
.58702 .40861 Mdot
.53395 .42973 Mdot
.79252 .56852 Mdot
.53116 .65764 Mdot
.40826 .22068 Mdot
.24203 .58309 Mdot
.55273 .38505 Mdot
.33864 .40161 Mdot
.54368 .35726 Mdot
.60617 .76171 Mdot
.36869 .40159 Mdot
.50157 .37244 Mdot
.48481 .47407 Mdot
.52923 .63772 Mdot
.21855 .62461 Mdot
.49262 .38881 Mdot
.36822 .66745 Mdot
.5601 .42069 Mdot
.29271 .78259 Mdot
.21458 .45067 Mdot
.58173 .34725 Mdot
.50762 .3955 Mdot
.75958 .68264 Mdot
.55143 .40037 Mdot
.29706 .62731 Mdot
.48147 .40507 Mdot
.3142 .40857 Mdot
.5492 .52601 Mdot
.49432 .56398 Mdot
.73461 .54059 Mdot
.55155 .64051 Mdot
.68178 .35842 Mdot
.73976 .52163 Mdot
.31392 .43009 Mdot
.50234 .38106 Mdot
.55342 .27695 Mdot
.58934 .68642 Mdot
.54314 .32462 Mdot
.42497 .62193 Mdot
.49004 .56148 Mdot
.55317 .66345 Mdot
.45168 .61895 Mdot
.58102 .35087 Mdot
.78478 .36431 Mdot
.58284 .55542 Mdot
.23309 .68196 Mdot
.43528 .6337 Mdot
.42314 .6095 Mdot
.34978 .53299 Mdot
.73442 .54059 Mdot
.77808 .61133 Mdot
.62264 .44854 Mdot
.44734 .60207 Mdot
.72859 .39342 Mdot
.60461 .67117 Mdot
.34903 .58745 Mdot
.35745 .45877 Mdot
.58091 .43557 Mdot
.54453 .37325 Mdot
.43099 .64444 Mdot
.42916 .37512 Mdot
.29817 .47729 Mdot
.45142 .61197 Mdot
.61613 .33703 Mdot
.33921 .61572 Mdot
.28076 .62999 Mdot
.29531 .61909 Mdot
.7452 .52621 Mdot
.63625 .69026 Mdot
.33262 .43547 Mdot
.6918 .50604 Mdot
.24751 .64273 Mdot
.57808 .38462 Mdot
.45166 .63971 Mdot
.27825 .61764 Mdot
.44274 .62479 Mdot
.70482 .51334 Mdot
.70897 .54409 Mdot
.32895 .40888 Mdot
.31614 .43995 Mdot
.56192 .23894 Mdot
.75894 .41014 Mdot
.55493 .40293 Mdot
.48293 .30119 Mdot
.37425 .41752 Mdot
.27891 .35148 Mdot
.70549 .5401 Mdot
.72211 .5079 Mdot
.36328 .29352 Mdot
.56068 .4338 Mdot
.52906 .7671 Mdot
.56856 .35706 Mdot
.70011 .41404 Mdot
.53191 .33349 Mdot
.57357 .63022 Mdot
.5609 .40867 Mdot
.33973 .73283 Mdot
.53269 .40979 Mdot
.56874 .35075 Mdot
.56992 .66379 Mdot
.48929 .40297 Mdot
.55755 .63122 Mdot
.5511 .43952 Mdot
.7474 .54209 Mdot
.55579 .64137 Mdot
.79352 .50697 Mdot
.6405 .52095 Mdot
.28257 .64301 Mdot
.7425 .52378 Mdot
.70339 .53597 Mdot
.76021 .35374 Mdot
.33652 .44663 Mdot
.40125 .46059 Mdot
.55492 .38408 Mdot
.60941 .66219 Mdot
.45742 .63142 Mdot
.53879 .3964 Mdot
.60235 .36075 Mdot
.4924 .39735 Mdot
.33705 .41073 Mdot
.57796 .67252 Mdot
.71238 .51612 Mdot
.60258 .63004 Mdot
.64742 .57356 Mdot
.58953 .61381 Mdot
.51037 .46314 Mdot
.49468 .433 Mdot
.56331 .29666 Mdot
.49558 .28355 Mdot
.3124 .25748 Mdot
.34693 .42534 Mdot
.28876 .63367 Mdot
.73239 .54301 Mdot
.36988 .49677 Mdot
.36303 .43805 Mdot
.58738 .63957 Mdot
.55449 .37061 Mdot
.6156 .3347 Mdot
.60848 .47219 Mdot
.31477 .37613 Mdot
.79201 .41939 Mdot
.5504 .65515 Mdot
.28356 .62376 Mdot
.36009 .54384 Mdot
.3818 .38321 Mdot
.47252 .53412 Mdot
.54778 .35943 Mdot
.70506 .53808 Mdot
.30517 .43878 Mdot
.72699 .66227 Mdot
.43333 .64723 Mdot
.42239 .53521 Mdot
.52343 .38296 Mdot
.21271 .51996 Mdot
.35205 .43823 Mdot
.72175 .50442 Mdot
.43004 .6443 Mdot
.70988 .54293 Mdot
.3013 .62712 Mdot
.31693 .73825 Mdot
.57454 .4142 Mdot
.55412 .34852 Mdot
.43152 .59378 Mdot
.3363 .43678 Mdot
.62372 .66491 Mdot
.7361 .66701 Mdot
.60553 .64637 Mdot
.51225 .53892 Mdot
.30304 .43039 Mdot
.25398 .39583 Mdot
.5812 .61754 Mdot
.39822 .62489 Mdot
.51163 .52977 Mdot
.40107 .62832 Mdot
.57429 .3578 Mdot
.36628 .41908 Mdot
.40645 .62631 Mdot
.72731 .63364 Mdot
.47696 .84052 Mdot
.29023 .45465 Mdot
.51374 .39061 Mdot
.6105 .80773 Mdot
.39151 .80997 Mdot
.45231 .35403 Mdot
.45589 .64026 Mdot
.52987 .36097 Mdot
.50711 .40043 Mdot
.57094 .40647 Mdot
.4135 .6419 Mdot
.61977 .57859 Mdot
.58187 .62723 Mdot
.56719 .38379 Mdot
.71043 .53705 Mdot
.5668 .63523 Mdot
.51926 .63455 Mdot
.60927 .63338 Mdot
.3652 .39633 Mdot
.50222 .39023 Mdot
.33266 .58599 Mdot
.32117 .80179 Mdot
.43899 .60827 Mdot
.28306 .64314 Mdot
.57454 .34943 Mdot
.55533 .20638 Mdot
.36611 .44032 Mdot
.6047 .64592 Mdot
.5314 .37074 Mdot
.69244 .59427 Mdot
.30969 .60855 Mdot
.55559 .65349 Mdot
.34065 .44616 Mdot
.45227 .35527 Mdot
.52983 .39048 Mdot
.55992 .42281 Mdot
.32489 .43516 Mdot
.27268 .71688 Mdot
.35096 .55947 Mdot
.54718 .35642 Mdot
.44837 .61447 Mdot
.45016 .14121 Mdot
.50479 .41676 Mdot
.2936 .3842 Mdot
.2783 .64635 Mdot
.2569 .59938 Mdot
.4232 .21839 Mdot
.46899 .41593 Mdot
.63811 .78211 Mdot
.68329 .30411 Mdot
.58991 .81413 Mdot
.67274 .39287 Mdot
.44016 .75092 Mdot
.44348 .86502 Mdot
.47575 .60924 Mdot
.28296 .32811 Mdot
.81327 .58901 Mdot
.26918 .5418 Mdot
.66422 .57031 Mdot
.49698 .69762 Mdot
.70392 .58839 Mdot
.17904 .42479 Mdot
.58846 .6159 Mdot
.6829 .43912 Mdot
.58958 .39751 Mdot
.38371 .80308 Mdot
.33123 .26661 Mdot
.32165 .2415 Mdot
.58668 .80635 Mdot
.73364 .59956 Mdot
.78755 .6761 Mdot
.54318 .8073 Mdot
.59624 .26767 Mdot
.5612 .49445 Mdot
.57465 .70349 Mdot
.44304 .46051 Mdot
.6798 .3441 Mdot
.52573 .31355 Mdot
.33382 .71167 Mdot
.60695 .60313 Mdot
.50528 .23321 Mdot
.44043 .153 Mdot
.59265 .66809 Mdot
.38088 .43808 Mdot
.79317 .59368 Mdot
.26942 .41139 Mdot
.44867 .58342 Mdot
.63917 .78175 Mdot
.41359 .83201 Mdot
.27899 .3221 Mdot
.25392 .66536 Mdot
.36772 .32317 Mdot
.69715 .26099 Mdot
.60718 .48759 Mdot
.2974 .43836 Mdot
.4764 .73409 Mdot
.42728 .4677 Mdot
.60623 .69818 Mdot
.25987 .34363 Mdot
.69888 .48901 Mdot
.80264 .47421 Mdot
.34211 .44486 Mdot
.43144 .22528 Mdot
.26762 .64448 Mdot
.25237 .64481 Mdot
.62037 .65834 Mdot
.61777 .75542 Mdot
.31706 .60887 Mdot
.31632 .59469 Mdot
.19092 .51745 Mdot
.75768 .72948 Mdot
.71009 .34005 Mdot
.62562 .72939 Mdot
.37305 .6218 Mdot
.68911 .30912 Mdot
.32136 .55076 Mdot
.74681 .37998 Mdot
.42829 .45363 Mdot
.85487 .56202 Mdot
.31216 .76151 Mdot
.81718 .63659 Mdot
.37976 .46276 Mdot
.54522 .44808 Mdot
.64933 .73325 Mdot
.44904 .31464 Mdot
.68547 .53326 Mdot
.73785 .74312 Mdot
.68645 .52546 Mdot
.39144 .41388 Mdot
.26046 .53644 Mdot
.28563 .29793 Mdot
.63406 .63423 Mdot
.74259 .55192 Mdot
.58401 .32708 Mdot
.88543 .48611 Mdot
.66122 .77389 Mdot
.23499 .59827 Mdot
.40375 .82662 Mdot
.49526 .64201 Mdot
.55537 .68412 Mdot
.41639 .64801 Mdot
.45285 .85396 Mdot
.3633 .43223 Mdot
.33531 .81613 Mdot
.4458 .84724 Mdot
.25184 .42898 Mdot
.89421 .45209 Mdot
.18546 .45965 Mdot
.34141 .27 Mdot
.64034 .28242 Mdot
.81431 .47267 Mdot
.32523 .52945 Mdot
.24207 .41017 Mdot
.50526 .6369 Mdot
.26593 .71957 Mdot
.50572 .84645 Mdot
.72517 .40762 Mdot
.53379 .60243 Mdot
.28206 .53669 Mdot
.62236 .4966 Mdot
.29533 .38774 Mdot
.67283 .5561 Mdot
.64943 .4817 Mdot
.8046 .65471 Mdot
.54663 .22189 Mdot
.5756 .15332 Mdot
.67959 .39701 Mdot
.22874 .36157 Mdot
.53757 .7915 Mdot
.78256 .50065 Mdot
.32389 .48109 Mdot
.29062 .57061 Mdot
.60137 .42364 Mdot
.38618 .52171 Mdot
.63349 .36854 Mdot
.71982 .48258 Mdot
.36237 .53445 Mdot
.43782 .78371 Mdot
.69229 .39622 Mdot
.7134 .71499 Mdot
.52413 .49272 Mdot
.34636 .39476 Mdot
.74553 .35849 Mdot
.71697 .36505 Mdot
.43217 .8283 Mdot
.2599 .47172 Mdot
.23915 .69106 Mdot
.26439 .46489 Mdot
.57181 .32338 Mdot
.28502 .33187 Mdot
.53913 .30877 Mdot
.73494 .3767 Mdot
.50022 .36193 Mdot
.19 .53419 Mdot
.35241 .80444 Mdot
.51216 .2509 Mdot
.68959 .36672 Mdot
.51391 .27315 Mdot
.27965 .73488 Mdot
.6592 .73209 Mdot
.22016 .46709 Mdot
.31562 .3624 Mdot
.87624 .51135 Mdot
.57614 .64269 Mdot
.73329 .40087 Mdot
.39657 .64708 Mdot
.70175 .66848 Mdot
.83229 .55686 Mdot
.27353 .46072 Mdot
.34229 .79992 Mdot
.30548 .57014 Mdot
.63405 .65456 Mdot
.35342 .60068 Mdot
.49896 .62076 Mdot
.54199 .26626 Mdot
.49878 .41507 Mdot
.55884 .2905 Mdot
.69745 .49666 Mdot
.4307 .31917 Mdot
.67848 .71426 Mdot
.41328 .70097 Mdot
.47674 .44019 Mdot
.42608 .7158 Mdot
.28536 .62071 Mdot
.40576 .53757 Mdot
.52602 .85844 Mdot
.48026 .42115 Mdot
.19662 .42945 Mdot
.30701 .753 Mdot
.50197 .53711 Mdot
.64754 .66546 Mdot
.22799 .56055 Mdot
.8397 .60029 Mdot
.40239 .83924 Mdot
.41922 .80166 Mdot
.61973 .80519 Mdot
.17677 .63288 Mdot
.84532 .50869 Mdot
.38093 .35667 Mdot
.40342 .65535 Mdot
.1285 .62641 Mdot
.59425 .63041 Mdot
.60647 .25487 Mdot
.45154 .30972 Mdot
.68988 .60202 Mdot
.27529 .41317 Mdot
.47599 .45177 Mdot
.43834 .67486 Mdot
.29958 .39436 Mdot
.58559 .32963 Mdot
.70166 .78109 Mdot
.85871 .55971 Mdot
.72058 .76476 Mdot
.32026 .74281 Mdot
.60639 .81609 Mdot
.80095 .63024 Mdot
.42996 .18873 Mdot
.78005 .61715 Mdot
.5521 .44171 Mdot
.74331 .43099 Mdot
.19095 .4562 Mdot
.62542 .652 Mdot
.27253 .66329 Mdot
.38654 .44899 Mdot
.8415 .57375 Mdot
.5378 .86122 Mdot
.38648 .28998 Mdot
.47923 .22303 Mdot
.64546 .50081 Mdot
.74614 .39651 Mdot
.59706 .28813 Mdot
.33516 .69913 Mdot
.47126 .82243 Mdot
.8078 .61938 Mdot
.71124 .37568 Mdot
.48135 .7051 Mdot
.42 .79347 Mdot
.22716 .4029 Mdot
.57357 .79267 Mdot
.80223 .58375 Mdot
.25424 .44256 Mdot
.3963 .38378 Mdot
.2898 .47193 Mdot
.32572 .68577 Mdot
.57849 .74469 Mdot
.69853 .33449 Mdot
.53693 .64181 Mdot
.72968 .41376 Mdot
.46455 .50289 Mdot
.78586 .61084 Mdot
.69817 .30784 Mdot
.72052 .41117 Mdot
.43803 .80137 Mdot
.67158 .79323 Mdot
.24225 .67059 Mdot
.80981 .39039 Mdot
.35725 .66789 Mdot
.63262 .38622 Mdot
.52704 .44251 Mdot
.31735 .77464 Mdot
.64572 .81937 Mdot
.3564 .81333 Mdot
.21038 .51608 Mdot
.71916 .63617 Mdot
.45521 .65018 Mdot
.69646 .28745 Mdot
.38751 .68838 Mdot
.47989 .82636 Mdot
.38011 .50415 Mdot
.4858 .61268 Mdot
.31572 .57051 Mdot
.59037 .25898 Mdot
.66258 .28581 Mdot
.44772 .23557 Mdot
.4915 .34692 Mdot
.37474 .24526 Mdot
.36669 .45118 Mdot
.21132 .50259 Mdot
.74463 .38482 Mdot
.57266 .64355 Mdot
.80298 .54393 Mdot
.57838 .28881 Mdot
.58655 .44413 Mdot
.59289 .73517 Mdot
.29287 .39056 Mdot
.49643 .28015 Mdot
.53573 .67432 Mdot
.46407 .86489 Mdot
.20089 .46417 Mdot
.58162 .27587 Mdot
.72509 .33762 Mdot
.78264 .57682 Mdot
.35768 .56017 Mdot
.40069 .60543 Mdot
.57484 .80705 Mdot
.63424 .53903 Mdot
.73869 .35169 Mdot
.38369 .23977 Mdot
.71522 .68393 Mdot
.59867 .35552 Mdot
.22318 .57769 Mdot
.48831 .18715 Mdot
.41539 .53869 Mdot
.39038 .40238 Mdot
.33237 .38021 Mdot
.17119 .39421 Mdot
.35484 .74036 Mdot
.24094 .45608 Mdot
.58424 .79731 Mdot
.40603 .63766 Mdot
.33742 .38913 Mdot
.72133 .42198 Mdot
.67051 .6583 Mdot
.51509 .21521 Mdot
.58725 .74916 Mdot
.62437 .29658 Mdot
.38198 .69465 Mdot
.61646 .80249 Mdot
.72317 .73481 Mdot
.48647 .14453 Mdot
.29574 .40896 Mdot
.67497 .70321 Mdot
.69284 .69094 Mdot
.2967 .43118 Mdot
.30828 .37773 Mdot
.5912 .4818 Mdot
.57602 .82802 Mdot
.40653 .49881 Mdot
.32767 .66631 Mdot
.51205 .53087 Mdot
.66288 .58544 Mdot
.73865 .65642 Mdot
.68808 .33065 Mdot
.59179 .78902 Mdot
.43173 .23429 Mdot
.82665 .46118 Mdot
.58225 .30176 Mdot
.57464 .23388 Mdot
.69641 .28691 Mdot
.58472 .49794 Mdot
.26214 .34608 Mdot
.45826 .7853 Mdot
.56893 .40316 Mdot
.75075 .73979 Mdot
.43074 .8225 Mdot
.37062 .51993 Mdot
.54415 .68997 Mdot
.54213 .42436 Mdot
.50227 .39812 Mdot
.40497 .37776 Mdot
.25129 .59239 Mdot
.84326 .45989 Mdot
.68719 .41056 Mdot
.6346 .37826 Mdot
.37726 .24008 Mdot
.19735 .42876 Mdot
.63386 .74154 Mdot
.50828 .80729 Mdot
.44625 .50499 Mdot
.19219 .4588 Mdot
.42304 .55322 Mdot
.31949 .66583 Mdot
.38672 .71624 Mdot
.79501 .63827 Mdot
.5684 .47598 Mdot
.26793 .57861 Mdot
.77115 .61367 Mdot
.57723 .35226 Mdot
.25027 .54092 Mdot
.5564 .79897 Mdot
.61898 .18038 Mdot
.31165 .54218 Mdot
.67923 .80054 Mdot
.56256 .29391 Mdot
.28153 .57933 Mdot
.84044 .54921 Mdot
.71214 .22652 Mdot
.32795 .70575 Mdot
.79335 .67075 Mdot
.37465 .56855 Mdot
.59213 .79553 Mdot
.47828 .62781 Mdot
.4613 .47899 Mdot
.45548 .32913 Mdot
.56911 .82972 Mdot
.65166 .69259 Mdot
.61955 .76458 Mdot
.3933 .37115 Mdot
.60688 .8222 Mdot
.42418 .4511 Mdot
.18422 .37809 Mdot
.60029 .60896 Mdot
.17449 .52806 Mdot
.33365 .35543 Mdot
.62435 .3154 Mdot
.72397 .39145 Mdot
.22073 .33745 Mdot
.37904 .2058 Mdot
.402 .36319 Mdot
.72426 .4507 Mdot
.23513 .57018 Mdot
.7204 .33112 Mdot
.47972 .83085 Mdot
.17946 .41397 Mdot
.71545 .67559 Mdot
.23592 .49244 Mdot
.2975 .73474 Mdot
.24594 .59735 Mdot
.39114 .73828 Mdot
.61995 .73716 Mdot
.2926 .69176 Mdot
.63069 .30303 Mdot
.24704 .23737 Mdot
.51428 .58667 Mdot
.59848 .478 Mdot
.83033 .60902 Mdot
.46592 .82284 Mdot
.36901 .50046 Mdot
.25596 .34178 Mdot
.61645 .23852 Mdot
.77208 .45024 Mdot
.56569 .35277 Mdot
.6141 .82065 Mdot
.78865 .48319 Mdot
.76209 .71405 Mdot
.2585 .72956 Mdot
.38451 .24931 Mdot
.49986 .45139 Mdot
.50901 .63434 Mdot
.62698 .47351 Mdot
.71382 .45336 Mdot
.80598 .6378 Mdot
.59164 .24524 Mdot
.57568 .5429 Mdot
.4399 .74387 Mdot
.54504 .7734 Mdot
.62301 .4292 Mdot
.18259 .47586 Mdot
.24823 .58024 Mdot
.68154 .38026 Mdot
.40486 .78722 Mdot
.7355 .39057 Mdot
.4141 .22017 Mdot
.70188 .29809 Mdot
.31234 .50408 Mdot
.48275 .66358 Mdot
.56525 .67792 Mdot
.7507 .68611 Mdot
.51971 .79532 Mdot
.19096 .53964 Mdot
.81564 .41327 Mdot
.28447 .56695 Mdot
.68096 .44985 Mdot
.70571 .70843 Mdot
.31763 .52683 Mdot
.57333 .70778 Mdot
.65505 .2809 Mdot
.56746 .23497 Mdot
.47938 .79274 Mdot
.45993 .41933 Mdot
.50926 .84886 Mdot
.696 .3358 Mdot
.75321 .66466 Mdot
.63541 .51092 Mdot
.45692 .28808 Mdot
.32887 .30685 Mdot
.8055 .50415 Mdot
.44148 .54227 Mdot
.88248 .49378 Mdot
.31043 .45423 Mdot
.76016 .72664 Mdot
.4504 .63293 Mdot
.52862 .16426 Mdot
.47803 .80753 Mdot
.45695 .51405 Mdot
.51287 .52214 Mdot
.22242 .58148 Mdot
.30812 .59859 Mdot
.28977 .73472 Mdot
.27907 .46337 Mdot
.60247 .61929 Mdot
.59365 .5489 Mdot
.32944 .67271 Mdot
.71259 .72355 Mdot
.5815 .42925 Mdot
.63617 .63684 Mdot
.59754 .49425 Mdot
.43426 .57003 Mdot
.32241 .77674 Mdot
.46485 .77661 Mdot
.56349 .31197 Mdot
.74898 .3979 Mdot
.81742 .61197 Mdot
.45032 .84312 Mdot
.3225 .4887 Mdot
.63328 .36537 Mdot
.38392 .62164 Mdot
.82286 .53458 Mdot
.66252 .76795 Mdot
.5182 .77022 Mdot
.34563 .58722 Mdot
.7095 .34365 Mdot
.74872 .76141 Mdot
.8571 .5603 Mdot
.82219 .41648 Mdot
.5183 .53355 Mdot
.41077 .42798 Mdot
.55867 .20979 Mdot
.74946 .66919 Mdot
.17283 .54925 Mdot
.42729 .81296 Mdot
.73246 .39569 Mdot
.6701 .21294 Mdot
.33792 .24017 Mdot
.63179 .57035 Mdot
.33002 .30773 Mdot
.4715 .29703 Mdot
.48423 .62568 Mdot
.76748 .45783 Mdot
.61996 .54808 Mdot
.44692 .58525 Mdot
.23762 .57254 Mdot
.32038 .59935 Mdot
.75693 .66008 Mdot
.50462 .20207 Mdot
.6325 .34795 Mdot
.68216 .74213 Mdot
.35264 .38012 Mdot
.72078 .66706 Mdot
.78304 .58082 Mdot
.62181 .5547 Mdot
.59862 .62792 Mdot
.50019 .32877 Mdot
.38483 .54535 Mdot
.4013 .55262 Mdot
.75484 .31212 Mdot
.68197 .51501 Mdot
.35345 .46815 Mdot
.29629 .27293 Mdot
.30035 .40708 Mdot
.62618 .83142 Mdot
.33652 .69987 Mdot
.36383 .24904 Mdot
.49265 .58936 Mdot
.4839 .71808 Mdot
.74555 .28371 Mdot
.59309 .26382 Mdot
.68808 .55722 Mdot
.41007 .41212 Mdot
.35582 .45353 Mdot
.49451 .59717 Mdot
.29562 .65273 Mdot
.45428 .22392 Mdot
.19236 .42242 Mdot
.78634 .57242 Mdot
.29106 .4279 Mdot
.62774 .5733 Mdot
.49985 .3054 Mdot
.51449 .85645 Mdot
.60447 .62861 Mdot
.87372 .52344 Mdot
.49686 .43631 Mdot
.83446 .50909 Mdot
.32614 .78213 Mdot
.34264 .55152 Mdot
.52586 .53715 Mdot
.52903 .70072 Mdot
.60292 .3893 Mdot
.63508 .3479 Mdot
.32483 .44225 Mdot
.77162 .62848 Mdot
.72421 .51556 Mdot
.78032 .41016 Mdot
.39704 .60716 Mdot
.23405 .37666 Mdot
.18668 .47953 Mdot
.37743 .44677 Mdot
.64257 .55018 Mdot
.65458 .71138 Mdot
.51697 .49788 Mdot
.5952 .49547 Mdot
.76029 .67958 Mdot
.51481 .22356 Mdot
.29868 .43849 Mdot
.82149 .42155 Mdot
.66716 .47419 Mdot
.4208 .85278 Mdot
.46715 .34818 Mdot
.6013 .48732 Mdot
.52497 .49569 Mdot
.22189 .56749 Mdot
.43184 .21674 Mdot
.49786 .81383 Mdot
.74701 .36627 Mdot
.45841 .46213 Mdot
.72204 .41369 Mdot
.54392 .31131 Mdot
.4335 .74416 Mdot
.17192 .5099 Mdot
.68329 .22368 Mdot
.34925 .32554 Mdot
.32569 .56324 Mdot
.3527 .3777 Mdot
.19643 .43311 Mdot
.32198 .46208 Mdot
.6515 .59583 Mdot
.50924 .23568 Mdot
.47721 .80854 Mdot
.46626 .85728 Mdot
.43091 .82746 Mdot
.64271 .46085 Mdot
.53344 .7747 Mdot
.6503 .29023 Mdot
.47093 .3372 Mdot
.47025 .52567 Mdot
.60414 .38168 Mdot
.61481 .43767 Mdot
.33753 .50276 Mdot
.19853 .54745 Mdot
.55136 .46922 Mdot
.56 .82714 Mdot
.41698 .84936 Mdot
.64694 .79985 Mdot
.57731 .74243 Mdot
.3701 .39765 Mdot
.84519 .5881 Mdot
.39919 .21378 Mdot
.47053 .83356 Mdot
.34002 .35468 Mdot
.16252 .41744 Mdot
.82842 .56954 Mdot
.44731 .78709 Mdot
.2469 .4191 Mdot
.21935 .6363 Mdot
.33122 .77971 Mdot
.18348 .38034 Mdot
.64799 .31625 Mdot
.31054 .76575 Mdot
.88368 .48396 Mdot
.35503 .34892 Mdot
.31078 .59546 Mdot
.31985 .30562 Mdot
.63204 .2851 Mdot
.18871 .40883 Mdot
.54589 .44387 Mdot
.5495 .61504 Mdot
.67991 .57897 Mdot
.72831 .38527 Mdot
.47411 .35526 Mdot
.19238 .39585 Mdot
.70846 .45483 Mdot
.67969 .44165 Mdot
.67935 .689 Mdot
.81657 .58533 Mdot
.44569 .21721 Mdot
.60694 .33126 Mdot
.39613 .43638 Mdot
.73978 .51053 Mdot
.67165 .34681 Mdot
.53278 .42246 Mdot
.47871 .55061 Mdot
.59903 .47306 Mdot
.69697 .78669 Mdot
.67146 .62263 Mdot
.61415 .5982 Mdot
.31263 .38678 Mdot
.24397 .58872 Mdot
.65336 .74641 Mdot
.26586 .53953 Mdot
.20427 .37415 Mdot
.54241 .22689 Mdot
.6269 .79564 Mdot
.30542 .57579 Mdot
.69908 .36662 Mdot
.72043 .2825 Mdot
.47226 .61834 Mdot
.45135 .32738 Mdot
.79898 .6429 Mdot
.2624 .55385 Mdot
.36879 .3889 Mdot
.41233 .77536 Mdot
.456 .75311 Mdot
.25233 .55982 Mdot
.30534 .75086 Mdot
.68664 .70343 Mdot
.35754 .27936 Mdot
.71121 .7409 Mdot
.52634 .6226 Mdot
.71357 .38112 Mdot
.37913 .75461 Mdot
.1842 .41428 Mdot
.51043 .49367 Mdot
.52556 .843 Mdot
.47538 .52602 Mdot
.79792 .48724 Mdot
.56956 .41875 Mdot
.47689 .20219 Mdot
.20733 .55322 Mdot
.40321 .78148 Mdot
.24754 .46529 Mdot
.38354 .4135 Mdot
.19385 .50063 Mdot
.57718 .69996 Mdot
.78369 .46536 Mdot
.657 .33774 Mdot
.26305 .38615 Mdot
.65684 .50792 Mdot
.26159 .64424 Mdot
.50396 .44035 Mdot
.80565 .46475 Mdot
.57096 .76326 Mdot
.43785 .34634 Mdot
.37774 .35508 Mdot
.74962 .68901 Mdot
.59932 .74682 Mdot
.18637 .54405 Mdot
.3819 .36279 Mdot
.23974 .63288 Mdot
.36039 .22584 Mdot
.25873 .51546 Mdot
.49424 .38986 Mdot
.65137 .59464 Mdot
.31332 .40491 Mdot
.71652 .7235 Mdot
.36532 .47523 Mdot
.79214 .50801 Mdot
.4198 .5175 Mdot
.64515 .73317 Mdot
.62421 .513 Mdot
.32971 .78312 Mdot
.21927 .63678 Mdot
.74505 .38367 Mdot
.42802 .58972 Mdot
.36945 .57628 Mdot
.30752 .53522 Mdot
.52865 .82781 Mdot
.30379 .48963 Mdot
.55234 .27617 Mdot
.31757 .56605 Mdot
.50387 .26256 Mdot
.2792 .74592 Mdot
.76463 .41376 Mdot
.46656 .52627 Mdot
.5831 .28017 Mdot
.2544 .65108 Mdot
.26922 .62979 Mdot
.6853 .61001 Mdot
.43022 .2074 Mdot
.55376 .59089 Mdot
.55754 .54796 Mdot
.52482 .44873 Mdot
.54981 .20497 Mdot
.69655 .74618 Mdot
.36495 .49698 Mdot
.46879 .51756 Mdot
.76616 .61665 Mdot
.79026 .46617 Mdot
.39897 .14414 Mdot
.74162 .75161 Mdot
.56925 .41982 Mdot
.52765 .5258 Mdot
.77804 .41423 Mdot
.54586 .66271 Mdot
.45949 .23191 Mdot
.74278 .6983 Mdot
.43296 .60366 Mdot
.71688 .64488 Mdot
.30069 .65364 Mdot
.21631 .57504 Mdot
.80519 .51365 Mdot
.46841 .64194 Mdot
.64195 .82813 Mdot
.4181 .80773 Mdot
.20961 .54437 Mdot
.32735 .17259 Mdot
.20044 .52122 Mdot
.41364 .45337 Mdot
.64421 .70697 Mdot
.66639 .79754 Mdot
.51248 .5342 Mdot
.70013 .66454 Mdot
.3839 .35371 Mdot
.74584 .37684 Mdot
.69612 .41233 Mdot
.23499 .49332 Mdot
.20247 .48959 Mdot
.18944 .36567 Mdot
.48556 .71701 Mdot
.77067 .32215 Mdot
.41822 .2322 Mdot
.72143 .74092 Mdot
.32779 .70338 Mdot
.65687 .20447 Mdot
.45477 .85377 Mdot
.73837 .43703 Mdot
.20288 .38992 Mdot
.64776 .68665 Mdot
.78192 .3913 Mdot
.51882 .18884 Mdot
.31127 .71404 Mdot
.52742 .22695 Mdot
.46019 .71537 Mdot
.25479 .49053 Mdot
.726 .41315 Mdot
.49109 .27619 Mdot
.47025 .52888 Mdot
.77724 .67921 Mdot
.22992 .33594 Mdot
.72345 .34222 Mdot
.73529 .63692 Mdot
.7938 .40521 Mdot
.67256 .75313 Mdot
.58341 .77567 Mdot
.54878 .51023 Mdot
.86829 .45563 Mdot
.80363 .65567 Mdot
.27136 .52805 Mdot
.50377 .40519 Mdot
.43452 .8613 Mdot
.58195 .51931 Mdot
.39282 .35901 Mdot
.35572 .78757 Mdot
.68376 .41015 Mdot
.59302 .47061 Mdot
.50171 .4142 Mdot
.63727 .27407 Mdot
.25702 .40549 Mdot
.48885 .28029 Mdot
.78068 .55288 Mdot
.72825 .3419 Mdot
.23165 .33797 Mdot
.82117 .48478 Mdot
.4546 .36879 Mdot
.30185 .42428 Mdot
.67951 .79351 Mdot
.5849 .2684 Mdot
.5958 .30252 Mdot
.33321 .28301 Mdot
.29813 .48269 Mdot
.48203 .67589 Mdot
.6322 .37652 Mdot
.36029 .55761 Mdot
.72345 .38868 Mdot
.73676 .68283 Mdot
.45277 .33541 Mdot
.89649 .44865 Mdot
.32866 .78685 Mdot
.2928 .43997 Mdot
.41399 .34819 Mdot
.6302 .56043 Mdot
.65571 .79197 Mdot
.4719 .70458 Mdot
.78279 .57808 Mdot
.28519 .2749 Mdot
.75799 .36381 Mdot
.556 .33239 Mdot
.32132 .74574 Mdot
.47998 .84954 Mdot
.24779 .30156 Mdot
.50946 .84825 Mdot
.51326 .45979 Mdot
.56006 .45319 Mdot
.6199 .15436 Mdot
.60304 .79878 Mdot
.47058 .41773 Mdot
.25197 .41669 Mdot
.27392 .39405 Mdot
.58448 .41577 Mdot
.31308 .63332 Mdot
.67826 .31932 Mdot
.69337 .42232 Mdot
.57366 .82757 Mdot
.32126 .38558 Mdot
.50407 .54234 Mdot
.4163 .65754 Mdot
.49641 .52557 Mdot
.57574 .31158 Mdot
.40558 .62013 Mdot
.69226 .43257 Mdot
.57433 .5248 Mdot
.38939 .66741 Mdot
.63866 .31138 Mdot
.2811 .67406 Mdot
.64377 .34006 Mdot
.64237 .47073 Mdot
.38169 .37327 Mdot
.37923 .20521 Mdot
.70978 .45373 Mdot
.71465 .46372 Mdot
.3088 .76122 Mdot
.16104 .59109 Mdot
.50058 .56873 Mdot
.4303 .39429 Mdot
.4324 .42002 Mdot
.41825 .21331 Mdot
.34536 .28124 Mdot
.43057 .66903 Mdot
.27386 .6285 Mdot
.53748 .4656 Mdot
.58092 .27609 Mdot
.41805 .65295 Mdot
.72106 .78035 Mdot
.52684 .43708 Mdot
.40553 .25472 Mdot
.51233 .8274 Mdot
.72801 .66201 Mdot
.64479 .41424 Mdot
.60523 .38372 Mdot
.41756 .46762 Mdot
.58296 .52443 Mdot
.52032 .28909 Mdot
.74906 .64721 Mdot
.67038 .77326 Mdot
.65381 .41194 Mdot
.39245 .25437 Mdot
.56145 .38787 Mdot
.75254 .53759 Mdot
.37869 .54057 Mdot
.75815 .32663 Mdot
.70103 .55595 Mdot
.44969 .83972 Mdot
.66414 .463 Mdot
.68692 .40975 Mdot
.30479 .29811 Mdot
.75631 .72375 Mdot
.30662 .54362 Mdot
.3771 .25067 Mdot
.3529 .51308 Mdot
.40157 .74932 Mdot
.72269 .44924 Mdot
.50614 .6146 Mdot
.56686 .46404 Mdot
.27378 .38994 Mdot
.5685 .84285 Mdot
.59117 .26321 Mdot
.42718 .66682 Mdot
.48269 .79499 Mdot
.3609 .2279 Mdot
.51138 .52084 Mdot
.28043 .20712 Mdot
.48394 .69665 Mdot
.6484 .82409 Mdot
.71803 .68858 Mdot
.48069 .46523 Mdot
.2347 .56651 Mdot
.48722 .34377 Mdot
.57586 .66293 Mdot
.66208 .78464 Mdot
.51315 .30019 Mdot
.25116 .5075 Mdot
.54253 .43928 Mdot
.41147 .48391 Mdot
.54975 .28153 Mdot
.51565 .7785 Mdot
.56942 .61129 Mdot
.314 .4868 Mdot
.58233 .78104 Mdot
.58643 .52416 Mdot
.15442 .44877 Mdot
.80668 .63794 Mdot
.57168 .80903 Mdot
.5555 .76835 Mdot
.52953 .15981 Mdot
.40853 .4126 Mdot
.47597 .32948 Mdot
.4527 .5922 Mdot
.64567 .28331 Mdot
.25531 .55566 Mdot
.74072 .67493 Mdot
.23685 .62775 Mdot
.52495 .50175 Mdot
.19681 .28678 Mdot
.72981 .43093 Mdot
.38061 .49151 Mdot
.2386 .53985 Mdot
.54816 .82782 Mdot
.75194 .59892 Mdot
.23262 .68051 Mdot
.33847 .72039 Mdot
.55706 .31168 Mdot
.4952 .19044 Mdot
.8211 .44765 Mdot
.49726 .76252 Mdot
.76235 .30672 Mdot
.5298 .78961 Mdot
.67996 .34595 Mdot
.39534 .77534 Mdot
.29688 .40963 Mdot
.27866 .42451 Mdot
.33576 .69005 Mdot
.29193 .6638 Mdot
.42254 .38097 Mdot
.64958 .7777 Mdot
.67046 .24249 Mdot
.783 .59256 Mdot
.62246 .8073 Mdot
.37111 .61428 Mdot
.3394 .37382 Mdot
.70056 .45481 Mdot
.66764 .51281 Mdot
.5338 .65377 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0S_ooool2o`0000oooooo0_l00008ooooo`;o
0000W_ooool001cooooo00?o0000ooooooooool0S_ooool2o`0000oooooo0_l00008ooooo`;o0000
W_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`28
ooooo`;o00001?ooool2o`000;Wooooo000Looooo`03o`000?oooooooooo07kooooo0_l00008oooo
o`;o00001?ooool2o`0000[ooooo1?l0002[ooooo`007?ooool00ol0003oooooooooo`1nooooo`;o
00000_ooool2o`0000?ooooo0_l00009ooooo`;o00001_ooool6o`0000_ooooo0_l0002Looooo`00
7?ooool00ol0003oooooooooo`22ooooo`;o00000oooool2o`0000Wooooo0_l00002ooooo`;o0000
1_ooool4o`0000Wooooo0_l0002Looooo`007?ooool2o`0008?ooooo0_l00007ooooo`;o00002Ooo
ool2o`0000Sooooo0_l0000Eooooo`;o0000T?ooool001cooooo00?o0000ooooooooool0P_ooool2
o`0000Oooooo0_l0000Oooooo`;o00002Oooool2o`0000gooooo0_l00021ooooo`007?ooool00ol0
003oooooooooo`27ooooo`;o00007oooool2o`0000;ooooo0_l0000Hooooo`;o0000POooool001co
oooo00?o0000ooooooooool0Qoooool2o`0001oooooo0_l0002Oooooo`007?ooool00ol0003ooooo
ooooo`1]ooooo`;o00004oooool3o`0000Oooooo0_l0000Jooooo`;o0000Woooool001cooooo00?o
0000ooooooooool0KOooool2o`0001?ooooo0ol00007ooooo`;o00006_ooool2o`0009oooooo000L
ooooo`03o`000?oooooooooo06_ooooo0_l0000@ooooo`;o0000;_ooool2o`0009[ooooo000Loooo
o`03o`000?oooooooooo06Oooooo0_l00002ooooo`;o00004?ooool2o`0002kooooo0_l00009oooo
o`;o0000Soooool001cooooo00?o0000ooooooooool0Ioooool2o`0004oooooo0_l0002?ooooo`00
7?ooool00ol0003oooooooooo`2?ooooo`;o00002_ooool4o`0002Kooooo0_l00002ooooo`;o0000
O_ooool001cooooo00?o0000ooooooooool0M?ooool2o`0001Wooooo0_l0000:ooooo`Co00009_oo
ool2o`0000;ooooo0ol0001mooooo`007?ooool00ol0003oooooooooo`1booooo`Co00005_ooool2
o`000003ooooool0003o000000[ooooo0_l0000]ooooo`;o00001?ooool2o`0007Oooooo000Loooo
o`03o`000?oooooooooo07;ooooo0_l0000<ooooo`;o00001_ooool6o`000003ooooool0003o0000
00[ooooo1?l00006ooooo`;o0000:Oooool2o`0007Oooooo00001_ooooook^k^oc8b<_l0003o<S8b
onk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`1looooo`;o00000_ooool2
o`0000Kooooo1?l0000Aooooo`;o00001_ooool3o`000003ooooool0003o000009kooooo00001_oo
ooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1_ooool00ol0003oooooooooo`1looooo`;o00002_ooool2o`0000cooooo0_l0000>ooooo`;o0000
00Coooooo`000?l0003o0000WOooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool0
2_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo06Wooooo0_l0000?ooooo`Co0000
2_ooool2o`0000cooooo0_l0000Booooo`;o0000WOooool00003ooooool0003ooooo00;ooooo00?o
0000ooooooooool02oooool00onHV9So8B4Qonk^kP06ooooo`?o0000JOooool2o`0000oooooo0_l0
000Iooooo`Co00001oooool2o`0000[ooooo0_l0002Kooooo`0000?oooooo`000?ooool00_ooool0
0ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0L_ooool2
o`0000?ooooo0ol00004ooooo`;o00005Oooool8o`0000?ooooo0_l0000:ooooo`;o000000?ooooo
o`000?l000000_l0000Oooooo`;o0000MOooool00003ooooool@413ooooo00;ooooo00?o410@oooo
ooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Oooooo0_l0000<oooo
o`;o00002oooool2o`000003ooooool0003o000000?o00001?ooool4o`0000Kooooo0_l00003oooo
o`;o00000oooool2o`0000Gooooo1Ol00005ooooo`;o00001Oooool2o`0000?ooooo1?l0000Ooooo
o`;o0000MOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonH
V9So410@00Kooooo00?o0000ooooooooool0Eoooool2o`0000cooooo0_l0000>ooooo`;o00002Ooo
ool2o`0000Kooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l00008ooooo`;o00001Ooo
ool2o`0000Gooooo0_l00005ooooo`?o0000UOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^
2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0O_ooool2o`0000;o
oooo1?l0000:ooooo`;o00004?ooool4o`0000?ooooo0_l00007ooooo`;o00008_ooool2o`00077o
oooo000Looooo`03o`000?oooooooooo07kooooo0_l00002ooooo`Ko000000?oooooo`000?l00000
0_ooool2o`0000Gooooo0_l0000<ooooo`Co00000oooool4o`0000?ooooo0_l00002ooooo`;o0000
8?ooool2o`00077ooooo000Looooo`03o`000?oooooooooo05kooooo0_l0000=ooooo`;o00004_oo
ool4o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000Gooooo0_l0000Eooooo`;o0000
0oooool2o`0000;ooooo0_l0000Rooooo`;o0000Koooool001cooooo00?o0000ooooooooool0D_oo
ool2o`0000[ooooo0_l0000=ooooo`;o00001oooool2o`0000Wooooo1?l00005ooooo`;o000000Co
ooooo`000?l0003ooooo0_l00006ooooo`;o00002Oooool2o`0000Wooooo0ol00006ooooo`;o0000
7oooool4o`0006gooooo000Looooo`03o`000?oooooooooo05;ooooo0_l00008ooooo`;o00004ooo
ool2o`0000?ooooo0_l00005ooooo`;o00002Oooool4o`0000Cooooo0_l00006ooooo`;o00002Ooo
ool2o`0000?ooooo0_l00002ooooo`go00001?ooool2o`0001_ooooo0_l00008ooooo`;o0000Hooo
ool001cooooo00?o0000ooooooooool0G?ooool2o`0001?ooooo0_l00003ooooo`;o00000oooool4
o`0000Cooooo0_l00003ooooo`;o00007_ooool2o`0000;ooooo0_l00003ooooo`Ko00001_ooool2
o`000003ooooool0003o000002;ooooo0_l0001Sooooo`007?ooool00ol0003oooooooooo`1`oooo
o`?o00002?ooool4o`0000Cooooo0ol0000<ooooo`;o00001_ooool2o`0000Cooooo0_l0000=oooo
o`;o00001_ooool2o`0000Oooooo0ol00026ooooo`007?ooool00ol0003oooooooooo`1Wooooo`;o
00001oooool2o`0000Cooooo0_l00002ooooo`;o00002?ooool2o`0000;ooooo0_l00004ooooo`;o
00000_ooool2o`0000Kooooo0_l00004ooooo`Co00002oooool2o`0000?ooooo1Ol00008ooooo`Co
0000Q?ooool001cooooo00?o0000ooooooooool0B?ooool2o`0000?ooooo0_l0000Eooooo`;o0000
00?oooooo`000?l000002_ooool9o`0000cooooo0_l00004ooooo`;o00004_ooool2o`0000kooooo
1Ol0000<ooooo`?o0000Poooool001cooooo00?o0000ooooooooool0B?ooool2o`0000?ooooo0_l0
000Eooooo`?o00000oooool2o`0000Oooooo2?l0000gooooo`?o00003oooool2o`00013ooooo0_l0
001aooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o000000?oooooo`000?l000000_l0000:
ooooo`;o0000A?ooool2o`0000[ooooo0_l0000<ooooo`Co0000Koooool001cooooo00?o0000oooo
ooooool0J?ooool4o`0000Kooooo0_l00002ooooo`;o000000?oooooo`000?l000001?ooool2o`00
02Oooooo0_l0000Booooo`;o00002_ooool2o`0000kooooo0ol0001^ooooo`007?ooool2o`0006_o
oooo0_l00006ooooo`;o00000oooool4o`0000Cooooo0_l0000Rooooo`;o00000oooool3o`0002go
oooo0ol00008ooooo`;o0000I?ooool001cooooo00?o0000ooooooooool0KOooool2o`0000;ooooo
0_l00004ooooo`;o00000oooool2o`0000;ooooo0_l0000Qooooo`?o00000oooool2o`0000[ooooo
0_l0000:ooooo`;o00002?ooool3o`0000[ooooo0_l00009ooooo`?o0000Hoooool001cooooo00?o
0000ooooooooool0H_ooool2o`0000Wooooo0_l00002ooooo`;o00001oooool4o`0000;ooooo0_l0
000Rooooo`;o00003oooool2o`0000Sooooo1?l00008ooooo`?o00005_ooool4o`0000?ooooo0_l0
001Looooo`007?ooool00ol0003oooooooooo`1Rooooo`;o00001oooool2o`0000gooooo0_l00010
ooooo`;o000000?oooooo`000?l000003Oooool2o`0000oooooo0_l00005ooooo`;o00000oooool2
o`0005cooooo000Looooo`03o`000?oooooooooo067ooooo0_l00003ooooo`;o00000oooool3o`00
02oooooo0_l000000ooooooo0000o`00000Jooooo`?o00003oooool2o`0000oooooo0_l0001Xoooo
o`007?ooool00ol0003oooooooooo`1Qooooo`;o000000?oooooo`000?l000001?l00002ooooo`;o
00001oooool2o`0002Kooooo0_l000000ooooooo0000o`000004ooooo`;o00001?ooool2o`0000_o
oooo0_l000000ooooooo0000o`000002o`0008Wooooo000Looooo`03o`000?oooooooooo06?ooooo
0ol00002ooooo`;o000000?oooooo`000?l000002?ooool2o`0002Kooooo0_l000000ooooooo0000
o`000004ooooo`;o00001?ooool2o`0000_ooooo0ol00002ooooo`;o00002Oooool2o`0000Cooooo
1?l00005ooooo`;o00004Oooool2o`0005cooooo000Looooo`03o`000?oooooooooo05gooooo0_l0
0004ooooo`;o00001?ooool4o`0003Kooooo0_l0000Eooooo`;o00003Oooool2o`0000Cooooo1?l0
0005ooooo`;o00004Oooool2o`0005cooooo000Looooo`03o`000?oooooooooo043ooooo0ol0000F
ooooo`;o00000_ooool2o`0000[ooooo0_l0000aooooo`;o00000_ooool2o`000003ooooool0003o
000000_ooooo0_l00007ooooo`;o00004?ooool2o`0000Cooooo0ol0000<ooooo`?o0000I_ooool0
01cooooo00?o0000ooooooooool0@?ooool3o`0001Kooooo0_l00002ooooo`;o000000?oooooo`00
0?l000000_ooool6o`0000Kooooo0_l0000Zooooo`;o00000_ooool2o`0000kooooo0_l00007oooo
o`;o00004?ooool2o`0000Cooooo1?l0000;ooooo`?o0000I_ooool001cooooo00?o0000oooooooo
ool0E_ooool3o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`Oo000000?oooooo`000?l0
00000_ooool2o`0000Wooooo0_l0000Nooooo`Oo00003Oooool2o`0000Gooooo0_l00002ooooo`;o
00002_ooool2o`0000Cooooo0_l00003ooooo`Co00001?ooool2o`0000_ooooo0_l0001Qooooo`00
7?ooool00ol0003oooooooooo`1Fooooo`Go00002Oooool2o`0000?ooooo0_l000000ooooooo0000
o`00000=ooooo`;o00007_ooool5o`0000oooooo0_l00003ooooo`Co00000_ooool2o`0000[ooooo
0_l00002ooooo`Ko000000?oooooo`000?l000001?l00002ooooo`;o00002oooool2o`0000Kooooo
0_l0001Iooooo`007?ooool00ol0003oooooooooo`0looooo`;o00006oooool2o`00023ooooo0_l0
000Dooooo`?o00001_ooool2o`000003ooooool0003o000000Kooooo0_l00005ooooo`;o00001_oo
ool2o`000004ooooool0003o0000o`0000?ooooo0ol0000:ooooo`;o00000_ooool2o`000003oooo
ool0003o000000Ko00001Oooool2o`0000Kooooo0_l00006ooooo`;o0000FOooool001cooooo00?o
0000ooooooooool0??ooool2o`0003cooooo0ol0000Dooooo`?o00001Oooool3o`0000Wooooo0_l0
0005ooooo`;o00001?ooool2o`0000?ooooo0ol00003ooooo`?o00003oooool4o`000004ooooool0
003o0000ooooo`;o00000_ooool2o`000003ooooool0003o000000gooooo0_l0001Jooooo`007?oo
ool00ol0003oooooooooo`1Gooooo`;o00006Oooool2o`0000Kooooo0_l0000Mooooo`;o00005_oo
ool4o`0001[ooooo0_l00003ooooo`;o00001Oooool2o`000003ooooool0003o000000gooooo0_l0
001Jooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00000_ooool2o`000003ooooool0003o
000000?o00000oooool2o`000003ooooool0003o000000kooooo0_l0000Pooooo`Co00001?ooool2
o`0001?ooooo1_l0000@ooooo`;o00001?ooool2o`0000Oooooo0_l00002ooooo`;o00001?ooool2
o`0000cooooo0_l0001Iooooo`007?ooool2o`0004kooooo0_l000000ooooooo0000o`000002oooo
o`;o000000?oooooo`000?l000000ol00003ooooo`;o000000?oooooo`000?l00000<?ooool4o`00
0004ooooool0003o0000ooooo`;o00001Oooool4o`0000?ooooo0_l00007ooooo`Co00001?ooool3
o`0000Wooooo0_l00004ooooo`;o00001oooool2o`0000;ooooo0_l00003ooooo`?o00000_ooool2
o`0000Sooooo0_l0001Iooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o000000?oooooo`00
0?l000003Oooool2o`0003;ooooo0_l00004ooooo`;o00002?ooool4o`0000?ooooo0_l00009oooo
o`;o00000_ooool7o`0000Wooooo0_l0000?ooooo`;o00000_ooool4o`0000;ooooo0ol0001Roooo
o`007?ooool00ol0003oooooooooo`1@ooooo`;o00003Oooool2o`0000?ooooo0_l000000ooooooo
0000o`00000?ooooo`;o00006?ooool3o`0000[ooooo0ol0000Gooooo`;o00000oooool2o`0000Wo
oooo0_l00003ooooo`;o00001?ooool2o`0000Cooooo0_l00002ooooo`Ko000000?oooooo`000?l0
00003Oooool2o`0005?ooooo000Looooo`03o`000?oooooooooo057ooooo0_l000000ooooooo0000
o`000003ooooo`;o00002Oooool2o`000003ooooool0003o000000oooooo0_l0000Eooooo`;o0000
00?oooooo`000?l000002_ooool4o`0000Wooooo1?l00006ooooo`;o000000Coooooo`000?l0003o
00004oooool2o`0000Cooooo0_l00006ooooo`co00003?ooool2o`0005?ooooo000Looooo`03o`00
0?oooooooooo057ooooo0_l000000ooooooo0000o`000003ooooo`;o00000oooool2o`0002kooooo
0ol0000=ooooo`;o00001oooool2o`0000;ooooo1?l000000ooooooo0000o`000008o`0001;ooooo
0_l0000>ooooo`?o00001Oooool4o`0000Wooooo0_l0001Fooooo`007?ooool00ol0003ooooooooo
o`1@ooooo`;o00003?ooool2o`0000cooooo1?l0000Nooooo`;o00001Oooool2o`00013ooooo0_l0
0004ooooo`So00000_ooool2o`000003ooooool0003o000000_ooooo0_l00003ooooo`;o000000?o
ooooo`000?l000001_ooool3o`0000?ooooo0_l00006ooooo`?o00000oooool2o`000004ooooool0
003o0000ooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0D?ooool2o`0000oooooo0_l0
0005ooooo`;o00000_ooool5o`0000Gooooo0_l0000@ooooo`;o00001?ooool2o`0000Gooooo0_l0
0007ooooo`;o00002?ooool2o`000004ooooool0003o0000ooooo`;o00000_ooool3o`0000;ooooo
0_l000000ooooooo0000o`000004ooooo`;o00001Oooool2o`0000Kooooo0_l00006ooooo`Co0000
0_ooool2o`000003ooooool0003o000000Sooooo1_l0001Iooooo`007?ooool00ol0003ooooooooo
o`1:ooooo`?o00002_ooool2o`0000Cooooo0_l00002ooooo`;o00001Oooool2o`0000Gooooo0_l0
0003ooooo`Co00004?ooool2o`0001Cooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo
1Ol000000ooooooo0000o`000003ooooo`Ko000000?oooooo`000?l000001?ooool2o`0001Kooooo
0ol00003ooooo`Co00002?ooool2o`000003ooooool0003o000000Sooooo0_l0001@ooooo`007?oo
ool00ol0003oooooooooo`1:ooooo`?o00002Oooool3o`0000Cooooo0_l0000<ooooo`;o000000?o
ooooo`000?l000001?ooool2o`0001Sooooo0_l0000?ooooo`;o000000?oooooo`000?l000002ol0
0004ooooo`Go00000_ooool2o`0000?ooooo0_l0000?ooooo`;o00001_ooool2o`0000Cooooo1?l0
0008ooooo`;o00002Oooool4o`00053ooooo000Looooo`03o`000?oooooooooo04_ooooo0_l00003
ooooo`;o00001?ooool5o`0000;ooooo0_l0000<ooooo`;o000000?oooooo`000?l000007_ooool4
o`0000gooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000?ooooo0ol00003
ooooo`?o000000Coooooo`000?l0003ooooo0ol00003ooooo`;o00001_ooool2o`0000Oooooo0_l0
0006ooooo`;o00006?ooool2o`000003ooooool0003o000000;o0000D?ooool001cooooo00?o0000
ooooooooool0D?ooool2o`0000Kooooo0ol00002ooooo`;o0000;oooool4o`0000Gooooo0_l00006
ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo2_l00004ooooo`?o00000_ooool2
o`000003ooooool0003o000000;ooooo1?l00002ooooo`;o00000oooool2o`0000Kooooo0_l00002
ooooo`Co00001_ooool2o`0000?ooooo0_l00005ooooo`;o00000oooool2o`00053ooooo000Loooo
o`03o`000?oooooooooo05Wooooo0_l0000/ooooo`?o00001?ooool3o`0000Kooooo0ol00005oooo
o`;o00001?ooool3o`000003ooooool0003o000000[o00000_ooool2o`000003ooooool0003o0000
00Oo000000Coooooo`000?l0003o00001?ooool2o`0000oooooo1Ol00005ooooo`;o00000oooool4
o`0005[ooooo000Looooo`03o`000?oooooooooo02oooooo0_l0000Cooooo`;o000000Coooooo`00
0?l0003o0000?Oooool3o`0000Gooooo1?l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l0
0002ooooo`?o000000?oooooo`000?l000005_l000000ooooooo0000o`000002ooooo`;o00000_oo
ool3o`000003ooooool0003o000000Sooooo0_l00002ooooo`;o00001_ooool3o`0000Oooooo0_l0
0003ooooo`;o000000?oooooo`000?l00000Eoooool001cooooo00?o0000ooooooooool0;oooool2
o`0001?ooooo0_l000001?oooooo0000o`000?l0000mooooo`;o00002?ooool2o`0000;ooooo0_l0
0004ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`00000?o`000005ooooool0
003o0000o`000?ooool01Ol00006ooooo`Ko00000oooool4o`000003ooooool0003o000000;ooooo
0_l00006ooooo`;o00000oooool2o`0000?ooooo0_l00006ooooo`;o0000Eoooool001cooooo00?o
0000ooooooooool0Coooool4o`00023ooooo0_l00006ooooo`;o00003Oooool2o`0000oooooo1Ol0
0002ooooo`Co000000?oooooo`000?l000005Ol00002ooooo`?o00000oooool4o`0000;ooooo1Ol0
0008ooooo`Co00001_ooool2o`0000;ooooo1?l00005ooooo`Co0000EOooool001cooooo00?o0000
ooooooooool0AOooool2o`0000Sooooo1_l00006ooooo`;o00005_ooool2o`0000Kooooo0_l00000
0ooooooo0000o`00000:ooooo`;o00003oooool5o`0000;ooooo6Ol000000ooooooo0000o`000005
o`0000Gooooo0_l000000ooooooo0000o`000003o`0000Kooooo0_l000000ooooooo0000o`000002
o`0000Kooooo0_l00002ooooo`Co00001?ooool5o`0000_ooooo0_l00018ooooo`007?ooool2o`00
04Kooooo0_l0000:ooooo`Co00001_ooool3o`00017ooooo0ol0000<ooooo`;o00000oooool2o`00
00Cooooo0ol00008ooooo`;o00001_ooool4o`0000;ooooo6ol000000ooooooo0000o`000002o`00
00Cooooo0_l00002ooooo`?o000000?oooooo`000?l000001_ooool2o`000003ooooool0003o0000
00;o00004_ooool4o`0000cooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`13ooooo`;o
00000_ooool2o`0000kooooo0_l00003ooooo`;o00004Oooool3o`0000Oooooo0_l00008ooooo`;o
000000Coooooo`000?l0003ooooo0_l00004ooooo`;o00000oooool2o`0000?ooooo0ol000001?oo
oooo0000o`000?oooolMo`0000;ooooo1?l00003ooooo`;o00000_ooool2o`0000;ooooo1Ol00004
ooooo`Co00000_ooool2o`0000gooooo0_l00002ooooo`;o000000?oooooo`000?l000000oooool2
o`0004oooooo000Looooo`03o`000?oooooooooo04?ooooo0_l00002ooooo`;o00003_ooool2o`00
013ooooo1?l0000:ooooo`Co00002oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`00
0004ooooool0003o0000ooooo`Co000000?oooooo`000?l000001Ol000000ooooooo0000o`00000K
o`0000;ooooo0_l00008ooooo`Co00001?ooool5o`000003ooooool0003o000000gooooo0_l00002
ooooo`Go00000oooool2o`000003ooooool0003o000004cooooo000Looooo`03o`000?oooooooooo
05kooooo0_l00009ooooo`Co00002_ooool3o`0000;ooooo0_l00006ooooo`;o00001?ooool2o`00
00?ooooo0_l00002ooooo`Ko00000_ooool2o`000003ooooool0003o000000;ooooo8?l00003oooo
o`;o000000?oooooo`000?l000001Oooool2o`0000Wooooo0_l0000Booooo`;o00000_ooool3o`00
00Kooooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`17ooooo`;o00005Oooool4o`000003
ooooool0003o000000Wooooo0_l00007ooooo`[o00000oooool2o`0000;ooooo0_l00002ooooo`Co
00001Oooool5o`0000Gooooo8?l000001?oooooo0000o`000?ooool4o`000003ooooool0003o0000
013ooooo0_l0000Booooo`;o00000oooool2o`0005Cooooo000Looooo`03o`000?oooooooooo03[o
oooo0_l0000;ooooo`;o00004oooool2o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`Co
000000?oooooo`000?l000001oooool5o`0000;ooooo0ol00007ooooo`;o00000_ooool5o`0000Oo
oooo0ol000000ooooooo0000o`00000To`000003ooooool0003o000000;o00000oooool2o`0000Co
oooo0_l00007ooooo`;o00002_ooool2o`0000Sooooo0_l000000ooooooo0000o`000007ooooo`;o
0000C?ooool001cooooo00?o0000ooooooooool0>_ooool2o`0000;ooooo0_l00006ooooo`;o0000
1_ooool2o`0000Sooooo0_l00002ooooo`;o00002oooool4o`0001Gooooo0_l0000;ooooo`?o0000
1_ooool3o`000003ooooool0003o000000?o000000?oooooo`000?l000001Ol000000ooooooo0000
o`00000Eo`0000?ooooo1?l00002ooooo`;o00000oooool3o`0000Oooooo0_l000001?oooooo0000
o`000?ooool2o`0000Cooooo0_l00007ooooo`?o000000?oooooo`000?l000000_l00005ooooo`;o
0000C?ooool001cooooo00?o0000ooooooooool0?_ooool2o`0000Kooooo0ol00005ooooo`;o0000
2?ooool3o`0000cooooo1?l000000ooooooo0000o`00000>ooooo`;o00001?ooool2o`0000cooooo
0_l00004ooooo`;o00001?ooool/o`0000;ooooo0_l00003ooooo`;o00002oooool2o`000003oooo
ool0003o000000gooooo0_l00002ooooo`Go0000D_ooool001cooooo00?o0000ooooooooool0?ooo
ool2o`0000Kooooo0_l0000@ooooo`;o00003?ooool7o`0000[ooooo0_l00002ooooo`;o00000_oo
ool2o`0000Kooooo0_l0000<ooooo`Co00000_oooolTo`000003ooooool0003o000000Co00009_oo
ool2o`0000Gooooo1Ol0001@ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00001Oooool2
o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000003oooool2o`0000Gooooo0_l0
00000ooooooo0000o`000004ooooo`Co00000_ooool2o`0000Oooooo0_l00006ooooo`;o00001_oo
ool2o`0000_ooooo0_l000000ooooooo0000o`000004ooooobSo00001?ooool2o`0000Kooooo0ol0
000>ooooo`;o00000oooool2o`000003ooooool0003o000000?o00001?ooool2o`000003ooooool0
003o0000053ooooo000Looooo`03o`000?oooooooooo03Sooooo0_l00006ooooo`Co000000Cooooo
o`000?l0003ooooo0_l0000@ooooo`;o00001?ooool2o`000003ooooool0003o000000?ooooo0_l0
0003ooooo`Go00003_ooool2o`0000Cooooo0_l0000<ooooo`?o00001?ooool2o`000005ooooool0
003o0000o`000?ooool08?l00002ooooo`Co00000_ooool4o`0000Cooooo0ol00005ooooo`;o0000
1oooool3o`0000;ooooo0_l000000ooooooo0000o`000004o`0000Sooooo0_l0000Eooooo`;o0000
=oooool001cooooo00?o0000ooooooooool0>?ooool2o`0000?ooooo0_l000000ooooooo0000o`00
0008ooooo`;o00003_ooool4o`0000Sooooo1_l000000ooooooo0000o`000004o`0000Gooooo1?l0
00001?oooooo0000o`000?l00006ooooo`;o00003?ooool2o`0000Gooooo0ol000000ooooooo0000
o`00000<o`000003ooooool0003o000000oo000000Coooooo`000?l0003o00000_ooool4o`0000?o
oooo0_l0000<ooooo`;o00002?ooool2o`0000Kooooo1Ol00008ooooo`;o00005Oooool2o`0003Oo
oooo000Looooo`03o`000?oooooooooo03gooooo0_l0000;ooooo`;o00001_ooool2o`0000Cooooo
0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00000>o`0000?o
oooo1?l000001Ooooooo0000o`000?l0003ooooo00;o00004oooool2o`0000Cooooo0ol000000ooo
oooo0000o`00000No`000005ooooool0003o0000o`000?ooool01?l000000ooooooo0000o`000005
ooooo`Co00005?ooool2o`000003ooooool0003o000000;o0000FOooool001cooooo00?o0000oooo
ooooool0?_ooool2o`0001;ooooo0_l000001?oooooo0000o`000?ooool2o`000005ooooool0003o
0000o`000?ooool00_l000001?oooooo0000o`000?oooolAo`0000_ooooo0_l0000Cooooo`;o0000
1?oooolXo`000003ooooool0003o000000;o000000?oooooo`000?l000001Oooool4o`0000?ooooo
0_l0000=ooooo`Ko00003Oooool2o`0000Oooooo0_l00014ooooo`0000Koooooonk^k_lb<S;o0000
oc8b<_o^k^h5ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000oooooooo
ool0?_ooool2o`0001Gooooo0_l00004ooooo`;o00001?oooolEo`0000Cooooo0_l0000Fooooo`;o
00001ooooolTo`000003ooooool0003o000000;ooooo1?l0000?ooooo`?o00003Oooool6o`0000go
oooo0_l00007ooooo`;o0000A?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q
8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Uooooo`;o00003Oooool2o`00
00Gooooo0_l0000Booooo`;o00001?ooool2o`0000Oooooo6?l00004ooooo`;o00001_ooool2o`00
00Cooooo0_l00008ooooo`;o000000Coooooo`000?l0003o00000ooooolTo`000003ooooool0003o
000000;ooooo1?l0000?ooooo`Co00000_ooool2o`0000Sooooo1Ol00002ooooo`?o000000?ooooo
o`000?l000001_ooool2o`0004gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo
00Wooooo1Ol00006ooooo`03o`000?oooooooooo02Gooooo0_l0000=ooooo`;o00001Oooool2o`00
01;ooooo0_l00006ooooo`;o00001?oooolKo`0000[ooooo0_l00004ooooo`;o00000_ooool2o`00
00Oooooo1?l00002oooooaco000000?oooooo`000?l000001?l00002ooooo`Ko00000_ooool2o`00
00oooooo0_l00002ooooo`;o00001oooool2o`0000;ooooo0_l00002ooooo`?o000000?oooooo`00
0?l00000EOooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?m4A4Co
gMgMooooool00007ooooo`?o0000A_ooool2o`0000Kooooo0_l00007ooooo`;o00000_ooool4o`00
0003ooooool0003o000001Ko00000oooool4o`0000gooooo0_l00005ooooo`;o000000?oooooo`00
0?l000000_l000000ooooooo0000o`00000Yo`0000;ooooo0_l00004ooooo`Co00003Oooool2o`00
00Gooooo0_l00002ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`;o0000D_ooool0
0003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo04Kooooo0_l00006ooooo`Co00002Oooool2o`0000?ooooo6?l00002
ooooo`Go000000?oooooo`000?l000004Oooool4o`000003ooooool0003o000000?o000000?ooooo
o`000?l000007?l000000ooooooo0000o`000007o`0000Sooooo1?l0000;ooooo`Co00002Oooool2
o`0000Kooooo0_l000000ooooooo0000o`000007ooooo`;o0000BOooool00003ooooool@413ooooo
00;ooooo00?o410@ooooooooool02_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo
03[ooooo0_l0000@ooooo`;o000000Coooooo`000?l0003o00002Oooool5o`000003ooooool0003o
000001Ko000000?oooooo`000?l000001?ooool2o`0001?ooooo0_l000001Ooooooo0000o`000?l0
003ooooo00?o000000?oooooo`000?l000002Ol000000ooooooo0000o`00000Fo`0001Wooooo0_l0
0009ooooo`;o00005?ooool4o`0004Oooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo
00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0jooooo`;o00003oooool3o`000004oooo
ool0003o0000ooooo`Co00000oooool7o`000003ooooool0003o000001Ko00002?ooool2o`0001Wo
oooo8Ol000000ooooooo0000o`000002o`0000oooooo0_l00007ooooo`?o000000?oooooo`000?l0
00001_ooool4o`0000Oooooo1ol00002ooooo`;o00001?ooool2o`0004Oooooo00001_ooooook^k^
oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`0goooo
o`?o00004Oooool2o`0000Gooooo3_l000000ooooooo0000o`00000Ko`0000?ooooo0_l0000Goooo
o`;o000000?oooooo`000?l000003ol00002ooooo`Go000000?oooooo`000?l000001Ol000000ooo
oooo0000o`00000;ooooo`;o000000Coooooo`000?l0003ooooo1?l00005ooooo`?o000000?ooooo
o`000?l000000_l00004ooooo`Go00001_ooool7o`000004ooooool0003o0000o`0000Wooooo0_l0
0012ooooo`007?ooool00ol0003oooooooooo`0Qooooo`;o00003_ooool2o`0000Cooooo0ol0000D
ooooo`;o00001_ooool4o`000003ooooool0003o0000027o00000oooool2o`0000Kooooo0_l0000:
ooooo`;o00000oooool2o`0000;ooooo1?l000001Ooooooo0000o`000?l0003ooooo01Wo00002ooo
ool2o`000003ooooool0003o000000?ooooo0_l0000:ooooo`?o00001Oooool4o`0000?ooooo0_l0
0005ooooo`?o000000?oooooo`000?l000001Oooool2o`0000?ooooo1?l00010ooooo`007?ooool0
0ol0003oooooooooo`0Qooooo`;o00003_ooool2o`0001?ooooo0_l00004ooooo`Co00000oooool2
o`000004ooooool0003o0000ooooo`Co000000?oooooo`000?l000001Ol000000ooooooo0000o`00
000Do`0000Cooooo0_l00007ooooo`;o00001oooool5o`000003ooooool0003o000000;o00000ooo
ool6o`0000;ooooo2Ol000000ooooooo0000o`00000>o`000004ooooool0003o0000o`0000;ooooo
0_l0000Looooo`;o00001oooool2o`0000gooooo1Ol00004ooooo`?o0000@?ooool001cooooo00?o
0000ooooooooool0=_ooool2o`0000;ooooo1?l00008ooooo`;o00001?ooool2o`0000?ooooo1?l0
00000ooooooo0000o`000004o`0000;ooooo8?l00002ooooo`?o00001Oooool3o`0000Oooooo1Ol0
00000ooooooo0000o`000002o`0000Kooooo0ol00002oooooako00000_ooool3o`0001?ooooo0_l0
0006ooooo`Co00001?ooool2o`0000Cooooo0_l00008ooooo`?o00001_ooool3o`00043ooooo000L
ooooo`03o`000?oooooooooo03Kooooo0_l00002ooooo`Co00003oooool2o`0000;ooooo0_l00003
ooooobGo000000Coooooo`000?l0003o00000_ooool3o`0000Cooooo0_l0000:ooooo`Go00001Ooo
ool4o`000003ooooool0003o000001ko00000_ooool2o`000003ooooool0003o000001?ooooo0_l0
0008ooooo`;o00001?ooool2o`0000?ooooo0ol00009ooooo`;o0000BOooool001cooooo00?o0000
ooooooooool0??ooool2o`0000oooooo0ol00008ooooo`;o000000?oooooo`000?l000007_l00002
ooooo`;o00000_ooool3o`0001?ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l00000
0ooooooo0000o`00000:o`000003ooooool0003o000000Wo00002_ooool4o`0000_ooooo0_l0000C
ooooo`;o00000oooool2o`0000;ooooo0_l0000=ooooo`;o0000A_ooool001cooooo00?o0000oooo
ooooool0??ooool2o`0000oooooo0ol00008ooooo`;o00000ooooolRo`0000;ooooo0_l00002oooo
o`;o00005?ooool5o`0000?ooooo0_l000000ooooooo0000o`00000Co`0000;ooooo0ol00006oooo
o`?o00002oooool2o`0000Oooooo0_l00008ooooo`Co00000oooool2o`0000Kooooo0_l00009oooo
o`;o0000A_ooool001cooooo00?o0000ooooooooool07oooool2o`0001_ooooo0_l0000?ooooo`;o
00001Oooool2o`0000?ooooo0ol000000ooooooo0000o`00000Io`000003ooooool0003o000000Co
00001_ooool2o`0000;ooooo0_l0000>ooooo`;o00000_ooool3o`0000Kooooo3ol000000ooooooo
0000o`000008o`000003ooooool0003o000000_ooooo0_l0000=ooooo`;o00002?ooool2o`0000?o
oooo0_l000000ooooooo0000o`000005ooooo`;o00000_ooool2o`0000;ooooo0_l00019ooooo`00
7?ooool00ol0003oooooooooo`0Oooooo`;o0000<oooool2o`0000?ooooo9_l00005ooooo`Co0000
00?oooooo`000?l000003?ooool4o`000003ooooool0003o000000;o00001?ooool2o`000003oooo
ool0003o000000;o000000?oooooo`000?l000004?l00003ooooo`;o000000?oooooo`000?l00000
1?ooool2o`0000;ooooo0_l0000:ooooo`;o00004?ooool2o`000003ooooool0003o000000Cooooo
0_l00002ooooo`?o00000_ooool2o`0004Wooooo000Looooo`03o`000?oooooooooo04oooooo0_l0
0003ooooo`;o00001OoooolTo`0000Gooooo1?l0000?ooooo`;o00000oooool6o`0000;ooooo0_l0
00000ooooooo0000o`000002o`000003ooooool0003o0000017o00001Oooool2o`0000Cooooo0_l0
0006ooooo`;o00001Oooool3o`0001Wooooo0_l00002ooooo`;o000000?oooooo`000?l00000Booo
ool001cooooo00?o0000ooooooooool0B?ooool2o`0000Gooooo0_l00003ooooo`;o00001_ooool2
o`000004ooooool0003o0000oooooaco00001_ooool3o`0000Oooooo0_l00008ooooo`;o00001_oo
ool2o`0000Gooooo1Ol000000ooooooo0000o`000005o`000003ooooool0003o000000?o000000?o
ooooo`000?l000000_l0000Cooooo`;o00001Oooool2o`0001_ooooo0_l00003ooooo`Co0000B_oo
ool001cooooo00?o0000ooooooooool0;_ooool2o`0001Sooooo0_l000000ooooooo0000o`00000=
ooooo`Co000000Coooooo`000?l0003ooooo6_l00008ooooo`;o00002?ooool3o`0000Gooooo1?l0
0005ooooo`;o00001Oooool?o`0000?ooooo1ol00007ooooo`;o00007oooool2o`0000gooooo0_l0
0003ooooo`Co00000oooool2o`0000?ooooo0_l0000Fooooo`;o0000:?ooool001cooooo0_l0000M
ooooo`;o00004?ooool2o`0001;ooooo0_l00007ooooo`Co00002oooool2o`000003ooooool0003o
000000?ooooo5?l000001?oooooo0000o`000?ooool2o`0000Kooooo1_l00007ooooo`?o00001?oo
ool3o`0000Kooooo0_l00005ooooo`oo00000oooool3o`0000_ooooo0_l00002ooooo`;o00001_oo
ool2o`0000Gooooo0_l0000:ooooo`Co00003_ooool2o`0000Oooooo1?l00003ooooo`;o00005_oo
ool2o`0002Sooooo000Looooo`03o`000?oooooooooo01cooooo0_l0000Tooooo`;o00001oooool4
o`0000Cooooo0_l00006ooooo`Co00000_oooolEo`000003ooooool0003o000000Wooooo1ol00007
ooooo`;o00000_ooool2o`000003ooooool0003o000000Kooooo0_l000000ooooooo0000o`000002
o`0000;ooooo0ol00003ooooo`;o00000_ooool2o`0000Oooooo0_l0000=ooooo`;o00001_ooool2
o`0000Gooooo0_l00005ooooo`Wo00003_ooool2o`0000;ooooo0_l00003ooooo`;o00005?ooool2
o`0000Oooooo0_l0000Xooooo`007?ooool00ol0003oooooooooo`0jooooo`?o00003_ooool2o`00
00Kooooo0_l00006ooooo`;o00001?ooool2o`000005ooooool0003o0000o`000?ooool01ol00000
0ooooooo0000o`000008o`0000Wooooo0_l00002ooooo`;o00001Oooool2o`0000Cooooo0_l00002
ooooo`;o00001Oooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000002Oooool2
o`0000Oooooo0_l00004ooooo`;o00003oooool2o`0000cooooo1_l0000?ooooo`;o00001?ooool2
o`000003ooooool0003o000000;ooooo0_l0000Booooo`;o0000<Oooool001cooooo00?o0000oooo
ooooool0>Oooool4o`0000?ooooo0_l00002ooooo`?o00001?ooool2o`0000Sooooo0_l0000=oooo
o`oo000000?oooooo`000?l000001?l00005ooooo`;o00000_ooool2o`0000Oooooo1?l00008oooo
o`;o00000_ooool2o`000004ooooool0003o0000ooooo`?o00000_ooool2o`0000Gooooo0_l00000
1?oooooo0000o`000?l00003ooooo`?o00001oooool2o`0000[ooooo0_l00003ooooo`;o00008Ooo
ool2o`0000Oooooo0_l00002ooooo`;o00001Oooool2o`0000?ooooo0_l0000iooooo`007?ooool0
0ol0003oooooooooo`0iooooo`;o00000oooool4o`0000;ooooo0ol00004ooooo`;o00001Oooool2
o`000003ooooool0003o000000;o00002oooool7o`0000;ooooo1ol000000ooooooo0000o`000004
o`0000;ooooo1?l00009ooooo`Ko000000?oooooo`000?l000002?ooool3o`000004ooooool0003o
0000ooooo`?o00000oooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`000004oooo
ool0003o0000o`0000gooooo0_l00004ooooo`;o00001Oooool2o`0000kooooo0_l00008ooooo`;o
00003Oooool2o`0000?ooooo0_l00005ooooo`;o00000oooool4o`0003Oooooo000Looooo`03o`00
0?oooooooooo01_ooooo0_l0000Nooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo
0_l000000ooooooo0000o`000002o`0000?ooooo0_l00003ooooo`;o00002oooool7o`0000;ooooo
0_l000000ooooooo0000o`000003o`0000?ooooo0ol00002ooooo`;o00001Oooool2o`000004oooo
ool0003o0000ooooo`;o00001Oooool3o`0000Cooooo0_l000000ooooooo0000o`000005ooooo`Co
00000_ooool2o`000004ooooool0003o0000ooooo`Co00000_ooool2o`00017ooooo0_l0000;oooo
o`;o00002Oooool2o`0000?ooooo0ol00006ooooo`?o000000?oooooo`000?l000002?ooool6o`00
0003ooooool0003o000000cooooo0_l0000;ooooo`;o0000:_ooool001cooooo00?o0000oooooooo
ool06oooool2o`0001kooooo0_l00007ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o
00005Oooool3o`0000;ooooo1Ol000000ooooooo0000o`00000?ooooo`;o000000?oooooo`000?l0
00000_l00006ooooo`?o00001?ooool2o`000003ooooool0003o000000Oooooo0_l00005ooooo`;o
000000?oooooo`000?l000000_l0000;ooooo`;o00001oooool2o`0000Gooooo0_l0000;ooooo`;o
00000oooool2o`0000Cooooo0_l00006ooooo`;o000000Coooooo`000?l0003o00002?ooool7o`00
01_ooooo0_l0000Zooooo`007?ooool00ol0003oooooooooo`15ooooo`;o000000?oooooo`000?l0
00001oooool2o`0000Oooooo0_l0000Aooooo`Co00000_ooool2o`000003ooooool0003o000000;o
00003Oooool4o`0000oooooo0ol00005ooooo`;o00002oooool2o`0000cooooo1?l000001Ooooooo
0000o`000?l0003ooooo00Co00000oooool2o`0000Kooooo1?l000000ooooooo0000o`00000Doooo
o`;o00003_ooool2o`0000?ooooo0_l0000@ooooo`;o0000<?ooool001cooooo00?o0000oooooooo
ool0>?ooool2o`0000_ooooo0_l0000:ooooo`;o00001oooool2o`0000cooooo0_l00003ooooo`;o
00000_ooool4o`000003ooooool0003o000000;o00002Oooool2o`0000?ooooo0_l00008ooooo`;o
00001_ooool2o`000003ooooool0003o000000?ooooo0ol0000>ooooo`Co00002?ooool2o`000004
ooooool0003o0000o`0000?ooooo0_l0000;ooooo`Co00008oooool2o`0000?ooooo0_l00002oooo
o`;o00004?ooool2o`00033ooooo000Looooo`03o`000?oooooooooo03Sooooo0ol0000<ooooo`;o
00005?ooool2o`0000Wooooo0_l00002ooooo`;o00000oooool4o`0000kooooo0_l0000=ooooo`;o
00002Oooool2o`0000Cooooo0_l0000:ooooo`;o00000_ooool4o`0000;ooooo0_l00004ooooo`;o
00000_ooool2o`0003Oooooo0_l00003ooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0
>Oooool2o`0000cooooo1?l000000ooooooo0000o`00000?ooooo`;o00001_ooool2o`0000;ooooo
0_l000000ooooooo0000o`00000Tooooo`;o000000?oooooo`000?l000002?ooool2o`0000kooooo
0_l00002ooooo`?o00000oooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000So
oooo1?l0000<ooooo`Co00000_ooool2o`000003ooooool0003o000001Cooooo0_l0001;ooooo`00
7?ooool00ol0003oooooooooo`0nooooo`;o00002?ooool3o`000003ooooool0003o000000Sooooo
0_l00005ooooo`;o00001_ooool2o`0000;ooooo0_l00006ooooo`;o00003?ooool5o`00017ooooo
0_l00004ooooo`;o00000_ooool2o`0000oooooo0_l000000ooooooo0000o`000002o`0000Gooooo
0ol0000>ooooo`Co00003?ooool4o`0000;ooooo0_l000000ooooooo0000o`00000Dooooo`;o0000
2Oooool2o`0001;ooooo0ol0000[ooooo`007?ooool00ol0003oooooooooo`0eooooo`;o00001ooo
ool2o`0000Sooooo0_l0000<ooooo`Co00002?ooool2o`000003ooooool0003o000000[ooooo0_l0
000;ooooo`Ko00005oooool2o`0000Kooooo0_l0000;ooooo`Oo00000_ooool2o`000005ooooool0
003o0000o`000?ooool00ol0000Looooo`Ko00001Oooool2o`0001?ooooo0_l00006ooooo`;o0000
4_ooool3o`0002_ooooo000Looooo`03o`000?oooooooooo03Cooooo0ol00007ooooo`;o00002Ooo
ool2o`0000Cooooo0_l00007ooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`;o0000
4Oooool2o`0000;ooooo1?l000000ooooooo0000o`00000Pooooo`;o00003Oooool4o`0000?ooooo
0_l00005ooooo`?o00001Oooool2o`0000Wooooo0_l00004ooooo`;o00000oooool7o`0000Gooooo
0_l00002ooooo`;o00003oooool2o`00017ooooo0_l0000eooooo`007?ooool00ol0003ooooooooo
o`0dooooo`;o00002_ooool2o`0000Oooooo0_l00004ooooo`;o00003_ooool2o`0000;ooooo0ol0
000Booooo`;o000000Coooooo`000?l0003o00002Oooool2o`0001Sooooo0ol00002ooooo`?o0000
2_ooool3o`0000Sooooo1?l00006ooooo`;o00002Oooool2o`0000Cooooo0_l00003ooooo`co0000
1?ooool2o`0000gooooo0_l0000Cooooo`;o00001oooool2o`0002cooooo000Looooo`03o`000?oo
oooooooo043ooooo0_l00007ooooo`;o00006?ooool3o`0000gooooo1Ol00003ooooo`?o00000_oo
ool2o`0000Gooooo0_l0000Hooooo`So00002_ooool3o`0000Cooooo0_l00002ooooo`Co00001?oo
ool2o`0001Gooooo3ol0000Aooooo`;o00003?ooool2o`0000kooooo0_l0000/ooooo`007?ooool2
o`0001Wooooo0_l0000Qooooo`;o00000oooool2o`0000kooooo0_l0000?ooooo`;o00004?ooool5
o`0000Cooooo0_l000000ooooooo0000o`000003o`0001cooooo0_l00002ooooo`;o000000?ooooo
o`000?l000001_ooool2o`0000Wooooo0_l00005ooooo`;o00000oooool2o`0000Kooooo0_l00006
ooooo`;o00001?oooolAo`0000gooooo0_l0000?ooooo`;o00001_ooool2o`0003Cooooo000Loooo
o`03o`000?oooooooooo01Sooooo0_l0000Qooooo`;o00000oooool3o`0000gooooo0_l0000?oooo
o`?o00001_ooool2o`0000Sooooo0ol000000ooooooo0000o`000005ooooo`;o000000?oooooo`00
0?l000002Oooool2o`0000Cooooo0_l0000:ooooo`?o00001Oooool2o`0000Kooooo0_l0000@oooo
o`?o00002_ooool4o`0000Cooooo0_l00003ooooo`?o000000?oooooo`000?l000003_l0000;oooo
o`;o00001_ooool2o`0000oooooo1?l0000booooo`007?ooool00ol0003oooooooooo`10ooooo`?o
00002_ooool5o`00013ooooo0_l00006ooooo`;o00003?ooool2o`0000;ooooo0_l0000?ooooo`;o
00001?ooool2o`0000[ooooo0_l0000Qooooo`;o00003?ooool4o`0000Gooooo6?l0000<ooooo`?o
00000_ooool2o`0000Wooooo0_l00006ooooo`;o0000<_ooool001cooooo00?o0000ooooooooool0
=?ooool2o`0000[ooooo0_l0000;ooooo`Ko00001?ooool2o`0002?ooooo0_l0000^ooooo`Co0000
00?oooooo`000?l000002oooool2o`0000_ooooo0_l00005ooooo`;o00000_ooool2o`000003oooo
ool0003o000001Ko000000?oooooo`000?l000002Oooool3o`0000;ooooo0_l00007ooooo`Ko0000
>?ooool001cooooo00?o0000ooooooooool0=?ooool2o`0000[ooooo0_l0000<ooooo`Oo00000_oo
ool4o`0001Cooooo0_l0000Pooooo`;o00002?ooool2o`0000oooooo1?l000000ooooooo0000o`00
000;ooooo`;o00001oooool2o`0000;ooooo1Ol00005ooooob3o00003Oooool2o`0000Oooooo1_l0
0008ooooo`;o0000;_ooool001cooooo00?o0000ooooooooool05oooool2o`0002Sooooo0_l00007
ooooo`;o00001?ooool2o`000004ooooool0003o0000o`0000?ooooo0_l0000=ooooo`Go00000_oo
ool2o`0001cooooo0_l00002ooooo`;o00002?ooool5o`0000Kooooo0ol0000Hooooo`;o00001?oo
ool2o`0000Cooooo0ol00005ooooob3o00003Oooool2o`0001Gooooo0_l0000^ooooo`007?ooool0
0ol0003oooooooooo`0Gooooo`;o00008Oooool3o`0000Cooooo0_l00007ooooo`;o00001?ooool3
o`000003ooooool0003o000001;ooooo1Ol00008ooooo`Co00003?ooool2o`0000Kooooo0_l00006
ooooo`;o00001_ooool4o`0000?ooooo1Ol0000?ooooo`?o00001_ooool2o`0000_ooooo0_l00005
oooooako0000E_ooool001cooooo00?o0000ooooooooool0>_ooool5o`0000;ooooo0_l00008oooo
o`;o00000_ooool4o`0000;ooooo0_l0000=ooooo`;o00002_ooool2o`0000?ooooo1?l000000ooo
oooo0000o`000004o`0000?ooooo1?l0000>ooooo`;o00002?ooool2o`000003ooooool0003o0000
00;o00001_ooool2o`0000[ooooo0ol0000@ooooo`?o00001ooooolMo`0002Kooooo0_l0000_oooo
o`007?ooool00ol0003oooooooooo`0looooo`Co00002oooool2o`0000;ooooo0_l00004ooooo`;o
00002oooool4o`0000[ooooo0_l00008ooooo`Ko00000oooool2o`0000cooooo2?l00004ooooo`So
00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000006ooooo`;o000000Coooooo`000?l0
003o00000_ooool2o`0000Sooooo1_l00006ooooo`;o00001?ooool>o`000003ooooool0003o0000
00Oo00009Oooool2o`0002oooooo000Looooo`03o`000?oooooooooo03Gooooo0_l00005ooooo`Co
00001?ooool2o`0000kooooo0_l0000<ooooo`?o000000Coooooo`000?l0003ooooo0_l00007oooo
o`;o00001oooool4o`0000_ooooo0_l00005ooooo`So00001?ooool8o`0000?ooooo0_l00005oooo
o`;o00001_ooool2o`000004ooooool0003o0000o`0000;ooooo0_l00008ooooo`;o00000_ooool2
o`0000?ooooo0_l00007oooooaSo00002oooool3o`0004Sooooo000Looooo`03o`000?oooooooooo
03Gooooo0_l0000=ooooo`;o00000oooool2o`0000Wooooo0_l00005ooooo`;o00001_ooool2o`00
0003ooooool0003o000000?o00001_ooool3o`0000?ooooo0_l00002ooooo`Ko00000oooool2o`00
00Cooooo0_l00002ooooo`;o00001Oooool3o`0000;ooooo0_l00003ooooo`;o000000Coooooo`00
0?l0003o00005Oooool2o`0000cooooo0_l00004ooooo`;o00000_ooool3o`0000;ooooo0_l00002
oooooaKo00001oooool2o`0000Cooooo0ol00009ooooo`;o00000oooool2o`0003Sooooo000Loooo
o`03o`000?oooooooooo03[ooooo0_l0000=ooooo`;o00004?ooool2o`0000?ooooo0_l00006oooo
o`;o00000_ooool4o`000004ooooool0003o0000o`0000;ooooo1Ol000000ooooooo0000o`000003
o`000003ooooool0003o000000Go00001Oooool2o`0000Cooooo1?l00002ooooo`;o00000oooool2
o`000003ooooool0003o000000Go00000_ooool2o`0000gooooo0_l00009ooooo`;o000000?ooooo
o`000?l000001?ooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool<o`000003ooooool0003o
000000Oo00001oooool2o`0000Cooooo0_l00007ooooo`;o000000?oooooo`000?l000000oooool2
o`0003Sooooo000Looooo`03o`000?oooooooooo03[ooooo0_l0000Eooooo`;o00001Oooool2o`00
00?ooooo0_l000000ooooooo0000o`000003ooooo`;o00000_ooool2o`000003ooooool0003o0000
00Oo000000Coooooo`000?l0003ooooo1_l000000ooooooo0000o`000009o`0000Oooooo1ol00006
ooooo`;o00000_ooool6o`0000;ooooo0ol0000Gooooo`;o00003?ooool2o`0000Kooooo6Ol0000:
ooooo`;o00001oooool2o`00043ooooo000Looooo`03o`000?oooooooooo03[ooooo0_l0000>oooo
o`Ko000000?oooooo`000?l000000ol00002ooooo`;o00000oooool2o`0000Kooooo0_l00002oooo
o`;o000000?oooooo`000?l000001?l000000ooooooo0000o`000004o`000004ooooool0003o0000
ooooo`;o000000Coooooo`000?l0003ooooo1Ol000000ooooooo0000o`000006o`000004ooooool0
003o0000ooooo`Oo00000oooool2o`0000;ooooo0_l00002ooooo`?o00000_ooool6o`0000Gooooo
0_l00005ooooo`Co00002?ooool2o`0000Oooooo0_l00009oooooa3o000000?oooooo`000?l00000
0ol0000Iooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0>Oooool4o`0000?ooooo0_l0
0008ooooo`Ko000000?oooooo`000?l000000ol00007ooooo`;o000000?oooooo`000?l000000_l0
00000ooooooo0000o`000007ooooo`;o000000Coooooo`000?l0003ooooo1Ol0000Booooo`Oo0000
00?oooooo`000?l000001ol00004ooooo`;o000000?oooooo`000?l000000oooool2o`0000;ooooo
1_l00005ooooo`;o00000_ooool2o`000003ooooool0003o000000;o00002?ooool2o`0000Wooooo
0_l00003ooooo`;o00000ooooolBo`000003ooooool0003o000000Oooooo0_l00004ooooo`;o0000
1Oooool2o`0000?ooooo1?l0000hooooo`007?ooool00ol0003oooooooooo`0Iooooo`;o00006_oo
ool2o`0000;ooooo1_l000000ooooooo0000o`00000?ooooo`;o00001oooool2o`000004ooooool0
003o0000ooooo`Co000000?oooooo`000?l000001oooool2o`000003ooooool0003o000000Kooooo
0_l0000<ooooo`;o00000oooool2o`0000;ooooo1Ol00002ooooo`;o00001oooool2o`0000oooooo
0_l00004ooooo`;o00000_ooool2o`000003ooooool0003o000000Gooooo0ol00003ooooo`;o0000
2?ooool2o`0000?ooooo0_l00005ooooo`Co000000?oooooo`000?l000002_l00009ooooo`;o0000
1?ooool3o`0000Cooooo0_l00005ooooo`;o0000>?ooool001cooooo0_l0000Jooooo`;o00006Ooo
ool3o`0000Kooooo0_l0000Booooo`;o00001oooool2o`0000Gooooo0_l00002ooooo`;o00000_oo
ool2o`0000?ooooo0_l00009ooooo`;o00003?ooool2o`0000Sooooo0ol00003ooooo`Go00003Ooo
ool2o`0000Kooooo0_l00004ooooo`;o00001?ooool2o`0000Kooooo0ol00003ooooo`Co00002Ooo
ool2o`0000;ooooo1?l00002ooooo`;o00000_ooool6o`0000Cooooo0_l0000@ooooo`;o00002Ooo
ool2o`0003[ooooo000Looooo`03o`000?oooooooooo03Cooooo0_l00007ooooo`;o000000?ooooo
o`000?l000003oooool3o`00017ooooo0_l00002ooooo`;o000000?oooooo`000?l000001?l0000=
ooooo`;o00000oooool4o`0000?ooooo1?l00003ooooo`;o00000oooool6o`0000cooooo0_l0000B
ooooo`;o00001_ooool3o`0000Gooooo0_l00009ooooo`;o00000_ooool4o`0000Kooooo1?l00003
ooooo`Go00002?ooool2o`00017ooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`10oooo
o`;o00000oooool2o`0000Sooooo0_l000000ooooooo0000o`000003ooooo`?o00004_ooool3o`00
0003ooooool0003o000000gooooo0_l00003ooooo`Co00000oooool7o`0000Kooooo0_l000001?oo
oooo0000o`000?ooool3o`0000Sooooo0_l0000?ooooo`;o00002_ooool2o`0000Kooooo0_l00007
ooooo`;o00000oooool3o`000003ooooool0003o000000Cooooo0_l00005ooooo`?o00002_ooool2
o`0000oooooo0_l0000looooo`007?ooool00ol0003oooooooooo`15ooooo`;o00001oooool3o`00
00Kooooo0ol0000Booooo`Oo00002?ooool2o`0001;ooooo0ol0000<ooooo`?o00006Oooool2o`00
00?ooooo0_l00005ooooo`;o000000?oooooo`000?l000000oooool2o`0000Oooooo0_l00003oooo
o`?o000000?oooooo`000?l000001?ooool2o`0000Kooooo0_l00006ooooo`;o00002?ooool2o`00
00Wooooo0_l00006ooooo`;o0000=?ooool001cooooo00?o0000ooooooooool0<Oooool2o`0001?o
oooo0_l00006ooooo`;o00001oooool4o`0000_ooooo0_l00004ooooo`So00001oooool2o`0001;o
oooo0_l00004ooooo`;o00001?ooool2o`0000;ooooo0_l00005ooooo`;o00005oooool2o`0000Co
oooo0ol000000ooooooo0000o`00000Sooooo`;o00001_ooool2o`0000Sooooo0_l0000@ooooo`?o
0000=?ooool001cooooo00?o0000ooooooooool07?ooool2o`0001?ooooo0_l000000ooooooo0000
o`00000;ooooo`;o00000oooool2o`000003ooooool0003o000000Cooooo0_l00006ooooo`Ko0000
1_ooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000;ooooo0ol0000Qooooo`;o
00001?ooool6o`0000Gooooo0_l0000Looooo`?o000000?oooooo`000?l000000oooool2o`0003?o
oooo0_l0000>ooooo`?o0000=?ooool001cooooo00?o0000ooooooooool07?ooool2o`0001?ooooo
0_l000000ooooooo0000o`000005ooooo`Co00000_ooool2o`000003ooooool0003o000000;ooooo
0ol00004ooooo`;o00002?ooool4o`0000Kooooo0_l00004ooooo`;o00000_ooool2o`0000;ooooo
0_l00003ooooo`;o00003?ooool2o`0001Oooooo1?l0000Pooooo`;o000000Goooooo`000?l0003o
0000ooooo`02o`0000?ooooo0_l00006ooooo`;o00009_ooool3o`0000;ooooo0_l00005ooooo`;o
00002?ooool2o`0003Cooooo000Looooo`03o`000?oooooooooo03_ooooo1?l00005ooooo`;o0000
0_ooool3o`0000kooooo1?l00003ooooo`;o000000?oooooo`000?l000002?ooool2o`0000Oooooo
0_l0000<ooooo`;o00000oooool2o`0001Cooooo0_l0000Pooooo`;o00001_ooool2o`0000Wooooo
0ol0000Uooooo`Co00002Oooool2o`0003kooooo000Looooo`03o`000?oooooooooo03kooooo0_l0
0003ooooo`;o00001?ooool2o`000003ooooool0003o000000gooooo0_l00002ooooo`?o000000?o
ooooo`000?l000009?ooool6o`0000Oooooo0_l0000`ooooo`Co00000oooool2o`0000?ooooo0_l0
000Vooooo`;o00004?ooool2o`0003Wooooo000Looooo`03o`000?oooooooooo03Gooooo0_l00006
ooooo`?o00000oooool4o`0000Gooooo0_l00005ooooo`;o00002Oooool3o`0000oooooo0_l00002
ooooo`;o00004Oooool8o`0000?ooooo0_l00002ooooo`;o00001?ooool2o`0002Sooooo1_l00000
0ooooooo0000o`000002o`0002Wooooo0_l0000Booooo`;o0000>Oooool001cooooo00?o0000oooo
ooooool0=Oooool2o`0000Kooooo0_l00006ooooo`;o00001Oooool3o`0000Cooooo0_l00003oooo
o`;o00001?ooool2o`0000;ooooo0_l0000<ooooo`;o00000_ooool2o`00017ooooo0_l00009oooo
o`;o00002?ooool2o`0002Sooooo0_l00005ooooo`Co00002?ooool2o`0000;ooooo0ol00004oooo
o`;o00005?ooool3o`0000Oooooo0ol00012ooooo`007?ooool00ol0003oooooooooo`0Oooooo`;o
00007oooool2o`0000?ooooo0_l00004ooooo`Ko00001oooool2o`0000Sooooo0_l0000Zooooo`;o
0000?oooool2o`0000Sooooo0_l00002ooooo`?o00001?ooool2o`0001Gooooo0ol00003ooooo`;o
000000Coooooo`000?l0003o0000@_ooool001cooooo00?o0000ooooooooool07oooool2o`0001oo
oooo0_l00009ooooo`;o00000_ooool2o`0000?ooooo0_l0000Booooo`;o00000_ooool5o`0001Oo
oooo0_l00003ooooo`?o00001?ooool2o`0000gooooo0_l0000Vooooo`Co00001Oooool2o`0000Oo
oooo0_l0000Mooooo`?o000000Goooooo`000?l0003o0000ooooo`03o`0000Sooooo0_l0000hoooo
o`007?ooool00ol0003oooooooooo`0aooooo`;o00006?ooool3o`0000Cooooo1?l0000:ooooo`;o
00001_ooool2o`0000;ooooo1Ol0000@ooooo`;o00001?ooool3o`0000;ooooo0ol00005ooooo`;o
00001_ooool2o`0000Gooooo0_l0000;ooooo`;o00006Oooool4o`0000Gooooo0_l0000;ooooo`;o
00006_ooool2o`000003ooooool0003o000000;ooooo0ol00008ooooo`;o0000>?ooool00006oooo
ooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006
ooooo`03o`000?oooooooooo037ooooo0_l00004ooooo`;o00004oooool4o`0000;ooooo0_l00000
0ooooooo0000o`000009ooooo`;o00001_ooool2o`0001Oooooo0_l00004ooooo`[o00002oooool2
o`0001;ooooo0_l00005ooooo`;o00002Oooool3o`0001Sooooo0_l00002ooooo`;o00004oooool2
o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`;o0000@oooool00006oooooomgMgOoV9RH
oooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`00
0?oooooooooo03Oooooo0_l0000=ooooo`;o00001?ooool4o`0000Gooooo0_l00006ooooo`;o0000
00?oooooo`000?l000000ol0000Cooooo`;o00001_oooolBo`000004ooooool0003o0000ooooo`;o
00001Oooool2o`0001Kooooo1?l00003ooooo`;o00001?ooool3o`0000_ooooo0_l0000;ooooo`;o
00004_ooool2o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l00000BOooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool0A_ooool5o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o
00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000004o`0001;ooooo0_l00006oooooaSo
00001Oooool2o`0001Kooooo0ol00004ooooo`?o00000oooool4o`0000Kooooo0_l00002ooooo`;o
00001Oooool2o`0000kooooo0_l00002ooooo`;o00000oooool3o`000003ooooool0003o000001Oo
oooo0_l0000jooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`00
0?nHV9SooooooiRHV?lQ8B401_ooool3o`0004Cooooo0_l00002ooooo`?o00001Oooool2o`0000;o
oooo0_l00002ooooo`;o00001_ooool2o`0000;ooooo0_l00009ooooo`;o00003oooool9o`000003
ooooool0003o000000[o00005?ooool2o`0000[ooooo0_l00003ooooo`Co00000_ooool2o`000003
ooooool0003o000000Kooooo0_l00002ooooo`;o00001Oooool2o`0000?ooooo0_l000000ooooooo
0000o`000006ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00005oooool2o`0003[o
oooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oeEEEOl0003o
410@olc<c006ooooo`03o`000?oooooooooo02;ooooo0_l0000Pooooo`;o00000_ooool2o`0000oo
oooo0_l0000@ooooo`;o00000_ooool2o`0000gooooo6Ol000000ooooooo0000o`00000@ooooo`;o
00001Oooool2o`0000?ooooo0ol000000ooooooo0000o`000003o`0000;ooooo0_l00005ooooo`;o
00001?ooool4o`0000[ooooo0_l000000ooooooo0000o`000003ooooo`;o00005?ooool2o`0000;o
oooo0_l0000<ooooo`;o0000>oooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool0
2Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo02;ooooo0_l0000eooooo`;o0000
1_ooool4o`0000Kooooo0ol0000?oooooaoo00002Oooool2o`0000Sooooo1?l000000ooooooo0000
o`000003o`000003ooooool0003o000000;o000000?oooooo`000?l000001?ooool2o`000003oooo
ool0003o000000Cooooo1?l0000Booooo`Co00000oooool2o`0000gooooo0_l00002ooooo`;o0000
2_ooool4o`0003_ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nH
V9P02?ooool00ol0003oooooooooo`1Hooooo`Co00001Oooool4o`0000;ooooo0_l000000ooooooo
0000o`000002o`0000oooooo7?l000000ooooooo0000o`000003ooooo`;o00001?ooool2o`0000Go
oooo1Ol00003ooooo`Co00000_ooool3o`0000;ooooo0_l00004ooooo`;o00002?ooool2o`0000[o
oooo0_l00009ooooo`;o00000oooool2o`0000cooooo1?l00009ooooo`;o00000_ooool2o`0003go
oooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool0
0ol0003oooooooooo`1Fooooo`Wo00002?ooool2o`000004ooooool0003o0000o`0000Sooooo0_l0
0006oooooaOo000000?oooooo`000?l000001Ol00003ooooo`Co00002Oooool6o`0000;ooooo3_l0
000;ooooo`Co00002_ooool2o`0000Wooooo0_l00007ooooo`;o00001_ooool6o`0000Wooooo0_l0
0011ooooo`007?ooool00ol0003oooooooooo`0Sooooo`;o0000<Oooool:o`000003ooooool0003o
000000Oooooo0_l00009ooooo`;o00001ooooolMo`0000Cooooo1?l00008oooooaOo000000?ooooo
o`000?l000001Oooool6o`0001gooooo1?l00004ooooo`Co000000?oooooo`000?l00000COooool0
01cooooo00?o0000ooooooooool08oooool3o`00033ooooo3Ol0000Booooo`;o000000?oooooo`00
0?l000000_l00002oooooago00000oooool5o`0000Gooooo6_l000001?oooooo0000o`000?l00004
ooooo`Co00001Oooool2o`0001Sooooo1?l00004ooooo`;o00000oooool2o`0000Oooooo0_l00014
ooooo`007?ooool00ol0003oooooooooo`0Tooooo`;o00007Oooool2o`0000Kooooo0_l00005oooo
o`;o000000?oooooo`000?l000002_l0000Dooooo`;o000000?oooooo`000?l000000_l00002oooo
oaKo000000?oooooo`000?l000000ol00004ooooo`;o000000?oooooo`000?l000001?ooool4o`00
0003ooooool0003o000001Co00000_ooool2o`0000Cooooo0_l00007ooooo`;o000000?oooooo`00
0?l000005?ooool4o`0000[ooooo0_l00007ooooo`;o0000A?ooool001cooooo00?o0000oooooooo
ool09_ooool2o`0001_ooooo0_l00004ooooo`Co000000?oooooo`000?l000000_ooool?o`0001Wo
oooo0_l00002oooooako00002_oooolHo`000003ooooool0003o000000?o00004_ooool2o`0001;o
oooo1?l00009ooooo`Co0000C_ooool001cooooo00?o0000ooooooooool09_ooool2o`00027ooooo
0_l00003ooooo`;o00001?ooool6o`000003ooooool0003o000000Co00005oooool4o`0000;ooooo
7_l00009ooooob;o00008_ooool5o`0000Wooooo1Ol00004ooooo`;o0000Aoooool001cooooo00?o
0000ooooooooool0=_ooool2o`0000Sooooo0_l00008ooooo`;o00001oooool=o`0000;ooooo0_l0
000Dooooo`;o00001?oooolKo`0000Wooooo7Ol000000ooooooo0000o`000005o`0000?ooooo0_l0
000Looooo`Co00002Oooool4o`000003ooooool0003o000000Cooooo0_l00017ooooo`007?ooool0
0ol0003oooooooooo`0fooooo`;o00002?ooool2o`0000;ooooo0_l00004ooooo`;o00001oooool>
o`000003ooooool0003o000000;ooooo0_l0000Fooooo`[o000000?oooooo`000?l000003ol00006
ooooobSo00000_ooool3o`000003ooooool0003o000001Kooooo1ol00007ooooo`?o00003oooool2
o`00047ooooo000Looooo`03o`000?oooooooooo04Cooooo0_l0000:ooooo`;o000000?oooooo`00
0?l000003?l00005ooooo`;o00002oooool2o`0000[ooooo6ol00005ooooo`?o00000ooooolAo`00
00;ooooo3Ol000000ooooooo0000o`000002ooooo`?o000000Coooooo`000?l0003ooooo0_l0000C
ooooo`;o00000oooool2o`0000Oooooo0_l000000ooooooo0000o`000005ooooo`;o00000_ooool2
o`0000;ooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`1;ooooo`Co000000?oooooo`00
0?l000003ol0000Booooo`;o000000?oooooo`000?l000001_ooool9o`000003ooooool0003o0000
00go00001_ooool4o`0000Gooooo7ol0000<ooooo`;o00007?ooool2o`0000Kooooo0_l00005oooo
o`Ko0000AOooool001cooooo00?o0000ooooooooool0Boooool5o`000003ooooool0003o000000go
00001?ooool3o`0000oooooo0_l00006oooooaWo00000oooool5o`0000Kooooo8Ol0000Oooooo`;o
00002?ooool2o`0000oooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`19ooooo`?o0000
0_ooool2o`000003ooooool0003o000000_o00001_ooool3o`0001Kooooo0_l000000ooooooo0000
o`00000Ao`0000Oooooo0ol00008oooooaSo000000?oooooo`000?l000001_l000000ooooooo0000
o`000007ooooo`;o00004oooool2o`0000Wooooo0_l0001Gooooo`007?ooool2o`0004Kooooo0_l0
0002ooooo`?o00000oooool2o`0000Cooooo3?l000000ooooooo0000o`000002o`00013ooooo0_l0
0005ooooo`;o00000oooool<o`000004ooooool0003o0000o`0001?ooooo8Ol000000ooooooo0000
o`000007ooooo`;o00007_ooool2o`0000;ooooo0_l0001Cooooo`007?ooool00ol0003ooooooooo
o`15ooooo`;o00002?ooool2o`0000Kooooo0_l000000ooooooo0000o`000005o`000003ooooool0
003o000000;o00004?ooool2o`0000Oooooo0_l00002ooooo`_o000000Coooooo`000?l0003o0000
5?oooolNo`0000?ooooo1_l00008ooooo`;o00007Oooool2o`0000_ooooo0ol00015ooooo`007?oo
ool00ol0003oooooooooo`1Gooooo`;o00001Oooool2o`0001[ooooo0_l00003ooooo`;o00000_oo
ool5o`000003ooooool0003o000000?o00003?ooool2o`0000Gooooo0_l00003oooooaoo000000Co
ooooo`000?l0003ooooo1?l00008ooooo`?o00005?ooool2o`0001?ooooo0ol00015ooooo`007?oo
ool00ol0003oooooooooo`0[ooooo`;o00009_ooool2o`0000cooooo0_l0000@ooooo`Co00000ooo
ool4o`0000Gooooo1Ol000001?oooooo0000o`000?ooool4o`0000?ooooo0_l00005ooooo`;o0000
1Oooool2o`0000Cooooo7_l000001?oooooo0000o`000?ooool3o`0000[ooooo0_l0000Aooooo`;o
000000?oooooo`000?l000000oooool3o`0005Gooooo000Looooo`03o`000?oooooooooo02_ooooo
0_l0000Vooooo`Co00001?ooool2o`0000Cooooo0_l0000@ooooo`Co00001Oooool2o`000003oooo
ool0003o000000;ooooo1Ol00002ooooo`;o00000_ooool2o`0000?ooooo0_l00004ooooo`;o0000
3_oooolLo`0000;ooooo0_l000000ooooooo0000o`00000Dooooo`;o00001_ooool4o`0000Gooooo
0ol0001Eooooo`007?ooool00ol0003oooooooooo`1?ooooo`;o00000oooool3o`0000Cooooo0_l0
0007ooooo`;o000000?oooooo`000?l000001oooool2o`0000;ooooo1?l00003ooooo`;o00000_oo
ool2o`0000Kooooo1Ol0000=ooooo`;o00003_oooolMo`000004ooooool0003o0000o`0000Cooooo
0ol0000?ooooo`;o00001?ooool7o`0000Cooooo0_l0001Fooooo`007?ooool00ol0003ooooooooo
o`1;ooooo`;o00000_ooool2o`0000?ooooo0ol00006ooooo`;o00001Oooool2o`000003ooooool0
003o000000Oooooo0_l00002ooooo`Co00000oooool2o`000003ooooool0003o000000Oooooo0ol0
0008ooooo`;o00001_ooool2o`0000gooooo7Ol00002ooooo`;o00001?ooool3o`0000oooooo0_l0
0004ooooo`;o00000oooool2o`0000?ooooo0_l0000<ooooo`;o0000BOooool001cooooo00?o0000
ooooooooool0Boooool2o`0000_ooooo0ol00002ooooo`;o00002?ooool2o`0000[ooooo0ol00005
ooooo`;o000000?oooooo`000?l000002?ooool2o`0000Sooooo0_l00006ooooo`;o000000?ooooo
o`000?l000002ooooolJo`0000Sooooo0_l000000ooooooo0000o`00000?ooooo`;o00000oooool2
o`0000Wooooo0_l0000<ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0F?ooool3o`00
00cooooo0_l0000:ooooo`;o00002Oooool2o`0000_ooooo0_l0000<ooooo`;o00000_ooool2o`00
00_ooooo0_l00002oooooaGo00002Oooool2o`0001Kooooo0ol00006ooooo`;o00003Oooool2o`00
04_ooooo000Looooo`03o`000?oooooooooo04Sooooo0_l00011ooooo`;o00003?ooool2o`0000_o
oooo0_l00003ooooo`;o00001Oooool=o`0000;ooooo0_l0000?ooooo`;o00004?ooool3o`0000Ko
oooo0_l00004ooooo`;o00001?ooool2o`000003ooooool0003o000004_ooooo000Looooo`03o`00
0?oooooooooo04Sooooo0_l00002ooooo`;o00003oooool2o`0002kooooo0_l0000Gooooo`;o0000
00?oooooo`000?l000000_l00003ooooo`Ko000000?oooooo`000?l000001_l000001?oooooo0000
o`000?l0000?ooooo`;o00002Oooool2o`0000gooooo0_l00005ooooo`;o00001?ooool2o`0004ko
oooo000Looooo`03o`000?oooooooooo04Sooooo0ol000000ooooooo0000o`00000?ooooo`;o0000
1oooool2o`0001_ooooo0_l00008ooooo`;o00006_ooool2o`0000Gooooo1?l00002ooooo`;o0000
0oooool3o`0000;ooooo0_l0000=ooooo`;o00003?ooool4o`0000Cooooo0_l00005ooooo`;o0000
0_ooool2o`000003ooooool0003o000005Cooooo000Looooo`03o`000?oooooooooo04Wooooo0_l0
0007ooooo`;o00004_ooool2o`0001;ooooo0_l00007ooooo`;o0000;?ooool3o`0000;ooooo0_l0
0004ooooo`Ko00003Oooool2o`0000Sooooo0_l00004ooooo`;o00001?ooool2o`0000Wooooo0_l0
001Gooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o00001_ooool2o`0000Oooooo0_l0000<
ooooo`;o00003_ooool3o`00037ooooo0_l0000?ooooo`Co00002Oooool4o`000003ooooool0003o
000000Oooooo0_l00002ooooo`;o00001_ooool3o`0000Sooooo0_l0001Gooooo`007?ooool00ol0
003oooooooooo`1:ooooo`;o00000_ooool2o`0000_ooooo0_l0000<ooooo`;o00003Oooool3o`00
02;ooooo0_l00002ooooo`;o00002_ooool2o`0001cooooo1?l000000ooooooo0000o`000006oooo
o`;o00000oooool2o`0000Oooooo0_l00005ooooo`;o00003?ooool2o`0004cooooo000Looooo`03
o`000?oooooooooo04kooooo0_l0000Xooooo`;o00005?ooool2o`0000Wooooo0_l00002ooooo`?o
000000?oooooo`000?l000007_ooool2o`0001Gooooo0_l0000Cooooo`;o00003?ooool2o`0004co
oooo000Looooo`;o0000J_ooool3o`0001Oooooo0_l00009ooooo`;o00002Oooool2o`0000?ooooo
0_l00007ooooo`?o00003_ooool2o`0000Oooooo0_l0000Hooooo`;o00004?ooool2o`0005[ooooo
000Looooo`03o`000?oooooooooo06Oooooo1Ol0000Gooooo`;o00004Oooool2o`000003ooooool0
003o000000cooooo1Ol0000;ooooo`?o00007Oooool2o`0000;ooooo0_l0000Eooooo`;o0000EOoo
ool001cooooo00?o0000ooooooooool0HOooool2o`0000Cooooo0_l0000Booooo`;o00005oooool4
o`000003ooooool0003o000000oooooo0_l0000:ooooo`?o00001oooool2o`0000_ooooo0_l00008
ooooo`?o000000Coooooo`000?l0003o00005?ooool2o`0005Gooooo000Looooo`03o`000?oooooo
oooo067ooooo0_l00003ooooo`?o00004_ooool2o`0001Oooooo0_l0000Mooooo`;o000000?ooooo
o`000?l000002?ooool2o`0000_ooooo0_l00002ooooo`?o00001?ooool2o`0000;ooooo0ol00002
ooooo`;o00001_ooool2o`0005kooooo000Looooo`03o`000?oooooooooo053ooooo0_l0000=oooo
o`Ko000000?oooooo`000?l000000ol0000Aooooo`;o0000=Oooool2o`0001cooooo0ol00005oooo
o`;o00000_ooool2o`0000;ooooo0_l00006ooooo`;o00002Oooool2o`0005?ooooo000Looooo`03
o`000?oooooooooo053ooooo0_l00003ooooo`;o00002?ooool7o`0000?ooooo0_l0000?ooooo`Co
00002Oooool3o`0000Sooooo0_l00006ooooo`;o00005Oooool2o`0000Cooooo0_l0000Pooooo`;o
00001_ooool2o`000003ooooool0003o000000kooooo0_l0001Cooooo`007?ooool00ol0003ooooo
ooooo`1Cooooo`Co00003?ooool3o`0000Cooooo0_l0000>ooooo`;o00000oooool2o`0000Kooooo
0ol00008ooooo`;o00001Oooool3o`0001Gooooo0_l00003ooooo`?o0000:?ooool2o`000003oooo
ool0003o000000Wooooo1?l0001Fooooo`007?ooool00ol0003oooooooooo`1Cooooo`Co000000?o
ooooo`000?l000002Oooool2o`0000Gooooo0_l0000Cooooo`;o00006?ooool2o`0000;ooooo0_l0
000Gooooo`;o00005oooool2o`0001?ooooo0ol00008ooooo`Co00001_ooool2o`0004kooooo000L
ooooo`03o`000?oooooooooo05Sooooo0_l00005ooooo`;o00007oooool2o`0001_ooooo0_l0000`
ooooo`;o00004oooool3o`0000_ooooo0ol00004ooooo`;o0000C_ooool001cooooo00?o0000oooo
ooooool0D?ooool3o`0000Sooooo0_l00002ooooo`;o00002?ooool2o`0001Gooooo0_l00010oooo
o`;o00000oooool2o`0002Wooooo0ol0001Dooooo`007?ooool00ol0003oooooooooo`1@ooooo`?o
00000oooool2o`0000?ooooo0_l000000ooooooo0000o`000005ooooo`;o00000_ooool4o`0000go
oooo0_l00014ooooo`Co00000oooool2o`0000Wooooo0_l00009ooooo`;o00004oooool2o`0005Go
oooo000Looooo`03o`000?oooooooooo05Kooooo0ol000001?oooooo0000o`000?ooool3o`0000Go
oooo0_l00004ooooo`;o00003Oooool2o`0001_ooooo0_l0000Tooooo`;o000000?oooooo`000?l0
00000_l0000:ooooo`?o000000?oooooo`000?l000001oooool4o`0000Sooooo0_l0001Pooooo`00
7?ooool00ol0003oooooooooo`1Aooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`;o
00001?ooool2o`0001Kooooo0_l0000Jooooo`;o00008?ooool2o`0000;ooooo0ol00002ooooo`;o
00000_ooool2o`0000Kooooo0ol000000ooooooo0000o`000007ooooo`;o00002_ooool2o`00063o
oooo000Looooo`03o`000?oooooooooo057ooooo0_l00008ooooo`;o00000_ooool2o`000004oooo
ool0003o0000o`0000_ooooo0_l00009ooooo`;o00005oooool2o`0000?ooooo0_l0000Nooooo`;o
00000oooool2o`0000Kooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000000Ko
oooo0_l00007ooooo`;o00000_ooool2o`0000Oooooo0_l0001Gooooo`007?ooool00ol0003ooooo
ooooo`1Kooooo`;o00000_ooool2o`000003ooooool0003o000000;o00002_ooool2o`0001Oooooo
1?l00007ooooo`;o00000oooool2o`0001gooooo0_l00009ooooo`;o00001Oooool2o`0000kooooo
0_l00007ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o0000Eoooool001cooooo00?o
0000ooooooooool0Eoooool2o`0000Wooooo1Ol0000Jooooo`;o00001?ooool6o`0002[ooooo0ol0
0005ooooo`;o00000_ooool2o`0000_ooooo0_l00008ooooo`;o00000_ooool2o`0000Kooooo0_l0
0004ooooo`;o0000Foooool001cooooo0_l0001Hooooo`;o00001_ooool2o`000004ooooool0003o
0000ooooo`;o00006?ooool4o`0000Cooooo0_l00002ooooo`;o0000:_ooool2o`0000;ooooo0_l0
0002ooooo`;o00001_ooool2o`0000Oooooo0_l0000<ooooo`;o00001_ooool2o`00067ooooo000L
ooooo`03o`000?oooooooooo05oooooo0ol0000=ooooo`;o00000oooool2o`0000Wooooo0_l0000:
ooooo`;o00000oooool2o`0002Wooooo0_l0000:ooooo`;o00002Oooool2o`0000?ooooo0_l0000D
ooooo`;o00000oooool2o`0005Gooooo000Looooo`03o`000?oooooooooo063ooooo0_l0000=oooo
o`?o00000_ooool2o`000003ooooool0003o000001Oooooo0_l0000cooooo`Co00001?ooool2o`00
00;ooooo0ol00003ooooo`;o00002oooool2o`0000Oooooo0_l00003ooooo`;o0000EOooool001co
oooo00?o0000ooooooooool0L?ooool2o`0000;ooooo0_l000000ooooooo0000o`000014ooooo`;o
00000_ooool2o`0000;ooooo1?l00004ooooo`;o00000_ooool2o`00017ooooo0_l0001Sooooo`00
7?ooool00ol0003oooooooooo`1Mooooo`;o00000_ooool3o`0003;ooooo0_l00006ooooo`;o0000
3oooool3o`0000Cooooo0_l00005ooooo`;o00000_ooool2o`0002cooooo0_l0001Hooooo`007?oo
ool00ol0003oooooooooo`1Mooooo`;o00000_ooool3o`0001?ooooo0ol0000Cooooo`Co00001Ooo
ool2o`000003ooooool0003o000000?ooooo0_l0000?ooooo`?o00001?ooool2o`0000Wooooo1_l0
000Fooooo`;o00001Oooool4o`0000Oooooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`1Q
ooooo`;o00005?ooool4o`0001;ooooo1?l00008ooooo`;o00001_ooool2o`0000Gooooo0_l00007
ooooo`?o00003oooool4o`0000cooooo0_l00008ooooo`;o00001Oooool4o`00067ooooo000Loooo
o`03o`000?oooooooooo07Wooooo0_l0000;ooooo`;o00006Oooool2o`0000;ooooo0_l000000ooo
oooo0000o`000007ooooo`?o00001Oooool2o`0001Sooooo0_l0001dooooo`007?ooool00ol0003o
ooooooooo`1Sooooo`?o000000?oooooo`000?l000005?ooool2o`0000?ooooo0_l00002ooooo`;o
00002Oooool2o`0001;ooooo0_l00003ooooo`;o000000?oooooo`000?l000002_ooool3o`0001Oo
oooo0_l000000ooooooo0000o`00001aooooo`007?ooool00ol0003oooooooooo`1Qooooo`Wo0000
4_ooool3o`0000?ooooo0_l0000=ooooo`Co00002?ooool2o`0000Gooooo0_l00004ooooo`Go0000
2oooool2o`0000;ooooo0_l0000?ooooo`;o00000_ooool5o`00077ooooo000Looooo`03o`000?oo
oooooooo067ooooo0_l00002ooooo`Go00004_ooool2o`000003ooooool0003o000001;ooooo0_l0
0002ooooo`;o00001?ooool2o`0000Gooooo0_l00004ooooo`?o00003?ooool2o`000003ooooool0
003o000000;o00002oooool3o`000003ooooool0003o000000?ooooo0_l0000:ooooo`;o00001?oo
ool2o`00067ooooo000Looooo`03o`000?oooooooooo05_ooooo0_l00009ooooo`Co00005Oooool2
o`0000Wooooo0_l00005ooooo`;o00000oooool3o`000003ooooool0003o000000[ooooo0_l00008
ooooo`;o00001oooool2o`000003ooooool0003o000000gooooo0ol00005ooooo`;o00002oooool4
o`0000;ooooo0_l0001Qooooo`007?ooool00ol0003oooooooooo`1Kooooo`;o00002_ooool2o`00
00?ooooo0_l00002ooooo`;o00003Oooool3o`0000Sooooo0_l00002ooooo`;o000000?oooooo`00
0?l000000oooool3o`000004ooooool0003o0000o`0000Wooooo0_l00008ooooo`;o00008?ooool3
o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l00000IOooool001cooooo00?o0000oooo
ooooool0Ioooool2o`0000?ooooo2?l0000;ooooo`?o00003?ooool2o`0000Oooooo0_l00002oooo
o`Co00002Oooool2o`00017ooooo0ol0000Dooooo`;o00001Oooool2o`0000Cooooo0_l0001Xoooo
o`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<00Kooooo00?o0000ooooooooool0K?ooool4o`0000;ooooo0_l0000Aooooo`;o00004Ooo
ool2o`0000;ooooo0ol00002ooooo`;o00001Oooool2o`000003ooooool0003o000000[ooooo0_l0
0002ooooo`?o00004oooool2o`0000?ooooo0_l000000ooooooo0000o`00001^ooooo`0000Kooooo
ogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Ko
oooo00?o0000ooooooooool0Joooool2o`0001Sooooo0_l0000Aooooo`?o00001Oooool3o`0000;o
oooo0_l00002ooooo`Co00002_ooool2o`000004ooooool0003o0000ooooo`;o00002Oooool2o`00
00Oooooo0_l00002ooooo`?o000000?oooooo`000?l00000K_ooool00003ooooool@413ooooo00;o
oooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool0Hoooool2o`0000Kooooo0_l00005ooooo`;o00007?ooool2o`0000Oooooo0_l00005oooo
o`Oo00000_ooool3o`0000Gooooo0_l00007ooooo`;o000000Coooooo`000?l0003ooooo0_l00006
ooooo`;o00001?ooool2o`0000Gooooo0_l00002ooooo`;o0000K_ooool00003ooooool0003ooooo
00;ooooo00?o0000ooooooooool02Oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0001S
ooooo`Co00001?ooool2o`0000Gooooo0_l00005ooooo`;o00002Oooool4o`0000?ooooo0_l00003
ooooo`;o00001oooool2o`0000Oooooo1ol00008ooooo`Co00002oooool2o`0000;ooooo1?l00006
ooooo`;o00002Oooool2o`0006kooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00Wooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo06Gooooo0_l00008
ooooo`;o00001Oooool2o`000003ooooool0003o000000Gooooo0_l00002ooooo`Co00000oooool2
o`0001Sooooo1?l0000:ooooo`;o00001_ooool2o`0000Oooooo1?l00021ooooo`0000?ooooooa0@
4?ooool00_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool0
0ol0003oooooooooo`1_ooooo`;o00001Oooool3o`0000;ooooo0_l00003ooooo`;o00000_ooool2
o`00017ooooo0ol00007ooooo`;o00002?ooool4o`0000Oooooo0ol00002ooooo`;o00000oooool2
o`000004ooooool0003o0000ooooo`;o0000POooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0Koooool4o`0000?o
oooo1?l000000ooooooo0000o`000007ooooo`;o000000?oooooo`000?l000003_ooool3o`0000?o
oooo0_l00002ooooo`;o00002?ooool5o`0000Kooooo0ol00002ooooo`;o00000oooool2o`000004
ooooool0003o0000ooooo`;o00003Oooool2o`0007;ooooo00001_ooooook^k^oc8b<_l0003o<S8b
onk^kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo06Wooooo0_l0
0004ooooo`Co00001?ooool3o`0000gooooo0_l0000Dooooo`?o00001_ooool2o`0000;ooooo1_l0
0006ooooo`;o00001?ooool4o`000003ooooool0003o000000;o00004?ooool2o`0007;ooooo000L
ooooo`03o`000?oooooooooo06Wooooo0_l00005ooooo`;o00001Oooool2o`0001gooooo0_l00006
ooooo`;o00001_ooool2o`0000;ooooo0_l00002ooooo`;o00003?ooool4o`000003ooooool0003o
000000;o0000Q?ooool001cooooo00?o0000ooooooooool0L?ooool2o`0000Gooooo0_l0000Koooo
o`Co00000_ooool2o`0000Oooooo0_l00009ooooo`;o00004Oooool2o`000003ooooool0003o0000
00Sooooo0_l0001iooooo`007?ooool00ol0003oooooooooo`28ooooo`;o00002_ooool3o`0000?o
oooo0_l00007ooooo`;o000000?oooooo`000?l000002_ooool2o`0000gooooo0_l000000ooooooo
0000o`000008ooooo`?o0000N?ooool001cooooo00?o0000ooooooooool0Ooooool2o`0000;ooooo
0_l00003ooooo`?o00002Oooool6o`0000Wooooo0_l000000ooooooo0000o`000002o`0000Cooooo
0_l00002ooooo`;o00000oooool2o`0001Cooooo1?l0001hooooo`007?ooool00ol0003ooooooooo
o`1oooooo`;o000000Coooooo`000?l0003o00000oooool3o`0000Cooooo0_l00006ooooo`?o0000
2Oooool2o`0000?ooooo0_l00004ooooo`;o00000_ooool2o`000003ooooool0003o000000;o0000
3oooool2o`0000?ooooo0_l0001jooooo`007?ooool00ol0003oooooooooo`22ooooo`?o00000_oo
ool5o`0000?ooooo0_l00002ooooo`Co000000?oooooo`000?l000002?ooool2o`000003ooooool0
003o000000Wooooo0_l00003ooooo`;o00004Oooool2o`0007oooooo000Looooo`03o`000?oooooo
oooo08?ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo1?l0000;
ooooo`;o000000?oooooo`000?l000002Oooool2o`00017ooooo0_l00024ooooo`007?ooool00ol0
003oooooooooo`1oooooo`;o00003Oooool2o`0000Oooooo0_l00009ooooo`;o00007oooool2o`00
08Cooooo000Looooo`03o`000?oooooooooo07oooooo1?l0000;ooooo`?o00001_ooool2o`0000ko
oooo0_l0000<ooooo`;o0000T_ooool001cooooo00?o0000ooooooooool0POooool2o`0000cooooo
0_l0000@ooooo`;o00001?ooool2o`0000cooooo0_l0002Booooo`007?ooool00ol0003ooooooooo
o`24ooooo`;o00001oooool2o`0000Wooooo0_l00007ooooo`?o0000YOooool001cooooo0_l00025
ooooo`?o00001_ooool2o`0000Wooooo0_l00008ooooo`;o0000YOooool001cooooo00?o0000oooo
ooooool0QOooool2o`0000Sooooo0ol0000<ooooo`;o00001oooool2o`000003ooooool0003o0000
09gooooo000Looooo`03o`000?oooooooooo08oooooo0ol00002ooooo`;o00001?ooool6o`0000?o
oooo0_l00002ooooo`Go0000WOooool001cooooo00?o0000ooooooooool0ROooool2o`0000Wooooo
0_l00004ooooo`Co00001Oooool2o`0000;ooooo0ol000000ooooooo0000o`00002Looooo`007?oo
ool00ol0003oooooooooo`29ooooo`;o000000?oooooo`000?l000001Oooool2o`0001Kooooo0_l0
002Looooo`007?ooool00ol0003oooooooooo`2<ooooo`;o00001Oooool2o`000;Cooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Boooo
o`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003ooooo
ooooo`05ooooo`?o0000oooooom:ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000D
ooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBoooo
o`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Booooo`03oeEEEOmVIVKo00000?oooooo
E?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Gooooo00Co410@o`000?l0
003ooooo0_l000000ol@413oooooooooo`0Eooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool0
1Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b<_l0003o410@olc<c02@ooooo`00Y_oo
ool01Ol0003ooooooooooooooooo000000Wooooo1_l00009ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B400oooool01OmEEEGoMgMgoooooonHV9So8B4Q00?ooooo00GoEEEEogMgMoooooooV9RHob4Q8@2@
ooooo`00Y_ooool01Ol0003ooooooooooooooooo000001Sooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000093o
oooo002Vooooo`05o`000?ooooooooooooooool000002Oooool6o`0000Wooooo00Go0000oiRHV?oo
ooooV9RHob4Q8@03ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003oV9RHoooooonH
V9So8B4Q093ooooo002Vooooo`05o`000?n7QhOoooooojVYZOl000006?ooool01Ol0003oEEEEo`00
0?l@413oc<c<00?ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0T?ooool00:Gooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Fooooo`03
oeEEEOn7QhOooooo00Gooooo00?oEEEEohN7Qoooool01Oooool00omEEEGoQhN7ooooo`2Booooo`00
`oooool00ooMgMgo410@oiRHV005ooooo`03omgMgOl@413oV9RH00Gooooo00?ogMgMoa0@4?nHV9P0
T_ooool00<Cooooo00Coc<c<odA4A?l0003o410@1?ooool01?o<c<coA4A4o`000?l@4104ooooo`04
olc<c?m4A4Co0000oa0@493ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000
\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(672) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.32313 .41093 Mdot
.38131 .41417 Mdot
.5239 .67864 Mdot
.5358 .38785 Mdot
.63249 .57699 Mdot
.53645 .65998 Mdot
.41733 .61909 Mdot
.40899 .63513 Mdot
.54667 .67053 Mdot
.33547 .27838 Mdot
.38693 .60349 Mdot
.6497 .40357 Mdot
.42319 .60816 Mdot
.58982 .39066 Mdot
.25059 .64434 Mdot
.50964 .43178 Mdot
.39444 .40403 Mdot
.68429 .52422 Mdot
.515 .43972 Mdot
.50784 .65999 Mdot
.41188 .45078 Mdot
.58281 .39109 Mdot
.38346 .41753 Mdot
.58733 .39145 Mdot
.54734 .42733 Mdot
.35175 .41065 Mdot
.31579 .40542 Mdot
.55245 .4059 Mdot
.58204 .42561 Mdot
.40278 .58899 Mdot
.66897 .60523 Mdot
.23709 .71445 Mdot
.50634 .3991 Mdot
.56903 .27126 Mdot
.45502 .62762 Mdot
.65984 .75556 Mdot
.56717 .66229 Mdot
.3834 .62207 Mdot
.43488 .63191 Mdot
.45036 .61956 Mdot
.44124 .6076 Mdot
.35959 .41195 Mdot
.42844 .57862 Mdot
.48688 .66966 Mdot
.53834 .37012 Mdot
.2402 .53989 Mdot
.77075 .58268 Mdot
.55389 .40331 Mdot
.3305 .41255 Mdot
.50775 .64425 Mdot
.66272 .26582 Mdot
.3809 .62168 Mdot
.28911 .5988 Mdot
.09689 .45057 Mdot
.41775 .59169 Mdot
.53988 .39296 Mdot
.55005 .64243 Mdot
.56152 .37217 Mdot
.56463 .3959 Mdot
.57398 .25474 Mdot
.57735 .41937 Mdot
.71255 .54029 Mdot
.32269 .4202 Mdot
.50062 .65808 Mdot
.54411 .66563 Mdot
.42842 .58932 Mdot
.38163 .38312 Mdot
.43186 .61165 Mdot
.60951 .44574 Mdot
.51301 .66098 Mdot
.55128 .39807 Mdot
.38526 .60515 Mdot
.39066 .38321 Mdot
.55886 .44644 Mdot
.28773 .53468 Mdot
.33865 .64086 Mdot
.73488 .58243 Mdot
.46596 .31902 Mdot
.42046 .18443 Mdot
.40466 .68296 Mdot
.59535 .39851 Mdot
.39474 .17212 Mdot
.27901 .63909 Mdot
.38573 .40334 Mdot
.59085 .29523 Mdot
.46179 .78661 Mdot
.59646 .42123 Mdot
.56903 .53045 Mdot
.57767 .33304 Mdot
.37341 .49781 Mdot
.55267 .66807 Mdot
.3499 .41673 Mdot
.5356 .37241 Mdot
.60508 .41899 Mdot
.49949 .21308 Mdot
.52214 .37093 Mdot
.54372 .37085 Mdot
.31183 .3647 Mdot
.39326 .60411 Mdot
.63661 .37085 Mdot
.48063 .66931 Mdot
.26485 .59564 Mdot
.52848 .4105 Mdot
.52822 .66728 Mdot
.37052 .43828 Mdot
.52975 .38216 Mdot
.42602 .59083 Mdot
.58251 .40828 Mdot
.4362 .56551 Mdot
.35242 .42523 Mdot
.60689 .41632 Mdot
.67973 .54458 Mdot
.31628 .51476 Mdot
.32649 .38654 Mdot
.25039 .33741 Mdot
.57361 .41473 Mdot
.5736 .39199 Mdot
.38176 .40966 Mdot
.54688 .63373 Mdot
.53246 .52898 Mdot
.39513 .39314 Mdot
.44344 .62778 Mdot
.35881 .43037 Mdot
.61284 .35781 Mdot
.53321 .63041 Mdot
.27223 .59324 Mdot
.25206 .60439 Mdot
.8115 .48063 Mdot
.56497 .44315 Mdot
.23915 .62558 Mdot
.52893 .64758 Mdot
.36669 .41603 Mdot
.43166 .60765 Mdot
.60743 .36422 Mdot
.36245 .38007 Mdot
.40916 .62937 Mdot
.69489 .5647 Mdot
.63258 .63505 Mdot
.32447 .37943 Mdot
.57624 .50207 Mdot
.43691 .63693 Mdot
.45055 .61679 Mdot
.68598 .29376 Mdot
.38259 .40334 Mdot
.70444 .56058 Mdot
.41511 .62798 Mdot
.7414 .40979 Mdot
.60373 .36125 Mdot
.72763 .33189 Mdot
.45304 .15184 Mdot
.67441 .27708 Mdot
.20648 .45288 Mdot
.72009 .53405 Mdot
.42105 .62928 Mdot
.53628 .41093 Mdot
.36629 .39481 Mdot
.36904 .40181 Mdot
.61534 .4096 Mdot
.55882 .42728 Mdot
.59035 .36435 Mdot
.61217 .38842 Mdot
.74614 .66013 Mdot
.59633 .36839 Mdot
.46883 .56244 Mdot
.34694 .37617 Mdot
.55525 .43329 Mdot
.5665 .68454 Mdot
.58132 .44693 Mdot
.38337 .6214 Mdot
.56109 .38891 Mdot
.55172 .42202 Mdot
.51875 .40015 Mdot
.44366 .61429 Mdot
.35075 .79556 Mdot
.34897 .22215 Mdot
.55842 .78851 Mdot
.22907 .43814 Mdot
.53823 .64344 Mdot
.6035 .39277 Mdot
.72335 .55532 Mdot
.58922 .3086 Mdot
.56739 .4004 Mdot
.63059 .24044 Mdot
.55753 .4189 Mdot
.41552 .34994 Mdot
.56863 .31854 Mdot
.51754 .81547 Mdot
.38668 .53786 Mdot
.58471 .42139 Mdot
.40311 .22133 Mdot
.74158 .33383 Mdot
.71716 .59284 Mdot
.42715 .59514 Mdot
.58033 .66822 Mdot
.56513 .64785 Mdot
.45195 .59998 Mdot
.6314 .37651 Mdot
.3316 .28812 Mdot
.63083 .42123 Mdot
.27609 .59581 Mdot
.36795 .44523 Mdot
.71278 .52538 Mdot
.31946 .38431 Mdot
.32666 .2038 Mdot
.46081 .45304 Mdot
.36811 .58183 Mdot
.67911 .52912 Mdot
.53847 .68484 Mdot
.28038 .6012 Mdot
.7197 .56035 Mdot
.54675 .37285 Mdot
.33918 .41757 Mdot
.74007 .3295 Mdot
.50317 .37184 Mdot
.8226 .63225 Mdot
.38354 .39182 Mdot
.47046 .52502 Mdot
.42783 .59877 Mdot
.51668 .62866 Mdot
.5905 .42416 Mdot
.58408 .36857 Mdot
.32185 .41757 Mdot
.55802 .4076 Mdot
.38822 .47668 Mdot
.55038 .41765 Mdot
.49209 .64203 Mdot
.69016 .58033 Mdot
.4506 .5874 Mdot
.81111 .46175 Mdot
.38937 .37732 Mdot
.51838 .56838 Mdot
.539 .67951 Mdot
.28254 .36811 Mdot
.38987 .59528 Mdot
.68877 .56112 Mdot
.5662 .67333 Mdot
.7251 .57629 Mdot
.52466 .41611 Mdot
.56302 .66511 Mdot
.69109 .53941 Mdot
.61263 .63855 Mdot
.5401 .3735 Mdot
.71238 .38832 Mdot
.41249 .6232 Mdot
.31454 .40056 Mdot
.57693 .42057 Mdot
.25065 .59801 Mdot
.62498 .39134 Mdot
.24003 .63175 Mdot
.27264 .58791 Mdot
.28697 .59386 Mdot
.35032 .66426 Mdot
.73106 .55572 Mdot
.23506 .49803 Mdot
.49549 .49867 Mdot
.39636 .39783 Mdot
.53818 .36557 Mdot
.42278 .83004 Mdot
.42061 .62636 Mdot
.54716 .37411 Mdot
.47602 .78932 Mdot
.41515 .62761 Mdot
.56639 .37625 Mdot
.44305 .60535 Mdot
.36921 .39726 Mdot
.53334 .54993 Mdot
.38402 .42588 Mdot
.54011 .38469 Mdot
.40537 .60387 Mdot
.57544 .67028 Mdot
.35124 .40919 Mdot
.57836 .40744 Mdot
.60005 .39024 Mdot
.2762 .60287 Mdot
.56064 .43461 Mdot
.44969 .82346 Mdot
.5516 .40224 Mdot
.54227 .68734 Mdot
.52563 .36597 Mdot
.73103 .30138 Mdot
.63366 .6304 Mdot
.36507 .37307 Mdot
.27801 .58756 Mdot
.55635 .66114 Mdot
.60939 .58124 Mdot
.64804 .54023 Mdot
.58927 .40204 Mdot
.2599 .60304 Mdot
.47535 .53599 Mdot
.41986 .5864 Mdot
.56865 .33589 Mdot
.42777 .46383 Mdot
.55483 .67731 Mdot
.27884 .59936 Mdot
.56972 .32245 Mdot
.37107 .43689 Mdot
.53815 .39687 Mdot
.56761 .6665 Mdot
.34888 .42941 Mdot
.60508 .35883 Mdot
.76998 .61527 Mdot
.25458 .59581 Mdot
.41556 .62279 Mdot
.6367 .45289 Mdot
.59128 .36012 Mdot
.56541 .64403 Mdot
.37027 .38739 Mdot
.40678 .59362 Mdot
.33329 .40376 Mdot
.76221 .34874 Mdot
.23844 .44659 Mdot
.64666 .72958 Mdot
.68438 .52044 Mdot
.16964 .54789 Mdot
.57832 .77919 Mdot
.25446 .47437 Mdot
.79147 .48858 Mdot
.63656 .79384 Mdot
.56689 .68118 Mdot
.6777 .33515 Mdot
.55673 .65237 Mdot
.53183 .4153 Mdot
.53847 .66325 Mdot
.48283 .83655 Mdot
.55258 .41091 Mdot
.54087 .64101 Mdot
.72566 .66815 Mdot
.56679 .42648 Mdot
.33483 .3775 Mdot
.21394 .65483 Mdot
.2761 .33282 Mdot
.49304 .47226 Mdot
.53774 .63739 Mdot
.57359 .22091 Mdot
.56219 .41788 Mdot
.49852 .41325 Mdot
.36083 .39723 Mdot
.58242 .33343 Mdot
.69522 .52734 Mdot
.70974 .57692 Mdot
.68829 .31442 Mdot
.25905 .34875 Mdot
.52812 .46629 Mdot
.35577 .40749 Mdot
.43187 .18015 Mdot
.28764 .53705 Mdot
.2494 .61026 Mdot
.43396 .634 Mdot
.3482 .79253 Mdot
.48837 .37937 Mdot
.60016 .49513 Mdot
.39938 .48751 Mdot
.3561 .42101 Mdot
.57552 .75714 Mdot
.41093 .59672 Mdot
.38653 .21782 Mdot
.38712 .29758 Mdot
.58092 .35966 Mdot
.40991 .58055 Mdot
.64696 .39477 Mdot
.38848 .48267 Mdot
.71671 .36211 Mdot
.52886 .72199 Mdot
.53845 .37964 Mdot
.24346 .50598 Mdot
.56873 .39341 Mdot
.73788 .34128 Mdot
.54393 .37953 Mdot
.33084 .39588 Mdot
.50359 .45611 Mdot
.62318 .54233 Mdot
.29661 .27128 Mdot
.44943 .4463 Mdot
.73172 .54531 Mdot
.59083 .38595 Mdot
.58111 .36263 Mdot
.70463 .53387 Mdot
.34113 .40011 Mdot
.55954 .35452 Mdot
.78565 .57151 Mdot
.5874 .35973 Mdot
.37977 .61097 Mdot
.57898 .55628 Mdot
.31418 .33305 Mdot
.60119 .41977 Mdot
.35514 .43307 Mdot
.43574 .59646 Mdot
.41856 .63542 Mdot
.50114 .44163 Mdot
.42961 .62547 Mdot
.54079 .40222 Mdot
.56563 .55267 Mdot
.37459 .42362 Mdot
.63015 .3373 Mdot
.34076 .39437 Mdot
.51939 .17825 Mdot
.44659 .60613 Mdot
.2594 .61675 Mdot
.67587 .39207 Mdot
.41309 .6083 Mdot
.28006 .3934 Mdot
.48058 .39558 Mdot
.58947 .44843 Mdot
.27371 .36627 Mdot
.57506 .64827 Mdot
.27491 .61431 Mdot
.4115 .59135 Mdot
.59165 .36306 Mdot
.52576 .40005 Mdot
.39088 .58694 Mdot
.52 .22802 Mdot
.6688 .60894 Mdot
.54377 .38403 Mdot
.33334 .39689 Mdot
.36387 .41555 Mdot
.59166 .3503 Mdot
.56812 .40457 Mdot
.55317 .68952 Mdot
.25793 .60458 Mdot
.28449 .59816 Mdot
.25269 .60715 Mdot
.54533 .62324 Mdot
.17078 .51642 Mdot
.4502 .61722 Mdot
.19323 .54465 Mdot
.39523 .7595 Mdot
.5015 .43701 Mdot
.57058 .64699 Mdot
.57681 .37266 Mdot
.53052 .42511 Mdot
.40232 .60151 Mdot
.20589 .3923 Mdot
.57295 .46879 Mdot
.31578 .38493 Mdot
.3814 .5991 Mdot
.6204 .32037 Mdot
.34433 .60656 Mdot
.68805 .53338 Mdot
.45654 .43844 Mdot
.40586 .58083 Mdot
.33856 .41369 Mdot
.39549 .58334 Mdot
.58402 .36256 Mdot
.60703 .42771 Mdot
.3705 .42196 Mdot
.73111 .55965 Mdot
.52769 .38141 Mdot
.56642 .37766 Mdot
.74463 .2826 Mdot
.28206 .53007 Mdot
.35961 .62853 Mdot
.54236 .43311 Mdot
.56356 .46048 Mdot
.7349 .55689 Mdot
.58038 .35488 Mdot
.59362 .42143 Mdot
.31698 .50592 Mdot
.45887 .60968 Mdot
.73475 .58074 Mdot
.36624 .23023 Mdot
.37931 .38842 Mdot
.45707 .81585 Mdot
.2646 .59401 Mdot
.45972 .60411 Mdot
.52295 .54806 Mdot
.26854 .61479 Mdot
.42047 .75538 Mdot
.52307 .78867 Mdot
.25867 .6143 Mdot
.56993 .69742 Mdot
.50453 .3335 Mdot
.61397 .38363 Mdot
.56069 .38475 Mdot
.72196 .56294 Mdot
.37845 .39784 Mdot
.42829 .5342 Mdot
.57285 .61504 Mdot
.57922 .39188 Mdot
.35691 .35572 Mdot
.48866 .80043 Mdot
.27732 .60544 Mdot
.72544 .54681 Mdot
.72501 .52942 Mdot
.57034 .39132 Mdot
.28342 .47788 Mdot
.35486 .40991 Mdot
.5784 .40721 Mdot
.60924 .38988 Mdot
.54506 .63552 Mdot
.33292 .41069 Mdot
.53719 .67919 Mdot
.26869 .58796 Mdot
.72398 .74063 Mdot
.75867 .29604 Mdot
.40162 .61485 Mdot
.5731 .77094 Mdot
.3762 .62182 Mdot
.46397 .68644 Mdot
.25617 .60885 Mdot
.58002 .40043 Mdot
.38378 .37442 Mdot
.58074 .40929 Mdot
.56583 .35671 Mdot
.55073 .36345 Mdot
.5323 .46765 Mdot
.63927 .24431 Mdot
.71443 .55421 Mdot
.55625 .46297 Mdot
.58212 .67427 Mdot
.50817 .80974 Mdot
.2332 .68525 Mdot
.59211 .37775 Mdot
.57437 .3887 Mdot
.37111 .37796 Mdot
.54358 .4479 Mdot
.40861 .58628 Mdot
.38458 .39803 Mdot
.52765 .397 Mdot
.61622 .69933 Mdot
.58741 .35452 Mdot
.5934 .77117 Mdot
.39419 .58377 Mdot
.45447 .43117 Mdot
.58572 .45477 Mdot
.25695 .61371 Mdot
.27287 .61539 Mdot
.24586 .60578 Mdot
.42033 .58424 Mdot
.55151 .6385 Mdot
.57327 .61991 Mdot
.59781 .33039 Mdot
.53785 .41009 Mdot
.59189 .44832 Mdot
.53184 .62158 Mdot
.57421 .54489 Mdot
.21174 .46334 Mdot
.54 .3227 Mdot
.58147 .65179 Mdot
.32459 .36234 Mdot
.24527 .31698 Mdot
.37939 .39277 Mdot
.72554 .58593 Mdot
.38278 .61579 Mdot
.68821 .52984 Mdot
.60078 .22858 Mdot
.36796 .4246 Mdot
.31615 .41101 Mdot
.53893 .64168 Mdot
.41688 .5214 Mdot
.09318 .5502 Mdot
.52347 .65623 Mdot
.78986 .53238 Mdot
.35734 .40039 Mdot
.51715 .42833 Mdot
.47584 .53965 Mdot
.42859 .52059 Mdot
.54722 .65068 Mdot
.5976 .3968 Mdot
.27181 .4093 Mdot
.55011 .68884 Mdot
.54965 .34373 Mdot
.53147 .63614 Mdot
.44112 .61353 Mdot
.52864 .64437 Mdot
.34735 .36346 Mdot
.5265 .42223 Mdot
.08733 .4847 Mdot
.32914 .58073 Mdot
.58077 .41685 Mdot
.37937 .60437 Mdot
.78436 .61728 Mdot
.56826 .36091 Mdot
.69532 .5261 Mdot
.58114 .6457 Mdot
.706 .65783 Mdot
.5666 .41906 Mdot
.54164 .65689 Mdot
.31513 .3763 Mdot
.44483 .65354 Mdot
.37221 .66458 Mdot
.28306 .6041 Mdot
.36907 .39216 Mdot
.24214 .59794 Mdot
.45989 .62356 Mdot
.52243 .38587 Mdot
.60644 .38162 Mdot
.33521 .38135 Mdot
.35398 .68715 Mdot
.5128 .40529 Mdot
.59525 .39833 Mdot
.53878 .68315 Mdot
.5766 .62903 Mdot
.27725 .68856 Mdot
.56869 .68129 Mdot
.56297 .46085 Mdot
.33301 .38366 Mdot
.53234 .40273 Mdot
.34226 .3748 Mdot
.53761 .36685 Mdot
.31992 .33821 Mdot
.379 .39396 Mdot
.25048 .40706 Mdot
.57236 .43563 Mdot
.66629 .38406 Mdot
.56552 .35573 Mdot
.54544 .37155 Mdot
.57818 .64144 Mdot
.69993 .5461 Mdot
.54685 .34229 Mdot
.52635 .5599 Mdot
.721 .56959 Mdot
.51596 .30262 Mdot
.54968 .63513 Mdot
.71066 .56748 Mdot
.7036 .43866 Mdot
.27832 .58779 Mdot
.71447 .54676 Mdot
.27862 .7181 Mdot
.40135 .61229 Mdot
.3798 .42399 Mdot
.56563 .42738 Mdot
.66516 .78455 Mdot
.66823 .6056 Mdot
.271 .60739 Mdot
.57266 .41684 Mdot
.57359 .36976 Mdot
.38005 .43443 Mdot
.3604 .18425 Mdot
.4984 .63759 Mdot
.53341 .38436 Mdot
.39355 .40284 Mdot
.43731 .15831 Mdot
.52365 .63819 Mdot
.71954 .54732 Mdot
.39134 .58255 Mdot
.4183 .42023 Mdot
.2817 .6082 Mdot
.44727 .60164 Mdot
.59703 .69222 Mdot
.58993 .2146 Mdot
.56356 .41412 Mdot
.57362 .65594 Mdot
.67168 .27414 Mdot
.62468 .35103 Mdot
.3885 .64111 Mdot
.42935 .37532 Mdot
.3548 .41991 Mdot
.38827 .58913 Mdot
.73102 .54101 Mdot
.37537 .42452 Mdot
.34072 .40152 Mdot
.40841 .63485 Mdot
.47251 .57552 Mdot
.46816 .52447 Mdot
.38293 .60236 Mdot
.35736 .50494 Mdot
.69269 .30905 Mdot
.25801 .60196 Mdot
.72558 .54533 Mdot
.76584 .34522 Mdot
.35722 .41245 Mdot
.3495 .79346 Mdot
.64201 .24843 Mdot
.54368 .37105 Mdot
.69164 .55295 Mdot
.42838 .76514 Mdot
.60331 .64287 Mdot
.40791 .62778 Mdot
.58922 .53936 Mdot
.70762 .5225 Mdot
.6032 .36414 Mdot
.33812 .33041 Mdot
.57807 .43135 Mdot
.41937 .62786 Mdot
.36328 .4779 Mdot
.3294 .40464 Mdot
.46071 .62223 Mdot
.39738 .47393 Mdot
.53282 .42917 Mdot
.59546 .41469 Mdot
.77338 .39761 Mdot
.3362 .41588 Mdot
.28318 .6068 Mdot
.58837 .40775 Mdot
.55974 .37402 Mdot
.52099 .3835 Mdot
.66599 .42706 Mdot
.28778 .49822 Mdot
.53269 .38331 Mdot
.53458 .62568 Mdot
.5908 .44475 Mdot
.59293 .41919 Mdot
.38765 .42582 Mdot
.70632 .26741 Mdot
.26063 .58931 Mdot
.55817 .38284 Mdot
.54479 .38362 Mdot
.44161 .6297 Mdot
.47173 .5302 Mdot
.41872 .51815 Mdot
.5185 .66502 Mdot
.77585 .47342 Mdot
.63046 .4194 Mdot
.3606 .38121 Mdot
.68032 .53647 Mdot
.52761 .43654 Mdot
.37152 .38125 Mdot
.61677 .42171 Mdot
.56099 .69034 Mdot
.25965 .60509 Mdot
.56378 .49305 Mdot
.71055 .543 Mdot
.44849 .57033 Mdot
.2112 .56637 Mdot
.57004 .68327 Mdot
.54085 .4203 Mdot
.47285 .6359 Mdot
.54149 .6774 Mdot
.27486 .60291 Mdot
.55582 .32579 Mdot
.36597 .40304 Mdot
.33146 .40581 Mdot
.71043 .32601 Mdot
.50501 .62772 Mdot
.60546 .18223 Mdot
.44012 .61508 Mdot
.59442 .34383 Mdot
.22189 .60756 Mdot
.32679 .39686 Mdot
.77055 .36898 Mdot
.71434 .56755 Mdot
.40719 .62731 Mdot
.27309 .58142 Mdot
.36814 .37929 Mdot
.3221 .39524 Mdot
.54096 .3676 Mdot
.58677 .37968 Mdot
.7959 .49915 Mdot
.73314 .33554 Mdot
.44231 .60749 Mdot
.71955 .53857 Mdot
.51066 .65315 Mdot
.53609 .4299 Mdot
.38626 .40921 Mdot
.42283 .35003 Mdot
.59661 .36507 Mdot
.54802 .68864 Mdot
.36334 .42083 Mdot
.71084 .53332 Mdot
.68999 .55789 Mdot
.5458 .3701 Mdot
.50442 .29297 Mdot
.41424 .61273 Mdot
.32845 .38273 Mdot
.31978 .4391 Mdot
.51539 .38129 Mdot
.59061 .38097 Mdot
.652 .38441 Mdot
.4485 .60336 Mdot
.54693 .48833 Mdot
.72087 .52226 Mdot
.3734 .40418 Mdot
.58229 .41407 Mdot
.71296 .54056 Mdot
.62928 .47137 Mdot
.26194 .61278 Mdot
.52916 .63733 Mdot
.70079 .5258 Mdot
.69418 .54214 Mdot
.71252 .57178 Mdot
.33555 .78424 Mdot
.39317 .43167 Mdot
.35992 .2283 Mdot
.54947 .36131 Mdot
.69638 .3193 Mdot
.57337 .44267 Mdot
.43852 .59065 Mdot
.57858 .6668 Mdot
.57239 .35703 Mdot
.54088 .36708 Mdot
.34868 .33289 Mdot
.63492 .3288 Mdot
.41809 .44409 Mdot
.34575 .42245 Mdot
.6692 .38874 Mdot
.56534 .64017 Mdot
.43551 .14422 Mdot
.3302 .80306 Mdot
.61521 .43954 Mdot
.44286 .52971 Mdot
.3852 .40005 Mdot
.42374 .63147 Mdot
.43653 .51663 Mdot
.41081 .57099 Mdot
.37491 .40815 Mdot
.53199 .42117 Mdot
.19717 .54157 Mdot
.7183 .57558 Mdot
.59189 .3668 Mdot
.43364 .60298 Mdot
.5912 .36561 Mdot
.42696 .58432 Mdot
.42451 .404 Mdot
.36277 .51698 Mdot
.55651 .41704 Mdot
.51477 .39947 Mdot
.50252 .4698 Mdot
.5904 .37785 Mdot
.44766 .73233 Mdot
.34796 .39553 Mdot
.26299 .38334 Mdot
.58475 .34851 Mdot
.50165 .27712 Mdot
.60197 .36742 Mdot
.35858 .69505 Mdot
.60617 .39416 Mdot
.58992 .51112 Mdot
.60331 .36248 Mdot
.60343 .39485 Mdot
.40709 .59766 Mdot
.43648 .63097 Mdot
.31571 .37674 Mdot
.27499 .6166 Mdot
.51624 .81459 Mdot
.57258 .38096 Mdot
.57072 .63186 Mdot
.22872 .59921 Mdot
.69617 .54409 Mdot
.37125 .40963 Mdot
.52349 .13081 Mdot
.44025 .60008 Mdot
.50506 .66448 Mdot
.39177 .70139 Mdot
.50786 .63535 Mdot
.49235 .66017 Mdot
.666 .37 Mdot
.72029 .53657 Mdot
.60392 .3684 Mdot
.54498 .27865 Mdot
.25793 .51675 Mdot
.55266 .34432 Mdot
.45077 .64482 Mdot
.60781 .30931 Mdot
.69326 .30576 Mdot
.73598 .56976 Mdot
.7188 .53018 Mdot
.41159 .59298 Mdot
.51439 .66991 Mdot
.63649 .38773 Mdot
.70828 .56747 Mdot
.58151 .66674 Mdot
.25709 .62042 Mdot
.66769 .57324 Mdot
.35893 .41012 Mdot
.50315 .48234 Mdot
.26047 .55546 Mdot
.44119 .60488 Mdot
.52642 .55692 Mdot
.39692 .37451 Mdot
.35429 .44013 Mdot
.2599 .61881 Mdot
.58687 .65598 Mdot
.39696 .3909 Mdot
.5258 .3877 Mdot
.50289 .37148 Mdot
.56992 .39459 Mdot
.70584 .56456 Mdot
.60834 .39998 Mdot
.58493 .66758 Mdot
.42776 .62152 Mdot
.55319 .67011 Mdot
.4129 .61511 Mdot
.19573 .51768 Mdot
.56566 .40625 Mdot
.58922 .38376 Mdot
.51532 .53884 Mdot
.31813 .39072 Mdot
.55958 .2556 Mdot
.58666 .64864 Mdot
.55363 .64531 Mdot
.53127 .40377 Mdot
.31273 .38227 Mdot
.68191 .5663 Mdot
.47617 .54709 Mdot
.60764 .39091 Mdot
.34856 .3945 Mdot
.53533 .39753 Mdot
.64755 .71993 Mdot
.34087 .53976 Mdot
.33187 .40288 Mdot
.28525 .27848 Mdot
.56199 .43688 Mdot
.55659 .3032 Mdot
.53767 .46224 Mdot
.75341 .50078 Mdot
.52306 .36129 Mdot
.38539 .39373 Mdot
.56251 .39173 Mdot
.36284 .38558 Mdot
.55136 .68357 Mdot
.44464 .62292 Mdot
.36455 .39172 Mdot
.59059 .42877 Mdot
.2856 .75876 Mdot
.43811 .60577 Mdot
.5968 .38794 Mdot
.39309 .59625 Mdot
.39253 .40981 Mdot
.32213 .40349 Mdot
.28899 .71965 Mdot
.34958 .60906 Mdot
.43667 .60217 Mdot
.53976 .40586 Mdot
.30126 .56959 Mdot
.53267 .40292 Mdot
.79766 .49069 Mdot
.57764 .34375 Mdot
.52759 .36305 Mdot
.17381 .56455 Mdot
.41694 .56891 Mdot
.56818 .16011 Mdot
.58734 .62043 Mdot
.31856 .77185 Mdot
.40726 .40678 Mdot
.73592 .56998 Mdot
.55904 .76868 Mdot
.26618 .58929 Mdot
.54869 .62906 Mdot
.57323 .35678 Mdot
.31859 .33621 Mdot
.38268 .59906 Mdot
.70227 .55182 Mdot
.55685 .41803 Mdot
.54906 .69286 Mdot
.2576 .69898 Mdot
.41984 .6296 Mdot
.36123 .41165 Mdot
.31686 .38895 Mdot
.38877 .19092 Mdot
.57905 .4151 Mdot
.58486 .3857 Mdot
.38265 .61784 Mdot
.63198 .39685 Mdot
.69942 .57056 Mdot
.69184 .69679 Mdot
.43089 .59797 Mdot
.32453 .58653 Mdot
.35164 .42555 Mdot
.57525 .37078 Mdot
.5899 .55963 Mdot
.36372 .7638 Mdot
.38999 .238 Mdot
.72269 .56087 Mdot
.78202 .44477 Mdot
.38516 .3934 Mdot
.43185 .60507 Mdot
.69513 .3712 Mdot
.62271 .38074 Mdot
.56953 .3698 Mdot
.77953 .43491 Mdot
.46828 .53479 Mdot
.67604 .51572 Mdot
.51973 .43803 Mdot
.48387 .53089 Mdot
.53055 .40594 Mdot
.52575 .40194 Mdot
.61819 .43733 Mdot
.60085 .41497 Mdot
.35354 .39029 Mdot
.33174 .32199 Mdot
.5341 .65376 Mdot
.48624 .206 Mdot
.59654 .53163 Mdot
.57393 .42737 Mdot
.53184 .4242 Mdot
.29626 .3156 Mdot
.23985 .58605 Mdot
.34969 .39907 Mdot
.29728 .37984 Mdot
.45238 .61441 Mdot
.6402 .33499 Mdot
.51544 .62377 Mdot
.44766 .40656 Mdot
.54427 .67446 Mdot
.34832 .39337 Mdot
.55697 .64245 Mdot
.45464 .61875 Mdot
.5734 .65672 Mdot
.54276 .62321 Mdot
.4137 .57654 Mdot
.34297 .42415 Mdot
.60381 .38433 Mdot
.44594 .60664 Mdot
.77911 .40648 Mdot
.70452 .5643 Mdot
.28705 .71911 Mdot
.52627 .44558 Mdot
.48547 .34444 Mdot
.77002 .61456 Mdot
.56168 .66138 Mdot
.32768 .53547 Mdot
.37876 .39389 Mdot
.67606 .54311 Mdot
.35756 .38788 Mdot
.60652 .23908 Mdot
.70196 .53648 Mdot
.28668 .72083 Mdot
.69495 .38864 Mdot
.59902 .58627 Mdot
.60814 .42006 Mdot
.32564 .34307 Mdot
.54739 .6767 Mdot
.37955 .61278 Mdot
.45743 .78105 Mdot
.56 .44379 Mdot
.25112 .47497 Mdot
.38198 .43837 Mdot
.28147 .59056 Mdot
.43102 .60956 Mdot
.4456 .64398 Mdot
.57515 .41367 Mdot
.5925 .5765 Mdot
.54795 .34901 Mdot
.6805 .36023 Mdot
.78532 .47187 Mdot
.43563 .38814 Mdot
.53922 .39712 Mdot
.52626 .67256 Mdot
.53629 .39979 Mdot
.51042 .33568 Mdot
.68435 .29393 Mdot
.53348 .44853 Mdot
.24007 .42984 Mdot
.72508 .64418 Mdot
.37544 .41943 Mdot
.56588 .46226 Mdot
.26803 .60172 Mdot
.54962 .43662 Mdot
.7565 .74333 Mdot
.71126 .5476 Mdot
.60699 .67489 Mdot
.59571 .42721 Mdot
.58486 .40886 Mdot
.47326 .32756 Mdot
.38263 .3532 Mdot
.27133 .58277 Mdot
.5647 .36781 Mdot
.76639 .44455 Mdot
.40335 .59493 Mdot
.59924 .35092 Mdot
.56373 .3888 Mdot
.79189 .38306 Mdot
.3978 .59632 Mdot
.56627 .65673 Mdot
.27628 .58741 Mdot
.51204 .65267 Mdot
.73789 .57164 Mdot
.41447 .50893 Mdot
.75471 .35021 Mdot
.33917 .5422 Mdot
.69643 .52415 Mdot
.61199 .40592 Mdot
.54693 .30137 Mdot
.59317 .41183 Mdot
.72349 .53426 Mdot
.4019 .58914 Mdot
.35558 .39237 Mdot
.54371 .49698 Mdot
.27588 .59678 Mdot
.54073 .35066 Mdot
.73648 .56559 Mdot
.36528 .39752 Mdot
.30499 .70892 Mdot
.37955 .40393 Mdot
.41188 .60461 Mdot
.45376 .60795 Mdot
.70253 .54026 Mdot
.35503 .38832 Mdot
.52104 .63519 Mdot
.57422 .61421 Mdot
.56925 .3438 Mdot
.383 .64445 Mdot
.35279 .36632 Mdot
.31514 .40556 Mdot
.37902 .37512 Mdot
.56461 .40971 Mdot
.46025 .53049 Mdot
.62489 .38362 Mdot
.42992 .59276 Mdot
.54362 .63133 Mdot
.7249 .33015 Mdot
.54103 .27646 Mdot
.32941 .57708 Mdot
.5409 .34687 Mdot
.59803 .41451 Mdot
.57061 .39141 Mdot
.54323 .38915 Mdot
.67402 .71099 Mdot
.56548 .40448 Mdot
.40683 .60796 Mdot
.53238 .66571 Mdot
.57542 .4182 Mdot
.26481 .60133 Mdot
.51401 .51919 Mdot
.68175 .53396 Mdot
.59249 .51346 Mdot
.3306 .79526 Mdot
.36369 .39735 Mdot
.56943 .67163 Mdot
.53371 .63134 Mdot
.69469 .56462 Mdot
.44034 .61734 Mdot
.37802 .39915 Mdot
.72502 .4858 Mdot
.72473 .56905 Mdot
.55741 .38233 Mdot
.54724 .54917 Mdot
.2672 .29471 Mdot
.61589 .40051 Mdot
.55337 .36413 Mdot
.28569 .59084 Mdot
.50135 .63934 Mdot
.65271 .80814 Mdot
.44301 .54383 Mdot
.70064 .54433 Mdot
.70156 .52995 Mdot
.38725 .38316 Mdot
.57638 .33661 Mdot
.41797 .61687 Mdot
.48204 .54064 Mdot
.79466 .59734 Mdot
.45451 .79479 Mdot
.45155 .68596 Mdot
.58204 .35348 Mdot
.42686 .33072 Mdot
.54087 .35951 Mdot
.37344 .43828 Mdot
.37878 .37902 Mdot
.35215 .40369 Mdot
.40919 .59716 Mdot
.52529 .1813 Mdot
.40719 .61082 Mdot
.33282 .7981 Mdot
.38786 .41087 Mdot
.62809 .6125 Mdot
.54754 .64045 Mdot
.59197 .33003 Mdot
.72211 .53915 Mdot
.41178 .65864 Mdot
.57562 .46113 Mdot
.27634 .47589 Mdot
.57058 .64725 Mdot
.32652 .41066 Mdot
.50015 .35458 Mdot
.54156 .81702 Mdot
.39492 .51772 Mdot
.75029 .59607 Mdot
.59857 .24718 Mdot
.70483 .53437 Mdot
.3509 .25848 Mdot
.71049 .57433 Mdot
.41173 .62876 Mdot
.56212 .44351 Mdot
.58073 .43449 Mdot
.53599 .38306 Mdot
.56251 .40356 Mdot
.40986 .59089 Mdot
.5684 .34926 Mdot
.73012 .30093 Mdot
.25757 .59612 Mdot
.62793 .64406 Mdot
.68532 .54492 Mdot
.42973 .58261 Mdot
.53595 .67196 Mdot
.27022 .61943 Mdot
.81056 .45052 Mdot
.5707 .35074 Mdot
.56911 .35586 Mdot
.25062 .60853 Mdot
.62975 .40046 Mdot
.49437 .36826 Mdot
.5373 .65719 Mdot
.42391 .48227 Mdot
.72712 .53328 Mdot
.68835 .53009 Mdot
.40179 .58157 Mdot
.35728 .38766 Mdot
.72118 .5647 Mdot
.52095 .67605 Mdot
.60708 .36211 Mdot
.5167 .40998 Mdot
.35076 .36616 Mdot
.64213 .2484 Mdot
.72233 .57893 Mdot
.47838 .39623 Mdot
.37022 .38496 Mdot
.38501 .43674 Mdot
.56712 .36649 Mdot
.51498 .36589 Mdot
.32894 .41988 Mdot
.68356 .54456 Mdot
.42535 .58033 Mdot
.62056 .59717 Mdot
.42598 .62451 Mdot
.37244 .39573 Mdot
.62255 .40387 Mdot
.34606 .42484 Mdot
.55972 .43608 Mdot
.28472 .20496 Mdot
.60514 .40844 Mdot
.27527 .3787 Mdot
.76188 .50396 Mdot
.52668 .63646 Mdot
.51724 .64088 Mdot
.26141 .60329 Mdot
.37786 .38856 Mdot
.52794 .4355 Mdot
.70957 .52957 Mdot
.30198 .75652 Mdot
.33249 .44094 Mdot
.57644 .64433 Mdot
.50766 .63041 Mdot
.40615 .58895 Mdot
.60542 .374 Mdot
.5761 .37433 Mdot
.57239 .65669 Mdot
.76338 .6342 Mdot
.35345 .38091 Mdot
.58493 .38611 Mdot
.59411 .41909 Mdot
.53176 .65484 Mdot
.57741 .61428 Mdot
.38024 .35576 Mdot
.6 .41538 Mdot
.69623 .40063 Mdot
.43133 .58756 Mdot
.54735 .40297 Mdot
.56075 .35152 Mdot
.69527 .55083 Mdot
.62947 .67217 Mdot
.68988 .30222 Mdot
.44533 .59339 Mdot
.28435 .60218 Mdot
.56844 .44339 Mdot
.54527 .64162 Mdot
.5173 .42762 Mdot
.62685 .77282 Mdot
.2631 .59206 Mdot
.57495 .40335 Mdot
.62446 .42589 Mdot
.3279 .37964 Mdot
.57766 .40556 Mdot
.38123 .34477 Mdot
.51978 .66112 Mdot
.57418 .40448 Mdot
.51065 .28658 Mdot
.40991 .58867 Mdot
.57472 .46037 Mdot
.70397 .52697 Mdot
.75932 .50851 Mdot
.22631 .56452 Mdot
.55416 .6232 Mdot
.68848 .55442 Mdot
.60896 .39734 Mdot
.53277 .68085 Mdot
.39002 .58326 Mdot
.25796 .46748 Mdot
.61633 .38834 Mdot
.43479 .61914 Mdot
.43112 .6182 Mdot
.7048 .54344 Mdot
.5169 .14326 Mdot
.6276 .42205 Mdot
.59557 .37901 Mdot
.83276 .52898 Mdot
.39848 .40493 Mdot
.59796 .37921 Mdot
.6056 .37707 Mdot
.41099 .62203 Mdot
.67712 .41766 Mdot
.34494 .45912 Mdot
.72576 .6683 Mdot
.42937 .58533 Mdot
.59284 .66788 Mdot
.53894 .68182 Mdot
.6866 .54939 Mdot
.37311 .41922 Mdot
.70661 .52099 Mdot
.53382 .64437 Mdot
.54439 .37285 Mdot
.39851 .6238 Mdot
.4344 .23839 Mdot
.38043 .62135 Mdot
.54127 .68899 Mdot
.34446 .43147 Mdot
.21865 .6088 Mdot
.86192 .52908 Mdot
.25215 .54888 Mdot
.43709 .58413 Mdot
.69598 .54447 Mdot
.45612 .55173 Mdot
.59813 .41381 Mdot
.35543 .24465 Mdot
.59491 .37235 Mdot
.60411 .24759 Mdot
.5798 .66588 Mdot
.25532 .61725 Mdot
.55914 .44435 Mdot
.77844 .44564 Mdot
.43734 .5853 Mdot
.41119 .58679 Mdot
.55057 .38582 Mdot
.41183 .607 Mdot
.58009 .3792 Mdot
.52786 .6573 Mdot
.52952 .14897 Mdot
.60257 .40186 Mdot
.55357 .45674 Mdot
.45908 .60802 Mdot
.28635 .71928 Mdot
.58947 .67132 Mdot
.43576 .33308 Mdot
.55908 .81706 Mdot
.41473 .60921 Mdot
.52667 .45885 Mdot
.56438 .66566 Mdot
.2869 .59277 Mdot
.51898 .68717 Mdot
.58733 .36704 Mdot
.56687 .35356 Mdot
.53104 .39528 Mdot
.59382 .41691 Mdot
.33813 .25931 Mdot
.5296 .33156 Mdot
.41243 .30393 Mdot
.5645 .35657 Mdot
.28641 .37399 Mdot
.40396 .60426 Mdot
.42235 .43446 Mdot
.6898 .5112 Mdot
.56431 .35321 Mdot
.37417 .34964 Mdot
.43486 .58569 Mdot
.35206 .80469 Mdot
.40143 .59267 Mdot
.55412 .66407 Mdot
.41613 .63294 Mdot
.56216 .43467 Mdot
.36167 .41588 Mdot
.52454 .66316 Mdot
.2089 .47655 Mdot
.55564 .63048 Mdot
.58031 .41681 Mdot
.6039 .61825 Mdot
.52924 .63492 Mdot
.54492 .51805 Mdot
.36517 .41712 Mdot
.75813 .42912 Mdot
.39718 .40993 Mdot
.58232 .40202 Mdot
.58774 .39929 Mdot
.2727 .61929 Mdot
.4209 .62957 Mdot
.39162 .40788 Mdot
.74082 .27876 Mdot
.74073 .55264 Mdot
.34673 .407 Mdot
.52466 .35276 Mdot
.45443 .53435 Mdot
.3279 .38688 Mdot
.75696 .46915 Mdot
.42148 .62814 Mdot
.39147 .38418 Mdot
.56058 .3271 Mdot
.61897 .49064 Mdot
.69231 .5689 Mdot
.56456 .69007 Mdot
.48596 .50924 Mdot
.53328 .67753 Mdot
.46223 .62449 Mdot
.49357 .6377 Mdot
.4016 .59824 Mdot
.27374 .36161 Mdot
.36646 .47639 Mdot
.46997 .61611 Mdot
.45833 .61579 Mdot
.54004 .64838 Mdot
.54373 .38719 Mdot
.61722 .54828 Mdot
.53359 .34539 Mdot
.60854 .42459 Mdot
.43956 .59445 Mdot
.38704 .39273 Mdot
.36338 .42943 Mdot
.31806 .34832 Mdot
.32048 .39809 Mdot
.53226 .67177 Mdot
.33861 .53046 Mdot
.59295 .23397 Mdot
.39025 .59599 Mdot
.37044 .58211 Mdot
.53244 .40827 Mdot
.54232 .64361 Mdot
.55615 .68515 Mdot
.41947 .62098 Mdot
.42568 .21744 Mdot
.57827 .45484 Mdot
.38889 .42694 Mdot
.38752 .41192 Mdot
.32919 .38888 Mdot
.35102 .37002 Mdot
.48172 .17707 Mdot
.37952 .61299 Mdot
.38445 .39525 Mdot
.55737 .39521 Mdot
.58298 .35622 Mdot
.28195 .59925 Mdot
.68909 .53537 Mdot
.56921 .44801 Mdot
.56925 .45149 Mdot
.56918 .36651 Mdot
.52973 .63601 Mdot
.628 .34008 Mdot
.26767 .59185 Mdot
.49666 .63602 Mdot
.52569 .62268 Mdot
.26132 .61729 Mdot
.37206 .45221 Mdot
.52961 .82923 Mdot
.5334 .38503 Mdot
.63685 .31168 Mdot
.54754 .64578 Mdot
.32688 .48459 Mdot
.54565 .48544 Mdot
.54158 .4019 Mdot
.64066 .52949 Mdot
.52536 .65824 Mdot
.36019 .44436 Mdot
.59108 .37373 Mdot
.25415 .60699 Mdot
.6802 .54154 Mdot
.55331 .33081 Mdot
.28551 .58968 Mdot
.34729 .39158 Mdot
.73339 .62518 Mdot
.39868 .39581 Mdot
.52491 .63523 Mdot
.56983 .46219 Mdot
.08492 .5315 Mdot
.54914 .6776 Mdot
.37853 .79459 Mdot
.38209 .47734 Mdot
.60266 .40593 Mdot
.53756 .67909 Mdot
.36063 .4431 Mdot
.43229 .58834 Mdot
.50216 .52823 Mdot
.38552 .41023 Mdot
.2659 .62011 Mdot
.27853 .6097 Mdot
.53369 .65476 Mdot
.35052 .42182 Mdot
.578 .34584 Mdot
.35054 .37367 Mdot
.40792 .63375 Mdot
.55212 .42307 Mdot
.51843 .81552 Mdot
.50198 .37336 Mdot
.37044 .38385 Mdot
.52686 .68218 Mdot
.73363 .55747 Mdot
.55699 .41578 Mdot
.43891 .81304 Mdot
.60673 .37711 Mdot
.39626 .59253 Mdot
.30467 .46382 Mdot
.41766 .24535 Mdot
.54385 .38082 Mdot
.53091 .41627 Mdot
.40294 .58003 Mdot
.54297 .37901 Mdot
.61462 .3927 Mdot
.39897 .64534 Mdot
.32412 .38737 Mdot
.57369 .39554 Mdot
.56584 .68677 Mdot
.61075 .26702 Mdot
.55168 .44751 Mdot
.22823 .4245 Mdot
.76798 .43638 Mdot
.30951 .46079 Mdot
.53158 .44204 Mdot
.78198 .40386 Mdot
.5904 .39448 Mdot
.55914 .40959 Mdot
.53538 .38982 Mdot
.40596 .32763 Mdot
.5375 .64504 Mdot
.58331 .65384 Mdot
.68144 .5592 Mdot
.77071 .44359 Mdot
.69451 .55563 Mdot
.41544 .57839 Mdot
.34955 .66612 Mdot
.25883 .59594 Mdot
.3594 .38689 Mdot
.52543 .41622 Mdot
.54604 .62674 Mdot
.57828 .36936 Mdot
.54812 .43491 Mdot
.52368 .65015 Mdot
.54303 .68031 Mdot
.50049 .62689 Mdot
.72098 .57275 Mdot
.35584 .39771 Mdot
.54041 .37135 Mdot
.72226 .56898 Mdot
.58923 .34774 Mdot
.45734 .54007 Mdot
.35328 .39878 Mdot
.34724 .37349 Mdot
.37854 .42864 Mdot
.55109 .36003 Mdot
.56524 .43241 Mdot
.40776 .61233 Mdot
.35621 .36601 Mdot
.38713 .59726 Mdot
.53526 .67738 Mdot
.51941 .64081 Mdot
.58721 .36656 Mdot
.48651 .37483 Mdot
.69745 .5326 Mdot
.55801 .66179 Mdot
.24905 .59877 Mdot
.6805 .55699 Mdot
.5719 .41653 Mdot
.53181 .67515 Mdot
.69027 .52853 Mdot
.47562 .21534 Mdot
.59315 .81388 Mdot
.73383 .56324 Mdot
.5515 .38613 Mdot
.48891 .31404 Mdot
.7014 .3609 Mdot
.73936 .54526 Mdot
.38892 .60631 Mdot
.60198 .37159 Mdot
.77459 .63582 Mdot
.71942 .52515 Mdot
.64773 .25332 Mdot
.5247 .64579 Mdot
.67469 .37687 Mdot
.54893 .3313 Mdot
.40437 .21224 Mdot
.71284 .52165 Mdot
.37536 .40049 Mdot
.38001 .36911 Mdot
.55333 .38155 Mdot
.72682 .52235 Mdot
.4028 .63581 Mdot
.53202 .63116 Mdot
.55449 .62576 Mdot
.34589 .41936 Mdot
.33516 .55899 Mdot
.55769 .68813 Mdot
.57245 .46541 Mdot
.55723 .70071 Mdot
.65733 .36734 Mdot
.4139 .18743 Mdot
.20054 .49123 Mdot
.51799 .40287 Mdot
.7356 .55451 Mdot
.40057 .57591 Mdot
.40931 .61066 Mdot
.41217 .59858 Mdot
.51481 .64761 Mdot
.45722 .51803 Mdot
.5758 .65502 Mdot
.25486 .48781 Mdot
.71399 .54085 Mdot
.74375 .42269 Mdot
.53346 .44049 Mdot
.60126 .40793 Mdot
.60426 .35672 Mdot
.53007 .39612 Mdot
.58987 .39313 Mdot
.44124 .60648 Mdot
.51102 .63827 Mdot
.71014 .66014 Mdot
.33323 .3932 Mdot
.29798 .68673 Mdot
.54805 .6403 Mdot
.28085 .58744 Mdot
.71209 .55588 Mdot
.75309 .35428 Mdot
.59738 .65876 Mdot
.55644 .64289 Mdot
.61636 .38119 Mdot
.38258 .3855 Mdot
.6603 .44091 Mdot
.59548 .3981 Mdot
.55951 .66133 Mdot
.51539 .67662 Mdot
.36436 .25469 Mdot
.63118 .43339 Mdot
.69493 .57806 Mdot
.45196 .53258 Mdot
.71229 .51926 Mdot
.50951 .37613 Mdot
.32598 .48637 Mdot
.53467 .64632 Mdot
.54796 .66531 Mdot
.73824 .55824 Mdot
.5258 .31715 Mdot
.36181 .42262 Mdot
.2538 .61631 Mdot
.39225 .60503 Mdot
.59453 .40536 Mdot
.51508 .65278 Mdot
.624 .30873 Mdot
.54091 .54958 Mdot
.42496 .59632 Mdot
.49763 .63634 Mdot
.60026 .36514 Mdot
.5492 .38019 Mdot
.70126 .53508 Mdot
.64756 .58984 Mdot
.53666 .34048 Mdot
.31955 .77263 Mdot
.37184 .50999 Mdot
.44816 .44981 Mdot
.5697 .37012 Mdot
.33528 .4134 Mdot
.25599 .60974 Mdot
.7264 .54616 Mdot
.59483 .35265 Mdot
.56841 .82441 Mdot
.34664 .36036 Mdot
.43635 .60747 Mdot
.25501 .61046 Mdot
.46514 .51795 Mdot
.60753 .37884 Mdot
.59478 .37248 Mdot
.5637 .40685 Mdot
.58527 .82655 Mdot
.58231 .66293 Mdot
.37005 .37101 Mdot
.72082 .56207 Mdot
.32407 .37887 Mdot
.58039 .64685 Mdot
.49857 .49588 Mdot
.57252 .41984 Mdot
.3816 .4314 Mdot
.37672 .4033 Mdot
.40663 .58845 Mdot
.44649 .5998 Mdot
.5747 .62439 Mdot
.60592 .40501 Mdot
.25365 .60231 Mdot
.39164 .39185 Mdot
.50196 .64746 Mdot
.70321 .53563 Mdot
.44938 .60952 Mdot
.56143 .35705 Mdot
.53518 .65165 Mdot
.53135 .36422 Mdot
.34102 .37646 Mdot
.55486 .64251 Mdot
.28026 .58469 Mdot
.69575 .53193 Mdot
.56354 .35496 Mdot
.74956 .62335 Mdot
.25506 .61419 Mdot
.5815 .43099 Mdot
.49993 .31911 Mdot
.71448 .51163 Mdot
.20879 .47111 Mdot
.57456 .6703 Mdot
.26712 .59607 Mdot
.37758 .37679 Mdot
.62998 .48001 Mdot
.5441 .66811 Mdot
.43644 .36259 Mdot
.62648 .56561 Mdot
.53999 .37543 Mdot
.3469 .41254 Mdot
.662 .54208 Mdot
.35136 .79747 Mdot
.70508 .3826 Mdot
.5811 .38867 Mdot
.53396 .67831 Mdot
.68677 .53084 Mdot
.39342 .5909 Mdot
.22941 .42427 Mdot
.40858 .19331 Mdot
.50161 .63201 Mdot
.53396 .3752 Mdot
.39046 .3908 Mdot
.42233 .62002 Mdot
.19283 .53455 Mdot
.52437 .67871 Mdot
.57534 .6763 Mdot
.56491 .41687 Mdot
.72582 .55933 Mdot
.75065 .65577 Mdot
.58414 .66088 Mdot
.51087 .64937 Mdot
.28977 .69012 Mdot
.7258 .57657 Mdot
.55769 .39243 Mdot
.31814 .34818 Mdot
.60869 .36651 Mdot
.33025 .77242 Mdot
.26326 .59608 Mdot
.33418 .3902 Mdot
.58965 .36216 Mdot
.72153 .64709 Mdot
.54156 .67328 Mdot
.44238 .52887 Mdot
.48883 .61481 Mdot
.44311 .61285 Mdot
.51636 .65347 Mdot
.58575 .37301 Mdot
.45368 .60248 Mdot
.69516 .53411 Mdot
.60048 .41494 Mdot
.56126 .43322 Mdot
.36498 .44166 Mdot
.40021 .62832 Mdot
.62509 .28211 Mdot
.43171 .63572 Mdot
.39526 .5837 Mdot
.39379 .43321 Mdot
.55511 .38166 Mdot
.55836 .65594 Mdot
.55741 .69298 Mdot
.56604 .3484 Mdot
.3322 .48663 Mdot
.3563 .42114 Mdot
.60396 .68955 Mdot
.65316 .80521 Mdot
.63344 .41704 Mdot
.25355 .59373 Mdot
.65913 .30699 Mdot
.41628 .58487 Mdot
.54839 .37053 Mdot
.36115 .38301 Mdot
.50701 .64599 Mdot
.55761 .68914 Mdot
.61664 .37278 Mdot
.42363 .62254 Mdot
.68515 .52896 Mdot
.56576 .68184 Mdot
.53359 .54918 Mdot
.57443 .40809 Mdot
.24935 .47271 Mdot
.56726 .67768 Mdot
.23569 .70326 Mdot
.71565 .65273 Mdot
.33415 .40479 Mdot
.54049 .43005 Mdot
.31518 .38254 Mdot
.7156 .56355 Mdot
.5097 .67991 Mdot
.42358 .62368 Mdot
.47334 .43203 Mdot
.78491 .35437 Mdot
.5386 .64148 Mdot
.35226 .39139 Mdot
.54651 .36544 Mdot
.48634 .4446 Mdot
.60669 .39267 Mdot
.66926 .44913 Mdot
.76334 .57379 Mdot
.45604 .61608 Mdot
.40084 .58648 Mdot
.53265 .42848 Mdot
.70905 .57309 Mdot
.58005 .68175 Mdot
.52509 .64824 Mdot
.43334 .13971 Mdot
.28347 .58541 Mdot
.79149 .51199 Mdot
.555 .35845 Mdot
.50429 .64071 Mdot
.54779 .27346 Mdot
.38263 .61746 Mdot
.57113 .33994 Mdot
.52037 .62812 Mdot
.35239 .75063 Mdot
.46303 .53837 Mdot
.57704 .39925 Mdot
.63261 .39431 Mdot
.39299 .59808 Mdot
.4534 .5495 Mdot
.57471 .65439 Mdot
.58696 .34377 Mdot
.44308 .63768 Mdot
.27862 .70201 Mdot
.76648 .32687 Mdot
.35567 .39817 Mdot
.52415 .6814 Mdot
.44275 .61129 Mdot
.64061 .36267 Mdot
.68493 .54308 Mdot
.51381 .66017 Mdot
.54295 .62956 Mdot
.54673 .42382 Mdot
.56055 .44983 Mdot
.63011 .42727 Mdot
.34161 .39915 Mdot
.40443 .61535 Mdot
.54158 .44156 Mdot
.35162 .53912 Mdot
.53065 .38719 Mdot
.40773 .61792 Mdot
.11989 .39805 Mdot
.61854 .39683 Mdot
.60081 .38332 Mdot
.68162 .49576 Mdot
.36898 .42638 Mdot
.32061 .38782 Mdot
.35048 .52608 Mdot
.5559 .35792 Mdot
.60874 .58594 Mdot
.35821 .39569 Mdot
.35604 .41982 Mdot
.62261 .61458 Mdot
.54919 .41815 Mdot
.44498 .56633 Mdot
.41733 .61822 Mdot
.44458 .60977 Mdot
.33167 .37754 Mdot
.58981 .32964 Mdot
.39288 .58088 Mdot
.31655 .27397 Mdot
.55031 .63848 Mdot
.32527 .4862 Mdot
.35985 .37607 Mdot
.61195 .57045 Mdot
.41717 .62883 Mdot
.2926 .77986 Mdot
.61978 .49765 Mdot
.54757 .35144 Mdot
.54672 .38174 Mdot
.69291 .5471 Mdot
.49592 .43551 Mdot
.28464 .5999 Mdot
.41067 .60521 Mdot
.6281 .73379 Mdot
.35193 .40446 Mdot
.60263 .38756 Mdot
.72781 .33522 Mdot
.20782 .53185 Mdot
.24637 .42645 Mdot
.37776 .4171 Mdot
.35352 .41161 Mdot
.56898 .64292 Mdot
.54155 .63389 Mdot
.56482 .39651 Mdot
.40708 .59968 Mdot
.3911 .379 Mdot
.39807 .61574 Mdot
.53355 .64519 Mdot
.5558 .64566 Mdot
.26802 .59046 Mdot
.61767 .34842 Mdot
.5222 .64256 Mdot
.29602 .71293 Mdot
.3557 .53578 Mdot
.34506 .44047 Mdot
.8579 .52673 Mdot
.18919 .53514 Mdot
.71261 .49517 Mdot
.67952 .54528 Mdot
.29628 .59807 Mdot
.43048 .63119 Mdot
.53093 .42376 Mdot
.57674 .36056 Mdot
.27687 .6064 Mdot
.43828 .62227 Mdot
.70537 .5561 Mdot
.41998 .62998 Mdot
.72365 .54603 Mdot
.58573 .64946 Mdot
.55497 .4473 Mdot
.61082 .38862 Mdot
.43437 .59866 Mdot
.56794 .65488 Mdot
.52582 .63549 Mdot
.68291 .55808 Mdot
.75459 .3627 Mdot
.53296 .65318 Mdot
.35861 .37556 Mdot
.54859 .23658 Mdot
.2782 .60935 Mdot
.59133 .37484 Mdot
.74205 .3418 Mdot
.37153 .24404 Mdot
.53787 .37588 Mdot
.25475 .61118 Mdot
.45401 .13495 Mdot
.56205 .44463 Mdot
.42121 .16197 Mdot
.27145 .59318 Mdot
.35073 .42724 Mdot
.56448 .66894 Mdot
.28438 .60493 Mdot
.63153 .34671 Mdot
.71631 .58848 Mdot
.53393 .4482 Mdot
.38401 .4147 Mdot
.36433 .43399 Mdot
.38789 .48219 Mdot
.33534 .7747 Mdot
.7313 .55098 Mdot
.70506 .55066 Mdot
.54128 .66705 Mdot
.33618 .63099 Mdot
.51224 .38335 Mdot
.70202 .54937 Mdot
.66249 .73087 Mdot
.53336 .40668 Mdot
.79623 .47862 Mdot
.63894 .52843 Mdot
.33831 .41555 Mdot
.38695 .45423 Mdot
.54194 .6707 Mdot
.35234 .39196 Mdot
.46602 .4704 Mdot
.60379 .35659 Mdot
.35218 .40077 Mdot
.40785 .62035 Mdot
.44025 .75421 Mdot
.31804 .398 Mdot
.50671 .53254 Mdot
.41897 .61628 Mdot
.71415 .5122 Mdot
.7096 .44782 Mdot
.73669 .7736 Mdot
.4093 .60379 Mdot
.56247 .66443 Mdot
.52215 .64026 Mdot
.5302 .65606 Mdot
.38563 .4111 Mdot
.54989 .68271 Mdot
.33851 .39123 Mdot
.59096 .62705 Mdot
.77562 .3865 Mdot
.70468 .53902 Mdot
.35615 .62251 Mdot
.36931 .40773 Mdot
.28536 .51522 Mdot
.85169 .49021 Mdot
.55211 .38945 Mdot
.43963 .63573 Mdot
.73706 .55224 Mdot
.28751 .6307 Mdot
.69536 .55179 Mdot
.56514 .66564 Mdot
.32343 .48594 Mdot
.57969 .38019 Mdot
.39546 .34879 Mdot
.70958 .52809 Mdot
.38226 .41405 Mdot
.58857 .42523 Mdot
.55948 .61743 Mdot
.69102 .55626 Mdot
.68068 .54195 Mdot
.5912 .39043 Mdot
.33053 .41351 Mdot
.55896 .64979 Mdot
.44161 .62839 Mdot
.67165 .52271 Mdot
.61358 .33764 Mdot
.54207 .3857 Mdot
.59913 .34547 Mdot
.41687 .52001 Mdot
.76129 .6494 Mdot
.41645 .6102 Mdot
.70342 .34701 Mdot
.5318 .63777 Mdot
.70147 .39189 Mdot
.28946 .53984 Mdot
.3654 .63156 Mdot
.26425 .59515 Mdot
.2613 .59673 Mdot
.58148 .39647 Mdot
.73969 .67942 Mdot
.26184 .3908 Mdot
.39407 .63948 Mdot
.27026 .61478 Mdot
.52652 .63513 Mdot
.35496 .36336 Mdot
.43169 .43111 Mdot
.58217 .44002 Mdot
.4479 .60226 Mdot
.53015 .6483 Mdot
.62967 .77225 Mdot
.71374 .54268 Mdot
.32809 .52052 Mdot
.57646 .41946 Mdot
.58685 .38403 Mdot
.42716 .60915 Mdot
.40845 .61245 Mdot
.23524 .45022 Mdot
.38943 .49014 Mdot
.47489 .79308 Mdot
.43932 .56483 Mdot
.65567 .76294 Mdot
.39957 .37209 Mdot
.36598 .38244 Mdot
.27188 .58787 Mdot
.40096 .57867 Mdot
.59768 .37525 Mdot
.35502 .4285 Mdot
.24884 .42402 Mdot
.39503 .43565 Mdot
.7905 .47049 Mdot
.61608 .58625 Mdot
.58426 .42039 Mdot
.37876 .382 Mdot
.35196 .39414 Mdot
.32986 .373 Mdot
.26097 .61658 Mdot
.566 .36926 Mdot
.54418 .3882 Mdot
.56252 .44282 Mdot
.47965 .4265 Mdot
.57721 .40662 Mdot
.29665 .54824 Mdot
.32539 .58693 Mdot
.62867 .70619 Mdot
.53791 .36985 Mdot
.4342 .6226 Mdot
.52482 .41239 Mdot
.70141 .57064 Mdot
.53455 .37185 Mdot
.7996 .50188 Mdot
.4189 .60019 Mdot
.51059 .32887 Mdot
.55122 .7054 Mdot
.57571 .42082 Mdot
.69633 .52464 Mdot
.75748 .65372 Mdot
.72293 .31895 Mdot
.29117 .69446 Mdot
.35728 .37516 Mdot
.57442 .6272 Mdot
.39312 .63171 Mdot
.55687 .65658 Mdot
.56435 .34386 Mdot
.25548 .59342 Mdot
.16746 .53676 Mdot
.59562 .55624 Mdot
.59665 .37121 Mdot
.55544 .32274 Mdot
.329 .40259 Mdot
.54364 .67611 Mdot
.4185 .4019 Mdot
.56102 .40892 Mdot
.71582 .56541 Mdot
.71679 .5679 Mdot
.43154 .45981 Mdot
.59015 .76482 Mdot
.6452 .46877 Mdot
.4248 .60972 Mdot
.55363 .68946 Mdot
.71298 .52202 Mdot
.27475 .36627 Mdot
.39591 .63491 Mdot
.41661 .58499 Mdot
.39903 .62681 Mdot
.59003 .41565 Mdot
.27681 .59024 Mdot
.62765 .75215 Mdot
.27206 .61847 Mdot
.57432 .42424 Mdot
.55192 .63189 Mdot
.2851 .60426 Mdot
.69255 .55129 Mdot
.40242 .5818 Mdot
.53705 .63681 Mdot
.58513 .40196 Mdot
.36171 .39902 Mdot
.71099 .33242 Mdot
.78858 .56546 Mdot
.61406 .65658 Mdot
.61438 .6519 Mdot
.38642 .42108 Mdot
.43745 .82836 Mdot
.38373 .64478 Mdot
.41936 .21936 Mdot
.66866 .5625 Mdot
.56426 .3484 Mdot
.57477 .17692 Mdot
.57509 .65832 Mdot
.52781 .66757 Mdot
.57322 .40121 Mdot
.5123 .66623 Mdot
.60426 .38926 Mdot
.57445 .64625 Mdot
.39709 .79164 Mdot
.5955 .43023 Mdot
.52971 .66898 Mdot
.51246 .37813 Mdot
.56149 .42106 Mdot
.32978 .40637 Mdot
.51026 .65576 Mdot
.54256 .35445 Mdot
.15874 .53644 Mdot
.41856 .58938 Mdot
.26428 .61746 Mdot
.34669 .6201 Mdot
.40958 .63077 Mdot
.34064 .40608 Mdot
.56454 .44641 Mdot
.70041 .53338 Mdot
.37171 .3995 Mdot
.54589 .6167 Mdot
.71621 .5291 Mdot
.33899 .53273 Mdot
.35098 .3751 Mdot
.28038 .60203 Mdot
.70159 .53059 Mdot
.53995 .4541 Mdot
.52118 .65548 Mdot
.79788 .58079 Mdot
.27169 .61812 Mdot
.57744 .37447 Mdot
.56149 .6969 Mdot
.41845 .62987 Mdot
.56638 .39007 Mdot
.53244 .67837 Mdot
.25756 .61508 Mdot
.57421 .43191 Mdot
.5802 .4308 Mdot
.44003 .42747 Mdot
.28043 .45024 Mdot
.69906 .5372 Mdot
.38228 .43734 Mdot
.55891 .39709 Mdot
.70975 .57376 Mdot
.42672 .69497 Mdot
.52113 .40521 Mdot
.3137 .38841 Mdot
.48245 .45115 Mdot
.54266 .63308 Mdot
.38861 .59473 Mdot
.54381 .69039 Mdot
.68011 .53927 Mdot
.76068 .28122 Mdot
.28026 .5892 Mdot
.59013 .32624 Mdot
.60189 .35308 Mdot
.49298 .65277 Mdot
.34884 .39692 Mdot
.44608 .77955 Mdot
.56047 .356 Mdot
.53502 .33146 Mdot
.59319 .38279 Mdot
.71049 .65369 Mdot
.35985 .42156 Mdot
.59299 .37817 Mdot
.51741 .33538 Mdot
.52725 .44101 Mdot
.69059 .52512 Mdot
.73481 .43185 Mdot
.52495 .40662 Mdot
.11187 .59764 Mdot
.25051 .60666 Mdot
.5246 .65168 Mdot
.49696 .5608 Mdot
.51377 .71146 Mdot
.42157 .18212 Mdot
.33956 .39491 Mdot
.65201 .42528 Mdot
.55837 .65263 Mdot
.70758 .29522 Mdot
.40128 .82296 Mdot
.56449 .42301 Mdot
.59801 .36355 Mdot
.56509 .66566 Mdot
.50376 .64349 Mdot
.25588 .59572 Mdot
.54109 .36101 Mdot
.5547 .32589 Mdot
.50583 .6624 Mdot
.58539 .40841 Mdot
.33159 .30199 Mdot
.4548 .62565 Mdot
.32438 .38247 Mdot
.39317 .59114 Mdot
.42561 .58809 Mdot
.51983 .20277 Mdot
.37194 .50963 Mdot
.4076 .61607 Mdot
.37762 .62917 Mdot
.80323 .50342 Mdot
.47648 .4436 Mdot
.70198 .52133 Mdot
.5497 .78096 Mdot
.536 .66216 Mdot
.56422 .36865 Mdot
.38958 .40073 Mdot
.43615 .1986 Mdot
.3943 .7345 Mdot
.31388 .48998 Mdot
.54798 .39041 Mdot
.53721 .66948 Mdot
.26043 .618 Mdot
.58984 .43404 Mdot
.69924 .3839 Mdot
.58338 .38581 Mdot
.52847 .63148 Mdot
.54772 .20869 Mdot
.41594 .36568 Mdot
.45131 .5717 Mdot
.31131 .41787 Mdot
.53505 .43953 Mdot
.34474 .379 Mdot
.43656 .61836 Mdot
.7183 .57307 Mdot
.69723 .5436 Mdot
.59564 .41685 Mdot
.36534 .47639 Mdot
.65038 .54995 Mdot
.56089 .41921 Mdot
.54825 .42244 Mdot
.26817 .59461 Mdot
.54924 .42265 Mdot
.59664 .34999 Mdot
.53098 .42978 Mdot
.5227 .37824 Mdot
.3959 .58299 Mdot
.47532 .34286 Mdot
.52551 .38474 Mdot
.63866 .40731 Mdot
.45265 .61175 Mdot
.65306 .37124 Mdot
.40187 .59337 Mdot
.532 .80699 Mdot
.39577 .60165 Mdot
.69865 .54215 Mdot
.58083 .68542 Mdot
.66607 .38505 Mdot
.39237 .38125 Mdot
.44493 .59625 Mdot
.71895 .5508 Mdot
.41051 .60144 Mdot
.57808 .67742 Mdot
.84106 .53804 Mdot
.40145 .4253 Mdot
.46165 .54427 Mdot
.63928 .50374 Mdot
.24778 .47054 Mdot
.55355 .6371 Mdot
.34484 .4179 Mdot
.38724 .34773 Mdot
.53533 .43379 Mdot
.6932 .53643 Mdot
.58243 .39474 Mdot
.39616 .58434 Mdot
.53503 .6654 Mdot
.60383 .62178 Mdot
.69715 .538 Mdot
.81288 .3741 Mdot
.55269 .62879 Mdot
.61415 .42341 Mdot
.4538 .61056 Mdot
.8564 .51759 Mdot
.39548 .59909 Mdot
.773 .3784 Mdot
.30752 .37139 Mdot
.56867 .21296 Mdot
.35994 .41276 Mdot
.24228 .40703 Mdot
.50012 .85602 Mdot
.40377 .81562 Mdot
.36923 .39337 Mdot
.59978 .69448 Mdot
.57969 .41494 Mdot
.5286 .39679 Mdot
.59852 .45715 Mdot
.34796 .44323 Mdot
.56283 .40213 Mdot
.28356 .60107 Mdot
.37886 .51363 Mdot
.70992 .68851 Mdot
.58528 .63497 Mdot
.60535 .38812 Mdot
.44043 .59591 Mdot
.37889 .60479 Mdot
.28194 .61044 Mdot
.41572 .63493 Mdot
.55548 .41716 Mdot
.36712 .40972 Mdot
.60872 .55238 Mdot
.7057 .5627 Mdot
.22161 .65044 Mdot
.67065 .52989 Mdot
.59239 .63985 Mdot
.61306 .44178 Mdot
.5558 .64501 Mdot
.65814 .19421 Mdot
.52937 .41373 Mdot
.35815 .39331 Mdot
.58619 .42471 Mdot
.53266 .43424 Mdot
.52914 .38205 Mdot
.53947 .68389 Mdot
.49694 .56628 Mdot
.58759 .40638 Mdot
.42106 .62517 Mdot
.62463 .64759 Mdot
.57284 .44829 Mdot
.56938 .74222 Mdot
.77946 .46668 Mdot
.25849 .48579 Mdot
.33025 .43348 Mdot
.55572 .66981 Mdot
.35279 .40741 Mdot
.34813 .4457 Mdot
.34046 .40593 Mdot
.61666 .74196 Mdot
.67393 .39368 Mdot
.38924 .17352 Mdot
.53681 .26132 Mdot
.44223 .20389 Mdot
.38733 .42638 Mdot
.45412 .71442 Mdot
.36484 .38411 Mdot
.33856 .39954 Mdot
.23323 .25419 Mdot
.37726 .38934 Mdot
.58552 .36584 Mdot
.61972 .40305 Mdot
.23714 .55238 Mdot
.80536 .48588 Mdot
.53558 .37164 Mdot
.56317 .39943 Mdot
.73083 .55906 Mdot
.48719 .36846 Mdot
.27957 .61766 Mdot
.33843 .50885 Mdot
.27238 .62826 Mdot
.59044 .39112 Mdot
.56904 .40296 Mdot
.5719 .33201 Mdot
.50296 .8607 Mdot
.42716 .19528 Mdot
.36715 .43252 Mdot
.61962 .3235 Mdot
.28529 .72781 Mdot
.61479 .38569 Mdot
.61282 .40015 Mdot
.56101 .43583 Mdot
.55857 .6547 Mdot
.35761 .36227 Mdot
.52482 .34036 Mdot
.24513 .50763 Mdot
.57355 .41737 Mdot
.41258 .65055 Mdot
.70971 .5076 Mdot
.58565 .37189 Mdot
.32331 .37795 Mdot
.53451 .39626 Mdot
.36896 .37735 Mdot
.32794 .38027 Mdot
.60605 .33664 Mdot
.61745 .75661 Mdot
.32659 .36814 Mdot
.57226 .4284 Mdot
.56544 .6572 Mdot
.35428 .79698 Mdot
.57834 .37307 Mdot
.72915 .55425 Mdot
.54647 .37171 Mdot
.68888 .527 Mdot
.5572 .42904 Mdot
.2673 .61978 Mdot
.40268 .25374 Mdot
.54626 .66532 Mdot
.66727 .52803 Mdot
.50172 .65213 Mdot
.45657 .43573 Mdot
.32948 .41676 Mdot
.2764 .62072 Mdot
.37516 .20549 Mdot
.26982 .59454 Mdot
.6992 .32599 Mdot
.37116 .70754 Mdot
.43154 .5935 Mdot
.35475 .37045 Mdot
.67603 .32468 Mdot
.55892 .7481 Mdot
.50716 .62536 Mdot
.52171 .62268 Mdot
.70511 .2385 Mdot
.52268 .14658 Mdot
.59236 .40332 Mdot
.80108 .61193 Mdot
.41726 .29186 Mdot
.51538 .41094 Mdot
.50842 .41815 Mdot
.53385 .62846 Mdot
.53769 .44268 Mdot
.49752 .5173 Mdot
.53981 .6475 Mdot
.71354 .55101 Mdot
.33542 .38796 Mdot
.68364 .53932 Mdot
.49149 .78441 Mdot
.34815 .55082 Mdot
.53184 .64041 Mdot
.52063 .38951 Mdot
.5978 .40572 Mdot
.37 .37434 Mdot
.3325 .33342 Mdot
.32316 .38774 Mdot
.72886 .53922 Mdot
.54428 .65573 Mdot
.40362 .20927 Mdot
.55139 .36602 Mdot
.37734 .40572 Mdot
.49392 .66691 Mdot
.54888 .37956 Mdot
.43765 .60259 Mdot
.54695 .3909 Mdot
.37695 .39473 Mdot
.54986 .42336 Mdot
.36451 .4101 Mdot
.57208 .65392 Mdot
.60685 .37087 Mdot
.56881 .40031 Mdot
.68921 .30087 Mdot
.70577 .55697 Mdot
.33562 .42129 Mdot
.49213 .51319 Mdot
.6103 .37131 Mdot
.69753 .39006 Mdot
.55828 .44658 Mdot
.6212 .45848 Mdot
.51685 .36407 Mdot
.28276 .59921 Mdot
.56533 .3393 Mdot
.57922 .3741 Mdot
.44549 .35383 Mdot
.51773 .28686 Mdot
.41171 .44445 Mdot
.44061 .58942 Mdot
.32299 .37878 Mdot
.51829 .6432 Mdot
.50994 .64189 Mdot
.55878 .68221 Mdot
.80451 .45688 Mdot
.61113 .33433 Mdot
.57773 .37978 Mdot
.45702 .61504 Mdot
.70482 .54825 Mdot
.38142 .41147 Mdot
.7049 .54308 Mdot
.33949 .50577 Mdot
.722 .5315 Mdot
.28436 .5964 Mdot
.71681 .65236 Mdot
.31565 .28616 Mdot
.72781 .5456 Mdot
.32311 .38667 Mdot
.60964 .58123 Mdot
.55858 .34948 Mdot
.3276 .73797 Mdot
.71729 .56521 Mdot
.7375 .27319 Mdot
.58905 .42989 Mdot
.49606 .5242 Mdot
.40876 .59113 Mdot
.68687 .53488 Mdot
.39882 .62839 Mdot
.53209 .39927 Mdot
.20953 .466 Mdot
.35544 .38899 Mdot
.46288 .62182 Mdot
.54799 .34751 Mdot
.68435 .53813 Mdot
.52655 .64173 Mdot
.56809 .50245 Mdot
.44372 .6159 Mdot
.71441 .31993 Mdot
.70492 .38259 Mdot
.5439 .65372 Mdot
.26879 .29653 Mdot
.38807 .61623 Mdot
.51767 .39613 Mdot
.65067 .44272 Mdot
.53887 .39576 Mdot
.51706 .63937 Mdot
.53535 .67599 Mdot
.26932 .56455 Mdot
.59151 .41842 Mdot
.58309 .43432 Mdot
.3841 .36657 Mdot
.54114 .64163 Mdot
.34515 .41423 Mdot
.37035 .37004 Mdot
.56582 .66287 Mdot
.33537 .4068 Mdot
.70754 .52784 Mdot
.38491 .50845 Mdot
.38838 .61456 Mdot
.43385 .61616 Mdot
.52333 .64152 Mdot
.58215 .67384 Mdot
.55377 .64334 Mdot
.54832 .39432 Mdot
.36342 .4248 Mdot
.53848 .42324 Mdot
.5244 .40432 Mdot
.30764 .36623 Mdot
.38401 .419 Mdot
.53479 .41543 Mdot
.62904 .58725 Mdot
.69195 .57229 Mdot
.53119 .67023 Mdot
.39988 .61609 Mdot
.68111 .28333 Mdot
.45829 .62402 Mdot
.60767 .40715 Mdot
.34964 .75094 Mdot
.38342 .41369 Mdot
.69423 .55059 Mdot
.74219 .53516 Mdot
.69345 .54131 Mdot
.46325 .62156 Mdot
.35838 .36817 Mdot
.34057 .53394 Mdot
.60765 .40285 Mdot
.41537 .51929 Mdot
.69368 .33733 Mdot
.27783 .53108 Mdot
.40658 .61813 Mdot
.55433 .39027 Mdot
.27257 .59424 Mdot
.35548 .25978 Mdot
.57836 .38653 Mdot
.56769 .34103 Mdot
.67433 .62786 Mdot
.63746 .40988 Mdot
.35537 .44112 Mdot
.40102 .47347 Mdot
.59639 .35473 Mdot
.4221 .43941 Mdot
.36149 .15728 Mdot
.58829 .42966 Mdot
.56842 .40969 Mdot
.571 .36307 Mdot
.53187 .42355 Mdot
.31162 .40324 Mdot
.66787 .60404 Mdot
.44164 .59481 Mdot
.394 .51002 Mdot
.39429 .62202 Mdot
.52238 .66204 Mdot
.50895 .52194 Mdot
.34335 .37115 Mdot
.69262 .54252 Mdot
.8345 .56855 Mdot
.35053 .49632 Mdot
.56788 .64231 Mdot
.46461 .18193 Mdot
.70781 .56459 Mdot
.5616 .34943 Mdot
.68339 .56275 Mdot
.50595 .63691 Mdot
.42035 .62187 Mdot
.61756 .38803 Mdot
.39181 .4035 Mdot
.317 .39539 Mdot
.55461 .39355 Mdot
.30502 .75833 Mdot
.41139 .63028 Mdot
.44097 .66218 Mdot
.58797 .4176 Mdot
.56886 .34103 Mdot
.32776 .38814 Mdot
.54107 .67469 Mdot
.35382 .68475 Mdot
.71469 .55675 Mdot
.53031 .35844 Mdot
.53275 .39604 Mdot
.35316 .5071 Mdot
.40918 .57852 Mdot
.26164 .60939 Mdot
.58894 .41848 Mdot
.36852 .51129 Mdot
.58566 .42254 Mdot
.48422 .40201 Mdot
.56265 .64886 Mdot
.62324 .40488 Mdot
.58729 .35494 Mdot
.61899 .29818 Mdot
.38621 .61651 Mdot
.35344 .39671 Mdot
.32737 .3594 Mdot
.25389 .60678 Mdot
.4307 .59738 Mdot
.53523 .40874 Mdot
.39165 .58889 Mdot
.52873 .38668 Mdot
.58485 .40524 Mdot
.40701 .61876 Mdot
.34381 .41375 Mdot
.44444 .77361 Mdot
.46063 .35721 Mdot
.54942 .43838 Mdot
.54161 .37721 Mdot
.80287 .46931 Mdot
.30879 .25891 Mdot
.57628 .35289 Mdot
.37455 .423 Mdot
.55056 .38014 Mdot
.43941 .61112 Mdot
.72641 .53555 Mdot
.36291 .39496 Mdot
.58636 .66303 Mdot
.57325 .65838 Mdot
.54665 .7051 Mdot
.28255 .59196 Mdot
.55739 .35401 Mdot
.40237 .42771 Mdot
.38793 .4157 Mdot
.24369 .63373 Mdot
.52381 .65248 Mdot
.70889 .52307 Mdot
.56739 .43798 Mdot
.57896 .502 Mdot
.43021 .58784 Mdot
.11462 .60166 Mdot
.33943 .54126 Mdot
.67776 .5299 Mdot
.31201 .46068 Mdot
.27654 .59718 Mdot
.59865 .37086 Mdot
.69751 .56931 Mdot
.57401 .67332 Mdot
.52933 .3991 Mdot
.6395 .37598 Mdot
.54262 .74551 Mdot
.58388 .63683 Mdot
.38921 .59231 Mdot
.58041 .66718 Mdot
.67754 .53671 Mdot
.28459 .59798 Mdot
.32695 .40766 Mdot
.58367 .3768 Mdot
.63455 .32928 Mdot
.52831 .65779 Mdot
.25988 .61994 Mdot
.58306 .42172 Mdot
.31614 .38746 Mdot
.54345 .68039 Mdot
.59459 .38991 Mdot
.40219 .22499 Mdot
.29891 .36937 Mdot
.53906 .65913 Mdot
.60371 .3531 Mdot
.46806 .43892 Mdot
.58195 .64639 Mdot
.53845 .62779 Mdot
.56327 .4022 Mdot
.7023 .5296 Mdot
.60581 .37452 Mdot
.4016 .59718 Mdot
.4972 .56631 Mdot
.43514 .60387 Mdot
.70131 .3535 Mdot
.62244 .37212 Mdot
.24843 .44618 Mdot
.38474 .3852 Mdot
.74386 .56149 Mdot
.45068 .34424 Mdot
.57558 .34265 Mdot
.50392 .81524 Mdot
.60788 .56856 Mdot
.26621 .64505 Mdot
.63053 .8021 Mdot
.72433 .5527 Mdot
.41209 .59822 Mdot
.56739 .40915 Mdot
.37438 .58512 Mdot
.7219 .54006 Mdot
.70053 .34733 Mdot
.60132 .3517 Mdot
.35881 .42047 Mdot
.57805 .41731 Mdot
.35902 .37536 Mdot
.54813 .37595 Mdot
.62172 .33696 Mdot
.69009 .57589 Mdot
.77055 .37351 Mdot
.55471 .35205 Mdot
.84235 .55942 Mdot
.53799 .50805 Mdot
.71954 .56226 Mdot
.55076 .43382 Mdot
.27078 .60816 Mdot
.42254 .62951 Mdot
.77517 .61877 Mdot
.55759 .64915 Mdot
.40411 .61017 Mdot
.33065 .39033 Mdot
.55124 .69468 Mdot
.25238 .60941 Mdot
.67046 .39513 Mdot
.68232 .54395 Mdot
.42271 .59116 Mdot
.58166 .3732 Mdot
.60799 .40826 Mdot
.72054 .64599 Mdot
.21411 .35221 Mdot
.38245 .36899 Mdot
.79198 .35644 Mdot
.36714 .43925 Mdot
.70384 .55291 Mdot
.56076 .6465 Mdot
.58906 .36256 Mdot
.57419 .3918 Mdot
.51326 .64875 Mdot
.36681 .42737 Mdot
.55624 .69999 Mdot
.50346 .19356 Mdot
.48895 .61893 Mdot
.75913 .40561 Mdot
.3646 .39125 Mdot
.76009 .40022 Mdot
.68082 .52817 Mdot
.61081 .7727 Mdot
.73158 .48582 Mdot
.41807 .58728 Mdot
.75743 .41071 Mdot
.38336 .40745 Mdot
.59527 .40018 Mdot
.27932 .60442 Mdot
.26429 .59205 Mdot
.33741 .3812 Mdot
.56228 .66755 Mdot
.68508 .54198 Mdot
.5731 .41007 Mdot
.29536 .51271 Mdot
.20157 .55013 Mdot
.55138 .68944 Mdot
.51055 .34414 Mdot
.40608 .62892 Mdot
.54454 .38056 Mdot
.72681 .56426 Mdot
.41178 .6105 Mdot
.2813 .5836 Mdot
.38823 .50485 Mdot
.56761 .43852 Mdot
.43643 .45337 Mdot
.42332 .59376 Mdot
.28287 .27204 Mdot
.56946 .39759 Mdot
.38795 .61635 Mdot
.62988 .44222 Mdot
.21336 .48173 Mdot
.62865 .5393 Mdot
.42387 .82214 Mdot
.55488 .62258 Mdot
.5727 .66296 Mdot
.17304 .46002 Mdot
.67076 .56523 Mdot
.44601 .60254 Mdot
.28476 .60179 Mdot
.72978 .45462 Mdot
.39124 .62516 Mdot
.61315 .40571 Mdot
.56197 .4456 Mdot
.50577 .20004 Mdot
.53025 .5142 Mdot
.25149 .61709 Mdot
.59011 .48103 Mdot
.54724 .41171 Mdot
.55578 .46021 Mdot
.56186 .38748 Mdot
.36468 .43382 Mdot
.38975 .62648 Mdot
.85086 .59024 Mdot
.38079 .61696 Mdot
.30446 .51409 Mdot
.53593 .66252 Mdot
.54246 .68777 Mdot
.58697 .37307 Mdot
.25644 .41112 Mdot
.7616 .65706 Mdot
.54415 .36886 Mdot
.72728 .51803 Mdot
.7065 .3765 Mdot
.56976 .45081 Mdot
.35299 .35855 Mdot
.52369 .33815 Mdot
.332 .42639 Mdot
.41292 .61429 Mdot
.72495 .55091 Mdot
.71399 .58096 Mdot
.41086 .59432 Mdot
.57461 .37983 Mdot
.74951 .5393 Mdot
.58889 .38291 Mdot
.59424 .40738 Mdot
.33031 .51007 Mdot
.73363 .53564 Mdot
.5521 .64123 Mdot
.69682 .54185 Mdot
.34022 .40046 Mdot
.17227 .31453 Mdot
.71043 .53929 Mdot
.48292 .45654 Mdot
.52918 .54103 Mdot
.75679 .40615 Mdot
.31796 .39578 Mdot
.732 .5479 Mdot
.38334 .60534 Mdot
.25254 .6458 Mdot
.28646 .28296 Mdot
.44531 .63261 Mdot
.57427 .39584 Mdot
.352 .37139 Mdot
.38374 .42424 Mdot
.40495 .63839 Mdot
.33823 .41631 Mdot
.60064 .44598 Mdot
.58087 .42842 Mdot
.44561 .60211 Mdot
.22645 .56184 Mdot
.3885 .62608 Mdot
.54871 .49794 Mdot
.56473 .43337 Mdot
.36041 .39431 Mdot
.53508 .46418 Mdot
.4033 .38254 Mdot
.26403 .59055 Mdot
.53002 .37735 Mdot
.68975 .5422 Mdot
.45827 .51855 Mdot
.53948 .66073 Mdot
.35594 .75428 Mdot
.35126 .37375 Mdot
.46832 .60457 Mdot
.32849 .40474 Mdot
.3959 .39434 Mdot
.41058 .63583 Mdot
.34528 .39365 Mdot
.56994 .41021 Mdot
.4527 .55236 Mdot
.36467 .37899 Mdot
.42632 .60566 Mdot
.68725 .54716 Mdot
.33854 .41006 Mdot
.53333 .69297 Mdot
.59928 .39951 Mdot
.54887 .634 Mdot
.72115 .52055 Mdot
.34599 .37059 Mdot
.73073 .54495 Mdot
.52595 .65586 Mdot
.68405 .5513 Mdot
.58864 .62052 Mdot
.40987 .57245 Mdot
.30902 .49243 Mdot
.43563 .37794 Mdot
.39075 .398 Mdot
.51039 .62327 Mdot
.5865 .35754 Mdot
.5974 .41167 Mdot
.67853 .54865 Mdot
.38677 .42175 Mdot
.34924 .79179 Mdot
.61457 .46562 Mdot
.28165 .56945 Mdot
.40754 .57668 Mdot
.74617 .31182 Mdot
.33506 .55856 Mdot
.26549 .65756 Mdot
.5045 .39659 Mdot
.27726 .59791 Mdot
.59354 .38186 Mdot
.72345 .31856 Mdot
.72628 .53384 Mdot
.43237 .73199 Mdot
.5119 .38574 Mdot
.54894 .64758 Mdot
.55305 .36932 Mdot
.79868 .61126 Mdot
.50032 .3756 Mdot
.73151 .5558 Mdot
.45045 .5953 Mdot
.3922 .38087 Mdot
.70725 .56344 Mdot
.57372 .65292 Mdot
.7544 .45017 Mdot
.60967 .35949 Mdot
.55142 .41272 Mdot
.50859 .62601 Mdot
.35208 .42029 Mdot
.52146 .65907 Mdot
.38859 .61521 Mdot
.70913 .54176 Mdot
.53519 .43041 Mdot
.59007 .44801 Mdot
.49282 .64446 Mdot
.37955 .60637 Mdot
.57049 .68752 Mdot
.3998 .58465 Mdot
.27832 .59856 Mdot
.55389 .35451 Mdot
.50206 .63315 Mdot
.51877 .43218 Mdot
.54947 .27776 Mdot
.32863 .49974 Mdot
.46397 .32147 Mdot
.55076 .63986 Mdot
.77916 .44839 Mdot
.41988 .59779 Mdot
.39855 .5896 Mdot
.58875 .23119 Mdot
.7492 .66722 Mdot
.60911 .58551 Mdot
.83632 .5389 Mdot
.3888 .61466 Mdot
.43055 .60159 Mdot
.57118 .67489 Mdot
.34111 .39016 Mdot
.30185 .38456 Mdot
.51287 .67251 Mdot
.74163 .3421 Mdot
.38143 .41112 Mdot
.48343 .82096 Mdot
.56654 .63174 Mdot
.51736 .36471 Mdot
.25075 .62005 Mdot
.72506 .56233 Mdot
.72459 .3328 Mdot
.82387 .56164 Mdot
.59252 .36847 Mdot
.46877 .15994 Mdot
.55423 .66765 Mdot
.42276 .55184 Mdot
.56558 .7866 Mdot
.58643 .34109 Mdot
.559 .36745 Mdot
.56835 .37999 Mdot
.74001 .55333 Mdot
.47094 .33772 Mdot
.59449 .36984 Mdot
.77552 .39226 Mdot
.61323 .41466 Mdot
.78777 .59261 Mdot
.69731 .54165 Mdot
.67502 .42538 Mdot
.54864 .62005 Mdot
.25896 .5113 Mdot
.59247 .46001 Mdot
.3879 .60704 Mdot
.52041 .76602 Mdot
.41402 .62333 Mdot
.67814 .73865 Mdot
.7296 .4834 Mdot
.3686 .43474 Mdot
.54817 .39114 Mdot
.52342 .62376 Mdot
.35815 .37255 Mdot
.36624 .70078 Mdot
.22849 .25515 Mdot
.38963 .58576 Mdot
.55462 .13438 Mdot
.40027 .5879 Mdot
.26008 .59334 Mdot
.33103 .38445 Mdot
.32142 .44811 Mdot
.4197 .51921 Mdot
.34375 .41238 Mdot
.55615 .72118 Mdot
.33817 .3579 Mdot
.76868 .42898 Mdot
.40044 .40019 Mdot
.42144 .60397 Mdot
.44828 .58664 Mdot
.64806 .39539 Mdot
.57719 .35392 Mdot
.38311 .51628 Mdot
.59186 .4676 Mdot
.555 .35816 Mdot
.53997 .64751 Mdot
.26242 .36663 Mdot
.46442 .58123 Mdot
.35917 .38204 Mdot
.42562 .58323 Mdot
.55754 .36723 Mdot
.54969 .43776 Mdot
.51803 .41697 Mdot
.7104 .30915 Mdot
.48539 .81857 Mdot
.588 .40457 Mdot
.59837 .3348 Mdot
.56972 .64812 Mdot
.74238 .62846 Mdot
.82675 .4526 Mdot
.73396 .46459 Mdot
.59827 .41571 Mdot
.70061 .55393 Mdot
.73312 .54085 Mdot
.61025 .43283 Mdot
.26683 .47912 Mdot
.59625 .69035 Mdot
.58134 .373 Mdot
.75286 .50655 Mdot
.50832 .67684 Mdot
.26868 .62018 Mdot
.52812 .65693 Mdot
.33216 .37261 Mdot
.26589 .59371 Mdot
.53708 .68159 Mdot
.28188 .38806 Mdot
.25472 .60589 Mdot
.21927 .49338 Mdot
.7292 .53964 Mdot
.56643 .38963 Mdot
.41434 .39313 Mdot
.51422 .647 Mdot
.41915 .59048 Mdot
.3648 .40495 Mdot
.39421 .57754 Mdot
.74383 .62977 Mdot
.72473 .34863 Mdot
.28018 .58956 Mdot
.39028 .60401 Mdot
.40772 .488 Mdot
.69824 .55057 Mdot
.41715 .63616 Mdot
.251 .41395 Mdot
.56642 .44912 Mdot
.71896 .71977 Mdot
.55311 .40824 Mdot
.26564 .71911 Mdot
.3995 .59021 Mdot
.26948 .58687 Mdot
.58383 .3789 Mdot
.55663 .62953 Mdot
.65332 .38839 Mdot
.58857 .38509 Mdot
.58293 .66349 Mdot
.59269 .40225 Mdot
.72396 .56845 Mdot
.3227 .42212 Mdot
.60866 .56538 Mdot
.70799 .27398 Mdot
.68868 .5578 Mdot
.28306 .57744 Mdot
.56264 .35413 Mdot
.63919 .65048 Mdot
.34917 .41413 Mdot
.57503 .33976 Mdot
.55509 .19461 Mdot
.34311 .38314 Mdot
.35321 .40912 Mdot
.5449 .42262 Mdot
.45174 .62957 Mdot
.5274 .63567 Mdot
.69649 .54832 Mdot
.33553 .64653 Mdot
.59616 .38883 Mdot
.55705 .39141 Mdot
.70663 .56416 Mdot
.43276 .60224 Mdot
.53588 .42929 Mdot
.35412 .71524 Mdot
.3019 .61795 Mdot
.42702 .58845 Mdot
.56713 .4497 Mdot
.73478 .72719 Mdot
.29998 .40211 Mdot
.44002 .15817 Mdot
.6657 .55547 Mdot
.5628 .66274 Mdot
.57931 .32221 Mdot
.09992 .56709 Mdot
.72531 .56022 Mdot
.27805 .52535 Mdot
.58723 .41011 Mdot
.56476 .3581 Mdot
.33039 .41525 Mdot
.53705 .41443 Mdot
.37768 .39254 Mdot
.70958 .27054 Mdot
.8728 .49605 Mdot
.3302 .40544 Mdot
.37282 .38475 Mdot
.36283 .45628 Mdot
.70419 .31371 Mdot
.33341 .38966 Mdot
.60636 .35395 Mdot
.60761 .71721 Mdot
.62968 .36401 Mdot
.68583 .52074 Mdot
.74517 .56454 Mdot
.37973 .36026 Mdot
.24454 .34307 Mdot
.6585 .37706 Mdot
.46605 .37984 Mdot
.65016 .5426 Mdot
.39656 .60505 Mdot
.55559 .44376 Mdot
.28395 .59357 Mdot
.55482 .68488 Mdot
.50055 .36533 Mdot
.56961 .38831 Mdot
.36636 .37718 Mdot
.74083 .5551 Mdot
.40779 .63347 Mdot
.56435 .39998 Mdot
.59214 .67584 Mdot
.71461 .5535 Mdot
.36577 .38031 Mdot
.48818 .46441 Mdot
.69719 .52155 Mdot
.58092 .45428 Mdot
.55637 .3584 Mdot
.58294 .42232 Mdot
.59938 .45795 Mdot
.41049 .59308 Mdot
.52904 .68506 Mdot
.62756 .40149 Mdot
.34437 .51378 Mdot
.47366 .53399 Mdot
.62436 .40823 Mdot
.36587 .42545 Mdot
.44623 .59945 Mdot
.25743 .60539 Mdot
.74344 .42304 Mdot
.57914 .4329 Mdot
.49426 .81553 Mdot
.45891 .18784 Mdot
.26393 .59948 Mdot
.38598 .43355 Mdot
.69325 .54613 Mdot
.55209 .41911 Mdot
.62541 .68186 Mdot
.59882 .42105 Mdot
.49951 .46319 Mdot
.55907 .66468 Mdot
.39608 .61094 Mdot
.29111 .62648 Mdot
.555 .68519 Mdot
.35286 .40796 Mdot
.32841 .79487 Mdot
.31898 .36728 Mdot
.3745 .36807 Mdot
.62853 .7562 Mdot
.4114 .61627 Mdot
.10781 .5858 Mdot
.30483 .26004 Mdot
.59906 .42271 Mdot
.43322 .62043 Mdot
.33232 .38066 Mdot
.55055 .39801 Mdot
.38876 .40233 Mdot
.3475 .36405 Mdot
.52485 .41496 Mdot
.56748 .35566 Mdot
.76145 .36441 Mdot
.48215 .83289 Mdot
.69549 .53542 Mdot
.35153 .42733 Mdot
.47472 .20354 Mdot
.59535 .36914 Mdot
.60779 .40179 Mdot
.53661 .75303 Mdot
.73133 .55339 Mdot
.34517 .2968 Mdot
.59171 .41467 Mdot
.5666 .19962 Mdot
.54776 .3609 Mdot
.41889 .42476 Mdot
.45439 .63067 Mdot
.27117 .4886 Mdot
.51899 .63777 Mdot
.31484 .38016 Mdot
.68835 .52856 Mdot
.30925 .38605 Mdot
.56812 .21947 Mdot
.4149 .61827 Mdot
.37705 .39479 Mdot
.5726 .69016 Mdot
.42607 .61551 Mdot
.41538 .58651 Mdot
.62353 .64727 Mdot
.55007 .69356 Mdot
.73588 .56304 Mdot
.41119 .62581 Mdot
.42546 .21717 Mdot
.41912 .60638 Mdot
.49175 .20414 Mdot
.59983 .36025 Mdot
.76821 .3857 Mdot
.32393 .56132 Mdot
.62216 .43863 Mdot
.39514 .62933 Mdot
.71081 .53363 Mdot
.53785 .40095 Mdot
.34085 .41859 Mdot
.71461 .54023 Mdot
.37707 .63228 Mdot
.58236 .67758 Mdot
.3968 .40281 Mdot
.45496 .61294 Mdot
.38168 .39714 Mdot
.71534 .34813 Mdot
.58932 .62942 Mdot
.65043 .51879 Mdot
.43444 .52391 Mdot
.51675 .3997 Mdot
.42396 .43698 Mdot
.61071 .36957 Mdot
.5743 .38736 Mdot
.5383 .65921 Mdot
.80356 .45463 Mdot
.34001 .41212 Mdot
.20751 .61691 Mdot
.39248 .59808 Mdot
.39547 .47573 Mdot
.53317 .48157 Mdot
.53025 .38586 Mdot
.35929 .37888 Mdot
.35556 .364 Mdot
.5167 .28733 Mdot
.5131 .65078 Mdot
.63283 .39953 Mdot
.61999 .43441 Mdot
.60911 .33192 Mdot
.40287 .58675 Mdot
.3765 .73148 Mdot
.52635 .67472 Mdot
.46957 .12678 Mdot
.53191 .67139 Mdot
.65215 .62678 Mdot
.34556 .39268 Mdot
.71354 .52575 Mdot
.60803 .39796 Mdot
.48231 .34162 Mdot
.31609 .40964 Mdot
.58905 .69977 Mdot
.69206 .54935 Mdot
.41526 .75606 Mdot
.40719 .61357 Mdot
.59863 .35415 Mdot
.52853 .4296 Mdot
.54221 .42854 Mdot
.56442 .41823 Mdot
.43351 .58552 Mdot
.61304 .40513 Mdot
.42415 .57735 Mdot
.37633 .23911 Mdot
.57515 .20673 Mdot
.52934 .62593 Mdot
.77433 .60273 Mdot
.39296 .40545 Mdot
.46758 .21688 Mdot
.33182 .29761 Mdot
.32606 .50037 Mdot
.60135 .62369 Mdot
.58879 .35264 Mdot
.56251 .66904 Mdot
.79965 .61502 Mdot
.52004 .62529 Mdot
.89108 .48682 Mdot
.68057 .36173 Mdot
.41091 .82449 Mdot
.55311 .40289 Mdot
.51391 .67489 Mdot
.32714 .31889 Mdot
.59536 .442 Mdot
.75185 .55871 Mdot
.53585 .48894 Mdot
.24218 .54393 Mdot
.7074 .52246 Mdot
.59927 .39675 Mdot
.3962 .38452 Mdot
.57085 .41123 Mdot
.60615 .39428 Mdot
.54539 .36892 Mdot
.37854 .62424 Mdot
.54974 .44962 Mdot
.60618 .37597 Mdot
.22108 .33711 Mdot
.79368 .47488 Mdot
.56595 .63827 Mdot
.49104 .29763 Mdot
.70526 .54829 Mdot
.36516 .37485 Mdot
.58982 .55963 Mdot
.4019 .60068 Mdot
.5291 .28067 Mdot
.55295 .40495 Mdot
.30136 .56168 Mdot
.45783 .62126 Mdot
.72112 .54415 Mdot
.25515 .60984 Mdot
.50007 .7976 Mdot
.51929 .63217 Mdot
.25311 .59869 Mdot
.54031 .66177 Mdot
.39531 .33365 Mdot
.36402 .37718 Mdot
.5186 .41179 Mdot
.40172 .62756 Mdot
.53952 .62898 Mdot
.80976 .48994 Mdot
.5595 .38084 Mdot
.54839 .63862 Mdot
.51741 .39975 Mdot
.47528 .54186 Mdot
.53363 .54611 Mdot
.50093 .64276 Mdot
.44978 .58917 Mdot
.4304 .61478 Mdot
.71037 .52738 Mdot
.36932 .37559 Mdot
.37809 .41962 Mdot
.4154 .61241 Mdot
.48576 .14299 Mdot
.59634 .38641 Mdot
.54997 .36165 Mdot
.34391 .52005 Mdot
.55763 .40441 Mdot
.76939 .45788 Mdot
.28545 .60932 Mdot
.39043 .39226 Mdot
.56286 .41346 Mdot
.53688 .4309 Mdot
.56532 .43897 Mdot
.7237 .35338 Mdot
.52958 .66198 Mdot
.54771 .41294 Mdot
.68575 .56052 Mdot
.23439 .44435 Mdot
.59285 .36095 Mdot
.57895 .45266 Mdot
.38015 .39829 Mdot
.76365 .321 Mdot
.4101 .58962 Mdot
.53851 .63936 Mdot
.569 .634 Mdot
.69076 .42566 Mdot
.31996 .42552 Mdot
.27247 .62178 Mdot
.48928 .69846 Mdot
.27487 .61505 Mdot
.71593 .56239 Mdot
.62865 .60184 Mdot
.59397 .6697 Mdot
.57485 .64843 Mdot
.41189 .57293 Mdot
.56633 .417 Mdot
.54882 .36066 Mdot
.28 .52383 Mdot
.53648 .37307 Mdot
.68937 .54834 Mdot
.45281 .61557 Mdot
.37898 .39919 Mdot
.72039 .56729 Mdot
.39121 .59454 Mdot
.35281 .42107 Mdot
.58152 .44506 Mdot
.53131 .44691 Mdot
.36121 .4081 Mdot
.33205 .37609 Mdot
.58182 .36624 Mdot
.20052 .3924 Mdot
.39158 .3868 Mdot
.3709 .39211 Mdot
.24649 .59986 Mdot
.51928 .63143 Mdot
.50956 .44544 Mdot
.42928 .62316 Mdot
.58516 .42017 Mdot
.5252 .62606 Mdot
.72866 .54538 Mdot
.36488 .41478 Mdot
.55819 .43859 Mdot
.58944 .39738 Mdot
.69948 .55369 Mdot
.7246 .52602 Mdot
.69066 .55666 Mdot
.38042 .5922 Mdot
.56864 .42636 Mdot
.33228 .39385 Mdot
.40965 .61749 Mdot
.73245 .53987 Mdot
.7057 .57598 Mdot
.23715 .32197 Mdot
.59245 .37006 Mdot
.63679 .54559 Mdot
.13457 .37558 Mdot
.75135 .45632 Mdot
.25578 .59892 Mdot
.49655 .64717 Mdot
.77193 .40079 Mdot
.66331 .53289 Mdot
.43628 .6199 Mdot
.69657 .49594 Mdot
.7439 .55554 Mdot
.52486 .40657 Mdot
.54143 .38396 Mdot
.53016 .35449 Mdot
.71298 .54853 Mdot
.7174 .35358 Mdot
.38019 .42557 Mdot
.42322 .26833 Mdot
.70542 .54822 Mdot
.50061 .64354 Mdot
.50032 .63627 Mdot
.5315 .67179 Mdot
.58819 .35079 Mdot
.48959 .30878 Mdot
.44504 .2077 Mdot
.36572 .29895 Mdot
.40466 .61 Mdot
.35909 .36317 Mdot
.60371 .62096 Mdot
.3535 .41014 Mdot
.55501 .68178 Mdot
.71723 .55006 Mdot
.33938 .42272 Mdot
.43572 .59837 Mdot
.43574 .6065 Mdot
.58621 .6672 Mdot
.52673 .65169 Mdot
.52951 .64065 Mdot
.32784 .37277 Mdot
.34514 .39343 Mdot
.54163 .43715 Mdot
.37154 .4094 Mdot
.40048 .19441 Mdot
.6803 .52305 Mdot
.51284 .62413 Mdot
.42319 .59539 Mdot
.35147 .37525 Mdot
.56773 .3923 Mdot
.69043 .63311 Mdot
.55176 .70458 Mdot
.69544 .56501 Mdot
.48731 .58242 Mdot
.86065 .40296 Mdot
.52933 .43423 Mdot
.398 .58421 Mdot
.25721 .46475 Mdot
.56379 .3765 Mdot
.56012 .65433 Mdot
.66712 .29358 Mdot
.26473 .61938 Mdot
.60286 .37211 Mdot
.55755 .34547 Mdot
.41011 .63545 Mdot
.56734 .55299 Mdot
.53135 .37966 Mdot
.46055 .4662 Mdot
.37855 .6035 Mdot
.52819 .67673 Mdot
.15705 .534 Mdot
.49253 .62034 Mdot
.77553 .37366 Mdot
.25777 .59917 Mdot
.52896 .4289 Mdot
.53982 .65033 Mdot
.70011 .56949 Mdot
.53427 .65086 Mdot
.39397 .42215 Mdot
.54283 .63318 Mdot
.55304 .38451 Mdot
.33381 .39517 Mdot
.42893 .59589 Mdot
.41112 .4662 Mdot
.22467 .34812 Mdot
.55964 .6304 Mdot
.28202 .58143 Mdot
.59913 .37014 Mdot
.36303 .25962 Mdot
.65048 .37571 Mdot
.58351 .35412 Mdot
.41245 .62322 Mdot
.3585 .3796 Mdot
.40919 .5765 Mdot
.55421 .45464 Mdot
.58959 .24011 Mdot
.39551 .59642 Mdot
.22217 .52167 Mdot
.71055 .56472 Mdot
.73977 .34163 Mdot
.5801 .38917 Mdot
.40036 .62621 Mdot
.56889 .427 Mdot
.35547 .42896 Mdot
.44485 .5055 Mdot
.23945 .4312 Mdot
.40593 .62824 Mdot
.29475 .75628 Mdot
.49064 .51206 Mdot
.49401 .41392 Mdot
.39162 .62085 Mdot
.45846 .33652 Mdot
.26655 .60906 Mdot
.71526 .55769 Mdot
.73133 .53455 Mdot
.68159 .54095 Mdot
.53719 .37192 Mdot
.55628 .31735 Mdot
.72451 .57619 Mdot
.38796 .58485 Mdot
.71667 .57395 Mdot
.71038 .3283 Mdot
.32458 .77546 Mdot
.69495 .56215 Mdot
.57978 .39454 Mdot
.57876 .45151 Mdot
.79548 .47697 Mdot
.52645 .67747 Mdot
.5096 .81263 Mdot
.32611 .25587 Mdot
.58629 .36111 Mdot
.66911 .40794 Mdot
.39421 .41267 Mdot
.27454 .44507 Mdot
.62482 .46121 Mdot
.61064 .57934 Mdot
.36874 .38534 Mdot
.47752 .55426 Mdot
.3879 .38941 Mdot
.52608 .43422 Mdot
.584 .40612 Mdot
.31948 .41609 Mdot
.3407 .73897 Mdot
.19482 .48516 Mdot
.2269 .66503 Mdot
.37743 .42116 Mdot
.38649 .6172 Mdot
.38966 .58776 Mdot
.4051 .6164 Mdot
.51814 .64194 Mdot
.32422 .37875 Mdot
.56178 .4261 Mdot
.5713 .65807 Mdot
.60292 .40753 Mdot
.42349 .61993 Mdot
.29328 .6262 Mdot
.37897 .39772 Mdot
.58014 .37424 Mdot
.28403 .28747 Mdot
.54154 .66961 Mdot
.70024 .55178 Mdot
.44885 .54601 Mdot
.49561 .64974 Mdot
.38228 .6215 Mdot
.31064 .41761 Mdot
.47228 .64812 Mdot
.67143 .6038 Mdot
.57241 .33229 Mdot
.61341 .36576 Mdot
.34323 .6388 Mdot
.25336 .32277 Mdot
.53953 .37506 Mdot
.57413 .65318 Mdot
.50672 .638 Mdot
.58125 .42902 Mdot
.32398 .4033 Mdot
.73898 .5657 Mdot
.67913 .54115 Mdot
.53399 .36165 Mdot
.41248 .51992 Mdot
.76773 .378 Mdot
.53403 .41778 Mdot
.49357 .44754 Mdot
.56756 .69161 Mdot
.25261 .60776 Mdot
.37342 .50926 Mdot
.69262 .52878 Mdot
.58872 .41083 Mdot
.19128 .51134 Mdot
.37445 .38985 Mdot
.53568 .63531 Mdot
.44089 .59837 Mdot
.75324 .56026 Mdot
.57865 .64085 Mdot
.58085 .42913 Mdot
.53627 .42987 Mdot
.41675 .63525 Mdot
.41969 .42249 Mdot
.716 .5481 Mdot
.57056 .65598 Mdot
.71265 .52544 Mdot
.3427 .39951 Mdot
.37343 .39653 Mdot
.62542 .42759 Mdot
.63 .42995 Mdot
.56739 .63349 Mdot
.54353 .34816 Mdot
.54272 .68236 Mdot
.72513 .64258 Mdot
.43001 .58723 Mdot
.57704 .33891 Mdot
.388 .4386 Mdot
.4212 .61909 Mdot
.57325 .35969 Mdot
.34336 .63015 Mdot
.52923 .40804 Mdot
.51421 .67457 Mdot
.59903 .23488 Mdot
.72173 .53845 Mdot
.44391 .41267 Mdot
.57414 .30086 Mdot
.55722 .40287 Mdot
.52327 .67793 Mdot
.6011 .32267 Mdot
.40094 .59488 Mdot
.35207 .3855 Mdot
.65825 .1953 Mdot
.42391 .6071 Mdot
.57543 .41122 Mdot
.71124 .5409 Mdot
.38626 .3732 Mdot
.27877 .59218 Mdot
.3503 .53055 Mdot
.49983 .37027 Mdot
.5012 .40184 Mdot
.56877 .41622 Mdot
.8385 .53595 Mdot
.53601 .6437 Mdot
.34084 .37637 Mdot
.41024 .58239 Mdot
.40956 .60586 Mdot
.54164 .67498 Mdot
.26061 .55475 Mdot
.37591 .77444 Mdot
.10339 .43326 Mdot
.57851 .64633 Mdot
.70148 .57266 Mdot
.47271 .52425 Mdot
.55618 .68586 Mdot
.5437 .64664 Mdot
.58812 .66548 Mdot
.30771 .55284 Mdot
.3563 .42399 Mdot
.59073 .39777 Mdot
.32994 .43339 Mdot
.52582 .41793 Mdot
.81105 .44111 Mdot
.41362 .61311 Mdot
.35064 .38686 Mdot
.35586 .64222 Mdot
.60974 .46231 Mdot
.55874 .37175 Mdot
.60684 .70363 Mdot
.51791 .34708 Mdot
.75218 .41685 Mdot
.55602 .46277 Mdot
.53208 .65726 Mdot
.66995 .3868 Mdot
.57591 .32297 Mdot
.30948 .27131 Mdot
.43508 .60093 Mdot
.27502 .58816 Mdot
.58617 .44028 Mdot
.48597 .41143 Mdot
.3819 .37081 Mdot
.33872 .42239 Mdot
.72688 .5752 Mdot
.41859 .53582 Mdot
.43273 .5981 Mdot
.42678 .79014 Mdot
.57142 .35351 Mdot
.37897 .56366 Mdot
.58913 .22645 Mdot
.57406 .36162 Mdot
.62188 .66996 Mdot
.52618 .28205 Mdot
.53098 .38636 Mdot
.39009 .30152 Mdot
.42431 .59933 Mdot
.56329 .19821 Mdot
.52255 .36775 Mdot
.55911 .65459 Mdot
.34314 .38916 Mdot
.39522 .40589 Mdot
.70353 .56827 Mdot
.35824 .21974 Mdot
.43911 .57615 Mdot
.34638 .39056 Mdot
.56554 .38121 Mdot
.41603 .59036 Mdot
.27338 .58994 Mdot
.50192 .38318 Mdot
.69458 .71496 Mdot
.37508 .40625 Mdot
.62264 .35328 Mdot
.22549 .60222 Mdot
.49616 .53309 Mdot
.49105 .8345 Mdot
.40242 .6172 Mdot
.68871 .52972 Mdot
.55315 .46355 Mdot
.48259 .69394 Mdot
.51455 .38118 Mdot
.79099 .41427 Mdot
.38238 .35619 Mdot
.72591 .53487 Mdot
.56904 .37553 Mdot
.53177 .37965 Mdot
.44946 .52121 Mdot
.71928 .52388 Mdot
.52991 .3817 Mdot
.63118 .41073 Mdot
.35559 .42081 Mdot
.28814 .60264 Mdot
.37898 .40408 Mdot
.57328 .39625 Mdot
.67215 .41713 Mdot
.33283 .41525 Mdot
.48213 .79623 Mdot
.72357 .58706 Mdot
.40095 .6005 Mdot
.48062 .40087 Mdot
.59605 .35783 Mdot
.69013 .7846 Mdot
.26307 .59089 Mdot
.80096 .3859 Mdot
.50147 .65912 Mdot
.1966 .59729 Mdot
.49623 .65529 Mdot
.38511 .81892 Mdot
.40526 .47748 Mdot
.559 .3373 Mdot
.72938 .49667 Mdot
.37929 .29705 Mdot
.4045 .57333 Mdot
.40516 .23247 Mdot
.57777 .35401 Mdot
.6007 .38553 Mdot
.56938 .6716 Mdot
.27174 .56123 Mdot
.2596 .47387 Mdot
.3949 .5127 Mdot
.72117 .54955 Mdot
.34925 .39734 Mdot
.54951 .38286 Mdot
.30109 .68857 Mdot
.56081 .63507 Mdot
.5518 .50505 Mdot
.5817 .3769 Mdot
.29542 .50504 Mdot
.25132 .52993 Mdot
.41872 .58954 Mdot
.50505 .66162 Mdot
.53058 .68556 Mdot
.55761 .44605 Mdot
.44354 .60765 Mdot
.53122 .42698 Mdot
.48625 .50764 Mdot
.5989 .33587 Mdot
.72806 .5547 Mdot
.60994 .39414 Mdot
.59634 .51726 Mdot
.38446 .8319 Mdot
.54408 .32689 Mdot
.37888 .37617 Mdot
.51812 .64573 Mdot
.53303 .66948 Mdot
.37915 .41913 Mdot
.53513 .67191 Mdot
.42442 .27482 Mdot
.54526 .21385 Mdot
.7228 .56056 Mdot
.31633 .30018 Mdot
.72411 .54514 Mdot
.27592 .58787 Mdot
.58904 .3674 Mdot
.5122 .71658 Mdot
.57847 .64507 Mdot
.68826 .29505 Mdot
.41609 .60677 Mdot
.26202 .59155 Mdot
.60028 .42465 Mdot
.63358 .60507 Mdot
.55976 .67723 Mdot
.50432 .7781 Mdot
.56347 .43968 Mdot
.35368 .42614 Mdot
.53176 .3831 Mdot
.59979 .34072 Mdot
.25331 .60025 Mdot
.56887 .41731 Mdot
.39091 .59487 Mdot
.32228 .37973 Mdot
.3879 .81517 Mdot
.51497 .64511 Mdot
.6037 .38355 Mdot
.56558 .38026 Mdot
.34443 .42744 Mdot
.613 .41314 Mdot
.43339 .6225 Mdot
.13137 .64224 Mdot
.71199 .56412 Mdot
.25267 .61108 Mdot
.49135 .78433 Mdot
.54377 .3891 Mdot
.53449 .4062 Mdot
.33931 .63846 Mdot
.21573 .42508 Mdot
.3893 .60035 Mdot
.62584 .38598 Mdot
.56752 .64595 Mdot
.71721 .54211 Mdot
.42446 .62957 Mdot
.57673 .42856 Mdot
.60025 .38346 Mdot
.72781 .55772 Mdot
.61364 .69879 Mdot
.55562 .70124 Mdot
.40484 .61267 Mdot
.65334 .44201 Mdot
.69616 .63573 Mdot
.59278 .38513 Mdot
.26469 .7047 Mdot
.36829 .39232 Mdot
.39167 .61752 Mdot
.46397 .34581 Mdot
.5189 .40783 Mdot
.38342 .62226 Mdot
.43072 .59735 Mdot
.58538 .43321 Mdot
.32108 .42721 Mdot
.33469 .36821 Mdot
.36876 .3901 Mdot
.61304 .23515 Mdot
.80166 .54385 Mdot
.5292 .63976 Mdot
.42776 .59983 Mdot
.51234 .62788 Mdot
.73585 .57225 Mdot
.47228 .53327 Mdot
.50505 .63878 Mdot
.39426 .40363 Mdot
.50687 .628 Mdot
.53021 .42143 Mdot
.43852 .60275 Mdot
.57654 .65101 Mdot
.54556 .39802 Mdot
.48735 .44348 Mdot
.62041 .51142 Mdot
.73913 .56263 Mdot
.4732 .54875 Mdot
.57369 .40537 Mdot
.25633 .60531 Mdot
.58332 .369 Mdot
.44575 .60213 Mdot
.58483 .52373 Mdot
.54815 .40696 Mdot
.57311 .63763 Mdot
.68821 .60632 Mdot
.51627 .66919 Mdot
.6154 .35771 Mdot
.57383 .39717 Mdot
.59474 .38458 Mdot
.53189 .37565 Mdot
.2308 .53393 Mdot
.42216 .57679 Mdot
.47797 .40158 Mdot
.58264 .63858 Mdot
.35797 .41247 Mdot
.3567 .43097 Mdot
.60524 .58288 Mdot
.25111 .59741 Mdot
.4399 .61347 Mdot
.59522 .38651 Mdot
.50472 .77767 Mdot
.29673 .62713 Mdot
.24799 .69401 Mdot
.62247 .62854 Mdot
.57504 .65182 Mdot
.37349 .37337 Mdot
.57527 .67841 Mdot
.59333 .42432 Mdot
.55317 .46218 Mdot
.40364 .81973 Mdot
.37993 .63151 Mdot
.71592 .54961 Mdot
.60359 .40747 Mdot
.75536 .35119 Mdot
.56975 .64821 Mdot
.56433 .69295 Mdot
.5357 .43501 Mdot
.32563 .36723 Mdot
.46648 .85511 Mdot
.44374 .60088 Mdot
.3716 .25314 Mdot
.38887 .35554 Mdot
.54654 .48956 Mdot
.41035 .59534 Mdot
.63843 .52913 Mdot
.51806 .66626 Mdot
.3387 .24289 Mdot
.36299 .40977 Mdot
.71287 .55166 Mdot
.62084 .42384 Mdot
.39504 .40201 Mdot
.49361 .64072 Mdot
.38117 .38688 Mdot
.52084 .42176 Mdot
.3969 .58015 Mdot
.53725 .67598 Mdot
.44535 .59065 Mdot
.3148 .40996 Mdot
.72336 .54249 Mdot
.69607 .31974 Mdot
.37358 .24807 Mdot
.52642 .28211 Mdot
.54807 .41358 Mdot
.5651 .74515 Mdot
.5644 .42887 Mdot
.36595 .36643 Mdot
.57998 .39011 Mdot
.41918 .44578 Mdot
.54415 .6885 Mdot
.61715 .34651 Mdot
.60919 .38196 Mdot
.34813 .24839 Mdot
.56429 .36558 Mdot
.59776 .42569 Mdot
.54752 .35201 Mdot
.41852 .37754 Mdot
.62986 .38056 Mdot
.35016 .42438 Mdot
.28476 .53265 Mdot
.54491 .64876 Mdot
.703 .57657 Mdot
.68202 .53058 Mdot
.7862 .40614 Mdot
.74419 .34454 Mdot
.26959 .55436 Mdot
.37759 .41519 Mdot
.38279 .60861 Mdot
.53274 .42928 Mdot
.43396 .34925 Mdot
.6624 .48393 Mdot
.52132 .66947 Mdot
.55157 .6263 Mdot
.637 .41221 Mdot
.83952 .57085 Mdot
.62758 .36608 Mdot
.34039 .53633 Mdot
.52633 .38729 Mdot
.57062 .33996 Mdot
.57013 .6921 Mdot
.71852 .33903 Mdot
.54782 .41283 Mdot
.38241 .37108 Mdot
.7096 .55453 Mdot
.66557 .41079 Mdot
.66953 .46328 Mdot
.60179 .50003 Mdot
.2778 .37704 Mdot
.56572 .42218 Mdot
.56735 .65864 Mdot
.39509 .39588 Mdot
.35147 .51254 Mdot
.40998 .61921 Mdot
.36843 .51922 Mdot
.39468 .22435 Mdot
.51719 .60965 Mdot
.71444 .55321 Mdot
.61896 .65299 Mdot
.55316 .38519 Mdot
.51978 .64114 Mdot
.52484 .426 Mdot
.29242 .63125 Mdot
.72919 .54337 Mdot
.30788 .39377 Mdot
.38569 .61622 Mdot
.37167 .42681 Mdot
.46783 .31859 Mdot
.66168 .47978 Mdot
.19623 .59927 Mdot
.5163 .63389 Mdot
.62844 .28659 Mdot
.33771 .38211 Mdot
.56769 .43512 Mdot
.11205 .41832 Mdot
.36532 .39255 Mdot
.36548 .42757 Mdot
.61207 .57916 Mdot
.70142 .35293 Mdot
.57354 .32165 Mdot
.38697 .39235 Mdot
.52663 .62008 Mdot
.69598 .53935 Mdot
.54003 .40359 Mdot
.54022 .35886 Mdot
.33387 .41817 Mdot
.55622 .6793 Mdot
.75714 .34741 Mdot
.52898 .65442 Mdot
.34632 .41816 Mdot
.54631 .66569 Mdot
.46585 .78582 Mdot
.55775 .63729 Mdot
.60857 .37647 Mdot
.59447 .3873 Mdot
.69036 .70191 Mdot
.37343 .39664 Mdot
.53634 .40268 Mdot
.59031 .40562 Mdot
.333 .38841 Mdot
.59434 .65624 Mdot
.53759 .28946 Mdot
.54965 .39432 Mdot
.59371 .39291 Mdot
.72136 .52874 Mdot
.49261 .55873 Mdot
.28286 .68449 Mdot
.53859 .40326 Mdot
.68101 .5507 Mdot
.3324 .37131 Mdot
.58102 .36761 Mdot
.72023 .33368 Mdot
.5038 .67247 Mdot
.60686 .41236 Mdot
.28098 .59308 Mdot
.54333 .37082 Mdot
.45982 .85525 Mdot
.60165 .37819 Mdot
.32953 .38397 Mdot
.34296 .38461 Mdot
.55344 .70256 Mdot
.35341 .40615 Mdot
.26017 .59537 Mdot
.42587 .61782 Mdot
.25024 .70627 Mdot
.26386 .59333 Mdot
.58428 .34207 Mdot
.30523 .25956 Mdot
.52805 .36733 Mdot
.59644 .43803 Mdot
.69879 .31068 Mdot
.26184 .59675 Mdot
.35311 .37825 Mdot
.3408 .73598 Mdot
.58229 .33739 Mdot
.4444 .60245 Mdot
.59272 .44494 Mdot
.60924 .40944 Mdot
.50054 .4891 Mdot
.60298 .24629 Mdot
.45316 .61255 Mdot
.50547 .43952 Mdot
.53905 .40503 Mdot
.23999 .38313 Mdot
.56134 .3847 Mdot
.69831 .56468 Mdot
.38586 .40883 Mdot
.57425 .68185 Mdot
.70395 .56016 Mdot
.54755 .38625 Mdot
.70991 .54873 Mdot
.53171 .63885 Mdot
.406 .62448 Mdot
.60894 .40005 Mdot
.68883 .52078 Mdot
.71863 .54757 Mdot
.55225 .43187 Mdot
.34679 .38843 Mdot
.64396 .35339 Mdot
.57924 .36604 Mdot
.57752 .43058 Mdot
.37823 .41946 Mdot
.34799 .19126 Mdot
.53844 .44327 Mdot
.63415 .53911 Mdot
.35187 .43441 Mdot
.25952 .62156 Mdot
.57805 .67182 Mdot
.51601 .42345 Mdot
.40926 .61071 Mdot
.41888 .61591 Mdot
.58322 .63211 Mdot
.31834 .40578 Mdot
.54398 .68052 Mdot
.49677 .39101 Mdot
.63419 .41763 Mdot
.62542 .42 Mdot
.66193 .19816 Mdot
.50329 .79784 Mdot
.32127 .38708 Mdot
.51876 .66934 Mdot
.38972 .51575 Mdot
.43877 .61274 Mdot
.58425 .63024 Mdot
.39056 .43634 Mdot
.34662 .372 Mdot
.39282 .40242 Mdot
.69435 .53054 Mdot
.52314 .65502 Mdot
.40112 .37699 Mdot
.31608 .37577 Mdot
.5489 .43959 Mdot
.53913 .40643 Mdot
.34717 .35302 Mdot
.79033 .47939 Mdot
.72777 .54883 Mdot
.56337 .65867 Mdot
.64312 .82586 Mdot
.44326 .59925 Mdot
.34544 .24972 Mdot
.54621 .39718 Mdot
.25288 .2195 Mdot
.62917 .39297 Mdot
.56404 .38219 Mdot
.33109 .37294 Mdot
.67456 .54301 Mdot
.70111 .53934 Mdot
.33824 .38256 Mdot
.303 .38788 Mdot
.68408 .54167 Mdot
.62593 .63642 Mdot
.27202 .7399 Mdot
.36114 .514 Mdot
.32855 .38836 Mdot
.34967 .26378 Mdot
.41894 .62954 Mdot
.34 .433 Mdot
.45061 .60723 Mdot
.54494 .64635 Mdot
.54786 .62706 Mdot
.42053 .63534 Mdot
.57375 .43593 Mdot
.54224 .63435 Mdot
.50574 .35654 Mdot
.44539 .81334 Mdot
.6663 .75342 Mdot
.19948 .43386 Mdot
.55375 .35599 Mdot
.26787 .48232 Mdot
.2421 .48627 Mdot
.5633 .40483 Mdot
.56777 .47525 Mdot
.71396 .54966 Mdot
.33943 .43088 Mdot
.44297 .61566 Mdot
.51685 .82086 Mdot
.59359 .38556 Mdot
.3405 .41269 Mdot
.43954 .60686 Mdot
.45531 .77795 Mdot
.4662 .47046 Mdot
.5316 .43219 Mdot
.08211 .50138 Mdot
.31202 .40429 Mdot
.57356 .68262 Mdot
.28587 .30041 Mdot
.33938 .43784 Mdot
.69993 .62559 Mdot
.54047 .69259 Mdot
.23846 .66031 Mdot
.36139 .37426 Mdot
.59071 .68605 Mdot
.34457 .40189 Mdot
.7229 .56825 Mdot
.314 .42175 Mdot
.54767 .67456 Mdot
.56748 .37132 Mdot
.54363 .67362 Mdot
.72945 .55914 Mdot
.52289 .63435 Mdot
.44174 .61754 Mdot
.25688 .60104 Mdot
.4352 .61048 Mdot
.47603 .53662 Mdot
.56813 .25174 Mdot
.39636 .61102 Mdot
.52686 .77342 Mdot
.53958 .37709 Mdot
.41748 .42699 Mdot
.57753 .67899 Mdot
.53919 .62127 Mdot
.45001 .53232 Mdot
.34236 .41057 Mdot
.55171 .67128 Mdot
.39804 .22583 Mdot
.45058 .14038 Mdot
.50562 .35128 Mdot
.78739 .56507 Mdot
.3316 .38908 Mdot
.55017 .69089 Mdot
.3435 .52262 Mdot
.38478 .42484 Mdot
.57351 .64115 Mdot
.39207 .62277 Mdot
.40826 .60274 Mdot
.56895 .44019 Mdot
.42574 .63896 Mdot
.52706 .68091 Mdot
.19569 .49254 Mdot
.38669 .40955 Mdot
.4651 .77416 Mdot
.68906 .55759 Mdot
.54076 .64253 Mdot
.58954 .32581 Mdot
.3096 .35535 Mdot
.55124 .6247 Mdot
.7314 .68687 Mdot
.68318 .80203 Mdot
.55213 .67029 Mdot
.38603 .40803 Mdot
.36281 .41603 Mdot
.55485 .32458 Mdot
.42445 .52086 Mdot
.55637 .67603 Mdot
.52723 .7249 Mdot
.79562 .42278 Mdot
.27836 .59812 Mdot
.26463 .29505 Mdot
.54849 .41229 Mdot
.57144 .42625 Mdot
.42352 .6258 Mdot
.55396 .37273 Mdot
.33605 .3657 Mdot
.61426 .42325 Mdot
.38674 .58913 Mdot
.52461 .67247 Mdot
.59296 .3747 Mdot
.70825 .53296 Mdot
.43383 .62364 Mdot
.38701 .6313 Mdot
.54589 .65838 Mdot
.39104 .39632 Mdot
.32649 .7365 Mdot
.52781 .65391 Mdot
.564 .42216 Mdot
.26786 .60198 Mdot
.51765 .41541 Mdot
.65772 .72398 Mdot
.3808 .42422 Mdot
.57334 .68117 Mdot
.38528 .43449 Mdot
.4297 .60494 Mdot
.56821 .62529 Mdot
.5613 .38964 Mdot
.56842 .63647 Mdot
.66614 .50893 Mdot
.64117 .68538 Mdot
.3134 .37679 Mdot
.71562 .51325 Mdot
.34177 .42508 Mdot
.27868 .59736 Mdot
.71204 .43523 Mdot
.71987 .5571 Mdot
.55758 .64048 Mdot
.49676 .80433 Mdot
.58654 .6596 Mdot
.56513 .36384 Mdot
.56428 .35678 Mdot
.57069 .67273 Mdot
.70813 .52915 Mdot
.73301 .3027 Mdot
.65815 .56575 Mdot
.36415 .37806 Mdot
.36227 .4768 Mdot
.58541 .84453 Mdot
.47205 .63518 Mdot
.38419 .62 Mdot
.51214 .45699 Mdot
.53049 .39692 Mdot
.40518 .63419 Mdot
.42713 .5841 Mdot
.73344 .54275 Mdot
.52312 .63888 Mdot
.40724 .41629 Mdot
.41654 .63134 Mdot
.61494 .30169 Mdot
.7327 .3355 Mdot
.53683 .33368 Mdot
.6251 .34855 Mdot
.59649 .35481 Mdot
.49588 .53557 Mdot
.40888 .57821 Mdot
.57781 .40428 Mdot
.61805 .43868 Mdot
.38971 .61271 Mdot
.72713 .56269 Mdot
.34291 .45006 Mdot
.55407 .66183 Mdot
.36803 .15136 Mdot
.60947 .39799 Mdot
.57139 .36859 Mdot
.40464 .6097 Mdot
.24608 .33529 Mdot
.32318 .39107 Mdot
.38929 .39894 Mdot
.53515 .64284 Mdot
.44446 .53399 Mdot
.61767 .40491 Mdot
.56664 .40529 Mdot
.55576 .64295 Mdot
.25761 .60358 Mdot
.1774 .45835 Mdot
.58781 .39718 Mdot
.41959 .59592 Mdot
.51682 .76657 Mdot
.4118 .5778 Mdot
.5279 .43156 Mdot
.5649 .36195 Mdot
.61134 .38148 Mdot
.53131 .3736 Mdot
.41783 .63375 Mdot
.5644 .40193 Mdot
.6497 .40391 Mdot
.36244 .38244 Mdot
.55459 .40935 Mdot
.77934 .40056 Mdot
.5891 .39114 Mdot
.70993 .53404 Mdot
.29007 .6973 Mdot
.60262 .39215 Mdot
.55703 .41211 Mdot
.65144 .55792 Mdot
.57154 .37841 Mdot
.42813 .59084 Mdot
.36374 .41234 Mdot
.42957 .60061 Mdot
.40271 .58722 Mdot
.52201 .62355 Mdot
.73685 .54953 Mdot
.51567 .37492 Mdot
.68248 .54856 Mdot
.58648 .32926 Mdot
.52091 .41946 Mdot
.48353 .55246 Mdot
.34015 .53826 Mdot
.66549 .52783 Mdot
.56574 .39367 Mdot
.53914 .64707 Mdot
.581 .66937 Mdot
.73269 .50248 Mdot
.5208 .34061 Mdot
.42693 .62992 Mdot
.40027 .62631 Mdot
.76655 .46089 Mdot
.48321 .47635 Mdot
.71703 .53795 Mdot
.39564 .50395 Mdot
.56257 .35079 Mdot
.59575 .40235 Mdot
.5832 .4502 Mdot
.50648 .63497 Mdot
.25416 .60513 Mdot
.52078 .66726 Mdot
.25956 .5834 Mdot
.41671 .57689 Mdot
.55584 .3553 Mdot
.62859 .77255 Mdot
.32045 .40254 Mdot
.3651 .41175 Mdot
.38098 .59694 Mdot
.51808 .67143 Mdot
.55371 .32616 Mdot
.67959 .20268 Mdot
.3733 .35965 Mdot
.68182 .56081 Mdot
.56996 .40798 Mdot
.54437 .65497 Mdot
.31525 .38833 Mdot
.72566 .52471 Mdot
.56434 .35291 Mdot
.59028 .65054 Mdot
.58385 .38949 Mdot
.37723 .30739 Mdot
.35607 .38177 Mdot
.28399 .63195 Mdot
.3166 .36959 Mdot
.39477 .62939 Mdot
.39515 .59285 Mdot
.57162 .35994 Mdot
.56151 .15008 Mdot
.30618 .37371 Mdot
.46317 .6217 Mdot
.72866 .56799 Mdot
.25403 .6121 Mdot
.73586 .55959 Mdot
.5501 .68546 Mdot
.7125 .55491 Mdot
.56944 .6343 Mdot
.7777 .48093 Mdot
.39155 .36783 Mdot
.7097 .56281 Mdot
.23338 .34568 Mdot
.52891 .44399 Mdot
.73004 .53515 Mdot
.63985 .40532 Mdot
.42908 .42766 Mdot
.55477 .64487 Mdot
.70611 .52998 Mdot
.55792 .43767 Mdot
.55629 .79986 Mdot
.39872 .5894 Mdot
.43092 .62869 Mdot
.51423 .38019 Mdot
.57893 .68343 Mdot
.30321 .39156 Mdot
.5883 .55638 Mdot
.2644 .6222 Mdot
.56686 .40437 Mdot
.56175 .35241 Mdot
.32886 .41913 Mdot
.37566 .36669 Mdot
.5655 .36022 Mdot
.41626 .2231 Mdot
.55273 .38619 Mdot
.40697 .59987 Mdot
.33395 .37472 Mdot
.36579 .41427 Mdot
.51126 .66862 Mdot
.31855 .40548 Mdot
.62525 .35264 Mdot
.37671 .58048 Mdot
.60873 .44173 Mdot
.42713 .60762 Mdot
.59795 .52217 Mdot
.51747 .64051 Mdot
.51582 .81475 Mdot
.31379 .39919 Mdot
.56482 .41668 Mdot
.34803 .42735 Mdot
.69032 .55558 Mdot
.37389 .39847 Mdot
.39889 .40232 Mdot
.57298 .35447 Mdot
.5295 .42974 Mdot
.26165 .60199 Mdot
.42482 .52239 Mdot
.35726 .38709 Mdot
.55432 .39296 Mdot
.53184 .35969 Mdot
.55319 .4481 Mdot
.49276 .51464 Mdot
.35063 .37066 Mdot
.5148 .20194 Mdot
.66479 .73396 Mdot
.35033 .38895 Mdot
.52445 .83759 Mdot
.28263 .60574 Mdot
.24986 .59853 Mdot
.4665 .61356 Mdot
.5915 .39655 Mdot
.54291 .67872 Mdot
.59639 .42155 Mdot
.50009 .36521 Mdot
.60413 .38869 Mdot
.73127 .5513 Mdot
.54804 .33734 Mdot
.27394 .6114 Mdot
.53051 .66011 Mdot
.54759 .39079 Mdot
.59621 .37746 Mdot
.25278 .59479 Mdot
.31422 .37023 Mdot
.35439 .37297 Mdot
.27315 .70979 Mdot
.71795 .56606 Mdot
.41192 .62221 Mdot
.58929 .4253 Mdot
.53747 .64536 Mdot
.53938 .67338 Mdot
.36919 .42747 Mdot
.5589 .65831 Mdot
.44622 .60336 Mdot
.55804 .38188 Mdot
.40711 .63449 Mdot
.73107 .55224 Mdot
.38562 .40942 Mdot
.58901 .42587 Mdot
.55131 .44008 Mdot
.34312 .38439 Mdot
.53987 .37544 Mdot
.7201 .52792 Mdot
.53825 .6281 Mdot
.34839 .37407 Mdot
.42426 .6175 Mdot
.50414 .65954 Mdot
.53314 .42693 Mdot
.76255 .71929 Mdot
.55222 .37349 Mdot
.59105 .4194 Mdot
.31627 .7801 Mdot
.56421 .46416 Mdot
.55008 .68899 Mdot
.35757 .43184 Mdot
.54675 .4508 Mdot
.81153 .4492 Mdot
.39812 .66725 Mdot
.58683 .6326 Mdot
.57027 .41185 Mdot
.49495 .82443 Mdot
.56158 .41167 Mdot
.44376 .77779 Mdot
.48146 .55067 Mdot
.81531 .57388 Mdot
.631 .35734 Mdot
.45453 .62851 Mdot
.26002 .60109 Mdot
.57976 .6776 Mdot
.42681 .33068 Mdot
.54678 .37299 Mdot
.47092 .33118 Mdot
.61298 .40506 Mdot
.4099 .59651 Mdot
.55289 .47335 Mdot
.56227 .65882 Mdot
.31458 .26281 Mdot
.56334 .42578 Mdot
.34461 .37105 Mdot
.51685 .62142 Mdot
.2602 .61781 Mdot
.55962 .43833 Mdot
.687 .55809 Mdot
.36072 .64089 Mdot
.63563 .39127 Mdot
.427 .61002 Mdot
.59058 .40786 Mdot
.49553 .42601 Mdot
.49733 .14634 Mdot
.36232 .38088 Mdot
.38615 .62089 Mdot
.26344 .43145 Mdot
.54156 .36687 Mdot
.35852 .37393 Mdot
.36074 .41077 Mdot
.70668 .57083 Mdot
.34311 .55837 Mdot
.45474 .66612 Mdot
.70585 .73255 Mdot
.50523 .2906 Mdot
.49925 .65407 Mdot
.21152 .46164 Mdot
.54225 .41101 Mdot
.66263 .47372 Mdot
.41884 .58797 Mdot
.57024 .37055 Mdot
.53783 .26137 Mdot
.37053 .39093 Mdot
.58318 .39681 Mdot
.72772 .55099 Mdot
.31531 .58737 Mdot
.61439 .49324 Mdot
.68733 .77745 Mdot
.55377 .61911 Mdot
.59979 .4426 Mdot
.64241 .37275 Mdot
.25711 .62043 Mdot
.52321 .41331 Mdot
.57622 .6817 Mdot
.57352 .74949 Mdot
.71428 .53012 Mdot
.31732 .39955 Mdot
.28063 .60972 Mdot
.61556 .37963 Mdot
.51537 .39176 Mdot
.70301 .57633 Mdot
.56649 .43311 Mdot
.29805 .28493 Mdot
.26872 .62861 Mdot
.55588 .6357 Mdot
.38302 .38761 Mdot
.59423 .35302 Mdot
.25483 .60605 Mdot
.56902 .35499 Mdot
.32812 .44841 Mdot
.57749 .41921 Mdot
.23146 .58301 Mdot
.34272 .39018 Mdot
.43044 .61076 Mdot
.51908 .36295 Mdot
.58796 .38075 Mdot
.69486 .63888 Mdot
.49848 .36864 Mdot
.60132 .37868 Mdot
.39334 .37921 Mdot
.3265 .40791 Mdot
.35712 .42549 Mdot
.54694 .63305 Mdot
.36864 .51135 Mdot
.41603 .60215 Mdot
.61413 .41717 Mdot
.41924 .63057 Mdot
.55112 .30973 Mdot
.69368 .57085 Mdot
.57303 .81725 Mdot
.54426 .38251 Mdot
.36795 .4233 Mdot
.19746 .51505 Mdot
.33026 .37189 Mdot
.46707 .5921 Mdot
.43343 .59842 Mdot
.36308 .39199 Mdot
.57338 .383 Mdot
.40194 .51377 Mdot
.72955 .74282 Mdot
.43576 .61581 Mdot
.56591 .45844 Mdot
.54633 .61875 Mdot
.57118 .63314 Mdot
.5101 .85884 Mdot
.39545 .58892 Mdot
.23848 .48246 Mdot
.55545 .39777 Mdot
.32364 .40732 Mdot
.40024 .61322 Mdot
.42495 .58832 Mdot
.5588 .64728 Mdot
.53648 .43817 Mdot
.58731 .38358 Mdot
.28203 .59468 Mdot
.40732 .62638 Mdot
.51407 .43528 Mdot
.5257 .39948 Mdot
.38751 .81784 Mdot
.40287 .42944 Mdot
.32071 .20725 Mdot
.49464 .40295 Mdot
.54802 .26378 Mdot
.51901 .52025 Mdot
.32104 .38436 Mdot
.58452 .43074 Mdot
.62138 .40648 Mdot
.50427 .66186 Mdot
.55475 .3795 Mdot
.50753 .65156 Mdot
.38256 .61699 Mdot
.58286 .82098 Mdot
.47608 .76686 Mdot
.60126 .62181 Mdot
.55826 .36933 Mdot
.55233 .494 Mdot
.69515 .55612 Mdot
.37521 .60074 Mdot
.33688 .41327 Mdot
.58314 .348 Mdot
.53665 .69149 Mdot
.56066 .64134 Mdot
.36337 .40515 Mdot
.2483 .50644 Mdot
.48099 .79605 Mdot
.53077 .37293 Mdot
.56989 .68184 Mdot
.4514 .76068 Mdot
.44388 .21982 Mdot
.435 .63671 Mdot
.71939 .53369 Mdot
.52737 .67391 Mdot
.38147 .62884 Mdot
.37064 .45755 Mdot
.35735 .39959 Mdot
.32165 .41505 Mdot
.67549 .68998 Mdot
.55245 .67703 Mdot
.69654 .55139 Mdot
.45792 .45428 Mdot
.42543 .4592 Mdot
.72935 .54571 Mdot
.52339 .67195 Mdot
.31872 .39724 Mdot
.34252 .41476 Mdot
.36212 .41306 Mdot
.3081 .27203 Mdot
.38684 .41879 Mdot
.47001 .18171 Mdot
.5251 .3734 Mdot
.36112 .26209 Mdot
.56417 .41218 Mdot
.44002 .62942 Mdot
.35425 .3817 Mdot
.46641 .52737 Mdot
.56848 .34404 Mdot
.69497 .76864 Mdot
.57278 .4062 Mdot
.36366 .5914 Mdot
.59302 .39496 Mdot
.30734 .29816 Mdot
.35087 .43428 Mdot
.56433 .39395 Mdot
.45725 .61224 Mdot
.71526 .54491 Mdot
.29388 .39806 Mdot
.60116 .38951 Mdot
.29487 .56973 Mdot
.6204 .43506 Mdot
.46465 .80843 Mdot
.66747 .60356 Mdot
.67809 .55528 Mdot
.6296 .41793 Mdot
.49578 .63372 Mdot
.29514 .37419 Mdot
.34562 .27728 Mdot
.43459 .61676 Mdot
.63933 .27664 Mdot
.55389 .6387 Mdot
.55593 .47315 Mdot
.60181 .34508 Mdot
.69679 .52846 Mdot
.29695 .38519 Mdot
.40448 .59896 Mdot
.54204 .37662 Mdot
.59085 .42923 Mdot
.74264 .66281 Mdot
.33661 .28044 Mdot
.51119 .42866 Mdot
.73374 .57236 Mdot
.52518 .20615 Mdot
.6007 .40049 Mdot
.59013 .6454 Mdot
.37133 .4342 Mdot
.60462 .33228 Mdot
.50096 .19959 Mdot
.55229 .39022 Mdot
.36452 .39588 Mdot
.31457 .40165 Mdot
.21982 .56 Mdot
.68466 .56303 Mdot
.5778 .41921 Mdot
.71231 .63569 Mdot
.56807 .42555 Mdot
.41236 .60022 Mdot
.53302 .44043 Mdot
.54607 .64227 Mdot
.33906 .52592 Mdot
.54008 .63076 Mdot
.56198 .44452 Mdot
.34943 .41427 Mdot
.40174 .60233 Mdot
.66535 .7064 Mdot
.56863 .56037 Mdot
.48125 .1821 Mdot
.36177 .64541 Mdot
.69494 .53238 Mdot
.73562 .53999 Mdot
.41512 .57187 Mdot
.5712 .39642 Mdot
.5172 .54001 Mdot
.61989 .35349 Mdot
.59636 .39421 Mdot
.60751 .39915 Mdot
.37404 .62815 Mdot
.43474 .60274 Mdot
.54631 .66924 Mdot
.5628 .36099 Mdot
.5553 .39353 Mdot
.35048 .39304 Mdot
.7191 .54673 Mdot
.55468 .63286 Mdot
.70915 .56589 Mdot
.53283 .65527 Mdot
.47245 .85185 Mdot
.55014 .45368 Mdot
.71457 .54374 Mdot
.40355 .57734 Mdot
.37374 .42291 Mdot
.26305 .59018 Mdot
.54657 .68402 Mdot
.5613 .66171 Mdot
.56411 .40358 Mdot
.38392 .40362 Mdot
.37915 .39221 Mdot
.68603 .53801 Mdot
.39725 .6203 Mdot
.57313 .43956 Mdot
.52564 .41302 Mdot
.77829 .60215 Mdot
.49925 .64505 Mdot
.43803 .21149 Mdot
.23744 .54796 Mdot
.57048 .39562 Mdot
.3749 .38445 Mdot
.58952 .37234 Mdot
.57278 .77392 Mdot
.39454 .40225 Mdot
.54706 .34975 Mdot
.4799 .4627 Mdot
.5147 .62975 Mdot
.20696 .5885 Mdot
.52613 .35869 Mdot
.33783 .63966 Mdot
.5464 .42454 Mdot
.26848 .76261 Mdot
.223 .41525 Mdot
.61724 .39195 Mdot
.53523 .36888 Mdot
.73719 .70794 Mdot
.55658 .40296 Mdot
.2794 .60665 Mdot
.50203 .37459 Mdot
.35056 .37219 Mdot
.54029 .5348 Mdot
.48988 .56738 Mdot
.70702 .57455 Mdot
.53499 .64216 Mdot
.70032 .3946 Mdot
.72431 .56627 Mdot
.33127 .38487 Mdot
.54261 .35602 Mdot
.60143 .28833 Mdot
.53672 .69787 Mdot
.60221 .34115 Mdot
.41168 .59889 Mdot
.48587 .564 Mdot
.51388 .65568 Mdot
.42814 .61669 Mdot
.61389 .39556 Mdot
.80014 .39587 Mdot
.57626 .56971 Mdot
.21146 .65182 Mdot
.40489 .61239 Mdot
.42237 .59121 Mdot
.34388 .5063 Mdot
.70682 .57444 Mdot
.75854 .6409 Mdot
.61507 .4784 Mdot
.44331 .60359 Mdot
.74279 .42616 Mdot
.55698 .69565 Mdot
.3393 .55978 Mdot
.34209 .43261 Mdot
.55801 .45423 Mdot
.57695 .38214 Mdot
.393 .61654 Mdot
.45875 .35954 Mdot
.29365 .43605 Mdot
.43544 .61246 Mdot
.64859 .37977 Mdot
.32362 .59098 Mdot
.26712 .59887 Mdot
.28423 .5976 Mdot
.72725 .57132 Mdot
.59965 .71586 Mdot
.33943 .39891 Mdot
.70063 .52581 Mdot
.23108 .60066 Mdot
.58231 .41814 Mdot
.4094 .62788 Mdot
.27353 .587 Mdot
.41733 .61339 Mdot
.70591 .53829 Mdot
.68346 .56279 Mdot
.36246 .38213 Mdot
.32342 .39241 Mdot
.60102 .2494 Mdot
.7705 .4439 Mdot
.5563 .40758 Mdot
.52871 .29209 Mdot
.38384 .41749 Mdot
.31055 .32063 Mdot
.6833 .55685 Mdot
.72224 .54811 Mdot
.39713 .2787 Mdot
.54 .43676 Mdot
.4962 .76685 Mdot
.60172 .39371 Mdot
.71232 .44726 Mdot
.59203 .34242 Mdot
.55942 .65096 Mdot
.55465 .41625 Mdot
.31109 .71405 Mdot
.53883 .39416 Mdot
.60703 .3888 Mdot
.52768 .66657 Mdot
.51159 .37132 Mdot
.54749 .64099 Mdot
.53112 .43484 Mdot
.72197 .58193 Mdot
.53717 .64535 Mdot
.79067 .54505 Mdot
.63289 .53655 Mdot
.25783 .61037 Mdot
.72565 .56885 Mdot
.68461 .55171 Mdot
.77789 .38582 Mdot
.33223 .40869 Mdot
.39632 .45275 Mdot
.57226 .39702 Mdot
.56592 .69213 Mdot
.42104 .62705 Mdot
.5538 .39033 Mdot
.6223 .41099 Mdot
.51927 .36601 Mdot
.36634 .38893 Mdot
.5282 .6777 Mdot
.70826 .54534 Mdot
.58 .66646 Mdot
.63216 .59679 Mdot
.58224 .64498 Mdot
.49978 .45066 Mdot
.49699 .4076 Mdot
.61488 .3154 Mdot
.54106 .27939 Mdot
.34174 .2383 Mdot
.35803 .40364 Mdot
.2688 .60718 Mdot
.70399 .57514 Mdot
.36021 .47514 Mdot
.35786 .42209 Mdot
.56051 .66559 Mdot
.58375 .38938 Mdot
.6491 .37667 Mdot
.59734 .49467 Mdot
.36046 .34861 Mdot
.80226 .45233 Mdot
.51927 .64901 Mdot
.27382 .59587 Mdot
.35413 .51881 Mdot
.41538 .37956 Mdot
.47118 .52988 Mdot
.58988 .37738 Mdot
.68432 .5546 Mdot
.31523 .38843 Mdot
.70325 .6879 Mdot
.39242 .62079 Mdot
.42299 .52121 Mdot
.55711 .3708 Mdot
.21267 .48678 Mdot
.34947 .41401 Mdot
.72497 .54548 Mdot
.39256 .61577 Mdot
.68464 .56197 Mdot
.28259 .60847 Mdot
.28969 .71783 Mdot
.55975 .43255 Mdot
.60101 .37559 Mdot
.43739 .58544 Mdot
.34054 .40187 Mdot
.58458 .69737 Mdot
.71256 .6927 Mdot
.57046 .68007 Mdot
.50612 .5428 Mdot
.32087 .38114 Mdot
.27666 .35612 Mdot
.57458 .64567 Mdot
.3871 .58605 Mdot
.5056 .53257 Mdot
.38737 .58922 Mdot
.60393 .3984 Mdot
.37638 .41392 Mdot
.39442 .58944 Mdot
.70402 .66012 Mdot
.44987 .83615 Mdot
.29219 .40662 Mdot
.54433 .36872 Mdot
.5819 .81879 Mdot
.36484 .79748 Mdot
.48936 .3342 Mdot
.41186 .63114 Mdot
.57881 .36234 Mdot
.53048 .37214 Mdot
.56189 .42412 Mdot
.38491 .60511 Mdot
.60932 .60165 Mdot
.56728 .65401 Mdot
.57763 .40818 Mdot
.68868 .55649 Mdot
.55054 .64972 Mdot
.5036 .62722 Mdot
.58371 .67118 Mdot
.39584 .39503 Mdot
.53509 .36264 Mdot
.32391 .5589 Mdot
.29618 .78399 Mdot
.43255 .60251 Mdot
.25803 .6108 Mdot
.61118 .39103 Mdot
.59033 .21487 Mdot
.35875 .4254 Mdot
.56995 .67941 Mdot
.57199 .36951 Mdot
.66867 .6206 Mdot
.30004 .58798 Mdot
.52497 .65113 Mdot
.33536 .4107 Mdot
.48901 .33529 Mdot
.55427 .38016 Mdot
.54524 .42628 Mdot
.33457 .394 Mdot
.24741 .69153 Mdot
.34403 .53275 Mdot
.59187 .375 Mdot
.43095 .61209 Mdot
.47325 .13763 Mdot
.51471 .38737 Mdot
.33225 .34752 Mdot
.253 .6111 Mdot
.25419 .56347 Mdot
.45335 .21062 Mdot
.48324 .39133 Mdot
.60909 .79652 Mdot
.71096 .33349 Mdot
.5606 .82253 Mdot
.68511 .42986 Mdot
.40699 .73953 Mdot
.41949 .858 Mdot
.45971 .61763 Mdot
.31366 .3014 Mdot
.79874 .61933 Mdot
.26672 .50866 Mdot
.64609 .59222 Mdot
.45523 .68945 Mdot
.67887 .61476 Mdot
.18904 .39465 Mdot
.58037 .64706 Mdot
.69296 .47027 Mdot
.58209 .43396 Mdot
.35699 .78999 Mdot
.36173 .24925 Mdot
.35042 .22386 Mdot
.55684 .8146 Mdot
.71011 .62815 Mdot
.76707 .70107 Mdot
.51313 .81041 Mdot
.63759 .28801 Mdot
.5467 .50296 Mdot
.52412 .70789 Mdot
.44402 .45017 Mdot
.70125 .37919 Mdot
.58387 .31784 Mdot
.305 .69086 Mdot
.59797 .63512 Mdot
.54264 .23292 Mdot
.46487 .1484 Mdot
.54449 .68586 Mdot
.37479 .43342 Mdot
.77614 .62462 Mdot
.29156 .3661 Mdot
.45383 .5833 Mdot
.61017 .79625 Mdot
.38768 .82109 Mdot
.30866 .29573 Mdot
.22924 .63003 Mdot
.40529 .30832 Mdot
.72613 .28594 Mdot
.5967 .50727 Mdot
.3084 .38632 Mdot
.43955 .72585 Mdot
.42601 .45837 Mdot
.55958 .7165 Mdot
.28704 .31334 Mdot
.71527 .51798 Mdot
.80501 .50868 Mdot
.3373 .41057 Mdot
.46218 .218 Mdot
.24741 .60437 Mdot
.23457 .60254 Mdot
.58182 .69254 Mdot
.58462 .76958 Mdot
.30583 .58765 Mdot
.30868 .56944 Mdot
.19143 .48549 Mdot
.73553 .75152 Mdot
.73015 .37292 Mdot
.59071 .74699 Mdot
.35854 .58568 Mdot
.71535 .33927 Mdot
.31555 .52073 Mdot
.76205 .41309 Mdot
.43012 .44545 Mdot
.84623 .58836 Mdot
.28572 .74153 Mdot
.79985 .66292 Mdot
.36659 .44895 Mdot
.52525 .44135 Mdot
.61811 .75266 Mdot
.48993 .29999 Mdot
.67303 .54265 Mdot
.71452 .76429 Mdot
.67989 .53594 Mdot
.40517 .41655 Mdot
.25833 .50272 Mdot
.3151 .27451 Mdot
.60884 .67178 Mdot
.7136 .58714 Mdot
.62913 .36562 Mdot
.88619 .5076 Mdot
.6334 .79074 Mdot
.2283 .56183 Mdot
.37773 .81474 Mdot
.46221 .63953 Mdot
.50557 .67683 Mdot
.38181 .61264 Mdot
.42756 .8475 Mdot
.3628 .41911 Mdot
.31061 .7999 Mdot
.42012 .83986 Mdot
.26488 .38615 Mdot
.89846 .471 Mdot
.192 .42791 Mdot
.37227 .25386 Mdot
.67534 .30788 Mdot
.8168 .50581 Mdot
.31941 .4989 Mdot
.25915 .37027 Mdot
.48097 .63208 Mdot
.24129 .69415 Mdot
.47879 .84518 Mdot
.73784 .4407 Mdot
.53629 .60744 Mdot
.27947 .50402 Mdot
.61472 .51608 Mdot
.33451 .3504 Mdot
.65429 .57337 Mdot
.6497 .50332 Mdot
.78547 .68029 Mdot
.58344 .22893 Mdot
.60103 .16151 Mdot
.69201 .43281 Mdot
.2503 .33016 Mdot
.50676 .79358 Mdot
.78121 .5407 Mdot
.31299 .44369 Mdot
.28734 .54019 Mdot
.58582 .45769 Mdot
.3815 .50253 Mdot
.64902 .41482 Mdot
.7348 .5224 Mdot
.35651 .50999 Mdot
.40832 .77352 Mdot
.70591 .43074 Mdot
.68803 .73799 Mdot
.51334 .49171 Mdot
.38466 .38424 Mdot
.76339 .39051 Mdot
.73461 .39787 Mdot
.4058 .81917 Mdot
.26274 .43275 Mdot
.2164 .66222 Mdot
.2677 .42417 Mdot
.62209 .35644 Mdot
.3164 .3049 Mdot
.59667 .31966 Mdot
.75123 .40915 Mdot
.55039 .34215 Mdot
.18869 .50257 Mdot
.3265 .78877 Mdot
.55315 .25163 Mdot
.70665 .40219 Mdot
.55959 .27423 Mdot
.25428 .71099 Mdot
.62923 .75236 Mdot
.22609 .43141 Mdot
.35906 .33681 Mdot
.87396 .53492 Mdot
.54998 .65988 Mdot
.74638 .43388 Mdot
.36859 .60793 Mdot
.67696 .69414 Mdot
.82303 .58659 Mdot
.27647 .41755 Mdot
.31655 .78337 Mdot
.30077 .5411 Mdot
.60152 .68979 Mdot
.34204 .57187 Mdot
.48247 .62237 Mdot
.58737 .27398 Mdot
.51135 .38427 Mdot
.60988 .30595 Mdot
.71195 .52325 Mdot
.46961 .30401 Mdot
.65016 .73693 Mdot
.37432 .68207 Mdot
.47992 .42032 Mdot
.38825 .70047 Mdot
.27704 .59435 Mdot
.40429 .52023 Mdot
.50027 .85991 Mdot
.49087 .39466 Mdot
.20703 .39708 Mdot
.28049 .73211 Mdot
.49675 .53915 Mdot
.61634 .69681 Mdot
.22476 .52666 Mdot
.82634 .62684 Mdot
.37719 .82763 Mdot
.39187 .79084 Mdot
.59149 .81735 Mdot
.165 .60556 Mdot
.84322 .5372 Mdot
.41921 .34495 Mdot
.36916 .61924 Mdot
.11908 .60724 Mdot
.57325 .66315 Mdot
.64499 .27446 Mdot
.49277 .29573 Mdot
.66624 .62907 Mdot
.29846 .36655 Mdot
.47596 .43537 Mdot
.39019 .65622 Mdot
.33948 .35616 Mdot
.62947 .36955 Mdot
.67715 .79947 Mdot
.85056 .5856 Mdot
.69659 .78438 Mdot
.29297 .72301 Mdot
.578 .82632 Mdot
.78248 .65805 Mdot
.45845 .18232 Mdot
.76033 .64632 Mdot
.53132 .43814 Mdot
.75378 .46519 Mdot
.19795 .4238 Mdot
.59119 .6884 Mdot
.24283 .62943 Mdot
.37816 .44241 Mdot
.83076 .60155 Mdot
.51273 .86413 Mdot
.42067 .27686 Mdot
.51276 .2201 Mdot
.64225 .51818 Mdot
.75934 .43003 Mdot
.64016 .31337 Mdot
.30601 .67733 Mdot
.44348 .81673 Mdot
.79053 .64773 Mdot
.7277 .40879 Mdot
.44035 .69597 Mdot
.39201 .7824 Mdot
.24347 .3665 Mdot
.54266 .79951 Mdot
.78721 .61532 Mdot
.26353 .40013 Mdot
.42621 .37805 Mdot
.28766 .42964 Mdot
.29654 .66304 Mdot
.54046 .75195 Mdot
.7199 .36754 Mdot
.52013 .63474 Mdot
.74163 .44703 Mdot
.46343 .49432 Mdot
.76696 .64054 Mdot
.72366 .33825 Mdot
.73307 .44429 Mdot
.4101 .79204 Mdot
.64544 .80959 Mdot
.21971 .63729 Mdot
.82228 .42026 Mdot
.32792 .64187 Mdot
.64026 .43173 Mdot
.51504 .42399 Mdot
.29135 .75554 Mdot
.61996 .83276 Mdot
.33061 .79826 Mdot
.21078 .48292 Mdot
.6956 .6624 Mdot
.40697 .63844 Mdot
.72497 .31587 Mdot
.35191 .66444 Mdot
.45194 .82178 Mdot
.37328 .48494 Mdot
.46901 .61971 Mdot
.30985 .54175 Mdot
.63148 .27675 Mdot
.69445 .31269 Mdot
.48029 .229 Mdot
.54233 .32925 Mdot
.40458 .23242 Mdot
.3535 .43303 Mdot
.21316 .46901 Mdot
.75936 .41799 Mdot
.5468 .6579 Mdot
.79351 .57892 Mdot
.62562 .31034 Mdot
.56426 .46488 Mdot
.55395 .74599 Mdot
.33062 .35167 Mdot
.5415 .27642 Mdot
.4933 .66199 Mdot
.43961 .8599 Mdot
.20721 .43053 Mdot
.62638 .29498 Mdot
.74507 .36958 Mdot
.76596 .60968 Mdot
.35078 .5344 Mdot
.40413 .57397 Mdot
.54487 .81396 Mdot
.62427 .55592 Mdot
.75739 .38347 Mdot
.41358 .22804 Mdot
.69031 .70868 Mdot
.62314 .40522 Mdot
.21783 .54304 Mdot
.51883 .18643 Mdot
.41535 .52305 Mdot
.41204 .40431 Mdot
.37925 .36119 Mdot
.18406 .36662 Mdot
.32588 .72236 Mdot
.24806 .41734 Mdot
.55384 .80547 Mdot
.38338 .59841 Mdot
.38149 .37339 Mdot
.73337 .45527 Mdot
.64379 .68779 Mdot
.55017 .2169 Mdot
.55065 .75829 Mdot
.66167 .32522 Mdot
.34745 .67179 Mdot
.5879 .8144 Mdot
.69871 .75644 Mdot
.51071 .14402 Mdot
.32878 .36425 Mdot
.64642 .72696 Mdot
.66648 .71563 Mdot
.31371 .38025 Mdot
.35242 .34744 Mdot
.57696 .49896 Mdot
.54752 .83487 Mdot
.40305 .4856 Mdot
.29862 .64418 Mdot
.50597 .53386 Mdot
.64386 .61075 Mdot
.71544 .68258 Mdot
.71106 .36357 Mdot
.56097 .79839 Mdot
.46303 .22658 Mdot
.83071 .49212 Mdot
.62995 .32869 Mdot
.6129 .24664 Mdot
.72498 .31527 Mdot
.572 .51218 Mdot
.28975 .31545 Mdot
.42825 .77676 Mdot
.56303 .42027 Mdot
.72822 .76116 Mdot
.40416 .81311 Mdot
.36459 .49762 Mdot
.49644 .68172 Mdot
.5338 .41323 Mdot
.52841 .36852 Mdot
.4354 .36842 Mdot
.24739 .55693 Mdot
.84742 .48791 Mdot
.69874 .44455 Mdot
.64586 .42421 Mdot
.40703 .22758 Mdot
.2079 .39633 Mdot
.60121 .75869 Mdot
.47867 .8053 Mdot
.44596 .495 Mdot
.19896 .42622 Mdot
.42537 .53828 Mdot
.28947 .64388 Mdot
.35299 .69691 Mdot
.77556 .66559 Mdot
.54974 .4859 Mdot
.26557 .54582 Mdot
.75096 .64293 Mdot
.61043 .39521 Mdot
.24823 .50691 Mdot
.526 .80376 Mdot
.6465 .19313 Mdot
.30685 .51117 Mdot
.65411 .81692 Mdot
.61375 .31158 Mdot
.27965 .54838 Mdot
.83261 .57807 Mdot
.73734 .24738 Mdot
.29939 .68403 Mdot
.77324 .69577 Mdot
.36959 .5434 Mdot
.5619 .80479 Mdot
.44723 .63212 Mdot
.45941 .46813 Mdot
.49683 .31284 Mdot
.54066 .83588 Mdot
.61933 .71801 Mdot
.58755 .77845 Mdot
.42721 .36209 Mdot
.57898 .83222 Mdot
.42629 .44376 Mdot
.19959 .34972 Mdot
.5915 .64273 Mdot
.17392 .49785 Mdot
.37751 .33547 Mdot
.66038 .3498 Mdot
.73854 .42416 Mdot
.24272 .30911 Mdot
.40756 .19399 Mdot
.43649 .35136 Mdot
.73679 .48564 Mdot
.23131 .53589 Mdot
.74117 .36305 Mdot
.45202 .8264 Mdot
.19078 .38427 Mdot
.69087 .70068 Mdot
.23799 .45692 Mdot
.27126 .71198 Mdot
.24074 .56082 Mdot
.35924 .72177 Mdot
.58512 .75316 Mdot
.26336 .66613 Mdot
.66627 .33328 Mdot
.26872 .2187 Mdot
.5112 .59147 Mdot
.58541 .49741 Mdot
.81557 .63607 Mdot
.43841 .81657 Mdot
.35999 .47841 Mdot
.28244 .31176 Mdot
.65227 .25712 Mdot
.77923 .4851 Mdot
.60387 .38846 Mdot
.58649 .8315 Mdot
.79034 .52006 Mdot
.74013 .73716 Mdot
.23469 .70486 Mdot
.41476 .23754 Mdot
.49442 .4327 Mdot
.48838 .62896 Mdot
.62083 .49746 Mdot
.72771 .487 Mdot
.7876 .66475 Mdot
.63077 .26155 Mdot
.56803 .55574 Mdot
.40582 .73211 Mdot
.51245 .77598 Mdot
.61641 .46482 Mdot
.18736 .44445 Mdot
.24444 .54568 Mdot
.69649 .41673 Mdot
.37676 .7748 Mdot
.74984 .42347 Mdot
.444 .21152 Mdot
.7286 .32783 Mdot
.30596 .47 Mdot
.4384 .65725 Mdot
.51516 .67402 Mdot
.72769 .71111 Mdot
.48938 .79466 Mdot
.18902 .50803 Mdot
.82563 .44392 Mdot
.28159 .53566 Mdot
.69125 .47929 Mdot
.67978 .73189 Mdot
.31226 .49536 Mdot
.5243 .71221 Mdot
.68819 .30685 Mdot
.60594 .24642 Mdot
.44963 .78673 Mdot
.47311 .39859 Mdot
.48251 .84806 Mdot
.71739 .36908 Mdot
.7306 .69096 Mdot
.62895 .52756 Mdot
.49768 .27685 Mdot
.36245 .2878 Mdot
.80324 .53952 Mdot
.44305 .53191 Mdot
.88234 .51598 Mdot
.30843 .40583 Mdot
.73817 .74887 Mdot
.41456 .6232 Mdot
.55656 .16811 Mdot
.44917 .80181 Mdot
.45704 .50536 Mdot
.50676 .52432 Mdot
.21656 .54666 Mdot
.30168 .57443 Mdot
.26388 .71138 Mdot
.28075 .41989 Mdot
.58756 .65604 Mdot
.58589 .56413 Mdot
.30024 .65013 Mdot
.68722 .74592 Mdot
.55982 .44972 Mdot
.61018 .67392 Mdot
.58592 .51134 Mdot
.44078 .56037 Mdot
.2964 .75814 Mdot
.43396 .76856 Mdot
.61717 .3363 Mdot
.76193 .43157 Mdot
.80137 .64009 Mdot
.42426 .83608 Mdot
.31268 .45315 Mdot
.65028 .41155 Mdot
.37221 .58242 Mdot
.81626 .5666 Mdot
.63455 .78536 Mdot
.486 .7686 Mdot
.33581 .55973 Mdot
.72921 .37675 Mdot
.7267 .78122 Mdot
.84879 .58639 Mdot
.83154 .44641 Mdot
.51163 .5379 Mdot
.41964 .42547 Mdot
.59413 .21894 Mdot
.72657 .69517 Mdot
.16989 .51964 Mdot
.40036 .80306 Mdot
.74623 .42857 Mdot
.69803 .23143 Mdot
.36733 .22385 Mdot
.61938 .59238 Mdot
.36381 .28878 Mdot
.51496 .28644 Mdot
.45719 .63034 Mdot
.77432 .49377 Mdot
.61073 .5659 Mdot
.45193 .58474 Mdot
.23371 .5381 Mdot
.31115 .57506 Mdot
.73458 .68668 Mdot
.53755 .20294 Mdot
.65757 .39128 Mdot
.65462 .76263 Mdot
.3958 .37115 Mdot
.69671 .69245 Mdot
.76606 .61317 Mdot
.61199 .57342 Mdot
.5785 .66298 Mdot
.55481 .31898 Mdot
.3805 .524 Mdot
.40049 .53269 Mdot
.7762 .34192 Mdot
.68396 .52664 Mdot
.33695 .4393 Mdot
.32562 .25185 Mdot
.3357 .36459 Mdot
.60028 .84272 Mdot
.3073 .67819 Mdot
.39373 .23496 Mdot
.48756 .59534 Mdot
.44445 .70982 Mdot
.76886 .31103 Mdot
.63449 .28293 Mdot
.66534 .5748 Mdot
.42654 .40915 Mdot
.34278 .42716 Mdot
.48828 .6033 Mdot
.26378 .62686 Mdot
.48628 .2187 Mdot
.20342 .39086 Mdot
.77074 .6058 Mdot
.30983 .37711 Mdot
.61582 .59571 Mdot
.55025 .29989 Mdot
.48844 .8564 Mdot
.58267 .6658 Mdot
.87004 .54743 Mdot
.49729 .41173 Mdot
.83212 .53938 Mdot
.30026 .76395 Mdot
.33627 .5236 Mdot
.51874 .54303 Mdot
.48421 .69394 Mdot
.60116 .43474 Mdot
.65986 .3907 Mdot
.3279 .39847 Mdot
.7507 .65675 Mdot
.71654 .55379 Mdot
.79182 .44345 Mdot
.39813 .57399 Mdot
.25505 .3428 Mdot
.19111 .44769 Mdot
.36697 .43674 Mdot
.63035 .56865 Mdot
.62318 .73371 Mdot
.50826 .49651 Mdot
.58337 .51199 Mdot
.73795 .70508 Mdot
.55106 .22499 Mdot
.30959 .38655 Mdot
.83029 .45185 Mdot
.67441 .49759 Mdot
.39613 .84321 Mdot
.50891 .32805 Mdot
.58976 .50604 Mdot
.5146 .49556 Mdot
.21771 .53344 Mdot
.46225 .2098 Mdot
.46876 .81078 Mdot
.7639 .39868 Mdot
.45862 .44987 Mdot
.73434 .44688 Mdot
.60168 .32525 Mdot
.39971 .73178 Mdot
.17311 .47992 Mdot
.71114 .24377 Mdot
.38709 .30849 Mdot
.31916 .5341 Mdot
.39608 .36799 Mdot
.20636 .40062 Mdot
.31323 .41771 Mdot
.63339 .624 Mdot
.54725 .23598 Mdot
.44843 .80278 Mdot
.44092 .85228 Mdot
.40452 .81818 Mdot
.64177 .4878 Mdot
.50141 .77554 Mdot
.68323 .3173 Mdot
.51519 .31963 Mdot
.46967 .52005 Mdot
.6077 .4291 Mdot
.60397 .4699 Mdot
.32845 .47275 Mdot
.19569 .51536 Mdot
.53125 .47092 Mdot
.53123 .83236 Mdot
.39206 .83932 Mdot
.61964 .81413 Mdot
.53874 .74939 Mdot
.39843 .3983 Mdot
.83328 .6147 Mdot
.42854 .20395 Mdot
.44332 .82826 Mdot
.38379 .33649 Mdot
.17248 .39011 Mdot
.8174 .59933 Mdot
.41775 .77773 Mdot
.26236 .37752 Mdot
.20546 .60038 Mdot
.30524 .76196 Mdot
.19859 .3519 Mdot
.6789 .34878 Mdot
.28431 .74574 Mdot
.88471 .50568 Mdot
.39664 .33346 Mdot
.30417 .57044 Mdot
.35259 .28546 Mdot
.66822 .3109 Mdot
.20127 .37829 Mdot
.52637 .43643 Mdot
.55226 .62448 Mdot
.65823 .60265 Mdot
.74365 .41783 Mdot
.51662 .33328 Mdot
.20663 .36547 Mdot
.72269 .48754 Mdot
.68936 .47233 Mdot
.65187 .71423 Mdot
.80276 .6156 Mdot
.4768 .21147 Mdot
.64375 .3727 Mdot
.39666 .43506 Mdot
.73382 .55954 Mdot
.69324 .38307 Mdot
.52939 .40489 Mdot
.47596 .54983 Mdot
.58547 .4934 Mdot
.67241 .80466 Mdot
.64806 .6528 Mdot
.60414 .62815 Mdot
.35797 .35642 Mdot
.23907 .55311 Mdot
.62329 .76485 Mdot
.2635 .50615 Mdot
.22175 .34372 Mdot
.5798 .23313 Mdot
.59842 .80872 Mdot
.30068 .54733 Mdot
.71625 .4011 Mdot
.7465 .3107 Mdot
.44759 .62499 Mdot
.49218 .31127 Mdot
.77974 .6697 Mdot
.25973 .52043 Mdot
.40315 .38689 Mdot
.38302 .76297 Mdot
.42264 .74348 Mdot
.24957 .52606 Mdot
.27885 .72968 Mdot
.65932 .72718 Mdot
.38958 .26461 Mdot
.68593 .76198 Mdot
.52312 .62005 Mdot
.72948 .41399 Mdot
.34966 .73862 Mdot
.19578 .38401 Mdot
.50214 .48997 Mdot
.49814 .84427 Mdot
.47424 .52144 Mdot
.79843 .52308 Mdot
.55367 .43134 Mdot
.5085 .19984 Mdot
.20402 .52047 Mdot
.37476 .76871 Mdot
.25243 .42673 Mdot
.39717 .41577 Mdot
.19617 .46821 Mdot
.52533 .70496 Mdot
.7882 .50094 Mdot
.68238 .37433 Mdot
.28982 .34739 Mdot
.65471 .52201 Mdot
.24295 .60252 Mdot
.50099 .41666 Mdot
.80938 .49851 Mdot
.53634 .76941 Mdot
.47475 .32887 Mdot
.41661 .343 Mdot
.72652 .7138 Mdot
.56327 .7585 Mdot
.18394 .51278 Mdot
.41957 .3521 Mdot
.22697 .59186 Mdot
.38945 .2116 Mdot
.25793 .48092 Mdot
.52719 .35972 Mdot
.63341 .62254 Mdot
.35199 .36946 Mdot
.69147 .7459 Mdot
.34997 .45299 Mdot
.78906 .54649 Mdot
.41938 .50456 Mdot
.61337 .75225 Mdot
.61638 .53015 Mdot
.30383 .76528 Mdot
.20529 .6009 Mdot
.75991 .41683 Mdot
.43673 .57932 Mdot
.36326 .54966 Mdot
.30307 .50346 Mdot
.49986 .82907 Mdot
.29791 .45174 Mdot
.60019 .28716 Mdot
.31164 .53689 Mdot
.54673 .26129 Mdot
.25403 .72277 Mdot
.77581 .44746 Mdot
.46633 .51999 Mdot
.62821 .30063 Mdot
.23352 .61028 Mdot
.25951 .59104 Mdot
.66181 .63789 Mdot
.46025 .20062 Mdot
.55717 .60263 Mdot
.55086 .55855 Mdot
.51149 .43202 Mdot
.58458 .2125 Mdot
.67025 .76664 Mdot
.35466 .47389 Mdot
.46819 .51084 Mdot
.74546 .64558 Mdot
.79429 .50133 Mdot
.42085 .1358 Mdot
.71873 .77221 Mdot
.55289 .43192 Mdot
.52009 .53107 Mdot
.78913 .44767 Mdot
.5085 .65209 Mdot
.49267 .22656 Mdot
.71918 .72239 Mdot
.43324 .59517 Mdot
.69322 .67093 Mdot
.2686 .63001 Mdot
.2109 .54101 Mdot
.80125 .54932 Mdot
.42397 .63946 Mdot
.61686 .84079 Mdot
.39112 .79696 Mdot
.2073 .51163 Mdot
.34903 .15928 Mdot
.20048 .48868 Mdot
.41337 .4469 Mdot
.61059 .7295 Mdot
.64006 .81325 Mdot
.50634 .53764 Mdot
.67544 .69048 Mdot
.42197 .34148 Mdot
.76153 .40974 Mdot
.70827 .44572 Mdot
.23701 .45789 Mdot
.20591 .4563 Mdot
.20639 .33759 Mdot
.44594 .70889 Mdot
.79013 .35169 Mdot
.4487 .22358 Mdot
.69692 .76211 Mdot
.29918 .68147 Mdot
.68483 .22159 Mdot
.42942 .84751 Mdot
.74908 .47163 Mdot
.21847 .35852 Mdot
.61463 .71333 Mdot
.79523 .42415 Mdot
.55056 .19169 Mdot
.28391 .6913 Mdot
.56458 .23047 Mdot
.42076 .7041 Mdot
.25608 .45418 Mdot
.73815 .44636 Mdot
.53491 .27132 Mdot
.46948 .5236 Mdot
.75608 .70445 Mdot
.25305 .30728 Mdot
.74304 .37435 Mdot
.71227 .66361 Mdot
.80563 .43756 Mdot
.64475 .77238 Mdot
.55096 .78397 Mdot
.53786 .51762 Mdot
.87272 .47905 Mdot
.78438 .68122 Mdot
.26923 .49455 Mdot
.52356 .37494 Mdot
.41035 .85328 Mdot
.57188 .53263 Mdot
.4291 .34735 Mdot
.32959 .772 Mdot
.69498 .44441 Mdot
.57729 .48976 Mdot
.51437 .38383 Mdot
.67294 .29814 Mdot
.27804 .36351 Mdot
.53301 .27467 Mdot
.76634 .59018 Mdot
.74783 .37381 Mdot
.25491 .30902 Mdot
.82199 .51713 Mdot
.48809 .3468 Mdot
.32525 .37616 Mdot
.65403 .81039 Mdot
.62809 .28671 Mdot
.63984 .3323 Mdot
.36462 .26556 Mdot
.2934 .44303 Mdot
.43815 .66786 Mdot
.64391 .42309 Mdot
.35356 .53231 Mdot
.73839 .42134 Mdot
.71288 .7078 Mdot
.49304 .3182 Mdot
.90101 .46705 Mdot
.30288 .76896 Mdot
.30246 .38806 Mdot
.45018 .33345 Mdot
.61879 .58056 Mdot
.62836 .80718 Mdot
.43073 .69433 Mdot
.76603 .61076 Mdot
.31383 .25302 Mdot
.77463 .39639 Mdot
.6104 .36043 Mdot
.29408 .7262 Mdot
.45363 .84568 Mdot
.27329 .27607 Mdot
.48266 .84746 Mdot
.50211 .44632 Mdot
.53648 .45663 Mdot
.6437 .16553 Mdot
.57357 .80935 Mdot
.48381 .39307 Mdot
.26874 .37421 Mdot
.30298 .35253 Mdot
.56702 .4424 Mdot
.29031 .61622 Mdot
.7042 .35067 Mdot
.70478 .45511 Mdot
.5451 .8342 Mdot
.36783 .36003 Mdot
.4986 .54525 Mdot
.37632 .62499 Mdot
.49235 .52499 Mdot
.62562 .34067 Mdot
.3992 .58494 Mdot
.70345 .46457 Mdot
.56478 .53706 Mdot
.35509 .63716 Mdot
.67192 .34346 Mdot
.24958 .64472 Mdot
.67034 .37932 Mdot
.64095 .49534 Mdot
.41761 .36589 Mdot
.40772 .19345 Mdot
.72387 .48666 Mdot
.72987 .49842 Mdot
.28244 .74087 Mdot
.1536 .5647 Mdot
.49578 .57315 Mdot
.45367 .38058 Mdot
.44605 .40984 Mdot
.44811 .20525 Mdot
.37714 .26525 Mdot
.3833 .64609 Mdot
.26371 .59307 Mdot
.51886 .46087 Mdot
.62583 .29507 Mdot
.37981 .61944 Mdot
.69785 .799 Mdot
.51736 .41694 Mdot
.43706 .24448 Mdot
.48377 .82647 Mdot
.70431 .68767 Mdot
.648 .45234 Mdot
.6076 .43083 Mdot
.41522 .45858 Mdot
.57344 .53795 Mdot
.57084 .29144 Mdot
.72652 .6741 Mdot
.64333 .79089 Mdot
.65993 .44928 Mdot
.42337 .24324 Mdot
.57172 .40491 Mdot
.73065 .58053 Mdot
.37369 .5187 Mdot
.77828 .35733 Mdot
.67461 .57485 Mdot
.42348 .83251 Mdot
.67013 .48917 Mdot
.69852 .44382 Mdot
.33584 .27662 Mdot
.73399 .74618 Mdot
.30223 .51241 Mdot
.40719 .23804 Mdot
.34534 .48701 Mdot
.37012 .73458 Mdot
.73531 .48384 Mdot
.49604 .61496 Mdot
.54519 .47264 Mdot
.30344 .34953 Mdot
.54147 .84882 Mdot
.63275 .28186 Mdot
.3808 .64183 Mdot
.453 .78941 Mdot
.39008 .21367 Mdot
.50546 .52257 Mdot
.30254 .19068 Mdot
.44207 .68768 Mdot
.62328 .83735 Mdot
.6931 .7131 Mdot
.47723 .45186 Mdot
.23119 .53237 Mdot
.53673 .32609 Mdot
.53303 .67023 Mdot
.63479 .80081 Mdot
.56566 .29971 Mdot
.25124 .47243 Mdot
.52592 .42875 Mdot
.40769 .47274 Mdot
.59917 .29247 Mdot
.48448 .77687 Mdot
.56972 .63187 Mdot
.30582 .44955 Mdot
.55042 .78913 Mdot
.57692 .53816 Mdot
.161 .42218 Mdot
.78836 .66484 Mdot
.54182 .81559 Mdot
.52187 .77221 Mdot
.55672 .16369 Mdot
.4247 .41025 Mdot
.52211 .31406 Mdot
.45277 .59607 Mdot
.67985 .30914 Mdot
.25267 .52198 Mdot
.71722 .70041 Mdot
.2254 .58763 Mdot
.51556 .50292 Mdot
.21567 .26564 Mdot
.74121 .4648 Mdot
.3718 .47351 Mdot
.23686 .50563 Mdot
.51928 .83166 Mdot
.73015 .62867 Mdot
.21113 .65012 Mdot
.3095 .70061 Mdot
.61246 .33279 Mdot
.52629 .19044 Mdot
.82685 .4791 Mdot
.46462 .75806 Mdot
.78338 .33545 Mdot
.49901 .79038 Mdot
.70103 .38125 Mdot
.3667 .76173 Mdot
.32988 .36503 Mdot
.29714 .37526 Mdot
.30645 .66761 Mdot
.25826 .63608 Mdot
.45054 .36787 Mdot
.621 .79324 Mdot
.70121 .26428 Mdot
.76507 .62368 Mdot
.59447 .81965 Mdot
.35897 .57974 Mdot
.38595 .35763 Mdot
.71443 .48591 Mdot
.66688 .52467 Mdot
.50548 .64224 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
09Gooooo0_l0002booooo`007?ooool00ol0003oooooooooo`2Eooooo`;o00003oooool2o`000:7o
oooo000Looooo`03o`000?oooooooooo093ooooo0_l0000Dooooo`;o00002?ooool2o`0009Oooooo
000Looooo`03o`000?oooooooooo08Gooooo0_l00009ooooo`;o00001?ooool2o`0001Sooooo0_l0
002Gooooo`007?ooool00ol0003oooooooooo`25ooooo`;o00000_ooool2o`0000Cooooo0_l00005
ooooo`;o0000/Oooool001cooooo00?o0000ooooooooool0ROooool3o`0000?ooooo0_l00009oooo
o`;o00001_ooool4o`000:?ooooo000Looooo`03o`000?oooooooooo08[ooooo0_l0000>ooooo`;o
00000_ooool2o`0000;ooooo1_l0002Qooooo`007?ooool00ol0003oooooooooo`2Cooooo`;o0000
2Oooool2o`0000Kooooo1?l00009ooooo`;o0000U?ooool001cooooo0_l0001eooooo`;o00006Ooo
ool2o`0000;ooooo0_l0000Cooooo`;o00002Oooool2o`0009Cooooo000Looooo`03o`000?oooooo
oooo07Cooooo0_l0000Iooooo`;o0000^?ooool001cooooo00?o0000ooooooooool0K_ooool2o`00
00;ooooo0_l0000Fooooo`?o00002?ooool2o`000;;ooooo000Looooo`03o`000?oooooooooo06ko
oooo0_l00002ooooo`;o00004Oooool2o`0000?ooooo0ol00008ooooo`;o00007_ooool2o`0000So
oooo0_l00028ooooo`007?ooool00ol0003oooooooooo`25ooooo`;o0000:_ooool2o`0000;ooooo
0_l00008ooooo`;o00003?ooool2o`0007[ooooo000Looooo`03o`000?oooooooooo0;7ooooo0_l0
000Jooooo`;o0000N_ooool001cooooo00?o0000ooooooooool0O?ooool2o`0003?ooooo0_l0002F
ooooo`007?ooool00ol0003oooooooooo`1kooooo`?o0000boooool001cooooo00?o0000oooooooo
ool0Noooool2o`0001cooooo0_l0000:ooooo`;o00004?ooool2o`00093ooooo000Looooo`03o`00
0?oooooooooo08Wooooo0_l0000>ooooo`;o00002_ooool4o`0000kooooo0_l0002@ooooo`007?oo
ool00ol0003oooooooooo`1aooooo`;o00004_ooool2o`0000;ooooo0_l00006ooooo`Ko00000_oo
ool2o`0000cooooo0_l0000Hooooo`;o0000Q_ooool001cooooo00?o0000ooooooooool0LOooool2
o`00013ooooo1?l0000:ooooo`Ko00000_ooool2o`0000[ooooo0_l0000Jooooo`;o0000Q_ooool0
01cooooo00?o0000ooooooooool0Goooool2o`0002;ooooo0_l0000<ooooo`;o00004_ooool4o`00
0:3ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool0
0ol0003oooooooooo`1Oooooo`;o00003?ooool2o`0000cooooo0_l00004ooooo`;o00003_ooool2
o`0000gooooo0_l00005ooooo`;o00001_ooool2o`0001gooooo0_l0001iooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo
00?o0000ooooooooool0KOooool2o`0000cooooo0_l000001?oooooo0000o`000?ooool2o`0000Co
oooo0_l0000Gooooo`;o00003Oooool4o`0001_ooooo0_l00002ooooo`;o0000MOooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`00
0?oooooooooo07kooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l00000
4oooool4o`0000kooooo1Ol0000Looooo`?o0000M?ooool00003ooooool0003ooooo00;ooooo00?o
0000ooooooooool02oooool00onHV9So8B4Qonk^kP06ooooo`?o0000R_ooool2o`0000Kooooo0_l0
000;ooooo`So00001?ooool2o`0000Kooooo0ol0000Mooooo`;o00001?ooool2o`0006kooooo0000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool0
0ol0003oooooooooo`1Iooooo`;o00002oooool2o`0000kooooo0_l0000?ooooo`;o00000oooool4
o`0000;ooooo0_l00002ooooo`;o00000_ooool4o`0000Gooooo1_l00002ooooo`;o0000;?ooool2
o`0006kooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`1Iooooo`;o00002Oooool4o`0000kooooo0_l00007oooo
o`;o00001_ooool2o`0000?ooooo1?l00006ooooo`;o00000_ooool4o`0000Wooooo0_l00005oooo
o`;o00001oooool2o`00093ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000
okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo06Cooooo0_l0000Eooooo`;o00000_oo
ool3o`0000Wooooo1?l000000ooooooo0000o`000002o`0000?ooooo0_l0000Eooooo`;o00001ooo
ool2o`00093ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c006ooooo`03o`000?oooooooooo07_ooooo0_l00003ooooo`;o00002Oooool3o`0000;o
oooo1?l00003ooooo`;o00001Oooool2o`0000gooooo0_l00006ooooo`;o00000oooool4o`0008_o
oooo000Looooo`03o`000?oooooooooo07[ooooo0ol00009ooooo`?o00002Oooool4o`000003oooo
ool0003o000000Gooooo0_l0000=ooooo`Co00001?ooool2o`0000?ooooo1?l0002;ooooo`007?oo
ool00ol0003oooooooooo`1>ooooo`;o00001?ooool2o`0001_ooooo0_l00007ooooo`;o00000ooo
ool2o`0000?ooooo1Ol00003ooooo`;o00001?ooool4o`0000Cooooo0_l00007ooooo`;o00002_oo
ool2o`0000Cooooo1?l00004ooooo`;o00007?ooool2o`0006cooooo000Looooo`03o`000?oooooo
oooo04kooooo0_l00004ooooo`;o00006?ooool2o`000004ooooool0003o0000ooooo`;o00001_oo
ool2o`000003ooooool0003o000000;ooooo0ol00006ooooo`Co00002_ooool2o`0000Oooooo0_l0
000@ooooo`Co00001?ooool2o`0001cooooo0_l0001/ooooo`007?ooool00ol0003oooooooooo`1^
ooooo`;o00001?ooool2o`0000Kooooo1_l000000ooooooo0000o`000009ooooo`;o00000oooool2
o`0000Oooooo0_l0000Aooooo`;o00002oooool2o`0008_ooooo000Looooo`03o`000?oooooooooo
077ooooo1?l00009ooooo`Co000000?oooooo`000?l000003_ooool2o`0000?ooooo0_l00002oooo
o`;o00001oooool2o`0000Sooooo0_l00003ooooo`;o00001?ooool4o`000003ooooool0003o0000
08Sooooo000Looooo`03o`000?oooooooooo077ooooo1?l0000;ooooo`;o000000?oooooo`000?l0
00004oooool2o`0000_ooooo0_l00005ooooo`;o00001_ooool2o`0000?ooooo1?l00002ooooo`;o
00007_ooool2o`0006Sooooo000Looooo`03o`000?oooooooooo07cooooo0_l00002ooooo`;o0000
:_ooool4o`0000Wooooo2?l00002ooooo`;o00006_ooool2o`0006Sooooo000Looooo`03o`000?oo
oooooooo06_ooooo0_l0000:ooooo`;o00000_ooool3o`0000?ooooo1?l00004ooooo`;o00008ooo
ool2o`0000gooooo2?l0000Looooo`;o0000I_ooool001cooooo00?o0000ooooooooool0J_ooool3
o`0000[ooooo0_l00002ooooo`;o00001?ooool4o`0000Cooooo0_l0000aooooo`;o00000oooool2
o`0000Kooooo0_l0000Fooooo`;o0000I_ooool001cooooo00?o0000ooooooooool0J_ooool2o`00
00Cooooo0_l00003ooooo`;o00003Oooool4o`0000;ooooo0_l0000`ooooo`;o00002oooool2o`00
0003ooooool0003o000001Gooooo0_l0001Tooooo`007?ooool00ol0003oooooooooo`1]ooooo`;o
000000?oooooo`000?l000000_l000001?oooooo0000o`000?l0000<ooooo`Co00000_ooool2o`00
03?ooooo1_l00007ooooo`?o00005?ooool2o`0000Oooooo0_l0001Kooooo`007?ooool2o`0006Oo
oooo0_l00004ooooo`?o00000oooool2o`0000;ooooo0_l0000hooooo`;o00000oooool2o`0000So
oooo1_l00008ooooo`;o00007Oooool2o`0005_ooooo000Looooo`03o`000?oooooooooo04Oooooo
0ol0000Hooooo`;o00000_ooool2o`0000Cooooo0_l00005ooooo`Co00002?ooool2o`0002oooooo
0_l00003ooooo`Co00001_ooool2o`0000kooooo0_l0001hooooo`007?ooool00ol0003ooooooooo
o`17ooooo`?o00006?ooool2o`0000;ooooo0_l00006ooooo`;o00000oooool4o`0000Sooooo0_l0
000aooooo`;o00000oooool2o`0001Kooooo0ol0001gooooo`007?ooool00ol0003oooooooooo`1O
ooooo`Co00000oooool2o`0000;ooooo0_l00002ooooo`Ko0000=oooool2o`000003ooooool0003o
000000;ooooo0_l0000Eooooo`;o00001Oooool2o`0007Oooooo000Looooo`03o`000?oooooooooo
05oooooo1Ol00006ooooo`;o00000_ooool6o`0000Oooooo0_l0000^ooooo`;o000000?oooooo`00
0?l000006Oooool2o`0001Gooooo0_l0001Wooooo`007?ooool00ol0003oooooooooo`12ooooo`;o
00007_ooool2o`0000[ooooo0_l00002ooooo`?o00000_ooool2o`0000;ooooo0_l0000aooooo`;o
00004oooool2o`0000kooooo0_l0000;ooooo`Co0000IOooool001cooooo00?o0000ooooooooool0
@_ooool2o`0002oooooo0_l00002ooooo`;o00003Oooool2o`0003_ooooo0_l0000>ooooo`;o0000
3Oooool3o`0006Cooooo000Looooo`03o`000?oooooooooo05Sooooo0_l00003ooooo`;o000000?o
ooooo`000?l000000ol0000Qooooo`;o00008_ooool2o`0000;ooooo0_l00005ooooo`;o00001?oo
ool2o`0002Gooooo0ol00007ooooo`;o0000Foooool001cooooo00?o0000ooooooooool0EOooool2
o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000003o`0000Cooooo0_l0000J
ooooo`?o00005_ooool2o`0000Wooooo1ol00002ooooo`;o000000?oooooo`000?l000001?ooool2
o`0000cooooo0_l000000ooooooo0000o`000002o`0000Kooooo0_l0000:ooooo`;o00002?ooool2
o`0005_ooooo000Looooo`03o`000?oooooooooo05Gooooo0_l00002ooooo`;o00002?ooool2o`00
00Cooooo0_l00002ooooo`;o00003_ooool2o`0000Kooooo0ol0000Fooooo`?o00002?ooool2o`00
0003ooooool0003o000000?o000000?oooooo`000?l000005Oooool2o`000003ooooool0003o0000
00;o00001_ooool3o`0001Cooooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o
00003_ooool3o`000003ooooool0003o000000kooooo0_l0000Pooooo`;o00001_ooool3o`0000;o
oooo1Ol0000Fooooo`;o000000?oooooo`000?l000002oooool2o`0001Cooooo0ol00003ooooo`;o
0000E?ooool001cooooo00?o0000ooooooooool0FOooool2o`0000;ooooo0_l00004ooooo`;o0000
1Oooool2o`0000?ooooo0_l0000fooooo`?o00007Oooool2o`000003ooooool0003o000000gooooo
0_l0000=ooooo`;o00001?ooool2o`0000?ooooo0_l0001Dooooo`007?ooool00ol0003ooooooooo
o`1Iooooo`;o00000_ooool2o`0000Cooooo0_l00003ooooo`;o00001Oooool2o`000003ooooool0
003o000002kooooo1?l0000Iooooo`?o00001_ooool2o`000003ooooool0003o000000cooooo0_l0
000=ooooo`;o0000Goooool001cooooo00?o0000ooooooooool0FOooool2o`0000gooooo0_l00008
ooooo`;o00004?ooool2o`0001[ooooo1_l00002ooooo`;o000000?oooooo`000?l000002Oooool2
o`0000Oooooo0ol00006ooooo`;o000000?oooooo`000?l00000O?ooool001cooooo00?o0000oooo
ooooool0D_ooool3o`0002oooooo0_l0000Jooooo`;o00001_ooool2o`000003ooooool0003o0000
00Wooooo0_l00004ooooo`;o000000?oooooo`000?l000001oooool2o`0000_ooooo0_l00004oooo
o`?o00001?ooool2o`0006Gooooo000Looooo`03o`000?oooooooooo05;ooooo1?l0000:ooooo`?o
00001Oooool2o`0000;ooooo0_l00009ooooo`;o000000?oooooo`000?l000008?ooool2o`0000;o
oooo0_l0000Jooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000_o
oooo1?l00002ooooo`?o00001?ooool2o`0000oooooo0_l0001Dooooo`007?ooool2o`0005Gooooo
0_l00003ooooo`;o00001Oooool5o`0000?ooooo0_l00002ooooo`;o00001Oooool2o`0000;ooooo
0_l000001?oooooo0000o`000?l0000Nooooo`?o00004?ooool3o`0000?ooooo0_l000000ooooooo
0000o`00000;ooooo`?o000000?oooooo`000?l000003Oooool2o`0000?ooooo0_l0000;ooooo`?o
00001oooool2o`0005Cooooo000Looooo`03o`000?oooooooooo05Wooooo0_l00007ooooo`?o0000
0oooool2o`0000Wooooo0_l00006ooooo`;o00001Oooool2o`00017ooooo0_l00004ooooo`;o0000
1oooool2o`0000Sooooo1Ol000001?oooooo0000o`000?ooool2o`0000_ooooo0_l00002ooooo`;o
00004_ooool2o`0000_ooooo0ol0001Mooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o0000
4oooool2o`0000?ooooo0_l0000=ooooo`;o00002Oooool2o`00017ooooo0_l0000=ooooo`;o0000
2oooool2o`0000oooooo0_l0000>ooooo`;o00002?ooool3o`0000_ooooo0_l0001Mooooo`007?oo
ool00ol0003oooooooooo`1;ooooo`;o000000Coooooo`000?l0003o00004_ooool2o`0001;ooooo
0_l000000ooooooo0000o`000004ooooo`;o00006Oooool2o`0001;ooooo0_l0000;ooooo`;o0000
1?ooool2o`0000?ooooo0_l00009ooooo`;o000000Coooooo`000?l0003ooooo0ol000000ooooooo
0000o`000003o`0000;ooooo0_l0000:ooooo`;o0000F?ooool001cooooo00?o0000ooooooooool0
Boooool2o`0000;ooooo0_l00007ooooo`Co00007_ooool2o`0000Cooooo0_l0000Iooooo`Go0000
3oooool2o`0000_ooooo0_l00004ooooo`Co000000?oooooo`000?l000000_ooool3o`0000Oooooo
0_l000001?oooooo0000o`000?l00002ooooo`So00002_ooool2o`0000Gooooo0_l0001Aooooo`00
7?ooool00ol0003oooooooooo`0dooooo`;o00005_ooool2o`0000[ooooo1?l000000ooooooo0000
o`00000looooo`Go00001_ooool2o`0001cooooo0_l00005ooooo`?o00003_ooool4o`000003oooo
ool0003o000000Gooooo0_l00005ooooo`;o00001Oooool2o`00057ooooo000Looooo`03o`000?oo
oooooooo03Cooooo0_l0000Fooooo`;o00003?ooool2o`000003ooooool0003o000000Sooooo0_l0
000[ooooo`;o00001Oooool3o`000003ooooool0003o000000?ooooo1Ol00007ooooo`?o00000_oo
ool2o`0000?ooooo0_l00002ooooo`;o00001?ooool2o`0001Cooooo1_l00004ooooo`;o000000Co
ooooo`000?l0003o0000Goooool001cooooo00?o0000ooooooooool0BOooool2o`0000Cooooo0_l0
000@ooooo`;o00001?ooool3o`0002Wooooo0ol00006ooooo`;o000000?oooooo`000?l000000ooo
ool2o`000003ooooool0003o000000?ooooo0_l00002ooooo`?o00000_ooool7o`0000;ooooo0ol0
0005ooooo`;o00004_ooool2o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l000002ooo
ool2o`0005?ooooo000Looooo`03o`000?oooooooooo04Wooooo0_l00004ooooo`;o00004?ooool2
o`0000Gooooo0_l0000Yooooo`;o00005_ooool3o`0000;ooooo0ol00002ooooo`Go00000_ooool2
o`000004ooooool0003o0000o`0000?ooooo0ol0000;ooooo`;o00000oooool2o`0000Gooooo0_l0
0002ooooo`;o00003oooool2o`0005?ooooo000Looooo`03o`000?oooooooooo083ooooo0_l0000D
ooooo`;o00002_ooool2o`0000Oooooo1?l000000ooooooo0000o`000002o`0000Oooooo0ol00002
ooooo`;o00000oooool2o`0000;ooooo0ol00007ooooo`;o00000oooool2o`0000Gooooo0_l00002
ooooo`;o00001?ooool2o`0000[ooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`1>oooo
o`;o00006_ooool2o`0001Cooooo0_l00005ooooo`;o00003?ooool3o`0000[ooooo0_l00004oooo
o`co00000_ooool2o`0000?ooooo1Ol000001?oooooo0000o`000?l00005ooooo`Go00005Oooool2
o`0000?ooooo0ol00002ooooo`;o00001_ooool2o`0005;ooooo000Looooo`03o`000?oooooooooo
04cooooo1?l00006ooooo`;o00002_ooool2o`0000Cooooo1?l00002ooooo`;o00001oooool2o`00
00Cooooo0_l00008ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Gooooo0_l00004oooo
o`;o00000oooool2o`0000;ooooo0_l00002ooooo`Go00000_ooool3o`0000Cooooo1Ol000000ooo
oooo0000o`000007o`0000Oooooo0_l00007ooooo`;o000000?oooooo`000?l000002Oooool2o`00
0003ooooool0003o000000Co000000?oooooo`000?l000003?ooool2o`0004cooooo000Looooo`03
o`000?oooooooooo03oooooo0_l00003ooooo`;o00001_ooool4o`0000Kooooo0_l0000:ooooo`Co
00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`Co00000_ooool2o`0000_o
oooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l00003ooooo`So
00000oooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000004o`0000Co
oooo2Ol000001?oooooo0000o`000?ooool2o`0000Oooooo0_l000000ooooooo0000o`000004oooo
o`;o00000oooool2o`000003ooooool0003o000000Co000000?oooooo`000?l000003?ooool2o`00
04cooooo000Looooo`03o`000?oooooooooo03oooooo0_l00003ooooo`;o00002?ooool2o`0001Co
oooo0_l0000;ooooo`;o00001_ooool2o`0000[ooooo0_l0000:ooooo`;o00000_ooool2o`0000;o
oooo0_l00007ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o000000?oooooo`000?l0
00000_ooool;o`0000;ooooo1?l000000ooooooo0000o`000005o`0001?ooooo0_l00005ooooo`Co
00000oooool2o`0005_ooooo000Looooo`03o`000?oooooooooo04Cooooo0_l00006ooooo`;o0000
00?oooooo`000?l000005Oooool2o`00013ooooo0_l0000:ooooo`?o00002?ooool2o`0000Kooooo
1Ol00006ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o000000?oooooo`000?l00000
0_l00002ooooo`ko00001Oooool3o`0000cooooo0_l0000=ooooo`?o00001?ooool4o`0000Sooooo
0_l0001?ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00000_ooool2o`0000;ooooo0_l0
00000ooooooo0000o`000009ooooo`;o00002_ooool4o`0000Gooooo0_l00007ooooo`Co00002?oo
ool2o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`0000;ooooo0_l000001?oooooo0000o`00
0?l00005ooooo`Co00001?ooool9o`000003ooooool0003o000000co00000oooool2o`0000;ooooo
0_l0000;ooooo`;o00002?ooool3o`0000[ooooo0ol00002ooooo`;o000000Coooooo`000?l0003o
oooo0_l0001?ooooo`007?ooool2o`0003kooooo0_l00006ooooo`;o000000?oooooo`000?l00000
1_ooool2o`0000Sooooo0_l00003ooooo`;o00000oooool2o`0000;ooooo0ol00004ooooo`Co0000
0oooool2o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`So00002?ooool2o`0000Kooooo
0_l00007ooooo`;o00001?ooool6o`000003ooooool0003o000000oo00000oooool6o`0000Sooooo
0_l00004ooooo`;o00001Oooool3o`0000;ooooo0_l000000ooooooo0000o`000007ooooo`Ko0000
D_ooool001cooooo00?o0000ooooooooool0?Oooool2o`0000?ooooo0_l000000ooooooo0000o`00
0009ooooo`;o00003Oooool2o`0000?ooooo0_l00002ooooo`?o00000_ooool2o`0000;ooooo0_l0
0003ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Cooooo1Ol000001Ooooooo0000o`00
0?l0003ooooo00;o00004Oooool2o`0000Gooooo0_l00003oooooaOo00000_ooool4o`0000Cooooo
0_l00004ooooo`;o00001?ooool2o`0000Gooooo0ol00002ooooo`Go00001oooool5o`0000Oooooo
0_l0001:ooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00000oooool2o`0001;ooooo0_l0
0007ooooo`Co00001Oooool2o`000003ooooool0003o000000;o000000Coooooo`000?l0003o0000
1Oooool5o`0000Sooooo0_l00003ooooo`;o000000?oooooo`000?l000004?ooool4o`0000Cooooo
0ol00002oooooaOo00000oooool3o`0000Cooooo0_l0000Aooooo`;o00000oooool4o`0000Sooooo
0ol00007ooooo`Co0000B_ooool001cooooo00?o0000ooooooooool0@oooool2o`00017ooooo0_l0
0009ooooo`;o00001?ooool2o`000004ooooool0003o0000o`0000;ooooo1?l000000ooooooo0000
o`000007o`0001Cooooo0ol0000;ooooo`Co00001?ooool4o`000004ooooool0003o0000ooooo`Wo
000000?oooooo`000?l000003Ol000000ooooooo0000o`00000>ooooo`;o00005_ooool2o`0000Ko
oooo1_l0001:ooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00004?ooool2o`0000oooooo
0ol000001?oooooo0000o`000?ooool6o`000003ooooool0003o000000Ko00002oooool2o`000003
ooooool0003o000000Gooooo0ol0000Aooooob7o00000oooool2o`000003ooooool0003o000000_o
oooo0_l00005ooooo`;o00000oooool2o`0000Kooooo0_l00002ooooo`;o00001_ooool2o`0004ko
oooo000Looooo`03o`000?oooooooooo03oooooo0_l0000Dooooo`Co00000_ooool2o`0000?ooooo
1?l00002ooooo`Go00000_ooool6o`0000Cooooo0ol00009ooooo`?o000000Coooooo`000?l0003o
oooo0_l0000Cooooo`;o00000oooool>o`000003ooooool0003o0000013o00000oooool3o`000003
ooooool0003o000000_ooooo0_l00005ooooo`;o000000?oooooo`000?l000000_l00006ooooo`;o
00000_ooool2o`000003ooooool0003o000005?ooooo000Looooo`03o`000?oooooooooo03Sooooo
0_l00005ooooo`;o00002_ooool2o`0000Gooooo0_l000000ooooooo0000o`000003o`000003oooo
ool0003o000000;o000000?oooooo`000?l000002Ol00002ooooo`So000000?oooooo`000?l00000
1ol00004ooooo`?o00001?ooool2o`0000?ooooo0_l00009ooooo`;o000000?oooooo`000?l00000
0_l00003ooooob7o00000oooool3o`0000Oooooo0_l0000?ooooo`Go00003?ooool4o`00057ooooo
000Looooo`03o`000?oooooooooo03Sooooo0_l0000Aooooo`;o00000oooool4o`0000Cooooo0_l0
0003ooooo`;o000000?oooooo`000?l000002Ol000000ooooooo0000o`00000Bo`0000[ooooo0_l0
0003ooooo`;o00002Oooool2o`000003ooooool0003o000000Go00000_oooolOo`000004ooooool0
003o0000ooooo`Co00000oooool4o`000003ooooool0003o000000Oooooo0_l00005ooooo`?o0000
1_ooool2o`0000Kooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`0Xooooo`;o00009_oo
ool2o`0000;ooooo0_l00003ooooo`;o000000Goooooo`000?l0003o0000ooooo`05o`0000;ooooo
5Ol000001?oooooo0000o`000?l00008ooooo`;o00004?ooool2o`0000?ooooo:Ol000000ooooooo
0000o`000004o`000003ooooool0003o000000?ooooo0_l00003ooooo`;o00000_ooool2o`0000Wo
oooo0_l00003ooooo`?o00001Oooool4o`0000[ooooo0_l00013ooooo`007?ooool00ol0003ooooo
ooooo`0Xooooo`;o00005?ooool2o`0001;ooooo2Ol000001Ooooooo0000o`000?l0003ooooo027o
00000oooool2o`000003ooooool0003o000000?o00003_ooool2o`0000?ooooo0_l000000ooooooo
0000o`00000Po`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000006o`0000?o
oooo0_l000000ooooooo0000o`000006ooooo`;o00001Oooool2o`0000?ooooo0ol00005ooooo`Co
00002_ooool2o`0004?ooooo000Looooo`03o`000?oooooooooo03kooooo0_l0000Booooo`;o0000
0_ooool3o`0000Cooooo0_l00002oooooaSo00000_ooool3o`000003ooooool0003o000000;ooooo
0ol000001?oooooo0000o`000?ooool2o`0000Cooooo0_l00002ooooo`;o00001Oooool2o`0000Go
oooo9_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000?o00000_ooool3o`00
00Oooooo1?l00005ooooo`;o00002oooool3o`00053ooooo000Looooo`03o`000?oooooooooo03[o
oooo1?l0000<ooooo`;o00001_ooool2o`0000Wooooo0ol00002ooooo`co000000?oooooo`000?l0
00004?l00002ooooo`;o00002oooool2o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`000003
ooooool0003o000002Oo00001?ooool3o`0000?ooooo0ol00005ooooo`Ko00003oooool2o`0000Wo
oooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`0jooooo`Co00003?ooool2o`0000Kooooo
0_l00009ooooobCo00007_ooool2o`000003ooooool0003o0000017o000000?oooooo`000?l00000
3_l000001Ooooooo0000o`000?l0003ooooo00;o00000oooool2o`0000?ooooo0ol00005ooooo`Ko
00003oooool2o`0000;ooooo1Ol00002ooooo`;o000000?oooooo`000?l00000Aoooool001cooooo
00?o0000ooooooooool0=?ooool2o`0000Sooooo0_l0000Aooooo`?o00001?ooool2o`0000?ooooo
9?l00009ooooo`;o00004_ooool2o`0000?ooooo9?l000001?oooooo0000o`000?ooool2o`0000?o
oooo0_l000000ooooooo0000o`000003o`0000Kooooo0ol00003ooooo`;o00003_ooool7o`0000Go
oooo0_l00017ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool2o`00
0003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0=?ooool2o`0000Oooooo1?l0000@oooo
o`;o00001?ooool3o`0000Gooooo8?l00004ooooo`;o00001Oooool2o`0000gooooo0_l00003oooo
o`;o00001?ooool3o`0000?ooooo8ol00003ooooo`Go000000?oooooo`000?l000000_l00004oooo
o`Co00000_ooool2o`0000kooooo0_l00002ooooo`;o0000Coooool00006oooooomgMgOoV9RHoooo
oonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0j
ooooo`;o000000?oooooo`000?l000000ol0000Eooooo`;o00001_ooool3o`000003ooooool0003o
000001_o00000oooool2o`0001?ooooo0ol000000ooooooo0000o`000002ooooo`;o00000_ooool2
o`0000;ooooo9Ol000001Ooooooo0000o`000?l0003ooooo00;o00000_ooool4o`0000Kooooo0_l0
000Fooooo`;o00001_ooool2o`0004Oooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooo
oooo00Wooooo1Ol00006ooooo`03o`000?oooooooooo02?ooooo0_l0000Eooooo`;o00001?ooool2
o`00013ooooo0_l00008ooooo`;o00001?oooolNo`0001Kooooo1?l00002ooooo`;o00000_oooolW
o`0000?ooooo0_l00002ooooo`?o00001Oooool2o`0000Sooooo0_l00009ooooo`;o00001_ooool3
o`000004ooooool0003o0000o`0000Kooooo0_l00017ooooo`0000?oooooo`000?ooool00_ooool0
0ol0003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0000Sooooo`;o00006_oo
ool2o`00017ooooo0_l00008ooooo`Co00000_oooolNo`0000Cooooo0_l0000@ooooo`Ko000000?o
ooooo`000?l00000;Ol0000Booooo`;o00000_ooool2o`000003ooooool0003o000000Cooooo0_l0
0006ooooo`?o000000?oooooo`000?l000000_l0000Iooooo`;o0000<oooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool02Oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oo
oooooooo03oooooo0_l0000Moooooa3o000000?oooooo`000?l000003ol00002ooooo`Ko00004?oo
ool4o`000003ooooool0003o000000;o00000_oooolXo`000004ooooool0003o0000ooooo`;o0000
3Oooool2o`0000;ooooo0_l000000ooooooo0000o`00000;ooooo`?o00000_ooool7o`0001Kooooo
0_l0000cooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03ogMgMoo<
c<co000000Oooooo00?o0000ooooooooool0Boooool2o`000003ooooool0003o000000Gooooo0_l0
0004ooooo`;o00000ooooolPo`000004ooooool0003o0000o`0000;ooooo0ol00005ooooo`;o0000
3_ooool2o`0000?ooooo9_l00003ooooo`;o000000?oooooo`000?l000001Oooool2o`00017ooooo
0_l00005ooooo`Go00001?ooool5o`0004_ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`co
oooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`1;ooooo`;o000000?oooooo`000?l0
00000_l00003ooooo`;o00001?ooool2o`0000Kooooo7?l00002ooooo`;o00000oooool3o`0000Co
oooo0ol0000:ooooo`;o00000_ooool2o`0000Cooooo:_l000000ooooooo0000o`000003ooooo`Co
00004Oooool2o`0000;ooooo0_l000000ooooooo0000o`000004o`0000?ooooo0_l0001>ooooo`00
00Koooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000oooo
ooooool0AOooool2o`0000Oooooo1?l0000Aoooooaco00001oooool2o`0000Cooooo0ol0000;oooo
o`;o000000Coooooo`000?l0003o00001?oooolTo`000003ooooool0003o000000;o00000_ooool2
o`0000?ooooo0_l0000Cooooo`;o00000_ooool2o`0000?ooooo1?l00007ooooo`;o0000B_ooool0
01cooooo00?o0000ooooooooool08Oooool2o`0002;ooooo0_l00006ooooo`?o00001_ooool2o`00
00Wooooo3ol000000ooooooo0000o`000002o`0000;ooooo2?l000001?oooooo0000o`000?l00009
ooooo`;o00003oooool6o`000003ooooool0003o000000Oo000000?oooooo`000?l000005_l00003
ooooo`?o00000oooool2o`0000Kooooo0ol00004ooooo`;o00002Oooool2o`0000?ooooo0_l00000
0ooooooo0000o`000003o`0000Oooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`0Qoooo
o`;o0000:_ooool2o`0000Oooooo0ol00008oooooa_o000000Coooooo`000?l0003ooooo0ol00000
0ooooooo0000o`00000Booooo`;o00001Oooool4o`000003ooooool0003o000000So000000?ooooo
o`000?l000006ol0000;ooooo`?o00001?ooool2o`0000cooooo1?l000000ooooooo0000o`000002
o`0001;ooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00002_ooool2o`00
00Oooooo0ol00004ooooo`;o00001?ooool2o`0000;ooooo0_l00009ooooo`;o000000?oooooo`00
0?l000005ol00006ooooo`?o00004Oooool2o`0000[ooooo9ol00002ooooo`?o00007?ooool6o`00
00cooooo0ol00006ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0<Oooool2o`0000So
oooo1?l00003ooooo`;o00000_ooool3o`0000?ooooo1?l00003ooooo`;o00003oooool3o`000003
ooooool0003o000001Co000000?oooooo`000?l000000oooool3o`000004ooooool0003o0000oooo
o`;o00002oooool2o`0000?ooooo0_l00005ooooo`;o000000?oooooo`000?l000008_l00002oooo
o`Go00000oooool4o`0000Cooooo0_l0000=ooooo`Ko00003?ooool3o`0004Sooooo000Looooo`03
o`000?oooooooooo03_ooooo1?l000000ooooooo0000o`000002o`0000Kooooo1_l0000:ooooo`;o
00002?ooool3o`000004ooooool0003o0000oooooa;o00000_ooool2o`0000?ooooo0ol000001?oo
oooo0000o`000?ooool2o`0000_ooooo0_l00003ooooo`;o00000oooool4o`000003ooooool0003o
000000Oo000000?oooooo`000?l000003Ol000001?oooooo0000o`000?l00003ooooo`Co00001Ooo
ool2o`0000?ooooo1?l00002ooooo`Co00000oooool2o`0000Wooooo1?l000001Ooooooo0000o`00
0?l0003ooooo00;o0000DOooool001cooooo00?o0000ooooooooool07_ooool2o`0001gooooo0_l0
00000ooooooo0000o`000004ooooo`;o00000_ooool2o`0000Kooooo0_l00006ooooo`;o00002ooo
ool3o`000003ooooool0003o0000017o000000?oooooo`000?l000001oooool2o`0000Kooooo0_l0
0004ooooo`;o00001Oooool2o`0000?ooooo3?l000000ooooooo0000o`00000?o`0000;ooooo0_l0
0005ooooo`;o000000?oooooo`000?l000003Oooool4o`0000?ooooo0_l00007ooooo`;o00000_oo
ool2o`000003ooooool0003o000000Co0000DOooool001cooooo00?o0000ooooooooool07_ooool2
o`0001gooooo0_l00007ooooo`;o00000_ooool2o`0000Kooooo0_l00008ooooo`;o00002Oooool3
o`000003ooooool0003o000000Go000000?oooooo`000?l000002_l00006ooooo`Go00001_ooool3
o`0000?ooooo0ol00004ooooo`Co000000?oooooo`000?l000006_l000001?oooooo0000o`000?oo
ool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000oooooo0_l00004ooooo`;o0000
1_ooool2o`0000;ooooo0_l00003ooooo`Co000000?oooooo`000?l00000C_ooool001cooooo00?o
0000ooooooooool0Aoooool2o`0001?ooooo0_l00006ooooo`;o00001?ooool3o`000004ooooool0
003o0000o`0000;ooooo3?l00006ooooo`?o00002Oooool2o`000004ooooool0003o0000ooooo`;o
00001?ooool5o`000003ooooool0003o000001So000000Coooooo`000?l0003o00000oooool4o`00
01Wooooo1?l0000Aooooo`;o000000?oooooo`000?l000001oooool2o`0004Gooooo000Looooo`03
o`000?oooooooooo04Oooooo0_l0000Cooooo`;o00001_ooool2o`0000;ooooo5?l00009ooooo`;o
00002_ooool2o`000003ooooool0003o000000Wooooo0ol00002ooooo`[o000000?oooooo`000?l0
00001ol000000ooooooo0000o`000002o`000005ooooool0003o0000o`000?ooool01_l000000ooo
oooo0000o`000005ooooo`;o000000?oooooo`000?l000003?ooool2o`0000Wooooo0_l0000Doooo
o`Co0000@oooool001cooooo00?o0000ooooooooool0>Oooool2o`0000gooooo0_l00003ooooo`;o
00001_ooool2o`0000Gooooo0_l00004ooooo`;o00001?ooool2o`0000;ooooo0ol000000ooooooo
0000o`000004o`000003ooooool0003o000000Wooooo1?l000001?oooooo0000o`000?l00004oooo
o`;o00001oooool2o`000004ooooool0003o0000o`0000;ooooo0_l000000ooooooo0000o`000003
ooooo`Oo00000oooool7o`000004ooooool0003o0000ooooo`Go000000Coooooo`000?l0003o0000
1?ooool2o`0000Gooooo0_l000000ooooooo0000o`000009ooooo`?o000000?oooooo`000?l00000
1_ooool4o`0000Oooooo1ol000000ooooooo0000o`000005ooooo`;o00000_ooool4o`0003gooooo
000Looooo`03o`000?oooooooooo03Wooooo0ol0000<ooooo`Co000000?oooooo`000?l000001_oo
ool2o`0000Wooooo1?l000000ooooooo0000o`000002o`0000Cooooo0_l00002ooooo`Go00003?oo
ool4o`000004ooooool0003o0000o`0000Cooooo0_l00007ooooo`;o000000?oooooo`000?l00000
1Ol000000ooooooo0000o`000003ooooo`Go000000?oooooo`000?l000002Ol000001?oooooo0000
o`000?ooool5o`000003ooooool0003o000000oooooo0_l000000ooooooo0000o`000006ooooo`?o
000000?oooooo`000?l000000_l00004ooooo`Go00001_ooool7o`000003ooooool0003o000000Go
oooo0_l00002ooooo`Co0000?Oooool001cooooo0_l0000Mooooo`;o00007?ooool2o`0000gooooo
0ol0000;ooooo`;o00001?ooool2o`000003ooooool0003o000000?ooooo1?l00003ooooo`;o0000
1Oooool4o`0000_ooooo0ol00007ooooo`Co000000?oooooo`000?l000001?ooool4o`0000;ooooo
1?l00008ooooo`?o000000?oooooo`000?l000003ol0000Aooooo`;o00000_ooool2o`000003oooo
ool0003o000000_ooooo0ol00005ooooo`Co00000_ooool2o`0000Gooooo0ol00002ooooo`;o0000
0_ooool5o`0000?ooooo0ol0000mooooo`007?ooool00ol0003oooooooooo`0Looooo`;o00008Ooo
ool2o`0000Sooooo0_l00004ooooo`;o00001_ooool2o`0000Cooooo0_l00003ooooo`;o00002?oo
ool4o`0000Gooooo0_l00003ooooo`;o000000?oooooo`000?l000000oooool2o`0000Kooooo1_l0
00001?oooooo0000o`000?l00003ooooo`Co00001?ooool2o`0000_ooooo2ol000000ooooooo0000
o`000002o`0000oooooo0_l00002ooooo`;o00004?ooool2o`0000Kooooo0ol00005ooooo`;o0000
3_ooool4o`0000Cooooo0ol0000mooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00001ooo
ool2o`0000Sooooo0ol00003ooooo`;o00004Oooool2o`0000[ooooo0_l00002ooooo`;o000000?o
ooooo`000?l000000oooool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o000000?o
ooooo`000?l000001Oooool3o`0000Gooooo0_l00005ooooo`;o000000?oooooo`000?l000001Ooo
ool4o`000003ooooool0003o000000;o000000?oooooo`000?l000000_ooool5o`0000;ooooo0_l0
0005ooooo`;o00000oooool2o`0001Cooooo0_l00006ooooo`?o00001?ooool2o`0000Cooooo0_l0
0009ooooo`?o0000AOooool001cooooo00?o0000ooooooooool0=Oooool3o`0000Oooooo1?l00006
ooooo`?o00005Oooool3o`0000Sooooo0_l00004ooooo`;o000000?oooooo`000?l000003?ooool2
o`000003ooooool0003o000000;o00003oooool2o`0000Gooooo0_l000000ooooooo0000o`000004
o`000003ooooool0003o000000Cooooo1_l000000ooooooo0000o`000002ooooo`Ko00001Oooool3
o`0002Oooooo0_l00003ooooo`?o00002_ooool4o`0004?ooooo000Looooo`03o`000?oooooooooo
03Gooooo0_l0000:ooooo`;o00003Oooool2o`0000gooooo1Ol00008ooooo`;o00006?ooool4o`00
00kooooo0_l000001?oooooo0000o`000?ooool2o`0000Gooooo1?l000001?oooooo0000o`000?l0
0003ooooo`Wo00001?ooool2o`0000?ooooo1?l000000ooooooo0000o`00000=ooooo`;o00002Ooo
ool2o`0000Sooooo1?l00006ooooo`;o00003Oooool2o`0004?ooooo000Looooo`03o`000?oooooo
oooo043ooooo0ol0000=ooooo`;o00003Oooool2o`00027ooooo0_l00003ooooo`;o00002Oooool2
o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0000Sooooo1Ol00003ooooo`?o000000?o
ooooo`000?l000000_l00004ooooo`;o00001?ooool4o`00013ooooo0_l00009ooooo`;o00002?oo
ool4o`0000;ooooo0_l00006ooooo`;o00009_ooool2o`0002Kooooo000Looooo`03o`000?oooooo
oooo03cooooo0_l00002ooooo`Co00002Oooool2o`000003ooooool0003o000000kooooo0_l0000P
ooooo`;o00003Oooool5o`0000Wooooo0_l00007ooooo`?o00002oooool2o`0000Cooooo0_l00002
ooooo`;o00000_ooool2o`0000Sooooo0_l0000=ooooo`;o00004_ooool3o`0000Gooooo0_l00002
ooooo`;o00000_ooool2o`0001gooooo0ol0000Vooooo`007?ooool00ol0003oooooooooo`0loooo
o`;o00000_ooool4o`0000Wooooo0ol000000ooooooo0000o`00000=ooooo`;o00001Oooool2o`00
00Kooooo0_l00004ooooo`;o00001_ooool6o`0000kooooo0_l000000ooooooo0000o`000006oooo
o`;o000000?oooooo`000?l000002?ooool2o`0000;ooooo0_l000001?oooooo0000o`000?l00003
ooooo`;o00002?ooool2o`0000Oooooo0_l00003ooooo`;o00000oooool2o`0000Oooooo0ol0000A
ooooo`Co00001?ooool2o`000003ooooool0003o000000;o00000_ooool2o`0001gooooo0_l0000W
ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00002oooool6o`0000?ooooo0_l0000?oooo
o`;o00001_ooool8o`0000?ooooo0_l000000ooooooo0000o`000004o`0001Kooooo0_l000000ooo
oooo0000o`00000?ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0001;ooooo0_l00008
ooooo`;o00001oooool2o`0001;ooooo0_l00006ooooo`;o000000Coooooo`000?l0003ooooo0ol0
0018ooooo`007?ooool00ol0003oooooooooo`0eooooo`;o00002Oooool2o`0000cooooo0ol00002
ooooo`;o000000?oooooo`000?l000000_l0000Gooooo`Co00000oooool4o`000004ooooool0003o
0000ooooo`;o00005oooool2o`0001[ooooo0_l0000=ooooo`;o00000oooool2o`0000Sooooo0_l0
0008ooooo`;o00007_ooool4o`0000Sooooo0_l0000=ooooo`;o0000;oooool001cooooo00?o0000
ooooooooool0=Oooool2o`0000[ooooo0ol00006ooooo`;o00001?ooool2o`000003ooooool0003o
000000?ooooo0_l0000Gooooo`?o00001?ooool4o`0000Cooooo0_l00004ooooo`;o00006?ooool2
o`0000Oooooo0_l0000Aooooo`;o00001_ooool2o`0000?ooooo0_l00008ooooo`;o00002?ooool2
o`0000[ooooo0_l0000>ooooo`;o00000_ooool4o`0000?ooooo0_l00003ooooo`;o00003Oooool2
o`0002oooooo000Looooo`03o`000?oooooooooo01Wooooo0_l0000Oooooo`Co00000oooool3o`00
00Kooooo0ol00003ooooo`;o000000?oooooo`000?l000004?ooool3o`0000kooooo0_l00002oooo
o`;o00000oooool2o`0000Gooooo0_l0000Hooooo`;o00001oooool2o`0000;ooooo1?l0000;oooo
o`;o00005Oooool2o`0000oooooo0_l00002ooooo`Ko00002oooool2o`0000Oooooo1?l00013oooo
o`007?ooool00ol0003oooooooooo`0Iooooo`;o00007oooool5o`0000;ooooo0_l00008ooooo`;o
00000_ooool3o`0000;ooooo0_l0000?ooooo`Go00000_ooool2o`0000Sooooo0_l00006ooooo`Go
00007?ooool2o`0000Wooooo0_l000000ooooooo0000o`000002o`0001cooooo0_l00004ooooo`;o
000000?oooooo`000?l000003?ooool2o`000003ooooool0003o000000Go00002oooool2o`0000;o
oooo0_l00003ooooo`;o00002oooool2o`0000gooooo0_l0000Yooooo`007?ooool00ol0003ooooo
ooooo`0looooo`?o00000_ooool2o`0000cooooo0_l00003ooooo`;o00002oooool3o`0000Cooooo
0_l00002ooooo`;o00003Oooool2o`000004ooooool0003o0000ooooo`;o00007?ooool2o`0000;o
oooo0_l00005ooooo`;o00000_ooool2o`0000Sooooo0_l0000;ooooo`;o00001_ooool2o`0000Oo
oooo0_l0000?ooooo`Co00004_ooool4o`0000;ooooo0_l00005ooooo`;o00000oooool4o`0000_o
oooo0_l0000Yooooo`007?ooool00ol0003oooooooooo`0looooo`?o00001Oooool2o`0000kooooo
0_l0000;ooooo`?o00005oooool2o`00013ooooo0_l00004ooooo`;o00002_ooool2o`0000;ooooo
0_l0000;ooooo`;o000000?oooooo`000?l000000oooool4o`0000;ooooo0ol00003ooooo`?o0000
1Oooool2o`0000cooooo0_l00008ooooo`;o00004_ooool2o`0000Gooooo0_l00002ooooo`;o0000
1Oooool2o`0000Gooooo0_l0000fooooo`007?ooool00ol0003oooooooooo`0eooooo`;o00003Ooo
ool2o`0000?ooooo0_l00009ooooo`;o00001?ooool2o`0000Kooooo0_l0000:ooooo`;o00000ooo
ool2o`000003ooooool0003o000001Gooooo0_l00004ooooo`;o00002?ooool3o`000003ooooool0
003o000000;o00002?ooool5o`000003ooooool0003o000000Gooooo0_l00002ooooo`?o00000ooo
ool4o`0000Cooooo0_l00009ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l0
0003ooooo`;o00003Oooool2o`0000Wooooo0_l0000Cooooo`;o0000;oooool001cooooo0_l0000H
ooooo`;o00007?ooool2o`0001;ooooo0_l0000?ooooo`;o00002?ooool5o`0000Gooooo0_l00003
ooooo`;o000000?oooooo`000?l000009Oooool3o`000003ooooool0003o000000[ooooo0ol00008
ooooo`Co00001?ooool2o`0000Cooooo0_l0000?ooooo`;o00001Oooool2o`0000Wooooo0_l00006
ooooo`;o00002Oooool6o`000003ooooool0003o000001?ooooo0_l0000_ooooo`007?ooool00ol0
003oooooooooo`0Gooooo`;o00008Oooool2o`0001Cooooo0_l00005ooooo`;o00001_ooool2o`00
00?ooooo1Ol00007ooooo`;o00001_ooool4o`000003ooooool0003o000000Gooooo0_l0000Noooo
o`;o00002?ooool2o`0000Gooooo1Ol00006ooooo`;o00002_ooool2o`000003ooooool0003o0000
01Wooooo0_l00005ooooo`;o000000?oooooo`000?l000001_ooool7o`0004Kooooo000Looooo`03
o`000?oooooooooo03[ooooo0_l0000=ooooo`Ko000000?oooooo`000?l000000_l00003ooooo`;o
00000oooool2o`000003ooooool0003o000000;ooooo0_l00006ooooo`?o000000Coooooo`000?l0
003o00001_ooool4o`000003ooooool0003o000000Gooooo0_l00007ooooo`;o00000_ooool2o`00
00Oooooo0_l00008ooooo`;o00001Oooool2o`000004ooooool0003o0000o`0000Cooooo1Ol00002
ooooo`Co00003?ooool2o`000003ooooool0003o000001;ooooo0_l00005ooooo`;o00001Oooool2
o`000003ooooool0003o000000_ooooo0_l00002ooooo`;o00005Oooool2o`0002_ooooo000Loooo
o`03o`000?oooooooooo03[ooooo0_l0000=ooooo`Ko00000oooool3o`0000Oooooo0_l00002oooo
o`;o000000?oooooo`000?l000000oooool6o`000004ooooool0003o0000o`0000?ooooo0ol00000
1?oooooo0000o`000?ooool2o`0000Gooooo0_l00008ooooo`;o00000_ooool2o`000003ooooool0
003o000000Cooooo0_l0000?ooooo`;o00000_ooool2o`0000_ooooo1?l0000Eooooo`;o00003?oo
ool2o`0000cooooo1?l0000=ooooo`;o000000?oooooo`000?l000005Oooool2o`0002_ooooo000L
ooooo`03o`000?oooooooooo03Sooooo1?l00004ooooo`;o00003_ooool2o`000003ooooool0003o
000000Oooooo1_l00006oooooa?o000000?oooooo`000?l000000ol00002ooooo`;o00003oooool2
o`0000Cooooo1?l0000:ooooo`;o00003?ooool2o`0000;ooooo1Ol00007ooooo`;o00003Oooool2
o`0000Gooooo0_l00006ooooo`?o00003?ooool2o`0000Sooooo0_l00003ooooo`;o0000AOooool0
01cooooo00?o0000ooooooooool0=?ooool2o`0000;ooooo1_l00002ooooo`;o00003_ooool2o`00
00Oooooo0_l000000ooooooo0000o`000003o`0000;ooooo0_l00007ooooo`Co00000_ooool4o`00
0003ooooool0003o000000So00002Oooool2o`00013ooooo1?l00008ooooo`;o00003?ooool2o`00
00;ooooo1_l00004ooooo`Co00004?ooool2o`0000;ooooo0_l00006ooooo`?o00005_ooool2o`00
00Sooooo0_l0000Booooo`;o0000;?ooool001cooooo00?o0000ooooooooool0<oooool3o`0000Ko
oooo0_l0000Booooo`;o00001oooool2o`0000Sooooo0_l00007ooooo`;o000000Coooooo`000?l0
003ooooo1_l000000ooooooo0000o`000004o`000003ooooool0003o000000Go00000oooool2o`00
00Gooooo1_l00005ooooo`Co00000oooool4o`0000Cooooo1?l0000?ooooo`;o00001?ooool2o`00
00Oooooo1?l00007ooooo`;o00002_ooool3o`000003ooooool0003o000001?ooooo0_l00008oooo
o`;o00002Oooool2o`0000Oooooo0_l0000/ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o
00001oooool2o`000003ooooool0003o000000?ooooo0_l00008ooooo`;o000000?oooooo`000?l0
00004?ooool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000000oooool4o`0000Go
oooo0_l000000ooooooo0000o`000007o`0000Gooooo0_l000000ooooooo0000o`000005o`0000So
oooo1ol00004ooooo`Co00003oooool2o`0000gooooo1_l00003ooooo`;o000000?oooooo`000?l0
00000ol000000ooooooo0000o`000009o`000003ooooool0003o0000013ooooo0_l000000ooooooo
0000o`00000@ooooo`;o0000=Oooool001cooooo00?o0000ooooooooool0?oooool2o`0000?ooooo
0_l00007ooooo`?o000000?oooooo`000?l000001?ooool2o`0000[ooooo0_l00002ooooo`;o0000
00?oooooo`000?l000001?l00008ooooo`;o00002Oooool8o`0000?ooooo0_l00004ooooo`Co0000
1?ooool3o`000003ooooool0003o000000;o00005_ooool2o`0000;ooooo0_l0000Aooooo`;o0000
0_ooool3o`000003ooooool0003o000000oo000000?oooooo`000?l000004oooool2o`0004Oooooo
000Looooo`03o`000?oooooooooo04Gooooo0_l00006ooooo`;o00002?ooool2o`00017ooooo0_l0
0002ooooo`;o00002?ooool2o`0000oooooo0_l000000ooooooo0000o`000006ooooo`Co00001?oo
ool7o`0000Kooooo0_l0000?ooooo`;o00003Oooool2o`000003ooooool0003o000000Kooooo0ol0
0002oooooa7o00008Oooool2o`0000Kooooo0ol0000cooooo`007?ooool00ol0003oooooooooo`0H
ooooo`;o00009_ooool2o`0000?ooooo1?l00005ooooo`;o00001oooool4o`0000oooooo0_l00002
ooooo`?o00003Oooool2o`0000cooooo1Ol000000ooooooo0000o`000003o`0000;ooooo0_l00004
ooooo`Co00000_ooool2o`0000;ooooo0_l0000:ooooo`?o00001_ooool2o`0000Cooooo0_l00003
ooooo`;o000000?oooooo`000?l000001_oooolFo`0001?ooooo0_l0000<ooooo`;o00001_ooool3
o`0003?ooooo000Looooo`03o`000?oooooooooo01Sooooo0_l0000Eooooo`;o00002Oooool3o`00
00?ooooo0_l000000ooooooo0000o`000002ooooo`;o00001Oooool2o`0000Oooooo1Ol00008oooo
o`;o000000Coooooo`000?l0003ooooo2?l0000<ooooo`;o00001oooool2o`0000?ooooo3?l00000
0ooooooo0000o`000002ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0000Gooooo0_l0
0007ooooo`?o00001_ooool2o`0000Cooooo0_l0000>oooooaSo000000?oooooo`000?l000003_oo
ool2o`0001Wooooo0_l0000_ooooo`007?ooool00ol0003oooooooooo`0_ooooo`?o000000?ooooo
o`000?l000001Oooool3o`0000Kooooo0_l00002ooooo`?o00003_ooool4o`0000Kooooo1?l00000
0ooooooo0000o`000002ooooo`Oo00002?ooool2o`0000Sooooo1Ol00004ooooo`;o000000Cooooo
o`000?l0003ooooo1_l00004ooooo`;o00000_ooool5o`0000Kooooo0_l00006ooooo`Ko00004?oo
ool2o`0000Sooooo0_l00002oooooaCo000000?oooooo`000?l000007_ooool3o`0000Sooooo0_l0
000_ooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o000000?oooooo`000?l000001oooool2
o`0000?ooooo0_l00004ooooo`Go00003_ooool2o`0000;ooooo0_l000001?oooooo0000o`000?l0
0007ooooo`;o000000?oooooo`000?l000002_ooool2o`0000Sooooo1?l00009ooooo`Co00000_oo
ool4o`0000?ooooo0_l000000ooooooo0000o`000003o`0000;ooooo0_l0000:ooooo`Ko00000_oo
ool2o`0000[ooooo1?l00003ooooo`;o00001ooooolEo`0000?ooooo0_l00008ooooo`;o00001Ooo
ool2o`0000Oooooo1_l0000iooooo`007?ooool00ol0003oooooooooo`0kooooo`?o00000oooool4
o`0000Gooooo0ol0000=ooooo`;o00000_ooool2o`000003ooooool0003o000000Oooooo0ol00000
0ooooooo0000o`000004ooooo`;o00005_ooool2o`0000?ooooo0ol00003ooooo`Co00000oooool2
o`000004ooooool0003o0000ooooo`?o000000?oooooo`000?l000003Oooool2o`0000?ooooo0_l0
0009ooooo`Go00000oooool2o`0000;ooooo0_l00002oooooaKo00000oooool2o`0000Sooooo0_l0
00000ooooooo0000o`000002ooooo`;o00001oooool4o`0003_ooooo000Looooo`03o`000?oooooo
oooo03?ooooo0_l00006ooooo`;o00001_ooool2o`0000Cooooo1Ol00005ooooo`;o00002Oooool2
o`0000[ooooo0_l00008ooooo`;o00005_ooool4o`0000;ooooo0_l00003ooooo`;o00001Oooool2
o`000003ooooool0003o000000;ooooo0ol00002ooooo`;o00002oooool2o`0000kooooo0_l00002
ooooo`;o00000_ooool2o`0000;ooooo0_l00002oooooaOo00003_ooool3o`0000;ooooo0_l0000D
ooooo`;o0000<?ooool001cooooo0_l0000Looooo`;o00005_ooool2o`0000Wooooo0_l00003oooo
o`;o00001?ooool2o`000003ooooool0003o000000;o00000oooool2o`0000;ooooo0_l00004oooo
o`?o00003Oooool2o`0000?ooooo0_l0000Jooooo`Co00001?ooool5o`0000?ooooo0_l00006oooo
o`;o000000?oooooo`000?l000001Ol0000Eooooo`;o00001?ooool2o`0000;ooooo0_l00008oooo
oaGo00003_ooool2o`0000;ooooo0_l0000Eooooo`;o0000<?ooool001cooooo00?o0000oooooooo
ool06oooool2o`00027ooooo0_l00009ooooo`?o00000_ooool2o`0000Oooooo0_l00004ooooo`;o
000000?oooooo`000?l000002oooool2o`0000?ooooo0_l0000Booooo`;o00001oooool3o`0000Co
oooo1Ol0000>ooooo`Oo00001?ooool3o`0000_ooooo0_l000000ooooooo0000o`000008ooooo`;o
00002?oooolFo`00017ooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`19ooooo`?o0000
00?oooooo`000?l000000_ooool2o`000003ooooool0003o000000[ooooo0_l0000Tooooo`;o0000
1oooool3o`0000Gooooo1?l0000<ooooo`;o00002oooool3o`000004ooooool0003o0000ooooo`;o
000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l0000;ooooo`;o00000_oooolHo`0005Wo
oooo000Looooo`03o`000?oooooooooo04Cooooo0_l00007ooooo`;o00000_ooool2o`000003oooo
ool0003o000000oooooo0_l00002ooooo`Go00007Oooool2o`0000oooooo0_l00009ooooo`;o0000
1_ooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool5o`0000Oooooo0_l00007ooooo`;o
00000_ooool2o`0000;ooooo2?l000000ooooooo0000o`00000@o`0001_ooooo0_l0000iooooo`00
7?ooool00ol0003oooooooooo`14ooooo`Co00000_ooool2o`0000?ooooo0_l00004ooooo`;o0000
1oooool2o`0000Gooooo0_l00002ooooo`Go00007Oooool2o`0000Sooooo0_l00005ooooo`Co0000
1oooool2o`0000Kooooo0_l00004ooooo`;o00001Oooool2o`0001;ooooo0_l00003ooooo`;o0000
0oooool6o`000003ooooool0003o0000013o00005Oooool2o`0000Cooooo0_l0000iooooo`007?oo
ool00ol0003oooooooooo`0^ooooo`;o00001Oooool2o`0000[ooooo0_l00003ooooo`;o00000_oo
ool2o`0000?ooooo0_l00003ooooo`?o00001oooool2o`0000Gooooo0_l0000@ooooo`;o00004Ooo
ool5o`0000Kooooo0_l00003ooooo`;o00000_ooool2o`0001_ooooo0_l00005ooooo`?o00000ooo
ool2o`0000Sooooo0_l000001?oooooo0000o`000?l00002oooooa3o000000?oooooo`000?l00000
0ol0000<ooooo`;o00001oooool2o`000003ooooool0003o000003oooooo000Looooo`03o`000?oo
oooooooo01gooooo0_l0000?ooooo`;o00001Oooool2o`0000[ooooo0_l00003ooooo`;o00003?oo
ool2o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l000005?ooool2o`0000_ooooo0_l0
0004ooooo`Go00002oooool3o`000003ooooool0003o000000Gooooo0_l0000Dooooo`;o00001Ooo
ool3o`0000?ooooo0ol00007ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`00
000Ao`0000cooooo0_l00007ooooo`;o00001?ooool2o`0003cooooo000Looooo`03o`000?oooooo
oooo01gooooo0_l0000iooooo`;o00000_ooool7o`0000Sooooo0_l0000Dooooo`Go00002?ooool3
o`0000[ooooo0_l00008ooooo`;o00004?ooool2o`0000Wooooo0ol00004ooooo`;o00004_oooolA
o`0000gooooo0_l0000>ooooo`Co0000>_ooool001cooooo00?o0000ooooooooool0G?ooool7o`00
00Sooooo0_l0000Aooooo`Oo00002Oooool3o`0000Gooooo0_l00005ooooo`;o00006?ooool2o`00
00[ooooo0_l0000<ooooo`;o000000?oooooo`000?l000000ol00004ooooo`go000000Coooooo`00
0?l0003o00001_ooool2o`0000Gooooo0_l00008ooooo`;o00001_ooool2o`0003[ooooo000Loooo
o`03o`000?oooooooooo05Sooooo0_l00004ooooo`;o000000?oooooo`000?l000001?ooool2o`00
01?ooooo3Ol00002ooooo`;o00002Oooool2o`0000Gooooo0_l0000Nooooo`;o00001?ooool2o`00
00Gooooo0_l00005ooooo`;o000000?oooooo`000?l000000ol00003ooooo`Co000000?oooooo`00
0?l000001ol0000:ooooo`;o00002?ooool2o`0000Gooooo0_l00004ooooo`;o0000??ooool001co
oooo00?o0000ooooooooool0EOooool2o`000003ooooool0003o000000gooooo0_l00008ooooo`;o
000000Coooooo`000?l0003ooooo0_l00003ooooo`go000000Coooooo`000?l0003o00001_ooool2
o`0002Sooooo0_l00003ooooo`Go00000oooool2o`00013ooooo1?l000000ooooooo0000o`000003
o`000003ooooool0003o000000Co00004Oooool3o`0000[ooooo0_l0000looooo`007?ooool00ol0
003oooooooooo`17ooooo`;o00002?ooool2o`000003ooooool0003o000000Co00003Oooool2o`00
00Sooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o0000013o00000oooool3o`00
0003ooooool0003o000000Kooooo0_l0000Tooooo`Ko00005Oooool2o`0000Kooooo0_l000001?oo
oooo0000o`000?ooool3o`0000[ooooo0_l00006ooooo`;o0000B?ooool001cooooo00?o0000oooo
ooooool07oooool2o`0002Gooooo0ol000000ooooooo0000o`000005ooooo`;o000000?oooooo`00
0?l000001?l00004ooooo`Co000000Coooooo`000?l0003ooooo0_l00009ooooo`;o00000_ooool3
o`0000;ooooo4_l00002ooooo`Co00002Oooool2o`0002;ooooo1ol00003ooooo`;o00006Oooool2
o`000005ooooool0003o0000o`000?ooool00_l0000:ooooo`;o00003oooool2o`0000Kooooo0_l0
000gooooo`007?ooool00ol0003oooooooooo`0Oooooo`;o00007oooool2o`0000Cooooo0_l00002
ooooo`;o00001Oooool:o`0000?ooooo1?l000000ooooooo0000o`000003o`0000Wooooo0_l00003
ooooo`;o00000_oooolGo`0002kooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l00004
ooooo`;o00004oooool6o`0000_ooooo0_l0000Aooooo`;o00001Oooool4o`0003Kooooo00001_oo
ooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0
1_ooool00ol0003oooooooooo`10ooooo`;o00001?ooool2o`0000Oooooo3?l0000:ooooo`;o0000
2oooool2o`0000Cooooo6?l00004ooooo`;o00003?ooool2o`00027ooooo0_l00007ooooo`?o0000
5?ooool2o`0000kooooo0_l00005ooooo`;o00004Oooool4o`0003Kooooo00001_ooooooMgMgoiRH
V?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0
003oooooooooo`0looooo`;o00002?ooool2o`0000Kooooo3Ol0000Gooooo`;o00001?oooolIo`00
00?ooooo0_l00005ooooo`;o00001Oooool2o`00023ooooo1?l00002ooooo`;o00000_ooool2o`00
01Gooooo0_l00009ooooo`;o00002_ooool4o`0004Wooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
027ooooo0_l0000Iooooo`;o000000?oooooo`000?l000001_ooool2o`0000;ooooo4Ol000000ooo
oooo0000o`00000IoooooaWo00002_ooool2o`0002Oooooo1?l00002ooooo`;o00009?ooool2o`00
00cooooo0_l00006ooooo`;o0000@Oooool00003ooooool0003ooooo00;ooooo00?o0000oooooooo
ool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0000Qooooo`?o00006?ooool2o`00
0003ooooool0003o000000Gooooo1?l000000ooooooo0000o`000008o`000003ooooool0003o0000
00Co000000?oooooo`000?l000005ooooolLo`0000Wooooo0_l0000Dooooo`;o00003oooool2o`00
00Cooooo0_l00008ooooo`;o000000?oooooo`000?l000008Oooool3o`0000_ooooo0_l00002oooo
o`;o0000?Oooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003o
EEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool08_ooool2o`0000kooooo0_l0000;oooo
o`;o00001Oooool4o`000003ooooool0003o000000So000000?oooooo`000?l000001?l0000@oooo
o`;o00002?oooolPo`0000Gooooo0_l0000Dooooo`;o00003oooool2o`0000Cooooo1?l00006oooo
o`;o000000Coooooo`000?l0003o00001?ooool2o`0001Wooooo1?l0000?ooooo`;o0000?Oooool0
0003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08oooo
o`03o`000?oooooooooo02?ooooo0_l0000=ooooo`;o00003oooool3o`0000Kooooo3ol0000Aoooo
o`Co00001?ooool2o`000003ooooool0003o000001go00003_ooool2o`0000Cooooo0_l0000Noooo
o`;o00002Oooool3o`0000Cooooo0_l0000Gooooo`Co0000D?ooool00006oooooomgMgOoV9RHoooo
oonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo02?ooooo0_l0000N
ooooo`?o00000_ooool2o`0000?ooooo3_l0000Cooooo`;o00001?ooool2o`0000;ooooo6ol0000A
ooooo`;o00001?ooool2o`0001cooooo0_l00003ooooo`;o00001_ooool2o`0001kooooo0_l00009
ooooo`;o0000Aoooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`00
0?l@4106ooooo`03o`000?oooooooooo04Sooooo0_l00003ooooo`Ko000000?oooooo`000?l00000
1?l0000Nooooo`ko000000?oooooo`000?l000002_l000000ooooooo0000o`000005ooooo`Co0000
5oooool4o`0000cooooo1?l00003ooooo`;o00002_ooool2o`0001[ooooo0ol00004ooooo`;o0000
0_ooool3o`0000Sooooo0_l0000looooo`007?ooool00ol0003oooooooooo`10ooooo`;o00003?oo
ool;o`0000;ooooo0_l000000ooooooo0000o`00000Hoooooaoo00001?ooool4o`0000oooooo0_l0
0002ooooo`;o00000_ooool4o`0000Kooooo0_l00004ooooo`;o00004Oooool2o`0001[ooooo1Ol0
00001?oooooo0000o`000?l00002ooooo`?o00002?ooool2o`0003cooooo000Looooo`03o`000?oo
oooooooo043ooooo0_l0000<ooooo`_o00000_ooool2o`000003ooooool0003o000000gooooo0_l0
0005ooooob?o00001?ooool3o`0000Kooooo2Ol000000ooooooo0000o`000004o`0000;ooooo0_l0
0003ooooo`;o00000oooool2o`0001?ooooo0_l0000Qooooo`;o000000?oooooo`000?l000000ooo
ool2o`0004Oooooo000Looooo`03o`000?oooooooooo04kooooo2_l0000Eooooo`;o000000?ooooo
o`000?l000000_oooolSo`0000;ooooo0_l000000ooooooo0000o`000004oooooa3o00001?ooool3
o`0000;ooooo0_l00003ooooo`;o00002?ooool2o`0000Wooooo0_l0000Iooooo`;o00000oooool2
o`000003ooooool0003o000000Kooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`1:oooo
o`;o00001_ooool2o`0000Oooooo1?l0000Aooooo`;o00001?oooolNo`0000Gooooo0_l00004oooo
oa?o00000oooool4o`0000?ooooo0_l00002ooooo`;o00002?ooool2o`0000Cooooo0_l00005oooo
o`;o00001oooool2o`000003ooooool0003o000000Gooooo0_l00004ooooo`;o00000oooool2o`00
0003ooooool0003o000000oooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`17ooooo`;o
000000Coooooo`000?l0003o00001Oooool5o`0000?ooooo1Ol0000:ooooo`;o000000?oooooo`00
0?l000000oooool2o`0000?ooooo6?l000000ooooooo0000o`000002o`0000Sooooo0_l00002oooo
oaGo000000?oooooo`000?l000001ol00002ooooo`;o00001?ooool2o`0000;ooooo0_l00004oooo
o`;o00000oooool4o`0000Oooooo0_l000000ooooooo0000o`000004ooooo`?o000000Coooooo`00
0?l0003o00006Oooool2o`0003kooooo000Looooo`03o`000?oooooooooo04Oooooo0_l000001?oo
oooo0000o`000?l00007ooooo`?o00000_ooool4o`0000cooooo0_l000000ooooooo0000o`000003
ooooo`Co00000_oooolLo`0000Gooooo0_l000000ooooooo0000o`00000Qo`0000Sooooo0_l00002
ooooo`;o00002Oooool2o`0000Gooooo0_l0000;ooooo`;o00000_ooool3o`0000Cooooo0_l0000A
ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0A?ooool2o`0000Cooooo0ol00003oooo
o`;o00001oooool2o`0001Gooooo0_l000000ooooooo0000o`000002ooooo`?o00000_oooolDo`00
00Kooooo1?l00003ooooo`Ko000000?oooooo`000?l000004_l00002ooooo`?o000000?oooooo`00
0?l000002?ooool4o`00013ooooo1?l00004ooooo`;o00003_ooool2o`0000;ooooo0_l0000;oooo
o`Co0000@?ooool001cooooo00?o0000ooooooooool0A?ooool2o`0000[ooooo0_l00005ooooo`;o
00004Oooool4o`0000;ooooo0_l0000:oooooa;o00001?ooool2o`0000;ooooo0_l00005oooooa_o
000000Goooooo`000?l0003o0000ooooo`03o`0000?ooooo0_l00003ooooo`Co00001oooool2o`00
00Wooooo0_l00004ooooo`;o00003oooool2o`000003ooooool0003o000000Kooooo0_l00003oooo
o`;o0000@_ooool001cooooo00?o0000ooooooooool09oooool2o`0002kooooo0_l0000>ooooo`;o
000000?oooooo`000?l000000_l00002ooooo`?o00001Oooool6o`0000;ooooo0_l00004ooooo`?o
00000oooool2o`0000Cooooo0_l00008oooooaoo000000Goooooo`000?l0003o0000ooooo`02o`00
0003ooooool0003o000000kooooo0_l00009ooooo`;o00002?ooool2o`0000Kooooo0_l000000ooo
oooo0000o`000002o`0000Wooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`0Wooooo`;o
00009?ooool3o`0000?ooooo0_l00005ooooo`;o000000?oooooo`000?l000002?ooool5o`0000Co
oooo1?l00004ooooo`Co00000_ooool2o`0000gooooo1?l0000;oooooaoo000000?oooooo`000?l0
00000_ooool2o`0000Kooooo0_l0000Looooo`Co00001?ooool4o`000003ooooool0003o000005Co
oooo000Looooo`03o`000?oooooooooo04gooooo0ol00003ooooo`;o00001Oooool2o`000003oooo
ool0003o000000[ooooo0_l00007ooooo`;o00001Oooool2o`0000?ooooo0_l0000=ooooo`Co0000
1Oooool2o`0000Cooooo8_l00009ooooo`?o00007?ooool4o`0000Cooooo0_l00003ooooo`;o0000
2?ooool2o`0004[ooooo000Looooo`;o0000@_ooool2o`000003ooooool0003o000001Sooooo0_l0
000Rooooo`;o00004_ooool2o`0000Cooooo8_l00006ooooo`;o000000?oooooo`000?l000000ooo
ool2o`000003ooooool0003o000001Cooooo1?l0000:ooooo`;o00002?ooool2o`0004[ooooo000L
ooooo`03o`000?oooooooooo047ooooo1Ol0000Hooooo`;o00008_ooool2o`0000Wooooo0_l0000=
oooooaCo000000?oooooo`000?l000002ol00006ooooo`?o00001Oooool2o`000003ooooool0003o
000001;ooooo1?l00009ooooo`Co0000EOooool001cooooo00?o0000ooooooooool0@_ooool2o`00
00oooooo0_l0000Vooooo`;o00001Oooool2o`0000Oooooo1?l0000>ooooo`Co000000?oooooo`00
0?l000003?l000000ooooooo0000o`000006o`000003ooooool0003o000000Co00001?ooool3o`00
01_ooooo0ol0000;ooooo`Ko00001?ooool2o`0004gooooo000Looooo`03o`000?oooooooooo04[o
oooo0_l00007ooooo`;o00009_ooool2o`0000Gooooo0_l00007ooooo`;o00003oooool2o`000003
ooooool0003o000001So000000?oooooo`000?l000001?l00004ooooo`;o00006oooool4o`0000[o
oooo0ol00002ooooo`;o00001?ooool2o`0004gooooo000Looooo`03o`000?oooooooooo04?ooooo
0_l000000ooooooo0000o`000002ooooo`;o00004Oooool2o`0000oooooo0ol00004ooooo`;o0000
5?ooool2o`0000oooooo0_l000000ooooooo0000o`00000=o`000003ooooool0003o000000co0000
8Oooool2o`000003ooooool0003o000000?o00001oooool4o`0000_ooooo0_l00002ooooo`;o0000
Aoooool001cooooo00?o0000ooooooooool0@oooool2o`000003ooooool0003o000000[ooooo0_l0
0009ooooo`;o000000?oooooo`000?l000003?ooool3o`0000Cooooo0_l00007ooooo`;o00002ooo
ool2o`0000?ooooo0_l0000;ooooo`;o000000?oooooo`000?l000007Ol0000Oooooo`;o00001?oo
ool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000001_ooool2o`0000;ooooo0_l0
0002ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0D_ooool2o`0000cooooo0_l0000<
ooooo`;o00003_ooool2o`0000_ooooo0_l00003ooooo`;o00001_ooool4o`000003ooooool0003o
000000?ooooo7Ol00007ooooo`;o00005Oooool2o`0000Wooooo0_l00006ooooo`;o00001_ooool3
o`0004kooooo000Looooo`03o`000?oooooooooo06gooooo0_l0000Yooooo`Co00001?oooolOo`00
00?ooooo0_l00002ooooo`;o000000?oooooo`000?l000004_ooool2o`0000Wooooo0_l0000?oooo
o`;o0000C_ooool001cooooo00?o0000ooooooooool0H?ooool2o`0000_ooooo0_l0000aoooooa_o
00000_ooool2o`0000;ooooo0ol00005ooooo`;o00007Oooool2o`0005oooooo000Looooo`03o`00
0?oooooooooo063ooooo0_l0000noooooa_o00000_ooool2o`0000;ooooo0_l0000Yooooo`;o0000
3Oooool2o`0004cooooo000Looooo`03o`000?oooooooooo05gooooo0_l000000ooooooo0000o`00
000Dooooo`;o00002?ooool2o`0001cooooo0_l00002ooooo`;o00000_oooolEo`0000cooooo0_l0
000Looooo`;o00001Oooool2o`0000gooooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`18
ooooo`;o00003_ooool2o`0000?ooooo0ol0000?ooooo`;o00001Oooool2o`0000Sooooo0_l0000=
ooooo`;o00000_ooool2o`0000Wooooo0_l00006oooooaGo000000?oooooo`000?l000002Oooool2
o`0000?ooooo0_l0000Gooooo`;o00001?ooool2o`0000kooooo0_l0001<ooooo`007?ooool00ol0
003oooooooooo`18ooooo`;o00003?ooool4o`0000?ooooo0ol0000?ooooo`;o00006oooool2o`00
0005ooooool0003o0000o`000?ooool00_l0000@ooooo`;o000000?oooooo`000?l000002Ol00000
0ooooooo0000o`000002o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000[ooooo0ol0
000Booooo`Co00001Oooool3o`0005cooooo000Looooo`03o`000?oooooooooo04gooooo0_l00007
ooooo`;o000000Coooooo`000?l0003o00000_ooool3o`0000kooooo0_l0000Kooooo`;o00000_oo
ool2o`0001?ooooo0_l00004ooooo`go000000Coooooo`000?l0003ooooo1_l0000;ooooo`;o0000
2Oooool2o`0000Gooooo1ol00004ooooo`;o0000GOooool001cooooo00?o0000ooooooooool0Booo
ool4o`0000[ooooo1?l00002ooooo`;o00004?ooool2o`0001Cooooo0ol000000ooooooo0000o`00
000<ooooo`?o00003Oooool?o`000003ooooool0003o000000?ooooo0ol0000Gooooo`;o00001Ooo
ool2o`0000?ooooo0_l00002ooooo`Co00002oooool2o`00053ooooo000Looooo`03o`000?oooooo
oooo04_ooooo1?l000000ooooooo0000o`000009ooooo`;o00004_ooool4o`0001Cooooo0ol00000
0ooooooo0000o`00000<ooooo`Co00003?ooool4o`0000;ooooo2?l00003ooooo`;o00000oooool2
o`0000?ooooo0_l0000Booooo`;o00000oooool2o`0000Wooooo0_l0000=ooooo`;o0000D?ooool0
01cooooo0_l0001Aooooo`;o00001Oooool2o`0000;ooooo0_l00004ooooo`;o00003?ooool2o`00
00;ooooo0_l00005ooooo`Co00007Oooool2o`0000kooooo0_l00004ooooo`Ko00000oooool4o`00
00Kooooo0_l0000Fooooo`?o00001_ooool2o`0000kooooo0_l0001Booooo`007?ooool00ol0003o
ooooooooo`19ooooo`;o00001oooool2o`0000?ooooo0_l00008ooooo`;o00004?ooool2o`0000Go
oooo1?l00007ooooo`;o00008?ooool2o`0000Gooooo1Ol00009ooooo`;o00000oooool2o`000003
ooooool0003o000001Kooooo0ol00006ooooo`;o00001Oooool2o`0000Cooooo0_l000000ooooooo
0000o`00001Booooo`007?ooool00ol0003oooooooooo`19ooooo`;o00000oooool2o`0000;ooooo
0_l0000Qooooo`;o00003_ooool2o`0001oooooo0ol00005ooooo`Co00003oooool2o`0000Gooooo
0_l0000:ooooo`;o00003_ooool2o`0000Kooooo0_l00004ooooo`;o0000EOooool001cooooo00?o
0000ooooooooool0C_ooool3o`000004ooooool0003o0000ooooo`;o00002?ooool2o`0001Cooooo
0_l0000Fooooo`;o00005oooool2o`0000Oooooo0_l0000Gooooo`;o00002_ooool2o`000003oooo
ool0003o000000?ooooo0_l00006ooooo`;o00000oooool2o`000003ooooool0003o000005_ooooo
000Looooo`03o`000?oooooooooo04Wooooo0_l00004ooooo`;o000000?oooooo`000?l000000ol0
0005ooooo`;o000000?oooooo`000?l000000_l0000Zooooo`;o000000?oooooo`000?l000004Ooo
ool2o`0000;ooooo0_l0000Kooooo`;o00002_ooool2o`0000Gooooo0_l00003ooooo`?o00002Ooo
ool3o`0005kooooo000Looooo`03o`000?oooooooooo04Wooooo0_l00009ooooo`;o00001_ooool2
o`0000?ooooo0_l0000<ooooo`;o00007oooool2o`00017ooooo0_l00002ooooo`;o00002Oooool2
o`0000_ooooo0_l000000ooooooo0000o`000002o`0000[ooooo0_l00003ooooo`;o00001_ooool3
o`0000Sooooo0_l0001Oooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00000_ooool5o`00
01?ooooo0_l0000booooo`;o00003Oooool2o`0000_ooooo0_l000001?oooooo0000o`000?ooool2
o`0000Sooooo0_l00004ooooo`;o00001oooool2o`0000Kooooo0_l0000<ooooo`;o0000Doooool0
01cooooo00?o0000ooooooooool0Coooool2o`0000;ooooo0_l00002ooooo`Ko00002Oooool2o`00
00Wooooo0_l0000eooooo`;o00001oooool2o`0001;ooooo0_l00008ooooo`;o00005Oooool2o`00
00cooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`1?ooooo`;o00002?ooool5o`0000So
oooo0_l00009ooooo`;o00006?ooool2o`0001[ooooo0ol00007ooooo`;o00007oooool2o`0001;o
oooo0_l0001Qooooo`007?ooool00ol0003oooooooooo`1Gooooo`Co000000?oooooo`000?l00000
;Oooool2o`0001[ooooo0_l0000Jooooo`;o00002Oooool2o`0000;ooooo0_l0000Gooooo`;o0000
G?ooool001cooooo00?o0000ooooooooool0Eoooool4o`0001cooooo0_l00005ooooo`Co00001ooo
ool2o`0000?ooooo0_l0000cooooo`;o00002Oooool2o`0000;ooooo0ol00004ooooo`;o00001_oo
ool2o`0000Sooooo0_l0001Looooo`007?ooool00ol0003oooooooooo`1Gooooo`;o00004_ooool2
o`0000Oooooo0_l000000ooooooo0000o`000003ooooo`Ko00001oooool2o`0000?ooooo0_l0000g
ooooo`?o00002Oooool3o`0000?ooooo0_l00006ooooo`;o0000I_ooool001cooooo00?o0000oooo
ooooool0I_ooool3o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`;o00001_ooool2o`00
04Wooooo0ol00005ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`;o00003oooool2o`00
05[ooooo000Looooo`03o`000?oooooooooo05Gooooo0_l000001?oooooo0000o`000?l0000;oooo
o`?o00000_ooool2o`000003ooooool0003o0000013ooooo0_l00013ooooo`;o00002?ooool2o`00
00Oooooo0_l00002ooooo`;o00002Oooool2o`0000Cooooo0_l0001Jooooo`007?ooool00ol0003o
ooooooooo`1Eooooo`;o000000Coooooo`000?l0003o00009Oooool2o`0000Cooooo0_l0000/oooo
o`?o00003_ooool2o`00023ooooo1?l00007ooooo`;o0000EOooool001cooooo00?o0000oooooooo
ool0FOooool2o`0002_ooooo0_l0000Tooooo`;o00000_ooool7o`0000Gooooo0_l0000Mooooo`Co
00002_ooool4o`0000Gooooo0_l0001Eooooo`007?ooool2o`0005[ooooo0_l0000Cooooo`?o0000
>_ooool3o`0000;ooooo1?l00003ooooo`;o00000oooool2o`0001gooooo1?l0000<ooooo`?o0000
Foooool001cooooo00?o0000ooooooooool0K_ooool4o`0001Wooooo0_l0000Nooooo`?o00002Ooo
ool2o`000003ooooool0003o000000Oooooo1?l000001?oooooo0000o`000?l0000:ooooo`;o0000
5?ooool3o`0005_ooooo000Looooo`03o`000?oooooooooo05_ooooo1Ol0000@ooooo`;o00004Ooo
ool4o`0000Cooooo0_l0000Nooooo`?o00002Oooool2o`000003ooooool0003o000000Oooooo1?l0
00001?oooooo0000o`000?l00008ooooo`Co00002?ooool2o`0000[ooooo0_l0001Looooo`007?oo
ool00ol0003oooooooooo`1Iooooo`So00007?ooool2o`0000Cooooo1?l00008ooooo`;o00000_oo
ool2o`0001[ooooo0_l00002ooooo`;o00000_ooool2o`0000Oooooo0_l00003ooooo`;o000000?o
ooooo`000?l000002Oooool2o`0000[ooooo0_l0001Xooooo`007?ooool00ol0003oooooooooo`1C
ooooo`;o00001?ooool2o`0000;ooooo1?l0000Booooo`;o00001?ooool2o`0000;ooooo0_l0000@
ooooo`;o00000_ooool2o`0001[ooooo0_l00002ooooo`;o00002oooool2o`0000oooooo0_l00008
ooooo`;o00000_ooool2o`0000Sooooo0_l0001Nooooo`007?ooool00ol0003oooooooooo`1Coooo
o`;o00002Oooool3o`00017ooooo0ol00004ooooo`;o00003?ooool2o`0001_ooooo0ol0000Eoooo
o`;o00002Oooool2o`0000Sooooo0_l00003ooooo`;o00000oooool2o`0000;ooooo0_l00003oooo
o`;o00000oooool2o`0005kooooo000Looooo`03o`000?oooooooooo05kooooo0ol0000Aooooo`;o
00000_ooool2o`0000oooooo1?l0000<ooooo`;o000000Coooooo`000?l0003ooooo0_l00005oooo
o`?o00000oooool2o`0000Kooooo0_l00006ooooo`Co00002Oooool2o`0000gooooo0_l00006oooo
o`;o00001?ooool2o`0006?ooooo000Looooo`03o`000?oooooooooo05oooooo0_l00003ooooo`;o
000000Coooooo`000?l0003o00003?ooool2o`00017ooooo0_l0000<ooooo`;o000000Coooooo`00
0?l0003ooooo0_l00007ooooo`;o00000_ooool2o`0000Kooooo0_l00002ooooo`;o00000_ooool2
o`000003ooooool0003o000000Cooooo0_l00003ooooo`?o00000oooool2o`0000kooooo0_l00006
ooooo`;o0000HOooool001cooooo00?o0000ooooooooool0I?ooool7o`0000_ooooo0ol00008oooo
o`;o00002_ooool2o`0000Cooooo0_l0000:ooooo`;o00000_ooool2o`000004ooooool0003o0000
o`0000gooooo0_l00005ooooo`;o00001?ooool2o`0000?ooooo0ol00003ooooo`;o00005_ooool2
o`0000?ooooo0_l0001Looooo`007?ooool00ol0003oooooooooo`1Vooooo`;o000000?oooooo`00
0?l000002oooool3o`0000Sooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0ol00000
1?oooooo0000o`000?ooool2o`0000Gooooo0_l00003ooooo`?o000000?oooooo`000?l000000_oo
ool2o`0000gooooo0_l00003ooooo`;o00007_ooool2o`0000kooooo0_l0001Looooo`007?ooool0
0ol0003oooooooooo`1Kooooo`;o00001_ooool2o`0001oooooo0_l000000ooooooo0000o`000003
ooooo`?o000000Coooooo`000?l0003o00001oooool2o`0000Cooooo0_l0000=ooooo`;o00001ooo
ool2o`000003ooooool0003o000001kooooo0_l0000;ooooo`;o0000Goooool001cooooo00?o0000
ooooooooool0Foooool3o`0000Gooooo0_l00004ooooo`;o00004Oooool2o`0000oooooo0_l00002
ooooo`;o00002Oooool2o`00017ooooo0_l00007ooooo`;o00006_ooool2o`0000Kooooo1?l00008
ooooo`;o0000Goooool001cooooo00?o0000ooooooooool0G?ooool2o`0000Gooooo0_l00004oooo
o`;o00004Oooool2o`00013ooooo0_l00002ooooo`Co00001_ooool2o`00017ooooo0_l00003oooo
o`;o00005?ooool2o`0000Sooooo0_l00006ooooo`Co0000JOooool001cooooo00?o0000oooooooo
ool0I_ooool2o`0000Sooooo0_l0000:ooooo`;o00002Oooool2o`0000Gooooo0ol000000ooooooo
0000o`000002o`000003ooooool0003o000000Gooooo0_l00006ooooo`;o00001oooool2o`000003
ooooool0003o000000;o00005?ooool2o`000003ooooool0003o000007[ooooo00001_ooooook^k^
oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`1Vooooo`;o00001Oooool5o`0000[ooooo0ol00002ooooo`;o00001?ooool2
o`0000Kooooo0_l00006ooooo`;o00001Oooool2o`000003ooooool0003o000000?ooooo0_l00007
ooooo`;o000000?oooooo`000?l000004_ooool2o`0000;ooooo1Ol0001jooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo
00?o0000ooooooooool0Ioooool3o`0000?ooooo1?l00002ooooo`;o00000_ooool2o`0000;ooooo
1?l00002ooooo`;o00003Oooool2o`0000Gooooo1_l00002ooooo`Co00007oooool2o`0000;ooooo
0_l00003ooooo`;o0000O?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0HOooool2o`0000Cooooo
0ol00004ooooo`?o00000_ooool2o`0000;ooooo0_l00002ooooo`;o00004oooool2o`0000Kooooo
1Ol00002ooooo`?o00002oooool2o`0000;ooooo0ol0000>ooooo`;o00005?ooool2o`0000Gooooo
0_l0001Xooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nH
V9SooooooiRHV?lb<S801_ooool3o`00067ooooo0_l00005ooooo`;o00005?ooool2o`0000kooooo
0_l0000;ooooo`;o00000oooool2o`0000Gooooo0_l00004ooooo`;o00000_ooool3o`0001Gooooo
0ol0000<ooooo`Co00000oooool2o`0006Sooooo00000ooooooo0000ooooo`02ooooo`03o`000?oo
oooooooo00Wooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo06Sooooo
0_l00005ooooo`;o00003Oooool2o`0000kooooo0_l00008ooooo`;o00001?ooool2o`0000Oooooo
0_l00007ooooo`;o000000?oooooo`000?l000005?ooool3o`0000Cooooo0_l00005ooooo`;o0000
00?oooooo`000?l00000KOooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Ooo
ool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0Koooool2o`0002;ooooo
0_l00003ooooo`;o00001?ooool2o`000003ooooool0003o000000Kooooo0_l00005ooooo`;o0000
00?oooooo`000?l000000_ooool2o`0000Kooooo0_l00007ooooo`;o00001?ooool4o`0000Gooooo
0_l0001`ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj
^_l000001_ooool00ol0003oooooooooo`2;ooooo`;o00001_ooool4o`0000[ooooo1?l00004oooo
o`;o00003?ooool2o`0000Kooooo0_l00007ooooo`;o00001?ooool5o`0007Kooooo00001_oooooo
k^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oo
oooooooo07Oooooo0_l000000ooooooo0000o`000003ooooo`?o00002Oooool4o`0000;ooooo0_l0
0002ooooo`;o00001_ooool2o`000003ooooool0003o000000Go00001Oooool3o`0000;ooooo0_l0
0008ooooo`Co00001_ooool2o`0000Gooooo0_l00003ooooo`;o0000M_ooool001cooooo00?o0000
ooooooooool0Moooool5o`0000?ooooo0ol00009ooooo`Co00000_ooool2o`0000Oooooo0_l00000
1?oooooo0000o`000?ooool2o`0000;ooooo0ol00005ooooo`?o00000_ooool3o`0000;ooooo0_l0
00000ooooooo0000o`000004o`0000Kooooo0_l00005ooooo`;o00000oooool2o`0007Kooooo000L
ooooo`03o`000?oooooooooo07Wooooo0ol00003ooooo`?o00001?ooool2o`0000?ooooo0ol00000
0ooooooo0000o`000008ooooo`?o00002?ooool2o`0000Kooooo0_l00004ooooo`;o00000_ooool2
o`000003ooooool0003o000000Co00004_ooool2o`0007Kooooo000Looooo`03o`000?oooooooooo
07[ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Kooooo0ol00008oooo
o`;o00000_ooool2o`0000Gooooo0_l0000<ooooo`;o000000?oooooo`000?l000000oooool2o`00
0003ooooool0003o000008[ooooo000Looooo`03o`000?oooooooooo07Oooooo0_l00006ooooo`;o
000000?oooooo`000?l000001_ooool7o`0000Sooooo0_l00002ooooo`;o00004oooool2o`000004
ooooool0003o0000ooooo`Co00004Oooool2o`0007[ooooo000Looooo`03o`000?oooooooooo07Oo
oooo0_l0000=ooooo`;o00000_ooool4o`000003ooooool0003o000000Sooooo0_l00004ooooo`;o
00001oooool2o`0000kooooo1Ol0000@ooooo`;o0000N_ooool001cooooo00?o0000ooooooooool0
NOooool2o`0000_ooooo0_l0000Aooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o
000000Coooooo`000?l0003o00000_ooool2o`0000Wooooo0_l000000ooooooo0000o`000009oooo
o`;o0000POooool001cooooo00?o0000ooooooooool0NOooool2o`0000_ooooo0_l00006ooooo`;o
00002Oooool2o`000003ooooool0003o000000Oooooo1_l000000ooooooo0000o`000002o`0000So
oooo0_l0000<ooooo`?o0000P?ooool001cooooo00?o0000ooooooooool0O?ooool2o`0000Oooooo
0ol00006ooooo`;o00002Oooool2o`0000cooooo0_l00003ooooo`Co00005oooool2o`00083ooooo
000Looooo`03o`000?oooooooooo07cooooo0ol00006ooooo`;o0000>?ooool2o`0000Cooooo0_l0
0022ooooo`007?ooool00ol0003oooooooooo`1mooooo`;o00004Oooool2o`0000Kooooo0_l00004
ooooo`;o00006_ooool2o`0000?ooooo0_l00004ooooo`;o0000P_ooool001cooooo00?o0000oooo
ooooool0Qoooool3o`0000Kooooo0_l00006ooooo`?o00000oooool2o`0000cooooo0_l0000<oooo
o`;o0000SOooool001cooooo0_l00028ooooo`?o000000?oooooo`000?l000002Oooool2o`000003
ooooool0003o0000017ooooo0_l0002Kooooo`007?ooool00ol0003oooooooooo`22ooooo`;o0000
1oooool2o`0000Gooooo1_l00007ooooo`;o0000Z?ooool001cooooo00?o0000ooooooooool0P_oo
ool2o`000003ooooool0003o000000_ooooo1?l00005ooooo`;o00000_ooool2o`000003ooooool0
003o00000:Gooooo000Looooo`03o`000?oooooooooo08Gooooo0_l00004ooooo`;o00003_ooool2
o`0000;ooooo1Ol0002Uooooo`007?ooool00ol0003oooooooooo`2;ooooo`;o00004_ooool3o`00
0003ooooool0003o00000:Cooooo000Looooo`03o`000?oooooooooo0:?ooooo0_l0002Tooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBooo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
4_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom:ooooo`005?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000
ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o0000ooooooooool0oooooomBoooo
o`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?oooooo
D_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`004_ooool00omEEEGoIVIVo`00003o
oooooeCooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Uooooo`04oa0@4?l0
003o0000ooooo`;o000000?o410@ooooooooool05Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00Go
oooo00?o0000onk^k_ooool00oooool5o`00093ooooo002Vooooo`05o`000?ooooooooooooooool0
00002Oooool6o`0000Wooooo00GoEEEEogMgMoooooooV9RHob4Q8@05ooooo`03oeEEEOnYZJWooooo
00?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A02@ooooo`00Y_ooool01Ol0003ooooooooooooooooo
000001Sooooo00Go0000ooooooooooooooooo`000005ooooo`03ojVYZOmEEEGooooo00Cooooo00?o
V9RHob4Q8Oo^k^h0TOooool00:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00002Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o8B4Qooooooooool01?ooool00onHV9So8B4Q
onk^kP2@ooooo`00Y_ooool01Ol0003oQhN7oooooonYZJWo000001Sooooo00Go0000oeEEEOl0003o
410@olc<c006ooooo`03oeEEEOo<c<cooooo00Gooooo00?oMgMgofIVI_ooool0Soooool00:Gooooo
00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Fooooo`03oeEEEOn7QhOooooo00Sooooo
00?oZJVYogMgMoooool01_ooool00ol0003oooooooooo`2>ooooo`00`oooool00ooMgMgo410@oiRH
V005ooooo`05oa0@4?oooooooooooooooolb<S800oooool01Ol0003o^[ZjoooooonHV9So410@093o
oooo0034ooooo`04olc<c?m4A4Co0000oa0@40?ooooo1Ol00003ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`0T?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(678) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.33872 .36262 Mdot
.38022 .40336 Mdot
.48318 .66239 Mdot
.57357 .37509 Mdot
.61601 .59381 Mdot
.5076 .65864 Mdot
.38784 .59518 Mdot
.37019 .60256 Mdot
.50708 .67185 Mdot
.36965 .26072 Mdot
.3835 .56643 Mdot
.65242 .45023 Mdot
.40246 .59476 Mdot
.59886 .42213 Mdot
.22529 .61139 Mdot
.51693 .40599 Mdot
.4005 .40554 Mdot
.69227 .5463 Mdot
.51599 .41555 Mdot
.48047 .64292 Mdot
.40867 .44103 Mdot
.59575 .41637 Mdot
.37975 .4067 Mdot
.59717 .42041 Mdot
.5476 .41127 Mdot
.3621 .37882 Mdot
.3357 .35597 Mdot
.56879 .39866 Mdot
.56542 .43692 Mdot
.40756 .57007 Mdot
.64343 .62548 Mdot
.21555 .68961 Mdot
.53606 .37275 Mdot
.61259 .2841 Mdot
.41817 .62256 Mdot
.63144 .77365 Mdot
.52978 .68283 Mdot
.36335 .57976 Mdot
.39162 .61542 Mdot
.41504 .61635 Mdot
.41709 .60638 Mdot
.36625 .38527 Mdot
.43246 .57987 Mdot
.45033 .65114 Mdot
.58858 .36681 Mdot
.24244 .50572 Mdot
.75246 .61971 Mdot
.5718 .3982 Mdot
.34392 .36642 Mdot
.49377 .63351 Mdot
.69589 .29043 Mdot
.36151 .57894 Mdot
.27354 .57904 Mdot
.10181 .43433 Mdot
.41531 .58379 Mdot
.57231 .38107 Mdot
.53354 .66097 Mdot
.60161 .3877 Mdot
.58353 .40317 Mdot
.61395 .26684 Mdot
.56815 .42812 Mdot
.70656 .57649 Mdot
.3315 .3704 Mdot
.47312 .6403 Mdot
.50902 .6674 Mdot
.42448 .58865 Mdot
.40804 .3854 Mdot
.40514 .60229 Mdot
.58656 .47176 Mdot
.48554 .64529 Mdot
.5747 .39315 Mdot
.38084 .56622 Mdot
.41515 .38796 Mdot
.54075 .43832 Mdot
.28874 .50355 Mdot
.3129 .61028 Mdot
.70181 .61624 Mdot
.50685 .30965 Mdot
.44867 .17783 Mdot
.36604 .66048 Mdot
.5942 .43068 Mdot
.42073 .16304 Mdot
.24939 .6109 Mdot
.3926 .40001 Mdot
.63803 .3162 Mdot
.43175 .77776 Mdot
.57751 .44515 Mdot
.55662 .54088 Mdot
.63194 .36158 Mdot
.37128 .47588 Mdot
.51355 .67515 Mdot
.35554 .38093 Mdot
.58463 .3661 Mdot
.58649 .44988 Mdot
.53138 .21381 Mdot
.57181 .35634 Mdot
.59176 .37162 Mdot
.35448 .32971 Mdot
.3882 .57104 Mdot
.65436 .42189 Mdot
.4432 .65183 Mdot
.25904 .56408 Mdot
.54953 .38706 Mdot
.49512 .65658 Mdot
.359 .41252 Mdot
.57262 .36771 Mdot
.42146 .58844 Mdot
.57966 .42535 Mdot
.44115 .56551 Mdot
.35075 .38852 Mdot
.58982 .44939 Mdot
.67551 .55591 Mdot
.31588 .48328 Mdot
.3625 .35026 Mdot
.27504 .30636 Mdot
.57037 .42167 Mdot
.5912 .40889 Mdot
.38417 .401 Mdot
.53849 .65367 Mdot
.52298 .53485 Mdot
.41014 .39764 Mdot
.40259 .61763 Mdot
.35244 .39732 Mdot
.64149 .40857 Mdot
.52968 .64194 Mdot
.26535 .56612 Mdot
.24276 .56422 Mdot
.81273 .51364 Mdot
.54573 .43896 Mdot
.21984 .58544 Mdot
.51323 .64807 Mdot
.3676 .39298 Mdot
.409 .60058 Mdot
.63288 .41378 Mdot
.39709 .37196 Mdot
.37422 .59682 Mdot
.67309 .57735 Mdot
.60828 .66289 Mdot
.36496 .34535 Mdot
.55982 .51242 Mdot
.392 .62035 Mdot
.4182 .61501 Mdot
.71678 .32234 Mdot
.38971 .39802 Mdot
.68328 .57969 Mdot
.37894 .59953 Mdot
.75255 .44399 Mdot
.63288 .40948 Mdot
.74981 .36466 Mdot
.47756 .14876 Mdot
.70678 .30337 Mdot
.21487 .42019 Mdot
.71688 .57876 Mdot
.38176 .60455 Mdot
.55494 .39103 Mdot
.38638 .38268 Mdot
.38142 .38789 Mdot
.60356 .45014 Mdot
.5537 .41919 Mdot
.62279 .40521 Mdot
.61563 .43628 Mdot
.72115 .68634 Mdot
.62249 .41265 Mdot
.46555 .56489 Mdot
.38892 .3589 Mdot
.54712 .42224 Mdot
.51661 .69604 Mdot
.5558 .45595 Mdot
.36394 .5791 Mdot
.58762 .39655 Mdot
.55433 .40975 Mdot
.54939 .37478 Mdot
.4126 .61063 Mdot
.32506 .7795 Mdot
.37883 .2075 Mdot
.52583 .79411 Mdot
.23914 .4035 Mdot
.5238 .65309 Mdot
.60494 .4332 Mdot
.70127 .59163 Mdot
.6392 .33287 Mdot
.58074 .40805 Mdot
.66523 .25993 Mdot
.56006 .41125 Mdot
.45196 .34554 Mdot
.62424 .33799 Mdot
.48729 .81554 Mdot
.38961 .51668 Mdot
.56989 .43594 Mdot
.43361 .21246 Mdot
.76256 .36684 Mdot
.68237 .61777 Mdot
.41822 .5918 Mdot
.53882 .69437 Mdot
.54043 .67345 Mdot
.43617 .60684 Mdot
.64529 .42892 Mdot
.36672 .26945 Mdot
.61942 .46264 Mdot
.2657 .57069 Mdot
.35576 .41788 Mdot
.71786 .56646 Mdot
.35604 .3448 Mdot
.3527 .18878 Mdot
.46366 .44116 Mdot
.36971 .54749 Mdot
.68454 .54616 Mdot
.49096 .67531 Mdot
.26422 .5779 Mdot
.69451 .59119 Mdot
.59223 .3754 Mdot
.34698 .37384 Mdot
.7618 .3622 Mdot
.54587 .35149 Mdot
.80585 .659 Mdot
.40134 .39227 Mdot
.46998 .52084 Mdot
.41516 .59424 Mdot
.51382 .63024 Mdot
.57138 .44269 Mdot
.61624 .40366 Mdot
.33259 .36772 Mdot
.57014 .40422 Mdot
.38382 .45885 Mdot
.5574 .40548 Mdot
.47165 .62959 Mdot
.66182 .59349 Mdot
.44393 .5949 Mdot
.81489 .49442 Mdot
.41878 .38211 Mdot
.51224 .57555 Mdot
.49434 .67123 Mdot
.31123 .32852 Mdot
.39183 .56402 Mdot
.67103 .57154 Mdot
.52128 .68831 Mdot
.6909 .60597 Mdot
.54199 .39078 Mdot
.52399 .6814 Mdot
.69098 .55982 Mdot
.58893 .67032 Mdot
.5874 .37023 Mdot
.72547 .42558 Mdot
.38125 .59415 Mdot
.3381 .35204 Mdot
.56705 .42864 Mdot
.24593 .55855 Mdot
.62769 .44147 Mdot
.2188 .59375 Mdot
.26942 .56123 Mdot
.27514 .57399 Mdot
.31981 .63613 Mdot
.70837 .59715 Mdot
.23931 .46398 Mdot
.4914 .49307 Mdot
.40704 .40187 Mdot
.59177 .36392 Mdot
.39647 .81954 Mdot
.3836 .60205 Mdot
.59158 .37651 Mdot
.44555 .7824 Mdot
.37924 .59925 Mdot
.60097 .39427 Mdot
.42117 .60629 Mdot
.38587 .38593 Mdot
.52473 .55774 Mdot
.37546 .41254 Mdot
.57911 .37668 Mdot
.39679 .57928 Mdot
.53223 .69278 Mdot
.36306 .37769 Mdot
.5787 .42137 Mdot
.60456 .42957 Mdot
.26016 .57684 Mdot
.54881 .42718 Mdot
.42177 .81533 Mdot
.57142 .39572 Mdot
.49328 .68032 Mdot
.57816 .35533 Mdot
.75646 .33094 Mdot
.61007 .65737 Mdot
.40409 .36797 Mdot
.27313 .56389 Mdot
.52199 .67444 Mdot
.59533 .59863 Mdot
.63849 .55238 Mdot
.58837 .42759 Mdot
.2498 .56719 Mdot
.47291 .53414 Mdot
.42138 .58261 Mdot
.62513 .35983 Mdot
.42682 .45371 Mdot
.5086 .68192 Mdot
.26458 .57549 Mdot
.62585 .3434 Mdot
.35994 .4117 Mdot
.56789 .38212 Mdot
.52705 .68541 Mdot
.34565 .3898 Mdot
.63561 .40737 Mdot
.74847 .6464 Mdot
.25075 .55878 Mdot
.38343 .59607 Mdot
.62466 .48502 Mdot
.62668 .40217 Mdot
.54392 .67123 Mdot
.3961 .38181 Mdot
.40698 .57587 Mdot
.35414 .36264 Mdot
.78027 .38147 Mdot
.24732 .41147 Mdot
.61656 .74917 Mdot
.69375 .54389 Mdot
.16715 .51822 Mdot
.54523 .78806 Mdot
.26026 .4397 Mdot
.79172 .52309 Mdot
.60875 .80803 Mdot
.51821 .69391 Mdot
.70394 .37038 Mdot
.52977 .67043 Mdot
.54811 .39253 Mdot
.50657 .66189 Mdot
.45465 .83238 Mdot
.56445 .40207 Mdot
.52795 .65399 Mdot
.69977 .69284 Mdot
.5581 .42449 Mdot
.37702 .3511 Mdot
.19539 .62452 Mdot
.30615 .30172 Mdot
.48901 .46032 Mdot
.52875 .64993 Mdot
.60872 .23104 Mdot
.56319 .41389 Mdot
.5184 .38686 Mdot
.38064 .37968 Mdot
.63512 .36471 Mdot
.7029 .55563 Mdot
.67751 .59661 Mdot
.71656 .34552 Mdot
.28453 .31529 Mdot
.51543 .45316 Mdot
.36776 .38027 Mdot
.45976 .17483 Mdot
.28856 .50607 Mdot
.23658 .5681 Mdot
.38996 .61644 Mdot
.32257 .77626 Mdot
.52323 .35815 Mdot
.5841 .51173 Mdot
.39774 .47214 Mdot
.3563 .38789 Mdot
.53922 .76629 Mdot
.40666 .58056 Mdot
.41682 .2069 Mdot
.42531 .28755 Mdot
.62165 .39454 Mdot
.41767 .57017 Mdot
.65292 .44316 Mdot
.3852 .46473 Mdot
.73412 .39746 Mdot
.48206 .71583 Mdot
.58163 .37255 Mdot
.24713 .47193 Mdot
.5877 .40539 Mdot
.75775 .37467 Mdot
.58552 .37699 Mdot
.35908 .35735 Mdot
.50034 .43863 Mdot
.61125 .55688 Mdot
.327 .24916 Mdot
.45318 .43611 Mdot
.71728 .59148 Mdot
.60365 .42033 Mdot
.61942 .39695 Mdot
.70654 .56676 Mdot
.3641 .36622 Mdot
.61232 .37304 Mdot
.77171 .60794 Mdot
.62497 .39922 Mdot
.36991 .56951 Mdot
.56778 .56929 Mdot
.3551 .30618 Mdot
.58222 .44769 Mdot
.34854 .39762 Mdot
.42341 .59774 Mdot
.37616 .60826 Mdot
.50417 .41923 Mdot
.39066 .60757 Mdot
.56509 .38741 Mdot
.55502 .56405 Mdot
.36825 .40384 Mdot
.66475 .38066 Mdot
.36911 .36353 Mdot
.54857 .18139 Mdot
.42422 .60824 Mdot
.23897 .57903 Mdot
.68724 .43459 Mdot
.39648 .58706 Mdot
.30012 .34957 Mdot
.50671 .37462 Mdot
.56293 .46307 Mdot
.30021 .32797 Mdot
.54834 .67884 Mdot
.25129 .58539 Mdot
.41202 .57873 Mdot
.62453 .40503 Mdot
.55582 .37741 Mdot
.3981 .55983 Mdot
.55477 .23027 Mdot
.64311 .6299 Mdot
.58204 .37938 Mdot
.36049 .35943 Mdot
.36603 .39045 Mdot
.6337 .39167 Mdot
.57725 .41108 Mdot
.5023 .69022 Mdot
.24707 .56741 Mdot
.26976 .57722 Mdot
.24128 .56674 Mdot
.54348 .64321 Mdot
.17212 .48652 Mdot
.41725 .61509 Mdot
.19168 .51166 Mdot
.36616 .74385 Mdot
.50689 .41319 Mdot
.54566 .67582 Mdot
.60929 .4007 Mdot
.53875 .40141 Mdot
.3973 .57594 Mdot
.22047 .36133 Mdot
.54904 .47481 Mdot
.35111 .34318 Mdot
.38134 .56068 Mdot
.66153 .35622 Mdot
.3305 .57173 Mdot
.69218 .55443 Mdot
.46329 .42695 Mdot
.41434 .56691 Mdot
.3498 .37114 Mdot
.40481 .56068 Mdot
.62099 .39912 Mdot
.58554 .45698 Mdot
.36602 .39944 Mdot
.70555 .59929 Mdot
.57124 .36594 Mdot
.59981 .3951 Mdot
.76873 .30915 Mdot
.2837 .49836 Mdot
.33704 .58984 Mdot
.54027 .41362 Mdot
.5397 .4589 Mdot
.71164 .59996 Mdot
.62473 .38986 Mdot
.57519 .44311 Mdot
.31681 .47409 Mdot
.43641 .61374 Mdot
.70167 .61487 Mdot
.39743 .21716 Mdot
.40136 .38797 Mdot
.42846 .808 Mdot
.26006 .56253 Mdot
.44195 .61008 Mdot
.51496 .5546 Mdot
.24646 .58216 Mdot
.38964 .74105 Mdot
.49066 .78894 Mdot
.24024 .57628 Mdot
.51768 .70827 Mdot
.55296 .32457 Mdot
.62123 .4339 Mdot
.59091 .39407 Mdot
.69467 .59451 Mdot
.39155 .39252 Mdot
.43237 .52315 Mdot
.56596 .64104 Mdot
.59362 .4137 Mdot
.40516 .34582 Mdot
.45823 .79574 Mdot
.25901 .57955 Mdot
.7101 .58922 Mdot
.72401 .57561 Mdot
.59029 .40568 Mdot
.28703 .44311 Mdot
.36493 .38072 Mdot
.57892 .42127 Mdot
.61205 .43526 Mdot
.53579 .65396 Mdot
.34763 .36629 Mdot
.49323 .66984 Mdot
.26685 .55915 Mdot
.69935 .76147 Mdot
.78096 .32375 Mdot
.38354 .58211 Mdot
.53863 .77914 Mdot
.35696 .57878 Mdot
.42391 .67015 Mdot
.24247 .57007 Mdot
.58599 .41897 Mdot
.41632 .37744 Mdot
.57797 .42445 Mdot
.615 .38021 Mdot
.60152 .37283 Mdot
.5182 .45592 Mdot
.67349 .26488 Mdot
.69542 .58387 Mdot
.53449 .45802 Mdot
.53754 .69904 Mdot
.47769 .80837 Mdot
.21213 .65804 Mdot
.612 .4163 Mdot
.59442 .40779 Mdot
.40473 .37596 Mdot
.53095 .43141 Mdot
.41372 .57351 Mdot
.39614 .39638 Mdot
.55985 .37605 Mdot
.58025 .72305 Mdot
.62871 .39403 Mdot
.56032 .78238 Mdot
.40335 .56006 Mdot
.46338 .42013 Mdot
.55931 .46692 Mdot
.23947 .57484 Mdot
.24914 .58518 Mdot
.23681 .56268 Mdot
.42356 .58141 Mdot
.53807 .65963 Mdot
.56505 .64795 Mdot
.64544 .36674 Mdot
.55672 .39124 Mdot
.56548 .46447 Mdot
.53255 .63415 Mdot
.56265 .55683 Mdot
.21917 .43031 Mdot
.59622 .3279 Mdot
.55122 .68432 Mdot
.37179 .33445 Mdot
.27016 .28876 Mdot
.3972 .39042 Mdot
.69051 .61471 Mdot
.36875 .57396 Mdot
.6943 .55243 Mdot
.63615 .2436 Mdot
.36242 .39916 Mdot
.33193 .36073 Mdot
.5259 .65285 Mdot
.41996 .50769 Mdot
.09039 .53451 Mdot
.50056 .648 Mdot
.78358 .56923 Mdot
.37542 .37837 Mdot
.52614 .40133 Mdot
.47291 .53837 Mdot
.4316 .50904 Mdot
.52391 .66278 Mdot
.59673 .43161 Mdot
.28656 .36761 Mdot
.49982 .68745 Mdot
.60823 .3549 Mdot
.52485 .64453 Mdot
.41089 .60886 Mdot
.51598 .64651 Mdot
.39531 .34902 Mdot
.53831 .3972 Mdot
.08967 .46983 Mdot
.32128 .55173 Mdot
.57156 .42931 Mdot
.37481 .56431 Mdot
.76465 .64825 Mdot
.61371 .38563 Mdot
.70354 .55478 Mdot
.55561 .67917 Mdot
.67929 .68138 Mdot
.56395 .41837 Mdot
.51417 .66122 Mdot
.35508 .33814 Mdot
.39958 .63772 Mdot
.33778 .63598 Mdot
.26421 .58154 Mdot
.39071 .38339 Mdot
.23801 .55511 Mdot
.42747 .62185 Mdot
.56302 .36598 Mdot
.61689 .42872 Mdot
.37513 .35358 Mdot
.32303 .66262 Mdot
.53937 .37832 Mdot
.59431 .43052 Mdot
.49199 .67395 Mdot
.56317 .66047 Mdot
.2531 .6626 Mdot
.51994 .69525 Mdot
.53929 .45902 Mdot
.3713 .3532 Mdot
.55885 .38264 Mdot
.38567 .3547 Mdot
.59042 .36425 Mdot
.36369 .31238 Mdot
.39576 .39082 Mdot
.26559 .36928 Mdot
.55337 .43686 Mdot
.67981 .42864 Mdot
.61538 .37907 Mdot
.59237 .3735 Mdot
.55637 .67452 Mdot
.69291 .56928 Mdot
.60605 .35148 Mdot
.51887 .56753 Mdot
.69004 .59811 Mdot
.56318 .30124 Mdot
.53941 .65621 Mdot
.68296 .58887 Mdot
.70997 .47402 Mdot
.27318 .56431 Mdot
.70206 .58079 Mdot
.25432 .69442 Mdot
.38596 .58058 Mdot
.37225 .40819 Mdot
.55687 .42433 Mdot
.63871 .80116 Mdot
.6428 .62593 Mdot
.25331 .57738 Mdot
.56823 .42221 Mdot
.60998 .39616 Mdot
.36912 .41627 Mdot
.38608 .17222 Mdot
.48406 .62771 Mdot
.57424 .37144 Mdot
.40037 .40445 Mdot
.46242 .15353 Mdot
.51677 .63999 Mdot
.70491 .58514 Mdot
.40097 .55727 Mdot
.42334 .41902 Mdot
.26037 .58411 Mdot
.42934 .60639 Mdot
.55432 .71603 Mdot
.62417 .22725 Mdot
.56693 .4128 Mdot
.54065 .6832 Mdot
.70425 .30002 Mdot
.65479 .40004 Mdot
.35337 .60362 Mdot
.45674 .37203 Mdot
.35627 .38627 Mdot
.39408 .55939 Mdot
.72011 .5881 Mdot
.36838 .40508 Mdot
.36247 .36657 Mdot
.36998 .60193 Mdot
.46784 .58111 Mdot
.46805 .5198 Mdot
.38068 .5634 Mdot
.35556 .47934 Mdot
.72124 .33953 Mdot
.24917 .5654 Mdot
.7115 .58859 Mdot
.78417 .37758 Mdot
.36426 .38373 Mdot
.32383 .77728 Mdot
.67635 .26965 Mdot
.59159 .37172 Mdot
.68002 .56658 Mdot
.39808 .75197 Mdot
.57828 .67693 Mdot
.3747 .5946 Mdot
.57682 .55282 Mdot
.71533 .56003 Mdot
.63014 .41219 Mdot
.3832 .31157 Mdot
.55917 .43801 Mdot
.38169 .60233 Mdot
.35763 .45239 Mdot
.34979 .36084 Mdot
.42942 .62132 Mdot
.39369 .45865 Mdot
.53699 .40638 Mdot
.58111 .44003 Mdot
.78519 .43152 Mdot
.34593 .3712 Mdot
.26247 .58372 Mdot
.58293 .43 Mdot
.5992 .38734 Mdot
.56312 .36373 Mdot
.6669 .4668 Mdot
.29026 .46482 Mdot
.5744 .37034 Mdot
.53323 .63927 Mdot
.56456 .4605 Mdot
.5761 .44101 Mdot
.37954 .41466 Mdot
.73452 .29258 Mdot
.26086 .5563 Mdot
.59118 .39096 Mdot
.58301 .38002 Mdot
.39974 .61789 Mdot
.47048 .52693 Mdot
.4217 .50496 Mdot
.48801 .64993 Mdot
.77837 .50809 Mdot
.61947 .46141 Mdot
.39493 .37148 Mdot
.68258 .55091 Mdot
.52773 .41285 Mdot
.40263 .37909 Mdot
.59962 .45815 Mdot
.50902 .69644 Mdot
.24795 .56869 Mdot
.54583 .4992 Mdot
.70289 .5761 Mdot
.4491 .574 Mdot
.20862 .5303 Mdot
.52059 .69755 Mdot
.54996 .40097 Mdot
.44303 .62885 Mdot
.49782 .67176 Mdot
.25923 .57613 Mdot
.61369 .33961 Mdot
.37837 .38609 Mdot
.35063 .36264 Mdot
.73499 .35805 Mdot
.49976 .62385 Mdot
.63391 .19425 Mdot
.40833 .60895 Mdot
.63873 .38468 Mdot
.21125 .56603 Mdot
.3543 .35528 Mdot
.78606 .40204 Mdot
.68589 .59166 Mdot
.37465 .59374 Mdot
.27345 .55454 Mdot
.40165 .37519 Mdot
.35085 .35179 Mdot
.59231 .36737 Mdot
.6078 .41334 Mdot
.79446 .53374 Mdot
.75428 .36863 Mdot
.41825 .60688 Mdot
.71263 .58131 Mdot
.48996 .63969 Mdot
.53864 .40816 Mdot
.38891 .40354 Mdot
.45864 .34462 Mdot
.62546 .4099 Mdot
.498 .68573 Mdot
.36135 .39287 Mdot
.71114 .57116 Mdot
.67448 .56902 Mdot
.59365 .37292 Mdot
.54889 .28963 Mdot
.39255 .58986 Mdot
.36728 .34961 Mdot
.32062 .39311 Mdot
.55802 .36011 Mdot
.60827 .41721 Mdot
.66399 .4322 Mdot
.4291 .60765 Mdot
.53037 .48825 Mdot
.72539 .56682 Mdot
.38193 .39228 Mdot
.57451 .42876 Mdot
.70659 .57694 Mdot
.61612 .4977 Mdot
.24349 .57654 Mdot
.52222 .64354 Mdot
.70831 .55814 Mdot
.69162 .56335 Mdot
.68205 .59369 Mdot
.31035 .76687 Mdot
.38537 .42169 Mdot
.39087 .21456 Mdot
.60224 .37038 Mdot
.72312 .35079 Mdot
.55141 .44511 Mdot
.43083 .59522 Mdot
.53777 .69256 Mdot
.61875 .38573 Mdot
.59264 .36699 Mdot
.39508 .31744 Mdot
.67048 .36854 Mdot
.417 .43645 Mdot
.34805 .38176 Mdot
.68121 .43265 Mdot
.54714 .66868 Mdot
.45876 .13924 Mdot
.3053 .78598 Mdot
.59386 .46949 Mdot
.44546 .52122 Mdot
.39464 .3979 Mdot
.38236 .60814 Mdot
.43931 .50644 Mdot
.4219 .5612 Mdot
.37953 .39541 Mdot
.54319 .39787 Mdot
.19612 .50822 Mdot
.68494 .6009 Mdot
.62159 .40832 Mdot
.41529 .60009 Mdot
.62221 .40686 Mdot
.42778 .58443 Mdot
.43844 .40419 Mdot
.36123 .4926 Mdot
.56114 .4092 Mdot
.54565 .37334 Mdot
.49684 .45692 Mdot
.6111 .41506 Mdot
.41259 .71875 Mdot
.37352 .36931 Mdot
.28345 .34396 Mdot
.63086 .38565 Mdot
.54378 .27438 Mdot
.62653 .41486 Mdot
.32744 .67163 Mdot
.60593 .43575 Mdot
.57513 .52468 Mdot
.6316 .41056 Mdot
.60305 .43436 Mdot
.40367 .57794 Mdot
.39362 .61572 Mdot
.35562 .33869 Mdot
.25006 .5874 Mdot
.48595 .81447 Mdot
.60024 .40208 Mdot
.55736 .66288 Mdot
.22162 .55673 Mdot
.69162 .56569 Mdot
.37585 .39326 Mdot
.54555 .13387 Mdot
.42371 .60259 Mdot
.4738 .64544 Mdot
.35726 .68044 Mdot
.49928 .62896 Mdot
.46094 .64239 Mdot
.6849 .41373 Mdot
.71489 .5806 Mdot
.62693 .41665 Mdot
.59012 .28578 Mdot
.26074 .48331 Mdot
.61066 .35768 Mdot
.40643 .63202 Mdot
.6531 .33851 Mdot
.72217 .33589 Mdot
.70609 .60805 Mdot
.71897 .57487 Mdot
.41056 .57949 Mdot
.48007 .6519 Mdot
.64411 .43882 Mdot
.68112 .58716 Mdot
.54111 .69403 Mdot
.23507 .58211 Mdot
.64694 .58363 Mdot
.36746 .3839 Mdot
.49692 .47318 Mdot
.2642 .52301 Mdot
.41982 .60514 Mdot
.51859 .56437 Mdot
.42666 .37941 Mdot
.34526 .40456 Mdot
.23791 .58137 Mdot
.55389 .6892 Mdot
.41414 .39598 Mdot
.56503 .36886 Mdot
.54561 .35122 Mdot
.58721 .40704 Mdot
.68126 .58337 Mdot
.6029 .44053 Mdot
.5446 .69621 Mdot
.39231 .60388 Mdot
.51232 .67658 Mdot
.38943 .59 Mdot
.19745 .48532 Mdot
.5747 .40995 Mdot
.60503 .41778 Mdot
.50779 .54379 Mdot
.34997 .3474 Mdot
.60041 .26491 Mdot
.55861 .68295 Mdot
.53371 .6648 Mdot
.5572 .38285 Mdot
.34879 .34037 Mdot
.6619 .57522 Mdot
.47267 .54717 Mdot
.6099 .43483 Mdot
.37492 .36932 Mdot
.5654 .38064 Mdot
.6175 .74052 Mdot
.33827 .5112 Mdot
.35367 .36131 Mdot
.31473 .25497 Mdot
.5477 .43022 Mdot
.60879 .31495 Mdot
.52238 .44955 Mdot
.75498 .54018 Mdot
.57634 .35072 Mdot
.40095 .39445 Mdot
.58598 .3992 Mdot
.39285 .37575 Mdot
.50294 .68395 Mdot
.40608 .61534 Mdot
.38823 .37999 Mdot
.56919 .44632 Mdot
.26145 .73752 Mdot
.41617 .60385 Mdot
.60463 .42606 Mdot
.39421 .5668 Mdot
.39474 .4076 Mdot
.34383 .35661 Mdot
.26405 .69704 Mdot
.33555 .57216 Mdot
.41862 .60148 Mdot
.56143 .38929 Mdot
.29749 .54372 Mdot
.55894 .38296 Mdot
.79748 .52493 Mdot
.62885 .37547 Mdot
.5815 .3547 Mdot
.16945 .53427 Mdot
.42702 .56227 Mdot
.59442 .16781 Mdot
.57473 .64969 Mdot
.29387 .75312 Mdot
.41519 .40922 Mdot
.70593 .60815 Mdot
.52355 .77431 Mdot
.2644 .5591 Mdot
.54286 .65052 Mdot
.61942 .38617 Mdot
.36148 .3102 Mdot
.38275 .56124 Mdot
.68936 .57347 Mdot
.56047 .41015 Mdot
.49741 .69018 Mdot
.23482 .67296 Mdot
.38072 .60401 Mdot
.36759 .38641 Mdot
.34976 .34584 Mdot
.41678 .18068 Mdot
.57227 .42664 Mdot
.60147 .41528 Mdot
.36661 .57574 Mdot
.63296 .44644 Mdot
.67233 .58448 Mdot
.66499 .71892 Mdot
.41822 .59574 Mdot
.31475 .55886 Mdot
.34999 .38824 Mdot
.61 .39817 Mdot
.57824 .57375 Mdot
.33666 .74685 Mdot
.42129 .2278 Mdot
.6966 .59386 Mdot
.78812 .47902 Mdot
.40109 .39412 Mdot
.41172 .59975 Mdot
.71239 .40941 Mdot
.633 .43281 Mdot
.60778 .39286 Mdot
.78682 .46937 Mdot
.467 .53147 Mdot
.68375 .53649 Mdot
.52097 .41292 Mdot
.48079 .52988 Mdot
.55485 .38424 Mdot
.55427 .37889 Mdot
.59814 .46915 Mdot
.5846 .4444 Mdot
.38232 .37127 Mdot
.37371 .3015 Mdot
.51145 .65437 Mdot
.51723 .20562 Mdot
.5838 .54571 Mdot
.56048 .43133 Mdot
.54046 .40088 Mdot
.32975 .28848 Mdot
.23991 .54566 Mdot
.37147 .37205 Mdot
.32799 .33576 Mdot
.42308 .61455 Mdot
.67303 .37653 Mdot
.51499 .62675 Mdot
.46447 .39796 Mdot
.50219 .67217 Mdot
.37578 .36867 Mdot
.53874 .6653 Mdot
.42178 .61759 Mdot
.53981 .68355 Mdot
.54154 .64207 Mdot
.42207 .56919 Mdot
.3448 .38105 Mdot
.61268 .4286 Mdot
.42297 .60822 Mdot
.78962 .44068 Mdot
.68044 .58226 Mdot
.26224 .69628 Mdot
.52082 .42339 Mdot
.52782 .33128 Mdot
.74856 .64578 Mdot
.52598 .67852 Mdot
.32577 .50565 Mdot
.39565 .39063 Mdot
.67212 .55425 Mdot
.38725 .37313 Mdot
.64267 .25562 Mdot
.70282 .56633 Mdot
.26188 .69806 Mdot
.70796 .42796 Mdot
.58625 .60392 Mdot
.58934 .45249 Mdot
.37187 .31884 Mdot
.50278 .67567 Mdot
.36814 .57095 Mdot
.42728 .77144 Mdot
.54247 .43596 Mdot
.25692 .44036 Mdot
.37062 .4207 Mdot
.27324 .56896 Mdot
.40656 .6009 Mdot
.40014 .6297 Mdot
.5719 .42233 Mdot
.58074 .59207 Mdot
.60534 .35845 Mdot
.70141 .39937 Mdot
.78793 .50618 Mdot
.45822 .3838 Mdot
.56838 .38307 Mdot
.48943 .65888 Mdot
.56417 .38275 Mdot
.56097 .32759 Mdot
.71531 .3225 Mdot
.52406 .4293 Mdot
.25131 .39401 Mdot
.69878 .66981 Mdot
.37158 .40187 Mdot
.54186 .46268 Mdot
.25605 .57103 Mdot
.54171 .42144 Mdot
.73442 .76447 Mdot
.69924 .57859 Mdot
.57104 .70499 Mdot
.57424 .44896 Mdot
.58023 .4277 Mdot
.51466 .31732 Mdot
.42507 .35078 Mdot
.27163 .55517 Mdot
.60669 .38761 Mdot
.77238 .4791 Mdot
.40357 .57365 Mdot
.63758 .39591 Mdot
.58908 .39871 Mdot
.80488 .41567 Mdot
.39821 .57015 Mdot
.53367 .67928 Mdot
.27211 .56273 Mdot
.49206 .63995 Mdot
.70781 .61024 Mdot
.41648 .49534 Mdot
.77277 .38335 Mdot
.33644 .51348 Mdot
.70542 .55399 Mdot
.60202 .44621 Mdot
.59782 .30939 Mdot
.58204 .4364 Mdot
.71934 .57998 Mdot
.40682 .56943 Mdot
.38181 .3737 Mdot
.52921 .49838 Mdot
.26481 .57146 Mdot
.59849 .3543 Mdot
.70826 .60583 Mdot
.38315 .38316 Mdot
.27895 .68683 Mdot
.38658 .39645 Mdot
.39961 .58463 Mdot
.43118 .61167 Mdot
.70015 .56871 Mdot
.38516 .37151 Mdot
.51556 .63653 Mdot
.56703 .64001 Mdot
.62342 .36967 Mdot
.34815 .60824 Mdot
.39931 .35504 Mdot
.33488 .35596 Mdot
.41232 .37686 Mdot
.57119 .41108 Mdot
.46059 .52515 Mdot
.63332 .43534 Mdot
.42245 .5918 Mdot
.53784 .65007 Mdot
.7476 .36273 Mdot
.58562 .28238 Mdot
.32239 .54801 Mdot
.59953 .35124 Mdot
.58283 .44195 Mdot
.59033 .40597 Mdot
.57752 .3817 Mdot
.64625 .7324 Mdot
.57621 .40877 Mdot
.39347 .58224 Mdot
.49977 .65865 Mdot
.56827 .42559 Mdot
.25447 .56869 Mdot
.5071 .52113 Mdot
.68538 .5505 Mdot
.57806 .52745 Mdot
.30554 .77786 Mdot
.38232 .3819 Mdot
.52537 .68958 Mdot
.52969 .64301 Mdot
.673 .5772 Mdot
.40626 .61005 Mdot
.38993 .39293 Mdot
.73206 .52185 Mdot
.69361 .60046 Mdot
.59121 .39006 Mdot
.53768 .55843 Mdot
.29493 .26888 Mdot
.60988 .44539 Mdot
.60265 .3755 Mdot
.27632 .57058 Mdot
.48768 .62912 Mdot
.62683 .82279 Mdot
.44565 .53712 Mdot
.69513 .56904 Mdot
.70669 .56182 Mdot
.4124 .38706 Mdot
.63056 .36566 Mdot
.39042 .59456 Mdot
.47811 .54064 Mdot
.77834 .62986 Mdot
.42511 .78545 Mdot
.41126 .66928 Mdot
.62655 .38962 Mdot
.46547 .32335 Mdot
.59672 .36173 Mdot
.36179 .41468 Mdot
.40947 .38099 Mdot
.36883 .37583 Mdot
.40528 .57938 Mdot
.55484 .18508 Mdot
.39076 .58385 Mdot
.30773 .78097 Mdot
.38929 .40544 Mdot
.60795 .63641 Mdot
.53343 .65835 Mdot
.64173 .36408 Mdot
.71409 .58326 Mdot
.36749 .63277 Mdot
.55026 .46736 Mdot
.28072 .44115 Mdot
.54543 .67601 Mdot
.34198 .36357 Mdot
.54609 .33936 Mdot
.5114 .82024 Mdot
.39591 .49962 Mdot
.72386 .63006 Mdot
.63598 .26299 Mdot
.70631 .56722 Mdot
.38368 .24338 Mdot
.67918 .59453 Mdot
.37625 .59788 Mdot
.54379 .4372 Mdot
.55911 .44306 Mdot
.57728 .37257 Mdot
.57574 .40569 Mdot
.41133 .57717 Mdot
.6205 .37495 Mdot
.75568 .33044 Mdot
.25314 .56053 Mdot
.60209 .67345 Mdot
.68109 .5584 Mdot
.43105 .58447 Mdot
.49778 .6648 Mdot
.2447 .58739 Mdot
.81588 .48299 Mdot
.62126 .37834 Mdot
.61746 .38204 Mdot
.23876 .56686 Mdot
.62773 .44879 Mdot
.53487 .34876 Mdot
.51072 .65811 Mdot
.42372 .47107 Mdot
.72292 .58004 Mdot
.69434 .55268 Mdot
.41086 .56419 Mdot
.38725 .37282 Mdot
.69301 .59502 Mdot
.48229 .65896 Mdot
.63434 .41151 Mdot
.53999 .38305 Mdot
.39754 .35362 Mdot
.67645 .26962 Mdot
.68749 .60637 Mdot
.5038 .37593 Mdot
.39841 .38051 Mdot
.37427 .42126 Mdot
.60899 .38866 Mdot
.56433 .35005 Mdot
.33684 .37198 Mdot
.67971 .55708 Mdot
.42963 .58043 Mdot
.60336 .6178 Mdot
.38858 .60447 Mdot
.38944 .38747 Mdot
.6158 .45006 Mdot
.34652 .38376 Mdot
.54723 .4279 Mdot
.30741 .18854 Mdot
.59294 .44358 Mdot
.299 .33774 Mdot
.7618 .54308 Mdot
.5206 .64119 Mdot
.50778 .63721 Mdot
.25066 .56821 Mdot
.40018 .38718 Mdot
.52871 .41176 Mdot
.713 .56753 Mdot
.27745 .73633 Mdot
.32919 .39762 Mdot
.55271 .6764 Mdot
.50165 .62645 Mdot
.41008 .57293 Mdot
.62299 .42241 Mdot
.60756 .40118 Mdot
.53893 .68293 Mdot
.74024 .66318 Mdot
.39017 .36633 Mdot
.60113 .41555 Mdot
.57694 .44188 Mdot
.50871 .65313 Mdot
.56924 .64049 Mdot
.42288 .35389 Mdot
.58367 .44401 Mdot
.70667 .43962 Mdot
.42807 .58892 Mdot
.56838 .39285 Mdot
.61456 .37118 Mdot
.68483 .56813 Mdot
.59869 .7003 Mdot
.71955 .33191 Mdot
.43471 .60055 Mdot
.26673 .58051 Mdot
.54791 .44197 Mdot
.53065 .65736 Mdot
.52683 .40056 Mdot
.59683 .78743 Mdot
.2606 .56001 Mdot
.58116 .41618 Mdot
.60884 .46397 Mdot
.36868 .34764 Mdot
.58017 .41971 Mdot
.42551 .33921 Mdot
.49266 .64812 Mdot
.57981 .41617 Mdot
.55499 .28474 Mdot
.41308 .57608 Mdot
.54928 .46589 Mdot
.71011 .56123 Mdot
.75874 .54889 Mdot
.22582 .52783 Mdot
.54999 .64711 Mdot
.67617 .5656 Mdot
.60564 .43938 Mdot
.48877 .66852 Mdot
.39915 .55687 Mdot
.26432 .43246 Mdot
.61963 .43811 Mdot
.39999 .60737 Mdot
.398 .60457 Mdot
.69884 .57182 Mdot
.54081 .1459 Mdot
.61441 .46252 Mdot
.61254 .41974 Mdot
.82807 .55895 Mdot
.4046 .40712 Mdot
.61364 .42159 Mdot
.62027 .42515 Mdot
.38155 .59241 Mdot
.6822 .45773 Mdot
.33747 .42449 Mdot
.69988 .693 Mdot
.42858 .58631 Mdot
.5545 .69885 Mdot
.49281 .67288 Mdot
.67876 .56139 Mdot
.36994 .39991 Mdot
.7152 .55793 Mdot
.51975 .65025 Mdot
.59074 .3734 Mdot
.37279 .5862 Mdot
.46602 .23316 Mdot
.36138 .57853 Mdot
.49185 .68119 Mdot
.34125 .38871 Mdot
.20755 .56832 Mdot
.85786 .55465 Mdot
.25483 .51545 Mdot
.43506 .58928 Mdot
.69112 .56572 Mdot
.45592 .54986 Mdot
.5834 .44158 Mdot
.38738 .23024 Mdot
.61828 .41472 Mdot
.64129 .26433 Mdot
.53969 .69266 Mdot
.23588 .57783 Mdot
.54172 .436 Mdot
.7844 .48002 Mdot
.43433 .59035 Mdot
.41535 .57614 Mdot
.58455 .38606 Mdot
.39714 .58555 Mdot
.60536 .40749 Mdot
.50335 .65142 Mdot
.55429 .15281 Mdot
.59603 .43793 Mdot
.53406 .44813 Mdot
.43808 .61264 Mdot
.26158 .6964 Mdot
.54844 .70027 Mdot
.47396 .32512 Mdot
.52906 .82237 Mdot
.39642 .58868 Mdot
.51586 .44221 Mdot
.52474 .68268 Mdot
.2759 .57287 Mdot
.47453 .66867 Mdot
.6191 .40503 Mdot
.61738 .37808 Mdot
.56402 .37662 Mdot
.57842 .44018 Mdot
.3707 .24245 Mdot
.58563 .33115 Mdot
.45086 .29618 Mdot
.61429 .37901 Mdot
.31484 .33246 Mdot
.39561 .57842 Mdot
.42462 .42927 Mdot
.70148 .53935 Mdot
.61602 .37573 Mdot
.41946 .3443 Mdot
.43218 .58935 Mdot
.32644 .78891 Mdot
.40403 .57097 Mdot
.51791 .67423 Mdot
.37608 .60446 Mdot
.54949 .42831 Mdot
.36429 .38888 Mdot
.4953 .65189 Mdot
.2149 .44378 Mdot
.54696 .6554 Mdot
.57139 .42889 Mdot
.58754 .64578 Mdot
.52375 .64211 Mdot
.53289 .52392 Mdot
.36567 .39234 Mdot
.76604 .46368 Mdot
.3994 .41028 Mdot
.58542 .42176 Mdot
.59016 .42486 Mdot
.24663 .58858 Mdot
.38144 .60467 Mdot
.39514 .40602 Mdot
.76537 .30492 Mdot
.72144 .59949 Mdot
.36185 .37338 Mdot
.57999 .3457 Mdot
.45528 .52844 Mdot
.36375 .35133 Mdot
.76069 .50453 Mdot
.38289 .60399 Mdot
.415 .38897 Mdot
.61857 .34389 Mdot
.60544 .51143 Mdot
.66815 .5803 Mdot
.51246 .69866 Mdot
.48379 .5048 Mdot
.49153 .66649 Mdot
.43084 .6228 Mdot
.47639 .62711 Mdot
.39973 .57383 Mdot
.30113 .32435 Mdot
.36051 .45179 Mdot
.44862 .61774 Mdot
.43013 .61721 Mdot
.52072 .65654 Mdot
.57948 .38103 Mdot
.605 .56288 Mdot
.59226 .3453 Mdot
.58829 .45575 Mdot
.42834 .59871 Mdot
.40322 .39463 Mdot
.35629 .39947 Mdot
.36305 .32014 Mdot
.3468 .35235 Mdot
.49501 .66208 Mdot
.3368 .50164 Mdot
.62912 .24794 Mdot
.39175 .56468 Mdot
.37312 .54794 Mdot
.55438 .38697 Mdot
.52669 .65617 Mdot
.50666 .68895 Mdot
.38737 .59776 Mdot
.45604 .2114 Mdot
.55193 .46206 Mdot
.38071 .41615 Mdot
.38818 .40583 Mdot
.36348 .35309 Mdot
.39607 .35715 Mdot
.51008 .17681 Mdot
.36792 .57112 Mdot
.39874 .39473 Mdot
.58042 .39669 Mdot
.62525 .39307 Mdot
.26685 .57709 Mdot
.69198 .55628 Mdot
.54693 .44786 Mdot
.54583 .45189 Mdot
.61011 .39036 Mdot
.52351 .64316 Mdot
.6623 .38468 Mdot
.26355 .56227 Mdot
.48217 .62664 Mdot
.52636 .6314 Mdot
.23986 .58055 Mdot
.36066 .42795 Mdot
.50027 .831 Mdot
.57374 .37181 Mdot
.67425 .345 Mdot
.52861 .66086 Mdot
.32566 .45198 Mdot
.52888 .48422 Mdot
.56584 .38777 Mdot
.6319 .54421 Mdot
.50042 .65011 Mdot
.34895 .41267 Mdot
.61519 .41282 Mdot
.24245 .56739 Mdot
.67863 .55389 Mdot
.61216 .34364 Mdot
.27702 .5692 Mdot
.37663 .36715 Mdot
.70632 .65272 Mdot
.41139 .40064 Mdot
.51958 .63917 Mdot
.54521 .46503 Mdot
.08357 .51707 Mdot
.50341 .67744 Mdot
.35211 .77976 Mdot
.37713 .45782 Mdot
.59269 .44034 Mdot
.49357 .67 Mdot
.34951 .41147 Mdot
.4281 .58999 Mdot
.4966 .52979 Mdot
.38743 .40366 Mdot
.24121 .58578 Mdot
.25685 .58372 Mdot
.51024 .65449 Mdot
.35188 .38465 Mdot
.62816 .37823 Mdot
.39341 .35956 Mdot
.37037 .60047 Mdot
.55365 .41088 Mdot
.48818 .81573 Mdot
.54363 .35251 Mdot
.39962 .38006 Mdot
.48335 .66661 Mdot
.70979 .59962 Mdot
.5625 .40861 Mdot
.41115 .80316 Mdot
.62103 .42576 Mdot
.39972 .56696 Mdot
.30599 .42618 Mdot
.4494 .23836 Mdot
.58451 .37766 Mdot
.54661 .39302 Mdot
.41244 .56389 Mdot
.58526 .37586 Mdot
.61445 .44023 Mdot
.35855 .61156 Mdot
.35934 .34918 Mdot
.58802 .41086 Mdot
.51505 .69717 Mdot
.65026 .28674 Mdot
.53604 .43484 Mdot
.2402 .38976 Mdot
.77497 .47097 Mdot
.31004 .42253 Mdot
.52652 .42054 Mdot
.79279 .43783 Mdot
.59559 .42459 Mdot
.56895 .40635 Mdot
.57174 .37592 Mdot
.44594 .32058 Mdot
.52182 .65324 Mdot
.55153 .68655 Mdot
.66611 .56757 Mdot
.77685 .47811 Mdot
.67995 .57007 Mdot
.42277 .57257 Mdot
.3191 .63835 Mdot
.25435 .56102 Mdot
.38938 .37399 Mdot
.54249 .39111 Mdot
.54232 .64708 Mdot
.6127 .39963 Mdot
.54217 .41875 Mdot
.50641 .64552 Mdot
.49686 .67462 Mdot
.49355 .62232 Mdot
.68842 .60041 Mdot
.37694 .37611 Mdot
.58921 .36919 Mdot
.69147 .59862 Mdot
.63383 .38722 Mdot
.45722 .53538 Mdot
.37423 .37462 Mdot
.39085 .35728 Mdot
.36932 .41059 Mdot
.6041 .37081 Mdot
.55269 .42851 Mdot
.38952 .58498 Mdot
.40238 .35684 Mdot
.38804 .56325 Mdot
.49313 .6675 Mdot
.51049 .63854 Mdot
.61943 .40458 Mdot
.52243 .35482 Mdot
.70196 .56073 Mdot
.52276 .67602 Mdot
.24409 .55833 Mdot
.66687 .56527 Mdot
.56817 .42133 Mdot
.49212 .66404 Mdot
.69715 .55301 Mdot
.50677 .21386 Mdot
.56454 .82348 Mdot
.7065 .60297 Mdot
.58481 .387 Mdot
.53291 .30634 Mdot
.72038 .39724 Mdot
.725 .5938 Mdot
.383 .56924 Mdot
.62286 .41871 Mdot
.75253 .66501 Mdot
.72279 .56982 Mdot
.68185 .27553 Mdot
.51145 .64434 Mdot
.69106 .41924 Mdot
.60779 .3415 Mdot
.43449 .20351 Mdot
.71997 .56303 Mdot
.38672 .39185 Mdot
.41695 .3705 Mdot
.58967 .3862 Mdot
.72952 .56819 Mdot
.36586 .60043 Mdot
.5282 .64161 Mdot
.54895 .65008 Mdot
.35049 .37963 Mdot
.33113 .52977 Mdot
.50689 .69241 Mdot
.54804 .47052 Mdot
.50381 .70322 Mdot
.67732 .41296 Mdot
.4423 .18002 Mdot
.20508 .45889 Mdot
.54669 .3767 Mdot
.71417 .59894 Mdot
.41208 .55848 Mdot
.39205 .5853 Mdot
.40566 .58236 Mdot
.49987 .63869 Mdot
.45872 .51082 Mdot
.54336 .68381 Mdot
.25942 .45363 Mdot
.707 .57791 Mdot
.753 .45692 Mdot
.52883 .41923 Mdot
.58998 .44048 Mdot
.63664 .40465 Mdot
.56255 .37669 Mdot
.59662 .42345 Mdot
.41823 .60588 Mdot
.50162 .63211 Mdot
.68357 .68393 Mdot
.36376 .35774 Mdot
.27236 .66228 Mdot
.53395 .65862 Mdot
.27508 .56541 Mdot
.69245 .58279 Mdot
.77059 .38759 Mdot
.56448 .6925 Mdot
.53796 .66524 Mdot
.62575 .43246 Mdot
.40658 .38751 Mdot
.65817 .47786 Mdot
.59461 .43058 Mdot
.52431 .6769 Mdot
.4767 .65758 Mdot
.39704 .24161 Mdot
.61712 .47064 Mdot
.66591 .59166 Mdot
.4533 .52603 Mdot
.72055 .56007 Mdot
.55294 .35528 Mdot
.32497 .45386 Mdot
.51861 .6517 Mdot
.5122 .67017 Mdot
.71465 .60243 Mdot
.57786 .317 Mdot
.35897 .39287 Mdot
.2355 .57615 Mdot
.38664 .57082 Mdot
.58809 .4337 Mdot
.4954 .64144 Mdot
.66475 .34033 Mdot
.53179 .5582 Mdot
.41552 .59109 Mdot
.48354 .62694 Mdot
.62745 .41195 Mdot
.58843 .38188 Mdot
.70334 .56501 Mdot
.6272 .60789 Mdot
.59607 .343 Mdot
.29485 .75398 Mdot
.37048 .4876 Mdot
.45108 .43972 Mdot
.60761 .39321 Mdot
.34731 .36919 Mdot
.24166 .57075 Mdot
.71153 .58946 Mdot
.63399 .39602 Mdot
.53927 .83071 Mdot
.3954 .34557 Mdot
.41298 .60349 Mdot
.24045 .57085 Mdot
.46574 .51194 Mdot
.61999 .42764 Mdot
.6181 .41472 Mdot
.57333 .40863 Mdot
.5571 .83477 Mdot
.54432 .69211 Mdot
.40889 .36866 Mdot
.69426 .59308 Mdot
.36477 .34476 Mdot
.55407 .68001 Mdot
.49376 .4899 Mdot
.56577 .42421 Mdot
.37134 .41502 Mdot
.38497 .39421 Mdot
.41077 .57306 Mdot
.43027 .60525 Mdot
.56408 .65416 Mdot
.59639 .44205 Mdot
.24551 .5634 Mdot
.40805 .39564 Mdot
.48318 .63367 Mdot
.70431 .5668 Mdot
.42415 .61097 Mdot
.61215 .3769 Mdot
.51416 .65429 Mdot
.58555 .35792 Mdot
.38362 .35489 Mdot
.53713 .66408 Mdot
.27652 .56201 Mdot
.70085 .55911 Mdot
.6146 .37674 Mdot
.72473 .6525 Mdot
.23784 .57434 Mdot
.56127 .44067 Mdot
.54629 .31214 Mdot
.72422 .55153 Mdot
.21539 .43831 Mdot
.53133 .69222 Mdot
.26008 .56575 Mdot
.41015 .37808 Mdot
.61813 .50449 Mdot
.50705 .66868 Mdot
.46841 .35589 Mdot
.61213 .58117 Mdot
.58587 .37128 Mdot
.35702 .37642 Mdot
.655 .55154 Mdot
.32566 .78149 Mdot
.71936 .42049 Mdot
.59728 .41361 Mdot
.49147 .6674 Mdot
.69229 .55207 Mdot
.39824 .56401 Mdot
.24147 .3894 Mdot
.43741 .18519 Mdot
.4923 .62529 Mdot
.58121 .36653 Mdot
.40802 .39439 Mdot
.39002 .59924 Mdot
.19247 .50191 Mdot
.48353 .66266 Mdot
.52888 .69642 Mdot
.56513 .41558 Mdot
.70048 .59545 Mdot
.72596 .68244 Mdot
.54766 .69164 Mdot
.49371 .63754 Mdot
.26481 .66527 Mdot
.69157 .60663 Mdot
.5829 .39551 Mdot
.36314 .32007 Mdot
.63182 .41652 Mdot
.30523 .75442 Mdot
.25771 .5635 Mdot
.36726 .35705 Mdot
.62424 .4029 Mdot
.69513 .67229 Mdot
.50107 .66953 Mdot
.44503 .5202 Mdot
.47938 .61355 Mdot
.41352 .60971 Mdot
.49615 .64245 Mdot
.61331 .40812 Mdot
.43599 .60859 Mdot
.6988 .55997 Mdot
.58432 .4441 Mdot
.55019 .42634 Mdot
.35328 .41227 Mdot
.36974 .59108 Mdot
.66471 .30649 Mdot
.38712 .61645 Mdot
.40442 .56077 Mdot
.38595 .42306 Mdot
.59054 .38777 Mdot
.52793 .67336 Mdot
.50473 .69602 Mdot
.6194 .37221 Mdot
.33057 .4551 Mdot
.35635 .38812 Mdot
.56458 .71522 Mdot
.62715 .82006 Mdot
.62478 .46033 Mdot
.2512 .55665 Mdot
.69231 .33819 Mdot
.42057 .57963 Mdot
.59497 .37538 Mdot
.39388 .37305 Mdot
.49145 .6342 Mdot
.50642 .69314 Mdot
.63307 .42488 Mdot
.3886 .6016 Mdot
.69137 .54983 Mdot
.51689 .69358 Mdot
.52493 .55697 Mdot
.5766 .41844 Mdot
.2554 .43804 Mdot
.52004 .69182 Mdot
.21442 .67746 Mdot
.68915 .67721 Mdot
.35396 .36369 Mdot
.54152 .40966 Mdot
.35191 .34161 Mdot
.68935 .58988 Mdot
.46958 .65976 Mdot
.38765 .6023 Mdot
.48266 .41532 Mdot
.80118 .38578 Mdot
.52583 .65251 Mdot
.38043 .37079 Mdot
.59747 .37061 Mdot
.48981 .42669 Mdot
.60763 .43523 Mdot
.66916 .48388 Mdot
.74428 .61396 Mdot
.42654 .61664 Mdot
.40763 .5669 Mdot
.53743 .40559 Mdot
.67859 .59244 Mdot
.53181 .70285 Mdot
.50945 .64566 Mdot
.4559 .13456 Mdot
.2784 .56369 Mdot
.78832 .54762 Mdot
.6074 .37282 Mdot
.49125 .63053 Mdot
.592 .28116 Mdot
.36696 .5754 Mdot
.62622 .36663 Mdot
.51873 .63198 Mdot
.32524 .73236 Mdot
.46212 .53454 Mdot
.58592 .41578 Mdot
.63535 .44462 Mdot
.39276 .56771 Mdot
.4539 .54652 Mdot
.54292 .68283 Mdot
.63437 .38095 Mdot
.3987 .62402 Mdot
.25462 .6773 Mdot
.78652 .35772 Mdot
.37641 .37617 Mdot
.4816 .66472 Mdot
.41475 .60884 Mdot
.66294 .41199 Mdot
.68218 .55728 Mdot
.48712 .6451 Mdot
.53854 .64829 Mdot
.55017 .40784 Mdot
.54068 .44367 Mdot
.61673 .46641 Mdot
.36538 .36615 Mdot
.38465 .58423 Mdot
.53347 .42287 Mdot
.34966 .51218 Mdot
.56986 .3712 Mdot
.38383 .58781 Mdot
.12916 .37917 Mdot
.61535 .44467 Mdot
.6115 .42611 Mdot
.68945 .52294 Mdot
.36222 .40126 Mdot
.35508 .34725 Mdot
.34891 .49926 Mdot
.60825 .37313 Mdot
.59438 .60406 Mdot
.38043 .37706 Mdot
.35718 .38706 Mdot
.60309 .63943 Mdot
.55633 .40505 Mdot
.44719 .56802 Mdot
.38872 .59475 Mdot
.4183 .60902 Mdot
.37377 .34895 Mdot
.64035 .3626 Mdot
.40343 .55716 Mdot
.34904 .25382 Mdot
.53723 .65895 Mdot
.32432 .45356 Mdot
.39824 .36718 Mdot
.59859 .58655 Mdot
.3796 .60164 Mdot
.26876 .75999 Mdot
.60716 .51746 Mdot
.6044 .36033 Mdot
.5857 .38063 Mdot
.68621 .5647 Mdot
.50272 .41241 Mdot
.26862 .57877 Mdot
.39831 .58391 Mdot
.59591 .75206 Mdot
.36795 .37599 Mdot
.60896 .42967 Mdot
.74934 .3682 Mdot
.20861 .49821 Mdot
.25799 .38988 Mdot
.37505 .40242 Mdot
.36248 .38059 Mdot
.54775 .67227 Mdot
.53442 .65064 Mdot
.58309 .40366 Mdot
.4018 .57881 Mdot
.419 .38419 Mdot
.3805 .58033 Mdot
.51881 .6504 Mdot
.53506 .66641 Mdot
.2648 .56119 Mdot
.65081 .39673 Mdot
.51233 .64123 Mdot
.27062 .69053 Mdot
.35403 .50963 Mdot
.3381 .39977 Mdot
.85409 .55289 Mdot
.18863 .50287 Mdot
.72241 .53058 Mdot
.67469 .55637 Mdot
.28106 .57859 Mdot
.388 .61221 Mdot
.54019 .40014 Mdot
.6187 .39205 Mdot
.25799 .58007 Mdot
.40006 .61124 Mdot
.68771 .5778 Mdot
.38053 .60439 Mdot
.70921 .5877 Mdot
.55713 .68352 Mdot
.53803 .4366 Mdot
.61436 .43554 Mdot
.42022 .59834 Mdot
.53666 .67926 Mdot
.52029 .63997 Mdot
.66827 .56676 Mdot
.77096 .3961 Mdot
.51113 .6533 Mdot
.39775 .36598 Mdot
.58606 .24273 Mdot
.25684 .58324 Mdot
.61431 .41379 Mdot
.76169 .37517 Mdot
.40353 .23185 Mdot
.5839 .36989 Mdot
.23974 .57134 Mdot
.47627 .13197 Mdot
.54337 .43849 Mdot
.44667 .1555 Mdot
.26491 .56562 Mdot
.34829 .3891 Mdot
.52245 .6845 Mdot
.26484 .58271 Mdot
.66231 .39358 Mdot
.68136 .6127 Mdot
.52451 .429 Mdot
.38254 .40533 Mdot
.35511 .40428 Mdot
.38448 .46411 Mdot
.31015 .75706 Mdot
.71216 .59474 Mdot
.6924 .57502 Mdot
.50574 .66601 Mdot
.31316 .6 Mdot
.55281 .36075 Mdot
.69146 .5722 Mdot
.63382 .75084 Mdot
.55636 .38618 Mdot
.7979 .51271 Mdot
.63006 .54341 Mdot
.34798 .37208 Mdot
.37724 .43722 Mdot
.50338 .66843 Mdot
.37996 .37109 Mdot
.46565 .45916 Mdot
.63644 .40433 Mdot
.37161 .37461 Mdot
.38146 .58922 Mdot
.40842 .74159 Mdot
.34416 .35133 Mdot
.50027 .53541 Mdot
.39155 .595 Mdot
.72388 .55216 Mdot
.71587 .48237 Mdot
.71427 .79255 Mdot
.39901 .58227 Mdot
.52413 .68065 Mdot
.51404 .6401 Mdot
.50637 .65253 Mdot
.38689 .40422 Mdot
.50192 .68209 Mdot
.37013 .36057 Mdot
.57483 .65868 Mdot
.78885 .41997 Mdot
.70256 .56972 Mdot
.33655 .5839 Mdot
.37621 .39082 Mdot
.28735 .48282 Mdot
.85219 .51715 Mdot
.58235 .38925 Mdot
.39537 .62097 Mdot
.71745 .59803 Mdot
.25846 .60497 Mdot
.68403 .56867 Mdot
.52541 .68322 Mdot
.32267 .45298 Mdot
.60432 .40773 Mdot
.43562 .34554 Mdot
.71392 .56638 Mdot
.38127 .40387 Mdot
.56939 .44198 Mdot
.55619 .64249 Mdot
.67666 .56823 Mdot
.67887 .55428 Mdot
.5996 .42318 Mdot
.34313 .36717 Mdot
.53382 .67072 Mdot
.4002 .61703 Mdot
.67565 .53997 Mdot
.65311 .38082 Mdot
.57964 .37885 Mdot
.64072 .38884 Mdot
.41985 .50636 Mdot
.73751 .67702 Mdot
.39633 .5904 Mdot
.72475 .38141 Mdot
.52398 .64574 Mdot
.71381 .43041 Mdot
.29012 .50916 Mdot
.34072 .59219 Mdot
.25903 .56332 Mdot
.25585 .56291 Mdot
.59028 .41809 Mdot
.71453 .70452 Mdot
.28055 .35113 Mdot
.35794 .60224 Mdot
.24762 .58315 Mdot
.52112 .64025 Mdot
.40219 .35344 Mdot
.43713 .42551 Mdot
.55826 .44955 Mdot
.42946 .60691 Mdot
.51348 .64924 Mdot
.5999 .78719 Mdot
.70523 .57851 Mdot
.32704 .49025 Mdot
.56771 .4274 Mdot
.60379 .416 Mdot
.40409 .59806 Mdot
.38978 .58554 Mdot
.24372 .4154 Mdot
.38733 .47224 Mdot
.4446 .78617 Mdot
.44349 .56523 Mdot
.62737 .7804 Mdot
.43023 .37607 Mdot
.39769 .37606 Mdot
.26896 .56077 Mdot
.41141 .56118 Mdot
.61714 .41871 Mdot
.3505 .39307 Mdot
.26083 .38708 Mdot
.38721 .42531 Mdot
.79331 .50462 Mdot
.60064 .60471 Mdot
.57041 .43481 Mdot
.40698 .38351 Mdot
.37767 .37172 Mdot
.37395 .34491 Mdot
.24015 .57967 Mdot
.60631 .38965 Mdot
.57888 .38197 Mdot
.54433 .4367 Mdot
.49124 .40699 Mdot
.57901 .41994 Mdot
.2962 .51875 Mdot
.31553 .55901 Mdot
.59566 .72878 Mdot
.58845 .36631 Mdot
.39643 .60878 Mdot
.54513 .38732 Mdot
.67378 .58551 Mdot
.58416 .36499 Mdot
.79765 .53625 Mdot
.40808 .58837 Mdot
.56061 .32237 Mdot
.4986 .70479 Mdot
.56635 .42777 Mdot
.70512 .55431 Mdot
.73329 .68084 Mdot
.74776 .35071 Mdot
.26617 .67014 Mdot
.39711 .36482 Mdot
.56255 .65777 Mdot
.36231 .59216 Mdot
.52621 .67255 Mdot
.6201 .36604 Mdot
.25317 .55733 Mdot
.16631 .50737 Mdot
.5838 .5706 Mdot
.62021 .4151 Mdot
.61274 .33604 Mdot
.35127 .35948 Mdot
.50043 .6726 Mdot
.43201 .40436 Mdot
.57036 .40755 Mdot
.68836 .5913 Mdot
.68763 .59379 Mdot
.43134 .45014 Mdot
.55607 .77601 Mdot
.6376 .49778 Mdot
.40188 .59656 Mdot
.50273 .6905 Mdot
.71988 .56348 Mdot
.30152 .32786 Mdot
.36203 .59695 Mdot
.42071 .57995 Mdot
.37034 .58915 Mdot
.57713 .43626 Mdot
.27045 .56591 Mdot
.59644 .76858 Mdot
.24666 .58749 Mdot
.56313 .42923 Mdot
.54332 .65472 Mdot
.26594 .58247 Mdot
.68222 .56641 Mdot
.41123 .56487 Mdot
.5287 .64909 Mdot
.58664 .42409 Mdot
.37949 .38111 Mdot
.73435 .36492 Mdot
.77603 .60188 Mdot
.58453 .68887 Mdot
.58628 .68428 Mdot
.38021 .41065 Mdot
.41036 .81923 Mdot
.34854 .60871 Mdot
.44981 .21266 Mdot
.65251 .57038 Mdot
.61824 .37084 Mdot
.60357 .18591 Mdot
.54015 .68547 Mdot
.49455 .65651 Mdot
.58247 .41351 Mdot
.48056 .6485 Mdot
.60868 .43166 Mdot
.54948 .67709 Mdot
.3701 .77779 Mdot
.57282 .45112 Mdot
.49504 .65862 Mdot
.55599 .35721 Mdot
.5602 .41559 Mdot
.34859 .36203 Mdot
.4871 .64111 Mdot
.59931 .35888 Mdot
.15755 .50841 Mdot
.41791 .58346 Mdot
.24176 .58227 Mdot
.32778 .58462 Mdot
.37348 .59843 Mdot
.35818 .36862 Mdot
.54437 .44247 Mdot
.70379 .56331 Mdot
.38529 .38879 Mdot
.54606 .63609 Mdot
.71794 .5723 Mdot
.33699 .50397 Mdot
.39265 .3608 Mdot
.2636 .57858 Mdot
.70638 .56232 Mdot
.5261 .43856 Mdot
.49916 .64619 Mdot
.78392 .61441 Mdot
.2466 .58698 Mdot
.60812 .40238 Mdot
.508 .70223 Mdot
.37964 .60332 Mdot
.58939 .40162 Mdot
.49027 .6666 Mdot
.23892 .5765 Mdot
.55703 .43521 Mdot
.56054 .43938 Mdot
.44819 .42059 Mdot
.28641 .41172 Mdot
.70024 .5646 Mdot
.3711 .42007 Mdot
.57968 .39898 Mdot
.67884 .59353 Mdot
.38816 .67618 Mdot
.54773 .37976 Mdot
.34615 .34416 Mdot
.48424 .43548 Mdot
.53588 .65083 Mdot
.39098 .56286 Mdot
.49364 .68432 Mdot
.68048 .55229 Mdot
.78291 .30688 Mdot
.27341 .56692 Mdot
.64088 .35779 Mdot
.63774 .39953 Mdot
.46632 .63668 Mdot
.37287 .37053 Mdot
.41624 .7686 Mdot
.61215 .37516 Mdot
.59229 .33365 Mdot
.60776 .42029 Mdot
.68383 .6777 Mdot
.35845 .39082 Mdot
.61203 .41725 Mdot
.57033 .32935 Mdot
.52428 .41796 Mdot
.69914 .55094 Mdot
.74295 .46606 Mdot
.54983 .38241 Mdot
.10488 .57979 Mdot
.24002 .56519 Mdot
.50579 .6468 Mdot
.49068 .5652 Mdot
.46813 .69875 Mdot
.44955 .17567 Mdot
.36766 .3629 Mdot
.6488 .46657 Mdot
.53083 .67173 Mdot
.73595 .32425 Mdot
.3752 .81039 Mdot
.55991 .41959 Mdot
.62753 .40927 Mdot
.52535 .6832 Mdot
.48868 .63187 Mdot
.25196 .55935 Mdot
.59652 .36308 Mdot
.6126 .33909 Mdot
.47618 .6439 Mdot
.58088 .42788 Mdot
.36897 .28264 Mdot
.4187 .62138 Mdot
.36289 .34688 Mdot
.39782 .56398 Mdot
.42365 .58641 Mdot
.5515 .20588 Mdot
.37057 .48726 Mdot
.38566 .58678 Mdot
.35268 .58714 Mdot
.80107 .53746 Mdot
.48137 .42779 Mdot
.71131 .5552 Mdot
.51595 .78501 Mdot
.50548 .65944 Mdot
.60579 .38776 Mdot
.39798 .40102 Mdot
.46567 .19356 Mdot
.3631 .71696 Mdot
.3142 .45664 Mdot
.57921 .38632 Mdot
.50068 .66432 Mdot
.23878 .58079 Mdot
.56645 .45008 Mdot
.71335 .42252 Mdot
.60079 .41406 Mdot
.52471 .63926 Mdot
.58105 .21483 Mdot
.44767 .36452 Mdot
.45093 .57614 Mdot
.32259 .3673 Mdot
.53058 .41857 Mdot
.38521 .35914 Mdot
.40211 .60817 Mdot
.68608 .59882 Mdot
.69296 .56624 Mdot
.5796 .44159 Mdot
.35934 .45141 Mdot
.63839 .56076 Mdot
.5615 .41371 Mdot
.55215 .40773 Mdot
.2618 .56505 Mdot
.55248 .40858 Mdot
.63667 .39366 Mdot
.53522 .40645 Mdot
.56831 .36112 Mdot
.40537 .56073 Mdot
.51539 .33041 Mdot
.56683 .36678 Mdot
.63658 .45456 Mdot
.4261 .61328 Mdot
.67138 .41832 Mdot
.4038 .57168 Mdot
.50118 .8089 Mdot
.39229 .57151 Mdot
.6955 .56664 Mdot
.53204 .70571 Mdot
.67918 .42968 Mdot
.41826 .38651 Mdot
.43186 .60263 Mdot
.70152 .58612 Mdot
.40201 .58226 Mdot
.53129 .69888 Mdot
.83549 .56668 Mdot
.39701 .42126 Mdot
.46045 .54127 Mdot
.6319 .52396 Mdot
.25405 .43582 Mdot
.54067 .65982 Mdot
.35095 .37801 Mdot
.42952 .34377 Mdot
.53505 .41214 Mdot
.69527 .55982 Mdot
.59225 .41798 Mdot
.40496 .56187 Mdot
.50215 .66047 Mdot
.58659 .65054 Mdot
.6978 .56356 Mdot
.8257 .40334 Mdot
.5459 .65226 Mdot
.59559 .45801 Mdot
.42878 .61304 Mdot
.85375 .54388 Mdot
.39411 .56998 Mdot
.78736 .41166 Mdot
.3463 .33223 Mdot
.6028 .22215 Mdot
.36578 .38594 Mdot
.25724 .37051 Mdot
.47367 .85468 Mdot
.37747 .80308 Mdot
.38964 .38409 Mdot
.55822 .71809 Mdot
.57267 .42709 Mdot
.56081 .37639 Mdot
.57403 .47616 Mdot
.33963 .40467 Mdot
.57717 .40512 Mdot
.26685 .57929 Mdot
.37801 .49262 Mdot
.6836 .71156 Mdot
.56644 .66891 Mdot
.61051 .43171 Mdot
.42776 .60036 Mdot
.37386 .56459 Mdot
.25914 .58601 Mdot
.37453 .60605 Mdot
.5605 .40859 Mdot
.37309 .39008 Mdot
.59663 .56719 Mdot
.68249 .58196 Mdot
.20219 .61874 Mdot
.67214 .54434 Mdot
.56969 .67448 Mdot
.59097 .47024 Mdot
.53564 .66607 Mdot
.68457 .21019 Mdot
.54756 .3902 Mdot
.38265 .37603 Mdot
.56824 .43967 Mdot
.53289 .41181 Mdot
.57215 .36724 Mdot
.49216 .67505 Mdot
.49095 .57106 Mdot
.58375 .42857 Mdot
.38481 .60152 Mdot
.59805 .67772 Mdot
.54932 .45092 Mdot
.52914 .75066 Mdot
.78272 .50109 Mdot
.26312 .45156 Mdot
.33026 .38747 Mdot
.51449 .67834 Mdot
.3658 .37799 Mdot
.33938 .40798 Mdot
.35818 .36842 Mdot
.58325 .75829 Mdot
.68465 .43653 Mdot
.41513 .16396 Mdot
.57883 .26565 Mdot
.47216 .19945 Mdot
.37899 .41489 Mdot
.41642 .69967 Mdot
.3955 .37633 Mdot
.3626 .36416 Mdot
.25478 .23378 Mdot
.399 .38725 Mdot
.61917 .40277 Mdot
.61253 .44879 Mdot
.23866 .51727 Mdot
.80588 .51946 Mdot
.58519 .36562 Mdot
.57976 .40386 Mdot
.70563 .5988 Mdot
.52527 .34954 Mdot
.253 .59081 Mdot
.33752 .47967 Mdot
.24349 .59753 Mdot
.59867 .42289 Mdot
.5791 .41093 Mdot
.62792 .35693 Mdot
.47708 .85981 Mdot
.45632 .18931 Mdot
.35792 .40484 Mdot
.66058 .36073 Mdot
.26055 .70526 Mdot
.62023 .43573 Mdot
.60708 .44337 Mdot
.54804 .42857 Mdot
.52918 .67292 Mdot
.4047 .35373 Mdot
.58111 .3365 Mdot
.24866 .47365 Mdot
.56816 .42335 Mdot
.36758 .62282 Mdot
.7207 .54455 Mdot
.61424 .40728 Mdot
.36433 .34374 Mdot
.56589 .37927 Mdot
.40363 .37403 Mdot
.36834 .348 Mdot
.64873 .37808 Mdot
.58531 .77159 Mdot
.37244 .33969 Mdot
.55894 .4307 Mdot
.53257 .67898 Mdot
.32849 .78114 Mdot
.60972 .40221 Mdot
.70749 .59523 Mdot
.59289 .37448 Mdot
.69636 .55105 Mdot
.55144 .41967 Mdot
.2424 .58619 Mdot
.43513 .24516 Mdot
.5109 .66888 Mdot
.66767 .54244 Mdot
.47922 .63638 Mdot
.46419 .42418 Mdot
.33963 .36946 Mdot
.24892 .59184 Mdot
.40426 .19361 Mdot
.26288 .56592 Mdot
.72458 .35805 Mdot
.33945 .68619 Mdot
.42295 .5932 Mdot
.39886 .35979 Mdot
.70421 .35805 Mdot
.5192 .75374 Mdot
.5037 .62366 Mdot
.52273 .62925 Mdot
.73174 .26011 Mdot
.54709 .14978 Mdot
.58868 .43081 Mdot
.78386 .64255 Mdot
.45448 .2843 Mdot
.53796 .38378 Mdot
.52564 .39056 Mdot
.53122 .64094 Mdot
.53018 .42309 Mdot
.49331 .51632 Mdot
.52133 .656 Mdot
.69767 .58182 Mdot
.37033 .35693 Mdot
.68394 .55458 Mdot
.46019 .77949 Mdot
.34551 .52252 Mdot
.52185 .64711 Mdot
.55873 .36768 Mdot
.58953 .43653 Mdot
.40655 .37188 Mdot
.37768 .31253 Mdot
.358 .34878 Mdot
.71969 .58595 Mdot
.51718 .66273 Mdot
.43363 .20043 Mdot
.60009 .37505 Mdot
.38329 .39594 Mdot
.45944 .64781 Mdot
.58869 .38124 Mdot
.41903 .6022 Mdot
.57821 .38571 Mdot
.39352 .38995 Mdot
.55222 .40958 Mdot
.37106 .38822 Mdot
.54102 .68108 Mdot
.62681 .42006 Mdot
.58144 .40921 Mdot
.71911 .3304 Mdot
.68725 .57856 Mdot
.34117 .3753 Mdot
.48883 .51047 Mdot
.62896 .4218 Mdot
.71023 .42905 Mdot
.54034 .43807 Mdot
.60349 .4859 Mdot
.56749 .34949 Mdot
.26754 .57742 Mdot
.62204 .36164 Mdot
.6093 .40358 Mdot
.48007 .34489 Mdot
.56278 .28649 Mdot
.40849 .43582 Mdot
.43356 .59542 Mdot
.36357 .34402 Mdot
.50748 .63896 Mdot
.49832 .63321 Mdot
.51018 .68868 Mdot
.80908 .48999 Mdot
.6527 .3756 Mdot
.6038 .40583 Mdot
.42893 .61642 Mdot
.69446 .57382 Mdot
.38244 .40183 Mdot
.69922 .57175 Mdot
.33855 .47667 Mdot
.72033 .57698 Mdot
.27098 .57561 Mdot
.69033 .67694 Mdot
.34905 .26501 Mdot
.7133 .58996 Mdot
.35867 .34821 Mdot
.59555 .59863 Mdot
.61389 .36739 Mdot
.30139 .71795 Mdot
.6896 .5923 Mdot
.76235 .29874 Mdot
.56743 .44602 Mdot
.49176 .52422 Mdot
.41036 .57634 Mdot
.69011 .55447 Mdot
.36882 .59058 Mdot
.56155 .37997 Mdot
.21667 .43313 Mdot
.38484 .37213 Mdot
.4332 .62151 Mdot
.60576 .35712 Mdot
.6855 .55446 Mdot
.51684 .6439 Mdot
.55175 .51074 Mdot
.41103 .61136 Mdot
.73977 .35164 Mdot
.7192 .4205 Mdot
.51868 .66161 Mdot
.29677 .27053 Mdot
.37301 .57573 Mdot
.55109 .37142 Mdot
.64464 .47911 Mdot
.56929 .38199 Mdot
.50841 .63633 Mdot
.49423 .66668 Mdot
.27291 .53403 Mdot
.57586 .43934 Mdot
.5609 .44495 Mdot
.42144 .36824 Mdot
.52759 .65445 Mdot
.35432 .37615 Mdot
.40975 .36784 Mdot
.52813 .68223 Mdot
.3532 .36544 Mdot
.71244 .56457 Mdot
.38415 .48895 Mdot
.37499 .5745 Mdot
.40221 .60546 Mdot
.51438 .64156 Mdot
.53781 .69879 Mdot
.53559 .66386 Mdot
.57613 .38869 Mdot
.35872 .39563 Mdot
.54592 .40227 Mdot
.55123 .38025 Mdot
.34816 .32907 Mdot
.37916 .40793 Mdot
.55014 .39393 Mdot
.6117 .60604 Mdot
.66585 .58381 Mdot
.49532 .66041 Mdot
.38127 .58162 Mdot
.71274 .31049 Mdot
.42476 .62161 Mdot
.59642 .44447 Mdot
.32267 .73255 Mdot
.38272 .40437 Mdot
.68421 .56728 Mdot
.73454 .58552 Mdot
.69165 .56243 Mdot
.43393 .62144 Mdot
.4031 .36011 Mdot
.33844 .50535 Mdot
.59991 .44181 Mdot
.4182 .50534 Mdot
.71767 .37108 Mdot
.2797 .4992 Mdot
.383 .58714 Mdot
.58288 .39155 Mdot
.26479 .56723 Mdot
.38842 .24536 Mdot
.59808 .41009 Mdot
.62335 .36534 Mdot
.64727 .65107 Mdot
.63372 .45616 Mdot
.34582 .40633 Mdot
.39773 .45917 Mdot
.63343 .39921 Mdot
.42301 .43304 Mdot
.38362 .14659 Mdot
.56693 .44523 Mdot
.57277 .4143 Mdot
.61365 .38937 Mdot
.54103 .40023 Mdot
.33265 .35359 Mdot
.6426 .62405 Mdot
.42986 .60023 Mdot
.39415 .49233 Mdot
.37176 .58297 Mdot
.4943 .65003 Mdot
.50277 .52358 Mdot
.38865 .35294 Mdot
.68985 .5624 Mdot
.82482 .59754 Mdot
.34845 .46902 Mdot
.54739 .67135 Mdot
.49325 .17989 Mdot
.68271 .58474 Mdot
.61604 .3698 Mdot
.66547 .57167 Mdot
.49582 .62903 Mdot
.38712 .5989 Mdot
.62126 .43812 Mdot
.39826 .40381 Mdot
.34502 .34937 Mdot
.5803 .39351 Mdot
.28046 .73838 Mdot
.37492 .59901 Mdot
.39647 .64457 Mdot
.5745 .43589 Mdot
.62422 .36622 Mdot
.36258 .35183 Mdot
.4996 .66994 Mdot
.32281 .65989 Mdot
.69355 .58529 Mdot
.58582 .35317 Mdot
.5648 .37804 Mdot
.35163 .48068 Mdot
.41783 .56755 Mdot
.24581 .57333 Mdot
.57435 .4373 Mdot
.36708 .48815 Mdot
.56955 .43759 Mdot
.50792 .37964 Mdot
.53756 .67259 Mdot
.61616 .45084 Mdot
.62838 .39441 Mdot
.66087 .32561 Mdot
.37114 .57542 Mdot
.37628 .37389 Mdot
.37549 .33376 Mdot
.24243 .56706 Mdot
.41865 .59525 Mdot
.556 .38877 Mdot
.39772 .56155 Mdot
.56854 .36969 Mdot
.58352 .42564 Mdot
.38259 .58776 Mdot
.35374 .37488 Mdot
.41427 .76229 Mdot
.49561 .34513 Mdot
.54032 .42297 Mdot
.58567 .37366 Mdot
.80577 .50281 Mdot
.33961 .23887 Mdot
.62357 .38481 Mdot
.36857 .40339 Mdot
.58926 .38304 Mdot
.41179 .60685 Mdot
.72062 .58196 Mdot
.38411 .38027 Mdot
.54893 .69384 Mdot
.53837 .68444 Mdot
.4939 .70161 Mdot
.27297 .57078 Mdot
.61114 .37079 Mdot
.39794 .42308 Mdot
.38581 .40825 Mdot
.22114 .59667 Mdot
.50435 .64661 Mdot
.71604 .56145 Mdot
.54938 .43513 Mdot
.56258 .51306 Mdot
.42703 .58855 Mdot
.10722 .58351 Mdot
.33675 .51257 Mdot
.68252 .546 Mdot
.31207 .42243 Mdot
.2649 .57219 Mdot
.62156 .41623 Mdot
.67163 .58249 Mdot
.52904 .69369 Mdot
.55955 .37837 Mdot
.65444 .42671 Mdot
.50176 .74664 Mdot
.56415 .67092 Mdot
.39315 .56191 Mdot
.53956 .69376 Mdot
.67884 .5501 Mdot
.26998 .57711 Mdot
.34484 .36143 Mdot
.60903 .40898 Mdot
.6701 .36922 Mdot
.50328 .65194 Mdot
.23718 .58256 Mdot
.56884 .4348 Mdot
.34991 .34469 Mdot
.49716 .67499 Mdot
.60156 .42558 Mdot
.43282 .21601 Mdot
.33402 .32921 Mdot
.5103 .66022 Mdot
.63882 .40017 Mdot
.47472 .42458 Mdot
.55581 .67999 Mdot
.53593 .64388 Mdot
.57729 .40555 Mdot
.70745 .56209 Mdot
.62277 .42305 Mdot
.40064 .57331 Mdot
.4912 .57112 Mdot
.41561 .60136 Mdot
.72168 .38892 Mdot
.63911 .42499 Mdot
.25714 .41043 Mdot
.40855 .388 Mdot
.72024 .60614 Mdot
.48767 .33455 Mdot
.62805 .37282 Mdot
.47378 .8133 Mdot
.59506 .58435 Mdot
.23778 .6145 Mdot
.60276 .81522 Mdot
.70414 .59116 Mdot
.40595 .58213 Mdot
.57284 .41311 Mdot
.37831 .55038 Mdot
.71311 .58371 Mdot
.72208 .38195 Mdot
.63831 .39765 Mdot
.35856 .38937 Mdot
.57007 .42726 Mdot
.39819 .3661 Mdot
.59085 .37844 Mdot
.65882 .38041 Mdot
.66299 .58766 Mdot
.78555 .40671 Mdot
.6101 .36677 Mdot
.83409 .58764 Mdot
.52595 .51089 Mdot
.69313 .59218 Mdot
.54438 .41958 Mdot
.25258 .57785 Mdot
.38268 .60576 Mdot
.75416 .64959 Mdot
.53332 .66942 Mdot
.38971 .58137 Mdot
.3638 .3547 Mdot
.49872 .69328 Mdot
.23938 .56855 Mdot
.68032 .43863 Mdot
.67897 .55615 Mdot
.41893 .58698 Mdot
.61124 .40499 Mdot
.59598 .44531 Mdot
.69406 .67115 Mdot
.233 .32275 Mdot
.41878 .37081 Mdot
.80759 .38729 Mdot
.35568 .4111 Mdot
.68949 .57513 Mdot
.5381 .67005 Mdot
.62362 .40284 Mdot
.59162 .4093 Mdot
.49713 .63834 Mdot
.35994 .40024 Mdot
.50259 .70171 Mdot
.53393 .19501 Mdot
.47858 .61633 Mdot
.77053 .43964 Mdot
.38872 .3798 Mdot
.77217 .43404 Mdot
.68687 .54662 Mdot
.57931 .78569 Mdot
.73754 .52265 Mdot
.41955 .5822 Mdot
.76818 .44492 Mdot
.38738 .40076 Mdot
.59274 .43149 Mdot
.26111 .5799 Mdot
.26133 .56063 Mdot
.37728 .35507 Mdot
.5215 .68212 Mdot
.6832 .55687 Mdot
.57429 .41847 Mdot
.29673 .48037 Mdot
.19974 .51588 Mdot
.50075 .68888 Mdot
.56174 .33412 Mdot
.3727 .59457 Mdot
.58516 .3781 Mdot
.69842 .59898 Mdot
.39352 .58703 Mdot
.27794 .56107 Mdot
.38748 .48623 Mdot
.54917 .43584 Mdot
.43777 .44435 Mdot
.41686 .58875 Mdot
.31175 .24904 Mdot
.58426 .40826 Mdot
.37279 .57579 Mdot
.61462 .47638 Mdot
.21879 .44878 Mdot
.61721 .55362 Mdot
.39725 .81143 Mdot
.55081 .64676 Mdot
.53438 .68678 Mdot
.17994 .43054 Mdot
.65304 .57354 Mdot
.4271 .60633 Mdot
.26736 .58035 Mdot
.73592 .48918 Mdot
.36663 .58472 Mdot
.60346 .44674 Mdot
.543 .43959 Mdot
.53687 .20167 Mdot
.52025 .51727 Mdot
.23335 .57626 Mdot
.56986 .49531 Mdot
.56089 .39885 Mdot
.53439 .45391 Mdot
.58923 .39646 Mdot
.35545 .40434 Mdot
.36436 .58559 Mdot
.83966 .6161 Mdot
.36568 .57462 Mdot
.30506 .48214 Mdot
.50515 .65958 Mdot
.49331 .68087 Mdot
.61382 .40914 Mdot
.2708 .37249 Mdot
.73764 .68407 Mdot
.59352 .37077 Mdot
.73149 .5628 Mdot
.72197 .41387 Mdot
.5464 .45148 Mdot
.4014 .34709 Mdot
.5792 .33407 Mdot
.33512 .37957 Mdot
.39027 .58963 Mdot
.70619 .59079 Mdot
.67967 .60332 Mdot
.40888 .57948 Mdot
.60225 .40319 Mdot
.74005 .58835 Mdot
.6057 .41701 Mdot
.58626 .43461 Mdot
.32952 .47986 Mdot
.7265 .58411 Mdot
.53619 .66167 Mdot
.69422 .56515 Mdot
.36309 .36574 Mdot
.18861 .29298 Mdot
.70604 .5743 Mdot
.48327 .44195 Mdot
.52055 .54789 Mdot
.76821 .44018 Mdot
.34583 .34993 Mdot
.71539 .59328 Mdot
.37871 .56572 Mdot
.22679 .61343 Mdot
.31628 .25908 Mdot
.40313 .62169 Mdot
.58799 .41153 Mdot
.39612 .35885 Mdot
.37579 .41118 Mdot
.36563 .60443 Mdot
.34726 .37249 Mdot
.57527 .46752 Mdot
.56269 .43809 Mdot
.42708 .60597 Mdot
.22615 .52544 Mdot
.36378 .58485 Mdot
.53352 .50077 Mdot
.55171 .42899 Mdot
.38317 .37814 Mdot
.52036 .45168 Mdot
.42728 .38798 Mdot
.26222 .55915 Mdot
.57615 .36506 Mdot
.68742 .56021 Mdot
.45968 .51154 Mdot
.50937 .66135 Mdot
.32877 .73641 Mdot
.39389 .36008 Mdot
.45324 .60993 Mdot
.34885 .36041 Mdot
.40976 .39887 Mdot
.37079 .6042 Mdot
.37324 .36654 Mdot
.57292 .41588 Mdot
.45337 .55014 Mdot
.39942 .37259 Mdot
.40709 .59612 Mdot
.68111 .56072 Mdot
.35297 .3692 Mdot
.48429 .68097 Mdot
.59534 .4343 Mdot
.5397 .65492 Mdot
.72636 .56479 Mdot
.39133 .35429 Mdot
.71661 .59092 Mdot
.50308 .64951 Mdot
.67482 .5616 Mdot
.57564 .64977 Mdot
.42062 .562 Mdot
.30982 .45903 Mdot
.46218 .37284 Mdot
.40108 .40021 Mdot
.5089 .62404 Mdot
.62614 .39654 Mdot
.58463 .43969 Mdot
.67095 .55859 Mdot
.38021 .4113 Mdot
.32357 .77556 Mdot
.5958 .48963 Mdot
.28287 .54249 Mdot
.41715 .56436 Mdot
.76927 .34232 Mdot
.33106 .52936 Mdot
.23888 .62851 Mdot
.53531 .37069 Mdot
.26477 .57325 Mdot
.60882 .42 Mdot
.74829 .35028 Mdot
.72184 .58034 Mdot
.39827 .71705 Mdot
.55098 .36237 Mdot
.52803 .66267 Mdot
.59875 .37858 Mdot
.78127 .64213 Mdot
.54049 .3541 Mdot
.70877 .59746 Mdot
.43837 .60316 Mdot
.41844 .38614 Mdot
.6831 .58356 Mdot
.5433 .68135 Mdot
.75981 .48484 Mdot
.63816 .40951 Mdot
.56225 .40253 Mdot
.50515 .62466 Mdot
.35412 .38466 Mdot
.49615 .64799 Mdot
.37448 .5751 Mdot
.70306 .57444 Mdot
.53761 .40843 Mdot
.56357 .46305 Mdot
.47133 .63104 Mdot
.37351 .56583 Mdot
.51943 .70081 Mdot
.40791 .56489 Mdot
.26491 .57445 Mdot
.60857 .36844 Mdot
.49232 .62599 Mdot
.52455 .40579 Mdot
.59458 .28616 Mdot
.32789 .46887 Mdot
.50463 .31192 Mdot
.53639 .66008 Mdot
.78478 .48272 Mdot
.41086 .58806 Mdot
.40394 .56699 Mdot
.62475 .24427 Mdot
.72437 .69318 Mdot
.59472 .60357 Mdot
.83045 .56823 Mdot
.37523 .57474 Mdot
.41434 .59752 Mdot
.52531 .69275 Mdot
.37318 .36199 Mdot
.33223 .33927 Mdot
.47676 .65343 Mdot
.76124 .37548 Mdot
.38273 .40163 Mdot
.4542 .81619 Mdot
.55432 .66168 Mdot
.56798 .3501 Mdot
.23094 .57958 Mdot
.69787 .59655 Mdot
.74681 .36554 Mdot
.81453 .59236 Mdot
.62049 .41009 Mdot
.49466 .15846 Mdot
.51509 .67611 Mdot
.43022 .54229 Mdot
.53293 .79338 Mdot
.63524 .37717 Mdot
.60368 .38249 Mdot
.59888 .39801 Mdot
.72009 .59976 Mdot
.51086 .32623 Mdot
.62028 .41254 Mdot
.788 .42593 Mdot
.59815 .45204 Mdot
.77119 .62629 Mdot
.69483 .56542 Mdot
.67838 .46443 Mdot
.54721 .64115 Mdot
.26194 .47781 Mdot
.56749 .47583 Mdot
.38158 .56895 Mdot
.48514 .76419 Mdot
.38204 .59533 Mdot
.65064 .75858 Mdot
.73581 .51967 Mdot
.35833 .4079 Mdot
.57871 .38687 Mdot
.52378 .63089 Mdot
.3997 .36343 Mdot
.33457 .67836 Mdot
.24956 .23479 Mdot
.3975 .55826 Mdot
.57705 .14017 Mdot
.40638 .56733 Mdot
.25738 .55949 Mdot
.36877 .35222 Mdot
.32021 .40565 Mdot
.42275 .50616 Mdot
.35485 .37403 Mdot
.50729 .72496 Mdot
.38773 .33846 Mdot
.77661 .46364 Mdot
.41025 .40415 Mdot
.40583 .59183 Mdot
.4424 .59393 Mdot
.65396 .4435 Mdot
.62352 .38652 Mdot
.38275 .49598 Mdot
.56847 .48289 Mdot
.60755 .37257 Mdot
.52144 .65612 Mdot
.28622 .32952 Mdot
.459 .58825 Mdot
.39328 .37102 Mdot
.4278 .58304 Mdot
.60295 .38109 Mdot
.54091 .42257 Mdot
.53594 .3898 Mdot
.73746 .33984 Mdot
.45597 .81397 Mdot
.58556 .4279 Mdot
.64467 .37345 Mdot
.54399 .67613 Mdot
.71673 .65661 Mdot
.83159 .48322 Mdot
.73969 .49958 Mdot
.58219 .4429 Mdot
.68621 .57332 Mdot
.72216 .5886 Mdot
.58797 .46235 Mdot
.27158 .44465 Mdot
.55331 .71462 Mdot
.61125 .4046 Mdot
.75375 .54728 Mdot
.46983 .65655 Mdot
.24313 .58731 Mdot
.5039 .65144 Mdot
.37664 .34616 Mdot
.26107 .56296 Mdot
.49155 .67155 Mdot
.3041 .34433 Mdot
.2437 .56677 Mdot
.22369 .46016 Mdot
.71963 .58642 Mdot
.58979 .40144 Mdot
.4319 .39702 Mdot
.49971 .63805 Mdot
.41724 .58438 Mdot
.37587 .38605 Mdot
.40567 .55551 Mdot
.71845 .65791 Mdot
.74387 .38254 Mdot
.27309 .56726 Mdot
.38594 .56896 Mdot
.40687 .47416 Mdot
.68743 .57011 Mdot
.37473 .6081 Mdot
.26484 .37629 Mdot
.54471 .44708 Mdot
.6933 .74178 Mdot
.56708 .40068 Mdot
.242 .69457 Mdot
.4043 .56807 Mdot
.26807 .55849 Mdot
.60724 .41043 Mdot
.54829 .65503 Mdot
.66356 .43578 Mdot
.60352 .41801 Mdot
.54465 .69275 Mdot
.58977 .4305 Mdot
.69322 .59951 Mdot
.33033 .37235 Mdot
.59597 .58096 Mdot
.73625 .30002 Mdot
.67347 .56836 Mdot
.28215 .55309 Mdot
.6145 .37525 Mdot
.61209 .67837 Mdot
.35727 .37895 Mdot
.62881 .36893 Mdot
.58673 .20181 Mdot
.38068 .36018 Mdot
.3645 .37911 Mdot
.55019 .4056 Mdot
.41249 .62264 Mdot
.52167 .64123 Mdot
.68808 .56784 Mdot
.30875 .61717 Mdot
.60344 .42611 Mdot
.5834 .39443 Mdot
.68214 .58363 Mdot
.41533 .59925 Mdot
.53899 .40745 Mdot
.32466 .69408 Mdot
.27805 .59583 Mdot
.42429 .58735 Mdot
.54499 .44827 Mdot
.71052 .74929 Mdot
.31994 .35281 Mdot
.46515 .15368 Mdot
.6531 .56264 Mdot
.52577 .68002 Mdot
.63344 .34767 Mdot
.09575 .55049 Mdot
.69937 .59552 Mdot
.28011 .4932 Mdot
.58028 .43043 Mdot
.61352 .38054 Mdot
.34157 .36848 Mdot
.55256 .3942 Mdot
.39619 .38924 Mdot
.73752 .29611 Mdot
.87281 .51942 Mdot
.34981 .36173 Mdot
.40036 .38204 Mdot
.35231 .42804 Mdot
.7312 .34475 Mdot
.36704 .35627 Mdot
.63988 .402 Mdot
.56982 .73621 Mdot
.65158 .41564 Mdot
.69547 .54494 Mdot
.72078 .60831 Mdot
.42177 .35985 Mdot
.26778 .31161 Mdot
.67443 .42321 Mdot
.49549 .36455 Mdot
.64035 .55415 Mdot
.38988 .57377 Mdot
.54006 .43283 Mdot
.27282 .57289 Mdot
.50557 .6877 Mdot
.54431 .34673 Mdot
.59252 .40347 Mdot
.40191 .3722 Mdot
.71992 .6012 Mdot
.37049 .60011 Mdot
.57979 .40519 Mdot
.55003 .7041 Mdot
.69616 .58371 Mdot
.39922 .37438 Mdot
.48582 .45101 Mdot
.70733 .55244 Mdot
.55437 .46329 Mdot
.60828 .37392 Mdot
.56833 .43516 Mdot
.57519 .47731 Mdot
.40985 .57866 Mdot
.48354 .67033 Mdot
.62414 .44922 Mdot
.34325 .48568 Mdot
.4717 .53157 Mdot
.6158 .45314 Mdot
.36025 .39803 Mdot
.43031 .60498 Mdot
.24607 .56781 Mdot
.75264 .45726 Mdot
.55875 .44023 Mdot
.46439 .81211 Mdot
.48792 .1852 Mdot
.25545 .56667 Mdot
.37589 .41941 Mdot
.68734 .5645 Mdot
.55704 .40775 Mdot
.59288 .70901 Mdot
.57958 .44679 Mdot
.49536 .44853 Mdot
.52122 .6783 Mdot
.38399 .57649 Mdot
.26303 .60196 Mdot
.50561 .68809 Mdot
.36533 .3783 Mdot
.30342 .7773 Mdot
.36372 .33478 Mdot
.41385 .36748 Mdot
.59764 .77235 Mdot
.38747 .58953 Mdot
.10195 .56826 Mdot
.33536 .23955 Mdot
.57902 .44813 Mdot
.39745 .60696 Mdot
.37266 .35118 Mdot
.57433 .39252 Mdot
.39615 .40135 Mdot
.39531 .34969 Mdot
.54307 .38975 Mdot
.6166 .38057 Mdot
.77761 .39761 Mdot
.45375 .82848 Mdot
.69819 .56095 Mdot
.3488 .38974 Mdot
.5052 .20222 Mdot
.62133 .41261 Mdot
.60092 .44126 Mdot
.4978 .75324 Mdot
.71035 .59609 Mdot
.3825 .28028 Mdot
.57888 .43699 Mdot
.599 .20841 Mdot
.60141 .36866 Mdot
.42287 .42234 Mdot
.41594 .62411 Mdot
.27504 .45469 Mdot
.51164 .63668 Mdot
.35285 .34016 Mdot
.69505 .55171 Mdot
.34168 .34156 Mdot
.60308 .22865 Mdot
.38735 .59302 Mdot
.39353 .39004 Mdot
.5212 .70409 Mdot
.39694 .59986 Mdot
.41868 .57976 Mdot
.59702 .67758 Mdot
.49807 .69151 Mdot
.70897 .60404 Mdot
.37829 .59516 Mdot
.45581 .2111 Mdot
.40192 .59096 Mdot
.5228 .20428 Mdot
.63126 .40704 Mdot
.78179 .4192 Mdot
.31973 .53242 Mdot
.60371 .47162 Mdot
.36561 .59029 Mdot
.71089 .57135 Mdot
.56428 .38452 Mdot
.34746 .37552 Mdot
.70794 .57813 Mdot
.35006 .59115 Mdot
.5363 .70129 Mdot
.40403 .40538 Mdot
.42807 .61465 Mdot
.39472 .39413 Mdot
.73533 .38219 Mdot
.57255 .66198 Mdot
.64586 .5354 Mdot
.43747 .51345 Mdot
.54769 .37382 Mdot
.42592 .43105 Mdot
.63078 .42017 Mdot
.59556 .40702 Mdot
.50965 .65968 Mdot
.80845 .48776 Mdot
.35232 .37128 Mdot
.19466 .58065 Mdot
.39233 .56736 Mdot
.39181 .45987 Mdot
.51911 .47607 Mdot
.57046 .37018 Mdot
.39578 .36893 Mdot
.4025 .35444 Mdot
.56171 .28672 Mdot
.49507 .63937 Mdot
.63247 .44851 Mdot
.60096 .46788 Mdot
.65206 .37166 Mdot
.40901 .56877 Mdot
.34634 .7128 Mdot
.48795 .66053 Mdot
.49085 .12528 Mdot
.49502 .66162 Mdot
.62715 .65118 Mdot
.37434 .36634 Mdot
.71827 .56741 Mdot
.60428 .43915 Mdot
.52411 .32909 Mdot
.33284 .35952 Mdot
.54271 .71911 Mdot
.68353 .56513 Mdot
.38476 .74139 Mdot
.38796 .5852 Mdot
.63509 .3996 Mdot
.53367 .40549 Mdot
.54385 .40889 Mdot
.56379 .41597 Mdot
.43133 .58852 Mdot
.60369 .44635 Mdot
.42952 .57598 Mdot
.40801 .22738 Mdot
.60849 .21683 Mdot
.52819 .63594 Mdot
.75455 .63576 Mdot
.39809 .40551 Mdot
.49852 .21465 Mdot
.36842 .27853 Mdot
.32543 .46917 Mdot
.58406 .65336 Mdot
.63066 .39281 Mdot
.52063 .68309 Mdot
.78195 .64548 Mdot
.51993 .63006 Mdot
.89203 .50695 Mdot
.7011 .40108 Mdot
.38469 .81279 Mdot
.57172 .39731 Mdot
.47629 .65562 Mdot
.36764 .29736 Mdot
.56942 .46089 Mdot
.73298 .60476 Mdot
.52193 .48636 Mdot
.24432 .50973 Mdot
.71516 .55984 Mdot
.59788 .43279 Mdot
.41895 .39007 Mdot
.57238 .41725 Mdot
.60582 .4358 Mdot
.59425 .37184 Mdot
.3572 .58131 Mdot
.53393 .43646 Mdot
.62169 .4245 Mdot
.2419 .30823 Mdot
.79589 .50898 Mdot
.54916 .66751 Mdot
.53437 .29196 Mdot
.69472 .57418 Mdot
.40282 .36951 Mdot
.57817 .57374 Mdot
.39778 .57524 Mdot
.57392 .28331 Mdot
.56987 .39845 Mdot
.29902 .53409 Mdot
.42532 .61999 Mdot
.70884 .58508 Mdot
.24101 .57039 Mdot
.46913 .79466 Mdot
.51512 .63375 Mdot
.24764 .56028 Mdot
.50918 .66252 Mdot
.43652 .3271 Mdot
.40028 .37067 Mdot
.54043 .38504 Mdot
.3713 .59108 Mdot
.53613 .64561 Mdot
.80969 .52321 Mdot
.59355 .39105 Mdot
.53568 .65788 Mdot
.54834 .37405 Mdot
.47224 .54083 Mdot
.52483 .55372 Mdot
.48497 .63083 Mdot
.44206 .59677 Mdot
.40088 .60259 Mdot
.71491 .56638 Mdot
.4052 .37271 Mdot
.37347 .40406 Mdot
.39349 .59056 Mdot
.50948 .14299 Mdot
.60584 .42483 Mdot
.60232 .37102 Mdot
.34267 .49193 Mdot
.57276 .40197 Mdot
.77384 .49247 Mdot
.26308 .58656 Mdot
.40656 .3956 Mdot
.56721 .41181 Mdot
.53838 .40948 Mdot
.54773 .43457 Mdot
.74206 .38769 Mdot
.50055 .65466 Mdot
.56006 .4001 Mdot
.66896 .56993 Mdot
.2436 .40944 Mdot
.62686 .40394 Mdot
.55253 .46022 Mdot
.39236 .39384 Mdot
.78438 .35146 Mdot
.41249 .57674 Mdot
.52766 .65151 Mdot
.55471 .66479 Mdot
.69688 .46325 Mdot
.32621 .37537 Mdot
.24532 .59088 Mdot
.44775 .68209 Mdot
.25084 .586 Mdot
.69035 .58938 Mdot
.60968 .62329 Mdot
.55515 .70029 Mdot
.54803 .67885 Mdot
.42201 .56397 Mdot
.56558 .41684 Mdot
.60223 .36938 Mdot
.28204 .49172 Mdot
.58487 .36716 Mdot
.68211 .56272 Mdot
.42248 .61529 Mdot
.39059 .39357 Mdot
.69083 .59608 Mdot
.39358 .56454 Mdot
.35402 .38569 Mdot
.55649 .45418 Mdot
.52346 .42658 Mdot
.37073 .38472 Mdot
.37489 .34832 Mdot
.61699 .4002 Mdot
.21473 .36193 Mdot
.41276 .3913 Mdot
.39195 .38462 Mdot
.24125 .5579 Mdot
.51551 .63332 Mdot
.50865 .42374 Mdot
.39206 .60587 Mdot
.57104 .43538 Mdot
.5243 .63347 Mdot
.71427 .59024 Mdot
.36735 .39086 Mdot
.54458 .4292 Mdot
.5926 .42528 Mdot
.68557 .57242 Mdot
.72588 .57186 Mdot
.67603 .56835 Mdot
.3841 .55611 Mdot
.55899 .42594 Mdot
.36231 .35737 Mdot
.3853 .58889 Mdot
.72231 .58763 Mdot
.67459 .59313 Mdot
.26077 .29348 Mdot
.61907 .4112 Mdot
.62493 .55887 Mdot
.14586 .35526 Mdot
.75639 .49112 Mdot
.24974 .56181 Mdot
.47532 .63267 Mdot
.78337 .43484 Mdot
.66038 .5447 Mdot
.40037 .60869 Mdot
.70716 .52705 Mdot
.72365 .60219 Mdot
.54979 .38233 Mdot
.58055 .37736 Mdot
.58638 .35015 Mdot
.69951 .58034 Mdot
.7362 .38813 Mdot
.37187 .40961 Mdot
.45779 .26146 Mdot
.69489 .57426 Mdot
.48397 .63119 Mdot
.48784 .62732 Mdot
.49438 .6616 Mdot
.63151 .39038 Mdot
.53351 .30183 Mdot
.47513 .20354 Mdot
.40409 .28593 Mdot
.39019 .58167 Mdot
.40574 .35556 Mdot
.58674 .64946 Mdot
.36377 .37983 Mdot
.50691 .6854 Mdot
.70096 .58441 Mdot
.34311 .37783 Mdot
.42158 .59901 Mdot
.41345 .60274 Mdot
.54639 .69647 Mdot
.5076 .64827 Mdot
.51997 .64555 Mdot
.37186 .34348 Mdot
.37333 .36635 Mdot
.53672 .41782 Mdot
.37623 .39338 Mdot
.42928 .1853 Mdot
.6879 .54321 Mdot
.51152 .62567 Mdot
.41521 .58944 Mdot
.3929 .36122 Mdot
.58817 .40394 Mdot
.66278 .65652 Mdot
.49899 .70416 Mdot
.67325 .57785 Mdot
.48161 .5874 Mdot
.86922 .42566 Mdot
.53061 .41077 Mdot
.40665 .56315 Mdot
.26387 .4296 Mdot
.59938 .39224 Mdot
.53073 .67384 Mdot
.70006 .32211 Mdot
.24085 .58442 Mdot
.62298 .41959 Mdot
.61439 .36252 Mdot
.37072 .60353 Mdot
.55664 .56457 Mdot
.57581 .36731 Mdot
.46098 .45496 Mdot
.37439 .56359 Mdot
.48808 .66295 Mdot
.15614 .50624 Mdot
.48401 .61764 Mdot
.79034 .40669 Mdot
.25118 .56305 Mdot
.53453 .40487 Mdot
.51877 .65719 Mdot
.67349 .58377 Mdot
.51421 .65329 Mdot
.38822 .41557 Mdot
.53594 .651 Mdot
.58701 .38747 Mdot
.36248 .35899 Mdot
.41878 .59327 Mdot
.40822 .45416 Mdot
.24493 .31791 Mdot
.54995 .65753 Mdot
.27974 .55841 Mdot
.62245 .4159 Mdot
.39604 .24636 Mdot
.66658 .42371 Mdot
.6269 .39121 Mdot
.38121 .59413 Mdot
.3947 .36892 Mdot
.41851 .5655 Mdot
.53514 .44568 Mdot
.62656 .25383 Mdot
.39619 .56859 Mdot
.22478 .48796 Mdot
.68472 .58685 Mdot
.75951 .37502 Mdot
.59643 .41302 Mdot
.37171 .58915 Mdot
.55859 .42668 Mdot
.3506 .39378 Mdot
.44705 .496 Mdot
.2505 .39548 Mdot
.37315 .59386 Mdot
.27032 .73558 Mdot
.48761 .50887 Mdot
.51293 .38859 Mdot
.37102 .58092 Mdot
.49706 .32616 Mdot
.24919 .57596 Mdot
.69322 .58621 Mdot
.72536 .58239 Mdot
.6807 .55402 Mdot
.58634 .367 Mdot
.61246 .33049 Mdot
.69033 .60551 Mdot
.39612 .55656 Mdot
.68434 .59838 Mdot
.73454 .3605 Mdot
.29976 .75718 Mdot
.67505 .57516 Mdot
.59141 .41562 Mdot
.55257 .45887 Mdot
.79739 .51105 Mdot
.48611 .66266 Mdot
.47925 .81151 Mdot
.35791 .23773 Mdot
.62333 .39967 Mdot
.67477 .4506 Mdot
.3945 .41013 Mdot
.28177 .40658 Mdot
.60875 .48897 Mdot
.59659 .59649 Mdot
.39707 .37975 Mdot
.47335 .5558 Mdot
.40714 .39244 Mdot
.52839 .40976 Mdot
.58233 .42541 Mdot
.33153 .36567 Mdot
.31372 .71938 Mdot
.19993 .45313 Mdot
.20617 .63571 Mdot
.3719 .40446 Mdot
.37068 .57609 Mdot
.39632 .5595 Mdot
.38396 .58522 Mdot
.50821 .63828 Mdot
.365 .34479 Mdot
.55615 .42023 Mdot
.5368 .68312 Mdot
.59167 .44148 Mdot
.39087 .60004 Mdot
.26569 .60209 Mdot
.39204 .3928 Mdot
.60964 .40443 Mdot
.31374 .263 Mdot
.50392 .66756 Mdot
.68789 .57203 Mdot
.45036 .54109 Mdot
.47215 .6344 Mdot
.36289 .579 Mdot
.3221 .36713 Mdot
.43693 .63644 Mdot
.64552 .62376 Mdot
.62828 .35761 Mdot
.63596 .41716 Mdot
.31777 .607 Mdot
.27924 .29366 Mdot
.58581 .37069 Mdot
.54343 .68173 Mdot
.49627 .62986 Mdot
.56241 .43888 Mdot
.34581 .35724 Mdot
.71153 .60719 Mdot
.67759 .55343 Mdot
.58936 .358 Mdot
.41517 .50531 Mdot
.78228 .41135 Mdot
.5476 .39556 Mdot
.49495 .42881 Mdot
.51515 .70188 Mdot
.24076 .56724 Mdot
.37209 .48724 Mdot
.69956 .55483 Mdot
.58043 .43211 Mdot
.19358 .47944 Mdot
.39653 .38579 Mdot
.52878 .64717 Mdot
.42594 .60212 Mdot
.7342 .60577 Mdot
.55718 .67409 Mdot
.56213 .43863 Mdot
.53879 .40818 Mdot
.37504 .60699 Mdot
.4245 .42049 Mdot
.70187 .58259 Mdot
.53795 .68145 Mdot
.71772 .56641 Mdot
.36587 .3671 Mdot
.38931 .38855 Mdot
.60985 .46537 Mdot
.61603 .46815 Mdot
.55381 .66377 Mdot
.60161 .35427 Mdot
.49557 .67609 Mdot
.6988 .66829 Mdot
.42742 .58801 Mdot
.63036 .36908 Mdot
.37758 .42423 Mdot
.3902 .59798 Mdot
.61741 .38862 Mdot
.32059 .59696 Mdot
.55212 .38532 Mdot
.47679 .65544 Mdot
.63509 .24996 Mdot
.71441 .58262 Mdot
.4579 .4054 Mdot
.62495 .31855 Mdot
.57392 .40072 Mdot
.4831 .66154 Mdot
.64841 .35622 Mdot
.40196 .57166 Mdot
.38551 .36796 Mdot
.68478 .21138 Mdot
.40403 .59488 Mdot
.57415 .42109 Mdot
.70518 .57572 Mdot
.41897 .37655 Mdot
.27024 .56895 Mdot
.34856 .50365 Mdot
.54174 .35021 Mdot
.52832 .37545 Mdot
.56719 .41843 Mdot
.83311 .56498 Mdot
.52194 .65156 Mdot
.38351 .35471 Mdot
.41712 .57209 Mdot
.39706 .58332 Mdot
.4998 .67051 Mdot
.26425 .5223 Mdot
.34877 .75868 Mdot
.10975 .41619 Mdot
.55285 .67879 Mdot
.67282 .58759 Mdot
.472 .52039 Mdot
.50641 .68952 Mdot
.52497 .65848 Mdot
.54975 .69601 Mdot
.30575 .52391 Mdot
.35429 .3902 Mdot
.59279 .42654 Mdot
.33008 .38729 Mdot
.54139 .39283 Mdot
.81761 .47334 Mdot
.39184 .58959 Mdot
.38329 .36755 Mdot
.328 .60856 Mdot
.58896 .48531 Mdot
.60038 .38507 Mdot
.56803 .7256 Mdot
.57201 .33863 Mdot
.76215 .45116 Mdot
.53433 .45762 Mdot
.50675 .65437 Mdot
.68272 .43055 Mdot
.63089 .34709 Mdot
.34115 .25051 Mdot
.41854 .60005 Mdot
.27079 .56281 Mdot
.56141 .45295 Mdot
.50518 .38842 Mdot
.41724 .37285 Mdot
.34282 .3773 Mdot
.69307 .60624 Mdot
.4236 .52275 Mdot
.41948 .59695 Mdot
.39825 .778 Mdot
.62022 .38166 Mdot
.38597 .53681 Mdot
.62464 .23942 Mdot
.6164 .39071 Mdot
.59037 .69938 Mdot
.57108 .28388 Mdot
.57073 .37095 Mdot
.42876 .29189 Mdot
.4122 .59208 Mdot
.59549 .20653 Mdot
.57367 .35463 Mdot
.5297 .67324 Mdot
.37562 .36304 Mdot
.40005 .40701 Mdot
.67684 .58453 Mdot
.38829 .20605 Mdot
.44142 .58161 Mdot
.37689 .36604 Mdot
.59639 .3963 Mdot
.41554 .58188 Mdot
.26851 .56365 Mdot
.53933 .35978 Mdot
.66762 .73649 Mdot
.3812 .39458 Mdot
.65186 .40328 Mdot
.21685 .55984 Mdot
.49107 .53437 Mdot
.46253 .83135 Mdot
.38162 .58389 Mdot
.6949 .5527 Mdot
.53235 .45725 Mdot
.44188 .67725 Mdot
.55708 .35974 Mdot
.80056 .44806 Mdot
.42435 .35479 Mdot
.72075 .58119 Mdot
.60296 .39607 Mdot
.57619 .36758 Mdot
.45151 .51309 Mdot
.72349 .56838 Mdot
.57308 .36755 Mdot
.62425 .45585 Mdot
.3561 .38741 Mdot
.26992 .58214 Mdot
.38599 .39616 Mdot
.58719 .41088 Mdot
.67628 .45799 Mdot
.34361 .36929 Mdot
.45173 .79039 Mdot
.68842 .61478 Mdot
.39726 .57448 Mdot
.50425 .37965 Mdot
.63099 .40243 Mdot
.66515 .80205 Mdot
.26139 .55895 Mdot
.81326 .41764 Mdot
.47339 .64111 Mdot
.18816 .56211 Mdot
.46924 .63833 Mdot
.35941 .80483 Mdot
.40292 .46375 Mdot
.61748 .35487 Mdot
.73581 .53515 Mdot
.41748 .28603 Mdot
.41607 .55896 Mdot
.43609 .22399 Mdot
.62382 .38704 Mdot
.60937 .42733 Mdot
.52535 .68953 Mdot
.27486 .53089 Mdot
.26527 .43913 Mdot
.39538 .495 Mdot
.70422 .58739 Mdot
.37278 .37101 Mdot
.58648 .38362 Mdot
.27526 .66452 Mdot
.54761 .66248 Mdot
.53719 .50988 Mdot
.60808 .40741 Mdot
.2971 .47212 Mdot
.25391 .49645 Mdot
.41786 .58364 Mdot
.47585 .64324 Mdot
.48453 .67162 Mdot
.5401 .43693 Mdot
.41935 .60756 Mdot
.53768 .40355 Mdot
.48405 .50292 Mdot
.64467 .37522 Mdot
.70609 .59473 Mdot
.60918 .43814 Mdot
.58249 .53176 Mdot
.35936 .81825 Mdot
.60165 .33411 Mdot
.41151 .37795 Mdot
.50511 .63997 Mdot
.49739 .66128 Mdot
.37465 .40461 Mdot
.49718 .66418 Mdot
.45984 .26789 Mdot
.57915 .21958 Mdot
.69691 .59378 Mdot
.35146 .27797 Mdot
.71037 .58761 Mdot
.27157 .56301 Mdot
.61967 .40661 Mdot
.46759 .7051 Mdot
.55381 .67777 Mdot
.71876 .32385 Mdot
.39976 .58876 Mdot
.26031 .55899 Mdot
.57935 .45043 Mdot
.61351 .62694 Mdot
.51311 .68585 Mdot
.47179 .77479 Mdot
.54637 .4339 Mdot
.35106 .39016 Mdot
.57374 .3696 Mdot
.64336 .38254 Mdot
.24678 .56158 Mdot
.56631 .41917 Mdot
.39308 .56452 Mdot
.3623 .3441 Mdot
.36202 .80125 Mdot
.5021 .6377 Mdot
.6133 .42809 Mdot
.59721 .39583 Mdot
.34359 .3848 Mdot
.59863 .45099 Mdot
.39579 .60819 Mdot
.12048 .62331 Mdot
.68621 .58749 Mdot
.23836 .57016 Mdot
.46004 .77938 Mdot
.57788 .38212 Mdot
.55757 .38641 Mdot
.31417 .60746 Mdot
.22718 .39162 Mdot
.38792 .56638 Mdot
.63268 .43733 Mdot
.54401 .67357 Mdot
.70799 .58106 Mdot
.38407 .6071 Mdot
.56078 .43468 Mdot
.61099 .42583 Mdot
.70359 .59606 Mdot
.57695 .72254 Mdot
.50223 .70273 Mdot
.38758 .58312 Mdot
.6484 .47863 Mdot
.66861 .65933 Mdot
.6053 .42138 Mdot
.24144 .67932 Mdot
.39005 .38293 Mdot
.37444 .57815 Mdot
.50181 .33414 Mdot
.54372 .38145 Mdot
.3632 .57995 Mdot
.41869 .59525 Mdot
.5631 .44586 Mdot
.32627 .37758 Mdot
.38122 .34478 Mdot
.3925 .38215 Mdot
.64844 .25237 Mdot
.79363 .57868 Mdot
.52052 .64493 Mdot
.41409 .59478 Mdot
.50884 .62751 Mdot
.70492 .60952 Mdot
.4706 .53049 Mdot
.49349 .62972 Mdot
.40058 .40522 Mdot
.50195 .62487 Mdot
.54169 .39757 Mdot
.41959 .60275 Mdot
.54736 .68149 Mdot
.57146 .38855 Mdot
.49114 .42505 Mdot
.60885 .52915 Mdot
.71317 .60547 Mdot
.47005 .54869 Mdot
.57879 .41626 Mdot
.24532 .56716 Mdot
.61551 .40338 Mdot
.42722 .60603 Mdot
.57118 .53639 Mdot
.56549 .39606 Mdot
.55524 .66956 Mdot
.6592 .62744 Mdot
.4825 .652 Mdot
.64343 .40889 Mdot
.58657 .41186 Mdot
.6068 .42254 Mdot
.57905 .36533 Mdot
.23286 .49975 Mdot
.4282 .5743 Mdot
.50084 .38125 Mdot
.56199 .67265 Mdot
.36474 .38429 Mdot
.3506 .39653 Mdot
.59163 .60032 Mdot
.24669 .55832 Mdot
.40979 .60813 Mdot
.60517 .42405 Mdot
.47212 .77438 Mdot
.26975 .60327 Mdot
.22583 .66743 Mdot
.60047 .65671 Mdot
.54538 .68128 Mdot
.40961 .37273 Mdot
.52783 .69773 Mdot
.5735 .445 Mdot
.53245 .45534 Mdot
.37743 .80729 Mdot
.35294 .58981 Mdot
.70049 .58316 Mdot
.59231 .44191 Mdot
.77328 .38433 Mdot
.54394 .6762 Mdot
.51134 .70068 Mdot
.53437 .41361 Mdot
.37176 .33852 Mdot
.44046 .84971 Mdot
.42628 .60464 Mdot
.4042 .24111 Mdot
.42922 .35443 Mdot
.53026 .48969 Mdot
.40763 .57951 Mdot
.62938 .544 Mdot
.48657 .65055 Mdot
.37002 .22644 Mdot
.37038 .38689 Mdot
.69666 .58155 Mdot
.6044 .46136 Mdot
.40256 .40442 Mdot
.47481 .62876 Mdot
.40421 .38793 Mdot
.53453 .39498 Mdot
.40764 .55942 Mdot
.4957 .668 Mdot
.43693 .59795 Mdot
.33127 .35961 Mdot
.7121 .58584 Mdot
.72277 .35127 Mdot
.40581 .23625 Mdot
.57134 .28401 Mdot
.5597 .40084 Mdot
.52514 .75242 Mdot
.55512 .42469 Mdot
.40934 .36232 Mdot
.59553 .41342 Mdot
.41826 .43794 Mdot
.49457 .68279 Mdot
.65148 .39403 Mdot
.61856 .43071 Mdot
.38016 .23297 Mdot
.60813 .38574 Mdot
.57666 .44932 Mdot
.60421 .3608 Mdot
.44493 .37852 Mdot
.64106 .43309 Mdot
.34973 .38626 Mdot
.28609 .50123 Mdot
.52395 .66027 Mdot
.67234 .59256 Mdot
.68724 .54877 Mdot
.7967 .43999 Mdot
.76332 .37793 Mdot
.27241 .52313 Mdot
.37629 .40124 Mdot
.37538 .56808 Mdot
.53685 .40646 Mdot
.4695 .34214 Mdot
.66185 .51056 Mdot
.48725 .6542 Mdot
.54655 .64924 Mdot
.632 .45767 Mdot
.82982 .59911 Mdot
.64827 .41822 Mdot
.33807 .50772 Mdot
.56582 .36885 Mdot
.62585 .36631 Mdot
.51807 .70398 Mdot
.74 .37213 Mdot
.56021 .40011 Mdot
.41744 .37326 Mdot
.69197 .58023 Mdot
.66975 .45367 Mdot
.66976 .49505 Mdot
.58657 .51666 Mdot
.30259 .33597 Mdot
.56111 .41999 Mdot
.53291 .68101 Mdot
.40738 .40001 Mdot
.3501 .48585 Mdot
.38374 .59002 Mdot
.36726 .49594 Mdot
.42529 .21435 Mdot
.51902 .61609 Mdot
.69631 .58346 Mdot
.59083 .68441 Mdot
.58652 .38792 Mdot
.51075 .63895 Mdot
.53398 .40054 Mdot
.26419 .60626 Mdot
.71648 .58931 Mdot
.33479 .34628 Mdot
.37099 .57502 Mdot
.36425 .4038 Mdot
.50895 .30927 Mdot
.66052 .50733 Mdot
.1874 .56421 Mdot
.51045 .63295 Mdot
.66772 .31241 Mdot
.37691 .35574 Mdot
.55168 .4328 Mdot
.11968 .40017 Mdot
.38793 .38093 Mdot
.35877 .39935 Mdot
.59786 .59635 Mdot
.72189 .38826 Mdot
.62893 .34431 Mdot
.40353 .39432 Mdot
.52845 .63002 Mdot
.69563 .56336 Mdot
.56349 .38783 Mdot
.59623 .36067 Mdot
.3421 .37196 Mdot
.50895 .68447 Mdot
.77553 .38036 Mdot
.50692 .65098 Mdot
.35179 .37922 Mdot
.51064 .66911 Mdot
.43562 .77744 Mdot
.54361 .66239 Mdot
.62296 .42605 Mdot
.60402 .42396 Mdot
.66338 .72385 Mdot
.38921 .3886 Mdot
.56179 .38483 Mdot
.58573 .4304 Mdot
.3677 .35543 Mdot
.56217 .69032 Mdot
.58465 .29438 Mdot
.57689 .3898 Mdot
.59838 .42652 Mdot
.72178 .57402 Mdot
.48656 .56253 Mdot
.25821 .65857 Mdot
.56284 .38662 Mdot
.67218 .56044 Mdot
.37754 .34548 Mdot
.61549 .40059 Mdot
.74261 .36638 Mdot
.46758 .6522 Mdot
.59199 .44697 Mdot
.27098 .57109 Mdot
.59153 .37129 Mdot
.43401 .84922 Mdot
.61675 .42344 Mdot
.36761 .35096 Mdot
.37938 .36082 Mdot
.5003 .70286 Mdot
.3674 .37788 Mdot
.25594 .56121 Mdot
.3945 .60074 Mdot
.22783 .68059 Mdot
.26012 .56153 Mdot
.63354 .37737 Mdot
.33577 .23915 Mdot
.58046 .35775 Mdot
.57135 .45813 Mdot
.72659 .34137 Mdot
.25622 .56323 Mdot
.39191 .36437 Mdot
.31367 .71619 Mdot
.63413 .37012 Mdot
.42543 .60563 Mdot
.56647 .46188 Mdot
.59656 .44673 Mdot
.495 .48156 Mdot
.64007 .26276 Mdot
.42599 .61386 Mdot
.50862 .41606 Mdot
.56166 .38822 Mdot
.25815 .34773 Mdot
.59129 .39459 Mdot
.67558 .57884 Mdot
.3888 .40309 Mdot
.52538 .69934 Mdot
.68326 .57906 Mdot
.58247 .38374 Mdot
.69736 .57798 Mdot
.52309 .64628 Mdot
.37649 .59065 Mdot
.60342 .44095 Mdot
.699 .54678 Mdot
.70409 .58451 Mdot
.54665 .41881 Mdot
.37906 .3654 Mdot
.67022 .39993 Mdot
.61583 .39806 Mdot
.55955 .43692 Mdot
.3737 .40409 Mdot
.37388 .17813 Mdot
.53031 .42399 Mdot
.62318 .55297 Mdot
.34551 .39688 Mdot
.23606 .58434 Mdot
.53418 .6953 Mdot
.52903 .39596 Mdot
.39198 .58528 Mdot
.39188 .59476 Mdot
.56645 .6654 Mdot
.33815 .35687 Mdot
.49751 .67549 Mdot
.52874 .36647 Mdot
.62567 .46083 Mdot
.61191 .46064 Mdot
.68849 .21469 Mdot
.47228 .79543 Mdot
.35631 .34728 Mdot
.48491 .65296 Mdot
.38997 .49679 Mdot
.40959 .60714 Mdot
.56822 .66306 Mdot
.38126 .42376 Mdot
.39115 .35578 Mdot
.39993 .40385 Mdot
.70029 .5572 Mdot
.50138 .64727 Mdot
.42886 .38223 Mdot
.35653 .33835 Mdot
.53917 .42391 Mdot
.56056 .38928 Mdot
.39695 .33828 Mdot
.79193 .51369 Mdot
.71051 .59159 Mdot
.52962 .67832 Mdot
.6179 .83883 Mdot
.4274 .60372 Mdot
.37749 .23394 Mdot
.57253 .3886 Mdot
.27405 .20179 Mdot
.63183 .44319 Mdot
.59479 .39556 Mdot
.37531 .34567 Mdot
.67031 .55389 Mdot
.69999 .56719 Mdot
.37709 .35636 Mdot
.332 .34165 Mdot
.6825 .55604 Mdot
.60187 .66548 Mdot
.24803 .71706 Mdot
.35948 .48927 Mdot
.36324 .35244 Mdot
.38281 .24847 Mdot
.3802 .60337 Mdot
.33737 .38887 Mdot
.42791 .6103 Mdot
.52615 .65925 Mdot
.54347 .64825 Mdot
.37763 .6094 Mdot
.55391 .43829 Mdot
.53459 .6514 Mdot
.55354 .34155 Mdot
.41728 .8041 Mdot
.63829 .77188 Mdot
.20956 .4019 Mdot
.6078 .36963 Mdot
.27232 .44805 Mdot
.24712 .45196 Mdot
.57495 .4071 Mdot
.54527 .47998 Mdot
.69915 .5816 Mdot
.33808 .38633 Mdot
.41052 .61083 Mdot
.48692 .8209 Mdot
.60528 .42225 Mdot
.35219 .37191 Mdot
.41626 .60515 Mdot
.42504 .76798 Mdot
.46582 .45922 Mdot
.53375 .40924 Mdot
.08309 .48736 Mdot
.33234 .35448 Mdot
.5244 .69941 Mdot
.31635 .27462 Mdot
.33491 .3948 Mdot
.67154 .64939 Mdot
.49011 .68433 Mdot
.21604 .63012 Mdot
.40066 .36671 Mdot
.54571 .7102 Mdot
.36505 .36947 Mdot
.69239 .59859 Mdot
.3229 .37121 Mdot
.50467 .67472 Mdot
.60551 .39221 Mdot
.50237 .67125 Mdot
.70415 .59791 Mdot
.51807 .63726 Mdot
.40739 .61096 Mdot
.24902 .56407 Mdot
.40899 .60398 Mdot
.47342 .53498 Mdot
.6079 .26246 Mdot
.38409 .57671 Mdot
.4923 .77339 Mdot
.58434 .37193 Mdot
.42039 .42415 Mdot
.52998 .69953 Mdot
.53962 .63859 Mdot
.45163 .52538 Mdot
.35542 .37212 Mdot
.51028 .67606 Mdot
.4287 .21629 Mdot
.47357 .13703 Mdot
.55434 .33802 Mdot
.7748 .60175 Mdot
.36578 .35478 Mdot
.49912 .68924 Mdot
.34216 .49445 Mdot
.37666 .41227 Mdot
.55285 .67278 Mdot
.36947 .58283 Mdot
.39946 .58101 Mdot
.54918 .43872 Mdot
.3802 .61578 Mdot
.48428 .6656 Mdot
.20005 .46048 Mdot
.38908 .40399 Mdot
.43418 .76516 Mdot
.67397 .56833 Mdot
.52651 .65456 Mdot
.6405 .35693 Mdot
.35188 .32235 Mdot
.54713 .6474 Mdot
.706 .71125 Mdot
.65885 .81834 Mdot
.51139 .67587 Mdot
.38954 .40274 Mdot
.36491 .38985 Mdot
.61251 .33774 Mdot
.42753 .50858 Mdot
.51068 .68233 Mdot
.4814 .71887 Mdot
.80432 .45628 Mdot
.2653 .57407 Mdot
.29204 .26916 Mdot
.56105 .40017 Mdot
.56029 .42829 Mdot
.38598 .60368 Mdot
.59684 .38152 Mdot
.38363 .34382 Mdot
.59579 .45795 Mdot
.39247 .55837 Mdot
.48802 .65799 Mdot
.61522 .41494 Mdot
.70964 .56889 Mdot
.39535 .60916 Mdot
.3584 .59015 Mdot
.51616 .66512 Mdot
.40302 .39908 Mdot
.30028 .71637 Mdot
.50644 .64995 Mdot
.5604 .41845 Mdot
.25574 .57112 Mdot
.5368 .38828 Mdot
.62868 .74437 Mdot
.37299 .40912 Mdot
.52469 .69827 Mdot
.37492 .41971 Mdot
.41021 .59826 Mdot
.55913 .65439 Mdot
.58712 .3971 Mdot
.55248 .66698 Mdot
.66886 .52961 Mdot
.61092 .71058 Mdot
.35252 .33763 Mdot
.72482 .55403 Mdot
.34326 .38094 Mdot
.2661 .57359 Mdot
.71931 .47044 Mdot
.69702 .58967 Mdot
.54088 .66452 Mdot
.46628 .80107 Mdot
.55122 .69164 Mdot
.60984 .38519 Mdot
.61403 .37901 Mdot
.52601 .6911 Mdot
.71222 .56612 Mdot
.75813 .33238 Mdot
.64127 .57614 Mdot
.39973 .37147 Mdot
.35639 .4509 Mdot
.55899 .85201 Mdot
.44203 .62854 Mdot
.36596 .57791 Mdot
.50615 .43953 Mdot
.56225 .37745 Mdot
.36839 .59965 Mdot
.42808 .58435 Mdot
.72099 .59013 Mdot
.51584 .64001 Mdot
.40919 .41578 Mdot
.37737 .60327 Mdot
.65796 .32953 Mdot
.75387 .36859 Mdot
.59486 .33667 Mdot
.6564 .39667 Mdot
.63343 .39935 Mdot
.49061 .53715 Mdot
.4177 .56698 Mdot
.58145 .41914 Mdot
.59787 .47005 Mdot
.37797 .57357 Mdot
.69965 .5983 Mdot
.33516 .41197 Mdot
.51969 .67306 Mdot
.3897 .14135 Mdot
.60559 .44007 Mdot
.6097 .39357 Mdot
.3905 .58151 Mdot
.27016 .30476 Mdot
.35533 .35041 Mdot
.39899 .39991 Mdot
.52208 .65056 Mdot
.44682 .52626 Mdot
.60908 .44877 Mdot
.57597 .41022 Mdot
.53741 .66487 Mdot
.2476 .56647 Mdot
.18462 .42829 Mdot
.5921 .42382 Mdot
.41243 .58702 Mdot
.4819 .76418 Mdot
.42017 .56904 Mdot
.53168 .40739 Mdot
.61102 .38362 Mdot
.62074 .43133 Mdot
.57997 .36371 Mdot
.37671 .6063 Mdot
.57804 .40637 Mdot
.65228 .45051 Mdot
.39523 .37361 Mdot
.56688 .40255 Mdot
.79059 .43453 Mdot
.59814 .42177 Mdot
.70998 .57094 Mdot
.26519 .67314 Mdot
.60476 .4323 Mdot
.56571 .40621 Mdot
.63711 .5686 Mdot
.60187 .39982 Mdot
.42292 .58954 Mdot
.36865 .38873 Mdot
.41464 .5964 Mdot
.40862 .56894 Mdot
.52259 .62998 Mdot
.7192 .59606 Mdot
.5617 .3561 Mdot
.67538 .55929 Mdot
.63821 .36059 Mdot
.5364 .39279 Mdot
.47861 .55441 Mdot
.33768 .50964 Mdot
.66501 .54193 Mdot
.586 .40294 Mdot
.52122 .65532 Mdot
.53887 .69542 Mdot
.73802 .54298 Mdot
.57569 .33485 Mdot
.38569 .60899 Mdot
.37156 .5892 Mdot
.77071 .49561 Mdot
.48082 .46537 Mdot
.71148 .57886 Mdot
.39539 .48699 Mdot
.61608 .37196 Mdot
.59114 .43303 Mdot
.55654 .46066 Mdot
.49767 .6282 Mdot
.24383 .56588 Mdot
.48846 .65243 Mdot
.26272 .55048 Mdot
.42418 .57161 Mdot
.6095 .37073 Mdot
.59873 .78736 Mdot
.34297 .35527 Mdot
.37004 .38951 Mdot
.38211 .55919 Mdot
.4827 .65427 Mdot
.61168 .33882 Mdot
.70523 .22037 Mdot
.41722 .35731 Mdot
.66536 .56933 Mdot
.57492 .41461 Mdot
.51792 .66248 Mdot
.34818 .34474 Mdot
.72741 .57064 Mdot
.6162 .37547 Mdot
.56101 .68508 Mdot
.5976 .41641 Mdot
.41709 .29624 Mdot
.39133 .3687 Mdot
.25443 .60534 Mdot
.35973 .335 Mdot
.36532 .59025 Mdot
.39845 .56635 Mdot
.61634 .38755 Mdot
.5863 .15684 Mdot
.34358 .33336 Mdot
.43373 .6215 Mdot
.69813 .60254 Mdot
.23856 .57176 Mdot
.71095 .60202 Mdot
.50106 .68456 Mdot
.69355 .58265 Mdot
.55485 .66524 Mdot
.77924 .51576 Mdot
.4262 .3707 Mdot
.68537 .5849 Mdot
.25484 .31486 Mdot
.52352 .42216 Mdot
.72386 .5826 Mdot
.63907 .45307 Mdot
.43486 .42303 Mdot
.53498 .66531 Mdot
.71017 .5652 Mdot
.54514 .42815 Mdot
.525 .80516 Mdot
.40422 .56701 Mdot
.38973 .61064 Mdot
.55726 .35898 Mdot
.53007 .70332 Mdot
.33007 .34426 Mdot
.57664 .57025 Mdot
.23903 .58728 Mdot
.57689 .40989 Mdot
.61477 .37287 Mdot
.33733 .37129 Mdot
.41552 .36635 Mdot
.61256 .38284 Mdot
.44686 .21606 Mdot
.58544 .38807 Mdot
.40156 .57881 Mdot
.37753 .34873 Mdot
.36838 .39132 Mdot
.47769 .64993 Mdot
.33861 .35671 Mdot
.65441 .40213 Mdot
.38278 .54767 Mdot
.58527 .46821 Mdot
.40561 .59746 Mdot
.58457 .53674 Mdot
.50829 .63717 Mdot
.48554 .81457 Mdot
.33823 .35095 Mdot
.56526 .41539 Mdot
.34629 .38731 Mdot
.67668 .56734 Mdot
.38772 .38983 Mdot
.40691 .4054 Mdot
.62065 .38383 Mdot
.53423 .40594 Mdot
.25189 .56732 Mdot
.42798 .51014 Mdot
.38775 .37252 Mdot
.58063 .39295 Mdot
.58745 .35508 Mdot
.53664 .43646 Mdot
.48935 .51233 Mdot
.39539 .35741 Mdot
.54625 .20453 Mdot
.63631 .75377 Mdot
.38125 .36828 Mdot
.49567 .83878 Mdot
.26274 .58263 Mdot
.24493 .55855 Mdot
.44472 .61634 Mdot
.59421 .42655 Mdot
.49787 .67351 Mdot
.57729 .44532 Mdot
.5437 .34661 Mdot
.60909 .43125 Mdot
.71188 .59491 Mdot
.60765 .34733 Mdot
.25246 .58241 Mdot
.50295 .65443 Mdot
.57867 .3862 Mdot
.61432 .41916 Mdot
.24981 .55712 Mdot
.35631 .33417 Mdot
.39672 .36143 Mdot
.24933 .68521 Mdot
.68964 .59341 Mdot
.38188 .59314 Mdot
.56989 .4426 Mdot
.52152 .65335 Mdot
.49933 .66802 Mdot
.36187 .40229 Mdot
.52635 .67493 Mdot
.42654 .6068 Mdot
.59191 .39036 Mdot
.36937 .60081 Mdot
.71093 .59533 Mdot
.38812 .40327 Mdot
.56938 .44282 Mdot
.54006 .4259 Mdot
.37969 .36082 Mdot
.58578 .37118 Mdot
.72143 .57292 Mdot
.53557 .64397 Mdot
.39144 .35843 Mdot
.39373 .59945 Mdot
.47637 .64164 Mdot
.53905 .4041 Mdot
.74001 .74198 Mdot
.59522 .38049 Mdot
.57484 .43964 Mdot
.29161 .76136 Mdot
.54071 .4641 Mdot
.49974 .68755 Mdot
.35089 .39795 Mdot
.5316 .43654 Mdot
.81701 .48156 Mdot
.35795 .64096 Mdot
.56901 .66615 Mdot
.57159 .41712 Mdot
.46559 .82139 Mdot
.56822 .40966 Mdot
.41388 .76653 Mdot
.47692 .55209 Mdot
.80371 .60535 Mdot
.65676 .40751 Mdot
.41706 .6229 Mdot
.25148 .56571 Mdot
.53312 .69996 Mdot
.46543 .32332 Mdot
.59215 .37552 Mdot
.51161 .32051 Mdot
.60367 .44628 Mdot
.40628 .57965 Mdot
.53297 .47068 Mdot
.52859 .67762 Mdot
.34617 .24309 Mdot
.55713 .42112 Mdot
.38986 .35372 Mdot
.51808 .62603 Mdot
.23875 .58047 Mdot
.54547 .42992 Mdot
.67184 .56797 Mdot
.33265 .60585 Mdot
.64099 .44221 Mdot
.4031 .59829 Mdot
.58395 .4319 Mdot
.50753 .40117 Mdot
.52157 .14727 Mdot
.39637 .37244 Mdot
.36678 .57921 Mdot
.27355 .39307 Mdot
.59326 .36741 Mdot
.39892 .36471 Mdot
.36805 .38561 Mdot
.67783 .58881 Mdot
.33917 .52909 Mdot
.41262 .65051 Mdot
.67983 .75344 Mdot
.54951 .28754 Mdot
.47434 .63732 Mdot
.21912 .42861 Mdot
.55866 .39485 Mdot
.66138 .50279 Mdot
.41936 .58307 Mdot
.60758 .39394 Mdot
.57989 .26593 Mdot
.39285 .38377 Mdot
.59062 .41972 Mdot
.70862 .59267 Mdot
.30516 .56259 Mdot
.60021 .51289 Mdot
.66183 .79519 Mdot
.55139 .64219 Mdot
.57414 .46414 Mdot
.65947 .42259 Mdot
.23508 .58214 Mdot
.5431 .38771 Mdot
.52751 .7005 Mdot
.53549 .75861 Mdot
.71585 .57156 Mdot
.3421 .35208 Mdot
.25848 .58483 Mdot
.62627 .43101 Mdot
.55146 .36752 Mdot
.67243 .59229 Mdot
.55271 .43007 Mdot
.32933 .26175 Mdot
.24026 .59642 Mdot
.54344 .66008 Mdot
.40495 .38922 Mdot
.63341 .39617 Mdot
.24366 .56696 Mdot
.61793 .38119 Mdot
.32492 .4071 Mdot
.56834 .42812 Mdot
.23003 .54339 Mdot
.37442 .36319 Mdot
.40493 .60098 Mdot
.57076 .34972 Mdot
.60732 .41495 Mdot
.66746 .66241 Mdot
.54042 .34903 Mdot
.61609 .42354 Mdot
.42069 .38478 Mdot
.34421 .36143 Mdot
.35384 .39193 Mdot
.53901 .65315 Mdot
.3672 .48824 Mdot
.40449 .5869 Mdot
.59803 .45404 Mdot
.37966 .6044 Mdot
.60498 .31975 Mdot
.66789 .5827 Mdot
.54366 .82433 Mdot
.58351 .37896 Mdot
.36317 .39823 Mdot
.1995 .48263 Mdot
.37495 .34447 Mdot
.45785 .60004 Mdot
.41971 .59759 Mdot
.38705 .37907 Mdot
.59891 .40385 Mdot
.4032 .49738 Mdot
.70539 .7637 Mdot
.40409 .60654 Mdot
.54146 .45781 Mdot
.54586 .63869 Mdot
.55691 .66446 Mdot
.48401 .85883 Mdot
.40154 .56425 Mdot
.24388 .4481 Mdot
.57726 .39643 Mdot
.34205 .35997 Mdot
.38436 .58033 Mdot
.423 .58624 Mdot
.53592 .66927 Mdot
.53255 .41744 Mdot
.6044 .41611 Mdot
.27048 .5731 Mdot
.37551 .59301 Mdot
.51828 .40994 Mdot
.55621 .37697 Mdot
.36171 .80393 Mdot
.39838 .42433 Mdot
.34669 .1917 Mdot
.51988 .37764 Mdot
.59055 .27093 Mdot
.51127 .52307 Mdot
.35785 .34577 Mdot
.56353 .44305 Mdot
.61274 .45126 Mdot
.47474 .64336 Mdot
.59214 .38632 Mdot
.48752 .6376 Mdot
.36736 .57497 Mdot
.55425 .82917 Mdot
.44406 .75873 Mdot
.58459 .65083 Mdot
.60189 .38309 Mdot
.53586 .49689 Mdot
.68002 .5708 Mdot
.37205 .56118 Mdot
.34879 .36994 Mdot
.63018 .38409 Mdot
.48731 .68102 Mdot
.54247 .66693 Mdot
.37479 .38504 Mdot
.2518 .47254 Mdot
.45062 .79005 Mdot
.57995 .36293 Mdot
.52094 .69644 Mdot
.41992 .74953 Mdot
.47437 .2155 Mdot
.39009 .61915 Mdot
.71666 .57815 Mdot
.48941 .66046 Mdot
.35609 .58656 Mdot
.36017 .43303 Mdot
.37618 .37803 Mdot
.33423 .36546 Mdot
.64819 .71242 Mdot
.50659 .67974 Mdot
.68534 .56931 Mdot
.46057 .44287 Mdot
.42451 .44958 Mdot
.71465 .59075 Mdot
.48729 .65698 Mdot
.34554 .35109 Mdot
.35192 .37452 Mdot
.36697 .38782 Mdot
.33968 .25102 Mdot
.38232 .40945 Mdot
.49872 .18026 Mdot
.57394 .35958 Mdot
.39428 .24855 Mdot
.56886 .41216 Mdot
.39795 .61683 Mdot
.39012 .36737 Mdot
.46622 .52276 Mdot
.62281 .36934 Mdot
.66956 .78714 Mdot
.57767 .41597 Mdot
.36054 .5535 Mdot
.59626 .42699 Mdot
.34087 .27476 Mdot
.3448 .39609 Mdot
.58505 .40189 Mdot
.43192 .6149 Mdot
.70423 .58066 Mdot
.31471 .35027 Mdot
.60608 .42985 Mdot
.29268 .54358 Mdot
.60146 .46848 Mdot
.43533 .80096 Mdot
.64229 .62348 Mdot
.66575 .56345 Mdot
.61876 .46032 Mdot
.48208 .6253 Mdot
.32696 .33198 Mdot
.38001 .26124 Mdot
.40219 .6062 Mdot
.6762 .30159 Mdot
.53962 .66112 Mdot
.53527 .47174 Mdot
.64249 .38924 Mdot
.7037 .55745 Mdot
.325 .33944 Mdot
.40096 .57641 Mdot
.58639 .37367 Mdot
.56919 .44689 Mdot
.71748 .68873 Mdot
.37107 .2629 Mdot
.52051 .40206 Mdot
.70217 .60847 Mdot
.5574 .20973 Mdot
.59556 .43586 Mdot
.56419 .68014 Mdot
.36092 .4095 Mdot
.64918 .37134 Mdot
.53193 .2007 Mdot
.5818 .38981 Mdot
.38424 .38187 Mdot
.33729 .35286 Mdot
.21872 .5237 Mdot
.66633 .57227 Mdot
.56847 .42839 Mdot
.68502 .66046 Mdot
.55939 .42477 Mdot
.40426 .58323 Mdot
.52858 .41901 Mdot
.53066 .65821 Mdot
.33758 .49708 Mdot
.5355 .64741 Mdot
.54336 .43831 Mdot
.35734 .37922 Mdot
.39614 .5759 Mdot
.63722 .72807 Mdot
.55838 .57261 Mdot
.5102 .18176 Mdot
.33206 .61164 Mdot
.69978 .5588 Mdot
.72513 .58867 Mdot
.42475 .56483 Mdot
.58612 .40914 Mdot
.50952 .54532 Mdot
.64951 .40372 Mdot
.59838 .42929 Mdot
.60283 .43952 Mdot
.35031 .58631 Mdot
.41642 .60065 Mdot
.50783 .67092 Mdot
.61045 .38119 Mdot
.5807 .39407 Mdot
.37765 .37016 Mdot
.70513 .58453 Mdot
.54467 .65707 Mdot
.68285 .58663 Mdot
.50914 .65408 Mdot
.44593 .84697 Mdot
.53287 .44218 Mdot
.70482 .57962 Mdot
.41383 .56193 Mdot
.36798 .40268 Mdot
.26184 .5583 Mdot
.49836 .68058 Mdot
.52541 .67841 Mdot
.57643 .40707 Mdot
.3907 .39902 Mdot
.39758 .38996 Mdot
.6872 .55555 Mdot
.37541 .58277 Mdot
.55213 .4415 Mdot
.54527 .38814 Mdot
.75922 .63516 Mdot
.4809 .63174 Mdot
.46819 .20664 Mdot
.23912 .51322 Mdot
.58653 .40808 Mdot
.40206 .38317 Mdot
.61567 .41061 Mdot
.53872 .78197 Mdot
.40183 .40443 Mdot
.60438 .35842 Mdot
.47926 .44964 Mdot
.51075 .62978 Mdot
.20071 .55114 Mdot
.58072 .35075 Mdot
.3124 .60911 Mdot
.54939 .40822 Mdot
.24562 .74128 Mdot
.23602 .38122 Mdot
.61761 .44107 Mdot
.58699 .36368 Mdot
.71253 .73139 Mdot
.57353 .40022 Mdot
.25956 .58172 Mdot
.54322 .35339 Mdot
.39445 .35855 Mdot
.53031 .54232 Mdot
.48416 .57174 Mdot
.67628 .5925 Mdot
.52258 .65015 Mdot
.71207 .43324 Mdot
.69479 .59837 Mdot
.36871 .35259 Mdot
.599 .36024 Mdot
.64567 .31 Mdot
.4857 .68796 Mdot
.64463 .38392 Mdot
.4051 .58211 Mdot
.4803 .56769 Mdot
.49137 .64252 Mdot
.39728 .60185 Mdot
.61159 .4414 Mdot
.81147 .42828 Mdot
.56601 .58333 Mdot
.19347 .62121 Mdot
.38789 .58302 Mdot
.41866 .58683 Mdot
.34276 .478 Mdot
.67616 .59226 Mdot
.73477 .66908 Mdot
.59879 .50032 Mdot
.42321 .60563 Mdot
.75155 .46039 Mdot
.50334 .69788 Mdot
.33513 .53045 Mdot
.339 .38898 Mdot
.53762 .44742 Mdot
.60134 .40647 Mdot
.37638 .57804 Mdot
.49296 .34771 Mdot
.3005 .39283 Mdot
.4072 .60492 Mdot
.6625 .42838 Mdot
.31239 .5638 Mdot
.25786 .56815 Mdot
.26996 .57664 Mdot
.69492 .60373 Mdot
.55937 .7339 Mdot
.3639 .36449 Mdot
.70819 .55804 Mdot
.22375 .55788 Mdot
.57123 .43155 Mdot
.3755 .59558 Mdot
.2706 .56078 Mdot
.39354 .59245 Mdot
.70395 .57027 Mdot
.6655 .57172 Mdot
.39549 .37341 Mdot
.35452 .35119 Mdot
.63858 .2658 Mdot
.7766 .47842 Mdot
.56931 .40279 Mdot
.57558 .2944 Mdot
.38019 .4069 Mdot
.34801 .29492 Mdot
.66959 .56571 Mdot
.70628 .58759 Mdot
.43275 .26955 Mdot
.53596 .41679 Mdot
.46291 .76125 Mdot
.60264 .43262 Mdot
.71881 .48183 Mdot
.63798 .38169 Mdot
.53314 .67163 Mdot
.56086 .40736 Mdot
.2848 .69253 Mdot
.57061 .381 Mdot
.61118 .43322 Mdot
.49523 .65579 Mdot
.55777 .35253 Mdot
.5329 .65857 Mdot
.53138 .41201 Mdot
.68681 .60896 Mdot
.5213 .65312 Mdot
.78209 .58192 Mdot
.62216 .55071 Mdot
.24247 .57219 Mdot
.69461 .60097 Mdot
.67503 .56207 Mdot
.79112 .41922 Mdot
.34876 .3647 Mdot
.38906 .43916 Mdot
.58603 .41039 Mdot
.51323 .70115 Mdot
.38338 .60287 Mdot
.58254 .39114 Mdot
.6115 .4542 Mdot
.57013 .35175 Mdot
.39206 .37993 Mdot
.48741 .66367 Mdot
.69934 .5753 Mdot
.53953 .69312 Mdot
.61325 .61715 Mdot
.55712 .67877 Mdot
.4991 .43166 Mdot
.52 .38158 Mdot
.65818 .34833 Mdot
.58621 .2854 Mdot
.37279 .22233 Mdot
.3728 .38028 Mdot
.25205 .57583 Mdot
.67366 .59144 Mdot
.35406 .44849 Mdot
.35672 .38987 Mdot
.5216 .67983 Mdot
.59767 .41627 Mdot
.66463 .42506 Mdot
.58093 .51057 Mdot
.40914 .33888 Mdot
.80747 .48554 Mdot
.50326 .64214 Mdot
.26425 .56941 Mdot
.35268 .49272 Mdot
.4409 .382 Mdot
.47004 .52647 Mdot
.61129 .41435 Mdot
.67236 .56415 Mdot
.34809 .34479 Mdot
.67673 .71063 Mdot
.37165 .58117 Mdot
.42611 .50866 Mdot
.60013 .38303 Mdot
.21761 .45388 Mdot
.35759 .3791 Mdot
.71082 .58831 Mdot
.37686 .57726 Mdot
.66705 .57115 Mdot
.26095 .58475 Mdot
.26472 .69518 Mdot
.54998 .42466 Mdot
.6187 .42123 Mdot
.43426 .59049 Mdot
.362 .36661 Mdot
.5363 .71582 Mdot
.68634 .71577 Mdot
.52214 .6956 Mdot
.49932 .54676 Mdot
.35982 .34401 Mdot
.30566 .31993 Mdot
.55006 .67671 Mdot
.3946 .55676 Mdot
.49929 .53527 Mdot
.39309 .55885 Mdot
.60025 .43679 Mdot
.37629 .39961 Mdot
.40019 .56384 Mdot
.67729 .68348 Mdot
.42259 .82855 Mdot
.30886 .35901 Mdot
.59374 .37083 Mdot
.55312 .82697 Mdot
.33877 .78213 Mdot
.53343 .3233 Mdot
.3746 .6001 Mdot
.61844 .39497 Mdot
.58024 .36227 Mdot
.55782 .41853 Mdot
.38052 .56604 Mdot
.59373 .62335 Mdot
.53687 .67836 Mdot
.57774 .42118 Mdot
.67457 .56726 Mdot
.52732 .66476 Mdot
.4981 .62312 Mdot
.54117 .69787 Mdot
.40901 .39946 Mdot
.59025 .35953 Mdot
.32003 .52988 Mdot
.27229 .76444 Mdot
.41489 .59923 Mdot
.24228 .57265 Mdot
.61275 .43715 Mdot
.62458 .2276 Mdot
.35501 .39292 Mdot
.52193 .69482 Mdot
.60931 .39468 Mdot
.64236 .64331 Mdot
.29006 .5672 Mdot
.50662 .64682 Mdot
.34974 .3676 Mdot
.53295 .32414 Mdot
.59134 .38628 Mdot
.54733 .40892 Mdot
.36423 .359 Mdot
.22526 .66476 Mdot
.34203 .50469 Mdot
.61443 .41431 Mdot
.404 .60185 Mdot
.49611 .13654 Mdot
.55347 .36416 Mdot
.3804 .32576 Mdot
.23858 .57035 Mdot
.25835 .52994 Mdot
.48364 .20723 Mdot
.51184 .36991 Mdot
.57968 .80791 Mdot
.73412 .36608 Mdot
.53101 .82793 Mdot
.68978 .46732 Mdot
.3754 .72315 Mdot
.39523 .84846 Mdot
.43045 .61863 Mdot
.34856 .27861 Mdot
.78054 .64944 Mdot
.26966 .47537 Mdot
.62566 .61089 Mdot
.4153 .67307 Mdot
.65157 .63671 Mdot
.20227 .3652 Mdot
.55389 .68017 Mdot
.69856 .50248 Mdot
.56031 .44377 Mdot
.33103 .77412 Mdot
.39402 .23575 Mdot
.38055 .20927 Mdot
.5266 .81969 Mdot
.68199 .65289 Mdot
.74426 .72493 Mdot
.48264 .80978 Mdot
.67518 .31512 Mdot
.5325 .50632 Mdot
.47569 .696 Mdot
.44659 .44066 Mdot
.71638 .41734 Mdot
.6365 .34359 Mdot
.27888 .66722 Mdot
.57699 .66862 Mdot
.57941 .23808 Mdot
.48913 .14654 Mdot
.49579 .68059 Mdot
.36439 .41154 Mdot
.75488 .65486 Mdot
.32417 .32656 Mdot
.44902 .5906 Mdot
.5808 .80775 Mdot
.36197 .80725 Mdot
.34213 .27275 Mdot
.21085 .59214 Mdot
.44426 .30028 Mdot
.75244 .31341 Mdot
.58192 .52234 Mdot
.34035 .34153 Mdot
.40415 .71099 Mdot
.42525 .44886 Mdot
.50928 .72148 Mdot
.3185 .28585 Mdot
.72319 .55995 Mdot
.80211 .54262 Mdot
.3515 .36867 Mdot
.49298 .21527 Mdot
.2391 .56189 Mdot
.2268 .55945 Mdot
.53243 .71114 Mdot
.55068 .77975 Mdot
.29548 .56597 Mdot
.30418 .54274 Mdot
.19644 .45372 Mdot
.71209 .772 Mdot
.74539 .40799 Mdot
.55422 .7595 Mdot
.35527 .55009 Mdot
.73704 .37239 Mdot
.31499 .48948 Mdot
.77227 .44747 Mdot
.43144 .43745 Mdot
.83491 .61496 Mdot
.26108 .71965 Mdot
.77976 .68897 Mdot
.35472 .42131 Mdot
.5227 .41776 Mdot
.58577 .76806 Mdot
.53337 .294 Mdot
.66863 .55335 Mdot
.69015 .78354 Mdot
.68241 .55038 Mdot
.40593 .41578 Mdot
.26173 .46903 Mdot
.3475 .25414 Mdot
.57427 .70252 Mdot
.67888 .60994 Mdot
.65003 .41752 Mdot
.88488 .52891 Mdot
.60514 .8048 Mdot
.22829 .5255 Mdot
.35207 .80012 Mdot
.42382 .631 Mdot
.46717 .65638 Mdot
.37066 .57118 Mdot
.40187 .83819 Mdot
.36237 .39146 Mdot
.28666 .78178 Mdot
.39425 .82948 Mdot
.28493 .34618 Mdot
.90094 .48945 Mdot
.2024 .39685 Mdot
.40493 .24193 Mdot
.70596 .33831 Mdot
.81458 .53849 Mdot
.31915 .46673 Mdot
.28164 .33303 Mdot
.4587 .62538 Mdot
.21963 .66755 Mdot
.45141 .84082 Mdot
.74488 .47506 Mdot
.53862 .62161 Mdot
.28232 .47093 Mdot
.60251 .53275 Mdot
.38336 .32952 Mdot
.63557 .58627 Mdot
.64565 .52412 Mdot
.76371 .70525 Mdot
.61933 .24097 Mdot
.62645 .17196 Mdot
.69757 .4694 Mdot
.27538 .30013 Mdot
.47536 .79154 Mdot
.77318 .57959 Mdot
.31443 .40018 Mdot
.28818 .50941 Mdot
.5598 .46995 Mdot
.38005 .48249 Mdot
.64753 .45912 Mdot
.73507 .56998 Mdot
.35491 .48428 Mdot
.37963 .7594 Mdot
.71311 .46661 Mdot
.66118 .75824 Mdot
.50506 .48626 Mdot
.40936 .38723 Mdot
.77653 .4241 Mdot
.74712 .43264 Mdot
.37953 .80689 Mdot
.27267 .39459 Mdot
.1971 .63294 Mdot
.27904 .38449 Mdot
.64951 .40749 Mdot
.35228 .28224 Mdot
.64562 .35049 Mdot
.7624 .44324 Mdot
.60932 .35395 Mdot
.19189 .47096 Mdot
.30155 .77087 Mdot
.59344 .25927 Mdot
.71728 .43977 Mdot
.60407 .28517 Mdot
.2315 .68566 Mdot
.5982 .76891 Mdot
.23703 .39693 Mdot
.40608 .32488 Mdot
.86939 .55852 Mdot
.51809 .66898 Mdot
.75392 .46825 Mdot
.35899 .56589 Mdot
.64966 .71632 Mdot
.81045 .61623 Mdot
.28911 .37542 Mdot
.29189 .76471 Mdot
.30031 .5112 Mdot
.56108 .71511 Mdot
.33655 .54124 Mdot
.46627 .61952 Mdot
.63033 .29073 Mdot
.55115 .3612 Mdot
.65442 .33433 Mdot
.71838 .56386 Mdot
.51098 .29611 Mdot
.62048 .75602 Mdot
.34031 .6573 Mdot
.49428 .40005 Mdot
.35402 .6792 Mdot
.26747 .56992 Mdot
.40643 .50383 Mdot
.47426 .85865 Mdot
.51964 .37093 Mdot
.22118 .36572 Mdot
.25595 .70935 Mdot
.49106 .54136 Mdot
.58052 .72114 Mdot
.22709 .49276 Mdot
.8103 .65364 Mdot
.35214 .81331 Mdot
.36498 .77664 Mdot
.56306 .82666 Mdot
.15582 .57811 Mdot
.83782 .56554 Mdot
.45659 .33926 Mdot
.35203 .57672 Mdot
.1111 .5886 Mdot
.5348 .68721 Mdot
.68086 .29948 Mdot
.53612 .29042 Mdot
.63974 .65268 Mdot
.33416 .32734 Mdot
.48398 .41832 Mdot
.35137 .62547 Mdot
.38917 .33753 Mdot
.64785 .42177 Mdot
.65228 .81573 Mdot
.83984 .61173 Mdot
.672 .80204 Mdot
.26782 .70096 Mdot
.54946 .83371 Mdot
.76074 .68519 Mdot
.48704 .17964 Mdot
.73655 .67415 Mdot
.52906 .4158 Mdot
.75803 .50038 Mdot
.20892 .39217 Mdot
.54613 .71191 Mdot
.22142 .59077 Mdot
.36618 .42158 Mdot
.81709 .62943 Mdot
.48749 .86446 Mdot
.45625 .26964 Mdot
.5458 .22197 Mdot
.63513 .53517 Mdot
.76711 .46461 Mdot
.67665 .34723 Mdot
.2797 .65249 Mdot
.41561 .80752 Mdot
.76988 .67559 Mdot
.73861 .44375 Mdot
.40136 .67875 Mdot
.36467 .76784 Mdot
.26405 .33197 Mdot
.51126 .80277 Mdot
.76803 .64644 Mdot
.28027 .3599 Mdot
.45249 .37633 Mdot
.29661 .38642 Mdot
.27006 .63696 Mdot
.50125 .75298 Mdot
.73624 .4031 Mdot
.51472 .6357 Mdot
.74792 .48154 Mdot
.46377 .48537 Mdot
.74396 .66912 Mdot
.74489 .37134 Mdot
.73987 .47875 Mdot
.38256 .77902 Mdot
.61912 .8236 Mdot
.20187 .60278 Mdot
.83087 .45034 Mdot
.30224 .61338 Mdot
.63101 .47104 Mdot
.5277 .39648 Mdot
.26696 .73457 Mdot
.59415 .84373 Mdot
.30561 .78099 Mdot
.21611 .45009 Mdot
.66874 .68543 Mdot
.36686 .60532 Mdot
.75002 .34734 Mdot
.32116 .63627 Mdot
.42384 .81377 Mdot
.36943 .46283 Mdot
.44466 .62018 Mdot
.30862 .51181 Mdot
.66963 .30089 Mdot
.72235 .34355 Mdot
.51285 .22744 Mdot
.60023 .33545 Mdot
.43551 .22386 Mdot
.34731 .3965 Mdot
.21999 .43595 Mdot
.76894 .45247 Mdot
.51727 .6656 Mdot
.77934 .61336 Mdot
.6659 .34267 Mdot
.54084 .46506 Mdot
.51337 .75025 Mdot
.37894 .32874 Mdot
.5861 .28247 Mdot
.46114 .64376 Mdot
.41481 .85228 Mdot
.2178 .39785 Mdot
.66642 .32259 Mdot
.76059 .40352 Mdot
.74411 .64156 Mdot
.34891 .50749 Mdot
.41552 .55928 Mdot
.51449 .81758 Mdot
.61115 .57065 Mdot
.77148 .41698 Mdot
.44438 .22067 Mdot
.66323 .73038 Mdot
.61583 .45102 Mdot
.21821 .50823 Mdot
.54885 .18953 Mdot
.41848 .50894 Mdot
.42289 .40775 Mdot
.42121 .36098 Mdot
.19945 .3394 Mdot
.2991 .70148 Mdot
.26127 .38021 Mdot
.52292 .81033 Mdot
.38378 .56136 Mdot
.41527 .37575 Mdot
.73939 .4899 Mdot
.61381 .71246 Mdot
.58459 .22323 Mdot
.51307 .76205 Mdot
.69214 .36062 Mdot
.31717 .64501 Mdot
.55912 .82343 Mdot
.67312 .77579 Mdot
.5347 .1461 Mdot
.37627 .33827 Mdot
.61627 .7468 Mdot
.63823 .73675 Mdot
.35127 .3397 Mdot
.4018 .33457 Mdot
.56006 .50939 Mdot
.51865 .83874 Mdot
.40149 .47107 Mdot
.27122 .61846 Mdot
.49953 .53681 Mdot
.62163 .63311 Mdot
.68928 .70613 Mdot
.72867 .39941 Mdot
.52964 .80443 Mdot
.49447 .2237 Mdot
.8306 .52274 Mdot
.6669 .36852 Mdot
.64949 .26465 Mdot
.75011 .34668 Mdot
.55723 .52191 Mdot
.3219 .2878 Mdot
.39878 .76408 Mdot
.56154 .41611 Mdot
.70459 .78088 Mdot
.37778 .80055 Mdot
.36215 .47347 Mdot
.45648 .66212 Mdot
.55127 .39165 Mdot
.58035 .35871 Mdot
.46536 .36245 Mdot
.25005 .52259 Mdot
.84811 .5156 Mdot
.70442 .47946 Mdot
.64051 .46617 Mdot
.43777 .21931 Mdot
.22219 .36493 Mdot
.56747 .77163 Mdot
.44876 .79937 Mdot
.4473 .48512 Mdot
.20973 .39442 Mdot
.43016 .52692 Mdot
.26093 .61741 Mdot
.32256 .67361 Mdot
.75294 .69204 Mdot
.5322 .48603 Mdot
.26805 .51369 Mdot
.72651 .67051 Mdot
.60873 .43906 Mdot
.25171 .47301 Mdot
.49501 .80486 Mdot
.67367 .20833 Mdot
.30736 .47912 Mdot
.62891 .83113 Mdot
.65744 .34278 Mdot
.28128 .51787 Mdot
.82166 .60688 Mdot
.76119 .26976 Mdot
.27363 .65945 Mdot
.75071 .71984 Mdot
.37027 .51862 Mdot
.53107 .8108 Mdot
.40565 .62227 Mdot
.4597 .45705 Mdot
.54209 .30628 Mdot
.5118 .839 Mdot
.58459 .73803 Mdot
.5549 .78863 Mdot
.4596 .35747 Mdot
.55083 .83949 Mdot
.42713 .4362 Mdot
.21746 .32189 Mdot
.56717 .67753 Mdot
.17736 .46761 Mdot
.42182 .32746 Mdot
.68592 .39156 Mdot
.74771 .45829 Mdot
.26739 .28188 Mdot
.43644 .18574 Mdot
.47146 .34397 Mdot
.74191 .52298 Mdot
.23326 .50163 Mdot
.7575 .39707 Mdot
.42414 .81864 Mdot
.20514 .35518 Mdot
.66392 .72267 Mdot
.24571 .42212 Mdot
.24749 .6874 Mdot
.24265 .52515 Mdot
.32974 .70145 Mdot
.54908 .7643 Mdot
.23808 .63777 Mdot
.69459 .36999 Mdot
.29128 .20105 Mdot
.50908 .59781 Mdot
.56851 .51013 Mdot
.79788 .66317 Mdot
.41082 .80687 Mdot
.35461 .45203 Mdot
.31296 .28426 Mdot
.68614 .28012 Mdot
.78016 .52005 Mdot
.6091 .43096 Mdot
.55867 .83962 Mdot
.78602 .55627 Mdot
.71659 .75873 Mdot
.21348 .67923 Mdot
.44597 .23028 Mdot
.50275 .40938 Mdot
.47276 .6224 Mdot
.60841 .51744 Mdot
.73435 .52351 Mdot
.76626 .69112 Mdot
.66762 .28323 Mdot
.55746 .56757 Mdot
.37356 .71506 Mdot
.47914 .7738 Mdot
.59809 .48951 Mdot
.19611 .41363 Mdot
.24663 .5116 Mdot
.70447 .45466 Mdot
.3496 .7591 Mdot
.75882 .45782 Mdot
.47422 .20724 Mdot
.75143 .36033 Mdot
.30693 .4336 Mdot
.39275 .63927 Mdot
.47807 .65531 Mdot
.70245 .73401 Mdot
.45866 .78984 Mdot
.19164 .47634 Mdot
.83161 .47441 Mdot
.28309 .50425 Mdot
.69778 .5104 Mdot
.65229 .75234 Mdot
.31271 .46243 Mdot
.47651 .70171 Mdot
.71747 .33706 Mdot
.64289 .26336 Mdot
.42008 .77645 Mdot
.49651 .38003 Mdot
.45533 .84421 Mdot
.73362 .40494 Mdot
.70523 .71512 Mdot
.61857 .54303 Mdot
.53936 .27362 Mdot
.39874 .27435 Mdot
.79593 .57409 Mdot
.44562 .5237 Mdot
.88003 .53807 Mdot
.32719 .35559 Mdot
.71484 .76958 Mdot
.38248 .59562 Mdot
.5842 .17488 Mdot
.42036 .79221 Mdot
.45872 .497 Mdot
.50079 .52599 Mdot
.21645 .51167 Mdot
.29664 .54989 Mdot
.24051 .68634 Mdot
.29264 .3769 Mdot
.55461 .68937 Mdot
.57452 .57817 Mdot
.27321 .62426 Mdot
.66054 .76564 Mdot
.54025 .44303 Mdot
.5754 .70409 Mdot
.57103 .52407 Mdot
.44499 .55905 Mdot
.27198 .7376 Mdot
.40376 .75604 Mdot
.65594 .37922 Mdot
.76949 .46615 Mdot
.78202 .668 Mdot
.3981 .82595 Mdot
.3129 .41275 Mdot
.65027 .45649 Mdot
.3757 .54834 Mdot
.80573 .59829 Mdot
.60606 .79989 Mdot
.45357 .76176 Mdot
.3317 .53048 Mdot
.744 .41204 Mdot
.70396 .79956 Mdot
.83786 .61274 Mdot
.8371 .47615 Mdot
.50444 .54223 Mdot
.42364 .42277 Mdot
.62876 .23245 Mdot
.70105 .71894 Mdot
.17085 .48985 Mdot
.37382 .7899 Mdot
.75452 .46289 Mdot
.7248 .2522 Mdot
.39802 .21093 Mdot
.60284 .61205 Mdot
.40031 .27553 Mdot
.55968 .28549 Mdot
.4202 .6248 Mdot
.77452 .52983 Mdot
.59785 .58156 Mdot
.44666 .59208 Mdot
.23566 .5038 Mdot
.30507 .54913 Mdot
.70933 .71123 Mdot
.56988 .20798 Mdot
.66711 .43764 Mdot
.62624 .78007 Mdot
.42764 .37507 Mdot
.67002 .71484 Mdot
.74406 .64448 Mdot
.59835 .58984 Mdot
.54018 .69018 Mdot
.61138 .33159 Mdot
.38053 .50265 Mdot
.40434 .51478 Mdot
.79425 .37323 Mdot
.69103 .54764 Mdot
.33273 .39628 Mdot
.35709 .2338 Mdot
.38361 .34271 Mdot
.57456 .85168 Mdot
.28091 .65346 Mdot
.42482 .22509 Mdot
.48148 .5997 Mdot
.40682 .69394 Mdot
.7896 .33984 Mdot
.67249 .30866 Mdot
.64457 .58605 Mdot
.43875 .40803 Mdot
.34257 .38336 Mdot
.48117 .60573 Mdot
.2367 .59235 Mdot
.51805 .2181 Mdot
.21799 .3602 Mdot
.75004 .63839 Mdot
.34748 .33628 Mdot
.59954 .61597 Mdot
.60101 .30907 Mdot
.46204 .85349 Mdot
.54302 .69402 Mdot
.864 .57158 Mdot
.51792 .3856 Mdot
.82603 .56933 Mdot
.27584 .7438 Mdot
.33498 .49439 Mdot
.51097 .54873 Mdot
.44336 .67712 Mdot
.57691 .45857 Mdot
.66995 .4366 Mdot
.35393 .35672 Mdot
.72599 .68336 Mdot
.69726 .58541 Mdot
.79818 .4773 Mdot
.41027 .55514 Mdot
.2802 .31067 Mdot
.19968 .41641 Mdot
.35627 .4086 Mdot
.61523 .58429 Mdot
.59022 .75162 Mdot
.50149 .4918 Mdot
.56851 .52418 Mdot
.71326 .72873 Mdot
.58674 .23147 Mdot
.34184 .34194 Mdot
.83519 .48196 Mdot
.68044 .52275 Mdot
.37125 .83098 Mdot
.55837 .32135 Mdot
.57431 .5197 Mdot
.50632 .49138 Mdot
.21906 .49925 Mdot
.4927 .20725 Mdot
.43943 .80391 Mdot
.776 .43252 Mdot
.46221 .43818 Mdot
.7409 .48136 Mdot
.64855 .36021 Mdot
.36785 .71432 Mdot
.17823 .45 Mdot
.73753 .26602 Mdot
.4268 .29874 Mdot
.31766 .5036 Mdot
.42963 .37093 Mdot
.22009 .36912 Mdot
.3245 .36694 Mdot
.61086 .64988 Mdot
.5846 .2419 Mdot
.41971 .79316 Mdot
.41525 .84449 Mdot
.37826 .80577 Mdot
.63441 .51187 Mdot
.46876 .7715 Mdot
.71163 .3489 Mdot
.56533 .31596 Mdot
.46965 .51507 Mdot
.58593 .45836 Mdot
.58339 .48979 Mdot
.32594 .43849 Mdot
.19765 .48306 Mdot
.51746 .46039 Mdot
.5021 .83435 Mdot
.36709 .82662 Mdot
.59213 .82582 Mdot
.49894 .74981 Mdot
.4091 .40257 Mdot
.81868 .64153 Mdot
.45835 .19804 Mdot
.41592 .81972 Mdot
.42705 .32955 Mdot
.18506 .363 Mdot
.80299 .62905 Mdot
.38882 .76438 Mdot
.28398 .33886 Mdot
.19649 .56311 Mdot
.28071 .74211 Mdot
.21623 .32402 Mdot
.70247 .38634 Mdot
.2598 .72392 Mdot
.88361 .52722 Mdot
.43765 .32694 Mdot
.29977 .54456 Mdot
.38823 .27047 Mdot
.69957 .34223 Mdot
.21696 .34854 Mdot
.52695 .41234 Mdot
.54798 .64763 Mdot
.63471 .62267 Mdot
.75363 .45203 Mdot
.56902 .32741 Mdot
.22384 .3359 Mdot
.73022 .52351 Mdot
.69461 .50396 Mdot
.62235 .73543 Mdot
.78535 .64576 Mdot
.50778 .21017 Mdot
.66096 .4222 Mdot
.38942 .42563 Mdot
.70863 .60086 Mdot
.70764 .42244 Mdot
.55481 .38286 Mdot
.47232 .55037 Mdot
.56784 .50618 Mdot
.64761 .8205 Mdot
.62072 .6795 Mdot
.58486 .65896 Mdot
.40593 .34715 Mdot
.2408 .51801 Mdot
.59239 .77976 Mdot
.26661 .47269 Mdot
.24213 .31418 Mdot
.61624 .24465 Mdot
.56959 .81895 Mdot
.29981 .51799 Mdot
.72747 .43761 Mdot
.76963 .34103 Mdot
.40876 .61807 Mdot
.53657 .3043 Mdot
.75751 .69574 Mdot
.26238 .48713 Mdot
.424 .39254 Mdot
.35492 .74695 Mdot
.39054 .72862 Mdot
.25228 .49247 Mdot
.2544 .70666 Mdot
.63041 .74735 Mdot
.42324 .25481 Mdot
.65966 .78061 Mdot
.52525 .62816 Mdot
.73984 .4486 Mdot
.32204 .71938 Mdot
.21053 .35446 Mdot
.49635 .48278 Mdot
.47037 .84245 Mdot
.47358 .51747 Mdot
.79348 .55817 Mdot
.5478 .41931 Mdot
.53964 .20179 Mdot
.20579 .48753 Mdot
.34741 .75258 Mdot
.26385 .38954 Mdot
.39553 .41348 Mdot
.20302 .43614 Mdot
.47642 .69249 Mdot
.78671 .53625 Mdot
.69939 .41495 Mdot
.32392 .31328 Mdot
.65104 .53755 Mdot
.2362 .55916 Mdot
.51895 .38995 Mdot
.80806 .53191 Mdot
.50079 .77074 Mdot
.51626 .31849 Mdot
.45459 .33726 Mdot
.70126 .73648 Mdot
.52628 .76509 Mdot
.18592 .48136 Mdot
.45508 .34752 Mdot
.22208 .55067 Mdot
.4194 .20105 Mdot
.26301 .44651 Mdot
.58184 .35216 Mdot
.61111 .64815 Mdot
.3972 .3573 Mdot
.66506 .76573 Mdot
.34095 .41846 Mdot
.78015 .58366 Mdot
.4215 .49209 Mdot
.58038 .76715 Mdot
.60464 .54532 Mdot
.27935 .7454 Mdot
.19618 .5637 Mdot
.76965 .4513 Mdot
.43835 .585 Mdot
.36312 .52304 Mdot
.30421 .47064 Mdot
.47074 .82695 Mdot
.30144 .41151 Mdot
.64442 .30834 Mdot
.31056 .5066 Mdot
.58884 .26798 Mdot
.23108 .69825 Mdot
.78151 .48189 Mdot
.46674 .51443 Mdot
.66793 .33001 Mdot
.22173 .56714 Mdot
.25861 .55729 Mdot
.63514 .66248 Mdot
.49024 .19806 Mdot
.55495 .6215 Mdot
.54185 .56883 Mdot
.51836 .40611 Mdot
.61862 .22421 Mdot
.64311 .78442 Mdot
.34874 .44553 Mdot
.46855 .50435 Mdot
.72054 .67264 Mdot
.79257 .53614 Mdot
.44242 .12962 Mdot
.69494 .79107 Mdot
.54696 .4193 Mdot
.51215 .53568 Mdot
.79494 .48161 Mdot
.4883 .63821 Mdot
.52562 .2262 Mdot
.69361 .74424 Mdot
.42267 .59533 Mdot
.66648 .69378 Mdot
.23996 .59793 Mdot
.2109 .50671 Mdot
.79234 .58417 Mdot
.37835 .6152 Mdot
.59185 .85114 Mdot
.36453 .78291 Mdot
.21004 .47881 Mdot
.37074 .14775 Mdot
.20527 .45633 Mdot
.4106 .43799 Mdot
.57483 .74673 Mdot
.61358 .8266 Mdot
.49963 .54118 Mdot
.64814 .7129 Mdot
.45972 .33511 Mdot
.77224 .44399 Mdot
.71456 .48041 Mdot
.24464 .42316 Mdot
.21398 .42365 Mdot
.22568 .31007 Mdot
.40813 .69306 Mdot
.80629 .38237 Mdot
.47944 .21961 Mdot
.67141 .78106 Mdot
.27339 .65665 Mdot
.7119 .24112 Mdot
.40365 .83838 Mdot
.75334 .5072 Mdot
.23714 .32812 Mdot
.57846 .73386 Mdot
.80379 .4577 Mdot
.58172 .1983 Mdot
.25941 .66606 Mdot
.60104 .23927 Mdot
.38391 .68551 Mdot
.26379 .41843 Mdot
.74464 .48084 Mdot
.57846 .2754 Mdot
.46928 .51906 Mdot
.73261 .72827 Mdot
.27913 .28003 Mdot
.75804 .4085 Mdot
.68582 .68748 Mdot
.81269 .47025 Mdot
.61633 .78867 Mdot
.51763 .78827 Mdot
.52689 .52251 Mdot
.87466 .5021 Mdot
.76252 .70613 Mdot
.27283 .46083 Mdot
.5713 .35959 Mdot
.38595 .84272 Mdot
.55957 .54363 Mdot
.46527 .34075 Mdot
.30459 .75395 Mdot
.70023 .47942 Mdot
.55839 .49992 Mdot
.55525 .36155 Mdot
.70487 .32717 Mdot
.30625 .32544 Mdot
.57702 .27831 Mdot
.74595 .62585 Mdot
.76288 .40763 Mdot
.28124 .28154 Mdot
.8184 .54902 Mdot
.53096 .33316 Mdot
.36742 .34392 Mdot
.62838 .82499 Mdot
.66744 .31251 Mdot
.67341 .37293 Mdot
.39811 .25257 Mdot
.29885 .40147 Mdot
.39458 .64953 Mdot
.63811 .4655 Mdot
.35185 .50595 Mdot
.74797 .45546 Mdot
.6867 .73024 Mdot
.53792 .31042 Mdot
.90384 .48494 Mdot
.27843 .74909 Mdot
.33114 .3417 Mdot
.48865 .32405 Mdot
.6036 .59821 Mdot
.60078 .81984 Mdot
.39188 .67594 Mdot
.74413 .64247 Mdot
.34466 .2338 Mdot
.78656 .43025 Mdot
.63795 .41073 Mdot
.26892 .7044 Mdot
.42691 .83876 Mdot
.30118 .25236 Mdot
.45541 .84362 Mdot
.50272 .42545 Mdot
.52307 .44128 Mdot
.66748 .17858 Mdot
.54362 .81679 Mdot
.51175 .37135 Mdot
.29226 .33504 Mdot
.34233 .31859 Mdot
.5473 .43969 Mdot
.26484 .59339 Mdot
.72479 .38552 Mdot
.71053 .48915 Mdot
.51615 .83782 Mdot
.41311 .35585 Mdot
.49247 .54836 Mdot
.35461 .58228 Mdot
.48857 .52453 Mdot
.66033 .38565 Mdot
.40728 .56459 Mdot
.70949 .49798 Mdot
.55322 .54739 Mdot
.32906 .60227 Mdot
.69742 .38135 Mdot
.22451 .61175 Mdot
.68586 .42281 Mdot
.63378 .5176 Mdot
.4491 .36437 Mdot
.43655 .18522 Mdot
.73115 .52268 Mdot
.73615 .53738 Mdot
.25789 .71872 Mdot
.14916 .53812 Mdot
.49016 .57836 Mdot
.48088 .36933 Mdot
.46142 .40184 Mdot
.47815 .20142 Mdot
.41077 .25405 Mdot
.34783 .61061 Mdot
.26022 .56122 Mdot
.50989 .44487 Mdot
.66599 .32264 Mdot
.36247 .57666 Mdot
.67428 .81585 Mdot
.53535 .38966 Mdot
.46926 .23936 Mdot
.45489 .82197 Mdot
.67781 .71044 Mdot
.64064 .48588 Mdot
.58532 .45952 Mdot
.41274 .44816 Mdot
.5615 .54945 Mdot
.61936 .30655 Mdot
.70073 .69865 Mdot
.6159 .80591 Mdot
.65728 .48411 Mdot
.45509 .23688 Mdot
.57842 .41433 Mdot
.69644 .61263 Mdot
.37282 .49645 Mdot
.79468 .38947 Mdot
.65183 .58518 Mdot
.39723 .82217 Mdot
.67307 .51554 Mdot
.70421 .47882 Mdot
.36985 .25907 Mdot
.71027 .76696 Mdot
.30308 .48024 Mdot
.43836 .22986 Mdot
.34257 .45784 Mdot
.34072 .7159 Mdot
.74066 .52081 Mdot
.49036 .61423 Mdot
.52725 .46666 Mdot
.34297 .31653 Mdot
.51426 .85206 Mdot
.67101 .30717 Mdot
.34766 .60444 Mdot
.42344 .77964 Mdot
.42015 .20317 Mdot
.4998 .52381 Mdot
.32516 .17566 Mdot
.40199 .67019 Mdot
.59818 .84835 Mdot
.66609 .73469 Mdot
.47941 .43724 Mdot
.23338 .49826 Mdot
.59316 .32955 Mdot
.49681 .66172 Mdot
.60725 .81441 Mdot
.61672 .31433 Mdot
.25728 .43773 Mdot
.53252 .40376 Mdot
.40505 .45968 Mdot
.64447 .31461 Mdot
.4529 .77042 Mdot
.55663 .66271 Mdot
.308 .40833 Mdot
.51778 .79343 Mdot
.56483 .55013 Mdot
.17044 .39575 Mdot
.7671 .69119 Mdot
.51155 .81883 Mdot
.4874 .77123 Mdot
.58367 .17035 Mdot
.436 .4095 Mdot
.57266 .31298 Mdot
.44019 .60398 Mdot
.70976 .33965 Mdot
.25544 .48845 Mdot
.69124 .72344 Mdot
.22139 .54724 Mdot
.50759 .50095 Mdot
.23574 .24479 Mdot
.74644 .49993 Mdot
.36541 .45057 Mdot
.24068 .47151 Mdot
.49012 .83219 Mdot
.70312 .65562 Mdot
.1933 .61926 Mdot
.28309 .67799 Mdot
.65397 .37352 Mdot
.55685 .19436 Mdot
.82828 .51021 Mdot
.43218 .74805 Mdot
.80145 .36543 Mdot
.46769 .78693 Mdot
.7157 .41955 Mdot
.33936 .7448 Mdot
.37725 .33948 Mdot
.32958 .3328 Mdot
.27995 .64204 Mdot
.2313 .60208 Mdot
.48162 .3578 Mdot
.59196 .80587 Mdot
.72987 .28904 Mdot
.74247 .65371 Mdot
.56631 .82917 Mdot
.35695 .54567 Mdot
.42665 .35716 Mdot
.72293 .52064 Mdot
.66786 .54022 Mdot
.49202 .63167 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`2Looooo`;o0000Zoooool001cooooo00?o0000oooo
ooooool0W?ooool2o`000:_ooooo000Looooo`03o`000?oooooooooo08cooooo0_l00009ooooo`;o
0000/?ooool001cooooo00?o0000ooooooooool0S?ooool2o`0000;ooooo0_l00005ooooo`;o0000
5?ooool2o`0009[ooooo000Looooo`03o`000?oooooooooo093ooooo0_l00004ooooo`;o00001Ooo
ool2o`0000kooooo0_l0002Jooooo`007?ooool00ol0003oooooooooo`1kooooo`;o00005?ooool2
o`0000?ooooo0_l00005ooooo`;o00006Oooool2o`0008oooooo000Looooo`03o`000?oooooooooo
07_ooooo0_l0000Dooooo`;o00003oooool2o`0001Cooooo0_l0002?ooooo`007?ooool00ol0003o
ooooooooo`1iooooo`;o00008?ooool2o`0000Gooooo0_l00002ooooo`;o00000_ooool4o`0009_o
oooo000Looooo`03o`000?oooooooooo07Gooooo0_l00002ooooo`;o00007?ooool2o`0000;ooooo
0_l00009ooooo`;o00000_ooool6o`0009Wooooo000Looooo`;o0000M_ooool2o`0001_ooooo0ol0
0002ooooo`;o00005Oooool4o`0009Oooooo000Looooo`03o`000?oooooooooo08gooooo0_l00003
ooooo`?o00006oooool2o`0000Wooooo0_l0002<ooooo`007?ooool00ol0003oooooooooo`2=oooo
o`;o00003_ooool2o`0001cooooo0_l0002<ooooo`007?ooool00ol0003oooooooooo`25ooooo`;o
00005_ooool2o`000:[ooooo000Looooo`03o`000?oooooooooo08?ooooo1?l00032ooooo`007?oo
ool00ol0003oooooooooo`23ooooo`;o0000>?ooool2o`0008[ooooo000Looooo`03o`000?oooooo
oooo07[ooooo0_l0000nooooo`;o000000?oooooo`000?l000002Oooool2o`0007oooooo000Loooo
o`03o`000?oooooooooo07[ooooo0_l0000Fooooo`;o00009_ooool2o`0000cooooo0_l0001ooooo
o`007?ooool00ol0003oooooooooo`1Vooooo`;o00003_ooool2o`0001Kooooo0_l00002ooooo`;o
00003_ooool2o`0001Kooooo0_l0002=ooooo`007?ooool00ol0003oooooooooo`1Vooooo`;o0000
3_ooool2o`0000cooooo0_l00006ooooo`Co00002_ooool6o`0000;ooooo0_l0000:ooooo`;o0000
9Oooool2o`0007;ooooo000Looooo`03o`000?oooooooooo08Cooooo0_l00006ooooo`;o00003?oo
ool6o`0000;ooooo0_l0000:ooooo`;o00009Oooool2o`0007;ooooo000Looooo`03o`000?oooooo
oooo08Sooooo1?l0000?ooooo`;o00001Oooool2o`0000cooooo0_l0000>ooooo`;o0000Qoooool0
01cooooo00?o0000ooooooooool0H?ooool2o`0000gooooo0_l0000Gooooo`Co00001?ooool2o`00
00Wooooo0_l0000Booooo`?o00003_ooool2o`0008Oooooo00001_ooooook^k^oc8b<_l0003o<S8b
onk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`1Pooooo`;o00002oooool4
o`0000oooooo0_l0000>ooooo`;o00000_ooool2o`0001Wooooo0_l0002Hooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo
00?o0000ooooooooool0KOooool2o`00017ooooo0_l0000Booooo`;o00005?ooool2o`0000Gooooo
0_l0000Gooooo`;o0000OOooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_oo
ool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo097ooooo0_l00003ooooo`;o00000ooo
ool2o`0000gooooo0_l00005ooooo`;o00001_ooool2o`0000oooooo0_l0001mooooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0001E
ooooo`;o00001?ooool2o`0002Oooooo0_l00003ooooo`;o00001_ooool2o`0000?ooooo1?l00000
0ooooooo0000o`000003ooooo`;o00001oooool5o`0000_ooooo1?l0002<ooooo`0000?oooooo`00
0?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000oooo
ooooool0EOooool2o`0000Cooooo0_l0000Mooooo`;o00002?ooool3o`0000;ooooo0_l0000<oooo
o`?o00001_ooool2o`0000;ooooo1?l000000ooooooo0000o`000006o`0000[ooooo0_l0002<oooo
o`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0Moooool5o`0000Sooooo0ol00002ooooo`;o00002Oooool7o`000003
ooooool0003o000000Kooooo1?l00006ooooo`?o00001?ooool2o`0000Oooooo0ol0000Fooooo`;o
0000L?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So
410@00Kooooo00?o0000ooooooooool0Moooool3o`0000Cooooo0_l00004ooooo`;o00002_ooool2
o`0000;ooooo1?l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l0000>ooooo`;o00000_oo
ool2o`0000Oooooo0ol0000Fooooo`;o00000_ooool2o`0006cooooo00001_ooooook^k^oc8b<_l0
003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo07_o
oooo0_l000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l000000oooool4o`0000[o
oooo1?l000000ooooooo0000o`000006ooooo`;o00001_ooool2o`0000Kooooo0_l0000Pooooo`?o
0000Joooool001cooooo00?o0000ooooooooool0Noooool4o`0000Oooooo1Ol00002ooooo`?o0000
1_ooool2o`0000Cooooo1?l000000ooooooo0000o`000002ooooo`;o00000_ooool2o`0000kooooo
0_l00007ooooo`;o00006?ooool2o`0006_ooooo000Looooo`03o`000?oooooooooo07gooooo0_l0
0009ooooo`Co000000?oooooo`000?l000001oooool4o`0000_ooooo0_l0000Aooooo`;o00002?oo
ool2o`0001gooooo0_l0001Vooooo`007?ooool00ol0003oooooooooo`1eooooo`;o00004oooool2
o`000003ooooool0003o000000Wooooo0_l00003ooooo`;o00003oooool2o`0000Sooooo1?l00004
ooooo`;o00000oooool2o`0001[ooooo0_l0001Vooooo`007?ooool00ol0003oooooooooo`1doooo
o`?o00002_ooool2o`0000?ooooo0_l00002ooooo`;o00004Oooool2o`0000Cooooo0_l00002oooo
o`;o00001Oooool2o`0000[ooooo0_l00004ooooo`;o00000oooool4o`00083ooooo000Looooo`03
o`000?oooooooooo07Cooooo0_l00004ooooo`;o00001Oooool2o`0000;ooooo0ol00003ooooo`Co
00005?ooool2o`0000;ooooo0_l00007ooooo`;o00003_ooool2o`0000Gooooo0_l00020ooooo`00
7?ooool00ol0003oooooooooo`1?ooooo`;o00006oooool2o`0000;ooooo0_l00006ooooo`Co0000
0oooool2o`0000Cooooo0_l00004ooooo`Co00001Oooool2o`0001[ooooo0_l00009ooooo`;o0000
0oooool4o`0000Cooooo0_l0001oooooo`007?ooool00ol0003oooooooooo`1=ooooo`Co00006ooo
ool2o`0000;ooooo0_l00005ooooo`?o00000_ooool2o`000004ooooool0003o0000o`0000kooooo
0_l00002ooooo`;o00009Oooool2o`0000Gooooo0_l00004ooooo`;o0000Ooooool001cooooo00?o
0000ooooooooool0COooool2o`0001[ooooo1?l00004ooooo`;o00001?ooool2o`0000?ooooo0_l0
0002ooooo`;o00003?ooool4o`0000?ooooo0_l0000Qooooo`;o00001Oooool2o`0000Kooooo0_l0
0020ooooo`007?ooool00ol0003oooooooooo`1Yooooo`Ko00000_ooool2o`0000;ooooo0_l00006
ooooo`;o000000?oooooo`000?l000003?ooool2o`0000Gooooo0_l0000Qooooo`Go00000_ooool2
o`0000Cooooo1?l0000Jooooo`;o0000I?ooool001cooooo00?o0000ooooooooool0BOooool2o`00
02;ooooo0_l00006ooooo`;o00000_ooool3o`000004ooooool0003o0000ooooo`;o00002?ooool2
o`0002kooooo0ol00007ooooo`Go00000_ooool2o`0001Kooooo0_l0001Tooooo`007?ooool00ol0
003oooooooooo`19ooooo`;o00005oooool2o`0000;ooooo0_l0000Aooooo`Ko00002oooool2o`00
03Sooooo0_l000000ooooooo0000o`000004o`0007cooooo000Looooo`;o0000Goooool2o`0000;o
oooo0_l00002ooooo`;o00000oooool2o`0000cooooo0_l000001?oooooo0000o`000?l0001:oooo
o`Co00000_ooool2o`0001Oooooo0_l0001Oooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o
00000oooool2o`0000Kooooo1Ol0000>ooooo`;o00000_ooool2o`0000;ooooo0_l00010ooooo`;o
000000?oooooo`000?l000000_ooool2o`0001Oooooo0_l0001Oooooo`007?ooool00ol0003ooooo
ooooo`1Sooooo`;o00002?ooool3o`0000kooooo0_l00002ooooo`;o00000_ooool2o`00043ooooo
0_l00003ooooo`;o0000N_ooool001cooooo00?o0000ooooooooool0Hoooool2o`0000oooooo0_l0
0002ooooo`;o00005oooool2o`0002[ooooo0_l0000>ooooo`;o00001Oooool2o`0001Cooooo0_l0
001Mooooo`007?ooool00ol0003oooooooooo`1Rooooo`?o00000_ooool2o`0000_ooooo0ol00000
0ooooooo0000o`00000Gooooo`;o0000:_ooool2o`0000?ooooo0_l00007ooooo`Ko00000oooool2
o`0001Cooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1Rooooo`;o00000oooool2o`00
00Gooooo0_l00005ooooo`;o0000@Oooool3o`0000Cooooo0_l000000ooooooo0000o`000002o`00
00Gooooo1_l00006ooooo`;o00004oooool2o`0005_ooooo000Looooo`03o`000?oooooooooo05_o
oooo1?l0000?ooooo`;o00000oooool2o`0000Gooooo0_l0000=ooooo`;o00001Oooool4o`0002Co
oooo1Ol00002ooooo`;o00000oooool2o`0000Kooooo0_l00009ooooo`?o00004_ooool2o`0000Go
oooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`1Kooooo`Co00003?ooool2o`0000Kooooo
0_l00005ooooo`;o00003Oooool2o`0000Gooooo1?l0000Gooooo`;o00003_ooool3o`0001[ooooo
0_l0000Iooooo`;o0000E?ooool001cooooo00?o0000ooooooooool0Hoooool2o`0000Kooooo0_l0
000Aooooo`;o0000:oooool4o`0000Wooooo0_l00002ooooo`;o00007?ooool2o`0006gooooo000L
ooooo`03o`000?oooooooooo05Oooooo0_l0000:ooooo`;o00001_ooool5o`0000Cooooo0_l00008
ooooo`;o0000;Oooool2o`0000Wooooo0_l0000Pooooo`?o0000K?ooool001cooooo00?o0000oooo
ooooool0Doooool2o`0000;ooooo0ol0000Cooooo`Co00000oooool2o`0000?ooooo0_l0000moooo
o`Oo00007?ooool2o`0006cooooo000Looooo`03o`000?oooooooooo05?ooooo0_l00003ooooo`;o
00002?ooool4o`0000Wooooo0_l00003ooooo`;o00000oooool2o`0000Gooooo0_l00002ooooo`;o
00002_ooool2o`0001oooooo0ol00002ooooo`?o000000?oooooo`000?l000000ol000001?oooooo
0000o`000?ooool2o`00013ooooo0_l0001booooo`007?ooool00ol0003oooooooooo`1Dooooo`;o
00003?ooool7o`0001Oooooo0_l00002ooooo`Co00002?ooool2o`0001gooooo1_l000001?oooooo
0000o`000?l00002ooooo`Co000000Coooooo`000?l0003ooooo0_l0000:ooooo`;o00001?ooool2
o`0001;ooooo0_l0001Nooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o00003oooool4o`00
01gooooo1?l0000Pooooo`;o00000oooool2o`0000;ooooo0_l0000Dooooo`;o00001?ooool2o`00
00gooooo0_l00009ooooo`;o0000G_ooool001cooooo00?o0000ooooooooool0>_ooool2o`0001Go
oooo0_l00004ooooo`;o00005?ooool2o`0001Wooooo0_l0000Oooooo`?o00000oooool2o`0000Ko
oooo0_l000000ooooooo0000o`00000=ooooo`;o00004oooool2o`0000_ooooo0_l0001Looooo`00
7?ooool00ol0003oooooooooo`0jooooo`;o00005Oooool2o`0000Cooooo0_l0000Dooooo`;o0000
1Oooool2o`0000kooooo0_l00009ooooo`;o00004Oooool2o`0000Gooooo0_l0000<ooooo`;o0000
00?oooooo`000?l00000;oooool3o`0005_ooooo000Looooo`;o0000Eoooool2o`0001cooooo1?l0
000<ooooo`;o000000?oooooo`000?l000001?ooool4o`00017ooooo0_l0000?ooooo`;o00008Ooo
ool5o`0000Kooooo0_l00008ooooo`?o00001_ooool2o`0005?ooooo000Looooo`03o`000?oooooo
oooo05Cooooo1?l00008ooooo`;o00005?ooool2o`0000oooooo0_l00004ooooo`;o00006oooool3
o`0000Kooooo0_l0000Qooooo`Go00001_ooool3o`0000Oooooo0_l00007ooooo`;o0000Doooool0
01cooooo00?o0000ooooooooool0E?ooool4o`0000Sooooo0_l0000>ooooo`;o0000=oooool5o`00
01Oooooo0_l0000=ooooo`Co00002_ooool2o`00017ooooo0_l00003ooooo`;o0000COooool001co
oooo00?o0000ooooooooool0A_ooool2o`0000?ooooo0_l00009ooooo`?o00005oooool4o`0002go
oooo0ol00005ooooo`Go00004?ooool3o`0000Cooooo0_l00007ooooo`;o00001?ooool5o`0000_o
oooo0_l0000?ooooo`?o00000_ooool2o`0004gooooo000Looooo`03o`000?oooooooooo04Kooooo
0_l00003ooooo`;o00001_ooool2o`0000;ooooo0_l0000<ooooo`;o00002oooool2o`0000?ooooo
1?l0000Uooooo`Co00001oooool2o`000003ooooool0003o000000Kooooo0_l00006ooooo`?o0000
3Oooool2o`0000Gooooo1?l0000;ooooo`;o00002oooool2o`0000?ooooo0_l0001Aooooo`007?oo
ool00ol0003oooooooooo`1;ooooo`;o00000_ooool2o`0000;ooooo0_l00004ooooo`;o00002_oo
ool2o`0000Gooooo0_l00004ooooo`;o00000oooool4o`0002Gooooo0_l0000<ooooo`;o00001?oo
ool6o`0000Sooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000001Ooo
ool2o`000003ooooool0003o000001Oooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`1;
ooooo`?o000000?oooooo`000?l000002?ooool2o`0000Gooooo0_l00009ooooo`?o00001?ooool2
o`000003ooooool0003o000000Kooooo0_l0000Tooooo`?o00003_ooool2o`0000;ooooo0_l00007
ooooo`?o000000?oooooo`000?l000000_l00002ooooo`;o000000?oooooo`000?l000002?ooool2
o`0006oooooo000Looooo`03o`000?oooooooooo04?ooooo0_l00003ooooo`;o00000_ooool2o`00
01;ooooo0_l00009ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o00001_ooool2
o`0000kooooo0_l0000Cooooo`Co00003?ooool2o`0000gooooo0_l00004ooooo`;o00003?ooool2
o`0000Wooooo0_l00003ooooo`;o0000H_ooool001cooooo00?o0000ooooooooool0@oooool2o`00
00?ooooo0_l0000Dooooo`Co00003Oooool2o`0000Oooooo0_l00006ooooo`;o00002oooool2o`00
00Cooooo0_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000000_ooool2o`00
00Gooooo0ol00004ooooo`Co00007oooool4o`0000Wooooo0_l00003ooooo`?o00000oooool2o`00
00gooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00001?ooool2o`0001?o
oooo1Ol00003ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Sooooo0ol00006ooooo`;o
00000oooool2o`0000?ooooo0_l00007ooooo`;o000000?oooooo`000?l000000oooool2o`000003
ooooool0003o000000;ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00001?ooool4o`00
0003ooooool0003o000000Oooooo0_l0000Cooooo`;o00003?ooool2o`0000?ooooo0_l00003oooo
o`;o00003Oooool2o`0004gooooo000Looooo`03o`000?oooooooooo04Wooooo0_l00007ooooo`;o
00001Oooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`000004ooooool0003o0000oooo
o`;o00000_ooool4o`0000Kooooo1?l0000:ooooo`Co000000?oooooo`000?l000006?ooool6o`00
00Sooooo0_l000000ooooooo0000o`000003ooooo`;o000000Coooooo`000?l0003o00000oooool2
o`0000gooooo0_l000000ooooooo0000o`00000:ooooo`;o00000oooool2o`0000[ooooo0_l0001E
ooooo`007?ooool00ol0003oooooooooo`1Booooo`;o00001?ooool5o`0000Kooooo0_l000001?oo
oooo0000o`000?l00003ooooo`So000000Goooooo`000?l0003o0000ooooo`02o`0000Cooooo0_l0
0006ooooo`;o00002Oooool2o`0000Oooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0ol0
0008ooooo`;o00000_ooool5o`000003ooooool0003o000000?o000000?oooooo`000?l000001ooo
ool2o`0000?ooooo0ol000000ooooooo0000o`00000?ooooo`;o00002_ooool2o`0005Gooooo000L
ooooo`03o`000?oooooooooo04Gooooo0_l0000Aooooo`;o000000?oooooo`000?l000001?l00006
ooooo`;o00000oooool8o`000004ooooool0003o0000o`0000;ooooo1ol0000?ooooo`Co00001ooo
ool2o`0000;ooooo0_l00008ooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`Go0000
0_ooool5o`000003ooooool0003o000000;ooooo0_l00003ooooo`;o00000_ooool3o`0000[ooooo
0_l00003ooooo`;o000000?oooooo`000?l000000_l0001Pooooo`007?ooool00ol0003ooooooooo
o`0mooooo`;o00001_ooool2o`0001;ooooo0_l00002ooooo`Co00001Oooool4o`000003ooooool0
003o000000Go00000oooool4o`000003ooooool0003o000000?o00000_ooool2o`0000?ooooo0_l0
0008ooooo`Go00006Oooool4o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o00000ooo
ool4o`000003ooooool0003o000000Oooooo0_l00002ooooo`;o00001oooool2o`0000?ooooo2?l0
0002ooooo`;o00002?ooool2o`0000Gooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`0m
ooooo`;o00006Oooool3o`0000Cooooo0_l00005ooooo`Co000000?oooooo`000?l000003_l00006
ooooo`;o00000_ooool5o`0000Oooooo1_l0000Gooooo`Co00003?ooool2o`0000;ooooo1Ol00000
0ooooooo0000o`000003o`0000Gooooo1Ol00008ooooo`;o00000_ooool2o`000003ooooool0003o
000000Ko00002?ooool2o`0000Gooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`1@oooo
o`;o00001_ooool3o`0000Cooooo0_l00006oooooaCo00000_ooool5o`0000?ooooo0_l000000ooo
oooo0000o`000002o`0000?ooooo1?l00002ooooo`;o000000?oooooo`000?l000000_ooool3o`00
00kooooo0_l0000:ooooo`;o00000_ooool3o`0000;ooooo1Ol000000ooooooo0000o`000003o`00
00Gooooo0_l000000ooooooo0000o`000003o`0000Gooooo0_l00004ooooo`Co000000?oooooo`00
0?l000001?ooool2o`0000Cooooo0_l0001Aooooo`007?ooool2o`0004Cooooo0_l0000;ooooo`;o
00001oooool2o`0000?ooooo0_l00003ooooo`;o00001?ooool@o`0000Cooooo1Ol00004ooooo`;o
00000_ooool2o`0000?ooooo0ol00006ooooo`;o00000_ooool3o`0000Sooooo0_l000000ooooooo
0000o`000003o`0000Gooooo2ol00003ooooo`;o00001Oooool3o`0000;ooooo0_l00002ooooo`;o
00000oooool3o`0000Wooooo1_l00006ooooo`?o0000Eoooool001cooooo00?o0000ooooooooool0
@oooool2o`0001;ooooo0_l00005ooooo`;o00000oooool3o`0000;ooooo4Ol00002ooooo`Oo0000
1?ooool2o`0001oooooo0_l000000ooooooo0000o`000004o`000004ooooool0003o0000ooooo`Wo
00000_ooool5o`0000[ooooo0_l00002ooooo`;o00003oooool2o`0000;ooooo0_l00003ooooo`;o
000000?oooooo`000?l000002_ooool2o`0004cooooo000Looooo`03o`000?oooooooooo02cooooo
0_l0000Aooooo`Co00005?ooool2o`0000_ooooo0_l000000ooooooo0000o`000008o`000003oooo
ool0003o0000013o00000_ooool4o`0000[ooooo0_l0000@ooooo`;o00001?oooolAo`0000;ooooo
1Ol000001?oooooo0000o`000?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o
00004_ooool2o`0000?ooooo0_l0000=ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0
;?ooool2o`00017ooooo1_l0000Booooo`;o00002?ooool2o`0000Cooooo8ol00008ooooo`Co0000
0oooool2o`0000_ooooo0_l00003ooooo`?o00000_ooool5o`000003ooooool0003o000000Ko0000
00?oooooo`000?l000002Ol00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000cooooo
0_l00005ooooo`;o000000?oooooo`000?l000003oooool2o`0004_ooooo000Looooo`03o`000?oo
oooooooo03Sooooo0_l00008ooooo`Co00004Oooool2o`0000Sooooo0_l00005oooooa_o000000?o
ooooo`000?l000000ol00009ooooo`?o00001?ooool2o`0000_ooooo0_l00003ooooo`;o00000_oo
ool4o`0000;ooooo5_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00008ooooo`;o0000
0_ooool2o`0000Gooooo0_l000000ooooooo0000o`000002ooooo`?o00000_ooool2o`0000Kooooo
0_l0001;ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00001?ooool2o`0000;ooooo1?l0
000Rooooo`Wo000000?oooooo`000?l000001_l000000ooooooo0000o`000003o`000003ooooool0
003o000000Co00001oooool2o`0000?ooooo0_l00008ooooo`;o00004?oooolDo`000003ooooool0
003o000000Wo00001?ooool2o`0000Sooooo0_l0000<ooooo`Oo00000_ooool2o`0000_ooooo0_l0
0016ooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00001?ooool2o`0000gooooo0_l00004
ooooo`;o00002_oooolRo`0000Oooooo0_l00008ooooo`;o00000oooool2o`0000Wooooo0_l00005
oooooa3o000000?oooooo`000?l000003_l00005ooooo`?o00004oooool8o`000003ooooool0003o
000000_ooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00002_ooool2o`00
0004ooooool0003o0000o`0000?ooooo0_l0000:ooooobGo00001oooool2o`0000Gooooo0_l00008
ooooo`;o000000Coooooo`000?l0003ooooo1?l00003ooooo`;o000000?oooooo`000?l000006?l0
0002ooooo`Co00000oooool3o`0000Kooooo0_l000000ooooooo0000o`000002ooooo`;o00001Ooo
ool7o`000003ooooool0003o000005?ooooo000Looooo`03o`000?oooooooooo053ooooo0_l00002
ooooo`;o00001?ooool2o`0000Wooooo3ol000000ooooooo0000o`00000<o`000004ooooool0003o
0000ooooo`?o00001oooool3o`0000gooooo0ol000001?oooooo0000o`000?ooool4o`000003oooo
ool0003o000000;o00001?oooolGo`0000;ooooo1Ol00004ooooo`;o00001Oooool2o`000003oooo
ool0003o000000;ooooo0_l00005ooooo`Co00000_ooool4o`0000Sooooo0_l00019ooooo`007?oo
ool00ol0003oooooooooo`1Booooo`;o00001_ooool3o`0000Wooooo0_l00003oooooa_o000000Co
ooooo`000?l0003o00000oooool4o`000003ooooool0003o000000cooooo0ol00002ooooo`;o0000
00?oooooo`000?l000008ol000000ooooooo0000o`000003o`0000Cooooo0_l0000Iooooo`Co0000
1Oooool2o`000003ooooool0003o000004Wooooo000Looooo`03o`000?oooooooooo02Kooooo0_l0
000Qooooo`;o00001_ooool3o`0000Oooooo0_l00009ooooo`;o000000Coooooo`000?l0003ooooo
6_l000001?oooooo0000o`000?l00003ooooo`Co00003Oooool5o`0000;ooooo0_l00004oooooaOo
000000?oooooo`000?l000002?l00002ooooo`Oo000000?oooooo`000?l000001_ooool2o`0000Oo
oooo0_l0000:ooooo`;o00000_ooool5o`0004cooooo000Looooo`03o`000?oooooooooo02Kooooo
0_l0000Qooooo`;o00001_ooool2o`0000Cooooo0_l0000@ooooo`;o000000?oooooo`000?l00000
2Ol000000ooooooo0000o`000009o`000003ooooool0003o000000Co000000?oooooo`000?l00000
1?ooool2o`0000_ooooo1Ol00002ooooo`;o00001?oooolGo`000003ooooool0003o0000017o0000
2Oooool2o`0000Kooooo0ol000001?oooooo0000o`000?ooool2o`0000Oooooo1Ol00006ooooo`;o
0000AOooool001cooooo00?o0000ooooooooool0DOooool2o`0000Cooooo0_l00004ooooo`;o0000
2?ooool;o`000003ooooool0003o000001;o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o
00004Oooool3o`0000Cooooo3?l000000ooooooo0000o`00000Fo`0000?ooooo0_l0000;ooooo`;o
00001Oooool3o`000003ooooool0003o000000?o00001_ooool3o`0000Oooooo1Ol00014ooooo`00
7?ooool00ol0003oooooooooo`1:ooooo`?o00000oooool4o`0000Wooooo0_l00008oooooaoo0000
00?oooooo`000?l000005oooool2o`000003ooooool0003o000000Co000000?oooooo`000?l00000
8ol00004ooooo`;o00002oooool2o`0000Gooooo0ol000000ooooooo0000o`000002o`0000Oooooo
0_l00006ooooo`Co000000?oooooo`000?l00000A?ooool00006ooooooo^k^ko<S8bo`000?lb<S;o
k^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo043o
oooo0_l00004ooooo`;o00000_ooool3o`000003ooooool0003o000000Co000000?oooooo`000?l0
00001oooool2o`0000Cooooo0_l00004oooooaoo00005oooool2o`000003ooooool0003o000000Co
000000?oooooo`000?l000008ol000001?oooooo0000o`000?ooool2o`0000Kooooo0_l0000:oooo
o`;o00000_ooool2o`00017ooooo0_l00019ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5
ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Cooooo0_l00008
ooooo`Co00001?ooool2o`000003ooooool0003o000000?ooooo0_l00005ooooo`;o00001oooool2
o`0000Cooooo0_l00002ooooo`?o000000?oooooo`000?l000005ol000001?oooooo0000o`000?oo
ool2o`0001gooooo7?l000000ooooooo0000o`000006o`0000?ooooo1Ol00006ooooo`;o00005Ooo
ool2o`0000?ooooo0_l0001@ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09
ooooo`Go00001_ooool00ol0003oooooooooo`0Sooooo`;o00003oooool2o`0000Sooooo1?l00000
0ooooooo0000o`000004ooooo`;o00000oooool2o`0000Gooooo0_l0000;ooooo`;o00000ooooolN
o`0000Cooooo0_l00008ooooo`;o00002?ooool2o`0000Wooooo9_l00002ooooo`?o00000oooool2
o`0000Sooooo0_l00004ooooo`;o000000?oooooo`000?l000000_l00005ooooo`;o00000oooool4
o`0004kooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgM
gOoooooo00001oooool3o`0002?ooooo0_l0000Kooooo`;o000000?oooooo`000?l000006?ooool2
o`0000?ooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo5ol0000>ooooo`?o00002?oo
ool2o`0000;ooooo0_l00002ooooo`Co000000?oooooo`000?l000001Ol000000ooooooo0000o`00
000:o`000003ooooool0003o000000go00000_ooool3o`0000?ooooo0_l00008ooooo`;o00001?oo
ool2o`000003ooooool0003o000000;o00003?ooool2o`000003ooooool0003o000000[ooooo0_l0
000oooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGo
ooooo`0000Oooooo00?o0000ooooooooool0@?ooool2o`0000Sooooo0_l0000Aooooo`;o00001Ooo
ool2o`0000Gooooo1?l000000ooooooo0000o`00000Bo`0000Gooooo1?l00004ooooo`?o00003Ooo
ool2o`000003ooooool0003o000002So000000?oooooo`000?l000000_l0000=ooooo`;o00002?oo
ool3o`0000Kooooo0_l00007ooooo`;o00002_ooool2o`0003oooooo00000ooooooo410@ooooo`02
ooooo`03oa0@4?oooooooooo00[ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`1:
ooooo`?o00002oooool2o`0000Kooooo0_l00002ooooo`Co00000oooool4o`000003ooooool0003o
000001?o000000Coooooo`000?l0003ooooo1?l00004ooooo`;o00002Oooool2o`0000;ooooo0_l0
0002ooooobgo000000?oooooo`000?l000004?ooool2o`0000Cooooo0_l00002ooooo`;o00000_oo
ool4o`0000Gooooo1?l0001:ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<ooooo`03onk^
k_m4A4Co000000Oooooo00?o0000ooooooooool0Boooool4o`000003ooooool0003o000000Kooooo
0ol00003ooooo`Co00001?ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l00000
4_l000001?oooooo0000o`000?ooool2o`0000;ooooo0ol0000?ooooo`;o00000_ooool2o`0000?o
oooo;?l000000ooooooo0000o`000002o`0000kooooo0_l00008ooooo`;o00000_ooool4o`0000Co
oooo1Ol0001:ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo
00Kooooo00?o0000ooooooooool0??ooool2o`0000gooooo1?l000000ooooooo0000o`000007oooo
o`;o00000oooool2o`0000;ooooo0_l00005ooooo`;o00000ooooolBo`0001Wooooo0_l00005oooo
o`?o000000?oooooo`000?l000009ol00003ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooo
oooo0000o`000002ooooo`;o00001_ooool2o`0000Gooooo0_l0000:ooooo`Co00001?ooool2o`00
04Gooooo000Looooo`03o`000?oooooooooo023ooooo0_l0000Jooooo`?o00003?ooool2o`0000Go
oooo0_l0000>ooooo`;o00001oooool2o`000003ooooool0003o000000co000000Coooooo`000?l0
003ooooo0ol0000Fooooo`;o00001_ooool2o`000003ooooool0003o000000So00000ooooolLo`00
00;ooooo0ol00004ooooo`Co000000?oooooo`000?l000000_ooool2o`0000Cooooo1?l0000>oooo
o`;o00002Oooool4o`0004?ooooo000Looooo`03o`000?oooooooooo023ooooo0_l0000Kooooo`;o
00000oooool2o`0000kooooo0_l0000Gooooo`;o00000_ooool3o`000003ooooool0003o000000Ko
00000_ooool2o`000004ooooool0003o0000o`0000?ooooo0_l00006ooooo`;o00000oooool2o`00
00Cooooo0_l00005ooooo`?o00000ooooolWo`0000;ooooo0_l00005ooooo`;o00001Oooool2o`00
00Kooooo0ol0000?ooooo`;o000000?oooooo`000?l000000ol00005ooooo`;o0000@oooool001co
oooo00?o0000ooooooooool0@_ooool2o`0000Sooooo0_l0000Cooooo`?o00001_ooool2o`0000?o
oooo0_l00002ooooo`Wo000000Coooooo`000?l0003o00001Oooool3o`0000;ooooo0_l00002oooo
o`;o00000oooool2o`000003ooooool0003o000000Sooooo0ol00002ooooobOo00000oooool:o`00
00;ooooo1?l00003ooooo`Ko00004?ooool7o`0004[ooooo000Looooo`03o`000?oooooooooo04;o
oooo0_l00008ooooo`;o00004_ooool4o`0000Kooooo0_l00005ooooo`;o00001?ooool6o`000003
ooooool0003o000000Gooooo0ol00002ooooo`;o00001oooool2o`000004ooooool0003o0000oooo
o`Go00000_ooool3o`0000;ooooo9?l000000ooooooo0000o`000002o`0000?ooooo2?l00002oooo
o`;o00001Oooool4o`0000;ooooo0_l0000>ooooo`;o00000_ooool2o`0001Wooooo0_l0000`oooo
o`007?ooool00ol0003oooooooooo`0gooooo`?o00002Oooool2o`0000gooooo0_l0000<ooooo`;o
00003Oooool4o`0000Oooooo0ol00009ooooo`?o000000?oooooo`000?l000001oooool2o`0000Co
oooo1_l000000ooooooo0000o`000004ooooo`?o00000ooooolNo`0000;ooooo1?l000000ooooooo
0000o`000003o`0000?ooooo0ol00006ooooo`Co00000_ooool2o`0001;ooooo0_l00006ooooo`;o
00004Oooool2o`00033ooooo000Looooo`03o`000?oooooooooo03Oooooo0ol00009ooooo`;o0000
3Oooool2o`0000cooooo0_l0000=ooooo`Co00004oooool3o`0001Cooooo0ol00006ooooo`Go0000
00?oooooo`000?l000008_l00003ooooo`?o00000oooool3o`0000Oooooo0ol00009ooooo`;o0000
1_ooool3o`000004ooooool0003o0000o`0000Kooooo0_l00013ooooo`007?ooool00ol0003ooooo
ooooo`0Mooooo`;o00007oooool2o`0000?ooooo0ol00009ooooo`;o000000?oooooo`000?l00000
3?ooool2o`0000oooooo0_l00004ooooo`;o00002?ooool2o`000003ooooool0003o000000?o0000
1_ooool2o`0000Oooooo1?l00002ooooo`;o00002OoooolPo`000003ooooool0003o000000;o0000
1_ooool4o`000003ooooool0003o000000;o00001oooool2o`0000Wooooo0_l00006ooooo`?o0000
00?oooooo`000?l000000_l0001:ooooo`007?ooool00ol0003oooooooooo`0Mooooo`;o00007ooo
ool2o`0000;ooooo1?l00009ooooo`Go00004_ooool2o`0000oooooo0_l00002ooooo`;o00001?oo
ool5o`000004ooooool0003o0000o`0000Gooooo0_l000000ooooooo0000o`000004ooooo`Co0000
0oooool4o`0000Cooooo8Ol00002ooooo`;o000000?oooooo`000?l000001Oooool4o`000003oooo
ool0003o000000;o00001Oooool2o`000004ooooool0003o0000ooooo`;o00003?ooool2o`0000?o
oooo1_l00018ooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00002oooool5o`0000?ooooo
0_l000000ooooooo0000o`00000:ooooo`;o00004oooool2o`0000Cooooo1Ol00002ooooo`;o0000
0oooool4o`000004ooooool0003o0000o`0000Cooooo0_l00004ooooo`Co000000?oooooo`000?l0
00001Ol000000ooooooo0000o`00000Qo`000003ooooool0003o000000?ooooo0_l00002ooooo`;o
00001oooool2o`000004ooooool0003o0000ooooo`;o00002_ooool4o`0000Gooooo1?l00018oooo
o`007?ooool00ol0003oooooooooo`12ooooo`;o00003?ooool2o`0000?ooooo1?l000000ooooooo
0000o`00000Booooo`;o00004Oooool2o`0000Oooooo0_l000000ooooooo0000o`000003ooooo`?o
00001?ooool2o`0000Oooooo1_l000000ooooooo0000o`00000Lo`000003ooooool0003o000000Co
00000_ooool3o`0001Wooooo0_l00003ooooo`;o000000?oooooo`000?l000000ol00004ooooo`;o
0000B_ooool001cooooo00?o0000ooooooooool0@_ooool3o`0000Oooooo0_l00004ooooo`;o0000
00?oooooo`000?l000005oooool3o`00017ooooo0_l00002ooooo`;o00000_ooool2o`00017ooooo
0_l00003ooooo`;o00000_ooool2o`0000;ooooo1ol000000ooooooo0000o`00000Bo`000003oooo
ool0003o000000Co00001?ooool2o`0001Wooooo0ol00002ooooo`;o00000oooool3o`0000Oooooo
0_l00017ooooo`007?ooool2o`0003Oooooo0_l0000:ooooo`?o00001oooool3o`0000?ooooo0_l0
00000ooooooo0000o`00000?ooooo`;o00001oooool6o`0000gooooo0_l00002ooooo`Co00003_oo
ool4o`000003ooooool0003o000000Kooooo0ol00002ooooo`Oo000000?oooooo`000?l000004_l0
00000ooooooo0000o`000003o`0000Cooooo0_l00005ooooo`;o00005?ooool2o`0000;ooooo0_l0
00000ooooooo0000o`000003o`0000Oooooo0_l00008ooooo`;o0000?Oooool001cooooo00?o0000
ooooooooool0=_ooool2o`0000Cooooo0ol00003ooooo`?o00002?ooool2o`0000;ooooo0ol00002
ooooo`;o00003Oooool5o`0000Gooooo1_l0000<ooooo`;o00000oooool4o`0000Sooooo0_l00004
ooooo`Co00002?ooool3o`0000;ooooo0ol00002ooooo`co000000?oooooo`000?l000001Ol00000
1?oooooo0000o`000?l00005ooooo`?o00000_ooool2o`0000Cooooo0ol00008ooooo`;o00003?oo
ool4o`000003ooooool0003o000000;o00004_ooool2o`0003gooooo000Looooo`03o`000?oooooo
oooo03cooooo1Ol00002ooooo`;o00003?ooool2o`0000?ooooo0_l0000:ooooo`;o000000?ooooo
o`000?l000000ol00002ooooo`;o00002Oooool2o`0000?ooooo0_l00003ooooo`;o00001?ooool2
o`0000Wooooo0_l0000:ooooo`;o00001?ooool3o`0000;ooooo1Ol00003ooooo`Co000000?ooooo
o`000?l000001Ol000001?oooooo0000o`000?l00002ooooo`?o000000Coooooo`000?l0003ooooo
1?l000000ooooooo0000o`000005ooooo`Ko00001Oooool2o`0000cooooo1_l0000<ooooo`;o0000
A_ooool001cooooo00?o0000ooooooooool0?Oooool4o`0000Cooooo0_l0000>ooooo`;o00002_oo
ool3o`0000Sooooo0_l00009ooooo`Co000000Goooooo`000?l0003o0000ooooo`02o`00013ooooo
1?l00005ooooo`;o000000?oooooo`000?l000001?ooool3o`0000;ooooo1Ol00002ooooo`?o0000
00?oooooo`000?l000001ol000000ooooooo0000o`000009o`000003ooooool0003o000000?ooooo
0_l00007ooooo`Co00004oooool6o`0000cooooo0_l00016ooooo`007?ooool00ol0003ooooooooo
o`0mooooo`Co00001?ooool2o`0000?ooooo0_l00009ooooo`;o00001?ooool2o`0000Cooooo0ol0
000@ooooo`;o00000oooool2o`000003ooooool0003o000000Co00004_ooool2o`0000Gooooo0_l0
0007ooooo`;o00001Oooool3o`0000;ooooo2Ol000001?oooooo0000o`000?l00004ooooo`So0000
1_ooool2o`0000Sooooo0_l00004ooooo`;o00003oooool3o`0000;ooooo0_l000000ooooooo0000
o`00001?ooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00004_ooool2o`0000oooooo0_l0
0005ooooo`Co00003_ooool2o`0000?ooooo0_l00004ooooo`;o00005oooool2o`0000kooooo0_l0
0002ooooo`[o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l000000ooooooo0000o`00
0003o`0000Cooooo0ol000000ooooooo0000o`000004ooooo`;o00000_ooool2o`000004ooooool0
003o0000ooooo`;o00000oooool2o`0000Sooooo0_l000000ooooooo0000o`000002ooooo`Go0000
Coooool001cooooo00?o0000ooooooooool06Oooool2o`0001_ooooo0_l00003ooooo`;o00005?oo
ool2o`0000Gooooo0_l00005ooooo`;o00000oooool5o`0000Cooooo0_l0000@ooooo`;o00001Ooo
ool2o`00013ooooo0_l0000>ooooo`?o000000?oooooo`000?l000000ol000000ooooooo0000o`00
0003ooooo`;o000000?oooooo`000?l000002ol00002ooooo`Go000000?oooooo`000?l000001?oo
ool2o`0000Gooooo0_l000000ooooooo0000o`000003ooooo`Co00001_ooool2o`000003ooooool0
003o000000?ooooo1?l00002ooooo`;o00001_ooool2o`0004?ooooo000Looooo`03o`000?oooooo
oooo01Wooooo0_l0000Pooooo`;o00003Oooool2o`000005ooooool0003o0000o`000?ooool01?l0
0003ooooo`;o00000oooool4o`0000;ooooo0_l000001?oooooo0000o`000?l00004ooooo`;o0000
0oooool2o`0000Kooooo0_l000000ooooooo0000o`000003o`0000Cooooo0_l0000Fooooo`;o0000
2Oooool3o`0000;ooooo0_l00002ooooo`;o00001_ooool8o`0000;ooooo0ol00002ooooo`;o0000
5?ooool2o`0000;ooooo0_l000000ooooooo0000o`000009ooooo`;o00001Oooool2o`0000;ooooo
0_l00006ooooo`Co0000@Oooool001cooooo00?o0000ooooooooool0>oooool2o`0000gooooo0_l0
00001?oooooo0000o`000?l00003ooooo`?o00001oooool2o`0000Cooooo0_l00005ooooo`;o0000
1_ooool2o`000003ooooool0003o000000?ooooo0_l000001?oooooo0000o`000?ooool2o`0001co
oooo0_l00005ooooo`;o00000oooool2o`0000?ooooo0_l00004ooooo`Co00000_ooool2o`0000?o
oooo0_l00002ooooo`;o00007Oooool2o`0000Wooooo0_l0000Fooooo`;o00000_ooool4o`0003_o
oooo000Looooo`03o`000?oooooooooo03_ooooo0_l00004ooooo`;o00003_ooool2o`000003oooo
ool0003o000000Wooooo0ol00005ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o0000
0oooool2o`0002kooooo0_l00006ooooo`Co00001?ooool4o`0000_ooooo0_l00008ooooo`?o0000
00?oooooo`000?l000003?ooool3o`0000[ooooo0ol00007ooooo`Oo000000?oooooo`000?l00000
2Oooool4o`0003_ooooo000Looooo`03o`000?oooooooooo03Wooooo1_l00002ooooo`;o00003_oo
ool2o`0000Oooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000;ooooo0_l0
00000ooooooo0000o`000006o`0000Kooooo0_l0000Sooooo`;o00003_ooool2o`0000Kooooo1?l0
000Eooooo`?o000000?oooooo`000?l000003?ooool3o`000003ooooool0003o000000;o00001Ooo
ool4o`0000Kooooo2_l00004ooooo`?o00000_ooool3o`0003cooooo000Looooo`03o`000?oooooo
oooo03Cooooo0_l00003ooooo`;o000000Coooooo`000?l0003o00004_ooool2o`0000Oooooo0_l0
00000ooooooo0000o`000002o`0000;ooooo0_l00007ooooo`Ko00001_ooool4o`0001;ooooo0_l0
0003ooooo`;o00002?ooool2o`000003ooooool0003o000000Cooooo1Ol0000:ooooo`;o00001Ooo
ool2o`0000;ooooo0_l00005ooooo`;o00000oooool2o`0000Cooooo0_l00002ooooo`;o00003?oo
ool4o`0000Gooooo1?l00002ooooo`;o00001Oooool3o`000003ooooool0003o000000;ooooo0_l0
00001?oooooo0000o`000?l00002ooooo`?o00005Oooool2o`0002Gooooo000Looooo`03o`000?oo
oooooooo01Oooooo0_l0000Kooooo`;o00001_ooool2o`000003ooooool0003o000000Cooooo0_l0
0008ooooo`;o000000?oooooo`000?l000003oooool2o`0000Oooooo1ol000001?oooooo0000o`00
0?l00002ooooo`?o000000?oooooo`000?l000003oooool2o`0000?ooooo0_l0000;ooooo`;o0000
1?ooool5o`00017ooooo2?l00003ooooo`;o00000oooool2o`0000Cooooo0_l00002ooooo`;o0000
2oooool2o`0000Kooooo0_l00006ooooo`;o00003Oooool3o`0001cooooo0ol0000Uooooo`007?oo
ool00ol0003oooooooooo`0Gooooo`;o00006oooool2o`0000Wooooo0_l00004ooooo`;o00001ooo
ool3o`000003ooooool0003o000000Cooooo0_l00009ooooo`;o00000_ooool2o`0000?ooooo0_l0
0003ooooo`[o000000Coooooo`000?l0003o00001_ooool2o`0001Kooooo1_l00005ooooo`?o0000
3oooool2o`0000;ooooo0_l00002ooooo`;o00007oooool2o`0000Kooooo0ol00004ooooo`;o0000
1?ooool2o`0000Wooooo0_l0000Looooo`;o00009_ooool001cooooo00?o0000ooooooooool0=?oo
ool2o`00013ooooo0_l00006ooooo`;o00001oooool3o`0000gooooo1ol000001?oooooo0000o`00
0?ooool2o`0000?ooooo0_l00003ooooo`?o00001Oooool3o`0001Gooooo1ol00005ooooo`;o0000
2oooool2o`0000?ooooo0_l00002ooooo`;o00005_ooool2o`0001Cooooo0_l00004ooooo`;o0000
0oooool3o`0000Wooooo1?l00012ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00001?oo
ool4o`0000Gooooo0_l00006ooooo`?o00003oooool4o`0000;ooooo0_l00003ooooo`?o00000_oo
ool8o`0000?ooooo0_l00007ooooo`;o00000_ooool2o`0000Wooooo0_l0000:ooooo`Co00002Ooo
ool2o`0000gooooo0_l00005ooooo`;o00002Oooool2o`0000_ooooo0_l0000Booooo`;o00003?oo
ool2o`0004;ooooo000Looooo`;o0000??ooool2o`0000?ooooo0_l000000ooooooo0000o`000003
ooooo`;o00001Oooool2o`0000Kooooo1?l0000?ooooo`;o00000_ooool2o`0000Cooooo0ol00002
ooooo`So00003?ooool2o`0000;ooooo0_l0000>ooooo`;o00001Oooool4o`0000;ooooo0_l00002
ooooo`;o00002oooool2o`0000?ooooo0_l00005ooooo`;o00005_ooool2o`0000Oooooo0_l00000
1?oooooo0000o`000?ooool2o`0000Kooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`0j
ooooo`?o00001_ooool2o`0000?ooooo0ol0000<ooooo`Go00001oooool2o`0000Gooooo1_l00008
ooooo`;o00000oooool2o`000003ooooool0003o000000?ooooo0_l0000=ooooo`;o00000oooool2
o`0000Kooooo0_l00007ooooo`;o00000_ooool2o`0000;ooooo0_l0000;ooooo`;o00001?ooool2
o`0000cooooo0_l00009ooooo`?o00002oooool2o`000004ooooool0003o0000ooooo`?o00001Ooo
ool2o`0000;ooooo0_l00002ooooo`;o00005?ooool2o`0002oooooo000Looooo`03o`000?oooooo
oooo02oooooo0_l000000ooooooo0000o`000006ooooo`;o00001Oooool2o`0000Kooooo1?l0000;
ooooo`Co00001Oooool4o`000003ooooool0003o000000;ooooo1ol00007ooooo`;o00001_ooool2
o`000003ooooool0003o000000?o00000oooool2o`0000Oooooo0_l00003ooooo`;o00003_ooool2
o`0000[ooooo0_l0000>ooooo`;o00003?ooool2o`0000Wooooo0ol0000@ooooo`Co00001?ooool2
o`000003ooooool0003o000000;o00000_ooool2o`0001Cooooo0_l00004ooooo`;o0000:Oooool0
01cooooo00?o0000ooooooooool0;oooool2o`000003ooooool0003o000000Sooooo0_l00003oooo
o`Co00001_ooool3o`0000cooooo0ol00004ooooo`;o00000oooool2o`0000;ooooo0_l00002oooo
o`?o00004_ooool7o`000003ooooool0003o000000Cooooo0_l00008ooooo`;o00002_ooool6o`00
00;ooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l0000Hooooo`;o00002_ooool2
o`00013ooooo0_l00006ooooo`;o000000Coooooo`000?l0003ooooo0_l00008ooooo`;o00004ooo
ool2o`0002Wooooo000Looooo`03o`000?oooooooooo02oooooo0_l0000:ooooo`?o00001Oooool2
o`0000Gooooo1?l00005ooooo`;o00001Oooool3o`000004ooooool0003o0000ooooo`;o00001ooo
ool2o`0000;ooooo0ol0000Cooooo`;o000000?oooooo`000?l000000ol00003ooooo`Oo00001Ooo
ool2o`0000[ooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000?o00000_oo
ool3o`0000?ooooo1?l00007ooooo`;o00001oooool2o`0000[ooooo0_l0000Looooo`Co00000ooo
ool2o`0000?ooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0Gooooo`;o00008_ooool4
o`0000Cooooo0_l00005ooooo`Co000000?oooooo`000?l000000_ooool2o`0000Wooooo0_l00000
0ooooooo0000o`000007ooooo`;o00000_ooool2o`0000_ooooo0_l00003ooooo`;o00002?ooool2
o`0000?ooooo0_l000000ooooooo0000o`000003o`0000Cooooo0ol00007ooooo`;o00002oooool3
o`0000Gooooo0ol00002ooooo`Co00001oooool2o`0000_ooooo0_l0000Pooooo`;o00000_ooool4
o`0000?ooooo0_l0000:ooooo`?o0000=_ooool001cooooo00?o0000ooooooooool05oooool2o`00
01[ooooo0_l00008ooooo`;o00002oooool3o`0000;ooooo0_l00007ooooo`;o00000_ooool4o`00
01Gooooo0_l00004ooooo`;o00000oooool2o`0000_ooooo0_l00005ooooo`Co00001?ooool2o`00
00Oooooo0_l0000@ooooo`;o00000_ooool2o`0000Cooooo0ol00006ooooo`;o00002oooool2o`00
01;ooooo0_l0000<ooooo`?o00001_ooool2o`0000cooooo0ol00005ooooo`;o0000;oooool001co
oooo00?o0000ooooooooool0<oooool2o`0001Kooooo0_l000000ooooooo0000o`000002ooooo`;o
000000Coooooo`000?l0003ooooo0_l00002ooooo`Co00003Oooool2o`0000?ooooo0_l000000ooo
oooo0000o`00000?ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Gooooo1?l00009oooo
o`?o00000oooool2o`0000Sooooo0_l00004ooooo`Co00001_ooool3o`0000Kooooo0_l0000=oooo
o`;o000000?oooooo`000?l000002Oooool2o`000003ooooool0003o000000?o00002oooool2o`00
0003ooooool0003o000000?ooooo0ol00005ooooo`;o00003?ooool2o`0002oooooo000Looooo`03
o`000?oooooooooo04?ooooo0_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l0
00000_ooool2o`000003ooooool0003o000000Wooooo0_l0000;ooooo`;o00000oooool2o`0001;o
oooo0_l000000ooooooo0000o`000002ooooo`Co000000?oooooo`000?l000000ol00004ooooo`?o
000000?oooooo`000?l000000ol00003ooooo`Co00001_ooool2o`0000;ooooo1_l0000>ooooo`;o
00000oooool2o`0000Wooooo0_l000000ooooooo0000o`000009ooooo`So00003_ooool4o`0000;o
oooo0_l00005ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0@oooool2o`000003oooo
ool0003o000000?ooooo0_l0000Cooooo`;o00001_ooool4o`0001cooooo0_l00003ooooo`Oo0000
00?oooooo`000?l000001?ooool3o`000004ooooool0003o0000o`0000Oooooo0_l0000:ooooo`Go
00002?ooool2o`0000Gooooo0_l00003ooooo`;o00001Oooool2o`0000_ooooo0_l00005ooooo`Co
00004_ooool2o`0001[ooooo0ol0000[ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o0000
1?ooool2o`0000Sooooo0_l00004ooooo`;o00003?ooool2o`0000;ooooo1?l0000Looooo`;o0000
1_ooool2o`0000;ooooo0ol000000ooooooo0000o`000004ooooo`;o00006?ooool3o`0000Oooooo
0_l0000Aooooo`;o00002oooool2o`0000?ooooo0_l0000?ooooo`;o00002Oooool2o`0001Kooooo
0ol0000[ooooo`007?ooool00ol0003oooooooooo`0Jooooo`;o00005oooool2o`0000_ooooo0_l0
000>ooooo`;o00000oooool3o`0000Gooooo0_l00005ooooo`;o00000_ooool3o`0002Kooooo2Ol0
0002ooooo`Go00000_ooool2o`000003ooooool0003o0000017ooooo0_l00005ooooo`;o00002Ooo
ool2o`000003ooooool0003o000001Oooooo0_l00002ooooo`;o00002oooool2o`0000Cooooo0_l0
0003ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool06_ooool2o`00017ooooo0_l00004
ooooo`;o00008?ooool2o`0000Kooooo0_l0000Kooooo`;o00004Oooool2o`0000;ooooo0ol00002
ooooo`;o00001?ooool5o`0000;ooooo0_l000000ooooooo0000o`00000>ooooo`;o00000_ooool2
o`0000Cooooo0_l00009ooooo`;o000000?oooooo`000?l000000_l00008ooooo`;o00003oooool2
o`0000oooooo1_l00003ooooo`;o00004oooool2o`0002gooooo000Looooo`03o`000?oooooooooo
02gooooo0_l0000kooooo`;o00003_ooool2o`00017ooooo1?l000000ooooooo0000o`000002oooo
o`Co00000_ooool2o`000003ooooool0003o0000013ooooo0_l00003ooooo`;o00000_ooool2o`00
01Cooooo0_l00002ooooo`?o000000?oooooo`000?l000000_l00004ooooo`;o00002Oooool2o`00
00Cooooo0_l00009ooooo`Ko00000oooool2o`0001?ooooo0_l0000]ooooo`007?ooool00ol0003o
ooooooooo`17ooooo`;o00003oooool2o`000003ooooool0003o000000Co00002Oooool2o`0001co
oooo0_l00005ooooo`;o000000?oooooo`000?l000000_ooool4o`0000;ooooo0_l000000ooooooo
0000o`000002o`0000Gooooo0_l00007ooooo`?o00004Oooool2o`0000;ooooo0_l00008ooooo`Oo
00000_ooool6o`0000Cooooo0_l00004ooooo`;o00000oooool2o`000003ooooool0003o000000_o
oooo0_l0000>ooooo`;o0000=_ooool001cooooo00?o0000ooooooooool0A?ooool2o`000004oooo
ool0003o0000ooooo`;o00003?ooool2o`000003ooooool0003o000000Co00001?ooool2o`0000Wo
oooo0_l00002ooooo`?o00000_ooool2o`0000gooooo0_l00006ooooo`;o00001?ooool2o`0000Ko
oooo1_l000001?oooooo0000o`000?ooool2o`0000Kooooo1?l00006ooooo`;o00001Oooool2o`00
00;ooooo0_l00002ooooo`;o00002?ooool6o`000003ooooool0003o000000Go00001Oooool2o`00
00Cooooo0_l00003ooooo`;o000000?oooooo`000?l000001_ooool2o`0000?ooooo0_l0000>oooo
o`;o0000=_ooool001cooooo0_l0000Looooo`;o00008?ooool2o`0000Gooooo0_l00004ooooo`;o
00001_ooool2o`0000Wooooo1?l00004ooooo`;o00002Oooool2o`0000;ooooo1ol0000Eooooo`;o
00000oooool3o`0000Cooooo1?l00002ooooo`;o000000?oooooo`000?l000002Oooool2o`000004
ooooool0003o0000o`0000Cooooo0_l00005ooooo`;o00000oooool2o`00017ooooo2?l0000@oooo
o`Co00001oooool2o`0000Sooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0Kooooo`;o
00008?ooool2o`0000Gooooo0_l0000<ooooo`;o00001?ooool2o`0000?ooooo1?l00004ooooo`;o
00002Oooool3o`0000?ooooo0ol0000Gooooo`;o00000oooool4o`0000?ooooo0_l00004ooooo`;o
00000oooool2o`0000[ooooo0ol00002ooooo`;o00002oooool4o`0000?ooooo0_l00003ooooo`;o
00000_ooool?o`0000?ooooo0ol00009ooooo`;o00004Oooool2o`0000[ooooo0_l0000eooooo`00
7?ooool00ol0003oooooooooo`14ooooo`;o00001?ooool2o`000003ooooool0003o000000Co0000
0_ooool2o`000003ooooool0003o000000_ooooo0_l0000:ooooo`;o00001_ooool2o`000003oooo
ool0003o000000Ko00004_ooool4o`0000[ooooo0_l000000ooooooo0000o`00000:ooooo`;o0000
0oooool2o`0000Wooooo1_l00003ooooo`;o00000oooool2o`0000;ooooo4?l00002ooooo`?o0000
4_ooool2o`0001Cooooo0ol0000dooooo`007?ooool00ol0003oooooooooo`13ooooo`Go000000?o
ooooo`000?l000003_l0000:ooooo`;o00004oooool3o`000003ooooool0003o000000Oo00002?oo
ool2o`0000Oooooo1?l0000:ooooo`;o000000?oooooo`000?l000001?l00006ooooo`;o00003_oo
ool2o`0000;ooooo0_l0000=oooooa?o00004oooool4o`0000Wooooo0_l00008ooooo`;o00000_oo
ool2o`00033ooooo000Looooo`03o`000?oooooooooo03Wooooo0_l000000ooooooo0000o`000005
ooooo`Go000000?oooooo`000?l000003_l00006ooooo`;o00000_ooool2o`00013ooooo0_l00000
0ooooooo0000o`00000?o`0000Cooooo0_l0000;ooooo`;o00002oooool6o`0001Cooooo0_l00004
ooooo`;o00000oooool2o`0000;ooooo0_l00002oooooaGo000000?oooooo`000?l000004_ooool2
o`0000Wooooo0_l0000<ooooo`;o0000<?ooool001cooooo00?o0000ooooooooool0>Oooool2o`00
0003ooooool0003o000000?ooooo0_l00006oooooa3o00000oooool2o`000004ooooool0003o0000
ooooo`;o00003Oooool2o`0000;ooooo5?l00003ooooo`;o00001Oooool2o`0000Gooooo1?l00007
ooooo`;o00002_ooool2o`0000kooooo0_l00009ooooo`;o00000_ooool2o`0000;ooooo6?l0000O
ooooo`?o0000>oooool001cooooo00?o0000ooooooooool07Oooool2o`0001[ooooo0_l000000ooo
oooo0000o`000002ooooo`?o000000?oooooo`000?l000000oooool@o`0000;ooooo0ol00004oooo
o`;o00003Oooool2o`000003ooooool0003o000001;o00001?ooool4o`0000?ooooo0_l00003oooo
o`;o00000_ooool2o`0000Oooooo0_l00005ooooo`;o00000oooool2o`0000;ooooo0_l00007oooo
o`;o00002oooool2o`0000Oooooo5ol0000@ooooo`;o00002oooool6o`0003_ooooo000Looooo`03
o`000?oooooooooo01gooooo0_l0000Qooooo`;o00000_ooool2o`0000?ooooo3ol00003ooooo`;o
00002oooool3o`0000Wooooo5?l00006ooooo`;o00002?ooool6o`0000Oooooo0_l00005ooooo`;o
00000oooool3o`000004ooooool0003o0000ooooo`Co00000_ooool2o`0000?ooooo0_l00006oooo
o`;o00000oooool2o`0000;ooooo6Ol0000>ooooo`;o00002oooool6o`0000Oooooo0_l0000boooo
o`007?ooool00ol0003oooooooooo`1:ooooo`Oo000000?oooooo`000?l000001?l0000@ooooo`?o
00002?ooool6o`000003ooooool0003o000000go00001Oooool2o`0000[ooooo1?l00005ooooo`;o
00003Oooool2o`0000Cooooo1?l00007ooooo`;o00002oooool2o`000003ooooool0003o000001Go
000000?oooooo`000?l000004_ooool2o`0001Cooooo0_l0000booooo`007?ooool00ol0003ooooo
ooooo`0_ooooo`;o00005ooooolBo`0001Gooooo5_l00002ooooo`?o00001?ooool3o`0000[ooooo
0_l00006ooooo`;o00004_ooool3o`0001?ooooo0_l000001?oooooo0000o`000?ooool2o`0000;o
oooo0ol000000ooooooo0000o`00000<o`0001Gooooo0ol00018ooooo`007?ooool00ol0003ooooo
ooooo`0Nooooo`;o00003oooool2o`0000_ooooo0_l00009oooooa3o000000?oooooo`000?l00000
5OoooolLo`000004ooooool0003o0000ooooo`;o00000oooool2o`0000Gooooo0_l0000Jooooo`;o
00001Oooool2o`0000?ooooo0_l00008ooooo`;o00001_oooolDo`0000kooooo0_l000000ooooooo
0000o`000002ooooo`;o0000BOooool001cooooo00?o0000ooooooooool07_ooool3o`0001_ooooo
0_l00009oooooa3o00004?ooool2o`000003ooooool0003o000000?ooooo7ol00006ooooo`;o0000
7_ooool2o`0000Sooooo0_l00003ooooo`?o00002?ooool2o`0000Cooooo5_l0000=ooooo`;o0000
00?oooooo`000?l000000_ooool2o`0004Wooooo000Looooo`03o`000?oooooooooo01oooooo0_l0
000Sooooo`;o00000oooool=o`00017ooooo0_l000000ooooooo0000o`000002oooooaco000000?o
ooooo`000?l000003?ooool2o`0001Wooooo0_l00008ooooo`?o00000oooool2o`0000Gooooo0_l0
00000ooooooo0000o`000002o`0000;ooooo5_l000000ooooooo0000o`00000=ooooo`;o00000_oo
ool2o`0000_ooooo0_l0000looooo`007?ooool00ol0003oooooooooo`0Pooooo`;o00008_ooool2
o`0000Cooooo2_l0000Fooooo`;o00000_oooolNo`0000;ooooo0_l000000ooooooo0000o`000006
ooooo`;o00009?ooool2o`0000[ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00000
0ooooooo0000o`00000Ao`000003ooooool0003o000000;o00007?ooool2o`0003cooooo00001_oo
ooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0
1_ooool00ol0003oooooooooo`0Pooooo`;o00007oooool5o`0000?ooooo0_l000000ooooooo0000
o`000002o`0000;ooooo0_l0000Fooooo`?o000000?oooooo`000?l000008?l000000ooooooo0000
o`00000Vooooo`;o00001?ooool2o`0000?ooooo0_l0000=oooooaOo00000oooool2o`0001Kooooo
0_l00012ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGo
MgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0@Oooool5o`0000?ooooo0ol000000ooo
oooo0000o`000003ooooo`;o00000oooool2o`0000_ooooo0_l00005ooooo`;o00001Oooool2o`00
0003ooooool0003o000000Oo000000?oooooo`000?l000002_l000001?oooooo0000o`000?l0000Z
ooooo`;o00000oooool2o`0000Cooooo0_l0000=oooooaOo00006oooool2o`0004;ooooo00000ooo
oooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo04Cooooo0_l00004ooooo`?o00002_ooool2o`0000Wooooo1?l0000<
oooooaco00000oooool2o`0000Kooooo0_l00007ooooo`;o00006?ooool6o`0001Kooooo4Ol0000I
ooooo`;o00001?ooool4o`0003gooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000?_ooool2o`0000Oooooo0_l00000
1?oooooo0000o`000?l00005ooooo`Co00003?ooool2o`0000?ooooo0_l00008oooooaco00001?oo
ool2o`0000Kooooo0_l00007ooooo`;o00006?ooool6o`0001Oooooo4?l0000?ooooo`;o00002?oo
ool2o`0000Cooooo1?l0000mooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09
ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0nooooo`;o00001ooo
ool2o`0000Kooooo1ol0000Aooooo`?o00000ooooolPo`0000cooooo0_l0000Pooooo`Ko00000_oo
ool2o`0001Cooooo2?l000000ooooooo0000o`000005o`000004ooooool0003o0000o`0000_ooooo
0_l00007ooooo`;o0000A_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Ooo
ool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo04oooooo1Ol0000>ooooo`?o00000_oo
ool3o`0000?ooooo1?l00002oooooa[o00003?ooool2o`00023ooooo1_l00002ooooo`;o00000ooo
ool2o`00017ooooo3Ol00002ooooo`?o00002_ooool2o`0000Sooooo0_l00004ooooo`;o0000@?oo
ool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`00
0?oooooooooo04Gooooo0_l00006ooooo`;o00004oooool3o`0000;ooooo0ol00003ooooo`;o0000
0_ooool2o`0000?ooooo6?l000000ooooooo0000o`00000_ooooo`;o00001Oooool3o`0000oooooo
1?l000000ooooooo0000o`000005o`000003ooooool0003o000000oooooo0_l0000>ooooo`;o0000
0oooool3o`0003[ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0
003o410@1_ooool00ol0003oooooooooo`15ooooo`?o00000_ooool2o`000003ooooool0003o0000
00oooooo0_l00002ooooo`;o00001?ooool2o`0000?ooooo0_l00002ooooo`;o00001?oooolGo`00
0003ooooool0003o000000Oooooo0_l00002ooooo`;o00008_ooool2o`0000Gooooo0_l0000@oooo
o`_o00002_ooool2o`0000Wooooo1?l0000>ooooo`Co0000>_ooool001cooooo00?o0000oooooooo
ool0?_ooool2o`0000Kooooo0_l00002ooooo`;o00001Oooool2o`000003ooooool0003o000000So
oooo0_l000000ooooooo0000o`00000DoooooaGo000000Coooooo`000?l0003o00002?ooool3o`00
0003ooooool0003o000000Oooooo0_l0000Hooooo`?o000000?oooooo`000?l000005Oooool5o`00
0003ooooool0003o000000cooooo0_l00009ooooo`Co00001_ooool2o`0000Kooooo1?l0000joooo
o`007?ooool00ol0003oooooooooo`0kooooo`;o000000?oooooo`000?l000004Oooool2o`000003
ooooool0003o000000_ooooo0_l0000Goooooa7o00000_ooool3o`0000Cooooo0_l00002ooooo`?o
00002_ooool2o`0000Cooooo0_l00003ooooo`;o00003Oooool3o`000003ooooool0003o000001Go
oooo0_l00004ooooo`;o00003oooool2o`00013ooooo0_l00008ooooo`;o0000>_ooool001cooooo
00?o0000ooooooooool08oooool2o`0001Kooooo0ol0000Gooooo`;o00007Oooool2o`0000Gooooo
4?l00002ooooo`;o00001Oooool4o`0000Gooooo1ol00007ooooo`;o00000oooool2o`0000_ooooo
0_l00003ooooo`;o00001_ooool2o`000004ooooool0003o0000o`00027ooooo0_l0001Fooooo`00
7?ooool00ol0003oooooooooo`0Sooooo`;o00005oooool2o`0001Oooooo0_l0000Gooooo`;o0000
1?ooool2o`0000Sooooo2Ol000000ooooooo0000o`000007ooooo`;o00000ooooolCo`0001Cooooo
0_l00003ooooo`Co00001?ooool2o`000004ooooool0003o0000o`0000;ooooo0_l0000Jooooo`;o
00001oooool2o`00053ooooo000Looooo`03o`000?oooooooooo04;ooooo0_l00006ooooo`;o0000
8_ooool2o`0000kooooo0_l00006ooooo`;o00001?ooool2o`0000?ooooo0_l00002ooooo`co0000
00?oooooo`000?l000001_l0000Jooooo`;o00001oooool2o`0000?ooooo0_l0000Cooooo`;o0000
1Oooool2o`0000Oooooo1?l00006ooooo`;o00000oooool2o`00047ooooo000Looooo`03o`000?oo
oooooooo03cooooo0_l00004ooooo`;o00001_ooool2o`0002Sooooo0_l00008ooooo`Co00001?oo
ool2o`0000Cooooo0_l00007ooooo`co000000?oooooo`000?l000001ol0000Kooooo`;o00001Ooo
ool2o`0001Sooooo0_l0000@ooooo`;o00001_ooool2o`0000?ooooo0_l00011ooooo`007?ooool0
0ol0003oooooooooo`0looooo`;o000000?oooooo`000?l000004oooool2o`0000kooooo0ol00003
ooooo`;o00002?ooool2o`0000[ooooo0_l00008ooooo`;o00002?oooolGo`0000?ooooo0_l0000B
ooooo`;o00000_ooool2o`0000Sooooo0_l0000Oooooo`Co0000E?ooool001cooooo00?o0000oooo
ooooool0?oooool2o`0000Wooooo0_l00008ooooo`;o00003_ooool3o`0000?ooooo0_l0000@oooo
o`Co00002_ooool2o`0000Sooooo1_l000000ooooooo0000o`00000>o`000003ooooool0003o0000
00;o00001?ooool3o`0000Wooooo1?l0000<ooooo`;o00007_ooool5o`0005Cooooo000Looooo`03
o`000?oooooooooo04[ooooo0_l0000;ooooo`;o00002oooool2o`0000_ooooo0_l00009ooooo`Co
00004_ooool2o`000003ooooool0003o000001Co000000?oooooo`000?l000001Ol000001?oooooo
0000o`000?l00009ooooo`;o00002oooool2o`0001oooooo1?l00008ooooo`?o00002Oooool2o`00
047ooooo000Looooo`03o`000?oooooooooo05Oooooo0_l0000:ooooo`;o00003?ooool2o`0000[o
oooo0_l0000Cooooo`;o00000_oooolMo`000003ooooool0003o000000Gooooo0_l0000@ooooo`;o
00007oooool3o`0000Gooooo0_l00002ooooo`?o00002Oooool2o`00047ooooo000Looooo`03o`00
0?oooooooooo06?ooooo0_l0000Gooooo`?o00004_ooool3o`0000;ooooo6ol00003ooooo`;o0000
00?oooooo`000?l000000_ooool2o`0000Kooooo0_l0000Aooooo`;o00005_ooool5o`0000;ooooo
0ol00002ooooo`?o0000C?ooool001cooooo0_l0001Hooooo`;o00008oooool2o`0000Cooooo0_l0
0008ooooo`;o000000?oooooo`000?l000000_l000001?oooooo0000o`000?oooolJo`0000?ooooo
0_l000001?oooooo0000o`000?ooool3o`0000Kooooo0_l00003ooooo`;o00000_ooool4o`0000Ko
oooo0_l0000:ooooo`;o00001?ooool2o`0000Oooooo0_l00002ooooo`;o00000oooool2o`0004go
oooo000Looooo`03o`000?oooooooooo05Oooooo0ol0000Xooooo`;o00002?ooool2o`000003oooo
ool0003o000000?ooooo0_l000000ooooooo0000o`00000Ho`000004ooooool0003o0000o`0000Go
oooo0ol00006ooooo`;o00000oooool2o`0000;ooooo1?l0000:ooooo`;o00001Oooool3o`0000Co
oooo0_l00003ooooo`;o00000_ooool2o`00013ooooo0_l00014ooooo`007?ooool00ol0003ooooo
ooooo`11ooooo`;o00003Oooool2o`0000?ooooo0_l000000ooooooo0000o`00000Aooooo`;o0000
9ooooolMo`000004ooooool0003o0000o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o
000000?oooooo`000?l000003oooool2o`0000Gooooo0_l00005ooooo`;o00000_ooool3o`0000Go
oooo0_l00002ooooo`;o00003oooool3o`0004Cooooo000Looooo`03o`000?oooooooooo047ooooo
0_l0000=ooooo`;o00000oooool2o`0000kooooo0_l00004ooooo`;o00001_ooool2o`0001oooooo
7_l000001?oooooo0000o`000?ooool3o`000003ooooool0003o000000?ooooo0_l000000ooooooo
0000o`00000?ooooo`Co00001?ooool2o`0000Sooooo0ol0000Jooooo`;o0000AOooool001cooooo
00?o0000ooooooooool0AOooool2o`0000Sooooo0_l00004ooooo`?o00003Oooool2o`0000cooooo
0_l0000Looooo`;o00000_ooool2o`0000;ooooo7ol0000:ooooo`;o00001oooool2o`0000Sooooo
0_l00004ooooo`;o00004?ooool2o`0000;ooooo0_l0000<ooooo`;o0000B?ooool001cooooo00?o
0000ooooooooool0A?ooool4o`0000Oooooo1Ol000000ooooooo0000o`000002o`0000cooooo0_l0
000Zooooo`;o00001_oooolJo`000004ooooool0003o0000o`0000Wooooo1?l00007ooooo`;o0000
2?ooool2o`0001Kooooo0_l00002ooooo`;o00001oooool2o`0000?ooooo0_l00018ooooo`007?oo
ool00ol0003oooooooooo`14ooooo`Co00002Oooool4o`0000;ooooo0_l0000Vooooo`;o000000?o
ooooo`000?l000000_ooool2o`0000kooooo0_l000000ooooooo0000o`00000<o`000003ooooool0
003o000000go000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l0000Looooo`?o00001ooo
ool2o`000004ooooool0003o0000ooooo`;o00002_ooool2o`0004gooooo000Looooo`03o`000?oo
oooooooo04Wooooo0_l00007ooooo`?o00004?ooool4o`0001Kooooo0_l000001Ooooooo0000o`00
0?l0003ooooo00;o00003_ooool2o`000003ooooool0003o000001_o00000_ooool2o`0000;ooooo
0_l00002ooooo`;o00007?ooool3o`0000Gooooo1?l000001?oooooo0000o`000?ooool2o`0005Wo
oooo000Looooo`03o`000?oooooooooo04;ooooo0_l00005ooooo`;o00001?ooool2o`000003oooo
ool0003o0000017ooooo1?l0000Aooooo`Co00001Oooool2o`0000Oooooo0_l0000<oooooago0000
00?oooooo`000?l000001_ooool2o`0001[ooooo1?l00006ooooo`;o00000oooool3o`0000Sooooo
0_l0001Aooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00000_ooool2o`0000?ooooo0_l0
0002ooooo`;o00001oooool2o`0000oooooo0_l00004ooooo`?o00002?ooool4o`000003ooooool0
003o000000_ooooo0_l0000>oooooa_o000000?oooooo`000?l000001?ooool2o`0000?ooooo0_l0
00000ooooooo0000o`00000Booooo`Co00003_ooool2o`0000Sooooo0_l0001Aooooo`007?ooool0
0ol0003oooooooooo`12ooooo`;o00000_ooool2o`0000?ooooo0_l0000;ooooo`;o00003oooool2
o`0000Cooooo0ol0000=ooooo`;o00003Oooool2o`0000[ooooo7?l00008ooooo`;o00000oooool2
o`000003ooooool0003o0000013ooooo1?l0000<ooooo`Co0000GOooool001cooooo00?o0000oooo
ooooool0Aoooool2o`000004ooooool0003o0000ooooo`;o00007?ooool2o`0000cooooo0_l0000C
ooooo`;o00002_oooolJo`0000Oooooo0ol0000Gooooo`;o000000?oooooo`000?l000000_l0000:
ooooo`So00001Oooool2o`0005Cooooo000Looooo`03o`000?oooooooooo04;ooooo0_l00003oooo
o`;o000000Coooooo`000?l0003ooooo0_l00008ooooo`;o00004_ooool2o`0000cooooo0_l0000O
ooooo`_o000000Goooooo`000?l0003o0000ooooo`0:o`0000Kooooo1?l0000Gooooo`;o00000ooo
ool3o`0000Sooooo0ol00004ooooo`;o00001Oooool2o`0000Cooooo0_l0001>ooooo`007?ooool0
0ol0003oooooooooo`12ooooo`;o00002Oooool2o`0000Gooooo0_l000000ooooooo0000o`000002
o`0003cooooo0_l000000ooooooo0000o`000002ooooo`Ko000000?oooooo`000?l000002ol00000
1?oooooo0000o`000?l00004ooooo`;o00007oooool2o`0000?ooooo0_l00003ooooo`;o00002_oo
ool2o`0000;ooooo0_l00002ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0Boooool2
o`0000;ooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l0000;ooooo`;o00006?ooool3
o`0001Cooooo0_l00005ooooo`Go000000?oooooo`000?l000002ol00002ooooo`?o00007oooool2
o`0000Wooooo0_l00005ooooo`;o00002?ooool3o`000003ooooool0003o000005;ooooo000Loooo
o`03o`000?oooooooooo04Oooooo0_l00002ooooo`;o00000_ooool5o`0001;ooooo0_l0000Hoooo
o`?o00004Oooool2o`000003ooooool0003o000000Gooooo5?l0000Sooooo`;o00002Oooool2o`00
00Gooooo0_l00009ooooo`;o0000EOooool001cooooo0_l00018ooooo`;o00002?ooool4o`0000So
oooo0_l00008ooooo`;o00006oooool2o`0000kooooo0_l000000ooooooo0000o`000004oooooaKo
00002Oooool2o`000003ooooool0003o000001oooooo0_l0001Wooooo`007?ooool00ol0003ooooo
ooooo`1Cooooo`?o00001oooool2o`0000Sooooo0_l0000Kooooo`;o00003_ooool2o`000003oooo
ool0003o000000Cooooo3ol00002ooooo`Go00000oooool3o`0000?ooooo0_l000000ooooooo0000
o`00000Sooooo`;o0000Hoooool001cooooo00?o0000ooooooooool0Coooool4o`000003ooooool0
003o000003kooooo0_l00008ooooo`Go000000?oooooo`000?l000001Ol00004ooooo`;o00001Ooo
ool3o`0002?ooooo0_l00006ooooo`;o00003_ooool2o`0005?ooooo000Looooo`03o`000?oooooo
oooo04oooooo1?l0000]ooooo`;o00008_ooool2o`0000?ooooo0_l00002ooooo`;o00003_ooool2
o`0000Cooooo0_l0000Cooooo`;o00000_ooool2o`0000Cooooo0ol0000?ooooo`;o0000Doooool0
01cooooo00?o0000ooooooooool0Coooool2o`0001cooooo0_l00005ooooo`;o00002_ooool2o`00
02Oooooo0_l00002ooooo`?o00003Oooool2o`0000Cooooo0ol00009ooooo`;o00001oooool4o`00
00Kooooo0ol0001Tooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00003oooool2o`0000;o
oooo0_l00007ooooo`Co00000oooool6o`0000Kooooo0_l0000Iooooo`;o00003oooool2o`0000;o
oooo2?l0000>ooooo`;o00002Oooool2o`0000Gooooo0_l00002ooooo`?o00001?ooool2o`0006Ko
oooo000Looooo`03o`000?oooooooooo04gooooo0_l000001?oooooo0000o`000?l0000;ooooo`;o
00000_ooool2o`000003ooooool0003o000000Cooooo0_l00005ooooo`;o00000_ooool2o`0000Ko
oooo0_l00002ooooo`;o00005Oooool2o`0000oooooo0_l000001?oooooo0000o`000?ooool6o`00
01Wooooo0_l00003ooooo`Co00000oooool2o`0000?ooooo0ol0000=ooooo`;o0000Eoooool001co
oooo00?o0000ooooooooool0D?ooool3o`0000_ooooo0_l00002ooooo`;o000000?oooooo`000?l0
00003oooool2o`0000[ooooo0_l0000Eooooo`;o00001oooool2o`0000Wooooo0_l00003ooooo`;o
00001?ooool3o`0001Wooooo0_l00007ooooo`;o000000?oooooo`000?l000003_ooool2o`0005Oo
oooo000Looooo`03o`000?oooooooooo057ooooo0_l0000Sooooo`;o0000:Oooool3o`00017ooooo
0_l000001?oooooo0000o`000?l0000Iooooo`;o00001oooool2o`0000oooooo0_l0001Iooooo`00
7?ooool00ol0003oooooooooo`1Aooooo`;o0000:?ooool2o`0002Cooooo0_l0000Booooo`;o0000
1oooool2o`0000_ooooo0_l00007ooooo`;o00003_ooool2o`0000Cooooo0_l00002ooooo`;o0000
FOooool001cooooo00?o0000ooooooooool0IOooool3o`0001?ooooo0_l00011ooooo`;o00002ooo
ool2o`000003ooooool0003o000000Cooooo0_l00005ooooo`;o00001oooool2o`0000Cooooo0_l0
001Mooooo`007?ooool00ol0003oooooooooo`1Cooooo`?o00003oooool3o`0004[ooooo0_l00004
ooooo`;o00003?ooool2o`0000Kooooo0_l00004ooooo`?o00001?ooool2o`0000?ooooo0_l00002
ooooo`;o0000Hoooool001cooooo00?o0000ooooooooool0DOooool8o`0000kooooo0_l00019oooo
o`;o000000Coooooo`000?l0003ooooo1?l0000:ooooo`;o00001?ooool2o`0000Oooooo0_l00009
ooooo`;o0000Ioooool001cooooo00?o0000ooooooooool0C?ooool2o`0000?ooooo0_l00002oooo
o`Co00003_ooool2o`00013ooooo1?l00004ooooo`;o0000<_ooool2o`0000?ooooo0_l00009oooo
o`;o00001Oooool2o`0000Oooooo0_l00006ooooo`;o000000?oooooo`000?l000002oooool2o`00
05[ooooo000Looooo`03o`000?oooooooooo04cooooo0_l00008ooooo`?o00004_ooool2o`0000Ko
oooo0_l00004ooooo`Co00001?ooool2o`0004;ooooo0_l000000ooooooo0000o`00000Cooooo`?o
00003Oooool2o`0005[ooooo000Looooo`03o`000?oooooooooo05Kooooo0ol0000Aooooo`?o0000
0oooool2o`000003ooooool0003o000001Cooooo0_l0000Dooooo`;o00005_ooool2o`0000_ooooo
0_l00002ooooo`?o00004oooool2o`0006Wooooo000Looooo`;o0000F?ooool2o`00017ooooo0_l0
0004ooooo`;o00004oooool2o`0000;ooooo0_l0000Cooooo`?o00000_ooool2o`0000?ooooo0_l0
000=ooooo`;o00002oooool2o`0000?ooooo0ol0000Gooooo`;o0000I?ooool001cooooo00?o0000
ooooooooool0Eoooool2o`0000?ooooo0_l000000ooooooo0000o`00000<ooooo`;o00003oooool2
o`0000Gooooo0_l0000Gooooo`?o00000_ooool7o`0001;ooooo1?l00004ooooo`;o00001?ooool3
o`0000?ooooo0_l00007ooooo`;o00002?ooool2o`0006Cooooo000Looooo`03o`000?oooooooooo
05cooooo1ol0000:ooooo`;o00003oooool3o`0001gooooo0ol00004ooooo`Co00004oooool4o`00
00Kooooo0_l00003ooooo`;o00000oooool2o`0000Oooooo0_l0001^ooooo`007?ooool00ol0003o
ooooooooo`1Dooooo`;o00002?ooool2o`000003ooooool0003o000000_ooooo0_l00008ooooo`;o
00001Oooool2o`0000_ooooo0_l0000Looooo`;o00001?ooool2o`0000Sooooo0_l0000:ooooo`;o
00002?ooool2o`000003ooooool0003o0000013ooooo0_l0001Rooooo`007?ooool00ol0003ooooo
ooooo`1Dooooo`;o00001Oooool2o`00017ooooo0_l00008ooooo`;o00002Oooool2o`0000Oooooo
0_l00002ooooo`;o000000?oooooo`000?l000003_ooool2o`0000Gooooo0_l00004ooooo`;o0000
2?ooool2o`0001Cooooo0_l000000ooooooo0000o`00000:ooooo`Co00000_ooool2o`0006;ooooo
000Looooo`03o`000?oooooooooo05Gooooo0_l00004ooooo`;o00007_ooool2o`000003ooooool0
003o000000?ooooo0_l00004ooooo`;o00001Oooool2o`000003ooooool0003o000000Cooooo0ol0
0007ooooo`;o00000_ooool2o`0000;ooooo0_l00002ooooo`;o00008_ooool3o`0000Wooooo1?l0
0008ooooo`;o0000G?ooool001cooooo00?o0000ooooooooool0EOooool2o`0000Cooooo0_l00004
ooooo`;o00004?ooool2o`0000Kooooo0_l000000ooooooo0000o`000003ooooo`;o000000Cooooo
o`000?l0003ooooo0_l0000>ooooo`?o00002oooool2o`0000;ooooo0_l00002ooooo`;o00002?oo
ool3o`0000;ooooo0ol0000Booooo`?o00003Oooool3o`0000Gooooo0_l0001Looooo`007?ooool0
0ol0003oooooooooo`1Nooooo`;o000000?oooooo`000?l000004?ooool2o`0000kooooo0_l00000
1?oooooo0000o`000?l00006ooooo`;o00001?ooool2o`0000Cooooo0_l00002ooooo`;o00005?oo
ool2o`0000;ooooo0ol00002ooooo`?o00002oooool2o`0001Gooooo0ol0001Sooooo`007?ooool0
0ol0003oooooooooo`1Nooooo`;o00001Oooool2o`000003ooooool0003o000001gooooo0_l00006
ooooo`;o00001?ooool5o`000005ooooool0003o0000o`000?ooool00_l00005ooooo`;o00002Ooo
ool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000Wooooo0_l000000ooooooo0000o`00
0009ooooo`;o00002oooool2o`0006?ooooo000Looooo`03o`000?oooooooooo05oooooo0ol00003
ooooo`;o000000?oooooo`000?l000002Oooool3o`0000?ooooo0_l00003ooooo`;o00001Oooool2
o`000003ooooool0003o000000;o00002Oooool5o`0000;ooooo0_l00008ooooo`;o00000oooool2
o`0000Cooooo0_l0000Fooooo`;o00003?ooool2o`00073ooooo000Looooo`03o`000?oooooooooo
05Wooooo0_l00004ooooo`?o00000oooool4o`000003ooooool0003o000000?ooooo0_l00002oooo
o`?o00000oooool2o`0000?ooooo0_l00005ooooo`Oo00001_ooool2o`0001Oooooo0_l00002oooo
o`;o00003?ooool2o`0000Wooooo0_l00008ooooo`;o00000_ooool2o`0000Wooooo0_l0001Voooo
o`007?ooool00ol0003oooooooooo`1Iooooo`;o00001Oooool2o`0000Cooooo0ol000000ooooooo
0000o`000003ooooo`;o00000_ooool2o`00017ooooo0_l00005ooooo`;o00000oooool2o`00013o
oooo0_l00005ooooo`;o00000_ooool2o`000003ooooool0003o000000Wooooo0_l00009ooooo`;o
00000oooool2o`0000?ooooo0_l00002ooooo`;o00001?ooool2o`0000?ooooo0_l0001Vooooo`00
7?ooool00ol0003oooooooooo`1Oooooo`;o00004_ooool2o`00017ooooo0_l00005ooooo`;o0000
1Oooool2o`0000kooooo0_l00007ooooo`;o00000oooool2o`0000Cooooo0_l00004ooooo`?o0000
3?ooool2o`0000Oooooo0_l00004ooooo`;o0000Joooool001cooooo00?o0000ooooooooool0Gooo
ool2o`0000Gooooo0_l0000>ooooo`;o00003_ooool2o`0000Gooooo1_l000000ooooooo0000o`00
0006ooooo`;o00001_ooool2o`0000Oooooo0_l000000ooooooo0000o`000006ooooo`;o00001?oo
ool3o`0000?ooooo0_l0000@ooooo`;o00001_ooool2o`0006Wooooo00001_ooooook^k^oc8b<_l0
003o<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003o
ooooooooo`1Vooooo`;o00003_ooool2o`0000gooooo0_l00008ooooo`Co00001?ooool2o`0000?o
oooo0_l00006ooooo`;o000000?oooooo`000?l000000_l00005ooooo`;o00004_ooool2o`0001So
oooo0_l00004ooooo`;o0000Hoooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q
8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo08Gooooo0_l0000:
ooooo`;o00000_ooool4o`0000_ooooo0_l000000ooooooo0000o`000002o`0002Sooooo0_l0000?
ooooo`;o0000Hoooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0Koooool2o`0000Kooooo0_l0000E
ooooo`;o000000?oooooo`000?l000000_ooool3o`0002Wooooo0_l0000@ooooo`;o00003?ooool2
o`0006Kooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRH
V?ooooooV9RHoc8b<P06ooooo`?o0000Koooool2o`000003ooooool0003o000000?ooooo0_l00009
ooooo`;o00001_ooool2o`0000;ooooo0_l00004ooooo`;o00003?ooool2o`0001gooooo0_l00009
ooooo`;o00001_ooool4o`0000Wooooo0_l0001Vooooo`0000?oooooo`000?ooool00_ooool00ol0
003oooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`1a
ooooo`?o00000oooool3o`0000Sooooo1?l00004ooooo`?o00001oooool2o`0000Oooooo0_l00003
ooooo`;o00000oooool3o`0001?ooooo0_l00002ooooo`;o000000?oooooo`000?l000001_ooool2
o`0000Kooooo1?l0001aooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09oooo
o`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`1aooooo`?o00000oooool3
o`0000Sooooo1?l000000ooooooo0000o`000002ooooo`;o00002_ooool4o`0000;ooooo1?l00006
ooooo`?o00003oooool2o`0000;ooooo0_l00002ooooo`Go0000Poooool00006oooooomgMgOoV9RH
oooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0
L_ooool2o`0000;ooooo1Ol00002ooooo`;o00001?ooool2o`0000;ooooo0_l0000:ooooo`;o0000
0_ooool4o`0000Cooooo0_l00005ooooo`;o000000?oooooo`000?l000003_ooool2o`0000Oooooo
0_l00025ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@
4?nYZJT01_ooool00ol0003oooooooooo`1_ooooo`;o00001Oooool2o`000003ooooool0003o0000
00;ooooo0_l00006ooooo`?o00002?ooool2o`000004ooooool0003o0000ooooo`Oo00002Oooool2
o`000003ooooool0003o000001Gooooo0ol0000=ooooo`;o00001Oooool2o`00073ooooo000Loooo
o`03o`000?oooooooooo06oooooo1?l0000Booooo`?o00002?ooool2o`0000Cooooo0_l00002oooo
o`?o00001Oooool3o`0000Sooooo0_l00006ooooo`;o00002Oooool3o`0000gooooo1?l00003oooo
o`;o0000L?ooool001cooooo00?o0000ooooooooool0LOooool2o`0000[ooooo0_l00003ooooo`?o
000000?oooooo`000?l000002?ooool2o`000003ooooool0003o000000Gooooo0_l00006ooooo`?o
00000_ooool2o`0000Cooooo0_l00006ooooo`;o00002?ooool2o`0000Oooooo0_l00005ooooo`;o
000000?oooooo`000?l00000MOooool001cooooo00?o0000ooooooooool0OOooool2o`0000?ooooo
0ol0000;ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Kooooo0_l00003ooooo`?o0000
0oooool2o`0000?ooooo1?l00009ooooo`;o00001?ooool2o`000003ooooool0003o000000Gooooo
0_l0001hooooo`007?ooool00ol0003oooooooooo`1dooooo`;o00002?ooool2o`0001Gooooo0_l0
000Aooooo`?o00000_ooool2o`000003ooooool0003o000000Co00001oooool2o`0000Gooooo0ol0
00000ooooooo0000o`00001oooooo`007?ooool00ol0003oooooooooo`1dooooo`?o00001Oooool4
o`0000Kooooo0_l00008ooooo`Co000000?oooooo`000?l000002?ooool2o`0000Sooooo1?l00003
ooooo`;o000000Coooooo`000?l0003o00001oooool2o`0000Gooooo0_l00003ooooo`;o0000O_oo
ool001cooooo00?o0000ooooooooool0MOooool2o`0000Gooooo0_l00008ooooo`;o00002?ooool4
o`0000Oooooo0_l00002ooooo`;o00002_ooool2o`0000;ooooo0ol00002ooooo`;o00004oooool2
o`0007kooooo000Looooo`03o`000?oooooooooo093ooooo0_l00009ooooo`;o00000_ooool2o`00
00kooooo1?l0002Fooooo`007?ooool00ol0003oooooooooo`1oooooo`;o00001_ooool2o`0001Co
oooo0_l00003ooooo`Go00002?ooool5o`00017ooooo0_l00022ooooo`007?ooool00ol0003ooooo
ooooo`1jooooo`;o00000oooool2o`0000Kooooo0_l00006ooooo`?o00000oooool2o`0000Kooooo
0_l00003ooooo`Go00002?ooool2o`000003ooooool0003o000000Wooooo0_l00006ooooo`;o0000
P_ooool001cooooo00?o0000ooooooooool0N_ooool2o`0000Oooooo0_l0000:ooooo`?o00000ooo
ool2o`0002Kooooo0_l0002:ooooo`007?ooool00ol0003oooooooooo`1mooooo`;o00001?ooool2
o`0000Cooooo1_l000000ooooooo0000o`00000]ooooo`;o0000R?ooool001cooooo0_l0001noooo
o`;o00001?ooool2o`0000Cooooo1_l0000Dooooo`;o00003Oooool2o`0000?ooooo0_l00003oooo
o`;o000000?oooooo`000?l00000R?ooool001cooooo00?o0000ooooooooool0Poooool2o`0000go
oooo0_l00002ooooo`;o00002oooool2o`0000gooooo0_l00003ooooo`;o00000oooool2o`0008_o
oooo000Looooo`03o`000?oooooooooo09;ooooo0_l00002ooooo`;o000000?oooooo`000?l00000
[_ooool001cooooo00?o0000ooooooooool0U_ooool5o`000:kooooo000Looooo`03o`000?oooooo
oooo09Oooooo0_l00002ooooo`;o0000[?ooool001cooooo00?o0000ooooooooool0Voooool2o`00
0:cooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000
oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Booooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooood[o
oooo000Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`005?oo
ool00ol0003oooooooooo`05ooooo`?o0000oooooom:ooooo`005?ooool00ol0003oooooooooo`3o
oooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000oooooooo
ool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Booooo`03oeEEEOmV
IVKo00000?ooooooE?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Gooooo
00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0Eooooo`05onk^k_lb<S;o0000oa0@
4?o<c<`01Oooool00ol0003ok^k^ooooo`03ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0T?ooool0
0:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00002Oooool01OmEEEGoMgMgoooooonH
V9So8B4Q00Gooooo00?oEEEEojVYZOooool00oooool01OlQ8B7oV9RHoooooonHV9So8B4Q093ooooo
002Vooooo`05o`000?ooooooooooooooool000006?ooool01Ol0003ooooooooooooooooo000000Go
oooo00?oZJVYoeEEEOooool00oooool01Ol0003ooooooooooooooooo0000093ooooo002Vooooo`05
o`000?ooooooooooooooool000002Oooool6o`0000Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@06
ooooo`03ob4Q8Ooooooooooo00;ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P2@ooooo`00Y_ooool0
1Ol0003oQhN7oooooonYZJWo000001Sooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03oeEE
EOo<c<cooooo00;ooooo00Goc<c<o`000?l0003o0000olc<c02@ooooo`00YOooool00ol@413o0000
ogMgM`02o`000003oiRHV?oooooooooo01Kooooo00?oEEEEohN7Qoooool02?ooool00onYZJWoMgMg
ooooo`02ooooo`05oa0@4?nj^[[ooooookZj^_l@4100T?ooool00<?ooooo00?ogMgMoa0@4?nHV9P0
1Oooool01Ol@413ooooooooooooooooo<S8b00?ooooo00Go0000okZj^_oooooo^[Zjo`00002@oooo
o`00a?ooool01?o<c<coA4A4o`000?l@4103ooooo`Go00000oooool01OnYZJWo410@o`000?l@413o
ZJVY093ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(684) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.37675 .32362 Mdot
.37987 .37512 Mdot
.45878 .6406 Mdot
.6213 .39114 Mdot
.59721 .60718 Mdot
.48607 .65533 Mdot
.37279 .5624 Mdot
.35188 .55846 Mdot
.47508 .66065 Mdot
.40629 .24788 Mdot
.39448 .54491 Mdot
.63856 .48864 Mdot
.38273 .57302 Mdot
.59244 .44068 Mdot
.20659 .57645 Mdot
.54719 .38327 Mdot
.39482 .39352 Mdot
.6969 .58026 Mdot
.53964 .39133 Mdot
.46782 .62964 Mdot
.40454 .42695 Mdot
.59643 .43541 Mdot
.37774 .37764 Mdot
.59325 .43848 Mdot
.57599 .39687 Mdot
.38659 .34834 Mdot
.3764 .31825 Mdot
.60053 .4032 Mdot
.56191 .42412 Mdot
.40897 .56551 Mdot
.61667 .64114 Mdot
.19661 .66425 Mdot
.58657 .36431 Mdot
.65316 .30505 Mdot
.37652 .59921 Mdot
.60248 .78841 Mdot
.48585 .68483 Mdot
.36566 .54025 Mdot
.35774 .57805 Mdot
.37635 .59263 Mdot
.38428 .58895 Mdot
.38421 .3546 Mdot
.42131 .58579 Mdot
.41746 .63094 Mdot
.63495 .39694 Mdot
.25024 .47249 Mdot
.72834 .65419 Mdot
.60244 .40526 Mdot
.38036 .32894 Mdot
.48881 .63276 Mdot
.72597 .31862 Mdot
.36413 .5388 Mdot
.25478 .55441 Mdot
.10826 .41752 Mdot
.40248 .57961 Mdot
.6164 .39428 Mdot
.50497 .67757 Mdot
.62483 .42286 Mdot
.60322 .41809 Mdot
.65178 .2854 Mdot
.57208 .42034 Mdot
.68747 .61173 Mdot
.36295 .3254 Mdot
.45764 .62513 Mdot
.48022 .66015 Mdot
.40606 .58794 Mdot
.41684 .38691 Mdot
.37765 .57751 Mdot
.56029 .47503 Mdot
.47388 .6335 Mdot
.60803 .40418 Mdot
.39237 .5427 Mdot
.42269 .39203 Mdot
.54564 .41385 Mdot
.29431 .47233 Mdot
.29179 .57851 Mdot
.66264 .63705 Mdot
.54975 .30828 Mdot
.47719 .17482 Mdot
.33354 .63144 Mdot
.58198 .44085 Mdot
.44697 .15677 Mdot
.22526 .57788 Mdot
.3916 .38359 Mdot
.67851 .34743 Mdot
.40189 .76442 Mdot
.56141 .43919 Mdot
.54308 .54865 Mdot
.66475 .41161 Mdot
.3731 .45282 Mdot
.47778 .66736 Mdot
.37988 .34419 Mdot
.63329 .39325 Mdot
.56453 .44998 Mdot
.5627 .21907 Mdot
.62864 .37408 Mdot
.63332 .40353 Mdot
.40612 .31307 Mdot
.39548 .55171 Mdot
.64817 .46934 Mdot
.4073 .63155 Mdot
.25576 .53653 Mdot
.59619 .38133 Mdot
.47636 .64499 Mdot
.35982 .37073 Mdot
.62489 .38468 Mdot
.40344 .58585 Mdot
.58032 .42665 Mdot
.4372 .57244 Mdot
.36978 .34552 Mdot
.56704 .45177 Mdot
.67712 .57553 Mdot
.32102 .45131 Mdot
.40818 .33579 Mdot
.30265 .27767 Mdot
.57965 .41809 Mdot
.6014 .42793 Mdot
.38448 .37695 Mdot
.51506 .67738 Mdot
.51343 .53975 Mdot
.41011 .39477 Mdot
.36517 .58556 Mdot
.36432 .35294 Mdot
.63762 .4593 Mdot
.51715 .66419 Mdot
.25841 .54131 Mdot
.24409 .52597 Mdot
.80915 .54637 Mdot
.54838 .41658 Mdot
.20927 .54262 Mdot
.49919 .65555 Mdot
.37894 .35984 Mdot
.38221 .58004 Mdot
.62449 .45963 Mdot
.41824 .37305 Mdot
.36087 .55532 Mdot
.6615 .58656 Mdot
.57965 .68694 Mdot
.41267 .33434 Mdot
.54374 .51668 Mdot
.35517 .58309 Mdot
.37993 .59427 Mdot
.74355 .35422 Mdot
.39092 .38017 Mdot
.66904 .5939 Mdot
.36178 .5593 Mdot
.75799 .47933 Mdot
.6276 .45683 Mdot
.76735 .39951 Mdot
.50213 .14853 Mdot
.73558 .33313 Mdot
.22772 .38838 Mdot
.69369 .62033 Mdot
.35888 .56401 Mdot
.59751 .38764 Mdot
.40073 .3703 Mdot
.39283 .36827 Mdot
.57651 .46244 Mdot
.57285 .4052 Mdot
.62192 .44906 Mdot
.59297 .46247 Mdot
.69293 .7101 Mdot
.6151 .45385 Mdot
.4595 .56857 Mdot
.42368 .36027 Mdot
.56518 .40354 Mdot
.46798 .68439 Mdot
.54206 .44086 Mdot
.36669 .54021 Mdot
.61076 .41733 Mdot
.58237 .39988 Mdot
.60089 .37254 Mdot
.37759 .58737 Mdot
.30035 .76102 Mdot
.4098 .19609 Mdot
.4929 .79588 Mdot
.25394 .37033 Mdot
.50375 .66645 Mdot
.58699 .45168 Mdot
.67186 .61476 Mdot
.67888 .37042 Mdot
.59751 .41858 Mdot
.69757 .28337 Mdot
.58442 .40458 Mdot
.48685 .34562 Mdot
.66805 .37626 Mdot
.45673 .81208 Mdot
.39703 .49833 Mdot
.56509 .4265 Mdot
.46482 .20795 Mdot
.77919 .40153 Mdot
.64724 .63113 Mdot
.39772 .58472 Mdot
.48718 .6996 Mdot
.50095 .68862 Mdot
.40676 .60297 Mdot
.63248 .47334 Mdot
.40463 .25609 Mdot
.59204 .48507 Mdot
.25456 .54498 Mdot
.3557 .3769 Mdot
.70428 .61202 Mdot
.40457 .32665 Mdot
.37935 .17598 Mdot
.46863 .43075 Mdot
.38259 .52153 Mdot
.68954 .57437 Mdot
.45814 .6525 Mdot
.24734 .5494 Mdot
.66775 .60895 Mdot
.63068 .40688 Mdot
.37817 .33469 Mdot
.77932 .39669 Mdot
.60029 .35248 Mdot
.78654 .68553 Mdot
.40475 .38631 Mdot
.46964 .5175 Mdot
.39301 .58317 Mdot
.51086 .64447 Mdot
.55949 .43255 Mdot
.61833 .44445 Mdot
.36594 .32379 Mdot
.59618 .40776 Mdot
.38249 .43758 Mdot
.58828 .39925 Mdot
.45952 .6192 Mdot
.63988 .59832 Mdot
.42476 .59901 Mdot
.81384 .52702 Mdot
.43116 .38853 Mdot
.50454 .58311 Mdot
.46432 .6518 Mdot
.34694 .29534 Mdot
.40283 .54999 Mdot
.6632 .5819 Mdot
.4755 .68152 Mdot
.6564 .6194 Mdot
.58676 .37967 Mdot
.48158 .67891 Mdot
.68978 .58997 Mdot
.55775 .69734 Mdot
.63204 .39893 Mdot
.73204 .46414 Mdot
.36932 .55785 Mdot
.38137 .31743 Mdot
.57102 .41988 Mdot
.24999 .52377 Mdot
.60452 .47447 Mdot
.20506 .55355 Mdot
.26564 .53773 Mdot
.26025 .55068 Mdot
.29457 .60533 Mdot
.6734 .6241 Mdot
.24886 .43063 Mdot
.48912 .48582 Mdot
.40376 .39537 Mdot
.63857 .39675 Mdot
.37002 .80588 Mdot
.3627 .56341 Mdot
.62947 .40718 Mdot
.41495 .77101 Mdot
.36231 .55931 Mdot
.61884 .42679 Mdot
.38801 .59233 Mdot
.39758 .37119 Mdot
.51485 .56488 Mdot
.37203 .38054 Mdot
.62327 .39701 Mdot
.39418 .56295 Mdot
.48245 .69337 Mdot
.38822 .34869 Mdot
.58385 .4239 Mdot
.58944 .44926 Mdot
.24538 .5462 Mdot
.56153 .40803 Mdot
.3937 .80373 Mdot
.6043 .40324 Mdot
.45686 .65718 Mdot
.6339 .37777 Mdot
.77834 .36245 Mdot
.58239 .68086 Mdot
.42759 .37394 Mdot
.2664 .5413 Mdot
.48499 .67377 Mdot
.57788 .61319 Mdot
.62756 .56445 Mdot
.58213 .43459 Mdot
.24707 .53243 Mdot
.47001 .53316 Mdot
.40836 .58345 Mdot
.6613 .40821 Mdot
.42663 .44303 Mdot
.46872 .66734 Mdot
.24963 .54785 Mdot
.6682 .3845 Mdot
.36086 .36995 Mdot
.61305 .39134 Mdot
.48204 .68424 Mdot
.36445 .34407 Mdot
.63176 .45675 Mdot
.72248 .67591 Mdot
.25367 .52685 Mdot
.36883 .56006 Mdot
.60299 .50694 Mdot
.62776 .44901 Mdot
.5058 .69026 Mdot
.40835 .37748 Mdot
.40367 .56884 Mdot
.39303 .33481 Mdot
.79406 .41563 Mdot
.26145 .37776 Mdot
.5856 .76459 Mdot
.69901 .5791 Mdot
.16856 .4881 Mdot
.51182 .79307 Mdot
.27154 .40577 Mdot
.78649 .55717 Mdot
.58088 .81934 Mdot
.47022 .68364 Mdot
.723 .40954 Mdot
.4942 .67841 Mdot
.5909 .38436 Mdot
.48258 .65576 Mdot
.42617 .82489 Mdot
.59537 .4022 Mdot
.50632 .67012 Mdot
.67102 .71452 Mdot
.57054 .4111 Mdot
.41924 .3469 Mdot
.18051 .59449 Mdot
.34026 .2745 Mdot
.48982 .44677 Mdot
.51028 .66866 Mdot
.64276 .24554 Mdot
.58351 .40838 Mdot
.55925 .3699 Mdot
.39935 .36433 Mdot
.66498 .41603 Mdot
.7012 .59586 Mdot
.65156 .60324 Mdot
.73979 .37989 Mdot
.31365 .28494 Mdot
.51524 .43299 Mdot
.38952 .35368 Mdot
.48785 .17314 Mdot
.29397 .47501 Mdot
.23555 .52663 Mdot
.35573 .5782 Mdot
.29801 .75756 Mdot
.57108 .35023 Mdot
.56553 .52127 Mdot
.39854 .45566 Mdot
.3748 .34846 Mdot
.50211 .77035 Mdot
.39931 .57151 Mdot
.44804 .19995 Mdot
.46441 .28491 Mdot
.63062 .44092 Mdot
.41544 .57283 Mdot
.64005 .48379 Mdot
.38501 .44435 Mdot
.74567 .43476 Mdot
.43859 .69624 Mdot
.6275 .39609 Mdot
.25611 .43859 Mdot
.60308 .42304 Mdot
.77294 .40979 Mdot
.62613 .40259 Mdot
.40086 .33661 Mdot
.50792 .41941 Mdot
.59644 .56889 Mdot
.35948 .23008 Mdot
.45806 .42763 Mdot
.68523 .62767 Mdot
.5966 .44369 Mdot
.62684 .44149 Mdot
.69561 .60648 Mdot
.39833 .34497 Mdot
.64354 .41889 Mdot
.75278 .64272 Mdot
.62892 .44607 Mdot
.3792 .53784 Mdot
.55405 .58033 Mdot
.40186 .28964 Mdot
.56297 .44495 Mdot
.36108 .35195 Mdot
.39678 .59083 Mdot
.35145 .56544 Mdot
.52272 .39735 Mdot
.3626 .57101 Mdot
.60718 .39261 Mdot
.54243 .57393 Mdot
.37128 .36755 Mdot
.68169 .4318 Mdot
.40436 .34816 Mdot
.57721 .18805 Mdot
.38993 .59572 Mdot
.22933 .53692 Mdot
.68779 .47698 Mdot
.3864 .56583 Mdot
.3285 .31137 Mdot
.5461 .36126 Mdot
.54313 .45326 Mdot
.33232 .2948 Mdot
.50523 .69744 Mdot
.23318 .54831 Mdot
.40449 .57446 Mdot
.62354 .44982 Mdot
.60642 .37849 Mdot
.40927 .55061 Mdot
.58872 .23745 Mdot
.61585 .64646 Mdot
.62261 .40134 Mdot
.40069 .33887 Mdot
.37983 .35719 Mdot
.64235 .44438 Mdot
.5931 .41737 Mdot
.45878 .67035 Mdot
.24502 .53081 Mdot
.25252 .5516 Mdot
.24143 .52672 Mdot
.52684 .67142 Mdot
.17748 .45624 Mdot
.37905 .59359 Mdot
.1951 .4783 Mdot
.33871 .72437 Mdot
.52962 .39089 Mdot
.50433 .69391 Mdot
.61734 .43733 Mdot
.57611 .3856 Mdot
.39764 .56173 Mdot
.23839 .33164 Mdot
.53245 .46559 Mdot
.40012 .32147 Mdot
.39528 .53907 Mdot
.68958 .40207 Mdot
.32549 .53611 Mdot
.6939 .58736 Mdot
.47204 .41749 Mdot
.41572 .568 Mdot
.38286 .3353 Mdot
.41364 .55611 Mdot
.62599 .44392 Mdot
.55989 .45643 Mdot
.37281 .36266 Mdot
.66994 .62336 Mdot
.62456 .38208 Mdot
.61755 .42643 Mdot
.7902 .33699 Mdot
.28997 .46674 Mdot
.32573 .5498 Mdot
.56795 .39448 Mdot
.53045 .4406 Mdot
.67516 .62862 Mdot
.63693 .43902 Mdot
.5613 .43554 Mdot
.32237 .44163 Mdot
.40356 .60622 Mdot
.66261 .63546 Mdot
.4298 .20807 Mdot
.4082 .38407 Mdot
.39972 .79658 Mdot
.25775 .53609 Mdot
.41417 .60693 Mdot
.50575 .56057 Mdot
.23244 .54262 Mdot
.36038 .72219 Mdot
.45772 .785 Mdot
.23266 .53448 Mdot
.46594 .69783 Mdot
.60455 .33153 Mdot
.59944 .46537 Mdot
.61429 .41843 Mdot
.66553 .61139 Mdot
.39635 .379 Mdot
.43697 .51459 Mdot
.54693 .66978 Mdot
.59798 .43238 Mdot
.44432 .35258 Mdot
.42742 .78701 Mdot
.24236 .5475 Mdot
.6801 .62089 Mdot
.70301 .62164 Mdot
.60392 .42536 Mdot
.29685 .40856 Mdot
.38708 .35151 Mdot
.58405 .42401 Mdot
.59074 .45891 Mdot
.51263 .67573 Mdot
.38431 .33141 Mdot
.46427 .65032 Mdot
.26529 .53491 Mdot
.67348 .7801 Mdot
.80051 .35251 Mdot
.38334 .55368 Mdot
.50378 .78293 Mdot
.35806 .53812 Mdot
.3864 .64705 Mdot
.23971 .52976 Mdot
.58947 .42865 Mdot
.43127 .38495 Mdot
.58044 .425 Mdot
.639 .42648 Mdot
.63757 .41176 Mdot
.51646 .43606 Mdot
.70531 .28926 Mdot
.6741 .60557 Mdot
.52739 .43899 Mdot
.48498 .70231 Mdot
.44693 .80325 Mdot
.19451 .63043 Mdot
.60487 .44817 Mdot
.6038 .42992 Mdot
.42068 .37992 Mdot
.54302 .406 Mdot
.41009 .57227 Mdot
.3969 .38467 Mdot
.61069 .38041 Mdot
.54183 .73949 Mdot
.63619 .44431 Mdot
.5269 .78962 Mdot
.41284 .55439 Mdot
.47423 .41141 Mdot
.54 .45727 Mdot
.2332 .53291 Mdot
.2319 .54704 Mdot
.23934 .52246 Mdot
.41133 .58412 Mdot
.50975 .68041 Mdot
.54272 .67805 Mdot
.67171 .41839 Mdot
.59864 .38903 Mdot
.54448 .45618 Mdot
.52377 .65801 Mdot
.5492 .56672 Mdot
.23117 .39811 Mdot
.64792 .3538 Mdot
.50542 .70256 Mdot
.42148 .32852 Mdot
.29741 .26246 Mdot
.40228 .3826 Mdot
.65356 .62954 Mdot
.37517 .53993 Mdot
.69667 .58761 Mdot
.66996 .26291 Mdot
.37044 .35981 Mdot
.36891 .31929 Mdot
.50562 .66801 Mdot
.42526 .49595 Mdot
.08884 .51889 Mdot
.48846 .64565 Mdot
.77167 .60489 Mdot
.39674 .35943 Mdot
.56206 .38119 Mdot
.46931 .53801 Mdot
.43627 .49936 Mdot
.49587 .67057 Mdot
.58278 .44357 Mdot
.30881 .32928 Mdot
.45818 .66647 Mdot
.65338 .39632 Mdot
.51139 .66293 Mdot
.37727 .58505 Mdot
.50257 .65695 Mdot
.43484 .35406 Mdot
.57861 .38247 Mdot
.09338 .45449 Mdot
.31962 .52079 Mdot
.57252 .42345 Mdot
.38756 .53721 Mdot
.74109 .67809 Mdot
.63342 .42976 Mdot
.70218 .59533 Mdot
.51313 .702 Mdot
.64971 .70125 Mdot
.5796 .41156 Mdot
.48943 .66182 Mdot
.40573 .32078 Mdot
.35856 .60705 Mdot
.31051 .60332 Mdot
.24468 .55223 Mdot
.40308 .37416 Mdot
.24444 .51717 Mdot
.38687 .60502 Mdot
.6176 .37535 Mdot
.59888 .4589 Mdot
.41607 .34719 Mdot
.29639 .63484 Mdot
.58907 .36961 Mdot
.58219 .44086 Mdot
.46009 .65211 Mdot
.53361 .69094 Mdot
.23251 .63499 Mdot
.471 .6859 Mdot
.53012 .44075 Mdot
.41335 .34428 Mdot
.60692 .38444 Mdot
.42377 .35499 Mdot
.6376 .39604 Mdot
.4128 .29977 Mdot
.4008 .38171 Mdot
.28608 .33407 Mdot
.55509 .41826 Mdot
.68047 .47298 Mdot
.64024 .42579 Mdot
.63223 .40551 Mdot
.51686 .69927 Mdot
.68425 .59652 Mdot
.65344 .39071 Mdot
.51 .57503 Mdot
.66005 .61097 Mdot
.61003 .31136 Mdot
.51374 .67956 Mdot
.66136 .59944 Mdot
.70988 .50968 Mdot
.26612 .5417 Mdot
.68084 .6099 Mdot
.23276 .66934 Mdot
.38631 .55492 Mdot
.37152 .37409 Mdot
.56992 .41023 Mdot
.61205 .81503 Mdot
.61607 .64173 Mdot
.24064 .54208 Mdot
.57806 .41686 Mdot
.62177 .43494 Mdot
.36593 .38057 Mdot
.41214 .16271 Mdot
.47929 .62323 Mdot
.62396 .38897 Mdot
.39513 .39267 Mdot
.48768 .15167 Mdot
.50814 .6543 Mdot
.6793 .61445 Mdot
.41201 .54954 Mdot
.42234 .41371 Mdot
.24004 .55223 Mdot
.39724 .59877 Mdot
.50579 .7268 Mdot
.65717 .24373 Mdot
.58648 .41043 Mdot
.49509 .69418 Mdot
.73339 .32939 Mdot
.66005 .45344 Mdot
.33525 .5594 Mdot
.48304 .37108 Mdot
.37609 .3475 Mdot
.40646 .54741 Mdot
.69019 .62781 Mdot
.37056 .36865 Mdot
.39681 .34369 Mdot
.3523 .55778 Mdot
.46027 .58529 Mdot
.4681 .51601 Mdot
.39355 .54059 Mdot
.35851 .45287 Mdot
.74527 .37314 Mdot
.24803 .5308 Mdot
.68171 .62168 Mdot
.79837 .41132 Mdot
.38407 .35229 Mdot
.29921 .75868 Mdot
.70811 .29468 Mdot
.63316 .40347 Mdot
.67624 .58454 Mdot
.36895 .73431 Mdot
.54307 .70438 Mdot
.36356 .5544 Mdot
.56236 .56359 Mdot
.7071 .60555 Mdot
.62286 .45735 Mdot
.43044 .30618 Mdot
.55746 .42191 Mdot
.36103 .56254 Mdot
.35747 .42283 Mdot
.39008 .3304 Mdot
.38959 .60594 Mdot
.39228 .44031 Mdot
.57071 .38817 Mdot
.5668 .43669 Mdot
.79206 .46616 Mdot
.37904 .33269 Mdot
.24187 .55308 Mdot
.57721 .43154 Mdot
.62392 .42074 Mdot
.61862 .3737 Mdot
.6582 .50226 Mdot
.29837 .43137 Mdot
.62469 .38826 Mdot
.52154 .66349 Mdot
.54499 .4504 Mdot
.5634 .4342 Mdot
.37422 .3852 Mdot
.76003 .31992 Mdot
.26285 .53023 Mdot
.61708 .4166 Mdot
.62255 .40258 Mdot
.36271 .58421 Mdot
.46912 .52456 Mdot
.42672 .49342 Mdot
.474 .63723 Mdot
.77506 .54267 Mdot
.59198 .48404 Mdot
.41704 .37142 Mdot
.68646 .57678 Mdot
.5556 .38997 Mdot
.4161 .38035 Mdot
.57155 .46702 Mdot
.46167 .68016 Mdot
.24462 .53223 Mdot
.53093 .49837 Mdot
.68529 .60853 Mdot
.44165 .58118 Mdot
.21227 .49398 Mdot
.47048 .68824 Mdot
.58622 .39145 Mdot
.40881 .61661 Mdot
.46719 .65411 Mdot
.2454 .54507 Mdot
.66084 .37619 Mdot
.3922 .36495 Mdot
.38976 .33192 Mdot
.75472 .39265 Mdot
.49936 .6304 Mdot
.66186 .20885 Mdot
.37508 .58309 Mdot
.65314 .43864 Mdot
.20844 .52411 Mdot
.39771 .33137 Mdot
.79688 .4362 Mdot
.66142 .603 Mdot
.36443 .55392 Mdot
.27291 .53122 Mdot
.41883 .37763 Mdot
.39611 .32657 Mdot
.63664 .40034 Mdot
.60509 .44332 Mdot
.78764 .56776 Mdot
.77079 .40362 Mdot
.38497 .59016 Mdot
.68813 .61878 Mdot
.48211 .63367 Mdot
.57094 .39013 Mdot
.38656 .38269 Mdot
.49408 .34353 Mdot
.62018 .45359 Mdot
.4576 .66403 Mdot
.37461 .35506 Mdot
.69532 .61207 Mdot
.66851 .58255 Mdot
.63336 .40604 Mdot
.59322 .29577 Mdot
.38118 .56367 Mdot
.41266 .33917 Mdot
.33825 .34587 Mdot
.61504 .36704 Mdot
.60195 .44572 Mdot
.65831 .47675 Mdot
.39625 .59915 Mdot
.51894 .48169 Mdot
.71081 .61495 Mdot
.38956 .37064 Mdot
.57448 .42514 Mdot
.68712 .61196 Mdot
.59568 .51562 Mdot
.23503 .53578 Mdot
.50994 .66045 Mdot
.70332 .60047 Mdot
.68772 .59242 Mdot
.65702 .60215 Mdot
.28646 .74724 Mdot
.37688 .396 Mdot
.42296 .20461 Mdot
.63995 .4102 Mdot
.74488 .38525 Mdot
.54656 .42549 Mdot
.40704 .59474 Mdot
.48715 .69759 Mdot
.63647 .43281 Mdot
.63709 .40026 Mdot
.44129 .3159 Mdot
.6925 .416 Mdot
.41401 .42569 Mdot
.37284 .33973 Mdot
.68101 .47611 Mdot
.51089 .69107 Mdot
.48201 .13675 Mdot
.28133 .76681 Mdot
.56644 .47618 Mdot
.44834 .51432 Mdot
.39469 .38422 Mdot
.35607 .56719 Mdot
.4435 .49783 Mdot
.42488 .56546 Mdot
.38531 .37003 Mdot
.58269 .38544 Mdot
.20013 .47457 Mdot
.65485 .61065 Mdot
.61808 .45059 Mdot
.38772 .58503 Mdot
.61997 .44989 Mdot
.41294 .58762 Mdot
.44699 .40418 Mdot
.36426 .46808 Mdot
.58695 .40412 Mdot
.59742 .36933 Mdot
.49785 .44144 Mdot
.60542 .4468 Mdot
.3797 .69893 Mdot
.40316 .35436 Mdot
.30941 .30861 Mdot
.64529 .43798 Mdot
.58554 .2796 Mdot
.61718 .45745 Mdot
.30036 .64477 Mdot
.58592 .45408 Mdot
.55871 .53331 Mdot
.62554 .45695 Mdot
.58485 .45074 Mdot
.39975 .56772 Mdot
.35911 .57927 Mdot
.40613 .32165 Mdot
.23118 .54998 Mdot
.45534 .81079 Mdot
.61162 .43113 Mdot
.52578 .69152 Mdot
.22373 .51492 Mdot
.68603 .59362 Mdot
.38443 .36602 Mdot
.56765 .13921 Mdot
.39297 .59289 Mdot
.45628 .62805 Mdot
.32701 .6545 Mdot
.49706 .63372 Mdot
.4364 .6248 Mdot
.69092 .45918 Mdot
.69053 .62006 Mdot
.61612 .45884 Mdot
.63298 .30213 Mdot
.26878 .45044 Mdot
.65335 .40095 Mdot
.36434 .60252 Mdot
.68792 .37841 Mdot
.74676 .36915 Mdot
.66764 .63131 Mdot
.69866 .61887 Mdot
.40285 .57383 Mdot
.46197 .63383 Mdot
.62812 .47953 Mdot
.66122 .59732 Mdot
.48972 .70123 Mdot
.22394 .53934 Mdot
.62929 .59021 Mdot
.38623 .35497 Mdot
.49491 .46104 Mdot
.27138 .4922 Mdot
.38751 .59071 Mdot
.50954 .57155 Mdot
.44291 .38695 Mdot
.3542 .35835 Mdot
.22671 .53914 Mdot
.50676 .70725 Mdot
.41593 .39627 Mdot
.61812 .37919 Mdot
.59995 .35212 Mdot
.60136 .42359 Mdot
.66436 .59501 Mdot
.58078 .45466 Mdot
.49322 .70557 Mdot
.36704 .56959 Mdot
.47567 .66705 Mdot
.37915 .56127 Mdot
.20406 .4529 Mdot
.59298 .41468 Mdot
.59964 .44348 Mdot
.49961 .54824 Mdot
.39724 .32328 Mdot
.63934 .28092 Mdot
.51519 .70582 Mdot
.50191 .67931 Mdot
.60546 .38337 Mdot
.39865 .3178 Mdot
.6506 .58135 Mdot
.46801 .54832 Mdot
.58939 .45685 Mdot
.40424 .35555 Mdot
.61277 .38827 Mdot
.58636 .75672 Mdot
.34118 .4822 Mdot
.39352 .33382 Mdot
.34639 .23415 Mdot
.5578 .40995 Mdot
.65578 .34093 Mdot
.52314 .42691 Mdot
.74849 .57965 Mdot
.63316 .37125 Mdot
.40252 .38723 Mdot
.60778 .41769 Mdot
.41154 .37219 Mdot
.46278 .66525 Mdot
.36929 .58573 Mdot
.40439 .37071 Mdot
.55563 .43509 Mdot
.23921 .71488 Mdot
.38535 .58713 Mdot
.59231 .4474 Mdot
.40312 .55404 Mdot
.38926 .39049 Mdot
.38609 .32371 Mdot
.24182 .67277 Mdot
.33179 .53501 Mdot
.38921 .58827 Mdot
.60344 .39107 Mdot
.29762 .51615 Mdot
.60678 .38473 Mdot
.792 .55874 Mdot
.65247 .42743 Mdot
.63658 .37963 Mdot
.16903 .50334 Mdot
.42788 .56719 Mdot
.62044 .17806 Mdot
.55106 .67858 Mdot
.27073 .73234 Mdot
.41304 .40484 Mdot
.66746 .63128 Mdot
.48753 .77512 Mdot
.26355 .53422 Mdot
.52115 .67737 Mdot
.63649 .43351 Mdot
.41001 .29646 Mdot
.39627 .54053 Mdot
.67865 .59534 Mdot
.5857 .4042 Mdot
.45483 .6679 Mdot
.21531 .64587 Mdot
.35865 .5631 Mdot
.38422 .35622 Mdot
.39772 .32217 Mdot
.4453 .17356 Mdot
.57554 .42234 Mdot
.60018 .43944 Mdot
.37167 .53979 Mdot
.61075 .48057 Mdot
.6555 .59135 Mdot
.6362 .73749 Mdot
.39409 .58609 Mdot
.31078 .52911 Mdot
.36936 .34491 Mdot
.61995 .43633 Mdot
.56394 .58564 Mdot
.31125 .72693 Mdot
.45367 .22211 Mdot
.66724 .61243 Mdot
.78873 .51349 Mdot
.40294 .38714 Mdot
.38515 .58202 Mdot
.72206 .44961 Mdot
.6141 .4718 Mdot
.62355 .43104 Mdot
.78866 .50411 Mdot
.46538 .52929 Mdot
.69023 .56536 Mdot
.54763 .38896 Mdot
.47746 .5294 Mdot
.60264 .38275 Mdot
.6044 .37854 Mdot
.57011 .47822 Mdot
.56646 .4434 Mdot
.40805 .36226 Mdot
.41947 .29145 Mdot
.49274 .65683 Mdot
.54791 .20962 Mdot
.56858 .5568 Mdot
.56502 .41699 Mdot
.5781 .3861 Mdot
.36727 .26609 Mdot
.24904 .51039 Mdot
.39923 .35366 Mdot
.37084 .30286 Mdot
.38533 .5979 Mdot
.69164 .4249 Mdot
.51295 .64191 Mdot
.48314 .39173 Mdot
.47073 .6572 Mdot
.40547 .35599 Mdot
.5056 .68352 Mdot
.38242 .59858 Mdot
.49412 .69371 Mdot
.52605 .66976 Mdot
.41954 .57378 Mdot
.37041 .33744 Mdot
.59576 .45547 Mdot
.38862 .59468 Mdot
.79515 .47545 Mdot
.66457 .59382 Mdot
.24014 .67184 Mdot
.53949 .39811 Mdot
.57548 .32994 Mdot
.7226 .67537 Mdot
.48494 .67876 Mdot
.32927 .47531 Mdot
.40086 .38153 Mdot
.67337 .57245 Mdot
.40993 .36684 Mdot
.6768 .27677 Mdot
.6933 .60376 Mdot
.23975 .6737 Mdot
.71287 .46837 Mdot
.56938 .61939 Mdot
.56494 .45434 Mdot
.42197 .31095 Mdot
.46858 .65968 Mdot
.37631 .53778 Mdot
.3975 .75725 Mdot
.54894 .4124 Mdot
.2682 .40646 Mdot
.36569 .38663 Mdot
.26248 .54593 Mdot
.38 .57818 Mdot
.35907 .59719 Mdot
.57973 .41957 Mdot
.56548 .60557 Mdot
.64978 .39954 Mdot
.71319 .44149 Mdot
.78496 .54037 Mdot
.48039 .38166 Mdot
.61257 .39237 Mdot
.46866 .64226 Mdot
.61036 .38871 Mdot
.61427 .33772 Mdot
.74221 .35445 Mdot
.53812 .40389 Mdot
.26766 .35998 Mdot
.66887 .69193 Mdot
.37493 .36832 Mdot
.53015 .44638 Mdot
.24785 .53931 Mdot
.56187 .40052 Mdot
.71122 .78417 Mdot
.68085 .6064 Mdot
.52855 .72414 Mdot
.5571 .44107 Mdot
.57825 .42836 Mdot
.5589 .31596 Mdot
.45881 .35753 Mdot
.27123 .53154 Mdot
.62764 .4265 Mdot
.77261 .51394 Mdot
.40351 .56506 Mdot
.64248 .44899 Mdot
.60953 .41998 Mdot
.81359 .44878 Mdot
.40349 .55936 Mdot
.49115 .68591 Mdot
.26651 .53989 Mdot
.48455 .63538 Mdot
.66885 .63449 Mdot
.42086 .48286 Mdot
.7864 .41803 Mdot
.33924 .48431 Mdot
.70393 .59532 Mdot
.57703 .45811 Mdot
.64531 .33119 Mdot
.57049 .43473 Mdot
.69491 .62269 Mdot
.40905 .56458 Mdot
.40551 .3629 Mdot
.51815 .49503 Mdot
.25319 .5451 Mdot
.64781 .3908 Mdot
.6703 .63089 Mdot
.39808 .36779 Mdot
.25586 .6627 Mdot
.38965 .37666 Mdot
.39073 .56746 Mdot
.39696 .60232 Mdot
.6896 .60279 Mdot
.4099 .3645 Mdot
.50946 .6511 Mdot
.5483 .66833 Mdot
.65325 .41964 Mdot
.32744 .56636 Mdot
.43447 .36159 Mdot
.37533 .31779 Mdot
.42723 .38368 Mdot
.59023 .4126 Mdot
.461 .52102 Mdot
.61373 .47354 Mdot
.40134 .58786 Mdot
.51737 .67441 Mdot
.76568 .39751 Mdot
.62825 .29719 Mdot
.32172 .51721 Mdot
.64964 .38735 Mdot
.56672 .43977 Mdot
.60368 .42557 Mdot
.61854 .39906 Mdot
.617 .74994 Mdot
.59478 .41522 Mdot
.38933 .56157 Mdot
.47924 .64922 Mdot
.5747 .41889 Mdot
.24889 .53661 Mdot
.5007 .52217 Mdot
.68919 .57856 Mdot
.56169 .53685 Mdot
.28156 .7583 Mdot
.3986 .3666 Mdot
.47838 .68575 Mdot
.51636 .66493 Mdot
.66154 .58641 Mdot
.37268 .58228 Mdot
.39481 .37781 Mdot
.731 .55975 Mdot
.66116 .61564 Mdot
.61787 .41602 Mdot
.52665 .56661 Mdot
.32495 .2454 Mdot
.58398 .464 Mdot
.636 .41473 Mdot
.26396 .5481 Mdot
.48308 .62612 Mdot
.60111 .83497 Mdot
.44715 .53378 Mdot
.68593 .59838 Mdot
.69961 .60295 Mdot
.42018 .39045 Mdot
.6611 .41658 Mdot
.37506 .56386 Mdot
.47349 .54125 Mdot
.75801 .66138 Mdot
.39594 .77185 Mdot
.37396 .64502 Mdot
.63842 .43979 Mdot
.50491 .32179 Mdot
.64278 .39818 Mdot
.36095 .37411 Mdot
.42127 .38545 Mdot
.39403 .35286 Mdot
.39949 .56978 Mdot
.58382 .19241 Mdot
.38615 .56007 Mdot
.28363 .76165 Mdot
.3858 .38435 Mdot
.58394 .6571 Mdot
.50707 .67631 Mdot
.67035 .41524 Mdot
.68786 .62089 Mdot
.33447 .59633 Mdot
.53406 .45502 Mdot
.29112 .40688 Mdot
.504 .69383 Mdot
.37999 .32615 Mdot
.59958 .34254 Mdot
.48098 .82018 Mdot
.40026 .48274 Mdot
.69007 .65906 Mdot
.6712 .2841 Mdot
.69508 .60665 Mdot
.41827 .23268 Mdot
.65422 .60168 Mdot
.36138 .55701 Mdot
.54872 .41412 Mdot
.55269 .42667 Mdot
.62508 .39243 Mdot
.59743 .41305 Mdot
.40538 .57291 Mdot
.64702 .42442 Mdot
.77768 .36193 Mdot
.25445 .52983 Mdot
.57128 .69827 Mdot
.68228 .58076 Mdot
.41636 .58887 Mdot
.47253 .6504 Mdot
.22758 .5478 Mdot
.81646 .51551 Mdot
.64461 .42803 Mdot
.6389 .4293 Mdot
.23879 .5261 Mdot
.60337 .47945 Mdot
.58608 .34582 Mdot
.4891 .65769 Mdot
.42513 .45954 Mdot
.69855 .62441 Mdot
.69657 .58785 Mdot
.41563 .56364 Mdot
.41022 .36671 Mdot
.66405 .61053 Mdot
.4601 .63837 Mdot
.62757 .45883 Mdot
.58835 .37323 Mdot
.4339 .35948 Mdot
.7082 .29466 Mdot
.65385 .61806 Mdot
.54166 .36246 Mdot
.41129 .37841 Mdot
.36833 .38941 Mdot
.62798 .42889 Mdot
.62168 .36202 Mdot
.3686 .32796 Mdot
.68166 .57892 Mdot
.41802 .58571 Mdot
.58242 .63528 Mdot
.36385 .56772 Mdot
.39874 .37486 Mdot
.5888 .47223 Mdot
.36986 .34012 Mdot
.5597 .40789 Mdot
.33049 .17348 Mdot
.57247 .44887 Mdot
.32932 .30225 Mdot
.75427 .58179 Mdot
.51036 .65796 Mdot
.50265 .64582 Mdot
.24684 .53369 Mdot
.40764 .38294 Mdot
.55756 .38936 Mdot
.69969 .61042 Mdot
.25484 .71438 Mdot
.34427 .34924 Mdot
.51146 .69883 Mdot
.50043 .63343 Mdot
.40817 .56919 Mdot
.60808 .45991 Mdot
.61604 .43626 Mdot
.49369 .69261 Mdot
.71306 .69021 Mdot
.4183 .36553 Mdot
.59976 .43931 Mdot
.56321 .43557 Mdot
.49145 .6541 Mdot
.55 .66855 Mdot
.45534 .36192 Mdot
.56607 .44235 Mdot
.70923 .4792 Mdot
.40948 .59009 Mdot
.60487 .39889 Mdot
.64639 .41813 Mdot
.67947 .58892 Mdot
.56408 .722 Mdot
.74494 .36481 Mdot
.40778 .59952 Mdot
.24741 .55274 Mdot
.54709 .42056 Mdot
.50567 .67377 Mdot
.56343 .38079 Mdot
.56661 .7986 Mdot
.26021 .53421 Mdot
.59002 .42339 Mdot
.58027 .47954 Mdot
.41497 .339 Mdot
.58614 .42425 Mdot
.46401 .34317 Mdot
.48052 .63968 Mdot
.58943 .42226 Mdot
.59875 .29208 Mdot
.40751 .57353 Mdot
.53379 .45263 Mdot
.70246 .60406 Mdot
.75026 .58888 Mdot
.23236 .492 Mdot
.52978 .67655 Mdot
.67243 .58166 Mdot
.58341 .45618 Mdot
.46072 .64701 Mdot
.41089 .54796 Mdot
.27624 .39829 Mdot
.59592 .46677 Mdot
.36966 .57644 Mdot
.37038 .57352 Mdot
.68619 .60303 Mdot
.56463 .15113 Mdot
.58617 .48179 Mdot
.60236 .45043 Mdot
.81955 .58868 Mdot
.3989 .39746 Mdot
.6016 .4523 Mdot
.60381 .4595 Mdot
.37142 .55715 Mdot
.67805 .49592 Mdot
.34145 .38287 Mdot
.67114 .71468 Mdot
.41222 .58899 Mdot
.50551 .71403 Mdot
.46164 .65191 Mdot
.67811 .58087 Mdot
.37519 .36575 Mdot
.70839 .60345 Mdot
.50278 .66184 Mdot
.63146 .40416 Mdot
.37012 .54901 Mdot
.49816 .23293 Mdot
.36421 .53851 Mdot
.45501 .6572 Mdot
.36136 .34169 Mdot
.20352 .52715 Mdot
.851 .58022 Mdot
.26262 .48342 Mdot
.41712 .59314 Mdot
.68565 .59319 Mdot
.45338 .55097 Mdot
.56728 .43982 Mdot
.4209 .21995 Mdot
.61005 .45221 Mdot
.67615 .28623 Mdot
.48872 .69915 Mdot
.22758 .53508 Mdot
.54841 .4121 Mdot
.78478 .51461 Mdot
.41537 .5937 Mdot
.40903 .57534 Mdot
.61829 .4078 Mdot
.3883 .56581 Mdot
.60924 .43819 Mdot
.48825 .64917 Mdot
.57892 .15932 Mdot
.57774 .44686 Mdot
.5326 .42548 Mdot
.40671 .60655 Mdot
.23952 .67191 Mdot
.49752 .71136 Mdot
.5136 .32292 Mdot
.49888 .82464 Mdot
.38475 .56634 Mdot
.52136 .4189 Mdot
.48153 .68044 Mdot
.26186 .54991 Mdot
.44428 .643 Mdot
.61901 .4471 Mdot
.64234 .42605 Mdot
.61401 .38417 Mdot
.56524 .43499 Mdot
.4052 .22963 Mdot
.6397 .35324 Mdot
.48978 .29529 Mdot
.63963 .42511 Mdot
.35158 .29831 Mdot
.39427 .56158 Mdot
.42338 .42156 Mdot
.70622 .57733 Mdot
.64351 .42321 Mdot
.45669 .35043 Mdot
.41367 .59223 Mdot
.30164 .77074 Mdot
.4061 .5637 Mdot
.48197 .67042 Mdot
.35476 .56178 Mdot
.56089 .40923 Mdot
.37988 .35501 Mdot
.48019 .6432 Mdot
.22549 .41164 Mdot
.52101 .68275 Mdot
.57286 .42307 Mdot
.56418 .67152 Mdot
.51225 .66073 Mdot
.52171 .52734 Mdot
.37809 .35803 Mdot
.7684 .49876 Mdot
.39247 .39614 Mdot
.58649 .42948 Mdot
.58566 .4348 Mdot
.22822 .54992 Mdot
.35853 .56392 Mdot
.39019 .38962 Mdot
.78732 .33245 Mdot
.68639 .6353 Mdot
.39087 .34591 Mdot
.63658 .36795 Mdot
.45599 .52418 Mdot
.40864 .33744 Mdot
.75801 .54004 Mdot
.36025 .56425 Mdot
.42179 .39268 Mdot
.66335 .38388 Mdot
.58681 .52603 Mdot
.65446 .58649 Mdot
.46359 .68429 Mdot
.48271 .50002 Mdot
.46509 .64738 Mdot
.39092 .60772 Mdot
.46793 .61973 Mdot
.4011 .56256 Mdot
.33388 .29204 Mdot
.35976 .42267 Mdot
.42229 .61157 Mdot
.39251 .6043 Mdot
.49847 .66539 Mdot
.62005 .40027 Mdot
.58989 .57498 Mdot
.64573 .37509 Mdot
.5624 .45683 Mdot
.401 .59476 Mdot
.40481 .38878 Mdot
.36567 .35631 Mdot
.41399 .30827 Mdot
.39158 .32362 Mdot
.47196 .6473 Mdot
.34031 .47237 Mdot
.66371 .26664 Mdot
.4024 .55043 Mdot
.38688 .52342 Mdot
.60021 .38438 Mdot
.50349 .67012 Mdot
.46295 .6717 Mdot
.36975 .56328 Mdot
.48687 .20983 Mdot
.5367 .44785 Mdot
.37457 .38743 Mdot
.38472 .38369 Mdot
.40736 .33826 Mdot
.43052 .36244 Mdot
.53833 .18024 Mdot
.37595 .53777 Mdot
.40004 .38595 Mdot
.6076 .41136 Mdot
.63453 .44169 Mdot
.25008 .55018 Mdot
.6927 .58853 Mdot
.54181 .42664 Mdot
.5383 .43153 Mdot
.62709 .43089 Mdot
.51128 .66117 Mdot
.67709 .43675 Mdot
.26048 .53725 Mdot
.47709 .62172 Mdot
.52061 .65281 Mdot
.22891 .5386 Mdot
.3573 .39145 Mdot
.4707 .82957 Mdot
.62342 .38883 Mdot
.70283 .38506 Mdot
.50114 .67362 Mdot
.33094 .41768 Mdot
.51793 .47609 Mdot
.60734 .39346 Mdot
.61996 .55799 Mdot
.48663 .64638 Mdot
.35286 .36883 Mdot
.60968 .44879 Mdot
.24181 .52787 Mdot
.6818 .5761 Mdot
.65923 .38165 Mdot
.26566 .54707 Mdot
.40743 .35601 Mdot
.67458 .67624 Mdot
.40965 .39726 Mdot
.51102 .65603 Mdot
.53144 .45041 Mdot
.0834 .50256 Mdot
.46779 .66118 Mdot
.32656 .76203 Mdot
.37588 .43453 Mdot
.57404 .44589 Mdot
.46449 .65062 Mdot
.35379 .36749 Mdot
.40858 .59065 Mdot
.491 .53118 Mdot
.38534 .3815 Mdot
.22616 .54483 Mdot
.23795 .54972 Mdot
.49163 .65588 Mdot
.37383 .34374 Mdot
.64966 .43007 Mdot
.42676 .36344 Mdot
.35403 .55651 Mdot
.58084 .40015 Mdot
.45762 .8124 Mdot
.59756 .35218 Mdot
.41264 .37899 Mdot
.45608 .64315 Mdot
.67344 .62691 Mdot
.58819 .40476 Mdot
.38348 .78975 Mdot
.60402 .46044 Mdot
.40685 .55825 Mdot
.31544 .38768 Mdot
.48196 .23653 Mdot
.62513 .40224 Mdot
.58925 .38385 Mdot
.41682 .56447 Mdot
.62687 .40156 Mdot
.58998 .46401 Mdot
.33502 .56811 Mdot
.40581 .33236 Mdot
.59814 .42634 Mdot
.46625 .68442 Mdot
.68625 .31243 Mdot
.54469 .40977 Mdot
.2567 .35668 Mdot
.77635 .50598 Mdot
.31956 .38283 Mdot
.54805 .39567 Mdot
.79865 .47251 Mdot
.58851 .43914 Mdot
.59361 .40812 Mdot
.61967 .39018 Mdot
.48549 .32016 Mdot
.50204 .6649 Mdot
.50479 .70411 Mdot
.65946 .5769 Mdot
.77729 .51294 Mdot
.67372 .58643 Mdot
.41758 .5773 Mdot
.29374 .60787 Mdot
.25498 .53102 Mdot
.41067 .36882 Mdot
.58702 .38017 Mdot
.52321 .67434 Mdot
.62007 .43929 Mdot
.56482 .39881 Mdot
.49567 .64918 Mdot
.46416 .65529 Mdot
.49242 .62542 Mdot
.65758 .61214 Mdot
.39983 .35986 Mdot
.6337 .3995 Mdot
.66075 .61241 Mdot
.64647 .44017 Mdot
.45653 .53266 Mdot
.39913 .35699 Mdot
.42629 .36006 Mdot
.36821 .37448 Mdot
.64062 .41182 Mdot
.56288 .41085 Mdot
.3843 .55953 Mdot
.43576 .36418 Mdot
.4 .54625 Mdot
.46593 .64893 Mdot
.5041 .64869 Mdot
.61968 .44697 Mdot
.56993 .34757 Mdot
.69716 .59984 Mdot
.48434 .67506 Mdot
.24858 .52255 Mdot
.66152 .57603 Mdot
.57889 .4163 Mdot
.46755 .64644 Mdot
.69868 .59065 Mdot
.53773 .21698 Mdot
.53593 .83005 Mdot
.66939 .6271 Mdot
.61763 .40863 Mdot
.57855 .30874 Mdot
.73262 .43597 Mdot
.69314 .63383 Mdot
.39249 .54637 Mdot
.61056 .4577 Mdot
.7268 .6927 Mdot
.70604 .61681 Mdot
.71327 .30145 Mdot
.50061 .65242 Mdot
.69636 .4629 Mdot
.65668 .37697 Mdot
.46533 .19889 Mdot
.7085 .61038 Mdot
.39329 .37454 Mdot
.43764 .37922 Mdot
.62044 .41218 Mdot
.71418 .61649 Mdot
.35009 .55564 Mdot
.51622 .66312 Mdot
.52683 .67908 Mdot
.37671 .34002 Mdot
.33314 .49983 Mdot
.46147 .67501 Mdot
.53213 .45906 Mdot
.45539 .68477 Mdot
.68244 .46017 Mdot
.47113 .17617 Mdot
.21431 .42693 Mdot
.59743 .37236 Mdot
.67832 .62987 Mdot
.41956 .55872 Mdot
.38548 .56165 Mdot
.39696 .57164 Mdot
.49446 .64081 Mdot
.46096 .50464 Mdot
.49738 .69667 Mdot
.26941 .42 Mdot
.68661 .61275 Mdot
.7564 .49203 Mdot
.55165 .39496 Mdot
.57217 .44383 Mdot
.63455 .45555 Mdot
.61278 .38303 Mdot
.59011 .43945 Mdot
.38562 .5897 Mdot
.49872 .63767 Mdot
.65411 .70416 Mdot
.40438 .34082 Mdot
.25019 .63568 Mdot
.50726 .67683 Mdot
.26682 .5432 Mdot
.67307 .60251 Mdot
.7835 .42241 Mdot
.52045 .71408 Mdot
.50499 .68287 Mdot
.60507 .46761 Mdot
.41384 .38711 Mdot
.64712 .50949 Mdot
.58232 .44115 Mdot
.48484 .67667 Mdot
.45359 .6356 Mdot
.43126 .23324 Mdot
.59039 .4908 Mdot
.6447 .59668 Mdot
.45467 .52103 Mdot
.71106 .60805 Mdot
.60928 .35939 Mdot
.33034 .4198 Mdot
.50072 .66155 Mdot
.48062 .66401 Mdot
.67772 .63269 Mdot
.62882 .3334 Mdot
.37286 .35323 Mdot
.2285 .53333 Mdot
.39439 .55029 Mdot
.57597 .4374 Mdot
.48797 .63883 Mdot
.69634 .38004 Mdot
.5213 .56593 Mdot
.39619 .58246 Mdot
.4789 .62253 Mdot
.62039 .45593 Mdot
.62349 .40832 Mdot
.69472 .60336 Mdot
.60514 .62203 Mdot
.64864 .37404 Mdot
.27168 .73327 Mdot
.37319 .46501 Mdot
.45481 .43094 Mdot
.62316 .43117 Mdot
.38187 .33262 Mdot
.23848 .53001 Mdot
.68111 .62218 Mdot
.63868 .44841 Mdot
.51006 .83403 Mdot
.43689 .35053 Mdot
.38301 .58437 Mdot
.23729 .52977 Mdot
.46686 .50669 Mdot
.60201 .46072 Mdot
.60993 .45208 Mdot
.59357 .41284 Mdot
.52893 .84015 Mdot
.49394 .70247 Mdot
.43122 .37598 Mdot
.66621 .61001 Mdot
.41272 .33372 Mdot
.51081 .70174 Mdot
.49111 .48187 Mdot
.57485 .41628 Mdot
.36803 .38057 Mdot
.39018 .37417 Mdot
.40851 .56978 Mdot
.39914 .59886 Mdot
.53833 .68498 Mdot
.57557 .45031 Mdot
.24672 .52707 Mdot
.40929 .39238 Mdot
.47569 .62608 Mdot
.69398 .60507 Mdot
.38831 .59693 Mdot
.64017 .42208 Mdot
.49506 .65902 Mdot
.63838 .38619 Mdot
.42199 .35378 Mdot
.50525 .68169 Mdot
.27046 .54033 Mdot
.69753 .59803 Mdot
.64177 .42342 Mdot
.69503 .67878 Mdot
.23202 .53218 Mdot
.55605 .42525 Mdot
.59433 .31747 Mdot
.71895 .59842 Mdot
.22654 .40621 Mdot
.482 .6923 Mdot
.25495 .53842 Mdot
.42402 .38389 Mdot
.59972 .52245 Mdot
.47756 .65911 Mdot
.50163 .35258 Mdot
.5953 .59366 Mdot
.63053 .39853 Mdot
.38472 .34314 Mdot
.65024 .56445 Mdot
.30091 .76309 Mdot
.72667 .45982 Mdot
.59975 .43533 Mdot
.46435 .64786 Mdot
.69508 .58554 Mdot
.40757 .55478 Mdot
.25807 .35623 Mdot
.46678 .18072 Mdot
.48991 .6266 Mdot
.63112 .39087 Mdot
.41021 .39168 Mdot
.36999 .56566 Mdot
.19695 .46899 Mdot
.45902 .64092 Mdot
.47775 .69332 Mdot
.58289 .41076 Mdot
.66869 .61654 Mdot
.69789 .70677 Mdot
.49811 .70468 Mdot
.48732 .63518 Mdot
.24328 .63852 Mdot
.6565 .62044 Mdot
.60965 .41267 Mdot
.41407 .30824 Mdot
.62145 .46095 Mdot
.28173 .73416 Mdot
.25539 .53519 Mdot
.40756 .34339 Mdot
.62514 .44824 Mdot
.66533 .69393 Mdot
.47182 .65499 Mdot
.44803 .51316 Mdot
.47451 .6119 Mdot
.379 .58763 Mdot
.48833 .63996 Mdot
.61267 .44479 Mdot
.40559 .60365 Mdot
.69548 .59716 Mdot
.56645 .44291 Mdot
.56333 .408 Mdot
.35603 .36927 Mdot
.3627 .54977 Mdot
.69946 .33688 Mdot
.35361 .57717 Mdot
.41333 .55593 Mdot
.37732 .39785 Mdot
.6195 .41395 Mdot
.49043 .6781 Mdot
.45829 .67735 Mdot
.64857 .42121 Mdot
.33516 .42172 Mdot
.37465 .34863 Mdot
.51999 .73003 Mdot
.60125 .83241 Mdot
.59872 .48626 Mdot
.25528 .52532 Mdot
.71947 .37389 Mdot
.41013 .58169 Mdot
.63207 .40897 Mdot
.41481 .37152 Mdot
.48578 .63155 Mdot
.46076 .67543 Mdot
.6177 .46688 Mdot
.36666 .56603 Mdot
.69504 .58283 Mdot
.46928 .68245 Mdot
.51501 .56406 Mdot
.58579 .42089 Mdot
.26691 .40414 Mdot
.47267 .68317 Mdot
.19604 .65115 Mdot
.65951 .69809 Mdot
.39214 .33513 Mdot
.57232 .39257 Mdot
.40151 .321 Mdot
.66526 .60416 Mdot
.44239 .63594 Mdot
.36531 .56588 Mdot
.49903 .40113 Mdot
.81363 .41807 Mdot
.50584 .6678 Mdot
.40711 .36059 Mdot
.63717 .4071 Mdot
.50226 .40988 Mdot
.58748 .45519 Mdot
.6623 .51566 Mdot
.71785 .65009 Mdot
.38827 .60156 Mdot
.41159 .56342 Mdot
.57174 .38784 Mdot
.65519 .59979 Mdot
.47924 .70152 Mdot
.49805 .65158 Mdot
.4784 .13179 Mdot
.27078 .54247 Mdot
.77959 .58243 Mdot
.64089 .41564 Mdot
.48683 .62921 Mdot
.63401 .29745 Mdot
.37227 .53979 Mdot
.65739 .41685 Mdot
.51453 .64978 Mdot
.30009 .71121 Mdot
.46066 .53217 Mdot
.59251 .42709 Mdot
.61442 .48043 Mdot
.40145 .55352 Mdot
.45231 .54654 Mdot
.49749 .69574 Mdot
.65233 .43432 Mdot
.35899 .58988 Mdot
.23369 .65114 Mdot
.8031 .38976 Mdot
.39938 .35943 Mdot
.45529 .64132 Mdot
.38064 .5882 Mdot
.66438 .46183 Mdot
.68379 .58095 Mdot
.4761 .63438 Mdot
.51926 .67343 Mdot
.58095 .39619 Mdot
.54094 .41984 Mdot
.58931 .48676 Mdot
.39937 .34604 Mdot
.38214 .55542 Mdot
.5532 .39875 Mdot
.35305 .48533 Mdot
.62108 .38506 Mdot
.37801 .55635 Mdot
.14001 .35986 Mdot
.58951 .46786 Mdot
.5968 .4531 Mdot
.69389 .5542 Mdot
.36879 .36123 Mdot
.40252 .32741 Mdot
.35225 .47232 Mdot
.64114 .41644 Mdot
.57637 .61946 Mdot
.40151 .36315 Mdot
.37616 .34859 Mdot
.57922 .66136 Mdot
.58791 .39825 Mdot
.44186 .57456 Mdot
.37379 .56278 Mdot
.38358 .59119 Mdot
.41814 .34332 Mdot
.67017 .41331 Mdot
.41373 .55094 Mdot
.3839 .23747 Mdot
.50963 .67944 Mdot
.32979 .4194 Mdot
.42356 .37101 Mdot
.5822 .59986 Mdot
.36018 .56096 Mdot
.24637 .73864 Mdot
.58967 .53212 Mdot
.64815 .40137 Mdot
.6233 .40522 Mdot
.6828 .5884 Mdot
.52481 .39131 Mdot
.25032 .5523 Mdot
.39064 .56614 Mdot
.56296 .76581 Mdot
.39324 .35217 Mdot
.59235 .45301 Mdot
.76612 .4032 Mdot
.21477 .46464 Mdot
.27503 .35521 Mdot
.37696 .37107 Mdot
.3854 .34941 Mdot
.50894 .69338 Mdot
.51422 .67284 Mdot
.60258 .41801 Mdot
.39776 .5668 Mdot
.43009 .39001 Mdot
.38282 .55056 Mdot
.50189 .66112 Mdot
.50163 .68106 Mdot
.2623 .53652 Mdot
.65732 .4506 Mdot
.50363 .65152 Mdot
.24808 .66628 Mdot
.35756 .48372 Mdot
.35129 .35125 Mdot
.84732 .57905 Mdot
.1928 .47029 Mdot
.72275 .57028 Mdot
.67588 .57533 Mdot
.26326 .55574 Mdot
.35688 .57324 Mdot
.57841 .38544 Mdot
.63083 .43748 Mdot
.2413 .54726 Mdot
.36702 .5791 Mdot
.67398 .59606 Mdot
.35813 .56325 Mdot
.6805 .61935 Mdot
.51301 .70551 Mdot
.54489 .41175 Mdot
.59235 .46098 Mdot
.39333 .58854 Mdot
.49378 .68848 Mdot
.51105 .65709 Mdot
.66244 .57766 Mdot
.78256 .43095 Mdot
.49334 .65614 Mdot
.42429 .36994 Mdot
.62237 .25415 Mdot
.23828 .54929 Mdot
.60834 .44863 Mdot
.77677 .41018 Mdot
.4369 .22402 Mdot
.63046 .39583 Mdot
.23621 .53001 Mdot
.49855 .13138 Mdot
.54728 .41505 Mdot
.47225 .1519 Mdot
.25852 .54073 Mdot
.36724 .34472 Mdot
.47852 .67972 Mdot
.24441 .55352 Mdot
.67243 .44592 Mdot
.64712 .62393 Mdot
.53881 .40357 Mdot
.38049 .3784 Mdot
.36157 .36057 Mdot
.38418 .44348 Mdot
.28643 .73709 Mdot
.67824 .62566 Mdot
.67939 .59871 Mdot
.4786 .65682 Mdot
.29481 .56824 Mdot
.60942 .36404 Mdot
.68103 .59661 Mdot
.60417 .76704 Mdot
.60232 .38519 Mdot
.79426 .54652 Mdot
.61772 .55729 Mdot
.38043 .3345 Mdot
.37133 .41075 Mdot
.47466 .65613 Mdot
.4065 .36035 Mdot
.46778 .44825 Mdot
.63458 .45526 Mdot
.39715 .35476 Mdot
.37478 .55553 Mdot
.37796 .72381 Mdot
.38915 .32103 Mdot
.49351 .53812 Mdot
.37533 .56484 Mdot
.71839 .59928 Mdot
.71591 .51762 Mdot
.69126 .80995 Mdot
.39267 .56606 Mdot
.48208 .67851 Mdot
.50586 .65224 Mdot
.48996 .65198 Mdot
.38459 .38143 Mdot
.46316 .66319 Mdot
.40736 .34757 Mdot
.54702 .6883 Mdot
.79732 .45432 Mdot
.69041 .60533 Mdot
.3281 .54442 Mdot
.38669 .36516 Mdot
.29446 .45041 Mdot
.84939 .54402 Mdot
.61469 .40803 Mdot
.35753 .58514 Mdot
.68227 .63173 Mdot
.23271 .57303 Mdot
.67848 .58853 Mdot
.48182 .68138 Mdot
.32839 .41861 Mdot
.60851 .43753 Mdot
.47068 .34899 Mdot
.70131 .61002 Mdot
.38034 .37626 Mdot
.55906 .43065 Mdot
.53795 .67219 Mdot
.67142 .58344 Mdot
.6819 .57652 Mdot
.59182 .44178 Mdot
.37902 .32883 Mdot
.49717 .68182 Mdot
.3636 .58372 Mdot
.68134 .56421 Mdot
.66987 .43446 Mdot
.6219 .39897 Mdot
.65176 .44279 Mdot
.42506 .49455 Mdot
.71016 .70268 Mdot
.38297 .56684 Mdot
.74005 .41848 Mdot
.50976 .66299 Mdot
.7187 .46992 Mdot
.29519 .47835 Mdot
.32886 .55071 Mdot
.25641 .53596 Mdot
.25457 .53346 Mdot
.59226 .43174 Mdot
.68675 .72714 Mdot
.30498 .31524 Mdot
.34078 .55721 Mdot
.23244 .54421 Mdot
.51152 .65787 Mdot
.43776 .36061 Mdot
.44014 .42013 Mdot
.54721 .43363 Mdot
.39712 .59908 Mdot
.49849 .65629 Mdot
.56994 .79873 Mdot
.68485 .61161 Mdot
.33144 .45955 Mdot
.5726 .41958 Mdot
.60065 .4416 Mdot
.3807 .5753 Mdot
.38389 .55994 Mdot
.25737 .38192 Mdot
.38826 .45302 Mdot
.41419 .77492 Mdot
.43944 .57187 Mdot
.59864 .79462 Mdot
.44922 .3836 Mdot
.41486 .37562 Mdot
.26566 .53716 Mdot
.41817 .5617 Mdot
.60614 .45348 Mdot
.36603 .34876 Mdot
.27832 .3521 Mdot
.37854 .40115 Mdot
.79066 .53864 Mdot
.58181 .62017 Mdot
.56647 .42612 Mdot
.41711 .38528 Mdot
.40426 .35879 Mdot
.42092 .34075 Mdot
.22982 .53777 Mdot
.62562 .4277 Mdot
.61901 .40038 Mdot
.54952 .41393 Mdot
.51324 .39022 Mdot
.5854 .42344 Mdot
.30002 .48871 Mdot
.3116 .52905 Mdot
.56093 .74559 Mdot
.6352 .39639 Mdot
.36589 .57517 Mdot
.5918 .37897 Mdot
.65607 .59273 Mdot
.63371 .3919 Mdot
.79047 .57004 Mdot
.39291 .57576 Mdot
.61251 .33232 Mdot
.45114 .68472 Mdot
.57156 .41884 Mdot
.70352 .5955 Mdot
.70567 .70586 Mdot
.76824 .38479 Mdot
.24445 .64395 Mdot
.42486 .36884 Mdot
.53462 .68852 Mdot
.35427 .54826 Mdot
.48975 .67638 Mdot
.65376 .41466 Mdot
.25643 .52712 Mdot
.16901 .47758 Mdot
.56929 .58261 Mdot
.61107 .45386 Mdot
.66053 .37071 Mdot
.39236 .33097 Mdot
.46889 .65627 Mdot
.4379 .40479 Mdot
.59317 .40991 Mdot
.66348 .6044 Mdot
.66112 .60569 Mdot
.4315 .44011 Mdot
.52155 .78282 Mdot
.62252 .52104 Mdot
.38059 .5731 Mdot
.45898 .67084 Mdot
.7081 .61072 Mdot
.33406 .29472 Mdot
.34959 .55212 Mdot
.40998 .58192 Mdot
.36505 .54912 Mdot
.5683 .43149 Mdot
.26265 .54248 Mdot
.56474 .78105 Mdot
.22885 .54864 Mdot
.56851 .41745 Mdot
.51829 .6807 Mdot
.24547 .55389 Mdot
.67852 .58594 Mdot
.41534 .56438 Mdot
.51092 .66816 Mdot
.58477 .43156 Mdot
.39729 .36393 Mdot
.75261 .3999 Mdot
.75843 .6368 Mdot
.54818 .71339 Mdot
.55116 .70967 Mdot
.37624 .38159 Mdot
.38313 .80679 Mdot
.32757 .56685 Mdot
.48079 .21037 Mdot
.64063 .57765 Mdot
.64894 .41929 Mdot
.63188 .19775 Mdot
.49329 .69513 Mdot
.47586 .64454 Mdot
.59317 .42312 Mdot
.46481 .63243 Mdot
.59073 .45394 Mdot
.50755 .69718 Mdot
.34388 .76059 Mdot
.55502 .44272 Mdot
.4747 .64578 Mdot
.61294 .36303 Mdot
.5803 .40729 Mdot
.38815 .32998 Mdot
.4781 .63238 Mdot
.64607 .39698 Mdot
.15982 .48 Mdot
.4048 .58134 Mdot
.22907 .54105 Mdot
.31705 .54828 Mdot
.35862 .55589 Mdot
.39189 .34081 Mdot
.54449 .41944 Mdot
.69642 .60259 Mdot
.39478 .37194 Mdot
.53319 .66462 Mdot
.6998 .61651 Mdot
.34035 .47478 Mdot
.42519 .36397 Mdot
.24631 .54956 Mdot
.69901 .6032 Mdot
.53298 .41363 Mdot
.48856 .64385 Mdot
.76576 .64698 Mdot
.22911 .54801 Mdot
.61524 .4374 Mdot
.45889 .68554 Mdot
.35854 .56208 Mdot
.60713 .4221 Mdot
.46372 .64669 Mdot
.2313 .53443 Mdot
.55893 .41848 Mdot
.5569 .42374 Mdot
.45531 .41497 Mdot
.29964 .37399 Mdot
.69288 .60083 Mdot
.36619 .38615 Mdot
.6053 .41222 Mdot
.65463 .60071 Mdot
.35375 .65045 Mdot
.59759 .37515 Mdot
.39445 .31831 Mdot
.49249 .42066 Mdot
.51524 .67391 Mdot
.40268 .54833 Mdot
.45472 .6607 Mdot
.6841 .57627 Mdot
.80287 .33337 Mdot
.26425 .54418 Mdot
.67321 .40662 Mdot
.6397 .45207 Mdot
.44763 .62207 Mdot
.40161 .35427 Mdot
.38695 .75322 Mdot
.64166 .42064 Mdot
.64565 .35962 Mdot
.59898 .44693 Mdot
.65415 .69801 Mdot
.3741 .35167 Mdot
.6041 .44869 Mdot
.62479 .34391 Mdot
.54765 .39335 Mdot
.70116 .58979 Mdot
.74497 .50122 Mdot
.59874 .37826 Mdot
.09912 .56249 Mdot
.24127 .5251 Mdot
.49411 .64923 Mdot
.4835 .56969 Mdot
.42862 .67396 Mdot
.47779 .17274 Mdot
.40369 .34663 Mdot
.63334 .4996 Mdot
.49395 .67978 Mdot
.76053 .35587 Mdot
.34935 .79482 Mdot
.57635 .40942 Mdot
.62263 .45416 Mdot
.48178 .68132 Mdot
.4833 .62833 Mdot
.25428 .52809 Mdot
.64178 .39938 Mdot
.66019 .37509 Mdot
.46074 .62821 Mdot
.57836 .42891 Mdot
.40972 .26998 Mdot
.37745 .59868 Mdot
.41017 .33383 Mdot
.40729 .55444 Mdot
.4072 .58646 Mdot
.58251 .21312 Mdot
.37326 .46469 Mdot
.38023 .55717 Mdot
.34651 .54416 Mdot
.79372 .57099 Mdot
.49237 .41357 Mdot
.70725 .59891 Mdot
.48172 .78479 Mdot
.48364 .65394 Mdot
.62701 .42598 Mdot
.39489 .38853 Mdot
.49545 .1927 Mdot
.33444 .69512 Mdot
.32089 .42241 Mdot
.61567 .40346 Mdot
.47558 .65219 Mdot
.22785 .53865 Mdot
.55167 .43808 Mdot
.71993 .46247 Mdot
.60099 .43828 Mdot
.51512 .65953 Mdot
.61349 .22507 Mdot
.47575 .36667 Mdot
.44288 .58308 Mdot
.3528 .32235 Mdot
.55407 .39482 Mdot
.42047 .35793 Mdot
.3707 .57829 Mdot
.6568 .60902 Mdot
.6866 .5951 Mdot
.56491 .4371 Mdot
.35873 .42198 Mdot
.62597 .57109 Mdot
.58278 .40709 Mdot
.58259 .39729 Mdot
.25674 .53894 Mdot
.58211 .39802 Mdot
.64343 .44686 Mdot
.56886 .38747 Mdot
.62418 .37578 Mdot
.41402 .55658 Mdot
.56029 .32732 Mdot
.62048 .37908 Mdot
.61523 .48765 Mdot
.38945 .59957 Mdot
.67284 .46565 Mdot
.40535 .56399 Mdot
.46997 .80722 Mdot
.39829 .55543 Mdot
.68804 .59755 Mdot
.4795 .70462 Mdot
.67941 .47393 Mdot
.42759 .39158 Mdot
.40271 .59877 Mdot
.67619 .61195 Mdot
.39457 .56855 Mdot
.47874 .69705 Mdot
.82642 .5952 Mdot
.38847 .40329 Mdot
.45812 .53992 Mdot
.61949 .54157 Mdot
.2658 .40194 Mdot
.51178 .68239 Mdot
.37839 .33952 Mdot
.46574 .34805 Mdot
.5642 .39137 Mdot
.69301 .59384 Mdot
.59327 .4333 Mdot
.41329 .55754 Mdot
.47991 .65172 Mdot
.56187 .6773 Mdot
.69204 .59813 Mdot
.83521 .43288 Mdot
.52248 .67993 Mdot
.56808 .4641 Mdot
.39292 .60141 Mdot
.848 .57019 Mdot
.40089 .55612 Mdot
.79697 .44591 Mdot
.39636 .30968 Mdot
.63599 .23544 Mdot
.38332 .35457 Mdot
.27711 .33635 Mdot
.44688 .85051 Mdot
.35146 .78744 Mdot
.40173 .37359 Mdot
.51154 .73021 Mdot
.57528 .42288 Mdot
.6114 .38141 Mdot
.55042 .4752 Mdot
.34989 .35699 Mdot
.59861 .41387 Mdot
.2484 .55185 Mdot
.38102 .47183 Mdot
.65492 .73141 Mdot
.53231 .69806 Mdot
.592 .4555 Mdot
.3989 .59504 Mdot
.38641 .53684 Mdot
.23804 .55327 Mdot
.35212 .56284 Mdot
.58721 .40329 Mdot
.38508 .36232 Mdot
.58166 .57937 Mdot
.66653 .59485 Mdot
.18702 .58702 Mdot
.67561 .56561 Mdot
.53337 .70273 Mdot
.56398 .4755 Mdot
.50238 .68137 Mdot
.7103 .22822 Mdot
.59217 .38238 Mdot
.40402 .36454 Mdot
.56057 .4279 Mdot
.56217 .39046 Mdot
.62472 .3839 Mdot
.45948 .65295 Mdot
.48399 .57596 Mdot
.57901 .43134 Mdot
.36411 .56374 Mdot
.56599 .70281 Mdot
.54105 .43143 Mdot
.48786 .752 Mdot
.78026 .5355 Mdot
.27319 .41793 Mdot
.35107 .33887 Mdot
.47603 .66957 Mdot
.38999 .35113 Mdot
.34806 .36091 Mdot
.39205 .34073 Mdot
.5491 .77006 Mdot
.68422 .47888 Mdot
.44128 .15714 Mdot
.61925 .27722 Mdot
.50233 .19935 Mdot
.37375 .38511 Mdot
.38162 .6779 Mdot
.41295 .37432 Mdot
.3988 .3428 Mdot
.27714 .21426 Mdot
.40648 .38221 Mdot
.6212 .44555 Mdot
.58562 .46871 Mdot
.2465 .48336 Mdot
.80139 .55274 Mdot
.63391 .39328 Mdot
.60092 .41528 Mdot
.67025 .62306 Mdot
.57354 .34409 Mdot
.23144 .55514 Mdot
.34196 .44974 Mdot
.22235 .56005 Mdot
.59162 .44088 Mdot
.59408 .41883 Mdot
.66466 .40462 Mdot
.45091 .85621 Mdot
.48583 .1874 Mdot
.36323 .36194 Mdot
.68713 .40841 Mdot
.23832 .68118 Mdot
.59757 .46574 Mdot
.58225 .46019 Mdot
.55963 .40878 Mdot
.49174 .67892 Mdot
.43964 .36144 Mdot
.63686 .35764 Mdot
.25752 .44033 Mdot
.57689 .41748 Mdot
.33663 .58269 Mdot
.71899 .58944 Mdot
.61391 .44505 Mdot
.41273 .33258 Mdot
.61391 .38771 Mdot
.42155 .37816 Mdot
.41447 .33897 Mdot
.66742 .43195 Mdot
.55265 .78254 Mdot
.42112 .33468 Mdot
.56472 .41569 Mdot
.49038 .6848 Mdot
.30364 .76283 Mdot
.6162 .43856 Mdot
.67376 .62211 Mdot
.63175 .40668 Mdot
.69908 .58827 Mdot
.57081 .4042 Mdot
.2267 .54562 Mdot
.4684 .24192 Mdot
.48058 .66235 Mdot
.66938 .56208 Mdot
.46861 .62573 Mdot
.47392 .41477 Mdot
.37362 .32783 Mdot
.22811 .55467 Mdot
.43409 .18517 Mdot
.25671 .54012 Mdot
.74478 .39298 Mdot
.31144 .66095 Mdot
.40054 .58877 Mdot
.43071 .36586 Mdot
.72602 .39536 Mdot
.47877 .75262 Mdot
.50306 .63225 Mdot
.5189 .6493 Mdot
.75663 .28348 Mdot
.57137 .15562 Mdot
.57908 .43633 Mdot
.76314 .67236 Mdot
.49238 .28343 Mdot
.58576 .37287 Mdot
.56769 .37352 Mdot
.51898 .66407 Mdot
.54968 .39828 Mdot
.48964 .51495 Mdot
.4994 .66568 Mdot
.67718 .60647 Mdot
.41 .34566 Mdot
.68646 .58051 Mdot
.42848 .76991 Mdot
.34873 .49445 Mdot
.50694 .66205 Mdot
.61295 .3734 Mdot
.57437 .44032 Mdot
.42609 .37786 Mdot
.42582 .30564 Mdot
.40474 .33095 Mdot
.69093 .62638 Mdot
.49062 .66496 Mdot
.46426 .19564 Mdot
.63497 .41261 Mdot
.38762 .37356 Mdot
.43214 .62806 Mdot
.62415 .40812 Mdot
.38896 .58887 Mdot
.61566 .40223 Mdot
.39976 .37945 Mdot
.58103 .39849 Mdot
.38519 .35983 Mdot
.49662 .69321 Mdot
.61349 .46088 Mdot
.59674 .41986 Mdot
.74473 .36314 Mdot
.67301 .59611 Mdot
.3712 .332 Mdot
.48634 .50731 Mdot
.61465 .4631 Mdot
.7151 .4691 Mdot
.54554 .41351 Mdot
.57865 .49942 Mdot
.62501 .36368 Mdot
.25041 .55077 Mdot
.65816 .40982 Mdot
.61474 .43903 Mdot
.51766 .34083 Mdot
.60691 .29569 Mdot
.40338 .42219 Mdot
.41014 .59637 Mdot
.41195 .33222 Mdot
.50145 .64679 Mdot
.49443 .63592 Mdot
.46593 .67366 Mdot
.80863 .52308 Mdot
.67263 .42859 Mdot
.60997 .43604 Mdot
.3914 .60312 Mdot
.6817 .6 Mdot
.38256 .37591 Mdot
.6865 .60334 Mdot
.34287 .44669 Mdot
.69817 .62112 Mdot
.2549 .55084 Mdot
.6607 .69796 Mdot
.38525 .24811 Mdot
.68225 .62387 Mdot
.40564 .33117 Mdot
.57807 .6132 Mdot
.64892 .41385 Mdot
.27746 .69549 Mdot
.6636 .60592 Mdot
.78475 .3257 Mdot
.55486 .43381 Mdot
.48759 .52423 Mdot
.40545 .57164 Mdot
.69214 .58557 Mdot
.36234 .54899 Mdot
.61047 .38462 Mdot
.22836 .40103 Mdot
.40911 .36454 Mdot
.39461 .60828 Mdot
.65076 .39808 Mdot
.68793 .58168 Mdot
.50523 .65633 Mdot
.53667 .51332 Mdot
.37575 .5865 Mdot
.7606 .38588 Mdot
.72651 .45984 Mdot
.49272 .66576 Mdot
.32712 .24697 Mdot
.3787 .54337 Mdot
.60389 .37108 Mdot
.62861 .50787 Mdot
.61396 .39239 Mdot
.50359 .64562 Mdot
.46765 .64914 Mdot
.27855 .50547 Mdot
.56466 .43265 Mdot
.55211 .42946 Mdot
.44443 .37731 Mdot
.50565 .67006 Mdot
.38275 .341 Mdot
.43276 .37553 Mdot
.48474 .68303 Mdot
.39022 .33527 Mdot
.70163 .60792 Mdot
.38691 .46959 Mdot
.38169 .54377 Mdot
.37283 .57684 Mdot
.50501 .65323 Mdot
.4853 .70232 Mdot
.50419 .68038 Mdot
.61228 .40243 Mdot
.3705 .35486 Mdot
.58183 .39004 Mdot
.60096 .37758 Mdot
.39866 .30833 Mdot
.37668 .37833 Mdot
.59151 .38661 Mdot
.59147 .62132 Mdot
.64962 .58928 Mdot
.47357 .64674 Mdot
.38231 .55172 Mdot
.74074 .34102 Mdot
.38385 .60308 Mdot
.57429 .45231 Mdot
.29771 .71137 Mdot
.38119 .37786 Mdot
.67962 .58799 Mdot
.71024 .63065 Mdot
.68843 .59198 Mdot
.39578 .60862 Mdot
.43381 .36737 Mdot
.34168 .47636 Mdot
.57799 .45304 Mdot
.42338 .49321 Mdot
.73561 .40794 Mdot
.28617 .46753 Mdot
.37817 .55549 Mdot
.61298 .41002 Mdot
.25696 .54198 Mdot
.42312 .23557 Mdot
.60336 .43407 Mdot
.65642 .41464 Mdot
.61788 .67012 Mdot
.61109 .4876 Mdot
.35364 .36051 Mdot
.3964 .44205 Mdot
.63572 .45046 Mdot
.42131 .42445 Mdot
.40573 .13783 Mdot
.55518 .43268 Mdot
.58794 .41565 Mdot
.63005 .43249 Mdot
.57909 .38595 Mdot
.3733 .31549 Mdot
.61616 .63948 Mdot
.40149 .59643 Mdot
.39746 .47528 Mdot
.37187 .54672 Mdot
.48066 .6417 Mdot
.49694 .52467 Mdot
.42727 .35513 Mdot
.68714 .59038 Mdot
.8119 .62629 Mdot
.35145 .44027 Mdot
.50918 .69264 Mdot
.52192 .18171 Mdot
.66445 .59672 Mdot
.6484 .41731 Mdot
.65664 .57935 Mdot
.49284 .63132 Mdot
.36838 .56368 Mdot
.5977 .468 Mdot
.39366 .39055 Mdot
.391 .32057 Mdot
.61025 .40912 Mdot
.25779 .71663 Mdot
.35915 .55691 Mdot
.35659 .61483 Mdot
.56738 .42954 Mdot
.65635 .41588 Mdot
.40734 .33679 Mdot
.4702 .65424 Mdot
.29624 .6318 Mdot
.67174 .60475 Mdot
.63991 .38086 Mdot
.61384 .38588 Mdot
.35496 .45352 Mdot
.41753 .57097 Mdot
.23948 .53397 Mdot
.56592 .43035 Mdot
.36988 .4648 Mdot
.56328 .42737 Mdot
.54653 .36467 Mdot
.49898 .68583 Mdot
.58906 .47311 Mdot
.63562 .44442 Mdot
.69542 .36091 Mdot
.37686 .54212 Mdot
.4013 .35845 Mdot
.4248 .32991 Mdot
.24205 .52764 Mdot
.3949 .58628 Mdot
.60003 .38678 Mdot
.40832 .55209 Mdot
.62066 .38278 Mdot
.58181 .42972 Mdot
.37722 .55552 Mdot
.3833 .33998 Mdot
.3848 .74636 Mdot
.53611 .33956 Mdot
.55933 .40102 Mdot
.62872 .40023 Mdot
.80356 .53615 Mdot
.37229 .22194 Mdot
.6405 .43464 Mdot
.3718 .36742 Mdot
.6229 .40976 Mdot
.37949 .58483 Mdot
.69468 .62466 Mdot
.40128 .36746 Mdot
.49908 .70703 Mdot
.49231 .69305 Mdot
.44829 .67961 Mdot
.26073 .54746 Mdot
.64468 .41602 Mdot
.38934 .40551 Mdot
.38161 .38355 Mdot
.20617 .55715 Mdot
.49303 .64802 Mdot
.70663 .60714 Mdot
.55423 .41486 Mdot
.54621 .51792 Mdot
.40871 .58938 Mdot
.10105 .56594 Mdot
.33961 .48343 Mdot
.68762 .57286 Mdot
.32138 .38243 Mdot
.25262 .54567 Mdot
.61134 .4554 Mdot
.6563 .58949 Mdot
.4793 .69153 Mdot
.60953 .38187 Mdot
.64652 .47261 Mdot
.46078 .73994 Mdot
.52839 .69926 Mdot
.40478 .54914 Mdot
.48813 .69978 Mdot
.68317 .57356 Mdot
.25281 .55161 Mdot
.38452 .32702 Mdot
.60971 .4419 Mdot
.69189 .41693 Mdot
.48776 .64931 Mdot
.22531 .54034 Mdot
.56571 .42505 Mdot
.39832 .32156 Mdot
.46416 .65569 Mdot
.59083 .44459 Mdot
.4642 .21148 Mdot
.37997 .3007 Mdot
.48705 .65814 Mdot
.64042 .45272 Mdot
.48611 .4124 Mdot
.51286 .70264 Mdot
.52042 .66861 Mdot
.59827 .41423 Mdot
.69994 .60351 Mdot
.60744 .46014 Mdot
.40209 .56286 Mdot
.48424 .57605 Mdot
.38687 .58572 Mdot
.73559 .42701 Mdot
.6254 .46927 Mdot
.27145 .37606 Mdot
.41551 .38859 Mdot
.6836 .63913 Mdot
.52772 .3307 Mdot
.65402 .42435 Mdot
.4434 .80769 Mdot
.57914 .59746 Mdot
.21619 .58072 Mdot
.57498 .82553 Mdot
.67413 .6169 Mdot
.39737 .57177 Mdot
.58911 .41502 Mdot
.39309 .52823 Mdot
.68671 .62039 Mdot
.73744 .41938 Mdot
.64189 .45054 Mdot
.37535 .3509 Mdot
.57387 .42117 Mdot
.42451 .37023 Mdot
.62752 .40796 Mdot
.67579 .43292 Mdot
.64426 .59268 Mdot
.79579 .44095 Mdot
.64717 .41139 Mdot
.82275 .6157 Mdot
.51579 .51073 Mdot
.6661 .60854 Mdot
.56573 .40038 Mdot
.23978 .54196 Mdot
.35834 .56529 Mdot
.72899 .679 Mdot
.49779 .68087 Mdot
.38794 .55822 Mdot
.40654 .33935 Mdot
.45451 .67159 Mdot
.23812 .52761 Mdot
.67848 .48101 Mdot
.68128 .5778 Mdot
.40259 .58343 Mdot
.61444 .44137 Mdot
.57352 .45265 Mdot
.66418 .69269 Mdot
.2544 .29477 Mdot
.43939 .3797 Mdot
.81956 .41882 Mdot
.35825 .3684 Mdot
.6774 .59622 Mdot
.50134 .68511 Mdot
.62468 .44788 Mdot
.60121 .42851 Mdot
.4912 .63835 Mdot
.36784 .35873 Mdot
.45477 .68246 Mdot
.56398 .20046 Mdot
.47326 .61367 Mdot
.77653 .47466 Mdot
.4049 .37101 Mdot
.77894 .4689 Mdot
.69171 .57645 Mdot
.54749 .79498 Mdot
.73548 .56086 Mdot
.40716 .58202 Mdot
.77345 .48005 Mdot
.38714 .37961 Mdot
.58039 .43999 Mdot
.24346 .54908 Mdot
.26024 .53504 Mdot
.41677 .34966 Mdot
.479 .67726 Mdot
.68489 .5815 Mdot
.58468 .41914 Mdot
.3035 .44782 Mdot
.20333 .48135 Mdot
.45817 .66826 Mdot
.61685 .34475 Mdot
.36198 .55321 Mdot
.62509 .4031 Mdot
.66518 .6177 Mdot
.38462 .56345 Mdot
.27222 .53974 Mdot
.38999 .46764 Mdot
.55343 .41539 Mdot
.43886 .43553 Mdot
.39937 .58258 Mdot
.34257 .22855 Mdot
.5989 .42175 Mdot
.37842 .54328 Mdot
.58857 .49483 Mdot
.22897 .41644 Mdot
.60289 .56581 Mdot
.37063 .79746 Mdot
.53074 .67638 Mdot
.48754 .69121 Mdot
.19051 .40132 Mdot
.64016 .57999 Mdot
.39431 .59713 Mdot
.24807 .55292 Mdot
.73574 .52449 Mdot
.36533 .5447 Mdot
.57773 .45967 Mdot
.54607 .41586 Mdot
.56744 .20745 Mdot
.51132 .51844 Mdot
.2265 .53291 Mdot
.55009 .49857 Mdot
.59571 .39735 Mdot
.52933 .43322 Mdot
.61152 .41862 Mdot
.36177 .36072 Mdot
.36237 .54388 Mdot
.82594 .64205 Mdot
.37133 .53865 Mdot
.31109 .44988 Mdot
.48324 .65373 Mdot
.45653 .65764 Mdot
.61207 .44574 Mdot
.29104 .33649 Mdot
.71041 .70917 Mdot
.63488 .40417 Mdot
.71953 .61099 Mdot
.73071 .45298 Mdot
.53894 .43112 Mdot
.4407 .35348 Mdot
.63466 .3537 Mdot
.36157 .33252 Mdot
.38003 .5618 Mdot
.67591 .61845 Mdot
.6499 .61166 Mdot
.40172 .57254 Mdot
.6116 .43332 Mdot
.7167 .63265 Mdot
.60069 .4436 Mdot
.57422 .43657 Mdot
.33425 .44904 Mdot
.70012 .62833 Mdot
.50651 .6799 Mdot
.68828 .59566 Mdot
.39794 .34389 Mdot
.20614 .27158 Mdot
.68895 .61029 Mdot
.48907 .42774 Mdot
.51106 .55388 Mdot
.77419 .47522 Mdot
.39166 .32152 Mdot
.6822 .62728 Mdot
.39081 .54076 Mdot
.20767 .57899 Mdot
.34844 .23805 Mdot
.36352 .58947 Mdot
.59748 .42667 Mdot
.42936 .36403 Mdot
.37282 .37937 Mdot
.3463 .55967 Mdot
.37943 .33421 Mdot
.55146 .46433 Mdot
.55934 .42361 Mdot
.39451 .59696 Mdot
.23274 .48988 Mdot
.36235 .54318 Mdot
.52147 .49874 Mdot
.56174 .41078 Mdot
.4025 .36583 Mdot
.52039 .42987 Mdot
.43888 .39309 Mdot
.26197 .53371 Mdot
.62879 .3855 Mdot
.68674 .58708 Mdot
.46174 .50555 Mdot
.48536 .65781 Mdot
.30352 .71561 Mdot
.42672 .36408 Mdot
.4335 .60749 Mdot
.38943 .32944 Mdot
.4087 .39521 Mdot
.35086 .56022 Mdot
.40525 .353 Mdot
.5865 .41665 Mdot
.45134 .55144 Mdot
.41945 .37486 Mdot
.38485 .57717 Mdot
.6811 .5821 Mdot
.38718 .3367 Mdot
.44824 .6546 Mdot
.57978 .44388 Mdot
.51503 .67897 Mdot
.71323 .61326 Mdot
.42854 .35766 Mdot
.6849 .62687 Mdot
.48956 .64819 Mdot
.67321 .57858 Mdot
.5519 .6785 Mdot
.42346 .5662 Mdot
.31681 .42507 Mdot
.48916 .37007 Mdot
.39784 .39044 Mdot
.50774 .6354 Mdot
.63214 .44475 Mdot
.56913 .43898 Mdot
.67014 .57451 Mdot
.37596 .38222 Mdot
.29899 .75688 Mdot
.57192 .50035 Mdot
.28542 .51614 Mdot
.41944 .56789 Mdot
.78879 .37442 Mdot
.33309 .49944 Mdot
.2176 .59739 Mdot
.5862 .36258 Mdot
.25161 .54636 Mdot
.59985 .44762 Mdot
.76879 .38431 Mdot
.69717 .62414 Mdot
.36649 .69644 Mdot
.6071 .36424 Mdot
.4992 .67389 Mdot
.63128 .41426 Mdot
.76026 .67216 Mdot
.59364 .35204 Mdot
.67359 .62463 Mdot
.41185 .6024 Mdot
.42808 .39133 Mdot
.66573 .59621 Mdot
.49869 .69515 Mdot
.75915 .51985 Mdot
.63284 .45925 Mdot
.59376 .40085 Mdot
.50412 .63386 Mdot
.37567 .3452 Mdot
.48408 .64228 Mdot
.38071 .54384 Mdot
.68682 .60795 Mdot
.56975 .38983 Mdot
.54354 .45348 Mdot
.45844 .61982 Mdot
.3855 .53748 Mdot
.46825 .69038 Mdot
.41335 .5622 Mdot
.25073 .54729 Mdot
.64506 .4123 Mdot
.4897 .62706 Mdot
.557 .38413 Mdot
.63718 .30366 Mdot
.33283 .43711 Mdot
.54734 .31019 Mdot
.50801 .67937 Mdot
.78481 .51725 Mdot
.3953 .5779 Mdot
.40936 .56107 Mdot
.65932 .26203 Mdot
.69648 .71688 Mdot
.57673 .6189 Mdot
.82097 .59736 Mdot
.38178 .54405 Mdot
.38933 .5835 Mdot
.47668 .68796 Mdot
.40873 .35075 Mdot
.37691 .30673 Mdot
.45626 .63327 Mdot
.77625 .41051 Mdot
.38292 .37605 Mdot
.42468 .80789 Mdot
.52346 .68976 Mdot
.62558 .36466 Mdot
.22216 .53564 Mdot
.66629 .61537 Mdot
.7643 .40044 Mdot
.80152 .62262 Mdot
.61549 .45113 Mdot
.52062 .1601 Mdot
.47825 .66903 Mdot
.43574 .53901 Mdot
.49998 .79636 Mdot
.65608 .43062 Mdot
.63051 .42069 Mdot
.61459 .42754 Mdot
.68462 .63464 Mdot
.55482 .32339 Mdot
.61319 .45247 Mdot
.79563 .46043 Mdot
.57128 .45989 Mdot
.75022 .65873 Mdot
.68852 .59635 Mdot
.67296 .50102 Mdot
.5313 .67028 Mdot
.27022 .44481 Mdot
.54547 .47247 Mdot
.39147 .54506 Mdot
.44957 .75685 Mdot
.36862 .55889 Mdot
.62216 .77519 Mdot
.73427 .55733 Mdot
.36169 .36526 Mdot
.61499 .40339 Mdot
.51902 .65143 Mdot
.4281 .369 Mdot
.30684 .65221 Mdot
.27142 .21523 Mdot
.40932 .54849 Mdot
.59948 .14809 Mdot
.4105 .56288 Mdot
.2583 .53183 Mdot
.41207 .3418 Mdot
.33274 .3604 Mdot
.42781 .49483 Mdot
.3849 .34041 Mdot
.45921 .71475 Mdot
.43431 .34084 Mdot
.77905 .49887 Mdot
.40724 .39884 Mdot
.38794 .57491 Mdot
.42315 .59812 Mdot
.64149 .48412 Mdot
.63896 .43591 Mdot
.38621 .47626 Mdot
.54669 .48216 Mdot
.64118 .41552 Mdot
.49939 .66582 Mdot
.31459 .29641 Mdot
.44875 .59221 Mdot
.41626 .37006 Mdot
.41411 .58683 Mdot
.63134 .41917 Mdot
.56017 .40099 Mdot
.58081 .37626 Mdot
.76038 .37323 Mdot
.42624 .8058 Mdot
.58051 .43243 Mdot
.66679 .42695 Mdot
.50252 .69277 Mdot
.68659 .68149 Mdot
.83235 .51378 Mdot
.73882 .53527 Mdot
.56576 .44023 Mdot
.67658 .59261 Mdot
.69227 .62932 Mdot
.56151 .46434 Mdot
.28209 .4109 Mdot
.50413 .72513 Mdot
.61481 .44115 Mdot
.74586 .58815 Mdot
.44436 .63394 Mdot
.22655 .54715 Mdot
.48871 .64961 Mdot
.42221 .34331 Mdot
.25807 .53698 Mdot
.46139 .65036 Mdot
.33487 .30686 Mdot
.24317 .52823 Mdot
.2331 .42747 Mdot
.69062 .62659 Mdot
.60746 .42233 Mdot
.44015 .3997 Mdot
.49449 .64026 Mdot
.40348 .58121 Mdot
.39045 .36283 Mdot
.41586 .55035 Mdot
.68865 .68294 Mdot
.75787 .41834 Mdot
.26371 .5444 Mdot
.39512 .54859 Mdot
.40817 .45973 Mdot
.67991 .59211 Mdot
.35051 .56493 Mdot
.28416 .34099 Mdot
.54104 .42484 Mdot
.66602 .76117 Mdot
.59797 .40327 Mdot
.22109 .66891 Mdot
.40868 .56201 Mdot
.26661 .53449 Mdot
.60749 .4413 Mdot
.52253 .68293 Mdot
.65677 .47934 Mdot
.59863 .44241 Mdot
.49413 .70316 Mdot
.57991 .43708 Mdot
.66143 .61448 Mdot
.36029 .32663 Mdot
.5803 .59382 Mdot
.76156 .32829 Mdot
.66772 .58159 Mdot
.28033 .53087 Mdot
.64299 .42203 Mdot
.58113 .70168 Mdot
.38287 .3445 Mdot
.65752 .42007 Mdot
.61756 .21258 Mdot
.41611 .35552 Mdot
.38811 .35048 Mdot
.5828 .39476 Mdot
.37112 .59547 Mdot
.51122 .65878 Mdot
.68198 .59158 Mdot
.28617 .58632 Mdot
.59153 .44644 Mdot
.61078 .41238 Mdot
.66488 .59569 Mdot
.38854 .58482 Mdot
.57183 .38983 Mdot
.29836 .66971 Mdot
.25373 .56907 Mdot
.40701 .58724 Mdot
.54032 .42648 Mdot
.68478 .76928 Mdot
.35484 .31216 Mdot
.49041 .15213 Mdot
.64437 .572 Mdot
.48386 .6795 Mdot
.67211 .39165 Mdot
.09285 .5341 Mdot
.6679 .61573 Mdot
.28694 .46126 Mdot
.57555 .42997 Mdot
.6378 .42588 Mdot
.37643 .32852 Mdot
.59325 .38833 Mdot
.4024 .38125 Mdot
.76269 .32381 Mdot
.87028 .54279 Mdot
.38955 .33083 Mdot
.41179 .38044 Mdot
.35148 .38998 Mdot
.75368 .37859 Mdot
.40791 .34277 Mdot
.64022 .45431 Mdot
.53022 .74841 Mdot
.64716 .46488 Mdot
.70031 .58147 Mdot
.68392 .64094 Mdot
.45081 .36876 Mdot
.29394 .28233 Mdot
.67515 .4692 Mdot
.53309 .35492 Mdot
.62959 .56574 Mdot
.39467 .55465 Mdot
.55004 .40865 Mdot
.25888 .54923 Mdot
.46273 .66996 Mdot
.59805 .34785 Mdot
.60685 .42584 Mdot
.42182 .37612 Mdot
.68403 .63549 Mdot
.35448 .55621 Mdot
.59972 .41609 Mdot
.4996 .71532 Mdot
.67469 .60612 Mdot
.41762 .37571 Mdot
.4889 .43683 Mdot
.70607 .59446 Mdot
.53776 .45041 Mdot
.6405 .41715 Mdot
.5651 .42494 Mdot
.5513 .47712 Mdot
.40308 .57274 Mdot
.45385 .64581 Mdot
.59863 .47759 Mdot
.34725 .45708 Mdot
.46939 .53005 Mdot
.58831 .47466 Mdot
.36976 .35745 Mdot
.39934 .59877 Mdot
.24401 .53043 Mdot
.75598 .49237 Mdot
.55506 .42373 Mdot
.43423 .80498 Mdot
.51701 .18655 Mdot
.25125 .53589 Mdot
.36995 .38814 Mdot
.6838 .58928 Mdot
.58607 .40037 Mdot
.55691 .72916 Mdot
.56178 .44226 Mdot
.49884 .43196 Mdot
.48136 .67482 Mdot
.38825 .55132 Mdot
.237 .57104 Mdot
.46255 .67033 Mdot
.38939 .35085 Mdot
.27952 .75759 Mdot
.41446 .32379 Mdot
.43702 .37606 Mdot
.56635 .78468 Mdot
.37846 .55963 Mdot
.09739 .55114 Mdot
.36775 .22208 Mdot
.56063 .44326 Mdot
.36805 .57459 Mdot
.41578 .34401 Mdot
.60836 .40345 Mdot
.39334 .38726 Mdot
.43444 .35475 Mdot
.58846 .3795 Mdot
.63966 .42769 Mdot
.78907 .43214 Mdot
.42505 .82067 Mdot
.69429 .59713 Mdot
.36719 .34543 Mdot
.53552 .2053 Mdot
.61407 .45314 Mdot
.579 .4535 Mdot
.45871 .74667 Mdot
.67576 .62505 Mdot
.42259 .27073 Mdot
.56841 .43305 Mdot
.63058 .22077 Mdot
.64082 .40815 Mdot
.42118 .41589 Mdot
.37393 .59898 Mdot
.28453 .42124 Mdot
.50611 .64824 Mdot
.40297 .32069 Mdot
.69766 .58767 Mdot
.38983 .3134 Mdot
.637 .24217 Mdot
.37474 .56108 Mdot
.39971 .37951 Mdot
.4691 .69507 Mdot
.37395 .57052 Mdot
.40849 .58043 Mdot
.56487 .70283 Mdot
.45477 .66951 Mdot
.67139 .62986 Mdot
.3659 .55669 Mdot
.48663 .2095 Mdot
.38603 .57143 Mdot
.55345 .20875 Mdot
.62783 .45451 Mdot
.79047 .45368 Mdot
.32111 .50219 Mdot
.57554 .48406 Mdot
.35961 .5473 Mdot
.69497 .61203 Mdot
.609 .38999 Mdot
.37727 .33588 Mdot
.6871 .61361 Mdot
.34038 .54738 Mdot
.4837 .70343 Mdot
.39867 .39588 Mdot
.39122 .60166 Mdot
.39752 .38242 Mdot
.74982 .41838 Mdot
.54298 .69177 Mdot
.63805 .55204 Mdot
.44157 .50499 Mdot
.59944 .37085 Mdot
.42505 .42319 Mdot
.61775 .4629 Mdot
.60501 .43038 Mdot
.48695 .6574 Mdot
.8083 .52093 Mdot
.38499 .33719 Mdot
.18661 .54363 Mdot
.40136 .55294 Mdot
.39066 .44105 Mdot
.5118 .46386 Mdot
.62205 .38478 Mdot
.42006 .37058 Mdot
.43744 .36176 Mdot
.60587 .29567 Mdot
.48836 .63735 Mdot
.60984 .48173 Mdot
.57262 .4785 Mdot
.6744 .42385 Mdot
.41092 .56563 Mdot
.31888 .69037 Mdot
.46573 .64219 Mdot
.51215 .12605 Mdot
.47233 .64709 Mdot
.59927 .67185 Mdot
.40628 .3538 Mdot
.70386 .61295 Mdot
.58258 .45488 Mdot
.57074 .32739 Mdot
.37077 .31897 Mdot
.49147 .72389 Mdot
.68046 .58634 Mdot
.35586 .72232 Mdot
.38316 .55839 Mdot
.63685 .45151 Mdot
.56794 .38619 Mdot
.5749 .39331 Mdot
.58181 .41004 Mdot
.41339 .5914 Mdot
.57812 .45957 Mdot
.4211 .58203 Mdot
.44091 .2199 Mdot
.64094 .23072 Mdot
.51972 .65818 Mdot
.73003 .6671 Mdot
.39283 .39162 Mdot
.52936 .21707 Mdot
.40827 .26567 Mdot
.33056 .43717 Mdot
.5585 .68101 Mdot
.63866 .44447 Mdot
.47768 .67719 Mdot
.76079 .6751 Mdot
.51643 .64888 Mdot
.89103 .52699 Mdot
.7124 .44329 Mdot
.35855 .79801 Mdot
.60315 .40459 Mdot
.45422 .63439 Mdot
.41235 .28499 Mdot
.54788 .45299 Mdot
.70191 .64288 Mdot
.51282 .47831 Mdot
.25206 .47659 Mdot
.70711 .60528 Mdot
.58257 .44524 Mdot
.42607 .39415 Mdot
.58493 .41701 Mdot
.58581 .45402 Mdot
.6345 .40565 Mdot
.35678 .53991 Mdot
.54144 .41135 Mdot
.60546 .4602 Mdot
.26497 .28087 Mdot
.79272 .54289 Mdot
.51378 .69161 Mdot
.57823 .29525 Mdot
.68158 .60039 Mdot
.42507 .37467 Mdot
.56387 .58562 Mdot
.39861 .56179 Mdot
.61728 .29513 Mdot
.60128 .4039 Mdot
.30069 .50528 Mdot
.38513 .60245 Mdot
.68225 .61773 Mdot
.2382 .52952 Mdot
.43775 .78756 Mdot
.51056 .64856 Mdot
.25037 .52612 Mdot
.48427 .65814 Mdot
.47561 .32791 Mdot
.4219 .37432 Mdot
.58804 .37485 Mdot
.36409 .55065 Mdot
.51935 .67009 Mdot
.80474 .55612 Mdot
.61807 .41863 Mdot
.50927 .67779 Mdot
.60004 .37139 Mdot
.46835 .54077 Mdot
.51489 .56054 Mdot
.47926 .62546 Mdot
.42067 .60016 Mdot
.37413 .57446 Mdot
.70206 .61051 Mdot
.4241 .37797 Mdot
.37477 .37127 Mdot
.38104 .56465 Mdot
.53323 .14568 Mdot
.59409 .44776 Mdot
.63947 .4108 Mdot
.3465 .46342 Mdot
.5995 .40845 Mdot
.77239 .52722 Mdot
.24095 .55593 Mdot
.40766 .39142 Mdot
.58757 .41006 Mdot
.56963 .39089 Mdot
.55369 .41362 Mdot
.75513 .42389 Mdot
.4831 .64828 Mdot
.59427 .3976 Mdot
.66165 .57983 Mdot
.25786 .37595 Mdot
.62644 .45029 Mdot
.53788 .44541 Mdot
.39598 .38032 Mdot
.80173 .38312 Mdot
.40655 .57352 Mdot
.50814 .66871 Mdot
.5216 .69205 Mdot
.69579 .50032 Mdot
.35337 .32855 Mdot
.22606 .55222 Mdot
.41113 .65816 Mdot
.23251 .54875 Mdot
.66632 .60461 Mdot
.58723 .64132 Mdot
.50626 .71542 Mdot
.50489 .69725 Mdot
.42315 .56838 Mdot
.58191 .41182 Mdot
.64073 .40935 Mdot
.28886 .45973 Mdot
.63274 .39433 Mdot
.68083 .58394 Mdot
.38431 .59783 Mdot
.39485 .37869 Mdot
.66185 .60971 Mdot
.40389 .55176 Mdot
.37475 .34571 Mdot
.5434 .43879 Mdot
.53969 .40119 Mdot
.3879 .358 Mdot
.41943 .34364 Mdot
.62215 .44246 Mdot
.23216 .33257 Mdot
.41766 .39292 Mdot
.40288 .3757 Mdot
.24635 .52067 Mdot
.5111 .64848 Mdot
.52517 .40049 Mdot
.36508 .57067 Mdot
.5662 .42691 Mdot
.51822 .6543 Mdot
.68292 .62478 Mdot
.38043 .35841 Mdot
.55659 .40772 Mdot
.58641 .437 Mdot
.67681 .59165 Mdot
.7078 .61926 Mdot
.67066 .58312 Mdot
.39898 .5372 Mdot
.56964 .41255 Mdot
.40351 .33941 Mdot
.37779 .55783 Mdot
.69298 .62888 Mdot
.65141 .59935 Mdot
.28657 .26666 Mdot
.61337 .4509 Mdot
.61067 .5705 Mdot
.15871 .33467 Mdot
.75521 .52628 Mdot
.251 .52858 Mdot
.46402 .6222 Mdot
.7898 .46958 Mdot
.6586 .56041 Mdot
.36899 .57751 Mdot
.7108 .5635 Mdot
.68869 .63828 Mdot
.59873 .37818 Mdot
.62347 .39871 Mdot
.64092 .37754 Mdot
.67956 .60742 Mdot
.74943 .42473 Mdot
.37054 .37519 Mdot
.49313 .26062 Mdot
.68162 .60058 Mdot
.47781 .62511 Mdot
.48391 .62517 Mdot
.47171 .64666 Mdot
.6416 .44255 Mdot
.57865 .30462 Mdot
.50546 .20381 Mdot
.44423 .28071 Mdot
.38793 .55873 Mdot
.43937 .36361 Mdot
.56235 .676 Mdot
.38698 .35017 Mdot
.46513 .66885 Mdot
.6772 .61063 Mdot
.37129 .33454 Mdot
.39392 .58985 Mdot
.38399 .58446 Mdot
.49535 .70709 Mdot
.49445 .65125 Mdot
.50655 .65972 Mdot
.41961 .33805 Mdot
.40549 .35299 Mdot
.561 .39593 Mdot
.38461 .36638 Mdot
.45861 .1797 Mdot
.69342 .5741 Mdot
.50983 .63852 Mdot
.39743 .58163 Mdot
.42499 .36439 Mdot
.60457 .42254 Mdot
.63257 .67555 Mdot
.45153 .68404 Mdot
.66129 .58697 Mdot
.47601 .59103 Mdot
.87556 .4481 Mdot
.56047 .38911 Mdot
.41388 .56009 Mdot
.2761 .39535 Mdot
.61981 .4242 Mdot
.49222 .68057 Mdot
.72846 .35469 Mdot
.22685 .5432 Mdot
.61002 .45828 Mdot
.65277 .40849 Mdot
.35141 .55954 Mdot
.54389 .5746 Mdot
.62734 .38706 Mdot
.46367 .4445 Mdot
.38733 .53646 Mdot
.46404 .64349 Mdot
.15863 .47811 Mdot
.4812 .61669 Mdot
.80054 .44075 Mdot
.25118 .53044 Mdot
.56931 .38612 Mdot
.49643 .66406 Mdot
.65708 .59124 Mdot
.4959 .65865 Mdot
.3809 .39197 Mdot
.51515 .67405 Mdot
.6182 .4108 Mdot
.40252 .34035 Mdot
.39682 .58569 Mdot
.40647 .43969 Mdot
.26779 .28942 Mdot
.52218 .68535 Mdot
.2753 .53742 Mdot
.61241 .45577 Mdot
.43067 .23801 Mdot
.66448 .47034 Mdot
.63731 .4412 Mdot
.36931 .55782 Mdot
.41925 .36991 Mdot
.41953 .56945 Mdot
.5351 .42235 Mdot
.66179 .27265 Mdot
.40336 .55686 Mdot
.2328 .45469 Mdot
.66433 .59923 Mdot
.77462 .4101 Mdot
.59992 .43434 Mdot
.36629 .5499 Mdot
.56865 .41276 Mdot
.36555 .34934 Mdot
.45046 .48724 Mdot
.26664 .36151 Mdot
.36307 .5531 Mdot
.24783 .71325 Mdot
.48546 .50525 Mdot
.55075 .37081 Mdot
.37286 .5452 Mdot
.53895 .32285 Mdot
.23932 .53823 Mdot
.67077 .60498 Mdot
.69972 .62686 Mdot
.68375 .57765 Mdot
.63362 .39537 Mdot
.66035 .36276 Mdot
.65626 .61861 Mdot
.40884 .54576 Mdot
.65576 .60758 Mdot
.75376 .39522 Mdot
.27644 .73679 Mdot
.66503 .58643 Mdot
.59514 .43149 Mdot
.5386 .44352 Mdot
.79397 .5449 Mdot
.46204 .64225 Mdot
.44862 .80674 Mdot
.39159 .2232 Mdot
.62727 .44552 Mdot
.66906 .49026 Mdot
.38813 .39226 Mdot
.29597 .36923 Mdot
.5851 .50474 Mdot
.57927 .61078 Mdot
.41092 .37713 Mdot
.46762 .55859 Mdot
.41075 .39008 Mdot
.55874 .3878 Mdot
.58149 .42864 Mdot
.36568 .3222 Mdot
.28904 .69712 Mdot
.2096 .42141 Mdot
.1894 .60625 Mdot
.37343 .37054 Mdot
.37592 .54225 Mdot
.40809 .54905 Mdot
.38078 .55528 Mdot
.50242 .64687 Mdot
.41291 .33392 Mdot
.57347 .40731 Mdot
.49171 .69095 Mdot
.57275 .44606 Mdot
.36973 .56658 Mdot
.23958 .57191 Mdot
.39652 .37955 Mdot
.61414 .43978 Mdot
.34588 .24136 Mdot
.47581 .65609 Mdot
.67877 .5934 Mdot
.45041 .53907 Mdot
.4584 .6218 Mdot
.3656 .53958 Mdot
.35222 .32219 Mdot
.39835 .6197 Mdot
.61866 .63887 Mdot
.66456 .40565 Mdot
.62561 .46314 Mdot
.29769 .57402 Mdot
.30784 .26679 Mdot
.63091 .39802 Mdot
.49862 .69548 Mdot
.49309 .63218 Mdot
.55842 .42415 Mdot
.38802 .32547 Mdot
.67319 .63429 Mdot
.68076 .57513 Mdot
.64064 .3891 Mdot
.4204 .49255 Mdot
.79197 .44575 Mdot
.58822 .38622 Mdot
.50699 .41039 Mdot
.46457 .68894 Mdot
.24064 .52682 Mdot
.37475 .46501 Mdot
.69948 .59384 Mdot
.57396 .43106 Mdot
.20064 .44748 Mdot
.40546 .37977 Mdot
.51251 .66713 Mdot
.39567 .59444 Mdot
.70361 .64375 Mdot
.51808 .69937 Mdot
.55852 .4238 Mdot
.57106 .39022 Mdot
.35167 .56388 Mdot
.42363 .4148 Mdot
.67926 .61057 Mdot
.49364 .69088 Mdot
.7042 .61192 Mdot
.39899 .34685 Mdot
.39778 .37524 Mdot
.58137 .48158 Mdot
.58872 .48792 Mdot
.5214 .69106 Mdot
.64967 .39247 Mdot
.46191 .65551 Mdot
.66878 .69045 Mdot
.40958 .5893 Mdot
.65851 .42059 Mdot
.37035 .39474 Mdot
.37141 .5652 Mdot
.63304 .43419 Mdot
.30396 .56305 Mdot
.59961 .38171 Mdot
.45504 .63442 Mdot
.66943 .26968 Mdot
.68861 .62079 Mdot
.47222 .40029 Mdot
.66877 .34902 Mdot
.60118 .4086 Mdot
.45928 .64011 Mdot
.67948 .40376 Mdot
.4043 .56275 Mdot
.41339 .36308 Mdot
.71061 .22954 Mdot
.38373 .57432 Mdot
.58204 .42047 Mdot
.68715 .61027 Mdot
.43506 .38456 Mdot
.25988 .54519 Mdot
.35184 .47671 Mdot
.595 .3495 Mdot
.57598 .36388 Mdot
.5812 .41391 Mdot
.82412 .59386 Mdot
.5035 .66425 Mdot
.42201 .35357 Mdot
.41356 .57384 Mdot
.39045 .56492 Mdot
.46995 .65468 Mdot
.2714 .49143 Mdot
.32295 .73979 Mdot
.11764 .39856 Mdot
.51017 .70032 Mdot
.6537 .59414 Mdot
.47141 .51729 Mdot
.46245 .67206 Mdot
.50022 .66969 Mdot
.49967 .70907 Mdot
.30854 .49402 Mdot
.37135 .34862 Mdot
.58527 .43774 Mdot
.35099 .3387 Mdot
.58475 .38082 Mdot
.81961 .50566 Mdot
.38102 .56301 Mdot
.41214 .36129 Mdot
.30758 .57305 Mdot
.56452 .49255 Mdot
.62648 .42008 Mdot
.52634 .73925 Mdot
.62869 .35521 Mdot
.76656 .48629 Mdot
.52746 .43842 Mdot
.48879 .653 Mdot
.68338 .47417 Mdot
.67061 .39057 Mdot
.37503 .23316 Mdot
.39034 .58771 Mdot
.26543 .53963 Mdot
.54704 .43929 Mdot
.53978 .37137 Mdot
.43591 .38136 Mdot
.37142 .33406 Mdot
.65773 .62098 Mdot
.42952 .51284 Mdot
.394 .5875 Mdot
.37032 .76196 Mdot
.64098 .43058 Mdot
.39918 .51861 Mdot
.6588 .25682 Mdot
.63053 .43517 Mdot
.55416 .72148 Mdot
.61464 .29502 Mdot
.62184 .3856 Mdot
.46808 .28979 Mdot
.39263 .58016 Mdot
.62687 .21841 Mdot
.63047 .37365 Mdot
.49187 .67948 Mdot
.40992 .35326 Mdot
.39396 .39423 Mdot
.65954 .59342 Mdot
.4194 .19576 Mdot
.42968 .58857 Mdot
.40854 .35572 Mdot
.6149 .42445 Mdot
.40429 .57904 Mdot
.26301 .53987 Mdot
.59257 .35603 Mdot
.63908 .75475 Mdot
.38717 .37107 Mdot
.65455 .4559 Mdot
.21706 .51758 Mdot
.48565 .53577 Mdot
.43368 .8248 Mdot
.38039 .55302 Mdot
.69702 .58836 Mdot
.52629 .43773 Mdot
.40536 .65389 Mdot
.61409 .36606 Mdot
.80519 .48231 Mdot
.45629 .36266 Mdot
.69541 .62421 Mdot
.61827 .4295 Mdot
.62743 .38761 Mdot
.45427 .5063 Mdot
.70776 .61586 Mdot
.62533 .38495 Mdot
.59795 .48252 Mdot
.37503 .34803 Mdot
.24926 .55549 Mdot
.38941 .37599 Mdot
.59775 .42567 Mdot
.67039 .49596 Mdot
.37801 .33027 Mdot
.42104 .78043 Mdot
.65196 .62885 Mdot
.39902 .56101 Mdot
.54134 .36507 Mdot
.63117 .45137 Mdot
.63985 .81721 Mdot
.26152 .53329 Mdot
.82151 .44994 Mdot
.45771 .62563 Mdot
.18439 .52608 Mdot
.45197 .62327 Mdot
.33407 .78789 Mdot
.40249 .4482 Mdot
.65899 .39952 Mdot
.73262 .57592 Mdot
.45685 .28253 Mdot
.42223 .56181 Mdot
.46777 .22016 Mdot
.6387 .43645 Mdot
.59442 .45204 Mdot
.47838 .68569 Mdot
.28022 .50203 Mdot
.27647 .40517 Mdot
.39908 .47816 Mdot
.67704 .61497 Mdot
.40112 .35437 Mdot
.62116 .40782 Mdot
.25281 .63829 Mdot
.51605 .68778 Mdot
.52469 .5105 Mdot
.61066 .44027 Mdot
.3044 .43903 Mdot
.2617 .46376 Mdot
.4046 .58137 Mdot
.46057 .62774 Mdot
.4541 .64704 Mdot
.54639 .41237 Mdot
.38549 .59139 Mdot
.57352 .38656 Mdot
.48304 .49773 Mdot
.66559 .42909 Mdot
.67303 .62065 Mdot
.58679 .45835 Mdot
.56627 .54218 Mdot
.33438 .80197 Mdot
.65284 .36425 Mdot
.42555 .38424 Mdot
.49898 .64576 Mdot
.47491 .64853 Mdot
.37522 .37249 Mdot
.47244 .64971 Mdot
.49594 .26723 Mdot
.61217 .22959 Mdot
.66749 .61262 Mdot
.39012 .26098 Mdot
.6815 .62024 Mdot
.26587 .54004 Mdot
.61801 .44847 Mdot
.42758 .68186 Mdot
.51187 .70027 Mdot
.74518 .35585 Mdot
.38676 .569 Mdot
.26074 .53306 Mdot
.55951 .44584 Mdot
.59012 .64527 Mdot
.46986 .6734 Mdot
.43878 .76653 Mdot
.55342 .41241 Mdot
.36875 .34683 Mdot
.62467 .38712 Mdot
.65931 .43701 Mdot
.24885 .52655 Mdot
.58004 .4137 Mdot
.40353 .55136 Mdot
.41076 .33127 Mdot
.33654 .78437 Mdot
.49738 .642 Mdot
.59656 .45567 Mdot
.61569 .42481 Mdot
.36637 .33938 Mdot
.57202 .45932 Mdot
.36585 .57441 Mdot
.11089 .6053 Mdot
.66493 .60058 Mdot
.23574 .52878 Mdot
.42834 .76976 Mdot
.61838 .39963 Mdot
.60305 .3862 Mdot
.29379 .57534 Mdot
.24274 .35955 Mdot
.39825 .54847 Mdot
.61223 .47449 Mdot
.50427 .69149 Mdot
.68472 .61505 Mdot
.35819 .56707 Mdot
.56172 .41971 Mdot
.59666 .45253 Mdot
.67045 .61952 Mdot
.53752 .73856 Mdot
.45427 .68351 Mdot
.38498 .55727 Mdot
.63372 .50833 Mdot
.63828 .67861 Mdot
.59662 .44552 Mdot
.22128 .6528 Mdot
.40303 .37342 Mdot
.37858 .54564 Mdot
.54413 .32981 Mdot
.59284 .37409 Mdot
.36538 .54027 Mdot
.39493 .58632 Mdot
.55262 .43147 Mdot
.35225 .33026 Mdot
.42664 .34489 Mdot
.40541 .375 Mdot
.68187 .27381 Mdot
.78087 .61251 Mdot
.50747 .65984 Mdot
.39165 .58248 Mdot
.50684 .63851 Mdot
.66626 .63192 Mdot
.46863 .52867 Mdot
.48979 .63019 Mdot
.39501 .39336 Mdot
.50114 .63233 Mdot
.58156 .38442 Mdot
.38903 .58955 Mdot
.50265 .69831 Mdot
.60994 .39849 Mdot
.50453 .40777 Mdot
.59302 .5432 Mdot
.67544 .63403 Mdot
.4655 .54992 Mdot
.58889 .42148 Mdot
.244 .52952 Mdot
.61815 .44377 Mdot
.39465 .59709 Mdot
.556 .54536 Mdot
.60064 .3989 Mdot
.51885 .69547 Mdot
.62951 .64269 Mdot
.46529 .63511 Mdot
.64004 .4596 Mdot
.59654 .42566 Mdot
.59656 .44734 Mdot
.6305 .38806 Mdot
.24073 .46614 Mdot
.42105 .5801 Mdot
.53609 .36668 Mdot
.52475 .70002 Mdot
.38394 .35294 Mdot
.36347 .35155 Mdot
.57439 .61511 Mdot
.25072 .52403 Mdot
.37689 .58383 Mdot
.59432 .4468 Mdot
.43903 .76612 Mdot
.24365 .57405 Mdot
.20708 .64004 Mdot
.57334 .68167 Mdot
.50078 .69672 Mdot
.42809 .37962 Mdot
.47623 .69347 Mdot
.55895 .43624 Mdot
.52725 .43506 Mdot
.35147 .79179 Mdot
.34488 .54629 Mdot
.67789 .60962 Mdot
.57294 .44694 Mdot
.78674 .41899 Mdot
.50243 .69277 Mdot
.46196 .68565 Mdot
.56227 .39219 Mdot
.4207 .33293 Mdot
.41401 .84147 Mdot
.39439 .59578 Mdot
.43816 .23387 Mdot
.46108 .36117 Mdot
.51887 .48359 Mdot
.40088 .57161 Mdot
.61688 .55775 Mdot
.47176 .63663 Mdot
.40289 .21366 Mdot
.38581 .35868 Mdot
.67676 .60544 Mdot
.57582 .47376 Mdot
.39729 .39422 Mdot
.46479 .61998 Mdot
.41112 .38583 Mdot
.57628 .37921 Mdot
.41608 .55666 Mdot
.46809 .65071 Mdot
.4124 .59942 Mdot
.36855 .31837 Mdot
.68424 .62074 Mdot
.74444 .38579 Mdot
.43939 .22898 Mdot
.61491 .29521 Mdot
.59348 .39783 Mdot
.48431 .75279 Mdot
.5684 .40945 Mdot
.43722 .37065 Mdot
.59913 .4338 Mdot
.41563 .42737 Mdot
.45643 .65977 Mdot
.65975 .44836 Mdot
.59885 .46139 Mdot
.41386 .22157 Mdot
.63009 .42615 Mdot
.55843 .44295 Mdot
.64776 .40182 Mdot
.4661 .3817 Mdot
.6252 .47501 Mdot
.37069 .34349 Mdot
.29201 .46981 Mdot
.49794 .66959 Mdot
.64989 .59832 Mdot
.69144 .57856 Mdot
.80224 .47457 Mdot
.77786 .41295 Mdot
.27843 .49299 Mdot
.37861 .37102 Mdot
.38619 .54005 Mdot
.57051 .38816 Mdot
.50639 .3396 Mdot
.6571 .53578 Mdot
.46984 .63876 Mdot
.52529 .67764 Mdot
.60863 .4879 Mdot
.81706 .62721 Mdot
.64108 .46655 Mdot
.34118 .4787 Mdot
.61877 .37984 Mdot
.65737 .41639 Mdot
.46651 .69297 Mdot
.75636 .4074 Mdot
.59436 .39771 Mdot
.43581 .38173 Mdot
.67485 .60076 Mdot
.66209 .4925 Mdot
.66453 .52471 Mdot
.5686 .52712 Mdot
.33432 .30074 Mdot
.57659 .41049 Mdot
.48953 .68633 Mdot
.40504 .39439 Mdot
.35361 .45865 Mdot
.37556 .55733 Mdot
.37042 .47284 Mdot
.45677 .20873 Mdot
.5185 .63251 Mdot
.67499 .60612 Mdot
.55657 .70939 Mdot
.6176 .41068 Mdot
.50405 .64913 Mdot
.57183 .38293 Mdot
.23802 .57583 Mdot
.68573 .62588 Mdot
.37908 .31226 Mdot
.37696 .5418 Mdot
.36848 .36472 Mdot
.55208 .30809 Mdot
.65472 .53298 Mdot
.18314 .52835 Mdot
.50682 .64442 Mdot
.70177 .34426 Mdot
.41601 .34982 Mdot
.55796 .41392 Mdot
.12895 .38151 Mdot
.40334 .37086 Mdot
.36763 .35742 Mdot
.58043 .61063 Mdot
.73592 .42628 Mdot
.67004 .3862 Mdot
.40539 .38882 Mdot
.52265 .65197 Mdot
.69062 .59603 Mdot
.60586 .39165 Mdot
.64319 .39679 Mdot
.37452 .33074 Mdot
.46733 .66941 Mdot
.78959 .41484 Mdot
.49168 .65181 Mdot
.37815 .34069 Mdot
.48019 .66225 Mdot
.40549 .76451 Mdot
.51229 .68564 Mdot
.60561 .46202 Mdot
.5937 .44581 Mdot
.63458 .74223 Mdot
.39766 .37517 Mdot
.60721 .38822 Mdot
.57811 .43382 Mdot
.40899 .3428 Mdot
.51766 .71194 Mdot
.62943 .31022 Mdot
.61178 .40377 Mdot
.58812 .44236 Mdot
.7019 .61966 Mdot
.47956 .56648 Mdot
.23715 .63083 Mdot
.60642 .3903 Mdot
.67069 .57633 Mdot
.42335 .34334 Mdot
.62083 .4418 Mdot
.76012 .40134 Mdot
.44309 .63102 Mdot
.56988 .45108 Mdot
.25866 .54725 Mdot
.63343 .40307 Mdot
.40774 .84035 Mdot
.60244 .45578 Mdot
.41205 .34022 Mdot
.4146 .35492 Mdot
.45273 .68282 Mdot
.39126 .35244 Mdot
.25597 .53223 Mdot
.37149 .56931 Mdot
.2084 .65408 Mdot
.25863 .53535 Mdot
.65454 .43051 Mdot
.36815 .22174 Mdot
.635 .3822 Mdot
.5503 .45037 Mdot
.74995 .37503 Mdot
.25458 .53396 Mdot
.42139 .36561 Mdot
.28891 .6937 Mdot
.6605 .42261 Mdot
.39282 .59555 Mdot
.5457 .45307 Mdot
.57308 .45426 Mdot
.49251 .47146 Mdot
.67492 .28434 Mdot
.38901 .59977 Mdot
.53007 .39309 Mdot
.60442 .3905 Mdot
.28044 .3149 Mdot
.61402 .41909 Mdot
.66277 .58897 Mdot
.38674 .38229 Mdot
.47346 .69291 Mdot
.66954 .59353 Mdot
.61928 .40453 Mdot
.68016 .60443 Mdot
.50861 .66259 Mdot
.36909 .55341 Mdot
.5809 .4554 Mdot
.70268 .58529 Mdot
.6792 .61342 Mdot
.56816 .40107 Mdot
.4108 .35713 Mdot
.67881 .45013 Mdot
.62342 .44021 Mdot
.55875 .42111 Mdot
.37491 .37144 Mdot
.40023 .16744 Mdot
.54898 .39907 Mdot
.60935 .56528 Mdot
.3592 .35039 Mdot
.22327 .54211 Mdot
.48266 .69656 Mdot
.56919 .378 Mdot
.38545 .56159 Mdot
.37578 .56496 Mdot
.53433 .69519 Mdot
.37911 .32014 Mdot
.4641 .65619 Mdot
.5784 .35764 Mdot
.59999 .48715 Mdot
.58346 .47836 Mdot
.71427 .2333 Mdot
.44081 .7889 Mdot
.40374 .3285 Mdot
.46783 .63684 Mdot
.39375 .47868 Mdot
.37744 .58319 Mdot
.53761 .69313 Mdot
.37326 .3961 Mdot
.42747 .3589 Mdot
.39497 .3919 Mdot
.69845 .59624 Mdot
.48983 .64599 Mdot
.44416 .38888 Mdot
.4071 .32205 Mdot
.55753 .40121 Mdot
.6029 .39039 Mdot
.44162 .34281 Mdot
.78805 .54772 Mdot
.67873 .62253 Mdot
.48823 .68184 Mdot
.59295 .84951 Mdot
.39632 .5962 Mdot
.41126 .22214 Mdot
.61049 .3994 Mdot
.29564 .185 Mdot
.60975 .47787 Mdot
.61478 .42265 Mdot
.42151 .34215 Mdot
.67111 .5712 Mdot
.69066 .6019 Mdot
.41572 .35034 Mdot
.37614 .3081 Mdot
.68459 .58039 Mdot
.57272 .69053 Mdot
.22632 .69304 Mdot
.36247 .46419 Mdot
.40756 .33769 Mdot
.4179 .23773 Mdot
.35891 .56239 Mdot
.35759 .34071 Mdot
.39323 .59952 Mdot
.50051 .67097 Mdot
.52333 .67575 Mdot
.35163 .56697 Mdot
.55407 .41982 Mdot
.51375 .67342 Mdot
.60899 .34789 Mdot
.38919 .7913 Mdot
.60964 .78708 Mdot
.22366 .37087 Mdot
.64369 .41305 Mdot
.28248 .41442 Mdot
.25742 .41845 Mdot
.59576 .41324 Mdot
.5294 .47238 Mdot
.67829 .60768 Mdot
.36005 .33863 Mdot
.37565 .58581 Mdot
.45669 .81752 Mdot
.59588 .44595 Mdot
.38438 .3374 Mdot
.38447 .58774 Mdot
.39528 .75335 Mdot
.46794 .44829 Mdot
.56515 .38888 Mdot
.08531 .47298 Mdot
.37248 .31588 Mdot
.47264 .69228 Mdot
.34974 .25203 Mdot
.35139 .34599 Mdot
.64049 .66846 Mdot
.45172 .65951 Mdot
.19819 .59941 Mdot
.42587 .3718 Mdot
.49399 .71763 Mdot
.39646 .34712 Mdot
.6614 .61306 Mdot
.35135 .32531 Mdot
.47088 .66042 Mdot
.62292 .4289 Mdot
.4716 .65683 Mdot
.66972 .62126 Mdot
.51107 .65356 Mdot
.37296 .58361 Mdot
.24889 .52977 Mdot
.37936 .58131 Mdot
.47031 .5342 Mdot
.64577 .27944 Mdot
.38815 .55152 Mdot
.45725 .76844 Mdot
.6293 .39782 Mdot
.41779 .41677 Mdot
.4774 .6966 Mdot
.52676 .66575 Mdot
.45334 .52002 Mdot
.38693 .33997 Mdot
.47443 .66523 Mdot
.46019 .21118 Mdot
.49656 .13619 Mdot
.60937 .34502 Mdot
.75708 .63686 Mdot
.40799 .34098 Mdot
.45667 .66778 Mdot
.34591 .46591 Mdot
.37301 .381 Mdot
.51402 .6966 Mdot
.3697 .54533 Mdot
.39416 .56589 Mdot
.55077 .41801 Mdot
.34895 .57453 Mdot
.45785 .64294 Mdot
.20913 .42866 Mdot
.38643 .38314 Mdot
.40366 .75125 Mdot
.66831 .58186 Mdot
.50469 .66927 Mdot
.67333 .4054 Mdot
.40245 .30442 Mdot
.52709 .6762 Mdot
.67821 .73301 Mdot
.63444 .83248 Mdot
.47546 .66599 Mdot
.38752 .38269 Mdot
.37953 .35602 Mdot
.66026 .3731 Mdot
.43246 .49817 Mdot
.47009 .6691 Mdot
.43835 .70031 Mdot
.80811 .49006 Mdot
.25134 .54722 Mdot
.32171 .24555 Mdot
.59484 .39838 Mdot
.56804 .41485 Mdot
.36277 .56572 Mdot
.62778 .41488 Mdot
.42901 .34509 Mdot
.56825 .46417 Mdot
.40555 .54526 Mdot
.46776 .64101 Mdot
.60794 .44996 Mdot
.69609 .60971 Mdot
.36478 .57483 Mdot
.3514 .54656 Mdot
.48786 .6651 Mdot
.40085 .39111 Mdot
.27639 .69383 Mdot
.4921 .65101 Mdot
.57767 .40911 Mdot
.24758 .53917 Mdot
.5825 .37556 Mdot
.5986 .76072 Mdot
.37161 .37546 Mdot
.47342 .69161 Mdot
.36913 .38792 Mdot
.38535 .58034 Mdot
.53334 .68506 Mdot
.61007 .41728 Mdot
.51769 .69265 Mdot
.67038 .55292 Mdot
.57821 .73032 Mdot
.40328 .31844 Mdot
.71825 .60154 Mdot
.36902 .33658 Mdot
.25236 .54728 Mdot
.72013 .50637 Mdot
.67052 .61007 Mdot
.5081 .6848 Mdot
.43541 .79383 Mdot
.50254 .70712 Mdot
.63154 .42694 Mdot
.63946 .42497 Mdot
.47812 .68734 Mdot
.70025 .609 Mdot
.77972 .36399 Mdot
.62562 .58369 Mdot
.42073 .37444 Mdot
.35624 .4208 Mdot
.53276 .857 Mdot
.40716 .61618 Mdot
.36962 .54066 Mdot
.51322 .41865 Mdot
.61222 .38335 Mdot
.35314 .55532 Mdot
.41332 .58771 Mdot
.69001 .62947 Mdot
.50737 .65358 Mdot
.40357 .40603 Mdot
.35687 .56117 Mdot
.69284 .36608 Mdot
.77039 .40358 Mdot
.648 .36484 Mdot
.66383 .45016 Mdot
.63561 .45055 Mdot
.48486 .53888 Mdot
.41787 .57044 Mdot
.58726 .42502 Mdot
.56986 .47907 Mdot
.38537 .54511 Mdot
.66639 .61807 Mdot
.34299 .36609 Mdot
.48428 .67133 Mdot
.41129 .13324 Mdot
.58295 .4566 Mdot
.62398 .43293 Mdot
.38827 .5589 Mdot
.29704 .27639 Mdot
.40129 .32958 Mdot
.39636 .38869 Mdot
.50441 .6639 Mdot
.44914 .5204 Mdot
.58218 .46593 Mdot
.59331 .41586 Mdot
.50483 .68226 Mdot
.24613 .53051 Mdot
.1956 .39861 Mdot
.58759 .43591 Mdot
.39746 .57875 Mdot
.44672 .75627 Mdot
.41812 .57333 Mdot
.56431 .38693 Mdot
.63363 .42654 Mdot
.60026 .46347 Mdot
.632 .38742 Mdot
.35353 .56361 Mdot
.59784 .41533 Mdot
.63832 .48882 Mdot
.41528 .37274 Mdot
.59616 .40427 Mdot
.79694 .46918 Mdot
.59243 .43991 Mdot
.69464 .6112 Mdot
.2435 .64717 Mdot
.58753 .451 Mdot
.59212 .40564 Mdot
.62272 .57786 Mdot
.61445 .43102 Mdot
.4038 .58728 Mdot
.38305 .3582 Mdot
.3906 .5834 Mdot
.41054 .56548 Mdot
.51853 .65006 Mdot
.68506 .63176 Mdot
.61913 .36597 Mdot
.67531 .57756 Mdot
.66981 .41058 Mdot
.57966 .3785 Mdot
.47254 .55716 Mdot
.34069 .48059 Mdot
.66554 .5605 Mdot
.60449 .42006 Mdot
.49987 .6653 Mdot
.48694 .70042 Mdot
.73276 .58579 Mdot
.63149 .35281 Mdot
.35775 .56938 Mdot
.3661 .54984 Mdot
.76889 .53048 Mdot
.48163 .45355 Mdot
.68915 .61665 Mdot
.39808 .47029 Mdot
.64668 .41961 Mdot
.57809 .4394 Mdot
.54009 .44751 Mdot
.49536 .63204 Mdot
.24389 .52772 Mdot
.47264 .63866 Mdot
.26745 .52384 Mdot
.41949 .57661 Mdot
.6438 .41507 Mdot
.56867 .79875 Mdot
.3858 .32236 Mdot
.38339 .35965 Mdot
.39648 .53844 Mdot
.46397 .6363 Mdot
.65961 .37442 Mdot
.73001 .23985 Mdot
.44815 .36659 Mdot
.65767 .57776 Mdot
.58867 .41749 Mdot
.49141 .66548 Mdot
.39647 .32025 Mdot
.71032 .61847 Mdot
.64384 .42305 Mdot
.51769 .70812 Mdot
.59726 .43695 Mdot
.45769 .29354 Mdot
.41697 .36754 Mdot
.22935 .57242 Mdot
.4109 .32135 Mdot
.35935 .54719 Mdot
.40639 .55688 Mdot
.63332 .43276 Mdot
.61097 .166 Mdot
.39291 .30874 Mdot
.39544 .60855 Mdot
.66304 .62061 Mdot
.23468 .53017 Mdot
.67382 .62966 Mdot
.46086 .66463 Mdot
.6739 .60332 Mdot
.52141 .69241 Mdot
.77498 .55037 Mdot
.44805 .37905 Mdot
.66639 .59849 Mdot
.27903 .2859 Mdot
.54343 .39691 Mdot
.69778 .62648 Mdot
.61899 .48748 Mdot
.43743 .41789 Mdot
.50248 .68054 Mdot
.69947 .6073 Mdot
.55798 .40713 Mdot
.49328 .80694 Mdot
.40951 .56126 Mdot
.35929 .57277 Mdot
.61431 .3655 Mdot
.47747 .70066 Mdot
.37268 .30897 Mdot
.56245 .58186 Mdot
.22364 .54605 Mdot
.59405 .41641 Mdot
.64515 .41991 Mdot
.36964 .32779 Mdot
.43966 .3753 Mdot
.63521 .42697 Mdot
.47802 .21348 Mdot
.61701 .40987 Mdot
.39761 .5666 Mdot
.42121 .34564 Mdot
.38079 .35944 Mdot
.45973 .63182 Mdot
.37978 .32033 Mdot
.6584 .4552 Mdot
.39787 .52848 Mdot
.55925 .47 Mdot
.38246 .57636 Mdot
.56868 .54763 Mdot
.5031 .64616 Mdot
.45495 .81084 Mdot
.38205 .31688 Mdot
.58314 .41073 Mdot
.36687 .34245 Mdot
.67201 .58295 Mdot
.39562 .37446 Mdot
.40241 .39767 Mdot
.63937 .43244 Mdot
.5682 .38672 Mdot
.24839 .53391 Mdot
.43292 .49992 Mdot
.41084 .36692 Mdot
.61086 .40904 Mdot
.64053 .38432 Mdot
.5438 .41144 Mdot
.48664 .50965 Mdot
.42981 .36243 Mdot
.57708 .21125 Mdot
.60688 .76992 Mdot
.40997 .36012 Mdot
.46672 .83689 Mdot
.24281 .55231 Mdot
.24919 .5232 Mdot
.41591 .61056 Mdot
.58594 .43891 Mdot
.46591 .65516 Mdot
.56117 .43921 Mdot
.59727 .34748 Mdot
.59132 .45404 Mdot
.67787 .62555 Mdot
.65563 .3854 Mdot
.23604 .54592 Mdot
.48546 .65003 Mdot
.6155 .40293 Mdot
.60396 .45152 Mdot
.25389 .52489 Mdot
.40783 .31832 Mdot
.42762 .3663 Mdot
.22845 .65935 Mdot
.66283 .60675 Mdot
.37087 .55771 Mdot
.55879 .43154 Mdot
.50171 .6647 Mdot
.47146 .65305 Mdot
.36783 .36179 Mdot
.48796 .67746 Mdot
.39336 .59692 Mdot
.61793 .41681 Mdot
.35285 .5566 Mdot
.67672 .62505 Mdot
.38611 .38183 Mdot
.55835 .43147 Mdot
.55639 .4031 Mdot
.41485 .35517 Mdot
.63054 .39838 Mdot
.70241 .6187 Mdot
.52009 .6685 Mdot
.42603 .36139 Mdot
.37221 .56819 Mdot
.4621 .62718 Mdot
.57447 .38757 Mdot
.71586 .7632 Mdot
.62788 .4129 Mdot
.56386 .43221 Mdot
.26838 .74066 Mdot
.52888 .44827 Mdot
.45806 .66652 Mdot
.36266 .35297 Mdot
.53933 .41143 Mdot
.81782 .51397 Mdot
.32663 .60766 Mdot
.53685 .69577 Mdot
.58467 .41635 Mdot
.43593 .81474 Mdot
.59011 .40954 Mdot
.38461 .75083 Mdot
.47125 .55439 Mdot
.7884 .63617 Mdot
.65856 .45922 Mdot
.37534 .59871 Mdot
.24941 .53254 Mdot
.4804 .69957 Mdot
.50487 .32175 Mdot
.63054 .40691 Mdot
.55557 .31854 Mdot
.57815 .45951 Mdot
.39988 .57069 Mdot
.52219 .45691 Mdot
.48778 .68056 Mdot
.37974 .22682 Mdot
.57325 .40846 Mdot
.42773 .3564 Mdot
.51614 .64336 Mdot
.22805 .53831 Mdot
.55653 .40869 Mdot
.66603 .58041 Mdot
.31322 .56864 Mdot
.62302 .48087 Mdot
.37976 .57458 Mdot
.57581 .43335 Mdot
.53722 .38065 Mdot
.54578 .15097 Mdot
.41724 .37286 Mdot
.36972 .54185 Mdot
.29016 .35656 Mdot
.63712 .40109 Mdot
.42634 .36961 Mdot
.38522 .35622 Mdot
.65718 .59673 Mdot
.34145 .49945 Mdot
.3719 .6253 Mdot
.65247 .77158 Mdot
.59355 .29378 Mdot
.46065 .62415 Mdot
.23128 .39644 Mdot
.59726 .39294 Mdot
.65504 .52953 Mdot
.40628 .58223 Mdot
.62249 .43165 Mdot
.62032 .27775 Mdot
.40425 .37603 Mdot
.59085 .43279 Mdot
.67642 .62157 Mdot
.29878 .53583 Mdot
.58157 .52629 Mdot
.6359 .81047 Mdot
.53412 .67179 Mdot
.55065 .45938 Mdot
.65529 .47003 Mdot
.22393 .53937 Mdot
.58959 .37811 Mdot
.475 .6956 Mdot
.49679 .76189 Mdot
.69867 .6149 Mdot
.38638 .31998 Mdot
.23827 .55174 Mdot
.60644 .46708 Mdot
.60575 .3684 Mdot
.65014 .5981 Mdot
.56132 .41213 Mdot
.36316 .24198 Mdot
.22045 .55787 Mdot
.514 .68438 Mdot
.4109 .38698 Mdot
.63801 .44836 Mdot
.243 .52834 Mdot
.63994 .42893 Mdot
.33622 .3614 Mdot
.57217 .42047 Mdot
.23746 .50616 Mdot
.40884 .35237 Mdot
.37865 .57688 Mdot
.62836 .36628 Mdot
.60339 .4438 Mdot
.63726 .68167 Mdot
.59325 .34801 Mdot
.6019 .45533 Mdot
.43191 .39055 Mdot
.38382 .32657 Mdot
.36962 .34956 Mdot
.5159 .67732 Mdot
.37001 .46492 Mdot
.39172 .57233 Mdot
.57069 .46171 Mdot
.3575 .56289 Mdot
.65359 .34605 Mdot
.65247 .58862 Mdot
.51418 .82841 Mdot
.62363 .40229 Mdot
.37169 .35976 Mdot
.2065 .45026 Mdot
.422 .34109 Mdot
.44392 .60172 Mdot
.3936 .5879 Mdot
.4044 .36936 Mdot
.60939 .43114 Mdot
.40748 .48211 Mdot
.68005 .78252 Mdot
.37345 .57873 Mdot
.53214 .4392 Mdot
.53164 .66748 Mdot
.52419 .6925 Mdot
.45767 .85609 Mdot
.40973 .55735 Mdot
.25451 .41464 Mdot
.60647 .40853 Mdot
.38238 .32426 Mdot
.38549 .55356 Mdot
.40675 .58598 Mdot
.50005 .68296 Mdot
.55714 .39443 Mdot
.60084 .44213 Mdot
.25652 .54873 Mdot
.3659 .55404 Mdot
.54636 .38637 Mdot
.60694 .37844 Mdot
.33628 .7871 Mdot
.38979 .40692 Mdot
.37336 .17832 Mdot
.56402 .36372 Mdot
.63115 .28564 Mdot
.50393 .52478 Mdot
.40591 .32882 Mdot
.55512 .42865 Mdot
.58532 .47083 Mdot
.45881 .62729 Mdot
.62146 .41432 Mdot
.47988 .63078 Mdot
.37298 .53975 Mdot
.5256 .83438 Mdot
.41226 .74515 Mdot
.55989 .67802 Mdot
.62901 .41981 Mdot
.52313 .49389 Mdot
.67324 .58688 Mdot
.38524 .53343 Mdot
.38278 .33401 Mdot
.64613 .43634 Mdot
.45103 .65532 Mdot
.50766 .68707 Mdot
.39054 .36152 Mdot
.26065 .43923 Mdot
.41998 .7799 Mdot
.63242 .38672 Mdot
.47126 .68756 Mdot
.3894 .73316 Mdot
.50512 .21581 Mdot
.35434 .58114 Mdot
.69397 .61983 Mdot
.46744 .64298 Mdot
.35131 .54378 Mdot
.35707 .39832 Mdot
.39758 .35995 Mdot
.36936 .323 Mdot
.61893 .73079 Mdot
.46868 .66458 Mdot
.679 .58992 Mdot
.46496 .43283 Mdot
.42367 .43886 Mdot
.68299 .62534 Mdot
.46769 .64013 Mdot
.3908 .32196 Mdot
.38206 .33846 Mdot
.38262 .35647 Mdot
.37349 .23343 Mdot
.37831 .38183 Mdot
.52738 .18264 Mdot
.62944 .37893 Mdot
.42919 .23997 Mdot
.58806 .41146 Mdot
.36193 .58245 Mdot
.4173 .36604 Mdot
.46619 .51912 Mdot
.65309 .41912 Mdot
.64357 .80319 Mdot
.58866 .42042 Mdot
.37045 .5224 Mdot
.58652 .4408 Mdot
.37764 .25574 Mdot
.35918 .34942 Mdot
.60501 .4186 Mdot
.39626 .60428 Mdot
.6824 .61172 Mdot
.34797 .31031 Mdot
.59023 .45069 Mdot
.29353 .51648 Mdot
.57306 .47946 Mdot
.40593 .78973 Mdot
.61598 .63881 Mdot
.66107 .57438 Mdot
.59103 .48264 Mdot
.47751 .62093 Mdot
.36961 .30008 Mdot
.41666 .25043 Mdot
.37225 .57723 Mdot
.70901 .3314 Mdot
.50978 .6823 Mdot
.52356 .45875 Mdot
.65333 .44328 Mdot
.70058 .59784 Mdot
.36603 .30441 Mdot
.39949 .5649 Mdot
.62908 .40083 Mdot
.55524 .43573 Mdot
.68918 .71209 Mdot
.40801 .25037 Mdot
.55444 .38067 Mdot
.66408 .6291 Mdot
.58884 .2175 Mdot
.57879 .44504 Mdot
.52371 .70583 Mdot
.36268 .36782 Mdot
.67206 .42385 Mdot
.56242 .20599 Mdot
.61399 .40794 Mdot
.39997 .36819 Mdot
.37992 .31743 Mdot
.22422 .48769 Mdot
.65739 .57998 Mdot
.57196 .42073 Mdot
.65438 .68097 Mdot
.57104 .4121 Mdot
.39515 .57084 Mdot
.55155 .39475 Mdot
.50497 .67414 Mdot
.34136 .46777 Mdot
.51756 .67119 Mdot
.54744 .4149 Mdot
.38271 .34468 Mdot
.39695 .56078 Mdot
.60752 .74561 Mdot
.54558 .58334 Mdot
.53895 .18525 Mdot
.31053 .57547 Mdot
.69699 .59719 Mdot
.69592 .63069 Mdot
.42463 .56962 Mdot
.59892 .42384 Mdot
.50111 .55005 Mdot
.65129 .4561 Mdot
.58571 .44376 Mdot
.58131 .45389 Mdot
.34404 .54349 Mdot
.38815 .58616 Mdot
.47643 .66079 Mdot
.63546 .42437 Mdot
.60995 .40984 Mdot
.40563 .35812 Mdot
.67994 .61434 Mdot
.51757 .68295 Mdot
.66305 .59797 Mdot
.49104 .65482 Mdot
.41894 .83918 Mdot
.53589 .41791 Mdot
.68365 .61176 Mdot
.41912 .56391 Mdot
.37186 .36644 Mdot
.26229 .5327 Mdot
.46118 .66009 Mdot
.48454 .67823 Mdot
.59647 .41441 Mdot
.39093 .38151 Mdot
.40298 .38264 Mdot
.68905 .58389 Mdot
.37565 .54876 Mdot
.55003 .42203 Mdot
.5915 .37963 Mdot
.73563 .6667 Mdot
.4731 .62397 Mdot
.49869 .20623 Mdot
.24694 .47951 Mdot
.60009 .4236 Mdot
.41256 .38204 Mdot
.61186 .44797 Mdot
.50426 .78581 Mdot
.39652 .39373 Mdot
.64923 .39903 Mdot
.48297 .43675 Mdot
.50812 .64185 Mdot
.20025 .51297 Mdot
.63675 .37446 Mdot
.29153 .57741 Mdot
.58002 .39598 Mdot
.22448 .71889 Mdot
.25328 .34884 Mdot
.59285 .46711 Mdot
.63608 .39291 Mdot
.68595 .75257 Mdot
.60146 .40798 Mdot
.24111 .54966 Mdot
.59709 .35269 Mdot
.42829 .36304 Mdot
.51986 .54853 Mdot
.47745 .57602 Mdot
.65325 .59918 Mdot
.50514 .66412 Mdot
.71623 .47278 Mdot
.66316 .61459 Mdot
.41176 .34196 Mdot
.64507 .39826 Mdot
.68417 .3401 Mdot
.44627 .66204 Mdot
.65954 .43843 Mdot
.39682 .57108 Mdot
.47361 .57161 Mdot
.4826 .63621 Mdot
.37235 .57168 Mdot
.58693 .4625 Mdot
.8185 .46113 Mdot
.55252 .59558 Mdot
.17913 .59089 Mdot
.38527 .55747 Mdot
.40249 .58317 Mdot
.34674 .4489 Mdot
.65332 .59895 Mdot
.70713 .6951 Mdot
.57742 .51295 Mdot
.39046 .59372 Mdot
.75438 .49548 Mdot
.45655 .67863 Mdot
.33724 .50056 Mdot
.35912 .34118 Mdot
.53574 .42465 Mdot
.6082 .43453 Mdot
.38066 .54671 Mdot
.53251 .34179 Mdot
.31772 .35081 Mdot
.37715 .58026 Mdot
.65747 .47404 Mdot
.30658 .53468 Mdot
.25146 .53855 Mdot
.25314 .55124 Mdot
.66034 .6197 Mdot
.51688 .74392 Mdot
.39955 .34407 Mdot
.7033 .60032 Mdot
.226 .51617 Mdot
.57012 .42461 Mdot
.36318 .55539 Mdot
.26686 .53759 Mdot
.37915 .56532 Mdot
.6909 .60669 Mdot
.65665 .57939 Mdot
.41566 .37282 Mdot
.40009 .32931 Mdot
.6738 .28755 Mdot
.77699 .51325 Mdot
.59711 .40626 Mdot
.62073 .30763 Mdot
.37794 .37809 Mdot
.39032 .27622 Mdot
.66457 .57783 Mdot
.67838 .61684 Mdot
.46938 .26674 Mdot
.56118 .39496 Mdot
.42956 .74999 Mdot
.58584 .44936 Mdot
.71902 .51721 Mdot
.65489 .43563 Mdot
.4959 .68164 Mdot
.58856 .40281 Mdot
.26135 .66889 Mdot
.61551 .39282 Mdot
.59142 .45694 Mdot
.47708 .64473 Mdot
.61462 .35997 Mdot
.50645 .67601 Mdot
.56035 .39021 Mdot
.6521 .62074 Mdot
.50173 .66442 Mdot
.76811 .61741 Mdot
.60836 .5633 Mdot
.23798 .53147 Mdot
.66156 .61682 Mdot
.67317 .57897 Mdot
.79967 .45351 Mdot
.38658 .3314 Mdot
.38276 .4178 Mdot
.5977 .42445 Mdot
.46329 .68716 Mdot
.36173 .5638 Mdot
.61319 .40945 Mdot
.58356 .47231 Mdot
.62767 .36798 Mdot
.40712 .37363 Mdot
.46277 .6435 Mdot
.68367 .60505 Mdot
.48835 .69933 Mdot
.59123 .6339 Mdot
.51518 .70245 Mdot
.51011 .41203 Mdot
.56322 .36642 Mdot
.68943 .39175 Mdot
.62927 .30067 Mdot
.4053 .20995 Mdot
.39319 .35794 Mdot
.24121 .54007 Mdot
.65176 .59767 Mdot
.35401 .41741 Mdot
.37354 .34992 Mdot
.48049 .67584 Mdot
.59743 .43694 Mdot
.66144 .4715 Mdot
.56237 .51918 Mdot
.45078 .34423 Mdot
.80762 .5188 Mdot
.49573 .64534 Mdot
.25458 .54337 Mdot
.356 .46635 Mdot
.45956 .38593 Mdot
.46882 .52397 Mdot
.60613 .44658 Mdot
.66875 .57857 Mdot
.39634 .32021 Mdot
.64794 .73002 Mdot
.37329 .5457 Mdot
.43113 .49801 Mdot
.62813 .41847 Mdot
.22733 .42154 Mdot
.383 .34482 Mdot
.68135 .62098 Mdot
.38178 .54655 Mdot
.65881 .57949 Mdot
.24007 .55312 Mdot
.24249 .67085 Mdot
.56486 .40666 Mdot
.60535 .45608 Mdot
.41517 .59376 Mdot
.39643 .34329 Mdot
.48369 .71725 Mdot
.65787 .73576 Mdot
.47263 .68771 Mdot
.49181 .55055 Mdot
.40855 .32926 Mdot
.34006 .2888 Mdot
.50841 .69733 Mdot
.40766 .545 Mdot
.49267 .53784 Mdot
.40588 .54617 Mdot
.58129 .44983 Mdot
.37976 .36988 Mdot
.40902 .55602 Mdot
.64778 .7032 Mdot
.39502 .81779 Mdot
.33751 .31733 Mdot
.63495 .40439 Mdot
.52427 .83211 Mdot
.31359 .76415 Mdot
.58133 .3245 Mdot
.35781 .55754 Mdot
.62801 .43948 Mdot
.63298 .38637 Mdot
.57614 .40739 Mdot
.39221 .54234 Mdot
.57359 .64271 Mdot
.49452 .68816 Mdot
.5836 .4231 Mdot
.66961 .58163 Mdot
.49692 .67415 Mdot
.49759 .62878 Mdot
.48904 .70421 Mdot
.40736 .39508 Mdot
.64036 .3914 Mdot
.3217 .49964 Mdot
.24978 .74337 Mdot
.38821 .58445 Mdot
.23744 .53179 Mdot
.59011 .46067 Mdot
.6576 .24415 Mdot
.36975 .35085 Mdot
.47282 .68694 Mdot
.62275 .43344 Mdot
.61384 .66186 Mdot
.28044 .5455 Mdot
.4948 .64989 Mdot
.38546 .33352 Mdot
.58086 .32509 Mdot
.62113 .41363 Mdot
.57779 .39524 Mdot
.40387 .34186 Mdot
.20663 .63719 Mdot
.34528 .47639 Mdot
.60797 .449 Mdot
.37715 .57646 Mdot
.51902 .13801 Mdot
.60917 .36713 Mdot
.43007 .3227 Mdot
.23581 .52898 Mdot
.26688 .49924 Mdot
.51406 .20837 Mdot
.55448 .35792 Mdot
.55012 .81627 Mdot
.75213 .40114 Mdot
.50131 .83033 Mdot
.68699 .50361 Mdot
.34609 .70219 Mdot
.37055 .83634 Mdot
.39222 .6052 Mdot
.38705 .26092 Mdot
.75893 .67871 Mdot
.27786 .44249 Mdot
.60327 .62569 Mdot
.37833 .64941 Mdot
.62256 .65409 Mdot
.2185 .33654 Mdot
.51051 .70174 Mdot
.69941 .53588 Mdot
.55275 .42793 Mdot
.30615 .75566 Mdot
.42791 .22666 Mdot
.41181 .19802 Mdot
.49616 .82167 Mdot
.65061 .67293 Mdot
.71943 .74729 Mdot
.45184 .80549 Mdot
.70766 .34767 Mdot
.52085 .50559 Mdot
.43547 .6703 Mdot
.44941 .43207 Mdot
.72431 .45702 Mdot
.67531 .38579 Mdot
.25609 .64141 Mdot
.54485 .69732 Mdot
.61497 .24827 Mdot
.51343 .14749 Mdot
.45893 .65871 Mdot
.36406 .37208 Mdot
.72964 .68368 Mdot
.36574 .29579 Mdot
.4347 .5956 Mdot
.55126 .81622 Mdot
.33656 .79055 Mdot
.37871 .25412 Mdot
.19875 .55291 Mdot
.48365 .29929 Mdot
.77565 .34274 Mdot
.56481 .53214 Mdot
.38815 .31248 Mdot
.37131 .68999 Mdot
.42447 .43825 Mdot
.46012 .71092 Mdot
.35345 .26213 Mdot
.71348 .60841 Mdot
.79407 .57599 Mdot
.38633 .33531 Mdot
.52377 .21721 Mdot
.24241 .52247 Mdot
.2292 .51792 Mdot
.47992 .7104 Mdot
.51637 .78565 Mdot
.28704 .54242 Mdot
.30416 .51429 Mdot
.20602 .42215 Mdot
.68767 .79066 Mdot
.75512 .4446 Mdot
.5169 .7667 Mdot
.3634 .51845 Mdot
.75352 .40774 Mdot
.31984 .45776 Mdot
.77709 .48267 Mdot
.43173 .42908 Mdot
.82092 .64153 Mdot
.23866 .69631 Mdot
.75716 .71433 Mdot
.35413 .38126 Mdot
.54603 .39299 Mdot
.55285 .77936 Mdot
.57744 .29707 Mdot
.66904 .56991 Mdot
.66503 .80066 Mdot
.68645 .57625 Mdot
.39908 .40434 Mdot
.27049 .4358 Mdot
.38227 .23755 Mdot
.53307 .72299 Mdot
.64627 .61981 Mdot
.64398 .46614 Mdot
.88145 .5503 Mdot
.57681 .8159 Mdot
.23522 .49013 Mdot
.32688 .78273 Mdot
.38113 .61005 Mdot
.44058 .63364 Mdot
.3791 .5393 Mdot
.37598 .82597 Mdot
.37644 .35499 Mdot
.26374 .76189 Mdot
.36819 .81613 Mdot
.31082 .31035 Mdot
.90168 .50764 Mdot
.21648 .36663 Mdot
.43892 .23485 Mdot
.73154 .3726 Mdot
.80774 .57069 Mdot
.32488 .43386 Mdot
.30862 .29958 Mdot
.4381 .61563 Mdot
.20129 .64032 Mdot
.42364 .8334 Mdot
.74575 .51018 Mdot
.5322 .64436 Mdot
.29036 .43795 Mdot
.58654 .54583 Mdot
.43189 .32826 Mdot
.61691 .59566 Mdot
.63702 .54348 Mdot
.73961 .72921 Mdot
.65392 .25768 Mdot
.6517 .18459 Mdot
.69636 .50551 Mdot
.30325 .27236 Mdot
.44345 .78532 Mdot
.7589 .61697 Mdot
.32934 .35517 Mdot
.29339 .47858 Mdot
.54018 .46172 Mdot
.38218 .46197 Mdot
.63122 .49404 Mdot
.71912 .61775 Mdot
.35809 .458 Mdot
.35204 .74138 Mdot
.71366 .50292 Mdot
.63323 .77539 Mdot
.50026 .47739 Mdot
.4169 .38869 Mdot
.78461 .45872 Mdot
.75386 .46874 Mdot
.35349 .79154 Mdot
.289 .35825 Mdot
.18145 .60388 Mdot
.29738 .34702 Mdot
.64903 .45887 Mdot
.39193 .26529 Mdot
.67962 .39576 Mdot
.76804 .47834 Mdot
.65442 .39543 Mdot
.19975 .43937 Mdot
.27783 .75087 Mdot
.6321 .27322 Mdot
.72079 .47817 Mdot
.64571 .30471 Mdot
.2116 .65944 Mdot
.56671 .78155 Mdot
.25252 .36399 Mdot
.45014 .32634 Mdot
.86247 .58224 Mdot
.48628 .6683 Mdot
.75553 .50323 Mdot
.36709 .53014 Mdot
.62047 .73453 Mdot
.79453 .64551 Mdot
.30996 .3362 Mdot
.26859 .74411 Mdot
.30449 .48066 Mdot
.51502 .72885 Mdot
.33848 .51019 Mdot
.45344 .61261 Mdot
.6696 .31521 Mdot
.60746 .36339 Mdot
.68957 .37261 Mdot
.70666 .61028 Mdot
.55336 .29617 Mdot
.59007 .77118 Mdot
.31178 .62825 Mdot
.52009 .38313 Mdot
.32411 .6531 Mdot
.25667 .54515 Mdot
.41155 .48912 Mdot
.44796 .85465 Mdot
.56525 .35911 Mdot
.23879 .33567 Mdot
.23387 .68521 Mdot
.48483 .54366 Mdot
.54199 .73798 Mdot
.23497 .45929 Mdot
.7917 .68025 Mdot
.32735 .7964 Mdot
.33896 .75916 Mdot
.53461 .83298 Mdot
.14921 .55069 Mdot
.82898 .59379 Mdot
.49329 .33847 Mdot
.35228 .53658 Mdot
.10438 .57058 Mdot
.48765 .69184 Mdot
.71299 .32899 Mdot
.57988 .29405 Mdot
.61078 .6723 Mdot
.38016 .29943 Mdot
.4993 .40354 Mdot
.3233 .58834 Mdot
.43558 .34006 Mdot
.6388 .46899 Mdot
.62732 .82969 Mdot
.82654 .63793 Mdot
.64708 .81752 Mdot
.24529 .67716 Mdot
.52089 .83818 Mdot
.73608 .7111 Mdot
.51574 .18081 Mdot
.70911 .69995 Mdot
.55474 .39245 Mdot
.75591 .53578 Mdot
.22361 .36153 Mdot
.49446 .71924 Mdot
.20844 .54918 Mdot
.36216 .38513 Mdot
.80055 .65713 Mdot
.462 .86225 Mdot
.49254 .26876 Mdot
.57829 .22847 Mdot
.62427 .55093 Mdot
.76934 .49968 Mdot
.70433 .38754 Mdot
.25692 .62528 Mdot
.38774 .79483 Mdot
.74623 .70246 Mdot
.74344 .47991 Mdot
.36591 .65437 Mdot
.33835 .74989 Mdot
.2883 .30018 Mdot
.47943 .80243 Mdot
.74503 .67648 Mdot
.30326 .3232 Mdot
.4763 .37677 Mdot
.31539 .34524 Mdot
.24718 .60827 Mdot
.46172 .74716 Mdot
.74672 .44044 Mdot
.50921 .64982 Mdot
.74802 .51667 Mdot
.46552 .47622 Mdot
.71717 .69594 Mdot
.76117 .4065 Mdot
.74049 .51399 Mdot
.35571 .76245 Mdot
.59298 .83512 Mdot
.18875 .56788 Mdot
.8356 .48054 Mdot
.27998 .5835 Mdot
.60862 .49765 Mdot
.5672 .37804 Mdot
.24453 .71205 Mdot
.56864 .85223 Mdot
.2816 .76156 Mdot
.22611 .41785 Mdot
.63926 .70461 Mdot
.34659 .56076 Mdot
.77083 .38106 Mdot
.29579 .60537 Mdot
.39559 .80228 Mdot
.36974 .43802 Mdot
.41394 .61248 Mdot
.31235 .48118 Mdot
.70354 .33031 Mdot
.74556 .37747 Mdot
.54512 .23087 Mdot
.65192 .36552 Mdot
.46718 .21994 Mdot
.3609 .35056 Mdot
.23145 .40365 Mdot
.77306 .4877 Mdot
.48836 .66622 Mdot
.76076 .64655 Mdot
.69676 .38305 Mdot
.52865 .44968 Mdot
.47223 .74716 Mdot
.42848 .32576 Mdot
.62871 .29741 Mdot
.43626 .62558 Mdot
.38964 .84198 Mdot
.23248 .36629 Mdot
.70003 .35692 Mdot
.77103 .43892 Mdot
.71734 .67143 Mdot
.35221 .48059 Mdot
.42175 .56202 Mdot
.48383 .81791 Mdot
.59548 .58264 Mdot
.78051 .45173 Mdot
.47576 .2179 Mdot
.63447 .74861 Mdot
.58868 .47301 Mdot
.22452 .47366 Mdot
.57834 .19639 Mdot
.42394 .49699 Mdot
.42402 .40637 Mdot
.44945 .37001 Mdot
.2172 .31285 Mdot
.27503 .67818 Mdot
.27986 .34526 Mdot
.49163 .8118 Mdot
.39712 .5414 Mdot
.43133 .38347 Mdot
.73911 .52524 Mdot
.58153 .73185 Mdot
.6181 .23398 Mdot
.47488 .76018 Mdot
.71455 .40085 Mdot
.29157 .61545 Mdot
.53031 .8294 Mdot
.6467 .79258 Mdot
.55861 .15082 Mdot
.42471 .3355 Mdot
.58521 .76239 Mdot
.60864 .75388 Mdot
.40148 .31915 Mdot
.44586 .33866 Mdot
.5436 .51316 Mdot
.48957 .83956 Mdot
.40217 .45546 Mdot
.24649 .58928 Mdot
.49271 .53965 Mdot
.59649 .65176 Mdot
.66062 .72656 Mdot
.74008 .43734 Mdot
.4979 .80693 Mdot
.52589 .2257 Mdot
.82638 .55317 Mdot
.68929 .41689 Mdot
.68364 .28743 Mdot
.771 .38033 Mdot
.54237 .52727 Mdot
.35776 .26427 Mdot
.37016 .74718 Mdot
.58049 .40854 Mdot
.68014 .7987 Mdot
.35174 .78483 Mdot
.3642 .44793 Mdot
.42384 .63844 Mdot
.59414 .3857 Mdot
.63459 .38312 Mdot
.49634 .35958 Mdot
.2582 .49015 Mdot
.84534 .54321 Mdot
.70386 .51453 Mdot
.62158 .49726 Mdot
.4692 .21558 Mdot
.23995 .33487 Mdot
.53312 .78028 Mdot
.41856 .78959 Mdot
.45017 .47545 Mdot
.22432 .36363 Mdot
.43526 .51877 Mdot
.23604 .58701 Mdot
.29598 .64706 Mdot
.72745 .71706 Mdot
.52019 .47896 Mdot
.27474 .48245 Mdot
.6982 .69563 Mdot
.58588 .45857 Mdot
.26053 .43971 Mdot
.46364 .80222 Mdot
.70017 .2258 Mdot
.3134 .44672 Mdot
.60392 .84305 Mdot
.69026 .38411 Mdot
.28649 .48763 Mdot
.80753 .63544 Mdot
.78335 .29324 Mdot
.25135 .63265 Mdot
.72605 .74257 Mdot
.37651 .49562 Mdot
.49995 .81348 Mdot
.36535 .59131 Mdot
.46218 .44668 Mdot
.58867 .31066 Mdot
.48275 .83903 Mdot
.5485 .75244 Mdot
.52202 .795 Mdot
.49131 .35619 Mdot
.5228 .84394 Mdot
.42647 .42754 Mdot
.23759 .2951 Mdot
.52875 .70463 Mdot
.18487 .43721 Mdot
.46262 .32946 Mdot
.69928 .43741 Mdot
.75082 .49346 Mdot
.29422 .25642 Mdot
.46586 .18114 Mdot
.5081 .34104 Mdot
.73916 .56121 Mdot
.24108 .46798 Mdot
.76869 .43264 Mdot
.39605 .80748 Mdot
.22235 .32697 Mdot
.63513 .74111 Mdot
.25873 .38854 Mdot
.22662 .66157 Mdot
.25092 .49155 Mdot
.30324 .67784 Mdot
.51217 .77039 Mdot
.21752 .60777 Mdot
.71435 .41131 Mdot
.31436 .1846 Mdot
.50616 .60706 Mdot
.55108 .51571 Mdot
.77756 .68993 Mdot
.38328 .79371 Mdot
.35494 .4218 Mdot
.34674 .26016 Mdot
.71722 .30674 Mdot
.77532 .55468 Mdot
.59153 .45388 Mdot
.531 .84503 Mdot
.7761 .59155 Mdot
.69179 .77843 Mdot
.19509 .65309 Mdot
.47797 .22792 Mdot
.5265 .38859 Mdot
.46361 .6158 Mdot
.59102 .53233 Mdot
.73279 .56179 Mdot
.74224 .71645 Mdot
.70117 .30957 Mdot
.54468 .57786 Mdot
.34387 .69328 Mdot
.44533 .76666 Mdot
.5741 .50113 Mdot
.20875 .38331 Mdot
.25437 .47866 Mdot
.705 .49267 Mdot
.32374 .74026 Mdot
.76213 .49287 Mdot
.50468 .20746 Mdot
.76983 .39498 Mdot
.31556 .39632 Mdot
.35313 .60729 Mdot
.45695 .63469 Mdot
.67536 .75443 Mdot
.42756 .78083 Mdot
.19893 .44461 Mdot
.83355 .50491 Mdot
.28901 .47294 Mdot
.69998 .54367 Mdot
.62365 .76936 Mdot
.31926 .42886 Mdot
.43511 .67734 Mdot
.74222 .37055 Mdot
.67754 .28532 Mdot
.39091 .76185 Mdot
.53046 .36648 Mdot
.42768 .83744 Mdot
.74384 .44259 Mdot
.67755 .73668 Mdot
.60454 .55645 Mdot
.58075 .2782 Mdot
.43714 .26761 Mdot
.78391 .60775 Mdot
.44832 .51714 Mdot
.87547 .56023 Mdot
.36459 .31493 Mdot
.6905 .78852 Mdot
.36862 .55929 Mdot
.61144 .18453 Mdot
.3917 .77869 Mdot
.46142 .48917 Mdot
.49502 .52727 Mdot
.22235 .4768 Mdot
.29497 .52357 Mdot
.22007 .66021 Mdot
.31348 .33685 Mdot
.50765 .70781 Mdot
.56033 .59018 Mdot
.24913 .59525 Mdot
.63291 .78239 Mdot
.54114 .419 Mdot
.5346 .72424 Mdot
.55487 .53187 Mdot
.44297 .56438 Mdot
.24946 .71541 Mdot
.3745 .73896 Mdot
.6736 .43218 Mdot
.77151 .50123 Mdot
.75977 .69525 Mdot
.37173 .81274 Mdot
.3241 .37046 Mdot
.63515 .49272 Mdot
.38999 .52503 Mdot
.7914 .6293 Mdot
.57748 .81134 Mdot
.4212 .74951 Mdot
.33369 .50051 Mdot
.75317 .44883 Mdot
.68073 .81622 Mdot
.82432 .63911 Mdot
.83885 .50595 Mdot
.49667 .54622 Mdot
.4222 .41629 Mdot
.66206 .24993 Mdot
.67331 .74002 Mdot
.17579 .45969 Mdot
.34781 .77349 Mdot
.75697 .49791 Mdot
.74998 .27481 Mdot
.4298 .20182 Mdot
.58274 .62857 Mdot
.43886 .2691 Mdot
.60364 .2939 Mdot
.37796 .60246 Mdot
.76855 .56557 Mdot
.58198 .5945 Mdot
.43054 .59691 Mdot
.24351 .47019 Mdot
.30332 .52116 Mdot
.68166 .73324 Mdot
.60138 .21699 Mdot
.66106 .48062 Mdot
.59742 .79425 Mdot
.44672 .38315 Mdot
.64125 .73376 Mdot
.71729 .67394 Mdot
.58165 .60342 Mdot
.49055 .698 Mdot
.65964 .36399 Mdot
.38476 .48231 Mdot
.41129 .5 Mdot
.80855 .40567 Mdot
.69534 .58053 Mdot
.34839 .34751 Mdot
.39032 .21926 Mdot
.42965 .34411 Mdot
.54912 .85821 Mdot
.25804 .62636 Mdot
.45688 .21972 Mdot
.47725 .60212 Mdot
.37231 .67128 Mdot
.8074 .36964 Mdot
.70574 .33983 Mdot
.62604 .59328 Mdot
.44639 .40698 Mdot
.36653 .33785 Mdot
.477 .60656 Mdot
.21942 .55193 Mdot
.54948 .22217 Mdot
.23581 .33076 Mdot
.72452 .66911 Mdot
.39762 .31372 Mdot
.57937 .63331 Mdot
.64805 .33171 Mdot
.43525 .84782 Mdot
.49185 .70274 Mdot
.85552 .59589 Mdot
.55899 .36899 Mdot
.81622 .59899 Mdot
.25321 .72197 Mdot
.33897 .4647 Mdot
.50228 .55386 Mdot
.4069 .65366 Mdot
.55347 .45349 Mdot
.66516 .47977 Mdot
.39655 .33179 Mdot
.69795 .70765 Mdot
.67402 .60793 Mdot
.7993 .51143 Mdot
.41927 .5529 Mdot
.3086 .28119 Mdot
.21227 .3857 Mdot
.35989 .3656 Mdot
.5978 .59678 Mdot
.55645 .76487 Mdot
.49731 .48443 Mdot
.55258 .53154 Mdot
.6866 .75011 Mdot
.62128 .24259 Mdot
.38993 .31375 Mdot
.83616 .51204 Mdot
.68439 .55101 Mdot
.34628 .81614 Mdot
.60983 .33045 Mdot
.55753 .52773 Mdot
.50102 .48411 Mdot
.22607 .46537 Mdot
.52313 .20924 Mdot
.40988 .79335 Mdot
.7829 .46727 Mdot
.46784 .42823 Mdot
.74125 .5166 Mdot
.67785 .40938 Mdot
.33862 .69233 Mdot
.18726 .42018 Mdot
.76207 .28996 Mdot
.46687 .29692 Mdot
.3215 .47245 Mdot
.45184 .3786 Mdot
.23729 .3389 Mdot
.35553 .32221 Mdot
.58442 .67245 Mdot
.62079 .25305 Mdot
.39113 .77966 Mdot
.38916 .83377 Mdot
.35225 .79028 Mdot
.62104 .53204 Mdot
.43577 .76235 Mdot
.73462 .38401 Mdot
.61578 .32754 Mdot
.4699 .51077 Mdot
.55982 .45822 Mdot
.56057 .49588 Mdot
.33132 .40146 Mdot
.20451 .45074 Mdot
.51412 .44234 Mdot
.47277 .83318 Mdot
.34205 .81126 Mdot
.56469 .83478 Mdot
.45898 .74293 Mdot
.4061 .3971 Mdot
.80148 .66822 Mdot
.48848 .1964 Mdot
.38834 .80785 Mdot
.46678 .33152 Mdot
.20019 .33638 Mdot
.78534 .65837 Mdot
.36085 .74704 Mdot
.31074 .30425 Mdot
.19299 .52494 Mdot
.258 .72047 Mdot
.23617 .29717 Mdot
.71762 .4276 Mdot
.23745 .7007 Mdot
.88035 .54882 Mdot
.47668 .32764 Mdot
.29935 .51688 Mdot
.4262 .26169 Mdot
.72509 .37767 Mdot
.23563 .31998 Mdot
.55509 .38945 Mdot
.52767 .67664 Mdot
.60949 .63855 Mdot
.75785 .48719 Mdot
.62284 .3412 Mdot
.2438 .30766 Mdot
.72939 .56168 Mdot
.69538 .53662 Mdot
.59162 .75222 Mdot
.76457 .67514 Mdot
.53857 .2134 Mdot
.65749 .46972 Mdot
.38076 .4029 Mdot
.67197 .62698 Mdot
.7138 .46321 Mdot
.60335 .38174 Mdot
.46733 .55209 Mdot
.54994 .51097 Mdot
.62281 .83402 Mdot
.59017 .70175 Mdot
.55725 .68694 Mdot
.44424 .35421 Mdot
.24868 .48433 Mdot
.56114 .79095 Mdot
.27504 .43966 Mdot
.26491 .28625 Mdot
.65136 .26113 Mdot
.54081 .82612 Mdot
.30343 .4879 Mdot
.7322 .47524 Mdot
.78923 .37295 Mdot
.36999 .58948 Mdot
.5823 .30754 Mdot
.73258 .7205 Mdot
.27021 .45442 Mdot
.43151 .39613 Mdot
.32838 .72743 Mdot
.36037 .70878 Mdot
.26023 .4596 Mdot
.23245 .68227 Mdot
.60049 .76358 Mdot
.45815 .25059 Mdot
.63275 .79651 Mdot
.52105 .64883 Mdot
.7441 .48434 Mdot
.29677 .69724 Mdot
.22823 .32591 Mdot
.49353 .47294 Mdot
.44214 .83756 Mdot
.47303 .51411 Mdot
.7834 .59243 Mdot
.56853 .402 Mdot
.57022 .20784 Mdot
.21271 .45474 Mdot
.32152 .73327 Mdot
.28097 .35422 Mdot
.38811 .39579 Mdot
.21414 .40463 Mdot
.43689 .66622 Mdot
.77953 .57088 Mdot
.70686 .45726 Mdot
.36419 .28576 Mdot
.64548 .55435 Mdot
.2407 .51963 Mdot
.55876 .37207 Mdot
.80177 .56489 Mdot
.46468 .767 Mdot
.56081 .31722 Mdot
.49155 .33669 Mdot
.6742 .75668 Mdot
.48854 .7663 Mdot
.19243 .44984 Mdot
.48946 .34708 Mdot
.22588 .51052 Mdot
.45013 .19433 Mdot
.27355 .41275 Mdot
.63735 .3769 Mdot
.58493 .67045 Mdot
.43131 .363 Mdot
.63769 .78269 Mdot
.34523 .37465 Mdot
.76574 .6194 Mdot
.42561 .48036 Mdot
.54676 .77783 Mdot
.5895 .55783 Mdot
.25662 .72376 Mdot
.19253 .52558 Mdot
.77394 .48653 Mdot
.42409 .59062 Mdot
.36918 .49813 Mdot
.31103 .43759 Mdot
.44131 .82136 Mdot
.31385 .37117 Mdot
.68311 .33793 Mdot
.31459 .47565 Mdot
.62912 .28196 Mdot
.21067 .67285 Mdot
.78155 .51656 Mdot
.46748 .50966 Mdot
.70042 .36633 Mdot
.21993 .52281 Mdot
.26067 .53057 Mdot
.60583 .68313 Mdot
.52023 .19987 Mdot
.54392 .64441 Mdot
.53078 .57826 Mdot
.549 .38347 Mdot
.65156 .23978 Mdot
.6155 .79924 Mdot
.34948 .41267 Mdot
.46995 .49824 Mdot
.69185 .69704 Mdot
.78541 .57032 Mdot
.46386 .12561 Mdot
.67053 .80798 Mdot
.56792 .40155 Mdot
.50389 .53971 Mdot
.79541 .51579 Mdot
.48061 .63166 Mdot
.55811 .23077 Mdot
.66645 .76353 Mdot
.39834 .58937 Mdot
.63728 .7128 Mdot
.21971 .55979 Mdot
.21656 .47244 Mdot
.77873 .6179 Mdot
.34795 .57348 Mdot
.56716 .8592 Mdot
.33874 .7657 Mdot
.21788 .44628 Mdot
.39237 .13795 Mdot
.2147 .4244 Mdot
.40637 .42488 Mdot
.53795 .75855 Mdot
.58731 .83745 Mdot
.49243 .54452 Mdot
.61887 .73124 Mdot
.49715 .33391 Mdot
.77757 .47911 Mdot
.71458 .51572 Mdot
.25754 .38964 Mdot
.22651 .39184 Mdot
.247 .28372 Mdot
.37344 .67039 Mdot
.81889 .4138 Mdot
.51031 .22038 Mdot
.64518 .79751 Mdot
.25111 .62958 Mdot
.73765 .26266 Mdot
.37768 .82633 Mdot
.75098 .54307 Mdot
.25857 .29938 Mdot
.54059 .74802 Mdot
.80741 .49153 Mdot
.61215 .20851 Mdot
.23833 .63907 Mdot
.63635 .25294 Mdot
.35084 .66069 Mdot
.27715 .38379 Mdot
.74491 .51601 Mdot
.62043 .28769 Mdot
.46922 .51534 Mdot
.70717 .75033 Mdot
.30763 .25488 Mdot
.76786 .44402 Mdot
.6565 .70787 Mdot
.81499 .50306 Mdot
.58763 .8017 Mdot
.48385 .78846 Mdot
.5167 .52529 Mdot
.87414 .52505 Mdot
.73833 .73 Mdot
.28185 .42758 Mdot
.62738 .37688 Mdot
.36124 .82953 Mdot
.54584 .55196 Mdot
.50215 .33881 Mdot
.28112 .73365 Mdot
.69942 .51437 Mdot
.54123 .50167 Mdot
.61191 .36635 Mdot
.73221 .36015 Mdot
.34055 .29296 Mdot
.61949 .2905 Mdot
.71973 .65895 Mdot
.77289 .44289 Mdot
.31006 .25626 Mdot
.81049 .58039 Mdot
.57954 .33217 Mdot
.41543 .33513 Mdot
.6029 .83718 Mdot
.70154 .34437 Mdot
.69347 .42053 Mdot
.43338 .24481 Mdot
.31373 .36049 Mdot
.3558 .62044 Mdot
.61802 .496 Mdot
.35518 .47967 Mdot
.7515 .49068 Mdot
.65862 .74976 Mdot
.58469 .31363 Mdot
.90501 .50254 Mdot
.25567 .7275 Mdot
.37485 .3078 Mdot
.52971 .32112 Mdot
.58534 .61276 Mdot
.57323 .82975 Mdot
.35704 .65046 Mdot
.71737 .67221 Mdot
.37719 .21774 Mdot
.79359 .46485 Mdot
.63179 .45994 Mdot
.2463 .68083 Mdot
.39991 .82877 Mdot
.33094 .23092 Mdot
.4277 .83684 Mdot
.51739 .40423 Mdot
.52854 .41669 Mdot
.69108 .19338 Mdot
.51357 .82111 Mdot
.55404 .35894 Mdot
.32126 .30055 Mdot
.39026 .29597 Mdot
.54871 .41801 Mdot
.2403 .56314 Mdot
.73923 .42296 Mdot
.71034 .52383 Mdot
.487 .83835 Mdot
.44541 .36505 Mdot
.48557 .55155 Mdot
.3525 .54056 Mdot
.48486 .52423 Mdot
.67444 .43826 Mdot
.4132 .56159 Mdot
.70968 .53241 Mdot
.54033 .55558 Mdot
.31099 .56585 Mdot
.71398 .42338 Mdot
.20596 .57692 Mdot
.68924 .46709 Mdot
.62111 .53664 Mdot
.47739 .36608 Mdot
.46593 .18063 Mdot
.73019 .56071 Mdot
.73249 .57872 Mdot
.2356 .69518 Mdot
.14766 .51113 Mdot
.48369 .58355 Mdot
.51292 .36163 Mdot
.47788 .3961 Mdot
.50838 .20199 Mdot
.44593 .24832 Mdot
.32592 .56951 Mdot
.25895 .53516 Mdot
.51409 .42396 Mdot
.69969 .35699 Mdot
.36651 .53806 Mdot
.65057 .83076 Mdot
.5802 .37592 Mdot
.50193 .23948 Mdot
.42571 .81398 Mdot
.64903 .7299 Mdot
.6243 .51218 Mdot
.55924 .45923 Mdot
.41044 .43492 Mdot
.54787 .55857 Mdot
.66295 .33271 Mdot
.67225 .72029 Mdot
.58837 .81803 Mdot
.64667 .51415 Mdot
.48755 .23565 Mdot
.59057 .42014 Mdot
.65851 .63007 Mdot
.3761 .47455 Mdot
.80695 .42271 Mdot
.63378 .59093 Mdot
.3708 .80869 Mdot
.6732 .54252 Mdot
.70364 .51393 Mdot
.40628 .24623 Mdot
.68546 .78584 Mdot
.30939 .44781 Mdot
.47037 .22653 Mdot
.34557 .42641 Mdot
.31388 .69369 Mdot
.73829 .55875 Mdot
.48888 .61699 Mdot
.51943 .45051 Mdot
.39053 .29441 Mdot
.48695 .85256 Mdot
.70457 .33798 Mdot
.32913 .56188 Mdot
.39418 .76553 Mdot
.45106 .19658 Mdot
.49442 .52464 Mdot
.34801 .16211 Mdot
.36547 .64504 Mdot
.57341 .85701 Mdot
.63747 .75293 Mdot
.48682 .42383 Mdot
.24135 .46469 Mdot
.64572 .35465 Mdot
.47402 .64831 Mdot
.57969 .82522 Mdot
.66204 .34199 Mdot
.26881 .4038 Mdot
.56797 .38457 Mdot
.40402 .44451 Mdot
.68342 .34584 Mdot
.42125 .759 Mdot
.52513 .69116 Mdot
.3207 .3662 Mdot
.48474 .79383 Mdot
.55094 .55963 Mdot
.18272 .36952 Mdot
.74316 .7165 Mdot
.48102 .81878 Mdot
.45249 .76518 Mdot
.61029 .17978 Mdot
.44227 .40846 Mdot
.62246 .32698 Mdot
.41422 .60355 Mdot
.73472 .37383 Mdot
.26343 .45556 Mdot
.66317 .74357 Mdot
.22574 .50782 Mdot
.50167 .49665 Mdot
.25666 .22459 Mdot
.74511 .53552 Mdot
.36382 .42271 Mdot
.24981 .43812 Mdot
.46073 .8295 Mdot
.67179 .6786 Mdot
.17919 .58866 Mdot
.25981 .6532 Mdot
.67502 .42586 Mdot
.58683 .20215 Mdot
.82545 .54113 Mdot
.40053 .73239 Mdot
.81617 .39622 Mdot
.4359 .77918 Mdot
.72309 .4593 Mdot
.31372 .7248 Mdot
.42542 .33752 Mdot
.37341 .30148 Mdot
.25701 .61394 Mdot
.21249 .56437 Mdot
.51675 .35168 Mdot
.56283 .81552 Mdot
.7559 .31607 Mdot
.7155 .68187 Mdot
.53816 .83577 Mdot
.36554 .51562 Mdot
.45729 .36487 Mdot
.72337 .55801 Mdot
.66986 .56065 Mdot
.48735 .63041 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`2Cooooo`;o00003_ooool2o`000:Cooooo000Loooo
o`03o`000?oooooooooo09?ooooo0_l0000>ooooo`;o0000Y?ooool001cooooo00?o0000oooooooo
ool0V?ooool2o`0000Cooooo0_l0002Yooooo`007?ooool00ol0003oooooooooo`22ooooo`;o0000
5?ooool2o`0000Cooooo0_l0002Yooooo`007?ooool00ol0003oooooooooo`1looooo`;o00000_oo
ool4o`0001Gooooo0_l00003ooooo`;o00001Oooool2o`000:;ooooo000Looooo`03o`000?oooooo
oooo07cooooo0_l00002ooooo`;o00005oooool2o`0000?ooooo0_l00005ooooo`;o00003_ooool2
o`0009;ooooo000Looooo`03o`000?oooooooooo0;Gooooo0_l0002Booooo`007?ooool00ol0003o
ooooooooo`2Sooooo`;o00001?ooool2o`0009kooooo000Looooo`03o`000?oooooooooo09oooooo
0_l00002ooooo`;o00001?ooool2o`0001Cooooo0_l00028ooooo`007?ooool2o`0009Oooooo0_l0
0003ooooo`?o000000?oooooo`000?l000003Oooool2o`0000;ooooo1?l00009ooooo`;o0000R?oo
ool001cooooo00?o0000ooooooooool0SOooool2o`0000Oooooo0_l00003ooooo`?o00004?ooool2
o`0000;ooooo1_l0002Aooooo`007?ooool00ol0003oooooooooo`2<ooooo`?o00009oooool4o`00
08oooooo000Looooo`03o`000?oooooooooo06gooooo0_l0000Cooooo`;o00002?ooool2o`0001Oo
oooo0_l0000Aooooo`;o0000Soooool001cooooo00?o0000ooooooooool0KOooool2o`0001?ooooo
0_l0000Qooooo`;o00007?ooool2o`0008Cooooo000Looooo`03o`000?oooooooooo07kooooo0_l0
0013ooooo`;o0000Q?ooool001cooooo00?o0000ooooooooool0O_ooool2o`000<Wooooo000Loooo
o`03o`000?oooooooooo06Sooooo0_l0000Sooooo`;o00002?ooool2o`0000;ooooo0_l0002/oooo
o`007?ooool00ol0003oooooooooo`1Xooooo`;o00003?ooool3o`0001Cooooo0_l00006ooooo`Co
00000_ooool2o`0002Wooooo0_l00021ooooo`007?ooool00ol0003oooooooooo`1fooooo`?o0000
6?ooool2o`000004ooooool0003o0000o`0000gooooo0_l00005ooooo`;o00005Oooool2o`0000;o
oooo0_l00021ooooo`007?ooool00ol0003oooooooooo`1Rooooo`;o0000;Oooool2o`000003oooo
ool0003o000000kooooo1_l000000ooooooo0000o`00000Eooooo`?o00002oooool2o`0007Oooooo
000Looooo`03o`000?oooooooooo05cooooo0_l00004ooooo`;o00009Oooool2o`0000oooooo0_l0
0008ooooo`Ko000000?oooooo`000?l000005_ooool2o`0000_ooooo0_l0001gooooo`007?ooool0
0ol0003oooooooooo`1Looooo`;o0000:oooool2o`0000oooooo0_l00008ooooo`;o00001Oooool2
o`0000_ooooo0_l0002?ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?oo
ool5o`0000Kooooo00?o0000ooooooooool0WOooool2o`0001Wooooo1?l0000Qooooo`;o0000J_oo
ool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A006ooooo`03o`000?oooooooooo087ooooo0_l000000ooooooo0000o`000008ooooo`?o
00000_ooool2o`0000Kooooo1?l0000Iooooo`Co00008Oooool2o`0006[ooooo00000ooooooo410@
ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003ooooo
ooooo`21ooooo`Go00002?ooool3o`0000;ooooo0_l00006ooooo`;o00000_ooool2o`0000Cooooo
0_l0000Aooooo`;o00003oooool2o`0007kooooo00000ooooooo0000ooooo`02ooooo`03o`000?oo
oooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0008;ooooo0_l00004ooooo`;o00001?oo
ool2o`0000?ooooo0_l0000:ooooo`Co00000_ooool2o`0000cooooo0_l00006ooooo`;o00003?oo
ool2o`0007kooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oMgMg
ofIVI_ooool01Oooool00ol0003oooooooooo`26ooooo`Co00005_ooool3o`0000Oooooo0_l00007
ooooo`;o00001_ooool2o`0008cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo
00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`26ooooo`Co00001oooool4o`00
00Wooooo1?l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00004ooooo`;o000000?ooooo
o`000?l000000_l0000<ooooo`;o00003_ooool2o`0007Cooooo00001_ooooooMgMgoiRHV?oooooo
V9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo083ooooo
0_l00006ooooo`;o00001oooool4o`0000?ooooo1?l00002ooooo`Co000000Coooooo`000?l0003o
oooo0_l00006ooooo`Co00000oooool2o`000003ooooool0003o000000Wooooo0_l0000>ooooo`;o
0000M?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0E?ooool4o`0002Oooooo0ol0000@ooooo`?o00000oooool4
o`0000oooooo0_l000000ooooooo0000o`000008ooooo`?o00002_ooool2o`0008;ooooo000Loooo
o`03o`000?oooooooooo05Cooooo1?l0000Oooooo`;o00001_ooool2o`0001Cooooo1Ol00006oooo
o`;o00001?ooool4o`000003ooooool0003o000000cooooo1?l00003ooooo`;o00000oooool2o`00
0003ooooool0003o000007oooooo000Looooo`03o`000?oooooooooo07Oooooo0_l00002ooooo`;o
00001_ooool4o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l000000ol00007ooooo`Co
00000_ooool4o`000003ooooool0003o000000Kooooo0_l00006ooooo`;o00000oooool2o`0000Ko
oooo0ol0001nooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00008_ooool3o`0000Cooooo
0_l00005ooooo`Go00000oooool3o`0000?ooooo0ol000000ooooooo0000o`00000<ooooo`;o0000
2oooool2o`0000;ooooo0_l0000Dooooo`;o0000O_ooool001cooooo00?o0000ooooooooool0D?oo
ool2o`0002;ooooo0ol000001?oooooo0000o`000?ooool2o`0000Gooooo0_l00003ooooo`;o0000
00?oooooo`000?l000001?ooool2o`0000?ooooo0_l0000@ooooo`;o00001_ooool2o`0001;ooooo
0_l0000Kooooo`;o0000Ioooool001cooooo00?o0000ooooooooool0K?ooool2o`0000?ooooo0_l0
0005ooooo`;o00001_ooool2o`0000Gooooo0_l00002ooooo`;o00002?ooool2o`000003ooooool0
003o000000gooooo0_l00009ooooo`;o00001?ooool2o`0000Wooooo0_l00007ooooo`;o00004_oo
ool2o`000003ooooool0003o000006Cooooo000Looooo`03o`000?oooooooooo06Sooooo0_l00002
ooooo`;o00000oooool2o`0000?ooooo0_l00008ooooo`;o00000_ooool2o`0000;ooooo0_l00000
0ooooooo0000o`00000;ooooo`;o00001?ooool2o`0000gooooo0_l00003ooooo`;o00001?ooool2
o`0000Wooooo0_l00007ooooo`;o00005Oooool3o`0006?ooooo000Looooo`03o`000?oooooooooo
06Sooooo0_l00003ooooo`;o00001oooool2o`0000cooooo1_l000000ooooooo0000o`00000<oooo
o`Co000000?oooooo`000?l000003Oooool2o`0001Kooooo0_l00004ooooo`;o00005oooool2o`00
06?ooooo000Looooo`03o`000?oooooooooo06gooooo0_l00009ooooo`?o00002Oooool6o`000003
ooooool0003o000000cooooo1?l00002ooooo`;o00006_ooool2o`0000Sooooo0_l00004ooooo`;o
00000oooool2o`0001Oooooo0_l0001Nooooo`007?ooool00ol0003oooooooooo`1]ooooo`;o0000
0oooool2o`0000Cooooo0ol00009ooooo`;o00000_ooool2o`0000[ooooo0_l00009ooooo`;o0000
6_ooool2o`0000Wooooo0_l00003ooooo`;o00000oooool2o`0001Oooooo0_l0001Nooooo`007?oo
ool00ol0003oooooooooo`1Uooooo`?o00001Oooool2o`0000?ooooo0_l0000<ooooo`;o00001ooo
ool2o`0000Wooooo0_l0000`ooooo`;o00000oooool4o`0000?ooooo0_l0001eooooo`007?ooool0
0ol0003oooooooooo`1Uooooo`Co00004?ooool2o`0000Gooooo0_l00007ooooo`;o00000_ooool2
o`0003Gooooo0_l00007ooooo`;o00000oooool2o`0007Gooooo000Looooo`;o0000J?ooool2o`00
00Gooooo0_l00009ooooo`;o00001Oooool3o`000003ooooool0003o000000Oooooo0_l00002oooo
o`;o0000<Oooool2o`0000gooooo0_l0001dooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o
00003?ooool2o`0000Oooooo0_l00008ooooo`;o000000?oooooo`000?l000002oooool2o`0003?o
oooo0_l00003ooooo`;o00001_ooool2o`0007Cooooo000Looooo`03o`000?oooooooooo05cooooo
0_l00002ooooo`?o00005?ooool2o`0000Oooooo0_l00014ooooo`;o00000oooool2o`0000Cooooo
0ol0001eooooo`007?ooool00ol0003oooooooooo`1Looooo`;o00000oooool2o`0000[ooooo0_l0
0008ooooo`;o000000Coooooo`000?l0003o00000oooool2o`0001[ooooo0_l0000booooo`Co0000
MOooool001cooooo00?o0000ooooooooool0GOooool2o`0000kooooo1Ol00008ooooo`?o00002_oo
ool2o`0001?ooooo0_l0000booooo`Co00000_ooool2o`0001Cooooo0_l0001Kooooo`007?ooool0
0ol0003oooooooooo`1Iooooo`;o00000_ooool2o`000003ooooool0003o000000gooooo0ol00002
ooooo`;o00001_ooool2o`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l000002Oooool2
o`0000Kooooo0_l0000cooooo`Ko00005?ooool2o`0005_ooooo000Looooo`03o`000?oooooooooo
05Wooooo0_l00005ooooo`;o00004_ooool2o`0000Kooooo0_l00003ooooo`;o00000oooool2o`00
00;ooooo0ol00008ooooo`;o00001Oooool3o`0003Gooooo1?l0001aooooo`007?ooool00ol0003o
ooooooooo`0oooooo`;o00007_ooool2o`00023ooooo0_l00003ooooo`;o00000oooool2o`0000oo
oooo0_l0000/ooooo`;o00001oooool2o`000003ooooool0003o000000;ooooo0_l0001]ooooo`00
7?ooool00ol0003oooooooooo`0oooooo`;o00007?ooool4o`0000[ooooo0_l0000>ooooo`;o0000
COooool2o`0000Oooooo0_l00003ooooo`Co00005?ooool2o`0005Oooooo000Looooo`03o`000?oo
oooooooo05gooooo1?l0000:ooooo`;o00003_ooool2o`0003cooooo0ol00009ooooo`?o00001_oo
ool2o`0000Sooooo0_l0000Fooooo`;o0000Eoooool001cooooo00?o0000ooooooooool0D_ooool2
o`0000Sooooo0_l000000ooooooo0000o`000002o`0002[ooooo0_l00002ooooo`;o00009_ooool3
o`0000Wooooo0ol000001?oooooo0000o`000?ooool4o`0007Wooooo000Looooo`03o`000?oooooo
oooo04gooooo0_l00003ooooo`;o00000oooool2o`0000?ooooo0_l00003ooooo`?o00003oooool2
o`0000gooooo0_l00009ooooo`;o00000_ooool4o`0000Oooooo0_l0000[ooooo`;o000000?ooooo
o`000?l000000_ooool2o`0000Cooooo1?l00005ooooo`;o00004Oooool2o`0005Gooooo000Loooo
o`03o`000?oooooooooo04gooooo0_l00003ooooo`;o00000oooool2o`0000Wooooo0_l00007oooo
o`;o00001_ooool2o`0000gooooo0_l0000?ooooo`;o00001oooool2o`0002Sooooo0_l000000ooo
oooo0000o`000005ooooo`;o00001?ooool6o`0000?ooooo1?l0000?ooooo`;o0000EOooool001co
oooo00?o0000ooooooooool0Doooool2o`0001Cooooo1?l0000Booooo`;o00001?ooool2o`0000go
oooo0_l0000Yooooo`;o00001?ooool3o`0000oooooo0_l000000ooooooo0000o`000005ooooo`;o
00004Oooool2o`0005?ooooo000Looooo`03o`000?oooooooooo04Wooooo0_l00004ooooo`;o0000
0_ooool2o`0001?ooooo1ol0000<ooooo`;o00000_ooool2o`0000Cooooo0_l0000:ooooo`;o0000
00?oooooo`000?l000001Oooool2o`0001_ooooo0ol00002ooooo`Go00000_ooool3o`0001_ooooo
0_l0000@ooooo`;o00001Oooool2o`0004cooooo000Looooo`03o`000?oooooooooo04Wooooo0_l0
0004ooooo`;o00004Oooool2o`0000Cooooo2?l00003ooooo`;o00001_ooool2o`0000Cooooo0_l0
000>ooooo`;o000000?oooooo`000?l000001Oooool2o`0001?ooooo0_l00006ooooo`?o00000_oo
ool2o`000005ooooool0003o0000o`000?ooool00ol000000ooooooo0000o`000002o`0001Kooooo
0_l0000Gooooo`;o0000C?ooool001cooooo0_l0001:ooooo`;o00001Oooool2o`0000Sooooo0_l0
0005ooooo`?o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l00003ooooo`Oo000000?o
ooooo`000?l000001?ooool3o`00013ooooo0_l00003ooooo`;o00005Oooool2o`0000Kooooo0_l0
0003ooooo`;o00000_ooool2o`0000Gooooo1?l0000Hooooo`;o0000Hoooool001cooooo00?o0000
ooooooooool0D?ooool2o`0000Sooooo0_l00005ooooo`;o00000_ooool6o`0000Sooooo1ol00005
ooooo`;o000000?oooooo`000?l000005Oooool2o`0001gooooo0_l0000?ooooo`Co000000?ooooo
o`000?l000005?ooool2o`0006?ooooo000Looooo`03o`000?oooooooooo04_ooooo0_l0000Doooo
o`;o00001?ooool4o`0000Sooooo1_l00006ooooo`;o00001_ooool3o`0002kooooo0ol0000;oooo
o`;o00000_ooool3o`000003ooooool0003o000000;o00004oooool2o`0006;ooooo000Looooo`03
o`000?oooooooooo04_ooooo0_l0000Dooooo`;o00001_ooool2o`0000;ooooo0_l00006ooooo`Co
00000oooool4o`0000?ooooo0_l00002ooooo`?o00009?ooool4o`0000Kooooo1Ol00009ooooo`;o
000000?oooooo`000?l000001Oooool2o`0000kooooo0_l00003ooooo`;o0000H_ooool001cooooo
00?o0000ooooooooool0@oooool2o`0001cooooo0_l00004ooooo`;o00001?ooool2o`000003oooo
ool0003o000000?ooooo1?l000000ooooooo0000o`000006o`000003ooooool0003o000000;o0000
9oooool4o`0000Kooooo1Ol00005ooooo`;o00001Oooool2o`00013ooooo0_l00003ooooo`;o0000
Ioooool001cooooo00?o0000ooooooooool0@oooool2o`0001;ooooo0_l00006ooooo`;o00001_oo
ool2o`0000Oooooo0_l000000ooooooo0000o`00000:o`000003ooooool0003o000000?ooooo0_l0
0005ooooo`;o00009?ooool2o`0000Kooooo0_l00006ooooo`;o00004_ooool2o`0000?ooooo0_l0
000Eooooo`;o0000EOooool001cooooo00?o0000ooooooooool0BOooool2o`0000cooooo0_l00006
ooooo`;o00002Oooool2o`0000Oooooo4?l00009ooooo`;o00003?ooool2o`0001Gooooo0ol00009
ooooo`;o00005oooool2o`00013ooooo0_l00008ooooo`?o0000E?ooool001cooooo00?o0000oooo
ooooool0BOooool2o`0001Cooooo0_l00009ooooo`;o00000oooool3o`000003ooooool0003o0000
00oo00001?ooool2o`00013ooooo0_l00004ooooo`;o000000?oooooo`000?l000000oooool2o`00
0003ooooool0003o000000Cooooo0ol00009ooooo`;o0000:Oooool2o`0000Wooooo0_l0001Doooo
o`007?ooool00ol0003oooooooooo`16ooooo`;o00005oooool2o`0000gooooo2?l000000ooooooo
0000o`00000<o`0000;ooooo0ol00004ooooo`;o00004?ooool2o`000003ooooool0003o000000?o
oooo0_l000000ooooooo0000o`000003ooooo`;o00001oooool2o`0003Wooooo0_l00005ooooo`;o
0000C?ooool001cooooo00?o0000ooooooooool0AOooool3o`0001Wooooo0_l0000;oooooago0000
0oooool2o`0000Oooooo0_l0000Gooooo`Co00000_ooool2o`000003ooooool0003o000000Wooooo
1?l0000Looooo`;o00001?ooool2o`0000Sooooo0_l00005ooooo`;o0000C?ooool001cooooo00?o
0000ooooooooool0AOooool2o`0000;ooooo0ol0000Eooooo`;o00003?ooool4o`000003ooooool0
003o000000ko000000Goooooo`000?l0003o0000ooooo`02o`0000Sooooo0ol000000ooooooo0000
o`00000?ooooo`;o00000oooool2o`0000?ooooo0_l00002ooooo`Co00001oooool7o`0000Kooooo
0ol0000@ooooo`Go00001?ooool2o`0000Sooooo0_l00006ooooo`;o0000Boooool001cooooo00?o
0000ooooooooool0<?ooool2o`0001Kooooo1?l0000=ooooo`;o00005?ooool2o`000004ooooool0
003o0000oooooa?o00002oooool3o`0000Sooooo0_l00008ooooo`;o00000oooool2o`0000Sooooo
0ol00007ooooo`Co00000oooool2o`0000Cooooo0ol00003ooooo`;o00002oooool4o`0000Kooooo
0_l0000?ooooo`;o00000oooool2o`0004Kooooo000Looooo`03o`000?oooooooooo033ooooo0_l0
000;ooooo`;o00001?ooool2o`0000?ooooo1?l0000:ooooo`;o000000?oooooo`000?l000000_l0
0004ooooo`?o00003Oooool?o`000003ooooool0003o000000Go00001Oooool2o`0000gooooo1?l0
000Tooooo`;o00000_ooool2o`0000[ooooo0_l00004ooooo`;o00000oooool4o`0000Sooooo0_l0
000@ooooo`;o00000_ooool2o`0004Kooooo000Looooo`03o`000?oooooooooo03gooooo0_l00004
ooooo`;o00001?ooool3o`0000[ooooo0_l000000ooooooo0000o`000002o`0000Cooooo0ol0000:
oooooa[o000000Goooooo`000?l0003o0000ooooo`02o`0000gooooo0_l000000ooooooo0000o`00
0002o`000003ooooool0003o000000Cooooo0_l0000Hooooo`;o000000?oooooo`000?l000002?oo
ool2o`0000Oooooo0_l00003ooooo`Co00002_ooool2o`0000kooooo0_l0001:ooooo`007?ooool0
0ol0003oooooooooo`19ooooo`;o00003_ooool2o`0001?ooooo8?l000000ooooooo0000o`000002
ooooo`;o00002?ooool6o`000003ooooool0003o000000?ooooo0ol0000;ooooo`;o00001_ooool2
o`0000Cooooo1?l00008ooooo`Co00001Oooool2o`0000Cooooo0ol0000:ooooo`;o00002Oooool2
o`0004oooooo000Looooo`03o`000?oooooooooo05Oooooo0_l00004ooooo`;o00001?ooool2o`00
00Gooooo0_l000001?oooooo0000o`000?l00003oooooaOo00000_ooool2o`000003ooooool0003o
000000;ooooo0_l00005ooooo`Go00002_ooool2o`0000[ooooo1?l00002ooooo`;o000000Gooooo
o`000?l0003o0000ooooo`02o`000003ooooool0003o000000;o00002?ooool4o`0000Cooooo0ol0
0004ooooo`Co00005?ooool2o`0004oooooo000Looooo`;o0000D?ooool2o`0000Kooooo0_l00004
ooooo`;o00001?ooool2o`0000Gooooo1_l000000ooooooo0000o`000005o`000003ooooool0003o
0000017o00001Oooool2o`000004ooooool0003o0000o`0000?ooooo0ol0000Hooooo`?o00000ooo
ool5o`0000;ooooo0_l0000=ooooo`;o00000_ooool2o`0000;ooooo0ol00006ooooo`;o0000IOoo
ool001cooooo00?o0000ooooooooool0Coooool2o`0000Kooooo0_l0000:ooooo`;o00001oooool4
o`000003ooooool0003o000000Go000000?oooooo`000?l000003?l00003ooooo`Go00000_ooool2
o`000004ooooool0003o0000o`0000Sooooo0_l00003ooooo`;o00004?ooool2o`0000Gooooo1?l0
0008ooooo`Go000000?oooooo`000?l000001?ooool2o`0002Wooooo0_l00017ooooo`007?ooool0
0ol0003oooooooooo`1@ooooo`;o00001?ooool4o`000003ooooool0003o000000[ooooo0_l00005
ooooo`;o00000_oooolMo`0000gooooo0_l000000ooooooo0000o`000003ooooo`;o00000oooool2
o`0001;ooooo1?l00007ooooo`Wo00003_ooool3o`0000Oooooo0_l00002ooooo`?o00000oooool2
o`0000_ooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`0Zooooo`;o00007oooool2o`00
00?ooooo0_l000001?oooooo0000o`000?ooool7o`0000[ooooo0_l00005ooooo`?o00000_oooolH
o`0000;ooooo0_l00002ooooo`;o00002Oooool3o`0000[ooooo0_l00005ooooo`;o00000_ooool2
o`0000;ooooo0_l00003ooooo`;o00000oooool4o`0000;ooooo0_l000001?oooooo0000o`000?oo
ool2o`0000oooooo0ol00007ooooo`?o000000Coooooo`000?l0003o00000oooool2o`0005Cooooo
000Looooo`03o`000?oooooooooo02[ooooo0_l0000Iooooo`;o00001?ooool2o`0000Kooooo0_l0
0005ooooo`;o00001_ooool2o`0000Cooooo0ol00002ooooo`Co000000?oooooo`000?l000006Ol0
0003ooooo`Co00002Oooool2o`0000Cooooo0_l00007ooooo`Ko00000_ooool2o`0000;ooooo0_l0
00000ooooooo0000o`000005ooooo`Ko00000oooool2o`000003ooooool0003o000000?ooooo0_l0
0009ooooo`;o00002_ooool2o`0000;ooooo0_l00009ooooo`;o0000C_ooool001cooooo00?o0000
ooooooooool0AOooool2o`000003ooooool0003o000000Cooooo0_l00003ooooo`;o00003Oooool4
o`0000;ooooo0ol000000ooooooo0000o`00000:o`000003ooooool0003o000001Co000000?ooooo
o`000?l000000_l00003ooooo`;o00002_ooool2o`0000Oooooo1?l00003ooooo`;o00000_ooool2
o`0000;ooooo0_l00004ooooo`Wo00001Oooool6o`0000Sooooo1Ol0000<ooooo`;o00002Oooool2
o`0004kooooo000Looooo`03o`000?oooooooooo04?ooooo1?l000000ooooooo0000o`000004oooo
o`;o00003?ooool2o`0000Kooooo0_l00006ooooo`;o000000?oooooo`000?l000001ol000000ooo
oooo0000o`00000Ho`0000Cooooo0_l0000@ooooo`Oo00000_ooool3o`0000;ooooo0_l00002oooo
o`;o000000Coooooo`000?l0003ooooo2Ol000000ooooooo0000o`000002ooooo`Go00002Oooool2
o`000003ooooool0003o000000cooooo0ol00008ooooo`;o0000C_ooool001cooooo00?o0000oooo
ooooool0>?ooool2o`0000Wooooo1?l00008ooooo`;o00002oooool2o`0000Cooooo0_l00002oooo
o`;o00001ooooolMo`0000;ooooo0ol00006ooooo`Ko00003?ooool5o`000004ooooool0003o0000
ooooo`?o00001oooool:o`0000;ooooo1Ol00006ooooo`;o00001?ooool2o`0001;ooooo1?l0000A
ooooo`;o0000AOooool001cooooo00?o0000ooooooooool0>?ooool2o`0000_ooooo0_l00008oooo
o`;o00003Oooool2o`0000;ooooo0_l00002ooooo`;o00001?ooool2o`0000?ooooo7?l000000ooo
oooo0000o`000009ooooo`Co00003oooool2o`000004ooooool0003o0000ooooo`;o000000?ooooo
o`000?l000000_ooool9o`000003ooooool0003o000000;o000000?oooooo`000?l000000ol00000
1Ooooooo0000o`000?l0003ooooo00?o00001?ooool2o`000003ooooool0003o000000Sooooo0_l0
0002ooooo`So000000?oooooo`000?l000001oooool3o`0000?ooooo0_l00015ooooo`007?ooool0
0ol0003oooooooooo`1@ooooo`?o000000?oooooo`000?l000002?ooool2o`0000cooooo0_l00002
ooooob7o00001_ooool2o`0001_ooooo0ol00002oooooaSo000000?oooooo`000?l000000ol00005
ooooo`;o00002?ooool7o`000003ooooool0003o000000Go00001oooool3o`0004[ooooo000Loooo
o`03o`000?oooooooooo02Kooooo0_l0000Xooooo`?o000000?oooooo`000?l000006Oooool3o`00
0003ooooool0003o000001co00000oooool2o`000004ooooool0003o0000o`00017ooooo0_l00003
ooooo`;o000000?oooooo`000?l000006Ol00004ooooo`Go00001Oooool4o`0000Sooooo0_l00002
ooooo`Co000000?oooooo`000?l000001?ooool2o`00053ooooo000Looooo`03o`000?oooooooooo
02Kooooo0_l0000Hooooo`;o00003_ooool2o`0000Cooooo0_l0000<ooooo`?o00001?ooool2o`00
00;ooooo0_l00002oooooago00001?ooool2o`0000;ooooo0_l0000;ooooo`;o00001?ooool2o`00
0003ooooool0003o000001ko00001?ooool5o`0000Gooooo1Ol0000:ooooo`?o00002?ooool3o`00
00Sooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`10ooooo`?o00003Oooool2o`0000Co
oooo0_l0000;ooooo`Co00001?ooool2o`0000Gooooo7_l00002ooooo`;o00004Oooool2o`0000Oo
oooo8?l000000ooooooo0000o`000002o`000003ooooool0003o000000Co00000_ooool2o`000003
ooooool0003o000000;o00002?ooool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo
0000o`000009ooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0@Oooool2o`0000?ooooo
0_l00008ooooo`;o00004Oooool2o`0000Wooooo0_l00002ooooo`Ko00000oooool<o`000005oooo
ool0003o0000o`000?ooool00ol00003ooooo`;o00003oooool2o`0000;ooooo0ol00004ooooo`;o
000000?oooooo`000?l000006ol000000ooooooo0000o`000002o`0000?ooooo1?l00007ooooo`;o
00002oooool2o`0000?ooooo0_l0000<ooooo`;o0000A_ooool00006ooooooo^k^ko<S8bo`000?lb
<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo
04Kooooo0_l00008ooooo`;o00007?ooool4o`0000;ooooo0_l00002oooooaOo00002_ooool2o`00
00Sooooo0_l00002ooooo`?o00000_oooolRo`000004ooooool0003o0000o`0000Cooooo0ol00003
ooooo`;o00004?ooool2o`000003ooooool0003o000000kooooo0_l00016ooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo04Kooooo0ol0000=ooooo`;o00002oooool2o`0000_ooooo0_l00003oooooaGo000000?o
ooooo`000?l000002_ooool4o`0000cooooo0ol00002oooooa7o000000?oooooo`000?l000004ol0
0004ooooo`Co000000?oooooo`000?l000002_ooool2o`0000Cooooo0_l000000ooooooo0000o`00
0003ooooo`;o000000?oooooo`000?l000002_ooool2o`0004;ooooo00000ooooooo410@ooooo`02
ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006ooooo`03o`000?oooooooooo02?ooooo0_l0000G
ooooo`;o00002Oooool2o`0000gooooo0_l0000;ooooo`;o00002oooool2o`0000?ooooo1?l00000
0ooooooo0000o`000009o`0000;ooooo0ol000000ooooooo0000o`00000:ooooo`;o00003Oooool2
o`0000?ooooo:Ol00005ooooo`;o00003Oooool2o`0000Oooooo0_l00002ooooo`?o000000?ooooo
o`000?l000002_ooool2o`0004;ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`0002?ooooo0_l0000Eooooo`Co00002?ooool3
o`0000[ooooo0_l000000ooooooo0000o`00000@ooooo`;o00001_ooool2o`0000Gooooo1Ol00002
ooooo`Go00002?ooool2o`0000Wooooo0_l00006ooooo`;o00001_ooool3o`0000;ooooo0ol00000
0ooooooo0000o`000006o`0000;ooooo6ol00008ooooo`;o00001_ooool2o`0000_ooooo1_l00002
ooooo`;o0000C_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?oM
gMgoEEEEooooool00007ooooo`03o`000?oooooooooo03[ooooo0_l00006ooooo`;o00000_ooool3
o`0000[ooooo1Ol0000@ooooo`;o00003Oooool6o`000005ooooool0003o0000o`000?ooool00_l0
0002ooooo`;o00000_ooool2o`000003ooooool0003o000000Oooooo0_l00006ooooo`;o00001?oo
ool2o`000003ooooool0003o000000;ooooo1?l00002ooooo`Oo00000_oooolCo`0000;ooooo0ol0
0002ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000006ooooo`;o00002ooo
ool:o`0000Sooooo0_l00014ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:
ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0@_ooool2o`0000;ooooo0ol0000:
ooooo`Go00000oooool4o`0001cooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00000_oo
ool2o`0000;ooooo1Ol0000?ooooo`Co00000_ooool2o`0000Gooooo8ol00002ooooo`;o000000Go
ooooo`000?l0003o0000ooooo`06o`0000kooooo0_l00004ooooo`Co000000Coooooo`000?l0003o
00002_ooool2o`0004Cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4
A?l000001oooool00ol0003oooooooooo`16ooooo`;o00002oooool2o`0000?ooooo0_l000000ooo
oooo0000o`000002o`0001Kooooo0_l00004ooooo`;o00003oooool3o`0000Oooooo0_l00002oooo
o`;o00000oooool5o`0000Oooooo;ol000000ooooooo0000o`000007ooooo`;o000000?oooooo`00
0?l000000_ooool2o`0000Cooooo1?l00002ooooo`Co00001Oooool2o`0004Oooooo00001_oooooo
k^k^oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`16
ooooo`;o00001oooool2o`0000Cooooo0_l000000ooooooo0000o`00000Dooooo`;o00001Oooool2
o`0000kooooo0ol00008ooooo`;o00001?ooool2o`0000;ooooo1?l000000ooooooo0000o`000003
o`0000Gooooo;ol0000<ooooo`;o000000?oooooo`000?l000003_ooool4o`0000;ooooo1Ol00004
ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool07oooool2o`0002Gooooo0ol00006oooo
o`?o00000oooool2o`000003ooooool0003o000000gooooo0ol00004ooooo`?o00002?ooool2o`00
00Wooooo1?l00002ooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00001Oooool2o`00
00?ooooo1?l000000ooooooo0000o`00000Yo`0000Cooooo0ol0000>ooooo`;o000000?oooooo`00
0?l000000_l00005ooooo`;o000000?oooooo`000?l000000_l00004ooooo`Co0000@Oooool001co
oooo00?o0000ooooooooool07oooool2o`0001Sooooo0_l00005ooooo`;o00001?ooool3o`0000Oo
oooo0_l00002ooooo`?o00000_ooool2o`0000cooooo1?l00004ooooo`?o00001oooool2o`0000Wo
oooo1?l00002ooooo`?o00002Oooool2o`0000Cooooo0_l00003ooooo`Co000000?oooooo`000?l0
00008ol000000ooooooo0000o`00000:o`0000Cooooo0ol0000=ooooo`?o000000?oooooo`000?l0
00000_l00008ooooo`;o00001_ooool4o`00047ooooo000Looooo`03o`000?oooooooooo03Wooooo
0_l00004ooooo`Go00000_ooool2o`0000cooooo0_l00003ooooo`;o00002_ooool6o`0000Gooooo
1?l0000;ooooo`?o00000oooool3o`0000?ooooo0_l0000=ooooo`Co00000oooool4o`000003oooo
ool0003o000000;ooooo:ol00002ooooo`;o00001?ooool2o`0000Gooooo0_l00006ooooo`;o0000
0_ooool3o`0000Sooooo0ol00004ooooo`;o00000_ooool2o`00047ooooo000Looooo`03o`000?oo
oooooooo03oooooo0_l000000ooooooo0000o`000004ooooo`;o00003_ooool2o`0000Wooooo1?l0
0006ooooo`;o000000?oooooo`000?l000000_l0000;ooooo`?o000000?oooooo`000?l000001?l0
0008ooooo`;o00001oooool3o`0000Kooooo0_l000001?oooooo0000o`000?ooool`o`0000Cooooo
0_l00005ooooo`?o00001?ooool3o`0000;ooooo0ol00008ooooo`;o00001Oooool2o`0004Gooooo
000Looooo`03o`000?oooooooooo043ooooo1?l00004ooooo`;o00000oooool2o`0000Wooooo0_l0
0009ooooo`?o00001oooool2o`00017ooooo0_l000000ooooooo0000o`000002ooooo`?o00001_oo
ool3o`000003ooooool0003o000000Gooooo0_l00008ooooo`?o000000Coooooo`000?l0003ooooo
5ol000000ooooooo0000o`00000=o`000003ooooool0003o000000?o00003?ooool2o`0000Cooooo
0_l0000=ooooo`;o0000COooool001cooooo00?o0000ooooooooool0@?ooool2o`0000_ooooo0_l0
000>ooooo`;o00001Oooool4o`00023ooooo0_l00004ooooo`Co000000Coooooo`000?l0003o0000
2?ooool2o`0000Cooooo0ol000001?oooooo0000o`000?oooolXo`000003ooooool0003o000000Ko
00006_ooool2o`0000;ooooo1?l0000=ooooo`;o0000??ooool001cooooo00?o0000ooooooooool0
>?ooool2o`0001[ooooo0_l00007ooooo`;o00001oooool4o`0000cooooo0_l0000:ooooo`;o0000
1oooool2o`000003ooooool0003o000000?ooooo0_l00004ooooo`Co000000?oooooo`000?l00000
1?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000Wo`000003ooooool0003o000000Go0000
3_ooool2o`0000;ooooo0_l00006ooooo`;o00001?ooool2o`000003ooooool0003o000000[ooooo
0_l0000looooo`007?ooool00ol0003oooooooooo`0hooooo`;o00000oooool2o`0000kooooo1_l0
00000ooooooo0000o`000002o`0000?ooooo0_l00002ooooo`Co00001Oooool2o`0000Cooooo0_l0
0004ooooo`Co000000Coooooo`000?l0003ooooo0_l00002ooooo`Co00000_ooool4o`000003oooo
ool0003o000000cooooo1?l00007ooooo`;o000000?oooooo`000?l000000_l00002oooooaCo0000
00?oooooo`000?l000004?l00002ooooo`Co00001Oooool2o`0000Wooooo0_l000001?oooooo0000
o`000?l00007ooooo`;o00001_ooool2o`0004Sooooo000Looooo`03o`000?oooooooooo03gooooo
0_l0000>ooooo`Ko00000oooool3o`0000;ooooo0_l00002ooooo`Co00000_ooool2o`0000Oooooo
0_l00004ooooo`;o00000oooool6o`000003ooooool0003o000000Cooooo1?l0000Dooooo`;o0000
0oooool2o`0000;ooooo1?l000000ooooooo0000o`00000Vo`0000?ooooo0_l00006ooooo`;o0000
0oooool2o`0000Oooooo1?l00006ooooo`;o00001_ooool3o`0004Oooooo000Looooo`03o`000?oo
oooooooo03gooooo0_l00004ooooo`;o00002oooool2o`0000;ooooo0_l000000ooooooo0000o`00
000<ooooo`;o00004_ooool8o`0000Kooooo0_l0000:ooooo`;o00002Oooool2o`0000?ooooo0_l0
0003ooooo`Ko00000ooooolNo`000003ooooool0003o000000Gooooo0_l0000;ooooo`;o00002?oo
ool5o`0000?ooooo0ol00004ooooo`Go0000Aoooool001cooooo00?o0000ooooooooool0?Oooool2
o`0000Cooooo0_l0000?ooooo`;o00002Oooool5o`0000Gooooo0_l000001?oooooo0000o`000?l0
0004ooooo`;o00001?ooool2o`0000Cooooo0_l0000Aooooo`Co00001Oooool2o`0000_ooooo0_l0
00001?oooooo0000o`000?l00004ooooo`?o000000?oooooo`000?l000005ol00004ooooo`;o0000
0_ooool2o`0001Sooooo0_l00003ooooo`;o00001Oooool4o`0000?ooooo0_l0000Cooooo`;o0000
;_ooool001cooooo0_l0000looooo`Ko00004oooool2o`0000Kooooo0_l000000ooooooo0000o`00
0003o`000003ooooool0003o000000;ooooo1_l00004ooooo`;o00002_ooool2o`00017ooooo1?l0
0005ooooo`;o00002?ooool2o`000003ooooool0003o000000Oo00000ooooolKo`0000?ooooo1?l0
0003ooooo`;o00003?ooool2o`0000Sooooo0_l00007ooooo`;o00002?ooool2o`000003ooooool0
003o0000013ooooo0_l0000^ooooo`007?ooool00ol0003oooooooooo`0Kooooo`;o00007_ooool2
o`0000;ooooo1?l00005ooooo`;o00002?ooool4o`0000Kooooo0_l00003ooooo`;o00000_ooool2
o`0000Cooooo0_l00003ooooo`?o00000_ooool2o`0000?ooooo0_l00002ooooo`?o00006?ooool2
o`0000[ooooo0_l000000ooooooo0000o`000008o`0000;ooooo6ol00003ooooo`Co00000oooool2
o`0000cooooo0_l000000ooooooo0000o`00000>ooooo`;o000000?oooooo`000?l000000ol00005
ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool06oooool2o`0001Wooooo0_l00007oooo
o`Co00001Oooool2o`0000Sooooo1?l0000>ooooo`;o00001oooool6o`0000;ooooo0_l00003oooo
o`;o00000_ooool3o`0001Sooooo0_l0000;ooooo`;o00000_oooolTo`0000;ooooo1Ol0000=oooo
o`;o00000oooool2o`000003ooooool0003o000000oooooo1ol00017ooooo`007?ooool00ol0003o
ooooooooo`0eooooo`?o00004Oooool2o`0000Kooooo0_l00006ooooo`?o00002?ooool2o`0000;o
oooo0_l00003ooooo`Ko00003_ooool2o`0000?ooooo0_l0000Eooooo`;o00001oooool2o`000004
ooooool0003o0000ooooo`Go000000Goooooo`000?l0003o0000ooooo`0Ho`000003ooooool0003o
000000Go00001?ooool2o`000003ooooool0003o000000?ooooo0_l00003ooooo`?o00004Oooool2
o`0000;ooooo0_l00005ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0=Oooool2o`00
00_ooooo0_l00005ooooo`Co00001?ooool2o`0000Kooooo0ol0000<ooooo`Co000000?oooooo`00
0?l000000oooool8o`0000Oooooo0_l00003ooooo`;o00005Oooool2o`0000?ooooo0_l00005oooo
o`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00000Mo`000003ooooool0003o
000000;o00001?ooool2o`000004ooooool0003o0000o`0000Cooooo2?l0000Booooo`?o00001Ooo
ool2o`00047ooooo000Looooo`03o`000?oooooooooo04;ooooo0_l00002ooooo`;o00000_ooool3
o`0000Cooooo0_l00006ooooo`?o00003_ooool5o`000003ooooool0003o000000So000000?ooooo
o`000?l000009Oooool2o`0000Gooooo0_l00004ooooo`;o00000_ooool@o`000003ooooool0003o
000000?o00000oooool4o`0000Oooooo0_l00003ooooo`Co00001?ooool4o`0000;ooooo0_l0000>
ooooo`;o000000Coooooo`000?l0003o0000BOooool001cooooo00?o0000ooooooooool0>oooool3
o`0000Sooooo0_l00002ooooo`?o00003?ooool4o`0000kooooo1?l000001?oooooo0000o`000?oo
ool5o`0000;ooooo0ol000000ooooooo0000o`00000Yooooo`;o00001oooool2o`0000;ooooo0_l0
00000ooooooo0000o`000008o`0000;ooooo1?l00003ooooo`[o000000Coooooo`000?l0003o0000
0_ooool2o`0000Kooooo1?l00009ooooo`;o00001_ooool3o`000003ooooool0003o000000;o0000
B?ooool001cooooo00?o0000ooooooooool06?ooool2o`00027ooooo0ol00005ooooo`Co00001?oo
ool2o`000003ooooool0003o000000[ooooo1?l00007ooooo`;o00001?ooool2o`0000;ooooo0_l0
0002ooooo`Co000000?oooooo`000?l000000_l00002ooooo`;o00007?ooool3o`0000Wooooo0_l0
0003ooooo`;o00000oooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`0000Kooooo0_l0
00001?oooooo0000o`000?ooool<o`0000;ooooo1?l00008ooooo`Co00002Oooool2o`0000Kooooo
0_l00002ooooo`Go0000Aoooool001cooooo00?o0000ooooooooool06?ooool2o`0002?ooooo0_l0
0004ooooo`Co00001oooool2o`0000[ooooo1?l00004ooooo`;o000000?oooooo`000?l000000_l0
0002ooooo`?o000000?oooooo`000?l000001?ooool7o`000003ooooool0003o000000oooooo0_l0
0003ooooo`;o00001oooool3o`0000Gooooo0_l00002ooooo`;o00000oooool4o`000003ooooool0
003o000000;o000000Coooooo`000?l0003ooooo1?l00003ooooo`Go000000Coooooo`000?l0003o
oooo0_l00002ooooo`;o00000_ooool3o`0000Cooooo1Ol00007ooooo`;o00000oooool2o`0000co
oooo0_l00004ooooo`Go0000A_ooool001cooooo00?o0000ooooooooool0<?ooool2o`000003oooo
ool0003o000000Oooooo0ol00006ooooo`;o00001_ooool4o`0000_ooooo0_l00004ooooo`;o0000
0oooool2o`0000;ooooo0ol000001?oooooo0000o`000?l00004ooooo`;o00000_ooool6o`0000Oo
oooo0_l00005ooooo`;o00000oooool2o`0000[ooooo0_l00002ooooo`Co00002?ooool2o`000003
ooooool0003o000000Co000000?oooooo`000?l000000_l00002ooooo`Ko00000_ooool3o`0000So
oooo1?l00003ooooo`Go00001Oooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o
00000_ooool2o`0000;ooooo1Ol00003ooooo`;o000000?oooooo`000?l00000A_ooool001cooooo
00?o0000ooooooooool0<?ooool2o`000003ooooool0003o000000Oooooo1?l0000<ooooo`Go0000
00?oooooo`000?l000000_ooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0000Oo
oooo0_l00002ooooo`?o00001oooool2o`000003ooooool0003o000000;o000000?oooooo`000?l0
00000_ooool4o`0001?ooooo0_l000000ooooooo0000o`000002ooooo`Co00001oooool2o`0000Go
oooo0ol000000ooooooo0000o`00000;o`000004ooooool0003o0000o`0000Sooooo1?l00003oooo
o`?o00001oooool2o`000003ooooool0003o000000Kooooo0_l00002ooooo`;o00000_ooool5o`00
00Oooooo0_l00008ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0?_ooool2o`0000co
oooo0ol00003ooooo`;o00000_ooool2o`0000Oooooo0_l000000ooooooo0000o`000006ooooo`?o
00000_ooool3o`0000Oooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`0001Co
oooo1_l00004ooooo`;o00001oooool2o`0000Oooooo2_l000000ooooooo0000o`000002o`000003
ooooool0003o000000?ooooo0ol00004ooooo`;o00001?ooool2o`0001?ooooo0_l00005ooooo`;o
00000_ooool2o`0000Oooooo0_l00008ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0
<oooool2o`00013ooooo0_l00006ooooo`;o00002_ooool2o`0000?ooooo0ol00009ooooo`;o0000
0oooool3o`00013ooooo0_l0000;ooooo`;o000000?oooooo`000?l000001oooool2o`000004oooo
ool0003o0000o`0000Cooooo0_l0000@ooooo`;o00000_ooool6o`000003ooooool0003o000000?o
00001Oooool3o`0001oooooo0_l00002ooooo`;o000000?oooooo`000?l000000ol0001?ooooo`00
7?ooool00ol0003oooooooooo`0cooooo`;o00004?ooool2o`000004ooooool0003o0000o`0000?o
oooo1?l00002ooooo`;o00000oooool2o`0000?ooooo0ol0000Qooooo`;o000000?oooooo`000?l0
00002?ooool2o`000003ooooool0003o0000023ooooo0_l00005ooooo`?o000000Coooooo`000?l0
003ooooo1Ol00005ooooo`;o00001Oooool2o`000003ooooool0003o000000Wooooo0_l0000=oooo
o`Co00000oooool3o`0000Sooooo0ol00014ooooo`007?ooool00ol0003oooooooooo`11ooooo`;o
00001Oooool3o`0000?ooooo1?l00002ooooo`;o000000?oooooo`000?l000002?ooool2o`0000_o
oooo0_l00007ooooo`;o00003?ooool4o`0001cooooo0ol0000<ooooo`;o00001Oooool3o`0000_o
oooo1?l00006ooooo`;o000000?oooooo`000?l000002Oooool2o`0000gooooo1_l0000<ooooo`?o
0000A?ooool001cooooo00?o0000ooooooooool0@Oooool2o`0001Cooooo0_l00008ooooo`;o0000
2oooool2o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`;o00001oooool5o`000003oooo
ool0003o000000Oooooo0_l00002ooooo`;o00001?ooool2o`0000Cooooo0ol000000ooooooo0000
o`000004ooooo`;o000000?oooooo`000?l000001oooool2o`0000Gooooo0_l000001Ooooooo0000
o`000?l0003ooooo00Co00002Oooool4o`0001Kooooo2?l0001Aooooo`007?ooool2o`0005Cooooo
0_l0000@ooooo`;o000000?oooooo`000?l000000ol00007ooooo`;o00001oooool2o`0000?ooooo
0_l00002ooooo`So00001oooool2o`0000;ooooo0_l00004ooooo`;o00001Oooool2o`000004oooo
ool0003o0000ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`Co00002?ooool2o`00
0004ooooool0003o0000o`0000;ooooo0_l0000:ooooo`Co00001?ooool2o`0000kooooo0_l00002
ooooo`;o00000_ooool5o`0004kooooo000Looooo`03o`000?oooooooooo01Oooooo0_l0000Joooo
o`;o00007_ooool2o`0000;ooooo0_l0000<ooooo`;o000000?oooooo`000?l000000ol0000Eoooo
o`;o00001Oooool5o`0000Cooooo0_l00005ooooo`;o00004Oooool2o`0000Sooooo1_l0000>oooo
o`;o00001_ooool2o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000001?ooool2o`00
00Sooooo0_l00002ooooo`;o00000_ooool5o`000003ooooool0003o000000Oooooo0_l00004oooo
o`;o00005Oooool2o`0002Gooooo000Looooo`03o`000?oooooooooo01Oooooo0_l0000Jooooo`;o
00004Oooool2o`000003ooooool0003o000000cooooo0_l00005ooooo`;o00001Oooool2o`0002Go
oooo0_l00002ooooo`Ko00001?ooool2o`0000Wooooo0_l0000Cooooo`;o00001?ooool2o`0000Ko
oooo0_l00008ooooo`;o00001oooool2o`000003ooooool0003o000000Cooooo1?l0000:ooooo`;o
00001?ooool2o`0000;ooooo0_l00007ooooo`?o00000oooool4o`0001;ooooo0ol0000Uooooo`00
7?ooool00ol0003oooooooooo`0/ooooo`;o00006?ooool2o`000003ooooool0003o000000;ooooo
0_l00008ooooo`;o00001Oooool2o`0000[ooooo0_l0000Tooooo`Oo00000oooool2o`0000Sooooo
1Ol00006ooooo`;o00003oooool2o`0000Kooooo1?l00002ooooo`;o00003_ooool2o`0000?ooooo
0_l000000ooooooo0000o`000006ooooo`;o00002?ooool2o`0000cooooo0_l00005ooooo`;o0000
4_ooool2o`0002Kooooo000Looooo`03o`000?oooooooooo02cooooo0_l0000?ooooo`;o00001ooo
ool2o`0000Gooooo0_l0000Kooooo`;o00007?ooool2o`0000Cooooo0_l00004ooooo`Co00000_oo
ool2o`0000Sooooo0_l000000ooooooo0000o`000002ooooo`Ko00001oooool2o`0000gooooo0_l0
00000ooooooo0000o`000002ooooo`;o00004Oooool4o`0000Sooooo0ol00007ooooo`Co000000?o
ooooo`000?l000000_ooool2o`0000Cooooo0_l00003ooooo`?o0000>oooool001cooooo00?o0000
ooooooooool0?Oooool2o`0000Kooooo0ol00004ooooo`;o00002oooool2o`000003ooooool0003o
000000?o00001?ooool2o`0000cooooo0_l0000Cooooo`Co00000_ooool2o`0000Cooooo1?l00003
ooooo`;o00003_ooool6o`0000Oooooo0_l00004ooooo`;o00001oooool2o`0000Gooooo0_l00003
ooooo`;o00002_ooool4o`000003ooooool0003o000000;o00001Oooool4o`0000Kooooo1ol00000
1?oooooo0000o`000?l00003ooooo`?o00000oooool3o`0003_ooooo000Looooo`03o`000?oooooo
oooo01Wooooo0_l0000Xooooo`Ko000000?oooooo`000?l000000_l0000;ooooo`;o000000?ooooo
o`000?l000000ol00004ooooo`;o00002oooool3o`0000Wooooo0_l0000:ooooo`;o00000_ooool4
o`0000;ooooo0ol00004ooooo`;o00001Oooool2o`0000Wooooo1?l00002ooooo`;o00002Oooool2
o`0001?ooooo0_l0000:ooooo`Co000000?oooooo`000?l000000_l00005ooooo`Co00000_ooool2
o`0000Gooooo0ol00002ooooo`;o00000_ooool4o`0004;ooooo000Looooo`03o`000?oooooooooo
01Wooooo0_l0000Xooooo`?o000000Coooooo`000?l0003ooooo1Ol0000@ooooo`;o00000oooool2
o`0000cooooo0_l000000ooooooo0000o`000002ooooo`?o00000_ooool2o`0000[ooooo0_l00002
ooooo`Wo00002?ooool2o`000003ooooool0003o000000[ooooo0_l00003ooooo`?o00002Oooool2
o`0000Gooooo0_l0000Mooooo`;o00003?ooool2o`0000kooooo0_l00014ooooo`007?ooool00ol0
003oooooooooo`0hooooo`;o000000?oooooo`000?l000000oooool2o`0000;ooooo0_l00004oooo
o`Oo00000_ooool2o`0000Oooooo0_l000000ooooooo0000o`000003ooooo`;o00003oooool2o`00
00;ooooo1?l0000Cooooo`Co000000?oooooo`000?l000000oooool8o`0000;ooooo0_l0000>oooo
o`;o00000oooool4o`0000;ooooo0_l00005ooooo`;o00003?ooool2o`0000gooooo0_l00006oooo
o`?o00001?ooool2o`0000oooooo0_l0000Cooooo`;o0000;oooool001cooooo00?o0000oooooooo
ool0>?ooool2o`000004ooooool0003o0000ooooo`Co00001oooool9o`000003ooooool0003o0000
00Oooooo0_l00003ooooo`;o00006?ooool5o`00013ooooo0_l000000ooooooo0000o`000004o`00
0003ooooool0003o000000Ko00000_ooool4o`0000Cooooo0_l00003ooooo`;o00000_ooool2o`00
00;ooooo1?l0000Dooooo`;o000000?oooooo`000?l000003Oooool2o`0000Kooooo0ol00004oooo
o`;o00000oooool2o`0000cooooo0_l0000Aooooo`;o00001?ooool2o`0002Wooooo000Looooo`03
o`000?oooooooooo03Sooooo0_l00004ooooo`;o00002?oooolAo`0000Sooooo0_l0000Aooooo`;o
00001_ooool4o`00017ooooo2?l00003ooooo`?o00001oooool2o`0000Cooooo0_l00002ooooo`?o
000000Coooooo`000?l0003o00001Oooool2o`0000Sooooo0_l00009ooooo`;o00004?ooool2o`00
017ooooo0ol0000<ooooo`;o00005oooool2o`0002Wooooo000Looooo`03o`000?oooooooooo01[o
oooo0_l0000XoooooaGo00001oooool2o`0000Kooooo0_l0000:ooooo`;o00000oooool2o`0001;o
oooo0_l00002ooooo`?o000000?oooooo`000?l000000oooool4o`0001;ooooo1_l00006ooooo`;o
00002?ooool2o`0000Wooooo0ol0000?ooooo`;o00001oooool4o`0000;ooooo0_l00002ooooo`;o
00000_ooool2o`0004gooooo000Looooo`03o`000?oooooooooo01[ooooo0_l0000Xoooooa7o0000
00?oooooo`000?l000001Oooool2o`000003ooooool0003o000000Cooooo1?l00005ooooo`go0000
00Coooooo`000?l0003o00003Oooool2o`0000Kooooo0_l00003ooooo`Go00004oooool3o`00017o
oooo0_l00009ooooo`?o00002_ooool3o`0000_ooooo1?l00002ooooo`;o00001_ooool2o`000003
ooooool0003o000000;ooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`15ooooo`Co0000
00?oooooo`000?l000003?l00005ooooo`;o00001oooool2o`0000Oooooo4Ol0000:ooooo`;o0000
0oooool4o`000003ooooool0003o000000;o00000_ooool5o`000004ooooool0003o0000ooooo`;o
00003_ooool2o`00013ooooo0ol0000Fooooo`?o00004Oooool2o`0000Oooooo1?l00002ooooo`;o
00001Oooool2o`0003oooooo000Looooo`03o`000?oooooooooo03Wooooo0_l00005ooooo`;o0000
0ooooolBo`0000?ooooo0_l0000;ooooo`;o00000ooooolCo`0000;ooooo0_l00007ooooo`;o0000
0oooool4o`000003ooooool0003o000000;o00000_ooool4o`0000;ooooo0_l000000ooooooo0000
o`00000?ooooo`;o00001oooool2o`0000Kooooo0_l00004ooooo`;o00002_ooool2o`0000Oooooo
0_l0000>ooooo`Co00001?ooool2o`000004ooooool0003o0000ooooo`;o00002?ooool2o`0000Go
oooo0ol00005ooooo`;o0000<?ooool001cooooo00?o0000ooooooooool0>Oooool2o`0000Gooooo
0_l00003oooooa7o000000Coooooo`000?l0003ooooo0_l0000;ooooo`;o00000_ooool5o`000003
ooooool0003o0000017o00002oooool2o`0000Wooooo1_l0000Aooooo`;o000000Coooooo`000?l0
003o00001?ooool4o`0000cooooo0_l0000:ooooo`;o00001oooool2o`0000kooooo0_l00006oooo
o`;o00000_ooool4o`0000?ooooo0_l0000:ooooo`?o00001Oooool2o`00033ooooo000Looooo`;o
00007Oooool2o`0000oooooo0_l0000Aooooo`;o00000oooool@o`0000;ooooo0_l0000:ooooo`;o
000000Coooooo`000?l0003o00000_oooolJo`0000[ooooo0ol000001?oooooo0000o`000?l00006
ooooo`Go00001?ooool2o`0000Kooooo0_l00002ooooo`;o00000_ooool2o`0000Cooooo0_l0000:
ooooo`;o00004_ooool2o`0001_ooooo0_l00002ooooo`Co00000oooool2o`0001Gooooo0_l0000]
ooooo`007?ooool00ol0003oooooooooo`0Looooo`;o00003oooool2o`0000kooooo1Ol00002oooo
o`oo00004?ooool2o`000004ooooool0003o0000o`0000Gooooo0ol000000ooooooo0000o`00000B
o`0000Wooooo0ol000001?oooooo0000o`000?l00004ooooo`Co000000Coooooo`000?l0003ooooo
0_l000000ooooooo0000o`000006ooooo`?o00005oooool2o`0000;ooooo0_l00009ooooo`;o0000
0oooool2o`000003ooooool0003o000001Sooooo0_l00006ooooo`;o00001oooool2o`0000oooooo
0_l0000]ooooo`007?ooool00ol0003oooooooooo`0mooooo`Co00000oooool5o`000003ooooool0
003o000000Go000000?oooooo`000?l000005oooool2o`000003ooooool0003o000001Ko00002Ooo
ool2o`0000?ooooo1?l00002ooooo`;o00000oooool2o`000003ooooool0003o000000Sooooo1?l0
0005ooooo`;o00002_ooool2o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l000001_oo
ool2o`0000Kooooo0_l0000;ooooo`;o00002oooool2o`0000;ooooo0_l00002ooooo`Co00001Ooo
ool2o`0003kooooo000Looooo`03o`000?oooooooooo03oooooo0_l00003ooooo`Go00000_ooool6
o`000003ooooool0003o000001Gooooo7_l0000=ooooo`Co00005?ooool5o`0000Cooooo0_l00005
ooooo`;o00000oooool2o`0000;ooooo0ol00006ooooo`;o00000_ooool2o`0001?ooooo0_l00000
0ooooooo0000o`000002o`0000[ooooo0_l00002ooooo`?o00000oooool2o`0001Gooooo0_l0000^
ooooo`007?ooool00ol0003oooooooooo`0Mooooo`;o00009Oooool3o`0000?ooooo0_l0000Coooo
o`;o00001_ooool4o`0000;ooooo6_l0000=ooooo`;o00002oooool4o`0000Wooooo0ol0000;oooo
o`;o00001?ooool2o`000004ooooool0003o0000o`0000[ooooo1_l0000;ooooo`;o00000_ooool7
o`0000oooooo0_l0000Jooooo`;o0000;_ooool001cooooo00?o0000ooooooooool07Oooool2o`00
02;ooooo0_l00007ooooo`;o00004oooool4o`0000Cooooo0_l00004oooooa_o00001?ooool2o`00
00[ooooo0_l00007ooooo`So00002_ooool2o`0000_ooooo1?l00004ooooo`?o00001?ooool2o`00
00?ooooo2_l00005ooooo`;o00001?ooool5o`0000Sooooo0_l00009ooooo`;o0000A_ooool001co
oooo00?o0000ooooooooool07Oooool2o`0001_ooooo0_l00005ooooo`;o00003?ooool2o`0000_o
oooo0_l00003ooooo`?o00000_ooool5o`0000?ooooo6ol00003ooooo`;o00001?ooool2o`0000Co
oooo0ol00008ooooo`Ko00001_ooool2o`0000;ooooo0_l00009ooooo`Ko00001?ooool3o`0000Co
oooo0_l00007ooooo`Ko00006?ooool2o`0000Cooooo0_l00003ooooo`;o0000A_ooool001cooooo
00?o0000ooooooooool07_ooool2o`0001[ooooo0_l0000;ooooo`Go00000oooool2o`0000_ooooo
0_l00004ooooo`;o00000_ooool5o`0000?ooooo2_l000000ooooooo0000o`00000>o`000004oooo
ool0003o0000o`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l000001oooool2o`0000_o
oooo0_l0000=ooooo`;o00000oooool2o`0000?ooooo0_l00004ooooo`;o00001_ooool3o`0000ko
oooo0_l0000@ooooo`Oo00000oooool2o`0000_ooooo0_l0000gooooo`007?ooool00ol0003ooooo
ooooo`0Nooooo`;o00009oooool6o`0000oooooo0ol000001?oooooo0000o`000?l0000:oooooa[o
00000oooool4o`0000Sooooo0_l0000:ooooo`;o00002?ooool3o`0000gooooo0_l00005ooooo`;o
00000oooool2o`0000Cooooo0_l00003ooooo`;o000000?oooooo`000?l000001ol00008ooooo`;o
00004?ooool7o`0000?ooooo0_l0000;ooooo`;o0000=oooool001cooooo00?o0000ooooooooool0
?oooool2o`0000Cooooo0_l000000ooooooo0000o`000003o`0000kooooo1?l000001?oooooo0000
o`000?l0000:ooooo`Go000000?oooooo`000?l000004_l00005ooooo`;o00002Oooool5o`0000Ko
oooo0_l00005ooooo`;o000000Coooooo`000?l0003o00003Oooool2o`0000Sooooo0_l00004oooo
o`;o00001?ooool=o`0000?ooooo0_l00006ooooo`;o00004_ooool2o`0004Wooooo000Looooo`03
o`000?oooooooooo03oooooo0ol000000ooooooo0000o`000002o`0001Cooooo0_l0000Booooo`co
000000?oooooo`000?l000001Ol000001?oooooo0000o`000?l00005ooooo`;o00002Oooool5o`00
00gooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o00002oooool2
o`0000Cooooo0_l00002oooooaCo00001_ooool2o`0000?ooooo1?l0000;ooooo`;o00000oooool2
o`0000[ooooo1?l0000fooooo`007?ooool00ol0003oooooooooo`10ooooo`;o000000?oooooo`00
0?l000004_ooool2o`00017ooooo0_l00003oooooaGo000000?oooooo`000?l000001Oooool2o`00
00_ooooo0_l00005ooooo`;o00002oooool2o`000004ooooool0003o0000ooooo`Co00000_ooool2
o`0000?ooooo0_l00007ooooo`;o00000oooool2o`0000;ooooo4_l0000=ooooo`Co00001_ooool2
o`0000Sooooo0_l0000:ooooo`Co000000?oooooo`000?l00000<oooool001cooooo00?o0000oooo
ooooool0>Oooool2o`0000kooooo0_l0000<ooooo`Co00003oooool2o`0000Cooooo5ol00005oooo
o`;o00001?ooool2o`0000Gooooo0_l00005ooooo`;o00002oooool2o`0000Cooooo1?l00007oooo
o`;o00001oooool2o`0000Sooooo4Ol00008ooooo`;o00000_ooool2o`0000Wooooo0_l0000Ioooo
o`;o0000<oooool001cooooo00?o0000ooooooooool0=_ooool5o`0000kooooo0_l000000ooooooo
0000o`00000;ooooo`;o00002_ooool2o`0000Wooooo6_l00008ooooo`;o00000oooool2o`0001Wo
oooo0ol0000Dooooo`?o00000oooool7o`000003ooooool0003o000000Wo00001?ooool2o`0000;o
oooo0_l00002ooooo`Co00005?ooool2o`00047ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^
kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0f
ooooo`?o00004oooool2o`0001Oooooo0_l0000:ooooo`Go000000?oooooo`000?l000001ol00000
0ooooooo0000o`000007o`0000Cooooo0_l00007ooooo`;o00006Oooool2o`0000Gooooo0_l00003
ooooo`;o00002?ooool4o`000003ooooool0003o000001?o00001?ooool2o`0000Sooooo0_l00006
ooooo`;o000000?oooooo`000?l000002Oooool5o`0003kooooo00001_ooooooMgMgoiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`0gooooo`;o00002_ooool2o`0000Sooooo0_l0000Jooooo`;o00001_oooolEo`0000;ooooo
0ol00003ooooo`;o00008?ooool2o`0000Oooooo0_l00003ooooo`;o00001Oooool2o`000003oooo
ool0003o000000?ooooo0ol000000ooooooo0000o`00000Ao`0001Cooooo0_l000000ooooooo0000
o`00000:ooooo`Co00001oooool2o`0003Gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oo
oooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo03Oooooo
0_l00004ooooo`;o00001?ooool2o`0000Sooooo0_l0000Jooooo`;o00001_ooool2o`0000;ooooo
3ol000000ooooooo0000o`000004o`0002Gooooo0_l00006ooooo`?o00000oooool2o`0000Gooooo
0_l00005oooooaSo00000_ooool2o`0001gooooo1_l00007ooooo`;o0000=Oooool00003ooooool0
003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo
0ol0000mooooo`;o00008_ooool2o`00013ooooo0_l000000ooooooo0000o`00000@o`0000Cooooo
0_l00009ooooo`;o00007oooool3o`00017ooooo0_l000000ooooooo0000o`00000Co`0000;ooooo
0_l0000Mooooo`;o0000@_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool08?ooool2o`0001Gooooo
0_l000000ooooooo0000o`00000Pooooo`;o00000oooool2o`00013ooooo0_l00002ooooo`ko0000
1oooool2o`0000Wooooo0_l0000Kooooo`;o00000oooool2o`0001Gooooo5?l00002ooooo`;o0000
3oooool2o`00053ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00?o
EEEEohN7Qoooool02?ooool00ol0003oooooooooo`0Pooooo`;o00005Oooool2o`000003ooooool0
003o000000Oooooo0_l00008ooooo`;o00003Oooool2o`0000Sooooo0_l00007ooooo`Co00001ooo
ool8o`000003ooooool0003o000000Cooooo0_l0000<ooooo`;o00002?ooool2o`00017ooooo0_l0
0008ooooo`;o00004OoooolEo`00017ooooo0_l00002ooooo`;o0000C?ooool00006oooooomgMgOo
V9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo04?ooooo
0_l00008ooooo`;o00003Oooool2o`0000Sooooo0_l00007ooooo`Co00001Oooool2o`000003oooo
ool0003o000000;o00001?ooool4o`0000;ooooo0_l00005ooooo`;o00001?ooool2o`0000Wooooo
0_l0000Eooooo`Co00000_ooool2o`0000oooooo6Ol0000Booooo`?o0000C?ooool00006ooooooo^
k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo
053ooooo0_l00009ooooo`;o00004oooool2o`0000Kooooo0_l00009ooooo`Co00001?ooool2o`00
00?ooooo0_l000001?oooooo0000o`000?ooool2o`0001oooooo1Ol0000CoooooaWo00004_ooool2
o`0000_ooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00002Oooool2o`00
01?ooooo0_l0000?ooooo`;o00002?ooool2o`0000Kooooo0_l000001?oooooo0000o`000?ooool4
o`0001[ooooo0ol0000Gooooo`go000000?oooooo`000?l000001ol0000;ooooo`;o000000Cooooo
o`000?l0003ooooo0_l0000<ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0L?ooool2
o`0000cooooo0_l000000ooooooo0000o`00000>ooooo`Go000000?oooooo`000?l000001?l0000H
ooooo`Ko000000?oooooo`000?l000000oooool2o`0000_ooooo6_l0000;ooooo`Go000000?ooooo
o`000?l00000C_ooool001cooooo00?o0000ooooooooool0L?ooool2o`0000cooooo0_l0000:oooo
o`;o00000_ooool<o`0001_ooooo1_l000000ooooooo0000o`000003ooooo`;o00002ooooolFo`00
017ooooo0_l0000:ooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0D?ooool2o`0002?o
oooo0_l0000Booooo`?o00000_ooool@o`0002;ooooo0_l0000<ooooo`;o00001_ooool;o`00023o
oooo0_l000000ooooooo0000o`000002o`00047ooooo000Looooo`03o`000?oooooooooo03_ooooo
0_l0000<ooooo`;o00000oooool4o`00013ooooo0_l0000Aooooo`;o00003Oooool2o`0000?ooooo
1Ol00002ooooo`Ko000000?oooooo`000?l000001ol0000Jooooo`;o00001?ooool2o`0000cooooo
5?l000000ooooooo0000o`00000Hooooo`;o00001Oooool4o`00047ooooo000Looooo`03o`000?oo
oooooooo03_ooooo0_l0000<ooooo`;o00000oooool2o`0000gooooo0_l00003ooooo`;o00001Ooo
ool2o`0001Kooooo0_l000000ooooooo0000o`000005ooooo`Co000000?oooooo`000?l000004?l0
0003ooooo`;o00004Oooool6o`00013ooooo5?l000000ooooooo0000o`000002o`0001Kooooo0_l0
001:ooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00001oooool2o`0000Cooooo0_l0000=
ooooo`;o00002_ooool2o`0001Kooooo0_l00008ooooo`Co000000?oooooo`000?l000004Ol00002
ooooo`;o00004Oooool3o`000003ooooool0003o000001Gooooo3?l00006ooooo`;o00002oooool3
o`0000Oooooo0_l00004ooooo`;o0000AOooool001cooooo00?o0000ooooooooool0?_ooool4o`00
00Kooooo1Ol000000ooooooo0000o`00000=ooooo`;o00009oooool2o`0000Cooooo0_l00002oooo
oa3o000000Coooooo`000?l0003o00005Oooool2o`0000Oooooo1Ol0000<ooooo`Co00000oooool4
o`0001Cooooo0ol00007ooooo`;o00001?ooool2o`0000Cooooo0ol0000nooooo`007?ooool00ol0
003oooooooooo`0nooooo`Co00002?ooool3o`000004ooooool0003o0000o`0003Gooooo0_l00005
ooooo`;o000000?oooooo`000?l000003_l000000ooooooo0000o`000003o`00017ooooo0_l00002
ooooo`;o00001Oooool5o`0000;ooooo0_l0000?ooooo`Co00000_ooool2o`0000oooooo0_l0000D
ooooo`Co0000?_ooool001cooooo00?o0000ooooooooool0@_ooool2o`0000Sooooo0_l000000ooo
oooo0000o`00000=ooooo`;o00004oooool2o`000003ooooool0003o000001Gooooo0_l000000ooo
oooo0000o`00000Do`0000?ooooo0_l00002ooooo`;o00002?ooool2o`0000;ooooo0ol00006oooo
o`?o00000_ooool2o`0000oooooo0_l00004ooooo`?o00003_ooool4o`0000Wooooo0_l00007oooo
o`?o0000?oooool001cooooo00?o0000ooooooooool0@_ooool2o`0000Oooooo0ol0000>ooooo`Co
00004oooool2o`000005ooooool0003o0000o`000?ooool00_l0000DoooooaOo00000_ooool2o`00
00;ooooo0_l0000=ooooo`;o00001_ooool2o`0001_ooooo0_l0000@ooooo`Co00001oooool2o`00
04Wooooo000Looooo`;o0000?Oooool2o`0000Kooooo0_l00002ooooo`;o000000?oooooo`000?l0
00003oooool2o`0000;ooooo0_l0000=ooooo`?o00001Oooool2o`000003ooooool0003o000001Co
oooo6?l0000Fooooo`;o00009Oooool2o`0000kooooo0_l0001Booooo`007?ooool00ol0003ooooo
ooooo`0looooo`;o00000_ooool2o`0000;ooooo0_l00002ooooo`;o00001oooool2o`0000gooooo
0_l00004ooooo`;o00001oooool3o`000003ooooool0003o000000_ooooo0_l0000<oooooaKo0000
00Coooooo`000?l0003o00005_ooool2o`0000Kooooo0_l0000Mooooo`;o00000_ooool2o`0005ko
oooo000Looooo`03o`000?oooooooooo03cooooo0_l00002ooooo`;o00003oooool2o`0001?ooooo
0_l0000;ooooo`;o00002oooool4o`0000[ooooo5_l000001?oooooo0000o`000?l0000Booooo`;o
00002_ooool2o`0001kooooo0_l000000ooooooo0000o`000005ooooo`;o00002Oooool2o`0000?o
oooo0_l00017ooooo`007?ooool00ol0003oooooooooo`11ooooo`;o000000?oooooo`000?l00000
0ol0000Hooooo`;o00002oooool2o`0001;ooooo0_l00009oooooa_o00004?ooool4o`0000Sooooo
0_l0000Fooooo`;o00002?ooool2o`0000Sooooo1?l00007ooooo`;o00000oooool2o`0004Oooooo
000Looooo`03o`000?oooooooooo03cooooo0_l00003ooooo`;o000000?oooooo`000?l000000ol0
0006ooooo`;o00004?ooool2o`0000_ooooo0_l0000Mooooo`go000000?oooooo`000?l000002ol0
00000ooooooo0000o`00000=ooooo`;o00002_ooool2o`0001Kooooo0_l0000Dooooo`;o0000EOoo
ool001cooooo00?o0000ooooooooool0??ooool2o`0000oooooo1?l0000iooooo`;o00001?ooool:
o`000003ooooool0003o000000ko0000?_ooool4o`0001Cooooo0_l00016ooooo`007?ooool00ol0
003oooooooooo`14ooooo`;o00000_ooool2o`000003ooooool0003o000000;o00000_ooool2o`00
00[ooooo0_l0000Fooooo`?o00004_ooool2o`0000Cooooo6ol00003ooooo`?o00002Oooool2o`00
00Wooooo0_l00005ooooo`;o00006_ooool5o`0001Cooooo0_l00016ooooo`007?ooool00ol0003o
ooooooooo`11ooooo`;o000000?oooooo`000?l000000_ooool5o`0000Cooooo0_l0000:ooooo`;o
00005_ooool3o`0000oooooo0_l000000ooooooo0000o`000004ooooo`co000000?oooooo`000?l0
00003_l000001?oooooo0000o`000?l00002ooooo`;o00001Oooool2o`0000?ooooo0_l00002oooo
o`Co00001Oooool2o`0000;ooooo0_l0000Cooooo`;o000000?oooooo`000?l000002Oooool3o`00
05?ooooo000Looooo`03o`000?oooooooooo047ooooo0_l00007ooooo`Co0000>Oooool2o`000003
ooooool0003o000000Cooooo3Ol000000ooooooo0000o`00000=o`0000Kooooo0_l00005ooooo`;o
00000oooool2o`0000;ooooo0_l00005ooooo`;o00001?ooool2o`0000Gooooo0_l0000<ooooo`Co
00001Oooool2o`0000?ooooo1?l0001Booooo`007?ooool00ol0003oooooooooo`1<ooooo`;o0000
2?ooool2o`0000Oooooo0_l0000Gooooo`;o00004?ooool2o`0000;ooooo0_l000001?oooooo0000
o`000?l00003oooooaCo00000_ooool8o`0001Gooooo1?l00008ooooo`?o00001Oooool2o`0000Oo
oooo1?l00002ooooo`?o00000oooool4o`0000Kooooo0_l0001:ooooo`007?ooool00ol0003ooooo
ooooo`18ooooo`Ko00002?ooool2o`0000Oooooo0_l0000Gooooo`;o00003Oooool2o`0000Gooooo
1_l000000ooooooo0000o`00000Bo`0000Cooooo1ol00002ooooo`;o000000?oooooo`000?l00000
1_ooool2o`0000Sooooo0ol00003ooooo`;o00000oooool2o`0000?ooooo1Ol00005ooooo`;o0000
0_ooool2o`0000;ooooo0_l00004ooooo`;o00002?ooool2o`0004[ooooo000Looooo`03o`000?oo
oooooooo04Sooooo1_l0000iooooo`;o00001_oooolIo`000003ooooool0003o000000;o00001Ooo
ool2o`0000;ooooo0_l000000ooooooo0000o`000006ooooo`;o00002?ooool2o`0000Cooooo0_l0
0008ooooo`?o00001oooool2o`0000;ooooo0_l0000Aooooo`;o0000Boooool001cooooo00?o0000
ooooooooool0B?ooool2o`0004Gooooo6Ol000000ooooooo0000o`000002o`000004ooooool0003o
0000ooooo`;o00001_ooool2o`0002kooooo0_l0000Aooooo`;o0000Boooool001cooooo00?o0000
ooooooooool0I?ooool2o`0000Cooooo0_l00009ooooo`;o00007?oooolFo`000004ooooool0003o
0000ooooo`?o000000?oooooo`000?l000000oooool2o`000003ooooool0003o000001Wooooo0ol0
000=ooooo`;o00000_ooool2o`0000oooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`16
ooooo`;o000000?oooooo`000?l000002oooool2o`0000;ooooo0_l00006ooooo`Co00000oooool5
o`0000Oooooo0_l0000MoooooaGo000000?oooooo`000?l000000ol00007ooooo`;o00007?ooool3
o`0000Sooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000Wooooo0_l00004
ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0A_ooool2o`000004ooooool0003o0000
o`0000[ooooo0_l00002ooooo`;o000000?oooooo`000?l000000oooool2o`0000Gooooo0_l00000
0ooooooo0000o`000005ooooo`;o00000oooool2o`00017ooooo0_l00007oooooa?o00000_ooool6
o`0000;ooooo0_l00003ooooo`;o00006Oooool5o`0000Oooooo1?l000001?oooooo0000o`000?oo
ool2o`0000cooooo0_l0001Dooooo`007?ooool2o`0004[ooooo0ol0000>ooooo`;o000000?ooooo
o`000?l000005?ooool2o`0000?ooooo0_l0000Aooooo`;o00001oooool2o`000003ooooool0003o
000001;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l0
000Aooooo`Ko00002?ooool2o`0000Cooooo0_l0001Tooooo`007?ooool00ol0003oooooooooo`19
ooooo`;o00008_ooool2o`0001cooooo0_l0000:oooooaCo00000_ooool2o`0000Gooooo0_l00003
ooooo`;o000000?oooooo`000?l000003_ooool2o`000003ooooool0003o000000;o00004?ooool2
o`0000[ooooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`1]ooooo`;o0000:OoooolCo`00
00;ooooo0_l00005ooooo`;o00005_ooool2o`000003ooooool0003o000000;o00003?ooool6o`00
00[ooooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`1Mooooo`?o00004Oooool2o`0001oo
oooo0_l00004ooooo`;o00000_ooool<o`0000Oooooo1?l0000Nooooo`;o00002_ooool8o`0000Ko
oooo0_l0001Looooo`007?ooool00ol0003oooooooooo`1<ooooo`Go00003?ooool3o`00017ooooo
0_l0000Oooooo`;o00001?ooool2o`0000Cooooo1?l00002ooooo`?o00001oooool5o`0001Sooooo
0_l0000?ooooo`?o00001?ooool2o`0000Kooooo0_l00005ooooo`;o0000EOooool001cooooo00?o
0000ooooooooool0B_ooool8o`0000gooooo0_l0000`ooooo`;o00001_ooool2o`0000Cooooo1?l0
00001?oooooo0000o`000?l00007ooooo`;o00006oooool2o`0000Wooooo0_l00004ooooo`Co0000
2?ooool2o`0000?ooooo0ol00002ooooo`;o0000EOooool001cooooo00?o0000ooooooooool0AOoo
ool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0000gooooo0_l0000`ooooo`;o0000
1_ooool2o`0000;ooooo1_l0000cooooo`?o00001Oooool2o`0000Sooooo1?l000001?oooooo0000
o`000?l0001Iooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00002?ooool3o`0001kooooo
0ol0000Zooooo`;o00002_ooool2o`0000Gooooo0_l000000ooooooo0000o`00000Rooooo`;o0000
4Oooool2o`0005gooooo000Looooo`03o`000?oooooooooo04oooooo0ol0000@ooooo`;o00001_oo
ool2o`0000Cooooo0ol00004ooooo`;o00008oooool2o`0000;ooooo0ol00005ooooo`Co00001?oo
ool2o`000003ooooool0003o000001kooooo0_l0001dooooo`007?ooool00ol0003oooooooooo`1?
ooooo`?o00003oooool3o`0000?ooooo0_l000000ooooooo0000o`00000;ooooo`;o00008oooool2
o`0000;ooooo0ol000000ooooooo0000o`000002ooooo`Co00001Oooool2o`00023ooooo0_l00006
ooooo`;o00003oooool2o`0005_ooooo000Looooo`03o`000?oooooooooo04oooooo0_l00003oooo
o`;o00002oooool2o`0000Cooooo0_l0000Eooooo`;o00008_ooool5o`0000[ooooo0_l00005oooo
o`?o00002_ooool2o`0000Sooooo1?l00008ooooo`;o00003oooool2o`0005_ooooo000Looooo`03
o`000?oooooooooo05Cooooo0ol000000ooooooo0000o`00000;ooooo`;o00003Oooool2o`0000Go
oooo0_l000000ooooooo0000o`00000Rooooo`;o000000?oooooo`000?l000004Oooool3o`0000[o
oooo0ol00005ooooo`Oo00001Oooool3o`00013ooooo0_l0001Kooooo`007?ooool00ol0003ooooo
ooooo`1<ooooo`;o00001oooool6o`0000[ooooo0_l0000=ooooo`Co00000oooool2o`0002kooooo
0ol0000Hooooo`;o00000oooool4o`0000?ooooo0_l00004ooooo`Co0000KOooool001cooooo00?o
0000ooooooooool0C?ooool2o`0000Gooooo0_l000001?oooooo0000o`000?ooool2o`0000[ooooo
0_l00008ooooo`;o00001Oooool2o`0001[ooooo0_l0000Cooooo`;o00000_ooool3o`0001gooooo
0_l0000:ooooo`?o0000Koooool001cooooo00?o0000ooooooooool0COooool2o`0000Cooooo0ol0
000?ooooo`;o00002?ooool2o`00017ooooo0_l0000=ooooo`?o00004?ooool2o`000003ooooool0
003o000000?ooooo0_l0000Looooo`?o00001oooool2o`000003ooooool0003o000000oooooo0_l0
001Oooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00001Oooool2o`0000?ooooo0_l0000F
ooooo`;o00000_ooool2o`0000;ooooo0_l00007ooooo`;o00003Oooool3o`0000;ooooo0_l0000<
ooooo`;o00001_ooool2o`0000Cooooo0_l0000>ooooo`;o00001_ooool2o`0000Sooooo0_l0000@
ooooo`Co0000Goooool001cooooo0_l0001Hooooo`Co00003oooool2o`0000Gooooo0_l00002oooo
o`;o00000_ooool2o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l000001oooool3o`00
00;ooooo0_l0000@ooooo`;o00000_ooool2o`0000Cooooo0_l0000>ooooo`;o000000?oooooo`00
0?l000000oooool2o`0000Kooooo0_l00007ooooo`;o00001Oooool2o`0000;ooooo0_l0001Qoooo
o`007?ooool00ol0003oooooooooo`1Gooooo`;o00004Oooool2o`0000gooooo0ol000000ooooooo
0000o`000002o`0000Cooooo0_l000000ooooooo0000o`00000>ooooo`Go00002oooool2o`0000Co
oooo0_l0000<ooooo`;o00001?ooool2o`000003ooooool0003o000000?ooooo0ol00005ooooo`;o
00001?ooool2o`000003ooooool0003o000000Gooooo0_l0001Uooooo`007?ooool00ol0003ooooo
ooooo`1Gooooo`;o00001?ooool2o`000003ooooool0003o000001Sooooo0_l000000ooooooo0000
o`00000>ooooo`?o00002?ooool5o`00017ooooo0_l0000;ooooo`?o00001?ooool2o`0000Oooooo
0ol00009ooooo`?o000000?oooooo`000?l00000K?ooool001cooooo00?o0000ooooooooool0Eooo
ool3o`0000?ooooo0_l000000ooooooo0000o`000008ooooo`Co00003oooool2o`0000Kooooo0_l0
0006ooooo`?o00001oooool2o`0001;ooooo0_l0000>ooooo`;o00003oooool2o`0000Wooooo0_l0
001`ooooo`007?ooool00ol0003oooooooooo`1Booooo`;o00001?ooool2o`0000?ooooo1?l00005
ooooo`;o00000_ooool4o`0000;ooooo0_l00003ooooo`;o00001?ooool2o`0000Sooooo0_l00003
ooooo`;o00002oooool2o`0000Gooooo0_l0000;ooooo`;o00003Oooool2o`0000?ooooo0_l0000D
ooooo`;o00003_ooool2o`0006;ooooo000Looooo`03o`000?oooooooooo05;ooooo0_l00004oooo
o`;o00001?ooool3o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o00001?ooool2o`00
00?ooooo0_l00004ooooo`?o000000Coooooo`000?l0003o00002?ooool7o`0000[ooooo0_l00000
0ooooooo0000o`000004ooooo`;o00002oooool4o`0000Gooooo0_l00003ooooo`;o00005?ooool2
o`0000kooooo0_l0001Rooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o00002?ooool2o`00
00Kooooo0_l0000@ooooo`;o000000Coooooo`000?l0003o00001Oooool2o`0000;ooooo2_l00006
ooooo`;o00001oooool2o`0000_ooooo1?l00005ooooo`;o00001?ooool3o`0000Cooooo0_l0000B
ooooo`;o0000K?ooool001cooooo00?o0000ooooooooool0G_ooool2o`0001gooooo0_l00004oooo
o`;o00000_ooool2o`0000Sooooo1?l0000:ooooo`;o00000_ooool2o`0000[ooooo0_l0000;oooo
o`;o00000_ooool3o`0000Cooooo0_l00007ooooo`;o00002Oooool2o`0006cooooo000Looooo`03
o`000?oooooooooo05kooooo0_l0000=ooooo`;o00003_ooool2o`0000Cooooo0_l0000Fooooo`;o
00000_ooool2o`0000;ooooo0_l0000:ooooo`;o00002oooool2o`0000Sooooo0_l00002ooooo`;o
00001?ooool2o`0007Oooooo000Looooo`03o`000?oooooooooo06gooooo0_l0000<ooooo`;o0000
1_ooool2o`0001Kooooo0_l0000Aooooo`;o00005_ooool2o`0000;ooooo0_l0000Aooooo`;o0000
J_ooool001cooooo00?o0000ooooooooool0Noooool2o`0000Sooooo1?l000000ooooooo0000o`00
000Mooooo`;o00000oooool4o`0000;ooooo0_l0000Qooooo`;o00001?ooool2o`0006[ooooo000L
ooooo`03o`000?oooooooooo06Kooooo0_l00002ooooo`;o00000oooool2o`0000[ooooo0_l00008
ooooo`Co000000?oooooo`000?l000000_l00003ooooo`;o00001_ooool2o`0000Gooooo0_l00004
ooooo`;o000000?oooooo`000?l000001Oooool2o`0000;ooooo0_l0000Dooooo`?o00002_ooool4
o`0000Sooooo0_l0001Tooooo`007?ooool00ol0003oooooooooo`1Vooooo`;o000000Coooooo`00
0?l0003o00000_ooool3o`0001Kooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l00006
ooooo`;o00001Oooool2o`0000;ooooo1?l00008ooooo`;o00000_ooool2o`0000[ooooo1?l00006
ooooo`?o00003?ooool4o`0000Kooooo0_l0001Tooooo`007?ooool00ol0003oooooooooo`1Yoooo
o`?o00000_ooool3o`0000Sooooo1?l00003ooooo`;o00000_ooool2o`000004ooooool0003o0000
ooooo`?o00003?ooool2o`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l000002_ooool2
o`0000_ooooo1?l0000Gooooo`?o0000Joooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Ooo
ool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo06[ooooo
0_l00002ooooo`?o00002?ooool4o`0000?ooooo0ol000000ooooooo0000o`000004ooooo`?o0000
3?ooool3o`0000Kooooo0_l00003ooooo`;o00002_ooool2o`0000Wooooo0_l0000>ooooo`;o0000
3?ooool2o`0006_ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1Wooooo`;o00001Oooool3o`00
00Cooooo0_l00002ooooo`?o00000_ooool2o`000003ooooool0003o000000Oooooo0_l0000>oooo
o`Co000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00001_ooool2o`0000kooooo0ol00009
ooooo`;o00000_ooool2o`0007Wooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo
00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo06Oooooo0_l00005
ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l00002ooooo`;o00007?ooool2
o`000003ooooool0003o000000Gooooo0_l00006ooooo`;o00001?ooool3o`0000Sooooo0_l00003
ooooo`;o00001?ooool2o`0000;ooooo0_l00004ooooo`;o00000oooool2o`0006kooooo00000ooo
oooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06
ooooo`?o0000JOooool2o`0000Kooooo0_l00009ooooo`?o00003_ooool2o`0000Cooooo0_l00003
ooooo`;o00006_ooool3o`0000Cooooo0_l00007ooooo`;o00001oooool2o`0000Gooooo0_l00003
ooooo`;o0000K_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Oo<
c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0JOooool2o`0000Wooooo0_l00003
ooooo`;o000000Coooooo`000?l0003o00002?ooool4o`0000;ooooo1?l00002ooooo`;o00000ooo
ool2o`00027ooooo0_l0000@ooooo`;o0000N_ooool00003ooooool@413ooooo00;ooooo00?o410@
ooooooooool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0M?oo
ool3o`0000;ooooo0ol000000ooooooo0000o`000007ooooo`Go000000?oooooo`000?l000000ol0
0004ooooo`;o00001Oooool4o`0003Kooooo0_l00005ooooo`;o0000J_ooool00006oooooomgMgOo
V9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000oooooooo
ool0Joooool2o`0000Sooooo0_l00003ooooo`;o000000?oooooo`000?l000001oooool2o`0000Co
oooo0_l00002ooooo`?o00000_ooool2o`0000Gooooo1?l0000Hooooo`;o00004Oooool2o`0000Wo
oooo0_l00005ooooo`;o0000J_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnY
ZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0Joooool2o`0000Oooooo0ol0000@
ooooo`;o000000?oooooo`000?l000001?ooool3o`0000Wooooo0_l000000ooooooo0000o`00000B
ooooo`;o00000oooool2o`0000Wooooo0_l00006ooooo`;o0000O?ooool001cooooo00?o0000oooo
ooooool0KOooool2o`0000Gooooo0_l00007ooooo`;o00002?ooool2o`000003ooooool0003o0000
00Gooooo0_l00005ooooo`?o00001?ooool2o`0000kooooo0_l00002ooooo`;o00000oooool2o`00
0003ooooool0003o000000Kooooo0_l00007ooooo`Co00002Oooool2o`0006kooooo000Looooo`03
o`000?oooooooooo06gooooo0_l0000>ooooo`;o00001oooool2o`0000Cooooo0_l00003ooooo`;o
00001Oooool3o`0000;ooooo0_l00004ooooo`;o00002_ooool2o`0000Sooooo1?l0000?ooooo`Co
00002Oooool2o`0006kooooo000Looooo`03o`000?oooooooooo08Kooooo1Ol000000ooooooo0000
o`00000:ooooo`;o00000oooool3o`0000?ooooo0_l0000Dooooo`;o0000S_ooool001cooooo00?o
0000ooooooooool0M_ooool3o`0000kooooo1?l0000Cooooo`;o00000oooool2o`0000Oooooo0_l0
0009ooooo`Co0000S_ooool001cooooo00?o0000ooooooooool0L_ooool2o`0000;ooooo0ol00005
ooooo`;o00004_ooool2o`000003ooooool0003o000000Sooooo0_l00002ooooo`;o00000oooool6
o`0000Sooooo0ol0000?ooooo`;o00001_ooool2o`0007Oooooo000Looooo`03o`000?oooooooooo
07;ooooo0_l00007ooooo`;o000000?oooooo`000?l000001_ooool2o`0000[ooooo0_l000001?oo
oooo0000o`000?l00007ooooo`;o000000?oooooo`000?l000000oooool5o`0000[ooooo0_l00008
ooooo`;o00001Oooool5o`0000Cooooo0_l0001gooooo`007?ooool00ol0003oooooooooo`1eoooo
o`;o00001?ooool2o`0000Wooooo0ol00003ooooo`;o00001_ooool4o`0000[ooooo0_l00003oooo
o`;o000000Coooooo`000?l0003o00001oooool2o`0000Gooooo1ol00005ooooo`;o000000?ooooo
o`000?l00000OOooool001cooooo00?o0000ooooooooool0MOooool2o`0000[ooooo0_l000001?oo
oooo0000o`000?ooool2o`0000?ooooo0_l00006ooooo`;o00000oooool4o`0000Sooooo0_l00000
1?oooooo0000o`000?ooool2o`0000Oooooo0_l00005ooooo`Oo0000Qoooool001cooooo00?o0000
ooooooooool0Noooool2o`0000Cooooo1Ol0000Cooooo`Co00002?ooool2o`000003ooooool0003o
000001Kooooo0_l00027ooooo`007?ooool00ol0003oooooooooo`1kooooo`;o00001_ooool2o`00
027ooooo0_l000000ooooooo0000o`00000Eooooo`;o0000Qoooool001cooooo00?o0000oooooooo
ool0R_ooool2o`0001[ooooo0_l000000ooooooo0000o`00000Booooo`;o0000R_ooool001cooooo
0_l0002;ooooo`;o000000?oooooo`000?l000002oooool2o`0001Wooooo0_l00006ooooo`;o0000
R_ooool001cooooo00?o0000ooooooooool0SOooool3o`000003ooooool0003o000000Oooooo0_l0
000Iooooo`;o0000T_ooool001cooooo00?o0000ooooooooool0S_ooool5o`0001Kooooo0_l00004
ooooo`;o00000oooool4o`00097ooooo000Looooo`03o`000?oooooooooo08oooooo0_l000000ooo
oooo0000o`00000Eooooo`;o00001?ooool2o`0000?ooooo1?l0002Aooooo`007?ooool00ol0003o
ooooooooo`2Booooo`;o0000]Oooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`004_oo
ool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000oooo
ooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`00
5?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_oo
ool001Cooooo00?o0000ooooooooool0oooooomBooooo`004_ooool00omEEEGoIVIVo`00003ooooo
oeCooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Uooooo`04oa0@4?l0003o
0000ooooo`;o000000?o410@ooooooooool05Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo
00Goc<c<ob4Q8Ol0003o8B4Qolc<c005ooooo`;o000000?o410@ooooooooool0S_ooool00:Kooooo
00Go0000ooooooooooooooooo`000009ooooo`Ko00002Oooool01OmEEEGoMgMgoooooonHV9So8B4Q
00?ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo08oooooo002Voooo
o`05o`000?ooooooooooooooool000006?ooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`Go0000T?ooool00:Kooooo00Go0000oooooooooooooooo
o`000009ooooo`Ko00002Oooool01Ol0003oV9RHoooooonHV9So8B4Q00?ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P03ooooo`04odA4A?oMgMgoooooo`00097ooooo002Vooooo`05o`000?n7QhOooooo
ojVYZOl000006?ooool01Ol0003oEEEEo`000?l@413oc<c<00?ooooo00Goc<c<o`000?l0003o0000
olc<c003ooooo`04omgMgOmEEEGoooooo`00097ooooo002Uooooo`03oa0@4?l0003oMgMg00;o0000
00?oV9RHooooooooool05_ooool00omEEEGoQhN7ooooo`05ooooo`05oa0@4?nj^[[ooooookZj^_l@
41001?ooool00omgMgOoc<c<o`00002Aooooo`00`oooool00ooMgMgo410@oiRHV005ooooo`05o`00
0?nj^[[ooooookZj^_l000001?ooool00oo^k^koA4A4o`00002Aooooo`00a?ooool01?o<c<coA4A4
o`000?l@4103ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01Oooool00omgMgOo0000ooooo`2@oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(690) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.4278 .30618 Mdot
.39683 .33795 Mdot
.44806 .62496 Mdot
.65179 .43416 Mdot
.57687 .61703 Mdot
.46781 .65535 Mdot
.37405 .53375 Mdot
.35631 .51785 Mdot
.45394 .64758 Mdot
.44477 .24053 Mdot
.40353 .54241 Mdot
.61268 .51262 Mdot
.37225 .54561 Mdot
.58931 .44174 Mdot
.19417 .54098 Mdot
.59739 .37881 Mdot
.39517 .36336 Mdot
.68812 .62296 Mdot
.58449 .38108 Mdot
.46319 .62532 Mdot
.40272 .4071 Mdot
.596 .44258 Mdot
.39333 .33818 Mdot
.59163 .44129 Mdot
.62049 .40704 Mdot
.42188 .32958 Mdot
.42883 .30173 Mdot
.62991 .42868 Mdot
.58675 .41086 Mdot
.39694 .56431 Mdot
.5889 .65195 Mdot
.18044 .63873 Mdot
.6409 .38454 Mdot
.68922 .33283 Mdot
.34713 .55721 Mdot
.57339 .79966 Mdot
.44728 .66877 Mdot
.38283 .51664 Mdot
.34652 .53225 Mdot
.35112 .55097 Mdot
.35946 .55345 Mdot
.41563 .33033 Mdot
.39553 .58207 Mdot
.38448 .60789 Mdot
.65428 .44723 Mdot
.263 .4406 Mdot
.69907 .68517 Mdot
.62888 .43131 Mdot
.42931 .31314 Mdot
.48305 .64429 Mdot
.75225 .34936 Mdot
.38159 .51429 Mdot
.23788 .52186 Mdot
.11627 .39996 Mdot
.37892 .56548 Mdot
.6465 .4335 Mdot
.46651 .68244 Mdot
.62347 .4572 Mdot
.6165 .43922 Mdot
.6865 .30957 Mdot
.59775 .41641 Mdot
.65758 .63787 Mdot
.41152 .29688 Mdot
.45193 .61569 Mdot
.45916 .6519 Mdot
.37582 .57258 Mdot
.41538 .37544 Mdot
.36437 .54279 Mdot
.54589 .45979 Mdot
.46794 .63281 Mdot
.63273 .43447 Mdot
.40363 .5394 Mdot
.42019 .38336 Mdot
.57998 .39714 Mdot
.30468 .44157 Mdot
.27463 .54665 Mdot
.62574 .64376 Mdot
.59319 .31563 Mdot
.50615 .17553 Mdot
.3077 .59787 Mdot
.58403 .43293 Mdot
.4735 .1533 Mdot
.20872 .54231 Mdot
.39848 .35218 Mdot
.71016 .3861 Mdot
.37262 .74645 Mdot
.57162 .41967 Mdot
.52926 .55382 Mdot
.66885 .46701 Mdot
.37925 .42908 Mdot
.45193 .65296 Mdot
.42003 .32129 Mdot
.65666 .44319 Mdot
.56407 .42966 Mdot
.59342 .22879 Mdot
.66814 .41998 Mdot
.64693 .45113 Mdot
.45521 .31793 Mdot
.39871 .54773 Mdot
.6234 .50156 Mdot
.37115 .60592 Mdot
.25174 .50882 Mdot
.64382 .4086 Mdot
.46541 .64211 Mdot
.38322 .32569 Mdot
.65905 .43034 Mdot
.37481 .56919 Mdot
.59674 .42561 Mdot
.42483 .57635 Mdot
.41045 .31352 Mdot
.56437 .43259 Mdot
.67639 .60733 Mdot
.33169 .41988 Mdot
.44604 .34117 Mdot
.33253 .25217 Mdot
.60462 .42134 Mdot
.60575 .44295 Mdot
.39859 .34253 Mdot
.47543 .69104 Mdot
.50375 .54333 Mdot
.40659 .37585 Mdot
.34739 .54025 Mdot
.40009 .31449 Mdot
.61067 .48866 Mdot
.48664 .68539 Mdot
.24958 .51374 Mdot
.25214 .49413 Mdot
.80079 .57886 Mdot
.58079 .39982 Mdot
.20747 .49931 Mdot
.47877 .66743 Mdot
.40791 .32819 Mdot
.36547 .54744 Mdot
.59629 .47981 Mdot
.42518 .36874 Mdot
.36935 .5208 Mdot
.6574 .60214 Mdot
.54759 .70574 Mdot
.45039 .34291 Mdot
.53006 .51609 Mdot
.34002 .53585 Mdot
.35267 .55423 Mdot
.76572 .38846 Mdot
.40043 .34921 Mdot
.66003 .61276 Mdot
.36734 .52311 Mdot
.75749 .51513 Mdot
.60059 .48016 Mdot
.77981 .43582 Mdot
.52706 .15122 Mdot
.76026 .36541 Mdot
.24456 .3577 Mdot
.65646 .64793 Mdot
.36032 .52349 Mdot
.64082 .41499 Mdot
.41447 .35243 Mdot
.41091 .34436 Mdot
.56268 .44748 Mdot
.61169 .40982 Mdot
.59991 .47071 Mdot
.57213 .45702 Mdot
.66207 .73068 Mdot
.59167 .46826 Mdot
.4517 .5713 Mdot
.44044 .36617 Mdot
.60774 .40346 Mdot
.43209 .65663 Mdot
.55291 .41746 Mdot
.3839 .51742 Mdot
.62101 .44415 Mdot
.62251 .41377 Mdot
.65087 .40272 Mdot
.3559 .54753 Mdot
.27693 .7403 Mdot
.44167 .18823 Mdot
.45981 .79382 Mdot
.27303 .33899 Mdot
.47383 .67664 Mdot
.57715 .44388 Mdot
.64577 .62643 Mdot
.70521 .41671 Mdot
.61322 .43543 Mdot
.72698 .31021 Mdot
.61951 .41797 Mdot
.52122 .34922 Mdot
.69429 .42649 Mdot
.42593 .80504 Mdot
.40732 .48429 Mdot
.58696 .41417 Mdot
.49683 .20807 Mdot
.79102 .43751 Mdot
.61707 .63459 Mdot
.37161 .56333 Mdot
.44039 .68117 Mdot
.45677 .68463 Mdot
.36974 .5818 Mdot
.60322 .49629 Mdot
.44471 .24896 Mdot
.56504 .48474 Mdot
.24377 .51403 Mdot
.37529 .33094 Mdot
.67179 .65095 Mdot
.44891 .33142 Mdot
.40642 .16547 Mdot
.47486 .42235 Mdot
.39981 .50801 Mdot
.68581 .61283 Mdot
.44137 .63052 Mdot
.23507 .51346 Mdot
.64762 .61991 Mdot
.64197 .4518 Mdot
.42444 .31463 Mdot
.79214 .43251 Mdot
.65259 .37812 Mdot
.76496 .71133 Mdot
.40591 .36445 Mdot
.46918 .51485 Mdot
.36985 .55822 Mdot
.49515 .66733 Mdot
.57666 .41436 Mdot
.60039 .46502 Mdot
.41568 .29788 Mdot
.62328 .42847 Mdot
.3858 .41323 Mdot
.62661 .41755 Mdot
.45541 .6128 Mdot
.62547 .60137 Mdot
.39644 .59039 Mdot
.80806 .55951 Mdot
.43195 .3862 Mdot
.49539 .59087 Mdot
.44901 .63456 Mdot
.38806 .27004 Mdot
.40511 .54988 Mdot
.66092 .60045 Mdot
.44049 .6591 Mdot
.63083 .6214 Mdot
.63771 .40065 Mdot
.44755 .662 Mdot
.67674 .62794 Mdot
.52122 .71656 Mdot
.65062 .44713 Mdot
.73139 .50306 Mdot
.37483 .52905 Mdot
.43371 .30494 Mdot
.59742 .41541 Mdot
.25811 .49566 Mdot
.57444 .47875 Mdot
.19875 .51205 Mdot
.25889 .51439 Mdot
.2447 .52154 Mdot
.27417 .57277 Mdot
.64004 .63502 Mdot
.26329 .39835 Mdot
.48906 .4774 Mdot
.40065 .37088 Mdot
.65682 .44897 Mdot
.34362 .78908 Mdot
.36483 .5253 Mdot
.64098 .45123 Mdot
.38462 .75498 Mdot
.3678 .52356 Mdot
.61618 .45537 Mdot
.3597 .55885 Mdot
.41171 .34995 Mdot
.50384 .57097 Mdot
.38674 .33781 Mdot
.64755 .44014 Mdot
.38838 .55211 Mdot
.43964 .67247 Mdot
.42277 .33126 Mdot
.6012 .42731 Mdot
.58042 .44403 Mdot
.23629 .5096 Mdot
.60096 .40298 Mdot
.36562 .7887 Mdot
.63178 .43133 Mdot
.43731 .63211 Mdot
.66927 .42678 Mdot
.79625 .39523 Mdot
.55135 .69945 Mdot
.43428 .37544 Mdot
.25677 .51743 Mdot
.45394 .6622 Mdot
.55789 .62452 Mdot
.6142 .57584 Mdot
.59001 .43043 Mdot
.24928 .50064 Mdot
.46641 .53278 Mdot
.38067 .57226 Mdot
.66738 .46411 Mdot
.42735 .43124 Mdot
.44335 .64583 Mdot
.23785 .51333 Mdot
.69021 .43742 Mdot
.3847 .32525 Mdot
.64729 .42888 Mdot
.4445 .66547 Mdot
.40561 .30919 Mdot
.60481 .48305 Mdot
.69247 .70267 Mdot
.25846 .50041 Mdot
.37272 .52946 Mdot
.57771 .51632 Mdot
.60502 .47513 Mdot
.45965 .69006 Mdot
.41444 .36264 Mdot
.38949 .56238 Mdot
.43551 .32819 Mdot
.8033 .45085 Mdot
.28022 .34588 Mdot
.55431 .7757 Mdot
.69025 .62286 Mdot
.17406 .4574 Mdot
.47842 .79416 Mdot
.28791 .37327 Mdot
.77591 .59048 Mdot
.55323 .82765 Mdot
.43447 .65718 Mdot
.7339 .45119 Mdot
.45797 .6726 Mdot
.63848 .40763 Mdot
.46427 .65228 Mdot
.39733 .81416 Mdot
.6281 .42445 Mdot
.4729 .68047 Mdot
.63992 .73251 Mdot
.60488 .41103 Mdot
.44657 .35561 Mdot
.16944 .5651 Mdot
.37728 .25202 Mdot
.49508 .43397 Mdot
.4772 .68301 Mdot
.67521 .26388 Mdot
.61555 .41942 Mdot
.61296 .37453 Mdot
.41825 .34857 Mdot
.66606 .4707 Mdot
.68069 .63882 Mdot
.63679 .60725 Mdot
.7575 .41654 Mdot
.34559 .25861 Mdot
.5287 .41386 Mdot
.42 .33474 Mdot
.51636 .17514 Mdot
.30409 .44437 Mdot
.2445 .4902 Mdot
.34434 .53194 Mdot
.27481 .73664 Mdot
.62411 .36174 Mdot
.54773 .52437 Mdot
.40224 .43856 Mdot
.41306 .31899 Mdot
.46478 .76916 Mdot
.38399 .55968 Mdot
.48019 .19729 Mdot
.50327 .29004 Mdot
.61251 .47217 Mdot
.39664 .57182 Mdot
.61358 .5091 Mdot
.38889 .42202 Mdot
.75082 .47337 Mdot
.4026 .66541 Mdot
.6507 .4421 Mdot
.27008 .40619 Mdot
.61149 .44165 Mdot
.78296 .44611 Mdot
.6437 .44606 Mdot
.43996 .33604 Mdot
.52642 .40375 Mdot
.57954 .5781 Mdot
.39347 .21443 Mdot
.46274 .42056 Mdot
.64583 .64651 Mdot
.58879 .44697 Mdot
.60899 .46986 Mdot
.66755 .64191 Mdot
.43251 .3388 Mdot
.64019 .46648 Mdot
.7293 .67523 Mdot
.60786 .47415 Mdot
.39501 .52427 Mdot
.53858 .58918 Mdot
.45063 .28646 Mdot
.56728 .4247 Mdot
.39716 .31221 Mdot
.36676 .56572 Mdot
.35018 .52199 Mdot
.55698 .38358 Mdot
.3579 .52897 Mdot
.64301 .42584 Mdot
.52818 .58188 Mdot
.39581 .32772 Mdot
.67929 .48248 Mdot
.43418 .34548 Mdot
.60546 .19819 Mdot
.3588 .56278 Mdot
.23131 .4956 Mdot
.67796 .51633 Mdot
.38096 .54653 Mdot
.36307 .28005 Mdot
.59649 .36244 Mdot
.54426 .43082 Mdot
.36862 .26764 Mdot
.45501 .69378 Mdot
.22591 .50684 Mdot
.38508 .56523 Mdot
.6008 .47247 Mdot
.6521 .41279 Mdot
.40936 .55293 Mdot
.62139 .24929 Mdot
.58728 .65829 Mdot
.64307 .44287 Mdot
.43837 .33743 Mdot
.4106 .32761 Mdot
.62147 .48198 Mdot
.61227 .43153 Mdot
.43166 .64175 Mdot
.24921 .49827 Mdot
.23763 .5182 Mdot
.24954 .49322 Mdot
.492 .69485 Mdot
.18694 .4257 Mdot
.35245 .55317 Mdot
.20375 .44475 Mdot
.31344 .70139 Mdot
.56984 .37908 Mdot
.45635 .69085 Mdot
.6056 .46018 Mdot
.62653 .39842 Mdot
.39166 .55468 Mdot
.25924 .30357 Mdot
.5285 .44777 Mdot
.44892 .3246 Mdot
.40698 .53667 Mdot
.70195 .45269 Mdot
.32966 .50088 Mdot
.68149 .62798 Mdot
.4816 .41089 Mdot
.40118 .56892 Mdot
.42804 .31936 Mdot
.40859 .56006 Mdot
.60668 .47069 Mdot
.55552 .43549 Mdot
.40082 .32547 Mdot
.63832 .63196 Mdot
.66083 .42761 Mdot
.61581 .45419 Mdot
.80873 .36553 Mdot
.30105 .43569 Mdot
.32532 .51121 Mdot
.61502 .39938 Mdot
.54103 .41814 Mdot
.63801 .64006 Mdot
.61921 .47517 Mdot
.57517 .41727 Mdot
.3336 .40965 Mdot
.36555 .58193 Mdot
.62612 .6416 Mdot
.46326 .20317 Mdot
.40981 .36604 Mdot
.37105 .78146 Mdot
.2535 .50973 Mdot
.37856 .5895 Mdot
.49563 .56581 Mdot
.22967 .5014 Mdot
.33341 .69907 Mdot
.4246 .77678 Mdot
.2362 .49499 Mdot
.4244 .66893 Mdot
.65251 .35426 Mdot
.57492 .46533 Mdot
.62175 .4473 Mdot
.64403 .61983 Mdot
.40485 .35254 Mdot
.44108 .50893 Mdot
.51675 .69452 Mdot
.59962 .44254 Mdot
.46922 .36544 Mdot
.39646 .77423 Mdot
.2332 .5094 Mdot
.64628 .63723 Mdot
.6656 .65579 Mdot
.6096 .44346 Mdot
.3126 .37517 Mdot
.41993 .33151 Mdot
.60119 .42752 Mdot
.57314 .45182 Mdot
.47421 .68833 Mdot
.4315 .31841 Mdot
.44986 .63381 Mdot
.26103 .51172 Mdot
.64672 .79628 Mdot
.81703 .38178 Mdot
.38911 .53909 Mdot
.46885 .7824 Mdot
.37492 .50924 Mdot
.35283 .6176 Mdot
.24625 .49446 Mdot
.59929 .43391 Mdot
.43315 .38406 Mdot
.59842 .425 Mdot
.62968 .46886 Mdot
.64172 .45891 Mdot
.52844 .41651 Mdot
.73397 .31675 Mdot
.6546 .62313 Mdot
.53886 .41705 Mdot
.43753 .68222 Mdot
.41589 .79436 Mdot
.18039 .60292 Mdot
.58904 .45623 Mdot
.60502 .44576 Mdot
.42204 .37387 Mdot
.58219 .39144 Mdot
.39186 .56839 Mdot
.40124 .35662 Mdot
.65362 .41751 Mdot
.5021 .74857 Mdot
.6155 .47803 Mdot
.49348 .79293 Mdot
.40927 .55804 Mdot
.48587 .40564 Mdot
.53895 .43579 Mdot
.23795 .49399 Mdot
.22586 .50511 Mdot
.25008 .48871 Mdot
.38329 .57493 Mdot
.46876 .68823 Mdot
.5082 .70188 Mdot
.67299 .47254 Mdot
.64061 .41694 Mdot
.54341 .43429 Mdot
.49745 .68424 Mdot
.53448 .57428 Mdot
.24743 .36701 Mdot
.68696 .39519 Mdot
.45374 .69829 Mdot
.46084 .34087 Mdot
.32636 .23874 Mdot
.40638 .35975 Mdot
.62269 .63307 Mdot
.39115 .52343 Mdot
.68326 .62966 Mdot
.70159 .28599 Mdot
.40094 .32228 Mdot
.42023 .29691 Mdot
.47401 .67896 Mdot
.43184 .48653 Mdot
.0884 .50326 Mdot
.47621 .6531 Mdot
.75472 .63896 Mdot
.42038 .34401 Mdot
.61579 .38558 Mdot
.46476 .53824 Mdot
.44166 .49154 Mdot
.46491 .67097 Mdot
.58195 .43508 Mdot
.337 .29564 Mdot
.43337 .63863 Mdot
.66892 .45261 Mdot
.48256 .68089 Mdot
.35748 .54575 Mdot
.4803 .67108 Mdot
.4571 .36626 Mdot
.6301 .39757 Mdot
.09843 .43848 Mdot
.32525 .48912 Mdot
.59524 .41808 Mdot
.40167 .52971 Mdot
.71417 .70599 Mdot
.62302 .46718 Mdot
.68197 .63889 Mdot
.46206 .70457 Mdot
.61795 .71673 Mdot
.61039 .41814 Mdot
.46643 .66123 Mdot
.45307 .32694 Mdot
.33074 .56374 Mdot
.28981 .5686 Mdot
.23131 .51498 Mdot
.4131 .35633 Mdot
.25635 .48634 Mdot
.35146 .5686 Mdot
.66084 .41632 Mdot
.5773 .45793 Mdot
.4437 .354 Mdot
.2744 .60465 Mdot
.64237 .39189 Mdot
.58413 .43311 Mdot
.44396 .63162 Mdot
.49077 .70959 Mdot
.21583 .6064 Mdot
.43393 .65946 Mdot
.54056 .41837 Mdot
.44381 .35054 Mdot
.6487 .41872 Mdot
.44442 .36325 Mdot
.65684 .44788 Mdot
.46152 .30307 Mdot
.40593 .35787 Mdot
.31097 .30209 Mdot
.58621 .40377 Mdot
.66869 .5127 Mdot
.63122 .4692 Mdot
.64427 .45185 Mdot
.46641 .70545 Mdot
.66793 .62785 Mdot
.67335 .44646 Mdot
.49943 .58194 Mdot
.63979 .61632 Mdot
.65307 .33209 Mdot
.47275 .69122 Mdot
.6499 .61014 Mdot
.7033 .54488 Mdot
.25617 .51765 Mdot
.65499 .63113 Mdot
.21427 .64335 Mdot
.39 .54193 Mdot
.39107 .33249 Mdot
.60521 .41015 Mdot
.58547 .82607 Mdot
.58827 .65272 Mdot
.23659 .50394 Mdot
.60473 .41951 Mdot
.61037 .46228 Mdot
.38184 .33625 Mdot
.43856 .15577 Mdot
.47708 .62974 Mdot
.65508 .43384 Mdot
.39576 .36268 Mdot
.51332 .15276 Mdot
.48656 .67364 Mdot
.65051 .63226 Mdot
.41222 .55303 Mdot
.41819 .40129 Mdot
.22799 .51311 Mdot
.36232 .57112 Mdot
.45569 .72364 Mdot
.68857 .26365 Mdot
.61545 .42279 Mdot
.44919 .68304 Mdot
.75847 .36128 Mdot
.64211 .49562 Mdot
.33358 .51647 Mdot
.50972 .37202 Mdot
.4148 .31959 Mdot
.40967 .54889 Mdot
.65018 .65054 Mdot
.39436 .32812 Mdot
.43235 .3368 Mdot
.35737 .5176 Mdot
.45278 .58634 Mdot
.46808 .51297 Mdot
.4053 .53771 Mdot
.36636 .42599 Mdot
.76423 .40896 Mdot
.25134 .50006 Mdot
.64674 .63911 Mdot
.80823 .44603 Mdot
.41725 .3291 Mdot
.27592 .73784 Mdot
.73654 .32279 Mdot
.64689 .451 Mdot
.67087 .61341 Mdot
.34167 .71228 Mdot
.50138 .72086 Mdot
.37234 .52265 Mdot
.54653 .57158 Mdot
.67942 .64816 Mdot
.59599 .47697 Mdot
.47419 .31474 Mdot
.58509 .40699 Mdot
.36408 .52369 Mdot
.36454 .39027 Mdot
.43632 .32295 Mdot
.35306 .57137 Mdot
.39458 .41914 Mdot
.62056 .39665 Mdot
.57801 .42129 Mdot
.79364 .50132 Mdot
.42631 .31427 Mdot
.2288 .51474 Mdot
.59027 .42522 Mdot
.62489 .45532 Mdot
.66225 .4149 Mdot
.64109 .53077 Mdot
.31199 .39872 Mdot
.65608 .43363 Mdot
.49141 .6875 Mdot
.54783 .42777 Mdot
.57806 .41765 Mdot
.38536 .34291 Mdot
.7824 .34875 Mdot
.26281 .50692 Mdot
.625 .44819 Mdot
.64181 .44365 Mdot
.34626 .53843 Mdot
.46745 .52287 Mdot
.43312 .48395 Mdot
.4667 .63544 Mdot
.76604 .57677 Mdot
.56493 .48332 Mdot
.42541 .36707 Mdot
.68263 .61398 Mdot
.60502 .38779 Mdot
.41788 .37061 Mdot
.5569 .45076 Mdot
.42874 .65047 Mdot
.24777 .49904 Mdot
.52103 .49218 Mdot
.65875 .63441 Mdot
.42841 .58286 Mdot
.22263 .45798 Mdot
.43227 .66122 Mdot
.63106 .4103 Mdot
.37098 .59377 Mdot
.45062 .63792 Mdot
.23725 .50864 Mdot
.68853 .42758 Mdot
.41311 .34228 Mdot
.4351 .32361 Mdot
.76903 .42894 Mdot
.49281 .64864 Mdot
.68903 .22584 Mdot
.35747 .54318 Mdot
.63731 .48372 Mdot
.21414 .48296 Mdot
.44107 .32999 Mdot
.80291 .47124 Mdot
.64706 .61233 Mdot
.37345 .52318 Mdot
.27138 .50862 Mdot
.422 .37145 Mdot
.44303 .3255 Mdot
.65221 .45073 Mdot
.59337 .45381 Mdot
.77565 .60086 Mdot
.78224 .43994 Mdot
.35905 .55474 Mdot
.65272 .64236 Mdot
.47674 .64071 Mdot
.61982 .3983 Mdot
.3958 .34799 Mdot
.53004 .34636 Mdot
.59569 .47225 Mdot
.43423 .63664 Mdot
.40808 .32227 Mdot
.66297 .64461 Mdot
.6657 .60519 Mdot
.64446 .45283 Mdot
.6354 .31056 Mdot
.37947 .54154 Mdot
.44719 .34678 Mdot
.37035 .30487 Mdot
.66235 .40453 Mdot
.58966 .45252 Mdot
.63779 .51077 Mdot
.36134 .57055 Mdot
.5139 .4707 Mdot
.67869 .65537 Mdot
.40687 .34269 Mdot
.59493 .4203 Mdot
.65717 .63769 Mdot
.57289 .52406 Mdot
.23729 .49687 Mdot
.48334 .67853 Mdot
.6791 .64321 Mdot
.67343 .62824 Mdot
.64328 .60941 Mdot
.26417 .72557 Mdot
.38159 .35588 Mdot
.45617 .19859 Mdot
.64515 .45906 Mdot
.76117 .4218 Mdot
.57083 .40487 Mdot
.37339 .57708 Mdot
.44134 .67945 Mdot
.62302 .47102 Mdot
.6526 .45089 Mdot
.48197 .32672 Mdot
.69905 .46624 Mdot
.41178 .40964 Mdot
.41688 .31282 Mdot
.66925 .51513 Mdot
.46338 .69497 Mdot
.50554 .13674 Mdot
.25854 .74575 Mdot
.54974 .46238 Mdot
.4511 .50941 Mdot
.40005 .35474 Mdot
.35419 .52456 Mdot
.44832 .49049 Mdot
.41315 .57073 Mdot
.40447 .33888 Mdot
.63193 .40286 Mdot
.20959 .44101 Mdot
.63509 .61397 Mdot
.59586 .46854 Mdot
.36491 .55432 Mdot
.59776 .46965 Mdot
.38353 .57792 Mdot
.44973 .40162 Mdot
.37174 .44401 Mdot
.62143 .41956 Mdot
.6491 .39684 Mdot
.5052 .42704 Mdot
.59051 .45594 Mdot
.35012 .67358 Mdot
.42852 .34746 Mdot
.33959 .27806 Mdot
.62812 .47963 Mdot
.62571 .29218 Mdot
.59133 .47256 Mdot
.27774 .61528 Mdot
.5746 .44502 Mdot
.54255 .5375 Mdot
.59862 .47872 Mdot
.5768 .44175 Mdot
.38764 .55874 Mdot
.34685 .53345 Mdot
.45286 .32791 Mdot
.22325 .50782 Mdot
.4245 .80351 Mdot
.60807 .45229 Mdot
.47973 .70641 Mdot
.23531 .47696 Mdot
.67138 .62771 Mdot
.40705 .33604 Mdot
.59003 .14693 Mdot
.36278 .56353 Mdot
.44904 .61653 Mdot
.30157 .62478 Mdot
.48967 .65051 Mdot
.41507 .60729 Mdot
.68399 .50228 Mdot
.65376 .64514 Mdot
.58984 .47278 Mdot
.67176 .3265 Mdot
.28167 .4185 Mdot
.66502 .45731 Mdot
.3367 .55763 Mdot
.71007 .42516 Mdot
.76641 .40458 Mdot
.63156 .63847 Mdot
.662 .65104 Mdot
.38439 .56363 Mdot
.45512 .62347 Mdot
.59827 .49924 Mdot
.65135 .60876 Mdot
.4416 .68445 Mdot
.22478 .49546 Mdot
.61359 .59565 Mdot
.41677 .33231 Mdot
.49735 .44825 Mdot
.2817 .46267 Mdot
.36049 .55736 Mdot
.49902 .57809 Mdot
.44829 .38966 Mdot
.38526 .31427 Mdot
.2274 .49634 Mdot
.45493 .70403 Mdot
.41205 .38172 Mdot
.65889 .42088 Mdot
.65227 .37751 Mdot
.61008 .44071 Mdot
.65586 .60946 Mdot
.57118 .44252 Mdot
.44293 .69148 Mdot
.36319 .53105 Mdot
.45015 .65111 Mdot
.38005 .53903 Mdot
.21556 .42076 Mdot
.61489 .43 Mdot
.59046 .4494 Mdot
.49083 .55202 Mdot
.44589 .32404 Mdot
.6755 .30272 Mdot
.46418 .70948 Mdot
.46304 .6803 Mdot
.6485 .41676 Mdot
.44869 .31948 Mdot
.64493 .59295 Mdot
.46198 .54974 Mdot
.57413 .44938 Mdot
.42832 .34897 Mdot
.6495 .42612 Mdot
.55472 .76831 Mdot
.34962 .45395 Mdot
.43651 .32799 Mdot
.37951 .21663 Mdot
.59618 .40131 Mdot
.6936 .37777 Mdot
.54202 .40628 Mdot
.73446 .61809 Mdot
.67227 .41782 Mdot
.40367 .36306 Mdot
.61917 .44223 Mdot
.42054 .36301 Mdot
.43887 .64037 Mdot
.35072 .54189 Mdot
.4166 .35597 Mdot
.57073 .41449 Mdot
.21918 .69117 Mdot
.36164 .55334 Mdot
.58345 .4454 Mdot
.40207 .5534 Mdot
.39285 .3567 Mdot
.43644 .31466 Mdot
.2226 .64735 Mdot
.33832 .49941 Mdot
.36344 .55736 Mdot
.642 .42195 Mdot
.30194 .48732 Mdot
.64843 .41889 Mdot
.7814 .59181 Mdot
.6433 .47603 Mdot
.66974 .42999 Mdot
.17267 .47166 Mdot
.41572 .57235 Mdot
.64611 .19082 Mdot
.51817 .70171 Mdot
.24948 .70981 Mdot
.40775 .38719 Mdot
.63146 .63836 Mdot
.45129 .77105 Mdot
.25991 .51093 Mdot
.48165 .69544 Mdot
.62257 .47147 Mdot
.45884 .29793 Mdot
.40732 .53902 Mdot
.66535 .62224 Mdot
.62061 .41869 Mdot
.42891 .63851 Mdot
.19938 .61826 Mdot
.36089 .52288 Mdot
.41442 .33109 Mdot
.44689 .32359 Mdot
.47433 .16989 Mdot
.59827 .41994 Mdot
.5942 .4477 Mdot
.38836 .52076 Mdot
.58027 .48982 Mdot
.64795 .60176 Mdot
.6059 .75212 Mdot
.36829 .56062 Mdot
.3133 .49769 Mdot
.41041 .31288 Mdot
.608 .46168 Mdot
.54763 .59499 Mdot
.28792 .70431 Mdot
.48692 .22138 Mdot
.64453 .62157 Mdot
.78386 .5479 Mdot
.40405 .36339 Mdot
.36578 .55075 Mdot
.72332 .4906 Mdot
.58346 .48268 Mdot
.61512 .46129 Mdot
.78503 .53892 Mdot
.46318 .52787 Mdot
.68845 .60237 Mdot
.59609 .38279 Mdot
.47373 .52928 Mdot
.64722 .41432 Mdot
.65079 .4115 Mdot
.55151 .46625 Mdot
.57117 .42555 Mdot
.42559 .35554 Mdot
.46538 .29413 Mdot
.47284 .66224 Mdot
.57823 .21805 Mdot
.55221 .56469 Mdot
.59558 .4097 Mdot
.62796 .40022 Mdot
.40771 .24955 Mdot
.26205 .48104 Mdot
.42643 .34366 Mdot
.42195 .2849 Mdot
.35413 .5608 Mdot
.69445 .47463 Mdot
.4982 .66544 Mdot
.50346 .38826 Mdot
.45204 .64232 Mdot
.42881 .35024 Mdot
.46346 .68613 Mdot
.35168 .5595 Mdot
.44872 .6819 Mdot
.49214 .69348 Mdot
.40025 .57435 Mdot
.41553 .30958 Mdot
.57828 .4529 Mdot
.35849 .56091 Mdot
.79534 .51061 Mdot
.65684 .60891 Mdot
.22107 .64631 Mdot
.58134 .38536 Mdot
.62384 .34262 Mdot
.69259 .70222 Mdot
.45049 .6646 Mdot
.33831 .44535 Mdot
.4061 .35783 Mdot
.67351 .6012 Mdot
.42334 .35926 Mdot
.70824 .30198 Mdot
.66804 .63875 Mdot
.22061 .64823 Mdot
.70917 .50826 Mdot
.54927 .63193 Mdot
.56091 .43397 Mdot
.46734 .32051 Mdot
.44831 .64169 Mdot
.39279 .52219 Mdot
.3685 .73834 Mdot
.58503 .3976 Mdot
.28447 .37399 Mdot
.37805 .34274 Mdot
.24959 .51915 Mdot
.36558 .54495 Mdot
.33499 .55083 Mdot
.60333 .42208 Mdot
.54751 .61648 Mdot
.66304 .4554 Mdot
.71514 .48454 Mdot
.77648 .57413 Mdot
.50287 .38134 Mdot
.64616 .42937 Mdot
.45917 .63359 Mdot
.64778 .42482 Mdot
.66203 .36536 Mdot
.76447 .38879 Mdot
.5768 .38858 Mdot
.28846 .32823 Mdot
.6362 .7097 Mdot
.39824 .33031 Mdot
.53666 .42458 Mdot
.24394 .50587 Mdot
.60654 .39908 Mdot
.68723 .80221 Mdot
.65785 .62948 Mdot
.48261 .73192 Mdot
.56615 .41952 Mdot
.59398 .42466 Mdot
.60387 .32455 Mdot
.48411 .36721 Mdot
.26956 .50884 Mdot
.62185 .46131 Mdot
.76701 .54863 Mdot
.39276 .56076 Mdot
.61964 .48496 Mdot
.61776 .44472 Mdot
.81773 .48254 Mdot
.39783 .55784 Mdot
.45079 .6739 Mdot
.25792 .51643 Mdot
.47853 .64403 Mdot
.6308 .64262 Mdot
.42716 .47183 Mdot
.79505 .45369 Mdot
.34766 .45571 Mdot
.68362 .63958 Mdot
.56614 .44362 Mdot
.68547 .36413 Mdot
.58261 .42222 Mdot
.65664 .65049 Mdot
.39784 .56378 Mdot
.42339 .35356 Mdot
.51148 .48799 Mdot
.24267 .51331 Mdot
.66878 .44585 Mdot
.63346 .63923 Mdot
.41471 .34891 Mdot
.23614 .63707 Mdot
.40226 .34612 Mdot
.38224 .55072 Mdot
.36023 .57354 Mdot
.6662 .63537 Mdot
.4251 .35818 Mdot
.48985 .67217 Mdot
.51885 .6929 Mdot
.64959 .47136 Mdot
.31955 .52484 Mdot
.45133 .37143 Mdot
.42782 .3005 Mdot
.42841 .38069 Mdot
.61548 .42681 Mdot
.46116 .51789 Mdot
.58294 .48416 Mdot
.37194 .5683 Mdot
.47959 .69125 Mdot
.77864 .43379 Mdot
.66718 .31979 Mdot
.32819 .48588 Mdot
.67286 .44198 Mdot
.57486 .42317 Mdot
.60927 .44339 Mdot
.64317 .43849 Mdot
.58673 .76339 Mdot
.61526 .43163 Mdot
.38644 .54741 Mdot
.46539 .64653 Mdot
.60079 .41779 Mdot
.24698 .50465 Mdot
.49487 .52246 Mdot
.68359 .61715 Mdot
.54525 .54196 Mdot
.25892 .73676 Mdot
.41598 .34886 Mdot
.44046 .66389 Mdot
.48537 .6853 Mdot
.6575 .60207 Mdot
.3563 .54114 Mdot
.40476 .35067 Mdot
.72185 .59826 Mdot
.63743 .61976 Mdot
.62599 .4484 Mdot
.51438 .57334 Mdot
.35656 .22499 Mdot
.56615 .4529 Mdot
.6376 .46 Mdot
.2496 .5213 Mdot
.47982 .63473 Mdot
.57563 .84455 Mdot
.44663 .53301 Mdot
.66748 .6302 Mdot
.67362 .64294 Mdot
.41762 .3806 Mdot
.66078 .47127 Mdot
.37465 .53625 Mdot
.46794 .54226 Mdot
.7341 .69118 Mdot
.36724 .75406 Mdot
.34172 .61414 Mdot
.62008 .47661 Mdot
.54488 .32619 Mdot
.65861 .45198 Mdot
.38194 .32905 Mdot
.42027 .37785 Mdot
.42365 .33853 Mdot
.38563 .55923 Mdot
.61239 .20327 Mdot
.38565 .54417 Mdot
.26081 .74034 Mdot
.39417 .34875 Mdot
.55652 .67375 Mdot
.46906 .6838 Mdot
.67321 .46996 Mdot
.65127 .64352 Mdot
.31387 .55509 Mdot
.53502 .43398 Mdot
.3072 .37388 Mdot
.45613 .6905 Mdot
.43009 .31086 Mdot
.6505 .36553 Mdot
.45031 .81676 Mdot
.40749 .46785 Mdot
.65082 .68045 Mdot
.70343 .30982 Mdot
.66701 .64159 Mdot
.45438 .22693 Mdot
.6407 .60753 Mdot
.3686 .52189 Mdot
.58335 .39851 Mdot
.57601 .40767 Mdot
.65273 .43759 Mdot
.61874 .43237 Mdot
.38719 .56532 Mdot
.63928 .47172 Mdot
.79571 .39471 Mdot
.25661 .50325 Mdot
.53692 .71677 Mdot
.67772 .61587 Mdot
.38752 .58077 Mdot
.45827 .6409 Mdot
.22202 .50429 Mdot
.81234 .54803 Mdot
.63389 .47294 Mdot
.6275 .47048 Mdot
.2478 .49133 Mdot
.57346 .48383 Mdot
.63843 .36341 Mdot
.46906 .65918 Mdot
.42838 .448 Mdot
.65966 .65453 Mdot
.68302 .62981 Mdot
.40465 .56618 Mdot
.42365 .35945 Mdot
.64353 .61837 Mdot
.45076 .62467 Mdot
.59959 .4815 Mdot
.64103 .3953 Mdot
.4522 .36988 Mdot
.73662 .32276 Mdot
.62945 .61952 Mdot
.5905 .36195 Mdot
.41585 .36564 Mdot
.37858 .34641 Mdot
.61994 .46302 Mdot
.66804 .40103 Mdot
.41749 .3025 Mdot
.67836 .6139 Mdot
.39092 .58023 Mdot
.55837 .64904 Mdot
.36223 .5277 Mdot
.40963 .35266 Mdot
.56538 .46614 Mdot
.41363 .31069 Mdot
.59965 .40162 Mdot
.3536 .15988 Mdot
.57047 .43322 Mdot
.36468 .27318 Mdot
.73995 .61926 Mdot
.4856 .67741 Mdot
.4879 .66414 Mdot
.24805 .50138 Mdot
.4101 .36485 Mdot
.60748 .38858 Mdot
.66802 .64714 Mdot
.23444 .69097 Mdot
.37717 .30712 Mdot
.46037 .70036 Mdot
.49266 .65256 Mdot
.39293 .56568 Mdot
.58327 .46708 Mdot
.60581 .45856 Mdot
.44898 .68075 Mdot
.68239 .71434 Mdot
.43122 .36511 Mdot
.5941 .44728 Mdot
.57655 .41842 Mdot
.4735 .65977 Mdot
.52063 .69277 Mdot
.47757 .37164 Mdot
.57189 .42455 Mdot
.7037 .51788 Mdot
.37825 .57659 Mdot
.63626 .42882 Mdot
.64365 .46731 Mdot
.67042 .61929 Mdot
.52745 .73674 Mdot
.76543 .39996 Mdot
.37216 .58034 Mdot
.23304 .51676 Mdot
.57583 .40178 Mdot
.46967 .68141 Mdot
.61729 .38615 Mdot
.53651 .80618 Mdot
.25685 .50996 Mdot
.60474 .43205 Mdot
.55736 .47142 Mdot
.44915 .34797 Mdot
.60199 .42932 Mdot
.49622 .35182 Mdot
.47272 .64361 Mdot
.60558 .43107 Mdot
.64014 .30768 Mdot
.3884 .56719 Mdot
.53619 .43116 Mdot
.67535 .64529 Mdot
.73442 .62732 Mdot
.2458 .45799 Mdot
.49245 .69924 Mdot
.66948 .60802 Mdot
.57151 .44521 Mdot
.44756 .62955 Mdot
.4125 .55104 Mdot
.2934 .36571 Mdot
.57211 .46426 Mdot
.35913 .53577 Mdot
.36239 .53522 Mdot
.6638 .63264 Mdot
.58854 .15906 Mdot
.56064 .47733 Mdot
.5858 .45541 Mdot
.80729 .61812 Mdot
.39631 .36981 Mdot
.58382 .45582 Mdot
.58041 .46301 Mdot
.37715 .53064 Mdot
.66555 .52996 Mdot
.35876 .33927 Mdot
.64005 .73268 Mdot
.3821 .57807 Mdot
.45337 .7097 Mdot
.44589 .63263 Mdot
.67459 .61266 Mdot
.40043 .32886 Mdot
.68234 .64712 Mdot
.4767 .67368 Mdot
.64515 .45049 Mdot
.38202 .52583 Mdot
.53052 .23803 Mdot
.38174 .51413 Mdot
.43507 .63125 Mdot
.40331 .3059 Mdot
.2072 .48607 Mdot
.84128 .60598 Mdot
.27432 .45267 Mdot
.38692 .58343 Mdot
.67147 .62716 Mdot
.44823 .55366 Mdot
.5752 .42353 Mdot
.45567 .21406 Mdot
.58896 .46288 Mdot
.70788 .31256 Mdot
.44182 .68189 Mdot
.23103 .49352 Mdot
.58465 .3972 Mdot
.7796 .54911 Mdot
.38431 .58261 Mdot
.38808 .5691 Mdot
.63438 .44387 Mdot
.38217 .54812 Mdot
.60016 .45432 Mdot
.47379 .65463 Mdot
.60354 .16861 Mdot
.57575 .43458 Mdot
.55493 .4035 Mdot
.36893 .58444 Mdot
.22048 .64635 Mdot
.44599 .70116 Mdot
.55447 .32707 Mdot
.46864 .82378 Mdot
.37949 .54534 Mdot
.54471 .39974 Mdot
.44649 .66278 Mdot
.24659 .52172 Mdot
.42565 .61904 Mdot
.59897 .46715 Mdot
.63307 .4705 Mdot
.65312 .42319 Mdot
.5786 .41926 Mdot
.44123 .22143 Mdot
.68144 .39344 Mdot
.52842 .30134 Mdot
.63118 .46843 Mdot
.39487 .27339 Mdot
.38962 .55165 Mdot
.4206 .40911 Mdot
.69674 .62223 Mdot
.63643 .46933 Mdot
.48486 .36108 Mdot
.38264 .58074 Mdot
.27791 .75034 Mdot
.39609 .56175 Mdot
.45364 .65796 Mdot
.35734 .5208 Mdot
.59937 .40311 Mdot
.41227 .32656 Mdot
.4702 .64488 Mdot
.24053 .38039 Mdot
.47817 .6984 Mdot
.59582 .41819 Mdot
.53489 .69278 Mdot
.48501 .68028 Mdot
.51161 .52856 Mdot
.40864 .32658 Mdot
.76493 .53396 Mdot
.39251 .36471 Mdot
.59704 .43184 Mdot
.59151 .4334 Mdot
.22108 .50669 Mdot
.35998 .52333 Mdot
.39393 .35646 Mdot
.80637 .36072 Mdot
.64438 .65427 Mdot
.42662 .33242 Mdot
.67577 .41412 Mdot
.45619 .52125 Mdot
.44534 .34283 Mdot
.7492 .57494 Mdot
.36173 .52404 Mdot
.41889 .38325 Mdot
.68636 .43755 Mdot
.56647 .53363 Mdot
.64831 .59817 Mdot
.42826 .65468 Mdot
.48267 .49504 Mdot
.45252 .63302 Mdot
.35353 .57409 Mdot
.46603 .61854 Mdot
.39318 .55801 Mdot
.37058 .26562 Mdot
.36626 .39037 Mdot
.39075 .59652 Mdot
.35586 .57169 Mdot
.47075 .67134 Mdot
.64278 .44039 Mdot
.57303 .58408 Mdot
.6783 .42572 Mdot
.55715 .43622 Mdot
.3676 .57188 Mdot
.40457 .3663 Mdot
.39904 .31737 Mdot
.46164 .31479 Mdot
.4413 .31963 Mdot
.45974 .63906 Mdot
.34915 .44353 Mdot
.69606 .28948 Mdot
.40446 .5501 Mdot
.40375 .51265 Mdot
.64469 .41409 Mdot
.47081 .67793 Mdot
.435 .64466 Mdot
.37083 .53137 Mdot
.51822 .21293 Mdot
.54217 .42506 Mdot
.38421 .34523 Mdot
.39388 .34746 Mdot
.44382 .34246 Mdot
.44606 .37081 Mdot
.56652 .18743 Mdot
.39252 .52193 Mdot
.40256 .35985 Mdot
.62542 .43856 Mdot
.61547 .47529 Mdot
.23657 .51562 Mdot
.67982 .62832 Mdot
.56475 .40467 Mdot
.55696 .40855 Mdot
.61756 .46366 Mdot
.48386 .6799 Mdot
.67108 .48641 Mdot
.25444 .51221 Mdot
.47528 .62676 Mdot
.4979 .67863 Mdot
.22972 .49675 Mdot
.36946 .34744 Mdot
.44095 .8249 Mdot
.6549 .43339 Mdot
.72122 .42947 Mdot
.46646 .67716 Mdot
.34324 .38262 Mdot
.51422 .46339 Mdot
.64242 .42661 Mdot
.60505 .5698 Mdot
.47411 .65196 Mdot
.37722 .32328 Mdot
.59113 .46048 Mdot
.24911 .49428 Mdot
.67976 .61113 Mdot
.68424 .43518 Mdot
.25202 .52121 Mdot
.43013 .35196 Mdot
.63973 .69452 Mdot
.40557 .37763 Mdot
.4876 .67657 Mdot
.53535 .42893 Mdot
.08434 .48784 Mdot
.44653 .64183 Mdot
.30217 .74154 Mdot
.37984 .40796 Mdot
.57412 .43175 Mdot
.44991 .63413 Mdot
.37905 .32205 Mdot
.37695 .57615 Mdot
.48521 .53237 Mdot
.39582 .34624 Mdot
.22294 .50104 Mdot
.22837 .50996 Mdot
.47252 .66075 Mdot
.41543 .31573 Mdot
.63819 .47662 Mdot
.44121 .3697 Mdot
.36062 .51745 Mdot
.62136 .41285 Mdot
.42682 .80549 Mdot
.65022 .3764 Mdot
.4164 .36706 Mdot
.44329 .62446 Mdot
.63812 .63746 Mdot
.6216 .42085 Mdot
.35611 .77277 Mdot
.58013 .46407 Mdot
.4014 .55856 Mdot
.33283 .35015 Mdot
.51493 .24015 Mdot
.64351 .44516 Mdot
.63764 .40606 Mdot
.40513 .56722 Mdot
.64511 .44585 Mdot
.56957 .45668 Mdot
.32805 .52418 Mdot
.44637 .33688 Mdot
.60572 .43977 Mdot
.43054 .65581 Mdot
.71775 .34288 Mdot
.58189 .39434 Mdot
.27727 .32575 Mdot
.77202 .54097 Mdot
.33772 .3441 Mdot
.59354 .38726 Mdot
.79921 .50764 Mdot
.58873 .43756 Mdot
.62156 .42681 Mdot
.65173 .43231 Mdot
.52393 .32565 Mdot
.47378 .67444 Mdot
.45304 .69926 Mdot
.65843 .59454 Mdot
.77202 .54763 Mdot
.66787 .61238 Mdot
.39486 .57559 Mdot
.2732 .57554 Mdot
.25596 .50444 Mdot
.42241 .36077 Mdot
.63769 .40129 Mdot
.48586 .69501 Mdot
.60553 .46345 Mdot
.61011 .40013 Mdot
.4801 .66067 Mdot
.44667 .63612 Mdot
.48793 .63886 Mdot
.63667 .61595 Mdot
.42205 .34706 Mdot
.65107 .44856 Mdot
.63936 .61759 Mdot
.62822 .48164 Mdot
.45481 .53141 Mdot
.42378 .34511 Mdot
.44324 .36755 Mdot
.38799 .33143 Mdot
.64417 .46044 Mdot
.59944 .40531 Mdot
.3849 .54245 Mdot
.45099 .3735 Mdot
.40602 .54575 Mdot
.45255 .63445 Mdot
.48724 .66716 Mdot
.59956 .46762 Mdot
.62219 .35862 Mdot
.6742 .6394 Mdot
.4525 .66228 Mdot
.25763 .49373 Mdot
.66096 .5952 Mdot
.60574 .4199 Mdot
.45576 .63464 Mdot
.68257 .63334 Mdot
.56844 .22474 Mdot
.50744 .83355 Mdot
.63536 .63502 Mdot
.6332 .44391 Mdot
.62299 .32141 Mdot
.73729 .47618 Mdot
.65115 .65759 Mdot
.40118 .54237 Mdot
.58619 .46735 Mdot
.69778 .71816 Mdot
.67144 .65467 Mdot
.74117 .33035 Mdot
.48202 .66684 Mdot
.69036 .50482 Mdot
.68496 .429 Mdot
.49684 .19865 Mdot
.67803 .65175 Mdot
.4063 .34778 Mdot
.44317 .38398 Mdot
.63116 .44795 Mdot
.68268 .65728 Mdot
.35607 .5156 Mdot
.4866 .6842 Mdot
.48723 .69956 Mdot
.42022 .31634 Mdot
.34137 .47035 Mdot
.43158 .64637 Mdot
.53116 .43936 Mdot
.42068 .65291 Mdot
.6728 .50341 Mdot
.5004 .17605 Mdot
.22804 .39556 Mdot
.64834 .4003 Mdot
.63947 .64328 Mdot
.41192 .56487 Mdot
.3839 .54426 Mdot
.38234 .5576 Mdot
.484 .6545 Mdot
.46377 .49942 Mdot
.44953 .68668 Mdot
.28442 .38759 Mdot
.65622 .63765 Mdot
.75371 .5274 Mdot
.59818 .38872 Mdot
.57472 .42914 Mdot
.60829 .48413 Mdot
.65315 .42133 Mdot
.58922 .43905 Mdot
.35987 .55503 Mdot
.48931 .65532 Mdot
.62242 .72017 Mdot
.43988 .3418 Mdot
.23193 .60757 Mdot
.46888 .68421 Mdot
.25582 .51891 Mdot
.65634 .62076 Mdot
.79128 .45819 Mdot
.46981 .71952 Mdot
.46337 .68521 Mdot
.57774 .47205 Mdot
.41271 .37304 Mdot
.62858 .53378 Mdot
.58392 .43336 Mdot
.45182 .66348 Mdot
.44252 .61887 Mdot
.46682 .22998 Mdot
.5641 .49159 Mdot
.63233 .60052 Mdot
.45569 .51745 Mdot
.68277 .65091 Mdot
.65968 .39152 Mdot
.34254 .38512 Mdot
.4754 .67181 Mdot
.4569 .65384 Mdot
.63791 .64569 Mdot
.67289 .36404 Mdot
.40797 .31997 Mdot
.23304 .49257 Mdot
.39919 .54607 Mdot
.58364 .42715 Mdot
.47984 .64883 Mdot
.7169 .42516 Mdot
.50963 .57239 Mdot
.37241 .56084 Mdot
.47689 .62885 Mdot
.5946 .47404 Mdot
.63664 .44781 Mdot
.66941 .63964 Mdot
.58187 .632 Mdot
.6808 .42451 Mdot
.25037 .71079 Mdot
.37994 .44279 Mdot
.45855 .42337 Mdot
.61474 .46108 Mdot
.42881 .31688 Mdot
.24504 .494 Mdot
.64604 .63903 Mdot
.6158 .48223 Mdot
.48092 .8343 Mdot
.46188 .36387 Mdot
.36229 .54997 Mdot
.24411 .49326 Mdot
.46848 .50214 Mdot
.57861 .46257 Mdot
.58897 .46269 Mdot
.61699 .42943 Mdot
.50102 .84261 Mdot
.4443 .68872 Mdot
.43669 .37886 Mdot
.64561 .61949 Mdot
.45081 .34241 Mdot
.45953 .70234 Mdot
.49109 .47257 Mdot
.60319 .41673 Mdot
.38352 .33666 Mdot
.40452 .34507 Mdot
.3927 .56618 Mdot
.36375 .57279 Mdot
.49955 .7066 Mdot
.57134 .43613 Mdot
.25333 .49647 Mdot
.40671 .37318 Mdot
.47241 .62902 Mdot
.66748 .63993 Mdot
.35685 .56227 Mdot
.63405 .46693 Mdot
.47309 .66544 Mdot
.66581 .43846 Mdot
.44359 .36161 Mdot
.46426 .68481 Mdot
.26204 .51706 Mdot
.67598 .63838 Mdot
.63452 .46856 Mdot
.66133 .70084 Mdot
.23727 .49301 Mdot
.5806 .40823 Mdot
.63984 .33492 Mdot
.69757 .64438 Mdot
.24204 .37505 Mdot
.43983 .67127 Mdot
.24954 .50964 Mdot
.42425 .37869 Mdot
.57805 .53243 Mdot
.45731 .64908 Mdot
.53738 .35324 Mdot
.57696 .60288 Mdot
.6501 .44593 Mdot
.42421 .3253 Mdot
.64563 .58091 Mdot
.27739 .74245 Mdot
.72624 .49958 Mdot
.59766 .44535 Mdot
.4514 .63268 Mdot
.68356 .62702 Mdot
.40483 .55596 Mdot
.27877 .32523 Mdot
.49671 .18008 Mdot
.48552 .63874 Mdot
.65749 .43975 Mdot
.40779 .37341 Mdot
.36899 .53234 Mdot
.20653 .43601 Mdot
.44825 .62529 Mdot
.43579 .6694 Mdot
.61304 .42022 Mdot
.6423 .62523 Mdot
.66702 .72804 Mdot
.44693 .69423 Mdot
.48093 .64555 Mdot
.22558 .61052 Mdot
.63027 .6226 Mdot
.62513 .44075 Mdot
.4617 .31477 Mdot
.5931 .47856 Mdot
.26009 .71193 Mdot
.25264 .50765 Mdot
.44017 .34566 Mdot
.60316 .4727 Mdot
.63288 .71122 Mdot
.45455 .64226 Mdot
.45098 .50806 Mdot
.47245 .61521 Mdot
.35674 .5486 Mdot
.47952 .64982 Mdot
.59629 .4607 Mdot
.36823 .58141 Mdot
.67511 .63657 Mdot
.57162 .42518 Mdot
.60235 .40428 Mdot
.38035 .32384 Mdot
.37474 .51984 Mdot
.72837 .3718 Mdot
.34299 .53065 Mdot
.40848 .55972 Mdot
.38114 .35839 Mdot
.62891 .44834 Mdot
.45532 .66899 Mdot
.42715 .64707 Mdot
.64342 .47031 Mdot
.34654 .38736 Mdot
.41281 .31896 Mdot
.47309 .73382 Mdot
.57558 .8421 Mdot
.57029 .48971 Mdot
.26082 .50013 Mdot
.73968 .4127 Mdot
.38351 .57278 Mdot
.64073 .454 Mdot
.42346 .36542 Mdot
.48078 .64133 Mdot
.43065 .64641 Mdot
.58777 .4807 Mdot
.36598 .52956 Mdot
.68524 .62444 Mdot
.43432 .65575 Mdot
.50399 .57008 Mdot
.60514 .42755 Mdot
.2834 .37169 Mdot
.43694 .65832 Mdot
.18076 .62476 Mdot
.62742 .71467 Mdot
.43467 .3276 Mdot
.61987 .40112 Mdot
.4501 .32499 Mdot
.64946 .61549 Mdot
.42413 .61464 Mdot
.36501 .52834 Mdot
.52214 .39134 Mdot
.82198 .45108 Mdot
.47434 .67904 Mdot
.4263 .35393 Mdot
.64601 .45561 Mdot
.52322 .39742 Mdot
.5745 .44687 Mdot
.64938 .54322 Mdot
.68472 .68087 Mdot
.35402 .56604 Mdot
.4011 .56422 Mdot
.62166 .39712 Mdot
.64313 .60687 Mdot
.43328 .67784 Mdot
.48057 .6641 Mdot
.50115 .13135 Mdot
.26092 .51883 Mdot
.76565 .61615 Mdot
.64073 .46309 Mdot
.48227 .63967 Mdot
.67218 .32123 Mdot
.38886 .52119 Mdot
.65607 .47127 Mdot
.49481 .67362 Mdot
.2774 .68757 Mdot
.45842 .53076 Mdot
.60227 .43573 Mdot
.58383 .49192 Mdot
.40127 .5523 Mdot
.44826 .54844 Mdot
.45012 .68612 Mdot
.63869 .48054 Mdot
.33904 .54276 Mdot
.21628 .62402 Mdot
.81586 .42251 Mdot
.42209 .34645 Mdot
.44295 .62298 Mdot
.35747 .55006 Mdot
.64712 .50231 Mdot
.67864 .61685 Mdot
.46997 .63545 Mdot
.48218 .69202 Mdot
.62442 .41018 Mdot
.56956 .39946 Mdot
.56306 .48565 Mdot
.4324 .34023 Mdot
.38687 .53894 Mdot
.59831 .39204 Mdot
.36152 .45958 Mdot
.65661 .42851 Mdot
.38324 .53614 Mdot
.1525 .34012 Mdot
.56761 .46107 Mdot
.5808 .45237 Mdot
.69177 .58974 Mdot
.39839 .32222 Mdot
.44704 .33083 Mdot
.36048 .44584 Mdot
.6402 .46374 Mdot
.55552 .63159 Mdot
.42059 .35002 Mdot
.41407 .3202 Mdot
.55151 .67923 Mdot
.62722 .41661 Mdot
.43029 .57797 Mdot
.37455 .53477 Mdot
.35729 .55427 Mdot
.44845 .35256 Mdot
.67419 .46835 Mdot
.41253 .55513 Mdot
.42053 .22552 Mdot
.46924 .68762 Mdot
.34208 .38467 Mdot
.43228 .37127 Mdot
.56382 .61 Mdot
.36459 .52251 Mdot
.22569 .71604 Mdot
.57014 .54088 Mdot
.66002 .45673 Mdot
.63959 .44582 Mdot
.67307 .6219 Mdot
.5624 .37938 Mdot
.2355 .51773 Mdot
.38334 .55021 Mdot
.52986 .77507 Mdot
.42365 .33749 Mdot
.57869 .4487 Mdot
.77773 .43959 Mdot
.22631 .4315 Mdot
.29664 .32308 Mdot
.39773 .33336 Mdot
.42027 .32899 Mdot
.46038 .6946 Mdot
.47769 .68804 Mdot
.61627 .43873 Mdot
.38718 .55663 Mdot
.43017 .3865 Mdot
.3912 .53719 Mdot
.47661 .6726 Mdot
.46177 .68098 Mdot
.25661 .51258 Mdot
.63876 .49287 Mdot
.48499 .6687 Mdot
.22875 .64076 Mdot
.3659 .45895 Mdot
.38553 .30864 Mdot
.83753 .60538 Mdot
.20194 .43751 Mdot
.71241 .61206 Mdot
.67538 .60605 Mdot
.24492 .52677 Mdot
.3498 .52878 Mdot
.62853 .39989 Mdot
.61515 .47021 Mdot
.23265 .50873 Mdot
.3544 .53595 Mdot
.66181 .61835 Mdot
.36012 .52282 Mdot
.64758 .63643 Mdot
.46177 .70751 Mdot
.58068 .39561 Mdot
.57259 .4549 Mdot
.36602 .56127 Mdot
.45132 .67789 Mdot
.48683 .67729 Mdot
.66158 .59707 Mdot
.78889 .4667 Mdot
.4738 .66246 Mdot
.43385 .37123 Mdot
.65685 .27025 Mdot
.22893 .50964 Mdot
.59049 .4593 Mdot
.78673 .44637 Mdot
.47142 .22095 Mdot
.65262 .4437 Mdot
.24292 .49296 Mdot
.52116 .13319 Mdot
.58094 .39846 Mdot
.49817 .15114 Mdot
.25013 .51342 Mdot
.40839 .31123 Mdot
.44434 .66007 Mdot
.2304 .51624 Mdot
.66158 .49275 Mdot
.62028 .62556 Mdot
.5779 .38858 Mdot
.39477 .3405 Mdot
.39194 .31818 Mdot
.38808 .42076 Mdot
.26452 .71506 Mdot
.64193 .6396 Mdot
.66328 .62461 Mdot
.4598 .64909 Mdot
.28043 .53692 Mdot
.65898 .39754 Mdot
.66593 .62508 Mdot
.57406 .77922 Mdot
.64546 .41627 Mdot
.78533 .57983 Mdot
.60248 .56893 Mdot
.42657 .31663 Mdot
.37453 .37577 Mdot
.4565 .64526 Mdot
.42607 .35328 Mdot
.47163 .4383 Mdot
.60843 .48396 Mdot
.42421 .34227 Mdot
.38126 .53304 Mdot
.3497 .70107 Mdot
.43985 .31501 Mdot
.4863 .54053 Mdot
.374 .5368 Mdot
.69652 .64523 Mdot
.70948 .55272 Mdot
.66791 .82566 Mdot
.38469 .55191 Mdot
.44826 .66219 Mdot
.48622 .67073 Mdot
.47352 .65744 Mdot
.39537 .34565 Mdot
.44057 .63945 Mdot
.43677 .34763 Mdot
.50994 .70971 Mdot
.80071 .48934 Mdot
.66469 .63724 Mdot
.33077 .50664 Mdot
.40927 .33749 Mdot
.30674 .41867 Mdot
.84329 .57105 Mdot
.63228 .44149 Mdot
.34083 .5381 Mdot
.64184 .6479 Mdot
.21489 .53681 Mdot
.67 .61812 Mdot
.44612 .66354 Mdot
.34091 .38379 Mdot
.60036 .45339 Mdot
.50167 .35575 Mdot
.66997 .64798 Mdot
.39628 .33903 Mdot
.57813 .41295 Mdot
.50503 .69706 Mdot
.66771 .60833 Mdot
.67965 .61161 Mdot
.58806 .44184 Mdot
.42813 .31185 Mdot
.45787 .67703 Mdot
.34745 .53825 Mdot
.68194 .59773 Mdot
.66194 .48465 Mdot
.64498 .44071 Mdot
.63346 .48588 Mdot
.43163 .48498 Mdot
.67979 .72559 Mdot
.37792 .54401 Mdot
.74877 .45733 Mdot
.4812 .67971 Mdot
.7156 .50919 Mdot
.30492 .44787 Mdot
.32923 .51126 Mdot
.25268 .50881 Mdot
.25359 .50595 Mdot
.59759 .43753 Mdot
.65685 .74676 Mdot
.33389 .28388 Mdot
.3424 .51352 Mdot
.22842 .50279 Mdot
.48662 .67807 Mdot
.45607 .37147 Mdot
.44022 .41333 Mdot
.56409 .41131 Mdot
.36205 .57123 Mdot
.47771 .66722 Mdot
.54008 .80668 Mdot
.65599 .63551 Mdot
.34127 .42907 Mdot
.59877 .41647 Mdot
.59257 .44923 Mdot
.36873 .5446 Mdot
.38431 .54231 Mdot
.27559 .3501 Mdot
.39269 .43299 Mdot
.38398 .75921 Mdot
.42806 .57581 Mdot
.56984 .8054 Mdot
.4586 .38845 Mdot
.42039 .36737 Mdot
.25941 .51386 Mdot
.40849 .56611 Mdot
.58541 .46031 Mdot
.40455 .31293 Mdot
.30048 .31979 Mdot
.38091 .36312 Mdot
.78259 .57226 Mdot
.56034 .6321 Mdot
.58837 .41491 Mdot
.4162 .37452 Mdot
.4258 .35054 Mdot
.45283 .35191 Mdot
.23112 .49645 Mdot
.61949 .46067 Mdot
.64215 .43974 Mdot
.58443 .39873 Mdot
.5456 .37986 Mdot
.60243 .42837 Mdot
.30855 .45866 Mdot
.31426 .49747 Mdot
.52551 .7567 Mdot
.65495 .44692 Mdot
.35711 .53289 Mdot
.64185 .40342 Mdot
.64809 .60295 Mdot
.6581 .44221 Mdot
.77827 .60293 Mdot
.37615 .55536 Mdot
.65951 .35794 Mdot
.41681 .65212 Mdot
.5987 .41535 Mdot
.6831 .63956 Mdot
.67513 .72808 Mdot
.78391 .42049 Mdot
.22646 .61651 Mdot
.43528 .37107 Mdot
.49301 .7083 Mdot
.3666 .51307 Mdot
.45599 .66763 Mdot
.6538 .46841 Mdot
.2602 .50233 Mdot
.17574 .44731 Mdot
.55287 .59189 Mdot
.58866 .46488 Mdot
.69076 .41983 Mdot
.43756 .32525 Mdot
.45086 .64036 Mdot
.43692 .40045 Mdot
.61963 .4275 Mdot
.64781 .61442 Mdot
.64466 .61377 Mdot
.43218 .42927 Mdot
.48697 .78542 Mdot
.6019 .53693 Mdot
.37062 .54383 Mdot
.43159 .64219 Mdot
.67731 .65183 Mdot
.37084 .26773 Mdot
.35772 .51338 Mdot
.38321 .57278 Mdot
.37732 .52147 Mdot
.58439 .41887 Mdot
.25212 .51688 Mdot
.53316 .78944 Mdot
.22243 .50558 Mdot
.59777 .41244 Mdot
.47649 .69536 Mdot
.23096 .51707 Mdot
.67175 .61652 Mdot
.40379 .5665 Mdot
.47812 .68323 Mdot
.59419 .43131 Mdot
.41724 .3465 Mdot
.7652 .43647 Mdot
.73631 .66958 Mdot
.5076 .72834 Mdot
.51157 .72584 Mdot
.38932 .34038 Mdot
.35587 .79108 Mdot
.31946 .52525 Mdot
.51236 .21278 Mdot
.63189 .58711 Mdot
.64533 .46922 Mdot
.65951 .21232 Mdot
.44733 .68225 Mdot
.46522 .64145 Mdot
.60654 .4344 Mdot
.45913 .62476 Mdot
.57715 .44814 Mdot
.457 .69563 Mdot
.31881 .74015 Mdot
.56274 .42062 Mdot
.46333 .64092 Mdot
.66171 .39818 Mdot
.61463 .41643 Mdot
.43524 .32106 Mdot
.47282 .63587 Mdot
.66221 .45205 Mdot
.16567 .45106 Mdot
.37914 .56823 Mdot
.22811 .49876 Mdot
.31469 .51235 Mdot
.36671 .51938 Mdot
.43082 .33073 Mdot
.57395 .40019 Mdot
.67137 .64043 Mdot
.4093 .34778 Mdot
.50351 .69068 Mdot
.66439 .65055 Mdot
.34908 .44606 Mdot
.43923 .3689 Mdot
.23426 .51312 Mdot
.67294 .64263 Mdot
.56383 .39422 Mdot
.47741 .65224 Mdot
.74376 .67793 Mdot
.22305 .50504 Mdot
.60432 .45857 Mdot
.42348 .65433 Mdot
.36171 .52224 Mdot
.61446 .4441 Mdot
.45135 .63161 Mdot
.235 .49443 Mdot
.58948 .40616 Mdot
.58284 .40776 Mdot
.4605 .41059 Mdot
.31936 .33856 Mdot
.67012 .63694 Mdot
.37871 .3423 Mdot
.62343 .43746 Mdot
.64185 .60715 Mdot
.3248 .61939 Mdot
.64765 .40348 Mdot
.44506 .31682 Mdot
.50614 .4091 Mdot
.4779 .68935 Mdot
.40628 .54839 Mdot
.43281 .63333 Mdot
.68126 .61235 Mdot
.82031 .36021 Mdot
.25244 .51871 Mdot
.68202 .46187 Mdot
.61516 .48522 Mdot
.43575 .60843 Mdot
.42753 .34608 Mdot
.3587 .73331 Mdot
.63668 .4668 Mdot
.68431 .40353 Mdot
.58715 .45072 Mdot
.62216 .71395 Mdot
.41016 .32012 Mdot
.58819 .45588 Mdot
.67094 .37697 Mdot
.5941 .3856 Mdot
.68511 .63395 Mdot
.74061 .53643 Mdot
.64732 .40751 Mdot
.09454 .54584 Mdot
.25036 .49187 Mdot
.47879 .65945 Mdot
.47547 .57358 Mdot
.39723 .64266 Mdot
.50648 .17343 Mdot
.4349 .34418 Mdot
.60884 .52031 Mdot
.45682 .67294 Mdot
.78092 .38927 Mdot
.3239 .77628 Mdot
.61025 .41457 Mdot
.59742 .47457 Mdot
.44613 .66348 Mdot
.47944 .63691 Mdot
.2579 .50179 Mdot
.65678 .45248 Mdot
.68854 .42611 Mdot
.45594 .61949 Mdot
.59352 .42499 Mdot
.45255 .26564 Mdot
.3481 .55704 Mdot
.44877 .34083 Mdot
.40488 .55553 Mdot
.37778 .5728 Mdot
.61265 .22443 Mdot
.37999 .44246 Mdot
.38421 .53826 Mdot
.35738 .50756 Mdot
.78155 .60367 Mdot
.50856 .4032 Mdot
.68437 .64344 Mdot
.44733 .78021 Mdot
.46645 .65252 Mdot
.62193 .46056 Mdot
.39768 .35858 Mdot
.52569 .19615 Mdot
.30894 .66961 Mdot
.33388 .3883 Mdot
.63736 .43937 Mdot
.45996 .64443 Mdot
.22874 .49639 Mdot
.56419 .41582 Mdot
.71838 .50249 Mdot
.59561 .44779 Mdot
.48838 .68142 Mdot
.64469 .23909 Mdot
.50179 .37025 Mdot
.43002 .58409 Mdot
.39721 .29024 Mdot
.60102 .39005 Mdot
.43901 .36299 Mdot
.35823 .53744 Mdot
.63808 .61353 Mdot
.67057 .62902 Mdot
.57625 .42043 Mdot
.36549 .38933 Mdot
.61217 .58097 Mdot
.61628 .41818 Mdot
.62469 .41216 Mdot
.25034 .5111 Mdot
.62384 .41233 Mdot
.62155 .48417 Mdot
.61923 .39484 Mdot
.66457 .42033 Mdot
.40854 .56068 Mdot
.60731 .33581 Mdot
.66039 .42215 Mdot
.58552 .50034 Mdot
.35594 .56511 Mdot
.65871 .50642 Mdot
.3952 .56146 Mdot
.43853 .80196 Mdot
.39742 .55208 Mdot
.66951 .63147 Mdot
.43255 .68149 Mdot
.66718 .51326 Mdot
.42655 .38603 Mdot
.36706 .57579 Mdot
.65066 .62826 Mdot
.38363 .55441 Mdot
.43479 .67326 Mdot
.81397 .62357 Mdot
.38729 .3708 Mdot
.45458 .54005 Mdot
.60279 .5553 Mdot
.28249 .36952 Mdot
.46934 .69106 Mdot
.42198 .31756 Mdot
.49636 .35618 Mdot
.61308 .39444 Mdot
.676 .63281 Mdot
.59654 .43902 Mdot
.40721 .56114 Mdot
.4644 .64818 Mdot
.53085 .69887 Mdot
.67177 .6348 Mdot
.84127 .46273 Mdot
.48154 .69769 Mdot
.55627 .446 Mdot
.35757 .56946 Mdot
.83915 .59668 Mdot
.39868 .55414 Mdot
.8016 .48094 Mdot
.44815 .3085 Mdot
.66777 .25237 Mdot
.41504 .32951 Mdot
.30103 .30502 Mdot
.41984 .8436 Mdot
.32597 .7687 Mdot
.41262 .35483 Mdot
.46325 .7302 Mdot
.5976 .41996 Mdot
.65339 .41892 Mdot
.53888 .45959 Mdot
.38079 .31298 Mdot
.6185 .43367 Mdot
.23428 .51634 Mdot
.38773 .45201 Mdot
.62447 .74761 Mdot
.48709 .71371 Mdot
.57649 .45015 Mdot
.36572 .57018 Mdot
.40086 .52841 Mdot
.22594 .51361 Mdot
.35316 .52057 Mdot
.62234 .41926 Mdot
.41039 .33472 Mdot
.56492 .58862 Mdot
.65768 .61112 Mdot
.17612 .55582 Mdot
.6766 .59606 Mdot
.48808 .71729 Mdot
.5483 .46091 Mdot
.46219 .68189 Mdot
.735 .24803 Mdot
.6405 .40678 Mdot
.42113 .35292 Mdot
.58205 .41217 Mdot
.61158 .39239 Mdot
.65958 .4295 Mdot
.44275 .63163 Mdot
.47613 .58025 Mdot
.59152 .42653 Mdot
.36574 .52661 Mdot
.53033 .72082 Mdot
.55992 .40868 Mdot
.44637 .7459 Mdot
.77222 .56953 Mdot
.28835 .3855 Mdot
.39059 .30026 Mdot
.44879 .65268 Mdot
.42222 .33401 Mdot
.37632 .31627 Mdot
.43099 .33084 Mdot
.5148 .77729 Mdot
.67329 .5176 Mdot
.46775 .15311 Mdot
.65727 .29509 Mdot
.53287 .20373 Mdot
.38505 .34269 Mdot
.35095 .6504 Mdot
.41999 .36517 Mdot
.4344 .33813 Mdot
.29988 .19597 Mdot
.40971 .36336 Mdot
.6017 .46799 Mdot
.56482 .45971 Mdot
.25925 .45127 Mdot
.79192 .58566 Mdot
.65699 .44358 Mdot
.61822 .4361 Mdot
.63873 .6319 Mdot
.6252 .35645 Mdot
.22009 .51348 Mdot
.35139 .41995 Mdot
.21065 .51857 Mdot
.58874 .44116 Mdot
.6113 .43302 Mdot
.67396 .46064 Mdot
.42455 .84997 Mdot
.51585 .18961 Mdot
.39263 .31992 Mdot
.69641 .46004 Mdot
.2189 .65602 Mdot
.57357 .46428 Mdot
.56771 .44799 Mdot
.59878 .402 Mdot
.45576 .67054 Mdot
.45782 .37236 Mdot
.67887 .39927 Mdot
.27137 .40795 Mdot
.60345 .41887 Mdot
.32147 .53869 Mdot
.70206 .63527 Mdot
.59687 .46184 Mdot
.4515 .34135 Mdot
.65056 .42636 Mdot
.42444 .37354 Mdot
.44877 .34767 Mdot
.65975 .48281 Mdot
.5201 .78937 Mdot
.45717 .34689 Mdot
.5965 .40889 Mdot
.45088 .67254 Mdot
.28003 .74223 Mdot
.60382 .45998 Mdot
.64163 .63357 Mdot
.64282 .45231 Mdot
.68455 .63152 Mdot
.61117 .40781 Mdot
.22283 .50195 Mdot
.50235 .24441 Mdot
.45801 .65313 Mdot
.66997 .58839 Mdot
.4654 .62338 Mdot
.48463 .40841 Mdot
.42305 .3064 Mdot
.21793 .51187 Mdot
.46472 .18019 Mdot
.24933 .51191 Mdot
.75927 .42992 Mdot
.28754 .63264 Mdot
.37075 .56804 Mdot
.44369 .37304 Mdot
.74061 .43527 Mdot
.43835 .7443 Mdot
.49515 .65244 Mdot
.49863 .67462 Mdot
.77937 .30814 Mdot
.59567 .16422 Mdot
.58674 .42875 Mdot
.73928 .70076 Mdot
.5302 .28942 Mdot
.63902 .39323 Mdot
.62229 .38248 Mdot
.48842 .68652 Mdot
.59439 .38976 Mdot
.48649 .51328 Mdot
.47122 .67233 Mdot
.65568 .62627 Mdot
.44021 .34872 Mdot
.6807 .61776 Mdot
.39685 .75546 Mdot
.35786 .4678 Mdot
.47969 .67713 Mdot
.65878 .41127 Mdot
.57961 .42797 Mdot
.42961 .37643 Mdot
.47069 .31367 Mdot
.44645 .33509 Mdot
.65139 .65 Mdot
.46502 .66366 Mdot
.49553 .19513 Mdot
.63896 .45808 Mdot
.40329 .34274 Mdot
.4074 .6085 Mdot
.6372 .44815 Mdot
.36282 .55749 Mdot
.63858 .43857 Mdot
.40679 .3557 Mdot
.6228 .41188 Mdot
.41237 .33364 Mdot
.45086 .68363 Mdot
.58688 .47237 Mdot
.61155 .43553 Mdot
.76553 .39816 Mdot
.66115 .6175 Mdot
.41878 .30703 Mdot
.48476 .50391 Mdot
.58688 .4752 Mdot
.71162 .50873 Mdot
.58014 .39691 Mdot
.55572 .49913 Mdot
.66985 .40454 Mdot
.23644 .51632 Mdot
.66244 .46562 Mdot
.60255 .45909 Mdot
.55862 .34291 Mdot
.64807 .31342 Mdot
.40039 .40096 Mdot
.37638 .5804 Mdot
.45109 .34059 Mdot
.48633 .66395 Mdot
.48654 .65076 Mdot
.43663 .6476 Mdot
.80323 .55617 Mdot
.66864 .48036 Mdot
.60255 .4537 Mdot
.35556 .56977 Mdot
.66361 .62732 Mdot
.39808 .34048 Mdot
.66373 .63304 Mdot
.35223 .41679 Mdot
.66044 .65206 Mdot
.2401 .51884 Mdot
.62859 .71469 Mdot
.42351 .2362 Mdot
.64563 .6412 Mdot
.44698 .3358 Mdot
.55807 .62452 Mdot
.64983 .46563 Mdot
.25622 .67108 Mdot
.64671 .61539 Mdot
.80436 .35342 Mdot
.57124 .41332 Mdot
.48344 .5242 Mdot
.38841 .56485 Mdot
.68142 .6254 Mdot
.37492 .51916 Mdot
.65073 .42133 Mdot
.24433 .36995 Mdot
.42451 .35752 Mdot
.35657 .57724 Mdot
.66514 .45412 Mdot
.68103 .61961 Mdot
.48279 .67282 Mdot
.52451 .51153 Mdot
.35516 .54579 Mdot
.77631 .42182 Mdot
.72606 .49961 Mdot
.4661 .666 Mdot
.35914 .22655 Mdot
.39239 .52903 Mdot
.65344 .40294 Mdot
.60546 .52632 Mdot
.64686 .43033 Mdot
.48877 .66463 Mdot
.45425 .636 Mdot
.28638 .47784 Mdot
.58054 .41742 Mdot
.57277 .40935 Mdot
.45383 .38379 Mdot
.47245 .67986 Mdot
.42427 .32235 Mdot
.43871 .37962 Mdot
.4475 .66679 Mdot
.43322 .32598 Mdot
.67171 .64705 Mdot
.39304 .45104 Mdot
.39453 .53172 Mdot
.36124 .53848 Mdot
.48487 .67081 Mdot
.43777 .68242 Mdot
.46419 .68308 Mdot
.63665 .43632 Mdot
.40468 .3193 Mdot
.62893 .40605 Mdot
.64911 .40827 Mdot
.45018 .30823 Mdot
.392 .33808 Mdot
.63758 .40998 Mdot
.5691 .63277 Mdot
.64106 .5973 Mdot
.46164 .6403 Mdot
.38995 .53737 Mdot
.76438 .37394 Mdot
.35023 .5648 Mdot
.56885 .43709 Mdot
.27517 .68776 Mdot
.39565 .34068 Mdot
.67115 .61884 Mdot
.6727 .66519 Mdot
.67425 .62842 Mdot
.3576 .57847 Mdot
.44619 .37513 Mdot
.35029 .44798 Mdot
.57072 .43972 Mdot
.43007 .4833 Mdot
.74692 .44681 Mdot
.29733 .43647 Mdot
.38402 .53589 Mdot
.62944 .4415 Mdot
.24798 .51334 Mdot
.45931 .23093 Mdot
.60073 .4476 Mdot
.65659 .46947 Mdot
.58672 .68456 Mdot
.58145 .49807 Mdot
.38323 .316 Mdot
.39841 .42228 Mdot
.61178 .48159 Mdot
.41874 .41124 Mdot
.42781 .13093 Mdot
.57262 .41261 Mdot
.61136 .42667 Mdot
.61834 .46661 Mdot
.62885 .40079 Mdot
.42586 .29712 Mdot
.58871 .65007 Mdot
.36711 .57333 Mdot
.40376 .45951 Mdot
.38495 .52596 Mdot
.47162 .64467 Mdot
.49133 .5252 Mdot
.44793 .36482 Mdot
.67464 .62649 Mdot
.79585 .6545 Mdot
.35982 .41068 Mdot
.46102 .6944 Mdot
.55066 .18745 Mdot
.65477 .61056 Mdot
.64634 .4677 Mdot
.6539 .59477 Mdot
.48694 .64539 Mdot
.36938 .5303 Mdot
.57268 .46694 Mdot
.39583 .35971 Mdot
.44164 .31626 Mdot
.62897 .43906 Mdot
.23729 .69337 Mdot
.36653 .52017 Mdot
.32753 .57464 Mdot
.5857 .41722 Mdot
.65561 .47031 Mdot
.44477 .34139 Mdot
.4535 .64052 Mdot
.27437 .60132 Mdot
.65371 .62074 Mdot
.67089 .43251 Mdot
.65182 .42466 Mdot
.36321 .42605 Mdot
.40052 .57161 Mdot
.2427 .49728 Mdot
.58381 .41676 Mdot
.37688 .44178 Mdot
.58473 .41345 Mdot
.59701 .36507 Mdot
.45688 .68112 Mdot
.56519 .46742 Mdot
.61491 .47772 Mdot
.72128 .40152 Mdot
.3915 .52654 Mdot
.42409 .34774 Mdot
.46299 .34321 Mdot
.24945 .49425 Mdot
.36865 .56146 Mdot
.64298 .41602 Mdot
.40752 .5539 Mdot
.65802 .42606 Mdot
.59451 .42812 Mdot
.38326 .53513 Mdot
.42535 .32234 Mdot
.35663 .72581 Mdot
.5812 .34285 Mdot
.6038 .39753 Mdot
.64744 .44609 Mdot
.79627 .56938 Mdot
.40631 .20858 Mdot
.62523 .47474 Mdot
.39635 .32792 Mdot
.6349 .44824 Mdot
.35935 .54726 Mdot
.65563 .65167 Mdot
.41705 .35168 Mdot
.44745 .69753 Mdot
.44769 .6799 Mdot
.4162 .64682 Mdot
.24703 .51938 Mdot
.64393 .46508 Mdot
.38748 .37418 Mdot
.39189 .34514 Mdot
.19846 .5164 Mdot
.47862 .65791 Mdot
.67785 .64897 Mdot
.58846 .40152 Mdot
.53203 .51786 Mdot
.37775 .57559 Mdot
.0961 .54909 Mdot
.34804 .45488 Mdot
.68498 .61021 Mdot
.33957 .34329 Mdot
.2418 .51339 Mdot
.58797 .46621 Mdot
.64964 .60105 Mdot
.43803 .66889 Mdot
.65195 .41815 Mdot
.621 .50313 Mdot
.421 .72436 Mdot
.48143 .71284 Mdot
.40717 .54985 Mdot
.44104 .68199 Mdot
.68167 .60904 Mdot
.23786 .51836 Mdot
.43381 .3157 Mdot
.59711 .45674 Mdot
.69793 .46731 Mdot
.47326 .65427 Mdot
.22535 .49677 Mdot
.58882 .41388 Mdot
.44764 .32352 Mdot
.44642 .63632 Mdot
.58513 .44254 Mdot
.49639 .2117 Mdot
.43244 .28823 Mdot
.46688 .65744 Mdot
.61573 .48608 Mdot
.50086 .40378 Mdot
.46176 .70491 Mdot
.48664 .69011 Mdot
.61797 .43363 Mdot
.67343 .6435 Mdot
.58271 .46674 Mdot
.39362 .55886 Mdot
.47636 .58037 Mdot
.36379 .55392 Mdot
.74236 .4667 Mdot
.59514 .48826 Mdot
.2907 .34376 Mdot
.4136 .37552 Mdot
.64135 .65644 Mdot
.57067 .33427 Mdot
.6471 .4747 Mdot
.41275 .79845 Mdot
.56126 .60746 Mdot
.20132 .54591 Mdot
.54747 .83294 Mdot
.64554 .62966 Mdot
.38249 .55801 Mdot
.61257 .42724 Mdot
.40831 .52162 Mdot
.65068 .64221 Mdot
.74601 .4586 Mdot
.61833 .48558 Mdot
.41176 .32071 Mdot
.59824 .41814 Mdot
.43386 .37153 Mdot
.63917 .4504 Mdot
.67085 .48361 Mdot
.63286 .59775 Mdot
.80112 .47605 Mdot
.6504 .46315 Mdot
.80828 .64349 Mdot
.50807 .50809 Mdot
.64666 .61857 Mdot
.61022 .40191 Mdot
.23605 .50352 Mdot
.35852 .52409 Mdot
.70013 .70603 Mdot
.45892 .6771 Mdot
.38831 .54477 Mdot
.44247 .34262 Mdot
.42652 .64139 Mdot
.24627 .4921 Mdot
.66565 .51844 Mdot
.67867 .61262 Mdot
.37584 .56724 Mdot
.60031 .46018 Mdot
.56806 .43695 Mdot
.63166 .7098 Mdot
.2779 .26874 Mdot
.44549 .38463 Mdot
.82767 .45095 Mdot
.38319 .32331 Mdot
.6639 .62155 Mdot
.45914 .68295 Mdot
.60301 .47213 Mdot
.60508 .44311 Mdot
.48271 .65056 Mdot
.39935 .32009 Mdot
.42118 .65066 Mdot
.59362 .20992 Mdot
.4713 .61624 Mdot
.77699 .5101 Mdot
.41672 .35657 Mdot
.78025 .50419 Mdot
.68634 .61612 Mdot
.51583 .80048 Mdot
.72571 .59919 Mdot
.38053 .57057 Mdot
.77309 .51558 Mdot
.39837 .34617 Mdot
.58396 .43135 Mdot
.23271 .51137 Mdot
.25616 .51055 Mdot
.44231 .35591 Mdot
.44641 .6591 Mdot
.67905 .6179 Mdot
.60632 .42586 Mdot
.31548 .41593 Mdot
.21274 .44712 Mdot
.43228 .63995 Mdot
.66499 .3755 Mdot
.3718 .52085 Mdot
.64264 .44571 Mdot
.63899 .62358 Mdot
.38186 .54426 Mdot
.26445 .51668 Mdot
.39573 .44969 Mdot
.58721 .40133 Mdot
.43973 .42652 Mdot
.3743 .5639 Mdot
.37466 .21111 Mdot
.61071 .43804 Mdot
.39221 .52873 Mdot
.56291 .49625 Mdot
.2437 .38501 Mdot
.58609 .57536 Mdot
.34418 .78023 Mdot
.49374 .69938 Mdot
.44492 .67456 Mdot
.20468 .37242 Mdot
.63077 .58864 Mdot
.36109 .56752 Mdot
.23343 .51725 Mdot
.72893 .55979 Mdot
.38032 .51929 Mdot
.5654 .44533 Mdot
.57885 .39852 Mdot
.5974 .21737 Mdot
.50386 .5179 Mdot
.23123 .49155 Mdot
.53547 .49294 Mdot
.63258 .42138 Mdot
.54526 .4109 Mdot
.62014 .44542 Mdot
.39203 .31838 Mdot
.37791 .5164 Mdot
.80972 .66788 Mdot
.38849 .5195 Mdot
.32244 .41808 Mdot
.46622 .65207 Mdot
.43665 .63221 Mdot
.59512 .46074 Mdot
.31612 .30383 Mdot
.68038 .73168 Mdot
.64729 .45246 Mdot
.6923 .65448 Mdot
.73186 .49287 Mdot
.55799 .40821 Mdot
.46435 .36658 Mdot
.67798 .39305 Mdot
.40735 .30045 Mdot
.38027 .53997 Mdot
.6455 .63216 Mdot
.62953 .61357 Mdot
.38473 .56219 Mdot
.60601 .45347 Mdot
.68229 .66822 Mdot
.59087 .45035 Mdot
.58331 .42556 Mdot
.34434 .41828 Mdot
.66013 .65831 Mdot
.4663 .68503 Mdot
.67121 .63061 Mdot
.43302 .33792 Mdot
.22471 .25069 Mdot
.65967 .63843 Mdot
.4996 .41607 Mdot
.50074 .55875 Mdot
.77454 .51072 Mdot
.44199 .31777 Mdot
.64364 .64386 Mdot
.40318 .53623 Mdot
.19469 .54407 Mdot
.38222 .22045 Mdot
.34319 .54332 Mdot
.60507 .43944 Mdot
.44356 .37133 Mdot
.38821 .33708 Mdot
.34819 .51667 Mdot
.42584 .31552 Mdot
.54394 .44479 Mdot
.58516 .40898 Mdot
.36134 .56758 Mdot
.24601 .45599 Mdot
.37817 .51593 Mdot
.51366 .49268 Mdot
.59862 .40445 Mdot
.41913 .35209 Mdot
.53681 .40962 Mdot
.44038 .39301 Mdot
.25884 .51027 Mdot
.66063 .43327 Mdot
.67668 .62374 Mdot
.46429 .50049 Mdot
.46552 .65571 Mdot
.28061 .69226 Mdot
.44071 .36999 Mdot
.41079 .59737 Mdot
.43649 .32181 Mdot
.40513 .37505 Mdot
.35369 .51853 Mdot
.43102 .3486 Mdot
.60965 .42606 Mdot
.44626 .5545 Mdot
.42489 .37048 Mdot
.36991 .54872 Mdot
.67604 .61616 Mdot
.43016 .32407 Mdot
.42744 .62721 Mdot
.57981 .43346 Mdot
.47439 .69189 Mdot
.68278 .65498 Mdot
.44744 .36701 Mdot
.64594 .6456 Mdot
.47557 .65526 Mdot
.67166 .60643 Mdot
.51917 .70152 Mdot
.4109 .57093 Mdot
.32998 .39132 Mdot
.51786 .36973 Mdot
.39865 .36225 Mdot
.49739 .65721 Mdot
.61153 .47559 Mdot
.57736 .4241 Mdot
.66986 .60044 Mdot
.38867 .34083 Mdot
.27578 .73597 Mdot
.55093 .49872 Mdot
.2902 .48976 Mdot
.40506 .57055 Mdot
.80439 .40756 Mdot
.34133 .46996 Mdot
.20184 .56558 Mdot
.64059 .38244 Mdot
.24051 .51332 Mdot
.58697 .45182 Mdot
.78453 .41997 Mdot
.65831 .65329 Mdot
.33806 .6709 Mdot
.65727 .39648 Mdot
.46487 .67545 Mdot
.63525 .45659 Mdot
.73605 .70068 Mdot
.64677 .37428 Mdot
.63979 .63562 Mdot
.37612 .58506 Mdot
.42724 .38616 Mdot
.65617 .61125 Mdot
.45132 .6867 Mdot
.75243 .55464 Mdot
.60513 .48548 Mdot
.6284 .42243 Mdot
.49535 .65455 Mdot
.41606 .31807 Mdot
.47443 .64795 Mdot
.39374 .531 Mdot
.66018 .63546 Mdot
.61889 .39724 Mdot
.54445 .4311 Mdot
.45369 .61266 Mdot
.39995 .52844 Mdot
.42936 .66208 Mdot
.40368 .56427 Mdot
.23911 .51351 Mdot
.64768 .46276 Mdot
.48524 .63911 Mdot
.6094 .38462 Mdot
.67553 .32904 Mdot
.34351 .40512 Mdot
.59082 .31716 Mdot
.4679 .68612 Mdot
.77928 .55165 Mdot
.37576 .55828 Mdot
.40111 .56179 Mdot
.69181 .28388 Mdot
.66614 .73765 Mdot
.55593 .63092 Mdot
.80795 .62619 Mdot
.39444 .53202 Mdot
.36722 .555 Mdot
.43774 .66443 Mdot
.43525 .35037 Mdot
.43003 .29221 Mdot
.44726 .61937 Mdot
.78615 .44672 Mdot
.39822 .34083 Mdot
.39491 .79596 Mdot
.47732 .70396 Mdot
.66996 .40612 Mdot
.22538 .49196 Mdot
.64156 .62274 Mdot
.77658 .43679 Mdot
.78501 .65209 Mdot
.5936 .46676 Mdot
.54683 .16494 Mdot
.45123 .65417 Mdot
.43642 .54074 Mdot
.46692 .79555 Mdot
.64557 .47954 Mdot
.62887 .45978 Mdot
.61313 .45257 Mdot
.64303 .65244 Mdot
.60064 .33093 Mdot
.59106 .46572 Mdot
.79806 .49551 Mdot
.56115 .44232 Mdot
.72534 .68912 Mdot
.67081 .63118 Mdot
.65974 .53321 Mdot
.49803 .69498 Mdot
.2834 .41276 Mdot
.53605 .45567 Mdot
.40159 .54085 Mdot
.41423 .74342 Mdot
.37345 .52884 Mdot
.59305 .78827 Mdot
.72511 .59522 Mdot
.38871 .32178 Mdot
.63707 .43884 Mdot
.49742 .67679 Mdot
.43854 .37331 Mdot
.28349 .62315 Mdot
.29365 .19682 Mdot
.41096 .55095 Mdot
.62199 .15824 Mdot
.40059 .5634 Mdot
.25757 .50712 Mdot
.44476 .34814 Mdot
.35836 .31805 Mdot
.43413 .48562 Mdot
.4262 .32407 Mdot
.41671 .68947 Mdot
.46555 .35512 Mdot
.77586 .5342 Mdot
.40273 .37704 Mdot
.37394 .55067 Mdot
.39405 .58931 Mdot
.61551 .51002 Mdot
.62305 .47455 Mdot
.39314 .45791 Mdot
.53452 .46963 Mdot
.64111 .46314 Mdot
.4711 .67238 Mdot
.34643 .26797 Mdot
.43811 .5905 Mdot
.4258 .36583 Mdot
.38535 .5783 Mdot
.63073 .45945 Mdot
.60466 .3981 Mdot
.63422 .3934 Mdot
.77858 .40842 Mdot
.39627 .79396 Mdot
.59126 .4282 Mdot
.66163 .47914 Mdot
.45559 .68855 Mdot
.65264 .70202 Mdot
.82906 .54436 Mdot
.73113 .5708 Mdot
.57372 .42291 Mdot
.66596 .61882 Mdot
.65155 .65329 Mdot
.55148 .44522 Mdot
.29789 .3783 Mdot
.45333 .72084 Mdot
.60071 .46034 Mdot
.72994 .62757 Mdot
.42799 .61399 Mdot
.22165 .50328 Mdot
.47393 .65523 Mdot
.45206 .35426 Mdot
.25295 .51055 Mdot
.44651 .63168 Mdot
.37179 .277 Mdot
.2499 .49532 Mdot
.24722 .39568 Mdot
.65102 .64992 Mdot
.61441 .44445 Mdot
.44004 .39745 Mdot
.48436 .65417 Mdot
.3782 .56703 Mdot
.41362 .33974 Mdot
.41462 .55548 Mdot
.65506 .70379 Mdot
.76613 .45538 Mdot
.25175 .51865 Mdot
.40104 .54552 Mdot
.4119 .44521 Mdot
.66853 .62162 Mdot
.34946 .52136 Mdot
.30814 .30865 Mdot
.56546 .40309 Mdot
.63743 .77759 Mdot
.6285 .42696 Mdot
.2032 .64262 Mdot
.39975 .56205 Mdot
.26272 .5114 Mdot
.59639 .45464 Mdot
.47983 .69943 Mdot
.63571 .51219 Mdot
.59088 .44798 Mdot
.44423 .68955 Mdot
.58652 .42968 Mdot
.63846 .61921 Mdot
.4077 .29603 Mdot
.56274 .60362 Mdot
.78346 .35806 Mdot
.66542 .60389 Mdot
.27863 .50877 Mdot
.63688 .46832 Mdot
.54759 .71918 Mdot
.42199 .32425 Mdot
.65387 .47349 Mdot
.64741 .22674 Mdot
.43706 .35864 Mdot
.4214 .33198 Mdot
.62664 .41046 Mdot
.34537 .55143 Mdot
.48567 .67845 Mdot
.67028 .62319 Mdot
.26724 .55445 Mdot
.58389 .44419 Mdot
.62598 .44136 Mdot
.65585 .61027 Mdot
.36565 .55493 Mdot
.62077 .39869 Mdot
.27566 .64279 Mdot
.23201 .5363 Mdot
.37714 .57303 Mdot
.5633 .40435 Mdot
.65792 .78689 Mdot
.40055 .28421 Mdot
.51605 .15357 Mdot
.63763 .58401 Mdot
.44908 .66409 Mdot
.68973 .44563 Mdot
.09107 .51791 Mdot
.6424 .62412 Mdot
.29859 .42994 Mdot
.59081 .42326 Mdot
.62924 .46772 Mdot
.4257 .30929 Mdot
.63766 .41263 Mdot
.40741 .35911 Mdot
.78464 .35294 Mdot
.86518 .56638 Mdot
.43566 .32276 Mdot
.41474 .36704 Mdot
.36515 .34603 Mdot
.7712 .41438 Mdot
.44091 .3456 Mdot
.61499 .487 Mdot
.48996 .75399 Mdot
.62224 .49796 Mdot
.68989 .62599 Mdot
.64146 .65865 Mdot
.46786 .37797 Mdot
.32236 .25604 Mdot
.66169 .50924 Mdot
.57827 .35448 Mdot
.61684 .57708 Mdot
.3957 .54858 Mdot
.58917 .39594 Mdot
.24436 .51969 Mdot
.43585 .64331 Mdot
.65005 .37132 Mdot
.61063 .44586 Mdot
.42639 .37268 Mdot
.64231 .65287 Mdot
.36145 .51743 Mdot
.61681 .43569 Mdot
.44778 .70702 Mdot
.65451 .62392 Mdot
.42246 .36961 Mdot
.49672 .42462 Mdot
.68636 .63953 Mdot
.54138 .42787 Mdot
.63891 .46393 Mdot
.58846 .41341 Mdot
.539 .46242 Mdot
.38555 .5634 Mdot
.43913 .62429 Mdot
.56956 .47865 Mdot
.35614 .42864 Mdot
.46653 .52917 Mdot
.56411 .46897 Mdot
.40205 .32044 Mdot
.36396 .57292 Mdot
.2488 .4974 Mdot
.75322 .52774 Mdot
.58113 .40685 Mdot
.40383 .79421 Mdot
.54627 .19201 Mdot
.2492 .5056 Mdot
.38041 .34516 Mdot
.67316 .6233 Mdot
.62429 .4167 Mdot
.51919 .74212 Mdot
.56891 .42199 Mdot
.50971 .41752 Mdot
.4501 .65964 Mdot
.39429 .54174 Mdot
.21827 .53504 Mdot
.43545 .64348 Mdot
.42201 .33333 Mdot
.25698 .73596 Mdot
.45767 .33359 Mdot
.44384 .38179 Mdot
.53517 .79302 Mdot
.38095 .53789 Mdot
.094 .53447 Mdot
.40144 .20806 Mdot
.56706 .42224 Mdot
.35956 .53374 Mdot
.44597 .35175 Mdot
.63362 .43424 Mdot
.39736 .35643 Mdot
.45618 .36667 Mdot
.63906 .40165 Mdot
.62929 .47 Mdot
.79547 .46758 Mdot
.39601 .80953 Mdot
.67426 .63573 Mdot
.40792 .31158 Mdot
.5657 .2128 Mdot
.59132 .46693 Mdot
.571 .44062 Mdot
.42048 .73262 Mdot
.64084 .63745 Mdot
.46426 .26963 Mdot
.58286 .41993 Mdot
.66099 .23647 Mdot
.64786 .45807 Mdot
.41726 .40287 Mdot
.3454 .55611 Mdot
.29927 .38872 Mdot
.48911 .66812 Mdot
.45124 .32553 Mdot
.68393 .63024 Mdot
.44192 .30781 Mdot
.66942 .25957 Mdot
.37676 .53506 Mdot
.4067 .35567 Mdot
.428 .66703 Mdot
.36785 .53736 Mdot
.38295 .57089 Mdot
.52902 .72085 Mdot
.42794 .63976 Mdot
.63481 .63878 Mdot
.37278 .5256 Mdot
.51798 .21256 Mdot
.37586 .54796 Mdot
.58369 .21756 Mdot
.60195 .47874 Mdot
.79393 .48884 Mdot
.32869 .47192 Mdot
.55356 .47634 Mdot
.37352 .51617 Mdot
.66268 .64433 Mdot
.64606 .42499 Mdot
.42298 .31452 Mdot
.65587 .63852 Mdot
.34692 .50758 Mdot
.43617 .68264 Mdot
.39677 .36805 Mdot
.35614 .56833 Mdot
.40311 .35544 Mdot
.75826 .45614 Mdot
.50352 .71199 Mdot
.62723 .56798 Mdot
.44619 .49822 Mdot
.65025 .39984 Mdot
.42284 .41125 Mdot
.58935 .47737 Mdot
.6052 .4469 Mdot
.46727 .65703 Mdot
.80319 .55409 Mdot
.42833 .32236 Mdot
.18356 .50618 Mdot
.40169 .55179 Mdot
.3933 .41959 Mdot
.5119 .4487 Mdot
.65738 .4288 Mdot
.42893 .36878 Mdot
.45484 .37218 Mdot
.64714 .31317 Mdot
.48087 .64798 Mdot
.57956 .49061 Mdot
.55302 .46737 Mdot
.67336 .47683 Mdot
.39861 .56527 Mdot
.29463 .66476 Mdot
.45605 .63097 Mdot
.53381 .12913 Mdot
.46024 .63931 Mdot
.56897 .68804 Mdot
.43109 .34988 Mdot
.67072 .65121 Mdot
.57208 .4437 Mdot
.61841 .33866 Mdot
.42257 .29799 Mdot
.44148 .71271 Mdot
.67285 .61856 Mdot
.32924 .69919 Mdot
.3851 .54105 Mdot
.61234 .48301 Mdot
.619 .39327 Mdot
.62175 .40358 Mdot
.61305 .41902 Mdot
.38261 .58012 Mdot
.56572 .44542 Mdot
.39652 .57999 Mdot
.47487 .21716 Mdot
.67204 .24798 Mdot
.49344 .68309 Mdot
.70129 .6959 Mdot
.39475 .36022 Mdot
.56007 .22417 Mdot
.45009 .26032 Mdot
.34144 .40508 Mdot
.52599 .7028 Mdot
.61774 .4797 Mdot
.44526 .65806 Mdot
.73649 .70328 Mdot
.49689 .67344 Mdot
.88807 .54719 Mdot
.71376 .48631 Mdot
.33272 .78011 Mdot
.62989 .43138 Mdot
.44388 .61864 Mdot
.45847 .28399 Mdot
.54834 .43088 Mdot
.6613 .67039 Mdot
.50962 .46676 Mdot
.26465 .44492 Mdot
.67959 .64799 Mdot
.5803 .43611 Mdot
.42388 .38686 Mdot
.60848 .42502 Mdot
.57459 .4449 Mdot
.6456 .45322 Mdot
.37312 .5097 Mdot
.57668 .3942 Mdot
.58125 .4651 Mdot
.28987 .25559 Mdot
.78419 .57634 Mdot
.4656 .69774 Mdot
.62082 .30712 Mdot
.66322 .62739 Mdot
.43102 .37413 Mdot
.54757 .59497 Mdot
.39224 .55558 Mdot
.65735 .31506 Mdot
.62962 .42965 Mdot
.30729 .47579 Mdot
.35141 .56489 Mdot
.64981 .63678 Mdot
.2451 .49352 Mdot
.40612 .77643 Mdot
.49241 .67078 Mdot
.25668 .49786 Mdot
.46429 .65483 Mdot
.51231 .33418 Mdot
.42793 .37183 Mdot
.64034 .39677 Mdot
.37544 .52143 Mdot
.48454 .69023 Mdot
.795 .58875 Mdot
.62355 .45005 Mdot
.46995 .68647 Mdot
.65056 .40084 Mdot
.46338 .5413 Mdot
.50394 .5662 Mdot
.47634 .63153 Mdot
.38935 .58917 Mdot
.36445 .53883 Mdot
.67042 .64873 Mdot
.42736 .37517 Mdot
.39585 .33216 Mdot
.37852 .54172 Mdot
.55728 .15115 Mdot
.58403 .4471 Mdot
.64419 .45922 Mdot
.35533 .4353 Mdot
.62431 .43122 Mdot
.76511 .56165 Mdot
.22649 .51759 Mdot
.40565 .37095 Mdot
.61643 .4234 Mdot
.61828 .39795 Mdot
.58906 .40057 Mdot
.76231 .46133 Mdot
.46964 .64967 Mdot
.63154 .42057 Mdot
.66019 .59797 Mdot
.27664 .34427 Mdot
.60307 .47499 Mdot
.5452 .42218 Mdot
.4036 .35295 Mdot
.81535 .41549 Mdot
.38761 .56645 Mdot
.47539 .68135 Mdot
.47393 .70419 Mdot
.68749 .53571 Mdot
.39701 .29436 Mdot
.21796 .50859 Mdot
.37899 .6298 Mdot
.22509 .50705 Mdot
.64997 .61647 Mdot
.56184 .65542 Mdot
.45406 .71159 Mdot
.45486 .69337 Mdot
.40892 .57231 Mdot
.61152 .42003 Mdot
.64664 .45884 Mdot
.30057 .42837 Mdot
.65535 .44379 Mdot
.67468 .61727 Mdot
.35345 .56007 Mdot
.4041 .35117 Mdot
.64227 .6166 Mdot
.40449 .5518 Mdot
.41499 .31752 Mdot
.55591 .41561 Mdot
.58028 .38734 Mdot
.41563 .33521 Mdot
.4493 .35339 Mdot
.60461 .46691 Mdot
.25242 .30466 Mdot
.41455 .38047 Mdot
.41182 .35686 Mdot
.25682 .4908 Mdot
.49289 .67096 Mdot
.55947 .38545 Mdot
.36059 .52989 Mdot
.58741 .41511 Mdot
.49488 .67919 Mdot
.64554 .64242 Mdot
.41011 .32873 Mdot
.59689 .39941 Mdot
.58977 .43494 Mdot
.66679 .61849 Mdot
.67247 .65702 Mdot
.66723 .60743 Mdot
.41008 .53564 Mdot
.60292 .41104 Mdot
.44016 .34013 Mdot
.38191 .53659 Mdot
.65239 .65346 Mdot
.63934 .60442 Mdot
.31402 .24228 Mdot
.5922 .46486 Mdot
.59434 .5799 Mdot
.17314 .31395 Mdot
.74785 .56116 Mdot
.25518 .50017 Mdot
.46166 .61791 Mdot
.79089 .50478 Mdot
.65727 .58127 Mdot
.35757 .53594 Mdot
.70442 .60393 Mdot
.64602 .65872 Mdot
.64736 .40743 Mdot
.64606 .44156 Mdot
.67378 .42841 Mdot
.65627 .62879 Mdot
.75655 .46279 Mdot
.38946 .33286 Mdot
.52865 .26612 Mdot
.66309 .62751 Mdot
.47493 .63002 Mdot
.48074 .63423 Mdot
.4599 .63855 Mdot
.62163 .48036 Mdot
.62253 .31707 Mdot
.53607 .20864 Mdot
.48475 .28418 Mdot
.38789 .545 Mdot
.45598 .37379 Mdot
.53174 .69756 Mdot
.42084 .3308 Mdot
.43891 .64409 Mdot
.65232 .62836 Mdot
.41775 .30861 Mdot
.36549 .56255 Mdot
.3629 .55082 Mdot
.44433 .6947 Mdot
.47786 .66089 Mdot
.48122 .67569 Mdot
.45367 .34935 Mdot
.43118 .3488 Mdot
.60785 .39535 Mdot
.40688 .33638 Mdot
.48854 .17778 Mdot
.68862 .61436 Mdot
.49756 .66112 Mdot
.37386 .56167 Mdot
.43873 .36897 Mdot
.61272 .44247 Mdot
.60049 .6898 Mdot
.41745 .65154 Mdot
.65699 .60226 Mdot
.47075 .5945 Mdot
.87974 .47037 Mdot
.6106 .39028 Mdot
.4058 .56322 Mdot
.29356 .36276 Mdot
.61919 .45454 Mdot
.45498 .6717 Mdot
.75169 .39015 Mdot
.22465 .49983 Mdot
.5855 .46736 Mdot
.65794 .46378 Mdot
.35491 .51832 Mdot
.52947 .58267 Mdot
.65855 .43405 Mdot
.4675 .43501 Mdot
.40173 .52868 Mdot
.45345 .63027 Mdot
.16463 .44944 Mdot
.48021 .62472 Mdot
.8059 .47551 Mdot
.25382 .50169 Mdot
.62028 .39414 Mdot
.47025 .66885 Mdot
.64999 .60259 Mdot
.47402 .66606 Mdot
.38621 .35235 Mdot
.47772 .68935 Mdot
.63133 .44559 Mdot
.4388 .33995 Mdot
.37033 .56297 Mdot
.40717 .42252 Mdot
.2928 .26321 Mdot
.47795 .7006 Mdot
.26952 .51472 Mdot
.58853 .46739 Mdot
.46666 .23503 Mdot
.64672 .50809 Mdot
.61829 .47678 Mdot
.37485 .52903 Mdot
.42867 .36789 Mdot
.4039 .57159 Mdot
.56044 .40078 Mdot
.69459 .29599 Mdot
.3999 .5558 Mdot
.24603 .42222 Mdot
.65275 .61196 Mdot
.78458 .44637 Mdot
.59867 .44504 Mdot
.37794 .52293 Mdot
.60201 .4104 Mdot
.40367 .313 Mdot
.45509 .47931 Mdot
.28723 .32977 Mdot
.37284 .5217 Mdot
.22759 .68964 Mdot
.48432 .5014 Mdot
.60245 .37126 Mdot
.38669 .52579 Mdot
.58303 .32803 Mdot
.23892 .50035 Mdot
.65288 .62008 Mdot
.66019 .65704 Mdot
.6804 .61361 Mdot
.65491 .4452 Mdot
.6936 .40851 Mdot
.63123 .62054 Mdot
.41256 .54815 Mdot
.63807 .61211 Mdot
.76746 .43161 Mdot
.2549 .71453 Mdot
.66099 .60476 Mdot
.59917 .4398 Mdot
.54741 .42007 Mdot
.78524 .57826 Mdot
.45163 .6281 Mdot
.41775 .79827 Mdot
.42669 .21276 Mdot
.60677 .47261 Mdot
.65356 .52385 Mdot
.39123 .35778 Mdot
.31631 .33433 Mdot
.56151 .50785 Mdot
.55954 .62184 Mdot
.41652 .36472 Mdot
.46014 .56125 Mdot
.40887 .37259 Mdot
.60948 .38826 Mdot
.59539 .42741 Mdot
.4157 .29664 Mdot
.26708 .67259 Mdot
.22359 .3903 Mdot
.17653 .57726 Mdot
.39532 .33094 Mdot
.39068 .52592 Mdot
.40964 .55101 Mdot
.38609 .53784 Mdot
.48706 .6647 Mdot
.45084 .34267 Mdot
.61023 .41135 Mdot
.44835 .67783 Mdot
.5731 .43115 Mdot
.368 .53241 Mdot
.22016 .53656 Mdot
.40454 .35295 Mdot
.60152 .45904 Mdot
.37971 .22322 Mdot
.45762 .64627 Mdot
.66683 .62128 Mdot
.44829 .53955 Mdot
.45364 .61404 Mdot
.38296 .51607 Mdot
.39635 .28995 Mdot
.35926 .59123 Mdot
.59109 .64899 Mdot
.67311 .46158 Mdot
.59631 .48332 Mdot
.28233 .54148 Mdot
.33845 .243 Mdot
.65082 .44575 Mdot
.45108 .68686 Mdot
.48688 .6464 Mdot
.58383 .40878 Mdot
.43748 .31785 Mdot
.63395 .64443 Mdot
.67948 .60968 Mdot
.6649 .44243 Mdot
.42732 .4822 Mdot
.79654 .48095 Mdot
.63554 .40739 Mdot
.52949 .39653 Mdot
.4269 .65939 Mdot
.24885 .49286 Mdot
.38139 .44316 Mdot
.68082 .63637 Mdot
.5887 .42259 Mdot
.21237 .41573 Mdot
.41067 .36113 Mdot
.48028 .68389 Mdot
.36372 .56693 Mdot
.6637 .67188 Mdot
.46786 .70649 Mdot
.58426 .40863 Mdot
.61989 .39845 Mdot
.35173 .52107 Mdot
.41989 .40288 Mdot
.65355 .63011 Mdot
.44989 .67947 Mdot
.67177 .65085 Mdot
.43152 .34028 Mdot
.4087 .35197 Mdot
.55757 .4748 Mdot
.56269 .48695 Mdot
.47405 .70346 Mdot
.66886 .44817 Mdot
.44406 .63461 Mdot
.63599 .70818 Mdot
.37872 .57625 Mdot
.65465 .47414 Mdot
.37754 .35325 Mdot
.37055 .53344 Mdot
.61929 .46964 Mdot
.29309 .52985 Mdot
.6459 .4113 Mdot
.44506 .61919 Mdot
.70138 .29345 Mdot
.6519 .64407 Mdot
.48606 .39722 Mdot
.70253 .38869 Mdot
.62499 .43248 Mdot
.44898 .62505 Mdot
.69043 .45743 Mdot
.39545 .56024 Mdot
.42885 .36036 Mdot
.73536 .24948 Mdot
.37176 .54686 Mdot
.60368 .42437 Mdot
.65851 .63686 Mdot
.43805 .38612 Mdot
.2478 .51731 Mdot
.36003 .45039 Mdot
.64761 .37189 Mdot
.6309 .37807 Mdot
.60924 .42055 Mdot
.81167 .62254 Mdot
.47536 .67543 Mdot
.44378 .3615 Mdot
.3938 .57132 Mdot
.3843 .54962 Mdot
.45296 .6405 Mdot
.28177 .46182 Mdot
.29887 .71799 Mdot
.12718 .38024 Mdot
.45882 .70047 Mdot
.64463 .60247 Mdot
.47074 .5148 Mdot
.43429 .64466 Mdot
.46875 .67475 Mdot
.44795 .70024 Mdot
.31652 .46387 Mdot
.40994 .31635 Mdot
.58853 .43431 Mdot
.39053 .30014 Mdot
.63568 .40033 Mdot
.81697 .53804 Mdot
.37992 .54119 Mdot
.42926 .35853 Mdot
.29391 .53817 Mdot
.54582 .48593 Mdot
.627 .45668 Mdot
.48325 .74436 Mdot
.67376 .39366 Mdot
.76512 .52179 Mdot
.53935 .41644 Mdot
.47182 .65685 Mdot
.6725 .51391 Mdot
.68893 .44462 Mdot
.4106 .21979 Mdot
.36463 .55807 Mdot
.25698 .51598 Mdot
.55882 .41644 Mdot
.5876 .36762 Mdot
.44007 .38477 Mdot
.41808 .30843 Mdot
.63099 .62349 Mdot
.43527 .50655 Mdot
.3672 .56129 Mdot
.34337 .74209 Mdot
.62837 .47253 Mdot
.41265 .51041 Mdot
.69102 .2781 Mdot
.61659 .4686 Mdot
.51542 .73554 Mdot
.65498 .31435 Mdot
.65662 .42946 Mdot
.50689 .29537 Mdot
.3721 .55663 Mdot
.65713 .23364 Mdot
.66946 .42019 Mdot
.45547 .6709 Mdot
.43411 .35263 Mdot
.39429 .36356 Mdot
.65191 .60534 Mdot
.45142 .18915 Mdot
.40808 .58617 Mdot
.43117 .35273 Mdot
.61625 .45108 Mdot
.38078 .56684 Mdot
.25439 .51531 Mdot
.64625 .37852 Mdot
.60935 .76937 Mdot
.40492 .34097 Mdot
.63363 .49531 Mdot
.22664 .47747 Mdot
.47971 .5372 Mdot
.40445 .81506 Mdot
.38758 .53651 Mdot
.68298 .63048 Mdot
.53853 .416 Mdot
.37236 .62593 Mdot
.66194 .40277 Mdot
.80473 .51675 Mdot
.47842 .37205 Mdot
.6565 .65193 Mdot
.61331 .45647 Mdot
.65815 .43461 Mdot
.45757 .50077 Mdot
.67411 .65494 Mdot
.65908 .43086 Mdot
.56938 .48453 Mdot
.41356 .31896 Mdot
.23285 .52038 Mdot
.40261 .34554 Mdot
.60621 .43914 Mdot
.65582 .52862 Mdot
.42648 .31183 Mdot
.39036 .76612 Mdot
.62183 .63202 Mdot
.39318 .55563 Mdot
.58999 .36369 Mdot
.60684 .47908 Mdot
.61443 .8299 Mdot
.25881 .50982 Mdot
.82551 .48269 Mdot
.45195 .61604 Mdot
.18561 .4894 Mdot
.44292 .61119 Mdot
.30935 .76827 Mdot
.40487 .43109 Mdot
.6717 .45611 Mdot
.7199 .6171 Mdot
.49619 .28714 Mdot
.41256 .5677 Mdot
.50022 .22133 Mdot
.62246 .47472 Mdot
.58053 .44981 Mdot
.4405 .66385 Mdot
.28849 .47372 Mdot
.29291 .37263 Mdot
.40571 .46284 Mdot
.64878 .63074 Mdot
.42713 .34569 Mdot
.63586 .4459 Mdot
.23425 .61049 Mdot
.46999 .69755 Mdot
.51514 .50767 Mdot
.59908 .45657 Mdot
.31705 .40665 Mdot
.27421 .4321 Mdot
.37895 .56807 Mdot
.45589 .61911 Mdot
.43894 .62507 Mdot
.58204 .39654 Mdot
.35856 .556 Mdot
.62384 .39737 Mdot
.48311 .49223 Mdot
.65883 .4807 Mdot
.64215 .63175 Mdot
.57161 .44894 Mdot
.54949 .54846 Mdot
.30975 .78312 Mdot
.68777 .41081 Mdot
.4261 .37994 Mdot
.48489 .66123 Mdot
.46173 .64227 Mdot
.39529 .33322 Mdot
.45863 .64053 Mdot
.53215 .27309 Mdot
.64385 .24354 Mdot
.64457 .62185 Mdot
.43131 .25036 Mdot
.64755 .63785 Mdot
.25713 .51639 Mdot
.59727 .46717 Mdot
.39479 .6506 Mdot
.4607 .70193 Mdot
.76701 .39015 Mdot
.37844 .54786 Mdot
.25829 .50942 Mdot
.56375 .42422 Mdot
.56389 .65961 Mdot
.4405 .65021 Mdot
.40579 .75316 Mdot
.58989 .39981 Mdot
.40867 .31342 Mdot
.65702 .43258 Mdot
.64622 .48488 Mdot
.25526 .49732 Mdot
.60875 .41954 Mdot
.40454 .55132 Mdot
.45073 .33899 Mdot
.31173 .76473 Mdot
.48571 .65742 Mdot
.5785 .45366 Mdot
.61633 .45187 Mdot
.4103 .30768 Mdot
.56206 .44218 Mdot
.35778 .53243 Mdot
.10259 .58834 Mdot
.65215 .61317 Mdot
.24328 .49186 Mdot
.39672 .75528 Mdot
.64255 .43879 Mdot
.64524 .41765 Mdot
.27758 .54351 Mdot
.26199 .32921 Mdot
.40313 .54698 Mdot
.58147 .48413 Mdot
.45771 .68938 Mdot
.65323 .63725 Mdot
.35675 .52511 Mdot
.59064 .40863 Mdot
.58122 .45194 Mdot
.64128 .62883 Mdot
.49669 .7468 Mdot
.42022 .65152 Mdot
.38718 .54196 Mdot
.61163 .52847 Mdot
.60599 .69299 Mdot
.58721 .44798 Mdot
.20454 .6256 Mdot
.41362 .35594 Mdot
.39108 .53066 Mdot
.58965 .33505 Mdot
.64434 .39916 Mdot
.38253 .51643 Mdot
.36865 .56151 Mdot
.57136 .41092 Mdot
.39494 .29512 Mdot
.45511 .35679 Mdot
.41415 .35886 Mdot
.7127 .29898 Mdot
.76362 .64499 Mdot
.48185 .67643 Mdot
.36955 .55667 Mdot
.49532 .66024 Mdot
.63033 .63849 Mdot
.46615 .52751 Mdot
.48466 .6424 Mdot
.39537 .36331 Mdot
.49365 .6518 Mdot
.63153 .40121 Mdot
.36238 .55797 Mdot
.45252 .6921 Mdot
.63928 .43208 Mdot
.52722 .39509 Mdot
.57472 .55269 Mdot
.63573 .64561 Mdot
.45944 .55139 Mdot
.60609 .43028 Mdot
.24949 .49673 Mdot
.60077 .46448 Mdot
.36135 .56778 Mdot
.54054 .55099 Mdot
.63408 .42591 Mdot
.46945 .70435 Mdot
.59988 .65203 Mdot
.45854 .62667 Mdot
.61344 .4904 Mdot
.60563 .43823 Mdot
.58561 .44894 Mdot
.65952 .43676 Mdot
.25379 .43363 Mdot
.3971 .57896 Mdot
.58256 .36367 Mdot
.47631 .71144 Mdot
.41668 .3293 Mdot
.40003 .3132 Mdot
.55442 .62677 Mdot
.2585 .49632 Mdot
.35821 .54479 Mdot
.58497 .44676 Mdot
.40599 .75273 Mdot
.22336 .53981 Mdot
.19194 .61229 Mdot
.54193 .70142 Mdot
.45198 .68948 Mdot
.43069 .37872 Mdot
.43444 .66861 Mdot
.5726 .41651 Mdot
.54152 .4131 Mdot
.32595 .77323 Mdot
.35413 .50836 Mdot
.65353 .62844 Mdot
.57245 .43194 Mdot
.79524 .45462 Mdot
.45552 .68847 Mdot
.42616 .65536 Mdot
.61085 .39367 Mdot
.45784 .34514 Mdot
.38708 .83043 Mdot
.36199 .56669 Mdot
.47335 .23185 Mdot
.48529 .3697 Mdot
.51351 .47318 Mdot
.38497 .56112 Mdot
.60153 .56923 Mdot
.46456 .63299 Mdot
.43699 .20487 Mdot
.41369 .33366 Mdot
.65627 .62541 Mdot
.55672 .46164 Mdot
.39654 .36559 Mdot
.46252 .61668 Mdot
.41108 .36979 Mdot
.62958 .39325 Mdot
.41024 .56172 Mdot
.45373 .6371 Mdot
.37797 .58365 Mdot
.41984 .29598 Mdot
.64889 .64042 Mdot
.76063 .4224 Mdot
.47413 .22673 Mdot
.65524 .31464 Mdot
.63089 .4202 Mdot
.44335 .74589 Mdot
.6048 .40866 Mdot
.44801 .37821 Mdot
.5988 .44413 Mdot
.41369 .41209 Mdot
.43535 .63341 Mdot
.64286 .49224 Mdot
.57622 .46052 Mdot
.4489 .21459 Mdot
.62371 .46276 Mdot
.56548 .42143 Mdot
.65931 .45695 Mdot
.48328 .38503 Mdot
.59464 .49324 Mdot
.41256 .31315 Mdot
.30272 .43892 Mdot
.46717 .67253 Mdot
.63826 .60297 Mdot
.68514 .61827 Mdot
.80262 .50941 Mdot
.78727 .44908 Mdot
.28787 .46369 Mdot
.39903 .33442 Mdot
.39975 .5319 Mdot
.62039 .3965 Mdot
.5452 .34216 Mdot
.64835 .55945 Mdot
.46179 .63262 Mdot
.48621 .69804 Mdot
.57914 .49709 Mdot
.80129 .65488 Mdot
.61404 .496 Mdot
.34972 .45032 Mdot
.6589 .42199 Mdot
.65639 .47093 Mdot
.42675 .66399 Mdot
.76708 .44406 Mdot
.6315 .42072 Mdot
.43982 .38494 Mdot
.65884 .62148 Mdot
.64455 .5239 Mdot
.65455 .55172 Mdot
.55065 .53164 Mdot
.37124 .27241 Mdot
.60945 .41529 Mdot
.44929 .67277 Mdot
.40218 .37116 Mdot
.36202 .43145 Mdot
.38051 .53446 Mdot
.37773 .45056 Mdot
.48913 .20773 Mdot
.50617 .65546 Mdot
.65469 .62419 Mdot
.51837 .72599 Mdot
.63114 .4451 Mdot
.48691 .66744 Mdot
.62413 .39336 Mdot
.21886 .54101 Mdot
.64706 .64543 Mdot
.43256 .29867 Mdot
.39172 .52634 Mdot
.39546 .32439 Mdot
.59565 .31574 Mdot
.64446 .55629 Mdot
.18369 .49189 Mdot
.49203 .6655 Mdot
.72944 .38055 Mdot
.44156 .35546 Mdot
.59273 .40334 Mdot
.13991 .36227 Mdot
.41578 .35507 Mdot
.4001 .31917 Mdot
.56063 .62165 Mdot
.74286 .46591 Mdot
.69087 .43923 Mdot
.40502 .36686 Mdot
.50024 .67834 Mdot
.67249 .63257 Mdot
.643 .42414 Mdot
.66013 .45108 Mdot
.42281 .30903 Mdot
.44067 .64601 Mdot
.7989 .45034 Mdot
.47515 .65885 Mdot
.42106 .31796 Mdot
.45772 .65273 Mdot
.37591 .74687 Mdot
.46787 .69322 Mdot
.58061 .467 Mdot
.58551 .44568 Mdot
.6044 .75672 Mdot
.40867 .35184 Mdot
.6463 .42225 Mdot
.58859 .42691 Mdot
.44169 .34644 Mdot
.46665 .71618 Mdot
.66971 .33532 Mdot
.63505 .43682 Mdot
.5857 .43894 Mdot
.66507 .65383 Mdot
.4716 .5699 Mdot
.22015 .60195 Mdot
.64434 .42345 Mdot
.67005 .60247 Mdot
.45311 .35464 Mdot
.6041 .46549 Mdot
.77224 .43774 Mdot
.42628 .61206 Mdot
.56687 .4336 Mdot
.24548 .51809 Mdot
.64746 .45088 Mdot
.38107 .82866 Mdot
.58143 .45859 Mdot
.44596 .34712 Mdot
.43632 .35718 Mdot
.41911 .65058 Mdot
.42212 .33578 Mdot
.2556 .50594 Mdot
.36704 .53481 Mdot
.1922 .62715 Mdot
.25475 .50975 Mdot
.64377 .47887 Mdot
.40183 .2078 Mdot
.66686 .43261 Mdot
.55227 .42816 Mdot
.76834 .41075 Mdot
.25316 .50631 Mdot
.43416 .36723 Mdot
.26698 .66894 Mdot
.65579 .47585 Mdot
.36101 .56517 Mdot
.5465 .4308 Mdot
.56652 .43814 Mdot
.49349 .46028 Mdot
.70674 .31035 Mdot
.35549 .5649 Mdot
.56962 .38051 Mdot
.64301 .42218 Mdot
.30611 .2852 Mdot
.62096 .44748 Mdot
.65775 .60454 Mdot
.39619 .34781 Mdot
.43248 .66682 Mdot
.66061 .61299 Mdot
.63814 .44256 Mdot
.65907 .62796 Mdot
.48058 .67866 Mdot
.37792 .52699 Mdot
.57067 .44321 Mdot
.68947 .63051 Mdot
.65125 .63157 Mdot
.61186 .40417 Mdot
.43165 .35533 Mdot
.66968 .496 Mdot
.6072 .46656 Mdot
.58697 .40729 Mdot
.39583 .33236 Mdot
.42688 .15921 Mdot
.59323 .38987 Mdot
.59295 .57516 Mdot
.39596 .3103 Mdot
.22239 .4975 Mdot
.43818 .6753 Mdot
.62337 .3875 Mdot
.38394 .54421 Mdot
.37423 .53723 Mdot
.49052 .7126 Mdot
.4311 .30548 Mdot
.44605 .63652 Mdot
.6331 .37288 Mdot
.57137 .49148 Mdot
.55972 .4713 Mdot
.73891 .25368 Mdot
.40907 .77833 Mdot
.44723 .33247 Mdot
.46046 .62973 Mdot
.40067 .46221 Mdot
.35918 .54489 Mdot
.49571 .7121 Mdot
.37906 .35549 Mdot
.44537 .36737 Mdot
.39603 .36185 Mdot
.67815 .63756 Mdot
.47719 .65435 Mdot
.44948 .39106 Mdot
.4533 .32875 Mdot
.6018 .39641 Mdot
.6422 .42102 Mdot
.4719 .35659 Mdot
.77876 .58119 Mdot
.64437 .63748 Mdot
.45108 .66894 Mdot
.56844 .85786 Mdot
.36307 .56862 Mdot
.44639 .21475 Mdot
.63872 .4331 Mdot
.31726 .16934 Mdot
.57912 .48612 Mdot
.61792 .45001 Mdot
.4523 .35315 Mdot
.6714 .59822 Mdot
.66768 .63577 Mdot
.44091 .35555 Mdot
.42929 .29294 Mdot
.67951 .61672 Mdot
.53962 .70978 Mdot
.20715 .66823 Mdot
.37005 .4394 Mdot
.44435 .34222 Mdot
.45455 .23219 Mdot
.36186 .52254 Mdot
.39897 .30356 Mdot
.35881 .56821 Mdot
.468 .67553 Mdot
.48509 .69588 Mdot
.34917 .52302 Mdot
.58381 .40414 Mdot
.47684 .68798 Mdot
.65913 .37636 Mdot
.36134 .77486 Mdot
.58075 .79886 Mdot
.24132 .34102 Mdot
.64576 .46262 Mdot
.29792 .38184 Mdot
.2727 .38608 Mdot
.61772 .43126 Mdot
.52397 .45717 Mdot
.65533 .62782 Mdot
.40309 .30333 Mdot
.35563 .54521 Mdot
.42621 .81065 Mdot
.58647 .4476 Mdot
.42777 .32192 Mdot
.36055 .55293 Mdot
.3664 .73396 Mdot
.47179 .43833 Mdot
.61516 .39332 Mdot
.08871 .45808 Mdot
.42486 .29682 Mdot
.43211 .66589 Mdot
.38529 .23342 Mdot
.38817 .30495 Mdot
.60778 .68218 Mdot
.42977 .63143 Mdot
.18482 .56897 Mdot
.43409 .37322 Mdot
.44301 .70619 Mdot
.42962 .33815 Mdot
.63944 .61835 Mdot
.39462 .29173 Mdot
.45006 .64393 Mdot
.6167 .45954 Mdot
.45312 .6429 Mdot
.63959 .62988 Mdot
.48943 .67491 Mdot
.35539 .5422 Mdot
.25276 .49981 Mdot
.36229 .5456 Mdot
.46645 .53399 Mdot
.68092 .30186 Mdot
.39405 .54176 Mdot
.42208 .75837 Mdot
.65007 .44464 Mdot
.41392 .40212 Mdot
.43391 .67207 Mdot
.49552 .69085 Mdot
.45469 .51621 Mdot
.42793 .32572 Mdot
.45022 .64919 Mdot
.49252 .2108 Mdot
.51989 .13788 Mdot
.65908 .37282 Mdot
.73474 .66978 Mdot
.44237 .34472 Mdot
.43096 .63906 Mdot
.35468 .43783 Mdot
.3872 .33855 Mdot
.46358 .70099 Mdot
.38395 .52332 Mdot
.38577 .55315 Mdot
.58207 .40165 Mdot
.34014 .52745 Mdot
.44579 .62554 Mdot
.22262 .39738 Mdot
.3954 .34825 Mdot
.37403 .73222 Mdot
.66588 .60457 Mdot
.47233 .67868 Mdot
.68289 .46062 Mdot
.45362 .30536 Mdot
.48931 .69792 Mdot
.64845 .75166 Mdot
.61012 .84439 Mdot
.45068 .65042 Mdot
.39643 .34867 Mdot
.41126 .32678 Mdot
.68952 .42326 Mdot
.43829 .48981 Mdot
.44351 .64783 Mdot
.40171 .67041 Mdot
.8069 .524 Mdot
.23962 .51382 Mdot
.35294 .2249 Mdot
.63121 .42152 Mdot
.59972 .41091 Mdot
.36298 .52614 Mdot
.63266 .45456 Mdot
.4573 .35768 Mdot
.55634 .44614 Mdot
.41059 .54657 Mdot
.45879 .63211 Mdot
.58913 .4597 Mdot
.6654 .64397 Mdot
.35639 .53221 Mdot
.36369 .51071 Mdot
.46263 .66108 Mdot
.40026 .36469 Mdot
.25521 .66935 Mdot
.47602 .65882 Mdot
.61136 .41542 Mdot
.24388 .5056 Mdot
.63578 .39383 Mdot
.56799 .77282 Mdot
.39013 .33355 Mdot
.43306 .66559 Mdot
.37992 .34477 Mdot
.36736 .55022 Mdot
.49267 .70572 Mdot
.62072 .44364 Mdot
.46896 .70159 Mdot
.66968 .57994 Mdot
.54419 .74431 Mdot
.4522 .32317 Mdot
.69516 .6473 Mdot
.41443 .30802 Mdot
.24037 .51448 Mdot
.71414 .54212 Mdot
.64869 .62261 Mdot
.46474 .68911 Mdot
.4043 .78267 Mdot
.45072 .70041 Mdot
.62396 .46422 Mdot
.63115 .46825 Mdot
.43934 .6649 Mdot
.66956 .64675 Mdot
.79733 .39683 Mdot
.61029 .59082 Mdot
.42656 .37113 Mdot
.36363 .38751 Mdot
.5067 .85941 Mdot
.3689 .59257 Mdot
.38625 .51994 Mdot
.5339 .40164 Mdot
.6526 .42127 Mdot
.36038 .51645 Mdot
.38397 .57822 Mdot
.6494 .65173 Mdot
.48647 .67265 Mdot
.39826 .38196 Mdot
.3605 .52115 Mdot
.71796 .40847 Mdot
.78186 .43991 Mdot
.68429 .41135 Mdot
.64828 .49453 Mdot
.61163 .48158 Mdot
.47845 .54065 Mdot
.40133 .57143 Mdot
.60178 .43056 Mdot
.55106 .46743 Mdot
.39678 .53585 Mdot
.63956 .62475 Mdot
.36768 .32143 Mdot
.45503 .66041 Mdot
.43283 .12693 Mdot
.57091 .44532 Mdot
.61363 .46272 Mdot
.38797 .54536 Mdot
.32599 .2509 Mdot
.4448 .33154 Mdot
.39858 .3597 Mdot
.47632 .67601 Mdot
.45098 .51638 Mdot
.56399 .4542 Mdot
.6139 .43088 Mdot
.4636 .68472 Mdot
.25023 .49871 Mdot
.21027 .36935 Mdot
.59137 .43545 Mdot
.37635 .56058 Mdot
.41178 .74227 Mdot
.3991 .57336 Mdot
.61533 .39131 Mdot
.62569 .46538 Mdot
.57627 .46393 Mdot
.66092 .43699 Mdot
.35422 .52152 Mdot
.61667 .43393 Mdot
.61242 .51267 Mdot
.42288 .36637 Mdot
.6266 .42632 Mdot
.79801 .50431 Mdot
.58997 .44131 Mdot
.66307 .64363 Mdot
.22545 .62001 Mdot
.578 .44373 Mdot
.6231 .42427 Mdot
.60774 .58624 Mdot
.60975 .45439 Mdot
.37423 .57026 Mdot
.41212 .33097 Mdot
.36812 .55612 Mdot
.39839 .56501 Mdot
.49786 .67524 Mdot
.64414 .64998 Mdot
.66543 .40528 Mdot
.67391 .60745 Mdot
.67559 .46594 Mdot
.63264 .3948 Mdot
.46494 .55988 Mdot
.34918 .45218 Mdot
.66572 .58478 Mdot
.61515 .44116 Mdot
.47186 .67262 Mdot
.43982 .68172 Mdot
.71716 .62837 Mdot
.67588 .39105 Mdot
.35422 .52645 Mdot
.3778 .52273 Mdot
.76112 .56495 Mdot
.48551 .44237 Mdot
.65494 .64197 Mdot
.40368 .45444 Mdot
.64274 .46841 Mdot
.58304 .42958 Mdot
.54579 .42426 Mdot
.48885 .64771 Mdot
.25081 .49535 Mdot
.46474 .63511 Mdot
.2715 .50028 Mdot
.39766 .57614 Mdot
.64398 .46401 Mdot
.53873 .80656 Mdot
.43657 .31324 Mdot
.41127 .33196 Mdot
.40799 .53636 Mdot
.45652 .62631 Mdot
.68841 .42521 Mdot
.75357 .26082 Mdot
.46562 .3765 Mdot
.65578 .59422 Mdot
.60995 .42818 Mdot
.46527 .66463 Mdot
.44651 .32067 Mdot
.67629 .65749 Mdot
.63691 .46939 Mdot
.46694 .71315 Mdot
.59498 .444 Mdot
.49745 .29941 Mdot
.42841 .36515 Mdot
.21236 .53566 Mdot
.45634 .32979 Mdot
.37329 .51591 Mdot
.4022 .55721 Mdot
.62056 .46894 Mdot
.63548 .17758 Mdot
.44547 .30518 Mdot
.3573 .57815 Mdot
.63536 .62502 Mdot
.24131 .49247 Mdot
.63648 .64011 Mdot
.43732 .63865 Mdot
.65623 .62187 Mdot
.47356 .70429 Mdot
.76505 .5844 Mdot
.45836 .38545 Mdot
.65497 .61306 Mdot
.30541 .2595 Mdot
.58716 .38594 Mdot
.65823 .65538 Mdot
.58933 .50216 Mdot
.43691 .41078 Mdot
.46276 .68152 Mdot
.67 .64528 Mdot
.59869 .40007 Mdot
.46141 .80521 Mdot
.40108 .56197 Mdot
.35284 .52906 Mdot
.66222 .40214 Mdot
.43222 .67607 Mdot
.42509 .29134 Mdot
.54639 .591 Mdot
.22007 .50125 Mdot
.61371 .43173 Mdot
.6409 .46791 Mdot
.41871 .30319 Mdot
.44799 .38182 Mdot
.62651 .46668 Mdot
.50981 .21571 Mdot
.63163 .44421 Mdot
.38726 .55643 Mdot
.44934 .35557 Mdot
.40958 .32956 Mdot
.45292 .62083 Mdot
.43169 .30618 Mdot
.63936 .49621 Mdot
.41151 .52357 Mdot
.54695 .45254 Mdot
.36902 .54644 Mdot
.5519 .55471 Mdot
.48805 .66469 Mdot
.42412 .8035 Mdot
.43444 .30501 Mdot
.61321 .4204 Mdot
.40923 .30974 Mdot
.66844 .60851 Mdot
.40789 .3497 Mdot
.3987 .37207 Mdot
.62566 .47267 Mdot
.61898 .39384 Mdot
.24892 .50247 Mdot
.43868 .49175 Mdot
.42395 .36007 Mdot
.62936 .43943 Mdot
.66873 .43691 Mdot
.57954 .39508 Mdot
.4847 .50675 Mdot
.44526 .37054 Mdot
.60713 .22209 Mdot
.57697 .78216 Mdot
.42865 .35616 Mdot
.4377 .83189 Mdot
.22991 .51426 Mdot
.25777 .49467 Mdot
.38084 .59295 Mdot
.58775 .43535 Mdot
.44862 .63742 Mdot
.57142 .41955 Mdot
.6493 .3705 Mdot
.57735 .44862 Mdot
.64179 .63926 Mdot
.67896 .44007 Mdot
.22985 .50559 Mdot
.4707 .65255 Mdot
.6378 .4389 Mdot
.58568 .45731 Mdot
.26018 .49895 Mdot
.4555 .32525 Mdot
.44002 .37167 Mdot
.21085 .63268 Mdot
.64538 .61541 Mdot
.37625 .53037 Mdot
.57702 .41339 Mdot
.47369 .67405 Mdot
.4555 .64108 Mdot
.39709 .32207 Mdot
.45382 .66652 Mdot
.36054 .56656 Mdot
.62525 .4489 Mdot
.35899 .5171 Mdot
.64143 .63809 Mdot
.3961 .34702 Mdot
.5767 .41313 Mdot
.59962 .39678 Mdot
.43632 .3575 Mdot
.65025 .44582 Mdot
.66612 .65362 Mdot
.48636 .68985 Mdot
.44197 .36815 Mdot
.36861 .53509 Mdot
.45825 .61981 Mdot
.62418 .39883 Mdot
.69045 .78263 Mdot
.63458 .4535 Mdot
.58039 .41669 Mdot
.24687 .71827 Mdot
.53421 .42693 Mdot
.43321 .63862 Mdot
.39827 .31367 Mdot
.57394 .39357 Mdot
.81395 .54639 Mdot
.30406 .57048 Mdot
.49394 .71374 Mdot
.60896 .42448 Mdot
.406 .80474 Mdot
.61833 .42504 Mdot
.3565 .73061 Mdot
.46411 .55674 Mdot
.7695 .66597 Mdot
.63888 .49887 Mdot
.34657 .55632 Mdot
.2508 .50212 Mdot
.43499 .67656 Mdot
.54484 .32616 Mdot
.64186 .45174 Mdot
.60068 .32646 Mdot
.56579 .44537 Mdot
.38509 .55991 Mdot
.52368 .43816 Mdot
.45157 .66787 Mdot
.41482 .21444 Mdot
.60906 .41176 Mdot
.44748 .36587 Mdot
.49981 .66773 Mdot
.22916 .4962 Mdot
.59612 .39986 Mdot
.66425 .60174 Mdot
.30187 .53204 Mdot
.59269 .49762 Mdot
.36869 .5436 Mdot
.58761 .42501 Mdot
.58352 .37345 Mdot
.5702 .15749 Mdot
.42444 .36792 Mdot
.38575 .52089 Mdot
.31223 .32281 Mdot
.65183 .45149 Mdot
.43624 .37245 Mdot
.41513 .33199 Mdot
.64732 .60612 Mdot
.35029 .47121 Mdot
.33812 .58988 Mdot
.62416 .78667 Mdot
.63546 .30847 Mdot
.45704 .617 Mdot
.24767 .36537 Mdot
.63695 .41911 Mdot
.64391 .55336 Mdot
.37965 .56991 Mdot
.61387 .46089 Mdot
.65831 .29588 Mdot
.41257 .35827 Mdot
.59591 .43681 Mdot
.64362 .63499 Mdot
.29702 .50712 Mdot
.56179 .53294 Mdot
.60982 .82312 Mdot
.50059 .69645 Mdot
.54621 .43854 Mdot
.63336 .50497 Mdot
.22475 .49548 Mdot
.6405 .40109 Mdot
.43246 .66999 Mdot
.45774 .75919 Mdot
.66417 .64876 Mdot
.4377 .31161 Mdot
.22711 .51207 Mdot
.57899 .4726 Mdot
.65546 .40087 Mdot
.63867 .60292 Mdot
.59709 .40479 Mdot
.39884 .22619 Mdot
.21018 .51569 Mdot
.47015 .69401 Mdot
.41037 .37042 Mdot
.61517 .48176 Mdot
.2497 .4953 Mdot
.62858 .47092 Mdot
.36204 .31817 Mdot
.5977 .41654 Mdot
.25208 .47286 Mdot
.43404 .35128 Mdot
.36572 .54341 Mdot
.6713 .40937 Mdot
.59206 .45268 Mdot
.60508 .69611 Mdot
.64577 .36925 Mdot
.58142 .4578 Mdot
.43231 .38789 Mdot
.4334 .31472 Mdot
.40777 .31548 Mdot
.47627 .69166 Mdot
.37699 .44194 Mdot
.37849 .55316 Mdot
.55951 .44391 Mdot
.35968 .5224 Mdot
.69174 .38473 Mdot
.64499 .59842 Mdot
.48475 .82937 Mdot
.64267 .44419 Mdot
.40209 .32298 Mdot
.21836 .41824 Mdot
.45354 .35253 Mdot
.42987 .59608 Mdot
.36665 .56115 Mdot
.41764 .35539 Mdot
.60684 .4506 Mdot
.41429 .46864 Mdot
.65386 .79906 Mdot
.35999 .53964 Mdot
.54397 .41629 Mdot
.50007 .69285 Mdot
.47722 .70608 Mdot
.43117 .85066 Mdot
.40444 .55921 Mdot
.27007 .38234 Mdot
.62767 .43609 Mdot
.43296 .31164 Mdot
.39061 .54067 Mdot
.37766 .57217 Mdot
.4594 .68049 Mdot
.60456 .39173 Mdot
.59221 .44968 Mdot
.24277 .51801 Mdot
.37465 .52448 Mdot
.59561 .38052 Mdot
.65246 .4131 Mdot
.31146 .76754 Mdot
.38779 .37632 Mdot
.40045 .16718 Mdot
.61838 .37171 Mdot
.66876 .30691 Mdot
.49724 .52562 Mdot
.44858 .33398 Mdot
.57645 .40993 Mdot
.56378 .46228 Mdot
.4533 .61772 Mdot
.62963 .4499 Mdot
.4753 .63633 Mdot
.38944 .52168 Mdot
.4971 .83655 Mdot
.38149 .72593 Mdot
.52848 .69986 Mdot
.62875 .45825 Mdot
.51554 .48635 Mdot
.66726 .61224 Mdot
.4011 .52378 Mdot
.42876 .31854 Mdot
.63004 .47903 Mdot
.43088 .62856 Mdot
.46302 .68995 Mdot
.4147 .33922 Mdot
.27447 .4069 Mdot
.38938 .7654 Mdot
.66173 .43654 Mdot
.43327 .66099 Mdot
.36054 .71156 Mdot
.53612 .22093 Mdot
.34062 .53396 Mdot
.65696 .64784 Mdot
.45752 .63286 Mdot
.3647 .50903 Mdot
.36697 .35653 Mdot
.42053 .34503 Mdot
.41993 .29982 Mdot
.58828 .74472 Mdot
.44514 .64428 Mdot
.66943 .61948 Mdot
.47028 .42453 Mdot
.42361 .42653 Mdot
.64527 .64291 Mdot
.4591 .63157 Mdot
.44111 .31741 Mdot
.42544 .32035 Mdot
.41313 .32976 Mdot
.40898 .21979 Mdot
.39073 .3416 Mdot
.55606 .18894 Mdot
.66589 .42647 Mdot
.46543 .23685 Mdot
.61538 .42454 Mdot
.34692 .53672 Mdot
.42989 .36466 Mdot
.46595 .51632 Mdot
.64982 .47096 Mdot
.61728 .81661 Mdot
.60703 .42961 Mdot
.38879 .5028 Mdot
.58627 .43671 Mdot
.41694 .24205 Mdot
.39651 .30968 Mdot
.61688 .44076 Mdot
.35899 .57468 Mdot
.65443 .63342 Mdot
.39038 .28108 Mdot
.57959 .44553 Mdot
.29792 .48845 Mdot
.55298 .4689 Mdot
.37662 .77459 Mdot
.58867 .64931 Mdot
.66076 .59365 Mdot
.56414 .48095 Mdot
.47597 .62646 Mdot
.41984 .28177 Mdot
.45512 .24562 Mdot
.36044 .5381 Mdot
.7369 .36488 Mdot
.46768 .68926 Mdot
.52407 .44027 Mdot
.63535 .48686 Mdot
.67858 .64001 Mdot
.41593 .28356 Mdot
.38998 .5575 Mdot
.64705 .44674 Mdot
.56974 .41485 Mdot
.65834 .7322 Mdot
.4469 .2436 Mdot
.60715 .38057 Mdot
.63062 .63463 Mdot
.61936 .22934 Mdot
.57809 .43378 Mdot
.47457 .71513 Mdot
.38785 .32413 Mdot
.67027 .47684 Mdot
.59238 .21545 Mdot
.63203 .44094 Mdot
.41561 .3508 Mdot
.4324 .30377 Mdot
.23631 .45309 Mdot
.65473 .59559 Mdot
.59731 .41649 Mdot
.62132 .69651 Mdot
.60433 .41188 Mdot
.38192 .5557 Mdot
.59818 .38853 Mdot
.46885 .68093 Mdot
.35034 .43892 Mdot
.48201 .6896 Mdot
.58124 .39844 Mdot
.42176 .32418 Mdot
.39202 .55366 Mdot
.57689 .7588 Mdot
.53074 .5923 Mdot
.56761 .19262 Mdot
.29641 .53971 Mdot
.67625 .63747 Mdot
.6549 .65705 Mdot
.40987 .57351 Mdot
.60862 .43908 Mdot
.49203 .55409 Mdot
.62902 .49405 Mdot
.58327 .43763 Mdot
.57213 .44218 Mdot
.35385 .50636 Mdot
.36433 .5553 Mdot
.45512 .64882 Mdot
.6287 .46529 Mdot
.6281 .43928 Mdot
.42724 .35142 Mdot
.65097 .63272 Mdot
.47444 .69607 Mdot
.65262 .61033 Mdot
.47267 .65972 Mdot
.39154 .82848 Mdot
.56486 .39731 Mdot
.65513 .63452 Mdot
.40778 .56791 Mdot
.39713 .32731 Mdot
.26009 .50937 Mdot
.44051 .63633 Mdot
.45052 .664 Mdot
.6169 .43243 Mdot
.39949 .35019 Mdot
.40687 .36042 Mdot
.68037 .62221 Mdot
.38685 .53036 Mdot
.57765 .40372 Mdot
.64134 .40385 Mdot
.70798 .69589 Mdot
.47048 .62545 Mdot
.52956 .21046 Mdot
.25964 .44742 Mdot
.60944 .43981 Mdot
.41426 .36859 Mdot
.59321 .46181 Mdot
.46974 .78546 Mdot
.39624 .36462 Mdot
.66301 .4548 Mdot
.49009 .42577 Mdot
.49456 .6639 Mdot
.2065 .47478 Mdot
.67286 .42319 Mdot
.27454 .54571 Mdot
.62395 .40936 Mdot
.20532 .69572 Mdot
.27432 .31856 Mdot
.57002 .46243 Mdot
.65869 .44437 Mdot
.65788 .77115 Mdot
.62574 .43231 Mdot
.23065 .51098 Mdot
.64987 .3768 Mdot
.44312 .37026 Mdot
.50893 .55312 Mdot
.4697 .5796 Mdot
.64147 .60536 Mdot
.4767 .6767 Mdot
.71233 .51189 Mdot
.63979 .62026 Mdot
.4444 .34805 Mdot
.66031 .45297 Mdot
.71549 .37635 Mdot
.42166 .63177 Mdot
.64582 .48587 Mdot
.38273 .55727 Mdot
.46585 .57473 Mdot
.47635 .64316 Mdot
.36557 .53632 Mdot
.56873 .45299 Mdot
.8211 .49455 Mdot
.53652 .60566 Mdot
.16855 .56126 Mdot
.3872 .54228 Mdot
.37596 .56702 Mdot
.35572 .41972 Mdot
.6417 .60526 Mdot
.67617 .71811 Mdot
.55659 .51633 Mdot
.36044 .56181 Mdot
.75106 .53076 Mdot
.42476 .64767 Mdot
.34573 .47149 Mdot
.40074 .3045 Mdot
.55945 .40264 Mdot
.60297 .45152 Mdot
.39211 .53313 Mdot
.57693 .34426 Mdot
.34363 .31289 Mdot
.3615 .54337 Mdot
.63647 .50854 Mdot
.3066 .50364 Mdot
.24704 .50758 Mdot
.23836 .51822 Mdot
.63393 .62278 Mdot
.47343 .74597 Mdot
.43402 .33945 Mdot
.6792 .64309 Mdot
.2378 .47856 Mdot
.59249 .4168 Mdot
.37132 .52274 Mdot
.26031 .51434 Mdot
.3765 .54029 Mdot
.66392 .63829 Mdot
.6539 .5948 Mdot
.42313 .3667 Mdot
.4441 .33046 Mdot
.70583 .31391 Mdot
.77166 .54793 Mdot
.6252 .42822 Mdot
.66188 .33032 Mdot
.39314 .3386 Mdot
.43587 .26655 Mdot
.66362 .59877 Mdot
.64814 .63301 Mdot
.50637 .27083 Mdot
.6085 .39482 Mdot
.39683 .73273 Mdot
.57851 .44135 Mdot
.71264 .55247 Mdot
.64121 .48237 Mdot
.45703 .67571 Mdot
.62358 .41996 Mdot
.24114 .64364 Mdot
.64729 .43173 Mdot
.57505 .45079 Mdot
.46625 .64266 Mdot
.66352 .39501 Mdot
.46874 .68309 Mdot
.60997 .39097 Mdot
.62632 .62214 Mdot
.47392 .67395 Mdot
.74924 .65108 Mdot
.5919 .57331 Mdot
.24353 .4948 Mdot
.63691 .62075 Mdot
.67145 .60671 Mdot
.80318 .48839 Mdot
.4332 .32048 Mdot
.38302 .38824 Mdot
.60741 .43849 Mdot
.42663 .65726 Mdot
.36366 .52466 Mdot
.63011 .4413 Mdot
.5621 .46326 Mdot
.67027 .41146 Mdot
.41636 .35977 Mdot
.45192 .62929 Mdot
.6606 .63136 Mdot
.44145 .68177 Mdot
.56667 .6466 Mdot
.46435 .70667 Mdot
.53304 .39701 Mdot
.61749 .37365 Mdot
.70623 .44099 Mdot
.66838 .32404 Mdot
.43899 .20147 Mdot
.4192 .34004 Mdot
.23883 .50249 Mdot
.64073 .60356 Mdot
.36204 .38283 Mdot
.41092 .31876 Mdot
.44867 .65949 Mdot
.59507 .44413 Mdot
.6423 .50803 Mdot
.54506 .52146 Mdot
.48115 .35623 Mdot
.80277 .55208 Mdot
.48241 .65835 Mdot
.24512 .51289 Mdot
.3641 .44026 Mdot
.47272 .38932 Mdot
.46731 .52217 Mdot
.59109 .4564 Mdot
.66748 .60262 Mdot
.44641 .32051 Mdot
.61741 .74556 Mdot
.38676 .52647 Mdot
.43711 .48949 Mdot
.62948 .45687 Mdot
.24164 .39005 Mdot
.42186 .32453 Mdot
.64698 .6383 Mdot
.39307 .53392 Mdot
.65681 .59602 Mdot
.22749 .51411 Mdot
.22332 .64536 Mdot
.60469 .40475 Mdot
.58328 .46149 Mdot
.38401 .58251 Mdot
.43235 .33624 Mdot
.4346 .69997 Mdot
.62765 .7522 Mdot
.43436 .66178 Mdot
.48353 .55386 Mdot
.45025 .33585 Mdot
.3784 .26382 Mdot
.45761 .69645 Mdot
.41225 .54702 Mdot
.48559 .54014 Mdot
.41016 .54754 Mdot
.57548 .43886 Mdot
.40076 .33455 Mdot
.40496 .5577 Mdot
.61614 .7185 Mdot
.36735 .80376 Mdot
.37483 .28457 Mdot
.64713 .45265 Mdot
.49555 .83418 Mdot
.28959 .74366 Mdot
.62865 .33873 Mdot
.36456 .51962 Mdot
.61138 .46947 Mdot
.66234 .4365 Mdot
.61192 .41338 Mdot
.40366 .53891 Mdot
.54941 .65887 Mdot
.45208 .67831 Mdot
.60186 .42676 Mdot
.66711 .60553 Mdot
.46304 .6734 Mdot
.49177 .6457 Mdot
.44006 .68699 Mdot
.40398 .37381 Mdot
.66277 .44491 Mdot
.32946 .46947 Mdot
.22888 .72098 Mdot
.3657 .55445 Mdot
.24281 .49479 Mdot
.57159 .45304 Mdot
.689 .26415 Mdot
.40695 .31637 Mdot
.43492 .66123 Mdot
.61237 .46213 Mdot
.58362 .67586 Mdot
.27074 .52168 Mdot
.47896 .66038 Mdot
.43104 .32069 Mdot
.62831 .33921 Mdot
.63012 .44927 Mdot
.62286 .40718 Mdot
.43874 .34194 Mdot
.19163 .60929 Mdot
.35374 .44873 Mdot
.58997 .4592 Mdot
.36494 .54203 Mdot
.54232 .14214 Mdot
.65819 .40132 Mdot
.47051 .33548 Mdot
.24322 .49204 Mdot
.27761 .47026 Mdot
.54459 .21411 Mdot
.60689 .36252 Mdot
.52079 .82139 Mdot
.76444 .43777 Mdot
.47159 .82965 Mdot
.67732 .5377 Mdot
.31973 .67721 Mdot
.34563 .82174 Mdot
.35527 .57235 Mdot
.42814 .24949 Mdot
.73426 .70652 Mdot
.29102 .4105 Mdot
.5794 .63633 Mdot
.34592 .61942 Mdot
.59225 .66654 Mdot
.23749 .30898 Mdot
.4592 .70208 Mdot
.69427 .57008 Mdot
.57489 .4085 Mdot
.28267 .73481 Mdot
.46309 .2223 Mdot
.44403 .19041 Mdot
.46564 .82048 Mdot
.6172 .68764 Mdot
.69294 .76779 Mdot
.42079 .79747 Mdot
.73401 .38413 Mdot
.51249 .50147 Mdot
.4057 .63833 Mdot
.45203 .42408 Mdot
.72422 .4972 Mdot
.69581 .43754 Mdot
.23713 .61394 Mdot
.50477 .71618 Mdot
.6489 .26305 Mdot
.53806 .15132 Mdot
.43882 .63413 Mdot
.38612 .32806 Mdot
.70092 .71026 Mdot
.41375 .2761 Mdot
.41479 .59107 Mdot
.52195 .82146 Mdot
.31172 .77114 Mdot
.41776 .2407 Mdot
.19298 .51286 Mdot
.52241 .30532 Mdot
.79534 .37324 Mdot
.54771 .5369 Mdot
.44063 .30559 Mdot
.34214 .66373 Mdot
.42439 .42609 Mdot
.41746 .68424 Mdot
.39099 .24311 Mdot
.68567 .6517 Mdot
.7813 .60849 Mdot
.43045 .32249 Mdot
.55451 .22386 Mdot
.25267 .49032 Mdot
.24126 .48092 Mdot
.4318 .68891 Mdot
.48203 .78741 Mdot
.28049 .51821 Mdot
.3093 .48462 Mdot
.21983 .39117 Mdot
.66256 .80731 Mdot
.75887 .48207 Mdot
.47924 .76862 Mdot
.38045 .49518 Mdot
.76422 .44456 Mdot
.33015 .42656 Mdot
.77636 .5182 Mdot
.43129 .41888 Mdot
.80431 .66788 Mdot
.21883 .67188 Mdot
.7324 .7385 Mdot
.37134 .3355 Mdot
.59224 .38461 Mdot
.51999 .78639 Mdot
.62029 .30887 Mdot
.6694 .59549 Mdot
.63943 .81544 Mdot
.68289 .61343 Mdot
.39479 .37764 Mdot
.28424 .40361 Mdot
.41883 .22529 Mdot
.48834 .73248 Mdot
.62155 .62036 Mdot
.61786 .49725 Mdot
.87586 .572 Mdot
.54868 .82393 Mdot
.24865 .45655 Mdot
.30244 .7627 Mdot
.34576 .57176 Mdot
.42142 .61297 Mdot
.39444 .52568 Mdot
.34981 .81098 Mdot
.40962 .32369 Mdot
.24207 .74043 Mdot
.34211 .79986 Mdot
.34114 .27948 Mdot
.90068 .52584 Mdot
.23399 .3374 Mdot
.47414 .23304 Mdot
.75127 .4095 Mdot
.79639 .60245 Mdot
.3365 .40116 Mdot
.33915 .27055 Mdot
.4187 .60265 Mdot
.18643 .61291 Mdot
.39554 .82286 Mdot
.74028 .54527 Mdot
.51271 .67014 Mdot
.30367 .40576 Mdot
.56855 .55462 Mdot
.46986 .34212 Mdot
.59851 .60202 Mdot
.6243 .56062 Mdot
.71355 .75169 Mdot
.68659 .27846 Mdot
.67658 .19933 Mdot
.68843 .54026 Mdot
.33322 .24762 Mdot
.41129 .77494 Mdot
.73911 .65206 Mdot
.35618 .31414 Mdot
.30318 .44811 Mdot
.53654 .4416 Mdot
.388 .44161 Mdot
.60489 .51432 Mdot
.68916 .6591 Mdot
.36606 .43162 Mdot
.32613 .71968 Mdot
.70738 .53879 Mdot
.60455 .78918 Mdot
.49954 .46668 Mdot
.4148 .37674 Mdot
.78734 .49395 Mdot
.75451 .50537 Mdot
.32789 .77309 Mdot
.31075 .32458 Mdot
.1694 .57545 Mdot
.32155 .31284 Mdot
.62533 .49478 Mdot
.4342 .25533 Mdot
.69481 .44858 Mdot
.76788 .51395 Mdot
.67054 .45179 Mdot
.21208 .40802 Mdot
.25564 .72899 Mdot
.6684 .2927 Mdot
.71677 .51638 Mdot
.68289 .33156 Mdot
.19481 .63273 Mdot
.53533 .79012 Mdot
.27209 .33294 Mdot
.48725 .33736 Mdot
.85311 .60627 Mdot
.45892 .66093 Mdot
.75104 .53829 Mdot
.3857 .50873 Mdot
.58997 .74838 Mdot
.77549 .67398 Mdot
.33736 .30145 Mdot
.24695 .72182 Mdot
.31372 .45023 Mdot
.46683 .73049 Mdot
.34773 .48039 Mdot
.44526 .60521 Mdot
.70378 .34585 Mdot
.65768 .3956 Mdot
.71339 .4174 Mdot
.67582 .65099 Mdot
.59555 .30433 Mdot
.55939 .78224 Mdot
.28875 .59619 Mdot
.55761 .37401 Mdot
.29901 .62335 Mdot
.24529 .51541 Mdot
.41897 .47688 Mdot
.42145 .84801 Mdot
.61958 .36815 Mdot
.25942 .30724 Mdot
.21451 .66008 Mdot
.4779 .54582 Mdot
.50206 .74728 Mdot
.24816 .42671 Mdot
.77075 .70619 Mdot
.30304 .77699 Mdot
.31412 .73858 Mdot
.5063 .83629 Mdot
.14518 .52354 Mdot
.81682 .62195 Mdot
.53014 .34205 Mdot
.36778 .5048 Mdot
.09892 .55333 Mdot
.44465 .6751 Mdot
.74044 .36191 Mdot
.62229 .30617 Mdot
.57988 .68742 Mdot
.43233 .28701 Mdot
.52167 .39314 Mdot
.30563 .5492 Mdot
.46734 .3544 Mdot
.61105 .4965 Mdot
.60247 .84127 Mdot
.81065 .66401 Mdot
.62201 .83066 Mdot
.22569 .65211 Mdot
.4925 .83964 Mdot
.7089 .73517 Mdot
.54458 .18593 Mdot
.67854 .72291 Mdot
.60287 .38892 Mdot
.74757 .5707 Mdot
.24171 .3321 Mdot
.4434 .70837 Mdot
.2036 .50651 Mdot
.37619 .34048 Mdot
.78129 .68421 Mdot
.43629 .85756 Mdot
.52896 .27446 Mdot
.60982 .23948 Mdot
.60963 .56442 Mdot
.76574 .53486 Mdot
.72185 .43193 Mdot
.23833 .59619 Mdot
.36004 .77858 Mdot
.72 .72774 Mdot
.74175 .5165 Mdot
.33545 .62413 Mdot
.31346 .72873 Mdot
.31548 .27167 Mdot
.44738 .79847 Mdot
.71868 .70464 Mdot
.33125 .29086 Mdot
.49897 .37852 Mdot
.34215 .30842 Mdot
.22886 .57769 Mdot
.42299 .73384 Mdot
.75086 .47889 Mdot
.49053 .67109 Mdot
.74177 .55171 Mdot
.46873 .46734 Mdot
.68712 .72016 Mdot
.77205 .44301 Mdot
.73457 .54917 Mdot
.32986 .74234 Mdot
.5671 .84391 Mdot
.18025 .53327 Mdot
.83643 .51092 Mdot
.26049 .55225 Mdot
.58092 .50804 Mdot
.62142 .38625 Mdot
.22438 .68833 Mdot
.54346 .85823 Mdot
.25887 .74019 Mdot
.24067 .38646 Mdot
.60779 .71936 Mdot
.3478 .51743 Mdot
.78705 .4164 Mdot
.27536 .57268 Mdot
.36734 .7873 Mdot
.37515 .41104 Mdot
.37794 .59324 Mdot
.32135 .45067 Mdot
.73232 .36378 Mdot
.76359 .41356 Mdot
.57678 .23926 Mdot
.68668 .4126 Mdot
.49965 .22102 Mdot
.39781 .31124 Mdot
.24729 .37239 Mdot
.77148 .52322 Mdot
.46222 .66202 Mdot
.7382 .67793 Mdot
.71627 .42871 Mdot
.53314 .42857 Mdot
.43164 .73621 Mdot
.46797 .33896 Mdot
.6676 .32014 Mdot
.41476 .6077 Mdot
.36408 .82901 Mdot
.25076 .33613 Mdot
.72593 .39598 Mdot
.77596 .47522 Mdot
.68614 .69809 Mdot
.3604 .45455 Mdot
.41188 .56772 Mdot
.45296 .81487 Mdot
.57803 .59171 Mdot
.78417 .48712 Mdot
.50781 .22006 Mdot
.60446 .76303 Mdot
.56499 .46707 Mdot
.23662 .44008 Mdot
.60741 .20696 Mdot
.43067 .48751 Mdot
.41925 .39516 Mdot
.46526 .37909 Mdot
.23701 .28727 Mdot
.25402 .65298 Mdot
.30301 .31309 Mdot
.4602 .80986 Mdot
.40767 .54048 Mdot
.43366 .3832 Mdot
.73216 .56052 Mdot
.54806 .74571 Mdot
.65019 .24867 Mdot
.43654 .75227 Mdot
.7278 .44401 Mdot
.27072 .58387 Mdot
.5016 .83227 Mdot
.61979 .80659 Mdot
.58263 .15828 Mdot
.45986 .34859 Mdot
.55377 .7736 Mdot
.57826 .76683 Mdot
.45072 .32297 Mdot
.47872 .35168 Mdot
.53006 .51157 Mdot
.46049 .83737 Mdot
.4056 .43918 Mdot
.22666 .55722 Mdot
.48539 .54216 Mdot
.56881 .66627 Mdot
.63 .74335 Mdot
.74467 .47652 Mdot
.46602 .80594 Mdot
.55719 .23267 Mdot
.81809 .58353 Mdot
.69491 .46795 Mdot
.71459 .31427 Mdot
.78734 .4156 Mdot
.52876 .52885 Mdot
.39633 .24584 Mdot
.34298 .72616 Mdot
.61362 .41724 Mdot
.65511 .81447 Mdot
.32625 .76598 Mdot
.37116 .42157 Mdot
.39414 .61426 Mdot
.63989 .41102 Mdot
.66591 .43352 Mdot
.52936 .35994 Mdot
.27039 .4597 Mdot
.83914 .57094 Mdot
.69711 .54912 Mdot
.59445 .51323 Mdot
.50138 .21672 Mdot
.26074 .30645 Mdot
.49877 .78463 Mdot
.38831 .77584 Mdot
.4544 .4665 Mdot
.24236 .33404 Mdot
.43936 .51379 Mdot
.21735 .55395 Mdot
.27368 .61807 Mdot
.69953 .7401 Mdot
.51548 .46699 Mdot
.28538 .45213 Mdot
.66666 .71741 Mdot
.57096 .4486 Mdot
.27433 .40738 Mdot
.43201 .79588 Mdot
.72565 .24523 Mdot
.32485 .41478 Mdot
.57932 .85255 Mdot
.71002 .43166 Mdot
.29584 .45771 Mdot
.79035 .66339 Mdot
.80351 .31732 Mdot
.23308 .60425 Mdot
.69965 .76357 Mdot
.38745 .47585 Mdot
.46869 .81284 Mdot
.34354 .54553 Mdot
.46578 .43716 Mdot
.63312 .32589 Mdot
.45364 .83605 Mdot
.51194 .76115 Mdot
.48915 .79759 Mdot
.52393 .35786 Mdot
.49506 .84555 Mdot
.42514 .41594 Mdot
.25967 .26984 Mdot
.48152 .71675 Mdot
.19646 .40697 Mdot
.49872 .33817 Mdot
.6997 .48375 Mdot
.74768 .52886 Mdot
.3225 .23334 Mdot
.49585 .18037 Mdot
.54704 .34325 Mdot
.72896 .59928 Mdot
.25409 .43546 Mdot
.77443 .46922 Mdot
.36789 .79292 Mdot
.24211 .29991 Mdot
.60493 .75564 Mdot
.27644 .35652 Mdot
.20896 .63498 Mdot
.26386 .46044 Mdot
.28018 .65152 Mdot
.47503 .77134 Mdot
.20182 .57722 Mdot
.72456 .4551 Mdot
.33756 .16956 Mdot
.4997 .62048 Mdot
.53597 .51549 Mdot
.75488 .71584 Mdot
.35595 .77704 Mdot
.36259 .38871 Mdot
.38296 .24035 Mdot
.74466 .33626 Mdot
.76487 .58869 Mdot
.57759 .44866 Mdot
.50366 .84762 Mdot
.76102 .62562 Mdot
.66607 .79602 Mdot
.17974 .6269 Mdot
.51051 .23078 Mdot
.5659 .37747 Mdot
.46078 .61245 Mdot
.57148 .54134 Mdot
.72313 .60052 Mdot
.71595 .74022 Mdot
.73062 .33966 Mdot
.53008 .58626 Mdot
.31749 .66744 Mdot
.4115 .75434 Mdot
.5526 .50023 Mdot
.225 .35381 Mdot
.26681 .44723 Mdot
.69828 .52966 Mdot
.29961 .71849 Mdot
.75951 .52817 Mdot
.53543 .21231 Mdot
.78331 .43115 Mdot
.33171 .35968 Mdot
.32647 .56481 Mdot
.44771 .62059 Mdot
.64681 .77198 Mdot
.39636 .76749 Mdot
.2108 .41305 Mdot
.83148 .53542 Mdot
.29956 .44217 Mdot
.69573 .57896 Mdot
.59428 .78274 Mdot
.33185 .39548 Mdot
.40343 .64507 Mdot
.76184 .40636 Mdot
.70909 .31162 Mdot
.36248 .74286 Mdot
.57463 .36275 Mdot
.39972 .82763 Mdot
.74753 .48132 Mdot
.648 .75516 Mdot
.58779 .56671 Mdot
.62072 .29006 Mdot
.47668 .26864 Mdot
.76739 .64014 Mdot
.4507 .51262 Mdot
.86867 .5827 Mdot
.41468 .29075 Mdot
.66543 .80546 Mdot
.37314 .52899 Mdot
.63822 .19702 Mdot
.36347 .76123 Mdot
.46499 .48187 Mdot
.48931 .52811 Mdot
.23417 .44291 Mdot
.29739 .49583 Mdot
.20283 .63347 Mdot
.34136 .30153 Mdot
.45583 .7053 Mdot
.54403 .59975 Mdot
.22967 .56378 Mdot
.60469 .7959 Mdot
.57049 .39896 Mdot
.49061 .73404 Mdot
.53926 .53536 Mdot
.43491 .5692 Mdot
.22916 .69191 Mdot
.34693 .71744 Mdot
.66816 .48304 Mdot
.76773 .53638 Mdot
.73489 .72125 Mdot
.34532 .7965 Mdot
.34541 .33003 Mdot
.60934 .51477 Mdot
.40639 .51617 Mdot
.7734 .65932 Mdot
.54906 .81962 Mdot
.38958 .73149 Mdot
.34196 .47103 Mdot
.75624 .48641 Mdot
.65722 .83109 Mdot
.80816 .66532 Mdot
.83681 .53571 Mdot
.48835 .54959 Mdot
.41843 .40369 Mdot
.69355 .27089 Mdot
.64379 .75796 Mdot
.18481 .42919 Mdot
.32258 .75388 Mdot
.75333 .53309 Mdot
.77319 .29881 Mdot
.46263 .1967 Mdot
.55975 .64142 Mdot
.47845 .27056 Mdot
.64488 .3107 Mdot
.34653 .56135 Mdot
.75665 .60033 Mdot
.56427 .60431 Mdot
.40721 .59094 Mdot
.25643 .4378 Mdot
.30691 .49159 Mdot
.65203 .75224 Mdot
.63184 .22984 Mdot
.64193 .51447 Mdot
.56856 .80495 Mdot
.4551 .38781 Mdot
.61085 .74875 Mdot
.68627 .70024 Mdot
.56279 .61385 Mdot
.44379 .68234 Mdot
.69267 .41031 Mdot
.3926 .46387 Mdot
.41973 .48892 Mdot
.81889 .43874 Mdot
.68686 .62239 Mdot
.38347 .30577 Mdot
.42488 .20864 Mdot
.45866 .35703 Mdot
.52394 .86223 Mdot
.23933 .59737 Mdot
.4898 .2193 Mdot
.47399 .60638 Mdot
.34213 .6431 Mdot
.82198 .39993 Mdot
.73337 .37499 Mdot
.60911 .59848 Mdot
.44877 .4037 Mdot
.41117 .30691 Mdot
.4744 .611 Mdot
.21249 .50822 Mdot
.58052 .23085 Mdot
.25649 .30286 Mdot
.69469 .69715 Mdot
.44851 .31399 Mdot
.55592 .64711 Mdot
.68764 .36506 Mdot
.4081 .83944 Mdot
.44265 .6875 Mdot
.84454 .62047 Mdot
.61267 .37366 Mdot
.80271 .62822 Mdot
.23266 .69875 Mdot
.34825 .43527 Mdot
.49276 .55828 Mdot
.374 .62575 Mdot
.55252 .43184 Mdot
.64759 .51497 Mdot
.43998 .32929 Mdot
.66713 .72889 Mdot
.65264 .62427 Mdot
.79511 .54555 Mdot
.41561 .55971 Mdot
.33958 .25536 Mdot
.22859 .35585 Mdot
.38674 .32129 Mdot
.57901 .60589 Mdot
.52248 .77347 Mdot
.49601 .47535 Mdot
.53733 .5347 Mdot
.65836 .76887 Mdot
.65431 .25796 Mdot
.44193 .30825 Mdot
.83325 .54211 Mdot
.68369 .58346 Mdot
.32144 .7987 Mdot
.65684 .35474 Mdot
.54139 .53083 Mdot
.49915 .47479 Mdot
.23852 .43236 Mdot
.55356 .21578 Mdot
.38036 .77894 Mdot
.78441 .50252 Mdot
.47432 .42018 Mdot
.73506 .55178 Mdot
.68551 .46359 Mdot
.31269 .66647 Mdot
.20017 .39057 Mdot
.78436 .31505 Mdot
.50601 .303 Mdot
.33085 .44193 Mdot
.46402 .38539 Mdot
.2576 .31025 Mdot
.40134 .29116 Mdot
.55464 .6905 Mdot
.65519 .26885 Mdot
.36296 .76225 Mdot
.36284 .82027 Mdot
.32671 .77171 Mdot
.6029 .54695 Mdot
.40292 .74789 Mdot
.75159 .42148 Mdot
.66129 .35305 Mdot
.47044 .50709 Mdot
.55421 .43759 Mdot
.54298 .49016 Mdot
.3454 .36337 Mdot
.21621 .41873 Mdot
.52239 .42354 Mdot
.4433 .82886 Mdot
.31718 .7933 Mdot
.53748 .8409 Mdot
.42011 .72791 Mdot
.40209 .37451 Mdot
.78185 .69436 Mdot
.51917 .19913 Mdot
.36072 .79267 Mdot
.50255 .33942 Mdot
.2177 .31051 Mdot
.76467 .68673 Mdot
.33434 .72582 Mdot
.34145 .27439 Mdot
.19551 .48621 Mdot
.2374 .69733 Mdot
.25811 .27181 Mdot
.72366 .47055 Mdot
.2176 .67643 Mdot
.87489 .57072 Mdot
.51348 .33378 Mdot
.30355 .48782 Mdot
.46568 .26003 Mdot
.74405 .41597 Mdot
.25688 .29294 Mdot
.6047 .38713 Mdot
.48977 .69842 Mdot
.5828 .64988 Mdot
.75604 .52271 Mdot
.66925 .37279 Mdot
.26614 .28114 Mdot
.72009 .60069 Mdot
.69064 .57008 Mdot
.56019 .76439 Mdot
.74075 .70318 Mdot
.56909 .22119 Mdot
.63655 .50554 Mdot
.3819 .36593 Mdot
.63713 .6365 Mdot
.71113 .50369 Mdot
.64829 .41388 Mdot
.46079 .55395 Mdot
.5351 .50926 Mdot
.59818 .84521 Mdot
.55739 .71863 Mdot
.52291 .70805 Mdot
.46815 .36689 Mdot
.26138 .45253 Mdot
.53003 .79831 Mdot
.28843 .40759 Mdot
.28969 .26048 Mdot
.68449 .2819 Mdot
.51213 .83021 Mdot
.312 .45774 Mdot
.72991 .51304 Mdot
.80495 .40589 Mdot
.3485 .54538 Mdot
.62653 .32099 Mdot
.70539 .74347 Mdot
.2828 .42264 Mdot
.43018 .39119 Mdot
.30393 .70476 Mdot
.33296 .68446 Mdot
.27301 .42775 Mdot
.21326 .65693 Mdot
.57009 .77568 Mdot
.49383 .25263 Mdot
.6055 .80947 Mdot
.50068 .6748 Mdot
.74188 .52052 Mdot
.27429 .67262 Mdot
.24855 .29868 Mdot
.49423 .46192 Mdot
.41369 .82958 Mdot
.47261 .51126 Mdot
.76843 .62554 Mdot
.61149 .40502 Mdot
.60016 .21801 Mdot
.22466 .42231 Mdot
.29754 .71104 Mdot
.30295 .32159 Mdot
.38962 .36157 Mdot
.22942 .37385 Mdot
.40852 .63452 Mdot
.767 .60463 Mdot
.70414 .49925 Mdot
.40922 .26678 Mdot
.63763 .57151 Mdot
.2524 .48695 Mdot
.61238 .37606 Mdot
.79075 .59736 Mdot
.42848 .75803 Mdot
.6061 .32616 Mdot
.52842 .3406 Mdot
.64575 .77403 Mdot
.45057 .76195 Mdot
.20347 .41829 Mdot
.52388 .35009 Mdot
.23876 .47389 Mdot
.48164 .19174 Mdot
.28922 .38027 Mdot
.6719 .42665 Mdot
.55544 .6883 Mdot
.44655 .37144 Mdot
.6097 .7965 Mdot
.36593 .32948 Mdot
.74641 .65321 Mdot
.43145 .4698 Mdot
.51314 .78416 Mdot
.57237 .56692 Mdot
.23594 .70067 Mdot
.19485 .48689 Mdot
.77256 .52206 Mdot
.39824 .58566 Mdot
.38053 .47652 Mdot
.32344 .40502 Mdot
.4115 .81249 Mdot
.33452 .33308 Mdot
.71482 .37368 Mdot
.3239 .44499 Mdot
.66666 .30228 Mdot
.1931 .64698 Mdot
.77597 .55107 Mdot
.46855 .50561 Mdot
.72428 .4074 Mdot
.22872 .48193 Mdot
.26051 .50713 Mdot
.57444 .69908 Mdot
.55036 .20608 Mdot
.52298 .66786 Mdot
.51775 .58636 Mdot
.59976 .3798 Mdot
.68299 .25879 Mdot
.58772 .81099 Mdot
.35876 .37638 Mdot
.47198 .4925 Mdot
.66006 .71791 Mdot
.77302 .60354 Mdot
.48541 .12372 Mdot
.64575 .82278 Mdot
.61137 .40429 Mdot
.49543 .54311 Mdot
.79051 .5499 Mdot
.4758 .63771 Mdot
.58979 .24014 Mdot
.63806 .77989 Mdot
.36878 .56633 Mdot
.60618 .72754 Mdot
.20866 .51836 Mdot
.22792 .43869 Mdot
.76072 .65025 Mdot
.33988 .52647 Mdot
.54281 .8649 Mdot
.31395 .74547 Mdot
.23061 .41431 Mdot
.4139 .12987 Mdot
.2286 .39308 Mdot
.40405 .40548 Mdot
.50072 .76486 Mdot
.56132 .84557 Mdot
.48468 .5474 Mdot
.58824 .74516 Mdot
.53506 .33757 Mdot
.77738 .51459 Mdot
.70814 .55079 Mdot
.27511 .35764 Mdot
.24307 .3611 Mdot
.27003 .25898 Mdot
.3431 .64214 Mdot
.82771 .44581 Mdot
.54142 .22603 Mdot
.61856 .81124 Mdot
.23293 .60087 Mdot
.76167 .28579 Mdot
.35142 .81149 Mdot
.74207 .57849 Mdot
.28231 .27276 Mdot
.50205 .7559 Mdot
.80599 .5255 Mdot
.64163 .22207 Mdot
.22106 .61099 Mdot
.66992 .2709 Mdot
.32258 .63106 Mdot
.29573 .35109 Mdot
.73877 .55112 Mdot
.65947 .30722 Mdot
.46915 .51231 Mdot
.68014 .77026 Mdot
.33772 .2325 Mdot
.77208 .48044 Mdot
.62496 .72419 Mdot
.81251 .53596 Mdot
.55902 .81138 Mdot
.44989 .78445 Mdot
.50763 .52615 Mdot
.87112 .5482 Mdot
.71219 .75238 Mdot
.29604 .39522 Mdot
.66582 .42301 Mdot
.33634 .81379 Mdot
.53169 .55774 Mdot
.5403 .3417 Mdot
.25952 .71139 Mdot
.69235 .54851 Mdot
.52863 .49673 Mdot
.66034 .40193 Mdot
.75432 .3958 Mdot
.37927 .26715 Mdot
.65888 .31024 Mdot
.68813 .68805 Mdot
.77739 .47895 Mdot
.34055 .23385 Mdot
.79831 .61131 Mdot
.62852 .34621 Mdot
.45214 .34492 Mdot
.57769 .84682 Mdot
.72923 .3807 Mdot
.69833 .4703 Mdot
.46993 .24293 Mdot
.33686 .32263 Mdot
.32633 .58251 Mdot
.59023 .51038 Mdot
.36329 .45423 Mdot
.74881 .5262 Mdot
.62905 .76595 Mdot
.62979 .32814 Mdot
.90452 .5201 Mdot
.23488 .70448 Mdot
.42773 .2918 Mdot
.57257 .32578 Mdot
.56485 .6238 Mdot
.54596 .8368 Mdot
.32761 .61943 Mdot
.68624 .69877 Mdot
.41097 .20524 Mdot
.79536 .49999 Mdot
.60375 .48525 Mdot
.22652 .65599 Mdot
.37263 .81573 Mdot
.36192 .21231 Mdot
.39969 .827 Mdot
.54666 .38907 Mdot
.5558 .39682 Mdot
.71422 .20978 Mdot
.48353 .82224 Mdot
.60652 .36328 Mdot
.35454 .2715 Mdot
.4416 .28881 Mdot
.57987 .40079 Mdot
.22254 .52592 Mdot
.74693 .46207 Mdot
.70396 .55859 Mdot
.45781 .83587 Mdot
.46297 .37542 Mdot
.47774 .55443 Mdot
.36743 .50763 Mdot
.48112 .52407 Mdot
.66674 .48745 Mdot
.40404 .56383 Mdot
.70363 .56735 Mdot
.52683 .56164 Mdot
.30035 .53013 Mdot
.72079 .46735 Mdot
.19358 .54163 Mdot
.68072 .50853 Mdot
.60387 .55117 Mdot
.50407 .36931 Mdot
.49587 .17985 Mdot
.72099 .59946 Mdot
.71902 .62039 Mdot
.21591 .67062 Mdot
.149 .48359 Mdot
.47701 .58831 Mdot
.55072 .3594 Mdot
.49503 .39284 Mdot
.53886 .20708 Mdot
.48209 .24871 Mdot
.31621 .52846 Mdot
.25514 .50983 Mdot
.53224 .40591 Mdot
.72563 .3961 Mdot
.38422 .5155 Mdot
.62691 .84362 Mdot
.63381 .39267 Mdot
.53477 .24509 Mdot
.39624 .80253 Mdot
.61849 .74555 Mdot
.60161 .52897 Mdot
.55304 .43877 Mdot
.41007 .41848 Mdot
.53348 .56532 Mdot
.69919 .36723 Mdot
.64153 .73839 Mdot
.56102 .82717 Mdot
.62919 .53767 Mdot
.52036 .23983 Mdot
.60825 .43097 Mdot
.62613 .63424 Mdot
.38331 .45371 Mdot
.81481 .45662 Mdot
.61922 .59602 Mdot
.34438 .79212 Mdot
.66987 .57064 Mdot
.69686 .54855 Mdot
.44445 .23876 Mdot
.65985 .80259 Mdot
.32101 .4159 Mdot
.50311 .22841 Mdot
.35483 .3937 Mdot
.29009 .66849 Mdot
.72853 .59656 Mdot
.48642 .62797 Mdot
.52401 .43107 Mdot
.44145 .2871 Mdot
.45963 .85033 Mdot
.73258 .37285 Mdot
.32408 .52024 Mdot
.36555 .74706 Mdot
.48278 .19421 Mdot
.48919 .52502 Mdot
.37082 .15012 Mdot
.33452 .61345 Mdot
.54896 .86334 Mdot
.60764 .76748 Mdot
.4981 .41312 Mdot
.25444 .43224 Mdot
.68529 .39629 Mdot
.46103 .64137 Mdot
.5524 .83312 Mdot
.69819 .37935 Mdot
.28536 .37133 Mdot
.61981 .39206 Mdot
.40571 .42729 Mdot
.71421 .38374 Mdot
.39004 .74228 Mdot
.47898 .70581 Mdot
.34297 .32658 Mdot
.45148 .79026 Mdot
.5362 .56665 Mdot
.19774 .34357 Mdot
.71698 .7403 Mdot
.45024 .81534 Mdot
.41756 .75384 Mdot
.63652 .19195 Mdot
.44292 .4044 Mdot
.66671 .35428 Mdot
.37913 .58729 Mdot
.75402 .4105 Mdot
.27627 .42366 Mdot
.63345 .76035 Mdot
.23878 .47155 Mdot
.49827 .49059 Mdot
.27803 .20541 Mdot
.73707 .57088 Mdot
.36927 .39112 Mdot
.26387 .40573 Mdot
.43112 .82353 Mdot
.63744 .69646 Mdot
.16885 .55875 Mdot
.24014 .62677 Mdot
.6732 .47834 Mdot
.61614 .21358 Mdot
.81834 .57198 Mdot
.37055 .71096 Mdot
.82747 .42748 Mdot
.40393 .76696 Mdot
.72245 .49939 Mdot
.29023 .70203 Mdot
.45925 .35059 Mdot
.42493 .2851 Mdot
.23826 .58386 Mdot
.20128 .52516 Mdot
.55674 .35138 Mdot
.53384 .82198 Mdot
.77883 .34468 Mdot
.6847 .70701 Mdot
.51018 .83948 Mdot
.38208 .49323 Mdot
.47862 .37364 Mdot
.71532 .59675 Mdot
.67049 .58733 Mdot
.48244 .64116 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`2Jooooo`;o0000[Oooool001cooooo00?o0000oooo
ooooool0ROooool2o`0000oooooo0_l0000>ooooo`;o0000WOooool001cooooo00?o0000oooooooo
ool0Poooool2o`0000;ooooo1?l0000Dooooo`;o00002Oooool2o`0009gooooo000Looooo`03o`00
0?oooooooooo08?ooooo0_l00002ooooo`;o00005_ooool2o`0000Gooooo0_l0002Qooooo`007?oo
ool00ol0003oooooooooo`2Pooooo`;o00000oooool3o`000:7ooooo000Looooo`03o`000?oooooo
oooo0:3ooooo0_l00003ooooo`;o0000X_ooool001cooooo00?o0000ooooooooool0[?ooool2o`00
09_ooooo000Looooo`03o`000?oooooooooo0:cooooo0_l0000>ooooo`;o0000Roooool001cooooo
00?o0000ooooooooool0MOooool2o`0004Gooooo0_l0002;ooooo`007?ooool2o`0007Kooooo0_l0
000Mooooo`Co00001_ooool2o`0000?ooooo0ol000000ooooooo0000o`000002ooooo`;o00001?oo
ool2o`0009Kooooo000Looooo`03o`000?oooooooooo08_ooooo0_l00007ooooo`Co00001_ooool2
o`0000?ooooo0ol000000ooooooo0000o`000002ooooo`;o00001?ooool2o`0009Kooooo000Loooo
o`03o`000?oooooooooo06oooooo0_l0000Fooooo`;o00000_ooool2o`0002Sooooo0_l00002oooo
o`Co00002Oooool2o`00087ooooo000Looooo`03o`000?oooooooooo06oooooo0_l0000Fooooo`;o
0000;?ooool2o`0000;ooooo1?l00009ooooo`;o0000POooool001cooooo00?o0000ooooooooool0
P?ooool2o`0002cooooo0_l0000>ooooo`;o0000ROooool001cooooo00?o0000ooooooooool0O_oo
ool4o`0002cooooo0_l0000>ooooo`Co0000Qoooool001cooooo00?o0000ooooooooool0Hoooool2
o`0000Gooooo0_l0000Booooo`;o00005_ooool2o`0002Sooooo0_l00027ooooo`007?ooool00ol0
003oooooooooo`1Sooooo`;o00001Oooool2o`0002[ooooo0_l00009ooooo`;o000000?oooooo`00
0?l00000Xoooool001cooooo00?o0000ooooooooool0Voooool2o`0000;ooooo1?l000000ooooooo
0000o`00000Uooooo`;o0000O?ooool001cooooo00?o0000ooooooooool0Toooool2o`0000Kooooo
2?l0000Xooooo`;o0000O?ooool001cooooo00?o0000ooooooooool0Toooool2o`0000Sooooo0ol0
002Yooooo`007?ooool00ol0003oooooooooo`2]ooooo`Co00000oooool2o`0009?ooooo000Loooo
o`03o`000?oooooooooo08cooooo0_l000000ooooooo0000o`00000Cooooo`;o00001oooool6o`00
0003ooooool0003o000009?ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44
ooooo`Go00001_ooool00ol0003oooooooooo`2<ooooo`;o000000?oooooo`000?l000002?ooool2
o`0000Wooooo0_l00008ooooo`;o000000?oooooo`000?l000000_ooool2o`0001Cooooo0_l00000
0ooooooo0000o`00001iooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0G?ooool4o`0003?ooooo
0_l00004ooooo`;o00000_ooool2o`0000Sooooo0_l00005ooooo`;o00001Oooool2o`0001Cooooo
0_l000000ooooooo0000o`00001iooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0G?ooool4o`00033ooooo0_l0
00000ooooooo0000o`000003ooooo`?o00000_ooool3o`0000Gooooo1?l0000Hooooo`;o00002Ooo
ool2o`0000[ooooo0_l0001_ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0;
ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0002;ooooo`;o00000oooool2o`0000Kooooo0_l00004
ooooo`;o00001Oooool2o`0001[ooooo0_l00009ooooo`;o00002_ooool2o`0006oooooo00000ooo
oooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0
003oooooooooo`1Gooooo`;o0000:Oooool2o`0000Kooooo0ol00006ooooo`;o00005?ooool2o`00
00Cooooo0_l0000Booooo`;o0000Q?ooool00003ooooool@413ooooo00;ooooo00?o410@oooooooo
ool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Oooooo0_l0000Vooooo`Go
00000_ooool2o`0000;ooooo0_l00007ooooo`;o00001_ooool2o`000003ooooool0003o000000Wo
oooo1?l00002ooooo`;o00004Oooool3o`0008Cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMg
M`_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo07;ooooo0_l00002
ooooo`;o00001oooool3o`0000Cooooo0_l0000Cooooo`Go00002?ooool5o`00013ooooo0_l00003
ooooo`;o00003_ooool2o`00013ooooo0_l0001Sooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1booooo`;o0000
0_ooool2o`0000Cooooo0_l00005ooooo`;o00000_ooool2o`0000Cooooo1Ol0000:ooooo`?o0000
1?ooool4o`000003ooooool0003o000000;o000000?oooooo`000?l000001Oooool2o`0000Oooooo
0_l00005ooooo`;o00003?ooool2o`00013ooooo0_l0001Sooooo`007?ooool00ol0003ooooooooo
o`1hooooo`;o00000_ooool2o`0000Gooooo0_l00002ooooo`;o00001?ooool5o`0000Cooooo0_l0
0007ooooo`;o000000?oooooo`000?l000000ol00006ooooo`;o000000?oooooo`000?l000000_oo
ool2o`0000;ooooo1?l000000ooooooo0000o`000002o`0000?ooooo0_l00023ooooo`007?ooool0
0ol0003oooooooooo`1hooooo`;o00001oooool3o`0000Sooooo0_l00007ooooo`?o00000_ooool3
o`0000;ooooo1Ol00006ooooo`;o00001?ooool2o`0000?ooooo0_l000000ooooooo0000o`000002
o`0000;ooooo0ol00028ooooo`007?ooool00ol0003oooooooooo`1hooooo`;o00001oooool3o`00
00Sooooo0_l00005ooooo`Co00000oooool3o`0000;ooooo1?l00007ooooo`;o00001?ooool4o`00
0003ooooool0003o000000[ooooo1?l00008ooooo`;o0000N_ooool001cooooo00?o0000oooooooo
ool0Koooool4o`0000Gooooo0_l00004ooooo`;o00001?ooool3o`0000Wooooo0_l000001?oooooo
0000o`000?ooool2o`0001Cooooo0_l00002ooooo`Co000000?oooooo`000?l000002_ooool4o`00
00Sooooo1?l0000;ooooo`;o0000Joooool001cooooo00?o0000ooooooooool0Koooool4o`0000_o
oooo0_l00004ooooo`?o00002Oooool2o`0000;ooooo1?l00008ooooo`Co00002?ooool2o`0000Oo
oooo0_l00002ooooo`;o00000_ooool2o`0000Kooooo0_l00002ooooo`;o00001?ooool2o`0000_o
oooo0_l0001[ooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o00000oooool3o`0000cooooo
0_l0000Eooooo`?o000000?oooooo`000?l000000_l00008ooooo`Co00003Oooool2o`0000Kooooo
0_l00002ooooo`;o00001_ooool2o`0000;ooooo0_l00007ooooo`;o0000MOooool001cooooo00?o
0000ooooooooool0IOooool2o`0000?ooooo0ol0000<ooooo`;o00002oooool2o`0000Sooooo2?l0
000Iooooo`;o00007oooool3o`0007Cooooo000Looooo`03o`000?oooooooooo06Kooooo0_l0000N
ooooo`;o00001Oooool2o`0000Cooooo0ol0000?ooooo`;o00000_ooool2o`0000gooooo0_l00008
ooooo`;o00002_ooool2o`0000?ooooo0_l0001dooooo`007?ooool00ol0003oooooooooo`1Roooo
o`;o00000_ooool2o`0000;ooooo0_l0000=ooooo`Co00001oooool2o`0000Oooooo0_l00006oooo
o`;o00003Oooool3o`0000;ooooo0_l0000=ooooo`;o00000_ooool2o`0000Cooooo0_l0000:oooo
o`;o0000NOooool001cooooo00?o0000ooooooooool0H_ooool2o`0000Kooooo0_l0000=ooooo`Ko
00001Oooool2o`0000Oooooo0_l000000ooooooo0000o`000003ooooo`;o00002?ooool2o`0000?o
oooo0_l00004ooooo`;o00004?ooool2o`0000oooooo0_l0000Iooooo`;o0000Goooool001cooooo
00?o0000ooooooooool0JOooool2o`0001;ooooo0_l0000>ooooo`;o000000?oooooo`000?l00000
1oooool2o`0000Cooooo0_l00009ooooo`;o00006_ooool2o`0000Gooooo1?l00006ooooo`;o0000
3oooool2o`000003ooooool0003o000005cooooo000Looooo`;o0000A_ooool2o`0001oooooo1Ol0
000<ooooo`;o00002?ooool2o`0000Cooooo0ol00003ooooo`;o00002_ooool2o`0002_ooooo0_l0
0007ooooo`;o00001?ooool4o`0001;ooooo0_l0001Looooo`007?ooool00ol0003oooooooooo`15
ooooo`;o00007oooool4o`000003ooooool0003o000000[ooooo0_l00008ooooo`;o00001?ooool4
o`0001;ooooo0_l0000fooooo`;o00005?ooool3o`0005_ooooo000Looooo`03o`000?oooooooooo
05[ooooo0_l00009ooooo`;o00001?ooool2o`0001cooooo0_l0000Booooo`;o0000<_ooool2o`00
01Wooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o00001?ooool2o`0000?o
oooo0_l00004ooooo`;o00001_ooool2o`0001oooooo0_l00004ooooo`;o0000>oooool2o`0000?o
oooo0_l00002ooooo`;o00005Oooool2o`0005Kooooo000Looooo`03o`000?oooooooooo05Cooooo
0_l00004ooooo`?o00000_ooool2o`0000cooooo0_l00008ooooo`;o00005Oooool2o`0000Cooooo
0_l0000iooooo`;o00001Oooool8o`0001?ooooo0_l0001Fooooo`007?ooool00ol0003ooooooooo
o`1Kooooo`;o00005oooool5o`0000Sooooo0_l00007ooooo`;o00000oooool2o`0001Oooooo0_l0
000Uooooo`;o00001oooool2o`0000;ooooo0_l0001[ooooo`007?ooool00ol0003oooooooooo`1A
ooooo`;o00001?ooool2o`00017ooooo0_l000000ooooooo0000o`000005ooooo`Go000000?ooooo
o`000?l000001Oooool2o`0000Oooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo0ol00007
ooooo`;o00001Oooool2o`0002Oooooo0ol00009ooooo`;o0000J_ooool001cooooo00?o0000oooo
ooooool0D?ooool3o`0000Cooooo0ol00009ooooo`;o00001Oooool2o`000003ooooool0003o0000
00;o00000_ooool4o`0000?ooooo0_l000000ooooooo0000o`00000Dooooo`;o00000_ooool3o`00
00Oooooo0_l00006ooooo`;o00009_ooool3o`0000;ooooo0_l00005ooooo`;o0000J_ooool001co
oooo00?o0000ooooooooool0D?ooool2o`0000Kooooo0_l00009ooooo`;o00001_ooool2o`0000;o
oooo0_l00002ooooo`Co00001_ooool2o`0000Cooooo0_l0000Sooooo`?o0000:oooool2o`00077o
oooo000Looooo`03o`000?oooooooooo06_ooooo0_l00005ooooo`;o000000?oooooo`000?l00000
3?ooool2o`0002?ooooo0_l0000aooooo`Co0000J_ooool001cooooo00?o0000ooooooooool0Dooo
ool2o`0001Kooooo0_l00005ooooo`;o00001oooool2o`0000Sooooo0_l0001Dooooo`Co0000J_oo
ool001cooooo00?o0000ooooooooool0Doooool2o`0000_ooooo0_l00007ooooo`;o00002oooool2
o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`Go00002Oooool2o`0000Oooooo0_l0000o
ooooo`Co000000?oooooo`000?l000004_ooool2o`0005?ooooo000Looooo`03o`000?oooooooooo
04Wooooo0_l0000Eooooo`;o00001oooool2o`0000_ooooo0_l00006ooooo`;o00000oooool5o`00
0004ooooool0003o0000ooooo`;o000000?oooooo`000?l000000_l00007ooooo`;o000000?ooooo
o`000?l00000?_ooool2o`000003ooooool0003o000001;ooooo0_l0001Cooooo`007?ooool00ol0
003oooooooooo`19ooooo`;o00007Oooool2o`0001;ooooo1Ol00002ooooo`;o000000?oooooo`00
0?l000000ol000001?oooooo0000o`000?ooool2o`0000cooooo0_l000000ooooooo0000o`000006
ooooo`;o00007?ooool3o`0001Gooooo0_l0001Yooooo`007?ooool00ol0003oooooooooo`1@oooo
o`;o00005_ooool2o`0001;ooooo1Ol00002ooooo`;o000000?oooooo`000?l000000_l00009oooo
o`;o00002oooool3o`0000Gooooo0_l0000Looooo`?o00002Oooool2o`000003ooooool0003o0000
00Oooooo1?l0001Wooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00006?ooool2o`00017o
oooo0_l00002ooooo`Wo00001oooool4o`0000cooooo0_l0000_ooooo`;o000000?oooooo`000?l0
00001oooool4o`0006Oooooo000Looooo`;o0000C?ooool4o`0001_ooooo0ol0000>ooooo`;o0000
1?ooool:o`0000Kooooo0_l0000;ooooo`;o00002?ooool2o`0002Sooooo0_l0000:ooooo`;o0000
1?ooool2o`00017ooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`1;ooooo`Oo00003ooo
ool4o`0000Gooooo0ol0000>ooooo`;o000000?oooooo`000?l000000ol000000ooooooo0000o`00
0005o`0000Oooooo0_l0000:ooooo`;o000000?oooooo`000?l000001Oooool2o`0001Cooooo0_l0
000Eooooo`;o000000Coooooo`000?l0003o00001oooool4o`00017ooooo0_l0001@ooooo`007?oo
ool00ol0003oooooooooo`1>ooooo`Go00002oooool2o`000003ooooool0003o000000;o00004?oo
ool7o`0000;ooooo0ol000000ooooooo0000o`00000;o`000003ooooool0003o000000;o00003Ooo
ool2o`0000?ooooo0_l0000Fooooo`;o00001_ooool2o`0000Cooooo0_l00004ooooo`;o000000Co
ooooo`000?l0003ooooo0ol00007ooooo`;o0000IOooool001cooooo00?o0000ooooooooool0@ooo
ool2o`0000Cooooo0_l00005ooooo`?o00002oooool4o`0000Wooooo0_l00008ooooo`Oo000000?o
ooooo`000?l000004ol0000Dooooo`;o00007_ooool2o`0000?ooooo1Ol00002ooooo`;o000000?o
ooooo`000?l000001?ooool2o`0000Cooooo0ol00004ooooo`;o00003oooool2o`0004kooooo000L
ooooo`03o`000?oooooooooo03Gooooo0_l0000<ooooo`;o00001?ooool2o`0000Gooooo0_l0000=
ooooo`?o00000oooool2o`0000Cooooo0ol0000:ooooo`?o00000_oooolCo`0000Gooooo0_l0000_
ooooo`;o00000oooool2o`000005ooooool0003o0000o`000?ooool00_l00007ooooo`;o00001?oo
ool4o`0000?ooooo0_l0000?ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0=Oooool2
o`0002Sooooo0_l00004ooooo`;o00001Oooool2o`0000;ooooo0_l00005ooooo`Co00000_oooolC
o`0000;ooooo0_l000001?oooooo0000o`000?l0000Uooooo`?o00001_ooool2o`0000Kooooo1_l0
000=ooooo`Go00001Oooool2o`0000kooooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`1E
ooooo`;o00001oooool2o`00013ooooo1?l00003ooooo`Co000000?oooooo`000?l000005_l00002
ooooo`;o00009?ooool4o`0000Kooooo0_l00009ooooo`?o000000?oooooo`000?l000003Oooool2
o`0000Gooooo0_l0000>ooooo`;o00001?ooool2o`0004Kooooo000Looooo`03o`000?oooooooooo
05Gooooo0_l00006ooooo`Co000000?oooooo`000?l000001_ooool2o`0000Gooooo1Ol000001?oo
oooo0000o`000?oooolHo`0000;ooooo0_l0000Vooooo`;o00002Oooool3o`0000_ooooo1?l0000B
ooooo`;o00005?ooool2o`0004Kooooo000Looooo`03o`000?oooooooooo05Kooooo0ol00004oooo
o`Oo00001_ooool2o`0000Sooooo0_l000000ooooooo0000o`00000Io`0000;ooooo0_l0000@oooo
o`;o00001Oooool2o`0000Oooooo0_l00008ooooo`?o00001?ooool5o`0000Wooooo1?l0000Boooo
o`;o0000G?ooool001cooooo00?o0000ooooooooool0DOooool2o`0000?ooooo0ol000000ooooooo
0000o`000005ooooo`;o00002Oooool2o`0000Wooooo2Ol000000ooooooo0000o`00000?o`0000Oo
oooo0_l0000;ooooo`;o00001Oooool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o
00000oooool4o`0000Kooooo0ol00009ooooo`Go0000Koooool001cooooo00?o0000ooooooooool0
Boooool2o`0000Cooooo0_l00007ooooo`;o00004?ooool2o`0000Gooooo0_l000000ooooooo0000
o`000008o`000003ooooool0003o000000oo00001oooool2o`0001Gooooo0_l00008ooooo`;o0000
0oooool2o`0000Sooooo0_l00005ooooo`;o000000Coooooo`000?l0003ooooo1_l0000Aooooo`;o
0000F_ooool001cooooo00?o0000ooooooooool0Boooool2o`0000Sooooo0_l00003ooooo`;o0000
1oooool2o`0000Cooooo0_l000000ooooooo0000o`000005ooooo`Go00000_ooool6o`000003oooo
ool0003o000000Oo00000_ooool7o`0000;ooooo0_l0000<ooooo`;o00004Oooool2o`0000Cooooo
0_l000000ooooooo0000o`00000;ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o
00000_ooool4o`0000oooooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`18ooooo`;o0000
00Coooooo`000?l0003ooooo0_l00005ooooo`;o00003?ooool3o`0000?ooooo0_l0000:ooooo`;o
000000?oooooo`000?l000006Ol00002ooooo`;o00001?ooool2o`000003ooooool0003o000000?o
oooo0_l00005ooooo`;o00002_ooool2o`0000Cooooo0_l00003ooooo`;o00000_ooool2o`0000Go
oooo0_l00008ooooo`;o00001?ooool2o`00013ooooo0_l0001Iooooo`007?ooool00ol0003ooooo
ooooo`0^ooooo`;o00006?ooool2o`000004ooooool0003o0000ooooo`;o00001Oooool2o`0000go
oooo0_l0000;ooooo`;o00000ooooolKo`000003ooooool0003o000000;o00001Oooool2o`000004
ooooool0003o0000o`0000Oooooo1_l0000Cooooo`;o00000_ooool2o`000003ooooool0003o0000
023ooooo0_l00002ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0;_ooool2o`0000go
oooo0_l0000<ooooo`;o00002?ooool3o`0000?ooooo0_l0000=ooooo`?o00001?ooool2o`0000?o
oooo6ol000000ooooooo0000o`000003o`0000Sooooo0_l00007ooooo`;o00000_ooool4o`0000;o
oooo0_l00004ooooo`?o00003?ooool3o`0001_ooooo0_l00003ooooo`;o00003Oooool2o`0004ko
oooo000Looooo`03o`000?oooooooooo03gooooo0_l0000Gooooo`?o00000_ooool2o`0000gooooo
0ol00006ooooo`?o000000?oooooo`000?l000000_l000000ooooooo0000o`00000Io`00017ooooo
0_l00003ooooo`?o00000_ooool2o`0000Cooooo0ol0000<ooooo`?o00005oooool2o`0000;ooooo
0_l0000Booooo`;o0000C_ooool001cooooo0_l0001Gooooo`?o00003oooool2o`0000Wooooo0ol0
00000ooooooo0000o`000002o`000003ooooool0003o000001Ko00004_ooool4o`0001kooooo0_l0
000Gooooo`;o00003_ooool2o`0000Oooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`15
ooooo`;o00003oooool2o`0000Cooooo0_l0000:ooooo`;o00003Oooool2o`000003ooooool0003o
000001So00001?ooool2o`0000?ooooo0_l00007ooooo`;o00000oooool2o`0000Cooooo0_l0000P
ooooo`;o00007?ooool2o`0000Oooooo0ol00004ooooo`;o0000A_ooool001cooooo00?o0000oooo
ooooool0AOooool4o`0000gooooo0_l00004ooooo`;o00005Oooool2o`0000;ooooo9?l00002oooo
o`Co00002_ooool2o`0000Cooooo0_l00005ooooo`;o00003Oooool2o`0000Oooooo1ol0000Toooo
o`;o00001?ooool2o`0004Kooooo000Looooo`03o`000?oooooooooo04Oooooo0_l00003ooooo`;o
00002?ooool2o`00013ooooo0_l00009ooooo`;o00000_ooool3o`000003ooooool0003o000001_o
000000?oooooo`000?l000000_ooool4o`0000Gooooo1?l00005ooooo`;o00001oooool2o`0000co
oooo0ol00007ooooo`Co000000?oooooo`000?l000009?ooool2o`0000[ooooo0_l00010ooooo`00
7?ooool00ol0003oooooooooo`0Zooooo`;o00007oooool3o`0000Sooooo0_l00004ooooo`;o0000
2_ooool2o`0000kooooo0_l000000ooooooo0000o`00000Bo`0000;ooooo0_l00007ooooo`;o0000
2_ooool4o`0000Gooooo0_l00006ooooo`;o00000oooool4o`000003ooooool0003o000000?ooooo
0ol00009ooooo`;o00006Oooool2o`0000Cooooo0_l00006ooooo`;o00001Oooool2o`0000?ooooo
0_l00010ooooo`007?ooool00ol0003oooooooooo`0Zooooo`;o00007oooool4o`0000gooooo0_l0
000>ooooo`;o00002_ooool2o`000003ooooool0003o000000go000000?oooooo`000?l000000ol0
00001Ooooooo0000o`000?l0003ooooo00;o00000oooool2o`0001_ooooo1?l000000ooooooo0000
o`000002o`000003ooooool0003o000000Cooooo0_l00003ooooo`;o00000_ooool2o`000003oooo
ool0003o000000;ooooo0_l00002ooooo`?o00003?ooool5o`0000Cooooo0_l0000=ooooo`?o0000
A?ooool001cooooo00?o0000ooooooooool0@Oooool2o`0000[ooooo0_l0000=ooooo`;o00003_oo
ool2o`0000[ooooo0_l00002oooooa_o00000_ooool2o`0000Gooooo0_l0000Gooooo`Oo00001Ooo
ool2o`0000Gooooo1_l000000ooooooo0000o`000002ooooo`;o00000_ooool3o`000003ooooool0
003o000000Wooooo1?l00005ooooo`;o00003_ooool2o`0004Cooooo000Looooo`03o`000?oooooo
oooo03oooooo1?l00009ooooo`?o00002Oooool3o`0001oooooo0_l000000ooooooo0000o`00000G
o`000003ooooool0003o000000?o00000oooool7o`0001Gooooo0_l00003ooooo`;o00000oooool2
o`0000Oooooo0ol0000>ooooo`;o00002?ooool2o`0005kooooo000Looooo`03o`000?oooooooooo
03oooooo0_l00006ooooo`;o00000_ooool4o`0000Wooooo1Ol00003ooooo`Co00005_ooool2o`00
0003ooooool0003o000001Ko00000_ooool5o`0000?ooooo0_l000000ooooooo0000o`000002o`00
00_ooooo0_l00007ooooo`;o00001?ooool2o`000003ooooool0003o000000;o00000oooool2o`00
00;ooooo0ol000000ooooooo0000o`000004o`0000cooooo0_l00003ooooo`?o00002?ooool2o`00
00Wooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`17ooooo`;o00000_ooool2o`0000co
oooo1_l000000ooooooo0000o`000002o`0000gooooo0_l00003ooooo`;o00000_ooool2o`000003
ooooool0003o000001?o000000Coooooo`000?l0003o00000_ooool2o`0000Cooooo0_l0000Aoooo
o`;o000000?oooooo`000?l000001?ooool2o`0000Oooooo1?l00002ooooo`?o00000_ooool:o`00
00Kooooo0_l00004ooooo`?o00000oooool2o`0000Sooooo0_l00009ooooo`;o0000B?ooool001co
oooo00?o0000ooooooooool09_ooool2o`0002;ooooo0_l0000>ooooo`;o000000?oooooo`000?l0
00004_ooool2o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000004Ol00003ooooo`?o
00002?ooool4o`0000_ooooo0_l00004ooooo`Co00000oooool2o`0000;ooooo1ol00004ooooo`;o
00000oooool6o`0000;ooooo0_l00006ooooo`?o00001?ooool2o`0000;ooooo0_l0000Kooooo`;o
0000@Oooool001cooooo00?o0000ooooooooool09_ooool2o`0002;ooooo0_l00008ooooo`;o0000
1?ooool2o`000003ooooool0003o000000cooooo0ol00004ooooo`;o00002_ooool2o`0000;ooooo
4?l000000ooooooo0000o`00000;ooooo`;o00002oooool2o`0000;ooooo1_l00003ooooo`;o0000
00?oooooo`000?l000001Ol00002ooooo`;o00001?ooool2o`0000oooooo1?l00003ooooo`;o0000
0oooool4o`0001Wooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`1:ooooo`?o00001ooo
ool3o`0000;ooooo0ol000000ooooooo0000o`00000<ooooo`Co00000oooool2o`0000[ooooo0_l0
00001?oooooo0000o`000?oooolAo`0000Cooooo0_l0000Fooooo`?o00001Oooool7o`000003oooo
ool0003o000000Ko00000oooool2o`0000oooooo0_l00004ooooo`?o00001Oooool2o`0005cooooo
000Looooo`03o`000?oooooooooo03gooooo0_l00006ooooo`;o00000oooool3o`0000Sooooo0_l0
0002ooooo`?o000000?oooooo`000?l000002_ooool2o`000004ooooool0003o0000o`0000?ooooo
0ol00004ooooo`;o00001_ooool2o`0000?ooooo1ol000000ooooooo0000o`000005o`000004oooo
ool0003o0000ooooo`;o00001Oooool2o`0000cooooo0_l00002ooooo`;o00001?oooolAo`0001Oo
oooo0_l000000ooooooo0000o`00000;ooooo`;o00000oooool2o`0000?ooooo0_l0001=ooooo`00
00Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo
00Cooooo00?o0000ooooooooool0?Oooool2o`0000Gooooo1Ol00002ooooo`;o00004?ooool2o`00
00Sooooo1?l00005ooooo`Ko00000oooool2o`0000gooooo0_l000001?oooooo0000o`000?ooool2
o`000003ooooool0003o000000?ooooo0_l00005ooooo`;o000000?oooooo`000?l000001?ooool2
o`0000Kooooo0_l00007ooooo`Co00000_oooolBo`0000?ooooo0_l00003ooooo`Go00001?ooool2
o`0000kooooo0_l00003ooooo`;o00000oooool2o`0004gooooo00001_ooooooMgMgoiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0A?oo
ool5o`0000Cooooo0_l0000=ooooo`;o00002Oooool3o`0000Kooooo0_l00002ooooo`;o00003_oo
ool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000gooooo0_l00007ooooo`Go0000
1_ooool4o`0000;ooooo1?l000001?oooooo0000o`000?oooolBo`000003ooooool0003o000000;o
000000?oooooo`000?l000001?l0000;ooooo`;o00001oooool2o`0000cooooo0_l00018ooooo`00
00?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`Go00001_ooool00ol0003ooooo
ooooo`0Rooooo`;o00008Oooool3o`0000Gooooo0_l00003ooooo`;o00002?ooool2o`0000Cooooo
0_l00004ooooo`;o00006_ooool2o`0000Gooooo0_l0000=ooooo`;o00002_ooool5o`0000;ooooo
0_l00002ooooob3o000000?oooooo`000?l000000_l00003ooooo`Co00002oooool2o`0000Oooooo
0_l00002ooooo`;o00002?ooool2o`0000Kooooo0_l00010ooooo`0000?oooooo`000?ooool00_oo
ool00ol0003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0000Rooooo`;o0000
8Oooool2o`0000_ooooo0_l0000>ooooo`;o00001_ooool2o`0001;ooooo0_l00003ooooo`Co0000
0oooool3o`000003ooooool0003o000000[ooooo0_l00005ooooo`;o00000oooool2o`0000;ooooo
0_l000000ooooooo0000o`000003ooooobGo00000_ooool2o`0000_ooooo0_l0000=ooooo`;o0000
4?ooool2o`00043ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Co
gMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`1Booooo`Co00000oooool2o`0000Cooooo
0_l00004ooooo`;o00000oooool4o`00013ooooo1?l000000ooooooo0000o`000002o`0000?ooooo
1_l0000:ooooo`;o00000oooool4o`0000Cooooo1ol00002oooooaGo000000?oooooo`000?l00000
4?l00002ooooo`;o00002_ooool2o`0000cooooo0ol0000;ooooo`;o0000AOooool00003ooooool@
413ooooo00;ooooo00?o410@ooooooooool02_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oo
oooooooo03cooooo0_l00003ooooo`;o00003oooool5o`0000;ooooo0ol00003ooooo`;o00000_oo
ool4o`0000Cooooo0ol0000:ooooo`;o00001Oooool3o`0000;ooooo0ol00005ooooo`Co00002_oo
ool2o`0000?ooooo1?l00004ooooo`Co000000?oooooo`000?l000000_oooolEo`000003ooooool0
003o000000Wo00000_ooool5o`0000;ooooo0_l00002ooooo`;o00001Oooool4o`0000Oooooo0_l0
0002ooooo`?o00000_ooool2o`0000Kooooo0ol00015ooooo`0000KoooooogMgMonHV9SooooooiRH
V?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0??ooool2o`0000?ooooo
0_l0000Aooooo`?o00000oooool3o`0000Kooooo0_l00004ooooo`;o00001_ooool2o`0000?ooooo
1?l00005ooooo`;o000000?oooooo`000?l000001?l00002ooooo`;o00001_ooool2o`0000Gooooo
0ol00005ooooo`;o00002?ooool4o`0000;ooooo1?l000000ooooooo0000o`00000=o`000003oooo
ool0003o000000co00000_ooool2o`0000;ooooo1_l00005ooooo`Co00001oooool3o`000003oooo
ool0003o000000;o000000?oooooo`000?l000001_ooool2o`0004Kooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`11ooooo`;o
00001?ooool2o`0000oooooo0_l000000ooooooo0000o`000009ooooo`;o000000?oooooo`000?l0
00001_ooool2o`0000?ooooo0_l00002ooooo`;o00001_ooool6o`0000;ooooo0ol00005ooooo`;o
00001Oooool2o`0000?ooooo0_l00008ooooo`;o000000?oooooo`000?l000000_l00002ooooo`co
000000?oooooo`000?l000001Ol000000ooooooo0000o`00000=o`000003ooooool0003o000000Oo
00003Oooool2o`0000?ooooo0_l000000ooooooo0000o`000003o`0000?ooooo0_l00007ooooo`;o
0000@_ooool001cooooo00?o0000ooooooooool0?_ooool2o`000003ooooool0003o000000;o0000
0_ooool2o`0000oooooo0_l00006ooooo`;o000000?oooooo`000?l000000ol00004ooooo`;o0000
00?oooooo`000?l000002Oooool2o`0000Gooooo0_l00003ooooo`;o00000oooool2o`00017ooooo
0ol000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000
o`00000Ho`000003ooooool0003o000000So00000_ooool3o`000003ooooool0003o000000Cooooo
0_l000000ooooooo0000o`000006ooooo`Co00000_ooool4o`000003ooooool0003o000000?ooooo
0_l00007ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0?_ooool2o`000003ooooool0
003o000000;o00004oooool2o`0000Kooooo0_l000000ooooooo0000o`000002o`000003ooooool0
003o000000;ooooo1_l00003ooooo`;o00000oooool4o`0000?ooooo0_l00003ooooo`Co00002Ooo
ool2o`000003ooooool0003o000000Oooooo0_l000000ooooooo0000o`000004ooooo`;o000000?o
ooooo`000?l000003ol000000ooooooo0000o`00000Jo`0000Cooooo0_l00002ooooo`;o000000?o
ooooo`000?l000002?ooool7o`0000?ooooo0_l000001?oooooo0000o`000?l0001;ooooo`007?oo
ool00ol0003oooooooooo`12ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Sooooo1?l0
000>ooooo`;o00001?ooool4o`0000?ooooo0_l00003ooooo`Ko000000?oooooo`000?l000001Ooo
ool2o`0000Gooooo2Ol00006ooooo`;o00001_ooool2o`0000?ooooo1Ol00003ooooobSo000000Co
ooooo`000?l0003o00004Oooool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000
o`000008ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0>Oooool2o`0000[ooooo0_l0
0005ooooo`?o00001_ooool5o`0000kooooo0_l00008ooooo`?o00001_ooool2o`000003ooooool0
003o000000?o00000oooool2o`0000?ooooo0_l00002ooooo`Co00000_ooool3o`0000?ooooo0_l0
00000ooooooo0000o`000002o`0000Cooooo0_l00002ooooo`Ko00000ooooolIo`000003ooooool0
003o000000co000000?oooooo`000?l000000_l00003ooooo`Co00003?ooool2o`00013ooooo0_l0
0002ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0>?ooool3o`0001;ooooo0_l00006
ooooo`;o00001_ooool3o`0000Sooooo0_l000000ooooooo0000o`000003ooooo`Go00000_ooool2
o`0000Oooooo0_l00004ooooo`;o000000?oooooo`000?l000000_l0000>ooooo`;o00000oooool2
o`0000Cooooo0_l000000ooooooo0000o`000007o`000004ooooool0003o0000ooooob[o00000ooo
ool5o`0000_ooooo0_l000000ooooooo0000o`00000Aooooo`;o0000?_ooool001cooooo00?o0000
ooooooooool0>?ooool2o`0000cooooo0_l00002ooooo`;o00000oooool2o`0000Cooooo0_l00006
ooooo`?o00002oooool2o`0000?ooooo1Ol00002ooooo`;o00000oooool2o`0000;ooooo0_l00005
ooooo`Co00004_ooool2o`0000Oooooo0_l000001Ooooooo0000o`000?l0003ooooo02co00000_oo
ool2o`0000Kooooo1_l0000:ooooo`Go000000?oooooo`000?l000001?l0001:ooooo`007?ooool0
0ol0003oooooooooo`0oooooo`;o00001Oooool2o`0000;ooooo0_l00003ooooo`;o00001?ooool2
o`0000Kooooo0ol0000=ooooo`;o000000?oooooo`000?l000000ol00007ooooo`;o00000_ooool2
o`0000Gooooo0_l0000;ooooo`;o00001oooool2o`0000_ooooo1Ol000000ooooooo0000o`00000V
o`0000;ooooo0_l00007ooooo`;o00000_ooool2o`0000Cooooo0_l00006ooooo`;o000000?ooooo
o`000?l000001Ol0001:ooooo`007?ooool00ol0003oooooooooo`0Looooo`;o00008?ooool3o`00
00Gooooo0_l000000ooooooo0000o`000004ooooo`?o00002oooool4o`0000cooooo1Ol000001?oo
oooo0000o`000?l00009ooooo`?o00004_ooool3o`0000oooooo0_l000000ooooooo0000o`000008
o`000003ooooool0003o0000027o00000_ooool7o`0000gooooo0_l00006ooooo`Oo000000?ooooo
o`000?l000001oooool2o`00047ooooo000Looooo`03o`000?oooooooooo01cooooo0_l0000Poooo
o`Co00001?ooool5o`0000Gooooo1?l0000:ooooo`?o00001oooool2o`0000Cooooo0ol00002oooo
o`?o000000?oooooo`000?l000000ol00003ooooo`?o00004oooool2o`0000?ooooo0_l0000:oooo
o`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000002o`000003ooooool0003o0000
027o000000?oooooo`000?l000001ol00002ooooo`;o00004Oooool7o`000003ooooool0003o0000
00Oooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0nooooo`Co00001_ooool2o`0000So
oooo0_l0000:ooooo`?o00001?ooool2o`000003ooooool0003o000000;o00000_ooool2o`000003
ooooool0003o000000;ooooo1ol00006ooooo`;o00005_ooool2o`0000oooooo;_l00003ooooo`;o
00001?ooool2o`0000Gooooo0_l00009ooooo`Go00000_ooool3o`0000Gooooo0_l00004ooooo`;o
0000?_ooool001cooooo00?o0000ooooooooool0<_ooool2o`000003ooooool0003o000000Oooooo
0_l000000ooooooo0000o`00000>ooooo`Co00002_ooool2o`0000Cooooo0_l00003ooooo`;o0000
0_ooool5o`0000;ooooo0_l0000;ooooo`;o00000oooool2o`0001Gooooo0_l00003ooooo`;o0000
0oooool2o`0000?ooooo;?l00003ooooo`Co00002Oooool2o`0000Cooooo0_l00003ooooo`?o0000
1?ooool3o`0000Gooooo0_l00004ooooo`;o0000?_ooool001cooooo0_l0000cooooo`;o000000?o
ooooo`000?l000002_ooool2o`0000kooooo1?l00004ooooo`;o00001?ooool2o`000004ooooool0
003o0000ooooo`;o00001oooool5o`0000Cooooo0_l000000ooooooo0000o`000003o`0000Sooooo
0_l0000Eooooo`;o00000oooool2o`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l00000
9Ol00006ooooo`;o00002oooool2o`0000;ooooo0_l0000;ooooo`;o00000_ooool3o`0000Cooooo
1?l0000nooooo`007?ooool00ol0003oooooooooo`0booooo`;o00005Oooool2o`0000Kooooo0_l0
0002ooooo`;o00000_ooool2o`0000Oooooo0_l000000ooooooo0000o`000006ooooo`?o000000Co
ooooo`000?l0003o00000oooool:o`0002Wooooo0_l00002ooooo`;o000000?oooooo`000?l00000
9Ol00008ooooo`;o00001_ooool2o`000003ooooool0003o000000Sooooo0_l00007ooooo`Go0000
1?ooool4o`0003kooooo000Looooo`03o`000?oooooooooo01Wooooo0_l0000Jooooo`;o00003_oo
ool2o`0000;ooooo0_l000001?oooooo0000o`000?l00006ooooo`;o00001Oooool2o`0000?ooooo
0ol00009ooooo`?o000000Coooooo`000?l0003o00001Oooool2o`000004ooooool0003o0000oooo
o`;o00009Oooool2o`0000;ooooo0_l00007oooooako000000?oooooo`000?l000001?l00004oooo
o`;o00000_ooool2o`0000Kooooo0_l00005ooooo`;o000000Coooooo`000?l0003ooooo0_l00006
ooooo`?o00001Oooool2o`0004;ooooo000Looooo`03o`000?oooooooooo01Wooooo0_l0000Joooo
o`;o00003_ooool2o`0000Gooooo0ol00003ooooo`Co00000_ooool2o`0000;ooooo0_l00003oooo
o`?o00003_ooool3o`0000Oooooo0_l000000ooooooo0000o`00000Looooo`;o00001oooool2o`00
00?ooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000001_o000000?ooooo
o`000?l000001Ol000000ooooooo0000o`000004o`0000oooooo0_l000000ooooooo0000o`000002
o`0000Oooooo0_l00006ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0D_ooool4o`00
00;ooooo1?l00007ooooo`;o00003Oooool3o`0000Oooooo1_l0000Kooooo`;o00001?ooool2o`00
00Kooooo0_l000000ooooooo0000o`00000Qo`000004ooooool0003o0000ooooo`Co000000Gooooo
o`000?l0003o0000ooooo`02o`0000oooooo0_l000000ooooooo0000o`000002o`0001Oooooo0_l0
000jooooo`007?ooool00ol0003oooooooooo`1Hooooo`Co00001oooool2o`0000cooooo0_l00009
ooooo`Oo00003Oooool2o`0000?ooooo0_l00006ooooo`Co000000?oooooo`000?l000000_l00005
ooooo`;o00000_ooool3o`000003ooooool0003o000001co000000?oooooo`000?l000000ol00000
1?oooooo0000o`000?ooool2o`000004ooooool0003o0000o`0000Gooooo0_l00005ooooo`Co0000
00?oooooo`000?l000002?ooool2o`000003ooooool0003o000000cooooo0_l0000jooooo`007?oo
ool00ol0003oooooooooo`1Fooooo`;o00003oooool2o`0000;ooooo0_l00004ooooo`;o00003_oo
ool4o`0000?ooooo0_l00006ooooo`;o00000oooool2o`0000Sooooo0_l000000ooooooo0000o`00
0002o`0000Cooooo0_l00003ooooo`?o000000?oooooo`000?l000009Ol00004ooooo`?o00001Ooo
ool3o`0000Cooooo0_l00009ooooo`;o00000_ooool2o`000003ooooool0003o000001Wooooo0_l0
000]ooooo`007?ooool00ol0003oooooooooo`0dooooo`;o00005?ooool2o`0000;ooooo0_l00006
ooooo`;o00000_ooool2o`0000_ooooo0_l00002ooooo`Go00004oooool2o`0000;ooooo0ol0000B
ooooo`;o00001Oooool2o`0000Gooooo0_l00004ooooo`Go00000oooool2o`000003ooooool0003o
000001co00001_ooool2o`0000Kooooo0_l00007ooooo`;o00001_ooool2o`0000Oooooo0_l0000G
ooooo`;o0000;Oooool001cooooo00?o0000ooooooooool0=?ooool2o`0000Wooooo0_l00008oooo
o`?o00000_ooool2o`0000[ooooo0_l00004ooooo`;o00001Oooool2o`0000Cooooo0ol00008oooo
o`Co00002?ooool2o`000003ooooool0003o000001?ooooo1?l00003ooooo`;o00002oooool4o`00
00Cooooo0_l000000ooooooo0000o`00000Ho`000004ooooool0003o0000o`0000Gooooo0_l0000<
ooooo`Ko00001_ooool2o`0000Kooooo1?l00015ooooo`007?ooool00ol0003oooooooooo`0ooooo
o`;o00001Oooool2o`000004ooooool0003o0000o`0000gooooo0_l00005ooooo`;o00005_ooool4
o`0000Sooooo0_l0000:ooooo`;o00002Oooool5o`00013ooooo1?l000000ooooooo0000o`000002
o`0000;ooooo4?l000000ooooooo0000o`000002o`000003ooooool0003o000000Ko00001Oooool2
o`0000cooooo1_l00006ooooo`?o00001Oooool4o`0004Gooooo000Looooo`03o`000?oooooooooo
04;ooooo0_l00002ooooo`?o000000Coooooo`000?l0003o00001?ooool2o`0000Kooooo0_l0000B
ooooo`;o00006?ooool3o`0000Kooooo0_l000000ooooooo0000o`000006ooooo`;o00005Oooool7
o`000003ooooool0003o000000oo000000?oooooo`000?l000000_l00002ooooo`Wo00005?ooool3
o`000003ooooool0003o000000;ooooo1?l00004ooooo`Co00000oooool4o`0003oooooo000Loooo
o`03o`000?oooooooooo02gooooo0_l0000=ooooo`;o00000_ooool4o`0000?ooooo0_l00002oooo
o`;o00000oooool3o`0000kooooo0_l00004ooooo`;o00001?ooool2o`0001;ooooo0_l00004oooo
o`Co00002?ooool2o`0000oooooo0_l00008ooooo`;o00000oooool:o`000003ooooool0003o0000
013o00000_ooool6o`000003ooooool0003o000000Cooooo0_l00003ooooo`;o00002Oooool2o`00
0004ooooool0003o0000o`0000;ooooo0_l00006ooooo`Co00000oooool4o`0003oooooo000Loooo
o`03o`000?oooooooooo01Sooooo0_l0000Cooooo`;o00002_ooool2o`000003ooooool0003o0000
00;ooooo0_l0000<ooooo`Co00002oooool6o`0000?ooooo0ol0000Hooooo`;o00000_ooool2o`00
0003ooooool0003o000000;o00005_ooool4o`0000Sooooo0_l00003ooooo`Wo00000_ooool:o`00
00;ooooo0ol000000ooooooo0000o`000003ooooo`Go00001oooool2o`0000?ooooo0_l0000<oooo
o`;o00001oooool2o`000003ooooool0003o000000?o0000A_ooool001cooooo00?o0000oooooooo
ool06?ooool2o`0001kooooo0ol000000ooooooo0000o`000008ooooo`Co000000?oooooo`000?l0
00001Ol00009ooooo`Oo00001?ooool2o`0001gooooo0_l000000ooooooo0000o`000006o`0000Ko
oooo0_l000000ooooooo0000o`000003ooooo`;o00000_ooool5o`0000Kooooo0_l00004ooooo`Wo
00000_ooool2o`0000?ooooo0ol00005ooooo`Co00001_ooool2o`00013ooooo0_l0000Booooo`;o
000000?oooooo`000?l000000ol00016ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o0000
2oooool=o`0000Wooooo0_l00003ooooo`;o00005_ooool2o`00017ooooo1Ol00006ooooo`;o0000
00?oooooo`000?l000000oooool2o`0000?ooooo1?l00003ooooo`;o000000?oooooo`000?l00000
1?ooool9o`000003ooooool0003o000000Cooooo0_l00002ooooo`[o00000_ooool2o`0001;ooooo
0_l000000ooooooo0000o`00000@ooooo`;o000000?oooooo`000?l000001_ooool2o`00043ooooo
000Looooo`03o`000?oooooooooo04Gooooo3Ol0000;ooooo`;o00000oooool2o`0001Cooooo0_l0
000Cooooo`;o00002_ooool2o`0000gooooo1?l00003ooooo`;o00000_ooool2o`0000?ooooo0ol0
0002ooooo`;o000000Coooooo`000?l0003ooooo3_l00002ooooo`;o000000?oooooo`000?l00000
3oooool2o`000003ooooool0003o0000013ooooo0_l000000ooooooo0000o`000006ooooo`;o0000
@?ooool001cooooo0_l00011ooooo`;o00000_ooool?o`000003ooooool0003o000000Oooooo0_l0
0003ooooo`;o00000oooool2o`000003ooooool0003o0000027ooooo0_l00002ooooo`Co00001Ooo
ool2o`0000Oooooo0_l00003ooooo`;o00001Oooool6o`0000?ooooo1?l000000ooooooo0000o`00
0003o`000003ooooool0003o000000Co00000oooool2o`0000Sooooo0_l00009ooooo`;o00001?oo
ool3o`0001Cooooo0ol00018ooooo`007?ooool00ol0003oooooooooo`0Iooooo`;o00009Oooool2
o`0000;ooooo2?l000000ooooooo0000o`000004o`000003ooooool0003o000000[ooooo0_l00005
ooooo`;o000000?oooooo`000?l000002?ooool2o`0000Gooooo0_l0000Dooooo`Go00001?ooool2
o`0000Oooooo0_l0000;ooooo`?o00001oooool4o`000003ooooool0003o000000Gooooo0ol00000
0ooooooo0000o`000004o`0000Oooooo0_l000000ooooooo0000o`000002o`0000?ooooo1?l00000
0ooooooo0000o`000004o`0000kooooo1ol00018ooooo`007?ooool00ol0003oooooooooo`0Ioooo
o`;o00007Oooool2o`0000Cooooo0_l00004oooooa3o00002Oooool2o`000003ooooool0003o0000
00Kooooo0_l00003ooooo`Go00000_ooool2o`0000Gooooo0_l000000ooooooo0000o`00000:oooo
o`;o00000oooool2o`0000?ooooo0ol00003ooooo`;o00001Oooool2o`000003ooooool0003o0000
00gooooo0_l00004ooooo`;o000000?oooooo`000?l000002?ooool2o`0000;ooooo1_l00002oooo
o`;o00000oooool2o`000003ooooool0003o000000;o00001Oooool2o`000003ooooool0003o0000
00;ooooo0_l00005ooooo`;o00001oooool8o`0004Oooooo000Looooo`03o`000?oooooooooo03So
oooo0_l00004ooooo`;o000000?oooooo`000?l000002?l000000ooooooo0000o`000008o`000003
ooooool0003o000000Cooooo0_l00009ooooo`;o00000oooool;o`0000;ooooo0_l00002ooooo`;o
00000_ooool2o`0000Kooooo1?l000000ooooooo0000o`000003ooooo`?o00000oooool2o`0000Go
oooo0_l000000ooooooo0000o`000004ooooo`;o00001oooool2o`0000Cooooo0_l000000ooooooo
0000o`000006ooooo`;o00001Oooool5o`0000;ooooo0ol00004ooooo`;o00002?ooool4o`0000[o
oooo0_l00005ooooo`?o00001?ooool4o`0000Wooooo0_l0000kooooo`007?ooool00ol0003ooooo
ooooo`0kooooo`Co00000_oooolEo`000003ooooool0003o000000Wooooo0_l00002ooooo`?o0000
0_ooool2o`0000;ooooo3Ol00003ooooo`;o000000?oooooo`000?l000001oooool3o`000003oooo
ool0003o000000?ooooo1?l00002ooooo`;o00002oooool5o`00013ooooo0ol00004ooooo`?o0000
1Oooool2o`0000Kooooo2?l00008ooooo`Co00000_ooool2o`0000_ooooo1Ol00004ooooo`Co0000
2Oooool2o`0003_ooooo000Looooo`03o`000?oooooooooo03_ooooo1?l00002oooooaGo00003?oo
ool2o`0000;ooooo2Ol000000ooooooo0000o`000003o`000003ooooool0003o000000?o00001?oo
ool3o`0000Wooooo0_l00002ooooo`?o00000_ooool4o`0000;ooooo0_l0000;ooooo`Go00001Ooo
ool2o`0000Gooooo0_l00003ooooo`;o00000_ooool4o`0000Kooooo1_l00004ooooo`Go00002_oo
ool3o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo1Ol00007ooooo`;o0000AOoo
ool001cooooo00?o0000ooooooooool06_ooool2o`00027ooooo0_l000001?oooooo0000o`000?l0
0003oooooa3o000000?oooooo`000?l000003Oooool2o`000003ooooool0003o000000;ooooo2?l0
00000ooooooo0000o`000004o`0000Cooooo0_l0000=ooooo`So00002Oooool2o`0000Kooooo1?l0
0005ooooo`;o00001Oooool2o`0000Oooooo0ol00009ooooo`Co00000oooool6o`0000Oooooo0_l0
0002ooooo`;o00001_ooool2o`0000?ooooo0_l00003ooooo`Co00001oooool2o`0001kooooo0_l0
000Uooooo`007?ooool00ol0003oooooooooo`0Jooooo`;o00009?ooool3o`0000?ooooo3Ol00000
1?oooooo0000o`000?ooool2o`0000gooooo0_l00005oooooa7o00000oooool2o`0000gooooo1_l0
0007ooooo`;o000000?oooooo`000?l000001oooool2o`0000;ooooo0_l0000Cooooo`;o00004?oo
ool2o`000003ooooool0003o000000Sooooo0_l0000:ooooo`;o00000oooool2o`000003ooooool0
003o000000?o0000:?ooool2o`0002Gooooo000Looooo`03o`000?oooooooooo02_ooooo0_l0000A
ooooo`;o00001Oooool2o`0000?ooooo1_l00004ooooo`;o00003_ooool2o`000003ooooool0003o
000000;ooooo0_l000000ooooooo0000o`00000Do`0000cooooo0_l00002ooooo`;o00000oooool7
o`000003ooooool0003o000000[ooooo0ol00006ooooo`;o00002Oooool2o`0000_ooooo0_l00000
0ooooooo0000o`00000Jooooo`Co000000Coooooo`000?l0003ooooo1?l00009ooooo`;o00007Ooo
ool2o`0002Kooooo000Looooo`03o`000?oooooooooo02_ooooo0_l0000Aooooo`;o00001Oooool2
o`0000Gooooo0_l0000Eooooo`?o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o
0000017o000000?oooooo`000?l000003oooool5o`000003ooooool0003o000000Go000000Cooooo
o`000?l0003o00001?ooool2o`0000Cooooo0_l00006ooooo`;o00002?ooool5o`0000Wooooo0_l0
00000ooooooo0000o`00000Looooo`Ko00003Oooool2o`0001gooooo0_l0000Vooooo`007?ooool0
0ol0003oooooooooo`1<ooooo`;o00003Oooool2o`000003ooooool0003o000000?ooooo0_l00006
ooooo`ko000000?oooooo`000?l000001Ol0000?ooooo`So00000_ooool3o`0000Gooooo0_l00004
ooooo`;o00000_ooool2o`000003ooooool0003o000000Oooooo0_l00006ooooo`;o000000?ooooo
o`000?l000001oooool2o`0000?ooooo0_l000000ooooooo0000o`000009ooooo`;o00003_ooool6
o`0005Cooooo000Looooo`03o`000?oooooooooo01_ooooo0_l0000Jooooo`;o00002?ooool4o`00
01Kooooo0_l000000ooooooo0000o`00000;ooooo`Co000000?oooooo`000?l000004Ol0000:oooo
o`;o000000Goooooo`000?l0003o0000ooooo`02o`0000Cooooo0_l0000?ooooo`?o000000?ooooo
o`000?l000000_ooool3o`0000;ooooo0_l0000>ooooo`;o00000_ooool2o`0000Gooooo0ol00006
ooooo`;o000000?oooooo`000?l000003oooool3o`0000;ooooo0_l000000ooooooo0000o`00000@
ooooo`Co0000>oooool001cooooo00?o0000ooooooooool06oooool2o`0001[ooooo0_l00008oooo
o`Go00000_ooool2o`0000gooooo0_l00003ooooo`;o00001oooool2o`0000Cooooo6?l0000:oooo
o`;o00001?ooool3o`0000;ooooo0_l0000Aooooo`Go00000oooool3o`0000[ooooo0_l00006oooo
o`?o00002?ooool2o`0000?ooooo0_l00002ooooo`;o00001?ooool2o`0000Wooooo0_l000001?oo
oooo0000o`000?l00002ooooo`Go00002_ooool4o`0000;ooooo1?l0000kooooo`007?ooool00ol0
003oooooooooo`0kooooo`;o00001Oooool5o`000003ooooool0003o000000gooooo0ol00002oooo
o`?o00001_ooool2o`0000Cooooo6?l00007ooooo`;o00000_ooool4o`000003ooooool0003o0000
00?ooooo1?l0000@ooooo`Co00001Oooool3o`0000Sooooo0_l00007ooooo`;o00003Oooool2o`00
00;ooooo0_l00004ooooo`;o00002Oooool2o`000003ooooool0003o000000Cooooo0ol00002oooo
o`;o00001oooool4o`00047ooooo000Looooo`03o`000?oooooooooo03_ooooo0ol00002ooooo`;o
000000?oooooo`000?l000000_l0000?ooooo`Co00000oooool2o`0000_ooooo5?l000000ooooooo
0000o`000002o`0000Oooooo0_l00002ooooo`Co000000Coooooo`000?l0003o00000_ooool4o`00
0004ooooool0003o0000ooooo`;o00002oooool2o`0000Kooooo0ol0000Gooooo`;o00002oooool2
o`0000?ooooo0_l000000ooooooo0000o`00000Aooooo`;o00000_ooool2o`0000cooooo1?l0000l
ooooo`007?ooool00ol0003oooooooooo`0Kooooo`;o00007oooool6o`0001?ooooo0ol0000Boooo
o`Go000000?oooooo`000?l000002_l00002ooooo`Ko00004?ooool2o`000004ooooool0003o0000
ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Nooooo`;o00003Oooool2o`00013ooooo0_l0
00000ooooooo0000o`000007ooooo`;o00002?ooool2o`0000;ooooo0_l000000ooooooo0000o`00
0004ooooo`?o00000_ooool4o`00013ooooo0_l0000Zooooo`007?ooool2o`0001cooooo0ol0000P
ooooo`;o00005Oooool2o`0000Wooooo0_l00007ooooo`;o000000?oooooo`000?l000003_l00000
0ooooooo0000o`000005o`0000[ooooo0_l00002ooooo`;o00000oooool2o`000004ooooool0003o
0000o`0000oooooo0_l000000ooooooo0000o`00000?ooooo`;o00006oooool4o`000003ooooool0
003o000000Oooooo1?l00006ooooo`_o00001?ooool3o`00013ooooo0_l00004ooooo`;o0000:_oo
ool001cooooo00?o0000ooooooooool07?ooool2o`0002Gooooo0_l0000<ooooo`;o00003Oooool2
o`0000Oooooo0_l000000ooooooo0000o`00000Fo`0000[ooooo0_l000001?oooooo0000o`000?l0
0005ooooo`Go00001?ooool2o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l000001_oo
ool2o`0000Oooooo0_l0000;ooooo`;o00000_ooool2o`0000[ooooo1?l000000ooooooo0000o`00
0002o`0000Gooooo1?l00006ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0000;ooooo
0_l0000Dooooo`;o0000<?ooool001cooooo00?o0000ooooooooool07?ooool2o`0001Sooooo0_l0
000;ooooo`;o000000?oooooo`000?l000002Oooool4o`0000gooooo0_l00008oooooaWo00002?oo
ool3o`000003ooooool0003o000000;o00000_ooool4o`000003ooooool0003o000000Cooooo0_l0
0004ooooo`;o00001_ooool2o`0000?ooooo1?l00007ooooo`;o00002oooool3o`000003ooooool0
003o0000013ooooo0ol00005ooooo`Co00000_ooool2o`0000Kooooo0_l00006ooooo`;o0000A_oo
ool001cooooo00?o0000ooooooooool0<oooool2o`000003ooooool0003o000000kooooo0_l0000;
ooooo`;o00003Oooool2o`0000Kooooo6ol00008ooooo`;o00001?ooool2o`0000;ooooo0_l00003
ooooo`;o000000?oooooo`000?l000002?ooool2o`0000Gooooo0_l00003ooooo`;o00002Oooool2
o`0000cooooo0ol0000@ooooo`;o00001_ooool2o`0000Kooooo0_l0000>ooooo`Co0000A?ooool0
01cooooo00?o0000ooooooooool0<oooool2o`0003Gooooo0_l000000ooooooo0000o`00000Fo`00
00gooooo0ol00007ooooo`;o000000?oooooo`000?l000001_ooool4o`0001cooooo0_l00006oooo
o`;o00004?ooool2o`0000Kooooo0ol00003ooooo`;o00001?ooool2o`0000cooooo0_l00014oooo
o`007?ooool00ol0003oooooooooo`0cooooo`;o00002Oooool2o`0000Oooooo0_l0000Mooooo`Co
00000ooooolGo`0000kooooo0_l00009ooooo`;o000000?oooooo`000?l000001Oooool2o`000003
ooooool0003o000000Cooooo0_l0000@ooooo`;o00000oooool2o`00027ooooo0_l00003ooooo`;o
00000_ooool4o`0001kooooo0_l0000booooo`007?ooool00ol0003oooooooooo`0cooooo`;o0000
0oooool2o`0000Cooooo0_l00007ooooo`;o00004Oooool2o`0000[ooooo1?l00004oooooaKo0000
1_ooool2o`00017ooooo0_l000000ooooooo0000o`000008ooooo`;o00001?ooool2o`0000Cooooo
0_l00003ooooo`;o00000oooool4o`0000Cooooo0_l0000Gooooo`;o00004?ooool2o`0000;ooooo
0_l00006ooooo`;o00005?ooool2o`0003;ooooo000Looooo`03o`000?oooooooooo03Sooooo0_l0
000Kooooo`?o00000_ooool2o`0000?ooooo0_l0000<oooooaSo00001Oooool2o`0000?ooooo0_l0
0004ooooo`;o00002Oooool4o`0000Kooooo0_l00002ooooo`;o00001_ooool2o`0000?ooooo0_l0
0003ooooo`?o00001Oooool2o`000003ooooool0003o000000Wooooo0_l00005ooooo`?o000000?o
ooooo`000?l000001oooool4o`000003ooooool0003o000000Kooooo0_l000000ooooooo0000o`00
0003ooooo`;o00001Oooool2o`0000Gooooo0ol00008ooooo`?o0000;_ooool001cooooo00?o0000
ooooooooool0<oooool2o`00023ooooo0ol00007ooooo`;o00001_ooool2o`0000Cooooo3_l00000
0ooooooo0000o`000007o`0000;ooooo0_l00006ooooo`;o00000oooool5o`0000Oooooo1Ol00005
ooooo`;o00000_ooool2o`0000_ooooo1?l00002ooooo`;o000000?oooooo`000?l000001Oooool2
o`0000Wooooo0_l00005ooooo`?o00002_ooool4o`000004ooooool0003o0000o`0000Kooooo1?l0
000:ooooo`;o00001Oooool3o`0000Sooooo0ol0000^ooooo`007?ooool00ol0003oooooooooo`0c
ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Oooooo0_l0000<ooooo`;o00004?ooool2
o`0000Kooooo3?l00002ooooo`?o000000?oooooo`000?l000000oooool4o`0000[ooooo0_l00000
0ooooooo0000o`000005ooooo`;o00000oooool2o`0000Gooooo0_l0000<ooooo`;o000000?ooooo
o`000?l000000_l00005ooooo`?o00009_ooool2o`000003ooooool0003o000000?ooooo0_l00000
1?oooooo0000o`000?ooool2o`0000?ooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`0f
ooooo`;o00001_ooool2o`0000Oooooo0_l0000Wooooo`;o000000?oooooo`000?l000002_l00007
ooooo`Co00002oooool4o`0000Gooooo0_l00008ooooo`;o00003_ooool2o`0000?ooooo0_l00004
ooooo`Co00001oooool2o`0000;ooooo0_l00002ooooo`;o00001_ooool2o`0000gooooo0_l00006
ooooo`;o00000_ooool4o`0000?ooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`1:oooo
o`;o00002?ooool2o`00013ooooo0_l0000;ooooo`co00002?ooool3o`0000_ooooo1?l00005oooo
o`;o00002?ooool2o`0000cooooo0_l00005ooooo`;o00001?ooool2o`0000Kooooo0_l000000ooo
oooo0000o`000002ooooo`Ko00000_ooool2o`0000;ooooo0_l0000Eooooo`;o00000_ooool4o`00
00Wooooo0_l0000>ooooo`;o0000<Oooool001cooooo00?o0000ooooooooool0B_ooool2o`0000So
oooo0_l0000@ooooo`;o00003?ooool8o`000005ooooool0003o0000o`000?ooool00_l00004oooo
o`?o00001Oooool2o`0001?ooooo0_l00002ooooo`;o00003?ooool2o`0000[ooooo0_l00005oooo
o`Co00001oooool4o`0000;ooooo0_l0000Iooooo`;o00001_ooool2o`0000Oooooo0_l0000>oooo
o`;o0000<Oooool001cooooo00?o0000ooooooooool07_ooool2o`0004[ooooo0_l00005ooooo`;o
00001?ooool2o`0000;ooooo1Ol000000ooooooo0000o`000002o`0000Kooooo0_l00002ooooo`;o
00001_ooool2o`0000Cooooo0_l00005ooooo`;o00000_ooool2o`000004ooooool0003o0000oooo
o`;o00001?ooool2o`0000cooooo0_l00005ooooo`;o00002oooool2o`0000Gooooo0_l0000Foooo
o`;o000000?oooooo`000?l000000oooool3o`0004Wooooo00001_ooooook^k^oc8b<_l0003o<S8b
onk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003ooooooooo
o`0Nooooo`;o0000B_ooool2o`0000Gooooo0_l000000ooooooo0000o`000004o`000003ooooool0
003o000000;o00000_ooool4o`0000Kooooo0_l0000:ooooo`;o00001?ooool2o`0000[ooooo1?l0
00000ooooooo0000o`000002o`0000;ooooo0_l00002ooooo`;o00002?ooool2o`0000Gooooo0_l0
0003ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000005ooooo`;o00005_oo
ool2o`000003ooooool0003o000000;o00000_ooool2o`0004Wooooo00001_ooooooMgMgoiRHV?oo
ooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003o
ooooooooo`1:ooooo`;o00003_ooool2o`0001Sooooo1_l000000ooooooo0000o`000005ooooo`;o
00001?ooool2o`0000_ooooo0_l0000Booooo`;o00000oooool4o`0000Kooooo0_l0000:ooooo`?o
00001Oooool4o`000003ooooool0003o000000;o000000?oooooo`000?l000000_l0000;ooooo`;o
000000Coooooo`000?l0003o00003oooool2o`000003ooooool0003o000000kooooo0_l0000joooo
o`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooooooo`1:ooooo`;o00003_ooool2o`0000Cooooo0_l0000Ioooo
o`;o00001Oooool2o`0000Cooooo0_l0000;ooooo`;o00005_ooool3o`0001;ooooo1Ol00003oooo
oa;o00002Oooool6o`0000Oooooo0_l00009ooooo`;o00003_ooool2o`0003[ooooo00000ooooooo
0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@06oooo
o`?o0000=oooool2o`0000_ooooo0_l00002ooooo`;o00002oooool2o`0000Wooooo0_l0000Roooo
o`;o00009oooool2o`0000Wooooo0_l00005ooooo`;o000000?oooooo`000?l000000oooool2o`00
0003ooooool0003o000000Go000000?oooooo`000?l000001Ol000000ooooooo0000o`000002o`00
00Sooooo1Ol00007ooooo`;o00000oooool4o`0000Cooooo0_l00018ooooo`0000?oooooo`000?oo
ool00_ooool00ol0003oooooooooo`09ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0
003oooooooooo`0gooooo`;o00002Oooool4o`0000;ooooo0_l0000;ooooo`;o00007_ooool2o`00
00gooooo0_l00007ooooo`;o00001oooool2o`0001?ooooo0_l00006ooooo`?o00000_ooool2o`00
00Gooooo0_l00006ooooo`;o000000?oooooo`000?l000003_l00002ooooo`;o00000oooool2o`00
00?ooooo0ol0000<ooooo`Oo00000oooool2o`0000_ooooo0ol00002ooooo`;o0000=_ooool00003
ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03
o`000?oooooooooo03_ooooo0_l00005ooooo`;o00001?ooool2o`0000_ooooo0_l0000Nooooo`;o
00000_ooool2o`0000Kooooo1?l00005ooooo`;o000000?oooooo`000?l000001oooool2o`0001?o
oooo0_l00006ooooo`?o00000_ooool2o`00017ooooo4Ol00005ooooo`;o00004_ooool2o`0000?o
oooo0_l0000@ooooo`?o00000_ooool2o`0003Kooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMg
M`_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0kooooo`;o00001oooool6o`00
02oooooo0_l00006ooooo`Co00000_ooool2o`000003ooooool0003o000000;o00000_ooool4o`00
00;ooooo0_l0000Kooooo`;o00005_oooolBo`0000Oooooo0_l0000Dooooo`;o00000oooool2o`00
04Sooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_oo
ool00ol0003oooooooooo`0iooooo`Co00001oooool7o`0000cooooo0_l0000@ooooo`Co00003ooo
ool2o`0000Oooooo1?l00003ooooo`;o000000?oooooo`000?l000000ol00002ooooo`;o00006ooo
ool2o`0001Cooooo1?l000000ooooooo0000o`00000>o`0000Kooooo0_l0000Iooooo`;o0000B?oo
ool001cooooo00?o0000ooooooooool0>Oooool2o`0000;ooooo0_l00007ooooo`;o000000?ooooo
o`000?l000002_ooool4o`00013ooooo1?l00002ooooo`;o00002oooool2o`0000Oooooo1?l00003
ooooo`co00005_ooool2o`0000?ooooo0_l00003ooooo`;o00003ooooolEo`0000Sooooo0_l00003
ooooo`;o00002?ooool2o`0000_ooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`0moooo
o`;o00001oooool2o`0000gooooo0_l0000?ooooo`?o00001?ooool4o`0001Kooooo0_l00003oooo
o`_o00002?ooool2o`0000gooooo0_l00002ooooo`;o00001?ooool2o`0000cooooo0_l000000ooo
oooo0000o`00000Bo`0000Wooooo0_l00003ooooo`Co00001_ooool2o`0000_ooooo0_l00002oooo
o`;o00001oooool2o`0003Sooooo000Looooo`03o`000?oooooooooo03Oooooo0_l0000:ooooo`;o
000000?oooooo`000?l000004?ooool2o`0000?ooooo0ol00006ooooo`Go00000_ooool2o`0001So
oooo0_l00002ooooo`[o00000oooool2o`0000Gooooo0_l0000@ooooo`Go00004?oooolHo`000003
ooooool0003o000000Gooooo0_l00005ooooo`;o00005Oooool4o`0000Oooooo0_l0000hooooo`00
7?ooool00ol0003oooooooooo`0gooooo`;o00000_ooool2o`0000;ooooo0_l00002ooooo`;o0000
1Oooool2o`0000cooooo0_l00003ooooo`?o00002Oooool2o`0000[ooooo0ol0000?ooooo`;o0000
0_oooolAo`0001Cooooo1_l0000@oooooaSo000000?oooooo`000?l000002?ooool4o`0000Kooooo
0_l000000ooooooo0000o`000009ooooo`Ko0000@_ooool001cooooo00?o0000ooooooooool0=ooo
ool2o`0000;ooooo0_l00002ooooo`;o00002Oooool2o`0001Wooooo0_l0000>ooooo`Co00003_oo
oolBo`000003ooooool0003o000001Cooooo0ol0000Cooooo`;o00001?oooolBo`0000Oooooo0_l0
0002ooooo`Co00001_ooool2o`000003ooooool0003o000000Wooooo1?l00014ooooo`007?ooool0
0ol0003oooooooooo`0looooo`Co000000?oooooo`000?l000005oooool2o`0000Wooooo0_l0000@
ooooo`;o00003?ooool2o`000003ooooool0003o0000013o00005Oooool5o`000003ooooool0003o
000000;ooooo0_l0000;ooooo`Co00000_oooolBo`0000Oooooo0_l0001Rooooo`007?ooool00ol0
003oooooooooo`0looooo`Oo00001_ooool2o`0000oooooo0_l0000Uooooo`;o00000_ooool2o`00
0003ooooool0003o0000013o00005Oooool5o`000004ooooool0003o0000ooooo`?o00002_oooolH
o`0000?ooooo0_l0001Wooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00001oooool2o`00
00Oooooo0_l0000eooooo`?o00001?oooolFo`0001_ooooo0_l0000;ooooo`;o00000_oooolDo`00
00?ooooo0_l0000?ooooo`;o00000_ooool2o`0005;ooooo000Looooo`03o`000?oooooooooo03Oo
oooo0_l00005ooooo`;o00000_ooool2o`0000?ooooo0_l0000=ooooo`;o00004oooool3o`0000oo
oooo0_l000000ooooooo0000o`000005oooooaKo00005Oooool2o`0001Cooooo5Ol0000Dooooo`;o
00000_ooool2o`0000cooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0nooooo`;o0000
0_ooool7o`0000;ooooo0_l00009ooooo`;o00004oooool3o`0000oooooo1?l00006oooooaOo0000
5?ooool4o`00017ooooo5_l000001?oooooo0000o`000?l0000Cooooo`;o00003Oooool2o`0004Co
oooo000Looooo`03o`000?oooooooooo03_ooooo0_l00007ooooo`?o00001?ooool2o`0003;ooooo
0_l00002ooooo`;o000000?oooooo`000?l000005_l0000Cooooo`Go00001Oooool3o`0000Wooooo
0_l000000ooooooo0000o`00000@o`0000;ooooo0ol0000Cooooo`;o0000Doooool001cooooo0_l0
000looooo`;o00001oooool4o`0000oooooo0_l0000Eooooo`;o00003Oooool2o`0000Cooooo7?l0
000Booooo`?o00001_ooool4o`000003ooooool0003o000000cooooo4?l000000ooooooo0000o`00
000<ooooo`;o00000_ooool2o`000003ooooool0003o000000Kooooo0_l0001<ooooo`007?ooool0
0ol0003oooooooooo`16ooooo`;o00001oooool2o`0000Kooooo0_l0000Eooooo`;o00003Oooool2
o`0000Gooooo2Ol000000ooooooo0000o`00000?o`0000;ooooo0_l0000@ooooo`;o00001Oooool4
o`000003ooooool0003o000000cooooo4_l0000=ooooo`;o000000Goooooo`000?l0003o0000oooo
o`02o`0000Kooooo0_l00002ooooo`?o0000Aoooool001cooooo00?o0000ooooooooool0@_ooool3
o`000003ooooool0003o000000Oooooo0_l0000dooooo`Oo000000?oooooo`000?l000004Ol00000
0ooooooo0000o`00000<ooooo`;o00000_ooool2o`0000Kooooo0_l0000@ooooo`oo000000?ooooo
o`000?l000004?ooool2o`0000kooooo0ol00017ooooo`007?ooool00ol0003oooooooooo`12oooo
o`?o000000?oooooo`000?l00000?ooooolEo`000004ooooool0003o0000o`0000oooooo0_l00002
ooooo`;o00001_ooool2o`00013ooooo2?l00002ooooo`Oo00006Oooool2o`00053ooooo000Loooo
o`03o`000?oooooooooo04;ooooo0_l0000Hooooo`;o00003Oooool2o`0001[ooooo6Ol0000Coooo
o`;o00008_ooool2o`0000?ooooo0_l0000Iooooo`;o00001?ooool2o`0000Gooooo0_l00013oooo
o`007?ooool00ol0003oooooooooo`10ooooo`;o00006_ooool2o`0000Cooooo0ol00006ooooo`;o
00004_ooool2o`0000Kooooo2ol000000ooooooo0000o`00000<o`0000Gooooo0_l0000=ooooo`;o
00001_ooool2o`0001Sooooo0_l000000ooooooo0000o`00000Jooooo`;o00001Oooool2o`0000;o
oooo1Ol00013ooooo`007?ooool00ol0003oooooooooo`10ooooo`Co00002oooool3o`000003oooo
ool0003o000000Kooooo0_l00004ooooo`Co00001Oooool2o`0001?ooooo0_l00005ooooo`co0000
00?oooooo`000?l000003?l00002ooooo`;o000000?oooooo`000?l000003Oooool2o`0000Kooooo
0_l0000Dooooo`;o00001Oooool2o`0000oooooo0_l00009ooooo`;o00002Oooool4o`0004Cooooo
000Looooo`03o`000?oooooooooo04;ooooo0ol0000:ooooo`?o000000?oooooo`000?l000000_l0
0004ooooo`;o00001?ooool2o`0000Oooooo0_l00002ooooo`;o00003oooool2o`0000Gooooo0_l0
00000ooooooo0000o`000002o`000003ooooool0003o0000013o00000oooool2o`0000cooooo0_l0
000Pooooo`?o00005Oooool2o`0000_ooooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`13
ooooo`;o00003_ooool4o`0000gooooo0_l00008ooooo`;o00006OoooolHo`00013ooooo0_l00007
ooooo`;o00006?ooool2o`0001?ooooo0_l0000=ooooo`;o0000Coooool001cooooo00?o0000oooo
ooooool0@oooool2o`0001oooooo0_l0000SoooooaSo00003_ooool2o`0000Wooooo0_l0000Doooo
o`;o00005oooool2o`000003ooooool0003o000000;o0000FOooool001cooooo00?o0000oooooooo
ool0ROoooolHo`0000kooooo0_l0000Aooooo`;o00003?ooool2o`0000Wooooo0_l0000?ooooo`Co
0000FOooool001cooooo00?o0000ooooooooool0J?ooool2o`0001[ooooo0_l00003oooooaOo0000
6oooool2o`0000Gooooo0_l0000Gooooo`;o00000_ooool2o`0001Cooooo0_l00003ooooo`;o0000
COooool001cooooo00?o0000ooooooooool0AOooool3o`0000kooooo0_l0000@ooooo`;o00006_oo
ool2o`0000?ooooo5ol0000Aooooo`;o00000_ooool2o`0000;ooooo1?l00002ooooo`;o00001?oo
ool2o`0001Gooooo0_l000000ooooooo0000o`000007ooooo`;o00002oooool2o`0000?ooooo0_l0
001=ooooo`007?ooool00ol0003oooooooooo`13ooooo`Oo00003?ooool3o`0002_ooooo0_l00003
oooooaWo00000oooool2o`0000?ooooo0_l00004ooooo`?o00000_ooool2o`0000;ooooo0_l00004
ooooo`;o00001?ooool2o`0001Gooooo0_l0000:ooooo`;o000000?oooooo`000?l00000G?ooool0
01cooooo00?o0000ooooooooool0?oooool2o`0000;ooooo0_l00002ooooo`Co00003?ooool2o`00
03?ooooo5_l00002ooooo`?o00000oooool2o`0000Cooooo0_l0000?ooooo`;o00002Oooool2o`00
01;ooooo1?l00007ooooo`;o00003Oooool2o`0004gooooo000Looooo`03o`000?oooooooooo03oo
oooo0_l00007ooooo`?o00007_ooool2o`0002;ooooo5Ol00002ooooo`;o00000oooool2o`0001Ko
oooo0_l00003ooooo`;o00000oooool3o`0000gooooo0_l000000ooooooo0000o`000004o`0001Ko
oooo0_l0001=ooooo`007?ooool2o`0004Wooooo0ol0000@ooooo`;o00001Oooool2o`0000?ooooo
1?l00003ooooo`;o00006Oooool2o`0000;ooooo5_l00002ooooo`;o000000Goooooo`000?l0003o
0000ooooo`02o`000003ooooool0003o000000Kooooo0_l00008ooooo`;o00000oooool2o`0000?o
oooo0_l00003ooooo`;o000000?oooooo`000?l000001_ooool2o`000003ooooool0003o000000_o
oooo0ol0001Kooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00003oooool3o`0000;ooooo
0_l000000ooooooo0000o`000003ooooo`;o00001Oooool2o`0001Wooooo0_l00002ooooo`go0000
00?oooooo`000?l000000_l00002ooooo`;o00000_ooool5o`0000;ooooo0_l000000ooooooo0000
o`000006ooooo`;o00005oooool5o`0000Kooooo1?l00007ooooo`;o00000oooool4o`0005[ooooo
000Looooo`03o`000?oooooooooo04Wooooo0_l0000?ooooo`;o00000oooool2o`0002_ooooo3_l0
0002ooooo`;o000000?oooooo`000?l000001Oooool3o`0000Gooooo0_l0000Kooooo`;o00001?oo
ool2o`0000Sooooo1?l000000ooooooo0000o`000002ooooo`Co00000oooool4o`0000Sooooo0_l0
001@ooooo`007?ooool00ol0003oooooooooo`1=ooooo`?o000000?oooooo`000?l000002_ooool2
o`0001Kooooo0_l0000Eooooo`[o000000Coooooo`000?l0003o00000_ooool2o`000004ooooool0
003o0000ooooo`;o00000_ooool2o`0000Cooooo1?l0000Iooooo`Co00003_ooool2o`0000?ooooo
0_l00002ooooo`;o00001Oooool2o`0000Sooooo1?l0001@ooooo`007?ooool00ol0003ooooooooo
o`1=ooooo`?o000000?oooooo`000?l000002_ooool2o`0000cooooo0_l00004ooooo`;o00000_oo
ool2o`0001Gooooo0_l00002ooooo`;o000000Goooooo`000?l0003o0000ooooo`08o`000003oooo
ool0003o000000;o00002?ooool2o`0001Sooooo0_l000000ooooooo0000o`000002o`0000gooooo
0_l00004ooooo`;o00004oooool2o`0005;ooooo000Looooo`03o`000?oooooooooo04Kooooo0_l0
0007ooooo`Go00005oooool4o`0000;ooooo0_l0000Iooooo`;o00000_ooool2o`0000;ooooo2ol0
00000ooooooo0000o`000004ooooo`;o00000oooool2o`0001Sooooo1Ol0000;ooooo`;o00000ooo
ool2o`0001Gooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`16ooooo`;o00001?ooool2
o`000004ooooool0003o0000ooooo`;o00002Oooool3o`0000Kooooo0_l00005ooooo`;o00009Ooo
ool4o`000003ooooool0003o000000;o00000oooool2o`0000Cooooo0_l00003ooooo`;o000000Co
ooooo`000?l0003ooooo0_l0000?ooooo`So00002Oooool4o`000004ooooool0003o0000ooooo`;o
00000_ooool2o`00013ooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`17ooooo`;o0000
0oooool3o`0000kooooo0ol00006ooooo`;o0000:?ooool2o`0000?ooooo0_l00008ooooo`;o0000
1oooool3o`0000?ooooo0_l000000ooooooo0000o`00000?ooooo`Ko00002oooool2o`0000?ooooo
1Ol00002ooooo`;o00002_ooool2o`0005cooooo000Looooo`03o`000?oooooooooo04Oooooo0_l0
0004ooooo`;o00000oooool2o`0001Gooooo0_l000000ooooooo0000o`000002ooooo`;o00001_oo
ool2o`0000_ooooo0_l00009ooooo`;o00003Oooool2o`000004ooooool0003o0000ooooo`;o0000
00Coooooo`000?l0003o00007?ooool2o`00013ooooo0_l0000@ooooo`;o0000G?ooool001cooooo
00?o0000ooooooooool0Coooool2o`000003ooooool0003o000000kooooo0_l00005ooooo`;o0000
00?oooooo`000?l000000_ooool2o`0000Kooooo0_l0000;ooooo`;o00006_ooool3o`000003oooo
ool0003o000001[ooooo0_l00004ooooo`;o00003?ooool2o`000004ooooool0003o0000o`0000_o
oooo0_l0001Qooooo`007?ooool00ol0003oooooooooo`1?ooooo`;o00004Oooool2o`0000cooooo
0_l00004ooooo`;o00000oooool4o`0000Kooooo0_l0000<ooooo`?o00000oooool4o`0000Cooooo
0_l0000Nooooo`;o00002Oooool2o`0000Cooooo1Ol000001?oooooo0000o`000?l0000;ooooo`;o
0000HOooool001cooooo00?o0000ooooooooool0D?ooool2o`0000Cooooo1?l0000Fooooo`Go0000
00?oooooo`000?l000000oooool4o`0000Kooooo0ol0000;ooooo`Go000000?oooooo`000?l00000
0ol00006ooooo`;o00009_ooool2o`0000Cooooo0ol00004ooooo`;o00001oooool2o`0006Gooooo
000Looooo`03o`000?oooooooooo053ooooo0_l00004ooooo`Co00002?ooool2o`0000gooooo1Ol0
000@ooooo`Co00003?ooool2o`0000Cooooo0_l00006ooooo`;o00000_ooool2o`0002?ooooo0_l0
0006ooooo`;o00002oooool2o`0000Kooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1;
ooooo`;o00000oooool3o`0000?ooooo0_l00006ooooo`;o00000_ooool4o`0000Kooooo0_l00006
ooooo`;o00004_ooool2o`0001_ooooo0_l000000ooooooo0000o`00000Sooooo`;o00001_ooool2
o`0000Sooooo0_l00004ooooo`;o00000oooool2o`0005gooooo000Looooo`03o`000?oooooooooo
04_ooooo0_l00003ooooo`?o00000oooool3o`000003ooooool0003o000000;ooooo0_l00004oooo
o`;o000000?oooooo`000?l000000oooool2o`0000Cooooo0_l00007ooooo`;o00001Oooool3o`00
00Kooooo0_l0000<ooooo`;o00002_ooool2o`0000Kooooo0_l0000<ooooo`;o00003?ooool2o`00
01Cooooo1?l00002ooooo`;o0000H_ooool001cooooo00?o0000ooooooooool0D?ooool2o`0000Co
oooo0ol000000ooooooo0000o`000006ooooo`;o00000oooool2o`0000Wooooo1_l00003ooooo`;o
00000_ooool2o`000004ooooool0003o0000o`0000Kooooo1?l00007ooooo`;o000000?oooooo`00
0?l000000oooool3o`0000cooooo0ol0000;ooooo`;o00002?ooool6o`0000Oooooo0_l0000=oooo
o`;o0000I_ooool001cooooo0_l0001Aooooo`;o00001Oooool2o`0000Wooooo0_l0000?ooooo`Go
00001oooool2o`0000_ooooo0ol00007ooooo`;o00001_ooool3o`0000gooooo0_l0000<ooooo`;o
00001Oooool6o`0000Wooooo0_l0001eooooo`007?ooool00ol0003oooooooooo`1Gooooo`;o0000
3?ooool2o`0000gooooo0_l0000:ooooo`Ko00001?ooool2o`0000oooooo0_l00002ooooo`;o0000
6oooool2o`0000?ooooo1?l00003ooooo`;o00001Oooool3o`0001;ooooo0_l0001Sooooo`007?oo
ool00ol0003oooooooooo`1Uooooo`;o00003Oooool2o`0000?ooooo0_l00002ooooo`;o000000?o
ooooo`000?l000001?l00004ooooo`;o00003oooool2o`0000;ooooo0_l00006ooooo`;o00006?oo
ool2o`0000Gooooo0_l00005ooooo`?o00004_ooool2o`0006?ooooo000Looooo`03o`000?oooooo
oooo07Wooooo0_l00002ooooo`;o00001_ooool4o`0000Sooooo0_l0000<ooooo`;o00001_ooool2
o`0000oooooo0_l00007ooooo`;o00001oooool2o`000003ooooool0003o000000;o0000N?ooool0
01cooooo00?o0000ooooooooool0Goooool2o`00017ooooo0_l00005ooooo`;o00002_ooool4o`00
00Kooooo1?l0000@ooooo`;o00004oooool2o`000003ooooool0003o000000Cooooo0_l00007oooo
o`;o000000?oooooo`000?l000004?ooool2o`0006Sooooo000Looooo`03o`000?oooooooooo05oo
oooo0_l000000ooooooo0000o`000002ooooo`;o00002_ooool2o`0000Oooooo0_l0000Booooo`;o
00003_ooool2o`0000;ooooo0_l0000=ooooo`;o00001?ooool2o`000003ooooool0003o000000Co
oooo0_l00006ooooo`;o00005?ooool2o`0006Sooooo000Looooo`03o`000?oooooooooo067ooooo
0ol00002ooooo`;o00004oooool6o`0001;ooooo0_l00003ooooo`;o00001Oooool2o`0000oooooo
1?l00004ooooo`;o00002?ooool2o`0000Gooooo0_l00007ooooo`;o00002Oooool2o`0006[ooooo
000Looooo`03o`000?oooooooooo067ooooo0ol00002ooooo`;o00002?ooool2o`0000_ooooo1?l0
000>ooooo`;o00000_ooool2o`0000;ooooo0ol0000Fooooo`;o00000oooool2o`0000_ooooo0_l0
000:ooooo`;o00000_ooool2o`0000Gooooo0_l00002ooooo`;o0000J_ooool001cooooo00?o0000
ooooooooool0H_ooool2o`0000;ooooo0ol00007ooooo`Co00000oooool2o`000004ooooool0003o
0000ooooo`;o00000oooool2o`0000_ooooo0_l00006ooooo`;o00003Oooool4o`0000Kooooo0_l0
0003ooooo`;o00005oooool2o`0000;ooooo0_l00005ooooo`;o0000K_ooool001cooooo00?o0000
ooooooooool0Goooool2o`0000Cooooo1?l00007ooooo`Co00000oooool5o`000004ooooool0003o
0000ooooo`Co00000_ooool2o`0001_ooooo0_l000000ooooooo0000o`000002o`0000Kooooo0_l0
0003ooooo`;o00005?ooool2o`000003ooooool0003o000007Wooooo000Looooo`03o`000?oooooo
oooo05oooooo0_l00004ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0ol00002
ooooo`;o000000?oooooo`000?l000001_ooool3o`0000?ooooo0_l00006ooooo`;o00004oooool2
o`0000gooooo0_l00003ooooo`?o00004Oooool2o`0007cooooo000Looooo`03o`000?oooooooooo
067ooooo0_l00005ooooo`;o00000_ooool2o`0000Oooooo0_l00009ooooo`;o00003?ooool2o`00
00Gooooo0_l00007ooooo`;o00000oooool2o`0000gooooo0_l00003ooooo`?o00000oooool2o`00
00cooooo0_l0000?ooooo`;o0000Joooool001cooooo00?o0000ooooooooool0HOooool2o`00017o
oooo0_l0000:ooooo`;o00003?ooool2o`0000Gooooo0_l00002ooooo`?o00000_ooool2o`0000?o
oooo1?l0000Fooooo`;o00002?ooool2o`0000Wooooo0_l00008ooooo`;o0000Joooool001cooooo
00?o0000ooooooooool0K?ooool2o`0000;ooooo0_l000001?oooooo0000o`000?l0000Iooooo`;o
00001?ooool2o`0000;ooooo0ol00009ooooo`;o00000_ooool3o`00017ooooo0_l00002ooooo`;o
00001?ooool2o`0000Wooooo0_l0001eooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5oooo
o`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0Hoooool2
o`0000Oooooo0_l00002ooooo`Ko00001oooool4o`0000;ooooo0_l0000:ooooo`;o000000?ooooo
o`000?l000001?ooool2o`0000?ooooo0_l00006ooooo`;o00000_ooool3o`0001Gooooo0_l00026
ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooo
oonHV9So8B4Q00Kooooo00?o0000ooooooooool0Hoooool2o`0000Oooooo0_l00003ooooo`;o0000
00?oooooo`000?l000001oooool4o`0000;ooooo1?l00002ooooo`;o00001oooool4o`0000;ooooo
0_l000000ooooooo0000o`000002o`0000_ooooo0_l0000Eooooo`?o00002_ooool2o`0000Gooooo
0_l0001booooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`1Uooooo`;o00001?ooool3o`0000oooooo
0_l00003ooooo`Go00000_ooool2o`0000?ooooo0_l00004ooooo`;o00001Oooool2o`0000Oooooo
0_l00002ooooo`;o00003?ooool2o`000003ooooool0003o000000Kooooo0ol0000:ooooo`;o0000
00?oooooo`000?l000000_ooool2o`0007;ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oo
oooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000IOooool2o`0000Cooooo
0_l00007ooooo`;o00001oooool2o`0000?ooooo1_l00003ooooo`;o000000?oooooo`000?l00000
5?ooool2o`0000;ooooo0_l0000<ooooo`;o000000?oooooo`000?l000005_ooool4o`0000Kooooo
0_l0001/ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05olc<c?l0
003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`1dooooo`;o00001oooool2o`000003oooo
ool0003o000000Cooooo0ol00002ooooo`;o00001Oooool4o`0001Gooooo0ol00007ooooo`;o0000
3oooool2o`0000_ooooo0ol00005ooooo`;o0000K?ooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0
OOooool2o`000003ooooool0003o000000Gooooo0_l00009ooooo`Co00005Oooool3o`0000Oooooo
0_l0000:ooooo`;o00000oooool2o`0000_ooooo0ol0001cooooo`0000KoooooogMgMonHV9Sooooo
oiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`1^oooo
o`;o00003Oooool2o`0000?ooooo0_l00003ooooo`;o00002Oooool4o`0001cooooo0_l00007oooo
o`;o00001?ooool2o`0000;ooooo0_l0000<ooooo`;o0000M?ooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0J_oo
ool2o`0000;ooooo0_l00005ooooo`;o00001_ooool2o`000003ooooool0003o000000;o00000ooo
ool2o`0000Kooooo0_l00003ooooo`;o00007?ooool2o`0000Oooooo0_l00008ooooo`;o00001Ooo
ool2o`0000?ooooo0_l0001fooooo`007?ooool00ol0003oooooooooo`1Zooooo`;o00002Oooool2
o`0000Kooooo0_l000000ooooooo0000o`00000=ooooo`;o0000=?ooool2o`0000Gooooo0_l00003
ooooo`;o0000M_ooool001cooooo00?o0000ooooooooool0KOooool2o`0000?ooooo0_l0000Koooo
o`;o00000oooool2o`0000?ooooo0_l0000:ooooo`?o00000_ooool2o`0000?ooooo0_l0000Doooo
o`;o0000P_ooool001cooooo00?o0000ooooooooool0KOooool2o`0000?ooooo0_l00009ooooo`;o
00002Oooool2o`000003ooooool0003o000000Oooooo0_l00003ooooo`;o00002_ooool3o`0000;o
oooo0_l00002ooooo`?o00004Oooool2o`0000[ooooo0_l0001iooooo`007?ooool00ol0003ooooo
ooooo`1mooooo`?o00002?ooool2o`000003ooooool0003o000000Oooooo0_l0000Hooooo`Ko0000
1_ooool2o`0000Kooooo0_l0000:ooooo`;o00001Oooool2o`0007;ooooo000Looooo`03o`000?oo
oooooooo07?ooooo0_l00003ooooo`Go000000?oooooo`000?l000000oooool2o`0000Oooooo0_l0
0007ooooo`;o00000oooool2o`0000Oooooo0_l0000;ooooo`Co00001_ooool2o`0000Sooooo1?l0
000:ooooo`;o000000?oooooo`000?l00000L_ooool001cooooo00?o0000ooooooooool0Loooool2
o`0000?ooooo1Ol00006ooooo`;o00001Oooool4o`0000Oooooo0_l000000ooooooo0000o`000002
o`000003ooooool0003o000000Ko00002Oooool4o`0001;ooooo1?l0000:ooooo`;o0000MOooool0
01cooooo00?o0000ooooooooool0R_ooool2o`0000Cooooo1?l00004ooooo`;o00000oooool6o`00
00_ooooo1?l0002Gooooo`007?ooool00ol0003oooooooooo`21ooooo`;o00003Oooool4o`0000So
oooo1?l000001?oooooo0000o`000?l0000:ooooo`;o0000VOooool001cooooo00?o0000oooooooo
ool0POooool2o`0000;ooooo0_l0000Eooooo`;o000000Coooooo`000?l0003ooooo0_l00007oooo
o`;o00002_ooool2o`0000Oooooo0_l00006ooooo`;o0000Ooooool001cooooo00?o0000oooooooo
ool0QOooool2o`0001Kooooo1?l0000:ooooo`;o00001_ooool3o`000004ooooool0003o0000o`00
00Gooooo1Ol00004ooooo`;o0000Ooooool001cooooo00?o0000ooooooooool0QOooool3o`0001Go
oooo0_l000000ooooooo0000o`00000Aooooo`?o000000Coooooo`000?l0003o00001Oooool2o`00
0003ooooool0003o000008Gooooo000Looooo`;o0000Q_ooool5o`0000Sooooo0_l0000<ooooo`;o
00005_ooool2o`0008oooooo000Looooo`03o`000?oooooooooo08Sooooo0_l00008ooooo`;o0000
9?ooool2o`0008oooooo000Looooo`03o`000?oooooooooo08[ooooo0_l0000Qooooo`;o00001_oo
ool2o`0009;ooooo000Looooo`03o`000?oooooooooo08[ooooo0_l0000Eooooo`;o00000oooool2
o`0000Gooooo0_l00006ooooo`;o0000T_ooool001cooooo00?o0000ooooooooool0XOooool2o`00
00?ooooo0_l00005ooooo`Co0000V?ooool001cooooo00?o0000ooooooooool0[Oooool4o`0009So
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooo
oom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Booooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooood[ooooo
000Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool0
0ol0003oooooooooo`05ooooo`?o0000oooooom:ooooo`005?ooool00ol0003oooooooooo`3ooooo
oe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0
oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Booooo`03oeEEEOmVIVKo
00000?ooooooE?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Gooooo00Co
410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0Eooooo`05onk^k_lb<S;o0000oa0@4?o<
c<`00oooool01?l@413o0000odA4A?o<c<`4ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0T?ooool0
0:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00002Oooool01OmEEEGoMgMgoooooonH
V9So8B4Q00Gooooo00?oV9RHoa0@4?oMgMd00oooool01OmgMgOoV9RHoooooonHV9SoMgMg093ooooo
002Vooooo`05o`000?ooooooooooooooool000006?ooool01Ol0003ooooooooooooooooo000000Ko
oooo00?oQhN7oeEEEOooool00_ooool01Ol@413ooooooooooooooooo410@093ooooo002Vooooo`05
o`000?ooooooooooooooool000002Oooool6o`0000Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@03
ooooo`05olc<c?lQ8B7o0000oeEEEOl000000oooool01Ol0003ooooooooooooooooo0000093ooooo
002Vooooo`05o`000?n7QhOoooooojVYZOl000006?ooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go8B4QohN7QoooooooV9RHo`000003ooooo`05o`000?ooooooooooooooool00000T?ooool0
0:Gooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Fooooo`03oeEEEOn7QhOooooo
00Gooooo00Go0000ooooooooooooooooo`000003ooooo`05oa0@4?ooooooooooooooool@4100T?oo
ool00<?ooooo00?ogMgMoa0@4?nHV9P01Oooool01OlQ8B7oV9RHoooooomgMgOoEEEE00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`2@ooooo`00a?ooool01?o<c<coA4A4o`000?l@4103ooooo`05olc<
c?l@413o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^093ooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(696) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.47601 .31328 Mdot
.43503 .3083 Mdot
.44458 .6199 Mdot
.65016 .48271 Mdot
.55598 .62312 Mdot
.4465 .65836 Mdot
.3811 .51735 Mdot
.3769 .49105 Mdot
.43942 .64023 Mdot
.48434 .23942 Mdot
.39619 .54484 Mdot
.5837 .51927 Mdot
.37053 .5203 Mdot
.60378 .43901 Mdot
.18724 .50601 Mdot
.65081 .40297 Mdot
.41428 .32378 Mdot
.66114 .66476 Mdot
.63867 .39688 Mdot
.45741 .63311 Mdot
.40712 .3816 Mdot
.6064 .44468 Mdot
.43164 .30596 Mdot
.60541 .44061 Mdot
.65271 .44565 Mdot
.45782 .32599 Mdot
.47882 .30954 Mdot
.64009 .46553 Mdot
.62892 .42161 Mdot
.37245 .54968 Mdot
.56066 .65792 Mdot
.16711 .61331 Mdot
.68001 .4305 Mdot
.71959 .36588 Mdot
.34242 .50871 Mdot
.54429 .80718 Mdot
.42178 .64524 Mdot
.39763 .51117 Mdot
.3589 .49317 Mdot
.35087 .50696 Mdot
.35627 .51282 Mdot
.45367 .3207 Mdot
.36329 .55909 Mdot
.35227 .5772 Mdot
.64107 .49139 Mdot
.27997 .41027 Mdot
.66539 .71191 Mdot
.63686 .46587 Mdot
.47357 .32105 Mdot
.46458 .66242 Mdot
.7741 .38184 Mdot
.39786 .50781 Mdot
.22846 .48289 Mdot
.12586 .38152 Mdot
.35746 .53441 Mdot
.64702 .47892 Mdot
.42806 .67053 Mdot
.60933 .47292 Mdot
.62077 .45944 Mdot
.71731 .33824 Mdot
.63169 .43424 Mdot
.62579 .65196 Mdot
.4655 .29155 Mdot
.44916 .61469 Mdot
.44136 .6478 Mdot
.35074 .5367 Mdot
.42048 .34694 Mdot
.36864 .51151 Mdot
.55055 .43798 Mdot
.45843 .64295 Mdot
.63659 .47026 Mdot
.39855 .54294 Mdot
.42049 .35741 Mdot
.63158 .40725 Mdot
.31986 .41184 Mdot
.25989 .51401 Mdot
.59795 .64035 Mdot
.63525 .33158 Mdot
.53576 .18004 Mdot
.28865 .56162 Mdot
.60899 .43069 Mdot
.50045 .1526 Mdot
.19933 .50612 Mdot
.4256 .31746 Mdot
.73189 .42925 Mdot
.34449 .72382 Mdot
.61062 .41482 Mdot
.51579 .55682 Mdot
.64695 .51098 Mdot
.38977 .40519 Mdot
.43477 .64115 Mdot
.46279 .3197 Mdot
.64623 .49086 Mdot
.59574 .41665 Mdot
.6232 .2428 Mdot
.677 .47698 Mdot
.6316 .4883 Mdot
.49048 .33786 Mdot
.38724 .5443 Mdot
.59181 .51131 Mdot
.33963 .57111 Mdot
.24913 .47881 Mdot
.66726 .45933 Mdot
.45188 .64829 Mdot
.42736 .29261 Mdot
.65943 .48411 Mdot
.35223 .53339 Mdot
.62274 .43775 Mdot
.40905 .57232 Mdot
.46013 .30527 Mdot
.59377 .41843 Mdot
.66169 .64653 Mdot
.34765 .38945 Mdot
.46617 .35187 Mdot
.36397 .23041 Mdot
.63095 .44243 Mdot
.61128 .45267 Mdot
.43325 .31212 Mdot
.42975 .68498 Mdot
.49406 .5457 Mdot
.41452 .34238 Mdot
.35492 .49843 Mdot
.45112 .29691 Mdot
.58225 .48932 Mdot
.44246 .69195 Mdot
.24353 .48087 Mdot
.26106 .46839 Mdot
.78776 .61098 Mdot
.63138 .41 Mdot
.21484 .45679 Mdot
.44641 .67534 Mdot
.45009 .31247 Mdot
.36555 .51438 Mdot
.57493 .47025 Mdot
.43106 .34964 Mdot
.38661 .50497 Mdot
.65077 .62996 Mdot
.51347 .71819 Mdot
.46914 .35541 Mdot
.51969 .51217 Mdot
.34869 .49228 Mdot
.34965 .50977 Mdot
.78279 .42419 Mdot
.42943 .3172 Mdot
.64681 .64059 Mdot
.384 .50483 Mdot
.75074 .55098 Mdot
.57736 .47282 Mdot
.78671 .47294 Mdot
.55262 .15686 Mdot
.7802 .39925 Mdot
.26501 .32854 Mdot
.61792 .65786 Mdot
.37871 .4983 Mdot
.65983 .46373 Mdot
.43569 .33074 Mdot
.43998 .32359 Mdot
.57847 .4272 Mdot
.64511 .44166 Mdot
.58363 .46458 Mdot
.57782 .43783 Mdot
.62911 .74742 Mdot
.58008 .4567 Mdot
.44357 .57142 Mdot
.44486 .36145 Mdot
.64771 .43418 Mdot
.41355 .62653 Mdot
.58881 .40546 Mdot
.39802 .51275 Mdot
.61898 .46493 Mdot
.64844 .45187 Mdot
.67681 .4555 Mdot
.35826 .50733 Mdot
.25508 .71753 Mdot
.47428 .18411 Mdot
.42684 .7879 Mdot
.29581 .30997 Mdot
.43667 .67497 Mdot
.59477 .43141 Mdot
.62718 .63602 Mdot
.71684 .46707 Mdot
.62244 .45538 Mdot
.75288 .3396 Mdot
.64282 .4525 Mdot
.55645 .3566 Mdot
.70039 .48054 Mdot
.39515 .79457 Mdot
.41872 .47445 Mdot
.62693 .42367 Mdot
.5295 .21307 Mdot
.79772 .47427 Mdot
.59359 .63182 Mdot
.35499 .52712 Mdot
.40863 .64829 Mdot
.41984 .66279 Mdot
.34123 .54111 Mdot
.57466 .49444 Mdot
.48591 .24915 Mdot
.55257 .46773 Mdot
.23871 .47776 Mdot
.41411 .29337 Mdot
.62899 .67236 Mdot
.4758 .34706 Mdot
.43363 .15739 Mdot
.48105 .41595 Mdot
.41244 .5068 Mdot
.6657 .6554 Mdot
.43595 .61803 Mdot
.23253 .47382 Mdot
.6338 .63405 Mdot
.62704 .48488 Mdot
.46942 .31842 Mdot
.79993 .46919 Mdot
.68973 .4235 Mdot
.7414 .73587 Mdot
.42093 .33114 Mdot
.46834 .51269 Mdot
.35847 .52285 Mdot
.46131 .6864 Mdot
.61858 .41536 Mdot
.58816 .46066 Mdot
.46949 .29598 Mdot
.63561 .46026 Mdot
.39473 .38644 Mdot
.64784 .45701 Mdot
.45269 .61439 Mdot
.61542 .6077 Mdot
.36373 .5666 Mdot
.79755 .59192 Mdot
.4301 .36994 Mdot
.48423 .59816 Mdot
.44135 .62731 Mdot
.43293 .25378 Mdot
.392 .54961 Mdot
.65439 .63162 Mdot
.4211 .63387 Mdot
.61742 .62309 Mdot
.66921 .44921 Mdot
.42594 .64174 Mdot
.64674 .66249 Mdot
.48193 .72685 Mdot
.63803 .48889 Mdot
.72318 .54133 Mdot
.38518 .51563 Mdot
.48065 .3159 Mdot
.63234 .43341 Mdot
.26445 .47236 Mdot
.56219 .46109 Mdot
.19969 .47015 Mdot
.25082 .48637 Mdot
.23366 .48484 Mdot
.2584 .53898 Mdot
.61614 .63679 Mdot
.28215 .36755 Mdot
.49127 .46867 Mdot
.4132 .33339 Mdot
.64206 .49398 Mdot
.31758 .76923 Mdot
.38098 .5038 Mdot
.62675 .48384 Mdot
.35503 .7342 Mdot
.38407 .50558 Mdot
.60601 .46641 Mdot
.35154 .51627 Mdot
.43601 .32709 Mdot
.49177 .57572 Mdot
.42485 .30198 Mdot
.64166 .48324 Mdot
.37468 .53773 Mdot
.41277 .64149 Mdot
.45704 .32767 Mdot
.62354 .44232 Mdot
.59678 .43364 Mdot
.2367 .47106 Mdot
.64396 .42872 Mdot
.33777 .77036 Mdot
.6389 .46815 Mdot
.43012 .61576 Mdot
.67262 .4832 Mdot
.80992 .42869 Mdot
.51804 .71208 Mdot
.43539 .3626 Mdot
.24688 .48732 Mdot
.43132 .64809 Mdot
.5361 .63228 Mdot
.59897 .58568 Mdot
.61462 .43425 Mdot
.254 .47187 Mdot
.46184 .53232 Mdot
.3542 .54013 Mdot
.64576 .50859 Mdot
.43027 .41838 Mdot
.43095 .62903 Mdot
.23481 .47475 Mdot
.6895 .49182 Mdot
.42949 .29307 Mdot
.6518 .47669 Mdot
.42124 .64088 Mdot
.45831 .29795 Mdot
.57927 .47893 Mdot
.65916 .72584 Mdot
.26092 .47719 Mdot
.38356 .51392 Mdot
.55615 .51415 Mdot
.58371 .47139 Mdot
.41874 .66904 Mdot
.4277 .33605 Mdot
.36737 .54238 Mdot
.46734 .3368 Mdot
.80748 .48661 Mdot
.30302 .31641 Mdot
.52312 .78229 Mdot
.66351 .66516 Mdot
.18377 .42602 Mdot
.44527 .79139 Mdot
.30886 .34277 Mdot
.76027 .62283 Mdot
.52592 .83278 Mdot
.41594 .62831 Mdot
.73594 .49387 Mdot
.42831 .65732 Mdot
.66433 .45627 Mdot
.44533 .65313 Mdot
.36843 .8002 Mdot
.64268 .46204 Mdot
.43352 .6759 Mdot
.60701 .74617 Mdot
.64017 .43707 Mdot
.45637 .36022 Mdot
.16197 .5367 Mdot
.41627 .23512 Mdot
.50382 .42451 Mdot
.43537 .68183 Mdot
.70547 .28552 Mdot
.63901 .45026 Mdot
.66337 .40633 Mdot
.44095 .33231 Mdot
.64198 .512 Mdot
.64321 .67151 Mdot
.62909 .61771 Mdot
.76924 .45451 Mdot
.37944 .23693 Mdot
.55448 .40218 Mdot
.45275 .32696 Mdot
.54548 .18108 Mdot
.31903 .41471 Mdot
.25795 .46057 Mdot
.35619 .49199 Mdot
.25327 .71372 Mdot
.67091 .3934 Mdot
.53314 .52237 Mdot
.40919 .42143 Mdot
.45918 .31151 Mdot
.42777 .76273 Mdot
.36534 .53645 Mdot
.51317 .19909 Mdot
.54067 .30273 Mdot
.59069 .47418 Mdot
.36831 .55345 Mdot
.58404 .51538 Mdot
.3974 .39822 Mdot
.74904 .51247 Mdot
.3759 .62884 Mdot
.64222 .48637 Mdot
.28855 .3753 Mdot
.6157 .4566 Mdot
.78751 .48303 Mdot
.63342 .48354 Mdot
.46455 .34499 Mdot
.55527 .39546 Mdot
.56166 .58392 Mdot
.4284 .20276 Mdot
.46632 .41385 Mdot
.61208 .64962 Mdot
.59848 .44136 Mdot
.59015 .47017 Mdot
.62947 .66281 Mdot
.45708 .34041 Mdot
.61527 .49153 Mdot
.70202 .70467 Mdot
.58625 .47251 Mdot
.40206 .52676 Mdot
.52205 .59555 Mdot
.49637 .29819 Mdot
.60287 .41528 Mdot
.44865 .29297 Mdot
.35016 .52517 Mdot
.36846 .48912 Mdot
.60432 .38486 Mdot
.37359 .49907 Mdot
.6516 .47227 Mdot
.51297 .5879 Mdot
.44057 .30183 Mdot
.65925 .52437 Mdot
.45338 .34514 Mdot
.63333 .21177 Mdot
.34739 .51852 Mdot
.24339 .45836 Mdot
.65911 .54982 Mdot
.37428 .52904 Mdot
.40201 .25629 Mdot
.64819 .38324 Mdot
.56803 .41309 Mdot
.40798 .24705 Mdot
.41336 .66818 Mdot
.23018 .46487 Mdot
.36202 .53982 Mdot
.58293 .46656 Mdot
.66981 .46629 Mdot
.39454 .5534 Mdot
.65249 .26543 Mdot
.55786 .66523 Mdot
.63593 .48162 Mdot
.46231 .34459 Mdot
.45235 .31462 Mdot
.59265 .48938 Mdot
.62558 .45306 Mdot
.41985 .61699 Mdot
.25578 .47003 Mdot
.23076 .47911 Mdot
.25974 .46603 Mdot
.44392 .70149 Mdot
.20063 .39515 Mdot
.35031 .50902 Mdot
.21791 .4116 Mdot
.29104 .67531 Mdot
.62222 .38679 Mdot
.4159 .66683 Mdot
.59515 .46112 Mdot
.66322 .44179 Mdot
.37528 .5414 Mdot
.28256 .27755 Mdot
.53809 .42948 Mdot
.48061 .34187 Mdot
.40357 .54112 Mdot
.69775 .50253 Mdot
.3433 .46816 Mdot
.65074 .66577 Mdot
.49053 .40671 Mdot
.37446 .55569 Mdot
.46915 .32537 Mdot
.38789 .55677 Mdot
.58803 .46918 Mdot
.58065 .41726 Mdot
.44642 .30457 Mdot
.61687 .63399 Mdot
.66373 .48213 Mdot
.60676 .46552 Mdot
.82406 .39428 Mdot
.31683 .40578 Mdot
.33579 .47575 Mdot
.65515 .43594 Mdot
.57078 .40459 Mdot
.61089 .63952 Mdot
.59333 .48123 Mdot
.61549 .41585 Mdot
.35027 .37865 Mdot
.33821 .53894 Mdot
.59947 .63795 Mdot
.49762 .20279 Mdot
.42228 .335 Mdot
.34271 .76284 Mdot
.24977 .48042 Mdot
.34533 .55456 Mdot
.48464 .56974 Mdot
.23773 .46214 Mdot
.30959 .6721 Mdot
.39154 .7641 Mdot
.24825 .4601 Mdot
.39884 .63214 Mdot
.69162 .38996 Mdot
.57204 .44628 Mdot
.61662 .4668 Mdot
.63128 .6311 Mdot
.42965 .32262 Mdot
.44401 .50569 Mdot
.4787 .70974 Mdot
.60833 .44757 Mdot
.48162 .37567 Mdot
.36563 .75738 Mdot
.23437 .46973 Mdot
.61911 .64221 Mdot
.62168 .67143 Mdot
.61294 .45592 Mdot
.33377 .34368 Mdot
.45521 .32523 Mdot
.62333 .4424 Mdot
.58391 .43402 Mdot
.43026 .68204 Mdot
.47195 .32742 Mdot
.44239 .62758 Mdot
.25447 .48581 Mdot
.61929 .80979 Mdot
.83033 .41112 Mdot
.38643 .53251 Mdot
.43425 .77755 Mdot
.39565 .49831 Mdot
.32581 .58238 Mdot
.25635 .46516 Mdot
.61632 .44358 Mdot
.43152 .3687 Mdot
.6242 .43892 Mdot
.60525 .48479 Mdot
.62125 .48821 Mdot
.55288 .40404 Mdot
.75898 .34667 Mdot
.63577 .64184 Mdot
.56807 .40383 Mdot
.40554 .64789 Mdot
.38493 .78174 Mdot
.1699 .57571 Mdot
.58958 .44659 Mdot
.6082 .45335 Mdot
.42591 .35044 Mdot
.6351 .40432 Mdot
.36548 .54741 Mdot
.42394 .32227 Mdot
.66688 .47125 Mdot
.46229 .75076 Mdot
.5892 .481 Mdot
.46041 .79229 Mdot
.39028 .55616 Mdot
.49693 .40235 Mdot
.55754 .41702 Mdot
.25035 .46021 Mdot
.23137 .46355 Mdot
.2632 .46208 Mdot
.35464 .54413 Mdot
.42621 .67638 Mdot
.46595 .71395 Mdot
.65145 .51603 Mdot
.65797 .46508 Mdot
.56451 .41552 Mdot
.45534 .69849 Mdot
.51929 .57966 Mdot
.26752 .33743 Mdot
.70932 .44576 Mdot
.41032 .67178 Mdot
.48229 .35825 Mdot
.35637 .21816 Mdot
.42478 .32793 Mdot
.60053 .63036 Mdot
.40005 .52413 Mdot
.65141 .66779 Mdot
.7304 .31212 Mdot
.44829 .30272 Mdot
.47348 .29827 Mdot
.43522 .67624 Mdot
.43923 .47965 Mdot
.08903 .48764 Mdot
.45433 .66462 Mdot
.73322 .67099 Mdot
.44575 .33205 Mdot
.66283 .42187 Mdot
.45904 .53815 Mdot
.44731 .48584 Mdot
.4344 .66335 Mdot
.60583 .43015 Mdot
.36925 .2675 Mdot
.42302 .61653 Mdot
.65334 .5023 Mdot
.44095 .68584 Mdot
.36126 .50709 Mdot
.44493 .67871 Mdot
.46347 .37302 Mdot
.66613 .44267 Mdot
.10479 .42164 Mdot
.33827 .45853 Mdot
.62888 .43297 Mdot
.40351 .5334 Mdot
.68449 .73117 Mdot
.60133 .47851 Mdot
.64456 .67241 Mdot
.4138 .68427 Mdot
.58454 .72725 Mdot
.63715 .4456 Mdot
.44201 .66022 Mdot
.48276 .34557 Mdot
.31982 .51617 Mdot
.27482 .53307 Mdot
.2284 .47376 Mdot
.43177 .33148 Mdot
.26937 .46144 Mdot
.33715 .51996 Mdot
.67366 .47201 Mdot
.58084 .4405 Mdot
.45494 .35709 Mdot
.25723 .57277 Mdot
.67762 .44053 Mdot
.60888 .43085 Mdot
.43825 .62095 Mdot
.44168 .7118 Mdot
.20325 .57735 Mdot
.41416 .62943 Mdot
.56995 .40472 Mdot
.45753 .35539 Mdot
.66212 .47059 Mdot
.45044 .3628 Mdot
.64285 .49342 Mdot
.50206 .32112 Mdot
.42601 .32649 Mdot
.33931 .2739 Mdot
.63312 .41695 Mdot
.64679 .54427 Mdot
.60632 .48626 Mdot
.62882 .48666 Mdot
.41683 .68874 Mdot
.64032 .65576 Mdot
.66298 .4992 Mdot
.48747 .58786 Mdot
.62978 .6258 Mdot
.69004 .36155 Mdot
.42769 .68247 Mdot
.64136 .6297 Mdot
.69034 .5789 Mdot
.24619 .48718 Mdot
.62954 .64614 Mdot
.19904 .61684 Mdot
.38469 .53487 Mdot
.43299 .30122 Mdot
.64108 .43682 Mdot
.55899 .83413 Mdot
.55988 .65888 Mdot
.24189 .46675 Mdot
.63272 .44167 Mdot
.59673 .466 Mdot
.42001 .29889 Mdot
.46534 .15143 Mdot
.46658 .64501 Mdot
.65283 .48469 Mdot
.41524 .32346 Mdot
.5396 .15684 Mdot
.44863 .68547 Mdot
.62586 .64286 Mdot
.39802 .55453 Mdot
.41797 .37925 Mdot
.22717 .47086 Mdot
.34302 .5268 Mdot
.40853 .70579 Mdot
.71775 .28637 Mdot
.63579 .45176 Mdot
.41495 .65528 Mdot
.77891 .39475 Mdot
.61051 .51663 Mdot
.3463 .47914 Mdot
.53786 .37537 Mdot
.46009 .31355 Mdot
.39803 .55093 Mdot
.6121 .65578 Mdot
.43896 .30093 Mdot
.45855 .33919 Mdot
.37811 .49174 Mdot
.4464 .58569 Mdot
.46777 .5105 Mdot
.4013 .5418 Mdot
.37902 .39931 Mdot
.77769 .44624 Mdot
.25595 .47274 Mdot
.61795 .64382 Mdot
.81327 .48123 Mdot
.45553 .32153 Mdot
.25426 .71497 Mdot
.76109 .35327 Mdot
.63168 .48821 Mdot
.65379 .64921 Mdot
.31707 .68612 Mdot
.45628 .72589 Mdot
.38764 .50909 Mdot
.53043 .57672 Mdot
.63791 .67639 Mdot
.57667 .46737 Mdot
.5099 .33352 Mdot
.63021 .41794 Mdot
.38135 .50206 Mdot
.37952 .35589 Mdot
.47188 .33387 Mdot
.3363 .52325 Mdot
.40176 .39556 Mdot
.66052 .43681 Mdot
.61551 .42018 Mdot
.7898 .53662 Mdot
.47089 .31962 Mdot
.22659 .47255 Mdot
.61961 .43207 Mdot
.61181 .47299 Mdot
.67599 .47093 Mdot
.61789 .55026 Mdot
.33068 .36759 Mdot
.65375 .48522 Mdot
.44653 .69673 Mdot
.57524 .41126 Mdot
.61777 .41826 Mdot
.41996 .30472 Mdot
.80127 .37839 Mdot
.25996 .48316 Mdot
.61807 .46973 Mdot
.63431 .4811 Mdot
.35482 .49677 Mdot
.46506 .52156 Mdot
.44054 .47678 Mdot
.45635 .64453 Mdot
.75154 .60981 Mdot
.55318 .46573 Mdot
.43217 .34871 Mdot
.66214 .65558 Mdot
.65451 .41788 Mdot
.42471 .34428 Mdot
.56939 .42818 Mdot
.4125 .62069 Mdot
.25415 .46975 Mdot
.51649 .48259 Mdot
.62918 .65107 Mdot
.41424 .57726 Mdot
.23969 .42377 Mdot
.41141 .62964 Mdot
.65705 .4545 Mdot
.33902 .55602 Mdot
.44127 .63107 Mdot
.23831 .47065 Mdot
.6932 .48282 Mdot
.44292 .32453 Mdot
.47053 .33353 Mdot
.77763 .46649 Mdot
.47041 .67001 Mdot
.71498 .24494 Mdot
.36336 .50564 Mdot
.6057 .50244 Mdot
.22883 .44388 Mdot
.47002 .34184 Mdot
.80365 .50674 Mdot
.63828 .62883 Mdot
.3881 .51049 Mdot
.2689 .48482 Mdot
.42721 .34861 Mdot
.47501 .33971 Mdot
.63644 .49186 Mdot
.5942 .44849 Mdot
.75881 .63283 Mdot
.78818 .47696 Mdot
.35479 .51337 Mdot
.61955 .651 Mdot
.46148 .6554 Mdot
.65891 .43792 Mdot
.4268 .3131 Mdot
.56761 .35396 Mdot
.5798 .46296 Mdot
.42467 .61604 Mdot
.45376 .30914 Mdot
.62451 .66069 Mdot
.65529 .63905 Mdot
.62814 .48727 Mdot
.67379 .33286 Mdot
.37767 .52577 Mdot
.46318 .35598 Mdot
.41294 .27541 Mdot
.68394 .45984 Mdot
.59352 .44501 Mdot
.6084 .52907 Mdot
.3428 .52578 Mdot
.51525 .45764 Mdot
.63494 .68089 Mdot
.43885 .31916 Mdot
.62673 .43379 Mdot
.62567 .6515 Mdot
.55278 .52365 Mdot
.24795 .46205 Mdot
.44287 .68529 Mdot
.63945 .673 Mdot
.64393 .66027 Mdot
.63633 .62359 Mdot
.24379 .70214 Mdot
.40751 .31317 Mdot
.4902 .19693 Mdot
.62405 .49101 Mdot
.77158 .45966 Mdot
.61885 .40574 Mdot
.34631 .53868 Mdot
.4104 .6475 Mdot
.59857 .48098 Mdot
.63667 .49221 Mdot
.51429 .34394 Mdot
.68979 .51356 Mdot
.41402 .38806 Mdot
.4652 .31045 Mdot
.64792 .5465 Mdot
.41875 .67621 Mdot
.52961 .13921 Mdot
.23721 .72307 Mdot
.55279 .44028 Mdot
.45321 .50616 Mdot
.42468 .32019 Mdot
.37226 .49355 Mdot
.45359 .48491 Mdot
.39109 .56481 Mdot
.44022 .31514 Mdot
.66366 .44883 Mdot
.2245 .40798 Mdot
.62538 .62106 Mdot
.58263 .46006 Mdot
.35932 .51678 Mdot
.58304 .46229 Mdot
.3532 .54651 Mdot
.4488 .39478 Mdot
.38317 .42111 Mdot
.64263 .45475 Mdot
.67951 .44837 Mdot
.51764 .41642 Mdot
.59063 .44753 Mdot
.325 .6437 Mdot
.44807 .3412 Mdot
.37276 .25283 Mdot
.59886 .49208 Mdot
.66309 .31112 Mdot
.57682 .46053 Mdot
.25983 .58396 Mdot
.59175 .43057 Mdot
.52801 .53801 Mdot
.57706 .47038 Mdot
.59649 .43006 Mdot
.36877 .53936 Mdot
.35873 .49403 Mdot
.48193 .34622 Mdot
.22708 .46466 Mdot
.39369 .79275 Mdot
.60366 .45873 Mdot
.42854 .70111 Mdot
.25429 .44402 Mdot
.64286 .6584 Mdot
.44404 .3159 Mdot
.61274 .15711 Mdot
.34954 .5212 Mdot
.4462 .61327 Mdot
.28127 .59242 Mdot
.46665 .67073 Mdot
.39465 .58802 Mdot
.66569 .53974 Mdot
.61821 .65385 Mdot
.57575 .45992 Mdot
.70506 .35722 Mdot
.29914 .38797 Mdot
.64567 .50347 Mdot
.33033 .50926 Mdot
.7183 .47471 Mdot
.78071 .44145 Mdot
.60629 .63633 Mdot
.62003 .66435 Mdot
.36263 .53843 Mdot
.45123 .62482 Mdot
.57057 .49627 Mdot
.64307 .62993 Mdot
.40796 .65165 Mdot
.23677 .45594 Mdot
.59935 .60149 Mdot
.45278 .32276 Mdot
.50382 .43708 Mdot
.29561 .43416 Mdot
.35348 .51577 Mdot
.48711 .58333 Mdot
.44702 .38401 Mdot
.43332 .28651 Mdot
.23894 .4575 Mdot
.40902 .6789 Mdot
.41548 .35171 Mdot
.66813 .47583 Mdot
.68964 .42256 Mdot
.61579 .45509 Mdot
.64594 .63444 Mdot
.59122 .42737 Mdot
.40562 .6589 Mdot
.37621 .50523 Mdot
.43431 .63838 Mdot
.38012 .5252 Mdot
.23185 .38926 Mdot
.62859 .45446 Mdot
.59697 .44393 Mdot
.48123 .5547 Mdot
.47842 .34003 Mdot
.70798 .32933 Mdot
.41446 .69175 Mdot
.42704 .66606 Mdot
.66373 .46879 Mdot
.48395 .33768 Mdot
.64117 .61194 Mdot
.45474 .55027 Mdot
.58716 .43289 Mdot
.44684 .34174 Mdot
.65589 .47639 Mdot
.5231 .7753 Mdot
.3629 .42711 Mdot
.46818 .33741 Mdot
.41355 .20289 Mdot
.64194 .42369 Mdot
.72006 .42153 Mdot
.57826 .39709 Mdot
.71385 .65432 Mdot
.68237 .47528 Mdot
.42052 .32854 Mdot
.61953 .46272 Mdot
.43145 .34167 Mdot
.4288 .62204 Mdot
.35747 .50112 Mdot
.43419 .33441 Mdot
.61274 .4113 Mdot
.20161 .6667 Mdot
.35813 .51397 Mdot
.59721 .43654 Mdot
.3858 .54925 Mdot
.41736 .31755 Mdot
.47769 .32748 Mdot
.20665 .62123 Mdot
.3548 .46845 Mdot
.35556 .51754 Mdot
.65447 .46928 Mdot
.31174 .45799 Mdot
.66177 .47062 Mdot
.76584 .62401 Mdot
.61344 .50055 Mdot
.67045 .48609 Mdot
.1804 .43918 Mdot
.39471 .56693 Mdot
.67126 .20609 Mdot
.47953 .71517 Mdot
.2304 .68584 Mdot
.41112 .35641 Mdot
.60626 .63621 Mdot
.41526 .76205 Mdot
.25405 .48476 Mdot
.43243 .69347 Mdot
.59794 .48095 Mdot
.50133 .31447 Mdot
.40244 .54322 Mdot
.64319 .65078 Mdot
.64288 .45369 Mdot
.41729 .6132 Mdot
.18707 .59056 Mdot
.37946 .49848 Mdot
.45239 .31999 Mdot
.47957 .34017 Mdot
.50396 .16958 Mdot
.62884 .43648 Mdot
.60055 .44583 Mdot
.39986 .52 Mdot
.56058 .47724 Mdot
.6428 .62166 Mdot
.57459 .76241 Mdot
.35551 .5229 Mdot
.32272 .46586 Mdot
.46044 .30478 Mdot
.59563 .46388 Mdot
.53025 .60155 Mdot
.26712 .67934 Mdot
.52097 .22595 Mdot
.6302 .63244 Mdot
.77363 .58204 Mdot
.42052 .32906 Mdot
.36293 .51595 Mdot
.71583 .53091 Mdot
.56548 .46846 Mdot
.60059 .46894 Mdot
.77594 .57354 Mdot
.46008 .5267 Mdot
.67367 .64463 Mdot
.64925 .40652 Mdot
.46926 .52908 Mdot
.66495 .46605 Mdot
.66992 .46459 Mdot
.55203 .4445 Mdot
.60647 .41777 Mdot
.44025 .34247 Mdot
.50705 .30959 Mdot
.44585 .66699 Mdot
.60809 .2308 Mdot
.5357 .56932 Mdot
.63573 .42852 Mdot
.66296 .44431 Mdot
.44998 .23985 Mdot
.27607 .45556 Mdot
.44954 .33746 Mdot
.47471 .28477 Mdot
.34546 .51475 Mdot
.68162 .52012 Mdot
.46568 .68618 Mdot
.5253 .38788 Mdot
.44056 .63533 Mdot
.44622 .3428 Mdot
.42372 .66986 Mdot
.34459 .51251 Mdot
.41524 .65412 Mdot
.4445 .70073 Mdot
.37127 .55792 Mdot
.46601 .30684 Mdot
.58684 .43714 Mdot
.34877 .51704 Mdot
.79022 .54572 Mdot
.64693 .6349 Mdot
.20527 .6201 Mdot
.63499 .39852 Mdot
.66757 .36866 Mdot
.65926 .72545 Mdot
.42699 .64596 Mdot
.3524 .41644 Mdot
.42616 .3266 Mdot
.66291 .63874 Mdot
.43602 .34226 Mdot
.73634 .33043 Mdot
.63192 .66141 Mdot
.20469 .6221 Mdot
.69695 .54602 Mdot
.52668 .64113 Mdot
.58874 .41779 Mdot
.50087 .34048 Mdot
.43765 .63131 Mdot
.40197 .52398 Mdot
.34099 .71464 Mdot
.63574 .41177 Mdot
.30528 .34346 Mdot
.4116 .30213 Mdot
.23923 .48487 Mdot
.36761 .51354 Mdot
.33263 .50372 Mdot
.62956 .4417 Mdot
.5276 .62434 Mdot
.64429 .50137 Mdot
.70688 .52629 Mdot
.76275 .60714 Mdot
.52612 .38316 Mdot
.65056 .47629 Mdot
.45061 .63635 Mdot
.65588 .47452 Mdot
.69827 .4063 Mdot
.78157 .42467 Mdot
.6297 .39811 Mdot
.31302 .29934 Mdot
.60151 .7224 Mdot
.44125 .30523 Mdot
.56088 .40889 Mdot
.2458 .47215 Mdot
.65011 .42998 Mdot
.66274 .81845 Mdot
.63262 .64784 Mdot
.4357 .72833 Mdot
.60481 .41165 Mdot
.62215 .43496 Mdot
.6468 .34295 Mdot
.50321 .37596 Mdot
.26656 .48492 Mdot
.60502 .47405 Mdot
.75564 .58282 Mdot
.37122 .54454 Mdot
.59031 .49112 Mdot
.61643 .46271 Mdot
.81716 .51675 Mdot
.37803 .54764 Mdot
.42174 .65126 Mdot
.24863 .4872 Mdot
.46111 .65929 Mdot
.60313 .63999 Mdot
.43518 .46272 Mdot
.79856 .49008 Mdot
.36101 .42869 Mdot
.64603 .67391 Mdot
.58552 .42567 Mdot
.7159 .40488 Mdot
.61817 .42436 Mdot
.6162 .65982 Mdot
.37361 .55021 Mdot
.4403 .33948 Mdot
.50907 .47857 Mdot
.23848 .47662 Mdot
.6576 .4979 Mdot
.60751 .63745 Mdot
.43861 .32925 Mdot
.22006 .61043 Mdot
.43317 .317 Mdot
.37154 .53171 Mdot
.33981 .52777 Mdot
.63313 .65806 Mdot
.43798 .34333 Mdot
.45273 .68713 Mdot
.48182 .70855 Mdot
.62162 .50193 Mdot
.32343 .48598 Mdot
.4545 .37268 Mdot
.47874 .30769 Mdot
.42838 .36175 Mdot
.63201 .45356 Mdot
.46059 .51559 Mdot
.56443 .47023 Mdot
.35122 .53065 Mdot
.43287 .68904 Mdot
.78603 .47096 Mdot
.70113 .34861 Mdot
.34184 .45587 Mdot
.66509 .49604 Mdot
.61155 .41889 Mdot
.61282 .45563 Mdot
.64006 .47949 Mdot
.55594 .77237 Mdot
.62725 .45542 Mdot
.37719 .53434 Mdot
.44942 .65091 Mdot
.63214 .43753 Mdot
.24902 .47321 Mdot
.48923 .52194 Mdot
.66078 .65866 Mdot
.53007 .54335 Mdot
.23794 .71359 Mdot
.43939 .33037 Mdot
.41845 .63649 Mdot
.44131 .69079 Mdot
.65088 .63 Mdot
.36391 .50377 Mdot
.43111 .3215 Mdot
.70503 .63584 Mdot
.62526 .62644 Mdot
.61858 .47061 Mdot
.50109 .57849 Mdot
.38911 .2081 Mdot
.57676 .43241 Mdot
.61711 .48541 Mdot
.23772 .4867 Mdot
.46676 .65197 Mdot
.55057 .85144 Mdot
.44355 .53322 Mdot
.6381 .65656 Mdot
.6342 .66848 Mdot
.41956 .35317 Mdot
.63458 .5095 Mdot
.37942 .51896 Mdot
.46127 .54272 Mdot
.70711 .71856 Mdot
.33953 .73197 Mdot
.31669 .57783 Mdot
.59336 .48317 Mdot
.58519 .33709 Mdot
.64161 .49677 Mdot
.42413 .29419 Mdot
.4226 .35203 Mdot
.4519 .33228 Mdot
.36688 .53775 Mdot
.64031 .21756 Mdot
.37948 .53231 Mdot
.23955 .71733 Mdot
.42473 .3127 Mdot
.52633 .68571 Mdot
.42897 .67391 Mdot
.65236 .51444 Mdot
.61777 .65071 Mdot
.30452 .51334 Mdot
.55333 .41605 Mdot
.32845 .34283 Mdot
.41593 .66637 Mdot
.47527 .31944 Mdot
.69006 .4051 Mdot
.41965 .81004 Mdot
.4172 .45549 Mdot
.60959 .69234 Mdot
.73189 .33922 Mdot
.62923 .66215 Mdot
.49162 .2266 Mdot
.63396 .62039 Mdot
.38553 .50514 Mdot
.63402 .41108 Mdot
.62223 .41107 Mdot
.64777 .48528 Mdot
.62877 .45841 Mdot
.36354 .54171 Mdot
.61175 .49438 Mdot
.8095 .42818 Mdot
.25726 .47811 Mdot
.50061 .72808 Mdot
.65694 .65498 Mdot
.35519 .55172 Mdot
.44667 .64077 Mdot
.22836 .4615 Mdot
.80349 .58046 Mdot
.60659 .49109 Mdot
.60253 .4842 Mdot
.25974 .46337 Mdot
.55866 .46738 Mdot
.68154 .39969 Mdot
.44528 .66179 Mdot
.4338 .43688 Mdot
.61675 .66557 Mdot
.65106 .66774 Mdot
.38005 .55701 Mdot
.43609 .34264 Mdot
.63199 .62985 Mdot
.447 .62194 Mdot
.57611 .47386 Mdot
.67484 .44434 Mdot
.4561 .37236 Mdot
.76115 .35323 Mdot
.61723 .62107 Mdot
.64213 .38002 Mdot
.42653 .33915 Mdot
.41009 .30496 Mdot
.60247 .47366 Mdot
.69077 .4556 Mdot
.47094 .30257 Mdot
.65884 .65362 Mdot
.35863 .55403 Mdot
.53193 .6587 Mdot
.37762 .50256 Mdot
.43258 .32664 Mdot
.56463 .44377 Mdot
.46404 .30603 Mdot
.64413 .42676 Mdot
.37642 .14792 Mdot
.59917 .42178 Mdot
.40354 .25099 Mdot
.71958 .65457 Mdot
.44548 .68676 Mdot
.45615 .68064 Mdot
.25251 .47163 Mdot
.42324 .33417 Mdot
.65595 .4203 Mdot
.62706 .66653 Mdot
.21654 .66645 Mdot
.42288 .27842 Mdot
.41402 .67834 Mdot
.46812 .67353 Mdot
.36802 .54692 Mdot
.57605 .45091 Mdot
.59655 .46026 Mdot
.41613 .65357 Mdot
.64881 .73486 Mdot
.43745 .35274 Mdot
.6009 .44553 Mdot
.61601 .41752 Mdot
.44805 .66634 Mdot
.48415 .7084 Mdot
.49192 .37964 Mdot
.60785 .41764 Mdot
.69034 .55419 Mdot
.35004 .54163 Mdot
.64426 .46993 Mdot
.61785 .49481 Mdot
.64901 .65301 Mdot
.48999 .74458 Mdot
.78068 .4366 Mdot
.34362 .54095 Mdot
.2284 .47611 Mdot
.62594 .40745 Mdot
.4308 .67315 Mdot
.66365 .42337 Mdot
.50676 .81015 Mdot
.25228 .48247 Mdot
.62097 .44727 Mdot
.55412 .45001 Mdot
.46418 .35792 Mdot
.62208 .44386 Mdot
.52448 .36218 Mdot
.45687 .65507 Mdot
.62233 .44754 Mdot
.67776 .33031 Mdot
.36328 .54374 Mdot
.55654 .41373 Mdot
.63482 .67136 Mdot
.7122 .66301 Mdot
.26392 .42678 Mdot
.44382 .70483 Mdot
.65637 .64383 Mdot
.58899 .42909 Mdot
.44225 .62265 Mdot
.39983 .55316 Mdot
.31522 .33535 Mdot
.571 .44428 Mdot
.37025 .50348 Mdot
.37285 .50637 Mdot
.63372 .65463 Mdot
.61272 .16978 Mdot
.55333 .45735 Mdot
.58869 .4437 Mdot
.79141 .64715 Mdot
.41082 .33021 Mdot
.58725 .44242 Mdot
.57792 .44589 Mdot
.38539 .51851 Mdot
.64646 .55837 Mdot
.38892 .30031 Mdot
.60716 .74636 Mdot
.35201 .54555 Mdot
.40678 .6854 Mdot
.43954 .62329 Mdot
.65696 .65068 Mdot
.44405 .30618 Mdot
.64177 .67768 Mdot
.44059 .67646 Mdot
.63069 .48668 Mdot
.39221 .51926 Mdot
.56269 .24854 Mdot
.39804 .50772 Mdot
.42736 .61344 Mdot
.45671 .29328 Mdot
.21934 .44624 Mdot
.82871 .63189 Mdot
.28968 .42345 Mdot
.35365 .55354 Mdot
.64337 .65818 Mdot
.44082 .55476 Mdot
.61162 .41932 Mdot
.49146 .21302 Mdot
.58307 .45049 Mdot
.73575 .34238 Mdot
.4095 .64968 Mdot
.24449 .4567 Mdot
.63559 .41113 Mdot
.76896 .58322 Mdot
.35175 .55103 Mdot
.36183 .5445 Mdot
.62883 .47542 Mdot
.37366 .53074 Mdot
.59726 .45379 Mdot
.45159 .66357 Mdot
.62819 .18066 Mdot
.60225 .42561 Mdot
.59841 .39724 Mdot
.33945 .54362 Mdot
.20471 .62013 Mdot
.40377 .67071 Mdot
.59596 .33844 Mdot
.43851 .8198 Mdot
.37449 .5272 Mdot
.58407 .39305 Mdot
.42456 .6412 Mdot
.23501 .48576 Mdot
.41467 .5997 Mdot
.58566 .46121 Mdot
.60709 .48863 Mdot
.66128 .47617 Mdot
.61726 .41955 Mdot
.47836 .21819 Mdot
.70542 .44452 Mdot
.56604 .31374 Mdot
.60673 .48569 Mdot
.44236 .25902 Mdot
.37609 .53861 Mdot
.42061 .39028 Mdot
.6711 .66536 Mdot
.61055 .49044 Mdot
.50626 .37155 Mdot
.35109 .54813 Mdot
.25554 .72789 Mdot
.37332 .54778 Mdot
.43344 .64555 Mdot
.37721 .49395 Mdot
.64289 .42753 Mdot
.45421 .31558 Mdot
.45419 .65405 Mdot
.25953 .35046 Mdot
.42807 .69235 Mdot
.6291 .43352 Mdot
.50113 .70737 Mdot
.44347 .68773 Mdot
.50268 .52834 Mdot
.45162 .31224 Mdot
.75562 .56889 Mdot
.4112 .32399 Mdot
.61708 .44077 Mdot
.61267 .43685 Mdot
.22587 .46297 Mdot
.37855 .49789 Mdot
.41847 .31785 Mdot
.82229 .38925 Mdot
.60596 .65673 Mdot
.45842 .33173 Mdot
.68841 .47099 Mdot
.45532 .51947 Mdot
.46433 .35243 Mdot
.73434 .60869 Mdot
.37942 .50001 Mdot
.41962 .35669 Mdot
.68461 .49268 Mdot
.54798 .53491 Mdot
.644 .61902 Mdot
.40992 .62328 Mdot
.48359 .48989 Mdot
.44501 .62948 Mdot
.33465 .52634 Mdot
.46173 .62766 Mdot
.3738 .54388 Mdot
.41019 .24571 Mdot
.38091 .35594 Mdot
.35744 .56875 Mdot
.33811 .52438 Mdot
.43816 .66939 Mdot
.63802 .48023 Mdot
.55511 .58993 Mdot
.68259 .48305 Mdot
.58225 .41804 Mdot
.34582 .53044 Mdot
.41878 .3318 Mdot
.44905 .29796 Mdot
.49793 .33493 Mdot
.47794 .3345 Mdot
.4488 .64102 Mdot
.36279 .41588 Mdot
.72551 .31578 Mdot
.3911 .54936 Mdot
.41369 .51351 Mdot
.66333 .4648 Mdot
.43379 .67255 Mdot
.42251 .62142 Mdot
.38102 .51307 Mdot
.54999 .22099 Mdot
.56861 .40913 Mdot
.41714 .30593 Mdot
.42546 .31169 Mdot
.46324 .3512 Mdot
.44896 .36861 Mdot
.59483 .1984 Mdot
.40197 .52363 Mdot
.42225 .32537 Mdot
.62747 .46614 Mdot
.59037 .47845 Mdot
.23199 .47635 Mdot
.64892 .66495 Mdot
.61193 .4019 Mdot
.59942 .40106 Mdot
.60042 .47226 Mdot
.44261 .68648 Mdot
.64735 .52472 Mdot
.24866 .48257 Mdot
.46611 .64072 Mdot
.45843 .69527 Mdot
.24105 .45864 Mdot
.39871 .30568 Mdot
.4111 .81704 Mdot
.6531 .48431 Mdot
.72855 .47594 Mdot
.43141 .66786 Mdot
.36249 .34825 Mdot
.51751 .4494 Mdot
.65048 .47237 Mdot
.5876 .57842 Mdot
.4534 .66206 Mdot
.41982 .28893 Mdot
.58651 .45053 Mdot
.25866 .46671 Mdot
.6617 .65178 Mdot
.68335 .49098 Mdot
.2399 .48779 Mdot
.44582 .34482 Mdot
.60299 .70655 Mdot
.41294 .34369 Mdot
.44797 .68784 Mdot
.55663 .41214 Mdot
.08631 .47287 Mdot
.43598 .62967 Mdot
.27937 .71848 Mdot
.39014 .37884 Mdot
.60366 .42302 Mdot
.4423 .62784 Mdot
.42287 .28865 Mdot
.34937 .54035 Mdot
.47899 .53328 Mdot
.42815 .31213 Mdot
.23151 .45937 Mdot
.2299 .46837 Mdot
.44666 .66593 Mdot
.46258 .31132 Mdot
.60867 .4972 Mdot
.44414 .36426 Mdot
.38145 .49452 Mdot
.64849 .45048 Mdot
.39603 .79518 Mdot
.68848 .42061 Mdot
.42592 .34054 Mdot
.43999 .61558 Mdot
.61277 .63759 Mdot
.64158 .45555 Mdot
.32932 .7523 Mdot
.57673 .44677 Mdot
.38077 .55085 Mdot
.35734 .31574 Mdot
.548 .24954 Mdot
.63412 .483 Mdot
.665 .45444 Mdot
.38034 .5579 Mdot
.63465 .48445 Mdot
.57612 .4366 Mdot
.33613 .48448 Mdot
.46955 .34942 Mdot
.61426 .45125 Mdot
.41217 .62515 Mdot
.74379 .3768 Mdot
.63408 .40651 Mdot
.3013 .29737 Mdot
.76199 .57556 Mdot
.36358 .30908 Mdot
.64607 .40929 Mdot
.79457 .54273 Mdot
.60733 .43657 Mdot
.63599 .45822 Mdot
.65182 .48159 Mdot
.56148 .33635 Mdot
.43813 .67387 Mdot
.40939 .67232 Mdot
.65408 .62352 Mdot
.7611 .58186 Mdot
.65244 .64653 Mdot
.36477 .55421 Mdot
.25731 .5419 Mdot
.25583 .47851 Mdot
.4343 .34218 Mdot
.66872 .44983 Mdot
.43668 .69681 Mdot
.59269 .46329 Mdot
.65158 .4334 Mdot
.45222 .67288 Mdot
.43868 .62625 Mdot
.47127 .65915 Mdot
.62658 .62348 Mdot
.44437 .3351 Mdot
.63724 .48994 Mdot
.62864 .62634 Mdot
.5983 .49399 Mdot
.45153 .53088 Mdot
.44687 .33575 Mdot
.4473 .36448 Mdot
.4303 .29861 Mdot
.62224 .491 Mdot
.64134 .42904 Mdot
.38048 .53086 Mdot
.45326 .37368 Mdot
.39628 .54775 Mdot
.44442 .6305 Mdot
.4534 .68238 Mdot
.58569 .46198 Mdot
.66908 .38864 Mdot
.63653 .6668 Mdot
.43006 .64668 Mdot
.26557 .47015 Mdot
.65631 .6263 Mdot
.63291 .4427 Mdot
.44714 .63372 Mdot
.64826 .66958 Mdot
.59872 .2371 Mdot
.47928 .83396 Mdot
.61201 .6349 Mdot
.62795 .47449 Mdot
.66381 .34319 Mdot
.73396 .51663 Mdot
.60923 .66343 Mdot
.39382 .5438 Mdot
.57757 .45256 Mdot
.66621 .74069 Mdot
.62754 .67499 Mdot
.76496 .36143 Mdot
.44928 .678 Mdot
.67404 .54254 Mdot
.68812 .48497 Mdot
.52908 .20303 Mdot
.63522 .6778 Mdot
.43442 .3213 Mdot
.44076 .37582 Mdot
.62274 .47456 Mdot
.63963 .68482 Mdot
.37714 .48923 Mdot
.44303 .69125 Mdot
.43705 .70114 Mdot
.46562 .31615 Mdot
.3554 .44279 Mdot
.41785 .61972 Mdot
.54535 .42112 Mdot
.40086 .61917 Mdot
.65077 .53806 Mdot
.53032 .17972 Mdot
.24601 .36524 Mdot
.67674 .45216 Mdot
.60982 .64337 Mdot
.39103 .56117 Mdot
.37815 .53088 Mdot
.36593 .53422 Mdot
.45948 .67131 Mdot
.46661 .49508 Mdot
.41317 .65838 Mdot
.30406 .35686 Mdot
.62512 .65065 Mdot
.74484 .5625 Mdot
.64926 .41414 Mdot
.60662 .42191 Mdot
.58171 .48258 Mdot
.66306 .47456 Mdot
.60621 .43766 Mdot
.35519 .51397 Mdot
.46347 .67464 Mdot
.58903 .73131 Mdot
.46035 .34798 Mdot
.21793 .57848 Mdot
.4286 .67397 Mdot
.24495 .48789 Mdot
.63875 .64218 Mdot
.79376 .49462 Mdot
.41967 .70774 Mdot
.42421 .66919 Mdot
.56868 .45418 Mdot
.41995 .34312 Mdot
.60488 .54877 Mdot
.60853 .43082 Mdot
.42878 .64665 Mdot
.43955 .61059 Mdot
.50331 .23235 Mdot
.54935 .47755 Mdot
.62492 .61051 Mdot
.45569 .51519 Mdot
.64108 .68044 Mdot
.68966 .44311 Mdot
.36144 .35112 Mdot
.44102 .67423 Mdot
.43843 .64661 Mdot
.60697 .64538 Mdot
.70623 .40514 Mdot
.45496 .30758 Mdot
.24705 .45683 Mdot
.38899 .54401 Mdot
.61413 .42759 Mdot
.45957 .66421 Mdot
.72551 .47271 Mdot
.49687 .5774 Mdot
.35753 .52637 Mdot
.46674 .64393 Mdot
.57783 .46384 Mdot
.62677 .47887 Mdot
.63227 .66304 Mdot
.55818 .63772 Mdot
.68628 .48137 Mdot
.23123 .68685 Mdot
.39032 .42157 Mdot
.46146 .41599 Mdot
.6005 .46853 Mdot
.47116 .32397 Mdot
.25574 .46408 Mdot
.61756 .64319 Mdot
.58814 .4856 Mdot
.45202 .83155 Mdot
.47141 .37288 Mdot
.36166 .51239 Mdot
.25556 .46295 Mdot
.47036 .49824 Mdot
.5771 .44489 Mdot
.58324 .45036 Mdot
.63045 .45584 Mdot
.47347 .84213 Mdot
.408 .65689 Mdot
.43608 .367 Mdot
.63272 .63215 Mdot
.46992 .35532 Mdot
.41263 .67973 Mdot
.49374 .46302 Mdot
.63439 .43898 Mdot
.42182 .29982 Mdot
.43546 .31838 Mdot
.36751 .54696 Mdot
.34268 .52896 Mdot
.45343 .71444 Mdot
.59725 .42389 Mdot
.26016 .47111 Mdot
.41602 .33971 Mdot
.4632 .6416 Mdot
.63067 .66157 Mdot
.34633 .5172 Mdot
.60998 .48695 Mdot
.44381 .66884 Mdot
.65948 .49201 Mdot
.45027 .36117 Mdot
.42507 .66979 Mdot
.25195 .48961 Mdot
.63875 .66769 Mdot
.60942 .48843 Mdot
.62445 .71755 Mdot
.25047 .45913 Mdot
.62595 .41494 Mdot
.67955 .36267 Mdot
.66303 .68192 Mdot
.26143 .34529 Mdot
.41364 .64076 Mdot
.24677 .47804 Mdot
.4255 .35638 Mdot
.55749 .53463 Mdot
.44138 .6444 Mdot
.57641 .35978 Mdot
.55773 .60893 Mdot
.63858 .48793 Mdot
.46247 .32578 Mdot
.64025 .60108 Mdot
.25541 .71975 Mdot
.71777 .53856 Mdot
.6046 .4473 Mdot
.44419 .6282 Mdot
.6534 .66642 Mdot
.38666 .55232 Mdot
.30297 .29684 Mdot
.52726 .18339 Mdot
.4694 .65841 Mdot
.64964 .48959 Mdot
.4166 .3406 Mdot
.37916 .51165 Mdot
.22133 .40347 Mdot
.44462 .62028 Mdot
.41071 .63726 Mdot
.63677 .44871 Mdot
.62544 .6328 Mdot
.6339 .74553 Mdot
.40738 .6636 Mdot
.46222 .66226 Mdot
.21197 .58177 Mdot
.61593 .62369 Mdot
.62517 .46679 Mdot
.49799 .33491 Mdot
.57384 .46748 Mdot
.24062 .68804 Mdot
.25077 .47859 Mdot
.45784 .35014 Mdot
.58428 .46831 Mdot
.5985 .72349 Mdot
.44276 .63781 Mdot
.45339 .50461 Mdot
.46696 .62623 Mdot
.35809 .50846 Mdot
.45876 .66475 Mdot
.58912 .45452 Mdot
.34035 .53984 Mdot
.63916 .666 Mdot
.60718 .41781 Mdot
.64388 .43071 Mdot
.42415 .29021 Mdot
.39073 .50876 Mdot
.75074 .40967 Mdot
.35502 .49061 Mdot
.38793 .55654 Mdot
.40544 .31527 Mdot
.62076 .47291 Mdot
.42844 .65296 Mdot
.41191 .61767 Mdot
.61612 .49661 Mdot
.36473 .35339 Mdot
.45902 .31125 Mdot
.42632 .72627 Mdot
.55029 .84905 Mdot
.55415 .47527 Mdot
.26342 .4772 Mdot
.75241 .45328 Mdot
.35593 .54272 Mdot
.62423 .48492 Mdot
.43183 .34586 Mdot
.46431 .65864 Mdot
.41671 .61913 Mdot
.56923 .46754 Mdot
.37911 .50727 Mdot
.65706 .66509 Mdot
.41651 .62734 Mdot
.49197 .57476 Mdot
.62542 .44568 Mdot
.30438 .34122 Mdot
.41799 .63062 Mdot
.16861 .59851 Mdot
.59355 .72628 Mdot
.4672 .3358 Mdot
.65691 .44046 Mdot
.48138 .34272 Mdot
.63816 .63304 Mdot
.4117 .5963 Mdot
.3792 .50564 Mdot
.5517 .38755 Mdot
.82611 .48454 Mdot
.43539 .67662 Mdot
.44189 .34232 Mdot
.62733 .48987 Mdot
.55195 .39149 Mdot
.58989 .43158 Mdot
.63146 .56549 Mdot
.64589 .70495 Mdot
.34108 .51862 Mdot
.37665 .55321 Mdot
.6609 .43785 Mdot
.63691 .62168 Mdot
.4038 .6427 Mdot
.45011 .67521 Mdot
.52437 .13323 Mdot
.24968 .4903 Mdot
.74696 .64835 Mdot
.61764 .48982 Mdot
.46636 .65802 Mdot
.70532 .35095 Mdot
.40003 .52087 Mdot
.62885 .50639 Mdot
.45735 .69051 Mdot
.25757 .66188 Mdot
.45502 .52993 Mdot
.6162 .44678 Mdot
.56243 .48127 Mdot
.3859 .54819 Mdot
.4418 .5495 Mdot
.41392 .65835 Mdot
.60762 .50068 Mdot
.34335 .49656 Mdot
.20253 .59649 Mdot
.82456 .45565 Mdot
.44486 .33484 Mdot
.43984 .6142 Mdot
.35746 .50977 Mdot
.61724 .52579 Mdot
.6569 .65627 Mdot
.45889 .64662 Mdot
.43475 .69187 Mdot
.65273 .45046 Mdot
.61953 .40143 Mdot
.55078 .46897 Mdot
.45594 .34104 Mdot
.38492 .53058 Mdot
.6482 .41758 Mdot
.37416 .43577 Mdot
.65901 .48183 Mdot
.38472 .52609 Mdot
.16667 .32001 Mdot
.57047 .43968 Mdot
.58911 .43821 Mdot
.68015 .62879 Mdot
.44609 .30054 Mdot
.47453 .34563 Mdot
.37307 .42052 Mdot
.61682 .48979 Mdot
.53258 .64006 Mdot
.4412 .33518 Mdot
.45926 .3133 Mdot
.52071 .6921 Mdot
.64908 .45678 Mdot
.41729 .57456 Mdot
.38056 .51827 Mdot
.35367 .51223 Mdot
.46019 .36014 Mdot
.65417 .51373 Mdot
.39683 .55612 Mdot
.45837 .21853 Mdot
.4269 .67648 Mdot
.3611 .35065 Mdot
.43531 .35786 Mdot
.54413 .61683 Mdot
.38239 .5018 Mdot
.20695 .69247 Mdot
.55135 .54392 Mdot
.64003 .50033 Mdot
.63069 .48039 Mdot
.64879 .65645 Mdot
.61226 .38374 Mdot
.22953 .47792 Mdot
.37265 .53256 Mdot
.49707 .77962 Mdot
.45271 .33173 Mdot
.5913 .43494 Mdot
.78365 .47674 Mdot
.24306 .39949 Mdot
.32204 .2941 Mdot
.43881 .30653 Mdot
.45736 .32423 Mdot
.41677 .67325 Mdot
.43306 .68528 Mdot
.6211 .45906 Mdot
.37012 .53822 Mdot
.42851 .36889 Mdot
.38955 .53309 Mdot
.44128 .67584 Mdot
.42573 .6652 Mdot
.25015 .484 Mdot
.60673 .51188 Mdot
.45034 .68158 Mdot
.21289 .61443 Mdot
.37825 .43617 Mdot
.43466 .28293 Mdot
.82477 .63179 Mdot
.21621 .40504 Mdot
.6921 .65283 Mdot
.66163 .64467 Mdot
.23096 .49031 Mdot
.36504 .49276 Mdot
.66358 .44433 Mdot
.59385 .47465 Mdot
.23448 .46897 Mdot
.36578 .49972 Mdot
.64406 .64571 Mdot
.37893 .49771 Mdot
.6206 .64277 Mdot
.41291 .68752 Mdot
.63262 .40658 Mdot
.58031 .43624 Mdot
.3536 .52168 Mdot
.41975 .65396 Mdot
.44677 .68765 Mdot
.65615 .62868 Mdot
.78982 .50304 Mdot
.44638 .66801 Mdot
.43666 .35922 Mdot
.68891 .29041 Mdot
.23063 .46831 Mdot
.58733 .44937 Mdot
.79137 .48316 Mdot
.50685 .223 Mdot
.64245 .48846 Mdot
.25486 .46205 Mdot
.54443 .13741 Mdot
.63197 .40906 Mdot
.52466 .15325 Mdot
.24423 .48095 Mdot
.45977 .30187 Mdot
.42419 .63771 Mdot
.22674 .47462 Mdot
.63435 .52538 Mdot
.60189 .62392 Mdot
.6309 .39885 Mdot
.43139 .30823 Mdot
.44093 .29317 Mdot
.39672 .3965 Mdot
.24474 .69127 Mdot
.61424 .64097 Mdot
.6399 .65023 Mdot
.44344 .64689 Mdot
.26908 .50589 Mdot
.68601 .45107 Mdot
.64123 .65269 Mdot
.54374 .78726 Mdot
.66199 .46706 Mdot
.77141 .6125 Mdot
.58469 .57715 Mdot
.46983 .3219 Mdot
.39124 .33557 Mdot
.44281 .64148 Mdot
.44222 .3418 Mdot
.47665 .42991 Mdot
.58187 .48247 Mdot
.44932 .33473 Mdot
.38598 .52288 Mdot
.32466 .6737 Mdot
.47992 .32985 Mdot
.47845 .54236 Mdot
.37864 .51856 Mdot
.6613 .68232 Mdot
.69659 .58693 Mdot
.64449 .83956 Mdot
.37213 .53437 Mdot
.42646 .6425 Mdot
.45012 .68363 Mdot
.44964 .66505 Mdot
.4282 .3115 Mdot
.43111 .62288 Mdot
.45371 .34839 Mdot
.46764 .71976 Mdot
.79877 .52472 Mdot
.63075 .65775 Mdot
.34419 .47245 Mdot
.44441 .3186 Mdot
.32382 .38824 Mdot
.83398 .59828 Mdot
.62958 .47277 Mdot
.34854 .49395 Mdot
.60839 .64913 Mdot
.20516 .49891 Mdot
.64963 .65198 Mdot
.42379 .64128 Mdot
.36017 .34975 Mdot
.59826 .45343 Mdot
.53056 .36436 Mdot
.62849 .66877 Mdot
.43381 .30849 Mdot
.62077 .41569 Mdot
.4619 .70973 Mdot
.65492 .64306 Mdot
.66132 .65218 Mdot
.60303 .43812 Mdot
.4734 .31891 Mdot
.42541 .65948 Mdot
.35631 .49725 Mdot
.67041 .63827 Mdot
.63459 .51945 Mdot
.6393 .48184 Mdot
.60166 .50162 Mdot
.43919 .47783 Mdot
.64692 .74515 Mdot
.3748 .5252 Mdot
.75027 .49724 Mdot
.44033 .68393 Mdot
.70429 .54687 Mdot
.31953 .41831 Mdot
.34125 .47563 Mdot
.24986 .47935 Mdot
.25285 .47806 Mdot
.61203 .44372 Mdot
.62522 .76286 Mdot
.36596 .25756 Mdot
.3596 .47981 Mdot
.23547 .46274 Mdot
.44615 .68792 Mdot
.45974 .37581 Mdot
.43931 .40291 Mdot
.60717 .40561 Mdot
.34276 .52675 Mdot
.44582 .6742 Mdot
.51056 .81103 Mdot
.62662 .64926 Mdot
.35617 .39964 Mdot
.6322 .43515 Mdot
.59822 .44542 Mdot
.3696 .51649 Mdot
.38019 .53031 Mdot
.29782 .32051 Mdot
.40083 .41266 Mdot
.3544 .73894 Mdot
.41427 .57277 Mdot
.54116 .81259 Mdot
.4599 .38839 Mdot
.42847 .34424 Mdot
.25161 .48632 Mdot
.38555 .55971 Mdot
.58364 .44613 Mdot
.45593 .29969 Mdot
.3264 .2908 Mdot
.40242 .32013 Mdot
.76939 .6053 Mdot
.53704 .64014 Mdot
.62732 .4253 Mdot
.42145 .34651 Mdot
.44407 .34023 Mdot
.46522 .36241 Mdot
.24266 .45891 Mdot
.60394 .47188 Mdot
.63818 .47948 Mdot
.63478 .41214 Mdot
.58806 .38013 Mdot
.6232 .44382 Mdot
.32215 .42932 Mdot
.32392 .46558 Mdot
.49017 .76219 Mdot
.6419 .49167 Mdot
.37047 .50035 Mdot
.66995 .45354 Mdot
.64262 .62269 Mdot
.64819 .4913 Mdot
.76133 .63472 Mdot
.36425 .52767 Mdot
.6968 .3959 Mdot
.39595 .61766 Mdot
.6331 .43447 Mdot
.64547 .67355 Mdot
.64226 .74682 Mdot
.79435 .45714 Mdot
.21239 .58833 Mdot
.43794 .36033 Mdot
.44457 .71215 Mdot
.38795 .49603 Mdot
.42983 .65292 Mdot
.6274 .50307 Mdot
.26092 .47915 Mdot
.18668 .41654 Mdot
.5355 .59826 Mdot
.58109 .45172 Mdot
.70028 .4745 Mdot
.47102 .33628 Mdot
.44045 .63294 Mdot
.43453 .38813 Mdot
.63402 .45705 Mdot
.63768 .63089 Mdot
.63569 .62777 Mdot
.4345 .41726 Mdot
.4527 .78387 Mdot
.57903 .54432 Mdot
.37119 .51804 Mdot
.41959 .61719 Mdot
.63442 .67733 Mdot
.41076 .24753 Mdot
.37934 .48883 Mdot
.35571 .54249 Mdot
.39164 .5123 Mdot
.62182 .4241 Mdot
.24319 .48452 Mdot
.50185 .79363 Mdot
.22786 .46262 Mdot
.63494 .43202 Mdot
.42833 .68881 Mdot
.22656 .47563 Mdot
.65209 .65211 Mdot
.37878 .55653 Mdot
.43597 .6829 Mdot
.61605 .43813 Mdot
.44199 .33038 Mdot
.77188 .47424 Mdot
.71032 .69959 Mdot
.46556 .7341 Mdot
.47028 .73291 Mdot
.42608 .30479 Mdot
.32885 .77222 Mdot
.32318 .4863 Mdot
.54442 .22015 Mdot
.62365 .59991 Mdot
.61848 .49737 Mdot
.68617 .22946 Mdot
.41393 .65335 Mdot
.45209 .64773 Mdot
.61972 .44968 Mdot
.45422 .62947 Mdot
.59075 .43371 Mdot
.41381 .67129 Mdot
.29532 .71666 Mdot
.60016 .41073 Mdot
.45085 .64571 Mdot
.68763 .45201 Mdot
.64119 .44802 Mdot
.47255 .33187 Mdot
.46085 .64869 Mdot
.64537 .49902 Mdot
.17522 .42151 Mdot
.35568 .53618 Mdot
.23813 .45956 Mdot
.32093 .47748 Mdot
.38553 .50151 Mdot
.4623 .33453 Mdot
.62461 .40498 Mdot
.63339 .66513 Mdot
.43629 .32388 Mdot
.46109 .70499 Mdot
.62233 .66599 Mdot
.36262 .41858 Mdot
.44234 .36223 Mdot
.23216 .47317 Mdot
.63369 .66775 Mdot
.61256 .39452 Mdot
.45575 .66501 Mdot
.71843 .70664 Mdot
.22882 .46245 Mdot
.59555 .45915 Mdot
.40399 .62111 Mdot
.3804 .49887 Mdot
.61509 .45994 Mdot
.44459 .62741 Mdot
.24757 .4591 Mdot
.63399 .42117 Mdot
.62802 .41653 Mdot
.46282 .40555 Mdot
.34451 .30668 Mdot
.63472 .66221 Mdot
.41268 .30194 Mdot
.6271 .46414 Mdot
.63541 .62093 Mdot
.30222 .58461 Mdot
.67398 .45541 Mdot
.48274 .33394 Mdot
.52376 .40232 Mdot
.43253 .68628 Mdot
.39452 .54942 Mdot
.42377 .61297 Mdot
.6621 .65361 Mdot
.83506 .38702 Mdot
.24208 .48604 Mdot
.66733 .51112 Mdot
.58676 .48837 Mdot
.42968 .59812 Mdot
.44845 .33965 Mdot
.33224 .70889 Mdot
.61225 .48896 Mdot
.70313 .45702 Mdot
.59398 .44214 Mdot
.58847 .72484 Mdot
.4565 .30966 Mdot
.58947 .44576 Mdot
.70283 .42265 Mdot
.64695 .40804 Mdot
.65067 .6714 Mdot
.72973 .57094 Mdot
.67061 .4594 Mdot
.09115 .52987 Mdot
.26132 .46531 Mdot
.45211 .67099 Mdot
.46637 .57638 Mdot
.37215 .60947 Mdot
.5358 .17786 Mdot
.45485 .34511 Mdot
.58179 .52692 Mdot
.4272 .65639 Mdot
.79666 .42367 Mdot
.29916 .75489 Mdot
.64026 .44351 Mdot
.57922 .46604 Mdot
.42384 .64125 Mdot
.46547 .65385 Mdot
.25939 .47792 Mdot
.63948 .49585 Mdot
.69412 .48135 Mdot
.45334 .62223 Mdot
.62159 .43471 Mdot
.49564 .27114 Mdot
.34341 .5091 Mdot
.469 .35325 Mdot
.38709 .55216 Mdot
.35191 .53831 Mdot
.64181 .23962 Mdot
.39036 .4212 Mdot
.3836 .52804 Mdot
.37979 .48382 Mdot
.76467 .63529 Mdot
.5289 .39747 Mdot
.64544 .67671 Mdot
.41308 .77127 Mdot
.44697 .65541 Mdot
.60564 .47366 Mdot
.41985 .32126 Mdot
.55655 .204 Mdot
.28727 .64115 Mdot
.35304 .35526 Mdot
.63518 .47595 Mdot
.44613 .64445 Mdot
.24029 .45801 Mdot
.60461 .40848 Mdot
.70822 .54118 Mdot
.60118 .44694 Mdot
.44625 .69109 Mdot
.67431 .2566 Mdot
.5273 .37522 Mdot
.41692 .57849 Mdot
.44981 .27526 Mdot
.65091 .41755 Mdot
.44478 .35832 Mdot
.36839 .50345 Mdot
.62906 .62279 Mdot
.64122 .65846 Mdot
.61457 .41838 Mdot
.38044 .35463 Mdot
.59685 .58949 Mdot
.64061 .45018 Mdot
.65124 .45209 Mdot
.24623 .47949 Mdot
.65053 .4517 Mdot
.59208 .49165 Mdot
.66079 .43424 Mdot
.67358 .4765 Mdot
.38758 .55705 Mdot
.65184 .35629 Mdot
.66827 .47734 Mdot
.56165 .49378 Mdot
.34327 .51889 Mdot
.63279 .53523 Mdot
.37274 .5469 Mdot
.40708 .79318 Mdot
.38252 .54502 Mdot
.6385 .65889 Mdot
.40136 .64546 Mdot
.64498 .54424 Mdot
.42543 .36551 Mdot
.3428 .53356 Mdot
.62916 .64093 Mdot
.36938 .53427 Mdot
.40762 .63971 Mdot
.79821 .65165 Mdot
.40332 .32931 Mdot
.44918 .54053 Mdot
.58351 .56401 Mdot
.30362 .33911 Mdot
.42519 .67897 Mdot
.46617 .31872 Mdot
.52347 .36565 Mdot
.65706 .4301 Mdot
.64242 .66466 Mdot
.61007 .4435 Mdot
.38562 .55636 Mdot
.4477 .65093 Mdot
.49559 .71295 Mdot
.63754 .66242 Mdot
.84384 .49282 Mdot
.43115 .69479 Mdot
.57264 .42451 Mdot
.34101 .52305 Mdot
.82724 .62331 Mdot
.38194 .54685 Mdot
.8009 .51639 Mdot
.48962 .32616 Mdot
.69761 .27246 Mdot
.45397 .31973 Mdot
.32822 .27707 Mdot
.39251 .83396 Mdot
.30134 .74699 Mdot
.43267 .33031 Mdot
.41593 .71769 Mdot
.62847 .43591 Mdot
.66545 .47247 Mdot
.54348 .43899 Mdot
.42738 .28345 Mdot
.62736 .45876 Mdot
.22968 .47617 Mdot
.39763 .43371 Mdot
.59261 .75968 Mdot
.43714 .71292 Mdot
.58826 .43454 Mdot
.34596 .52794 Mdot
.4037 .53205 Mdot
.22512 .47052 Mdot
.3726 .49039 Mdot
.6435 .45522 Mdot
.44722 .31818 Mdot
.54717 .59474 Mdot
.64623 .63729 Mdot
.1692 .52561 Mdot
.66718 .63419 Mdot
.43836 .71648 Mdot
.5523 .43885 Mdot
.42544 .66608 Mdot
.75831 .26924 Mdot
.66639 .45632 Mdot
.43932 .33709 Mdot
.62451 .41839 Mdot
.65724 .42713 Mdot
.66074 .48351 Mdot
.43703 .6199 Mdot
.46729 .58371 Mdot
.61907 .43372 Mdot
.3808 .50543 Mdot
.49292 .73126 Mdot
.60345 .40209 Mdot
.40588 .73233 Mdot
.75876 .60278 Mdot
.30818 .3548 Mdot
.44214 .27975 Mdot
.43227 .63788 Mdot
.45459 .32862 Mdot
.42024 .28418 Mdot
.46232 .33473 Mdot
.48092 .77987 Mdot
.65338 .54976 Mdot
.49465 .1518 Mdot
.69192 .31829 Mdot
.5637 .21272 Mdot
.41977 .30446 Mdot
.3255 .61857 Mdot
.4296 .34245 Mdot
.45887 .34168 Mdot
.32261 .17921 Mdot
.42412 .33285 Mdot
.5868 .46378 Mdot
.56948 .43741 Mdot
.27614 .42119 Mdot
.7777 .61788 Mdot
.64623 .49128 Mdot
.62483 .45951 Mdot
.61729 .63414 Mdot
.6711 .38664 Mdot
.22023 .46866 Mdot
.36619 .39066 Mdot
.20819 .47565 Mdot
.60402 .43828 Mdot
.62361 .4529 Mdot
.65615 .50882 Mdot
.39796 .84118 Mdot
.54649 .19615 Mdot
.44126 .29475 Mdot
.68781 .50918 Mdot
.20253 .63019 Mdot
.57201 .44481 Mdot
.58284 .42928 Mdot
.64331 .4263 Mdot
.42785 .65416 Mdot
.46167 .37708 Mdot
.70061 .45264 Mdot
.28972 .3771 Mdot
.63261 .44029 Mdot
.3206 .49629 Mdot
.67191 .67598 Mdot
.58847 .45575 Mdot
.47138 .355 Mdot
.65642 .47719 Mdot
.42798 .35244 Mdot
.46403 .35751 Mdot
.6317 .51683 Mdot
.48792 .79207 Mdot
.4739 .36098 Mdot
.6369 .42882 Mdot
.42263 .65058 Mdot
.25797 .71954 Mdot
.59414 .45967 Mdot
.61846 .63693 Mdot
.62728 .48577 Mdot
.65155 .66964 Mdot
.64642 .43987 Mdot
.23077 .46002 Mdot
.53666 .25311 Mdot
.43974 .64733 Mdot
.66383 .62204 Mdot
.45975 .63236 Mdot
.49486 .40458 Mdot
.47278 .31016 Mdot
.21913 .46732 Mdot
.49608 .17889 Mdot
.24479 .47945 Mdot
.7676 .46795 Mdot
.26817 .60212 Mdot
.35071 .52962 Mdot
.44536 .36828 Mdot
.74734 .47668 Mdot
.39906 .72859 Mdot
.47044 .67416 Mdot
.46127 .69292 Mdot
.79965 .33359 Mdot
.62013 .17564 Mdot
.61439 .43082 Mdot
.71276 .72706 Mdot
.56715 .30208 Mdot
.67468 .44128 Mdot
.6683 .42123 Mdot
.44373 .694 Mdot
.64603 .41239 Mdot
.48376 .51136 Mdot
.43782 .67032 Mdot
.63394 .64437 Mdot
.45566 .35171 Mdot
.65783 .65808 Mdot
.36569 .73602 Mdot
.37173 .44367 Mdot
.44046 .68116 Mdot
.67611 .4666 Mdot
.61109 .4248 Mdot
.43103 .35938 Mdot
.50688 .3329 Mdot
.47093 .34826 Mdot
.61321 .65595 Mdot
.43935 .65997 Mdot
.52753 .19912 Mdot
.61964 .48552 Mdot
.4365 .31613 Mdot
.38217 .58598 Mdot
.62685 .47947 Mdot
.35503 .51721 Mdot
.6368 .47654 Mdot
.42834 .32592 Mdot
.65024 .45073 Mdot
.44922 .31943 Mdot
.41592 .65702 Mdot
.57419 .45798 Mdot
.6214 .45411 Mdot
.78109 .43467 Mdot
.6443 .64465 Mdot
.46962 .30745 Mdot
.48406 .50034 Mdot
.57228 .46106 Mdot
.69974 .54644 Mdot
.63179 .4072 Mdot
.54171 .48876 Mdot
.68991 .45995 Mdot
.23134 .47695 Mdot
.63861 .507 Mdot
.59403 .45816 Mdot
.60223 .353 Mdot
.68487 .33826 Mdot
.40515 .37229 Mdot
.34657 .54362 Mdot
.47148 .35433 Mdot
.45491 .67957 Mdot
.46386 .66963 Mdot
.42297 .62444 Mdot
.79288 .5891 Mdot
.64408 .51953 Mdot
.59915 .4552 Mdot
.33932 .52243 Mdot
.6379 .65186 Mdot
.43434 .31063 Mdot
.63336 .65477 Mdot
.36706 .38721 Mdot
.61828 .66392 Mdot
.23207 .4805 Mdot
.59466 .72646 Mdot
.46329 .23004 Mdot
.61571 .6446 Mdot
.4709 .34903 Mdot
.53627 .63226 Mdot
.62459 .49845 Mdot
.238 .64517 Mdot
.63635 .63058 Mdot
.82095 .3814 Mdot
.61399 .41095 Mdot
.47905 .52413 Mdot
.3648 .54256 Mdot
.65262 .66412 Mdot
.39116 .50823 Mdot
.66123 .47365 Mdot
.26412 .34033 Mdot
.43809 .34246 Mdot
.33464 .53043 Mdot
.64759 .5017 Mdot
.65673 .65979 Mdot
.4457 .68191 Mdot
.51587 .50669 Mdot
.35894 .50587 Mdot
.78669 .45893 Mdot
.71756 .5386 Mdot
.43855 .66218 Mdot
.39215 .20979 Mdot
.39681 .52881 Mdot
.67848 .45647 Mdot
.58003 .53293 Mdot
.65018 .47731 Mdot
.45658 .68152 Mdot
.44524 .63322 Mdot
.29769 .45044 Mdot
.61998 .42006 Mdot
.61805 .40967 Mdot
.45405 .38245 Mdot
.43359 .6751 Mdot
.46475 .32425 Mdot
.43744 .36906 Mdot
.42313 .64435 Mdot
.46746 .33371 Mdot
.63052 .66958 Mdot
.40228 .43385 Mdot
.39634 .53229 Mdot
.36993 .5067 Mdot
.4488 .68264 Mdot
.40566 .64815 Mdot
.42607 .66867 Mdot
.6376 .47411 Mdot
.45284 .30413 Mdot
.65907 .44984 Mdot
.67127 .46079 Mdot
.49126 .32641 Mdot
.43037 .30502 Mdot
.66183 .45797 Mdot
.5454 .64007 Mdot
.63703 .61317 Mdot
.4498 .64376 Mdot
.38847 .53216 Mdot
.78321 .40842 Mdot
.33917 .51583 Mdot
.5941 .42316 Mdot
.25547 .66215 Mdot
.43209 .30894 Mdot
.64987 .65324 Mdot
.62779 .6854 Mdot
.64442 .66097 Mdot
.33455 .53201 Mdot
.44722 .3714 Mdot
.36368 .42083 Mdot
.59338 .42556 Mdot
.43791 .47576 Mdot
.75086 .4871 Mdot
.31312 .40659 Mdot
.38546 .52656 Mdot
.62754 .47051 Mdot
.24258 .47966 Mdot
.49656 .23199 Mdot
.60406 .45078 Mdot
.63014 .50563 Mdot
.5544 .69378 Mdot
.55944 .48953 Mdot
.43027 .28653 Mdot
.40488 .40042 Mdot
.58515 .48206 Mdot
.41944 .39238 Mdot
.44984 .12582 Mdot
.61588 .41144 Mdot
.62968 .45029 Mdot
.59865 .47465 Mdot
.66315 .44531 Mdot
.47805 .30241 Mdot
.56092 .65586 Mdot
.34446 .53136 Mdot
.41282 .44548 Mdot
.39403 .5214 Mdot
.45542 .65501 Mdot
.48571 .52514 Mdot
.45354 .36639 Mdot
.64627 .66014 Mdot
.77679 .68187 Mdot
.37385 .38076 Mdot
.41733 .67364 Mdot
.5797 .19722 Mdot
.64457 .63428 Mdot
.62019 .49715 Mdot
.64974 .6201 Mdot
.46716 .66512 Mdot
.38084 .51107 Mdot
.56918 .44713 Mdot
.41752 .32105 Mdot
.48049 .33185 Mdot
.62951 .46915 Mdot
.21922 .66892 Mdot
.38502 .50199 Mdot
.31157 .52938 Mdot
.62386 .4243 Mdot
.62867 .50549 Mdot
.46484 .35122 Mdot
.44265 .63563 Mdot
.25736 .56918 Mdot
.6371 .63983 Mdot
.66963 .48847 Mdot
.65889 .47686 Mdot
.37631 .3989 Mdot
.37258 .5566 Mdot
.25178 .46538 Mdot
.62287 .42243 Mdot
.38766 .41974 Mdot
.62571 .42138 Mdot
.64924 .38652 Mdot
.42208 .66075 Mdot
.56354 .44503 Mdot
.58884 .48024 Mdot
.73766 .44517 Mdot
.39803 .52648 Mdot
.44507 .33732 Mdot
.48359 .36013 Mdot
.25895 .46688 Mdot
.35497 .5237 Mdot
.66048 .46571 Mdot
.39154 .55299 Mdot
.66261 .48013 Mdot
.6192 .43697 Mdot
.38558 .52554 Mdot
.46539 .3252 Mdot
.33058 .70067 Mdot
.62778 .35714 Mdot
.64946 .4268 Mdot
.63626 .48621 Mdot
.78403 .6021 Mdot
.44124 .19919 Mdot
.59843 .48566 Mdot
.44094 .30236 Mdot
.62514 .47766 Mdot
.36175 .50898 Mdot
.61473 .65997 Mdot
.4378 .33271 Mdot
.40628 .66728 Mdot
.41557 .65195 Mdot
.39665 .61374 Mdot
.23695 .4838 Mdot
.61936 .49363 Mdot
.40175 .3335 Mdot
.42535 .30911 Mdot
.19775 .47512 Mdot
.45305 .6699 Mdot
.63592 .67573 Mdot
.63623 .41743 Mdot
.52103 .51437 Mdot
.35023 .54045 Mdot
.09238 .53296 Mdot
.36138 .42786 Mdot
.66653 .65266 Mdot
.36576 .30797 Mdot
.23776 .4763 Mdot
.57956 .45245 Mdot
.64459 .62247 Mdot
.41324 .63808 Mdot
.66504 .4713 Mdot
.5898 .51182 Mdot
.38429 .699 Mdot
.43057 .70845 Mdot
.39437 .55064 Mdot
.40877 .64933 Mdot
.66448 .65057 Mdot
.23081 .47933 Mdot
.47524 .32667 Mdot
.59333 .45285 Mdot
.68799 .51446 Mdot
.4514 .66288 Mdot
.23656 .4571 Mdot
.62836 .42511 Mdot
.48026 .34043 Mdot
.43837 .62614 Mdot
.60079 .4363 Mdot
.52925 .21687 Mdot
.48299 .2946 Mdot
.4446 .65866 Mdot
.58694 .48969 Mdot
.51791 .39915 Mdot
.4135 .68442 Mdot
.44004 .6946 Mdot
.62705 .45833 Mdot
.63374 .66867 Mdot
.57598 .45034 Mdot
.37347 .54456 Mdot
.46751 .58389 Mdot
.35902 .51573 Mdot
.74142 .50707 Mdot
.57093 .48037 Mdot
.31414 .31413 Mdot
.4193 .34607 Mdot
.60267 .65807 Mdot
.61474 .34688 Mdot
.61764 .50237 Mdot
.38218 .78557 Mdot
.54199 .6143 Mdot
.19266 .51101 Mdot
.52034 .8373 Mdot
.62446 .63757 Mdot
.36568 .5345 Mdot
.62984 .45149 Mdot
.41371 .52555 Mdot
.61833 .64928 Mdot
.74709 .49887 Mdot
.58911 .4909 Mdot
.45734 .3115 Mdot
.63045 .43557 Mdot
.43656 .35944 Mdot
.62621 .48203 Mdot
.64709 .52267 Mdot
.62607 .60886 Mdot
.80112 .51162 Mdot
.62649 .49738 Mdot
.79081 .67075 Mdot
.50277 .50389 Mdot
.63417 .63249 Mdot
.65033 .43481 Mdot
.24179 .46621 Mdot
.37695 .49698 Mdot
.66827 .73008 Mdot
.42615 .66051 Mdot
.38093 .53479 Mdot
.46194 .35037 Mdot
.41309 .61373 Mdot
.25803 .46317 Mdot
.64406 .54815 Mdot
.65994 .65262 Mdot
.3543 .53289 Mdot
.5918 .45716 Mdot
.59349 .42269 Mdot
.59725 .7218 Mdot
.30306 .24509 Mdot
.4435 .37795 Mdot
.83183 .48338 Mdot
.42828 .29108 Mdot
.64283 .64923 Mdot
.42262 .66381 Mdot
.5846 .46778 Mdot
.61076 .45221 Mdot
.46084 .66749 Mdot
.44813 .30002 Mdot
.40238 .61777 Mdot
.6227 .22334 Mdot
.46596 .62705 Mdot
.77162 .54562 Mdot
.4338 .33481 Mdot
.77578 .53968 Mdot
.66403 .65852 Mdot
.48456 .80222 Mdot
.70859 .63631 Mdot
.35515 .53887 Mdot
.76689 .55112 Mdot
.43029 .31395 Mdot
.61042 .42985 Mdot
.23234 .47116 Mdot
.25129 .48245 Mdot
.45228 .357 Mdot
.42657 .6391 Mdot
.65642 .65739 Mdot
.62764 .4459 Mdot
.33251 .3853 Mdot
.22793 .4135 Mdot
.42129 .61644 Mdot
.69888 .42054 Mdot
.38824 .50716 Mdot
.63298 .48262 Mdot
.6238 .62964 Mdot
.37677 .52905 Mdot
.2548 .49021 Mdot
.40455 .43294 Mdot
.63543 .4163 Mdot
.44119 .41601 Mdot
.35603 .52962 Mdot
.40748 .19715 Mdot
.61862 .45447 Mdot
.3969 .52848 Mdot
.54739 .48443 Mdot
.26252 .35492 Mdot
.56811 .5815 Mdot
.31827 .75981 Mdot
.44557 .70584 Mdot
.41635 .64648 Mdot
.22225 .34412 Mdot
.62241 .60064 Mdot
.34502 .52316 Mdot
.22833 .47672 Mdot
.71565 .59427 Mdot
.39476 .51245 Mdot
.58314 .42661 Mdot
.63008 .40745 Mdot
.62666 .23133 Mdot
.49764 .51625 Mdot
.24594 .45527 Mdot
.52796 .48155 Mdot
.64849 .46327 Mdot
.581 .40033 Mdot
.61723 .46477 Mdot
.44099 .29336 Mdot
.39442 .50764 Mdot
.79111 .69326 Mdot
.4005 .51866 Mdot
.33898 .38751 Mdot
.44703 .65493 Mdot
.42922 .6153 Mdot
.58843 .45367 Mdot
.34489 .27522 Mdot
.64803 .75103 Mdot
.63077 .48921 Mdot
.65327 .68751 Mdot
.72512 .53232 Mdot
.60104 .40116 Mdot
.47392 .37515 Mdot
.70278 .44452 Mdot
.46138 .29188 Mdot
.37946 .52586 Mdot
.62249 .63886 Mdot
.61857 .61727 Mdot
.36394 .53811 Mdot
.60132 .4577 Mdot
.64001 .69334 Mdot
.59626 .44475 Mdot
.61542 .42657 Mdot
.35971 .38834 Mdot
.6163 .66982 Mdot
.42634 .67188 Mdot
.64044 .65979 Mdot
.4581 .34038 Mdot
.24413 .23061 Mdot
.62667 .65407 Mdot
.51317 .40884 Mdot
.48976 .56231 Mdot
.76905 .5463 Mdot
.47977 .33332 Mdot
.61243 .64598 Mdot
.40029 .5401 Mdot
.1872 .50963 Mdot
.41703 .20683 Mdot
.34815 .49822 Mdot
.61422 .45059 Mdot
.44598 .36709 Mdot
.42701 .30217 Mdot
.36726 .48452 Mdot
.46991 .32032 Mdot
.55808 .42381 Mdot
.62897 .41917 Mdot
.34514 .52335 Mdot
.264 .42473 Mdot
.39482 .50733 Mdot
.5101 .48416 Mdot
.64145 .42781 Mdot
.43873 .33483 Mdot
.56886 .399 Mdot
.4375 .38263 Mdot
.25367 .48375 Mdot
.65821 .48694 Mdot
.65005 .65999 Mdot
.46694 .49629 Mdot
.44446 .65631 Mdot
.26049 .66675 Mdot
.44345 .36407 Mdot
.38536 .57964 Mdot
.47285 .3332 Mdot
.41397 .34067 Mdot
.37377 .48946 Mdot
.44888 .34396 Mdot
.62929 .44868 Mdot
.43874 .55566 Mdot
.42988 .35059 Mdot
.36671 .5192 Mdot
.65548 .65443 Mdot
.46699 .33009 Mdot
.41734 .60557 Mdot
.60612 .4277 Mdot
.42855 .68452 Mdot
.63998 .68321 Mdot
.45209 .36732 Mdot
.61279 .64882 Mdot
.45253 .66552 Mdot
.65878 .64331 Mdot
.48087 .71509 Mdot
.38752 .56365 Mdot
.34898 .35883 Mdot
.54946 .37273 Mdot
.41778 .32456 Mdot
.46981 .67911 Mdot
.58756 .47598 Mdot
.61309 .42115 Mdot
.6607 .63629 Mdot
.42504 .30479 Mdot
.25425 .71303 Mdot
.53847 .48821 Mdot
.2985 .46258 Mdot
.37904 .55955 Mdot
.81582 .44116 Mdot
.35531 .44239 Mdot
.19132 .53388 Mdot
.68059 .42751 Mdot
.23685 .47571 Mdot
.59282 .44261 Mdot
.79507 .45656 Mdot
.61606 .6634 Mdot
.31393 .64138 Mdot
.68545 .44955 Mdot
.43144 .66546 Mdot
.61799 .48177 Mdot
.70914 .72698 Mdot
.6866 .41694 Mdot
.6155 .63706 Mdot
.34447 .54827 Mdot
.42601 .36622 Mdot
.64512 .63602 Mdot
.4145 .65965 Mdot
.73976 .58864 Mdot
.57885 .48208 Mdot
.64471 .46117 Mdot
.46942 .67618 Mdot
.46177 .31363 Mdot
.45586 .65955 Mdot
.3963 .53118 Mdot
.62922 .65285 Mdot
.65906 .43639 Mdot
.56811 .41329 Mdot
.45092 .61291 Mdot
.40292 .53203 Mdot
.40764 .62882 Mdot
.37967 .55531 Mdot
.23563 .47538 Mdot
.62412 .49511 Mdot
.469 .65867 Mdot
.65859 .41696 Mdot
.70822 .36064 Mdot
.35976 .37391 Mdot
.63312 .33282 Mdot
.4268 .67413 Mdot
.76831 .58562 Mdot
.36153 .52838 Mdot
.37804 .55203 Mdot
.72162 .30911 Mdot
.6338 .75495 Mdot
.53309 .6393 Mdot
.79155 .65459 Mdot
.39606 .53242 Mdot
.35995 .51902 Mdot
.41549 .63491 Mdot
.45055 .34849 Mdot
.48122 .29858 Mdot
.44442 .61457 Mdot
.79068 .48353 Mdot
.43421 .31092 Mdot
.3652 .78061 Mdot
.42605 .69661 Mdot
.6889 .46183 Mdot
.23942 .45351 Mdot
.62681 .6309 Mdot
.78319 .474 Mdot
.76522 .68041 Mdot
.58247 .45694 Mdot
.57351 .17312 Mdot
.43351 .64109 Mdot
.43164 .54354 Mdot
.43402 .79091 Mdot
.61466 .5048 Mdot
.61091 .47846 Mdot
.60646 .4627 Mdot
.60623 .65434 Mdot
.64475 .34924 Mdot
.58177 .45419 Mdot
.79514 .53085 Mdot
.58152 .42316 Mdot
.69718 .71674 Mdot
.63969 .65977 Mdot
.64046 .55946 Mdot
.45205 .70562 Mdot
.30121 .38217 Mdot
.54258 .43548 Mdot
.39542 .54321 Mdot
.37991 .72359 Mdot
.38446 .51424 Mdot
.56358 .79757 Mdot
.70872 .6321 Mdot
.43586 .29333 Mdot
.63549 .4755 Mdot
.45873 .69387 Mdot
.43976 .36455 Mdot
.26478 .59202 Mdot
.31588 .17987 Mdot
.39803 .55272 Mdot
.64465 .1707 Mdot
.37652 .55238 Mdot
.25498 .4811 Mdot
.46006 .35493 Mdot
.39415 .28396 Mdot
.44129 .47877 Mdot
.46458 .32688 Mdot
.38448 .65233 Mdot
.4805 .3686 Mdot
.76698 .56915 Mdot
.41129 .34132 Mdot
.36709 .52382 Mdot
.36098 .56411 Mdot
.58585 .51734 Mdot
.59671 .48372 Mdot
.40312 .4415 Mdot
.53461 .45168 Mdot
.61795 .49016 Mdot
.4377 .67023 Mdot
.38081 .24481 Mdot
.4299 .58529 Mdot
.4332 .34828 Mdot
.35444 .54816 Mdot
.61245 .4797 Mdot
.64963 .42788 Mdot
.6714 .43978 Mdot
.79164 .44473 Mdot
.36637 .77865 Mdot
.61737 .43427 Mdot
.63429 .51525 Mdot
.41665 .66447 Mdot
.61605 .71704 Mdot
.82171 .57499 Mdot
.717 .60541 Mdot
.61066 .41799 Mdot
.64634 .64942 Mdot
.61112 .65899 Mdot
.5672 .42358 Mdot
.31855 .34763 Mdot
.40653 .70095 Mdot
.59192 .45758 Mdot
.70711 .66405 Mdot
.41815 .59767 Mdot
.2287 .4606 Mdot
.45132 .66408 Mdot
.46283 .36346 Mdot
.24871 .48064 Mdot
.44047 .62319 Mdot
.41306 .25523 Mdot
.25848 .46804 Mdot
.26571 .36521 Mdot
.61304 .65568 Mdot
.61473 .46006 Mdot
.4373 .38677 Mdot
.45999 .67127 Mdot
.35591 .5347 Mdot
.44522 .3237 Mdot
.39932 .55695 Mdot
.61876 .71936 Mdot
.76843 .49328 Mdot
.24151 .48564 Mdot
.39118 .54516 Mdot
.41829 .43119 Mdot
.64582 .65298 Mdot
.36776 .48826 Mdot
.3357 .28003 Mdot
.61347 .4013 Mdot
.60789 .79078 Mdot
.64068 .46363 Mdot
.18851 .616 Mdot
.37644 .55104 Mdot
.25641 .48627 Mdot
.59498 .45119 Mdot
.42893 .69457 Mdot
.60646 .52946 Mdot
.59857 .44349 Mdot
.40753 .65763 Mdot
.6134 .43109 Mdot
.6267 .62678 Mdot
.46158 .28764 Mdot
.54388 .61031 Mdot
.80164 .38862 Mdot
.65581 .6377 Mdot
.2776 .48516 Mdot
.61152 .49012 Mdot
.51264 .73036 Mdot
.46198 .32325 Mdot
.62558 .50633 Mdot
.6759 .24402 Mdot
.44569 .3542 Mdot
.45568 .32681 Mdot
.65394 .45199 Mdot
.345 .50429 Mdot
.445 .68736 Mdot
.64573 .65518 Mdot
.25131 .52136 Mdot
.59858 .43624 Mdot
.62519 .46771 Mdot
.64547 .63502 Mdot
.35918 .51768 Mdot
.65925 .43883 Mdot
.25696 .61404 Mdot
.21853 .49862 Mdot
.35134 .53803 Mdot
.61018 .40088 Mdot
.63027 .80187 Mdot
.4526 .27165 Mdot
.54233 .15803 Mdot
.63084 .59995 Mdot
.42608 .64431 Mdot
.68473 .49883 Mdot
.09038 .50197 Mdot
.62641 .63225 Mdot
.31493 .39987 Mdot
.62174 .43162 Mdot
.60558 .48365 Mdot
.47306 .31469 Mdot
.65966 .46014 Mdot
.42596 .32835 Mdot
.80304 .38282 Mdot
.85754 .59043 Mdot
.47156 .33332 Mdot
.42484 .33925 Mdot
.39417 .30509 Mdot
.78338 .45149 Mdot
.45851 .35068 Mdot
.58609 .4902 Mdot
.4499 .75295 Mdot
.59026 .50648 Mdot
.66108 .66753 Mdot
.60186 .66075 Mdot
.47487 .38302 Mdot
.35236 .23324 Mdot
.6372 .53888 Mdot
.62717 .36776 Mdot
.60236 .58731 Mdot
.38387 .54227 Mdot
.63965 .41381 Mdot
.23463 .48291 Mdot
.42405 .62133 Mdot
.68922 .41322 Mdot
.61126 .45777 Mdot
.42992 .35359 Mdot
.60548 .65454 Mdot
.38222 .49528 Mdot
.62432 .45826 Mdot
.40345 .679 Mdot
.63509 .64216 Mdot
.42858 .3477 Mdot
.50758 .41612 Mdot
.64934 .67541 Mdot
.56576 .41099 Mdot
.61564 .48885 Mdot
.62847 .42454 Mdot
.54216 .44211 Mdot
.36365 .53937 Mdot
.43462 .61209 Mdot
.55908 .45959 Mdot
.37006 .40076 Mdot
.46279 .52838 Mdot
.56161 .44641 Mdot
.45018 .30255 Mdot
.34273 .52917 Mdot
.25612 .46908 Mdot
.74427 .56281 Mdot
.62728 .41458 Mdot
.3735 .7798 Mdot
.57595 .20164 Mdot
.24984 .47522 Mdot
.41297 .30445 Mdot
.64773 .65731 Mdot
.64705 .45497 Mdot
.48106 .74826 Mdot
.60643 .41449 Mdot
.52615 .40801 Mdot
.42949 .64291 Mdot
.38819 .5384 Mdot
.20817 .49638 Mdot
.42353 .6211 Mdot
.45499 .32807 Mdot
.23613 .71275 Mdot
.48317 .35219 Mdot
.44191 .37436 Mdot
.50427 .7973 Mdot
.3817 .52527 Mdot
.09175 .51832 Mdot
.43602 .1979 Mdot
.60421 .41372 Mdot
.37192 .50296 Mdot
.45855 .35775 Mdot
.63744 .47086 Mdot
.42131 .31962 Mdot
.46202 .37293 Mdot
.66937 .45073 Mdot
.60427 .48529 Mdot
.79656 .50363 Mdot
.36696 .79508 Mdot
.63895 .66489 Mdot
.45922 .30171 Mdot
.59564 .22473 Mdot
.58094 .45535 Mdot
.5928 .42621 Mdot
.38423 .71027 Mdot
.61501 .6388 Mdot
.50574 .27819 Mdot
.6201 .42334 Mdot
.68986 .25514 Mdot
.62716 .49257 Mdot
.41742 .381 Mdot
.34167 .50714 Mdot
.31889 .35795 Mdot
.45452 .68412 Mdot
.48203 .34367 Mdot
.65172 .66853 Mdot
.48533 .32355 Mdot
.69973 .28029 Mdot
.38152 .52042 Mdot
.42831 .32585 Mdot
.40367 .63194 Mdot
.37477 .51271 Mdot
.35666 .54104 Mdot
.49137 .73118 Mdot
.41561 .61342 Mdot
.60901 .63745 Mdot
.38619 .51163 Mdot
.54975 .22056 Mdot
.37039 .52467 Mdot
.61339 .23063 Mdot
.57913 .47233 Mdot
.7919 .52439 Mdot
.34232 .44273 Mdot
.54808 .45686 Mdot
.39159 .5042 Mdot
.62452 .66028 Mdot
.65452 .47357 Mdot
.46849 .3171 Mdot
.62425 .6509 Mdot
.3669 .47767 Mdot
.40411 .64777 Mdot
.41228 .32865 Mdot
.34084 .52148 Mdot
.42614 .32291 Mdot
.76039 .49468 Mdot
.45865 .7196 Mdot
.61324 .58191 Mdot
.45066 .49342 Mdot
.67839 .45216 Mdot
.42293 .394 Mdot
.57235 .46451 Mdot
.60721 .45401 Mdot
.44514 .65881 Mdot
.79309 .58712 Mdot
.46716 .32759 Mdot
.18554 .46858 Mdot
.38674 .54829 Mdot
.40077 .39591 Mdot
.5194 .43454 Mdot
.65939 .48232 Mdot
.43378 .35308 Mdot
.45808 .37543 Mdot
.68407 .33781 Mdot
.46086 .66422 Mdot
.55993 .47822 Mdot
.55274 .44562 Mdot
.65122 .51897 Mdot
.3735 .55162 Mdot
.27412 .63664 Mdot
.44894 .63132 Mdot
.55612 .13453 Mdot
.44912 .64171 Mdot
.53687 .69896 Mdot
.44798 .34465 Mdot
.62787 .67169 Mdot
.59089 .4285 Mdot
.66225 .36242 Mdot
.47545 .30131 Mdot
.39847 .68477 Mdot
.65129 .65422 Mdot
.30571 .67237 Mdot
.38186 .53031 Mdot
.58523 .48406 Mdot
.66154 .43245 Mdot
.65623 .4436 Mdot
.63789 .44812 Mdot
.3513 .54755 Mdot
.58337 .42678 Mdot
.36493 .55836 Mdot
.50974 .21944 Mdot
.70132 .26817 Mdot
.45098 .69563 Mdot
.66906 .72133 Mdot
.41625 .32096 Mdot
.5905 .23605 Mdot
.49258 .26377 Mdot
.35789 .37381 Mdot
.48929 .71625 Mdot
.59038 .48435 Mdot
.42614 .63746 Mdot
.70962 .72929 Mdot
.45982 .69142 Mdot
.88314 .5678 Mdot
.70489 .52783 Mdot
.30745 .75922 Mdot
.63752 .46669 Mdot
.44094 .61137 Mdot
.50214 .296 Mdot
.57388 .41335 Mdot
.61666 .68437 Mdot
.51218 .4539 Mdot
.2813 .41483 Mdot
.63816 .67642 Mdot
.60393 .42947 Mdot
.42293 .36423 Mdot
.62962 .44727 Mdot
.59185 .4305 Mdot
.62876 .48833 Mdot
.39417 .49763 Mdot
.62886 .40243 Mdot
.57651 .44818 Mdot
.31604 .23287 Mdot
.77061 .60918 Mdot
.41912 .68059 Mdot
.66038 .32672 Mdot
.6376 .65156 Mdot
.43312 .35885 Mdot
.53019 .60154 Mdot
.37502 .54221 Mdot
.69279 .34165 Mdot
.63896 .46573 Mdot
.31927 .44641 Mdot
.34003 .51634 Mdot
.62176 .64473 Mdot
.25614 .46371 Mdot
.37456 .76104 Mdot
.45632 .68752 Mdot
.26158 .47413 Mdot
.44395 .65457 Mdot
.54759 .3447 Mdot
.43153 .35436 Mdot
.67352 .44589 Mdot
.39038 .51072 Mdot
.43794 .69288 Mdot
.78065 .62065 Mdot
.6154 .46941 Mdot
.42805 .67647 Mdot
.67791 .45335 Mdot
.45719 .54138 Mdot
.4922 .57053 Mdot
.46536 .64648 Mdot
.35565 .56077 Mdot
.37164 .50997 Mdot
.62861 .66968 Mdot
.42956 .35637 Mdot
.43793 .3044 Mdot
.37702 .52491 Mdot
.58185 .15942 Mdot
.5959 .43784 Mdot
.62312 .49035 Mdot
.36894 .40795 Mdot
.63372 .46226 Mdot
.75212 .59532 Mdot
.22272 .47445 Mdot
.41653 .33678 Mdot
.63582 .45277 Mdot
.65818 .43668 Mdot
.63727 .41731 Mdot
.76339 .49955 Mdot
.45111 .65668 Mdot
.64851 .46215 Mdot
.65475 .6286 Mdot
.29933 .31493 Mdot
.58256 .47002 Mdot
.57479 .40743 Mdot
.42849 .32188 Mdot
.82506 .44822 Mdot
.36312 .54266 Mdot
.43484 .679 Mdot
.42306 .69383 Mdot
.67286 .5684 Mdot
.45005 .27867 Mdot
.2214 .46397 Mdot
.35077 .59764 Mdot
.2293 .46472 Mdot
.63784 .63409 Mdot
.53406 .66515 Mdot
.40704 .68835 Mdot
.41347 .66772 Mdot
.38406 .56311 Mdot
.63606 .44742 Mdot
.62553 .49204 Mdot
.317 .39826 Mdot
.64467 .49031 Mdot
.65363 .65442 Mdot
.34554 .51385 Mdot
.43028 .32126 Mdot
.63205 .62776 Mdot
.38975 .55017 Mdot
.4613 .31222 Mdot
.59405 .4051 Mdot
.63364 .39946 Mdot
.44989 .32321 Mdot
.46043 .36122 Mdot
.58949 .46504 Mdot
.27512 .27856 Mdot
.4176 .35154 Mdot
.43056 .33067 Mdot
.26704 .46671 Mdot
.45673 .68786 Mdot
.60766 .3868 Mdot
.37512 .50211 Mdot
.62655 .42459 Mdot
.45453 .69407 Mdot
.61478 .64568 Mdot
.45127 .31479 Mdot
.64363 .42294 Mdot
.6103 .43616 Mdot
.64716 .64987 Mdot
.62804 .67774 Mdot
.65509 .64196 Mdot
.40714 .54059 Mdot
.63905 .4355 Mdot
.46175 .34738 Mdot
.38343 .52531 Mdot
.61151 .65957 Mdot
.63309 .61735 Mdot
.34252 .22075 Mdot
.58318 .45441 Mdot
.57661 .58647 Mdot
.18912 .29324 Mdot
.73436 .59511 Mdot
.25866 .47521 Mdot
.45873 .62528 Mdot
.78651 .54006 Mdot
.65273 .60774 Mdot
.36881 .50219 Mdot
.68689 .6454 Mdot
.60517 .66242 Mdot
.6707 .45933 Mdot
.63929 .48298 Mdot
.67576 .48562 Mdot
.63224 .64612 Mdot
.75719 .50158 Mdot
.43104 .30039 Mdot
.56374 .27801 Mdot
.63742 .6515 Mdot
.46481 .64408 Mdot
.4677 .652 Mdot
.44917 .64081 Mdot
.59324 .48788 Mdot
.66294 .33813 Mdot
.56687 .2182 Mdot
.52362 .29674 Mdot
.3804 .53455 Mdot
.45871 .37707 Mdot
.4968 .71179 Mdot
.45628 .32568 Mdot
.42716 .62425 Mdot
.63018 .64241 Mdot
.46811 .30797 Mdot
.35214 .5222 Mdot
.36133 .51328 Mdot
.40524 .66287 Mdot
.4504 .67097 Mdot
.44261 .68188 Mdot
.46795 .36119 Mdot
.44885 .3442 Mdot
.65325 .42763 Mdot
.44368 .31593 Mdot
.51908 .1797 Mdot
.66733 .65737 Mdot
.46758 .68261 Mdot
.3576 .52806 Mdot
.44181 .36186 Mdot
.61563 .45791 Mdot
.56738 .6986 Mdot
.397 .61732 Mdot
.65038 .6297 Mdot
.46492 .59918 Mdot
.88183 .49263 Mdot
.65742 .42417 Mdot
.38286 .5564 Mdot
.31565 .33247 Mdot
.60867 .46826 Mdot
.4265 .65402 Mdot
.76922 .42741 Mdot
.23401 .45909 Mdot
.57716 .45222 Mdot
.63386 .50307 Mdot
.37524 .49025 Mdot
.51409 .58873 Mdot
.65542 .48686 Mdot
.47216 .4269 Mdot
.40424 .53237 Mdot
.44698 .62837 Mdot
.17425 .42016 Mdot
.47053 .64106 Mdot
.80606 .51071 Mdot
.25643 .47544 Mdot
.66189 .43412 Mdot
.4395 .66769 Mdot
.64447 .62395 Mdot
.44403 .67005 Mdot
.41441 .31176 Mdot
.43238 .6861 Mdot
.62506 .4737 Mdot
.46083 .3462 Mdot
.3546 .52588 Mdot
.41177 .40312 Mdot
.3194 .23974 Mdot
.42706 .69391 Mdot
.26263 .48938 Mdot
.5789 .45387 Mdot
.50355 .23799 Mdot
.61812 .53094 Mdot
.59187 .48193 Mdot
.3852 .51563 Mdot
.43408 .35225 Mdot
.37701 .55926 Mdot
.60705 .39723 Mdot
.72426 .32308 Mdot
.38163 .54854 Mdot
.26393 .39117 Mdot
.6424 .6335 Mdot
.78913 .48323 Mdot
.60542 .44795 Mdot
.39127 .51405 Mdot
.63903 .43436 Mdot
.45512 .29896 Mdot
.46065 .4728 Mdot
.31161 .30086 Mdot
.38848 .50874 Mdot
.20985 .66507 Mdot
.48411 .49739 Mdot
.65489 .39676 Mdot
.39531 .52252 Mdot
.62689 .34266 Mdot
.24677 .46544 Mdot
.6371 .63875 Mdot
.61655 .66848 Mdot
.66057 .65439 Mdot
.64321 .49075 Mdot
.70908 .46087 Mdot
.61849 .6227 Mdot
.40192 .55104 Mdot
.6295 .62183 Mdot
.77537 .46925 Mdot
.23546 .69071 Mdot
.65214 .63532 Mdot
.61071 .44599 Mdot
.57931 .40628 Mdot
.77149 .611 Mdot
.44631 .62517 Mdot
.38691 .78616 Mdot
.46281 .20679 Mdot
.58668 .47065 Mdot
.63061 .5485 Mdot
.41513 .31762 Mdot
.34175 .3031 Mdot
.54448 .50099 Mdot
.53818 .62933 Mdot
.4276 .33908 Mdot
.45169 .56224 Mdot
.41775 .34045 Mdot
.65744 .4212 Mdot
.62034 .4374 Mdot
.46947 .29457 Mdot
.24825 .6463 Mdot
.24165 .36016 Mdot
.16754 .54905 Mdot
.4382 .30329 Mdot
.39791 .52547 Mdot
.39638 .55237 Mdot
.38527 .5293 Mdot
.45501 .68054 Mdot
.46976 .3555 Mdot
.643 .44156 Mdot
.41734 .65132 Mdot
.60344 .42206 Mdot
.37846 .51067 Mdot
.20932 .49829 Mdot
.4291 .32261 Mdot
.59347 .45735 Mdot
.41464 .20907 Mdot
.44319 .64316 Mdot
.64496 .65148 Mdot
.44342 .54046 Mdot
.45089 .61433 Mdot
.39798 .51062 Mdot
.4487 .27453 Mdot
.33071 .54896 Mdot
.56345 .65419 Mdot
.65461 .5092 Mdot
.5732 .47444 Mdot
.27052 .50934 Mdot
.37039 .22283 Mdot
.63931 .48832 Mdot
.41423 .65961 Mdot
.46657 .666 Mdot
.6281 .41794 Mdot
.47639 .33095 Mdot
.6046 .64299 Mdot
.66242 .65023 Mdot
.65525 .49463 Mdot
.43551 .47425 Mdot
.79571 .51663 Mdot
.66253 .45467 Mdot
.56167 .39052 Mdot
.40602 .62591 Mdot
.25947 .46532 Mdot
.39157 .42231 Mdot
.64466 .67021 Mdot
.6212 .42955 Mdot
.22872 .38454 Mdot
.42645 .33211 Mdot
.43736 .68541 Mdot
.34725 .52414 Mdot
.61924 .68725 Mdot
.4178 .69115 Mdot
.62851 .41821 Mdot
.65885 .4381 Mdot
.37072 .48964 Mdot
.41935 .38193 Mdot
.62951 .64436 Mdot
.41763 .65359 Mdot
.62901 .67228 Mdot
.45529 .34032 Mdot
.43255 .3255 Mdot
.55226 .45433 Mdot
.54995 .47083 Mdot
.4233 .69318 Mdot
.65615 .4995 Mdot
.43694 .62291 Mdot
.60116 .72074 Mdot
.35057 .54169 Mdot
.62633 .5073 Mdot
.40494 .3103 Mdot
.37928 .5137 Mdot
.59691 .47723 Mdot
.28759 .49799 Mdot
.66654 .46268 Mdot
.44216 .61271 Mdot
.73029 .32056 Mdot
.61778 .65159 Mdot
.49864 .39624 Mdot
.72457 .43397 Mdot
.63299 .46332 Mdot
.44533 .62072 Mdot
.68051 .50791 Mdot
.37389 .54661 Mdot
.43881 .34783 Mdot
.7587 .27085 Mdot
.36922 .52029 Mdot
.62762 .44306 Mdot
.62712 .65217 Mdot
.43541 .37432 Mdot
.23913 .48244 Mdot
.3726 .42539 Mdot
.68748 .41362 Mdot
.67527 .41837 Mdot
.63427 .44587 Mdot
.79582 .65089 Mdot
.43851 .67593 Mdot
.45051 .36125 Mdot
.36565 .55071 Mdot
.37376 .53323 Mdot
.4422 .63508 Mdot
.29576 .43324 Mdot
.27702 .69358 Mdot
.13841 .36115 Mdot
.41283 .67721 Mdot
.63953 .61965 Mdot
.46973 .51272 Mdot
.42171 .62084 Mdot
.43453 .66899 Mdot
.40547 .67045 Mdot
.32981 .43448 Mdot
.45824 .30682 Mdot
.61022 .43487 Mdot
.44206 .27962 Mdot
.66807 .44807 Mdot
.80966 .57036 Mdot
.3782 .52607 Mdot
.44042 .34727 Mdot
.28597 .50452 Mdot
.53801 .4705 Mdot
.61214 .47535 Mdot
.44009 .74132 Mdot
.69922 .44574 Mdot
.75783 .55725 Mdot
.56914 .40345 Mdot
.44876 .66312 Mdot
.6518 .54645 Mdot
.68415 .49816 Mdot
.44728 .21095 Mdot
.35565 .51875 Mdot
.24811 .48643 Mdot
.59751 .40658 Mdot
.64054 .38472 Mdot
.43735 .37446 Mdot
.46843 .30808 Mdot
.61603 .62465 Mdot
.43941 .50317 Mdot
.35429 .52252 Mdot
.3179 .71839 Mdot
.60214 .48642 Mdot
.42052 .51078 Mdot
.72072 .30255 Mdot
.59598 .47462 Mdot
.47576 .74174 Mdot
.69077 .34046 Mdot
.65811 .48264 Mdot
.54416 .30817 Mdot
.36101 .5243 Mdot
.68592 .25189 Mdot
.678 .47748 Mdot
.4274 .65407 Mdot
.44804 .34865 Mdot
.41344 .3236 Mdot
.64502 .62777 Mdot
.48421 .18644 Mdot
.37939 .57054 Mdot
.44593 .34611 Mdot
.60976 .46437 Mdot
.35776 .53679 Mdot
.24632 .48462 Mdot
.68539 .4231 Mdot
.57879 .78009 Mdot
.43897 .31659 Mdot
.60141 .51086 Mdot
.24497 .44198 Mdot
.47298 .53831 Mdot
.37517 .80201 Mdot
.38744 .52973 Mdot
.65058 .66812 Mdot
.56813 .40315 Mdot
.34386 .59327 Mdot
.68487 .45772 Mdot
.79914 .55125 Mdot
.49305 .37985 Mdot
.61522 .66082 Mdot
.6032 .46479 Mdot
.65453 .48706 Mdot
.46099 .49646 Mdot
.63007 .67722 Mdot
.65896 .48457 Mdot
.55565 .46774 Mdot
.45955 .31195 Mdot
.22565 .4796 Mdot
.43386 .317 Mdot
.61512 .45138 Mdot
.63461 .5538 Mdot
.47228 .31758 Mdot
.36001 .7475 Mdot
.60013 .62942 Mdot
.37578 .54302 Mdot
.64203 .38165 Mdot
.58218 .47579 Mdot
.58901 .84005 Mdot
.25397 .48345 Mdot
.82514 .51573 Mdot
.44919 .61507 Mdot
.19214 .4523 Mdot
.43997 .60449 Mdot
.28557 .74606 Mdot
.41069 .41309 Mdot
.65511 .50537 Mdot
.69845 .65621 Mdot
.53396 .29978 Mdot
.39112 .56295 Mdot
.53325 .22777 Mdot
.59614 .48338 Mdot
.59144 .43667 Mdot
.41851 .63651 Mdot
.30044 .44569 Mdot
.31405 .34212 Mdot
.41499 .44956 Mdot
.62594 .64064 Mdot
.44847 .3391 Mdot
.62799 .47745 Mdot
.21987 .58163 Mdot
.42246 .68442 Mdot
.50871 .5027 Mdot
.59452 .4542 Mdot
.33484 .37562 Mdot
.29106 .40185 Mdot
.35567 .53594 Mdot
.45331 .62177 Mdot
.43421 .61249 Mdot
.6336 .40843 Mdot
.35321 .51392 Mdot
.66214 .43933 Mdot
.48432 .48651 Mdot
.63049 .51465 Mdot
.62024 .63628 Mdot
.58546 .43144 Mdot
.53351 .55103 Mdot
.28574 .76179 Mdot
.70233 .46505 Mdot
.42662 .35907 Mdot
.45564 .67679 Mdot
.44878 .64497 Mdot
.43674 .30454 Mdot
.44717 .64091 Mdot
.56783 .28545 Mdot
.67386 .26111 Mdot
.62999 .63263 Mdot
.47404 .24721 Mdot
.61945 .64362 Mdot
.24795 .48678 Mdot
.58456 .46 Mdot
.36908 .61629 Mdot
.41363 .6802 Mdot
.78378 .42591 Mdot
.37182 .52711 Mdot
.25383 .48292 Mdot
.59916 .41334 Mdot
.53537 .6694 Mdot
.42582 .62902 Mdot
.37332 .73436 Mdot
.63835 .41747 Mdot
.45882 .30365 Mdot
.65543 .48514 Mdot
.61497 .50968 Mdot
.26094 .47297 Mdot
.63493 .44499 Mdot
.3902 .54998 Mdot
.47225 .35313 Mdot
.28793 .74243 Mdot
.45899 .67453 Mdot
.58623 .43771 Mdot
.6091 .46479 Mdot
.46317 .30095 Mdot
.58261 .42336 Mdot
.37137 .50071 Mdot
.09568 .57244 Mdot
.6413 .63382 Mdot
.2559 .46134 Mdot
.36558 .73579 Mdot
.63935 .47925 Mdot
.66062 .46813 Mdot
.26398 .51121 Mdot
.28438 .30098 Mdot
.39219 .54709 Mdot
.56353 .46976 Mdot
.41772 .66687 Mdot
.62356 .64791 Mdot
.37477 .496 Mdot
.63324 .42365 Mdot
.58975 .43829 Mdot
.62176 .63409 Mdot
.45569 .74773 Mdot
.40079 .61804 Mdot
.38257 .53252 Mdot
.58624 .53736 Mdot
.57256 .70195 Mdot
.59668 .4407 Mdot
.19139 .59819 Mdot
.43239 .33175 Mdot
.39463 .52888 Mdot
.63478 .35122 Mdot
.67477 .4498 Mdot
.39752 .51073 Mdot
.35493 .52373 Mdot
.61561 .40963 Mdot
.44752 .27806 Mdot
.46515 .36645 Mdot
.43041 .33367 Mdot
.74039 .32714 Mdot
.74238 .67565 Mdot
.44272 .68284 Mdot
.35966 .52187 Mdot
.46593 .68104 Mdot
.60514 .636 Mdot
.46283 .52654 Mdot
.46686 .66149 Mdot
.41448 .32382 Mdot
.46943 .67317 Mdot
.66462 .44708 Mdot
.35427 .51725 Mdot
.41247 .6651 Mdot
.64333 .47365 Mdot
.55853 .38969 Mdot
.55611 .55739 Mdot
.60529 .64471 Mdot
.45207 .55207 Mdot
.62335 .44763 Mdot
.25713 .46896 Mdot
.58881 .46055 Mdot
.34498 .52351 Mdot
.52567 .55366 Mdot
.64543 .4669 Mdot
.41946 .69013 Mdot
.57104 .65584 Mdot
.45292 .63041 Mdot
.58388 .493 Mdot
.61566 .45053 Mdot
.59494 .44001 Mdot
.65396 .48905 Mdot
.27147 .40272 Mdot
.36602 .55818 Mdot
.63425 .37829 Mdot
.4253 .70338 Mdot
.45506 .32112 Mdot
.45147 .29597 Mdot
.5324 .63496 Mdot
.26425 .47312 Mdot
.36275 .50699 Mdot
.59673 .43836 Mdot
.37348 .73388 Mdot
.2112 .50257 Mdot
.18037 .5846 Mdot
.50778 .71456 Mdot
.41347 .66244 Mdot
.4311 .3621 Mdot
.40978 .63598 Mdot
.61344 .41368 Mdot
.57418 .40143 Mdot
.30119 .75176 Mdot
.37596 .48227 Mdot
.63086 .64352 Mdot
.60211 .42215 Mdot
.79858 .49098 Mdot
.41664 .66435 Mdot
.40697 .62285 Mdot
.65611 .42796 Mdot
.47592 .36005 Mdot
.35989 .81664 Mdot
.34629 .52302 Mdot
.50934 .23562 Mdot
.50412 .37753 Mdot
.51426 .46063 Mdot
.36493 .53788 Mdot
.58371 .57729 Mdot
.4556 .64082 Mdot
.47206 .20044 Mdot
.44997 .32064 Mdot
.635 .64448 Mdot
.5603 .43837 Mdot
.41375 .32623 Mdot
.45954 .62424 Mdot
.42076 .33912 Mdot
.66846 .43776 Mdot
.38954 .55862 Mdot
.44431 .63348 Mdot
.34633 .54785 Mdot
.47313 .29686 Mdot
.61842 .64651 Mdot
.77089 .46029 Mdot
.50971 .22998 Mdot
.691 .34084 Mdot
.64841 .46151 Mdot
.40338 .73165 Mdot
.64202 .43554 Mdot
.44791 .37459 Mdot
.60636 .44763 Mdot
.41571 .39187 Mdot
.42714 .61499 Mdot
.61118 .51396 Mdot
.57739 .44228 Mdot
.485 .21243 Mdot
.60518 .47633 Mdot
.60291 .41246 Mdot
.63915 .49998 Mdot
.49701 .38821 Mdot
.56944 .48686 Mdot
.46192 .30687 Mdot
.31819 .40911 Mdot
.43493 .66635 Mdot
.63206 .61567 Mdot
.66141 .66015 Mdot
.79784 .54434 Mdot
.79133 .48582 Mdot
.30133 .43503 Mdot
.43925 .30815 Mdot
.40033 .53542 Mdot
.66051 .43658 Mdot
.58614 .3511 Mdot
.63594 .58115 Mdot
.45336 .63818 Mdot
.43587 .69909 Mdot
.55815 .48756 Mdot
.78264 .68187 Mdot
.58294 .49965 Mdot
.36307 .42325 Mdot
.66713 .47684 Mdot
.62937 .5064 Mdot
.40371 .62916 Mdot
.77192 .48178 Mdot
.64835 .46221 Mdot
.43711 .37444 Mdot
.63975 .64479 Mdot
.61985 .54493 Mdot
.6402 .57561 Mdot
.53511 .5313 Mdot
.4118 .25144 Mdot
.63916 .44329 Mdot
.42114 .64929 Mdot
.41407 .33468 Mdot
.37503 .40484 Mdot
.38431 .5231 Mdot
.38863 .42981 Mdot
.52227 .21157 Mdot
.47962 .67818 Mdot
.635 .64245 Mdot
.47874 .73429 Mdot
.62537 .47334 Mdot
.45291 .68232 Mdot
.66486 .43543 Mdot
.20753 .50419 Mdot
.61363 .64934 Mdot
.48251 .30844 Mdot
.39833 .52651 Mdot
.44213 .29958 Mdot
.63767 .33207 Mdot
.63027 .57663 Mdot
.18934 .45499 Mdot
.45919 .68371 Mdot
.75015 .41965 Mdot
.45192 .35618 Mdot
.63819 .42212 Mdot
.15264 .34243 Mdot
.43439 .33322 Mdot
.44924 .30003 Mdot
.53926 .62907 Mdot
.74213 .50626 Mdot
.68935 .49331 Mdot
.41868 .33258 Mdot
.4615 .69603 Mdot
.63985 .66183 Mdot
.65317 .47124 Mdot
.6437 .49726 Mdot
.47127 .3123 Mdot
.42812 .6268 Mdot
.80318 .48657 Mdot
.44987 .66737 Mdot
.4653 .31817 Mdot
.43972 .64682 Mdot
.34744 .72446 Mdot
.42298 .67913 Mdot
.57445 .44979 Mdot
.59804 .4382 Mdot
.5733 .76693 Mdot
.43265 .32541 Mdot
.65721 .47198 Mdot
.61712 .43146 Mdot
.45859 .3517 Mdot
.41663 .70177 Mdot
.70367 .3677 Mdot
.63598 .47306 Mdot
.60441 .43488 Mdot
.62176 .66927 Mdot
.46279 .57206 Mdot
.20745 .57244 Mdot
.65474 .47158 Mdot
.65984 .63853 Mdot
.46385 .36422 Mdot
.59022 .46368 Mdot
.77859 .47513 Mdot
.41515 .59563 Mdot
.59543 .42018 Mdot
.23669 .48195 Mdot
.63224 .48857 Mdot
.35413 .8142 Mdot
.58309 .44256 Mdot
.46182 .35533 Mdot
.44624 .35284 Mdot
.39958 .61707 Mdot
.45316 .32944 Mdot
.25439 .47923 Mdot
.37612 .51078 Mdot
.17935 .60021 Mdot
.25075 .48116 Mdot
.61297 .50302 Mdot
.4364 .19771 Mdot
.66532 .48767 Mdot
.58149 .41202 Mdot
.78134 .44785 Mdot
.25224 .47804 Mdot
.43855 .35673 Mdot
.24825 .64243 Mdot
.62737 .50925 Mdot
.34693 .52137 Mdot
.57127 .41316 Mdot
.59092 .42262 Mdot
.49779 .44951 Mdot
.73479 .33987 Mdot
.3431 .51851 Mdot
.62199 .38786 Mdot
.65496 .47001 Mdot
.33436 .25903 Mdot
.61593 .46628 Mdot
.64983 .63224 Mdot
.42727 .31326 Mdot
.40867 .63372 Mdot
.64705 .64126 Mdot
.63273 .47789 Mdot
.6346 .6482 Mdot
.44036 .6828 Mdot
.38864 .51698 Mdot
.59015 .42748 Mdot
.65789 .67075 Mdot
.62689 .64313 Mdot
.6496 .43769 Mdot
.44433 .34782 Mdot
.64578 .53127 Mdot
.59144 .46662 Mdot
.63139 .41971 Mdot
.43779 .30449 Mdot
.45384 .15356 Mdot
.64509 .41161 Mdot
.57512 .58189 Mdot
.44772 .2907 Mdot
.23305 .4566 Mdot
.4098 .64282 Mdot
.66734 .42823 Mdot
.37822 .53089 Mdot
.37842 .51895 Mdot
.44137 .71404 Mdot
.47859 .31483 Mdot
.43795 .62593 Mdot
.6776 .41164 Mdot
.55434 .47802 Mdot
.55631 .44948 Mdot
.76204 .27544 Mdot
.3774 .76355 Mdot
.47353 .34689 Mdot
.45338 .63465 Mdot
.41039 .44786 Mdot
.36358 .50766 Mdot
.44803 .71652 Mdot
.40523 .31231 Mdot
.44968 .36599 Mdot
.41608 .32287 Mdot
.6413 .66893 Mdot
.4543 .66631 Mdot
.4485 .38583 Mdot
.4818 .34705 Mdot
.64868 .42431 Mdot
.65545 .4688 Mdot
.48908 .36999 Mdot
.76436 .61388 Mdot
.61761 .64093 Mdot
.42495 .64885 Mdot
.54438 .86374 Mdot
.34546 .52513 Mdot
.48256 .21217 Mdot
.64201 .47386 Mdot
.33857 .15503 Mdot
.56118 .4718 Mdot
.61176 .46512 Mdot
.46381 .36291 Mdot
.66271 .63448 Mdot
.63385 .65953 Mdot
.45127 .35572 Mdot
.48064 .29909 Mdot
.65764 .65663 Mdot
.50421 .72205 Mdot
.19072 .64297 Mdot
.38172 .41553 Mdot
.46388 .35141 Mdot
.49233 .23244 Mdot
.38034 .49921 Mdot
.45224 .28785 Mdot
.34287 .52258 Mdot
.43351 .66861 Mdot
.43544 .6967 Mdot
.36679 .48908 Mdot
.63111 .41517 Mdot
.43243 .6844 Mdot
.69459 .42156 Mdot
.33402 .75485 Mdot
.55176 .80696 Mdot
.26225 .31272 Mdot
.62239 .49355 Mdot
.31821 .35113 Mdot
.29244 .35537 Mdot
.62916 .45717 Mdot
.5293 .4404 Mdot
.63247 .64481 Mdot
.45682 .29094 Mdot
.35988 .50576 Mdot
.39575 .80046 Mdot
.59668 .43994 Mdot
.46715 .32688 Mdot
.35764 .51309 Mdot
.33923 .70973 Mdot
.47683 .42993 Mdot
.65903 .43027 Mdot
.09322 .44254 Mdot
.47727 .30141 Mdot
.40876 .63286 Mdot
.42227 .21943 Mdot
.4387 .28186 Mdot
.57434 .69011 Mdot
.42009 .60958 Mdot
.17588 .53916 Mdot
.43608 .36084 Mdot
.40035 .67591 Mdot
.45576 .33749 Mdot
.62828 .62689 Mdot
.44671 .27507 Mdot
.43808 .63435 Mdot
.60297 .46909 Mdot
.44121 .63675 Mdot
.61954 .63354 Mdot
.45075 .68831 Mdot
.36214 .50377 Mdot
.25718 .47343 Mdot
.36527 .51058 Mdot
.46159 .53365 Mdot
.71256 .32881 Mdot
.38799 .53822 Mdot
.38729 .74285 Mdot
.6396 .48725 Mdot
.41492 .37882 Mdot
.40737 .63842 Mdot
.44982 .70148 Mdot
.45505 .51382 Mdot
.46436 .32926 Mdot
.43542 .63742 Mdot
.52558 .21536 Mdot
.54391 .14213 Mdot
.69525 .41649 Mdot
.70851 .69984 Mdot
.46039 .35135 Mdot
.41985 .6149 Mdot
.36821 .41061 Mdot
.42491 .30266 Mdot
.41613 .68169 Mdot
.39523 .51888 Mdot
.37185 .53578 Mdot
.63138 .41224 Mdot
.35262 .48743 Mdot
.44224 .61841 Mdot
.24035 .36703 Mdot
.42623 .31304 Mdot
.34612 .70795 Mdot
.65577 .63859 Mdot
.43429 .67443 Mdot
.66897 .51039 Mdot
.4951 .32358 Mdot
.43982 .70153 Mdot
.61716 .7667 Mdot
.58607 .85389 Mdot
.43514 .63854 Mdot
.42683 .3139 Mdot
.45336 .31476 Mdot
.69691 .47832 Mdot
.44444 .48378 Mdot
.43007 .6303 Mdot
.37418 .63388 Mdot
.80061 .55795 Mdot
.23577 .47583 Mdot
.38508 .2077 Mdot
.64744 .46249 Mdot
.63729 .43279 Mdot
.37913 .50245 Mdot
.61786 .4787 Mdot
.46759 .36785 Mdot
.57261 .42462 Mdot
.40075 .54944 Mdot
.45089 .63484 Mdot
.58622 .44858 Mdot
.62658 .66225 Mdot
.37024 .49941 Mdot
.38583 .49153 Mdot
.43916 .65629 Mdot
.4171 .32749 Mdot
.23708 .64341 Mdot
.45052 .66814 Mdot
.64016 .44488 Mdot
.24599 .47193 Mdot
.67219 .44086 Mdot
.53723 .78054 Mdot
.43131 .30122 Mdot
.40995 .6331 Mdot
.41265 .30403 Mdot
.36416 .51729 Mdot
.44414 .70996 Mdot
.61927 .46449 Mdot
.41987 .68687 Mdot
.66356 .6114 Mdot
.50979 .75263 Mdot
.48445 .34211 Mdot
.65881 .68334 Mdot
.46608 .30474 Mdot
.23579 .47669 Mdot
.70149 .5767 Mdot
.63232 .63636 Mdot
.42288 .67309 Mdot
.37328 .76761 Mdot
.4073 .67214 Mdot
.60425 .47741 Mdot
.60681 .48553 Mdot
.41681 .63623 Mdot
.62866 .66757 Mdot
.81071 .43032 Mdot
.5948 .59717 Mdot
.4308 .35259 Mdot
.37924 .35241 Mdot
.48091 .85926 Mdot
.33738 .55361 Mdot
.39867 .51745 Mdot
.56736 .39371 Mdot
.66268 .47432 Mdot
.38146 .49352 Mdot
.35336 .54706 Mdot
.61082 .65645 Mdot
.44915 .68487 Mdot
.40607 .34512 Mdot
.38004 .49703 Mdot
.73241 .454 Mdot
.7878 .47694 Mdot
.69867 .46637 Mdot
.61753 .51937 Mdot
.58503 .48194 Mdot
.47119 .54194 Mdot
.37366 .55716 Mdot
.6208 .44421 Mdot
.5509 .44596 Mdot
.39492 .53694 Mdot
.62344 .63065 Mdot
.40649 .28602 Mdot
.43325 .64824 Mdot
.45432 .12239 Mdot
.58835 .42887 Mdot
.59853 .4687 Mdot
.38015 .53477 Mdot
.3564 .2289 Mdot
.47202 .345 Mdot
.41965 .32255 Mdot
.43874 .67719 Mdot
.4516 .51413 Mdot
.57366 .43266 Mdot
.62715 .45405 Mdot
.42467 .66911 Mdot
.2562 .47102 Mdot
.22838 .34081 Mdot
.61069 .43768 Mdot
.35991 .52983 Mdot
.37794 .72185 Mdot
.37023 .55641 Mdot
.66029 .42832 Mdot
.60454 .47941 Mdot
.57422 .44541 Mdot
.65524 .48972 Mdot
.37354 .49179 Mdot
.62593 .45744 Mdot
.58348 .51923 Mdot
.43083 .34593 Mdot
.63994 .46186 Mdot
.79381 .53949 Mdot
.60453 .43931 Mdot
.62524 .66014 Mdot
.21125 .59217 Mdot
.5955 .43186 Mdot
.63942 .45825 Mdot
.59154 .59317 Mdot
.60267 .461 Mdot
.35112 .53369 Mdot
.45107 .31783 Mdot
.35942 .52034 Mdot
.37343 .5513 Mdot
.46004 .69304 Mdot
.60858 .65218 Mdot
.68582 .4608 Mdot
.65983 .64544 Mdot
.65686 .51256 Mdot
.66954 .44084 Mdot
.4563 .56105 Mdot
.36252 .42514 Mdot
.66059 .61601 Mdot
.61821 .45921 Mdot
.43806 .67109 Mdot
.40784 .64844 Mdot
.69243 .66753 Mdot
.70195 .44198 Mdot
.37149 .49463 Mdot
.3913 .5138 Mdot
.74761 .59856 Mdot
.49167 .43282 Mdot
.62122 .6525 Mdot
.41214 .43986 Mdot
.61644 .49481 Mdot
.61154 .42827 Mdot
.57445 .40881 Mdot
.4675 .66793 Mdot
.25913 .46861 Mdot
.45488 .64276 Mdot
.27431 .47782 Mdot
.36763 .55688 Mdot
.62 .49301 Mdot
.50913 .81076 Mdot
.47862 .32625 Mdot
.44981 .31757 Mdot
.40472 .54098 Mdot
.45129 .62825 Mdot
.69452 .48048 Mdot
.77556 .28292 Mdot
.47178 .38157 Mdot
.65158 .62101 Mdot
.62744 .44983 Mdot
.43888 .66069 Mdot
.48132 .33776 Mdot
.6318 .68086 Mdot
.61091 .49085 Mdot
.41668 .6983 Mdot
.60451 .44454 Mdot
.5348 .31295 Mdot
.43543 .35023 Mdot
.20343 .49752 Mdot
.48416 .34882 Mdot
.39157 .50378 Mdot
.38272 .55093 Mdot
.5983 .47775 Mdot
.6598 .19158 Mdot
.48901 .32158 Mdot
.33453 .53157 Mdot
.61923 .62813 Mdot
.25399 .46078 Mdot
.60958 .63904 Mdot
.42769 .61977 Mdot
.63781 .64267 Mdot
.42276 .69361 Mdot
.74968 .61724 Mdot
.45968 .38616 Mdot
.64326 .63626 Mdot
.33337 .23619 Mdot
.64063 .4032 Mdot
.61532 .66535 Mdot
.56413 .4973 Mdot
.43579 .39912 Mdot
.42607 .66643 Mdot
.6298 .66701 Mdot
.64449 .4249 Mdot
.42965 .80001 Mdot
.3779 .55209 Mdot
.36856 .49496 Mdot
.68551 .45696 Mdot
.40365 .64083 Mdot
.47734 .29459 Mdot
.52932 .59736 Mdot
.22849 .45849 Mdot
.62623 .45426 Mdot
.61506 .49301 Mdot
.47154 .30414 Mdot
.4468 .37719 Mdot
.60414 .48082 Mdot
.5421 .22294 Mdot
.62655 .47337 Mdot
.37034 .53823 Mdot
.45918 .36236 Mdot
.45037 .31476 Mdot
.4503 .62084 Mdot
.47867 .31593 Mdot
.60754 .51547 Mdot
.41519 .52789 Mdot
.55645 .43045 Mdot
.3682 .51746 Mdot
.53549 .55833 Mdot
.45589 .68113 Mdot
.39332 .79268 Mdot
.48113 .31641 Mdot
.6367 .44892 Mdot
.46123 .30152 Mdot
.65534 .64366 Mdot
.43387 .32364 Mdot
.41113 .33342 Mdot
.5998 .48436 Mdot
.6612 .43304 Mdot
.25224 .47292 Mdot
.44454 .48598 Mdot
.43582 .34323 Mdot
.62944 .4696 Mdot
.664 .49141 Mdot
.63168 .40526 Mdot
.48347 .50371 Mdot
.44819 .36786 Mdot
.63631 .23686 Mdot
.54687 .79034 Mdot
.44176 .34554 Mdot
.40861 .82388 Mdot
.22783 .47254 Mdot
.26495 .47121 Mdot
.34727 .55971 Mdot
.60883 .43473 Mdot
.43978 .62887 Mdot
.61049 .41462 Mdot
.68881 .41192 Mdot
.59042 .43411 Mdot
.61439 .6406 Mdot
.6736 .49588 Mdot
.23463 .4654 Mdot
.45036 .65943 Mdot
.63594 .47611 Mdot
.58675 .44466 Mdot
.2637 .47607 Mdot
.4862 .34475 Mdot
.44192 .36464 Mdot
.19674 .60562 Mdot
.63536 .62946 Mdot
.38505 .51761 Mdot
.61951 .41509 Mdot
.43833 .67359 Mdot
.44415 .63802 Mdot
.44496 .29941 Mdot
.4287 .65022 Mdot
.34544 .52213 Mdot
.61761 .47023 Mdot
.37991 .49278 Mdot
.61501 .63953 Mdot
.42779 .31275 Mdot
.61938 .4147 Mdot
.64702 .42302 Mdot
.44599 .353 Mdot
.63879 .48798 Mdot
.62276 .66993 Mdot
.4399 .69421 Mdot
.44565 .36387 Mdot
.37687 .51246 Mdot
.4554 .62466 Mdot
.66137 .4409 Mdot
.66413 .80005 Mdot
.62016 .47975 Mdot
.62033 .41953 Mdot
.22736 .69447 Mdot
.55611 .41077 Mdot
.42282 .6164 Mdot
.44945 .29486 Mdot
.62569 .40002 Mdot
.8054 .57871 Mdot
.28927 .53197 Mdot
.4457 .7168 Mdot
.6304 .44742 Mdot
.37611 .79119 Mdot
.6355 .45497 Mdot
.3303 .70592 Mdot
.45583 .5577 Mdot
.74742 .69431 Mdot
.60729 .5178 Mdot
.34259 .50786 Mdot
.25388 .47385 Mdot
.40608 .64234 Mdot
.58514 .33706 Mdot
.62701 .48476 Mdot
.64406 .34438 Mdot
.58348 .42678 Mdot
.36594 .53751 Mdot
.53675 .42187 Mdot
.426 .64875 Mdot
.45095 .20641 Mdot
.64197 .44089 Mdot
.45262 .36667 Mdot
.4662 .68854 Mdot
.24084 .45802 Mdot
.64282 .42264 Mdot
.65611 .63499 Mdot
.29801 .4972 Mdot
.5671 .49214 Mdot
.3704 .51606 Mdot
.61834 .42977 Mdot
.63747 .38868 Mdot
.59502 .16691 Mdot
.43097 .34837 Mdot
.39786 .51806 Mdot
.33871 .29277 Mdot
.6355 .492 Mdot
.4382 .36209 Mdot
.4521 .3211 Mdot
.64105 .6245 Mdot
.36471 .44544 Mdot
.31587 .54676 Mdot
.59518 .79849 Mdot
.6737 .33048 Mdot
.45452 .62048 Mdot
.26786 .33585 Mdot
.65351 .46447 Mdot
.62858 .57356 Mdot
.35495 .5377 Mdot
.60006 .46774 Mdot
.6929 .31932 Mdot
.42989 .33203 Mdot
.61182 .44203 Mdot
.61895 .63904 Mdot
.30053 .47748 Mdot
.54412 .53368 Mdot
.58367 .83303 Mdot
.45551 .7078 Mdot
.56533 .41856 Mdot
.60232 .5209 Mdot
.23673 .45594 Mdot
.67076 .45071 Mdot
.40698 .63611 Mdot
.41892 .75035 Mdot
.62296 .66446 Mdot
.48033 .32534 Mdot
.22723 .46967 Mdot
.5691 .45515 Mdot
.68137 .4546 Mdot
.63262 .6159 Mdot
.64025 .42676 Mdot
.43578 .21497 Mdot
.2092 .47229 Mdot
.42432 .6819 Mdot
.41994 .33928 Mdot
.58776 .48463 Mdot
.25834 .46789 Mdot
.60317 .48539 Mdot
.39922 .28388 Mdot
.63155 .43426 Mdot
.26956 .44442 Mdot
.44899 .34792 Mdot
.36891 .51307 Mdot
.68772 .46573 Mdot
.59461 .44691 Mdot
.57169 .70523 Mdot
.68655 .40953 Mdot
.58392 .442 Mdot
.43022 .37199 Mdot
.47555 .32552 Mdot
.45704 .3043 Mdot
.43008 .68619 Mdot
.38777 .41995 Mdot
.36738 .52906 Mdot
.57836 .4237 Mdot
.37878 .49704 Mdot
.7168 .4309 Mdot
.64084 .6168 Mdot
.45555 .82722 Mdot
.63441 .48195 Mdot
.44882 .30417 Mdot
.23495 .38693 Mdot
.46566 .36314 Mdot
.41876 .58661 Mdot
.3541 .52202 Mdot
.43528 .33506 Mdot
.60458 .45699 Mdot
.4233 .45762 Mdot
.62708 .81313 Mdot
.36833 .50598 Mdot
.57613 .40365 Mdot
.45553 .70522 Mdot
.42594 .69866 Mdot
.40449 .84266 Mdot
.38347 .55346 Mdot
.29001 .35173 Mdot
.63143 .46692 Mdot
.47693 .32228 Mdot
.38623 .53472 Mdot
.35222 .53775 Mdot
.42435 .66267 Mdot
.65268 .42172 Mdot
.5976 .4454 Mdot
.23467 .48072 Mdot
.38813 .51252 Mdot
.64913 .40378 Mdot
.66982 .46671 Mdot
.2876 .74535 Mdot
.401 .3364 Mdot
.42766 .15842 Mdot
.66743 .40497 Mdot
.70232 .33354 Mdot
.49077 .52555 Mdot
.4737 .34866 Mdot
.62119 .4127 Mdot
.56648 .43941 Mdot
.45062 .61792 Mdot
.61983 .47415 Mdot
.46254 .65065 Mdot
.40016 .52174 Mdot
.46892 .83567 Mdot
.3528 .70079 Mdot
.49265 .71387 Mdot
.61207 .47754 Mdot
.51292 .47601 Mdot
.65213 .64601 Mdot
.40689 .52738 Mdot
.47012 .32531 Mdot
.60072 .49302 Mdot
.42215 .60866 Mdot
.42118 .67202 Mdot
.44625 .32442 Mdot
.29282 .37608 Mdot
.35913 .74657 Mdot
.65652 .48968 Mdot
.41264 .63004 Mdot
.33451 .6849 Mdot
.56724 .23105 Mdot
.35032 .49147 Mdot
.6183 .65816 Mdot
.44945 .63415 Mdot
.38706 .49076 Mdot
.39189 .31456 Mdot
.44505 .33269 Mdot
.47335 .30162 Mdot
.55676 .7539 Mdot
.43347 .62978 Mdot
.64817 .65244 Mdot
.47549 .41757 Mdot
.42604 .41221 Mdot
.61424 .64598 Mdot
.4514 .63474 Mdot
.47934 .3326 Mdot
.4669 .32405 Mdot
.4526 .31812 Mdot
.44558 .21065 Mdot
.42671 .30625 Mdot
.58499 .19925 Mdot
.66963 .48217 Mdot
.50259 .2398 Mdot
.63409 .45249 Mdot
.35672 .49606 Mdot
.43674 .35126 Mdot
.46517 .51415 Mdot
.62204 .50183 Mdot
.59081 .82724 Mdot
.62449 .44811 Mdot
.40646 .49709 Mdot
.60676 .43425 Mdot
.45771 .23448 Mdot
.44852 .29068 Mdot
.61957 .46036 Mdot
.3381 .52825 Mdot
.62733 .64678 Mdot
.43878 .26407 Mdot
.5949 .43383 Mdot
.30699 .45955 Mdot
.55177 .44748 Mdot
.34772 .75565 Mdot
.56105 .65503 Mdot
.65636 .62441 Mdot
.55388 .46235 Mdot
.46673 .64075 Mdot
.47266 .27989 Mdot
.49454 .24772 Mdot
.36969 .50576 Mdot
.75915 .40082 Mdot
.42487 .67604 Mdot
.53629 .42363 Mdot
.6034 .50386 Mdot
.64036 .67066 Mdot
.46939 .27989 Mdot
.3716 .54097 Mdot
.63541 .48626 Mdot
.61151 .41088 Mdot
.62549 .7484 Mdot
.48685 .24346 Mdot
.65814 .41088 Mdot
.60782 .63306 Mdot
.64869 .24502 Mdot
.60469 .42667 Mdot
.4238 .70596 Mdot
.43384 .29421 Mdot
.64681 .51783 Mdot
.62174 .229 Mdot
.62991 .47234 Mdot
.43764 .33098 Mdot
.48028 .31388 Mdot
.25429 .42054 Mdot
.65044 .62159 Mdot
.63138 .43391 Mdot
.58695 .70638 Mdot
.63916 .43714 Mdot
.36724 .53316 Mdot
.64932 .41394 Mdot
.43057 .67207 Mdot
.36416 .41112 Mdot
.43588 .69029 Mdot
.63225 .40929 Mdot
.4619 .32301 Mdot
.37643 .54134 Mdot
.54581 .76725 Mdot
.5145 .59905 Mdot
.59641 .20397 Mdot
.28859 .50514 Mdot
.63958 .66741 Mdot
.61217 .66478 Mdot
.38509 .56432 Mdot
.6165 .45327 Mdot
.4821 .55695 Mdot
.59661 .50649 Mdot
.60424 .43243 Mdot
.59234 .42767 Mdot
.37582 .48049 Mdot
.35807 .51691 Mdot
.43972 .64208 Mdot
.60676 .48164 Mdot
.62868 .46855 Mdot
.44434 .34196 Mdot
.62577 .64348 Mdot
.42646 .68741 Mdot
.64324 .63223 Mdot
.44749 .66554 Mdot
.36388 .815 Mdot
.61355 .39714 Mdot
.62687 .64798 Mdot
.3839 .56014 Mdot
.44204 .30262 Mdot
.25531 .48389 Mdot
.43236 .62092 Mdot
.42736 .64566 Mdot
.62751 .45702 Mdot
.42796 .31702 Mdot
.42456 .32872 Mdot
.65418 .66146 Mdot
.39189 .52548 Mdot
.62634 .40999 Mdot
.66927 .45377 Mdot
.677 .722 Mdot
.46283 .63682 Mdot
.5607 .21951 Mdot
.27658 .41716 Mdot
.61627 .45421 Mdot
.42353 .34012 Mdot
.5864 .45296 Mdot
.43554 .78091 Mdot
.41421 .32529 Mdot
.64459 .50102 Mdot
.49924 .41787 Mdot
.46278 .68363 Mdot
.22022 .43736 Mdot
.6788 .48088 Mdot
.25984 .5132 Mdot
.65312 .44956 Mdot
.18833 .67201 Mdot
.2985 .29081 Mdot
.57108 .44179 Mdot
.6471 .49281 Mdot
.62865 .78679 Mdot
.63368 .46383 Mdot
.23099 .47007 Mdot
.68816 .42113 Mdot
.44598 .36609 Mdot
.49781 .55632 Mdot
.46147 .58201 Mdot
.63546 .61939 Mdot
.43852 .67791 Mdot
.70035 .54917 Mdot
.62726 .62827 Mdot
.45981 .3546 Mdot
.64266 .49841 Mdot
.73869 .41658 Mdot
.4075 .60582 Mdot
.6145 .51026 Mdot
.36645 .53446 Mdot
.45773 .57637 Mdot
.45987 .65709 Mdot
.37412 .50999 Mdot
.57895 .43337 Mdot
.81909 .52826 Mdot
.5186 .61345 Mdot
.16157 .53264 Mdot
.38231 .53269 Mdot
.35453 .53284 Mdot
.37007 .39078 Mdot
.63575 .61948 Mdot
.64253 .73735 Mdot
.54047 .51242 Mdot
.34944 .51865 Mdot
.74154 .56558 Mdot
.40843 .61703 Mdot
.36002 .44478 Mdot
.45417 .29001 Mdot
.60529 .39805 Mdot
.60149 .4544 Mdot
.39347 .53129 Mdot
.62342 .3575 Mdot
.37588 .28127 Mdot
.36651 .50894 Mdot
.60642 .5262 Mdot
.31333 .47215 Mdot
.2466 .47518 Mdot
.23129 .47936 Mdot
.61952 .62585 Mdot
.43039 .73992 Mdot
.45764 .34203 Mdot
.63959 .673 Mdot
.25654 .44646 Mdot
.62841 .42991 Mdot
.3869 .50825 Mdot
.25208 .48709 Mdot
.37714 .52241 Mdot
.62948 .65764 Mdot
.64974 .62013 Mdot
.4308 .34637 Mdot
.4722 .34389 Mdot
.7339 .34391 Mdot
.76068 .58215 Mdot
.63718 .46164 Mdot
.69711 .36065 Mdot
.43116 .30607 Mdot
.48215 .26768 Mdot
.65708 .63171 Mdot
.62372 .64132 Mdot
.54298 .28208 Mdot
.65396 .42754 Mdot
.3657 .70898 Mdot
.59803 .43095 Mdot
.69977 .58677 Mdot
.60973 .50406 Mdot
.42561 .65799 Mdot
.64369 .45649 Mdot
.22445 .61732 Mdot
.6492 .47842 Mdot
.58649 .43423 Mdot
.45226 .64936 Mdot
.69079 .44794 Mdot
.42916 .67316 Mdot
.65671 .42451 Mdot
.61168 .62197 Mdot
.43855 .67377 Mdot
.72607 .68237 Mdot
.57392 .57997 Mdot
.25407 .46388 Mdot
.62397 .62668 Mdot
.65848 .6435 Mdot
.80145 .52361 Mdot
.47159 .33015 Mdot
.39383 .35267 Mdot
.61638 .45206 Mdot
.4067 .62432 Mdot
.38051 .50227 Mdot
.62821 .47096 Mdot
.56434 .4398 Mdot
.68535 .46825 Mdot
.43107 .33606 Mdot
.44607 .62628 Mdot
.63274 .65118 Mdot
.40924 .64937 Mdot
.54031 .65503 Mdot
.41503 .68852 Mdot
.56695 .39069 Mdot
.66678 .40723 Mdot
.70728 .49137 Mdot
.70223 .35387 Mdot
.47358 .19726 Mdot
.44818 .32897 Mdot
.24495 .46685 Mdot
.63508 .61761 Mdot
.3789 .3466 Mdot
.45774 .30939 Mdot
.42834 .64144 Mdot
.60443 .44468 Mdot
.61283 .52866 Mdot
.53119 .51877 Mdot
.50262 .36875 Mdot
.7929 .58523 Mdot
.45565 .6732 Mdot
.24069 .47763 Mdot
.37644 .41519 Mdot
.48073 .39141 Mdot
.4651 .52077 Mdot
.59048 .44821 Mdot
.65796 .63754 Mdot
.48135 .3376 Mdot
.58553 .75683 Mdot
.39484 .52299 Mdot
.44342 .48335 Mdot
.6137 .47737 Mdot
.26017 .35982 Mdot
.4617 .32329 Mdot
.61873 .64344 Mdot
.39356 .53257 Mdot
.65239 .62376 Mdot
.22601 .47151 Mdot
.20747 .61917 Mdot
.64497 .43292 Mdot
.58122 .4457 Mdot
.35154 .55074 Mdot
.45899 .33888 Mdot
.39601 .6656 Mdot
.5961 .76471 Mdot
.41339 .63121 Mdot
.47423 .55627 Mdot
.47397 .35079 Mdot
.41958 .24577 Mdot
.41382 .67252 Mdot
.40232 .55013 Mdot
.47785 .54192 Mdot
.39958 .55006 Mdot
.59814 .42774 Mdot
.44061 .30964 Mdot
.38533 .55319 Mdot
.58288 .72891 Mdot
.33968 .78668 Mdot
.41813 .26174 Mdot
.63048 .48918 Mdot
.46714 .83315 Mdot
.26713 .72091 Mdot
.67086 .36497 Mdot
.38393 .49981 Mdot
.59198 .47154 Mdot
.65722 .4898 Mdot
.64227 .44413 Mdot
.39892 .54256 Mdot
.52184 .67097 Mdot
.42011 .65485 Mdot
.6244 .44263 Mdot
.65609 .64015 Mdot
.43149 .66266 Mdot
.47104 .66693 Mdot
.40541 .65307 Mdot
.41387 .33866 Mdot
.65096 .4953 Mdot
.34311 .44037 Mdot
.20984 .69755 Mdot
.35966 .51746 Mdot
.25353 .46347 Mdot
.58135 .43441 Mdot
.71818 .28695 Mdot
.45598 .30419 Mdot
.4143 .63117 Mdot
.59813 .46737 Mdot
.55203 .68491 Mdot
.26007 .49458 Mdot
.45158 .67168 Mdot
.47006 .3287 Mdot
.67065 .36548 Mdot
.62077 .47428 Mdot
.65416 .4472 Mdot
.45937 .34713 Mdot
.1803 .58146 Mdot
.36686 .42224 Mdot
.58715 .44893 Mdot
.36956 .51177 Mdot
.56622 .14895 Mdot
.68304 .4556 Mdot
.49734 .35394 Mdot
.25573 .46146 Mdot
.29065 .44287 Mdot
.57517 .22463 Mdot
.65735 .38788 Mdot
.49177 .82326 Mdot
.7708 .47559 Mdot
.44206 .82596 Mdot
.66169 .56831 Mdot
.29711 .6489 Mdot
.32052 .80466 Mdot
.33722 .52488 Mdot
.47079 .24535 Mdot
.70712 .73216 Mdot
.30886 .37997 Mdot
.55488 .6426 Mdot
.32018 .58424 Mdot
.56135 .67378 Mdot
.25883 .28282 Mdot
.4125 .67923 Mdot
.6829 .60453 Mdot
.62065 .41071 Mdot
.26092 .71181 Mdot
.49927 .22307 Mdot
.47698 .18668 Mdot
.43517 .8161 Mdot
.5828 .6962 Mdot
.66523 .78611 Mdot
.38976 .78579 Mdot
.75358 .42308 Mdot
.50754 .49527 Mdot
.38305 .60656 Mdot
.45433 .41562 Mdot
.71581 .53658 Mdot
.69638 .49083 Mdot
.2223 .58535 Mdot
.46033 .7231 Mdot
.68064 .28189 Mdot
.56327 .15811 Mdot
.43135 .6182 Mdot
.43003 .29553 Mdot
.66939 .73396 Mdot
.4648 .27015 Mdot
.39106 .57728 Mdot
.49296 .82344 Mdot
.28776 .74911 Mdot
.45828 .2333 Mdot
.1934 .47272 Mdot
.5599 .31762 Mdot
.81125 .40429 Mdot
.53239 .5375 Mdot
.48531 .32042 Mdot
.31761 .6334 Mdot
.4267 .41191 Mdot
.38644 .64629 Mdot
.43025 .22961 Mdot
.64448 .68272 Mdot
.76395 .63986 Mdot
.46835 .32935 Mdot
.58506 .23539 Mdot
.26414 .46485 Mdot
.25938 .45019 Mdot
.39757 .65237 Mdot
.44798 .78509 Mdot
.27548 .49213 Mdot
.32038 .45477 Mdot
.23772 .36104 Mdot
.63701 .8218 Mdot
.75628 .51986 Mdot
.44196 .76528 Mdot
.39966 .48295 Mdot
.76895 .48246 Mdot
.34568 .3964 Mdot
.76985 .55364 Mdot
.43195 .40581 Mdot
.78521 .69365 Mdot
.20181 .64673 Mdot
.70598 .76095 Mdot
.40664 .29596 Mdot
.64565 .40569 Mdot
.48751 .78922 Mdot
.66008 .32857 Mdot
.66227 .63049 Mdot
.61352 .82778 Mdot
.66274 .65518 Mdot
.40543 .3388 Mdot
.30263 .37292 Mdot
.45659 .21797 Mdot
.4425 .73131 Mdot
.60648 .61978 Mdot
.58625 .50318 Mdot
.8681 .59422 Mdot
.52092 .82868 Mdot
.26651 .42567 Mdot
.27907 .74019 Mdot
.33012 .52278 Mdot
.40679 .59413 Mdot
.4007 .52783 Mdot
.32367 .79326 Mdot
.4541 .31143 Mdot
.2219 .71765 Mdot
.31619 .78075 Mdot
.37465 .25409 Mdot
.89795 .54431 Mdot
.25455 .30957 Mdot
.51012 .23709 Mdot
.76476 .4479 Mdot
.78079 .63343 Mdot
.35381 .36942 Mdot
.37215 .24649 Mdot
.40025 .58646 Mdot
.17504 .5856 Mdot
.36722 .8094 Mdot
.7284 .57958 Mdot
.48074 .69107 Mdot
.32175 .37503 Mdot
.55051 .5591 Mdot
.49318 .35932 Mdot
.58025 .60639 Mdot
.60787 .57417 Mdot
.68602 .77225 Mdot
.71674 .30254 Mdot
.7008 .21608 Mdot
.67442 .57274 Mdot
.36461 .22648 Mdot
.37917 .76015 Mdot
.7146 .68417 Mdot
.39177 .28127 Mdot
.3178 .41856 Mdot
.55082 .42205 Mdot
.39723 .42195 Mdot
.57722 .51827 Mdot
.64851 .68939 Mdot
.37854 .40576 Mdot
.30253 .69449 Mdot
.69445 .57334 Mdot
.57537 .79939 Mdot
.50263 .45554 Mdot
.41946 .34789 Mdot
.78446 .52948 Mdot
.74873 .54203 Mdot
.30304 .75167 Mdot
.33691 .29453 Mdot
.16098 .54789 Mdot
.35012 .28299 Mdot
.59298 .50486 Mdot
.4779 .25367 Mdot
.69008 .50034 Mdot
.76183 .54961 Mdot
.65595 .5023 Mdot
.22882 .37728 Mdot
.23527 .70555 Mdot
.70146 .31682 Mdot
.70508 .55311 Mdot
.71433 .36413 Mdot
.18134 .60596 Mdot
.50421 .79453 Mdot
.29518 .30428 Mdot
.51735 .3522 Mdot
.84127 .6306 Mdot
.43621 .65244 Mdot
.74043 .57273 Mdot
.40297 .5038 Mdot
.5586 .75758 Mdot
.7536 .70122 Mdot
.36937 .27234 Mdot
.22724 .69812 Mdot
.328 .4207 Mdot
.41926 .71961 Mdot
.3636 .45417 Mdot
.44233 .60065 Mdot
.7318 .38113 Mdot
.68622 .44847 Mdot
.72482 .46542 Mdot
.63305 .67558 Mdot
.63594 .32024 Mdot
.52882 .78905 Mdot
.27124 .56225 Mdot
.60476 .378 Mdot
.27902 .59104 Mdot
.23872 .47963 Mdot
.42792 .46747 Mdot
.39466 .83877 Mdot
.66811 .40058 Mdot
.28261 .28088 Mdot
.19806 .63436 Mdot
.47003 .54734 Mdot
.46198 .74954 Mdot
.26602 .39564 Mdot
.74778 .73093 Mdot
.27948 .75517 Mdot
.2909 .71509 Mdot
.47834 .83654 Mdot
.14371 .49684 Mdot
.80138 .64987 Mdot
.56803 .35042 Mdot
.39019 .48854 Mdot
.09476 .53688 Mdot
.4158 .64667 Mdot
.7626 .39707 Mdot
.66163 .3259 Mdot
.54759 .69731 Mdot
.48287 .2929 Mdot
.55059 .38877 Mdot
.29683 .51091 Mdot
.48341 .36846 Mdot
.58041 .49861 Mdot
.57785 .85029 Mdot
.79231 .68964 Mdot
.59691 .84137 Mdot
.20927 .62625 Mdot
.46441 .8381 Mdot
.67982 .75691 Mdot
.57374 .19508 Mdot
.6454 .74238 Mdot
.65262 .41766 Mdot
.73312 .60454 Mdot
.26282 .30427 Mdot
.40025 .67911 Mdot
.20708 .46369 Mdot
.41054 .30009 Mdot
.7596 .71023 Mdot
.41048 .85043 Mdot
.56486 .28674 Mdot
.64006 .25475 Mdot
.59198 .57416 Mdot
.75632 .56977 Mdot
.72838 .47827 Mdot
.22424 .56587 Mdot
.33279 .75888 Mdot
.69179 .75085 Mdot
.73339 .55267 Mdot
.3113 .58973 Mdot
.29049 .70457 Mdot
.34479 .24681 Mdot
.41528 .7908 Mdot
.68963 .73019 Mdot
.36269 .26349 Mdot
.52125 .38175 Mdot
.37459 .2778 Mdot
.21573 .54596 Mdot
.38617 .7122 Mdot
.74815 .51769 Mdot
.45409 .68683 Mdot
.72922 .58589 Mdot
.47341 .45887 Mdot
.65436 .74114 Mdot
.77712 .48042 Mdot
.72217 .58356 Mdot
.30553 .71883 Mdot
.54166 .85004 Mdot
.17629 .49929 Mdot
.83332 .54152 Mdot
.24402 .51907 Mdot
.55827 .50332 Mdot
.66647 .42572 Mdot
.20676 .66373 Mdot
.51861 .86159 Mdot
.23769 .71715 Mdot
.25934 .35634 Mdot
.57483 .72905 Mdot
.3666 .48481 Mdot
.79817 .45264 Mdot
.25961 .53879 Mdot
.33935 .76896 Mdot
.38651 .38228 Mdot
.34473 .55856 Mdot
.33554 .42122 Mdot
.75524 .39995 Mdot
.77602 .45108 Mdot
.60763 .25249 Mdot
.70027 .46738 Mdot
.5327 .22736 Mdot
.44963 .2928 Mdot
.26703 .34265 Mdot
.76413 .55859 Mdot
.43827 .65635 Mdot
.71217 .70681 Mdot
.72352 .47657 Mdot
.55375 .4121 Mdot
.3928 .71667 Mdot
.49242 .35694 Mdot
.70148 .34908 Mdot
.39419 .58817 Mdot
.33826 .81347 Mdot
.27223 .30779 Mdot
.74343 .43775 Mdot
.77514 .51197 Mdot
.65121 .7205 Mdot
.37296 .43001 Mdot
.39007 .56258 Mdot
.42211 .80853 Mdot
.55966 .59768 Mdot
.78215 .52293 Mdot
.54036 .22735 Mdot
.57362 .77331 Mdot
.56365 .44459 Mdot
.25402 .408 Mdot
.6358 .22116 Mdot
.43813 .48071 Mdot
.41854 .37168 Mdot
.47062 .38321 Mdot
.25863 .263 Mdot
.23642 .62641 Mdot
.32972 .28442 Mdot
.42884 .80454 Mdot
.4018 .54438 Mdot
.43214 .36826 Mdot
.7188 .59492 Mdot
.51422 .75406 Mdot
.68047 .26694 Mdot
.39876 .73804 Mdot
.73108 .48854 Mdot
.25463 .55077 Mdot
.47323 .83201 Mdot
.59253 .81768 Mdot
.60698 .16858 Mdot
.47617 .36301 Mdot
.52242 .78025 Mdot
.5475 .77531 Mdot
.48328 .34136 Mdot
.50089 .36574 Mdot
.52034 .50643 Mdot
.43156 .83231 Mdot
.41212 .4229 Mdot
.21324 .52342 Mdot
.47741 .54405 Mdot
.53914 .67603 Mdot
.59785 .75597 Mdot
.74194 .51609 Mdot
.43426 .80146 Mdot
.588 .24459 Mdot
.80581 .61363 Mdot
.68368 .51519 Mdot
.74165 .34432 Mdot
.79859 .45177 Mdot
.51717 .52771 Mdot
.43669 .23339 Mdot
.31792 .7011 Mdot
.63985 .44765 Mdot
.62978 .82805 Mdot
.30169 .74414 Mdot
.38324 .39476 Mdot
.36503 .58619 Mdot
.66255 .45999 Mdot
.66357 .48821 Mdot
.56585 .36491 Mdot
.28552 .43091 Mdot
.82954 .59881 Mdot
.68424 .58232 Mdot
.56873 .51354 Mdot
.53417 .22293 Mdot
.28408 .28016 Mdot
.46474 .78478 Mdot
.35827 .75819 Mdot
.46006 .45844 Mdot
.26348 .30608 Mdot
.44145 .51146 Mdot
.20536 .51982 Mdot
.25591 .58731 Mdot
.66976 .76067 Mdot
.51773 .45314 Mdot
.30017 .42285 Mdot
.63256 .73498 Mdot
.58522 .43093 Mdot
.29266 .37656 Mdot
.40033 .78576 Mdot
.74974 .26624 Mdot
.34156 .38405 Mdot
.55513 .85957 Mdot
.71551 .48136 Mdot
.30964 .42856 Mdot
.77035 .69043 Mdot
.82141 .34161 Mdot
.21916 .57482 Mdot
.67194 .78251 Mdot
.40114 .46058 Mdot
.43756 .80883 Mdot
.34707 .49974 Mdot
.47026 .42883 Mdot
.67304 .35038 Mdot
.42466 .83017 Mdot
.47552 .76436 Mdot
.4566 .79642 Mdot
.55896 .36354 Mdot
.46766 .84429 Mdot
.42577 .40048 Mdot
.28336 .24643 Mdot
.4308 .71214 Mdot
.21209 .37691 Mdot
.531 .35025 Mdot
.68733 .52656 Mdot
.73823 .56377 Mdot
.35164 .21313 Mdot
.52646 .18357 Mdot
.5884 .35215 Mdot
.71174 .63597 Mdot
.2717 .40458 Mdot
.77438 .5063 Mdot
.33989 .7751 Mdot
.26406 .27429 Mdot
.57377 .76588 Mdot
.29828 .32664 Mdot
.19474 .60802 Mdot
.27986 .43132 Mdot
.26097 .62316 Mdot
.43829 .76721 Mdot
.19096 .54667 Mdot
.72433 .49962 Mdot
.36051 .1561 Mdot
.48599 .6367 Mdot
.52455 .51121 Mdot
.73022 .74027 Mdot
.3291 .75696 Mdot
.37818 .354 Mdot
.42082 .22547 Mdot
.76788 .36777 Mdot
.74901 .62143 Mdot
.59056 .43426 Mdot
.47665 .84737 Mdot
.74127 .6579 Mdot
.63973 .8113 Mdot
.16745 .60086 Mdot
.54326 .23912 Mdot
.61683 .38363 Mdot
.4582 .6183 Mdot
.55254 .54455 Mdot
.70582 .63813 Mdot
.68793 .76192 Mdot
.75521 .37241 Mdot
.51436 .59258 Mdot
.29516 .6384 Mdot
.37812 .73655 Mdot
.53929 .49038 Mdot
.24458 .3254 Mdot
.28316 .41739 Mdot
.68441 .56419 Mdot
.27771 .69409 Mdot
.75087 .56331 Mdot
.56634 .22201 Mdot
.79137 .46813 Mdot
.35479 .32542 Mdot
.31475 .51854 Mdot
.44489 .61605 Mdot
.61712 .78635 Mdot
.36537 .7498 Mdot
.22719 .38204 Mdot
.82537 .56602 Mdot
.3148 .41245 Mdot
.68421 .61522 Mdot
.56447 .79224 Mdot
.35022 .36328 Mdot
.37977 .61139 Mdot
.77589 .44366 Mdot
.73684 .34132 Mdot
.33544 .71942 Mdot
.62494 .37427 Mdot
.37145 .81495 Mdot
.74419 .5203 Mdot
.61698 .7701 Mdot
.56941 .57303 Mdot
.65809 .30826 Mdot
.51605 .27829 Mdot
.74685 .67089 Mdot
.45215 .50983 Mdot
.85956 .60569 Mdot
.4685 .28719 Mdot
.63989 .82026 Mdot
.38416 .51405 Mdot
.66436 .21233 Mdot
.33607 .73975 Mdot
.46953 .47536 Mdot
.48341 .52847 Mdot
.2515 .41054 Mdot
.30443 .46678 Mdot
.189 .60647 Mdot
.37424 .27228 Mdot
.40929 .68097 Mdot
.52632 .60665 Mdot
.21604 .53074 Mdot
.57606 .80602 Mdot
.62074 .40168 Mdot
.44558 .73366 Mdot
.52541 .53541 Mdot
.4242 .56888 Mdot
.2113 .6674 Mdot
.32182 .69161 Mdot
.64332 .5212 Mdot
.75817 .57122 Mdot
.70798 .74533 Mdot
.31913 .77732 Mdot
.37522 .29503 Mdot
.58108 .52053 Mdot
.41451 .51864 Mdot
.7521 .68793 Mdot
.52099 .82455 Mdot
.35963 .70735 Mdot
.35607 .44359 Mdot
.75287 .52419 Mdot
.63366 .84406 Mdot
.78953 .69102 Mdot
.83096 .56552 Mdot
.47922 .55203 Mdot
.41836 .38249 Mdot
.72268 .29474 Mdot
.61291 .77233 Mdot
.19807 .39865 Mdot
.29857 .73125 Mdot
.74358 .56783 Mdot
.79413 .32371 Mdot
.49625 .19589 Mdot
.53469 .65021 Mdot
.51777 .28067 Mdot
.68203 .33457 Mdot
.33874 .51173 Mdot
.73932 .63366 Mdot
.54527 .61098 Mdot
.37839 .57339 Mdot
.27388 .40707 Mdot
.31647 .46136 Mdot
.62083 .76771 Mdot
.66097 .24624 Mdot
.61402 .53464 Mdot
.53981 .81203 Mdot
.45554 .38619 Mdot
.57929 .75944 Mdot
.6517 .72246 Mdot
.54266 .62082 Mdot
.41093 .65112 Mdot
.70731 .46325 Mdot
.40338 .448 Mdot
.42868 .48175 Mdot
.82503 .47233 Mdot
.66021 .66401 Mdot
.43218 .27992 Mdot
.46042 .20232 Mdot
.4698 .36788 Mdot
.49924 .86376 Mdot
.22511 .56716 Mdot
.52348 .22408 Mdot
.46819 .61525 Mdot
.31731 .6108 Mdot
.83322 .43028 Mdot
.75468 .41282 Mdot
.59331 .60323 Mdot
.44783 .39632 Mdot
.46428 .30113 Mdot
.46868 .62157 Mdot
.21577 .46425 Mdot
.61073 .24408 Mdot
.2796 .27692 Mdot
.66125 .72131 Mdot
.48715 .33228 Mdot
.53002 .65695 Mdot
.71752 .40593 Mdot
.38066 .82829 Mdot
.40729 .65491 Mdot
.83103 .64524 Mdot
.66314 .40503 Mdot
.78573 .65687 Mdot
.21444 .67443 Mdot
.36244 .40693 Mdot
.48233 .56146 Mdot
.34541 .59324 Mdot
.57923 .41444 Mdot
.62092 .53771 Mdot
.46968 .34069 Mdot
.63408 .74639 Mdot
.63361 .64065 Mdot
.78569 .57935 Mdot
.39809 .56012 Mdot
.37225 .23367 Mdot
.24833 .32718 Mdot
.43359 .29184 Mdot
.55941 .61178 Mdot
.48883 .77732 Mdot
.49779 .46572 Mdot
.52383 .53464 Mdot
.62892 .78464 Mdot
.68527 .27701 Mdot
.48515 .32405 Mdot
.82643 .57221 Mdot
.67443 .62028 Mdot
.29685 .77872 Mdot
.69485 .39121 Mdot
.52754 .53 Mdot
.50073 .46479 Mdot
.25604 .40075 Mdot
.58388 .22703 Mdot
.35111 .76082 Mdot
.78025 .53793 Mdot
.4805 .41419 Mdot
.72244 .58613 Mdot
.67179 .51256 Mdot
.29076 .63757 Mdot
.21681 .3614 Mdot
.80407 .34082 Mdot
.54305 .31599 Mdot
.34536 .41238 Mdot
.46819 .38726 Mdot
.28049 .28363 Mdot
.45488 .27853 Mdot
.52234 .70303 Mdot
.68721 .28873 Mdot
.3356 .74086 Mdot
.33638 .80401 Mdot
.30195 .75018 Mdot
.58197 .55527 Mdot
.37085 .72775 Mdot
.76206 .46024 Mdot
.6981 .38953 Mdot
.47108 .50393 Mdot
.5771 .41841 Mdot
.53457 .47658 Mdot
.36801 .32672 Mdot
.23265 .38736 Mdot
.54136 .40991 Mdot
.41379 .82145 Mdot
.29273 .77283 Mdot
.51069 .8441 Mdot
.38377 .70384 Mdot
.41223 .33821 Mdot
.76002 .7195 Mdot
.55045 .20646 Mdot
.33329 .77429 Mdot
.53532 .35062 Mdot
.23733 .28558 Mdot
.74132 .7136 Mdot
.30995 .70089 Mdot
.37496 .24984 Mdot
.20454 .44747 Mdot
.21916 .67299 Mdot
.28171 .24827 Mdot
.71983 .51349 Mdot
.20049 .65145 Mdot
.86721 .59312 Mdot
.54898 .34422 Mdot
.31343 .45829 Mdot
.50565 .26663 Mdot
.75594 .45592 Mdot
.28031 .26781 Mdot
.6545 .41694 Mdot
.44037 .70226 Mdot
.55529 .65668 Mdot
.74804 .55813 Mdot
.70245 .41687 Mdot
.29046 .25675 Mdot
.70284 .63879 Mdot
.67977 .60423 Mdot
.52872 .77189 Mdot
.71439 .72922 Mdot
.59925 .2335 Mdot
.60584 .52323 Mdot
.40166 .32331 Mdot
.61258 .63657 Mdot
.69958 .54222 Mdot
.66609 .46603 Mdot
.45302 .5547 Mdot
.52467 .50322 Mdot
.57386 .85384 Mdot
.52331 .72963 Mdot
.48475 .72024 Mdot
.47946 .3763 Mdot
.27801 .42266 Mdot
.49927 .80178 Mdot
.30649 .37699 Mdot
.31594 .23731 Mdot
.71501 .3062 Mdot
.48377 .83116 Mdot
.32569 .42834 Mdot
.72026 .55007 Mdot
.81657 .43927 Mdot
.35246 .50214 Mdot
.66688 .34336 Mdot
.6765 .76417 Mdot
.29997 .39222 Mdot
.42808 .37407 Mdot
.28215 .67927 Mdot
.30924 .65629 Mdot
.29018 .39733 Mdot
.19707 .63103 Mdot
.53951 .78349 Mdot
.52973 .26145 Mdot
.57804 .81931 Mdot
.46371 .69382 Mdot
.73304 .55623 Mdot
.25503 .64604 Mdot
.2711 .27311 Mdot
.49828 .4511 Mdot
.38499 .81864 Mdot
.47212 .50879 Mdot
.74908 .65709 Mdot
.64876 .43805 Mdot
.62935 .23219 Mdot
.2415 .39087 Mdot
.276 .6862 Mdot
.32887 .29232 Mdot
.41097 .32022 Mdot
.24845 .34425 Mdot
.38699 .60425 Mdot
.74948 .63695 Mdot
.69151 .53853 Mdot
.45681 .25806 Mdot
.62735 .58884 Mdot
.26598 .46109 Mdot
.66284 .40807 Mdot
.77515 .62901 Mdot
.39271 .74345 Mdot
.6491 .34519 Mdot
.56608 .34922 Mdot
.61619 .78821 Mdot
.4129 .75191 Mdot
.21901 .38714 Mdot
.55968 .35721 Mdot
.25768 .44195 Mdot
.51394 .19341 Mdot
.30954 .34963 Mdot
.67527 .48368 Mdot
.52341 .70072 Mdot
.44921 .36935 Mdot
.58127 .80701 Mdot
.40167 .29183 Mdot
.72273 .6845 Mdot
.43908 .46093 Mdot
.47992 .78622 Mdot
.55448 .57221 Mdot
.21757 .67641 Mdot
.20355 .44813 Mdot
.76541 .55746 Mdot
.36595 .5639 Mdot
.39542 .45953 Mdot
.34113 .3738 Mdot
.38174 .80026 Mdot
.36201 .29957 Mdot
.73865 .41347 Mdot
.3384 .41543 Mdot
.70043 .3278 Mdot
.1785 .62099 Mdot
.76486 .58509 Mdot
.46973 .50218 Mdot
.7388 .45107 Mdot
.24675 .4465 Mdot
.25732 .48273 Mdot
.54155 .70971 Mdot
.5805 .21675 Mdot
.49341 .687 Mdot
.50329 .59295 Mdot
.65279 .40561 Mdot
.71232 .28065 Mdot
.55993 .81944 Mdot
.3777 .33892 Mdot
.47463 .48723 Mdot
.62587 .73442 Mdot
.75579 .63552 Mdot
.50728 .12389 Mdot
.62079 .83534 Mdot
.64922 .43742 Mdot
.48648 .54532 Mdot
.78037 .5837 Mdot
.46228 .65224 Mdot
.62042 .25417 Mdot
.60874 .79309 Mdot
.35088 .52695 Mdot
.57371 .73737 Mdot
.20648 .47566 Mdot
.24474 .40624 Mdot
.73878 .68068 Mdot
.35258 .48673 Mdot
.51894 .86815 Mdot
.29061 .72238 Mdot
.24802 .38337 Mdot
.43523 .12343 Mdot
.24669 .36282 Mdot
.40798 .37986 Mdot
.46374 .76589 Mdot
.53581 .85107 Mdot
.4761 .54954 Mdot
.55673 .75432 Mdot
.57408 .34679 Mdot
.7714 .55006 Mdot
.69527 .58495 Mdot
.29682 .32772 Mdot
.26331 .33184 Mdot
.29438 .23627 Mdot
.31816 .60973 Mdot
.83266 .47807 Mdot
.5725 .23675 Mdot
.59167 .82211 Mdot
.21919 .5711 Mdot
.78359 .31005 Mdot
.32519 .79391 Mdot
.7269 .61271 Mdot
.30789 .24869 Mdot
.46366 .75759 Mdot
.79946 .55946 Mdot
.6699 .23882 Mdot
.2078 .58231 Mdot
.70109 .29254 Mdot
.29989 .59799 Mdot
.3188 .32104 Mdot
.72625 .58538 Mdot
.69443 .33272 Mdot
.46885 .50981 Mdot
.65195 .78772 Mdot
.36886 .21336 Mdot
.77041 .51726 Mdot
.59169 .73576 Mdot
.80517 .5688 Mdot
.53061 .81753 Mdot
.41615 .77627 Mdot
.49962 .52578 Mdot
.86563 .57173 Mdot
.68457 .7728 Mdot
.31502 .36451 Mdot
.67246 .47918 Mdot
.31142 .79561 Mdot
.51768 .56136 Mdot
.58022 .35042 Mdot
.24009 .68748 Mdot
.6794 .58117 Mdot
.52174 .48749 Mdot
.68421 .45661 Mdot
.77074 .43315 Mdot
.42122 .24882 Mdot
.694 .3362 Mdot
.65185 .71214 Mdot
.77616 .51543 Mdot
.37214 .21481 Mdot
.78212 .6415 Mdot
.67201 .37433 Mdot
.4695 .3576 Mdot
.55291 .85384 Mdot
.74993 .41985 Mdot
.68784 .51667 Mdot
.50725 .24758 Mdot
.36638 .29004 Mdot
.30782 .53953 Mdot
.56525 .5086 Mdot
.37562 .43036 Mdot
.7398 .56134 Mdot
.5984 .77849 Mdot
.67042 .35241 Mdot
.90241 .53789 Mdot
.21632 .6803 Mdot
.4794 .29668 Mdot
.6156 .33891 Mdot
.54294 .63106 Mdot
.51908 .84089 Mdot
.30465 .58452 Mdot
.65143 .72113 Mdot
.44569 .19667 Mdot
.79174 .53528 Mdot
.57785 .48094 Mdot
.20985 .63029 Mdot
.3453 .79977 Mdot
.39356 .19697 Mdot
.37138 .81427 Mdot
.5885 .38633 Mdot
.60076 .39319 Mdot
.73663 .22758 Mdot
.45368 .8202 Mdot
.65718 .38868 Mdot
.39075 .2484 Mdot
.48987 .2993 Mdot
.63018 .40995 Mdot
.2147 .48383 Mdot
.74727 .5021 Mdot
.69121 .59267 Mdot
.42877 .8305 Mdot
.46803 .38027 Mdot
.4688 .55639 Mdot
.38972 .49137 Mdot
.47703 .52391 Mdot
.64132 .52377 Mdot
.38033 .55536 Mdot
.69098 .60218 Mdot
.51316 .56566 Mdot
.29674 .49605 Mdot
.71721 .51113 Mdot
.18663 .50686 Mdot
.66185 .54405 Mdot
.58383 .55996 Mdot
.53066 .37417 Mdot
.52643 .18302 Mdot
.70397 .63729 Mdot
.69661 .65967 Mdot
.19902 .64541 Mdot
.15315 .45545 Mdot
.46914 .59329 Mdot
.59388 .3658 Mdot
.5123 .3923 Mdot
.56949 .21681 Mdot
.51875 .25589 Mdot
.31776 .4897 Mdot
.251 .48142 Mdot
.56345 .39659 Mdot
.74313 .43795 Mdot
.39911 .51081 Mdot
.60346 .85427 Mdot
.67154 .43877 Mdot
.56746 .25627 Mdot
.36681 .78766 Mdot
.58658 .75692 Mdot
.57712 .53496 Mdot
.57451 .41904 Mdot
.41362 .39887 Mdot
.51884 .56977 Mdot
.72652 .40757 Mdot
.60911 .75236 Mdot
.53396 .83315 Mdot
.60674 .55295 Mdot
.55314 .24965 Mdot
.62386 .44965 Mdot
.60355 .63177 Mdot
.39382 .43458 Mdot
.81804 .4912 Mdot
.60706 .60265 Mdot
.31825 .77254 Mdot
.66213 .60047 Mdot
.68396 .58173 Mdot
.48382 .23744 Mdot
.63374 .81707 Mdot
.3378 .38523 Mdot
.53623 .2358 Mdot
.37109 .3605 Mdot
.26985 .6409 Mdot
.71178 .63312 Mdot
.47438 .64663 Mdot
.54032 .41561 Mdot
.4897 .29687 Mdot
.43236 .84542 Mdot
.7543 .41045 Mdot
.33165 .4821 Mdot
.33813 .72415 Mdot
.5153 .19621 Mdot
.48388 .52497 Mdot
.39333 .13976 Mdot
.31074 .5772 Mdot
.52502 .86719 Mdot
.57699 .77805 Mdot
.51187 .40682 Mdot
.27215 .40135 Mdot
.70747 .44758 Mdot
.44871 .64377 Mdot
.52547 .838 Mdot
.72342 .42284 Mdot
.30642 .34087 Mdot
.66275 .43164 Mdot
.41104 .40865 Mdot
.736 .42567 Mdot
.35993 .72009 Mdot
.42775 .6999 Mdot
.37299 .2925 Mdot
.41835 .78274 Mdot
.52122 .57125 Mdot
.21537 .3181 Mdot
.68907 .76206 Mdot
.41948 .80859 Mdot
.38312 .73681 Mdot
.66227 .20685 Mdot
.44082 .39488 Mdot
.70213 .39166 Mdot
.34613 .55244 Mdot
.76725 .44862 Mdot
.29355 .39316 Mdot
.60252 .77347 Mdot
.25782 .43955 Mdot
.49733 .48338 Mdot
.29954 .18759 Mdot
.72276 .60521 Mdot
.38324 .35677 Mdot
.28238 .37481 Mdot
.40136 .81442 Mdot
.60127 .70834 Mdot
.16213 .52986 Mdot
.22435 .59923 Mdot
.65079 .51993 Mdot
.64461 .2287 Mdot
.80711 .60266 Mdot
.34345 .68381 Mdot
.83509 .45891 Mdot
.37209 .7502 Mdot
.71342 .53851 Mdot
.26935 .67683 Mdot
.47416 .36406 Mdot
.47709 .28662 Mdot
.22441 .55239 Mdot
.19738 .48507 Mdot
.60084 .36002 Mdot
.50527 .82521 Mdot
.79826 .37423 Mdot
.65068 .72839 Mdot
.48254 .84016 Mdot
.40062 .48087 Mdot
.49279 .38089 Mdot
.69912 .63508 Mdot
.66424 .62091 Mdot
.46573 .6594 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0T?oo
ool2o`000;Oooooo000Looooo`03o`000?oooooooooo08[ooooo0_l00002ooooo`Co00003oooool2
o`000:Kooooo000Looooo`03o`000?oooooooooo08[ooooo0_l00002ooooo`;o00004Oooool2o`00
0:Kooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
Yoooool2o`0000Sooooo0_l0002Fooooo`007?ooool00ol0003oooooooooo`2Wooooo`;o00001?oo
ool2o`0000;ooooo0_l0002Fooooo`007?ooool00ol0003oooooooooo`1looooo`;o0000:_ooool2
o`0000?ooooo0_l0002Jooooo`007?ooool00ol0003oooooooooo`1looooo`;o0000:_ooool2o`00
00?ooooo0_l0002Jooooo`007?ooool00ol0003oooooooooo`2]ooooo`;o0000V_ooool001cooooo
00?o0000ooooooooool0Moooool2o`0003_ooooo0_l0002Cooooo`007?ooool2o`0007Sooooo0_l0
000Gooooo`;o000000?oooooo`000?l000002?ooool4o`0000Kooooo0_l0000;ooooo`;o0000Tooo
ool001cooooo00?o0000ooooooooool0J_ooool2o`0000Gooooo0_l0000Mooooo`;o000000?ooooo
o`000?l000002?ooool4o`0000Kooooo0_l00003ooooo`;o00000_ooool2o`0009Oooooo000Loooo
o`03o`000?oooooooooo06[ooooo0_l00005ooooo`;o00005?ooool4o`00027ooooo0_l00002oooo
o`;o000000?oooooo`000?l000001?ooool2o`0000Sooooo0_l00024ooooo`007?ooool00ol0003o
ooooooooo`27ooooo`Co00008Oooool2o`0000Gooooo0_l00004ooooo`;o00002?ooool2o`0008Co
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0__oo
ool2o`000003ooooool0003o000008Kooooo000Looooo`03o`000?oooooooooo0:3ooooo0_l0000L
ooooo`;o000000?oooooo`000?l000000_l00009ooooo`;o0000NOooool001cooooo00?o0000oooo
ooooool0X?ooool2o`0001Gooooo0_l0000:ooooo`;o00002Oooool2o`0007Wooooo000Looooo`03
o`000?oooooooooo0:[ooooo0_l0000;ooooo`;o00003Oooool2o`00087ooooo000Looooo`03o`00
0?oooooooooo06?ooooo1?l0000fooooo`;o00001_ooool2o`000003ooooool0003o000000;o0000
00?oooooo`000?l000005oooool4o`0007oooooo000Looooo`03o`000?oooooooooo06?ooooo1?l0
000_ooooo`;o00001Oooool2o`0000Kooooo1ol000000ooooooo0000o`00000Iooooo`;o0000Oooo
ool001cooooo00?o0000ooooooooool0G_ooool2o`0003Kooooo0ol000000ooooooo0000o`00000;
ooooo`?o0000Woooool001cooooo00?o0000ooooooooool0G_ooool2o`0003Oooooo0_l000000ooo
oooo0000o`00002]ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5
o`0000Kooooo00?o0000ooooooooool0Xoooool2o`0002kooooo0_l0001dooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo
00?o0000ooooooooool0SOooool2o`0000cooooo1?l00004ooooo`?o00002?ooool2o`0000Oooooo
0_l0000Jooooo`;o0000M?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_oo
ool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo07cooooo0_l00003ooooo`;o00001ooo
ool5o`0000Oooooo0_l00003ooooo`Co00001?ooool3o`0000;ooooo0_l00004ooooo`;o00001ooo
ool5o`000003ooooool0003o000008[ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0007cooooo0_l00003ooooo`Co00000_ooool2
o`000003ooooool0003o000000;o00001?ooool2o`0000;ooooo0_l00006ooooo`;o00000oooool2
o`0000?ooooo0_l0000=ooooo`Go000000?oooooo`000?l00000R_ooool00003ooooool0003ooooo
00;ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo
08?ooooo0_l00002ooooo`;o00002Oooool2o`0000;ooooo0_l00006ooooo`;o00002?ooool2o`00
00Oooooo0_l00004ooooo`;o00001Oooool2o`0001Kooooo0_l0001aooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0NOooool4o`0000Kooooo0ol00009ooooo`;o00000_ooool2o`0001[ooooo1?l0000;ooooo`;o
00004oooool2o`000003ooooool0003o0000077ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMg
M`_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo07Wooooo1Ol00005
ooooo`?o00001oooool4o`0000;ooooo0_l00004ooooo`;o00002oooool2o`0000Oooooo0_l0000I
ooooo`;o00001oooool3o`0007?ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo06kooooo0_l00004ooooo`?o0000
1Oooool2o`0000cooooo0_l000001?oooooo0000o`000?l00009ooooo`Go00002?ooool4o`0000Wo
oooo0_l0000Eooooo`;o00002?ooool2o`0007?ooooo000Looooo`03o`000?oooooooooo06kooooo
1?l00002ooooo`?o00004oooool2o`0000Gooooo0_l00005ooooo`Ko00002Oooool3o`0000Wooooo
1?l00002ooooo`;o00004Oooool2o`0001;ooooo0_l0001Wooooo`007?ooool00ol0003ooooooooo
o`1/ooooo`;o00000_ooool2o`0001?ooooo0_l0000:ooooo`;o00001Oooool2o`0000Sooooo0_l0
0004ooooo`;o00000oooool4o`000003ooooool0003o000000?o00000_ooool2o`00013ooooo0ol0
000Booooo`;o0000Ioooool001cooooo00?o0000ooooooooool0K?ooool2o`0000Oooooo0_l0000>
ooooo`;o00005oooool2o`000004ooooool0003o0000o`0000;ooooo0_l00002ooooo`Oo000000?o
ooooo`000?l000000_l000000ooooooo0000o`00000=ooooo`;o00000oooool2o`0007cooooo000L
ooooo`03o`000?oooooooooo07?ooooo1?l0000>ooooo`;o00005Oooool4o`000003ooooool0003o
000000;ooooo0ol000000ooooooo0000o`000003o`0000Kooooo0_l000001?oooooo0000o`000?oo
ool2o`0000;ooooo0_l00006ooooo`;o00008oooool2o`0005cooooo000Looooo`03o`000?oooooo
oooo04cooooo0_l0000Rooooo`Go00004?ooool2o`000003ooooool0003o000000Wooooo0_l00007
ooooo`;o00001?ooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`00000<
ooooo`;o00000_ooool2o`0000;ooooo0ol000000ooooooo0000o`000006ooooo`;o00002oooool2
o`0000kooooo0_l0001Looooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00005Oooool2o`00
00[ooooo1Ol000000ooooooo0000o`00000Aooooo`Co00001Oooool4o`0000Oooooo2?l0000@oooo
o`;o00002Oooool2o`000005ooooool0003o0000o`000?ooool01Ol00003ooooo`;o00002oooool2
o`0006cooooo000Looooo`03o`000?oooooooooo05cooooo0_l00005ooooo`;o00001?ooool2o`00
00Cooooo0_l00004ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Gooooo0_l00005oooo
o`;o00002Oooool8o`0000Kooooo0_l00008ooooo`Co00000_ooool4o`000003ooooool0003o0000
00Oooooo1Ol0001looooo`007?ooool00ol0003oooooooooo`1Looooo`;o00001Oooool3o`0000?o
oooo0_l0000=ooooo`;o00002Oooool2o`0000Wooooo0_l000000ooooooo0000o`000006ooooo`?o
00000oooool5o`0000Kooooo0_l000000ooooooo0000o`000007ooooo`;o00000_ooool4o`000003
ooooool0003o000000[ooooo1?l00007ooooo`;o0000LOooool001cooooo00?o0000ooooooooool0
Hoooool3o`0002Sooooo0_l00009ooooo`?o00000oooool5o`0000Wooooo0_l0000@ooooo`;o0000
1_ooool2o`0000Cooooo0_l00007ooooo`;o0000LOooool001cooooo00?o0000ooooooooool0Gooo
ool2o`0001Oooooo0_l00008ooooo`;o000000?oooooo`000?l000003_ooool2o`0000?ooooo0_l0
000Oooooo`;o00001_ooool2o`0000;ooooo0_l00006ooooo`;o00000_ooool2o`0000?ooooo0_l0
000:ooooo`;o0000Hoooool001cooooo00?o0000ooooooooool0F?ooool2o`0000Gooooo0ol0000:
ooooo`;o00001oooool2o`000004ooooool0003o0000ooooo`;o00001?ooool3o`000003ooooool0
003o000000kooooo0ol00002ooooo`;o000000?oooooo`000?l000000_ooool2o`00013ooooo0_l0
0006ooooo`;o00001_ooool2o`0000[ooooo0_l00002ooooo`;o00000oooool2o`0000[ooooo0_l0
001Sooooo`007?ooool2o`0005Wooooo0_l00006ooooo`;o00002_ooool2o`0000Oooooo0ol00003
ooooo`;o00000_ooool5o`000003ooooool0003o000000oooooo0_l00002ooooo`;o000000?ooooo
o`000?l000000_ooool2o`0000_ooooo1?l000000ooooooo0000o`00000Vooooo`;o0000K?ooool0
01cooooo00?o0000ooooooooool0MOooool3o`0000Oooooo0_l000000ooooooo0000o`000005oooo
o`;o00003?ooool2o`0001;ooooo0_l000000ooooooo0000o`000002o`00013ooooo0_l00002oooo
o`;o00001?ooool2o`0000gooooo0ol0001[ooooo`007?ooool00ol0003oooooooooo`1Kooooo`;o
00005_ooool5o`0000Oooooo0_l000000ooooooo0000o`000005ooooo`;o00001_ooool2o`0000Co
oooo0_l0000<ooooo`;o00001?ooool2o`0000Sooooo0_l0000;ooooo`;o00000_ooool2o`0000Co
oooo0_l00009ooooo`;o00000oooool2o`0006_ooooo000Looooo`03o`000?oooooooooo05_ooooo
0_l0000<ooooo`;o00002?ooool2o`0000[ooooo0_l0000;ooooo`;o00000oooool2o`0001;ooooo
0_l000000ooooooo0000o`00000;ooooo`;o00008?ooool2o`00073ooooo000Looooo`03o`000?oo
oooooooo053ooooo0_l0000Gooooo`;o00001oooool2o`00013ooooo0_l00005ooooo`?o00003_oo
ool2o`0000[ooooo0_l0000]ooooo`;o0000L?ooool001cooooo00?o0000ooooooooool0D?ooool2
o`0000Gooooo0_l0000Iooooo`Co00003_ooool2o`0000Gooooo0_l0000<ooooo`;o000000?ooooo
o`000?l000000_ooool2o`0002kooooo0_l00007ooooo`;o00005Oooool2o`0005Oooooo000Loooo
o`03o`000?oooooooooo05Oooooo0_l0000Kooooo`;o00007Oooool2o`0000Cooooo0_l00005oooo
o`;o0000;_ooool2o`0000Oooooo0_l00005ooooo`;o00003_ooool2o`000003ooooool0003o0000
05Cooooo000Looooo`03o`000?oooooooooo05Cooooo0_l0000Dooooo`;o00002?ooool4o`0001Oo
oooo0_l00002ooooo`;o00002?ooool2o`00043ooooo0ol0000Aooooo`;o0000E?ooool001cooooo
00?o0000ooooooooool0D_ooool4o`000003ooooool0003o0000017ooooo1?l00006ooooo`Co0000
2_ooool2o`0000Wooooo1?l0000<ooooo`;o0000??ooool2o`0000;ooooo0_l0000Cooooo`;o0000
Doooool001cooooo00?o0000ooooooooool0D_ooool2o`0000;ooooo1?l0000=ooooo`Co000000?o
ooooo`000?l000002?ooool2o`0000[ooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo
1_l00003ooooo`?o00002Oooool2o`000003ooooool0003o000000gooooo0_l0000Vooooo`;o0000
5oooool2o`0005?ooooo000Looooo`03o`000?oooooooooo053ooooo0_l00004ooooo`Go00003?oo
ool4o`0000?ooooo0_l00006ooooo`;o00001?ooool2o`0000Sooooo0_l000000ooooooo0000o`00
0007o`0000?ooooo0ol00009ooooo`;o000000?oooooo`000?l000001oooool2o`0000Cooooo0_l0
000Tooooo`;o00001?ooool2o`0000?ooooo0_l0000Booooo`;o0000Coooool001cooooo00?o0000
ooooooooool0BOooool2o`0000Gooooo0_l00005ooooo`Co00003?ooool2o`0000Gooooo0_l00006
ooooo`;o00001?ooool6o`0000?ooooo2?l00009ooooo`;o00003?ooool2o`0000Oooooo0_l00006
ooooo`;o00008_ooool2o`0000Cooooo1?l000000ooooooo0000o`00000Booooo`;o0000Coooool0
01cooooo00?o0000ooooooooool0BOooool2o`0000cooooo0_l0000>ooooo`;o00004oooool6o`00
00?ooooo1_l00004ooooo`;o000000?oooooo`000?l000001Ol0000Kooooo`?o00009?ooool2o`00
00Cooooo0_l00002ooooo`;o0000H_ooool001cooooo00?o0000ooooooooool0GOooool2o`0000Oo
oooo0ol0000:ooooo`;o00002_ooool2o`0000Cooooo1_l00003ooooo`So000000?oooooo`000?l0
00006oooool2o`0002Gooooo0ol00007ooooo`;o0000H_ooool001cooooo00?o0000ooooooooool0
>_ooool2o`00027ooooo0_l00006ooooo`Co000000?oooooo`000?l000001oooool5o`0000Oooooo
0_l00002ooooo`;o000000?oooooo`000?l000004ol00011ooooo`;o00000_ooool2o`0000Gooooo
0_l0001Pooooo`007?ooool00ol0003oooooooooo`0jooooo`;o00008_ooool3o`0000Cooooo0_l0
0003ooooo`;o00002Oooool3o`0000Sooooo0_l000001?oooooo0000o`000?ooool=o`0000;ooooo
3?l00005ooooo`;o0000>?ooool2o`0000Gooooo0_l0001Pooooo`007?ooool2o`0005[ooooo0_l0
0003ooooo`Ko00003_ooool2o`0000Oooooo0_l00003ooooo`Co000000Coooooo`000?l0003ooooo
6Ol00005ooooo`;o00000_ooool2o`0009gooooo000Looooo`03o`000?oooooooooo05;ooooo0_l0
0005ooooo`;o000000?oooooo`000?l000000oooool3o`0000Oooooo0_l00005ooooo`;o00001ooo
ool2o`0000Gooooo0_l000000ooooooo0000o`00000Co`000003ooooool0003o000000gooooo1?l0
0006ooooo`;o0000;oooool3o`00067ooooo000Looooo`03o`000?oooooooooo05;ooooo0_l00000
0ooooooo0000o`000005ooooo`;o00003Oooool3o`0000kooooo1?l000000ooooooo0000o`00000D
o`000003ooooool0003o000001;ooooo0_l00006ooooo`;o0000;_ooool4o`00067ooooo000Loooo
o`03o`000?oooooooooo04oooooo0_l000001?oooooo0000o`000?ooool2o`0000Gooooo0_l0000>
ooooo`;o00001?ooool3o`0000Oooooo1ol000000ooooooo0000o`000008o`0000;ooooo2ol00006
ooooo`;o00002_ooool2o`0002?ooooo0_l0000@ooooo`;o000000?oooooo`000?l000004_ooool2
o`0004cooooo000Looooo`03o`000?oooooooooo04oooooo1?l00009ooooo`;o00005?ooool3o`00
00_ooooo1Ol000000ooooooo0000o`000005o`000003ooooool0003o000000_o00001_ooool2o`00
00Oooooo0_l000000ooooooo0000o`000005ooooo`;o00007?ooool4o`00017ooooo1?l0000@oooo
o`;o0000C?ooool001cooooo00?o0000ooooooooool0DOooool2o`0000_ooooo0ol000000ooooooo
0000o`00000<ooooo`;o00002_ooool2o`0000;ooooo1Ol000000ooooooo0000o`00000Co`0000Co
oooo0_l00009ooooo`;o000000?oooooo`000?l000001Oooool2o`0001kooooo0_l0000:ooooo`;o
00001_ooool3o`0005kooooo000Looooo`03o`000?oooooooooo03;ooooo0_l0000>ooooo`;o0000
6_ooool3o`000003ooooool0003o000000cooooo0_l0000:ooooo`;o000000Goooooo`000?l0003o
0000ooooo`0?o`000003ooooool0003o000000Ko00001?ooool2o`0000cooooo0_l00003ooooo`;o
0000:Oooool2o`000003ooooool0003o000000Kooooo0_l0001Oooooo`007?ooool00ol0003ooooo
ooooo`0booooo`;o00003_ooool2o`0001Wooooo0_l00005ooooo`;o00006Oooool2o`000003oooo
ool0003o000001Go000000Coooooo`000?l0003o00000_ooool2o`00017ooooo0_l0000Gooooo`;o
00004?ooool2o`0000Sooooo1?l0001Nooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o0000
3oooool2o`0000Gooooo0_l0000:ooooo`;o00003Oooool2o`000003ooooool0003o000001go0000
:_ooool2o`0000Kooooo0_l0000Booooo`Co00004oooool2o`0004Wooooo000Looooo`03o`000?oo
oooooooo04cooooo0ol00003ooooo`;o00002Oooool2o`00017ooooo0_l00002ooooo`;o00002Ooo
ool2o`000003ooooool0003o000001_o0000=?ooool2o`0000_ooooo1_l00007ooooo`;o00003ooo
ool2o`0004Wooooo000Looooo`03o`000?oooooooooo04gooooo0_l00003ooooo`;o00002Oooool2
o`0000Cooooo0_l0000?ooooo`;o00002Oooool2o`000003ooooool0003o000001[o0000;Oooool2
o`0000Kooooo0_l00002ooooo`?o00001_ooool6o`0000Gooooo1?l0001Jooooo`007?ooool00ol0
003oooooooooo`1Booooo`;o00003oooool2o`0001Kooooo0_l00002ooooo`;o000000?oooooo`00
0?l000006?l00002ooooo`;o000000Coooooo`000?l0003o00009_ooool3o`0000[ooooo1Ol00002
ooooo`Co00002Oooool2o`0001?ooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`1Coooo
o`;o00003_ooool2o`0001Kooooo0_l00002ooooo`;o000000?oooooo`000?l000005ol000000ooo
oooo0000o`000002o`000004ooooool0003o0000o`0000oooooo0_l00005ooooo`;o00000_ooool2
o`0000[ooooo0_l00008ooooo`;o000000Coooooo`000?l0003ooooo0ol000000ooooooo0000o`00
0002o`0000?ooooo0_l0000Iooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0A_ooool2
o`0000[ooooo0ol0000:ooooo`?o00005Oooool2o`0000Kooooo2ol000000ooooooo0000o`000006
o`000003ooooool0003o000000Go000000Coooooo`000?l0003ooooo0_l0000Booooo`;o00001Ooo
ool2o`0000;ooooo0_l00004ooooo`;o00003_ooool2o`0000Cooooo1_l00005ooooo`;o00000ooo
ool4o`0000?ooooo0_l0000>ooooo`;o00001?ooool2o`00043ooooo000Looooo`03o`000?oooooo
oooo02kooooo0_l0000Dooooo`Co00001Oooool2o`0000?ooooo0ol0000:ooooo`Go00000oooool4
o`0000cooooo0_l00007oooooaCo000000?oooooo`000?l000001Ol00003ooooo`;o00000_ooool2
o`0000Wooooo0ol0000Cooooo`;o00000_ooool2o`0000?ooooo0ol00004ooooo`?o00001_ooool2
o`0000_ooooo1Ol00002ooooo`;o00003_ooool2o`0000Cooooo0_l00010ooooo`007?ooool00ol0
003oooooooooo`0^ooooo`;o00005?ooool2o`0000Oooooo0_l00002ooooo`Co00002_ooool7o`00
0003ooooool0003o000000;o00003?ooool2o`0000Oooooo7?l00007ooooo`;o00002Oooool3o`00
00Kooooo0_l0000;ooooo`;o00000_ooool2o`0000?ooooo1?l00003ooooo`?o00005?ooool4o`00
00Cooooo0_l0001Dooooo`007?ooool2o`0005;ooooo0_l0000>ooooo`;o000000?oooooo`000?l0
00002oooool3o`0000?ooooo0_l00007ooooo`;o00000_oooolHo`0000gooooo0ol00008ooooo`Oo
00002Oooool2o`0000Sooooo0ol00006ooooo`;o00001oooool3o`00013ooooo0_l0001Dooooo`00
7?ooool00ol0003oooooooooo`1Aooooo`;o00001oooool2o`0000Gooooo0_l000000ooooooo0000
o`00000;ooooo`Co00000_ooool2o`0000?ooooo0_l00005ooooo`Wo000000?oooooo`000?l00000
2Ol000001?oooooo0000o`000?l00002ooooo`;o00001?ooool2o`0000?ooooo0ol00008ooooo`?o
00000_ooool4o`0000?ooooo0_l00008ooooo`;o00000_ooool2o`0000Kooooo0ol00007ooooo`?o
00004?ooool2o`0005Cooooo000Looooo`03o`000?oooooooooo057ooooo0ol00006ooooo`?o0000
0_ooool3o`0000;ooooo0_l00009ooooo`;o000000Coooooo`000?l0003o00000_ooool4o`000003
ooooool0003o000000Cooooo5_l000001?oooooo0000o`000?ooool4o`0000Cooooo0_l0000;oooo
o`;o00000_ooool2o`0000Cooooo0_l00003ooooo`;o00001_ooool4o`0000Cooooo0_l00004oooo
o`;o00002?ooool2o`00017ooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o
00001?ooool3o`0000Oooooo0_l00002ooooo`?o00000_ooool2o`0000Sooooo0ol00007ooooo`?o
00001oooool2o`000003ooooool0003o000001Co000000?oooooo`000?l000004oooool3o`0000?o
oooo0_l00006ooooo`;o00001_ooool3o`0000Kooooo0_l0000?ooooo`;o0000I_ooool001cooooo
00?o0000ooooooooool0:Oooool2o`0001Sooooo0_l00005ooooo`Co00000oooool2o`00017ooooo
0_l00008ooooo`;o00001Oooool2o`0000kooooo5_l000000ooooooo0000o`000009ooooo`;o0000
2Oooool2o`0000?ooooo0_l00006ooooo`;o00001_ooool2o`0000[ooooo0_l00004ooooo`;o0000
00Coooooo`000?l0003ooooo1Ol0000Aooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0
:Oooool2o`0001Sooooo0_l00005ooooo`Co00001Oooool2o`0000kooooo0_l00009ooooo`;o0000
1Oooool2o`0000oooooo4ol00006ooooo`;o00001Oooool5o`0000Oooooo1?l00007ooooo`;o0000
5?ooool2o`000004ooooool0003o0000ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooo
oooo0000o`000004o`0000gooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`1:ooooo`Co
00001Oooool2o`0000?ooooo0_l00009ooooo`;o00000oooool2o`0000Gooooo0_l0000Eooooo`co
000000?oooooo`000?l000001_l00004ooooo`?o00001?ooool2o`000003ooooool0003o000000Oo
oooo1?l00007ooooo`;o00002Oooool2o`0000_ooooo0ol00009ooooo`;o000000?oooooo`000?l0
00000_l0000>ooooo`;o0000DOooool001cooooo00?o0000ooooooooool0B_ooool2o`0000cooooo
0_l0000>ooooo`;o00001Oooool2o`0000oooooo0_l00002ooooo`;o000000?oooooo`000?l00000
0ol000000ooooooo0000o`000003o`000003ooooool0003o000000;o000000?oooooo`000?l00000
0ol00003ooooo`?o00009Oooool2o`0000_ooooo0_l0000:ooooo`;o00003oooool2o`0000;ooooo
0_l0001Aooooo`007?ooool00ol0003oooooooooo`1Hooooo`Co00000oooool2o`0000Cooooo0_l0
0002ooooo`Co00001?ooool2o`0000gooooo0_l00002ooooo`;o000000?oooooo`000?l000003ol0
0003ooooo`;o00001?ooool2o`0000Gooooo1Ol00002ooooo`;o00005_ooool2o`0000gooooo0_l0
000Jooooo`;o00002oooool2o`0004Sooooo000Looooo`03o`000?oooooooooo047ooooo0_l00004
ooooo`;o00003oooool5o`0000;ooooo0ol00003ooooo`;o00000_ooool4o`000004ooooool0003o
0000ooooo`;o00005?ooool2o`000003ooooool0003o000000oo00001Oooool2o`0000Kooooo1Ol0
0002ooooo`;o00004?ooool2o`0000Cooooo0_l000000ooooooo0000o`00000:ooooo`;o00005_oo
ool2o`0000oooooo0ol00017ooooo`007?ooool00ol0003oooooooooo`0Uooooo`;o00006_ooool2
o`0000Cooooo0_l0000Aooooo`?o00000oooool3o`0000_ooooo0_l00006ooooo`;o00000oooool2
o`0000Cooooo1Ol00005ooooo`Co00000_ooool6o`000005ooooool0003o0000o`000?ooool00_l0
0002ooooo`;o00001?ooool2o`0001?ooooo0_l00004ooooo`;o00001oooool2o`000003ooooool0
003o000001_ooooo0_l00002ooooo`;o00004?ooool2o`0000Gooooo0_l00010ooooo`007?ooool0
0ol0003oooooooooo`0Uooooo`;o00007oooool3o`0000Cooooo0_l0000?ooooo`;o000000?ooooo
o`000?l000002?ooool2o`0000Wooooo0_l00002ooooo`?o00001?ooool5o`0000Cooooo0_l00000
1?oooooo0000o`000?ooool2o`0000;ooooo1?l00004ooooo`;o00002?ooool3o`0001;ooooo0_l0
0004ooooo`Ko00001Oooool5o`0001Wooooo0_l0000<ooooo`;o00001oooool2o`0000Cooooo0_l0
0010ooooo`007?ooool00ol0003oooooooooo`13ooooo`;o000000?oooooo`000?l000000ol00002
ooooo`;o00003oooool2o`0000Sooooo1Ol00006ooooo`;o00001Oooool4o`0000Kooooo0_l00004
ooooo`;o000000?oooooo`000?l000002Ol0000?ooooo`;o00001_ooool2o`0000[ooooo0_l00004
ooooo`Oo00001?ooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`00023ooooo0_l0
0007ooooo`;o00002?ooool2o`0003cooooo000Looooo`03o`000?oooooooooo04?ooooo0_l00003
ooooo`Go00004?ooool2o`0000Kooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o
000000;ooooo1Ol00006ooooo`;o00001Oooool4o`0000;ooooo0ol00002ooooo`So00002?ooool2
o`0000Oooooo0_l00006ooooo`;o000000?oooooo`000?l000000_l00005ooooo`;o00001Oooool2
o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo0_l00005
ooooo`Co00008?ooool2o`0000Cooooo0_l00002ooooo`;o0000??ooool00006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oo
oooooooo04Sooooo0_l000000ooooooo0000o`000005ooooo`;o00002?ooool4o`0000Gooooo0_l0
0006ooooo`;o00000_ooool5o`0000gooooo1Ol000000ooooooo0000o`000007ooooo`;o00001?oo
ool2o`0000Cooooo0_l00003ooooo`;o00002_ooool8o`0000?ooooo0_l00003ooooo`;o00002_oo
ool2o`0000Gooooo0_l00002ooooo`;o00001Oooool5o`0001oooooo0_l00004ooooo`;o0000@?oo
ool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0mooooo`;o00004oooool3o`0000Oooooo1?l0000=ooooo`;o0000
2_ooool2o`0000;ooooo1?l00002ooooo`Go00000oooool2o`000003ooooool0003o000000Sooooo
0_l00004ooooo`;o00000oooool2o`0000_ooooo1ol000000ooooooo0000o`000002o`0000?ooooo
0_l00002ooooo`?o00001_ooool2o`0000?ooooo0_l00003ooooo`;o00001_ooool4o`0001;ooooo
0_l00003ooooo`;o00003Oooool2o`0003oooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oo
oooooooo00Wooooo1Ol00006ooooo`03o`000?oooooooooo03gooooo0_l0000<ooooo`;o00001_oo
ool2o`0000Kooooo0_l00006ooooo`;o00002?ooool2o`000003ooooool0003o000000Gooooo1?l0
0002ooooo`Co00000_ooool2o`0000Gooooo0ol000000ooooooo0000o`00000>ooooo`;o00001?oo
ool2o`0000;ooooo0_l00007ooooo`Ko000000?oooooo`000?l000001Oooool7o`000003ooooool0
003o000000Go00000oooool2o`0000Oooooo0_l00003ooooo`;o00004Oooool4o`0000?ooooo0ol0
000<ooooo`;o0000?oooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool0
1?m4A4CogMgMooooool00007ooooo`?o0000?Oooool2o`0000cooooo0_l00002ooooo`;o00000ooo
ool3o`0000Cooooo0_l00006ooooo`;o00002oooool2o`0000;ooooo0_l000000ooooooo0000o`00
0004ooooo`;o000000?oooooo`000?l000000ol00002ooooo`;o000000Coooooo`000?l0003o0000
4Oooool2o`0000Cooooo1_l00006ooooo`;o00000oooool6o`0000Cooooo3ol00002ooooo`;o0000
0oooool2o`0000?ooooo0_l0000Fooooo`?o00001Oooool2o`0004gooooo00000ooooooo0000oooo
o`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003ooooo
ooooo`13ooooo`?o00001_ooool2o`000003ooooool0003o000000?ooooo0ol00004ooooo`;o0000
1_ooool2o`0000oooooo1Ol00002ooooo`;o00000oooool4o`0000?ooooo1_l00006ooooo`;o0000
2?ooool3o`0000Kooooo0_l00008ooooo`;o00000ooooolMo`0000;ooooo0ol00005ooooo`;o0000
00Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00000<ooooo`;o00003oooool2o`0004?o
oooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oMgMgolc<c?l00000
1oooool00ol0003oooooooooo`13ooooo`Co00001Oooool2o`000003ooooool0003o000000Cooooo
0_l0000;ooooo`Co00003?ooool7o`0000;ooooo0_l00005ooooo`;o00001Oooool2o`0000Sooooo
0_l00007ooooo`?o00001?ooool2o`0000;ooooo0_l00007ooooo`Co000000?oooooo`000?l00000
0ol000000ooooooo0000o`000003o`000003ooooool0003o000000;ooooo2?l000000ooooooo0000
o`000002o`0000;ooooo0ol00005ooooo`;o000000Coooooo`000?l0003ooooo0_l000001?oooooo
0000o`000?ooool2o`00017ooooo0_l00007ooooo`;o0000@oooool00006oooooomgMgOoV9RHoooo
oonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo04?ooooo1?l00007
ooooo`?o00001?ooool4o`0000Wooooo1?l00006ooooo`;o00001?ooool4o`0000cooooo0_l00003
ooooo`;o00004oooool2o`0000Gooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo2ol00003
ooooo`oo000000Goooooo`000?l0003o0000ooooo`05o`000004ooooool0003o0000ooooo`?o0000
2_ooool2o`0000Kooooo0ol00008ooooo`;o00003Oooool2o`0003gooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`13ooooo`;o
000000?oooooo`000?l000001_ooool2o`0000Oooooo0ol00009ooooo`?o00001?ooool4o`0000Go
oooo0ol000001?oooooo0000o`000?l00004ooooo`;o00000_ooool2o`0000?ooooo0_l00007oooo
o`;o00000_ooool2o`0000;ooooo0_l0000Booooo`;o00000_ooool3o`000003ooooool0003o0000
00Go00001?oooolBo`000003ooooool0003o000000Cooooo0_l000001?oooooo0000o`000?l0000>
ooooo`;o00000_ooool3o`0001Oooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0ioooo
o`;o00002oooool2o`0000kooooo1?l0000:ooooo`;o00001?ooool2o`0000?ooooo0_l000000ooo
oooo0000o`000003ooooo`?o00001?ooool2o`0000;ooooo0_l00004ooooo`?o000000?oooooo`00
0?l000000_ooool6o`000003ooooool0003o000000;o00000oooool2o`000004ooooool0003o0000
ooooo`;o00001_ooool2o`0000;ooooo0ol000000ooooooo0000o`00000Ho`000003ooooool0003o
000000?o00001?ooool2o`000003ooooool0003o000000Go00002_ooool2o`0000?ooooo0_l0001F
ooooo`007?ooool00ol0003oooooooooo`0Nooooo`;o00005Oooool2o`0000;ooooo0_l0000Doooo
o`;o00001Oooool4o`0000[ooooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l000001?oo
oooo0000o`000?ooool2o`0000;ooooo1?l00004ooooo`;o00001Oooool3o`000003ooooool0003o
000000Cooooo0_l00003ooooo`Co00000oooool2o`000004ooooool0003o0000ooooo`;o00001ooo
ool2o`000005ooooool0003o0000o`000?ooool00_l000000ooooooo0000o`00000Eo`000003oooo
ool0003o000000?o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000005o`0000Co
oooo0_l00004ooooo`;o00000_ooool2o`0005Oooooo000Looooo`03o`000?oooooooooo01kooooo
0_l0000Eooooo`;o00004oooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`?o0000
00?oooooo`000?l000000_ooool2o`0000Oooooo1?l00007ooooo`Go00000_ooool6o`0000;ooooo
0ol0000Looooo`;o00002?ooool7o`000003ooooool0003o000000Oo000000?oooooo`000?l00000
6Ol00004ooooo`So00000oooool3o`0000Oooooo0ol00007ooooo`;o00000oooool2o`0004Sooooo
000Looooo`03o`000?oooooooooo03Sooooo0_l0000@ooooo`;o00001_ooool3o`0000;ooooo0_l0
00000ooooooo0000o`000002ooooo`;o00004_ooool5o`0000Cooooo1?l00003ooooo`;o00004_oo
ool2o`0000Sooooo0_l00008ooooo`?o00000_ooool2o`000003ooooool0003o000002?o00000_oo
ool5o`0000?ooooo0_l00004ooooo`;o00000_ooool2o`0000Cooooo0_l00003ooooo`;o00000_oo
ool3o`0000;ooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00006?ooool3
o`0000Cooooo0_l00006ooooo`;o00000_ooool3o`0000[ooooo0_l000001?oooooo0000o`000?l0
0003ooooo`;o00006?ooool4o`0001;ooooo0_l00004ooooo`;o00000_ooool2o`000003ooooool0
003o0000013o000000?oooooo`000?l000002_l00002ooooo`;o00002_ooool2o`0000?ooooo0ol0
0009ooooo`;o00000oooool2o`0000Kooooo0ol00005ooooo`;o0000??ooool001cooooo00?o0000
ooooooooool0Eoooool4o`000003ooooool0003o000000?ooooo0_l00002ooooo`?o00002_ooool2
o`000004ooooool0003o0000o`0000?ooooo1ol00002ooooo`;o00003oooool4o`0000?ooooo0_l0
000=ooooo`;o00001?ooool2o`0000;ooooo8_l00002ooooo`;o00002_ooool2o`000003ooooool0
003o000000;o00002oooool2o`0000[ooooo0ol00005ooooo`;o0000??ooool001cooooo00?o0000
ooooooooool0Eoooool2o`0000?ooooo1?l00007ooooo`;o00003Oooool3o`0000?ooooo1_l00002
ooooo`;o00000oooool2o`00017ooooo0_l00002ooooo`;o00000oooool2o`0000Gooooo0_l00009
oooooaoo00004_ooool2o`0000gooooo0_l000000ooooooo0000o`00001=ooooo`007?ooool00ol0
003oooooooooo`0gooooo`;o00002oooool2o`0000[ooooo0_l0000<ooooo`;o00001oooool2o`00
00gooooo0ol00003ooooo`;o00001?ooool2o`0000Gooooo0_l0000Eooooo`;o00000oooool2o`00
00Gooooo;?l0000Fooooo`;o00002_ooool2o`0000Wooooo0_l00012ooooo`007?ooool00ol0003o
ooooooooo`0Kooooo`;o00006_ooool2o`0000_ooooo0_l00006ooooo`;o00000_ooool2o`0000Wo
oooo0_l0000>ooooo`?o00000_ooool2o`0000gooooo0_l000000ooooooo0000o`00000Tooooo`;o
00000_oooolUo`000003ooooool0003o000000Ko00000_ooool2o`0000;ooooo0_l0000<ooooo`;o
00002_ooool2o`0000Wooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`0Kooooo`;o0000
9oooool2o`000003ooooool0003o000000?ooooo0_l000001?oooooo0000o`000?l00002ooooo`;o
00001Oooool2o`000003ooooool0003o000000Cooooo0_l00005ooooo`?o00000_ooool7o`0000So
oooo0_l000000ooooooo0000o`00000Tooooo`;o00000_ooool2o`000005ooooool0003o0000o`00
0?ooool09ol00002ooooo`;o000000?oooooo`000?l000001?l00007ooooo`;o00002_ooool4o`00
0003ooooool0003o000000Kooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`0nooooo`?o
00000oooool2o`000003ooooool0003o000000?ooooo0_l000001?oooooo0000o`000?l00002oooo
o`;o00002?ooool2o`0000Cooooo0_l0000:ooooo`Oo00002?ooool2o`000004ooooool0003o0000
o`0001Wooooo0_l00004ooooo`;o00002OoooolPo`000005ooooool0003o0000o`000?ooool04Ol0
0007ooooo`;o00001oooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000002Ooo
ool2o`0003oooooo000Looooo`;o0000??ooool2o`000004ooooool0003o0000o`0000_ooooo0_l0
0003ooooo`;o00002_ooool2o`00023ooooo0_l000001?oooooo0000o`000?l0000Iooooo`;o0000
1?ooool2o`0000Cooooo0_l00003ooooo`Co00000_ooool:o`000003ooooool0003o000001go0000
00?oooooo`000?l000000_l00008ooooo`;o00001oooool2o`000003ooooool0003o000000?o0000
0_ooool3o`0000Kooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00002_oo
ool3o`0000gooooo1?l00003ooooo`;o00000oooool2o`0000Gooooo0_l00005ooooo`;o00003?oo
ool2o`00013ooooo0_l0000Hooooo`Co000000Coooooo`000?l0003o00001?ooool2o`0000Cooooo
0_l00003ooooob[o000000?oooooo`000?l000002?ooool4o`0000?ooooo0_l00003ooooo`Co0000
00?oooooo`000?l000000_ooool3o`0000Kooooo0_l0000oooooo`007?ooool00ol0003ooooooooo
o`0^ooooo`;o00002_ooool2o`0000Kooooo0_l00003ooooo`So00001oooool2o`0000[ooooo1?l0
0004ooooo`?o00001Oooool2o`00013ooooo1?l0000:ooooo`;o00003?ooool2o`000004ooooool0
003o0000o`0000Sooooo1?l00003oooooaco000000?oooooo`000?l000002ol00002ooooo`;o0000
1oooool2o`0000Gooooo0ol00002ooooo`;o00001_ooool2o`0000Sooooo0_l0000oooooo`007?oo
ool00ol0003oooooooooo`12ooooo`;o00000_ooool<o`000004ooooool0003o0000o`0000[ooooo
1Ol00005ooooo`?o00004?ooool4o`0000Gooooo0_l00003ooooo`;o00001Oooool2o`0000;ooooo
0_l0000;ooooo`?o00002?ooool7o`000003ooooool0003o000001Wo000000?oooooo`000?l00000
1?l000000ooooooo0000o`000003o`0000?ooooo1?l0000=ooooo`Co000000?oooooo`000?l00000
0oooool4o`0000_ooooo0_l0000looooo`007?ooool00ol0003oooooooooo`10oooooaKo00001ooo
ool2o`000004ooooool0003o0000ooooo`;o00006?ooool4o`0000Wooooo0ol00009ooooo`;o0000
1Oooool4o`0000;ooooo0_l0000;ooooo`Go000000?oooooo`000?l000008?l00002ooooo`Co0000
1?ooool3o`0000oooooo0_l000000ooooooo0000o`000003ooooo`;o00003Oooool2o`0003cooooo
000Looooo`03o`000?oooooooooo043ooooo5Ol00008ooooo`Co00001?ooool2o`00023ooooo0_l0
00000ooooooo0000o`00000Aooooo`Co00003oooool4o`000003ooooool0003o000002?o00000_oo
ool2o`000003ooooool0003o000000?o000000Coooooo`000?l0003ooooo0_l0000<ooooo`;o0000
00?oooooo`000?l00000C_ooool001cooooo00?o0000ooooooooool0>Oooool2o`0000;ooooo0_l0
0004oooooa;o00002_ooool2o`0000Cooooo0_l00005ooooo`;o00000_ooool2o`0001Gooooo0_l0
000Cooooo`Co00002oooool2o`0000;ooooo8Ol000000ooooooo0000o`000007o`000005ooooool0
003o0000o`000?ooool00ol00003ooooo`;o000000?oooooo`000?l000003?ooool5o`000005oooo
ool0003o0000o`000?ooool00_l00017ooooo`007?ooool00ol0003oooooooooo`0Hooooo`;o0000
7oooool6o`000003ooooool0003o000000;ooooo4Ol0000=ooooo`;o00002?ooool2o`0000;ooooo
0_l0000Pooooo`;o00002?ooool2o`0000gooooo0_l00002ooooo`;o00000_ooool3o`000003oooo
ool0003o000001Ko000000?oooooo`000?l000002?l000001?oooooo0000o`000?l0000:ooooo`;o
00003_ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000001_ooool2o`0003oo
oooo000Looooo`03o`000?oooooooooo01Sooooo0_l0000Qooooo`Oo00000oooool?o`0000kooooo
0_l00005ooooo`Go00005_ooool2o`0000Cooooo0ol00005ooooo`;o000000?oooooo`000?l00000
3?ooool2o`0000Gooooo0_l00004ooooo`Go000000?oooooo`000?l000003Ol000000ooooooo0000
o`000007o`000003ooooool0003o000000[o00001?ooool2o`0000Cooooo1Ol00004ooooo`;o0000
1_ooool7o`000003ooooool0003o000000Oooooo0_l0000oooooo`007?ooool00ol0003ooooooooo
o`0mooooo`Go00000oooool?o`000003ooooool0003o000000Oooooo0_l00005ooooo`;o00000_oo
ool6o`0000;ooooo1?l0000?ooooo`;o00001?ooool4o`0000Oooooo0_l0000;ooooo`?o00001Ooo
ool2o`0000?ooooo1Ol00002ooooobKo00000oooool3o`0000Cooooo1Ol00004ooooo`;o00001_oo
ool7o`000003ooooool0003o000000[ooooo0_l0000looooo`007?ooool00ol0003oooooooooo`16
ooooo`go00000_ooool2o`0000Oooooo0_l00005ooooo`;o000000?oooooo`000?l000000oooool2
o`0000;ooooo1?l000000ooooooo0000o`000006ooooo`;o00002?ooool2o`000004ooooool0003o
0000o`00013ooooo0_l00002ooooo`Co00000_ooool2o`0000Gooooo1_l000000ooooooo0000o`00
000Zo`0000?ooooo0_l00002ooooo`;o00002oooool5o`000004ooooool0003o0000o`0000Gooooo
0_l00004ooooo`?o0000??ooool001cooooo00?o0000ooooooooool0??ooool2o`0000Cooooo0_l0
0003oooooa7o00003Oooool2o`000004ooooool0003o0000o`0000Sooooo1ol00004ooooo`;o0000
2?ooool2o`000003ooooool0003o000000Go00002?ooool2o`0000;ooooo0_l00002ooooo`Co0000
0_ooool2o`0000Cooooo0_l00003ooooo`;o000000?oooooo`000?l000002ol00002oooooago0000
0oooool2o`0000oooooo1Ol000001?oooooo0000o`000?l00005ooooo`;o00000oooool3o`0003go
oooo000Looooo`03o`000?oooooooooo01Wooooo0_l0000Qooooo`;o00001?ooool2o`0000Cooooo
4?l0000=ooooo`;o00000_ooool2o`0000Cooooo0_l00002ooooo`Oo000000?oooooo`000?l00000
4?ooool5o`0000Cooooo0_l00002ooooo`;o00001_ooool2o`0000;ooooo0_l00003ooooo`Go0000
0_ooool2o`000003ooooool0003o000000;ooooo8Ol00002ooooo`;o00003?ooool2o`0000Cooooo
0_l0000;ooooo`;o00000_ooool3o`0000Gooooo0_l0000nooooo`007?ooool00ol0003ooooooooo
o`0Iooooo`;o0000;?ooool2o`000003ooooool0003o000000Go000000?oooooo`000?l000000_oo
ool2o`0000_ooooo0_l00009ooooo`Co000000?oooooo`000?l000001?l000001?oooooo0000o`00
0?l0000Iooooo`;o000000?oooooo`000?l000002oooool2o`0000?ooooo0ol00004ooooo`Go0000
0_oooolOo`0000;ooooo1_l00002ooooo`;o00001_ooool2o`0000Cooooo0_l0000>ooooo`Co0000
0_ooool2o`0001?ooooo0_l0000/ooooo`007?ooool00ol0003oooooooooo`17ooooo`;o00001?oo
ool6o`0000?ooooo0_l0000;ooooo`;o00002?ooool@o`0001;ooooo0_l00003ooooo`;o00000ooo
ool2o`0000Kooooo0_l00008ooooo`;o00001_ooool3o`000004ooooool0003o0000oooooa3o0000
00?oooooo`000?l000002Ol00004ooooo`Ko00000_ooool2o`0000Oooooo0_l00006ooooo`;o0000
00?oooooo`000?l000001_ooool4o`0000Cooooo0_l00006ooooo`;o00002oooool2o`0002cooooo
000Looooo`03o`000?oooooooooo02_ooooo0_l0000Aooooo`Co000000?oooooo`000?l000003?oo
ool2o`0000Oooooo0_l000000ooooooo0000o`000005ooooo`;o00001_ooool3o`000003ooooool0
003o000000go000000?oooooo`000?l000003Oooool2o`000003ooooool0003o000000?o00000_oo
ool2o`0000Kooooo0_l0000@ooooo`;o000000?oooooo`000?l000001?l00003ooooo`;o000000?o
ooooo`000?l000001_l00002ooooo`[o000000Coooooo`000?l0003ooooo1?l0000=ooooo`;o0000
0oooool2o`000004ooooool0003o0000ooooo`;o00001_ooool2o`0000kooooo0_l0000iooooo`00
7?ooool2o`0002cooooo0_l00009ooooo`;o00001_ooool4o`000003ooooool0003o000001Gooooo
0_l000000ooooooo0000o`000005ooooo`;o00001_ooool3o`000004ooooool0003o0000ooooo`co
000000?oooooo`000?l000004?ooool5o`0000;ooooo0_l0000Booooo`;o00001?ooool2o`000004
ooooool0003o0000ooooo`?o00001?ooool:o`0000;ooooo2_l000001?oooooo0000o`000?ooool4
o`0000Wooooo0_l00006ooooo`Oo0000Doooool001cooooo00?o0000ooooooooool06_ooool2o`00
01[ooooo0_l00007ooooo`Co00005_ooool2o`0000gooooo0_l00002oooooa7o00000_ooool2o`00
00[ooooo0_l00003ooooo`;o00000oooool2o`0000;ooooo0_l00005ooooo`?o00001?ooool2o`00
00Cooooo0_l00003ooooo`;o00001_ooool5o`000003ooooool0003o0000017o000000?oooooo`00
0?l000001_ooool2o`000003ooooool0003o000000Kooooo0_l00006ooooo`;o000000?oooooo`00
0?l000000_l00007ooooo`Co0000B?ooool001cooooo00?o0000ooooooooool06_ooool2o`0001go
oooo0_l00002ooooo`;o000000Coooooo`000?l0003o00004Oooool2o`0000?ooooo0ol0000<oooo
o`;o000000?oooooo`000?l000005?l000000ooooooo0000o`000007ooooo`?o000000Coooooo`00
0?l0003o00000oooool2o`0000;ooooo0_l00005ooooo`?o000000?oooooo`000?l000000ol00009
ooooo`;o00001ooooolHo`0000Kooooo0_l00004ooooo`;o00003?ooool4o`0000Oooooo0_l00003
ooooo`Ko0000A_ooool001cooooo00?o0000ooooooooool0>Oooool6o`0001Gooooo0_l00004oooo
o`;o000000?oooooo`000?l000002Oooool2o`000003ooooool0003o000001?o00000_ooool2o`00
0003ooooool0003o000000Gooooo0_l000000ooooooo0000o`000003ooooo`Co00003?ooool3o`00
00gooooo0_l00006ooooo`Ko00000_ooool2o`000003ooooool0003o000000Oo000000?oooooo`00
0?l000000_ooool3o`000004ooooool0003o0000ooooo`;o00001oooool2o`0000Kooooo0_l00009
ooooo`;o00001oooool3o`0004Gooooo000Looooo`03o`000?oooooooooo03Wooooo1?l0000Doooo
o`Go00001oooool4o`0000Oooooo6?l00003ooooo`Co00001Oooool2o`000005ooooool0003o0000
o`000?ooool01Ol000000ooooooo0000o`00000:ooooo`Co00000oooool2o`0000?ooooo0_l00000
1?oooooo0000o`000?l00005ooooo`;o00000_ooool6o`0000;ooooo1?l000001Ooooooo0000o`00
0?l0003ooooo00?o000000Coooooo`000?l0003o00001?ooool2o`0000Oooooo0ol00008ooooo`;o
00001_ooool2o`0000Kooooo1?l00015ooooo`007?ooool00ol0003oooooooooo`1Aooooo`?o0000
2oooool2o`0000?ooooo0_l00004oooooaKo00000oooool2o`0000Oooooo0_l000000ooooooo0000
o`000006o`0000;ooooo0_l00003ooooo`;o00001Oooool4o`0000?ooooo0_l00003ooooo`;o0000
0_ooool2o`0000?ooooo1?l00003ooooo`Co00001?ooool3o`000004ooooool0003o0000ooooo`Co
00000_ooool2o`0000;ooooo1?l00008ooooo`;o00000oooool4o`000003ooooool0003o000000Co
oooo1?l00005ooooo`?o00001?ooool4o`0003oooooo000Looooo`03o`000?oooooooooo01[ooooo
0_l0000Sooooo`;o00002oooool2o`0001Gooooo0ol00004oooooaKo00000oooool2o`0000_ooooo
1?l0000:ooooo`;o00001Oooool2o`0000;ooooo0_l0000=ooooo`Go00001?ooool6o`0000;ooooo
0ol000000ooooooo0000o`000003o`0000Sooooo1?l0000=ooooo`Ko000000?oooooo`000?l00000
0_ooool4o`0000Gooooo0ol00004ooooo`Co0000?oooool001cooooo00?o0000ooooooooool06_oo
ool2o`0002?ooooo0_l000000ooooooo0000o`000008ooooo`Co00004oooool2o`0000?ooooo6?l0
0003ooooo`;o00002oooool2o`000003ooooool0003o000000Kooooo0_l0000<ooooo`;o00003Ooo
ool5o`0000?ooooo0ol00002ooooo`;o00000oooool2o`000003ooooool0003o000000?o00002?oo
ool2o`0001;ooooo0ol000000ooooooo0000o`000006ooooo`;o0000COooool001cooooo00?o0000
ooooooooool0<oooool2o`0000gooooo0_l0000:ooooo`;o00006?oooolIo`0000;ooooo0_l0000>
ooooo`;o00000_ooool7o`000003ooooool0003o000000Sooooo0_l00005ooooo`;o00001oooool2
o`0000Gooooo0ol00002ooooo`;o00000oooool2o`000004ooooool0003o0000o`0000;ooooo0_l0
0007ooooo`;o00001Oooool2o`0000gooooo0_l00007ooooo`;o000000Coooooo`000?l0003ooooo
0ol00016ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o0000;?ooool2o`0000Kooooo6Ol0
00000ooooooo0000o`00000=ooooo`co000000Coooooo`000?l0003o00000_ooool2o`0000[ooooo
0_l00007ooooo`;o00001_ooool6o`0000?ooooo0_l000001?oooooo0000o`000?l00002ooooo`;o
00001oooool2o`0000Cooooo0ol0000=ooooo`;o00002?ooool4o`000004ooooool0003o0000o`00
00?ooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0Jooooo`;o00005Oooool2o`0000oo
oooo0_l0000Fooooo`;o00001Oooool2o`0000Kooooo6Ol000000ooooooo0000o`00000:ooooo`So
00000_ooool2o`0000Gooooo0_l00002ooooo`;o00000_ooool4o`0000gooooo0_l00006ooooo`Ko
00001oooool2o`00017ooooo0_l00002ooooo`;o000000?oooooo`000?l000004Oooool2o`000003
ooooool0003o000000Kooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0Jooooo`;o0000
5Oooool2o`0000Oooooo0_l00006ooooo`;o00004_ooool2o`0000;ooooo0_l0000=ooooo`;o0000
00?oooooo`000?l000005?l0000:ooooo`;o000000?oooooo`000?l000000ol00004ooooo`;o0000
3?ooool6o`000005ooooool0003o0000o`000?ooool00_l00005ooooo`?o00002Oooool3o`0000?o
oooo0_l00002ooooo`;o00005Oooool2o`000003ooooool0003o000001?ooooo0ol00019ooooo`00
7?ooool00ol0003oooooooooo`0Jooooo`?o00005?ooool2o`0000Oooooo0_l0000Eooooo`;o0000
0oooool2o`0001Cooooo5Ol0000;ooooo`;o00000oooool3o`0000;ooooo1?l0000<ooooo`Go0000
0_ooool3o`000003ooooool0003o000000Gooooo1Ol00007ooooo`Co00000_ooool3o`0000?ooooo
0_l0000;ooooo`;o00001Oooool3o`0001?ooooo0_l000000ooooooo0000o`00000Rooooo`;o0000
9_ooool001cooooo00?o0000ooooooooool06oooool2o`0001Cooooo0_l00002ooooo`;o00006Ooo
ool3o`0000gooooo0_l00008ooooo`oo000000Coooooo`000?l0003ooooo1_l00009ooooo`Co0000
00?oooooo`000?l000000_ooool4o`0000oooooo0ol0000@ooooo`;o00002Oooool2o`0000?ooooo
0_l00003ooooo`;o00000_ooool2o`0000Oooooo0_l00003ooooo`Oo00003oooool8o`0000_ooooo
0_l0000Dooooo`;o00009_ooool001cooooo00?o0000ooooooooool0=Oooool2o`0001Wooooo0_l0
000>ooooo`;o00002?oooolIo`0000Gooooo0_l00002ooooo`Co000000Goooooo`000?l0003o0000
ooooo`05o`0000kooooo0_l00005ooooo`?o00001_ooool2o`0000cooooo0_l00006ooooo`;o0000
0oooool3o`000003ooooool0003o000000Kooooo0_l000000ooooooo0000o`000003ooooo`;o0000
1_ooool2o`0000Oooooo0_l00002ooooo`Go00002_ooool2o`0001?ooooo0_l0000Wooooo`007?oo
ool00ol0003oooooooooo`0aooooo`;o00001oooool2o`0000Kooooo0_l0000Oooooo`;o00001_oo
oolFo`0000Oooooo0_l00008ooooo`;o000000?oooooo`000?l000001Ol000000ooooooo0000o`00
0009ooooo`;o00001Oooool3o`0000Kooooo0_l0000<ooooo`;o00001_ooool4o`000003ooooool0
003o000000;ooooo0_l00006ooooo`Co00003?ooool2o`0000Gooooo0ol00004ooooo`Co00007ooo
ool2o`0002Oooooo000Looooo`;o0000<_ooool4o`0000Gooooo0_l00006ooooo`;o00002oooool2
o`0001;ooooo0_l00003ooooo`;o00000_ooool5o`0000;ooooo3_l0000;ooooo`;o00000_ooool2
o`0000?ooooo1?l000001?oooooo0000o`000?ooool2o`0000_ooooo0_l0000Eooooo`;o00000_oo
ool2o`0000;ooooo0_l00002ooooo`Oo00002oooool4o`0000?ooooo0_l00008ooooo`;o00000_oo
ool5o`0000Cooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00004?ooool2
o`0000Sooooo0_l0000GoooooaWo00002oooool2o`000004ooooool0003o0000o`0000Gooooo0ol0
000=ooooo`;o000000?oooooo`000?l000005Oooool2o`0000;ooooo0_l00002ooooo`?o000000Co
ooooo`000?l0003ooooo1?l00008ooooo`;o00000_ooool3o`0000?ooooo0_l00002ooooo`;o0000
1?ooool2o`0000;ooooo1Ol00007ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0AOoo
ool2o`0002?ooooo5_l0000;ooooo`;o00000_ooool2o`0000Cooooo1_l00003ooooo`;o00001?oo
ool2o`000003ooooool0003o0000013ooooo0_l00006ooooo`;o00001oooool2o`00013ooooo0_l0
0003ooooo`;o00001oooool2o`0000Kooooo0_l00002ooooo`;o00002?ooool2o`0004Oooooo000L
ooooo`03o`000?oooooooooo06[ooooo1Ol00003ooooo`ko00002oooool2o`0000;ooooo0ol00003
ooooo`?o000000?oooooo`000?l000000oooool2o`0000Cooooo0_l00004ooooo`;o00000oooool4
o`0000Kooooo0ol0000@ooooo`Co00006_ooool2o`0000?ooooo0_l000000ooooooo0000o`000003
o`0000Wooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o00001?ooool2o`00
013ooooo0ol000000ooooooo0000o`00000;o`000003ooooool0003o000000oooooo0ol00007oooo
o`Co00001oooool2o`0000Cooooo0_l00003ooooo`Co00001oooool2o`00013ooooo1?l0000Moooo
o`Go00000_ooool3o`0000Wooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`15ooooo`;o
00003Oooool2o`0000Cooooo0_l0000Dooooo`Go00001?ooool4o`0001;ooooo0ol00007ooooo`Co
00001_ooool3o`0001Cooooo0_l0000=ooooo`;o00004?ooool2o`0000oooooo1_l0000Fooooo`Co
0000?Oooool001cooooo00?o0000ooooooooool0AOooool2o`0000Wooooo0_l0000Nooooo`Go0000
1?ooool5o`0000Sooooo0_l0000Kooooo`;o00001Oooool2o`0000kooooo0_l0000=ooooo`;o0000
2?ooool2o`0000;ooooo0_l00002ooooo`;o00003oooool4o`0000;ooooo0_l000000ooooooo0000
o`00000;ooooo`;o00001?ooool4o`0000oooooo0_l0000/ooooo`007?ooool00ol0003ooooooooo
o`0Kooooo`;o00008oooool2o`000003ooooool0003o000000;o00002Oooool2o`0001Wooooo0_l0
0003ooooo`;o00001_ooool2o`0000;ooooo0_l00003ooooo`Co000000?oooooo`000?l000001?oo
ool2o`0000Gooooo0_l00005ooooo`Co00001oooool3o`0000;ooooo0_l00004ooooo`;o00008Ooo
ool2o`0000;ooooo0_l0000@ooooo`;o00000_ooool3o`0000;ooooo0_l000000ooooooo0000o`00
000;ooooo`?o00001?ooool2o`0000[ooooo0_l00004ooooo`;o0000;?ooool001cooooo00?o0000
ooooooooool06oooool2o`0001Kooooo0_l0000;ooooo`;o000000?oooooo`000?l000002oooool2
o`0001Wooooo0_l0000:ooooo`?o00001oooool5o`0000Kooooo0_l00005ooooo`;o00001Oooool4
o`0000Oooooo0ol00008ooooo`;o00000oooool2o`0000Kooooo0_l00003ooooo`;o00001?ooool2
o`0000;ooooo0_l00009ooooo`;o00001Oooool2o`0000Wooooo0_l00002ooooo`;o00000oooool4
o`0000;ooooo0_l00009ooooo`;o00000_ooool4o`0000[ooooo0_l0000booooo`007?ooool00ol0
003oooooooooo`0cooooo`;o00002Oooool2o`0000?ooooo0_l0000Looooo`Co00002_ooool2o`00
00Kooooo0_l00002ooooo`;o00001_ooool3o`0000_ooooo0_l000000ooooooo0000o`000006oooo
o`Go00002?ooool2o`0000[ooooo0_l00003ooooo`Go00000oooool2o`0000Cooooo0ol000000ooo
oooo0000o`00000>ooooo`Ko00004_ooool2o`0000;ooooo0_l00008ooooo`;o00000oooool2o`00
043ooooo000Looooo`03o`000?oooooooooo03Oooooo0_l00005ooooo`;o000000?oooooo`000?l0
00000ol0000Kooooo`Co00002_ooool2o`0000Sooooo1?l00006ooooo`?o00002oooool5o`0000So
oooo0ol00004ooooo`;o00000_ooool2o`0000[ooooo1?l000001?oooooo0000o`000?l00006oooo
o`;o00001?ooool4o`0000cooooo1Ol00002ooooo`;o00001oooool2o`0000Sooooo0_l00006oooo
o`;o00001?ooool3o`0004Gooooo000Looooo`03o`000?oooooooooo03Oooooo0_l00007ooooo`?o
000000?oooooo`000?l000002oooool2o`0000_ooooo0ol00003ooooo`Co00004Oooool2o`0001Oo
oooo1?l00004ooooo`;o00002Oooool2o`0000cooooo1_l0000:ooooo`;o00001_ooool2o`0000co
oooo0ol00002ooooo`;o00001oooool4o`0000Oooooo1ol000001?oooooo0000o`000?l00004oooo
o`;o0000A_ooool001cooooo00?o0000ooooooooool0=Oooool4o`0000Oooooo0_l00003ooooo`;o
00002?ooool4o`0000_ooooo0ol00003ooooo`Co00002oooool2o`0000?ooooo0_l00002ooooo`Co
00001?ooool2o`0000;ooooo0_l00003ooooo`;o00001Oooool2o`0000Cooooo0ol00006ooooo`;o
00003_ooool2o`0000?ooooo0_l00005ooooo`?o00006?ooool2o`0000;ooooo1?l00005ooooo`Co
00001oooool7o`000003ooooool0003o000000;ooooo0_l00019ooooo`007?ooool00ol0003ooooo
ooooo`0eooooo`;o00000_ooool2o`0000Kooooo0_l00002ooooo`;o00002?ooool2o`0000Kooooo
0_l00008ooooo`;o00004?ooool2o`0000?ooooo0_l00002ooooo`Co00001?ooool2o`0000;ooooo
0_l00003ooooo`;o00003?ooool2o`0000Kooooo0_l0000<ooooo`;o00001Oooool2o`0000Cooooo
1?l00006ooooo`;o00005?ooool4o`0000Gooooo1?l000000ooooooo0000o`000008ooooo`;o0000
1_ooool2o`0001?ooooo0_l0000dooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o
8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0>Oooool2o`00
00Kooooo0_l0000?ooooo`;o00000oooool3o`0000Oooooo0_l00009ooooo`;o00004_ooool2o`00
01?ooooo0_l00009ooooo`;o000000?oooooo`000?l000003?ooool2o`0000Wooooo1?l00008oooo
o`;o00004oooool2o`0000Kooooo0_l00005ooooo`;o00004?ooool3o`0001;ooooo0_l000000ooo
oooo0000o`00000aooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0?_ooool2o`000003ooooool0
003o000000oooooo0_l00004ooooo`;o00004_ooool2o`0001;ooooo1Ol0000@ooooo`;o00002Ooo
ool2o`000004ooooool0003o0000ooooo`Co00001?ooool2o`0000cooooo0ol0000Nooooo`;o0000
1_ooool3o`0000?ooooo0_l00004ooooo`;o00003?ooool2o`0001Gooooo0_l0000aooooo`0000?o
oooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`0cooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo
0_l00005ooooo`;o00005oooool2o`0000kooooo0_l0000Booooo`Co00000_ooool2o`0000Wooooo
0_l00005ooooo`;o00001oooool2o`000003ooooool0003o000000Co00000_ooool2o`0000;ooooo
0_l00009ooooo`;o00002?ooool4o`0000Sooooo0_l0000Aooooo`;o00000oooool2o`0000;ooooo
1?l0000Gooooo`?o0000??ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0000cooooo`;o00000_ooool2o`000003oooo
ool0003o000000Wooooo0_l0000<ooooo`;o00002Oooool2o`0000kooooo0_l0000Cooooo`?o0000
0_ooool2o`0000;ooooo0_l00005ooooo`;o00001Oooool2o`0000Oooooo0_l00003ooooo`Co0000
1_ooool2o`0000Wooooo1_l00003ooooo`Go000000?oooooo`000?l000001Oooool2o`0000Sooooo
0_l0000@ooooo`;o00000_ooool2o`0000Kooooo0_l00005ooooo`;o00001_ooool3o`0003cooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oeEEEOl0003o410@
olc<c006ooooo`03o`000?oooooooooo03?ooooo0_l00002ooooo`;o000000?oooooo`000?l00000
0_l0000Eooooo`;o00009?ooool3o`0000Gooooo0_l000000ooooooo0000o`000005ooooo`?o0000
6Oooool3o`0000oooooo0_l00002ooooo`Ko00000oooool2o`0000Cooooo0_l0000;ooooo`?o0000
00?oooooo`000?l000001_ooool4o`000003ooooool0003o000000Oooooo0_l000000ooooooo0000
o`000003ooooo`;o00001Oooool2o`0000oooooo0_l0000dooooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0=ooo
ool2o`000003ooooool0003o000000;o00009_ooool2o`0000oooooo0_l00002ooooo`?o00001Ooo
ool2o`000004ooooool0003o0000o`0000Cooooo0_l0000Jooooo`;o00002?ooool2o`0000Kooooo
0_l00009ooooo`;o00000_ooool2o`0000Kooooo0_l00007ooooo`?o00002Oooool4o`000004oooo
ool0003o0000o`0000Oooooo1Ol0000Jooooo`;o0000=?ooool00006oooooomgMgOoV9RHoooooonH
V9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo03cooooo0_l00006oooo
o`;o00007Oooool3o`0000oooooo0_l000000ooooooo0000o`00000;ooooo`;o00000_ooool5o`00
01oooooo0_l00002ooooo`?o00004?ooool2o`000004ooooool0003o0000o`0000;ooooo0_l00002
ooooo`;o00000_ooool2o`0001;ooooo0_l000000ooooooo0000o`000003ooooo`;o00000_ooool2
o`000003ooooool0003o000000?ooooo0_l0001;ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^
k^h<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0<oooool2o`0000cooooo
0_l000000ooooooo0000o`00000:ooooo`;o00004Oooool2o`0001?ooooo0_l00003ooooo`;o0000
0oooool?o`0000?ooooo0_l0000?ooooo`;o00001Oooool3o`0000?ooooo0_l0000Cooooo`;o0000
00?oooooo`000?l000000_l00006ooooo`;o00001?ooool2o`0000cooooo0_l00006ooooo`;o0000
0_ooool2o`000003ooooool0003o000000?ooooo0_l00004ooooo`;o0000AOooool001cooooo00?o
0000ooooooooool0<oooool2o`0000Gooooo0_l000000ooooooo0000o`000002ooooo`;o00000_oo
ool2o`0000Wooooo0_l0000Dooooo`;o00003?ooool2o`0000Oooooo5_l000000ooooooo0000o`00
000?ooooo`;o00001Oooool3o`0001Kooooo0_l00002ooooo`Go00001Oooool2o`0000Gooooo0_l0
000Dooooo`;o00000_ooool2o`0000?ooooo0_l00007ooooo`;o0000AOooool001cooooo00?o0000
ooooooooool0=_ooool2o`0000;ooooo0_l000000ooooooo0000o`000003o`0000?ooooo0_l0000O
ooooo`;o00003?ooool2o`0000Oooooo5_l000000ooooooo0000o`00000Gooooo`;o00004_oooolA
o`000005ooooool0003o0000o`000?ooool00_l0000Fooooo`?o00001oooool3o`0004gooooo000L
ooooo`03o`000?oooooooooo03Kooooo0_l00007ooooo`?o00003oooool2o`0002_ooooo6?l0000B
ooooo`;o00000oooool2o`0000;ooooo0_l0000=oooooa?o000000Coooooo`000?l0003ooooo0_l0
000Fooooo`;o00000_ooool4o`0000?ooooo0_l0000=ooooo`;o0000?_ooool001cooooo00?o0000
ooooooooool0?oooool3o`0000Oooooo0_l00006ooooo`;o0000;OoooolFo`0001;ooooo0_l00007
ooooo`;o00003Oooool2o`0000;ooooo3ol0000Pooooo`Co00004_ooool2o`0003kooooo000Loooo
o`03o`000?oooooooooo03cooooo1_l00007ooooo`;o0000:oooool2o`0000Oooooo1ol000000ooo
oooo0000o`00000=o`0001Gooooo1?l0000@ooooo`;o00001?ooool@o`0000Cooooo0_l0000Moooo
o`;o00004oooool2o`0003[ooooo000Looooo`03o`000?oooooooooo03cooooo1_l0000Qooooo`;o
00004Oooool2o`0000Kooooo5_l0000Fooooo`Go00003_ooool7o`000003ooooool0003o0000013o
00000_ooool2o`0000Oooooo0ol00007ooooo`;o00001Oooool2o`0000?ooooo1?l0000<ooooo`?o
00000_ooool2o`0003[ooooo000Looooo`03o`000?oooooooooo03gooooo0_l0000Fooooo`;o0000
3?ooool2o`00017ooooo0_l00006ooooo`_o000000?oooooo`000?l000002Ol00005ooooo`;o0000
3Oooool3o`00017ooooo0_l000000ooooooo0000o`00000Eo`0000Sooooo1_l00007ooooo`;o0000
0_ooool7o`0000?ooooo0_l0000<ooooo`?o0000?_ooool001cooooo00?o0000ooooooooool0EOoo
ool2o`0000Cooooo0ol0000Roooooa;o000000?oooooo`000?l000001Oooool2o`0000gooooo1_l0
0003ooooo`;o00002_oooolJo`0000Oooooo1_l0000;ooooo`Oo0000D_ooool001cooooo00?o0000
ooooooooool0>_ooool2o`0000gooooo0_l00002ooooo`;o00001Oooool2o`0000Cooooo1?l00004
ooooo`;o00006ooooolHo`00013ooooo2?l000000ooooooo0000o`000002o`0000[ooooo4_l00000
0ooooooo0000o`000005o`0000Wooooo0_l0000Aooooo`;o00001?ooool2o`0004gooooo000Loooo
o`03o`000?oooooooooo03[ooooo0_l000000ooooooo0000o`00000:ooooo`?o000000?oooooo`00
0?l000000_l00003ooooo`;o00001?ooool2o`0000Kooooo0_l00002ooooo`;o00004_ooool2o`00
00?ooooo6Ol0000?ooooo`;o00001oooool2o`0000oooooo5?l00002ooooo`;o00000_ooool2o`00
01gooooo0_l0000>ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0?Oooool3o`0000[o
oooo0_l000000ooooooo0000o`000002o`0000cooooo0_l00007ooooo`;o00004_ooool2o`0000?o
oooo6Ol0000YoooooaCo00000_ooool2o`0000;ooooo0_l0000Booooo`;o00003?ooool2o`0000_o
oooo0_l0000mooooo`007?ooool2o`0003kooooo0ol0000Mooooo`;o00006_ooool2o`0000;ooooo
0_l000000ooooooo0000o`00000?o`000003ooooool0003o000000;o00005?ooool2o`0001Kooooo
5Ol00006ooooo`;o00004?ooool2o`0000cooooo1Ol00017ooooo`007?ooool00ol0003ooooooooo
o`0mooooo`;o0000>_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000Do`0001Cooooo1?l0
0004ooooo`?o000000?oooooo`000?l000002OoooolFo`0000Kooooo0_l00005ooooo`Co00005Ooo
ool5o`0004Oooooo000Looooo`03o`000?oooooooooo067ooooo0_l0000Mooooo`[o000000?ooooo
o`000?l000002_l0000Aooooo`?o000000?oooooo`000?l000000oooool4o`000003ooooool0003o
000000Sooooo1ol000000ooooooo0000o`00000=o`0000Sooooo0_l00003ooooo`Co00001Oooool2
o`000003ooooool0003o000000Wooooo1?l0001:ooooo`007?ooool00ol0003oooooooooo`1@oooo
o`;o00003oooool2o`0001gooooo2Ol00002ooooo`co00004Oooool3o`0000Kooooo0ol0000<oooo
oaOo00001oooool3o`0000cooooo0_l000000ooooooo0000o`000009ooooo`;o0000C?ooool001co
oooo00?o0000ooooooooool0?oooool3o`0000gooooo0ol0000^oooooaOo00004oooool2o`0001Co
oooo5_l00008ooooo`;o00000_ooool4o`0006?ooooo000Looooo`03o`000?oooooooooo03kooooo
1ol0000:ooooo`Co0000:_ooool2o`000003ooooool0003o000001Go00004oooool2o`0000Gooooo
0_l0000>oooooaOo00001Oooool2o`0000?ooooo1?l0001Sooooo`007?ooool00ol0003ooooooooo
o`0nooooo`;o000000?oooooo`000?l000000ol0000;ooooo`;o0000:_ooool5o`000003ooooool0
003o000001;o00003oooool2o`0000;ooooo0_l00005ooooo`;o00004OoooolAo`000003ooooool0
003o000000Gooooo0_l0000;ooooo`;o00000oooool2o`0000cooooo0_l0001:ooooo`007?ooool0
0ol0003oooooooooo`0iooooo`;o00001oooool4o`0001[ooooo0ol00003ooooo`;o00005ooooolH
o`0000oooooo0_l00002ooooo`;o00001oooool2o`0000oooooo4?l0000Fooooo`;o00000oooool2
o`0000cooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00001oooool3o`00
00oooooo0_l00005ooooo`;o00000oooool3o`0000?ooooo0_l0000Fooooo`;o000000?oooooo`00
0?l000005?l0000Dooooo`;o00001_ooool2o`00017ooooo3?l00004ooooo`;o00005Oooool2o`00
05[ooooo000Looooo`03o`000?oooooooooo04?ooooo0_l0000>ooooo`?o00000_ooool2o`000003
ooooool0003o0000027ooooo6Ol000000ooooooo0000o`00000Aooooo`;o00006oooool9o`0000Go
oooo0_l0000Eooooo`;o00001_ooool2o`0005;ooooo000Looooo`03o`000?oooooooooo04?ooooo
0_l0000>ooooo`;o00000oooool2o`0002Cooooo6Ol000000ooooooo0000o`00000^ooooo`So0000
0_ooool4o`0001;ooooo0_l00002ooooo`;o00001oooool2o`0000;ooooo0ol0001=ooooo`007?oo
ool00ol0003oooooooooo`17ooooo`;o00003Oooool2o`0000_ooooo0_l00004ooooo`;o000000?o
ooooo`000?l000004?oooolHo`00017ooooo0_l00007ooooo`;o00004oooool2o`000003ooooool0
003o000000Ko00000_ooool4o`0000kooooo0_l000001?oooooo0000o`000?l00002ooooo`;o0000
2oooool3o`0004gooooo000Looooo`03o`000?oooooooooo04Oooooo0_l000000ooooooo0000o`00
000:ooooo`;o00002oooool2o`0000Cooooo0_l000000ooooooo0000o`00000@oooooaSo00001ooo
ool2o`0000Sooooo0_l00007ooooo`;o00004oooool2o`000003ooooool0003o000000;ooooo0_l0
00001?oooooo0000o`000?l0000Booooo`;o000000?oooooo`000?l000001oooool2o`0000cooooo
0_l00019ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00001Oooool7o`0001Oooooo0_l0
000IoooooaKo00000_ooool2o`0000?ooooo0_l00006ooooo`;o00004?ooool2o`0000Wooooo0_l0
00000ooooooo0000o`000008ooooo`?o00007_ooool2o`0000Cooooo0_l00005ooooo`?o0000BOoo
ool001cooooo00?o0000ooooooooool0@?ooool2o`0000Cooooo0_l000001?oooooo0000o`000?oo
ool2o`0000Sooooo0_l00007ooooo`;o00001?ooool2o`0001cooooo4_l00003ooooo`;o00002ooo
ool2o`0000Wooooo0_l00005ooooo`;o00002Oooool2o`0000Sooooo0_l0000Qooooo`;o00001Ooo
ool2o`0000?ooooo1?l0001:ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00001?ooool2
o`0000kooooo0_l00007ooooo`;o00006?ooool2o`0000Wooooo4Ol0000Fooooo`;o000000?ooooo
o`000?l000000_l00003ooooo`;o00000oooool2o`00013ooooo0_l0000Qooooo`;o00002_ooool4
o`0004[ooooo000Looooo`;o0000@Oooool2o`0000Cooooo0_l00003ooooo`;o00005?ooool2o`00
0003ooooool0003o000000;ooooo0_l00005ooooo`;o00002?ooool2o`0000Gooooo0_l00002oooo
o`;o000000Coooooo`000?l0003ooooo2_l0000Booooo`;o00000oooool2o`000003ooooool0003o
000000Gooooo0ol00002ooooo`;o00009_ooool3o`0000cooooo0_l0001Fooooo`007?ooool00ol0
003oooooooooo`1;ooooo`;o00003_ooool2o`0000Cooooo0_l000000ooooooo0000o`000002oooo
o`;o00001Oooool2o`0000Sooooo0_l00005ooooo`;o00000_ooool5o`000003ooooool0003o0000
00So00004_ooool2o`0000kooooo0_l0000Fooooo`;o00004?ooool5o`0000cooooo0_l0001Foooo
o`007?ooool00ol0003oooooooooo`19ooooo`;o00004?ooool2o`0000_ooooo0_l00003ooooo`;o
00000_ooool2o`0000Kooooo0_l00006ooooo`;o00000_ooool3o`0000?ooooo2Ol0000;ooooo`;o
00001Oooool2o`0000kooooo0_l00003ooooo`;o00000oooool2o`0000cooooo0_l0000@ooooo`;o
00000_ooool4o`00067ooooo000Looooo`03o`000?oooooooooo04Wooooo0_l0000Mooooo`Co0000
00?oooooo`000?l000000_ooool4o`0000Cooooo0_l00006ooooo`;o00000_ooool5o`0000?ooooo
1ol00004ooooo`Co00000oooool2o`0000_ooooo0_l0000=ooooo`;o00000oooool2o`0002;ooooo
1?l0000;ooooo`;o0000E?ooool001cooooo00?o0000ooooooooool0BOooool3o`0000?ooooo1?l0
000Eooooo`Co00001oooool2o`0000Cooooo0ol0000<ooooo`Oo000000?oooooo`000?l000001?l0
0002ooooo`So00001Oooool2o`0000Gooooo0_l0000Booooo`;o00003_ooool2o`0000;ooooo0_l0
000Gooooo`;o00001?ooool2o`0005Cooooo000Looooo`03o`000?oooooooooo04Wooooo0ol00003
ooooo`Co00002?ooool3o`0000gooooo0_l0000=ooooo`Co00002_ooool:o`0000;ooooo0_l00002
ooooo`;o000000?oooooo`000?l000000ol000000ooooooo0000o`000002ooooo`;o00007Oooool2
o`000003ooooool0003o000000Oooooo0_l00002ooooo`;o00002Oooool2o`0000cooooo0_l0001J
ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00001?ooool2o`0000?ooooo0ol00005oooo
o`;o00000_ooool3o`0000;ooooo0_l00002ooooo`;o00000oooool4o`0000Cooooo0_l00009oooo
o`;o00001Oooool3o`0000Gooooo1Ol000001?oooooo0000o`000?ooool2o`0000;ooooo1Ol00004
ooooo`Co00007oooool5o`0000Oooooo0_l0000=ooooo`;o000000?oooooo`000?l000003oooool2
o`0005Cooooo000Looooo`03o`000?oooooooooo04Cooooo0_l00003ooooo`;o00001?ooool3o`00
0003ooooool0003o000000;ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003oooo
o`;o00001_ooool2o`0000Cooooo0ol00009ooooo`?o00002oooool5o`0000Cooooo0_l00004oooo
o`;o000000?oooooo`000?l000006Oooool4o`0000?ooooo0_l00009ooooo`;o000000Coooooo`00
0?l0003ooooo1?l00008ooooo`;o00003oooool2o`0005Cooooo000Looooo`03o`000?oooooooooo
04Wooooo0_l00008ooooo`;o00001_ooool2o`0000gooooo1Ol00008ooooo`?o00003Oooool2o`00
00Oooooo1?l0000<ooooo`;o00006Oooool7o`0000kooooo1Ol000000ooooooo0000o`000002o`00
06oooooo000Looooo`03o`000?oooooooooo04oooooo0_l0000Iooooo`Go00001_ooool2o`0000Oo
oooo0_l00007ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Oooooo0_l00004ooooo`;o
00001Oooool2o`0000oooooo0_l000000ooooooo0000o`000003o`00017ooooo1?l0000?ooooo`?o
0000Hoooool001cooooo00?o0000ooooooooool0Coooool2o`0000cooooo0_l0000<ooooo`;o0000
2?ooool2o`0000Oooooo1?l00008ooooo`Co00001oooool2o`0000;ooooo0_l000001?oooooo0000
o`000?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000?ooooo`;o000000?oooooo`000?l0
00000_l0000Booooo`;o00000oooool2o`0000Cooooo0ol00004ooooo`Co00002Oooool2o`0005So
oooo000Looooo`03o`000?oooooooooo05gooooo0_l0000<ooooo`;o00000oooool2o`000004oooo
ool0003o0000ooooo`;o00001oooool3o`0000[ooooo0ol00004ooooo`Co000000?oooooo`000?l0
00000_ooool2o`0000Gooooo0_l0000Gooooo`;o00002_ooool4o`0000?ooooo0_l00004ooooo`?o
00000oooool3o`0000Cooooo0_l00009ooooo`Co0000F?ooool001cooooo00?o0000ooooooooool0
Koooool3o`000004ooooool0003o0000ooooo`Go00000oooool2o`0000gooooo0_l00004ooooo`;o
00000oooool2o`0001gooooo0_l00003ooooo`;o00002_ooool4o`000003ooooool0003o000000;o
00001Oooool2o`0001Gooooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`1Gooooo`;o0000
4?ooool2o`0000Cooooo0_l00006ooooo`Co00000oooool2o`0000Sooooo0_l000000ooooooo0000
o`00000:ooooo`;o00007_ooool2o`0001Cooooo0_l00002ooooo`;o00000_ooool2o`0001;ooooo
0_l0001Nooooo`007?ooool00ol0003oooooooooo`1Gooooo`;o000000?oooooo`000?l000000_oo
ool2o`0000Wooooo0_l0000?ooooo`Co00002_ooool2o`000003ooooool0003o000000[ooooo0_l0
0002ooooo`;o0000<Oooool2o`000003ooooool0003o000000;ooooo0_l0000Booooo`;o0000G_oo
ool001cooooo00?o0000ooooooooool0FOooool3o`0000;ooooo0_l0000Aooooo`;o00001oooool4
o`0001;ooooo0_l00007ooooo`Co00009?ooool2o`0000Kooooo0ol000001?oooooo0000o`000?l0
000Booooo`;o0000IOooool001cooooo0_l0001Jooooo`?o00000_ooool2o`00017ooooo1_l0000=
ooooo`;o00002_ooool4o`0000Gooooo0_l0000Vooooo`;o00001?ooool5o`000003ooooool0003o
000000;o00003?ooool2o`0000?ooooo0_l0001Uooooo`007?ooool00ol0003oooooooooo`1Joooo
o`;o00000_ooool3o`0000Kooooo0_l0000:ooooo`Co00002oooool4o`0000Sooooo0_l00002oooo
o`;o00003_ooool3o`0000cooooo0_l0000?ooooo`;o00000oooool2o`0000Kooooo0_l0000<oooo
o`;o0000J_ooool001cooooo00?o0000ooooooooool0Eoooool2o`0000Cooooo1?l00006ooooo`Co
00000_ooool2o`0000Cooooo0_l0000=ooooo`;o00002_ooool2o`0000?ooooo0_l0000=ooooo`?o
00003?ooool3o`0000Kooooo0ol000000ooooooo0000o`000002ooooo`;o00001_ooool2o`0000go
oooo0_l0001^ooooo`007?ooool00ol0003oooooooooo`1Gooooo`;o00001?ooool2o`000003oooo
ool0003o000000;ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00002ooooo`Co0000
0_ooool2o`0001[ooooo0_l0000Mooooo`;o00001?ooool8o`0000[ooooo0_l0000:ooooo`;o0000
00?oooooo`000?l00000K_ooool001cooooo00?o0000ooooooooool0FOooool2o`0000Gooooo0_l0
0002ooooo`;o00000_ooool2o`0000;ooooo1?l000000ooooooo0000o`000003ooooo`?o00002_oo
ool2o`0000;ooooo0_l0000Booooo`;o00006_ooool3o`0000?ooooo0_l00008ooooo`;o00003Ooo
ool2o`0000Cooooo0_l00004ooooo`;o0000IOooool001cooooo00?o0000ooooooooool0FOooool2
o`00017ooooo1?l00006ooooo`?o00000_ooool2o`0000Kooooo0_l00002ooooo`;o00000oooool2
o`0000Gooooo0_l00002ooooo`;o00000_ooool2o`0001[ooooo0_l00005ooooo`;o00001Oooool4
o`0000oooooo0_l00002ooooo`;o00001?ooool2o`0006Gooooo000Looooo`03o`000?oooooooooo
06?ooooo0_l00006ooooo`;o00002Oooool2o`0000?ooooo0_l0000>ooooo`?o00001Oooool2o`00
00;ooooo0_l0000Eooooo`;o00001_ooool3o`0000Gooooo0_l00005ooooo`?o00004?ooool2o`00
06oooooo000Looooo`03o`000?oooooooooo05_ooooo0_l00006ooooo`?o000000Coooooo`000?l0
003ooooo0ol00009ooooo`;o00002_ooool2o`0000Oooooo0_l0000Kooooo`;o00001?ooool2o`00
0003ooooool0003o000000?ooooo0_l0000;ooooo`Go00004oooool2o`0006cooooo000Looooo`03
o`000?oooooooooo05_ooooo0_l00007ooooo`;o000000?oooooo`000?l000001?l0000Eooooo`;o
00008_ooool4o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`;o00001oooool2o`000003
ooooool0003o000000;o00005?ooool2o`0006cooooo000Looooo`03o`000?oooooooooo05gooooo
0_l00005ooooo`;o00000oooool4o`0000Kooooo0_l0000>ooooo`;o00001?ooool2o`00013ooooo
0_l00009ooooo`;o00001_ooool2o`0000Oooooo0ol00005ooooo`?o0000Qoooool001cooooo00?o
0000ooooooooool0GOooool2o`0000Cooooo0ol0000=ooooo`;o000000Coooooo`000?l0003ooooo
0_l00008ooooo`;o00001?ooool3o`0000cooooo0_l000001?oooooo0000o`000?ooool2o`0000Ko
oooo0_l00003ooooo`;o00002oooool2o`0000Gooooo0_l00028ooooo`007?ooool00ol0003ooooo
ooooo`1Sooooo`;o00003_ooool2o`000004ooooool0003o0000ooooo`;o00002Oooool2o`0000Co
oooo0_l00002ooooo`?o00000_ooool2o`0000?ooooo0_l00004ooooo`;o00001_ooool2o`0000?o
oooo0_l0000;ooooo`;o00003oooool2o`0000_ooooo0_l0001aooooo`007?ooool00ol0003ooooo
ooooo`1[ooooo`;o00001_ooool2o`0000?ooooo1Ol000000ooooooo0000o`000004ooooo`;o0000
00?oooooo`000?l000001Oooool3o`0000;ooooo0_l00003ooooo`;o00003?ooool2o`0000?ooooo
1?l0000Eooooo`?o000000Coooooo`000?l0003o00001Oooool2o`0000;ooooo1?l0001aooooo`00
7?ooool00ol0003oooooooooo`1[ooooo`;o00001_ooool2o`000003ooooool0003o000000Go0000
00?oooooo`000?l000000oooool2o`0000;ooooo1?l00002ooooo`;o00002Oooool2o`000003oooo
ool0003o000000_ooooo0_l00003ooooo`?o00004_ooool5o`000003ooooool0003o000000Kooooo
0_l00002ooooo`;o0000Loooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Co
oooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo06Gooooo0ol0000>oooo
o`;o00001?ooool3o`000004ooooool0003o0000ooooo`;o00001?ooool2o`0000;ooooo0_l00003
ooooo`;o00001oooool2o`0000;ooooo0ol00006ooooo`;o00001?ooool2o`0000Cooooo0_l0000<
ooooo`;o0000QOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go
8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo067ooooo0_l00002ooooo`?o0000
2oooool2o`0000Oooooo0ol000000ooooooo0000o`00000?ooooo`?o00001oooool2o`0000;ooooo
0ol0000Aooooo`?o00003?ooool2o`0008Gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oo
oooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo067ooooo
0_l00009ooooo`;o00001Oooool3o`0000;ooooo0_l00003ooooo`;o00002Oooool2o`0000Oooooo
0_l0000=ooooo`;o00004Oooool2o`0000;ooooo0_l00005ooooo`;o00005?ooool2o`0007?ooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RH
oc8b<P06ooooo`?o0000K?ooool2o`0000Kooooo1_l00003ooooo`;o00002Oooool3o`0000oooooo
0_l00002ooooo`;o00005oooool2o`0000Gooooo0_l00009ooooo`;o00002Oooool2o`0007?ooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Goc<c<o`000?l0003o0000
olc<c006ooooo`03o`000?oooooooooo06Cooooo0_l00004ooooo`;o00002_ooool2o`00013ooooo
0ol0000?ooooo`;o00000_ooool2o`0001Oooooo0_l0000@ooooo`;o0000O_ooool00003ooooool@
413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo
00?o0000ooooooooool0I?ooool2o`0000Cooooo0_l00008ooooo`;o00003oooool2o`000003oooo
ool0003o000000;o00008Oooool4o`0000Kooooo1?l0000:ooooo`;o0000P_ooool00006oooooomg
MgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000oooo
ooooool0M?ooool2o`0000oooooo0_l00003ooooo`;o00005Oooool3o`0000Sooooo1Ol00008oooo
o`;o00002_ooool2o`0000Gooooo0_l0001kooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;
ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`1Zooooo`;o00000ooo
ool2o`000004ooooool0003o0000ooooo`;o00002?ooool2o`0000Cooooo0_l00003ooooo`;o0000
5Oooool3o`0000Sooooo0_l0000Jooooo`;o00000_ooool2o`0007_ooooo000Looooo`03o`000?oo
oooooooo06[ooooo0_l00003ooooo`Go000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l0
00000ooooooo0000o`000006ooooo`;o00007Oooool2o`0001;ooooo0_l00009ooooo`Co00001ooo
ool2o`0007Cooooo000Looooo`03o`000?oooooooooo077ooooo0_l00006ooooo`;o00001oooool3
o`0000Kooooo0_l00003ooooo`;o00005oooool2o`0000Oooooo0_l00004ooooo`;o00000_ooool3
o`0000_ooooo1?l00005ooooo`;o0000M?ooool001cooooo00?o0000ooooooooool0POooool4o`00
00Kooooo0_l00003ooooo`;o00002_ooool2o`0000;ooooo0_l00003ooooo`;o00002oooool2o`00
00Cooooo0_l00002ooooo`;o00003Oooool3o`0007_ooooo000Looooo`03o`000?oooooooooo07So
oooo0_l00007ooooo`;o00002Oooool2o`0000;ooooo0_l0000:ooooo`;o00000_ooool2o`0000?o
oooo0_l0000Eooooo`;o00001_ooool2o`0000?ooooo0_l0001nooooo`007?ooool00ol0003ooooo
ooooo`1hooooo`;o00003?ooool4o`0000;ooooo0_l00002ooooo`;o00001oooool2o`0000[ooooo
0_l0000Eooooo`;o00001_ooool2o`0000?ooooo0_l0001nooooo`007?ooool00ol0003ooooooooo
o`1looooo`;o00002?ooool4o`0000Gooooo0_l00003ooooo`Oo00002_ooool4o`000003ooooool0
003o000000Kooooo0_l00006ooooo`;o0000SOooool001cooooo00?o0000ooooooooool0O?ooool2
o`0000[ooooo0_l00005ooooo`;o00000oooool6o`0000_ooooo1?l000000ooooooo0000o`000006
ooooo`;o00001_ooool2o`0000[ooooo0_l00021ooooo`007?ooool00ol0003oooooooooo`1loooo
o`;o00005Oooool4o`000004ooooool0003o0000o`0000[ooooo1?l0000Cooooo`;o00002?ooool2
o`0000Kooooo0_l0001iooooo`007?ooool00ol0003oooooooooo`1looooo`Ko00004Oooool2o`00
0004ooooool0003o0000ooooo`;o00002_ooool4o`0001?ooooo1?l0000>ooooo`;o0000NOooool0
01cooooo00?o0000ooooooooool0O_ooool4o`0000Oooooo0_l00009ooooo`Co00002_ooool2o`00
0003ooooool0003o000001Oooooo0_l0000:ooooo`;o0000OOooool001cooooo00?o0000oooooooo
ool0ROooool2o`0000Wooooo0_l000000ooooooo0000o`000009ooooo`;o00002oooool2o`0001Wo
oooo0_l0001mooooo`007?ooool2o`0008?ooooo0_l0000Cooooo`;o00004Oooool4o`000003oooo
ool0003o000000Oooooo0_l0002?ooooo`007?ooool00ol0003oooooooooo`22ooooo`;o00009_oo
ool4o`000004ooooool0003o0000o`0000Gooooo0ol000000ooooooo0000o`000003ooooo`;o0000
Qoooool001cooooo00?o0000ooooooooool0V?ooool2o`0001Kooooo0_l00005ooooo`;o00000_oo
ool2o`0000?ooooo0_l00027ooooo`007?ooool00ol0003oooooooooo`2Hooooo`;o00002oooool2
o`0000[ooooo0_l0002Fooooo`007?ooool00ol0003oooooooooo`2Nooooo`;o00001Oooool2o`00
00Kooooo0_l00002ooooo`;o0000U_ooool001cooooo00?o0000ooooooooool0W_ooool2o`0000Go
oooo1?l00004ooooo`;o0000V_ooool001cooooo00?o0000ooooooooool0YOooool4o`000:3ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000
oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo
00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool0
01Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;o
oooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooo
oomBooooo`004_ooool00omEEEGoIVIVo`00003ooooooeCooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo002Uooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool0
5Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Co410@o`000?m4A4Coc<c<1?ooool01Oo^
k^ko<S8bo`000?l@413oc<c<093ooooo002Vooooo`05o`000?ooooooooooooooool000002Oooool6
o`0000Wooooo00GoEEEEogMgMoooooooV9RHob4Q8@05ooooo`03oiRHV?l@413ogMgM00?ooooo00Go
EEEEogMgMoooooooV9RHob4Q8@2@ooooo`00Y_ooool01Ol0003ooooooooooooooooo000001Sooooo
00Go0000ooooooooooooooooo`000006ooooo`03ohN7QomEEEGooooo00;ooooo00Go0000oooooooo
ooooooooo`00002@ooooo`00Y_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l00009oooo
o`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Oo<c<co8B4Qo`000?mEEEGo000000?ooooo00Go
0000oiRHV?ooooooV9RHob4Q8@2@ooooo`00Y_ooool01Ol0003oQhN7oooooonYZJWo000001Sooooo
00Go0000oeEEEOl0003o410@olc<c003ooooo`05ob4Q8On7QhOooooooiRHV?l000000oooool01Ol0
003oEEEEo`000?l@413oc<c<093ooooo002Uooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHoooo
ooooool05_ooool00omEEEGoQhN7ooooo`05ooooo`05o`000?ooooooooooooooool000000oooool0
0omEEEGoQhN7ooooo`2Booooo`00`oooool00ooMgMgo410@oiRHV005ooooo`05ob4Q8OnHV9Sooooo
ogMgMomEEED00oooool00ooMgMgo410@oiRHV02Booooo`00a?ooool01?o<c<coA4A4o`000?l@4103
ooooo`05olc<c?l@413o0000oc8b<_o^k^h01?ooool01?o<c<coA4A4o`000?l@412@ooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(702) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.50804 .33586 Mdot
.48393 .30127 Mdot
.43776 .6267 Mdot
.62445 .51175 Mdot
.53497 .62566 Mdot
.41716 .65859 Mdot
.38181 .50774 Mdot
.39792 .48323 Mdot
.42318 .63889 Mdot
.52434 .24533 Mdot
.37487 .53445 Mdot
.56204 .51044 Mdot
.37369 .49977 Mdot
.63212 .4517 Mdot
.18539 .47188 Mdot
.6864 .45273 Mdot
.45618 .29285 Mdot
.61971 .69471 Mdot
.68123 .44001 Mdot
.43927 .64667 Mdot
.42033 .35136 Mdot
.62829 .456 Mdot
.48228 .29655 Mdot
.63156 .45365 Mdot
.65451 .49336 Mdot
.48528 .3315 Mdot
.51289 .33347 Mdot
.62903 .49427 Mdot
.66079 .46181 Mdot
.35163 .51541 Mdot
.53268 .65916 Mdot
.15672 .58814 Mdot
.6918 .48855 Mdot
.74347 .40272 Mdot
.36075 .47136 Mdot
.51533 .81094 Mdot
.4084 .62456 Mdot
.39781 .51573 Mdot
.384 .47192 Mdot
.37116 .47574 Mdot
.37164 .48332 Mdot
.4869 .32526 Mdot
.33991 .51712 Mdot
.32823 .53651 Mdot
.61205 .50916 Mdot
.30082 .38187 Mdot
.62848 .73348 Mdot
.62685 .49152 Mdot
.50027 .34035 Mdot
.4292 .67544 Mdot
.79116 .41535 Mdot
.40064 .51267 Mdot
.23 .43988 Mdot
.13706 .36211 Mdot
.35365 .49505 Mdot
.62406 .50696 Mdot
.39842 .64687 Mdot
.60458 .471 Mdot
.62328 .47408 Mdot
.74339 .37034 Mdot
.65113 .47178 Mdot
.59891 .65763 Mdot
.51299 .30882 Mdot
.44257 .62269 Mdot
.42008 .64614 Mdot
.34654 .49184 Mdot
.44563 .31173 Mdot
.38017 .49404 Mdot
.57401 .4233 Mdot
.4345 .65646 Mdot
.62327 .49332 Mdot
.37828 .53518 Mdot
.43896 .32202 Mdot
.67256 .44992 Mdot
.33966 .38393 Mdot
.24787 .47979 Mdot
.57993 .6351 Mdot
.67352 .35525 Mdot
.56593 .18847 Mdot
.27615 .52422 Mdot
.64264 .45192 Mdot
.52792 .15472 Mdot
.19616 .47036 Mdot
.47096 .2979 Mdot
.74318 .47451 Mdot
.31835 .69644 Mdot
.65549 .44242 Mdot
.50281 .55783 Mdot
.61199 .53049 Mdot
.40446 .38142 Mdot
.4198 .63486 Mdot
.49347 .33201 Mdot
.61668 .51342 Mdot
.6433 .43275 Mdot
.6518 .26096 Mdot
.65614 .52482 Mdot
.60683 .49856 Mdot
.50813 .35837 Mdot
.36627 .52601 Mdot
.56927 .50032 Mdot
.3193 .52761 Mdot
.24966 .44555 Mdot
.65662 .50932 Mdot
.42658 .65598 Mdot
.48174 .28226 Mdot
.63217 .51984 Mdot
.35067 .49105 Mdot
.64347 .46654 Mdot
.39287 .56057 Mdot
.50217 .31983 Mdot
.64072 .43259 Mdot
.62955 .68314 Mdot
.36853 .36084 Mdot
.47337 .35283 Mdot
.39626 .21273 Mdot
.64339 .4755 Mdot
.62361 .46296 Mdot
.48009 .30176 Mdot
.39093 .65877 Mdot
.48417 .54658 Mdot
.44361 .30559 Mdot
.37882 .47306 Mdot
.50114 .30616 Mdot
.57232 .47053 Mdot
.39618 .67691 Mdot
.24372 .44318 Mdot
.26829 .4447 Mdot
.7704 .64232 Mdot
.67077 .45289 Mdot
.23136 .41632 Mdot
.40699 .66888 Mdot
.49062 .31705 Mdot
.3761 .49253 Mdot
.58104 .45036 Mdot
.45119 .32076 Mdot
.39534 .50373 Mdot
.63166 .66487 Mdot
.47829 .72402 Mdot
.47363 .35744 Mdot
.51305 .50617 Mdot
.37319 .46397 Mdot
.36817 .47649 Mdot
.79441 .46076 Mdot
.47393 .30113 Mdot
.62127 .67036 Mdot
.3939 .5019 Mdot
.73768 .58597 Mdot
.58118 .45306 Mdot
.78787 .5105 Mdot
.57894 .1655 Mdot
.79512 .43395 Mdot
.28863 .3014 Mdot
.58867 .6557 Mdot
.3949 .49226 Mdot
.64571 .5082 Mdot
.46836 .31363 Mdot
.47641 .31412 Mdot
.61937 .4266 Mdot
.65259 .48579 Mdot
.5937 .44932 Mdot
.61127 .43118 Mdot
.59459 .75978 Mdot
.59817 .44239 Mdot
.43615 .56949 Mdot
.45242 .34105 Mdot
.66074 .48332 Mdot
.40728 .60483 Mdot
.63871 .41941 Mdot
.39688 .51717 Mdot
.61752 .47512 Mdot
.64623 .49367 Mdot
.66988 .51023 Mdot
.377 .4819 Mdot
.23516 .69297 Mdot
.50759 .18392 Mdot
.39437 .77828 Mdot
.32171 .28381 Mdot
.40107 .65859 Mdot
.63231 .4407 Mdot
.61211 .65117 Mdot
.71331 .51703 Mdot
.62762 .47377 Mdot
.77484 .37089 Mdot
.6416 .48996 Mdot
.59375 .36908 Mdot
.68641 .53048 Mdot
.36456 .7807 Mdot
.4297 .46988 Mdot
.65799 .46171 Mdot
.56282 .22314 Mdot
.79896 .51168 Mdot
.57634 .62863 Mdot
.35857 .48957 Mdot
.39468 .61496 Mdot
.39745 .63376 Mdot
.33468 .49133 Mdot
.56348 .47616 Mdot
.52693 .25768 Mdot
.55963 .44707 Mdot
.24283 .43824 Mdot
.46587 .27366 Mdot
.5876 .67523 Mdot
.48461 .35748 Mdot
.46088 .15182 Mdot
.48632 .41067 Mdot
.41475 .51193 Mdot
.62897 .69088 Mdot
.43168 .61774 Mdot
.24097 .43315 Mdot
.61753 .65568 Mdot
.60652 .49263 Mdot
.49916 .3359 Mdot
.80235 .50644 Mdot
.70498 .47897 Mdot
.71627 .75863 Mdot
.45758 .30171 Mdot
.46694 .5108 Mdot
.36516 .48999 Mdot
.41584 .68982 Mdot
.66027 .44904 Mdot
.6007 .44944 Mdot
.51387 .31581 Mdot
.63056 .48782 Mdot
.41036 .3575 Mdot
.64149 .49606 Mdot
.44496 .62386 Mdot
.60668 .61893 Mdot
.33788 .5257 Mdot
.7825 .62375 Mdot
.43893 .34078 Mdot
.47045 .60521 Mdot
.43146 .6309 Mdot
.48008 .24725 Mdot
.36859 .53365 Mdot
.63339 .66801 Mdot
.41327 .61646 Mdot
.60867 .63366 Mdot
.66682 .50305 Mdot
.41349 .62641 Mdot
.60568 .68251 Mdot
.44228 .72884 Mdot
.61099 .50469 Mdot
.70741 .57772 Mdot
.38588 .50963 Mdot
.51023 .33979 Mdot
.65223 .4718 Mdot
.26859 .44849 Mdot
.5753 .44055 Mdot
.20762 .42891 Mdot
.24521 .45183 Mdot
.2328 .44318 Mdot
.24736 .50422 Mdot
.60277 .64193 Mdot
.30499 .3389 Mdot
.49575 .46029 Mdot
.44862 .29831 Mdot
.6116 .51188 Mdot
.29221 .74657 Mdot
.39292 .49926 Mdot
.60709 .49177 Mdot
.32695 .70868 Mdot
.39336 .50244 Mdot
.60799 .46495 Mdot
.36509 .48146 Mdot
.47133 .31217 Mdot
.47879 .57888 Mdot
.47721 .2876 Mdot
.61714 .50463 Mdot
.36143 .51063 Mdot
.40172 .61382 Mdot
.48347 .33171 Mdot
.63972 .4692 Mdot
.63226 .44344 Mdot
.24718 .43308 Mdot
.66304 .47713 Mdot
.31055 .74883 Mdot
.6263 .49442 Mdot
.42663 .61033 Mdot
.64759 .52694 Mdot
.81921 .46231 Mdot
.48349 .71823 Mdot
.44554 .33443 Mdot
.24125 .45017 Mdot
.41391 .63603 Mdot
.51321 .63635 Mdot
.58176 .5923 Mdot
.64252 .45834 Mdot
.25922 .44459 Mdot
.45622 .53136 Mdot
.34602 .49613 Mdot
.61084 .52731 Mdot
.43629 .40483 Mdot
.4234 .62231 Mdot
.24221 .43459 Mdot
.66808 .53773 Mdot
.4837 .28433 Mdot
.62952 .50971 Mdot
.41012 .62121 Mdot
.5056 .31235 Mdot
.5777 .45907 Mdot
.62339 .74471 Mdot
.26044 .45162 Mdot
.3863 .50742 Mdot
.54273 .50397 Mdot
.58789 .45401 Mdot
.39293 .63732 Mdot
.459 .30969 Mdot
.35322 .50642 Mdot
.48346 .34508 Mdot
.80643 .52278 Mdot
.32925 .28993 Mdot
.49222 .78436 Mdot
.62259 .69616 Mdot
.19794 .39421 Mdot
.41264 .78486 Mdot
.33378 .31494 Mdot
.73995 .6536 Mdot
.49891 .83465 Mdot
.40961 .60813 Mdot
.72861 .53616 Mdot
.4066 .63878 Mdot
.65595 .50608 Mdot
.41945 .65375 Mdot
.33968 .78331 Mdot
.63347 .49486 Mdot
.39854 .65585 Mdot
.57279 .7551 Mdot
.65342 .4797 Mdot
.46042 .3498 Mdot
.15811 .50918 Mdot
.45651 .22421 Mdot
.51421 .41838 Mdot
.3961 .66154 Mdot
.73295 .30969 Mdot
.64089 .48599 Mdot
.69308 .45903 Mdot
.47032 .3192 Mdot
.60688 .5277 Mdot
.59842 .68556 Mdot
.62143 .63801 Mdot
.77472 .49336 Mdot
.41441 .22016 Mdot
.59125 .40139 Mdot
.48144 .32755 Mdot
.57517 .19081 Mdot
.33859 .38684 Mdot
.27169 .43706 Mdot
.38147 .46875 Mdot
.23375 .68906 Mdot
.70304 .44041 Mdot
.52247 .51695 Mdot
.41933 .40487 Mdot
.49728 .32393 Mdot
.39161 .75129 Mdot
.35703 .50154 Mdot
.54677 .20566 Mdot
.57557 .3217 Mdot
.59064 .45997 Mdot
.34658 .51528 Mdot
.56304 .50492 Mdot
.41093 .37334 Mdot
.74005 .55119 Mdot
.35672 .59199 Mdot
.61572 .50698 Mdot
.31112 .34652 Mdot
.62277 .46833 Mdot
.78632 .52028 Mdot
.61143 .4974 Mdot
.47631 .34734 Mdot
.59286 .39718 Mdot
.54352 .58619 Mdot
.46394 .19539 Mdot
.46944 .40656 Mdot
.58993 .64702 Mdot
.62675 .44831 Mdot
.59366 .45682 Mdot
.59372 .66752 Mdot
.47357 .33808 Mdot
.59442 .48777 Mdot
.67179 .73047 Mdot
.58882 .45624 Mdot
.39182 .52833 Mdot
.50488 .59939 Mdot
.53359 .32276 Mdot
.64971 .43692 Mdot
.50027 .29984 Mdot
.35637 .48533 Mdot
.39305 .47538 Mdot
.65447 .40781 Mdot
.39148 .4892 Mdot
.63233 .50718 Mdot
.4971 .59168 Mdot
.49163 .30192 Mdot
.62774 .55138 Mdot
.46797 .33737 Mdot
.66062 .22871 Mdot
.3595 .47993 Mdot
.26173 .42846 Mdot
.63424 .57571 Mdot
.36819 .50676 Mdot
.44361 .24005 Mdot
.68918 .42283 Mdot
.60976 .41257 Mdot
.44924 .23336 Mdot
.38913 .63298 Mdot
.24564 .42609 Mdot
.35187 .50096 Mdot
.59143 .45024 Mdot
.65428 .51494 Mdot
.37056 .53828 Mdot
.6815 .28541 Mdot
.52846 .66725 Mdot
.61435 .49852 Mdot
.47482 .34515 Mdot
.49058 .32043 Mdot
.57997 .47335 Mdot
.63127 .47556 Mdot
.41643 .60323 Mdot
.26211 .44452 Mdot
.23481 .43698 Mdot
.26897 .44247 Mdot
.39465 .68703 Mdot
.21859 .36487 Mdot
.36929 .47654 Mdot
.23767 .37936 Mdot
.27217 .64652 Mdot
.67094 .41857 Mdot
.39198 .63364 Mdot
.60535 .4539 Mdot
.66705 .49575 Mdot
.35895 .5128 Mdot
.30789 .25393 Mdot
.55927 .4183 Mdot
.49337 .35694 Mdot
.38515 .53767 Mdot
.67781 .54609 Mdot
.36517 .44131 Mdot
.60793 .68799 Mdot
.49766 .40401 Mdot
.35026 .52178 Mdot
.49347 .33993 Mdot
.36176 .53442 Mdot
.59297 .45493 Mdot
.6271 .42249 Mdot
.49374 .30878 Mdot
.60453 .64074 Mdot
.63761 .52152 Mdot
.60924 .46512 Mdot
.83609 .42286 Mdot
.33717 .37774 Mdot
.35663 .44567 Mdot
.6648 .48849 Mdot
.61554 .40886 Mdot
.59638 .63939 Mdot
.58657 .46653 Mdot
.65815 .44708 Mdot
.37217 .34949 Mdot
.33331 .48936 Mdot
.58253 .63381 Mdot
.53258 .20724 Mdot
.45576 .30501 Mdot
.31514 .74079 Mdot
.24876 .44698 Mdot
.32897 .50637 Mdot
.4728 .57229 Mdot
.25479 .42803 Mdot
.28981 .64178 Mdot
.35906 .74716 Mdot
.26462 .4328 Mdot
.38706 .59882 Mdot
.71895 .43464 Mdot
.59867 .43251 Mdot
.61441 .47405 Mdot
.6178 .65145 Mdot
.47037 .30421 Mdot
.44541 .50437 Mdot
.43734 .71422 Mdot
.62669 .45865 Mdot
.48378 .37886 Mdot
.33551 .73654 Mdot
.24612 .43112 Mdot
.6017 .64741 Mdot
.58329 .67025 Mdot
.62164 .46566 Mdot
.35975 .31519 Mdot
.48427 .32891 Mdot
.63954 .46906 Mdot
.62024 .43364 Mdot
.39284 .65678 Mdot
.49405 .34311 Mdot
.432 .632 Mdot
.24867 .45356 Mdot
.59145 .82048 Mdot
.8403 .44023 Mdot
.3735 .51977 Mdot
.40017 .76855 Mdot
.40572 .50253 Mdot
.30722 .54283 Mdot
.26678 .44083 Mdot
.63481 .46369 Mdot
.44028 .33976 Mdot
.64315 .46827 Mdot
.59234 .47585 Mdot
.60048 .48986 Mdot
.58836 .40218 Mdot
.77989 .37826 Mdot
.61306 .66191 Mdot
.61172 .40713 Mdot
.39133 .61284 Mdot
.35433 .76554 Mdot
.16285 .54892 Mdot
.61548 .44329 Mdot
.6211 .46073 Mdot
.44715 .31802 Mdot
.67613 .44831 Mdot
.34823 .50848 Mdot
.46643 .29913 Mdot
.64759 .51667 Mdot
.42336 .74653 Mdot
.58378 .46412 Mdot
.42793 .78778 Mdot
.36469 .53624 Mdot
.50611 .40119 Mdot
.59251 .41104 Mdot
.26612 .43395 Mdot
.24773 .42571 Mdot
.27512 .43934 Mdot
.34305 .49922 Mdot
.39368 .64893 Mdot
.42061 .71343 Mdot
.61713 .53866 Mdot
.64311 .5077 Mdot
.6038 .41253 Mdot
.40599 .69395 Mdot
.50398 .58273 Mdot
.29097 .30987 Mdot
.71362 .49875 Mdot
.38469 .634 Mdot
.48793 .36777 Mdot
.38681 .20099 Mdot
.46295 .30297 Mdot
.58605 .62902 Mdot
.39125 .52568 Mdot
.6078 .6899 Mdot
.75595 .34051 Mdot
.49615 .30898 Mdot
.51551 .32001 Mdot
.3994 .65786 Mdot
.44664 .47549 Mdot
.09076 .47205 Mdot
.41908 .66943 Mdot
.70787 .70024 Mdot
.47334 .32356 Mdot
.68309 .47855 Mdot
.45215 .53736 Mdot
.45309 .48233 Mdot
.40684 .64918 Mdot
.6412 .44906 Mdot
.40408 .24533 Mdot
.41991 .60549 Mdot
.61946 .52765 Mdot
.39754 .67025 Mdot
.37911 .48451 Mdot
.40401 .66938 Mdot
.4629 .36651 Mdot
.66914 .4974 Mdot
.11242 .40391 Mdot
.35805 .43134 Mdot
.65083 .4689 Mdot
.38939 .53306 Mdot
.6529 .75296 Mdot
.59459 .4688 Mdot
.59938 .6875 Mdot
.38071 .64722 Mdot
.55022 .73214 Mdot
.64396 .48206 Mdot
.4133 .65539 Mdot
.49404 .36022 Mdot
.32478 .47161 Mdot
.26452 .49732 Mdot
.23698 .43193 Mdot
.46528 .31057 Mdot
.28099 .4397 Mdot
.3478 .47482 Mdot
.65489 .5203 Mdot
.61275 .43436 Mdot
.46139 .3464 Mdot
.24517 .53979 Mdot
.68227 .49876 Mdot
.64243 .45192 Mdot
.43292 .62293 Mdot
.39253 .6971 Mdot
.19484 .54816 Mdot
.40724 .60731 Mdot
.6143 .40854 Mdot
.46421 .34757 Mdot
.643 .51359 Mdot
.45533 .34708 Mdot
.61253 .51219 Mdot
.53076 .34584 Mdot
.46494 .30318 Mdot
.36998 .25021 Mdot
.66677 .46099 Mdot
.61894 .565 Mdot
.59204 .47772 Mdot
.60631 .49521 Mdot
.38062 .65341 Mdot
.60546 .67283 Mdot
.63073 .53227 Mdot
.47393 .59276 Mdot
.61939 .64591 Mdot
.71947 .39744 Mdot
.391 .65474 Mdot
.62507 .6586 Mdot
.6715 .61061 Mdot
.24077 .44961 Mdot
.60588 .65824 Mdot
.18723 .59017 Mdot
.37042 .51921 Mdot
.48515 .29427 Mdot
.65422 .4802 Mdot
.53269 .83911 Mdot
.53166 .66026 Mdot
.25485 .43369 Mdot
.645 .47654 Mdot
.60203 .45776 Mdot
.47292 .28144 Mdot
.49243 .14966 Mdot
.44037 .6618 Mdot
.62579 .51511 Mdot
.45739 .2933 Mdot
.56664 .1639 Mdot
.40355 .6779 Mdot
.60608 .65346 Mdot
.37488 .54187 Mdot
.4284 .34902 Mdot
.23795 .42944 Mdot
.34882 .48156 Mdot
.36946 .67321 Mdot
.74425 .31132 Mdot
.63766 .48413 Mdot
.39737 .62472 Mdot
.7944 .42911 Mdot
.581 .51384 Mdot
.37057 .45209 Mdot
.56835 .38237 Mdot
.49638 .32608 Mdot
.37559 .53971 Mdot
.58534 .6516 Mdot
.49051 .29961 Mdot
.47539 .33873 Mdot
.39824 .48475 Mdot
.44067 .58568 Mdot
.46697 .50842 Mdot
.38201 .53658 Mdot
.39625 .37297 Mdot
.7854 .4842 Mdot
.2599 .44636 Mdot
.59951 .64729 Mdot
.81338 .51692 Mdot
.48738 .32726 Mdot
.2346 .69034 Mdot
.78135 .38534 Mdot
.60695 .49857 Mdot
.62037 .68021 Mdot
.29616 .65618 Mdot
.41078 .72009 Mdot
.39278 .50717 Mdot
.51461 .57919 Mdot
.59224 .68533 Mdot
.58523 .44822 Mdot
.53651 .35465 Mdot
.66448 .4599 Mdot
.39433 .49803 Mdot
.40359 .32218 Mdot
.48923 .34684 Mdot
.34415 .47661 Mdot
.41437 .37029 Mdot
.66876 .49119 Mdot
.65499 .45049 Mdot
.78045 .57175 Mdot
.49933 .33766 Mdot
.23606 .43054 Mdot
.64703 .46119 Mdot
.60608 .4731 Mdot
.65838 .5204 Mdot
.59191 .55919 Mdot
.35408 .33881 Mdot
.62635 .51616 Mdot
.39825 .68498 Mdot
.62063 .41531 Mdot
.65773 .45081 Mdot
.47137 .28546 Mdot
.81647 .40836 Mdot
.25504 .45493 Mdot
.61279 .4767 Mdot
.61372 .49676 Mdot
.37912 .47166 Mdot
.46176 .52021 Mdot
.44817 .4722 Mdot
.43202 .65631 Mdot
.73192 .64126 Mdot
.56155 .44496 Mdot
.45257 .32083 Mdot
.62463 .68939 Mdot
.67964 .47222 Mdot
.45067 .31245 Mdot
.60696 .42172 Mdot
.40713 .59988 Mdot
.26116 .44346 Mdot
.51712 .47171 Mdot
.60183 .66017 Mdot
.40226 .56637 Mdot
.26247 .39239 Mdot
.40404 .60507 Mdot
.65063 .50113 Mdot
.32324 .50791 Mdot
.42931 .63379 Mdot
.2489 .43374 Mdot
.67561 .53212 Mdot
.47749 .31733 Mdot
.48832 .34567 Mdot
.78022 .50438 Mdot
.43175 .68378 Mdot
.73936 .26584 Mdot
.38142 .48558 Mdot
.58156 .49269 Mdot
.25237 .40946 Mdot
.48248 .35017 Mdot
.79894 .54258 Mdot
.62354 .65533 Mdot
.39196 .50842 Mdot
.26533 .45836 Mdot
.44934 .31733 Mdot
.48837 .35242 Mdot
.60817 .50522 Mdot
.61693 .44764 Mdot
.73747 .66307 Mdot
.78843 .51439 Mdot
.37003 .4824 Mdot
.59521 .65227 Mdot
.43007 .66846 Mdot
.66635 .49143 Mdot
.47444 .29654 Mdot
.60727 .36825 Mdot
.59215 .4461 Mdot
.42151 .6063 Mdot
.49532 .31786 Mdot
.59163 .66185 Mdot
.6291 .67456 Mdot
.60545 .49498 Mdot
.70711 .36093 Mdot
.37268 .50868 Mdot
.46834 .35282 Mdot
.46171 .25916 Mdot
.67525 .51491 Mdot
.61988 .44572 Mdot
.57968 .52956 Mdot
.34946 .4809 Mdot
.52209 .44612 Mdot
.58931 .6883 Mdot
.47885 .31076 Mdot
.64901 .46769 Mdot
.5992 .65732 Mdot
.53837 .51681 Mdot
.26302 .43429 Mdot
.39914 .6718 Mdot
.59452 .68346 Mdot
.60496 .67867 Mdot
.625 .64918 Mdot
.22562 .67723 Mdot
.45243 .2832 Mdot
.52483 .19983 Mdot
.60023 .49386 Mdot
.7758 .49822 Mdot
.66539 .43976 Mdot
.34137 .49008 Mdot
.39688 .61567 Mdot
.59056 .46909 Mdot
.60817 .50568 Mdot
.53985 .36165 Mdot
.66627 .55296 Mdot
.42406 .36119 Mdot
.50212 .32743 Mdot
.62088 .56784 Mdot
.38871 .64288 Mdot
.55438 .14416 Mdot
.21758 .699 Mdot
.57618 .42479 Mdot
.45433 .50416 Mdot
.46852 .29858 Mdot
.39375 .48264 Mdot
.45918 .48115 Mdot
.36424 .54313 Mdot
.48254 .30979 Mdot
.66154 .50073 Mdot
.24485 .37626 Mdot
.61746 .6384 Mdot
.59704 .44587 Mdot
.37074 .488 Mdot
.59531 .4475 Mdot
.34011 .50006 Mdot
.44904 .38169 Mdot
.39788 .39959 Mdot
.6395 .49105 Mdot
.67825 .50562 Mdot
.53317 .41136 Mdot
.61532 .44449 Mdot
.30533 .61052 Mdot
.46761 .3302 Mdot
.40773 .23312 Mdot
.58283 .47904 Mdot
.69667 .33521 Mdot
.59155 .44323 Mdot
.24692 .55149 Mdot
.63028 .4379 Mdot
.5157 .53574 Mdot
.583 .45078 Mdot
.63472 .44138 Mdot
.35656 .50582 Mdot
.38362 .47252 Mdot
.49258 .36022 Mdot
.24237 .42481 Mdot
.36309 .77858 Mdot
.61322 .45922 Mdot
.38336 .67484 Mdot
.2763 .41713 Mdot
.60544 .67663 Mdot
.48439 .31375 Mdot
.63599 .16981 Mdot
.35934 .48281 Mdot
.44082 .61965 Mdot
.26648 .55841 Mdot
.42698 .68256 Mdot
.37391 .56467 Mdot
.63919 .56821 Mdot
.59194 .6532 Mdot
.59105 .44241 Mdot
.73179 .3926 Mdot
.32086 .35941 Mdot
.61124 .52252 Mdot
.34399 .46696 Mdot
.71224 .52326 Mdot
.78938 .47907 Mdot
.5918 .63487 Mdot
.58615 .66231 Mdot
.35351 .50059 Mdot
.43933 .63487 Mdot
.55953 .47827 Mdot
.6261 .66011 Mdot
.39243 .61696 Mdot
.25717 .42268 Mdot
.58498 .60689 Mdot
.48475 .32556 Mdot
.5129 .42885 Mdot
.31351 .40684 Mdot
.36714 .48265 Mdot
.47395 .58749 Mdot
.44702 .36766 Mdot
.48902 .28162 Mdot
.25851 .42517 Mdot
.37985 .6397 Mdot
.43851 .31438 Mdot
.64609 .52016 Mdot
.70541 .47783 Mdot
.62416 .46776 Mdot
.62516 .66568 Mdot
.63222 .43588 Mdot
.38665 .62107 Mdot
.38911 .49677 Mdot
.4209 .6324 Mdot
.37446 .51078 Mdot
.25265 .3591 Mdot
.63165 .47888 Mdot
.62329 .44806 Mdot
.47101 .55602 Mdot
.49184 .35466 Mdot
.73599 .35958 Mdot
.37771 .65574 Mdot
.40051 .64302 Mdot
.64591 .51346 Mdot
.49978 .35611 Mdot
.63223 .64032 Mdot
.44654 .54939 Mdot
.62428 .43551 Mdot
.46647 .32934 Mdot
.63332 .51269 Mdot
.49176 .77752 Mdot
.38012 .40245 Mdot
.48371 .34612 Mdot
.44805 .19318 Mdot
.6662 .47208 Mdot
.7342 .46907 Mdot
.62668 .40741 Mdot
.68771 .68702 Mdot
.66391 .52537 Mdot
.45913 .29991 Mdot
.6198 .4745 Mdot
.45727 .31575 Mdot
.42443 .61494 Mdot
.38023 .47715 Mdot
.4646 .31413 Mdot
.65867 .44081 Mdot
.18663 .64169 Mdot
.37208 .48551 Mdot
.6302 .44518 Mdot
.36257 .52752 Mdot
.46295 .2914 Mdot
.49917 .34675 Mdot
.19415 .59474 Mdot
.37815 .44545 Mdot
.36748 .4852 Mdot
.63697 .50768 Mdot
.32753 .42922 Mdot
.64262 .51339 Mdot
.74573 .65475 Mdot
.5876 .49451 Mdot
.64382 .52772 Mdot
.19241 .40609 Mdot
.36907 .54769 Mdot
.69573 .22379 Mdot
.43856 .71847 Mdot
.21379 .6607 Mdot
.43219 .31874 Mdot
.5918 .63479 Mdot
.38002 .74825 Mdot
.24897 .45256 Mdot
.38862 .66924 Mdot
.59014 .46874 Mdot
.53255 .33974 Mdot
.38315 .53825 Mdot
.61098 .67292 Mdot
.6406 .49065 Mdot
.4138 .59815 Mdot
.17843 .56292 Mdot
.39525 .49301 Mdot
.48669 .32379 Mdot
.49307 .35539 Mdot
.5342 .1728 Mdot
.64765 .47079 Mdot
.62371 .45168 Mdot
.39346 .52328 Mdot
.56211 .45541 Mdot
.63055 .65244 Mdot
.54248 .76807 Mdot
.36285 .48775 Mdot
.33993 .43612 Mdot
.50271 .31964 Mdot
.60313 .45574 Mdot
.51216 .60529 Mdot
.24931 .65236 Mdot
.55542 .23631 Mdot
.61629 .6515 Mdot
.75804 .61537 Mdot
.45875 .30021 Mdot
.37339 .49087 Mdot
.69948 .56872 Mdot
.57313 .44742 Mdot
.60224 .46194 Mdot
.76143 .60742 Mdot
.45587 .52549 Mdot
.64406 .68385 Mdot
.68352 .45707 Mdot
.46394 .52836 Mdot
.64913 .51248 Mdot
.65559 .5139 Mdot
.57297 .42762 Mdot
.65096 .44167 Mdot
.46212 .32375 Mdot
.54033 .33362 Mdot
.41166 .66334 Mdot
.63717 .24781 Mdot
.51983 .57094 Mdot
.65839 .47144 Mdot
.66466 .4974 Mdot
.49321 .23774 Mdot
.28981 .43301 Mdot
.47136 .32972 Mdot
.52092 .30324 Mdot
.36047 .47661 Mdot
.6555 .55614 Mdot
.42117 .69236 Mdot
.54851 .39114 Mdot
.42651 .63637 Mdot
.46532 .32936 Mdot
.39597 .64213 Mdot
.3611 .4748 Mdot
.3982 .62417 Mdot
.3953 .68674 Mdot
.34672 .52125 Mdot
.50521 .32508 Mdot
.62083 .43721 Mdot
.36195 .47999 Mdot
.7797 .58052 Mdot
.62557 .66666 Mdot
.19293 .59356 Mdot
.67842 .44065 Mdot
.70245 .40511 Mdot
.62345 .74437 Mdot
.4121 .63021 Mdot
.37102 .38945 Mdot
.46496 .30335 Mdot
.63599 .67763 Mdot
.45975 .3199 Mdot
.76054 .3613 Mdot
.59623 .66852 Mdot
.19219 .59562 Mdot
.67678 .58004 Mdot
.50214 .64656 Mdot
.63612 .42855 Mdot
.52181 .36096 Mdot
.42678 .63041 Mdot
.39337 .52662 Mdot
.31598 .68614 Mdot
.67207 .45735 Mdot
.33 .31551 Mdot
.46164 .27833 Mdot
.23712 .44455 Mdot
.37794 .49405 Mdot
.34959 .46412 Mdot
.64333 .474 Mdot
.50622 .62898 Mdot
.61051 .51959 Mdot
.68886 .56462 Mdot
.74401 .63884 Mdot
.55036 .38794 Mdot
.62872 .5085 Mdot
.43258 .64568 Mdot
.63452 .51165 Mdot
.72001 .45536 Mdot
.79319 .46141 Mdot
.67524 .43737 Mdot
.34063 .27395 Mdot
.56549 .72906 Mdot
.49009 .3049 Mdot
.59962 .40724 Mdot
.25309 .43943 Mdot
.66619 .48138 Mdot
.63802 .83275 Mdot
.6065 .66182 Mdot
.39041 .71391 Mdot
.65272 .43528 Mdot
.64569 .46471 Mdot
.68459 .36974 Mdot
.51708 .38353 Mdot
.26209 .45812 Mdot
.60086 .46804 Mdot
.73872 .61581 Mdot
.35405 .51085 Mdot
.57716 .47435 Mdot
.61787 .47188 Mdot
.81179 .55109 Mdot
.3569 .51888 Mdot
.40522 .62834 Mdot
.2428 .45115 Mdot
.42761 .67112 Mdot
.58671 .6361 Mdot
.44473 .456 Mdot
.79648 .52686 Mdot
.3784 .40385 Mdot
.60039 .69005 Mdot
.6281 .43083 Mdot
.73555 .45028 Mdot
.65297 .45538 Mdot
.58588 .65626 Mdot
.35224 .51681 Mdot
.46439 .32216 Mdot
.51098 .46858 Mdot
.2437 .43741 Mdot
.62488 .52748 Mdot
.59298 .63618 Mdot
.47129 .31558 Mdot
.20777 .58327 Mdot
.47667 .30435 Mdot
.36449 .5052 Mdot
.34493 .48033 Mdot
.59919 .66739 Mdot
.46014 .32222 Mdot
.40687 .6831 Mdot
.44147 .7139 Mdot
.59282 .50142 Mdot
.33932 .45158 Mdot
.45494 .35995 Mdot
.51398 .33165 Mdot
.44165 .33014 Mdot
.63418 .48155 Mdot
.45913 .51372 Mdot
.57076 .44889 Mdot
.35236 .48893 Mdot
.39082 .66524 Mdot
.78767 .50857 Mdot
.72907 .38214 Mdot
.36174 .42938 Mdot
.63394 .53141 Mdot
.65372 .44649 Mdot
.62183 .46544 Mdot
.61845 .50111 Mdot
.52475 .77685 Mdot
.63012 .47811 Mdot
.3656 .51169 Mdot
.42338 .65586 Mdot
.64841 .47393 Mdot
.25447 .44215 Mdot
.48378 .52089 Mdot
.62158 .69059 Mdot
.51681 .54182 Mdot
.21891 .68905 Mdot
.47089 .31683 Mdot
.40946 .61577 Mdot
.39566 .67473 Mdot
.63173 .66497 Mdot
.383 .48482 Mdot
.47216 .30494 Mdot
.68136 .67074 Mdot
.61561 .64265 Mdot
.61235 .47755 Mdot
.48715 .58185 Mdot
.42208 .19508 Mdot
.61371 .42795 Mdot
.59983 .48472 Mdot
.23456 .44597 Mdot
.43691 .66806 Mdot
.52577 .85554 Mdot
.43834 .53242 Mdot
.60345 .67118 Mdot
.59321 .6756 Mdot
.44088 .31728 Mdot
.60018 .51951 Mdot
.37935 .50748 Mdot
.45354 .5421 Mdot
.6778 .74288 Mdot
.31349 .70563 Mdot
.29995 .53819 Mdot
.58505 .46812 Mdot
.62529 .3554 Mdot
.61002 .5136 Mdot
.47822 .281 Mdot
.44378 .31761 Mdot
.47678 .32937 Mdot
.35682 .50344 Mdot
.66749 .23518 Mdot
.36853 .51309 Mdot
.22016 .69291 Mdot
.47283 .29445 Mdot
.49432 .69206 Mdot
.39692 .64992 Mdot
.61803 .53774 Mdot
.59401 .65098 Mdot
.30475 .47421 Mdot
.58621 .40954 Mdot
.35427 .31474 Mdot
.39226 .63331 Mdot
.50289 .34039 Mdot
.71381 .45515 Mdot
.38923 .80014 Mdot
.42856 .44627 Mdot
.57008 .69378 Mdot
.75598 .37134 Mdot
.59397 .66679 Mdot
.52944 .23224 Mdot
.62473 .64436 Mdot
.39457 .50312 Mdot
.67154 .45559 Mdot
.66516 .44788 Mdot
.62101 .51127 Mdot
.6284 .48081 Mdot
.35131 .50318 Mdot
.59027 .48794 Mdot
.81888 .46181 Mdot
.25644 .45028 Mdot
.46407 .73238 Mdot
.61935 .68593 Mdot
.33801 .50589 Mdot
.4274 .64606 Mdot
.24583 .42306 Mdot
.79 .61254 Mdot
.58899 .48212 Mdot
.59087 .47379 Mdot
.2711 .44008 Mdot
.56675 .44576 Mdot
.70918 .44891 Mdot
.41438 .65971 Mdot
.44146 .42681 Mdot
.58292 .66208 Mdot
.60747 .68958 Mdot
.3541 .52729 Mdot
.4595 .32017 Mdot
.61892 .65102 Mdot
.43816 .6299 Mdot
.57914 .45386 Mdot
.67644 .50173 Mdot
.45628 .36077 Mdot
.78141 .38529 Mdot
.60913 .63205 Mdot
.68497 .41669 Mdot
.4558 .31051 Mdot
.45885 .27936 Mdot
.59949 .46617 Mdot
.6866 .51144 Mdot
.51127 .32362 Mdot
.62208 .68628 Mdot
.33905 .50967 Mdot
.50367 .66395 Mdot
.39176 .49572 Mdot
.46944 .30885 Mdot
.59084 .42855 Mdot
.50438 .32313 Mdot
.6649 .47569 Mdot
.39873 .13766 Mdot
.6431 .43883 Mdot
.4446 .23584 Mdot
.6941 .68661 Mdot
.40047 .67569 Mdot
.41196 .68169 Mdot
.25835 .44349 Mdot
.45712 .30529 Mdot
.67888 .47517 Mdot
.58981 .66877 Mdot
.20134 .64111 Mdot
.47565 .26661 Mdot
.38399 .64186 Mdot
.4276 .68517 Mdot
.35029 .50994 Mdot
.59963 .43681 Mdot
.60716 .4544 Mdot
.39924 .62463 Mdot
.61316 .75101 Mdot
.45316 .32781 Mdot
.62421 .45185 Mdot
.65731 .44887 Mdot
.41354 .66509 Mdot
.44452 .71413 Mdot
.49921 .38471 Mdot
.65198 .44265 Mdot
.66989 .58649 Mdot
.34169 .4944 Mdot
.62842 .50002 Mdot
.59382 .49194 Mdot
.61364 .67905 Mdot
.45298 .74598 Mdot
.7903 .47404 Mdot
.33708 .49137 Mdot
.23511 .43379 Mdot
.66912 .44648 Mdot
.39855 .65133 Mdot
.68263 .48027 Mdot
.47743 .81039 Mdot
.24917 .44993 Mdot
.63393 .46907 Mdot
.57279 .43154 Mdot
.46793 .35489 Mdot
.63757 .46861 Mdot
.55088 .37354 Mdot
.42639 .66493 Mdot
.6344 .47036 Mdot
.71049 .35837 Mdot
.34947 .50433 Mdot
.59173 .40883 Mdot
.59184 .67834 Mdot
.68483 .69479 Mdot
.28502 .39835 Mdot
.39419 .6906 Mdot
.62657 .67838 Mdot
.62891 .43506 Mdot
.43471 .6278 Mdot
.37767 .54242 Mdot
.34103 .308 Mdot
.59879 .431 Mdot
.38693 .49034 Mdot
.38641 .49481 Mdot
.602 .66606 Mdot
.63721 .1833 Mdot
.56719 .43735 Mdot
.61763 .44139 Mdot
.77213 .67541 Mdot
.44823 .29501 Mdot
.61739 .43979 Mdot
.60579 .43495 Mdot
.38355 .51157 Mdot
.62305 .57971 Mdot
.42853 .27136 Mdot
.57295 .75532 Mdot
.33999 .49858 Mdot
.37503 .64532 Mdot
.4325 .62602 Mdot
.62215 .68321 Mdot
.49116 .30787 Mdot
.59549 .68988 Mdot
.40259 .66357 Mdot
.60746 .49684 Mdot
.38756 .51721 Mdot
.59431 .26462 Mdot
.40086 .51262 Mdot
.42442 .60604 Mdot
.50647 .30625 Mdot
.24031 .40923 Mdot
.81333 .65785 Mdot
.30894 .39572 Mdot
.33578 .50713 Mdot
.60593 .67697 Mdot
.43248 .55286 Mdot
.65348 .44687 Mdot
.52793 .21724 Mdot
.60656 .44047 Mdot
.75915 .3748 Mdot
.39494 .61654 Mdot
.26351 .4276 Mdot
.6724 .45654 Mdot
.75292 .61646 Mdot
.33595 .50381 Mdot
.34788 .50389 Mdot
.61461 .4888 Mdot
.36644 .50684 Mdot
.61389 .45215 Mdot
.41763 .66645 Mdot
.65285 .19556 Mdot
.64252 .44354 Mdot
.64996 .41796 Mdot
.33103 .49383 Mdot
.19239 .59359 Mdot
.37945 .62989 Mdot
.63671 .35798 Mdot
.40869 .81271 Mdot
.36981 .50623 Mdot
.63356 .40673 Mdot
.41271 .62466 Mdot
.23317 .44441 Mdot
.40904 .58511 Mdot
.59831 .44834 Mdot
.59098 .48023 Mdot
.63848 .51636 Mdot
.65645 .4514 Mdot
.51619 .22049 Mdot
.70988 .49865 Mdot
.60235 .3321 Mdot
.59273 .47747 Mdot
.4918 .25645 Mdot
.36162 .51237 Mdot
.42815 .3658 Mdot
.63268 .69914 Mdot
.5921 .48389 Mdot
.52251 .38087 Mdot
.33742 .50058 Mdot
.23487 .70366 Mdot
.35337 .5148 Mdot
.41667 .63656 Mdot
.39647 .48655 Mdot
.66341 .47562 Mdot
.49109 .32267 Mdot
.4249 .66216 Mdot
.28213 .32236 Mdot
.38631 .66449 Mdot
.65045 .46938 Mdot
.46527 .71426 Mdot
.39853 .67436 Mdot
.49477 .52691 Mdot
.49178 .31825 Mdot
.74046 .60277 Mdot
.45236 .29142 Mdot
.63777 .4632 Mdot
.63906 .45795 Mdot
.24206 .42325 Mdot
.39503 .49169 Mdot
.46406 .29233 Mdot
.83492 .41763 Mdot
.57912 .65006 Mdot
.48114 .33491 Mdot
.6742 .52343 Mdot
.45297 .5182 Mdot
.47153 .3516 Mdot
.71396 .64058 Mdot
.3944 .49465 Mdot
.43878 .32089 Mdot
.66104 .53731 Mdot
.53314 .53121 Mdot
.63265 .65044 Mdot
.4036 .59955 Mdot
.48555 .48483 Mdot
.43266 .63562 Mdot
.33945 .47881 Mdot
.4452 .6432 Mdot
.35617 .51269 Mdot
.45158 .23268 Mdot
.40489 .32199 Mdot
.33281 .52628 Mdot
.34564 .47778 Mdot
.4054 .65684 Mdot
.61663 .49962 Mdot
.53707 .59251 Mdot
.66086 .53055 Mdot
.62894 .42412 Mdot
.34821 .48528 Mdot
.45525 .30051 Mdot
.49923 .30555 Mdot
.51979 .35707 Mdot
.49475 .35107 Mdot
.42866 .64803 Mdot
.38059 .39001 Mdot
.75157 .34456 Mdot
.36768 .53266 Mdot
.4122 .51897 Mdot
.64837 .51088 Mdot
.40078 .6541 Mdot
.41874 .60906 Mdot
.38544 .50512 Mdot
.58193 .23414 Mdot
.61143 .41053 Mdot
.46774 .28416 Mdot
.47403 .29451 Mdot
.47142 .34991 Mdot
.45185 .35149 Mdot
.62313 .21327 Mdot
.39357 .5264 Mdot
.46292 .29944 Mdot
.62131 .48312 Mdot
.58679 .46288 Mdot
.23821 .43505 Mdot
.60651 .68593 Mdot
.66163 .43091 Mdot
.65073 .42213 Mdot
.59927 .46404 Mdot
.39841 .67245 Mdot
.61395 .54484 Mdot
.24617 .4477 Mdot
.44232 .65765 Mdot
.41012 .69399 Mdot
.25968 .4273 Mdot
.44203 .27584 Mdot
.38149 .80618 Mdot
.62623 .51509 Mdot
.72438 .52208 Mdot
.40221 .64872 Mdot
.38862 .3164 Mdot
.5267 .43788 Mdot
.63132 .50638 Mdot
.56885 .58305 Mdot
.41984 .66698 Mdot
.47348 .2738 Mdot
.60925 .44286 Mdot
.26742 .44284 Mdot
.62624 .68677 Mdot
.65966 .53588 Mdot
.23551 .44761 Mdot
.46361 .33012 Mdot
.56556 .71109 Mdot
.44125 .30627 Mdot
.40222 .67909 Mdot
.59225 .40789 Mdot
.08929 .45771 Mdot
.42654 .62755 Mdot
.25866 .6931 Mdot
.40792 .34786 Mdot
.64547 .44312 Mdot
.43179 .63214 Mdot
.47733 .27568 Mdot
.34228 .49306 Mdot
.47214 .53344 Mdot
.47616 .2972 Mdot
.2505 .42288 Mdot
.24281 .42835 Mdot
.41284 .66349 Mdot
.49971 .32624 Mdot
.58644 .48874 Mdot
.45046 .34298 Mdot
.39867 .48995 Mdot
.64742 .49294 Mdot
.36543 .78146 Mdot
.70543 .47562 Mdot
.45431 .31087 Mdot
.43585 .61901 Mdot
.59906 .63955 Mdot
.63805 .49073 Mdot
.3036 .72849 Mdot
.60378 .43484 Mdot
.35735 .52353 Mdot
.3877 .28647 Mdot
.58068 .26495 Mdot
.61224 .49769 Mdot
.65817 .5051 Mdot
.35398 .52821 Mdot
.61153 .49901 Mdot
.61013 .42955 Mdot
.35756 .45252 Mdot
.47759 .35419 Mdot
.62671 .46492 Mdot
.40597 .60271 Mdot
.76399 .41306 Mdot
.67439 .45042 Mdot
.32814 .27215 Mdot
.74635 .60922 Mdot
.39552 .28004 Mdot
.67987 .45939 Mdot
.78466 .57751 Mdot
.6364 .45351 Mdot
.63243 .48724 Mdot
.62652 .51244 Mdot
.59887 .3524 Mdot
.40264 .65945 Mdot
.38361 .63399 Mdot
.63768 .65961 Mdot
.74465 .61506 Mdot
.62122 .67766 Mdot
.3435 .51349 Mdot
.2463 .50723 Mdot
.255 .44963 Mdot
.45873 .31837 Mdot
.66581 .50331 Mdot
.39021 .67615 Mdot
.60157 .45367 Mdot
.66424 .48487 Mdot
.41254 .67303 Mdot
.43025 .62752 Mdot
.43812 .67522 Mdot
.61771 .64137 Mdot
.47016 .32375 Mdot
.60982 .50466 Mdot
.61836 .64548 Mdot
.58125 .48068 Mdot
.4466 .52999 Mdot
.47113 .32641 Mdot
.45243 .34594 Mdot
.48327 .28968 Mdot
.59911 .49241 Mdot
.66113 .47579 Mdot
.37024 .51347 Mdot
.45376 .36009 Mdot
.37405 .53631 Mdot
.4317 .63602 Mdot
.40889 .6803 Mdot
.59761 .44883 Mdot
.70266 .43346 Mdot
.59582 .67642 Mdot
.41385 .63382 Mdot
.27152 .4469 Mdot
.63786 .66339 Mdot
.64418 .47722 Mdot
.4317 .64084 Mdot
.60393 .68856 Mdot
.6282 .25399 Mdot
.45149 .83121 Mdot
.59905 .6373 Mdot
.61481 .48755 Mdot
.69879 .37217 Mdot
.72222 .55595 Mdot
.57797 .65693 Mdot
.37272 .53178 Mdot
.59978 .43848 Mdot
.63276 .7597 Mdot
.58518 .67675 Mdot
.7843 .39392 Mdot
.40739 .67328 Mdot
.6496 .57307 Mdot
.66794 .53295 Mdot
.56183 .21229 Mdot
.58981 .68484 Mdot
.47454 .3078 Mdot
.44353 .35309 Mdot
.61154 .48302 Mdot
.59298 .69611 Mdot
.39906 .4814 Mdot
.39687 .67686 Mdot
.38931 .68103 Mdot
.49821 .33178 Mdot
.37374 .41833 Mdot
.41373 .60368 Mdot
.57279 .41229 Mdot
.39123 .59088 Mdot
.62146 .56041 Mdot
.56081 .18733 Mdot
.26783 .33643 Mdot
.67222 .50793 Mdot
.59278 .64131 Mdot
.36447 .54026 Mdot
.36886 .51121 Mdot
.35939 .50094 Mdot
.41927 .67826 Mdot
.46929 .49163 Mdot
.39417 .62546 Mdot
.32777 .32852 Mdot
.59948 .65644 Mdot
.7298 .59644 Mdot
.67873 .46619 Mdot
.6483 .44475 Mdot
.57673 .46306 Mdot
.64135 .51652 Mdot
.63479 .4531 Mdot
.3699 .48304 Mdot
.42174 .68328 Mdot
.55461 .73699 Mdot
.47112 .34547 Mdot
.20824 .54893 Mdot
.39665 .64958 Mdot
.23925 .44948 Mdot
.61464 .66479 Mdot
.79054 .53133 Mdot
.37642 .67918 Mdot
.39672 .64213 Mdot
.58844 .43623 Mdot
.44792 .3085 Mdot
.5799 .55336 Mdot
.64226 .45161 Mdot
.413 .63249 Mdot
.43627 .61301 Mdot
.54016 .24085 Mdot
.5507 .45835 Mdot
.61832 .62772 Mdot
.45444 .51362 Mdot
.59451 .6922 Mdot
.69337 .50045 Mdot
.38705 .31952 Mdot
.40422 .66268 Mdot
.41903 .64236 Mdot
.58823 .64143 Mdot
.72712 .45239 Mdot
.49717 .31768 Mdot
.26549 .429 Mdot
.36801 .52751 Mdot
.64815 .45425 Mdot
.42351 .67341 Mdot
.7218 .51994 Mdot
.48335 .58068 Mdot
.36123 .4909 Mdot
.44111 .66082 Mdot
.58952 .44592 Mdot
.6107 .48882 Mdot
.59544 .67003 Mdot
.53486 .6395 Mdot
.6665 .53028 Mdot
.21453 .66171 Mdot
.4039 .40161 Mdot
.46442 .40778 Mdot
.60253 .46163 Mdot
.49613 .34049 Mdot
.2672 .43971 Mdot
.59967 .64666 Mdot
.57937 .46771 Mdot
.42352 .82585 Mdot
.47172 .37173 Mdot
.37545 .48792 Mdot
.26796 .43862 Mdot
.47213 .49501 Mdot
.60566 .434 Mdot
.60683 .44053 Mdot
.63143 .48117 Mdot
.44621 .83864 Mdot
.38999 .62085 Mdot
.44381 .33967 Mdot
.61805 .65339 Mdot
.47434 .35803 Mdot
.3822 .64228 Mdot
.49888 .45408 Mdot
.64834 .47643 Mdot
.47469 .28354 Mdot
.47722 .30721 Mdot
.34992 .50959 Mdot
.34677 .48249 Mdot
.4053 .70756 Mdot
.63997 .43859 Mdot
.265 .4468 Mdot
.44691 .30385 Mdot
.43922 .65757 Mdot
.59528 .66753 Mdot
.35947 .47852 Mdot
.59409 .48062 Mdot
.40925 .66239 Mdot
.62861 .52483 Mdot
.45606 .34552 Mdot
.39693 .64335 Mdot
.24431 .45502 Mdot
.59672 .6789 Mdot
.5927 .48149 Mdot
.58558 .72798 Mdot
.26689 .43294 Mdot
.66458 .45428 Mdot
.71132 .39821 Mdot
.61939 .70767 Mdot
.28433 .31739 Mdot
.40288 .61414 Mdot
.24856 .44354 Mdot
.443 .32327 Mdot
.54087 .53051 Mdot
.42202 .64377 Mdot
.61837 .37487 Mdot
.53834 .61167 Mdot
.61196 .50459 Mdot
.48845 .33514 Mdot
.63105 .62603 Mdot
.23529 .69526 Mdot
.70125 .57522 Mdot
.62472 .45552 Mdot
.43284 .63392 Mdot
.61036 .69057 Mdot
.36205 .53028 Mdot
.32996 .27166 Mdot
.55833 .19083 Mdot
.43639 .67426 Mdot
.62037 .51552 Mdot
.44682 .30476 Mdot
.38554 .50299 Mdot
.24125 .372 Mdot
.43757 .62708 Mdot
.40102 .60934 Mdot
.64089 .48343 Mdot
.61283 .64749 Mdot
.59914 .75872 Mdot
.38615 .6257 Mdot
.42699 .67393 Mdot
.20254 .55267 Mdot
.60681 .63296 Mdot
.61952 .48133 Mdot
.51989 .35706 Mdot
.58234 .44771 Mdot
.22363 .66276 Mdot
.25108 .44648 Mdot
.46783 .34456 Mdot
.59093 .45219 Mdot
.56286 .72981 Mdot
.42657 .64038 Mdot
.4549 .50249 Mdot
.45002 .64283 Mdot
.3761 .48243 Mdot
.42253 .67315 Mdot
.60733 .44663 Mdot
.33483 .49009 Mdot
.59808 .67813 Mdot
.65141 .44226 Mdot
.66127 .47852 Mdot
.47885 .27788 Mdot
.395 .5091 Mdot
.76628 .44924 Mdot
.38048 .46676 Mdot
.36188 .5343 Mdot
.44882 .28362 Mdot
.61169 .48048 Mdot
.40925 .63614 Mdot
.40669 .59718 Mdot
.59157 .49234 Mdot
.38984 .32154 Mdot
.49735 .32362 Mdot
.38224 .70783 Mdot
.52527 .85316 Mdot
.5568 .45467 Mdot
.26344 .45203 Mdot
.75737 .49446 Mdot
.34513 .49905 Mdot
.60473 .49028 Mdot
.45442 .31866 Mdot
.43097 .67254 Mdot
.41241 .60224 Mdot
.57765 .44712 Mdot
.38914 .50029 Mdot
.61481 .69237 Mdot
.41053 .60798 Mdot
.47907 .57784 Mdot
.63767 .47224 Mdot
.32922 .31335 Mdot
.41119 .61152 Mdot
.15961 .57254 Mdot
.55852 .73216 Mdot
.48403 .34442 Mdot
.66232 .49253 Mdot
.49387 .35782 Mdot
.62087 .65854 Mdot
.40387 .58031 Mdot
.39049 .49933 Mdot
.58783 .39132 Mdot
.82594 .5183 Mdot
.39927 .65826 Mdot
.46317 .32514 Mdot
.60307 .49587 Mdot
.58802 .39393 Mdot
.62788 .43696 Mdot
.61 .58162 Mdot
.60349 .72093 Mdot
.35328 .47605 Mdot
.35302 .52154 Mdot
.66822 .49209 Mdot
.62631 .64788 Mdot
.39108 .60826 Mdot
.40966 .6724 Mdot
.54822 .13738 Mdot
.2418 .45432 Mdot
.72405 .67837 Mdot
.59707 .48811 Mdot
.43336 .67307 Mdot
.73241 .38505 Mdot
.39312 .52385 Mdot
.59681 .51195 Mdot
.41037 .68969 Mdot
.24103 .63451 Mdot
.4502 .52897 Mdot
.63184 .46485 Mdot
.56115 .45979 Mdot
.36312 .52696 Mdot
.43399 .54801 Mdot
.39487 .62601 Mdot
.58368 .49159 Mdot
.36615 .46408 Mdot
.1926 .56884 Mdot
.82912 .48891 Mdot
.47065 .32408 Mdot
.43594 .61732 Mdot
.37473 .48265 Mdot
.58627 .52872 Mdot
.61858 .68668 Mdot
.43272 .65985 Mdot
.39073 .66955 Mdot
.65059 .49593 Mdot
.66757 .43549 Mdot
.55693 .44874 Mdot
.47241 .33739 Mdot
.37359 .51758 Mdot
.67545 .4695 Mdot
.39013 .41453 Mdot
.63298 .51816 Mdot
.37678 .51535 Mdot
.1825 .29963 Mdot
.60114 .42831 Mdot
.62217 .43941 Mdot
.6575 .668 Mdot
.49614 .30567 Mdot
.4842 .35577 Mdot
.38931 .39688 Mdot
.59657 .48751 Mdot
.50821 .64467 Mdot
.46825 .32084 Mdot
.49603 .32525 Mdot
.48784 .69889 Mdot
.64263 .49682 Mdot
.40617 .56549 Mdot
.38066 .50791 Mdot
.37004 .48091 Mdot
.46315 .35295 Mdot
.62008 .53832 Mdot
.37297 .54185 Mdot
.49697 .21704 Mdot
.39406 .64962 Mdot
.38679 .31907 Mdot
.44841 .33009 Mdot
.52399 .62026 Mdot
.39513 .49853 Mdot
.19037 .66815 Mdot
.53507 .54207 Mdot
.60733 .51516 Mdot
.612 .49312 Mdot
.6111 .68074 Mdot
.66189 .41014 Mdot
.23468 .43564 Mdot
.3644 .50658 Mdot
.46494 .77959 Mdot
.47769 .32983 Mdot
.62664 .43965 Mdot
.78376 .51422 Mdot
.2644 .36928 Mdot
.35043 .26892 Mdot
.48767 .30367 Mdot
.48638 .33019 Mdot
.38895 .63923 Mdot
.39279 .66199 Mdot
.62377 .4742 Mdot
.35831 .50644 Mdot
.43834 .33877 Mdot
.37577 .52272 Mdot
.40341 .66391 Mdot
.40018 .64113 Mdot
.24631 .44966 Mdot
.57954 .50574 Mdot
.4064 .67671 Mdot
.20072 .58761 Mdot
.39372 .41593 Mdot
.49032 .27907 Mdot
.80908 .65818 Mdot
.23562 .37336 Mdot
.66306 .68898 Mdot
.63079 .68178 Mdot
.22721 .44845 Mdot
.38928 .47645 Mdot
.66526 .49762 Mdot
.59252 .46207 Mdot
.24684 .43069 Mdot
.38655 .48333 Mdot
.61537 .67112 Mdot
.39535 .49177 Mdot
.60243 .6489 Mdot
.37851 .65023 Mdot
.67353 .44971 Mdot
.61506 .43208 Mdot
.36241 .48577 Mdot
.40217 .62814 Mdot
.40122 .67773 Mdot
.63652 .66597 Mdot
.78502 .53954 Mdot
.41141 .66445 Mdot
.4484 .33213 Mdot
.71795 .31384 Mdot
.24359 .42861 Mdot
.61102 .44288 Mdot
.79035 .52035 Mdot
.54277 .2308 Mdot
.61473 .50849 Mdot
.26813 .43756 Mdot
.56856 .14405 Mdot
.67171 .45222 Mdot
.55175 .15824 Mdot
.24416 .44371 Mdot
.50416 .31682 Mdot
.41414 .62198 Mdot
.2347 .43211 Mdot
.60108 .53747 Mdot
.58979 .6251 Mdot
.67576 .43901 Mdot
.48103 .29781 Mdot
.49395 .29381 Mdot
.4106 .37097 Mdot
.2274 .666 Mdot
.59869 .64279 Mdot
.60918 .6697 Mdot
.42184 .64753 Mdot
.25836 .47356 Mdot
.68381 .50776 Mdot
.60824 .6721 Mdot
.51343 .79093 Mdot
.64536 .51145 Mdot
.75275 .644 Mdot
.56582 .5813 Mdot
.49673 .33832 Mdot
.42231 .29822 Mdot
.42454 .64311 Mdot
.46375 .32515 Mdot
.48209 .42283 Mdot
.57694 .46297 Mdot
.47336 .32818 Mdot
.38024 .51464 Mdot
.30399 .64232 Mdot
.4998 .34945 Mdot
.46994 .54301 Mdot
.3793 .50656 Mdot
.61704 .70726 Mdot
.67764 .61933 Mdot
.62116 .85159 Mdot
.36264 .50681 Mdot
.41349 .62744 Mdot
.40546 .678 Mdot
.41537 .66573 Mdot
.47654 .29688 Mdot
.4263 .61775 Mdot
.46608 .33966 Mdot
.42342 .71868 Mdot
.79137 .56012 Mdot
.59781 .66496 Mdot
.3669 .44537 Mdot
.4827 .31561 Mdot
.34542 .35984 Mdot
.82138 .62577 Mdot
.61714 .48815 Mdot
.37273 .46514 Mdot
.58682 .6449 Mdot
.20272 .46076 Mdot
.61488 .67893 Mdot
.41206 .62396 Mdot
.38603 .31825 Mdot
.6149 .45279 Mdot
.55911 .37464 Mdot
.5894 .67176 Mdot
.48294 .30026 Mdot
.66126 .45099 Mdot
.41479 .7082 Mdot
.62588 .67704 Mdot
.62559 .68681 Mdot
.63252 .45071 Mdot
.50177 .3389 Mdot
.4034 .63716 Mdot
.38052 .47321 Mdot
.64384 .67807 Mdot
.60033 .53052 Mdot
.6163 .50169 Mdot
.57917 .48995 Mdot
.4468 .4734 Mdot
.61223 .76076 Mdot
.37164 .50572 Mdot
.74426 .53727 Mdot
.39807 .66815 Mdot
.68526 .58154 Mdot
.33879 .3905 Mdot
.36376 .44711 Mdot
.24973 .44636 Mdot
.25311 .44748 Mdot
.63238 .46022 Mdot
.59233 .77499 Mdot
.39997 .23661 Mdot
.38563 .45949 Mdot
.25234 .42717 Mdot
.4006 .6773 Mdot
.4585 .36647 Mdot
.44172 .38806 Mdot
.65668 .43143 Mdot
.34864 .48137 Mdot
.4073 .6676 Mdot
.48142 .81165 Mdot
.60156 .6571 Mdot
.3758 .37172 Mdot
.65059 .47268 Mdot
.62264 .44964 Mdot
.37652 .49725 Mdot
.37047 .51295 Mdot
.32349 .29369 Mdot
.41261 .39256 Mdot
.32615 .71417 Mdot
.40117 .56299 Mdot
.51265 .8161 Mdot
.4579 .37937 Mdot
.45334 .31505 Mdot
.24591 .45226 Mdot
.35822 .53419 Mdot
.6111 .43877 Mdot
.50305 .31236 Mdot
.35524 .26576 Mdot
.44282 .28595 Mdot
.75123 .63719 Mdot
.51261 .64426 Mdot
.65678 .46307 Mdot
.44666 .31203 Mdot
.46601 .32602 Mdot
.46707 .35909 Mdot
.26084 .42851 Mdot
.60199 .46599 Mdot
.61729 .49937 Mdot
.67127 .45721 Mdot
.63592 .39657 Mdot
.63819 .46954 Mdot
.3407 .40164 Mdot
.34142 .43594 Mdot
.45546 .76235 Mdot
.6126 .51012 Mdot
.38897 .48786 Mdot
.66404 .50634 Mdot
.62987 .65329 Mdot
.6182 .51541 Mdot
.73995 .66484 Mdot
.3642 .49689 Mdot
.72184 .442 Mdot
.38345 .58769 Mdot
.65168 .47298 Mdot
.59993 .68926 Mdot
.60763 .76158 Mdot
.79944 .49451 Mdot
.20241 .55978 Mdot
.4485 .33396 Mdot
.39542 .69948 Mdot
.40183 .49601 Mdot
.41019 .63756 Mdot
.59676 .5072 Mdot
.25874 .45302 Mdot
.20202 .38545 Mdot
.51771 .60177 Mdot
.60374 .43995 Mdot
.68866 .52599 Mdot
.48683 .34763 Mdot
.42774 .63444 Mdot
.43752 .36727 Mdot
.63231 .48493 Mdot
.62192 .6565 Mdot
.62245 .65231 Mdot
.4396 .40426 Mdot
.41915 .77821 Mdot
.55782 .54326 Mdot
.37597 .4994 Mdot
.41609 .60317 Mdot
.58925 .68374 Mdot
.4526 .23446 Mdot
.40057 .48229 Mdot
.34516 .49874 Mdot
.39283 .51215 Mdot
.65505 .45805 Mdot
.24034 .44553 Mdot
.47111 .7937 Mdot
.24455 .42365 Mdot
.65486 .47296 Mdot
.38809 .66102 Mdot
.23377 .43284 Mdot
.61685 .68078 Mdot
.3533 .52588 Mdot
.39588 .66293 Mdot
.63967 .46126 Mdot
.47243 .31924 Mdot
.77224 .51245 Mdot
.68123 .72616 Mdot
.42366 .73127 Mdot
.42899 .73148 Mdot
.47753 .29067 Mdot
.30245 .75036 Mdot
.3389 .45181 Mdot
.57676 .23267 Mdot
.61451 .61593 Mdot
.59251 .49433 Mdot
.71152 .24895 Mdot
.3974 .62256 Mdot
.42706 .65571 Mdot
.63112 .46899 Mdot
.43891 .64126 Mdot
.62707 .43865 Mdot
.38777 .63581 Mdot
.27396 .69034 Mdot
.64937 .43116 Mdot
.42735 .6532 Mdot
.68508 .50853 Mdot
.64435 .48637 Mdot
.49125 .34612 Mdot
.43311 .66289 Mdot
.61224 .51855 Mdot
.18854 .3913 Mdot
.35069 .49484 Mdot
.25671 .42638 Mdot
.33666 .44522 Mdot
.39727 .50061 Mdot
.48144 .33964 Mdot
.66946 .44281 Mdot
.59483 .67249 Mdot
.47387 .31084 Mdot
.41308 .70378 Mdot
.58685 .66532 Mdot
.38023 .39296 Mdot
.45033 .33944 Mdot
.24114 .43257 Mdot
.59334 .67463 Mdot
.66335 .42314 Mdot
.41993 .67089 Mdot
.6904 .73251 Mdot
.24573 .42389 Mdot
.60754 .45321 Mdot
.39601 .59378 Mdot
.3956 .4941 Mdot
.61942 .46937 Mdot
.43356 .63353 Mdot
.26471 .4315 Mdot
.66384 .46524 Mdot
.66449 .45717 Mdot
.46415 .39783 Mdot
.374 .2795 Mdot
.59759 .67166 Mdot
.46315 .27878 Mdot
.62277 .48188 Mdot
.62558 .64599 Mdot
.28641 .54756 Mdot
.66686 .50913 Mdot
.50045 .35331 Mdot
.54415 .40093 Mdot
.39196 .6624 Mdot
.37145 .53582 Mdot
.42114 .60304 Mdot
.62562 .68814 Mdot
.84701 .41349 Mdot
.2383 .44643 Mdot
.63571 .54397 Mdot
.57637 .47029 Mdot
.42699 .59274 Mdot
.46902 .32977 Mdot
.30849 .68003 Mdot
.59422 .48375 Mdot
.70093 .51155 Mdot
.62304 .44497 Mdot
.55378 .72996 Mdot
.49678 .32041 Mdot
.61622 .44285 Mdot
.71749 .47475 Mdot
.68119 .45817 Mdot
.60575 .69186 Mdot
.71254 .60401 Mdot
.66022 .51062 Mdot
.08902 .51453 Mdot
.27105 .44205 Mdot
.4136 .67174 Mdot
.45648 .57809 Mdot
.35079 .57525 Mdot
.56573 .18612 Mdot
.46896 .33874 Mdot
.55989 .52075 Mdot
.40642 .63702 Mdot
.80753 .45858 Mdot
.2755 .73085 Mdot
.64778 .48327 Mdot
.58887 .44799 Mdot
.41211 .62399 Mdot
.43464 .6693 Mdot
.25832 .45145 Mdot
.60866 .511 Mdot
.67737 .53109 Mdot
.44201 .63314 Mdot
.64564 .46413 Mdot
.53679 .28749 Mdot
.3617 .47214 Mdot
.47484 .35602 Mdot
.36253 .53059 Mdot
.34597 .49353 Mdot
.66961 .25849 Mdot
.40394 .40117 Mdot
.37448 .51526 Mdot
.40257 .47649 Mdot
.74345 .66534 Mdot
.55252 .39735 Mdot
.59917 .69199 Mdot
.37939 .75817 Mdot
.41916 .65693 Mdot
.60159 .46831 Mdot
.46361 .29525 Mdot
.58763 .21648 Mdot
.27007 .61046 Mdot
.37806 .32473 Mdot
.61807 .4948 Mdot
.42493 .6483 Mdot
.25939 .42634 Mdot
.65373 .4323 Mdot
.68989 .57698 Mdot
.62301 .45262 Mdot
.39972 .67999 Mdot
.70193 .27717 Mdot
.55315 .38252 Mdot
.40657 .56844 Mdot
.50289 .27972 Mdot
.67734 .47054 Mdot
.45421 .33849 Mdot
.38587 .48864 Mdot
.61995 .64272 Mdot
.60428 .67518 Mdot
.65585 .44841 Mdot
.40482 .32062 Mdot
.58005 .59546 Mdot
.64207 .48712 Mdot
.64813 .49577 Mdot
.24689 .44407 Mdot
.64792 .49506 Mdot
.5781 .47551 Mdot
.67119 .48933 Mdot
.65218 .52315 Mdot
.36135 .53432 Mdot
.68972 .38675 Mdot
.64537 .52116 Mdot
.55359 .4756 Mdot
.35525 .47754 Mdot
.60178 .54804 Mdot
.35346 .51371 Mdot
.37585 .78088 Mdot
.36191 .52183 Mdot
.60216 .6729 Mdot
.38716 .60907 Mdot
.61694 .56414 Mdot
.43785 .33323 Mdot
.343 .48506 Mdot
.60971 .65552 Mdot
.36119 .50412 Mdot
.39679 .60846 Mdot
.77933 .67914 Mdot
.43967 .29273 Mdot
.44218 .53956 Mdot
.56345 .56684 Mdot
.32857 .31132 Mdot
.39145 .6499 Mdot
.4966 .33381 Mdot
.54897 .37604 Mdot
.67153 .48448 Mdot
.60122 .68011 Mdot
.6315 .45855 Mdot
.35958 .532 Mdot
.42222 .65439 Mdot
.45841 .71879 Mdot
.5993 .67432 Mdot
.84287 .52317 Mdot
.38727 .66955 Mdot
.61381 .42164 Mdot
.34997 .47834 Mdot
.81231 .65001 Mdot
.36043 .52229 Mdot
.79469 .55203 Mdot
.51328 .3498 Mdot
.72504 .29515 Mdot
.48783 .32499 Mdot
.35773 .25313 Mdot
.36521 .82174 Mdot
.278 .72254 Mdot
.46675 .31074 Mdot
.37366 .69252 Mdot
.64797 .4702 Mdot
.64525 .51665 Mdot
.56338 .4244 Mdot
.48216 .27436 Mdot
.62736 .47969 Mdot
.23625 .43422 Mdot
.41022 .41732 Mdot
.55978 .76722 Mdot
.38875 .6956 Mdot
.62411 .43711 Mdot
.35044 .48404 Mdot
.39047 .53233 Mdot
.23606 .4286 Mdot
.39573 .47969 Mdot
.63975 .49194 Mdot
.48475 .31801 Mdot
.52925 .59779 Mdot
.62331 .66783 Mdot
.16614 .49642 Mdot
.6428 .674 Mdot
.39033 .70065 Mdot
.57615 .42387 Mdot
.39945 .64138 Mdot
.77991 .29144 Mdot
.65805 .50692 Mdot
.46567 .32005 Mdot
.66122 .45611 Mdot
.67422 .48193 Mdot
.63374 .52044 Mdot
.43241 .62078 Mdot
.4574 .58699 Mdot
.64528 .46162 Mdot
.39157 .50025 Mdot
.45533 .73439 Mdot
.65448 .42558 Mdot
.36762 .71089 Mdot
.74014 .6347 Mdot
.33211 .32658 Mdot
.49716 .28071 Mdot
.41981 .63005 Mdot
.48123 .33001 Mdot
.47355 .27018 Mdot
.48129 .33976 Mdot
.44774 .77806 Mdot
.62788 .57348 Mdot
.52204 .15325 Mdot
.72258 .34553 Mdot
.59464 .2265 Mdot
.47122 .28513 Mdot
.30607 .58367 Mdot
.45547 .31475 Mdot
.474 .34043 Mdot
.34506 .16423 Mdot
.45879 .30518 Mdot
.59681 .45061 Mdot
.60116 .42674 Mdot
.29632 .39307 Mdot
.75904 .64903 Mdot
.61647 .51369 Mdot
.62539 .47775 Mdot
.60493 .6412 Mdot
.70434 .43067 Mdot
.23208 .4258 Mdot
.3859 .36238 Mdot
.21455 .43226 Mdot
.63294 .45159 Mdot
.63037 .47374 Mdot
.62226 .53534 Mdot
.37126 .82992 Mdot
.57774 .20706 Mdot
.49385 .29566 Mdot
.66364 .54939 Mdot
.18942 .60399 Mdot
.59967 .43169 Mdot
.62265 .43064 Mdot
.66476 .47489 Mdot
.40817 .63629 Mdot
.45999 .36884 Mdot
.70014 .50824 Mdot
.31219 .34831 Mdot
.64618 .47575 Mdot
.33294 .45857 Mdot
.6318 .70642 Mdot
.60566 .44681 Mdot
.47576 .35902 Mdot
.63328 .51353 Mdot
.44722 .32101 Mdot
.46806 .3545 Mdot
.59729 .5254 Mdot
.45638 .79064 Mdot
.47655 .36486 Mdot
.65878 .47247 Mdot
.4063 .62878 Mdot
.23779 .69499 Mdot
.60603 .4525 Mdot
.60484 .644 Mdot
.60601 .49336 Mdot
.60728 .6913 Mdot
.65499 .48579 Mdot
.24938 .42303 Mdot
.57046 .26827 Mdot
.41938 .6442 Mdot
.64567 .66061 Mdot
.4414 .64721 Mdot
.50325 .4028 Mdot
.50768 .33169 Mdot
.23164 .42452 Mdot
.52806 .1815 Mdot
.24587 .44309 Mdot
.76945 .50668 Mdot
.25364 .57019 Mdot
.3529 .48805 Mdot
.44945 .34813 Mdot
.74576 .51855 Mdot
.36228 .70498 Mdot
.43022 .68664 Mdot
.41398 .69435 Mdot
.81726 .35938 Mdot
.64473 .18989 Mdot
.64552 .45635 Mdot
.68425 .75068 Mdot
.60261 .32078 Mdot
.67869 .49933 Mdot
.68798 .47813 Mdot
.39663 .67996 Mdot
.67781 .46299 Mdot
.48128 .50935 Mdot
.40461 .65702 Mdot
.60999 .66144 Mdot
.46528 .34354 Mdot
.61853 .68844 Mdot
.33596 .71147 Mdot
.38877 .42307 Mdot
.39966 .6663 Mdot
.66137 .51751 Mdot
.64878 .45011 Mdot
.44469 .32886 Mdot
.53272 .3547 Mdot
.47939 .35466 Mdot
.58618 .65223 Mdot
.41184 .65242 Mdot
.56015 .20786 Mdot
.60139 .48684 Mdot
.47942 .30691 Mdot
.35614 .55643 Mdot
.61031 .48923 Mdot
.3673 .48461 Mdot
.61862 .49658 Mdot
.46711 .30475 Mdot
.64851 .49432 Mdot
.48515 .32061 Mdot
.39731 .6267 Mdot
.59125 .44055 Mdot
.62816 .4723 Mdot
.79106 .47199 Mdot
.61636 .67071 Mdot
.50727 .32754 Mdot
.48404 .49673 Mdot
.58639 .44215 Mdot
.68003 .58072 Mdot
.67271 .44998 Mdot
.53854 .47337 Mdot
.68275 .51504 Mdot
.2371 .43535 Mdot
.60412 .52016 Mdot
.60742 .45171 Mdot
.64538 .37358 Mdot
.71629 .36846 Mdot
.42121 .33848 Mdot
.33737 .4946 Mdot
.47624 .3587 Mdot
.41108 .67979 Mdot
.42445 .68021 Mdot
.41852 .61176 Mdot
.77782 .62144 Mdot
.60955 .53713 Mdot
.61378 .45419 Mdot
.34865 .4771 Mdot
.60671 .66861 Mdot
.48185 .30193 Mdot
.60166 .66579 Mdot
.38701 .35856 Mdot
.58506 .66098 Mdot
.23482 .43854 Mdot
.55955 .73251 Mdot
.5039 .23034 Mdot
.59706 .64598 Mdot
.47891 .35508 Mdot
.51338 .63632 Mdot
.59603 .49978 Mdot
.22311 .61815 Mdot
.62126 .65514 Mdot
.83442 .40927 Mdot
.6597 .44142 Mdot
.4741 .52365 Mdot
.35144 .50463 Mdot
.61042 .68847 Mdot
.39568 .50904 Mdot
.64007 .51484 Mdot
.28733 .31264 Mdot
.46085 .32182 Mdot
.33618 .48213 Mdot
.61343 .5225 Mdot
.61653 .68871 Mdot
.40274 .67225 Mdot
.51081 .50019 Mdot
.3785 .48163 Mdot
.79136 .49663 Mdot
.701 .57525 Mdot
.41004 .65295 Mdot
.42562 .19698 Mdot
.38532 .5259 Mdot
.67102 .51151 Mdot
.55846 .52864 Mdot
.62775 .50875 Mdot
.41215 .68269 Mdot
.43072 .63894 Mdot
.31314 .42332 Mdot
.65756 .45393 Mdot
.66308 .44324 Mdot
.45282 .36988 Mdot
.39907 .65543 Mdot
.49122 .33604 Mdot
.44378 .34281 Mdot
.40999 .6253 Mdot
.48572 .34344 Mdot
.59023 .67392 Mdot
.41419 .41836 Mdot
.38261 .52747 Mdot
.38457 .49244 Mdot
.40471 .67594 Mdot
.39137 .61309 Mdot
.39828 .64365 Mdot
.62095 .4961 Mdot
.49812 .31353 Mdot
.65613 .49969 Mdot
.6599 .51182 Mdot
.51515 .35022 Mdot
.48145 .2947 Mdot
.65205 .50597 Mdot
.52106 .64336 Mdot
.62862 .63878 Mdot
.42776 .6509 Mdot
.37547 .52138 Mdot
.79691 .4437 Mdot
.35311 .47346 Mdot
.63793 .43578 Mdot
.23902 .63492 Mdot
.48128 .29891 Mdot
.61416 .67984 Mdot
.58353 .68975 Mdot
.60487 .67954 Mdot
.33483 .48343 Mdot
.44965 .35306 Mdot
.38104 .3956 Mdot
.63554 .43657 Mdot
.44588 .47104 Mdot
.74711 .52775 Mdot
.33341 .37853 Mdot
.37698 .5162 Mdot
.61777 .48523 Mdot
.24405 .44173 Mdot
.53425 .23924 Mdot
.62104 .45642 Mdot
.59805 .51216 Mdot
.52145 .6975 Mdot
.55372 .47051 Mdot
.48584 .27935 Mdot
.41619 .37728 Mdot
.57989 .46321 Mdot
.42715 .36844 Mdot
.47182 .12251 Mdot
.66077 .44334 Mdot
.6358 .478 Mdot
.59597 .4647 Mdot
.664 .49815 Mdot
.51656 .3261 Mdot
.53344 .65706 Mdot
.3463 .4849 Mdot
.42408 .43383 Mdot
.38744 .51986 Mdot
.4253 .66379 Mdot
.48 .52469 Mdot
.45587 .35298 Mdot
.60669 .68066 Mdot
.75499 .70799 Mdot
.39376 .35112 Mdot
.38915 .63993 Mdot
.60894 .21101 Mdot
.62429 .66461 Mdot
.59367 .4952 Mdot
.63627 .65431 Mdot
.43048 .6787 Mdot
.38701 .50378 Mdot
.5945 .43195 Mdot
.46128 .29352 Mdot
.49916 .35093 Mdot
.62001 .48637 Mdot
.20386 .64361 Mdot
.39665 .50066 Mdot
.30801 .48509 Mdot
.6559 .45975 Mdot
.59697 .51085 Mdot
.4727 .3513 Mdot
.42769 .6386 Mdot
.2455 .53594 Mdot
.61543 .66213 Mdot
.64196 .52879 Mdot
.63574 .51514 Mdot
.39402 .37226 Mdot
.34836 .52108 Mdot
.2632 .43902 Mdot
.65699 .45773 Mdot
.40172 .3989 Mdot
.65934 .4592 Mdot
.68986 .42791 Mdot
.40028 .63465 Mdot
.58856 .42906 Mdot
.58415 .46332 Mdot
.74404 .48979 Mdot
.38793 .52552 Mdot
.46885 .32548 Mdot
.48944 .36951 Mdot
.26753 .44305 Mdot
.36171 .48777 Mdot
.64487 .50973 Mdot
.36694 .53536 Mdot
.63745 .51961 Mdot
.64239 .46332 Mdot
.37784 .5158 Mdot
.49091 .33705 Mdot
.30765 .67107 Mdot
.67008 .38332 Mdot
.6685 .47846 Mdot
.61133 .50144 Mdot
.76715 .63407 Mdot
.47674 .19411 Mdot
.58686 .47287 Mdot
.49168 .3027 Mdot
.61059 .48674 Mdot
.37806 .48613 Mdot
.58458 .65581 Mdot
.46813 .3165 Mdot
.38336 .62809 Mdot
.39955 .6231 Mdot
.38409 .58527 Mdot
.2362 .443 Mdot
.59553 .49206 Mdot
.43559 .29583 Mdot
.47512 .29284 Mdot
.20373 .43422 Mdot
.41499 .67181 Mdot
.59077 .68311 Mdot
.66811 .46335 Mdot
.51377 .50862 Mdot
.34282 .49371 Mdot
.08997 .5175 Mdot
.37875 .403 Mdot
.63136 .68932 Mdot
.39816 .27889 Mdot
.24338 .43686 Mdot
.60176 .43947 Mdot
.63138 .65431 Mdot
.40347 .61209 Mdot
.64556 .51571 Mdot
.56777 .50067 Mdot
.35391 .66345 Mdot
.38383 .68588 Mdot
.37092 .53644 Mdot
.39434 .6158 Mdot
.63007 .68717 Mdot
.23468 .43718 Mdot
.49743 .34482 Mdot
.61206 .4488 Mdot
.66384 .55327 Mdot
.4179 .66585 Mdot
.25649 .42355 Mdot
.65747 .46373 Mdot
.49373 .35591 Mdot
.43009 .62714 Mdot
.63281 .44803 Mdot
.56271 .22726 Mdot
.52403 .31805 Mdot
.41579 .65699 Mdot
.57562 .47181 Mdot
.53612 .39909 Mdot
.38042 .64722 Mdot
.39335 .6769 Mdot
.62756 .47922 Mdot
.59281 .67542 Mdot
.60004 .43645 Mdot
.3555 .5128 Mdot
.45758 .58722 Mdot
.37137 .48721 Mdot
.7324 .54695 Mdot
.56924 .45963 Mdot
.34118 .2879 Mdot
.44529 .3104 Mdot
.57514 .65053 Mdot
.65658 .36928 Mdot
.58984 .49926 Mdot
.35195 .76927 Mdot
.52216 .6178 Mdot
.18942 .47692 Mdot
.49353 .83851 Mdot
.60922 .64961 Mdot
.359 .50087 Mdot
.63484 .47867 Mdot
.40641 .52944 Mdot
.59557 .65049 Mdot
.74044 .53912 Mdot
.57642 .47374 Mdot
.49607 .32243 Mdot
.64929 .47157 Mdot
.4482 .33223 Mdot
.60805 .4902 Mdot
.61318 .54252 Mdot
.61923 .62668 Mdot
.79557 .54743 Mdot
.59789 .50044 Mdot
.77054 .69713 Mdot
.49975 .4988 Mdot
.61874 .65484 Mdot
.66203 .48528 Mdot
.2552 .43328 Mdot
.39457 .48959 Mdot
.63416 .75033 Mdot
.40328 .63859 Mdot
.36759 .51556 Mdot
.47091 .34828 Mdot
.40829 .5952 Mdot
.26978 .43954 Mdot
.61721 .56786 Mdot
.6238 .68633 Mdot
.35271 .49214 Mdot
.60677 .44974 Mdot
.63777 .43506 Mdot
.56161 .7278 Mdot
.32942 .22413 Mdot
.44514 .35784 Mdot
.83196 .51607 Mdot
.483 .28173 Mdot
.61189 .67183 Mdot
.39887 .63713 Mdot
.59163 .45201 Mdot
.62372 .46235 Mdot
.42277 .67661 Mdot
.49776 .30683 Mdot
.39347 .59066 Mdot
.651 .24059 Mdot
.44885 .64358 Mdot
.76048 .58081 Mdot
.46404 .314 Mdot
.76549 .57498 Mdot
.62553 .69223 Mdot
.45389 .8001 Mdot
.68499 .67072 Mdot
.34784 .49601 Mdot
.75494 .58619 Mdot
.47677 .30012 Mdot
.6442 .45262 Mdot
.24297 .43118 Mdot
.24838 .4493 Mdot
.45979 .34411 Mdot
.41528 .6253 Mdot
.61748 .68701 Mdot
.63862 .47427 Mdot
.3542 .35669 Mdot
.24894 .38152 Mdot
.41816 .60401 Mdot
.71477 .47322 Mdot
.39465 .5063 Mdot
.61182 .49646 Mdot
.61312 .64374 Mdot
.36951 .50913 Mdot
.24675 .45703 Mdot
.41604 .41772 Mdot
.66855 .46179 Mdot
.4452 .40407 Mdot
.35702 .49158 Mdot
.44053 .18697 Mdot
.62635 .46998 Mdot
.38562 .52579 Mdot
.54537 .4669 Mdot
.28503 .32672 Mdot
.54975 .5839 Mdot
.29323 .73643 Mdot
.39576 .69315 Mdot
.40292 .62032 Mdot
.24302 .31677 Mdot
.6133 .61598 Mdot
.35361 .48092 Mdot
.23456 .43428 Mdot
.69622 .62693 Mdot
.39483 .51453 Mdot
.62496 .42957 Mdot
.67161 .44923 Mdot
.65493 .2492 Mdot
.49252 .51365 Mdot
.26539 .42692 Mdot
.52825 .4681 Mdot
.63681 .50004 Mdot
.63021 .4113 Mdot
.61656 .47357 Mdot
.49396 .29405 Mdot
.39825 .51092 Mdot
.77027 .71782 Mdot
.39489 .52274 Mdot
.36032 .35887 Mdot
.41948 .65665 Mdot
.42586 .60917 Mdot
.60764 .44574 Mdot
.37618 .25138 Mdot
.614 .76671 Mdot
.60567 .49838 Mdot
.6075 .70737 Mdot
.71041 .56998 Mdot
.65231 .42321 Mdot
.47412 .37491 Mdot
.70695 .49943 Mdot
.51016 .30733 Mdot
.37357 .51043 Mdot
.60692 .64859 Mdot
.61161 .62998 Mdot
.35466 .50135 Mdot
.61276 .45693 Mdot
.59364 .7058 Mdot
.62202 .44781 Mdot
.6497 .45465 Mdot
.38013 .35973 Mdot
.5803 .66639 Mdot
.39649 .64594 Mdot
.60285 .67523 Mdot
.47427 .33898 Mdot
.26416 .21159 Mdot
.59786 .65938 Mdot
.52804 .40621 Mdot
.47819 .5644 Mdot
.75776 .5815 Mdot
.49742 .35142 Mdot
.59312 .64468 Mdot
.38137 .53481 Mdot
.18478 .47601 Mdot
.45246 .19744 Mdot
.3716 .4681 Mdot
.62729 .46464 Mdot
.45039 .34743 Mdot
.47922 .28962 Mdot
.39263 .46955 Mdot
.49803 .33743 Mdot
.5916 .41522 Mdot
.66285 .46004 Mdot
.35357 .4811 Mdot
.28516 .39607 Mdot
.39873 .51098 Mdot
.5107 .47454 Mdot
.66228 .47497 Mdot
.46706 .31839 Mdot
.61357 .40444 Mdot
.43996 .36061 Mdot
.24938 .45165 Mdot
.62963 .52065 Mdot
.60988 .68379 Mdot
.46938 .49295 Mdot
.41706 .65519 Mdot
.24359 .63947 Mdot
.4501 .34218 Mdot
.35849 .55216 Mdot
.49058 .34711 Mdot
.44426 .30397 Mdot
.39692 .47947 Mdot
.46604 .33245 Mdot
.63701 .47694 Mdot
.4301 .55362 Mdot
.44976 .32067 Mdot
.37273 .49581 Mdot
.61822 .68454 Mdot
.4881 .34107 Mdot
.41381 .59206 Mdot
.64343 .44791 Mdot
.39042 .65728 Mdot
.5934 .69453 Mdot
.45452 .35272 Mdot
.5912 .64684 Mdot
.4172 .66851 Mdot
.62904 .67945 Mdot
.44029 .71867 Mdot
.35993 .53913 Mdot
.37352 .32878 Mdot
.58503 .38094 Mdot
.45937 .29565 Mdot
.428 .68968 Mdot
.58684 .4595 Mdot
.65286 .44928 Mdot
.63553 .67483 Mdot
.47654 .28976 Mdot
.23476 .68833 Mdot
.53578 .47344 Mdot
.31153 .43515 Mdot
.35221 .52837 Mdot
.82288 .475 Mdot
.37362 .41788 Mdot
.18578 .5028 Mdot
.6943 .48502 Mdot
.24314 .43608 Mdot
.62177 .44421 Mdot
.80027 .49389 Mdot
.5836 .65954 Mdot
.29501 .60889 Mdot
.68425 .50643 Mdot
.40371 .64729 Mdot
.60303 .48311 Mdot
.68021 .75049 Mdot
.7057 .47133 Mdot
.60205 .64155 Mdot
.33216 .49912 Mdot
.43789 .33433 Mdot
.62345 .66623 Mdot
.39471 .62738 Mdot
.72134 .62112 Mdot
.57476 .46222 Mdot
.63564 .49605 Mdot
.42832 .68755 Mdot
.49746 .32732 Mdot
.42314 .6673 Mdot
.3833 .52683 Mdot
.60048 .66104 Mdot
.6678 .49035 Mdot
.60984 .41272 Mdot
.44412 .62121 Mdot
.38955 .53193 Mdot
.39982 .60135 Mdot
.35452 .52571 Mdot
.24237 .43536 Mdot
.59737 .49649 Mdot
.43583 .67438 Mdot
.68331 .47233 Mdot
.73423 .39675 Mdot
.3818 .34409 Mdot
.67172 .35637 Mdot
.3954 .64788 Mdot
.75198 .6187 Mdot
.36222 .49469 Mdot
.35465 .52189 Mdot
.74812 .33686 Mdot
.60002 .76829 Mdot
.50887 .64384 Mdot
.77193 .68219 Mdot
.38225 .52733 Mdot
.3693 .48961 Mdot
.40694 .61208 Mdot
.46391 .33674 Mdot
.52104 .32262 Mdot
.43942 .62049 Mdot
.78954 .52072 Mdot
.48156 .30197 Mdot
.33588 .76192 Mdot
.38332 .66791 Mdot
.68028 .51654 Mdot
.26061 .42191 Mdot
.61486 .64742 Mdot
.78396 .51157 Mdot
.74248 .70716 Mdot
.59986 .44393 Mdot
.60075 .18465 Mdot
.41903 .63357 Mdot
.42307 .54349 Mdot
.40159 .78257 Mdot
.58702 .50049 Mdot
.6009 .4751 Mdot
.61148 .46344 Mdot
.58095 .64824 Mdot
.68337 .37697 Mdot
.60191 .44185 Mdot
.7868 .56609 Mdot
.62587 .4267 Mdot
.66653 .74085 Mdot
.60236 .67452 Mdot
.61714 .57851 Mdot
.40239 .698 Mdot
.32329 .35359 Mdot
.56348 .42206 Mdot
.37467 .53281 Mdot
.34794 .69691 Mdot
.38659 .50826 Mdot
.53384 .80299 Mdot
.68581 .66652 Mdot
.48957 .28979 Mdot
.61859 .49485 Mdot
.41083 .69322 Mdot
.44738 .3393 Mdot
.25106 .55963 Mdot
.33783 .16462 Mdot
.37524 .54078 Mdot
.66741 .1855 Mdot
.35333 .52083 Mdot
.25235 .45071 Mdot
.46642 .34949 Mdot
.4365 .26042 Mdot
.44864 .47447 Mdot
.48902 .33737 Mdot
.36495 .61137 Mdot
.48339 .3738 Mdot
.75252 .60338 Mdot
.44117 .30387 Mdot
.36893 .49803 Mdot
.33645 .52154 Mdot
.56392 .50796 Mdot
.58705 .47035 Mdot
.41552 .42738 Mdot
.54645 .43604 Mdot
.59702 .48857 Mdot
.4046 .65685 Mdot
.41667 .22713 Mdot
.42443 .57946 Mdot
.45355 .32133 Mdot
.33982 .50218 Mdot
.60088 .47706 Mdot
.66768 .47942 Mdot
.67666 .49722 Mdot
.7993 .48171 Mdot
.33689 .75996 Mdot
.64394 .46055 Mdot
.59965 .52547 Mdot
.39392 .63242 Mdot
.5779 .72574 Mdot
.81032 .60567 Mdot
.69675 .63818 Mdot
.65371 .4451 Mdot
.61422 .67494 Mdot
.58227 .65357 Mdot
.606 .41829 Mdot
.34346 .31974 Mdot
.36924 .66574 Mdot
.60645 .45002 Mdot
.67886 .69616 Mdot
.41342 .5856 Mdot
.24679 .42255 Mdot
.41714 .66656 Mdot
.46432 .35792 Mdot
.24778 .44644 Mdot
.4332 .62682 Mdot
.45705 .24189 Mdot
.26609 .44396 Mdot
.28798 .33668 Mdot
.58623 .65195 Mdot
.61909 .46912 Mdot
.43943 .36628 Mdot
.41974 .67863 Mdot
.35224 .49418 Mdot
.47952 .31908 Mdot
.37617 .54437 Mdot
.58068 .72876 Mdot
.76441 .53147 Mdot
.23821 .44586 Mdot
.36947 .53019 Mdot
.42752 .41812 Mdot
.61126 .67635 Mdot
.39264 .47397 Mdot
.36587 .25576 Mdot
.66304 .43133 Mdot
.57762 .80053 Mdot
.63087 .49392 Mdot
.1771 .58932 Mdot
.35396 .51979 Mdot
.25017 .455 Mdot
.61485 .44935 Mdot
.38595 .66757 Mdot
.57822 .52939 Mdot
.62475 .44919 Mdot
.38916 .62115 Mdot
.64477 .45572 Mdot
.61673 .6442 Mdot
.51132 .30209 Mdot
.5245 .61371 Mdot
.81585 .41952 Mdot
.63049 .67377 Mdot
.27712 .4597 Mdot
.59296 .4842 Mdot
.47743 .73503 Mdot
.49013 .33337 Mdot
.59437 .50936 Mdot
.70276 .26414 Mdot
.45724 .33625 Mdot
.48332 .3301 Mdot
.65026 .49761 Mdot
.36598 .47016 Mdot
.39986 .67567 Mdot
.60962 .67742 Mdot
.23967 .48617 Mdot
.63144 .44618 Mdot
.61877 .48177 Mdot
.62442 .66581 Mdot
.36994 .48829 Mdot
.66585 .49224 Mdot
.24267 .58405 Mdot
.21389 .45841 Mdot
.3458 .49298 Mdot
.66051 .42874 Mdot
.60208 .81402 Mdot
.5045 .27659 Mdot
.56938 .16551 Mdot
.62186 .61967 Mdot
.41229 .62823 Mdot
.66003 .54146 Mdot
.09085 .48629 Mdot
.61385 .64801 Mdot
.33575 .37171 Mdot
.64848 .46259 Mdot
.5934 .47511 Mdot
.50467 .33564 Mdot
.64823 .50608 Mdot
.46352 .30415 Mdot
.8177 .41299 Mdot
.84735 .61496 Mdot
.48935 .34629 Mdot
.45448 .30934 Mdot
.43534 .27489 Mdot
.78981 .48923 Mdot
.46798 .34549 Mdot
.57466 .47218 Mdot
.41083 .74573 Mdot
.56943 .49325 Mdot
.61875 .6965 Mdot
.57287 .65299 Mdot
.47489 .38159 Mdot
.38324 .21424 Mdot
.60719 .55445 Mdot
.67162 .39605 Mdot
.58585 .59469 Mdot
.36464 .52171 Mdot
.67284 .46176 Mdot
.23505 .44156 Mdot
.42021 .61029 Mdot
.7097 .46604 Mdot
.6189 .46508 Mdot
.44775 .32312 Mdot
.58009 .64814 Mdot
.39871 .49128 Mdot
.62617 .47674 Mdot
.37531 .63761 Mdot
.6124 .66145 Mdot
.45092 .31758 Mdot
.51972 .41178 Mdot
.60333 .69396 Mdot
.60677 .41033 Mdot
.59648 .48598 Mdot
.65802 .46344 Mdot
.56025 .42686 Mdot
.35336 .50184 Mdot
.4314 .61043 Mdot
.57287 .43895 Mdot
.38845 .37389 Mdot
.45806 .52727 Mdot
.58514 .42946 Mdot
.49746 .31033 Mdot
.34664 .48264 Mdot
.26319 .44399 Mdot
.72914 .59671 Mdot
.66552 .45483 Mdot
.34358 .76199 Mdot
.60568 .21552 Mdot
.25329 .44386 Mdot
.46289 .28058 Mdot
.60971 .68032 Mdot
.64261 .49437 Mdot
.44353 .74802 Mdot
.65266 .43895 Mdot
.54662 .40468 Mdot
.41545 .63079 Mdot
.37085 .52399 Mdot
.20595 .45703 Mdot
.41977 .60968 Mdot
.4819 .33011 Mdot
.21723 .68819 Mdot
.49127 .36441 Mdot
.44482 .35221 Mdot
.47391 .79753 Mdot
.37535 .51231 Mdot
.09071 .50267 Mdot
.47111 .19193 Mdot
.65143 .43663 Mdot
.38821 .49135 Mdot
.46342 .34998 Mdot
.62333 .49438 Mdot
.46598 .29549 Mdot
.46134 .36538 Mdot
.66573 .50418 Mdot
.5913 .47569 Mdot
.79201 .5399 Mdot
.33813 .7776 Mdot
.59866 .67721 Mdot
.5039 .31629 Mdot
.62509 .24106 Mdot
.60013 .44207 Mdot
.63455 .43649 Mdot
.35227 .67899 Mdot
.60081 .64223 Mdot
.54462 .29688 Mdot
.65482 .45622 Mdot
.71674 .27639 Mdot
.60104 .49737 Mdot
.4276 .35144 Mdot
.36075 .47004 Mdot
.34283 .32969 Mdot
.40943 .68264 Mdot
.49416 .35871 Mdot
.60786 .69066 Mdot
.50985 .34699 Mdot
.72738 .30364 Mdot
.37936 .5099 Mdot
.46714 .30468 Mdot
.39388 .60089 Mdot
.38237 .50022 Mdot
.34703 .49834 Mdot
.45355 .73414 Mdot
.4116 .59695 Mdot
.5948 .63695 Mdot
.38984 .50782 Mdot
.5817 .23366 Mdot
.36985 .5014 Mdot
.64225 .24785 Mdot
.58327 .45285 Mdot
.78432 .55994 Mdot
.36104 .41621 Mdot
.56084 .4378 Mdot
.39896 .50655 Mdot
.59188 .66149 Mdot
.63392 .5101 Mdot
.4995 .33441 Mdot
.59869 .65583 Mdot
.3921 .46123 Mdot
.38971 .61199 Mdot
.45084 .29478 Mdot
.35098 .47742 Mdot
.46767 .3013 Mdot
.7558 .53358 Mdot
.41202 .71503 Mdot
.59661 .59271 Mdot
.45471 .49052 Mdot
.67398 .50848 Mdot
.42937 .3718 Mdot
.5834 .44488 Mdot
.61987 .4602 Mdot
.41604 .65761 Mdot
.77824 .61956 Mdot
.49025 .33975 Mdot
.19244 .43118 Mdot
.36385 .52785 Mdot
.41363 .37063 Mdot
.53222 .42498 Mdot
.63307 .51874 Mdot
.45059 .32523 Mdot
.45726 .36508 Mdot
.71564 .36785 Mdot
.42465 .67436 Mdot
.56081 .4566 Mdot
.57337 .4284 Mdot
.61714 .54139 Mdot
.35145 .51779 Mdot
.25789 .60665 Mdot
.43426 .64002 Mdot
.57935 .14228 Mdot
.42848 .6488 Mdot
.50364 .70418 Mdot
.46501 .33202 Mdot
.58727 .67386 Mdot
.63107 .4362 Mdot
.69822 .39617 Mdot
.51528 .32406 Mdot
.36882 .64353 Mdot
.6146 .68148 Mdot
.28613 .64234 Mdot
.37156 .51459 Mdot
.57835 .46529 Mdot
.67341 .48812 Mdot
.65895 .49439 Mdot
.6421 .48398 Mdot
.33798 .50007 Mdot
.62506 .42982 Mdot
.34151 .51734 Mdot
.54518 .22721 Mdot
.7283 .29076 Mdot
.40265 .68802 Mdot
.6342 .74256 Mdot
.45996 .29259 Mdot
.62028 .25256 Mdot
.53384 .27756 Mdot
.38004 .34407 Mdot
.45074 .72089 Mdot
.58195 .46752 Mdot
.41576 .62376 Mdot
.6808 .75258 Mdot
.4127 .69229 Mdot
.87625 .58901 Mdot
.68632 .56568 Mdot
.28309 .73556 Mdot
.6266 .49249 Mdot
.43737 .61497 Mdot
.53924 .31944 Mdot
.61832 .41581 Mdot
.57547 .6838 Mdot
.51962 .44298 Mdot
.30172 .38662 Mdot
.59244 .68555 Mdot
.64058 .44712 Mdot
.4369 .33066 Mdot
.63842 .47661 Mdot
.63043 .43794 Mdot
.60506 .49614 Mdot
.40506 .50125 Mdot
.67311 .44241 Mdot
.6024 .4355 Mdot
.34303 .21303 Mdot
.75219 .64086 Mdot
.38645 .64661 Mdot
.69542 .35254 Mdot
.60674 .66818 Mdot
.44637 .32954 Mdot
.5121 .60528 Mdot
.35818 .51292 Mdot
.72266 .37327 Mdot
.6282 .49335 Mdot
.33687 .41842 Mdot
.35381 .4742 Mdot
.60174 .65082 Mdot
.26781 .43949 Mdot
.3436 .74167 Mdot
.4102 .68667 Mdot
.26394 .44937 Mdot
.41775 .65347 Mdot
.58251 .35901 Mdot
.44829 .32475 Mdot
.67388 .50233 Mdot
.39324 .51019 Mdot
.3924 .67331 Mdot
.762 .65159 Mdot
.6114 .47431 Mdot
.39478 .65069 Mdot
.67259 .50917 Mdot
.44977 .54061 Mdot
.47969 .57327 Mdot
.43842 .66279 Mdot
.33357 .51584 Mdot
.38304 .49604 Mdot
.58894 .67263 Mdot
.4457 .32537 Mdot
.48845 .30155 Mdot
.37304 .50771 Mdot
.60705 .17064 Mdot
.6282 .4447 Mdot
.60012 .4927 Mdot
.38679 .38194 Mdot
.62792 .48702 Mdot
.73372 .6276 Mdot
.23083 .43083 Mdot
.4495 .30222 Mdot
.63681 .48462 Mdot
.66677 .49024 Mdot
.66879 .46384 Mdot
.75801 .53798 Mdot
.4212 .66152 Mdot
.63775 .49942 Mdot
.6355 .6654 Mdot
.32534 .28849 Mdot
.58818 .4524 Mdot
.6207 .41267 Mdot
.47009 .30279 Mdot
.83073 .48098 Mdot
.35025 .50352 Mdot
.39748 .65915 Mdot
.3825 .66269 Mdot
.65312 .59748 Mdot
.50374 .2843 Mdot
.23617 .42276 Mdot
.32818 .56087 Mdot
.24478 .42565 Mdot
.61997 .65903 Mdot
.50477 .67028 Mdot
.37396 .64894 Mdot
.38947 .63268 Mdot
.35592 .53552 Mdot
.64165 .48218 Mdot
.60041 .49571 Mdot
.33794 .37008 Mdot
.61558 .51167 Mdot
.6165 .68325 Mdot
.3612 .47615 Mdot
.47176 .30406 Mdot
.62005 .64937 Mdot
.36598 .53188 Mdot
.49818 .32599 Mdot
.64462 .42234 Mdot
.67727 .44124 Mdot
.48268 .32315 Mdot
.46285 .354 Mdot
.59766 .45298 Mdot
.29978 .25468 Mdot
.44037 .31483 Mdot
.46508 .30912 Mdot
.2755 .44424 Mdot
.41051 .68727 Mdot
.65803 .41156 Mdot
.39059 .49329 Mdot
.65701 .46201 Mdot
.40652 .68992 Mdot
.59543 .64598 Mdot
.48976 .31957 Mdot
.66793 .47237 Mdot
.63843 .45575 Mdot
.61449 .67582 Mdot
.5842 .6798 Mdot
.62683 .67643 Mdot
.3902 .53929 Mdot
.65414 .47799 Mdot
.47263 .34632 Mdot
.37649 .51388 Mdot
.58221 .65419 Mdot
.62476 .64056 Mdot
.3715 .20252 Mdot
.60284 .44281 Mdot
.5581 .58949 Mdot
.20658 .27273 Mdot
.71514 .62741 Mdot
.25992 .44945 Mdot
.44415 .63908 Mdot
.77653 .57516 Mdot
.6411 .63947 Mdot
.38688 .48797 Mdot
.65907 .68333 Mdot
.575 .65483 Mdot
.66037 .51061 Mdot
.61554 .50234 Mdot
.65086 .52984 Mdot
.60759 .66068 Mdot
.75094 .54053 Mdot
.48359 .29182 Mdot
.59751 .29609 Mdot
.60667 .66799 Mdot
.43927 .66038 Mdot
.43784 .66837 Mdot
.42903 .64816 Mdot
.58145 .47225 Mdot
.69798 .36599 Mdot
.59767 .23259 Mdot
.55902 .31716 Mdot
.36743 .51494 Mdot
.45744 .36705 Mdot
.45991 .7179 Mdot
.48457 .33005 Mdot
.42238 .61527 Mdot
.60918 .65711 Mdot
.50588 .32718 Mdot
.3607 .48507 Mdot
.37457 .48808 Mdot
.38443 .62397 Mdot
.4124 .67012 Mdot
.40066 .66901 Mdot
.4702 .36039 Mdot
.46585 .33256 Mdot
.67061 .48081 Mdot
.48414 .31343 Mdot
.55024 .18559 Mdot
.63022 .69273 Mdot
.42436 .69103 Mdot
.35968 .49182 Mdot
.45018 .33863 Mdot
.62156 .46885 Mdot
.53375 .70165 Mdot
.38506 .58792 Mdot
.63154 .66443 Mdot
.45573 .60668 Mdot
.88189 .51503 Mdot
.67688 .47938 Mdot
.35683 .52934 Mdot
.3417 .30527 Mdot
.60812 .46811 Mdot
.40731 .63481 Mdot
.78081 .46575 Mdot
.25315 .42385 Mdot
.59966 .43809 Mdot
.60174 .51261 Mdot
.39738 .48128 Mdot
.49806 .59251 Mdot
.62704 .51845 Mdot
.47727 .4196 Mdot
.39092 .5328 Mdot
.43459 .63604 Mdot
.18757 .39023 Mdot
.44625 .65872 Mdot
.80088 .5462 Mdot
.25804 .4482 Mdot
.67231 .48957 Mdot
.40724 .65728 Mdot
.63049 .65569 Mdot
.40865 .66332 Mdot
.46212 .28602 Mdot
.39195 .66211 Mdot
.61368 .48461 Mdot
.47264 .34483 Mdot
.35943 .48866 Mdot
.42116 .38189 Mdot
.34703 .21936 Mdot
.38503 .66551 Mdot
.25488 .46016 Mdot
.59982 .43997 Mdot
.54069 .24745 Mdot
.58762 .53574 Mdot
.58495 .46629 Mdot
.3859 .50965 Mdot
.45135 .32483 Mdot
.35065 .52659 Mdot
.6583 .42296 Mdot
.75022 .35291 Mdot
.35929 .52298 Mdot
.2859 .36204 Mdot
.6233 .66239 Mdot
.78798 .52045 Mdot
.62459 .45643 Mdot
.39119 .51306 Mdot
.65512 .47733 Mdot
.50292 .31114 Mdot
.46693 .46744 Mdot
.33907 .27538 Mdot
.39358 .50752 Mdot
.19479 .6398 Mdot
.48463 .49335 Mdot
.69146 .44449 Mdot
.38787 .52138 Mdot
.66721 .36652 Mdot
.2596 .43603 Mdot
.61623 .6615 Mdot
.58119 .66506 Mdot
.62349 .68779 Mdot
.61412 .51066 Mdot
.70633 .51351 Mdot
.61 .6342 Mdot
.3811 .54256 Mdot
.6206 .64219 Mdot
.77714 .50729 Mdot
.2184 .6656 Mdot
.6292 .67004 Mdot
.62955 .46 Mdot
.62713 .41443 Mdot
.75296 .64258 Mdot
.43594 .63264 Mdot
.35641 .77057 Mdot
.49965 .20573 Mdot
.59071 .45517 Mdot
.60357 .56225 Mdot
.46037 .28994 Mdot
.37115 .27645 Mdot
.53672 .48851 Mdot
.51582 .63317 Mdot
.45663 .31124 Mdot
.44282 .56103 Mdot
.44794 .30531 Mdot
.67932 .47656 Mdot
.64258 .46444 Mdot
.51448 .31412 Mdot
.23291 .61866 Mdot
.26348 .33142 Mdot
.16224 .52159 Mdot
.48911 .30093 Mdot
.38845 .52488 Mdot
.37315 .53919 Mdot
.37477 .51732 Mdot
.41089 .68056 Mdot
.4741 .35801 Mdot
.65129 .4842 Mdot
.40143 .6243 Mdot
.64603 .44234 Mdot
.38598 .50191 Mdot
.20635 .45936 Mdot
.47 .30372 Mdot
.6078 .45094 Mdot
.45024 .19921 Mdot
.42382 .64465 Mdot
.61169 .67484 Mdot
.43654 .53945 Mdot
.4438 .62299 Mdot
.39852 .51543 Mdot
.50172 .27813 Mdot
.31974 .49992 Mdot
.53644 .65492 Mdot
.62052 .53455 Mdot
.57594 .45404 Mdot
.26013 .47643 Mdot
.40303 .20664 Mdot
.61232 .50553 Mdot
.39449 .62715 Mdot
.42936 .67908 Mdot
.6634 .45841 Mdot
.49551 .34805 Mdot
.5873 .63869 Mdot
.62796 .68605 Mdot
.6233 .52334 Mdot
.44392 .46931 Mdot
.78929 .5524 Mdot
.65545 .50424 Mdot
.60253 .39558 Mdot
.39838 .59824 Mdot
.26931 .44178 Mdot
.40493 .40273 Mdot
.60026 .68588 Mdot
.65005 .46097 Mdot
.24942 .35455 Mdot
.46108 .30658 Mdot
.3954 .66625 Mdot
.35475 .48289 Mdot
.57716 .68863 Mdot
.38021 .65664 Mdot
.6634 .45893 Mdot
.66613 .49155 Mdot
.39467 .47755 Mdot
.42861 .35324 Mdot
.60725 .6574 Mdot
.40054 .62599 Mdot
.58767 .67516 Mdot
.47254 .33641 Mdot
.47026 .30827 Mdot
.56768 .435 Mdot
.555 .45083 Mdot
.38291 .66211 Mdot
.62293 .52755 Mdot
.43089 .62324 Mdot
.56505 .72722 Mdot
.34202 .49479 Mdot
.59461 .511 Mdot
.44988 .28038 Mdot
.38387 .5043 Mdot
.59253 .46559 Mdot
.2864 .467 Mdot
.6533 .51117 Mdot
.43809 .61722 Mdot
.75569 .35011 Mdot
.59334 .65151 Mdot
.50877 .39694 Mdot
.73429 .48163 Mdot
.62666 .48685 Mdot
.43778 .62788 Mdot
.65349 .54668 Mdot
.35448 .5145 Mdot
.45739 .32568 Mdot
.78027 .2932 Mdot
.37305 .49857 Mdot
.64115 .47302 Mdot
.59963 .65889 Mdot
.44059 .3486 Mdot
.23903 .44227 Mdot
.38871 .40233 Mdot
.70807 .46689 Mdot
.69545 .47455 Mdot
.64208 .47993 Mdot
.77676 .6786 Mdot
.40161 .66108 Mdot
.45617 .3458 Mdot
.34611 .51112 Mdot
.36449 .50793 Mdot
.4277 .63775 Mdot
.31378 .40588 Mdot
.25792 .66683 Mdot
.15135 .34122 Mdot
.38371 .64022 Mdot
.62917 .64806 Mdot
.46821 .51087 Mdot
.41803 .60789 Mdot
.40344 .65274 Mdot
.38112 .63037 Mdot
.3483 .40693 Mdot
.49987 .31967 Mdot
.63957 .45506 Mdot
.49705 .2805 Mdot
.66661 .50184 Mdot
.79775 .60249 Mdot
.37272 .5093 Mdot
.45875 .32676 Mdot
.28227 .47212 Mdot
.54258 .45323 Mdot
.60429 .47455 Mdot
.39811 .73047 Mdot
.70229 .50174 Mdot
.7445 .59196 Mdot
.61336 .4074 Mdot
.41591 .66371 Mdot
.62515 .56946 Mdot
.65931 .54087 Mdot
.48478 .20707 Mdot
.36657 .48588 Mdot
.24288 .45021 Mdot
.64808 .42585 Mdot
.68407 .423 Mdot
.4417 .34951 Mdot
.50602 .32746 Mdot
.60661 .63371 Mdot
.44151 .50207 Mdot
.36222 .48668 Mdot
.29463 .69106 Mdot
.58897 .47547 Mdot
.42056 .51585 Mdot
.74726 .32941 Mdot
.59408 .46324 Mdot
.43656 .7408 Mdot
.72107 .37166 Mdot
.63171 .51795 Mdot
.57904 .32691 Mdot
.36546 .49271 Mdot
.71278 .27278 Mdot
.65713 .52549 Mdot
.40792 .63576 Mdot
.46226 .33452 Mdot
.45528 .29231 Mdot
.62874 .65955 Mdot
.5176 .18782 Mdot
.35096 .53925 Mdot
.46276 .33101 Mdot
.61217 .46707 Mdot
.35166 .49653 Mdot
.24272 .44765 Mdot
.70136 .47927 Mdot
.54758 .78664 Mdot
.48071 .30945 Mdot
.57603 .50212 Mdot
.26879 .4125 Mdot
.46538 .53837 Mdot
.34601 .78606 Mdot
.37629 .51937 Mdot
.60683 .68945 Mdot
.61194 .40674 Mdot
.32185 .55559 Mdot
.67791 .51329 Mdot
.7885 .58541 Mdot
.50091 .38516 Mdot
.58443 .65673 Mdot
.60755 .46175 Mdot
.62611 .51788 Mdot
.46394 .49329 Mdot
.58586 .68049 Mdot
.63149 .51976 Mdot
.56307 .44644 Mdot
.4972 .32453 Mdot
.22994 .43594 Mdot
.47712 .30498 Mdot
.62709 .4657 Mdot
.60928 .56986 Mdot
.50193 .33727 Mdot
.3307 .72458 Mdot
.58578 .62829 Mdot
.35807 .51405 Mdot
.68498 .41902 Mdot
.58296 .45655 Mdot
.56371 .84754 Mdot
.24984 .45163 Mdot
.82035 .54913 Mdot
.44249 .62317 Mdot
.20403 .41506 Mdot
.43768 .60645 Mdot
.26311 .72146 Mdot
.42025 .39475 Mdot
.62124 .53162 Mdot
.66983 .69069 Mdot
.56894 .31919 Mdot
.36436 .54167 Mdot
.5665 .2399 Mdot
.58689 .46978 Mdot
.62545 .44055 Mdot
.40952 .61583 Mdot
.3169 .41835 Mdot
.33926 .31443 Mdot
.42626 .43896 Mdot
.6079 .6525 Mdot
.46946 .32952 Mdot
.61253 .48912 Mdot
.20977 .55231 Mdot
.38657 .65238 Mdot
.50529 .49653 Mdot
.61159 .45027 Mdot
.35744 .34677 Mdot
.31208 .37344 Mdot
.35091 .4947 Mdot
.44223 .63264 Mdot
.43096 .6105 Mdot
.67301 .45242 Mdot
.36833 .48146 Mdot
.66813 .4936 Mdot
.48683 .48086 Mdot
.59608 .52203 Mdot
.60678 .64509 Mdot
.62367 .43358 Mdot
.5191 .55055 Mdot
.26264 .73817 Mdot
.69595 .51854 Mdot
.44207 .32649 Mdot
.41282 .67861 Mdot
.42638 .65095 Mdot
.48737 .3005 Mdot
.42764 .64659 Mdot
.60206 .30394 Mdot
.70176 .28183 Mdot
.61605 .65145 Mdot
.51688 .25258 Mdot
.60088 .64837 Mdot
.24251 .45039 Mdot
.59859 .44695 Mdot
.34823 .58094 Mdot
.38269 .64327 Mdot
.79508 .46248 Mdot
.36849 .50368 Mdot
.25011 .4512 Mdot
.6476 .43266 Mdot
.50542 .6745 Mdot
.41959 .61763 Mdot
.34228 .71006 Mdot
.66928 .46464 Mdot
.50237 .31759 Mdot
.62792 .51742 Mdot
.5859 .5069 Mdot
.26424 .44837 Mdot
.64323 .48 Mdot
.36652 .53219 Mdot
.4776 .3586 Mdot
.26554 .71766 Mdot
.417 .68004 Mdot
.61984 .43701 Mdot
.61138 .46673 Mdot
.507 .31814 Mdot
.62688 .42758 Mdot
.38926 .48892 Mdot
.09021 .55744 Mdot
.62236 .66174 Mdot
.26948 .43724 Mdot
.33588 .71119 Mdot
.61819 .50032 Mdot
.64324 .51121 Mdot
.25209 .47767 Mdot
.3094 .27534 Mdot
.3697 .53227 Mdot
.57021 .44833 Mdot
.39344 .63495 Mdot
.60054 .65384 Mdot
.39384 .48694 Mdot
.66126 .46648 Mdot
.62271 .43995 Mdot
.60925 .64501 Mdot
.41566 .7418 Mdot
.39101 .59007 Mdot
.3704 .5162 Mdot
.56311 .53536 Mdot
.53862 .70494 Mdot
.62627 .4466 Mdot
.18178 .57088 Mdot
.46549 .31123 Mdot
.38325 .52434 Mdot
.67523 .37768 Mdot
.67202 .50554 Mdot
.39806 .51532 Mdot
.36164 .48775 Mdot
.66146 .44138 Mdot
.50152 .28193 Mdot
.46615 .36228 Mdot
.4627 .31058 Mdot
.76435 .3575 Mdot
.71768 .70397 Mdot
.40024 .66982 Mdot
.3668 .49057 Mdot
.42268 .68907 Mdot
.59044 .6342 Mdot
.45854 .52533 Mdot
.43207 .67588 Mdot
.45637 .29299 Mdot
.42935 .68551 Mdot
.66398 .49988 Mdot
.36666 .48404 Mdot
.39004 .62996 Mdot
.62495 .50105 Mdot
.59787 .39416 Mdot
.53868 .55769 Mdot
.58693 .64025 Mdot
.44383 .55098 Mdot
.63486 .47128 Mdot
.26412 .44428 Mdot
.60129 .44974 Mdot
.35329 .48109 Mdot
.51193 .55377 Mdot
.63159 .49949 Mdot
.38176 .65625 Mdot
.54382 .65473 Mdot
.43749 .64157 Mdot
.5713 .47506 Mdot
.62816 .46583 Mdot
.6257 .44489 Mdot
.62461 .51869 Mdot
.29311 .37381 Mdot
.34244 .51788 Mdot
.67913 .41187 Mdot
.38071 .67584 Mdot
.48742 .32665 Mdot
.50175 .30545 Mdot
.50904 .63946 Mdot
.26777 .44904 Mdot
.38008 .48584 Mdot
.62835 .44562 Mdot
.34242 .70948 Mdot
.20686 .46462 Mdot
.17253 .5571 Mdot
.47225 .7207 Mdot
.39234 .62863 Mdot
.44315 .33168 Mdot
.40041 .60774 Mdot
.65801 .44356 Mdot
.62092 .40857 Mdot
.27758 .72758 Mdot
.39984 .47229 Mdot
.60874 .65824 Mdot
.645 .44134 Mdot
.79632 .52772 Mdot
.39399 .63233 Mdot
.40008 .59688 Mdot
.67258 .48224 Mdot
.47884 .3657 Mdot
.33264 .80029 Mdot
.35488 .48167 Mdot
.54553 .24565 Mdot
.51828 .3846 Mdot
.52035 .44909 Mdot
.3555 .50197 Mdot
.56485 .58129 Mdot
.43363 .65279 Mdot
.50778 .2007 Mdot
.48474 .32199 Mdot
.61056 .66246 Mdot
.58794 .42431 Mdot
.45406 .29405 Mdot
.4452 .63838 Mdot
.45148 .3063 Mdot
.67548 .49457 Mdot
.36322 .53719 Mdot
.42996 .63838 Mdot
.33395 .49895 Mdot
.51595 .31826 Mdot
.59781 .64899 Mdot
.77491 .49891 Mdot
.54561 .23922 Mdot
.72123 .37214 Mdot
.63818 .49899 Mdot
.36567 .70964 Mdot
.65593 .48014 Mdot
.4493 .35717 Mdot
.62545 .45708 Mdot
.4247 .36692 Mdot
.42397 .60725 Mdot
.58213 .51057 Mdot
.60787 .43293 Mdot
.52175 .21553 Mdot
.59904 .46961 Mdot
.65094 .4346 Mdot
.60675 .5141 Mdot
.50676 .3914 Mdot
.5636 .46662 Mdot
.50235 .32233 Mdot
.33822 .38114 Mdot
.40532 .65159 Mdot
.62418 .63799 Mdot
.62164 .69187 Mdot
.78792 .57892 Mdot
.78973 .52291 Mdot
.31917 .40755 Mdot
.48683 .30499 Mdot
.38448 .53219 Mdot
.66895 .49101 Mdot
.62806 .36883 Mdot
.62024 .60068 Mdot
.43351 .6491 Mdot
.38901 .67791 Mdot
.55356 .46835 Mdot
.76133 .70775 Mdot
.56714 .48333 Mdot
.38039 .39818 Mdot
.64437 .52024 Mdot
.5972 .51236 Mdot
.39453 .59904 Mdot
.77045 .51985 Mdot
.63757 .49934 Mdot
.44157 .34939 Mdot
.61324 .66694 Mdot
.59225 .55351 Mdot
.62246 .59614 Mdot
.52279 .52747 Mdot
.45464 .23821 Mdot
.64728 .48234 Mdot
.40577 .62653 Mdot
.44859 .2996 Mdot
.39237 .3791 Mdot
.37889 .51351 Mdot
.4024 .41093 Mdot
.55609 .22048 Mdot
.4413 .69155 Mdot
.61212 .66151 Mdot
.43911 .73472 Mdot
.61416 .4847 Mdot
.40846 .67978 Mdot
.674 .4915 Mdot
.20349 .46708 Mdot
.59154 .6477 Mdot
.51676 .3333 Mdot
.3882 .52576 Mdot
.49354 .3013 Mdot
.67574 .35607 Mdot
.61278 .59348 Mdot
.20007 .41793 Mdot
.41424 .68638 Mdot
.76361 .46027 Mdot
.46005 .34322 Mdot
.66531 .46873 Mdot
.16712 .32203 Mdot
.46564 .31368 Mdot
.49849 .30772 Mdot
.51695 .63282 Mdot
.73337 .54617 Mdot
.66755 .53871 Mdot
.4546 .3009 Mdot
.41335 .6967 Mdot
.60118 .67599 Mdot
.63441 .50782 Mdot
.61157 .5158 Mdot
.50509 .33268 Mdot
.42236 .61807 Mdot
.80199 .52318 Mdot
.41417 .66741 Mdot
.49642 .33287 Mdot
.41966 .64382 Mdot
.3209 .69721 Mdot
.38991 .64825 Mdot
.5988 .43547 Mdot
.62938 .44664 Mdot
.54145 .77263 Mdot
.47039 .3083 Mdot
.63739 .51111 Mdot
.64632 .45885 Mdot
.46738 .34619 Mdot
.37553 .6695 Mdot
.73016 .40541 Mdot
.62076 .49411 Mdot
.63625 .45036 Mdot
.58456 .66816 Mdot
.45338 .57295 Mdot
.19908 .5427 Mdot
.63548 .50919 Mdot
.6333 .67643 Mdot
.46524 .35941 Mdot
.59942 .4525 Mdot
.7789 .51277 Mdot
.40863 .58183 Mdot
.64125 .43505 Mdot
.23748 .44118 Mdot
.60703 .49927 Mdot
.32715 .79722 Mdot
.61341 .43686 Mdot
.46764 .35124 Mdot
.45845 .33577 Mdot
.38903 .58885 Mdot
.47974 .32912 Mdot
.25328 .44917 Mdot
.38466 .50024 Mdot
.16989 .57349 Mdot
.24892 .44809 Mdot
.5863 .49722 Mdot
.47147 .19181 Mdot
.63693 .52594 Mdot
.62905 .41958 Mdot
.78863 .48562 Mdot
.25266 .44708 Mdot
.45123 .33165 Mdot
.23312 .61461 Mdot
.59476 .51389 Mdot
.35685 .4812 Mdot
.61456 .41427 Mdot
.63554 .43314 Mdot
.50469 .44053 Mdot
.75851 .372 Mdot
.35535 .47723 Mdot
.67084 .41985 Mdot
.63685 .50843 Mdot
.36441 .23684 Mdot
.61444 .47321 Mdot
.62951 .6663 Mdot
.47477 .29706 Mdot
.39979 .60536 Mdot
.62094 .67091 Mdot
.61511 .49358 Mdot
.60744 .66381 Mdot
.39868 .66733 Mdot
.38701 .51303 Mdot
.63115 .43512 Mdot
.61391 .69676 Mdot
.60655 .65448 Mdot
.65896 .48688 Mdot
.46065 .33065 Mdot
.6139 .55076 Mdot
.59768 .45514 Mdot
.66367 .46228 Mdot
.48829 .30149 Mdot
.48104 .15047 Mdot
.67773 .46169 Mdot
.55656 .58481 Mdot
.49998 .29659 Mdot
.25323 .42145 Mdot
.39815 .61209 Mdot
.68201 .48577 Mdot
.36889 .51127 Mdot
.37884 .50653 Mdot
.39262 .69951 Mdot
.50912 .33817 Mdot
.42992 .62656 Mdot
.701 .46573 Mdot
.55535 .45773 Mdot
.57609 .43113 Mdot
.78335 .29816 Mdot
.3463 .7448 Mdot
.48243 .35587 Mdot
.43549 .64601 Mdot
.42223 .4362 Mdot
.38013 .48704 Mdot
.39973 .70643 Mdot
.44962 .28174 Mdot
.45336 .34944 Mdot
.45862 .29355 Mdot
.59781 .68189 Mdot
.41808 .67051 Mdot
.44813 .37078 Mdot
.49192 .36067 Mdot
.67016 .476 Mdot
.63818 .50808 Mdot
.49606 .37771 Mdot
.74513 .6452 Mdot
.60146 .64557 Mdot
.40903 .62998 Mdot
.5208 .86708 Mdot
.35235 .48225 Mdot
.51941 .21484 Mdot
.62391 .49999 Mdot
.35929 .14223 Mdot
.56643 .4499 Mdot
.6128 .46914 Mdot
.46547 .3583 Mdot
.63844 .67368 Mdot
.59869 .66899 Mdot
.45991 .34233 Mdot
.52035 .32312 Mdot
.61913 .68742 Mdot
.46812 .72728 Mdot
.1772 .61748 Mdot
.397 .39272 Mdot
.47181 .3506 Mdot
.53058 .23894 Mdot
.39539 .49444 Mdot
.50419 .29672 Mdot
.35211 .47925 Mdot
.40305 .65142 Mdot
.38936 .67502 Mdot
.39167 .47412 Mdot
.66711 .45804 Mdot
.39287 .6607 Mdot
.71037 .4755 Mdot
.30769 .73144 Mdot
.52281 .81137 Mdot
.28592 .2864 Mdot
.5974 .49415 Mdot
.34278 .32311 Mdot
.3161 .32697 Mdot
.62964 .4806 Mdot
.54348 .42774 Mdot
.60874 .66029 Mdot
.50725 .30358 Mdot
.37921 .4824 Mdot
.36542 .787 Mdot
.62697 .44629 Mdot
.49082 .33933 Mdot
.37241 .48463 Mdot
.31482 .6807 Mdot
.48228 .42287 Mdot
.67304 .48538 Mdot
.09879 .42637 Mdot
.51657 .32481 Mdot
.40012 .60488 Mdot
.46015 .21043 Mdot
.49425 .28077 Mdot
.54099 .69187 Mdot
.41769 .59755 Mdot
.17101 .51024 Mdot
.44703 .33318 Mdot
.3741 .63377 Mdot
.47501 .33541 Mdot
.61785 .64564 Mdot
.50008 .27768 Mdot
.42544 .63315 Mdot
.60373 .46375 Mdot
.42616 .63808 Mdot
.60748 .64268 Mdot
.40463 .68213 Mdot
.38187 .48317 Mdot
.26024 .44754 Mdot
.37897 .49033 Mdot
.45567 .53274 Mdot
.73987 .35919 Mdot
.3708 .52372 Mdot
.3537 .72188 Mdot
.61313 .50511 Mdot
.42652 .34792 Mdot
.39689 .60743 Mdot
.40005 .69203 Mdot
.45416 .51219 Mdot
.48697 .33853 Mdot
.42211 .63279 Mdot
.55932 .22507 Mdot
.56872 .14894 Mdot
.71335 .46908 Mdot
.67917 .72636 Mdot
.46901 .34755 Mdot
.41671 .60158 Mdot
.3859 .38485 Mdot
.47707 .28814 Mdot
.38372 .64599 Mdot
.39005 .5193 Mdot
.36134 .5071 Mdot
.66929 .45526 Mdot
.37816 .46242 Mdot
.43692 .62384 Mdot
.26199 .33805 Mdot
.47398 .29599 Mdot
.32113 .67838 Mdot
.62982 .67446 Mdot
.39992 .65577 Mdot
.63783 .54414 Mdot
.52124 .34845 Mdot
.39126 .68361 Mdot
.58467 .7777 Mdot
.56218 .86102 Mdot
.42136 .63334 Mdot
.47404 .29703 Mdot
.49113 .32142 Mdot
.68239 .52887 Mdot
.45084 .48012 Mdot
.42213 .62243 Mdot
.35468 .59628 Mdot
.78933 .59159 Mdot
.24207 .43574 Mdot
.41765 .19427 Mdot
.63662 .49883 Mdot
.65549 .47516 Mdot
.39273 .49677 Mdot
.60517 .48108 Mdot
.4685 .36526 Mdot
.61371 .42168 Mdot
.3797 .54081 Mdot
.43363 .64453 Mdot
.61095 .44169 Mdot
.59214 .66475 Mdot
.38936 .4868 Mdot
.40292 .4891 Mdot
.41387 .64976 Mdot
.45677 .29683 Mdot
.22229 .61637 Mdot
.41417 .66849 Mdot
.64648 .48394 Mdot
.25341 .43943 Mdot
.67655 .49832 Mdot
.5065 .78373 Mdot
.48361 .29272 Mdot
.40141 .60605 Mdot
.46257 .28011 Mdot
.37299 .49263 Mdot
.39463 .69673 Mdot
.61808 .47514 Mdot
.3836 .65293 Mdot
.64869 .6473 Mdot
.47576 .75528 Mdot
.49806 .35896 Mdot
.61385 .70687 Mdot
.50662 .32319 Mdot
.24131 .43642 Mdot
.68254 .6092 Mdot
.61505 .65591 Mdot
.39344 .6437 Mdot
.34277 .74882 Mdot
.38193 .63274 Mdot
.59751 .46974 Mdot
.59289 .47739 Mdot
.40787 .61413 Mdot
.59023 .67087 Mdot
.81972 .46399 Mdot
.57884 .60224 Mdot
.449 .32286 Mdot
.40427 .31836 Mdot
.4555 .85651 Mdot
.32313 .50512 Mdot
.39388 .52093 Mdot
.61108 .39988 Mdot
.64111 .51615 Mdot
.39923 .48882 Mdot
.33981 .50058 Mdot
.58376 .65152 Mdot
.40419 .67796 Mdot
.43362 .30659 Mdot
.3964 .49184 Mdot
.73573 .50028 Mdot
.78803 .51438 Mdot
.69049 .51985 Mdot
.58571 .52052 Mdot
.57989 .46306 Mdot
.46309 .54201 Mdot
.34897 .52233 Mdot
.63659 .46767 Mdot
.57062 .42871 Mdot
.37803 .52895 Mdot
.61234 .64415 Mdot
.45444 .2649 Mdot
.41505 .63813 Mdot
.47582 .1196 Mdot
.62849 .43447 Mdot
.60098 .4606 Mdot
.3671 .51478 Mdot
.38756 .21065 Mdot
.48224 .3536 Mdot
.46257 .29584 Mdot
.401 .66208 Mdot
.4507 .51277 Mdot
.60969 .42623 Mdot
.63124 .47741 Mdot
.39708 .64252 Mdot
.26156 .44543 Mdot
.24968 .3134 Mdot
.63723 .45673 Mdot
.35977 .49421 Mdot
.34648 .69461 Mdot
.34657 .51917 Mdot
.67574 .48407 Mdot
.59602 .47126 Mdot
.60193 .43293 Mdot
.6255 .5201 Mdot
.3955 .48175 Mdot
.62772 .47782 Mdot
.56189 .51036 Mdot
.45372 .31793 Mdot
.63178 .49246 Mdot
.78427 .57443 Mdot
.63227 .45244 Mdot
.59248 .66191 Mdot
.20105 .56397 Mdot
.63257 .44151 Mdot
.63433 .49035 Mdot
.57448 .59781 Mdot
.61048 .45939 Mdot
.34954 .49047 Mdot
.48747 .32129 Mdot
.36792 .48972 Mdot
.35156 .51748 Mdot
.41247 .69361 Mdot
.58473 .64736 Mdot
.67697 .51579 Mdot
.62846 .68152 Mdot
.62313 .53912 Mdot
.67399 .49734 Mdot
.44708 .56028 Mdot
.37983 .4002 Mdot
.64543 .65269 Mdot
.62202 .4717 Mdot
.40429 .65773 Mdot
.39374 .61457 Mdot
.66082 .70071 Mdot
.70733 .49707 Mdot
.39267 .48313 Mdot
.39141 .51291 Mdot
.72868 .63064 Mdot
.49903 .42583 Mdot
.59529 .65429 Mdot
.42302 .42716 Mdot
.59295 .49109 Mdot
.64618 .45261 Mdot
.61996 .41334 Mdot
.42933 .68096 Mdot
.2662 .44456 Mdot
.43196 .65387 Mdot
.27639 .45421 Mdot
.34434 .5178 Mdot
.59633 .49203 Mdot
.47992 .81124 Mdot
.5009 .34656 Mdot
.48685 .32 Mdot
.38671 .5383 Mdot
.43754 .63848 Mdot
.67823 .53047 Mdot
.79572 .30573 Mdot
.4709 .37878 Mdot
.63713 .65598 Mdot
.63505 .47581 Mdot
.41114 .65237 Mdot
.49657 .35484 Mdot
.58687 .68621 Mdot
.59206 .48445 Mdot
.37667 .66489 Mdot
.62731 .45442 Mdot
.56894 .33211 Mdot
.45361 .32442 Mdot
.20167 .45924 Mdot
.49419 .36285 Mdot
.39926 .50623 Mdot
.35903 .52554 Mdot
.5931 .46667 Mdot
.68379 .208 Mdot
.51522 .3462 Mdot
.33516 .48307 Mdot
.60902 .63868 Mdot
.26846 .43608 Mdot
.59498 .63831 Mdot
.42383 .61201 Mdot
.61368 .66416 Mdot
.38238 .66222 Mdot
.72933 .64831 Mdot
.45743 .37692 Mdot
.622 .66501 Mdot
.36231 .21628 Mdot
.68006 .44963 Mdot
.58193 .6613 Mdot
.55408 .48005 Mdot
.43867 .3823 Mdot
.39965 .64225 Mdot
.59133 .67124 Mdot
.66678 .47445 Mdot
.39821 .79134 Mdot
.35451 .5218 Mdot
.39071 .48123 Mdot
.67923 .51265 Mdot
.39148 .6069 Mdot
.51991 .31688 Mdot
.51176 .60101 Mdot
.24761 .42095 Mdot
.63058 .47667 Mdot
.59329 .48881 Mdot
.51074 .32547 Mdot
.44793 .35935 Mdot
.59459 .47203 Mdot
.57462 .23548 Mdot
.61485 .48574 Mdot
.35843 .50664 Mdot
.46128 .35383 Mdot
.4892 .31874 Mdot
.44077 .63026 Mdot
.5084 .33915 Mdot
.57925 .51102 Mdot
.40716 .53138 Mdot
.5864 .41881 Mdot
.37496 .49641 Mdot
.52019 .55889 Mdot
.41158 .68179 Mdot
.36274 .77845 Mdot
.51033 .34036 Mdot
.64066 .48349 Mdot
.50536 .31748 Mdot
.6258 .67767 Mdot
.47252 .30851 Mdot
.44642 .29746 Mdot
.58881 .47242 Mdot
.6726 .4885 Mdot
.25704 .44407 Mdot
.45046 .48256 Mdot
.45889 .32028 Mdot
.6196 .48652 Mdot
.63386 .52759 Mdot
.67363 .44759 Mdot
.4828 .50065 Mdot
.4516 .35008 Mdot
.66422 .25543 Mdot
.51672 .79426 Mdot
.46075 .3269 Mdot
.37966 .81295 Mdot
.23733 .43088 Mdot
.27004 .44767 Mdot
.32782 .51282 Mdot
.63892 .45386 Mdot
.42954 .63065 Mdot
.6555 .44215 Mdot
.70996 .4644 Mdot
.62648 .43857 Mdot
.59909 .64272 Mdot
.64509 .53558 Mdot
.24982 .42852 Mdot
.41914 .66275 Mdot
.61841 .49558 Mdot
.61511 .44036 Mdot
.26471 .45121 Mdot
.49892 .36142 Mdot
.44879 .34136 Mdot
.18615 .57858 Mdot
.62131 .65345 Mdot
.3841 .51077 Mdot
.66098 .4495 Mdot
.40293 .65949 Mdot
.42733 .64183 Mdot
.49577 .30365 Mdot
.41098 .63467 Mdot
.35487 .48064 Mdot
.61207 .47656 Mdot
.39873 .48707 Mdot
.60038 .64267 Mdot
.4755 .29724 Mdot
.66117 .44907 Mdot
.67014 .47403 Mdot
.4582 .33566 Mdot
.6121 .50482 Mdot
.58488 .66938 Mdot
.39336 .6764 Mdot
.45166 .34394 Mdot
.38362 .50179 Mdot
.44218 .63674 Mdot
.66603 .4945 Mdot
.6373 .81526 Mdot
.60588 .48363 Mdot
.65815 .45379 Mdot
.21013 .66954 Mdot
.59176 .40695 Mdot
.41974 .60524 Mdot
.50055 .3026 Mdot
.6721 .4376 Mdot
.79224 .61074 Mdot
.28078 .49414 Mdot
.39738 .70534 Mdot
.63869 .47737 Mdot
.34651 .77449 Mdot
.63482 .48532 Mdot
.30695 .67684 Mdot
.44684 .55685 Mdot
.72257 .72063 Mdot
.57852 .5141 Mdot
.36145 .47096 Mdot
.25743 .44567 Mdot
.39403 .60926 Mdot
.62523 .35536 Mdot
.60658 .49254 Mdot
.68238 .37105 Mdot
.62518 .42989 Mdot
.35646 .50257 Mdot
.55955 .41312 Mdot
.40988 .63097 Mdot
.48781 .20316 Mdot
.6512 .4831 Mdot
.45512 .35251 Mdot
.42122 .69427 Mdot
.25984 .42666 Mdot
.66768 .4717 Mdot
.63259 .67175 Mdot
.30099 .46379 Mdot
.5588 .47286 Mdot
.37729 .4978 Mdot
.64844 .45888 Mdot
.68209 .42763 Mdot
.62032 .17931 Mdot
.45203 .31975 Mdot
.39281 .52072 Mdot
.36848 .26726 Mdot
.60737 .50445 Mdot
.44764 .33574 Mdot
.48565 .32411 Mdot
.62779 .65383 Mdot
.3827 .42339 Mdot
.30601 .5012 Mdot
.56563 .80684 Mdot
.70702 .35815 Mdot
.44365 .63183 Mdot
.29138 .30836 Mdot
.63979 .50427 Mdot
.60991 .58945 Mdot
.34876 .49521 Mdot
.60291 .46087 Mdot
.72344 .34681 Mdot
.4636 .30929 Mdot
.63383 .4594 Mdot
.604 .64568 Mdot
.31018 .44778 Mdot
.53008 .52984 Mdot
.55755 .84009 Mdot
.40666 .70265 Mdot
.60445 .41464 Mdot
.57465 .51658 Mdot
.25713 .42266 Mdot
.66717 .50469 Mdot
.39714 .60565 Mdot
.3811 .73556 Mdot
.58822 .66425 Mdot
.5032 .34685 Mdot
.23893 .42856 Mdot
.58814 .43701 Mdot
.67578 .51069 Mdot
.62461 .63864 Mdot
.66246 .4735 Mdot
.47361 .20877 Mdot
.21727 .42893 Mdot
.38918 .65156 Mdot
.45071 .30583 Mdot
.57982 .46657 Mdot
.2661 .4438 Mdot
.59045 .47513 Mdot
.44369 .26121 Mdot
.65104 .47169 Mdot
.28794 .41935 Mdot
.46332 .33492 Mdot
.37905 .49506 Mdot
.67641 .51955 Mdot
.61878 .44733 Mdot
.53774 .70839 Mdot
.70914 .4616 Mdot
.61461 .43721 Mdot
.43823 .34352 Mdot
.49855 .34432 Mdot
.50076 .31683 Mdot
.39049 .66012 Mdot
.4018 .39917 Mdot
.36455 .50028 Mdot
.62182 .42483 Mdot
.39563 .49094 Mdot
.72756 .48045 Mdot
.63121 .64599 Mdot
.42678 .82197 Mdot
.61317 .49734 Mdot
.49552 .31043 Mdot
.25595 .35703 Mdot
.46738 .36003 Mdot
.41148 .57602 Mdot
.36252 .48629 Mdot
.46479 .31539 Mdot
.61543 .45928 Mdot
.43403 .44932 Mdot
.59996 .82455 Mdot
.38415 .49044 Mdot
.62325 .41099 Mdot
.4063 .70025 Mdot
.38249 .67026 Mdot
.3777 .83217 Mdot
.35858 .52792 Mdot
.3138 .32344 Mdot
.62289 .48709 Mdot
.50214 .34318 Mdot
.37178 .52057 Mdot
.34671 .49341 Mdot
.40078 .63812 Mdot
.67526 .47535 Mdot
.62227 .44913 Mdot
.23682 .43946 Mdot
.39035 .50977 Mdot
.68493 .45338 Mdot
.65401 .51521 Mdot
.26507 .72071 Mdot
.43312 .29819 Mdot
.45484 .15213 Mdot
.69664 .45709 Mdot
.73108 .36426 Mdot
.48449 .52474 Mdot
.48147 .35709 Mdot
.66355 .44864 Mdot
.59596 .42669 Mdot
.44238 .62722 Mdot
.61008 .48031 Mdot
.43353 .66544 Mdot
.39275 .52441 Mdot
.44111 .83169 Mdot
.32768 .66967 Mdot
.45489 .71934 Mdot
.6024 .47559 Mdot
.5153 .46518 Mdot
.62134 .67713 Mdot
.39711 .53045 Mdot
.49424 .3406 Mdot
.5836 .48084 Mdot
.42018 .59837 Mdot
.39292 .64145 Mdot
.47959 .32038 Mdot
.31533 .34735 Mdot
.32997 .72342 Mdot
.62673 .52106 Mdot
.40533 .6064 Mdot
.31259 .65353 Mdot
.59805 .24615 Mdot
.37517 .46435 Mdot
.58876 .65609 Mdot
.43301 .64295 Mdot
.40405 .48876 Mdot
.4299 .28135 Mdot
.47243 .32322 Mdot
.51356 .32363 Mdot
.52475 .75799 Mdot
.42477 .62523 Mdot
.6134 .67807 Mdot
.47998 .41144 Mdot
.43222 .39661 Mdot
.59474 .64579 Mdot
.43404 .64478 Mdot
.49744 .35074 Mdot
.49291 .33748 Mdot
.48822 .32284 Mdot
.483 .20642 Mdot
.47758 .29223 Mdot
.61401 .21357 Mdot
.64431 .52486 Mdot
.53998 .24943 Mdot
.63617 .48294 Mdot
.3812 .47257 Mdot
.45372 .32618 Mdot
.46369 .5123 Mdot
.59315 .50162 Mdot
.56424 .83502 Mdot
.63502 .47247 Mdot
.4147 .50136 Mdot
.63818 .45196 Mdot
.49949 .23387 Mdot
.50063 .29718 Mdot
.62184 .47342 Mdot
.34235 .48032 Mdot
.60397 .65657 Mdot
.48984 .26048 Mdot
.63058 .44199 Mdot
.3219 .43105 Mdot
.57102 .42976 Mdot
.31975 .73303 Mdot
.53377 .65621 Mdot
.63887 .6613 Mdot
.56452 .44167 Mdot
.44288 .65778 Mdot
.52007 .29578 Mdot
.53386 .2576 Mdot
.38507 .49154 Mdot
.77554 .43822 Mdot
.39301 .64755 Mdot
.55841 .41437 Mdot
.57938 .49341 Mdot
.59622 .68235 Mdot
.51779 .29469 Mdot
.35697 .50912 Mdot
.61072 .50072 Mdot
.65801 .4395 Mdot
.59113 .76019 Mdot
.527 .25087 Mdot
.68689 .46478 Mdot
.59474 .63346 Mdot
.67648 .26427 Mdot
.64339 .44615 Mdot
.37936 .67856 Mdot
.48757 .28892 Mdot
.61221 .53724 Mdot
.65021 .24652 Mdot
.61768 .48824 Mdot
.46937 .31552 Mdot
.51126 .33792 Mdot
.27639 .39074 Mdot
.63603 .65622 Mdot
.65127 .47136 Mdot
.55193 .70966 Mdot
.65275 .47899 Mdot
.361 .50169 Mdot
.67891 .46599 Mdot
.39907 .65042 Mdot
.38223 .38492 Mdot
.39212 .669 Mdot
.67171 .45263 Mdot
.49026 .33317 Mdot
.35973 .51391 Mdot
.51454 .77098 Mdot
.4972 .60349 Mdot
.62501 .21932 Mdot
.28566 .47196 Mdot
.59744 .6794 Mdot
.57974 .65936 Mdot
.35701 .53755 Mdot
.6262 .46763 Mdot
.47154 .55841 Mdot
.5738 .49461 Mdot
.6383 .44898 Mdot
.63302 .43689 Mdot
.39971 .46988 Mdot
.36983 .48696 Mdot
.42235 .6405 Mdot
.59571 .47426 Mdot
.62002 .48534 Mdot
.46485 .32716 Mdot
.60553 .65367 Mdot
.3876 .65819 Mdot
.62473 .66205 Mdot
.41363 .66407 Mdot
.33621 .79885 Mdot
.66423 .42679 Mdot
.60273 .65672 Mdot
.35638 .53295 Mdot
.49233 .30388 Mdot
.25064 .45272 Mdot
.42792 .61722 Mdot
.41252 .6304 Mdot
.6289 .47905 Mdot
.47302 .29973 Mdot
.46221 .30322 Mdot
.61311 .68795 Mdot
.38301 .52049 Mdot
.66808 .44959 Mdot
.66315 .50625 Mdot
.64359 .74414 Mdot
.44156 .65295 Mdot
.5919 .23352 Mdot
.29706 .38887 Mdot
.62523 .46782 Mdot
.45287 .30888 Mdot
.60678 .44401 Mdot
.40193 .77235 Mdot
.45516 .29371 Mdot
.61087 .51952 Mdot
.50873 .41337 Mdot
.41833 .68886 Mdot
.2419 .40214 Mdot
.65652 .528 Mdot
.24777 .47901 Mdot
.65161 .49571 Mdot
.17368 .64797 Mdot
.32526 .26617 Mdot
.60056 .42968 Mdot
.61647 .51546 Mdot
.59857 .79922 Mdot
.62665 .48771 Mdot
.24252 .42993 Mdot
.70488 .47633 Mdot
.45083 .34639 Mdot
.48641 .55789 Mdot
.4526 .5841 Mdot
.62624 .64454 Mdot
.40043 .66231 Mdot
.6808 .58316 Mdot
.61647 .64585 Mdot
.46644 .34907 Mdot
.61023 .5158 Mdot
.75345 .45903 Mdot
.40005 .58526 Mdot
.58541 .50741 Mdot
.35946 .50149 Mdot
.4491 .57687 Mdot
.42769 .66876 Mdot
.38431 .49821 Mdot
.61557 .42984 Mdot
.81243 .56193 Mdot
.49917 .61859 Mdot
.1582 .50493 Mdot
.37009 .51602 Mdot
.35292 .49226 Mdot
.38939 .3626 Mdot
.62646 .64487 Mdot
.60693 .75213 Mdot
.53063 .5037 Mdot
.36133 .48133 Mdot
.72581 .59922 Mdot
.40216 .59401 Mdot
.37827 .42151 Mdot
.50532 .30063 Mdot
.65667 .42278 Mdot
.616 .45577 Mdot
.38057 .52479 Mdot
.66638 .38283 Mdot
.41216 .25696 Mdot
.38096 .49061 Mdot
.57793 .52502 Mdot
.32735 .44113 Mdot
.25097 .44172 Mdot
.23506 .43734 Mdot
.61011 .63728 Mdot
.38882 .72601 Mdot
.47288 .33952 Mdot
.59464 .68358 Mdot
.27736 .42054 Mdot
.65331 .46681 Mdot
.39298 .5061 Mdot
.24582 .45312 Mdot
.3752 .50681 Mdot
.59704 .66373 Mdot
.63625 .65435 Mdot
.45337 .31822 Mdot
.48309 .35305 Mdot
.7574 .3766 Mdot
.74417 .61531 Mdot
.63037 .48987 Mdot
.72509 .39665 Mdot
.48179 .29618 Mdot
.52643 .28114 Mdot
.63545 .66928 Mdot
.60585 .65086 Mdot
.57787 .30025 Mdot
.67123 .48104 Mdot
.33787 .67848 Mdot
.63528 .44309 Mdot
.68075 .6193 Mdot
.58369 .4967 Mdot
.40441 .63641 Mdot
.63882 .49278 Mdot
.21147 .5904 Mdot
.6262 .50854 Mdot
.62263 .43563 Mdot
.42622 .6571 Mdot
.69152 .50481 Mdot
.3975 .64966 Mdot
.67602 .47944 Mdot
.60261 .62875 Mdot
.40296 .65983 Mdot
.69932 .71072 Mdot
.55539 .5828 Mdot
.26608 .43888 Mdot
.61434 .64167 Mdot
.62864 .67943 Mdot
.7943 .55898 Mdot
.49167 .34447 Mdot
.41838 .31545 Mdot
.62721 .46705 Mdot
.39955 .59766 Mdot
.39368 .49763 Mdot
.61779 .48604 Mdot
.59282 .42622 Mdot
.6718 .52112 Mdot
.46132 .31238 Mdot
.43516 .63354 Mdot
.60399 .66348 Mdot
.39482 .61614 Mdot
.51264 .65895 Mdot
.3795 .65229 Mdot
.61029 .39749 Mdot
.69504 .46021 Mdot
.69291 .53813 Mdot
.72963 .38849 Mdot
.5088 .19761 Mdot
.47716 .32434 Mdot
.25707 .43572 Mdot
.62633 .64235 Mdot
.40554 .3121 Mdot
.4978 .32124 Mdot
.41539 .62865 Mdot
.62713 .45441 Mdot
.58312 .53069 Mdot
.52154 .51277 Mdot
.51734 .37897 Mdot
.77823 .6178 Mdot
.41502 .67622 Mdot
.24451 .43926 Mdot
.39261 .39136 Mdot
.48351 .39047 Mdot
.46197 .51939 Mdot
.61454 .44467 Mdot
.63239 .67467 Mdot
.49669 .35477 Mdot
.55271 .76343 Mdot
.38717 .5213 Mdot
.44999 .47967 Mdot
.60356 .47685 Mdot
.28239 .33144 Mdot
.48991 .33317 Mdot
.60043 .64771 Mdot
.37979 .52555 Mdot
.63634 .65937 Mdot
.23624 .4296 Mdot
.19513 .5926 Mdot
.66006 .48072 Mdot
.60921 .43698 Mdot
.33598 .50342 Mdot
.4759 .33896 Mdot
.37395 .62339 Mdot
.56355 .77279 Mdot
.40583 .60781 Mdot
.46426 .55705 Mdot
.4804 .35861 Mdot
.46248 .2352 Mdot
.38709 .63686 Mdot
.38185 .54229 Mdot
.46943 .5425 Mdot
.37792 .54035 Mdot
.63779 .44145 Mdot
.48666 .30707 Mdot
.36041 .52955 Mdot
.54873 .73375 Mdot
.31237 .76666 Mdot
.46511 .24941 Mdot
.60551 .49812 Mdot
.43911 .82901 Mdot
.24661 .69613 Mdot
.70476 .40052 Mdot
.39726 .49759 Mdot
.59382 .45882 Mdot
.62734 .52168 Mdot
.64854 .48506 Mdot
.37886 .53524 Mdot
.49166 .67816 Mdot
.40199 .62904 Mdot
.63988 .47006 Mdot
.62898 .67581 Mdot
.40545 .64561 Mdot
.43388 .68168 Mdot
.38904 .61656 Mdot
.44557 .30233 Mdot
.61884 .52041 Mdot
.36174 .41387 Mdot
.19289 .67329 Mdot
.37039 .48862 Mdot
.26602 .43831 Mdot
.61739 .43199 Mdot
.74465 .31197 Mdot
.50014 .31598 Mdot
.40687 .60858 Mdot
.60183 .45949 Mdot
.51992 .68854 Mdot
.25031 .46287 Mdot
.4128 .67169 Mdot
.49152 .34255 Mdot
.70462 .40119 Mdot
.61055 .48118 Mdot
.6543 .49518 Mdot
.47091 .3441 Mdot
.17271 .55382 Mdot
.38381 .39768 Mdot
.61132 .44254 Mdot
.38047 .49504 Mdot
.59088 .15845 Mdot
.67712 .51158 Mdot
.51195 .36962 Mdot
.26926 .4373 Mdot
.30736 .4162 Mdot
.60549 .2399 Mdot
.69496 .43147 Mdot
.46322 .8218 Mdot
.7708 .51387 Mdot
.41284 .81929 Mdot
.64178 .59502 Mdot
.27899 .61802 Mdot
.29551 .78531 Mdot
.34406 .47787 Mdot
.51372 .24947 Mdot
.6781 .75507 Mdot
.33106 .3515 Mdot
.53032 .64477 Mdot
.30231 .54547 Mdot
.5304 .67581 Mdot
.28219 .25843 Mdot
.38237 .64177 Mdot
.66469 .63896 Mdot
.66431 .44628 Mdot
.24131 .6869 Mdot
.53603 .22961 Mdot
.5106 .18702 Mdot
.40502 .80853 Mdot
.54835 .69828 Mdot
.63679 .80194 Mdot
.35906 .77059 Mdot
.76615 .46337 Mdot
.50585 .48797 Mdot
.36317 .57509 Mdot
.45728 .40614 Mdot
.69907 .57349 Mdot
.67794 .53778 Mdot
.2117 .55626 Mdot
.41489 .71904 Mdot
.70961 .30403 Mdot
.5892 .16791 Mdot
.42739 .61369 Mdot
.48363 .28683 Mdot
.63579 .75398 Mdot
.514 .27978 Mdot
.36559 .55375 Mdot
.46443 .8221 Mdot
.26503 .72467 Mdot
.4998 .23274 Mdot
.19983 .43301 Mdot
.59603 .33556 Mdot
.82322 .4355 Mdot
.51955 .53497 Mdot
.51187 .34461 Mdot
.29863 .60008 Mdot
.43272 .39637 Mdot
.36828 .60614 Mdot
.47058 .22214 Mdot
.59768 .69724 Mdot
.74237 .66962 Mdot
.48969 .34167 Mdot
.61503 .25162 Mdot
.27405 .44209 Mdot
.27823 .42555 Mdot
.38037 .61267 Mdot
.4146 .77878 Mdot
.27141 .464 Mdot
.33768 .42622 Mdot
.25939 .33224 Mdot
.6113 .83399 Mdot
.74701 .55737 Mdot
.40566 .75697 Mdot
.41545 .4813 Mdot
.76726 .52077 Mdot
.36601 .36809 Mdot
.75767 .58862 Mdot
.43633 .38991 Mdot
.76381 .71845 Mdot
.18771 .62113 Mdot
.67838 .78128 Mdot
.45495 .2719 Mdot
.68171 .45479 Mdot
.45568 .78784 Mdot
.69524 .35461 Mdot
.6403 .66964 Mdot
.58746 .83756 Mdot
.62553 .68946 Mdot
.43662 .30074 Mdot
.32528 .34438 Mdot
.49514 .21611 Mdot
.39756 .72008 Mdot
.59728 .62409 Mdot
.56787 .48826 Mdot
.85817 .61702 Mdot
.4935 .83008 Mdot
.28732 .39733 Mdot
.25716 .7154 Mdot
.33599 .47611 Mdot
.39601 .57585 Mdot
.3897 .52818 Mdot
.29783 .77299 Mdot
.49395 .31974 Mdot
.20347 .69385 Mdot
.29073 .75904 Mdot
.41003 .23439 Mdot
.89353 .56328 Mdot
.27774 .28351 Mdot
.54628 .24749 Mdot
.77171 .48725 Mdot
.76117 .6634 Mdot
.37674 .33955 Mdot
.40667 .22761 Mdot
.38248 .56644 Mdot
.16718 .55863 Mdot
.33895 .79313 Mdot
.7104 .6123 Mdot
.44058 .70073 Mdot
.34433 .34653 Mdot
.53359 .55963 Mdot
.5041 .37255 Mdot
.56212 .60838 Mdot
.58872 .58319 Mdot
.65754 .79051 Mdot
.74371 .3292 Mdot
.7241 .23469 Mdot
.65537 .60214 Mdot
.39674 .2093 Mdot
.34768 .74119 Mdot
.68626 .71274 Mdot
.4331 .25816 Mdot
.33704 .39074 Mdot
.58091 .41306 Mdot
.40961 .4034 Mdot
.55768 .50857 Mdot
.60213 .70643 Mdot
.39523 .38061 Mdot
.28196 .66609 Mdot
.67538 .60538 Mdot
.54581 .80587 Mdot
.50901 .44579 Mdot
.4442 .31213 Mdot
.77589 .56497 Mdot
.73639 .57785 Mdot
.27933 .72751 Mdot
.36637 .26892 Mdot
.15601 .52114 Mdot
.38186 .25825 Mdot
.57188 .49158 Mdot
.52117 .2615 Mdot
.66732 .5436 Mdot
.7498 .58475 Mdot
.62233 .52965 Mdot
.2497 .3477 Mdot
.21699 .68079 Mdot
.73073 .34448 Mdot
.68613 .58709 Mdot
.73915 .40085 Mdot
.17119 .5793 Mdot
.47363 .79482 Mdot
.32122 .27849 Mdot
.54241 .3672 Mdot
.82697 .65522 Mdot
.41437 .64404 Mdot
.72375 .60583 Mdot
.40803 .50874 Mdot
.52675 .7618 Mdot
.72926 .72669 Mdot
.40426 .24939 Mdot
.20973 .67326 Mdot
.34707 .39301 Mdot
.376 .69631 Mdot
.38339 .43295 Mdot
.44004 .60284 Mdot
.75304 .41938 Mdot
.68593 .50544 Mdot
.72344 .51354 Mdot
.5886 .68088 Mdot
.67294 .34289 Mdot
.49845 .79154 Mdot
.25914 .52717 Mdot
.6535 .40056 Mdot
.26446 .55714 Mdot
.2411 .43959 Mdot
.43813 .46121 Mdot
.36783 .82704 Mdot
.69907 .45088 Mdot
.30791 .25697 Mdot
.18479 .60835 Mdot
.46135 .54749 Mdot
.42278 .74524 Mdot
.28794 .3665 Mdot
.72314 .75399 Mdot
.257 .73115 Mdot
.26988 .68888 Mdot
.45072 .83368 Mdot
.14479 .47068 Mdot
.78286 .6773 Mdot
.60742 .36524 Mdot
.40704 .48719 Mdot
.09198 .52114 Mdot
.40233 .61992 Mdot
.77918 .43361 Mdot
.69647 .35172 Mdot
.51445 .70166 Mdot
.52453 .31588 Mdot
.58612 .39194 Mdot
.29515 .47444 Mdot
.4878 .37476 Mdot
.56582 .48178 Mdot
.55341 .85676 Mdot
.77166 .71446 Mdot
.57195 .84955 Mdot
.19624 .59992 Mdot
.4367 .83355 Mdot
.64949 .7758 Mdot
.60324 .20825 Mdot
.61039 .75773 Mdot
.67844 .47133 Mdot
.71304 .63659 Mdot
.28649 .27842 Mdot
.37261 .63706 Mdot
.21876 .42181 Mdot
.46053 .27646 Mdot
.73578 .73473 Mdot
.38458 .84098 Mdot
.59925 .30521 Mdot
.6686 .27397 Mdot
.57273 .5794 Mdot
.74108 .60361 Mdot
.72347 .52416 Mdot
.21496 .53491 Mdot
.30643 .7359 Mdot
.66219 .77121 Mdot
.71822 .58748 Mdot
.29412 .55254 Mdot
.27006 .67764 Mdot
.37548 .22607 Mdot
.38351 .77957 Mdot
.65862 .7524 Mdot
.39633 .2415 Mdot
.54343 .38722 Mdot
.41057 .25412 Mdot
.2078 .51383 Mdot
.35352 .68158 Mdot
.73831 .55594 Mdot
.40823 .68418 Mdot
.7107 .61847 Mdot
.47937 .45138 Mdot
.61977 .75819 Mdot
.77608 .51808 Mdot
.70361 .61624 Mdot
.28331 .69215 Mdot
.51653 .85332 Mdot
.17647 .4662 Mdot
.82623 .57237 Mdot
.23256 .48342 Mdot
.54704 .4892 Mdot
.68319 .483 Mdot
.19181 .63849 Mdot
.49411 .86226 Mdot
.2184 .69275 Mdot
.28169 .32806 Mdot
.54108 .73335 Mdot
.39204 .46942 Mdot
.8041 .48952 Mdot
.24854 .50399 Mdot
.312 .74738 Mdot
.40437 .35236 Mdot
.32642 .5111 Mdot
.35451 .39366 Mdot
.77207 .43774 Mdot
.78262 .48923 Mdot
.6372 .2704 Mdot
.6921 .52057 Mdot
.566 .23938 Mdot
.50111 .30043 Mdot
.29027 .31487 Mdot
.75103 .59338 Mdot
.41331 .64884 Mdot
.68338 .73257 Mdot
.71816 .52375 Mdot
.58779 .40723 Mdot
.35789 .68797 Mdot
.5034 .37096 Mdot
.72933 .38271 Mdot
.37324 .56455 Mdot
.31245 .79553 Mdot
.29637 .28168 Mdot
.75225 .48082 Mdot
.76841 .54883 Mdot
.61356 .73774 Mdot
.38894 .40767 Mdot
.36307 .54047 Mdot
.39152 .79895 Mdot
.54113 .60054 Mdot
.7744 .55878 Mdot
.57303 .24014 Mdot
.54208 .77925 Mdot
.58899 .42881 Mdot
.27584 .37814 Mdot
.66337 .23885 Mdot
.44551 .47672 Mdot
.43108 .3385 Mdot
.46971 .37965 Mdot
.28169 .24038 Mdot
.22255 .59897 Mdot
.35915 .25982 Mdot
.39781 .79588 Mdot
.38208 .53851 Mdot
.44083 .33944 Mdot
.69933 .62751 Mdot
.4807 .75682 Mdot
.70846 .28825 Mdot
.3626 .71727 Mdot
.724 .53239 Mdot
.24359 .51661 Mdot
.44522 .82857 Mdot
.56501 .82571 Mdot
.63171 .18172 Mdot
.47868 .36786 Mdot
.49138 .78228 Mdot
.51655 .77926 Mdot
.49699 .35794 Mdot
.51519 .37705 Mdot
.51485 .49923 Mdot
.40294 .82448 Mdot
.4218 .40719 Mdot
.20617 .48917 Mdot
.46875 .54467 Mdot
.50814 .68086 Mdot
.56465 .76406 Mdot
.73151 .55493 Mdot
.40288 .79357 Mdot
.61807 .26142 Mdot
.78963 .64335 Mdot
.65798 .55289 Mdot
.76428 .37673 Mdot
.80467 .48857 Mdot
.5078 .52472 Mdot
.47825 .22758 Mdot
.29583 .67222 Mdot
.64377 .48521 Mdot
.60433 .83931 Mdot
.27849 .71952 Mdot
.40016 .36778 Mdot
.33921 .55028 Mdot
.65116 .50757 Mdot
.63463 .52526 Mdot
.60639 .37714 Mdot
.3041 .40364 Mdot
.81654 .62688 Mdot
.66581 .61361 Mdot
.55245 .50195 Mdot
.5673 .23462 Mdot
.30954 .25634 Mdot
.43141 .7808 Mdot
.32899 .73678 Mdot
.46694 .4516 Mdot
.28718 .28012 Mdot
.44143 .51065 Mdot
.19952 .48566 Mdot
.24301 .55548 Mdot
.63873 .7783 Mdot
.52597 .44137 Mdot
.31925 .39509 Mdot
.59663 .74765 Mdot
.62381 .43317 Mdot
.31515 .34782 Mdot
.36897 .77209 Mdot
.77209 .28839 Mdot
.36316 .35525 Mdot
.53127 .86397 Mdot
.70634 .52925 Mdot
.32814 .40085 Mdot
.74776 .71611 Mdot
.83695 .36578 Mdot
.20965 .5449 Mdot
.64347 .79903 Mdot
.41631 .45015 Mdot
.40679 .80155 Mdot
.37002 .4685 Mdot
.47541 .4213 Mdot
.70628 .38198 Mdot
.39586 .82149 Mdot
.4399 .76236 Mdot
.42458 .79148 Mdot
.5974 .3749 Mdot
.44054 .84009 Mdot
.43135 .38144 Mdot
.30826 .22519 Mdot
.38392 .69096 Mdot
.23166 .34749 Mdot
.56124 .36426 Mdot
.66365 .5624 Mdot
.72244 .59749 Mdot
.38112 .19614 Mdot
.5576 .1909 Mdot
.63065 .37021 Mdot
.68833 .66998 Mdot
.29326 .3757 Mdot
.7684 .54352 Mdot
.31242 .75414 Mdot
.28781 .2506 Mdot
.54186 .77158 Mdot
.32368 .29945 Mdot
.18397 .58107 Mdot
.29876 .40418 Mdot
.2461 .59341 Mdot
.40245 .75828 Mdot
.18471 .51667 Mdot
.7133 .5425 Mdot
.38295 .14436 Mdot
.46301 .65286 Mdot
.5175 .50439 Mdot
.70404 .76277 Mdot
.30322 .73364 Mdot
.40282 .32031 Mdot
.45965 .21597 Mdot
.78652 .40057 Mdot
.72825 .65234 Mdot
.62648 .43875 Mdot
.44998 .84426 Mdot
.71746 .6878 Mdot
.61308 .82415 Mdot
.15824 .57508 Mdot
.57588 .25326 Mdot
.66601 .41209 Mdot
.44703 .63112 Mdot
.53604 .54279 Mdot
.68176 .67285 Mdot
.65877 .78108 Mdot
.77459 .40695 Mdot
.49787 .5966 Mdot
.27759 .60694 Mdot
.34613 .71315 Mdot
.53577 .4759 Mdot
.26711 .2985 Mdot
.30326 .38931 Mdot
.66451 .59525 Mdot
.25854 .66732 Mdot
.73619 .59739 Mdot
.59718 .23657 Mdot
.79386 .50571 Mdot
.3839 .29544 Mdot
.31673 .47478 Mdot
.43944 .62249 Mdot
.5866 .79733 Mdot
.3353 .72775 Mdot
.24787 .35215 Mdot
.81526 .59681 Mdot
.33458 .3845 Mdot
.66472 .65181 Mdot
.53433 .79769 Mdot
.37412 .33328 Mdot
.35986 .57819 Mdot
.78418 .48171 Mdot
.76022 .37357 Mdot
.31056 .69162 Mdot
.67114 .40351 Mdot
.34326 .79954 Mdot
.73349 .55854 Mdot
.58479 .78116 Mdot
.5509 .57507 Mdot
.69185 .33166 Mdot
.55327 .2968 Mdot
.72278 .6994 Mdot
.45235 .50816 Mdot
.84812 .6292 Mdot
.51622 .30441 Mdot
.61417 .83279 Mdot
.38657 .50792 Mdot
.68971 .23034 Mdot
.31006 .71443 Mdot
.47483 .46967 Mdot
.47725 .52844 Mdot
.27337 .38047 Mdot
.31757 .43792 Mdot
.17859 .57952 Mdot
.41012 .24961 Mdot
.37902 .64181 Mdot
.50762 .61074 Mdot
.20838 .49715 Mdot
.54715 .81255 Mdot
.66827 .43653 Mdot
.40137 .72389 Mdot
.51385 .53286 Mdot
.41485 .56329 Mdot
.19609 .64216 Mdot
.30022 .66176 Mdot
.60902 .53845 Mdot
.74285 .60504 Mdot
.67956 .76704 Mdot
.29346 .75542 Mdot
.41068 .26775 Mdot
.55996 .51197 Mdot
.41042 .52396 Mdot
.72791 .71463 Mdot
.49328 .82601 Mdot
.33296 .6769 Mdot
.37446 .41934 Mdot
.74274 .56151 Mdot
.61029 .85508 Mdot
.76858 .71586 Mdot
.82132 .59551 Mdot
.46946 .55309 Mdot
.42786 .35379 Mdot
.74889 .32073 Mdot
.58091 .78283 Mdot
.21564 .36824 Mdot
.27628 .70581 Mdot
.72773 .60133 Mdot
.81257 .34906 Mdot
.53048 .19964 Mdot
.50811 .6548 Mdot
.55469 .29957 Mdot
.71404 .36379 Mdot
.35465 .47103 Mdot
.71709 .66472 Mdot
.52579 .61433 Mdot
.35015 .54167 Mdot
.29523 .37835 Mdot
.33266 .43211 Mdot
.58842 .77928 Mdot
.68847 .26592 Mdot
.58473 .53893 Mdot
.51125 .81542 Mdot
.45394 .37492 Mdot
.54685 .76546 Mdot
.61446 .73973 Mdot
.52188 .62432 Mdot
.39569 .61862 Mdot
.70304 .51601 Mdot
.41643 .43508 Mdot
.43733 .47851 Mdot
.82688 .50615 Mdot
.61876 .69373 Mdot
.48709 .27418 Mdot
.49667 .20069 Mdot
.4709 .36688 Mdot
.47488 .86269 Mdot
.21567 .53628 Mdot
.55763 .23453 Mdot
.45526 .62956 Mdot
.29859 .57565 Mdot
.84099 .46052 Mdot
.76937 .45216 Mdot
.57758 .60689 Mdot
.4484 .38311 Mdot
.50762 .31887 Mdot
.45333 .63741 Mdot
.22919 .42176 Mdot
.63988 .26174 Mdot
.30466 .25328 Mdot
.62514 .74099 Mdot
.50675 .35379 Mdot
.50209 .66245 Mdot
.73669 .45121 Mdot
.35314 .81457 Mdot
.39018 .61898 Mdot
.81507 .67004 Mdot
.69358 .45721 Mdot
.76546 .68452 Mdot
.19875 .64928 Mdot
.38101 .38009 Mdot
.47131 .56321 Mdot
.32316 .55564 Mdot
.62567 .41973 Mdot
.5913 .54528 Mdot
.48288 .34922 Mdot
.59941 .75963 Mdot
.61265 .65941 Mdot
.77117 .61266 Mdot
.37381 .54533 Mdot
.40595 .21651 Mdot
.2711 .30012 Mdot
.48794 .2866 Mdot
.53979 .61437 Mdot
.45586 .77656 Mdot
.50246 .45649 Mdot
.51259 .53206 Mdot
.59858 .79716 Mdot
.71362 .29914 Mdot
.50932 .34732 Mdot
.81575 .60249 Mdot
.65513 .65869 Mdot
.27283 .75647 Mdot
.72122 .43604 Mdot
.51654 .52641 Mdot
.50557 .45513 Mdot
.27783 .37114 Mdot
.61382 .24288 Mdot
.32264 .73914 Mdot
.77033 .5732 Mdot
.48549 .40911 Mdot
.7037 .61876 Mdot
.64171 .54698 Mdot
.2735 .60637 Mdot
.23704 .33298 Mdot
.82104 .36687 Mdot
.5777 .33434 Mdot
.36456 .3848 Mdot
.46738 .38218 Mdot
.30554 .25942 Mdot
.50759 .28693 Mdot
.48863 .7093 Mdot
.71625 .31189 Mdot
.30961 .7157 Mdot
.31007 .78519 Mdot
.2784 .72592 Mdot
.56127 .55677 Mdot
.34056 .70179 Mdot
.76573 .49969 Mdot
.72399 .43355 Mdot
.47159 .50127 Mdot
.62198 .4209 Mdot
.53651 .46086 Mdot
.3984 .29474 Mdot
.25352 .35734 Mdot
.56919 .40506 Mdot
.38445 .81109 Mdot
.269 .75009 Mdot
.48426 .84427 Mdot
.3527 .67014 Mdot
.44423 .30148 Mdot
.73629 .74321 Mdot
.58202 .21854 Mdot
.30643 .75288 Mdot
.56684 .36417 Mdot
.25879 .26193 Mdot
.71576 .73841 Mdot
.28845 .67245 Mdot
.41016 .23079 Mdot
.22058 .40953 Mdot
.20354 .64776 Mdot
.30655 .22688 Mdot
.70583 .55418 Mdot
.18625 .62603 Mdot
.85734 .6161 Mdot
.58423 .3586 Mdot
.32944 .42942 Mdot
.54446 .28244 Mdot
.76043 .49625 Mdot
.30549 .24494 Mdot
.68034 .47124 Mdot
.39156 .68487 Mdot
.52747 .65871 Mdot
.73386 .59251 Mdot
.71959 .46788 Mdot
.31627 .23486 Mdot
.67848 .67392 Mdot
.66208 .63858 Mdot
.49735 .77458 Mdot
.6861 .75267 Mdot
.62867 .25028 Mdot
.57729 .52085 Mdot
.44041 .28804 Mdot
.59916 .63877 Mdot
.67972 .57701 Mdot
.65036 .51305 Mdot
.44448 .55364 Mdot
.51933 .49475 Mdot
.54972 .85996 Mdot
.48897 .73448 Mdot
.44528 .72358 Mdot
.4804 .3786 Mdot
.29794 .3947 Mdot
.46907 .80136 Mdot
.32887 .3485 Mdot
.34312 .2171 Mdot
.74223 .33323 Mdot
.45581 .8289 Mdot
.34434 .40069 Mdot
.70344 .58513 Mdot
.8239 .47285 Mdot
.37505 .47385 Mdot
.70132 .37272 Mdot
.64648 .78216 Mdot
.3214 .36375 Mdot
.43622 .34546 Mdot
.2636 .65132 Mdot
.29012 .62502 Mdot
.3115 .36879 Mdot
.18407 .60489 Mdot
.50898 .78684 Mdot
.56476 .27737 Mdot
.55046 .82599 Mdot
.41669 .69649 Mdot
.71751 .59061 Mdot
.2394 .61796 Mdot
.29547 .2496 Mdot
.50499 .44203 Mdot
.35636 .80485 Mdot
.47135 .50661 Mdot
.72578 .68653 Mdot
.65808 .48647 Mdot
.6575 .25023 Mdot
.26278 .36104 Mdot
.25739 .65907 Mdot
.35781 .26711 Mdot
.45408 .28904 Mdot
.27093 .31622 Mdot
.36792 .57446 Mdot
.72742 .66729 Mdot
.66983 .57281 Mdot
.50484 .26079 Mdot
.61445 .60573 Mdot
.27821 .43883 Mdot
.69176 .46138 Mdot
.75531 .65942 Mdot
.35816 .72326 Mdot
.68668 .37274 Mdot
.60501 .36396 Mdot
.58585 .79905 Mdot
.37615 .73628 Mdot
.23897 .35682 Mdot
.59784 .36991 Mdot
.27935 .41526 Mdot
.54692 .19964 Mdot
.33393 .32157 Mdot
.65086 .52842 Mdot
.48988 .70698 Mdot
.45176 .35246 Mdot
.55251 .81402 Mdot
.44753 .26727 Mdot
.69551 .71274 Mdot
.44817 .45413 Mdot
.44739 .78409 Mdot
.53702 .57374 Mdot
.20173 .65126 Mdot
.21919 .41015 Mdot
.75254 .59231 Mdot
.34029 .52378 Mdot
.41177 .44786 Mdot
.36388 .34471 Mdot
.35208 .78497 Mdot
.39454 .27213 Mdot
.75418 .45555 Mdot
.35763 .38779 Mdot
.7297 .35736 Mdot
.16694 .59511 Mdot
.74834 .61816 Mdot
.47079 .49935 Mdot
.74348 .4955 Mdot
.2695 .41798 Mdot
.25313 .45314 Mdot
.50789 .71457 Mdot
.6105 .23202 Mdot
.4579 .69771 Mdot
.48752 .59766 Mdot
.68628 .45688 Mdot
.73908 .30478 Mdot
.53213 .82456 Mdot
.40639 .3045 Mdot
.478 .4826 Mdot
.58991 .74581 Mdot
.73409 .6657 Mdot
.5296 .12609 Mdot
.59574 .8456 Mdot
.65893 .48644 Mdot
.47716 .54645 Mdot
.76506 .61687 Mdot
.43245 .66653 Mdot
.64958 .27263 Mdot
.57873 .80293 Mdot
.35544 .48674 Mdot
.5404 .74198 Mdot
.21274 .43265 Mdot
.2663 .37582 Mdot
.71349 .70868 Mdot
.37817 .46179 Mdot
.49542 .86889 Mdot
.26922 .69667 Mdot
.2696 .35413 Mdot
.45633 .1186 Mdot
.26858 .3341 Mdot
.42134 .34894 Mdot
.42766 .76187 Mdot
.51061 .8537 Mdot
.46683 .55026 Mdot
.52475 .75842 Mdot
.61406 .36287 Mdot
.75972 .58512 Mdot
.67636 .61724 Mdot
.32206 .30047 Mdot
.28676 .30454 Mdot
.31963 .2159 Mdot
.29938 .57445 Mdot
.83365 .51057 Mdot
.60308 .25245 Mdot
.56459 .83002 Mdot
.20995 .54084 Mdot
.80318 .33496 Mdot
.29924 .77377 Mdot
.70602 .64494 Mdot
.33478 .22749 Mdot
.42617 .75361 Mdot
.78795 .59308 Mdot
.69667 .25852 Mdot
.19869 .55338 Mdot
.72925 .31703 Mdot
.28324 .56274 Mdot
.34575 .29441 Mdot
.70768 .61799 Mdot
.7245 .36278 Mdot
.46812 .50768 Mdot
.62307 .80244 Mdot
.40045 .19782 Mdot
.76269 .5541 Mdot
.55733 .74212 Mdot
.79306 .60141 Mdot
.50251 .82006 Mdot
.38282 .76411 Mdot
.49244 .5243 Mdot
.85775 .59571 Mdot
.65602 .79091 Mdot
.33828 .33614 Mdot
.64927 .52436 Mdot
.28675 .77517 Mdot
.50407 .56278 Mdot
.62138 .36714 Mdot
.22315 .66219 Mdot
.66118 .61176 Mdot
.52079 .47633 Mdot
.67785 .51239 Mdot
.78123 .4715 Mdot
.46514 .23855 Mdot
.72398 .36688 Mdot
.61241 .72997 Mdot
.76904 .55202 Mdot
.40425 .19948 Mdot
.76213 .67071 Mdot
.7057 .41331 Mdot
.47267 .3591 Mdot
.52839 .85811 Mdot
.76336 .46053 Mdot
.66371 .5549 Mdot
.54447 .25941 Mdot
.4003 .264 Mdot
.2998 .49634 Mdot
.55092 .49534 Mdot
.39124 .40865 Mdot
.72445 .59527 Mdot
.56689 .7871 Mdot
.70419 .38422 Mdot
.89871 .55615 Mdot
.20022 .65524 Mdot
.52052 .31999 Mdot
.65621 .36087 Mdot
.52029 .63456 Mdot
.49253 .84192 Mdot
.28863 .54721 Mdot
.61392 .7384 Mdot
.48088 .19235 Mdot
.78265 .57042 Mdot
.5748 .46097 Mdot
.19648 .60408 Mdot
.31814 .78104 Mdot
.42537 .18516 Mdot
.34314 .7988 Mdot
.63765 .40253 Mdot
.65212 .41506 Mdot
.75798 .24657 Mdot
.42421 .81488 Mdot
.69472 .43263 Mdot
.4288 .23145 Mdot
.5277 .32435 Mdot
.67015 .45206 Mdot
.21696 .43978 Mdot
.73999 .54201 Mdot
.67251 .6252 Mdot
.39997 .82231 Mdot
.46649 .37555 Mdot
.45915 .55672 Mdot
.40535 .4908 Mdot
.47227 .52331 Mdot
.60744 .54004 Mdot
.35503 .52632 Mdot
.67198 .63591 Mdot
.49962 .56767 Mdot
.29961 .46326 Mdot
.7028 .55245 Mdot
.1847 .47293 Mdot
.63582 .57109 Mdot
.56339 .5625 Mdot
.55812 .38165 Mdot
.55751 .19031 Mdot
.67997 .67229 Mdot
.66704 .69392 Mdot
.18508 .61983 Mdot
.15994 .42693 Mdot
.4591 .59909 Mdot
.63917 .38443 Mdot
.52887 .39465 Mdot
.60012 .23132 Mdot
.55482 .27035 Mdot
.3302 .45419 Mdot
.2489 .44842 Mdot
.60539 .40046 Mdot
.75188 .4811 Mdot
.39937 .51585 Mdot
.58019 .8628 Mdot
.67761 .49647 Mdot
.59929 .27312 Mdot
.33769 .76961 Mdot
.55373 .76365 Mdot
.55621 .53119 Mdot
.61819 .41964 Mdot
.42262 .37642 Mdot
.50442 .57194 Mdot
.74438 .45121 Mdot
.57544 .76182 Mdot
.50713 .8359 Mdot
.58245 .55898 Mdot
.58545 .26535 Mdot
.63334 .47258 Mdot
.58966 .63083 Mdot
.40704 .41757 Mdot
.81651 .52623 Mdot
.5951 .61018 Mdot
.29274 .75018 Mdot
.64821 .63226 Mdot
.66551 .61294 Mdot
.52364 .24288 Mdot
.60737 .82908 Mdot
.35938 .35653 Mdot
.56934 .24907 Mdot
.39449 .32846 Mdot
.25369 .6115 Mdot
.68879 .66715 Mdot
.44728 .66443 Mdot
.56633 .40875 Mdot
.52847 .32133 Mdot
.40521 .83788 Mdot
.76946 .44959 Mdot
.35138 .44964 Mdot
.31266 .69685 Mdot
.54849 .20288 Mdot
.47838 .52463 Mdot
.41535 .13111 Mdot
.29489 .53813 Mdot
.50146 .86854 Mdot
.54566 .78441 Mdot
.52649 .40479 Mdot
.29384 .37245 Mdot
.71071 .50115 Mdot
.42702 .65001 Mdot
.49884 .83976 Mdot
.73702 .46966 Mdot
.33138 .31306 Mdot
.67519 .4878 Mdot
.42051 .38908 Mdot
.74834 .46965 Mdot
.33209 .69224 Mdot
.3832 .67285 Mdot
.40808 .26581 Mdot
.38569 .77149 Mdot
.50648 .57349 Mdot
.23541 .2934 Mdot
.66002 .7813 Mdot
.38895 .79863 Mdot
.35017 .71395 Mdot
.68734 .22441 Mdot
.44205 .37836 Mdot
.72687 .43587 Mdot
.33085 .50403 Mdot
.77412 .48769 Mdot
.31502 .36459 Mdot
.57058 .78254 Mdot
.27971 .41241 Mdot
.49898 .47572 Mdot
.32092 .17135 Mdot
.70247 .63769 Mdot
.40683 .32247 Mdot
.30495 .34597 Mdot
.37182 .80224 Mdot
.56426 .71301 Mdot
.15907 .50189 Mdot
.21257 .57114 Mdot
.61674 .54205 Mdot
.67196 .24723 Mdot
.79181 .63302 Mdot
.32088 .65138 Mdot
.83904 .49039 Mdot
.34107 .72894 Mdot
.69612 .57505 Mdot
.25156 .64957 Mdot
.47633 .36718 Mdot
.52221 .30643 Mdot
.21565 .52023 Mdot
.19993 .4453 Mdot
.64534 .38043 Mdot
.47705 .82509 Mdot
.81403 .40418 Mdot
.61436 .74515 Mdot
.45522 .83779 Mdot
.41651 .47829 Mdot
.50052 .38582 Mdot
.67535 .67089 Mdot
.64648 .65938 Mdot
.432 .6738 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo093ooooo0_l00005ooooo`;o0000/?ooool001cooooo00?o
0000ooooooooool0T?ooool2o`0000Cooooo0ol0002`ooooo`007?ooool00ol0003oooooooooo`2F
ooooo`;o00004?ooool2o`0009oooooo000Looooo`03o`000?oooooooooo0:Sooooo0_l0002Ooooo
o`007?ooool00ol0003oooooooooo`23ooooo`;o0000a?ooool001cooooo00?o0000ooooooooool0
Poooool2o`000<Cooooo000Looooo`03o`000?oooooooooo07kooooo0_l0000^ooooo`;o0000VOoo
ool001cooooo00?o0000ooooooooool0O_ooool2o`0002kooooo0_l0002Iooooo`007?ooool00ol0
003oooooooooo`1aooooo`;o00001_ooool2o`0003Gooooo0_l00003ooooo`;o000000?oooooo`00
0?l00000Soooool001cooooo00?o0000ooooooooool0LOooool2o`0000Kooooo0_l0000eooooo`;o
00000oooool2o`000003ooooool0003o000008oooooo000Looooo`03o`000?oooooooooo09Wooooo
0_l000000ooooooo0000o`00000Gooooo`;o0000T_ooool001cooooo0_l0002Aooooo`Co00001Ooo
ool2o`000003ooooool0003o000000Sooooo0_l0000=ooooo`;o0000T_ooool001cooooo00?o0000
ooooooooool0T?ooool4o`0001;ooooo1?l0002Oooooo`007?ooool00ol0003oooooooooo`2Xoooo
o`;o00001Oooool2o`0000_ooooo0_l0002;ooooo`007?ooool00ol0003oooooooooo`2_ooooo`;o
00002oooool2o`0008_ooooo000Looooo`03o`000?oooooooooo06[ooooo1?l00016ooooo`?o0000
00?oooooo`000?l00000Soooool001cooooo00?o0000ooooooooool0J_ooool4o`0004Kooooo0ol0
00000ooooooo0000o`000002ooooo`;o0000Roooool001cooooo00?o0000ooooooooool0IOooool2
o`0005Gooooo0_l00003ooooo`;o00002?ooool2o`0007cooooo000Looooo`03o`000?oooooooooo
06Gooooo0_l00013ooooo`;o00005Oooool2o`0000Sooooo0_l0001looooo`007?ooool00ol0003o
ooooooooo`2Zooooo`;o0000WOooool001cooooo00?o0000ooooooooool0Z?ooool2o`0001cooooo
0_l00021ooooo`007?ooool00ol0003oooooooooo`2Qooooo`;o00001Oooool2o`0001cooooo0_l0
00000ooooooo0000o`000002o`0007cooooo000Looooo`03o`000?oooooooooo08Kooooo0_l00003
ooooo`;o00005?ooool3o`0000_ooooo0_l000000ooooooo0000o`000002o`0000Wooooo0_l00008
ooooo`Co00002?ooool2o`0007;ooooo000Looooo`03o`000?oooooooooo08Kooooo0_l00003oooo
o`;o00005Oooool4o`0000Wooooo1ol00009ooooo`;o00003Oooool2o`0000Gooooo0_l0001boooo
o`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000
ooooooooool0S_ooool2o`0000Gooooo0_l000000ooooooo0000o`00000:ooooo`;o00002oooool5
o`000003ooooool0003o000001Gooooo0_l0001iooooo`0000KoooooogMgMonHV9SooooooiRHV?mg
MgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0
N?ooool2o`0000[ooooo0ol00007ooooo`;o00000oooool7o`0001Oooooo0ol00003ooooo`;o0000
5oooool2o`0007Oooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?o
V9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`1hooooo`;o00001?ooool4o`0000;ooooo1Ol0
0006ooooo`;o00000_ooool2o`0000;ooooo0_l00009ooooo`;o00000oooool4o`0000?ooooo0_l0
000Pooooo`;o0000Moooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool0
0onHV9So8B4Qonk^kP06ooooo`?o0000MOooool2o`0000?ooooo0_l00002ooooo`Co00001Oooool2
o`0000Kooooo0_l0000=ooooo`;o000000Coooooo`000?l0003o00000oooool4o`0000?ooooo0_l0
002Iooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKo
oooo00Gooooo00?o0000ooooooooool0MOooool2o`0000?ooooo0_l0000Oooooo`;o000000?ooooo
o`000?l000000ol0000;ooooo`;o0000VOooool00003ooooool@413ooooo00;ooooo00?o410@oooo
ooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07oooooo0_l0000Eoooo
o`;o000000?oooooo`000?l000000_l00002ooooo`;o00002?ooool2o`0000?ooooo0_l00002oooo
o`;o00001?ooool2o`0000Kooooo0_l0000Hooooo`;o0000KOooool00006oooooomgMgOoV9RHoooo
oonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0D_oo
ool2o`0002Kooooo0_l000000ooooooo0000o`000002o`00017ooooo0_l00002ooooo`;o000000Co
ooooo`000?l0003o00003Oooool2o`0000Oooooo0ol00003ooooo`;o00001_ooool4o`0001Kooooo
0_l0001]ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01_ooool00ol0003oooooooooo`1Booooo`;o00006?ooool2o`0000_ooooo0ol000000ooo
oooo0000o`00000Cooooo`;o00004Oooool2o`0000cooooo0_l0000=ooooo`Co000000?oooooo`00
0?l00000P?ooool001cooooo00?o0000ooooooooool0I?ooool2o`0000Kooooo0_l00004ooooo`;o
00001Oooool2o`0000;ooooo0_l000000ooooooo0000o`00000@ooooo`;o00002Oooool3o`0000Go
oooo1Ol0000Aooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`;o0000P?ooool001co
oooo00?o0000ooooooooool0I?ooool2o`0000Kooooo0ol00003ooooo`;o00003?ooool2o`000003
ooooool0003o000000gooooo0_l00009ooooo`?o00001?ooool6o`0000Oooooo0_l00006ooooo`Co
00001?ooool2o`0000Cooooo0_l00020ooooo`007?ooool00ol0003oooooooooo`1Wooooo`;o0000
1?ooool2o`0001Cooooo0_l0000<ooooo`;o00000_ooool2o`0000gooooo0_l0000;ooooo`Co0000
1?ooool2o`0000cooooo0_l0000Booooo`;o000000?oooooo`000?l00000JOooool001cooooo00?o
0000ooooooooool0H?ooool2o`0000Gooooo1?l0000;ooooo`;o00002?ooool2o`0000;ooooo0_l0
000;ooooo`;o00000_ooool2o`000003ooooool0003o000001?ooooo0_l00003ooooo`?o00002?oo
ool2o`0001cooooo0_l000000ooooooo0000o`00001Yooooo`007?ooool00ol0003oooooooooo`1P
ooooo`;o00001oooool2o`0000_ooooo0_l00008ooooo`?o000000?oooooo`000?l000004_ooool2
o`0000Kooooo0_l00008ooooo`;o000000?oooooo`000?l000000oooool3o`0000Sooooo0_l0000D
ooooo`;o00001oooool2o`0006_ooooo000Looooo`03o`000?oooooooooo087ooooo0_l00005oooo
o`;o00001?ooool3o`0000gooooo1?l00006ooooo`Co000000?oooooo`000?l000002Oooool3o`00
0003ooooool0003o000000?o00000_ooool2o`0000kooooo0_l00007ooooo`;o0000Joooool001co
oooo00?o0000ooooooooool0Hoooool2o`0000kooooo0_l00009ooooo`;o000000?oooooo`000?l0
00001Oooool2o`0000?ooooo1?l000000ooooooo0000o`00000:ooooo`?o00001oooool2o`0000Oo
oooo0_l00002ooooo`Ko000000?oooooo`000?l000000ol00002ooooo`;o00004?ooool2o`00013o
oooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`1Sooooo`;o00003_ooool2o`0000Wooooo
0_l000000ooooooo0000o`000009ooooo`Wo00001oooool2o`0000_ooooo0ol000000ooooooo0000
o`000002ooooo`;o000000?oooooo`000?l000001Ol00003ooooo`;o000000?oooooo`000?l00000
4Oooool3o`00013ooooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o00008ooo
ool2o`0000gooooo0_l00002ooooo`Go00001oooool2o`0000Sooooo0_l000000ooooooo0000o`00
0004o`0000Gooooo1?l00009ooooo`;o000000Coooooo`000?l0003ooooo0_l00007ooooo`;o0000
0_ooool2o`0007?ooooo000Looooo`03o`000?oooooooooo05Sooooo0_l00006ooooo`;o00006ooo
ool2o`000003ooooool0003o000000oooooo0_l0000Cooooo`?o00000oooool3o`0000Oooooo0_l0
0006ooooo`;o00001?ooool2o`000003ooooool0003o000000Oooooo0_l0001gooooo`007?ooool0
0ol0003oooooooooo`1Pooooo`;o00007_ooool2o`0001Kooooo0_l0000=ooooo`;o00000oooool4
o`0000Gooooo0_l00007ooooo`;o00002oooool8o`0000?ooooo0_l0000;ooooo`;o00003Oooool2
o`0005Gooooo000Looooo`;o0000Foooool4o`0001Kooooo1?l00008ooooo`?o00004?ooool2o`00
00?ooooo0_l00009ooooo`;o00000_ooool2o`0000?ooooo1?l00005ooooo`;o00003Oooool2o`00
00;ooooo0_l000000ooooooo0000o`000007o`0000;ooooo0_l0000;ooooo`;o00003Oooool2o`00
05Gooooo000Looooo`03o`000?oooooooooo05[ooooo2?l0000>ooooo`;o00000_ooool4o`0000So
oooo1?l0000?ooooo`;o00003_ooool3o`000003ooooool0003o000000?ooooo0_l00009ooooo`;o
00001oooool2o`0000;ooooo1_l00008ooooo`Co0000Loooool001cooooo00?o0000ooooooooool0
F?ooool2o`0000Cooooo1Ol0000=ooooo`;o000000?oooooo`000?l000000oooool2o`0000Sooooo
0_l00005ooooo`;o00004Oooool2o`0000Kooooo0_l000001?oooooo0000o`000?ooool2o`0000_o
oooo0_l00007ooooo`;o00001?ooool4o`0000[ooooo1?l00007ooooo`;o0000J?ooool001cooooo
00?o0000ooooooooool0F?ooool2o`0000Kooooo0ol0000>ooooo`Co00000oooool2o`0000Sooooo
0_l00005ooooo`Go00001?ooool2o`0000Oooooo0ol00002ooooo`;o00001?ooool3o`000004oooo
ool0003o0000ooooo`;o00005_ooool2o`0000Wooooo0_l00004ooooo`;o00001oooool2o`0006So
oooo000Looooo`03o`000?oooooooooo053ooooo0_l0000>ooooo`;o00003oooool2o`0000_ooooo
0_l0000:ooooo`Co00001?ooool2o`0000Oooooo0_l00003ooooo`;o00001?ooool2o`0000Gooooo
0_l0000>ooooo`;o00001_ooool2o`0000Gooooo0_l00002ooooo`;o00001_ooool2o`0000Kooooo
0_l0001Wooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00005?ooool2o`0000Sooooo0_l0
0002ooooo`;o00002?ooool2o`000004ooooool0003o0000o`0000[ooooo1?l00005ooooo`;o0000
8?ooool3o`000003ooooool0003o000000gooooo0_l0000:ooooo`;o00000_ooool2o`0000;ooooo
0_l0000:ooooo`;o0000Foooool001cooooo00?o0000ooooooooool0I_ooool2o`0000Kooooo1?l0
00001?oooooo0000o`000?l0000;ooooo`?o00002_ooool4o`0000Cooooo0ol0000Gooooo`;o0000
1?ooool2o`000004ooooool0003o0000o`0000oooooo0_l0000?ooooo`;o00003_ooool2o`0005_o
oooo000Looooo`03o`000?oooooooooo03oooooo0_l0000Vooooo`;o00000_ooool2o`000003oooo
ool0003o000000?ooooo0_l00007ooooo`;o00002Oooool2o`0000Oooooo0_l00002ooooo`Co0000
6?ooool2o`0000Cooooo0_l00007ooooo`;o00002_ooool2o`0000;ooooo0_l00004ooooo`;o0000
3Oooool2o`0006?ooooo000Looooo`03o`000?oooooooooo03oooooo0_l0000Pooooo`;o00001?oo
ool2o`000004ooooool0003o0000o`0000Sooooo0_l00005ooooo`;o00002Oooool2o`000003oooo
ool0003o000000;o00000_ooool<o`0000Cooooo0_l0000Mooooo`;o00003_ooool2o`0000Cooooo
0_l0000=ooooo`?o0000H_ooool001cooooo00?o0000ooooooooool0FOooool3o`0000Gooooo0_l0
0002ooooo`;o00000oooool2o`0000Wooooo0ol00005ooooo`?o00002_ooool4o`0000?ooooo1?l0
0002ooooo`Oo000000Goooooo`000?l0003o0000ooooo`02o`0000Gooooo0_l00008ooooo`;o0000
:_ooool2o`0000?ooooo0_l0001Rooooo`007?ooool00ol0003oooooooooo`1Iooooo`?o000000?o
ooooo`000?l000001_ooool2o`0000oooooo0_l00005ooooo`?o00002?ooool2o`0000Cooooo1ol0
00000ooooooo0000o`00000:o`000003ooooool0003o000000;ooooo0_l000001?oooooo0000o`00
0?ooool2o`0000Gooooo0_l0000Zooooo`;o0000Ioooool001cooooo00?o0000ooooooooool0Eooo
ool2o`0000Cooooo0_l00006ooooo`;o00008Oooool2o`0000;ooooo1Ol000000ooooooo0000o`00
000>o`0000Gooooo0_l00004ooooo`;o0000:oooool2o`0000Cooooo0_l0001Wooooo`007?ooool0
0ol0003oooooooooo`1Gooooo`Co00002_ooool3o`0000?ooooo0_l0000=ooooo`;o00003ooooolB
o`0000?ooooo0ol00008ooooo`;o0000;Oooool2o`0000Kooooo0_l0000Cooooo`;o0000D?ooool0
01cooooo00?o0000ooooooooool0FOooool2o`0000_ooooo0ol00002ooooo`;o00003Oooool2o`00
00oooooo0_l00002ooooo`Ko00000_ooool6o`0000Cooooo0_l00008ooooo`;o0000=Oooool2o`00
00Gooooo0_l0000<ooooo`;o000000?oooooo`000?l00000COooool001cooooo00?o0000oooooooo
ool0BOooool2o`0001[ooooo1?l00004ooooo`;o00002_ooool2o`0000?ooooo0_l0000;ooooo`;o
000000?oooooo`000?l000003ol00005ooooo`;o0000@_ooool3o`0000oooooo0_l0001=ooooo`00
7?ooool00ol0003oooooooooo`19ooooo`;o00002?ooool2o`00013ooooo0_l00006ooooo`;o0000
2_ooool2o`0000?ooooo0_l00005ooooo`;o00000_oooolCo`000003ooooool0003o000000?o0000
0_ooool3o`0000Kooooo0_l000000ooooooo0000o`00000<ooooo`;o0000:?ooool2o`00013ooooo
0ol0001<ooooo`007?ooool2o`0003Wooooo0_l0000Iooooo`?o00001?ooool2o`0000Wooooo0_l0
000Nooooo`;o00000_ooool3o`000003ooooool0003o000001?o00000oooool2o`0000Kooooo0_l0
00000ooooooo0000o`000006ooooo`;o00001?ooool2o`0002Cooooo0_l0000Eooooo`;o0000C?oo
ool001cooooo00?o0000ooooooooool0>?ooool2o`0001[ooooo0_l00003ooooo`?o00002Oooool2
o`0001Wooooo0_l00008oooooago00002Oooool2o`0000Kooooo0_l00006ooooo`;o00008Oooool3
o`0000;ooooo0_l00002ooooo`;o0000Foooool001cooooo00?o0000ooooooooool0FOooool2o`00
013ooooo0_l0000Cooooo`;o00001oooool2o`000003ooooool0003o000001[o00005oooool3o`00
027ooooo0_l00003ooooo`;o00000_ooool2o`00017ooooo0_l00018ooooo`007?ooool00ol0003o
ooooooooo`1Kooooo`;o00003_ooool2o`0001cooooo0_l000000ooooooo0000o`00000Go`000003
ooooool0003o000001Oooooo0_l0000Yooooo`;o00004oooool2o`0004Sooooo000Looooo`03o`00
0?oooooooooo04gooooo0_l0000;ooooo`?o00002_ooool3o`000003ooooool0003o000001?ooooo
0_l0000;oooooaGo000000?oooooo`000?l00000@?ooool2o`0000?ooooo0_l00002ooooo`;o0000
FOooool001cooooo00?o0000ooooooooool0Boooool4o`0000Gooooo0_l00004ooooo`?o00002_oo
ool5o`0000?ooooo1?l00007ooooo`;o00001?ooool2o`0000;ooooo0_l00005oooooaOo000000?o
ooooo`000?l000001?l0000looooo`;o00000_ooool2o`0000?ooooo0_l0001Iooooo`007?ooool0
0ol0003oooooooooo`1;ooooo`;o00001oooool2o`0000?ooooo1?l0000:ooooo`Oo000000?ooooo
o`000?l000000_l00007ooooo`;o00001?ooool2o`0000;ooooo0_l00003ooooob3o00000_ooool2
o`0000Gooooo0_l000000ooooooo0000o`00000booooo`;o0000G_ooool001cooooo00?o0000oooo
ooooool0<oooool2o`0002?ooooo0ol0000>ooooo`;o000000?oooooo`000?l000003?ooool3o`00
00;ooooo0ol00007oooooa[o000000?oooooo`000?l000001ol00005ooooo`;o000000?oooooo`00
0?l000000_l00007ooooo`;o0000;Oooool2o`0005Sooooo000Looooo`03o`000?oooooooooo03?o
oooo0_l0000Sooooo`;o00002?ooool2o`0000Gooooo0_l000000ooooooo0000o`000009ooooo`;o
00000_ooool2o`0000;ooooo0ol00009oooooaco000000?oooooo`000?l000000_l0000;ooooo`;o
00001oooool2o`0002gooooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`1Hooooo`?o0000
1oooool3o`0000;ooooo0ol0000<ooooo`?o00000oooool2o`0000kooooo6_l00002ooooo`;o0000
3_ooool2o`0003Cooooo0ol0001Hooooo`007?ooool00ol0003oooooooooo`1Aooooo`?o00001?oo
ool3o`0000Sooooo0_l00002ooooo`?o00000_ooool2o`0000Sooooo0_l00004ooooo`;o00003?oo
oolKo`00013ooooo0_l000000ooooooo0000o`000006ooooo`;o00006oooool2o`0000oooooo0ol0
001Hooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00001_ooool5o`0000;ooooo0_l0000B
ooooo`;o00002?ooool2o`0001;ooooo1ol000000ooooooo0000o`00000Bo`0000Kooooo0_l00007
ooooo`;o000000?oooooo`000?l000001?ooool4o`0001_ooooo1?l0000<ooooo`;o00004_ooool2
o`0004Kooooo000Looooo`03o`000?oooooooooo04Wooooo0_l00006ooooo`Go00001?ooool2o`00
00kooooo0_l0000:ooooo`;o00003Oooool2o`000003ooooool0003o000000;o000000?oooooo`00
0?l000005ol00006ooooo`;o00002_ooool2o`0000Cooooo0_l0000Oooooo`;o00003?ooool4o`00
013ooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o00008_ooool4o`0000Go
oooo0_l00003ooooo`;o00002Oooool2o`0000?ooooo0_l00006ooooo`;o00003?ooool2o`000004
ooooool0003o0000oooooaWo00001Oooool2o`0004Cooooo0_l000000ooooooo0000o`00001Eoooo
o`007?ooool00ol0003oooooooooo`0]ooooo`;o0000<?ooool2o`0000Gooooo0_l00007ooooo`;o
000000?oooooo`000?l000000oooool3o`00017ooooo1_l000000ooooooo0000o`00000Ao`0000Co
oooo0_l0000/ooooo`;o00004Oooool2o`0000Cooooo1?l0001Eooooo`007?ooool00ol0003ooooo
ooooo`18ooooo`;o00000oooool2o`00013ooooo1_l000000ooooooo0000o`000004ooooo`;o0000
0_ooool4o`0000Cooooo0_l00007ooooo`;o00001ooooolLo`0000?ooooo0_l0000/ooooo`;o0000
3_ooool2o`000003ooooool0003o000000Cooooo0_l0001Gooooo`007?ooool2o`0004Wooooo0_l0
0003ooooo`;o00004?ooool6o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l0
000:ooooo`;o00000_ooool4o`000003ooooool0003o000001co000000?oooooo`000?l00000??oo
ool2o`0000Wooooo0_l0000@ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0COooool2
o`0001?ooooo0_l000000ooooooo0000o`000003o`0000_ooooo0_l00005ooooo`;o00000_ooool2
o`0000?ooooo1?l00002ooooo`go000000?oooooo`000?l000003Ol0000Gooooo`;o00007Oooool2
o`00013ooooo1?l0000@ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0B_ooool2o`00
0003ooooool0003o000000;o00000oooool2o`0000oooooo0_l000000ooooooo0000o`000005oooo
o`Go00002?ooool2o`0000;ooooo0_l00003ooooo`Co00000ooooolGo`0000;ooooo0_l00002oooo
o`Co00004_ooool2o`0000Kooooo0_l0000=ooooo`Co00001?ooool2o`00013ooooo0_l0001Goooo
o`007?ooool00ol0003oooooooooo`1:ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o
00003oooool2o`0000Gooooo0_l000000ooooooo0000o`000003o`0000Cooooo1?l00006ooooo`;o
00002Oooool5o`000003ooooool0003o000000ko00000_ooool2o`0000;ooooo1?l0000<ooooo`?o
00002oooool2o`0000;ooooo0_l00009ooooo`Co00001?ooool2o`0000;ooooo0ol00004ooooo`Ko
00001Oooool2o`00013ooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0Yooooo`;o0000
8oooool3o`000003ooooool0003o000000Gooooo0_l0000:ooooo`;o00001Oooool2o`0000?ooooo
0_l000000ooooooo0000o`000002ooooo`Go00001Oooool2o`0000;ooooo0_l00003ooooo`Oo0000
00?oooooo`000?l000002ol000000ooooooo0000o`000003ooooo`;o00001?ooool2o`0000_ooooo
0ol00008ooooo`;o00001Oooool2o`0000Cooooo0_l0000?ooooo`?o00000oooool7o`0000Cooooo
0ol0000@ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0:Oooool2o`0001Sooooo0_l0
000=ooooo`;o00001Oooool2o`0000Sooooo1?l0000=ooooo`;o00001?ooool3o`0000Wooooo0ol0
0002ooooo`;o00000oooool:o`0000;ooooo1?l00006ooooo`;o00001?ooool2o`0000Gooooo0ol0
000;ooooo`Go00002oooool2o`0000cooooo0_l000000ooooooo0000o`000002o`0000;ooooo1?l0
0007ooooo`;o00005oooool2o`0003_ooooo000Looooo`03o`000?oooooooooo04;ooooo0ol0000=
ooooo`;o00001_ooool2o`0000Gooooo1_l0000<ooooo`;o00002Oooool2o`0000Kooooo0ol00000
0ooooooo0000o`000003o`0000;ooooo2Ol000001?oooooo0000o`000?l0000>ooooo`;o00001Ooo
ool3o`0000Oooooo0_l00002ooooo`?o00000_ooool4o`0000Oooooo0_l00002ooooo`;o00002?oo
ool2o`0000?ooooo1Ol000000ooooooo0000o`00000Kooooo`;o00000oooool2o`0003_ooooo000L
ooooo`03o`000?oooooooooo04;ooooo0_l00007ooooo`;o00001Oooool2o`0000?ooooo0_l00000
0ooooooo0000o`000002o`0000?ooooo0_l00006ooooo`?o00001oooool2o`000003ooooool0003o
000000Cooooo1?l00002ooooo`?o000000?oooooo`000?l000001?l000000ooooooo0000o`00000;
o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000007ooooo`;o00003oooool3
o`000003ooooool0003o000000?ooooo1Ol00006ooooo`;o00000_ooool2o`0000?ooooo0ol00002
ooooo`;o00001?ooool4o`0000Gooooo0_l00002ooooo`?o00000oooool2o`0000gooooo0_l00010
ooooo`007?ooool00ol0003oooooooooo`19ooooo`Co00002_ooool2o`0000;ooooo0ol00004oooo
o`;o00001Oooool3o`0000[ooooo0_l00002ooooo`Go00000oooool3o`0000?ooooo0_l00004oooo
o`Co00000_ooool4o`000003ooooool0003o000000;o00000oooool2o`000003ooooool0003o0000
00[ooooo0_l000000ooooooo0000o`00000:ooooo`;o00001Oooool2o`0000;ooooo0_l00003oooo
o`;o00002_ooool3o`0000;ooooo0ol00004ooooo`?o00001Oooool2o`0000;ooooo0ol00003oooo
o`;o0000Coooool001cooooo00?o0000ooooooooool0BOooool2o`000003ooooool0003o000000Go
oooo0_l000000ooooooo0000o`000003ooooo`?o00001?ooool2o`0000Gooooo0ol0000>ooooo`;o
000000?oooooo`000?l000000oooool3o`000003ooooool0003o000000Cooooo0_l00002ooooo`?o
000000?oooooo`000?l000002Ol00005ooooo`;o00002Oooool2o`000003ooooool0003o000000[o
oooo0_l000000ooooooo0000o`000002ooooo`;o00001oooool2o`0000Sooooo1Ol00003ooooo`;o
00001Oooool2o`0000Wooooo1?l00004ooooo`;o0000COooool001cooooo00?o0000ooooooooool0
BOooool2o`000004ooooool0003o0000o`0000Cooooo1Ol00004ooooo`;o00002oooool3o`0000co
oooo0_l00002ooooo`?o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000002o`00
00;ooooo1?l000000ooooooo0000o`000002ooooo`Ko00000_ooool2o`0000Gooooo1?l00007oooo
o`;o000000?oooooo`000?l000001_ooool2o`0000Gooooo0_l0000;ooooo`;o00002?ooool4o`00
01Kooooo1?l00004ooooo`;o0000COooool001cooooo00?o0000ooooooooool0BOooool2o`0000;o
oooo0_l00006ooooo`;o00001oooool2o`0000Wooooo1?l00006ooooo`;o00000oooool7o`000003
ooooool0003o000000?ooooo0_l000001?oooooo0000o`000?ooool2o`000004ooooool0003o0000
ooooo`;o000000?oooooo`000?l000001Ol00003ooooo`;o00001?ooool4o`0000Sooooo1?l00000
0ooooooo0000o`000003ooooo`;o00004?ooool4o`0000Gooooo0ol00009ooooo`?o00001Oooool2
o`0005kooooo000Looooo`03o`000?oooooooooo03kooooo0_l0000Nooooo`;o00002Oooool4o`00
00?ooooo0_l000000ooooooo0000o`000003ooooo`Co00002Oooool2o`0000Cooooo0_l000000ooo
oooo0000o`000004ooooo`;o00002?ooool3o`0000?ooooo0ol00006ooooo`Go00000oooool2o`00
01Gooooo0_l00007ooooo`?o00001?ooool2o`0000?ooooo0ol00005ooooo`?o00003_ooool2o`00
04gooooo000Looooo`03o`000?oooooooooo03Wooooo0_l00003ooooo`;o00005_ooool2o`0000Go
oooo1?l00009ooooo`;o00001?ooool2o`0000?ooooo0_l000000ooooooo0000o`00000;ooooo`;o
00000oooool4o`0000_ooooo0_l00004ooooo`;o00003?ooool4o`0002_ooooo0_l0000;ooooo`?o
00003_ooool2o`0004gooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0iooooo`?o00005_ooool2o`00
00;ooooo0_l00005ooooo`Co00002Oooool2o`000003ooooool0003o000000;o00001?ooool2o`00
0003ooooool0003o000000;ooooo0ol00003ooooo`;o000000?oooooo`000?l000000oooool4o`00
00_ooooo0_l00006ooooo`;o00002oooool2o`0000_ooooo0_l0000/ooooo`?o00003oooool2o`00
04cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0>_ooool2o`000003ooooool0003o000001?ooooo0_l00005
ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000007ooooo`Co00001oooool2
o`000003ooooool0003o000000;o00000oooool2o`000003ooooool0003o000000;ooooo0_l0000F
ooooo`?o00001?ooool2o`0000Cooooo0_l0000;ooooo`Oo00002Oooool2o`0000Wooooo0_l00007
ooooo`;o00001oooool5o`0000kooooo0_l0001<ooooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`09ooooo`Go00001_ooool00ol0003oooooooooo`0mooooo`;o00006_ooool3o`00
0003ooooool0003o000000;ooooo0_l000000ooooooo0000o`00000Booooo`Go000000Coooooo`00
0?l0003o00001?ooool2o`0000;ooooo0_l00008ooooo`;o00003Oooool2o`0000Cooooo1?l00004
ooooo`;o00002oooool8o`0000Kooooo0_l00009ooooo`;o00001oooool2o`0000;ooooo0_l00000
0ooooooo0000o`000002o`000003ooooool0003o000005cooooo00000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`0004_ooooo0_l0000<
ooooo`?o00002oooool2o`0000;ooooo0ol00009ooooo`Ko000000?oooooo`000?l000000_l0000A
ooooo`;o00002oooool3o`0000Oooooo0_l000001?oooooo0000o`000?ooool2o`0000Wooooo0ol0
0003ooooo`Co00001_ooool2o`0000?ooooo0_l0000?ooooo`Co000000?oooooo`000?l000001?oo
ool4o`0000cooooo0_l0001;ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09
ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool08Oooool2o`0001Sooooo0_l0
000>ooooo`;o00004?ooool4o`000003ooooool0003o000000?ooooo0_l00002ooooo`?o00002Ooo
ool3o`000003ooooool0003o000000;ooooo1?l000000ooooooo0000o`000004ooooo`Go00000_oo
ool2o`0000_ooooo1Ol00004ooooo`?o00000oooool3o`0000Gooooo0_l00004ooooo`?o00000ooo
ool2o`000003ooooool0003o000000Gooooo0_l00003ooooo`;o00001?ooool2o`0000Sooooo0ol0
0006ooooo`;o000000?oooooo`000?l000000_l0000<ooooo`;o00001oooool2o`0004;ooooo0000
0ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oMgMgolc<c?l000001oooool0
0ol0003oooooooooo`0Qooooo`;o00006?ooool2o`0000gooooo0_l00002ooooo`;o00003Oooool4
o`000003ooooool0003o000000;o00001oooool2o`0000Sooooo0_l00002ooooo`;o00001?ooool2
o`000004ooooool0003o0000o`0000?ooooo1Ol00002ooooo`Ko00000oooool2o`0000;ooooo0_l0
0007ooooo`?o00001?ooool2o`0000Cooooo0ol00004ooooo`Ko00000_ooool9o`0000Gooooo0_l0
0003ooooo`;o00002?ooool2o`0000Oooooo0_l0000=ooooo`;o00002oooool2o`0000Cooooo0_l0
000looooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo
00?o0000ooooooooool0@oooool3o`0000Cooooo0_l00002ooooo`;o00001?ooool2o`000003oooo
ool0003o000000Wooooo1?l00007ooooo`;o00003?ooool2o`0000;ooooo0_l00004ooooo`;o0000
3?ooool4o`000003ooooool0003o000000;o00002Oooool2o`0000;ooooo0_l00009ooooo`Co0000
0ooooolAo`0000Gooooo1_l00002ooooo`;o00007Oooool2o`0000_ooooo0_l00004ooooo`;o0000
??ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03
o`000?oooooooooo03oooooo0_l00002ooooo`?o00003_ooool2o`000003ooooool0003o000001Wo
oooo0_l00007ooooo`;o00000_ooool2o`0001Oooooo1?l00005ooooo`;o00000_ooool2o`0000;o
oooo0_l00007ooooo`;o00000_ooool2o`000003ooooool0003o000000Co000000?oooooo`000?l0
00002Ol00005ooooo`Oo00000_ooool2o`0000Kooooo0_l0000Aooooo`;o00001oooool2o`0000Oo
oooo0_l00007ooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0?Oooool4o`0000Kooooo
0_l0000;ooooo`Go00001oooool2o`000003ooooool0003o000000Gooooo0_l00006ooooo`;o0000
0_ooool2o`0000?ooooo0ol00002ooooo`Go00000_ooool2o`0001Sooooo1?l0000=ooooo`;o0000
1Oooool2o`000003ooooool0003o000000?ooooo2Ol00005ooooo`?o00001?ooool2o`0000?ooooo
0_l00004ooooo`;o00004Oooool2o`0000Oooooo0_l00007ooooo`;o00000oooool2o`0000;ooooo
0_l0000hooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00001?ooool2o`0000;ooooo0_l0
0004ooooo`Co00000oooool4o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l000001Ooo
ool2o`0000Kooooo0_l00002ooooo`?o00000oooool2o`0000;ooooo1Ol00002ooooo`;o00003_oo
ool2o`0000[ooooo0_l0000=ooooo`;o00001oooool2o`0000Cooooo0_l000000ooooooo0000o`00
0005o`000004ooooool0003o0000ooooo`;o00001Oooool2o`0000?ooooo0_l0000Dooooo`;o0000
4_ooool2o`0000Cooooo0_l0000looooo`007?ooool00ol0003oooooooooo`13ooooo`;o00000_oo
ool<o`0000?ooooo0_l00002ooooo`;o00001_ooool2o`0001;ooooo1ol0000Jooooo`Co00006?oo
ool2o`0000;ooooo0_l00002ooooo`;o00001?ooool2o`000003ooooool0003o000000Go000000?o
ooooo`000?l000002_l00002ooooo`Co00004oooool2o`0001;ooooo0_l00005ooooo`;o0000>ooo
ool001cooooo00?o0000ooooooooool07?ooool2o`0001;ooooo0_l0000Fooooo`co00000oooool2
o`0000Wooooo0_l00006ooooo`;o00003Oooool4o`0000Kooooo0_l000000ooooooo0000o`000004
ooooo`;o00002oooool2o`0000?ooooo0_l00009ooooo`;o00000_ooool2o`0000?ooooo0ol00000
1?oooooo0000o`000?l00002ooooo`Ko000000?oooooo`000?l000001ol00003ooooo`So00001?oo
ool4o`0002kooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0Looooo`;o00004_ooool2
o`0000kooooo0_l000000ooooooo0000o`000002ooooo`ko00000_ooool2o`0000cooooo1?l00000
0ooooooo0000o`000006ooooo`;o00003oooool2o`000003ooooool0003o000000Cooooo0_l0000@
ooooo`;o00000oooool2o`0000Cooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00002
ooooo`Oo000000?oooooo`000?l000001_l000000ooooooo0000o`000002ooooo`Oo00001?ooool4
o`0000?ooooo0_l0000Kooooo`;o0000BOooool001cooooo00?o0000ooooooooool0>oooool4o`00
0003ooooool0003o000000?o00000_ooool>o`0000Gooooo0_l00009ooooo`Go00001oooool3o`00
00Gooooo0_l0000;ooooo`;o00006oooool2o`00017ooooo0ol000000ooooooo0000o`00000>o`00
0003ooooool0003o000000Wo00002?ooool5o`0000Cooooo0_l0000@ooooo`;o00000oooool2o`00
04Wooooo000Looooo`03o`000?oooooooooo03_ooooo1Ol000001?oooooo0000o`000?l00003oooo
oa3o00000oooool2o`0000Gooooo0_l00005ooooo`;o000000?oooooo`000?l000001?ooool2o`00
00Kooooo0_l00009ooooo`Co00009_ooool2o`0000Gooooo1?l00002oooooaco00001oooool4o`00
00Cooooo1?l0000?ooooo`;o00000oooool2o`0000Sooooo0_l0000oooooo`007?ooool00ol0003o
ooooooooo`0nooooo`;o00000oooool2o`0000;ooooo1ol000000ooooooo0000o`000009o`0000Oo
oooo1?l00006ooooo`;o00005oooool5o`0001kooooo0_l00005ooooo`;o00000_ooool6o`0000?o
oooo0_l00002oooooaco00002oooool4o`0000gooooo0ol0000>ooooo`;o00000oooool2o`0003[o
oooo000Looooo`03o`000?oooooooooo04?ooooo0_l00002ooooo`[o000000?oooooo`000?l00000
1_l00009ooooo`;o00000_ooool2o`0000[ooooo0_l0000Booooo`;o00005oooool2o`0000?ooooo
1?l00009ooooo`Oo00000_ooool3o`000003ooooool0003o000001[o00001_ooool2o`0000Cooooo
0_l0000>ooooo`?o00004oooool2o`0003[ooooo000Looooo`03o`000?oooooooooo03gooooo0_l0
0009oooooa3o00003oooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`00
0002ooooo`;o00003_ooool2o`0001Oooooo1?l000000ooooooo0000o`000002o`0000[ooooo0ol0
00001?oooooo0000o`000?oooolQo`0000;ooooo0_l00002ooooo`;o00001?ooool2o`0001Kooooo
0_l00018ooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00001ooooolBo`0000Wooooo0_l0
0007ooooo`;o00001?ooool5o`0000;ooooo0_l00009ooooo`;o00000oooool4o`0001Oooooo0_l0
00001?oooooo0000o`000?l00009ooooobWo00000oooool2o`0000Cooooo0_l0000@ooooo`;o0000
2?ooool2o`0004Sooooo000Looooo`;o0000Aoooool2o`000003ooooool0003o000000_o00002ooo
ool2o`0000Oooooo0_l00002ooooo`Ko000000?oooooo`000?l000002oooool3o`0000Cooooo0_l0
0009ooooo`;o00000_ooool2o`0000_ooooo0_l0000:ooooob[o00001?ooool2o`0000;ooooo0_l0
0003ooooo`;o000000Coooooo`000?l0003ooooo0_l00005ooooo`?o0000DOooool001cooooo00?o
0000ooooooooool0Boooool9o`0000;ooooo0_l0000@ooooo`Co00000_ooool4o`0000?ooooo0_l0
000<ooooo`;o00002Oooool2o`0000Cooooo0_l00002ooooo`;o00001?ooool4o`0000[ooooo0_l0
0003ooooo`Go000000?oooooo`000?l000009?l00002ooooo`;o00000oooool6o`000004ooooool0
003o0000ooooo`;o000000?oooooo`000?l000000oooool2o`00057ooooo000Looooo`03o`000?oo
oooooooo01Wooooo0_l0000Tooooo`;o000000?oooooo`000?l000001oooool9o`0000;ooooo0_l0
000@ooooo`;o00008oooool3o`0000kooooo1?l0000:ooooo`;o000000?oooooo`000?l000001?l0
0002ooooobWo00001?ooool4o`0000Wooooo0_l0000?ooooo`;o0000AOooool001cooooo00?o0000
ooooooooool06Oooool2o`0002?ooooo0ol000000ooooooo0000o`000008ooooo`;o000000?ooooo
o`000?l000000ol00002ooooo`;o00004?ooool2o`0000gooooo0_l000000ooooooo0000o`000002
o`0000gooooo1?l0000>ooooo`Co00002_ooool2o`0000;ooooo<Ol00003ooooo`;o00003?ooool2
o`000003ooooool0003o000000Sooooo0_l00002ooooo`;o00000_ooool2o`0000Gooooo0_l0000j
ooooo`007?ooool00ol0003oooooooooo`0nooooo`?o00003Oooool3o`0000?ooooo1?l00006oooo
o`;o00003_ooool2o`0000?ooooo1_l000000ooooooo0000o`000002o`0000gooooo0_l0000@oooo
o`;o00003?ooool2o`0000Kooooo;Ol00003ooooo`;o00003?ooool2o`000004ooooool0003o0000
o`0000Oooooo0_l00006ooooo`;o00001Oooool2o`0003[ooooo000Looooo`03o`000?oooooooooo
03Kooooo0_l00006ooooo`?o00003Oooool2o`0000Cooooo0_l00003ooooo`;o00000oooool2o`00
00cooooo1?l00003ooooo`Oo00006_ooool2o`0000kooooo0_l00007ooooo`;o00001?ooool2o`00
00;ooooo9_l00003ooooo`Go000000?oooooo`000?l000003Oooool2o`0000?ooooo0_l00002oooo
o`;o00001_ooool2o`00047ooooo000Looooo`03o`000?oooooooooo02_ooooo0_l00009ooooo`;o
00001?ooool4o`0001Wooooo0_l0000Aooooo`;o000000?oooooo`000?l000001_l000000ooooooo
0000o`000002ooooo`Co00002?ooool2o`0000;ooooo0ol00005ooooo`Co00002_ooool4o`0000;o
oooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00000Jo`00
0004ooooool0003o0000o`0000;ooooo0ol00005ooooo`So00000oooool3o`000003ooooool0003o
000000Wooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`0Jooooo`;o00003oooool2o`00
00_ooooo0ol000000ooooooo0000o`00000Booooo`;o00001_ooool3o`0000_ooooo0_l00007oooo
oa7o00002?ooool2o`0000;ooooo1?l00006ooooo`;o00002_ooool4o`0000;ooooo1Ol00003oooo
o`Co00000_oooolVo`0000Gooooo0_l000000ooooooo0000o`000005ooooo`?o000000?oooooo`00
0?l000002Oooool2o`000003ooooool0003o000000Wooooo0_l0000oooooo`007?ooool00ol0003o
ooooooooo`0Jooooo`;o00007?ooool4o`0001Cooooo0ol00005ooooo`?o000000Coooooo`000?l0
003ooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00000C
o`0000cooooo0ol0000>ooooo`;o00000_ooool5o`0000?ooooo0ol00003ooooo`Go000000?ooooo
o`000?l000009?l00002ooooo`;o000000?oooooo`000?l000001?l00007ooooo`;o00002_ooool2
o`000003ooooool0003o000000Sooooo0ol0000oooooo`007?ooool00ol0003oooooooooo`0hoooo
o`Co00004Oooool3o`000003ooooool0003o000000Wooooo0_l000000ooooooo0000o`000002oooo
o`;o00001?ooool>o`000004ooooool0003o0000ooooo`Ko00000oooool2o`0000Cooooo0_l00000
0ooooooo0000o`000002o`0000gooooo0_l00002ooooo`;o000000?oooooo`000?l000000oooool2
o`0000Cooooo1Ol000000ooooooo0000o`00000_o`0000Oooooo0_l0000=ooooo`;o00002?ooool2
o`00043ooooo000Looooo`03o`000?oooooooooo04Sooooo0_l00003ooooo`?o00006OoooolGo`00
00?ooooo0ol00004ooooo`;o00000_ooool5o`0000Gooooo1?l0000Dooooo`Ko00000oooool6o`00
0003ooooool0003o000001co00000_ooool3o`0000Kooooo1?l00003ooooo`?o00002?ooool4o`00
0003ooooool0003o000000Sooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0Jooooo`;o
00008Oooool2o`0000Wooooo1?l0000Dooooo`;o00001oooool2o`000003ooooool0003o000001;o
00000oooool2o`0000[ooooo1?l00005ooooo`Co00006?ooool2o`0000?ooooo8ol00002ooooo`;o
00002Oooool4o`0000?ooooo0ol00008ooooo`?o00000_ooool2o`0000Sooooo0_l0000mooooo`00
7?ooool00ol0003oooooooooo`0Jooooo`;o00008Oooool4o`0000Wooooo0_l0000Dooooo`;o0000
1oooool2o`000003ooooool0003o000001Co00006?ooool2o`0000Gooooo0_l00008ooooo`;o0000
00?oooooo`000?l000001Oooool2o`0000Cooooo8Ol000001?oooooo0000o`000?l0000Gooooo`So
00000_ooool3o`0000Gooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0oooooo`;o0000
:?oooolIo`0000kooooo0_l00003ooooo`;o00002_ooool2o`0000Sooooo0_l000000ooooooo0000
o`000005oooooa[o00000oooool8o`0000?ooooo0_l0000?ooooo`;o00001oooool5o`000003oooo
ool0003o000000;ooooo0ol00005ooooo`;o00000_ooool2o`0003[ooooo000Looooo`03o`000?oo
oooooooo05Oooooo0_l0000?oooooa[o00003_ooool2o`000003ooooool0003o000000?o00000_oo
ool2o`0000Wooooo0_l00008ooooo`;o00001?oooolUo`0001Cooooo0_l00002ooooo`;o00001?oo
ool2o`0000Kooooo0_l0000;ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0<_ooool2
o`0000cooooo0_l0000@ooooo`;o00000oooool2o`0000Gooooo0_l00008oooooaWo00004_ooool5
o`000004ooooool0003o0000o`0000?ooooo0ol00003ooooo`;o00002?ooool2o`0000Cooooo9ol0
0006ooooo`Co00002?ooool2o`0000;ooooo0ol00003ooooo`;o00000oooool2o`000003ooooool0
003o000004Oooooo000Looooo`;o0000<Oooool4o`0000cooooo0_l0000@ooooo`;o00002_ooool4
o`0000;ooooo0_l00002oooooa[o000000?oooooo`000?l000004?ooool2o`0000;ooooo0_l00004
ooooo`Ko00004?ooool2o`0000?ooooo8_l000001?oooooo0000o`000?ooool6o`0000Gooooo0_l0
0006ooooo`Co000000?oooooo`000?l000000oooool2o`0004[ooooo000Looooo`03o`000?oooooo
oooo01[ooooo0_l0000Dooooo`;o00001oooool2o`0001;ooooo0_l0000Aooooo`;o00000_ooool2
o`0000;ooooo5ol000001?oooooo0000o`000?ooool2o`0000Oooooo0ol000000ooooooo0000o`00
0003ooooo`;o00000_ooool2o`0000Oooooo1?l00003ooooo`;o00000_ooool2o`000004ooooool0
003o0000ooooo`Ko00000_ooool5o`000003ooooool0003o000000_o00000_ooool;o`0000;ooooo
0_l000000ooooooo0000o`000003o`0000Kooooo0_l00008ooooo`;o000000?oooooo`000?l00000
0_l0001=ooooo`007?ooool00ol0003oooooooooo`0Jooooo`;o00005?ooool2o`0000Oooooo0_l0
000Aooooo`?o00005_oooolMo`0000[ooooo0ol000000ooooooo0000o`000002ooooo`?o00003?oo
ool3o`0000?ooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`Ko0000
00?oooooo`000?l000000_oooolMo`0001Oooooo0_l000001?oooooo0000o`000?l00002ooooo`;o
000000?oooooo`000?l000001_ooool2o`0003kooooo000Looooo`03o`000?oooooooooo033ooooo
0_l00002ooooo`;o00005_ooool2o`0001Oooooo1ol000000ooooooo0000o`00000Ao`000003oooo
ool0003o000000Wooooo0_l000000ooooooo0000o`000003ooooo`?o00000_ooool2o`0000Sooooo
0_l0000<ooooo`Co00000oooool8o`0000;ooooo1?l000000ooooooo0000o`00000Do`0000?ooooo
0_l0000Dooooo`;o000000Coooooo`000?l0003ooooo1?l000000ooooooo0000o`000006ooooo`Co
0000??ooool001cooooo00?o0000ooooooooool0<?ooool2o`0000;ooooo0_l0000:ooooo`;o0000
9?ooool3o`000003ooooool0003o000001Co000000?oooooo`000?l000000_l00007ooooo`;o0000
00?oooooo`000?l000001Ol00003ooooo`;o000000?oooooo`000?l000001Oooool2o`000003oooo
ool0003o000000Wooooo1?l00003ooooo`?o00000_oooolPo`0000?ooooo1?l00003ooooo`;o0000
3_ooool7o`0000;ooooo0_l00009ooooo`;o0000??ooool001cooooo00?o0000ooooooooool06Ooo
ool2o`0001gooooo0_l00006ooooo`;o00002Oooool2o`0001[ooooo6Ol00003ooooo`Co00002?oo
ool6o`0000Oooooo0_l00008ooooo`;o00000oooool2o`0000Gooooo0_l00003ooooo`Co00000_oo
oolHo`000003ooooool0003o000000Go00000oooool6o`000003ooooool0003o000000kooooo1ol0
0002ooooo`;o00000_ooool2o`0000Cooooo0_l0000?ooooo`;o0000;?ooool001cooooo00?o0000
ooooooooool06Oooool3o`0001cooooo0_l00008ooooo`;o00001oooool2o`0001cooooo2Ol00002
ooooo`co00000_ooool2o`000003ooooool0003o000000Sooooo0_l000000ooooooo0000o`00000B
ooooo`;o00000oooool2o`0000[ooooo0_l00006oooooaKo00000oooool8o`000004ooooool0003o
0000ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Kooooo1?l00002ooooo`?o00001Ooo
ool2o`0000;ooooo1?l0000?ooooo`;o0000;?ooool001cooooo00?o0000ooooooooool06_ooool2
o`0001?ooooo1?l0000?ooooo`;o00009_ooool>o`000003ooooool0003o000000Co00000oooool2
o`0000_ooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000005oooool2
o`0000Cooooo1?l00002ooooo`Co000000?oooooo`000?l000002?l000000ooooooo0000o`000005
o`000003ooooool0003o000000;o00000_ooool4o`0000Cooooo0_l000000ooooooo0000o`000005
ooooo`;o00001Oooool5o`0000;ooooo0ol00002ooooo`?o00001?ooool2o`0000Cooooo0_l0000i
ooooo`007?ooool00ol0003oooooooooo`0Jooooo`;o00004oooool4o`0002?ooooo0_l0000@oooo
oaOo00000oooool2o`0000cooooo0ol00003ooooo`So00000oooool2o`000003ooooool0003o0000
00cooooo0_l00004ooooo`Co00000_ooool3o`0000;ooooo0_l00002ooooo`Ko000000?oooooo`00
0?l000002Ol00003ooooo`?o00001Oooool5o`0000cooooo0_l00005ooooo`?o00000_ooool3o`00
0003ooooool0003o000000Oooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o
00001?ooool2o`0000cooooo0_l00002ooooo`Go000000?oooooo`000?l000003_l00002ooooo`Co
00002_ooool7o`000003ooooool0003o000000Oo00000_ooool2o`000003ooooool0003o000000;o
00002_ooool2o`0000Cooooo1Ol000000ooooooo0000o`00000Fo`0000Cooooo1?l00004ooooo`;o
000000?oooooo`000?l000000_l00006ooooo`;o00003_ooool2o`0000Cooooo0_l00012ooooo`00
7?ooool00ol0003oooooooooo`1@ooooo`;o00004_ooool2o`0000Sooooo4Ol000001?oooooo0000
o`000?l00008ooooo`[o00000_ooool2o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l0
00000ol000000ooooooo0000o`000003ooooo`?o00001?ooool5o`0000;ooooo3Ol000000ooooooo
0000o`000008o`000003ooooool0003o000000?o00001Oooool2o`0000?ooooo0_l00006ooooo`;o
00000oooool2o`0000Oooooo1?l00018ooooo`007?ooool00ol0003oooooooooo`12ooooo`;o0000
;?ooool?o`0000;ooooo0_l00008ooooo`Co000000?oooooo`000?l000001?ooool2o`0000_ooooo
1?l000001Ooooooo0000o`000?l0003ooooo00;o00000oooool4o`0000Gooooo0ol00002ooooo`;o
00000_ooool2o`000004ooooool0003o0000ooooo`?o00000_ooool4o`000003ooooool0003o0000
00;o000000?oooooo`000?l000000ol0000:ooooo`;o00002Oooool4o`0000Oooooo0_l0001:oooo
o`007?ooool00ol0003oooooooooo`12ooooo`;o00002?ooool2o`0000kooooo1?l00007ooooo`;o
00001oooool=o`0001;ooooo0ol000001?oooooo0000o`000?ooool2o`0000_ooooo1?l0000<oooo
o`;o00001_ooool2o`0000;ooooo0_l000000ooooooo0000o`000004o`0000Kooooo0_l00002oooo
o`Go000000?oooooo`000?l000000oooool2o`0000[ooooo0_l00003ooooo`;o00000_ooool2o`00
05Gooooo000Looooo`03o`000?oooooooooo043ooooo1?l00008ooooo`;o00003_ooool4o`0000Oo
oooo0_l00005ooooo`oo00003Oooool7o`0000;ooooo0_l0000?ooooo`;o00005?ooool2o`0000?o
oooo0_l000000ooooooo0000o`000005o`0000Wooooo1Ol000000ooooooo0000o`000003ooooo`;o
00002_ooool2o`0000;ooooo1ol00007ooooo`Co0000B_ooool001cooooo00?o0000ooooooooool0
?Oooool2o`000003ooooool0003o000000[ooooo0_l0000Booooo`;o00003?ooool2o`000003oooo
ool0003o000000Oo000000?oooooo`000?l000002Oooool2o`0000;ooooo2?l000000ooooooo0000
o`000002o`0000gooooo0_l00004ooooo`;o00001Oooool2o`0000Oooooo0_l00006ooooo`Oo0000
0_ooool2o`0000Gooooo1Ol0000=ooooo`;o00001oooool2o`000003ooooool0003o000000Cooooo
0_l00003ooooo`Co000000?oooooo`000?l00000Aoooool001cooooo00?o0000ooooooooool0?Ooo
ool2o`000003ooooool0003o000001Oooooo0ol00002ooooo`Co00004Oooool7o`0000cooooo0_l0
00000ooooooo0000o`000005ooooo`Wo000000?oooooo`000?l000003_ooool2o`0000Gooooo0_l0
0009ooooo`;o00000_ooool2o`000003ooooool0003o000000;o00001?ooool4o`000003ooooool0
003o000000?ooooo0_l000000ooooooo0000o`00000:ooooo`;o00001?ooool2o`000003ooooool0
003o000000Oooooo0_l00007ooooo`?o0000Aoooool001cooooo0_l0000booooo`;o00002Oooool2
o`0000;ooooo0_l0000Gooooo`?o00000_ooool2o`0000[ooooo0_l00008ooooo`Co00004Oooool2
o`000004ooooool0003o0000o`0000?ooooo1?l000001?oooooo0000o`000?ooool2o`0000Wooooo
0_l0000Eooooo`;o00000_ooool2o`0000;ooooo0_l00007ooooo`;o000000?oooooo`000?l00000
0_ooool2o`0000;ooooo0_l0000@ooooo`;o000000?oooooo`000?l000001oooool2o`0000Oooooo
0ol00002ooooo`;o000000?oooooo`000?l00000@?ooool001cooooo00?o0000ooooooooool0<Ooo
ool2o`000003ooooool0003o000000Kooooo1_l0000:ooooo`;o00003_ooool2o`0000cooooo0_l0
0005ooooo`Co00004oooool3o`000004ooooool0003o0000o`0000Gooooo0ol0000<ooooo`Co0000
4_ooool2o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`0000Sooooo1Ol00009ooooo`?o0000
2_ooool2o`0000Gooooo1?l00005ooooo`?o00001?ooool2o`000003ooooool0003o0000043ooooo
000Looooo`03o`000?oooooooooo03Cooooo0_l00007ooooo`Ko00002?ooool3o`0000Cooooo0_l0
0008ooooo`;o00001oooool2o`0000Wooooo1Ol0000Cooooo`?o00000_ooool2o`0000;ooooo1_l0
000<ooooo`;o00003_ooool2o`0000Cooooo0_l00002ooooo`;o00000_ooool2o`0000Gooooo0_l0
0007ooooo`Ko00002Oooool3o`0000Cooooo0_l000000ooooooo0000o`000002o`000003ooooool0
003o000000?ooooo1?l00005ooooo`?o00008?ooool2o`0002Oooooo000Looooo`03o`000?oooooo
oooo01[ooooo0_l0000Gooooo`?o00002?ooool2o`000003ooooool0003o000000Sooooo0_l00000
0ooooooo0000o`000002ooooo`?o00004?ooool2o`0000Wooooo0_l0000Kooooo`;o00000_ooool6
o`0000?ooooo0_l00004ooooo`;o00000oooool2o`0000?ooooo0ol00006ooooo`;o00001?ooool2
o`000003ooooool0003o000000?ooooo0_l00003ooooo`;o00002Oooool2o`000003ooooool0003o
0000017ooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000Oooooo0_l00000
0ooooooo0000o`000003o`00023ooooo0_l0000Wooooo`007?ooool00ol0003oooooooooo`0Joooo
o`;o00005oooool2o`000003ooooool0003o000000Kooooo0_l0000>ooooo`;o00000oooool2o`00
00?ooooo0_l0000=ooooo`;o00004oooool2o`000003ooooool0003o000000;ooooo0_l00007oooo
o`?o00001_ooool2o`0000?ooooo0_l00004ooooo`;o00000oooool2o`0000?ooooo0ol00006oooo
o`;o00001?ooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o00003?ooool2o`00
01Cooooo0_l000000ooooooo0000o`000009ooooo`;o000000?oooooo`000?l000000ol00004oooo
o`;o00006?ooool2o`0002Wooooo000Looooo`03o`000?oooooooooo03Kooooo0_l00006ooooo`;o
00006?ooool2o`0000gooooo0_l0000=ooooo`;o000000Coooooo`000?l0003ooooo0_l000001Ooo
oooo0000o`000?l0003ooooo00;o00001oooool2o`0000Oooooo0_l000000ooooooo0000o`000006
ooooo`;o00004Oooool2o`0000_ooooo0_l00003ooooo`;o00003Oooool2o`0000Gooooo0ol0000?
ooooo`;o00002Oooool2o`0000;ooooo0_l00006ooooo`;o00006?ooool2o`0002Wooooo000Loooo
o`03o`000?oooooooooo03_ooooo0_l000000ooooooo0000o`00000fooooo`;o000000?oooooo`00
0?l000001?ooool3o`0000Sooooo0_l0000<ooooo`;o00001Oooool2o`0001;ooooo0_l0000@oooo
o`Co00000oooool2o`0000gooooo0ol000000ooooooo0000o`00000Gooooo`;o00000_ooool2o`00
04_ooooo000Looooo`03o`000?oooooooooo033ooooo0_l00005ooooo`;o00000_ooool2o`0000Co
oooo0_l0000<ooooo`;o0000;oooool2o`0000Sooooo0_l0000:ooooo`;o00001oooool3o`0000?o
oooo0_l0000<ooooo`;o00003Oooool2o`000003ooooool0003o000000;o00000_ooool3o`00017o
oooo0_l00002ooooo`;o00005Oooool2o`0000gooooo0_l0000nooooo`007?ooool00ol0003ooooo
ooooo`0`ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Sooooo0_l0000<ooooo`;o0000
3?ooool3o`0000kooooo0_l00002ooooo`Co00001oooool2o`00017ooooo0_l00004ooooo`Co0000
1_ooool3o`0000;ooooo0_l00004ooooo`;o00000_ooool2o`00017ooooo0_l00004ooooo`Go0000
0_ooool2o`0000Gooooo0_l00006ooooo`Co000000?oooooo`000?l000004?ooool8o`0000cooooo
0_l0000nooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o000000?oooooo`000?l000001?oo
ool2o`0002;ooooo0ol0000>ooooo`;o000000?oooooo`000?l000000ol00007ooooo`;o00000ooo
ool2o`0000[ooooo1Ol00005ooooo`;o00001oooool2o`0000Sooooo0_l00002ooooo`;o00005?oo
ool2o`000003ooooool0003o000000;o00000oooool2o`0000Gooooo0_l000001?oooooo0000o`00
0?ooool8o`0000Oooooo0_l00008ooooo`Go000000Coooooo`000?l0003o0000Boooool001cooooo
00?o0000ooooooooool0=?ooool7o`0003;ooooo0_l00002ooooo`;o00003?ooool5o`0000;ooooo
0_l00006ooooo`;o000000?oooooo`000?l000001Oooool4o`0000Oooooo0_l0000?ooooo`Co0000
2_ooool2o`000003ooooool0003o000000;o00003oooool6o`0000Cooooo0_l00007ooooo`;o0000
1Oooool3o`0000Cooooo1Ol0001;ooooo`007?ooool00ol0003oooooooooo`0dooooo`Ko00001_oo
ool2o`0000Wooooo0_l0000Cooooo`;o00002oooool2o`00013ooooo1?l00003ooooo`;o00001ooo
ool2o`0000Sooooo0ol00004ooooo`;o000000?oooooo`000?l000002_ooool4o`000003ooooool0
003o000000;o00000oooool2o`0000Gooooo0_l00003ooooo`;o00003oooool5o`0001?ooooo1Ol0
0004ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0;oooool2o`0000gooooo1?l00009
ooooo`;o00004oooool2o`0001Oooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l00006
ooooo`;o00000_ooool4o`0000?ooooo0_l00008ooooo`;o00002oooool6o`0000;ooooo0_l00004
ooooo`;o00006Oooool2o`000003ooooool0003o000000;o00001?ooool2o`0000;ooooo0_l00005
ooooo`;o00000_ooool5o`0000Oooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`0_oooo
o`;o00001Oooool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`00000foooo
o`Oo000000?oooooo`000?l000000_l00006ooooo`;o00001?ooool2o`0000?ooooo0_l0000Eoooo
o`;o00000oooool2o`0000kooooo0_l0000Booooo`;o00000oooool2o`0000Cooooo0_l00002oooo
o`;o00001Oooool2o`0000?ooooo1?l00007ooooo`;o00006oooool2o`0002kooooo00001_oooooo
k^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_oo
ool00ol0003oooooooooo`0fooooo`;o000000?oooooo`000?l000000ol00003ooooo`;o00002Ooo
ool2o`0002;ooooo0_l00009ooooo`Ko00000_ooool2o`0000;ooooo0_l0000=ooooo`;o00001_oo
ool2o`0000_ooooo0_l00005ooooo`;o00001Oooool2o`0000?ooooo0_l00002ooooo`?o00008?oo
ool2o`0000Cooooo0_l000000ooooooo0000o`000004o`0000Sooooo0ol0000Jooooo`;o0000;_oo
ool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMgMooooooo
V9RHob4Q8@06ooooo`03o`000?oooooooooo03?ooooo0_l00006ooooo`?o00003_ooool2o`00027o
oooo0ol0000;ooooo`So00000_ooool2o`0000gooooo0_l00006ooooo`;o00002oooool2o`0000co
oooo1?l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Go
oooo0_l0000Booooo`Go000000?oooooo`000?l000000ol00009ooooo`?o00001_ooool4o`0000[o
oooo0_l0000dooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`0cooooo`;o00001_ooool3o`0000Oo
oooo0_l0000Fooooo`;o00004?ooool2o`0000Wooooo3Ol0000:ooooo`;o00002?ooool2o`000003
ooooool0003o000000;o00001_ooool2o`0000gooooo1_l00009ooooo`;o00001Oooool2o`000003
ooooool0003o000000;ooooo0_l0000Aooooo`Ko00006?ooool4o`0000[ooooo0_l0000dooooo`00
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ
8B401_ooool3o`0003cooooo0_l00007ooooo`;o00005_ooool2o`0001_ooooo3Ol00004ooooo`;o
00001?ooool2o`0000Sooooo0_l000000ooooooo0000o`000006o`0000;ooooo0_l00002ooooo`;o
00002Oooool3o`0000cooooo0_l00008ooooo`?o00005?ooool4o`0000;ooooo0_l00002ooooo`;o
00002oooool3o`0000Cooooo0_l00012ooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooo
ooooo`09ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0hooooo`Ko
00004_ooool2o`0000?ooooo0_l0000Mooooo`;o00001_ooool<o`0000;ooooo0ol00008ooooo`;o
00001oooool2o`0000;ooooo1?l00006ooooo`;o00002_ooool2o`0000[ooooo1?l00009ooooo`;o
00001Oooool2o`0000[ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00002ooooo`;o
00002oooool3o`0000;ooooo1?l00012ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooo
ooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0>?ooool6o`0001;ooooo
0_l00003ooooo`?o00001?ooool2o`0001Kooooo0_l00004ooooo`oo000000?oooooo`000?l00000
1?ooool2o`0000?ooooo0_l0000<ooooo`;o00003_ooool2o`0000?ooooo1?l00008ooooo`;o0000
4_ooool4o`0000Sooooo0_l000000ooooooo0000o`000004ooooo`Co00000oooool2o`0000gooooo
0_l00014ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00So
oooo00?o0000ooooooooool0>?ooool2o`0001Gooooo0_l00003ooooo`Co00001?ooool2o`000003
ooooool0003o000001;ooooo0_l00003oooooa;o00001_ooool2o`0000oooooo0_l00008ooooo`;o
00001_ooool2o`0000?ooooo1?l00002ooooo`;o00004oooool2o`000003ooooool0003o000000;o
oooo0_l00007ooooo`;o00002_ooool2o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`?o
0000BOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106
ooooo`03o`000?oooooooooo04Sooooo0_l00005ooooo`;o00000oooool2o`0000Wooooo0_l0000B
ooooo`;o00000oooool2o`000003ooooool0003o000000oo00005Oooool2o`0000Cooooo0_l00002
ooooo`?o00004?ooool2o`0001?ooooo1Ol0000;ooooo`;o00001oooool4o`0000;ooooo0_l00003
ooooo`;o00001?ooool3o`0000oooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0foooo
o`;o00003Oooool2o`000003ooooool0003o000000;o00002oooool2o`0002;ooooo4_l0000Aoooo
o`;o00001_ooool3o`0000?ooooo0_l0000Cooooo`Go00003_ooool2o`0000;ooooo0_l00007oooo
o`Co00001oooool8o`000003ooooool0003o000000;ooooo0_l0000Dooooo`;o00000_ooool2o`00
03Cooooo000Looooo`03o`000?oooooooooo03Kooooo1Ol0000:ooooo`;o000000?oooooo`000?l0
00000_l0000;ooooo`;o00008OoooolEo`0000oooooo0_l00006ooooo`;o00006Oooool7o`00013o
oooo0ol00006ooooo`Co00000_ooool2o`0000Kooooo1?l00002ooooo`;o00000_ooool2o`0001So
oooo0_l0000dooooo`007?ooool00ol0003oooooooooo`0hooooo`?o00008?ooool2o`0001Wooooo
0_l000000ooooooo0000o`00000Do`0001Oooooo0_l0000Dooooo`Co00001_ooool2o`00013ooooo
0ol0000<ooooo`;o00004?ooool3o`0004gooooo000Looooo`03o`000?oooooooooo03Wooooo0_l0
000Pooooo`;o00006Oooool2o`000003ooooool0003o000001Co00005oooool2o`0000;ooooo0_l0
000@ooooo`Co00001Oooool2o`0000;ooooo0_l0000<ooooo`;o00001Oooool3o`0000?ooooo0_l0
0005ooooo`;o00003Oooool2o`0000Wooooo1?l00010ooooo`007?ooool00ol0003oooooooooo`0i
ooooo`;o0000?OoooolGo`000003ooooool0003o000000oooooo0_l00007ooooo`;o00002oooool2
o`0000;ooooo0ol00002ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00003?ooool2
o`0000Gooooo0ol00003ooooo`;o00000oooool4o`0001Sooooo1?l00007ooooo`;o0000=oooool0
01cooooo00?o0000ooooooooool0M_oooolIo`000003ooooool0003o000000oooooo0_l000000ooo
oooo0000o`00000Aooooo`So000000?oooooo`000?l000000ol0000:ooooo`;o00006?ooool2o`00
00[ooooo0_l00006ooooo`;o00004Oooool2o`0003Oooooo000Looooo`03o`000?oooooooooo04[o
oooo0ol0000XoooooaWo00000_ooool2o`00017ooooo1?l0000Booooo`_o00002oooool2o`0000Go
oooo0_l0000<ooooo`;o00001oooool2o`000003ooooool0003o000000?ooooo0_l00006ooooo`;o
0000B_ooool001cooooo00?o0000ooooooooool0>oooool3o`0000cooooo0ol0000Xoooooa[o0000
00?oooooo`000?l000004?ooool5o`0000?ooooo0_l0000=ooooo`So000000Coooooo`000?l0003o
oooo2Ol00005ooooo`Go00001oooool3o`0000;ooooo0_l00007ooooo`Go0000Eoooool001cooooo
00?o0000ooooooooool0>Oooool8o`0000[ooooo0_l0000<ooooo`?o00000oooool2o`0001?ooooo
7?l0000Booooo`;o000000?oooooo`000?l000000oooool2o`0000oooooo4ol00005ooooo`?o0000
2Oooool3o`0000;ooooo0_l00004ooooo`;o00000_ooool2o`000003ooooool0003o000000?ooooo
0_l00005ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0>Oooool2o`000003ooooool0
003o000000?o00005?ooool2o`0000;ooooo0ol00003ooooo`;o00004oooool>o`000003ooooool0
003o000000_o00003oooool8o`000003ooooool0003o0000017ooooo4?l0000Gooooo`Co00001?oo
ool2o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o00001Oooool2o`0004[ooooo000L
ooooo`03o`000?oooooooooo03Gooooo0_l00006ooooo`?o00003_ooool2o`0000Gooooo0_l0000O
ooooo`co000000?oooooo`000?l000002Ol0000Aooooo`Ko00000oooool2o`0000oooooo4_l00004
ooooo`;o00004Oooool2o`0000Gooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l0001D
ooooo`007?ooool2o`0003Kooooo0_l00006ooooo`?o00003Oooool3o`0000;ooooo0_l0000Aoooo
o`;o00003ooooolEo`000003ooooool0003o000000Gooooo0_l0000RoooooaGo00000_ooool3o`00
00?ooooo0_l0000Cooooo`;o00002?ooool3o`0000kooooo0_l00013ooooo`007?ooool00ol0003o
ooooooooo`0mooooo`?o00003Oooool2o`0000?ooooo0_l0000>ooooo`;o000000?oooooo`000?l0
00004?oooolDo`000003ooooool0003o000000Gooooo0_l0000<ooooo`;o00001oooool2o`000003
ooooool0003o000000Oooooo5ol000000ooooooo0000o`000004ooooo`;o00004oooool2o`0000;o
oooo0ol00004ooooo`;o00003_ooool2o`0000?ooooo0_l0000nooooo`007?ooool00ol0003ooooo
ooooo`0mooooo`;o00007Oooool2o`0000Cooooo0_l0000CoooooaSo00004_ooool4o`0000?ooooo
1?l000000ooooooo0000o`000007oooooaOo00001?ooool2o`0001[ooooo0ol0000Cooooo`?o0000
0oooool2o`0003kooooo000Looooo`03o`000?oooooooooo04;ooooo0_l0000<ooooo`;o00002_oo
ool4o`0001Sooooo5ol0000Dooooo`;o00000oooool4o`0000cooooo4_l000000ooooooo0000o`00
0003o`000003ooooool0003o000001oooooo0_l0000?ooooo`?o0000@oooool001cooooo00?o0000
ooooooooool0@_ooool2o`000003ooooool0003o000000Wooooo0_l0000<ooooo`;o00003oooool2
o`0000Kooooo6Ol0000?ooooo`?o00001oooool2o`0000kooooo5ol0000Eooooo`;o00001Oooool3
o`0000?ooooo0ol0001Dooooo`007?ooool00ol0003oooooooooo`0jooooo`;o00001oooool5o`00
00Sooooo0_l00006ooooo`;o00005Oooool2o`0000?ooooo0_l000000ooooooo0000o`00000Do`00
0003ooooool0003o000000oooooo0ol00006ooooo`;o00003ooooolDo`0000Gooooo0_l00007oooo
o`?o00001oooool2o`000004ooooool0003o0000ooooo`Go00000oooool2o`0005Cooooo000Loooo
o`03o`000?oooooooooo03[ooooo0_l00005ooooo`Co000000?oooooo`000?l000002?ooool2o`00
00Kooooo0_l00006ooooo`;o00001Oooool2o`0000Kooooo0_l00003ooooo`Co000000?oooooo`00
0?l000004Ol0000Dooooo`;o00001_ooool2o`0000oooooo5Ol00004ooooo`;o00001?ooool6o`00
00[ooooo0_l000000ooooooo0000o`000003o`0000Cooooo0_l0000?ooooo`;o0000@_ooool001co
oooo00?o0000ooooooooool0>oooool2o`0000?ooooo0ol0000Gooooo`Co00000_ooool2o`0000Go
oooo0_l00006ooooo`;o00000oooool4o`000003ooooool0003o0000017o00005?ooool2o`0001So
oooo3_l000000ooooooo0000o`000004o`0000Wooooo1_l0000?ooooo`;o00001Oooool2o`0000oo
oooo0_l00012ooooo`007?ooool00ol0003oooooooooo`0kooooo`;o00000oooool2o`0000Cooooo
0_l0000Booooo`Co00000_ooool2o`0000Kooooo0_l0000:ooooo`;o00000_ooool=o`000003oooo
ool0003o000000Go00004oooool2o`0000Oooooo0_l0000?oooooaGo00002_ooool3o`0001_ooooo
0_l000000ooooooo0000o`00001=ooooo`007?ooool00ol0003oooooooooo`16ooooo`;o00003?oo
ool2o`0000[ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o00001_oo
oolFo`0000oooooo0_l00002ooooo`;o00001oooool2o`0000oooooo5Ol0000Hooooo`;o00003_oo
ool5o`0004gooooo000Looooo`03o`000?oooooooooo04?ooooo0_l0000?ooooo`;o00002_ooool2
o`000003ooooool0003o000000;o00000oooool2o`0000?ooooo0_l00006ooooo`;o00000_ooool@
o`00017ooooo0_l00003ooooo`;o00005ooooolEo`0000?ooooo0_l0000Cooooo`;o00003_ooool4
o`0004kooooo000Looooo`03o`000?oooooooooo04?ooooo0_l0000Nooooo`;o00002_ooool2o`00
00Sooooo4_l0000Fooooo`;o00005?ooool2o`0000;ooooo4?l00002ooooo`;o00000oooool2o`00
00[ooooo0_l00008ooooo`;o00002oooool4o`00053ooooo000Looooo`03o`000?oooooooooo04?o
oooo0_l00003ooooo`Go00001oooool2o`0000gooooo0_l0000<ooooo`;o00001_oooolAo`0001_o
oooo0_l0000@oooooaCo00000_ooool2o`0000Gooooo0_l00006ooooo`Co00001Oooool2o`000003
ooooool0003o000000_ooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`13ooooo`?o0000
0_ooool5o`0000Oooooo0ol000000ooooooo0000o`000002ooooo`;o00000oooool2o`0000Gooooo
0_l00007ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`go00000oooool2o`0000oo
oooo0_l00006ooooo`;o00001Oooool2o`0000[ooooo4ol00009ooooo`Co00001?ooool2o`0000Oo
oooo0_l0001Rooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00000oooool3o`0000;ooooo
1?l00004ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo0_l00003ooooo`;o0000
1Oooool2o`0000?ooooo0_l00007ooooo`;o000000?oooooo`000?l000003Ol00004ooooo`;o0000
3oooool2o`0000gooooo0_l00007ooooo`;o00001_ooool>o`0000[ooooo0ol00003ooooo`;o0000
K?ooool001cooooo00?o0000ooooooooool0?_ooool2o`0000?ooooo0_l00004ooooo`Go00000_oo
ool2o`0000;ooooo0_l0000<ooooo`Go00001_ooool2o`0000Oooooo0_l00003ooooo`co00002_oo
ool2o`0000Sooooo0_l00009ooooo`;o00001_ooool2o`0000Gooooo0_l00006ooooo`Go00000_oo
ool4o`0000gooooo0_l00002ooooo`Co00006Oooool2o`00057ooooo000Looooo`;o0000A?ooool2
o`0000Oooooo0_l00006ooooo`;o00003?ooool5o`0000Cooooo1?l00007ooooo`;o00000oooool7
o`000004ooooool0003o0000o`0000Gooooo0_l00004ooooo`;o00002?ooool2o`0000Kooooo0_l0
00000ooooooo0000o`000002ooooo`;o00000_ooool2o`0000gooooo0ol00004ooooo`Co00000_oo
ool2o`0000Oooooo0_l00004ooooo`;o00001oooool2o`0000?ooooo0_l0000=ooooo`;o0000DOoo
ool001cooooo00?o0000ooooooooool0BOooool2o`00023ooooo0_l00005ooooo`;o00001oooool4
o`000003ooooool0003o000000;o00001oooool2o`0001?ooooo0_l000000ooooooo0000o`000005
ooooo`?o00007Oooool2o`0000Oooooo0_l0000=ooooo`;o000000?oooooo`000?l000000_l0001P
ooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00002oooool2o`0000[ooooo0_l0000>oooo
o`;o00001?ooool2o`0000?ooooo2?l0000Fooooo`;o00000oooool2o`0000Wooooo0_l0000@oooo
o`;o000000?oooooo`000?l000001Ol00002ooooo`;o00006_ooool2o`0000Kooooo0_l00002oooo
o`Co0000E?ooool001cooooo00?o0000ooooooooool0E_ooool2o`0000[ooooo0_l00002ooooo`;o
000000?oooooo`000?l000000ol00005ooooo`?o00000_ooool2o`0000?ooooo1Ol000000ooooooo
0000o`00000Fooooo`;o00003_ooool2o`0000?ooooo0_l00002ooooo`;o00001oooool2o`000003
ooooool0003o000000Go00000_ooool2o`0001Cooooo0_l00003ooooo`;o00001oooool2o`0000;o
oooo1?l0001Dooooo`007?ooool00ol0003oooooooooo`1Qooooo`;o00000oooool2o`000003oooo
ool0003o000000Go00000oooool3o`0000Gooooo0_l00008ooooo`;o00000oooool5o`0000Cooooo
0_l00006ooooo`;o00003_ooool2o`0000?ooooo0_l00002ooooo`;o00009Oooool2o`000004oooo
ool0003o0000o`0000?ooooo0_l0000Aooooo`;o0000D?ooool001cooooo00?o0000ooooooooool0
D?ooool2o`0000oooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool3o`0000;ooooo
0_l00007ooooo`;o00001Oooool2o`000003ooooool0003o000000?ooooo1Ol00004ooooo`;o0000
3?ooool2o`00017ooooo0_l0000Uooooo`;o000000?oooooo`000?l000002Oooool2o`0000Cooooo
0_l00005ooooo`?o0000D?ooool001cooooo00?o0000ooooooooool0D?ooool2o`000003ooooool0
003o000000;ooooo0_l00008ooooo`;o00003oooool2o`0000Wooooo0_l00003ooooo`?o000000?o
ooooo`000?l000000oooool2o`0000?ooooo1?l00005ooooo`;o00001_ooool2o`0004Cooooo1?l0
0004ooooo`;o00000oooool4o`00057ooooo000Looooo`03o`000?oooooooooo05;ooooo0ol00002
ooooo`;o00003_ooool2o`0000Kooooo1?l0000:ooooo`;o00000oooool3o`000003ooooool0003o
000000?ooooo2Ol00002ooooo`;o000000?oooooo`000?l000009Oooool2o`0002Gooooo0_l0000;
ooooo`Co0000DOooool001cooooo00?o0000ooooooooool0D_ooool2o`0000?ooooo0_l0000>oooo
o`?o00001Oooool4o`0000Sooooo0_l00002ooooo`;o00003?ooool4o`0000Gooooo1?l0000Noooo
o`;o00001_ooool2o`0001Oooooo0_l0000>ooooo`;o0000G_ooool001cooooo00?o0000oooooooo
ool0D_ooool2o`0000;ooooo0ol00006ooooo`;o00001oooool5o`0000kooooo0_l00002ooooo`;o
00002oooool2o`0000Kooooo0_l00002ooooo`;o00006Oooool3o`0000;ooooo1?l0000Mooooo`;o
00003_ooool2o`0005kooooo000Looooo`03o`000?oooooooooo053ooooo0_l00004ooooo`?o0000
1_ooool3o`0000Oooooo1?l0000Aooooo`;o00001_ooool4o`0000;ooooo0_l00005ooooo`?o0000
6Oooool7o`0000?ooooo0ol00007ooooo`;o00004Oooool2o`0000;ooooo1?l0001[ooooo`007?oo
ool00ol0003oooooooooo`1@ooooo`;o00001?ooool4o`0000Gooooo0ol00002ooooo`;o00004_oo
ool2o`0000Cooooo0_l00006ooooo`Co000000?oooooo`000?l000000oooool2o`000003ooooool0
003o000000;ooooo0_l00002ooooo`;o00003oooool8o`0000oooooo0_l00003ooooo`;o00003?oo
ool2o`0000;ooooo1?l0000=ooooo`;o0000G?ooool001cooooo00?o0000ooooooooool0D_ooool2
o`0000Cooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`000003ooooool0
003o000000;o00002oooool4o`00017ooooo0_l00003ooooo`;o00001Oooool2o`0000;ooooo0_l0
000?ooooo`Ko00004_ooool2o`0000;ooooo0_l0000Kooooo`;o00001?ooool2o`0005cooooo000L
ooooo`03o`000?oooooooooo05;ooooo0_l00008ooooo`;o00001Oooool8o`000004ooooool0003o
0000o`0000Oooooo0_l0000;ooooo`;o00001Oooool2o`00023ooooo0_l00002ooooo`?o00004Ooo
ool2o`000003ooooool0003o000000cooooo0_l0000>ooooo`;o0000H_ooool001cooooo00?o0000
ooooooooool0Hoooool4o`0000Gooooo0ol0000Dooooo`;o000000?oooooo`000?l000000_ooool2
o`00023ooooo0_l00003ooooo`;o00004Oooool2o`000004ooooool0003o0000ooooo`;o000000?o
ooooo`000?l000001_ooool2o`000003ooooool0003o0000017ooooo0_l0001Looooo`007?ooool0
0ol0003oooooooooo`1Kooooo`;o00001Oooool2o`0000Wooooo0_l00002ooooo`;o00001Oooool2
o`0000Sooooo0_l00002ooooo`;o00001?ooool2o`000003ooooool0003o000002_ooooo1?l00004
ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000009ooooo`;o00004Ooo
ool2o`0005cooooo000Looooo`;o0000EOooool2o`0000Gooooo0_l00002ooooo`Go00002?ooool2
o`0000?ooooo0_l00005ooooo`;o000000?oooooo`000?l000001Oooool2o`0000;ooooo0_l00004
ooooo`;o000000?oooooo`000?l00000:oooool4o`0000?ooooo0_l00005ooooo`;o00003Oooool3
o`0006gooooo000Looooo`03o`000?oooooooooo05Cooooo0_l00005ooooo`;o00000_ooool5o`00
00Sooooo0_l0000=ooooo`;o00002_ooool2o`0003Sooooo1?l00005ooooo`?o00000oooool4o`00
00Gooooo1?l0000:ooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0EOooool2o`0000Go
oooo0_l00002ooooo`Co00007?ooool2o`0000Gooooo0_l0000>ooooo`?o00007?ooool2o`0000Wo
oooo0_l00008ooooo`;o00000oooool4o`0000Cooooo1Ol0000:ooooo`;o0000H?ooool001cooooo
00?o0000ooooooooool0EOooool2o`0000Cooooo0ol0000<ooooo`;o00003?ooool2o`0000Gooooo
0ol0000Eooooo`?o00003Oooool2o`0000gooooo0_l00004ooooo`Go000000?oooooo`000?l00000
0_ooool2o`0000;ooooo0_l0000<ooooo`;o00002oooool2o`0006;ooooo000Looooo`03o`000?oo
oooooooo05_ooooo0_l0000<ooooo`Go00002_ooool2o`0000Gooooo0_l00006ooooo`;o00000_oo
ool2o`0000?ooooo0_l0000Eooooo`;o00001oooool2o`0000Gooooo0_l00003ooooo`Go000000Go
ooooo`000?l0003o0000ooooo`02o`0000;ooooo0_l0000Eooooo`;o00000_ooool2o`0006;ooooo
000Looooo`03o`000?oooooooooo06;ooooo0_l00005ooooo`;o000000Coooooo`000?l0003ooooo
0_l00008ooooo`;o00003?ooool2o`0000;ooooo0_l00003ooooo`;o00005Oooool2o`0000Gooooo
1?l00002ooooo`;o000000?oooooo`000?l000002Oooool4o`0001_ooooo0_l0001Vooooo`007?oo
ool00ol0003oooooooooo`1Rooooo`;o00001_ooool2o`0000?ooooo0_l00008ooooo`;o00000ooo
ool2o`0002cooooo1?l00002ooooo`Co00002Oooool2o`0000?ooooo0_l0000Cooooo`;o0000K_oo
ool001cooooo00?o0000ooooooooool0GOooool2o`0000_ooooo0_l00003ooooo`Co000000?ooooo
o`000?l000001?ooool2o`0000;ooooo0ol0000Rooooo`;o00001oooool2o`0000Cooooo0ol0000:
ooooo`;o00004_ooool2o`0000Cooooo0_l0001^ooooo`007?ooool00ol0003oooooooooo`1Ioooo
o`;o00000_ooool2o`0000kooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00001?ooool2
o`0000?ooooo0_l0000Mooooo`;o00000oooool2o`0000Oooooo0_l00005ooooo`;o00002?ooool2
o`00013ooooo0_l00002ooooo`;o0000M?ooool001cooooo00?o0000ooooooooool0FOooool2o`00
00;ooooo0_l0000;ooooo`;o000000?oooooo`000?l000000oooool2o`0000Sooooo0_l00005oooo
o`?o00002?ooool4o`0000[ooooo1?l00007ooooo`;o00004Oooool2o`000003ooooool0003o0000
00gooooo0_l000000ooooooo0000o`00001hooooo`007?ooool00ol0003oooooooooo`1Tooooo`;o
00001?ooool2o`0000Kooooo0ol000001?oooooo0000o`000?ooool2o`000003ooooool0003o0000
00Gooooo0ol00002ooooo`;o00001?ooool4o`000003ooooool0003o000000Oooooo0_l00006oooo
o`;o000000?oooooo`000?l000000oooool2o`0000cooooo0ol0000?ooooo`Co00000_ooool3o`00
00Cooooo0_l0001^ooooo`007?ooool00ol0003oooooooooo`1Looooo`;o00000oooool2o`000003
ooooool0003o000000Gooooo0_l00002ooooo`;o00000_ooool2o`000004ooooool0003o0000oooo
o`;o00001?ooool2o`000003ooooool0003o000000Cooooo0_l00004ooooo`;o00000oooool2o`00
00Oooooo0_l00003ooooo`;o000000?oooooo`000?l000001_ooool3o`0000Oooooo0_l000000ooo
oooo0000o`000002o`00017ooooo0_l00002ooooo`?o00001?ooool2o`0006kooooo000Looooo`03
o`000?oooooooooo05cooooo0_l00003ooooo`;o00002?ooool6o`0000;ooooo0_l0000:ooooo`;o
000000?oooooo`000?l000000oooool2o`0000Gooooo1?l0000:ooooo`;o00000oooool3o`0000Wo
oooo0ol00004ooooo`Co000000?oooooo`000?l00000S_ooool001cooooo00?o0000ooooooooool0
KOooool2o`0000Cooooo0_l00009ooooo`;o00001_ooool3o`0000Oooooo0_l0000@ooooo`?o0000
2Oooool2o`0000Cooooo0_l0000Kooooo`?o0000MOooool00006ooooooo^k^ko<S8bo`000?lb<S;o
k^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo
06[ooooo0_l0000Booooo`?o00001Oooool2o`0000Sooooo0_l00003ooooo`;o00001oooool2o`00
00?ooooo0ol0000[ooooo`?o0000MOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo06;ooooo0_l0
0003ooooo`;o000000?oooooo`000?l000004Oooool4o`0001Cooooo0ol00006ooooo`;o00001?oo
ool2o`0001Gooooo0_l00002ooooo`;o0000R?ooool00003ooooool@413ooooo00;ooooo00?o410@
ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0H_oo
ool2o`0000?ooooo1?l000000ooooooo0000o`00000=ooooo`Co00004Oooool2o`0000Cooooo0_l0
000Booooo`;o00003?ooool2o`000003ooooool0003o000000;ooooo0_l0000<ooooo`;o0000N_oo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Olb<S;oV9RHoooooonH
V9So<S8b00Kooooo0ol0001Xooooo`?o000000?oooooo`000?l000001oooool2o`0000Cooooo0_l0
0003ooooo`;o00003_ooool2o`0000?ooooo0_l0000Cooooo`;o00003?ooool2o`000003ooooool0
003o000000;ooooo0_l00006ooooo`;o00000_ooool4o`0007[ooooo00000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo00Wooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oo
oooooooo073ooooo0_l00003ooooo`;o000000?oooooo`000?l000001_ooool2o`0001?ooooo0_l0
000Cooooo`;o00000_ooool2o`0000Cooooo0_l00002ooooo`;o00003Oooool2o`0000;ooooo0_l0
001looooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[o
oooookZj^_l@41001_ooool00ol0003oooooooooo`1`ooooo`;o00001_ooool2o`0000Kooooo0_l0
000/ooooo`;o00001?ooool2o`0009?ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo
00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo07Sooooo0ol00005ooooo`?o
00005?ooool4o`0000Wooooo1?l00006ooooo`;o0000VOooool00006ooooooo^k^ko<S8bo`000?lb
<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0Koooool2
o`0000Oooooo0ol00006ooooo`;o00000oooool2o`0000oooooo1?l00007ooooo`Ko00001_ooool4
o`0000kooooo0_l00009ooooo`;o0000O?ooool001cooooo00?o0000ooooooooool0Koooool2o`00
01Gooooo0_l0000Jooooo`?o00002oooool2o`0000kooooo0_l00009ooooo`;o0000O?ooool001co
oooo00?o0000ooooooooool0Loooool2o`0000Sooooo0_l00003ooooo`;o00000oooool2o`0000[o
oooo0_l0000:ooooo`;o00006oooool2o`0008_ooooo000Looooo`03o`000?oooooooooo07?ooooo
0_l00008ooooo`Co000000?oooooo`000?l000000oooool2o`0000[ooooo0_l00002ooooo`;o0000
1_ooool2o`0000Sooooo0_l0000Aooooo`;o000000?oooooo`000?l000000_ooool2o`0008Cooooo
000Looooo`03o`000?oooooooooo07Cooooo0_l00008ooooo`?o00001Oooool2o`0000oooooo0_l0
0003ooooo`;o00002oooool2o`0000Cooooo0_l00003ooooo`;o00002Oooool2o`0000;ooooo0_l0
0024ooooo`007?ooool00ol0003oooooooooo`1dooooo`?o00003oooool2o`0000?ooooo1ol0000:
ooooo`?o00004?ooool2o`0000?ooooo0_l0000<ooooo`;o0000QOooool001cooooo00?o0000oooo
ooooool0MOooool4o`00017ooooo2?l0000;ooooo`;o00005Oooool2o`0000cooooo1?l00005oooo
o`;o0000O?ooool001cooooo00?o0000ooooooooool0Moooool2o`00017ooooo1?l000000ooooooo
0000o`00000=ooooo`;o000000?oooooo`000?l000004Oooool2o`0000Gooooo0_l00006ooooo`?o
00001Oooool2o`0007cooooo000Looooo`03o`000?oooooooooo083ooooo0_l00009ooooo`Co0000
00?oooooo`000?l000002oooool3o`000003ooooool0003o000000Kooooo0_l00006ooooo`;o0000
00?oooooo`000?l000001Oooool2o`0000Cooooo0_l00026ooooo`007?ooool00ol0003ooooooooo
o`1iooooo`;o00001Oooool2o`0000Wooooo1?l000000ooooooo0000o`00000:ooooo`Co00002Ooo
ool2o`0000Kooooo0_l0000>ooooo`;o0000Q_ooool001cooooo00?o0000ooooooooool0NOooool2
o`0001?ooooo0_l0000:ooooo`Co00008?ooool2o`0008Wooooo000Looooo`03o`000?oooooooooo
08kooooo0_l0000:ooooo`;o00005oooool2o`000003ooooool0003o000000Kooooo0_l00029oooo
o`007?ooool2o`000;Cooooo0_l000000ooooooo0000o`00000>ooooo`;o0000POooool001cooooo
00?o0000ooooooooool0X_ooool4o`000003ooooool0003o000001Wooooo0_l00002ooooo`;o0000
POooool001cooooo00?o0000ooooooooool0T?ooool2o`00013ooooo1?l000001?oooooo0000o`00
0?l00006ooooo`;o00004?ooool2o`0008Gooooo000Looooo`03o`000?oooooooooo093ooooo0_l0
000;ooooo`;o00002Oooool2o`0000Gooooo0ol000000ooooooo0000o`00002Dooooo`007?ooool0
0ol0003oooooooooo`2Gooooo`;o00001?ooool2o`0000[ooooo0_l00004ooooo`;o00000_ooool2
o`0000Cooooo0_l0002>ooooo`007?ooool00ol0003oooooooooo`2Gooooo`;o00003?ooool2o`00
00;ooooo0_l0000>ooooo`;o0000S_ooool001cooooo00?o0000ooooooooool0WOooool4o`0000Co
oooo0_l0002Rooooo`007?ooool00ol0003oooooooooo`2Mooooo`Co0000Z?ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`004_ooool4o`000003
oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Ooo
ool3o`000?ooooooB_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0
003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo
00?o0000ooooooooool0oooooomBooooo`004_ooool00omEEEGoIVIVo`00003ooooooeCooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo002Uooooo`04oa0@4?l0003o0000ooooo`;o
000000?o410@ooooooooool05oooool00ol0003ok^k^ooooo`03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool5o`00093ooooo002Vooooo`05o`000?ooooooooooooooool000002Oooool6o`00
00_ooooo00?oEEEEojVYZOooool00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A02@ooooo`00Y_ooool01Ol0003ooooooooooooooooo000001[ooooo00?o
ZJVYoeEEEOooool00oooool01Ol@413ooooooooooooooooo410@00Cooooo00?oV9RHob4Q8Oo^k^h0
TOooool00:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00003?ooool00olQ8B7ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool00onHV9So8B4Qonk^kP2@ooooo`00
Y_ooool01Ol0003oQhN7oooooonYZJWo000001_ooooo00?oEEEEolc<c?ooool00_ooool01Ol0003o
oooooooooooooooo000000Kooooo00?oMgMgofIVI_ooool0Soooool00:Gooooo00?o410@o`000?mg
MgL00_l000000onHV9Soooooooooo`0Iooooo`03ojVYZOmgMgOooooo00;ooooo00Go410@oooooooo
oooooooooa0@4007ooooo`03o`000?oooooooooo08kooooo0033ooooo`05oa0@4?oooooooooooooo
oolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go0000okZj^_ooooooV9RHoa0@
402@ooooo`00`oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`0T?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001
\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(708) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.52054 .356 Mdot
.52525 .31758 Mdot
.41679 .63721 Mdot
.59915 .51168 Mdot
.51445 .62491 Mdot
.38294 .64742 Mdot
.37468 .49345 Mdot
.40643 .48802 Mdot
.3989 .63794 Mdot
.5637 .25928 Mdot
.35405 .50367 Mdot
.55449 .49267 Mdot
.37711 .48244 Mdot
.65388 .48512 Mdot
.18812 .43877 Mdot
.69242 .5125 Mdot
.5098 .28536 Mdot
.57136 .70681 Mdot
.69749 .49894 Mdot
.40541 .65525 Mdot
.44486 .31928 Mdot
.64788 .48375 Mdot
.52724 .31274 Mdot
.65184 .48552 Mdot
.63086 .52393 Mdot
.50409 .33542 Mdot
.52758 .35694 Mdot
.61436 .50337 Mdot
.66149 .51179 Mdot
.35026 .47182 Mdot
.50575 .65617 Mdot
.14927 .56331 Mdot
.67425 .54205 Mdot
.76044 .44189 Mdot
.38878 .45412 Mdot
.48641 .81082 Mdot
.39886 .6134 Mdot
.38267 .51044 Mdot
.40415 .46982 Mdot
.39376 .46566 Mdot
.38958 .4725 Mdot
.50986 .33371 Mdot
.33908 .46719 Mdot
.31793 .48894 Mdot
.59378 .50019 Mdot
.32538 .35582 Mdot
.58953 .74911 Mdot
.6155 .49991 Mdot
.50992 .35297 Mdot
.38404 .67136 Mdot
.80332 .4493 Mdot
.38738 .51063 Mdot
.24336 .39657 Mdot
.14972 .34177 Mdot
.3689 .4622 Mdot
.60228 .50782 Mdot
.38077 .61995 Mdot
.62052 .47094 Mdot
.62915 .48761 Mdot
.76426 .40462 Mdot
.64588 .5099 Mdot
.57882 .66324 Mdot
.54314 .33889 Mdot
.42308 .63498 Mdot
.39248 .6408 Mdot
.36525 .45512 Mdot
.49146 .28905 Mdot
.38567 .48523 Mdot
.61203 .42499 Mdot
.39564 .66046 Mdot
.61212 .49797 Mdot
.3564 .50748 Mdot
.47918 .29237 Mdot
.68153 .50897 Mdot
.36365 .35858 Mdot
.24155 .44272 Mdot
.56796 .63379 Mdot
.70619 .38506 Mdot
.59665 .20093 Mdot
.26985 .48643 Mdot
.65972 .49378 Mdot
.5559 .15968 Mdot
.19846 .43546 Mdot
.51926 .30359 Mdot
.7441 .52031 Mdot
.29538 .66456 Mdot
.67637 .49563 Mdot
.49052 .55692 Mdot
.58303 .52426 Mdot
.4234 .35816 Mdot
.39954 .63193 Mdot
.50928 .34298 Mdot
.59362 .50727 Mdot
.67592 .48066 Mdot
.67864 .28302 Mdot
.61942 .548 Mdot
.59878 .4878 Mdot
.51233 .36944 Mdot
.35234 .48908 Mdot
.56627 .47987 Mdot
.31282 .48011 Mdot
.25599 .40988 Mdot
.62429 .53614 Mdot
.39003 .65433 Mdot
.53307 .29701 Mdot
.59987 .52513 Mdot
.36959 .45796 Mdot
.64631 .50109 Mdot
.37728 .54163 Mdot
.52542 .34285 Mdot
.67433 .47917 Mdot
.58462 .70549 Mdot
.39396 .33472 Mdot
.4819 .33871 Mdot
.42884 .19928 Mdot
.63773 .50521 Mdot
.63906 .48279 Mdot
.52245 .31465 Mdot
.36891 .62265 Mdot
.47411 .54625 Mdot
.49212 .28382 Mdot
.40022 .46824 Mdot
.53437 .33217 Mdot
.5889 .45284 Mdot
.36113 .64335 Mdot
.25346 .40477 Mdot
.2738 .41899 Mdot
.74889 .67235 Mdot
.67732 .51099 Mdot
.25735 .38083 Mdot
.3715 .64507 Mdot
.51867 .33266 Mdot
.38474 .48141 Mdot
.61325 .44421 Mdot
.49119 .29851 Mdot
.38784 .50182 Mdot
.59625 .6949 Mdot
.44324 .72324 Mdot
.47958 .34319 Mdot
.51005 .49903 Mdot
.4003 .45484 Mdot
.39145 .46414 Mdot
.80057 .49766 Mdot
.51922 .30882 Mdot
.58336 .69094 Mdot
.3877 .49976 Mdot
.71843 .61929 Mdot
.61164 .44579 Mdot
.78319 .54823 Mdot
.60604 .17724 Mdot
.80499 .46899 Mdot
.31487 .27678 Mdot
.57127 .65332 Mdot
.39633 .49469 Mdot
.61523 .52663 Mdot
.50706 .31027 Mdot
.51138 .31828 Mdot
.66251 .45879 Mdot
.63511 .51815 Mdot
.62789 .45167 Mdot
.65398 .45556 Mdot
.55906 .76732 Mdot
.63691 .45144 Mdot
.42865 .56684 Mdot
.47732 .31431 Mdot
.64289 .52358 Mdot
.4055 .59467 Mdot
.67946 .46341 Mdot
.38081 .51066 Mdot
.62527 .48324 Mdot
.62482 .51735 Mdot
.63751 .54645 Mdot
.39391 .47566 Mdot
.21745 .66691 Mdot
.54133 .18791 Mdot
.3627 .76518 Mdot
.3501 .26101 Mdot
.37491 .63106 Mdot
.66306 .47991 Mdot
.59113 .67191 Mdot
.69502 .5624 Mdot
.63154 .49114 Mdot
.79258 .40331 Mdot
.62476 .51136 Mdot
.6325 .38876 Mdot
.65588 .56916 Mdot
.33462 .76381 Mdot
.43915 .4694 Mdot
.65953 .51021 Mdot
.59617 .23866 Mdot
.79441 .54924 Mdot
.56302 .62751 Mdot
.37682 .46421 Mdot
.39172 .59216 Mdot
.38704 .60953 Mdot
.35152 .4482 Mdot
.57434 .45706 Mdot
.56611 .27551 Mdot
.58376 .43573 Mdot
.25686 .40115 Mdot
.52082 .27528 Mdot
.55769 .66647 Mdot
.48733 .35155 Mdot
.48802 .14878 Mdot
.49107 .40519 Mdot
.40603 .51413 Mdot
.58225 .71065 Mdot
.41842 .62575 Mdot
.25947 .39696 Mdot
.59127 .67951 Mdot
.60367 .48381 Mdot
.5115 .34961 Mdot
.79908 .54395 Mdot
.69677 .53424 Mdot
.68997 .7792 Mdot
.50763 .29298 Mdot
.46494 .50888 Mdot
.38067 .47054 Mdot
.36873 .67339 Mdot
.67333 .50294 Mdot
.63418 .45707 Mdot
.53963 .34512 Mdot
.62056 .50093 Mdot
.43374 .32811 Mdot
.62009 .51493 Mdot
.42434 .63674 Mdot
.596 .63517 Mdot
.33119 .47593 Mdot
.76307 .65474 Mdot
.46743 .3081 Mdot
.45336 .61156 Mdot
.40945 .63763 Mdot
.52759 .25146 Mdot
.34981 .49767 Mdot
.59606 .69785 Mdot
.40581 .61087 Mdot
.59758 .65414 Mdot
.63693 .5396 Mdot
.40128 .61969 Mdot
.56532 .6848 Mdot
.40359 .72321 Mdot
.59628 .49542 Mdot
.68447 .61083 Mdot
.37608 .49795 Mdot
.52094 .3597 Mdot
.64655 .51082 Mdot
.27169 .42144 Mdot
.61012 .43577 Mdot
.2221 .38847 Mdot
.24783 .41185 Mdot
.24376 .39978 Mdot
.24176 .46865 Mdot
.59001 .65692 Mdot
.33128 .31291 Mdot
.502 .45304 Mdot
.50028 .28294 Mdot
.59169 .50249 Mdot
.26794 .72143 Mdot
.38884 .49753 Mdot
.60473 .4838 Mdot
.30141 .67845 Mdot
.38693 .49965 Mdot
.62786 .47064 Mdot
.38666 .46569 Mdot
.50982 .31237 Mdot
.46517 .58027 Mdot
.5281 .29974 Mdot
.59989 .50024 Mdot
.36136 .47531 Mdot
.39868 .59791 Mdot
.50278 .33387 Mdot
.64163 .4992 Mdot
.66081 .48127 Mdot
.2646 .40057 Mdot
.64967 .52212 Mdot
.28447 .72452 Mdot
.61273 .50113 Mdot
.41802 .61547 Mdot
.61039 .54391 Mdot
.82408 .496 Mdot
.44869 .71792 Mdot
.47706 .30539 Mdot
.24602 .40823 Mdot
.39552 .62736 Mdot
.48981 .63672 Mdot
.56337 .59487 Mdot
.6537 .49663 Mdot
.26411 .41481 Mdot
.44978 .52945 Mdot
.36137 .45707 Mdot
.5831 .51934 Mdot
.44588 .3912 Mdot
.40993 .62536 Mdot
.25929 .39859 Mdot
.63253 .56672 Mdot
.5337 .30067 Mdot
.60349 .51435 Mdot
.40162 .61219 Mdot
.53404 .33899 Mdot
.60347 .44741 Mdot
.58593 .75866 Mdot
.26031 .41998 Mdot
.37796 .49709 Mdot
.53888 .49 Mdot
.61868 .45027 Mdot
.38231 .60778 Mdot
.50455 .29905 Mdot
.35894 .46745 Mdot
.49368 .34166 Mdot
.80002 .55933 Mdot
.35823 .26704 Mdot
.46172 .7819 Mdot
.57435 .71038 Mdot
.21651 .36209 Mdot
.381 .77467 Mdot
.36207 .2906 Mdot
.71526 .6821 Mdot
.47203 .83321 Mdot
.40659 .59986 Mdot
.71186 .57625 Mdot
.38996 .62217 Mdot
.62512 .53331 Mdot
.38725 .64604 Mdot
.31155 .76365 Mdot
.61638 .50748 Mdot
.37531 .62667 Mdot
.53767 .75874 Mdot
.64048 .51566 Mdot
.47607 .32687 Mdot
.15768 .48246 Mdot
.49727 .2195 Mdot
.52447 .41579 Mdot
.37031 .62909 Mdot
.75715 .33575 Mdot
.6275 .50854 Mdot
.69467 .51846 Mdot
.50408 .31509 Mdot
.5804 .51786 Mdot
.55884 .68216 Mdot
.60483 .66737 Mdot
.77382 .53247 Mdot
.44986 .20848 Mdot
.63507 .41643 Mdot
.50457 .32988 Mdot
.60537 .20467 Mdot
.36238 .36152 Mdot
.28264 .41539 Mdot
.40429 .46501 Mdot
.21651 .66294 Mdot
.71658 .49526 Mdot
.51617 .5095 Mdot
.43258 .38932 Mdot
.5183 .34176 Mdot
.35684 .73524 Mdot
.36611 .46772 Mdot
.58068 .21718 Mdot
.60758 .3453 Mdot
.61765 .45517 Mdot
.34648 .46845 Mdot
.558 .48583 Mdot
.43009 .34796 Mdot
.72367 .58841 Mdot
.34254 .55571 Mdot
.59742 .50095 Mdot
.33728 .32046 Mdot
.6339 .48449 Mdot
.77924 .55751 Mdot
.60232 .49057 Mdot
.48712 .33662 Mdot
.63648 .41359 Mdot
.52608 .585 Mdot
.49975 .19242 Mdot
.4739 .3979 Mdot
.57677 .64874 Mdot
.65347 .47896 Mdot
.62274 .45557 Mdot
.56789 .66483 Mdot
.492 .32825 Mdot
.5989 .47331 Mdot
.63946 .75198 Mdot
.61821 .45205 Mdot
.37098 .51451 Mdot
.48739 .60065 Mdot
.55958 .35146 Mdot
.6773 .48805 Mdot
.53774 .32651 Mdot
.37836 .4602 Mdot
.40829 .47795 Mdot
.69234 .45182 Mdot
.39685 .49028 Mdot
.60692 .51487 Mdot
.48077 .59314 Mdot
.53 .32353 Mdot
.59421 .56007 Mdot
.4893 .32303 Mdot
.68697 .24889 Mdot
.38415 .45995 Mdot
.28009 .40464 Mdot
.60705 .59256 Mdot
.36827 .48003 Mdot
.48651 .23139 Mdot
.71249 .47461 Mdot
.65737 .43796 Mdot
.49143 .22655 Mdot
.3814 .60093 Mdot
.26886 .39497 Mdot
.36258 .46353 Mdot
.62499 .45055 Mdot
.61984 .53851 Mdot
.34939 .50368 Mdot
.7079 .30873 Mdot
.49969 .66466 Mdot
.60293 .4936 Mdot
.48761 .33374 Mdot
.51608 .33445 Mdot
.59647 .45685 Mdot
.63169 .49509 Mdot
.41341 .6013 Mdot
.26722 .41611 Mdot
.25066 .39609 Mdot
.27606 .41792 Mdot
.35534 .65374 Mdot
.24085 .33536 Mdot
.39212 .465 Mdot
.26276 .34911 Mdot
.25753 .6154 Mdot
.70124 .46921 Mdot
.38322 .60414 Mdot
.63485 .4631 Mdot
.64083 .53525 Mdot
.35781 .47495 Mdot
.33474 .23309 Mdot
.58941 .41781 Mdot
.49439 .35822 Mdot
.36228 .51606 Mdot
.6459 .57851 Mdot
.3913 .42276 Mdot
.56424 .69151 Mdot
.50243 .40134 Mdot
.34435 .4753 Mdot
.50402 .34733 Mdot
.3446 .49352 Mdot
.62333 .4541 Mdot
.66995 .46045 Mdot
.52688 .32998 Mdot
.59196 .65766 Mdot
.60343 .53136 Mdot
.62853 .47173 Mdot
.84483 .4512 Mdot
.36161 .35228 Mdot
.38445 .42454 Mdot
.64298 .52945 Mdot
.66295 .4379 Mdot
.58592 .64933 Mdot
.60892 .45607 Mdot
.67376 .50043 Mdot
.39901 .32311 Mdot
.35075 .4466 Mdot
.57138 .63391 Mdot
.56788 .21683 Mdot
.50453 .29332 Mdot
.28887 .71575 Mdot
.25421 .41033 Mdot
.33424 .45814 Mdot
.46027 .57318 Mdot
.27473 .40124 Mdot
.27497 .60868 Mdot
.32777 .72619 Mdot
.27923 .40925 Mdot
.3834 .5722 Mdot
.73331 .48397 Mdot
.64195 .4456 Mdot
.62431 .48021 Mdot
.59447 .67688 Mdot
.51501 .30724 Mdot
.44486 .50369 Mdot
.39554 .70863 Mdot
.64462 .48352 Mdot
.48296 .37196 Mdot
.30684 .71201 Mdot
.26541 .3987 Mdot
.58643 .65963 Mdot
.55769 .6602 Mdot
.63561 .48233 Mdot
.3898 .29081 Mdot
.50539 .33316 Mdot
.64167 .49899 Mdot
.65983 .46523 Mdot
.37139 .62251 Mdot
.50268 .34977 Mdot
.40906 .63889 Mdot
.24952 .4153 Mdot
.56336 .82832 Mdot
.84692 .469 Mdot
.36087 .49122 Mdot
.36724 .75576 Mdot
.39915 .5065 Mdot
.29766 .501 Mdot
.27489 .41595 Mdot
.64432 .49265 Mdot
.46923 .30761 Mdot
.64445 .50161 Mdot
.60709 .46465 Mdot
.60225 .47767 Mdot
.63141 .41577 Mdot
.7965 .41087 Mdot
.58387 .67899 Mdot
.65914 .43352 Mdot
.38862 .58737 Mdot
.32463 .7461 Mdot
.15925 .52249 Mdot
.65009 .46669 Mdot
.6396 .47963 Mdot
.48959 .29385 Mdot
.6861 .50788 Mdot
.35325 .46541 Mdot
.51554 .30002 Mdot
.61315 .53477 Mdot
.38617 .73647 Mdot
.60751 .4532 Mdot
.39637 .77957 Mdot
.34587 .49727 Mdot
.51288 .40072 Mdot
.63786 .42515 Mdot
.27967 .41076 Mdot
.27088 .39582 Mdot
.28472 .41792 Mdot
.35611 .45683 Mdot
.37679 .617 Mdot
.37576 .7016 Mdot
.58427 .53773 Mdot
.61344 .52413 Mdot
.6513 .43372 Mdot
.36075 .67041 Mdot
.48872 .58344 Mdot
.31723 .28493 Mdot
.70008 .54853 Mdot
.3773 .59798 Mdot
.48786 .3636 Mdot
.41728 .18754 Mdot
.51131 .29917 Mdot
.5756 .63185 Mdot
.37104 .51205 Mdot
.56324 .69315 Mdot
.77777 .37031 Mdot
.52854 .33168 Mdot
.53881 .34873 Mdot
.37451 .62895 Mdot
.45357 .4737 Mdot
.09369 .45648 Mdot
.37812 .65782 Mdot
.67949 .72611 Mdot
.50259 .32029 Mdot
.66831 .53349 Mdot
.44469 .53502 Mdot
.45845 .48052 Mdot
.38386 .62984 Mdot
.66148 .49131 Mdot
.44028 .2294 Mdot
.41504 .60665 Mdot
.58865 .52479 Mdot
.36572 .63781 Mdot
.39338 .4791 Mdot
.36967 .64264 Mdot
.46837 .34627 Mdot
.64214 .53772 Mdot
.12118 .38539 Mdot
.38274 .40939 Mdot
.64836 .50829 Mdot
.36751 .51608 Mdot
.62007 .77073 Mdot
.61497 .46234 Mdot
.55859 .68475 Mdot
.36747 .60648 Mdot
.51547 .731 Mdot
.63243 .50896 Mdot
.38308 .64098 Mdot
.4944 .36133 Mdot
.34402 .43452 Mdot
.25832 .46149 Mdot
.25672 .394 Mdot
.50758 .30567 Mdot
.29156 .41811 Mdot
.37494 .44634 Mdot
.61871 .5432 Mdot
.65365 .4591 Mdot
.47895 .32457 Mdot
.23843 .5062 Mdot
.65674 .54638 Mdot
.65961 .49362 Mdot
.41591 .63147 Mdot
.35141 .66679 Mdot
.19047 .51914 Mdot
.40498 .59701 Mdot
.66173 .43672 Mdot
.47976 .32763 Mdot
.61054 .52859 Mdot
.47485 .32117 Mdot
.59204 .50337 Mdot
.54905 .36822 Mdot
.51266 .30137 Mdot
.4022 .23134 Mdot
.6669 .51435 Mdot
.59018 .57348 Mdot
.60524 .46553 Mdot
.60136 .48512 Mdot
.36427 .61149 Mdot
.5711 .67755 Mdot
.59495 .53761 Mdot
.45873 .59623 Mdot
.59907 .6735 Mdot
.74054 .43756 Mdot
.37148 .6194 Mdot
.59446 .68722 Mdot
.64755 .63947 Mdot
.24607 .4075 Mdot
.58253 .67028 Mdot
.17899 .56344 Mdot
.3595 .48785 Mdot
.53034 .3126 Mdot
.64062 .51658 Mdot
.50643 .84097 Mdot
.5044 .65735 Mdot
.27009 .40544 Mdot
.63777 .50706 Mdot
.6295 .46232 Mdot
.52735 .28994 Mdot
.51982 .15051 Mdot
.39967 .66786 Mdot
.59758 .51528 Mdot
.51068 .28676 Mdot
.59437 .17411 Mdot
.36467 .65006 Mdot
.586 .66776 Mdot
.35179 .51076 Mdot
.45319 .31602 Mdot
.25937 .39294 Mdot
.37375 .45158 Mdot
.34463 .62942 Mdot
.76753 .33774 Mdot
.62731 .50484 Mdot
.39099 .60257 Mdot
.80486 .46382 Mdot
.56901 .49463 Mdot
.39815 .43784 Mdot
.60186 .39499 Mdot
.51596 .34222 Mdot
.35284 .50913 Mdot
.56993 .64847 Mdot
.53073 .321 Mdot
.49259 .33022 Mdot
.40542 .48958 Mdot
.43264 .58798 Mdot
.46556 .50643 Mdot
.35931 .51229 Mdot
.41811 .34757 Mdot
.78705 .52262 Mdot
.26349 .41626 Mdot
.58471 .65746 Mdot
.80845 .55281 Mdot
.50867 .33517 Mdot
.21719 .66423 Mdot
.7971 .41833 Mdot
.59883 .48788 Mdot
.57697 .69617 Mdot
.27985 .62296 Mdot
.3676 .70466 Mdot
.38352 .50186 Mdot
.4993 .57912 Mdot
.55461 .67804 Mdot
.6196 .44549 Mdot
.5565 .37398 Mdot
.66615 .51244 Mdot
.39085 .49787 Mdot
.43668 .29309 Mdot
.49694 .34803 Mdot
.37028 .44492 Mdot
.43353 .34389 Mdot
.64522 .5338 Mdot
.66846 .50116 Mdot
.76563 .60631 Mdot
.51057 .35072 Mdot
.25663 .3927 Mdot
.65349 .50159 Mdot
.61979 .47315 Mdot
.62228 .54586 Mdot
.56716 .55775 Mdot
.38169 .31332 Mdot
.59717 .51653 Mdot
.35822 .65355 Mdot
.66735 .44867 Mdot
.66995 .50287 Mdot
.52468 .29266 Mdot
.82789 .43832 Mdot
.25398 .4198 Mdot
.6211 .48019 Mdot
.6041 .49209 Mdot
.4012 .46698 Mdot
.45764 .51837 Mdot
.45566 .46986 Mdot
.39356 .65889 Mdot
.70755 .67038 Mdot
.58747 .43464 Mdot
.49215 .29965 Mdot
.57754 .70631 Mdot
.66844 .52818 Mdot
.49602 .29319 Mdot
.65352 .44445 Mdot
.40576 .58946 Mdot
.26705 .41499 Mdot
.52214 .46193 Mdot
.57877 .6674 Mdot
.39375 .5522 Mdot
.28892 .36478 Mdot
.40266 .59211 Mdot
.62297 .52564 Mdot
.32625 .45954 Mdot
.40604 .63861 Mdot
.26538 .40202 Mdot
.64148 .56586 Mdot
.50968 .32103 Mdot
.49693 .34645 Mdot
.77685 .54254 Mdot
.38507 .68003 Mdot
.76179 .28823 Mdot
.39384 .48125 Mdot
.5835 .47116 Mdot
.2802 .38176 Mdot
.48998 .34432 Mdot
.78873 .57837 Mdot
.59558 .68403 Mdot
.38201 .50196 Mdot
.26194 .4267 Mdot
.49193 .29503 Mdot
.49312 .35106 Mdot
.59422 .49402 Mdot
.64784 .47008 Mdot
.71211 .69092 Mdot
.78281 .55192 Mdot
.38917 .4705 Mdot
.57869 .65657 Mdot
.38748 .66661 Mdot
.64261 .53221 Mdot
.52226 .30588 Mdot
.64732 .39122 Mdot
.62856 .44886 Mdot
.41589 .60866 Mdot
.52146 .33696 Mdot
.57083 .65935 Mdot
.58784 .69959 Mdot
.60105 .48433 Mdot
.73449 .39318 Mdot
.36906 .48515 Mdot
.47879 .33526 Mdot
.51331 .25701 Mdot
.64275 .55292 Mdot
.65124 .47178 Mdot
.56106 .51556 Mdot
.37472 .45172 Mdot
.53292 .43799 Mdot
.55128 .68034 Mdot
.51533 .31874 Mdot
.64835 .50622 Mdot
.57921 .66333 Mdot
.53076 .50613 Mdot
.27657 .40961 Mdot
.36569 .6405 Mdot
.55712 .6774 Mdot
.56666 .68077 Mdot
.60093 .67982 Mdot
.20991 .65106 Mdot
.50788 .27484 Mdot
.55987 .20756 Mdot
.59845 .48057 Mdot
.77372 .53701 Mdot
.68549 .49698 Mdot
.36073 .4509 Mdot
.39372 .59481 Mdot
.61112 .4598 Mdot
.59388 .49442 Mdot
.56108 .37858 Mdot
.63314 .58009 Mdot
.44395 .33128 Mdot
.5199 .34718 Mdot
.59265 .5778 Mdot
.37676 .60805 Mdot
.57981 .15163 Mdot
.19991 .67386 Mdot
.61486 .42677 Mdot
.45413 .50272 Mdot
.51726 .30169 Mdot
.40391 .48642 Mdot
.46462 .47868 Mdot
.34306 .50436 Mdot
.51841 .32153 Mdot
.63266 .53408 Mdot
.27008 .34678 Mdot
.60206 .66514 Mdot
.63346 .45235 Mdot
.38562 .47466 Mdot
.63072 .45188 Mdot
.35267 .45541 Mdot
.45572 .36258 Mdot
.41564 .37981 Mdot
.6227 .51025 Mdot
.64912 .54862 Mdot
.55005 .41159 Mdot
.64909 .46713 Mdot
.29178 .57515 Mdot
.49444 .31852 Mdot
.44353 .21911 Mdot
.59497 .46182 Mdot
.72572 .36315 Mdot
.62993 .4469 Mdot
.23924 .51836 Mdot
.66392 .47656 Mdot
.5057 .53154 Mdot
.61525 .44561 Mdot
.66404 .48215 Mdot
.36204 .46931 Mdot
.4036 .47034 Mdot
.49292 .3602 Mdot
.26655 .39218 Mdot
.33318 .76133 Mdot
.63614 .47222 Mdot
.35449 .63338 Mdot
.29819 .3949 Mdot
.56821 .67971 Mdot
.5168 .32541 Mdot
.65966 .18506 Mdot
.38214 .46148 Mdot
.42364 .63133 Mdot
.25738 .52357 Mdot
.37977 .67554 Mdot
.35371 .53478 Mdot
.60943 .58565 Mdot
.5755 .65423 Mdot
.62999 .44611 Mdot
.75145 .43107 Mdot
.34637 .33352 Mdot
.58503 .51333 Mdot
.37231 .43815 Mdot
.69241 .56698 Mdot
.7921 .51715 Mdot
.58259 .64133 Mdot
.56556 .65594 Mdot
.36423 .46454 Mdot
.41253 .64562 Mdot
.56834 .45909 Mdot
.59425 .68886 Mdot
.38915 .5917 Mdot
.28038 .3977 Mdot
.57012 .61073 Mdot
.50823 .3319 Mdot
.52282 .42418 Mdot
.33573 .3813 Mdot
.3872 .46824 Mdot
.45949 .59016 Mdot
.45766 .34225 Mdot
.53806 .3003 Mdot
.27983 .40053 Mdot
.36992 .59997 Mdot
.48234 .28683 Mdot
.6106 .53661 Mdot
.6979 .53318 Mdot
.63513 .48542 Mdot
.58961 .69148 Mdot
.66661 .47658 Mdot
.38279 .5897 Mdot
.38868 .49316 Mdot
.40175 .63101 Mdot
.3683 .4878 Mdot
.27746 .33095 Mdot
.62893 .49707 Mdot
.65154 .47585 Mdot
.46024 .55572 Mdot
.4945 .35545 Mdot
.75908 .3923 Mdot
.36045 .6121 Mdot
.38424 .6192 Mdot
.61297 .53085 Mdot
.50098 .36249 Mdot
.61161 .67407 Mdot
.43807 .54653 Mdot
.66156 .46997 Mdot
.49443 .31701 Mdot
.6037 .51963 Mdot
.46083 .77502 Mdot
.40055 .38033 Mdot
.49326 .3426 Mdot
.48258 .18768 Mdot
.65658 .52119 Mdot
.73601 .51737 Mdot
.67232 .44238 Mdot
.65747 .715 Mdot
.62786 .5538 Mdot
.50971 .29325 Mdot
.62704 .48486 Mdot
.49903 .30076 Mdot
.41462 .6193 Mdot
.39877 .47336 Mdot
.50458 .30689 Mdot
.67997 .49592 Mdot
.17438 .6162 Mdot
.38833 .47434 Mdot
.65814 .48041 Mdot
.34903 .48771 Mdot
.51602 .29034 Mdot
.5052 .35606 Mdot
.18515 .56804 Mdot
.40308 .43227 Mdot
.3857 .47021 Mdot
.60926 .51903 Mdot
.34962 .40258 Mdot
.61033 .52812 Mdot
.72138 .6834 Mdot
.58758 .47515 Mdot
.60667 .54201 Mdot
.20864 .37267 Mdot
.34608 .51289 Mdot
.71927 .24377 Mdot
.39782 .71267 Mdot
.19985 .63454 Mdot
.47275 .28805 Mdot
.58258 .64125 Mdot
.3461 .72996 Mdot
.25034 .41461 Mdot
.36104 .63041 Mdot
.61098 .45936 Mdot
.55295 .36423 Mdot
.36 .51476 Mdot
.57429 .68263 Mdot
.62363 .51093 Mdot
.41163 .59308 Mdot
.17352 .53557 Mdot
.3959 .49543 Mdot
.51084 .33277 Mdot
.49503 .35692 Mdot
.56499 .17963 Mdot
.64467 .50654 Mdot
.64886 .47787 Mdot
.37399 .51212 Mdot
.58352 .44151 Mdot
.60327 .68524 Mdot
.50986 .76884 Mdot
.38094 .46735 Mdot
.36436 .41017 Mdot
.52605 .34301 Mdot
.63178 .46222 Mdot
.49387 .60614 Mdot
.23492 .62363 Mdot
.5896 .25267 Mdot
.59349 .67564 Mdot
.73743 .64727 Mdot
.50928 .2931 Mdot
.38476 .47839 Mdot
.67512 .60229 Mdot
.60428 .43895 Mdot
.62648 .46459 Mdot
.74183 .64 Mdot
.45061 .52359 Mdot
.60302 .71294 Mdot
.68576 .51646 Mdot
.45795 .52684 Mdot
.61616 .53263 Mdot
.62142 .53869 Mdot
.60951 .42718 Mdot
.67408 .49264 Mdot
.49612 .30975 Mdot
.56537 .35924 Mdot
.37718 .64535 Mdot
.66501 .26892 Mdot
.50494 .56988 Mdot
.65084 .51575 Mdot
.63746 .53445 Mdot
.53659 .24379 Mdot
.30533 .41074 Mdot
.49692 .32168 Mdot
.5536 .33405 Mdot
.38655 .45827 Mdot
.62215 .57863 Mdot
.37351 .6803 Mdot
.57323 .3989 Mdot
.40254 .63865 Mdot
.49377 .31599 Mdot
.382 .61421 Mdot
.38776 .45733 Mdot
.39185 .60295 Mdot
.35583 .6538 Mdot
.34211 .47255 Mdot
.52442 .34776 Mdot
.65813 .46817 Mdot
.38564 .46203 Mdot
.76382 .61455 Mdot
.58934 .69234 Mdot
.18409 .56685 Mdot
.69469 .49971 Mdot
.72626 .44858 Mdot
.58594 .75834 Mdot
.39807 .62133 Mdot
.39349 .36502 Mdot
.51258 .30151 Mdot
.59395 .70578 Mdot
.49757 .30533 Mdot
.78051 .3937 Mdot
.5688 .6674 Mdot
.18316 .56897 Mdot
.65035 .60859 Mdot
.47622 .64791 Mdot
.67369 .47245 Mdot
.53292 .37644 Mdot
.40667 .63413 Mdot
.373 .51449 Mdot
.29467 .6531 Mdot
.6743 .51466 Mdot
.35807 .29096 Mdot
.51758 .27733 Mdot
.2469 .40204 Mdot
.38439 .48362 Mdot
.37921 .43928 Mdot
.63906 .50444 Mdot
.48395 .63015 Mdot
.58611 .50946 Mdot
.66228 .59708 Mdot
.72058 .66855 Mdot
.57603 .39688 Mdot
.60389 .51282 Mdot
.40085 .65033 Mdot
.60511 .51984 Mdot
.72628 .50753 Mdot
.79926 .49849 Mdot
.69456 .4955 Mdot
.37064 .25253 Mdot
.52902 .72911 Mdot
.52697 .32463 Mdot
.64627 .42601 Mdot
.26364 .4081 Mdot
.64906 .52657 Mdot
.61341 .84497 Mdot
.58015 .6727 Mdot
.34949 .68977 Mdot
.68057 .48806 Mdot
.64934 .50209 Mdot
.71517 .40281 Mdot
.52578 .39021 Mdot
.25822 .42536 Mdot
.62044 .46658 Mdot
.71658 .64679 Mdot
.35582 .47063 Mdot
.59235 .4565 Mdot
.62821 .48199 Mdot
.8015 .58544 Mdot
.35133 .47755 Mdot
.39485 .61312 Mdot
.24649 .40994 Mdot
.38423 .6668 Mdot
.57695 .63835 Mdot
.45464 .45175 Mdot
.78866 .56365 Mdot
.399 .38168 Mdot
.5581 .68802 Mdot
.66706 .46939 Mdot
.74415 .49737 Mdot
.66248 .50316 Mdot
.56823 .65185 Mdot
.34961 .47311 Mdot
.49858 .31099 Mdot
.51647 .45961 Mdot
.25822 .40116 Mdot
.59233 .52815 Mdot
.58373 .64358 Mdot
.5073 .31412 Mdot
.1994 .55588 Mdot
.51856 .31314 Mdot
.36759 .47587 Mdot
.37005 .44785 Mdot
.57161 .66897 Mdot
.49611 .307 Mdot
.36422 .65815 Mdot
.40057 .70952 Mdot
.58643 .48325 Mdot
.36564 .42351 Mdot
.46624 .33416 Mdot
.52999 .35613 Mdot
.47678 .29995 Mdot
.62779 .50058 Mdot
.45665 .5119 Mdot
.59991 .43911 Mdot
.3726 .45837 Mdot
.36484 .62809 Mdot
.78346 .54639 Mdot
.75051 .41872 Mdot
.38586 .40809 Mdot
.59761 .53886 Mdot
.67141 .49767 Mdot
.63591 .48238 Mdot
.60316 .49872 Mdot
.49333 .77652 Mdot
.62889 .49539 Mdot
.36283 .47968 Mdot
.38811 .65144 Mdot
.64223 .50865 Mdot
.26234 .41058 Mdot
.47833 .51941 Mdot
.57396 .70477 Mdot
.50555 .53815 Mdot
.20203 .66338 Mdot
.50614 .3144 Mdot
.40338 .60668 Mdot
.36205 .6408 Mdot
.59626 .69499 Mdot
.39544 .48179 Mdot
.51551 .30931 Mdot
.65208 .70107 Mdot
.5986 .66793 Mdot
.62013 .48026 Mdot
.47258 .58328 Mdot
.45506 .18614 Mdot
.65735 .45512 Mdot
.60623 .47414 Mdot
.2433 .40241 Mdot
.39428 .67088 Mdot
.50107 .85679 Mdot
.43141 .52973 Mdot
.57121 .67486 Mdot
.56143 .6702 Mdot
.48373 .28976 Mdot
.57979 .50465 Mdot
.37351 .49102 Mdot
.44526 .53981 Mdot
.6469 .76362 Mdot
.28999 .67528 Mdot
.29168 .49698 Mdot
.60613 .45605 Mdot
.66318 .38154 Mdot
.58961 .5032 Mdot
.53113 .29314 Mdot
.48651 .29159 Mdot
.50036 .32649 Mdot
.36433 .46837 Mdot
.69353 .25598 Mdot
.36329 .48313 Mdot
.20288 .66736 Mdot
.52217 .30245 Mdot
.46117 .69251 Mdot
.37809 .62071 Mdot
.58497 .53694 Mdot
.57833 .65467 Mdot
.31319 .43853 Mdot
.62941 .42063 Mdot
.38393 .29065 Mdot
.38356 .60417 Mdot
.51272 .35485 Mdot
.71985 .50923 Mdot
.35941 .78722 Mdot
.44106 .4404 Mdot
.53493 .68508 Mdot
.77525 .40521 Mdot
.56864 .66451 Mdot
.56727 .24426 Mdot
.6037 .67535 Mdot
.38754 .50092 Mdot
.67548 .5132 Mdot
.67792 .50439 Mdot
.59748 .50852 Mdot
.62569 .49535 Mdot
.36018 .46441 Mdot
.59505 .47145 Mdot
.82385 .49552 Mdot
.25778 .417 Mdot
.42808 .73004 Mdot
.5735 .69937 Mdot
.34584 .45808 Mdot
.39697 .647 Mdot
.27059 .39263 Mdot
.77201 .64397 Mdot
.59858 .46678 Mdot
.60744 .4626 Mdot
.27992 .4174 Mdot
.5952 .43618 Mdot
.71817 .50358 Mdot
.38083 .64535 Mdot
.45134 .41798 Mdot
.56241 .654 Mdot
.56316 .6926 Mdot
.34333 .48231 Mdot
.49722 .30526 Mdot
.59547 .67749 Mdot
.41486 .6406 Mdot
.6086 .44514 Mdot
.64822 .54515 Mdot
.46664 .33566 Mdot
.79717 .41827 Mdot
.59825 .65255 Mdot
.71135 .46625 Mdot
.50154 .29652 Mdot
.51477 .27622 Mdot
.62103 .46456 Mdot
.65866 .55603 Mdot
.53178 .3497 Mdot
.57575 .70193 Mdot
.34409 .46097 Mdot
.4744 .66455 Mdot
.39129 .49451 Mdot
.51115 .3088 Mdot
.63376 .43715 Mdot
.52502 .3461 Mdot
.65242 .52256 Mdot
.42038 .1292 Mdot
.67142 .48604 Mdot
.48676 .22769 Mdot
.6647 .71441 Mdot
.3642 .64525 Mdot
.36806 .66125 Mdot
.26429 .41366 Mdot
.50557 .29478 Mdot
.6658 .52971 Mdot
.56413 .66289 Mdot
.18915 .61518 Mdot
.52872 .27329 Mdot
.37317 .60392 Mdot
.38031 .6784 Mdot
.3537 .46764 Mdot
.64132 .44928 Mdot
.63585 .46483 Mdot
.39246 .60431 Mdot
.5762 .76237 Mdot
.48751 .30459 Mdot
.64901 .47839 Mdot
.67151 .50127 Mdot
.37711 .64864 Mdot
.40434 .71047 Mdot
.50029 .38498 Mdot
.67385 .49393 Mdot
.64401 .61378 Mdot
.35835 .45338 Mdot
.60966 .50656 Mdot
.59488 .47611 Mdot
.5725 .68905 Mdot
.41705 .74139 Mdot
.79405 .51193 Mdot
.35471 .4492 Mdot
.25348 .39424 Mdot
.68212 .50471 Mdot
.37815 .62327 Mdot
.66665 .53451 Mdot
.44854 .80687 Mdot
.25227 .41268 Mdot
.63881 .49428 Mdot
.60836 .42944 Mdot
.47734 .33695 Mdot
.64104 .49714 Mdot
.57689 .38702 Mdot
.38553 .66113 Mdot
.63786 .49526 Mdot
.73758 .3903 Mdot
.35768 .46385 Mdot
.63662 .42286 Mdot
.55854 .67133 Mdot
.65362 .72177 Mdot
.30893 .37253 Mdot
.35397 .65826 Mdot
.58335 .7002 Mdot
.66497 .47344 Mdot
.41384 .63679 Mdot
.35401 .51363 Mdot
.37018 .28437 Mdot
.64262 .44465 Mdot
.39304 .48778 Mdot
.38877 .49004 Mdot
.57431 .67068 Mdot
.66192 .19965 Mdot
.59832 .43124 Mdot
.65293 .46765 Mdot
.74971 .70241 Mdot
.50088 .28042 Mdot
.65399 .46663 Mdot
.6477 .45341 Mdot
.37297 .49695 Mdot
.59807 .59326 Mdot
.47333 .25416 Mdot
.53785 .759 Mdot
.35365 .45454 Mdot
.36235 .60253 Mdot
.4135 .63402 Mdot
.57716 .69981 Mdot
.52568 .32752 Mdot
.55484 .68496 Mdot
.3725 .63642 Mdot
.60062 .487 Mdot
.3723 .5035 Mdot
.62442 .28616 Mdot
.38764 .51075 Mdot
.41807 .60981 Mdot
.53882 .33432 Mdot
.26881 .37773 Mdot
.79523 .68357 Mdot
.33212 .37008 Mdot
.34215 .45863 Mdot
.56831 .68034 Mdot
.42427 .5484 Mdot
.6709 .4978 Mdot
.56465 .22717 Mdot
.64525 .45746 Mdot
.77771 .40887 Mdot
.39169 .59369 Mdot
.28221 .40456 Mdot
.67529 .51428 Mdot
.73182 .6481 Mdot
.34493 .45615 Mdot
.3567 .46256 Mdot
.6115 .48831 Mdot
.36727 .4784 Mdot
.64233 .46952 Mdot
.3786 .65401 Mdot
.67738 .21326 Mdot
.66712 .48896 Mdot
.6876 .46546 Mdot
.34496 .44876 Mdot
.18357 .56688 Mdot
.37276 .59201 Mdot
.67417 .38576 Mdot
.37944 .80267 Mdot
.36957 .48136 Mdot
.67758 .44456 Mdot
.40178 .61758 Mdot
.24316 .40086 Mdot
.40712 .57475 Mdot
.63288 .4546 Mdot
.60209 .46649 Mdot
.60586 .52718 Mdot
.66854 .5026 Mdot
.55427 .22888 Mdot
.69515 .54901 Mdot
.63676 .35583 Mdot
.60608 .46579 Mdot
.53991 .26652 Mdot
.36001 .47646 Mdot
.4454 .3373 Mdot
.58639 .71939 Mdot
.60007 .46947 Mdot
.53388 .3893 Mdot
.34918 .45445 Mdot
.21613 .67794 Mdot
.35206 .47256 Mdot
.39672 .63035 Mdot
.40247 .49098 Mdot
.65122 .52153 Mdot
.51472 .33605 Mdot
.3854 .65775 Mdot
.3078 .29664 Mdot
.36233 .62437 Mdot
.64768 .5082 Mdot
.42886 .71367 Mdot
.36386 .64245 Mdot
.48771 .52451 Mdot
.5186 .33429 Mdot
.71984 .63487 Mdot
.50671 .28113 Mdot
.64639 .49491 Mdot
.65214 .49367 Mdot
.26707 .39081 Mdot
.39691 .49442 Mdot
.51648 .29213 Mdot
.84433 .44579 Mdot
.5635 .64433 Mdot
.49895 .3334 Mdot
.64013 .55842 Mdot
.44926 .51641 Mdot
.48142 .33632 Mdot
.68854 .66973 Mdot
.39391 .49584 Mdot
.47958 .29148 Mdot
.62443 .56244 Mdot
.52244 .52409 Mdot
.60634 .68424 Mdot
.40266 .5863 Mdot
.48874 .48026 Mdot
.40712 .64229 Mdot
.36394 .44324 Mdot
.413 .65498 Mdot
.35586 .47308 Mdot
.4939 .22651 Mdot
.43822 .29272 Mdot
.32616 .47676 Mdot
.37172 .44679 Mdot
.37822 .63397 Mdot
.60323 .49613 Mdot
.51959 .59192 Mdot
.62422 .55625 Mdot
.67069 .46338 Mdot
.37114 .45315 Mdot
.50612 .28999 Mdot
.53325 .33073 Mdot
.52995 .37369 Mdot
.49871 .35538 Mdot
.39655 .64958 Mdot
.40212 .36635 Mdot
.77368 .37498 Mdot
.3496 .496 Mdot
.39883 .51912 Mdot
.6162 .5308 Mdot
.37764 .6274 Mdot
.41276 .60902 Mdot
.37913 .49512 Mdot
.61342 .25262 Mdot
.65904 .43698 Mdot
.52244 .28829 Mdot
.52301 .3037 Mdot
.48239 .33474 Mdot
.46959 .32377 Mdot
.65118 .232 Mdot
.37327 .51449 Mdot
.51284 .29665 Mdot
.62022 .49064 Mdot
.6117 .45426 Mdot
.25553 .39652 Mdot
.56424 .68855 Mdot
.68934 .48567 Mdot
.6867 .47143 Mdot
.62264 .46332 Mdot
.3649 .64053 Mdot
.58255 .54478 Mdot
.2517 .4093 Mdot
.40291 .66548 Mdot
.3638 .67352 Mdot
.27921 .40286 Mdot
.49276 .2619 Mdot
.35235 .79247 Mdot
.59785 .51563 Mdot
.70883 .56542 Mdot
.38176 .62493 Mdot
.42094 .28959 Mdot
.53958 .43108 Mdot
.6069 .51347 Mdot
.54994 .58293 Mdot
.37968 .6567 Mdot
.52815 .28107 Mdot
.64572 .46097 Mdot
.27414 .41746 Mdot
.57999 .70564 Mdot
.62287 .56031 Mdot
.24293 .40397 Mdot
.49224 .31489 Mdot
.52897 .70755 Mdot
.48915 .28262 Mdot
.3633 .65002 Mdot
.63718 .42236 Mdot
.09335 .44236 Mdot
.40844 .6317 Mdot
.24041 .66567 Mdot
.43429 .31737 Mdot
.6693 .4905 Mdot
.40883 .63887 Mdot
.53143 .28594 Mdot
.35983 .45304 Mdot
.4647 .53236 Mdot
.52299 .30803 Mdot
.27479 .39485 Mdot
.26486 .39496 Mdot
.37769 .64668 Mdot
.51857 .34484 Mdot
.59092 .47022 Mdot
.47462 .3149 Mdot
.40117 .49482 Mdot
.62617 .51791 Mdot
.33547 .76473 Mdot
.69905 .53127 Mdot
.50012 .29538 Mdot
.42052 .6287 Mdot
.58817 .65187 Mdot
.62217 .50884 Mdot
.27956 .70171 Mdot
.64598 .45157 Mdot
.3482 .48126 Mdot
.42226 .26368 Mdot
.61181 .28635 Mdot
.60251 .4914 Mdot
.62755 .53437 Mdot
.34267 .48305 Mdot
.60101 .49157 Mdot
.65372 .45334 Mdot
.38683 .43223 Mdot
.48395 .34301 Mdot
.63899 .4863 Mdot
.40461 .59145 Mdot
.77809 .45065 Mdot
.68261 .50983 Mdot
.35719 .25049 Mdot
.72547 .64114 Mdot
.43147 .25832 Mdot
.6795 .51867 Mdot
.76944 .6117 Mdot
.65475 .48951 Mdot
.62201 .50218 Mdot
.59985 .51389 Mdot
.63563 .37451 Mdot
.37515 .63321 Mdot
.37622 .59731 Mdot
.60556 .69359 Mdot
.72303 .64641 Mdot
.57903 .69525 Mdot
.34544 .4654 Mdot
.24073 .47184 Mdot
.25706 .41576 Mdot
.49805 .30356 Mdot
.63575 .53903 Mdot
.35809 .63851 Mdot
.63195 .4599 Mdot
.64484 .52708 Mdot
.37225 .65409 Mdot
.41093 .63405 Mdot
.39333 .67718 Mdot
.60067 .66823 Mdot
.50064 .31735 Mdot
.59562 .49458 Mdot
.59866 .67234 Mdot
.59205 .46213 Mdot
.4406 .52757 Mdot
.49923 .31968 Mdot
.47381 .31859 Mdot
.53139 .30659 Mdot
.59885 .47895 Mdot
.64916 .52003 Mdot
.36391 .48496 Mdot
.4654 .3339 Mdot
.3528 .50469 Mdot
.40618 .64202 Mdot
.3666 .65701 Mdot
.6319 .45432 Mdot
.71932 .48651 Mdot
.56257 .67246 Mdot
.39683 .6257 Mdot
.27604 .42169 Mdot
.60354 .69646 Mdot
.63667 .5067 Mdot
.4032 .64587 Mdot
.56122 .68905 Mdot
.65634 .27527 Mdot
.42406 .82529 Mdot
.58904 .64999 Mdot
.61271 .48777 Mdot
.72656 .40629 Mdot
.70217 .59257 Mdot
.55916 .64842 Mdot
.35354 .4994 Mdot
.64073 .45049 Mdot
.59826 .77462 Mdot
.55478 .66657 Mdot
.79898 .42718 Mdot
.36923 .64921 Mdot
.62076 .59477 Mdot
.63209 .5625 Mdot
.59491 .22654 Mdot
.55317 .67638 Mdot
.51485 .31308 Mdot
.46294 .32267 Mdot
.61492 .48251 Mdot
.55055 .69134 Mdot
.4088 .48633 Mdot
.36155 .64378 Mdot
.35493 .64339 Mdot
.51337 .34664 Mdot
.39503 .39774 Mdot
.4112 .5993 Mdot
.61042 .41715 Mdot
.38716 .56839 Mdot
.59108 .56871 Mdot
.59182 .19899 Mdot
.29303 .30977 Mdot
.64105 .54647 Mdot
.58193 .6475 Mdot
.34408 .50125 Mdot
.36498 .48261 Mdot
.36828 .4695 Mdot
.37444 .66506 Mdot
.47182 .48895 Mdot
.38823 .60005 Mdot
.35503 .30331 Mdot
.57995 .66309 Mdot
.70888 .62836 Mdot
.67237 .52373 Mdot
.6696 .49332 Mdot
.59963 .44938 Mdot
.60804 .52972 Mdot
.6542 .48798 Mdot
.38869 .47088 Mdot
.37469 .6718 Mdot
.51956 .73683 Mdot
.48516 .33095 Mdot
.20301 .51919 Mdot
.37814 .62021 Mdot
.24492 .40659 Mdot
.5826 .68194 Mdot
.7815 .56794 Mdot
.34727 .63715 Mdot
.38248 .61493 Mdot
.62898 .44049 Mdot
.49544 .28875 Mdot
.5581 .54796 Mdot
.65979 .49334 Mdot
.39717 .6239 Mdot
.42386 .62216 Mdot
.5766 .25608 Mdot
.56628 .44394 Mdot
.60536 .65267 Mdot
.45189 .51196 Mdot
.55317 .68709 Mdot
.67147 .55048 Mdot
.41881 .29252 Mdot
.37388 .63729 Mdot
.39436 .6369 Mdot
.57799 .64383 Mdot
.7349 .50209 Mdot
.52298 .33828 Mdot
.28288 .40657 Mdot
.35247 .49169 Mdot
.66072 .49921 Mdot
.37988 .66504 Mdot
.70584 .56398 Mdot
.46916 .58215 Mdot
.37751 .46726 Mdot
.40075 .6674 Mdot
.62597 .44693 Mdot
.60932 .4851 Mdot
.56713 .66777 Mdot
.51234 .6378 Mdot
.63055 .55947 Mdot
.20049 .63555 Mdot
.42038 .38316 Mdot
.46946 .39838 Mdot
.62695 .46467 Mdot
.50592 .34988 Mdot
.27618 .41539 Mdot
.58516 .65721 Mdot
.59986 .45316 Mdot
.39548 .81721 Mdot
.47317 .35776 Mdot
.38841 .47847 Mdot
.27779 .41497 Mdot
.47375 .49235 Mdot
.64798 .45263 Mdot
.64543 .45771 Mdot
.62682 .49808 Mdot
.41927 .83219 Mdot
.38609 .59255 Mdot
.47209 .30895 Mdot
.59325 .67842 Mdot
.47971 .34419 Mdot
.37122 .60325 Mdot
.5057 .44676 Mdot
.63995 .5098 Mdot
.52782 .29345 Mdot
.51687 .31524 Mdot
.3537 .46718 Mdot
.37108 .45048 Mdot
.3601 .68734 Mdot
.66955 .48391 Mdot
.26878 .41884 Mdot
.49645 .28517 Mdot
.39962 .66407 Mdot
.56894 .66603 Mdot
.38492 .45892 Mdot
.6047 .46835 Mdot
.37655 .64211 Mdot
.59573 .52775 Mdot
.47641 .3202 Mdot
.38196 .616 Mdot
.24498 .4141 Mdot
.56134 .67476 Mdot
.60266 .46815 Mdot
.54591 .73091 Mdot
.28116 .41036 Mdot
.67145 .50875 Mdot
.73395 .43891 Mdot
.57176 .72 Mdot
.31018 .29192 Mdot
.39943 .5993 Mdot
.25681 .4079 Mdot
.48252 .2951 Mdot
.52947 .52204 Mdot
.39509 .64078 Mdot
.65977 .4009 Mdot
.51943 .61128 Mdot
.59691 .49602 Mdot
.50338 .34019 Mdot
.61456 .65544 Mdot
.21734 .66927 Mdot
.67732 .60815 Mdot
.64622 .48047 Mdot
.40834 .64102 Mdot
.56473 .69566 Mdot
.34699 .48979 Mdot
.35918 .2501 Mdot
.58991 .20251 Mdot
.3917 .67546 Mdot
.59429 .5116 Mdot
.49599 .28567 Mdot
.38094 .49401 Mdot
.26606 .34244 Mdot
.41639 .63752 Mdot
.39934 .59345 Mdot
.62957 .50714 Mdot
.59397 .66989 Mdot
.56331 .76711 Mdot
.38142 .59272 Mdot
.38258 .66847 Mdot
.1973 .52358 Mdot
.5964 .65206 Mdot
.6209 .48816 Mdot
.53012 .3737 Mdot
.61652 .44352 Mdot
.20946 .63633 Mdot
.25632 .41135 Mdot
.48388 .3277 Mdot
.62314 .45127 Mdot
.52674 .72966 Mdot
.40004 .64182 Mdot
.45514 .50102 Mdot
.4185 .65538 Mdot
.39298 .4754 Mdot
.37919 .66397 Mdot
.64153 .4612 Mdot
.35249 .44755 Mdot
.56276 .67507 Mdot
.67384 .49333 Mdot
.64706 .52154 Mdot
.53234 .28978 Mdot
.38426 .50458 Mdot
.77504 .48962 Mdot
.40474 .4623 Mdot
.34474 .49348 Mdot
.50313 .27255 Mdot
.61728 .4812 Mdot
.39289 .62288 Mdot
.40534 .58615 Mdot
.59265 .47535 Mdot
.42151 .29415 Mdot
.5186 .34165 Mdot
.34355 .67909 Mdot
.50034 .85437 Mdot
.5763 .44088 Mdot
.26354 .42156 Mdot
.75436 .53561 Mdot
.3582 .45808 Mdot
.60467 .481 Mdot
.4951 .29976 Mdot
.38685 .6704 Mdot
.41029 .5966 Mdot
.61099 .44065 Mdot
.38552 .49523 Mdot
.56715 .70069 Mdot
.4073 .60054 Mdot
.46554 .57915 Mdot
.63769 .49888 Mdot
.35736 .28889 Mdot
.40634 .60439 Mdot
.15376 .54687 Mdot
.52297 .73184 Mdot
.49448 .34174 Mdot
.63797 .52977 Mdot
.4945 .35926 Mdot
.59131 .68411 Mdot
.40081 .56696 Mdot
.38724 .4957 Mdot
.62915 .40657 Mdot
.82139 .55229 Mdot
.37419 .62915 Mdot
.49569 .31154 Mdot
.59873 .48357 Mdot
.62982 .40885 Mdot
.66299 .47396 Mdot
.58699 .59079 Mdot
.55967 .72748 Mdot
.38038 .45165 Mdot
.34652 .47692 Mdot
.64414 .53394 Mdot
.60272 .67935 Mdot
.38878 .58339 Mdot
.37094 .6507 Mdot
.57275 .14382 Mdot
.24336 .41195 Mdot
.69749 .70549 Mdot
.60092 .47483 Mdot
.38899 .6725 Mdot
.75296 .4221 Mdot
.37346 .51226 Mdot
.58201 .49506 Mdot
.36467 .66862 Mdot
.22822 .60578 Mdot
.44432 .52678 Mdot
.64168 .49063 Mdot
.58006 .44444 Mdot
.34974 .48759 Mdot
.42562 .54378 Mdot
.38854 .60115 Mdot
.58627 .47105 Mdot
.39465 .4505 Mdot
.1864 .54122 Mdot
.82955 .52215 Mdot
.50067 .31799 Mdot
.42157 .62693 Mdot
.39197 .47449 Mdot
.56615 .51447 Mdot
.57252 .69925 Mdot
.3927 .6621 Mdot
.36218 .6321 Mdot
.62615 .5223 Mdot
.6904 .49234 Mdot
.57909 .43676 Mdot
.49183 .32685 Mdot
.36259 .49022 Mdot
.66673 .52429 Mdot
.40847 .3963 Mdot
.60108 .52416 Mdot
.36608 .49227 Mdot
.19994 .27917 Mdot
.64592 .44469 Mdot
.65746 .4706 Mdot
.62494 .70158 Mdot
.53081 .32912 Mdot
.48801 .34993 Mdot
.40882 .37529 Mdot
.60101 .47416 Mdot
.48292 .64528 Mdot
.50171 .31397 Mdot
.51633 .3415 Mdot
.45387 .69931 Mdot
.62024 .51635 Mdot
.39839 .5532 Mdot
.37387 .49248 Mdot
.39011 .46935 Mdot
.47561 .33176 Mdot
.58631 .53878 Mdot
.35019 .5092 Mdot
.536 .22146 Mdot
.37661 .61787 Mdot
.4186 .29213 Mdot
.48234 .30339 Mdot
.50388 .62045 Mdot
.39091 .49879 Mdot
.1761 .64323 Mdot
.52198 .53657 Mdot
.58696 .50329 Mdot
.6063 .48861 Mdot
.56991 .68804 Mdot
.69707 .45612 Mdot
.25157 .3952 Mdot
.36639 .47636 Mdot
.43355 .77515 Mdot
.50057 .32758 Mdot
.66026 .4746 Mdot
.77797 .5518 Mdot
.28965 .34156 Mdot
.38102 .248 Mdot
.52614 .32198 Mdot
.50578 .33576 Mdot
.37871 .60541 Mdot
.36805 .62684 Mdot
.62928 .48808 Mdot
.3628 .4709 Mdot
.4682 .30609 Mdot
.36022 .49522 Mdot
.3727 .63749 Mdot
.38514 .61751 Mdot
.25031 .41084 Mdot
.57253 .48493 Mdot
.36689 .65142 Mdot
.19219 .56068 Mdot
.41148 .39867 Mdot
.53966 .29768 Mdot
.79056 .68422 Mdot
.26011 .34337 Mdot
.62801 .71758 Mdot
.58644 .70541 Mdot
.23455 .40444 Mdot
.40516 .47784 Mdot
.63794 .53503 Mdot
.61812 .4575 Mdot
.26633 .39884 Mdot
.39886 .4832 Mdot
.57852 .68588 Mdot
.39705 .49471 Mdot
.58626 .66132 Mdot
.36381 .60797 Mdot
.68254 .50894 Mdot
.65659 .4595 Mdot
.38211 .46596 Mdot
.39296 .60987 Mdot
.36347 .64784 Mdot
.6006 .69781 Mdot
.77438 .57585 Mdot
.37636 .64595 Mdot
.48087 .305 Mdot
.74342 .33972 Mdot
.26531 .39557 Mdot
.64706 .46253 Mdot
.78348 .55756 Mdot
.57873 .24461 Mdot
.59581 .50149 Mdot
.27877 .41429 Mdot
.59341 .15311 Mdot
.67864 .51093 Mdot
.57944 .16619 Mdot
.25336 .40538 Mdot
.52949 .34179 Mdot
.40414 .61673 Mdot
.25414 .39302 Mdot
.5742 .52928 Mdot
.57957 .63073 Mdot
.69377 .49757 Mdot
.52569 .31282 Mdot
.53648 .31747 Mdot
.43037 .34493 Mdot
.21285 .63949 Mdot
.58623 .65375 Mdot
.5756 .67925 Mdot
.3926 .64351 Mdot
.25119 .43816 Mdot
.65577 .55271 Mdot
.57323 .67966 Mdot
.4831 .79016 Mdot
.61338 .52881 Mdot
.72963 .67372 Mdot
.54703 .58079 Mdot
.50775 .34909 Mdot
.46488 .27233 Mdot
.39702 .64239 Mdot
.49601 .31209 Mdot
.48816 .41644 Mdot
.59997 .4494 Mdot
.49921 .3227 Mdot
.36856 .49536 Mdot
.28883 .60773 Mdot
.50424 .3582 Mdot
.4608 .54222 Mdot
.37421 .49055 Mdot
.56948 .71821 Mdot
.65331 .64904 Mdot
.59812 .8617 Mdot
.36524 .47478 Mdot
.40063 .62047 Mdot
.3657 .65183 Mdot
.37772 .65107 Mdot
.52341 .30811 Mdot
.41473 .62331 Mdot
.4865 .32288 Mdot
.38031 .70798 Mdot
.77866 .59518 Mdot
.57261 .6664 Mdot
.39378 .42817 Mdot
.51429 .32495 Mdot
.37109 .3342 Mdot
.80563 .65329 Mdot
.61346 .49003 Mdot
.3998 .45604 Mdot
.57488 .64502 Mdot
.20655 .42315 Mdot
.57345 .69014 Mdot
.4017 .61639 Mdot
.41789 .29145 Mdot
.6425 .47069 Mdot
.58861 .3884 Mdot
.56154 .66489 Mdot
.5253 .31613 Mdot
.67219 .50484 Mdot
.36854 .69317 Mdot
.58342 .6988 Mdot
.57927 .70515 Mdot
.65498 .485 Mdot
.51235 .3532 Mdot
.38916 .61778 Mdot
.40123 .46945 Mdot
.60397 .70896 Mdot
.57537 .51913 Mdot
.60151 .49731 Mdot
.58298 .46854 Mdot
.45413 .47134 Mdot
.57648 .77198 Mdot
.37095 .48289 Mdot
.73054 .57625 Mdot
.36728 .63631 Mdot
.65965 .61162 Mdot
.36233 .36524 Mdot
.39139 .42897 Mdot
.25541 .41047 Mdot
.25706 .4132 Mdot
.64631 .48908 Mdot
.55843 .7829 Mdot
.43489 .22116 Mdot
.40952 .45432 Mdot
.27342 .39935 Mdot
.36337 .64689 Mdot
.46546 .34365 Mdot
.45012 .37006 Mdot
.68575 .48518 Mdot
.37363 .45132 Mdot
.37241 .64432 Mdot
.45265 .8085 Mdot
.58084 .66548 Mdot
.39981 .34602 Mdot
.64471 .50988 Mdot
.64989 .47603 Mdot
.38078 .48408 Mdot
.36444 .48494 Mdot
.3519 .27027 Mdot
.4282 .37302 Mdot
.30021 .68499 Mdot
.39078 .54848 Mdot
.48422 .81587 Mdot
.46198 .36113 Mdot
.49675 .29683 Mdot
.24805 .41257 Mdot
.3422 .49117 Mdot
.64989 .46046 Mdot
.53175 .33795 Mdot
.38618 .24514 Mdot
.4951 .27016 Mdot
.72842 .66732 Mdot
.48758 .64442 Mdot
.6574 .51032 Mdot
.49238 .28992 Mdot
.49663 .31468 Mdot
.47453 .34054 Mdot
.2793 .40434 Mdot
.62292 .46643 Mdot
.60378 .49651 Mdot
.67382 .51416 Mdot
.67876 .43189 Mdot
.64047 .49807 Mdot
.36366 .37662 Mdot
.36603 .41032 Mdot
.42181 .75743 Mdot
.59346 .50146 Mdot
.39644 .48767 Mdot
.63259 .53975 Mdot
.60215 .68563 Mdot
.59316 .51003 Mdot
.71465 .69261 Mdot
.37443 .47243 Mdot
.7336 .49188 Mdot
.37533 .56055 Mdot
.64511 .51093 Mdot
.55815 .68691 Mdot
.57192 .77185 Mdot
.79881 .53225 Mdot
.19645 .53125 Mdot
.47967 .3065 Mdot
.35276 .6713 Mdot
.39866 .50108 Mdot
.39257 .62485 Mdot
.58514 .49024 Mdot
.25808 .42015 Mdot
.22188 .3544 Mdot
.4999 .60239 Mdot
.64334 .45477 Mdot
.65923 .56651 Mdot
.49471 .34645 Mdot
.4046 .63801 Mdot
.45166 .33966 Mdot
.62395 .50083 Mdot
.59356 .68369 Mdot
.59693 .68092 Mdot
.44848 .39087 Mdot
.38661 .76872 Mdot
.54126 .53559 Mdot
.37861 .48445 Mdot
.41318 .60094 Mdot
.55335 .6749 Mdot
.49544 .22852 Mdot
.40932 .48736 Mdot
.35846 .45793 Mdot
.38032 .50477 Mdot
.66115 .50614 Mdot
.24892 .40425 Mdot
.441 .78957 Mdot
.26916 .39246 Mdot
.6472 .51356 Mdot
.36563 .62249 Mdot
.25261 .3931 Mdot
.574 .69333 Mdot
.3437 .48061 Mdot
.36929 .63006 Mdot
.64932 .49564 Mdot
.50524 .31715 Mdot
.76614 .5506 Mdot
.64998 .7488 Mdot
.38358 .72078 Mdot
.38929 .72247 Mdot
.52717 .30325 Mdot
.27713 .72589 Mdot
.36513 .42355 Mdot
.60875 .25062 Mdot
.60177 .63509 Mdot
.59184 .47733 Mdot
.73524 .27059 Mdot
.39187 .60089 Mdot
.39053 .65451 Mdot
.63753 .49187 Mdot
.40833 .65066 Mdot
.66126 .47436 Mdot
.37925 .60176 Mdot
.25527 .66146 Mdot
.68101 .48201 Mdot
.39234 .65277 Mdot
.65735 .55364 Mdot
.62923 .51162 Mdot
.49884 .34928 Mdot
.39212 .66462 Mdot
.58777 .50942 Mdot
.20559 .36061 Mdot
.36664 .45973 Mdot
.27751 .40082 Mdot
.36137 .41758 Mdot
.39129 .50152 Mdot
.49563 .33619 Mdot
.68582 .5011 Mdot
.56482 .66907 Mdot
.51225 .31413 Mdot
.36633 .68705 Mdot
.56436 .65845 Mdot
.40148 .36962 Mdot
.47706 .31183 Mdot
.26009 .3967 Mdot
.56222 .6696 Mdot
.69451 .47518 Mdot
.3781 .65981 Mdot
.66043 .75498 Mdot
.27008 .39326 Mdot
.63702 .46458 Mdot
.39415 .57461 Mdot
.39516 .49639 Mdot
.63121 .48213 Mdot
.40909 .64116 Mdot
.28032 .40829 Mdot
.66071 .51552 Mdot
.66871 .51062 Mdot
.46785 .38683 Mdot
.40658 .25773 Mdot
.56729 .67043 Mdot
.5192 .27904 Mdot
.62204 .49119 Mdot
.60333 .67727 Mdot
.27743 .50938 Mdot
.63443 .54368 Mdot
.50285 .36108 Mdot
.56652 .40508 Mdot
.36729 .62654 Mdot
.35099 .502 Mdot
.41689 .60512 Mdot
.57894 .70614 Mdot
.85621 .43947 Mdot
.24646 .40382 Mdot
.60005 .55499 Mdot
.59429 .45365 Mdot
.42246 .59408 Mdot
.49555 .31957 Mdot
.28862 .64703 Mdot
.60215 .47039 Mdot
.67914 .55867 Mdot
.6538 .47417 Mdot
.51864 .72892 Mdot
.52062 .3395 Mdot
.65092 .46714 Mdot
.71433 .52755 Mdot
.68216 .51752 Mdot
.56092 .69352 Mdot
.68948 .63456 Mdot
.62709 .53986 Mdot
.08829 .49965 Mdot
.27857 .41857 Mdot
.37349 .65403 Mdot
.44557 .57914 Mdot
.33359 .53784 Mdot
.59621 .1983 Mdot
.48883 .32468 Mdot
.54833 .50632 Mdot
.39086 .6207 Mdot
.81349 .49364 Mdot
.25337 .70451 Mdot
.63382 .51279 Mdot
.6238 .44766 Mdot
.40172 .61646 Mdot
.39153 .6705 Mdot
.25863 .41883 Mdot
.59049 .49977 Mdot
.64377 .56593 Mdot
.41584 .6453 Mdot
.64987 .50179 Mdot
.57218 .3142 Mdot
.38926 .45558 Mdot
.4811 .34263 Mdot
.34712 .49037 Mdot
.36342 .45562 Mdot
.69564 .28075 Mdot
.42045 .38264 Mdot
.36483 .48994 Mdot
.41466 .48097 Mdot
.71838 .69315 Mdot
.57926 .40352 Mdot
.55638 .68934 Mdot
.34674 .74111 Mdot
.38504 .64819 Mdot
.62071 .46728 Mdot
.51497 .29404 Mdot
.61879 .23361 Mdot
.25787 .57812 Mdot
.40852 .2982 Mdot
.60811 .49454 Mdot
.39392 .64691 Mdot
.27969 .4019 Mdot
.68328 .48532 Mdot
.66448 .60814 Mdot
.64766 .4777 Mdot
.3614 .64887 Mdot
.7271 .30037 Mdot
.58017 .3934 Mdot
.3999 .55617 Mdot
.54797 .30353 Mdot
.66752 .52594 Mdot
.48038 .31329 Mdot
.39387 .48602 Mdot
.60133 .67107 Mdot
.56864 .67788 Mdot
.67097 .50019 Mdot
.43846 .29151 Mdot
.56214 .59793 Mdot
.62727 .51014 Mdot
.62458 .52021 Mdot
.25513 .40724 Mdot
.62494 .51959 Mdot
.59264 .45753 Mdot
.64891 .53433 Mdot
.61544 .54367 Mdot
.34435 .49315 Mdot
.71834 .42448 Mdot
.6097 .53698 Mdot
.56248 .45772 Mdot
.38179 .45447 Mdot
.57397 .54443 Mdot
.35302 .47195 Mdot
.34529 .76543 Mdot
.35255 .4828 Mdot
.56915 .67477 Mdot
.38426 .5807 Mdot
.58824 .57163 Mdot
.4713 .30108 Mdot
.36561 .44913 Mdot
.58669 .67242 Mdot
.36667 .47237 Mdot
.39508 .5887 Mdot
.75756 .70564 Mdot
.4904 .27299 Mdot
.43457 .5362 Mdot
.5448 .56397 Mdot
.35677 .28695 Mdot
.37482 .61582 Mdot
.51056 .3465 Mdot
.57407 .38862 Mdot
.65224 .53173 Mdot
.56337 .67874 Mdot
.64739 .48761 Mdot
.34432 .48979 Mdot
.38839 .64922 Mdot
.42115 .7169 Mdot
.56637 .6734 Mdot
.83841 .55382 Mdot
.36001 .62981 Mdot
.65981 .44987 Mdot
.37623 .4505 Mdot
.79447 .67648 Mdot
.35125 .48218 Mdot
.78307 .58742 Mdot
.52112 .36731 Mdot
.74957 .31982 Mdot
.51069 .33441 Mdot
.38885 .23355 Mdot
.33807 .80711 Mdot
.25642 .69566 Mdot
.50828 .3072 Mdot
.34033 .65549 Mdot
.64541 .50653 Mdot
.61116 .53296 Mdot
.59536 .42253 Mdot
.53498 .28716 Mdot
.62619 .49388 Mdot
.25429 .39505 Mdot
.4251 .40322 Mdot
.52619 .76987 Mdot
.34937 .66301 Mdot
.66037 .47087 Mdot
.37407 .4543 Mdot
.36883 .51643 Mdot
.25788 .39148 Mdot
.40765 .48407 Mdot
.62216 .51098 Mdot
.5139 .32806 Mdot
.5117 .59785 Mdot
.58664 .69129 Mdot
.1668 .4681 Mdot
.60395 .70585 Mdot
.34937 .67104 Mdot
.61501 .4262 Mdot
.38458 .61699 Mdot
.79948 .31421 Mdot
.62661 .53555 Mdot
.50085 .31108 Mdot
.66723 .50831 Mdot
.65658 .53171 Mdot
.60088 .52708 Mdot
.417 .62916 Mdot
.44551 .59032 Mdot
.65209 .50035 Mdot
.3871 .49707 Mdot
.41855 .73079 Mdot
.68755 .4771 Mdot
.33336 .68161 Mdot
.71672 .66452 Mdot
.35961 .30159 Mdot
.54383 .30302 Mdot
.40264 .62827 Mdot
.50261 .33095 Mdot
.52753 .27654 Mdot
.49545 .33613 Mdot
.41545 .77198 Mdot
.6006 .58752 Mdot
.54992 .15749 Mdot
.74847 .37567 Mdot
.62524 .24513 Mdot
.5247 .29222 Mdot
.29316 .54678 Mdot
.49856 .29854 Mdot
.49048 .32995 Mdot
.36702 .1512 Mdot
.50702 .29634 Mdot
.62994 .45463 Mdot
.64634 .44356 Mdot
.31994 .36721 Mdot
.73618 .6786 Mdot
.59332 .50737 Mdot
.62696 .4912 Mdot
.59201 .65834 Mdot
.72175 .48244 Mdot
.25499 .38793 Mdot
.41054 .33579 Mdot
.22936 .39006 Mdot
.65446 .48576 Mdot
.63288 .49344 Mdot
.58832 .53614 Mdot
.34468 .81637 Mdot
.60922 .22257 Mdot
.53541 .31929 Mdot
.62944 .57549 Mdot
.17963 .57756 Mdot
.6433 .44584 Mdot
.66318 .46491 Mdot
.65296 .52202 Mdot
.39221 .62191 Mdot
.46556 .34743 Mdot
.67887 .55634 Mdot
.33829 .32224 Mdot
.63921 .50767 Mdot
.35745 .42722 Mdot
.58624 .72516 Mdot
.64004 .45988 Mdot
.48007 .34599 Mdot
.60324 .52027 Mdot
.48781 .29576 Mdot
.47763 .33666 Mdot
.57502 .51133 Mdot
.42568 .78517 Mdot
.47807 .35244 Mdot
.65021 .51657 Mdot
.39533 .61456 Mdot
.21982 .66888 Mdot
.63638 .46297 Mdot
.59054 .66029 Mdot
.60276 .48381 Mdot
.56223 .69406 Mdot
.6368 .52013 Mdot
.27374 .39443 Mdot
.60259 .28999 Mdot
.39335 .63862 Mdot
.6137 .6963 Mdot
.40693 .6568 Mdot
.50937 .40148 Mdot
.52259 .3533 Mdot
.25497 .38689 Mdot
.56047 .18816 Mdot
.25517 .406 Mdot
.76456 .54538 Mdot
.24429 .53744 Mdot
.37369 .45843 Mdot
.47028 .31933 Mdot
.73558 .55964 Mdot
.32997 .67321 Mdot
.38337 .68148 Mdot
.36687 .67693 Mdot
.83217 .38513 Mdot
.66939 .20698 Mdot
.65725 .49812 Mdot
.65433 .77119 Mdot
.63581 .34483 Mdot
.65199 .54496 Mdot
.6747 .53415 Mdot
.35968 .64672 Mdot
.67415 .5212 Mdot
.47895 .50723 Mdot
.37771 .63331 Mdot
.58244 .67584 Mdot
.48318 .32504 Mdot
.57161 .70051 Mdot
.30873 .68183 Mdot
.40775 .40641 Mdot
.36928 .63603 Mdot
.62605 .54576 Mdot
.66497 .49713 Mdot
.48024 .30039 Mdot
.55066 .37396 Mdot
.48496 .34487 Mdot
.57051 .64938 Mdot
.38425 .63725 Mdot
.59306 .22147 Mdot
.6056 .47638 Mdot
.51843 .31712 Mdot
.33583 .51708 Mdot
.60875 .48501 Mdot
.386 .4697 Mdot
.60686 .496 Mdot
.51281 .30439 Mdot
.62586 .51962 Mdot
.51221 .32976 Mdot
.3901 .60404 Mdot
.63117 .44518 Mdot
.6331 .49089 Mdot
.79522 .50974 Mdot
.57948 .68661 Mdot
.52482 .35046 Mdot
.48467 .49324 Mdot
.6248 .44284 Mdot
.65391 .60991 Mdot
.68159 .50907 Mdot
.54549 .4592 Mdot
.65244 .55701 Mdot
.25423 .39614 Mdot
.58191 .50703 Mdot
.63805 .46376 Mdot
.68344 .40459 Mdot
.74145 .40244 Mdot
.45118 .30536 Mdot
.35315 .45105 Mdot
.48054 .34599 Mdot
.36826 .65861 Mdot
.37784 .67129 Mdot
.41152 .61141 Mdot
.75821 .6528 Mdot
.57975 .53209 Mdot
.64064 .47037 Mdot
.37526 .44859 Mdot
.57503 .67633 Mdot
.52345 .31623 Mdot
.57432 .67023 Mdot
.41219 .33164 Mdot
.56516 .6544 Mdot
.24947 .39706 Mdot
.5239 .73235 Mdot
.54467 .23769 Mdot
.58326 .65436 Mdot
.48436 .34478 Mdot
.49 .63668 Mdot
.59016 .48336 Mdot
.21182 .59029 Mdot
.59409 .68231 Mdot
.84475 .43687 Mdot
.68012 .49695 Mdot
.4686 .52223 Mdot
.35904 .4653 Mdot
.56577 .69389 Mdot
.38491 .50504 Mdot
.60768 .52721 Mdot
.31339 .28747 Mdot
.49681 .30745 Mdot
.35817 .44359 Mdot
.58637 .51458 Mdot
.57002 .69911 Mdot
.36733 .64405 Mdot
.50938 .49286 Mdot
.39504 .47652 Mdot
.7902 .53469 Mdot
.67703 .60815 Mdot
.38302 .63581 Mdot
.45911 .18838 Mdot
.36552 .50693 Mdot
.63842 .54802 Mdot
.54467 .51669 Mdot
.60316 .5122 Mdot
.36783 .66244 Mdot
.40369 .64369 Mdot
.33357 .39735 Mdot
.66682 .50492 Mdot
.68084 .49991 Mdot
.4606 .34666 Mdot
.37587 .62682 Mdot
.50475 .34315 Mdot
.46991 .31186 Mdot
.39958 .61551 Mdot
.49629 .34264 Mdot
.56058 .66702 Mdot
.42838 .40504 Mdot
.36265 .50549 Mdot
.38975 .48736 Mdot
.36634 .64922 Mdot
.38864 .58761 Mdot
.38258 .61751 Mdot
.60849 .49762 Mdot
.5268 .33616 Mdot
.62838 .52908 Mdot
.62628 .54047 Mdot
.52381 .36828 Mdot
.52777 .31043 Mdot
.62173 .53015 Mdot
.49663 .6428 Mdot
.60963 .67132 Mdot
.39409 .65126 Mdot
.36087 .4941 Mdot
.80547 .47925 Mdot
.38097 .44952 Mdot
.6703 .4803 Mdot
.22623 .60637 Mdot
.52515 .31385 Mdot
.57245 .6901 Mdot
.54655 .68037 Mdot
.56616 .68142 Mdot
.3557 .44375 Mdot
.4671 .32455 Mdot
.40191 .37268 Mdot
.6682 .47941 Mdot
.45372 .46876 Mdot
.73543 .56764 Mdot
.35779 .35302 Mdot
.36557 .49289 Mdot
.61641 .4889 Mdot
.25493 .40405 Mdot
.57163 .25328 Mdot
.64332 .47766 Mdot
.58273 .49575 Mdot
.48854 .69551 Mdot
.56505 .45319 Mdot
.53666 .29573 Mdot
.4333 .3531 Mdot
.6036 .45071 Mdot
.44379 .34098 Mdot
.49375 .12094 Mdot
.67913 .49902 Mdot
.63166 .50009 Mdot
.61953 .46119 Mdot
.63637 .53439 Mdot
.53643 .35321 Mdot
.50703 .65412 Mdot
.36939 .45144 Mdot
.43708 .42498 Mdot
.37039 .50483 Mdot
.3851 .65932 Mdot
.47398 .52348 Mdot
.47118 .32712 Mdot
.56685 .68393 Mdot
.73075 .73238 Mdot
.4199 .3231 Mdot
.37854 .60612 Mdot
.6381 .22891 Mdot
.58962 .69022 Mdot
.59206 .4786 Mdot
.6073 .68882 Mdot
.38401 .67487 Mdot
.38126 .49557 Mdot
.63739 .44197 Mdot
.51385 .29045 Mdot
.50264 .35868 Mdot
.61661 .49138 Mdot
.19149 .61764 Mdot
.39073 .5011 Mdot
.31491 .44523 Mdot
.66 .50775 Mdot
.58283 .49397 Mdot
.48231 .33686 Mdot
.40186 .64127 Mdot
.23898 .50208 Mdot
.58512 .68128 Mdot
.60483 .54177 Mdot
.60432 .52376 Mdot
.41632 .34673 Mdot
.34346 .47351 Mdot
.2728 .41304 Mdot
.6627 .5071 Mdot
.41885 .37955 Mdot
.6629 .50936 Mdot
.71096 .48168 Mdot
.38855 .61288 Mdot
.63077 .436 Mdot
.60847 .45299 Mdot
.74036 .53426 Mdot
.36791 .50903 Mdot
.49862 .31706 Mdot
.48932 .36632 Mdot
.27411 .41764 Mdot
.38019 .46629 Mdot
.61378 .5271 Mdot
.3479 .49803 Mdot
.6039 .52932 Mdot
.64883 .49874 Mdot
.36635 .49354 Mdot
.50384 .34342 Mdot
.28912 .63742 Mdot
.70352 .41928 Mdot
.65338 .5264 Mdot
.59893 .49301 Mdot
.7458 .66473 Mdot
.51263 .19347 Mdot
.60428 .45977 Mdot
.52953 .32415 Mdot
.61109 .48383 Mdot
.39142 .47936 Mdot
.56709 .65079 Mdot
.50482 .31156 Mdot
.37798 .59241 Mdot
.39333 .60339 Mdot
.37545 .55886 Mdot
.24731 .40058 Mdot
.59621 .47702 Mdot
.48417 .27333 Mdot
.52453 .30318 Mdot
.21586 .39409 Mdot
.37429 .65553 Mdot
.55473 .67487 Mdot
.6658 .51656 Mdot
.5101 .50163 Mdot
.36003 .45372 Mdot
.08897 .50252 Mdot
.39935 .38077 Mdot
.58542 .71107 Mdot
.43461 .25743 Mdot
.2584 .40064 Mdot
.64197 .45279 Mdot
.60283 .68711 Mdot
.40062 .59803 Mdot
.61175 .5324 Mdot
.56464 .48039 Mdot
.33412 .62011 Mdot
.34932 .64743 Mdot
.35038 .50218 Mdot
.39124 .59253 Mdot
.58422 .70868 Mdot
.25037 .39616 Mdot
.50461 .35357 Mdot
.64362 .46634 Mdot
.63047 .57937 Mdot
.37906 .65381 Mdot
.2793 .39825 Mdot
.65722 .51115 Mdot
.49524 .3578 Mdot
.41108 .63363 Mdot
.65738 .48397 Mdot
.59615 .24322 Mdot
.54986 .34826 Mdot
.38329 .64477 Mdot
.59226 .45441 Mdot
.55468 .40326 Mdot
.36719 .60632 Mdot
.35952 .64133 Mdot
.62669 .49381 Mdot
.5613 .66979 Mdot
.64187 .44938 Mdot
.35527 .47272 Mdot
.44564 .59061 Mdot
.38661 .47477 Mdot
.71508 .58497 Mdot
.59145 .44521 Mdot
.37104 .26561 Mdot
.49179 .28799 Mdot
.55837 .64307 Mdot
.69239 .40065 Mdot
.58578 .48005 Mdot
.32257 .74985 Mdot
.50234 .61811 Mdot
.19106 .44376 Mdot
.46688 .83649 Mdot
.59038 .66828 Mdot
.36808 .46913 Mdot
.63062 .49963 Mdot
.39044 .52459 Mdot
.57984 .65581 Mdot
.72575 .57807 Mdot
.59189 .45589 Mdot
.51854 .34001 Mdot
.64495 .50827 Mdot
.48065 .30497 Mdot
.60663 .48369 Mdot
.58177 .54121 Mdot
.60612 .65185 Mdot
.78455 .58304 Mdot
.59105 .48468 Mdot
.74769 .72224 Mdot
.49904 .49335 Mdot
.59264 .68 Mdot
.64254 .52563 Mdot
.27072 .40535 Mdot
.39845 .49273 Mdot
.59872 .76614 Mdot
.3883 .61871 Mdot
.36084 .48337 Mdot
.48312 .33298 Mdot
.40679 .58522 Mdot
.27891 .41647 Mdot
.58947 .57641 Mdot
.57749 .70336 Mdot
.3705 .46015 Mdot
.63889 .46225 Mdot
.67073 .47963 Mdot
.52557 .72725 Mdot
.35655 .20617 Mdot
.46113 .32878 Mdot
.82803 .54897 Mdot
.53408 .29711 Mdot
.57566 .68293 Mdot
.38641 .61336 Mdot
.62399 .45164 Mdot
.63966 .48261 Mdot
.37792 .66693 Mdot
.53126 .33092 Mdot
.39016 .56983 Mdot
.67816 .26153 Mdot
.41676 .65596 Mdot
.7435 .61482 Mdot
.50436 .30628 Mdot
.74939 .60927 Mdot
.57803 .70923 Mdot
.424 .79422 Mdot
.6561 .70073 Mdot
.36317 .4582 Mdot
.73712 .61998 Mdot
.52157 .3108 Mdot
.65998 .49533 Mdot
.26274 .39691 Mdot
.25215 .41177 Mdot
.47967 .32144 Mdot
.40306 .62048 Mdot
.57153 .69857 Mdot
.63629 .50062 Mdot
.38012 .3309 Mdot
.27471 .35223 Mdot
.41434 .60359 Mdot
.71173 .52686 Mdot
.3857 .50274 Mdot
.60333 .49036 Mdot
.5964 .66717 Mdot
.36701 .4823 Mdot
.2458 .41734 Mdot
.42989 .40453 Mdot
.66754 .5158 Mdot
.45294 .39135 Mdot
.37422 .46368 Mdot
.47349 .18071 Mdot
.63428 .48829 Mdot
.36581 .50713 Mdot
.55618 .45176 Mdot
.31072 .30093 Mdot
.53206 .58257 Mdot
.26954 .71042 Mdot
.35423 .66259 Mdot
.39697 .60451 Mdot
.26667 .29084 Mdot
.60081 .6346 Mdot
.37878 .45528 Mdot
.25251 .39431 Mdot
.67124 .65681 Mdot
.38059 .50763 Mdot
.66546 .46598 Mdot
.68142 .50803 Mdot
.68176 .27076 Mdot
.48857 .51047 Mdot
.28424 .40454 Mdot
.53542 .45625 Mdot
.61447 .51358 Mdot
.67503 .44905 Mdot
.62602 .48171 Mdot
.53636 .31774 Mdot
.38613 .50794 Mdot
.74745 .74118 Mdot
.37565 .51285 Mdot
.38601 .33293 Mdot
.38539 .6483 Mdot
.41791 .61387 Mdot
.64241 .46102 Mdot
.40905 .23266 Mdot
.57902 .77825 Mdot
.59823 .48694 Mdot
.56078 .71272 Mdot
.68802 .6043 Mdot
.68724 .47334 Mdot
.47483 .36277 Mdot
.69091 .54991 Mdot
.54143 .33656 Mdot
.3681 .48677 Mdot
.58956 .66546 Mdot
.60033 .65154 Mdot
.36447 .46577 Mdot
.63776 .47077 Mdot
.54964 .70428 Mdot
.65094 .47462 Mdot
.66125 .50053 Mdot
.40549 .33325 Mdot
.55742 .65573 Mdot
.3802 .61744 Mdot
.56779 .67677 Mdot
.49174 .32937 Mdot
.28459 .19384 Mdot
.57696 .66324 Mdot
.54285 .40769 Mdot
.4662 .56474 Mdot
.74055 .61549 Mdot
.50059 .3577 Mdot
.58061 .64997 Mdot
.35914 .51015 Mdot
.1869 .44339 Mdot
.48805 .19244 Mdot
.39824 .45875 Mdot
.63954 .48666 Mdot
.47139 .31907 Mdot
.52878 .30355 Mdot
.41093 .4701 Mdot
.50947 .34961 Mdot
.63694 .42811 Mdot
.66477 .5117 Mdot
.37864 .45534 Mdot
.30923 .37008 Mdot
.38655 .50832 Mdot
.51502 .46571 Mdot
.6508 .52042 Mdot
.50284 .31153 Mdot
.66074 .43172 Mdot
.45618 .33097 Mdot
.25123 .41409 Mdot
.59774 .52388 Mdot
.56765 .68949 Mdot
.4716 .49032 Mdot
.3851 .6447 Mdot
.23036 .61069 Mdot
.47494 .31403 Mdot
.33738 .5124 Mdot
.4978 .34936 Mdot
.49349 .28325 Mdot
.40864 .48411 Mdot
.49189 .31845 Mdot
.63316 .50057 Mdot
.42197 .54885 Mdot
.49019 .29731 Mdot
.38008 .48 Mdot
.57331 .69738 Mdot
.49939 .34327 Mdot
.41174 .58584 Mdot
.6638 .49223 Mdot
.36952 .62102 Mdot
.55147 .68954 Mdot
.47049 .32617 Mdot
.57799 .64965 Mdot
.37731 .65517 Mdot
.58525 .70269 Mdot
.39992 .71332 Mdot
.34113 .49717 Mdot
.40321 .30251 Mdot
.62384 .39706 Mdot
.51145 .29029 Mdot
.38091 .68268 Mdot
.61395 .45254 Mdot
.66826 .49909 Mdot
.59452 .70364 Mdot
.52679 .30141 Mdot
.21757 .66215 Mdot
.54227 .45986 Mdot
.33018 .40808 Mdot
.34132 .48209 Mdot
.8256 .50882 Mdot
.3949 .39718 Mdot
.1848 .47247 Mdot
.67939 .53952 Mdot
.25884 .40003 Mdot
.6536 .47271 Mdot
.79979 .53153 Mdot
.56434 .65266 Mdot
.28195 .57435 Mdot
.65679 .552 Mdot
.38344 .62537 Mdot
.60973 .47568 Mdot
.6499 .77074 Mdot
.70162 .52746 Mdot
.58965 .65599 Mdot
.34338 .45224 Mdot
.47064 .30207 Mdot
.58781 .69048 Mdot
.38786 .60205 Mdot
.6976 .65113 Mdot
.59753 .4482 Mdot
.6167 .51003 Mdot
.38121 .681 Mdot
.51592 .3437 Mdot
.38207 .66 Mdot
.36347 .5057 Mdot
.57731 .66655 Mdot
.64475 .53264 Mdot
.65745 .43817 Mdot
.42527 .63378 Mdot
.36785 .51535 Mdot
.39911 .58507 Mdot
.34467 .48124 Mdot
.2588 .39914 Mdot
.59393 .48137 Mdot
.39107 .67519 Mdot
.6726 .5292 Mdot
.75303 .43584 Mdot
.40939 .31699 Mdot
.70467 .38629 Mdot
.37844 .6178 Mdot
.73061 .65012 Mdot
.37508 .46973 Mdot
.34746 .47827 Mdot
.77089 .3662 Mdot
.56518 .7773 Mdot
.48379 .64441 Mdot
.74937 .70855 Mdot
.36244 .50503 Mdot
.38351 .47423 Mdot
.40311 .60108 Mdot
.48748 .31926 Mdot
.54392 .35183 Mdot
.42208 .63167 Mdot
.78255 .55791 Mdot
.52324 .31601 Mdot
.30749 .74029 Mdot
.35827 .62585 Mdot
.6488 .55682 Mdot
.28358 .39829 Mdot
.5953 .67148 Mdot
.77887 .54928 Mdot
.71716 .73181 Mdot
.63735 .45357 Mdot
.62839 .19967 Mdot
.39993 .63023 Mdot
.41348 .53821 Mdot
.37005 .77072 Mdot
.58262 .47974 Mdot
.61473 .4701 Mdot
.6314 .47274 Mdot
.56656 .64391 Mdot
.71388 .41173 Mdot
.64052 .45419 Mdot
.77311 .60094 Mdot
.6674 .4639 Mdot
.63425 .76086 Mdot
.56803 .67594 Mdot
.59244 .58959 Mdot
.35765 .67316 Mdot
.34915 .32778 Mdot
.59605 .42113 Mdot
.35447 .50199 Mdot
.3204 .66308 Mdot
.37758 .49779 Mdot
.50383 .80438 Mdot
.65747 .69677 Mdot
.53546 .31065 Mdot
.60835 .49499 Mdot
.36444 .67314 Mdot
.47503 .31027 Mdot
.24256 .52651 Mdot
.35932 .15121 Mdot
.35231 .50992 Mdot
.69016 .20262 Mdot
.34727 .47658 Mdot
.25424 .41507 Mdot
.47975 .33089 Mdot
.48239 .24746 Mdot
.45568 .47236 Mdot
.50224 .34188 Mdot
.35476 .57303 Mdot
.48286 .36643 Mdot
.73273 .63608 Mdot
.48992 .28107 Mdot
.37611 .47729 Mdot
.33237 .47158 Mdot
.55734 .48927 Mdot
.60656 .45839 Mdot
.42972 .41617 Mdot
.56684 .4284 Mdot
.60048 .47514 Mdot
.37782 .63317 Mdot
.45317 .21509 Mdot
.42041 .57625 Mdot
.4925 .30073 Mdot
.35076 .45645 Mdot
.61316 .47105 Mdot
.65186 .52647 Mdot
.65065 .54247 Mdot
.80138 .51904 Mdot
.30837 .73826 Mdot
.65237 .49877 Mdot
.57653 .51194 Mdot
.38515 .60511 Mdot
.53921 .72696 Mdot
.79497 .63609 Mdot
.67099 .66803 Mdot
.67272 .4967 Mdot
.57524 .68692 Mdot
.56559 .64809 Mdot
.6533 .4408 Mdot
.37203 .29535 Mdot
.34778 .6207 Mdot
.63844 .46212 Mdot
.64659 .72298 Mdot
.4114 .57795 Mdot
.2717 .3927 Mdot
.37825 .65357 Mdot
.47342 .33749 Mdot
.25389 .40936 Mdot
.41345 .63511 Mdot
.50217 .2373 Mdot
.27191 .41757 Mdot
.31363 .3106 Mdot
.5707 .64923 Mdot
.63124 .48174 Mdot
.45331 .33855 Mdot
.37462 .66581 Mdot
.36847 .46067 Mdot
.50965 .32385 Mdot
.3525 .51437 Mdot
.54189 .73095 Mdot
.75393 .5691 Mdot
.24684 .40338 Mdot
.35196 .49516 Mdot
.43927 .40638 Mdot
.57231 .68497 Mdot
.40872 .47595 Mdot
.39778 .23626 Mdot
.69006 .48645 Mdot
.54676 .80666 Mdot
.61566 .50471 Mdot
.16915 .56289 Mdot
.34851 .47623 Mdot
.24991 .41737 Mdot
.64517 .46904 Mdot
.36029 .62699 Mdot
.56 .51542 Mdot
.65154 .47765 Mdot
.38524 .59202 Mdot
.65742 .49723 Mdot
.5984 .67008 Mdot
.5455 .33207 Mdot
.50523 .61395 Mdot
.82606 .4504 Mdot
.58968 .70007 Mdot
.27645 .43138 Mdot
.6006 .47009 Mdot
.44262 .73346 Mdot
.50584 .34077 Mdot
.58196 .49141 Mdot
.72755 .28677 Mdot
.48399 .3136 Mdot
.50388 .3329 Mdot
.62481 .52308 Mdot
.39328 .45699 Mdot
.36388 .64471 Mdot
.57056 .68415 Mdot
.23442 .44944 Mdot
.65807 .48193 Mdot
.62007 .48778 Mdot
.58889 .691 Mdot
.38492 .47412 Mdot
.64162 .53232 Mdot
.23306 .55328 Mdot
.21751 .41749 Mdot
.36367 .45521 Mdot
.68981 .48259 Mdot
.57364 .82325 Mdot
.5496 .29929 Mdot
.59715 .17618 Mdot
.60827 .64366 Mdot
.39942 .61998 Mdot
.6238 .56582 Mdot
.0926 .47079 Mdot
.59429 .6711 Mdot
.36063 .34618 Mdot
.65295 .50343 Mdot
.60869 .46489 Mdot
.5172 .35344 Mdot
.61839 .52715 Mdot
.51113 .3005 Mdot
.82855 .44311 Mdot
.83463 .63992 Mdot
.49734 .34776 Mdot
.50113 .29467 Mdot
.48331 .25855 Mdot
.79036 .52738 Mdot
.48331 .32855 Mdot
.59077 .45443 Mdot
.37367 .73285 Mdot
.57066 .47244 Mdot
.57029 .70776 Mdot
.55454 .64431 Mdot
.47504 .37102 Mdot
.41448 .19932 Mdot
.57834 .55534 Mdot
.70464 .43655 Mdot
.5679 .59851 Mdot
.35435 .48463 Mdot
.67094 .518 Mdot
.24737 .39912 Mdot
.41336 .61161 Mdot
.70948 .52148 Mdot
.63456 .47973 Mdot
.48681 .29761 Mdot
.56558 .64343 Mdot
.39995 .49614 Mdot
.62822 .49136 Mdot
.36546 .59648 Mdot
.58383 .67813 Mdot
.49309 .29638 Mdot
.53144 .41114 Mdot
.55829 .6939 Mdot
.6543 .43361 Mdot
.60225 .47303 Mdot
.65789 .51133 Mdot
.58981 .42332 Mdot
.36303 .46502 Mdot
.42132 .61726 Mdot
.60687 .43383 Mdot
.41116 .34854 Mdot
.45242 .52545 Mdot
.62624 .4342 Mdot
.52859 .33345 Mdot
.37086 .45046 Mdot
.26879 .41627 Mdot
.70813 .62856 Mdot
.67163 .50961 Mdot
.3146 .74102 Mdot
.63531 .23369 Mdot
.26004 .41094 Mdot
.51932 .28084 Mdot
.56913 .68641 Mdot
.62201 .5148 Mdot
.40723 .74195 Mdot
.67759 .4914 Mdot
.57011 .40773 Mdot
.39965 .62482 Mdot
.35638 .49128 Mdot
.21055 .41788 Mdot
.41328 .61061 Mdot
.50296 .33161 Mdot
.20049 .66254 Mdot
.49144 .36294 Mdot
.46439 .32197 Mdot
.44412 .79363 Mdot
.36759 .48939 Mdot
.09104 .48737 Mdot
.50655 .19028 Mdot
.67869 .48869 Mdot
.39294 .48929 Mdot
.47769 .32919 Mdot
.61121 .49862 Mdot
.51664 .29657 Mdot
.46778 .34387 Mdot
.63526 .53954 Mdot
.60624 .46394 Mdot
.78173 .57602 Mdot
.31001 .75733 Mdot
.56381 .6748 Mdot
.52965 .34128 Mdot
.65358 .2617 Mdot
.63891 .45283 Mdot
.66764 .47867 Mdot
.32799 .63907 Mdot
.58831 .65532 Mdot
.57786 .32404 Mdot
.6628 .50483 Mdot
.74124 .29981 Mdot
.59599 .48368 Mdot
.45125 .31892 Mdot
.38912 .45288 Mdot
.37058 .30479 Mdot
.36602 .65987 Mdot
.49464 .36018 Mdot
.56292 .69388 Mdot
.51749 .3636 Mdot
.75191 .32902 Mdot
.37161 .49215 Mdot
.51287 .30439 Mdot
.39221 .57943 Mdot
.38142 .49013 Mdot
.36051 .45893 Mdot
.41657 .7303 Mdot
.40969 .58981 Mdot
.58529 .64587 Mdot
.38058 .50003 Mdot
.61323 .25208 Mdot
.37369 .47946 Mdot
.66982 .26905 Mdot
.61422 .44689 Mdot
.77126 .59515 Mdot
.38377 .39326 Mdot
.58826 .43012 Mdot
.3894 .50598 Mdot
.57127 .65932 Mdot
.60578 .51823 Mdot
.51277 .34905 Mdot
.57975 .66197 Mdot
.41402 .45867 Mdot
.38695 .58524 Mdot
.5038 .28227 Mdot
.37759 .45069 Mdot
.51544 .303 Mdot
.74408 .57195 Mdot
.36751 .69952 Mdot
.57791 .59955 Mdot
.458 .48878 Mdot
.64298 .54792 Mdot
.44442 .3457 Mdot
.6197 .44257 Mdot
.63936 .47834 Mdot
.38301 .6455 Mdot
.75881 .65104 Mdot
.50167 .34438 Mdot
.20392 .39439 Mdot
.34967 .48887 Mdot
.43286 .34437 Mdot
.54812 .42123 Mdot
.60094 .52482 Mdot
.48756 .3009 Mdot
.46527 .34142 Mdot
.74097 .4017 Mdot
.38044 .66679 Mdot
.58109 .44227 Mdot
.60992 .4278 Mdot
.58449 .54147 Mdot
.34824 .47323 Mdot
.24639 .5753 Mdot
.40557 .64683 Mdot
.6034 .15235 Mdot
.39594 .65007 Mdot
.47002 .70351 Mdot
.49162 .31728 Mdot
.5584 .66521 Mdot
.66564 .47595 Mdot
.72404 .43679 Mdot
.53607 .35144 Mdot
.3562 .59892 Mdot
.57202 .6918 Mdot
.27135 .60964 Mdot
.36377 .48678 Mdot
.60026 .4513 Mdot
.65198 .535 Mdot
.63385 .52814 Mdot
.6298 .50844 Mdot
.35025 .45437 Mdot
.66542 .46629 Mdot
.34053 .46746 Mdot
.58067 .24091 Mdot
.75253 .31522 Mdot
.35992 .66044 Mdot
.59765 .75892 Mdot
.51317 .28852 Mdot
.64879 .27364 Mdot
.5709 .30209 Mdot
.40766 .31713 Mdot
.41243 .71752 Mdot
.60303 .45421 Mdot
.40432 .61975 Mdot
.65064 .77269 Mdot
.366 .67356 Mdot
.8674 .61085 Mdot
.65937 .59753 Mdot
.26014 .70947 Mdot
.61452 .50025 Mdot
.42377 .62486 Mdot
.56732 .34795 Mdot
.66535 .4476 Mdot
.54258 .6723 Mdot
.53029 .43559 Mdot
.32583 .36069 Mdot
.55466 .67841 Mdot
.66283 .4898 Mdot
.472 .29854 Mdot
.63411 .50158 Mdot
.66398 .47671 Mdot
.5998 .48492 Mdot
.39906 .50551 Mdot
.68897 .50126 Mdot
.64443 .4508 Mdot
.37047 .19631 Mdot
.72922 .67078 Mdot
.37301 .60933 Mdot
.72494 .38292 Mdot
.57538 .67615 Mdot
.48113 .30182 Mdot
.49381 .60613 Mdot
.35714 .47455 Mdot
.74623 .40825 Mdot
.61465 .5021 Mdot
.3598 .39316 Mdot
.38148 .4507 Mdot
.58474 .66187 Mdot
.27696 .41553 Mdot
.31392 .71851 Mdot
.36526 .665 Mdot
.26581 .42001 Mdot
.38655 .64409 Mdot
.61758 .37824 Mdot
.48609 .29916 Mdot
.64502 .54393 Mdot
.38199 .50393 Mdot
.36102 .63703 Mdot
.73931 .68099 Mdot
.62222 .47793 Mdot
.37637 .61937 Mdot
.64108 .5475 Mdot
.44184 .53789 Mdot
.46663 .57426 Mdot
.39737 .66763 Mdot
.33319 .46628 Mdot
.38561 .48831 Mdot
.56055 .66527 Mdot
.4835 .29819 Mdot
.52806 .32095 Mdot
.37004 .48506 Mdot
.63282 .18476 Mdot
.65725 .47846 Mdot
.59941 .47963 Mdot
.40856 .35768 Mdot
.61998 .4983 Mdot
.71033 .65763 Mdot
.25046 .39073 Mdot
.49979 .28616 Mdot
.62647 .5044 Mdot
.64378 .53184 Mdot
.66591 .51723 Mdot
.74583 .57578 Mdot
.38331 .65376 Mdot
.61545 .51396 Mdot
.59987 .69696 Mdot
.354 .26552 Mdot
.62006 .4496 Mdot
.66765 .44566 Mdot
.51586 .3062 Mdot
.83243 .51369 Mdot
.35901 .4639 Mdot
.37261 .6283 Mdot
.36061 .62053 Mdot
.62965 .62255 Mdot
.54729 .30997 Mdot
.26116 .38751 Mdot
.31354 .51979 Mdot
.26835 .39416 Mdot
.59029 .6837 Mdot
.47458 .67054 Mdot
.35985 .60497 Mdot
.38178 .60103 Mdot
.33988 .49126 Mdot
.63099 .5071 Mdot
.59697 .48209 Mdot
.36293 .34455 Mdot
.59416 .50495 Mdot
.5726 .69486 Mdot
.38727 .45851 Mdot
.51591 .30845 Mdot
.59728 .67695 Mdot
.34873 .49396 Mdot
.51749 .34355 Mdot
.68257 .46969 Mdot
.6933 .50035 Mdot
.50866 .3288 Mdot
.47478 .33256 Mdot
.62908 .45649 Mdot
.32598 .23336 Mdot
.48438 .28784 Mdot
.50854 .30472 Mdot
.28211 .42159 Mdot
.36531 .66594 Mdot
.6943 .45775 Mdot
.3927 .49217 Mdot
.65857 .50984 Mdot
.36192 .6658 Mdot
.58191 .65286 Mdot
.51615 .33331 Mdot
.65781 .5223 Mdot
.65386 .49218 Mdot
.5749 .68772 Mdot
.55199 .66907 Mdot
.58458 .69917 Mdot
.36808 .52147 Mdot
.64243 .51542 Mdot
.48547 .33277 Mdot
.367 .49124 Mdot
.56525 .64847 Mdot
.60592 .67176 Mdot
.40058 .18775 Mdot
.64059 .45546 Mdot
.53984 .58875 Mdot
.2254 .25262 Mdot
.69067 .6571 Mdot
.26118 .41827 Mdot
.41425 .65127 Mdot
.76106 .60949 Mdot
.61891 .67452 Mdot
.39507 .4863 Mdot
.62352 .71349 Mdot
.55645 .64607 Mdot
.62724 .53996 Mdot
.6006 .49713 Mdot
.61342 .54887 Mdot
.58165 .67318 Mdot
.7376 .57865 Mdot
.53061 .3091 Mdot
.629 .3197 Mdot
.57549 .67598 Mdot
.39884 .66626 Mdot
.39517 .67164 Mdot
.39672 .64995 Mdot
.59897 .45684 Mdot
.72638 .39884 Mdot
.62791 .25193 Mdot
.58979 .34238 Mdot
.36123 .48291 Mdot
.46456 .34403 Mdot
.42284 .71634 Mdot
.50473 .33402 Mdot
.41296 .61826 Mdot
.58524 .67281 Mdot
.52365 .34947 Mdot
.38155 .46402 Mdot
.38779 .47789 Mdot
.38015 .5899 Mdot
.37364 .65147 Mdot
.36815 .63927 Mdot
.47582 .34389 Mdot
.4917 .31834 Mdot
.65371 .52904 Mdot
.51686 .32501 Mdot
.58184 .1956 Mdot
.58351 .7129 Mdot
.37689 .68136 Mdot
.37583 .46621 Mdot
.47754 .31111 Mdot
.63281 .4837 Mdot
.50045 .69863 Mdot
.37772 .56161 Mdot
.5964 .69454 Mdot
.44072 .61593 Mdot
.88002 .53764 Mdot
.66098 .53143 Mdot
.344 .48584 Mdot
.37103 .28183 Mdot
.62528 .47229 Mdot
.39261 .61998 Mdot
.78629 .50446 Mdot
.27644 .397 Mdot
.6408 .45014 Mdot
.58498 .4978 Mdot
.40759 .48601 Mdot
.4816 .59395 Mdot
.59653 .51927 Mdot
.48279 .4126 Mdot
.36936 .51715 Mdot
.40824 .64383 Mdot
.20455 .35981 Mdot
.4071 .66774 Mdot
.79032 .58174 Mdot
.26041 .41645 Mdot
.64995 .5352 Mdot
.37884 .63617 Mdot
.60115 .68778 Mdot
.37567 .64222 Mdot
.51755 .28524 Mdot
.36746 .62628 Mdot
.6147 .48517 Mdot
.4865 .33169 Mdot
.37808 .46458 Mdot
.43611 .35952 Mdot
.37527 .20232 Mdot
.36085 .62448 Mdot
.25096 .42408 Mdot
.64006 .45145 Mdot
.57702 .26416 Mdot
.5654 .52445 Mdot
.60732 .45502 Mdot
.37608 .49798 Mdot
.48839 .30123 Mdot
.34134 .47951 Mdot
.69128 .47426 Mdot
.77204 .38455 Mdot
.34996 .48199 Mdot
.31147 .33538 Mdot
.59037 .68821 Mdot
.78096 .55767 Mdot
.64536 .48075 Mdot
.37822 .5041 Mdot
.64365 .51591 Mdot
.5325 .33692 Mdot
.47395 .46318 Mdot
.36898 .25383 Mdot
.38399 .50265 Mdot
.18266 .61402 Mdot
.48599 .48953 Mdot
.7033 .5034 Mdot
.36979 .50613 Mdot
.70102 .39807 Mdot
.27196 .40938 Mdot
.5861 .68168 Mdot
.55907 .65521 Mdot
.57674 .70419 Mdot
.59399 .50303 Mdot
.68626 .56009 Mdot
.59836 .65557 Mdot
.35741 .51669 Mdot
.60209 .67102 Mdot
.77272 .54549 Mdot
.20398 .63939 Mdot
.59055 .69689 Mdot
.64499 .48657 Mdot
.67231 .45136 Mdot
.72995 .67241 Mdot
.4114 .64179 Mdot
.32673 .75183 Mdot
.53695 .20987 Mdot
.62088 .45272 Mdot
.57672 .56445 Mdot
.51456 .28684 Mdot
.40343 .25505 Mdot
.53828 .47452 Mdot
.49311 .6334 Mdot
.50173 .29768 Mdot
.434 .55809 Mdot
.49692 .28684 Mdot
.66534 .53082 Mdot
.64786 .49941 Mdot
.54133 .34394 Mdot
.22139 .59004 Mdot
.2886 .30474 Mdot
.16051 .49477 Mdot
.52892 .32098 Mdot
.36863 .50903 Mdot
.35101 .50661 Mdot
.36348 .49128 Mdot
.36781 .65915 Mdot
.47957 .34402 Mdot
.63546 .51623 Mdot
.39421 .60617 Mdot
.67034 .4903 Mdot
.38213 .49374 Mdot
.21022 .4206 Mdot
.51515 .30662 Mdot
.63888 .4637 Mdot
.48598 .19378 Mdot
.39558 .64304 Mdot
.5735 .68441 Mdot
.42847 .53583 Mdot
.4239 .63557 Mdot
.38357 .51076 Mdot
.54748 .30097 Mdot
.32591 .45321 Mdot
.51079 .65167 Mdot
.58741 .53416 Mdot
.60423 .44382 Mdot
.25278 .44128 Mdot
.43584 .19462 Mdot
.59644 .49709 Mdot
.38778 .60165 Mdot
.38277 .67432 Mdot
.66673 .51089 Mdot
.50096 .35405 Mdot
.57788 .64104 Mdot
.5821 .70641 Mdot
.59248 .52204 Mdot
.45222 .46696 Mdot
.77734 .58793 Mdot
.62552 .53162 Mdot
.64779 .41671 Mdot
.39743 .58079 Mdot
.2769 .41765 Mdot
.42113 .3847 Mdot
.55995 .68366 Mdot
.6554 .50397 Mdot
.27408 .32641 Mdot
.50801 .29943 Mdot
.36693 .63255 Mdot
.37873 .45742 Mdot
.54207 .67809 Mdot
.36221 .61393 Mdot
.66623 .51124 Mdot
.64231 .53212 Mdot
.40828 .4813 Mdot
.45124 .32107 Mdot
.58392 .67114 Mdot
.39281 .60662 Mdot
.55778 .66645 Mdot
.49264 .32641 Mdot
.51204 .30928 Mdot
.59965 .42997 Mdot
.57543 .4382 Mdot
.36125 .62022 Mdot
.59099 .52688 Mdot
.41429 .63069 Mdot
.52855 .72695 Mdot
.35848 .45379 Mdot
.58107 .4932 Mdot
.50418 .27053 Mdot
.37875 .49346 Mdot
.61572 .45928 Mdot
.28776 .43641 Mdot
.62047 .53491 Mdot
.42312 .62765 Mdot
.77708 .38124 Mdot
.57753 .65439 Mdot
.51574 .39798 Mdot
.73149 .52935 Mdot
.61952 .49716 Mdot
.41599 .63841 Mdot
.61776 .56763 Mdot
.35313 .4731 Mdot
.49187 .30662 Mdot
.79981 .31613 Mdot
.37782 .48137 Mdot
.63876 .50215 Mdot
.57842 .66461 Mdot
.46373 .31665 Mdot
.25053 .40134 Mdot
.40781 .38157 Mdot
.70708 .52273 Mdot
.68673 .53138 Mdot
.63308 .50626 Mdot
.75475 .70521 Mdot
.37359 .63351 Mdot
.47629 .32051 Mdot
.34943 .46564 Mdot
.36531 .477 Mdot
.4024 .6406 Mdot
.3361 .38034 Mdot
.24203 .63802 Mdot
.16592 .32054 Mdot
.37373 .60242 Mdot
.60488 .68076 Mdot
.46612 .50894 Mdot
.41272 .60724 Mdot
.37987 .62903 Mdot
.37468 .59308 Mdot
.37121 .3823 Mdot
.52359 .34136 Mdot
.65514 .49281 Mdot
.54382 .30267 Mdot
.63726 .53867 Mdot
.78135 .63413 Mdot
.36857 .48546 Mdot
.49192 .30845 Mdot
.28063 .44047 Mdot
.55726 .44124 Mdot
.61743 .47246 Mdot
.35856 .71268 Mdot
.6837 .55184 Mdot
.72539 .62513 Mdot
.66074 .43484 Mdot
.37915 .65005 Mdot
.59692 .58154 Mdot
.62291 .56483 Mdot
.52279 .20843 Mdot
.38465 .46979 Mdot
.24726 .40924 Mdot
.68316 .47533 Mdot
.70867 .47541 Mdot
.46393 .31802 Mdot
.52359 .34973 Mdot
.59609 .65275 Mdot
.44138 .50191 Mdot
.38132 .46623 Mdot
.27439 .66037 Mdot
.60419 .46248 Mdot
.4125 .51747 Mdot
.77023 .35781 Mdot
.61885 .45915 Mdot
.39884 .73349 Mdot
.74509 .40633 Mdot
.60019 .52286 Mdot
.6114 .35001 Mdot
.37866 .47197 Mdot
.73735 .29595 Mdot
.62044 .5493 Mdot
.39238 .62128 Mdot
.48821 .31644 Mdot
.50923 .28421 Mdot
.59695 .68991 Mdot
.55146 .19355 Mdot
.33466 .49326 Mdot
.4911 .31464 Mdot
.62877 .47504 Mdot
.36608 .46125 Mdot
.24909 .40715 Mdot
.69183 .53502 Mdot
.51591 .78882 Mdot
.51745 .31973 Mdot
.57155 .48126 Mdot
.29328 .38869 Mdot
.45716 .53723 Mdot
.31744 .76728 Mdot
.3628 .4938 Mdot
.56279 .69202 Mdot
.65933 .43324 Mdot
.30857 .51383 Mdot
.64646 .55335 Mdot
.77276 .61892 Mdot
.50281 .38602 Mdot
.56649 .65129 Mdot
.63026 .46873 Mdot
.59606 .51785 Mdot
.46634 .49094 Mdot
.55283 .67021 Mdot
.59938 .52447 Mdot
.58923 .43584 Mdot
.51778 .34202 Mdot
.24615 .39375 Mdot
.51839 .31391 Mdot
.63849 .48697 Mdot
.58317 .57601 Mdot
.51343 .35239 Mdot
.30321 .69759 Mdot
.57523 .63108 Mdot
.35613 .4752 Mdot
.71074 .46961 Mdot
.61148 .4487 Mdot
.5384 .85238 Mdot
.25161 .41435 Mdot
.81109 .58259 Mdot
.42271 .63546 Mdot
.2213 .37823 Mdot
.4271 .61462 Mdot
.24237 .69476 Mdot
.43383 .37657 Mdot
.5887 .53089 Mdot
.63624 .71869 Mdot
.60046 .34336 Mdot
.34358 .50278 Mdot
.59931 .25784 Mdot
.60685 .45799 Mdot
.6588 .47405 Mdot
.40339 .60679 Mdot
.33822 .3925 Mdot
.3679 .29032 Mdot
.4391 .43136 Mdot
.58772 .66892 Mdot
.49599 .31984 Mdot
.61007 .48678 Mdot
.2041 .52273 Mdot
.36986 .61413 Mdot
.50491 .48992 Mdot
.64218 .46663 Mdot
.38438 .32098 Mdot
.33688 .34748 Mdot
.36695 .45983 Mdot
.41635 .64489 Mdot
.42098 .61719 Mdot
.67955 .51141 Mdot
.3887 .46839 Mdot
.64319 .53476 Mdot
.4907 .47579 Mdot
.57571 .50664 Mdot
.59144 .66289 Mdot
.66241 .46811 Mdot
.50647 .54764 Mdot
.24084 .71262 Mdot
.67055 .56293 Mdot
.47961 .29715 Mdot
.36992 .65923 Mdot
.39315 .65019 Mdot
.52804 .31947 Mdot
.3968 .64762 Mdot
.63395 .32783 Mdot
.72708 .30522 Mdot
.59337 .6754 Mdot
.55837 .26725 Mdot
.58529 .65947 Mdot
.24684 .40917 Mdot
.63409 .45412 Mdot
.33208 .54347 Mdot
.37124 .60431 Mdot
.80093 .49938 Mdot
.37103 .47907 Mdot
.25212 .41416 Mdot
.67885 .48277 Mdot
.4746 .67455 Mdot
.40993 .61809 Mdot
.31408 .68012 Mdot
.66564 .51799 Mdot
.52732 .3414 Mdot
.59757 .51901 Mdot
.57724 .48625 Mdot
.26683 .4195 Mdot
.63366 .50726 Mdot
.34898 .49466 Mdot
.48144 .34672 Mdot
.24501 .69075 Mdot
.37203 .6644 Mdot
.65761 .46723 Mdot
.62855 .47424 Mdot
.53116 .34407 Mdot
.66773 .46543 Mdot
.39571 .48854 Mdot
.08618 .54312 Mdot
.5901 .68711 Mdot
.28033 .41469 Mdot
.30868 .68149 Mdot
.60356 .49792 Mdot
.61177 .52688 Mdot
.24541 .44113 Mdot
.3366 .25276 Mdot
.3512 .49727 Mdot
.59935 .43863 Mdot
.38372 .60652 Mdot
.58222 .66256 Mdot
.40027 .49038 Mdot
.65749 .51499 Mdot
.65743 .47137 Mdot
.59316 .66501 Mdot
.37761 .72972 Mdot
.38664 .56751 Mdot
.36188 .48643 Mdot
.54704 .52473 Mdot
.50507 .70168 Mdot
.65454 .47773 Mdot
.17596 .54367 Mdot
.50721 .30623 Mdot
.36453 .50383 Mdot
.70746 .41228 Mdot
.64155 .54479 Mdot
.38318 .51037 Mdot
.38016 .46622 Mdot
.68137 .49762 Mdot
.54648 .30631 Mdot
.47229 .34332 Mdot
.50613 .30316 Mdot
.78434 .38921 Mdot
.69018 .72931 Mdot
.36745 .63962 Mdot
.38124 .47236 Mdot
.37503 .67824 Mdot
.58104 .63957 Mdot
.4533 .52351 Mdot
.3867 .67376 Mdot
.50991 .28563 Mdot
.38233 .67991 Mdot
.63544 .53544 Mdot
.38601 .4688 Mdot
.38328 .59953 Mdot
.60696 .50431 Mdot
.64204 .41312 Mdot
.52343 .55415 Mdot
.57735 .64207 Mdot
.43542 .54786 Mdot
.63724 .49606 Mdot
.26955 .41688 Mdot
.63445 .45771 Mdot
.3784 .4551 Mdot
.49951 .5518 Mdot
.61187 .50888 Mdot
.36371 .61447 Mdot
.51905 .65008 Mdot
.40708 .65004 Mdot
.58456 .45594 Mdot
.63892 .48794 Mdot
.65553 .4764 Mdot
.59477 .51754 Mdot
.31832 .34737 Mdot
.34102 .46803 Mdot
.70829 .45951 Mdot
.35214 .63361 Mdot
.50915 .33489 Mdot
.53534 .3318 Mdot
.4849 .64018 Mdot
.27042 .42144 Mdot
.39282 .48057 Mdot
.65662 .47905 Mdot
.31425 .67941 Mdot
.20934 .42689 Mdot
.16819 .52997 Mdot
.43663 .7199 Mdot
.38555 .60072 Mdot
.47699 .302 Mdot
.39906 .59147 Mdot
.67704 .49782 Mdot
.66777 .4409 Mdot
.25561 .70101 Mdot
.41455 .47515 Mdot
.58415 .67301 Mdot
.67059 .48903 Mdot
.78832 .56446 Mdot
.38523 .6051 Mdot
.39938 .58091 Mdot
.6547 .53105 Mdot
.47939 .35463 Mdot
.3057 .78164 Mdot
.37951 .45684 Mdot
.58106 .26253 Mdot
.5277 .39121 Mdot
.53022 .44074 Mdot
.3646 .46669 Mdot
.54613 .58069 Mdot
.39713 .65688 Mdot
.54396 .20589 Mdot
.5109 .33009 Mdot
.58198 .67689 Mdot
.63109 .43255 Mdot
.50738 .2844 Mdot
.41574 .65085 Mdot
.49999 .29029 Mdot
.65059 .54014 Mdot
.34438 .49724 Mdot
.40352 .64271 Mdot
.3459 .45243 Mdot
.54039 .34756 Mdot
.58243 .65697 Mdot
.77256 .53775 Mdot
.58118 .25483 Mdot
.74517 .40689 Mdot
.61601 .51405 Mdot
.33202 .67976 Mdot
.64186 .51798 Mdot
.46428 .32902 Mdot
.64531 .48178 Mdot
.44242 .33896 Mdot
.41729 .61093 Mdot
.57181 .49053 Mdot
.65032 .45382 Mdot
.55879 .22429 Mdot
.61787 .46595 Mdot
.67981 .48643 Mdot
.58728 .50188 Mdot
.51217 .39312 Mdot
.57985 .4494 Mdot
.52372 .34447 Mdot
.36242 .35573 Mdot
.38157 .63006 Mdot
.60675 .66877 Mdot
.57379 .70588 Mdot
.7728 .61296 Mdot
.7823 .55999 Mdot
.34156 .38197 Mdot
.52467 .32228 Mdot
.36269 .51098 Mdot
.64553 .53382 Mdot
.66776 .39648 Mdot
.60218 .61787 Mdot
.3994 .65373 Mdot
.35639 .63958 Mdot
.56583 .45139 Mdot
.73764 .7321 Mdot
.57417 .46316 Mdot
.4011 .37551 Mdot
.60914 .53537 Mdot
.58202 .49564 Mdot
.39291 .57828 Mdot
.76255 .55766 Mdot
.61541 .51376 Mdot
.46391 .31785 Mdot
.58012 .68171 Mdot
.56727 .54989 Mdot
.60259 .61303 Mdot
.51391 .52133 Mdot
.49857 .23283 Mdot
.63424 .51188 Mdot
.39611 .61231 Mdot
.49985 .28377 Mdot
.41379 .35468 Mdot
.36864 .49345 Mdot
.41863 .39418 Mdot
.59005 .23489 Mdot
.39751 .69113 Mdot
.58362 .67789 Mdot
.40078 .72817 Mdot
.61489 .48562 Mdot
.36654 .65611 Mdot
.65064 .53738 Mdot
.20578 .43047 Mdot
.57786 .65047 Mdot
.53272 .35812 Mdot
.36807 .50945 Mdot
.53178 .32423 Mdot
.70811 .38612 Mdot
.59308 .60628 Mdot
.21585 .38115 Mdot
.36815 .66825 Mdot
.76999 .5016 Mdot
.48046 .32089 Mdot
.65882 .51853 Mdot
.18333 .30116 Mdot
.50549 .30767 Mdot
.53122 .33203 Mdot
.49435 .63298 Mdot
.71635 .58431 Mdot
.632 .5673 Mdot
.50534 .28966 Mdot
.36635 .6791 Mdot
.56624 .67591 Mdot
.60767 .51702 Mdot
.58912 .5063 Mdot
.51935 .35211 Mdot
.41181 .621 Mdot
.79523 .5601 Mdot
.37613 .65113 Mdot
.51106 .34585 Mdot
.39373 .63861 Mdot
.29755 .66528 Mdot
.37474 .61322 Mdot
.64104 .44773 Mdot
.65644 .48043 Mdot
.50912 .77355 Mdot
.51209 .30943 Mdot
.60742 .52188 Mdot
.65533 .49993 Mdot
.4825 .32871 Mdot
.35137 .62543 Mdot
.74845 .44649 Mdot
.61013 .49636 Mdot
.65749 .48796 Mdot
.56033 .65919 Mdot
.44313 .57309 Mdot
.19501 .51309 Mdot
.60734 .51885 Mdot
.59116 .70363 Mdot
.47318 .33964 Mdot
.63097 .4576 Mdot
.77319 .55057 Mdot
.40602 .57103 Mdot
.67299 .48174 Mdot
.25004 .39984 Mdot
.59829 .48844 Mdot
.30053 .77792 Mdot
.65283 .46135 Mdot
.47934 .33331 Mdot
.48507 .31412 Mdot
.38359 .56504 Mdot
.50234 .32911 Mdot
.256 .41447 Mdot
.38279 .49183 Mdot
.16385 .547 Mdot
.25348 .41121 Mdot
.58449 .47669 Mdot
.5069 .19022 Mdot
.60158 .53532 Mdot
.67249 .45858 Mdot
.78997 .52383 Mdot
.25703 .41268 Mdot
.48334 .3062 Mdot
.22188 .58586 Mdot
.57936 .49636 Mdot
.38143 .45833 Mdot
.66202 .44322 Mdot
.67056 .47651 Mdot
.51314 .43387 Mdot
.77746 .40579 Mdot
.38199 .45433 Mdot
.70074 .47106 Mdot
.60866 .51947 Mdot
.3955 .21893 Mdot
.62503 .47982 Mdot
.59318 .69484 Mdot
.52219 .30663 Mdot
.39876 .58877 Mdot
.58273 .69095 Mdot
.60759 .49143 Mdot
.57915 .6746 Mdot
.36811 .6361 Mdot
.37469 .50074 Mdot
.6664 .47518 Mdot
.5657 .70424 Mdot
.58558 .66881 Mdot
.63892 .52398 Mdot
.49017 .31254 Mdot
.5831 .55295 Mdot
.62763 .45761 Mdot
.6633 .51354 Mdot
.52799 .3208 Mdot
.50845 .14999 Mdot
.67517 .52025 Mdot
.53843 .58379 Mdot
.53938 .32327 Mdot
.27783 .39484 Mdot
.39582 .59305 Mdot
.66295 .53786 Mdot
.36495 .48267 Mdot
.374 .4901 Mdot
.35099 .6703 Mdot
.52051 .35805 Mdot
.41136 .63305 Mdot
.69935 .52358 Mdot
.57291 .44309 Mdot
.61332 .43054 Mdot
.80257 .3214 Mdot
.3164 .7223 Mdot
.48659 .34848 Mdot
.40284 .65243 Mdot
.43566 .42771 Mdot
.3918 .48128 Mdot
.35562 .68301 Mdot
.50401 .27152 Mdot
.47196 .32236 Mdot
.51164 .28804 Mdot
.56018 .678 Mdot
.37697 .65766 Mdot
.45731 .34688 Mdot
.49225 .36008 Mdot
.65685 .52583 Mdot
.6097 .52031 Mdot
.49576 .37743 Mdot
.72135 .67451 Mdot
.58716 .65819 Mdot
.3964 .6182 Mdot
.4974 .86786 Mdot
.37689 .45494 Mdot
.55656 .22316 Mdot
.60709 .50266 Mdot
.37931 .13105 Mdot
.5928 .43865 Mdot
.62742 .47654 Mdot
.47395 .33868 Mdot
.59847 .70422 Mdot
.57005 .66958 Mdot
.48104 .32008 Mdot
.54279 .35217 Mdot
.57258 .70026 Mdot
.43234 .72571 Mdot
.16674 .59202 Mdot
.4157 .37142 Mdot
.4822 .33561 Mdot
.56855 .25235 Mdot
.39473 .49644 Mdot
.54258 .32488 Mdot
.37813 .45292 Mdot
.38052 .62769 Mdot
.35822 .63678 Mdot
.408 .4758 Mdot
.66989 .51257 Mdot
.36891 .6258 Mdot
.70522 .52998 Mdot
.28295 .70502 Mdot
.4938 .81195 Mdot
.31186 .2625 Mdot
.59595 .47954 Mdot
.37105 .29853 Mdot
.34319 .30148 Mdot
.62647 .49628 Mdot
.56384 .42286 Mdot
.5826 .67409 Mdot
.54111 .33224 Mdot
.39499 .47768 Mdot
.33566 .77063 Mdot
.65523 .47818 Mdot
.50235 .34464 Mdot
.38915 .47404 Mdot
.29442 .64715 Mdot
.48836 .41649 Mdot
.65322 .53317 Mdot
.10541 .40963 Mdot
.5372 .35232 Mdot
.39918 .58864 Mdot
.49854 .2066 Mdot
.54185 .30189 Mdot
.50876 .68754 Mdot
.41511 .59582 Mdot
.17008 .48203 Mdot
.4791 .30507 Mdot
.3652 .59295 Mdot
.49483 .32807 Mdot
.59825 .67212 Mdot
.54647 .2999 Mdot
.404 .63531 Mdot
.62598 .46666 Mdot
.40121 .63969 Mdot
.59312 .66166 Mdot
.36321 .65523 Mdot
.39616 .48009 Mdot
.26298 .41717 Mdot
.38826 .48235 Mdot
.44897 .53078 Mdot
.76243 .39187 Mdot
.35654 .49106 Mdot
.32222 .69549 Mdot
.5972 .49731 Mdot
.45202 .31482 Mdot
.39533 .5879 Mdot
.35716 .66369 Mdot
.45196 .51059 Mdot
.50004 .34066 Mdot
.40221 .63235 Mdot
.59305 .2404 Mdot
.59426 .15832 Mdot
.71216 .52335 Mdot
.64765 .74885 Mdot
.4825 .331 Mdot
.41413 .59988 Mdot
.40739 .36097 Mdot
.5278 .30021 Mdot
.37094 .60709 Mdot
.37298 .50676 Mdot
.36428 .47368 Mdot
.67408 .51183 Mdot
.40425 .45568 Mdot
.41811 .634 Mdot
.28708 .31112 Mdot
.52224 .30496 Mdot
.30062 .64386 Mdot
.58862 .70003 Mdot
.37613 .62782 Mdot
.60193 .5564 Mdot
.53369 .36866 Mdot
.35482 .64759 Mdot
.55128 .78443 Mdot
.53842 .86572 Mdot
.40142 .63212 Mdot
.52174 .30589 Mdot
.51571 .33543 Mdot
.65039 .56655 Mdot
.45675 .47843 Mdot
.40905 .62447 Mdot
.34092 .55926 Mdot
.77306 .62457 Mdot
.25825 .39919 Mdot
.4502 .18483 Mdot
.61524 .51264 Mdot
.64575 .51516 Mdot
.39096 .49588 Mdot
.61275 .47632 Mdot
.47257 .34821 Mdot
.65971 .44982 Mdot
.35603 .51378 Mdot
.40232 .6501 Mdot
.64781 .46187 Mdot
.56896 .66173 Mdot
.3976 .48728 Mdot
.40601 .49428 Mdot
.38696 .63732 Mdot
.50881 .28879 Mdot
.21115 .58856 Mdot
.37553 .65198 Mdot
.63246 .51206 Mdot
.26389 .40829 Mdot
.64997 .54309 Mdot
.47593 .78228 Mdot
.53016 .31004 Mdot
.40026 .59084 Mdot
.51895 .28009 Mdot
.38301 .47889 Mdot
.35278 .66707 Mdot
.62556 .48372 Mdot
.36714 .6127 Mdot
.62254 .68332 Mdot
.44246 .75248 Mdot
.49855 .36334 Mdot
.56647 .71587 Mdot
.52714 .34731 Mdot
.25709 .39913 Mdot
.65808 .63869 Mdot
.58957 .67751 Mdot
.37959 .61287 Mdot
.3134 .72651 Mdot
.3749 .59536 Mdot
.61659 .46489 Mdot
.6063 .46584 Mdot
.40292 .60375 Mdot
.56285 .66472 Mdot
.82431 .4977 Mdot
.56212 .60453 Mdot
.48806 .29814 Mdot
.4383 .28964 Mdot
.43045 .85115 Mdot
.32766 .45722 Mdot
.37542 .51082 Mdot
.65779 .42544 Mdot
.60798 .52919 Mdot
.40271 .49378 Mdot
.35196 .45553 Mdot
.56825 .6475 Mdot
.36501 .65069 Mdot
.47908 .2798 Mdot
.39766 .49553 Mdot
.72759 .54551 Mdot
.78241 .55191 Mdot
.66248 .5627 Mdot
.56913 .50341 Mdot
.6037 .45063 Mdot
.45433 .54078 Mdot
.34301 .47488 Mdot
.64142 .49589 Mdot
.60574 .42699 Mdot
.35856 .50202 Mdot
.59566 .66687 Mdot
.50682 .25912 Mdot
.39487 .62999 Mdot
.4973 .11848 Mdot
.66506 .47266 Mdot
.62665 .4629 Mdot
.36117 .48252 Mdot
.41899 .19645 Mdot
.48778 .34662 Mdot
.51394 .29348 Mdot
.37264 .63371 Mdot
.44828 .51129 Mdot
.65464 .45039 Mdot
.63004 .49597 Mdot
.3825 .61555 Mdot
.26599 .41642 Mdot
.2738 .28758 Mdot
.65227 .49163 Mdot
.37399 .46727 Mdot
.31967 .66024 Mdot
.3435 .47095 Mdot
.65685 .53384 Mdot
.61414 .4646 Mdot
.64508 .44865 Mdot
.59488 .51978 Mdot
.40586 .48607 Mdot
.62801 .49321 Mdot
.55439 .4926 Mdot
.49511 .29876 Mdot
.61732 .5046 Mdot
.76938 .60882 Mdot
.65333 .48557 Mdot
.57146 .66007 Mdot
.19477 .5358 Mdot
.66257 .48055 Mdot
.62042 .50551 Mdot
.5567 .59927 Mdot
.63423 .47001 Mdot
.36905 .45676 Mdot
.51327 .33217 Mdot
.3826 .47303 Mdot
.34857 .4731 Mdot
.36567 .6749 Mdot
.57139 .64531 Mdot
.64474 .55449 Mdot
.58391 .70367 Mdot
.5887 .54149 Mdot
.64752 .54091 Mdot
.43781 .55785 Mdot
.40045 .37771 Mdot
.61709 .68909 Mdot
.63059 .48541 Mdot
.37709 .63351 Mdot
.39086 .59097 Mdot
.62446 .72655 Mdot
.69221 .54809 Mdot
.40277 .48651 Mdot
.37853 .50417 Mdot
.70475 .66036 Mdot
.50645 .42087 Mdot
.57779 .65785 Mdot
.43591 .41677 Mdot
.59485 .47505 Mdot
.66112 .49684 Mdot
.667 .44599 Mdot
.38237 .6759 Mdot
.27161 .41799 Mdot
.39514 .65674 Mdot
.27803 .42785 Mdot
.3428 .46862 Mdot
.5969 .47738 Mdot
.45111 .80796 Mdot
.50721 .35718 Mdot
.51384 .33096 Mdot
.36402 .51791 Mdot
.40894 .64761 Mdot
.64487 .56587 Mdot
.8138 .32883 Mdot
.47204 .36598 Mdot
.60711 .6905 Mdot
.63324 .49837 Mdot
.38393 .63649 Mdot
.498 .35926 Mdot
.55047 .6767 Mdot
.59956 .46983 Mdot
.35469 .6205 Mdot
.64868 .48222 Mdot
.60015 .35494 Mdot
.4903 .30273 Mdot
.20598 .4216 Mdot
.49449 .36371 Mdot
.38985 .50601 Mdot
.34794 .4838 Mdot
.61545 .4602 Mdot
.70724 .22675 Mdot
.52507 .36582 Mdot
.35632 .44368 Mdot
.59614 .65957 Mdot
.2802 .41339 Mdot
.58511 .64723 Mdot
.41534 .6159 Mdot
.58252 .68071 Mdot
.36078 .62004 Mdot
.70436 .67692 Mdot
.46192 .35756 Mdot
.5875 .68865 Mdot
.39173 .20001 Mdot
.68853 .50957 Mdot
.56174 .65298 Mdot
.56086 .46174 Mdot
.44861 .36139 Mdot
.3842 .61781 Mdot
.56336 .66573 Mdot
.65507 .52298 Mdot
.3675 .77936 Mdot
.34742 .47811 Mdot
.40312 .48399 Mdot
.64828 .55368 Mdot
.3893 .5826 Mdot
.5456 .34729 Mdot
.49406 .6019 Mdot
.27323 .39175 Mdot
.63038 .49505 Mdot
.59702 .47353 Mdot
.52996 .35073 Mdot
.46208 .33131 Mdot
.61231 .46401 Mdot
.60673 .25356 Mdot
.61434 .48679 Mdot
.36271 .4711 Mdot
.47394 .33128 Mdot
.51639 .33239 Mdot
.41662 .64213 Mdot
.51925 .3581 Mdot
.56912 .49125 Mdot
.39155 .52622 Mdot
.63018 .42796 Mdot
.38073 .48231 Mdot
.50637 .55683 Mdot
.36777 .66099 Mdot
.33285 .76115 Mdot
.52079 .3601 Mdot
.62939 .50698 Mdot
.53009 .34283 Mdot
.58303 .69913 Mdot
.51315 .31159 Mdot
.49817 .28065 Mdot
.6066 .4606 Mdot
.65089 .53474 Mdot
.2627 .41328 Mdot
.4558 .48106 Mdot
.49677 .30477 Mdot
.61625 .49113 Mdot
.59878 .53475 Mdot
.68466 .50674 Mdot
.48264 .49761 Mdot
.47037 .32223 Mdot
.69049 .27748 Mdot
.4865 .79384 Mdot
.49302 .3103 Mdot
.35112 .79932 Mdot
.25779 .39352 Mdot
.27388 .42154 Mdot
.32883 .4637 Mdot
.65586 .49173 Mdot
.40832 .63621 Mdot
.67663 .49542 Mdot
.71067 .51986 Mdot
.66092 .47381 Mdot
.58662 .65408 Mdot
.60757 .55085 Mdot
.27039 .39902 Mdot
.38142 .65269 Mdot
.60762 .49526 Mdot
.65191 .4649 Mdot
.26555 .42155 Mdot
.49932 .36587 Mdot
.47459 .31271 Mdot
.1793 .55156 Mdot
.59533 .68107 Mdot
.37393 .49704 Mdot
.6734 .50362 Mdot
.37526 .63352 Mdot
.39961 .64356 Mdot
.53187 .3273 Mdot
.3947 .62354 Mdot
.38006 .45623 Mdot
.62077 .47956 Mdot
.40383 .49196 Mdot
.58775 .65522 Mdot
.52255 .30747 Mdot
.67395 .50339 Mdot
.6584 .52453 Mdot
.48499 .31386 Mdot
.59683 .49632 Mdot
.55972 .66032 Mdot
.3598 .64082 Mdot
.47473 .31635 Mdot
.38077 .4919 Mdot
.41379 .64858 Mdot
.6405 .53378 Mdot
.61031 .82804 Mdot
.61108 .47821 Mdot
.66736 .50514 Mdot
.19533 .64362 Mdot
.63643 .42131 Mdot
.41501 .60624 Mdot
.53619 .32896 Mdot
.69205 .49549 Mdot
.77459 .64215 Mdot
.27681 .45772 Mdot
.35389 .68043 Mdot
.63357 .50218 Mdot
.31768 .75481 Mdot
.62486 .50312 Mdot
.28762 .64372 Mdot
.43783 .55427 Mdot
.6955 .74438 Mdot
.56681 .49517 Mdot
.38946 .4543 Mdot
.26168 .41449 Mdot
.39199 .58685 Mdot
.66312 .3815 Mdot
.60379 .48381 Mdot
.71333 .40432 Mdot
.66548 .46646 Mdot
.36481 .4677 Mdot
.58992 .41454 Mdot
.39631 .61977 Mdot
.52515 .20491 Mdot
.63625 .51557 Mdot
.47101 .32626 Mdot
.37359 .68222 Mdot
.27981 .40237 Mdot
.65816 .52172 Mdot
.59297 .70013 Mdot
.31041 .43224 Mdot
.57036 .45449 Mdot
.38069 .48501 Mdot
.65649 .50168 Mdot
.70518 .48231 Mdot
.64599 .19469 Mdot
.49254 .29854 Mdot
.3745 .50983 Mdot
.40061 .2468 Mdot
.59432 .49283 Mdot
.47778 .30744 Mdot
.50991 .33199 Mdot
.60002 .68517 Mdot
.40285 .40558 Mdot
.30702 .45821 Mdot
.53568 .81156 Mdot
.73464 .3899 Mdot
.41812 .64455 Mdot
.31768 .28349 Mdot
.61327 .519 Mdot
.58918 .60032 Mdot
.36466 .45843 Mdot
.62784 .46459 Mdot
.74917 .37718 Mdot
.50759 .30336 Mdot
.64787 .48996 Mdot
.58907 .66068 Mdot
.32654 .41869 Mdot
.52001 .52297 Mdot
.5314 .84427 Mdot
.36079 .68181 Mdot
.65197 .4362 Mdot
.56237 .49876 Mdot
.28036 .39767 Mdot
.63653 .54092 Mdot
.39578 .58656 Mdot
.34515 .71523 Mdot
.56632 .65853 Mdot
.50967 .35896 Mdot
.26096 .3929 Mdot
.62843 .44076 Mdot
.64444 .55039 Mdot
.60677 .66966 Mdot
.65223 .51973 Mdot
.51201 .20785 Mdot
.23429 .38738 Mdot
.37227 .61534 Mdot
.49945 .28937 Mdot
.60121 .45267 Mdot
.27204 .41747 Mdot
.6059 .46312 Mdot
.49203 .2506 Mdot
.64591 .50978 Mdot
.30806 .39657 Mdot
.48851 .31761 Mdot
.38411 .48497 Mdot
.64326 .55676 Mdot
.64928 .47157 Mdot
.50405 .70537 Mdot
.71126 .51742 Mdot
.65353 .46262 Mdot
.46511 .3106 Mdot
.50601 .35411 Mdot
.52648 .34004 Mdot
.36779 .62342 Mdot
.41888 .37989 Mdot
.37178 .47405 Mdot
.66517 .45916 Mdot
.39795 .49438 Mdot
.72398 .5301 Mdot
.60773 .67951 Mdot
.39847 .81366 Mdot
.60331 .49197 Mdot
.52705 .3323 Mdot
.28085 .32918 Mdot
.47421 .3417 Mdot
.40733 .56625 Mdot
.38179 .46632 Mdot
.50376 .30775 Mdot
.63748 .47412 Mdot
.44546 .44419 Mdot
.57269 .83331 Mdot
.39126 .4859 Mdot
.66974 .44511 Mdot
.36045 .67855 Mdot
.35637 .6279 Mdot
.35106 .81935 Mdot
.34607 .48555 Mdot
.34093 .29804 Mdot
.61746 .49417 Mdot
.51049 .35598 Mdot
.35929 .48995 Mdot
.36424 .45604 Mdot
.38712 .61591 Mdot
.6621 .52803 Mdot
.65006 .47546 Mdot
.25077 .39846 Mdot
.37972 .50154 Mdot
.69039 .51306 Mdot
.61949 .53851 Mdot
.2443 .69394 Mdot
.48037 .27407 Mdot
.48185 .14836 Mdot
.69995 .51642 Mdot
.75442 .39772 Mdot
.47825 .5234 Mdot
.48514 .34857 Mdot
.67605 .50419 Mdot
.64038 .43948 Mdot
.41999 .63962 Mdot
.61647 .4798 Mdot
.3917 .66681 Mdot
.37291 .51238 Mdot
.41374 .82469 Mdot
.30816 .63311 Mdot
.41711 .71685 Mdot
.61534 .47151 Mdot
.52158 .45574 Mdot
.57941 .69501 Mdot
.37735 .52001 Mdot
.50427 .34839 Mdot
.59431 .46336 Mdot
.41732 .59919 Mdot
.38041 .61078 Mdot
.50872 .32456 Mdot
.34149 .32138 Mdot
.30266 .69617 Mdot
.59548 .52189 Mdot
.40356 .59448 Mdot
.29613 .61824 Mdot
.62792 .26637 Mdot
.40182 .45659 Mdot
.57116 .65362 Mdot
.40284 .64843 Mdot
.40737 .49402 Mdot
.47624 .26172 Mdot
.50232 .31925 Mdot
.53436 .35053 Mdot
.49255 .75681 Mdot
.40885 .62862 Mdot
.57284 .68812 Mdot
.48443 .40473 Mdot
.44283 .38017 Mdot
.58143 .65211 Mdot
.40247 .65057 Mdot
.50102 .35728 Mdot
.50508 .34543 Mdot
.5126 .33363 Mdot
.52094 .20739 Mdot
.52652 .30483 Mdot
.64284 .23199 Mdot
.60773 .53963 Mdot
.57643 .26652 Mdot
.62756 .50296 Mdot
.40204 .46917 Mdot
.48908 .30396 Mdot
.46147 .51042 Mdot
.58653 .48358 Mdot
.53759 .83986 Mdot
.63624 .49676 Mdot
.41067 .50637 Mdot
.65715 .49026 Mdot
.54139 .24078 Mdot
.53955 .32409 Mdot
.62901 .48607 Mdot
.36704 .44605 Mdot
.58265 .66751 Mdot
.53905 .27134 Mdot
.66091 .47911 Mdot
.34297 .40397 Mdot
.6061 .42774 Mdot
.29335 .70704 Mdot
.50758 .65328 Mdot
.60578 .69533 Mdot
.59314 .4332 Mdot
.40348 .66582 Mdot
.55597 .3259 Mdot
.57149 .27615 Mdot
.39085 .48719 Mdot
.78589 .47623 Mdot
.37723 .6153 Mdot
.5881 .41515 Mdot
.58079 .47179 Mdot
.55885 .6774 Mdot
.55444 .32454 Mdot
.35947 .4715 Mdot
.59916 .49201 Mdot
.68069 .49446 Mdot
.55578 .76706 Mdot
.56604 .26664 Mdot
.68313 .52325 Mdot
.58563 .64246 Mdot
.70233 .28678 Mdot
.66533 .49113 Mdot
.34974 .6367 Mdot
.53455 .30852 Mdot
.58142 .53348 Mdot
.67736 .26781 Mdot
.61367 .49052 Mdot
.50624 .31224 Mdot
.52314 .35908 Mdot
.30149 .36401 Mdot
.60593 .6903 Mdot
.64636 .50981 Mdot
.51732 .70607 Mdot
.64065 .51476 Mdot
.36861 .47127 Mdot
.67272 .52364 Mdot
.37901 .6231 Mdot
.40417 .36075 Mdot
.36335 .63258 Mdot
.67827 .51126 Mdot
.50608 .34079 Mdot
.35747 .47615 Mdot
.48319 .76976 Mdot
.47909 .60543 Mdot
.65322 .23862 Mdot
.28566 .43997 Mdot
.56143 .67556 Mdot
.5602 .65068 Mdot
.33975 .49398 Mdot
.6363 .48708 Mdot
.46046 .5582 Mdot
.57427 .47348 Mdot
.65989 .48898 Mdot
.66637 .4779 Mdot
.41554 .47183 Mdot
.38587 .4733 Mdot
.39739 .63847 Mdot
.61143 .46593 Mdot
.61754 .49082 Mdot
.49513 .31428 Mdot
.58553 .66735 Mdot
.36702 .61972 Mdot
.59176 .68911 Mdot
.37776 .64794 Mdot
.30888 .78032 Mdot
.69331 .48043 Mdot
.5818 .66639 Mdot
.34158 .48894 Mdot
.52919 .32548 Mdot
.25162 .4157 Mdot
.41613 .6236 Mdot
.39819 .62186 Mdot
.62748 .49485 Mdot
.51961 .30711 Mdot
.51063 .29857 Mdot
.56795 .6957 Mdot
.36654 .50114 Mdot
.6784 .50718 Mdot
.63174 .53902 Mdot
.6086 .76185 Mdot
.4038 .66154 Mdot
.62257 .25259 Mdot
.32107 .36288 Mdot
.63564 .48635 Mdot
.49999 .29297 Mdot
.64292 .45943 Mdot
.36931 .76004 Mdot
.50855 .28511 Mdot
.58636 .50961 Mdot
.51729 .41122 Mdot
.37089 .67448 Mdot
.27048 .37147 Mdot
.61961 .55109 Mdot
.24145 .44185 Mdot
.62707 .523 Mdot
.16148 .62379 Mdot
.35399 .24491 Mdot
.64491 .44518 Mdot
.59216 .50899 Mdot
.56789 .80833 Mdot
.61876 .49763 Mdot
.26335 .39584 Mdot
.69801 .53201 Mdot
.47242 .31826 Mdot
.47489 .5579 Mdot
.44193 .58659 Mdot
.60471 .67623 Mdot
.37221 .63334 Mdot
.65495 .61245 Mdot
.59726 .67134 Mdot
.48003 .33053 Mdot
.58833 .50551 Mdot
.75989 .50226 Mdot
.39786 .56964 Mdot
.5765 .48681 Mdot
.36787 .46977 Mdot
.43946 .57736 Mdot
.38521 .66507 Mdot
.38442 .49044 Mdot
.65808 .45826 Mdot
.80107 .59553 Mdot
.47864 .62075 Mdot
.15823 .47803 Mdot
.36186 .48604 Mdot
.37058 .46039 Mdot
.41376 .33585 Mdot
.60467 .67662 Mdot
.57009 .762 Mdot
.52743 .49258 Mdot
.38442 .46239 Mdot
.70426 .63065 Mdot
.4014 .57959 Mdot
.39907 .4024 Mdot
.5413 .32903 Mdot
.69029 .4737 Mdot
.64079 .47301 Mdot
.36233 .50151 Mdot
.70071 .41837 Mdot
.45059 .24026 Mdot
.38918 .48385 Mdot
.56122 .5096 Mdot
.34932 .41285 Mdot
.26011 .40822 Mdot
.25064 .39642 Mdot
.59748 .65903 Mdot
.34994 .705 Mdot
.49051 .32845 Mdot
.55714 .67761 Mdot
.29798 .39888 Mdot
.65181 .50936 Mdot
.38437 .50141 Mdot
.2474 .41324 Mdot
.3719 .48674 Mdot
.57306 .66502 Mdot
.60726 .68885 Mdot
.49464 .29866 Mdot
.48875 .34697 Mdot
.77591 .41099 Mdot
.72249 .64662 Mdot
.61871 .5019 Mdot
.74526 .43629 Mdot
.52714 .31204 Mdot
.56467 .30709 Mdot
.59752 .69966 Mdot
.58752 .66594 Mdot
.60999 .32429 Mdot
.65416 .52955 Mdot
.31568 .6415 Mdot
.66301 .48359 Mdot
.65626 .64906 Mdot
.58263 .47515 Mdot
.39012 .61824 Mdot
.621 .5107 Mdot
.20241 .56295 Mdot
.60241 .51076 Mdot
.66037 .46865 Mdot
.38906 .65493 Mdot
.66751 .553 Mdot
.37859 .62107 Mdot
.66007 .53103 Mdot
.59353 .64411 Mdot
.37506 .63381 Mdot
.66986 .73555 Mdot
.53736 .58161 Mdot
.27572 .41429 Mdot
.59836 .6662 Mdot
.58483 .70239 Mdot
.78188 .594 Mdot
.50008 .3486 Mdot
.45621 .28542 Mdot
.63733 .48768 Mdot
.39878 .58123 Mdot
.39079 .49712 Mdot
.61569 .48938 Mdot
.63677 .43691 Mdot
.63735 .5553 Mdot
.50402 .30274 Mdot
.41023 .64213 Mdot
.57745 .67113 Mdot
.39164 .59325 Mdot
.48448 .65852 Mdot
.36378 .61005 Mdot
.65653 .4225 Mdot
.69599 .51957 Mdot
.66502 .57638 Mdot
.75013 .42627 Mdot
.54452 .20274 Mdot
.50428 .32427 Mdot
.27008 .40795 Mdot
.60606 .67415 Mdot
.44104 .28415 Mdot
.52077 .34072 Mdot
.40098 .62313 Mdot
.64858 .48205 Mdot
.56327 .51707 Mdot
.51642 .50493 Mdot
.52574 .38703 Mdot
.75893 .64941 Mdot
.37235 .65924 Mdot
.25736 .40277 Mdot
.41224 .36925 Mdot
.4843 .38418 Mdot
.45806 .51755 Mdot
.64843 .46652 Mdot
.59106 .70193 Mdot
.49814 .3593 Mdot
.51924 .76504 Mdot
.36926 .50545 Mdot
.456 .47802 Mdot
.61509 .47302 Mdot
.30792 .30543 Mdot
.50584 .34048 Mdot
.58526 .65861 Mdot
.36136 .50125 Mdot
.60437 .69287 Mdot
.25744 .3922 Mdot
.18632 .56585 Mdot
.64435 .52168 Mdot
.64945 .45771 Mdot
.34525 .45589 Mdot
.49273 .33081 Mdot
.36681 .58491 Mdot
.53023 .77622 Mdot
.4037 .59624 Mdot
.45369 .55643 Mdot
.48341 .34881 Mdot
.50636 .23225 Mdot
.37827 .60202 Mdot
.35824 .5171 Mdot
.46037 .54168 Mdot
.35463 .51181 Mdot
.66593 .48449 Mdot
.52312 .32348 Mdot
.34635 .48809 Mdot
.51415 .73262 Mdot
.28591 .74409 Mdot
.51347 .24806 Mdot
.59836 .48665 Mdot
.41156 .82181 Mdot
.22838 .66961 Mdot
.7286 .44224 Mdot
.39316 .49986 Mdot
.62156 .45672 Mdot
.59575 .52312 Mdot
.63293 .51439 Mdot
.35681 .50805 Mdot
.45952 .67979 Mdot
.39242 .61037 Mdot
.64088 .49973 Mdot
.58706 .7003 Mdot
.38536 .62591 Mdot
.38752 .67969 Mdot
.38579 .58831 Mdot
.49557 .28317 Mdot
.5905 .51528 Mdot
.3843 .39078 Mdot
.1782 .64842 Mdot
.38494 .47469 Mdot
.27612 .41385 Mdot
.65846 .46149 Mdot
.7679 .33847 Mdot
.52659 .33913 Mdot
.40436 .59787 Mdot
.6281 .46304 Mdot
.48787 .68677 Mdot
.24597 .42482 Mdot
.37307 .6532 Mdot
.50105 .34725 Mdot
.72841 .44314 Mdot
.616 .48065 Mdot
.62954 .52484 Mdot
.48599 .32976 Mdot
.16864 .52658 Mdot
.40408 .37542 Mdot
.64752 .46262 Mdot
.38495 .48598 Mdot
.61636 .1707 Mdot
.64585 .55174 Mdot
.51742 .37895 Mdot
.28007 .41463 Mdot
.32818 .39089 Mdot
.63503 .26003 Mdot
.7136 .48571 Mdot
.43506 .81702 Mdot
.76425 .55199 Mdot
.38413 .80968 Mdot
.61902 .61741 Mdot
.26601 .5852 Mdot
.27102 .76404 Mdot
.36989 .44569 Mdot
.55568 .26266 Mdot
.64782 .77475 Mdot
.35709 .3259 Mdot
.50629 .6432 Mdot
.2927 .50477 Mdot
.50024 .67274 Mdot
.30711 .23625 Mdot
.37164 .60292 Mdot
.63969 .67184 Mdot
.67884 .50281 Mdot
.22413 .66038 Mdot
.57285 .24227 Mdot
.54469 .19167 Mdot
.37545 .79805 Mdot
.51497 .69359 Mdot
.60805 .81504 Mdot
.32918 .75219 Mdot
.77186 .50431 Mdot
.50746 .48055 Mdot
.34538 .54085 Mdot
.46287 .39531 Mdot
.67477 .60639 Mdot
.64483 .57155 Mdot
.20553 .52685 Mdot
.37131 .70509 Mdot
.73537 .32883 Mdot
.61588 .18074 Mdot
.41729 .61956 Mdot
.53282 .30361 Mdot
.60099 .76977 Mdot
.5557 .3052 Mdot
.34341 .51797 Mdot
.43628 .81744 Mdot
.24396 .6981 Mdot
.54146 .23957 Mdot
.21179 .39408 Mdot
.63046 .35868 Mdot
.83122 .4666 Mdot
.5094 .53021 Mdot
.5209 .36352 Mdot
.28572 .56482 Mdot
.44321 .37991 Mdot
.35868 .56959 Mdot
.51137 .22097 Mdot
.55307 .69428 Mdot
.71704 .69711 Mdot
.50021 .34509 Mdot
.64381 .27257 Mdot
.2818 .41976 Mdot
.2965 .4045 Mdot
.37586 .57896 Mdot
.38225 .76865 Mdot
.26741 .43275 Mdot
.361 .40069 Mdot
.2844 .30539 Mdot
.58561 .8438 Mdot
.73103 .59365 Mdot
.37073 .74409 Mdot
.42233 .48699 Mdot
.75899 .55867 Mdot
.39069 .34227 Mdot
.73976 .62231 Mdot
.44616 .37174 Mdot
.74036 .74187 Mdot
.17674 .59523 Mdot
.65011 .79906 Mdot
.50885 .26599 Mdot
.68579 .51438 Mdot
.4247 .78236 Mdot
.72477 .38531 Mdot
.60283 .70195 Mdot
.56137 .84475 Mdot
.57854 .70707 Mdot
.48497 .2769 Mdot
.35164 .31872 Mdot
.53414 .22011 Mdot
.35586 .69994 Mdot
.58743 .63483 Mdot
.57199 .46769 Mdot
.84606 .6404 Mdot
.46624 .82807 Mdot
.31111 .37148 Mdot
.23712 .68872 Mdot
.35976 .43993 Mdot
.38881 .55757 Mdot
.36875 .5126 Mdot
.27269 .75055 Mdot
.51902 .33691 Mdot
.18698 .66924 Mdot
.26617 .73509 Mdot
.44628 .22055 Mdot
.88749 .58289 Mdot
.30314 .2596 Mdot
.58166 .26482 Mdot
.77208 .52696 Mdot
.73788 .69173 Mdot
.40501 .31287 Mdot
.44185 .21407 Mdot
.36517 .5411 Mdot
.16276 .53196 Mdot
.31113 .7743 Mdot
.68675 .64246 Mdot
.39723 .69798 Mdot
.37087 .32104 Mdot
.51856 .55673 Mdot
.50608 .37727 Mdot
.54437 .60768 Mdot
.56836 .58638 Mdot
.62861 .80609 Mdot
.76705 .35754 Mdot
.74618 .25498 Mdot
.63233 .62826 Mdot
.42909 .19623 Mdot
.31745 .71831 Mdot
.65521 .73718 Mdot
.47742 .24465 Mdot
.36058 .36544 Mdot
.62229 .42082 Mdot
.4249 .38624 Mdot
.55123 .4915 Mdot
.55616 .70856 Mdot
.41597 .35663 Mdot
.26516 .63481 Mdot
.65104 .63423 Mdot
.51587 .80846 Mdot
.51768 .43846 Mdot
.48978 .28829 Mdot
.76166 .59992 Mdot
.71758 .61188 Mdot
.25726 .70092 Mdot
.39826 .24826 Mdot
.15442 .49514 Mdot
.41555 .23909 Mdot
.57421 .47061 Mdot
.56191 .28008 Mdot
.63251 .57172 Mdot
.73178 .61853 Mdot
.58998 .52907 Mdot
.27433 .31989 Mdot
.20099 .6549 Mdot
.75548 .37464 Mdot
.66094 .61707 Mdot
.75683 .44022 Mdot
.16445 .55289 Mdot
.44364 .79091 Mdot
.3496 .25607 Mdot
.56465 .38229 Mdot
.81024 .67992 Mdot
.39088 .63362 Mdot
.70142 .6367 Mdot
.39865 .51126 Mdot
.49465 .76091 Mdot
.70292 .74988 Mdot
.44075 .23297 Mdot
.19458 .64742 Mdot
.37036 .36795 Mdot
.34099 .66122 Mdot
.40472 .41757 Mdot
.42991 .61089 Mdot
.76717 .45928 Mdot
.65944 .55195 Mdot
.70937 .55883 Mdot
.55455 .67163 Mdot
.70512 .371 Mdot
.46837 .78964 Mdot
.25264 .49156 Mdot
.69188 .44133 Mdot
.25556 .52244 Mdot
.25441 .40089 Mdot
.44842 .45808 Mdot
.34111 .81298 Mdot
.70655 .5093 Mdot
.33482 .23588 Mdot
.17476 .58217 Mdot
.45206 .54627 Mdot
.38537 .735 Mdot
.31344 .33987 Mdot
.69721 .77494 Mdot
.23597 .70527 Mdot
.25153 .66028 Mdot
.42345 .82769 Mdot
.14842 .44507 Mdot
.76146 .70382 Mdot
.64694 .38827 Mdot
.41138 .49267 Mdot
.09066 .5059 Mdot
.39672 .60359 Mdot
.78998 .47075 Mdot
.72586 .38201 Mdot
.48111 .70021 Mdot
.55146 .34641 Mdot
.6271 .40649 Mdot
.29915 .44062 Mdot
.48735 .37024 Mdot
.57363 .46184 Mdot
.52897 .86068 Mdot
.74895 .73809 Mdot
.54699 .85521 Mdot
.18665 .5733 Mdot
.40943 .82611 Mdot
.61849 .79138 Mdot
.63275 .22557 Mdot
.57423 .76853 Mdot
.66794 .52702 Mdot
.68783 .66593 Mdot
.31226 .255 Mdot
.36248 .59489 Mdot
.23899 .38227 Mdot
.51599 .27442 Mdot
.71021 .75723 Mdot
.35874 .82932 Mdot
.63128 .32909 Mdot
.69498 .29677 Mdot
.55329 .57958 Mdot
.72042 .63568 Mdot
.70726 .56708 Mdot
.21043 .5037 Mdot
.28152 .70998 Mdot
.6318 .78838 Mdot
.6966 .61981 Mdot
.28404 .5138 Mdot
.25269 .64825 Mdot
.40684 .20957 Mdot
.35247 .76503 Mdot
.62637 .7707 Mdot
.43111 .22511 Mdot
.56568 .3958 Mdot
.44846 .23772 Mdot
.20491 .48181 Mdot
.32831 .64216 Mdot
.72113 .59255 Mdot
.36472 .6605 Mdot
.68669 .64845 Mdot
.48634 .44516 Mdot
.58396 .77099 Mdot
.76892 .55573 Mdot
.67948 .64624 Mdot
.26386 .66257 Mdot
.49152 .85365 Mdot
.18056 .43405 Mdot
.81523 .60335 Mdot
.2285 .44658 Mdot
.54893 .47258 Mdot
.66583 .53647 Mdot
.17975 .61276 Mdot
.46977 .8602 Mdot
.2012 .66725 Mdot
.30724 .30213 Mdot
.507 .73169 Mdot
.4106 .46975 Mdot
.80452 .52654 Mdot
.2429 .46839 Mdot
.28581 .72297 Mdot
.42966 .32304 Mdot
.32825 .46225 Mdot
.3776 .36879 Mdot
.78265 .47623 Mdot
.78317 .52777 Mdot
.66494 .29268 Mdot
.66469 .56358 Mdot
.59887 .2572 Mdot
.53803 .32732 Mdot
.31642 .28969 Mdot
.73225 .62673 Mdot
.38728 .63608 Mdot
.65266 .75469 Mdot
.70027 .56709 Mdot
.63125 .41957 Mdot
.3301 .64979 Mdot
.50515 .37576 Mdot
.75065 .41939 Mdot
.35291 .53431 Mdot
.28699 .77549 Mdot
.32271 .25829 Mdot
.7523 .52415 Mdot
.7557 .58508 Mdot
.57435 .74904 Mdot
.40765 .38789 Mdot
.34299 .50063 Mdot
.36155 .7863 Mdot
.52298 .60022 Mdot
.76086 .59415 Mdot
.60513 .25861 Mdot
.51007 .78061 Mdot
.63137 .43613 Mdot
.30113 .35092 Mdot
.68975 .25988 Mdot
.45224 .47522 Mdot
.4614 .30493 Mdot
.47102 .36654 Mdot
.30584 .21973 Mdot
.2127 .57085 Mdot
.39044 .23976 Mdot
.36744 .78402 Mdot
.35888 .51397 Mdot
.46989 .30755 Mdot
.67435 .65733 Mdot
.44781 .75426 Mdot
.73369 .3121 Mdot
.32934 .68998 Mdot
.70657 .57343 Mdot
.23797 .48184 Mdot
.41766 .82199 Mdot
.5373 .83062 Mdot
.65672 .19775 Mdot
.47884 .35693 Mdot
.46075 .77973 Mdot
.48549 .77843 Mdot
.49758 .36176 Mdot
.52225 .38516 Mdot
.51352 .49109 Mdot
.37467 .81391 Mdot
.43446 .39246 Mdot
.20487 .45522 Mdot
.45944 .54391 Mdot
.47652 .68043 Mdot
.53061 .76714 Mdot
.71327 .59175 Mdot
.37221 .78234 Mdot
.64664 .28298 Mdot
.76975 .67228 Mdot
.624 .57636 Mdot
.78217 .41063 Mdot
.80527 .52548 Mdot
.50051 .52048 Mdot
.52037 .22877 Mdot
.27768 .63988 Mdot
.62978 .51049 Mdot
.57894 .84823 Mdot
.25714 .69243 Mdot
.42243 .34136 Mdot
.3232 .50611 Mdot
.62018 .53059 Mdot
.6001 .53288 Mdot
.6481 .39984 Mdot
.32643 .37819 Mdot
.80026 .65487 Mdot
.64242 .64239 Mdot
.54902 .48516 Mdot
.60017 .25195 Mdot
.33658 .23539 Mdot
.3991 .77289 Mdot
.30117 .71185 Mdot
.47479 .44598 Mdot
.31304 .2566 Mdot
.43928 .50973 Mdot
.19918 .45213 Mdot
.23521 .52301 Mdot
.60707 .79256 Mdot
.53837 .43381 Mdot
.34253 .36952 Mdot
.55936 .75498 Mdot
.66276 .46793 Mdot
.34128 .32184 Mdot
.33839 .75512 Mdot
.79237 .31128 Mdot
.38925 .32923 Mdot
.5076 .86576 Mdot
.68376 .57132 Mdot
.35113 .37549 Mdot
.72294 .73992 Mdot
.8501 .38959 Mdot
.20471 .51476 Mdot
.61467 .81285 Mdot
.43098 .44513 Mdot
.37667 .79115 Mdot
.39692 .45812 Mdot
.4812 .41413 Mdot
.7317 .41856 Mdot
.36747 .81009 Mdot
.4055 .75551 Mdot
.3934 .78297 Mdot
.6377 .395 Mdot
.4137 .83303 Mdot
.44363 .35945 Mdot
.33398 .20638 Mdot
.34749 .65463 Mdot
.255 .3193 Mdot
.59121 .3809 Mdot
.63236 .58827 Mdot
.70071 .62888 Mdot
.41046 .18258 Mdot
.58924 .20248 Mdot
.67032 .39849 Mdot
.65979 .69979 Mdot
.31835 .34929 Mdot
.75638 .58016 Mdot
.28599 .73045 Mdot
.31295 .22915 Mdot
.50945 .77249 Mdot
.35199 .27564 Mdot
.17691 .55418 Mdot
.32104 .37887 Mdot
.23584 .56267 Mdot
.36792 .74495 Mdot
.18281 .48723 Mdot
.6918 .58145 Mdot
.40471 .13448 Mdot
.43002 .66357 Mdot
.51479 .49623 Mdot
.67685 .78293 Mdot
.27884 .70744 Mdot
.43621 .29153 Mdot
.49902 .21203 Mdot
.80041 .43404 Mdot
.70298 .68068 Mdot
.66079 .47392 Mdot
.42346 .83826 Mdot
.69026 .71453 Mdot
.58632 .83439 Mdot
.15213 .54966 Mdot
.60738 .27332 Mdot
.69945 .45929 Mdot
.42174 .64458 Mdot
.52273 .53729 Mdot
.65223 .70295 Mdot
.62901 .79733 Mdot
.78854 .44251 Mdot
.48082 .59824 Mdot
.26535 .57379 Mdot
.31685 .68407 Mdot
.54142 .46225 Mdot
.29214 .27356 Mdot
.32709 .36346 Mdot
.63993 .62205 Mdot
.24258 .63847 Mdot
.71579 .62964 Mdot
.62735 .25616 Mdot
.79054 .54352 Mdot
.4176 .27144 Mdot
.33072 .43673 Mdot
.42079 .6337 Mdot
.55534 .80471 Mdot
.30693 .70161 Mdot
.27244 .32404 Mdot
.80115 .6274 Mdot
.35854 .35907 Mdot
.63727 .68581 Mdot
.50385 .79898 Mdot
.40322 .30686 Mdot
.34291 .54307 Mdot
.78638 .52022 Mdot
.77882 .40743 Mdot
.28896 .65967 Mdot
.70401 .44714 Mdot
.3154 .78162 Mdot
.71534 .59487 Mdot
.55176 .78799 Mdot
.53349 .57301 Mdot
.72119 .35901 Mdot
.58606 .3227 Mdot
.69578 .72508 Mdot
.45109 .50678 Mdot
.83439 .65317 Mdot
.54861 .33512 Mdot
.58847 .84296 Mdot
.37779 .49758 Mdot
.71398 .25088 Mdot
.28626 .68555 Mdot
.48093 .46503 Mdot
.47061 .52731 Mdot
.2987 .35311 Mdot
.33718 .40999 Mdot
.17178 .55278 Mdot
.44761 .23385 Mdot
.36811 .60135 Mdot
.48849 .61187 Mdot
.2063 .46375 Mdot
.51792 .81543 Mdot
.69009 .4937 Mdot
.35988 .70577 Mdot
.50455 .52858 Mdot
.40739 .5542 Mdot
.1838 .61638 Mdot
.28318 .62834 Mdot
.57908 .53367 Mdot
.72217 .63711 Mdot
.65014 .78591 Mdot
.26876 .73118 Mdot
.44948 .24896 Mdot
.55193 .49504 Mdot
.39611 .52224 Mdot
.70133 .73886 Mdot
.46572 .82399 Mdot
.31162 .64049 Mdot
.3957 .39906 Mdot
.7258 .59736 Mdot
.5871 .86412 Mdot
.74557 .73942 Mdot
.8079 .62548 Mdot
.4591 .55264 Mdot
.45033 .32177 Mdot
.77173 .34815 Mdot
.54812 .78909 Mdot
.23761 .3385 Mdot
.25623 .67785 Mdot
.70616 .63272 Mdot
.82838 .37442 Mdot
.56512 .20815 Mdot
.48066 .65507 Mdot
.58715 .32549 Mdot
.74007 .39684 Mdot
.38327 .44887 Mdot
.6906 .69273 Mdot
.50646 .61451 Mdot
.33324 .49606 Mdot
.32014 .35205 Mdot
.35559 .40554 Mdot
.55511 .78666 Mdot
.7139 .28854 Mdot
.56263 .52869 Mdot
.48278 .81504 Mdot
.45995 .35397 Mdot
.51384 .76653 Mdot
.57567 .75132 Mdot
.501 .62444 Mdot
.39188 .59608 Mdot
.68112 .56183 Mdot
.43086 .42582 Mdot
.44394 .47827 Mdot
.82441 .54004 Mdot
.57053 .70515 Mdot
.5383 .28933 Mdot
.53339 .20395 Mdot
.47362 .35152 Mdot
.45065 .85894 Mdot
.21098 .50511 Mdot
.59156 .25088 Mdot
.43087 .64341 Mdot
.28643 .53872 Mdot
.84536 .49046 Mdot
.77753 .49217 Mdot
.56167 .6087 Mdot
.45515 .36446 Mdot
.53125 .34486 Mdot
.42494 .6509 Mdot
.25307 .38413 Mdot
.66735 .2836 Mdot
.33123 .23233 Mdot
.58723 .75549 Mdot
.51121 .36562 Mdot
.47297 .66334 Mdot
.745 .4981 Mdot
.32589 .79852 Mdot
.38662 .59126 Mdot
.7967 .69464 Mdot
.69657 .51679 Mdot
.74221 .71073 Mdot
.18588 .6235 Mdot
.40368 .35524 Mdot
.45972 .56333 Mdot
.30969 .51374 Mdot
.67001 .45668 Mdot
.5664 .53829 Mdot
.49083 .34401 Mdot
.56367 .76813 Mdot
.58553 .67733 Mdot
.75178 .64483 Mdot
.35031 .51362 Mdot
.44001 .20398 Mdot
.29643 .27512 Mdot
.53574 .30598 Mdot
.5207 .61387 Mdot
.42377 .77134 Mdot
.50928 .44881 Mdot
.50355 .52787 Mdot
.5676 .80629 Mdot
.73893 .32372 Mdot
.5167 .36344 Mdot
.8012 .63256 Mdot
.6252 .69387 Mdot
.24982 .73229 Mdot
.73498 .48508 Mdot
.50833 .52106 Mdot
.51275 .44728 Mdot
.30319 .34411 Mdot
.64282 .2634 Mdot
.29554 .7142 Mdot
.75471 .6076 Mdot
.48998 .40352 Mdot
.67943 .64871 Mdot
.6059 .56181 Mdot
.26144 .57355 Mdot
.26058 .30588 Mdot
.83523 .39283 Mdot
.61013 .3567 Mdot
.38776 .35982 Mdot
.46905 .36877 Mdot
.33228 .238 Mdot
.54917 .31392 Mdot
.45436 .70929 Mdot
.7418 .33753 Mdot
.28576 .68703 Mdot
.28431 .76413 Mdot
.25651 .69925 Mdot
.54322 .55195 Mdot
.31371 .66982 Mdot
.76233 .53923 Mdot
.73821 .48141 Mdot
.47179 .49892 Mdot
.6669 .45557 Mdot
.54709 .44841 Mdot
.43456 .27039 Mdot
.27834 .32933 Mdot
.60478 .41121 Mdot
.35558 .79794 Mdot
.24635 .72539 Mdot
.45801 .8413 Mdot
.331 .62808 Mdot
.49438 .28164 Mdot
.71106 .76503 Mdot
.61368 .23546 Mdot
.28063 .72881 Mdot
.59846 .38114 Mdot
.28177 .23989 Mdot
.68846 .76069 Mdot
.27064 .64088 Mdot
.44612 .21739 Mdot
.24432 .37354 Mdot
.19081 .62183 Mdot
.33227 .20789 Mdot
.68241 .59047 Mdot
.175 .6003 Mdot
.84524 .63964 Mdot
.61959 .3781 Mdot
.35183 .40288 Mdot
.57941 .30741 Mdot
.7574 .5366 Mdot
.33193 .22468 Mdot
.66989 .52774 Mdot
.35442 .64935 Mdot
.50019 .65652 Mdot
.7137 .62503 Mdot
.72006 .52045 Mdot
.34313 .21575 Mdot
.64836 .70421 Mdot
.63734 .67174 Mdot
.46631 .77244 Mdot
.65646 .77311 Mdot
.65686 .27138 Mdot
.56244 .50417 Mdot
.49174 .27022 Mdot
.58862 .65136 Mdot
.65316 .60632 Mdot
.617 .53404 Mdot
.43587 .55068 Mdot
.51901 .48541 Mdot
.52567 .86353 Mdot
.45484 .7333 Mdot
.40642 .71888 Mdot
.47957 .36976 Mdot
.32133 .36894 Mdot
.4395 .79696 Mdot
.35504 .32288 Mdot
.37086 .2001 Mdot
.7657 .36202 Mdot
.42821 .82342 Mdot
.3673 .37575 Mdot
.67988 .61705 Mdot
.82697 .50639 Mdot
.39735 .46659 Mdot
.72858 .40705 Mdot
.61592 .79705 Mdot
.34665 .3379 Mdot
.46217 .31232 Mdot
.24887 .62124 Mdot
.27637 .59141 Mdot
.33658 .34276 Mdot
.17434 .57861 Mdot
.47852 .78565 Mdot
.59757 .30038 Mdot
.52272 .82937 Mdot
.36927 .68127 Mdot
.69565 .62251 Mdot
.22777 .5888 Mdot
.32122 .22849 Mdot
.51345 .43518 Mdot
.32806 .78849 Mdot
.4702 .5045 Mdot
.69917 .71311 Mdot
.63857 .52305 Mdot
.68417 .27191 Mdot
.28787 .33348 Mdot
.24219 .62992 Mdot
.38893 .24646 Mdot
.50939 .28084 Mdot
.2963 .29034 Mdot
.35028 .5419 Mdot
.70137 .69488 Mdot
.64158 .60012 Mdot
.55012 .27632 Mdot
.59893 .62191 Mdot
.28859 .41764 Mdot
.69144 .52048 Mdot
.73155 .68804 Mdot
.32576 .69749 Mdot
.71671 .40656 Mdot
.64413 .38647 Mdot
.55479 .80632 Mdot
.34116 .7154 Mdot
.26308 .32803 Mdot
.63729 .39046 Mdot
.30129 .39256 Mdot
.58027 .21055 Mdot
.36182 .29686 Mdot
.61352 .54753 Mdot
.45573 .707 Mdot
.46888 .32472 Mdot
.52345 .81749 Mdot
.49859 .25774 Mdot
.6656 .73731 Mdot
.4578 .44952 Mdot
.41575 .77787 Mdot
.52075 .57187 Mdot
.18867 .6254 Mdot
.24232 .37393 Mdot
.73397 .62577 Mdot
.3347 .47371 Mdot
.42763 .44179 Mdot
.3912 .3187 Mdot
.32307 .76683 Mdot
.43027 .25165 Mdot
.76155 .49846 Mdot
.38094 .36279 Mdot
.75396 .38964 Mdot
.15853 .5693 Mdot
.72673 .64946 Mdot
.47148 .49694 Mdot
.73815 .53948 Mdot
.29235 .39553 Mdot
.25343 .4174 Mdot
.47401 .71357 Mdot
.63987 .25189 Mdot
.41963 .69877 Mdot
.47054 .60025 Mdot
.68892 .51633 Mdot
.76278 .33056 Mdot
.50429 .82624 Mdot
.44337 .27778 Mdot
.48211 .47887 Mdot
.55273 .75163 Mdot
.70844 .69336 Mdot
.55244 .13025 Mdot
.57082 .85351 Mdot
.63922 .52373 Mdot
.46735 .546 Mdot
.74487 .64876 Mdot
.39033 .66689 Mdot
.67674 .29518 Mdot
.54816 .80923 Mdot
.37664 .46004 Mdot
.50661 .74083 Mdot
.22695 .39058 Mdot
.2917 .34808 Mdot
.68554 .73363 Mdot
.40427 .45481 Mdot
.47206 .86709 Mdot
.25029 .66863 Mdot
.29483 .32714 Mdot
.47714 .11536 Mdot
.2938 .30753 Mdot
.44678 .31636 Mdot
.39296 .75319 Mdot
.48555 .85339 Mdot
.45692 .54959 Mdot
.49257 .75726 Mdot
.65337 .38733 Mdot
.74227 .61896 Mdot
.65215 .64678 Mdot
.35023 .27651 Mdot
.3129 .27972 Mdot
.34548 .19812 Mdot
.2872 .53734 Mdot
.83067 .54319 Mdot
.63253 .27319 Mdot
.53737 .83489 Mdot
.20534 .5104 Mdot
.82028 .36005 Mdot
.274 .75143 Mdot
.67999 .67423 Mdot
.36252 .20949 Mdot
.39014 .74442 Mdot
.77141 .626 Mdot
.72159 .28087 Mdot
.19361 .52452 Mdot
.75386 .34363 Mdot
.27288 .52629 Mdot
.37573 .27177 Mdot
.68359 .64796 Mdot
.74902 .3959 Mdot
.46685 .50566 Mdot
.59382 .81421 Mdot
.43199 .18607 Mdot
.74881 .59014 Mdot
.52227 .74276 Mdot
.77627 .63342 Mdot
.47455 .81893 Mdot
.35051 .74826 Mdot
.48597 .522 Mdot
.84738 .62024 Mdot
.62703 .80632 Mdot
.36531 .31097 Mdot
.61237 .54268 Mdot
.26272 .7528 Mdot
.49111 .56216 Mdot
.66126 .39331 Mdot
.20904 .63577 Mdot
.63821 .63998 Mdot
.52501 .46585 Mdot
.64658 .55272 Mdot
.78557 .51024 Mdot
.50998 .23657 Mdot
.74811 .40071 Mdot
.57114 .74063 Mdot
.75598 .58799 Mdot
.43637 .1881 Mdot
.73872 .69827 Mdot
.72746 .45931 Mdot
.47809 .34417 Mdot
.50396 .85961 Mdot
.76967 .5019 Mdot
.63067 .58089 Mdot
.58008 .27918 Mdot
.43681 .24507 Mdot
.30029 .45607 Mdot
.55041 .47813 Mdot
.40951 .38947 Mdot
.7031 .62698 Mdot
.53478 .79148 Mdot
.72981 .42134 Mdot
.89349 .57501 Mdot
.1868 .62946 Mdot
.54463 .34987 Mdot
.6916 .39071 Mdot
.49752 .63443 Mdot
.46614 .83978 Mdot
.27956 .50869 Mdot
.57486 .74982 Mdot
.5165 .19243 Mdot
.76815 .60506 Mdot
.59838 .44747 Mdot
.18653 .57754 Mdot
.29163 .75985 Mdot
.4571 .17707 Mdot
.31525 .78081 Mdot
.68047 .44045 Mdot
.6897 .46188 Mdot
.77803 .26654 Mdot
.39523 .80642 Mdot
.7129 .48734 Mdot
.46763 .22073 Mdot
.55159 .35314 Mdot
.67759 .51013 Mdot
.22893 .39591 Mdot
.72479 .58055 Mdot
.6482 .65552 Mdot
.37155 .81139 Mdot
.46884 .35985 Mdot
.44905 .55556 Mdot
.40698 .49619 Mdot
.46694 .52183 Mdot
.57774 .53517 Mdot
.34461 .48205 Mdot
.64691 .66752 Mdot
.48633 .56765 Mdot
.30856 .43217 Mdot
.67864 .58884 Mdot
.18731 .44002 Mdot
.60716 .58769 Mdot
.54475 .55894 Mdot
.5874 .39326 Mdot
.5891 .20181 Mdot
.65031 .7026 Mdot
.63257 .72131 Mdot
.17424 .59401 Mdot
.16925 .39828 Mdot
.44532 .60562 Mdot
.67976 .41698 Mdot
.54402 .39963 Mdot
.63021 .25068 Mdot
.58878 .29251 Mdot
.35335 .42334 Mdot
.25321 .41144 Mdot
.65183 .42294 Mdot
.7518 .5245 Mdot
.3841 .51162 Mdot
.55717 .86909 Mdot
.65212 .54256 Mdot
.62939 .2954 Mdot
.30939 .74869 Mdot
.52022 .76539 Mdot
.54227 .52039 Mdot
.66426 .45151 Mdot
.43826 .35204 Mdot
.49042 .57197 Mdot
.75279 .49624 Mdot
.54083 .76625 Mdot
.4804 .83535 Mdot
.56 .55583 Mdot
.61622 .28685 Mdot
.63534 .49539 Mdot
.57991 .63587 Mdot
.42248 .40301 Mdot
.81014 .56137 Mdot
.58213 .61843 Mdot
.26827 .7254 Mdot
.62662 .66546 Mdot
.64213 .64163 Mdot
.563 .25612 Mdot
.58094 .83857 Mdot
.38532 .33061 Mdot
.60158 .26838 Mdot
.42516 .30019 Mdot
.24202 .58077 Mdot
.66059 .69711 Mdot
.4072 .67233 Mdot
.60049 .41307 Mdot
.55378 .35075 Mdot
.37838 .82787 Mdot
.77811 .48943 Mdot
.37974 .42647 Mdot
.29021 .66538 Mdot
.582 .21436 Mdot
.47245 .52337 Mdot
.43678 .12417 Mdot
.28678 .49781 Mdot
.47806 .86731 Mdot
.51388 .78632 Mdot
.54069 .40653 Mdot
.3191 .34602 Mdot
.69549 .55083 Mdot
.39417 .64996 Mdot
.47233 .83832 Mdot
.73894 .51713 Mdot
.35964 .28872 Mdot
.65407 .53589 Mdot
.4346 .36917 Mdot
.75133 .51429 Mdot
.30807 .65872 Mdot
.35545 .63101 Mdot
.44616 .24715 Mdot
.35388 .75675 Mdot
.49219 .57351 Mdot
.25761 .2698 Mdot
.63037 .79766 Mdot
.35903 .78561 Mdot
.31994 .68517 Mdot
.7115 .24446 Mdot
.45145 .35637 Mdot
.74022 .48346 Mdot
.33821 .45616 Mdot
.7746 .52708 Mdot
.34026 .33859 Mdot
.53796 .78731 Mdot
.30227 .38905 Mdot
.50298 .46873 Mdot
.34198 .15683 Mdot
.6768 .66728 Mdot
.44037 .29285 Mdot
.33104 .31979 Mdot
.34271 .78728 Mdot
.52783 .70991 Mdot
.15943 .47475 Mdot
.20505 .54267 Mdot
.58429 .5422 Mdot
.69785 .26899 Mdot
.77261 .66268 Mdot
.30448 .61471 Mdot
.83933 .52183 Mdot
.31178 .70336 Mdot
.67143 .60736 Mdot
.23732 .62051 Mdot
.4773 .35491 Mdot
.55342 .33733 Mdot
.21194 .48791 Mdot
.20824 .40624 Mdot
.68414 .41299 Mdot
.44918 .82157 Mdot
.82603 .43419 Mdot
.57646 .75676 Mdot
.4282 .83229 Mdot
.42471 .48342 Mdot
.50239 .38644 Mdot
.64527 .70184 Mdot
.61519 .69522 Mdot
.38739 .6721 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Gooooo`;o
0000/?ooool001cooooo00?o0000ooooooooool0Uoooool2o`0000Gooooo0_l0002Yooooo`007?oo
ool00ol0003oooooooooo`2Mooooo`?o0000ZOooool001cooooo00?o0000ooooooooool0R_ooool2
o`00017ooooo0_l0002Zooooo`007?ooool00ol0003oooooooooo`25ooooo`;o00000oooool2o`00
0;gooooo000Looooo`03o`000?oooooooooo07Oooooo0_l0000<ooooo`;o0000:Oooool2o`0009Oo
oooo000Looooo`03o`000?oooooooooo07Oooooo0_l00007ooooo`;o0000;_ooool2o`0009Oooooo
000Looooo`03o`000?oooooooooo083ooooo0_l00037ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0;Kooooo0_l0002Aooooo`007?ooool00ol0003o
ooooooooo`2fooooo`;o0000TOooool001cooooo00?o0000ooooooooool0VOooool4o`0000Cooooo
0_l00002ooooo`;o0000X_ooool001cooooo0_l0001booooo`Co00009?ooool4o`0000Cooooo0_l0
0002ooooo`;o00004_ooool2o`0000;ooooo0_l000000ooooooo0000o`000027ooooo`007?ooool0
0ol0003oooooooooo`1[ooooo`;o00001?ooool4o`0004Cooooo0_l00002ooooo`;o000000?ooooo
o`000?l00000Qoooool001cooooo00?o0000ooooooooool0Joooool2o`0004;ooooo1?l0000:oooo
o`;o0000R_ooool001cooooo00?o0000ooooooooool0[oooool4o`0000[ooooo0_l0002:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0;Sooooo0_l0
002?ooooo`007?ooool00ol0003oooooooooo`2hooooo`;o00002_ooool2o`0008?ooooo000Loooo
o`03o`000?oooooooooo0;gooooo0_l00005ooooo`;o0000Poooool001cooooo00?o0000oooooooo
ool0TOooool2o`0002[ooooo0ol000000ooooooo0000o`000026ooooo`007?ooool00ol0003ooooo
ooooo`2Aooooo`;o00000oooool2o`0001cooooo0_l00008ooooo`;o000000Coooooo`000?l0003o
oooo0_l00023ooooo`007?ooool00ol0003oooooooooo`22ooooo`;o00004_ooool2o`0001cooooo
0_l0000>ooooo`;o0000Poooool001cooooo00?o0000ooooooooool0P_ooool4o`0000?ooooo0_l0
0003ooooo`Co00001oooool2o`0002oooooo0_l00006ooooo`;o0000MOooool001cooooo00?o0000
ooooooooool0O_ooool2o`0000Cooooo0_l00003ooooo`?o00000_ooool5o`0000Kooooo0_l00006
ooooo`;o00002Oooool2o`0000Cooooo0_l0000Fooooo`;o00001_ooool2o`0007Gooooo00001_oo
ooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003ooooooooo
o`1Iooooo`;o00008oooool2o`0000[ooooo0_l00005ooooo`;o00001oooool3o`0000;ooooo1ol0
0006ooooo`Go000000?oooooo`000?l00000UOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo05Wo
oooo0_l0000Jooooo`;o00003Oooool2o`0000;ooooo1?l0000>ooooo`?o00000_ooool2o`0000;o
oooo0ol00007ooooo`Co00002?ooool2o`0001?ooooo0_l0001iooooo`0000?ooooooa0@4?ooool0
0_ooool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0
K?ooool2o`0000Oooooo0_l00005ooooo`;o00001Oooool3o`0000;ooooo1?l0000]ooooo`;o0000
00?oooooo`000?l000000_l00008ooooo`;o00001?ooool2o`0000;ooooo0ol0001dooooo`0000?o
ooooo`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0
001/ooooo`;o00001oooool3o`0000Cooooo0_l00005ooooo`;o00000oooool2o`0002?ooooo0_l0
000=ooooo`Co00002?ooool2o`0000Sooooo0ol00007ooooo`;o0000Joooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooo
oooo073ooooo0_l00003ooooo`?o00004oooool2o`0001[ooooo1?l00002ooooo`;o00003Oooool4
o`000003ooooool0003o000001Wooooo0_l0001[ooooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0J?ooool3o`00
00Gooooo0_l0000Iooooo`;o000000?oooooo`000?l000003_ooool2o`0000?ooooo2?l00002oooo
o`;o00000oooool4o`0000_ooooo0_l0000Cooooo`;o0000LOooool00006oooooomgMgOoV9RHoooo
oonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0J?oo
ool3o`0000Oooooo0_l0000<ooooo`;o00003?ooool2o`0000kooooo0_l00003ooooo`Go00000ooo
ool2o`0000Gooooo1?l00003ooooo`;o00006oooool2o`00077ooooo00001_ooooook^k^oc8b<_l0
003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo07;o
oooo0_l0000<ooooo`;o00002_ooool2o`000003ooooool0003o000000gooooo0_l0000;ooooo`;o
00003?ooool2o`0001gooooo0_l0001_ooooo`007?ooool00ol0003oooooooooo`1/ooooo`;o0000
7_ooool5o`0002Cooooo0_l00002ooooo`;o00007Oooool2o`0006oooooo000Looooo`03o`000?oo
oooooooo063ooooo0_l0000:ooooo`;o00003oooool2o`0000_ooooo1Ol00005ooooo`;o00002?oo
ool2o`0000;ooooo0_l00006ooooo`;o00002Oooool2o`0000;ooooo0_l00002ooooo`;o0000R_oo
ool001cooooo00?o0000ooooooooool0H?ooool2o`0000Kooooo0_l0000Cooooo`;o00002oooool5
o`0000Gooooo0_l00008ooooo`;o00000_ooool2o`0000Kooooo0_l00005ooooo`?o00002Oooool2
o`0000?ooooo0_l00025ooooo`007?ooool00ol0003oooooooooo`1Xooooo`;o00007_ooool2o`00
013ooooo1Ol0000Booooo`Go00001oooool2o`0000?ooooo0_l00006ooooo`;o00005_ooool2o`00
06Gooooo000Looooo`03o`000?oooooooooo06;ooooo0_l000000ooooooo0000o`00000Qooooo`;o
000000?oooooo`000?l000003Oooool5o`0000Kooooo0_l00009ooooo`;o00000_ooool2o`0000Oo
oooo0_l0000;ooooo`?o00005Oooool2o`0006Gooooo000Looooo`03o`000?oooooooooo06;ooooo
0_l000000ooooooo0000o`000004o`00013ooooo0_l00002ooooo`Co00002?ooool2o`000003oooo
ool0003o000000[ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00000_ooool2o`0000Wo
oooo0_l0000Cooooo`;o00001?ooool4o`000003ooooool0003o000007Oooooo000Looooo`03o`00
0?oooooooooo063ooooo0_l00004ooooo`Ko00003oooool8o`0000Sooooo0_l000000ooooooo0000
o`00000:ooooo`;o00000_ooool2o`000004ooooool0003o0000o`0001Sooooo0_l00006ooooo`?o
00001?ooool4o`000003ooooool0003o000007Oooooo000Looooo`03o`000?oooooooooo05Sooooo
0_l00006ooooo`;o00001_ooool4o`0000oooooo1?l00004ooooo`;o00002Oooool2o`0000oooooo
0_l000000ooooooo0000o`000008ooooo`?o00003Oooool4o`0000Cooooo0_l0000:ooooo`;o0000
Moooool001cooooo00?o0000ooooooooool0F?ooool2o`0000kooooo0_l0000Aooooo`;o00001_oo
ool2o`0000Wooooo0ol0000>ooooo`;o00002oooool3o`0000Oooooo0_l000000ooooooo0000o`00
0002ooooo`?o00004?ooool2o`0007Oooooo000Looooo`03o`000?oooooooooo06oooooo0_l00009
ooooo`;o00003_ooool2o`0000?ooooo0_l00006ooooo`;o00004_ooool3o`0000Kooooo1ol00002
ooooo`?o00001oooool2o`0001[ooooo0_l000000ooooooo0000o`00001Qooooo`007?ooool00ol0
003oooooooooo`1_ooooo`;o00001oooool5o`000003ooooool0003o000000[ooooo0_l000001?oo
oooo0000o`000?l00007ooooo`Co00002?ooool2o`0000Kooooo0_l00007ooooo`;o00000_ooool2
o`0000Cooooo0_l00007ooooo`;o00004_ooool2o`0000Kooooo0_l000000ooooooo0000o`00001Q
ooooo`007?ooool2o`00077ooooo0ol00005ooooo`;o000000Coooooo`000?l0003ooooo0_l00008
ooooo`;o00000oooool3o`0000Wooooo0_l000000ooooooo0000o`000005ooooo`;o00000oooool2
o`0000_ooooo0_l00005ooooo`;o000000Coooooo`000?l0003ooooo0ol00003ooooo`?o000000?o
ooooo`000?l000003Oooool2o`0000Oooooo0_l0001Sooooo`007?ooool00ol0003oooooooooo`16
ooooo`;o00006_ooool2o`0000Kooooo0_l00004ooooo`?o000000Coooooo`000?l0003o00002?oo
ool2o`0000Oooooo0_l0000<ooooo`;o00001?ooool2o`0000[ooooo0_l0000;ooooo`?o000000Co
ooooo`000?l0003ooooo0_l000000ooooooo0000o`000004o`000003ooooool0003o000000?o0000
00?oooooo`000?l000005_ooool2o`0000Wooooo0_l0001Hooooo`007?ooool00ol0003ooooooooo
o`16ooooo`;o00006_ooool2o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o00001?oo
ool3o`0000Sooooo0ol00006ooooo`?o00002oooool2o`000003ooooool0003o000000?ooooo0_l0
0003ooooo`;o00003_ooool2o`000003ooooool0003o000000?o000000Coooooo`000?l0003ooooo
1_l000000ooooooo0000o`000002o`0001?ooooo0_l0000@ooooo`;o0000F?ooool001cooooo00?o
0000ooooooooool0Goooool2o`000004ooooool0003o0000ooooo`;o00001oooool2o`00013ooooo
0_l00006ooooo`?o00003_ooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`0000kooooo
0_l00003ooooo`;o00001Oooool4o`0000Gooooo1?l0000<ooooo`;o00000_ooool3o`0006[ooooo
000Looooo`03o`000?oooooooooo05oooooo0_l000000ooooooo0000o`00000:ooooo`;o00005Ooo
ool2o`00013ooooo0_l00003ooooo`;o00000oooool2o`0000kooooo1?l00003ooooo`?o00001_oo
ool2o`0000Oooooo0_l000000ooooooo0000o`000002ooooo`;o00001Oooool2o`0000;ooooo0_l0
001[ooooo`007?ooool00ol0003oooooooooo`1Rooooo`;o00002oooool4o`0000;ooooo0_l0000>
ooooo`;o00004?ooool2o`0000?ooooo0_l00004ooooo`;o00002?ooool2o`0000?ooooo1Ol00000
0ooooooo0000o`000002o`0000gooooo0_l00003ooooo`;o00000_ooool2o`0000Gooooo0_l0000O
ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0D?ooool2o`0001gooooo1?l00002oooo
o`;o00004_ooool2o`00017ooooo0ol000000ooooooo0000o`000002o`0000Sooooo0_l00004oooo
o`Co000000?oooooo`000?l000000_l00005ooooo`;o00001_ooool2o`0000[ooooo2?l00003oooo
o`;o00002_ooool2o`0000cooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o
00002Oooool2o`0001;ooooo0_l00005ooooo`;o00003?ooool2o`0000?ooooo0_l00008ooooo`;o
00001Oooool5o`000003ooooool0003o000000Kooooo0_l000000ooooooo0000o`00000Cooooo`Co
00001_ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000001?l00002ooooo`;o
00000oooool2o`0000[ooooo0_l0001Looooo`007?ooool00ol0003oooooooooo`1Kooooo`Co0000
1?ooool2o`0000Wooooo0ol00005ooooo`;o00003?ooool2o`0000gooooo0_l00003ooooo`Ko0000
0_ooool7o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000?ooooo1?l0000:ooooo`;o
00001_ooool2o`000003ooooool0003o000000Go00001_ooool2o`0006gooooo000Looooo`03o`00
0?oooooooooo03gooooo0_l0000Nooooo`;o00000oooool3o`0000Wooooo0ol0000Kooooo`;o0000
2_ooool4o`0000Gooooo1_l000000ooooooo0000o`000005ooooo`;o00000_ooool5o`000003oooo
ool0003o000001Kooooo0_l00009ooooo`;o0000Joooool001cooooo00?o0000ooooooooool0?Ooo
ool2o`0002?ooooo0_l0000Aooooo`;o00005Oooool2o`0000[ooooo0_l000000ooooooo0000o`00
000:o`000003ooooool0003o000000Wooooo0_l00004ooooo`;o00004oooool2o`0000Wooooo0_l0
00000ooooooo0000o`000002o`0000Oooooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`1S
ooooo`;o00004?ooool2o`0001Gooooo0_l00002ooooo`;o00002Oooool<o`000004ooooool0003o
0000o`0001cooooo0_l00005ooooo`;o00001Oooool2o`0000;ooooo0_l00003ooooo`;o00001ooo
ool2o`00063ooooo000Looooo`03o`000?oooooooooo05Gooooo0_l0000;ooooo`?o00002oooool3
o`0000;ooooo0_l0000Eooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`00000=
o`000003ooooool0003o000000;o00005_ooool3o`000003ooooool0003o000000cooooo0_l00009
ooooo`;o00000_ooool2o`0000?ooooo0_l00009ooooo`;o0000Doooool001cooooo00?o0000oooo
ooooool0Doooool4o`0000Kooooo0_l00002ooooo`Co00002oooool6o`0000?ooooo1?l00007oooo
o`?o00000oooool3o`0000Wooooo5ol0000Cooooo`;o000000Coooooo`000?l0003o00006_ooool2
o`0000;ooooo0_l00003ooooo`;o00002Oooool2o`0005?ooooo000Looooo`03o`000?oooooooooo
05?ooooo0_l00008ooooo`;o00000_ooool4o`0000cooooo1_l00002ooooo`Co00001oooool3o`00
00?ooooo0ol0000;ooooo`ko000000?oooooo`000?l000000_l0000@ooooo`;o00000oooool2o`00
00Oooooo0_l00009ooooo`;o00000_ooool2o`0006oooooo000Looooo`03o`000?oooooooooo063o
oooo0_l00009ooooo`;o00001Oooool2o`000003ooooool0003o000000[ooooo0_l000001?oooooo
0000o`000?l00003ooooo`?o00002Oooool@o`000003ooooool0003o000000Go00003Oooool2o`00
00cooooo0_l00009ooooo`;o00000_ooool2o`0000Cooooo0_l0000<ooooo`;o0000Foooool001co
oooo0_l0000iooooo`;o00009_ooool3o`0000Sooooo0ol00003ooooo`?o000000?oooooo`000?l0
00002_ooool2o`0000?ooooo0_l0000=oooooa7o000000?oooooo`000?l000002?l0000=ooooo`;o
00007_ooool2o`0000Sooooo0_l00002ooooo`?o0000F_ooool001cooooo00?o0000ooooooooool0
>?ooool2o`00023ooooo0_l00004ooooo`?o00002Oooool2o`0000;ooooo0ol0000<ooooo`;o0000
1Oooool2o`0000gooooo7?l00005ooooo`;o00001_ooool2o`0002Sooooo0_l00003ooooo`;o0000
F_ooool001cooooo00?o0000ooooooooool0DOooool2o`0000Kooooo1Ol00002ooooo`;o00003_oo
ool2o`0000?ooooo0_l00008ooooo`;o00003_ooool2o`000003ooooool0003o000001co000000Co
ooooo`000?l0003ooooo1_l0000^ooooo`;o0000Goooool001cooooo00?o0000ooooooooool0DOoo
ool2o`0000Kooooo1Ol00002ooooo`Co00004Oooool2o`0000Sooooo0_l0000>ooooo`;o000000?o
ooooo`000?l000001ol000000ooooooo0000o`00000>o`0000;ooooo0_l000001?oooooo0000o`00
0?ooool2o`0000;ooooo0_l0000Xooooo`;o00001?ooool2o`0005oooooo000Looooo`03o`000?oo
oooooooo05[ooooo0ol00005ooooo`;o00001?ooool2o`0000Wooooo0_l00003ooooo`;o00001_oo
ool2o`00013ooooo6_l00002ooooo`?o0000<Oooool2o`0000Oooooo0_l0000Aooooo`;o0000BOoo
ool001cooooo00?o0000ooooooooool0F_ooool2o`0000cooooo0_l00009ooooo`;o00000oooool2
o`0000Kooooo0ol0000:ooooo`Co000000?oooooo`000?l000005ol00004ooooo`;o00001Oooool2
o`0003?ooooo0_l00004ooooo`;o00002oooool4o`0004Oooooo000Looooo`03o`000?oooooooooo
04oooooo0_l00004ooooo`;o00004Oooool2o`0000Cooooo0_l0000;ooooo`;o00001?ooool2o`00
00Kooooo0_l00002ooooo`Co00000_oooolIo`0000[ooooo0_l0000Aooooo`;o00009Oooool3o`00
00gooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`0booooo`;o00006oooool2o`0000Co
oooo0_l0000Aooooo`Go000000?oooooo`000?l000000_l00003ooooo`;o00000_ooool4o`000004
ooooool0003o0000ooooo`;o00000_ooool2o`000004ooooool0003o0000o`0000;ooooo1?l00002
oooooaWo00003oooool2o`0000cooooo0_l0000Uooooo`;o00003oooool2o`0004Kooooo000Loooo
o`03o`000?oooooooooo03;ooooo0_l0000Qooooo`;o00004oooool3o`0000?ooooo0_l00003oooo
o`;o00000_ooool2o`0000?ooooo0_l00005ooooo`;o000000?oooooo`000?l000001Oooool2o`00
00;ooooo2_l000000ooooooo0000o`00000>o`0000;ooooo0ol00005ooooo`;o000000?oooooo`00
0?l000001Oooool2o`0002Sooooo0_l0000Cooooo`;o0000A_ooool001cooooo00?o0000oooooooo
ool0D_ooool2o`000003ooooool0003o000000?o00000_ooool2o`00013ooooo1?l00009ooooo`;o
00003?ooool2o`0000Oooooo7?l00002ooooo`?o00001Oooool2o`000003ooooool0003o000000Go
oooo0_l00005ooooo`?o00007oooool3o`0000;ooooo0_l0000Cooooo`;o0000@_ooool001cooooo
00?o0000ooooooooool0D_ooool2o`000003ooooool0003o000000?o00000_ooool2o`00013ooooo
0_l00008ooooo`Go00001Oooool2o`0000Gooooo0_l000000ooooooo0000o`000002oooooaKo0000
00?oooooo`000?l000001_l0000Jooooo`?o00007oooool2o`0000?ooooo0_l00002ooooo`;o0000
3oooool2o`0004;ooooo000Looooo`03o`000?oooooooooo04_ooooo0_l00009ooooo`;o00000_oo
ool2o`0000Gooooo0_l0000:ooooo`;o00001_ooool2o`000003ooooool0003o000000Co00000_oo
ool4o`0000Sooooo0_l00002ooooob;o0000@_ooool2o`0005?ooooo000Looooo`03o`000?oooooo
oooo04Wooooo1?l0000=ooooo`;o00001Oooool2o`0000Sooooo1?l00006ooooo`;o00000oooool4
o`0000;ooooo1Ol00008ooooo`Co00000_oooolOo`0003_ooooo0_l00003ooooo`;o00000_ooool2
o`00057ooooo000Looooo`03o`000?oooooooooo04Wooooo0_l0000?ooooo`;o00001_ooool2o`00
00Oooooo1?l0000Cooooo`Go00001Oooool5o`0000;ooooo2Ol000000ooooooo0000o`00000@o`00
0003ooooool0003o000003_ooooo0ol00002ooooo`;o00000_ooool2o`00057ooooo000Looooo`03
o`000?oooooooooo02gooooo0_l0000Rooooo`Co00001Oooool2o`0000?ooooo0_l000000ooooooo
0000o`000006ooooo`;o00001_ooool2o`0000Oooooo0_l00008ooooo`;o00000_ooool2o`000004
ooooool0003o0000ooooob3o00003Oooool2o`000003ooooool0003o000002gooooo0_l000000ooo
oooo0000o`00001Fooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o00008_ooool5o`0000Wo
oooo0_l00003ooooo`;o00001?ooool2o`0000Gooooo0ol00007ooooo`;o000000?oooooo`000?l0
00000oooool3o`0000;ooooo0ol00002ooooo`;o00000_oooolJo`000003ooooool0003o000000?o
00002oooool2o`000004ooooool0003o0000ooooo`;o00001oooool2o`0002Cooooo0_l0001Foooo
o`007?ooool2o`0005?ooooo1?l00005ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Co
oooo0_l00005ooooo`;o00002oooool2o`0000;ooooo1?l00002ooooo`;o00000oooool2o`0000;o
oooo8Ol00003ooooo`;o00002oooool3o`0000Kooooo0_l0000Zooooo`;o0000D?ooool001cooooo
00?o0000ooooooooool0D_ooool2o`0000;ooooo0_l00003ooooo`Go00001?ooool2o`0000[ooooo
1?l0000>ooooo`;o00001?ooool5o`0000Gooooo0_l00002oooooako000000?oooooo`000?l00000
3?ooool2o`0003;ooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00004?oo
ool2o`0000Gooooo0_l00005ooooo`Co00002?ooool4o`0000_ooooo0_l00002ooooo`;o00001?oo
ool4o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`Co000000?oooooo`000?l000005?l0
00000ooooooo0000o`00000;ooooo`;o000000?oooooo`000?l000001oooool2o`0007cooooo000L
ooooo`03o`000?oooooooooo03oooooo0_l00003ooooo`;o00008?ooool2o`0000Wooooo0ol00006
ooooo`;o00000oooool6o`000003ooooool0003o000000;ooooo1?l000001?oooooo0000o`000?oo
ool2o`000003ooooool0003o000000?o00000_ooool?o`0000Wooooo0_l00009ooooo`;o000000?o
ooooo`000?l000001Oooool4o`0001Wooooo0_l0000=ooooo`?o00003oooool2o`00043ooooo000L
ooooo`03o`000?oooooooooo03oooooo0_l00002ooooo`;o00008?ooool3o`0000Wooooo0ol00004
ooooo`Co00001?ooool3o`0000?ooooo0_l00002ooooo`[o000000Coooooo`000?l0003o00001?oo
ool8o`000005ooooool0003o0000o`000?ooool00_l00009ooooo`;o00004oooool2o`0001_ooooo
1?l0000;ooooo`?o00003oooool2o`00043ooooo000Looooo`03o`000?oooooooooo03oooooo0_l0
0002ooooo`;o00005Oooool2o`0000;ooooo0_l00005ooooo`Co00002?ooool3o`0000Cooooo0_l0
0002ooooo`;o000000?oooooo`000?l000000_l0000;ooooo`Ko00000_ooool2o`0000?ooooo3_l0
0007ooooo`;o0000=_ooool2o`0000_ooooo1?l0001@ooooo`007?ooool00ol0003oooooooooo`1J
ooooo`;o00000_ooool2o`0000Cooooo1Ol00008ooooo`?o000000?oooooo`000?l000000_l00003
ooooo`;o000000Coooooo`000?l0003ooooo0_l00005ooooo`;o00001Oooool2o`0000?ooooo0ol0
00000ooooooo0000o`000005o`0000;ooooo1ol000000ooooooo0000o`000003ooooo`?o0000AOoo
ool2o`00053ooooo000Looooo`03o`000?oooooooooo05Cooooo0_l0000;ooooo`;o000000Gooooo
o`000?l0003o0000ooooo`02o`0000;ooooo0_l00007ooooo`Co00001_ooool2o`000004ooooool0
003o0000o`0000Cooooo0_l00002ooooo`?o00001Oooool8o`0000Kooooo0_l000000ooooooo0000
o`000002ooooo`;o00000oooool2o`00033ooooo0_l0000Fooooo`;o0000C_ooool001cooooo00?o
0000ooooooooool0@?ooool2o`0000Wooooo0ol00006ooooo`;o00002oooool2o`0000Gooooo0_l0
0002ooooo`Co00003oooool6o`0000;ooooo0_l00004ooooo`?o00001oooool6o`0000_ooooo0_l0
0005ooooo`Co00006?ooool2o`0001Cooooo0_l0000?ooooo`;o00001?ooool3o`0000kooooo0_l0
000nooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00000_ooool2o`0000Gooooo0ol00006
ooooo`;o00004?ooool2o`0000Kooooo0_l00002ooooo`Co00002?ooool5o`0000Cooooo1?l0000B
ooooo`;o000000Coooooo`000?l0003o00001Oooool3o`0000Cooooo1Ol0000Aooooo`;o00001?oo
ool2o`0002;ooooo1Ol00004ooooo`;o00003oooool2o`0003kooooo000Looooo`03o`000?oooooo
oooo04;ooooo1?l0000:ooooo`;o00000_ooool2o`000003ooooool0003o000000cooooo0ol00000
0ooooooo0000o`000007ooooo`Co00002?ooool2o`000003ooooool0003o000000?o00000oooool2
o`000003ooooool0003o000000oooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00000ooo
ool2o`0000Oooooo0_l00008ooooo`;o000000?oooooo`000?l000001?ooool2o`0000gooooo0_l0
000Iooooo`?o00001oooool2o`0004kooooo000Looooo`03o`000?oooooooooo04;ooooo0_l00006
ooooo`;o00000_ooool4o`0000Gooooo0_l0000<ooooo`;o00000_ooool4o`0000Sooooo0_l00007
ooooo`;o000000?oooooo`000?l000001?l00005ooooo`;o00003?ooool2o`0000Sooooo0_l0000>
ooooo`;o00001_ooool2o`000003ooooool0003o000001?ooooo0_l0000Booooo`;o00003Oooool4
o`0004kooooo000Looooo`03o`000?oooooooooo02Cooooo0_l0000Rooooo`Co00000_ooool5o`00
01Sooooo0_l00008ooooo`;o00002_ooool2o`0000;ooooo0ol0000<ooooo`;o00001?ooool2o`00
00?ooooo0ol00004ooooo`?o00002oooool2o`0000;ooooo0_l0000Cooooo`;o000000?oooooo`00
0?l000001Oooool2o`0000Sooooo0ol00004ooooo`;o00003Oooool2o`00017ooooo0_l0000moooo
o`007?ooool00ol0003oooooooooo`0Tooooo`;o00007_ooool6o`0000Cooooo1ol00007ooooo`Co
00001oooool2o`00013ooooo0_l00006ooooo`;o00000oooool2o`000003ooooool0003o000000?o
oooo0_l00004ooooo`;o00002Oooool3o`0000Cooooo0ol000000ooooooo0000o`00000;ooooo`?o
000000?oooooo`000?l000003Oooool8o`0000Gooooo0_l00004ooooo`;o00000_ooool3o`0000Co
oooo0_l000001?oooooo0000o`000?l00003ooooo`;o00002?ooool2o`0000gooooo0_l00004oooo
o`;o0000=oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l00000
0ol@413oooooooooo`04ooooo`03o`000?oooooooooo047ooooo2?l00003ooooo`_o00001Oooool4
o`0000Oooooo0_l000000ooooooo0000o`000005ooooo`;o00001_ooool2o`0000Kooooo0_l00006
ooooo`;o00000_ooool4o`0001;ooooo0_l00002ooooo`Go00002oooool6o`0000gooooo0ol00000
0ooooooo0000o`000003ooooo`;o00002?ooool2o`0000cooooo0ol00003ooooo`Go00001?ooool3
o`0000kooooo0_l00003ooooo`;o0000=oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Ooo
ool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0oooooo`Go00000ooo
ool2o`0000;ooooo3_l00002ooooo`Oo00002?ooool2o`0000Gooooo0_l00006ooooo`;o00000_oo
ool2o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o00000_ooool4o`0000;ooooo0_l0
000>ooooo`;o00000oooool2o`0000[ooooo0_l000000ooooooo0000o`000004o`0000?ooooo0_l0
0005ooooo`;o00000_ooool2o`000003ooooool0003o000000?ooooo1?l0000Dooooo`Ko00000_oo
ool3o`0000Cooooo0_l0000?ooooo`;o0000??ooool00003ooooool@413ooooo00;ooooo00?o410@
ooooooooool02Oooool5o`0000Kooooo00?o0000ooooooooool0<oooool2o`0000[ooooo0_l00006
ooooo`;o00000_ooool?o`000003ooooool0003o000000;o000000?oooooo`000?l000001oooool2
o`0001;ooooo0_l00002ooooo`Go00003Oooool5o`0000cooooo0_l00007ooooo`;o00001Oooool5
o`0000Oooooo0_l00005ooooo`;o00000_ooool2o`0000;ooooo0_l00004ooooo`?o00002?ooool2
o`0000Kooooo0_l00003ooooo`Ko0000E_ooool00003ooooool0003ooooo00;ooooo00?o0000oooo
ooooool02Oooool01?m4A4CogMgMooooool00007ooooo`?o0000<oooool2o`0001Kooooo3ol00003
ooooo`;o00002_ooool2o`0000?ooooo0ol000000ooooooo0000o`000009ooooo`?o00000_ooool2
o`000004ooooool0003o0000o`0000gooooo0ol00007ooooo`;o000000?oooooo`000?l000000_l0
0007ooooo`;o000000?oooooo`000?l000001?ooool2o`0001Oooooo0_l00002ooooo`;o000000?o
ooooo`000?l000001Oooool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`00
0003ooooo`Ko00002oooool2o`0004Wooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`10ooooo`;o00001_oo
ool2o`000003ooooool0003o000000ko00000_ooool2o`0000gooooo2?l0000:ooooo`Go00000_oo
ool5o`000003ooooool0003o000000gooooo1?l000001?oooooo0000o`000?ooool3o`0000_ooooo
0_l00002ooooo`;o00000_ooool2o`0001Wooooo0_l00005ooooo`;o000000?oooooo`000?l00000
1Oooool3o`000003ooooool0003o000000?ooooo1?l00003ooooo`;o00000_ooool3o`0000?ooooo
0_l00019ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03ogMgMoo<
c<co000000Oooooo00?o0000ooooooooool0@?ooool2o`0000Kooooo0_l000000ooooooo0000o`00
000>o`0000;ooooo0_l00009ooooo`;o00000_ooool2o`0000;ooooo0_l00007ooooo`?o00000ooo
ool4o`0000Cooooo0ol000000ooooooo0000o`00000=ooooo`Co00003_ooool3o`0000Gooooo0ol0
00000ooooooo0000o`00000>ooooo`?o00003oooool2o`0000Sooooo0ol000001?oooooo0000o`00
0?l00003ooooo`?o00000oooool2o`0000;ooooo0ol0001>ooooo`0000KoooooogMgMonHV9Sooooo
oiRHV?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool07oooool2o`0002[o
oooo3ol00005ooooo`;o00001oooool4o`0000Oooooo0_l00004ooooo`?o0000:?ooool2o`0000?o
oooo0_l000000ooooooo0000o`000003o`0000Cooooo0_l0000:ooooo`;o00001Oooool3o`0001Oo
oooo1Ol00002ooooo`;o00000oooool3o`0000Oooooo1?l00003ooooo`;o0000B?ooool00006oooo
ooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo
01oooooo0_l0000Zooooo`oo00001Oooool2o`0000Wooooo0_l00002ooooo`;o00000oooool2o`00
02Cooooo0_l00009ooooo`;o00000oooool2o`0000Cooooo0_l0000:ooooo`?o000000?oooooo`00
0?l000000_l00008ooooo`Co00002oooool2o`0000Kooooo1?l0000Booooo`Co00000oooool2o`00
04Sooooo000Looooo`03o`000?oooooooooo047ooooo1?l00007oooooa7o00002Oooool2o`0000Ko
oooo0_l00002ooooo`;o00003?ooool2o`0000Kooooo1?l00003ooooo`;o00002?ooool4o`0000[o
oooo0_l0000Booooo`?o000000?oooooo`000?l000000_ooool2o`0000Cooooo2?l00008ooooo`?o
00001?ooool2o`0000Sooooo0_l00004ooooo`;o00003Oooool2o`0004Sooooo000Looooo`03o`00
0?oooooooooo03oooooo1_l00007oooooa7o00002Oooool2o`0000[ooooo0_l0000<ooooo`;o0000
1_ooool4o`0000?ooooo0_l0000:ooooo`;o00001?ooool2o`0000Cooooo0_l00005ooooo`;o0000
3?ooool4o`0000?ooooo0_l000001?oooooo0000o`000?ooool4o`0000;ooooo0_l00008ooooo`;o
00001Oooool3o`0000Kooooo0ol00004ooooo`;o00003Oooool2o`0004Sooooo000Looooo`03o`00
0?oooooooooo03oooooo1?l00009ooooo`ko00005Oooool2o`0000;ooooo0_l00004ooooo`Co0000
9?ooool2o`0000?ooooo0_l00006ooooo`;o00000oooool2o`0000Oooooo1?l00006ooooo`;o0000
00?oooooo`000?l000000_l00003ooooo`?o00003_ooool2o`0000?ooooo0_l000000ooooooo0000
o`000005ooooo`?o0000E_ooool001cooooo00?o0000ooooooooool0?oooool3o`0000[ooooo1ol0
0004ooooo`;o00005_ooool3o`000003ooooool0003o000000?ooooo1Ol0000;ooooo`Co00006_oo
ool2o`0000_ooooo0_l00007ooooo`Co000000?oooooo`000?l000000ol00003ooooo`Co000000?o
ooooo`000?l000001?l0000Booooo`;o00002?ooool3o`0000gooooo0_l00017ooooo`007?ooool0
0ol0003oooooooooo`0oooooo`?o00003_ooool3o`0000Cooooo0_l0000Gooooo`;o00001_ooool2
o`000004ooooool0003o0000o`0000[ooooo1?l0000Pooooo`;o00001_ooool2o`0000Gooooo0_l0
0002ooooo`Oo00000oooool4o`000003ooooool0003o000000;ooooo0_l0000Looooo`;o00003_oo
ool2o`0004Oooooo000Looooo`03o`000?oooooooooo03Oooooo0_l00006ooooo`;o00004_ooool2
o`000003ooooool0003o000000Wooooo0_l0000Gooooo`Co000000?oooooo`000?l000002_ooool2
o`0001Kooooo0_l00006ooooo`?o00001_ooool2o`0000Gooooo2_l00004ooooo`Co00000oooool5
o`0000Cooooo0_l0000Eooooo`;o00003_ooool2o`0004Oooooo000Looooo`03o`000?oooooooooo
03Oooooo0_l00004ooooo`;o00005?ooool2o`000003ooooool0003o000000;ooooo0_l00005oooo
o`;o00001Oooool2o`0000;ooooo0_l0000<ooooo`;o00000oooool2o`0000[ooooo0_l0000Foooo
o`;o00000oooool2o`000003ooooool0003o000000_ooooo3?l00004ooooo`Go00000oooool5o`00
00Cooooo0_l00006ooooo`;o00001?ooool2o`0000Gooooo0_l000000ooooooo0000o`00000=oooo
o`;o00001_ooool2o`0000Gooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0iooooo`;o
00000_ooool2o`0000oooooo0_l00009ooooo`?o00001_ooool2o`0000Cooooo0_l00002ooooo`;o
00000oooool2o`0000;ooooo1?l00005ooooo`;o00008oooool3o`0000;ooooo0ol0000<ooooo`go
00001?ooool6o`0000;ooooo1_l0000;ooooo`;o00001?ooool2o`0000;ooooo1Ol000001?oooooo
0000o`000?l0000Dooooo`?o00001?ooool2o`000003ooooool0003o000003Gooooo000Looooo`03
o`000?oooooooooo01_ooooo0_l0000Looooo`;o00004?ooool5o`0000Oooooo1?l00002ooooo`;o
00000oooool2o`0000gooooo0ol000000ooooooo0000o`000002o`0000Gooooo0_l00007ooooo`;o
00000oooool2o`0001Kooooo0_l00002ooooo`?o00001_ooool2o`0000?ooooo1_l000000ooooooo
0000o`000006o`000003ooooool0003o000000Ko00000_ooool;o`0000;ooooo0_l0000:ooooo`Ko
00000oooool3o`0000Oooooo0_l0000;ooooo`;o00001oooool2o`0003Gooooo000Looooo`03o`00
0?oooooooooo01_ooooo0_l0000@ooooo`;o00002_ooool3o`0000oooooo1Ol00007ooooo`;o0000
1?ooool2o`0000Cooooo0_l0000;ooooo`So00003oooool3o`0000;ooooo0ol00007ooooo`;o0000
0_ooool2o`0000cooooo0_l00007ooooo`;o000000?oooooo`000?l000002?l00002oooooa;o0000
00?oooooo`000?l000001_l00002ooooo`;o00002_ooool2o`0000Sooooo0_l00007ooooo`;o0000
2oooool2o`0000?ooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o00002ooo
ool2o`0000_ooooo0ol0000Iooooo`;o00001oooool?o`0000gooooo0_l00003ooooo`;o00000_oo
ool2o`0000?ooooo0_l00002ooooo`;o00001Oooool4o`0000Wooooo0_l00004ooooo`;o00000ooo
ool2o`000003ooooool0003o000000go000000?oooooo`000?l000001?l00002ooooo`Ko00001ooo
ool2o`0000Gooooo0_l00005ooooo`;o00004?ooool2o`0000_ooooo0_l0000iooooo`007?ooool2
o`0003kooooo0_l00008ooooo`?o00008_ooool?o`000003ooooool0003o000001;ooooo0ol0000>
ooooo`Co00002Oooool2o`000004ooooool0003o0000ooooo`;o00000oooool2o`0000?ooooo1?l0
00000ooooooo0000o`00000Do`0000Cooooo0_l00002ooooo`;o00001Oooool2o`0000Gooooo0_l0
0008ooooo`;o00001_ooool2o`0000Kooooo0_l00004ooooo`;o0000>?ooool001cooooo00?o0000
ooooooooool0?Oooool4o`0002Gooooo0_l00004ooooo`ko000000?oooooo`000?l000001_l0000=
ooooo`;o00003Oooool2o`00013ooooo0_l000001?oooooo0000o`000?l00005oooooago00001?oo
ool2o`0001[ooooo0_l0000>ooooo`;o00001?ooool2o`0003Sooooo000Looooo`03o`000?oooooo
oooo01_ooooo0_l0000Rooooo`;o00005Oooool2o`0000Kooooo1?l00004oooooaoo00002Oooool2
o`0000oooooo0_l00005ooooo`;o00000_ooool2o`0000Oooooo1_l000000ooooooo0000o`00000M
o`0000Gooooo0ol0001Xooooo`007?ooool00ol0003oooooooooo`0Kooooo`;o0000<oooool2o`00
00Cooooo0_l00006ooooo`Co00001?oooolKo`0000;ooooo0_l00009ooooo`;o00005?ooool4o`00
00;ooooo1Ol00003ooooo`Oo000000?oooooo`000?l000007Ol00003ooooo`Go000000?oooooo`00
0?l000001?ooool2o`0000_ooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`0oooooo`;o
00003oooool2o`0001Cooooo0ol00003ooooo`;o00000_ooool=o`0000?ooooo0_l0000Dooooo`;o
00003?ooool4o`0000Cooooo0ol00003ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o
000000?oooooo`000?l000005_l000001?oooooo0000o`000?ooool2o`000004ooooool0003o0000
ooooo`;o00001?ooool2o`0000_ooooo0_l0000;ooooo`;o0000AOooool001cooooo00?o0000oooo
ooooool0?oooool2o`0002Kooooo6ol0000=ooooo`;o00001Oooool4o`0000[ooooo1Ol00003oooo
o`;o00002?ooool3o`0000Cooooo6ol000001?oooooo0000o`000?ooool2o`0000Gooooo0_l0000M
ooooo`;o00001_ooool2o`0003gooooo000Looooo`03o`000?oooooooooo01[ooooo0_l0000Foooo
o`;o00005oooool2o`0001cooooo6ol00007ooooo`;o00000_ooool3o`0000Kooooo0_l00006oooo
o`;o00000_ooool2o`000003ooooool0003o000000gooooo0ol000000ooooooo0000o`000002o`00
0003ooooool0003o000001Ko00000oooool4o`0000;ooooo0_l000000ooooooo0000o`00000Hoooo
o`;o00000oooool2o`0000Kooooo0_l00003ooooo`;o0000>?ooool001cooooo00?o0000oooooooo
ool06_ooool2o`0001Kooooo0_l00004ooooo`;o00004?ooool3o`0001_ooooo5Ol000000ooooooo
0000o`000005o`0000Kooooo0_l00003ooooo`;o00003_ooool2o`0000gooooo0_l00005ooooob?o
000000?oooooo`000?l000000_l00002ooooo`;o000000?oooooo`000?l000006?ooool2o`0000?o
oooo0_l0000;ooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0<?ooool2o`0000Kooooo
0_l0000@ooooo`;o00006_oooolJo`000003ooooool0003o000000;o00002_ooool3o`0000[ooooo
0_l0000=ooooo`;o00000_ooool2o`0000Gooooo6?l000000ooooooo0000o`000008o`000003oooo
ool0003o000000Co00000_ooool4o`0001Cooooo0ol0001<ooooo`007?ooool00ol0003ooooooooo
o`0`ooooo`;o0000<?ooool2o`0000;ooooo1?l000000ooooooo0000o`00000Bo`000003ooooool0
003o000000?o00001oooool2o`000003ooooool0003o000000Co00001?ooool5o`0000gooooo0_l0
0002ooooo`;o00000oooool2o`0000?ooooo8?l000000ooooooo0000o`000004o`0000;ooooo1?l0
000Dooooo`?o00001Oooool2o`0004Gooooo000Looooo`03o`000?oooooooooo033ooooo0_l00002
ooooo`;o00002Oooool2o`0000Wooooo0_l0000Fooooo`;o00001ooooolJo`000003ooooool0003o
000000Cooooo0_l00002ooooo`Go00001?ooool4o`0000Cooooo0_l0000<ooooo`;o00000oooool4
o`000003ooooool0003o0000023o000000Coooooo`000?l0003o00000_ooool4o`0000;ooooo0_l0
0003ooooo`;o00005?ooool2o`0004Gooooo000Looooo`03o`000?oooooooooo033ooooo0_l00002
ooooo`;o00002Oooool2o`0000Wooooo0_l00008ooooo`;o00005OoooolJo`000003ooooool0003o
000000Sooooo0ol0000>ooooo`;o00000_ooool2o`0000Sooooo1?l000000ooooooo0000o`000004
o`000003ooooool0003o000002;o00000_ooool8o`000003ooooool0003o000000?o0000F_ooool0
01cooooo00?o0000ooooooooool06_ooool2o`0001cooooo0_l00007ooooo`;o00004Oooool2o`00
00kooooo0_l00005oooooaSo00000_ooool2o`0000[ooooo0_l00003ooooo`;o00000_ooool2o`00
00Wooooo0_l00008ooooo`Co00000oooool4o`000003ooooool0003o0000027o00001_ooool4o`00
00;ooooo1Ol0000:ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool06_ooool2o`0001co
oooo0_l00007ooooo`;o00002oooool2o`0001Cooooo0_l00005oooooaWo000000?oooooo`000?l0
00002_ooool2o`000003ooooool0003o000000;o00000_ooool2o`0000Cooooo0_l000000ooooooo
0000o`000003ooooo`;o000000?oooooo`000?l000000_ooool4o`0000;ooooo1ol00003oooooaco
000000?oooooo`000?l000001_ooool2o`0000Cooooo0_l0000<ooooo`?o00005?ooool2o`0003So
oooo000Looooo`03o`000?oooooooooo02kooooo1?l0000Looooo`;o00006OoooolKo`00013ooooo
1?l00002ooooo`;o00000_ooool7o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`?o0000
0_ooool4o`000005ooooool0003o0000o`000?ooool07_l000000ooooooo0000o`000002o`0000Go
oooo0_l00003ooooo`;o00003?ooool3o`0000Wooooo0_l00002ooooo`;o00001Oooool2o`0003So
oooo000Looooo`03o`000?oooooooooo02kooooo1?l0000Wooooo`Co00003?oooolJo`0001;ooooo
0_l00002ooooo`?o00000_ooool2o`0000;ooooo0ol0000;ooooo`;o000000?oooooo`000?l00000
0_l000000ooooooo0000o`000002o`000003ooooool0003o0000027o00001Oooool2o`0000Oooooo
0_l000001?oooooo0000o`000?ooool2o`0000[ooooo0_l00002ooooo`;o00000_ooool2o`0003oo
oooo000Looooo`;o00006_ooool2o`0003kooooo1_l0000:ooooo`So000000?oooooo`000?l00000
3_l0000:ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00001oooool3o`0000kooooo
0_l00003ooooobWo00003Oooool2o`000004ooooool0003o0000ooooo`Co00002?ooool2o`0000Ko
oooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0Iooooo`;o00009_ooool2o`0000Oooooo
0_l0000?ooooo`Co00003OoooolDo`0000cooooo0ol000000ooooooo0000o`000003ooooo`;o0000
2oooool4o`0000gooooo1?l00002ooooob[o00000_ooool2o`0000Cooooo0_l00006ooooo`;o0000
00Coooooo`000?l0003o00000oooool2o`0000;ooooo0_l00017ooooo`007?ooool00ol0003ooooo
ooooo`0Iooooo`?o00009Oooool2o`0000Oooooo0_l0000?ooooo`;o00002?ooool2o`0000Gooooo
4Ol000000ooooooo0000o`000002ooooo`;o00002Oooool5o`000003ooooool0003o000000;o0000
00?oooooo`000?l000002_ooool2o`0000?ooooo0_l00003ooooo`;o00000oooool<o`000003oooo
ool0003o000001_o00001?ooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000Ko
oooo0_l00002ooooo`;o00000oooool2o`0000_ooooo0_l0000nooooo`007?ooool00ol0003ooooo
ooooo`0Jooooo`;o00008oooool4o`0000Oooooo0_l0000:ooooo`?o00003?ooool2o`0000Oooooo
3ol000000ooooooo0000o`000002ooooo`;o00001oooool2o`0000;ooooo0_l000000ooooooo0000
o`000002o`0000;ooooo0_l000000ooooooo0000o`000007ooooo`;o00000oooool2o`0000?ooooo
0_l00003ooooo`;o00000_oooolWo`0000Cooooo0_l00002ooooo`Co00004Oooool2o`000003oooo
ool0003o000000Sooooo0ol0000nooooo`007?ooool00ol0003oooooooooo`0looooo`;o000000?o
ooooo`000?l000005Oooool5o`0000Kooooo0_l00007ooooo`;o000000?oooooo`000?l000003Ol0
0002ooooo`Co00002Oooool2o`000003ooooool0003o000000Ko00001Oooool2o`0000Oooooo0_l0
000=ooooo`;o00000_ooool2o`000003ooooool0003o000002?o00000oooool2o`0000;ooooo0_l0
000Cooooo`;o000000?oooooo`000?l000002?ooool2o`000003ooooool0003o000003cooooo000L
ooooo`03o`000?oooooooooo03cooooo0_l000000ooooooo0000o`00000Hooooo`;o00001_ooool2
o`0000Kooooo0ol000000ooooooo0000o`000009o`000003ooooool0003o000000?ooooo1?l0000<
ooooo`Go00006_ooool2o`0000?ooooo1?l000001?oooooo0000o`000?oooolXo`0000[ooooo0_l0
0002ooooo`;o00002oooool3o`0000_ooooo0_l0000looooo`007?ooool00ol0003oooooooooo`0j
ooooo`;o00000_ooool3o`0000Wooooo0_l0000Fooooo`;o00001Oooool2o`000004ooooool0003o
0000ooooo`[o00001Oooool2o`0000;ooooo0_l0000:ooooo`;o000000?oooooo`000?l000001Ooo
ool2o`0001;ooooo0ol00003ooooo`Co000000?oooooo`000?l000003?l000000ooooooo0000o`00
000Jo`000003ooooool0003o000000Kooooo1ol0000:ooooo`?o000000?oooooo`000?l00000Aooo
ool001cooooo00?o0000ooooooooool0<?ooool2o`0000Sooooo0_l00002ooooo`?o00002?ooool3
o`0000?ooooo0_l0000Aooooo`;o00002?ooool2o`0000Gooooo0ol000000ooooooo0000o`000004
ooooo`?o00000_ooool2o`0000gooooo0_l000000ooooooo0000o`000006o`0000?ooooo2?l00000
0ooooooo0000o`000002ooooo`;o00002Oooool5o`000003ooooool0003o000000Ko00000_ooool3
o`000003ooooool0003o000000oo000000Coooooo`000?l0003o00000_ooool6o`0000?ooooo0_l0
00000ooooooo0000o`00000<ooooo`;o00000_ooool2o`0000Sooooo0_l000000ooooooo0000o`00
000jooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00002Oooool3o`000003ooooool0003o
000000Sooooo1?l00002ooooo`?o00000oooool2o`0001gooooo0_l00005ooooo`Co00004?ooool2
o`0000?ooooo2Ol00002ooooo`_o00001?ooool2o`0000Cooooo0_l00004ooooo`_o00000_ooool4
o`000003ooooool0003o000000Ko000000?oooooo`000?l000000_l000001?oooooo0000o`000?oo
ool4o`000003ooooool0003o000000Co00002?ooool3o`0000Wooooo0ol00003ooooo`;o00001_oo
ool2o`000003ooooool0003o000003[ooooo000Looooo`03o`000?oooooooooo03?ooooo0_l00006
ooooo`?o000000?oooooo`000?l000002_ooool2o`0000?ooooo0_l00003ooooo`;o00009?ooool2
o`0000kooooo2?l00002ooooo`;o00001?ooool2o`0000?ooooo0_l00004ooooo`;o00001_ooool2
o`0000?ooooo0ol000001?oooooo0000o`000?oooolOo`0000Kooooo0ol000001?oooooo0000o`00
0?l00004ooooo`;o00001?ooool3o`0000Cooooo0ol000000ooooooo0000o`000002o`0000?ooooo
0_l00015ooooo`007?ooool00ol0003oooooooooo`0aooooo`Co00001oooool2o`000003ooooool0
003o000004Oooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000Co00002Ooo
ool4o`0000oooooo0_l00002ooooob;o00000_ooool2o`0000;ooooo1ol000001?oooooo0000o`00
0?ooool2o`0000_ooooo0ol000000ooooooo0000o`000002o`000003ooooool0003o000004Oooooo
000Looooo`03o`000?oooooooooo037ooooo1_l00005ooooo`;o0000<Oooool2o`0001Oooooo0_l0
0003ooooo`?o00000oooool2o`0000cooooo0ol00008ooooo`;o00002_ooool5o`0000;ooooo6_l0
0002ooooo`So00001?ooool2o`0000Cooooo0_l00002ooooo`;o00001Oooool2o`0000?ooooo0_l0
00000ooooooo0000o`000017ooooo`007?ooool00ol0003oooooooooo`0eooooo`;o00001Oooool2
o`0000kooooo0_l0000;ooooo`?o00003Oooool2o`0000Cooooo0_l0000Booooo`;o00000_ooool4
o`000004ooooool0003o0000o`0000;ooooo0_l0000=ooooo`;o00001?ooool2o`0000Cooooo0_l0
0006ooooo`;o00000_oooolQo`0000Cooooo1?l0000<ooooo`;o00000_ooool3o`0000?ooooo0ol0
0003ooooo`;o00006oooool2o`0002gooooo000Looooo`03o`000?oooooooooo03Wooooo0_l0000A
ooooo`;o00002oooool3o`0000gooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l00002
ooooo`;o00002_ooool2o`0000;ooooo1?l000001Ooooooo0000o`000?l0003ooooo00Co00003?oo
ool2o`0000Cooooo0_l0000<ooooo`;o00000oooool7o`000003ooooool0003o0000013o000000?o
ooooo`000?l000000oooool2o`00017ooooo0_l00004ooooo`Co000000Coooooo`000?l0003o0000
3_ooool2o`00013ooooo0_l0000]ooooo`007?ooool00ol0003oooooooooo`0Hooooo`;o00006ooo
ool2o`0000;ooooo0_l00004ooooo`;o00009oooool2o`0000;ooooo1?l00003ooooo`;o00000_oo
ool2o`0000kooooo0_l00004ooooo`;o000000?oooooo`000?l000000_l0000Sooooo`Ko00001?oo
ool6o`000003ooooool0003o000000So00001Oooool4o`00017ooooo0_l00006ooooo`;o00000ooo
ool2o`0000;ooooo0_l000000ooooooo0000o`000006ooooo`Co0000?Oooool001cooooo00?o0000
ooooooooool06?ooool2o`0001Cooooo0_l00002ooooo`;o000000?oooooo`000?l000002?ooool2
o`0001_ooooo0_l0000:ooooo`;o00000_ooool2o`0001Wooooo0_l000001?oooooo0000o`000?l0
0002ooooo`Wo00002Oooool2o`0000oooooo0_l00003ooooo`Go00001OoooolCo`0000?ooooo0_l0
0004ooooo`;o00002_ooool2o`0000[ooooo2_l000000ooooooo0000o`000008ooooo`;o0000?Ooo
ool001cooooo0_l0000_ooooo`;o00000_ooool2o`0002Sooooo0_l0000Mooooo`;o00002?ooool3
o`0000;ooooo0ol00002ooooo`Co000000?oooooo`000?l000000_l00009ooooo`;o00003oooool4
o`0000cooooo2?l000000ooooooo0000o`000004o`000003ooooool0003o000000;ooooo0_l00005
ooooo`Go00001oooool2o`0000[ooooo2?l000000ooooooo0000o`000009ooooo`;o0000?_ooool0
01cooooo00?o0000ooooooooool0;_ooool2o`0000;ooooo1ol0000?ooooo`;o0000<Oooool5o`00
0003ooooool0003o000000;ooooo0ol00002ooooo`;o00001Oooool2o`0000_ooooo0_l00006oooo
o`;o00001Oooool2o`0000Gooooo0_l00004ooooo`;o00001_ooool8o`0000?ooooo1ol000001?oo
oooo0000o`000?l00002ooooo`;o000000?oooooo`000?l000000ol0000Booooo`Wo000000?ooooo
o`000?l000000oooool2o`0000;ooooo1?l00002ooooo`;o0000>_ooool001cooooo00?o0000oooo
ooooool0<_ooool7o`0000Cooooo0_l00009ooooo`;o00008_ooool2o`0000kooooo1?l000000ooo
oooo0000o`000007ooooo`;o00000_ooool6o`0000Sooooo1?l000000ooooooo0000o`000002oooo
o`?o00001Oooool2o`0000?ooooo0_l00004ooooo`Co00000oooool3o`0000Gooooo0ol000000ooo
oooo0000o`000007o`000003ooooool0003o000000;ooooo0ol0000Hooooo`Co000000Coooooo`00
0?l0003o00001oooool2o`0000;ooooo0_l00004ooooo`;o0000>_ooool001cooooo00?o0000oooo
ooooool0?Oooool2o`0002cooooo0ol00008ooooo`;o00000oooool2o`000003ooooool0003o0000
00Wooooo0ol00002ooooo`Ko00000oooool2o`0000?ooooo0_l00003ooooo`;o00000_ooool2o`00
00Kooooo0_l00003ooooo`Co00000_ooool2o`0000?ooooo1Ol00005ooooo`go00001Oooool4o`00
00Kooooo0_l00006ooooo`;o00001_ooool5o`000003ooooool0003o000000;o000000?oooooo`00
0?l000000_l00017ooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o00001?ooool2o`000003
ooooool0003o000000?ooooo0_l000000ooooooo0000o`000009ooooo`;o00008?ooool2o`0000Wo
oooo0ol00002ooooo`;o00003?ooool3o`0000Kooooo0_l00003ooooo`;o00000oooool2o`0000oo
oooo0_l00005ooooo`;o00001oooool2o`0000;ooooo0_l00004ooooo`Oo00001Oooool2o`000004
ooooool0003o0000ooooo`Co000000?oooooo`000?l000000oooool2o`0000Kooooo0_l00006oooo
o`?o00000oooool4o`000003ooooool0003o000000;o000000?oooooo`000?l00000A?ooool001co
oooo00?o0000ooooooooool0;Oooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool4o`00
0003ooooool0003o000000Wooooo0_l0000>ooooo`;o00006oooool5o`0000Kooooo0_l0000?oooo
o`Co00001_ooool2o`0000oooooo0_l00009ooooo`;o00001oooool2o`0000Cooooo0_l000001?oo
oooo0000o`000?ooool4o`000003ooooool0003o000000Co000000?oooooo`000?l000000oooool2
o`000004ooooool0003o0000o`0001Sooooo0_l00005ooooo`;o0000A?ooool001cooooo00?o0000
ooooooooool0<?ooool2o`0000Kooooo0ol0000Nooooo`;o00005_ooool2o`0000Kooooo0ol00000
1Ooooooo0000o`000?l0003ooooo00;o00001?ooool2o`0000_ooooo0_l00004ooooo`;o00004Ooo
ool2o`0000Wooooo0_l00002ooooo`;o00001oooool4o`000004ooooool0003o0000ooooo`Wo0000
1oooool2o`000003ooooool0003o000000;o00001oooool2o`0000Cooooo0_l00007ooooo`Co0000
Boooool001cooooo00?o0000ooooooooool0<?ooool2o`0000Kooooo0_l00007ooooo`;o0000;_oo
ool2o`0000Kooooo2Ol00005ooooo`;o00004Oooool4o`0000;ooooo0_l00003ooooo`;o00005?oo
ool3o`0000Oooooo0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o000000Oooooo0_l0
00001?oooooo0000o`000?ooool4o`0000Oooooo0_l000001?oooooo0000o`000?ooool2o`0000Oo
oooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00001_ooool2o`0000Wooooo
0_l00003ooooo`?o00001?ooool2o`000003ooooool0003o000001?ooooo0_l00007ooooo`Go0000
0_ooool3o`0000Wooooo0_l00004ooooo`Co00001_ooool2o`0000;ooooo0_l00003ooooo`;o0000
0oooool2o`0000oooooo0ol0000;ooooo`?o00000_ooool2o`0000[ooooo0_l00006ooooo`;o0000
2_ooool2o`0000Sooooo0_l0000Tooooo`;o0000:Oooool001cooooo00?o0000ooooooooool0=Ooo
ool6o`00017ooooo0_l00002ooooo`Co00001?ooool2o`000003ooooool0003o000001?ooooo0_l0
000:ooooo`;o00000oooool3o`000003ooooool0003o000000Cooooo0ol00004ooooo`Co00001_oo
ool2o`0000cooooo0_l0000>ooooo`Go00001oooool5o`0000?ooooo0_l00004ooooo`;o00003?oo
ool3o`0000?ooooo0ol000000ooooooo0000o`000002o`0000Sooooo1_l0000Pooooo`;o0000:Ooo
ool001cooooo00?o0000ooooooooool0=Oooool6o`00013ooooo0_l00003ooooo`;o00009?ooool2
o`000004ooooool0003o0000ooooo`Go000000Coooooo`000?l0003ooooo0_l00004ooooo`Co0000
1?ooool2o`0000Wooooo0_l0000;ooooo`;o000000?oooooo`000?l000000_l00008ooooo`Ko0000
1_ooool6o`0000;ooooo0_l00004ooooo`;o00001oooool2o`0000Cooooo0_l00003ooooo`?o0000
00?oooooo`000?l000001?ooool2o`0000Kooooo1Ol0001:ooooo`007?ooool00ol0003ooooooooo
o`0eooooo`;o00005?ooool2o`0002Kooooo0_l000001?oooooo0000o`000?ooool8o`0000cooooo
0_l00004ooooo`Go00000oooool2o`000003ooooool0003o000000Oooooo1_l000000ooooooo0000
o`000002o`0000cooooo0_l00009ooooo`?o00004Oooool2o`0000Gooooo0ol000000ooooooo0000
o`000008ooooo`;o00001oooool4o`0000Gooooo0_l0000Fooooo`;o0000:oooool001cooooo00?o
0000ooooooooool0=Oooool2o`0000gooooo0_l0000=ooooo`;o00007_ooool2o`0000Gooooo2_l0
0005ooooo`;o000000?oooooo`000?l000001oooool3o`0000?ooooo0_l0000:ooooo`Ko00000_oo
ool2o`0000Cooooo0_l00008ooooo`Go00008?ooool3o`0000_ooooo0_l00005ooooo`Co00001?oo
ool2o`000003ooooool0003o000001Kooooo0_l0000[ooooo`007?ooool00ol0003oooooooooo`11
ooooo`;o000000?oooooo`000?l000000_l0000;ooooo`;o00008oooool<o`0000Gooooo0_l00000
1?oooooo0000o`000?l00003ooooo`;o00006?ooool2o`0000Oooooo0_l00004ooooo`Wo00001_oo
ool2o`0000gooooo0ol0000;ooooo`;o00001_ooool2o`000003ooooool0003o000000Gooooo1?l0
0004ooooo`;o0000A_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo
00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo03;ooooo0_l000000ooooooo
0000o`00000:ooooo`;o000000?oooooo`000?l000000_l0000>ooooo`;o00006ooooolAo`000003
ooooool0003o000000Kooooo0_l00003ooooo`;o00001?ooool3o`0000[ooooo0_l00005ooooo`;o
00003Oooool5o`000003ooooool0003o000000Oooooo0_l0000=ooooo`?o00001?ooool2o`0000;o
oooo1Ol000000ooooooo0000o`000003ooooo`;o00000_ooool2o`0000Gooooo0_l0001=ooooo`00
00KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So
8B4Q00Kooooo00?o0000ooooooooool0<_ooool2o`000004ooooool0003o0000o`0001kooooo0_l0
000JoooooaGo00002_ooool2o`0000Gooooo0ol0000:ooooo`;o00003?ooool2o`0000Wooooo0_l0
00000ooooooo0000o`000003ooooo`;o00002oooool2o`0000_ooooo0_l00002ooooo`So00001ooo
ool2o`0000;ooooo1Ol00004ooooo`;o0000Aoooool00003ooooool@413ooooo00;ooooo00?o410@
ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0=Ooo
ool3o`0003Sooooo5_l0000;ooooo`;o00000_ooool2o`000003ooooool0003o000000Sooooo0_l0
0002ooooo`;o00002Oooool6o`000003ooooool0003o000000;ooooo0_l00008ooooo`;o00001Ooo
ool2o`0000?ooooo0ol0000@ooooo`;o000000?oooooo`000?l000002_ooool2o`000003ooooool0
003o000000;o00001Oooool2o`0004Oooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo00Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000=Oooool2o`0003Wooooo5_l0
000?ooooo`;o000000Coooooo`000?l0003ooooo1_l000000ooooooo0000o`000002ooooo`;o0000
2Oooool6o`000003ooooool0003o000000;ooooo0_l0000?ooooo`;o00000oooool2o`0000Cooooo
0_l0000Jooooo`;o000000?oooooo`000?l000003?ooool2o`0004;ooooo00000ooooooo0000oooo
o`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`00
0?oooooooooo04Kooooo0_l0000YoooooaGo00001oooool2o`0000Wooooo0_l000000ooooooo0000
o`000004o`0001;ooooo0_l00008ooooo`;o00004Oooool2o`0000Gooooo0ol00002ooooo`;o0000
5oooool4o`0000cooooo0_l00012ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0A_ooool2o`0000cooooo1?l0
0002ooooo`;o00005OoooolEo`0000Oooooo0_l00009ooooo`;o00000oooool2o`0000kooooo0_l0
0004ooooo`;o00002?ooool2o`00013ooooo0ol00002ooooo`Ko00000_ooool2o`0001;ooooo2?l0
001Aooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo
00?o0000ooooooooool0=oooool2o`0000kooooo0_l0000;ooooo`Co00000_ooool2o`0001Gooooo
5Ol00002ooooo`;o00001_ooool2o`0000Wooooo0_l00008ooooo`;o00001_ooool2o`0000Cooooo
1?l0000Hooooo`_o000000?oooooo`000?l000002?ooool2o`0000Wooooo1Ol000000ooooooo0000
o`00000Nooooo`;o0000<Oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<co
A4A4o`000?l@4106ooooo`03o`000?oooooooooo03Oooooo1Ol0000;ooooo`;o00001oooool2o`00
00gooooo0_l0000@oooooaGo000000Coooooo`000?l0003o00001_ooool2o`0000Wooooo0_l00003
ooooo`?o00000_ooool2o`0000kooooo0_l00009ooooo`;o00002oooool2o`0000;ooooo0ol00007
ooooo`;o00002?ooool2o`0000Kooooo0ol00004ooooo`Go00007Oooool2o`00037ooooo000Loooo
o`03o`000?oooooooooo03Gooooo0_l000000ooooooo0000o`000003o`0001?ooooo0_l0000:oooo
o`;o000000?oooooo`000?l000004OoooolGo`0000;ooooo0_l0000Booooo`Co00000_ooool2o`00
01;ooooo0_l00005ooooo`;o00000oooool2o`0000Kooooo0_l00004ooooo`;o00001?ooool2o`00
00oooooo0_l000001?oooooo0000o`000?l00004ooooo`;o000000?oooooo`000?l00000D?ooool0
01cooooo00?o0000ooooooooool0=Oooool2o`000003ooooool0003o000000?o00003?ooool2o`00
00;ooooo0_l0000=ooooo`;o00002oooool2o`0000;ooooo6_l00004ooooo`;o00002oooool2o`00
00Gooooo0ol0000Gooooo`;o00001?ooool3o`0000?ooooo0_l00005ooooo`;o00001Oooool2o`00
00Cooooo0_l00003ooooo`;o00001_ooool2o`0000;ooooo1Ol00008ooooo`;o00005_ooool2o`00
03Sooooo000Looooo`03o`000?oooooooooo037ooooo0_l00006ooooo`?o00003Oooool2o`0000;o
oooo0_l00008ooooo`;o00004?ooool2o`0000;ooooo6ol0000@ooooo`;o00001Oooool3o`000003
ooooool0003o000001[ooooo0_l00008ooooo`;o000000?oooooo`000?l000004?ooool2o`0000Co
oooo1_l00002ooooo`;o00002Oooool2o`0001Kooooo0_l0000hooooo`007?ooool00ol0003ooooo
ooooo`0aooooo`;o00001_ooool3o`0000gooooo0_l0000<ooooo`;o00003oooool2o`0000Cooooo
6_l0000Gooooo`;o00000_ooool2o`0000kooooo0_l0000Dooooo`;o00004oooool2o`000004oooo
ool0003o0000ooooo`;o00000_ooool6o`0000Wooooo0_l00007ooooo`;o000000?oooooo`000?l0
0000A?ooool001cooooo00?o0000ooooooooool0>Oooool3o`0000oooooo0_l0000;ooooo`;o0000
3_ooool2o`0000;ooooo3ol00002ooooo`_o00004Oooool2o`0001Sooooo0_l00002ooooo`?o0000
4?ooool2o`0001Cooooo1?l000000ooooooo0000o`000003ooooo`?o00002_ooool2o`0000Oooooo
0_l000000ooooooo0000o`000014ooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00004?oo
ool2o`0000_ooooo0_l00006ooooo`;o00002_ooool2o`000003ooooool0003o000001Oo00004Ooo
ool2o`000004ooooool0003o0000o`0001Kooooo1Ol0000@ooooo`;o00001?ooool2o`0000kooooo
1?l000000ooooooo0000o`00000Aooooo`Co00001?ooool2o`0004Oooooo000Looooo`03o`000?oo
oooooooo03gooooo0_l000000ooooooo0000o`00000@ooooo`;o00001_ooool2o`0000Cooooo0_l0
000;oooooa_o00004oooool5o`0001Gooooo2?l000000ooooooo0000o`000002o`0000kooooo0_l0
000:ooooo`;o00000_ooool4o`0000;ooooo0ol000000ooooooo0000o`00000<ooooo`Co00000_oo
ool4o`0004Oooooo000Looooo`03o`000?oooooooooo03gooooo1_l00008ooooo`;o00001Oooool2
o`0000;ooooo0_l00002ooooo`;o00001_ooool2o`0000?ooooo0_l00004oooooa_o00004_ooool3
o`000003ooooool0003o000000?ooooo0_l0000Cooooo`Go000000?oooooo`000?l000000_l0000:
ooooo`;o000000Coooooo`000?l0003ooooo0_l00008ooooo`;o00000_ooool2o`0000Cooooo0ol0
00001?oooooo0000o`000?ooool2o`0000oooooo0_l0000;ooooo`;o00000_ooool2o`0003Sooooo
000Looooo`03o`000?oooooooooo03Kooooo0_l00004ooooo`;o000000?oooooo`000?l000000_l0
0008ooooo`;o00001oooool4o`0000[ooooo0ol00002ooooo`;o00001oooool;o`000003ooooool0
003o000000Wo000000?oooooo`000?l000004?ooool2o`0000;ooooo0_l000000ooooooo0000o`00
0002o`0000gooooo1?l00002ooooo`Co00004?ooool5o`000003ooooool0003o000000Oooooo0_l0
000;ooooo`;o00000oooool2o`0000Wooooo0_l0000Aooooo`;o00000_ooool2o`0003Sooooo000L
ooooo`03o`000?oooooooooo03Kooooo0_l00004ooooo`;o00005_ooool2o`0000Cooooo0_l00002
ooooo`;o00000oooool2o`0000;ooooo0_l00007oooooaOo000000?oooooo`000?l000003oooool4
o`000004ooooool0003o0000ooooo`;o00003Oooool<o`000003ooooool0003o000000?ooooo0_l0
0009ooooo`;o00002_ooool4o`0000[ooooo0ol00006ooooo`;o00001Oooool3o`0004oooooo000L
ooooo`03o`000?oooooooooo03Kooooo0_l00004ooooo`;o00004?ooool2o`0000[ooooo1_l00008
ooooo`;o00001?oooolIo`00013ooooo1_l0000Cooooo`oo00000oooool2o`0000cooooo0ol00006
ooooo`Co00002?ooool=o`000003ooooool0003o000000;ooooo0_l0001@ooooo`007?ooool2o`00
03Oooooo0_l00004ooooo`;o00000_ooool2o`0000cooooo0_l0000:ooooo`Co00002_ooool2o`00
00Cooooo5ol000000ooooooo0000o`00000?ooooo`;o00002Oooool2o`000003ooooool0003o0000
00_ooooo4Ol0000=ooooo`?o00001_ooool4o`0000;ooooo0_l00004ooooo`;o000000?oooooo`00
0?l000001_l00002ooooo`?o0000E?ooool001cooooo00?o0000ooooooooool0?_ooool4o`0001[o
oooo0_l0000=ooooo`Co000000?oooooo`000?l000005_l0000@ooooo`;o00001oooool3o`000003
ooooool0003o000000[ooooo4_l000000ooooooo0000o`000009ooooo`;o00003_ooool2o`0000Wo
oooo0_l00006ooooo`Co00002_ooool4o`0000Oooooo0_l0000looooo`007?ooool00ol0003ooooo
ooooo`0nooooo`;o00007?ooool2o`0000;ooooo0_l00009oooooa_o00004_ooool4o`0000?ooooo
1?l0000>oooooa3o00000oooool2o`0000Wooooo0_l00005ooooo`?o00001?ooool2o`0000Cooooo
0_l0000?ooooo`;o00002_ooool4o`0000Oooooo0_l0000looooo`007?ooool00ol0003ooooooooo
o`15ooooo`;o00001oooool3o`0000Cooooo0_l00003ooooo`;o00001?ooool2o`0000;ooooo0_l0
0005ooooo`;o00000_ooool<o`000003ooooool0003o000000Co00000_ooool2o`0001Cooooo0_l0
0003ooooo`Co00003_ooool?o`0001Kooooo0ol00004ooooo`;o00000_ooool4o`0006Cooooo000L
ooooo`03o`000?oooooooooo03gooooo0ol00003ooooo`Co00001oooool3o`000004ooooool0003o
0000ooooo`;o00000oooool4o`0000Kooooo0_l00005ooooo`;o000000?oooooo`000?l000002ol0
00000ooooooo0000o`000003o`0000Oooooo0_l0000<ooooo`;o00001oooool2o`00013ooooo4Ol0
000Oooooo`;o00000_ooool2o`0000Oooooo0_l00007ooooo`;o0000D?ooool001cooooo00?o0000
ooooooooool0?Oooool3o`0000?ooooo0_l00005ooooo`;o00001_ooool2o`0000Oooooo1?l00005
ooooo`;o00002?oooolDo`0000Kooooo0_l0000<ooooo`;o00001oooool2o`0000oooooo4ol00005
ooooo`;o00001?ooool2o`0000Kooooo1?l00002ooooo`;o00001oooool2o`0000;ooooo0_l00003
ooooo`;o00001oooool2o`00053ooooo000Looooo`03o`000?oooooooooo03Wooooo0_l00003oooo
o`;o00000oooool5o`0000;ooooo0_l00002ooooo`;o00002oooool4o`0000?ooooo0_l0000:oooo
oaCo00005?ooool2o`0001Sooooo5?l00004ooooo`;o00001?ooool2o`0000Kooooo1?l00002oooo
o`;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`00001Nooooo`007?ooool00ol0003o
ooooooooo`0iooooo`;o00000_ooool2o`0000Cooooo1Ol00006ooooo`;o00004_ooool2o`0000?o
oooo0_l00005oooooa7o00000_ooool2o`0001?ooooo0_l00007ooooo`;o00002oooool2o`0000;o
oooo5Ol00006ooooo`?o00002oooool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o
000000?oooooo`000?l000001?ooool2o`0000Gooooo0_l0001Aooooo`007?ooool00ol0003ooooo
ooooo`0mooooo`;o00006oooool2o`0000_ooooo0_l00007ooooo`oo00000_ooool2o`0001?ooooo
0_l00007ooooo`;o00002oooool2o`000003ooooool0003o000001Ko00001?ooool3o`0000_ooooo
0_l00006ooooo`;o00001?ooool4o`0000Cooooo0_l00005ooooo`;o00001_ooool2o`0004Wooooo
000Looooo`03o`000?oooooooooo04?ooooo0_l0000;ooooo`;o00002?ooool2o`0000;ooooo0_l0
0002ooooo`;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000=o`0001Cooooo0_l0
0002ooooo`?o00004ooooolHo`000003ooooool0003o000001[ooooo0_l00004ooooo`;o00000_oo
ool2o`00017ooooo0_l00003ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0@oooool2
o`0000_ooooo0_l0000<ooooo`;o000000Coooooo`000?l0003o00001?ooool3o`000004ooooool0
003o0000ooooo`go00005_ooool2o`0000?ooooo0_l0000CoooooaSo00000_ooool2o`0001Wooooo
0_l00002ooooo`Co00000_ooool3o`00013ooooo0_l00003ooooo`;o0000A?ooool001cooooo00?o
0000ooooooooool0FOooool2o`0000?ooooo0_l000000ooooooo0000o`000003o`0000?ooooo0_l0
0005ooooo`?o000000?oooooo`000?l000001Ol0000_ooooo`;o00001?oooolCo`0000?ooooo0_l0
0003ooooo`;o00005?ooool2o`0000;ooooo1?l00003ooooo`;o00003oooool3o`0004Wooooo000L
ooooo`03o`000?oooooooooo04Wooooo0_l0000>ooooo`;o00000oooool2o`0000?ooooo0ol00008
ooooo`;o000000?oooooo`000?l000000_l0000Vooooo`;o00001?ooool2o`0000Oooooo0_l00003
ooooo`_o000000?oooooo`000?l000001_l00002ooooo`;o00001?ooool2o`0001gooooo0_l0000A
ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0BOooool2o`000003ooooool0003o0000
00;ooooo0_l00007ooooo`;o00003?ooool2o`0000Gooooo0_l000000ooooooo0000o`000002o`00
00Sooooo0_l0000Cooooo`;o00001oooool2o`0000Cooooo0_l0000<ooooo`[o000000?oooooo`00
0?l000001ol00002ooooo`;o00005_ooool2o`0000Gooooo0_l00004ooooo`Co0000Foooool001co
oooo00?o0000ooooooooool0Boooool3o`0000;ooooo0_l0000Cooooo`Co00002oooool2o`0000Oo
oooo0_l0000Cooooo`;o00001oooool2o`0000Oooooo0_l00009oooooa7o000000Coooooo`000?l0
003ooooo0_l000000ooooooo0000o`00000Dooooo`;o000000?oooooo`000?l000001_l00004oooo
o`;o00004Oooool2o`0004Sooooo000Looooo`03o`000?oooooooooo04_ooooo0ol00002ooooo`;o
00003Oooool2o`0000Cooooo0ol0000<ooooo`;o00001oooool2o`0000Kooooo0_l0000Dooooo`;o
00000_ooool2o`0000?ooooo0_l0000:oooooa?o000000Coooooo`000?l0003ooooo0_l00009oooo
o`?o00002oooool4o`000004ooooool0003o0000o`0000Cooooo0_l0000Aooooo`;o0000B?ooool0
01cooooo0_l0001=ooooo`;o000000Coooooo`000?l0003o00001Oooool2o`0000Kooooo0ol00004
ooooo`;o00002?ooool2o`0000;ooooo1?l00005ooooo`;o00001_ooool2o`0000Wooooo0_l00007
ooooo`;o00001?ooool3o`0001;ooooo3_l00002ooooo`;o000000?oooooo`000?l000001Oooool7
o`00013ooooo0_l00005ooooo`;o0000Foooool001cooooo00?o0000ooooooooool0Coooool3o`00
00Gooooo0ol00006ooooo`Co00002_ooool4o`0000;ooooo1?l0000Hooooo`;o00000oooool2o`00
00;ooooo0_l00005ooooo`;o00003Oooool2o`0000?ooooo3_l00005ooooo`;o00001Oooool7o`00
01_ooooo0ol000000ooooooo0000o`00001Cooooo`007?ooool00ol0003oooooooooo`19ooooo`;o
00001?ooool2o`0000Kooooo0ol00002ooooo`;o00001?ooool2o`0000[ooooo0_l000001?oooooo
0000o`000?ooool3o`000003ooooool0003o000001Kooooo0_l00003ooooo`;o00002Oooool2o`00
00;ooooo0_l00002ooooo`;o00001Oooool2o`0000?ooooo3_l0000=ooooo`?o00003Oooool2o`00
00oooooo1_l0001Cooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00001_ooool2o`000004
ooooool0003o0000ooooo`?o00000_ooool2o`0001?ooooo0_l00005ooooo`;o00000oooool5o`00
00kooooo0_l0000>ooooo`;o00000_ooool2o`0000;ooooo0_l00007ooooo`;o00000_ooool:o`00
0003ooooool0003o000001gooooo0_l0000<ooooo`;o000000?oooooo`000?l000000_l0001Eoooo
o`007?ooool00ol0003oooooooooo`1;ooooo`;o00001?ooool2o`000003ooooool0003o000000;o
oooo0_l00002ooooo`Ko00003oooool2o`0000[ooooo1Ol00006ooooo`;o00001_ooool2o`0000Co
oooo0_l0000@ooooo`;o00001oooool3o`0000?ooooo1Ol00004ooooo`;o00001Oooool2o`0000_o
oooo0_l00009ooooo`;o00003?ooool2o`000003ooooool0003o000005Oooooo000Looooo`03o`00
0?oooooooooo04_ooooo0_l0000=ooooo`So00002Oooool3o`0000?ooooo0_l0000:ooooo`?o0000
0_ooool8o`0000cooooo0_l0000Jooooo`Co00001?ooool2o`0000Cooooo0_l00005ooooo`;o0000
2Oooool4o`0000Kooooo0_l000000ooooooo0000o`00001Xooooo`007?ooool00ol0003ooooooooo
o`1Jooooo`;o00001_ooool3o`0000Kooooo0ol0000Booooo`So00000_ooool2o`0000;ooooo0_l0
000Tooooo`Co00000oooool2o`0000_ooooo0_l000000ooooooo0000o`000005ooooo`;o00002?oo
ool2o`0006_ooooo000Looooo`03o`000?oooooooooo05?ooooo0_l00004ooooo`;o00001oooool3
o`0001Cooooo1?l00002ooooo`?o00002?ooool6o`0002Gooooo0ol00003ooooo`;o00002oooool5
o`000004ooooool0003o0000ooooo`;o00007?ooool2o`0005Sooooo000Looooo`03o`000?oooooo
oooo04cooooo0_l00005ooooo`;o000000Coooooo`000?l0003ooooo0_l00007ooooo`?o00000_oo
ool2o`00013ooooo1?l00002ooooo`;o00002?ooool2o`000003ooooool0003o000002gooooo0_l0
000:ooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000Kooooo0_l0
0003ooooo`;o00003oooool2o`0005Sooooo000Looooo`03o`000?oooooooooo04cooooo0_l00005
ooooo`;o000000?oooooo`000?l000000ol00007ooooo`;o00000oooool2o`0000kooooo0_l00005
ooooo`;o00002Oooool2o`0001[ooooo1Ol000000ooooooo0000o`000005ooooo`;o00001oooool2
o`0000[ooooo0_l0000@ooooo`;o000000?oooooo`000?l000000_l0001Yooooo`007?ooool00ol0
003oooooooooo`1=ooooo`;o00001Oooool2o`000003ooooool0003o000000;o00004_ooool2o`00
00Oooooo0ol00005ooooo`;o00001?ooool2o`000003ooooool0003o000001Sooooo2Ol000000ooo
oooo0000o`000003o`0000;ooooo0_l0000Xooooo`;o00001oooool2o`0000?ooooo1?l0001Koooo
o`007?ooool00ol0003oooooooooo`1=ooooo`;o00001?ooool3o`0000?ooooo0_l0000Booooo`;o
000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000?ooooo0_l00004ooooo`;o
000000?oooooo`000?l000000oooool2o`0000;ooooo0_l0000?ooooo`Oo00001?ooool4o`0002Ko
oooo0_l00003ooooo`;o00002?ooool2o`0000?ooooo1?l0001Kooooo`007?ooool00ol0003ooooo
ooooo`1Cooooo`;o00002oooool2o`0000kooooo0_l00007ooooo`?o00000_ooool2o`0000cooooo
0_l00002ooooo`;o00004oooool2o`0002[ooooo0_l000000ooooooo0000o`000002o`0000?ooooo
0_l00003ooooo`;o00003Oooool2o`0005Sooooo000Looooo`03o`000?oooooooooo063ooooo1?l0
0009ooooo`;o00002oooool2o`0000Gooooo0_l000000ooooooo0000o`00000Kooooo`;o00000_oo
ool2o`0000oooooo0_l0000Iooooo`;o000000?oooooo`000?l000002_ooool2o`0000Gooooo0_l0
0004ooooo`Co0000F?ooool001cooooo00?o0000ooooooooool0FOooool2o`0000Gooooo1?l00009
ooooo`;o00001Oooool3o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l000006oooool2
o`0000?ooooo0_l0000>ooooo`;o00009_ooool2o`0000Oooooo0_l00004ooooo`Co0000F?ooool0
01cooooo00?o0000ooooooooool0FOooool2o`0000_ooooo0_l00006ooooo`;o00001?ooool3o`00
00Cooooo0_l0000Yooooo`;o0000=_ooool2o`0006Wooooo000Looooo`;o0000E_ooool2o`0000[o
oooo0_l00002ooooo`?o00001_ooool2o`0004Oooooo0_l00003ooooo`;o00004Oooool2o`00013o
oooo0_l0001Vooooo`007?ooool00ol0003oooooooooo`1Booooo`;o000000?oooooo`000?l00000
2_ooool2o`0000;ooooo1?l0000Cooooo`;o00003_ooool4o`00023ooooo0_l00005ooooo`;o0000
0oooool2o`0000kooooo0_l000000ooooooo0000o`00000@ooooo`;o0000I_ooool001cooooo00?o
0000ooooooooool0D_ooool2o`0000gooooo1?l000001Ooooooo0000o`000?l0003ooooo00;o0000
0oooool2o`0000?ooooo0_l00006ooooo`;o00000_ooool2o`0000?ooooo0_l00005ooooo`Co0000
3?ooool2o`0001;ooooo1?l00003ooooo`;o00000_ooool2o`0000oooooo0_l00002ooooo`;o0000
00?oooooo`000?l000003_ooool2o`0006Cooooo000Looooo`03o`000?oooooooooo05_ooooo0_l0
0004ooooo`Co00001Oooool2o`0000?ooooo0_l00003ooooo`;o00002_ooool2o`0000?ooooo0_l0
000Eooooo`;o00003Oooool2o`0000Gooooo0_l00003ooooo`;o00000_ooool2o`000003ooooool0
003o0000013ooooo0_l000000ooooooo0000o`00000>ooooo`;o0000I?ooool001cooooo00?o0000
ooooooooool0Foooool2o`0000Cooooo0_l00005ooooo`?o00002Oooool2o`0002Oooooo0_l0000<
ooooo`;o00002?ooool4o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00001_ooool2
o`0000;ooooo0_l0000<ooooo`;o0000Joooool001cooooo00?o0000ooooooooool0E?ooool2o`00
00?ooooo0_l00006ooooo`;o00000_ooool2o`000005ooooool0003o0000o`000?ooool00_l00000
1?oooooo0000o`000?ooool2o`0002Wooooo0_l00004ooooo`Co00001Oooool2o`0000Oooooo1?l0
0006ooooo`;o000000?oooooo`000?l000001_ooool2o`0000;ooooo0_l0000<ooooo`;o00001Ooo
ool2o`0006Cooooo000Looooo`03o`000?oooooooooo05Cooooo0_l00003ooooo`;o00002?ooool4
o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000Cooooo1?l0
000Mooooo`;o00001oooool9o`000003ooooool0003o000000?ooooo1?l00002ooooo`;o00001_oo
ool2o`0002;ooooo0_l0001Tooooo`007?ooool00ol0003oooooooooo`1Sooooo`;o00001?ooool2
o`0000Wooooo0_l00002ooooo`Co00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`00000<
ooooo`;o00000oooool2o`0000Oooooo0_l00003ooooo`Co00001_ooool4o`000005ooooool0003o
0000o`000?ooool00_l00003ooooo`;o00001Oooool4o`0000Gooooo1?l0001fooooo`007?ooool0
0ol0003oooooooooo`1Jooooo`;o00001Oooool2o`0000Kooooo0_l00009ooooo`;o00000_ooool2
o`0000Cooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l00007ooooo`Co00003?oo
ool2o`0001;ooooo0ol000000ooooooo0000o`000003ooooo`;o00001Oooool4o`0000Gooooo1?l0
000<ooooo`;o0000J?ooool001cooooo00?o0000ooooooooool0F_ooool2o`0000;ooooo0_l00000
0ooooooo0000o`00000Eooooo`;o00002Oooool2o`0000Cooooo0_l00007ooooo`;o00001_ooool4
o`0000Cooooo0_l00004ooooo`;o00002_ooool2o`0000;ooooo0_l00005ooooo`;o00003_ooool4
o`0000cooooo0_l0001Xooooo`007?ooool00ol0003oooooooooo`1Nooooo`Oo00003oooool2o`00
00Oooooo0_l00004ooooo`;o00003Oooool2o`0000Kooooo1?l00004ooooo`;o00001?ooool2o`00
00[ooooo0_l00002ooooo`;o00008_ooool2o`0006_ooooo000Looooo`03o`000?oooooooooo063o
oooo1Ol0000?ooooo`?o00001Oooool3o`0000Oooooo0ol00009ooooo`;o00000oooool2o`0000Wo
oooo0_l0000;ooooo`;o000000?oooooo`000?l000009?ooool2o`0000;ooooo0_l0001[ooooo`00
7?ooool00ol0003oooooooooo`1/ooooo`;o00000oooool6o`0000Gooooo0_l00008ooooo`?o0000
3_ooool3o`0000Wooooo0_l00006ooooo`;o00000_ooool5o`0001Gooooo0_l00004ooooo`;o0000
1oooool2o`0006oooooo000Looooo`03o`000?oooooooooo06Oooooo0_l00003ooooo`;o00000ooo
ool3o`0000?ooooo0_l0000Cooooo`;o00001_ooool2o`0000;ooooo0ol00008ooooo`?o00001?oo
ool3o`000003ooooool0003o000000?o00004_ooool2o`0000;ooooo0_l00004ooooo`;o0000N?oo
ool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o
8B4Qolc<c006ooooo`03o`000?oooooooooo06Oooooo0_l00006ooooo`;o00001_ooool2o`0000go
oooo0_l00004ooooo`?o00001Oooool2o`0000?ooooo0ol00008ooooo`;o00001?ooool2o`0000;o
oooo0_l0000Aooooo`;o00000_ooool2o`0008;ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMg
M`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1_
ooooo`;o00005Oooool2o`0000?ooooo1?l0000;ooooo`;o00009Oooool2o`000003ooooool0003o
000000?ooooo0_l0001nooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`1Vooooo`;o00001_ooool4
o`0000Cooooo0_l0000Cooooo`;o00004oooool2o`0002;ooooo0_l00003ooooo`;o00001?ooool2
o`0007Sooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRH
V?ooooooV9RHoc8b<P06ooooo`?o0000I_ooool2o`0000Kooooo1?l00004ooooo`Co00009_ooool2
o`0002Oooooo0_l00004ooooo`;o0000N?ooool00003ooooool0003ooooo00;ooooo00?o0000oooo
ooooool02Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0N?ooool2
o`0000?ooooo0_l0000?ooooo`;o00004?ooool2o`0000cooooo1Ol00002ooooo`;o00004Oooool2
o`0007oooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go410@okZj
^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo06[ooooo0_l0000=ooooo`;o00000_ooool2
o`0000oooooo0ol0000?ooooo`;o00000_ooool2o`0000Sooooo1Ol00002ooooo`;o00004Oooool2
o`0007oooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zj
o`000006ooooo`03o`000?oooooooooo06[ooooo0ol00007ooooo`?o00000_ooool2o`0001Cooooo
0_l00009ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Cooooo0_l00002ooooo`;o0000
1Oooool2o`0000gooooo0_l00023ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05
ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`1[ooooo`;o00001oooool4o`00
00Kooooo0_l0000Iooooo`?o000000?oooooo`000?l000001Oooool2o`0000Cooooo0_l0000Aoooo
o`;o00000oooool4o`0008?ooooo000Looooo`03o`000?oooooooooo06cooooo0_l00008ooooo`;o
00001Oooool3o`0000[ooooo0_l0000:ooooo`;o000000Coooooo`000?l0003o00002?ooool4o`00
01Gooooo0_l00003ooooo`;o0000QOooool001cooooo00?o0000ooooooooool0K?ooool4o`0000go
oooo0_l00003ooooo`Co00001?ooool2o`0000;ooooo0_l00006ooooo`;o00003_ooool2o`000:7o
oooo000Looooo`03o`000?oooooooooo06kooooo0_l0000Booooo`Oo00001Oooool2o`0000Cooooo
0_l0000Qooooo`;o0000T?ooool001cooooo00?o0000ooooooooool0Moooool2o`0000Sooooo1?l0
00001?oooooo0000o`000?l0000;ooooo`;o00002_ooool2o`00017ooooo0_l00002ooooo`;o0000
2Oooool2o`0008Gooooo000Looooo`03o`000?oooooooooo077ooooo0_l00004ooooo`;o00002?oo
ool2o`0000?ooooo0_l0000<ooooo`;o00002_ooool2o`0000Cooooo0_l00003ooooo`;o00001_oo
ool2o`0000gooooo0_l00025ooooo`007?ooool00ol0003oooooooooo`1aooooo`;o00004?ooool3
o`000003ooooool0003o000000gooooo0_l0000>ooooo`;o00000oooool2o`0000Wooooo0_l00003
ooooo`;o0000S?ooool001cooooo00?o0000ooooooooool0Poooool3o`000003ooooool0003o0000
00_ooooo1_l0000Aooooo`;o00002Oooool2o`0000?ooooo0_l0002<ooooo`007?ooool00ol0003o
ooooooooo`26ooooo`;o00003?ooool6o`00017ooooo0_l0000<ooooo`;o0000S_ooool001cooooo
00?o0000ooooooooool0Q_ooool2o`0000Wooooo0_l000000ooooooo0000o`000002o`0000Wooooo
0_l00008ooooo`;o00003?ooool4o`0008cooooo000Looooo`03o`000?oooooooooo097ooooo0_l0
000>ooooo`;o00001_ooool2o`0000Sooooo0_l00005ooooo`?o00001_ooool2o`0008Cooooo000L
ooooo`03o`000?oooooooooo0:Wooooo0_l00008ooooo`;o00000oooool2o`0000Wooooo0_l00024
ooooo`007?ooool2o`0008Wooooo0_l0000Qooooo`;o00002oooool2o`0008oooooo000Looooo`03
o`000?oooooooooo08Sooooo0_l0000@ooooo`Co000000?oooooo`000?l000002_ooool2o`000003
ooooool0003o000000Kooooo0_l0002Aooooo`007?ooool00ol0003oooooooooo`2?ooooo`;o0000
2Oooool4o`000003ooooool0003o000000gooooo0_l00006ooooo`;o0000TOooool001cooooo00?o
0000ooooooooool0Soooool2o`0000Cooooo0_l00008ooooo`?o00001_ooool2o`0001Gooooo0_l0
0028ooooo`007?ooool00ol0003oooooooooo`2Eooooo`;o00002Oooool2o`0000Gooooo0ol0000A
ooooo`;o00000_ooool2o`0008Sooooo000Looooo`03o`000?oooooooooo09Kooooo1?l00004oooo
o`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo0_l0000>ooooo`;o0000S?ooool001co
oooo00?o0000ooooooooool0U_ooool4o`0000Cooooo0_l000000ooooooo0000o`000008ooooo`;o
00001?ooool2o`0009Kooooo000Looooo`03o`000?oooooooooo0;7ooooo0_l0002Fooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Booooo`Co
000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003ooooooooo
o`05ooooo`?o0000oooooom:ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Doooo
o`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`00
5?ooool00ol0003oooooooooo`3ooooooe;ooooo000Booooo`03oeEEEOmVIVKo00000?ooooooE?oo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Gooooo00Co410@o`000?l0003o
oooo0_l000000ol@413oooooooooo`0Gooooo`03o`000?o^k^kooooo00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0T?ooool00:Kooooo00Go0000oooo
ooooooooooooo`000009ooooo`Ko00002oooool00omEEEGoZJVYooooo`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool01OlQ8B7oV9RHoooooonHV9So8B4Q093ooooo002Vooooo`05o`000?oo
ooooooooooooool000006_ooool00onYZJWoEEEEooooo`03ooooo`05oa0@4?ooooooooooooooool@
41000oooool01Ol0003ooooooooooooooooo0000093ooooo002Vooooo`05o`000?oooooooooooooo
ool000002Oooool6o`0000cooooo00?o8B4Qooooooooool00_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P2@ooooo`00Y_ooool01Ol0003oQhN7oooooonY
ZJWo000001_ooooo00?oEEEEolc<c?ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Goc<c<o`000?l0003o0000olc<c02@ooooo`00YOooool00ol@413o0000ogMgM`02o`000003oiRH
V?oooooooooo01Wooooo00?oZJVYogMgMoooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@okZj^_oooooo^[Zjoa0@402@ooooo`00`oooool01Ol@413ooooooooooooooooo<S8b
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05o`000?nj^[[ooooookZj^_l00000T?oo
ool00<?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01OnYZJWo410@o`00
0?l@413oZJVY093ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(714) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.5211 .36084 Mdot
.54829 .34196 Mdot
.38091 .64074 Mdot
.59719 .497 Mdot
.49508 .62115 Mdot
.35322 .62161 Mdot
.36907 .46737 Mdot
.39906 .48963 Mdot
.36738 .62841 Mdot
.60089 .28164 Mdot
.34891 .45914 Mdot
.56206 .4756 Mdot
.37928 .46439 Mdot
.65246 .52714 Mdot
.19489 .4068 Mdot
.6683 .56452 Mdot
.55945 .30401 Mdot
.52674 .70094 Mdot
.68363 .55635 Mdot
.36241 .64754 Mdot
.48182 .29279 Mdot
.65064 .52125 Mdot
.55342 .33989 Mdot
.65107 .5255 Mdot
.6076 .52764 Mdot
.52192 .33333 Mdot
.5296 .36731 Mdot
.61423 .50177 Mdot
.63445 .54522 Mdot
.37142 .43567 Mdot
.4804 .64947 Mdot
.1448 .53869 Mdot
.63534 .57604 Mdot
.77024 .48237 Mdot
.40839 .45496 Mdot
.45736 .8068 Mdot
.38375 .60921 Mdot
.36439 .48629 Mdot
.40905 .47506 Mdot
.40353 .46869 Mdot
.39512 .47002 Mdot
.52635 .33762 Mdot
.36165 .42651 Mdot
.32218 .44134 Mdot
.60263 .48585 Mdot
.35317 .33282 Mdot
.54956 .7585 Mdot
.61795 .50064 Mdot
.51464 .35048 Mdot
.34118 .64749 Mdot
.81045 .48348 Mdot
.36847 .49055 Mdot
.268 .35823 Mdot
.16369 .3207 Mdot
.39122 .44694 Mdot
.60291 .49523 Mdot
.37091 .59788 Mdot
.64564 .49153 Mdot
.63707 .50665 Mdot
.77965 .44019 Mdot
.62694 .53093 Mdot
.55777 .67398 Mdot
.55539 .3656 Mdot
.38858 .64196 Mdot
.36219 .6248 Mdot
.39343 .43868 Mdot
.54485 .29142 Mdot
.38183 .47323 Mdot
.65518 .4485 Mdot
.35255 .64474 Mdot
.61752 .49716 Mdot
.34791 .46384 Mdot
.53266 .28384 Mdot
.65564 .55831 Mdot
.39109 .33659 Mdot
.24343 .40396 Mdot
.55806 .6369 Mdot
.73216 .41924 Mdot
.62748 .21754 Mdot
.26936 .44883 Mdot
.64795 .53558 Mdot
.58435 .1675 Mdot
.20554 .40163 Mdot
.55416 .32793 Mdot
.73487 .56473 Mdot
.27698 .62852 Mdot
.66013 .54838 Mdot
.4789 .55437 Mdot
.57477 .50344 Mdot
.44714 .33602 Mdot
.37187 .62468 Mdot
.51986 .3428 Mdot
.59652 .49121 Mdot
.67275 .53982 Mdot
.70317 .30859 Mdot
.58752 .54348 Mdot
.61752 .4819 Mdot
.51239 .36739 Mdot
.35922 .44711 Mdot
.58332 .46475 Mdot
.31889 .43503 Mdot
.27063 .37265 Mdot
.5954 .5327 Mdot
.35232 .63406 Mdot
.56835 .33013 Mdot
.58651 .50931 Mdot
.39433 .44452 Mdot
.63451 .52704 Mdot
.36343 .51572 Mdot
.5329 .35666 Mdot
.67266 .53788 Mdot
.53699 .70912 Mdot
.42359 .31217 Mdot
.50632 .31813 Mdot
.46131 .19017 Mdot
.62625 .52174 Mdot
.64706 .51306 Mdot
.54836 .33794 Mdot
.3632 .58898 Mdot
.46399 .54433 Mdot
.54742 .28749 Mdot
.40655 .47301 Mdot
.5473 .35721 Mdot
.62491 .45495 Mdot
.34513 .60147 Mdot
.27268 .3683 Mdot
.27888 .38957 Mdot
.7237 .70043 Mdot
.64951 .55676 Mdot
.28992 .35305 Mdot
.34973 .6101 Mdot
.53276 .34512 Mdot
.38449 .47052 Mdot
.65461 .46726 Mdot
.54109 .29899 Mdot
.37197 .48413 Mdot
.54977 .70958 Mdot
.40897 .71635 Mdot
.50119 .3205 Mdot
.51043 .49169 Mdot
.41615 .45997 Mdot
.40323 .46636 Mdot
.80127 .5345 Mdot
.5504 .33156 Mdot
.54167 .69526 Mdot
.37308 .48273 Mdot
.69341 .6497 Mdot
.65258 .46724 Mdot
.7727 .58583 Mdot
.63375 .19203 Mdot
.80976 .50403 Mdot
.34323 .25526 Mdot
.55838 .65895 Mdot
.38414 .48713 Mdot
.59559 .51858 Mdot
.54231 .32178 Mdot
.53875 .33054 Mdot
.68026 .5155 Mdot
.61417 .52666 Mdot
.66368 .48525 Mdot
.67737 .50773 Mdot
.52277 .76972 Mdot
.66991 .49201 Mdot
.42067 .56509 Mdot
.52176 .2982 Mdot
.61504 .53694 Mdot
.3979 .59551 Mdot
.68985 .52384 Mdot
.3628 .48479 Mdot
.6385 .50147 Mdot
.60826 .51798 Mdot
.60078 .55364 Mdot
.39513 .47532 Mdot
.20222 .63961 Mdot
.57531 .19613 Mdot
.33242 .74894 Mdot
.38038 .24202 Mdot
.36101 .60129 Mdot
.66319 .53126 Mdot
.55922 .69057 Mdot
.66371 .59887 Mdot
.63531 .5102 Mdot
.80602 .43629 Mdot
.61339 .51433 Mdot
.66921 .41779 Mdot
.61694 .59125 Mdot
.30589 .74422 Mdot
.44555 .47095 Mdot
.63432 .54275 Mdot
.62895 .25973 Mdot
.78427 .58649 Mdot
.55115 .62762 Mdot
.39441 .4554 Mdot
.3908 .58136 Mdot
.38027 .59497 Mdot
.38339 .42197 Mdot
.60254 .4511 Mdot
.60112 .30325 Mdot
.61937 .44119 Mdot
.27853 .36843 Mdot
.56969 .2984 Mdot
.54136 .65771 Mdot
.50014 .33268 Mdot
.51496 .14837 Mdot
.49646 .39868 Mdot
.39117 .50666 Mdot
.53397 .71283 Mdot
.38987 .63224 Mdot
.28377 .36757 Mdot
.55406 .69549 Mdot
.62428 .48381 Mdot
.51762 .34931 Mdot
.79028 .58119 Mdot
.66712 .579 Mdot
.66292 .79718 Mdot
.55447 .31 Mdot
.46229 .50662 Mdot
.39144 .46183 Mdot
.3313 .63949 Mdot
.65112 .55009 Mdot
.66477 .49466 Mdot
.54828 .36783 Mdot
.62005 .50515 Mdot
.46595 .30206 Mdot
.60757 .51307 Mdot
.38921 .64368 Mdot
.5797 .6554 Mdot
.34602 .42969 Mdot
.73959 .68418 Mdot
.5147 .28848 Mdot
.43223 .61587 Mdot
.37427 .63657 Mdot
.57326 .26651 Mdot
.35031 .45185 Mdot
.54874 .71166 Mdot
.38936 .61236 Mdot
.57502 .68095 Mdot
.60252 .54581 Mdot
.38116 .61697 Mdot
.53517 .67512 Mdot
.36698 .71103 Mdot
.60893 .48422 Mdot
.65539 .63911 Mdot
.36639 .47105 Mdot
.52099 .36417 Mdot
.62657 .53198 Mdot
.27544 .38991 Mdot
.65326 .45781 Mdot
.24298 .35027 Mdot
.26172 .37032 Mdot
.26663 .36039 Mdot
.24215 .43282 Mdot
.5685 .67894 Mdot
.3605 .29034 Mdot
.50965 .44738 Mdot
.55387 .29358 Mdot
.59882 .48675 Mdot
.24527 .69427 Mdot
.37553 .4825 Mdot
.62498 .48466 Mdot
.27978 .64379 Mdot
.37254 .48199 Mdot
.65067 .49754 Mdot
.39903 .46406 Mdot
.54226 .32564 Mdot
.45077 .58024 Mdot
.563 .33049 Mdot
.60778 .48904 Mdot
.37702 .44671 Mdot
.3922 .59443 Mdot
.52241 .33123 Mdot
.63371 .52225 Mdot
.66021 .53071 Mdot
.28529 .37333 Mdot
.61996 .54156 Mdot
.26006 .69793 Mdot
.61522 .49919 Mdot
.39577 .62297 Mdot
.58215 .53411 Mdot
.82468 .52941 Mdot
.41451 .71144 Mdot
.52632 .2919 Mdot
.26286 .36692 Mdot
.37296 .61794 Mdot
.4664 .6332 Mdot
.54486 .59257 Mdot
.64227 .53155 Mdot
.27343 .381 Mdot
.44297 .52592 Mdot
.38978 .43669 Mdot
.57857 .49802 Mdot
.45921 .37801 Mdot
.38322 .62734 Mdot
.28248 .36853 Mdot
.59533 .57516 Mdot
.56663 .33389 Mdot
.59794 .50123 Mdot
.38596 .61054 Mdot
.54318 .36121 Mdot
.64384 .4619 Mdot
.54788 .76727 Mdot
.26591 .38152 Mdot
.3681 .47236 Mdot
.54391 .47673 Mdot
.65708 .47649 Mdot
.37883 .58879 Mdot
.54912 .31235 Mdot
.38157 .44069 Mdot
.51127 .32829 Mdot
.78827 .59576 Mdot
.38931 .24819 Mdot
.43163 .77493 Mdot
.52816 .70734 Mdot
.23954 .33046 Mdot
.35057 .76121 Mdot
.393 .2704 Mdot
.68685 .70761 Mdot
.44509 .82842 Mdot
.39627 .60237 Mdot
.68594 .612 Mdot
.37367 .60876 Mdot
.59774 .53081 Mdot
.3561 .62422 Mdot
.2846 .74175 Mdot
.61184 .50579 Mdot
.36406 .59816 Mdot
.50205 .75679 Mdot
.61924 .52955 Mdot
.5115 .306 Mdot
.16053 .45627 Mdot
.53793 .22097 Mdot
.53349 .41554 Mdot
.36029 .59531 Mdot
.77777 .36306 Mdot
.61743 .51484 Mdot
.66861 .56865 Mdot
.53723 .32174 Mdot
.57718 .49641 Mdot
.53205 .66933 Mdot
.57308 .6966 Mdot
.76642 .57141 Mdot
.48531 .20197 Mdot
.67582 .45074 Mdot
.52642 .33055 Mdot
.63565 .22255 Mdot
.38965 .33955 Mdot
.29173 .39084 Mdot
.41287 .47077 Mdot
.20179 .63559 Mdot
.71028 .54953 Mdot
.51394 .50128 Mdot
.44893 .37515 Mdot
.52702 .34993 Mdot
.3243 .71518 Mdot
.38569 .44754 Mdot
.6144 .23386 Mdot
.63668 .37257 Mdot
.65398 .47933 Mdot
.36976 .43128 Mdot
.56953 .46955 Mdot
.45588 .32348 Mdot
.70013 .62282 Mdot
.33283 .5181 Mdot
.60512 .48809 Mdot
.36651 .29782 Mdot
.64274 .50938 Mdot
.7663 .59434 Mdot
.61755 .48604 Mdot
.51134 .32021 Mdot
.67674 .44776 Mdot
.51004 .58065 Mdot
.53553 .19393 Mdot
.48121 .38749 Mdot
.56368 .65963 Mdot
.65773 .52418 Mdot
.65772 .48393 Mdot
.5506 .66457 Mdot
.52089 .31856 Mdot
.62742 .47429 Mdot
.60592 .76888 Mdot
.65591 .47748 Mdot
.35419 .47998 Mdot
.46987 .59927 Mdot
.57701 .37738 Mdot
.6676 .54483 Mdot
.55445 .35535 Mdot
.39813 .45388 Mdot
.40713 .48297 Mdot
.70805 .50864 Mdot
.38743 .48523 Mdot
.59972 .50351 Mdot
.4642 .59223 Mdot
.54815 .34907 Mdot
.56768 .55193 Mdot
.52328 .31315 Mdot
.71198 .27208 Mdot
.4019 .45839 Mdot
.29601 .38331 Mdot
.57991 .60024 Mdot
.37694 .45515 Mdot
.52948 .23026 Mdot
.71589 .53027 Mdot
.68946 .48838 Mdot
.53357 .22671 Mdot
.38152 .58123 Mdot
.29264 .37135 Mdot
.3866 .44194 Mdot
.66195 .48191 Mdot
.59107 .53229 Mdot
.34561 .45665 Mdot
.73118 .33482 Mdot
.47201 .65779 Mdot
.61537 .48801 Mdot
.51397 .31864 Mdot
.52965 .34376 Mdot
.63392 .46267 Mdot
.63181 .51203 Mdot
.40026 .60635 Mdot
.27507 .38382 Mdot
.27616 .36152 Mdot
.28176 .39022 Mdot
.33441 .60921 Mdot
.26733 .30739 Mdot
.40296 .46738 Mdot
.29228 .32201 Mdot
.24769 .58233 Mdot
.7069 .52765 Mdot
.38111 .58617 Mdot
.66079 .49921 Mdot
.60694 .54476 Mdot
.37507 .44328 Mdot
.36263 .21533 Mdot
.62612 .43067 Mdot
.50093 .3432 Mdot
.34754 .47602 Mdot
.60885 .59673 Mdot
.41708 .41285 Mdot
.52997 .68038 Mdot
.50659 .39695 Mdot
.36307 .43378 Mdot
.5138 .34127 Mdot
.3494 .44608 Mdot
.65897 .48335 Mdot
.68426 .51964 Mdot
.54116 .35072 Mdot
.56931 .68094 Mdot
.58456 .51718 Mdot
.65023 .4987 Mdot
.85034 .4791 Mdot
.3895 .33023 Mdot
.41245 .41347 Mdot
.61125 .54143 Mdot
.69304 .48973 Mdot
.56984 .66842 Mdot
.64636 .47259 Mdot
.65348 .54923 Mdot
.43034 .3008 Mdot
.38292 .42023 Mdot
.56126 .63924 Mdot
.60295 .23176 Mdot
.55254 .30753 Mdot
.26462 .68821 Mdot
.2687 .37189 Mdot
.35828 .41951 Mdot
.44713 .57278 Mdot
.29319 .37908 Mdot
.26591 .57347 Mdot
.29845 .70175 Mdot
.2917 .38611 Mdot
.38407 .5519 Mdot
.73442 .53393 Mdot
.67624 .48974 Mdot
.64055 .49935 Mdot
.55823 .69641 Mdot
.54892 .3271 Mdot
.44261 .50196 Mdot
.35608 .69444 Mdot
.64922 .51827 Mdot
.48838 .35513 Mdot
.28043 .68427 Mdot
.28733 .37255 Mdot
.56456 .67841 Mdot
.5438 .65345 Mdot
.64562 .50988 Mdot
.42303 .27143 Mdot
.52435 .33318 Mdot
.63391 .52219 Mdot
.67345 .51933 Mdot
.36463 .59115 Mdot
.51146 .34193 Mdot
.37307 .63727 Mdot
.26056 .37366 Mdot
.53513 .8332 Mdot
.85032 .49735 Mdot
.36377 .45347 Mdot
.33592 .73944 Mdot
.38194 .49683 Mdot
.29656 .45896 Mdot
.28207 .38847 Mdot
.64093 .52181 Mdot
.51699 .28894 Mdot
.6331 .5257 Mdot
.63981 .47631 Mdot
.62752 .47949 Mdot
.67267 .44843 Mdot
.80873 .44397 Mdot
.5498 .68831 Mdot
.69197 .48263 Mdot
.38998 .57326 Mdot
.29646 .72383 Mdot
.15909 .49632 Mdot
.6665 .51389 Mdot
.65014 .51213 Mdot
.54144 .29375 Mdot
.66239 .5598 Mdot
.37848 .43465 Mdot
.55444 .32247 Mdot
.589 .52533 Mdot
.35134 .72135 Mdot
.64624 .4694 Mdot
.36599 .76782 Mdot
.34759 .44946 Mdot
.51734 .39939 Mdot
.67844 .46292 Mdot
.2911 .3872 Mdot
.29374 .37305 Mdot
.29292 .39301 Mdot
.38552 .43187 Mdot
.37054 .59164 Mdot
.33476 .68015 Mdot
.56743 .51991 Mdot
.59613 .5152 Mdot
.68683 .48027 Mdot
.32792 .63153 Mdot
.47378 .58192 Mdot
.34577 .26317 Mdot
.67051 .58966 Mdot
.37953 .57462 Mdot
.49409 .34632 Mdot
.44751 .1778 Mdot
.5526 .31843 Mdot
.5646 .63953 Mdot
.35513 .47745 Mdot
.52821 .68149 Mdot
.79558 .40079 Mdot
.54159 .353 Mdot
.54594 .36966 Mdot
.36223 .59923 Mdot
.45931 .473 Mdot
.09793 .44081 Mdot
.34423 .62746 Mdot
.64885 .74799 Mdot
.53259 .32333 Mdot
.62952 .5658 Mdot
.43717 .53098 Mdot
.46276 .47928 Mdot
.36575 .60879 Mdot
.65128 .53603 Mdot
.47709 .21965 Mdot
.39848 .6126 Mdot
.57889 .50482 Mdot
.35189 .59923 Mdot
.39185 .47672 Mdot
.35057 .60649 Mdot
.49045 .31965 Mdot
.60688 .54826 Mdot
.13108 .36629 Mdot
.40918 .39352 Mdot
.62962 .53222 Mdot
.35118 .47921 Mdot
.58669 .78416 Mdot
.64768 .48177 Mdot
.53014 .67142 Mdot
.36893 .5742 Mdot
.4809 .72338 Mdot
.6199 .51909 Mdot
.35768 .61647 Mdot
.4993 .34654 Mdot
.37455 .40705 Mdot
.25746 .425 Mdot
.28326 .36372 Mdot
.54594 .31946 Mdot
.3022 .39492 Mdot
.4046 .43902 Mdot
.58822 .53704 Mdot
.67459 .51068 Mdot
.51547 .30627 Mdot
.23719 .47239 Mdot
.61611 .56868 Mdot
.64803 .53542 Mdot
.38394 .6356 Mdot
.32381 .62436 Mdot
.19013 .49026 Mdot
.39649 .59813 Mdot
.69268 .48785 Mdot
.51374 .30885 Mdot
.59117 .51779 Mdot
.51486 .30124 Mdot
.5984 .48755 Mdot
.56002 .38603 Mdot
.55176 .32115 Mdot
.43526 .21741 Mdot
.63708 .55114 Mdot
.56492 .56981 Mdot
.63772 .47523 Mdot
.62161 .48262 Mdot
.36488 .57573 Mdot
.54366 .67523 Mdot
.57506 .52145 Mdot
.44144 .59825 Mdot
.56407 .69778 Mdot
.75297 .48018 Mdot
.36631 .58872 Mdot
.55148 .70294 Mdot
.61922 .66524 Mdot
.2635 .36634 Mdot
.55505 .68204 Mdot
.17431 .53667 Mdot
.36572 .45071 Mdot
.55603 .34179 Mdot
.61864 .53024 Mdot
.48 .83971 Mdot
.47863 .65068 Mdot
.28583 .37969 Mdot
.62465 .52265 Mdot
.65799 .49417 Mdot
.56828 .31998 Mdot
.54746 .15397 Mdot
.3536 .65552 Mdot
.59292 .49953 Mdot
.55942 .30627 Mdot
.62268 .18741 Mdot
.34279 .6099 Mdot
.55881 .68358 Mdot
.34291 .46488 Mdot
.49352 .29027 Mdot
.28625 .36452 Mdot
.40086 .44282 Mdot
.33781 .58248 Mdot
.78733 .36513 Mdot
.62055 .51278 Mdot
.38598 .59204 Mdot
.81024 .49859 Mdot
.57974 .47576 Mdot
.42125 .43667 Mdot
.63764 .41617 Mdot
.52493 .34814 Mdot
.34451 .46368 Mdot
.5585 .65326 Mdot
.5505 .34796 Mdot
.51969 .32026 Mdot
.39683 .49039 Mdot
.42027 .59263 Mdot
.4635 .50419 Mdot
.3471 .47015 Mdot
.44503 .32421 Mdot
.7827 .56101 Mdot
.2717 .3814 Mdot
.5649 .67531 Mdot
.79847 .58884 Mdot
.52458 .33733 Mdot
.2023 .63687 Mdot
.80831 .45179 Mdot
.61749 .48198 Mdot
.53455 .69332 Mdot
.26931 .58707 Mdot
.3285 .68126 Mdot
.36859 .48029 Mdot
.48475 .5766 Mdot
.5309 .66454 Mdot
.65979 .47337 Mdot
.572 .39159 Mdot
.63763 .54941 Mdot
.37701 .48439 Mdot
.47679 .27296 Mdot
.50863 .3355 Mdot
.40131 .43368 Mdot
.46045 .31837 Mdot
.61065 .54718 Mdot
.64797 .54574 Mdot
.74557 .63953 Mdot
.51635 .34935 Mdot
.28404 .36276 Mdot
.63791 .53344 Mdot
.64348 .49214 Mdot
.59013 .54234 Mdot
.5485 .54717 Mdot
.4128 .29217 Mdot
.59157 .50047 Mdot
.33658 .60987 Mdot
.69028 .50488 Mdot
.64796 .54762 Mdot
.56501 .32214 Mdot
.83561 .46813 Mdot
.26082 .37889 Mdot
.63849 .49665 Mdot
.61742 .48817 Mdot
.40852 .47204 Mdot
.45278 .51565 Mdot
.46236 .46874 Mdot
.35206 .64146 Mdot
.67906 .69623 Mdot
.62498 .44219 Mdot
.54147 .30084 Mdot
.53124 .70442 Mdot
.63144 .56184 Mdot
.54687 .29925 Mdot
.68392 .4954 Mdot
.40038 .58889 Mdot
.2758 .38307 Mdot
.53073 .45448 Mdot
.55493 .67658 Mdot
.38782 .53572 Mdot
.31764 .34105 Mdot
.39717 .59093 Mdot
.60136 .52303 Mdot
.34547 .41904 Mdot
.37117 .63477 Mdot
.28477 .37476 Mdot
.60238 .57947 Mdot
.53579 .33044 Mdot
.50969 .33427 Mdot
.76726 .5806 Mdot
.34037 .65848 Mdot
.78201 .31178 Mdot
.39044 .47825 Mdot
.61145 .46314 Mdot
.30865 .36081 Mdot
.50694 .32763 Mdot
.77293 .61363 Mdot
.55432 .70187 Mdot
.36743 .47896 Mdot
.26311 .38823 Mdot
.54296 .29685 Mdot
.50414 .33537 Mdot
.60836 .48218 Mdot
.6625 .51442 Mdot
.68329 .71567 Mdot
.77141 .58925 Mdot
.39655 .46863 Mdot
.56197 .66908 Mdot
.34491 .64468 Mdot
.60955 .54347 Mdot
.55459 .33165 Mdot
.68312 .42379 Mdot
.6655 .48338 Mdot
.39799 .61502 Mdot
.53241 .34986 Mdot
.55608 .66384 Mdot
.54082 .70595 Mdot
.62209 .48199 Mdot
.7556 .42803 Mdot
.37303 .45816 Mdot
.50702 .3136 Mdot
.56325 .26918 Mdot
.60311 .56464 Mdot
.66287 .51817 Mdot
.55862 .49575 Mdot
.40136 .44371 Mdot
.5453 .4347 Mdot
.52624 .66528 Mdot
.54067 .3345 Mdot
.63132 .5312 Mdot
.55793 .6744 Mdot
.53002 .49429 Mdot
.28851 .38544 Mdot
.34998 .60165 Mdot
.5337 .66495 Mdot
.53872 .67335 Mdot
.56162 .7033 Mdot
.19691 .62384 Mdot
.56098 .28989 Mdot
.59488 .2203 Mdot
.62255 .47796 Mdot
.7652 .5756 Mdot
.66944 .55344 Mdot
.39172 .43134 Mdot
.3908 .58617 Mdot
.64628 .47695 Mdot
.60771 .48221 Mdot
.5794 .39549 Mdot
.59788 .59297 Mdot
.47585 .30373 Mdot
.5253 .35463 Mdot
.56695 .57626 Mdot
.37517 .58377 Mdot
.60588 .16158 Mdot
.18436 .64788 Mdot
.65815 .45199 Mdot
.45257 .50085 Mdot
.55427 .32504 Mdot
.39695 .48785 Mdot
.46932 .47699 Mdot
.34043 .45434 Mdot
.54053 .33886 Mdot
.60195 .53696 Mdot
.29917 .32052 Mdot
.57195 .69345 Mdot
.66721 .49023 Mdot
.39087 .46787 Mdot
.6657 .48772 Mdot
.38251 .42805 Mdot
.47204 .33918 Mdot
.43649 .36202 Mdot
.61316 .51214 Mdot
.60891 .56493 Mdot
.56696 .41677 Mdot
.66561 .51345 Mdot
.28486 .5386 Mdot
.52957 .31471 Mdot
.47963 .21079 Mdot
.6308 .46469 Mdot
.74964 .3937 Mdot
.66736 .48262 Mdot
.23693 .48501 Mdot
.66679 .52967 Mdot
.49799 .52615 Mdot
.65592 .46996 Mdot
.66186 .5332 Mdot
.38211 .44453 Mdot
.40809 .47541 Mdot
.49891 .34463 Mdot
.29258 .3678 Mdot
.30451 .74139 Mdot
.6545 .50546 Mdot
.34583 .58941 Mdot
.3205 .37542 Mdot
.54042 .67401 Mdot
.53666 .33952 Mdot
.68359 .20283 Mdot
.39961 .45803 Mdot
.39135 .63915 Mdot
.25408 .4884 Mdot
.33715 .6494 Mdot
.33915 .49637 Mdot
.58052 .59147 Mdot
.56118 .66389 Mdot
.66775 .48193 Mdot
.76376 .47139 Mdot
.37514 .31113 Mdot
.58481 .49279 Mdot
.40375 .42681 Mdot
.66066 .60185 Mdot
.78894 .55522 Mdot
.56988 .65662 Mdot
.55287 .65589 Mdot
.38691 .44408 Mdot
.3731 .64459 Mdot
.59309 .45125 Mdot
.55044 .70377 Mdot
.38951 .57849 Mdot
.30103 .37805 Mdot
.55416 .61202 Mdot
.52684 .33508 Mdot
.53247 .42234 Mdot
.36202 .35856 Mdot
.39724 .46583 Mdot
.44342 .59141 Mdot
.48405 .31372 Mdot
.57045 .33475 Mdot
.29864 .38023 Mdot
.37234 .57051 Mdot
.53766 .28185 Mdot
.58615 .52595 Mdot
.66904 .5786 Mdot
.64261 .51083 Mdot
.54525 .70124 Mdot
.66878 .53134 Mdot
.38518 .57075 Mdot
.37833 .48002 Mdot
.37378 .62587 Mdot
.37043 .45868 Mdot
.30569 .3056 Mdot
.62842 .51051 Mdot
.65948 .52093 Mdot
.44934 .55397 Mdot
.5025 .34039 Mdot
.777 .42651 Mdot
.36145 .57329 Mdot
.37294 .60065 Mdot
.59136 .52132 Mdot
.50317 .35119 Mdot
.57627 .70405 Mdot
.4297 .54205 Mdot
.67072 .52375 Mdot
.53069 .31379 Mdot
.59349 .50587 Mdot
.43043 .76788 Mdot
.42385 .36103 Mdot
.51029 .32863 Mdot
.51678 .18656 Mdot
.62506 .54684 Mdot
.72574 .564 Mdot
.69714 .49726 Mdot
.62433 .73762 Mdot
.59194 .55527 Mdot
.55551 .31203 Mdot
.63823 .50368 Mdot
.54513 .3084 Mdot
.39078 .62506 Mdot
.40067 .47713 Mdot
.54349 .31736 Mdot
.66359 .55067 Mdot
.16512 .59039 Mdot
.39278 .46995 Mdot
.65913 .52853 Mdot
.35761 .44436 Mdot
.56087 .31422 Mdot
.5096 .34901 Mdot
.17982 .54117 Mdot
.42486 .42882 Mdot
.3947 .46566 Mdot
.59757 .50827 Mdot
.37703 .37995 Mdot
.59132 .5172 Mdot
.69333 .70923 Mdot
.61425 .46767 Mdot
.58042 .53026 Mdot
.22882 .33956 Mdot
.33781 .46487 Mdot
.74158 .26584 Mdot
.3593 .69918 Mdot
.1889 .60763 Mdot
.5262 .2766 Mdot
.5699 .65652 Mdot
.31439 .7078 Mdot
.26179 .37322 Mdot
.35348 .58975 Mdot
.64643 .47655 Mdot
.56617 .38456 Mdot
.34645 .47325 Mdot
.54206 .68146 Mdot
.61311 .51324 Mdot
.40277 .59576 Mdot
.17218 .50846 Mdot
.38326 .48718 Mdot
.5276 .33801 Mdot
.50203 .34213 Mdot
.59611 .19011 Mdot
.62903 .52822 Mdot
.65635 .5195 Mdot
.35719 .47994 Mdot
.61912 .44504 Mdot
.56131 .70819 Mdot
.47699 .76453 Mdot
.39429 .46047 Mdot
.39319 .3903 Mdot
.53341 .35727 Mdot
.65952 .49604 Mdot
.47579 .60415 Mdot
.22438 .59333 Mdot
.62252 .27531 Mdot
.55833 .69485 Mdot
.71219 .67693 Mdot
.55534 .31151 Mdot
.38713 .46903 Mdot
.6446 .62969 Mdot
.64672 .45638 Mdot
.65434 .49296 Mdot
.71733 .67051 Mdot
.44474 .52008 Mdot
.55517 .72831 Mdot
.65659 .56446 Mdot
.45142 .52408 Mdot
.59236 .52478 Mdot
.59197 .53331 Mdot
.65265 .44915 Mdot
.66056 .54536 Mdot
.53697 .31103 Mdot
.58503 .38307 Mdot
.3521 .61495 Mdot
.69092 .29386 Mdot
.49128 .56648 Mdot
.62518 .53844 Mdot
.60492 .54111 Mdot
.57899 .25876 Mdot
.32383 .38828 Mdot
.52859 .31885 Mdot
.57164 .36521 Mdot
.40443 .45831 Mdot
.58877 .58637 Mdot
.33197 .65155 Mdot
.59958 .41194 Mdot
.36893 .63199 Mdot
.53108 .3126 Mdot
.37499 .59421 Mdot
.40581 .458 Mdot
.38625 .59326 Mdot
.33473 .6094 Mdot
.36222 .43111 Mdot
.52932 .35875 Mdot
.66994 .52038 Mdot
.40142 .46131 Mdot
.74277 .64715 Mdot
.5446 .70157 Mdot
.17893 .54 Mdot
.67938 .55681 Mdot
.73822 .49603 Mdot
.54784 .76696 Mdot
.37836 .61557 Mdot
.4194 .34362 Mdot
.55162 .32118 Mdot
.54529 .71673 Mdot
.541 .30976 Mdot
.79603 .42692 Mdot
.54934 .66699 Mdot
.17773 .54216 Mdot
.62023 .63113 Mdot
.44941 .64496 Mdot
.67762 .53273 Mdot
.53632 .38549 Mdot
.37476 .63195 Mdot
.35566 .48152 Mdot
.2787 .61602 Mdot
.64403 .55676 Mdot
.38873 .27045 Mdot
.56719 .29971 Mdot
.26839 .36319 Mdot
.38236 .47131 Mdot
.40876 .43247 Mdot
.62768 .5225 Mdot
.46124 .62758 Mdot
.58855 .49003 Mdot
.63029 .62179 Mdot
.69298 .69541 Mdot
.60341 .41109 Mdot
.59956 .50012 Mdot
.36121 .63991 Mdot
.59423 .50675 Mdot
.71713 .55781 Mdot
.79984 .53553 Mdot
.68215 .55354 Mdot
.40234 .23544 Mdot
.49288 .7219 Mdot
.54468 .34766 Mdot
.68476 .4678 Mdot
.27845 .37697 Mdot
.61695 .54438 Mdot
.58909 .85498 Mdot
.55205 .6811 Mdot
.31502 .65672 Mdot
.67084 .54646 Mdot
.63526 .5301 Mdot
.73779 .44011 Mdot
.53011 .39402 Mdot
.26062 .38544 Mdot
.64882 .48899 Mdot
.68973 .67488 Mdot
.37695 .4395 Mdot
.62887 .45945 Mdot
.6415 .50343 Mdot
.78638 .61957 Mdot
.36795 .43939 Mdot
.38188 .60536 Mdot
.26197 .36843 Mdot
.34284 .64228 Mdot
.56618 .64867 Mdot
.46445 .44967 Mdot
.77521 .60007 Mdot
.42238 .36244 Mdot
.52765 .67416 Mdot
.67507 .52654 Mdot
.74201 .54403 Mdot
.64183 .54183 Mdot
.55628 .65481 Mdot
.36988 .43586 Mdot
.53736 .31407 Mdot
.52444 .45278 Mdot
.27968 .36938 Mdot
.57912 .50954 Mdot
.57019 .66015 Mdot
.53962 .32427 Mdot
.19503 .52832 Mdot
.5468 .33395 Mdot
.38005 .45274 Mdot
.40034 .4366 Mdot
.54989 .67055 Mdot
.53899 .30939 Mdot
.33715 .61776 Mdot
.36168 .6968 Mdot
.60836 .47169 Mdot
.39698 .40547 Mdot
.4973 .30772 Mdot
.53273 .36857 Mdot
.52804 .28783 Mdot
.62462 .51113 Mdot
.45318 .5095 Mdot
.64172 .4533 Mdot
.39585 .44745 Mdot
.35788 .58991 Mdot
.77345 .58411 Mdot
.76508 .45721 Mdot
.41148 .39249 Mdot
.57613 .52357 Mdot
.65356 .5463 Mdot
.64574 .51016 Mdot
.61123 .49072 Mdot
.46186 .77141 Mdot
.62991 .50975 Mdot
.37433 .44998 Mdot
.35305 .62971 Mdot
.62587 .5272 Mdot
.27534 .37738 Mdot
.47301 .51685 Mdot
.52898 .70008 Mdot
.4964 .53303 Mdot
.18748 .63671 Mdot
.53881 .32333 Mdot
.39026 .60695 Mdot
.3475 .59964 Mdot
.54975 .70966 Mdot
.39139 .47985 Mdot
.54772 .32888 Mdot
.61876 .72548 Mdot
.56734 .69354 Mdot
.63781 .49586 Mdot
.45753 .58282 Mdot
.48781 .18136 Mdot
.67973 .5093 Mdot
.63297 .48092 Mdot
.26429 .36189 Mdot
.34875 .65472 Mdot
.47627 .85524 Mdot
.42393 .52448 Mdot
.54556 .67373 Mdot
.5422 .66269 Mdot
.53791 .28531 Mdot
.58622 .48403 Mdot
.3704 .46505 Mdot
.43703 .53583 Mdot
.61507 .78042 Mdot
.27021 .64124 Mdot
.29108 .45597 Mdot
.64382 .47018 Mdot
.69587 .41489 Mdot
.59641 .48647 Mdot
.56914 .32526 Mdot
.53967 .28916 Mdot
.52677 .32472 Mdot
.38419 .4462 Mdot
.71805 .2797 Mdot
.37173 .45193 Mdot
.18785 .64082 Mdot
.55692 .32906 Mdot
.4278 .68708 Mdot
.36912 .59597 Mdot
.56836 .51894 Mdot
.56274 .66705 Mdot
.32921 .40646 Mdot
.67133 .45334 Mdot
.41659 .27138 Mdot
.38127 .58652 Mdot
.51553 .35407 Mdot
.70827 .56082 Mdot
.33051 .77151 Mdot
.45349 .43811 Mdot
.50679 .66918 Mdot
.78948 .44007 Mdot
.55129 .66505 Mdot
.60411 .26332 Mdot
.56707 .70207 Mdot
.37224 .48329 Mdot
.64616 .55674 Mdot
.65469 .55386 Mdot
.5986 .49376 Mdot
.62805 .50695 Mdot
.38461 .44021 Mdot
.62488 .4703 Mdot
.82452 .52895 Mdot
.26618 .37806 Mdot
.39341 .72166 Mdot
.53058 .69352 Mdot
.37395 .42495 Mdot
.36046 .63373 Mdot
.29565 .37008 Mdot
.74977 .67406 Mdot
.63126 .47038 Mdot
.64144 .47543 Mdot
.28674 .39139 Mdot
.63592 .4478 Mdot
.70846 .5565 Mdot
.3537 .61801 Mdot
.46309 .41095 Mdot
.55031 .65176 Mdot
.5285 .68091 Mdot
.35672 .43773 Mdot
.54087 .30939 Mdot
.55857 .69761 Mdot
.37757 .64207 Mdot
.64981 .46433 Mdot
.60873 .56068 Mdot
.49658 .30914 Mdot
.80838 .45173 Mdot
.57624 .67946 Mdot
.71869 .5212 Mdot
.54908 .30753 Mdot
.56553 .29644 Mdot
.65066 .4883 Mdot
.61783 .57947 Mdot
.53645 .3658 Mdot
.53083 .6978 Mdot
.37082 .42557 Mdot
.44454 .66037 Mdot
.37969 .48293 Mdot
.54558 .32473 Mdot
.67383 .47533 Mdot
.53081 .35825 Mdot
.62147 .54424 Mdot
.44134 .12255 Mdot
.66425 .54002 Mdot
.52888 .22663 Mdot
.63249 .73727 Mdot
.3458 .60503 Mdot
.33715 .62367 Mdot
.2745 .38047 Mdot
.5523 .30976 Mdot
.6283 .5611 Mdot
.54946 .66006 Mdot
.17997 .5886 Mdot
.57505 .29801 Mdot
.37443 .57672 Mdot
.33687 .65333 Mdot
.37753 .43619 Mdot
.67388 .49313 Mdot
.66011 .50112 Mdot
.38591 .59519 Mdot
.53861 .76855 Mdot
.53567 .30005 Mdot
.65598 .51989 Mdot
.65065 .54803 Mdot
.34981 .61782 Mdot
.36594 .69873 Mdot
.50101 .37759 Mdot
.6592 .54592 Mdot
.615 .63573 Mdot
.38877 .43127 Mdot
.60862 .50004 Mdot
.6218 .47285 Mdot
.53673 .6843 Mdot
.38275 .73142 Mdot
.79199 .54982 Mdot
.38662 .42506 Mdot
.28007 .36192 Mdot
.65938 .55637 Mdot
.36755 .59811 Mdot
.62755 .56551 Mdot
.41997 .79961 Mdot
.26503 .37243 Mdot
.63662 .51777 Mdot
.6515 .45061 Mdot
.5046 .3141 Mdot
.63525 .52087 Mdot
.60343 .40405 Mdot
.34608 .63701 Mdot
.63518 .51738 Mdot
.75866 .42463 Mdot
.38324 .43762 Mdot
.67742 .45945 Mdot
.53903 .66139 Mdot
.61991 .74331 Mdot
.33556 .34968 Mdot
.33053 .61409 Mdot
.53695 .70238 Mdot
.67023 .52827 Mdot
.37846 .6387 Mdot
.34291 .46912 Mdot
.40188 .26522 Mdot
.67714 .48914 Mdot
.38565 .48086 Mdot
.38051 .47845 Mdot
.55021 .67419 Mdot
.6866 .21878 Mdot
.6398 .44579 Mdot
.66728 .51659 Mdot
.72454 .72764 Mdot
.55522 .29157 Mdot
.66872 .51659 Mdot
.67512 .50155 Mdot
.36545 .46759 Mdot
.57319 .59848 Mdot
.52027 .24816 Mdot
.50224 .7571 Mdot
.38382 .42822 Mdot
.36458 .56689 Mdot
.38013 .63629 Mdot
.53243 .69643 Mdot
.54169 .34838 Mdot
.52675 .67034 Mdot
.35632 .60336 Mdot
.61949 .48295 Mdot
.36025 .47086 Mdot
.65194 .31285 Mdot
.36867 .49086 Mdot
.39905 .61696 Mdot
.5515 .36091 Mdot
.30018 .35372 Mdot
.77453 .70872 Mdot
.35894 .34734 Mdot
.36927 .42305 Mdot
.54005 .67448 Mdot
.41705 .54226 Mdot
.653 .54599 Mdot
.60095 .24313 Mdot
.67095 .5034 Mdot
.7912 .44386 Mdot
.39013 .58302 Mdot
.29844 .38372 Mdot
.64529 .55721 Mdot
.70609 .67732 Mdot
.37339 .42317 Mdot
.38325 .43602 Mdot
.62538 .49216 Mdot
.37778 .45353 Mdot
.66012 .50943 Mdot
.34692 .62408 Mdot
.70151 .23369 Mdot
.65792 .53892 Mdot
.69593 .52571 Mdot
.3754 .41832 Mdot
.17841 .54005 Mdot
.37549 .56518 Mdot
.70529 .42056 Mdot
.35095 .78983 Mdot
.3765 .45694 Mdot
.69981 .50058 Mdot
.38277 .6155 Mdot
.26526 .36084 Mdot
.40454 .56998 Mdot
.66549 .49165 Mdot
.63449 .47312 Mdot
.58902 .51401 Mdot
.6469 .54645 Mdot
.592 .2437 Mdot
.6635 .58888 Mdot
.66813 .38476 Mdot
.63824 .4761 Mdot
.58309 .29022 Mdot
.37534 .44594 Mdot
.47467 .30955 Mdot
.53743 .72512 Mdot
.63091 .4731 Mdot
.54042 .39636 Mdot
.3789 .42482 Mdot
.19959 .65101 Mdot
.37248 .43739 Mdot
.37151 .62111 Mdot
.39246 .48977 Mdot
.6213 .54246 Mdot
.52764 .34339 Mdot
.34788 .6334 Mdot
.33601 .27389 Mdot
.35808 .58503 Mdot
.62932 .5316 Mdot
.39317 .70615 Mdot
.34753 .60223 Mdot
.48133 .52132 Mdot
.53166 .34592 Mdot
.69406 .66417 Mdot
.55882 .29679 Mdot
.63996 .52452 Mdot
.64401 .52903 Mdot
.29383 .3668 Mdot
.38485 .48745 Mdot
.56012 .31633 Mdot
.85053 .47348 Mdot
.55392 .64454 Mdot
.5207 .32755 Mdot
.60082 .56918 Mdot
.44473 .51335 Mdot
.50797 .31609 Mdot
.65881 .6951 Mdot
.38116 .48579 Mdot
.53335 .28344 Mdot
.58893 .56479 Mdot
.51613 .51547 Mdot
.56522 .7094 Mdot
.39977 .58368 Mdot
.493 .47614 Mdot
.36979 .63838 Mdot
.39635 .42683 Mdot
.36951 .65202 Mdot
.37514 .44073 Mdot
.53614 .22735 Mdot
.47878 .27273 Mdot
.33841 .43043 Mdot
.40196 .43686 Mdot
.36048 .60665 Mdot
.61344 .48949 Mdot
.50321 .58834 Mdot
.58881 .55624 Mdot
.68253 .5229 Mdot
.39829 .44207 Mdot
.55513 .30579 Mdot
.54683 .35568 Mdot
.53209 .38179 Mdot
.50542 .34299 Mdot
.35875 .63554 Mdot
.42708 .34537 Mdot
.79165 .40624 Mdot
.35144 .45051 Mdot
.3817 .506 Mdot
.59355 .52306 Mdot
.36463 .60096 Mdot
.39539 .61428 Mdot
.37017 .47239 Mdot
.64358 .27646 Mdot
.69086 .48754 Mdot
.56598 .31615 Mdot
.55664 .3305 Mdot
.50987 .31564 Mdot
.5082 .30028 Mdot
.67847 .25448 Mdot
.35586 .48175 Mdot
.55516 .31763 Mdot
.62884 .5003 Mdot
.6495 .47365 Mdot
.28062 .3647 Mdot
.53192 .67764 Mdot
.68307 .54536 Mdot
.69092 .53209 Mdot
.65266 .48893 Mdot
.34951 .60114 Mdot
.56286 .52921 Mdot
.26733 .37001 Mdot
.35681 .65532 Mdot
.32838 .63716 Mdot
.29637 .3818 Mdot
.54562 .26458 Mdot
.32404 .77619 Mdot
.59282 .49994 Mdot
.68217 .60329 Mdot
.36811 .60289 Mdot
.45797 .26968 Mdot
.55382 .42983 Mdot
.60093 .50238 Mdot
.53238 .57829 Mdot
.34571 .62759 Mdot
.57282 .30907 Mdot
.66869 .50661 Mdot
.28028 .3889 Mdot
.53319 .70544 Mdot
.5876 .56102 Mdot
.26276 .36293 Mdot
.53103 .31058 Mdot
.49494 .69582 Mdot
.54526 .28396 Mdot
.34201 .60904 Mdot
.67786 .45908 Mdot
.09864 .42679 Mdot
.37775 .63131 Mdot
.22504 .63657 Mdot
.46965 .29226 Mdot
.6583 .54117 Mdot
.37292 .63708 Mdot
.57294 .31655 Mdot
.39027 .43232 Mdot
.45697 .53024 Mdot
.55358 .33371 Mdot
.29773 .37381 Mdot
.28937 .36922 Mdot
.35141 .61654 Mdot
.52549 .35204 Mdot
.62112 .46681 Mdot
.51898 .29685 Mdot
.38864 .491 Mdot
.60865 .51936 Mdot
.30669 .74531 Mdot
.67119 .57761 Mdot
.54888 .3052 Mdot
.38987 .63573 Mdot
.57009 .67276 Mdot
.61407 .51091 Mdot
.25783 .67244 Mdot
.6753 .49854 Mdot
.36215 .4396 Mdot
.45952 .24783 Mdot
.64015 .31346 Mdot
.61696 .4866 Mdot
.59859 .53344 Mdot
.35554 .43787 Mdot
.61583 .48551 Mdot
.67871 .50542 Mdot
.41415 .42521 Mdot
.50415 .3228 Mdot
.64392 .51454 Mdot
.39875 .59102 Mdot
.78598 .48893 Mdot
.65639 .55931 Mdot
.38791 .23274 Mdot
.69969 .67045 Mdot
.46984 .24408 Mdot
.64735 .56246 Mdot
.74914 .6446 Mdot
.64904 .52963 Mdot
.6198 .50697 Mdot
.5958 .49917 Mdot
.6698 .40355 Mdot
.35966 .6032 Mdot
.37865 .57306 Mdot
.56063 .71507 Mdot
.69672 .67509 Mdot
.53632 .69437 Mdot
.37034 .42892 Mdot
.24107 .43623 Mdot
.26661 .37686 Mdot
.54256 .30915 Mdot
.6019 .54425 Mdot
.34603 .59551 Mdot
.66141 .4948 Mdot
.61383 .54111 Mdot
.34391 .61925 Mdot
.37801 .63473 Mdot
.34772 .66069 Mdot
.56882 .69511 Mdot
.53376 .31975 Mdot
.60909 .48334 Mdot
.56451 .69668 Mdot
.62731 .46271 Mdot
.43402 .52315 Mdot
.5313 .31979 Mdot
.51586 .29881 Mdot
.56099 .33778 Mdot
.6239 .47738 Mdot
.62107 .53968 Mdot
.37055 .45331 Mdot
.4967 .30728 Mdot
.34733 .45941 Mdot
.36919 .63746 Mdot
.33916 .61812 Mdot
.66503 .49066 Mdot
.71774 .54034 Mdot
.54152 .66498 Mdot
.37478 .61789 Mdot
.27951 .3925 Mdot
.55728 .71591 Mdot
.62433 .52155 Mdot
.36508 .63812 Mdot
.52944 .67644 Mdot
.68236 .30062 Mdot
.39696 .81627 Mdot
.57152 .67134 Mdot
.62661 .49289 Mdot
.74671 .44381 Mdot
.67441 .62462 Mdot
.54814 .64529 Mdot
.35168 .4552 Mdot
.67282 .49391 Mdot
.56325 .78516 Mdot
.53834 .65586 Mdot
.80893 .46081 Mdot
.34575 .61222 Mdot
.59103 .60739 Mdot
.59475 .56918 Mdot
.62763 .24598 Mdot
.5306 .66264 Mdot
.54455 .33074 Mdot
.50212 .29714 Mdot
.63254 .49246 Mdot
.5193 .67531 Mdot
.40304 .48894 Mdot
.34511 .60212 Mdot
.34054 .59844 Mdot
.52055 .34875 Mdot
.41826 .38114 Mdot
.39977 .60348 Mdot
.65251 .43992 Mdot
.38679 .55011 Mdot
.56537 .5634 Mdot
.62298 .21479 Mdot
.32108 .28587 Mdot
.6032 .55638 Mdot
.56799 .66321 Mdot
.34339 .45159 Mdot
.37307 .45325 Mdot
.38556 .45047 Mdot
.33809 .63259 Mdot
.4741 .48677 Mdot
.38561 .58677 Mdot
.38512 .28199 Mdot
.5585 .67494 Mdot
.68246 .65713 Mdot
.63723 .5612 Mdot
.6559 .5429 Mdot
.63915 .4602 Mdot
.58874 .51762 Mdot
.65009 .52855 Mdot
.39593 .46843 Mdot
.33531 .64106 Mdot
.48457 .73021 Mdot
.51464 .31504 Mdot
.20213 .48951 Mdot
.36945 .59562 Mdot
.26301 .36535 Mdot
.54716 .68888 Mdot
.76669 .60399 Mdot
.33742 .58977 Mdot
.37479 .59529 Mdot
.66918 .47581 Mdot
.54814 .29481 Mdot
.54297 .53524 Mdot
.64836 .53546 Mdot
.37618 .61686 Mdot
.39719 .63087 Mdot
.61139 .27842 Mdot
.59238 .44126 Mdot
.58131 .68215 Mdot
.44829 .50943 Mdot
.52397 .67183 Mdot
.63202 .58165 Mdot
.45533 .27218 Mdot
.3563 .6053 Mdot
.36579 .62367 Mdot
.56577 .65556 Mdot
.72962 .55077 Mdot
.53305 .3519 Mdot
.29783 .38527 Mdot
.35714 .44901 Mdot
.64394 .5386 Mdot
.34102 .63672 Mdot
.67819 .6019 Mdot
.45432 .58191 Mdot
.39242 .45767 Mdot
.35463 .65579 Mdot
.66437 .47968 Mdot
.62678 .48897 Mdot
.54805 .6657 Mdot
.49111 .63284 Mdot
.59337 .5641 Mdot
.18944 .60862 Mdot
.43987 .36655 Mdot
.47768 .38785 Mdot
.65458 .4934 Mdot
.51363 .34485 Mdot
.28379 .38877 Mdot
.56532 .67549 Mdot
.63861 .46292 Mdot
.368 .80568 Mdot
.48693 .33366 Mdot
.38928 .47215 Mdot
.28589 .38918 Mdot
.47521 .49004 Mdot
.67579 .50096 Mdot
.67088 .50375 Mdot
.62628 .50913 Mdot
.39264 .82281 Mdot
.38721 .57665 Mdot
.5196 .29137 Mdot
.55628 .69641 Mdot
.50051 .32147 Mdot
.37292 .57447 Mdot
.51394 .44131 Mdot
.62358 .52585 Mdot
.56668 .32421 Mdot
.54419 .33385 Mdot
.37782 .43596 Mdot
.39996 .43986 Mdot
.32219 .65543 Mdot
.6646 .53768 Mdot
.27444 .38646 Mdot
.55023 .29241 Mdot
.35413 .65161 Mdot
.55039 .66627 Mdot
.403 .45784 Mdot
.63544 .47638 Mdot
.35408 .61162 Mdot
.58176 .51042 Mdot
.51681 .3016 Mdot
.37389 .59569 Mdot
.25748 .37145 Mdot
.53902 .66551 Mdot
.63389 .47454 Mdot
.50677 .72555 Mdot
.2932 .38733 Mdot
.64503 .55156 Mdot
.74697 .4827 Mdot
.52474 .71828 Mdot
.33846 .26949 Mdot
.39201 .59677 Mdot
.27299 .37211 Mdot
.53496 .2885 Mdot
.52366 .51157 Mdot
.36349 .62709 Mdot
.69418 .43785 Mdot
.50154 .60797 Mdot
.60895 .48494 Mdot
.51787 .33558 Mdot
.58785 .68633 Mdot
.20181 .64203 Mdot
.64746 .63566 Mdot
.65275 .51836 Mdot
.37138 .63832 Mdot
.52761 .68473 Mdot
.35426 .44471 Mdot
.39005 .2325 Mdot
.62154 .21852 Mdot
.34627 .65777 Mdot
.59351 .49503 Mdot
.54971 .29249 Mdot
.37201 .4735 Mdot
.29478 .31577 Mdot
.38036 .64076 Mdot
.39456 .58999 Mdot
.61984 .51581 Mdot
.56258 .69153 Mdot
.52674 .77041 Mdot
.38377 .57274 Mdot
.3412 .64289 Mdot
.1962 .49454 Mdot
.57528 .678 Mdot
.63143 .49984 Mdot
.53231 .38189 Mdot
.65775 .46924 Mdot
.19833 .60894 Mdot
.26967 .37366 Mdot
.51635 .31199 Mdot
.66017 .48095 Mdot
.49093 .72241 Mdot
.36532 .63224 Mdot
.45401 .49922 Mdot
.37524 .65501 Mdot
.39477 .4744 Mdot
.34112 .63493 Mdot
.66618 .50355 Mdot
.38464 .42214 Mdot
.53988 .66677 Mdot
.65972 .54558 Mdot
.61883 .53896 Mdot
.57175 .32173 Mdot
.36778 .4829 Mdot
.77708 .52988 Mdot
.41522 .4684 Mdot
.34955 .44612 Mdot
.55754 .28367 Mdot
.63517 .49388 Mdot
.37465 .61214 Mdot
.40152 .58447 Mdot
.61993 .47089 Mdot
.45832 .27355 Mdot
.52733 .35012 Mdot
.31334 .64069 Mdot
.47531 .85272 Mdot
.60814 .44162 Mdot
.26778 .38496 Mdot
.74335 .57604 Mdot
.38685 .43457 Mdot
.62728 .48332 Mdot
.54351 .30388 Mdot
.34332 .64854 Mdot
.40035 .59982 Mdot
.65334 .46267 Mdot
.37435 .47836 Mdot
.52609 .69089 Mdot
.39638 .6034 Mdot
.4513 .57901 Mdot
.63181 .51881 Mdot
.38804 .26845 Mdot
.39352 .60664 Mdot
.1511 .52149 Mdot
.48763 .72472 Mdot
.51168 .32897 Mdot
.60796 .53765 Mdot
.50044 .34434 Mdot
.55112 .6983 Mdot
.40002 .55729 Mdot
.37543 .48013 Mdot
.66922 .43658 Mdot
.81248 .58629 Mdot
.36196 .59907 Mdot
.53541 .31169 Mdot
.62085 .47975 Mdot
.67022 .4395 Mdot
.66836 .52743 Mdot
.56422 .59222 Mdot
.51689 .72366 Mdot
.40475 .44763 Mdot
.364 .43593 Mdot
.60983 .54637 Mdot
.56371 .70415 Mdot
.39036 .56883 Mdot
.34556 .6149 Mdot
.59789 .15258 Mdot
.25753 .3693 Mdot
.66787 .72903 Mdot
.62822 .4768 Mdot
.34436 .65256 Mdot
.76667 .46091 Mdot
.35676 .47964 Mdot
.59549 .47761 Mdot
.33109 .63084 Mdot
.21938 .57586 Mdot
.43801 .5227 Mdot
.64141 .51871 Mdot
.61337 .44526 Mdot
.35831 .44465 Mdot
.41813 .53723 Mdot
.38529 .5882 Mdot
.61502 .46455 Mdot
.41429 .45295 Mdot
.18419 .51366 Mdot
.82594 .55523 Mdot
.5333 .32017 Mdot
.39204 .63459 Mdot
.39491 .47306 Mdot
.56454 .49396 Mdot
.53011 .6928 Mdot
.35001 .64395 Mdot
.3534 .59184 Mdot
.60567 .52274 Mdot
.67914 .55097 Mdot
.6122 .43985 Mdot
.52188 .31757 Mdot
.36552 .45454 Mdot
.63145 .55763 Mdot
.42894 .3812 Mdot
.58805 .50889 Mdot
.36562 .45879 Mdot
.21885 .2588 Mdot
.67913 .49126 Mdot
.66748 .52169 Mdot
.58549 .72593 Mdot
.54533 .35312 Mdot
.50165 .33144 Mdot
.43151 .35601 Mdot
.62872 .47651 Mdot
.45728 .64162 Mdot
.53681 .31879 Mdot
.5256 .34802 Mdot
.41977 .69355 Mdot
.60643 .51407 Mdot
.39343 .53938 Mdot
.36941 .46611 Mdot
.39808 .46878 Mdot
.50736 .3092 Mdot
.56837 .52148 Mdot
.34268 .46241 Mdot
.575 .23221 Mdot
.36998 .59221 Mdot
.45511 .27184 Mdot
.53205 .29459 Mdot
.48434 .61747 Mdot
.37645 .48495 Mdot
.16431 .61789 Mdot
.51272 .52897 Mdot
.59396 .48551 Mdot
.62182 .48819 Mdot
.53587 .68132 Mdot
.71005 .51303 Mdot
.27762 .36146 Mdot
.37899 .45183 Mdot
.40305 .76636 Mdot
.52606 .32553 Mdot
.66583 .52625 Mdot
.7662 .58908 Mdot
.31808 .31697 Mdot
.41316 .23168 Mdot
.54582 .34543 Mdot
.52257 .33504 Mdot
.37779 .58314 Mdot
.36049 .59149 Mdot
.63673 .50697 Mdot
.38133 .44601 Mdot
.51636 .28744 Mdot
.35988 .45565 Mdot
.35565 .60443 Mdot
.37442 .60012 Mdot
.26478 .3704 Mdot
.58971 .46853 Mdot
.34305 .61269 Mdot
.18759 .53349 Mdot
.43121 .38454 Mdot
.57321 .33244 Mdot
.76937 .70959 Mdot
.28889 .31606 Mdot
.5892 .73818 Mdot
.53856 .71055 Mdot
.2528 .3615 Mdot
.40367 .48223 Mdot
.605 .54207 Mdot
.65313 .48138 Mdot
.28794 .37316 Mdot
.3935 .48328 Mdot
.54226 .68749 Mdot
.38479 .48771 Mdot
.56332 .67949 Mdot
.36535 .57248 Mdot
.65694 .5588 Mdot
.67602 .5128 Mdot
.39613 .46065 Mdot
.38296 .60078 Mdot
.34359 .60704 Mdot
.55347 .71508 Mdot
.75798 .61127 Mdot
.35132 .61482 Mdot
.53008 .29447 Mdot
.76499 .36726 Mdot
.28934 .36996 Mdot
.66823 .50873 Mdot
.77085 .59446 Mdot
.61375 .2649 Mdot
.60329 .48762 Mdot
.28753 .38911 Mdot
.61902 .16461 Mdot
.65099 .55758 Mdot
.60765 .17716 Mdot
.27211 .36858 Mdot
.53724 .3594 Mdot
.38474 .61656 Mdot
.28148 .3615 Mdot
.56369 .50954 Mdot
.56796 .64075 Mdot
.6797 .55512 Mdot
.55216 .33892 Mdot
.55845 .34873 Mdot
.45711 .31998 Mdot
.20131 .61189 Mdot
.56794 .67322 Mdot
.54506 .68044 Mdot
.36041 .62697 Mdot
.25146 .39927 Mdot
.61484 .57414 Mdot
.54345 .67845 Mdot
.45279 .78498 Mdot
.59294 .51955 Mdot
.70258 .70087 Mdot
.52984 .57583 Mdot
.51534 .34583 Mdot
.51354 .26115 Mdot
.36335 .63003 Mdot
.53518 .31231 Mdot
.49493 .41041 Mdot
.63955 .46048 Mdot
.52904 .32152 Mdot
.36439 .46264 Mdot
.28017 .57091 Mdot
.5077 .34994 Mdot
.45144 .54009 Mdot
.37113 .46547 Mdot
.5233 .71492 Mdot
.62409 .67542 Mdot
.57554 .86983 Mdot
.37965 .45007 Mdot
.38029 .61712 Mdot
.34217 .61226 Mdot
.34845 .62058 Mdot
.55384 .33403 Mdot
.38833 .62837 Mdot
.52167 .31085 Mdot
.3404 .68903 Mdot
.76056 .62934 Mdot
.55223 .66997 Mdot
.41897 .42115 Mdot
.53548 .33694 Mdot
.40018 .31224 Mdot
.7868 .68053 Mdot
.62514 .49448 Mdot
.41517 .46143 Mdot
.56309 .6541 Mdot
.2157 .38663 Mdot
.53655 .68592 Mdot
.38345 .61435 Mdot
.45434 .27126 Mdot
.65922 .51021 Mdot
.61951 .40747 Mdot
.54601 .65935 Mdot
.54939 .34104 Mdot
.64858 .5502 Mdot
.32791 .66667 Mdot
.53733 .70104 Mdot
.53274 .7043 Mdot
.65313 .52807 Mdot
.51619 .35258 Mdot
.37612 .60427 Mdot
.40651 .47423 Mdot
.5562 .72553 Mdot
.57106 .49819 Mdot
.61134 .48875 Mdot
.61223 .46133 Mdot
.46047 .47048 Mdot
.54005 .77851 Mdot
.37588 .4589 Mdot
.70895 .61276 Mdot
.35384 .599 Mdot
.62952 .63617 Mdot
.38939 .34334 Mdot
.41735 .42176 Mdot
.26962 .37265 Mdot
.26875 .37521 Mdot
.64511 .5221 Mdot
.52386 .7862 Mdot
.47023 .21125 Mdot
.42356 .46035 Mdot
.29343 .37716 Mdot
.34418 .60606 Mdot
.48988 .31625 Mdot
.46555 .34982 Mdot
.67935 .54492 Mdot
.40096 .44251 Mdot
.35069 .61012 Mdot
.42413 .80162 Mdot
.55738 .67733 Mdot
.42795 .32333 Mdot
.6263 .52993 Mdot
.65849 .51954 Mdot
.37977 .46844 Mdot
.37085 .45378 Mdot
.38245 .25073 Mdot
.44786 .35443 Mdot
.27765 .65166 Mdot
.38267 .53015 Mdot
.45565 .81187 Mdot
.47718 .33724 Mdot
.54599 .30311 Mdot
.26137 .37096 Mdot
.34912 .44316 Mdot
.67142 .50928 Mdot
.54123 .35904 Mdot
.41855 .22926 Mdot
.54968 .27512 Mdot
.70149 .69485 Mdot
.46252 .64044 Mdot
.63306 .54099 Mdot
.54527 .29299 Mdot
.5336 .31442 Mdot
.49958 .31585 Mdot
.29539 .38287 Mdot
.65062 .49101 Mdot
.61347 .4901 Mdot
.64385 .55615 Mdot
.70536 .48246 Mdot
.63409 .52079 Mdot
.39022 .35502 Mdot
.3948 .39085 Mdot
.38942 .74789 Mdot
.60125 .48667 Mdot
.38869 .48358 Mdot
.59937 .54239 Mdot
.55987 .70774 Mdot
.59388 .49328 Mdot
.68594 .71738 Mdot
.38649 .4575 Mdot
.73185 .54156 Mdot
.37015 .53499 Mdot
.62567 .53081 Mdot
.52839 .67317 Mdot
.53552 .77736 Mdot
.79251 .56976 Mdot
.1946 .50268 Mdot
.52838 .29452 Mdot
.32248 .63081 Mdot
.38245 .49257 Mdot
.37316 .6134 Mdot
.60231 .47543 Mdot
.26388 .38044 Mdot
.24622 .32392 Mdot
.48255 .60026 Mdot
.67172 .49976 Mdot
.62003 .59028 Mdot
.50832 .33255 Mdot
.37064 .63321 Mdot
.47979 .31123 Mdot
.62214 .50792 Mdot
.55298 .7 Mdot
.55741 .70102 Mdot
.46127 .37768 Mdot
.3555 .75569 Mdot
.53144 .52379 Mdot
.37832 .46666 Mdot
.40029 .6059 Mdot
.53173 .66153 Mdot
.5382 .22988 Mdot
.40311 .48976 Mdot
.38714 .4347 Mdot
.36479 .47943 Mdot
.63856 .54209 Mdot
.26876 .36553 Mdot
.41158 .78135 Mdot
.29459 .36929 Mdot
.62479 .53406 Mdot
.36137 .58589 Mdot
.27996 .36067 Mdot
.53474 .68872 Mdot
.35836 .43681 Mdot
.35921 .59513 Mdot
.64083 .52736 Mdot
.53632 .32406 Mdot
.75355 .58794 Mdot
.61737 .76705 Mdot
.3464 .70388 Mdot
.35231 .70701 Mdot
.55995 .33273 Mdot
.25338 .69928 Mdot
.39651 .40532 Mdot
.63953 .27404 Mdot
.58349 .65753 Mdot
.61785 .47149 Mdot
.75705 .29409 Mdot
.38721 .59113 Mdot
.35248 .63465 Mdot
.63811 .51565 Mdot
.36706 .64576 Mdot
.66676 .52667 Mdot
.37985 .58008 Mdot
.23981 .6304 Mdot
.67671 .54228 Mdot
.35447 .63461 Mdot
.61642 .57619 Mdot
.61576 .5179 Mdot
.50907 .33807 Mdot
.34866 .64618 Mdot
.58997 .49064 Mdot
.22628 .32997 Mdot
.39153 .44327 Mdot
.29614 .37976 Mdot
.39171 .39736 Mdot
.37507 .48688 Mdot
.5167 .32643 Mdot
.66661 .55602 Mdot
.54556 .66459 Mdot
.54231 .32897 Mdot
.32635 .65731 Mdot
.55111 .65689 Mdot
.42605 .34899 Mdot
.52306 .29636 Mdot
.28447 .36778 Mdot
.54324 .6629 Mdot
.69623 .53562 Mdot
.34296 .62951 Mdot
.62922 .77367 Mdot
.29481 .37041 Mdot
.661 .50197 Mdot
.39451 .56237 Mdot
.38194 .48711 Mdot
.64324 .50604 Mdot
.37193 .63898 Mdot
.29364 .3858 Mdot
.63136 .5467 Mdot
.64115 .55045 Mdot
.47621 .37335 Mdot
.44122 .24176 Mdot
.54626 .66752 Mdot
.56783 .30297 Mdot
.62951 .50208 Mdot
.56548 .70321 Mdot
.27501 .47094 Mdot
.59954 .54826 Mdot
.50515 .35131 Mdot
.59045 .41496 Mdot
.36027 .59056 Mdot
.34792 .456 Mdot
.40074 .61156 Mdot
.53229 .7052 Mdot
.86273 .46499 Mdot
.26659 .36413 Mdot
.5725 .54571 Mdot
.63188 .459 Mdot
.41012 .60085 Mdot
.5294 .31636 Mdot
.27406 .61044 Mdot
.63204 .47537 Mdot
.64261 .59155 Mdot
.66218 .52162 Mdot
.48378 .72115 Mdot
.53024 .35059 Mdot
.66658 .51481 Mdot
.69436 .57586 Mdot
.6512 .56334 Mdot
.52635 .6807 Mdot
.66127 .66143 Mdot
.59527 .53813 Mdot
.08902 .48493 Mdot
.2842 .3917 Mdot
.34453 .62017 Mdot
.43312 .58031 Mdot
.32326 .49667 Mdot
.62688 .21454 Mdot
.52174 .31384 Mdot
.54891 .48981 Mdot
.37507 .60841 Mdot
.81463 .52855 Mdot
.23325 .67625 Mdot
.61743 .5222 Mdot
.66232 .47853 Mdot
.38342 .61443 Mdot
.34666 .6522 Mdot
.26536 .37971 Mdot
.6 .48427 Mdot
.60431 .58096 Mdot
.37664 .64608 Mdot
.6358 .53042 Mdot
.59931 .34696 Mdot
.40786 .45689 Mdot
.50263 .32087 Mdot
.35393 .44519 Mdot
.39189 .43744 Mdot
.71942 .30606 Mdot
.44 .36592 Mdot
.36689 .45648 Mdot
.41298 .48641 Mdot
.68989 .71808 Mdot
.60899 .41666 Mdot
.52541 .67485 Mdot
.31599 .72064 Mdot
.35365 .62413 Mdot
.6485 .48964 Mdot
.55807 .317 Mdot
.6493 .25549 Mdot
.25115 .54467 Mdot
.44334 .27738 Mdot
.61791 .49246 Mdot
.35889 .63089 Mdot
.29753 .38123 Mdot
.67639 .54504 Mdot
.63395 .63349 Mdot
.6559 .51835 Mdot
.34166 .6068 Mdot
.74947 .32573 Mdot
.60884 .40946 Mdot
.39614 .54377 Mdot
.57776 .33895 Mdot
.63143 .55945 Mdot
.52501 .29961 Mdot
.38748 .48065 Mdot
.56758 .69763 Mdot
.54193 .67327 Mdot
.65101 .54716 Mdot
.47919 .27182 Mdot
.5439 .59589 Mdot
.61591 .51554 Mdot
.606 .51985 Mdot
.27211 .37067 Mdot
.60666 .51966 Mdot
.62904 .4603 Mdot
.61302 .55084 Mdot
.58577 .53606 Mdot
.34948 .44568 Mdot
.73684 .46701 Mdot
.58532 .52595 Mdot
.58448 .44972 Mdot
.40385 .45129 Mdot
.55663 .52887 Mdot
.37373 .43785 Mdot
.31593 .74715 Mdot
.36468 .44314 Mdot
.54441 .67178 Mdot
.38643 .56206 Mdot
.56342 .56694 Mdot
.52165 .28546 Mdot
.39631 .43404 Mdot
.55597 .68712 Mdot
.38243 .45033 Mdot
.39421 .5806 Mdot
.73323 .73063 Mdot
.54526 .27484 Mdot
.42693 .53098 Mdot
.52936 .55647 Mdot
.38746 .26658 Mdot
.37004 .58879 Mdot
.51872 .34633 Mdot
.59958 .4047 Mdot
.61662 .55145 Mdot
.53785 .66952 Mdot
.64696 .52243 Mdot
.35197 .4433 Mdot
.35456 .62794 Mdot
.38504 .70823 Mdot
.54355 .66859 Mdot
.83051 .58468 Mdot
.35296 .58869 Mdot
.68459 .50468 Mdot
.40305 .44379 Mdot
.77381 .70235 Mdot
.36412 .44191 Mdot
.7659 .6221 Mdot
.5211 .37108 Mdot
.7709 .34597 Mdot
.52627 .33879 Mdot
.42096 .21856 Mdot
.3115 .79035 Mdot
.23711 .66675 Mdot
.5452 .32108 Mdot
.32109 .6094 Mdot
.62944 .52883 Mdot
.58881 .52249 Mdot
.63491 .43701 Mdot
.57488 .31894 Mdot
.62966 .50676 Mdot
.28034 .36294 Mdot
.44188 .39173 Mdot
.49218 .76738 Mdot
.32442 .61911 Mdot
.66914 .52374 Mdot
.39931 .44534 Mdot
.35203 .48051 Mdot
.28592 .36259 Mdot
.40294 .48713 Mdot
.61221 .51217 Mdot
.53292 .33829 Mdot
.49494 .59506 Mdot
.54336 .69846 Mdot
.17091 .44052 Mdot
.55625 .72311 Mdot
.32037 .62981 Mdot
.65829 .4515 Mdot
.37449 .59912 Mdot
.81683 .33723 Mdot
.59724 .53371 Mdot
.53848 .31626 Mdot
.64156 .54815 Mdot
.61986 .55521 Mdot
.58576 .51167 Mdot
.38643 .63432 Mdot
.43043 .5938 Mdot
.6382 .5317 Mdot
.37441 .48074 Mdot
.38344 .72119 Mdot
.68769 .5376 Mdot
.30511 .6448 Mdot
.68902 .6914 Mdot
.38994 .2806 Mdot
.57409 .33822 Mdot
.37621 .62457 Mdot
.52457 .32935 Mdot
.57375 .30252 Mdot
.51665 .32623 Mdot
.38438 .76179 Mdot
.57422 .59134 Mdot
.57821 .16451 Mdot
.76949 .40754 Mdot
.6548 .26858 Mdot
.56528 .3217 Mdot
.28691 .50891 Mdot
.54624 .30632 Mdot
.51868 .31841 Mdot
.38844 .14012 Mdot
.55215 .3124 Mdot
.66354 .4893 Mdot
.68 .49029 Mdot
.34681 .34416 Mdot
.70964 .7058 Mdot
.59618 .49118 Mdot
.63251 .50629 Mdot
.56892 .68157 Mdot
.72232 .53569 Mdot
.28529 .35825 Mdot
.44022 .31239 Mdot
.25235 .35109 Mdot
.65219 .52792 Mdot
.634 .51235 Mdot
.57126 .51827 Mdot
.31855 .80075 Mdot
.64036 .2427 Mdot
.55618 .34949 Mdot
.59385 .58527 Mdot
.17324 .55098 Mdot
.67692 .49084 Mdot
.67597 .52091 Mdot
.62213 .5443 Mdot
.37496 .61071 Mdot
.4874 .3204 Mdot
.64197 .58955 Mdot
.36747 .29961 Mdot
.62496 .52416 Mdot
.38965 .40601 Mdot
.53909 .73169 Mdot
.6663 .50145 Mdot
.49941 .32335 Mdot
.59263 .50623 Mdot
.53925 .29369 Mdot
.50505 .31402 Mdot
.57605 .49029 Mdot
.39583 .77569 Mdot
.49359 .3289 Mdot
.62422 .53841 Mdot
.38123 .60706 Mdot
.20432 .6415 Mdot
.66184 .50045 Mdot
.56673 .6822 Mdot
.62368 .48309 Mdot
.52693 .68189 Mdot
.6138 .52943 Mdot
.29711 .37302 Mdot
.63148 .31789 Mdot
.36412 .62399 Mdot
.57055 .72042 Mdot
.36292 .64991 Mdot
.51382 .39913 Mdot
.5245 .36068 Mdot
.28584 .35742 Mdot
.59315 .19896 Mdot
.2732 .37001 Mdot
.75301 .58338 Mdot
.24029 .50432 Mdot
.39645 .44842 Mdot
.51201 .29748 Mdot
.71655 .59864 Mdot
.30494 .63357 Mdot
.33891 .6591 Mdot
.32894 .64321 Mdot
.84435 .41054 Mdot
.69384 .22685 Mdot
.6429 .5352 Mdot
.62364 .78817 Mdot
.66593 .37359 Mdot
.61188 .5635 Mdot
.63669 .57016 Mdot
.34196 .60377 Mdot
.64024 .56065 Mdot
.47675 .50466 Mdot
.36071 .60568 Mdot
.55113 .68512 Mdot
.51796 .3097 Mdot
.52887 .69345 Mdot
.28538 .64726 Mdot
.42811 .39378 Mdot
.35509 .6003 Mdot
.59289 .54449 Mdot
.64868 .54124 Mdot
.5313 .29067 Mdot
.56285 .39031 Mdot
.50337 .32503 Mdot
.55873 .6546 Mdot
.3608 .61473 Mdot
.6257 .24015 Mdot
.63105 .48161 Mdot
.54377 .33636 Mdot
.32782 .46992 Mdot
.62649 .48846 Mdot
.39531 .46564 Mdot
.61587 .49221 Mdot
.54968 .32336 Mdot
.60724 .52039 Mdot
.53066 .33764 Mdot
.38479 .59264 Mdot
.669 .48191 Mdot
.63645 .51144 Mdot
.79361 .5475 Mdot
.5423 .68885 Mdot
.52825 .36073 Mdot
.48601 .48991 Mdot
.66506 .4751 Mdot
.62381 .63327 Mdot
.65565 .5584 Mdot
.56014 .45079 Mdot
.61161 .57625 Mdot
.27962 .36364 Mdot
.58665 .48647 Mdot
.66226 .50239 Mdot
.71233 .4439 Mdot
.76008 .43871 Mdot
.49429 .28242 Mdot
.38448 .42534 Mdot
.49971 .32362 Mdot
.33894 .62094 Mdot
.33732 .64274 Mdot
.39307 .61607 Mdot
.73441 .68244 Mdot
.56693 .51259 Mdot
.65851 .50841 Mdot
.40368 .44144 Mdot
.54673 .67819 Mdot
.54793 .33975 Mdot
.55052 .67393 Mdot
.44266 .30818 Mdot
.5529 .65428 Mdot
.27439 .36146 Mdot
.48845 .72536 Mdot
.58471 .25261 Mdot
.56583 .67134 Mdot
.50305 .32463 Mdot
.4666 .63315 Mdot
.61248 .47381 Mdot
.20436 .56181 Mdot
.55433 .69955 Mdot
.85202 .46402 Mdot
.66292 .55128 Mdot
.46279 .51978 Mdot
.38322 .43966 Mdot
.52945 .68349 Mdot
.3681 .48384 Mdot
.59021 .51493 Mdot
.34179 .2654 Mdot
.53903 .31031 Mdot
.39121 .42283 Mdot
.58496 .49437 Mdot
.52876 .69103 Mdot
.34837 .60605 Mdot
.51119 .48564 Mdot
.39512 .47676 Mdot
.78325 .57263 Mdot
.64716 .63561 Mdot
.36127 .61252 Mdot
.49235 .18408 Mdot
.35414 .4683 Mdot
.60089 .556 Mdot
.54087 .5018 Mdot
.59962 .49921 Mdot
.3363 .62483 Mdot
.36651 .63679 Mdot
.359 .3738 Mdot
.64368 .54618 Mdot
.6613 .55323 Mdot
.48389 .31885 Mdot
.36422 .59882 Mdot
.51671 .33887 Mdot
.51584 .29221 Mdot
.38282 .61175 Mdot
.51206 .331 Mdot
.54375 .66001 Mdot
.44444 .3943 Mdot
.35329 .46511 Mdot
.38312 .4779 Mdot
.34425 .61022 Mdot
.38997 .57354 Mdot
.37327 .59759 Mdot
.61554 .49424 Mdot
.53757 .35399 Mdot
.60258 .5298 Mdot
.5945 .53828 Mdot
.52444 .37377 Mdot
.55548 .33856 Mdot
.59758 .52582 Mdot
.47272 .63841 Mdot
.5756 .70136 Mdot
.35637 .63481 Mdot
.36129 .45523 Mdot
.80892 .5147 Mdot
.40636 .4458 Mdot
.66844 .53607 Mdot
.21734 .57665 Mdot
.55098 .33931 Mdot
.53599 .68504 Mdot
.52141 .66424 Mdot
.53797 .67334 Mdot
.38878 .42119 Mdot
.50511 .30003 Mdot
.42599 .35245 Mdot
.66756 .53417 Mdot
.46066 .4679 Mdot
.71551 .60537 Mdot
.38563 .33091 Mdot
.36485 .45863 Mdot
.62796 .49639 Mdot
.27458 .3688 Mdot
.60752 .2746 Mdot
.65372 .51447 Mdot
.59574 .47836 Mdot
.45637 .68807 Mdot
.58903 .44701 Mdot
.57188 .32968 Mdot
.45711 .32918 Mdot
.64322 .46433 Mdot
.47138 .31363 Mdot
.51559 .12111 Mdot
.66017 .55178 Mdot
.6273 .51423 Mdot
.65193 .48499 Mdot
.60418 .54015 Mdot
.54129 .37125 Mdot
.48225 .64754 Mdot
.39829 .43929 Mdot
.45108 .41943 Mdot
.35826 .47009 Mdot
.34676 .63473 Mdot
.46784 .52101 Mdot
.50714 .30355 Mdot
.53675 .67562 Mdot
.70441 .75457 Mdot
.45238 .2992 Mdot
.37732 .58364 Mdot
.66662 .25086 Mdot
.54598 .70047 Mdot
.61737 .47235 Mdot
.56446 .71286 Mdot
.34026 .65165 Mdot
.37106 .47463 Mdot
.67476 .4829 Mdot
.5595 .31265 Mdot
.5063 .34901 Mdot
.62593 .4976 Mdot
.18212 .59096 Mdot
.37478 .48613 Mdot
.33069 .41062 Mdot
.63657 .54192 Mdot
.59713 .47715 Mdot
.50812 .31709 Mdot
.36675 .63336 Mdot
.23801 .46803 Mdot
.54903 .69088 Mdot
.57929 .52927 Mdot
.59053 .50993 Mdot
.44356 .3234 Mdot
.36319 .43231 Mdot
.28218 .38565 Mdot
.63882 .54388 Mdot
.43917 .36201 Mdot
.63727 .54517 Mdot
.7106 .53809 Mdot
.37897 .59944 Mdot
.67187 .47224 Mdot
.64718 .47004 Mdot
.72666 .57707 Mdot
.35429 .47196 Mdot
.5329 .31768 Mdot
.49407 .35034 Mdot
.28012 .38898 Mdot
.39474 .45937 Mdot
.59432 .51815 Mdot
.34859 .4511 Mdot
.58623 .51525 Mdot
.63785 .52819 Mdot
.36473 .45969 Mdot
.51595 .33824 Mdot
.27636 .60036 Mdot
.72596 .46195 Mdot
.62007 .54805 Mdot
.61315 .48466 Mdot
.72052 .69335 Mdot
.54867 .19733 Mdot
.6406 .47108 Mdot
.5473 .34915 Mdot
.62899 .48985 Mdot
.39039 .47517 Mdot
.55556 .65287 Mdot
.54021 .32037 Mdot
.38093 .56959 Mdot
.38683 .59513 Mdot
.36951 .53327 Mdot
.2699 .36251 Mdot
.62259 .47432 Mdot
.53827 .27077 Mdot
.55808 .33106 Mdot
.23362 .35572 Mdot
.34391 .62226 Mdot
.53309 .66208 Mdot
.63473 .5516 Mdot
.50986 .4943 Mdot
.39017 .433 Mdot
.08945 .48771 Mdot
.42277 .36142 Mdot
.53652 .71556 Mdot
.4734 .24368 Mdot
.28023 .36921 Mdot
.67222 .49699 Mdot
.55988 .70912 Mdot
.39323 .59645 Mdot
.58956 .52224 Mdot
.58084 .46518 Mdot
.32807 .57544 Mdot
.33359 .60071 Mdot
.34735 .45583 Mdot
.39037 .58133 Mdot
.53599 .71214 Mdot
.27582 .3614 Mdot
.51061 .34655 Mdot
.66336 .50864 Mdot
.59548 .59084 Mdot
.34726 .62426 Mdot
.29963 .37823 Mdot
.6323 .54126 Mdot
.5017 .34315 Mdot
.37843 .6345 Mdot
.65529 .52976 Mdot
.62879 .26493 Mdot
.56288 .37391 Mdot
.35516 .61967 Mdot
.62913 .45807 Mdot
.57266 .41152 Mdot
.36873 .57384 Mdot
.34538 .59871 Mdot
.63003 .50716 Mdot
.54239 .66233 Mdot
.67415 .49359 Mdot
.375 .44005 Mdot
.43047 .59414 Mdot
.39138 .46875 Mdot
.68987 .61942 Mdot
.62981 .4517 Mdot
.40299 .24782 Mdot
.54553 .29081 Mdot
.54851 .64064 Mdot
.7196 .43857 Mdot
.60944 .4695 Mdot
.29464 .72772 Mdot
.48301 .61527 Mdot
.19702 .41165 Mdot
.44022 .83122 Mdot
.56121 .68761 Mdot
.38574 .45011 Mdot
.6271 .51312 Mdot
.37181 .50528 Mdot
.56305 .66952 Mdot
.70312 .61423 Mdot
.62839 .45874 Mdot
.52817 .34907 Mdot
.62775 .52931 Mdot
.52991 .29425 Mdot
.62628 .48616 Mdot
.5638 .52442 Mdot
.58222 .68133 Mdot
.76789 .61801 Mdot
.61259 .47507 Mdot
.72263 .74561 Mdot
.50047 .48793 Mdot
.55474 .69692 Mdot
.61344 .53817 Mdot
.28643 .37998 Mdot
.38735 .48778 Mdot
.56254 .7772 Mdot
.37511 .60424 Mdot
.37023 .44978 Mdot
.51176 .3149 Mdot
.40282 .58382 Mdot
.28611 .39049 Mdot
.56452 .57372 Mdot
.53179 .70087 Mdot
.39352 .44701 Mdot
.66388 .50212 Mdot
.66936 .53591 Mdot
.48993 .71951 Mdot
.38416 .19138 Mdot
.49606 .30173 Mdot
.82012 .58193 Mdot
.56906 .33054 Mdot
.54263 .68292 Mdot
.37765 .59785 Mdot
.66066 .48196 Mdot
.64752 .51351 Mdot
.33909 .63747 Mdot
.54464 .35453 Mdot
.39024 .55368 Mdot
.70367 .28587 Mdot
.37299 .65473 Mdot
.72099 .64694 Mdot
.54382 .31678 Mdot
.72773 .64191 Mdot
.531 .70824 Mdot
.39489 .78466 Mdot
.62331 .72516 Mdot
.39039 .4391 Mdot
.71378 .65159 Mdot
.55056 .33468 Mdot
.64677 .53641 Mdot
.28641 .36953 Mdot
.26568 .37177 Mdot
.51835 .30466 Mdot
.38171 .6191 Mdot
.52996 .69155 Mdot
.62947 .51841 Mdot
.40965 .3089 Mdot
.30413 .32661 Mdot
.39967 .6091 Mdot
.69092 .57552 Mdot
.36978 .48287 Mdot
.61839 .48672 Mdot
.5662 .69135 Mdot
.37439 .45499 Mdot
.25594 .37468 Mdot
.44569 .39378 Mdot
.63673 .55251 Mdot
.46471 .37839 Mdot
.39327 .45273 Mdot
.5061 .17854 Mdot
.63952 .51133 Mdot
.3542 .46868 Mdot
.57605 .44544 Mdot
.339 .27821 Mdot
.51588 .57786 Mdot
.2478 .68227 Mdot
.32806 .61957 Mdot
.38811 .59969 Mdot
.29284 .26684 Mdot
.58289 .6565 Mdot
.40151 .44993 Mdot
.2791 .3614 Mdot
.64151 .68282 Mdot
.36374 .48198 Mdot
.67669 .52295 Mdot
.65618 .55776 Mdot
.70663 .29568 Mdot
.48568 .50686 Mdot
.30071 .3842 Mdot
.54708 .44913 Mdot
.6054 .50815 Mdot
.69554 .50646 Mdot
.64033 .50145 Mdot
.55815 .34885 Mdot
.36803 .48723 Mdot
.72289 .76295 Mdot
.35812 .48207 Mdot
.41557 .3107 Mdot
.35374 .62452 Mdot
.39659 .62127 Mdot
.66681 .50411 Mdot
.44276 .21914 Mdot
.54341 .78543 Mdot
.61786 .48105 Mdot
.51828 .70375 Mdot
.65895 .63354 Mdot
.6901 .53394 Mdot
.48566 .34034 Mdot
.65757 .58847 Mdot
.55388 .36349 Mdot
.37119 .45803 Mdot
.5626 .68506 Mdot
.57811 .67926 Mdot
.38617 .44497 Mdot
.65659 .50611 Mdot
.51244 .69009 Mdot
.66025 .51972 Mdot
.64317 .53962 Mdot
.43554 .31021 Mdot
.54442 .64996 Mdot
.37215 .59522 Mdot
.54215 .67187 Mdot
.51987 .31903 Mdot
.30519 .17752 Mdot
.55676 .67224 Mdot
.55633 .41266 Mdot
.45389 .56356 Mdot
.71778 .6475 Mdot
.5054 .34646 Mdot
.5662 .66461 Mdot
.34819 .46789 Mdot
.19303 .41184 Mdot
.52338 .19199 Mdot
.41236 .46411 Mdot
.64388 .51518 Mdot
.51325 .29787 Mdot
.56096 .33386 Mdot
.41548 .47668 Mdot
.51623 .34765 Mdot
.67769 .4662 Mdot
.63702 .54789 Mdot
.40139 .44987 Mdot
.33607 .34705 Mdot
.36831 .48791 Mdot
.52218 .45849 Mdot
.62173 .54132 Mdot
.53919 .31844 Mdot
.69348 .48046 Mdot
.48943 .30274 Mdot
.26296 .37303 Mdot
.58598 .50731 Mdot
.53352 .68078 Mdot
.47354 .48813 Mdot
.35601 .6212 Mdot
.22106 .58062 Mdot
.51983 .29647 Mdot
.33104 .464 Mdot
.5083 .33724 Mdot
.54874 .28816 Mdot
.40411 .48736 Mdot
.52819 .31243 Mdot
.62773 .51573 Mdot
.415 .5423 Mdot
.54067 .2971 Mdot
.38293 .46591 Mdot
.53173 .69166 Mdot
.51339 .33407 Mdot
.40572 .58644 Mdot
.65218 .53822 Mdot
.36437 .58824 Mdot
.5211 .67366 Mdot
.50724 .30251 Mdot
.56441 .66176 Mdot
.34557 .62419 Mdot
.53812 .70676 Mdot
.36161 .7004 Mdot
.34378 .44702 Mdot
.43715 .2815 Mdot
.66228 .42425 Mdot
.55815 .31062 Mdot
.3369 .65905 Mdot
.65217 .4743 Mdot
.64959 .54464 Mdot
.54623 .7153 Mdot
.56092 .33112 Mdot
.20296 .63472 Mdot
.55573 .4515 Mdot
.35496 .38327 Mdot
.35491 .43655 Mdot
.82408 .54241 Mdot
.41815 .38044 Mdot
.18805 .44281 Mdot
.64186 .5766 Mdot
.28108 .36915 Mdot
.66337 .52053 Mdot
.79365 .56899 Mdot
.55258 .65214 Mdot
.27516 .53864 Mdot
.61588 .57418 Mdot
.36856 .60489 Mdot
.63462 .48478 Mdot
.61881 .78733 Mdot
.6761 .57561 Mdot
.5688 .67782 Mdot
.37257 .41979 Mdot
.52057 .28583 Mdot
.54462 .69901 Mdot
.38453 .58847 Mdot
.6692 .67769 Mdot
.63691 .45783 Mdot
.60981 .50758 Mdot
.3372 .65714 Mdot
.52405 .34903 Mdot
.3448 .6329 Mdot
.35364 .4658 Mdot
.5547 .67464 Mdot
.61084 .54573 Mdot
.68943 .48871 Mdot
.39167 .64171 Mdot
.3517 .47865 Mdot
.39815 .58016 Mdot
.35882 .43773 Mdot
.28167 .36855 Mdot
.6177 .4751 Mdot
.3457 .65704 Mdot
.63548 .56531 Mdot
.76435 .47664 Mdot
.44219 .29444 Mdot
.7308 .42074 Mdot
.37099 .59387 Mdot
.70466 .67908 Mdot
.38907 .45682 Mdot
.36385 .43728 Mdot
.78958 .39643 Mdot
.52962 .78163 Mdot
.4584 .64074 Mdot
.72425 .73318 Mdot
.35349 .46461 Mdot
.38998 .46591 Mdot
.39333 .60171 Mdot
.525 .30926 Mdot
.55297 .37371 Mdot
.38951 .63887 Mdot
.76978 .59477 Mdot
.54793 .33944 Mdot
.28066 .71616 Mdot
.35335 .58456 Mdot
.60824 .57348 Mdot
.30389 .37908 Mdot
.56247 .69358 Mdot
.76777 .58678 Mdot
.68969 .75385 Mdot
.66892 .49426 Mdot
.65612 .21814 Mdot
.37326 .62381 Mdot
.40488 .52905 Mdot
.33979 .75567 Mdot
.60576 .46779 Mdot
.64222 .48608 Mdot
.65124 .50167 Mdot
.55687 .64639 Mdot
.73538 .45127 Mdot
.6705 .49722 Mdot
.75415 .63467 Mdot
.67967 .52243 Mdot
.60103 .77649 Mdot
.54288 .67156 Mdot
.5683 .59199 Mdot
.32481 .6344 Mdot
.37821 .30554 Mdot
.63566 .43624 Mdot
.35038 .45785 Mdot
.30008 .62257 Mdot
.36737 .47237 Mdot
.47356 .80175 Mdot
.62507 .72164 Mdot
.56178 .3432 Mdot
.61767 .49285 Mdot
.32891 .63689 Mdot
.52198 .294 Mdot
.23943 .49313 Mdot
.38029 .13967 Mdot
.34371 .46425 Mdot
.71269 .22201 Mdot
.365 .43616 Mdot
.26479 .375 Mdot
.51117 .3111 Mdot
.52915 .24482 Mdot
.46181 .47129 Mdot
.51601 .33569 Mdot
.35018 .5384 Mdot
.48974 .34768 Mdot
.70785 .6664 Mdot
.54626 .28311 Mdot
.38319 .46121 Mdot
.34996 .42715 Mdot
.56721 .47232 Mdot
.6432 .47212 Mdot
.44531 .4083 Mdot
.59295 .43106 Mdot
.62766 .4766 Mdot
.36085 .60567 Mdot
.48976 .20867 Mdot
.41375 .57698 Mdot
.54132 .30203 Mdot
.38012 .42731 Mdot
.6404 .48522 Mdot
.61896 .54677 Mdot
.61131 .55997 Mdot
.79789 .55633 Mdot
.28144 .71399 Mdot
.63972 .53128 Mdot
.57729 .49079 Mdot
.38165 .58894 Mdot
.50123 .71994 Mdot
.77576 .6659 Mdot
.64066 .69379 Mdot
.65562 .54671 Mdot
.53972 .68525 Mdot
.55494 .6493 Mdot
.68571 .49072 Mdot
.40347 .27549 Mdot
.34414 .57617 Mdot
.66372 .50166 Mdot
.6119 .74398 Mdot
.40742 .57592 Mdot
.29651 .37065 Mdot
.34703 .62337 Mdot
.50108 .31285 Mdot
.26924 .37115 Mdot
.37932 .63712 Mdot
.54716 .24138 Mdot
.27819 .38763 Mdot
.34206 .28767 Mdot
.55891 .65463 Mdot
.64361 .50589 Mdot
.48203 .30999 Mdot
.33779 .6336 Mdot
.39199 .44554 Mdot
.53368 .33196 Mdot
.34153 .46921 Mdot
.50354 .72515 Mdot
.73676 .60554 Mdot
.26731 .36401 Mdot
.35391 .45117 Mdot
.45324 .39657 Mdot
.53937 .68118 Mdot
.40888 .48149 Mdot
.43068 .22167 Mdot
.68328 .54605 Mdot
.51548 .80905 Mdot
.61382 .50358 Mdot
.16457 .53636 Mdot
.36642 .43679 Mdot
.25936 .3757 Mdot
.66199 .51159 Mdot
.35485 .58634 Mdot
.55758 .49588 Mdot
.6579 .52182 Mdot
.38673 .57535 Mdot
.64376 .53499 Mdot
.56579 .69491 Mdot
.56139 .36236 Mdot
.48658 .61116 Mdot
.83229 .48114 Mdot
.54233 .708 Mdot
.27662 .39951 Mdot
.63096 .47389 Mdot
.40884 .72615 Mdot
.51886 .3382 Mdot
.59795 .47507 Mdot
.74994 .31153 Mdot
.52708 .30271 Mdot
.52374 .33163 Mdot
.60428 .52233 Mdot
.4098 .46052 Mdot
.34597 .60434 Mdot
.53889 .679 Mdot
.23652 .41234 Mdot
.65764 .52933 Mdot
.63124 .49899 Mdot
.54497 .70029 Mdot
.39092 .46701 Mdot
.60882 .54272 Mdot
.2284 .52202 Mdot
.22815 .37766 Mdot
.39226 .43736 Mdot
.686 .54266 Mdot
.54509 .82945 Mdot
.58127 .33462 Mdot
.6255 .18998 Mdot
.58645 .67105 Mdot
.37993 .61563 Mdot
.58868 .56926 Mdot
.09573 .45528 Mdot
.56198 .69257 Mdot
.38891 .32412 Mdot
.63609 .53381 Mdot
.64097 .47781 Mdot
.5194 .35644 Mdot
.59734 .52103 Mdot
.55155 .31924 Mdot
.83564 .47308 Mdot
.81939 .66514 Mdot
.50906 .33561 Mdot
.54983 .30554 Mdot
.53378 .25613 Mdot
.78502 .56546 Mdot
.51533 .31213 Mdot
.62721 .45706 Mdot
.33917 .71511 Mdot
.59269 .46017 Mdot
.52579 .70145 Mdot
.54369 .6397 Mdot
.48313 .35169 Mdot
.44567 .18853 Mdot
.55729 .54374 Mdot
.7234 .48513 Mdot
.5492 .59758 Mdot
.3646 .44537 Mdot
.63863 .55639 Mdot
.27095 .36166 Mdot
.39433 .61713 Mdot
.68937 .5719 Mdot
.64732 .50781 Mdot
.53783 .29423 Mdot
.55612 .64524 Mdot
.38656 .49079 Mdot
.63314 .50745 Mdot
.36782 .56397 Mdot
.55035 .68778 Mdot
.54336 .29909 Mdot
.54136 .41315 Mdot
.52417 .68004 Mdot
.68882 .48131 Mdot
.63045 .47693 Mdot
.63254 .54192 Mdot
.62731 .43496 Mdot
.38587 .44324 Mdot
.39762 .62576 Mdot
.64993 .45376 Mdot
.43836 .3256 Mdot
.44622 .52213 Mdot
.66864 .46737 Mdot
.54065 .35403 Mdot
.39983 .43968 Mdot
.27634 .38494 Mdot
.68162 .65725 Mdot
.64463 .55213 Mdot
.28719 .71743 Mdot
.66419 .25613 Mdot
.27315 .37592 Mdot
.56738 .30548 Mdot
.5365 .6794 Mdot
.60881 .51438 Mdot
.37275 .73065 Mdot
.66491 .54687 Mdot
.59609 .41756 Mdot
.37683 .61967 Mdot
.36045 .45084 Mdot
.22099 .37999 Mdot
.39485 .61609 Mdot
.52425 .33005 Mdot
.18608 .63592 Mdot
.49669 .34711 Mdot
.50411 .29709 Mdot
.41491 .78573 Mdot
.36875 .45877 Mdot
.09285 .47216 Mdot
.54201 .19298 Mdot
.66831 .54606 Mdot
.3846 .48155 Mdot
.51095 .30863 Mdot
.61641 .49679 Mdot
.55744 .32056 Mdot
.49164 .31699 Mdot
.60137 .54438 Mdot
.63958 .47518 Mdot
.76569 .61148 Mdot
.28316 .73477 Mdot
.54084 .66739 Mdot
.53762 .35924 Mdot
.68043 .28644 Mdot
.67032 .49475 Mdot
.66776 .53334 Mdot
.31561 .59381 Mdot
.56835 .67628 Mdot
.60399 .35502 Mdot
.64067 .54285 Mdot
.76301 .32497 Mdot
.61825 .47778 Mdot
.48993 .2923 Mdot
.40934 .45366 Mdot
.4014 .28417 Mdot
.33699 .6207 Mdot
.50002 .34538 Mdot
.52752 .68206 Mdot
.51743 .36523 Mdot
.77298 .35579 Mdot
.36853 .46386 Mdot
.54972 .32342 Mdot
.39312 .56692 Mdot
.37518 .47194 Mdot
.38827 .43721 Mdot
.38132 .72041 Mdot
.4028 .59081 Mdot
.57074 .66404 Mdot
.36757 .47639 Mdot
.64345 .27585 Mdot
.38015 .45994 Mdot
.69547 .29395 Mdot
.65457 .47017 Mdot
.75275 .62925 Mdot
.40889 .37435 Mdot
.62574 .43925 Mdot
.37156 .4885 Mdot
.55636 .66425 Mdot
.59606 .50572 Mdot
.5188 .34994 Mdot
.55913 .67401 Mdot
.42531 .46556 Mdot
.3888 .5694 Mdot
.55653 .29583 Mdot
.40374 .44496 Mdot
.55224 .32453 Mdot
.72523 .60865 Mdot
.32758 .67476 Mdot
.55813 .60115 Mdot
.4602 .48735 Mdot
.60407 .55938 Mdot
.46985 .3189 Mdot
.6609 .47092 Mdot
.65112 .5113 Mdot
.35455 .62004 Mdot
.73513 .68083 Mdot
.51399 .33693 Mdot
.21961 .35862 Mdot
.35722 .4455 Mdot
.45965 .319 Mdot
.56525 .42347 Mdot
.58747 .50946 Mdot
.53733 .29748 Mdot
.49125 .31399 Mdot
.7598 .43786 Mdot
.34055 .63919 Mdot
.61531 .4444 Mdot
.65314 .45001 Mdot
.56568 .52485 Mdot
.36851 .43497 Mdot
.23996 .54297 Mdot
.36642 .64078 Mdot
.62829 .16475 Mdot
.35812 .63542 Mdot
.43663 .69702 Mdot
.52891 .31149 Mdot
.54273 .65736 Mdot
.66859 .53033 Mdot
.73907 .4817 Mdot
.54121 .36995 Mdot
.35732 .56109 Mdot
.53461 .68596 Mdot
.26212 .57484 Mdot
.36897 .45401 Mdot
.63946 .46199 Mdot
.61496 .55407 Mdot
.60662 .53322 Mdot
.61883 .51664 Mdot
.38015 .42551 Mdot
.67641 .52317 Mdot
.36344 .42731 Mdot
.61544 .2608 Mdot
.77372 .34106 Mdot
.33319 .61826 Mdot
.56037 .77014 Mdot
.56012 .31014 Mdot
.67525 .29901 Mdot
.60055 .33488 Mdot
.44032 .29468 Mdot
.37563 .70732 Mdot
.64157 .46626 Mdot
.383 .61943 Mdot
.61975 .78923 Mdot
.32966 .63815 Mdot
.85661 .63335 Mdot
.62736 .62151 Mdot
.23914 .68138 Mdot
.61707 .50008 Mdot
.39548 .63341 Mdot
.58835 .37523 Mdot
.68954 .50314 Mdot
.52116 .65703 Mdot
.54195 .4326 Mdot
.35328 .33773 Mdot
.53071 .66484 Mdot
.65368 .53641 Mdot
.52315 .28399 Mdot
.62738 .51701 Mdot
.66671 .5298 Mdot
.62075 .48126 Mdot
.38196 .49602 Mdot
.67067 .55708 Mdot
.67484 .49672 Mdot
.39805 .18282 Mdot
.70223 .69812 Mdot
.37202 .5815 Mdot
.74845 .41628 Mdot
.54706 .67842 Mdot
.53156 .29244 Mdot
.47573 .60414 Mdot
.37491 .44252 Mdot
.76319 .44531 Mdot
.61552 .50125 Mdot
.38687 .37183 Mdot
.40595 .44729 Mdot
.56203 .6785 Mdot
.28454 .38919 Mdot
.2863 .69211 Mdot
.33338 .62648 Mdot
.27088 .3853 Mdot
.35711 .62202 Mdot
.65176 .40415 Mdot
.53675 .29478 Mdot
.6068 .55688 Mdot
.3664 .48035 Mdot
.34929 .59562 Mdot
.71305 .70816 Mdot
.64116 .49656 Mdot
.36902 .59324 Mdot
.60288 .55748 Mdot
.43401 .5335 Mdot
.45301 .5737 Mdot
.35167 .6536 Mdot
.35367 .42408 Mdot
.37933 .47479 Mdot
.54488 .65886 Mdot
.53488 .2917 Mdot
.54815 .34616 Mdot
.37359 .45903 Mdot
.65894 .20186 Mdot
.66035 .52676 Mdot
.62399 .47819 Mdot
.43427 .33574 Mdot
.62201 .5033 Mdot
.68244 .68455 Mdot
.2792 .35787 Mdot
.55233 .29629 Mdot
.62045 .51184 Mdot
.61054 .54416 Mdot
.6344 .5521 Mdot
.72682 .61195 Mdot
.34928 .62773 Mdot
.60566 .50912 Mdot
.55285 .71396 Mdot
.38473 .24645 Mdot
.65852 .47712 Mdot
.69223 .50103 Mdot
.55019 .32709 Mdot
.8302 .54619 Mdot
.38416 .43886 Mdot
.36181 .59688 Mdot
.35849 .58074 Mdot
.60367 .6443 Mdot
.5739 .34514 Mdot
.29081 .36096 Mdot
.30809 .47608 Mdot
.29278 .37042 Mdot
.55073 .69713 Mdot
.44404 .66584 Mdot
.36189 .56715 Mdot
.38168 .58168 Mdot
.34693 .44212 Mdot
.6207 .51699 Mdot
.62022 .47765 Mdot
.39133 .32251 Mdot
.5989 .48959 Mdot
.53294 .68901 Mdot
.40476 .45901 Mdot
.54858 .32866 Mdot
.56031 .69875 Mdot
.35237 .4486 Mdot
.52535 .35031 Mdot
.6881 .53054 Mdot
.67709 .55722 Mdot
.52943 .33377 Mdot
.50606 .30941 Mdot
.66179 .48999 Mdot
.35327 .21489 Mdot
.53915 .28431 Mdot
.54714 .31969 Mdot
.2871 .39466 Mdot
.33288 .62771 Mdot
.70672 .51573 Mdot
.38251 .48285 Mdot
.63408 .54173 Mdot
.33106 .62588 Mdot
.5658 .66875 Mdot
.53047 .34322 Mdot
.62529 .54873 Mdot
.64622 .52992 Mdot
.53899 .68551 Mdot
.53401 .65638 Mdot
.5382 .70253 Mdot
.35004 .4859 Mdot
.62059 .53107 Mdot
.5134 .31646 Mdot
.36692 .45913 Mdot
.55451 .64936 Mdot
.57153 .70049 Mdot
.42951 .17654 Mdot
.66968 .49835 Mdot
.52283 .58433 Mdot
.24542 .23316 Mdot
.66162 .68319 Mdot
.26803 .381 Mdot
.37237 .64985 Mdot
.74029 .64239 Mdot
.58438 .70535 Mdot
.38833 .48177 Mdot
.5832 .73455 Mdot
.54553 .64203 Mdot
.59535 .53836 Mdot
.61089 .48797 Mdot
.58303 .54191 Mdot
.55254 .68284 Mdot
.71704 .61473 Mdot
.55868 .33927 Mdot
.65721 .34796 Mdot
.54723 .67843 Mdot
.35305 .65327 Mdot
.34935 .6562 Mdot
.35863 .63602 Mdot
.63666 .46466 Mdot
.74779 .43484 Mdot
.65685 .27609 Mdot
.61655 .36992 Mdot
.37082 .44994 Mdot
.48885 .31651 Mdot
.38683 .70793 Mdot
.52334 .33306 Mdot
.39011 .62336 Mdot
.55481 .68609 Mdot
.52762 .35916 Mdot
.39738 .45922 Mdot
.3894 .47132 Mdot
.38306 .56874 Mdot
.3463 .61778 Mdot
.35222 .60229 Mdot
.49796 .31942 Mdot
.52816 .3122 Mdot
.61895 .55045 Mdot
.53699 .33936 Mdot
.61368 .20976 Mdot
.53454 .71619 Mdot
.33395 .65489 Mdot
.39231 .45567 Mdot
.52394 .29618 Mdot
.64279 .5081 Mdot
.46843 .68996 Mdot
.37352 .53735 Mdot
.55004 .70945 Mdot
.4176 .62412 Mdot
.87626 .56047 Mdot
.62341 .5587 Mdot
.35465 .44042 Mdot
.40285 .26293 Mdot
.64771 .49627 Mdot
.37641 .60947 Mdot
.78566 .54316 Mdot
.29775 .37634 Mdot
.67307 .49363 Mdot
.59637 .48071 Mdot
.40173 .48847 Mdot
.46492 .59299 Mdot
.58881 .50263 Mdot
.48973 .40567 Mdot
.3522 .48169 Mdot
.37006 .64036 Mdot
.22507 .3294 Mdot
.36117 .65989 Mdot
.77427 .61671 Mdot
.2689 .37938 Mdot
.6134 .5525 Mdot
.35922 .60891 Mdot
.55766 .70851 Mdot
.35362 .61099 Mdot
.56439 .30963 Mdot
.3605 .59052 Mdot
.63011 .49341 Mdot
.51491 .31649 Mdot
.39486 .45668 Mdot
.45745 .3368 Mdot
.40378 .18875 Mdot
.35666 .58439 Mdot
.25595 .38282 Mdot
.67186 .49434 Mdot
.61103 .28851 Mdot
.55831 .50466 Mdot
.64533 .47049 Mdot
.36638 .47106 Mdot
.53786 .29849 Mdot
.35681 .43489 Mdot
.69355 .53477 Mdot
.78933 .41717 Mdot
.36316 .44102 Mdot
.34009 .31186 Mdot
.54782 .69992 Mdot
.76813 .59451 Mdot
.65206 .51772 Mdot
.36368 .47694 Mdot
.62094 .53241 Mdot
.54256 .35897 Mdot
.4813 .46033 Mdot
.40062 .23656 Mdot
.36853 .48126 Mdot
.17355 .58774 Mdot
.4882 .48596 Mdot
.68901 .55953 Mdot
.35713 .4707 Mdot
.72679 .435 Mdot
.28424 .3831 Mdot
.54935 .69205 Mdot
.5464 .65052 Mdot
.53108 .7013 Mdot
.60038 .48805 Mdot
.65193 .59495 Mdot
.57484 .68302 Mdot
.34391 .47435 Mdot
.56831 .69799 Mdot
.762 .58331 Mdot
.19254 .61234 Mdot
.54389 .70603 Mdot
.64668 .51989 Mdot
.69229 .50922 Mdot
.70298 .69968 Mdot
.37367 .64103 Mdot
.29846 .73032 Mdot
.57425 .21942 Mdot
.65774 .48024 Mdot
.55482 .55621 Mdot
.5618 .30942 Mdot
.43756 .23924 Mdot
.54734 .46359 Mdot
.47058 .62992 Mdot
.54853 .30869 Mdot
.42561 .55458 Mdot
.54996 .29438 Mdot
.62739 .56164 Mdot
.63677 .52762 Mdot
.55113 .36785 Mdot
.21402 .56062 Mdot
.3165 .28066 Mdot
.16227 .4684 Mdot
.5489 .34675 Mdot
.35471 .47246 Mdot
.3448 .46024 Mdot
.36509 .45587 Mdot
.33836 .6212 Mdot
.50054 .32124 Mdot
.61577 .52566 Mdot
.38579 .59864 Mdot
.65939 .54171 Mdot
.37292 .47447 Mdot
.21994 .38302 Mdot
.54945 .32682 Mdot
.66278 .50305 Mdot
.52144 .193 Mdot
.36221 .62926 Mdot
.54042 .68193 Mdot
.42077 .52994 Mdot
.38923 .64268 Mdot
.36506 .48737 Mdot
.57854 .33634 Mdot
.34654 .41529 Mdot
.48702 .64498 Mdot
.5717 .5156 Mdot
.64553 .45995 Mdot
.25234 .40304 Mdot
.46844 .18673 Mdot
.60763 .48527 Mdot
.38466 .588 Mdot
.33947 .65006 Mdot
.63919 .54906 Mdot
.50778 .34379 Mdot
.56633 .65244 Mdot
.53473 .70805 Mdot
.58369 .5035 Mdot
.45957 .4663 Mdot
.75984 .62257 Mdot
.59909 .52972 Mdot
.68589 .4559 Mdot
.39745 .57322 Mdot
.28287 .39045 Mdot
.44026 .36849 Mdot
.53202 .67099 Mdot
.63701 .53617 Mdot
.30215 .30088 Mdot
.55065 .31569 Mdot
.35635 .59534 Mdot
.40008 .45174 Mdot
.51766 .66181 Mdot
.36257 .57602 Mdot
.63853 .54884 Mdot
.6094 .54314 Mdot
.40525 .48533 Mdot
.48899 .29396 Mdot
.55522 .68387 Mdot
.38483 .59774 Mdot
.54146 .65776 Mdot
.52267 .31796 Mdot
.54572 .32584 Mdot
.64146 .44554 Mdot
.60662 .43951 Mdot
.35929 .58076 Mdot
.57907 .50774 Mdot
.38307 .63412 Mdot
.49248 .71932 Mdot
.38876 .4317 Mdot
.59579 .47596 Mdot
.55811 .28182 Mdot
.37118 .47114 Mdot
.65024 .48054 Mdot
.29102 .40574 Mdot
.59373 .52927 Mdot
.39311 .63578 Mdot
.79421 .41315 Mdot
.56236 .666 Mdot
.51971 .39756 Mdot
.71671 .57478 Mdot
.62272 .50242 Mdot
.37957 .64116 Mdot
.58438 .56918 Mdot
.37298 .43852 Mdot
.53698 .30523 Mdot
.81708 .3393 Mdot
.38054 .46458 Mdot
.62952 .52118 Mdot
.55664 .67451 Mdot
.50641 .29291 Mdot
.27256 .36464 Mdot
.42976 .36328 Mdot
.68551 .57278 Mdot
.65274 .57408 Mdot
.62265 .51835 Mdot
.73014 .73022 Mdot
.35878 .60195 Mdot
.51648 .30173 Mdot
.37458 .43181 Mdot
.37788 .45111 Mdot
.36749 .6333 Mdot
.36245 .35763 Mdot
.22984 .60736 Mdot
.18197 .29926 Mdot
.37533 .57582 Mdot
.56519 .7064 Mdot
.46346 .50666 Mdot
.39638 .61247 Mdot
.36457 .60434 Mdot
.37748 .56768 Mdot
.39743 .36123 Mdot
.53196 .35421 Mdot
.64632 .53128 Mdot
.57426 .33788 Mdot
.60309 .54511 Mdot
.76058 .66478 Mdot
.37253 .45785 Mdot
.53565 .30637 Mdot
.27963 .40767 Mdot
.57893 .43834 Mdot
.64239 .48972 Mdot
.32254 .689 Mdot
.64783 .58772 Mdot
.70073 .65567 Mdot
.6926 .48495 Mdot
.34978 .62078 Mdot
.57054 .58228 Mdot
.58796 .56746 Mdot
.56089 .2152 Mdot
.39443 .4646 Mdot
.26324 .36807 Mdot
.68445 .53598 Mdot
.71139 .53224 Mdot
.50594 .29397 Mdot
.52742 .35927 Mdot
.57473 .67855 Mdot
.43925 .50049 Mdot
.39544 .4602 Mdot
.25805 .6267 Mdot
.63883 .4726 Mdot
.39999 .51122 Mdot
.78929 .38706 Mdot
.65274 .48312 Mdot
.36338 .72058 Mdot
.76253 .44313 Mdot
.58847 .50726 Mdot
.64118 .37708 Mdot
.38909 .46091 Mdot
.75929 .32097 Mdot
.58793 .54564 Mdot
.37545 .61034 Mdot
.52758 .30799 Mdot
.55945 .30222 Mdot
.55237 .70676 Mdot
.58558 .20373 Mdot
.33956 .44355 Mdot
.53056 .30943 Mdot
.64774 .50063 Mdot
.3902 .44375 Mdot
.26671 .36737 Mdot
.65964 .57818 Mdot
.48385 .78654 Mdot
.54124 .33699 Mdot
.59012 .46597 Mdot
.31783 .36905 Mdot
.4488 .53457 Mdot
.29 .7462 Mdot
.36268 .45651 Mdot
.52862 .68015 Mdot
.69217 .48229 Mdot
.30468 .47025 Mdot
.60618 .56791 Mdot
.75211 .65123 Mdot
.50372 .38004 Mdot
.55491 .65279 Mdot
.65366 .49854 Mdot
.58967 .50121 Mdot
.4681 .48899 Mdot
.53427 .65759 Mdot
.58666 .50849 Mdot
.62769 .44397 Mdot
.52646 .34964 Mdot
.27278 .35771 Mdot
.54613 .3343 Mdot
.64306 .51439 Mdot
.55981 .57214 Mdot
.51739 .35284 Mdot
.27852 .66696 Mdot
.56406 .63832 Mdot
.37369 .44195 Mdot
.71649 .52525 Mdot
.65145 .46936 Mdot
.51295 .85456 Mdot
.2631 .37339 Mdot
.79734 .61604 Mdot
.38793 .6422 Mdot
.24406 .34271 Mdot
.40446 .6239 Mdot
.22377 .66645 Mdot
.45171 .35903 Mdot
.57468 .51185 Mdot
.59947 .7397 Mdot
.62879 .37063 Mdot
.34196 .45276 Mdot
.63049 .28186 Mdot
.64364 .47211 Mdot
.66535 .52494 Mdot
.39021 .60706 Mdot
.36428 .36935 Mdot
.39924 .27057 Mdot
.45235 .42721 Mdot
.55905 .68585 Mdot
.52943 .31691 Mdot
.62581 .49033 Mdot
.20278 .49317 Mdot
.36773 .58282 Mdot
.50728 .48346 Mdot
.66238 .50762 Mdot
.41502 .29928 Mdot
.365 .32479 Mdot
.39165 .44362 Mdot
.37732 .64605 Mdot
.39735 .62561 Mdot
.65167 .55844 Mdot
.39802 .46712 Mdot
.60881 .5463 Mdot
.49566 .47129 Mdot
.58004 .48579 Mdot
.56556 .68478 Mdot
.67282 .52284 Mdot
.49562 .54289 Mdot
.22079 .68551 Mdot
.63248 .59197 Mdot
.53162 .28777 Mdot
.33936 .6228 Mdot
.35646 .63302 Mdot
.54918 .34519 Mdot
.36001 .63409 Mdot
.66262 .35628 Mdot
.74945 .3308 Mdot
.55841 .6946 Mdot
.59618 .29221 Mdot
.56397 .67734 Mdot
.2629 .3679 Mdot
.66655 .49221 Mdot
.32225 .5033 Mdot
.37271 .57543 Mdot
.80133 .53621 Mdot
.37917 .45729 Mdot
.26368 .37345 Mdot
.67372 .54242 Mdot
.4436 .66952 Mdot
.38792 .62158 Mdot
.29019 .64469 Mdot
.63368 .55236 Mdot
.53538 .35738 Mdot
.58977 .50279 Mdot
.59536 .47016 Mdot
.27219 .38563 Mdot
.62211 .51931 Mdot
.35201 .44922 Mdot
.49975 .32483 Mdot
.22674 .66215 Mdot
.33724 .63008 Mdot
.67039 .51937 Mdot
.64826 .50004 Mdot
.53782 .36206 Mdot
.6787 .52388 Mdot
.3875 .48342 Mdot
.08358 .52919 Mdot
.54837 .69902 Mdot
.28918 .38981 Mdot
.28541 .64684 Mdot
.61215 .49063 Mdot
.59313 .51678 Mdot
.24661 .40233 Mdot
.36527 .23356 Mdot
.35167 .45229 Mdot
.64111 .45254 Mdot
.3802 .58895 Mdot
.5601 .67669 Mdot
.3905 .48799 Mdot
.6296 .54361 Mdot
.66681 .52223 Mdot
.5653 .68753 Mdot
.34232 .71236 Mdot
.38598 .54881 Mdot
.36826 .45212 Mdot
.54024 .5099 Mdot
.47281 .69249 Mdot
.65941 .5244 Mdot
.17378 .51668 Mdot
.54534 .31948 Mdot
.35561 .46486 Mdot
.73014 .45245 Mdot
.60412 .55503 Mdot
.36483 .48669 Mdot
.39478 .45932 Mdot
.66383 .55224 Mdot
.57494 .34152 Mdot
.49567 .31767 Mdot
.54701 .31651 Mdot
.80006 .42155 Mdot
.66051 .75112 Mdot
.35162 .60206 Mdot
.39023 .46316 Mdot
.33342 .64962 Mdot
.56918 .65342 Mdot
.44743 .52025 Mdot
.34242 .65234 Mdot
.55944 .30441 Mdot
.33813 .65652 Mdot
.60306 .54038 Mdot
.39607 .46517 Mdot
.38312 .58154 Mdot
.60891 .49657 Mdot
.68122 .44922 Mdot
.51106 .54779 Mdot
.56568 .6531 Mdot
.42721 .54319 Mdot
.6341 .5172 Mdot
.27657 .38578 Mdot
.66452 .49536 Mdot
.4014 .44946 Mdot
.4883 .54808 Mdot
.60792 .50321 Mdot
.36343 .57773 Mdot
.49697 .6426 Mdot
.36622 .64443 Mdot
.6181 .45455 Mdot
.64243 .51518 Mdot
.66119 .52428 Mdot
.58898 .50041 Mdot
.34667 .32407 Mdot
.36376 .42788 Mdot
.71882 .51413 Mdot
.34357 .58852 Mdot
.52506 .33762 Mdot
.54862 .35753 Mdot
.46042 .63676 Mdot
.27421 .38916 Mdot
.39024 .47701 Mdot
.65943 .52669 Mdot
.29049 .64378 Mdot
.21755 .39017 Mdot
.16739 .50308 Mdot
.40186 .7127 Mdot
.38386 .58492 Mdot
.52755 .28945 Mdot
.39529 .58746 Mdot
.659 .54991 Mdot
.69476 .49462 Mdot
.23574 .67247 Mdot
.41581 .48203 Mdot
.55404 .68519 Mdot
.66079 .54115 Mdot
.7747 .60082 Mdot
.38169 .58901 Mdot
.399 .57516 Mdot
.61877 .553 Mdot
.49312 .3318 Mdot
.27953 .76104 Mdot
.40094 .45188 Mdot
.61451 .28663 Mdot
.53286 .39563 Mdot
.54204 .43673 Mdot
.38557 .44558 Mdot
.52904 .5757 Mdot
.35539 .64259 Mdot
.58019 .21618 Mdot
.52968 .33658 Mdot
.55015 .68527 Mdot
.67278 .46845 Mdot
.55815 .30092 Mdot
.37415 .65026 Mdot
.55093 .30041 Mdot
.612 .55765 Mdot
.34643 .44864 Mdot
.36692 .63587 Mdot
.37567 .42136 Mdot
.54862 .36964 Mdot
.56386 .67289 Mdot
.76375 .57631 Mdot
.61527 .27725 Mdot
.7625 .44378 Mdot
.60591 .50958 Mdot
.30458 .64236 Mdot
.61836 .5322 Mdot
.49907 .30281 Mdot
.65112 .51813 Mdot
.47094 .31165 Mdot
.39779 .61791 Mdot
.58577 .47243 Mdot
.67638 .50364 Mdot
.59553 .23906 Mdot
.64745 .48643 Mdot
.67148 .54517 Mdot
.59534 .48459 Mdot
.51484 .39156 Mdot
.61222 .44821 Mdot
.53045 .35618 Mdot
.39007 .3337 Mdot
.36461 .60675 Mdot
.57412 .69843 Mdot
.52864 .70136 Mdot
.75265 .6458 Mdot
.76907 .59667 Mdot
.36808 .35942 Mdot
.5444 .34454 Mdot
.34999 .47055 Mdot
.61086 .54748 Mdot
.70029 .43309 Mdot
.58215 .63272 Mdot
.35849 .64166 Mdot
.34399 .59568 Mdot
.59049 .44597 Mdot
.71188 .75446 Mdot
.60117 .45486 Mdot
.42491 .35558 Mdot
.58594 .52402 Mdot
.5951 .47801 Mdot
.39363 .56604 Mdot
.74809 .59449 Mdot
.6058 .50896 Mdot
.50602 .29383 Mdot
.54592 .68635 Mdot
.54995 .5366 Mdot
.58141 .62613 Mdot
.5084 .51408 Mdot
.54247 .23539 Mdot
.61844 .52206 Mdot
.38301 .60578 Mdot
.55326 .29401 Mdot
.43954 .33231 Mdot
.36597 .46176 Mdot
.43722 .37985 Mdot
.62356 .25489 Mdot
.35361 .67759 Mdot
.55039 .68743 Mdot
.36471 .71546 Mdot
.62983 .49375 Mdot
.33974 .61716 Mdot
.61306 .55511 Mdot
.21338 .39484 Mdot
.56411 .66249 Mdot
.53589 .37193 Mdot
.35414 .47246 Mdot
.54939 .35067 Mdot
.73372 .42043 Mdot
.57242 .61414 Mdot
.23657 .34546 Mdot
.33315 .63226 Mdot
.76929 .54271 Mdot
.51932 .30486 Mdot
.62813 .54696 Mdot
.20113 .28 Mdot
.54339 .3187 Mdot
.54395 .35517 Mdot
.472 .62947 Mdot
.69143 .61896 Mdot
.59496 .57564 Mdot
.55482 .30476 Mdot
.32787 .64604 Mdot
.54174 .67004 Mdot
.59831 .50572 Mdot
.59352 .48867 Mdot
.52185 .35725 Mdot
.38749 .62499 Mdot
.78297 .59662 Mdot
.34769 .61934 Mdot
.51943 .3463 Mdot
.36432 .62433 Mdot
.27884 .62902 Mdot
.3713 .58649 Mdot
.67457 .4914 Mdot
.65803 .52738 Mdot
.47652 .76955 Mdot
.54564 .32597 Mdot
.59402 .50973 Mdot
.6403 .5343 Mdot
.51469 .31162 Mdot
.3464 .58139 Mdot
.75833 .48936 Mdot
.61764 .49488 Mdot
.65182 .5314 Mdot
.54689 .65437 Mdot
.43177 .57317 Mdot
.19506 .48367 Mdot
.59652 .50707 Mdot
.54312 .71261 Mdot
.49919 .31457 Mdot
.66231 .49236 Mdot
.76129 .5879 Mdot
.40386 .56454 Mdot
.66936 .53861 Mdot
.27322 .36348 Mdot
.61659 .48186 Mdot
.27471 .75668 Mdot
.67236 .51191 Mdot
.50895 .31255 Mdot
.52736 .30394 Mdot
.38184 .54426 Mdot
.52582 .32805 Mdot
.26679 .37543 Mdot
.37474 .47408 Mdot
.16121 .52058 Mdot
.26732 .37206 Mdot
.60964 .46692 Mdot
.54235 .19298 Mdot
.58088 .52076 Mdot
.68757 .51792 Mdot
.78538 .56199 Mdot
.26916 .37487 Mdot
.53159 .29738 Mdot
.2149 .55636 Mdot
.59173 .47763 Mdot
.40118 .45472 Mdot
.68986 .49682 Mdot
.67186 .53374 Mdot
.52165 .42966 Mdot
.79144 .44051 Mdot
.40406 .45127 Mdot
.7053 .52996 Mdot
.59682 .5083 Mdot
.42718 .20538 Mdot
.64135 .49979 Mdot
.54695 .70683 Mdot
.554 .33216 Mdot
.39631 .58408 Mdot
.54129 .69469 Mdot
.62023 .49055 Mdot
.55018 .68121 Mdot
.35443 .59945 Mdot
.36354 .47131 Mdot
.66981 .5303 Mdot
.52354 .69439 Mdot
.55783 .68389 Mdot
.61247 .53403 Mdot
.53159 .30733 Mdot
.56109 .54054 Mdot
.66006 .48955 Mdot
.63453 .54771 Mdot
.5482 .34602 Mdot
.53596 .15211 Mdot
.64179 .56068 Mdot
.52173 .57908 Mdot
.55813 .35403 Mdot
.30046 .37479 Mdot
.39274 .58619 Mdot
.6231 .56563 Mdot
.373 .45325 Mdot
.3714 .46506 Mdot
.32182 .62904 Mdot
.52062 .36242 Mdot
.37906 .63421 Mdot
.67379 .57283 Mdot
.60268 .44205 Mdot
.65672 .45488 Mdot
.81949 .34483 Mdot
.28845 .69661 Mdot
.50175 .32927 Mdot
.36172 .64325 Mdot
.44971 .4228 Mdot
.38901 .47651 Mdot
.32014 .64818 Mdot
.55814 .28295 Mdot
.51136 .30053 Mdot
.55942 .30845 Mdot
.53596 .66687 Mdot
.34379 .62644 Mdot
.481 .31901 Mdot
.49854 .3442 Mdot
.62283 .55063 Mdot
.59674 .50958 Mdot
.49736 .36692 Mdot
.6936 .70099 Mdot
.56593 .67785 Mdot
.37948 .61129 Mdot
.47392 .86609 Mdot
.40059 .44813 Mdot
.59344 .23745 Mdot
.61042 .49572 Mdot
.39857 .12155 Mdot
.63271 .44818 Mdot
.64566 .50025 Mdot
.50057 .31404 Mdot
.55004 .71868 Mdot
.54854 .66947 Mdot
.52033 .30475 Mdot
.55115 .37344 Mdot
.52956 .6938 Mdot
.39761 .71789 Mdot
.15939 .56628 Mdot
.43793 .35197 Mdot
.50904 .31613 Mdot
.60505 .27321 Mdot
.38151 .48679 Mdot
.56107 .35642 Mdot
.40264 .44734 Mdot
.36575 .6039 Mdot
.34724 .59401 Mdot
.40819 .48121 Mdot
.64097 .55242 Mdot
.36152 .59147 Mdot
.68075 .57754 Mdot
.26046 .67609 Mdot
.4646 .80868 Mdot
.33963 .24148 Mdot
.62082 .47553 Mdot
.40226 .27837 Mdot
.37305 .27969 Mdot
.62768 .50803 Mdot
.58822 .42684 Mdot
.55243 .68429 Mdot
.55554 .36062 Mdot
.3941 .47734 Mdot
.307 .75162 Mdot
.65939 .52517 Mdot
.51425 .33775 Mdot
.39354 .47048 Mdot
.27971 .60966 Mdot
.49513 .41049 Mdot
.6167 .55353 Mdot
.11312 .39246 Mdot
.54258 .3711 Mdot
.39661 .58432 Mdot
.53689 .20804 Mdot
.57285 .33698 Mdot
.47846 .6777 Mdot
.4041 .60062 Mdot
.17285 .45444 Mdot
.52846 .29311 Mdot
.36732 .56065 Mdot
.5226 .3208 Mdot
.56433 .69622 Mdot
.57814 .33519 Mdot
.37215 .63077 Mdot
.65247 .49374 Mdot
.36742 .63163 Mdot
.56754 .68505 Mdot
.33854 .61413 Mdot
.39301 .47962 Mdot
.27051 .38158 Mdot
.38586 .474 Mdot
.44197 .52718 Mdot
.77999 .42591 Mdot
.36077 .45077 Mdot
.29428 .66396 Mdot
.60808 .48585 Mdot
.49245 .28931 Mdot
.3947 .57994 Mdot
.32939 .62162 Mdot
.44864 .50817 Mdot
.51568 .33289 Mdot
.37313 .6272 Mdot
.62616 .26145 Mdot
.62055 .17032 Mdot
.69255 .57306 Mdot
.61479 .76687 Mdot
.51291 .31314 Mdot
.40155 .60508 Mdot
.43264 .33946 Mdot
.56248 .33071 Mdot
.3715 .57766 Mdot
.35868 .47401 Mdot
.38 .44868 Mdot
.64557 .55503 Mdot
.41887 .46155 Mdot
.38412 .63894 Mdot
.31508 .28683 Mdot
.55522 .33095 Mdot
.28649 .60517 Mdot
.5414 .70704 Mdot
.36368 .59987 Mdot
.57355 .54816 Mdot
.53685 .38012 Mdot
.33792 .60242 Mdot
.5172 .7865 Mdot
.51471 .86798 Mdot
.37282 .62639 Mdot
.5542 .33133 Mdot
.52875 .34396 Mdot
.61062 .58554 Mdot
.4615 .47735 Mdot
.38316 .6261 Mdot
.33192 .52167 Mdot
.75203 .65635 Mdot
.28117 .36821 Mdot
.48255 .17944 Mdot
.60667 .50812 Mdot
.62273 .53374 Mdot
.37846 .4834 Mdot
.63626 .48774 Mdot
.49239 .32264 Mdot
.68455 .50459 Mdot
.3442 .4703 Mdot
.36244 .64088 Mdot
.66916 .50881 Mdot
.55344 .66362 Mdot
.38996 .4843 Mdot
.39463 .4935 Mdot
.36198 .6173 Mdot
.55731 .30683 Mdot
.20382 .56013 Mdot
.34684 .61971 Mdot
.61723 .52068 Mdot
.27849 .37724 Mdot
.61063 .56003 Mdot
.44546 .77627 Mdot
.55767 .33974 Mdot
.39625 .58786 Mdot
.56738 .30428 Mdot
.38564 .46781 Mdot
.32456 .62506 Mdot
.63827 .50193 Mdot
.36652 .57922 Mdot
.58595 .71251 Mdot
.41012 .74461 Mdot
.50114 .35061 Mdot
.52164 .71043 Mdot
.53223 .36072 Mdot
.28022 .36739 Mdot
.62912 .66455 Mdot
.55428 .69278 Mdot
.37445 .59072 Mdot
.28586 .70125 Mdot
.37755 .57008 Mdot
.64724 .4847 Mdot
.63839 .47632 Mdot
.39169 .604 Mdot
.54724 .66022 Mdot
.82463 .53114 Mdot
.54487 .60312 Mdot
.53866 .29581 Mdot
.4791 .27036 Mdot
.40544 .84313 Mdot
.3483 .41777 Mdot
.35872 .47996 Mdot
.69279 .47072 Mdot
.58904 .51705 Mdot
.39098 .49146 Mdot
.38173 .42758 Mdot
.55739 .65095 Mdot
.34256 .6107 Mdot
.53357 .27351 Mdot
.38483 .48863 Mdot
.70835 .58797 Mdot
.77097 .58924 Mdot
.62293 .58814 Mdot
.57444 .48328 Mdot
.64334 .46435 Mdot
.4455 .53787 Mdot
.36184 .43289 Mdot
.63657 .52066 Mdot
.64853 .4467 Mdot
.3532 .46 Mdot
.56585 .69061 Mdot
.55827 .26885 Mdot
.37082 .61923 Mdot
.51874 .11904 Mdot
.67096 .52777 Mdot
.65567 .49209 Mdot
.3711 .44971 Mdot
.45026 .18632 Mdot
.50383 .32815 Mdot
.5578 .31567 Mdot
.35823 .60123 Mdot
.44471 .50872 Mdot
.68114 .50282 Mdot
.63005 .51099 Mdot
.37442 .59584 Mdot
.27373 .38318 Mdot
.30038 .26386 Mdot
.64588 .52832 Mdot
.39045 .45462 Mdot
.30031 .6193 Mdot
.36487 .43081 Mdot
.61911 .55723 Mdot
.64554 .48242 Mdot
.67648 .49498 Mdot
.5872 .50242 Mdot
.39955 .48815 Mdot
.63135 .50804 Mdot
.56197 .47556 Mdot
.54398 .30307 Mdot
.61491 .50479 Mdot
.74935 .64194 Mdot
.65177 .52684 Mdot
.55598 .66496 Mdot
.19257 .50757 Mdot
.66222 .53135 Mdot
.61595 .50765 Mdot
.53883 .59667 Mdot
.65509 .50261 Mdot
.39474 .44312 Mdot
.52942 .33996 Mdot
.39047 .46457 Mdot
.36892 .43511 Mdot
.32894 .63987 Mdot
.56035 .65147 Mdot
.60471 .56791 Mdot
.53678 .70659 Mdot
.56865 .52528 Mdot
.60954 .55589 Mdot
.42886 .55465 Mdot
.42408 .35802 Mdot
.57716 .71616 Mdot
.63992 .50694 Mdot
.3603 .60526 Mdot
.39081 .57926 Mdot
.58548 .74501 Mdot
.65937 .58747 Mdot
.39557 .48742 Mdot
.36385 .47729 Mdot
.67638 .68675 Mdot
.5137 .41711 Mdot
.56071 .66927 Mdot
.45032 .40926 Mdot
.62242 .47223 Mdot
.64618 .53797 Mdot
.69161 .50133 Mdot
.33886 .65168 Mdot
.27762 .3877 Mdot
.35413 .64075 Mdot
.27915 .39757 Mdot
.36552 .42913 Mdot
.62305 .47502 Mdot
.42257 .80093 Mdot
.51037 .35153 Mdot
.53068 .33982 Mdot
.34804 .47914 Mdot
.369 .64374 Mdot
.60526 .58155 Mdot
.82965 .35191 Mdot
.48249 .34439 Mdot
.56356 .71386 Mdot
.62974 .5148 Mdot
.36119 .61387 Mdot
.50273 .34604 Mdot
.52763 .66209 Mdot
.63022 .47289 Mdot
.35197 .57853 Mdot
.65242 .52131 Mdot
.62912 .38083 Mdot
.53874 .30137 Mdot
.2155 .38506 Mdot
.49836 .34934 Mdot
.37197 .48891 Mdot
.35983 .44115 Mdot
.64945 .48088 Mdot
.72987 .24769 Mdot
.52611 .37258 Mdot
.38939 .42156 Mdot
.57098 .68544 Mdot
.28991 .38898 Mdot
.57015 .66547 Mdot
.39337 .62228 Mdot
.5479 .68804 Mdot
.35891 .58038 Mdot
.67546 .70212 Mdot
.47881 .33248 Mdot
.54562 .69758 Mdot
.42131 .1875 Mdot
.66457 .56165 Mdot
.54986 .65049 Mdot
.58148 .45233 Mdot
.46693 .33811 Mdot
.37381 .59944 Mdot
.54692 .66126 Mdot
.62302 .54685 Mdot
.33787 .76434 Mdot
.36393 .43716 Mdot
.39752 .48606 Mdot
.6078 .56964 Mdot
.39079 .56835 Mdot
.55659 .37166 Mdot
.47661 .60007 Mdot
.29841 .37031 Mdot
.63109 .51088 Mdot
.62558 .47292 Mdot
.53399 .36502 Mdot
.4953 .30417 Mdot
.64447 .48048 Mdot
.63749 .27725 Mdot
.62848 .49379 Mdot
.38112 .44602 Mdot
.50635 .30804 Mdot
.53126 .34294 Mdot
.37871 .64419 Mdot
.51923 .36147 Mdot
.58179 .47302 Mdot
.37364 .50764 Mdot
.67219 .46248 Mdot
.38129 .46754 Mdot
.49423 .55267 Mdot
.33717 .62317 Mdot
.3042 .74116 Mdot
.52078 .36439 Mdot
.61987 .51558 Mdot
.53734 .36049 Mdot
.53694 .70101 Mdot
.54465 .32831 Mdot
.55316 .28952 Mdot
.64206 .47355 Mdot
.61426 .55288 Mdot
.27347 .37914 Mdot
.45986 .48015 Mdot
.54099 .30867 Mdot
.62592 .49721 Mdot
.57931 .51906 Mdot
.66124 .55861 Mdot
.48291 .49462 Mdot
.51001 .29959 Mdot
.7146 .30271 Mdot
.45625 .78908 Mdot
.53489 .30847 Mdot
.32329 .78325 Mdot
.28453 .36406 Mdot
.27749 .39122 Mdot
.34809 .42176 Mdot
.64765 .53148 Mdot
.37445 .6347 Mdot
.66057 .54843 Mdot
.69163 .57074 Mdot
.667 .5261 Mdot
.56801 .67384 Mdot
.57844 .5422 Mdot
.2911 .37549 Mdot
.34907 .62513 Mdot
.61698 .49243 Mdot
.66898 .51393 Mdot
.26962 .38625 Mdot
.50088 .35389 Mdot
.52024 .29537 Mdot
.17617 .52461 Mdot
.5561 .69978 Mdot
.36589 .46853 Mdot
.65068 .55046 Mdot
.35949 .60355 Mdot
.364 .63324 Mdot
.54753 .35267 Mdot
.37514 .61435 Mdot
.40168 .45179 Mdot
.63883 .49609 Mdot
.39341 .49109 Mdot
.56806 .67575 Mdot
.55366 .33301 Mdot
.6514 .55073 Mdot
.62459 .55097 Mdot
.52752 .30371 Mdot
.60862 .48506 Mdot
.54599 .6548 Mdot
.34592 .59838 Mdot
.51818 .29787 Mdot
.37345 .47224 Mdot
.3731 .64752 Mdot
.60734 .54308 Mdot
.58343 .83828 Mdot
.63369 .4873 Mdot
.64397 .54672 Mdot
.18327 .61692 Mdot
.67722 .45742 Mdot
.39869 .61215 Mdot
.55121 .3562 Mdot
.67896 .55345 Mdot
.75268 .67232 Mdot
.27615 .42177 Mdot
.31977 .64408 Mdot
.62655 .51684 Mdot
.29019 .73265 Mdot
.62063 .50983 Mdot
.27372 .60711 Mdot
.42906 .55066 Mdot
.66675 .76507 Mdot
.57661 .47636 Mdot
.40874 .45549 Mdot
.27164 .37914 Mdot
.39265 .57568 Mdot
.69582 .41484 Mdot
.62436 .48391 Mdot
.73606 .44206 Mdot
.67632 .52332 Mdot
.38495 .4463 Mdot
.62628 .42835 Mdot
.37845 .61263 Mdot
.56261 .21186 Mdot
.61675 .5259 Mdot
.50764 .30281 Mdot
.33161 .65419 Mdot
.29733 .38162 Mdot
.62585 .54862 Mdot
.5453 .71087 Mdot
.32609 .40267 Mdot
.59687 .44867 Mdot
.37892 .4688 Mdot
.6395 .53607 Mdot
.70364 .54044 Mdot
.67178 .21305 Mdot
.54214 .30032 Mdot
.35841 .47818 Mdot
.43415 .23162 Mdot
.60947 .48155 Mdot
.52613 .29382 Mdot
.52769 .3367 Mdot
.55775 .70609 Mdot
.42436 .39205 Mdot
.31626 .42002 Mdot
.5053 .81263 Mdot
.75616 .42421 Mdot
.37927 .64675 Mdot
.34623 .26182 Mdot
.60001 .5108 Mdot
.5677 .60524 Mdot
.39112 .44057 Mdot
.65522 .4941 Mdot
.77001 .40927 Mdot
.54762 .31795 Mdot
.64512 .52382 Mdot
.56552 .68132 Mdot
.3503 .39197 Mdot
.51402 .51473 Mdot
.50505 .84559 Mdot
.32367 .64768 Mdot
.68653 .48396 Mdot
.56897 .47971 Mdot
.30103 .37802 Mdot
.60183 .54689 Mdot
.39547 .57882 Mdot
.31214 .69012 Mdot
.5529 .65872 Mdot
.5111 .35486 Mdot
.28759 .3654 Mdot
.66865 .4757 Mdot
.60474 .56315 Mdot
.57362 .69922 Mdot
.62307 .54206 Mdot
.5505 .21231 Mdot
.26026 .34967 Mdot
.36874 .58604 Mdot
.55088 .29903 Mdot
.64021 .46368 Mdot
.27838 .38765 Mdot
.63983 .47442 Mdot
.54106 .25194 Mdot
.62705 .5309 Mdot
.33072 .37537 Mdot
.52689 .30898 Mdot
.38104 .47174 Mdot
.60342 .56945 Mdot
.66201 .51653 Mdot
.47143 .69631 Mdot
.69339 .56892 Mdot
.67175 .51336 Mdot
.51088 .28919 Mdot
.51127 .34815 Mdot
.53525 .35589 Mdot
.36218 .58857 Mdot
.43914 .36243 Mdot
.38378 .45582 Mdot
.68177 .51685 Mdot
.38584 .48824 Mdot
.70678 .57658 Mdot
.56912 .70686 Mdot
.37076 .80238 Mdot
.617 .4875 Mdot
.53993 .35211 Mdot
.30907 .30414 Mdot
.49844 .31677 Mdot
.4049 .55857 Mdot
.39565 .4606 Mdot
.54244 .31708 Mdot
.65369 .5076 Mdot
.45696 .44216 Mdot
.54543 .83928 Mdot
.38532 .47843 Mdot
.69397 .50066 Mdot
.3245 .64287 Mdot
.35044 .58556 Mdot
.32486 .80444 Mdot
.35675 .44133 Mdot
.37079 .27631 Mdot
.62404 .49948 Mdot
.51335 .3532 Mdot
.36377 .45169 Mdot
.39227 .43849 Mdot
.37635 .60071 Mdot
.62582 .55687 Mdot
.65907 .51942 Mdot
.27486 .36307 Mdot
.36609 .47656 Mdot
.66507 .56423 Mdot
.59084 .53212 Mdot
.22572 .66549 Mdot
.53388 .26903 Mdot
.50857 .1472 Mdot
.67747 .56832 Mdot
.77211 .43285 Mdot
.47207 .52087 Mdot
.50078 .3286 Mdot
.6529 .55255 Mdot
.6778 .48203 Mdot
.38314 .6441 Mdot
.63585 .49259 Mdot
.34766 .64824 Mdot
.35632 .47929 Mdot
.38672 .8146 Mdot
.29645 .59266 Mdot
.38064 .70752 Mdot
.64164 .48739 Mdot
.53064 .44915 Mdot
.53669 .69452 Mdot
.35766 .49077 Mdot
.51335 .34228 Mdot
.62923 .46511 Mdot
.4042 .60538 Mdot
.37611 .58964 Mdot
.53264 .33148 Mdot
.37073 .2989 Mdot
.27824 .66523 Mdot
.58593 .50458 Mdot
.39669 .59429 Mdot
.2866 .58011 Mdot
.65595 .29154 Mdot
.41646 .46235 Mdot
.55822 .65913 Mdot
.36363 .63991 Mdot
.39654 .49389 Mdot
.52611 .25612 Mdot
.53324 .32248 Mdot
.53928 .36825 Mdot
.46036 .75036 Mdot
.3802 .62919 Mdot
.53755 .68391 Mdot
.49058 .39713 Mdot
.45809 .36378 Mdot
.56584 .66755 Mdot
.36233 .64139 Mdot
.50595 .34648 Mdot
.51562 .34082 Mdot
.52793 .34014 Mdot
.559 .21371 Mdot
.55839 .33353 Mdot
.67095 .25438 Mdot
.58239 .52796 Mdot
.61031 .29146 Mdot
.62236 .51208 Mdot
.40753 .47409 Mdot
.53721 .30106 Mdot
.45846 .50819 Mdot
.60827 .47193 Mdot
.51073 .84178 Mdot
.6329 .51665 Mdot
.39758 .50322 Mdot
.64962 .53201 Mdot
.58241 .25587 Mdot
.55786 .35465 Mdot
.63836 .50587 Mdot
.39837 .43222 Mdot
.55702 .68036 Mdot
.58209 .29724 Mdot
.66228 .52949 Mdot
.36976 .38037 Mdot
.64899 .44761 Mdot
.26925 .67831 Mdot
.48303 .64675 Mdot
.56033 .71637 Mdot
.63306 .44421 Mdot
.35734 .65601 Mdot
.57744 .35899 Mdot
.60523 .30378 Mdot
.38416 .47874 Mdot
.79016 .5144 Mdot
.37169 .59061 Mdot
.62376 .42814 Mdot
.60752 .46224 Mdot
.53523 .66578 Mdot
.57598 .35789 Mdot
.3789 .44318 Mdot
.61419 .48431 Mdot
.66558 .55024 Mdot
.51968 .76879 Mdot
.60208 .29145 Mdot
.64987 .56726 Mdot
.57176 .66014 Mdot
.72574 .31216 Mdot
.65441 .53885 Mdot
.34001 .58995 Mdot
.56235 .34108 Mdot
.5675 .51433 Mdot
.70264 .29258 Mdot
.62484 .49487 Mdot
.54045 .32216 Mdot
.52382 .36546 Mdot
.32919 .34049 Mdot
.56218 .71309 Mdot
.62728 .53129 Mdot
.48443 .69563 Mdot
.62004 .52916 Mdot
.38437 .45163 Mdot
.63764 .56137 Mdot
.36806 .59878 Mdot
.42979 .33916 Mdot
.35402 .59292 Mdot
.65038 .55751 Mdot
.519 .33843 Mdot
.37389 .44354 Mdot
.45204 .76356 Mdot
.46038 .60458 Mdot
.68049 .26178 Mdot
.28715 .4079 Mdot
.53855 .66609 Mdot
.54879 .64766 Mdot
.34479 .44415 Mdot
.64179 .51256 Mdot
.44926 .55655 Mdot
.59746 .4614 Mdot
.65225 .53384 Mdot
.66747 .53204 Mdot
.41899 .47923 Mdot
.39219 .46738 Mdot
.36624 .62746 Mdot
.6425 .48081 Mdot
.62701 .49813 Mdot
.5331 .31279 Mdot
.55881 .6829 Mdot
.36354 .58494 Mdot
.54826 .70171 Mdot
.35057 .61772 Mdot
.28238 .75979 Mdot
.69142 .54073 Mdot
.5573 .67883 Mdot
.35018 .44126 Mdot
.54609 .34978 Mdot
.26204 .37455 Mdot
.38928 .62933 Mdot
.37808 .61612 Mdot
.62956 .50829 Mdot
.55188 .33068 Mdot
.55264 .3174 Mdot
.52967 .68654 Mdot
.35875 .4641 Mdot
.65328 .55556 Mdot
.59901 .54091 Mdot
.57279 .77467 Mdot
.35828 .65205 Mdot
.65191 .2767 Mdot
.34834 .33981 Mdot
.64207 .51167 Mdot
.54992 .30292 Mdot
.66825 .50331 Mdot
.33826 .74433 Mdot
.55868 .30267 Mdot
.58865 .49025 Mdot
.52387 .41005 Mdot
.33214 .64225 Mdot
.30178 .34695 Mdot
.58691 .54749 Mdot
.24345 .40291 Mdot
.6058 .524 Mdot
.15181 .59928 Mdot
.38422 .22744 Mdot
.67824 .49115 Mdot
.59392 .49202 Mdot
.53685 .8139 Mdot
.62185 .50202 Mdot
.28761 .3691 Mdot
.66943 .57785 Mdot
.51478 .29784 Mdot
.46336 .55621 Mdot
.42826 .58978 Mdot
.56752 .70325 Mdot
.3583 .60053 Mdot
.6251 .63618 Mdot
.56406 .69494 Mdot
.51167 .31102 Mdot
.59345 .48776 Mdot
.75836 .54502 Mdot
.39762 .55877 Mdot
.59409 .47037 Mdot
.38512 .45022 Mdot
.42833 .57858 Mdot
.3441 .64109 Mdot
.37687 .47485 Mdot
.67785 .51259 Mdot
.78502 .62879 Mdot
.45725 .6195 Mdot
.16152 .4517 Mdot
.36856 .45191 Mdot
.39341 .44724 Mdot
.44343 .31222 Mdot
.56724 .70351 Mdot
.53262 .76659 Mdot
.53037 .48176 Mdot
.4004 .46055 Mdot
.67731 .6588 Mdot
.40046 .57438 Mdot
.42143 .38749 Mdot
.55736 .35863 Mdot
.69293 .53424 Mdot
.65639 .50992 Mdot
.35604 .46158 Mdot
.72393 .46104 Mdot
.49011 .23119 Mdot
.38526 .47557 Mdot
.56183 .48958 Mdot
.37792 .38953 Mdot
.27548 .37452 Mdot
.27595 .36171 Mdot
.57225 .68576 Mdot
.31504 .67784 Mdot
.51986 .3175 Mdot
.53358 .66512 Mdot
.31882 .3794 Mdot
.63066 .53571 Mdot
.36949 .48077 Mdot
.26027 .37134 Mdot
.37311 .46152 Mdot
.55344 .66957 Mdot
.56439 .71285 Mdot
.54371 .30252 Mdot
.50418 .32904 Mdot
.78919 .44635 Mdot
.69612 .67524 Mdot
.6181 .50428 Mdot
.75738 .47809 Mdot
.55385 .33932 Mdot
.59314 .34121 Mdot
.54975 .71424 Mdot
.56097 .68374 Mdot
.63842 .35279 Mdot
.61904 .55126 Mdot
.30208 .59943 Mdot
.65972 .53337 Mdot
.62695 .67534 Mdot
.60811 .46513 Mdot
.37629 .60558 Mdot
.61177 .51115 Mdot
.19731 .53546 Mdot
.60039 .49761 Mdot
.67098 .52211 Mdot
.35146 .63379 Mdot
.62746 .5818 Mdot
.36915 .59673 Mdot
.62283 .55763 Mdot
.57654 .66685 Mdot
.35921 .60359 Mdot
.6385 .75629 Mdot
.52089 .57676 Mdot
.28411 .38792 Mdot
.56826 .69211 Mdot
.53782 .70609 Mdot
.76406 .62825 Mdot
.51034 .33864 Mdot
.50345 .26906 Mdot
.64183 .5137 Mdot
.39852 .57503 Mdot
.37746 .48394 Mdot
.62709 .496 Mdot
.67609 .47685 Mdot
.59866 .56342 Mdot
.54624 .31433 Mdot
.37249 .64051 Mdot
.55164 .67752 Mdot
.39029 .58249 Mdot
.45644 .65363 Mdot
.3649 .57414 Mdot
.69224 .46627 Mdot
.67009 .56962 Mdot
.62887 .60227 Mdot
.76343 .466 Mdot
.58033 .21281 Mdot
.53051 .32713 Mdot
.28379 .38117 Mdot
.57022 .70237 Mdot
.48281 .26628 Mdot
.52971 .35143 Mdot
.37873 .61947 Mdot
.65252 .52116 Mdot
.56014 .49684 Mdot
.51546 .49646 Mdot
.52926 .39118 Mdot
.73533 .67933 Mdot
.34056 .62454 Mdot
.2777 .3697 Mdot
.43541 .3492 Mdot
.48858 .37227 Mdot
.45338 .51491 Mdot
.66576 .51254 Mdot
.54328 .71093 Mdot
.50279 .34616 Mdot
.48545 .76139 Mdot
.35724 .46968 Mdot
.46081 .47704 Mdot
.64036 .488 Mdot
.33614 .28243 Mdot
.51905 .33799 Mdot
.5645 .67666 Mdot
.35562 .46082 Mdot
.55943 .7139 Mdot
.28509 .36288 Mdot
.18124 .53892 Mdot
.61717 .53679 Mdot
.67321 .50666 Mdot
.37386 .42319 Mdot
.5193 .32073 Mdot
.36831 .55443 Mdot
.49639 .77471 Mdot
.39599 .5965 Mdot
.44315 .55429 Mdot
.49952 .32791 Mdot
.55001 .23719 Mdot
.37902 .57944 Mdot
.34433 .47523 Mdot
.45109 .53949 Mdot
.34428 .46745 Mdot
.66116 .53572 Mdot
.54236 .34404 Mdot
.35502 .44318 Mdot
.47969 .72514 Mdot
.26083 .71943 Mdot
.56106 .25793 Mdot
.61821 .481 Mdot
.38438 .81149 Mdot
.21274 .64169 Mdot
.74169 .48767 Mdot
.37772 .4874 Mdot
.65622 .48378 Mdot
.58517 .50585 Mdot
.61562 .5224 Mdot
.34783 .46462 Mdot
.42651 .67554 Mdot
.38239 .60073 Mdot
.63283 .52186 Mdot
.54002 .70593 Mdot
.36904 .60721 Mdot
.34244 .65968 Mdot
.38767 .57182 Mdot
.55031 .28979 Mdot
.58764 .49662 Mdot
.40932 .37154 Mdot
.1659 .62304 Mdot
.39044 .46732 Mdot
.28485 .38783 Mdot
.67561 .51558 Mdot
.78766 .36591 Mdot
.53583 .35547 Mdot
.39568 .59886 Mdot
.65655 .49341 Mdot
.45644 .67969 Mdot
.25172 .38271 Mdot
.34489 .61902 Mdot
.5118 .3385 Mdot
.74133 .48882 Mdot
.63483 .49257 Mdot
.60614 .52732 Mdot
.5161 .31487 Mdot
.16814 .49958 Mdot
.42746 .35575 Mdot
.6684 .50912 Mdot
.38075 .47299 Mdot
.64251 .18575 Mdot
.60577 .56569 Mdot
.51694 .37958 Mdot
.28889 .38971 Mdot
.35336 .36778 Mdot
.66296 .28487 Mdot
.7115 .54126 Mdot
.40727 .80888 Mdot
.75113 .58927 Mdot
.3561 .79735 Mdot
.5945 .63609 Mdot
.2587 .55103 Mdot
.24748 .74119 Mdot
.40084 .43422 Mdot
.59456 .28578 Mdot
.61687 .79089 Mdot
.38632 .30399 Mdot
.48343 .63817 Mdot
.29082 .46372 Mdot
.47144 .66518 Mdot
.33319 .21654 Mdot
.37337 .57452 Mdot
.60812 .70047 Mdot
.6569 .55357 Mdot
.20971 .63254 Mdot
.60876 .26157 Mdot
.57903 .2007 Mdot
.34674 .78467 Mdot
.484 .68276 Mdot
.57932 .82519 Mdot
.30071 .73099 Mdot
.77069 .54503 Mdot
.5119 .47369 Mdot
.33307 .50165 Mdot
.47238 .38371 Mdot
.64459 .63357 Mdot
.60621 .58816 Mdot
.20372 .49741 Mdot
.3317 .68289 Mdot
.7575 .35555 Mdot
.64306 .19674 Mdot
.39281 .62643 Mdot
.56405 .33619 Mdot
.56555 .78099 Mdot
.58464 .34056 Mdot
.33343 .47085 Mdot
.40849 .80943 Mdot
.22496 .66984 Mdot
.5823 .25439 Mdot
.22874 .35659 Mdot
.66215 .38702 Mdot
.83534 .49744 Mdot
.5019 .52418 Mdot
.52095 .36756 Mdot
.27922 .52853 Mdot
.45842 .36343 Mdot
.35372 .5363 Mdot
.55221 .22622 Mdot
.51981 .6791 Mdot
.68843 .7217 Mdot
.51262 .3361 Mdot
.67056 .29795 Mdot
.28771 .39339 Mdot
.31482 .3847 Mdot
.37776 .55428 Mdot
.3513 .75509 Mdot
.26662 .39691 Mdot
.38868 .37974 Mdot
.31223 .28107 Mdot
.56005 .85117 Mdot
.70843 .62758 Mdot
.33796 .72715 Mdot
.41987 .49146 Mdot
.74391 .59568 Mdot
.41935 .31978 Mdot
.71645 .6539 Mdot
.46215 .35232 Mdot
.71514 .7635 Mdot
.16904 .56909 Mdot
.6216 .81402 Mdot
.56114 .27881 Mdot
.65781 .56329 Mdot
.39461 .77283 Mdot
.74808 .41904 Mdot
.55527 .71958 Mdot
.53524 .84933 Mdot
.53181 .70602 Mdot
.53988 .27482 Mdot
.38107 .29677 Mdot
.57312 .23033 Mdot
.31906 .67229 Mdot
.57415 .65117 Mdot
.59654 .45732 Mdot
.83178 .6642 Mdot
.439 .82265 Mdot
.33774 .34852 Mdot
.21926 .66052 Mdot
.39319 .42035 Mdot
.38451 .53901 Mdot
.35332 .47628 Mdot
.24878 .72635 Mdot
.53037 .34773 Mdot
.17255 .64397 Mdot
.24303 .70933 Mdot
.48285 .2126 Mdot
.87985 .60317 Mdot
.33025 .23829 Mdot
.61479 .28947 Mdot
.76582 .56643 Mdot
.71132 .71777 Mdot
.43802 .29089 Mdot
.47719 .20584 Mdot
.35029 .50879 Mdot
.16177 .50549 Mdot
.28429 .75336 Mdot
.65817 .66891 Mdot
.35517 .6843 Mdot
.40073 .2995 Mdot
.50601 .55118 Mdot
.50621 .37176 Mdot
.52727 .60405 Mdot
.54864 .58339 Mdot
.59962 .81876 Mdot
.78642 .38681 Mdot
.76681 .27677 Mdot
.60612 .65169 Mdot
.46126 .18734 Mdot
.28936 .692 Mdot
.62234 .75695 Mdot
.52254 .24064 Mdot
.38766 .3435 Mdot
.66498 .44992 Mdot
.44312 .37074 Mdot
.55852 .4753 Mdot
.51581 .69662 Mdot
.44108 .3345 Mdot
.25293 .60106 Mdot
.62252 .65954 Mdot
.48563 .80716 Mdot
.527 .43405 Mdot
.54368 .28931 Mdot
.74193 .6335 Mdot
.69266 .64294 Mdot
.23732 .67232 Mdot
.4316 .23283 Mdot
.15613 .46958 Mdot
.45033 .22554 Mdot
.59875 .45956 Mdot
.59713 .30962 Mdot
.59567 .58182 Mdot
.70809 .64996 Mdot
.57681 .50997 Mdot
.30224 .29456 Mdot
.18753 .62812 Mdot
.77563 .40625 Mdot
.63125 .64204 Mdot
.7671 .48107 Mdot
.16109 .52645 Mdot
.41429 .78292 Mdot
.37972 .23741 Mdot
.58516 .39863 Mdot
.79115 .70441 Mdot
.36635 .61821 Mdot
.67396 .66415 Mdot
.38134 .49997 Mdot
.46252 .75481 Mdot
.67503 .77033 Mdot
.47798 .22294 Mdot
.18207 .62081 Mdot
.39709 .34625 Mdot
.31881 .61623 Mdot
.42617 .40812 Mdot
.40897 .61997 Mdot
.77413 .4999 Mdot
.61855 .57602 Mdot
.68298 .59837 Mdot
.53512 .65942 Mdot
.73162 .40301 Mdot
.4385 .78338 Mdot
.25187 .45572 Mdot
.71204 .49439 Mdot
.25242 .48743 Mdot
.27655 .3667 Mdot
.45773 .45757 Mdot
.31486 .79685 Mdot
.69046 .5635 Mdot
.36281 .21791 Mdot
.168 .55584 Mdot
.44272 .5434 Mdot
.35038 .71961 Mdot
.34208 .31638 Mdot
.67038 .79343 Mdot
.21674 .67785 Mdot
.23638 .62962 Mdot
.39649 .81865 Mdot
.15461 .41995 Mdot
.7375 .72895 Mdot
.68242 .42036 Mdot
.40273 .49388 Mdot
.09085 .49087 Mdot
.3885 .59861 Mdot
.79493 .5081 Mdot
.74932 .41522 Mdot
.44826 .69318 Mdot
.5657 .37312 Mdot
.6673 .43575 Mdot
.3074 .40926 Mdot
.49175 .35458 Mdot
.60064 .45392 Mdot
.5045 .86201 Mdot
.72442 .76015 Mdot
.52196 .85832 Mdot
.18066 .54643 Mdot
.38252 .81563 Mdot
.58732 .80338 Mdot
.66171 .247 Mdot
.53742 .77444 Mdot
.63142 .56059 Mdot
.65822 .69151 Mdot
.33968 .23437 Mdot
.36448 .56048 Mdot
.26812 .34706 Mdot
.56663 .29469 Mdot
.68328 .77731 Mdot
.33321 .81559 Mdot
.66006 .35751 Mdot
.7186 .32267 Mdot
.53553 .57455 Mdot
.69464 .66498 Mdot
.68008 .6044 Mdot
.21067 .47254 Mdot
.2587 .68168 Mdot
.60109 .80209 Mdot
.66918 .64834 Mdot
.28097 .47465 Mdot
.239 .61667 Mdot
.43848 .19748 Mdot
.32271 .74756 Mdot
.59355 .78477 Mdot
.46641 .21432 Mdot
.58811 .40823 Mdot
.48733 .22853 Mdot
.20681 .45024 Mdot
.31487 .59688 Mdot
.69699 .62621 Mdot
.33587 .62073 Mdot
.65785 .67473 Mdot
.49447 .44033 Mdot
.54748 .77913 Mdot
.7555 .59253 Mdot
.65046 .67242 Mdot
.24783 .63046 Mdot
.46643 .85107 Mdot
.18815 .40304 Mdot
.80031 .63426 Mdot
.23151 .4097 Mdot
.56185 .46055 Mdot
.62623 .56658 Mdot
.17076 .58663 Mdot
.44536 .85542 Mdot
.18625 .6408 Mdot
.33544 .27919 Mdot
.47313 .72384 Mdot
.41541 .4763 Mdot
.79952 .56352 Mdot
.24324 .4325 Mdot
.26135 .69624 Mdot
.46299 .29787 Mdot
.34775 .42083 Mdot
.40404 .34724 Mdot
.78698 .51487 Mdot
.77767 .56629 Mdot
.69007 .3189 Mdot
.62566 .59006 Mdot
.63016 .28112 Mdot
.55433 .35603 Mdot
.34492 .2677 Mdot
.70804 .65767 Mdot
.36297 .61669 Mdot
.62073 .77271 Mdot
.67087 .60348 Mdot
.67288 .45297 Mdot
.31381 .60463 Mdot
.50539 .36948 Mdot
.76509 .45798 Mdot
.33845 .49543 Mdot
.26232 .75371 Mdot
.3508 .23803 Mdot
.74371 .56654 Mdot
.73694 .61995 Mdot
.53417 .75381 Mdot
.42886 .37078 Mdot
.34295 .45053 Mdot
.33252 .77082 Mdot
.50578 .59692 Mdot
.74168 .62816 Mdot
.63564 .2829 Mdot
.47773 .77726 Mdot
.67231 .47275 Mdot
.32939 .32696 Mdot
.71451 .28399 Mdot
.45755 .47477 Mdot
.50841 .28385 Mdot
.48159 .34512 Mdot
.33072 .20129 Mdot
.20694 .54229 Mdot
.42291 .22446 Mdot
.33808 .76919 Mdot
.34598 .4718 Mdot
.51776 .28923 Mdot
.64466 .6833 Mdot
.41579 .74663 Mdot
.75581 .33791 Mdot
.30042 .65649 Mdot
.67917 .60923 Mdot
.23812 .44696 Mdot
.39047 .81225 Mdot
.50928 .83237 Mdot
.68174 .21663 Mdot
.4914 .33415 Mdot
.43058 .77265 Mdot
.45453 .77286 Mdot
.50114 .34841 Mdot
.5242 .38789 Mdot
.51588 .48316 Mdot
.3471 .8008 Mdot
.45015 .37915 Mdot
.20878 .42202 Mdot
.44996 .54168 Mdot
.44498 .67473 Mdot
.49613 .76497 Mdot
.68764 .62494 Mdot
.34261 .76807 Mdot
.67286 .30894 Mdot
.74647 .69989 Mdot
.58976 .58404 Mdot
.79515 .44531 Mdot
.80052 .56234 Mdot
.49528 .51545 Mdot
.5623 .23723 Mdot
.26457 .60452 Mdot
.61705 .5177 Mdot
.55368 .85475 Mdot
.23815 .66327 Mdot
.45065 .317 Mdot
.32121 .45757 Mdot
.5963 .52521 Mdot
.58134 .51744 Mdot
.68471 .43426 Mdot
.35247 .35537 Mdot
.78079 .68241 Mdot
.61435 .66856 Mdot
.55812 .47036 Mdot
.63175 .27516 Mdot
.36469 .21759 Mdot
.36807 .76127 Mdot
.2756 .68397 Mdot
.4834 .44192 Mdot
.34059 .23594 Mdot
.43526 .50735 Mdot
.20375 .41946 Mdot
.23262 .49035 Mdot
.57525 .80311 Mdot
.55227 .43181 Mdot
.36954 .34706 Mdot
.52147 .7564 Mdot
.67322 .5229 Mdot
.3705 .29935 Mdot
.30918 .73526 Mdot
.81034 .33457 Mdot
.41933 .30702 Mdot
.48383 .86499 Mdot
.65024 .60336 Mdot
.37793 .35339 Mdot
.69625 .76141 Mdot
.86091 .41283 Mdot
.20421 .48469 Mdot
.58586 .82378 Mdot
.44397 .4448 Mdot
.3475 .77776 Mdot
.41176 .46312 Mdot
.48841 .4072 Mdot
.74892 .45835 Mdot
.33973 .7962 Mdot
.37258 .74423 Mdot
.36337 .77104 Mdot
.67516 .42583 Mdot
.38722 .82314 Mdot
.46359 .336 Mdot
.36024 .19018 Mdot
.3278 .60859 Mdot
.28176 .29295 Mdot
.62163 .40189 Mdot
.59912 .60303 Mdot
.6735 .6569 Mdot
.43955 .17251 Mdot
.62094 .21841 Mdot
.70232 .43581 Mdot
.62749 .7243 Mdot
.3466 .326 Mdot
.73818 .61551 Mdot
.26117 .70452 Mdot
.33909 .21016 Mdot
.47678 .76844 Mdot
.38254 .25572 Mdot
.17343 .52735 Mdot
.34681 .35604 Mdot
.23054 .5313 Mdot
.33547 .72769 Mdot
.185 .45834 Mdot
.66117 .6136 Mdot
.42575 .12647 Mdot
.38972 .66394 Mdot
.51594 .48805 Mdot
.64905 .8003 Mdot
.25659 .67887 Mdot
.47632 .27173 Mdot
.53836 .21371 Mdot
.80944 .46778 Mdot
.67387 .70559 Mdot
.66681 .5261 Mdot
.39713 .82938 Mdot
.66034 .73749 Mdot
.55964 .84201 Mdot
.14915 .5245 Mdot
.63659 .2993 Mdot
.71066 .51636 Mdot
.38335 .64826 Mdot
.51328 .52963 Mdot
.61883 .72709 Mdot
.59907 .81035 Mdot
.79699 .47862 Mdot
.4634 .59738 Mdot
.25888 .5395 Mdot
.29167 .64945 Mdot
.55425 .45338 Mdot
.31924 .25102 Mdot
.35434 .34056 Mdot
.61228 .64481 Mdot
.23033 .60777 Mdot
.68997 .65896 Mdot
.65607 .28066 Mdot
.78155 .58117 Mdot
.45438 .25418 Mdot
.356 .40525 Mdot
.38682 .64014 Mdot
.52366 .80839 Mdot
.28118 .67186 Mdot
.30039 .29845 Mdot
.78315 .65756 Mdot
.386 .33699 Mdot
.60325 .71337 Mdot
.47311 .79609 Mdot
.43675 .28546 Mdot
.33127 .50389 Mdot
.78253 .55871 Mdot
.79247 .44217 Mdot
.27192 .62399 Mdot
.71975 .49951 Mdot
.28839 .76164 Mdot
.69011 .62779 Mdot
.51806 .79035 Mdot
.5182 .56742 Mdot
.74556 .38912 Mdot
.6132 .35289 Mdot
.66643 .74733 Mdot
.44853 .50467 Mdot
.81837 .67739 Mdot
.56439 .3653 Mdot
.56291 .85066 Mdot
.36765 .47246 Mdot
.73685 .27372 Mdot
.26549 .65335 Mdot
.48776 .4615 Mdot
.46379 .52498 Mdot
.32695 .32908 Mdot
.36342 .38506 Mdot
.16846 .5261 Mdot
.48589 .22491 Mdot
.3704 .57029 Mdot
.46926 .60995 Mdot
.2093 .43096 Mdot
.48839 .81461 Mdot
.67777 .55201 Mdot
.32257 .68066 Mdot
.4975 .52324 Mdot
.40259 .54427 Mdot
.17448 .59005 Mdot
.27193 .59201 Mdot
.56549 .5146 Mdot
.69642 .66645 Mdot
.62028 .80163 Mdot
.24551 .70502 Mdot
.48996 .23864 Mdot
.55789 .47829 Mdot
.37838 .50676 Mdot
.67287 .76012 Mdot
.43819 .81848 Mdot
.29821 .5994 Mdot
.41879 .38286 Mdot
.70226 .63059 Mdot
.56434 .87113 Mdot
.72076 .76133 Mdot
.79078 .65515 Mdot
.44863 .55069 Mdot
.48754 .29446 Mdot
.79093 .3764 Mdot
.51469 .79089 Mdot
.26391 .31015 Mdot
.23892 .64778 Mdot
.67927 .66087 Mdot
.84156 .39948 Mdot
.59969 .22163 Mdot
.45295 .65088 Mdot
.61416 .35531 Mdot
.75985 .4322 Mdot
.40806 .44626 Mdot
.66054 .71689 Mdot
.4878 .61166 Mdot
.33611 .44631 Mdot
.34822 .32885 Mdot
.38383 .38375 Mdot
.52112 .78955 Mdot
.73685 .31371 Mdot
.55372 .51013 Mdot
.45419 .81087 Mdot
.47921 .32775 Mdot
.48056 .76244 Mdot
.53604 .7567 Mdot
.48064 .62127 Mdot
.38921 .58584 Mdot
.64558 .5948 Mdot
.44594 .42045 Mdot
.44802 .47924 Mdot
.81772 .57395 Mdot
.52646 .6982 Mdot
.5763 .32244 Mdot
.57021 .21234 Mdot
.49098 .32648 Mdot
.42641 .85256 Mdot
.21108 .47397 Mdot
.62432 .27337 Mdot
.39511 .64952 Mdot
.28093 .50099 Mdot
.84641 .51999 Mdot
.77917 .532 Mdot
.54532 .60751 Mdot
.47096 .34182 Mdot
.5376 .36258 Mdot
.38495 .65381 Mdot
.28494 .35419 Mdot
.69248 .30929 Mdot
.35883 .21435 Mdot
.5487 .76442 Mdot
.51147 .36271 Mdot
.44312 .65944 Mdot
.74274 .54452 Mdot
.29926 .78039 Mdot
.38788 .57576 Mdot
.77604 .71869 Mdot
.67223 .56805 Mdot
.71637 .73499 Mdot
.17588 .59709 Mdot
.43023 .33305 Mdot
.44794 .56198 Mdot
.30577 .46987 Mdot
.68702 .5153 Mdot
.55303 .52144 Mdot
.50771 .32794 Mdot
.52718 .77156 Mdot
.55187 .68895 Mdot
.72783 .67511 Mdot
.34041 .46725 Mdot
.47407 .19621 Mdot
.32387 .25261 Mdot
.56501 .33935 Mdot
.50267 .61042 Mdot
.39279 .76185 Mdot
.51759 .44318 Mdot
.49666 .52264 Mdot
.53621 .81183 Mdot
.76082 .35011 Mdot
.51669 .36452 Mdot
.78291 .66221 Mdot
.58694 .72041 Mdot
.22818 .70659 Mdot
.73586 .53455 Mdot
.50295 .51477 Mdot
.52136 .44173 Mdot
.33161 .32022 Mdot
.67012 .28835 Mdot
.27056 .68658 Mdot
.73361 .64049 Mdot
.49533 .39666 Mdot
.6503 .67484 Mdot
.57558 .5567 Mdot
.25504 .53963 Mdot
.28707 .28066 Mdot
.84663 .41843 Mdot
.64039 .38314 Mdot
.41454 .33802 Mdot
.47952 .34817 Mdot
.36016 .21968 Mdot
.57405 .34887 Mdot
.42032 .70307 Mdot
.76348 .36486 Mdot
.26488 .65511 Mdot
.25958 .74122 Mdot
.23679 .67056 Mdot
.52967 .54245 Mdot
.29231 .63196 Mdot
.75194 .57814 Mdot
.74056 .53 Mdot
.47163 .4966 Mdot
.68557 .51333 Mdot
.56361 .44289 Mdot
.47434 .25467 Mdot
.30655 .30408 Mdot
.6449 .43167 Mdot
.32746 .78229 Mdot
.22516 .69913 Mdot
.43174 .83523 Mdot
.32235 .58288 Mdot
.54999 .28739 Mdot
.68467 .78456 Mdot
.64468 .25733 Mdot
.2564 .70258 Mdot
.63062 .40336 Mdot
.30591 .21974 Mdot
.65994 .77999 Mdot
.25746 .60652 Mdot
.48229 .20964 Mdot
.27544 .34177 Mdot
.18105 .59521 Mdot
.35854 .1915 Mdot
.65126 .61999 Mdot
.16698 .57433 Mdot
.83094 .66359 Mdot
.65389 .40437 Mdot
.37946 .38054 Mdot
.608 .33897 Mdot
.74673 .57649 Mdot
.35926 .20728 Mdot
.63297 .56254 Mdot
.33656 .6041 Mdot
.47404 .65041 Mdot
.68791 .65453 Mdot
.70426 .56984 Mdot
.37072 .19962 Mdot
.61436 .72815 Mdot
.60566 .70079 Mdot
.43572 .76552 Mdot
.62608 .79014 Mdot
.68305 .29653 Mdot
.5661 .48443 Mdot
.5462 .27285 Mdot
.57061 .67252 Mdot
.62261 .62926 Mdot
.59201 .52657 Mdot
.4275 .54641 Mdot
.52295 .47663 Mdot
.5016 .86455 Mdot
.42146 .7264 Mdot
.36936 .70741 Mdot
.48653 .35073 Mdot
.34805 .34595 Mdot
.41053 .78873 Mdot
.38434 .30098 Mdot
.39884 .18642 Mdot
.78507 .39184 Mdot
.40092 .81479 Mdot
.39379 .35423 Mdot
.65076 .64435 Mdot
.82586 .53967 Mdot
.40544 .47087 Mdot
.74828 .44464 Mdot
.58524 .8085 Mdot
.37523 .3155 Mdot
.50659 .28931 Mdot
.23852 .58931 Mdot
.26866 .55627 Mdot
.3649 .32003 Mdot
.16793 .55222 Mdot
.44813 .77995 Mdot
.62636 .32947 Mdot
.4947 .82943 Mdot
.3291 .65057 Mdot
.6681 .65071 Mdot
.2205 .55873 Mdot
.34797 .21001 Mdot
.52206 .43086 Mdot
.30056 .76987 Mdot
.46864 .50217 Mdot
.66977 .73624 Mdot
.61289 .53305 Mdot
.70884 .29689 Mdot
.31618 .3089 Mdot
.23092 .59897 Mdot
.4215 .23064 Mdot
.56069 .29853 Mdot
.32415 .2671 Mdot
.33741 .50421 Mdot
.6719 .71898 Mdot
.61035 .61968 Mdot
.58907 .30504 Mdot
.58062 .63742 Mdot
.29837 .39389 Mdot
.66283 .56891 Mdot
.70433 .71413 Mdot
.29686 .66652 Mdot
.7385 .44464 Mdot
.67969 .41779 Mdot
.52334 .80993 Mdot
.30895 .68993 Mdot
.29084 .30158 Mdot
.67405 .42072 Mdot
.32451 .37245 Mdot
.61354 .22632 Mdot
.39249 .27626 Mdot
.58339 .5402 Mdot
.42174 .70083 Mdot
.50679 .30076 Mdot
.49404 .81733 Mdot
.55049 .26301 Mdot
.63389 .75773 Mdot
.4676 .44695 Mdot
.38518 .76767 Mdot
.5063 .56709 Mdot
.1785 .59887 Mdot
.27291 .34153 Mdot
.70996 .65687 Mdot
.35214 .42892 Mdot
.44201 .44105 Mdot
.42256 .29694 Mdot
.29517 .74622 Mdot
.46786 .23816 Mdot
.76105 .54111 Mdot
.40769 .34109 Mdot
.77289 .42358 Mdot
.15332 .54362 Mdot
.70052 .67819 Mdot
.4718 .49467 Mdot
.72274 .5817 Mdot
.31418 .37668 Mdot
.26221 .37655 Mdot
.44058 .70673 Mdot
.66791 .2762 Mdot
.38121 .6912 Mdot
.45238 .60054 Mdot
.66115 .5656 Mdot
.7831 .3574 Mdot
.47625 .82446 Mdot
.48562 .26153 Mdot
.48663 .47567 Mdot
.5149 .75128 Mdot
.67937 .71779 Mdot
.5758 .13637 Mdot
.54596 .85908 Mdot
.61281 .53408 Mdot
.45731 .54426 Mdot
.72015 .67861 Mdot
.34668 .64724 Mdot
.7012 .32134 Mdot
.5172 .81191 Mdot
.39719 .45231 Mdot
.47286 .73379 Mdot
.24886 .35147 Mdot
.32017 .32363 Mdot
.65558 .75498 Mdot
.41927 .46042 Mdot
.44857 .86272 Mdot
.23428 .63863 Mdot
.3231 .30315 Mdot
.49763 .11375 Mdot
.32183 .2837 Mdot
.48513 .29036 Mdot
.35999 .74023 Mdot
.46043 .85018 Mdot
.44693 .54734 Mdot
.4604 .75083 Mdot
.68795 .42046 Mdot
.71938 .65081 Mdot
.62312 .67307 Mdot
.38063 .25642 Mdot
.34123 .25795 Mdot
.37163 .18309 Mdot
.28174 .49944 Mdot
.82382 .57585 Mdot
.65987 .29875 Mdot
.5099 .83671 Mdot
.20526 .48003 Mdot
.83476 .38495 Mdot
.24997 .72732 Mdot
.64965 .69945 Mdot
.3908 .19484 Mdot
.3562 .73057 Mdot
.75013 .65766 Mdot
.74426 .30554 Mdot
.1926 .49573 Mdot
.77461 .37161 Mdot
.26883 .48941 Mdot
.40798 .25386 Mdot
.65464 .67417 Mdot
.76772 .43091 Mdot
.46498 .5034 Mdot
.56463 .82281 Mdot
.46331 .17816 Mdot
.7288 .62457 Mdot
.48699 .73722 Mdot
.75498 .66429 Mdot
.44648 .81414 Mdot
.31991 .72912 Mdot
.48006 .51898 Mdot
.83464 .64518 Mdot
.59798 .81881 Mdot
.39545 .2898 Mdot
.58401 .53345 Mdot
.23979 .7289 Mdot
.47882 .55974 Mdot
.69498 .42859 Mdot
.19798 .6084 Mdot
.61085 .66594 Mdot
.53352 .4577 Mdot
.60631 .56731 Mdot
.78378 .54897 Mdot
.55446 .24308 Mdot
.76615 .43649 Mdot
.52917 .7436 Mdot
.73695 .62257 Mdot
.46827 .18065 Mdot
.71224 .72366 Mdot
.73649 .50876 Mdot
.49941 .32064 Mdot
.47942 .8584 Mdot
.76888 .54306 Mdot
.59598 .59292 Mdot
.61201 .30706 Mdot
.47472 .23323 Mdot
.30686 .41964 Mdot
.56211 .46459 Mdot
.43022 .37291 Mdot
.67618 .65536 Mdot
.50213 .7915 Mdot
.74684 .46187 Mdot
.88678 .59452 Mdot
.17617 .60301 Mdot
.55452 .37282 Mdot
.71967 .42639 Mdot
.47519 .63065 Mdot
.43972 .83447 Mdot
.2772 .46994 Mdot
.53486 .75481 Mdot
.55229 .19695 Mdot
.74841 .63842 Mdot
.63808 .45797 Mdot
.18006 .55071 Mdot
.26625 .73667 Mdot
.48851 .17275 Mdot
.28822 .76076 Mdot
.70373 .49484 Mdot
.70019 .52168 Mdot
.79655 .28728 Mdot
.367 .79497 Mdot
.70983 .54307 Mdot
.50652 .21626 Mdot
.56469 .37735 Mdot
.6504 .55649 Mdot
.24964 .35518 Mdot
.70182 .61626 Mdot
.61864 .6826 Mdot
.34383 .79793 Mdot
.48265 .33575 Mdot
.43891 .55307 Mdot
.39467 .4951 Mdot
.46123 .51939 Mdot
.56358 .51654 Mdot
.35815 .43823 Mdot
.61614 .69511 Mdot
.47347 .56582 Mdot
.32332 .40284 Mdot
.64678 .61771 Mdot
.19391 .40824 Mdot
.57917 .59356 Mdot
.53 .55055 Mdot
.61872 .41106 Mdot
.62076 .21764 Mdot
.61667 .72679 Mdot
.59508 .74156 Mdot
.16664 .56796 Mdot
.18096 .36988 Mdot
.42589 .61157 Mdot
.70867 .46069 Mdot
.55684 .40684 Mdot
.65903 .27479 Mdot
.61861 .32176 Mdot
.38444 .40059 Mdot
.26689 .37207 Mdot
.6889 .46562 Mdot
.74301 .56693 Mdot
.3653 .48859 Mdot
.5343 .87315 Mdot
.61239 .56124 Mdot
.65663 .32264 Mdot
.28252 .72537 Mdot
.48637 .76187 Mdot
.53707 .50647 Mdot
.6865 .50796 Mdot
.46179 .32732 Mdot
.47694 .56999 Mdot
.752 .5409 Mdot
.50562 .76536 Mdot
.45355 .83146 Mdot
.54318 .54511 Mdot
.64425 .31383 Mdot
.63363 .51529 Mdot
.56874 .64785 Mdot
.43978 .39121 Mdot
.79893 .59666 Mdot
.56698 .62599 Mdot
.24532 .69864 Mdot
.59586 .69637 Mdot
.61415 .66771 Mdot
.60048 .27751 Mdot
.5546 .84549 Mdot
.41509 .30847 Mdot
.63168 .29389 Mdot
.46203 .27855 Mdot
.23522 .54904 Mdot
.6285 .72187 Mdot
.36165 .66403 Mdot
.64009 .4315 Mdot
.56843 .37627 Mdot
.35196 .81538 Mdot
.78029 .5291 Mdot
.40939 .41468 Mdot
.27204 .63009 Mdot
.61537 .23086 Mdot
.46636 .5209 Mdot
.45757 .11903 Mdot
.28585 .45766 Mdot
.45456 .86352 Mdot
.48173 .78369 Mdot
.55312 .41139 Mdot
.34752 .32274 Mdot
.66395 .59028 Mdot
.35718 .63373 Mdot
.44578 .83363 Mdot
.72946 .56311 Mdot
.39047 .26846 Mdot
.61623 .55666 Mdot
.45375 .34942 Mdot
.74524 .55801 Mdot
.29008 .62 Mdot
.34793 .58784 Mdot
.48579 .23654 Mdot
.32355 .73884 Mdot
.47849 .57143 Mdot
.28169 .24769 Mdot
.60053 .81082 Mdot
.33005 .76978 Mdot
.29396 .65065 Mdot
.73444 .26679 Mdot
.47122 .33119 Mdot
.74205 .53152 Mdot
.36473 .41956 Mdot
.76855 .56633 Mdot
.36874 .31597 Mdot
.50476 .7875 Mdot
.32648 .36841 Mdot
.50919 .46262 Mdot
.36262 .1441 Mdot
.64667 .69289 Mdot
.48153 .27291 Mdot
.36015 .29696 Mdot
.31448 .76974 Mdot
.49362 .69881 Mdot
.16305 .44821 Mdot
.20167 .51415 Mdot
.56519 .5258 Mdot
.72182 .29365 Mdot
.74978 .6911 Mdot
.2957 .57552 Mdot
.83602 .55313 Mdot
.28503 .67401 Mdot
.64113 .63395 Mdot
.2271 .58987 Mdot
.49152 .3313 Mdot
.57052 .36748 Mdot
.21317 .45586 Mdot
.2217 .36847 Mdot
.71223 .45495 Mdot
.42146 .81474 Mdot
.83432 .46408 Mdot
.53812 .76279 Mdot
.40144 .82378 Mdot
.42418 .4881 Mdot
.50338 .38031 Mdot
.61089 .72616 Mdot
.57284 .72013 Mdot
.34322 .65093 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0W_ooool2o`000:Wooooo000Looooo`03o`000?oooooooooo09ko
oooo0_l0002Yooooo`007?ooool00ol0003oooooooooo`2Aooooo`;o00004_ooool2o`000:;ooooo
000Looooo`03o`000?oooooooooo07kooooo0_l0000<ooooo`;o00000oooool2o`00017ooooo0ol0
002Rooooo`007?ooool00ol0003oooooooooo`1nooooo`;o00003?ooool2o`0001Kooooo0_l0002S
ooooo`007?ooool00ol0003oooooooooo`27ooooo`;o0000`?ooool001cooooo00?o0000oooooooo
ool0Qoooool2o`000<3ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0]oooool2o`00093ooooo000Looooo`03o`000?oooooooooo07Sooooo1?l0000k
ooooo`;o0000T?ooool001cooooo00?o0000ooooooooool0L_ooool2o`0000Cooooo1?l0003=oooo
o`007?ooool00ol0003oooooooooo`1booooo`;o0000;Oooool2o`000:Kooooo000Looooo`03o`00
0?oooooooooo0:7ooooo0_l000000ooooooo0000o`00002Sooooo`007?ooool2o`000:Gooooo0_l0
0004ooooo`;o00004_ooool2o`0008Wooooo000Looooo`03o`000?oooooooooo0:[ooooo0_l00002
ooooo`;o00003_ooool2o`0008Wooooo000Looooo`03o`000?oooooooooo0:kooooo0_l0002Ioooo
o`007?ooool00ol0003oooooooooo`31ooooo`;o0000Q_ooool001cooooo00?o0000ooooooooool0
^?ooool2o`0000Oooooo0_l00002ooooo`;o000000?oooooo`000?l00000Ooooool001cooooo00?o
0000ooooooooool0^?ooool4o`0000Wooooo0_l000000ooooooo0000o`00001oooooo`007?ooool0
0ol0003oooooooooo`2jooooo`;o00002_ooool2o`00087ooooo000Looooo`03o`000?oooooooooo
08_ooooo0_l0000>ooooo`;o0000:Oooool2o`00087ooooo000Looooo`03o`000?oooooooooo05oo
oooo0_l0000Wooooo`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00001_ooool2o`00
02Gooooo0_l00025ooooo`007?ooool00ol0003oooooooooo`1Oooooo`;o00009oooool2o`0000Co
oooo0_l00003ooooo`?o00000oooool4o`0000Cooooo0_l0000Oooooo`;o0000QOooool001cooooo
00?o0000ooooooooool0MOooool2o`0000Oooooo0_l0000Dooooo`;o00000oooool5o`0000?ooooo
0_l0002Vooooo`007?ooool00ol0003oooooooooo`1eooooo`;o00001oooool2o`0000Gooooo0_l0
0008ooooo`;o000000?oooooo`000?l000000_l00006ooooo`;o00001_ooool2o`00023ooooo0_l0
0005ooooo`;o0000N_ooool001cooooo00?o0000ooooooooool0LOooool2o`0000_ooooo0ol00004
ooooo`;o00001_ooool4o`000003ooooool0003o000000;o00003_ooool2o`0001Sooooo0_l00006
ooooo`?o00001?ooool2o`0007[ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ
8B44ooooo`Go00001_ooool00ol0003oooooooooo`1aooooo`;o00001_ooool2o`0000Cooooo0_l0
000<ooooo`;o00000oooool2o`0001;ooooo0_l00004ooooo`;o00004?ooool2o`0000Oooooo0_l0
00000ooooooo0000o`00001mooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q
1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0LOooool2o`0000Ko
oooo1?l0000Iooooo`;o00003_ooool2o`0000;ooooo1?l00002ooooo`;o00001Oooool2o`00017o
oooo0_l000000ooooooo0000o`00001jooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooo
ooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0MOooool2o`0000Cooooo
0_l0000>ooooo`;o00002Oooool2o`0001;ooooo0_l00002ooooo`Co00001Oooool2o`0000Cooooo
0_l0000>ooooo`;o0000N_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02ooo
ool00onHV9So8B4Qonk^kP06ooooo`?o0000J?ooool2o`0000_ooooo0_l0000Dooooo`;o00003Ooo
ool2o`0001;ooooo0_l00008ooooo`;o00000oooool2o`0001?ooooo0_l00006ooooo`;o0000KOoo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`05
ooooo`03o`000?oooooooooo06Sooooo0_l0000Mooooo`;o00003_ooool2o`000003ooooool0003o
000001cooooo1?l0000Fooooo`;o00001_ooool2o`0006gooooo00000ooooooo410@ooooo`02oooo
o`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1aoooo
o`;o00005?ooool2o`0000kooooo0_l00002ooooo`;o00003_ooool2o`0000gooooo0_l0002=oooo
o`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_oo
ool00ol0003oooooooooo`1Zooooo`;o000000?oooooo`000?l000000_ooool2o`0002;ooooo0_l0
00000ooooooo0000o`000003o`0000kooooo0_l00002ooooo`;o00000_ooool4o`0000gooooo0_l0
0023ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`01_ooool00ol0003oooooooooo`1Zooooo`;o000000?oooooo`000?l000001Ol0000Pooooo`?o
000000Coooooo`000?l0003o00004?ooool2o`0000;ooooo0_l000000ooooooo0000o`000003o`00
00;ooooo0_l00009ooooo`;o000000Coooooo`000?l0003o00003?ooool2o`00077ooooo000Loooo
o`03o`000?oooooooooo06Wooooo0_l00004ooooo`Ko00005Oooool2o`0000Sooooo0_l00003oooo
o`;o00001_ooool2o`0000Sooooo0_l00005ooooo`;o00001Oooool2o`0000_ooooo1?l00007oooo
o`;o00000oooool2o`0000;ooooo0_l0001]ooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o
00001oooool2o`0000Kooooo1?l0000@ooooo`;o00000oooool4o`0000Wooooo0_l00008ooooo`;o
00002?ooool2o`0000[ooooo1?l00002ooooo`;o00001oooool4o`0000Oooooo0_l00007ooooo`?o
0000K?ooool001cooooo00?o0000ooooooooool0H?ooool2o`0000oooooo0_l0000Booooo`Go0000
0_ooool2o`0000Wooooo0ol0000Aooooo`;o00002_ooool2o`0000Cooooo1?l0000:ooooo`;o0000
3_ooool2o`0000Oooooo0_l0001Sooooo`007?ooool00ol0003oooooooooo`1iooooo`;o00002ooo
ool4o`0000Gooooo0_l00007ooooo`Co00003?ooool4o`0000Cooooo0_l0000=ooooo`;o00000ooo
ool2o`0000Gooooo0_l0000Aooooo`;o00001?ooool2o`0006?ooooo000Looooo`03o`000?oooooo
oooo07Wooooo0_l00009ooooo`?o00002?ooool2o`0000Wooooo0ol0000;ooooo`Go00000oooool2
o`0000Cooooo0_l0000<ooooo`;o00006?ooool2o`0006Wooooo000Looooo`03o`000?oooooooooo
04cooooo0_l0000Uooooo`;o00001Oooool3o`0000Gooooo1Ol000001?oooooo0000o`000?l0000;
ooooo`;o00000oooool2o`0000_ooooo0_l000000ooooooo0000o`000009ooooo`?o00001oooool2
o`0000;ooooo0_l0000Jooooo`;o0000Ioooool001cooooo00?o0000ooooooooool0C?ooool2o`00
01gooooo0_l00006ooooo`;o00001Oooool3o`000005ooooool0003o0000o`000?ooool00_l00004
ooooo`?o00002oooool2o`0000;ooooo0ol0000?ooooo`;o00002Oooool2o`0000Oooooo0_l00002
ooooo`;o00006_ooool2o`0006Oooooo000Looooo`03o`000?oooooooooo06Sooooo0_l000001?oo
oooo0000o`000?ooool2o`0000Sooooo0_l00004ooooo`?o00002Oooool2o`0000Sooooo0_l00004
ooooo`?o00003oooool2o`000003ooooool0003o000000;ooooo0_l00008ooooo`?o0000ROooool0
01cooooo00?o0000ooooooooool0J?ooool2o`000004ooooool0003o0000ooooo`;o00002?ooool2
o`00013ooooo1?l00006ooooo`;o00001Oooool2o`0000Wooooo0_l00006ooooo`Co000000?ooooo
o`000?l000002?ooool4o`0000Kooooo0_l00003ooooo`;o0000Noooool001cooooo00?o0000oooo
ooooool0Joooool2o`0000_ooooo0_l0000Booooo`;o00001oooool3o`0000kooooo1?l00004oooo
o`Co00002oooool4o`0000Kooooo0ol00002ooooo`;o0000Noooool001cooooo00?o0000oooooooo
ool0F?ooool2o`0001oooooo1?l00002ooooo`;o00004Oooool2o`000004ooooool0003o0000o`00
00gooooo0_l000000ooooooo0000o`00000Cooooo`;o00002Oooool2o`0000Wooooo0_l0000Doooo
o`;o0000G_ooool001cooooo0_l0001Iooooo`;o00002_ooool2o`0001;ooooo1Ol00002ooooo`;o
00004Oooool2o`00017ooooo0_l00005ooooo`;o00009Oooool4o`0001;ooooo0_l0001Nooooo`00
7?ooool00ol0003oooooooooo`1Tooooo`?o00001Oooool2o`0000[ooooo0_l00007ooooo`;o0000
3Oooool2o`0000Cooooo0_l0000Dooooo`;o00002oooool3o`0000_ooooo0_l00006ooooo`;o0000
1?ooool3o`000003ooooool0003o000006kooooo000Looooo`03o`000?oooooooooo06Gooooo0_l0
0004ooooo`?o00002_ooool3o`0000Kooooo0_l0000=ooooo`;o00001?ooool2o`0000oooooo0_l0
00000ooooooo0000o`000006ooooo`;o00001Oooool3o`0000_ooooo0_l00005ooooo`?o00000ooo
ool4o`000003ooooool0003o000006kooooo000Looooo`03o`000?oooooooooo04?ooooo0_l0000V
ooooo`;o00002oooool3o`0001oooooo0_l00007ooooo`;o00000_ooool2o`000003ooooool0003o
000000Kooooo0_l00004ooooo`?o00001oooool4o`0000;ooooo0ol00003ooooo`;o00001?ooool2
o`0007?ooooo000Looooo`03o`000?oooooooooo04?ooooo0_l0000Iooooo`;o00003Oooool2o`00
013ooooo0_l0000Iooooo`;o00001oooool2o`0000Sooooo1?l00007ooooo`;o00001_ooool6o`00
00;ooooo0ol0000>ooooo`;o0000K_ooool001cooooo00?o0000ooooooooool0Foooool2o`000003
ooooool0003o000000Kooooo0_l00003ooooo`Co00002oooool2o`0000?ooooo0_l0000Hooooo`;o
00004_ooool4o`0000Gooooo0_l00008ooooo`;o00000_ooool2o`0000;ooooo0_l0000?ooooo`;o
00004?ooool4o`0005[ooooo000Looooo`03o`000?oooooooooo05_ooooo0_l00009ooooo`;o0000
0_ooool4o`0000cooooo1ol0000@ooooo`;o00001Oooool3o`0000Gooooo0_l00008ooooo`?o0000
1Oooool3o`000003ooooool0003o000000cooooo0_l00002ooooo`;o00001oooool2o`0001Sooooo
1?l0001Jooooo`007?ooool00ol0003oooooooooo`1Yooooo`?o00003_ooool6o`0000Cooooo1?l0
0008ooooo`?o00001?ooool4o`0000Gooooo0_l00008ooooo`?o000000?oooooo`000?l000000_oo
ool3o`0000cooooo0_l00004ooooo`;o00002?ooool2o`00013ooooo0_l00007ooooo`;o0000Fooo
ool001cooooo00?o0000ooooooooool0JOooool2o`0000[ooooo0_l00005ooooo`;o000000?ooooo
o`000?l000000oooool4o`0000Sooooo0ol00004ooooo`Co00003?ooool2o`000003ooooool0003o
000000Go00004?ooool3o`0000;ooooo1Ol000001Ooooooo0000o`000?l0003ooooo00Co000000?o
ooooo`000?l000003?ooool2o`0000Oooooo0_l00007ooooo`;o0000D_ooool001cooooo00?o0000
ooooooooool0?_ooool2o`0002Wooooo0ol00009ooooo`;o00001Oooool2o`000003ooooool0003o
000000_ooooo0_l00004ooooo`;o00004oooool2o`0000?ooooo1Ol00002ooooo`;o00002_ooool2
o`000003ooooool0003o000000Co000000?oooooo`000?l000001?l000000ooooooo0000o`000002
o`000003ooooool0003o000000kooooo0_l0000>ooooo`;o0000D_ooool001cooooo00?o0000oooo
ooooool0?_ooool2o`0001[ooooo0_l00006ooooo`?o00001?ooool3o`0000Wooooo0_l00002oooo
o`Co00000_ooool2o`0000Wooooo1?l00004ooooo`;o00002Oooool2o`0000cooooo0_l000000ooo
oooo0000o`000002ooooo`?o00002_ooool2o`0000;ooooo0ol00003ooooo`Co00001?ooool2o`00
01;ooooo0_l0001Rooooo`007?ooool00ol0003oooooooooo`1Jooooo`;o00001_ooool5o`0000;o
oooo0_l0000>ooooo`Co00000_ooool2o`0000Wooooo0_l0000Aooooo`;o00000_ooool2o`0000;o
oooo0ol000000ooooooo0000o`000005o`000004ooooool0003o0000o`0000Wooooo1?l00008oooo
o`Co00001?ooool2o`000003ooooool0003o000000_ooooo0_l000000ooooooo0000o`00001Soooo
o`007?ooool00ol0003oooooooooo`1Sooooo`Co00001?ooool2o`0001;ooooo0_l00009ooooo`;o
00004?ooool2o`0000?ooooo4_l0000:ooooo`;o00001?ooool3o`0000kooooo1?l000000ooooooo
0000o`000006ooooo`;o000000?oooooo`000?l000006Oooool2o`0004Sooooo000Looooo`03o`00
0?oooooooooo06?ooooo0_l00006ooooo`;o00001?ooool2o`0000[ooooo0_l00003ooooo`;o0000
1oooool2o`0000Sooooo0_l00003ooooo`Go00000_oooolCo`0000Kooooo0_l00002ooooo`So0000
2oooool2o`0000?ooooo0_l000000ooooooo0000o`00000Tooooo`;o0000B?ooool001cooooo00?o
0000ooooooooool0F?ooool2o`0000Cooooo0_l0000Aooooo`;o00002_ooool2o`0000?ooooo0_l0
0007ooooo`?o00001oooool2o`0000;ooooo1_l00002ooooo`;o000000?oooooo`000?l000004?l0
0004ooooo`;o00000_ooool8o`0000?ooooo0_l00006ooooo`;o00002_ooool5o`0000Gooooo0_l0
0009ooooo`;o0000EOooool001cooooo00?o0000ooooooooool0F?ooool2o`0000Cooooo0_l0000A
ooooo`Co00000oooool2o`0000cooooo0_l00003ooooo`?o00001Oooool2o`0000Cooooo1?l00002
oooooaco00003_ooool2o`0000_ooooo0_l00002ooooo`;o000000?oooooo`000?l000001Ol00003
ooooo`;o00002Oooool2o`0005Gooooo000Looooo`;o0000>?ooool2o`0002;ooooo0_l000000ooo
oooo0000o`00000Aooooo`Ko000000Coooooo`000?l0003o00000oooool2o`0000?ooooo0_l00000
0ooooooo0000o`000002o`0000Gooooo0_l00002ooooo`;o00002_oooolLo`00013ooooo0_l00006
ooooo`;o000000?oooooo`000?l000001?l00006ooooo`;o0000IOooool001cooooo00?o0000oooo
ooooool0=oooool2o`0002;ooooo0_l000000ooooooo0000o`000003o`0000;ooooo0_l0000=oooo
o`?o00000_ooool3o`0000;ooooo0_l00003ooooo`;o00000oooool2o`0000Gooooo0_l00003oooo
o`;o000000?oooooo`000?l000000_oooolNo`0000Kooooo1?l00008ooooo`;o00001_ooool2o`00
00?ooooo1?l00008ooooo`;o0000Hoooool001cooooo00?o0000ooooooooool0Doooool2o`0000_o
oooo0ol00002ooooo`;o00004?ooool2o`000003ooooool0003o000000Sooooo0_l0000>ooooo`;o
000000?oooooo`000?l000000_ooool5o`000003ooooool0003o0000017o000000?oooooo`000?l0
00000_l00003ooooo`;o000000?oooooo`000?l000001?l0000Oooooo`Co00001_ooool2o`0005Wo
oooo000Looooo`03o`000?oooooooooo05;ooooo0ol0000;ooooo`;o000000?oooooo`000?l00000
4_ooool2o`0000Sooooo1Ol00004ooooo`Co00002?ooool2o`000003ooooool0003o000000?ooooo
0_l000000ooooooo0000o`00000Eo`0000Cooooo1?l00003ooooo`;o00004_ooool2o`0000Cooooo
0_l00002ooooo`;o00000oooool2o`0000Kooooo0_l0001Iooooo`007?ooool00ol0003ooooooooo
o`1Booooo`;o00003oooool2o`0000Kooooo0_l00009ooooo`;o00001_ooool2o`000003ooooool0
003o000000;o000000?oooooo`000?l000000_ooool4o`0000Oooooo1_l000000ooooooo0000o`00
000Jo`0000Kooooo0_l0000<ooooo`?o000000?oooooo`000?l000001Oooool2o`0000Cooooo0_l0
0002ooooo`;o00001Oooool2o`0000;ooooo0_l00002ooooo`;o00002?ooool2o`0004gooooo000L
ooooo`03o`000?oooooooooo05[ooooo1?l00006ooooo`;o00001Oooool2o`0000Oooooo1?l00006
ooooo`;o00001_ooool2o`0000?ooooo0ol000000ooooooo0000o`000004ooooo`;o000000?ooooo
o`000?l000007_l0000Dooooo`?o000000?oooooo`000?l000005_ooool2o`0000;ooooo0_l00002
ooooo`;o00002?ooool2o`0004gooooo000Looooo`03o`000?oooooooooo05[ooooo1?l00006oooo
o`;o00001Oooool2o`0000Kooooo1Ol0000<ooooo`;o00002Oooool5o`000004ooooool0003o0000
ooooob7o00004?ooool2o`00017ooooo0_l0001[ooooo`007?ooool00ol0003oooooooooo`0aoooo
o`;o0000:?ooool4o`0000Wooooo0_l00003ooooo`;o00001?ooool2o`0000Kooooo0_l00007oooo
o`;o00002oooool3o`000004ooooool0003o0000oooooa_o000000?oooooo`000?l000000ol0000<
ooooo`;o00000_ooool2o`0000Oooooo0_l00008ooooo`;o00000_ooool2o`0000Cooooo0_l0000;
ooooo`;o0000E?ooool001cooooo00?o0000ooooooooool0<Oooool2o`0001Wooooo0_l0000=oooo
o`Co00001Oooool2o`0000;ooooo0_l00003ooooo`;o00001?ooool2o`0000Kooooo0_l0000:oooo
o`;o00000_ooool4o`000003ooooool0003o000000Wooooo6?l000000ooooooo0000o`000003o`00
00cooooo0_l0000;ooooo`;o00003?ooool2o`0000Cooooo0_l00008ooooo`;o000000Coooooo`00
0?l0003o0000Doooool001cooooo00?o0000ooooooooool0AOooool2o`0000Gooooo0_l0000Aoooo
o`;o00000oooool5o`0000Cooooo0_l00004ooooo`;o00001_ooool2o`0000[ooooo0_l00002oooo
o`Co000000?oooooo`000?l000000_l00004ooooo`;o00000_oooolGo`000004ooooool0003o0000
o`0003Wooooo0_l00002ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0AOooool3o`00
00;ooooo0_l0000Cooooo`;o00001Oooool3o`0000Cooooo0_l0000;ooooo`?o00003_ooool2o`00
00Cooooo0ol000001?oooooo0000o`000?ooool2o`0000;ooooo7?l0000@ooooo`;o00009_ooool2
o`0005Oooooo000Looooo`03o`000?oooooooooo04Kooooo0_l00002ooooo`;o00008oooool2o`00
00Wooooo0ol0000;ooooo`;o000000Coooooo`000?l0003o00001oooool2o`000003ooooool0003o
000000Co000000?oooooo`000?l000006_l00004ooooo`;o00001oooool2o`00023ooooo0_l00004
ooooo`;o00004Oooool2o`0004Cooooo000Looooo`03o`000?oooooooooo06oooooo0_l00009oooo
o`?o00001_ooool2o`0000?ooooo0ol000001?oooooo0000o`000?l00002ooooo`Go000000?ooooo
o`000?l000001Ol000000ooooooo0000o`00000Jo`0000Cooooo0_l0000Yooooo`;o00001_ooool2
o`0000oooooo0_l000000ooooooo0000o`000011ooooo`007?ooool00ol0003oooooooooo`17oooo
o`;o00003?ooool2o`0000cooooo0_l00002ooooo`;o00001?ooool4o`0000Wooooo0ol00004oooo
o`Co00000oooool3o`0000;ooooo0_l00002ooooo`_o00000ooooolMo`000003ooooool0003o0000
00?ooooo0_l0000^ooooo`;o00001?ooool2o`0000cooooo0_l00011ooooo`007?ooool00ol0003o
ooooooooo`17ooooo`;o00000oooool2o`0000Oooooo0ol0000;ooooo`;o00000_ooool2o`0000Co
oooo1?l00009ooooo`?o00001?ooool2o`000003ooooool0003o000000;ooooo0ol0000:ooooo`?o
000000Coooooo`000?l0003o00000_oooolHo`000003ooooool0003o000000?o000000?oooooo`00
0?l000000oooool2o`0003Cooooo0_l0000<ooooo`;o0000@Oooool001cooooo00?o0000oooooooo
ool0BOooool2o`000003ooooool0003o000000Gooooo0_l000000ooooooo0000o`000006ooooo`;o
00002Oooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000001?ooool5o`000003
ooooool0003o000000;ooooo0_l000000ooooooo0000o`00000<ooooo`;o00000_ooool>o`000005
ooooool0003o0000o`000?ooool02Ol00002ooooo`;o00001_ooool2o`0003Kooooo0_l0000=oooo
o`;o0000@Oooool001cooooo0_l0001:ooooo`Co00001?ooool4o`0000Wooooo0_l00009ooooo`?o
000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000Oooooo0_l000000ooooooo
0000o`000005ooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000?o
oooo4ol000000ooooooo0000o`000006o`0000?ooooo0_l00006ooooo`;o00004Oooool2o`0001oo
oooo0_l00002ooooo`;o00003Oooool2o`00047ooooo000Looooo`03o`000?oooooooooo04_ooooo
1Ol000000ooooooo0000o`000007ooooo`;o00000_ooool2o`0000Wooooo0ol0000;ooooo`;o0000
3_ooool2o`000004ooooool0003o0000o`0000?ooooo1Ol00003ooooo`Co000000?oooooo`000?l0
00005Ol00003ooooo`;o00002_ooool2o`0000Oooooo0_l00004ooooo`;o00007oooool2o`0001Go
oooo0_l0000mooooo`007?ooool00ol0003oooooooooo`17ooooo`?o00000oooool3o`0000Wooooo
0ol00002ooooo`;o00003Oooool4o`0000Kooooo0_l00002ooooo`?o00002?ooool4o`000004oooo
ool0003o0000ooooo`;o00000_ooool2o`0000Gooooo1Ol000000ooooooo0000o`00000Co`0000co
oooo0_l000001?oooooo0000o`000?l00006ooooo`;o00001Oooool2o`0001gooooo0_l00003oooo
o`;o00004Oooool2o`0003gooooo000Looooo`03o`000?oooooooooo04Cooooo0_l000001?oooooo
0000o`000?l00003ooooo`;o00001?ooool8o`0001;ooooo1?l000000ooooooo0000o`000002o`00
00Gooooo0ol00008ooooo`Co00001?ooool3o`0000[ooooo0ol00004ooooo`;o000000?oooooo`00
0?l000003Ol00003ooooo`?o00001_ooool2o`0000;ooooo0_l0000=ooooo`;o00007Oooool2o`00
00?ooooo0_l00002ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0A?ooool2o`0000So
oooo0_l00002ooooo`_o00001?ooool2o`0000oooooo1?l00007ooooo`;o00001_ooool8o`0000;o
oooo0_l0000Aooooo`;o000000?oooooo`000?l000003_l00002ooooo`?o00006Oooool2o`0002Co
oooo1?l0001<ooooo`007?ooool00ol0003oooooooooo`0Wooooo`;o00009Oooool2o`0000;ooooo
2ol00004ooooo`;o00006_ooool2o`0000Kooooo2?l00004ooooo`;o00003ooooolFo`0003cooooo
0_l00003ooooo`;o000000?oooooo`000?l00000Boooool001cooooo00?o0000ooooooooool09ooo
ool2o`0001_ooooo0_l0000:ooooo`ko00001_ooool4o`0000Oooooo0_l00002ooooo`;o00005_oo
ool2o`0000Cooooo0_l0000;ooooo`;o00000oooool:o`000003ooooool0003o000000?o000000?o
ooooo`000?l000000_l0000looooo`?o00001Oooool2o`0004_ooooo000Looooo`03o`000?oooooo
oooo03Oooooo0_l0000;ooooo`;o00002_ooool?o`0000Gooooo1?l00007ooooo`;o00000_ooool2
o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`000004ooooool0003o0000o`0000gooooo0_l0
00000ooooooo0000o`00000Co`0000?ooooo0_l0000<ooooo`;o00000_ooool2o`0002_ooooo0_l0
00000ooooooo0000o`00001?ooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00005_ooool9
o`000003ooooool0003o000000Go00001?ooool6o`0000Oooooo0_l00007ooooo`;o00001Oooool2
o`0000Gooooo0_l00002ooooo`Co00001oooool2o`0000;ooooo0_l00003ooooo`?o00000oooool3
o`000003ooooool0003o000000[o00001Oooool2o`0000Oooooo0_l00002ooooo`;o000000?ooooo
o`000?l000002?ooool2o`00027ooooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`16oooo
o`;o00001ooooolAo`0000;ooooo1?l00002ooooo`;o00001oooool2o`0000kooooo0_l00005oooo
o`;o00001?ooool2o`000003ooooool0003o000000;o00000_ooool2o`0000Kooooo0_l00006oooo
o`;o00001_ooool3o`000003ooooool0003o000000;o000000Coooooo`000?l0003ooooo0_l0000>
ooooo`?o00001oooool2o`0002Kooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`14oooo
o`Co00002Oooool:o`000003ooooool0003o000000?o000000?oooooo`000?l000000_l0000>oooo
o`;o000000Goooooo`000?l0003o0000ooooo`02o`0000Oooooo0_l00002ooooo`Co00000_ooool2
o`000003ooooool0003o000000;o00002_ooool3o`0000;ooooo0_l00003ooooo`Co00001oooool3
o`000003ooooool0003o000000oooooo0_l000000ooooooo0000o`00000_ooooo`;o0000B_ooool0
01cooooo00?o0000ooooooooool0A?ooool2o`0000Sooooo3Ol000000ooooooo0000o`000003o`00
00;ooooo0ol0000:ooooo`;o00000_ooool2o`000003ooooool0003o000000Co00001oooool2o`00
00;ooooo1?l00002ooooo`;o00001_ooool2o`0000Sooooo0_l00002ooooo`;o00000oooool4o`00
00Oooooo0_l00004ooooo`;o00003Oooool2o`000003ooooool0003o000000Oooooo0_l0001boooo
o`007?ooool00ol0003oooooooooo`12ooooo`Co00002?oooolBo`0000?ooooo0_l0000;ooooo`Co
00001Oooool2o`0000Wooooo0ol000000ooooooo0000o`00000<ooooo`Go00003?ooool5o`0000Ko
oooo1?l00004ooooo`;o00004?ooool2o`0000Gooooo1?l0000Uooooo`?o00003?ooool2o`0003co
oooo000Looooo`03o`000?oooooooooo04;ooooo0ol0000<ooooo`ko00001_ooool2o`0000_ooooo
0_l00003ooooo`;o00000oooool3o`0000Kooooo0_l0000@ooooo`Co00003?ooool2o`000003oooo
ool0003o000000Kooooo0ol0000Nooooo`;o00006Oooool2o`0000cooooo0ol0000<ooooo`;o0000
??ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413o
ooooooooo`04ooooo`03o`000?oooooooooo027ooooo0_l0000Pooooo`;o00003Oooool2o`000003
ooooool0003o000000So00001_ooool2o`0000Oooooo0_l00007ooooo`;o00000oooool3o`0000;o
oooo0ol00002ooooo`?o00000_ooool4o`0001Cooooo0_l00003ooooo`;o00002Oooool2o`000003
ooooool0003o000003Kooooo1?l00009ooooo`;o0000C?ooool00006oooooomgMgOoV9RHoooooonH
V9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Qoooo
o`;o00007oooool2o`0000oooooo0_l000000ooooooo0000o`000008o`0000kooooo0_l0000Aoooo
o`?o00000_ooool3o`0000;ooooo1_l0000;ooooo`?o00000_ooool4o`0000?ooooo0ol000000ooo
oooo0000o`000008ooooo`Co0000=_ooool2o`0000Wooooo1?l0001:ooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`09ooooo`Go00001_ooool00ol0003oooooooooo`12ooooo`;o
00002_ooool2o`0000?ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00000_ooool2o`00
01cooooo0_l0000?ooooo`Co00002oooool4o`000003ooooool0003o000000Co00000_ooool2o`00
0003ooooool0003o000000[ooooo1?l00011ooooo`;o00003oooool2o`0003Wooooo00000ooooooo
0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`00
03Wooooo0_l00004ooooo`;o00002_ooool5o`0000Kooooo0ol0000<ooooo`?o00004Oooool2o`00
0003ooooool0003o0000023ooooo0_l00003ooooo`Co00004oooool2o`0000[ooooo0_l0000Roooo
o`;o00004oooool2o`0000gooooo0_l0000iooooo`0000?oooooo`000?ooool00_ooool00ol0003o
ooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0>Oooool2o`00
00Cooooo0_l0000:ooooo`Go00002oooool2o`0000Sooooo0ol00008ooooo`;o00001oooool6o`00
01cooooo0_l0000Rooooo`?o00001?ooool2o`000003ooooool0003o000000Gooooo0ol00003oooo
o`;o00004_ooool2o`0000cooooo0_l00003ooooo`Co0000B?ooool00003ooooool@413ooooo00;o
oooo00?o410@ooooooooool02_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo03_o
oooo0ol0000=ooooo`;o00002_ooool2o`000004ooooool0003o0000o`0000?ooooo0_l00005oooo
o`;o00001oooool2o`0000Cooooo0_l00003ooooo`Co00002?ooool2o`0000Cooooo1?l0000:oooo
o`;o00005?ooool2o`0000Sooooo0_l00002ooooo`Go000000?oooooo`000?l000000_ooool2o`00
00Gooooo0ol00003ooooo`;o00007_ooool4o`0000?ooooo0_l0001:ooooo`0000KoooooogMgMonH
V9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0>oooool3
o`0000Wooooo1?l0000<ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Gooooo0ol0000<
ooooo`;o00003oooool2o`0000Cooooo1?l00002ooooo`;o00001_ooool4o`0000Oooooo0_l00008
ooooo`?o00000oooool2o`0000?ooooo0_l00002ooooo`Go000000?oooooo`000?l00000;oooool2
o`0001Kooooo0_l0000iooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0
003ooooo00Kooooo00?o0000ooooooooool0>oooool3o`0000Wooooo1?l0000Mooooo`;o00000ooo
ool2o`0001;ooooo1Ol0000=ooooo`;o00002?ooool2o`0000Oooooo0_l00002ooooo`Co00000_oo
ool3o`0000?ooooo0_l00004ooooo`;o000000Coooooo`000?l0003o00000oooool2o`0001Oooooo
0_l0000@ooooo`;o00003?ooool2o`0000kooooo0_l00004ooooo`;o0000<oooool001cooooo00?o
0000ooooooooool0KOooool2o`0000Oooooo0_l00009ooooo`Go00007Oooool2o`0000Gooooo1?l0
0003ooooo`;o000000?oooooo`000?l000001_ooool4o`0000;ooooo0_l00007ooooo`;o00002Ooo
ool2o`000003ooooool0003o000000?ooooo0_l0000?ooooo`?o00002oooool3o`0000oooooo0_l0
0003ooooo`;o0000<oooool001cooooo00?o0000ooooooooool0;oooool2o`0000gooooo0_l0000F
ooooo`;o00002?ooool2o`000003ooooool0003o000000Oooooo0ol00002ooooo`Oo000000?ooooo
o`000?l000000ol00006ooooo`;o00001oooool4o`0001;ooooo0_l0000?ooooo`;o00002?ooool2
o`0000;ooooo0_l00007ooooo`;o00002Oooool8o`0000?ooooo0_l00007ooooo`?o00000_ooool2
o`0000cooooo0_l000000ooooooo0000o`00000=ooooo`;o0000>?ooool001cooooo00?o0000oooo
ooooool0;oooool2o`0000gooooo1?l0000Dooooo`;o00002?ooool2o`000003ooooool0003o0000
00Oooooo4_l00006ooooo`;o00001oooool4o`0001Sooooo0_l00009ooooo`;o00007Oooool2o`00
00;ooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l00007ooooo`?o00000_ooool2o`00
0004ooooool0003o0000o`0000;ooooo0_l00007ooooo`;o0000Aoooool001cooooo00?o0000oooo
ooooool07?ooool2o`0002;ooooo0_l0000>ooooo`;o00007?ooool3o`000003ooooool0003o0000
00go00000_ooool2o`0000Wooooo0ol0000Hooooo`;o00002Oooool2o`0000Gooooo0_l0000Foooo
o`;o00000oooool4o`0000[ooooo0_l0000:ooooo`?o00000_ooool5o`0000?ooooo0_l00018oooo
o`007?ooool00ol0003oooooooooo`0Looooo`;o00008_ooool2o`0000kooooo0_l0000Hooooo`;o
000000?oooooo`000?l000000_l000000ooooooo0000o`000008o`000003ooooool0003o000000;o
00000_ooool2o`000003ooooool0003o000000Oooooo0_l0000Eooooo`;o00002?ooool2o`0000Wo
oooo1?l00008ooooo`?o00003_ooool2o`0000Cooooo0_l00006ooooo`;o00002_ooool2o`0000;o
oooo0_l000001?oooooo0000o`000?l00003ooooo`;o0000B?ooool001cooooo00?o0000oooooooo
ool0@?ooool2o`0000Wooooo0_l0000Mooooo`;o000000?oooooo`000?l000000_l000000ooooooo
0000o`000004o`000003ooooool0003o000000So00000oooool2o`0001kooooo0ol00003ooooo`;o
00000_ooool2o`0000_ooooo0_l00008ooooo`?o00000_ooool4o`0000kooooo1?l0000@ooooo`?o
000000Coooooo`000?l0003o0000D?ooool001cooooo00?o0000ooooooooool0Boooool2o`0001Oo
oooo0_l0000:oooooa?o00000_ooool2o`00023ooooo0_l00003ooooo`?o000000?oooooo`000?l0
00005_ooool8o`0000Gooooo0ol00003ooooo`;o00000oooool2o`0000Kooooo0_l00005ooooo`;o
00000_ooool6o`0000Wooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o0000
5oooool2o`0000[ooooo4_l00003ooooo`;o00002Oooool2o`0001[ooooo0ol00009ooooo`;o0000
1oooool4o`0000;ooooo1_l00003ooooo`;o00000oooool3o`0000?ooooo0_l000000ooooooo0000
o`000002o`0000Cooooo1?l00002ooooo`;o000000?oooooo`000?l000000_ooool4o`0000;ooooo
0_l00002ooooo`;o00000oooool2o`0004Gooooo000Looooo`03o`000?oooooooooo01cooooo0_l0
000Fooooo`;o00000oooool2o`0002[ooooo0_l00006oooooaGo00002_ooool2o`0000;ooooo0ol0
0006ooooo`;o00000_ooool2o`0000Cooooo1Ol0000;ooooo`;o00000oooool2o`0000?ooooo0_l0
00000ooooooo0000o`000007o`0000Oooooo0_l00004ooooo`;o00001_ooool2o`0000Kooooo0_l0
0003ooooo`?o00001Oooool3o`0000?ooooo0_l00002ooooo`?o0000BOooool001cooooo00?o0000
ooooooooool07?ooool2o`0001Kooooo0_l00003ooooo`;o0000:_ooool2o`0000;ooooo3?l00000
0ooooooo0000o`00000;o`0000Wooooo0_l00003ooooo`;o00001_ooool2o`0000;ooooo0_l00004
ooooo`Go00002oooool2o`0000;ooooo0_l00003ooooo`?o000000?oooooo`000?l000003Ol0000E
ooooo`;o00001Oooool3o`000003ooooool0003o000000?ooooo0_l00007ooooo`?o00000oooool2
o`0004Cooooo000Looooo`03o`000?oooooooooo037ooooo0_l0000Gooooo`;o00002?ooool2o`00
01?ooooo3?l000000ooooooo0000o`00000;o`0000Wooooo0_l00006ooooo`;o00003?ooool2o`00
00Gooooo0_l00003ooooo`;o00001oooool2o`0000?ooooo1?l00003ooooo`Co000000?oooooo`00
0?l000002Ol00004ooooo`Co00002Oooool2o`0000Kooooo0_l000000ooooooo0000o`000003oooo
o`;o00001oooool3o`0000?ooooo0_l00014ooooo`007?ooool2o`0003;ooooo0_l0000<ooooo`;o
00002Oooool2o`0000Sooooo0_l0000FoooooaKo00004Oooool3o`0000cooooo0_l00005ooooo`;o
00000oooool2o`000004ooooool0003o0000o`0000Gooooo2Ol000000ooooooo0000o`000004oooo
o`Go000000?oooooo`000?l000001Ol000000ooooooo0000o`000002o`0000kooooo1?l0000Foooo
o`;o0000A?ooool001cooooo00?o0000ooooooooool06oooool2o`0001Cooooo0_l000000ooooooo
0000o`000009ooooo`;o00003Oooool2o`0001_ooooo6_l0000>ooooo`;o00004_ooool4o`0000Go
oooo1?l00005ooooo`?o000000?oooooo`000?l000000ol00003ooooo`Ko000000?oooooo`000?l0
00003?l0000:ooooo`;o00000oooool4o`0001Kooooo0_l00014ooooo`007?ooool00ol0003ooooo
ooooo`0Kooooo`;o00004oooool2o`0000;ooooo0_l00002ooooo`;o00002?ooool2o`0000[ooooo
0_l00009ooooo`Co00002?ooool2o`0000Cooooo6_l0000<ooooo`;o00004oooool6o`0000Cooooo
0_l0000<ooooo`?o00001?ooool?o`0000;ooooo1?l000000ooooooo0000o`000007ooooo`;o0000
2Oooool2o`0000Cooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00001_oo
ool2o`0000Sooooo0_l0000Eooooo`Ko00001_ooool2o`0000Gooooo7?l00009ooooo`;o00001_oo
ool4o`0000Wooooo0_l00002ooooo`;o00001oooool2o`0000Sooooo1?l00002ooooo`;o00000ooo
ool:o`0000Kooooo0_l000000ooooooo0000o`000005ooooo`;o00000oooool2o`0000Kooooo0_l0
0004ooooo`;o00003?ooool2o`0004Cooooo000Looooo`03o`000?oooooooooo05_ooooo1?l00009
ooooob3o00004Oooool4o`0000Gooooo0_l0000:ooooo`;o00000oooool2o`0000Gooooo0_l00000
0ooooooo0000o`000002o`000003ooooool0003o000000;o00000_ooool:o`0000Gooooo1?l00007
ooooo`;o00000oooool3o`0000Gooooo0_l00004ooooo`;o00003?ooool2o`0000Kooooo0_l00004
ooooo`;o0000=_ooool001cooooo00?o0000ooooooooool0B_ooool2o`0000oooooo0_l0000;oooo
oaWo000000?oooooo`000?l000001?l0000:ooooo`;o00003_ooool2o`0000[ooooo0_l00003oooo
o`;o00001?ooool5o`0000?ooooo4_l00002ooooo`[o00002Oooool2o`0000;ooooo0_l00006oooo
o`;o00003Oooool2o`0000Kooooo0_l00004ooooo`;o000000?oooooo`000?l00000<oooool001co
oooo00?o0000ooooooooool0;oooool4o`0001Oooooo0_l0000:ooooo`;o00001oooool3o`0000Go
oooo7_l000000ooooooo0000o`000005ooooo`;o00000oooool2o`0001kooooo0_l000000ooooooo
0000o`000002ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000008o`000003
ooooool0003o000000co000000?oooooo`000?l000000_l0000=ooooo`;o00001_ooool2o`0000go
oooo0_l00007ooooo`;o00001_ooool2o`0003?ooooo000Looooo`03o`000?oooooooooo01[ooooo
0_l0000Cooooo`Co00003_ooool2o`0000Kooooo0_l0000;ooooo`;o00001oooool3o`0000Gooooo
7_l00008ooooo`;o00000_ooool3o`0000Wooooo0_l00004ooooo`;o00003Oooool5o`0000;ooooo
1ol00002oooooa?o000000Coooooo`000?l0003o00001?ooool2o`0001Gooooo0_l0000Fooooo`;o
00000_ooool2o`0003Oooooo000Looooo`03o`000?oooooooooo01[ooooo0_l0000Uooooo`;o0000
1_ooool2o`0000gooooo0_l00006ooooo`;o00002_oooolIo`0000cooooo0ol000000ooooooo0000
o`000003ooooo`Go00001?ooool2o`000003ooooool0003o000000Gooooo0_l00003ooooo`Co0000
0_ooool4o`0000;ooooo7?l0000Jooooo`;o00005_ooool2o`0000;ooooo0_l0000gooooo`007?oo
ool00ol0003oooooooooo`0oooooo`;o00005oooool2o`0000Kooooo0_l0000:oooooa[o00002?oo
ool2o`000003ooooool0003o000000Co00000oooool4o`0000Sooooo0_l00005ooooo`;o00000_oo
ool6o`000005ooooool0003o0000o`000?ooool01_l000000ooooooo0000o`00000Eo`000003oooo
ool0003o000001Cooooo1Ol00009ooooo`;o00003oooool2o`0003Oooooo000Looooo`03o`000?oo
oooooooo03oooooo0_l0000/oooooa7o000000?oooooo`000?l000001Ol00008ooooo`;o00000_oo
ool3o`0000oooooo0_l00003ooooo`;o00001_ooool2o`0000;ooooo1?l00003ooooo`Co00000_oo
ool2o`000003ooooool0003o000001?o000000?oooooo`000?l000000_l00002ooooo`;o00002Ooo
ool2o`000003ooooool0003o000000?o000000Coooooo`000?l0003o00001oooool2o`0000[ooooo
0_l00003ooooo`;o0000=oooool001cooooo00?o0000ooooooooool06Oooool2o`00027ooooo0_l0
00000ooooooo0000o`000008ooooo`;o00008ooooolGo`0001Kooooo0_l00004ooooo`Go00000ooo
ool2o`0000Wooooo0_l000000ooooooo0000o`00000Qo`000003ooooool0003o000000;o00000_oo
ool2o`0000Cooooo0_l00003ooooo`;o000000?oooooo`000?l000001?ooool3o`0000_ooooo0_l0
0006ooooo`;o0000??ooool001cooooo00?o0000ooooooooool06Oooool2o`00027ooooo1Ol00008
ooooo`;o00000oooool3o`0000?ooooo0_l0000Hooooo`;o00000_oooolBo`0000;ooooo0_l0000:
ooooo`Ko00000oooool2o`0000;ooooo1ol0000=ooooo`?o00000ooooolMo`0000;ooooo0_l00000
0ooooooo0000o`000002o`0000Sooooo0_l00004ooooo`;o00001?ooool2o`0000Kooooo0_l00006
ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool06Oooool3o`0001kooooo0_l00002oooo
o`;o00002?ooool2o`0000Cooooo0ol00003ooooo`;o00006_ooool2o`000003ooooool0003o0000
00go00000oooool3o`0000[ooooo1ol000000ooooooo0000o`000003ooooo`;o000000?oooooo`00
0?l000000_l00009ooooo`;o00000_ooool2o`0000;ooooo0ol000000ooooooo0000o`00000Ro`00
00kooooo0_l00004ooooo`;o00001_ooool2o`0004cooooo000Looooo`03o`000?oooooooooo01[o
oooo0_l0000Nooooo`Ko00002?ooool4o`0001kooooo0_l00004ooooo`;o00000_ooool2o`0000;o
oooo2Ol00004ooooo`;o00003oooool6o`0000Kooooo0_l00004ooooo`;o00001Oooool2o`000003
ooooool0003o000000;o000000?oooooo`000?l000002Ol000000ooooooo0000o`00000Ko`000003
ooooool0003o000000;o0000I?ooool001cooooo00?o0000ooooooooool0<?ooool2o`0000Wooooo
1Ol0000:ooooo`;o00006Oooool2o`0000?ooooo0_l0000<ooooo`;o00000_ooool5o`0001Cooooo
0ol000000ooooooo0000o`000007ooooo`Co00000_ooool2o`0000Oooooo7Ol000000ooooooo0000
o`00000Do`0000Oooooo0_l0000Eooooo`;o00001oooool2o`0000;ooooo0_l0000gooooo`007?oo
ool2o`00037ooooo0_l000000ooooooo0000o`000009ooooo`;o00006?ooool2o`0000_ooooo0_l0
00000ooooooo0000o`000002o`0000cooooo0_l0000Aooooo`;o00000_ooool3o`0000?ooooo0_l0
000<ooooo`?o00001_ooool2o`0000?ooooo0ol00002ooooo`Co000000?oooooo`000?l000001?l0
00000ooooooo0000o`00000Fo`0000;ooooo1_l00004ooooo`;o00001?ooool2o`0000[ooooo0_l0
0009ooooo`;o00001oooool2o`0000;ooooo0_l0000gooooo`007?ooool00ol0003oooooooooo`0c
ooooo`;o00001oooool2o`0000cooooo0_l0000<ooooo`;o00002oooool2o`000003ooooool0003o
000000;o00003?ooool2o`0000?ooooo0_l0000<ooooo`Oo000000Goooooo`000?l0003o0000oooo
o`02o`0000[ooooo0_l00007ooooo`;o00001?ooool2o`0000?ooooo2_l000000ooooooo0000o`00
0007o`000003ooooool0003o000001Co00001?ooool2o`00013ooooo0_l00009ooooo`;o0000A?oo
ool001cooooo00?o0000ooooooooool0<Oooool4o`0000Kooooo0ol0000<ooooo`;o00006Oooool2
o`000003ooooool0003o000000;o00002Oooool5o`000003ooooool0003o000000;o00002oooool6
o`0000;ooooo1?l000001?oooooo0000o`000?ooool2o`0000oooooo0_l00005ooooo`;o00000ooo
ool:o`000003ooooool0003o000000co000000?oooooo`000?l000003Ol0000Sooooo`;o0000A?oo
ool001cooooo00?o0000ooooooooool0<Oooool2o`000003ooooool0003o000000Gooooo0_l0000L
ooooo`;o00004oooool2o`0000Gooooo1Ol000000ooooooo0000o`00000=ooooo`;o000000?ooooo
o`000?l000001_l00005ooooo`;o00003oooool3o`0000;ooooo0_l000000ooooooo0000o`000003
oooooaSo000000?oooooo`000?l000003Ol00002ooooo`;o00001oooool2o`00017ooooo0_l00019
ooooo`007?ooool00ol0003oooooooooo`0dooooo`;o00000_ooool2o`0000Cooooo0_l0000Ioooo
o`;o00004oooool2o`0000kooooo0_l0000=ooooo`Ko00003_ooool2o`0000?ooooo0_l00004oooo
o`;o00000_ooool2o`000005ooooool0003o0000o`000?ooool0:?l00003ooooo`?o000000?ooooo
o`000?l000000oooool2o`00017ooooo0_l00019ooooo`007?ooool00ol0003oooooooooo`0eoooo
o`;o000000?oooooo`000?l000001?ooool2o`0003;ooooo0_l0000:ooooo`;o00003Oooool5o`00
00Cooooo0_l00005ooooo`;o000000?oooooo`000?l000001_l0000;ooooo`Ko000000?oooooo`00
0?l000001?l000000ooooooo0000o`00000Jo`0000Gooooo0ol000000ooooooo0000o`00000Doooo
o`?o00001?ooool2o`0004Cooooo000Looooo`03o`000?oooooooooo03Gooooo0_l0000aooooo`;o
00002?ooool2o`0001Wooooo2?l000000ooooooo0000o`000002o`0000?ooooo0_l000001?oooooo
0000o`000?ooool3o`0000gooooo3Ol000000ooooooo0000o`00000Ko`0000Cooooo0ol0000Goooo
o`?o00001?ooool2o`0000[ooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o
00000_ooool2o`0001?ooooo0_l0000Pooooo`;o00007oooool7o`0000;ooooo2Ol00003ooooo`;o
00004?ooool2o`0000?ooooo:Ol00002ooooo`;o00001?ooool2o`0002Oooooo0_l0000hooooo`00
7?ooool00ol0003oooooooooo`0]ooooo`;o00000_ooool4o`000003ooooool0003o000000kooooo
0_l0000Pooooo`;o00007?ooool2o`000003ooooool0003o000000Ko00000_ooool5o`000003oooo
ool0003o000000?ooooo0ol00008ooooo`;o00001Oooool2o`000003ooooool0003o000000ko0000
00?oooooo`000?l000007?l00003ooooo`?o0000HOooool001cooooo00?o0000ooooooooool05ooo
ool2o`0001Cooooo0_l00002ooooo`Oo00001?ooool2o`0001Wooooo0_l0000Wooooo`;o00001?oo
ool2o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o00002Oooool3o`0000;ooooo0_l0
0004ooooo`;o00001_ooool?o`000003ooooool0003o000001So000000?oooooo`000?l000000_l0
0002ooooo`;o000000?oooooo`000?l000004oooool2o`0000Wooooo0_l000000ooooooo0000o`00
000oooooo`007?ooool00ol0003oooooooooo`0Gooooo`;o00007?ooool2o`0000Gooooo0_l00009
ooooo`;o00003_ooool2o`00023ooooo0_l00005ooooo`;o00000oooool4o`000003ooooool0003o
000000;o00000oooool2o`00013ooooo0_l0000<ooooo`Co00000oooool3o`000003ooooool0003o
000001co00000_ooool3o`0000;ooooo1_l00006ooooo`;o00002_ooool3o`0000Wooooo0_l00000
0ooooooo0000o`00000oooooo`007?ooool00ol0003oooooooooo`0iooooo`;o000000?oooooo`00
0?l000002Oooool2o`0002_ooooo0ol00002ooooo`?o00002Oooool7o`0000;ooooo0_l000000ooo
oooo0000o`00000:ooooo`;o00003_ooool2o`0000[ooooo8Ol00002ooooo`Co000000?oooooo`00
0?l000001_l00002ooooo`Co00002_ooool2o`0000Gooooo0_l00006ooooo`;o0000?oooool001co
oooo00?o0000ooooooooool0:oooool2o`0000Gooooo0_l000000ooooooo0000o`000002ooooo`;o
000000?oooooo`000?l000006?ooool2o`000003ooooool0003o000001?ooooo0ol00003ooooo`Co
00000_ooool2o`0000Sooooo0_l00003ooooo`?o000000Coooooo`000?l0003o00003Oooool2o`00
00kooooo1?l00008ooooob3o00000_ooool5o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`00
01?ooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o00001Oooool2o`000003
ooooool0003o000000;o00005_ooool3o`0000Cooooo0_l000000ooooooo0000o`00000Cooooo`?o
00001Oooool2o`000004ooooool0003o0000ooooo`;o00001_ooool2o`0000Cooooo0_l000000ooo
oooo0000o`000002o`0001kooooo0_l000000ooooooo0000o`000006ooooo`oo000000?oooooo`00
0?l000003Ol00002ooooo`Co00000_ooool6o`0000?ooooo0_l00004ooooo`;o000000?oooooo`00
0?l000002oooool2o`0000Kooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o
00001_ooool3o`0000Oooooo0_l00008ooooo`;o00000_ooool4o`0002Kooooo0ol000000ooooooo
0000o`000003o`0000;ooooo0ol000001?oooooo0000o`000?l00002ooooo`Wo00002?ooool2o`00
00Wooooo0_l00007ooooo`?o00001?oooolWo`0000;ooooo1_l00003ooooo`;o000000Coooooo`00
0?l0003ooooo0_l000001?oooooo0000o`000?ooool3o`0000;ooooo0_l0000;ooooo`;o0000?ooo
ool001cooooo00?o0000ooooooooool0;_ooool2o`0000Kooooo0ol00007ooooo`;o00002?ooool2
o`0000;ooooo0_l0000Xooooo`;o00000oooool4o`0000;ooooo0ol000001?oooooo0000o`000?l0
0002ooooo`?o00000_ooool4o`0000Kooooo1?l00003ooooo`;o00001?ooool2o`0000?ooooo0ol0
00000ooooooo0000o`000003ooooo`Co000000?oooooo`000?l000008?l00006ooooo`;o00002?oo
ool2o`0000Cooooo0_l000001?oooooo0000o`000?l00002ooooo`;o000000?oooooo`000?l00000
2?ooool4o`0003gooooo000Looooo`;o0000=_ooool4o`00013ooooo0_l00005ooooo`;o0000:?oo
ool2o`0000_ooooo0ol00003ooooo`?o00002oooool2o`0000Cooooo0ol00004ooooo`;o00000ooo
ool3o`0000Kooooo0ol00002ooooo`;o00000_oooolIo`000004ooooool0003o0000o`0000Oooooo
0_l00004ooooo`;o00004?ooool5o`0000[ooooo0_l0000mooooo`007?ooool00ol0003ooooooooo
o`0cooooo`Ko00004?ooool2o`0000Gooooo0_l0000Uooooo`Ko00002oooool2o`000003ooooool0
003o000000?o00003Oooool2o`0000;ooooo0_l00005ooooo`;o00002oooool4o`0000Kooooo7Ol0
0007ooooo`;o00001?ooool2o`00013ooooo1?l0000=ooooo`;o0000>oooool001cooooo00?o0000
ooooooooool0<oooool2o`0000gooooo0_l0000@ooooo`;o00007_ooool2o`000003ooooool0003o
000000Co000000?oooooo`000?l000001oooool3o`000003ooooool0003o000000?o00000oooool2
o`0000?ooooo0_l00003ooooo`;o00002Oooool2o`0000Kooooo0_l00003ooooo`Co00000_oooolQ
o`0000Kooooo0_l0000Hooooo`;o000000?oooooo`000?l000001oooool2o`0000;ooooo0_l0000k
ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00002_ooool2o`000003ooooool0003o0000
00;o00003_ooool2o`0001kooooo0_l00007ooooo`Go00001Oooool3o`0000Cooooo0_l00003oooo
o`;o00000oooool2o`0000kooooo0_l00006ooooo`;o00001Oooool2o`0000;ooooo4?l000000ooo
oooo0000o`00000@o`0000Cooooo0_l000000ooooooo0000o`000007ooooo`;o00002_ooool4o`00
0003ooooool0003o000000Oooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0oooooo`;o
000000?oooooo`000?l000000_l0000Zooooo`;o000000Coooooo`000?l0003o00001?ooool5o`00
0003ooooool0003o000000cooooo0_l00008ooooo`;o00006_ooool2o`0000Gooooo0_l00002oooo
o`Ko00000_ooool?o`0000Kooooo0_l00004ooooo`;o000000?oooooo`000?l000000_ooool2o`00
00?ooooo0_l0000:ooooo`?o00000oooool2o`0001Oooooo0_l0000^ooooo`007?ooool00ol0003o
ooooooooo`0`ooooo`;o00003Oooool2o`000003ooooool0003o000002cooooo0_l000000ooooooo
0000o`000003o`0000;ooooo1?l000000ooooooo0000o`000004ooooo`;o00001oooool4o`0000Co
oooo0_l00004ooooo`;o00005_ooool2o`0000Gooooo2_l00002oooooa3o00001Oooool2o`0000Co
oooo0_l00004ooooo`Go000000?oooooo`000?l000001Oooool3o`000003ooooool0003o000000;o
00000oooool2o`0001Oooooo0_l0000^ooooo`007?ooool00ol0003oooooooooo`0`ooooo`Go0000
?Oooool<o`000003ooooool0003o000000Cooooo0_l00009ooooo`;o00001?ooool2o`0000Cooooo
0_l00003ooooo`;o00000_ooool2o`0000cooooo0_l00005ooooo`co000000?oooooo`000?l00000
1?l00002ooooo`_o00000oooool2o`0000Wooooo0_l000001?oooooo0000o`000?ooool2o`0000Go
oooo0ol000000ooooooo0000o`000002o`000003ooooool0003o000004Wooooo000Looooo`03o`00
0?oooooooooo03;ooooo0ol0000Rooooo`;o00006Oooool<o`0000;ooooo0_l0000;ooooo`;o0000
2?ooool3o`0000Oooooo0_l00002ooooo`;o00002oooool4o`0000Cooooo3?l00005ooooo`;o0000
0_ooool2o`0000?ooooo1_l000000ooooooo0000o`000002o`0000;ooooo0_l0000;ooooo`;o0000
1Oooool2o`0000Cooooo0_l000000ooooooo0000o`000019ooooo`007?ooool00ol0003ooooooooo
o`0cooooo`;o00003oooool2o`0000_ooooo1?l00002ooooo`;o00000oooool2o`0000Wooooo0_l0
0009oooooa3o00001oooool2o`0000;ooooo1?l00006ooooo`?o00003_ooool4o`0000Kooooo1?l0
0007ooooo`?o00000_ooool4o`0000Gooooo0_l00003ooooo`;o00001Oooool3o`000003ooooool0
003o000000?o000000?oooooo`000?l000000_ooool2o`0000kooooo0_l00004ooooo`;o000000?o
ooooo`000?l000001_ooool4o`0003oooooo000Looooo`03o`000?oooooooooo03?ooooo0_l0000>
ooooo`?o00002oooool4o`0000Oooooo0_l00009ooooo`;o00000oooool2o`000004ooooool0003o
0000ooooo`ko000000?oooooo`000?l000000_l00002ooooo`Co00001?ooool2o`0000Wooooo0_l0
0008ooooo`?o000000?oooooo`000?l000000_l00008ooooo`;o00001oooool3o`0000;ooooo1Ol0
0004ooooo`Co000000?oooooo`000?l000000_l00002ooooo`Go00000_ooool3o`0000;ooooo0_l0
00001?oooooo0000o`000?ooool2o`0000Cooooo1?l00002ooooo`?o00003oooool4o`0003oooooo
000Looooo`03o`000?oooooooooo04?ooooo0ol0000Cooooo`;o00004OoooolDo`000003ooooool0
003o000000;o00000_ooool4o`0000Cooooo0ol00004ooooo`;o00000_ooool2o`0000Kooooo1_l0
00000ooooooo0000o`000009ooooo`;o00002?ooool9o`000003ooooool0003o000000Go00000ooo
ool2o`000005ooooool0003o0000o`000?ooool00_l00007ooooo`;o00000oooool3o`0000Cooooo
1?l00002ooooo`?o00000oooool2o`000003ooooool0003o000000Sooooo0_l00010ooooo`007?oo
ool00ol0003oooooooooo`14ooooo`;o00001oooool2o`0000[ooooo0_l0000:ooooo`;o00000ooo
ool2o`000003ooooool0003o000001;o00002?ooool2o`0000Cooooo1?l00003ooooo`;o00002_oo
ool2o`0000;ooooo0_l00006ooooo`;o00001_ooool2o`0000Cooooo1ol00002ooooo`;o000000?o
ooooo`000?l000000_l00009ooooo`;o00004?ooool2o`0000Sooooo0_l000000ooooooo0000o`00
0003o`000004ooooool0003o0000ooooo`;o00002?ooool2o`000003ooooool0003o000003gooooo
000Looooo`03o`000?oooooooooo03Cooooo0ol0000Fooooo`;o00001Oooool2o`0000oooooo0_l0
0003ooooo`;o000000?oooooo`000?l000004ol0000?ooooo`;o00004oooool2o`0000Kooooo0_l0
0006ooooo`;o00000oooool4o`0000;ooooo1?l00002ooooo`;o00001_ooool2o`000003ooooool0
003o000000kooooo0_l0000=ooooo`So00000_ooool2o`0000Oooooo0_l00004ooooo`;o0000?Ooo
ool001cooooo00?o0000ooooooooool0<_ooool7o`0000gooooo0_l00002ooooo`;o00002?ooool2
o`0001Cooooo6?l00005ooooo`;o00005oooool2o`0001Wooooo1Ol000000ooooooo0000o`000006
o`0000Cooooo1?l000000ooooooo0000o`000004o`0000[ooooo0_l0000<ooooo`Wo00000_ooool2
o`0000?ooooo0_l00002ooooo`;o0000@oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Ooo
ool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo03;ooooo
0_l000000ooooooo0000o`000002o`0000cooooo0ol00002ooooo`;o00002Oooool2o`0000Kooooo
0_l00004ooooo`;o00001OoooolGo`0000Cooooo1Ol00002ooooo`;o00001Oooool2o`0000_ooooo
0_l0000;ooooo`;o00001Oooool7o`0000?ooooo0_l00005ooooo`Co000000Coooooo`000?l0003o
oooo0_l00003ooooo`Ko00006?ooool4o`000003ooooool0003o000000;o00001oooool2o`0004Oo
oooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B401_ooool00ol0003oooooooooo`0eooooo`Co00003?ooool2o`0000kooooo0_l00006
ooooo`;o00001?ooool2o`0000Oooooo5Ol00004ooooo`;o000000?oooooo`000?l000000_ooool2
o`0000Gooooo0_l00008ooooo`;o00000_ooool2o`0000Sooooo1?l00005ooooo`Oo00000oooool2
o`0000;ooooo0_l00006ooooo`;o000000?oooooo`000?l000000ol0000Looooo`?o000000Cooooo
o`000?l0003ooooo1?l00002ooooo`?o00000_ooool2o`0001[ooooo0_l0000[ooooo`0000?ooooo
oa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`0^ooooo`;o00001Oooool4o`0000kooooo0_l0000=ooooo`;o00001Ooo
ool3o`0000?ooooo0_l00006oooooaKo00002oooool2o`0000Gooooo2?l00002ooooo`;o00000_oo
ool2o`0000Sooooo1_l00005ooooo`;o000000?oooooo`000?l000001oooool2o`0000[ooooo1?l0
0002ooooo`;o00001?ooool2o`0000Wooooo0_l00007ooooo`?o00001Oooool4o`000004ooooool0
003o0000o`0000;ooooo0_l0000Jooooo`;o0000:oooool00003ooooool0003ooooo00;ooooo00?o
0000ooooooooool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0000^ooooo`;o0000
1_ooool2o`0000oooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0ol00009oooooa[o0000
2Oooool2o`000003ooooool0003o000000Cooooo1_l0000Booooo`Co000000?oooooo`000?l00000
0_ooool2o`000003ooooool0003o000000Cooooo0_l00007ooooo`;o00001Oooool2o`0000;ooooo
1Ol000001?oooooo0000o`000?l00009ooooo`;o00004Oooool2o`00023ooooo0_l0000]ooooo`00
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`01_ooool00ol0003oooooooooo`0fooooo`;o00005_ooool6o`0000Gooooo0_l00007ooooo`;o
00001OoooolJo`0000cooooo0_l000000ooooooo0000o`000003ooooo`;o00003oooool2o`0000?o
oooo0_l00003ooooo`;o000000?oooooo`000?l000002?ooool2o`0000Oooooo0_l00005ooooo`;o
00000_ooool2o`000004ooooool0003o0000ooooo`?o00002Oooool2o`0000Gooooo0_l00007oooo
o`;o000000?oooooo`000?l000008?ooool2o`0002gooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`0jooooo`;o
000000?oooooo`000?l000002?ooool2o`0000Oooooo1?l000000ooooooo0000o`000004o`0000Oo
oooo0_l000000ooooooo0000o`00000Ko`00013ooooo0_l00003ooooo`;o00001_ooool2o`0000Oo
oooo0_l00003ooooo`;o00001_ooool2o`0000Gooooo0_l0000Kooooo`;o00002_ooool2o`000003
ooooool0003o000000;ooooo0_l00007ooooo`;o0000D_ooool00006oooooomgMgOoV9RHoooooonH
V9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo03[ooooo1_l00007oooo
o`;o00003?ooool4o`0000cooooo6ol00007ooooo`;o00003?ooool2o`0000?ooooo0ol00002oooo
o`?o00002oooool2o`000003ooooool0003o000000[ooooo0_l0000Kooooo`Co00001Oooool2o`00
00Cooooo0_l00008ooooo`;o000000?oooooo`000?l00000D_ooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo03_ooooo0_l0
00000ooooooo0000o`00000Eooooo`;o00004Oooool<o`000003ooooool0003o000000Wo00001ooo
ool4o`0000[ooooo0_l00002ooooo`Co00000oooool2o`0000kooooo0_l00004ooooo`;o00006ooo
ool2o`0000Kooooo0_l00004ooooo`?o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o0000
1?ooool2o`000003ooooool0003o000000;o0000D?ooool001cooooo00?o0000ooooooooool0<_oo
ool2o`0000Cooooo0_l0000@ooooo`;o00002oooool2o`0000_ooooo0_l00002oooooa?o000000?o
ooooo`000?l000000_l00009ooooo`;o00003_ooool3o`0001[ooooo0_l0000Fooooo`;o00000ooo
ool2o`0000Sooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00001Oooool2o`0000Sooooo
1?l00005ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0<_ooool2o`0000?ooooo0ol0
000@ooooo`;o00002oooool2o`0000;ooooo0_l000000ooooooo0000o`000004oooooaco000000?o
ooooo`000?l000003_ooool2o`0000Gooooo1?l000000ooooooo0000o`00000Sooooo`;o00001?oo
ool3o`0000?ooooo1?l0000:ooooo`?o000000?oooooo`000?l000002_ooool2o`0000Sooooo1?l0
0002ooooo`;o000000?oooooo`000?l00000B?ooool001cooooo00?o0000ooooooooool0<_ooool2
o`0000?ooooo0_l00003ooooo`;o00005oooool2o`0000Cooooo0_l000000ooooooo0000o`000005
oooooa[o000000Goooooo`000?l0003o0000ooooo`02o`0000_ooooo0_l00005ooooo`;o00000ooo
ool2o`0002?ooooo0_l00004ooooo`?o00001Oooool2o`0000Gooooo0_l00003ooooo`;o00000_oo
ool2o`0000Oooooo0_l000000ooooooo0000o`000005ooooo`Co00001Oooool2o`0004_ooooo000L
ooooo`03o`000?oooooooooo03;ooooo0_l00005ooooo`;o000000?oooooo`000?l000004_ooool2
o`0000?ooooo0_l00007ooooo`;o00001OoooolCo`000003ooooool0003o000000Co000000?ooooo
o`000?l000000_ooool2o`0000cooooo0_l0000Kooooo`;o00000oooool2o`0000?ooooo0_l0000L
ooooo`;o00000oooool2o`000003ooooool0003o000000?o00001Oooool2o`000004ooooool0003o
0000o`0000Cooooo1?l0001Booooo`007?ooool00ol0003oooooooooo`0iooooo`;o00003_ooool3
o`000004ooooool0003o0000ooooo`;o00000oooool4o`0000_ooooo0ol000000ooooooo0000o`00
000Eo`0001?ooooo0_l000000ooooooo0000o`000002o`0001Kooooo0_l00003ooooo`;o00000ooo
ool2o`0000_ooooo0_l00006ooooo`;o00003?ooool2o`000003ooooool0003o000000?o00002Ooo
ool2o`0000;ooooo1Ol00005ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0@?ooool2
o`0000Oooooo0ol000000ooooooo0000o`000006ooooo`Co00000_ooool2o`0000;ooooo0_l00003
oooooa_o00005Oooool5o`0000?ooooo0_l0000Kooooo`;o00002oooool3o`000003ooooool0003o
000000Co00000_ooool2o`0000cooooo0_l0000;ooooo`;o00000_ooool5o`0000Gooooo0_l00003
ooooo`;o00004?ooool2o`0003Gooooo000Looooo`03o`000?oooooooooo03Wooooo0_l00003oooo
o`Co00000oooool2o`0001Cooooo0_l00002ooooo`;o00001OoooolIo`0001?ooooo1?l00006oooo
o`;o00005?ooool2o`0000Gooooo0_l00002ooooo`;o00001Oooool2o`000003ooooool0003o0000
00So000000?oooooo`000?l000006Oooool2o`0000;ooooo0_l0000=ooooo`;o00004?ooool2o`00
03Gooooo000Looooo`03o`000?oooooooooo03Wooooo0_l00003ooooo`;o00001Oooool2o`000003
ooooool0003o000001cooooo6?l0000Dooooo`;o00000_ooool2o`000003ooooool0003o000001;o
oooo0_l00003ooooo`Co00000oooool2o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l0
00000_l00003ooooo`Go00005oooool2o`0000;ooooo1Ol0001Fooooo`007?ooool00ol0003ooooo
ooooo`0iooooo`;o00000oooool5o`0000Gooooo0_l0000:ooooo`;o00002Oooool2o`000003oooo
ool0003o000000;ooooo2?l000000ooooooo0000o`00000<o`0001Cooooo0ol00002ooooo`;o0000
00?oooooo`000?l000000oooool2o`0000gooooo0ol00003ooooo`Co00004_ooool2o`0000Kooooo
0_l0000:ooooo`;o00002_ooool3o`000003ooooool0003o000000?o0000Eoooool001cooooo00?o
0000ooooooooool0=?ooool2o`0000?ooooo0_l00003ooooo`Go00004Oooool2o`000003ooooool0
003o000000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000006Ol0000Aooooo`;o000000?o
ooooo`000?l000001oooool2o`0000;ooooo0_l0000=ooooo`Ko00000_ooool2o`0000Wooooo0_l0
00000ooooooo0000o`000004ooooo`;o00001Oooool2o`0000_ooooo0_l0000:ooooo`;o00000_oo
ool2o`000004ooooool0003o0000o`0001Sooooo0_l0000looooo`007?ooool00ol0003ooooooooo
o`0dooooo`;o00000_ooool2o`00013ooooo0_l0000;ooooo`Ko00000_ooool2o`0000?ooooo3Ol0
00000ooooooo0000o`00000;o`0000oooooo0_l00008ooooo`Co00004_ooool5o`000004ooooool0
003o0000o`0000Wooooo0_l000000ooooooo0000o`00000;ooooo`;o00001?ooool2o`0000Gooooo
0_l00006ooooo`?o00001Oooool2o`000004ooooool0003o0000o`0001Sooooo0_l0000looooo`00
7?ooool2o`0003Wooooo0_l00003ooooo`;o00002oooool2o`0000[ooooo0_l000000ooooooo0000
o`000003o`0000Kooooo5ol00002ooooo`;o00004?ooool2o`0000Gooooo1Ol0000Booooo`co0000
2?ooool2o`0001;ooooo0ol00005ooooo`;o00000oooool6o`0000Gooooo0_l000000ooooooo0000
o`00001Gooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00004oooool3o`000003ooooool0
003o000000Cooooo0_l00007oooooa?o000000?oooooo`000?l000005?ooool4o`0000?ooooo1?l0
000Aoooooa3o00001_ooool2o`0001;ooooo0_l000000ooooooo0000o`000002ooooo`;o00000_oo
ool8o`0000Sooooo0_l0000;ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0D_ooool3
o`0000Wooooo0_l00003ooooo`oo00000oooool3o`000003ooooool0003o000001Kooooo0_l00003
ooooo`;o00003_ooool2o`0000;ooooo3Ol00002ooooo`?o00006oooool7o`0000;ooooo1ol00009
ooooo`;o00002Oooool4o`0004[ooooo000Looooo`03o`000?oooooooooo04Cooooo0_l0000Hoooo
o`;o00000oooool2o`000003ooooool0003o000000;ooooo2_l0000Hooooo`?o00001oooool2o`00
00cooooo5?l00002ooooo`;o00002_ooool2o`0000_ooooo0_l00002ooooo`Oo00001?ooool3o`00
00_ooooo0_l00009ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0A?ooool4o`0000;o
oooo0_l0000@ooooo`;o00003?ooool5o`0000?ooooo0_l00007ooooo`;o00003oooool3o`0000Ko
oooo0_l0000=oooooaCo00003_ooool2o`000003ooooool0003o000000Sooooo0_l00002ooooo`Co
00000oooool2o`00017ooooo1?l00005ooooo`;o00002_ooool2o`0000;ooooo0_l0000mooooo`00
7?ooool00ol0003oooooooooo`15ooooo`?o000000Coooooo`000?l0003o00002oooool2o`0000?o
oooo0ol00008ooooo`;o00002Oooool2o`0000Oooooo0_l0000?ooooo`;o00001oooool2o`0000oo
oooo5?l00009ooooo`Co00000_ooool2o`0000cooooo0_l00005ooooo`;o00000_ooool2o`0000go
oooo1?l00003ooooo`Co00002_ooool2o`0000;ooooo0_l0000mooooo`007?ooool00ol0003ooooo
ooooo`15ooooo`?o000000?oooooo`000?l000003?ooool2o`0000Cooooo0_l00008ooooo`;o0000
8oooool2o`0001?ooooo0_l00004oooooa?o000000?oooooo`000?l000001_ooool4o`0000_ooooo
0_l0000:ooooo`?o000000Coooooo`000?l0003ooooo0_l0000Aooooo`;o0000Coooool001cooooo
00?o0000ooooooooool0AOooool2o`0000;ooooo0_l00005ooooo`;o00001_ooool3o`0000Wooooo
0_l0000Vooooo`;o00004oooool2o`0000?ooooo4_l00003ooooo`;o00001oooool2o`000003oooo
ool0003o000000Kooooo1Ol0000;ooooo`;o00001?ooool2o`0000Wooooo0ol0001Fooooo`007?oo
ool00ol0003oooooooooo`18ooooo`?o00001Oooool3o`0000Gooooo0ol00009ooooo`;o000000?o
ooooo`000?l000007_ooool2o`0000Cooooo0_l0000Foooooa?o00003oooool3o`0000Gooooo1Ol0
0008ooooo`Go000000?oooooo`000?l000000_l00003ooooo`;o00001Oooool3o`0001?ooooo0_l0
0011ooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00000oooool2o`0000Kooooo0ol00000
0ooooooo0000o`00000=ooooo`;o00000_ooool4o`0000Cooooo0_l0000Fooooo`;o00001?ooool2
o`0000;ooooo0_l00005ooooo`;o00002ooooolEo`0000gooooo0ol00005ooooo`;o000000?ooooo
o`000?l000000_ooool2o`0000Cooooo3?l000000ooooooo0000o`000002o`0000oooooo0_l00008
ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0@oooool2o`0000Gooooo0_l000001?oo
oooo0000o`000?ooool2o`0000;ooooo0_l0000=ooooo`So00001?ooool2o`00023ooooo0_l00005
ooooo`?o00002_oooolFo`0000[ooooo0_l00006ooooo`?o00000oooool2o`000003ooooool0003o
000000Sooooo0ol00003ooooo`;o00000oooool2o`0000gooooo1?l0001;ooooo`007?ooool00ol0
003oooooooooo`14ooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`;o00000_ooool5
o`0000cooooo1Ol00006ooooo`;o00009oooool2o`0000cooooo5_l00008ooooo`;o00001_ooool3
o`0000?ooooo0_l00003ooooo`Co00003oooool3o`0000cooooo0_l0001=ooooo`007?ooool00ol0
003oooooooooo`14ooooo`;o00003?ooool7o`0000cooooo0_l00004ooooo`;o00000oooool2o`00
01Gooooo0_l00007ooooo`;o00005_ooool@o`0000?ooooo0_l0000Kooooo`Co00004?ooool2o`00
05_ooooo000Looooo`03o`000?oooooooooo05;ooooo0_l00005ooooo`?o00001Oooool3o`000003
ooooool0003o000000Cooooo0_l0000;ooooo`;o00003Oooool2o`0000Oooooo0_l00002ooooo`Co
00002oooool2o`0000;ooooo4?l0000Gooooo`;o00000_ooool2o`0000Sooooo0_l0000Booooo`;o
0000Eoooool001cooooo00?o0000ooooooooool0C?ooool2o`0000_ooooo0ol00005ooooo`?o0000
3?ooool2o`0000Kooooo0_l0000;ooooo`;o00001oooool2o`0000Cooooo1?l00002ooooo`;o0000
00?oooooo`000?l000001?ooool2o`000003ooooool0003o000000Ko000000?oooooo`000?l00000
1ol0000<ooooo`;o00001_ooool4o`0000;ooooo0_l00008ooooo`?o000000?oooooo`000?l00000
1?ooool2o`0000Sooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00000ooo
ool2o`0000Oooooo0_l0000Dooooo`Go00004?ooool2o`0000?ooooo0_l00002ooooo`;o00001Ooo
ool2o`0000?ooooo0_l000000ooooooo0000o`000005oooooaGo00001Oooool2o`0000Cooooo0_l0
0006ooooo`;o00001?ooool2o`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l000001?oo
ool2o`00067ooooo000Looooo`;o0000A_ooool2o`0000Gooooo0_l000000ooooooo0000o`000002
o`0000Kooooo0ol000000ooooooo0000o`00000Booooo`Co00004?ooool2o`0000?ooooo0_l00009
ooooo`;o00001_ooool2o`0000Gooooo0_l000000ooooooo0000o`00000@o`0000Gooooo0_l00000
1?oooooo0000o`000?l0000;ooooo`;o00001oooool3o`0000?ooooo1Ol00004ooooo`;o00001_oo
ool2o`0005Sooooo000Looooo`03o`000?oooooooooo04Gooooo0_l00005ooooo`;o000000?ooooo
o`000?l000000_l00006ooooo`;o00000_ooool2o`0000kooooo0_l00002ooooo`?o00004Oooool2
o`0001kooooo5?l00008ooooo`?o00002oooool2o`0000Oooooo0_l00004ooooo`Go00001?ooool2
o`0000Kooooo0_l00007ooooo`;o00000oooool2o`0004[ooooo000Looooo`03o`000?oooooooooo
04Kooooo0_l00004ooooo`;o00000_ooool3o`0000oooooo0_l00009ooooo`Co00000oooool:o`00
00Oooooo0_l00004ooooo`;o00006?ooool2o`000003ooooool0003o000000oo000000?oooooo`00
0?l000006oooool2o`0000;ooooo0_l00006ooooo`?o00004_ooool2o`0000?ooooo0_l0001:oooo
o`007?ooool00ol0003oooooooooo`16ooooo`;o00000oooool2o`0001Gooooo0_l0000;ooooo`;o
00000_ooool;o`0000gooooo0_l0000Ioooooa7o00000oooool2o`0001_ooooo0_l00002ooooo`Co
00001?ooool3o`00013ooooo1?l0001?ooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o0000
2oooool2o`00017ooooo0_l00006ooooo`;o00002_ooool2o`0000;ooooo0_l0000Qooooo`;o0000
0_ooool<o`0000Gooooo0_l00003ooooo`;o00006oooool2o`0000;ooooo0_l0000Cooooo`Co0000
Coooool001cooooo00?o0000ooooooooool0Eoooool5o`0000[ooooo0_l00002ooooo`?o00001_oo
ool2o`0000[ooooo1_l0000Qooooo`;o00000_ooool<o`0000;ooooo0_l000000ooooooo0000o`00
0003ooooo`;o00004Oooool2o`0000Gooooo0ol00004ooooo`;o0000I_ooool001cooooo00?o0000
ooooooooool0DOooool2o`0000Cooooo0_l000000ooooooo0000o`000007ooooo`;o000000?ooooo
o`000?l000000_ooool2o`0000;ooooo0_l00002ooooo`?o00000oooool2o`0000?ooooo0_l00002
ooooo`;o00006?ooool3o`000003ooooool0003o000000Gooooo0ol000000ooooooo0000o`000008
o`0000;ooooo1?l000000ooooooo0000o`00000Fooooo`;o000000Coooooo`000?l0003ooooo1Ol0
0005ooooo`;o00004oooool2o`0004oooooo000Looooo`03o`000?oooooooooo057ooooo0_l0000@
ooooo`;o00002Oooool2o`0000;ooooo0_l00004ooooo`?o000000Coooooo`000?l0003o00006Ooo
ool6o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000006ooooo`Co00000ooo
ool2o`0000?ooooo0_l0000:ooooo`?o00003?ooool2o`000004ooooool0003o0000ooooo`;o0000
1Oooool3o`0001;ooooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00002Ooo
ool2o`0000?ooooo0_l0000?ooooo`;o00002Oooool2o`000003ooooool0003o000000?ooooo0_l0
0002ooooo`;o00003oooool8o`0000;ooooo0ol000000ooooooo0000o`000005ooooo`;o00001?oo
ool2o`0000Oooooo0_l00007ooooo`Oo00004_ooool2o`0000Kooooo0_l0001Sooooo`007?ooool0
0ol0003oooooooooo`1:ooooo`;o000000?oooooo`000?l000002Oooool2o`0000;ooooo0ol00005
ooooo`;o00000oooool3o`0001Gooooo0_l00002ooooo`;o00003oooool4o`000003ooooool0003o
000000?ooooo0ol00008ooooo`;o00001?ooool2o`0000Oooooo0_l00007ooooo`Oo00002oooool2
o`00017ooooo0_l00002ooooo`;o0000Foooool001cooooo00?o0000ooooooooool0B_ooool2o`00
0003ooooool0003o000000cooooo1Ol00004ooooo`;o00000oooool3o`0000Cooooo0_l00003oooo
o`;o00000_ooool2o`0001oooooo0_l0000?ooooo`;o00001?ooool2o`00017ooooo0ol0000>oooo
o`;o00004Oooool6o`0005_ooooo000Looooo`03o`000?oooooooooo05Sooooo0_l000000ooooooo
0000o`000003o`000003ooooool0003o000000gooooo0_l00003ooooo`;o00000_ooool2o`0001_o
oooo0_l00002ooooo`;o00003oooool2o`0000gooooo0_l0000Yooooo`Oo0000GOooool001cooooo
00?o0000ooooooooool0Doooool2o`0000?ooooo0_l00007ooooo`;o00000_ooool2o`0002oooooo
0_l00002ooooo`;o00007_ooool4o`0000Wooooo0_l000000ooooooo0000o`000007ooooo`;o0000
00?oooooo`000?l000003Oooool4o`00063ooooo000Looooo`03o`000?oooooooooo04gooooo0_l0
0002ooooo`Co00001?ooool2o`0000Cooooo0_l00004ooooo`;o00000_ooool2o`0000Kooooo0_l0
000Wooooo`;o00008?ooool5o`0000Kooooo0_l000000ooooooo0000o`000007ooooo`;o000000?o
ooooo`000?l00000LOooool001cooooo00?o0000ooooooooool0COooool2o`0000;ooooo0_l00006
ooooo`;o00001?ooool3o`0000Oooooo0ol00005ooooo`;o00000_ooool2o`0000[ooooo0_l0000U
ooooo`;o00004?ooool2o`0000;ooooo0ol00002ooooo`;o000000?oooooo`000?l00000POooool0
01cooooo00?o0000ooooooooool0F_ooool4o`0000;ooooo0_l000000ooooooo0000o`000002o`00
00?ooooo0_l00009ooooo`;o00001?ooool2o`0000Cooooo1?l0000Sooooo`;o00004?ooool2o`00
00Oooooo0_l000000ooooooo0000o`000007ooooo`;o00001?ooool2o`00013ooooo0_l0001Poooo
o`007?ooool2o`0005_ooooo1?l00002ooooo`;o000000?oooooo`000?l000000_l000000ooooooo
0000o`00000Aooooo`;o00001_ooool2o`0000gooooo0_l0000?ooooo`;o0000:_ooool2o`0000;o
oooo1?l0000@ooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0DOooool2o`0000Kooooo
0_l00005ooooo`;o00001_ooool2o`0002Sooooo0_l0000?ooooo`;o00001Oooool2o`0002Oooooo
0_l00007ooooo`;o00001Oooool2o`0006Cooooo000Looooo`03o`000?oooooooooo057ooooo0_l0
0003ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Wooooo0_l000000ooooooo0000o`00
0002o`00023ooooo0_l0000;ooooo`;o00001Oooool2o`0000;ooooo0_l0000Jooooo`;o00001?oo
ool2o`0000?ooooo0_l00009ooooo`;o00000oooool4o`0006Cooooo000Looooo`03o`000?oooooo
oooo05Kooooo1?l0000Aooooo`;o000000?oooooo`000?l000000_l0000Pooooo`;o00002oooool2
o`0000Gooooo0_l00002ooooo`;o00000oooool2o`0001Gooooo0_l00002ooooo`Co00000oooool2
o`0000Cooooo0_l00008ooooo`;o00001Oooool2o`0005oooooo000Looooo`03o`000?oooooooooo
05Oooooo1Ol0000Booooo`;o00001?ooool2o`0000?ooooo0_l000000ooooooo0000o`00000Aoooo
o`;o00001oooool4o`0000oooooo0_l00002ooooo`;o00006Oooool2o`0000_ooooo0_l00005oooo
o`;o00001?ooool6o`0005oooooo000Looooo`03o`000?oooooooooo05Oooooo0_l000000ooooooo
0000o`00000>ooooo`;o00000_ooool2o`0000Cooooo0_l00003ooooo`;o000000Coooooo`000?l0
003ooooo0_l00009ooooo`;o00000oooool2o`0000Kooooo1Ol000001?oooooo0000o`000?ooool2
o`0000Oooooo1?l000000ooooooo0000o`00000Uooooo`;o00001oooool2o`0000Cooooo1Ol0001P
ooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o00000_ooool2o`0000?ooooo0_l000000ooo
oooo0000o`000002o`0000Gooooo0_l00004ooooo`;o00001?ooool2o`0000Oooooo1?l0000;oooo
o`;o00000oooool3o`000003ooooool0003o000000?ooooo0ol000000ooooooo0000o`000002o`00
0003ooooool0003o0000017ooooo0_l000001?oooooo0000o`000?l0000>ooooo`;o0000L_ooool0
01cooooo00?o0000ooooooooool0G_ooool2o`0000;ooooo0_l00003ooooo`Oo00001?ooool3o`00
00Cooooo0_l000000ooooooo0000o`00000:ooooo`;o00001_ooool4o`0000?ooooo0_l00003oooo
o`;o00001oooool4o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00003Oooool2o`00
0003ooooool0003o000000;o00003oooool2o`00073ooooo000Looooo`03o`000?oooooooooo06So
oooo0_l00008ooooo`;o00002?ooool3o`0000Wooooo0_l00006ooooo`Co00002Oooool2o`0000So
oooo0_l00002ooooo`;o00001Oooool2o`0000;ooooo0_l0000>ooooo`;o000000?oooooo`000?l0
00003?ooool2o`00073ooooo000Looooo`03o`000?oooooooooo06Kooooo0_l00005ooooo`;o0000
3_ooool2o`0000Wooooo0_l00003ooooo`;o00002?ooool2o`0000Cooooo0_l0000;ooooo`Ko0000
0oooool2o`000003ooooool0003o000000Oooooo0_l00008ooooo`;o00003oooool2o`0006gooooo
000Looooo`03o`000?oooooooooo05gooooo0_l00007ooooo`;o00001Oooool2o`0001?ooooo0_l0
0009ooooo`?o00001oooool2o`0000oooooo2?l00003ooooo`?o00002Oooool2o`0000?ooooo0_l0
000=ooooo`;o00001Oooool2o`0006gooooo000Looooo`03o`000?oooooooooo05gooooo0_l00006
ooooo`Co00001?ooool2o`0000kooooo0_l00003ooooo`?o00001_ooool2o`000004ooooool0003o
0000o`0000Sooooo0_l0000=ooooo`;o00002Oooool3o`0000Gooooo1?l00005ooooo`;o00003Ooo
ool2o`0000Kooooo0_l0001/ooooo`007?ooool00ol0003oooooooooo`1Uooooo`Co00001?ooool2
o`0000kooooo0_l00004ooooo`;o00001_ooool2o`0000;ooooo0_l00008ooooo`;o00001Oooool2
o`0000;ooooo1?l00005ooooo`;o00001?ooool2o`0000Kooooo1?l00006ooooo`Co00004_ooool2
o`0006cooooo000Looooo`03o`000?oooooooooo067ooooo0_l0000;ooooo`;o00004_ooool3o`00
00_ooooo0_l00007ooooo`;o00001Oooool2o`000003ooooool0003o000000?o00001Oooool2o`00
01Kooooo1Ol0001oooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool0
1Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0HOooool2o`0000_ooooo0_l0
000Booooo`;o00003?ooool2o`0000gooooo0_l00002ooooo`Go00007Oooool5o`0000cooooo0_l0
001aooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RH
oooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0Hoooool2o`0000Kooooo0_l00003ooooo`;o
000000?oooooo`000?l000008Oooool2o`0000Oooooo0_l0000cooooo`Co0000LOooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool0Hoooool2o`0000Kooooo0ol00002ooooo`;o000000?oooooo`000?l0
00004?ooool2o`0000oooooo0_l0000gooooo`;o00000oooool2o`0007?ooooo00000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o
0000I?ooool2o`0000Kooooo0ol00006ooooo`;o00003_ooool3o`0000kooooo0_l0000Oooooo`;o
00000_ooool2o`0000;ooooo0_l00005ooooo`;o00001oooool2o`0007Sooooo00000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03
o`000?oooooooooo06Cooooo1?l00005ooooo`;o00001Oooool3o`0000oooooo0_l00009ooooo`;o
00000oooool2o`0001oooooo0_l00002ooooo`;o00000_ooool2o`0000Gooooo0_l00021ooooo`00
00?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@
41001_ooool00ol0003oooooooooo`1Vooooo`;o00003?ooool2o`0000_ooooo0_l0000>ooooo`Co
00001Oooool2o`0000Sooooo1?l0000Booooo`;o0000SOooool00006oooooomgMgOoV9RHoooooonH
V9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0NOooool4
o`0000Cooooo0_l0000=ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Cooooo0_l00002
ooooo`Co00000_ooool2o`0000kooooo0_l00003ooooo`;o0000R?ooool00006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0
JOooool2o`0000Cooooo0_l00008ooooo`Co000000?oooooo`000?l000001Oooool2o`0000Kooooo
0_l000000ooooooo0000o`000009ooooo`;o00000oooool2o`0000;ooooo0_l00004ooooo`?o0000
4_ooool2o`0000Gooooo0_l00021ooooo`007?ooool00ol0003oooooooooo`1Yooooo`;o00001?oo
ool2o`0000Sooooo0ol000001?oooooo0000o`000?l00005ooooo`;o00001?ooool4o`0000cooooo
1?l0000<ooooo`;o00004Oooool3o`0000Gooooo0_l00021ooooo`007?ooool00ol0003ooooooooo
o`1mooooo`;o00003?ooool2o`00013ooooo0_l0000Oooooo`?o0000R?ooool001cooooo00?o0000
ooooooooool0N_ooool4o`000003ooooool0003o000000[ooooo0_l0000:ooooo`;o00006oooool2
o`0000;ooooo0_l000000ooooooo0000o`00002<ooooo`007?ooool00ol0003oooooooooo`1joooo
o`Co000000?oooooo`000?l000002_ooool4o`0000Sooooo0_l0000Kooooo`;o00000_ooool2o`00
0003ooooool0003o000008cooooo000Looooo`03o`000?oooooooooo07gooooo0_l0000<ooooo`Co
000000?oooooo`000?l000002oooool2o`0000kooooo0_l0002Jooooo`007?ooool00ol0003ooooo
ooooo`1mooooo`;o00003?ooool4o`000003ooooool0003o000000_ooooo0_l00003ooooo`;o0000
1_ooool2o`000003ooooool0003o000009[ooooo000Looooo`03o`000?oooooooooo08Sooooo0_l0
00000ooooooo0000o`000002o`0001?ooooo0_l00006ooooo`;o0000WOooool001cooooo00?o0000
ooooooooool0R?ooool2o`0000kooooo0_l00008ooooo`;o00002Oooool2o`0000_ooooo0_l0002=
ooooo`007?ooool00ol0003oooooooooo`20ooooo`;o00005_ooool2o`0000Sooooo0_l00009oooo
o`;o00000oooool2o`0000Kooooo0_l0002=ooooo`007?ooool00ol0003oooooooooo`20ooooo`;o
00007_ooool4o`0000cooooo1?l0002Eooooo`007?ooool00ol0003oooooooooo`2Pooooo`;o0000
2?ooool2o`0000Cooooo0_l0002Gooooo`007?ooool2o`0008Sooooo0_l00009ooooo`Co000000?o
ooooo`000?l000004Oooool2o`0000Kooooo0ol0002Dooooo`007?ooool00ol0003oooooooooo`27
ooooo`;o00001?ooool2o`0000?ooooo1?l000000ooooooo0000o`00000:ooooo`;o00002oooool5
o`0000Oooooo0_l0002;ooooo`007?ooool00ol0003oooooooooo`2=ooooo`;o00002?ooool3o`00
00Wooooo0_l000000ooooooo0000o`000006ooooo`Co00002_ooool2o`0008_ooooo000Looooo`03
o`000?oooooooooo09Sooooo0_l00006ooooo`;o00001?ooool2o`0000Kooooo0_l0002Iooooo`00
7?ooool00ol0003oooooooooo`2>ooooo`Co00001oooool2o`0000Cooooo0ol0002Wooooo`007?oo
ool00ol0003oooooooooo`2>ooooo`Co00001?ooool2o`000003ooooool0003o000000Cooooo0_l0
0002ooooo`;o0000Y?ooool001cooooo00?o0000ooooooooool0U_ooool2o`0000_ooooo0_l0000?
ooooo`;o000000?oooooo`000?l00000T?ooool001cooooo00?o0000ooooooooool0Z_ooool2o`00
00Sooooo0_l000000ooooooo0000o`00002@ooooo`007?ooool00ol0003oooooooooo`2Zooooo`;o
0000WOooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2
o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001;ooooo1?l000000ol@413oooooooooo`03
ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo0ol0003ooooood[o
oooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooo
oomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo
0?ooooooD_ooool001;ooooo00?oEEEEofIVI_l00000oooooomDooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00YOooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooo
oooo01Oooooo00?o0000onk^k_ooool01?ooool4o`000003oa0@4?oooooooooo00;ooooo0_l00000
0ol@413oooooooooo`2>ooooo`00Y_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l0000;
ooooo`03oeEEEOnYZJWooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2?
ooooo`00Y_ooool01Ol0003ooooooooooooooooo000001[ooooo00?oZJVYoeEEEOooool01_ooool0
0ol0003oooooooooo`02ooooo`Go0000T?ooool00:Kooooo00Go0000ooooooooooooooooo`000009
ooooo`Ko00003?ooool00olQ8B7oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00CoA4A4
omgMgOoooooo0000TOooool00:Kooooo00Go0000ohN7QoooooooZJVYo`00000Kooooo`03oeEEEOo<
c<cooooo00Gooooo00?o0000ooooooooool00_ooool01?oMgMgoEEEEooooool0002Aooooo`00YOoo
ool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo01Wooooo00?oZJVYogMgMoooool01Ooo
ool00ol0003oooooooooo`03ooooo`03ogMgMoo<c<co0000097ooooo0033ooooo`05oa0@4?oooooo
oooooooooolb<S801_ooool00ol0003oooooooooo`03ooooo`03onk^k_m4A4Co0000097ooooo0033
ooooo`Go00001?ooool00omEEEGoIVIVo`000006ooooo`03ogMgMol0003ooooo093ooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(720) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.52732 .34844 Mdot
.55702 .35771 Mdot
.33875 .62686 Mdot
.62028 .49436 Mdot
.47738 .61464 Mdot
.33632 .58776 Mdot
.37603 .43508 Mdot
.38332 .47607 Mdot
.33715 .60553 Mdot
.63352 .3126 Mdot
.36711 .41628 Mdot
.58117 .46776 Mdot
.38435 .44247 Mdot
.63049 .55637 Mdot
.20534 .37593 Mdot
.62458 .59378 Mdot
.59119 .34 Mdot
.49348 .68165 Mdot
.64546 .59741 Mdot
.32299 .62003 Mdot
.52815 .27945 Mdot
.63448 .55201 Mdot
.56177 .36095 Mdot
.63113 .55434 Mdot
.60501 .51852 Mdot
.54739 .32903 Mdot
.53143 .36229 Mdot
.63091 .51022 Mdot
.60627 .55068 Mdot
.40203 .42011 Mdot
.45697 .63944 Mdot
.14329 .51399 Mdot
.59278 .58298 Mdot
.7731 .52335 Mdot
.41077 .45998 Mdot
.42812 .79896 Mdot
.35858 .60248 Mdot
.35829 .44334 Mdot
.39907 .47325 Mdot
.39657 .46641 Mdot
.38882 .45995 Mdot
.54633 .33531 Mdot
.39703 .40477 Mdot
.33833 .40046 Mdot
.63275 .49214 Mdot
.38381 .31371 Mdot
.50982 .76159 Mdot
.6341 .51291 Mdot
.52955 .33538 Mdot
.31112 .60728 Mdot
.81276 .51766 Mdot
.35848 .45035 Mdot
.30071 .32838 Mdot
.17879 .29928 Mdot
.40495 .44482 Mdot
.62687 .49757 Mdot
.36162 .58192 Mdot
.65665 .53243 Mdot
.63941 .53326 Mdot
.78955 .47628 Mdot
.6138 .53535 Mdot
.52963 .68578 Mdot
.55625 .38039 Mdot
.34551 .63281 Mdot
.33745 .59796 Mdot
.41286 .44003 Mdot
.59044 .3187 Mdot
.37833 .44903 Mdot
.6875 .49393 Mdot
.31881 .61008 Mdot
.63668 .51084 Mdot
.36233 .41899 Mdot
.58533 .30133 Mdot
.61262 .57836 Mdot
.42133 .31873 Mdot
.25258 .36561 Mdot
.54542 .64345 Mdot
.75116 .45587 Mdot
.65791 .23826 Mdot
.27443 .41184 Mdot
.62116 .55631 Mdot
.61309 .17821 Mdot
.21657 .36912 Mdot
.57022 .35406 Mdot
.71568 .60608 Mdot
.26485 .58886 Mdot
.62078 .57522 Mdot
.46807 .55021 Mdot
.59046 .48779 Mdot
.47623 .3167 Mdot
.34191 .60619 Mdot
.53851 .33337 Mdot
.62331 .49062 Mdot
.63677 .58038 Mdot
.72469 .33724 Mdot
.57669 .52265 Mdot
.64783 .50223 Mdot
.51856 .35235 Mdot
.38599 .41664 Mdot
.6142 .4667 Mdot
.33431 .39662 Mdot
.29392 .33872 Mdot
.59112 .51607 Mdot
.32623 .59897 Mdot
.58244 .36486 Mdot
.60071 .49581 Mdot
.40879 .44523 Mdot
.62113 .54006 Mdot
.35349 .48138 Mdot
.53739 .35417 Mdot
.63777 .57918 Mdot
.49546 .69545 Mdot
.45676 .29452 Mdot
.54833 .30781 Mdot
.49348 .18529 Mdot
.62144 .5299 Mdot
.63959 .54501 Mdot
.55945 .3553 Mdot
.3649 .56688 Mdot
.45399 .54128 Mdot
.59374 .31548 Mdot
.39727 .47075 Mdot
.54901 .36708 Mdot
.66438 .48522 Mdot
.34697 .56394 Mdot
.29923 .33778 Mdot
.28764 .35402 Mdot
.69526 .72591 Mdot
.60859 .57195 Mdot
.32235 .33428 Mdot
.34392 .57462 Mdot
.54483 .34569 Mdot
.38188 .4501 Mdot
.67967 .51815 Mdot
.58398 .32389 Mdot
.3644 .44744 Mdot
.50387 .7053 Mdot
.3762 .70389 Mdot
.54228 .30607 Mdot
.5136 .48504 Mdot
.41603 .46696 Mdot
.39771 .4649 Mdot
.79648 .57085 Mdot
.56493 .35325 Mdot
.50692 .68544 Mdot
.36602 .44736 Mdot
.66328 .67613 Mdot
.67836 .51701 Mdot
.75635 .62254 Mdot
.66172 .20992 Mdot
.80957 .53889 Mdot
.37316 .23727 Mdot
.53971 .67298 Mdot
.37101 .46048 Mdot
.60247 .50583 Mdot
.56733 .34046 Mdot
.55856 .34233 Mdot
.65999 .57047 Mdot
.61005 .52293 Mdot
.67319 .53956 Mdot
.66372 .56372 Mdot
.48622 .76679 Mdot
.67185 .54827 Mdot
.41132 .56454 Mdot
.57294 .30688 Mdot
.60205 .5299 Mdot
.37727 .59817 Mdot
.66617 .57873 Mdot
.35828 .44117 Mdot
.64448 .53192 Mdot
.61328 .51364 Mdot
.58063 .53729 Mdot
.38564 .46268 Mdot
.1897 .61141 Mdot
.60931 .20858 Mdot
.30394 .72992 Mdot
.41195 .22716 Mdot
.35547 .57634 Mdot
.63349 .56812 Mdot
.51887 .69834 Mdot
.62377 .62295 Mdot
.63562 .53321 Mdot
.81518 .46932 Mdot
.61993 .51555 Mdot
.69893 .45573 Mdot
.58006 .59569 Mdot
.27893 .72241 Mdot
.44863 .47247 Mdot
.60813 .54882 Mdot
.66009 .28627 Mdot
.76856 .62321 Mdot
.53806 .6281 Mdot
.39909 .4523 Mdot
.38329 .58041 Mdot
.36734 .58727 Mdot
.41624 .41564 Mdot
.64007 .46665 Mdot
.62854 .33933 Mdot
.65818 .46714 Mdot
.30401 .34184 Mdot
.60275 .33699 Mdot
.5303 .65733 Mdot
.53273 .31378 Mdot
.54172 .15065 Mdot
.50434 .3905 Mdot
.37577 .48589 Mdot
.49204 .69853 Mdot
.35072 .62572 Mdot
.3089 .34443 Mdot
.51279 .69659 Mdot
.65073 .50938 Mdot
.53239 .33641 Mdot
.77603 .6179 Mdot
.62347 .60533 Mdot
.63537 .81231 Mdot
.58339 .34268 Mdot
.45916 .50379 Mdot
.3922 .45249 Mdot
.31047 .59432 Mdot
.61297 .56799 Mdot
.6661 .5474 Mdot
.5484 .37686 Mdot
.63164 .5168 Mdot
.50604 .28443 Mdot
.61679 .51059 Mdot
.3459 .63455 Mdot
.55455 .67887 Mdot
.37763 .39738 Mdot
.71244 .71135 Mdot
.56911 .29246 Mdot
.4065 .61595 Mdot
.33603 .61831 Mdot
.61445 .29288 Mdot
.37382 .4129 Mdot
.5024 .70663 Mdot
.36036 .60884 Mdot
.53725 .70318 Mdot
.58716 .52999 Mdot
.35196 .60729 Mdot
.5166 .66542 Mdot
.33329 .69349 Mdot
.63948 .49626 Mdot
.62185 .66156 Mdot
.37129 .4347 Mdot
.52558 .35178 Mdot
.61271 .53562 Mdot
.28447 .35243 Mdot
.68356 .50612 Mdot
.27004 .31512 Mdot
.28697 .3322 Mdot
.29834 .32909 Mdot
.24843 .39757 Mdot
.5329 .69817 Mdot
.39196 .27188 Mdot
.51816 .44344 Mdot
.59461 .32644 Mdot
.62855 .48971 Mdot
.22484 .66569 Mdot
.36769 .44933 Mdot
.65052 .51053 Mdot
.26349 .60514 Mdot
.36618 .44634 Mdot
.65471 .54009 Mdot
.39508 .46063 Mdot
.56428 .3427 Mdot
.43574 .57865 Mdot
.57664 .36179 Mdot
.63528 .49803 Mdot
.39792 .43229 Mdot
.37421 .59449 Mdot
.54938 .32818 Mdot
.62481 .5371 Mdot
.63189 .56519 Mdot
.3056 .34884 Mdot
.60122 .53647 Mdot
.23798 .66965 Mdot
.63366 .50986 Mdot
.35995 .62125 Mdot
.57795 .51288 Mdot
.82108 .56245 Mdot
.38166 .69923 Mdot
.57853 .30494 Mdot
.29054 .33081 Mdot
.34717 .60131 Mdot
.44343 .62585 Mdot
.52781 .58512 Mdot
.62142 .54913 Mdot
.28939 .34501 Mdot
.43648 .52071 Mdot
.41198 .43542 Mdot
.59829 .48555 Mdot
.47641 .36571 Mdot
.34699 .61772 Mdot
.30711 .34432 Mdot
.56715 .56518 Mdot
.57868 .36626 Mdot
.61836 .49721 Mdot
.35915 .60512 Mdot
.54414 .36671 Mdot
.67568 .50592 Mdot
.50952 .77028 Mdot
.28255 .3417 Mdot
.37122 .43687 Mdot
.5557 .46811 Mdot
.67548 .52881 Mdot
.37164 .58063 Mdot
.57843 .3402 Mdot
.40481 .43267 Mdot
.54501 .31763 Mdot
.77129 .6316 Mdot
.42185 .23381 Mdot
.40208 .76361 Mdot
.49069 .68936 Mdot
.26677 .30011 Mdot
.32176 .74464 Mdot
.42578 .25499 Mdot
.65529 .72928 Mdot
.41792 .82038 Mdot
.37162 .60383 Mdot
.65223 .64123 Mdot
.35397 .59402 Mdot
.59467 .51549 Mdot
.3354 .59248 Mdot
.25939 .71799 Mdot
.62601 .51012 Mdot
.35902 .5762 Mdot
.46642 .74895 Mdot
.6107 .52848 Mdot
.56082 .30403 Mdot
.16654 .43043 Mdot
.57791 .22861 Mdot
.54063 .41608 Mdot
.3595 .57029 Mdot
.79461 .39107 Mdot
.62229 .51883 Mdot
.62484 .59733 Mdot
.56473 .33585 Mdot
.59724 .4841 Mdot
.518 .65871 Mdot
.52808 .71347 Mdot
.7528 .6094 Mdot
.52055 .20046 Mdot
.70071 .50118 Mdot
.55209 .33126 Mdot
.66538 .24458 Mdot
.41969 .32168 Mdot
.30046 .363 Mdot
.40654 .47215 Mdot
.1899 .60735 Mdot
.6857 .59687 Mdot
.51524 .49337 Mdot
.46839 .36254 Mdot
.53807 .34449 Mdot
.29479 .69173 Mdot
.40177 .44071 Mdot
.6471 .25581 Mdot
.66256 .40351 Mdot
.67134 .52962 Mdot
.40309 .4154 Mdot
.5931 .46514 Mdot
.48878 .30334 Mdot
.67007 .65279 Mdot
.32919 .47846 Mdot
.63353 .49537 Mdot
.39808 .27942 Mdot
.6403 .5395 Mdot
.74755 .62993 Mdot
.64513 .50466 Mdot
.55092 .31274 Mdot
.7021 .497 Mdot
.49601 .57363 Mdot
.57095 .19995 Mdot
.49274 .37645 Mdot
.54213 .67747 Mdot
.63578 .55974 Mdot
.67022 .53542 Mdot
.53238 .67166 Mdot
.55857 .31939 Mdot
.65887 .50568 Mdot
.57187 .78091 Mdot
.67398 .52908 Mdot
.35521 .43377 Mdot
.45269 .59515 Mdot
.58877 .39957 Mdot
.62903 .57948 Mdot
.55664 .37192 Mdot
.4027 .45408 Mdot
.39313 .47732 Mdot
.69924 .56649 Mdot
.37422 .46173 Mdot
.61856 .4997 Mdot
.44772 .58887 Mdot
.55281 .36211 Mdot
.55498 .53288 Mdot
.56381 .31818 Mdot
.73516 .29796 Mdot
.4015 .45922 Mdot
.30934 .36038 Mdot
.55454 .59891 Mdot
.39104 .43626 Mdot
.57155 .23654 Mdot
.69979 .58225 Mdot
.69167 .54919 Mdot
.57484 .23377 Mdot
.37807 .57522 Mdot
.31396 .35148 Mdot
.40669 .43796 Mdot
.67469 .53601 Mdot
.58754 .51399 Mdot
.3654 .41315 Mdot
.75085 .36308 Mdot
.44606 .647 Mdot
.64217 .50387 Mdot
.55395 .31374 Mdot
.5438 .3421 Mdot
.66877 .50009 Mdot
.63233 .53073 Mdot
.37272 .60904 Mdot
.28846 .3477 Mdot
.30712 .33598 Mdot
.29024 .35645 Mdot
.33347 .56525 Mdot
.29766 .28194 Mdot
.39678 .46531 Mdot
.32479 .29915 Mdot
.24336 .54771 Mdot
.68834 .58165 Mdot
.37455 .58024 Mdot
.65945 .54858 Mdot
.591 .53108 Mdot
.3993 .42851 Mdot
.39117 .20088 Mdot
.66312 .45955 Mdot
.525 .32225 Mdot
.35257 .42829 Mdot
.57447 .60077 Mdot
.4396 .41142 Mdot
.50937 .66568 Mdot
.51247 .39004 Mdot
.39607 .41162 Mdot
.53588 .32794 Mdot
.37629 .40913 Mdot
.67152 .53565 Mdot
.66136 .57473 Mdot
.5466 .35683 Mdot
.53222 .7002 Mdot
.59268 .50027 Mdot
.65351 .54036 Mdot
.85279 .50674 Mdot
.42017 .31237 Mdot
.43637 .41213 Mdot
.59628 .53047 Mdot
.69406 .55088 Mdot
.54068 .68958 Mdot
.67113 .51883 Mdot
.61523 .56956 Mdot
.4653 .28409 Mdot
.41615 .41312 Mdot
.54738 .64867 Mdot
.63712 .25218 Mdot
.58408 .33931 Mdot
.24301 .65877 Mdot
.29283 .33708 Mdot
.39466 .39654 Mdot
.43337 .57107 Mdot
.30877 .35657 Mdot
.26335 .53685 Mdot
.27189 .67468 Mdot
.30271 .36003 Mdot
.38618 .53682 Mdot
.72289 .58157 Mdot
.67832 .54948 Mdot
.64739 .53255 Mdot
.51459 .70128 Mdot
.56711 .34936 Mdot
.43961 .49811 Mdot
.32053 .67344 Mdot
.63628 .54938 Mdot
.50673 .33269 Mdot
.25712 .6541 Mdot
.30801 .34959 Mdot
.53048 .69487 Mdot
.53312 .65496 Mdot
.64148 .54221 Mdot
.45841 .25781 Mdot
.54885 .33098 Mdot
.62497 .53727 Mdot
.65086 .56931 Mdot
.36418 .57022 Mdot
.53376 .32688 Mdot
.33483 .61795 Mdot
.2835 .3337 Mdot
.50692 .8351 Mdot
.85053 .52542 Mdot
.38438 .42377 Mdot
.30671 .72011 Mdot
.36658 .46818 Mdot
.30246 .4187 Mdot
.29155 .35541 Mdot
.62896 .54352 Mdot
.57112 .29451 Mdot
.62154 .53813 Mdot
.66473 .51773 Mdot
.65565 .50959 Mdot
.69917 .49756 Mdot
.81664 .47708 Mdot
.51596 .68758 Mdot
.69799 .54317 Mdot
.38692 .56908 Mdot
.27048 .69936 Mdot
.16232 .47022 Mdot
.65004 .56156 Mdot
.64204 .54721 Mdot
.58734 .31914 Mdot
.61832 .5853 Mdot
.40698 .42512 Mdot
.57425 .35097 Mdot
.59075 .50785 Mdot
.31948 .70201 Mdot
.67306 .51556 Mdot
.33701 .75285 Mdot
.37216 .41004 Mdot
.52159 .39512 Mdot
.69827 .51835 Mdot
.30145 .36036 Mdot
.31381 .35303 Mdot
.30082 .36503 Mdot
.41267 .42766 Mdot
.36634 .57597 Mdot
.29986 .65149 Mdot
.57108 .49988 Mdot
.6058 .50399 Mdot
.6952 .54027 Mdot
.31375 .58432 Mdot
.45943 .57828 Mdot
.37605 .2451 Mdot
.62961 .61701 Mdot
.38045 .56546 Mdot
.51698 .32333 Mdot
.47735 .1718 Mdot
.57588 .34705 Mdot
.54941 .65075 Mdot
.3579 .43189 Mdot
.50719 .66551 Mdot
.80933 .43133 Mdot
.54541 .35868 Mdot
.54564 .37662 Mdot
.35753 .57555 Mdot
.46365 .47239 Mdot
.10361 .42483 Mdot
.32745 .58707 Mdot
.61665 .76542 Mdot
.5611 .33257 Mdot
.59136 .56692 Mdot
.43013 .52531 Mdot
.46588 .478 Mdot
.35107 .58716 Mdot
.62261 .55961 Mdot
.51408 .21586 Mdot
.36758 .61372 Mdot
.59498 .48988 Mdot
.35225 .56719 Mdot
.38234 .46034 Mdot
.34684 .57231 Mdot
.53129 .3005 Mdot
.58838 .53441 Mdot
.14211 .34688 Mdot
.43537 .38355 Mdot
.61412 .5383 Mdot
.35335 .43212 Mdot
.55311 .79309 Mdot
.66544 .52761 Mdot
.51511 .65892 Mdot
.37469 .55603 Mdot
.44751 .70907 Mdot
.62036 .52284 Mdot
.34207 .58692 Mdot
.52124 .32478 Mdot
.41001 .39226 Mdot
.26301 .38825 Mdot
.31131 .34145 Mdot
.57109 .34223 Mdot
.31297 .36929 Mdot
.42011 .44578 Mdot
.58166 .51667 Mdot
.65893 .56435 Mdot
.56359 .30734 Mdot
.24131 .43886 Mdot
.58192 .56335 Mdot
.62133 .55629 Mdot
.34386 .62471 Mdot
.31503 .57583 Mdot
.19375 .46156 Mdot
.37417 .60029 Mdot
.69505 .54887 Mdot
.56052 .30757 Mdot
.5988 .50346 Mdot
.5665 .30353 Mdot
.6276 .48985 Mdot
.56541 .39937 Mdot
.57331 .3481 Mdot
.46861 .20847 Mdot
.60306 .55694 Mdot
.54705 .55576 Mdot
.6643 .51525 Mdot
.6501 .50627 Mdot
.3716 .55446 Mdot
.5219 .67284 Mdot
.57897 .50129 Mdot
.42161 .59792 Mdot
.51873 .70757 Mdot
.7567 .52404 Mdot
.36646 .56939 Mdot
.50747 .70031 Mdot
.58674 .68725 Mdot
.2916 .33087 Mdot
.52285 .68862 Mdot
.17318 .50971 Mdot
.3879 .42409 Mdot
.56304 .36424 Mdot
.60974 .52845 Mdot
.45323 .83532 Mdot
.45473 .64053 Mdot
.30097 .35263 Mdot
.61985 .52883 Mdot
.66199 .54331 Mdot
.58824 .35729 Mdot
.57515 .16009 Mdot
.31461 .62405 Mdot
.61423 .49314 Mdot
.58953 .34212 Mdot
.65123 .20388 Mdot
.34062 .56903 Mdot
.52362 .69329 Mdot
.35622 .4181 Mdot
.54462 .28162 Mdot
.31319 .34361 Mdot
.41452 .44732 Mdot
.34593 .54376 Mdot
.8035 .39297 Mdot
.62586 .52053 Mdot
.3724 .58873 Mdot
.81072 .53327 Mdot
.60775 .47211 Mdot
.43495 .44439 Mdot
.67138 .44785 Mdot
.53792 .34145 Mdot
.35885 .41774 Mdot
.54266 .66646 Mdot
.55533 .3635 Mdot
.55665 .31939 Mdot
.38097 .47467 Mdot
.40052 .59712 Mdot
.46097 .5014 Mdot
.35656 .4235 Mdot
.47715 .30496 Mdot
.77226 .59896 Mdot
.28761 .3443 Mdot
.53278 .69284 Mdot
.7836 .62426 Mdot
.54558 .33365 Mdot
.19021 .60863 Mdot
.81502 .48528 Mdot
.64775 .50225 Mdot
.50408 .67897 Mdot
.26551 .54932 Mdot
.29527 .65168 Mdot
.36508 .44174 Mdot
.4713 .57196 Mdot
.51903 .65451 Mdot
.67944 .52724 Mdot
.58414 .40837 Mdot
.60469 .55608 Mdot
.36736 .452 Mdot
.52091 .26337 Mdot
.53713 .32072 Mdot
.42114 .43863 Mdot
.49553 .29826 Mdot
.59154 .53534 Mdot
.61345 .56213 Mdot
.72047 .67051 Mdot
.53151 .33557 Mdot
.31257 .34109 Mdot
.61748 .54612 Mdot
.65492 .53097 Mdot
.57967 .52198 Mdot
.53886 .53155 Mdot
.44663 .27624 Mdot
.61219 .49291 Mdot
.33515 .5666 Mdot
.67979 .56458 Mdot
.6122 .56341 Mdot
.58356 .3576 Mdot
.83978 .49774 Mdot
.27989 .33775 Mdot
.64844 .52935 Mdot
.6435 .50577 Mdot
.40032 .47105 Mdot
.44773 .5117 Mdot
.46774 .46826 Mdot
.32071 .60616 Mdot
.6471 .71792 Mdot
.66399 .4714 Mdot
.58293 .32568 Mdot
.49433 .68721 Mdot
.59391 .56317 Mdot
.58699 .32828 Mdot
.68074 .5556 Mdot
.38391 .59228 Mdot
.28966 .34768 Mdot
.54084 .45028 Mdot
.52653 .68486 Mdot
.38451 .51819 Mdot
.34824 .32154 Mdot
.38029 .59304 Mdot
.6042 .51139 Mdot
.3779 .39002 Mdot
.335 .61428 Mdot
.304 .34928 Mdot
.57014 .5736 Mdot
.55707 .33958 Mdot
.53891 .32058 Mdot
.75164 .61769 Mdot
.3054 .62224 Mdot
.79983 .33619 Mdot
.38034 .45982 Mdot
.65035 .48309 Mdot
.33633 .34456 Mdot
.54217 .31442 Mdot
.75175 .64766 Mdot
.50978 .702 Mdot
.36539 .4399 Mdot
.27565 .34685 Mdot
.58642 .32344 Mdot
.53388 .31799 Mdot
.64037 .49462 Mdot
.64687 .55895 Mdot
.65156 .73657 Mdot
.75419 .6256 Mdot
.39067 .46058 Mdot
.53514 .68552 Mdot
.3149 .60542 Mdot
.59366 .53128 Mdot
.56801 .35667 Mdot
.70998 .46435 Mdot
.67599 .539 Mdot
.36573 .61561 Mdot
.54146 .34867 Mdot
.53551 .67583 Mdot
.49938 .69433 Mdot
.65082 .50632 Mdot
.77038 .46424 Mdot
.38638 .43406 Mdot
.55193 .30545 Mdot
.60756 .29531 Mdot
.57566 .55163 Mdot
.64382 .56121 Mdot
.57128 .4813 Mdot
.4142 .44817 Mdot
.55777 .43564 Mdot
.51386 .65217 Mdot
.55675 .34632 Mdot
.61589 .53921 Mdot
.52942 .68623 Mdot
.53511 .48418 Mdot
.29973 .35769 Mdot
.34967 .56778 Mdot
.52141 .65706 Mdot
.52011 .66714 Mdot
.51479 .70977 Mdot
.18685 .59568 Mdot
.60099 .32474 Mdot
.62935 .2381 Mdot
.65372 .50414 Mdot
.7505 .6132 Mdot
.62754 .58647 Mdot
.41656 .43099 Mdot
.3798 .5854 Mdot
.6681 .52272 Mdot
.63977 .49411 Mdot
.59576 .41348 Mdot
.56672 .59228 Mdot
.51846 .28618 Mdot
.53394 .34674 Mdot
.54733 .5643 Mdot
.37351 .57248 Mdot
.63241 .17401 Mdot
.1711 .62117 Mdot
.6886 .49984 Mdot
.45025 .49772 Mdot
.57231 .35238 Mdot
.38144 .47263 Mdot
.47324 .47556 Mdot
.36027 .41003 Mdot
.55372 .34877 Mdot
.59341 .52214 Mdot
.33105 .29834 Mdot
.52804 .71055 Mdot
.67149 .54535 Mdot
.38734 .45486 Mdot
.67251 .54253 Mdot
.41342 .42199 Mdot
.49978 .31627 Mdot
.46049 .3466 Mdot
.62161 .51425 Mdot
.57893 .55444 Mdot
.58322 .4264 Mdot
.64982 .56068 Mdot
.28474 .50178 Mdot
.56632 .32471 Mdot
.51567 .20787 Mdot
.66579 .49981 Mdot
.76837 .42569 Mdot
.6779 .53937 Mdot
.23998 .45187 Mdot
.63749 .57024 Mdot
.49239 .52011 Mdot
.67893 .52169 Mdot
.63116 .56791 Mdot
.40239 .43587 Mdot
.3976 .47307 Mdot
.52232 .32283 Mdot
.31652 .34896 Mdot
.27768 .71921 Mdot
.65017 .54758 Mdot
.35289 .5542 Mdot
.34496 .35717 Mdot
.52081 .66904 Mdot
.55086 .34564 Mdot
.70746 .22302 Mdot
.39972 .45785 Mdot
.34934 .63199 Mdot
.2566 .45346 Mdot
.30761 .60849 Mdot
.33561 .45018 Mdot
.55524 .58635 Mdot
.53806 .67999 Mdot
.67872 .53899 Mdot
.76889 .51259 Mdot
.40647 .29298 Mdot
.60896 .48492 Mdot
.42659 .43032 Mdot
.62114 .62479 Mdot
.77996 .59286 Mdot
.54753 .67716 Mdot
.53863 .66533 Mdot
.40526 .43978 Mdot
.33131 .62463 Mdot
.62752 .46146 Mdot
.50644 .70011 Mdot
.38403 .57591 Mdot
.31907 .35863 Mdot
.53703 .6095 Mdot
.54866 .33424 Mdot
.54085 .42224 Mdot
.39167 .33971 Mdot
.39279 .45985 Mdot
.42557 .59072 Mdot
.52628 .29456 Mdot
.58288 .36886 Mdot
.31459 .35938 Mdot
.37787 .55447 Mdot
.58944 .30243 Mdot
.58756 .50714 Mdot
.62576 .60606 Mdot
.63903 .54012 Mdot
.50451 .69315 Mdot
.63807 .57264 Mdot
.38549 .56322 Mdot
.37106 .44997 Mdot
.3421 .60883 Mdot
.38442 .432 Mdot
.33663 .28377 Mdot
.63179 .52688 Mdot
.63946 .5597 Mdot
.43847 .55091 Mdot
.52842 .32078 Mdot
.78966 .46131 Mdot
.36927 .54907 Mdot
.36011 .58621 Mdot
.59613 .50594 Mdot
.52093 .33088 Mdot
.52988 .72071 Mdot
.42218 .53632 Mdot
.64519 .56997 Mdot
.56761 .32515 Mdot
.61066 .49707 Mdot
.40071 .75619 Mdot
.44979 .3449 Mdot
.54403 .31719 Mdot
.55056 .18978 Mdot
.59988 .54457 Mdot
.70385 .60629 Mdot
.693 .55822 Mdot
.58954 .75445 Mdot
.57335 .53675 Mdot
.58251 .34495 Mdot
.64249 .53279 Mdot
.57929 .33415 Mdot
.35433 .62066 Mdot
.38877 .46868 Mdot
.57142 .3388 Mdot
.62267 .57982 Mdot
.15877 .564 Mdot
.38718 .45772 Mdot
.63295 .56313 Mdot
.38618 .41382 Mdot
.58494 .34981 Mdot
.52705 .33144 Mdot
.17807 .51405 Mdot
.44119 .43321 Mdot
.39112 .45741 Mdot
.61293 .50081 Mdot
.40779 .36275 Mdot
.59943 .50313 Mdot
.66216 .73148 Mdot
.65205 .48897 Mdot
.57878 .50922 Mdot
.25276 .30754 Mdot
.35046 .41664 Mdot
.76237 .28972 Mdot
.32437 .67934 Mdot
.18094 .57986 Mdot
.58081 .28814 Mdot
.54759 .67705 Mdot
.28569 .68252 Mdot
.28506 .33394 Mdot
.35867 .5598 Mdot
.66848 .52247 Mdot
.57409 .4008 Mdot
.35365 .42573 Mdot
.5171 .67551 Mdot
.62065 .51478 Mdot
.38087 .60023 Mdot
.17449 .48141 Mdot
.37033 .45976 Mdot
.5467 .3366 Mdot
.52667 .32193 Mdot
.62738 .2043 Mdot
.61727 .53565 Mdot
.63897 .55624 Mdot
.3576 .43467 Mdot
.65846 .47095 Mdot
.51283 .71351 Mdot
.44425 .75505 Mdot
.39466 .4545 Mdot
.42307 .37702 Mdot
.53731 .35503 Mdot
.66139 .54558 Mdot
.45836 .59942 Mdot
.21797 .56167 Mdot
.65272 .30408 Mdot
.51548 .7003 Mdot
.68287 .70338 Mdot
.5828 .34444 Mdot
.38442 .45186 Mdot
.61027 .65019 Mdot
.67973 .50075 Mdot
.66069 .5402 Mdot
.68863 .69791 Mdot
.43911 .51505 Mdot
.50662 .7296 Mdot
.61191 .58455 Mdot
.44496 .51971 Mdot
.59436 .50882 Mdot
.58761 .51517 Mdot
.68566 .49391 Mdot
.6227 .57366 Mdot
.57299 .32902 Mdot
.60146 .40569 Mdot
.34113 .58086 Mdot
.71419 .32227 Mdot
.4791 .5611 Mdot
.60652 .53825 Mdot
.59239 .52686 Mdot
.61863 .28277 Mdot
.34662 .36646 Mdot
.56262 .32634 Mdot
.57924 .38919 Mdot
.40413 .46043 Mdot
.56087 .58044 Mdot
.30319 .6101 Mdot
.62736 .43193 Mdot
.33549 .60997 Mdot
.5687 .32475 Mdot
.366 .58211 Mdot
.40579 .46089 Mdot
.37157 .59003 Mdot
.33367 .56553 Mdot
.39624 .4089 Mdot
.53385 .35311 Mdot
.64706 .56763 Mdot
.39895 .46086 Mdot
.71694 .67738 Mdot
.50397 .69292 Mdot
.17734 .51291 Mdot
.63951 .59551 Mdot
.73825 .54469 Mdot
.50944 .76995 Mdot
.35142 .60382 Mdot
.44843 .32594 Mdot
.57318 .34801 Mdot
.4982 .70967 Mdot
.57605 .33172 Mdot
.80705 .46034 Mdot
.53018 .67239 Mdot
.17586 .51509 Mdot
.5889 .64775 Mdot
.42221 .63728 Mdot
.64596 .57945 Mdot
.53649 .38643 Mdot
.33888 .61483 Mdot
.35527 .4357 Mdot
.26983 .57574 Mdot
.60454 .5674 Mdot
.42127 .2546 Mdot
.60003 .33794 Mdot
.29866 .33197 Mdot
.38014 .44847 Mdot
.42694 .43902 Mdot
.62151 .5316 Mdot
.43851 .62121 Mdot
.61509 .48519 Mdot
.59644 .63823 Mdot
.66187 .71853 Mdot
.632 .43241 Mdot
.62066 .49774 Mdot
.32628 .61103 Mdot
.6108 .49798 Mdot
.69335 .6024 Mdot
.79485 .57208 Mdot
.64392 .59484 Mdot
.43511 .22288 Mdot
.45834 .70715 Mdot
.55105 .35808 Mdot
.70059 .52485 Mdot
.29689 .34611 Mdot
.59732 .53658 Mdot
.56517 .86277 Mdot
.52211 .68506 Mdot
.28921 .61593 Mdot
.63146 .58317 Mdot
.61889 .54216 Mdot
.75233 .47982 Mdot
.53255 .39338 Mdot
.27528 .34339 Mdot
.6605 .53354 Mdot
.65876 .69896 Mdot
.40303 .42774 Mdot
.66653 .49293 Mdot
.64455 .53545 Mdot
.76642 .65287 Mdot
.3974 .41969 Mdot
.35997 .59782 Mdot
.28852 .33121 Mdot
.3155 .60161 Mdot
.54866 .66516 Mdot
.47333 .44939 Mdot
.75623 .63548 Mdot
.44829 .3464 Mdot
.51111 .65957 Mdot
.6472 .57439 Mdot
.72969 .5885 Mdot
.61287 .55437 Mdot
.54085 .66667 Mdot
.4009 .41895 Mdot
.57085 .33133 Mdot
.53385 .44867 Mdot
.3042 .34315 Mdot
.59231 .49299 Mdot
.54583 .68141 Mdot
.56395 .33951 Mdot
.19483 .50042 Mdot
.56097 .35153 Mdot
.39465 .43802 Mdot
.41869 .44171 Mdot
.52811 .67558 Mdot
.57528 .32972 Mdot
.33024 .57408 Mdot
.32623 .67734 Mdot
.64517 .48743 Mdot
.42702 .3978 Mdot
.54574 .2953 Mdot
.53378 .36596 Mdot
.58083 .30211 Mdot
.62932 .52359 Mdot
.44926 .5059 Mdot
.67736 .49404 Mdot
.40715 .44819 Mdot
.36163 .56325 Mdot
.75754 .62098 Mdot
.77287 .49672 Mdot
.43707 .38244 Mdot
.5787 .50316 Mdot
.61701 .56771 Mdot
.64131 .54245 Mdot
.63706 .50182 Mdot
.43054 .76138 Mdot
.63318 .52793 Mdot
.39383 .43144 Mdot
.32985 .59525 Mdot
.61649 .53237 Mdot
.29398 .34421 Mdot
.46803 .51346 Mdot
.4956 .68164 Mdot
.48934 .52705 Mdot
.17548 .60927 Mdot
.56429 .33822 Mdot
.36437 .60467 Mdot
.34946 .56418 Mdot
.50383 .70536 Mdot
.37998 .46158 Mdot
.56506 .34938 Mdot
.58301 .74322 Mdot
.52338 .70736 Mdot
.6487 .52834 Mdot
.44231 .58053 Mdot
.52031 .18073 Mdot
.6642 .56609 Mdot
.65764 .51532 Mdot
.29497 .32866 Mdot
.3119 .62047 Mdot
.4512 .85092 Mdot
.41743 .51646 Mdot
.52386 .67364 Mdot
.52928 .66265 Mdot
.58885 .30693 Mdot
.61557 .48038 Mdot
.37884 .43503 Mdot
.42943 .5305 Mdot
.58289 .79301 Mdot
.25529 .60392 Mdot
.29688 .41659 Mdot
.67109 .51486 Mdot
.72074 .45356 Mdot
.62628 .48781 Mdot
.5861 .3616 Mdot
.58851 .31274 Mdot
.55697 .32817 Mdot
.40217 .43871 Mdot
.74057 .30598 Mdot
.39075 .43001 Mdot
.17527 .61347 Mdot
.5717 .35682 Mdot
.39502 .67583 Mdot
.36251 .57864 Mdot
.5728 .49906 Mdot
.53691 .68419 Mdot
.35273 .37852 Mdot
.69695 .5044 Mdot
.45132 .25766 Mdot
.37435 .58067 Mdot
.52779 .33901 Mdot
.68047 .60488 Mdot
.30298 .75331 Mdot
.46464 .43893 Mdot
.48708 .65175 Mdot
.79877 .47526 Mdot
.5324 .67267 Mdot
.63851 .28966 Mdot
.52014 .71323 Mdot
.36512 .44704 Mdot
.60608 .5691 Mdot
.61378 .574 Mdot
.62378 .4935 Mdot
.63445 .52495 Mdot
.40677 .43485 Mdot
.65921 .50006 Mdot
.82099 .56201 Mdot
.28547 .33927 Mdot
.36057 .70796 Mdot
.50128 .67665 Mdot
.40863 .41286 Mdot
.33016 .60461 Mdot
.31796 .35175 Mdot
.72361 .70222 Mdot
.66345 .50574 Mdot
.66628 .51818 Mdot
.29494 .3605 Mdot
.67391 .48394 Mdot
.68151 .60183 Mdot
.33935 .5849 Mdot
.47616 .40606 Mdot
.53816 .65831 Mdot
.50782 .66521 Mdot
.3885 .40915 Mdot
.57627 .33135 Mdot
.51429 .70247 Mdot
.3356 .62559 Mdot
.67821 .51218 Mdot
.58106 .54884 Mdot
.54425 .29591 Mdot
.8151 .4852 Mdot
.53923 .70258 Mdot
.7072 .57453 Mdot
.58211 .33666 Mdot
.60068 .33393 Mdot
.66216 .53438 Mdot
.57993 .57952 Mdot
.53725 .36565 Mdot
.49844 .68065 Mdot
.40588 .41114 Mdot
.41479 .65122 Mdot
.36989 .45315 Mdot
.56686 .34508 Mdot
.688 .53357 Mdot
.5351 .35384 Mdot
.59994 .53975 Mdot
.46166 .11779 Mdot
.62854 .57373 Mdot
.5702 .23254 Mdot
.59851 .75473 Mdot
.34532 .56735 Mdot
.32586 .5798 Mdot
.2907 .34535 Mdot
.58226 .34086 Mdot
.59207 .56014 Mdot
.53478 .66701 Mdot
.17409 .56148 Mdot
.60722 .33709 Mdot
.37672 .56369 Mdot
.30533 .61378 Mdot
.40545 .42562 Mdot
.67365 .55129 Mdot
.65729 .54958 Mdot
.36983 .59159 Mdot
.50076 .76928 Mdot
.5802 .32032 Mdot
.63844 .5561 Mdot
.61384 .5661 Mdot
.33799 .5815 Mdot
.33065 .68037 Mdot
.50886 .36351 Mdot
.62134 .57276 Mdot
.58481 .65294 Mdot
.4149 .42912 Mdot
.62854 .50471 Mdot
.65592 .49954 Mdot
.51192 .6732 Mdot
.35053 .71675 Mdot
.7842 .58728 Mdot
.41749 .42127 Mdot
.31001 .33854 Mdot
.61647 .58016 Mdot
.36027 .57921 Mdot
.59015 .5653 Mdot
.3917 .78873 Mdot
.28891 .33519 Mdot
.6301 .53778 Mdot
.68457 .49544 Mdot
.54952 .30404 Mdot
.62678 .53789 Mdot
.63039 .42641 Mdot
.32105 .59771 Mdot
.62967 .53627 Mdot
.77368 .4602 Mdot
.40768 .43141 Mdot
.69902 .51353 Mdot
.52752 .65886 Mdot
.5849 .75913 Mdot
.36488 .33016 Mdot
.32698 .56814 Mdot
.49916 .68826 Mdot
.6415 .57206 Mdot
.3379 .62334 Mdot
.35318 .42131 Mdot
.43535 .25103 Mdot
.67959 .54905 Mdot
.37518 .45689 Mdot
.37355 .45089 Mdot
.52588 .67852 Mdot
.71087 .24057 Mdot
.67707 .48358 Mdot
.64824 .56365 Mdot
.69708 .75055 Mdot
.59651 .32464 Mdot
.64928 .56467 Mdot
.66733 .5582 Mdot
.37364 .43216 Mdot
.54979 .59526 Mdot
.56708 .25304 Mdot
.46661 .74933 Mdot
.41403 .42298 Mdot
.37182 .5441 Mdot
.34033 .62262 Mdot
.50049 .68031 Mdot
.54851 .35581 Mdot
.51239 .65617 Mdot
.35175 .57431 Mdot
.64852 .50459 Mdot
.36768 .42951 Mdot
.67561 .3441 Mdot
.35843 .4508 Mdot
.36548 .61783 Mdot
.55266 .37368 Mdot
.33083 .33705 Mdot
.75144 .73287 Mdot
.38884 .32844 Mdot
.40502 .40742 Mdot
.5203 .66903 Mdot
.41135 .53473 Mdot
.61676 .56697 Mdot
.63589 .26533 Mdot
.66272 .55722 Mdot
.7997 .47913 Mdot
.38174 .58183 Mdot
.31228 .36148 Mdot
.60527 .56884 Mdot
.67628 .70315 Mdot
.40854 .41054 Mdot
.40873 .42995 Mdot
.64505 .51527 Mdot
.39284 .43631 Mdot
.64978 .55448 Mdot
.33153 .58545 Mdot
.72483 .25667 Mdot
.62453 .56732 Mdot
.67358 .58073 Mdot
.41071 .4062 Mdot
.17681 .51297 Mdot
.38077 .55028 Mdot
.72806 .45997 Mdot
.32349 .77436 Mdot
.38931 .43665 Mdot
.69376 .56121 Mdot
.35386 .60727 Mdot
.29663 .32854 Mdot
.39731 .57092 Mdot
.66914 .54552 Mdot
.66383 .5109 Mdot
.59973 .49998 Mdot
.61227 .56166 Mdot
.62837 .26513 Mdot
.62127 .61298 Mdot
.69481 .41857 Mdot
.66401 .51637 Mdot
.61701 .32647 Mdot
.39751 .43029 Mdot
.51545 .29038 Mdot
.4911 .71617 Mdot
.66178 .50781 Mdot
.54345 .39988 Mdot
.41246 .41624 Mdot
.18554 .62319 Mdot
.40163 .42224 Mdot
.34424 .6028 Mdot
.37683 .47013 Mdot
.60125 .5382 Mdot
.54278 .34013 Mdot
.32466 .59527 Mdot
.36617 .2548 Mdot
.36443 .55865 Mdot
.61449 .53771 Mdot
.35937 .69258 Mdot
.34792 .56637 Mdot
.47568 .51744 Mdot
.5436 .34529 Mdot
.66381 .68959 Mdot
.5957 .33241 Mdot
.62615 .54384 Mdot
.62447 .54953 Mdot
.31843 .34868 Mdot
.37143 .46138 Mdot
.58281 .35104 Mdot
.85372 .50092 Mdot
.54169 .65153 Mdot
.55148 .32453 Mdot
.57241 .55738 Mdot
.44009 .50879 Mdot
.55103 .30771 Mdot
.6256 .71578 Mdot
.36944 .45677 Mdot
.58594 .30137 Mdot
.56649 .54874 Mdot
.51409 .50665 Mdot
.51606 .7175 Mdot
.38698 .58671 Mdot
.49803 .47245 Mdot
.33209 .61635 Mdot
.42202 .42821 Mdot
.32643 .62984 Mdot
.40111 .42695 Mdot
.57744 .23511 Mdot
.52345 .2636 Mdot
.36631 .39479 Mdot
.41966 .44262 Mdot
.35092 .58068 Mdot
.63966 .50303 Mdot
.48849 .58211 Mdot
.57051 .53749 Mdot
.6573 .57621 Mdot
.41335 .44559 Mdot
.58699 .3394 Mdot
.54899 .36549 Mdot
.53188 .38028 Mdot
.52856 .3243 Mdot
.32809 .60504 Mdot
.4554 .32777 Mdot
.80532 .43768 Mdot
.37593 .41287 Mdot
.3664 .47868 Mdot
.59685 .50806 Mdot
.35702 .57923 Mdot
.36396 .6137 Mdot
.37241 .43866 Mdot
.67128 .30544 Mdot
.69359 .5484 Mdot
.58833 .35335 Mdot
.57048 .35751 Mdot
.55284 .30882 Mdot
.56016 .29751 Mdot
.70439 .28055 Mdot
.35527 .43598 Mdot
.57819 .3485 Mdot
.64026 .52267 Mdot
.6724 .52184 Mdot
.30853 .34081 Mdot
.51262 .66486 Mdot
.64715 .59013 Mdot
.66327 .58425 Mdot
.6629 .53616 Mdot
.34972 .56698 Mdot
.56069 .50838 Mdot
.293 .33519 Mdot
.31672 .62575 Mdot
.31011 .59087 Mdot
.31075 .35958 Mdot
.59492 .28284 Mdot
.29699 .75758 Mdot
.61388 .49331 Mdot
.64643 .633 Mdot
.35662 .58405 Mdot
.49782 .25778 Mdot
.56789 .43338 Mdot
.62043 .49999 Mdot
.51773 .56943 Mdot
.32809 .58813 Mdot
.59923 .34882 Mdot
.65822 .55822 Mdot
.28944 .35447 Mdot
.49501 .68922 Mdot
.56721 .54355 Mdot
.29273 .32839 Mdot
.57017 .32344 Mdot
.46568 .67739 Mdot
.59382 .30973 Mdot
.34073 .56779 Mdot
.69947 .51305 Mdot
.1053 .41086 Mdot
.34109 .61676 Mdot
.21299 .60614 Mdot
.51201 .27727 Mdot
.62335 .56897 Mdot
.33483 .61767 Mdot
.59519 .35564 Mdot
.41509 .43121 Mdot
.44931 .52661 Mdot
.56584 .35716 Mdot
.3177 .35495 Mdot
.31247 .34853 Mdot
.33964 .58165 Mdot
.53572 .34488 Mdot
.65805 .49381 Mdot
.57135 .30328 Mdot
.37328 .46787 Mdot
.61244 .51463 Mdot
.27967 .72365 Mdot
.62834 .60642 Mdot
.58374 .33471 Mdot
.34927 .62846 Mdot
.53816 .69375 Mdot
.62327 .51434 Mdot
.239 .64123 Mdot
.67007 .55609 Mdot
.39285 .41485 Mdot
.49804 .23889 Mdot
.66427 .34546 Mdot
.64434 .50447 Mdot
.59338 .51788 Mdot
.38724 .40834 Mdot
.64424 .50285 Mdot
.66676 .56281 Mdot
.43437 .42921 Mdot
.54332 .3095 Mdot
.63664 .54299 Mdot
.38129 .5938 Mdot
.78773 .52743 Mdot
.61281 .57982 Mdot
.41966 .21915 Mdot
.66966 .69611 Mdot
.50931 .23721 Mdot
.60483 .57554 Mdot
.72403 .67535 Mdot
.62662 .55439 Mdot
.63004 .51738 Mdot
.6175 .49468 Mdot
.69836 .43926 Mdot
.35338 .57692 Mdot
.3808 .56283 Mdot
.5099 .71888 Mdot
.66628 .70001 Mdot
.50445 .68094 Mdot
.40447 .41388 Mdot
.24723 .40119 Mdot
.28682 .33874 Mdot
.57734 .33257 Mdot
.58783 .52826 Mdot
.35048 .5596 Mdot
.66372 .54569 Mdot
.59805 .5318 Mdot
.33389 .57879 Mdot
.33959 .61972 Mdot
.30925 .62828 Mdot
.52416 .70955 Mdot
.56455 .33154 Mdot
.64022 .49589 Mdot
.51954 .70716 Mdot
.66416 .49509 Mdot
.4278 .51657 Mdot
.56326 .32934 Mdot
.56815 .30239 Mdot
.57042 .36506 Mdot
.65491 .50493 Mdot
.60329 .53592 Mdot
.38894 .4296 Mdot
.54517 .29472 Mdot
.36523 .41566 Mdot
.3322 .61506 Mdot
.33159 .57523 Mdot
.66965 .54449 Mdot
.69875 .58956 Mdot
.52731 .66371 Mdot
.34809 .60279 Mdot
.28677 .35676 Mdot
.50696 .71722 Mdot
.62064 .52799 Mdot
.32948 .61236 Mdot
.5113 .66237 Mdot
.70542 .32967 Mdot
.37016 .80421 Mdot
.54016 .69311 Mdot
.64512 .51679 Mdot
.75928 .4833 Mdot
.64046 .65039 Mdot
.53781 .64885 Mdot
.37306 .41555 Mdot
.67226 .55129 Mdot
.52819 .79113 Mdot
.52774 .65309 Mdot
.81428 .49446 Mdot
.34063 .57314 Mdot
.56339 .61121 Mdot
.56859 .55599 Mdot
.65911 .27056 Mdot
.51927 .6529 Mdot
.5618 .34766 Mdot
.55409 .29088 Mdot
.64858 .52184 Mdot
.5013 .65713 Mdot
.38795 .47888 Mdot
.34658 .56445 Mdot
.34539 .55817 Mdot
.5347 .33827 Mdot
.44272 .36844 Mdot
.37384 .6064 Mdot
.68674 .48124 Mdot
.38798 .53566 Mdot
.54909 .5475 Mdot
.65381 .23475 Mdot
.35143 .26538 Mdot
.58047 .54147 Mdot
.54256 .68354 Mdot
.36568 .40925 Mdot
.39047 .43185 Mdot
.39919 .44194 Mdot
.31998 .58894 Mdot
.47609 .48467 Mdot
.37636 .58357 Mdot
.41735 .26523 Mdot
.52934 .68717 Mdot
.65135 .68157 Mdot
.59805 .56663 Mdot
.62064 .56776 Mdot
.67335 .501 Mdot
.59653 .50233 Mdot
.62808 .55486 Mdot
.39034 .45991 Mdot
.31196 .59735 Mdot
.45036 .71684 Mdot
.55686 .3121 Mdot
.20556 .45993 Mdot
.36291 .5786 Mdot
.29166 .32999 Mdot
.51433 .68541 Mdot
.74629 .63867 Mdot
.34483 .54961 Mdot
.36507 .58291 Mdot
.68429 .53314 Mdot
.59051 .32457 Mdot
.53729 .51989 Mdot
.62147 .55662 Mdot
.34948 .60308 Mdot
.35878 .62806 Mdot
.64277 .30793 Mdot
.62462 .4533 Mdot
.54315 .70661 Mdot
.4443 .50544 Mdot
.50851 .65608 Mdot
.59069 .58869 Mdot
.49478 .25964 Mdot
.35032 .57599 Mdot
.3398 .60008 Mdot
.54558 .67403 Mdot
.71199 .59587 Mdot
.54053 .35068 Mdot
.31062 .36224 Mdot
.38282 .416 Mdot
.61653 .55424 Mdot
.31864 .59452 Mdot
.64131 .63072 Mdot
.43911 .57994 Mdot
.3962 .4515 Mdot
.31517 .62502 Mdot
.67809 .53529 Mdot
.64827 .51469 Mdot
.5304 .67023 Mdot
.47179 .62488 Mdot
.56976 .54854 Mdot
.18136 .58082 Mdot
.4624 .35204 Mdot
.48992 .37695 Mdot
.66047 .54066 Mdot
.53294 .33038 Mdot
.29313 .35678 Mdot
.53294 .69327 Mdot
.67179 .50371 Mdot
.34122 .79148 Mdot
.51864 .31082 Mdot
.38342 .45548 Mdot
.29507 .35841 Mdot
.4765 .48774 Mdot
.66833 .55815 Mdot
.66236 .55742 Mdot
.63178 .52426 Mdot
.36622 .81057 Mdot
.38365 .5722 Mdot
.57304 .29873 Mdot
.51326 .69936 Mdot
.54098 .30634 Mdot
.37705 .5597 Mdot
.52265 .43765 Mdot
.61642 .5297 Mdot
.58406 .35982 Mdot
.55941 .3491 Mdot
.40576 .42567 Mdot
.41618 .44475 Mdot
.29497 .61384 Mdot
.63029 .57274 Mdot
.28598 .34922 Mdot
.59305 .32313 Mdot
.31635 .61937 Mdot
.53116 .67279 Mdot
.40307 .45939 Mdot
.66224 .51433 Mdot
.34449 .57965 Mdot
.59473 .49457 Mdot
.56786 .30546 Mdot
.36443 .58249 Mdot
.28142 .33125 Mdot
.52528 .66193 Mdot
.66257 .51156 Mdot
.4694 .71156 Mdot
.3037 .36157 Mdot
.60779 .56371 Mdot
.7504 .52802 Mdot
.48405 .70302 Mdot
.36862 .25069 Mdot
.37218 .5967 Mdot
.29644 .33999 Mdot
.5858 .3085 Mdot
.52329 .50129 Mdot
.33631 .60106 Mdot
.71675 .48263 Mdot
.48521 .60199 Mdot
.63901 .49669 Mdot
.54321 .32715 Mdot
.54935 .71106 Mdot
.18893 .6139 Mdot
.61354 .65698 Mdot
.63806 .55252 Mdot
.33315 .61753 Mdot
.50465 .66778 Mdot
.38257 .41154 Mdot
.42196 .2191 Mdot
.65274 .23887 Mdot
.30929 .62349 Mdot
.61763 .49092 Mdot
.5927 .32293 Mdot
.37256 .44084 Mdot
.32659 .29293 Mdot
.33828 .62648 Mdot
.37925 .59099 Mdot
.62306 .52119 Mdot
.52043 .70202 Mdot
.48992 .76839 Mdot
.38372 .56516 Mdot
.3142 .60157 Mdot
.19924 .4656 Mdot
.53925 .70081 Mdot
.64198 .52485 Mdot
.53209 .38051 Mdot
.68058 .52185 Mdot
.19032 .58056 Mdot
.29223 .33864 Mdot
.56016 .31163 Mdot
.67421 .53435 Mdot
.45659 .70781 Mdot
.3335 .60719 Mdot
.45209 .49637 Mdot
.33073 .6366 Mdot
.38593 .46187 Mdot
.32006 .59276 Mdot
.65923 .55467 Mdot
.41706 .41657 Mdot
.52509 .66355 Mdot
.62191 .57303 Mdot
.60262 .53385 Mdot
.591 .35969 Mdot
.36269 .4429 Mdot
.77246 .56958 Mdot
.41075 .47168 Mdot
.37644 .40925 Mdot
.60134 .31509 Mdot
.64885 .52495 Mdot
.35195 .59777 Mdot
.38766 .58817 Mdot
.65552 .49631 Mdot
.49829 .26109 Mdot
.53814 .34488 Mdot
.2952 .59484 Mdot
.44999 .84824 Mdot
.64539 .46144 Mdot
.28158 .34524 Mdot
.72438 .61428 Mdot
.41168 .43121 Mdot
.65278 .51177 Mdot
.58178 .32954 Mdot
.31167 .60956 Mdot
.37631 .60342 Mdot
.68139 .51223 Mdot
.37001 .44558 Mdot
.49953 .67205 Mdot
.37114 .60476 Mdot
.43649 .57729 Mdot
.62675 .53376 Mdot
.42057 .25264 Mdot
.36702 .60614 Mdot
.15164 .49609 Mdot
.45344 .71055 Mdot
.54475 .31836 Mdot
.59718 .52566 Mdot
.52376 .3231 Mdot
.50941 .69587 Mdot
.3977 .55216 Mdot
.36922 .44752 Mdot
.69876 .48023 Mdot
.79937 .61993 Mdot
.35754 .57517 Mdot
.5717 .32808 Mdot
.65152 .50385 Mdot
.69919 .48442 Mdot
.6405 .57023 Mdot
.54346 .58563 Mdot
.4772 .70952 Mdot
.41371 .45256 Mdot
.39602 .41395 Mdot
.59165 .5341 Mdot
.51636 .71219 Mdot
.38925 .56331 Mdot
.33844 .5755 Mdot
.62352 .16359 Mdot
.28284 .32981 Mdot
.63589 .7483 Mdot
.65789 .50835 Mdot
.31016 .61537 Mdot
.77363 .50065 Mdot
.3575 .43427 Mdot
.62905 .48172 Mdot
.31665 .58431 Mdot
.21493 .5449 Mdot
.43194 .51668 Mdot
.63183 .5426 Mdot
.65225 .46777 Mdot
.38666 .41456 Mdot
.41209 .52928 Mdot
.37505 .58476 Mdot
.65366 .48696 Mdot
.41796 .46135 Mdot
.18584 .48606 Mdot
.8183 .588 Mdot
.56399 .33137 Mdot
.35188 .62878 Mdot
.38685 .4613 Mdot
.58046 .48026 Mdot
.50141 .67579 Mdot
.31802 .60758 Mdot
.35747 .5617 Mdot
.6076 .51426 Mdot
.64029 .59151 Mdot
.64991 .46196 Mdot
.55985 .31963 Mdot
.38471 .42579 Mdot
.59535 .55819 Mdot
.45112 .36926 Mdot
.60271 .49617 Mdot
.38126 .42797 Mdot
.23907 .23876 Mdot
.67954 .55141 Mdot
.64405 .56662 Mdot
.54259 .74011 Mdot
.54844 .36222 Mdot
.53493 .31381 Mdot
.45741 .33956 Mdot
.65837 .50858 Mdot
.43168 .6337 Mdot
.56685 .33373 Mdot
.53842 .34191 Mdot
.38652 .682 Mdot
.61514 .51027 Mdot
.39079 .52503 Mdot
.37733 .43473 Mdot
.3917 .46205 Mdot
.55521 .30293 Mdot
.5712 .50127 Mdot
.35774 .41622 Mdot
.61304 .24927 Mdot
.3657 .57598 Mdot
.49453 .25934 Mdot
.5813 .3125 Mdot
.4659 .61143 Mdot
.36669 .45199 Mdot
.15506 .59198 Mdot
.50728 .52049 Mdot
.62419 .48569 Mdot
.64618 .50977 Mdot
.51327 .67038 Mdot
.69948 .5698 Mdot
.30839 .3368 Mdot
.39488 .43663 Mdot
.37365 .75355 Mdot
.55595 .32801 Mdot
.63931 .56771 Mdot
.74854 .62523 Mdot
.34902 .29626 Mdot
.4462 .22008 Mdot
.55325 .35769 Mdot
.54634 .3306 Mdot
.3751 .57427 Mdot
.36211 .56687 Mdot
.63897 .53308 Mdot
.40082 .43595 Mdot
.57084 .29269 Mdot
.37992 .42165 Mdot
.35068 .57468 Mdot
.36106 .58699 Mdot
.29017 .33388 Mdot
.62273 .47224 Mdot
.3387 .57181 Mdot
.18689 .50602 Mdot
.45252 .37357 Mdot
.58739 .36817 Mdot
.74572 .73381 Mdot
.32098 .29254 Mdot
.54868 .75084 Mdot
.4959 .69808 Mdot
.28071 .3236 Mdot
.38923 .4743 Mdot
.59171 .52772 Mdot
.6692 .53076 Mdot
.30808 .35029 Mdot
.37979 .46582 Mdot
.51296 .67995 Mdot
.37129 .46157 Mdot
.52898 .69461 Mdot
.37238 .55118 Mdot
.61347 .5799 Mdot
.65829 .5666 Mdot
.39537 .45631 Mdot
.36382 .59466 Mdot
.34296 .56727 Mdot
.50449 .71363 Mdot
.73593 .64499 Mdot
.34093 .58008 Mdot
.58008 .3107 Mdot
.78247 .39585 Mdot
.31187 .34902 Mdot
.65594 .55947 Mdot
.7525 .63026 Mdot
.64644 .29175 Mdot
.63217 .49366 Mdot
.29679 .35939 Mdot
.6451 .17853 Mdot
.60938 .57392 Mdot
.63618 .19112 Mdot
.29852 .33754 Mdot
.53893 .35976 Mdot
.35435 .60968 Mdot
.31139 .33888 Mdot
.57237 .49137 Mdot
.55125 .65402 Mdot
.64026 .59457 Mdot
.56144 .35927 Mdot
.56282 .37053 Mdot
.49123 .3 Mdot
.19295 .58335 Mdot
.53627 .69301 Mdot
.51935 .67768 Mdot
.33508 .59839 Mdot
.26079 .35867 Mdot
.57937 .57058 Mdot
.51974 .67482 Mdot
.42246 .77547 Mdot
.59909 .50538 Mdot
.67206 .7247 Mdot
.51573 .56691 Mdot
.53336 .33221 Mdot
.5639 .26447 Mdot
.33413 .60358 Mdot
.5711 .32828 Mdot
.50311 .4043 Mdot
.67349 .5016 Mdot
.56073 .32832 Mdot
.37721 .42884 Mdot
.27879 .53307 Mdot
.52503 .33135 Mdot
.44237 .53641 Mdot
.3789 .43587 Mdot
.48407 .69798 Mdot
.59056 .69715 Mdot
.55339 .87593 Mdot
.39667 .43642 Mdot
.35135 .60675 Mdot
.3384 .57094 Mdot
.33512 .58312 Mdot
.56582 .35757 Mdot
.35086 .62181 Mdot
.56448 .31537 Mdot
.3055 .66364 Mdot
.7373 .66187 Mdot
.52962 .67737 Mdot
.43948 .4234 Mdot
.55192 .34302 Mdot
.43206 .29483 Mdot
.76505 .70705 Mdot
.64307 .51632 Mdot
.4142 .46736 Mdot
.54478 .67077 Mdot
.22936 .3518 Mdot
.51069 .6743 Mdot
.35502 .6068 Mdot
.49362 .25877 Mdot
.64859 .55413 Mdot
.65038 .434 Mdot
.53346 .66336 Mdot
.5583 .35813 Mdot
.6111 .56584 Mdot
.29539 .63113 Mdot
.50027 .68724 Mdot
.49537 .68779 Mdot
.63007 .55741 Mdot
.52922 .3381 Mdot
.35836 .59215 Mdot
.39646 .47144 Mdot
.50698 .72703 Mdot
.58793 .48368 Mdot
.63847 .50082 Mdot
.65151 .48218 Mdot
.46541 .47 Mdot
.50342 .78017 Mdot
.38733 .43696 Mdot
.68011 .64502 Mdot
.35348 .56851 Mdot
.59704 .65492 Mdot
.41918 .32549 Mdot
.43809 .42433 Mdot
.29303 .33807 Mdot
.2901 .33896 Mdot
.63089 .54742 Mdot
.48889 .7848 Mdot
.50556 .20664 Mdot
.42492 .46749 Mdot
.31044 .35548 Mdot
.34382 .56694 Mdot
.53251 .29791 Mdot
.48895 .32953 Mdot
.6423 .58785 Mdot
.41484 .44712 Mdot
.34429 .57546 Mdot
.3958 .79111 Mdot
.52719 .68777 Mdot
.45985 .30499 Mdot
.61433 .53425 Mdot
.64009 .55815 Mdot
.38116 .44473 Mdot
.38872 .43009 Mdot
.41449 .23549 Mdot
.472 .33749 Mdot
.25972 .61469 Mdot
.37703 .5092 Mdot
.42687 .80415 Mdot
.50611 .31367 Mdot
.58369 .33094 Mdot
.28616 .33237 Mdot
.37731 .40729 Mdot
.65779 .56162 Mdot
.54256 .36291 Mdot
.4517 .2182 Mdot
.5984 .29955 Mdot
.67095 .71898 Mdot
.43783 .63233 Mdot
.60879 .54653 Mdot
.58989 .32079 Mdot
.56866 .32818 Mdot
.54375 .30198 Mdot
.30885 .35987 Mdot
.65998 .53625 Mdot
.63928 .5034 Mdot
.60466 .56666 Mdot
.71084 .53987 Mdot
.62625 .53679 Mdot
.41942 .33748 Mdot
.42444 .37801 Mdot
.35864 .73407 Mdot
.63097 .4915 Mdot
.37594 .46158 Mdot
.58725 .52554 Mdot
.51174 .71197 Mdot
.61914 .49013 Mdot
.65437 .73842 Mdot
.39359 .44597 Mdot
.71741 .58833 Mdot
.367 .50894 Mdot
.61323 .53421 Mdot
.51243 .65921 Mdot
.49892 .7779 Mdot
.78068 .60665 Mdot
.19684 .47416 Mdot
.57893 .30929 Mdot
.30951 .58298 Mdot
.36793 .46418 Mdot
.35042 .59759 Mdot
.63757 .48529 Mdot
.28157 .34007 Mdot
.2751 .29518 Mdot
.46612 .5955 Mdot
.66649 .55504 Mdot
.58225 .59543 Mdot
.53937 .31853 Mdot
.33565 .61248 Mdot
.52164 .29204 Mdot
.63055 .51992 Mdot
.50948 .699 Mdot
.5122 .7041 Mdot
.47815 .36515 Mdot
.32614 .73936 Mdot
.5285 .51114 Mdot
.3819 .44261 Mdot
.373 .60867 Mdot
.52058 .65294 Mdot
.57992 .23843 Mdot
.38805 .47957 Mdot
.41176 .43154 Mdot
.36341 .43784 Mdot
.6109 .55181 Mdot
.29761 .33363 Mdot
.38288 .76916 Mdot
.31743 .35081 Mdot
.60997 .53539 Mdot
.36573 .56226 Mdot
.31077 .33754 Mdot
.50752 .67525 Mdot
.39052 .40984 Mdot
.35902 .56927 Mdot
.62418 .5459 Mdot
.56243 .33637 Mdot
.73445 .62386 Mdot
.5841 .78066 Mdot
.31313 .68179 Mdot
.31896 .68639 Mdot
.57215 .36123 Mdot
.2318 .67115 Mdot
.4267 .39748 Mdot
.6679 .30274 Mdot
.55649 .68211 Mdot
.65364 .49505 Mdot
.77665 .31915 Mdot
.3738 .58863 Mdot
.32586 .59966 Mdot
.63263 .53823 Mdot
.32667 .62139 Mdot
.63975 .56864 Mdot
.3778 .57271 Mdot
.22818 .59738 Mdot
.63989 .58454 Mdot
.32679 .60103 Mdot
.57965 .57426 Mdot
.6186 .51911 Mdot
.5353 .32274 Mdot
.31592 .60929 Mdot
.61638 .48633 Mdot
.25018 .30003 Mdot
.40828 .44259 Mdot
.31175 .35823 Mdot
.42258 .38573 Mdot
.36471 .45246 Mdot
.5501 .32058 Mdot
.62368 .58603 Mdot
.52987 .66709 Mdot
.56176 .34465 Mdot
.29707 .61705 Mdot
.53731 .66516 Mdot
.45382 .33167 Mdot
.57464 .3064 Mdot
.30932 .34496 Mdot
.52974 .66374 Mdot
.66939 .5873 Mdot
.32513 .5884 Mdot
.59739 .78825 Mdot
.31687 .35166 Mdot
.65711 .55067 Mdot
.39389 .55659 Mdot
.36939 .45855 Mdot
.64336 .53824 Mdot
.33316 .61853 Mdot
.30508 .36086 Mdot
.60342 .54932 Mdot
.60581 .55957 Mdot
.49098 .35814 Mdot
.47688 .23161 Mdot
.5283 .66989 Mdot
.59851 .34152 Mdot
.63915 .52411 Mdot
.51833 .71286 Mdot
.2788 .43302 Mdot
.58328 .53112 Mdot
.52227 .3317 Mdot
.61578 .43157 Mdot
.36259 .5658 Mdot
.36849 .41388 Mdot
.37026 .61373 Mdot
.49456 .68853 Mdot
.86673 .49 Mdot
.29626 .33139 Mdot
.56181 .52517 Mdot
.66889 .49461 Mdot
.3857 .60586 Mdot
.56498 .32557 Mdot
.26632 .57101 Mdot
.66098 .51059 Mdot
.60098 .60603 Mdot
.64045 .5624 Mdot
.45038 .70653 Mdot
.53965 .34753 Mdot
.64928 .56215 Mdot
.65987 .61412 Mdot
.60746 .57936 Mdot
.50594 .66398 Mdot
.62882 .68352 Mdot
.58695 .52046 Mdot
.09124 .47004 Mdot
.29211 .35917 Mdot
.3335 .58007 Mdot
.41828 .58164 Mdot
.32247 .45243 Mdot
.65723 .23479 Mdot
.5624 .31726 Mdot
.56001 .47761 Mdot
.35479 .5949 Mdot
.81102 .56303 Mdot
.21555 .64665 Mdot
.616 .52276 Mdot
.67753 .53327 Mdot
.35495 .60685 Mdot
.31166 .61595 Mdot
.28344 .33998 Mdot
.63139 .48915 Mdot
.57102 .57645 Mdot
.33341 .62865 Mdot
.61891 .54279 Mdot
.61881 .38025 Mdot
.40871 .46112 Mdot
.54331 .30723 Mdot
.38195 .41158 Mdot
.41274 .4377 Mdot
.7404 .33397 Mdot
.46264 .35129 Mdot
.38404 .4279 Mdot
.40123 .48265 Mdot
.65857 .73943 Mdot
.6403 .43917 Mdot
.50843 .65901 Mdot
.28786 .69729 Mdot
.33448 .59046 Mdot
.65982 .53372 Mdot
.58078 .35015 Mdot
.67836 .2819 Mdot
.25028 .51054 Mdot
.48112 .26346 Mdot
.64061 .50865 Mdot
.33152 .60077 Mdot
.31257 .35966 Mdot
.63849 .58606 Mdot
.60087 .65254 Mdot
.63973 .55528 Mdot
.34195 .56564 Mdot
.7687 .35282 Mdot
.63832 .43268 Mdot
.39423 .53154 Mdot
.5913 .37364 Mdot
.59466 .56025 Mdot
.57434 .31093 Mdot
.37661 .4584 Mdot
.52199 .71035 Mdot
.52217 .66991 Mdot
.61462 .56584 Mdot
.5239 .26297 Mdot
.52683 .58894 Mdot
.62067 .51803 Mdot
.61015 .51295 Mdot
.29687 .33866 Mdot
.61077 .51333 Mdot
.66639 .49397 Mdot
.59024 .54037 Mdot
.58011 .5151 Mdot
.37657 .40895 Mdot
.74505 .51204 Mdot
.58675 .50681 Mdot
.61476 .45646 Mdot
.40989 .45492 Mdot
.55409 .50956 Mdot
.40212 .42366 Mdot
.28833 .72647 Mdot
.39265 .41913 Mdot
.52452 .67118 Mdot
.38852 .55205 Mdot
.54653 .55223 Mdot
.57603 .29464 Mdot
.41767 .43665 Mdot
.51973 .69287 Mdot
.39783 .43905 Mdot
.38571 .58115 Mdot
.70673 .75357 Mdot
.5955 .29716 Mdot
.42024 .52388 Mdot
.51846 .5458 Mdot
.41997 .25083 Mdot
.36808 .57282 Mdot
.53521 .335 Mdot
.6257 .42591 Mdot
.59181 .54305 Mdot
.52189 .66377 Mdot
.63157 .54923 Mdot
.38069 .40914 Mdot
.33188 .59473 Mdot
.35115 .69367 Mdot
.52614 .66814 Mdot
.81922 .61545 Mdot
.35885 .55843 Mdot
.67342 .56395 Mdot
.41542 .44889 Mdot
.75055 .72717 Mdot
.39308 .41794 Mdot
.74345 .65528 Mdot
.52386 .36037 Mdot
.78878 .37312 Mdot
.54534 .33593 Mdot
.45355 .2082 Mdot
.28585 .77173 Mdot
.22051 .63639 Mdot
.56943 .34257 Mdot
.31984 .56165 Mdot
.61695 .53634 Mdot
.59272 .50571 Mdot
.67276 .47062 Mdot
.59598 .35811 Mdot
.63545 .52637 Mdot
.30953 .33941 Mdot
.46038 .38301 Mdot
.4582 .75969 Mdot
.31888 .57042 Mdot
.64384 .56888 Mdot
.41133 .4485 Mdot
.35312 .4336 Mdot
.31421 .34188 Mdot
.38779 .47739 Mdot
.6209 .51356 Mdot
.54946 .34147 Mdot
.47952 .58963 Mdot
.50547 .68933 Mdot
.17832 .4135 Mdot
.50651 .72431 Mdot
.30812 .58188 Mdot
.68883 .49918 Mdot
.36189 .58613 Mdot
.83183 .36025 Mdot
.59198 .51759 Mdot
.5697 .33372 Mdot
.60782 .55831 Mdot
.59083 .54859 Mdot
.59819 .49704 Mdot
.34657 .62537 Mdot
.41102 .59609 Mdot
.61911 .54554 Mdot
.36819 .44707 Mdot
.35044 .70644 Mdot
.6562 .58708 Mdot
.286 .60132 Mdot
.6577 .71433 Mdot
.42236 .26432 Mdot
.58647 .37239 Mdot
.34421 .60978 Mdot
.55206 .32895 Mdot
.60376 .34235 Mdot
.55023 .32042 Mdot
.35468 .74786 Mdot
.55081 .58539 Mdot
.60678 .17438 Mdot
.78541 .44022 Mdot
.68235 .29665 Mdot
.58412 .3574 Mdot
.28745 .47088 Mdot
.58144 .33355 Mdot
.55726 .31745 Mdot
.4093 .13104 Mdot
.58015 .34265 Mdot
.66974 .54263 Mdot
.68117 .55059 Mdot
.37667 .32478 Mdot
.67983 .7299 Mdot
.62296 .49039 Mdot
.63731 .52883 Mdot
.53153 .70036 Mdot
.70665 .58528 Mdot
.31631 .33783 Mdot
.47456 .2943 Mdot
.28339 .31675 Mdot
.62971 .55648 Mdot
.6332 .53293 Mdot
.5767 .49851 Mdot
.29315 .78326 Mdot
.67036 .26736 Mdot
.55997 .36941 Mdot
.56418 .58001 Mdot
.17037 .52405 Mdot
.67793 .55071 Mdot
.6519 .57174 Mdot
.60026 .54032 Mdot
.35307 .5968 Mdot
.52725 .3001 Mdot
.59995 .60336 Mdot
.39903 .28122 Mdot
.61868 .52991 Mdot
.42183 .39645 Mdot
.49341 .72565 Mdot
.66121 .55324 Mdot
.53867 .307 Mdot
.60951 .4968 Mdot
.58611 .31746 Mdot
.54997 .30431 Mdot
.5989 .4799 Mdot
.36699 .76253 Mdot
.52897 .30828 Mdot
.60603 .53748 Mdot
.35851 .59878 Mdot
.19152 .6132 Mdot
.65906 .55004 Mdot
.52948 .69918 Mdot
.65091 .50841 Mdot
.50577 .66519 Mdot
.60748 .52435 Mdot
.31751 .35424 Mdot
.65562 .35072 Mdot
.33884 .59892 Mdot
.5219 .73021 Mdot
.32243 .6231 Mdot
.51859 .39411 Mdot
.52962 .351 Mdot
.31718 .33727 Mdot
.62579 .21393 Mdot
.29832 .33905 Mdot
.7347 .61999 Mdot
.24173 .47124 Mdot
.40666 .44924 Mdot
.56458 .29811 Mdot
.68917 .63364 Mdot
.29086 .58799 Mdot
.30428 .62267 Mdot
.30626 .59846 Mdot
.85388 .43541 Mdot
.71768 .24935 Mdot
.61873 .55149 Mdot
.59262 .80144 Mdot
.69158 .40664 Mdot
.58132 .5539 Mdot
.59465 .57656 Mdot
.34376 .56345 Mdot
.60028 .56823 Mdot
.47471 .50164 Mdot
.3518 .58002 Mdot
.51885 .68677 Mdot
.56291 .31151 Mdot
.50005 .67568 Mdot
.26762 .60819 Mdot
.44939 .3853 Mdot
.35334 .57065 Mdot
.58054 .52499 Mdot
.61707 .56 Mdot
.58251 .3079 Mdot
.57063 .40393 Mdot
.54111 .31046 Mdot
.5422 .66832 Mdot
.34461 .58803 Mdot
.65727 .26384 Mdot
.65609 .51406 Mdot
.55746 .35018 Mdot
.33556 .42194 Mdot
.6485 .51414 Mdot
.39153 .45797 Mdot
.63948 .50669 Mdot
.57033 .34775 Mdot
.61061 .51413 Mdot
.54867 .33906 Mdot
.37128 .58852 Mdot
.67961 .53957 Mdot
.63521 .53483 Mdot
.78631 .58482 Mdot
.51198 .68099 Mdot
.53205 .354 Mdot
.48793 .48664 Mdot
.68193 .53117 Mdot
.59199 .65077 Mdot
.61259 .57844 Mdot
.57903 .45047 Mdot
.57672 .57223 Mdot
.30848 .3395 Mdot
.61499 .48209 Mdot
.65759 .55164 Mdot
.72987 .4883 Mdot
.77218 .47617 Mdot
.54598 .27609 Mdot
.41615 .42042 Mdot
.53879 .30735 Mdot
.32925 .5779 Mdot
.31203 .60001 Mdot
.36089 .61415 Mdot
.70683 .70965 Mdot
.5749 .49381 Mdot
.64978 .55258 Mdot
.41769 .44735 Mdot
.5216 .67784 Mdot
.55805 .356 Mdot
.52621 .67865 Mdot
.47792 .29041 Mdot
.53925 .66341 Mdot
.30561 .33487 Mdot
.4541 .7113 Mdot
.62282 .27536 Mdot
.53604 .69007 Mdot
.54113 .30999 Mdot
.44367 .62579 Mdot
.64829 .49237 Mdot
.20086 .53268 Mdot
.51055 .69992 Mdot
.85639 .49085 Mdot
.62178 .57964 Mdot
.45677 .51657 Mdot
.40638 .43325 Mdot
.50702 .66777 Mdot
.3622 .44385 Mdot
.60018 .50111 Mdot
.37198 .24698 Mdot
.5746 .33037 Mdot
.42135 .4211 Mdot
.60821 .48594 Mdot
.50157 .67356 Mdot
.34606 .57018 Mdot
.51577 .47935 Mdot
.38476 .46343 Mdot
.77034 .61012 Mdot
.61324 .65689 Mdot
.34653 .58651 Mdot
.52535 .18406 Mdot
.36469 .4246 Mdot
.57921 .54005 Mdot
.54614 .48846 Mdot
.62129 .49729 Mdot
.32439 .58056 Mdot
.33111 .61228 Mdot
.38886 .35424 Mdot
.61054 .55872 Mdot
.61941 .57952 Mdot
.52378 .29837 Mdot
.35859 .57693 Mdot
.53976 .3284 Mdot
.56943 .29659 Mdot
.35637 .60403 Mdot
.54332 .31996 Mdot
.53183 .66193 Mdot
.46223 .38624 Mdot
.36659 .42217 Mdot
.37555 .45282 Mdot
.34121 .57035 Mdot
.38677 .56946 Mdot
.36268 .58368 Mdot
.63774 .50753 Mdot
.54196 .35572 Mdot
.59969 .51667 Mdot
.58619 .52027 Mdot
.52626 .36624 Mdot
.56428 .36174 Mdot
.59845 .51169 Mdot
.44978 .63021 Mdot
.52965 .71841 Mdot
.3275 .60256 Mdot
.38122 .42262 Mdot
.80734 .54985 Mdot
.41645 .4519 Mdot
.63462 .57505 Mdot
.21276 .5459 Mdot
.56038 .35848 Mdot
.51091 .67325 Mdot
.50809 .64964 Mdot
.51961 .6665 Mdot
.42006 .41765 Mdot
.557 .29504 Mdot
.45315 .33545 Mdot
.6351 .57329 Mdot
.46617 .4676 Mdot
.68787 .63922 Mdot
.41622 .31296 Mdot
.3809 .42725 Mdot
.643 .51989 Mdot
.30045 .33934 Mdot
.64018 .30335 Mdot
.64193 .55148 Mdot
.62927 .48241 Mdot
.42548 .67545 Mdot
.62091 .45631 Mdot
.5869 .36582 Mdot
.48825 .30864 Mdot
.67407 .50831 Mdot
.51006 .29352 Mdot
.53735 .12309 Mdot
.61913 .57753 Mdot
.62822 .52745 Mdot
.66559 .5328 Mdot
.59261 .5257 Mdot
.54043 .37435 Mdot
.45944 .63774 Mdot
.41552 .44345 Mdot
.46531 .41755 Mdot
.36676 .42787 Mdot
.32312 .59589 Mdot
.46171 .5177 Mdot
.55818 .29907 Mdot
.51741 .66701 Mdot
.67634 .77413 Mdot
.49016 .28235 Mdot
.37458 .57437 Mdot
.69383 .27668 Mdot
.50539 .69304 Mdot
.65293 .49534 Mdot
.51411 .71973 Mdot
.30811 .61243 Mdot
.37109 .44065 Mdot
.68306 .54213 Mdot
.58493 .34783 Mdot
.52466 .32984 Mdot
.64095 .51867 Mdot
.17603 .56372 Mdot
.36496 .45157 Mdot
.35493 .38129 Mdot
.60997 .55008 Mdot
.63118 .48257 Mdot
.55048 .30843 Mdot
.33345 .60938 Mdot
.24246 .43429 Mdot
.51375 .6886 Mdot
.57827 .50831 Mdot
.60458 .49793 Mdot
.47583 .30429 Mdot
.39672 .41061 Mdot
.29335 .35356 Mdot
.60967 .55324 Mdot
.46277 .34668 Mdot
.60784 .55288 Mdot
.68944 .58877 Mdot
.36325 .59023 Mdot
.68865 .52968 Mdot
.67325 .51681 Mdot
.70321 .61627 Mdot
.36174 .42728 Mdot
.56576 .32954 Mdot
.51435 .32748 Mdot
.28923 .35442 Mdot
.39581 .45442 Mdot
.60159 .50501 Mdot
.37231 .41152 Mdot
.5959 .49965 Mdot
.6219 .54361 Mdot
.37993 .42767 Mdot
.53981 .32746 Mdot
.27086 .56091 Mdot
.73683 .50845 Mdot
.59624 .54195 Mdot
.64269 .50006 Mdot
.69171 .71921 Mdot
.5845 .20576 Mdot
.66861 .51359 Mdot
.55206 .3614 Mdot
.64877 .51719 Mdot
.38224 .45812 Mdot
.5412 .6637 Mdot
.56732 .33774 Mdot
.38378 .55949 Mdot
.37038 .59214 Mdot
.36563 .50655 Mdot
.30062 .33253 Mdot
.65575 .50143 Mdot
.59029 .28788 Mdot
.57144 .35888 Mdot
.25632 .31952 Mdot
.33142 .58177 Mdot
.52175 .65444 Mdot
.60146 .55554 Mdot
.51241 .48754 Mdot
.4146 .43187 Mdot
.09144 .47275 Mdot
.4488 .34528 Mdot
.49277 .70312 Mdot
.51329 .23752 Mdot
.30478 .34339 Mdot
.66923 .55325 Mdot
.51129 .71316 Mdot
.37326 .59701 Mdot
.59365 .50584 Mdot
.61055 .46587 Mdot
.33366 .53584 Mdot
.33711 .55759 Mdot
.36795 .41351 Mdot
.38306 .58015 Mdot
.49361 .69847 Mdot
.3069 .33568 Mdot
.52957 .32992 Mdot
.65263 .55631 Mdot
.56516 .58857 Mdot
.33156 .58584 Mdot
.31713 .35839 Mdot
.60817 .54611 Mdot
.52563 .32256 Mdot
.34 .61986 Mdot
.62985 .56021 Mdot
.65945 .29223 Mdot
.56686 .39103 Mdot
.3386 .58759 Mdot
.66712 .49161 Mdot
.58988 .42387 Mdot
.37465 .55545 Mdot
.34856 .56183 Mdot
.63532 .5269 Mdot
.52963 .66255 Mdot
.67345 .55178 Mdot
.4015 .42639 Mdot
.41093 .59643 Mdot
.38704 .45578 Mdot
.65773 .64829 Mdot
.66879 .48489 Mdot
.43633 .23479 Mdot
.59113 .3184 Mdot
.53883 .64334 Mdot
.7371 .48044 Mdot
.64693 .48663 Mdot
.26881 .70348 Mdot
.46472 .60944 Mdot
.20685 .38063 Mdot
.41338 .82278 Mdot
.52214 .69821 Mdot
.39959 .44194 Mdot
.62901 .52678 Mdot
.35798 .47112 Mdot
.53546 .68669 Mdot
.67323 .64575 Mdot
.66638 .49183 Mdot
.53935 .34476 Mdot
.61564 .53512 Mdot
.58006 .31034 Mdot
.65014 .51259 Mdot
.56426 .50386 Mdot
.54453 .70621 Mdot
.74587 .65156 Mdot
.64791 .49342 Mdot
.69573 .76684 Mdot
.50368 .48287 Mdot
.51208 .69825 Mdot
.60013 .52949 Mdot
.30128 .3532 Mdot
.37321 .46384 Mdot
.52626 .78336 Mdot
.358 .59129 Mdot
.39153 .4276 Mdot
.55483 .30976 Mdot
.38905 .58783 Mdot
.29465 .35946 Mdot
.54595 .56102 Mdot
.49694 .68391 Mdot
.40614 .44644 Mdot
.65895 .55237 Mdot
.63561 .57565 Mdot
.45613 .70445 Mdot
.41196 .17981 Mdot
.54607 .29065 Mdot
.80828 .61464 Mdot
.58305 .36545 Mdot
.51643 .677 Mdot
.36407 .58764 Mdot
.67376 .53542 Mdot
.63946 .54563 Mdot
.31698 .5944 Mdot
.54725 .36259 Mdot
.39086 .5422 Mdot
.72686 .31327 Mdot
.32879 .63496 Mdot
.69341 .67616 Mdot
.57206 .33873 Mdot
.70087 .67179 Mdot
.49209 .6916 Mdot
.3666 .77151 Mdot
.58814 .74326 Mdot
.41076 .43834 Mdot
.68549 .68005 Mdot
.56297 .35528 Mdot
.61985 .55566 Mdot
.3096 .34719 Mdot
.29004 .33519 Mdot
.56676 .30868 Mdot
.35083 .60957 Mdot
.50216 .67464 Mdot
.62589 .53138 Mdot
.44216 .29162 Mdot
.336 .30527 Mdot
.37066 .61119 Mdot
.65501 .61319 Mdot
.36391 .4446 Mdot
.6452 .50581 Mdot
.52339 .70502 Mdot
.3898 .43385 Mdot
.27764 .33308 Mdot
.46328 .38559 Mdot
.60181 .55769 Mdot
.48085 .3658 Mdot
.40088 .44995 Mdot
.53839 .18041 Mdot
.63691 .53765 Mdot
.36442 .42488 Mdot
.60164 .45036 Mdot
.36931 .25924 Mdot
.50204 .57027 Mdot
.22852 .65252 Mdot
.32189 .57181 Mdot
.36742 .5972 Mdot
.32114 .2453 Mdot
.55645 .68072 Mdot
.40909 .45285 Mdot
.3096 .33761 Mdot
.60791 .70386 Mdot
.36086 .43891 Mdot
.65117 .57332 Mdot
.61328 .5784 Mdot
.72893 .32365 Mdot
.48366 .50306 Mdot
.31517 .3624 Mdot
.56109 .44728 Mdot
.6193 .5064 Mdot
.6848 .56609 Mdot
.64553 .53345 Mdot
.56241 .37042 Mdot
.36001 .44664 Mdot
.69689 .78277 Mdot
.35677 .43696 Mdot
.44832 .29327 Mdot
.3342 .5909 Mdot
.36128 .62031 Mdot
.65916 .55542 Mdot
.47678 .21084 Mdot
.50773 .78803 Mdot
.64863 .50201 Mdot
.48513 .68316 Mdot
.62494 .65653 Mdot
.66128 .58528 Mdot
.51296 .31668 Mdot
.61467 .60957 Mdot
.5549 .37764 Mdot
.38543 .43236 Mdot
.52476 .69776 Mdot
.54112 .70321 Mdot
.40415 .43971 Mdot
.65076 .54973 Mdot
.48633 .6691 Mdot
.6409 .55979 Mdot
.61529 .55412 Mdot
.46985 .29248 Mdot
.53424 .65164 Mdot
.36418 .58058 Mdot
.52319 .66914 Mdot
.55761 .31881 Mdot
.32578 .16271 Mdot
.53031 .68349 Mdot
.56771 .42009 Mdot
.44166 .5609 Mdot
.68992 .67649 Mdot
.52587 .32719 Mdot
.54056 .684 Mdot
.35935 .4221 Mdot
.20284 .38136 Mdot
.55823 .1961 Mdot
.40958 .46775 Mdot
.63609 .54325 Mdot
.56575 .29942 Mdot
.57249 .3626 Mdot
.40657 .47702 Mdot
.53263 .33416 Mdot
.6961 .52263 Mdot
.60556 .55455 Mdot
.40904 .45275 Mdot
.36561 .32745 Mdot
.35981 .44754 Mdot
.5312 .45372 Mdot
.60239 .53766 Mdot
.56833 .33568 Mdot
.70073 .54061 Mdot
.53708 .28853 Mdot
.28637 .33448 Mdot
.60154 .49429 Mdot
.51192 .66831 Mdot
.47519 .48598 Mdot
.33774 .58966 Mdot
.21613 .54939 Mdot
.57216 .30365 Mdot
.34234 .41593 Mdot
.53544 .32172 Mdot
.59425 .31702 Mdot
.38923 .47849 Mdot
.56722 .32206 Mdot
.62722 .52853 Mdot
.40965 .53442 Mdot
.58497 .32191 Mdot
.38479 .44648 Mdot
.50337 .67575 Mdot
.54162 .32292 Mdot
.38981 .59105 Mdot
.62136 .56158 Mdot
.36587 .56719 Mdot
.50422 .65646 Mdot
.55862 .29843 Mdot
.54124 .68006 Mdot
.33073 .58471 Mdot
.49732 .69349 Mdot
.32677 .68117 Mdot
.36873 .40674 Mdot
.47415 .26693 Mdot
.69378 .46284 Mdot
.58539 .34541 Mdot
.30305 .62208 Mdot
.67368 .52399 Mdot
.61523 .56288 Mdot
.49936 .70872 Mdot
.57413 .36086 Mdot
.19121 .6064 Mdot
.57283 .45024 Mdot
.3854 .3627 Mdot
.38697 .40702 Mdot
.8184 .57561 Mdot
.44269 .36757 Mdot
.19515 .41381 Mdot
.59812 .58735 Mdot
.3055 .34386 Mdot
.64212 .56283 Mdot
.78204 .6058 Mdot
.53956 .66047 Mdot
.275 .50252 Mdot
.57998 .57112 Mdot
.35515 .58621 Mdot
.65564 .51912 Mdot
.58745 .80008 Mdot
.63452 .60742 Mdot
.53388 .69744 Mdot
.40832 .40617 Mdot
.57501 .29418 Mdot
.50572 .69076 Mdot
.37444 .58454 Mdot
.63683 .69979 Mdot
.67276 .49668 Mdot
.62307 .50938 Mdot
.30393 .61937 Mdot
.53678 .3414 Mdot
.32356 .59277 Mdot
.36633 .42277 Mdot
.52773 .68327 Mdot
.59275 .53406 Mdot
.69139 .54954 Mdot
.34894 .63421 Mdot
.35418 .4318 Mdot
.38825 .58243 Mdot
.39061 .41081 Mdot
.30644 .34384 Mdot
.65191 .49777 Mdot
.3092 .62222 Mdot
.5955 .57012 Mdot
.76841 .51821 Mdot
.47911 .2784 Mdot
.74978 .45774 Mdot
.36484 .57838 Mdot
.67469 .70463 Mdot
.39538 .44802 Mdot
.39533 .41477 Mdot
.80414 .42688 Mdot
.49379 .7811 Mdot
.43309 .63285 Mdot
.69699 .75554 Mdot
.36722 .42195 Mdot
.38827 .45305 Mdot
.36968 .60189 Mdot
.56762 .31728 Mdot
.55341 .38511 Mdot
.34755 .63077 Mdot
.75127 .63049 Mdot
.55824 .35582 Mdot
.25604 .69008 Mdot
.36103 .55476 Mdot
.57556 .56665 Mdot
.32227 .35999 Mdot
.51922 .70328 Mdot
.75079 .62325 Mdot
.66051 .77289 Mdot
.66926 .54941 Mdot
.68342 .24003 Mdot
.34321 .60662 Mdot
.39861 .51728 Mdot
.31122 .73773 Mdot
.64316 .48247 Mdot
.65891 .52634 Mdot
.65159 .54282 Mdot
.5433 .65599 Mdot
.74767 .49355 Mdot
.66783 .55246 Mdot
.73011 .66651 Mdot
.65438 .57472 Mdot
.5675 .78745 Mdot
.52382 .6696 Mdot
.54651 .58566 Mdot
.30916 .5872 Mdot
.40976 .28761 Mdot
.67334 .47004 Mdot
.36965 .41629 Mdot
.29039 .57741 Mdot
.37077 .43625 Mdot
.44303 .79507 Mdot
.59006 .7402 Mdot
.56907 .36896 Mdot
.64016 .50866 Mdot
.31067 .59068 Mdot
.57463 .30324 Mdot
.24174 .45991 Mdot
.4007 .13001 Mdot
.35756 .41789 Mdot
.73471 .24354 Mdot
.39681 .41499 Mdot
.28659 .33666 Mdot
.55701 .30696 Mdot
.57489 .25235 Mdot
.46662 .47066 Mdot
.54197 .32584 Mdot
.3489 .50511 Mdot
.51215 .32429 Mdot
.67861 .6933 Mdot
.59469 .30918 Mdot
.38889 .44462 Mdot
.38363 .39765 Mdot
.58929 .46641 Mdot
.6695 .51637 Mdot
.46166 .40393 Mdot
.6231 .44537 Mdot
.6577 .5077 Mdot
.35186 .58013 Mdot
.52622 .20773 Mdot
.40184 .58052 Mdot
.58195 .32642 Mdot
.41254 .41978 Mdot
.65851 .5243 Mdot
.59661 .54005 Mdot
.58294 .54917 Mdot
.78898 .59309 Mdot
.25677 .68774 Mdot
.62027 .5467 Mdot
.60038 .48059 Mdot
.37265 .58304 Mdot
.46583 .70435 Mdot
.7529 .69456 Mdot
.60661 .71434 Mdot
.61829 .56992 Mdot
.51322 .67612 Mdot
.54156 .65853 Mdot
.68634 .55127 Mdot
.43692 .26065 Mdot
.35248 .54141 Mdot
.65925 .55194 Mdot
.57597 .75887 Mdot
.39699 .57942 Mdot
.31848 .35244 Mdot
.33217 .58482 Mdot
.54719 .30085 Mdot
.2939 .33702 Mdot
.33932 .62269 Mdot
.59068 .25411 Mdot
.28834 .3522 Mdot
.37267 .2686 Mdot
.54228 .6685 Mdot
.64369 .53848 Mdot
.525 .29148 Mdot
.31907 .5898 Mdot
.40658 .44442 Mdot
.55479 .33853 Mdot
.35173 .42093 Mdot
.46687 .711 Mdot
.71304 .63955 Mdot
.29707 .33178 Mdot
.37817 .41482 Mdot
.4692 .38891 Mdot
.51572 .67296 Mdot
.39555 .47732 Mdot
.46408 .21209 Mdot
.64725 .59065 Mdot
.4838 .80772 Mdot
.62918 .51071 Mdot
.16345 .50965 Mdot
.3977 .41663 Mdot
.28073 .3348 Mdot
.64905 .55704 Mdot
.36158 .55752 Mdot
.56976 .48139 Mdot
.63786 .55874 Mdot
.38404 .57019 Mdot
.61937 .55217 Mdot
.52141 .70703 Mdot
.56393 .38179 Mdot
.4691 .60556 Mdot
.83466 .5117 Mdot
.49936 .69767 Mdot
.2811 .362 Mdot
.66132 .50849 Mdot
.37652 .71356 Mdot
.54163 .32959 Mdot
.63254 .48174 Mdot
.7696 .33806 Mdot
.57341 .31486 Mdot
.54977 .32956 Mdot
.60693 .51302 Mdot
.4086 .46436 Mdot
.34581 .56692 Mdot
.51677 .67106 Mdot
.24505 .376 Mdot
.6315 .56214 Mdot
.64259 .52423 Mdot
.50499 .69208 Mdot
.38796 .45447 Mdot
.59377 .53021 Mdot
.22885 .49052 Mdot
.24449 .3398 Mdot
.41302 .43784 Mdot
.65197 .58975 Mdot
.51656 .83256 Mdot
.59728 .37106 Mdot
.65407 .20697 Mdot
.55352 .69744 Mdot
.35217 .60518 Mdot
.56462 .55497 Mdot
.10035 .43951 Mdot
.51937 .70218 Mdot
.41993 .3063 Mdot
.6162 .54472 Mdot
.66432 .51976 Mdot
.52897 .34345 Mdot
.60211 .5082 Mdot
.57459 .34675 Mdot
.8391 .50285 Mdot
.80171 .69035 Mdot
.53734 .32108 Mdot
.58402 .33572 Mdot
.58263 .2671 Mdot
.77371 .60311 Mdot
.55935 .31088 Mdot
.66597 .48919 Mdot
.30789 .69332 Mdot
.62801 .46828 Mdot
.49243 .68192 Mdot
.53512 .63957 Mdot
.50395 .32887 Mdot
.47671 .18185 Mdot
.54838 .52559 Mdot
.7271 .53735 Mdot
.53135 .59123 Mdot
.39109 .42033 Mdot
.60085 .5626 Mdot
.30218 .33268 Mdot
.36126 .61575 Mdot
.65274 .61018 Mdot
.64417 .54262 Mdot
.58497 .31685 Mdot
.543 .65391 Mdot
.37163 .46589 Mdot
.63671 .52993 Mdot
.37439 .54293 Mdot
.5166 .68776 Mdot
.58522 .3258 Mdot
.54912 .41603 Mdot
.50422 .66242 Mdot
.69618 .54154 Mdot
.65906 .51039 Mdot
.6078 .54678 Mdot
.6653 .46477 Mdot
.40535 .43834 Mdot
.36091 .62423 Mdot
.68273 .49897 Mdot
.47005 .30677 Mdot
.44023 .51718 Mdot
.689 .5229 Mdot
.54404 .35848 Mdot
.41624 .44454 Mdot
.28867 .34919 Mdot
.65045 .68157 Mdot
.60718 .56383 Mdot
.26201 .69175 Mdot
.69162 .28262 Mdot
.29336 .34204 Mdot
.59651 .34393 Mdot
.5149 .66949 Mdot
.61662 .51219 Mdot
.3406 .71484 Mdot
.62558 .57852 Mdot
.62412 .43546 Mdot
.34783 .60607 Mdot
.38412 .41964 Mdot
.23626 .34388 Mdot
.36234 .61509 Mdot
.55133 .32908 Mdot
.17421 .60856 Mdot
.5187 .32462 Mdot
.55634 .29213 Mdot
.38631 .77388 Mdot
.38331 .43057 Mdot
.09618 .45674 Mdot
.57723 .20006 Mdot
.62917 .58085 Mdot
.37403 .45643 Mdot
.55854 .30526 Mdot
.63631 .50967 Mdot
.57786 .35199 Mdot
.53423 .29904 Mdot
.58734 .52815 Mdot
.66539 .51667 Mdot
.74413 .64548 Mdot
.25819 .71034 Mdot
.5253 .66483 Mdot
.53927 .3599 Mdot
.70478 .31498 Mdot
.66981 .55054 Mdot
.63582 .57299 Mdot
.31741 .54947 Mdot
.53455 .69589 Mdot
.62421 .38656 Mdot
.61146 .55404 Mdot
.78178 .35145 Mdot
.65093 .50023 Mdot
.53942 .28166 Mdot
.41274 .45945 Mdot
.43445 .2685 Mdot
.32795 .57685 Mdot
.52267 .32391 Mdot
.50621 .66562 Mdot
.52268 .35102 Mdot
.79038 .38343 Mdot
.37875 .43288 Mdot
.57032 .34782 Mdot
.39166 .56214 Mdot
.37565 .44268 Mdot
.41077 .43484 Mdot
.34826 .70539 Mdot
.38447 .59502 Mdot
.54391 .68569 Mdot
.36758 .43861 Mdot
.67124 .30477 Mdot
.38857 .44131 Mdot
.71851 .32219 Mdot
.6779 .52123 Mdot
.72899 .66143 Mdot
.43558 .35953 Mdot
.66441 .46865 Mdot
.36156 .4509 Mdot
.53537 .67643 Mdot
.61341 .49847 Mdot
.53275 .33775 Mdot
.53029 .68704 Mdot
.42503 .47115 Mdot
.38812 .56328 Mdot
.59487 .33025 Mdot
.41504 .45005 Mdot
.57121 .35051 Mdot
.6994 .64228 Mdot
.29455 .64261 Mdot
.5385 .59659 Mdot
.46135 .48561 Mdot
.57912 .54527 Mdot
.50637 .29779 Mdot
.68171 .52513 Mdot
.64328 .54764 Mdot
.33807 .5874 Mdot
.70762 .7082 Mdot
.53963 .32522 Mdot
.23908 .32435 Mdot
.38517 .41416 Mdot
.4944 .29889 Mdot
.58227 .43116 Mdot
.60165 .4963 Mdot
.5828 .31954 Mdot
.53534 .29681 Mdot
.77211 .47522 Mdot
.31651 .59691 Mdot
.65425 .46805 Mdot
.6858 .49531 Mdot
.56613 .50427 Mdot
.40027 .41712 Mdot
.23894 .50996 Mdot
.32861 .61588 Mdot
.65369 .17943 Mdot
.32789 .60445 Mdot
.40424 .68519 Mdot
.5683 .32211 Mdot
.53155 .65819 Mdot
.63861 .57195 Mdot
.74315 .52853 Mdot
.54059 .37306 Mdot
.36448 .53274 Mdot
.50933 .67299 Mdot
.25917 .53855 Mdot
.38739 .42853 Mdot
.67277 .50326 Mdot
.589 .54475 Mdot
.59985 .52146 Mdot
.62174 .52077 Mdot
.41319 .41788 Mdot
.65076 .57328 Mdot
.39855 .40682 Mdot
.64825 .287 Mdot
.79163 .36783 Mdot
.3268 .5728 Mdot
.52273 .77598 Mdot
.58717 .34607 Mdot
.69872 .32828 Mdot
.62154 .3705 Mdot
.47698 .27861 Mdot
.34153 .69122 Mdot
.67205 .50941 Mdot
.35137 .61085 Mdot
.58859 .802 Mdot
.31032 .59232 Mdot
.84388 .65636 Mdot
.59385 .63726 Mdot
.22049 .65185 Mdot
.63404 .51188 Mdot
.35604 .62934 Mdot
.60496 .40062 Mdot
.68034 .56304 Mdot
.50887 .64437 Mdot
.55327 .43322 Mdot
.38364 .31862 Mdot
.51876 .65456 Mdot
.62362 .56203 Mdot
.57758 .29428 Mdot
.62599 .52876 Mdot
.63733 .57024 Mdot
.65046 .50469 Mdot
.36677 .46736 Mdot
.62821 .58993 Mdot
.67131 .55448 Mdot
.42563 .17261 Mdot
.6717 .7221 Mdot
.37323 .5671 Mdot
.76592 .45126 Mdot
.52161 .67831 Mdot
.58196 .30995 Mdot
.4583 .59942 Mdot
.39974 .42788 Mdot
.77356 .48345 Mdot
.63215 .51108 Mdot
.41628 .35515 Mdot
.41496 .45286 Mdot
.52887 .69283 Mdot
.29367 .35756 Mdot
.26162 .6632 Mdot
.32125 .58076 Mdot
.28384 .34659 Mdot
.33753 .59129 Mdot
.68214 .43771 Mdot
.58403 .31654 Mdot
.58237 .54365 Mdot
.3637 .43986 Mdot
.35262 .56206 Mdot
.68365 .73231 Mdot
.65002 .53154 Mdot
.36456 .57608 Mdot
.57957 .5426 Mdot
.42684 .52759 Mdot
.43914 .57154 Mdot
.31408 .62048 Mdot
.38891 .39751 Mdot
.37569 .44778 Mdot
.53294 .66179 Mdot
.58442 .31192 Mdot
.55443 .36026 Mdot
.38596 .43494 Mdot
.68509 .22191 Mdot
.63507 .56338 Mdot
.65448 .50558 Mdot
.46402 .31731 Mdot
.63419 .51775 Mdot
.65076 .70725 Mdot
.31157 .33472 Mdot
.592 .32878 Mdot
.62653 .52005 Mdot
.59375 .53244 Mdot
.60089 .55568 Mdot
.70116 .64514 Mdot
.32972 .59063 Mdot
.61868 .5071 Mdot
.50445 .71206 Mdot
.41684 .23171 Mdot
.676 .53015 Mdot
.68499 .56134 Mdot
.56794 .3504 Mdot
.82415 .57834 Mdot
.4074 .43325 Mdot
.35911 .57304 Mdot
.36628 .55469 Mdot
.57538 .66384 Mdot
.58443 .3769 Mdot
.31936 .34257 Mdot
.31203 .43256 Mdot
.31479 .3509 Mdot
.51006 .69467 Mdot
.41371 .65606 Mdot
.36957 .54248 Mdot
.3779 .57589 Mdot
.37504 .40545 Mdot
.62262 .52244 Mdot
.65237 .50186 Mdot
.42248 .30476 Mdot
.62678 .49137 Mdot
.50604 .67435 Mdot
.404 .46104 Mdot
.56575 .34998 Mdot
.51517 .70499 Mdot
.37818 .41243 Mdot
.53676 .34344 Mdot
.66011 .58265 Mdot
.63634 .59439 Mdot
.55112 .33574 Mdot
.55398 .3021 Mdot
.66799 .54227 Mdot
.38123 .19957 Mdot
.58997 .30652 Mdot
.57157 .34341 Mdot
.29392 .36309 Mdot
.32007 .58169 Mdot
.69375 .57272 Mdot
.3718 .45552 Mdot
.60877 .5479 Mdot
.32006 .57907 Mdot
.53771 .6877 Mdot
.54467 .34243 Mdot
.59852 .54625 Mdot
.6249 .55195 Mdot
.5126 .67573 Mdot
.52347 .65031 Mdot
.49981 .68916 Mdot
.34827 .43856 Mdot
.61018 .53039 Mdot
.55502 .31197 Mdot
.38183 .42922 Mdot
.54127 .65829 Mdot
.5252 .7152 Mdot
.45812 .16889 Mdot
.66629 .55286 Mdot
.50795 .57657 Mdot
.26646 .21456 Mdot
.62875 .70463 Mdot
.28478 .34215 Mdot
.3292 .62945 Mdot
.71452 .67285 Mdot
.54062 .72453 Mdot
.37657 .45993 Mdot
.54065 .74654 Mdot
.53652 .64335 Mdot
.58685 .52068 Mdot
.63863 .50001 Mdot
.57365 .52064 Mdot
.52111 .68668 Mdot
.68963 .64721 Mdot
.56706 .36449 Mdot
.68133 .38002 Mdot
.52169 .6785 Mdot
.31504 .62081 Mdot
.31177 .62281 Mdot
.3277 .6054 Mdot
.6697 .50422 Mdot
.76217 .47264 Mdot
.68349 .30496 Mdot
.64019 .39933 Mdot
.39177 .4282 Mdot
.53113 .29774 Mdot
.35295 .69362 Mdot
.54839 .33007 Mdot
.35436 .61899 Mdot
.51991 .69103 Mdot
.53253 .35213 Mdot
.39717 .45681 Mdot
.38408 .45518 Mdot
.38533 .55946 Mdot
.3364 .57887 Mdot
.35051 .57007 Mdot
.53975 .30359 Mdot
.56737 .32189 Mdot
.59382 .54345 Mdot
.55117 .34585 Mdot
.64529 .22818 Mdot
.49127 .70316 Mdot
.30288 .61531 Mdot
.39788 .45048 Mdot
.57531 .30701 Mdot
.6414 .53891 Mdot
.43834 .67612 Mdot
.37136 .51346 Mdot
.50411 .70538 Mdot
.38597 .62535 Mdot
.8706 .58353 Mdot
.5902 .55405 Mdot
.38521 .40929 Mdot
.4364 .24898 Mdot
.65404 .53688 Mdot
.35459 .59694 Mdot
.77902 .58142 Mdot
.31598 .35662 Mdot
.67267 .55122 Mdot
.62951 .48441 Mdot
.38636 .47746 Mdot
.44836 .58953 Mdot
.60782 .4927 Mdot
.49866 .39883 Mdot
.35246 .43481 Mdot
.33119 .61833 Mdot
.24871 .29963 Mdot
.31856 .63402 Mdot
.75294 .65049 Mdot
.28685 .34144 Mdot
.58924 .54231 Mdot
.34863 .58162 Mdot
.50983 .71084 Mdot
.3448 .5787 Mdot
.59117 .34715 Mdot
.36272 .56598 Mdot
.64655 .52021 Mdot
.55605 .3132 Mdot
.3982 .45331 Mdot
.48598 .31633 Mdot
.43237 .17868 Mdot
.36381 .55693 Mdot
.27247 .33981 Mdot
.67123 .55108 Mdot
.64055 .3204 Mdot
.56747 .48767 Mdot
.67183 .51611 Mdot
.37127 .43469 Mdot
.58247 .32085 Mdot
.38954 .40733 Mdot
.66586 .5864 Mdot
.80221 .45007 Mdot
.39287 .41658 Mdot
.3712 .29225 Mdot
.50667 .69405 Mdot
.74951 .63018 Mdot
.63825 .55161 Mdot
.36479 .43555 Mdot
.60924 .53146 Mdot
.5439 .36412 Mdot
.48874 .45841 Mdot
.43337 .22383 Mdot
.36433 .44238 Mdot
.16762 .56094 Mdot
.49113 .48255 Mdot
.65274 .6016 Mdot
.36529 .42761 Mdot
.74393 .47506 Mdot
.29707 .35345 Mdot
.51306 .68973 Mdot
.53565 .65382 Mdot
.49619 .68392 Mdot
.62924 .4916 Mdot
.61055 .61392 Mdot
.53597 .70467 Mdot
.35051 .42577 Mdot
.52259 .71116 Mdot
.74514 .62001 Mdot
.18402 .58435 Mdot
.50121 .69682 Mdot
.63358 .54785 Mdot
.67868 .56842 Mdot
.67249 .72364 Mdot
.33323 .62169 Mdot
.27228 .70661 Mdot
.61099 .23446 Mdot
.67314 .53245 Mdot
.54207 .54065 Mdot
.58909 .34608 Mdot
.47263 .22904 Mdot
.56168 .45822 Mdot
.4487 .62283 Mdot
.58092 .33708 Mdot
.4171 .55122 Mdot
.5918 .3253 Mdot
.5913 .5602 Mdot
.62181 .54237 Mdot
.55143 .37905 Mdot
.21098 .53052 Mdot
.34669 .25979 Mdot
.16736 .44232 Mdot
.5546 .36131 Mdot
.36168 .42781 Mdot
.36174 .41535 Mdot
.38337 .42608 Mdot
.32862 .57791 Mdot
.54117 .3062 Mdot
.61192 .52356 Mdot
.36699 .5947 Mdot
.62376 .57031 Mdot
.37228 .44214 Mdot
.23448 .34721 Mdot
.56766 .34963 Mdot
.65735 .55241 Mdot
.55642 .19683 Mdot
.33418 .60194 Mdot
.51589 .67434 Mdot
.41435 .52175 Mdot
.34609 .63374 Mdot
.35806 .44485 Mdot
.5931 .37194 Mdot
.37916 .3877 Mdot
.4655 .63538 Mdot
.57905 .49629 Mdot
.67765 .50461 Mdot
.26064 .36325 Mdot
.50073 .18303 Mdot
.63764 .49579 Mdot
.37488 .58419 Mdot
.30859 .61006 Mdot
.60581 .55705 Mdot
.52968 .32614 Mdot
.54735 .67036 Mdot
.49457 .69285 Mdot
.60144 .49094 Mdot
.46539 .4662 Mdot
.73696 .65554 Mdot
.59676 .51516 Mdot
.70637 .50836 Mdot
.39124 .57291 Mdot
.29126 .35735 Mdot
.46235 .35435 Mdot
.51692 .65992 Mdot
.61475 .54681 Mdot
.33297 .27869 Mdot
.5767 .34376 Mdot
.35724 .56719 Mdot
.40624 .45356 Mdot
.50358 .64709 Mdot
.36989 .55294 Mdot
.60563 .55639 Mdot
.59381 .5309 Mdot
.39063 .47777 Mdot
.53788 .28246 Mdot
.52166 .68998 Mdot
.36721 .59322 Mdot
.53038 .65746 Mdot
.56005 .32056 Mdot
.56609 .34586 Mdot
.67831 .48403 Mdot
.64303 .45874 Mdot
.36684 .55533 Mdot
.59342 .4918 Mdot
.34382 .62292 Mdot
.45841 .70407 Mdot
.41461 .42956 Mdot
.62968 .48083 Mdot
.6024 .31268 Mdot
.37403 .43884 Mdot
.668 .52835 Mdot
.29526 .3735 Mdot
.59221 .51272 Mdot
.35252 .63027 Mdot
.80707 .44521 Mdot
.53737 .68294 Mdot
.5234 .39355 Mdot
.69041 .61495 Mdot
.63529 .518 Mdot
.33749 .62626 Mdot
.56175 .55428 Mdot
.40122 .42348 Mdot
.5773 .32513 Mdot
.83198 .36245 Mdot
.38479 .4437 Mdot
.62357 .53271 Mdot
.52873 .68505 Mdot
.55958 .29048 Mdot
.30191 .33568 Mdot
.45449 .34774 Mdot
.64733 .60953 Mdot
.60784 .59126 Mdot
.62252 .52486 Mdot
.70333 .7531 Mdot
.35394 .5751 Mdot
.56754 .30527 Mdot
.4066 .41984 Mdot
.39489 .43527 Mdot
.33386 .60994 Mdot
.39212 .33882 Mdot
.22166 .57509 Mdot
.19924 .27769 Mdot
.37763 .5634 Mdot
.51703 .71512 Mdot
.46037 .50382 Mdot
.36591 .61256 Mdot
.35426 .5822 Mdot
.38211 .55496 Mdot
.42597 .34424 Mdot
.53837 .3516 Mdot
.62383 .55269 Mdot
.58681 .37219 Mdot
.58808 .52959 Mdot
.73577 .69386 Mdot
.38635 .43346 Mdot
.57576 .32475 Mdot
.28213 .37126 Mdot
.60481 .44611 Mdot
.6562 .52868 Mdot
.29116 .66073 Mdot
.60487 .60393 Mdot
.6713 .68261 Mdot
.69699 .54573 Mdot
.33554 .5843 Mdot
.54885 .57253 Mdot
.56478 .55231 Mdot
.59852 .22733 Mdot
.39166 .45662 Mdot
.29015 .3317 Mdot
.65246 .58508 Mdot
.69274 .58446 Mdot
.55889 .29099 Mdot
.53234 .35207 Mdot
.53842 .70103 Mdot
.43579 .49669 Mdot
.39542 .45545 Mdot
.24659 .59038 Mdot
.66661 .51378 Mdot
.38738 .4966 Mdot
.80435 .4166 Mdot
.66759 .53187 Mdot
.33066 .70297 Mdot
.77343 .48102 Mdot
.60433 .4953 Mdot
.66769 .40833 Mdot
.39188 .4499 Mdot
.77831 .34744 Mdot
.57571 .52499 Mdot
.35355 .5969 Mdot
.56999 .31873 Mdot
.59247 .33829 Mdot
.50672 .70473 Mdot
.61949 .21838 Mdot
.36444 .40294 Mdot
.57072 .32229 Mdot
.65047 .5393 Mdot
.40716 .44202 Mdot
.29428 .33334 Mdot
.61491 .6 Mdot
.45142 .77965 Mdot
.55541 .34828 Mdot
.62367 .47076 Mdot
.34349 .35194 Mdot
.44072 .53044 Mdot
.26426 .72321 Mdot
.38118 .42442 Mdot
.50837 .66469 Mdot
.6984 .54282 Mdot
.3096 .42763 Mdot
.57611 .55739 Mdot
.72689 .6815 Mdot
.51042 .36765 Mdot
.54086 .6631 Mdot
.65563 .5432 Mdot
.60965 .49231 Mdot
.46928 .48694 Mdot
.52355 .65156 Mdot
.60149 .49533 Mdot
.66673 .47492 Mdot
.5379 .34381 Mdot
.30589 .33095 Mdot
.56032 .35112 Mdot
.6363 .54218 Mdot
.54246 .5594 Mdot
.52989 .33908 Mdot
.25764 .63326 Mdot
.54925 .64868 Mdot
.39938 .42639 Mdot
.7026 .57824 Mdot
.67639 .51865 Mdot
.48736 .85413 Mdot
.28623 .33477 Mdot
.77921 .64893 Mdot
.34479 .63264 Mdot
.27267 .30984 Mdot
.36912 .62492 Mdot
.20766 .63692 Mdot
.47416 .34283 Mdot
.58525 .4935 Mdot
.56125 .75362 Mdot
.65395 .40099 Mdot
.36314 .40951 Mdot
.65872 .31161 Mdot
.66978 .51667 Mdot
.63991 .56666 Mdot
.36427 .60473 Mdot
.39414 .35049 Mdot
.43246 .25576 Mdot
.46529 .42656 Mdot
.52215 .69503 Mdot
.56457 .32594 Mdot
.64672 .51462 Mdot
.2058 .46369 Mdot
.37044 .56468 Mdot
.51199 .47779 Mdot
.65288 .55503 Mdot
.44862 .28273 Mdot
.39588 .30616 Mdot
.40804 .44292 Mdot
.33399 .62912 Mdot
.36068 .62402 Mdot
.60955 .57522 Mdot
.39262 .46118 Mdot
.59107 .53347 Mdot
.50157 .46743 Mdot
.60654 .47845 Mdot
.52683 .70013 Mdot
.64768 .5709 Mdot
.48665 .53682 Mdot
.20277 .65733 Mdot
.59233 .60234 Mdot
.58374 .30502 Mdot
.32813 .57991 Mdot
.32886 .60094 Mdot
.55575 .36057 Mdot
.32969 .6046 Mdot
.68709 .38858 Mdot
.76853 .35805 Mdot
.51568 .70021 Mdot
.62713 .327 Mdot
.53083 .69362 Mdot
.28991 .3314 Mdot
.66939 .54654 Mdot
.3208 .46057 Mdot
.37646 .56064 Mdot
.79623 .57258 Mdot
.39034 .43924 Mdot
.28676 .33512 Mdot
.63648 .58264 Mdot
.41295 .65938 Mdot
.35336 .61622 Mdot
.27267 .60425 Mdot
.6003 .55534 Mdot
.53844 .35657 Mdot
.60878 .49328 Mdot
.63001 .47663 Mdot
.28468 .34743 Mdot
.62145 .52478 Mdot
.37738 .41253 Mdot
.53799 .30819 Mdot
.21114 .63228 Mdot
.32126 .58608 Mdot
.64822 .5674 Mdot
.65126 .53943 Mdot
.539 .36286 Mdot
.6525 .57502 Mdot
.37513 .4604 Mdot
.08237 .51533 Mdot
.50758 .69383 Mdot
.29819 .36086 Mdot
.26776 .60769 Mdot
.63788 .50256 Mdot
.60157 .5036 Mdot
.25573 .36322 Mdot
.39507 .21815 Mdot
.37505 .41397 Mdot
.67712 .49274 Mdot
.37203 .58193 Mdot
.52897 .68992 Mdot
.3756 .46677 Mdot
.60488 .54563 Mdot
.64312 .56639 Mdot
.52482 .70181 Mdot
.31043 .69064 Mdot
.38705 .53361 Mdot
.38843 .42699 Mdot
.54286 .49563 Mdot
.44281 .67802 Mdot
.6365 .56135 Mdot
.17524 .48969 Mdot
.57075 .34172 Mdot
.36891 .42332 Mdot
.74285 .49581 Mdot
.58193 .54034 Mdot
.35831 .44399 Mdot
.39588 .45443 Mdot
.62212 .58107 Mdot
.58669 .37481 Mdot
.53841 .30123 Mdot
.574 .34126 Mdot
.81152 .45396 Mdot
.62921 .76892 Mdot
.35033 .5694 Mdot
.39053 .45198 Mdot
.30517 .6079 Mdot
.54861 .6729 Mdot
.4417 .51549 Mdot
.3091 .61428 Mdot
.59088 .34037 Mdot
.30477 .61869 Mdot
.5916 .52539 Mdot
.39233 .45845 Mdot
.37878 .57658 Mdot
.63127 .50308 Mdot
.70486 .49918 Mdot
.50167 .53959 Mdot
.54668 .67092 Mdot
.41985 .53733 Mdot
.62927 .53518 Mdot
.28823 .34988 Mdot
.66533 .54778 Mdot
.40941 .45245 Mdot
.47846 .54297 Mdot
.62538 .50573 Mdot
.37022 .55549 Mdot
.47803 .63287 Mdot
.32673 .6194 Mdot
.65807 .48003 Mdot
.6353 .54197 Mdot
.63761 .56287 Mdot
.60939 .49148 Mdot
.37768 .30466 Mdot
.3987 .40757 Mdot
.71033 .5685 Mdot
.35109 .55201 Mdot
.54562 .33422 Mdot
.55028 .36853 Mdot
.43605 .62924 Mdot
.28396 .35126 Mdot
.38098 .45896 Mdot
.6346 .56251 Mdot
.27323 .60311 Mdot
.23052 .35511 Mdot
.17017 .47628 Mdot
.36876 .69986 Mdot
.37688 .58084 Mdot
.58013 .30345 Mdot
.3816 .58865 Mdot
.61912 .57521 Mdot
.69237 .55559 Mdot
.21843 .64253 Mdot
.40556 .48071 Mdot
.52018 .68968 Mdot
.62514 .57127 Mdot
.75553 .63613 Mdot
.37262 .58314 Mdot
.39126 .57638 Mdot
.59184 .54582 Mdot
.52651 .31027 Mdot
.25463 .73888 Mdot
.40685 .45404 Mdot
.64388 .3178 Mdot
.53551 .39622 Mdot
.55396 .43677 Mdot
.40336 .43954 Mdot
.51499 .56684 Mdot
.32162 .60968 Mdot
.61594 .23166 Mdot
.54899 .33759 Mdot
.51829 .6859 Mdot
.69136 .52502 Mdot
.59252 .33638 Mdot
.33044 .63108 Mdot
.58841 .33204 Mdot
.58487 .54699 Mdot
.37128 .40894 Mdot
.33191 .61178 Mdot
.41063 .41006 Mdot
.54849 .37866 Mdot
.53371 .69019 Mdot
.7487 .61385 Mdot
.64621 .30639 Mdot
.77327 .48177 Mdot
.61848 .50753 Mdot
.28658 .59838 Mdot
.60792 .52942 Mdot
.54955 .29299 Mdot
.6374 .55098 Mdot
.51013 .29194 Mdot
.36377 .6181 Mdot
.61673 .47278 Mdot
.66651 .56033 Mdot
.63111 .25996 Mdot
.6617 .53078 Mdot
.6327 .58281 Mdot
.62634 .48602 Mdot
.51858 .38491 Mdot
.65139 .46995 Mdot
.53618 .35196 Mdot
.42052 .31583 Mdot
.35231 .58437 Mdot
.52867 .71544 Mdot
.49452 .68285 Mdot
.7278 .67659 Mdot
.75012 .63216 Mdot
.39785 .34097 Mdot
.55282 .35584 Mdot
.359 .42476 Mdot
.59145 .53575 Mdot
.72226 .47597 Mdot
.56076 .64572 Mdot
.32376 .61081 Mdot
.34898 .5583 Mdot
.62283 .45613 Mdot
.68442 .77443 Mdot
.6388 .46905 Mdot
.45164 .33887 Mdot
.58878 .50564 Mdot
.6285 .48173 Mdot
.39235 .56121 Mdot
.72709 .62954 Mdot
.61892 .50712 Mdot
.559 .29094 Mdot
.51559 .68243 Mdot
.54389 .51956 Mdot
.55953 .6359 Mdot
.50623 .50668 Mdot
.58501 .24575 Mdot
.61676 .52345 Mdot
.36031 .59903 Mdot
.59398 .32666 Mdot
.46982 .31344 Mdot
.37898 .42972 Mdot
.45795 .36806 Mdot
.65554 .28051 Mdot
.31452 .65324 Mdot
.51686 .68757 Mdot
.3315 .69776 Mdot
.64613 .52016 Mdot
.33281 .57453 Mdot
.58721 .54485 Mdot
.22547 .36081 Mdot
.5406 .68059 Mdot
.53579 .37161 Mdot
.36118 .42763 Mdot
.55318 .36427 Mdot
.75237 .4571 Mdot
.55127 .61651 Mdot
.26199 .31164 Mdot
.31705 .58654 Mdot
.76169 .58298 Mdot
.56729 .30962 Mdot
.60146 .54704 Mdot
.2203 .2588 Mdot
.57032 .33953 Mdot
.54636 .3624 Mdot
.45038 .62239 Mdot
.65956 .64814 Mdot
.56677 .56584 Mdot
.58755 .33832 Mdot
.30367 .60192 Mdot
.52413 .66751 Mdot
.61566 .49991 Mdot
.62166 .48725 Mdot
.53006 .34607 Mdot
.35147 .61871 Mdot
.76532 .6325 Mdot
.3358 .58136 Mdot
.53568 .33552 Mdot
.33868 .59938 Mdot
.26656 .58904 Mdot
.3701 .57173 Mdot
.67558 .55038 Mdot
.6333 .56155 Mdot
.44398 .76051 Mdot
.56594 .34587 Mdot
.60832 .49957 Mdot
.61806 .54869 Mdot
.55926 .31004 Mdot
.35492 .54748 Mdot
.75977 .53281 Mdot
.63857 .50974 Mdot
.62665 .55781 Mdot
.53533 .65864 Mdot
.41879 .57352 Mdot
.19926 .45442 Mdot
.61289 .4995 Mdot
.49821 .7035 Mdot
.54418 .3009 Mdot
.6664 .54435 Mdot
.74331 .624 Mdot
.39912 .56321 Mdot
.63397 .57723 Mdot
.30325 .33541 Mdot
.64719 .5014 Mdot
.25022 .73397 Mdot
.65612 .56404 Mdot
.55421 .30621 Mdot
.5727 .31592 Mdot
.3822 .52611 Mdot
.55379 .32927 Mdot
.28815 .33794 Mdot
.37363 .44347 Mdot
.16206 .49413 Mdot
.29139 .33634 Mdot
.64779 .48477 Mdot
.57757 .20012 Mdot
.58619 .50122 Mdot
.66674 .57435 Mdot
.77484 .59972 Mdot
.29075 .33901 Mdot
.57953 .31469 Mdot
.21232 .52624 Mdot
.62416 .47936 Mdot
.40441 .45622 Mdot
.68569 .55734 Mdot
.63943 .57624 Mdot
.52996 .42724 Mdot
.80052 .47555 Mdot
.41008 .455 Mdot
.685 .58345 Mdot
.61221 .50037 Mdot
.45908 .19622 Mdot
.6475 .53346 Mdot
.50292 .70016 Mdot
.56718 .35654 Mdot
.3846 .58561 Mdot
.50714 .68469 Mdot
.6435 .50968 Mdot
.52118 .68328 Mdot
.35353 .56937 Mdot
.36935 .43244 Mdot
.63974 .57284 Mdot
.49518 .67417 Mdot
.52291 .69255 Mdot
.60287 .5262 Mdot
.57281 .32186 Mdot
.55345 .52101 Mdot
.66718 .54104 Mdot
.60437 .55254 Mdot
.55455 .36022 Mdot
.56347 .15692 Mdot
.60139 .56945 Mdot
.50754 .57107 Mdot
.56078 .37396 Mdot
.32029 .35641 Mdot
.38095 .58626 Mdot
.58726 .56287 Mdot
.39043 .43178 Mdot
.37942 .43588 Mdot
.31001 .581 Mdot
.52614 .34959 Mdot
.34059 .62012 Mdot
.6312 .6039 Mdot
.63853 .45888 Mdot
.68679 .50341 Mdot
.83397 .36819 Mdot
.2633 .66845 Mdot
.53663 .31238 Mdot
.32451 .61483 Mdot
.4637 .42178 Mdot
.38039 .45749 Mdot
.29692 .60378 Mdot
.60198 .31429 Mdot
.5634 .3001 Mdot
.58792 .34419 Mdot
.52222 .66031 Mdot
.32801 .58579 Mdot
.52013 .29806 Mdot
.52233 .3223 Mdot
.59575 .54615 Mdot
.61106 .50104 Mdot
.50856 .34796 Mdot
.66246 .72382 Mdot
.53179 .69549 Mdot
.35482 .60108 Mdot
.45014 .86183 Mdot
.4099 .45114 Mdot
.62924 .25782 Mdot
.63304 .50388 Mdot
.41714 .11368 Mdot
.67132 .48263 Mdot
.64959 .53733 Mdot
.5459 .30134 Mdot
.50082 .71496 Mdot
.52815 .67348 Mdot
.56803 .31039 Mdot
.55115 .38364 Mdot
.50033 .67635 Mdot
.36466 .70462 Mdot
.15522 .54037 Mdot
.46394 .33504 Mdot
.55185 .30851 Mdot
.63833 .30171 Mdot
.36923 .45791 Mdot
.56418 .3774 Mdot
.41224 .4514 Mdot
.35501 .58285 Mdot
.35203 .55918 Mdot
.39468 .47673 Mdot
.60449 .56096 Mdot
.36258 .56776 Mdot
.64105 .61122 Mdot
.24084 .6452 Mdot
.43514 .80159 Mdot
.36871 .22372 Mdot
.65393 .50081 Mdot
.43554 .26321 Mdot
.40494 .26214 Mdot
.6334 .52509 Mdot
.61548 .4403 Mdot
.52005 .68751 Mdot
.55687 .37666 Mdot
.38363 .4628 Mdot
.27995 .73045 Mdot
.63583 .56171 Mdot
.53912 .32593 Mdot
.38741 .4587 Mdot
.27242 .56932 Mdot
.50328 .4044 Mdot
.59034 .54515 Mdot
.12204 .37495 Mdot
.54182 .37525 Mdot
.38462 .58598 Mdot
.57468 .21476 Mdot
.58518 .37118 Mdot
.45078 .66374 Mdot
.37947 .605 Mdot
.17912 .42728 Mdot
.57961 .308 Mdot
.3736 .53845 Mdot
.55797 .3222 Mdot
.51958 .70669 Mdot
.59288 .37108 Mdot
.33803 .61165 Mdot
.65889 .53945 Mdot
.33495 .60838 Mdot
.52817 .7018 Mdot
.33403 .57121 Mdot
.38137 .463 Mdot
.28646 .34376 Mdot
.38005 .45313 Mdot
.43531 .52192 Mdot
.79248 .46044 Mdot
.3844 .41987 Mdot
.27107 .62795 Mdot
.63764 .49649 Mdot
.54334 .28053 Mdot
.38638 .58063 Mdot
.32166 .57427 Mdot
.44487 .50429 Mdot
.54411 .32377 Mdot
.34087 .60942 Mdot
.6575 .28814 Mdot
.64725 .18488 Mdot
.65725 .61171 Mdot
.58128 .78017 Mdot
.55693 .30955 Mdot
.3746 .60843 Mdot
.46173 .32134 Mdot
.57598 .36159 Mdot
.3748 .56222 Mdot
.36371 .43046 Mdot
.39799 .43609 Mdot
.6064 .56708 Mdot
.41846 .46901 Mdot
.34243 .62753 Mdot
.34545 .26583 Mdot
.56899 .35672 Mdot
.28073 .56377 Mdot
.4992 .69594 Mdot
.35758 .57741 Mdot
.56165 .52787 Mdot
.53576 .38075 Mdot
.34103 .56027 Mdot
.48268 .78389 Mdot
.49094 .86787 Mdot
.34125 .60845 Mdot
.5679 .35618 Mdot
.5431 .34145 Mdot
.57526 .5853 Mdot
.46498 .47628 Mdot
.34753 .61669 Mdot
.32871 .48265 Mdot
.72654 .68612 Mdot
.3063 .34333 Mdot
.51462 .17804 Mdot
.62027 .50733 Mdot
.60912 .5336 Mdot
.36886 .45246 Mdot
.65427 .52232 Mdot
.53171 .30333 Mdot
.67346 .56387 Mdot
.35364 .42267 Mdot
.32631 .61296 Mdot
.65655 .56004 Mdot
.53437 .67335 Mdot
.37654 .46327 Mdot
.37829 .47541 Mdot
.34304 .59128 Mdot
.58765 .34159 Mdot
.20046 .53111 Mdot
.33508 .58113 Mdot
.61723 .5217 Mdot
.29669 .34628 Mdot
.58252 .54893 Mdot
.41533 .76571 Mdot
.56571 .3641 Mdot
.38193 .58947 Mdot
.5973 .34273 Mdot
.38457 .44988 Mdot
.31528 .57665 Mdot
.64397 .53195 Mdot
.37156 .55972 Mdot
.54235 .73009 Mdot
.37912 .73197 Mdot
.51983 .32953 Mdot
.48461 .69164 Mdot
.53477 .35711 Mdot
.30617 .34226 Mdot
.59632 .68601 Mdot
.51487 .69495 Mdot
.36855 .57859 Mdot
.26088 .67377 Mdot
.38164 .55816 Mdot
.66292 .5294 Mdot
.66394 .51665 Mdot
.36716 .60295 Mdot
.53361 .66525 Mdot
.82077 .56422 Mdot
.52758 .59735 Mdot
.58457 .31908 Mdot
.52364 .26181 Mdot
.38033 .83251 Mdot
.38185 .39019 Mdot
.35878 .43513 Mdot
.70554 .5281 Mdot
.59729 .50207 Mdot
.37512 .47031 Mdot
.41328 .42105 Mdot
.54285 .66261 Mdot
.33985 .56967 Mdot
.58682 .28893 Mdot
.37099 .46243 Mdot
.67899 .62485 Mdot
.75373 .62557 Mdot
.5843 .5936 Mdot
.59889 .47505 Mdot
.67414 .50842 Mdot
.43703 .53367 Mdot
.39523 .40991 Mdot
.62765 .53902 Mdot
.68335 .48879 Mdot
.37076 .41915 Mdot
.52349 .70425 Mdot
.60426 .29356 Mdot
.34527 .60059 Mdot
.54015 .12133 Mdot
.6425 .57232 Mdot
.66225 .54039 Mdot
.39212 .42835 Mdot
.48131 .18024 Mdot
.53924 .31286 Mdot
.58152 .34908 Mdot
.35421 .57402 Mdot
.44077 .50449 Mdot
.6713 .56178 Mdot
.63225 .52862 Mdot
.3645 .58309 Mdot
.28787 .34654 Mdot
.32897 .24275 Mdot
.62607 .55091 Mdot
.39792 .44829 Mdot
.29183 .57409 Mdot
.39879 .41087 Mdot
.58899 .55019 Mdot
.66365 .52656 Mdot
.67394 .55406 Mdot
.60614 .49179 Mdot
.384 .47531 Mdot
.63529 .52853 Mdot
.58104 .46773 Mdot
.58262 .32932 Mdot
.62888 .51218 Mdot
.72444 .67293 Mdot
.63038 .5556 Mdot
.53473 .67671 Mdot
.19442 .47932 Mdot
.63276 .5673 Mdot
.6272 .51435 Mdot
.52221 .58968 Mdot
.65296 .54661 Mdot
.41022 .44448 Mdot
.54619 .33934 Mdot
.38953 .45287 Mdot
.40053 .41758 Mdot
.30856 .59422 Mdot
.54439 .6656 Mdot
.57521 .55685 Mdot
.49659 .69249 Mdot
.56918 .50468 Mdot
.58465 .54387 Mdot
.4199 .55137 Mdot
.45049 .34156 Mdot
.5301 .73008 Mdot
.64075 .53589 Mdot
.35198 .5793 Mdot
.38441 .57764 Mdot
.5454 .75636 Mdot
.61635 .60946 Mdot
.38026 .47102 Mdot
.36461 .43588 Mdot
.64431 .70886 Mdot
.52062 .41362 Mdot
.5343 .6847 Mdot
.46566 .40486 Mdot
.65664 .49956 Mdot
.61827 .55594 Mdot
.68407 .56157 Mdot
.30728 .61203 Mdot
.2878 .35189 Mdot
.3222 .60685 Mdot
.28398 .36092 Mdot
.39999 .41005 Mdot
.65567 .50238 Mdot
.39427 .79029 Mdot
.52584 .33405 Mdot
.54705 .34038 Mdot
.35081 .43108 Mdot
.32886 .62077 Mdot
.57156 .57764 Mdot
.84319 .37475 Mdot
.50734 .32074 Mdot
.51296 .71992 Mdot
.62901 .53001 Mdot
.34543 .58762 Mdot
.5242 .32563 Mdot
.51632 .65054 Mdot
.66145 .50702 Mdot
.36079 .54806 Mdot
.63536 .55363 Mdot
.65556 .41051 Mdot
.581 .32383 Mdot
.22946 .35024 Mdot
.51857 .32727 Mdot
.36159 .45162 Mdot
.39006 .4138 Mdot
.66724 .5281 Mdot
.75137 .27061 Mdot
.52779 .36593 Mdot
.42042 .41847 Mdot
.53087 .7045 Mdot
.29932 .36074 Mdot
.54267 .68685 Mdot
.35785 .61964 Mdot
.51528 .68552 Mdot
.36667 .55465 Mdot
.64327 .72317 Mdot
.51051 .30923 Mdot
.50726 .69044 Mdot
.45084 .17872 Mdot
.62047 .58859 Mdot
.53808 .65639 Mdot
.61073 .45716 Mdot
.49502 .31608 Mdot
.36139 .58584 Mdot
.53277 .66579 Mdot
.59876 .54305 Mdot
.30975 .74659 Mdot
.39545 .41476 Mdot
.38241 .47172 Mdot
.57654 .56074 Mdot
.38972 .56288 Mdot
.55762 .38584 Mdot
.45981 .59558 Mdot
.32079 .35276 Mdot
.63288 .52954 Mdot
.65839 .50292 Mdot
.53539 .36306 Mdot
.54444 .29196 Mdot
.66449 .52439 Mdot
.66564 .30634 Mdot
.64539 .51898 Mdot
.4007 .43576 Mdot
.55517 .30144 Mdot
.54535 .34294 Mdot
.33572 .62837 Mdot
.5257 .34768 Mdot
.61104 .47127 Mdot
.35985 .4756 Mdot
.69405 .51718 Mdot
.38265 .44571 Mdot
.48388 .54684 Mdot
.32624 .57933 Mdot
.27739 .71893 Mdot
.52533 .35186 Mdot
.62327 .52112 Mdot
.53882 .36091 Mdot
.50006 .68697 Mdot
.56364 .34635 Mdot
.59623 .32106 Mdot
.66791 .51696 Mdot
.58946 .54316 Mdot
.29094 .34396 Mdot
.46265 .47891 Mdot
.57688 .33095 Mdot
.64127 .51846 Mdot
.58572 .4996 Mdot
.61742 .58343 Mdot
.48356 .4916 Mdot
.56218 .29833 Mdot
.73599 .33071 Mdot
.42594 .78006 Mdot
.57381 .3255 Mdot
.29658 .76497 Mdot
.31211 .34236 Mdot
.28541 .35447 Mdot
.38164 .39303 Mdot
.62437 .55401 Mdot
.33714 .61689 Mdot
.62113 .57565 Mdot
.656 .60989 Mdot
.64037 .56851 Mdot
.53591 .69359 Mdot
.56916 .52104 Mdot
.30926 .35336 Mdot
.33169 .58796 Mdot
.64006 .50781 Mdot
.65178 .56327 Mdot
.28213 .34691 Mdot
.51755 .33287 Mdot
.57283 .303 Mdot
.17671 .49761 Mdot
.51167 .7018 Mdot
.37311 .433 Mdot
.61245 .56788 Mdot
.35303 .5771 Mdot
.33218 .60701 Mdot
.55067 .36394 Mdot
.3507 .60006 Mdot
.40757 .4543 Mdot
.64909 .52932 Mdot
.37741 .47214 Mdot
.53469 .69526 Mdot
.56636 .3568 Mdot
.61284 .56872 Mdot
.59642 .54761 Mdot
.57296 .3159 Mdot
.63864 .49648 Mdot
.53459 .65835 Mdot
.34907 .56195 Mdot
.57035 .30351 Mdot
.37442 .44138 Mdot
.33033 .62756 Mdot
.59253 .52975 Mdot
.55678 .84587 Mdot
.65323 .51983 Mdot
.61028 .55931 Mdot
.17402 .5895 Mdot
.69966 .51075 Mdot
.36802 .61344 Mdot
.55318 .36979 Mdot
.63955 .59303 Mdot
.72685 .70064 Mdot
.27977 .38528 Mdot
.29887 .59857 Mdot
.62571 .5279 Mdot
.26468 .70851 Mdot
.62822 .51937 Mdot
.26669 .56781 Mdot
.42059 .54653 Mdot
.63674 .78228 Mdot
.60305 .47134 Mdot
.41065 .46056 Mdot
.2894 .34284 Mdot
.38726 .57376 Mdot
.7207 .45349 Mdot
.65071 .50951 Mdot
.75039 .48237 Mdot
.65057 .57331 Mdot
.40247 .43943 Mdot
.66275 .45713 Mdot
.35344 .60136 Mdot
.59965 .22393 Mdot
.61231 .52445 Mdot
.55892 .29894 Mdot
.30171 .61367 Mdot
.31206 .35983 Mdot
.59892 .54658 Mdot
.50033 .70318 Mdot
.34815 .37601 Mdot
.63223 .46135 Mdot
.38038 .44419 Mdot
.61617 .54889 Mdot
.67858 .59085 Mdot
.69725 .23433 Mdot
.58368 .32583 Mdot
.35997 .43353 Mdot
.46841 .22175 Mdot
.64178 .49517 Mdot
.57773 .30669 Mdot
.54781 .33591 Mdot
.51074 .7088 Mdot
.44665 .38286 Mdot
.33171 .38694 Mdot
.47451 .80998 Mdot
.77155 .45986 Mdot
.3355 .63115 Mdot
.37649 .24383 Mdot
.61298 .50384 Mdot
.54642 .60346 Mdot
.41022 .44039 Mdot
.66028 .54157 Mdot
.78575 .44216 Mdot
.57321 .3427 Mdot
.62945 .54819 Mdot
.52919 .69767 Mdot
.38109 .36989 Mdot
.51204 .5063 Mdot
.47844 .8441 Mdot
.29977 .60342 Mdot
.6923 .54424 Mdot
.59117 .47147 Mdot
.31908 .35861 Mdot
.58589 .53072 Mdot
.38739 .57952 Mdot
.28302 .66135 Mdot
.53724 .66853 Mdot
.52416 .33755 Mdot
.31371 .34489 Mdot
.68399 .53289 Mdot
.57737 .55017 Mdot
.52788 .71565 Mdot
.60253 .53928 Mdot
.58847 .22202 Mdot
.29436 .31811 Mdot
.36918 .56893 Mdot
.58933 .3307 Mdot
.67245 .50567 Mdot
.28849 .35233 Mdot
.66603 .51621 Mdot
.58806 .26483 Mdot
.6139 .53542 Mdot
.35719 .35576 Mdot
.5689 .31875 Mdot
.37908 .44754 Mdot
.57392 .55872 Mdot
.64469 .55966 Mdot
.44092 .68188 Mdot
.65859 .60897 Mdot
.65437 .56469 Mdot
.5651 .29044 Mdot
.52886 .33157 Mdot
.5393 .35534 Mdot
.36465 .56558 Mdot
.46266 .34716 Mdot
.39376 .44274 Mdot
.66059 .57199 Mdot
.37189 .46295 Mdot
.67705 .61623 Mdot
.52087 .7183 Mdot
.34377 .78829 Mdot
.64374 .50501 Mdot
.54479 .3566 Mdot
.33991 .28265 Mdot
.54192 .30203 Mdot
.40116 .5548 Mdot
.39518 .45583 Mdot
.57109 .3377 Mdot
.64787 .54798 Mdot
.46728 .4427 Mdot
.51829 .84239 Mdot
.37651 .45506 Mdot
.68718 .56111 Mdot
.30328 .59733 Mdot
.35814 .5538 Mdot
.29934 .78757 Mdot
.38698 .41141 Mdot
.40257 .2588 Mdot
.63839 .51785 Mdot
.52681 .33701 Mdot
.3858 .4229 Mdot
.41228 .43905 Mdot
.36129 .58916 Mdot
.59273 .55371 Mdot
.64051 .5586 Mdot
.30509 .3363 Mdot
.36656 .43742 Mdot
.62087 .59114 Mdot
.58746 .51377 Mdot
.20969 .6358 Mdot
.58639 .28324 Mdot
.53507 .1487 Mdot
.63618 .60258 Mdot
.78411 .46871 Mdot
.46613 .51739 Mdot
.53628 .31134 Mdot
.61305 .57142 Mdot
.68622 .54168 Mdot
.33966 .63128 Mdot
.65025 .52482 Mdot
.31415 .61128 Mdot
.35743 .43383 Mdot
.36013 .80164 Mdot
.29448 .55073 Mdot
.3466 .6923 Mdot
.65758 .52666 Mdot
.5408 .44577 Mdot
.50458 .68129 Mdot
.3513 .44623 Mdot
.53475 .32835 Mdot
.66454 .499 Mdot
.37713 .60924 Mdot
.36999 .57905 Mdot
.55464 .33732 Mdot
.40236 .2807 Mdot
.25767 .63116 Mdot
.60333 .49254 Mdot
.37737 .5964 Mdot
.28512 .54081 Mdot
.68095 .3213 Mdot
.41527 .4685 Mdot
.53952 .67305 Mdot
.32754 .6129 Mdot
.38047 .47744 Mdot
.57527 .26395 Mdot
.56211 .33266 Mdot
.53912 .37001 Mdot
.4286 .73862 Mdot
.34384 .61697 Mdot
.51276 .67348 Mdot
.49964 .3884 Mdot
.47834 .34817 Mdot
.53849 .68661 Mdot
.32593 .61339 Mdot
.52626 .32747 Mdot
.53743 .32888 Mdot
.54519 .33816 Mdot
.59658 .22529 Mdot
.57015 .36064 Mdot
.69767 .28058 Mdot
.58246 .50727 Mdot
.63934 .3241 Mdot
.62737 .5219 Mdot
.39775 .47196 Mdot
.58034 .32234 Mdot
.45489 .50507 Mdot
.645 .48753 Mdot
.48363 .84086 Mdot
.62911 .53381 Mdot
.38221 .48668 Mdot
.62498 .55608 Mdot
.62115 .2793 Mdot
.56029 .3742 Mdot
.64075 .53402 Mdot
.42009 .43556 Mdot
.52495 .68945 Mdot
.61348 .33568 Mdot
.63421 .56644 Mdot
.40066 .36207 Mdot
.68351 .49023 Mdot
.24822 .64738 Mdot
.46049 .63705 Mdot
.50939 .71984 Mdot
.67158 .47818 Mdot
.31686 .62695 Mdot
.5877 .38699 Mdot
.63224 .33918 Mdot
.37554 .45421 Mdot
.78836 .55231 Mdot
.36754 .57604 Mdot
.66005 .45582 Mdot
.64624 .47954 Mdot
.52233 .65891 Mdot
.58553 .3859 Mdot
.40161 .43203 Mdot
.64377 .50075 Mdot
.62463 .58128 Mdot
.48332 .76516 Mdot
.63232 .32514 Mdot
.60544 .58216 Mdot
.54688 .68201 Mdot
.74618 .33997 Mdot
.62228 .56398 Mdot
.3475 .55099 Mdot
.57053 .36795 Mdot
.57461 .49521 Mdot
.7254 .32049 Mdot
.6426 .51627 Mdot
.56605 .339 Mdot
.52713 .35556 Mdot
.35935 .32072 Mdot
.5119 .71827 Mdot
.61368 .53582 Mdot
.45477 .67947 Mdot
.61151 .52885 Mdot
.39763 .44139 Mdot
.59827 .56713 Mdot
.35991 .58027 Mdot
.45906 .3211 Mdot
.35722 .56316 Mdot
.60895 .57335 Mdot
.54152 .32984 Mdot
.39841 .42757 Mdot
.42121 .75243 Mdot
.44136 .60079 Mdot
.70614 .28855 Mdot
.29067 .3741 Mdot
.52457 .66195 Mdot
.53784 .65216 Mdot
.37135 .40552 Mdot
.63713 .54022 Mdot
.43804 .55364 Mdot
.63407 .47195 Mdot
.62487 .55939 Mdot
.6364 .57204 Mdot
.41042 .4801 Mdot
.38846 .45587 Mdot
.33729 .60374 Mdot
.66307 .52318 Mdot
.64108 .51992 Mdot
.56965 .3267 Mdot
.52409 .69284 Mdot
.36731 .5632 Mdot
.5059 .69611 Mdot
.33838 .58202 Mdot
.2572 .73761 Mdot
.66045 .58989 Mdot
.52613 .68871 Mdot
.37952 .40683 Mdot
.55073 .36071 Mdot
.28428 .33497 Mdot
.35134 .62313 Mdot
.3509 .60407 Mdot
.63416 .52697 Mdot
.56659 .35393 Mdot
.57667 .34644 Mdot
.50526 .6703 Mdot
.37219 .42498 Mdot
.61194 .57411 Mdot
.58803 .52415 Mdot
.53676 .78241 Mdot
.31868 .62258 Mdot
.67888 .30567 Mdot
.37851 .32049 Mdot
.63802 .54005 Mdot
.586 .33353 Mdot
.66089 .55566 Mdot
.30918 .72561 Mdot
.59163 .33834 Mdot
.61509 .48537 Mdot
.52955 .40841 Mdot
.30907 .59797 Mdot
.33376 .32867 Mdot
.57376 .52688 Mdot
.25282 .36437 Mdot
.6067 .51506 Mdot
.14471 .57463 Mdot
.41536 .21393 Mdot
.67883 .5512 Mdot
.61998 .48944 Mdot
.50573 .81594 Mdot
.63514 .51703 Mdot
.31097 .34759 Mdot
.62618 .60563 Mdot
.56726 .30064 Mdot
.45204 .55316 Mdot
.41018 .59243 Mdot
.52026 .71447 Mdot
.35476 .57346 Mdot
.59318 .65437 Mdot
.5199 .70558 Mdot
.55744 .30729 Mdot
.62217 .48668 Mdot
.749 .58664 Mdot
.39605 .55306 Mdot
.62834 .47598 Mdot
.3992 .44143 Mdot
.41418 .58072 Mdot
.31702 .60081 Mdot
.37426 .44574 Mdot
.65998 .5674 Mdot
.76442 .66112 Mdot
.4353 .6145 Mdot
.16793 .42577 Mdot
.38879 .42716 Mdot
.40587 .44652 Mdot
.47807 .29399 Mdot
.51992 .71445 Mdot
.49494 .76567 Mdot
.5382 .47338 Mdot
.39834 .4599 Mdot
.64581 .68252 Mdot
.3925 .57607 Mdot
.4447 .37669 Mdot
.55904 .37662 Mdot
.6652 .58596 Mdot
.64731 .55151 Mdot
.37209 .42181 Mdot
.73531 .50782 Mdot
.53018 .22935 Mdot
.37855 .45339 Mdot
.57821 .47712 Mdot
.4099 .37313 Mdot
.29649 .34288 Mdot
.30683 .33599 Mdot
.53186 .70555 Mdot
.28534 .64574 Mdot
.55867 .31788 Mdot
.52123 .65708 Mdot
.34178 .36048 Mdot
.6117 .5411 Mdot
.36526 .44287 Mdot
.28474 .33202 Mdot
.38355 .43565 Mdot
.53047 .67822 Mdot
.51405 .71968 Mdot
.58287 .32869 Mdot
.53888 .31367 Mdot
.79736 .48199 Mdot
.66563 .70007 Mdot
.63123 .51469 Mdot
.76132 .52091 Mdot
.56246 .36094 Mdot
.6116 .37615 Mdot
.50219 .71008 Mdot
.52469 .69541 Mdot
.6628 .3847 Mdot
.59327 .54428 Mdot
.29955 .5557 Mdot
.62958 .56607 Mdot
.59345 .69689 Mdot
.64642 .48222 Mdot
.3574 .59346 Mdot
.62145 .5127 Mdot
.19636 .5075 Mdot
.62304 .49695 Mdot
.64661 .56927 Mdot
.32604 .59809 Mdot
.58714 .58682 Mdot
.36192 .57935 Mdot
.59064 .55267 Mdot
.54665 .69078 Mdot
.35288 .5769 Mdot
.60599 .77256 Mdot
.50706 .56867 Mdot
.29393 .35641 Mdot
.52492 .70711 Mdot
.4975 .69258 Mdot
.74111 .66094 Mdot
.53571 .32392 Mdot
.55455 .26815 Mdot
.6362 .54077 Mdot
.39103 .57595 Mdot
.36791 .45202 Mdot
.64287 .5189 Mdot
.68864 .53567 Mdot
.57353 .54862 Mdot
.5753 .33915 Mdot
.33271 .62032 Mdot
.52437 .6823 Mdot
.38221 .58135 Mdot
.42902 .64438 Mdot
.3718 .55269 Mdot
.7071 .52208 Mdot
.62666 .59911 Mdot
.59152 .61401 Mdot
.76964 .50674 Mdot
.61574 .22788 Mdot
.55699 .33289 Mdot
.29808 .35204 Mdot
.52329 .71572 Mdot
.52797 .25945 Mdot
.53877 .34775 Mdot
.34892 .6075 Mdot
.63554 .55365 Mdot
.57302 .48209 Mdot
.51795 .48871 Mdot
.53117 .38977 Mdot
.70786 .70682 Mdot
.32757 .58219 Mdot
.30234 .34196 Mdot
.46229 .33194 Mdot
.50061 .35559 Mdot
.44846 .51105 Mdot
.65073 .56027 Mdot
.49893 .70169 Mdot
.52417 .32576 Mdot
.45183 .75237 Mdot
.36626 .42704 Mdot
.46433 .47602 Mdot
.65636 .52597 Mdot
.36646 .26317 Mdot
.54192 .3296 Mdot
.53161 .69357 Mdot
.37235 .42113 Mdot
.50932 .71698 Mdot
.31333 .34172 Mdot
.17981 .51177 Mdot
.60342 .53135 Mdot
.66151 .56073 Mdot
.40893 .41091 Mdot
.55607 .31935 Mdot
.37285 .53137 Mdot
.46238 .76812 Mdot
.37509 .59845 Mdot
.43259 .55121 Mdot
.53564 .31016 Mdot
.59223 .24995 Mdot
.37771 .57118 Mdot
.35028 .42661 Mdot
.44213 .53576 Mdot
.35575 .42048 Mdot
.62893 .56861 Mdot
.55175 .35366 Mdot
.38422 .4112 Mdot
.44627 .71103 Mdot
.2377 .69322 Mdot
.60531 .27879 Mdot
.64891 .5023 Mdot
.35772 .79828 Mdot
.19998 .61272 Mdot
.74402 .53464 Mdot
.36631 .45522 Mdot
.66933 .53446 Mdot
.60164 .49303 Mdot
.61467 .52147 Mdot
.36161 .41954 Mdot
.39358 .66547 Mdot
.36358 .5942 Mdot
.62469 .53611 Mdot
.49892 .69374 Mdot
.35347 .58867 Mdot
.30625 .62477 Mdot
.38632 .56595 Mdot
.59439 .31993 Mdot
.61005 .48859 Mdot
.43608 .3562 Mdot
.15606 .59711 Mdot
.38747 .45416 Mdot
.29473 .35684 Mdot
.65566 .56831 Mdot
.80377 .3938 Mdot
.53993 .35545 Mdot
.3731 .60057 Mdot
.66171 .5419 Mdot
.42622 .66774 Mdot
.26807 .33955 Mdot
.33464 .57915 Mdot
.53683 .32478 Mdot
.74335 .53599 Mdot
.64971 .52391 Mdot
.60429 .51724 Mdot
.55798 .31319 Mdot
.17122 .4727 Mdot
.45388 .33914 Mdot
.6557 .55985 Mdot
.37792 .44798 Mdot
.66902 .2035 Mdot
.57676 .55402 Mdot
.51972 .37 Mdot
.29793 .36062 Mdot
.38263 .34821 Mdot
.6883 .31406 Mdot
.6897 .59096 Mdot
.37984 .79742 Mdot
.73141 .62498 Mdot
.32898 .78239 Mdot
.56909 .65219 Mdot
.25757 .51605 Mdot
.22536 .7172 Mdot
.42049 .4391 Mdot
.62743 .31874 Mdot
.58571 .80322 Mdot
.41808 .28649 Mdot
.46215 .62973 Mdot
.29578 .42388 Mdot
.4444 .65347 Mdot
.36007 .1995 Mdot
.37726 .56014 Mdot
.57137 .72172 Mdot
.61565 .57583 Mdot
.19832 .60364 Mdot
.64252 .28768 Mdot
.61324 .21416 Mdot
.31912 .7687 Mdot
.4563 .66735 Mdot
.55084 .83225 Mdot
.27432 .70753 Mdot
.76275 .58496 Mdot
.51839 .46816 Mdot
.32967 .4579 Mdot
.48621 .37203 Mdot
.6106 .65435 Mdot
.57227 .58757 Mdot
.20626 .46802 Mdot
.29777 .65444 Mdot
.77569 .38353 Mdot
.67046 .21572 Mdot
.35583 .62266 Mdot
.57472 .36598 Mdot
.53002 .78747 Mdot
.60044 .37561 Mdot
.34151 .42171 Mdot
.38103 .79808 Mdot
.2084 .64038 Mdot
.621 .2774 Mdot
.25016 .32095 Mdot
.68944 .42058 Mdot
.83561 .52804 Mdot
.49696 .51766 Mdot
.52437 .35575 Mdot
.27932 .49195 Mdot
.4787 .3477 Mdot
.3516 .5038 Mdot
.59225 .23792 Mdot
.50001 .66012 Mdot
.65711 .74271 Mdot
.53941 .32372 Mdot
.6943 .32737 Mdot
.29512 .36251 Mdot
.33486 .36454 Mdot
.38163 .53697 Mdot
.32211 .73832 Mdot
.27419 .35707 Mdot
.41837 .36405 Mdot
.34237 .25988 Mdot
.53468 .85598 Mdot
.67976 .65779 Mdot
.30779 .70677 Mdot
.41094 .48861 Mdot
.72212 .63065 Mdot
.45139 .30184 Mdot
.68831 .68242 Mdot
.48505 .33324 Mdot
.6885 .78295 Mdot
.16462 .54252 Mdot
.5931 .82601 Mdot
.60518 .30923 Mdot
.61321 .58448 Mdot
.36561 .75958 Mdot
.76521 .45443 Mdot
.50479 .71952 Mdot
.50914 .85128 Mdot
.49379 .68928 Mdot
.59176 .29437 Mdot
.4129 .27921 Mdot
.6112 .24679 Mdot
.28863 .6382 Mdot
.55259 .67162 Mdot
.63304 .46826 Mdot
.81538 .6882 Mdot
.41155 .81388 Mdot
.36717 .32897 Mdot
.20395 .63116 Mdot
.42313 .41864 Mdot
.38266 .52077 Mdot
.35733 .43036 Mdot
.22658 .7009 Mdot
.5416 .34551 Mdot
.16031 .61828 Mdot
.2218 .68231 Mdot
.51939 .21022 Mdot
.8706 .62407 Mdot
.35863 .21996 Mdot
.64357 .32122 Mdot
.75321 .60491 Mdot
.68195 .7409 Mdot
.47475 .27527 Mdot
.51241 .20271 Mdot
.34253 .46855 Mdot
.16428 .47909 Mdot
.25894 .73067 Mdot
.62554 .69068 Mdot
.31745 .66177 Mdot
.43313 .28274 Mdot
.49603 .54384 Mdot
.51324 .35657 Mdot
.51119 .59739 Mdot
.53157 .57432 Mdot
.57079 .82832 Mdot
.80172 .41645 Mdot
.78577 .29982 Mdot
.57658 .67308 Mdot
.49311 .18259 Mdot
.26425 .66307 Mdot
.58853 .77178 Mdot
.56709 .24567 Mdot
.41747 .32562 Mdot
.69364 .49848 Mdot
.4643 .3571 Mdot
.57594 .46721 Mdot
.48667 .67546 Mdot
.47082 .31561 Mdot
.24615 .56521 Mdot
.59035 .68097 Mdot
.45502 .80195 Mdot
.53615 .43209 Mdot
.5908 .31554 Mdot
.71694 .66476 Mdot
.66235 .66981 Mdot
.21996 .64229 Mdot
.46574 .22266 Mdot
.16105 .44419 Mdot
.48559 .2176 Mdot
.63593 .47142 Mdot
.62307 .34718 Mdot
.56558 .57532 Mdot
.67938 .67807 Mdot
.5892 .49259 Mdot
.33281 .27242 Mdot
.17675 .60052 Mdot
.79095 .43849 Mdot
.59876 .66184 Mdot
.77024 .52251 Mdot
.16121 .49993 Mdot
.38559 .77094 Mdot
.41102 .22283 Mdot
.60468 .41739 Mdot
.76985 .72831 Mdot
.34404 .59587 Mdot
.64218 .68722 Mdot
.36556 .47106 Mdot
.43072 .74348 Mdot
.646 .78765 Mdot
.51548 .21916 Mdot
.17231 .59348 Mdot
.42652 .32854 Mdot
.31414 .56804 Mdot
.44672 .40448 Mdot
.37559 .62254 Mdot
.77403 .54061 Mdot
.581 .57496 Mdot
.64674 .62904 Mdot
.52415 .65385 Mdot
.75199 .43732 Mdot
.40887 .77288 Mdot
.25673 .42023 Mdot
.71156 .55154 Mdot
.25504 .45264 Mdot
.30377 .33956 Mdot
.4653 .45817 Mdot
.28944 .77889 Mdot
.65453 .60462 Mdot
.39151 .20331 Mdot
.16469 .52918 Mdot
.43366 .53931 Mdot
.31845 .69995 Mdot
.37321 .2968 Mdot
.64296 .80915 Mdot
.19963 .64946 Mdot
.22495 .59711 Mdot
.36979 .80662 Mdot
.16333 .39525 Mdot
.71132 .75215 Mdot
.70959 .45998 Mdot
.38766 .48251 Mdot
.09259 .47569 Mdot
.36852 .59644 Mdot
.79409 .5453 Mdot
.76682 .45 Mdot
.41654 .68094 Mdot
.57101 .39184 Mdot
.69746 .47879 Mdot
.31837 .37951 Mdot
.50987 .33203 Mdot
.63803 .46791 Mdot
.47984 .86081 Mdot
.6984 .78026 Mdot
.49686 .8589 Mdot
.17825 .51926 Mdot
.35608 .80238 Mdot
.55628 .81162 Mdot
.68946 .27237 Mdot
.50037 .77524 Mdot
.59427 .56161 Mdot
.62502 .71239 Mdot
.36827 .21688 Mdot
.37109 .53638 Mdot
.30416 .31942 Mdot
.60247 .3321 Mdot
.65535 .79465 Mdot
.30826 .79995 Mdot
.68471 .38982 Mdot
.73891 .35117 Mdot
.52113 .56494 Mdot
.6644 .69041 Mdot
.64404 .63342 Mdot
.2154 .44168 Mdot
.23854 .65155 Mdot
.57043 .8121 Mdot
.63688 .67188 Mdot
.28443 .43605 Mdot
.22949 .58319 Mdot
.47014 .18969 Mdot
.29473 .72753 Mdot
.56051 .79445 Mdot
.50179 .20898 Mdot
.61098 .42557 Mdot
.52666 .22629 Mdot
.21315 .41924 Mdot
.31602 .55201 Mdot
.66658 .65534 Mdot
.32709 .57638 Mdot
.62508 .69635 Mdot
.5032 .43669 Mdot
.51091 .78245 Mdot
.73584 .62787 Mdot
.61753 .69388 Mdot
.23595 .59612 Mdot
.44109 .84568 Mdot
.19896 .37309 Mdot
.78158 .66471 Mdot
.24064 .37381 Mdot
.58229 .45773 Mdot
.58893 .5659 Mdot
.16489 .55997 Mdot
.42076 .84806 Mdot
.17372 .61356 Mdot
.36568 .25995 Mdot
.44026 .70969 Mdot
.40668 .47674 Mdot
.78929 .59995 Mdot
.24947 .39716 Mdot
.2393 .66778 Mdot
.50296 .28121 Mdot
.38123 .39223 Mdot
.43318 .32961 Mdot
.78506 .55325 Mdot
.76584 .60427 Mdot
.7117 .34856 Mdot
.58656 .59724 Mdot
.65854 .31077 Mdot
.55635 .3723 Mdot
.37528 .24943 Mdot
.67916 .68526 Mdot
.34389 .5916 Mdot
.58825 .78643 Mdot
.63276 .62992 Mdot
.6981 .50408 Mdot
.31262 .55855 Mdot
.51324 .35327 Mdot
.77273 .49758 Mdot
.33528 .44903 Mdot
.23895 .73058 Mdot
.38002 .22129 Mdot
.72663 .60661 Mdot
.71235 .65236 Mdot
.49415 .7517 Mdot
.45248 .35647 Mdot
.36575 .40843 Mdot
.30487 .7528 Mdot
.49027 .59079 Mdot
.71706 .65991 Mdot
.66319 .31266 Mdot
.44532 .76904 Mdot
.68866 .53037 Mdot
.36019 .30682 Mdot
.73708 .31079 Mdot
.46136 .47417 Mdot
.56348 .2845 Mdot
.50607 .32152 Mdot
.35604 .18521 Mdot
.2055 .51337 Mdot
.45603 .214 Mdot
.31014 .7517 Mdot
.35429 .42443 Mdot
.57178 .29533 Mdot
.61115 .70433 Mdot
.38496 .7342 Mdot
.7745 .36518 Mdot
.27789 .61722 Mdot
.64369 .63739 Mdot
.24381 .41257 Mdot
.3637 .79954 Mdot
.48097 .83103 Mdot
.70639 .23824 Mdot
.52309 .31185 Mdot
.401 .76119 Mdot
.42375 .76254 Mdot
.52133 .32732 Mdot
.52593 .38362 Mdot
.52132 .4765 Mdot
.32036 .78531 Mdot
.46871 .36745 Mdot
.21716 .38989 Mdot
.4407 .538 Mdot
.41411 .66402 Mdot
.46167 .75751 Mdot
.65561 .65286 Mdot
.31444 .75101 Mdot
.69573 .33886 Mdot
.72007 .7256 Mdot
.56161 .57723 Mdot
.80319 .48025 Mdot
.79055 .59871 Mdot
.49193 .51008 Mdot
.60291 .25295 Mdot
.25756 .56676 Mdot
.61965 .51997 Mdot
.52858 .85879 Mdot
.22198 .63263 Mdot
.48489 .29788 Mdot
.33243 .41238 Mdot
.59774 .51073 Mdot
.5892 .49907 Mdot
.7102 .47806 Mdot
.38186 .33613 Mdot
.75832 .70906 Mdot
.58172 .6912 Mdot
.57595 .46384 Mdot
.66082 .30397 Mdot
.3935 .20318 Mdot
.33861 .74623 Mdot
.25301 .65383 Mdot
.4926 .43939 Mdot
.36932 .21846 Mdot
.43008 .50239 Mdot
.2125 .38785 Mdot
.23527 .45784 Mdot
.5436 .8099 Mdot
.56618 .43463 Mdot
.39951 .32863 Mdot
.48346 .75163 Mdot
.64798 .5712 Mdot
.40211 .28112 Mdot
.28201 .71298 Mdot
.82589 .35797 Mdot
.4527 .2898 Mdot
.45978 .8617 Mdot
.61099 .6226 Mdot
.40766 .33541 Mdot
.66806 .78019 Mdot
.86948 .43536 Mdot
.20809 .45475 Mdot
.55732 .83162 Mdot
.45381 .44811 Mdot
.31957 .7616 Mdot
.40942 .46687 Mdot
.49756 .40062 Mdot
.75798 .50009 Mdot
.31292 .78001 Mdot
.34169 .72897 Mdot
.33465 .75599 Mdot
.70377 .4665 Mdot
.36097 .81044 Mdot
.49248 .31451 Mdot
.38674 .17672 Mdot
.32723 .56257 Mdot
.31149 .26928 Mdot
.65137 .42921 Mdot
.5684 .60693 Mdot
.64173 .68032 Mdot
.46821 .16594 Mdot
.6522 .23869 Mdot
.7234 .47925 Mdot
.59274 .74273 Mdot
.37754 .30659 Mdot
.71404 .64841 Mdot
.2385 .67697 Mdot
.36589 .19385 Mdot
.44418 .75932 Mdot
.41466 .24017 Mdot
.17357 .50045 Mdot
.37595 .33666 Mdot
.23037 .49951 Mdot
.30558 .7071 Mdot
.19106 .42989 Mdot
.62417 .63685 Mdot
.44613 .12036 Mdot
.34706 .65166 Mdot
.52037 .48096 Mdot
.62097 .81466 Mdot
.23702 .64849 Mdot
.52022 .26231 Mdot
.57704 .22095 Mdot
.81378 .50156 Mdot
.64159 .72631 Mdot
.64021 .56837 Mdot
.37097 .81775 Mdot
.62837 .75606 Mdot
.53316 .84683 Mdot
.14931 .4993 Mdot
.66195 .3307 Mdot
.69869 .57242 Mdot
.33918 .63512 Mdot
.50772 .52104 Mdot
.58311 .74464 Mdot
.56923 .81997 Mdot
.80002 .51488 Mdot
.44595 .59383 Mdot
.25857 .50466 Mdot
.27252 .6097 Mdot
.57086 .45138 Mdot
.34797 .23137 Mdot
.38454 .3215 Mdot
.5824 .66434 Mdot
.2221 .57543 Mdot
.6595 .68422 Mdot
.68228 .30986 Mdot
.76673 .61829 Mdot
.49272 .24384 Mdot
.39031 .38286 Mdot
.34428 .63028 Mdot
.4916 .8083 Mdot
.25917 .63906 Mdot
.33113 .27609 Mdot
.76142 .68679 Mdot
.41623 .31904 Mdot
.56488 .73227 Mdot
.44218 .78896 Mdot
.47362 .27044 Mdot
.32801 .46088 Mdot
.77257 .59676 Mdot
.80119 .47722 Mdot
.26093 .58508 Mdot
.71779 .55448 Mdot
.26274 .73993 Mdot
.6587 .65578 Mdot
.4839 .78822 Mdot
.50577 .55902 Mdot
.76473 .42082 Mdot
.63522 .38477 Mdot
.6353 .76567 Mdot
.44535 .50098 Mdot
.80012 .7016 Mdot
.56838 .3855 Mdot
.53755 .85582 Mdot
.37086 .43654 Mdot
.75796 .29856 Mdot
.24867 .61843 Mdot
.49511 .45884 Mdot
.45682 .52177 Mdot
.35771 .3089 Mdot
.39473 .36566 Mdot
.16871 .49936 Mdot
.52446 .22259 Mdot
.37646 .55263 Mdot
.45037 .60499 Mdot
.21688 .39906 Mdot
.45848 .81008 Mdot
.63821 .59136 Mdot
.29084 .65007 Mdot
.49249 .51733 Mdot
.39956 .53464 Mdot
.16834 .56319 Mdot
.2676 .55366 Mdot
.57193 .49542 Mdot
.66629 .69201 Mdot
.59032 .81397 Mdot
.22425 .67752 Mdot
.53134 .23636 Mdot
.57465 .46917 Mdot
.36371 .47752 Mdot
.64296 .77798 Mdot
.41051 .80951 Mdot
.29518 .55632 Mdot
.44299 .37062 Mdot
.67281 .65986 Mdot
.54192 .87608 Mdot
.69446 .78121 Mdot
.77006 .68411 Mdot
.43821 .54744 Mdot
.53581 .28232 Mdot
.80636 .40492 Mdot
.4808 .78823 Mdot
.29428 .28426 Mdot
.22486 .61602 Mdot
.6479 .68467 Mdot
.85212 .42399 Mdot
.6337 .24015 Mdot
.42546 .64221 Mdot
.63637 .38682 Mdot
.77333 .46874 Mdot
.41747 .45304 Mdot
.62772 .73637 Mdot
.47036 .60598 Mdot
.35813 .40391 Mdot
.37904 .30952 Mdot
.4144 .36784 Mdot
.48669 .7879 Mdot
.75689 .34099 Mdot
.55927 .49273 Mdot
.4254 .80297 Mdot
.5135 .30507 Mdot
.44744 .75307 Mdot
.49655 .75567 Mdot
.46132 .61499 Mdot
.37912 .58436 Mdot
.60446 .61108 Mdot
.4609 .41944 Mdot
.44941 .47919 Mdot
.80683 .60747 Mdot
.49511 .67877 Mdot
.59587 .36116 Mdot
.60661 .22582 Mdot
.52773 .3056 Mdot
.40199 .84361 Mdot
.21568 .44312 Mdot
.65454 .30184 Mdot
.35283 .64193 Mdot
.2821 .46332 Mdot
.84416 .54921 Mdot
.77432 .57132 Mdot
.52865 .60247 Mdot
.49742 .3193 Mdot
.53873 .36322 Mdot
.34088 .64088 Mdot
.3178 .33363 Mdot
.71446 .33837 Mdot
.38707 .1996 Mdot
.5099 .76752 Mdot
.51987 .34628 Mdot
.41327 .65052 Mdot
.73048 .58878 Mdot
.2737 .76047 Mdot
.38448 .57135 Mdot
.75328 .7418 Mdot
.62931 .59925 Mdot
.68835 .75674 Mdot
.16901 .57012 Mdot
.46059 .31465 Mdot
.43602 .55945 Mdot
.31087 .42698 Mdot
.66791 .5724 Mdot
.55342 .50316 Mdot
.54255 .31511 Mdot
.49045 .76974 Mdot
.51647 .69002 Mdot
.69981 .70272 Mdot
.3519 .41905 Mdot
.50787 .19295 Mdot
.35293 .23319 Mdot
.57442 .36853 Mdot
.48629 .60428 Mdot
.36309 .74843 Mdot
.52649 .43964 Mdot
.49172 .51686 Mdot
.50473 .81376 Mdot
.77899 .37773 Mdot
.52249 .34993 Mdot
.76104 .69094 Mdot
.54399 .73621 Mdot
.20836 .67987 Mdot
.7245 .58179 Mdot
.50028 .50834 Mdot
.53061 .43862 Mdot
.36257 .30017 Mdot
.69476 .3174 Mdot
.24839 .65689 Mdot
.70734 .67075 Mdot
.50348 .3879 Mdot
.61729 .69624 Mdot
.55978 .53792 Mdot
.25463 .50516 Mdot
.31609 .258 Mdot
.85539 .4435 Mdot
.66772 .41424 Mdot
.44444 .32019 Mdot
.50256 .32505 Mdot
.38877 .20473 Mdot
.58379 .3794 Mdot
.38735 .69117 Mdot
.78113 .39332 Mdot
.24783 .62057 Mdot
.2364 .71691 Mdot
.21969 .64045 Mdot
.52162 .53071 Mdot
.27893 .58929 Mdot
.73446 .6156 Mdot
.7316 .57682 Mdot
.47122 .49405 Mdot
.66754 .57072 Mdot
.58342 .44551 Mdot
.51585 .24745 Mdot
.33743 .28233 Mdot
.68063 .46797 Mdot
.3005 .76434 Mdot
.20591 .67185 Mdot
.40539 .82618 Mdot
.32671 .54097 Mdot
.59531 .3167 Mdot
.65745 .80151 Mdot
.67418 .28392 Mdot
.23429 .67479 Mdot
.66137 .43277 Mdot
.33091 .20176 Mdot
.63059 .79596 Mdot
.24988 .56988 Mdot
.51838 .20727 Mdot
.31219 .31706 Mdot
.17447 .56799 Mdot
.38507 .17784 Mdot
.61537 .64107 Mdot
.16215 .54788 Mdot
.81449 .68774 Mdot
.68415 .43831 Mdot
.41016 .36374 Mdot
.62974 .37324 Mdot
.72847 .61444 Mdot
.3871 .19296 Mdot
.59471 .56505 Mdot
.33857 .5614 Mdot
.44946 .64053 Mdot
.65728 .67986 Mdot
.67398 .61124 Mdot
.39861 .1867 Mdot
.57799 .74519 Mdot
.56846 .7221 Mdot
.40576 .75391 Mdot
.59537 .80357 Mdot
.70643 .32536 Mdot
.586 .47398 Mdot
.59613 .2947 Mdot
.53872 .69379 Mdot
.59075 .64581 Mdot
.59266 .51 Mdot
.41975 .54125 Mdot
.53027 .46978 Mdot
.47731 .86308 Mdot
.38929 .71421 Mdot
.33525 .69016 Mdot
.50747 .32761 Mdot
.37781 .32663 Mdot
.38218 .77668 Mdot
.41613 .28348 Mdot
.42688 .17611 Mdot
.80027 .422 Mdot
.37394 .80301 Mdot
.42284 .33672 Mdot
.61744 .66622 Mdot
.82068 .57259 Mdot
.39734 .46884 Mdot
.76046 .48411 Mdot
.55475 .81637 Mdot
.40638 .29733 Mdot
.56047 .28779 Mdot
.23301 .55579 Mdot
.26753 .52026 Mdot
.39595 .30139 Mdot
.16498 .52551 Mdot
.41792 .7698 Mdot
.64996 .36277 Mdot
.46633 .82625 Mdot
.3019 .60815 Mdot
.63582 .67397 Mdot
.21789 .52797 Mdot
.37532 .19447 Mdot
.5305 .42843 Mdot
.27431 .74934 Mdot
.4668 .49936 Mdot
.63821 .75533 Mdot
.60392 .5259 Mdot
.73093 .32485 Mdot
.34703 .28805 Mdot
.2239 .56643 Mdot
.45488 .21976 Mdot
.59586 .33497 Mdot
.35395 .24713 Mdot
.33294 .46102 Mdot
.63973 .73889 Mdot
.57967 .63182 Mdot
.61672 .34365 Mdot
.55955 .65262 Mdot
.30754 .36776 Mdot
.61815 .59342 Mdot
.67408 .73708 Mdot
.27268 .63104 Mdot
.75193 .48518 Mdot
.70744 .45671 Mdot
.49154 .80985 Mdot
.28048 .66093 Mdot
.32165 .27828 Mdot
.70293 .45987 Mdot
.35041 .35403 Mdot
.64607 .24704 Mdot
.42512 .26045 Mdot
.57507 .51888 Mdot
.38877 .68902 Mdot
.5586 .2968 Mdot
.46424 .81356 Mdot
.59829 .28255 Mdot
.60112 .77356 Mdot
.47681 .44626 Mdot
.35587 .75385 Mdot
.49407 .56005 Mdot
.17148 .57176 Mdot
.30978 .31598 Mdot
.68126 .68469 Mdot
.38598 .40009 Mdot
.45289 .4447 Mdot
.45708 .28063 Mdot
.269 .72364 Mdot
.50634 .2314 Mdot
.75295 .58266 Mdot
.43735 .32335 Mdot
.78648 .45825 Mdot
.15131 .51795 Mdot
.67026 .70333 Mdot
.47184 .49222 Mdot
.69773 .62008 Mdot
.33663 .35865 Mdot
.28291 .33654 Mdot
.40819 .69446 Mdot
.69378 .30476 Mdot
.34476 .676 Mdot
.43317 .59809 Mdot
.61644 .58924 Mdot
.79985 .38483 Mdot
.44782 .81926 Mdot
.53079 .25615 Mdot
.49151 .47277 Mdot
.47704 .7444 Mdot
.64749 .73827 Mdot
.59958 .14446 Mdot
.52124 .86221 Mdot
.60303 .52648 Mdot
.44748 .54102 Mdot
.69143 .70557 Mdot
.31425 .6095 Mdot
.72225 .35061 Mdot
.48587 .81096 Mdot
.40356 .45241 Mdot
.43979 .72069 Mdot
.27824 .31649 Mdot
.35109 .3031 Mdot
.62418 .77228 Mdot
.41947 .46825 Mdot
.42476 .85583 Mdot
.22167 .60699 Mdot
.35385 .28281 Mdot
.51783 .1138 Mdot
.35212 .26326 Mdot
.53307 .27873 Mdot
.3292 .72353 Mdot
.43508 .84416 Mdot
.43704 .54383 Mdot
.42865 .73913 Mdot
.71399 .46027 Mdot
.69155 .67971 Mdot
.5898 .6949 Mdot
.41262 .24064 Mdot
.37119 .23972 Mdot
.3979 .17086 Mdot
.28298 .46161 Mdot
.81309 .6083 Mdot
.68398 .32869 Mdot
.48215 .83557 Mdot
.20954 .44986 Mdot
.84659 .4094 Mdot
.22766 .70193 Mdot
.61589 .71971 Mdot
.4193 .18362 Mdot
.32478 .71274 Mdot
.72441 .68726 Mdot
.76433 .33212 Mdot
.19562 .46706 Mdot
.7913 .40029 Mdot
.27105 .45278 Mdot
.44168 .2409 Mdot
.62178 .6957 Mdot
.78057 .4668 Mdot
.46269 .50061 Mdot
.53559 .82816 Mdot
.49416 .17405 Mdot
.70287 .65622 Mdot
.4524 .7251 Mdot
.72955 .69337 Mdot
.41827 .80571 Mdot
.29164 .70717 Mdot
.47488 .51527 Mdot
.81947 .67039 Mdot
.56912 .82817 Mdot
.42786 .27343 Mdot
.58022 .51241 Mdot
.21841 .70397 Mdot
.46734 .55557 Mdot
.71876 .47055 Mdot
.19003 .58004 Mdot
.57872 .68886 Mdot
.54404 .45305 Mdot
.5764 .55655 Mdot
.77592 .58729 Mdot
.59742 .25819 Mdot
.77805 .4732 Mdot
.48771 .73829 Mdot
.71219 .6547 Mdot
.49981 .17716 Mdot
.68321 .74625 Mdot
.73281 .55833 Mdot
.54046 .30516 Mdot
.45462 .85448 Mdot
.76119 .58335 Mdot
.56547 .59173 Mdot
.63794 .34166 Mdot
.51334 .2281 Mdot
.31742 .38648 Mdot
.58256 .46054 Mdot
.45328 .35916 Mdot
.64458 .67919 Mdot
.46906 .78698 Mdot
.75533 .50447 Mdot
.87862 .61462 Mdot
.16862 .576 Mdot
.55521 .3854 Mdot
.73938 .46565 Mdot
.45381 .62336 Mdot
.41314 .82607 Mdot
.28108 .43176 Mdot
.49501 .7531 Mdot
.58792 .20598 Mdot
.72365 .66965 Mdot
.67348 .49762 Mdot
.17715 .52354 Mdot
.24257 .71195 Mdot
.5196 .17215 Mdot
.26256 .73897 Mdot
.70208 .5545 Mdot
.68151 .57795 Mdot
.81342 .30862 Mdot
.3396 .78062 Mdot
.68677 .59236 Mdot
.54507 .21792 Mdot
.57019 .39453 Mdot
.60938 .57248 Mdot
.2783 .31901 Mdot
.67177 .64733 Mdot
.5843 .70463 Mdot
.31699 .78213 Mdot
.51277 .31235 Mdot
.42896 .54976 Mdot
.37834 .4769 Mdot
.45531 .5161 Mdot
.56849 .497 Mdot
.38973 .4106 Mdot
.5807 .71653 Mdot
.46115 .56212 Mdot
.34393 .3761 Mdot
.61067 .63747 Mdot
.20417 .37755 Mdot
.55422 .58918 Mdot
.52021 .53923 Mdot
.65038 .43719 Mdot
.652 .23779 Mdot
.58063 .7442 Mdot
.55626 .7547 Mdot
.16231 .54151 Mdot
.19488 .34207 Mdot
.40005 .61367 Mdot
.72244 .51099 Mdot
.56674 .41537 Mdot
.68564 .30349 Mdot
.64258 .35586 Mdot
.41724 .38786 Mdot
.29097 .33609 Mdot
.70478 .52161 Mdot
.72568 .60699 Mdot
.35755 .44635 Mdot
.51149 .87501 Mdot
.5828 .55123 Mdot
.67995 .35408 Mdot
.25769 .70016 Mdot
.45269 .753 Mdot
.54018 .49327 Mdot
.67274 .56692 Mdot
.49394 .30623 Mdot
.46417 .56601 Mdot
.74243 .5841 Mdot
.47031 .75912 Mdot
.42643 .82434 Mdot
.53438 .53046 Mdot
.66819 .34559 Mdot
.6306 .53389 Mdot
.55041 .66512 Mdot
.45872 .38234 Mdot
.78299 .63144 Mdot
.54969 .63173 Mdot
.2245 .67049 Mdot
.55704 .71904 Mdot
.58164 .69035 Mdot
.63397 .3073 Mdot
.52842 .84969 Mdot
.44799 .29119 Mdot
.65801 .32517 Mdot
.50282 .26561 Mdot
.23366 .51658 Mdot
.59382 .74058 Mdot
.31903 .63943 Mdot
.67666 .46617 Mdot
.57561 .39547 Mdot
.32619 .80064 Mdot
.77603 .56828 Mdot
.43418 .41367 Mdot
.25959 .59147 Mdot
.64784 .25244 Mdot
.46019 .51766 Mdot
.47782 .11571 Mdot
.29114 .41873 Mdot
.43075 .85721 Mdot
.44924 .77639 Mdot
.56313 .41804 Mdot
.37857 .30337 Mdot
.62209 .61458 Mdot
.32865 .60215 Mdot
.419 .82578 Mdot
.70895 .60532 Mdot
.42313 .2529 Mdot
.58786 .54808 Mdot
.47851 .33097 Mdot
.73038 .59957 Mdot
.28063 .5773 Mdot
.35522 .5542 Mdot
.52629 .2335 Mdot
.29524 .71827 Mdot
.46556 .56733 Mdot
.30734 .22746 Mdot
.57079 .82063 Mdot
.30248 .75145 Mdot
.27415 .61075 Mdot
.75579 .29114 Mdot
.50269 .30859 Mdot
.733 .57782 Mdot
.4012 .40066 Mdot
.75623 .60468 Mdot
.39989 .29749 Mdot
.47112 .78299 Mdot
.35338 .35003 Mdot
.51701 .45805 Mdot
.38275 .13311 Mdot
.61288 .71348 Mdot
.52706 .26436 Mdot
.3916 .27826 Mdot
.28757 .75004 Mdot
.46358 .68076 Mdot
.16976 .42212 Mdot
.20261 .48551 Mdot
.56505 .50514 Mdot
.74339 .32089 Mdot
.72361 .71765 Mdot
.29557 .53578 Mdot
.82919 .58419 Mdot
.2621 .64146 Mdot
.60739 .65419 Mdot
.22119 .55782 Mdot
.52515 .30951 Mdot
.5777 .39019 Mdot
.21903 .42429 Mdot
.23961 .33261 Mdot
.727 .50267 Mdot
.39385 .80447 Mdot
.83907 .49378 Mdot
.49959 .76304 Mdot
.37481 .81233 Mdot
.41716 .48739 Mdot
.51015 .36795 Mdot
.57398 .74319 Mdot
.52478 .73114 Mdot
.31018 .61263 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0Q?ooool2o`000<?ooooo000Looooo`03o`000?oooooooooo08Co
oooo0_l0000Aooooo`;o00002oooool2o`000:?ooooo000Looooo`03o`000?oooooooooo09;ooooo
0_l00003ooooo`;o00002oooool2o`000:?ooooo000Looooo`03o`000?oooooooooo08gooooo0_l0
0003ooooo`;o00006?ooool2o`0009_ooooo000Looooo`03o`000?oooooooooo08gooooo0_l0000L
ooooo`?o0000Voooool001cooooo00?o0000ooooooooool0Zoooool2o`0009cooooo000Looooo`03
o`000?oooooooooo07kooooo0_l000000ooooooo0000o`000036ooooo`007?ooool00ol0003ooooo
ooooo`1iooooo`;o00000oooool2o`000003ooooool0003o00000<Kooooo000Looooo`03o`000?oo
oooooooo07Wooooo0_l0003>ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0;oooooo0_l00028ooooo`007?ooool00ol0003oooooooooo`2oooooo`;o
0000R?ooool001cooooo00?o0000ooooooooool0Z_ooool4o`0009_ooooo000Looooo`;o0000Zooo
ool4o`0009_ooooo000Looooo`03o`000?oooooooooo0;?ooooo0_l0002Dooooo`007?ooool00ol0
003oooooooooo`2cooooo`;o0000U?ooool001cooooo00?o0000ooooooooool0I_ooool2o`0004oo
oooo0_l0002@ooooo`007?ooool00ol0003oooooooooo`1Vooooo`;o0000;?ooool2o`00027ooooo
0_l0000>ooooo`;o0000P?ooool001cooooo00?o0000ooooooooool0TOooool2o`000003ooooool0
003o0000037ooooo0_l00020ooooo`007?ooool00ol0003oooooooooo`1nooooo`;o00004Oooool2
o`0000Cooooo0_l0000<ooooo`;o0000X_ooool001cooooo00?o0000ooooooooool0O_ooool2o`00
00Oooooo0_l0000>ooooo`;o00001?ooool2o`0000Kooooo0_l0000Jooooo`;o00001oooool2o`00
07gooooo000Looooo`03o`000?oooooooooo07Wooooo0ol0000;ooooo`;o00005?ooool4o`0000;o
oooo0_l0000Looooo`Co00001Oooool2o`0007gooooo000Looooo`03o`000?oooooooooo07Wooooo
0ol00006ooooo`;o00000oooool4o`0000Cooooo0_l00008ooooo`;o00001?ooool2o`0000;ooooo
1?l00004ooooo`;o00005_ooool2o`0000Wooooo0_l000000ooooooo0000o`00001fooooo`007?oo
ool00ol0003oooooooooo`22ooooo`Co00000oooool2o`0000Cooooo0_l00006ooooo`Co000000Co
ooooo`000?l0003ooooo0_l00004ooooo`Co00000_ooool2o`00027ooooo0_l000000ooooooo0000
o`00001fooooo`007?ooool00ol0003oooooooooo`1`ooooo`;o00003?ooool2o`0000Cooooo0_l0
000Aooooo`;o00000oooool5o`0000Kooooo0_l0000Uooooo`;o0000NOooool001cooooo00?o0000
ooooooooool0L?ooool2o`0000cooooo0_l0000Eooooo`;o00001_ooool2o`00013ooooo0_l0000M
ooooo`;o0000NOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol0
0006ooooo`03o`000?oooooooooo07?ooooo0_l00005ooooo`;o00006Oooool2o`0000[ooooo0_l0
000<ooooo`;o00006_ooool2o`0007cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1cooooo`;o
000000?oooooo`000?l000000_ooool2o`0001Gooooo0_l0000>ooooo`;o00003_ooool3o`0001Oo
oooo0_l0001looooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0LOooool2o`0000?ooooo1_l0000Eooooo`;o0000
7_ooool3o`0000;ooooo0_l0002Aooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooooooo
o`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0001Xooooo`;o00001oooool2o`0000Gooooo1Ol0
000Vooooo`Co00003oooool4o`0008oooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`1Xooooo`;o00004Oooool3
o`0002Gooooo1?l0000Aooooo`Go00002oooool2o`0000Kooooo0_l00004ooooo`;o0000LOooool0
0003ooooool@413ooooo00;ooooo00?o410@ooooooooool03Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo07_ooooo0ol0000Booooo`;o00000_ooool2o`0000Wooooo0ol00002oooo
o`Go00004Oooool3o`0000Gooooo0_l00004ooooo`;o00001_ooool3o`0000?ooooo0_l0001aoooo
o`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_oo
ool00ol0003oooooooooo`2@ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000Kooooo
0ol00002ooooo`Go00006Oooool2o`0000gooooo1?l0001dooooo`0000Koooooonk^k_lb<S;o0000
oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Coooo
o`;o0000;_ooool2o`0000_ooooo0_l000000ooooooo0000o`000002ooooo`;o00003?ooool2o`00
013ooooo0_l0000:ooooo`;o00000_ooool2o`0000[ooooo0_l0001dooooo`007?ooool00ol0003o
ooooooooo`1Cooooo`;o00007oooool2o`0000Oooooo0_l00004ooooo`;o00002_ooool3o`0000So
oooo0_l00007ooooo`;o00002?ooool2o`0000Sooooo0_l0000:ooooo`Ko00003Oooool2o`00077o
oooo000Looooo`03o`000?oooooooooo077ooooo0_l000000ooooooo0000o`000002ooooo`;o0000
0oooool2o`0000Kooooo0_l00006ooooo`Go00002?ooool2o`0000Oooooo0ol00007ooooo`;o0000
2Oooool2o`0000_ooooo0_l0000?ooooo`;o0000LOooool001cooooo00?o0000ooooooooool0LOoo
ool2o`000003ooooool0003o000000;ooooo0_l00008ooooo`;o000000?oooooo`000?l000000_oo
ool3o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000kooooo0_l000000ooooooo0000
o`00000?ooooo`;o000000?oooooo`000?l000000_ooool2o`0001[ooooo0_l00005ooooo`;o0000
IOooool001cooooo00?o0000ooooooooool0H?ooool2o`0001;ooooo0_l0000<ooooo`;o00001Ooo
ool3o`0000Sooooo0_l0000Aooooo`;o00004_ooool2o`000003ooooool0003o000000?o00006?oo
ool2o`0000Gooooo0_l0001Uooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o00008?ooool2
o`0001;ooooo0_l0000;ooooo`;o00000_ooool3o`0000kooooo0_l00004ooooo`Go000000?ooooo
o`000?l000002?ooool2o`0007Wooooo000Looooo`03o`000?oooooooooo06gooooo1?l0000Coooo
o`?o00003oooool3o`0000Sooooo1?l00002ooooo`?o00002oooool5o`0000[ooooo0_l00008oooo
o`;o0000NOooool001cooooo00?o0000ooooooooool0KOooool4o`0001;ooooo1?l00003ooooo`;o
00002oooool2o`0000Sooooo0_l00004ooooo`Co00002_ooool5o`0000Wooooo0ol0000;ooooo`?o
00002oooool2o`0006Sooooo000Looooo`03o`000?oooooooooo04[ooooo0_l0000Yooooo`;o0000
3?ooool2o`0000Gooooo0_l0000Booooo`;o00000_ooool3o`0000Cooooo0_l0000;ooooo`Go0000
0_ooool2o`0000Cooooo0_l00004ooooo`;o00001Oooool4o`0000Kooooo0_l00003ooooo`;o0000
00?oooooo`000?l00000IOooool001cooooo00?o0000ooooooooool0B_ooool2o`0001_ooooo0_l0
000<ooooo`;o00002oooool3o`0000Oooooo0_l0000@ooooo`;o00000_ooool3o`0001Cooooo0_l0
0002ooooo`;o00002_ooool3o`0000Cooooo1?l00006ooooo`;o00001_ooool3o`0006Cooooo000L
ooooo`03o`000?oooooooooo06Gooooo1?l0000=ooooo`?o00002Oooool3o`0000Oooooo0_l0000>
ooooo`;o00005_ooool2o`0000Cooooo0_l0000>ooooo`;o00002?ooool2o`0000gooooo0_l00006
ooooo`;o0000G?ooool001cooooo00?o0000ooooooooool0IOooool2o`0000Sooooo0_l00004oooo
o`Co00004Oooool2o`00013ooooo0_l00006ooooo`;o00003_ooool2o`0000Cooooo0_l00007oooo
o`;o00002Oooool2o`0000Cooooo0_l0000Eooooo`;o0000G?ooool001cooooo0_l0001`ooooo`;o
00000oooool4o`0000gooooo0_l00003ooooo`;o00006?ooool2o`00017ooooo0_l00004ooooo`;o
00001?ooool2o`0000Kooooo0_l000000ooooooo0000o`00000Eooooo`;o0000H_ooool001cooooo
00?o0000ooooooooool0Loooool5o`0000gooooo1?l000000ooooooo0000o`00000Xooooo`;o0000
00?oooooo`000?l000000oooool3o`000003ooooool0003o000000Wooooo0_l00002ooooo`;o0000
5?ooool2o`0006;ooooo000Looooo`03o`000?oooooooooo06?ooooo0_l0000>ooooo`;o00004?oo
ool6o`0000Cooooo1?l0000;ooooo`;o00002Oooool2o`0000Wooooo0_l00006ooooo`Ko00001ooo
ool2o`0000?ooooo0ol0000Gooooo`;o0000Goooool001cooooo00?o0000ooooooooool0A?ooool2
o`0001gooooo0_l00006ooooo`Co00001?ooool3o`0000Wooooo0_l00005ooooo`;o000000Cooooo
o`000?l0003o00000oooool4o`0000[ooooo0ol00008ooooo`?o00004oooool2o`0000Wooooo0_l0
0003ooooo`;o00006?ooool2o`0005oooooo000Looooo`03o`000?oooooooooo04Cooooo0_l0000U
ooooo`Ko00000_ooool3o`0000Wooooo0ol00003ooooo`?o00000_ooool2o`0000gooooo0_l00002
ooooo`?o00001Oooool5o`0000Wooooo0_l00002ooooo`;o00004?ooool2o`0000Oooooo0_l0001e
ooooo`007?ooool00ol0003oooooooooo`1/ooooo`Go00000_ooool2o`0000_ooooo0_l00002oooo
o`?o00000oooool2o`0000[ooooo0_l000000ooooooo0000o`000005ooooo`;o00000oooool4o`00
00[ooooo0_l00002ooooo`Ko00002oooool2o`000003ooooool0003o000000Gooooo0_l00002oooo
o`;o0000LOooool001cooooo00?o0000ooooooooool0HOooool2o`0000Wooooo1?l00005ooooo`;o
00003Oooool2o`0000?ooooo0_l0000;ooooo`;o00002?ooool2o`0000kooooo0_l00007ooooo`Co
00002oooool2o`000003ooooool0003o000000Gooooo0_l00002ooooo`;o00006?ooool2o`0005Oo
oooo000Looooo`03o`000?oooooooooo067ooooo0_l00005ooooo`;o00002oooool2o`0000Gooooo
0_l00009ooooo`Co00002oooool2o`0001Sooooo0_l0000Pooooo`;o00002?ooool2o`0001;ooooo
0_l0001Gooooo`007?ooool00ol0003oooooooooo`1Xooooo`;o00004_ooool2o`0000Wooooo0_l0
0004ooooo`;o00001oooool2o`0001Kooooo0_l0000Gooooo`;o00004oooool4o`0006Wooooo000L
ooooo`03o`000?oooooooooo03gooooo0_l0000Vooooo`;o000000?oooooo`000?l000004Oooool2
o`000003ooooool0003o000000;ooooo0_l00009ooooo`;o00001oooool4o`0000Wooooo0_l00003
ooooo`?o00000oooool2o`00017ooooo0_l00003ooooo`?o00005Oooool2o`0006Wooooo000Loooo
o`03o`000?oooooooooo03gooooo0_l0000Nooooo`;o00001_ooool2o`000003ooooool0003o0000
00?o00000_ooool2o`0000[ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00001Oooool2
o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`?o000000?oooooo`000?l000000oooool2
o`000003ooooool0003o000000?ooooo1ol0000>ooooo`Ko00000_ooool3o`0000Wooooo0_l00006
ooooo`;o00000_ooool6o`0006Kooooo000Looooo`03o`000?oooooooooo05cooooo0ol0000;oooo
o`?o00000_ooool2o`0000gooooo0ol00002ooooo`;o00001?ooool2o`0000?ooooo0_l000000ooo
oooo0000o`000002o`0000Kooooo0_l00003ooooo`?o00000_ooool2o`0000?ooooo1Ol00004oooo
o`;o00001_ooool6o`0000Cooooo0_l0000:ooooo`Co00000_ooool4o`0000;ooooo1_l0001Voooo
o`007?ooool00ol0003oooooooooo`1Looooo`;o00003?ooool2o`000003ooooool0003o000001;o
oooo1Ol0000=ooooo`;o00003?ooool2o`0000;ooooo0_l00004ooooo`;o00001Oooool3o`0000Co
oooo1Ol0000?ooooo`Co000000Coooooo`000?l0003o00000_ooool2o`0000Wooooo0_l0001Uoooo
o`007?ooool00ol0003oooooooooo`1]ooooo`;o00001_ooool2o`0000[ooooo0_l000000ooooooo
0000o`000006ooooo`Go00001_ooool2o`0000Wooooo1ol00002ooooo`co00000_ooool5o`0000ko
oooo1Ol000000ooooooo0000o`00000>ooooo`;o00003_ooool4o`0005?ooooo000Looooo`03o`00
0?oooooooooo05Kooooo0_l0000=ooooo`?o00003Oooool2o`0000Wooooo0_l00007ooooo`;o0000
00?oooooo`000?l000001Ol00002ooooo`Go00002?ooool7o`0000Cooooo3Ol00002ooooo`Co0000
00?oooooo`000?l000000ol00006ooooo`Co00000_ooool2o`0001kooooo1?l0001Cooooo`007?oo
ool00ol0003oooooooooo`1Fooooo`;o00003Oooool5o`0000Cooooo0_l00005ooooo`;o00001ooo
ool4o`0000Oooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool7o`000003ooooool0
003o000000;ooooo0ol000000ooooooo0000o`000005o`000003ooooool0003o000000_o00000_oo
ool4o`000003ooooool0003o000000?o00005?ooool2o`0000oooooo0_l00005ooooo`;o0000EOoo
ool001cooooo0_l0000gooooo`;o00005Oooool3o`0000?ooooo0_l0000Aooooo`Co00001?ooool2
o`0000;ooooo0_l000000ooooooo0000o`000006ooooo`Go00006?ooool5o`0000;ooooo0_l00002
ooooo`_o000000?oooooo`000?l000001Ol00002ooooo`?o000000Coooooo`000?l0003o00006Ooo
ool2o`0000oooooo0_l00005ooooo`;o00001oooool2o`0004cooooo000Looooo`03o`000?oooooo
oooo03Kooooo0_l0000Eooooo`?o00000oooool2o`00017ooooo0_l00006ooooo`;o00000_ooool2
o`0000?ooooo0_l00004ooooo`;o00001_ooool2o`0000Sooooo0_l00006ooooo`;o00000_ooool4
o`0000Wooooo5_l000000ooooooo0000o`00000;ooooo`;o00000_ooool8o`0000?ooooo0_l00000
0ooooooo0000o`00000Kooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0C_ooool2o`00
01Wooooo0_l00003ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Cooooo0_l00006oooo
o`;o00002?ooool2o`000004ooooool0003o0000ooooo`Co00000_ooool4o`0000Cooooo0_l00003
oooooaKo00003?ooool>o`000003ooooool0003o000000;o000000?oooooo`000?l000003Oooool2
o`0005[ooooo000Looooo`03o`000?oooooooooo04kooooo0_l00005ooooo`;o00004_ooool2o`00
00Gooooo0ol00004ooooo`;o00001?ooool2o`0000Kooooo0_l0000;ooooo`;o000000?oooooo`00
0?l000000_l00002ooooo`Co000000?oooooo`000?l000007Ol00002ooooo`;o00001oooool2o`00
0004ooooool0003o0000o`0000;ooooo1_l000001?oooooo0000o`000?l0000@ooooo`?o00005Ooo
ool2o`0004?ooooo000Looooo`03o`000?oooooooooo057ooooo0_l00002ooooo`;o00006Oooool2
o`0000Gooooo1?l00008ooooo`Co00003_ooool2o`0000Cooooo0_l00003oooooaoo000000Cooooo
o`000?l0003o00001oooool2o`000003ooooool0003o000000?ooooo1?l00004ooooo`;o00003?oo
ool2o`0000;ooooo0_l0000Fooooo`;o0000@oooool001cooooo00?o0000ooooooooool0DOooool2
o`000004ooooool0003o0000ooooo`?o00001oooool3o`0001Gooooo0_l00008ooooo`Co00002ooo
ool2o`000003ooooool0003o000000;o000000?oooooo`000?l000002Ol000001?oooooo0000o`00
0?ooool5o`000003ooooool0003o0000017o00002?ooool2o`0000Kooooo1?l00006ooooo`;o0000
0oooool2o`0000Gooooo0_l0001Oooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00000_oo
ool2o`000004ooooool0003o0000o`0000;ooooo0_l000000ooooooo0000o`000003o`0001Gooooo
0_l00008ooooo`Co00002oooool7o`000003ooooool0003o000000Go00000_ooool2o`0000Gooooo
1Ol00002oooooa7o00001_ooool2o`0000?ooooo0_l0000=ooooo`Co000000?oooooo`000?l00000
5Oooool2o`0004oooooo000Looooo`03o`000?oooooooooo04kooooo1?l00005ooooo`;o00000ooo
ool2o`000003ooooool0003o000000cooooo0_l00002ooooo`;o00001?ooool4o`0000Sooooo1?l0
0006ooooo`;o00000_ooool4o`0000Wooooo0_l000000ooooooo0000o`000003oooooa;o000000?o
ooooo`000?l000001Ol00008ooooo`;o00000_ooool3o`0000[ooooo0_l00003ooooo`;o00001?oo
ool6o`0000Cooooo0_l00008ooooo`;o0000Coooool001cooooo00?o0000ooooooooool0B_ooool2
o`0000;ooooo0_l00007ooooo`;o00005?ooool2o`0000;ooooo0_l00004ooooo`Co00002Oooool3
o`0000?ooooo0_l000001Ooooooo0000o`000?l0003ooooo00?o00002ooooolRo`0000Wooooo1Ol0
0003ooooo`;o00001Oooool2o`0000Oooooo2_l00002ooooo`;o0000FOooool001cooooo00?o0000
ooooooooool0B_ooool2o`0000_ooooo0_l00002ooooo`Go00002Oooool2o`0000Sooooo0ol00000
0ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000001?ooool2o`000004ooooool0003o
0000ooooo`;o00000_ooool4o`0000gooooo8_l00004ooooo`;o000000?oooooo`000?l000001?l0
0004ooooo`;o00001_ooool2o`0000;ooooo0ol000000ooooooo0000o`000005ooooo`?o0000GOoo
ool001cooooo00?o0000ooooooooool0F?ooool:o`0000Oooooo0_l00008ooooo`?o000000?ooooo
o`000?l000000_ooool2o`000003ooooool0003o000000Oooooo1?l00005ooooo`Co00001?ooool2
o`000003ooooool0003o000000?ooooo8_l00003ooooo`;o000000?oooooo`000?l000002Oooool2
o`0000Gooooo0_l00002ooooo`Go00002?ooool2o`0000Oooooo0_l0001Cooooo`007?ooool00ol0
003oooooooooo`1:ooooo`;o00002_ooool=o`000004ooooool0003o0000o`0000cooooo0_l0000<
ooooo`;o00001_ooool2o`0000Cooooo1_l00003ooooo`Go00001?oooolQo`00017ooooo0_l0000<
ooooo`;o00002?ooool4o`0000Gooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`1:oooo
o`;o00002_oooolAo`000003ooooool0003o000000cooooo1?l00007ooooo`;o000000?oooooo`00
0?l000000_l00007ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo0_l00005oooo
o`;o000000?oooooo`000?l000007ol0000Oooooo`;o00000_ooool2o`0000?ooooo0_l00007oooo
o`;o00002?ooool2o`0004Oooooo000Looooo`03o`000?oooooooooo04cooooo0_l00005oooooa;o
00000oooool2o`0000cooooo1?l000000ooooooo0000o`000002o`0000Gooooo1?l00007ooooo`Co
00000oooool2o`0000kooooo7ol00003ooooo`Go00004Oooool2o`0000Cooooo0_l00002ooooo`;o
00001Oooool2o`000003ooooool0003o000000;ooooo0_l00008ooooo`;o0000Aoooool001cooooo
00?o0000ooooooooool0??ooool2o`0000_ooooo0_l000000ooooooo0000o`000005oooooa?o0000
1?ooool2o`0000oooooo1?l00008ooooo`;o00001_ooool4o`0000?ooooo0_l0000@ooooo`;o0000
00?oooooo`000?l000005Ol00003ooooo`;o000000?oooooo`000?l000000ol0000;ooooo`;o0000
1?ooool2o`0000oooooo0_l000000ooooooo0000o`00001Eooooo`007?ooool00ol0003ooooooooo
o`0Zooooo`;o00004?ooool2o`0000[ooooo0ol0000;oooooa3o00001?ooool2o`0001_ooooo0_l0
0005ooooo`Oo000000?oooooo`000?l000000_l0000;oooooago00000oooool4o`0000_ooooo0ol0
00000ooooooo0000o`00000Oooooo`;o0000C_ooool001cooooo0_l0000[ooooo`;o00006oooool3
o`0000cooooo4?l00009ooooo`;o00002?ooool2o`000003ooooool0003o0000013ooooo1ol00003
ooooo`;o00001oooool2o`0000;ooooo6Ol000000ooooooo0000o`000006ooooo`;o00002?ooool2
o`000004ooooool0003o0000o`0000cooooo0_l00002ooooo`;o00004?ooool2o`0004kooooo000L
ooooo`03o`000?oooooooooo04Oooooo0_l0000@ooooo`go00001_ooool5o`0000Sooooo0_l00000
0ooooooo0000o`00000Dooooo`?o00000oooool2o`0000Oooooo3Ol000000ooooooo0000o`00000<
o`0000;ooooo0_l0000@ooooo`;o00004?ooool2o`0000;ooooo0_l00003ooooo`;o00002?ooool2
o`0000;ooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`17ooooo`;o00003?ooool2o`00
00;ooooo1ol000000ooooooo0000o`000003o`0000Kooooo1_l00009ooooo`;o00001_ooool2o`00
00Gooooo0_l00003ooooo`;o000000Coooooo`000?l0003o00002_ooool2o`0000;ooooo6_l00000
0ooooooo0000o`00000=ooooo`;o00002_ooool2o`00017ooooo0_l00008ooooo`;o00000_ooool2
o`0004gooooo000Looooo`03o`000?oooooooooo04Oooooo0_l00008ooooo`;o00000_ooool2o`00
00;ooooo3_l00003ooooo`Co00000_ooool2o`0000Wooooo0_l00006ooooo`;o00001Oooool2o`00
00?ooooo0_l000001?oooooo0000o`000?l00007ooooo`;o000000?oooooo`000?l000000_ooool2
o`0000;ooooo0_l000000ooooooo0000o`00000<o`0000;ooooo1_l0000=ooooo`;o00002_ooool2
o`0001_ooooo0_l0000@ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0A_ooool2o`00
00Oooooo1?l00005ooooo`oo00000oooool4o`0000_ooooo0_l00003ooooo`;o000000?oooooo`00
0?l000001oooool2o`0000?ooooo0_l00003ooooo`;o00001_ooool2o`0000Sooooo0_l000000ooo
oooo0000o`00000Eo`0000oooooo0_l0000Oooooo`;o00001?ooool2o`00013ooooo1?l0000moooo
o`007?ooool00ol0003oooooooooo`16ooooo`;o00001_ooool5o`0000Gooooo0ol000000ooooooo
0000o`000007o`0000Cooooo1?l0000<ooooo`;o000000?oooooo`000?l000000_l000001?oooooo
0000o`000?ooool2o`0000kooooo0_l000001?oooooo0000o`000?l00008ooooo`;o00000_oooolG
o`000003ooooool0003o000000oooooo0_l0000Oooooo`;o00001_ooool2o`00013ooooo0_l0000m
ooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00002Oooool2o`0000kooooo1_l00005oooo
o`;o00000_ooool2o`0000gooooo0_l00003ooooo`Go00001_ooool2o`000003ooooool0003o0000
00;o000000Coooooo`000?l0003ooooo0ol00008ooooo`;o00000ooooolFo`0003_ooooo0_l00003
ooooo`;o00003?ooool2o`0003cooooo000Looooo`03o`000?oooooooooo04?ooooo0_l0000Coooo
o`;o00001_ooool4o`0000Wooooo0_l00009ooooo`;o00002Oooool2o`0000Oooooo0_l000000ooo
oooo0000o`000002o`000003ooooool0003o000000Cooooo0_l00006ooooo`;o000000?oooooo`00
0?l000000oooool?o`000003ooooool0003o000000Co00001_ooool2o`0003Gooooo0_l0000<oooo
o`;o0000??ooool001cooooo00?o0000ooooooooool09?ooool2o`0001Oooooo0_l0000;ooooo`;o
00003?ooool2o`000004ooooool0003o0000o`0001[ooooo0_l00007ooooo`;o00002Oooool2o`00
0003ooooool0003o000000Wooooo0_l00009ooooo`;o00000oooool4o`0000;ooooo1Ol00005oooo
o`Oo00001Oooool2o`000003ooooool0003o0000037ooooo0_l0000@ooooo`;o0000>Oooool001co
oooo00?o0000ooooooooool09?ooool2o`0001Oooooo1?l00009ooooo`Co00003Oooool3o`0000ko
oooo1Ol0000@ooooo`;o00000oooool2o`0000Gooooo1?l0000:ooooo`?o00003_ooool9o`0000Go
oooo1?l000000ooooooo0000o`000002ooooo`;o00001?ooool2o`0002kooooo0_l000000ooooooo
0000o`00000@ooooo`;o0000>Oooool001cooooo00?o0000ooooooooool0?_ooool3o`0000_ooooo
0_l0000Fooooo`;o00001_ooool6o`0001Cooooo0_l00005ooooo`;o00003?ooool3o`0000_ooooo
0ol000000ooooooo0000o`000006o`0000Gooooo0_l00007ooooo`Co00004oooool2o`0001gooooo
0_l0001>ooooo`007?ooool00ol0003oooooooooo`0nooooo`?o00008oooool2o`0000[ooooo0_l0
0009ooooo`;o00003Oooool2o`000003ooooool0003o000000;ooooo0ol0000Cooooo`Go00000ooo
ool6o`0000Gooooo0_l00009ooooo`;o00001?ooool2o`0000Oooooo0_l00004ooooo`;o00007?oo
ool2o`0000?ooooo0_l000000ooooooo0000o`000017ooooo`007?ooool00ol0003oooooooooo`11
ooooo`;o00005?ooool2o`0000[ooooo0_l00003ooooo`;o00003Oooool2o`0000;ooooo0_l00007
ooooo`Co00000_ooool2o`000005ooooool0003o0000o`000?ooool01?l0000;ooooo`;o00000ooo
ool4o`0000;ooooo0_l00002ooooo`Co00000_ooool2o`0000?ooooo0ol0000:ooooo`;o00000_oo
ool2o`0000Oooooo0_l0000Rooooo`;o00000oooool2o`000003ooooool0003o000004Oooooo000L
ooooo`03o`000?oooooooooo047ooooo1?l0000=ooooo`;o00000oooool2o`0000[ooooo0_l00003
ooooo`;o00003Oooool3o`0000[ooooo1?l00006ooooo`;o00000_ooool5o`0000Sooooo0ol00000
0ooooooo0000o`000002o`0000;ooooo1?l00003ooooo`?o000000Goooooo`000?l0003o0000oooo
o`05o`0000[ooooo0_l00002ooooo`;o00003_ooool2o`0006cooooo00001_ooooook^k^oc8b<_l0
003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003ooooo
ooooo`13ooooo`;o00003Oooool2o`0002?ooooo0ol00007ooooo`;o00004_ooool2o`0000Sooooo
0ol000000ooooooo0000o`000003o`000003ooooool0003o000000Wooooo1_l0000Qooooo`;o0000
7Oooool2o`0000;ooooo0_l000000ooooooo0000o`000016ooooo`0000KoooooogMgMonHV9Sooooo
oiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo037o
oooo0_l0000Jooooo`;o00006_ooool2o`0000Sooooo0_l00003ooooo`;o00000_ooool2o`0000?o
oooo0_l00002ooooo`;o00007_ooool3o`000004ooooool0003o0000o`0000Wooooo1?l00011oooo
o`;o00000_ooool2o`000003ooooool0003o000004Kooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00Wooooo1Ol00006ooooo`03o`000?oooooooooo037ooooo0_l0000@ooooo`;o
00002?ooool2o`0001[ooooo0_l00008ooooo`;o00000_ooool7o`0000Oooooo1?l0000Eooooo`;o
00001_ooool2o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`Go00000_ooool2o`0000oo
oooo0_l0000/ooooo`;o0000COooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
2Oooool01?m4A4CogMgMooooool00007ooooo`?o0000@oooool2o`0000Sooooo0_l0000Kooooo`;o
00001oooool2o`0000;ooooo1_l00002ooooo`;o00001_ooool2o`0001Gooooo0_l0000=ooooo`;o
00001Oooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o00002Oooool2o`0000?o
oooo0_l0000Zooooo`;o0000B_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
2Oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo04gooooo0_l0000Kooooo`;o
00001Oooool7o`0000Gooooo1ol00009ooooo`;o00000oooool4o`000003ooooool0003o000000Go
oooo1?l0000Dooooo`?o00001oooool3o`0000kooooo1?l0000Xooooo`;o00000oooool2o`0004Go
oooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oMgMgolc<c?l00000
1oooool00ol0003oooooooooo`1aoooooa?o00002Oooool2o`0000?ooooo1?l000000ooooooo0000
o`000007ooooo`;o00001_ooool2o`0000cooooo0_l00002ooooo`;o00001?ooool2o`00017ooooo
1?l00006ooooo`;o00008oooool2o`0000_ooooo0_l0000hooooo`0000KoooooogMgMonHV9Sooooo
oiRHV?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool07oooool2o`0002[o
oooo0_l00008ooooo`;o00004Oooool2o`0000Oooooo4ol00006ooooo`?o00006oooool2o`00013o
oooo0_l0000Eooooo`;o00000_ooool2o`0000Kooooo0_l0000`ooooo`;o0000>?ooool00006oooo
ooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo
01oooooo0_l0000Eooooo`;o00001?ooool2o`0000gooooo0_l00008ooooo`;o00004Oooool2o`00
00Oooooo5?l00004ooooo`Co00006?ooool2o`0000gooooo0_l00008ooooo`;o00004Oooool2o`00
00;ooooo0_l0001booooo`007?ooool00ol0003oooooooooo`0fooooo`;o00001?ooool2o`0001go
oooo1_l0000:ooooo`;o000000?oooooo`000?l000006?l000000ooooooo0000o`000008ooooo`;o
00004?ooool2o`0000Gooooo0_l000000ooooooo0000o`000002ooooo`?o00002?ooool2o`000003
ooooool0003o000001;ooooo0_l00007ooooo`;o00008Oooool2o`0004Kooooo000Looooo`03o`00
0?oooooooooo04;ooooo0_l0000<ooooo`;o00002Oooool6o`0000[ooooo0_l000000ooooooo0000
o`000007o`000003ooooool0003o000000ko00002_ooool3o`0001Oooooo0_l000000ooooooo0000
o`000002ooooo`Co00002_ooool2o`0001Wooooo1?l0000Eooooo`;o00002_ooool2o`0004Kooooo
000Looooo`03o`000?oooooooooo01kooooo0_l0000Cooooo`;o00003Oooool3o`0000_ooooo0_l0
000:ooooo`;o00002oooool4o`0000;ooooo2?l000000ooooooo0000o`00000=o`0000Cooooo0_l0
0005ooooo`?o00005oooool2o`0000Oooooo0_l00005ooooo`;o00007_ooool2o`0001Oooooo0_l0
0009ooooo`;o00003oooool2o`0003Kooooo000Looooo`03o`000?oooooooooo01kooooo0_l0000C
ooooo`;o000000?oooooo`000?l000002oooool2o`0001Oooooo0_l00003ooooo`;o00001_ooool2
o`0000?ooooo2Ol000000ooooooo0000o`000003o`000003ooooool0003o000000Go00001_ooool2
o`0000Kooooo0_l0000Cooooo`;o00000_ooool2o`0000cooooo1?l00005ooooo`;o00000_ooool4
o`0002_ooooo0_l00008ooooo`?o00003_ooool2o`0003Kooooo000Looooo`03o`000?oooooooooo
03;ooooo0ol000000ooooooo0000o`000002ooooo`;o00009Oooool2o`0000_ooooo7Ol00008oooo
o`;o00004oooool3o`0000oooooo0_l00007ooooo`;o00000_ooool4o`0000Gooooo0_l0000Toooo
o`;o00002Oooool2o`0004Kooooo000Looooo`03o`000?oooooooooo03;ooooo0_l00006ooooo`;o
00006oooool3o`0000Sooooo0_l0000:oooooago000000?oooooo`000?l000006oooool3o`0000Co
oooo0_l00003ooooo`;o00000_ooool2o`0000Wooooo0_l00002ooooo`Ko000000Goooooo`000?l0
003o0000ooooo`02o`0002kooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o
00002_ooool4o`0000Oooooo0_l0000;oooooaSo00001Oooool2o`0001;ooooo0_l00008ooooo`;o
00001?ooool3o`000004ooooool0003o0000o`0000;ooooo0_l00009ooooo`;o000000?oooooo`00
0?l000001Ol000000ooooooo0000o`000002ooooo`;o0000;_ooool2o`0000gooooo0_l00003oooo
o`;o0000<?ooool001cooooo00?o0000ooooooooool07Oooool2o`0002cooooo0_l0000<ooooo`;o
00004_oooolLo`0000[ooooo0_l00007ooooo`;o00000_ooool2o`0000Cooooo1Ol00005ooooo`?o
000000?oooooo`000?l000003_ooool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo
0000o`000009ooooo`;o00000oooool2o`0000oooooo0_l00009ooooo`Co00000oooool2o`0000ko
oooo0_l00003ooooo`;o0000<?ooool001cooooo00?o0000ooooooooool07Oooool2o`0001Cooooo
0_l0000=ooooo`;o00001oooool2o`00023ooooo0_l00002oooooaSo00002_ooool3o`0000Kooooo
0_l00008ooooo`Go00006Oooool2o`0000Kooooo0_l0000<ooooo`;o00000oooool2o`0000oooooo
0_l00009ooooo`Co00000oooool2o`0004Gooooo000Looooo`03o`000?oooooooooo037ooooo1?l0
000=ooooo`;o0000:_oooolIo`0000?ooooo0_l00003ooooo`;o00000oooool2o`000003ooooool0
003o000000cooooo0_l00005ooooo`;o00003?ooool2o`0000Gooooo0_l00004ooooo`;o0000<_oo
ool2o`0000Gooooo0_l0000>ooooo`;o0000=Oooool001cooooo00?o0000ooooooooool0<Oooool2
o`0003Kooooo0_l00003oooooaWo00000oooool2o`0000?ooooo0ol00004ooooo`?o00003?ooool2
o`0000?ooooo1?l00004ooooo`;o00001_ooool2o`0000Gooooo0_l00004ooooo`;o00003Oooool2
o`0002[ooooo0_l0000>ooooo`;o0000=Oooool001cooooo0_l00011ooooo`;o00002?ooool2o`00
00?ooooo0_l0000Dooooo`;o00000_ooool2o`0000Kooooo5Ol0000:ooooo`;o00001?ooool2o`00
01;ooooo1?l00004ooooo`;o00000_ooool4o`0000Kooooo0_l0000Dooooo`;o00007Oooool2o`00
00[ooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`0mooooo`;o000000?oooooo`000?l0
00002?ooool2o`0000?ooooo0ol00002ooooo`;o00003oooool2o`0000;ooooo0_l00006oooooaGo
00008oooool2o`000004ooooool0003o0000o`0000Oooooo1?l00006ooooo`;o00001Oooool2o`00
01gooooo0_l0000=ooooo`;o00002_ooool2o`000003ooooool0003o000004?ooooo000Looooo`03
o`000?oooooooooo01cooooo0_l0000Oooooo`;o000000?oooooo`000?l000001oooool2o`0000Go
oooo0_l00002ooooo`;o00004Oooool2o`0000[ooooo4ol0000=ooooo`;o00001_ooool2o`0000Oo
oooo0_l00003ooooo`;o00000_ooool2o`0000Cooooo0_l00004ooooo`;o00002?ooool6o`0000Co
oooo0_l00004ooooo`;o00002_ooool2o`000003ooooool0003o000000;ooooo0_l00008ooooo`?o
00000_ooool2o`0000Gooooo0_l00006ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0
7?ooool2o`0001gooooo0_l00002ooooo`;o00002?ooool4o`0000_ooooo0_l0000:ooooo`;o0000
00Coooooo`000?l0003o00002_oooolBo`0000gooooo0_l00006ooooo`Co00001Oooool2o`0000go
oooo0_l00004ooooo`;o00002?ooool=o`0000?ooooo0ol00009ooooo`Oo00000oooool2o`0000Go
oooo0ol00004ooooo`?o00000_ooool4o`0000;ooooo0_l00015ooooo`007?ooool00ol0003ooooo
ooooo`0kooooo`;o00000_ooool2o`0000[ooooo0_l0000;ooooo`;o00002_ooool2o`000004oooo
ool0003o0000o`0000[ooooo4_l0000Gooooo`;o00006?ooool4o`0000gooooo2Ol00003ooooo`;o
00002?ooool2o`000003ooooool0003o000000?o00000oooool2o`0000_ooooo1?l00003ooooo`?o
00000_ooool2o`0004Gooooo000Looooo`03o`000?oooooooooo03cooooo1Ol0000Gooooo`;o0000
6Oooool<o`0000;ooooo1?l000000ooooooo0000o`00000;ooooo`?o00002Oooool2o`0001Kooooo
1?l000001?oooooo0000o`000?l00004ooooo`?o00001Oooool3o`000003ooooool0003o000000Go
00000_ooool3o`0000?ooooo0_l000000ooooooo0000o`000002o`0000Oooooo0_l00008ooooo`;o
00000_ooool2o`0004gooooo000Looooo`03o`000?oooooooooo01[ooooo0_l0000Eooooo`;o0000
2Oooool5o`0001Wooooo0_l0000@ooooo`;o00000oooool9o`000003ooooool0003o000000?o0000
00?oooooo`000?l000001Ol0000;ooooo`?o00002Oooool2o`0000Cooooo0_l000000ooooooo0000
o`000007ooooo`;o00001?ooool4o`000004ooooool0003o0000o`0000Cooooo0ol000000ooooooo
0000o`000005o`0000;ooooo1_l000000ooooooo0000o`000002o`0000Kooooo0_l00003ooooo`;o
00001?ooool2o`0000Wooooo0_l000001?oooooo0000o`000?l00008ooooo`;o0000@_ooool001co
oooo00?o0000ooooooooool06_ooool2o`0001Gooooo0_l000000ooooooo0000o`000006ooooo`;o
00003Oooool2o`0000gooooo0_l0000@ooooo`;o00000oooool4o`000003ooooool0003o000000;o
000000?oooooo`000?l000002ol00006ooooo`;o00000_ooool4o`0000Kooooo1?l00005ooooo`;o
000000Coooooo`000?l0003ooooo0_l00004ooooo`;o00001?ooool2o`0000;ooooo0ol00002oooo
o`ko00000_ooool6o`000003ooooool0003o000000gooooo0_l0000<ooooo`;o000000?oooooo`00
0?l000001?l00008ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool06_ooool2o`0001So
oooo0_l00006ooooo`;o00003Oooool2o`0002Cooooo0_l00004ooooo`go00000_ooool2o`0000Ko
oooo0_l00002ooooo`?o000000?oooooo`000?l000001?ooool4o`0000Kooooo0_l00003ooooo`;o
00002oooool2o`000005ooooool0003o0000o`000?ooool03_l00007ooooo`?o00004?ooool2o`00
00Gooooo0_l00004ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o000000?oooooo`00
0?l000000oooool2o`0004;ooooo000Looooo`03o`000?oooooooooo01[ooooo0_l0000Fooooo`Co
00001Oooool2o`0002[ooooo0_l00008ooooo`Co00000_ooool8o`000003ooooool0003o000000;o
00002_ooool2o`0000?ooooo1Ol0000;ooooo`Go00002_ooool2o`0000Cooooo0ol00004ooooo`Co
00001?ooool4o`0000?ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00001oooool2o`00
00;ooooo0_l00002ooooo`;o00001Oooool2o`000003ooooool0003o000000Cooooo0_l00004oooo
o`;o000000Coooooo`000?l0003o00000_ooool2o`0004;ooooo000Looooo`03o`000?oooooooooo
03;ooooo0_l000000ooooooo0000o`000004ooooo`;o0000:_ooool2o`0000Kooooo0_l000001?oo
oooo0000o`000?l00003ooooo`co00002_ooool2o`0000?ooooo0ol00006ooooo`;o00000_ooool2
o`000003ooooool0003o000000;o00002oooool2o`000005ooooool0003o0000o`000?ooool00_l0
0004ooooo`Co000000Coooooo`000?l0003ooooo1Ol000000ooooooo0000o`000005o`0000;ooooo
0_l00003ooooo`;o00000_ooool2o`0000;ooooo1_l00003ooooo`;o00000_ooool5o`0000;ooooo
0_l00006ooooo`Co0000A_ooool001cooooo00?o0000ooooooooool0=Oooool2o`0000;ooooo0_l0
0003ooooo`;o00009oooool2o`0000Kooooo0_l00005ooooo`;o00000_ooool2o`0000?ooooo0ol0
000@ooooo`;o00000oooool2o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l0
0003ooooo`;o00002Oooool3o`0000?ooooo0_l000001Ooooooo0000o`000?l0003ooooo00Co0000
00?oooooo`000?l000002Ol00002ooooo`Wo00000_ooool2o`0000Cooooo0_l00005ooooo`;o0000
0_ooool2o`000003ooooool0003o000000;ooooo0_l00006ooooo`;o00001?ooool2o`0004;ooooo
000Looooo`03o`000?oooooooooo03Wooooo0_l00003ooooo`;o0000=_ooool4o`0000Sooooo1?l0
000<ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00001_ooool3o`0000Cooooo0_l0
0002ooooo`;o00001Oooool2o`0000Cooooo1_l000000ooooooo0000o`000009o`000003ooooool0
003o000000?o000000?oooooo`000?l000001_l00003ooooo`;o00002?ooool2o`0000Gooooo0_l0
00000ooooooo0000o`000002ooooo`;o00003?ooool2o`0004;ooooo000Looooo`03o`000?oooooo
oooo03Gooooo0_l0000@ooooo`;o00003_ooool2o`0001oooooo0_l00008ooooo`Co00003oooool8
o`0000Kooooo0ol00008ooooo`;o00001Oooool3o`0000Cooooo0ol000000ooooooo0000o`000002
o`000003ooooool0003o000000Go00000_ooool5o`0000;ooooo0_l00003ooooo`;o00003Oooool2
o`0002Oooooo0_l00002ooooo`;o0000<Oooool001cooooo00?o0000ooooooooool0<Oooool2o`00
00;ooooo0_l0000@ooooo`;o00003_ooool2o`0003cooooo0ol000000ooooooo0000o`000009oooo
o`;o00001_ooool3o`0000?ooooo0_l00002ooooo`?o000000?oooooo`000?l000000ol000000ooo
oooo0000o`00000Eo`000003ooooool0003o000000Co00004Oooool2o`0001Cooooo0_l00006oooo
o`;o00000oooool2o`0000;ooooo0_l0000aooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o
000000?oooooo`000?l000000oooool2o`0004;ooooo0_l0000>ooooo`?o00000_ooool2o`0000Co
oooo0_l0000=ooooo`;o00001_ooool3o`0000?ooooo0_l000000ooooooo0000o`000005o`000003
ooooool0003o000001_o000000?oooooo`000?l000001Ol0000;ooooo`Co00001_ooool2o`0000co
oooo0_l00006ooooo`;o0000>_ooool001cooooo0_l0000^ooooo`?o000000?oooooo`000?l00000
1Ol00004ooooo`;o00002Oooool2o`00013ooooo0_l0000Oooooo`;o00003_ooool7o`000003oooo
ool0003o000000Co00003_ooool2o`0000gooooo5Ol000000ooooooo0000o`00000Fo`0000[ooooo
0_l00003ooooo`;o00000oooool2o`0000cooooo0_l00006ooooo`;o00000_ooool2o`0003Kooooo
000Looooo`03o`000?oooooooooo02gooooo0_l00002ooooo`Ko00001Oooool2o`0000Wooooo0_l0
0007ooooo`;o00001?ooool2o`000003ooooool0003o000001?ooooo0_l0000Hooooo`;o000000?o
ooooo`000?l000000_l00002ooooo`Oo000000?oooooo`000?l000002oooool2o`0000Sooooo0_l0
0002ooooob[o000000?oooooo`000?l000000_l00005ooooo`;o00002?ooool2o`0000?ooooo0_l0
000<ooooo`;o00001_ooool2o`0000;ooooo0_l0000fooooo`007?ooool00ol0003oooooooooo`0i
ooooo`;o000000?oooooo`000?l000004Oooool3o`0000Cooooo0_l0000Fooooo`;o00000oooool2
o`0001?ooooo0_l000000ooooooo0000o`000007o`0000Gooooo0_l00006ooooo`Co00002oooool2
o`0000;ooooo0ol000000ooooooo0000o`00000So`0000;ooooo0_l00007ooooo`;o000000?ooooo
o`000?l000001Oooool2o`0000;ooooo0_l0000Eooooo`;o00000_ooool2o`0003Kooooo000Loooo
o`03o`000?oooooooooo037ooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o0000
00cooooo0_l00002ooooo`?o00007Oooool2o`0000?ooooo0_l00002ooooo`;o00004_ooool7o`00
00[ooooo0_l000000ooooooo0000o`000004o`0000?ooooo0_l00006ooooo`Ko00000_ooool:o`00
00;ooooo4_l000000ooooooo0000o`000003o`0000?ooooo0_l000000ooooooo0000o`000003oooo
o`;o00000_ooool3o`0000Sooooo0_l0000Iooooo`;o0000=_ooool001cooooo00?o0000oooooooo
ool0:oooool2o`0000Cooooo0_l00002ooooo`Co00001_ooool2o`0000Wooooo0_l00002ooooo`;o
00008oooool6o`0001;ooooo0_l000000ooooooo0000o`000004ooooo`;o00001_ooool2o`000003
ooooool0003o000000Oooooo0_l00006ooooo`Co00001?oooolTo`0000?ooooo0_l000000ooooooo
0000o`000003ooooo`;o00000oooool4o`0000Kooooo0_l0000Cooooo`;o0000??ooool001cooooo
00?o0000ooooooooool05oooool2o`0001;ooooo0_l00008ooooo`Co00001_ooool2o`0000Oooooo
0_l00006ooooo`;o00008oooool2o`0000Oooooo0_l00004ooooo`;o000000?oooooo`000?l00000
2_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l0000JooooobCo00000_ooool3o`0000go
oooo0_l00006ooooo`;o00002?ooool2o`0000Wooooo0_l0000looooo`007?ooool00ol0003ooooo
ooooo`0Gooooo`;o00005?ooool2o`0000Kooooo0ol0000@ooooo`;o00001_ooool2o`000003oooo
ool0003o000002Cooooo0_l00003ooooo`;o00001?ooool2o`000003ooooool0003o000000Ko0000
00?oooooo`000?l000001?l000000ooooooo0000o`000003ooooo`Co00002oooool4o`0000Sooooo
9?l00003ooooo`?o00005Oooool2o`0000Sooooo0_l00002ooooo`;o0000@oooool001cooooo00?o
0000ooooooooool0;Oooool2o`0000Oooooo0_l0000Kooooo`;o00009?ooool2o`0000Sooooo0_l0
0005ooooo`;o000000?oooooo`000?l000000_ooool5o`000003ooooool0003o000000?ooooo1?l0
00000ooooooo0000o`000008ooooo`Co000000?oooooo`000?l000000ooooolNo`000003ooooool0
003o000000Go000000?oooooo`000?l000001_l0000?ooooo`;o000000Coooooo`000?l0003o0000
2oooool2o`0004?ooooo000Looooo`03o`000?oooooooooo03;ooooo1_l00009ooooo`;o0000=Ooo
ool5o`0000Kooooo1?l000000ooooooo0000o`000002o`0000Gooooo0_l0000>ooooo`;o00002ooo
ool4o`000003ooooool0003o000002oo00003_ooool3o`000004ooooool0003o0000o`0001Oooooo
0_l0000gooooo`007?ooool00ol0003oooooooooo`0booooo`Ko00002Oooool4o`0003?ooooo0_l0
00000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l000000ol00004ooooo`;o00002ooo
ool2o`00017ooooo0_l00003ooooo`;o00000_ooool>o`000003ooooool0003o000001Co000000Co
ooooo`000?l0003ooooo0ol0000;ooooo`Ko00002?ooool2o`0000kooooo0_l00002ooooo`;o0000
=oooool001cooooo00?o0000ooooooooool0<_ooool2o`0000Wooooo0ol000000ooooooo0000o`00
0002o`00033ooooo0_l00005ooooo`;o00001?ooool2o`0000?ooooo0ol000001?oooooo0000o`00
0?ooool2o`0000_ooooo0_l00009ooooo`;o00000_ooool3o`0000Kooooo0_l00002ooooo`;o0000
00?oooooo`000?l000008_l00003ooooo`;o00002oooool4o`0000[ooooo0_l0000>ooooo`;o0000
>oooool001cooooo00?o0000ooooooooool0?Oooool3o`000003ooooool0003o000001Cooooo0_l0
0003ooooo`;o00005Oooool4o`0000?ooooo1_l000001?oooooo0000o`000?l00004ooooo`Ko0000
6?ooool2o`0000;ooooo0ol00004ooooo`;o00001ooooolTo`00013ooooo0_l00003ooooo`;o0000
3oooool2o`0004?ooooo000Looooo`03o`000?oooooooooo053ooooo1?l00003ooooo`;o00000ooo
ool2o`0000_ooooo0_l00008ooooo`Wo00000_ooool2o`000005ooooool0003o0000o`000?ooool0
0_l00003ooooo`Co00003?ooool2o`0001Gooooo0ol00002ooooo`;o000000?oooooo`000?l00000
8ol0000:ooooo`;o00001?ooool2o`0000?ooooo0_l0000>ooooo`?o0000@oooool001cooooo00?o
0000ooooooooool0;oooool4o`0001gooooo1?l00005ooooo`;o00002oooool2o`000003ooooool0
003o000000Cooooo0_l00004ooooo`Oo00002Oooool2o`0000;ooooo2Ol00008ooooo`;o00000ooo
ool2o`0000Cooooo0_l00005ooooo`;o00001?ooool2o`0000;ooooo1Ol000000ooooooo0000o`00
000Oo`000003ooooool0003o000000;o000000?oooooo`000?l000000oooool2o`0000Cooooo0_l0
0008ooooo`;o00002Oooool2o`0004Cooooo000Looooo`03o`000?oooooooooo02oooooo1Ol0000>
ooooo`;o00005Oooool2o`0000_ooooo0_l00005ooooo`Co00000oooool4o`0000?ooooo0_l00008
ooooo`;o00000_ooool3o`0000;ooooo1?l00006ooooo`;o00000oooool4o`0000Cooooo0_l00005
ooooo`;o00001_ooool2o`0000;ooooo2_l000000ooooooo0000o`00000:o`000003ooooool0003o
0000013o000000?oooooo`000?l000001oooool2o`0000[ooooo0_l0001?ooooo`007?ooool00ol0
003oooooooooo`0aooooo`?o00003Oooool3o`0000Oooooo0_l0000Pooooo`;o000000Goooooo`00
0?l0003o0000ooooo`04o`0000?ooooo0_l00008ooooo`;o00000oooool3o`0000_ooooo0ol00002
ooooo`;o00001_ooool2o`0000Sooooo0_l00003ooooo`;o00000_oooolQo`000004ooooool0003o
0000ooooo`Co00002oooool2o`00013ooooo0_l00019ooooo`007?ooool2o`0003;ooooo0_l0000>
ooooo`Co00001_ooool2o`0000Kooooo0_l00007ooooo`;o00001Oooool2o`0000Oooooo0ol00000
1Ooooooo0000o`000?l0003ooooo00?o000000?oooooo`000?l000002oooool2o`000003ooooool0
003o000000?o00001oooool2o`0000?ooooo0_l0000:ooooo`;o00002?ooool2o`0000?ooooo9ol0
0002ooooo`Co00007Oooool2o`0000;ooooo0_l0000:ooooo`;o0000>Oooool001cooooo00?o0000
ooooooooool0@oooool2o`0000kooooo0_l00007ooooo`;o00001Oooool2o`0000Oooooo1ol00000
0ooooooo0000o`000006o`000003ooooool0003o000000Gooooo0ol000000ooooooo0000o`000003
o`0000;ooooo0_l00003ooooo`;o00006?ooool2o`0000?ooooo3?l000000ooooooo0000o`00000N
o`0000?ooooo0_l0000Fooooo`?o00001?ooool2o`0000[ooooo0_l0000iooooo`007?ooool00ol0
003oooooooooo`18ooooo`;o00002Oooool2o`0000Oooooo1?l00003ooooo`;o00002OoooolCo`00
00?ooooo0ol00004ooooo`;o00000_ooool2o`0000?ooooo0_l0000Hooooo`;o00000oooool/o`00
0004ooooool0003o0000ooooo`Co00005?ooool3o`0004_ooooo000Looooo`03o`000?oooooooooo
03;ooooo0_l0000@ooooo`;o00000_ooool2o`0001;ooooo1?l00002ooooo`;o00001_oooolAo`00
0004ooooool0003o0000ooooo`;o00002Oooool2o`0000Sooooo0_l00007ooooo`;o00000_ooool2
o`0000Wooooo1?l00004ooooo`Ko00000_oooolLo`000003ooooool0003o000000Co000000?ooooo
o`000?l000000oooool2o`0000?ooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`0boooo
o`Go00003?ooool3o`0000kooooo0_l0000<ooooo`Co000000Coooooo`000?l0003ooooo5_l0000:
ooooo`Co00001?ooool2o`0000Cooooo0_l00003ooooo`;o00000_ooool2o`0000Wooooo1?l00006
ooooob;o000000?oooooo`000?l000001Ol0000:ooooo`;o00006?ooool2o`000003ooooool0003o
0000043ooooo000Looooo`03o`000?oooooooooo033ooooo0_l000000ooooooo0000o`000002o`00
00cooooo1?l00005ooooo`;o00001_ooool2o`000003ooooool0003o000000_ooooo0_l000000ooo
oooo0000o`00000Go`0000;ooooo0_l00008ooooo`;o00001?ooool3o`0000?ooooo0_l0000<oooo
o`;o00001_ooool2o`0000Cooooo0_l00002ooooobGo000000Coooooo`000?l0003o00008oooool2
o`000003ooooool0003o0000043ooooo000Looooo`03o`000?oooooooooo033ooooo0_l00003oooo
o`;o00003_ooool2o`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l000001?l00009oooo
o`;o00000_ooool2o`000003ooooool0003o0000017o00001_ooool2o`0000oooooo0_l0000<oooo
o`;o000000?oooooo`000?l000000_l00006ooooo`;o00001?ooool2o`000003ooooool0003o0000
00?ooooo6_l000000ooooooo0000o`000004o`0000;ooooo0_l00002ooooo`;o00004_ooool3o`00
00gooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0cooooo`Co00005_ooool2o`000004
ooooool0003o0000ooooo`Co00002oooool6o`000003ooooool0003o0000017o000000?oooooo`00
0?l000002_ooool4o`0000Kooooo1?l00008ooooo`Co000000?oooooo`000?l000002Oooool2o`00
00Kooooo1?l000000ooooooo0000o`00000Mo`0000?ooooo0ol00002ooooo`;o00004_ooool3o`00
00Cooooo0ol00006ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0:oooool2o`0000Ko
oooo0ol0000>ooooo`;o00001oooool2o`0000Cooooo0ol00005ooooo`;o00001_oooolLo`0000Go
oooo0_l00003ooooo`Co00002?ooool2o`0000Kooooo1_l00006ooooo`;o00001?ooool2o`0000?o
oooo0ol000001?oooooo0000o`000?l00003ooooo`;o000000?oooooo`000?l000005?l00007oooo
o`?o000000?oooooo`000?l000005?ooool2o`0000Cooooo0ol00005ooooo`?o0000@?ooool001co
oooo00?o0000ooooooooool0:oooool2o`0000Kooooo0_l0000?ooooo`;o00003_ooool2o`000003
ooooool0003o000000;ooooo0_l00006oooooa_o00001_ooool2o`0000Cooooo0_l00005ooooo`;o
00002_ooool2o`0000;ooooo0_l00006ooooo`;o00002?ooool5o`000003ooooool0003o000000;o
oooo0_l00002oooooaKo00000oooool2o`0000Cooooo1?l00006ooooo`;o00006_ooool4o`0003oo
oooo000Looooo`03o`000?oooooooooo03?ooooo0_l00002ooooo`;o000000?oooooo`000?l00000
6oooool2o`0000;ooooo0_l00003ooooob7o00000_ooool3o`0000Cooooo1?l00003ooooo`;o0000
3_ooool2o`0000oooooo0ol000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00003ooooo`ko
00000_ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000000_l00002ooooo`;o
00001Oooool5o`0000gooooo0_l0000=ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0
=oooool6o`0000[ooooo0_l00008ooooo`;o00003OoooolLo`000003ooooool0003o000000;o0000
0_ooool3o`0000Gooooo0ol0000=ooooo`;o00005Oooool3o`0000Cooooo0_l00002ooooo`;o0000
0_oooolAo`000005ooooool0003o0000o`000?ooool00_l00002ooooo`Co000000?oooooo`000?l0
00001Oooool3o`0000?ooooo0_l00002ooooo`Go00000oooool2o`000003ooooool0003o000000co
oooo0_l0000;ooooo`;o0000<?ooool001cooooo00?o0000ooooooooool0>?ooool2o`000003oooo
ool0003o000000[ooooo0_l00008ooooo`;o00002?ooool2o`0000Cooooo7?l0000Nooooo`;o0000
2oooool2o`0000?ooooo1_l00003ooooo`?o00000_oooolDo`000003ooooool0003o000000Ko0000
0oooool4o`000003ooooool0003o000000;o00002Oooool9o`0000;ooooo0_l000001?oooooo0000
o`000?l00008ooooo`;o00000_ooool2o`0000_ooooo0_l0000`ooooo`007?ooool00ol0003ooooo
ooooo`0eooooo`;o00005Oooool2o`0000Cooooo0ol00002ooooo`;o00000_ooool2o`0000Cooooo
7?l00009ooooo`;o00001_ooool2o`0000Sooooo0_l000000ooooooo0000o`000009ooooo`Go0000
0_ooool6o`000003ooooool0003o000000?o00000_ooool3o`000004ooooool0003o0000ooooo`So
00000_ooool<o`000004ooooool0003o0000ooooo`;o000000Coooooo`000?l0003ooooo0_l00000
0ooooooo0000o`000002ooooo`;o00001?ooool2o`0000Oooooo0_l000000ooooooo0000o`000009
ooooo`;o0000@Oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Go
k^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo02oooooo0_l00003ooooo`?o0000
5Oooool2o`0000?ooooo1?l00002ooooo`;o00002?ooool2o`000003ooooool0003o000000So0000
00?oooooo`000?l000003?l00004ooooo`;o00000oooool2o`0000Gooooo0ol00008ooooo`;o0000
00?oooooo`000?l000002Oooool5o`0000Gooooo0_l00002ooooo`;o00001?ooool4o`0000Cooooo
2?l00002ooooo`Ko000000?oooooo`000?l000001?ooool5o`000003ooooool0003o000000Cooooo
0_l00002ooooo`;o00003oooool4o`0004_ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0_oooo
o`;o00000oooool2o`0000?ooooo0_l0000:ooooo`?o000000?oooooo`000?l000001_ooool2o`00
00Wooooo0_l000000ooooooo0000o`00000=o`000003ooooool0003o000000[o00000oooool2o`00
0004ooooool0003o0000o`0000Wooooo1?l000000ooooooo0000o`000002o`0000cooooo0_l00004
ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l00003ooooo`Co00002?ooool4
o`0000;ooooo1Ol0000;ooooo`;o00001_ooool2o`0001;ooooo0_l000000ooooooo0000o`000002
o`0004_ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo02oooooo0_l00008ooooo`;o00002_ooool3
o`000003ooooool0003o000000kooooo0_l000000ooooooo0000o`00000Mo`0000?ooooo0_l00002
ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Cooooo1ol0000<ooooo`;o00001?ooool2
o`000003ooooool0003o000000;ooooo0ol00007ooooo`Co00001oooool2o`000003ooooool0003o
000000Oo00002oooool2o`0000Kooooo0_l00004ooooo`;o00003?ooool3o`0000?ooooo0_l0001:
ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9Sooooo
oiRHV?lQ8B401_ooool3o`0003Kooooo0_l0000Mooooo`;o00000_ooool2o`0000;ooooo5_l00000
0ooooooo0000o`000004o`0000_ooooo0_l00002ooooo`;o000000?oooooo`000?l000000oooool2
o`0000Oooooo0_l0000<ooooo`;o00001?ooool4o`0000Gooooo0_l00004ooooo`Co00000oooool2
o`0000;ooooo1Ol00003ooooo`;o00002?ooool2o`000003ooooool0003o000000[ooooo0_l0000<
ooooo`?o00000oooool2o`0004[ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo03Kooooo0_l00002
ooooo`;o000000?oooooo`000?l000000_ooool2o`0000cooooo0_l000001?oooooo0000o`000?oo
ool2o`0000;ooooo0_l00002ooooo`Co000000?oooooo`000?l000006?l0000@ooooo`;o000000?o
ooooo`000?l000001?ooool2o`0000?ooooo0_l0000<ooooo`;o00001?ooool2o`0000Oooooo0_l0
0004ooooo`Ko00001?ooool6o`0000?ooooo0ol00006ooooo`?o000000?oooooo`000?l000000_oo
ool3o`000004ooooool0003o0000ooooo`;o00001oooool3o`000004ooooool0003o0000ooooo`Co
0000COooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7
ooooo`08ooooo`03o`000?oooooooooo03Gooooo0_l00003ooooo`;o000000?oooooo`000?l00000
0_ooool2o`000003ooooool0003o000000Wooooo0_l000000ooooooo0000o`000003o`0000Kooooo
7ol0000Cooooo`;o00000_ooool4o`0000?ooooo0_l0000?ooooo`;o00002?ooool2o`0000Sooooo
1?l000001?oooooo0000o`000?ooool5o`0000;ooooo0_l000001?oooooo0000o`000?l00005oooo
o`;o00001_ooool3o`000004ooooool0003o0000ooooo`;o00001oooool3o`000003ooooool0003o
000000?ooooo0_l00006ooooo`Co0000@oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2ooo
ool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo03Gooooo0_l00003ooooo`;o000000?o
ooooo`000?l000001Oooool2o`0000gooooo1?l00007oooooa_o00006_ooool3o`0001Gooooo0_l0
0006ooooo`Co00002_ooool2o`000003ooooool0003o000000Cooooo2_l00003ooooo`;o00003ooo
ool2o`0000Oooooo0_l00003ooooo`;o00002_ooool4o`0004?ooooo00001_ooooook^k^oc8b<_l0
003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`0eooooo`;o
00000oooool5o`0001;ooooo0_l00002ooooo`;o00001OoooolDo`000003ooooool0003o000000Co
00001oooool2o`0000[ooooo0_l00006ooooo`Co000000?oooooo`000?l000006_ooool2o`0000Oo
oooo0_l00003ooooo`Co000000?oooooo`000?l000001?ooool2o`0000;ooooo1Ol00002ooooo`;o
00000oooool2o`0000Wooooo1_l00002ooooo`?o00001?ooool2o`0000_ooooo0_l000000ooooooo
0000o`00000Booooo`;o0000;Oooool001cooooo00?o0000ooooooooool0<?ooool2o`0000?ooooo
0_l00003ooooo`?o00002?ooool2o`0000Kooooo0_l00002ooooo`;o00001?ooool2o`000003oooo
ool0003o000000So00000_oooolAo`0000Oooooo1?l00008ooooo`;o00001_ooool2o`0000?ooooo
0_l0000Fooooo`;o00002oooool2o`0000Gooooo0_l000001?oooooo0000o`000?ooool2o`0000Ko
oooo1?l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00004ooooo`Ko00000_ooool3o`0000?o
oooo0_l000000ooooooo0000o`000009ooooo`;o000000?oooooo`000?l000004_ooool2o`0002go
oooo000Looooo`03o`000?oooooooooo033ooooo0_l00002ooooo`;o00003oooool2o`0000Kooooo
0_l00008ooooo`;o000000Coooooo`000?l0003ooooo1?l000000ooooooo0000o`00000Ao`0000_o
oooo0_l00009ooooo`;o00008_ooool2o`0001Sooooo0_l0000=ooooo`;o00001Oooool4o`0000So
oooo0_l000000ooooooo0000o`000004o`000004ooooool0003o0000ooooo`;o00001_ooool2o`00
04Oooooo000Looooo`03o`000?oooooooooo03Cooooo0_l00003ooooo`;o00004_ooool2o`00013o
oooo6Ol0000Cooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o0000;?ooool2o`000004
ooooool0003o0000o`00013ooooo0_l00004ooooo`;o00002Oooool3o`000003ooooool0003o0000
00Co00000_ooool2o`0000?ooooo0_l00003ooooo`;o00005Oooool2o`00033ooooo000Looooo`03
o`000?oooooooooo03Wooooo0_l0000Iooooo`;o00002Oooool8o`000003ooooool0003o000000ko
00000_ooool2o`00013ooooo1_l00003ooooo`;o00005?ooool2o`0001Kooooo0_l000001?oooooo
0000o`000?l0000@ooooo`;o00003oooool3o`000003ooooool0003o000000Co00000_ooool2o`00
00?ooooo0_l0000Jooooo`;o0000<?ooool001cooooo00?o0000ooooooooool0?oooool2o`0000oo
oooo0_l00002ooooo`?o00001Oooool2o`0000?ooooo1?l000000ooooooo0000o`00000;o`0000Oo
oooo0_l0000>ooooo`Ko00000_ooool2o`0001Oooooo0_l0000Mooooo`;o000000Coooooo`000?l0
003o00005oooool3o`000003ooooool0003o000000;ooooo1?l0001Fooooo`007?ooool00ol0003o
ooooooooo`0oooooo`Co000000?oooooo`000?l000002_ooool2o`0000?ooooo0_l00005ooooo`;o
00000oooool2o`000003ooooool0003o000000co00005_ooool4o`0000;ooooo0_l00002ooooo`;o
00001?ooool2o`0001Gooooo0_l00008ooooo`;o00003oooool2o`000004ooooool0003o0000o`00
00cooooo0_l00009ooooo`?o00001Oooool4o`0000;ooooo1?l00002ooooo`;o0000C?ooool001co
oooo00?o0000ooooooooool0@?ooool3o`000003ooooool0003o000000[ooooo0_l0000Booooo`;o
000000?oooooo`000?l000001ol0000Eooooo`;o000000?oooooo`000?l000000_l00006ooooo`?o
00000oooool2o`0001Gooooo0_l000000ooooooo0000o`000005ooooo`;o00000_ooool2o`0000So
oooo0_l00004ooooo`?o00003?ooool2o`0001;ooooo1?l000000ooooooo0000o`000002o`0000;o
oooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00000_ooool2o`0000[ooooo
0_l00008ooooo`;o00002?ooool2o`000003ooooool0003o000000?o000000?oooooo`000?l00000
5_ooool2o`0000Oooooo1ol0000Eooooo`;o00001_ooool2o`0000Wooooo0ol00003ooooo`;o0000
0_ooool2o`0000Cooooo0_l0000=ooooo`;o00001_ooool2o`0000Wooooo0_l000000ooooooo0000
o`00001Eooooo`007?ooool00ol0003oooooooooo`10ooooo`;o000000Coooooo`000?l0003o0000
1?ooool2o`0000Cooooo0ol00007ooooo`Co00001_ooool2o`0000Gooooo0_l00002ooooo`;o0000
5Oooool2o`0000Kooooo1Ol0000Gooooo`Go00003oooool2o`0000?ooooo0ol0000:ooooo`;o0000
2_ooool2o`000003ooooool0003o000000?ooooo0_l00009ooooo`;o0000F?ooool001cooooo00?o
0000ooooooooool0@_ooool4o`0000Cooooo0ol00004ooooo`;o00001_ooool2o`000003ooooool0
003o000000gooooo0_l00002ooooo`;o00005Oooool4o`0001Sooooo0_l00007ooooo`Co00000ooo
ool2o`0000Sooooo0_l00006ooooo`;o00002_ooool2o`0000Gooooo1?l00004ooooo`?o00002Ooo
ool2o`000003ooooool0003o000005Wooooo000Looooo`03o`000?oooooooooo03gooooo0_l00003
ooooo`;o00001Oooool6o`0000[ooooo0_l0000]ooooo`;o00000oooool2o`00017ooooo1?l00007
ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000Sooooo0_l0000Dooooo`;o00000_oo
ool5o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o00001Oooool2o`000003ooooool0
003o000000;o00001oooool2o`0004kooooo000Looooo`;o0000?_ooool2o`0000Gooooo0_l00000
0ooooooo0000o`000003o`000003ooooool0003o000000cooooo1Ol0000=ooooo`;o00005?ooool2
o`0000Sooooo0_l0000;ooooo`;o00001?ooool8o`0000;ooooo1ol000001?oooooo0000o`000?oo
ool2o`0000Gooooo1Ol000000ooooooo0000o`000008ooooo`;o00000oooool3o`0000;ooooo0_l0
0004ooooo`;o00001_ooool2o`0000Sooooo1Ol00002ooooo`;o00000_ooool2o`0004kooooo000L
ooooo`03o`000?oooooooooo04Cooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo1?l0
0009ooooo`Go00000_ooool2o`0000Wooooo0_l0000Dooooo`;o00002?ooool2o`0000_ooooo0_l0
0007ooooo`ko000000Coooooo`000?l0003ooooo0_l00003ooooo`;o000000?oooooo`000?l00000
0_l000001?oooooo0000o`000?l00007ooooo`;o00000oooool3o`000004ooooool0003o0000o`00
00cooooo0_l00006ooooo`Co000000?oooooo`000?l000000_ooool2o`0005;ooooo000Looooo`03
o`000?oooooooooo03kooooo0_l0000;ooooo`Oo00002oooool2o`0000?ooooo0_l0000Oooooo`;o
00002?ooool2o`00013ooooo4_l00009ooooo`;o000000Coooooo`000?l0003o00000_ooool4o`00
0003ooooool0003o000000Wooooo0_l000000ooooooo0000o`000002ooooo`;o00001_ooool2o`00
0003ooooool0003o000000Kooooo1?l0000Nooooo`;o0000>Oooool001cooooo00?o0000oooooooo
ool0?_ooool2o`0000_ooooo1?l00008ooooo`?o000000?oooooo`000?l000001_ooool2o`0001go
oooo0ol0000Joooooa3o00004?ooool2o`0000;ooooo1_l0000>ooooo`Co00001_ooool2o`0000;o
oooo0_l00002ooooo`;o000000Coooooo`000?l0003o00001Oooool2o`0001Sooooo0_l0000ioooo
o`007?ooool00ol0003oooooooooo`1Aooooo`?o00000oooool3o`000003ooooool0003o000000?o
oooo0_l000000ooooooo0000o`00000Mooooo`?o00002_ooool2o`0000kooooo4_l00006ooooo`Co
00001?ooool2o`0000Gooooo0_l0000?ooooo`;o00003?ooool2o`0000;ooooo0_l000001?oooooo
0000o`000?l00005ooooo`;o00001?ooool2o`0004gooooo000Looooo`03o`000?oooooooooo04Go
oooo0_l00003ooooo`;o00001Oooool3o`0000cooooo0_l0000Jooooo`;o00001Oooool2o`0000;o
oooo0_l00006ooooo`?o00003_oooolAo`0000Kooooo1?l0000:ooooo`;o00007_ooool2o`0000;o
oooo0_l0000?ooooo`;o0000COooool001cooooo00?o0000ooooooooool0AOooool2o`000003oooo
ool0003o000000;o00001_ooool2o`0002Sooooo0_l00009ooooo`;o00001oooool2o`0000Sooooo
0_l00004oooooa3o00005Oooool2o`0000cooooo0_l0000=ooooo`;o00000_ooool5o`0001_ooooo
0_l00011ooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00001?ooool2o`000003ooooool0
003o000000;o00001Oooool3o`00013ooooo0_l0000dooooo`;o000000?oooooo`000?l000004ol0
0006ooooo`;o00004Oooool2o`0000Kooooo0_l0000;ooooo`[o00007?ooool2o`00047ooooo000L
ooooo`03o`000?oooooooooo03oooooo0_l00007ooooo`Co00001Oooool2o`0000;ooooo0_l0000=
ooooo`Co00001?ooool2o`0000oooooo0_l00007ooooo`;o00000oooool2o`0000Oooooo0_l00004
ooooo`;o000000?oooooo`000?l000004ol00006ooooo`;o00004Oooool2o`0000Oooooo0_l00006
ooooo`?o000000?oooooo`000?l000000_ooool7o`0005kooooo000Looooo`03o`000?oooooooooo
043ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l00009ooooo`;o00003oooool4o`00
00;ooooo0_l0000?ooooo`;o00001oooool2o`0000?ooooo0ol00002ooooo`;o00000_ooool2o`00
00Cooooo0_l000000ooooooo0000o`00000Co`0001_ooooo0ol00002ooooo`Co00000oooool6o`00
00Kooooo1_l0001Nooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00000_ooool3o`0001;o
oooo0_l00007ooooo`;o00000_ooool4o`00013ooooo0_l00008ooooo`;o00001Oooool3o`0000;o
oooo0_l000000ooooooo0000o`000005ooooo`So000000?oooooo`000?l000003_l00009ooooo`;o
00002_ooool2o`0000?ooooo1ol00002ooooo`;o000000?oooooo`000?l000001?l00009ooooo`;o
0000Goooool001cooooo00?o0000ooooooooool0A?ooool2o`0001?ooooo0_l00007ooooo`Ko0000
4_ooool2o`0000Cooooo0_l00002ooooo`;o00001Oooool2o`0000Kooooo0_l00005oooooaKo0000
00?oooooo`000?l000002Oooool4o`0000Sooooo0_l00004ooooo`Ko00000_ooool2o`000004oooo
ool0003o0000ooooo`;o00002_ooool2o`0000cooooo0_l0001Aooooo`007?ooool00ol0003ooooo
ooooo`1@ooooo`;o00004_ooool2o`0001Gooooo0_l00003ooooo`;o00006_oooolCo`0000Wooooo
0_l000001?oooooo0000o`000?ooool2o`0000gooooo1?l000000ooooooo0000o`000002o`0000?o
oooo0_l0000=ooooo`;o00002_ooool4o`0000gooooo0_l00012ooooo`007?ooool00ol0003ooooo
ooooo`1?ooooo`Co00002Oooool2o`0000?ooooo0_l00006ooooo`Ko00000_ooool2o`0000Oooooo
0ol0000MoooooaKo00002?ooool5o`0000[ooooo0_l00004ooooo`;o00001Oooool3o`00017ooooo
0_l00009ooooo`?o00002oooool2o`0000;ooooo0_l00012ooooo`007?ooool00ol0003ooooooooo
o`1:ooooo`;o00000oooool4o`0000Wooooo0_l00002ooooo`?o00001_ooool:o`0000Oooooo0_l0
0005ooooo`;o00005ooooolFo`0000Wooooo0_l000000ooooooo0000o`000007ooooo`Co00002ooo
ool3o`0000;ooooo0_l0000>ooooo`Co00001?ooool4o`0000cooooo0_l00016ooooo`007?ooool0
0ol0003oooooooooo`1:ooooo`;o00003_ooool2o`0000Cooooo0_l00006ooooo`?o00000oooool3
o`00013ooooo0_l0000Fooooo`;o000000?oooooo`000?l000004?l00002ooooo`;o00002_ooool3
o`0000Kooooo1?l00009ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o00002ooo
ool4o`0000Cooooo0_l0001Fooooo`007?ooool2o`0004Oooooo0_l00008ooooo`;o00000_ooool2
o`0000Cooooo0_l00008ooooo`;o00000_ooool2o`0000[ooooo0_l00002ooooo`;o00007oooool2
o`000003ooooool0003o000000oo00000oooool2o`0000[ooooo0ol00006ooooo`Co00000_ooool2
o`0000Gooooo1_l00004ooooo`;o00002_ooool2o`0001Kooooo0_l00017ooooo`007?ooool00ol0
003oooooooooo`13ooooo`;o000000?oooooo`000?l000002?ooool2o`0000;ooooo0_l0000>oooo
o`;o00000_ooool2o`0000Wooooo1ol0000Fooooo`?o000000?oooooo`000?l000000oooool2o`00
0003ooooool0003o0000013o00003?ooool2o`0000Kooooo0ol00003ooooo`;o000000?oooooo`00
0?l000001oooool8o`0000Cooooo0_l00005ooooo`?o00005_ooool2o`0004Oooooo000Looooo`03
o`000?oooooooooo04?ooooo0_l0000?ooooo`?o00001?ooool2o`0000?ooooo0_l00006ooooo`;o
00000oooool3o`000003ooooool0003o000000;o000000?oooooo`000?l000005oooool4o`000003
ooooool0003o000000?ooooo0_l000000ooooooo0000o`00000Ao`0000_ooooo0_l00006ooooo`?o
00000oooool2o`0000Kooooo0_l00004ooooo`Ko000000Coooooo`000?l0003ooooo1?l00003oooo
o`;o00003?ooool2o`0005;ooooo000Looooo`03o`000?oooooooooo053ooooo1?l000000ooooooo
0000o`000004ooooo`;o00000oooool2o`0000_ooooo0ol000000ooooooo0000o`00000Hooooo`So
000000Coooooo`000?l0003ooooo0_l00005ooooo`go00000_ooool4o`0001gooooo1?l0000;oooo
o`;o00000oooool4o`0000gooooo1?l0001Booooo`007?ooool00ol0003oooooooooo`1;ooooo`;o
00000oooool4o`0000Cooooo0_l0000<ooooo`;o00003oooool2o`0000;ooooo0_l0000>ooooo`Oo
00000_ooool5o`0000Gooooo3?l00005ooooo`;o00004?ooool4o`0000;ooooo0_l00005ooooo`;o
00000_ooool2o`0000kooooo1?l0000=ooooo`;o0000E?ooool001cooooo00?o0000ooooooooool0
AOooool2o`0000;ooooo1?l0000;ooooo`;o00003?ooool2o`0000?ooooo0_l000000ooooooo0000
o`000007ooooo`;o00000_ooool2o`0001;ooooo0_l00004ooooo`;o00001Oooool2o`000003oooo
ool0003o000000Wo00003oooool2o`0000Kooooo1?l00002ooooo`;o00002Oooool2o`0007Gooooo
000Looooo`03o`000?oooooooooo04Gooooo0_l00002ooooo`;o00001_ooool2o`0000?ooooo0_l0
0004ooooo`;o00000_ooool2o`0000Wooooo0_l000000ooooooo0000o`00000Oooooo`;o00002ooo
ool2o`000003ooooool0003o000000Wo00001oooool2o`0000Kooooo0_l00009ooooo`;o000000?o
ooooo`000?l000001Oooool2o`0000?ooooo0_l000000ooooooo0000o`000005ooooo`;o00002?oo
ool2o`00063ooooo000Looooo`03o`000?oooooooooo057ooooo2?l00003ooooo`;o00000_ooool2
o`0000Gooooo0_l0000Rooooo`;o00004oooool7o`000003ooooool0003o000000Oooooo0_l00002
ooooo`?o00003?ooool2o`0000Oooooo0ol00003ooooo`;o000000Coooooo`000?l0003o00001?oo
ool2o`0000Sooooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`1Booooo`Co000000Cooooo
o`000?l0003ooooo0_l00005ooooo`;o00001?ooool2o`0002;ooooo0_l00002ooooo`;o00003?oo
ool2o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`0000Oooooo0ol0000Eooooo`;o00001?oo
ool2o`000004ooooool0003o0000o`0000Gooooo0_l00006ooooo`;o0000HOooool001cooooo00?o
0000ooooooooool0F_ooool4o`0000?ooooo0_l00008ooooo`;o00008_ooool2o`0000cooooo0_l0
0002ooooo`;o00002Oooool2o`0001oooooo0_l00002ooooo`Co00000_ooool2o`0000Gooooo0_l0
0006ooooo`;o00002?ooool2o`0000Cooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`1:
ooooo`;o00001?ooool2o`0000Gooooo0_l00003ooooo`;o000000?oooooo`000?l000002_ooool2
o`0000[ooooo0_l0000Xooooo`;o00000oooool4o`0000;ooooo0_l00006ooooo`;o00006oooool4
o`0000Cooooo0ol0000Dooooo`;o00001?ooool2o`00057ooooo000Looooo`03o`000?oooooooooo
04[ooooo0_l00002ooooo`Co00001Oooool2o`0000Kooooo0_l0000@ooooo`;o00001?ooool4o`00
02_ooooo1?l00002ooooo`;o00001_ooool2o`0001gooooo0_l00004ooooo`?o00004_ooool4o`00
05Oooooo000Looooo`03o`000?oooooooooo04kooooo1_l0000=ooooo`;o00000_ooool2o`0000[o
oooo0_l00006ooooo`;o00003?ooool2o`0001;ooooo0_l0000@ooooo`;o00006Oooool2o`0000;o
oooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l0000Eooooo`;o0000FOooool001cooooo
00?o0000ooooooooool0Coooool5o`0000gooooo0_l00002ooooo`?o00007oooool2o`0001;ooooo
0_l0000?ooooo`?o00003Oooool3o`0000Wooooo0_l00002ooooo`;o000000?oooooo`000?l00000
0ol00003ooooo`;o000000?oooooo`000?l000005Oooool2o`0005Kooooo000Looooo`03o`000?oo
oooooooo05;ooooo0_l0000Aooooo`?o00007oooool3o`0000gooooo0_l0000Cooooo`;o00002Ooo
ool8o`0001?ooooo0_l00006ooooo`;o00005Oooool2o`0005Kooooo000Looooo`03o`000?oooooo
oooo067ooooo0_l00002ooooo`;o00000oooool2o`0000?ooooo0_l0000Gooooo`;o00003Oooool2
o`0001?ooooo0_l00009ooooo`So00003?ooool2o`0000Gooooo0_l00006ooooo`;o0000KOooool0
01cooooo0_l0001Fooooo`;o00000oooool2o`0000Gooooo0ol00006ooooo`;o00000oooool2o`00
0003ooooool0003o0000023ooooo0_l0000Fooooo`Co00006oooool2o`0000gooooo0_l00003oooo
o`;o0000J?ooool001cooooo00?o0000ooooooooool0EOooool2o`0000?ooooo0_l00003ooooo`Go
00001_ooool2o`0000Cooooo1?l00002ooooo`;o00002?ooool2o`0000?ooooo0_l00007ooooo`?o
00000oooool2o`0000?ooooo0_l00002ooooo`;o00003oooool2o`0000?ooooo0_l00007ooooo`;o
00008Oooool6o`0006Cooooo000Looooo`03o`000?oooooooooo05gooooo1_l00006ooooo`?o0000
1?ooool2o`0000Cooooo0_l00006ooooo`Co00000oooool2o`0000Kooooo1?l000000ooooooo0000
o`000005ooooo`;o00000_ooool3o`0000gooooo0_l00002ooooo`Co00001oooool2o`000003oooo
ool0003o000000Oooooo0_l00002ooooo`;o00003_ooool2o`000003ooooool0003o000000Co0000
I?ooool001cooooo00?o0000ooooooooool0EOooool2o`0000Kooooo0_l0000:ooooo`;o00002?oo
ool2o`0000Wooooo0_l0000<ooooo`?o00000_ooool3o`000003ooooool0003o000000Oooooo0_l0
000=ooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`;o00001ooo
ool2o`0000;ooooo0_l0000>ooooo`;o000000?oooooo`000?l00000J?ooool001cooooo00?o0000
ooooooooool0EOooool2o`0000gooooo0_l0000=ooooo`;o00002_ooool2o`0000Gooooo1?l00002
ooooo`?o00000_ooool2o`0000;ooooo0_l00008ooooo`;o000000?oooooo`000?l000004oooool2
o`000003ooooool0003o000008gooooo000Looooo`03o`000?oooooooooo05gooooo0ol00004oooo
o`;o00003Oooool2o`0000[ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l0000?oooo
o`?o000000?oooooo`000?l000000_l000000ooooooo0000o`00000Qooooo`;o00001?ooool2o`00
017ooooo0_l0001Yooooo`007?ooool00ol0003oooooooooo`1Mooooo`?o00001?ooool2o`0001?o
oooo0_l00008ooooo`?o00001oooool2o`0000?ooooo0_l00005ooooo`So000000?oooooo`000?l0
00008Oooool2o`0000;ooooo1?l0000Aooooo`;o0000JOooool001cooooo00?o0000ooooooooool0
FOooool2o`0000Wooooo0_l0000=ooooo`;o00001?ooool3o`0000Gooooo0_l000000ooooooo0000
o`000007ooooo`;o00000oooool2o`0000Oooooo0ol000001?oooooo0000o`000?ooool2o`0001Oo
oooo0_l00004ooooo`;o00001?ooool4o`0000Sooooo0_l0001dooooo`007?ooool00ol0003ooooo
ooooo`1Iooooo`;o00002_ooool2o`0000cooooo0_l00005ooooo`;o00001Oooool2o`0000;ooooo
0_l0000Hooooo`;o000000?oooooo`000?l000000_ooool2o`0001?ooooo0_l00002ooooo`Co0000
1?ooool2o`0000[ooooo0_l00003ooooo`;o000000?oooooo`000?l00000K?ooool001cooooo00?o
0000ooooooooool0F_ooool2o`0000Wooooo0_l0000Aooooo`Co00002Oooool2o`0000Oooooo0_l0
000>ooooo`?o00001Oooool2o`0001Oooooo0_l0000<ooooo`;o00002Oooool2o`000003ooooool0
003o000006cooooo000Looooo`03o`000?oooooooooo05[ooooo0_l00006ooooo`?o00001_ooool2
o`0000_ooooo0_l0000=ooooo`;o00001Oooool3o`0000cooooo1Ol0000Dooooo`;o000000Cooooo
o`000?l0003o00004Oooool2o`0000Kooooo0_l00007ooooo`?o0000J?ooool001cooooo00?o0000
ooooooooool0G?ooool2o`0000Cooooo1?l000000ooooooo0000o`000002ooooo`;o00006_ooool2
o`0000Kooooo0_l00004ooooo`;o00000_ooool6o`000003ooooool0003o000000;o00000oooool2
o`0000;ooooo0_l00009ooooo`;o000000Coooooo`000?l0003o00003oooool2o`0000Sooooo0_l0
0005ooooo`Go0000J?ooool001cooooo00?o0000ooooooooool0G?ooool4o`0000Cooooo0_l00000
0ooooooo0000o`000003ooooo`;o00009oooool2o`000003ooooool0003o000000?o00001?ooool3
o`0000?ooooo0ol000000ooooooo0000o`000008ooooo`;o00001?ooool2o`000003ooooool0003o
000000_ooooo0_l000000ooooooo0000o`00000<ooooo`;o000000?oooooo`000?l00000J?ooool0
01cooooo00?o0000ooooooooool0G_ooool2o`0000_ooooo0ol0000=ooooo`Co00003Oooool2o`00
00Oooooo0_l000000ooooooo0000o`000002o`0000Gooooo0_l00005ooooo`;o00002oooool2o`00
00Cooooo0_l000000ooooooo0000o`00000>ooooo`;o0000NOooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oo
oooooooo06_ooooo0_l0000>ooooo`Co00003Oooool2o`0001[ooooo0_l00006ooooo`Co00001_oo
ool2o`0008gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q
8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1hooooo`;o00004_ooool2o`0002;o
oooo1?l00006ooooo`;o00003Oooool2o`0000Kooooo0_l0001fooooo`0000?ooooooa0@4?ooool0
0_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`1Pooooo`;o00001?ooool2o`0000Sooooo1?l00004ooooo`;o00003Oooool2o`0000?o
oooo0_l0000]ooooo`;o00003?ooool2o`0000Kooooo0_l0001fooooo`0000?oooooo`000?ooool0
0_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`00063o
oooo0_l00004ooooo`;o00002?ooool4o`0000;ooooo1?l0000<ooooo`?o000000?oooooo`000?l0
00001?ooool2o`0002Sooooo1_l0000Booooo`;o0000MOooool00003ooooool0003ooooo00;ooooo
00?o0000ooooooooool02Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000oooooooo
ool0L?ooool3o`000003ooooool0003o000000;o00001?ooool2o`0000Kooooo1Ol000000ooooooo
0000o`000004ooooo`;o0000:?ooool6o`0001;ooooo0_l0001eooooo`0000?ooooooa0@4?ooool0
0_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003o
ooooooooo`1dooooo`?o00001Oooool2o`0000Cooooo1?l000000ooooooo0000o`00000@ooooo`;o
000000?oooooo`000?l000003oooool2o`0001kooooo0_l0001jooooo`0000KoooooogMgMonHV9So
oooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`1b
ooooo`?o000000?oooooo`000?l000002_ooool2o`0000gooooo0_l00003ooooo`;o000000?ooooo
o`000?l000000ol0000?ooooo`;o00000_ooool2o`0000?ooooo0_l0000Cooooo`Co0000N_ooool0
0006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo
00?o0000ooooooooool0L_ooool3o`000003ooooool0003o000000[ooooo0_l0000=ooooo`Co0000
00?oooooo`000?l000000_ooool2o`0000Cooooo0ol0000>ooooo`;o00000oooool2o`0000Cooooo
0_l00008ooooo`;o00000oooool2o`0007cooooo000Looooo`03o`000?oooooooooo07Gooooo0_l0
000;ooooo`;o00003oooool2o`0000_ooooo0ol0000=ooooo`;o00002_ooool2o`0000Sooooo0_l0
0021ooooo`007?ooool00ol0003oooooooooo`1eooooo`;o00003Oooool2o`0000Sooooo0_l0000P
ooooo`;o00000oooool3o`00097ooooo000Looooo`03o`000?oooooooooo08?ooooo0ol000000ooo
oooo0000o`000005ooooo`;o00009Oooool3o`00097ooooo000Looooo`03o`000?oooooooooo083o
oooo1_l000000ooooooo0000o`00000;ooooo`;o00005?ooool2o`0000Wooooo0ol00005ooooo`;o
0000R_ooool001cooooo00?o0000ooooooooool0P?ooool6o`0000kooooo0_l00002ooooo`;o0000
4?ooool2o`0000Wooooo0ol00005ooooo`;o0000R_ooool001cooooo00?o0000ooooooooool0N?oo
ool2o`0001kooooo0_l0000:ooooo`;o00002Oooool4o`0009Kooooo000Looooo`03o`000?oooooo
oooo07Sooooo0_l0000Eooooo`;o00002?ooool2o`0000Kooooo0_l000000ooooooo0000o`000009
ooooo`Co0000U_ooool001cooooo00?o0000ooooooooool0Soooool2o`0000Sooooo0_l00006oooo
o`;o0000Y_ooool001cooooo00?o0000ooooooooool0Ooooool2o`0001Sooooo0_l0000:ooooo`;o
0000X_ooool001cooooo00?o0000ooooooooool0Ooooool2o`0000Wooooo1?l0000:ooooo`?o0000
2_ooool2o`0000;ooooo0_l00006ooooo`;o0000U_ooool001cooooo00?o0000ooooooooool0QOoo
ool2o`0000?ooooo1_l00008ooooo`;o00003_ooool3o`0000Kooooo0_l0002Fooooo`007?ooool2
o`0008Kooooo0_l00007ooooo`?o00004Oooool2o`0000Cooooo0_l0002Oooooo`007?ooool00ol0
003oooooooooo`26ooooo`;o00001oooool3o`0000Wooooo0_l00005ooooo`;o00001_ooool3o`00
09cooooo000Looooo`03o`000?oooooooooo08Kooooo1?l00006ooooo`;o00002Oooool2o`000003
ooooool0003o000000Sooooo1Ol0002Looooo`007?ooool00ol0003oooooooooo`28ooooo`;o0000
1?ooool2o`0000;ooooo0_l00004ooooo`;o00001?ooool2o`0000Kooooo1?l0002Oooooo`007?oo
ool00ol0003oooooooooo`2>ooooo`;o00000_ooool2o`0000?ooooo0ol0000<ooooo`;o00003?oo
ool2o`0009?ooooo000Looooo`03o`000?oooooooooo09Oooooo0_l00003ooooo`;o00005_ooool2
o`0009?ooooo000Looooo`03o`000?oooooooooo09cooooo0_l0002[ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0:;ooooo0_l00008ooooo`;o0000
0_ooool2o`0009Oooooo000Looooo`03o`000?oooooooooo0:;ooooo0_l00008ooooo`;o00000_oo
ool2o`0009Oooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?oo
ooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom:oooo
o`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo
00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o0000ooooooooool0oooo
oomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo
0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`004_ooool00omEEEGoIVIV
o`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Uooooo`04
oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05oooool00ol0003ok^k^ooooo`03oooo
o`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^093ooooo002Vooooo`05o`000?oooooooooo
ooooool000002Oooool6o`0000_ooooo00?oEEEEojVYZOooool00oooool01OnHV9So8B4Qonk^k_oo
ooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`2@ooooo`00Y_ooool01Ol0003ooooooooo
oooooooo000001[ooooo00?oZJVYoeEEEOooool01?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@4100T?ooool00:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko
00003?ooool00olQ8B7oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooo
ooooooooo`00002@ooooo`00Y_ooool01Ol0003oQhN7oooooonYZJWo000001_ooooo00?oEEEEolc<
c?ooool01Oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000T?ooool0
0:Gooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Iooooo`03ojVYZOmgMgOooooo
00Kooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo08kooooo0033oooo
o`05oa0@4?oooooooooooooooolb<S800oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`2@ooooo`00`oooool5o`0000?ooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0T?ooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(726) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.5516 .33132 Mdot
.56443 .35741 Mdot
.30275 .59429 Mdot
.64989 .52128 Mdot
.46196 .60563 Mdot
.33293 .55413 Mdot
.39696 .40903 Mdot
.37341 .44366 Mdot
.31737 .57151 Mdot
.65879 .35068 Mdot
.40189 .39143 Mdot
.60695 .47338 Mdot
.39559 .41976 Mdot
.60646 .56472 Mdot
.21896 .34642 Mdot
.5813 .59471 Mdot
.60124 .3756 Mdot
.47512 .65969 Mdot
.5978 .61307 Mdot
.2981 .57756 Mdot
.57929 .28223 Mdot
.61199 .56596 Mdot
.56614 .3647 Mdot
.60844 .56422 Mdot
.62329 .52325 Mdot
.58107 .33285 Mdot
.54551 .34588 Mdot
.64658 .54001 Mdot
.59869 .54144 Mdot
.42391 .42247 Mdot
.43589 .6264 Mdot
.14476 .48901 Mdot
.56495 .56725 Mdot
.76909 .56416 Mdot
.40006 .4529 Mdot
.39889 .78734 Mdot
.32926 .58359 Mdot
.37558 .39947 Mdot
.3859 .45422 Mdot
.38581 .44544 Mdot
.38414 .43256 Mdot
.57555 .33527 Mdot
.43021 .40337 Mdot
.36317 .36772 Mdot
.66051 .5294 Mdot
.41654 .29922 Mdot
.47063 .75845 Mdot
.64619 .54423 Mdot
.5633 .32286 Mdot
.30054 .56001 Mdot
.81042 .55171 Mdot
.37068 .40422 Mdot
.33577 .30848 Mdot
.19481 .27796 Mdot
.40498 .43949 Mdot
.65317 .52896 Mdot
.34816 .56748 Mdot
.64044 .57377 Mdot
.63055 .56035 Mdot
.7942 .5123 Mdot
.61629 .53943 Mdot
.4938 .69066 Mdot
.55504 .38052 Mdot
.30588 .60532 Mdot
.32417 .56447 Mdot
.41437 .44292 Mdot
.61566 .359 Mdot
.38708 .41676 Mdot
.69622 .55219 Mdot
.30364 .56573 Mdot
.64934 .54517 Mdot
.39587 .38934 Mdot
.62372 .33944 Mdot
.58015 .56791 Mdot
.45363 .30576 Mdot
.26793 .32887 Mdot
.52775 .65206 Mdot
.7632 .49337 Mdot
.68722 .26299 Mdot
.28487 .37598 Mdot
.602 .55649 Mdot
.64182 .19173 Mdot
.23121 .33819 Mdot
.57561 .36742 Mdot
.68704 .64266 Mdot
.26074 .54659 Mdot
.58695 .56983 Mdot
.45834 .54467 Mdot
.62083 .49315 Mdot
.51014 .30302 Mdot
.3189 .57539 Mdot
.572 .32776 Mdot
.65385 .5207 Mdot
.59341 .5877 Mdot
.7425 .36849 Mdot
.59116 .50736 Mdot
.66261 .54856 Mdot
.54156 .33255 Mdot
.41607 .40715 Mdot
.64907 .49082 Mdot
.35645 .36487 Mdot
.32332 .31096 Mdot
.6114 .51118 Mdot
.31821 .55814 Mdot
.58239 .38571 Mdot
.63154 .50604 Mdot
.40791 .44269 Mdot
.61643 .54818 Mdot
.35226 .43924 Mdot
.55536 .34101 Mdot
.59455 .5874 Mdot
.46792 .67212 Mdot
.49253 .28298 Mdot
.59584 .32022 Mdot
.52524 .18456 Mdot
.62538 .54289 Mdot
.62037 .56675 Mdot
.56765 .35808 Mdot
.36359 .55703 Mdot
.44483 .5366 Mdot
.62059 .35746 Mdot
.38496 .45009 Mdot
.55469 .36092 Mdot
.68459 .53874 Mdot
.35627 .54086 Mdot
.32867 .31419 Mdot
.30635 .31614 Mdot
.66423 .74789 Mdot
.58228 .5594 Mdot
.35229 .3214 Mdot
.34743 .54813 Mdot
.5665 .34004 Mdot
.38812 .42062 Mdot
.67046 .57756 Mdot
.60677 .35985 Mdot
.37802 .40585 Mdot
.46689 .68521 Mdot
.34557 .68651 Mdot
.59204 .31384 Mdot
.51923 .47976 Mdot
.4051 .46182 Mdot
.38719 .44526 Mdot
.78645 .60648 Mdot
.57242 .36188 Mdot
.48354 .67068 Mdot
.37944 .40684 Mdot
.62916 .69729 Mdot
.6702 .57618 Mdot
.73433 .65754 Mdot
.68942 .23079 Mdot
.80463 .57348 Mdot
.40417 .22331 Mdot
.50823 .6876 Mdot
.37319 .41948 Mdot
.6284 .51389 Mdot
.58351 .35655 Mdot
.5773 .34987 Mdot
.61572 .59893 Mdot
.62376 .52977 Mdot
.64749 .58914 Mdot
.62248 .5971 Mdot
.44995 .75849 Mdot
.63996 .59332 Mdot
.399 .56502 Mdot
.6125 .33886 Mdot
.61253 .52699 Mdot
.34447 .59103 Mdot
.61978 .60927 Mdot
.37719 .39816 Mdot
.63416 .56388 Mdot
.63289 .52728 Mdot
.5875 .51825 Mdot
.38048 .43114 Mdot
.18001 .58238 Mdot
.64273 .22514 Mdot
.27771 .70857 Mdot
.44432 .21666 Mdot
.35111 .55845 Mdot
.5986 .5745 Mdot
.47935 .69024 Mdot
.58282 .63332 Mdot
.62893 .55703 Mdot
.82021 .5021 Mdot
.63604 .53385 Mdot
.71794 .49972 Mdot
.55229 .58476 Mdot
.25424 .69883 Mdot
.44894 .47195 Mdot
.60145 .54173 Mdot
.68792 .31794 Mdot
.74759 .65842 Mdot
.52293 .6271 Mdot
.39544 .43868 Mdot
.3612 .57973 Mdot
.3458 .57592 Mdot
.43634 .4234 Mdot
.67263 .5055 Mdot
.64647 .37916 Mdot
.68605 .51281 Mdot
.32986 .31965 Mdot
.61612 .37766 Mdot
.51483 .66529 Mdot
.5797 .31176 Mdot
.56843 .15563 Mdot
.51593 .38166 Mdot
.36708 .4527 Mdot
.46276 .67392 Mdot
.31151 .60074 Mdot
.33238 .32422 Mdot
.4781 .68368 Mdot
.65773 .55568 Mdot
.56494 .32518 Mdot
.75658 .65329 Mdot
.58028 .60978 Mdot
.60755 .82445 Mdot
.59289 .37128 Mdot
.45591 .49988 Mdot
.39138 .43192 Mdot
.30956 .54789 Mdot
.58798 .55851 Mdot
.63504 .58918 Mdot
.55044 .37193 Mdot
.64159 .5444 Mdot
.55127 .27859 Mdot
.63751 .52847 Mdot
.30589 .60756 Mdot
.51753 .69819 Mdot
.41661 .38279 Mdot
.68215 .73542 Mdot
.61727 .32068 Mdot
.3765 .60944 Mdot
.30658 .58336 Mdot
.64796 .32972 Mdot
.40968 .39456 Mdot
.46513 .68587 Mdot
.32595 .59095 Mdot
.48989 .71021 Mdot
.59905 .51722 Mdot
.32262 .58355 Mdot
.50261 .66272 Mdot
.30328 .67173 Mdot
.66242 .53794 Mdot
.58558 .6777 Mdot
.39386 .4046 Mdot
.54788 .33367 Mdot
.61536 .53867 Mdot
.30457 .31345 Mdot
.68406 .56632 Mdot
.30282 .28387 Mdot
.32033 .30244 Mdot
.33329 .30763 Mdot
.25994 .36356 Mdot
.4874 .7027 Mdot
.42506 .25808 Mdot
.52718 .44096 Mdot
.61332 .36729 Mdot
.6584 .52402 Mdot
.20695 .63626 Mdot
.3792 .40924 Mdot
.65659 .55622 Mdot
.25412 .56327 Mdot
.38037 .40632 Mdot
.63279 .57658 Mdot
.38761 .43945 Mdot
.58014 .35514 Mdot
.42022 .57482 Mdot
.57717 .37891 Mdot
.65853 .536 Mdot
.41108 .42711 Mdot
.34487 .58621 Mdot
.58297 .33409 Mdot
.6208 .5498 Mdot
.60014 .57127 Mdot
.32599 .32453 Mdot
.60694 .52977 Mdot
.21867 .64032 Mdot
.64844 .54208 Mdot
.32003 .6023 Mdot
.59732 .50166 Mdot
.81344 .59502 Mdot
.35083 .68203 Mdot
.61715 .34031 Mdot
.325 .30384 Mdot
.32517 .57436 Mdot
.42138 .61493 Mdot
.5137 .57315 Mdot
.60838 .55309 Mdot
.31455 .31122 Mdot
.43076 .5141 Mdot
.41693 .43964 Mdot
.63103 .49688 Mdot
.49737 .35478 Mdot
.31283 .59008 Mdot
.33078 .32306 Mdot
.55529 .54373 Mdot
.57776 .38405 Mdot
.64697 .52178 Mdot
.32764 .58656 Mdot
.55153 .35693 Mdot
.67716 .56591 Mdot
.47155 .76772 Mdot
.31002 .30536 Mdot
.39216 .40544 Mdot
.57083 .46578 Mdot
.65816 .58334 Mdot
.35378 .57331 Mdot
.59034 .36594 Mdot
.41486 .4324 Mdot
.58807 .32437 Mdot
.74936 .66595 Mdot
.45513 .22407 Mdot
.37328 .74807 Mdot
.46742 .66533 Mdot
.29818 .27224 Mdot
.29489 .72547 Mdot
.45974 .24476 Mdot
.62125 .74646 Mdot
.39051 .80918 Mdot
.33645 .59315 Mdot
.61356 .66189 Mdot
.33425 .57225 Mdot
.61545 .51334 Mdot
.32825 .55792 Mdot
.23644 .69286 Mdot
.64378 .53588 Mdot
.35257 .56102 Mdot
.43147 .73509 Mdot
.61971 .53327 Mdot
.60694 .3277 Mdot
.17561 .4048 Mdot
.61671 .24234 Mdot
.54683 .41592 Mdot
.35825 .55682 Mdot
.80757 .41941 Mdot
.63481 .53764 Mdot
.58067 .59953 Mdot
.58578 .35165 Mdot
.63007 .49512 Mdot
.5068 .65754 Mdot
.4788 .71201 Mdot
.73286 .64574 Mdot
.55546 .20369 Mdot
.70325 .55952 Mdot
.58225 .33808 Mdot
.69378 .27047 Mdot
.45178 .30864 Mdot
.3118 .32972 Mdot
.39324 .45946 Mdot
.18088 .57825 Mdot
.64589 .63175 Mdot
.51954 .48693 Mdot
.49096 .35184 Mdot
.56302 .33405 Mdot
.26887 .66574 Mdot
.40581 .43465 Mdot
.67786 .2828 Mdot
.68416 .43842 Mdot
.65373 .58185 Mdot
.42757 .41799 Mdot
.62327 .47724 Mdot
.52756 .29113 Mdot
.63485 .67648 Mdot
.33328 .43642 Mdot
.65913 .53263 Mdot
.43136 .2658 Mdot
.62548 .56449 Mdot
.72322 .66344 Mdot
.65904 .54821 Mdot
.59505 .32613 Mdot
.70696 .55382 Mdot
.48441 .56452 Mdot
.6057 .2105 Mdot
.50932 .36523 Mdot
.50693 .69296 Mdot
.60627 .57127 Mdot
.64797 .58489 Mdot
.50533 .68123 Mdot
.59517 .33707 Mdot
.66574 .5579 Mdot
.53771 .78789 Mdot
.65655 .58282 Mdot
.37903 .39243 Mdot
.4364 .58827 Mdot
.59655 .4187 Mdot
.58878 .57995 Mdot
.55783 .37136 Mdot
.39683 .44301 Mdot
.38034 .45298 Mdot
.66846 .61446 Mdot
.37447 .42264 Mdot
.6458 .52361 Mdot
.43175 .58295 Mdot
.55932 .35817 Mdot
.55879 .51368 Mdot
.59914 .34075 Mdot
.75598 .32614 Mdot
.39259 .44485 Mdot
.322 .33344 Mdot
.53347 .58911 Mdot
.40409 .42346 Mdot
.61215 .24989 Mdot
.66634 .6246 Mdot
.66383 .60229 Mdot
.61468 .24746 Mdot
.36246 .57223 Mdot
.33286 .33104 Mdot
.41134 .43698 Mdot
.65162 .58784 Mdot
.60855 .50758 Mdot
.40111 .38794 Mdot
.76649 .39302 Mdot
.42204 .63276 Mdot
.65806 .54534 Mdot
.59641 .32944 Mdot
.56866 .33689 Mdot
.6772 .55771 Mdot
.62968 .5528 Mdot
.33544 .59829 Mdot
.31167 .31224 Mdot
.33675 .31777 Mdot
.30687 .31912 Mdot
.34628 .53269 Mdot
.33142 .26005 Mdot
.38638 .44469 Mdot
.35927 .28142 Mdot
.24514 .51195 Mdot
.64938 .62163 Mdot
.35564 .57482 Mdot
.62874 .58501 Mdot
.60213 .52004 Mdot
.41518 .426 Mdot
.42009 .18991 Mdot
.69025 .50353 Mdot
.5677 .31192 Mdot
.37902 .3882 Mdot
.5473 .59207 Mdot
.45702 .41703 Mdot
.49827 .65688 Mdot
.52253 .38055 Mdot
.42556 .4101 Mdot
.57439 .3227 Mdot
.41327 .39349 Mdot
.64892 .58582 Mdot
.61523 .60302 Mdot
.55917 .34945 Mdot
.48623 .70373 Mdot
.62139 .50283 Mdot
.63183 .57578 Mdot
.85231 .53416 Mdot
.4529 .29951 Mdot
.45398 .41868 Mdot
.60749 .52298 Mdot
.66636 .60382 Mdot
.49782 .70213 Mdot
.66272 .57408 Mdot
.58812 .56137 Mdot
.50282 .27405 Mdot
.4377 .42022 Mdot
.5277 .66089 Mdot
.66938 .27796 Mdot
.5955 .36979 Mdot
.22447 .62815 Mdot
.32337 .30923 Mdot
.43038 .39154 Mdot
.41928 .56765 Mdot
.3237 .33085 Mdot
.26802 .49976 Mdot
.24878 .64573 Mdot
.31559 .32897 Mdot
.38791 .52626 Mdot
.69989 .62462 Mdot
.64617 .59768 Mdot
.63512 .5666 Mdot
.47531 .68872 Mdot
.57648 .3615 Mdot
.43622 .49244 Mdot
.28992 .64738 Mdot
.61507 .56617 Mdot
.53999 .31407 Mdot
.23761 .62221 Mdot
.32772 .32653 Mdot
.48737 .69815 Mdot
.51745 .66394 Mdot
.62368 .56691 Mdot
.49499 .25019 Mdot
.58047 .33513 Mdot
.62073 .55003 Mdot
.60875 .59065 Mdot
.36037 .55969 Mdot
.57361 .32049 Mdot
.30622 .58227 Mdot
.31564 .30124 Mdot
.47878 .83403 Mdot
.84771 .5533 Mdot
.41057 .41111 Mdot
.28004 .69833 Mdot
.36575 .42437 Mdot
.31393 .38112 Mdot
.30876 .31901 Mdot
.61692 .55681 Mdot
.61804 .32451 Mdot
.61841 .54752 Mdot
.65862 .57013 Mdot
.66013 .55927 Mdot
.70389 .55541 Mdot
.82039 .51004 Mdot
.48646 .6799 Mdot
.67572 .59906 Mdot
.37398 .57025 Mdot
.2473 .67322 Mdot
.16887 .44403 Mdot
.61262 .58471 Mdot
.61968 .56997 Mdot
.61299 .35789 Mdot
.58001 .57946 Mdot
.42271 .42911 Mdot
.58017 .36903 Mdot
.6155 .50606 Mdot
.29098 .67933 Mdot
.66706 .57253 Mdot
.30974 .73494 Mdot
.40916 .39096 Mdot
.52898 .38779 Mdot
.69008 .57839 Mdot
.31419 .32836 Mdot
.33169 .33184 Mdot
.31121 .3316 Mdot
.4243 .43414 Mdot
.35579 .56597 Mdot
.27205 .6174 Mdot
.59157 .49093 Mdot
.63245 .51553 Mdot
.67336 .59691 Mdot
.31908 .53972 Mdot
.44594 .57247 Mdot
.40753 .23126 Mdot
.58662 .62805 Mdot
.37217 .56472 Mdot
.5576 .30887 Mdot
.50684 .16944 Mdot
.58375 .36799 Mdot
.52828 .66458 Mdot
.38365 .39287 Mdot
.49661 .65504 Mdot
.81901 .46146 Mdot
.55714 .35007 Mdot
.54868 .36994 Mdot
.35263 .55939 Mdot
.46664 .47143 Mdot
.11083 .40835 Mdot
.32858 .54808 Mdot
.58345 .77813 Mdot
.58643 .34667 Mdot
.57399 .5471 Mdot
.42433 .51817 Mdot
.46813 .47623 Mdot
.33951 .56391 Mdot
.59996 .55951 Mdot
.55081 .21761 Mdot
.32935 .59976 Mdot
.62624 .49756 Mdot
.3571 .54819 Mdot
.38032 .42637 Mdot
.35057 .54844 Mdot
.58417 .30159 Mdot
.59705 .52071 Mdot
.15436 .32736 Mdot
.46046 .37881 Mdot
.61414 .54123 Mdot
.37764 .39069 Mdot
.51975 .79736 Mdot
.65049 .57714 Mdot
.50454 .65539 Mdot
.3752 .55022 Mdot
.41651 .68857 Mdot
.63046 .53821 Mdot
.33647 .55704 Mdot
.5621 .31153 Mdot
.4413 .39013 Mdot
.27448 .35254 Mdot
.33686 .32376 Mdot
.58415 .36091 Mdot
.32356 .34154 Mdot
.41781 .45103 Mdot
.60016 .50593 Mdot
.61787 .59391 Mdot
.60664 .33267 Mdot
.25057 .40609 Mdot
.56915 .54171 Mdot
.6021 .55663 Mdot
.30697 .59518 Mdot
.32478 .53275 Mdot
.20134 .43301 Mdot
.34054 .59123 Mdot
.6688 .60267 Mdot
.60461 .33039 Mdot
.62639 .50951 Mdot
.6107 .3313 Mdot
.65758 .52339 Mdot
.56736 .40692 Mdot
.58127 .36636 Mdot
.50191 .20437 Mdot
.5909 .54373 Mdot
.54021 .53692 Mdot
.66054 .56806 Mdot
.66022 .55316 Mdot
.37442 .54615 Mdot
.49982 .6737 Mdot
.60284 .4949 Mdot
.39943 .59377 Mdot
.47389 .69834 Mdot
.75191 .56786 Mdot
.36213 .56028 Mdot
.47261 .68247 Mdot
.55031 .70385 Mdot
.32604 .30458 Mdot
.48855 .68683 Mdot
.17568 .48237 Mdot
.41246 .41437 Mdot
.56574 .36892 Mdot
.61908 .53247 Mdot
.42606 .828 Mdot
.43307 .62731 Mdot
.31911 .32336 Mdot
.62536 .54099 Mdot
.63477 .58404 Mdot
.59076 .38444 Mdot
.60284 .16893 Mdot
.29002 .57975 Mdot
.64538 .51538 Mdot
.59862 .37569 Mdot
.67954 .22343 Mdot
.34948 .54078 Mdot
.48529 .69088 Mdot
.38891 .38444 Mdot
.59801 .29298 Mdot
.33727 .32609 Mdot
.41166 .44815 Mdot
.35919 .51746 Mdot
.81592 .42088 Mdot
.63537 .54156 Mdot
.34774 .58037 Mdot
.8065 .56773 Mdot
.6427 .49218 Mdot
.43759 .45181 Mdot
.6966 .48953 Mdot
.56526 .33188 Mdot
.39241 .38597 Mdot
.5146 .68286 Mdot
.56043 .36149 Mdot
.59404 .33544 Mdot
.37227 .44048 Mdot
.37174 .5959 Mdot
.4582 .49782 Mdot
.38704 .38761 Mdot
.51364 .29242 Mdot
.75597 .63567 Mdot
.31338 .30974 Mdot
.49013 .69866 Mdot
.76404 .65857 Mdot
.57637 .33376 Mdot
.18099 .57952 Mdot
.81741 .51853 Mdot
.66255 .54852 Mdot
.48608 .66362 Mdot
.26946 .51087 Mdot
.26863 .61764 Mdot
.38316 .40288 Mdot
.4592 .56543 Mdot
.50853 .65373 Mdot
.66311 .58409 Mdot
.59338 .42443 Mdot
.59279 .54408 Mdot
.37687 .41082 Mdot
.56683 .26473 Mdot
.58029 .31965 Mdot
.42325 .44609 Mdot
.53671 .28754 Mdot
.59931 .52309 Mdot
.59295 .55397 Mdot
.69085 .69829 Mdot
.56488 .32409 Mdot
.33837 .32414 Mdot
.60899 .54822 Mdot
.64067 .5716 Mdot
.59521 .50822 Mdot
.53938 .51589 Mdot
.48217 .26621 Mdot
.64362 .51349 Mdot
.34724 .53487 Mdot
.64038 .60738 Mdot
.59116 .55413 Mdot
.58541 .3812 Mdot
.84058 .52717 Mdot
.30944 .30161 Mdot
.63851 .56561 Mdot
.65721 .54761 Mdot
.3873 .45328 Mdot
.44302 .50635 Mdot
.47185 .46773 Mdot
.30824 .56268 Mdot
.61249 .73464 Mdot
.68944 .51975 Mdot
.60459 .36053 Mdot
.47247 .66463 Mdot
.57881 .54396 Mdot
.60544 .36496 Mdot
.6455 .60253 Mdot
.35425 .58935 Mdot
.3128 .31289 Mdot
.55127 .44925 Mdot
.49301 .68734 Mdot
.38385 .50038 Mdot
.38052 .30642 Mdot
.35047 .58833 Mdot
.62672 .51852 Mdot
.41704 .37511 Mdot
.30919 .57869 Mdot
.32422 .32366 Mdot
.55326 .55398 Mdot
.57864 .34696 Mdot
.58191 .32101 Mdot
.72999 .65303 Mdot
.28472 .57586 Mdot
.81512 .36124 Mdot
.3796 .42465 Mdot
.67661 .53071 Mdot
.36431 .33091 Mdot
.58769 .3197 Mdot
.72566 .67959 Mdot
.4725 .68569 Mdot
.38498 .40204 Mdot
.29931 .30658 Mdot
.6089 .3609 Mdot
.57872 .31535 Mdot
.66408 .5372 Mdot
.61249 .58044 Mdot
.61763 .75298 Mdot
.73139 .66013 Mdot
.38477 .43487 Mdot
.49704 .69469 Mdot
.30471 .55977 Mdot
.60448 .52174 Mdot
.57267 .36722 Mdot
.72536 .50949 Mdot
.65072 .59033 Mdot
.32705 .60047 Mdot
.56209 .33956 Mdot
.50397 .6871 Mdot
.47208 .67253 Mdot
.66054 .5537 Mdot
.77907 .50076 Mdot
.40373 .41822 Mdot
.59981 .32142 Mdot
.64206 .33362 Mdot
.57193 .52968 Mdot
.60908 .57914 Mdot
.5943 .47929 Mdot
.41086 .44839 Mdot
.56883 .43973 Mdot
.50485 .64751 Mdot
.57314 .35053 Mdot
.61438 .54325 Mdot
.49335 .69084 Mdot
.5444 .4778 Mdot
.31434 .32546 Mdot
.3553 .54667 Mdot
.50981 .65853 Mdot
.50317 .66723 Mdot
.47056 .69742 Mdot
.17972 .56674 Mdot
.6208 .36798 Mdot
.6625 .26086 Mdot
.6641 .55383 Mdot
.72955 .64904 Mdot
.58555 .58736 Mdot
.42437 .43867 Mdot
.35512 .58204 Mdot
.65681 .57546 Mdot
.66402 .53632 Mdot
.61053 .43341 Mdot
.54364 .57985 Mdot
.56738 .2834 Mdot
.55824 .33311 Mdot
.53726 .54628 Mdot
.36261 .56711 Mdot
.65915 .18886 Mdot
.1603 .59407 Mdot
.69325 .55937 Mdot
.44768 .49328 Mdot
.578 .3682 Mdot
.37324 .43832 Mdot
.47659 .47409 Mdot
.39632 .38204 Mdot
.56949 .3493 Mdot
.61053 .51627 Mdot
.36478 .2811 Mdot
.47972 .70929 Mdot
.64162 .59145 Mdot
.38714 .42833 Mdot
.64468 .59043 Mdot
.42971 .42919 Mdot
.53792 .30137 Mdot
.4877 .33428 Mdot
.638 .53454 Mdot
.57319 .53248 Mdot
.59836 .44006 Mdot
.61303 .58396 Mdot
.2914 .46548 Mdot
.59549 .34677 Mdot
.5514 .21009 Mdot
.67547 .55602 Mdot
.78175 .45821 Mdot
.65239 .59157 Mdot
.24828 .41935 Mdot
.59883 .57928 Mdot
.48886 .51372 Mdot
.66697 .57992 Mdot
.59762 .57237 Mdot
.41055 .43243 Mdot
.38475 .45266 Mdot
.56435 .31086 Mdot
.33746 .33087 Mdot
.25319 .69529 Mdot
.62377 .57695 Mdot
.36429 .5344 Mdot
.37308 .33997 Mdot
.5021 .66947 Mdot
.57026 .345 Mdot
.73085 .24546 Mdot
.39228 .44236 Mdot
.30901 .60663 Mdot
.26479 .41925 Mdot
.2969 .56026 Mdot
.34667 .40327 Mdot
.5365 .57237 Mdot
.50258 .69242 Mdot
.6535 .59178 Mdot
.76692 .55393 Mdot
.43966 .27979 Mdot
.64294 .50448 Mdot
.43506 .43953 Mdot
.58099 .6348 Mdot
.76532 .62951 Mdot
.51157 .69515 Mdot
.51314 .67921 Mdot
.40882 .43688 Mdot
.29962 .58727 Mdot
.66144 .49286 Mdot
.47221 .68158 Mdot
.36566 .57597 Mdot
.33554 .33745 Mdot
.51984 .60229 Mdot
.57783 .3367 Mdot
.54814 .42255 Mdot
.42382 .32567 Mdot
.3866 .4366 Mdot
.40608 .58705 Mdot
.5777 .29361 Mdot
.58257 .38912 Mdot
.32885 .33584 Mdot
.37771 .55012 Mdot
.62583 .34194 Mdot
.61224 .50346 Mdot
.58207 .61197 Mdot
.62436 .56371 Mdot
.47653 .67445 Mdot
.59776 .58165 Mdot
.37753 .56399 Mdot
.38123 .4118 Mdot
.31685 .57804 Mdot
.4044 .41552 Mdot
.36961 .26625 Mdot
.63285 .55017 Mdot
.60805 .57447 Mdot
.4281 .54656 Mdot
.57204 .31321 Mdot
.79741 .49606 Mdot
.37583 .53752 Mdot
.3436 .56988 Mdot
.62231 .50887 Mdot
.55811 .31539 Mdot
.4792 .72032 Mdot
.41552 .52993 Mdot
.60415 .58619 Mdot
.59586 .34812 Mdot
.64053 .51525 Mdot
.37192 .7402 Mdot
.47825 .33242 Mdot
.58765 .32321 Mdot
.58392 .19723 Mdot
.59948 .53355 Mdot
.67116 .64214 Mdot
.66157 .60825 Mdot
.55395 .76534 Mdot
.57936 .51662 Mdot
.59073 .37199 Mdot
.63238 .56272 Mdot
.59547 .36312 Mdot
.31598 .59801 Mdot
.37935 .43959 Mdot
.58703 .35921 Mdot
.58478 .57533 Mdot
.15543 .53712 Mdot
.38489 .42966 Mdot
.60228 .57091 Mdot
.41797 .405 Mdot
.59037 .37697 Mdot
.56413 .31882 Mdot
.17998 .48647 Mdot
.4492 .44173 Mdot
.3873 .43353 Mdot
.64051 .51957 Mdot
.4396 .35141 Mdot
.62719 .50982 Mdot
.62848 .74946 Mdot
.6746 .53831 Mdot
.6002 .49969 Mdot
.2798 .27743 Mdot
.38086 .38071 Mdot
.78131 .3151 Mdot
.29402 .65478 Mdot
.17623 .55143 Mdot
.62603 .3204 Mdot
.51168 .69507 Mdot
.26069 .65491 Mdot
.31724 .3023 Mdot
.36516 .54507 Mdot
.65734 .57547 Mdot
.57783 .41277 Mdot
.38188 .38729 Mdot
.49571 .67174 Mdot
.63704 .53403 Mdot
.34599 .59461 Mdot
.18055 .45417 Mdot
.37322 .41841 Mdot
.57479 .33628 Mdot
.56968 .31275 Mdot
.65828 .22209 Mdot
.61826 .54248 Mdot
.6106 .57209 Mdot
.38145 .39412 Mdot
.6857 .51804 Mdot
.46802 .70032 Mdot
.41212 .74039 Mdot
.39127 .43546 Mdot
.45188 .3701 Mdot
.55469 .34166 Mdot
.63248 .58486 Mdot
.44215 .59198 Mdot
.21616 .52865 Mdot
.67834 .33844 Mdot
.47641 .68873 Mdot
.65015 .72579 Mdot
.5913 .3719 Mdot
.38797 .42393 Mdot
.57466 .66418 Mdot
.68489 .5607 Mdot
.63647 .58128 Mdot
.6563 .72133 Mdot
.43392 .5087 Mdot
.46073 .7176 Mdot
.57626 .57476 Mdot
.43898 .51414 Mdot
.61885 .50923 Mdot
.608 .50834 Mdot
.69477 .55219 Mdot
.58908 .56991 Mdot
.59579 .35491 Mdot
.61561 .42863 Mdot
.34145 .55106 Mdot
.73406 .35366 Mdot
.46856 .55401 Mdot
.6092 .53499 Mdot
.60658 .51833 Mdot
.65313 .31573 Mdot
.37481 .34675 Mdot
.59216 .34454 Mdot
.58041 .40454 Mdot
.39381 .44793 Mdot
.54287 .56408 Mdot
.29178 .56158 Mdot
.65434 .46053 Mdot
.31285 .57476 Mdot
.59678 .34884 Mdot
.34977 .57075 Mdot
.39494 .44966 Mdot
.34626 .58094 Mdot
.34636 .53306 Mdot
.4273 .40738 Mdot
.55356 .3382 Mdot
.60683 .58615 Mdot
.38992 .4434 Mdot
.68679 .70432 Mdot
.47636 .67391 Mdot
.17941 .48537 Mdot
.59206 .60672 Mdot
.72684 .59204 Mdot
.47142 .76734 Mdot
.32499 .5798 Mdot
.4804 .31296 Mdot
.58125 .36619 Mdot
.46055 .68756 Mdot
.59539 .35905 Mdot
.81386 .49338 Mdot
.50379 .68018 Mdot
.17762 .48757 Mdot
.55735 .65986 Mdot
.39495 .62508 Mdot
.60035 .59485 Mdot
.54012 .37862 Mdot
.31065 .58172 Mdot
.37787 .39347 Mdot
.27003 .5337 Mdot
.58308 .55276 Mdot
.45498 .24382 Mdot
.61224 .37774 Mdot
.33197 .31001 Mdot
.38856 .41823 Mdot
.42998 .44704 Mdot
.62402 .54389 Mdot
.41622 .61108 Mdot
.64878 .50952 Mdot
.56351 .64769 Mdot
.62793 .73714 Mdot
.65932 .46257 Mdot
.64854 .52406 Mdot
.30732 .57022 Mdot
.64023 .516 Mdot
.65674 .63768 Mdot
.78456 .6079 Mdot
.59608 .60909 Mdot
.46854 .21507 Mdot
.42718 .6854 Mdot
.5608 .3534 Mdot
.68888 .58412 Mdot
.32045 .31695 Mdot
.60361 .52719 Mdot
.54166 .86822 Mdot
.49095 .68358 Mdot
.27478 .56903 Mdot
.58919 .58644 Mdot
.61332 .54736 Mdot
.75898 .52057 Mdot
.5373 .38721 Mdot
.30078 .30395 Mdot
.64187 .57733 Mdot
.62457 .71814 Mdot
.41807 .42814 Mdot
.68126 .5493 Mdot
.63107 .56588 Mdot
.74195 .68463 Mdot
.42132 .4189 Mdot
.33362 .58016 Mdot
.32263 .3028 Mdot
.30834 .55631 Mdot
.51981 .68322 Mdot
.48113 .45013 Mdot
.73198 .669 Mdot
.4766 .33401 Mdot
.50133 .6529 Mdot
.60337 .59147 Mdot
.7079 .62933 Mdot
.59925 .5486 Mdot
.51336 .68209 Mdot
.42396 .42064 Mdot
.59273 .35444 Mdot
.5434 .44691 Mdot
.32904 .32051 Mdot
.62227 .4978 Mdot
.50746 .69818 Mdot
.58245 .35301 Mdot
.19877 .47228 Mdot
.57142 .35728 Mdot
.40428 .4275 Mdot
.41856 .44792 Mdot
.50049 .68137 Mdot
.59653 .35725 Mdot
.33901 .53864 Mdot
.29539 .65281 Mdot
.67114 .53297 Mdot
.45207 .39959 Mdot
.59904 .30757 Mdot
.54505 .35061 Mdot
.62035 .33842 Mdot
.63455 .54618 Mdot
.44552 .50075 Mdot
.68806 .55248 Mdot
.40463 .44312 Mdot
.36458 .55104 Mdot
.73592 .65621 Mdot
.77402 .53653 Mdot
.46188 .37731 Mdot
.60205 .49592 Mdot
.59057 .56101 Mdot
.62339 .56689 Mdot
.65676 .53996 Mdot
.39969 .74667 Mdot
.63254 .55197 Mdot
.40964 .42343 Mdot
.32321 .55689 Mdot
.62045 .54009 Mdot
.31935 .3139 Mdot
.46344 .50931 Mdot
.47722 .6606 Mdot
.48428 .52049 Mdot
.1662 .58132 Mdot
.58365 .35258 Mdot
.33089 .58963 Mdot
.35756 .54305 Mdot
.46683 .68525 Mdot
.37812 .4259 Mdot
.57532 .35968 Mdot
.54606 .75418 Mdot
.47722 .70232 Mdot
.63955 .56523 Mdot
.42705 .5759 Mdot
.55248 .18405 Mdot
.62177 .59898 Mdot
.65581 .56469 Mdot
.33047 .30522 Mdot
.29061 .57459 Mdot
.42577 .84396 Mdot
.41249 .50682 Mdot
.50009 .67609 Mdot
.51064 .67029 Mdot
.6227 .3469 Mdot
.65052 .50567 Mdot
.39877 .41161 Mdot
.42293 .52388 Mdot
.55067 .80126 Mdot
.24637 .56385 Mdot
.30771 .37953 Mdot
.66608 .57106 Mdot
.73658 .495 Mdot
.65735 .52056 Mdot
.58728 .38591 Mdot
.61858 .35266 Mdot
.58752 .34066 Mdot
.40787 .43385 Mdot
.76054 .33443 Mdot
.40933 .42012 Mdot
.16539 .58566 Mdot
.57531 .37076 Mdot
.36359 .65915 Mdot
.3516 .56551 Mdot
.59418 .49101 Mdot
.49899 .69501 Mdot
.38434 .35616 Mdot
.69757 .56423 Mdot
.48721 .24967 Mdot
.35513 .57505 Mdot
.55892 .32434 Mdot
.63989 .63658 Mdot
.27718 .73297 Mdot
.47357 .44178 Mdot
.47497 .63609 Mdot
.80316 .51034 Mdot
.5046 .68216 Mdot
.66858 .32282 Mdot
.47281 .70537 Mdot
.37894 .40605 Mdot
.58279 .55517 Mdot
.58395 .56445 Mdot
.65304 .52346 Mdot
.63575 .55141 Mdot
.41415 .4352 Mdot
.67099 .55329 Mdot
.81341 .5946 Mdot
.31464 .30564 Mdot
.33028 .68973 Mdot
.48533 .65998 Mdot
.43268 .41745 Mdot
.31501 .56611 Mdot
.33764 .33307 Mdot
.69389 .7276 Mdot
.66874 .56005 Mdot
.65942 .57123 Mdot
.30816 .3245 Mdot
.69179 .53857 Mdot
.64079 .63439 Mdot
.33702 .55345 Mdot
.48998 .40351 Mdot
.51794 .67093 Mdot
.49724 .65527 Mdot
.42241 .40277 Mdot
.59582 .359 Mdot
.47435 .68945 Mdot
.30152 .59095 Mdot
.67397 .57229 Mdot
.57948 .52737 Mdot
.59768 .30702 Mdot
.8175 .51844 Mdot
.49188 .71117 Mdot
.67864 .62021 Mdot
.59571 .36675 Mdot
.61514 .37496 Mdot
.64232 .57901 Mdot
.55773 .56153 Mdot
.54761 .35137 Mdot
.48045 .66133 Mdot
.43189 .41429 Mdot
.38538 .637 Mdot
.37786 .41316 Mdot
.57965 .35881 Mdot
.66825 .59104 Mdot
.55396 .33945 Mdot
.60346 .53063 Mdot
.48149 .11489 Mdot
.5919 .57428 Mdot
.61021 .24511 Mdot
.56359 .76658 Mdot
.35319 .54283 Mdot
.33238 .54103 Mdot
.31551 .31226 Mdot
.59299 .36932 Mdot
.57993 .54047 Mdot
.50997 .67841 Mdot
.17148 .53367 Mdot
.62159 .37883 Mdot
.37173 .56106 Mdot
.29078 .56581 Mdot
.42135 .42855 Mdot
.63981 .59612 Mdot
.62647 .58383 Mdot
.34403 .58117 Mdot
.46326 .76454 Mdot
.60705 .35501 Mdot
.61046 .57154 Mdot
.58997 .55746 Mdot
.33912 .54961 Mdot
.29978 .65703 Mdot
.52719 .34594 Mdot
.58906 .5682 Mdot
.55363 .66669 Mdot
.42468 .43637 Mdot
.64932 .53481 Mdot
.66945 .55117 Mdot
.49483 .66524 Mdot
.32088 .69806 Mdot
.77085 .6239 Mdot
.43339 .42956 Mdot
.33763 .32109 Mdot
.58113 .5718 Mdot
.3502 .56434 Mdot
.57427 .54506 Mdot
.36389 .77436 Mdot
.32066 .30546 Mdot
.62249 .55475 Mdot
.69287 .55406 Mdot
.59867 .31828 Mdot
.62096 .55194 Mdot
.65615 .45588 Mdot
.31606 .55438 Mdot
.62364 .55356 Mdot
.78295 .49599 Mdot
.41774 .43381 Mdot
.69383 .5737 Mdot
.5126 .66528 Mdot
.5493 .7691 Mdot
.39668 .31481 Mdot
.33916 .53186 Mdot
.4762 .66744 Mdot
.60036 .5844 Mdot
.30412 .58982 Mdot
.38343 .38459 Mdot
.46982 .2422 Mdot
.64789 .59811 Mdot
.37859 .4193 Mdot
.38227 .41396 Mdot
.49739 .68196 Mdot
.7342 .26484 Mdot
.69422 .53828 Mdot
.61009 .58449 Mdot
.66775 .77058 Mdot
.61641 .36653 Mdot
.6102 .58606 Mdot
.62893 .59621 Mdot
.39755 .40563 Mdot
.53053 .58429 Mdot
.61151 .26807 Mdot
.43165 .73556 Mdot
.42935 .43031 Mdot
.37819 .53186 Mdot
.30593 .59059 Mdot
.48247 .66227 Mdot
.56101 .34997 Mdot
.5029 .65053 Mdot
.35135 .55398 Mdot
.66089 .55081 Mdot
.39491 .39918 Mdot
.69443 .37892 Mdot
.37033 .40454 Mdot
.32609 .6023 Mdot
.55451 .37085 Mdot
.36012 .32417 Mdot
.72622 .75555 Mdot
.42103 .31417 Mdot
.43349 .40952 Mdot
.50187 .66903 Mdot
.4067 .52747 Mdot
.591 .56023 Mdot
.66824 .29361 Mdot
.62523 .59236 Mdot
.80329 .51429 Mdot
.35903 .58014 Mdot
.3249 .33587 Mdot
.58245 .55446 Mdot
.64314 .7247 Mdot
.43396 .41457 Mdot
.41964 .4337 Mdot
.64962 .55464 Mdot
.40491 .42507 Mdot
.61779 .58037 Mdot
.33219 .54914 Mdot
.74688 .28191 Mdot
.59485 .56642 Mdot
.62875 .61495 Mdot
.43775 .40982 Mdot
.17887 .48545 Mdot
.38162 .54509 Mdot
.74181 .5016 Mdot
.29733 .75652 Mdot
.40294 .42205 Mdot
.6616 .61025 Mdot
.32358 .58487 Mdot
.33205 .30618 Mdot
.38202 .57301 Mdot
.63926 .59008 Mdot
.66428 .5644 Mdot
.62919 .50816 Mdot
.59264 .5528 Mdot
.66205 .29312 Mdot
.57926 .61933 Mdot
.7151 .45637 Mdot
.65928 .56877 Mdot
.63739 .36913 Mdot
.41261 .42569 Mdot
.56344 .28555 Mdot
.4527 .69394 Mdot
.66569 .56096 Mdot
.54625 .3987 Mdot
.43329 .42302 Mdot
.174 .59469 Mdot
.42194 .42387 Mdot
.3227 .57374 Mdot
.37123 .43265 Mdot
.60566 .5307 Mdot
.56954 .33492 Mdot
.32075 .55353 Mdot
.39783 .23979 Mdot
.36857 .5472 Mdot
.61486 .54123 Mdot
.32838 .67392 Mdot
.35528 .54396 Mdot
.47096 .51274 Mdot
.56604 .33878 Mdot
.62995 .71006 Mdot
.6104 .3723 Mdot
.61538 .55451 Mdot
.60952 .55593 Mdot
.33998 .33151 Mdot
.37289 .42059 Mdot
.58765 .37613 Mdot
.85403 .52812 Mdot
.52343 .6635 Mdot
.58704 .33392 Mdot
.56486 .53508 Mdot
.43574 .5025 Mdot
.59796 .32243 Mdot
.5898 .73092 Mdot
.3748 .41558 Mdot
.62411 .33969 Mdot
.56438 .52647 Mdot
.51577 .49879 Mdot
.46866 .70716 Mdot
.36102 .58583 Mdot
.50393 .46948 Mdot
.30604 .57895 Mdot
.43205 .43692 Mdot
.29391 .59102 Mdot
.4176 .42637 Mdot
.61724 .24957 Mdot
.56989 .26575 Mdot
.40496 .3739 Mdot
.41912 .4488 Mdot
.34548 .55845 Mdot
.65737 .54283 Mdot
.4758 .5738 Mdot
.57557 .51705 Mdot
.61083 .60113 Mdot
.41162 .44632 Mdot
.59792 .37212 Mdot
.55531 .35908 Mdot
.53809 .36952 Mdot
.57036 .31538 Mdot
.31358 .56531 Mdot
.48705 .31473 Mdot
.81481 .4687 Mdot
.41153 .39628 Mdot
.36189 .43755 Mdot
.62184 .51066 Mdot
.34902 .56192 Mdot
.32622 .59773 Mdot
.39162 .4072 Mdot
.69516 .33891 Mdot
.66699 .60212 Mdot
.5922 .38186 Mdot
.57411 .37017 Mdot
.59872 .32485 Mdot
.60967 .32098 Mdot
.72818 .30976 Mdot
.37768 .39362 Mdot
.58469 .37086 Mdot
.6405 .55509 Mdot
.66116 .57692 Mdot
.33468 .32179 Mdot
.50086 .65885 Mdot
.5991 .60636 Mdot
.6161 .612 Mdot
.64138 .58056 Mdot
.35586 .54596 Mdot
.5747 .49484 Mdot
.32477 .30825 Mdot
.29027 .58241 Mdot
.31144 .54471 Mdot
.324 .33381 Mdot
.63611 .31539 Mdot
.27156 .73702 Mdot
.645 .51523 Mdot
.60586 .65219 Mdot
.3444 .56549 Mdot
.53892 .25404 Mdot
.58076 .4408 Mdot
.64712 .52536 Mdot
.50702 .55753 Mdot
.3281 .54941 Mdot
.6066 .38512 Mdot
.6209 .58945 Mdot
.30762 .31728 Mdot
.47176 .66659 Mdot
.56818 .5219 Mdot
.32844 .30357 Mdot
.59864 .34929 Mdot
.44234 .6557 Mdot
.62447 .35166 Mdot
.35032 .53975 Mdot
.69461 .57316 Mdot
.11338 .39443 Mdot
.31037 .58508 Mdot
.20437 .57448 Mdot
.55813 .27409 Mdot
.59298 .56669 Mdot
.30643 .58198 Mdot
.59941 .38822 Mdot
.42291 .4384 Mdot
.44221 .52153 Mdot
.57083 .36552 Mdot
.33556 .33477 Mdot
.33307 .32862 Mdot
.33999 .55074 Mdot
.56099 .33282 Mdot
.67517 .54658 Mdot
.61375 .33433 Mdot
.37023 .42813 Mdot
.63161 .52715 Mdot
.25488 .70023 Mdot
.58408 .61378 Mdot
.59833 .36686 Mdot
.30969 .60273 Mdot
.49353 .70361 Mdot
.63891 .53598 Mdot
.22354 .60883 Mdot
.63289 .5968 Mdot
.42153 .41096 Mdot
.53692 .23669 Mdot
.68312 .3811 Mdot
.65876 .54744 Mdot
.61282 .5138 Mdot
.42211 .40116 Mdot
.66008 .54634 Mdot
.62586 .59865 Mdot
.44375 .4389 Mdot
.5911 .31719 Mdot
.62078 .56317 Mdot
.35085 .5894 Mdot
.78358 .56573 Mdot
.57925 .56943 Mdot
.45203 .20991 Mdot
.63615 .71709 Mdot
.54892 .23728 Mdot
.57733 .56091 Mdot
.69458 .70308 Mdot
.60627 .56025 Mdot
.64025 .54336 Mdot
.64746 .51923 Mdot
.71866 .47987 Mdot
.34981 .55731 Mdot
.37448 .56247 Mdot
.46431 .70487 Mdot
.63254 .72024 Mdot
.48506 .66541 Mdot
.42937 .4169 Mdot
.25853 .3674 Mdot
.31638 .30614 Mdot
.59551 .3606 Mdot
.6009 .51649 Mdot
.36085 .53906 Mdot
.63426 .58661 Mdot
.60799 .52494 Mdot
.33862 .54478 Mdot
.30734 .58705 Mdot
.28388 .58438 Mdot
.47705 .7051 Mdot
.58913 .3491 Mdot
.66311 .53816 Mdot
.47458 .69865 Mdot
.67819 .5507 Mdot
.42256 .50858 Mdot
.59017 .34677 Mdot
.61235 .33135 Mdot
.57116 .37633 Mdot
.66407 .55516 Mdot
.60879 .53116 Mdot
.40875 .41838 Mdot
.59865 .30656 Mdot
.4002 .38953 Mdot
.30715 .57773 Mdot
.3393 .54039 Mdot
.6405 .58982 Mdot
.66431 .62938 Mdot
.50897 .66993 Mdot
.32433 .57645 Mdot
.30364 .318 Mdot
.46298 .70106 Mdot
.62646 .5412 Mdot
.3079 .57333 Mdot
.50085 .65563 Mdot
.72464 .36191 Mdot
.34375 .78926 Mdot
.49558 .70453 Mdot
.64827 .55559 Mdot
.76447 .52347 Mdot
.6028 .66868 Mdot
.52191 .65749 Mdot
.40789 .3959 Mdot
.63833 .59528 Mdot
.49342 .79248 Mdot
.51492 .65821 Mdot
.81512 .52787 Mdot
.34676 .54436 Mdot
.5392 .60641 Mdot
.56215 .53349 Mdot
.68814 .30004 Mdot
.50908 .6521 Mdot
.57489 .35579 Mdot
.60687 .3093 Mdot
.64535 .56136 Mdot
.49254 .64457 Mdot
.3759 .45027 Mdot
.35575 .54108 Mdot
.35783 .53376 Mdot
.56534 .32778 Mdot
.46827 .35962 Mdot
.3373 .59654 Mdot
.70234 .53486 Mdot
.38917 .52502 Mdot
.54567 .52811 Mdot
.68361 .25874 Mdot
.38351 .24895 Mdot
.58436 .52109 Mdot
.50341 .69821 Mdot
.40268 .38539 Mdot
.4076 .42082 Mdot
.40313 .43334 Mdot
.32237 .54548 Mdot
.47794 .48239 Mdot
.35389 .57864 Mdot
.45098 .25354 Mdot
.49262 .69146 Mdot
.61659 .70059 Mdot
.57912 .54878 Mdot
.59254 .56365 Mdot
.6796 .56041 Mdot
.62483 .50705 Mdot
.60656 .56177 Mdot
.38501 .4341 Mdot
.30884 .55104 Mdot
.41821 .69692 Mdot
.59933 .33077 Mdot
.21321 .43058 Mdot
.35179 .56576 Mdot
.32661 .30404 Mdot
.48741 .67688 Mdot
.72052 .67107 Mdot
.35836 .52376 Mdot
.34862 .57074 Mdot
.664 .58992 Mdot
.61116 .36399 Mdot
.54058 .50625 Mdot
.60189 .55691 Mdot
.3247 .57771 Mdot
.31753 .60817 Mdot
.66848 .34375 Mdot
.65712 .48216 Mdot
.49536 .71646 Mdot
.44058 .49969 Mdot
.4998 .64778 Mdot
.56123 .57506 Mdot
.53571 .25525 Mdot
.34932 .55422 Mdot
.32327 .56805 Mdot
.5118 .69155 Mdot
.68276 .63508 Mdot
.56001 .34037 Mdot
.32255 .33541 Mdot
.41451 .40412 Mdot
.60135 .55159 Mdot
.31675 .55048 Mdot
.60023 .6483 Mdot
.42365 .57569 Mdot
.39424 .4354 Mdot
.28976 .58111 Mdot
.65557 .58907 Mdot
.65172 .55691 Mdot
.5055 .67836 Mdot
.45484 .61468 Mdot
.56791 .52648 Mdot
.17652 .55234 Mdot
.48815 .34025 Mdot
.50674 .36634 Mdot
.63593 .58138 Mdot
.57014 .32191 Mdot
.3091 .32074 Mdot
.48988 .69913 Mdot
.67621 .56235 Mdot
.31531 .77475 Mdot
.56544 .30143 Mdot
.38466 .42473 Mdot
.30963 .32299 Mdot
.47772 .48523 Mdot
.62995 .59685 Mdot
.62479 .5922 Mdot
.63515 .54869 Mdot
.34015 .7956 Mdot
.36868 .57231 Mdot
.61743 .33061 Mdot
.47617 .68613 Mdot
.59087 .31299 Mdot
.37454 .55683 Mdot
.53155 .43553 Mdot
.62258 .53862 Mdot
.58513 .38314 Mdot
.57244 .3545 Mdot
.4215 .42879 Mdot
.41461 .44792 Mdot
.28124 .56611 Mdot
.59346 .57493 Mdot
.30823 .31186 Mdot
.61444 .36391 Mdot
.29446 .57436 Mdot
.50393 .68132 Mdot
.39363 .44638 Mdot
.6599 .56636 Mdot
.34385 .55267 Mdot
.62503 .50056 Mdot
.61033 .33401 Mdot
.34874 .56995 Mdot
.31462 .29859 Mdot
.50939 .66675 Mdot
.66276 .56436 Mdot
.43641 .68895 Mdot
.3158 .33077 Mdot
.58817 .55151 Mdot
.74439 .57315 Mdot
.45299 .67715 Mdot
.40017 .23598 Mdot
.34181 .58696 Mdot
.32474 .31352 Mdot
.61962 .34738 Mdot
.52755 .49287 Mdot
.3209 .56667 Mdot
.72572 .53149 Mdot
.47095 .59386 Mdot
.66183 .53793 Mdot
.57993 .32828 Mdot
.50252 .72223 Mdot
.17881 .58497 Mdot
.5777 .67215 Mdot
.61324 .56931 Mdot
.30565 .5808 Mdot
.49347 .65505 Mdot
.41718 .40048 Mdot
.45445 .21008 Mdot
.68274 .26342 Mdot
.28677 .57796 Mdot
.64912 .51641 Mdot
.6143 .36359 Mdot
.38995 .40824 Mdot
.36055 .2748 Mdot
.30259 .59357 Mdot
.35105 .58613 Mdot
.63329 .53958 Mdot
.47747 .69456 Mdot
.4534 .76102 Mdot
.37466 .56558 Mdot
.30738 .55579 Mdot
.20641 .43677 Mdot
.49226 .7098 Mdot
.63936 .55777 Mdot
.53816 .36986 Mdot
.66847 .58063 Mdot
.18562 .55124 Mdot
.32179 .3097 Mdot
.60172 .33323 Mdot
.65245 .58653 Mdot
.42538 .68634 Mdot
.3143 .57075 Mdot
.4498 .49226 Mdot
.29463 .60213 Mdot
.38121 .43087 Mdot
.3194 .54917 Mdot
.62405 .58819 Mdot
.4364 .42463 Mdot
.5081 .66812 Mdot
.58915 .56884 Mdot
.6099 .52954 Mdot
.59352 .388 Mdot
.38009 .40201 Mdot
.76126 .60823 Mdot
.39815 .46205 Mdot
.41336 .39371 Mdot
.62734 .35859 Mdot
.64268 .56337 Mdot
.33017 .57435 Mdot
.36086 .58716 Mdot
.67181 .54792 Mdot
.53986 .25715 Mdot
.56276 .33437 Mdot
.2933 .54682 Mdot
.42432 .84109 Mdot
.67664 .50099 Mdot
.30671 .30712 Mdot
.69766 .64913 Mdot
.4204 .4367 Mdot
.65658 .55879 Mdot
.60075 .36233 Mdot
.29915 .56242 Mdot
.34053 .59518 Mdot
.67702 .57274 Mdot
.38408 .40838 Mdot
.48639 .65542 Mdot
.3356 .59376 Mdot
.42132 .5734 Mdot
.62458 .54964 Mdot
.45422 .24187 Mdot
.33184 .59266 Mdot
.15541 .47034 Mdot
.4219 .68966 Mdot
.58746 .32464 Mdot
.61204 .52093 Mdot
.56586 .3118 Mdot
.47705 .68035 Mdot
.39219 .5503 Mdot
.38185 .40904 Mdot
.71189 .53206 Mdot
.78214 .65285 Mdot
.35298 .55911 Mdot
.59581 .35328 Mdot
.66315 .55224 Mdot
.71053 .53779 Mdot
.60071 .58205 Mdot
.52724 .57228 Mdot
.44402 .68537 Mdot
.40776 .45056 Mdot
.4241 .41246 Mdot
.60037 .52235 Mdot
.47071 .70133 Mdot
.38041 .56434 Mdot
.34391 .54474 Mdot
.64942 .17684 Mdot
.31701 .29847 Mdot
.60213 .76291 Mdot
.66263 .55952 Mdot
.29331 .56828 Mdot
.77394 .54065 Mdot
.38158 .39387 Mdot
.6617 .51683 Mdot
.32215 .54034 Mdot
.21516 .5129 Mdot
.42667 .50931 Mdot
.619 .55881 Mdot
.68171 .51184 Mdot
.41781 .40597 Mdot
.4079 .52073 Mdot
.35221 .5788 Mdot
.67673 .53684 Mdot
.40775 .45904 Mdot
.19132 .45828 Mdot
.8068 .62023 Mdot
.58896 .34852 Mdot
.31164 .60469 Mdot
.38211 .43143 Mdot
.60803 .48253 Mdot
.48601 .65938 Mdot
.30516 .563 Mdot
.36345 .54652 Mdot
.62804 .52295 Mdot
.59271 .60268 Mdot
.6802 .50334 Mdot
.59574 .33832 Mdot
.40934 .41262 Mdot
.58411 .5407 Mdot
.47496 .36055 Mdot
.63342 .50796 Mdot
.40574 .41073 Mdot
.26028 .21927 Mdot
.64635 .59947 Mdot
.60538 .58276 Mdot
.49856 .7446 Mdot
.55656 .3552 Mdot
.58172 .31343 Mdot
.48645 .32687 Mdot
.66272 .55994 Mdot
.40656 .62174 Mdot
.58862 .35232 Mdot
.56526 .33252 Mdot
.35502 .6649 Mdot
.63649 .52691 Mdot
.39059 .5111 Mdot
.39809 .41008 Mdot
.38458 .43698 Mdot
.60355 .32214 Mdot
.59148 .49183 Mdot
.39141 .3843 Mdot
.64907 .27265 Mdot
.35549 .56556 Mdot
.53539 .25492 Mdot
.61378 .34913 Mdot
.44921 .60272 Mdot
.37636 .41039 Mdot
.14841 .56578 Mdot
.50539 .5121 Mdot
.65638 .51699 Mdot
.65511 .55224 Mdot
.49751 .66408 Mdot
.66805 .61657 Mdot
.33731 .31899 Mdot
.40561 .427 Mdot
.34559 .73693 Mdot
.58704 .33968 Mdot
.60169 .57924 Mdot
.72515 .65943 Mdot
.38188 .28007 Mdot
.47966 .21341 Mdot
.56229 .35456 Mdot
.5792 .33279 Mdot
.36176 .56966 Mdot
.36227 .55527 Mdot
.63051 .55987 Mdot
.4095 .43133 Mdot
.61841 .32201 Mdot
.40929 .40587 Mdot
.35056 .55344 Mdot
.34324 .57124 Mdot
.32274 .30549 Mdot
.65777 .50222 Mdot
.34662 .54179 Mdot
.19012 .47817 Mdot
.47537 .36588 Mdot
.58851 .39171 Mdot
.71992 .7564 Mdot
.35541 .27378 Mdot
.50797 .75611 Mdot
.46639 .67464 Mdot
.31683 .29328 Mdot
.37787 .44607 Mdot
.6053 .51841 Mdot
.65092 .58137 Mdot
.32728 .32696 Mdot
.37528 .42974 Mdot
.49065 .67159 Mdot
.37268 .42067 Mdot
.48678 .69664 Mdot
.37653 .5422 Mdot
.57959 .56983 Mdot
.61615 .59488 Mdot
.39055 .43719 Mdot
.3381 .57993 Mdot
.35191 .54095 Mdot
.46264 .69514 Mdot
.7086 .67603 Mdot
.34196 .55028 Mdot
.61429 .34692 Mdot
.79572 .42497 Mdot
.33208 .32855 Mdot
.61834 .58833 Mdot
.72868 .66412 Mdot
.67519 .3248 Mdot
.6592 .53019 Mdot
.31049 .32468 Mdot
.67137 .1948 Mdot
.58135 .56178 Mdot
.66466 .20801 Mdot
.32823 .31355 Mdot
.55245 .34645 Mdot
.32216 .58752 Mdot
.33871 .32203 Mdot
.59468 .48609 Mdot
.52808 .66956 Mdot
.59269 .60616 Mdot
.56661 .36288 Mdot
.56284 .37447 Mdot
.53113 .28859 Mdot
.18788 .55376 Mdot
.49229 .70168 Mdot
.49522 .67553 Mdot
.32275 .5633 Mdot
.27797 .31943 Mdot
.56223 .54988 Mdot
.49744 .6735 Mdot
.39249 .76161 Mdot
.62557 .51086 Mdot
.63887 .74438 Mdot
.50548 .55521 Mdot
.56904 .32326 Mdot
.6119 .28132 Mdot
.31775 .56762 Mdot
.59532 .3529 Mdot
.51318 .39904 Mdot
.67921 .56107 Mdot
.58957 .34401 Mdot
.40256 .40744 Mdot
.28521 .49547 Mdot
.56215 .31771 Mdot
.43396 .53145 Mdot
.39814 .412 Mdot
.45571 .67182 Mdot
.5535 .71277 Mdot
.5316 .87996 Mdot
.40672 .42838 Mdot
.32271 .58261 Mdot
.34699 .54082 Mdot
.33612 .54929 Mdot
.57062 .36582 Mdot
.31298 .59681 Mdot
.60162 .33946 Mdot
.27651 .63375 Mdot
.70925 .69173 Mdot
.49989 .68405 Mdot
.45205 .43153 Mdot
.57296 .34436 Mdot
.46582 .28284 Mdot
.74063 .73231 Mdot
.64769 .55365 Mdot
.40275 .46093 Mdot
.5132 .6882 Mdot
.24667 .31901 Mdot
.49339 .66509 Mdot
.32447 .58524 Mdot
.53429 .25424 Mdot
.61738 .57917 Mdot
.67725 .46947 Mdot
.51204 .6738 Mdot
.5649 .35879 Mdot
.58854 .55536 Mdot
.27274 .58832 Mdot
.47784 .66723 Mdot
.47308 .6655 Mdot
.6054 .5649 Mdot
.56088 .3245 Mdot
.33759 .57378 Mdot
.38415 .44999 Mdot
.46087 .71423 Mdot
.61817 .48892 Mdot
.65841 .54044 Mdot
.67782 .53017 Mdot
.46898 .46932 Mdot
.46701 .77698 Mdot
.40172 .42034 Mdot
.64518 .6711 Mdot
.35678 .55042 Mdot
.56341 .66892 Mdot
.45101 .31242 Mdot
.4502 .43288 Mdot
.32291 .30995 Mdot
.31952 .30841 Mdot
.61433 .56049 Mdot
.45384 .77879 Mdot
.54052 .20709 Mdot
.41668 .46691 Mdot
.32621 .33128 Mdot
.35261 .54132 Mdot
.58549 .30021 Mdot
.52054 .31333 Mdot
.59485 .60027 Mdot
.41206 .44827 Mdot
.34698 .54911 Mdot
.36786 .77709 Mdot
.49114 .69004 Mdot
.49489 .29243 Mdot
.61751 .53929 Mdot
.6096 .57414 Mdot
.39213 .41763 Mdot
.40823 .41844 Mdot
.44737 .22482 Mdot
.50083 .32413 Mdot
.24762 .5747 Mdot
.37442 .48576 Mdot
.39805 .79281 Mdot
.54728 .29991 Mdot
.60099 .36464 Mdot
.31934 .30205 Mdot
.41474 .39264 Mdot
.61841 .5912 Mdot
.5526 .35177 Mdot
.48514 .21208 Mdot
.63356 .33971 Mdot
.63756 .73884 Mdot
.41398 .62043 Mdot
.60383 .54108 Mdot
.61363 .3606 Mdot
.59404 .35076 Mdot
.5953 .31196 Mdot
.32176 .33282 Mdot
.63927 .57849 Mdot
.65684 .54274 Mdot
.58374 .55216 Mdot
.6945 .59518 Mdot
.6217 .55087 Mdot
.45047 .32468 Mdot
.45285 .3714 Mdot
.32986 .71647 Mdot
.65959 .52751 Mdot
.37565 .42355 Mdot
.60198 .51447 Mdot
.46787 .69771 Mdot
.65069 .51697 Mdot
.62064 .75511 Mdot
.39709 .43012 Mdot
.69126 .62976 Mdot
.36624 .4814 Mdot
.61682 .53837 Mdot
.50241 .65356 Mdot
.46248 .77349 Mdot
.76354 .64244 Mdot
.20319 .44567 Mdot
.61456 .34487 Mdot
.31526 .53768 Mdot
.36883 .42107 Mdot
.32974 .57306 Mdot
.66707 .52631 Mdot
.31005 .30384 Mdot
.30843 .26908 Mdot
.45116 .58823 Mdot
.6301 .59378 Mdot
.55385 .58448 Mdot
.58333 .32007 Mdot
.31093 .57733 Mdot
.57165 .2892 Mdot
.63836 .54519 Mdot
.47466 .68283 Mdot
.47224 .68951 Mdot
.49908 .35391 Mdot
.29888 .72023 Mdot
.53191 .50049 Mdot
.39426 .41749 Mdot
.33581 .5981 Mdot
.51013 .6531 Mdot
.61997 .25396 Mdot
.37584 .45115 Mdot
.42016 .437 Mdot
.38481 .3996 Mdot
.60039 .54562 Mdot
.33 .31046 Mdot
.3551 .75324 Mdot
.33751 .33231 Mdot
.61372 .53631 Mdot
.36723 .55253 Mdot
.339 .32076 Mdot
.49089 .66324 Mdot
.42325 .40476 Mdot
.35889 .55561 Mdot
.61261 .55384 Mdot
.58412 .34991 Mdot
.709 .6573 Mdot
.55058 .7894 Mdot
.28439 .65597 Mdot
.28979 .66188 Mdot
.57388 .37462 Mdot
.2129 .64207 Mdot
.4519 .39914 Mdot
.6925 .33612 Mdot
.51803 .70143 Mdot
.67158 .5456 Mdot
.79381 .34544 Mdot
.34876 .58112 Mdot
.31737 .55864 Mdot
.6232 .55718 Mdot
.29925 .58102 Mdot
.60123 .58022 Mdot
.36462 .56978 Mdot
.22079 .56274 Mdot
.59419 .59491 Mdot
.3166 .56054 Mdot
.56031 .55447 Mdot
.63251 .53471 Mdot
.57762 .31939 Mdot
.30229 .56387 Mdot
.64962 .51156 Mdot
.27684 .27158 Mdot
.40909 .44084 Mdot
.32603 .33363 Mdot
.45085 .38172 Mdot
.37448 .40945 Mdot
.58923 .33056 Mdot
.58323 .58404 Mdot
.50759 .67503 Mdot
.57723 .35403 Mdot
.28114 .56956 Mdot
.51261 .67811 Mdot
.48475 .31874 Mdot
.61384 .33942 Mdot
.33239 .32477 Mdot
.51004 .67167 Mdot
.62351 .61797 Mdot
.32619 .54785 Mdot
.56529 .79853 Mdot
.33629 .33255 Mdot
.62552 .58426 Mdot
.38768 .55616 Mdot
.37345 .4169 Mdot
.62804 .56639 Mdot
.3049 .58182 Mdot
.31752 .33113 Mdot
.59805 .53868 Mdot
.59044 .54715 Mdot
.51299 .34344 Mdot
.51289 .2273 Mdot
.5048 .67641 Mdot
.60869 .37983 Mdot
.63864 .55502 Mdot
.47174 .70358 Mdot
.2884 .39645 Mdot
.59423 .51581 Mdot
.55904 .31657 Mdot
.6414 .4562 Mdot
.3633 .55447 Mdot
.4042 .39092 Mdot
.33183 .60112 Mdot
.47179 .66585 Mdot
.86834 .51454 Mdot
.33011 .30801 Mdot
.57051 .50706 Mdot
.68159 .55195 Mdot
.34983 .60073 Mdot
.59408 .34613 Mdot
.26703 .53003 Mdot
.66255 .56285 Mdot
.56482 .60261 Mdot
.60644 .57697 Mdot
.41963 .68561 Mdot
.5618 .33734 Mdot
.61174 .58442 Mdot
.61634 .63781 Mdot
.57641 .5662 Mdot
.49606 .65288 Mdot
.59327 .69999 Mdot
.60451 .51112 Mdot
.09496 .45466 Mdot
.30657 .32208 Mdot
.33744 .54566 Mdot
.3999 .5809 Mdot
.33175 .4087 Mdot
.68657 .25896 Mdot
.59901 .33899 Mdot
.57742 .47357 Mdot
.3338 .57368 Mdot
.80281 .59693 Mdot
.20062 .6162 Mdot
.6279 .53454 Mdot
.65651 .58746 Mdot
.3244 .58524 Mdot
.29395 .56925 Mdot
.31208 .30488 Mdot
.66089 .5257 Mdot
.55256 .55774 Mdot
.29865 .59323 Mdot
.61276 .5477 Mdot
.63284 .41207 Mdot
.39749 .45217 Mdot
.59227 .31553 Mdot
.41676 .40002 Mdot
.4157 .44156 Mdot
.75805 .36406 Mdot
.48855 .3394 Mdot
.40738 .41321 Mdot
.38776 .46521 Mdot
.62506 .75657 Mdot
.66908 .47265 Mdot
.4993 .65042 Mdot
.26291 .67172 Mdot
.32964 .55543 Mdot
.64129 .57691 Mdot
.58606 .37398 Mdot
.70473 .31248 Mdot
.25558 .47617 Mdot
.52066 .25688 Mdot
.65328 .54708 Mdot
.31911 .56317 Mdot
.3261 .33491 Mdot
.5927 .59537 Mdot
.56671 .66621 Mdot
.61175 .57223 Mdot
.35237 .53872 Mdot
.78448 .38123 Mdot
.66574 .46486 Mdot
.39363 .52079 Mdot
.59384 .39843 Mdot
.5818 .54185 Mdot
.61062 .34351 Mdot
.37835 .42131 Mdot
.47518 .70403 Mdot
.50208 .6714 Mdot
.59065 .55775 Mdot
.57029 .26533 Mdot
.51226 .57752 Mdot
.63456 .53584 Mdot
.63093 .5243 Mdot
.32603 .31305 Mdot
.63117 .52503 Mdot
.68047 .55051 Mdot
.59433 .52556 Mdot
.59904 .50412 Mdot
.41357 .39355 Mdot
.74326 .55794 Mdot
.61148 .50273 Mdot
.64767 .48064 Mdot
.40266 .44915 Mdot
.56517 .49552 Mdot
.42103 .42506 Mdot
.26294 .70384 Mdot
.4187 .4146 Mdot
.50219 .67449 Mdot
.38593 .54888 Mdot
.54101 .53336 Mdot
.62123 .32732 Mdot
.42062 .444 Mdot
.48395 .68706 Mdot
.40497 .43071 Mdot
.36299 .5812 Mdot
.67848 .77402 Mdot
.63261 .33625 Mdot
.41536 .51528 Mdot
.5127 .53357 Mdot
.45357 .24007 Mdot
.35966 .56429 Mdot
.56831 .32618 Mdot
.65096 .45398 Mdot
.59369 .52818 Mdot
.50649 .66576 Mdot
.61305 .56201 Mdot
.41702 .397 Mdot
.32459 .55774 Mdot
.32036 .67421 Mdot
.50515 .67313 Mdot
.80462 .64598 Mdot
.36595 .54348 Mdot
.63245 .60356 Mdot
.41156 .44969 Mdot
.72501 .75044 Mdot
.4197 .41388 Mdot
.71601 .68607 Mdot
.5411 .34226 Mdot
.80306 .40092 Mdot
.57443 .33478 Mdot
.48631 .20248 Mdot
.26149 .7515 Mdot
.20699 .6051 Mdot
.58299 .35963 Mdot
.33337 .52325 Mdot
.61749 .54258 Mdot
.61887 .50619 Mdot
.69576 .51983 Mdot
.60001 .39035 Mdot
.63494 .55308 Mdot
.33659 .32144 Mdot
.48016 .37718 Mdot
.42456 .74665 Mdot
.33053 .52989 Mdot
.60383 .58415 Mdot
.40809 .44646 Mdot
.3764 .3914 Mdot
.3395 .32548 Mdot
.37607 .44841 Mdot
.63811 .53356 Mdot
.57272 .34128 Mdot
.46592 .58198 Mdot
.47992 .67236 Mdot
.18892 .38692 Mdot
.46079 .71024 Mdot
.31424 .5365 Mdot
.69388 .55856 Mdot
.34435 .57112 Mdot
.84446 .38311 Mdot
.61151 .51266 Mdot
.59018 .3548 Mdot
.59286 .54751 Mdot
.58847 .53137 Mdot
.62849 .50487 Mdot
.30858 .59765 Mdot
.38637 .59404 Mdot
.61038 .54929 Mdot
.38141 .40807 Mdot
.3203 .68732 Mdot
.60832 .60986 Mdot
.2793 .55386 Mdot
.62353 .73257 Mdot
.45618 .25322 Mdot
.58729 .39436 Mdot
.3171 .58044 Mdot
.58401 .33682 Mdot
.61508 .38171 Mdot
.58942 .33058 Mdot
.32671 .73051 Mdot
.53329 .57143 Mdot
.63535 .18698 Mdot
.79641 .47297 Mdot
.70683 .32888 Mdot
.58609 .38148 Mdot
.29459 .43354 Mdot
.5974 .36446 Mdot
.59584 .33477 Mdot
.4297 .12384 Mdot
.59005 .36879 Mdot
.64192 .58884 Mdot
.64881 .59979 Mdot
.40883 .30983 Mdot
.6475 .75021 Mdot
.65368 .52022 Mdot
.63356 .55608 Mdot
.48562 .70329 Mdot
.67615 .6274 Mdot
.34422 .32346 Mdot
.51216 .28331 Mdot
.32115 .28934 Mdot
.60598 .56407 Mdot
.62812 .55478 Mdot
.59997 .49218 Mdot
.26882 .76414 Mdot
.69818 .29628 Mdot
.56107 .37081 Mdot
.54564 .56318 Mdot
.17101 .49663 Mdot
.64495 .59817 Mdot
.60837 .59335 Mdot
.60327 .53116 Mdot
.33148 .57423 Mdot
.5792 .29871 Mdot
.56406 .59846 Mdot
.43231 .26762 Mdot
.62382 .5406 Mdot
.4487 .39776 Mdot
.45204 .7075 Mdot
.62658 .58894 Mdot
.58859 .31166 Mdot
.6396 .51409 Mdot
.61339 .35581 Mdot
.59887 .31887 Mdot
.63284 .4932 Mdot
.33936 .74583 Mdot
.57855 .30559 Mdot
.60946 .53419 Mdot
.33217 .58001 Mdot
.1816 .58404 Mdot
.62734 .5855 Mdot
.48434 .70055 Mdot
.6587 .55523 Mdot
.49553 .65374 Mdot
.62079 .52843 Mdot
.33569 .33429 Mdot
.67402 .38682 Mdot
.32391 .5663 Mdot
.47329 .72603 Mdot
.29561 .58092 Mdot
.52681 .38601 Mdot
.55174 .33447 Mdot
.34543 .32323 Mdot
.65785 .23294 Mdot
.32701 .31431 Mdot
.70978 .65406 Mdot
.24868 .43858 Mdot
.40353 .44334 Mdot
.61243 .32466 Mdot
.65439 .6624 Mdot
.29127 .5412 Mdot
.28362 .57633 Mdot
.30322 .55023 Mdot
.86077 .45958 Mdot
.74039 .27424 Mdot
.60491 .55202 Mdot
.5616 .81081 Mdot
.7116 .44329 Mdot
.57589 .53212 Mdot
.56989 .55916 Mdot
.35465 .53796 Mdot
.57951 .55127 Mdot
.47287 .49811 Mdot
.34642 .55858 Mdot
.48829 .6819 Mdot
.60345 .33539 Mdot
.48492 .65846 Mdot
.25718 .56551 Mdot
.47091 .38076 Mdot
.35509 .5522 Mdot
.59471 .51054 Mdot
.59673 .5551 Mdot
.6178 .34523 Mdot
.57487 .4142 Mdot
.58887 .31605 Mdot
.51305 .6845 Mdot
.3364 .55986 Mdot
.68659 .2924 Mdot
.65612 .5628 Mdot
.57051 .35339 Mdot
.35596 .38077 Mdot
.65233 .55677 Mdot
.38711 .43425 Mdot
.65425 .54496 Mdot
.57958 .36346 Mdot
.63053 .52535 Mdot
.57412 .33924 Mdot
.34713 .57953 Mdot
.65403 .59257 Mdot
.62732 .55756 Mdot
.77353 .62133 Mdot
.48947 .67152 Mdot
.55157 .33813 Mdot
.49049 .48347 Mdot
.66263 .58787 Mdot
.55961 .66385 Mdot
.58008 .56797 Mdot
.60013 .45889 Mdot
.55915 .55187 Mdot
.33557 .32091 Mdot
.64955 .50673 Mdot
.6251 .58518 Mdot
.73587 .53508 Mdot
.77797 .51387 Mdot
.59865 .28777 Mdot
.43299 .42848 Mdot
.58853 .312 Mdot
.33593 .54135 Mdot
.30695 .55351 Mdot
.32357 .59628 Mdot
.67609 .73354 Mdot
.59801 .48855 Mdot
.61937 .57933 Mdot
.41453 .45044 Mdot
.49609 .67768 Mdot
.56633 .35726 Mdot
.49744 .68232 Mdot
.51651 .28018 Mdot
.51484 .67757 Mdot
.33616 .31617 Mdot
.4224 .69042 Mdot
.65729 .30587 Mdot
.49417 .69915 Mdot
.58912 .31573 Mdot
.42168 .61488 Mdot
.67019 .53989 Mdot
.2015 .50287 Mdot
.47445 .68437 Mdot
.85801 .51732 Mdot
.5844 .57448 Mdot
.45119 .51201 Mdot
.41532 .43394 Mdot
.49547 .65672 Mdot
.3789 .40226 Mdot
.62908 .50923 Mdot
.40344 .23269 Mdot
.59562 .35705 Mdot
.43674 .42997 Mdot
.64194 .50471 Mdot
.48759 .6577 Mdot
.35172 .54599 Mdot
.52247 .4745 Mdot
.37951 .43088 Mdot
.75179 .64624 Mdot
.57742 .67202 Mdot
.3385 .5599 Mdot
.55797 .18809 Mdot
.39547 .39432 Mdot
.584 .51974 Mdot
.5581 .48059 Mdot
.64926 .52425 Mdot
.33086 .54083 Mdot
.3088 .57426 Mdot
.42172 .34013 Mdot
.59415 .54958 Mdot
.58315 .57279 Mdot
.57467 .29521 Mdot
.35172 .56127 Mdot
.57676 .32607 Mdot
.61624 .32606 Mdot
.3271 .58352 Mdot
.58551 .32445 Mdot
.51233 .6713 Mdot
.48117 .38104 Mdot
.39873 .39459 Mdot
.38208 .41661 Mdot
.34899 .5424 Mdot
.37355 .57058 Mdot
.34693 .56967 Mdot
.6526 .54405 Mdot
.5572 .34535 Mdot
.61967 .51786 Mdot
.60375 .51057 Mdot
.53963 .34959 Mdot
.56771 .36785 Mdot
.62132 .51402 Mdot
.42831 .61869 Mdot
.47863 .71778 Mdot
.31555 .56249 Mdot
.40945 .40763 Mdot
.80087 .58458 Mdot
.41076 .45214 Mdot
.59423 .58037 Mdot
.21273 .5141 Mdot
.56619 .36114 Mdot
.49425 .66441 Mdot
.50052 .64158 Mdot
.50338 .66624 Mdot
.43801 .4264 Mdot
.60822 .31602 Mdot
.48329 .32264 Mdot
.59548 .57933 Mdot
.47022 .46721 Mdot
.65343 .66708 Mdot
.44886 .29998 Mdot
.40605 .41003 Mdot
.64439 .55569 Mdot
.32866 .31599 Mdot
.66728 .33873 Mdot
.616 .57212 Mdot
.66162 .51765 Mdot
.3963 .65827 Mdot
.65414 .48361 Mdot
.58796 .38959 Mdot
.52577 .2954 Mdot
.67389 .5673 Mdot
.55621 .28632 Mdot
.55912 .12691 Mdot
.58438 .57078 Mdot
.63072 .54738 Mdot
.64624 .5804 Mdot
.60755 .51779 Mdot
.54598 .36367 Mdot
.43905 .62501 Mdot
.41474 .44673 Mdot
.47854 .41915 Mdot
.39533 .39763 Mdot
.31924 .55338 Mdot
.45589 .51349 Mdot
.60765 .32114 Mdot
.50187 .6648 Mdot
.64695 .79076 Mdot
.5315 .27437 Mdot
.3614 .56945 Mdot
.71887 .30601 Mdot
.47715 .67499 Mdot
.67094 .54549 Mdot
.46667 .70853 Mdot
.29414 .56465 Mdot
.38899 .40692 Mdot
.65634 .59556 Mdot
.59142 .3757 Mdot
.5628 .31656 Mdot
.64451 .5533 Mdot
.17325 .53579 Mdot
.37535 .409 Mdot
.38791 .35867 Mdot
.60138 .54393 Mdot
.66314 .51922 Mdot
.59717 .32252 Mdot
.31238 .57286 Mdot
.252 .40134 Mdot
.4847 .67868 Mdot
.59985 .49889 Mdot
.63458 .51077 Mdot
.51225 .29184 Mdot
.42656 .40943 Mdot
.31171 .31877 Mdot
.59845 .54548 Mdot
.48979 .3343 Mdot
.59769 .54393 Mdot
.65081 .62685 Mdot
.34132 .57563 Mdot
.67157 .58831 Mdot
.66617 .57358 Mdot
.67046 .64968 Mdot
.39095 .3933 Mdot
.59138 .34904 Mdot
.55219 .31074 Mdot
.30746 .31713 Mdot
.39202 .43657 Mdot
.62808 .51268 Mdot
.4088 .39225 Mdot
.62532 .50485 Mdot
.61357 .55068 Mdot
.40518 .40938 Mdot
.57753 .3256 Mdot
.27409 .5206 Mdot
.73609 .55615 Mdot
.59846 .52992 Mdot
.66153 .54325 Mdot
.66005 .7414 Mdot
.61959 .21864 Mdot
.66523 .56891 Mdot
.55921 .35691 Mdot
.64967 .55878 Mdot
.38198 .42486 Mdot
.51573 .67892 Mdot
.58565 .35499 Mdot
.3789 .55936 Mdot
.34398 .58196 Mdot
.36434 .47764 Mdot
.33336 .31162 Mdot
.6677 .55273 Mdot
.63219 .32229 Mdot
.57424 .3721 Mdot
.2833 .28631 Mdot
.33481 .54592 Mdot
.51066 .65574 Mdot
.591 .54186 Mdot
.51746 .48207 Mdot
.42191 .43878 Mdot
.09493 .45732 Mdot
.47726 .33281 Mdot
.46036 .67871 Mdot
.5533 .23846 Mdot
.32938 .32102 Mdot
.6339 .59458 Mdot
.46716 .69878 Mdot
.34234 .58784 Mdot
.61979 .50695 Mdot
.64501 .48779 Mdot
.3456 .50335 Mdot
.35127 .5276 Mdot
.40375 .39021 Mdot
.36115 .57945 Mdot
.46413 .67438 Mdot
.33676 .31746 Mdot
.56774 .3192 Mdot
.61816 .58377 Mdot
.54339 .57471 Mdot
.3319 .5495 Mdot
.33287 .3365 Mdot
.60385 .54034 Mdot
.56824 .31248 Mdot
.30745 .58746 Mdot
.60305 .56633 Mdot
.68661 .32473 Mdot
.56689 .39904 Mdot
.33424 .55542 Mdot
.68252 .54778 Mdot
.60628 .44032 Mdot
.37549 .5494 Mdot
.35842 .53995 Mdot
.63441 .55326 Mdot
.51087 .67043 Mdot
.63929 .59628 Mdot
.41832 .42629 Mdot
.38614 .59433 Mdot
.38629 .4285 Mdot
.62073 .66989 Mdot
.68773 .53919 Mdot
.47036 .22678 Mdot
.61643 .35903 Mdot
.52386 .64961 Mdot
.74483 .5241 Mdot
.67264 .53301 Mdot
.24567 .67764 Mdot
.44809 .60094 Mdot
.22002 .35093 Mdot
.38629 .81129 Mdot
.48087 .69306 Mdot
.40336 .43366 Mdot
.63166 .5477 Mdot
.35832 .42522 Mdot
.49637 .69591 Mdot
.63752 .67055 Mdot
.68189 .54785 Mdot
.5637 .33511 Mdot
.61767 .54083 Mdot
.61454 .34657 Mdot
.65454 .55716 Mdot
.58091 .49204 Mdot
.49713 .71675 Mdot
.71887 .68278 Mdot
.66928 .54074 Mdot
.66735 .78549 Mdot
.50859 .47866 Mdot
.47649 .68433 Mdot
.61146 .52523 Mdot
.31898 .3239 Mdot
.37246 .42397 Mdot
.49025 .78456 Mdot
.3382 .57273 Mdot
.41179 .4195 Mdot
.5995 .32728 Mdot
.36261 .58722 Mdot
.30856 .32353 Mdot
.53711 .54292 Mdot
.47712 .66296 Mdot
.40491 .44134 Mdot
.62549 .58666 Mdot
.5946 .58189 Mdot
.4256 .68275 Mdot
.43981 .17156 Mdot
.59976 .30312 Mdot
.79267 .64684 Mdot
.58312 .38661 Mdot
.49433 .67236 Mdot
.34392 .57396 Mdot
.65119 .58695 Mdot
.61977 .56696 Mdot
.31534 .5499 Mdot
.55563 .35474 Mdot
.39093 .53494 Mdot
.74715 .34334 Mdot
.29375 .59906 Mdot
.66142 .70122 Mdot
.58744 .35972 Mdot
.66941 .69774 Mdot
.4674 .66768 Mdot
.33934 .75502 Mdot
.55169 .7548 Mdot
.4137 .44042 Mdot
.65302 .70419 Mdot
.56982 .36134 Mdot
.60191 .55506 Mdot
.33101 .32622 Mdot
.32185 .3062 Mdot
.60766 .33614 Mdot
.32041 .58495 Mdot
.4874 .65893 Mdot
.62626 .54756 Mdot
.47674 .28006 Mdot
.36942 .28894 Mdot
.33289 .59917 Mdot
.61064 .63493 Mdot
.37982 .40382 Mdot
.65809 .54899 Mdot
.47803 .70012 Mdot
.40556 .42121 Mdot
.30901 .29789 Mdot
.48214 .38014 Mdot
.58935 .54358 Mdot
.50136 .35429 Mdot
.39818 .43914 Mdot
.57037 .1862 Mdot
.62558 .56057 Mdot
.39505 .39425 Mdot
.63024 .46831 Mdot
.40114 .2445 Mdot
.49104 .56045 Mdot
.21213 .62183 Mdot
.33296 .5324 Mdot
.33825 .58455 Mdot
.35114 .22676 Mdot
.51863 .70017 Mdot
.4033 .44732 Mdot
.33787 .32021 Mdot
.57148 .71892 Mdot
.38154 .3985 Mdot
.60701 .59396 Mdot
.58051 .56827 Mdot
.74804 .35414 Mdot
.48233 .4991 Mdot
.32837 .33797 Mdot
.57523 .45051 Mdot
.64208 .52818 Mdot
.64694 .61054 Mdot
.63333 .5656 Mdot
.56257 .37401 Mdot
.3748 .40252 Mdot
.66984 .80032 Mdot
.37872 .39496 Mdot
.48338 .28169 Mdot
.32912 .55565 Mdot
.3215 .60219 Mdot
.6235 .58857 Mdot
.51065 .20755 Mdot
.47227 .78608 Mdot
.66323 .54894 Mdot
.46482 .65895 Mdot
.58826 .67281 Mdot
.61381 .61165 Mdot
.55531 .30328 Mdot
.57431 .61185 Mdot
.55442 .37662 Mdot
.40464 .41659 Mdot
.48236 .69513 Mdot
.49378 .71277 Mdot
.40819 .43597 Mdot
.62232 .5786 Mdot
.47178 .6483 Mdot
.60869 .57577 Mdot
.60078 .55051 Mdot
.50712 .28158 Mdot
.51915 .65983 Mdot
.35044 .56825 Mdot
.50311 .6716 Mdot
.59504 .33592 Mdot
.34622 .1495 Mdot
.49583 .68942 Mdot
.57671 .42862 Mdot
.42965 .55678 Mdot
.65769 .70124 Mdot
.56582 .31551 Mdot
.50152 .69741 Mdot
.39116 .3888 Mdot
.21586 .35208 Mdot
.59253 .20469 Mdot
.39688 .45807 Mdot
.6203 .56283 Mdot
.61259 .32684 Mdot
.57368 .37605 Mdot
.39312 .46366 Mdot
.56693 .32386 Mdot
.68508 .58231 Mdot
.59474 .54356 Mdot
.40332 .44722 Mdot
.39753 .31211 Mdot
.37394 .40296 Mdot
.54076 .45139 Mdot
.60685 .53133 Mdot
.58785 .35472 Mdot
.68058 .59718 Mdot
.59041 .29495 Mdot
.31836 .30342 Mdot
.63282 .50564 Mdot
.49828 .66116 Mdot
.47668 .48358 Mdot
.33191 .55679 Mdot
.21586 .51705 Mdot
.61402 .33521 Mdot
.36794 .37772 Mdot
.57831 .31891 Mdot
.6199 .35909 Mdot
.37694 .45082 Mdot
.59808 .34599 Mdot
.62932 .54711 Mdot
.40531 .52699 Mdot
.60905 .35896 Mdot
.39248 .42184 Mdot
.48767 .66059 Mdot
.58224 .32466 Mdot
.36157 .58991 Mdot
.59778 .5597 Mdot
.36381 .55794 Mdot
.49584 .64546 Mdot
.60823 .32081 Mdot
.50462 .69458 Mdot
.33225 .54803 Mdot
.4709 .67105 Mdot
.29635 .65724 Mdot
.40673 .38571 Mdot
.51297 .25934 Mdot
.71279 .50919 Mdot
.59317 .37453 Mdot
.28302 .57555 Mdot
.66051 .57906 Mdot
.59336 .55586 Mdot
.46191 .6868 Mdot
.57553 .37604 Mdot
.18238 .57717 Mdot
.59153 .4564 Mdot
.41927 .34832 Mdot
.42266 .39978 Mdot
.80864 .60823 Mdot
.46838 .35853 Mdot
.20591 .38545 Mdot
.56656 .57403 Mdot
.32966 .32176 Mdot
.60696 .57867 Mdot
.76515 .64154 Mdot
.51713 .67437 Mdot
.28154 .46676 Mdot
.5624 .55055 Mdot
.34186 .56618 Mdot
.65132 .56542 Mdot
.55608 .80884 Mdot
.5892 .61847 Mdot
.48843 .703 Mdot
.43624 .40907 Mdot
.62074 .32623 Mdot
.47904 .67359 Mdot
.35195 .57827 Mdot
.60151 .71644 Mdot
.68263 .55522 Mdot
.64248 .53304 Mdot
.28549 .57212 Mdot
.56448 .33108 Mdot
.32201 .55068 Mdot
.39815 .39469 Mdot
.49475 .68715 Mdot
.60143 .52294 Mdot
.66325 .60247 Mdot
.30836 .60886 Mdot
.37896 .39088 Mdot
.36482 .58289 Mdot
.42269 .4057 Mdot
.33052 .32236 Mdot
.66855 .54731 Mdot
.28752 .57626 Mdot
.57471 .55167 Mdot
.76527 .55976 Mdot
.51855 .26989 Mdot
.76162 .49567 Mdot
.3528 .56693 Mdot
.64145 .72584 Mdot
.39634 .43283 Mdot
.42315 .41277 Mdot
.81451 .45701 Mdot
.45803 .77582 Mdot
.40832 .62098 Mdot
.66798 .77515 Mdot
.39943 .395 Mdot
.38898 .42832 Mdot
.33612 .59026 Mdot
.60203 .34336 Mdot
.55328 .3847 Mdot
.30778 .60419 Mdot
.72727 .66422 Mdot
.56658 .35732 Mdot
.23418 .66271 Mdot
.36891 .54018 Mdot
.56151 .5452 Mdot
.33967 .33942 Mdot
.47614 .6946 Mdot
.72802 .65785 Mdot
.63001 .78854 Mdot
.63655 .59237 Mdot
.70963 .26522 Mdot
.31913 .5767 Mdot
.39518 .50389 Mdot
.28474 .71731 Mdot
.67208 .52647 Mdot
.64689 .57205 Mdot
.62863 .57556 Mdot
.52208 .67038 Mdot
.751 .53717 Mdot
.63303 .59323 Mdot
.70145 .69544 Mdot
.60897 .59767 Mdot
.534 .79362 Mdot
.50305 .67252 Mdot
.52976 .57208 Mdot
.31263 .54127 Mdot
.4431 .27472 Mdot
.69629 .51908 Mdot
.40447 .39355 Mdot
.29443 .53233 Mdot
.39228 .4048 Mdot
.41242 .78434 Mdot
.55358 .75218 Mdot
.56853 .3785 Mdot
.65303 .54672 Mdot
.31209 .54469 Mdot
.61577 .33624 Mdot
.24941 .42726 Mdot
.42062 .12216 Mdot
.39071 .3852 Mdot
.75584 .26698 Mdot
.42393 .41399 Mdot
.31742 .30483 Mdot
.60266 .32696 Mdot
.61802 .26932 Mdot
.4702 .46987 Mdot
.58019 .32652 Mdot
.35059 .47104 Mdot
.55093 .30809 Mdot
.64566 .7158 Mdot
.62549 .35119 Mdot
.39599 .42499 Mdot
.4217 .3868 Mdot
.61824 .47632 Mdot
.66354 .57144 Mdot
.47777 .40317 Mdot
.65348 .47289 Mdot
.66312 .55891 Mdot
.34633 .55872 Mdot
.56236 .21194 Mdot
.3808 .58282 Mdot
.60334 .3604 Mdot
.43087 .42685 Mdot
.64836 .5706 Mdot
.60028 .52892 Mdot
.58108 .52792 Mdot
.77489 .62901 Mdot
.2349 .66018 Mdot
.60997 .55087 Mdot
.63441 .49472 Mdot
.35209 .57594 Mdot
.43507 .6812 Mdot
.7267 .72143 Mdot
.56995 .72877 Mdot
.58958 .56373 Mdot
.49343 .66876 Mdot
.51954 .67295 Mdot
.65518 .60229 Mdot
.47165 .25136 Mdot
.36464 .51788 Mdot
.62602 .58667 Mdot
.53952 .76758 Mdot
.37579 .58207 Mdot
.33792 .33368 Mdot
.33306 .54898 Mdot
.59849 .31385 Mdot
.32442 .30996 Mdot
.30532 .59001 Mdot
.63131 .27528 Mdot
.30825 .31501 Mdot
.40487 .25394 Mdot
.51298 .68473 Mdot
.628 .5668 Mdot
.57596 .29045 Mdot
.32086 .54602 Mdot
.40657 .44054 Mdot
.57818 .34433 Mdot
.38148 .38369 Mdot
.43428 .68864 Mdot
.68303 .66971 Mdot
.33063 .30883 Mdot
.41227 .39957 Mdot
.48658 .38363 Mdot
.49687 .6684 Mdot
.38237 .45516 Mdot
.4975 .2074 Mdot
.59917 .60697 Mdot
.45181 .80265 Mdot
.64519 .53885 Mdot
.16589 .48261 Mdot
.42344 .41622 Mdot
.31193 .30029 Mdot
.61527 .58122 Mdot
.36773 .544 Mdot
.59204 .4788 Mdot
.60806 .57253 Mdot
.37074 .57053 Mdot
.60467 .5529 Mdot
.47593 .70023 Mdot
.5622 .38686 Mdot
.45336 .59748 Mdot
.83331 .54209 Mdot
.46954 .67547 Mdot
.29588 .32193 Mdot
.66475 .56129 Mdot
.34626 .69629 Mdot
.57703 .32827 Mdot
.66453 .51935 Mdot
.78626 .36601 Mdot
.60721 .34616 Mdot
.58214 .33516 Mdot
.62817 .52169 Mdot
.39631 .45456 Mdot
.35374 .54282 Mdot
.49869 .66773 Mdot
.2587 .34137 Mdot
.60234 .56901 Mdot
.64021 .5579 Mdot
.47762 .674 Mdot
.38774 .42874 Mdot
.60542 .52118 Mdot
.23447 .45891 Mdot
.26536 .30473 Mdot
.41583 .44185 Mdot
.60387 .60938 Mdot
.48818 .83255 Mdot
.60182 .4 Mdot
.68237 .22709 Mdot
.50967 .71341 Mdot
.32429 .58166 Mdot
.55894 .53246 Mdot
.10658 .42323 Mdot
.47685 .69374 Mdot
.45301 .29355 Mdot
.60954 .54641 Mdot
.65645 .57145 Mdot
.55661 .32805 Mdot
.6267 .51497 Mdot
.58304 .36668 Mdot
.83912 .53244 Mdot
.7817 .7152 Mdot
.5803 .32005 Mdot
.59787 .36765 Mdot
.62711 .29057 Mdot
.75674 .6395 Mdot
.6017 .33198 Mdot
.68323 .5443 Mdot
.28039 .66846 Mdot
.66245 .50107 Mdot
.47385 .65955 Mdot
.52256 .64245 Mdot
.53836 .31098 Mdot
.50748 .17909 Mdot
.55305 .50889 Mdot
.71588 .58846 Mdot
.51602 .57993 Mdot
.41698 .41438 Mdot
.5844 .54668 Mdot
.33462 .31267 Mdot
.32328 .59795 Mdot
.60751 .6309 Mdot
.62469 .56938 Mdot
.61303 .35475 Mdot
.52305 .66745 Mdot
.3702 .42495 Mdot
.63231 .55617 Mdot
.37994 .53158 Mdot
.48658 .68059 Mdot
.60614 .36198 Mdot
.55525 .41836 Mdot
.49489 .65046 Mdot
.67404 .59788 Mdot
.66145 .56175 Mdot
.60305 .54039 Mdot
.69143 .51091 Mdot
.41016 .43614 Mdot
.32006 .60571 Mdot
.68885 .55843 Mdot
.50551 .29404 Mdot
.43476 .51103 Mdot
.67695 .58267 Mdot
.55647 .34897 Mdot
.41477 .44785 Mdot
.31075 .31325 Mdot
.61564 .70047 Mdot
.58769 .55123 Mdot
.23964 .66462 Mdot
.71656 .31276 Mdot
.32043 .31234 Mdot
.60518 .38083 Mdot
.4989 .66474 Mdot
.63629 .52923 Mdot
.31122 .69528 Mdot
.58709 .57609 Mdot
.65182 .46297 Mdot
.32163 .57944 Mdot
.41312 .40804 Mdot
.25544 .31016 Mdot
.32441 .59801 Mdot
.58346 .33625 Mdot
.16507 .58068 Mdot
.55909 .31035 Mdot
.60842 .31229 Mdot
.35849 .75833 Mdot
.40491 .41385 Mdot
.10108 .44082 Mdot
.61181 .21152 Mdot
.58841 .58169 Mdot
.37819 .41825 Mdot
.6047 .32685 Mdot
.65008 .54417 Mdot
.58234 .37288 Mdot
.58761 .30237 Mdot
.60046 .51616 Mdot
.66007 .56966 Mdot
.71747 .6771 Mdot
.23563 .6846 Mdot
.50724 .66946 Mdot
.55257 .34676 Mdot
.72584 .34679 Mdot
.63632 .59336 Mdot
.59611 .57978 Mdot
.33054 .51212 Mdot
.48956 .70241 Mdot
.64043 .41796 Mdot
.59876 .54731 Mdot
.79732 .37892 Mdot
.66604 .54897 Mdot
.59271 .29002 Mdot
.40238 .454 Mdot
.46894 .25842 Mdot
.33558 .53973 Mdot
.56419 .31173 Mdot
.49574 .6544 Mdot
.54593 .33204 Mdot
.804 .4116 Mdot
.40044 .41065 Mdot
.57952 .36349 Mdot
.38311 .5632 Mdot
.39061 .41169 Mdot
.41666 .43832 Mdot
.31813 .68602 Mdot
.353 .59176 Mdot
.50309 .70081 Mdot
.38786 .40316 Mdot
.69524 .33818 Mdot
.39861 .4233 Mdot
.73823 .3533 Mdot
.66641 .57911 Mdot
.70042 .69065 Mdot
.46349 .34889 Mdot
.69024 .51607 Mdot
.37308 .40635 Mdot
.50348 .68752 Mdot
.64224 .51853 Mdot
.56418 .32626 Mdot
.49318 .69219 Mdot
.41667 .46942 Mdot
.37954 .56424 Mdot
.61106 .37031 Mdot
.41053 .45007 Mdot
.57834 .36596 Mdot
.66714 .6711 Mdot
.26911 .60513 Mdot
.52138 .58618 Mdot
.46177 .48304 Mdot
.5801 .52405 Mdot
.55107 .28864 Mdot
.66712 .58336 Mdot
.61994 .57125 Mdot
.33415 .55491 Mdot
.67689 .73224 Mdot
.57916 .32425 Mdot
.26168 .29229 Mdot
.41713 .4045 Mdot
.53521 .28793 Mdot
.59873 .44389 Mdot
.63234 .50717 Mdot
.60944 .35589 Mdot
.58879 .30121 Mdot
.77813 .51281 Mdot
.31303 .55211 Mdot
.68313 .51297 Mdot
.69396 .55388 Mdot
.58351 .49251 Mdot
.42472 .41837 Mdot
.24365 .47657 Mdot
.30459 .57638 Mdot
.67932 .19638 Mdot
.31401 .5646 Mdot
.37337 .66823 Mdot
.59864 .34695 Mdot
.51489 .66707 Mdot
.5985 .58161 Mdot
.73658 .57522 Mdot
.54658 .36214 Mdot
.37206 .51186 Mdot
.49357 .66286 Mdot
.26329 .50159 Mdot
.40879 .41648 Mdot
.67727 .56245 Mdot
.58988 .52776 Mdot
.61714 .52067 Mdot
.63291 .53825 Mdot
.43273 .42506 Mdot
.60671 .59358 Mdot
.42992 .40633 Mdot
.6774 .31918 Mdot
.80609 .39524 Mdot
.33698 .53569 Mdot
.48544 .77652 Mdot
.59451 .37632 Mdot
.71825 .36093 Mdot
.6354 .40464 Mdot
.51612 .26992 Mdot
.31088 .67049 Mdot
.67145 .56723 Mdot
.31979 .58655 Mdot
.55746 .81088 Mdot
.3107 .54607 Mdot
.82924 .67974 Mdot
.5616 .64619 Mdot
.20463 .62148 Mdot
.64703 .54358 Mdot
.31495 .60782 Mdot
.61874 .4254 Mdot
.64155 .60671 Mdot
.50174 .63701 Mdot
.56305 .4362 Mdot
.41615 .3041 Mdot
.5083 .65359 Mdot
.59857 .562 Mdot
.62235 .32758 Mdot
.62854 .54618 Mdot
.59875 .57914 Mdot
.66182 .55222 Mdot
.36629 .42358 Mdot
.58482 .59215 Mdot
.63529 .59657 Mdot
.45311 .16569 Mdot
.63842 .74189 Mdot
.36726 .56212 Mdot
.77743 .48673 Mdot
.49575 .67809 Mdot
.61607 .34705 Mdot
.44209 .59198 Mdot
.41597 .42596 Mdot
.77752 .52186 Mdot
.64662 .54153 Mdot
.44698 .34362 Mdot
.40876 .45164 Mdot
.4881 .69523 Mdot
.30898 .32157 Mdot
.24044 .63264 Mdot
.32841 .53926 Mdot
.30807 .3091 Mdot
.33032 .55818 Mdot
.70489 .47799 Mdot
.61262 .35404 Mdot
.58472 .52333 Mdot
.38347 .40088 Mdot
.36064 .54335 Mdot
.65181 .75284 Mdot
.63745 .56812 Mdot
.3549 .56488 Mdot
.58255 .52176 Mdot
.42098 .52031 Mdot
.42524 .56749 Mdot
.2921 .5751 Mdot
.42599 .3899 Mdot
.38639 .41391 Mdot
.51295 .67183 Mdot
.61631 .35002 Mdot
.56123 .35744 Mdot
.40277 .41823 Mdot
.71075 .2447 Mdot
.6031 .57291 Mdot
.66322 .55543 Mdot
.49738 .30412 Mdot
.64205 .54711 Mdot
.61615 .72494 Mdot
.34162 .31913 Mdot
.60931 .368 Mdot
.63614 .54187 Mdot
.60365 .52249 Mdot
.59047 .54164 Mdot
.6693 .67378 Mdot
.32705 .55259 Mdot
.64117 .52806 Mdot
.46335 .6932 Mdot
.44974 .22149 Mdot
.65752 .58455 Mdot
.64856 .6078 Mdot
.57627 .3629 Mdot
.81428 .61008 Mdot
.41595 .43472 Mdot
.35559 .55866 Mdot
.37157 .5432 Mdot
.54353 .68135 Mdot
.58489 .39671 Mdot
.34469 .32809 Mdot
.32368 .3924 Mdot
.33422 .33113 Mdot
.4783 .67997 Mdot
.38397 .64126 Mdot
.37675 .52825 Mdot
.36174 .57275 Mdot
.41317 .38924 Mdot
.63202 .53989 Mdot
.66539 .55118 Mdot
.45568 .29212 Mdot
.6563 .52406 Mdot
.49056 .66136 Mdot
.39337 .44823 Mdot
.57522 .36065 Mdot
.47315 .69261 Mdot
.41359 .39776 Mdot
.56289 .33244 Mdot
.61245 .60855 Mdot
.58942 .6032 Mdot
.57819 .33961 Mdot
.60305 .32042 Mdot
.64059 .58752 Mdot
.40965 .18749 Mdot
.62372 .34691 Mdot
.58349 .36202 Mdot
.30583 .32629 Mdot
.32702 .53937 Mdot
.65867 .61729 Mdot
.37739 .41618 Mdot
.60262 .54179 Mdot
.32837 .53725 Mdot
.49696 .6985 Mdot
.56896 .3378 Mdot
.59691 .53394 Mdot
.6076 .55753 Mdot
.49339 .66789 Mdot
.51284 .65194 Mdot
.47614 .66846 Mdot
.36706 .39277 Mdot
.61782 .53386 Mdot
.59824 .32909 Mdot
.40512 .41186 Mdot
.51954 .67253 Mdot
.47589 .71143 Mdot
.48643 .1647 Mdot
.63133 .59239 Mdot
.49599 .56621 Mdot
.28832 .197 Mdot
.59308 .72051 Mdot
.31203 .30691 Mdot
.29572 .59187 Mdot
.68426 .69991 Mdot
.49264 .73016 Mdot
.37719 .42247 Mdot
.49787 .75035 Mdot
.52248 .64863 Mdot
.60428 .51118 Mdot
.65914 .54004 Mdot
.58811 .50507 Mdot
.48931 .68386 Mdot
.65616 .6744 Mdot
.56876 .37286 Mdot
.70047 .41513 Mdot
.49565 .67832 Mdot
.29249 .57576 Mdot
.28891 .57755 Mdot
.31305 .56544 Mdot
.67434 .56178 Mdot
.7697 .51101 Mdot
.70671 .33777 Mdot
.66074 .43152 Mdot
.41139 .42001 Mdot
.58381 .29915 Mdot
.32213 .67434 Mdot
.58089 .33425 Mdot
.31675 .5964 Mdot
.48545 .68591 Mdot
.55325 .3367 Mdot
.39136 .43927 Mdot
.38522 .42523 Mdot
.38006 .55947 Mdot
.3402 .54634 Mdot
.35409 .54941 Mdot
.59126 .31002 Mdot
.59829 .34602 Mdot
.59515 .52956 Mdot
.57028 .34539 Mdot
.67601 .25067 Mdot
.45911 .67837 Mdot
.28753 .56738 Mdot
.39586 .43653 Mdot
.61385 .34041 Mdot
.6265 .5651 Mdot
.41066 .65802 Mdot
.37138 .48913 Mdot
.46698 .68541 Mdot
.34798 .61559 Mdot
.86299 .60676 Mdot
.58354 .53492 Mdot
.42022 .40052 Mdot
.47089 .2404 Mdot
.63513 .57428 Mdot
.33195 .57546 Mdot
.76641 .61874 Mdot
.33236 .33493 Mdot
.63881 .59549 Mdot
.66116 .5198 Mdot
.37505 .44741 Mdot
.43238 .58349 Mdot
.63958 .50967 Mdot
.51012 .39244 Mdot
.37481 .39179 Mdot
.304 .58037 Mdot
.27503 .2713 Mdot
.28738 .59415 Mdot
.72676 .68221 Mdot
.31463 .30768 Mdot
.59196 .52627 Mdot
.3438 .55743 Mdot
.46719 .69496 Mdot
.34476 .55215 Mdot
.59783 .37999 Mdot
.36323 .55473 Mdot
.64582 .55877 Mdot
.59809 .33087 Mdot
.39424 .43834 Mdot
.52108 .30194 Mdot
.46088 .17214 Mdot
.36912 .5446 Mdot
.29924 .3009 Mdot
.6374 .59453 Mdot
.66332 .35808 Mdot
.58807 .48219 Mdot
.66561 .57236 Mdot
.39385 .40457 Mdot
.60817 .35671 Mdot
.4242 .40183 Mdot
.6192 .61535 Mdot
.81071 .48262 Mdot
.42043 .41252 Mdot
.40425 .27715 Mdot
.47711 .6767 Mdot
.72536 .66382 Mdot
.61409 .56901 Mdot
.38783 .39959 Mdot
.61633 .53365 Mdot
.55272 .35394 Mdot
.49609 .45714 Mdot
.4668 .21581 Mdot
.38198 .40277 Mdot
.16486 .53347 Mdot
.49484 .47942 Mdot
.6057 .62208 Mdot
.39424 .39629 Mdot
.7525 .51659 Mdot
.31504 .3211 Mdot
.48352 .6789 Mdot
.51925 .66367 Mdot
.47639 .66266 Mdot
.65818 .52626 Mdot
.57168 .61673 Mdot
.48832 .71046 Mdot
.37728 .38593 Mdot
.47534 .70534 Mdot
.72217 .65468 Mdot
.17871 .55565 Mdot
.47156 .67557 Mdot
.61517 .56306 Mdot
.6378 .60919 Mdot
.6393 .74344 Mdot
.30263 .58517 Mdot
.24875 .68124 Mdot
.64639 .25497 Mdot
.65297 .58471 Mdot
.54017 .5233 Mdot
.59633 .37778 Mdot
.50803 .22452 Mdot
.57809 .45956 Mdot
.42798 .61243 Mdot
.59448 .3661 Mdot
.40839 .54804 Mdot
.61168 .36516 Mdot
.57928 .54024 Mdot
.61465 .54996 Mdot
.5516 .37629 Mdot
.21255 .49971 Mdot
.37858 .24282 Mdot
.17567 .41633 Mdot
.56086 .35863 Mdot
.39055 .39352 Mdot
.39645 .38659 Mdot
.40834 .41162 Mdot
.33546 .541 Mdot
.59109 .31304 Mdot
.62455 .53163 Mdot
.33993 .58204 Mdot
.59215 .56802 Mdot
.38868 .40857 Mdot
.25291 .31364 Mdot
.57662 .36216 Mdot
.62435 .58539 Mdot
.59085 .20521 Mdot
.31922 .56607 Mdot
.49596 .6697 Mdot
.41005 .51206 Mdot
.30616 .60672 Mdot
.3742 .40031 Mdot
.59616 .39827 Mdot
.41801 .37324 Mdot
.44664 .62312 Mdot
.60371 .49185 Mdot
.67994 .56479 Mdot
.27644 .3246 Mdot
.53257 .18338 Mdot
.66162 .5362 Mdot
.3525 .57825 Mdot
.29643 .56213 Mdot
.59266 .54543 Mdot
.57037 .3172 Mdot
.51552 .68857 Mdot
.46889 .66956 Mdot
.63355 .50314 Mdot
.46961 .46603 Mdot
.70909 .68584 Mdot
.61772 .5147 Mdot
.70485 .56601 Mdot
.3747 .57492 Mdot
.30708 .32026 Mdot
.48755 .34287 Mdot
.50577 .65794 Mdot
.60689 .54627 Mdot
.36589 .26064 Mdot
.5866 .36666 Mdot
.35969 .55231 Mdot
.40023 .44557 Mdot
.49646 .63714 Mdot
.37434 .54307 Mdot
.59313 .54486 Mdot
.60492 .52162 Mdot
.37818 .45119 Mdot
.59107 .2899 Mdot
.487 .68673 Mdot
.34118 .5809 Mdot
.51478 .6655 Mdot
.59513 .33903 Mdot
.57863 .35858 Mdot
.69488 .53896 Mdot
.67463 .49674 Mdot
.37151 .54438 Mdot
.6239 .49777 Mdot
.30775 .59322 Mdot
.42791 .68204 Mdot
.42404 .43669 Mdot
.66252 .5164 Mdot
.62974 .35595 Mdot
.39262 .40871 Mdot
.65195 .57912 Mdot
.30376 .33723 Mdot
.61439 .50996 Mdot
.31186 .60665 Mdot
.81572 .47681 Mdot
.50013 .69435 Mdot
.53044 .38599 Mdot
.65388 .64691 Mdot
.64236 .54819 Mdot
.30223 .59285 Mdot
.5564 .53217 Mdot
.42065 .42436 Mdot
.60142 .35614 Mdot
.84446 .38543 Mdot
.39478 .42067 Mdot
.62407 .54628 Mdot
.49391 .68936 Mdot
.61114 .31251 Mdot
.3324 .31456 Mdot
.48196 .33555 Mdot
.60165 .62771 Mdot
.5716 .58262 Mdot
.62998 .54111 Mdot
.67475 .77341 Mdot
.35162 .5563 Mdot
.61026 .33362 Mdot
.4269 .42453 Mdot
.40682 .42631 Mdot
.3121 .57367 Mdot
.42428 .32481 Mdot
.21794 .54136 Mdot
.21741 .25626 Mdot
.3724 .56131 Mdot
.47011 .70512 Mdot
.45713 .50005 Mdot
.32821 .59787 Mdot
.34527 .56221 Mdot
.3801 .55233 Mdot
.4562 .33164 Mdot
.55791 .33955 Mdot
.60644 .55696 Mdot
.58773 .39442 Mdot
.60028 .51747 Mdot
.7073 .72054 Mdot
.40421 .41793 Mdot
.60079 .35468 Mdot
.29332 .33259 Mdot
.63277 .46571 Mdot
.64337 .57128 Mdot
.26509 .62935 Mdot
.56735 .60051 Mdot
.63789 .70465 Mdot
.67312 .60078 Mdot
.3354 .55058 Mdot
.53576 .55561 Mdot
.56059 .52971 Mdot
.63504 .24489 Mdot
.38815 .43363 Mdot
.32406 .30414 Mdot
.60454 .60521 Mdot
.65566 .62465 Mdot
.61054 .31265 Mdot
.55314 .33656 Mdot
.49141 .70939 Mdot
.43168 .49067 Mdot
.39112 .43676 Mdot
.24098 .55187 Mdot
.66359 .56807 Mdot
.37835 .47354 Mdot
.81534 .44587 Mdot
.64865 .58109 Mdot
.30129 .6816 Mdot
.77796 .51916 Mdot
.63531 .50869 Mdot
.68955 .44391 Mdot
.39319 .43031 Mdot
.79417 .37502 Mdot
.58876 .50853 Mdot
.33158 .57467 Mdot
.60228 .34626 Mdot
.60355 .37514 Mdot
.46902 .68611 Mdot
.65269 .23746 Mdot
.40266 .37967 Mdot
.59988 .34906 Mdot
.63098 .57278 Mdot
.40854 .43966 Mdot
.32713 .30797 Mdot
.57386 .59817 Mdot
.41911 .76813 Mdot
.57085 .35047 Mdot
.65857 .50117 Mdot
.37176 .33617 Mdot
.43333 .52497 Mdot
.24069 .69876 Mdot
.40823 .40871 Mdot
.49788 .65529 Mdot
.67643 .5988 Mdot
.32145 .38836 Mdot
.56833 .53528 Mdot
.69752 .70892 Mdot
.5269 .35086 Mdot
.51595 .67806 Mdot
.63074 .579 Mdot
.64148 .51089 Mdot
.47008 .48439 Mdot
.5126 .65354 Mdot
.63247 .50635 Mdot
.69051 .52502 Mdot
.56342 .33346 Mdot
.33886 .31336 Mdot
.57137 .35646 Mdot
.62134 .56244 Mdot
.53423 .54194 Mdot
.56071 .32551 Mdot
.2414 .59723 Mdot
.52884 .66134 Mdot
.41706 .42483 Mdot
.67108 .62237 Mdot
.66721 .57649 Mdot
.46162 .85111 Mdot
.31805 .30351 Mdot
.75693 .68074 Mdot
.30535 .60471 Mdot
.3067 .2805 Mdot
.32791 .61041 Mdot
.19437 .60662 Mdot
.50148 .32955 Mdot
.61281 .49361 Mdot
.52263 .76063 Mdot
.67536 .43493 Mdot
.39982 .38369 Mdot
.68223 .34639 Mdot
.66351 .5718 Mdot
.60282 .57912 Mdot
.33079 .58962 Mdot
.42656 .33683 Mdot
.4668 .24632 Mdot
.4768 .42885 Mdot
.48333 .6908 Mdot
.59356 .34599 Mdot
.65103 .55561 Mdot
.21309 .43438 Mdot
.36796 .55829 Mdot
.51848 .47335 Mdot
.61928 .58326 Mdot
.48423 .27211 Mdot
.42874 .29232 Mdot
.4087 .44083 Mdot
.29886 .59414 Mdot
.31989 .60536 Mdot
.58053 .56315 Mdot
.38569 .43732 Mdot
.60031 .52162 Mdot
.50848 .46459 Mdot
.64146 .49731 Mdot
.48205 .69894 Mdot
.60546 .5891 Mdot
.47983 .52996 Mdot
.18717 .62856 Mdot
.55915 .59578 Mdot
.62042 .34275 Mdot
.33396 .54239 Mdot
.31773 .56166 Mdot
.56192 .35872 Mdot
.3148 .56581 Mdot
.70646 .42402 Mdot
.78402 .38659 Mdot
.47656 .68882 Mdot
.64814 .36779 Mdot
.48851 .69753 Mdot
.32398 .3038 Mdot
.63874 .59082 Mdot
.32832 .41755 Mdot
.37372 .55767 Mdot
.78593 .6082 Mdot
.40122 .42414 Mdot
.31843 .30404 Mdot
.59252 .58998 Mdot
.38302 .64418 Mdot
.31755 .59306 Mdot
.26378 .56002 Mdot
.59035 .54108 Mdot
.55438 .34357 Mdot
.6403 .5109 Mdot
.66382 .5121 Mdot
.30828 .31006 Mdot
.62947 .54017 Mdot
.41289 .3972 Mdot
.58738 .31197 Mdot
.19851 .60161 Mdot
.32522 .54366 Mdot
.60785 .58702 Mdot
.63131 .57349 Mdot
.55043 .3493 Mdot
.60732 .5964 Mdot
.37595 .422 Mdot
.08249 .50126 Mdot
.47773 .6773 Mdot
.31081 .32661 Mdot
.2575 .56492 Mdot
.65668 .54108 Mdot
.62889 .51183 Mdot
.27165 .32558 Mdot
.42543 .20672 Mdot
.4103 .39639 Mdot
.68882 .55089 Mdot
.35275 .57463 Mdot
.49038 .69318 Mdot
.37223 .42832 Mdot
.6023 .53739 Mdot
.60492 .58177 Mdot
.48013 .69853 Mdot
.28251 .66567 Mdot
.38855 .52186 Mdot
.4106 .41658 Mdot
.55279 .48617 Mdot
.41553 .65933 Mdot
.60535 .57289 Mdot
.18044 .46243 Mdot
.58436 .36032 Mdot
.40023 .39719 Mdot
.7458 .54067 Mdot
.58665 .52089 Mdot
.37511 .3999 Mdot
.39206 .43665 Mdot
.58391 .57643 Mdot
.58772 .39643 Mdot
.59127 .30729 Mdot
.58654 .36289 Mdot
.81892 .48597 Mdot
.59676 .78241 Mdot
.3545 .54867 Mdot
.39093 .43002 Mdot
.29529 .55929 Mdot
.51503 .69148 Mdot
.43643 .50952 Mdot
.29339 .56686 Mdot
.60077 .37564 Mdot
.28664 .57136 Mdot
.60671 .51696 Mdot
.38723 .43533 Mdot
.36156 .57391 Mdot
.65222 .53605 Mdot
.7084 .55572 Mdot
.49571 .53069 Mdot
.51463 .68896 Mdot
.41343 .53103 Mdot
.62443 .55261 Mdot
.30984 .31344 Mdot
.63408 .58888 Mdot
.40385 .44732 Mdot
.47019 .53663 Mdot
.64658 .53283 Mdot
.37315 .54667 Mdot
.46238 .62123 Mdot
.30072 .57888 Mdot
.68311 .5302 Mdot
.62108 .56148 Mdot
.6047 .57479 Mdot
.64153 .51005 Mdot
.41075 .28985 Mdot
.42957 .40723 Mdot
.68458 .61614 Mdot
.36339 .53056 Mdot
.57594 .3341 Mdot
.55497 .36347 Mdot
.41223 .61784 Mdot
.3049 .3124 Mdot
.38062 .42441 Mdot
.60356 .57196 Mdot
.26483 .55868 Mdot
.24734 .32209 Mdot
.17653 .44935 Mdot
.33804 .68203 Mdot
.35638 .57671 Mdot
.61909 .33957 Mdot
.35452 .58546 Mdot
.58608 .5687 Mdot
.66173 .60649 Mdot
.20401 .61169 Mdot
.39193 .46621 Mdot
.4866 .68519 Mdot
.59211 .56981 Mdot
.73111 .66953 Mdot
.35199 .576 Mdot
.37179 .57853 Mdot
.59155 .53003 Mdot
.57495 .30534 Mdot
.23148 .7156 Mdot
.40045 .44633 Mdot
.6671 .35475 Mdot
.53959 .39146 Mdot
.56461 .43976 Mdot
.40785 .43525 Mdot
.50475 .55525 Mdot
.30579 .56654 Mdot
.6505 .2523 Mdot
.57545 .33875 Mdot
.48872 .68078 Mdot
.67814 .5845 Mdot
.60477 .37381 Mdot
.29588 .59461 Mdot
.60387 .3685 Mdot
.58452 .527 Mdot
.40869 .3894 Mdot
.30961 .57426 Mdot
.4356 .41472 Mdot
.54981 .37414 Mdot
.49266 .69743 Mdot
.72738 .64955 Mdot
.67195 .34162 Mdot
.77764 .52001 Mdot
.64074 .52814 Mdot
.28141 .551 Mdot
.61703 .53149 Mdot
.60269 .30816 Mdot
.61423 .56795 Mdot
.55635 .28517 Mdot
.32452 .60157 Mdot
.65208 .49881 Mdot
.62687 .59693 Mdot
.66435 .28691 Mdot
.645 .57661 Mdot
.5901 .58705 Mdot
.65803 .51895 Mdot
.52789 .37381 Mdot
.68082 .5144 Mdot
.5561 .33849 Mdot
.45301 .30291 Mdot
.34256 .56251 Mdot
.47867 .71429 Mdot
.47546 .66106 Mdot
.69862 .70453 Mdot
.72571 .6656 Mdot
.42989 .32738 Mdot
.56346 .353 Mdot
.3894 .38997 Mdot
.59891 .52329 Mdot
.73274 .5219 Mdot
.53684 .65801 Mdot
.30611 .56867 Mdot
.3604 .53648 Mdot
.65605 .4844 Mdot
.65563 .79164 Mdot
.67168 .50792 Mdot
.48115 .32616 Mdot
.61451 .50336 Mdot
.66124 .51644 Mdot
.38424 .56223 Mdot
.69974 .66169 Mdot
.64133 .52828 Mdot
.61063 .31266 Mdot
.49015 .67586 Mdot
.54903 .5048 Mdot
.53775 .64231 Mdot
.50695 .49985 Mdot
.62544 .26378 Mdot
.62783 .53555 Mdot
.3328 .58151 Mdot
.61259 .3672 Mdot
.50405 .30024 Mdot
.40304 .40949 Mdot
.48079 .3589 Mdot
.6845 .31145 Mdot
.28271 .62133 Mdot
.48684 .6807 Mdot
.30182 .67608 Mdot
.64566 .5584 Mdot
.34066 .54046 Mdot
.58821 .52683 Mdot
.24125 .32853 Mdot
.50381 .69464 Mdot
.54379 .35816 Mdot
.39015 .39304 Mdot
.55866 .36078 Mdot
.76408 .4946 Mdot
.53094 .61286 Mdot
.29163 .28057 Mdot
.32111 .54249 Mdot
.74733 .62171 Mdot
.60733 .33731 Mdot
.59862 .53603 Mdot
.24045 .23789 Mdot
.58584 .35866 Mdot
.5552 .35393 Mdot
.43 .61209 Mdot
.6227 .67013 Mdot
.5546 .54455 Mdot
.59905 .37191 Mdot
.29858 .55289 Mdot
.50474 .67092 Mdot
.64335 .52134 Mdot
.65378 .51646 Mdot
.5556 .33057 Mdot
.31486 .59415 Mdot
.74256 .66675 Mdot
.33789 .54817 Mdot
.56827 .32681 Mdot
.32342 .56663 Mdot
.26259 .5464 Mdot
.36165 .56447 Mdot
.64255 .59667 Mdot
.60368 .57022 Mdot
.41187 .74648 Mdot
.57854 .35845 Mdot
.63724 .51499 Mdot
.60702 .55004 Mdot
.60219 .33126 Mdot
.36669 .52715 Mdot
.75317 .5759 Mdot
.65128 .54607 Mdot
.60342 .56207 Mdot
.51636 .66985 Mdot
.40326 .57273 Mdot
.20747 .42546 Mdot
.64124 .51875 Mdot
.46437 .68067 Mdot
.59619 .31149 Mdot
.63757 .58768 Mdot
.71941 .65799 Mdot
.38834 .56479 Mdot
.59284 .58192 Mdot
.33375 .31518 Mdot
.66296 .54747 Mdot
.22755 .71016 Mdot
.61579 .59139 Mdot
.60115 .32398 Mdot
.60602 .34646 Mdot
.38413 .51002 Mdot
.58481 .3385 Mdot
.31821 .30655 Mdot
.38856 .41027 Mdot
.1664 .46743 Mdot
.32247 .30779 Mdot
.6741 .53138 Mdot
.61215 .21163 Mdot
.61283 .49901 Mdot
.62124 .60637 Mdot
.75858 .63625 Mdot
.32014 .30887 Mdot
.61103 .35007 Mdot
.21444 .4955 Mdot
.6583 .51091 Mdot
.3968 .44569 Mdot
.65123 .60573 Mdot
.59689 .58609 Mdot
.53802 .42568 Mdot
.80482 .51044 Mdot
.40278 .44934 Mdot
.64448 .6218 Mdot
.64016 .51871 Mdot
.49087 .19134 Mdot
.63438 .56719 Mdot
.47004 .67953 Mdot
.57213 .36634 Mdot
.35931 .58419 Mdot
.48421 .67029 Mdot
.65385 .55001 Mdot
.49192 .68146 Mdot
.35615 .55122 Mdot
.39411 .40194 Mdot
.59874 .5834 Mdot
.48074 .65482 Mdot
.48556 .68971 Mdot
.616 .52568 Mdot
.60141 .35055 Mdot
.56095 .50429 Mdot
.64079 .58632 Mdot
.59576 .54145 Mdot
.56133 .35748 Mdot
.59093 .16445 Mdot
.57934 .55299 Mdot
.49648 .56062 Mdot
.55972 .376 Mdot
.33835 .33668 Mdot
.35553 .58325 Mdot
.5739 .54187 Mdot
.40764 .42076 Mdot
.39844 .41249 Mdot
.31679 .53609 Mdot
.54982 .33184 Mdot
.30761 .58812 Mdot
.58611 .61204 Mdot
.67095 .49512 Mdot
.68911 .56334 Mdot
.84598 .39131 Mdot
.24154 .63865 Mdot
.58402 .31378 Mdot
.30318 .57299 Mdot
.47623 .42418 Mdot
.38143 .42295 Mdot
.2899 .55526 Mdot
.62841 .35772 Mdot
.6108 .32597 Mdot
.59614 .37573 Mdot
.50923 .6629 Mdot
.32981 .54734 Mdot
.56987 .29307 Mdot
.56463 .31052 Mdot
.59464 .5324 Mdot
.63878 .51815 Mdot
.53408 .32822 Mdot
.62861 .74223 Mdot
.48766 .69975 Mdot
.32868 .57955 Mdot
.4259 .8551 Mdot
.40515 .44692 Mdot
.66282 .28421 Mdot
.65272 .53798 Mdot
.43509 .10745 Mdot
.69064 .53645 Mdot
.63216 .57101 Mdot
.59727 .31321 Mdot
.45976 .69494 Mdot
.50206 .67956 Mdot
.60724 .33849 Mdot
.55131 .38177 Mdot
.48473 .65915 Mdot
.33418 .68662 Mdot
.15431 .5141 Mdot
.49371 .32199 Mdot
.59819 .32377 Mdot
.66603 .33705 Mdot
.3738 .41631 Mdot
.56191 .38222 Mdot
.40712 .44881 Mdot
.34494 .56331 Mdot
.36197 .53974 Mdot
.38173 .45376 Mdot
.58834 .54736 Mdot
.36179 .55646 Mdot
.59573 .62645 Mdot
.22457 .61313 Mdot
.40557 .79079 Mdot
.39869 .20957 Mdot
.66721 .55119 Mdot
.47017 .25362 Mdot
.43825 .24947 Mdot
.63516 .55056 Mdot
.64372 .46451 Mdot
.48822 .68351 Mdot
.55608 .37664 Mdot
.37933 .42944 Mdot
.25499 .70754 Mdot
.60475 .57253 Mdot
.57824 .32422 Mdot
.38428 .43043 Mdot
.27438 .52774 Mdot
.51331 .39916 Mdot
.59076 .52876 Mdot
.13228 .35712 Mdot
.5466 .36577 Mdot
.35911 .58449 Mdot
.61163 .22667 Mdot
.58552 .39253 Mdot
.42614 .6464 Mdot
.34299 .59798 Mdot
.18878 .40042 Mdot
.61584 .34399 Mdot
.37932 .52445 Mdot
.59266 .33819 Mdot
.47477 .69821 Mdot
.59581 .39749 Mdot
.31274 .57804 Mdot
.63593 .57947 Mdot
.31394 .57285 Mdot
.48258 .70161 Mdot
.34375 .53825 Mdot
.37795 .42803 Mdot
.31264 .30877 Mdot
.38477 .42024 Mdot
.42953 .51519 Mdot
.80016 .49492 Mdot
.41316 .40846 Mdot
.25405 .58826 Mdot
.66112 .53672 Mdot
.59672 .29116 Mdot
.36395 .58101 Mdot
.332 .53421 Mdot
.44133 .49861 Mdot
.5831 .32724 Mdot
.31583 .57776 Mdot
.6854 .32014 Mdot
.67405 .20197 Mdot
.61278 .63442 Mdot
.54755 .78851 Mdot
.60104 .32896 Mdot
.33746 .59858 Mdot
.49441 .30811 Mdot
.57671 .3782 Mdot
.37189 .55849 Mdot
.39077 .39635 Mdot
.40772 .42925 Mdot
.58457 .55353 Mdot
.40812 .46482 Mdot
.30498 .59738 Mdot
.37765 .24881 Mdot
.57335 .36818 Mdot
.28506 .52208 Mdot
.47071 .67389 Mdot
.3509 .56089 Mdot
.56925 .50908 Mdot
.54054 .37078 Mdot
.35406 .53289 Mdot
.44803 .7766 Mdot
.46702 .86544 Mdot
.31678 .57708 Mdot
.57284 .36676 Mdot
.56871 .33595 Mdot
.55179 .56979 Mdot
.46744 .47474 Mdot
.3138 .58943 Mdot
.33257 .44158 Mdot
.69707 .71309 Mdot
.33077 .32197 Mdot
.54633 .18053 Mdot
.64215 .52954 Mdot
.61455 .53468 Mdot
.37764 .41206 Mdot
.64777 .56618 Mdot
.58391 .30403 Mdot
.63253 .60353 Mdot
.3834 .38558 Mdot
.3057 .57211 Mdot
.61841 .58918 Mdot
.50511 .68415 Mdot
.37489 .42541 Mdot
.37041 .43993 Mdot
.33275 .56178 Mdot
.59724 .37394 Mdot
.20125 .50143 Mdot
.33763 .54753 Mdot
.62955 .53499 Mdot
.32015 .31689 Mdot
.58085 .52763 Mdot
.38567 .75075 Mdot
.56787 .3713 Mdot
.35428 .58625 Mdot
.60666 .38029 Mdot
.38962 .42314 Mdot
.32478 .53346 Mdot
.63387 .56348 Mdot
.37165 .55318 Mdot
.49609 .73564 Mdot
.34982 .71505 Mdot
.55774 .31399 Mdot
.45972 .66609 Mdot
.55142 .34212 Mdot
.33146 .32127 Mdot
.56025 .70213 Mdot
.48026 .6843 Mdot
.35426 .56958 Mdot
.23913 .64471 Mdot
.37806 .55703 Mdot
.64704 .57662 Mdot
.65898 .56894 Mdot
.33374 .58975 Mdot
.51071 .67583 Mdot
.81285 .59679 Mdot
.51217 .58728 Mdot
.61103 .35646 Mdot
.56975 .26421 Mdot
.35523 .81935 Mdot
.42076 .37717 Mdot
.38241 .39509 Mdot
.69316 .58617 Mdot
.62573 .50749 Mdot
.37012 .43188 Mdot
.43038 .42826 Mdot
.51748 .67837 Mdot
.34866 .54075 Mdot
.62974 .32308 Mdot
.37193 .42129 Mdot
.64116 .653 Mdot
.73088 .66008 Mdot
.55568 .58182 Mdot
.63275 .4891 Mdot
.67384 .56743 Mdot
.42944 .52809 Mdot
.4261 .40787 Mdot
.62034 .5533 Mdot
.69597 .54548 Mdot
.40424 .39641 Mdot
.47837 .6995 Mdot
.6402 .3314 Mdot
.32504 .57231 Mdot
.5616 .12541 Mdot
.60096 .58555 Mdot
.6374 .58255 Mdot
.41144 .42038 Mdot
.51204 .17807 Mdot
.58608 .31617 Mdot
.58742 .37385 Mdot
.35268 .55566 Mdot
.43707 .49827 Mdot
.63108 .60097 Mdot
.63152 .55155 Mdot
.34821 .57048 Mdot
.31198 .31121 Mdot
.35913 .22479 Mdot
.60906 .55802 Mdot
.39745 .43546 Mdot
.29699 .52949 Mdot
.42766 .41089 Mdot
.58563 .5315 Mdot
.64997 .57539 Mdot
.63839 .5979 Mdot
.63821 .50758 Mdot
.37404 .44318 Mdot
.63295 .55415 Mdot
.60675 .4733 Mdot
.6015 .36283 Mdot
.64386 .53945 Mdot
.6951 .70089 Mdot
.60703 .56421 Mdot
.50292 .68732 Mdot
.20032 .45106 Mdot
.59889 .57336 Mdot
.64119 .53927 Mdot
.50797 .57871 Mdot
.62623 .57871 Mdot
.40957 .44336 Mdot
.57234 .33731 Mdot
.38975 .42947 Mdot
.42459 .41899 Mdot
.30788 .54726 Mdot
.51639 .68251 Mdot
.56786 .5347 Mdot
.47096 .66993 Mdot
.58783 .49343 Mdot
.58664 .52475 Mdot
.41073 .54795 Mdot
.47954 .32892 Mdot
.48173 .73024 Mdot
.62882 .56294 Mdot
.34714 .55814 Mdot
.36436 .57778 Mdot
.50539 .76067 Mdot
.57547 .61237 Mdot
.37304 .43566 Mdot
.38741 .3996 Mdot
.60938 .72577 Mdot
.52827 .40991 Mdot
.49716 .69339 Mdot
.48105 .40364 Mdot
.66986 .55155 Mdot
.60082 .55389 Mdot
.64717 .60756 Mdot
.29381 .56406 Mdot
.30799 .3145 Mdot
.30858 .56402 Mdot
.29878 .32144 Mdot
.42888 .41064 Mdot
.66681 .55349 Mdot
.36637 .77615 Mdot
.56093 .31995 Mdot
.57207 .33858 Mdot
.37483 .38904 Mdot
.3009 .58159 Mdot
.55242 .55934 Mdot
.85437 .39717 Mdot
.54618 .30484 Mdot
.46589 .70802 Mdot
.62885 .5495 Mdot
.33708 .56007 Mdot
.56495 .31365 Mdot
.50719 .64741 Mdot
.6662 .56018 Mdot
.37069 .53124 Mdot
.61104 .56754 Mdot
.67827 .44482 Mdot
.60475 .35801 Mdot
.24704 .31746 Mdot
.55752 .31202 Mdot
.37259 .40687 Mdot
.42045 .40795 Mdot
.65153 .57852 Mdot
.77138 .29525 Mdot
.54086 .34943 Mdot
.43778 .4273 Mdot
.48395 .70623 Mdot
.31191 .32722 Mdot
.50128 .70106 Mdot
.31903 .59939 Mdot
.48773 .67782 Mdot
.37179 .54339 Mdot
.60861 .73922 Mdot
.55501 .29782 Mdot
.48012 .67457 Mdot
.48017 .17359 Mdot
.58034 .5852 Mdot
.51911 .66844 Mdot
.64329 .47927 Mdot
.5319 .30123 Mdot
.34443 .57051 Mdot
.50991 .67579 Mdot
.59977 .53199 Mdot
.28352 .72648 Mdot
.42323 .41285 Mdot
.37415 .43785 Mdot
.56632 .53869 Mdot
.38108 .56389 Mdot
.55682 .38762 Mdot
.44425 .58847 Mdot
.34086 .3348 Mdot
.63098 .55261 Mdot
.66798 .55536 Mdot
.54785 .34794 Mdot
.59824 .30326 Mdot
.65247 .57458 Mdot
.68973 .34016 Mdot
.64639 .5571 Mdot
.40959 .43114 Mdot
.60426 .32083 Mdot
.569 .33867 Mdot
.30025 .59427 Mdot
.55075 .33001 Mdot
.64622 .49352 Mdot
.35815 .43107 Mdot
.68636 .57732 Mdot
.39206 .41947 Mdot
.47542 .53977 Mdot
.33292 .54085 Mdot
.25294 .69496 Mdot
.54763 .33366 Mdot
.63346 .53971 Mdot
.55158 .34738 Mdot
.47787 .6669 Mdot
.57692 .35668 Mdot
.61877 .36339 Mdot
.66178 .57111 Mdot
.59151 .52695 Mdot
.31677 .31167 Mdot
.46445 .47698 Mdot
.59651 .35926 Mdot
.64486 .55344 Mdot
.61251 .49772 Mdot
.58009 .57639 Mdot
.48464 .48846 Mdot
.61073 .32327 Mdot
.75408 .36101 Mdot
.39586 .76678 Mdot
.59906 .35354 Mdot
.27133 .74482 Mdot
.33702 .32476 Mdot
.30402 .31554 Mdot
.4205 .38027 Mdot
.60555 .55809 Mdot
.30823 .58265 Mdot
.58681 .57044 Mdot
.61098 .63209 Mdot
.60171 .5807 Mdot
.49171 .70184 Mdot
.58193 .50451 Mdot
.32636 .32939 Mdot
.33026 .55146 Mdot
.65367 .54612 Mdot
.6128 .58729 Mdot
.30615 .3085 Mdot
.55303 .3154 Mdot
.61481 .33495 Mdot
.18095 .47029 Mdot
.47357 .6869 Mdot
.39653 .40551 Mdot
.58775 .55804 Mdot
.34951 .55719 Mdot
.31383 .56974 Mdot
.5571 .35859 Mdot
.32766 .57565 Mdot
.40093 .44703 Mdot
.63888 .56611 Mdot
.3709 .43543 Mdot
.48996 .70206 Mdot
.5714 .36574 Mdot
.58734 .55906 Mdot
.59401 .53374 Mdot
.60618 .34664 Mdot
.66175 .53749 Mdot
.51621 .6691 Mdot
.35865 .54046 Mdot
.61302 .33392 Mdot
.39086 .41007 Mdot
.29741 .59019 Mdot
.60464 .52012 Mdot
.53046 .85061 Mdot
.64947 .56393 Mdot
.59348 .5498 Mdot
.16772 .56141 Mdot
.69619 .57082 Mdot
.32984 .59974 Mdot
.5564 .36683 Mdot
.59203 .60386 Mdot
.69743 .7263 Mdot
.28979 .34857 Mdot
.29556 .54984 Mdot
.62913 .54546 Mdot
.2417 .68289 Mdot
.6376 .54292 Mdot
.26812 .52713 Mdot
.41245 .54206 Mdot
.60584 .79576 Mdot
.63728 .48841 Mdot
.39968 .45322 Mdot
.31617 .31007 Mdot
.37032 .57497 Mdot
.73655 .49492 Mdot
.65761 .55574 Mdot
.75653 .52388 Mdot
.60654 .59345 Mdot
.40739 .43448 Mdot
.68998 .50031 Mdot
.32783 .57885 Mdot
.63571 .24121 Mdot
.62409 .53244 Mdot
.60823 .32155 Mdot
.28772 .56555 Mdot
.32539 .33472 Mdot
.59697 .53436 Mdot
.46612 .68114 Mdot
.37736 .35358 Mdot
.66572 .49524 Mdot
.3922 .41666 Mdot
.60582 .54855 Mdot
.63563 .62484 Mdot
.72188 .25835 Mdot
.605 .3611 Mdot
.38494 .39497 Mdot
.50284 .21727 Mdot
.66452 .53861 Mdot
.61553 .34157 Mdot
.57602 .33685 Mdot
.46871 .69334 Mdot
.46918 .37768 Mdot
.35176 .35835 Mdot
.44334 .80371 Mdot
.78107 .49579 Mdot
.29924 .59755 Mdot
.40792 .23005 Mdot
.63874 .52138 Mdot
.52683 .59493 Mdot
.41199 .44112 Mdot
.63503 .58176 Mdot
.79652 .4751 Mdot
.585 .36306 Mdot
.61301 .55962 Mdot
.48467 .6991 Mdot
.41637 .35486 Mdot
.51353 .49875 Mdot
.45163 .83988 Mdot
.29336 .55456 Mdot
.66739 .59919 Mdot
.62204 .48146 Mdot
.33557 .33745 Mdot
.59724 .51698 Mdot
.36557 .58047 Mdot
.25856 .62999 Mdot
.51004 .68165 Mdot
.55663 .32161 Mdot
.33692 .32713 Mdot
.66381 .58967 Mdot
.57469 .52841 Mdot
.47791 .71391 Mdot
.60574 .53229 Mdot
.62549 .23709 Mdot
.33358 .29568 Mdot
.36378 .56143 Mdot
.6056 .36808 Mdot
.67501 .56431 Mdot
.30829 .31519 Mdot
.66098 .56963 Mdot
.63084 .28865 Mdot
.6163 .53955 Mdot
.38827 .33883 Mdot
.60164 .34538 Mdot
.38875 .41681 Mdot
.56537 .53647 Mdot
.61074 .57897 Mdot
.41307 .66292 Mdot
.6137 .63234 Mdot
.61404 .59037 Mdot
.61507 .31587 Mdot
.56573 .3199 Mdot
.55582 .34315 Mdot
.36446 .55554 Mdot
.48956 .33483 Mdot
.39981 .42886 Mdot
.61553 .60044 Mdot
.37219 .42233 Mdot
.63737 .64506 Mdot
.47153 .71135 Mdot
.31769 .77161 Mdot
.65797 .54731 Mdot
.55827 .34802 Mdot
.37276 .26543 Mdot
.59383 .31055 Mdot
.39366 .55443 Mdot
.39073 .43673 Mdot
.58773 .35829 Mdot
.62212 .57526 Mdot
.47571 .4448 Mdot
.4913 .84263 Mdot
.38092 .41883 Mdot
.65177 .60851 Mdot
.30128 .54841 Mdot
.36784 .53724 Mdot
.27483 .76897 Mdot
.42001 .40359 Mdot
.43572 .2461 Mdot
.64402 .55072 Mdot
.55955 .32249 Mdot
.41204 .41181 Mdot
.41446 .44196 Mdot
.34139 .57327 Mdot
.58587 .53602 Mdot
.60945 .57476 Mdot
.33473 .31688 Mdot
.38792 .40182 Mdot
.5798 .58888 Mdot
.60857 .50739 Mdot
.19653 .60531 Mdot
.6304 .31452 Mdot
.56151 .15287 Mdot
.58999 .61328 Mdot
.79075 .50455 Mdot
.46063 .51315 Mdot
.58422 .3128 Mdot
.58543 .56163 Mdot
.66065 .59624 Mdot
.30197 .60005 Mdot
.6435 .56442 Mdot
.2995 .56507 Mdot
.38178 .3936 Mdot
.33408 .78588 Mdot
.30291 .51052 Mdot
.31584 .67229 Mdot
.64586 .5712 Mdot
.5509 .44523 Mdot
.48492 .66577 Mdot
.3658 .3991 Mdot
.57323 .32206 Mdot
.67531 .55465 Mdot
.33975 .60038 Mdot
.3545 .5709 Mdot
.57905 .34353 Mdot
.43568 .26735 Mdot
.24182 .59467 Mdot
.63514 .50583 Mdot
.34584 .58957 Mdot
.29226 .50224 Mdot
.70183 .35504 Mdot
.40406 .46248 Mdot
.50808 .68754 Mdot
.30642 .57274 Mdot
.3712 .44363 Mdot
.62093 .28424 Mdot
.58691 .34759 Mdot
.54669 .3573 Mdot
.39788 .72168 Mdot
.31163 .58715 Mdot
.49505 .6662 Mdot
.51244 .37929 Mdot
.504 .33479 Mdot
.49822 .69822 Mdot
.30515 .57233 Mdot
.56607 .31589 Mdot
.57475 .32446 Mdot
.57261 .33585 Mdot
.63314 .24224 Mdot
.57256 .37235 Mdot
.72212 .31019 Mdot
.606 .50036 Mdot
.66123 .36227 Mdot
.63502 .54359 Mdot
.38506 .4517 Mdot
.60552 .35655 Mdot
.45135 .50061 Mdot
.67098 .533 Mdot
.45635 .83714 Mdot
.62556 .55171 Mdot
.37157 .45695 Mdot
.60405 .55965 Mdot
.65558 .31103 Mdot
.55929 .37594 Mdot
.63047 .56192 Mdot
.42399 .4436 Mdot
.48882 .68931 Mdot
.6298 .37779 Mdot
.60028 .57407 Mdot
.43337 .34986 Mdot
.69532 .54746 Mdot
.23081 .61507 Mdot
.44038 .62445 Mdot
.46365 .70577 Mdot
.69285 .53025 Mdot
.28961 .58399 Mdot
.59141 .40732 Mdot
.65056 .37845 Mdot
.38096 .41761 Mdot
.78069 .58965 Mdot
.35629 .56678 Mdot
.68793 .49818 Mdot
.67522 .52454 Mdot
.50996 .66145 Mdot
.58815 .40518 Mdot
.41346 .42967 Mdot
.6616 .54455 Mdot
.58536 .57862 Mdot
.44722 .75613 Mdot
.65399 .36473 Mdot
.57351 .56883 Mdot
.5081 .69909 Mdot
.76321 .36976 Mdot
.59634 .56217 Mdot
.36055 .52702 Mdot
.57011 .37886 Mdot
.59737 .4893 Mdot
.74502 .35107 Mdot
.64751 .55323 Mdot
.58397 .35458 Mdot
.54668 .33781 Mdot
.39155 .30519 Mdot
.4658 .70536 Mdot
.61583 .53958 Mdot
.429 .65911 Mdot
.61997 .53412 Mdot
.40276 .43178 Mdot
.5789 .54932 Mdot
.34908 .56492 Mdot
.49179 .30796 Mdot
.36245 .54804 Mdot
.58149 .56097 Mdot
.57676 .32832 Mdot
.4155 .4248 Mdot
.39118 .73653 Mdot
.4226 .5938 Mdot
.72939 .31845 Mdot
.29985 .33706 Mdot
.50907 .66624 Mdot
.52108 .66247 Mdot
.40959 .38656 Mdot
.62343 .56213 Mdot
.42726 .54944 Mdot
.66773 .50905 Mdot
.60128 .56139 Mdot
.59703 .57958 Mdot
.39736 .46866 Mdot
.38694 .42996 Mdot
.31898 .56988 Mdot
.65244 .57298 Mdot
.64343 .55414 Mdot
.59576 .35077 Mdot
.48584 .69099 Mdot
.36743 .55465 Mdot
.47509 .67779 Mdot
.33894 .55031 Mdot
.23384 .71425 Mdot
.61293 .61525 Mdot
.48992 .68982 Mdot
.41682 .39394 Mdot
.55881 .35533 Mdot
.31581 .30246 Mdot
.31281 .59845 Mdot
.32456 .57968 Mdot
.63384 .55229 Mdot
.57313 .36392 Mdot
.58477 .36828 Mdot
.49272 .65748 Mdot
.40174 .40096 Mdot
.58279 .56341 Mdot
.60366 .51401 Mdot
.50092 .78508 Mdot
.29369 .57888 Mdot
.70224 .33878 Mdot
.41089 .30567 Mdot
.62398 .56281 Mdot
.60087 .36792 Mdot
.62472 .59007 Mdot
.28249 .70439 Mdot
.60269 .37474 Mdot
.64872 .50968 Mdot
.53561 .40527 Mdot
.30595 .55069 Mdot
.36552 .31576 Mdot
.58535 .50928 Mdot
.26845 .32747 Mdot
.62679 .52266 Mdot
.14017 .5495 Mdot
.44699 .20462 Mdot
.64566 .59896 Mdot
.65164 .51704 Mdot
.47468 .81447 Mdot
.64316 .5475 Mdot
.33214 .32724 Mdot
.58234 .6116 Mdot
.61284 .32907 Mdot
.44133 .5484 Mdot
.38661 .59125 Mdot
.47245 .70676 Mdot
.35341 .55564 Mdot
.56028 .66827 Mdot
.47538 .69741 Mdot
.60275 .32759 Mdot
.65439 .51635 Mdot
.73226 .62617 Mdot
.39069 .55136 Mdot
.66253 .51022 Mdot
.40359 .43307 Mdot
.39544 .58106 Mdot
.31016 .5561 Mdot
.38711 .41178 Mdot
.61718 .59679 Mdot
.73945 .69186 Mdot
.41336 .60569 Mdot
.17737 .40008 Mdot
.41066 .41698 Mdot
.40464 .44117 Mdot
.5162 .28318 Mdot
.47221 .70647 Mdot
.45766 .75922 Mdot
.54866 .46878 Mdot
.39013 .44218 Mdot
.61078 .70075 Mdot
.37332 .57839 Mdot
.4686 .36994 Mdot
.5575 .37779 Mdot
.61842 .61461 Mdot
.61885 .57668 Mdot
.40377 .39914 Mdot
.73476 .55597 Mdot
.57014 .23431 Mdot
.38361 .41914 Mdot
.60415 .47905 Mdot
.44181 .36412 Mdot
.3226 .31503 Mdot
.33648 .31762 Mdot
.48448 .70792 Mdot
.26179 .6099 Mdot
.59637 .33625 Mdot
.50967 .65841 Mdot
.36849 .3424 Mdot
.61034 .54069 Mdot
.3824 .40367 Mdot
.31799 .30097 Mdot
.4009 .41625 Mdot
.49971 .68538 Mdot
.46665 .70844 Mdot
.60217 .36259 Mdot
.58535 .31643 Mdot
.80043 .51756 Mdot
.63186 .7202 Mdot
.64314 .54285 Mdot
.75739 .56372 Mdot
.56665 .36537 Mdot
.62284 .40777 Mdot
.46299 .68966 Mdot
.48413 .69338 Mdot
.68254 .41951 Mdot
.594 .5298 Mdot
.30892 .51482 Mdot
.59831 .56983 Mdot
.55657 .71247 Mdot
.67439 .52777 Mdot
.33607 .57426 Mdot
.63908 .53355 Mdot
.19959 .47916 Mdot
.65077 .52543 Mdot
.60555 .58694 Mdot
.31891 .55715 Mdot
.55951 .57204 Mdot
.3507 .56565 Mdot
.58503 .53415 Mdot
.50326 .7062 Mdot
.34963 .55691 Mdot
.57289 .78417 Mdot
.49639 .55822 Mdot
.31008 .32096 Mdot
.47845 .70347 Mdot
.47171 .67033 Mdot
.71333 .69114 Mdot
.57729 .32038 Mdot
.6048 .28239 Mdot
.62254 .56162 Mdot
.37193 .57805 Mdot
.37727 .41117 Mdot
.64523 .55499 Mdot
.66769 .59266 Mdot
.57178 .52678 Mdot
.58898 .36275 Mdot
.30332 .58338 Mdot
.49397 .68358 Mdot
.3597 .57999 Mdot
.40238 .63084 Mdot
.37545 .54389 Mdot
.69822 .58016 Mdot
.58209 .60297 Mdot
.55861 .6127 Mdot
.76886 .54771 Mdot
.65008 .24795 Mdot
.58389 .34324 Mdot
.31697 .32098 Mdot
.47426 .71047 Mdot
.57427 .26344 Mdot
.56103 .33689 Mdot
.32101 .5816 Mdot
.61111 .56771 Mdot
.59693 .48049 Mdot
.52346 .48261 Mdot
.5363 .38221 Mdot
.67711 .73098 Mdot
.33199 .54402 Mdot
.32831 .31867 Mdot
.49288 .31882 Mdot
.52298 .33804 Mdot
.44386 .50578 Mdot
.6139 .58448 Mdot
.46619 .67908 Mdot
.56484 .31371 Mdot
.41884 .73789 Mdot
.39551 .39683 Mdot
.46677 .47453 Mdot
.64576 .56988 Mdot
.3984 .24812 Mdot
.57721 .32852 Mdot
.48895 .69818 Mdot
.40443 .39898 Mdot
.46458 .70213 Mdot
.33871 .32494 Mdot
.18207 .48416 Mdot
.61238 .52886 Mdot
.62202 .59354 Mdot
.434 .41518 Mdot
.59373 .33493 Mdot
.37811 .51372 Mdot
.42854 .75644 Mdot
.3426 .5901 Mdot
.42244 .54701 Mdot
.58423 .31152 Mdot
.63203 .27045 Mdot
.36594 .56834 Mdot
.37656 .3863 Mdot
.43383 .53074 Mdot
.3875 .38548 Mdot
.59598 .57092 Mdot
.56451 .35074 Mdot
.41841 .40138 Mdot
.41508 .69079 Mdot
.21709 .66605 Mdot
.64378 .31021 Mdot
.66314 .54935 Mdot
.33166 .7823 Mdot
.19036 .58284 Mdot
.73589 .58103 Mdot
.37366 .41236 Mdot
.64798 .58376 Mdot
.63328 .5048 Mdot
.62809 .53276 Mdot
.39488 .38911 Mdot
.3615 .64936 Mdot
.33834 .57935 Mdot
.62163 .54915 Mdot
.47213 .67184 Mdot
.33895 .56702 Mdot
.2838 .57933 Mdot
.37604 .56693 Mdot
.61794 .36182 Mdot
.64306 .50832 Mdot
.46428 .34505 Mdot
.14879 .57088 Mdot
.38773 .4281 Mdot
.31045 .3217 Mdot
.61311 .59392 Mdot
.81612 .42174 Mdot
.55615 .34365 Mdot
.33953 .59091 Mdot
.63576 .58301 Mdot
.39755 .65127 Mdot
.29371 .30043 Mdot
.33885 .54554 Mdot
.57752 .32175 Mdot
.73479 .58252 Mdot
.64405 .56346 Mdot
.62344 .52194 Mdot
.59931 .33253 Mdot
.17787 .4457 Mdot
.48322 .32645 Mdot
.6179 .58835 Mdot
.38769 .41592 Mdot
.69543 .22387 Mdot
.57133 .53202 Mdot
.53333 .35341 Mdot
.31072 .32627 Mdot
.41495 .33342 Mdot
.70998 .34705 Mdot
.65118 .62848 Mdot
.35284 .78287 Mdot
.70525 .65807 Mdot
.30298 .76504 Mdot
.54144 .66736 Mdot
.26296 .48082 Mdot
.2051 .69252 Mdot
.42219 .44638 Mdot
.65114 .35897 Mdot
.55459 .81172 Mdot
.45158 .2742 Mdot
.44299 .61853 Mdot
.30634 .38625 Mdot
.41948 .63823 Mdot
.38741 .18536 Mdot
.37442 .55758 Mdot
.53145 .7341 Mdot
.58369 .56724 Mdot
.1901 .57376 Mdot
.67231 .32023 Mdot
.64683 .23195 Mdot
.29293 .7504 Mdot
.43237 .64885 Mdot
.52263 .83613 Mdot
.25059 .68236 Mdot
.74818 .62339 Mdot
.52655 .46433 Mdot
.33781 .41256 Mdot
.50464 .3609 Mdot
.57501 .66897 Mdot
.54885 .57307 Mdot
.21315 .43874 Mdot
.27042 .6213 Mdot
.7898 .41236 Mdot
.69751 .23763 Mdot
.31636 .60096 Mdot
.57422 .3807 Mdot
.49473 .78913 Mdot
.60678 .40429 Mdot
.36517 .38089 Mdot
.35398 .78365 Mdot
.19458 .61009 Mdot
.65564 .30854 Mdot
.27538 .28802 Mdot
.71038 .45856 Mdot
.83228 .55843 Mdot
.49441 .51097 Mdot
.54437 .33719 Mdot
.286 .45585 Mdot
.50447 .33424 Mdot
.35246 .4699 Mdot
.63064 .25602 Mdot
.49075 .6464 Mdot
.62372 .75955 Mdot
.58019 .32326 Mdot
.71404 .36031 Mdot
.30716 .32628 Mdot
.35792 .34469 Mdot
.38478 .52538 Mdot
.29504 .71883 Mdot
.29209 .31581 Mdot
.44863 .35377 Mdot
.3743 .24251 Mdot
.50949 .85824 Mdot
.64602 .68265 Mdot
.2807 .68364 Mdot
.39952 .47693 Mdot
.69384 .66242 Mdot
.48614 .28955 Mdot
.65602 .70671 Mdot
.51519 .31774 Mdot
.66076 .79992 Mdot
.16362 .51543 Mdot
.56495 .8348 Mdot
.6341 .35173 Mdot
.57709 .57533 Mdot
.33789 .74279 Mdot
.77629 .49033 Mdot
.46082 .70291 Mdot
.48311 .85058 Mdot
.47057 .66618 Mdot
.63126 .33202 Mdot
.44636 .26672 Mdot
.64737 .26947 Mdot
.26564 .59922 Mdot
.51939 .69086 Mdot
.66689 .50398 Mdot
.79694 .71214 Mdot
.38406 .80184 Mdot
.39904 .31365 Mdot
.19153 .60108 Mdot
.43994 .4277 Mdot
.38308 .5031 Mdot
.38398 .39173 Mdot
.20659 .67468 Mdot
.5646 .33731 Mdot
.15034 .59238 Mdot
.20296 .65461 Mdot
.55562 .21311 Mdot
.85975 .6455 Mdot
.38789 .20487 Mdot
.66601 .35855 Mdot
.73412 .64178 Mdot
.65042 .76049 Mdot
.5136 .26678 Mdot
.54727 .20444 Mdot
.34688 .42252 Mdot
.17026 .45256 Mdot
.23556 .70668 Mdot
.58993 .70681 Mdot
.28585 .63301 Mdot
.46725 .27149 Mdot
.48891 .5354 Mdot
.53441 .33709 Mdot
.4972 .58788 Mdot
.51945 .56075 Mdot
.54224 .83465 Mdot
.81287 .44589 Mdot
.80287 .32387 Mdot
.54242 .69146 Mdot
.52457 .18188 Mdot
.24273 .63241 Mdot
.55437 .78146 Mdot
.60994 .2594 Mdot
.44931 .31253 Mdot
.69839 .55765 Mdot
.48865 .3459 Mdot
.59927 .47072 Mdot
.47017 .65311 Mdot
.50465 .30228 Mdot
.24568 .52781 Mdot
.55478 .69753 Mdot
.42415 .7929 Mdot
.54455 .43133 Mdot
.61828 .35628 Mdot
.68716 .69266 Mdot
.62787 .69117 Mdot
.20553 .61134 Mdot
.5001 .21786 Mdot
.16908 .41883 Mdot
.52071 .215 Mdot
.66924 .50942 Mdot
.63846 .38632 Mdot
.5488 .55668 Mdot
.64646 .70155 Mdot
.61828 .49548 Mdot
.36547 .25421 Mdot
.16879 .57231 Mdot
.80157 .47068 Mdot
.56435 .67683 Mdot
.76628 .5638 Mdot
.16484 .47314 Mdot
.35774 .75521 Mdot
.44303 .21251 Mdot
.62337 .43975 Mdot
.74657 .75123 Mdot
.32885 .56688 Mdot
.60706 .70483 Mdot
.36384 .42717 Mdot
.39986 .72702 Mdot
.61613 .80157 Mdot
.55274 .22113 Mdot
.1654 .56551 Mdot
.45807 .31552 Mdot
.32593 .52647 Mdot
.46511 .40633 Mdot
.33519 .61081 Mdot
.76707 .58081 Mdot
.56093 .55542 Mdot
.60537 .6482 Mdot
.51245 .65679 Mdot
.76617 .47254 Mdot
.37973 .75823 Mdot
.26692 .3857 Mdot
.69115 .60412 Mdot
.26328 .41859 Mdot
.33134 .31819 Mdot
.4709 .459 Mdot
.26514 .75933 Mdot
.60823 .62615 Mdot
.42063 .19229 Mdot
.16488 .50203 Mdot
.42548 .53404 Mdot
.28997 .67694 Mdot
.4063 .28177 Mdot
.61514 .82194 Mdot
.18497 .62041 Mdot
.2176 .56311 Mdot
.34346 .79174 Mdot
.17447 .37091 Mdot
.68336 .77291 Mdot
.72598 .50405 Mdot
.37525 .45459 Mdot
.09587 .46006 Mdot
.33953 .58456 Mdot
.78765 .58209 Mdot
.77843 .48525 Mdot
.38638 .66375 Mdot
.57163 .40237 Mdot
.71141 .53032 Mdot
.33024 .35075 Mdot
.54418 .31341 Mdot
.67101 .50611 Mdot
.45491 .85712 Mdot
.67126 .79811 Mdot
.47169 .85696 Mdot
.17942 .49157 Mdot
.33016 .78643 Mdot
.5255 .81598 Mdot
.7151 .30135 Mdot
.46355 .77093 Mdot
.58036 .54272 Mdot
.58915 .72768 Mdot
.39764 .20284 Mdot
.37748 .52008 Mdot
.3418 .30123 Mdot
.61819 .37401 Mdot
.62668 .80893 Mdot
.28408 .78254 Mdot
.70426 .42531 Mdot
.75533 .38177 Mdot
.51138 .55238 Mdot
.63058 .71093 Mdot
.60353 .65196 Mdot
.22449 .41137 Mdot
.22149 .62032 Mdot
.53994 .81836 Mdot
.60121 .68945 Mdot
.29391 .39888 Mdot
.22471 .54801 Mdot
.50155 .18609 Mdot
.26899 .70541 Mdot
.5277 .79953 Mdot
.53683 .20873 Mdot
.63378 .44899 Mdot
.56587 .23054 Mdot
.22365 .38908 Mdot
.32917 .51399 Mdot
.6313 .67824 Mdot
.3352 .53886 Mdot
.5894 .71231 Mdot
.51245 .43455 Mdot
.47463 .78096 Mdot
.71015 .66078 Mdot
.58169 .70965 Mdot
.22886 .55988 Mdot
.41538 .83755 Mdot
.21267 .34434 Mdot
.75919 .69423 Mdot
.25465 .33968 Mdot
.60668 .46619 Mdot
.57289 .54544 Mdot
.16214 .53265 Mdot
.39573 .83811 Mdot
.16387 .58589 Mdot
.3975 .24485 Mdot
.40945 .68976 Mdot
.39325 .4635 Mdot
.774 .63546 Mdot
.26099 .36303 Mdot
.22005 .63822 Mdot
.54719 .27526 Mdot
.42025 .37916 Mdot
.4646 .31661 Mdot
.7771 .59101 Mdot
.74808 .6409 Mdot
.72916 .38105 Mdot
.55636 .58747 Mdot
.68223 .34548 Mdot
.55749 .37159 Mdot
.40691 .23542 Mdot
.64628 .70832 Mdot
.33277 .56268 Mdot
.55555 .7956 Mdot
.59192 .64474 Mdot
.69889 .56365 Mdot
.32526 .51863 Mdot
.53608 .33341 Mdot
.77371 .53748 Mdot
.34671 .4022 Mdot
.21733 .70653 Mdot
.4101 .20837 Mdot
.70138 .64325 Mdot
.68228 .68102 Mdot
.45481 .7427 Mdot
.4784 .34543 Mdot
.40297 .38483 Mdot
.27897 .73259 Mdot
.47692 .58236 Mdot
.68746 .6882 Mdot
.68622 .34721 Mdot
.41316 .75605 Mdot
.67108 .58886 Mdot
.39298 .29114 Mdot
.75696 .33991 Mdot
.46383 .47297 Mdot
.61471 .30735 Mdot
.5442 .30537 Mdot
.38155 .17166 Mdot
.20851 .48393 Mdot
.48929 .20841 Mdot
.28398 .73188 Mdot
.38345 .38689 Mdot
.61823 .32594 Mdot
.57484 .71944 Mdot
.35571 .71743 Mdot
.78951 .39351 Mdot
.26367 .5731 Mdot
.60392 .65599 Mdot
.25452 .37925 Mdot
.33747 .78394 Mdot
.45241 .82665 Mdot
.73014 .2624 Mdot
.57037 .30427 Mdot
.37224 .74547 Mdot
.39347 .74761 Mdot
.56076 .31323 Mdot
.53319 .37318 Mdot
.52903 .47172 Mdot
.29471 .76765 Mdot
.49013 .35756 Mdot
.22956 .35911 Mdot
.43215 .53305 Mdot
.3842 .64827 Mdot
.42759 .74448 Mdot
.61907 .67383 Mdot
.28807 .73154 Mdot
.71427 .37209 Mdot
.69105 .74879 Mdot
.54479 .55971 Mdot
.80653 .515 Mdot
.77558 .63418 Mdot
.49026 .50463 Mdot
.64106 .27591 Mdot
.25797 .52743 Mdot
.63244 .53606 Mdot
.50364 .86033 Mdot
.20902 .60101 Mdot
.52366 .28662 Mdot
.35279 .37473 Mdot
.62118 .5129 Mdot
.61718 .49964 Mdot
.7217 .52698 Mdot
.4139 .32138 Mdot
.73314 .73423 Mdot
.54449 .70792 Mdot
.59881 .46824 Mdot
.68573 .3378 Mdot
.42271 .1924 Mdot
.31102 .72818 Mdot
.23408 .62213 Mdot
.50197 .43815 Mdot
.39887 .20449 Mdot
.42514 .4946 Mdot
.22506 .35755 Mdot
.24307 .42584 Mdot
.51228 .81275 Mdot
.57901 .4414 Mdot
.43164 .31493 Mdot
.44597 .74044 Mdot
.60554 .58959 Mdot
.43543 .26775 Mdot
.25741 .6888 Mdot
.83896 .38134 Mdot
.48844 .27862 Mdot
.43531 .8559 Mdot
.57292 .62891 Mdot
.43936 .32223 Mdot
.63871 .79596 Mdot
.87587 .45715 Mdot
.21615 .42517 Mdot
.52904 .8363 Mdot
.4599 .45172 Mdot
.2932 .74306 Mdot
.39672 .45723 Mdot
.50893 .39473 Mdot
.75907 .54241 Mdot
.28733 .76172 Mdot
.3131 .71032 Mdot
.30758 .73808 Mdot
.71981 .51298 Mdot
.33512 .79509 Mdot
.52928 .30007 Mdot
.41318 .16611 Mdot
.34097 .52718 Mdot
.34368 .24906 Mdot
.67729 .4643 Mdot
.54261 .60058 Mdot
.60649 .69814 Mdot
.49656 .16282 Mdot
.68228 .26317 Mdot
.73281 .52567 Mdot
.55662 .75478 Mdot
.41055 .29177 Mdot
.68421 .67763 Mdot
.21859 .64839 Mdot
.39302 .18049 Mdot
.41206 .74516 Mdot
.44773 .22929 Mdot
.17737 .47322 Mdot
.40787 .32154 Mdot
.2355 .46745 Mdot
.27874 .68384 Mdot
.20087 .40186 Mdot
.58543 .65057 Mdot
.46597 .11615 Mdot
.30822 .62807 Mdot
.52752 .47573 Mdot
.59276 .8258 Mdot
.22057 .61703 Mdot
.56579 .2636 Mdot
.61479 .23378 Mdot
.81356 .53515 Mdot
.60694 .74204 Mdot
.6017 .58046 Mdot
.34503 .80344 Mdot
.59494 .76988 Mdot
.50683 .84882 Mdot
.15263 .47376 Mdot
.68208 .36642 Mdot
.66625 .61808 Mdot
.30077 .6045 Mdot
.50577 .51253 Mdot
.54626 .75549 Mdot
.53962 .82606 Mdot
.79791 .55107 Mdot
.42901 .58741 Mdot
.26461 .46983 Mdot
.26149 .56591 Mdot
.58912 .45664 Mdot
.37784 .21504 Mdot
.41693 .30701 Mdot
.54968 .68078 Mdot
.21834 .54162 Mdot
.62531 .70434 Mdot
.70481 .34304 Mdot
.74642 .65393 Mdot
.53173 .24045 Mdot
.42729 .37202 Mdot
.30553 .60168 Mdot
.45944 .80447 Mdot
.24164 .60411 Mdot
.36399 .25777 Mdot
.73621 .71446 Mdot
.44849 .30597 Mdot
.52444 .74223 Mdot
.41119 .77758 Mdot
.51236 .26241 Mdot
.33535 .41623 Mdot
.75673 .6336 Mdot
.80515 .5121 Mdot
.25751 .5438 Mdot
.69878 .60524 Mdot
.23886 .71692 Mdot
.62278 .6772 Mdot
.4496 .78156 Mdot
.49673 .54882 Mdot
.77857 .45322 Mdot
.65314 .41773 Mdot
.60284 .77975 Mdot
.44222 .4956 Mdot
.77979 .72544 Mdot
.56765 .3942 Mdot
.51239 .85843 Mdot
.39213 .40499 Mdot
.77698 .32504 Mdot
.23655 .58135 Mdot
.50272 .45697 Mdot
.45033 .5171 Mdot
.39041 .29316 Mdot
.42845 .35295 Mdot
.17256 .47231 Mdot
.56285 .2264 Mdot
.37791 .54668 Mdot
.4324 .59702 Mdot
.22852 .36833 Mdot
.42825 .80192 Mdot
.59101 .60101 Mdot
.26542 .6155 Mdot
.48949 .51118 Mdot
.39717 .52635 Mdot
.16534 .53565 Mdot
.27135 .51456 Mdot
.59342 .48845 Mdot
.63259 .71272 Mdot
.56046 .82283 Mdot
.2055 .64927 Mdot
.57271 .24155 Mdot
.59768 .47167 Mdot
.36043 .43446 Mdot
.61198 .79213 Mdot
.38283 .7972 Mdot
.30355 .51511 Mdot
.46817 .36234 Mdot
.63858 .68349 Mdot
.51977 .87894 Mdot
.66707 .79871 Mdot
.74598 .71181 Mdot
.42841 .54293 Mdot
.58883 .28865 Mdot
.81791 .43333 Mdot
.44674 .78104 Mdot
.32835 .26188 Mdot
.21444 .58303 Mdot
.61301 .70308 Mdot
.86009 .44781 Mdot
.66635 .26355 Mdot
.39841 .62908 Mdot
.6547 .41965 Mdot
.78075 .50546 Mdot
.41107 .45352 Mdot
.59289 .75063 Mdot
.45471 .59786 Mdot
.39489 .37656 Mdot
.41196 .29478 Mdot
.44534 .35801 Mdot
.45215 .78173 Mdot
.77367 .37 Mdot
.57541 .48399 Mdot
.39661 .79142 Mdot
.5603 .29577 Mdot
.41496 .73837 Mdot
.45749 .74802 Mdot
.4436 .60582 Mdot
.35529 .58085 Mdot
.56733 .61082 Mdot
.47409 .42227 Mdot
.44908 .47707 Mdot
.79199 .64042 Mdot
.47845 .65809 Mdot
.59962 .39233 Mdot
.64198 .24441 Mdot
.57856 .30303 Mdot
.37718 .83213 Mdot
.22466 .41279 Mdot
.68046 .3358 Mdot
.31177 .61925 Mdot
.28969 .42648 Mdot
.83868 .57818 Mdot
.76301 .60965 Mdot
.51268 .59326 Mdot
.53387 .30361 Mdot
.55003 .34951 Mdot
.30119 .61251 Mdot
.34811 .3203 Mdot
.7325 .37031 Mdot
.41573 .1882 Mdot
.47152 .76485 Mdot
.54647 .32672 Mdot
.38361 .63641 Mdot
.70889 .62949 Mdot
.24964 .73912 Mdot
.37009 .57178 Mdot
.72868 .76359 Mdot
.58411 .60473 Mdot
.65857 .77549 Mdot
.16518 .54244 Mdot
.49432 .30163 Mdot
.4243 .55576 Mdot
.32296 .38765 Mdot
.62307 .60571 Mdot
.56568 .49083 Mdot
.58763 .3205 Mdot
.45398 .76261 Mdot
.48479 .68211 Mdot
.66838 .72667 Mdot
.38241 .38269 Mdot
.54123 .19414 Mdot
.38316 .21718 Mdot
.57328 .38253 Mdot
.472 .59602 Mdot
.33499 .7314 Mdot
.53554 .43787 Mdot
.48873 .51084 Mdot
.47329 .81209 Mdot
.79326 .40616 Mdot
.54645 .33096 Mdot
.73585 .71814 Mdot
.49941 .74136 Mdot
.19077 .65266 Mdot
.70204 .62464 Mdot
.49995 .50215 Mdot
.53961 .4372 Mdot
.39548 .28462 Mdot
.71579 .35004 Mdot
.22956 .62585 Mdot
.67644 .69731 Mdot
.51559 .3784 Mdot
.5814 .71192 Mdot
.56261 .517 Mdot
.26047 .47062 Mdot
.3472 .23853 Mdot
.86149 .46788 Mdot
.69019 .45024 Mdot
.47704 .3073 Mdot
.53825 .30794 Mdot
.41788 .19333 Mdot
.58437 .39844 Mdot
.35627 .67404 Mdot
.79456 .42236 Mdot
.23533 .58395 Mdot
.21524 .69169 Mdot
.20555 .60942 Mdot
.51937 .51899 Mdot
.27638 .5441 Mdot
.71009 .65046 Mdot
.71225 .62015 Mdot
.47069 .49103 Mdot
.62323 .60434 Mdot
.60472 .45648 Mdot
.55787 .24847 Mdot
.37034 .26486 Mdot
.70191 .51662 Mdot
.27501 .74441 Mdot
.18897 .64405 Mdot
.37885 .81415 Mdot
.33962 .50682 Mdot
.62103 .35914 Mdot
.62965 .81563 Mdot
.7008 .3149 Mdot
.2149 .64605 Mdot
.68681 .47021 Mdot
.35649 .18614 Mdot
.6007 .80841 Mdot
.24893 .53157 Mdot
.55415 .21001 Mdot
.34874 .30103 Mdot
.17111 .54007 Mdot
.41157 .16703 Mdot
.57846 .65388 Mdot
.16061 .52089 Mdot
.79598 .7118 Mdot
.70659 .47876 Mdot
.44168 .35277 Mdot
.64564 .40743 Mdot
.70279 .64935 Mdot
.41525 .1818 Mdot
.57791 .54605 Mdot
.35183 .53228 Mdot
.42676 .62732 Mdot
.62286 .69988 Mdot
.63262 .63997 Mdot
.42673 .17699 Mdot
.54061 .75535 Mdot
.52801 .7342 Mdot
.3767 .73787 Mdot
.56468 .81321 Mdot
.72616 .35739 Mdot
.61514 .48067 Mdot
.63409 .33294 Mdot
.494 .70403 Mdot
.5589 .65729 Mdot
.61638 .50868 Mdot
.41283 .5357 Mdot
.53957 .46568 Mdot
.45272 .85917 Mdot
.35894 .69719 Mdot
.3049 .66844 Mdot
.54336 .30992 Mdot
.40992 .31172 Mdot
.35462 .7611 Mdot
.44962 .27114 Mdot
.45485 .1692 Mdot
.8112 .452 Mdot
.34734 .7883 Mdot
.45381 .32388 Mdot
.58149 .6822 Mdot
.81148 .60499 Mdot
.38554 .44836 Mdot
.76535 .52424 Mdot
.52453 .8205 Mdot
.43948 .2841 Mdot
.61224 .30981 Mdot
.23293 .5209 Mdot
.27334 .48424 Mdot
.42891 .28755 Mdot
.16552 .49833 Mdot
.38812 .75527 Mdot
.66797 .39846 Mdot
.43762 .81987 Mdot
.29203 .55946 Mdot
.60023 .69135 Mdot
.22021 .49652 Mdot
.40306 .18195 Mdot
.53864 .42694 Mdot
.24979 .72728 Mdot
.46484 .49597 Mdot
.60502 .76998 Mdot
.617 .52637 Mdot
.74982 .35525 Mdot
.37983 .2716 Mdot
.22167 .53242 Mdot
.48853 .21392 Mdot
.60909 .37423 Mdot
.38518 .23086 Mdot
.34021 .41524 Mdot
.60552 .754 Mdot
.55123 .63742 Mdot
.6314 .38399 Mdot
.53422 .66849 Mdot
.31766 .33776 Mdot
.57742 .5905 Mdot
.64155 .75617 Mdot
.25462 .59192 Mdot
.75722 .52684 Mdot
.72476 .50023 Mdot
.45962 .80608 Mdot
.25653 .62949 Mdot
.35481 .25899 Mdot
.72056 .50455 Mdot
.38014 .33747 Mdot
.67701 .27247 Mdot
.45908 .24986 Mdot
.59077 .50436 Mdot
.35763 .67191 Mdot
.60881 .31907 Mdot
.43409 .8062 Mdot
.63842 .31535 Mdot
.56787 .78466 Mdot
.48523 .44672 Mdot
.32813 .73668 Mdot
.48432 .55127 Mdot
.16753 .54393 Mdot
.34695 .29919 Mdot
.64851 .70807 Mdot
.42345 .39131 Mdot
.45958 .44902 Mdot
.49373 .27058 Mdot
.24503 .69951 Mdot
.54483 .23109 Mdot
.73744 .62237 Mdot
.46947 .31043 Mdot
.79506 .49292 Mdot
.15252 .49198 Mdot
.63675 .72397 Mdot
.47174 .48933 Mdot
.66367 .65212 Mdot
.36158 .341 Mdot
.31346 .30257 Mdot
.37747 .67713 Mdot
.71646 .33691 Mdot
.31212 .65479 Mdot
.41347 .59222 Mdot
.57761 .58378 Mdot
.81297 .41253 Mdot
.41912 .81072 Mdot
.57668 .26107 Mdot
.49686 .47032 Mdot
.44011 .73072 Mdot
.6135 .75417 Mdot
.62364 .15455 Mdot
.49667 .86288 Mdot
.6159 .52597 Mdot
.43823 .53642 Mdot
.65939 .72868 Mdot
.30098 .56339 Mdot
.73921 .38244 Mdot
.45428 .80637 Mdot
.39868 .44278 Mdot
.40824 .70174 Mdot
.31441 .28705 Mdot
.38393 .28709 Mdot
.59179 .78526 Mdot
.40943 .46491 Mdot
.40058 .84657 Mdot
.21275 .57401 Mdot
.38644 .26687 Mdot
.53786 .11555 Mdot
.38411 .24687 Mdot
.58524 .28391 Mdot
.30101 .70365 Mdot
.40933 .83539 Mdot
.42789 .53912 Mdot
.39793 .72223 Mdot
.72961 .50393 Mdot
.65947 .70442 Mdot
.55285 .71075 Mdot
.44558 .22952 Mdot
.40229 .22549 Mdot
.4241 .16152 Mdot
.29066 .42464 Mdot
.79871 .64028 Mdot
.70382 .36243 Mdot
.45418 .8315 Mdot
.21802 .4201 Mdot
.85582 .43326 Mdot
.20755 .67576 Mdot
.57974 .73421 Mdot
.44791 .17593 Mdot
.29629 .69162 Mdot
.69472 .71398 Mdot
.78148 .36027 Mdot
.20268 .43849 Mdot
.80387 .42929 Mdot
.27931 .41711 Mdot
.47619 .23326 Mdot
.58602 .71155 Mdot
.78786 .50273 Mdot
.46018 .49713 Mdot
.50678 .83019 Mdot
.52456 .17363 Mdot
.67158 .68368 Mdot
.41931 .70637 Mdot
.70034 .71981 Mdot
.39005 .79378 Mdot
.26627 .68302 Mdot
.4705 .51075 Mdot
.802 .69558 Mdot
.54052 .83428 Mdot
.46186 .26243 Mdot
.60051 .50245 Mdot
.19903 .67845 Mdot
.45695 .54991 Mdot
.73117 .51592 Mdot
.1854 .55076 Mdot
.54153 .7061 Mdot
.55522 .45212 Mdot
.5692 .53447 Mdot
.76204 .62452 Mdot
.63722 .28168 Mdot
.78406 .50996 Mdot
.44811 .72408 Mdot
.68209 .68309 Mdot
.53085 .17746 Mdot
.65216 .76547 Mdot
.71731 .6052 Mdot
.59105 .31172 Mdot
.42949 .84797 Mdot
.7467 .62209 Mdot
.54285 .57911 Mdot
.65627 .37991 Mdot
.55186 .22935 Mdot
.32923 .35563 Mdot
.60767 .46852 Mdot
.47857 .3485 Mdot
.60943 .69739 Mdot
.4358 .7779 Mdot
.75542 .54773 Mdot
.86894 .63524 Mdot
.16402 .54827 Mdot
.55478 .38594 Mdot
.75066 .50647 Mdot
.43387 .61299 Mdot
.38629 .8147 Mdot
.2908 .39497 Mdot
.45574 .74457 Mdot
.62284 .21939 Mdot
.69437 .69779 Mdot
.68242 .55646 Mdot
.1778 .49583 Mdot
.22109 .68618 Mdot
.55039 .17518 Mdot
.23871 .71587 Mdot
.67651 .60699 Mdot
.63982 .61667 Mdot
.82854 .33038 Mdot
.31331 .76366 Mdot
.64709 .62867 Mdot
.5831 .22547 Mdot
.5714 .40458 Mdot
.58239 .56038 Mdot
.31442 .28899 Mdot
.63609 .67174 Mdot
.54627 .7196 Mdot
.29134 .76416 Mdot
.5569 .30044 Mdot
.41926 .54548 Mdot
.37002 .44183 Mdot
.44983 .51142 Mdot
.58816 .48838 Mdot
.42227 .4049 Mdot
.54204 .73008 Mdot
.44972 .55671 Mdot
.37108 .35305 Mdot
.57438 .64859 Mdot
.21759 .34815 Mdot
.53501 .57612 Mdot
.51598 .52708 Mdot
.67782 .47311 Mdot
.68209 .26213 Mdot
.54348 .75479 Mdot
.51717 .76087 Mdot
.1614 .51456 Mdot
.21082 .3152 Mdot
.36796 .60799 Mdot
.72036 .56377 Mdot
.57417 .42384 Mdot
.70894 .33608 Mdot
.66002 .39238 Mdot
.44679 .38464 Mdot
.32223 .30736 Mdot
.69573 .58037 Mdot
.7001 .64354 Mdot
.37257 .40104 Mdot
.4887 .87471 Mdot
.57936 .52977 Mdot
.69837 .38883 Mdot
.2355 .67363 Mdot
.4196 .73866 Mdot
.54958 .48459 Mdot
.63058 .60505 Mdot
.53341 .29359 Mdot
.45242 .56027 Mdot
.72474 .6247 Mdot
.43525 .74724 Mdot
.39896 .81414 Mdot
.53439 .51592 Mdot
.68703 .38095 Mdot
.62614 .55306 Mdot
.52122 .68348 Mdot
.47891 .37647 Mdot
.76252 .66514 Mdot
.53126 .63474 Mdot
.20623 .64154 Mdot
.51326 .73041 Mdot
.5445 .70716 Mdot
.66068 .34438 Mdot
.5024 .85114 Mdot
.48315 .27977 Mdot
.67909 .36103 Mdot
.54555 .26197 Mdot
.23764 .48359 Mdot
.55762 .75287 Mdot
.28624 .60223 Mdot
.6994 .514 Mdot
.57788 .4084 Mdot
.30115 .78375 Mdot
.7653 .60657 Mdot
.45153 .42118 Mdot
.25432 .55024 Mdot
.67851 .27889 Mdot
.45437 .51336 Mdot
.49766 .1142 Mdot
.30166 .38171 Mdot
.40655 .84853 Mdot
.41699 .76439 Mdot
.57081 .42504 Mdot
.41168 .28861 Mdot
.58009 .62184 Mdot
.31652 .56275 Mdot
.3919 .81493 Mdot
.67803 .64182 Mdot
.45692 .24245 Mdot
.58631 .52941 Mdot
.50904 .31659 Mdot
.70716 .63783 Mdot
.28207 .53344 Mdot
.3659 .53592 Mdot
.56681 .23759 Mdot
.26944 .69553 Mdot
.45373 .56143 Mdot
.33427 .20946 Mdot
.54128 .82693 Mdot
.27667 .73097 Mdot
.26269 .56667 Mdot
.77518 .31715 Mdot
.54438 .29598 Mdot
.71387 .62076 Mdot
.43455 .40003 Mdot
.73752 .64152 Mdot
.43291 .28387 Mdot
.43736 .77378 Mdot
.38385 .33403 Mdot
.52578 .45502 Mdot
.40237 .12384 Mdot
.5765 .72817 Mdot
.57434 .26767 Mdot
.42476 .26428 Mdot
.2624 .72852 Mdot
.43908 .65881 Mdot
.17952 .39631 Mdot
.20792 .45672 Mdot
.58176 .49299 Mdot
.7621 .35026 Mdot
.69447 .74167 Mdot
.30401 .49761 Mdot
.81886 .6149 Mdot
.2437 .60669 Mdot
.57219 .66853 Mdot
.22007 .5245 Mdot
.57385 .30398 Mdot
.57883 .40459 Mdot
.22926 .39357 Mdot
.26108 .29938 Mdot
.72821 .55298 Mdot
.36648 .79106 Mdot
.84045 .52327 Mdot
.46152 .75744 Mdot
.34846 .79806 Mdot
.40718 .47845 Mdot
.52656 .35129 Mdot
.53593 .75303 Mdot
.47634 .72863 Mdot
.29559 .56526 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`2:ooooo`;o0000_Oooool001cooooo00?o0000ooooooooool0R_ooool2
o`000;gooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0U?ooool2o`0000?ooooo0_l00003ooooo`;o00002oooool2o`0009cooooo000Looooo`03o`00
0?oooooooooo09Cooooo0_l00003ooooo`;o00000oooool2o`0000_ooooo0_l0002Looooo`007?oo
ool00ol0003oooooooooo`25ooooo`;o0000`_ooool001cooooo00?o0000ooooooooool0Ooooool2
o`0000Cooooo0_l000000ooooooo0000o`00000Yooooo`;o0000U?ooool001cooooo00?o0000oooo
ooooool0Ooooool2o`0000Oooooo0_l0000Xooooo`?o0000U?ooool001cooooo00?o0000oooooooo
ool0/_ooool2o`0009Gooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`1]ooooo`;o0000f_ooool001cooooo0_l0001^ooooo`;o0000A?oo
ool2o`0009Cooooo000Looooo`03o`000?oooooooooo0;?ooooo1?l0000@ooooo`;o0000P?ooool0
01cooooo00?o0000ooooooooool0]Oooool2o`00013ooooo0_l00020ooooo`007?ooool00ol0003o
ooooooooo`26ooooo`;o00005_ooool2o`000:Wooooo000Looooo`03o`000?oooooooooo08;ooooo
0_l00002ooooo`;o00001oooool2o`0000Wooooo0_l00002ooooo`;o00007?ooool2o`0008_ooooo
000Looooo`03o`000?oooooooooo08;ooooo0_l0000;ooooo`?o00002?ooool2o`00023ooooo0_l0
0002ooooo`;o0000Qoooool001cooooo00?o0000ooooooooool0N?ooool2o`0000Sooooo0_l00007
ooooo`;o00000oooool4o`0000gooooo0_l0000Mooooo`;o0000Qoooool001cooooo00?o0000oooo
ooooool0N?ooool2o`00017ooooo0_l00005ooooo`;o00001?ooool2o`0000Oooooo0_l00004oooo
o`;o00001_ooool2o`0009Sooooo000Looooo`03o`000?oooooooooo08Oooooo0_l00005ooooo`;o
00002?ooool2o`0000Wooooo0_l00002ooooo`Co00001?ooool2o`0001kooooo0_l0001hooooo`00
7?ooool00ol0003oooooooooo`1looooo`;o00002Oooool2o`0000Gooooo0_l0000Aooooo`Co0000
1?ooool2o`0000?ooooo0_l0000Oooooo`;o0000N?ooool001cooooo00?o0000ooooooooool0O?oo
ool2o`000003ooooool0003o000000;ooooo0_l0000Looooo`;o00001?ooool4o`0000?ooooo1?l0
002Gooooo`007?ooool00ol0003oooooooooo`1`ooooo`;o00002?ooool2o`0000?ooooo1_l0000J
ooooo`;o00001_ooool4o`0000Gooooo0_l00004ooooo`;o00004oooool2o`0007cooooo000Loooo
o`03o`000?oooooooooo073ooooo0_l00008ooooo`;o00001Oooool6o`0001Sooooo0_l0000@oooo
o`;o00000oooool2o`0001?ooooo0_l00005ooooo`;o0000MOooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo08?ooooo1Ol0000D
ooooo`;o00004oooool2o`0001[ooooo0_l00003ooooo`;o0000MOooool00006oooooomgMgOoV9RH
oooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`00
0?oooooooooo08Cooooo1?l0000Dooooo`;o00003_ooool2o`0001oooooo0_l00007ooooo`;o0000
00?oooooo`000?l00000K_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_oo
ool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo05[ooooo0_l0001@ooooo`;o00003?oo
ool2o`0001[ooooo0_l000000ooooooo0000o`00001^ooooo`0000?oooooo`000?ooool00_ooool0
0ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0001Jooooo`;o00008Oooool2
o`0001_ooooo0_l0000Nooooo`;o00006oooool2o`00073ooooo00000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`1joooo
o`;o000000Coooooo`000?l0003o00003Oooool2o`0000_ooooo0_l00003ooooo`;o00003Oooool2
o`000003ooooool0003o000000Wooooo0ol0000Hooooo`;o0000L?ooool00003ooooool@413ooooo
00;ooooo00?o410@ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
07[ooooo0_l00002ooooo`;o000000?oooooo`000?l000000oooool2o`0000Gooooo0_l0000<oooo
o`;o000000Goooooo`000?l0003o0000ooooo`02o`0000Oooooo1Ol000000ooooooo0000o`000009
ooooo`?o00005Oooool2o`0007?ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go
0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo06Wooooo0_l0000Cooooo`;o0000
00?oooooo`000?l000000oooool2o`0000Oooooo0ol00008ooooo`?o000000?oooooo`000?l00000
0_ooool2o`0000Oooooo0ol000001Ooooooo0000o`000?l0003ooooo00;o00003?ooool4o`0000oo
oooo0_l0001cooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Yooooo`;o00003?ooool2o`0000Gooooo0_l0000<
ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0000;ooooo1Ol00008ooooo`;o00002?oo
ool6o`0000cooooo1?l00024ooooo`007?ooool00ol0003oooooooooo`1gooooo`Co00004Oooool3
o`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool3o`0000?ooooo0_l00008
ooooo`Co0000U_ooool001cooooo00?o0000ooooooooool0DOooool2o`0002Kooooo0_l0000Boooo
o`?o00001?ooool2o`0000Wooooo0ol0000=ooooo`?o00004oooool4o`00083ooooo000Looooo`03
o`000?oooooooooo057ooooo0_l0000]ooooo`;o00003?ooool4o`0000oooooo0_l0000=ooooo`;o
00004oooool4o`0000Wooooo0_l00005ooooo`;o00000oooool2o`0006Wooooo000Looooo`03o`00
0?oooooooooo06kooooo0_l000000ooooooo0000o`00000<ooooo`?o00003?ooool4o`0000?ooooo
0_l0000:ooooo`Co00003_ooool2o`0000Gooooo0_l00007ooooo`;o00002?ooool2o`0000?ooooo
0_l00005ooooo`?o00000_ooool2o`0006Wooooo000Looooo`03o`000?oooooooooo06kooooo0_l0
00000ooooooo0000o`00000<ooooo`Co00002_ooool3o`0000Gooooo0_l0000<ooooo`;o00002_oo
ool2o`0000;ooooo0ol00004ooooo`;o00001oooool2o`0000Sooooo0_l0000;ooooo`Co0000Jooo
ool001cooooo00?o0000ooooooooool0NOooool2o`0000Cooooo1?l0000:ooooo`?o00001oooool2
o`0001Cooooo1?l00003ooooo`;o00003_ooool2o`0000Sooooo0_l00002ooooo`;o00002?ooool2
o`0006_ooooo000Looooo`03o`000?oooooooooo07Wooooo0_l00003ooooo`Go00005?ooool2o`00
01;ooooo1?l00006ooooo`;o00003Oooool2o`0000Sooooo0_l00002ooooo`;o0000MOooool001co
oooo00?o0000ooooooooool0B_ooool2o`00027ooooo0_l0000>ooooo`Go00003_ooool2o`0001Wo
oooo0_l00002ooooo`?o00000_ooool3o`00013ooooo0_l00007ooooo`;o00003Oooool2o`0006So
oooo000Looooo`03o`000?oooooooooo04[ooooo0_l0000Qooooo`;o00001oooool3o`0000Cooooo
0_l0000Aooooo`?o00000_ooool2o`0001;ooooo0_l00004ooooo`?o00000_ooool4o`0000gooooo
1?l000001?oooooo0000o`000?l00003ooooo`;o00003Oooool2o`0006Sooooo000Looooo`03o`00
0?oooooooooo07Kooooo0ol00004ooooo`Co00002Oooool2o`0000Cooooo1?l000000ooooooo0000
o`00000Booooo`;o00002oooool2o`0000[ooooo0_l000000ooooooo0000o`000003ooooo`Go0000
5?ooool2o`0000Gooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1/ooooo`;o00002Ooo
ool4o`0000;ooooo1?l00009ooooo`;o00001?ooool6o`0001_ooooo0_l0000?ooooo`Co00001?oo
ool2o`000003ooooool0003o000000;o00004_ooool2o`0000Gooooo0_l0001Mooooo`007?ooool2
o`0006gooooo0_l00009ooooo`Co00000oooool2o`0000_ooooo0_l00004ooooo`;o000000Cooooo
o`000?l0003o00001?ooool4o`0001;ooooo0_l0000@ooooo`Co00002?ooool3o`0000Kooooo0_l0
001_ooooo`007?ooool00ol0003oooooooooo`1cooooo`;o00002oooool2o`0000Wooooo0_l00002
ooooo`Co00000_ooool2o`0000Cooooo1?l0000;ooooo`?o00005_ooool5o`0000Kooooo1?l00006
ooooo`;o0000Koooool001cooooo00?o0000ooooooooool0@oooool2o`0002kooooo0_l0000;oooo
o`;o00001?ooool2o`0000Oooooo0ol00003ooooo`;o00003_ooool2o`0000?ooooo1?l0000Hoooo
o`;o000000?oooooo`000?l000000oooool2o`0001Oooooo0_l0001Pooooo`007?ooool00ol0003o
ooooooooo`13ooooo`;o00008oooool2o`0000Kooooo0_l000000ooooooo0000o`00000Aooooo`;o
00003Oooool2o`0000cooooo1?l00005ooooo`;o00002_ooool2o`0000Sooooo0_l00005ooooo`;o
00002?ooool2o`0000Gooooo0ol0000:ooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0
Ioooool3o`0000Kooooo0_l000000ooooooo0000o`00000Aooooo`;o00002_ooool2o`0000oooooo
0_l00008ooooo`;o00001Oooool6o`0000Sooooo0_l00003ooooo`;o00002_ooool4o`0000?ooooo
0ol0000<ooooo`;o0000G_ooool001cooooo00?o0000ooooooooool0Ioooool2o`0000_ooooo0ol0
0003ooooo`;o00002_ooool6o`000003ooooool0003o000000?ooooo0_l00005ooooo`;o00002?oo
ool2o`0000Sooooo0_l00005ooooo`Go00003_ooool2o`0000cooooo0_l00003ooooo`?o00001_oo
ool2o`0000Cooooo1?l00005ooooo`;o0000EOooool001cooooo00?o0000ooooooooool0H?ooool2
o`0001;ooooo0ol00003ooooo`;o00003?ooool4o`000003ooooool0003o000000[ooooo0_l00002
ooooo`;o00001?ooool4o`0000kooooo1?l0000:ooooo`Co00000oooool2o`0000;ooooo0_l0000>
ooooo`;o00000oooool2o`0000Kooooo0_l00005ooooo`;o0000EOooool001cooooo00?o0000oooo
ooooool0E_ooool2o`0000Gooooo0_l000000ooooooo0000o`00000>ooooo`;o00001_ooool2o`00
01Cooooo0_l00004ooooo`;o00001?ooool2o`000003ooooool0003o000000Gooooo0ol0000Loooo
o`Co00000oooool2o`0000;ooooo0ol00007ooooo`;o00001?ooool2o`0006Wooooo000Looooo`03
o`000?oooooooooo05Kooooo0_l00005ooooo`;o00004Oooool3o`0000Gooooo0_l0000Booooo`Go
00000oooool2o`0000Cooooo0_l00004ooooo`;o00001oooool2o`0000?ooooo0_l00002ooooo`;o
00005Oooool2o`000004ooooool0003o0000ooooo`;o00001oooool2o`0001?ooooo0_l0001Joooo
o`007?ooool00ol0003oooooooooo`0looooo`;o00006Oooool2o`0001Sooooo0_l00005ooooo`;o
00001_ooool2o`0000Wooooo0ol000000ooooooo0000o`000006ooooo`Ko00000oooool2o`0000Oo
oooo0_l00003ooooo`?o000000?oooooo`000?l000005Oooool2o`000003ooooool0003o000000So
oooo0_l000000ooooooo0000o`00000Booooo`;o0000F_ooool001cooooo00?o0000ooooooooool0
??ooool2o`0001Wooooo0_l00002ooooo`;o00000oooool2o`0000oooooo1?l00003ooooo`;o0000
1_ooool2o`0000Wooooo0_l00007ooooo`;o000000?oooooo`000?l000001Ol00003ooooo`;o0000
00?oooooo`000?l000002Oooool2o`0000Oooooo0_l00007ooooo`Co00001_ooool2o`0000Wooooo
1Ol0000Dooooo`;o0000F?ooool001cooooo00?o0000ooooooooool0Foooool2o`0000;ooooo0ol0
000?ooooo`Co00002?ooool2o`000003ooooool0003o000000Oooooo1?l00007ooooo`;o00000ooo
ool2o`000003ooooool0003o000000?ooooo1Ol0000;ooooo`Ko000000?oooooo`000?l000000_l0
0005ooooo`Co000000?oooooo`000?l000000oooool2o`0000Oooooo0_l00002ooooo`;o00005Ooo
ool2o`0005Sooooo000Looooo`03o`000?oooooooooo05Kooooo1?l00005ooooo`;o000000Cooooo
o`000?l0003ooooo0_l0000=ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00001?oo
ool5o`0001Kooooo0_l000001?oooooo0000o`000?ooool4o`0000;ooooo2Ol00002ooooo`?o0000
0_ooool2o`0000Gooooo0_l000000ooooooo0000o`000009ooooo`;o0000Loooool001cooooo00?o
0000ooooooooool0DOooool2o`0000?ooooo1?l00008ooooo`;o000000?oooooo`000?l000003Ooo
ool2o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`;o00001?ooool2o`0000Kooooo0_l0
0008ooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000Go00000_oo
ool4o`0000?ooooo0ol00002ooooo`Ko00001oooool3o`0000Wooooo0_l00005ooooo`;o0000K?oo
ool001cooooo00?o0000ooooooooool0DOooool2o`00013ooooo0_l0000Fooooo`?o00001?ooool2
o`0000Cooooo0_l00005ooooo`?o00002?ooool2o`000004ooooool0003o0000ooooo`;o000000?o
ooooo`000?l000000_ooool5o`0000Wooooo1Ol00002ooooo`Co00002?ooool2o`0000Wooooo1?l0
0004ooooo`;o00006_ooool2o`00053ooooo000Looooo`03o`000?oooooooooo067ooooo1?l00004
ooooo`;o00004?ooool2o`0000Gooooo0_l0000;ooooo`;o00003oooool2o`0000Gooooo0_l00000
1?oooooo0000o`000?ooool2o`0000;ooooo0ol000000ooooooo0000o`000003o`0000;ooooo1?l0
000Cooooo`Co00002?ooool2o`0001Kooooo0_l0001@ooooo`007?ooool2o`0005;ooooo0_l00009
ooooo`?o00000_ooool5o`0000?ooooo1ol0000Dooooo`;o00002?ooool3o`0000cooooo0_l00000
0ooooooo0000o`000006ooooo`So000000?oooooo`000?l000000ol00002ooooo`Go00007oooool2
o`000003ooooool0003o000000?ooooo0_l0001Sooooo`007?ooool00ol0003oooooooooo`1Aoooo
o`?o00002?ooool4o`000003ooooool0003o000000Ko00000_ooool5o`0001?ooooo0ol00008oooo
o`?o00003?ooool7o`000004ooooool0003o0000ooooo`Go000000Coooooo`000?l0003ooooo0_l0
00000ooooooo0000o`000007o`0000;ooooo0_l0000Kooooo`;o00001_ooool2o`0006?ooooo000L
ooooo`03o`000?oooooooooo05;ooooo0_l0000:ooooo`go00003Oooool2o`000003ooooool0003o
000000Gooooo1?l00008ooooo`Co00001Oooool2o`0000Gooooo1_l000000ooooooo0000o`000003
ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000?ooooo2ol00003ooooo`;o00003?oo
ool2o`0001;ooooo0_l0001Qooooo`007?ooool00ol0003oooooooooo`1?ooooo`;o00003Oooool=
o`0000gooooo0_l000000ooooooo0000o`000004ooooo`Go00002?ooool4o`0000?ooooo1?l00003
ooooo`?o00003?ooool;o`000004ooooool0003o0000o`0000;ooooo2_l00007ooooo`;o00000_oo
ool3o`0001;ooooo1Ol0001Nooooo`007?ooool00ol0003oooooooooo`1>ooooo`?o00003_ooool=
o`00017ooooo0ol000000ooooooo0000o`00000;ooooo`?o00001?ooool2o`000003ooooool0003o
000000;ooooo0ol00006ooooo`;o00001?ooool=o`000003ooooool0003o000000[o00002?ooool2
o`0000;ooooo0_l00008ooooo`;o00001?ooool2o`0000;ooooo1_l0001Nooooo`007?ooool00ol0
003oooooooooo`11ooooo`;o00002oooool2o`0000_ooooo0_l00002ooooo`go00001oooool2o`00
00Sooooo0ol000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000001?ooool7o`00
00?ooooo1?l00006ooooo`;o000000?oooooo`000?l000001?ooool4o`000003ooooool0003o0000
00oo000000?oooooo`000?l000000_l00003ooooo`Go00000_ooool3o`0000Sooooo0_l00003oooo
o`?o00000_ooool2o`0001?ooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`11ooooo`;o
00002Oooool3o`0000Sooooo0_l00002ooooo`;o00000_ooool>o`0000Kooooo0_l00008ooooo`;o
00001_ooool2o`000003ooooool0003o000000Oooooo1?l00005ooooo`Co00001?ooool4o`0000Ko
oooo0_l00002oooooa7o000000?oooooo`000?l000000_l00003ooooo`Go00000_ooool2o`0000Ko
oooo0_l000001?oooooo0000o`000?l00002ooooo`;o00001oooool2o`0000gooooo1?l0001=oooo
o`007?ooool00ol0003oooooooooo`1<ooooo`?o00002?ooool2o`0000?ooooo2Ol00002ooooo`[o
00004?ooool4o`0000Kooooo0_l0000<ooooo`Ko00001Oooool2o`0000_ooooo4ol000001?oooooo
0000o`000?ooool4o`0000Wooooo1Ol000001?oooooo0000o`000?l0000;ooooo`;o00003Oooool2
o`0004oooooo000Looooo`03o`000?oooooooooo04gooooo0_l00006ooooo`?o00001?ooool3o`00
0003ooooool0003o0000017o00003_ooool4o`000003ooooool0003o000000?ooooo0_l00002oooo
o`?o00001oooool2o`0000;ooooo1?l0000@ooooo`co000000?oooooo`000?l000003?l00009oooo
o`Go000000?oooooo`000?l000005Oooool2o`0000Gooooo0_l00006ooooo`;o0000A_ooool001co
oooo00?o0000ooooooooool0;_ooool2o`0001_ooooo0_l00006ooooo`Go00002?ooool>o`0000?o
oooo0_l0000Cooooo`Co00001Oooool3o`0000Kooooo1?l00003ooooo`;o00002Oooool2o`0000;o
oooo0_l000000ooooooo0000o`00000:o`000003ooooool0003o000000So00004?ooool2o`000003
ooooool0003o000000Gooooo0_l0000>ooooo`;o00001Oooool2o`0000Kooooo0_l00016ooooo`00
7?ooool00ol0003oooooooooo`0^ooooo`;o00006oooool2o`0000Kooooo0_l0000<ooooo`go0000
1Oooool2o`0001?ooooo0_l00006ooooo`;o00001_ooool4o`0000?ooooo0_l00009ooooo`;o0000
0_oooolJo`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000004Oooool2o`0002Go
oooo0_l0000nooooo`007?ooool00ol0003oooooooooo`1Looooo`;o00000oooool<o`0000Kooooo
0_l00004ooooo`;o00002?ooool2o`0000_ooooo0_l00005ooooo`Ko00000_ooool3o`0000Sooooo
7Ol00002ooooo`So00008_ooool2o`0001Cooooo0_l0000nooooo`007?ooool00ol0003ooooooooo
o`17ooooo`;o00004oooool5o`0000;ooooo2_l00008ooooo`;o000000Coooooo`000?l0003o0000
2?ooool2o`0000;ooooo0_l0000>ooooo`Ko00000oooool2o`0000Cooooo0_l00002oooooako0000
0_ooool2o`000003ooooool0003o000000Kooooo0_l00002ooooo`Oo00000_ooool2o`000003oooo
ool0003o000000cooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`17ooooo`;o00001_oo
ool3o`0000cooooo0ol00002ooooo`[o00001Oooool2o`000004ooooool0003o0000ooooo`Co0000
2Oooool4o`0001;ooooo0_l00009ooooo`;o00000_ooool2o`000003ooooool0003o000001[o0000
00?oooooo`000?l000002Oooool3o`000003ooooool0003o000000Wo000000?oooooo`000?l00000
2oooool2o`0005Gooooo000Looooo`03o`000?oooooooooo047ooooo0_l0000<ooooo`?o00004ooo
ool2o`0000Cooooo0_l00004ooooo`Ko00000oooool2o`0000Wooooo0_l00006ooooo`;o00003?oo
ool2o`0000Kooooo0_l00007ooooo`;o000000?oooooo`000?l000004Ol000000ooooooo0000o`00
0007o`0000Oooooo1Ol00004ooooo`Oo00003?ooool2o`000003ooooool0003o000005Gooooo000L
ooooo`03o`000?oooooooooo047ooooo1?l0000/ooooo`;o000000?oooooo`000?l000000_l0000E
ooooo`;o00001?ooool2o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`;o00000_ooool2
o`0000?ooooo1ol00002oooooaGo00002Oooool4o`0000?ooooo0ol00004ooooo`Co00000oooool2
o`0000Gooooo0_l0000=ooooo`;o0000BOooool001cooooo0_l00014ooooo`?o00005?ooool2o`00
00cooooo0_l0000<ooooo`;o00003?ooool2o`0000?ooooo0_l00008ooooo`;o00000oooool2o`00
0003ooooool0003o000000[ooooo0_l00003oooooago00002Oooool2o`0000Kooooo0ol00006oooo
o`Co000000?oooooo`000?l000002_ooool2o`0000Sooooo0_l00019ooooo`007?ooool00ol0003o
ooooooooo`12ooooo`Co00003oooool2o`0000?ooooo0_l0000<ooooo`;o00002oooool4o`0000_o
oooo0_l000000ooooooo0000o`000007o`0000?ooooo0_l00003ooooo`;o00000_ooool4o`0000Oo
oooo1?l000000ooooooo0000o`00000Do`000003ooooool0003o000000Co000000?oooooo`000?l0
00001_ooool2o`00017ooooo0_l00004ooooo`Go00001?ooool2o`0005?ooooo000Looooo`03o`00
0?oooooooooo02Oooooo0_l0000Iooooo`;o00004Oooool2o`00013ooooo0_l0000<ooooo`Ko0000
2Oooool2o`000003ooooool0003o000000;ooooo1Ol0000<ooooo`Go00001_ooool4o`0000?ooooo
1ol000000ooooooo0000o`00000Do`0000Wooooo0_l00009ooooo`;o00002Oooool7o`0005Oooooo
000Looooo`03o`000?oooooooooo02Oooooo0_l0000Looooo`Co00007_ooool2o`0000Kooooo0_l0
0008ooooo`?o00002?ooool2o`0000Oooooo0_l00005ooooo`;o00000_ooool2o`000004ooooool0
003o0000ooooo`?o00003?oooolNo`0000Gooooo0_l00002ooooo`?o00002Oooool2o`0000Kooooo
0_l00005ooooo`?o0000Eoooool001cooooo00?o0000ooooooooool0AOooool4o`0000Sooooo0_l0
000Looooo`;o00002Oooool2o`00017ooooo0_l00005ooooo`;o000000Goooooo`000?l0003o0000
ooooo`02o`0000?ooooo0_l0000;oooooago00001_ooool2o`000003ooooool0003o000000;o0000
0_ooool2o`0000Kooooo0_l000000ooooooo0000o`000004o`0000Oooooo0_l00007ooooo`;o0000
2Oooool2o`0004;ooooo000Looooo`03o`000?oooooooooo057ooooo0_l0000Mooooo`;o00006_oo
ool2o`0000Kooooo0_l000000ooooooo0000o`000007ooooo`Co00002_oooolIo`0000[ooooo1?l0
0004ooooo`;o00001_ooool2o`000003ooooool0003o000000Co00001oooool3o`0000Kooooo1?l0
0007ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0Aoooool2o`0000Oooooo0ol0000M
ooooo`Co00006?ooool2o`0000Wooooo0_l00008ooooo`?o00002_ooool2o`000004ooooool0003o
0000oooooaCo00000oooool2o`0000;ooooo1?l00007ooooo`;o00004Oooool2o`0000?ooooo0_l0
0008ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0=Oooool2o`00013ooooo0_l00007
ooooo`;o00008?ooool2o`0001?ooooo0_l00006ooooo`;o00000oooool2o`0001Gooooo7Ol00003
ooooo`;o00000_ooool2o`0000Wooooo0_l00008ooooo`;o00001?ooool2o`000003ooooool0003o
000000Gooooo0_l000000ooooooo0000o`00001@ooooo`007?ooool00ol0003oooooooooo`0eoooo
o`;o0000>?ooool2o`0000oooooo0_l00002ooooo`;o000000?oooooo`000?l000001_ooool2o`00
00?ooooo0_l0000Boooooaoo00007Oooool2o`0000Cooooo0_l00008ooooo`;o000000?oooooo`00
0?l000001Oooool2o`0004Wooooo000Looooo`03o`000?oooooooooo05Wooooo0_l0000Dooooo`;o
00000oooool2o`0000Oooooo0_l000000ooooooo0000o`000002ooooo`?o00002oooool2o`000004
ooooool0003o0000ooooo`;o00002_ooool2o`0000;ooooo0ol000001?oooooo0000o`000?oooolH
o`0000;ooooo0_l00005ooooo`;o0000;?ooool2o`0004Wooooo000Looooo`03o`000?oooooooooo
04oooooo0_l00008ooooo`;o00000oooool6o`0000cooooo0_l000001?oooooo0000o`000?l00002
ooooo`;o00000oooool4o`0000Cooooo0_l00008ooooo`;o000000Coooooo`000?l0003ooooo0_l0
00001?oooooo0000o`000?l00008ooooo`Go00001?ooool2o`000003ooooool0003o000000?o0000
00?oooooo`000?l000004Ol000000ooooooo0000o`000003ooooo`Go00001oooool3o`000003oooo
ool0003o000000Wooooo0_l00007ooooo`;o00001oooool2o`0000;ooooo0_l0000<ooooo`;o0000
>_ooool001cooooo00?o0000ooooooooool0Coooool2o`0000gooooo1_l0000<ooooo`;o000000?o
ooooo`000?l000000oooool9o`0000?ooooo0ol00006ooooo`Co000000Coooooo`000?l0003ooooo
0_l00002ooooo`?o00001oooool5o`0000;ooooo0_l00003oooooa7o000000?oooooo`000?l00000
1Ol000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000001oooool3o`000003oooo
ool0003o000000Wooooo0_l000000ooooooo0000o`000004ooooo`;o00001oooool2o`0000;ooooo
0_l0000<ooooo`?o0000>Oooool001cooooo00?o0000ooooooooool0>_ooool2o`0000?ooooo0_l0
000Booooo`;o00002oooool2o`0000?ooooo0_l0000@ooooo`co000000Coooooo`000?l0003o0000
1_ooool2o`0000_ooooo0_l0000;ooooo`Ko00000oooool5o`000003ooooool0003o000000Oo0000
0_ooool2o`0000Kooooo0_l000000ooooooo0000o`000009ooooo`;o00004oooool2o`0000gooooo
0_l0000Aooooo`;o0000>Oooool001cooooo00?o0000ooooooooool0>_ooool2o`0000?ooooo0_l0
0004ooooo`;o00003?ooool2o`0000_ooooo0_l00003ooooo`;o00003oooool>o`000003ooooool0
003o000000;o00000oooool2o`0001Wooooo1_l00003ooooo`Go00001?ooool:o`0000Wooooo0_l0
0009ooooo`;o00001_ooool2o`0001[ooooo0_l0000Aooooo`;o0000>Oooool00006ooooooo^k^ko
<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`00
0?oooooooooo04Gooooo1?l0000Looooo`;o00003?ooool2o`000003ooooool0003o000001;o0000
0_ooool2o`0001Cooooo0_l00008ooooo`;o00002oooool8o`0001;ooooo0_l0000:ooooo`;o0000
5?ooool2o`0000Kooooo0_l0000@ooooo`;o0000>?ooool00006oooooomgMgOoV9RHoooooonHV9So
MgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Qooooo`;o
00005?ooool2o`0000kooooo0_l0000Aooooo`?o00002?ooool2o`0000cooooo0_l000000ooooooo
0000o`00000Bo`0001Sooooo0_l00008ooooo`;o00001oooool2o`0000?ooooo0ol00002ooooo`;o
00004_ooool2o`00023ooooo0_l00006ooooo`;o00000oooool2o`0000_ooooo0_l000000ooooooo
0000o`00000eooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`Go0000
1_ooool00ol0003oooooooooo`0Qooooo`;o00004oooool3o`00027ooooo1?l0000Eooooo`;o0000
00?oooooo`000?l000004?l000000ooooooo0000o`000003ooooo`?o00004Oooool3o`0000Wooooo
0_l00004ooooo`?o00000oooool8o`0001?ooooo0_l0000[ooooo`;o00003_ooool2o`0003Gooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo0000
1oooool3o`0003Kooooo0_l00002ooooo`;o00000_ooool2o`0000kooooo0_l0000<ooooo`;o0000
3oooool2o`0000Cooooo5Ol000000ooooooo0000o`000003ooooo`?o00001_ooool2o`0000[ooooo
0_l00009ooooo`;o00001?ooool4o`0000;ooooo0_l000000ooooooo0000o`000003o`0001?ooooo
0_l0000Zooooo`;o0000A_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Ooo
ool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo03Gooooo0_l00003ooooo`;o0000
0_ooool2o`0000kooooo0_l0000Mooooo`;o00001_oooolEo`0000Wooooo0_l00002ooooo`Ko0000
3Oooool2o`0000[ooooo1ol00004ooooo`;o00002?ooool2o`00037ooooo0_l000000ooooooo0000
o`000016ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03ogMgMoo<
c<co000000Oooooo00?o0000ooooooooool08?ooool2o`0001?ooooo0_l0000Gooooo`;o00006?oo
ool2o`0000_ooooo5ol00007ooooo`;o00001?ooool4o`0000gooooo0_l00009ooooo`Wo00000ooo
ool2o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l00000;_ooool2o`0004Wooooo0000
1_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l000001oooool00ol0003ooooo
ooooo`0Pooooo`;o00008oooool2o`00027ooooo1?l00009oooooaOo00007?ooool2o`0000_ooooo
0_l000000ooooooo0000o`000002ooooo`;o00002Oooool2o`000003ooooool0003o000000;ooooo
0_l0000]ooooo`;o00000_ooool2o`000003ooooool0003o000004?ooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`15ooooo`;o
00008oooool3o`0000Wooooo1ol000000ooooooo0000o`00000<o`0001cooooo0_l0000=ooooo`?o
00004?ooool2o`0001Cooooo0_l0000Kooooo`;o00000_ooool2o`000003ooooool0003o000004?o
oooo000Looooo`03o`000?oooooooooo03Gooooo0_l0000>ooooo`;o00002oooool2o`0000?ooooo
0_l0000>ooooo`Ko00002?oooolGo`0000Cooooo0ol0000Kooooo`;o000000?oooooo`000?l00000
1?ooool3o`0000Cooooo0_l0000<ooooo`;o00000_ooool2o`0000kooooo0_l0001Wooooo`007?oo
ool00ol0003oooooooooo`0cooooo`Co00003?ooool2o`0000Sooooo0_l00003ooooo`;o00000ooo
ool2o`0000kooooo1?l00009oooooa3o000000?oooooo`000?l000001Ol00003ooooo`Co00001Ooo
ool2o`0001Cooooo0_l000000ooooooo0000o`00000;ooooo`;o00003?ooool2o`0000;ooooo0ol0
0007ooooo`;o00009oooool4o`0004;ooooo000Looooo`03o`000?oooooooooo01oooooo0_l0000B
ooooo`;o00003_ooool2o`0000Sooooo0_l00003ooooo`;o00001oooool2o`00013ooooo0_l00004
oooooaWo00000oooool2o`0000Gooooo1?l0000Dooooo`;o00001oooool2o`0000Cooooo0_l0000B
ooooo`;o00001oooool2o`0000Kooooo0_l0000Jooooo`;o00000oooool4o`0004;ooooo000Loooo
o`03o`000?oooooooooo01oooooo0_l0000Oooooo`;o000000?oooooo`000?l000001_ooool4o`00
00_ooooo0ol0000@ooooo`;o00000_oooolLo`0000Wooooo0ol0000Booooo`;o000000?oooooo`00
0?l000001_ooool3o`0000Cooooo0_l00006ooooo`;o00006_ooool3o`0001[ooooo0ol00018oooo
o`007?ooool00ol0003oooooooooo`10ooooo`Go00001_ooool4o`0000_ooooo0_l0000Eooooo`?o
000000?oooooo`000?l000005_l0000:ooooo`;o00004_ooool2o`0000Wooooo1?l0000:ooooo`?o
00006_ooool2o`0001cooooo1?l00016ooooo`007?ooool00ol0003oooooooooo`0nooooo`;o0000
0_ooool2o`0001Sooooo0_l0000Cooooo`;o000000?oooooo`000?l000005_l00002ooooo`?o0000
1_ooool2o`0001Cooooo0_l00009ooooo`;o00002Oooool3o`0000gooooo0_l0000/ooooo`;o0000
0oooool2o`0000[ooooo0_l0000eooooo`007?ooool00ol0003oooooooooo`0nooooo`?o000000?o
ooooo`000?l000006?ooool2o`0000_ooooo0_l00006ooooo`;o000000Goooooo`000?l0003o0000
ooooo`0@o`000003ooooool0003o000000?ooooo0ol0000Booooo`;o00001?ooool2o`000004oooo
ool0003o0000o`0000Cooooo0_l0000>ooooo`;o00003_ooool2o`0000?ooooo0_l0000/ooooo`;o
00002_ooool2o`0003Gooooo000Looooo`03o`000?oooooooooo03kooooo0ol000000ooooooo0000
o`000009ooooo`;o00006_ooool2o`0000Cooooo1Ol000000ooooooo0000o`00000Ao`000003oooo
ool0003o000000?o00004Oooool2o`0000;ooooo0_l00004ooooo`Go00001Oooool4o`0000Sooooo
1?l00004ooooo`;o00003oooool4o`0006gooooo000Looooo`03o`000?oooooooooo01gooooo0_l0
000Oooooo`;o00000_ooool2o`0000Wooooo0_l0000Iooooo`;o00001Oooool2o`000003ooooool0
003o000000Go000000?oooooo`000?l000003?l00002ooooo`Ko00001_ooool2o`0000Oooooo0_l0
0006ooooo`;o000000?oooooo`000?l000002?ooool3o`000004ooooool0003o0000o`0000Cooooo
1?l00004ooooo`;o00004Oooool2o`0000Oooooo0_l0001Tooooo`007?ooool00ol0003ooooooooo
o`0Mooooo`;o00005?ooool2o`000003ooooool0003o000000Kooooo0_l0000Xooooo`;o00002_oo
ool5o`000003ooooool0003o000000co00001_ooool2o`0000Kooooo0ol0000>ooooo`;o00001_oo
ool2o`0000Oooooo0ol00004ooooo`;o00006?ooool2o`000003ooooool0003o000000Gooooo0_l0
000Oooooo`?o0000@_ooool001cooooo00?o0000ooooooooool0<oooool2o`000003ooooool0003o
000000Kooooo0_l0000eoooooaGo00002?ooool2o`0000?ooooo0_l000000ooooooo0000o`00000A
ooooo`Co00003_ooool2o`0000Wooooo0_l0000=ooooo`;o000000?oooooo`000?l000009_ooool3
o`0000gooooo0_l0000cooooo`007?ooool2o`0003Gooooo1?l00005ooooo`;o0000=oooool5o`00
0003ooooool0003o000000So00000_ooool4o`0000Kooooo0_l00005ooooo`?o00004?ooool7o`00
00Cooooo0_l0000Aooooo`;o00004?ooool2o`0002Kooooo0_l0000>ooooo`;o0000<oooool001co
oooo00?o0000ooooooooool06oooool2o`0001Oooooo0_l000000ooooooo0000o`000004ooooo`;o
0000=Oooool8o`000003ooooool0003o000000Oo00001?ooool2o`0000Kooooo0_l00005ooooo`;o
00003?ooool2o`0000?ooooo0_l00003ooooo`;o00001?ooool2o`0001Oooooo0_l0000:ooooo`;o
00006oooool2o`0000Wooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`0Kooooo`;o0000
6_ooool2o`000003ooooool0003o000000Cooooo0_l0000Gooooo`;o00006Oooool8o`000003oooo
ool0003o000000;o000000?oooooo`000?l000006Oooool2o`000003ooooool0003o000000Gooooo
0_l0000Cooooo`;o00000oooool2o`0000[ooooo0_l000001?oooooo0000o`000?l0000@ooooo`?o
00004oooool3o`0000Wooooo0_l0000Booooo`;o0000;_ooool001cooooo00?o0000ooooooooool0
6oooool2o`0001gooooo0_l00004ooooo`;o00001_ooool2o`0000oooooo0_l0000Jooooo`;o0000
1Oooool7o`0001;ooooo0_l00006ooooo`;o000000?oooooo`000?l000005_ooool2o`0000;ooooo
0_l000000ooooooo0000o`000002o`0000[ooooo0_l00002ooooo`;o00004?ooool3o`0001Cooooo
0_l00009ooooo`?o00003?ooool2o`0000?ooooo0_l0000^ooooo`007?ooool00ol0003ooooooooo
o`0Kooooo`;o00006_ooool2o`0000oooooo0_l0000booooo`Oo00004_ooool2o`0000[ooooo0_l0
0004ooooo`;o00003oooool2o`0000Gooooo0_l0000<ooooo`;o000000?oooooo`000?l000001?l0
0002ooooo`;o0000;?ooool2o`0000cooooo0_l0000cooooo`007?ooool00ol0003oooooooooo`0b
ooooo`;o00000oooool2o`00013ooooo0_l0000=ooooo`;o000000?oooooo`000?l000007Oooool9
o`000003ooooool0003o000000oooooo0ol00009ooooo`;o00001?ooool2o`0000?ooooo0_l00008
ooooo`;o00002Oooool2o`0000Oooooo0_l000001?oooooo0000o`000?ooool6o`0000;ooooo0_l0
000jooooo`;o0000<oooool001cooooo00?o0000ooooooooool0;oooool2o`000003ooooool0003o
000000?ooooo0_l0000@ooooo`;o00001_ooool3o`0000Cooooo0_l000000ooooooo0000o`00000A
ooooo`?o00002Oooool5o`0000Gooooo0_l0000?ooooo`?o00001_ooool4o`0000[ooooo1?l00006
ooooo`;o00001oooool5o`0000Gooooo0ol0000<ooooo`;o000000?oooooo`000?l000009?ooool2
o`0000;ooooo0_l0000=ooooo`;o0000<oooool001cooooo00?o0000ooooooooool0;_ooool3o`00
0003ooooool0003o000000Go00001?ooool2o`0001;ooooo0ol0000Jooooo`?o00001_ooool2o`00
00Cooooo0_l00005ooooo`;o00002?ooool2o`0000?ooooo1_l00005ooooo`Co00000oooool2o`00
0003ooooool0003o000000Cooooo0_l00008ooooo`;o00001?ooool6o`0000Gooooo0_l00005oooo
o`;o00001?ooool4o`000003ooooool0003o000001Sooooo0_l00008ooooo`Co00000_ooool2o`00
04;ooooo000Looooo`03o`000?oooooooooo02kooooo0_l00002ooooo`Ko00001Oooool2o`0000co
oooo0_l00002ooooo`;o00009_ooool2o`0000Gooooo0_l0000>ooooo`;o00000oooool3o`000003
ooooool0003o000000cooooo1Ol0000>ooooo`;o00001?ooool2o`000003ooooool0003o000000;o
oooo1?l00007ooooo`;o00001?ooool4o`0001_ooooo0_l00008ooooo`;o00001?ooool2o`0004;o
oooo000Looooo`03o`000?oooooooooo03[ooooo0_l000000ooooooo0000o`00000<ooooo`;o0000
0_ooool2o`0002;ooooo0_l00009ooooo`;o000000?oooooo`000?l000002oooool2o`0000?ooooo
0ol00007ooooo`;o00000_ooool2o`0000;ooooo1Ol00003ooooo`;o00003_ooool2o`000003oooo
ool0003o000000?ooooo1?l00004ooooo`;o00004_ooool3o`0000;ooooo0_l0000Gooooo`;o0000
1?ooool2o`0004;ooooo000Looooo`03o`000?oooooooooo03;ooooo0_l000000ooooooo0000o`00
0003ooooo`;o000000?oooooo`000?l000004oooool2o`0001oooooo0_l0000<ooooo`;o00003ooo
ool2o`0000?ooooo0_l00004ooooo`;o00000_ooool2o`000003ooooool0003o000000;o00001Ooo
ool2o`0000?ooooo0_l00007ooooo`go00001Oooool4o`000003ooooool0003o000000gooooo0ol0
0002ooooo`;o00007?ooool2o`0004?ooooo000Looooo`03o`000?oooooooooo03;ooooo0_l00000
0ooooooo0000o`000002o`0000Oooooo0_l00007ooooo`;o00001oooool2o`000003ooooool0003o
000001cooooo0_l000000ooooooo0000o`00000Jooooo`;o000000?oooooo`000?l000000_l00003
ooooo`;o00001_ooool4o`0000Oooooo1Ol00003ooooo`;o00000_ooool5o`0000;ooooo1_l00007
ooooo`Go00009Oooool2o`0000Wooooo1?l00011ooooo`007?ooool00ol0003oooooooooo`0[oooo
o`;o00002Oooool3o`0000Oooooo0_l00007ooooo`;o00002_ooool2o`0001kooooo0ol0000Moooo
o`Co000000?oooooo`000?l000000_l00007ooooo`;o00002?ooool3o`0000Gooooo0_l00002oooo
o`Go00001Oooool2o`0000?ooooo0ol000001?oooooo0000o`000?ooool2o`0000_ooooo0_l0000I
ooooo`;o00002oooool2o`00047ooooo000Looooo`03o`000?oooooooooo02_ooooo0_l000000ooo
oooo0000o`000006ooooo`?o0000??ooool2o`00017ooooo1?l00002ooooo`;o00001Oooool2o`00
00?ooooo0_l00009ooooo`;o00003Oooool2o`0000?ooooo2Ol00003ooooo`;o00000oooool7o`00
00gooooo0_l0000Hooooo`?o0000C_ooool001cooooo00?o0000ooooooooool0;_ooool2o`0000Oo
oooo0_l00009ooooo`;o00005Oooool2o`0002_ooooo2_l00005ooooo`;o00004Oooool2o`0000[o
oooo0_l000000ooooooo0000o`000009o`000003ooooool0003o000000?o000000Goooooo`000?l0
003o0000ooooo`04o`0000;ooooo1Ol0000Cooooo`;o00001oooool2o`0000;ooooo0_l00004oooo
o`Co00000oooool2o`0004;ooooo000Looooo`03o`000?oooooooooo03;ooooo1_l0000:ooooo`Co
00004oooool2o`0000Cooooo0_l0000Uooooo`;o00000_ooool6o`000003ooooool0003o000000;o
000000?oooooo`000?l000002oooool3o`0000;ooooo0_l0000:ooooo`;o000000?oooooo`000?l0
00001?l00003ooooo`;o000000?oooooo`000?l000001ol000000ooooooo0000o`000003o`000003
ooooool0003o000000Co00000oooool2o`0000gooooo0_l00007ooooo`;o00001?ooool3o`000003
ooooool0003o000000;o00000oooool2o`0004;ooooo000Looooo`;o00006?ooool2o`0001Wooooo
1_l00006ooooo`;o000000Coooooo`000?l0003ooooo0_l0000<ooooo`?o00002_ooool2o`0001So
oooo0_l0000?ooooo`_o000000Coooooo`000?l0003ooooo0_l00006ooooo`Go00000oooool2o`00
01?ooooo3Ol00002ooooo`;o000000?oooooo`000?l000000ol00002ooooo`?o00000_ooool2o`00
00Oooooo0_l000000ooooooo0000o`000003ooooo`;o00002_ooool4o`0000;ooooo0_l00018oooo
o`007?ooool00ol0003oooooooooo`0Gooooo`;o00006Oooool2o`0000[ooooo0_l000000ooooooo
0000o`00000?ooooo`?o00001_ooool2o`00013ooooo0_l0000:ooooo`;o00000_ooool2o`0000_o
oooo2Ol00006ooooo`Co00000_ooool4o`0000Kooooo0_l00004ooooo`;o000000?oooooo`000?l0
00001Oooool2o`000003ooooool0003o000000ko000000?oooooo`000?l000000oooool5o`000005
ooooool0003o0000o`000?ooool00_l00007ooooo`Ko00000_ooool2o`0000[ooooo0_l000001?oo
oooo0000o`000?l00008ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0<_ooool2o`00
00[ooooo0_l0000Kooooo`;o00003_ooool4o`0000[ooooo0_l00002ooooo`;o00000oooool2o`00
00Kooooo1?l0000=ooooo`;o00000_ooool2o`0000_ooooo0_l000001?oooooo0000o`000?ooool2
o`0000;ooooo0_l000000ooooooo0000o`000003o`000004ooooool0003o0000oooooa;o000000?o
ooooo`000?l000001?l000000ooooooo0000o`000008ooooo`Go00001Oooool2o`0000Sooooo1Ol0
0008ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0E?ooool2o`0000Wooooo0_l0000:
ooooo`;o00003?ooool4o`0000Gooooo0_l00002ooooo`So00001Oooool4o`0000Cooooo1?l0000=
ooooo`;o00000_ooool2o`0000?ooooo0ol00002oooooaoo00001?ooool2o`0000Gooooo0_l00002
ooooo`;o00001_ooool2o`0000Cooooo0_l00002ooooo`?o00001?ooool3o`0000?ooooo0_l00010
ooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00004Oooool3o`0000Sooooo0_l00006oooo
o`;o00002Oooool2o`0000Kooooo0ol0000;ooooo`So00001?ooool2o`0000?ooooo1ol000000ooo
oooo0000o`000007o`0000Cooooo1?l000001?oooooo0000o`000?l0000=ooooo`Co000000?ooooo
o`000?l000000ooooolGo`000003ooooool0003o000000Co00000_ooool7o`0000?ooooo1_l0000<
ooooo`;o000000?oooooo`000?l000000_l000001?oooooo0000o`000?ooool3o`0000?ooooo0_l0
0010ooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o000000?oooooo`000?l000003_ooool3
o`0000Sooooo0_l00006ooooo`;o00002Oooool4o`0000Cooooo0ol0000;ooooo`Co00002?ooool4
o`0000?ooooo0_l000001?oooooo0000o`000?ooool6o`000003ooooool0003o000000Cooooo0_l0
0003ooooo`?o00001oooool3o`0000Gooooo0ol00002ooooo`?o00000ooooolIo`0000?ooooo1Ol0
00001?oooooo0000o`000?l00004ooooo`;o00000_ooool2o`0000Gooooo0_l00006ooooo`;o0000
0oooool2o`000004ooooool0003o0000o`0000oooooo0_l000000ooooooo0000o`00000aooooo`00
7?ooool00ol0003oooooooooo`0aooooo`;o00003oooool2o`00013ooooo0_l00009ooooo`Co0000
0oooool2o`0000Wooooo1?l00002ooooo`;o00002_ooool7o`0000Gooooo0_l0000Dooooo`;o0000
0oooool3o`0000Kooooo0_l00002oooooaoo00000oooool9o`0000Sooooo0_l00005ooooo`;o0000
1_ooool2o`0000Gooooo1?l00002ooooo`;o00002oooool2o`000003ooooool0003o0000037ooooo
000Looooo`03o`000?oooooooooo033ooooo0_l0000Fooooo`;o00002oooool2o`0000;ooooo0_l0
000;ooooo`;o000000?oooooo`000?l000001_ooool4o`0000;ooooo0_l000000ooooooo0000o`00
0002o`0000?ooooo0_l00002ooooo`?o00001?ooool2o`0000cooooo0_l00009ooooo`;o00001Ooo
ool2o`0000Oooooo0_l00002ooooo`Co000000?oooooo`000?l000002_l00002ooooo`[o00001Ooo
ool5o`0000[ooooo0_l00007ooooo`Co00000_ooool2o`0000Gooooo0_l00004ooooo`;o00001Ooo
ool2o`0003[ooooo000Looooo`03o`000?oooooooooo033ooooo0_l0000Booooo`;o00000_ooool2
o`0000_ooooo0_l00002ooooo`;o00002oooool2o`000003ooooool0003o000000Kooooo0_l00004
ooooo`So00000_ooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0000cooooo0_l0
000@ooooo`;o00001_ooool3o`0000;ooooo4_l000000ooooooo0000o`00000<o`0000?ooooo0_l0
000;ooooo`;o00000_ooool2o`0000;ooooo1Ol00002ooooo`;o00004_ooool2o`0003[ooooo000L
ooooo`03o`000?oooooooooo04?ooooo0ol00006ooooo`;o00000_ooool2o`000003ooooool0003o
000000;o00001_ooool2o`0000Oooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo1?l0
0002ooooo`So000000?oooooo`000?l000001?ooool5o`0001Wooooo0_l00007ooooo`;o00001Ooo
oolDo`000003ooooool0003o000000oo00000oooool2o`0000Sooooo0_l000000ooooooo0000o`00
0002ooooo`;o00000_ooool2o`000003ooooool0003o000000kooooo0_l00006ooooo`;o00000ooo
ool2o`0003Gooooo000Looooo`03o`000?oooooooooo037ooooo0_l0000@ooooo`?o00001_ooool3
o`000004ooooool0003o0000ooooo`Co00001Oooool3o`0000Wooooo4_l00006ooooo`;o000000?o
ooooo`000?l000000oooool3o`0000gooooo0_l00003ooooo`;o00001Oooool2o`0000Oooooo0_l0
0002ooooo`?o00000_oooolIo`000003ooooool0003o000000?o00000_ooool5o`000003ooooool0
003o000000Cooooo0_l00002ooooo`?o00002?ooool2o`00017ooooo0_l00006ooooo`;o00000ooo
ool2o`0003Gooooo000Looooo`03o`000?oooooooooo037ooooo1_l0000=ooooo`;o00001oooool2
o`0000Cooooo0ol00002ooooo`;o00000_ooool2o`0000Sooooo1_l000000ooooooo0000o`00000;
o`000003ooooool0003o000000Gooooo0ol000001?oooooo0000o`000?ooool2o`0000gooooo0_l0
00000ooooooo0000o`000002o`0000Cooooo0_l00007ooooo`;o00000ooooolPo`000003ooooool0
003o000000;ooooo1_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000?ooooo
0_l000000ooooooo0000o`00000Gooooo`;o00001oooool2o`0000;ooooo0_l0000fooooo`007?oo
ool00ol0003oooooooooo`0_ooooo`;o000000?oooooo`000?l000000ol0000Mooooo`;o00000_oo
ool2o`0000Sooooo0ol000000ooooooo0000o`00000@o`0000?ooooo0_l00005ooooo`;o00000_oo
ool2o`000003ooooool0003o000000Co00001_ooool2o`0000Cooooo0_l00006ooooo`;o00001ooo
ool2o`0000Gooooo1?l00003ooooob3o000000?oooooo`000?l000001Ol000000ooooooo0000o`00
0006ooooo`;o00000oooool2o`0000Kooooo0_l0000:ooooo`;o00002oooool2o`0003Kooooo000L
ooooo`03o`000?oooooooooo02oooooo0_l00003ooooo`;o00003Oooool2o`0001Kooooo0_l00005
oooooaKo00003oooool2o`0000;ooooo1?l00006ooooo`Co00004Oooool4o`0000Kooooo9_l00000
0ooooooo0000o`000003o`0000?ooooo0_l00009ooooo`Co00001_ooool2o`0004oooooo000Loooo
o`03o`000?oooooooooo03;ooooo1?l0000=ooooo`;o00002oooool2o`0000Cooooo0_l00003oooo
o`;o00001?oooolHo`0000Wooooo0_l00003ooooo`;o00002?ooool2o`0000Cooooo0_l0000Aoooo
o`?o00000oooool3o`0000;ooooo8?l000000ooooooo0000o`000002ooooo`Ko00003_ooool2o`00
00?ooooo0_l00003ooooo`;o00004Oooool2o`0003cooooo000Looooo`03o`000?oooooooooo03;o
oooo0ol0000@ooooo`;o00002Oooool4o`0000;ooooo0_l00004ooooo`;o00000_ooool4o`000003
ooooool0003o000001?o00001oooool8o`0000Sooooo0_l0000Hooooo`;o00000oooool5o`000003
ooooool0003o000002Co00000_ooool2o`0001;ooooo0ol000000ooooooo0000o`00000Cooooo`;o
0000??ooool001cooooo0_l0000[ooooo`;o00001_ooool2o`0000Gooooo0_l0000:ooooo`;o0000
2?ooool5o`0000Cooooo0_l00002ooooob;o00000oooool8o`0000?ooooo0_l00003ooooo`;o0000
2oooool2o`0000_ooooo0_l00006ooooo`;o000000?oooooo`000?l00000:?l0000Booooo`;o0000
0_ooool2o`0000Oooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`0Zooooo`;o00001_oo
ool2o`0000;ooooo0_l000000ooooooo0000o`00000@ooooo`;o00000_ooool2o`0000Kooooo0ol0
0002ooooob;o00002Oooool2o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000001?oo
ool2o`0000;ooooo0_l00002ooooo`;o00003?ooool5o`0000;ooooo8Ol000000ooooooo0000o`00
0005o`0000;ooooo0_l00005ooooo`;o00002_ooool2o`0000Sooooo0_l00002ooooo`;o00002ooo
ool2o`0003Oooooo000Looooo`03o`000?oooooooooo03Kooooo0_l000000ooooooo0000o`00000@
ooooo`;o00002_ooool2o`000003ooooool0003o000000?o000000?oooooo`000?l000007?l00008
ooooo`Co00001?ooool2o`0000Cooooo0_l00004ooooo`;o00001?ooool4o`0000Kooooo0_l00002
ooooo`Ko00000ooooolYo`000004ooooool0003o0000o`0000Gooooo1?l00008ooooo`;o00003?oo
ool2o`0000_ooooo0_l0000gooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00003oooool2
o`0000Wooooo0_l00006ooooobCo00002?ooool4o`0000Cooooo0ol0000;ooooo`?o000000Cooooo
o`000?l0003o00001oooool2o`000003ooooool0003o000000Go000000?oooooo`000?l000000_oo
oolNo`000003ooooool0003o000000[o00001oooool2o`000003ooooool0003o000000Gooooo0_l0
000Dooooo`;o0000??ooool001cooooo00?o0000ooooooooool0<oooool2o`0000kooooo0ol00000
0ooooooo0000o`000006ooooo`;o000000?oooooo`000?l000001oooool7o`000003ooooool0003o
000001Ko00005?ooool3o`0000[ooooo1?l000000ooooooo0000o`000002ooooo`;o00001_ooool2
o`000004ooooool0003o0000o`0000;ooooo0_l000000ooooooo0000o`00000Yo`0000_ooooo0_l0
0005ooooo`;o00005?ooool2o`0003cooooo000Looooo`03o`000?oooooooooo02gooooo0_l00003
ooooo`?o00003_ooool3o`0000Kooooo0_l000000ooooooo0000o`000002o`0000Gooooo4_l00000
0ooooooo0000o`00000?o`0000;ooooo0_l0000@ooooo`?o00001oooool2o`000004ooooool0003o
0000o`0000Gooooo0_l00006ooooo`;o00000_ooool2o`0000Cooooo7ol000000ooooooo0000o`00
0005o`000003ooooool0003o000000;o00000oooool2o`0000[ooooo0_l000001?oooooo0000o`00
0?l00003ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0;Oooool2o`0000?ooooo0_l0
0003ooooo`;o00004oooool2o`0000;ooooo1?l00002oooooa?o000000?oooooo`000?l000004?l0
0002ooooo`;o00001?ooool4o`0000Wooooo0_l00007ooooo`;o000000?oooooo`000?l000003_oo
ool2o`0000Gooooo0_l000000ooooooo0000o`000006o`000003ooooool0003o000001[o00000ooo
ool4o`0000?ooooo0_l00008ooooo`Co000000Coooooo`000?l0003o00000oooool2o`0000Gooooo
0_l00015ooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o00001?ooool2o`0000;ooooo0_l0
000Iooooo`;o00000_ooool8o`000003ooooool0003o000001Oo00001oooool2o`0000?ooooo1?l0
0005ooooo`;o00006?ooool6o`0000;ooooo0_l000000ooooooo0000o`000002o`000003ooooool0
003o0000027o00001?ooool2o`00013ooooo0_l0000@ooooo`;o0000AOooool001cooooo00?o0000
ooooooooool0;Oooool2o`0000Cooooo0_l00005ooooo`;o00000oooool4o`0000[ooooo0_l00003
ooooo`;o00001?ooool6o`000003ooooool0003o000001Wo00001Oooool2o`0000Cooooo0ol00005
ooooo`;o00002?ooool2o`0000[ooooo0_l00002ooooo`[o000000?oooooo`000?l000000_l00000
0ooooooo0000o`00000Qo`0000Cooooo0_l0000;ooooo`;o000000?oooooo`000?l000004_ooool2
o`0004Gooooo000Looooo`03o`000?oooooooooo03Oooooo1Ol00003ooooo`Co00002_ooool2o`00
00?ooooo0_l00004ooooob;o00002oooool4o`0000kooooo0_l00008ooooo`Co00001Oooool2o`00
0003ooooool0003o000000;o00000_ooool3o`000003ooooool0003o000000_o000000?oooooo`00
0?l000004Ol00003ooooo`Go00002oooool2o`000004ooooool0003o0000ooooo`;o00003oooool2
o`0000Wooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`0booooo`;o00000oooool3o`00
00oooooo0_l0000=ooooob3o00001Oooool3o`0000Oooooo0_l0000;ooooo`;o00002oooool5o`00
00Cooooo0_l000000ooooooo0000o`000002ooooo`;o00001_oooolOo`0000?ooooo1_l0000:oooo
o`;o00001?ooool2o`0000;ooooo0_l0000Fooooo`;o0000>_ooool001cooooo00?o0000oooooooo
ool0<_ooool2o`0000;ooooo0ol000000ooooooo0000o`000006ooooo`;o00001Oooool2o`0000go
oooo7Ol000000ooooooo0000o`000002o`0000?ooooo0ol00008ooooo`?o00002Oooool2o`000003
ooooool0003o000000_ooooo0_l00003ooooo`;o00000_ooool2o`000004ooooool0003o0000o`00
00?ooooo8Ol000001?oooooo0000o`000?ooool6o`0000[ooooo0_l00008ooooo`;o00001Oooool2
o`0000;ooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`0booooo`;o00000_ooool3o`00
0003ooooool0003o000000Kooooo0_l00005ooooo`;o00003Oooool5o`000003ooooool0003o0000
00Wo000000?oooooo`000?l000002Ol000000ooooooo0000o`000002o`0000Kooooo0_l00006oooo
o`?o00003?ooool2o`0000Gooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l00005
ooooo`?o00000ooooolHo`000003ooooool0003o000000Ko000000Coooooo`000?l0003ooooo1?l0
000<ooooo`;o00003oooool2o`0000;ooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`0b
ooooo`;o00006oooool2o`0000Cooooo0_l00005oooooaSo00001_ooool2o`0000Cooooo0_l00006
ooooo`Co000000?oooooo`000?l000000_l0000=ooooo`;o00000oooool2o`000003ooooool0003o
000000;ooooo0_l00005ooooo`;o00001OoooolPo`0000Gooooo0_l00006ooooo`;o00004_ooool3
o`0004gooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0]ooooo`;o000000?oooooo`000?l00000
7Oooool2o`0000Cooooo0_l00003ooooo`_o000000?oooooo`000?l000002Ol000000ooooooo0000
o`000006ooooo`;o00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`Oo0000
1?ooool2o`0000cooooo0_l00005ooooo`;o00000_ooool2o`0000Sooooo1?l000001?oooooo0000
o`000?oooolCo`000003ooooool0003o000000;o00003Oooool2o`000003ooooool0003o000000oo
oooo0ol0001=ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmE
EEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0;Oooool2o`000003ooooool0003o
000000?ooooo0_l0000Dooooo`;o00000_ooool2o`0000Wooooo3Ol000000ooooooo0000o`000007
o`0000Cooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l000001?oooooo0000o`000?oo
ool2o`000003ooooool0003o000000Oooooo0ol0000;ooooo`;o00000_ooool2o`0000Gooooo0_l0
0002ooooo`;o00001Oooool3o`000003ooooool0003o0000013o000000?oooooo`000?l000002Ol0
0003ooooo`;o00002?ooool2o`0001Oooooo0_l000000ooooooo0000o`000013ooooo`0000?ooooo
oa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`0eooooo`;o00005?ooool2o`0000Kooooo0_l00007oooooa?o00001_oo
ool2o`0001;ooooo0_l00005ooooo`;o00001?ooool2o`0000oooooo0_l00009ooooo`?o00000_oo
ool4o`0000;ooooo7_l00003ooooo`;o00008Oooool2o`000003ooooool0003o000004?ooooo0000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oiRHV?ooooooV9RHob4Q
8@06ooooo`?o0000>oooool4o`000003ooooool0003o0000017ooooo0_l00004ooooo`;o000000?o
ooooo`000?l000004_l0000Nooooo`Co00004oooool2o`0000Gooooo0_l00005ooooo`So000000Co
ooooo`000?l0003o00000ooooolAo`000003ooooool0003o000000Co0000Koooool00003ooooool0
003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo
00?o0000ooooooooool0>oooool4o`000003ooooool0003o000000Wooooo0_l00007ooooo`;o0000
0oooool2o`000003ooooool0003o000000co00001?ooool2o`0001?ooooo0_l00007ooooo`Co0000
0_ooool2o`00017ooooo0_l00004ooooo`?o00001_ooool3o`0000;ooooo4ol00002ooooo`_o0000
1?ooool4o`0000Cooooo0_l0000>ooooo`;o00001Oooool2o`0000Kooooo0_l00013ooooo`0000?o
oooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o
0000ooooooooool0>oooool3o`000004ooooool0003o0000o`0000?ooooo0_l00004ooooo`;o0000
1oooool2o`0000Sooooo2?l0000>ooooo`;o000000?oooooo`000?l000002_ooool2o`0000Oooooo
0_l00004ooooo`;o00005oooool2o`0000gooooo0_l000000ooooooo0000o`000006o`000003oooo
ool0003o000000[o000000?oooooo`000?l000000_l000000ooooooo0000o`000003ooooo`Co0000
1?ooool2o`0000cooooo1?l00004ooooo`?o00001Oooool3o`0000kooooo0_l0000cooooo`0000Ko
ooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000oooooooo
ool0??ooool2o`000003ooooool0003o000000Cooooo0_l00004ooooo`;o00001?ooool2o`0000_o
oooo1?l000000ooooooo0000o`000002ooooo`Co00002Oooool2o`000003ooooool0003o000000[o
oooo0_l00002ooooo`?o0000:?ooool2o`000003ooooool0003o0000017o00000oooool7o`000003
ooooool0003o000000?ooooo0_l0000Iooooo`?o00001Oooool2o`0000Kooooo1?l0000=ooooo`;o
0000<oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106
ooooo`03o`000?oooooooooo03cooooo0_l000000ooooooo0000o`000004ooooo`Co00002?ooool4
o`0000Wooooo0_l00007ooooo`Co00000_ooool2o`0001Cooooo2?l00005ooooo`;o00005oooool2
o`0000Oooooo0_l000000ooooooo0000o`000009o`0000;ooooo1Ol000000ooooooo0000o`000004
ooooo`;o00000oooool4o`0002kooooo0ol00011ooooo`007?ooool00ol0003oooooooooo`0moooo
o`;o00001Oooool5o`0000[ooooo1?l0000Fooooo`;o00004oooool2o`000003ooooool0003o0000
00Co000000?oooooo`000?l000000_ooool2o`0001Oooooo0_l0000;ooooo`;o00000_ooool6o`00
00?ooooo1ol00002ooooo`;o00001?ooool2o`000003ooooool0003o000000Cooooo0_l0000Hoooo
o`;o00003oooool2o`00047ooooo000Looooo`03o`000?oooooooooo03Sooooo0_l00003ooooo`Ko
000000?oooooo`000?l000003_ooool3o`000003ooooool0003o000000Sooooo0_l0000Looooo`Go
00000_ooool2o`0000?ooooo0_l00004ooooo`;o00008_ooool5o`000003ooooool0003o000000Wo
oooo0_l00003ooooo`Go000000Coooooo`000?l0003ooooo0_l00002ooooo`Co00001oooool2o`00
00Wooooo0_l00004ooooo`Co00002Oooool2o`0004Gooooo000Looooo`03o`000?oooooooooo03So
oooo0_l00005ooooo`Co000000?oooooo`000?l000000_ooool3o`0000Wooooo0_l00002ooooo`;o
00002?ooool2o`0001Wooooo0_l000000ooooooo0000o`000003o`0000Kooooo1?l00003ooooo`;o
00009?ooool3o`0000Kooooo0_l00008ooooo`;o000000?oooooo`000?l000000ol00002ooooo`?o
000000?oooooo`000?l000001Oooool2o`0000;ooooo0_l00002ooooo`;o00000_ooool2o`000003
ooooool0003o000000?ooooo0_l000000ooooooo0000o`000009ooooo`;o0000AOooool001cooooo
00?o0000ooooooooool0AOooool6o`0001Gooooo0_l0000Kooooo`;o00002?ooool8o`0001Oooooo
0_l0000Cooooo`;o000000?oooooo`000?l000001?l00007ooooo`;o00000oooool3o`0000;ooooo
1Ol00006ooooo`;o00001_ooool6o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000
o`00001@ooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00002_ooool4o`0000Oooooo1?l0
000<ooooo`;o00007?ooool3o`0000Kooooo1Ol0000Jooooo`;o00003_ooool2o`0000?ooooo0_l0
00000ooooooo0000o`000004o`0000[ooooo1?l00002ooooo`;o00000_ooool2o`0000?ooooo0_l0
0003ooooo`;o00001_ooool2o`0000Wooooo0_l000000ooooooo0000o`00001?ooooo`007?ooool0
0ol0003oooooooooo`0iooooo`;o00003oooool3o`0000?ooooo1?l00002ooooo`;o000000?ooooo
o`000?l000008oooool3o`0000Cooooo0_l0000_ooooo`;o00000_ooool2o`0000Kooooo1?l00008
ooooo`Co00000_ooool2o`0000Oooooo0_l00003ooooo`;o00003_ooool2o`000004ooooool0003o
0000ooooo`;o0000Coooool001cooooo00?o0000ooooooooool0@?ooool2o`0000Sooooo0ol00009
ooooo`;o000000?oooooo`000?l000007_ooool2o`0000[ooooo0_l0000@ooooo`;o00001Oooool3
o`0000Sooooo0_l00004ooooo`;o00002?ooool3o`0000Oooooo0ol00006ooooo`Co00002_ooool2
o`0001Kooooo0ol00003ooooo`;o00007?ooool2o`00037ooooo000Looooo`03o`000?oooooooooo
043ooooo0_l000001?oooooo0000o`000?l00005ooooo`;o0000;?ooool2o`0000[ooooo0_l0000@
ooooo`;o00001Oooool3o`0000Sooooo0_l00004ooooo`;o00002?ooool2o`0000Sooooo0ol00004
ooooo`Co00001?ooool2o`0000Kooooo0_l00006ooooo`;o00003_ooool3o`0000?ooooo0_l00003
ooooo`;o000000?oooooo`000?l000005?ooool2o`00037ooooo000Looooo`03o`000?oooooooooo
03oooooo1ol00005ooooo`;o0000;?ooool2o`0000[ooooo0_l0000Hooooo`;o00001Oooool2o`00
00?ooooo0_l0000Gooooo`;o00001?ooool2o`0000Kooooo0_l00002ooooo`Co000000?oooooo`00
0?l000000oooool4o`0000Oooooo0ol000001?oooooo0000o`000?ooool5o`0000Kooooo0_l00000
0ooooooo0000o`000017ooooo`007?ooool00ol0003oooooooooo`0jooooo`;o00000oooool5o`00
00Kooooo0_l000000ooooooo0000o`00000Zooooo`;o00003?ooool2o`0001?ooooo1Ol00005oooo
o`;o00000oooool2o`0000Kooooo0_l00007ooooo`;o00003Oooool2o`0000Wooooo1?l000000ooo
oooo0000o`000003ooooo`;o00002?ooool4o`000004ooooool0003o0000o`0000;ooooo0ol0000;
ooooo`;o00003oooool2o`0003Cooooo000Looooo`03o`000?oooooooooo03[ooooo0_l00003oooo
o`;o000000Coooooo`000?l0003o00001Oooool2o`000003ooooool0003o000000_ooooo0_l0000F
ooooo`;o00001Oooool2o`0000cooooo1?l0000:ooooo`;o00001Oooool7o`0000?ooooo0_l0000;
ooooo`;o00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`0000Sooooo0_l00004
ooooo`;o00000oooool2o`0000Oooooo0ol00006ooooo`Co00001?ooool2o`0000cooooo0_l00002
ooooo`;o00003oooool2o`0003Cooooo000Looooo`;o0000>oooool2o`0000?ooooo0_l00002oooo
o`;o00005Oooool4o`0001Cooooo0_l00005ooooo`;o00000_ooool2o`0000[ooooo0_l0000:oooo
o`;o00001_ooool8o`000003ooooool0003o000000;o00002Oooool2o`0000;ooooo0_l000000ooo
oooo0000o`000003ooooo`Co00003_ooool2o`000003ooooool0003o000000;o00001oooool3o`00
0003ooooool0003o000000?ooooo0ol0000?ooooo`;o00000_ooool2o`0004Wooooo000Looooo`03
o`000?oooooooooo03[ooooo0_l00002ooooo`;o00004Oooool2o`0000Wooooo0_l00004ooooo`;o
00006Oooool2o`0000gooooo0_l00007ooooo`;o000000?oooooo`000?l000000_l000000ooooooo
0000o`000006o`0000?ooooo0_l0000>ooooo`Co00001?ooool3o`0000Wooooo0_l00006ooooo`;o
00003Oooool2o`0000;ooooo1?l00004ooooo`;o000000?oooooo`000?l000001_ooool2o`0004go
oooo000Looooo`03o`000?oooooooooo03kooooo0_l0000Aooooo`;o00001_ooool2o`000003oooo
ool0003o000000;o00000_ooool2o`0001Wooooo0_l00003ooooo`;o00001oooool3o`0000Gooooo
1?l000000ooooooo0000o`00000;o`000003ooooool0003o000000?ooooo0_l00005ooooo`;o0000
1?ooool2o`0000Kooooo0_l0000:ooooo`;o00004oooool4o`000003ooooool0003o000000Go0000
0_ooool2o`000003ooooool0003o000000;o0000Doooool001cooooo00?o0000ooooooooool0BOoo
ool2o`0000kooooo0ol000001?oooooo0000o`000?l0000Booooo`;o00002Oooool2o`0000?ooooo
0ol00003ooooo`;o000000?oooooo`000?l000001_ooool2o`000003ooooool0003o000001;o0000
00?oooooo`000?l000001?ooool3o`0000cooooo0_l00002ooooo`;o00006Oooool6o`000003oooo
ool0003o000000Go00000_ooool2o`0000?ooooo0_l0001Cooooo`007?ooool00ol0003ooooooooo
o`18ooooo`Co00003_ooool2o`0001Cooooo1?l00006ooooo`;o00001_ooool3o`0000?ooooo0_l0
000<oooooaCo00001oooool3o`0000?ooooo0_l0000;ooooo`;o00002oooool2o`0000_ooooo0ol0
0002ooooo`;o00000_ooool5o`0000Sooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`13
ooooo`;o00000oooool4o`0000Sooooo0_l00002ooooo`;o00005_ooool2o`0000Cooooo0_l00002
ooooo`;o00001_ooool2o`0000kooooo6?l00002ooooo`;o00000_ooool6o`000003ooooool0003o
000001Oooooo0ol0000;ooooo`;o00001oooool4o`0000;ooooo0_l000000ooooooo0000o`000002
ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0@oooool2o`0000oooooo0_l000001?oo
oooo0000o`000?l00005ooooo`Co00004oooool2o`0001[ooooo2_l000000ooooooo0000o`00000?
o`0000;ooooo2Ol00007ooooo`;o00001?ooool2o`0000?ooooo0_l000000ooooooo0000o`000002
o`0000?ooooo0_l00003ooooo`;o00002_ooool6o`000004ooooool0003o0000ooooo`;o0000Eooo
ool001cooooo00?o0000ooooooooool0BOooool2o`0000;ooooo0_l00003ooooo`;o00000oooool2
o`0000Kooooo2_l00007ooooo`;o00007_ooool2o`000003ooooool0003o000001Oo00001oooool2
o`000003ooooool0003o000000;o000000?oooooo`000?l000000oooool2o`0000?ooooo0ol00003
ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`?o00000_ooool2o`0000[ooooo0_l0
0002ooooo`;o0000GOooool001cooooo00?o0000ooooooooool0?oooool3o`0000Oooooo0_l00002
ooooo`;o00000oooool2o`0000Kooooo0_l00002ooooo`?o00000_ooool6o`0000Oooooo0_l00005
ooooo`;o00005_ooool3o`000003ooooool0003o000000Go000000?oooooo`000?l000002_l0000=
ooooo`;o00000_ooool2o`000003ooooool0003o000000Sooooo1?l000001?oooooo0000o`000?l0
0004ooooo`;o00000oooool2o`0000[ooooo0_l000000ooooooo0000o`00001Rooooo`007?ooool0
0ol0003oooooooooo`0mooooo`Go00002_ooool2o`0000cooooo0ol000000ooooooo0000o`00000G
ooooo`;o00005_oooolGo`0000kooooo0_l00004ooooo`;o00002oooool5o`0000kooooo0_l00006
ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Pooooo`;o0000?Oooool001cooooo00?o0000
ooooooooool0?Oooool2o`0000cooooo1Ol00003ooooo`;o00000_ooool2o`0000;ooooo0_l00000
0ooooooo0000o`00000:ooooo`;o00000_ooool2o`0001Oooooo0_l000000ooooooo0000o`000005
oooooaOo00001Oooool4o`0000Sooooo0ol0000=ooooo`;o000000?oooooo`000?l000000_l0000:
ooooo`;o00002_ooool4o`0000Sooooo0_l0000Fooooo`;o0000?Oooool001cooooo00?o0000oooo
ooooool0A?ooool2o`0000?ooooo1ol00003ooooo`;o00000_ooool2o`0000Gooooo0_l00004oooo
o`;o00000oooool3o`000004ooooool0003o0000o`0001Gooooo1?l000000ooooooo0000o`000002
o`0000Gooooo5Ol00005ooooo`Co00002?ooool2o`00017ooooo1?l00006ooooo`;o00000_ooool2
o`0000Oooooo1ol00003ooooo`;o00000oooool2o`0005Gooooo000Looooo`03o`000?oooooooooo
04Cooooo0_l00003ooooo`;o00001Oooool2o`0000Gooooo0_l0000;ooooo`;o00000_ooool3o`00
00;ooooo0_l0000Booooo`;o000000?oooooo`000?l000002?l00004oooooaCo00006_ooool2o`00
01Cooooo0_l00004ooooo`;o00001Oooool4o`0000Kooooo0_l0001Jooooo`007?ooool00ol0003o
ooooooooo`0oooooo`;o000000?oooooo`000?l000001Oooool2o`0000Gooooo0_l0000;ooooo`;o
00001Oooool2o`0000;ooooo0_l0000Gooooo`Ko00000_ooool3o`0000Kooooo0ol000000ooooooo
0000o`00000?o`0000Gooooo0_l0000Aooooo`?o00001_ooool2o`00017ooooo0ol00002ooooo`;o
000000Coooooo`000?l0003o00001_ooool2o`0005_ooooo000Looooo`03o`000?oooooooooo03oo
oooo0_l000000ooooooo0000o`000005ooooo`;o00000oooool3o`0000?ooooo0_l00007ooooo`;o
00000_ooool2o`00023ooooo1?l00008ooooo`;o000000?oooooo`000?l000004ol00005ooooo`;o
00004Oooool2o`0000Oooooo0_l0000Aooooo`;o00000oooool2o`000004ooooool0003o0000o`00
00Kooooo0_l00005ooooo`;o00003?ooool2o`0004Kooooo000Looooo`03o`000?oooooooooo04[o
oooo0_l00002ooooo`?o00000oooool2o`000003ooooool0003o000000Sooooo0_l00002ooooo`;o
00001_ooool2o`0000;ooooo0_l0000Aooooo`;o00002Oooool2o`000003ooooool0003o000001;o
00002_ooool2o`0000oooooo0ol00005ooooo`;o00002oooool4o`0000?ooooo1Ol0000Aooooo`;o
00003?ooool2o`0004Kooooo000Looooo`;o0000Boooool4o`000003ooooool0003o000000Kooooo
0_l0000<ooooo`;o00001_ooool2o`0000;ooooo0_l0000>ooooo`;o000000?oooooo`000?l00000
3Oooool@o`000004ooooool0003o0000o`0000Wooooo1?l00009ooooo`;o00000_ooool:o`0000?o
oooo0_l00002ooooo`?o000000?oooooo`000?l000001?l000001?oooooo0000o`000?l0001Yoooo
o`007?ooool00ol0003oooooooooo`1<ooooo`;o000000Coooooo`000?l0003ooooo0_l00004oooo
o`;o00001?ooool2o`00027ooooo0_l0000?oooooa7o00000_ooool2o`0000Sooooo0_l000000ooo
oooo0000o`000009ooooo`;o00000_ooool8o`0000;ooooo0_l000000ooooooo0000o`000005o`00
00Gooooo0ol000001?oooooo0000o`000?l0001Xooooo`007?ooool00ol0003oooooooooo`13oooo
o`;o00001?ooool2o`0000Cooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00004oooo
o`;o00009?ooool2o`0000Wooooo0_l000000ooooooo0000o`00000;o`000003ooooool0003o0000
00[ooooo1Ol0000;ooooo`;o00000oooool4o`0000;ooooo0_l00002ooooo`;o00000_ooool5o`00
00Oooooo0_l000001?oooooo0000o`000?l0001Xooooo`007?ooool00ol0003oooooooooo`13oooo
o`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o00000oooool4o`0000[ooooo0_l0000P
ooooo`;o00002Oooool2o`000003ooooool0003o000000[o00000_ooool2o`0000[ooooo0ol00000
0ooooooo0000o`000007ooooo`;o000000?oooooo`000?l000002oooool2o`0000?ooooo1Ol0000<
ooooo`;o0000J?ooool001cooooo00?o0000ooooooooool0A_ooool4o`0000cooooo0_l0000:oooo
o`;o0000;_ooool8o`000003ooooool0003o000000;o00000oooool2o`0000cooooo0ol00006oooo
o`Go00002oooool3o`0000;ooooo0_l0000>ooooo`?o00002_ooool2o`0000;ooooo0_l0000>oooo
o`;o0000B?ooool001cooooo00?o0000ooooooooool0Aoooool5o`0000gooooo0_l0000<ooooo`;o
00001Oooool4o`00023ooooo0_l00003ooooo`?o00000oooool3o`0000;ooooo0_l0000<ooooo`?o
00001_ooool5o`0000;ooooo0_l00008ooooo`?o000000?oooooo`000?l000003_ooool3o`0000[o
oooo0_l00002ooooo`;o00002Oooool2o`0000?ooooo0_l00018ooooo`007?ooool00ol0003ooooo
ooooo`17ooooo`;o000000?oooooo`000?l000003Oooool2o`000004ooooool0003o0000o`0000So
oooo0_l00005ooooo`Co00008?ooool2o`0000Cooooo0_l00003ooooo`?o00003_ooool2o`0000Ko
oooo0ol00004ooooo`;o000000?oooooo`000?l000001Oooool6o`000003ooooool0003o0000013o
oooo1?l00007ooooo`;o00003Oooool2o`0004gooooo000Looooo`03o`000?oooooooooo05cooooo
0ol0000Oooooo`;o00004_ooool2o`0000Cooooo0_l00005ooooo`;o00003Oooool2o`0000Kooooo
0ol00004ooooo`;o00002?ooool5o`0000Gooooo0_l0000=ooooo`Co00001?ooool2o`000003oooo
ool0003o000005cooooo000Looooo`03o`000?oooooooooo05Sooooo0_l00002ooooo`;o00008?oo
ool2o`0000kooooo0_l00006ooooo`;o00001oooool2o`00027ooooo1?l00005ooooo`So00000_oo
ool2o`0000Sooooo0_l00007ooooo`;o00003oooool2o`0004kooooo000Looooo`03o`000?oooooo
oooo04gooooo0_l00003ooooo`;o00001?ooool2o`0000;ooooo0_l00003ooooo`;o00006oooool2
o`0000kooooo0_l00006ooooo`?o00007?ooool4o`0000?ooooo0_l00004ooooo`Co00001Oooool6
o`000004ooooool0003o0000ooooo`;o00001oooool3o`0001Sooooo0_l0001>ooooo`007?ooool0
0ol0003oooooooooo`1=ooooo`;o00000oooool2o`0000;ooooo1_l00005ooooo`;o00000oooool2
o`000003ooooool0003o000001?ooooo0_l0000;ooooo`;o00002_ooool4o`000003ooooool0003o
000000Gooooo0_l00007ooooo`;o00001oooool4o`0000?ooooo0_l00009ooooo`;o00002Oooool2
o`0000Cooooo0_l00004ooooo`;o00003Oooool2o`0005[ooooo000Looooo`03o`000?oooooooooo
05Kooooo1_l00005ooooo`;o00000oooool2o`000003ooooool0003o000001gooooo0_l000000ooo
oooo0000o`00000<ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`0000?ooooo0ol00000
0ooooooo0000o`00000;ooooo`;o000000?oooooo`000?l000001Oooool2o`0000;ooooo0_l0000?
ooooo`Co00003_ooool2o`000003ooooool0003o000005[ooooo000Looooo`03o`000?oooooooooo
04gooooo0_l00005ooooo`Co00002?ooool3o`0000Cooooo0_l00004ooooo`;o00002?ooool2o`00
00;ooooo0_l00006ooooo`Co000000?oooooo`000?l000004oooool2o`0000Wooooo0ol0000>oooo
o`;o00002?ooool2o`0000?ooooo0_l000000ooooooo0000o`00000;ooooo`Co00003_ooool2o`00
05gooooo000Looooo`03o`000?oooooooooo04gooooo0_l00005ooooo`;o00002_ooool2o`0000Go
oooo0_l00004ooooo`;o00001_ooool4o`0000;ooooo0_l00005ooooo`Go00001_ooool2o`0000oo
oooo0_l0000Qooooo`?o00001?ooool2o`000004ooooool0003o0000o`0000Gooooo0_l00009oooo
o`;o0000JOooool001cooooo00?o0000ooooooooool0E?ooool4o`0000Cooooo0_l0000<ooooo`;o
00002Oooool2o`0000_ooooo0_l00003ooooo`;o00001?ooool2o`000003ooooool0003o000000co
oooo0_l00007ooooo`;o00006?ooool3o`0000Cooooo0_l00002ooooo`;o00001Oooool2o`0000Wo
oooo0_l0001Yooooo`007?ooool00ol0003oooooooooo`1Dooooo`Co00001?ooool2o`0000cooooo
0ol00008ooooo`?o00001?ooool4o`0000;ooooo0_l00002ooooo`?o000000?oooooo`000?l00000
1?ooool3o`0000_ooooo0_l00007ooooo`;o00007Oooool4o`0000;ooooo0_l00006ooooo`;o0000
Loooool001cooooo0_l0001Looooo`;o00003_ooool2o`0000Sooooo0ol00002ooooo`Ko00000_oo
ool2o`0000;ooooo0_l00002ooooo`;o00001Oooool2o`0000_ooooo0_l0000Mooooo`;o00001ooo
ool4o`0000Gooooo0_l00003ooooo`;o00001oooool2o`0000Wooooo0_l00005ooooo`;o0000F?oo
ool001cooooo00?o0000ooooooooool0DOooool2o`0000Sooooo0_l0000Cooooo`;o00002?ooool2
o`0002;ooooo0_l0000:ooooo`;o00000_ooool5o`0000[ooooo0_l00002ooooo`;o000000Gooooo
o`000?l0003o0000ooooo`02o`0000Gooooo0ol0000;ooooo`;o00002Oooool2o`0000Gooooo0_l0
001Hooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o00002_ooool2o`0000cooooo0_l00003
ooooo`;o00002?ooool2o`0000Kooooo0_l00003ooooo`;o00001Oooool2o`0000;ooooo0_l0000=
ooooo`;o00001oooool9o`0000kooooo0_l000000ooooooo0000o`000003o`0000Cooooo0_l00000
0ooooooo0000o`00000Dooooo`Co0000Goooool001cooooo00?o0000ooooooooool0D_ooool2o`00
00Wooooo0_l0000<ooooo`;o00000oooool3o`0000Gooooo1?l00006ooooo`;o00000oooool2o`00
00Gooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00002Oooool3o`0000?ooooo0_l00004
ooooo`Oo00004oooool3o`0000Cooooo1?l0000Eooooo`Co0000Goooool001cooooo00?o0000oooo
ooooool0D_ooool2o`0000Kooooo0_l00006ooooo`;o00002oooool4o`0000Gooooo0_l00002oooo
o`;o00004?ooool5o`0000;ooooo0_l00009ooooo`;o00000_ooool4o`0001Sooooo0_l00005oooo
o`;o00001_ooool2o`0001Sooooo0_l0001Nooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o
00001?ooool3o`0000;ooooo0_l000000ooooooo0000o`00000;ooooo`;o00002oooool3o`0000Go
oooo0_l0000:ooooo`;o000000?oooooo`000?l000000_l0000=ooooo`;o00002_ooool2o`000003
ooooool0003o000000_ooooo0_l0000>ooooo`;o00005oooool2o`0005kooooo000Looooo`03o`00
0?oooooooooo05Cooooo1?l00003ooooo`?o000000?oooooo`000?l000007?ooool2o`0000Gooooo
0_l0000=ooooo`Co00005?ooool2o`0000;ooooo0ol000000ooooooo0000o`000008ooooo`;o0000
4Oooool2o`0007Oooooo000Looooo`03o`000?oooooooooo05Kooooo0_l00004ooooo`;o00001Ooo
ool2o`0001oooooo0_l0000=ooooo`Co00005?ooool2o`0000;ooooo0_l0000<ooooo`;o00000_oo
ool2o`0001;ooooo0_l00003ooooo`;o0000KOooool001cooooo00?o0000ooooooooool0Hoooool2
o`0000gooooo0_l0000Fooooo`;o00001Oooool4o`0002cooooo0_l0000?ooooo`;o000000?ooooo
o`000?l000001Ol0001]ooooo`007?ooool00ol0003oooooooooo`1Sooooo`;o00003Oooool4o`00
00cooooo0_l00006ooooo`;o00000_ooool8o`0000Cooooo0_l0000Nooooo`;o00005_ooool2o`00
0003ooooool0003o000000Co0000K_ooool001cooooo00?o0000ooooooooool0Loooool3o`0000co
oooo0_l00006ooooo`;o000000?oooooo`000?l000000ol00002ooooo`Co00000_ooool2o`0001Co
oooo0_l00008ooooo`;o00001?ooool2o`0008Oooooo000Looooo`03o`000?oooooooooo05Wooooo
0_l00003ooooo`;o00002?ooool4o`0000?ooooo0_l0000Aooooo`;o00002Oooool4o`0000Gooooo
0_l00003ooooo`;o00000_ooool2o`0000oooooo0_l00003ooooo`?o00001?ooool6o`0008Oooooo
000Looooo`03o`000?oooooooooo05Wooooo0_l00003ooooo`;o00002?ooool4o`000003ooooool0
003o000000;o00003Oooool2o`0000;ooooo0_l0000Booooo`;o00000oooool2o`0000;ooooo0_l0
000:ooooo`;o00002?ooool3o`0000Cooooo1?l0000Eooooo`;o0000L_ooool001cooooo00?o0000
ooooooooool0J?ooool3o`000004ooooool0003o0000o`0000Cooooo0_l00008ooooo`Go00005?oo
ool2o`0000Gooooo0_l0000<ooooo`;o000000Coooooo`000?l0003o00006?ooool2o`0000?ooooo
0_l00005ooooo`;o0000L_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Co
oooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo06cooooo0_l00005oooo
o`;o00001_ooool7o`0000Cooooo0_l0000Eooooo`;o00002oooool2o`0000;ooooo0ol0000Boooo
o`;o00001?ooool2o`0000?ooooo0_l000000ooooooo0000o`00001fooooo`0000KoooooogMgMonH
V9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o
0000ooooooooool0JOooool5o`0000_ooooo1?l000000ooooooo0000o`000006ooooo`;o00005Ooo
ool2o`0000Kooooo0_l00003ooooo`;o00001Oooool2o`0000kooooo1?l00007ooooo`;o00000ooo
ool2o`0007Kooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo06Wooooo1_l0000:ooooo`;o0000:_oo
ool2o`000003ooooool0003o000000Oooooo0_l000000ooooooo0000o`00000;ooooo`;o00002Ooo
ool2o`0000Gooooo1Ol0001aooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09
ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`0006cooooo0ol0000:ooooo`;o00003?oo
ool2o`0000?ooooo0_l000000ooooooo0000o`00000Gooooo`;o00001Oooool2o`0000?ooooo0_l0
000>ooooo`;o00003Oooool5o`00077ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo00Wooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo06cooooo0_l0
000;ooooo`;o00003?ooool4o`000004ooooool0003o0000ooooo`Go00006oooool2o`0001?ooooo
0_l00023ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj
^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`1kooooo`;o00003?ooool2o`0000Gooooo
1?l0000Mooooo`;o00003?ooool2o`0000Oooooo0_l0001oooooo`0000KoooooogMgMonHV9Sooooo
oiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`1joooo
o`?o00001oooool2o`00013ooooo0_l0000;ooooo`;o00002oooool5o`0000[ooooo0_l00007oooo
o`;o0000Ooooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@
413oZJVY00Kooooo00?o0000ooooooooool0Moooool2o`000003ooooool0003o000000Co00001?oo
ool2o`00013ooooo0_l0000;ooooo`;o00000_ooool2o`0000Oooooo1_l0000Cooooo`;o0000O_oo
ool001cooooo00?o0000ooooooooool0Moooool2o`000003ooooool0003o000000Co00005_ooool2
o`0000oooooo0_l00003ooooo`;o00001_ooool2o`0001?ooooo0_l0001nooooo`007?ooool00ol0
003oooooooooo`1`ooooo`;o00006?ooool2o`0001_ooooo0_l00003ooooo`;o00005_ooool2o`00
08?ooooo000Looooo`03o`000?oooooooooo073ooooo0_l0000Hooooo`;o00006oooool2o`0000Wo
oooo0_l0000>ooooo`Co0000Poooool001cooooo00?o0000ooooooooool0Qoooool2o`0000Kooooo
0_l0000Kooooo`;o00001?ooool2o`0000Wooooo0_l00003ooooo`;o0000QOooool001cooooo00?o
0000ooooooooool0Qoooool2o`0000Kooooo0ol0000?ooooo`;o00002Oooool2o`0000oooooo0_l0
002:ooooo`007?ooool00ol0003oooooooooo`1gooooo`;o00005oooool2o`0000Kooooo0_l00000
0ooooooo0000o`000004ooooo`;o00002Oooool2o`0009_ooooo000Looooo`03o`000?oooooooooo
07Oooooo0_l00008ooooo`Co00002oooool2o`0000Kooooo0_l000000ooooooo0000o`000009oooo
o`Co00000_ooool2o`0000Kooooo0_l0002Cooooo`007?ooool00ol0003oooooooooo`1mooooo`;o
00000_ooool4o`0000[ooooo0ol0000Dooooo`Co00000_ooool2o`0000Kooooo0_l0002Cooooo`00
7?ooool00ol0003oooooooooo`1mooooo`;o00001oooool2o`0000Oooooo0_l0000;ooooo`;o0000
Zoooool001cooooo00?o0000ooooooooool0O_ooool2o`0000Kooooo0ol0000Cooooo`;o0000Zooo
ool001cooooo00?o0000ooooooooool0O_ooool4o`0000Gooooo0ol0000Gooooo`;o0000Y_ooool0
01cooooo0_l00021ooooo`;o00001_ooool2o`0000Sooooo0_l00005ooooo`;o00001?ooool4o`00
00Kooooo0_l0002Nooooo`007?ooool00ol0003oooooooooo`27ooooo`;o000000?oooooo`000?l0
00001_ooool2o`0000Gooooo0_l00004ooooo`;o00002?ooool2o`0009kooooo000Looooo`03o`00
0?oooooooooo08Oooooo0_l000000ooooooo0000o`000003ooooo`?o00000oooool2o`0000_ooooo
0ol0002Tooooo`007?ooool00ol0003oooooooooo`2?ooooo`?o00000oooool2o`0000Wooooo1Ol0
002Tooooo`007?ooool00ol0003oooooooooo`2Nooooo`Co0000Yoooool001cooooo00?o0000oooo
ooooool0U?ooool2o`0000Sooooo0_l0000<ooooo`;o0000Voooool001cooooo00?o0000oooooooo
ool0U?ooool2o`0001Kooooo0_l0002Kooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo09_ooooo0_l0002/ooooo`007?ooool00ol0003oooooooooo`2K
ooooo`;o00002?ooool2o`0000;ooooo0_l0002Nooooo`007?ooool00ol0003oooooooooo`2Uoooo
o`;o00000_ooool2o`0009kooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001;ooooo1?l000000ol@413o
ooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo0ol0
003ooooood[ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000oooo
ooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`00
0?oooooooooo0?ooooooD_ooool001;ooooo00?oEEEEofIVI_l00000oooooomDooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00YOooool01?l@413o0000o`000?ooool2o`000003
oa0@4?oooooooooo01Oooooo00?o0000onk^k_ooool00oooool5o`0000?ooooo00Gok^k^oc8b<_l0
003o410@olc<c02@ooooo`00Y_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l0000;oooo
o`03oeEEEOnYZJWooooo00?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05oeEEEOmgMgOo
oooooiRHV?lQ8B40T?ooool00:Kooooo00Go0000ooooooooooooooooo`00000Jooooo`03ojVYZOmE
EEGooooo00Cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol0003ooooooooooooooooo0000093ooooo
002Vooooo`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo00?o8B4Qooooooooool0
1?ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?nHV9SooooooiRHV?lQ8B40T?ooool00:Kooooo
00Go0000ohN7QoooooooZJVYo`00000Kooooo`03oeEEEOo<c<cooooo00Gooooo00?oMgMgofIVI_oo
ool00_ooool01Ol0003oEEEEo`000?l@413oc<c<093ooooo002Uooooo`03oa0@4?l0003oMgMg00;o
000000?oV9RHooooooooool06Oooool00onYZJWoMgMgooooo`06ooooo`06o`000?oooooooooooooo
oomEEEGoQhN7Toooool00<?ooooo00Go410@oooooooooooooooooc8b<P03ooooo`05o`000?nj^[[o
oooooiRHV?l@41000oooool00ooMgMgo410@oiRHV02Booooo`00`oooool5o`0000?ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c004ooooo`04olc<c?m4A4Co0000oa0@493ooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(732) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.59356 .32524 Mdot
.58612 .35079 Mdot
.28265 .54857 Mdot
.6591 .57224 Mdot
.44937 .59501 Mdot
.33762 .52845 Mdot
.42184 .39703 Mdot
.38093 .39992 Mdot
.31241 .53356 Mdot
.67452 .3924 Mdot
.43638 .38818 Mdot
.63435 .49495 Mdot
.41267 .40059 Mdot
.59684 .56197 Mdot
.23542 .31841 Mdot
.55688 .57404 Mdot
.5992 .3947 Mdot
.46673 .64494 Mdot
.55894 .60476 Mdot
.29335 .53021 Mdot
.62903 .30081 Mdot
.59843 .56721 Mdot
.58159 .35754 Mdot
.59828 .56334 Mdot
.64066 .55432 Mdot
.6152 .35075 Mdot
.57889 .33274 Mdot
.64148 .58286 Mdot
.61215 .54389 Mdot
.42836 .42555 Mdot
.41773 .61093 Mdot
.1492 .46354 Mdot
.56074 .54295 Mdot
.75856 .6041 Mdot
.39268 .42712 Mdot
.36985 .77214 Mdot
.3067 .55036 Mdot
.41224 .37121 Mdot
.38362 .41745 Mdot
.38804 .40787 Mdot
.39634 .39712 Mdot
.61016 .34717 Mdot
.44828 .41348 Mdot
.39524 .34347 Mdot
.65984 .58454 Mdot
.45066 .28994 Mdot
.43246 .74914 Mdot
.63742 .58479 Mdot
.60954 .32855 Mdot
.31008 .51643 Mdot
.80371 .58541 Mdot
.40444 .37027 Mdot
.36803 .2969 Mdot
.21164 .25715 Mdot
.40275 .41951 Mdot
.65505 .58052 Mdot
.33168 .54855 Mdot
.60752 .59456 Mdot
.61319 .57956 Mdot
.79373 .54772 Mdot
.62401 .5583 Mdot
.4556 .68257 Mdot
.56408 .3691 Mdot
.27801 .56384 Mdot
.32335 .5314 Mdot
.40664 .4309 Mdot
.61962 .39555 Mdot
.41013 .39096 Mdot
.67803 .60969 Mdot
.30826 .52229 Mdot
.63852 .58756 Mdot
.43379 .38201 Mdot
.64008 .38461 Mdot
.57614 .54658 Mdot
.48741 .29822 Mdot
.28794 .29498 Mdot
.50524 .66194 Mdot
.7686 .53069 Mdot
.7145 .29144 Mdot
.30035 .34191 Mdot
.6016 .55406 Mdot
.67023 .20796 Mdot
.24878 .30921 Mdot
.5859 .36623 Mdot
.65008 .67224 Mdot
.26653 .50338 Mdot
.58048 .55048 Mdot
.44996 .53782 Mdot
.65126 .5252 Mdot
.5477 .29697 Mdot
.30936 .53758 Mdot
.61279 .33933 Mdot
.66217 .57371 Mdot
.56929 .5697 Mdot
.75599 .40182 Mdot
.61959 .51505 Mdot
.64431 .59853 Mdot
.5812 .32166 Mdot
.43455 .41076 Mdot
.6732 .53669 Mdot
.38392 .33966 Mdot
.355 .29003 Mdot
.63861 .53515 Mdot
.32544 .52279 Mdot
.58182 .38843 Mdot
.65603 .5459 Mdot
.40247 .4245 Mdot
.61652 .56253 Mdot
.36476 .39311 Mdot
.59179 .33385 Mdot
.57019 .56986 Mdot
.45487 .6498 Mdot
.53002 .27821 Mdot
.63288 .35435 Mdot
.5565 .18786 Mdot
.62625 .56749 Mdot
.60187 .57458 Mdot
.58763 .35349 Mdot
.35004 .55059 Mdot
.4366 .53074 Mdot
.62603 .39671 Mdot
.38484 .41183 Mdot
.57652 .34796 Mdot
.67397 .59869 Mdot
.36069 .53269 Mdot
.35755 .29576 Mdot
.33488 .28183 Mdot
.63115 .76583 Mdot
.58541 .54104 Mdot
.37999 .31085 Mdot
.35048 .53326 Mdot
.60117 .34202 Mdot
.40785 .39376 Mdot
.62982 .61962 Mdot
.61149 .38863 Mdot
.41165 .37683 Mdot
.44522 .6592 Mdot
.31778 .66489 Mdot
.63442 .34601 Mdot
.52682 .47618 Mdot
.39403 .44088 Mdot
.38895 .40887 Mdot
.77145 .64118 Mdot
.58765 .35958 Mdot
.468 .65945 Mdot
.41217 .37865 Mdot
.59216 .71215 Mdot
.6302 .6186 Mdot
.70705 .68985 Mdot
.71622 .25449 Mdot
.79531 .60765 Mdot
.43595 .21362 Mdot
.46637 .69128 Mdot
.3979 .38092 Mdot
.64997 .55103 Mdot
.59834 .36605 Mdot
.59992 .3568 Mdot
.57424 .59341 Mdot
.63623 .55893 Mdot
.60265 .61037 Mdot
.57948 .59638 Mdot
.41434 .74484 Mdot
.59436 .60728 Mdot
.38182 .56289 Mdot
.63037 .37935 Mdot
.631 .54768 Mdot
.31054 .56633 Mdot
.57396 .60925 Mdot
.41442 .37178 Mdot
.61207 .58413 Mdot
.64376 .5647 Mdot
.61389 .52042 Mdot
.39523 .39312 Mdot
.17337 .55296 Mdot
.67507 .24563 Mdot
.25409 .68536 Mdot
.47703 .21083 Mdot
.34225 .54364 Mdot
.58362 .56164 Mdot
.44924 .67071 Mdot
.54701 .63164 Mdot
.61532 .57673 Mdot
.82122 .53425 Mdot
.64043 .57156 Mdot
.72495 .54624 Mdot
.53778 .56428 Mdot
.23223 .67396 Mdot
.44726 .46865 Mdot
.61355 .54647 Mdot
.71118 .35397 Mdot
.72173 .69135 Mdot
.50693 .62298 Mdot
.39796 .41053 Mdot
.3297 .56585 Mdot
.32247 .55362 Mdot
.43998 .43263 Mdot
.68481 .56061 Mdot
.65542 .41761 Mdot
.69216 .56888 Mdot
.35476 .29939 Mdot
.61464 .40818 Mdot
.48769 .67539 Mdot
.62723 .33457 Mdot
.59513 .16325 Mdot
.53215 .37296 Mdot
.37179 .40963 Mdot
.44818 .649 Mdot
.28378 .55988 Mdot
.35418 .30361 Mdot
.45413 .66473 Mdot
.63435 .59872 Mdot
.60931 .33144 Mdot
.73229 .68664 Mdot
.54892 .59558 Mdot
.57956 .83345 Mdot
.59439 .38391 Mdot
.453 .49476 Mdot
.40087 .40283 Mdot
.32506 .5101 Mdot
.5903 .54471 Mdot
.5927 .59993 Mdot
.56568 .35783 Mdot
.63437 .58138 Mdot
.59835 .2848 Mdot
.64569 .56897 Mdot
.27715 .56701 Mdot
.4699 .70473 Mdot
.45066 .38618 Mdot
.6493 .75571 Mdot
.64724 .36534 Mdot
.3429 .59398 Mdot
.29451 .53832 Mdot
.67025 .37368 Mdot
.43963 .39628 Mdot
.44326 .65888 Mdot
.2988 .55573 Mdot
.44223 .69806 Mdot
.62605 .52923 Mdot
.30325 .54661 Mdot
.48311 .66683 Mdot
.27753 .64679 Mdot
.6539 .59226 Mdot
.54823 .68762 Mdot
.42319 .39166 Mdot
.58821 .32469 Mdot
.62411 .55712 Mdot
.3346 .27941 Mdot
.65303 .61913 Mdot
.34109 .25838 Mdot
.35755 .28241 Mdot
.36626 .29507 Mdot
.27597 .33149 Mdot
.44352 .68791 Mdot
.45914 .24939 Mdot
.53645 .4399 Mdot
.6142 .39883 Mdot
.66276 .57873 Mdot
.19206 .60652 Mdot
.41031 .37971 Mdot
.63311 .59811 Mdot
.25342 .5192 Mdot
.41322 .37927 Mdot
.60049 .59007 Mdot
.39315 .40455 Mdot
.59742 .36217 Mdot
.40463 .56797 Mdot
.57926 .37696 Mdot
.65257 .5892 Mdot
.41513 .41873 Mdot
.31362 .56188 Mdot
.61537 .3532 Mdot
.61741 .56694 Mdot
.58745 .5608 Mdot
.34769 .29897 Mdot
.62537 .54456 Mdot
.20247 .61058 Mdot
.64077 .58531 Mdot
.28816 .56574 Mdot
.62739 .51537 Mdot
.8019 .62711 Mdot
.32277 .66035 Mdot
.63322 .3828 Mdot
.36096 .28672 Mdot
.31385 .54006 Mdot
.40089 .60069 Mdot
.50439 .5587 Mdot
.60793 .5579 Mdot
.34667 .28351 Mdot
.42643 .50639 Mdot
.41009 .43097 Mdot
.6589 .53592 Mdot
.5222 .34661 Mdot
.29214 .54794 Mdot
.35331 .30182 Mdot
.5621 .52409 Mdot
.57857 .38344 Mdot
.65684 .57055 Mdot
.30318 .55226 Mdot
.57693 .34362 Mdot
.64455 .61603 Mdot
.4346 .75974 Mdot
.34582 .27725 Mdot
.42154 .39041 Mdot
.58659 .47029 Mdot
.61467 .61481 Mdot
.32939 .55663 Mdot
.59601 .37809 Mdot
.41381 .42507 Mdot
.62536 .3516 Mdot
.72298 .698 Mdot
.48899 .2192 Mdot
.34561 .72857 Mdot
.45745 .64467 Mdot
.33327 .24771 Mdot
.2703 .70404 Mdot
.49423 .23992 Mdot
.5855 .75851 Mdot
.36301 .79495 Mdot
.30395 .56401 Mdot
.57324 .67308 Mdot
.32038 .54362 Mdot
.64096 .54044 Mdot
.33157 .52864 Mdot
.21615 .6669 Mdot
.64336 .57836 Mdot
.34031 .54657 Mdot
.39799 .71516 Mdot
.63106 .55772 Mdot
.63475 .36721 Mdot
.18775 .37925 Mdot
.6537 .26186 Mdot
.55356 .41406 Mdot
.34728 .54713 Mdot
.81661 .44783 Mdot
.63648 .57274 Mdot
.55372 .58064 Mdot
.60337 .36548 Mdot
.65853 .53329 Mdot
.48939 .66385 Mdot
.43426 .69256 Mdot
.70707 .67938 Mdot
.58984 .21139 Mdot
.68294 .61475 Mdot
.61194 .35489 Mdot
.71991 .30002 Mdot
.48529 .30097 Mdot
.33166 .29371 Mdot
.3863 .42965 Mdot
.17496 .54874 Mdot
.59802 .6494 Mdot
.52642 .48234 Mdot
.51675 .34421 Mdot
.60227 .33536 Mdot
.24696 .63803 Mdot
.40667 .41763 Mdot
.70542 .31455 Mdot
.69989 .47701 Mdot
.61151 .61028 Mdot
.43479 .42477 Mdot
.65229 .50828 Mdot
.56956 .28874 Mdot
.59611 .69252 Mdot
.3463 .39448 Mdot
.65602 .58704 Mdot
.46571 .25739 Mdot
.60662 .57759 Mdot
.69376 .69386 Mdot
.64198 .59599 Mdot
.62823 .35836 Mdot
.69059 .60919 Mdot
.47542 .554 Mdot
.63952 .22523 Mdot
.53113 .35528 Mdot
.46161 .69466 Mdot
.5907 .5655 Mdot
.6052 .60772 Mdot
.46856 .6845 Mdot
.62011 .36575 Mdot
.63849 .60533 Mdot
.50373 .78988 Mdot
.61351 .61319 Mdot
.41814 .3697 Mdot
.42149 .57893 Mdot
.60091 .43524 Mdot
.57278 .55982 Mdot
.57164 .35923 Mdot
.39571 .41488 Mdot
.38052 .41215 Mdot
.62164 .64465 Mdot
.39684 .38366 Mdot
.65467 .57115 Mdot
.41674 .57435 Mdot
.58216 .34806 Mdot
.57544 .50404 Mdot
.61966 .37128 Mdot
.7739 .3562 Mdot
.39221 .41298 Mdot
.33911 .30237 Mdot
.51902 .57297 Mdot
.41417 .41032 Mdot
.6506 .26995 Mdot
.62031 .65204 Mdot
.61552 .6325 Mdot
.65249 .26748 Mdot
.33642 .56105 Mdot
.35081 .30779 Mdot
.40847 .42427 Mdot
.60687 .61277 Mdot
.63737 .52964 Mdot
.43795 .38448 Mdot
.77776 .42422 Mdot
.4004 .61535 Mdot
.64393 .59392 Mdot
.62663 .36175 Mdot
.60467 .34194 Mdot
.65037 .61126 Mdot
.61967 .57544 Mdot
.30052 .56895 Mdot
.34305 .28227 Mdot
.36312 .30309 Mdot
.33353 .28395 Mdot
.36031 .51647 Mdot
.36775 .24279 Mdot
.38885 .40769 Mdot
.39462 .26959 Mdot
.25378 .47567 Mdot
.59968 .64064 Mdot
.3295 .55889 Mdot
.59181 .5922 Mdot
.62742 .53407 Mdot
.41841 .42204 Mdot
.44924 .18262 Mdot
.69983 .55644 Mdot
.61759 .32419 Mdot
.41926 .36675 Mdot
.53032 .57405 Mdot
.46772 .42634 Mdot
.48483 .65769 Mdot
.53835 .37046 Mdot
.43919 .41803 Mdot
.61766 .33826 Mdot
.44271 .39744 Mdot
.60555 .60917 Mdot
.57243 .59834 Mdot
.58907 .34179 Mdot
.44233 .68811 Mdot
.64952 .53569 Mdot
.60051 .58882 Mdot
.84903 .56135 Mdot
.487 .29213 Mdot
.4638 .42845 Mdot
.6298 .54065 Mdot
.61868 .63526 Mdot
.44976 .69575 Mdot
.62382 .61226 Mdot
.58814 .54635 Mdot
.54144 .27106 Mdot
.44344 .43041 Mdot
.50033 .67358 Mdot
.69851 .30891 Mdot
.59705 .38516 Mdot
.20941 .59698 Mdot
.35623 .28911 Mdot
.45578 .39989 Mdot
.40487 .56198 Mdot
.3419 .30143 Mdot
.28041 .46342 Mdot
.22949 .6158 Mdot
.3355 .2949 Mdot
.38883 .5194 Mdot
.66666 .6605 Mdot
.59792 .61594 Mdot
.61025 .5863 Mdot
.44823 .66686 Mdot
.59055 .36265 Mdot
.43314 .48484 Mdot
.26494 .61817 Mdot
.59977 .56989 Mdot
.58425 .30829 Mdot
.22216 .58947 Mdot
.3481 .30145 Mdot
.44679 .68356 Mdot
.49047 .67504 Mdot
.60344 .57737 Mdot
.53183 .24871 Mdot
.61316 .35156 Mdot
.61717 .56698 Mdot
.57588 .58126 Mdot
.34544 .55072 Mdot
.61851 .33612 Mdot
.29532 .53709 Mdot
.35378 .27831 Mdot
.45078 .82987 Mdot
.84196 .581 Mdot
.42771 .40969 Mdot
.25631 .6746 Mdot
.38699 .38068 Mdot
.32958 .34653 Mdot
.33552 .28471 Mdot
.60923 .56684 Mdot
.64524 .36949 Mdot
.61816 .56393 Mdot
.62298 .60685 Mdot
.63278 .60225 Mdot
.68593 .61119 Mdot
.8201 .5424 Mdot
.46132 .66841 Mdot
.6312 .63683 Mdot
.34889 .56488 Mdot
.22731 .64595 Mdot
.17883 .4176 Mdot
.58246 .57919 Mdot
.59857 .57565 Mdot
.61785 .39272 Mdot
.56656 .55655 Mdot
.42227 .42923 Mdot
.58772 .3711 Mdot
.64381 .53424 Mdot
.26637 .65419 Mdot
.62898 .61431 Mdot
.28449 .71449 Mdot
.44139 .39232 Mdot
.54164 .37848 Mdot
.65567 .6279 Mdot
.3346 .29369 Mdot
.34913 .30748 Mdot
.33011 .29511 Mdot
.41994 .43351 Mdot
.33697 .55243 Mdot
.25166 .57994 Mdot
.61996 .50164 Mdot
.65175 .55534 Mdot
.62819 .63414 Mdot
.33715 .50762 Mdot
.43391 .56469 Mdot
.4398 .22192 Mdot
.54968 .62436 Mdot
.35036 .56045 Mdot
.60775 .31384 Mdot
.53598 .17062 Mdot
.59062 .37363 Mdot
.4984 .67799 Mdot
.42257 .37418 Mdot
.48452 .6543 Mdot
.82461 .49103 Mdot
.58708 .3408 Mdot
.5655 .35524 Mdot
.342 .54537 Mdot
.4685 .46974 Mdot
.11963 .3912 Mdot
.33999 .52066 Mdot
.54964 .78587 Mdot
.60761 .36343 Mdot
.58508 .52996 Mdot
.41997 .51027 Mdot
.46965 .47391 Mdot
.3314 .54024 Mdot
.5978 .55412 Mdot
.58698 .22458 Mdot
.29541 .56731 Mdot
.65495 .5336 Mdot
.35506 .54004 Mdot
.39868 .39006 Mdot
.35175 .53574 Mdot
.6337 .32723 Mdot
.62296 .53009 Mdot
.1679 .30791 Mdot
.48378 .37927 Mdot
.6212 .55736 Mdot
.41711 .36737 Mdot
.48678 .79697 Mdot
.61175 .60463 Mdot
.4893 .65996 Mdot
.36538 .5485 Mdot
.38891 .66311 Mdot
.63342 .56939 Mdot
.33687 .53298 Mdot
.61213 .31916 Mdot
.46471 .39799 Mdot
.29119 .31874 Mdot
.35937 .30642 Mdot
.59568 .3693 Mdot
.33723 .31001 Mdot
.40751 .44071 Mdot
.62975 .52114 Mdot
.57894 .59055 Mdot
.63083 .37102 Mdot
.2646 .37452 Mdot
.58179 .52498 Mdot
.60154 .55421 Mdot
.28461 .55111 Mdot
.3438 .50416 Mdot
.21278 .40466 Mdot
.30769 .56434 Mdot
.62182 .63581 Mdot
.63114 .36804 Mdot
.65078 .54567 Mdot
.63477 .37229 Mdot
.66268 .57785 Mdot
.56944 .40767 Mdot
.59022 .37029 Mdot
.5349 .205 Mdot
.60435 .53872 Mdot
.54485 .52047 Mdot
.62601 .60718 Mdot
.63832 .59926 Mdot
.36807 .54435 Mdot
.4719 .67462 Mdot
.63361 .51367 Mdot
.37502 .58442 Mdot
.43964 .67424 Mdot
.73911 .61038 Mdot
.34584 .55227 Mdot
.45171 .66018 Mdot
.51069 .71311 Mdot
.36147 .28801 Mdot
.45619 .67514 Mdot
.18178 .45448 Mdot
.42604 .41314 Mdot
.57851 .36136 Mdot
.63128 .5567 Mdot
.39865 .8178 Mdot
.41421 .61148 Mdot
.34218 .29319 Mdot
.62798 .56657 Mdot
.59625 .59634 Mdot
.58887 .39442 Mdot
.63039 .18042 Mdot
.2843 .53005 Mdot
.6603 .56386 Mdot
.59702 .39257 Mdot
.70706 .24592 Mdot
.35714 .52778 Mdot
.45146 .6757 Mdot
.42988 .37202 Mdot
.64475 .32345 Mdot
.35852 .30794 Mdot
.40249 .43262 Mdot
.37117 .5008 Mdot
.82466 .44885 Mdot
.63326 .57507 Mdot
.31977 .55841 Mdot
.79793 .60177 Mdot
.66849 .53616 Mdot
.43202 .45164 Mdot
.70894 .53758 Mdot
.6053 .33595 Mdot
.43268 .37639 Mdot
.47462 .6911 Mdot
.58032 .35122 Mdot
.6207 .36379 Mdot
.38212 .39621 Mdot
.33642 .58267 Mdot
.45562 .49308 Mdot
.42752 .37336 Mdot
.55267 .28816 Mdot
.7342 .6704 Mdot
.34653 .28192 Mdot
.44774 .68621 Mdot
.74007 .6911 Mdot
.61172 .34701 Mdot
.17485 .55001 Mdot
.81563 .55134 Mdot
.64429 .59848 Mdot
.47453 .65596 Mdot
.28187 .47324 Mdot
.24897 .58061 Mdot
.41731 .3801 Mdot
.44879 .5573 Mdot
.4924 .65964 Mdot
.61906 .61899 Mdot
.59969 .43965 Mdot
.60576 .54037 Mdot
.40736 .37845 Mdot
.61236 .2764 Mdot
.6236 .34157 Mdot
.4137 .44121 Mdot
.58117 .28776 Mdot
.62344 .53354 Mdot
.59756 .5459 Mdot
.65727 .72179 Mdot
.60996 .33069 Mdot
.3609 .30757 Mdot
.61236 .55613 Mdot
.60944 .59349 Mdot
.62409 .5189 Mdot
.54816 .50464 Mdot
.51862 .26244 Mdot
.66036 .56095 Mdot
.35974 .51959 Mdot
.58994 .6204 Mdot
.59613 .54466 Mdot
.58512 .38605 Mdot
.83812 .55633 Mdot
.34697 .27449 Mdot
.61318 .58847 Mdot
.6413 .5944 Mdot
.38487 .41748 Mdot
.43914 .49965 Mdot
.47496 .46682 Mdot
.31418 .52192 Mdot
.5761 .74573 Mdot
.69141 .57679 Mdot
.6093 .38715 Mdot
.46254 .64717 Mdot
.59262 .53043 Mdot
.60782 .39068 Mdot
.59573 .61957 Mdot
.31896 .57005 Mdot
.34374 .28333 Mdot
.56111 .45058 Mdot
.45773 .67932 Mdot
.38617 .48292 Mdot
.41414 .2958 Mdot
.31633 .56707 Mdot
.6461 .55364 Mdot
.45276 .37573 Mdot
.30054 .5352 Mdot
.34662 .29713 Mdot
.55486 .53272 Mdot
.60297 .35645 Mdot
.62381 .34395 Mdot
.70282 .68552 Mdot
.28211 .5255 Mdot
.82782 .3867 Mdot
.39948 .38845 Mdot
.67199 .59046 Mdot
.39442 .31826 Mdot
.62827 .34787 Mdot
.6949 .70847 Mdot
.44897 .66268 Mdot
.41906 .3814 Mdot
.33201 .27261 Mdot
.6128 .39109 Mdot
.62488 .33682 Mdot
.65596 .59243 Mdot
.5856 .57582 Mdot
.58211 .76437 Mdot
.70341 .69186 Mdot
.39497 .39918 Mdot
.45411 .68854 Mdot
.31366 .51799 Mdot
.62822 .53723 Mdot
.58411 .364 Mdot
.72889 .55614 Mdot
.60496 .61385 Mdot
.29353 .56698 Mdot
.59826 .338 Mdot
.46376 .68796 Mdot
.45841 .65248 Mdot
.63807 .59975 Mdot
.78197 .53671 Mdot
.41814 .40754 Mdot
.6345 .35802 Mdot
.6626 .37921 Mdot
.59135 .5183 Mdot
.58494 .57229 Mdot
.62092 .49301 Mdot
.40178 .43207 Mdot
.57775 .44578 Mdot
.49281 .64939 Mdot
.59697 .35349 Mdot
.6196 .5585 Mdot
.45524 .68234 Mdot
.55621 .47559 Mdot
.33651 .29165 Mdot
.35562 .53769 Mdot
.4903 .66629 Mdot
.47936 .67134 Mdot
.43838 .67151 Mdot
.17581 .53723 Mdot
.62221 .40409 Mdot
.69332 .28841 Mdot
.6407 .60218 Mdot
.70286 .68205 Mdot
.56458 .56626 Mdot
.41642 .43658 Mdot
.32356 .56421 Mdot
.61787 .60862 Mdot
.6567 .59169 Mdot
.62407 .45586 Mdot
.53176 .56047 Mdot
.61745 .29632 Mdot
.59893 .33095 Mdot
.53839 .52854 Mdot
.34017 .55757 Mdot
.68573 .20601 Mdot
.15203 .56669 Mdot
.66971 .61551 Mdot
.44523 .48739 Mdot
.58691 .36865 Mdot
.38446 .39435 Mdot
.47951 .4726 Mdot
.43671 .37518 Mdot
.59575 .34975 Mdot
.63582 .53853 Mdot
.39964 .26938 Mdot
.43593 .68974 Mdot
.59661 .60721 Mdot
.4013 .39704 Mdot
.59966 .60901 Mdot
.42942 .43301 Mdot
.58317 .29899 Mdot
.51791 .32638 Mdot
.64101 .57345 Mdot
.59176 .52058 Mdot
.61209 .45729 Mdot
.58325 .57893 Mdot
.30439 .43043 Mdot
.61277 .3716 Mdot
.58658 .21714 Mdot
.64979 .6095 Mdot
.78992 .49068 Mdot
.60592 .61609 Mdot
.26145 .38784 Mdot
.57946 .56477 Mdot
.48721 .50739 Mdot
.6248 .61888 Mdot
.58498 .55964 Mdot
.41113 .42102 Mdot
.38351 .41457 Mdot
.61455 .32045 Mdot
.35643 .31077 Mdot
.23147 .67008 Mdot
.59466 .58288 Mdot
.36948 .52681 Mdot
.40599 .32549 Mdot
.47683 .67268 Mdot
.59961 .348 Mdot
.75327 .26992 Mdot
.39369 .41067 Mdot
.27945 .56685 Mdot
.27826 .38635 Mdot
.30639 .51536 Mdot
.3696 .36387 Mdot
.52779 .55372 Mdot
.45904 .69109 Mdot
.60685 .61712 Mdot
.7582 .59457 Mdot
.47396 .27208 Mdot
.66479 .55117 Mdot
.42979 .44248 Mdot
.54571 .63363 Mdot
.74536 .66448 Mdot
.46395 .69928 Mdot
.47553 .68754 Mdot
.40697 .42181 Mdot
.28614 .5399 Mdot
.68145 .54263 Mdot
.45216 .65923 Mdot
.33651 .56539 Mdot
.35131 .31359 Mdot
.50484 .5902 Mdot
.61046 .3501 Mdot
.55517 .42207 Mdot
.45727 .31699 Mdot
.39468 .4018 Mdot
.3848 .57903 Mdot
.6292 .31367 Mdot
.58133 .39255 Mdot
.34443 .30828 Mdot
.36743 .54908 Mdot
.64055 .38732 Mdot
.6418 .52916 Mdot
.54946 .59919 Mdot
.60673 .57631 Mdot
.46053 .65693 Mdot
.57674 .56587 Mdot
.35634 .56167 Mdot
.41003 .38297 Mdot
.30551 .53872 Mdot
.42066 .40691 Mdot
.40399 .25373 Mdot
.62393 .57684 Mdot
.58868 .56874 Mdot
.41835 .54091 Mdot
.62085 .32906 Mdot
.80031 .53028 Mdot
.37471 .53489 Mdot
.32713 .54746 Mdot
.64802 .54207 Mdot
.60719 .31898 Mdot
.43281 .70371 Mdot
.4101 .52357 Mdot
.57648 .57392 Mdot
.61196 .37268 Mdot
.6572 .56056 Mdot
.34447 .72015 Mdot
.509 .32463 Mdot
.62589 .35043 Mdot
.6168 .20874 Mdot
.61749 .54004 Mdot
.6296 .66847 Mdot
.61266 .63581 Mdot
.51804 .77027 Mdot
.60414 .51352 Mdot
.59244 .38249 Mdot
.61207 .58216 Mdot
.60094 .38072 Mdot
.28807 .55847 Mdot
.38817 .39792 Mdot
.59855 .37085 Mdot
.57393 .55421 Mdot
.15518 .50963 Mdot
.39898 .39594 Mdot
.58894 .56221 Mdot
.43767 .41028 Mdot
.59012 .38632 Mdot
.61235 .3265 Mdot
.18562 .4583 Mdot
.44931 .44648 Mdot
.39741 .40043 Mdot
.65433 .56431 Mdot
.47119 .34615 Mdot
.65125 .54654 Mdot
.59301 .76256 Mdot
.66422 .5966 Mdot
.63078 .51602 Mdot
.30936 .25007 Mdot
.42247 .36235 Mdot
.7981 .34164 Mdot
.26884 .62706 Mdot
.17469 .52227 Mdot
.65448 .36582 Mdot
.46411 .69928 Mdot
.23982 .62581 Mdot
.35473 .28012 Mdot
.36271 .54072 Mdot
.6183 .60905 Mdot
.57922 .41917 Mdot
.42252 .3685 Mdot
.4721 .66983 Mdot
.64087 .57241 Mdot
.30998 .57069 Mdot
.19021 .42673 Mdot
.39866 .38028 Mdot
.60899 .34708 Mdot
.61904 .32659 Mdot
.68834 .24331 Mdot
.62247 .56145 Mdot
.59214 .5694 Mdot
.42008 .37299 Mdot
.68899 .57529 Mdot
.43464 .67284 Mdot
.38115 .72066 Mdot
.39814 .405 Mdot
.47882 .36901 Mdot
.59078 .33385 Mdot
.59422 .59503 Mdot
.42776 .58223 Mdot
.21918 .49447 Mdot
.69761 .37699 Mdot
.44886 .66756 Mdot
.61486 .74321 Mdot
.5929 .38293 Mdot
.40522 .39527 Mdot
.53935 .67247 Mdot
.65751 .61567 Mdot
.59929 .59594 Mdot
.62122 .73976 Mdot
.43013 .50088 Mdot
.42127 .6931 Mdot
.56678 .55172 Mdot
.43405 .50738 Mdot
.6453 .53975 Mdot
.63667 .52982 Mdot
.67624 .60989 Mdot
.58188 .55189 Mdot
.60682 .37635 Mdot
.62825 .45314 Mdot
.34503 .53147 Mdot
.74977 .38749 Mdot
.4599 .54574 Mdot
.62331 .54976 Mdot
.63174 .53668 Mdot
.67988 .35618 Mdot
.40888 .33114 Mdot
.61254 .36744 Mdot
.57976 .40992 Mdot
.39124 .41696 Mdot
.53791 .54388 Mdot
.29961 .51533 Mdot
.67614 .49866 Mdot
.30648 .53391 Mdot
.61198 .37388 Mdot
.32933 .55211 Mdot
.39108 .41967 Mdot
.31838 .55799 Mdot
.3602 .51694 Mdot
.44276 .41664 Mdot
.59164 .33094 Mdot
.578 .5758 Mdot
.39169 .40957 Mdot
.65296 .7269 Mdot
.46076 .65645 Mdot
.18519 .45727 Mdot
.55726 .59337 Mdot
.70486 .6357 Mdot
.43445 .75931 Mdot
.30814 .54459 Mdot
.51448 .30569 Mdot
.59032 .37015 Mdot
.43786 .65842 Mdot
.60363 .37828 Mdot
.81643 .52579 Mdot
.46831 .68262 Mdot
.18301 .45947 Mdot
.52569 .66873 Mdot
.36779 .60811 Mdot
.56838 .58079 Mdot
.55415 .36577 Mdot
.2985 .53859 Mdot
.41655 .36939 Mdot
.2809 .49234 Mdot
.59112 .53805 Mdot
.48929 .2383 Mdot
.61017 .40541 Mdot
.36355 .29584 Mdot
.40993 .39307 Mdot
.42214 .44543 Mdot
.62457 .56685 Mdot
.39488 .59739 Mdot
.66604 .55946 Mdot
.5326 .6516 Mdot
.59201 .75047 Mdot
.68055 .50222 Mdot
.65607 .57348 Mdot
.30713 .52756 Mdot
.65651 .56101 Mdot
.61132 .65982 Mdot
.76924 .64274 Mdot
.55886 .59816 Mdot
.5021 .21204 Mdot
.40088 .65873 Mdot
.58699 .34555 Mdot
.65236 .63149 Mdot
.34802 .29074 Mdot
.62437 .53996 Mdot
.51844 .87131 Mdot
.45987 .67473 Mdot
.27502 .52033 Mdot
.56766 .56656 Mdot
.6155 .55948 Mdot
.75822 .56121 Mdot
.54856 .37686 Mdot
.33497 .27157 Mdot
.60568 .59785 Mdot
.58809 .73147 Mdot
.41871 .42579 Mdot
.66151 .60711 Mdot
.60847 .58273 Mdot
.71352 .71405 Mdot
.42851 .4219 Mdot
.31217 .54974 Mdot
.3594 .28426 Mdot
.31903 .51665 Mdot
.47907 .69374 Mdot
.48793 .45137 Mdot
.70296 .69968 Mdot
.50706 .32625 Mdot
.48839 .65483 Mdot
.57229 .57867 Mdot
.67755 .66468 Mdot
.60653 .5479 Mdot
.47398 .68994 Mdot
.42968 .42443 Mdot
.60533 .37332 Mdot
.55275 .44716 Mdot
.35336 .29921 Mdot
.65173 .53123 Mdot
.45883 .69924 Mdot
.6004 .36317 Mdot
.20694 .44375 Mdot
.59059 .35583 Mdot
.41111 .41242 Mdot
.40863 .4388 Mdot
.46565 .68102 Mdot
.6056 .3783 Mdot
.35292 .51848 Mdot
.26992 .62495 Mdot
.6656 .5909 Mdot
.47002 .40823 Mdot
.64189 .34334 Mdot
.57548 .33637 Mdot
.63748 .38265 Mdot
.62856 .57648 Mdot
.44236 .4943 Mdot
.66754 .61025 Mdot
.4001 .42157 Mdot
.35669 .54619 Mdot
.70902 .68881 Mdot
.76892 .57598 Mdot
.4853 .37716 Mdot
.6328 .51402 Mdot
.59015 .54796 Mdot
.60331 .57712 Mdot
.64793 .59027 Mdot
.36984 .72735 Mdot
.62209 .57738 Mdot
.41705 .41553 Mdot
.32957 .52473 Mdot
.6259 .5621 Mdot
.3493 .28843 Mdot
.45938 .50433 Mdot
.46845 .64702 Mdot
.481 .5137 Mdot
.15972 .55277 Mdot
.60143 .36403 Mdot
.30272 .55718 Mdot
.35979 .53603 Mdot
.44514 .65919 Mdot
.39748 .38805 Mdot
.59106 .36037 Mdot
.50862 .75841 Mdot
.43857 .68022 Mdot
.61414 .5891 Mdot
.41233 .56835 Mdot
.58409 .19104 Mdot
.57813 .59781 Mdot
.62523 .60169 Mdot
.36516 .29164 Mdot
.28873 .52586 Mdot
.4 .83453 Mdot
.41052 .49598 Mdot
.46977 .67674 Mdot
.48063 .67847 Mdot
.63435 .38984 Mdot
.66925 .55584 Mdot
.42081 .39995 Mdot
.41795 .51669 Mdot
.51868 .80513 Mdot
.24477 .52179 Mdot
.32313 .34482 Mdot
.62889 .61277 Mdot
.74321 .53716 Mdot
.66469 .5749 Mdot
.58577 .39302 Mdot
.6262 .39256 Mdot
.61292 .3611 Mdot
.40849 .41921 Mdot
.77756 .36464 Mdot
.4195 .41369 Mdot
.15821 .55728 Mdot
.58343 .36866 Mdot
.33442 .63726 Mdot
.33529 .54932 Mdot
.62334 .50353 Mdot
.4549 .6904 Mdot
.42266 .34185 Mdot
.67301 .61888 Mdot
.52341 .24766 Mdot
.32898 .55876 Mdot
.60502 .32585 Mdot
.59299 .65205 Mdot
.25342 .71087 Mdot
.48048 .44488 Mdot
.46797 .62384 Mdot
.8029 .54476 Mdot
.46749 .68469 Mdot
.69221 .36158 Mdot
.43419 .68098 Mdot
.4123 .37778 Mdot
.58907 .53913 Mdot
.58269 .54508 Mdot
.65947 .57602 Mdot
.62448 .57971 Mdot
.41144 .42593 Mdot
.64743 .60579 Mdot
.80192 .62671 Mdot
.35039 .28046 Mdot
.30311 .66766 Mdot
.47558 .65204 Mdot
.43984 .42719 Mdot
.31612 .52793 Mdot
.3557 .31217 Mdot
.66133 .74943 Mdot
.63951 .60825 Mdot
.62275 .60808 Mdot
.33138 .28825 Mdot
.68198 .59751 Mdot
.59337 .65002 Mdot
.34058 .53042 Mdot
.50396 .40361 Mdot
.48497 .68258 Mdot
.48482 .65501 Mdot
.4427 .41077 Mdot
.60392 .37863 Mdot
.44701 .66689 Mdot
.28448 .54442 Mdot
.63677 .61824 Mdot
.60214 .52084 Mdot
.64118 .34193 Mdot
.81574 .55124 Mdot
.44372 .70053 Mdot
.63623 .6532 Mdot
.59884 .38324 Mdot
.61382 .40551 Mdot
.60468 .59923 Mdot
.55613 .53861 Mdot
.57756 .33766 Mdot
.47125 .64974 Mdot
.4412 .4245 Mdot
.35665 .61778 Mdot
.40658 .38058 Mdot
.59439 .36375 Mdot
.62248 .62717 Mdot
.59134 .33198 Mdot
.62224 .54194 Mdot
.501 .11384 Mdot
.57995 .55663 Mdot
.64833 .26402 Mdot
.52827 .77274 Mdot
.35765 .53266 Mdot
.34742 .51673 Mdot
.34687 .28472 Mdot
.59549 .38259 Mdot
.5957 .52912 Mdot
.47355 .68535 Mdot
.17214 .50511 Mdot
.62162 .41209 Mdot
.35226 .55774 Mdot
.29547 .51865 Mdot
.42133 .4281 Mdot
.59301 .60945 Mdot
.59127 .5896 Mdot
.31681 .5568 Mdot
.42668 .75444 Mdot
.61459 .38606 Mdot
.59257 .56898 Mdot
.59256 .54562 Mdot
.3451 .52868 Mdot
.27398 .6302 Mdot
.55772 .33159 Mdot
.58328 .55088 Mdot
.52064 .67743 Mdot
.41854 .43528 Mdot
.64772 .58171 Mdot
.64786 .60378 Mdot
.47765 .66382 Mdot
.29423 .67603 Mdot
.75225 .65902 Mdot
.4331 .43513 Mdot
.36189 .30547 Mdot
.5738 .55009 Mdot
.33579 .54751 Mdot
.58664 .52878 Mdot
.33676 .75674 Mdot
.35616 .28473 Mdot
.61388 .5705 Mdot
.67267 .61148 Mdot
.63593 .35457 Mdot
.61559 .56801 Mdot
.67703 .49351 Mdot
.32675 .5185 Mdot
.61557 .57091 Mdot
.78671 .53127 Mdot
.41461 .42847 Mdot
.66309 .62519 Mdot
.48629 .67445 Mdot
.5135 .77321 Mdot
.43053 .3041 Mdot
.35564 .51115 Mdot
.46461 .65178 Mdot
.57588 .56982 Mdot
.28715 .54399 Mdot
.42466 .36768 Mdot
.5047 .23895 Mdot
.59928 .61763 Mdot
.40274 .38456 Mdot
.40913 .38507 Mdot
.4637 .67894 Mdot
.75605 .2913 Mdot
.6848 .5968 Mdot
.58113 .577 Mdot
.63701 .78728 Mdot
.61747 .40079 Mdot
.58003 .57837 Mdot
.58454 .60064 Mdot
.42474 .39583 Mdot
.51776 .56797 Mdot
.65232 .29237 Mdot
.39812 .71574 Mdot
.42826 .43356 Mdot
.37911 .52749 Mdot
.28765 .54555 Mdot
.47258 .65201 Mdot
.58992 .34348 Mdot
.49035 .65261 Mdot
.34686 .54045 Mdot
.64094 .59858 Mdot
.42734 .38908 Mdot
.70748 .41627 Mdot
.40383 .37026 Mdot
.29214 .56872 Mdot
.56949 .35748 Mdot
.38966 .31355 Mdot
.69922 .77631 Mdot
.45473 .30519 Mdot
.44633 .42043 Mdot
.47713 .67212 Mdot
.40291 .52089 Mdot
.59108 .54786 Mdot
.69655 .32757 Mdot
.58439 .59467 Mdot
.8022 .54883 Mdot
.32769 .56494 Mdot
.34066 .30601 Mdot
.58936 .5385 Mdot
.6075 .74106 Mdot
.443 .42528 Mdot
.41586 .43013 Mdot
.63001 .59208 Mdot
.41333 .41185 Mdot
.58859 .58012 Mdot
.34149 .52382 Mdot
.76714 .30911 Mdot
.58855 .55411 Mdot
.57933 .62139 Mdot
.45027 .42114 Mdot
.18462 .45737 Mdot
.37418 .54514 Mdot
.74665 .54359 Mdot
.27274 .73657 Mdot
.4147 .40859 Mdot
.61273 .63747 Mdot
.30252 .54836 Mdot
.36601 .2933 Mdot
.35654 .56913 Mdot
.59541 .60418 Mdot
.63189 .60786 Mdot
.65342 .54637 Mdot
.59831 .54503 Mdot
.69137 .3273 Mdot
.54581 .61026 Mdot
.72779 .49681 Mdot
.62451 .60662 Mdot
.64478 .4097 Mdot
.41706 .41947 Mdot
.61372 .29653 Mdot
.42566 .66374 Mdot
.63581 .6069 Mdot
.55294 .39262 Mdot
.43708 .43094 Mdot
.16538 .56581 Mdot
.42549 .42535 Mdot
.31319 .53821 Mdot
.38682 .38902 Mdot
.62388 .544 Mdot
.60652 .34152 Mdot
.33068 .52046 Mdot
.43046 .22947 Mdot
.36311 .54373 Mdot
.6216 .55797 Mdot
.30106 .65101 Mdot
.35788 .53534 Mdot
.46719 .50734 Mdot
.60163 .34086 Mdot
.59348 .72459 Mdot
.60954 .39993 Mdot
.61047 .56451 Mdot
.60617 .56021 Mdot
.35938 .31269 Mdot
.39686 .38141 Mdot
.58823 .38299 Mdot
.8516 .55501 Mdot
.49506 .67643 Mdot
.61784 .35674 Mdot
.57908 .51958 Mdot
.43254 .49459 Mdot
.63264 .35754 Mdot
.55241 .73991 Mdot
.40212 .37966 Mdot
.6403 .38494 Mdot
.58167 .5137 Mdot
.52051 .49253 Mdot
.43068 .6812 Mdot
.32615 .57065 Mdot
.51072 .46749 Mdot
.29839 .53392 Mdot
.42656 .43935 Mdot
.27889 .54257 Mdot
.41966 .42443 Mdot
.6549 .27041 Mdot
.61578 .27849 Mdot
.4441 .36993 Mdot
.40907 .44001 Mdot
.33972 .53986 Mdot
.64575 .5922 Mdot
.46545 .56396 Mdot
.599 .51176 Mdot
.57043 .59331 Mdot
.40319 .43102 Mdot
.59779 .38905 Mdot
.57843 .34675 Mdot
.55711 .35422 Mdot
.61868 .32938 Mdot
.31581 .52657 Mdot
.52109 .30747 Mdot
.82002 .49921 Mdot
.43987 .3992 Mdot
.37518 .39141 Mdot
.64693 .54335 Mdot
.33773 .54488 Mdot
.29459 .56336 Mdot
.41997 .39081 Mdot
.71385 .37591 Mdot
.61948 .63434 Mdot
.59048 .39291 Mdot
.58304 .36741 Mdot
.63138 .35996 Mdot
.64152 .36284 Mdot
.749 .3416 Mdot
.4163 .36932 Mdot
.58925 .3764 Mdot
.62389 .58508 Mdot
.62069 .61288 Mdot
.3582 .30393 Mdot
.48548 .66197 Mdot
.56146 .59509 Mdot
.57081 .61088 Mdot
.60292 .59945 Mdot
.35651 .53751 Mdot
.59799 .49533 Mdot
.35812 .28955 Mdot
.28252 .53257 Mdot
.32819 .50823 Mdot
.34074 .30387 Mdot
.66523 .35917 Mdot
.24808 .71485 Mdot
.66015 .56346 Mdot
.56521 .66083 Mdot
.33197 .54455 Mdot
.5799 .25824 Mdot
.59121 .45076 Mdot
.65414 .57345 Mdot
.50087 .54462 Mdot
.33865 .5215 Mdot
.60345 .40751 Mdot
.58387 .58923 Mdot
.3355 .28308 Mdot
.46112 .64815 Mdot
.58823 .5118 Mdot
.36421 .28897 Mdot
.6128 .37572 Mdot
.425 .63339 Mdot
.63363 .3939 Mdot
.35829 .52726 Mdot
.66445 .62487 Mdot
.12299 .37739 Mdot
.29517 .54166 Mdot
.1996 .54219 Mdot
.60532 .28292 Mdot
.5871 .55289 Mdot
.29573 .53691 Mdot
.59545 .40514 Mdot
.4152 .4354 Mdot
.4359 .5155 Mdot
.58407 .36132 Mdot
.35236 .3119 Mdot
.35233 .30654 Mdot
.34459 .53019 Mdot
.60148 .33288 Mdot
.65762 .60318 Mdot
.63484 .37639 Mdot
.38908 .3851 Mdot
.64307 .56365 Mdot
.23274 .6755 Mdot
.55028 .60229 Mdot
.60064 .38562 Mdot
.28165 .5618 Mdot
.44651 .69374 Mdot
.64031 .57497 Mdot
.21194 .57583 Mdot
.58737 .60444 Mdot
.43529 .41652 Mdot
.57528 .2408 Mdot
.69587 .41898 Mdot
.64248 .59543 Mdot
.63869 .53853 Mdot
.44375 .40925 Mdot
.64436 .59585 Mdot
.58132 .60067 Mdot
.44178 .44455 Mdot
.63191 .34849 Mdot
.60536 .57311 Mdot
.31614 .56827 Mdot
.77392 .60338 Mdot
.57396 .54766 Mdot
.48463 .20514 Mdot
.6001 .73249 Mdot
.5878 .24385 Mdot
.57891 .54053 Mdot
.66135 .72675 Mdot
.60081 .5595 Mdot
.63448 .57987 Mdot
.65909 .5688 Mdot
.72943 .52298 Mdot
.3428 .5419 Mdot
.35399 .55974 Mdot
.42918 .67668 Mdot
.5964 .73488 Mdot
.47285 .65666 Mdot
.43715 .42505 Mdot
.27433 .33545 Mdot
.35176 .282 Mdot
.60262 .37926 Mdot
.62791 .53029 Mdot
.36452 .5322 Mdot
.59405 .59759 Mdot
.62903 .54238 Mdot
.34863 .52417 Mdot
.29157 .54229 Mdot
.27533 .53397 Mdot
.43669 .68315 Mdot
.60726 .36719 Mdot
.65428 .59271 Mdot
.43978 .67492 Mdot
.657 .60719 Mdot
.41944 .4991 Mdot
.60967 .36688 Mdot
.63597 .37321 Mdot
.5772 .37161 Mdot
.6395 .60284 Mdot
.62569 .54708 Mdot
.42061 .41231 Mdot
.64201 .3419 Mdot
.43644 .38532 Mdot
.30026 .53335 Mdot
.352 .52045 Mdot
.59653 .60503 Mdot
.61863 .65529 Mdot
.47995 .67726 Mdot
.31123 .54136 Mdot
.33085 .28194 Mdot
.43061 .6719 Mdot
.62842 .56757 Mdot
.30472 .53028 Mdot
.48696 .65799 Mdot
.73917 .39668 Mdot
.31794 .77161 Mdot
.44753 .69637 Mdot
.62828 .59145 Mdot
.7627 .56352 Mdot
.56396 .67908 Mdot
.49823 .66894 Mdot
.43762 .39638 Mdot
.59216 .60751 Mdot
.45923 .7892 Mdot
.49345 .66784 Mdot
.81171 .56091 Mdot
.35315 .52943 Mdot
.51985 .5934 Mdot
.57594 .51792 Mdot
.71345 .33384 Mdot
.49342 .65756 Mdot
.59385 .35784 Mdot
.64649 .34896 Mdot
.62123 .59179 Mdot
.48583 .6394 Mdot
.37894 .40809 Mdot
.36026 .53264 Mdot
.36621 .52391 Mdot
.60796 .33344 Mdot
.49462 .35465 Mdot
.30269 .56806 Mdot
.69544 .59157 Mdot
.39013 .51765 Mdot
.55466 .5133 Mdot
.71153 .28648 Mdot
.41685 .23709 Mdot
.60987 .52012 Mdot
.45523 .69643 Mdot
.44042 .38295 Mdot
.41807 .41239 Mdot
.40607 .41429 Mdot
.33747 .51463 Mdot
.47975 .47998 Mdot
.32532 .56075 Mdot
.48527 .24729 Mdot
.45441 .68222 Mdot
.57939 .7133 Mdot
.59008 .53333 Mdot
.58935 .55086 Mdot
.65098 .61394 Mdot
.65063 .54224 Mdot
.59959 .56049 Mdot
.39569 .39888 Mdot
.3227 .51242 Mdot
.38932 .67133 Mdot
.6274 .36492 Mdot
.22502 .4016 Mdot
.33513 .54965 Mdot
.3623 .28804 Mdot
.46429 .66703 Mdot
.68986 .70024 Mdot
.37042 .50984 Mdot
.32876 .55136 Mdot
.61782 .62363 Mdot
.61345 .39493 Mdot
.55108 .49762 Mdot
.60118 .55419 Mdot
.31013 .54263 Mdot
.28441 .57231 Mdot
.6865 .38387 Mdot
.67984 .52714 Mdot
.44608 .70856 Mdot
.43744 .4926 Mdot
.48952 .64728 Mdot
.55201 .55132 Mdot
.57661 .25875 Mdot
.3457 .53927 Mdot
.31941 .53373 Mdot
.46662 .69651 Mdot
.64368 .66547 Mdot
.59617 .3368 Mdot
.33866 .30426 Mdot
.43607 .40767 Mdot
.6053 .55113 Mdot
.33013 .51557 Mdot
.56018 .65485 Mdot
.40844 .56841 Mdot
.39977 .40742 Mdot
.28307 .53119 Mdot
.60986 .61679 Mdot
.62931 .59473 Mdot
.47058 .68247 Mdot
.44129 .6025 Mdot
.58679 .5147 Mdot
.17486 .52316 Mdot
.51693 .33225 Mdot
.52822 .35711 Mdot
.59888 .59557 Mdot
.61517 .33397 Mdot
.33471 .28599 Mdot
.44726 .68642 Mdot
.64574 .61353 Mdot
.29047 .75571 Mdot
.61728 .3135 Mdot
.40262 .3928 Mdot
.33376 .28774 Mdot
.47901 .48251 Mdot
.58506 .60207 Mdot
.58424 .59423 Mdot
.62662 .57805 Mdot
.31458 .7781 Mdot
.34206 .56419 Mdot
.64049 .37497 Mdot
.45092 .66535 Mdot
.63405 .3443 Mdot
.3589 .5548 Mdot
.54064 .43425 Mdot
.62842 .56308 Mdot
.58457 .38801 Mdot
.59341 .35509 Mdot
.4213 .42834 Mdot
.40501 .43524 Mdot
.28454 .51709 Mdot
.58029 .55818 Mdot
.33967 .28017 Mdot
.61655 .39758 Mdot
.29263 .52659 Mdot
.46764 .68358 Mdot
.39195 .4153 Mdot
.62673 .60576 Mdot
.3447 .53438 Mdot
.65315 .53601 Mdot
.63244 .37434 Mdot
.32957 .55083 Mdot
.35385 .27568 Mdot
.4831 .67438 Mdot
.63058 .60677 Mdot
.41003 .66049 Mdot
.3347 .29643 Mdot
.5961 .54102 Mdot
.72952 .6166 Mdot
.4346 .64898 Mdot
.43261 .22589 Mdot
.31118 .56082 Mdot
.35443 .29244 Mdot
.63068 .38914 Mdot
.53544 .48718 Mdot
.31944 .53131 Mdot
.72147 .58085 Mdot
.45931 .58394 Mdot
.65341 .59202 Mdot
.61774 .34692 Mdot
.45313 .71843 Mdot
.17174 .55563 Mdot
.54114 .68168 Mdot
.59599 .57001 Mdot
.29635 .53547 Mdot
.48254 .65222 Mdot
.44085 .40653 Mdot
.48719 .20556 Mdot
.71062 .29192 Mdot
.28262 .52773 Mdot
.6621 .56704 Mdot
.61653 .39726 Mdot
.41819 .38968 Mdot
.39571 .26225 Mdot
.28312 .54772 Mdot
.318 .5654 Mdot
.63387 .57244 Mdot
.44464 .67309 Mdot
.41756 .7484 Mdot
.35239 .56192 Mdot
.3186 .51581 Mdot
.21762 .40813 Mdot
.44416 .69931 Mdot
.62074 .58536 Mdot
.55699 .35462 Mdot
.62614 .62031 Mdot
.18435 .52121 Mdot
.35447 .28813 Mdot
.62708 .36833 Mdot
.60822 .61252 Mdot
.39869 .6599 Mdot
.31119 .5314 Mdot
.44756 .48669 Mdot
.27226 .55712 Mdot
.39588 .39356 Mdot
.33305 .51596 Mdot
.58666 .59075 Mdot
.43929 .43352 Mdot
.48111 .67506 Mdot
.58282 .55131 Mdot
.62752 .54703 Mdot
.5903 .40041 Mdot
.41557 .37663 Mdot
.74391 .64526 Mdot
.38898 .43645 Mdot
.44265 .39773 Mdot
.63397 .39984 Mdot
.61775 .59065 Mdot
.31633 .54287 Mdot
.32549 .57166 Mdot
.65311 .60291 Mdot
.58138 .2615 Mdot
.60188 .33535 Mdot
.30818 .50413 Mdot
.39831 .83138 Mdot
.68996 .55455 Mdot
.34093 .27649 Mdot
.66395 .67878 Mdot
.4143 .43244 Mdot
.63082 .59932 Mdot
.60519 .38492 Mdot
.30717 .51779 Mdot
.30562 .5684 Mdot
.64022 .62003 Mdot
.41428 .38399 Mdot
.47784 .64816 Mdot
.30307 .56417 Mdot
.40616 .56665 Mdot
.61966 .56994 Mdot
.48847 .23629 Mdot
.3013 .56089 Mdot
.16244 .4439 Mdot
.3943 .66359 Mdot
.6248 .35128 Mdot
.63446 .54324 Mdot
.61587 .32248 Mdot
.45625 .66153 Mdot
.3812 .54975 Mdot
.41236 .38213 Mdot
.70694 .5856 Mdot
.76105 .68458 Mdot
.34246 .54539 Mdot
.60805 .37547 Mdot
.64138 .60077 Mdot
.70281 .59225 Mdot
.57802 .568 Mdot
.51848 .55554 Mdot
.42012 .65606 Mdot
.39855 .43107 Mdot
.43608 .41896 Mdot
.62472 .53401 Mdot
.43558 .67523 Mdot
.35929 .56258 Mdot
.35138 .52777 Mdot
.67531 .19222 Mdot
.3563 .27713 Mdot
.56721 .77236 Mdot
.63441 .60416 Mdot
.29639 .5212 Mdot
.76801 .58023 Mdot
.42031 .37294 Mdot
.67042 .57215 Mdot
.33961 .50996 Mdot
.22026 .48002 Mdot
.42322 .50053 Mdot
.60844 .56951 Mdot
.68893 .56831 Mdot
.43675 .41089 Mdot
.40533 .51256 Mdot
.32403 .55988 Mdot
.66734 .59597 Mdot
.39657 .43972 Mdot
.20071 .43038 Mdot
.79158 .6518 Mdot
.60761 .36673 Mdot
.28186 .56516 Mdot
.39601 .39467 Mdot
.63785 .50507 Mdot
.47624 .65194 Mdot
.31158 .5208 Mdot
.36028 .54163 Mdot
.64388 .55791 Mdot
.55939 .58782 Mdot
.69177 .55743 Mdot
.61948 .36697 Mdot
.42572 .40966 Mdot
.59975 .5321 Mdot
.5002 .35524 Mdot
.6566 .54907 Mdot
.42528 .40566 Mdot
.28207 .20058 Mdot
.59741 .61754 Mdot
.57991 .57195 Mdot
.45564 .74042 Mdot
.58247 .34433 Mdot
.62782 .33771 Mdot
.51844 .3191 Mdot
.6341 .60444 Mdot
.38218 .60578 Mdot
.6045 .36844 Mdot
.6049 .33635 Mdot
.32623 .64273 Mdot
.64627 .56709 Mdot
.39258 .49856 Mdot
.42166 .3986 Mdot
.39326 .40034 Mdot
.6365 .36069 Mdot
.62004 .50239 Mdot
.43217 .37393 Mdot
.68183 .30219 Mdot
.33719 .55193 Mdot
.57622 .25837 Mdot
.62375 .38768 Mdot
.43492 .59189 Mdot
.40723 .37777 Mdot
.14438 .53916 Mdot
.50662 .50466 Mdot
.66655 .57082 Mdot
.63575 .59516 Mdot
.47971 .66464 Mdot
.62132 .64614 Mdot
.36291 .30411 Mdot
.41221 .41344 Mdot
.3192 .71685 Mdot
.61342 .36012 Mdot
.58104 .56681 Mdot
.69646 .69059 Mdot
.41598 .26897 Mdot
.51317 .21157 Mdot
.58702 .34744 Mdot
.61412 .34901 Mdot
.33772 .55884 Mdot
.35095 .54851 Mdot
.6136 .57931 Mdot
.41125 .41942 Mdot
.6472 .36704 Mdot
.43137 .4054 Mdot
.34703 .53952 Mdot
.32562 .5483 Mdot
.35801 .28628 Mdot
.67584 .55401 Mdot
.35492 .5268 Mdot
.19733 .44991 Mdot
.49938 .36148 Mdot
.5856 .4004 Mdot
.69231 .7769 Mdot
.39107 .26072 Mdot
.46795 .75426 Mdot
.45184 .65094 Mdot
.3574 .27262 Mdot
.38267 .40336 Mdot
.63069 .53563 Mdot
.60948 .60772 Mdot
.34741 .30136 Mdot
.39241 .38873 Mdot
.47026 .66575 Mdot
.3966 .38135 Mdot
.44766 .68176 Mdot
.37241 .54114 Mdot
.57397 .54806 Mdot
.57725 .59014 Mdot
.39644 .40552 Mdot
.31463 .55216 Mdot
.35831 .52972 Mdot
.43443 .66595 Mdot
.67641 .70319 Mdot
.34594 .53119 Mdot
.62568 .3864 Mdot
.80462 .45424 Mdot
.35131 .30579 Mdot
.58318 .58646 Mdot
.69984 .69507 Mdot
.69794 .36281 Mdot
.65818 .5849 Mdot
.33348 .28928 Mdot
.69747 .21331 Mdot
.58257 .54209 Mdot
.6927 .22767 Mdot
.3576 .2951 Mdot
.58569 .33573 Mdot
.2994 .55013 Mdot
.36252 .30665 Mdot
.6229 .49939 Mdot
.49484 .68382 Mdot
.55784 .59275 Mdot
.5832 .35619 Mdot
.57308 .3653 Mdot
.5741 .28737 Mdot
.18625 .52341 Mdot
.44672 .69074 Mdot
.46848 .67234 Mdot
.32372 .52963 Mdot
.30095 .28362 Mdot
.56819 .52911 Mdot
.47116 .67259 Mdot
.36311 .74373 Mdot
.64961 .54634 Mdot
.60364 .75929 Mdot
.49967 .54272 Mdot
.61351 .33385 Mdot
.65389 .31041 Mdot
.31644 .53055 Mdot
.60803 .37483 Mdot
.52568 .39459 Mdot
.65008 .61415 Mdot
.61146 .36481 Mdot
.42623 .40121 Mdot
.29929 .45977 Mdot
.61096 .32395 Mdot
.42678 .52532 Mdot
.42016 .39953 Mdot
.44017 .6456 Mdot
.51384 .72077 Mdot
.51009 .88192 Mdot
.41174 .41519 Mdot
.30421 .54582 Mdot
.35579 .52606 Mdot
.34374 .52644 Mdot
.58373 .36142 Mdot
.28712 .55568 Mdot
.62223 .37254 Mdot
.25359 .60111 Mdot
.67702 .71797 Mdot
.46346 .68256 Mdot
.45637 .43888 Mdot
.60171 .34998 Mdot
.50097 .2767 Mdot
.71387 .75584 Mdot
.62968 .59014 Mdot
.39229 .43817 Mdot
.47 .6947 Mdot
.26684 .28864 Mdot
.47722 .6627 Mdot
.30265 .54921 Mdot
.57495 .25748 Mdot
.58925 .57895 Mdot
.69529 .51309 Mdot
.47843 .6825 Mdot
.58533 .35202 Mdot
.59322 .54342 Mdot
.262 .54072 Mdot
.46615 .65276 Mdot
.46275 .64822 Mdot
.59614 .56122 Mdot
.6066 .32754 Mdot
.32042 .54684 Mdot
.38444 .41105 Mdot
.42244 .6883 Mdot
.64883 .51878 Mdot
.64856 .59171 Mdot
.67342 .5903 Mdot
.47143 .46806 Mdot
.43134 .76881 Mdot
.41541 .40668 Mdot
.60587 .68934 Mdot
.35282 .54144 Mdot
.52882 .67858 Mdot
.4842 .30467 Mdot
.45316 .43997 Mdot
.35532 .28914 Mdot
.35329 .28567 Mdot
.60461 .56644 Mdot
.41935 .76826 Mdot
.57494 .21226 Mdot
.40571 .45457 Mdot
.34399 .30337 Mdot
.35843 .53062 Mdot
.63506 .32655 Mdot
.55842 .3057 Mdot
.5619 .58525 Mdot
.40278 .43312 Mdot
.34942 .53375 Mdot
.34051 .75982 Mdot
.45478 .67984 Mdot
.53192 .28692 Mdot
.62485 .55925 Mdot
.58977 .56976 Mdot
.41244 .39625 Mdot
.4203 .41185 Mdot
.48086 .21898 Mdot
.53388 .31621 Mdot
.24269 .53248 Mdot
.37552 .45991 Mdot
.36932 .77802 Mdot
.59614 .30158 Mdot
.60413 .38657 Mdot
.35683 .28142 Mdot
.44422 .39736 Mdot
.58117 .58875 Mdot
.58194 .3398 Mdot
.51857 .21082 Mdot
.65017 .38604 Mdot
.60204 .75373 Mdot
.3914 .60492 Mdot
.61546 .54826 Mdot
.61705 .39485 Mdot
.60887 .37254 Mdot
.63751 .34621 Mdot
.33918 .30172 Mdot
.60312 .59646 Mdot
.64548 .59177 Mdot
.5921 .53819 Mdot
.65914 .63946 Mdot
.61694 .56815 Mdot
.48271 .31681 Mdot
.47932 .37063 Mdot
.30345 .69561 Mdot
.66071 .58245 Mdot
.39721 .38495 Mdot
.62951 .52964 Mdot
.43647 .67027 Mdot
.66276 .56842 Mdot
.5853 .76691 Mdot
.40532 .40684 Mdot
.65481 .6631 Mdot
.36895 .45146 Mdot
.62522 .55819 Mdot
.48878 .65633 Mdot
.42681 .76411 Mdot
.74145 .67642 Mdot
.21369 .41715 Mdot
.62745 .38502 Mdot
.334 .50387 Mdot
.39244 .37958 Mdot
.31743 .54157 Mdot
.66755 .58329 Mdot
.34671 .2763 Mdot
.34586 .24715 Mdot
.4382 .57903 Mdot
.58651 .5994 Mdot
.53938 .56362 Mdot
.62536 .3446 Mdot
.30284 .53501 Mdot
.62308 .30485 Mdot
.63167 .57913 Mdot
.45272 .66181 Mdot
.44566 .66566 Mdot
.52413 .34547 Mdot
.27405 .69874 Mdot
.54026 .49321 Mdot
.41373 .39826 Mdot
.30088 .56894 Mdot
.49362 .65943 Mdot
.65761 .27614 Mdot
.37846 .40917 Mdot
.41393 .43239 Mdot
.42046 .3798 Mdot
.60971 .54742 Mdot
.36141 .29475 Mdot
.32848 .73383 Mdot
.35588 .31165 Mdot
.62506 .55446 Mdot
.35714 .5485 Mdot
.36364 .30615 Mdot
.47768 .65932 Mdot
.44174 .41279 Mdot
.3488 .54665 Mdot
.60961 .56187 Mdot
.60378 .36305 Mdot
.67766 .68668 Mdot
.51718 .79328 Mdot
.26053 .62758 Mdot
.26541 .63473 Mdot
.57997 .37133 Mdot
.19696 .61264 Mdot
.47005 .40774 Mdot
.71188 .37323 Mdot
.47046 .70745 Mdot
.65501 .60132 Mdot
.80833 .37266 Mdot
.31985 .55967 Mdot
.32445 .52276 Mdot
.61205 .57219 Mdot
.29132 .53358 Mdot
.57991 .56707 Mdot
.34002 .56047 Mdot
.218 .5268 Mdot
.5648 .57833 Mdot
.32229 .52397 Mdot
.56324 .53218 Mdot
.63765 .56923 Mdot
.62195 .33899 Mdot
.3087 .52022 Mdot
.66543 .56209 Mdot
.3055 .24536 Mdot
.40438 .42436 Mdot
.34264 .30491 Mdot
.47534 .38465 Mdot
.40608 .37578 Mdot
.62159 .3566 Mdot
.56541 .56203 Mdot
.47441 .68124 Mdot
.59661 .35895 Mdot
.28236 .51983 Mdot
.47578 .68642 Mdot
.51814 .31125 Mdot
.63103 .3805 Mdot
.35385 .30391 Mdot
.47897 .6795 Mdot
.57522 .62238 Mdot
.33859 .51899 Mdot
.53329 .80446 Mdot
.35423 .31103 Mdot
.59037 .58913 Mdot
.3726 .55644 Mdot
.39994 .37951 Mdot
.60628 .58059 Mdot
.29487 .53615 Mdot
.33604 .29765 Mdot
.61344 .54176 Mdot
.6015 .54025 Mdot
.54219 .33221 Mdot
.54866 .22857 Mdot
.47159 .68054 Mdot
.60581 .40435 Mdot
.62284 .58356 Mdot
.43469 .67829 Mdot
.30329 .36182 Mdot
.62181 .52398 Mdot
.60805 .32053 Mdot
.66389 .49027 Mdot
.35241 .54843 Mdot
.43816 .38913 Mdot
.29664 .57021 Mdot
.46143 .64764 Mdot
.86764 .5386 Mdot
.36315 .29335 Mdot
.59313 .50278 Mdot
.65979 .60906 Mdot
.31154 .57843 Mdot
.61244 .37 Mdot
.27766 .48947 Mdot
.6315 .60581 Mdot
.54083 .58515 Mdot
.58558 .56896 Mdot
.39269 .65995 Mdot
.59935 .33638 Mdot
.58214 .57824 Mdot
.57201 .64538 Mdot
.5736 .54451 Mdot
.48502 .65134 Mdot
.55581 .7101 Mdot
.63276 .52915 Mdot
.10016 .43855 Mdot
.33134 .28592 Mdot
.3473 .52417 Mdot
.37762 .57507 Mdot
.34944 .36944 Mdot
.71408 .28676 Mdot
.62094 .37013 Mdot
.59706 .47923 Mdot
.31872 .54447 Mdot
.79028 .63026 Mdot
.18873 .58542 Mdot
.63504 .56527 Mdot
.61136 .61637 Mdot
.30262 .54916 Mdot
.29628 .52216 Mdot
.34826 .27828 Mdot
.66322 .58108 Mdot
.55214 .5361 Mdot
.28072 .54621 Mdot
.6149 .55914 Mdot
.64321 .44297 Mdot
.39145 .42434 Mdot
.63363 .34781 Mdot
.44094 .40598 Mdot
.4082 .43112 Mdot
.77191 .39591 Mdot
.51752 .3314 Mdot
.42414 .40841 Mdot
.38164 .4337 Mdot
.58991 .76898 Mdot
.68886 .5164 Mdot
.4881 .65036 Mdot
.24153 .64459 Mdot
.33457 .52748 Mdot
.60562 .59712 Mdot
.58799 .37972 Mdot
.72735 .34658 Mdot
.26716 .44217 Mdot
.56054 .25757 Mdot
.63926 .59132 Mdot
.32164 .52744 Mdot
.34217 .30594 Mdot
.56365 .57831 Mdot
.53225 .67511 Mdot
.59259 .57039 Mdot
.36006 .52749 Mdot
.79663 .41066 Mdot
.68594 .50613 Mdot
.39404 .51196 Mdot
.59139 .41189 Mdot
.59682 .53119 Mdot
.62532 .38172 Mdot
.40104 .38553 Mdot
.43637 .68077 Mdot
.47503 .67441 Mdot
.59281 .54627 Mdot
.61608 .27818 Mdot
.50192 .56348 Mdot
.63789 .57158 Mdot
.64476 .56109 Mdot
.35595 .29319 Mdot
.64437 .5618 Mdot
.65962 .60777 Mdot
.61778 .53078 Mdot
.62885 .51873 Mdot
.44288 .39769 Mdot
.73193 .60275 Mdot
.64133 .52786 Mdot
.67283 .52251 Mdot
.39577 .42527 Mdot
.58485 .49264 Mdot
.42371 .42565 Mdot
.24017 .67973 Mdot
.42998 .41751 Mdot
.47219 .67703 Mdot
.37572 .54906 Mdot
.54699 .51762 Mdot
.64592 .373 Mdot
.41112 .43758 Mdot
.4541 .6716 Mdot
.40904 .4147 Mdot
.33022 .56794 Mdot
.64885 .79155 Mdot
.65113 .38271 Mdot
.41235 .50632 Mdot
.51194 .52204 Mdot
.48776 .23446 Mdot
.34061 .5537 Mdot
.61114 .33505 Mdot
.67213 .49014 Mdot
.61572 .53184 Mdot
.48236 .67192 Mdot
.60258 .56611 Mdot
.44326 .40332 Mdot
.32967 .52626 Mdot
.29348 .65084 Mdot
.47485 .67801 Mdot
.7869 .67588 Mdot
.36458 .5394 Mdot
.58492 .61102 Mdot
.40194 .43392 Mdot
.69752 .77167 Mdot
.43134 .41762 Mdot
.68426 .71339 Mdot
.57593 .32874 Mdot
.81359 .4291 Mdot
.60983 .34586 Mdot
.51897 .20136 Mdot
.23873 .72996 Mdot
.19686 .5734 Mdot
.59584 .3674 Mdot
.35246 .49801 Mdot
.62194 .56085 Mdot
.64641 .53699 Mdot
.69706 .57592 Mdot
.59611 .40769 Mdot
.62246 .57978 Mdot
.36051 .30501 Mdot
.50085 .37445 Mdot
.39188 .72844 Mdot
.34935 .5042 Mdot
.57791 .5719 Mdot
.40054 .42767 Mdot
.4155 .36682 Mdot
.36151 .30901 Mdot
.38002 .40583 Mdot
.64188 .57288 Mdot
.60398 .34809 Mdot
.45451 .57276 Mdot
.46453 .65791 Mdot
.20255 .36088 Mdot
.42397 .68277 Mdot
.33319 .50236 Mdot
.67109 .61489 Mdot
.32627 .54891 Mdot
.8547 .40579 Mdot
.63814 .53647 Mdot
.60356 .37118 Mdot
.60301 .54224 Mdot
.60911 .52961 Mdot
.65423 .54269 Mdot
.28389 .55477 Mdot
.35663 .58434 Mdot
.61223 .55783 Mdot
.41273 .38119 Mdot
.29356 .66465 Mdot
.56626 .60414 Mdot
.28786 .50766 Mdot
.58735 .7453 Mdot
.49059 .24765 Mdot
.58448 .40241 Mdot
.30329 .54089 Mdot
.61391 .35575 Mdot
.61343 .41059 Mdot
.62169 .35678 Mdot
.30076 .71013 Mdot
.52488 .5534 Mdot
.66367 .20228 Mdot
.80259 .50519 Mdot
.72702 .36444 Mdot
.58563 .387 Mdot
.30786 .3978 Mdot
.60136 .38327 Mdot
.62228 .36491 Mdot
.44969 .11856 Mdot
.59391 .37968 Mdot
.59821 .60551 Mdot
.59952 .61969 Mdot
.44268 .3 Mdot
.61318 .76609 Mdot
.66241 .57316 Mdot
.61886 .57999 Mdot
.44226 .68717 Mdot
.63372 .65793 Mdot
.36854 .30999 Mdot
.55179 .28034 Mdot
.36239 .2713 Mdot
.59719 .56124 Mdot
.61693 .57506 Mdot
.63035 .50886 Mdot
.24584 .74363 Mdot
.72274 .32902 Mdot
.57422 .36043 Mdot
.54137 .54241 Mdot
.17516 .46864 Mdot
.59666 .61537 Mdot
.57386 .58365 Mdot
.62179 .54209 Mdot
.31707 .54354 Mdot
.63037 .32068 Mdot
.54199 .57952 Mdot
.46667 .25929 Mdot
.62744 .56512 Mdot
.46782 .4068 Mdot
.41836 .67846 Mdot
.58763 .59319 Mdot
.63315 .34131 Mdot
.65735 .55892 Mdot
.61924 .39184 Mdot
.63567 .35523 Mdot
.66101 .53264 Mdot
.31325 .72594 Mdot
.6285 .32756 Mdot
.62404 .54952 Mdot
.31157 .54877 Mdot
.17468 .55451 Mdot
.59059 .59142 Mdot
.44348 .68345 Mdot
.63542 .59919 Mdot
.48434 .65202 Mdot
.63537 .55562 Mdot
.35273 .31169 Mdot
.6864 .42467 Mdot
.32147 .53269 Mdot
.42865 .70939 Mdot
.28827 .53258 Mdot
.54026 .37654 Mdot
.59188 .32741 Mdot
.37022 .31026 Mdot
.68871 .25587 Mdot
.35593 .29457 Mdot
.67878 .6841 Mdot
.26092 .40675 Mdot
.3993 .42072 Mdot
.64085 .36754 Mdot
.61412 .68287 Mdot
.30707 .49946 Mdot
.28071 .52569 Mdot
.31767 .50971 Mdot
.86502 .48303 Mdot
.76141 .30121 Mdot
.60692 .55441 Mdot
.53071 .81628 Mdot
.72484 .48255 Mdot
.59536 .52169 Mdot
.57184 .53752 Mdot
.36175 .52802 Mdot
.58888 .53492 Mdot
.47143 .49399 Mdot
.34 .54059 Mdot
.46032 .67132 Mdot
.62657 .37106 Mdot
.47576 .65023 Mdot
.25597 .52052 Mdot
.49203 .38018 Mdot
.35032 .54162 Mdot
.62317 .5203 Mdot
.59926 .54934 Mdot
.63017 .38685 Mdot
.57697 .41983 Mdot
.63121 .34576 Mdot
.4722 .69175 Mdot
.3341 .53517 Mdot
.71258 .3253 Mdot
.62704 .60098 Mdot
.59314 .35288 Mdot
.38491 .3499 Mdot
.62983 .59514 Mdot
.39676 .40074 Mdot
.64181 .59099 Mdot
.59116 .36677 Mdot
.64374 .56154 Mdot
.60639 .34821 Mdot
.32008 .55735 Mdot
.60698 .61812 Mdot
.61394 .5757 Mdot
.75555 .65645 Mdot
.46985 .66476 Mdot
.58968 .32971 Mdot
.49381 .48064 Mdot
.61714 .62125 Mdot
.52663 .67308 Mdot
.57602 .54661 Mdot
.62154 .47659 Mdot
.56318 .53018 Mdot
.35973 .30408 Mdot
.66805 .55664 Mdot
.58946 .58942 Mdot
.73079 .58178 Mdot
.77772 .55111 Mdot
.6451 .31624 Mdot
.43336 .43423 Mdot
.63296 .34161 Mdot
.34944 .51922 Mdot
.31969 .51373 Mdot
.2938 .56027 Mdot
.64275 .75338 Mdot
.62755 .50396 Mdot
.59027 .58072 Mdot
.40436 .43736 Mdot
.46687 .67465 Mdot
.58745 .35204 Mdot
.46346 .67926 Mdot
.55686 .27817 Mdot
.47795 .68699 Mdot
.36356 .30187 Mdot
.39467 .66429 Mdot
.68564 .34337 Mdot
.4493 .68994 Mdot
.63154 .34566 Mdot
.40125 .60066 Mdot
.65888 .59659 Mdot
.20645 .47226 Mdot
.4513 .66288 Mdot
.85701 .54338 Mdot
.57437 .55332 Mdot
.44646 .50614 Mdot
.41304 .42633 Mdot
.48316 .65552 Mdot
.41435 .37567 Mdot
.6529 .54733 Mdot
.43575 .22293 Mdot
.60518 .37737 Mdot
.4365 .43704 Mdot
.66401 .55093 Mdot
.47784 .65134 Mdot
.35442 .53452 Mdot
.53085 .47152 Mdot
.39478 .39218 Mdot
.72801 .68023 Mdot
.5409 .68154 Mdot
.33511 .53649 Mdot
.59014 .19592 Mdot
.43055 .38578 Mdot
.60963 .51893 Mdot
.57356 .47983 Mdot
.65638 .57414 Mdot
.3464 .51562 Mdot
.30447 .53145 Mdot
.45568 .33215 Mdot
.60215 .54435 Mdot
.57477 .55148 Mdot
.62655 .31363 Mdot
.33965 .54619 Mdot
.61714 .34259 Mdot
.64276 .3705 Mdot
.30564 .54909 Mdot
.62375 .34944 Mdot
.48076 .68033 Mdot
.50082 .3789 Mdot
.43246 .38857 Mdot
.40711 .38621 Mdot
.35575 .52911 Mdot
.34823 .56496 Mdot
.32894 .54943 Mdot
.64159 .58935 Mdot
.59072 .33782 Mdot
.64186 .54761 Mdot
.63222 .52803 Mdot
.57044 .3342 Mdot
.58049 .36151 Mdot
.64505 .54586 Mdot
.40898 .60412 Mdot
.43283 .70003 Mdot
.31973 .52514 Mdot
.42999 .40666 Mdot
.78989 .61879 Mdot
.40051 .43544 Mdot
.57583 .56289 Mdot
.21745 .4814 Mdot
.58427 .35447 Mdot
.47814 .66269 Mdot
.49251 .63944 Mdot
.48035 .67056 Mdot
.44009 .43514 Mdot
.64374 .3572 Mdot
.51608 .31495 Mdot
.57751 .56271 Mdot
.47314 .4663 Mdot
.61391 .68718 Mdot
.48284 .29242 Mdot
.42604 .40549 Mdot
.62573 .58844 Mdot
.35623 .29665 Mdot
.68668 .37892 Mdot
.5948 .57378 Mdot
.66981 .57302 Mdot
.36918 .63689 Mdot
.67764 .5284 Mdot
.58558 .39764 Mdot
.56711 .29184 Mdot
.63981 .61523 Mdot
.60559 .29376 Mdot
.58098 .13258 Mdot
.57756 .55019 Mdot
.62526 .57391 Mdot
.60637 .60326 Mdot
.63276 .53711 Mdot
.56723 .34821 Mdot
.42167 .61002 Mdot
.40546 .43434 Mdot
.49005 .42316 Mdot
.42849 .38824 Mdot
.32985 .5194 Mdot
.45101 .5079 Mdot
.63999 .36198 Mdot
.48095 .66827 Mdot
.61658 .80412 Mdot
.57403 .2755 Mdot
.33759 .55849 Mdot
.74077 .33831 Mdot
.46056 .65775 Mdot
.6545 .601 Mdot
.42875 .68207 Mdot
.30011 .51832 Mdot
.4185 .38804 Mdot
.60803 .62213 Mdot
.5914 .38616 Mdot
.61189 .32362 Mdot
.628 .5875 Mdot
.17372 .50709 Mdot
.40724 .37617 Mdot
.42747 .34556 Mdot
.61168 .54747 Mdot
.66987 .57506 Mdot
.63208 .35707 Mdot
.308 .53213 Mdot
.26627 .36969 Mdot
.46161 .66614 Mdot
.63047 .51503 Mdot
.65589 .5525 Mdot
.55115 .28755 Mdot
.44052 .41809 Mdot
.3386 .28604 Mdot
.60864 .54568 Mdot
.51998 .32636 Mdot
.60944 .54428 Mdot
.60225 .64669 Mdot
.32039 .55059 Mdot
.62729 .62729 Mdot
.62746 .61436 Mdot
.6301 .67484 Mdot
.42825 .38117 Mdot
.60861 .3692 Mdot
.6009 .31174 Mdot
.33543 .28291 Mdot
.39771 .40635 Mdot
.65043 .54975 Mdot
.44039 .39341 Mdot
.65183 .54048 Mdot
.61282 .56122 Mdot
.42609 .40442 Mdot
.61797 .343 Mdot
.28697 .48158 Mdot
.72439 .60295 Mdot
.61876 .53697 Mdot
.6483 .59516 Mdot
.62617 .75926 Mdot
.65362 .23579 Mdot
.62951 .61098 Mdot
.58308 .34705 Mdot
.62629 .59398 Mdot
.40087 .39062 Mdot
.47784 .68851 Mdot
.60076 .36716 Mdot
.36048 .55852 Mdot
.31615 .55746 Mdot
.3672 .44539 Mdot
.36378 .2977 Mdot
.64482 .60372 Mdot
.65866 .36799 Mdot
.58183 .36916 Mdot
.31385 .25701 Mdot
.3456 .52269 Mdot
.49264 .6633 Mdot
.6056 .53776 Mdot
.52457 .47823 Mdot
.41404 .43487 Mdot
.09991 .44116 Mdot
.50796 .32503 Mdot
.44302 .65161 Mdot
.59254 .24603 Mdot
.35334 .29972 Mdot
.58907 .60328 Mdot
.43522 .67092 Mdot
.31098 .56199 Mdot
.64687 .53842 Mdot
.6707 .53124 Mdot
.35858 .47706 Mdot
.36521 .51259 Mdot
.43829 .38818 Mdot
.3299 .56561 Mdot
.44951 .64983 Mdot
.36334 .30292 Mdot
.61502 .33005 Mdot
.58637 .5829 Mdot
.53379 .55482 Mdot
.34102 .52395 Mdot
.34843 .31128 Mdot
.61609 .54792 Mdot
.61788 .32512 Mdot
.29128 .54276 Mdot
.5936 .56016 Mdot
.70868 .36153 Mdot
.56815 .39739 Mdot
.33716 .5303 Mdot
.66429 .60618 Mdot
.62173 .46095 Mdot
.36628 .54778 Mdot
.36252 .53259 Mdot
.62198 .57943 Mdot
.48065 .67872 Mdot
.59253 .60916 Mdot
.42028 .42489 Mdot
.35626 .58452 Mdot
.40067 .39642 Mdot
.5812 .68299 Mdot
.67713 .59886 Mdot
.50472 .22385 Mdot
.62037 .39604 Mdot
.50352 .65783 Mdot
.74323 .56788 Mdot
.66683 .59136 Mdot
.22561 .65072 Mdot
.43376 .59027 Mdot
.23617 .32271 Mdot
.35915 .79685 Mdot
.44763 .67413 Mdot
.40596 .41469 Mdot
.62551 .57481 Mdot
.37822 .37981 Mdot
.45282 .68898 Mdot
.59795 .68712 Mdot
.66349 .60612 Mdot
.60213 .33661 Mdot
.62359 .56016 Mdot
.62615 .38628 Mdot
.63091 .597 Mdot
.60606 .49599 Mdot
.4476 .70994 Mdot
.68736 .71066 Mdot
.6573 .59699 Mdot
.6379 .80122 Mdot
.51491 .47553 Mdot
.45262 .66415 Mdot
.63144 .54561 Mdot
.34169 .29343 Mdot
.39406 .38332 Mdot
.4549 .78079 Mdot
.32175 .54638 Mdot
.42127 .41564 Mdot
.6301 .36239 Mdot
.32712 .57257 Mdot
.33238 .2877 Mdot
.53923 .52571 Mdot
.46752 .64893 Mdot
.40143 .4206 Mdot
.58862 .59075 Mdot
.57471 .5644 Mdot
.39974 .65649 Mdot
.4676 .16671 Mdot
.64394 .33816 Mdot
.77352 .6781 Mdot
.58224 .39013 Mdot
.471 .66924 Mdot
.32329 .55087 Mdot
.60694 .6118 Mdot
.60138 .57419 Mdot
.32928 .51437 Mdot
.58208 .34354 Mdot
.38757 .53145 Mdot
.76392 .3755 Mdot
.27326 .55268 Mdot
.6259 .72104 Mdot
.59844 .37153 Mdot
.63414 .71863 Mdot
.45651 .64635 Mdot
.31338 .73546 Mdot
.51468 .75985 Mdot
.40756 .42846 Mdot
.61727 .72283 Mdot
.58639 .35719 Mdot
.60274 .55328 Mdot
.35153 .30369 Mdot
.35679 .2861 Mdot
.62887 .37436 Mdot
.30076 .54667 Mdot
.47732 .65247 Mdot
.62253 .57037 Mdot
.51265 .27467 Mdot
.40376 .27804 Mdot
.29826 .56854 Mdot
.56708 .64014 Mdot
.41436 .37736 Mdot
.64065 .5957 Mdot
.44057 .6785 Mdot
.41671 .41067 Mdot
.34765 .27167 Mdot
.5019 .37765 Mdot
.60304 .53746 Mdot
.52635 .34545 Mdot
.39907 .41306 Mdot
.60198 .19559 Mdot
.61025 .57574 Mdot
.43033 .38537 Mdot
.65664 .50076 Mdot
.43398 .23455 Mdot
.48304 .54937 Mdot
.19887 .59066 Mdot
.35075 .50822 Mdot
.31077 .55643 Mdot
.3825 .21166 Mdot
.4711 .70674 Mdot
.39704 .42405 Mdot
.36272 .30514 Mdot
.53332 .72732 Mdot
.4185 .37594 Mdot
.5727 .58339 Mdot
.57618 .54697 Mdot
.76336 .38672 Mdot
.48177 .49493 Mdot
.34295 .30948 Mdot
.58772 .45795 Mdot
.64872 .57196 Mdot
.59624 .62799 Mdot
.61005 .58436 Mdot
.57319 .36466 Mdot
.41012 .37229 Mdot
.64203 .81535 Mdot
.41707 .3711 Mdot
.51994 .2765 Mdot
.33407 .52734 Mdot
.28914 .56631 Mdot
.58606 .59059 Mdot
.54412 .2091 Mdot
.43743 .77952 Mdot
.64447 .5991 Mdot
.45633 .63888 Mdot
.55077 .68258 Mdot
.56942 .60933 Mdot
.60601 .30827 Mdot
.54439 .59846 Mdot
.56593 .36422 Mdot
.41992 .40764 Mdot
.44666 .67703 Mdot
.44511 .70361 Mdot
.40722 .42069 Mdot
.59255 .5827 Mdot
.46556 .6337 Mdot
.58781 .56999 Mdot
.60588 .55012 Mdot
.54622 .27825 Mdot
.49477 .67123 Mdot
.33205 .55064 Mdot
.4753 .67529 Mdot
.62093 .36495 Mdot
.36642 .13788 Mdot
.45753 .68331 Mdot
.58265 .43659 Mdot
.4182 .5508 Mdot
.622 .72059 Mdot
.6149 .32545 Mdot
.45458 .69435 Mdot
.43068 .37782 Mdot
.23178 .32418 Mdot
.62614 .21753 Mdot
.38904 .43063 Mdot
.60542 .57255 Mdot
.63943 .36951 Mdot
.57894 .3726 Mdot
.38539 .4352 Mdot
.61159 .33237 Mdot
.64715 .62934 Mdot
.60772 .54166 Mdot
.3971 .42397 Mdot
.43136 .30146 Mdot
.40895 .37185 Mdot
.55034 .45115 Mdot
.62428 .54545 Mdot
.60224 .36901 Mdot
.63838 .63757 Mdot
.63922 .32261 Mdot
.3552 .28169 Mdot
.65714 .54635 Mdot
.48256 .66253 Mdot
.47815 .48096 Mdot
.33461 .52997 Mdot
.22049 .48374 Mdot
.63439 .37723 Mdot
.40472 .35216 Mdot
.6227 .33926 Mdot
.62431 .39763 Mdot
.37937 .40894 Mdot
.61495 .37338 Mdot
.6247 .57266 Mdot
.40184 .52032 Mdot
.6139 .39004 Mdot
.40936 .3985 Mdot
.47693 .65435 Mdot
.62162 .34666 Mdot
.32531 .57426 Mdot
.59615 .55263 Mdot
.34926 .55141 Mdot
.48777 .64212 Mdot
.64063 .36198 Mdot
.45882 .69432 Mdot
.3424 .52291 Mdot
.45827 .65071 Mdot
.271 .6301 Mdot
.4428 .38558 Mdot
.55241 .25883 Mdot
.71728 .55877 Mdot
.5932 .38676 Mdot
.28062 .52498 Mdot
.61881 .61375 Mdot
.59627 .54724 Mdot
.43963 .65833 Mdot
.58008 .37348 Mdot
.17667 .54755 Mdot
.61 .47007 Mdot
.45412 .34108 Mdot
.44522 .4082 Mdot
.79501 .64025 Mdot
.4949 .35339 Mdot
.22006 .35792 Mdot
.55803 .54957 Mdot
.3531 .30031 Mdot
.5843 .57037 Mdot
.74336 .67553 Mdot
.48186 .68536 Mdot
.29448 .43208 Mdot
.56804 .52962 Mdot
.33011 .54347 Mdot
.62161 .59858 Mdot
.52493 .81355 Mdot
.55232 .61065 Mdot
.4439 .68903 Mdot
.44931 .42029 Mdot
.64624 .37184 Mdot
.46293 .65813 Mdot
.32429 .5593 Mdot
.56422 .72695 Mdot
.65864 .6115 Mdot
.645 .57565 Mdot
.28537 .5227 Mdot
.60522 .33477 Mdot
.33368 .51884 Mdot
.43203 .38821 Mdot
.4587 .68064 Mdot
.62519 .53532 Mdot
.61479 .63227 Mdot
.2783 .56977 Mdot
.41854 .3686 Mdot
.33099 .5702 Mdot
.44055 .41323 Mdot
.35353 .30126 Mdot
.65059 .60106 Mdot
.28454 .52648 Mdot
.58301 .53315 Mdot
.75527 .60051 Mdot
.55892 .26917 Mdot
.76666 .53341 Mdot
.33449 .5512 Mdot
.60575 .74187 Mdot
.40283 .40759 Mdot
.43505 .41867 Mdot
.82071 .48671 Mdot
.42293 .76577 Mdot
.3844 .60521 Mdot
.63768 .79156 Mdot
.43266 .38947 Mdot
.40234 .3986 Mdot
.30553 .56083 Mdot
.6195 .37516 Mdot
.56092 .3743 Mdot
.27974 .56303 Mdot
.69824 .69501 Mdot
.58756 .35225 Mdot
.2155 .63458 Mdot
.36879 .53637 Mdot
.56969 .52566 Mdot
.35614 .3172 Mdot
.44385 .67232 Mdot
.69993 .68953 Mdot
.59855 .80052 Mdot
.5921 .60361 Mdot
.73404 .29334 Mdot
.30815 .5388 Mdot
.39544 .48994 Mdot
.26072 .69486 Mdot
.67141 .58489 Mdot
.6131 .5987 Mdot
.59871 .58608 Mdot
.48872 .68359 Mdot
.74573 .58052 Mdot
.58902 .60139 Mdot
.6687 .72054 Mdot
.57136 .58835 Mdot
.50076 .79506 Mdot
.47441 .67607 Mdot
.52108 .55481 Mdot
.33054 .50583 Mdot
.47746 .26733 Mdot
.69791 .57495 Mdot
.43677 .39178 Mdot
.31179 .49307 Mdot
.42206 .39019 Mdot
.38206 .76975 Mdot
.51644 .75758 Mdot
.5742 .37247 Mdot
.63942 .59096 Mdot
.32884 .5085 Mdot
.63503 .37892 Mdot
.26216 .39557 Mdot
.44008 .11609 Mdot
.43134 .3742 Mdot
.77568 .29205 Mdot
.43465 .41999 Mdot
.35354 .28196 Mdot
.63236 .36417 Mdot
.65742 .29513 Mdot
.47277 .46858 Mdot
.6191 .34604 Mdot
.35698 .43424 Mdot
.59974 .3092 Mdot
.60996 .73295 Mdot
.63506 .39394 Mdot
.40876 .40335 Mdot
.45198 .39235 Mdot
.64736 .50473 Mdot
.62616 .61125 Mdot
.4927 .40581 Mdot
.67685 .51388 Mdot
.63537 .60416 Mdot
.33982 .54064 Mdot
.59793 .22101 Mdot
.35002 .57584 Mdot
.60838 .38599 Mdot
.43221 .43209 Mdot
.61528 .59906 Mdot
.6208 .538 Mdot
.6036 .52223 Mdot
.75588 .66351 Mdot
.21628 .63186 Mdot
.61067 .55821 Mdot
.66203 .53548 Mdot
.32622 .55758 Mdot
.41083 .65367 Mdot
.69757 .74585 Mdot
.53192 .73654 Mdot
.58727 .54872 Mdot
.47392 .66572 Mdot
.48474 .68516 Mdot
.60556 .62652 Mdot
.50679 .24781 Mdot
.37458 .50292 Mdot
.58892 .59117 Mdot
.50304 .77025 Mdot
.34377 .57388 Mdot
.35581 .31271 Mdot
.34216 .52423 Mdot
.63854 .35014 Mdot
.35668 .29031 Mdot
.28775 .54466 Mdot
.66777 .30459 Mdot
.3376 .28207 Mdot
.43823 .2442 Mdot
.472 .69189 Mdot
.60589 .58077 Mdot
.62741 .30885 Mdot
.33603 .51418 Mdot
.403 .42171 Mdot
.60476 .35461 Mdot
.42278 .36531 Mdot
.40778 .66058 Mdot
.64762 .69453 Mdot
.36309 .29421 Mdot
.43833 .40295 Mdot
.50504 .38102 Mdot
.47562 .66802 Mdot
.38102 .41584 Mdot
.53067 .2075 Mdot
.56128 .59601 Mdot
.41998 .79392 Mdot
.64164 .58118 Mdot
.17178 .45509 Mdot
.4324 .42129 Mdot
.35033 .27521 Mdot
.58655 .57867 Mdot
.36527 .54042 Mdot
.61792 .49119 Mdot
.59047 .56761 Mdot
.3453 .56384 Mdot
.60605 .55462 Mdot
.43934 .67727 Mdot
.56667 .37929 Mdot
.43998 .58735 Mdot
.8284 .57223 Mdot
.45446 .65309 Mdot
.32032 .28346 Mdot
.63468 .60648 Mdot
.31864 .67496 Mdot
.61592 .34425 Mdot
.67081 .57554 Mdot
.79967 .39501 Mdot
.62085 .3811 Mdot
.6141 .3531 Mdot
.64487 .55711 Mdot
.38987 .42614 Mdot
.35795 .53306 Mdot
.47696 .66876 Mdot
.27655 .30914 Mdot
.59072 .56115 Mdot
.62114 .5861 Mdot
.46165 .6574 Mdot
.40132 .3978 Mdot
.62928 .53767 Mdot
.24536 .4275 Mdot
.28956 .27301 Mdot
.40815 .43146 Mdot
.56357 .60151 Mdot
.45998 .82932 Mdot
.59993 .41877 Mdot
.7098 .25016 Mdot
.46073 .71344 Mdot
.30596 .54584 Mdot
.57171 .51654 Mdot
.1144 .40621 Mdot
.44496 .67197 Mdot
.48733 .28638 Mdot
.6142 .55576 Mdot
.62033 .60591 Mdot
.60051 .32652 Mdot
.64822 .55074 Mdot
.59108 .37212 Mdot
.8358 .56179 Mdot
.75961 .73931 Mdot
.62336 .34186 Mdot
.59987 .38574 Mdot
.66441 .32537 Mdot
.73445 .67391 Mdot
.62801 .3674 Mdot
.66805 .60348 Mdot
.25709 .64145 Mdot
.67958 .55363 Mdot
.46555 .64405 Mdot
.50531 .6463 Mdot
.58248 .30578 Mdot
.53791 .18022 Mdot
.56783 .49999 Mdot
.69095 .63447 Mdot
.50504 .56542 Mdot
.42893 .41631 Mdot
.59646 .53571 Mdot
.36431 .29909 Mdot
.2926 .56206 Mdot
.56438 .63364 Mdot
.60173 .57944 Mdot
.61948 .39093 Mdot
.49176 .68079 Mdot
.39117 .38289 Mdot
.61805 .57903 Mdot
.38042 .52737 Mdot
.46077 .66901 Mdot
.6099 .38939 Mdot
.56094 .41825 Mdot
.4852 .64771 Mdot
.62899 .63515 Mdot
.6316 .60446 Mdot
.6156 .54724 Mdot
.69764 .56572 Mdot
.40832 .42268 Mdot
.28683 .57014 Mdot
.66441 .61464 Mdot
.54339 .28897 Mdot
.43059 .50353 Mdot
.63558 .62636 Mdot
.58748 .33961 Mdot
.40517 .43533 Mdot
.34141 .28231 Mdot
.57841 .71304 Mdot
.59596 .54051 Mdot
.22053 .6366 Mdot
.73812 .34596 Mdot
.3514 .28847 Mdot
.60174 .4025 Mdot
.47971 .66621 Mdot
.64435 .56861 Mdot
.28508 .67264 Mdot
.57505 .55572 Mdot
.67438 .50106 Mdot
.30675 .54245 Mdot
.43188 .40949 Mdot
.27755 .27932 Mdot
.29328 .56273 Mdot
.61403 .35492 Mdot
.15869 .5522 Mdot
.60918 .31597 Mdot
.64598 .35303 Mdot
.33172 .73932 Mdot
.42227 .40662 Mdot
.10761 .42412 Mdot
.64546 .22709 Mdot
.571 .56136 Mdot
.40318 .38366 Mdot
.63383 .36522 Mdot
.6399 .5876 Mdot
.58645 .37572 Mdot
.63586 .33035 Mdot
.62764 .52963 Mdot
.62444 .60772 Mdot
.68602 .70527 Mdot
.21589 .65803 Mdot
.47941 .67585 Mdot
.58561 .33601 Mdot
.74266 .38124 Mdot
.59147 .60425 Mdot
.57747 .56342 Mdot
.34831 .48368 Mdot
.44483 .6893 Mdot
.65328 .4502 Mdot
.6073 .54685 Mdot
.80956 .40712 Mdot
.64681 .60072 Mdot
.64089 .31698 Mdot
.39366 .43006 Mdot
.50402 .25414 Mdot
.35031 .51746 Mdot
.61424 .32101 Mdot
.48422 .65295 Mdot
.58679 .32279 Mdot
.81369 .43998 Mdot
.42248 .40107 Mdot
.5911 .36674 Mdot
.36302 .56218 Mdot
.41606 .39203 Mdot
.41084 .42998 Mdot
.2915 .66316 Mdot
.31689 .57157 Mdot
.45427 .69852 Mdot
.4203 .38487 Mdot
.71409 .37515 Mdot
.41145 .40512 Mdot
.75392 .38674 Mdot
.62461 .618 Mdot
.66755 .7159 Mdot
.49224 .34253 Mdot
.69408 .57225 Mdot
.40635 .37306 Mdot
.46316 .68792 Mdot
.65616 .56457 Mdot
.60805 .33147 Mdot
.45412 .68327 Mdot
.40631 .45722 Mdot
.35837 .56232 Mdot
.61089 .39905 Mdot
.40096 .43329 Mdot
.58866 .36737 Mdot
.62959 .69351 Mdot
.25233 .56338 Mdot
.50877 .5714 Mdot
.46175 .47933 Mdot
.60406 .51909 Mdot
.59959 .29356 Mdot
.62349 .62127 Mdot
.59754 .57653 Mdot
.33758 .52983 Mdot
.64351 .75222 Mdot
.61994 .34364 Mdot
.28656 .26298 Mdot
.43751 .40945 Mdot
.57926 .28772 Mdot
.61404 .46119 Mdot
.65617 .54757 Mdot
.61594 .38859 Mdot
.63704 .3297 Mdot
.77813 .54992 Mdot
.32596 .51509 Mdot
.68956 .56951 Mdot
.67419 .61131 Mdot
.60968 .4979 Mdot
.43195 .42342 Mdot
.25427 .4434 Mdot
.29986 .53107 Mdot
.70477 .21546 Mdot
.31674 .52619 Mdot
.34469 .64649 Mdot
.61458 .3744 Mdot
.4862 .67726 Mdot
.57719 .56628 Mdot
.71992 .62009 Mdot
.56879 .34679 Mdot
.37941 .49611 Mdot
.47921 .66083 Mdot
.27502 .46517 Mdot
.42218 .41139 Mdot
.64688 .61409 Mdot
.61249 .52852 Mdot
.63833 .54745 Mdot
.63483 .57145 Mdot
.43526 .43192 Mdot
.57277 .58284 Mdot
.44573 .41644 Mdot
.70122 .35636 Mdot
.817 .42302 Mdot
.35286 .51412 Mdot
.44895 .77173 Mdot
.59362 .38951 Mdot
.73291 .39624 Mdot
.6446 .43704 Mdot
.5562 .26886 Mdot
.28454 .64612 Mdot
.63712 .61385 Mdot
.29898 .54786 Mdot
.52653 .81578 Mdot
.32702 .50905 Mdot
.81281 .70323 Mdot
.53139 .64959 Mdot
.19179 .5907 Mdot
.63853 .58507 Mdot
.28288 .57082 Mdot
.63074 .4511 Mdot
.59111 .62054 Mdot
.49308 .63379 Mdot
.571 .44053 Mdot
.45013 .29479 Mdot
.49231 .65933 Mdot
.59477 .55442 Mdot
.64673 .37337 Mdot
.62509 .57159 Mdot
.57954 .56463 Mdot
.64036 .5999 Mdot
.38808 .38028 Mdot
.5608 .57162 Mdot
.58929 .60619 Mdot
.4805 .16206 Mdot
.60306 .75681 Mdot
.34763 .5565 Mdot
.78317 .52172 Mdot
.46638 .67468 Mdot
.62728 .38739 Mdot
.42768 .58223 Mdot
.41892 .42276 Mdot
.77543 .55991 Mdot
.64013 .5837 Mdot
.47815 .33696 Mdot
.39898 .43306 Mdot
.44938 .68163 Mdot
.33406 .28648 Mdot
.22325 .60122 Mdot
.34524 .51264 Mdot
.34125 .27841 Mdot
.33249 .53012 Mdot
.7176 .52242 Mdot
.61953 .39018 Mdot
.60982 .52189 Mdot
.4188 .37925 Mdot
.36134 .53761 Mdot
.61806 .76909 Mdot
.61035 .58896 Mdot
.33755 .55103 Mdot
.60756 .51931 Mdot
.41673 .5125 Mdot
.41158 .56116 Mdot
.28978 .52664 Mdot
.45341 .39702 Mdot
.41182 .38897 Mdot
.48067 .68117 Mdot
.62556 .38964 Mdot
.58404 .34868 Mdot
.41763 .40666 Mdot
.73533 .27001 Mdot
.58755 .56401 Mdot
.63857 .60243 Mdot
.53359 .29762 Mdot
.63214 .58293 Mdot
.57955 .73682 Mdot
.3677 .30624 Mdot
.61007 .39602 Mdot
.63343 .57585 Mdot
.62715 .53699 Mdot
.60525 .53722 Mdot
.63233 .6963 Mdot
.3354 .52353 Mdot
.64826 .57123 Mdot
.4364 .66428 Mdot
.48317 .21604 Mdot
.61356 .61514 Mdot
.5981 .62656 Mdot
.58945 .36346 Mdot
.80086 .64127 Mdot
.41288 .42733 Mdot
.34415 .54676 Mdot
.3684 .54073 Mdot
.50653 .69411 Mdot
.58244 .4033 Mdot
.36711 .31304 Mdot
.3408 .35661 Mdot
.35235 .30879 Mdot
.45733 .66211 Mdot
.35519 .62147 Mdot
.38002 .52182 Mdot
.33543 .56103 Mdot
.44505 .39274 Mdot
.63286 .57155 Mdot
.64422 .60157 Mdot
.49014 .28512 Mdot
.66123 .57804 Mdot
.47845 .65724 Mdot
.39082 .4169 Mdot
.59034 .36098 Mdot
.4437 .66883 Mdot
.4404 .40207 Mdot
.60316 .33426 Mdot
.56928 .60437 Mdot
.55723 .58756 Mdot
.60845 .35208 Mdot
.63736 .35894 Mdot
.59785 .60344 Mdot
.43834 .17888 Mdot
.63548 .39018 Mdot
.59454 .36944 Mdot
.32807 .28886 Mdot
.34407 .51192 Mdot
.60956 .64176 Mdot
.40401 .38186 Mdot
.61418 .54753 Mdot
.3458 .51064 Mdot
.45115 .69165 Mdot
.60428 .34276 Mdot
.61518 .538 Mdot
.60379 .55933 Mdot
.47469 .66499 Mdot
.49575 .65869 Mdot
.46402 .65248 Mdot
.40251 .36149 Mdot
.62945 .55649 Mdot
.628 .36289 Mdot
.42402 .40573 Mdot
.48504 .68477 Mdot
.43279 .69015 Mdot
.51446 .16393 Mdot
.58815 .59929 Mdot
.48738 .55426 Mdot
.31069 .18061 Mdot
.55564 .73016 Mdot
.34694 .27941 Mdot
.2796 .544 Mdot
.65015 .72244 Mdot
.44541 .72265 Mdot
.39926 .38537 Mdot
.45626 .74635 Mdot
.50299 .65612 Mdot
.63254 .529 Mdot
.64941 .59203 Mdot
.61628 .51109 Mdot
.45901 .67357 Mdot
.61803 .69471 Mdot
.57789 .36696 Mdot
.71393 .45254 Mdot
.46614 .67477 Mdot
.28964 .52728 Mdot
.2849 .52792 Mdot
.31533 .52643 Mdot
.64406 .61225 Mdot
.7707 .54914 Mdot
.72535 .37384 Mdot
.67724 .46728 Mdot
.42064 .41557 Mdot
.63398 .32421 Mdot
.29515 .6511 Mdot
.61406 .35142 Mdot
.28963 .55696 Mdot
.45575 .67188 Mdot
.59218 .32978 Mdot
.39533 .40755 Mdot
.40258 .39356 Mdot
.36147 .55897 Mdot
.34826 .52663 Mdot
.35253 .53893 Mdot
.63564 .34142 Mdot
.61506 .37358 Mdot
.6162 .53389 Mdot
.59932 .34823 Mdot
.70505 .27708 Mdot
.44172 .65101 Mdot
.29076 .51929 Mdot
.39978 .40946 Mdot
.63029 .38127 Mdot
.60662 .57873 Mdot
.38571 .63632 Mdot
.37422 .46394 Mdot
.44514 .65941 Mdot
.31026 .59248 Mdot
.85348 .63013 Mdot
.60227 .52821 Mdot
.44289 .4081 Mdot
.50576 .23736 Mdot
.60379 .5906 Mdot
.31607 .54483 Mdot
.74819 .65452 Mdot
.34853 .30993 Mdot
.59244 .60807 Mdot
.668 .57524 Mdot
.37984 .40443 Mdot
.4174 .5748 Mdot
.65989 .55471 Mdot
.52437 .3871 Mdot
.41355 .3658 Mdot
.29563 .53443 Mdot
.30325 .24513 Mdot
.27169 .54583 Mdot
.69609 .71093 Mdot
.34909 .28161 Mdot
.61526 .52928 Mdot
.34002 .53795 Mdot
.43804 .66752 Mdot
.34561 .5346 Mdot
.59522 .39578 Mdot
.3521 .5486 Mdot
.62384 .59095 Mdot
.62658 .36406 Mdot
.39756 .40929 Mdot
.56081 .29663 Mdot
.48929 .16908 Mdot
.36569 .54138 Mdot
.33394 .269 Mdot
.59178 .60613 Mdot
.67761 .39877 Mdot
.61353 .49182 Mdot
.62762 .61324 Mdot
.4232 .39164 Mdot
.61445 .38799 Mdot
.44476 .41051 Mdot
.57202 .61683 Mdot
.81482 .51451 Mdot
.43308 .41707 Mdot
.43851 .26715 Mdot
.45915 .65894 Mdot
.69614 .69444 Mdot
.59669 .57055 Mdot
.42253 .38272 Mdot
.62869 .55511 Mdot
.58029 .3416 Mdot
.50351 .45668 Mdot
.50039 .21257 Mdot
.41656 .37888 Mdot
.16533 .50528 Mdot
.49934 .47689 Mdot
.56253 .62074 Mdot
.42857 .38626 Mdot
.75295 .55813 Mdot
.34011 .28931 Mdot
.46089 .66536 Mdot
.49186 .67547 Mdot
.46695 .64819 Mdot
.66073 .5808 Mdot
.5415 .6058 Mdot
.44095 .69721 Mdot
.41768 .36375 Mdot
.43562 .68233 Mdot
.69364 .68617 Mdot
.17661 .52629 Mdot
.45609 .65432 Mdot
.60267 .56841 Mdot
.5874 .6205 Mdot
.60406 .75845 Mdot
.29017 .53867 Mdot
.22828 .65469 Mdot
.67963 .28064 Mdot
.60951 .61167 Mdot
.54817 .51003 Mdot
.59465 .39247 Mdot
.54319 .22544 Mdot
.59398 .46736 Mdot
.40907 .59893 Mdot
.5984 .38174 Mdot
.39838 .54464 Mdot
.61349 .39612 Mdot
.59515 .52857 Mdot
.61402 .56182 Mdot
.56402 .36337 Mdot
.219 .4682 Mdot
.41175 .23021 Mdot
.18723 .39034 Mdot
.58285 .34933 Mdot
.42786 .38099 Mdot
.43572 .38005 Mdot
.426 .40826 Mdot
.34941 .5186 Mdot
.63418 .3445 Mdot
.63529 .56074 Mdot
.31368 .55509 Mdot
.58545 .55304 Mdot
.41715 .38858 Mdot
.27427 .28286 Mdot
.59018 .36323 Mdot
.58885 .58898 Mdot
.62462 .2179 Mdot
.31897 .52996 Mdot
.47407 .66838 Mdot
.40802 .50204 Mdot
.2776 .56591 Mdot
.41036 .37059 Mdot
.59363 .41329 Mdot
.45361 .37321 Mdot
.43116 .60902 Mdot
.63436 .51139 Mdot
.64856 .61668 Mdot
.29796 .28889 Mdot
.56383 .1876 Mdot
.65481 .59071 Mdot
.32468 .55961 Mdot
.30456 .51673 Mdot
.60465 .54098 Mdot
.61794 .33084 Mdot
.47183 .69624 Mdot
.45713 .64847 Mdot
.65872 .54431 Mdot
.47257 .46526 Mdot
.67682 .71242 Mdot
.64207 .54349 Mdot
.68218 .61943 Mdot
.34676 .56839 Mdot
.333 .28481 Mdot
.51571 .33492 Mdot
.48857 .66379 Mdot
.61284 .55339 Mdot
.4003 .24741 Mdot
.59326 .37528 Mdot
.35239 .54474 Mdot
.39616 .41991 Mdot
.48875 .63199 Mdot
.37033 .54137 Mdot
.60548 .54105 Mdot
.62863 .53752 Mdot
.38002 .40961 Mdot
.63966 .31606 Mdot
.45565 .67377 Mdot
.31533 .55481 Mdot
.48748 .67559 Mdot
.61857 .36689 Mdot
.59393 .36266 Mdot
.68507 .59741 Mdot
.69004 .54892 Mdot
.36745 .54184 Mdot
.65305 .53232 Mdot
.2866 .54916 Mdot
.40249 .65551 Mdot
.41763 .4351 Mdot
.67131 .57187 Mdot
.63809 .39883 Mdot
.41948 .39257 Mdot
.6116 .60706 Mdot
.32106 .29949 Mdot
.64151 .53671 Mdot
.28126 .56794 Mdot
.8201 .50786 Mdot
.45602 .69078 Mdot
.54336 .37598 Mdot
.61027 .66772 Mdot
.63135 .58365 Mdot
.28346 .54679 Mdot
.56819 .516 Mdot
.42387 .42499 Mdot
.60966 .3819 Mdot
.85453 .40822 Mdot
.41152 .40021 Mdot
.62245 .56802 Mdot
.45664 .68164 Mdot
.64769 .35421 Mdot
.36086 .29859 Mdot
.51196 .32774 Mdot
.55996 .6274 Mdot
.55696 .55868 Mdot
.63057 .57044 Mdot
.6448 .79061 Mdot
.34466 .54235 Mdot
.63268 .37399 Mdot
.42979 .4285 Mdot
.41336 .41425 Mdot
.30709 .53264 Mdot
.45771 .31613 Mdot
.21902 .50628 Mdot
.23618 .23545 Mdot
.35267 .55819 Mdot
.43276 .67938 Mdot
.45421 .49508 Mdot
.29581 .56456 Mdot
.33575 .54261 Mdot
.36761 .55192 Mdot
.48759 .32405 Mdot
.59488 .33472 Mdot
.60364 .55807 Mdot
.58489 .40283 Mdot
.62705 .5305 Mdot
.67561 .74407 Mdot
.41862 .40786 Mdot
.61024 .38055 Mdot
.31317 .29412 Mdot
.65831 .49863 Mdot
.61145 .59546 Mdot
.24454 .596 Mdot
.54359 .58212 Mdot
.60155 .72081 Mdot
.62758 .63675 Mdot
.34221 .52705 Mdot
.53345 .53727 Mdot
.57507 .51505 Mdot
.66972 .26768 Mdot
.3978 .40121 Mdot
.35996 .28628 Mdot
.56508 .59571 Mdot
.60725 .64698 Mdot
.64721 .35419 Mdot
.59215 .32962 Mdot
.44353 .69826 Mdot
.42819 .48226 Mdot
.39708 .40572 Mdot
.24209 .51173 Mdot
.62861 .60939 Mdot
.3759 .44248 Mdot
.82227 .47485 Mdot
.60783 .60568 Mdot
.27571 .65732 Mdot
.77646 .5569 Mdot
.65754 .55105 Mdot
.70501 .48342 Mdot
.40309 .40339 Mdot
.80676 .40345 Mdot
.6166 .51416 Mdot
.31667 .54396 Mdot
.61748 .37702 Mdot
.60164 .39632 Mdot
.44621 .66098 Mdot
.68448 .26079 Mdot
.442 .37635 Mdot
.61376 .37664 Mdot
.60242 .5864 Mdot
.40484 .4231 Mdot
.36044 .29116 Mdot
.54959 .57863 Mdot
.38723 .75216 Mdot
.59564 .35154 Mdot
.67687 .55291 Mdot
.40417 .32239 Mdot
.42725 .51854 Mdot
.21969 .67333 Mdot
.42837 .40645 Mdot
.48522 .65547 Mdot
.63223 .63698 Mdot
.3382 .35321 Mdot
.58385 .52048 Mdot
.66459 .73251 Mdot
.55531 .33621 Mdot
.47853 .68793 Mdot
.59735 .58988 Mdot
.66049 .55709 Mdot
.47071 .48122 Mdot
.49493 .66098 Mdot
.65659 .54683 Mdot
.68927 .58279 Mdot
.60293 .33534 Mdot
.36814 .3014 Mdot
.59122 .35532 Mdot
.60631 .57322 Mdot
.536 .52544 Mdot
.60581 .32804 Mdot
.23054 .55958 Mdot
.50099 .67411 Mdot
.42045 .42308 Mdot
.62612 .65213 Mdot
.62682 .61685 Mdot
.43585 .84549 Mdot
.35486 .28153 Mdot
.73086 .71068 Mdot
.27799 .56282 Mdot
.34622 .25692 Mdot
.29177 .5795 Mdot
.18397 .57595 Mdot
.53329 .32121 Mdot
.64382 .52012 Mdot
.48418 .76091 Mdot
.69158 .4726 Mdot
.43927 .37958 Mdot
.69951 .38481 Mdot
.6259 .61144 Mdot
.58175 .56756 Mdot
.30267 .55711 Mdot
.46001 .32902 Mdot
.50161 .24243 Mdot
.48649 .43263 Mdot
.45066 .67407 Mdot
.61223 .36947 Mdot
.63004 .59361 Mdot
.22458 .40539 Mdot
.35191 .55376 Mdot
.52647 .47041 Mdot
.58739 .58344 Mdot
.5209 .2679 Mdot
.46283 .28379 Mdot
.40414 .42398 Mdot
.28016 .54728 Mdot
.28683 .56961 Mdot
.58055 .54288 Mdot
.39363 .40148 Mdot
.6251 .53349 Mdot
.51627 .46283 Mdot
.66643 .54215 Mdot
.44359 .68021 Mdot
.57508 .57757 Mdot
.47484 .52252 Mdot
.17426 .59959 Mdot
.53911 .57654 Mdot
.63451 .38606 Mdot
.34755 .51896 Mdot
.32206 .52548 Mdot
.58346 .35007 Mdot
.31623 .52758 Mdot
.7199 .46182 Mdot
.79574 .4161 Mdot
.44887 .66774 Mdot
.65856 .40856 Mdot
.44781 .68393 Mdot
.3601 .28598 Mdot
.59461 .60429 Mdot
.3442 .37744 Mdot
.35733 .55542 Mdot
.77067 .64288 Mdot
.41215 .40794 Mdot
.35493 .28217 Mdot
.5671 .57183 Mdot
.35423 .62403 Mdot
.29236 .55346 Mdot
.26585 .51418 Mdot
.60547 .53681 Mdot
.58933 .33488 Mdot
.65969 .55636 Mdot
.67493 .56735 Mdot
.34089 .27911 Mdot
.63111 .56957 Mdot
.44027 .40105 Mdot
.63221 .34068 Mdot
.18899 .57055 Mdot
.34063 .51475 Mdot
.57793 .57733 Mdot
.60205 .58708 Mdot
.58178 .33704 Mdot
.57127 .58607 Mdot
.39859 .38422 Mdot
.08385 .48672 Mdot
.45907 .65982 Mdot
.33258 .29085 Mdot
.25653 .51989 Mdot
.64687 .59079 Mdot
.65145 .54957 Mdot
.29256 .29093 Mdot
.45623 .19955 Mdot
.43896 .3985 Mdot
.66958 .60912 Mdot
.32768 .55699 Mdot
.45203 .68178 Mdot
.39079 .38618 Mdot
.61723 .54489 Mdot
.5805 .57086 Mdot
.44295 .67836 Mdot
.25899 .63844 Mdot
.39028 .5131 Mdot
.42307 .413 Mdot
.56713 .48318 Mdot
.39136 .63723 Mdot
.58875 .56572 Mdot
.18937 .43487 Mdot
.5962 .3691 Mdot
.43183 .39195 Mdot
.73941 .58511 Mdot
.61259 .5217 Mdot
.41159 .37108 Mdot
.39768 .40642 Mdot
.5723 .55487 Mdot
.5851 .40515 Mdot
.63678 .33842 Mdot
.5958 .37278 Mdot
.82213 .51734 Mdot
.56353 .79135 Mdot
.35342 .53867 Mdot
.40209 .40127 Mdot
.30528 .51414 Mdot
.46953 .69827 Mdot
.43238 .50211 Mdot
.29756 .52003 Mdot
.59875 .39433 Mdot
.28706 .52234 Mdot
.63249 .53575 Mdot
.39602 .40153 Mdot
.33444 .56176 Mdot
.64848 .58465 Mdot
.69152 .61049 Mdot
.49277 .52175 Mdot
.4708 .69606 Mdot
.40795 .52492 Mdot
.61686 .57113 Mdot
.34032 .28196 Mdot
.59228 .59896 Mdot
.39737 .42452 Mdot
.46351 .52935 Mdot
.64771 .57845 Mdot
.36676 .5445 Mdot
.45081 .60875 Mdot
.29454 .53198 Mdot
.67866 .59005 Mdot
.60705 .57253 Mdot
.58668 .56632 Mdot
.661 .5563 Mdot
.44519 .28019 Mdot
.44473 .41722 Mdot
.64445 .65195 Mdot
.37126 .5212 Mdot
.61122 .34683 Mdot
.57485 .35027 Mdot
.38943 .60278 Mdot
.33565 .27886 Mdot
.40035 .38918 Mdot
.58867 .56379 Mdot
.26772 .5129 Mdot
.26718 .29147 Mdot
.18648 .42219 Mdot
.31047 .65999 Mdot
.32856 .56076 Mdot
.63551 .38305 Mdot
.32105 .56678 Mdot
.58078 .5492 Mdot
.61289 .63449 Mdot
.1928 .58047 Mdot
.38463 .43808 Mdot
.45682 .6723 Mdot
.58391 .55405 Mdot
.70191 .70006 Mdot
.32611 .55756 Mdot
.34105 .56991 Mdot
.61274 .53121 Mdot
.62562 .3244 Mdot
.21048 .69156 Mdot
.39586 .42077 Mdot
.68237 .39508 Mdot
.54938 .3825 Mdot
.57337 .44463 Mdot
.40751 .41996 Mdot
.49886 .54287 Mdot
.30919 .52391 Mdot
.68304 .27784 Mdot
.60754 .34912 Mdot
.46145 .67088 Mdot
.63681 .62813 Mdot
.60338 .39635 Mdot
.27769 .54722 Mdot
.60474 .3917 Mdot
.60769 .52405 Mdot
.44198 .39046 Mdot
.30498 .53186 Mdot
.44458 .42568 Mdot
.56391 .36044 Mdot
.44992 .68722 Mdot
.70031 .68233 Mdot
.69053 .38115 Mdot
.77596 .55789 Mdot
.64792 .57099 Mdot
.29158 .50577 Mdot
.63077 .55441 Mdot
.64415 .3459 Mdot
.59772 .57011 Mdot
.60555 .29276 Mdot
.29138 .56703 Mdot
.67342 .54813 Mdot
.58269 .59967 Mdot
.69375 .31969 Mdot
.60826 .5999 Mdot
.56778 .56755 Mdot
.66634 .57343 Mdot
.54585 .36105 Mdot
.68672 .57166 Mdot
.59391 .33274 Mdot
.48696 .29542 Mdot
.33425 .54106 Mdot
.43338 .69542 Mdot
.46662 .64628 Mdot
.66573 .72861 Mdot
.69631 .69605 Mdot
.4631 .31918 Mdot
.58904 .34727 Mdot
.42878 .37727 Mdot
.62299 .53332 Mdot
.73194 .56839 Mdot
.5094 .66955 Mdot
.30767 .52575 Mdot
.36589 .52853 Mdot
.67893 .52996 Mdot
.62589 .80583 Mdot
.68282 .56374 Mdot
.51326 .31835 Mdot
.64382 .53099 Mdot
.67035 .57163 Mdot
.36484 .5616 Mdot
.66657 .68933 Mdot
.64818 .5715 Mdot
.64727 .35423 Mdot
.46627 .66849 Mdot
.56266 .49676 Mdot
.5152 .64607 Mdot
.51018 .49409 Mdot
.66279 .28911 Mdot
.63418 .56579 Mdot
.31048 .55048 Mdot
.61354 .39818 Mdot
.54124 .29432 Mdot
.42483 .4027 Mdot
.50565 .35287 Mdot
.70901 .34703 Mdot
.25902 .58484 Mdot
.46078 .66929 Mdot
.27619 .65137 Mdot
.62408 .59066 Mdot
.35268 .52141 Mdot
.61142 .52668 Mdot
.26005 .29851 Mdot
.45822 .69378 Mdot
.569 .34267 Mdot
.42788 .3803 Mdot
.57965 .34966 Mdot
.7692 .53192 Mdot
.51296 .60292 Mdot
.32535 .25327 Mdot
.3379 .51126 Mdot
.72652 .65816 Mdot
.62773 .37505 Mdot
.61538 .54073 Mdot
.26118 .21767 Mdot
.59822 .36944 Mdot
.58238 .34271 Mdot
.41153 .59875 Mdot
.58316 .6836 Mdot
.56084 .52481 Mdot
.59873 .38987 Mdot
.31191 .51015 Mdot
.47674 .67571 Mdot
.65486 .56766 Mdot
.66516 .56926 Mdot
.59804 .32739 Mdot
.29006 .55338 Mdot
.71521 .69858 Mdot
.34562 .52665 Mdot
.61071 .33541 Mdot
.3209 .53266 Mdot
.26893 .50304 Mdot
.34166 .55508 Mdot
.59514 .61218 Mdot
.59034 .56286 Mdot
.38073 .72757 Mdot
.59396 .36251 Mdot
.65523 .55814 Mdot
.60974 .55528 Mdot
.62887 .36719 Mdot
.37477 .51729 Mdot
.73893 .61754 Mdot
.63891 .5894 Mdot
.59769 .55811 Mdot
.48475 .68079 Mdot
.38471 .56831 Mdot
.2196 .39685 Mdot
.65535 .56409 Mdot
.44624 .65446 Mdot
.63835 .34629 Mdot
.59549 .601 Mdot
.69002 .68864 Mdot
.3687 .56367 Mdot
.57363 .56354 Mdot
.36177 .29981 Mdot
.6456 .59817 Mdot
.20706 .68565 Mdot
.57951 .587 Mdot
.63354 .36089 Mdot
.61982 .38026 Mdot
.38785 .49606 Mdot
.61307 .35743 Mdot
.35322 .28358 Mdot
.41584 .3893 Mdot
.17424 .44041 Mdot
.35638 .28759 Mdot
.66936 .59034 Mdot
.64579 .22725 Mdot
.64347 .52557 Mdot
.57578 .60654 Mdot
.73696 .67088 Mdot
.35356 .2864 Mdot
.62078 .38657 Mdot
.22153 .46411 Mdot
.67168 .56459 Mdot
.39418 .41726 Mdot
.60108 .62658 Mdot
.57256 .56959 Mdot
.54639 .42406 Mdot
.80454 .54466 Mdot
.39575 .42555 Mdot
.59453 .63808 Mdot
.65467 .56332 Mdot
.5224 .19069 Mdot
.60929 .58603 Mdot
.45221 .65633 Mdot
.58437 .36291 Mdot
.32542 .5684 Mdot
.46866 .65969 Mdot
.63694 .59316 Mdot
.46205 .67398 Mdot
.35175 .54161 Mdot
.42513 .39033 Mdot
.5758 .56794 Mdot
.47357 .64394 Mdot
.45255 .67495 Mdot
.63421 .54982 Mdot
.61369 .37875 Mdot
.57961 .49819 Mdot
.59874 .60278 Mdot
.60998 .54136 Mdot
.58406 .34878 Mdot
.61831 .1747 Mdot
.58752 .5358 Mdot
.48886 .5489 Mdot
.5701 .36517 Mdot
.35532 .3148 Mdot
.32306 .56547 Mdot
.58794 .52668 Mdot
.41814 .4124 Mdot
.41992 .40004 Mdot
.33576 .50315 Mdot
.59133 .32456 Mdot
.2908 .54351 Mdot
.55201 .59996 Mdot
.68775 .54665 Mdot
.66174 .61797 Mdot
.85556 .41419 Mdot
.22356 .60804 Mdot
.62918 .33989 Mdot
.30193 .52773 Mdot
.48677 .42836 Mdot
.40196 .38905 Mdot
.30083 .51001 Mdot
.63569 .39961 Mdot
.63872 .36783 Mdot
.5951 .39045 Mdot
.48636 .67053 Mdot
.34138 .52078 Mdot
.62179 .30808 Mdot
.61488 .32041 Mdot
.61414 .53516 Mdot
.65414 .56189 Mdot
.57316 .31707 Mdot
.59288 .75555 Mdot
.44569 .68521 Mdot
.31027 .54641 Mdot
.40137 .84614 Mdot
.39837 .42528 Mdot
.69264 .31647 Mdot
.6471 .58617 Mdot
.45261 .10278 Mdot
.68217 .59545 Mdot
.60465 .58635 Mdot
.63813 .34877 Mdot
.43214 .665 Mdot
.46772 .68091 Mdot
.62675 .37587 Mdot
.56074 .37037 Mdot
.47541 .65079 Mdot
.30682 .66459 Mdot
.15661 .48718 Mdot
.5268 .31442 Mdot
.63183 .35875 Mdot
.68592 .37738 Mdot
.40069 .37939 Mdot
.56793 .37328 Mdot
.39881 .42883 Mdot
.33447 .54323 Mdot
.36477 .53348 Mdot
.38112 .41365 Mdot
.59956 .53886 Mdot
.34949 .54913 Mdot
.55585 .62402 Mdot
.2121 .58048 Mdot
.37615 .77635 Mdot
.42924 .19925 Mdot
.6458 .6026 Mdot
.50526 .24976 Mdot
.47236 .24186 Mdot
.62491 .57887 Mdot
.66773 .50078 Mdot
.4589 .67242 Mdot
.56713 .36464 Mdot
.39572 .39114 Mdot
.23255 .68332 Mdot
.58877 .56504 Mdot
.61933 .34277 Mdot
.39804 .3959 Mdot
.28689 .48749 Mdot
.52577 .39471 Mdot
.61274 .52981 Mdot
.14396 .33899 Mdot
.5664 .35043 Mdot
.32511 .56853 Mdot
.64729 .24355 Mdot
.58307 .39894 Mdot
.40473 .62649 Mdot
.30632 .57256 Mdot
.20169 .37398 Mdot
.62924 .38503 Mdot
.38321 .51649 Mdot
.61778 .36424 Mdot
.44023 .67467 Mdot
.59311 .41219 Mdot
.30319 .53655 Mdot
.60026 .59436 Mdot
.30899 .53291 Mdot
.44185 .68313 Mdot
.35569 .52112 Mdot
.39578 .38926 Mdot
.34639 .28087 Mdot
.40614 .39048 Mdot
.42514 .50747 Mdot
.80315 .5288 Mdot
.43155 .40979 Mdot
.24455 .54574 Mdot
.65393 .59089 Mdot
.64383 .32032 Mdot
.33117 .56829 Mdot
.34956 .50962 Mdot
.43825 .49169 Mdot
.62039 .3491 Mdot
.30521 .53795 Mdot
.70847 .35663 Mdot
.70055 .22144 Mdot
.56869 .64009 Mdot
.51392 .79195 Mdot
.62985 .36472 Mdot
.30184 .57036 Mdot
.52982 .30128 Mdot
.57942 .37607 Mdot
.35493 .55556 Mdot
.42633 .38327 Mdot
.41164 .41661 Mdot
.59173 .53952 Mdot
.39657 .44657 Mdot
.28182 .55299 Mdot
.41116 .23626 Mdot
.58391 .36525 Mdot
.30033 .48352 Mdot
.45644 .65261 Mdot
.33967 .54536 Mdot
.59114 .50369 Mdot
.55848 .35574 Mdot
.36474 .52111 Mdot
.41389 .76476 Mdot
.44298 .86064 Mdot
.30642 .5379 Mdot
.58455 .36374 Mdot
.6053 .34141 Mdot
.54486 .54779 Mdot
.46904 .4726 Mdot
.29322 .54773 Mdot
.34468 .40011 Mdot
.66417 .7363 Mdot
.35405 .30125 Mdot
.57742 .18664 Mdot
.64766 .57297 Mdot
.62681 .55421 Mdot
.40716 .3798 Mdot
.61863 .59618 Mdot
.63282 .32978 Mdot
.58498 .61104 Mdot
.42441 .36845 Mdot
.30436 .52827 Mdot
.58261 .58716 Mdot
.46646 .68657 Mdot
.39519 .38565 Mdot
.38097 .39531 Mdot
.33034 .53447 Mdot
.5966 .38993 Mdot
.20634 .47096 Mdot
.34597 .52593 Mdot
.63566 .5669 Mdot
.34779 .29048 Mdot
.60351 .52189 Mdot
.35699 .73161 Mdot
.57834 .36493 Mdot
.32043 .56733 Mdot
.60345 .40318 Mdot
.40677 .3964 Mdot
.34364 .50486 Mdot
.61226 .5837 Mdot
.35995 .55041 Mdot
.45051 .7301 Mdot
.32274 .69426 Mdot
.60701 .31769 Mdot
.44759 .64251 Mdot
.58736 .33219 Mdot
.35521 .3014 Mdot
.52166 .71154 Mdot
.4548 .66672 Mdot
.33286 .55414 Mdot
.22087 .61495 Mdot
.36187 .55595 Mdot
.60961 .60154 Mdot
.62415 .60648 Mdot
.3044 .55895 Mdot
.4759 .68362 Mdot
.80105 .62887 Mdot
.49988 .57379 Mdot
.61691 .39025 Mdot
.61526 .2768 Mdot
.33022 .8038 Mdot
.45511 .37943 Mdot
.42062 .37453 Mdot
.65837 .63333 Mdot
.65112 .54331 Mdot
.38635 .38802 Mdot
.43076 .43275 Mdot
.4796 .68892 Mdot
.35673 .52717 Mdot
.65606 .36896 Mdot
.39547 .3813 Mdot
.59824 .67002 Mdot
.70284 .69176 Mdot
.54247 .56012 Mdot
.66148 .52754 Mdot
.63968 .61528 Mdot
.42313 .52162 Mdot
.44142 .41659 Mdot
.61406 .56809 Mdot
.68211 .60357 Mdot
.43489 .39427 Mdot
.44123 .67813 Mdot
.66164 .37723 Mdot
.31591 .53827 Mdot
.58317 .13127 Mdot
.57527 .57127 Mdot
.59896 .59751 Mdot
.42037 .41579 Mdot
.5424 .17974 Mdot
.62932 .34365 Mdot
.58904 .38086 Mdot
.34579 .54258 Mdot
.43396 .49066 Mdot
.58458 .60721 Mdot
.62188 .57638 Mdot
.3288 .5509 Mdot
.34411 .28188 Mdot
.39052 .2104 Mdot
.60417 .5608 Mdot
.40139 .41006 Mdot
.31486 .49123 Mdot
.44019 .41983 Mdot
.60628 .52759 Mdot
.61257 .60313 Mdot
.59123 .6099 Mdot
.66009 .5518 Mdot
.38172 .39949 Mdot
.6203 .57865 Mdot
.6341 .49474 Mdot
.60551 .38586 Mdot
.6403 .58058 Mdot
.66189 .72478 Mdot
.59759 .56217 Mdot
.46295 .68735 Mdot
.21038 .42269 Mdot
.58482 .56115 Mdot
.63881 .57853 Mdot
.49739 .56532 Mdot
.59478 .586 Mdot
.40315 .42661 Mdot
.60675 .34549 Mdot
.40187 .39994 Mdot
.4314 .42376 Mdot
.32379 .50891 Mdot
.47636 .69167 Mdot
.58348 .51999 Mdot
.45887 .64997 Mdot
.61562 .50136 Mdot
.61108 .52422 Mdot
.40075 .54423 Mdot
.51104 .3211 Mdot
.43549 .7182 Mdot
.60987 .57948 Mdot
.34076 .54074 Mdot
.33391 .56609 Mdot
.46619 .75839 Mdot
.54504 .5993 Mdot
.38624 .39201 Mdot
.42224 .38231 Mdot
.57258 .73675 Mdot
.53771 .40604 Mdot
.45518 .68758 Mdot
.49566 .40563 Mdot
.64789 .60421 Mdot
.60309 .5518 Mdot
.59662 .62535 Mdot
.3002 .51775 Mdot
.33765 .28164 Mdot
.3133 .52317 Mdot
.32373 .28314 Mdot
.44138 .42021 Mdot
.64335 .60362 Mdot
.3391 .75875 Mdot
.60924 .32457 Mdot
.60567 .346 Mdot
.41418 .36401 Mdot
.29215 .53459 Mdot
.55114 .53754 Mdot
.86323 .41923 Mdot
.5941 .30458 Mdot
.42848 .68117 Mdot
.62223 .57333 Mdot
.33423 .53576 Mdot
.61466 .3232 Mdot
.49425 .65012 Mdot
.63689 .60682 Mdot
.37501 .52431 Mdot
.59651 .56725 Mdot
.69512 .48381 Mdot
.61096 .38582 Mdot
.26741 .28715 Mdot
.6071 .3161 Mdot
.4055 .37304 Mdot
.43698 .4138 Mdot
.61163 .60633 Mdot
.78956 .32125 Mdot
.57186 .33428 Mdot
.43924 .4358 Mdot
.43975 .68911 Mdot
.33322 .29182 Mdot
.45262 .69741 Mdot
.28911 .56164 Mdot
.46361 .66796 Mdot
.3684 .54097 Mdot
.5723 .74969 Mdot
.60605 .30372 Mdot
.46278 .65964 Mdot
.50926 .1721 Mdot
.56239 .56253 Mdot
.4878 .68065 Mdot
.66941 .51931 Mdot
.57493 .29746 Mdot
.3269 .54849 Mdot
.47536 .68318 Mdot
.61861 .53938 Mdot
.25951 .70442 Mdot
.43505 .41878 Mdot
.38554 .39426 Mdot
.57941 .52231 Mdot
.36031 .56237 Mdot
.56263 .37845 Mdot
.43047 .5792 Mdot
.35939 .31509 Mdot
.62059 .57641 Mdot
.64276 .60531 Mdot
.58008 .33509 Mdot
.64285 .33756 Mdot
.61504 .60463 Mdot
.70829 .37765 Mdot
.62571 .59064 Mdot
.41144 .41941 Mdot
.63789 .35994 Mdot
.60373 .34333 Mdot
.28103 .54776 Mdot
.59339 .32388 Mdot
.6707 .53924 Mdot
.37505 .38487 Mdot
.65062 .62653 Mdot
.411 .39701 Mdot
.4689 .53179 Mdot
.3479 .51689 Mdot
.23126 .66971 Mdot
.58793 .32456 Mdot
.63385 .57265 Mdot
.58425 .33601 Mdot
.46635 .65253 Mdot
.59433 .36009 Mdot
.62121 .40016 Mdot
.62479 .60978 Mdot
.61446 .52933 Mdot
.34847 .28535 Mdot
.46542 .47431 Mdot
.60416 .37941 Mdot
.62809 .58783 Mdot
.64333 .52407 Mdot
.56911 .55382 Mdot
.48629 .4853 Mdot
.64063 .36542 Mdot
.76837 .3932 Mdot
.36626 .74952 Mdot
.60991 .37845 Mdot
.24787 .72311 Mdot
.35897 .30706 Mdot
.33271 .28052 Mdot
.45436 .38376 Mdot
.60222 .55785 Mdot
.29621 .53833 Mdot
.57983 .55091 Mdot
.56709 .63635 Mdot
.57973 .56775 Mdot
.44632 .69041 Mdot
.60876 .50655 Mdot
.34512 .3022 Mdot
.33834 .52457 Mdot
.64038 .59114 Mdot
.58069 .58139 Mdot
.33944 .27705 Mdot
.60116 .31549 Mdot
.63521 .37745 Mdot
.18892 .44255 Mdot
.44869 .66429 Mdot
.42422 .39483 Mdot
.5905 .54429 Mdot
.34279 .54161 Mdot
.31185 .53035 Mdot
.58021 .34719 Mdot
.31376 .54252 Mdot
.39579 .42183 Mdot
.61297 .58902 Mdot
.38457 .39108 Mdot
.44525 .68925 Mdot
.58429 .3619 Mdot
.5894 .54454 Mdot
.61282 .53543 Mdot
.6198 .3805 Mdot
.65375 .59167 Mdot
.48532 .67993 Mdot
.3623 .53333 Mdot
.63457 .37568 Mdot
.41741 .39148 Mdot
.28211 .54251 Mdot
.62929 .5363 Mdot
.50434 .85253 Mdot
.62167 .59635 Mdot
.60148 .54398 Mdot
.16445 .53265 Mdot
.66779 .6234 Mdot
.29578 .56756 Mdot
.57358 .35394 Mdot
.55844 .58927 Mdot
.66508 .74854 Mdot
.30611 .31278 Mdot
.30989 .50695 Mdot
.62609 .57175 Mdot
.22164 .65629 Mdot
.63332 .57754 Mdot
.27933 .48706 Mdot
.40409 .53794 Mdot
.57426 .80527 Mdot
.66507 .52898 Mdot
.39234 .42718 Mdot
.34903 .28407 Mdot
.34192 .56676 Mdot
.74321 .53708 Mdot
.63421 .59866 Mdot
.75491 .56532 Mdot
.57277 .5826 Mdot
.40776 .41909 Mdot
.70082 .55228 Mdot
.31056 .54534 Mdot
.6701 .26343 Mdot
.63439 .56085 Mdot
.6401 .36263 Mdot
.29222 .51785 Mdot
.34159 .30538 Mdot
.61499 .5383 Mdot
.44763 .65558 Mdot
.41348 .33736 Mdot
.68392 .54642 Mdot
.41322 .39588 Mdot
.61032 .55354 Mdot
.58652 .63701 Mdot
.74511 .28486 Mdot
.60936 .38786 Mdot
.42285 .37685 Mdot
.53702 .21786 Mdot
.65506 .59365 Mdot
.63082 .38304 Mdot
.60929 .34854 Mdot
.44028 .66691 Mdot
.4913 .37662 Mdot
.37543 .33426 Mdot
.41213 .79385 Mdot
.78498 .5312 Mdot
.27796 .5514 Mdot
.44013 .22075 Mdot
.65186 .56452 Mdot
.51192 .58082 Mdot
.40603 .42732 Mdot
.59805 .59509 Mdot
.80249 .5075 Mdot
.59475 .37149 Mdot
.60476 .56491 Mdot
.44476 .68237 Mdot
.4524 .34853 Mdot
.51794 .49266 Mdot
.42467 .83298 Mdot
.30538 .51004 Mdot
.62011 .63239 Mdot
.65178 .51255 Mdot
.35135 .31361 Mdot
.6245 .52747 Mdot
.33302 .56869 Mdot
.23911 .59711 Mdot
.47161 .68782 Mdot
.60435 .3223 Mdot
.35757 .3083 Mdot
.61769 .62333 Mdot
.59557 .51879 Mdot
.43306 .69448 Mdot
.62291 .54504 Mdot
.6609 .25717 Mdot
.37154 .28358 Mdot
.34575 .55411 Mdot
.60655 .39292 Mdot
.64303 .61403 Mdot
.33752 .28219 Mdot
.62522 .60837 Mdot
.66716 .32276 Mdot
.62391 .55837 Mdot
.42351 .32671 Mdot
.61771 .376 Mdot
.4111 .3926 Mdot
.57912 .52063 Mdot
.58593 .57345 Mdot
.38823 .64037 Mdot
.56919 .63756 Mdot
.57921 .58486 Mdot
.64856 .35932 Mdot
.6132 .32875 Mdot
.59093 .33551 Mdot
.35212 .54987 Mdot
.51963 .32689 Mdot
.40771 .40883 Mdot
.57342 .59509 Mdot
.39497 .38212 Mdot
.59259 .66048 Mdot
.43031 .68807 Mdot
.29274 .75252 Mdot
.64207 .5948 Mdot
.58957 .34024 Mdot
.40695 .25318 Mdot
.63716 .3437 Mdot
.38042 .55393 Mdot
.39689 .40537 Mdot
.5996 .37093 Mdot
.59508 .58049 Mdot
.48258 .44722 Mdot
.46445 .8399 Mdot
.40475 .38623 Mdot
.60156 .62943 Mdot
.31659 .50757 Mdot
.36988 .53188 Mdot
.25161 .74891 Mdot
.44026 .41038 Mdot
.46971 .23832 Mdot
.63006 .58603 Mdot
.60678 .32516 Mdot
.42799 .41121 Mdot
.40716 .43025 Mdot
.32274 .54875 Mdot
.60403 .53047 Mdot
.58912 .56999 Mdot
.3616 .30134 Mdot
.42119 .38414 Mdot
.55946 .56652 Mdot
.63744 .52949 Mdot
.18636 .57445 Mdot
.66098 .35851 Mdot
.58792 .15965 Mdot
.55412 .6028 Mdot
.79218 .53983 Mdot
.45587 .50785 Mdot
.62975 .3391 Mdot
.58601 .54452 Mdot
.61243 .6258 Mdot
.27819 .5554 Mdot
.61736 .59184 Mdot
.30551 .52 Mdot
.42061 .37295 Mdot
.30873 .76758 Mdot
.31997 .4754 Mdot
.2892 .64845 Mdot
.61313 .5974 Mdot
.56023 .44664 Mdot
.47255 .65684 Mdot
.39943 .36462 Mdot
.61727 .3368 Mdot
.6507 .60864 Mdot
.30272 .57349 Mdot
.33185 .55528 Mdot
.60588 .35498 Mdot
.47004 .25932 Mdot
.23153 .55649 Mdot
.6588 .54809 Mdot
.31225 .56565 Mdot
.30747 .46645 Mdot
.71733 .39175 Mdot
.39317 .44096 Mdot
.46629 .69114 Mdot
.30428 .5291 Mdot
.37926 .3995 Mdot
.66026 .316 Mdot
.60717 .36436 Mdot
.57231 .34253 Mdot
.36891 .69975 Mdot
.29399 .54428 Mdot
.47689 .66484 Mdot
.52971 .37089 Mdot
.53465 .32578 Mdot
.452 .69242 Mdot
.3038 .52816 Mdot
.615 .32598 Mdot
.61679 .33972 Mdot
.60794 .34485 Mdot
.66794 .2643 Mdot
.58062 .3685 Mdot
.74342 .34265 Mdot
.63652 .52126 Mdot
.67457 .40282 Mdot
.6312 .57571 Mdot
.3841 .41367 Mdot
.61246 .38564 Mdot
.44829 .49489 Mdot
.66544 .59088 Mdot
.42895 .83064 Mdot
.61831 .57165 Mdot
.37332 .41616 Mdot
.60011 .55734 Mdot
.68317 .34998 Mdot
.56984 .36489 Mdot
.61171 .58027 Mdot
.41483 .43987 Mdot
.45424 .67729 Mdot
.63342 .41406 Mdot
.58497 .56259 Mdot
.46601 .34412 Mdot
.68002 .60554 Mdot
.21743 .58201 Mdot
.42333 .60966 Mdot
.42819 .67766 Mdot
.68836 .58843 Mdot
.28077 .53392 Mdot
.59129 .42053 Mdot
.66055 .41725 Mdot
.40569 .38562 Mdot
.76744 .62607 Mdot
.33649 .55337 Mdot
.69992 .54975 Mdot
.67533 .58384 Mdot
.48799 .66941 Mdot
.58749 .41596 Mdot
.41483 .42232 Mdot
.64716 .59588 Mdot
.57153 .55733 Mdot
.41179 .74171 Mdot
.66611 .40567 Mdot
.56856 .54604 Mdot
.45938 .7004 Mdot
.7764 .40115 Mdot
.59313 .55287 Mdot
.3712 .51534 Mdot
.57496 .37361 Mdot
.62693 .50422 Mdot
.76085 .38382 Mdot
.62995 .58983 Mdot
.60008 .3654 Mdot
.58455 .32726 Mdot
.42536 .2944 Mdot
.42993 .67773 Mdot
.62361 .55799 Mdot
.40754 .63644 Mdot
.63056 .55845 Mdot
.40704 .41311 Mdot
.58948 .53352 Mdot
.33467 .5472 Mdot
.52708 .30109 Mdot
.35817 .54279 Mdot
.58339 .54161 Mdot
.61572 .34403 Mdot
.41943 .42174 Mdot
.36244 .71605 Mdot
.40461 .58351 Mdot
.74945 .35095 Mdot
.31771 .29899 Mdot
.48336 .67372 Mdot
.49406 .67474 Mdot
.4442 .388 Mdot
.60767 .57477 Mdot
.41699 .54377 Mdot
.67935 .56465 Mdot
.59704 .55611 Mdot
.57817 .56382 Mdot
.38863 .44495 Mdot
.39992 .39786 Mdot
.31502 .53303 Mdot
.61613 .60364 Mdot
.62655 .587 Mdot
.6099 .37405 Mdot
.45161 .67622 Mdot
.35518 .55044 Mdot
.45706 .65825 Mdot
.3444 .52912 Mdot
.21268 .69008 Mdot
.568 .6139 Mdot
.45437 .67863 Mdot
.4449 .39971 Mdot
.58405 .34563 Mdot
.35331 .27925 Mdot
.2859 .55758 Mdot
.30805 .54424 Mdot
.62254 .57856 Mdot
.5867 .36168 Mdot
.59105 .37473 Mdot
.48116 .6545 Mdot
.43053 .39632 Mdot
.58255 .54381 Mdot
.63108 .53075 Mdot
.46563 .78268 Mdot
.28825 .53025 Mdot
.7208 .37524 Mdot
.44483 .296 Mdot
.60735 .57555 Mdot
.60225 .38861 Mdot
.58572 .59261 Mdot
.25858 .68118 Mdot
.60095 .39527 Mdot
.66592 .5596 Mdot
.54407 .40035 Mdot
.32011 .51106 Mdot
.39757 .30593 Mdot
.61242 .51229 Mdot
.28876 .29347 Mdot
.6433 .55675 Mdot
.1382 .52382 Mdot
.47888 .19957 Mdot
.59699 .61659 Mdot
.66334 .56895 Mdot
.44391 .80942 Mdot
.63248 .58399 Mdot
.35206 .30507 Mdot
.54973 .59866 Mdot
.638 .37153 Mdot
.43159 .54236 Mdot
.3572 .58243 Mdot
.43315 .68254 Mdot
.34615 .54305 Mdot
.52617 .6782 Mdot
.4412 .67435 Mdot
.63196 .36474 Mdot
.66566 .56939 Mdot
.70852 .66261 Mdot
.37904 .55115 Mdot
.67503 .56484 Mdot
.40652 .4146 Mdot
.37125 .57549 Mdot
.3207 .51723 Mdot
.41382 .38862 Mdot
.57652 .59246 Mdot
.71069 .72022 Mdot
.39182 .59305 Mdot
.18984 .37455 Mdot
.42277 .41329 Mdot
.40136 .42022 Mdot
.55642 .28073 Mdot
.43317 .68206 Mdot
.42113 .74719 Mdot
.56046 .46821 Mdot
.39262 .40874 Mdot
.57347 .71259 Mdot
.34288 .57038 Mdot
.49265 .36712 Mdot
.56746 .36636 Mdot
.57169 .61548 Mdot
.59206 .5786 Mdot
.43295 .39643 Mdot
.72293 .60314 Mdot
.6092 .24559 Mdot
.40622 .38887 Mdot
.63272 .49906 Mdot
.47202 .3616 Mdot
.35138 .29149 Mdot
.36293 .30284 Mdot
.43929 .69146 Mdot
.2451 .57121 Mdot
.62146 .36626 Mdot
.49032 .66609 Mdot
.39988 .32673 Mdot
.61952 .55379 Mdot
.41628 .37979 Mdot
.35611 .2797 Mdot
.41822 .40404 Mdot
.46242 .68341 Mdot
.42879 .68194 Mdot
.6062 .3863 Mdot
.62872 .34331 Mdot
.79864 .55255 Mdot
.59569 .73471 Mdot
.63678 .58185 Mdot
.74596 .6056 Mdot
.58145 .35849 Mdot
.62965 .43603 Mdot
.4386 .6611 Mdot
.44889 .67684 Mdot
.69693 .45684 Mdot
.61507 .53307 Mdot
.32721 .48051 Mdot
.58769 .55861 Mdot
.51723 .72063 Mdot
.6723 .58688 Mdot
.31922 .54631 Mdot
.64249 .57356 Mdot
.20711 .45036 Mdot
.6564 .57616 Mdot
.57668 .57553 Mdot
.32671 .52234 Mdot
.552 .54846 Mdot
.33471 .54884 Mdot
.60423 .52874 Mdot
.45417 .70357 Mdot
.34312 .54148 Mdot
.53954 .79092 Mdot
.48919 .54668 Mdot
.33552 .28661 Mdot
.43847 .68224 Mdot
.45933 .65074 Mdot
.6814 .71784 Mdot
.62112 .33938 Mdot
.64903 .31037 Mdot
.60767 .57379 Mdot
.34155 .56961 Mdot
.40745 .379 Mdot
.62689 .5888 Mdot
.6214 .62793 Mdot
.59215 .51639 Mdot
.59735 .37486 Mdot
.29232 .53709 Mdot
.46102 .67727 Mdot
.32828 .56522 Mdot
.37678 .61321 Mdot
.37048 .54246 Mdot
.66721 .62976 Mdot
.55284 .58575 Mdot
.53336 .59988 Mdot
.76147 .5881 Mdot
.6826 .27276 Mdot
.60884 .35922 Mdot
.34195 .29037 Mdot
.43228 .68811 Mdot
.61959 .27739 Mdot
.59902 .33548 Mdot
.30429 .54401 Mdot
.59639 .5674 Mdot
.62453 .49577 Mdot
.53148 .47876 Mdot
.54949 .3705 Mdot
.64367 .75105 Mdot
.34522 .51923 Mdot
.35397 .29773 Mdot
.52647 .31141 Mdot
.55545 .32561 Mdot
.44007 .49915 Mdot
.58339 .58005 Mdot
.449 .65409 Mdot
.61453 .32314 Mdot
.38716 .718 Mdot
.42906 .38776 Mdot
.46831 .47238 Mdot
.61415 .59657 Mdot
.43139 .23794 Mdot
.61586 .34456 Mdot
.44753 .68484 Mdot
.43346 .39677 Mdot
.43107 .67352 Mdot
.36085 .30822 Mdot
.18815 .45599 Mdot
.62965 .54877 Mdot
.58163 .59316 Mdot
.44264 .4258 Mdot
.62092 .36321 Mdot
.38341 .50038 Mdot
.39534 .73983 Mdot
.30974 .56435 Mdot
.4126 .54176 Mdot
.63032 .33785 Mdot
.66821 .29842 Mdot
.34217 .56015 Mdot
.41674 .36345 Mdot
.42678 .52458 Mdot
.4284 .37186 Mdot
.58533 .55756 Mdot
.59153 .34664 Mdot
.44095 .40786 Mdot
.38712 .66544 Mdot
.19931 .63841 Mdot
.6734 .35112 Mdot
.64401 .59926 Mdot
.30639 .76376 Mdot
.18389 .55247 Mdot
.71785 .62521 Mdot
.40327 .37697 Mdot
.6058 .60695 Mdot
.65781 .54581 Mdot
.6366 .56439 Mdot
.4333 .38112 Mdot
.33139 .62748 Mdot
.31531 .55181 Mdot
.61844 .56734 Mdot
.45884 .65205 Mdot
.3279 .54235 Mdot
.27881 .52856 Mdot
.35308 .56329 Mdot
.62082 .39871 Mdot
.66293 .55536 Mdot
.49358 .33808 Mdot
.14406 .54428 Mdot
.40181 .39741 Mdot
.33538 .28727 Mdot
.57616 .58723 Mdot
.82479 .44972 Mdot
.5909 .33605 Mdot
.30722 .56345 Mdot
.5976 .59648 Mdot
.3707 .63071 Mdot
.32635 .26717 Mdot
.34817 .52499 Mdot
.6204 .3405 Mdot
.71625 .62666 Mdot
.61854 .59179 Mdot
.6417 .55359 Mdot
.62606 .36615 Mdot
.1881 .41853 Mdot
.51528 .31866 Mdot
.58291 .58615 Mdot
.41112 .39116 Mdot
.72118 .24674 Mdot
.58955 .51951 Mdot
.56135 .33761 Mdot
.33269 .29054 Mdot
.44911 .32445 Mdot
.72688 .38301 Mdot
.603 .64848 Mdot
.32648 .76538 Mdot
.67313 .68687 Mdot
.27832 .74557 Mdot
.50909 .68034 Mdot
.27499 .44624 Mdot
.18705 .66752 Mdot
.41249 .44066 Mdot
.66393 .40114 Mdot
.5237 .81622 Mdot
.48609 .26756 Mdot
.42679 .60495 Mdot
.32185 .35119 Mdot
.39699 .61975 Mdot
.41504 .17425 Mdot
.35806 .55551 Mdot
.49025 .73758 Mdot
.58005 .54707 Mdot
.18517 .54326 Mdot
.6963 .35817 Mdot
.67913 .25385 Mdot
.26842 .73004 Mdot
.41238 .6284 Mdot
.49462 .8367 Mdot
.22991 .65597 Mdot
.72728 .6596 Mdot
.53575 .46252 Mdot
.35632 .37181 Mdot
.52774 .3517 Mdot
.53908 .67805 Mdot
.54008 .55185 Mdot
.22427 .40972 Mdot
.24975 .58538 Mdot
.79966 .44168 Mdot
.72357 .26228 Mdot
.28662 .56233 Mdot
.57665 .37755 Mdot
.46005 .78598 Mdot
.60778 .4259 Mdot
.40043 .35313 Mdot
.32755 .76626 Mdot
.18367 .57951 Mdot
.68378 .34693 Mdot
.30335 .25836 Mdot
.72349 .49961 Mdot
.82543 .58855 Mdot
.49402 .50461 Mdot
.58219 .32603 Mdot
.29887 .42094 Mdot
.53531 .32521 Mdot
.3584 .43265 Mdot
.66656 .28028 Mdot
.48395 .64067 Mdot
.58878 .77172 Mdot
.62125 .34391 Mdot
.72877 .39597 Mdot
.32934 .28927 Mdot
.38462 .32675 Mdot
.38688 .51807 Mdot
.27042 .69705 Mdot
.31866 .27838 Mdot
.47864 .34879 Mdot
.40754 .22941 Mdot
.48438 .85785 Mdot
.60835 .70085 Mdot
.25709 .65846 Mdot
.39167 .45723 Mdot
.65969 .68933 Mdot
.52262 .28386 Mdot
.62049 .72568 Mdot
.55115 .30952 Mdot
.63221 .81418 Mdot
.16598 .48768 Mdot
.53693 .84046 Mdot
.64511 .39647 Mdot
.56715 .55236 Mdot
.31179 .72282 Mdot
.78154 .52572 Mdot
.42779 .67345 Mdot
.45716 .8471 Mdot
.46019 .6471 Mdot
.65225 .37849 Mdot
.48074 .25977 Mdot
.6805 .29819 Mdot
.25133 .55619 Mdot
.47421 .69978 Mdot
.68138 .55816 Mdot
.77666 .73569 Mdot
.35663 .78668 Mdot
.43289 .30308 Mdot
.18197 .57058 Mdot
.44177 .43622 Mdot
.38615 .48641 Mdot
.42332 .3737 Mdot
.18916 .64813 Mdot
.60147 .33874 Mdot
.14271 .56641 Mdot
.18684 .62667 Mdot
.59128 .22097 Mdot
.84728 .66731 Mdot
.4177 .19332 Mdot
.6804 .39888 Mdot
.70905 .67593 Mdot
.6172 .77603 Mdot
.55334 .26568 Mdot
.58156 .21075 Mdot
.36501 .37834 Mdot
.17971 .42576 Mdot
.21455 .68183 Mdot
.5524 .71659 Mdot
.26094 .60042 Mdot
.50237 .26621 Mdot
.48439 .52659 Mdot
.57001 .32382 Mdot
.48558 .57601 Mdot
.5137 .54549 Mdot
.51387 .83771 Mdot
.81992 .47505 Mdot
.81793 .34862 Mdot
.50255 .70292 Mdot
.55553 .1851 Mdot
.2253 .60083 Mdot
.52013 .78593 Mdot
.64997 .28109 Mdot
.4825 .30474 Mdot
.67761 .61388 Mdot
.51603 .33801 Mdot
.6246 .48773 Mdot
.46331 .63687 Mdot
.54169 .29614 Mdot
.25253 .48953 Mdot
.51595 .70764 Mdot
.39341 .78002 Mdot
.55265 .43113 Mdot
.62393 .39499 Mdot
.65319 .71604 Mdot
.59048 .70593 Mdot
.19434 .58001 Mdot
.53423 .21815 Mdot
.18023 .39339 Mdot
.55537 .2175 Mdot
.68024 .56544 Mdot
.64581 .42255 Mdot
.54819 .5358 Mdot
.61031 .71929 Mdot
.64886 .52604 Mdot
.39959 .2406 Mdot
.16379 .5435 Mdot
.80757 .50233 Mdot
.52829 .68724 Mdot
.75559 .6042 Mdot
.17193 .44598 Mdot
.33101 .73598 Mdot
.47533 .20673 Mdot
.64081 .46698 Mdot
.7216 .77279 Mdot
.32335 .53613 Mdot
.56975 .71614 Mdot
.38321 .38235 Mdot
.37063 .70555 Mdot
.58564 .8119 Mdot
.58944 .22849 Mdot
.16146 .53689 Mdot
.49103 .30779 Mdot
.34585 .49825 Mdot
.47993 .41245 Mdot
.29782 .58295 Mdot
.75365 .61986 Mdot
.56348 .53293 Mdot
.56437 .6557 Mdot
.49302 .66527 Mdot
.77425 .50778 Mdot
.35142 .73969 Mdot
.28193 .35285 Mdot
.65367 .64508 Mdot
.27676 .38582 Mdot
.35726 .29973 Mdot
.47501 .45928 Mdot
.24228 .73842 Mdot
.56458 .62725 Mdot
.44999 .18501 Mdot
.16845 .47432 Mdot
.41825 .52783 Mdot
.26548 .65149 Mdot
.44073 .27186 Mdot
.58711 .83165 Mdot
.17297 .59111 Mdot
.21473 .5278 Mdot
.31767 .77421 Mdot
.18811 .34693 Mdot
.65398 .79091 Mdot
.73118 .54965 Mdot
.37656 .41352 Mdot
.10062 .44371 Mdot
.3115 .55718 Mdot
.77604 .61816 Mdot
.78433 .52002 Mdot
.35818 .6421 Mdot
.57218 .40361 Mdot
.70724 .5838 Mdot
.34323 .32128 Mdot
.5901 .3094 Mdot
.68328 .56134 Mdot
.42993 .85097 Mdot
.64332 .81341 Mdot
.44653 .85244 Mdot
.18431 .46328 Mdot
.30498 .76798 Mdot
.495 .81636 Mdot
.7377 .33345 Mdot
.42755 .76153 Mdot
.59494 .53072 Mdot
.5517 .73675 Mdot
.42752 .19243 Mdot
.38258 .50962 Mdot
.37695 .29221 Mdot
.61741 .40708 Mdot
.59747 .82002 Mdot
.26089 .76355 Mdot
.71787 .46322 Mdot
.76739 .41406 Mdot
.50687 .53903 Mdot
.59417 .72553 Mdot
.56323 .66014 Mdot
.23782 .38182 Mdot
.20792 .58856 Mdot
.5097 .82075 Mdot
.56356 .7003 Mdot
.30878 .3638 Mdot
.2251 .51139 Mdot
.53268 .18658 Mdot
.24586 .68166 Mdot
.49521 .80007 Mdot
.57133 .2133 Mdot
.65469 .48004 Mdot
.60425 .2408 Mdot
.23796 .35993 Mdot
.34747 .48543 Mdot
.59274 .69356 Mdot
.35041 .51634 Mdot
.55183 .72195 Mdot
.52222 .43339 Mdot
.43907 .77453 Mdot
.67884 .68979 Mdot
.54394 .71894 Mdot
.22708 .52205 Mdot
.38937 .8268 Mdot
.229 .31697 Mdot
.73353 .72219 Mdot
.27262 .30795 Mdot
.63175 .48726 Mdot
.58466 .5285 Mdot
.16262 .50464 Mdot
.37051 .82572 Mdot
.15668 .55767 Mdot
.43036 .23455 Mdot
.38152 .66495 Mdot
.38549 .43506 Mdot
.75398 .66951 Mdot
.27705 .33087 Mdot
.204 .60824 Mdot
.59283 .28032 Mdot
.45449 .38221 Mdot
.49764 .30892 Mdot
.76334 .6278 Mdot
.72475 .67531 Mdot
.74162 .41576 Mdot
.5403 .56667 Mdot
.69972 .38387 Mdot
.57125 .35933 Mdot
.43939 .22602 Mdot
.61042 .72582 Mdot
.32948 .53519 Mdot
.52307 .80019 Mdot
.55357 .64885 Mdot
.67509 .61844 Mdot
.34478 .48941 Mdot
.57373 .32118 Mdot
.76842 .57701 Mdot
.36984 .36312 Mdot
.19781 .68199 Mdot
.44064 .19952 Mdot
.66868 .67465 Mdot
.64752 .70466 Mdot
.41708 .72718 Mdot
.50642 .338 Mdot
.44092 .38257 Mdot
.25513 .71057 Mdot
.4658 .57228 Mdot
.65344 .71193 Mdot
.70327 .38524 Mdot
.38172 .7384 Mdot
.62658 .62737 Mdot
.42713 .28049 Mdot
.77369 .37087 Mdot
.46512 .47089 Mdot
.65253 .3485 Mdot
.59138 .30402 Mdot
.40707 .16074 Mdot
.21623 .45396 Mdot
.52244 .2076 Mdot
.2599 .71013 Mdot
.42418 .36954 Mdot
.6444 .37096 Mdot
.53682 .72799 Mdot
.32856 .69668 Mdot
.80071 .42262 Mdot
.25995 .52615 Mdot
.56395 .66505 Mdot
.26972 .34755 Mdot
.31197 .76569 Mdot
.42375 .81931 Mdot
.75245 .28887 Mdot
.62153 .31969 Mdot
.34469 .72577 Mdot
.36418 .72828 Mdot
.61046 .31939 Mdot
.55095 .35927 Mdot
.53824 .46919 Mdot
.27041 .74804 Mdot
.51452 .35046 Mdot
.24539 .3299 Mdot
.4248 .52694 Mdot
.35566 .6278 Mdot
.39455 .72613 Mdot
.58008 .68677 Mdot
.2638 .71002 Mdot
.72757 .40788 Mdot
.6599 .76882 Mdot
.54202 .53925 Mdot
.80532 .54915 Mdot
.75589 .66823 Mdot
.4901 .49937 Mdot
.67536 .30602 Mdot
.26701 .48769 Mdot
.63645 .56991 Mdot
.47877 .85927 Mdot
.19957 .56895 Mdot
.56497 .28455 Mdot
.37915 .34544 Mdot
.6455 .54482 Mdot
.64713 .52952 Mdot
.71903 .57705 Mdot
.44758 .31193 Mdot
.70558 .75739 Mdot
.50379 .71634 Mdot
.62321 .48502 Mdot
.70494 .37554 Mdot
.45215 .18535 Mdot
.28563 .70749 Mdot
.21906 .58969 Mdot
.51145 .4382 Mdot
.42894 .19423 Mdot
.42139 .48496 Mdot
.24087 .32875 Mdot
.25576 .39473 Mdot
.48132 .81161 Mdot
.58933 .45064 Mdot
.46508 .30657 Mdot
.40989 .72296 Mdot
.57479 .57811 Mdot
.46979 .25969 Mdot
.23578 .66325 Mdot
.84952 .40461 Mdot
.52555 .27401 Mdot
.4106 .84783 Mdot
.54057 .6243 Mdot
.47225 .31424 Mdot
.60852 .80839 Mdot
.88005 .47825 Mdot
.22845 .39604 Mdot
.50096 .83768 Mdot
.46286 .45374 Mdot
.26867 .72239 Mdot
.3892 .42953 Mdot
.52282 .39006 Mdot
.75264 .58437 Mdot
.2632 .7416 Mdot
.28724 .68876 Mdot
.28245 .71771 Mdot
.72239 .5616 Mdot
.30981 .77732 Mdot
.57151 .29612 Mdot
.43972 .15839 Mdot
.35791 .50653 Mdot
.37786 .233 Mdot
.69529 .5067 Mdot
.5238 .58548 Mdot
.56909 .70949 Mdot
.5246 .16304 Mdot
.71024 .29164 Mdot
.73075 .57252 Mdot
.51987 .76051 Mdot
.44493 .2821 Mdot
.64951 .70181 Mdot
.20172 .61938 Mdot
.42035 .17007 Mdot
.38093 .72608 Mdot
.48139 .22332 Mdot
.18485 .44553 Mdot
.44165 .31161 Mdot
.24603 .43546 Mdot
.25533 .65862 Mdot
.21419 .37442 Mdot
.54874 .65587 Mdot
.48547 .11384 Mdot
.27728 .59651 Mdot
.53646 .47273 Mdot
.56449 .83368 Mdot
.20765 .58504 Mdot
.61101 .27487 Mdot
.65104 .25184 Mdot
.80895 .5684 Mdot
.57073 .75225 Mdot
.57994 .56758 Mdot
.31936 .78661 Mdot
.56051 .77871 Mdot
.48063 .84789 Mdot
.15912 .44756 Mdot
.69585 .40484 Mdot
.61914 .64648 Mdot
.27522 .5613 Mdot
.50701 .50498 Mdot
.50896 .75968 Mdot
.51027 .82859 Mdot
.79092 .58682 Mdot
.413 .57816 Mdot
.27693 .43576 Mdot
.26054 .51978 Mdot
.60705 .46921 Mdot
.40853 .20235 Mdot
.45082 .29775 Mdot
.51328 .69288 Mdot
.21939 .50646 Mdot
.58846 .71829 Mdot
.72251 .3794 Mdot
.721 .68728 Mdot
.57038 .24356 Mdot
.46011 .37252 Mdot
.27959 .55874 Mdot
.42748 .79699 Mdot
.22919 .56765 Mdot
.39834 .2442 Mdot
.70795 .73993 Mdot
.48218 .29825 Mdot
.48346 .74385 Mdot
.38058 .76218 Mdot
.55192 .26159 Mdot
.35263 .37519 Mdot
.73534 .66849 Mdot
.80452 .54635 Mdot
.26328 .50142 Mdot
.66498 .64665 Mdot
.2172 .69298 Mdot
.58411 .69089 Mdot
.41569 .77055 Mdot
.49124 .5379 Mdot
.78717 .48569 Mdot
.66707 .45244 Mdot
.56943 .78934 Mdot
.43932 .48892 Mdot
.75762 .74854 Mdot
.56948 .39147 Mdot
.4873 .8584 Mdot
.42183 .39014 Mdot
.79352 .3528 Mdot
.22979 .54264 Mdot
.5107 .4561 Mdot
.44479 .51121 Mdot
.42448 .28241 Mdot
.46197 .34747 Mdot
.18001 .44484 Mdot
.60054 .23591 Mdot
.3702 .54582 Mdot
.4159 .58626 Mdot
.24376 .33902 Mdot
.39795 .79021 Mdot
.55928 .58503 Mdot
.24685 .57808 Mdot
.48829 .50513 Mdot
.39552 .51958 Mdot
.16555 .50739 Mdot
.28393 .47639 Mdot
.6218 .50068 Mdot
.5963 .72762 Mdot
.53085 .82813 Mdot
.18954 .62074 Mdot
.6132 .25367 Mdot
.62293 .48773 Mdot
.37554 .38826 Mdot
.58023 .80232 Mdot
.35531 .7817 Mdot
.32132 .4798 Mdot
.49403 .35784 Mdot
.60073 .70029 Mdot
.49778 .87966 Mdot
.63885 .81362 Mdot
.71893 .7377 Mdot
.41931 .53733 Mdot
.63783 .31327 Mdot
.82565 .46153 Mdot
.41304 .76949 Mdot
.36516 .24421 Mdot
.20797 .54915 Mdot
.57578 .71519 Mdot
.86542 .47092 Mdot
.69655 .29173 Mdot
.37202 .61159 Mdot
.66906 .45455 Mdot
.78243 .54164 Mdot
.40054 .43705 Mdot
.55682 .75933 Mdot
.44146 .58772 Mdot
.4359 .36781 Mdot
.44624 .28519 Mdot
.4755 .35387 Mdot
.41804 .7712 Mdot
.78683 .40036 Mdot
.59693 .4871 Mdot
.36793 .77642 Mdot
.61209 .30487 Mdot
.38373 .71844 Mdot
.41983 .73419 Mdot
.42817 .59428 Mdot
.32452 .56334 Mdot
.53991 .59669 Mdot
.4849 .42701 Mdot
.4476 .47282 Mdot
.77335 .67241 Mdot
.47034 .64559 Mdot
.59592 .4094 Mdot
.6756 .26791 Mdot
.62917 .32492 Mdot
.35216 .8183 Mdot
.23789 .38321 Mdot
.70033 .37397 Mdot
.27932 .58546 Mdot
.3032 .39129 Mdot
.83017 .60684 Mdot
.74569 .6464 Mdot
.49964 .58042 Mdot
.57743 .2997 Mdot
.58124 .33706 Mdot
.27263 .57315 Mdot
.37504 .30907 Mdot
.74588 .40454 Mdot
.44461 .18039 Mdot
.43425 .75661 Mdot
.59032 .31931 Mdot
.35457 .61715 Mdot
.67887 .66486 Mdot
.22739 .71664 Mdot
.34384 .56442 Mdot
.70254 .78365 Mdot
.5533 .58861 Mdot
.62752 .79085 Mdot
.16452 .51402 Mdot
.53059 .29523 Mdot
.41272 .55023 Mdot
.33991 .35262 Mdot
.57729 .60693 Mdot
.58491 .48923 Mdot
.62771 .34843 Mdot
.41821 .75032 Mdot
.45877 .66862 Mdot
.63418 .74617 Mdot
.42385 .3652 Mdot
.57397 .19951 Mdot
.41419 .20501 Mdot
.57555 .37932 Mdot
.46036 .586 Mdot
.30883 .71113 Mdot
.54451 .43697 Mdot
.48746 .50488 Mdot
.44218 .8068 Mdot
.80352 .43512 Mdot
.58805 .32216 Mdot
.70774 .74316 Mdot
.45572 .73723 Mdot
.1757 .62539 Mdot
.66963 .66073 Mdot
.50173 .49662 Mdot
.54837 .43673 Mdot
.42976 .27414 Mdot
.73215 .3855 Mdot
.21439 .59419 Mdot
.64166 .71905 Mdot
.53291 .36916 Mdot
.54362 .72112 Mdot
.58066 .50705 Mdot
.27254 .43669 Mdot
.37998 .22286 Mdot
.86498 .49156 Mdot
.70577 .4906 Mdot
.51173 .30026 Mdot
.58281 .30369 Mdot
.44725 .1857 Mdot
.58222 .40501 Mdot
.32784 .65219 Mdot
.80365 .4516 Mdot
.22797 .54576 Mdot
.19648 .66597 Mdot
.19469 .57801 Mdot
.52208 .50887 Mdot
.28702 .50026 Mdot
.67937 .68126 Mdot
.6835 .65797 Mdot
.47025 .48739 Mdot
.57779 .60537 Mdot
.6261 .47643 Mdot
.59924 .25724 Mdot
.40464 .25233 Mdot
.70438 .5706 Mdot
.25133 .72284 Mdot
.17461 .61614 Mdot
.35228 .79936 Mdot
.35474 .47988 Mdot
.62571 .39804 Mdot
.60137 .82676 Mdot
.72348 .34957 Mdot
.19846 .61692 Mdot
.70292 .51419 Mdot
.38249 .17303 Mdot
.57041 .81719 Mdot
.25574 .49233 Mdot
.58937 .21756 Mdot
.38325 .29276 Mdot
.17099 .5114 Mdot
.43815 .15911 Mdot
.54334 .65999 Mdot
.16243 .49325 Mdot
.77558 .73544 Mdot
.71897 .52315 Mdot
.47285 .34775 Mdot
.65703 .44146 Mdot
.67035 .67954 Mdot
.44355 .17404 Mdot
.5904 .53111 Mdot
.36395 .5192 Mdot
.40649 .61113 Mdot
.58579 .71359 Mdot
.58685 .65321 Mdot
.45482 .17069 Mdot
.50286 .75865 Mdot
.4863 .73712 Mdot
.349 .71761 Mdot
.53408 .81906 Mdot
.74137 .39197 Mdot
.64512 .50784 Mdot
.65455 .37936 Mdot
.44662 .69456 Mdot
.52755 .66537 Mdot
.64359 .53731 Mdot
.40618 .53044 Mdot
.54983 .46449 Mdot
.42801 .85284 Mdot
.33098 .67591 Mdot
.27899 .64337 Mdot
.58954 .3067 Mdot
.44375 .30197 Mdot
.32807 .74217 Mdot
.48406 .26441 Mdot
.48273 .16568 Mdot
.81795 .48162 Mdot
.32132 .77082 Mdot
.48599 .31599 Mdot
.54422 .69206 Mdot
.79849 .63683 Mdot
.38617 .41055 Mdot
.76335 .56423 Mdot
.49458 .82081 Mdot
.47373 .27635 Mdot
.64974 .35123 Mdot
.23888 .48512 Mdot
.28619 .44916 Mdot
.4631 .27906 Mdot
.16948 .4706 Mdot
.35913 .73664 Mdot
.68039 .43552 Mdot
.4087 .8104 Mdot
.30135 .51362 Mdot
.56265 .7021 Mdot
.2277 .46443 Mdot
.43099 .17259 Mdot
.547 .42549 Mdot
.22734 .70407 Mdot
.46298 .49178 Mdot
.57071 .77983 Mdot
.63442 .55113 Mdot
.76495 .38771 Mdot
.41387 .26021 Mdot
.22457 .4972 Mdot
.52211 .21301 Mdot
.60753 .40025 Mdot
.41748 .21889 Mdot
.35882 .37355 Mdot
.56995 .76377 Mdot
.52532 .63761 Mdot
.636 .41917 Mdot
.50153 .68241 Mdot
.33302 .30343 Mdot
.55663 .56829 Mdot
.60722 .77091 Mdot
.24392 .54997 Mdot
.7548 .56839 Mdot
.73111 .54545 Mdot
.42789 .79871 Mdot
.23747 .59664 Mdot
.38966 .24452 Mdot
.72595 .55144 Mdot
.41437 .32433 Mdot
.70527 .30248 Mdot
.49357 .24476 Mdot
.61955 .51246 Mdot
.3291 .65002 Mdot
.64219 .36057 Mdot
.4038 .79543 Mdot
.66717 .35877 Mdot
.53449 .7909 Mdot
.4928 .44799 Mdot
.30223 .71649 Mdot
.47714 .54156 Mdot
.16676 .51536 Mdot
.38201 .2904 Mdot
.61273 .72594 Mdot
.45091 .39846 Mdot
.46282 .45174 Mdot
.53141 .26716 Mdot
.22365 .67429 Mdot
.58268 .23683 Mdot
.71497 .65923 Mdot
.50339 .3031 Mdot
.79869 .52707 Mdot
.15697 .46541 Mdot
.60084 .73924 Mdot
.4717 .48587 Mdot
.62252 .6754 Mdot
.39016 .32491 Mdot
.35093 .27772 Mdot
.34897 .65518 Mdot
.73498 .37207 Mdot
.28475 .62902 Mdot
.39364 .58254 Mdot
.56119 .56054 Mdot
.82245 .44042 Mdot
.39025 .79885 Mdot
.62136 .27551 Mdot
.50277 .46862 Mdot
.40511 .70993 Mdot
.57801 .76496 Mdot
.64786 .16662 Mdot
.47215 .86103 Mdot
.63395 .54992 Mdot
.4301 .53056 Mdot
.62474 .74712 Mdot
.30808 .51927 Mdot
.75143 .41627 Mdot
.42282 .79825 Mdot
.3969 .41621 Mdot
.37921 .67735 Mdot
.35554 .26583 Mdot
.41805 .27619 Mdot
.55877 .79372 Mdot
.39781 .44758 Mdot
.37606 .83493 Mdot
.2079 .54004 Mdot
.42029 .2559 Mdot
.55784 .11902 Mdot
.41734 .23502 Mdot
.63447 .30546 Mdot
.27575 .6812 Mdot
.38334 .82398 Mdot
.41954 .53332 Mdot
.36895 .70035 Mdot
.73459 .54874 Mdot
.624 .72391 Mdot
.51322 .71901 Mdot
.47915 .22331 Mdot
.43422 .21557 Mdot
.45034 .15508 Mdot
.30426 .38938 Mdot
.78079 .67148 Mdot
.71825 .399 Mdot
.42609 .82455 Mdot
.23073 .39091 Mdot
.86239 .4565 Mdot
.19001 .64924 Mdot
.5421 .74237 Mdot
.47647 .17177 Mdot
.27119 .66797 Mdot
.66166 .73686 Mdot
.79546 .38965 Mdot
.21372 .41003 Mdot
.81229 .45825 Mdot
.29311 .383 Mdot
.51093 .23095 Mdot
.54838 .72099 Mdot
.78987 .53812 Mdot
.45775 .49267 Mdot
.47825 .82878 Mdot
.5545 .17682 Mdot
.63576 .7057 Mdot
.38914 .68138 Mdot
.66789 .74283 Mdot
.36195 .77852 Mdot
.24416 .65726 Mdot
.46696 .50554 Mdot
.78243 .72042 Mdot
.51211 .83711 Mdot
.49656 .25722 Mdot
.63066 .51855 Mdot
.18201 .65275 Mdot
.44795 .54284 Mdot
.73237 .56208 Mdot
.1842 .52076 Mdot
.50036 .71477 Mdot
.56568 .4541 Mdot
.58544 .52026 Mdot
.74255 .66005 Mdot
.6722 .31343 Mdot
.78451 .54619 Mdot
.4115 .70124 Mdot
.64739 .70654 Mdot
.5614 .18148 Mdot
.61957 .78081 Mdot
.69097 .64673 Mdot
.63478 .34313 Mdot
.40403 .83907 Mdot
.72576 .65852 Mdot
.53132 .55981 Mdot
.66717 .41852 Mdot
.58969 .23655 Mdot
.34254 .32532 Mdot
.63364 .49024 Mdot
.5059 .3414 Mdot
.57203 .70913 Mdot
.4029 .76453 Mdot
.74755 .5904 Mdot
.85774 .65628 Mdot
.16253 .51982 Mdot
.56159 .376 Mdot
.75388 .54728 Mdot
.41611 .59972 Mdot
.35937 .80045 Mdot
.30577 .36021 Mdot
.41803 .72969 Mdot
.65668 .23701 Mdot
.66107 .72179 Mdot
.65743 .61231 Mdot
.18206 .46751 Mdot
.20222 .65982 Mdot
.58072 .18172 Mdot
.21709 .69184 Mdot
.63233 .64281 Mdot
.58926 .62976 Mdot
.84189 .35235 Mdot
.28833 .74431 Mdot
.59859 .64675 Mdot
.62035 .23847 Mdot
.57236 .40632 Mdot
.58471 .54168 Mdot
.35545 .26757 Mdot
.59668 .688 Mdot
.50583 .72633 Mdot
.26709 .7443 Mdot
.60842 .30712 Mdot
.4098 .54062 Mdot
.37944 .39727 Mdot
.44517 .50546 Mdot
.61497 .49721 Mdot
.44089 .41242 Mdot
.50193 .7354 Mdot
.43955 .54977 Mdot
.40487 .33518 Mdot
.54051 .65272 Mdot
.23387 .32022 Mdot
.52487 .55808 Mdot
.51688 .51599 Mdot
.69571 .51765 Mdot
.71012 .29042 Mdot
.50591 .75858 Mdot
.47845 .76035 Mdot
.16384 .48696 Mdot
.22857 .28961 Mdot
.33154 .59107 Mdot
.70335 .61423 Mdot
.5788 .43048 Mdot
.72783 .3719 Mdot
.67149 .4295 Mdot
.47115 .38933 Mdot
.35643 .28713 Mdot
.66345 .62974 Mdot
.66704 .67472 Mdot
.40811 .36973 Mdot
.46589 .8722 Mdot
.60068 .52226 Mdot
.71119 .42591 Mdot
.2163 .64628 Mdot
.3878 .71891 Mdot
.56298 .4816 Mdot
.5831 .61135 Mdot
.57696 .29177 Mdot
.44205 .55293 Mdot
.6995 .66161 Mdot
.40109 .73004 Mdot
.37138 .80087 Mdot
.5416 .50489 Mdot
.69989 .41867 Mdot
.6174 .57271 Mdot
.48041 .69437 Mdot
.49993 .37378 Mdot
.73792 .69697 Mdot
.51217 .63461 Mdot
.19083 .61229 Mdot
.46805 .73044 Mdot
.50383 .71572 Mdot
.67828 .38591 Mdot
.4765 .84974 Mdot
.5197 .27475 Mdot
.69351 .39986 Mdot
.58845 .26737 Mdot
.24739 .4505 Mdot
.52076 .75879 Mdot
.26638 .55684 Mdot
.70322 .56811 Mdot
.5784 .41371 Mdot
.27706 .76492 Mdot
.74858 .6434 Mdot
.46002 .43077 Mdot
.25778 .50749 Mdot
.70619 .31 Mdot
.44948 .50768 Mdot
.51726 .11451 Mdot
.31708 .34693 Mdot
.38201 .8375 Mdot
.38522 .74789 Mdot
.57597 .4307 Mdot
.44616 .27901 Mdot
.54579 .61418 Mdot
.3202 .52582 Mdot
.36472 .80114 Mdot
.63831 .66983 Mdot
.49128 .23725 Mdot
.60813 .52681 Mdot
.54424 .30887 Mdot
.67632 .67108 Mdot
.29615 .49252 Mdot
.3695 .52942 Mdot
.60644 .24829 Mdot
.24654 .6711 Mdot
.44334 .55392 Mdot
.36224 .19396 Mdot
.51202 .82971 Mdot
.25296 .70874 Mdot
.26164 .52025 Mdot
.79228 .34448 Mdot
.59173 .29693 Mdot
.68564 .65848 Mdot
.45428 .41057 Mdot
.71293 .67579 Mdot
.46712 .27565 Mdot
.40403 .7601 Mdot
.41817 .32176 Mdot
.53506 .45366 Mdot
.42144 .11621 Mdot
.53867 .73638 Mdot
.62073 .28208 Mdot
.45903 .25543 Mdot
.23934 .70555 Mdot
.42038 .6357 Mdot
.19229 .37075 Mdot
.21768 .42771 Mdot
.60741 .49726 Mdot
.77749 .38131 Mdot
.66298 .76247 Mdot
.31942 .46295 Mdot
.80523 .64521 Mdot
.23046 .57038 Mdot
.53666 .67757 Mdot
.22405 .49007 Mdot
.62486 .3222 Mdot
.57845 .40932 Mdot
.24349 .36388 Mdot
.28527 .26903 Mdot
.71649 .60209 Mdot
.33946 .77463 Mdot
.83859 .55246 Mdot
.4243 .74593 Mdot
.32249 .78112 Mdot
.39881 .46247 Mdot
.55473 .33671 Mdot
.49753 .75574 Mdot
.43098 .71401 Mdot
.30124 .51912 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0Soooool2o`000;Sooooo
000Looooo`03o`000?oooooooooo08oooooo0_l0002hooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0QOooool2o`0000Cooooo0_l0000=ooooo`;o00000oooool2o`0000?ooooo0_l0002Sooooo`00
7?ooool00ol0003oooooooooo`25ooooo`;o00001?ooool2o`000003ooooool0003o000000[ooooo
0_l00003ooooo`;o00000oooool2o`0000_ooooo0_l0002Fooooo`007?ooool00ol0003ooooooooo
o`2>ooooo`;o00008Oooool2o`0009Kooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2jooooo`;o
0000SOooool001cooooo00?o0000ooooooooool0^Oooool3o`0008gooooo000Looooo`03o`000?oo
oooooooo07?ooooo0_l00014ooooo`;o0000S_ooool001cooooo00?o0000ooooooooool0Loooool2
o`000=Cooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooo
oom;ooooo`007?ooool00ol0003oooooooooo`2?ooooo`;o0000^?ooool001cooooo00?o0000oooo
ooooool0Roooool2o`0000;ooooo0_l0000Zooooo`;o0000S?ooool001cooooo00?o0000oooooooo
ool0P?ooool2o`0000Wooooo0_l0000;ooooo`;o00003Oooool2o`0001;ooooo0_l0002<ooooo`00
7?ooool00ol0003oooooooooo`20ooooo`;o00005_ooool3o`0000Sooooo0_l00002ooooo`;o0000
5Oooool2o`0008Wooooo000Looooo`03o`000?oooooooooo09Cooooo0_l00003ooooo`Co00001_oo
ool2o`0001Wooooo0_l0000?ooooo`;o0000N?ooool001cooooo00?o0000ooooooooool0QOooool2
o`0000Wooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Gooooo0_l00006
ooooo`;o00008oooool2o`0007Sooooo000Looooo`03o`000?oooooooooo07Wooooo0_l00008oooo
o`Co000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00005ooooo`;o00002Oooool2o`00
00Kooooo0_l0000Iooooo`;o0000P_ooool001cooooo00?o0000ooooooooool0NOooool2o`0000So
oooo0_l00003ooooo`;o00000_ooool2o`0002;ooooo0_l0000Cooooo`;o0000P_ooool001cooooo
00?o0000ooooooooool0HOooool2o`0002Sooooo1?l0000Looooo`?o00000_ooool2o`000003oooo
ool0003o000001Cooooo0_l0001nooooo`007?ooool00ol0003oooooooooo`1Qooooo`;o0000:?oo
ool5o`0001_ooooo0ol00005ooooo`;o00001?ooool2o`0000kooooo0_l0001nooooo`007?ooool0
0ol0003oooooooooo`2>ooooo`?o00006?ooool2o`0000Kooooo1?l00003ooooo`?o0000S_ooool0
01cooooo00?o0000ooooooooool0S_ooool3o`0001Gooooo0_l000000ooooooo0000o`000006oooo
o`Co00000oooool2o`0008oooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44
ooooo`Go00001_ooool00ol0003oooooooooo`24ooooo`;o000000?oooooo`000?l000007Oooool2
o`0000Wooooo0_l00007ooooo`;o00007?ooool2o`0006oooooo00001_ooooooMgMgoiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003ooooo
ooooo`1booooo`;o00004?ooool2o`000004ooooool0003o0000o`00033ooooo1?l00002ooooo`;o
00005_ooool2o`0006oooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo
00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`1booooo`;o00005?ooool2o`000003oooo
ool0003o000000?ooooo0_l00006ooooo`;o00007Oooool2o`0000?ooooo0_l00002ooooo`;o0000
Qoooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^
kP06ooooo`?o0000F?ooool2o`0002Oooooo0_l00005ooooo`;o000000?oooooo`000?l000000ooo
ool2o`0000Kooooo0_l0000;ooooo`;o00004?ooool2o`0001_ooooo0_l0001cooooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000
ooooooooool0F?ooool2o`0002Oooooo1?l0000Eooooo`;o00002Oooool2o`0000?ooooo0_l0000X
ooooo`;o00001Oooool2o`0006cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo
00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`23ooooo`;o00004_ooool2o`00
0003ooooool0003o000000[ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00005_ooool2
o`0000oooooo0_l00003ooooo`;o0000K?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2ooo
ool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0NOooool4o`0001[ooooo
0_l00006ooooo`;o00000_ooool5o`000003ooooool0003o000000;ooooo0_l00008ooooo`Co0000
00?oooooo`000?l000001oooool2o`0000oooooo0_l0001aooooo`0000Koooooonk^k_lb<S;o0000
oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1ioooo
o`Co00003Oooool2o`0000_ooooo0_l00006ooooo`;o00000_ooool5o`0000kooooo1Ol000000ooo
oooo0000o`00000Qooooo`;o0000J?ooool001cooooo00?o0000ooooooooool0DOooool2o`0003Ko
oooo0ol0000=ooooo`;o00001?ooool2o`0000Gooooo0_l00002ooooo`?o00001?ooool2o`0000?o
oooo0_l00003ooooo`?o00002Oooool3o`0001Gooooo1?l0001Vooooo`007?ooool00ol0003ooooo
ooooo`1Aooooo`;o0000<Oooool2o`0000?ooooo1?l0000;ooooo`Go00003Oooool3o`0000Cooooo
0_l00008ooooo`Go00001oooool3o`0001Kooooo0ol0001Vooooo`007?ooool00ol0003ooooooooo
o`1hooooo`;o00002_ooool2o`0000Cooooo0ol0000;ooooo`Go00000oooool2o`0001Wooooo1Ol0
000Pooooo`;o0000Ioooool001cooooo00?o0000ooooooooool0N?ooool2o`0000oooooo1?l0000;
ooooo`?o00001Oooool2o`0000_ooooo0_l0000<ooooo`;o00003oooool4o`0000gooooo0_l0001Z
ooooo`007?ooool00ol0003oooooooooo`21ooooo`?o00001?ooool5o`00023ooooo0ol0000<oooo
o`;o00003_ooool4o`0000gooooo0_l0001Zooooo`007?ooool00ol0003oooooooooo`1gooooo`;o
00002?ooool3o`0000Cooooo0_l0000Hooooo`;o00002_ooool2o`0000cooooo0_l0002;ooooo`00
7?ooool00ol0003oooooooooo`19ooooo`;o0000;?ooool2o`0000Wooooo1?l00002ooooo`?o0000
4?ooool2o`0000Gooooo0_l0000Eooooo`;o000000Coooooo`000?l0003ooooo0_l0000@ooooo`?o
0000MOooool001cooooo00?o0000ooooooooool0BOooool2o`0003Oooooo1?l00002ooooo`?o0000
2_ooool2o`0000Cooooo1?l000001?oooooo0000o`000?l0000Fooooo`;o000000Coooooo`000?l0
003ooooo0_l00005ooooo`;o00002Oooool3o`0007Gooooo000Looooo`03o`000?oooooooooo07Co
oooo0_l00008ooooo`;o00001?ooool2o`0000;ooooo0_l0000;ooooo`?o00000oooool8o`0001Co
oooo0_l00007ooooo`;o00001?ooool2o`00087ooooo000Looooo`03o`000?oooooooooo05oooooo
0ol0000Aooooo`?o00001Oooool2o`000003ooooool0003o000000_ooooo0_l00009ooooo`;o0000
1Oooool4o`0001Gooooo0ol00002ooooo`Co000000?oooooo`000?l000000_l0000:ooooo`;o0000
1oooool2o`0000?ooooo0_l00004ooooo`;o0000IOooool001cooooo00?o0000ooooooooool0Gooo
ool3o`0000Oooooo0_l00002ooooo`;o00001?ooool2o`0000Kooooo0_l000000ooooooo0000o`00
000;ooooo`;o00003Oooool5o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000002ooo
ool2o`0000?ooooo1?l00002ooooo`?o00002_ooool2o`0000Oooooo0_l00003ooooo`;o00001?oo
ool2o`0000;ooooo0_l0001Qooooo`007?ooool2o`0006;ooooo0_l00006ooooo`;o00000_ooool2
o`0000oooooo1?l0000?ooooo`;o00001oooool4o`0000;ooooo0ol00003ooooo`;o000000?ooooo
o`000?l000005_ooool2o`0000gooooo0_l0000Aooooo`;o000000?oooooo`000?l00000HOooool0
01cooooo00?o0000ooooooooool0HOooool2o`0000?ooooo0_l0000Gooooo`?o00003oooool2o`00
00gooooo0_l0000Qooooo`;o00002oooool2o`0000Oooooo0_l00008ooooo`Co0000H_ooool001co
oooo00?o0000ooooooooool0@Oooool2o`0001cooooo0_l000000ooooooo0000o`000002ooooo`;o
00000oooool4o`00013ooooo0ol00003ooooo`;o00002_ooool2o`000003ooooool0003o000000So
oooo1?l0000@ooooo`;o00000oooool4o`0000Cooooo0_l00002ooooo`;o00003_ooool2o`0000Co
oooo0_l000000ooooooo0000o`000007ooooo`;o0000H_ooool001cooooo00?o0000ooooooooool0
@Oooool2o`0001cooooo0_l000000ooooooo0000o`000007ooooo`Co00003?ooool2o`0000Kooooo
1?l0000=ooooo`?o000000?oooooo`000?l000001?ooool2o`00013ooooo1?l00003ooooo`Co0000
1?ooool2o`0001;ooooo0_l00006ooooo`?o0000Joooool001cooooo00?o0000ooooooooool0FOoo
ool2o`00023ooooo1?l00004ooooo`;o00003oooool3o`000004ooooool0003o0000o`0000[ooooo
0_l00009ooooo`;o00001_ooool3o`0001Cooooo1?l00002ooooo`?o00000oooool2o`0000[ooooo
0_l0001Pooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o00002oooool2o`0000Sooooo0_l0
000;ooooo`;o00003?ooool2o`0000[ooooo1Ol00003ooooo`;o00001?ooool2o`0000;ooooo0_l0
0005ooooo`;o00002Oooool2o`0001;ooooo1?l00002ooooo`?o00003oooool2o`00063ooooo000L
ooooo`03o`000?oooooooooo05Wooooo0_l0000;ooooo`;o000000?oooooo`000?l000001Oooool2
o`0000[ooooo1?l00003ooooo`;o00001_ooool2o`0000[ooooo0_l000000ooooooo0000o`000003
ooooo`;o00001?ooool2o`0000;ooooo0_l00005ooooo`Co00001oooool2o`0001?ooooo0ol00003
ooooo`Co00004Oooool2o`0000Cooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`1Ioooo
o`?o00003?ooool3o`0000;ooooo0_l000000ooooooo0000o`000002o`0000Sooooo1?l00003oooo
o`;o00001_ooool2o`0000Wooooo0_l0000=ooooo`;o00001Oooool2o`0000?ooooo0ol0000Loooo
o`?o00001Oooool4o`0000oooooo0_l00004ooooo`;o0000E_ooool001cooooo00?o0000oooooooo
ool0F_ooool2o`0000cooooo3?l0000@ooooo`;o00000_ooool2o`000003ooooool0003o000000Oo
oooo1?l00007ooooo`;o00000_ooool6o`0000?ooooo0_l00009ooooo`;o00002_ooool5o`0000[o
oooo0_l00006ooooo`;o0000KOooool001cooooo00?o0000ooooooooool0E_ooool2o`0000cooooo
0_l00003ooooo`Wo00003Oooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000Cooooo
1Ol00007ooooo`;o00000_ooool7o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`;o0000
2_ooool5o`0000[ooooo0_l00006ooooo`;o00001Oooool2o`0006Kooooo000Looooo`03o`000?oo
oooooooo05Gooooo0ol0000<ooooo`?o000000?oooooo`000?l000002?l0000=ooooo`;o00001Ooo
ool3o`0000Cooooo0_l00004ooooo`;o00004oooool2o`0000Cooooo1Ol0000:ooooo`;o00000_oo
ool2o`000003ooooool0003o000000;o00001oooool2o`0000Cooooo0_l00002ooooo`?o00001Ooo
ool2o`0006Kooooo000Looooo`03o`000?oooooooooo05Gooooo0_l00007ooooo`;o00001?ooool3
o`000003ooooool0003o000000Wo00000_ooool2o`0000oooooo0ol00004ooooo`;o00001?ooool2
o`0000Kooooo0_l00009ooooo`;o00001oooool4o`000003ooooool0003o000000Oooooo1_l00003
ooooo`;o00001oooool2o`0000Cooooo0_l00002ooooo`;o00004oooool2o`0005Wooooo000Loooo
o`03o`000?oooooooooo05?ooooo0_l00008ooooo`?o00001?ooool2o`000003ooooool0003o0000
00ko00005_ooool2o`0000Cooooo0_l00006ooooo`;o00002Oooool2o`000003ooooool0003o0000
00;ooooo1Ol00002ooooo`Oo00001?ooool2o`0001?ooooo0_l00007ooooo`;o00001?ooool3o`00
00Sooooo0_l000000ooooooo0000o`00001Fooooo`007?ooool00ol0003oooooooooo`17ooooo`;o
00002_ooool2o`0000Kooooo1?l00008ooooo`ko00000_ooool3o`0001Gooooo0_l00008ooooo`Co
00003?ooool2o`0000;ooooo1Ol00002ooooo`Oo00005Oooool2o`0000;ooooo0_l00007ooooo`?o
00000oooool3o`0000_ooooo0ol00004ooooo`;o0000Coooool001cooooo00?o0000ooooooooool0
Aoooool2o`0000[ooooo0_l00005ooooo`?o00001Oooool2o`0000Cooooo3Ol00002ooooo`Co0000
2oooool2o`0000Kooooo0ol00008ooooo`?o00003Oooool2o`000003ooooool0003o000000Kooooo
0_l00002ooooo`;o00001Oooool4o`0000gooooo1?l0000:ooooo`;o00000oooool3o`0000Gooooo
0_l00005ooooo`;o00001?ooool2o`0004oooooo000Looooo`03o`000?oooooooooo057ooooo0_l0
0007ooooo`;o00001_ooool2o`0000Cooooo3_l00003ooooo`;o00002?ooool2o`000003ooooool0
003o000000Gooooo1?l00008ooooo`Co00003?ooool7o`0000;ooooo0_l00002ooooo`?o00000ooo
ool2o`000003ooooool0003o000000;o000000Coooooo`000?l0003o00002oooool2o`000003oooo
ool0003o000000;ooooo0_l0000@ooooo`;o0000G?ooool001cooooo0_l0001Booooo`;o00004?oo
ool4o`0000;ooooo3Ol0000=ooooo`;o00000oooool2o`0000;ooooo1Ol00008ooooo`Co00001Ooo
ool2o`0000?ooooo2Ol00002ooooo`;o00000_ooool:o`0000Cooooo0ol00002ooooo`;o00002_oo
ool2o`0000;ooooo0_l0000;ooooo`;o00003?ooool2o`0005?ooooo000Looooo`03o`000?oooooo
oooo06?ooooo1?l000000ooooooo0000o`00000<o`0001;ooooo0ol000000ooooooo0000o`00000;
ooooo`?o00001?ooool4o`0000?ooooo0ol0000>ooooo`So000000?oooooo`000?l000001_ooool2
o`0000[ooooo0_l00003ooooo`;o00001Oooool2o`0000?ooooo0_l0000<ooooo`;o0000Doooool0
01cooooo00?o0000ooooooooool0J?ooool>o`0000Oooooo0_l00009ooooo`?o000000?oooooo`00
0?l000000_ooool2o`000003ooooool0003o000000Cooooo1Ol00002ooooo`;o000000Coooooo`00
0?l0003ooooo0_l0000:ooooo`;o00001Oooool6o`0000;ooooo1?l00002ooooo`;o000000?ooooo
o`000?l000002Oooool2o`000003ooooool0003o000000;o00001Oooool2o`0006Kooooo000Loooo
o`03o`000?oooooooooo03?ooooo0_l0000Hooooo`;o00001_ooool3o`0001;ooooo4?l00003oooo
o`;o00004Oooool2o`000003ooooool0003o000000Oooooo1?l00003ooooo`;o000000?oooooo`00
0?l000001Oooool4o`000003ooooool0003o000000Gooooo1Ol000000ooooooo0000o`000004o`00
0003ooooool0003o000000Co00000oooool4o`0000Gooooo0_l00005ooooo`;o000000?oooooo`00
0?l000004Oooool2o`0005;ooooo000Looooo`03o`000?oooooooooo03?ooooo0_l0000Hooooo`;o
00001_ooool3o`0000Sooooo0_l00008oooooa3o000000?oooooo`000?l000003oooool4o`0000ko
oooo0_l00005ooooo`Co00001?ooool4o`0000Wooooo1?l000000ooooooo0000o`000003o`000003
ooooool0003o000000Ko00000_ooool4o`0000Cooooo0_l00006ooooo`;o000000?oooooo`000?l0
00004Oooool2o`0005;ooooo000Looooo`03o`000?oooooooooo04Oooooo0_l0000Gooooo`;o0000
2oooool6o`000003ooooool0003o000000Gooooo0_l0000?ooooo`Co000000?oooooo`000?l00000
0oooool2o`000004ooooool0003o0000o`0000Sooooo1Ol000000ooooooo0000o`00000:ooooo`;o
00001oooool5o`000004ooooool0003o0000ooooo`So00000oooool2o`0000;ooooo0_l00004oooo
o`;o00000_ooool2o`0006Kooooo000Looooo`03o`000?oooooooooo04Oooooo1?l0000@ooooo`;o
00004oooool3o`0000Wooooo0_l0000Cooooo`Co000000Coooooo`000?l0003ooooo0ol00007oooo
o`Ko000000?oooooo`000?l000002_ooool2o`0000Cooooo0_l000000ooooooo0000o`000004o`00
0003ooooool0003o000000Cooooo1?l00003ooooo`;o00002?ooool3o`000003ooooool0003o0000
06Kooooo000Looooo`03o`000?oooooooooo04Sooooo0ol0000@ooooo`;o00003oooool2o`0000;o
oooo0_l0000:ooooo`;o00000_ooool2o`0000;ooooo0_l0000=ooooo`;o00003Oooool5o`0000;o
oooo0_l0000<ooooo`Oo00000oooool:o`000004ooooool0003o0000o`0000Kooooo0_l00007oooo
o`;o00007Oooool2o`0004[ooooo000Looooo`03o`000?oooooooooo04Sooooo0ol0000Qooooo`;o
00003Oooool2o`0000?ooooo0_l000001?oooooo0000o`000?l00008ooooo`;o00002oooool2o`00
00Cooooo0ol00005ooooo`?o00001Oooool2o`0000;ooooo2_l00002ooooo`oo00001?ooool3o`00
00gooooo0_l0000Gooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0B?ooool2o`000003
ooooool0003o000001oooooo0_l0000;ooooo`Co000000?oooooo`000?l000000_l000001?oooooo
0000o`000?ooool2o`0000Kooooo0_l00002ooooo`;o00001oooool2o`0000Cooooo1_l00003oooo
o`;o00001Oooool2o`0000;ooooo6?l000000ooooooo0000o`000004ooooo`;o00001oooool3o`00
00Cooooo0_l000000ooooooo0000o`00001Pooooo`007?ooool00ol0003oooooooooo`1;ooooo`?o
00002?ooool2o`00027ooooo0_l00003ooooo`;o000000?oooooo`000?l000000oooool2o`0000So
oooo1?l0000?ooooo`Co00001Oooool2o`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l0
00004Ol0000@ooooo`?o00001oooool2o`00063ooooo000Looooo`03o`000?oooooooooo04cooooo
0_l00007ooooo`?o00007_ooool2o`0000Sooooo0ol0000=ooooo`;o00004_ooool2o`0000Kooooo
0_l00003ooooo`;o00000ooooolAo`000003ooooool0003o000000?o00005oooool2o`0000Kooooo
0_l0001Kooooo`007?ooool00ol0003oooooooooo`1Eooooo`;o00007oooool2o`0000Sooooo0_l0
00000ooooooo0000o`00000Cooooo`;o00000oooool2o`0000;ooooo0_l000000ooooooo0000o`00
000:ooooo`Go000000?oooooo`000?l000005ol0000Eooooo`;o00001_ooool3o`0005[ooooo000L
ooooo`03o`000?oooooooooo02_ooooo0_l0000Nooooo`;o0000;?ooool2o`0000Sooooo0_l0000;
ooooo`;o00001_ooool2o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000002_ooool5
o`0000;ooooo6?l0000Nooooo`Co00003_ooool2o`0004Sooooo000Looooo`03o`000?oooooooooo
02_ooooo0_l0000Nooooo`;o00004Oooool2o`0000Gooooo0_l0000Booooo`;o00000_ooool2o`00
00Oooooo0_l00008ooooo`;o00000_ooool2o`0000Kooooo0_l00003ooooo`;o000000?oooooo`00
0?l000003oooool9o`000003ooooool0003o000000ko00003?ooool2o`00017ooooo0ol0000=oooo
o`?o0000B?ooool001cooooo00?o0000ooooooooool0>Oooool2o`0001Wooooo0_l00008ooooo`;o
00000oooool6o`0000kooooo0_l00004ooooo`;o00001oooool3o`0000Wooooo1_l00004ooooo`;o
00001_ooool5o`0000cooooo2Ol000000ooooooo0000o`00000>o`0000_ooooo0ol00006ooooo`;o
00000oooool2o`0000;ooooo1?l0000>ooooo`;o0000BOooool001cooooo0_l0000jooooo`;o0000
6Oooool2o`0000gooooo0_l00002ooooo`;o00003_ooool4o`0000cooooo0_l00006ooooo`;o0000
00Coooooo`000?l0003ooooo1Ol00009ooooo`;o000000Coooooo`000?l0003o00002ooooolNo`00
00Sooooo0_l00007ooooo`;o00000_ooool3o`0000;ooooo0_l00002ooooo`;o00005?ooool2o`00
047ooooo000Looooo`03o`000?oooooooooo05Sooooo0_l0000;ooooo`;o00000oooool3o`0000co
oooo0_l00003ooooo`Co00003Oooool2o`0000Kooooo0ol00003ooooo`;o000000Coooooo`000?l0
003ooooo0_l00003ooooo`;o00002_ooool2o`000003ooooool0003o000001Wo00001Oooool2o`00
0003ooooool0003o000000Oooooo0_l00002ooooo`;o00001oooool2o`0000cooooo0_l00006oooo
o`;o00001_ooool2o`0003Wooooo000Looooo`03o`000?oooooooooo05Sooooo0_l0000;ooooo`;o
00000oooool3o`00017ooooo1?l0000Eooooo`;o00001?ooool5o`0000Kooooo0ol00006ooooo`Go
000000?oooooo`000?l000004?l000001Ooooooo0000o`000?l0003ooooo00?o00001_ooool4o`00
00Gooooo1Ol0000Cooooo`;o00001?ooool2o`0000kooooo0_l0000iooooo`007?ooool00ol0003o
ooooooooo`14ooooo`;o00001?ooool2o`0001Cooooo0_l00009ooooo`;o0000<?ooool4o`0000Oo
oooo0ol00004ooooo`Wo000000?oooooo`000?l000005_l00002ooooo`Co00000_ooool2o`0000?o
oooo1_l0000Dooooo`;o0000Coooool001cooooo00?o0000ooooooooool0?_ooool2o`0000Cooooo
0_l00004ooooo`;o00004oooool3o`0001;ooooo0_l00009ooooo`;o00001?ooool2o`0000oooooo
0_l00005ooooo`?o00003_ooool3o`0000;ooooo4_l000000ooooooo0000o`000009o`0000;ooooo
1?l00006ooooo`Co000000?oooooo`000?l00000IOooool001cooooo00?o0000ooooooooool0?_oo
ool2o`0000_ooooo0_l0000Booooo`Co00004Oooool2o`0000Sooooo0ol00002ooooo`Go00003_oo
ool2o`0000Kooooo0_l0000>ooooo`Co000000?oooooo`000?l000006ol000000ooooooo0000o`00
000:ooooo`Co000000?oooooo`000?l000001?ooool2o`0000oooooo0_l0001>ooooo`007?ooool0
0ol0003oooooooooo`1;ooooo`;o00005?ooool2o`0000_ooooo0_l00004ooooo`;o00002?ooool2
o`0000?ooooo1Ol00002ooooo`;o00003?ooool2o`0000;ooooo0_l0000;ooooo`;o00001Oooool2
o`000003ooooool0003o000001_o000000Coooooo`000?l0003o00005?ooool2o`0000oooooo0_l0
001>ooooo`007?ooool00ol0003oooooooooo`0kooooo`;o00005_ooool2o`0001Wooooo1?l0000=
ooooo`go000000?oooooo`000?l000000oooool2o`0000Cooooo0_l00002ooooo`;o00002_ooool5
o`0000;ooooo0_l000001?oooooo0000o`000?l00002oooooaWo000000Coooooo`000?l0003o0000
5Oooool4o`0000_ooooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`0jooooo`?o000000?o
ooooo`000?l000000_ooool2o`0000kooooo0ol0000Jooooo`Co00003?ooool=o`000004ooooool0
003o0000ooooo`Co00001?ooool2o`0000Gooooo0_l00007ooooo`Go00000_ooool2o`000004oooo
ool0003o0000oooooa_o00001_ooool2o`0000Sooooo3Ol00007ooooo`;o00000_ooool2o`0000Wo
oooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0Tooooo`;o00005?ooool2o`0000;ooooo
0_l00002ooooo`;o00003_ooool2o`0001Sooooo0_l000000ooooooo0000o`000004o`0000[ooooo
3ol000001?oooooo0000o`000?l00008ooooo`Co000000?oooooo`000?l000002?ooool2o`000003
ooooool0003o000000;o00000_oooolEo`000003ooooool0003o000000So000000Coooooo`000?l0
003ooooo0_l00003ooooo`;o00000_ooool;o`0000[ooooo0_l0000=ooooo`;o0000A?ooool001co
oooo00?o0000ooooooooool09?ooool2o`0001?ooooo0_l0000aooooo`;o00001Oooool2o`0000;o
oooo0_l000000ooooooo0000o`00000Bo`000004ooooool0003o0000o`0000Oooooo1Ol000001?oo
oooo0000o`000?l0000:ooooo`Co00000oooool3o`000005ooooool0003o0000o`000?ooool04_l0
0003ooooo`Go00001_ooool6o`000003ooooool0003o000000;o000000?oooooo`000?l000001?oo
ool2o`0000[ooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00003oooool2
o`0000oooooo0_l0000IoooooaOo00000oooool2o`0000Gooooo1?l000001?oooooo0000o`000?oo
ool3o`0000gooooo0_l00003ooooo`;o000000Goooooo`000?l0003o0000ooooo`0Co`0000;ooooo
1Ol00006ooooo`Ko00001_ooool3o`0000?ooooo0_l00004ooooo`;o00001?ooool2o`0004kooooo
000Looooo`03o`000?oooooooooo04[ooooo0_l00005ooooo`;o00000oooool3o`0000;ooooo0_l0
000Iooooo`;o000000?oooooo`000?l000004ol000001?oooooo0000o`000?l00005ooooo`;o0000
3_ooool2o`0000Kooooo0_l00007oooooaKo000000Coooooo`000?l0003o00001oooool4o`0000;o
oooo1?l00005ooooo`Co00001?ooool7o`0001;ooooo0_l0000nooooo`007?ooool00ol0003ooooo
ooooo`0iooooo`;o00003?ooool2o`0000Sooooo0_l00003ooooo`?o00001_ooool2o`0001Gooooo
0_l00002oooooaOo00001?ooool2o`0000oooooo0ol0000@oooooaGo000000?oooooo`000?l00000
2?ooool2o`0000Kooooo0_l00007ooooo`;o00001?ooool3o`000004ooooool0003o0000o`0000So
oooo0_l00008ooooo`;o0000?_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q
8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo02?ooooo0_l0000Boooo
o`Co00003?ooool2o`0001Kooooo0_l0000Booooo`;o000000Coooooo`000?l0003ooooo6?l00004
ooooo`;o00003oooool2o`0000Sooooo0_l00003ooooo`;o00000_oooolDo`0000[ooooo0_l0000<
ooooo`;o00001_ooool2o`0000Oooooo0_l00007ooooo`;o0000B?ooool00006oooooomgMgOoV9RH
oooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Sooooo`;o00004_ooool2o`0000_ooooo0_l000000ooooooo0000o`000006ooooo`Co00003?oo
ool2o`0000cooooo0_l00004ooooo`;o000000?oooooo`000?l000006_l0000Eooooo`;o00001ooo
ool2o`0000?ooooo0_l00002oooooaCo000000?oooooo`000?l000001oooool2o`000003ooooool0
003o000000Wooooo0_l00002ooooo`Ko00001oooool3o`0000Oooooo0_l00017ooooo`0000?ooooo
oa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`Go00001_ooool00ol0003oooooooooo`14
ooooo`;o000000?oooooo`000?l000001_ooool4o`0000gooooo0_l0000:ooooo`?o00002?ooool5
o`000003ooooool0003o000001?o000000?oooooo`000?l000004_ooool2o`0000cooooo0_l00003
oooooa?o000000?oooooo`000?l000002?ooool4o`000003ooooool0003o000000Oooooo0_l00000
0ooooooo0000o`000003o`0000Wooooo0_l00007ooooo`;o0000Aoooool00003ooooool0003ooooo
00;ooooo00?o0000ooooooooool02Oooool01?m4A4CogMgMooooool00007ooooo`?o0000AOooool2
o`0001Wooooo0_l0000:ooooo`;o00002OoooolBo`0000;ooooo1ol000000ooooooo0000o`00000H
ooooo`;o00001_ooool2o`0000;ooooo1Ol00002ooooo`Wo000000Coooooo`000?l0003o00001ooo
ool2o`000003ooooool0003o000000;o00000_ooool2o`0000Oooooo0_l0000:ooooo`;o00001?oo
ool2o`0000;ooooo0_l0001;ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09
ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool08Oooool2o`0001kooooo0_l0
0002ooooo`;o0000<Oooool3o`000003ooooool0003o000000co000000Coooooo`000?l0003o0000
3_ooool3o`000003ooooool0003o000000Wooooo1?l00007ooooo`;o000000?oooooo`000?l00000
3Ol0000<ooooo`Go00001Oooool2o`0000kooooo0_l00002ooooo`;o00001?ooool2o`0000;ooooo
0_l00004ooooo`;o00003?ooool4o`0003Gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oo
oooooooo00[ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0Qooooo`;o00007_oo
ool6o`0000[ooooo0_l0000ToooooaSo00001Oooool3o`0000Gooooo0ol000000ooooooo0000o`00
0009ooooo`;o00002?ooool7o`0000;ooooo2_l0000:ooooo`;o000000?oooooo`000?l000001ooo
ool2o`0000Wooooo0_l00003ooooo`;o00004_ooool3o`0000_ooooo1?l0000eooooo`0000Kooooo
ogMgMonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0
@_ooool5o`0000[ooooo0_l0000Roooooa[o000000?oooooo`000?l000000_ooool3o`000003oooo
ool0003o000001_ooooo0_l000001Ooooooo0000o`000?l0003ooooo00Ko000000?oooooo`000?l0
00000ol00006ooooo`;o00000_ooool2o`0001Gooooo0_l0000Dooooo`;o00000_ooool2o`0000go
oooo0_l0000eooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo
00Kooooo00?o0000ooooooooool0@_ooool2o`000003ooooool0003o000002kooooo7Ol00006oooo
o`;o00005_ooool2o`0000Kooooo0ol000001?oooooo0000o`000?l00004ooooo`;o000000?ooooo
o`000?l000000_ooool2o`0000;ooooo0_l0000Uooooo`;o00002?ooool2o`00017ooooo0_l0000e
ooooo`007?ooool00ol0003oooooooooo`0fooooo`;o000000?oooooo`000?l000001oooool2o`00
03;ooooo6_l0000Pooooo`Co00001?ooool2o`000003ooooool0003o000000;o00002oooool2o`00
00Gooooo1_l00009ooooo`Co00002Oooool2o`000003ooooool0003o000000?ooooo0_l00008oooo
o`;o00004Oooool2o`0003Gooooo000Looooo`03o`000?oooooooooo03Kooooo0_l000000ooooooo
0000o`000007ooooo`;o00006Oooool2o`0001Oooooo4Ol000000ooooooo0000o`000007o`00027o
oooo0_l00004ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000[ooooo0_l00004oooo
o`Ko00001oooool6o`0000Wooooo0_l000000ooooooo0000o`00000=ooooo`;o00005?ooool2o`00
03;ooooo000Looooo`03o`000?oooooooooo01oooooo0_l0000Hooooo`;o00001_ooool2o`0001[o
oooo0_l0000LoooooaKo00002_ooool2o`00017ooooo0_l000000ooooooo0000o`000005ooooo`;o
00000_ooool2o`000003ooooool0003o000000[ooooo0_l000000ooooooo0000o`00000;ooooo`;o
000000?oooooo`000?l000006Oooool2o`0000Gooooo0_l00004ooooo`;o00003Oooool2o`0003;o
oooo000Looooo`03o`000?oooooooooo01oooooo0_l0000Fooooo`Go00001Oooool4o`0000Oooooo
0_l0000]oooooaCo00001Oooool2o`0000Cooooo0ol0000Aooooo`;o000000?oooooo`000?l00000
3oooool2o`0000[ooooo0_l0000;ooooo`;o00001_ooool2o`0001Cooooo0_l00005ooooo`;o0000
1?ooool2o`00047ooooo000Looooo`03o`000?oooooooooo03Oooooo0_l000001?oooooo0000o`00
0?ooool2o`0000Cooooo0_l00007ooooo`;o00004Oooool2o`0001Wooooo5Ol00003ooooo`Co0000
1?ooool2o`0001;ooooo0_l00007ooooo`?o00002?ooool2o`0001;ooooo0_l0000;ooooo`;o0000
7oooool2o`0004?ooooo000Looooo`03o`000?oooooooooo03gooooo0_l0000Mooooo`;o000000?o
ooooo`000?l000004?ooool2o`0000Gooooo5_l00004ooooo`?o00001Oooool2o`0000[ooooo0_l0
0008ooooo`;o00001Oooool3o`0001cooooo0_l0000/ooooo`;o0000@oooool001cooooo00?o0000
ooooooooool0>_ooool2o`00013ooooo0_l00007ooooo`?o00001?ooool2o`0001;ooooo0ol00005
ooooo`Go000000?oooooo`000?l000003_l0000<ooooo`;o00002_ooool2o`0000Cooooo1_l00007
ooooo`;o00001?ooool2o`0000Sooooo0_l00003ooooo`;o00002Oooool2o`0002Kooooo0_l00016
ooooo`007?ooool00ol0003oooooooooo`0Mooooo`;o00006oooool2o`00013ooooo0_l00007oooo
o`?o00006?ooool2o`0000Oooooo3Ol000000ooooooo0000o`000005o`000004ooooool0003o0000
o`00013ooooo0_l00006ooooo`Ko00002Oooool2o`0000Cooooo0_l00008ooooo`;o00000oooool2
o`0000Wooooo0_l0000Vooooo`;o000000?oooooo`000?l00000@oooool001cooooo00?o0000oooo
ooooool07Oooool2o`0001Kooooo0_l00003ooooo`;o00004oooool2o`0000;ooooo0_l0000Qoooo
o`;o000000Coooooo`000?l0003ooooo0ol000000ooooooo0000o`000003o`0000;ooooo0ol00005
ooooo`?o00004?ooool2o`0000Kooooo0_l0000:ooooo`;o00001oooool2o`0000cooooo0_l00003
ooooo`;o0000;?ooool2o`0000;ooooo0_l000000ooooooo0000o`000010ooooo`007?ooool00ol0
003oooooooooo`0Mooooo`;o00004_ooool2o`000003ooooool0003o000000Ko00001?ooool2o`00
00gooooo0_l00002ooooo`;o000000?oooooo`000?l000007?ooool4o`0000?ooooo0ol00003oooo
o`Ko000000?oooooo`000?l000000_ooool4o`0000Sooooo0_l0000Looooo`Co00004oooool2o`00
00?ooooo0_l0000/ooooo`;o00001Oooool2o`00043ooooo000Looooo`03o`000?oooooooooo01go
oooo0_l0000Aooooo`?o000000Coooooo`000?l0003ooooo0ol00006ooooo`;o00005?ooool2o`00
0003ooooool0003o000001Wooooo0_l00005ooooo`Co00001_ooool2o`0000Gooooo1?l00008oooo
o`?o000000?oooooo`000?l000004_ooool4o`0000;ooooo1?l0001;ooooo`;o000000?oooooo`00
0?l00000?oooool001cooooo0_l0000aooooo`;o00002_ooool2o`0000;ooooo0_l0000;ooooo`;o
00002_ooool2o`0001Wooooo0_l00007ooooo`;o00002_ooool2o`0000Sooooo0_l00004ooooo`Go
00004Oooool5o`0000Sooooo0_l0000;ooooo`;o00001Oooool2o`0000?ooooo0_l0000=ooooo`;o
00006oooool2o`0000;ooooo0_l000000ooooooo0000o`00000oooooo`007?ooool00ol0003ooooo
ooooo`0dooooo`;o000000?oooooo`000?l000000oooool2o`0000;ooooo0_l000000ooooooo0000
o`000008ooooo`;o00009Oooool2o`0000[ooooo0_l00007ooooo`;o00002?ooool2o`0000Kooooo
0_l0000=ooooo`;o00000oooool2o`000003ooooool0003o000000;o00001_ooool2o`0000[ooooo
0ol00005ooooo`;o00000oooool3o`0000cooooo0_l0000Kooooo`?o00001?ooool2o`0003oooooo
000Looooo`03o`000?oooooooooo03Cooooo0_l000000ooooooo0000o`000002o`0000Sooooo0_l0
000fooooo`;o00000oooool2o`00017ooooo0_l0000;ooooo`Co00001_ooool2o`0000Sooooo0_l0
0005ooooo`;o00001_ooool2o`0000;ooooo0ol0000<ooooo`;o00001oooool2o`00027ooooo1?l0
000>ooooo`;o0000<oooool001cooooo00?o0000ooooooooool0>?ooool3o`0002;ooooo0_l0000G
ooooo`;o00000oooool2o`0000?ooooo0_l0000Eooooo`;o00001oooool4o`0001Oooooo0_l00006
ooooo`Ko00005_ooool2o`0000Gooooo0_l0000Looooo`;o00000_ooool2o`0000[ooooo0_l0000c
ooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o00002Oooool2o`0000[ooooo1?l0000?oooo
o`;o00001?ooool2o`0000Gooooo0_l0000@ooooo`;o00001_ooool2o`0001Oooooo0_l0000;oooo
o`;o00001?ooool2o`0000?ooooo0_l0000Cooooo`Co00007Oooool3o`00023ooooo0_l0000ooooo
o`007?ooool00ol0003oooooooooo`0]ooooo`Co00001_ooool3o`0000[ooooo1?l0000>ooooo`?o
00001oooool2o`0000;ooooo0_l0000@ooooo`;o00001_ooool2o`0001Kooooo0ol00009ooooo`Co
00001?ooool2o`0000?ooooo0_l0000<ooooo`;o00003Oooool2o`0000[ooooo0_l0000;ooooo`;o
0000H_ooool001cooooo00?o0000ooooooooool0;oooool2o`0000;ooooo1_l00006ooooo`;o0000
0_ooool2o`00017ooooo0_l00008ooooo`;o0000;?ooool2o`0000?ooooo1_l00007ooooo`Co0000
0oooool2o`0000;ooooo0_l00005ooooo`;o00001oooool4o`0000;ooooo0ol00008ooooo`;o0000
2_ooool2o`0003_ooooo0_l0000booooo`007?ooool00ol0003oooooooooo`0cooooo`Co00002?oo
ool2o`0000;ooooo0_l0000Cooooo`;o0000=?ooool2o`0000?ooooo1ol00006ooooo`;o00001Ooo
ool6o`0000Gooooo0_l00007ooooo`;o00001?ooool3o`0001Wooooo0_l0000fooooo`;o0000<_oo
ool001cooooo00?o0000ooooooooool0<oooool2o`0000[ooooo0_l0000>ooooo`;o00001oooool3
o`0000Wooooo0_l0000;ooooo`;o00006oooool2o`0000?ooooo1?l000000ooooooo0000o`000004
ooooo`;o00000oooool2o`0000;ooooo1Ol00005ooooo`;o00004oooool4o`0001?ooooo0_l00000
0ooooooo0000o`00000Uooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0<oooool2o`00
00oooooo0_l00009ooooo`;o00002?ooool2o`0000Wooooo0ol00009ooooo`?o00007oooool3o`00
00?ooooo0_l00004ooooo`;o00000oooool2o`0000;ooooo1?l00006ooooo`;o00001?ooool2o`00
00Gooooo0_l00006ooooo`Co00001oooool2o`0000gooooo0_l0000Uooooo`;o00004Oooool2o`00
02gooooo000Looooo`03o`000?oooooooooo04?ooooo0ol0000Cooooo`;o00002_ooool4o`0000Oo
oooo0_l00008ooooo`;o00002oooool2o`0000Wooooo0_l000001?oooooo0000o`000?ooool2o`00
00?ooooo0_l00008ooooo`Co00002?ooool3o`000003ooooool0003o000000Gooooo0_l0000Aoooo
o`;o00003_ooool2o`0000Gooooo0_l0000Looooo`;o00003Oooool2o`0000?ooooo0_l0000]oooo
o`007?ooool00ol0003oooooooooo`13ooooo`?o00001?ooool2o`0000gooooo0_l00003ooooo`;o
00001oooool2o`0000Cooooo0_l0000;ooooo`;o00002Oooool6o`0000[ooooo0_l000000ooooooo
0000o`000002o`000003ooooool0003o000000Sooooo0_l0000:ooooo`?o00004Oooool2o`0001Go
oooo0_l000000ooooooo0000o`000005ooooo`;o00004_ooool2o`0000Sooooo0_l0000=ooooo`;o
0000<_ooool001cooooo00?o0000ooooooooool06?ooool2o`0001Gooooo0_l000000ooooooo0000
o`00000@ooooo`;o00001?ooool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l00000
0ol00003ooooo`;o00003?ooool3o`0000_ooooo0_l00009ooooo`;o00000_ooool7o`0000Gooooo
0_l00003ooooo`;o00003_ooool2o`0000kooooo0_l00002ooooo`;o00001oooool4o`0001?ooooo
0_l0000Looooo`;o00002Oooool2o`00043ooooo000Looooo`03o`000?oooooooooo01Sooooo0_l0
000Eooooo`;o000000?oooooo`000?l000004Oooool2o`0000Oooooo0ol00002ooooo`;o000000?o
ooooo`000?l000000ol000000ooooooo0000o`000005ooooo`;o00001oooool2o`0000oooooo0_l0
000:ooooo`Oo000000?oooooo`000?l000001?l0000=ooooo`?o00000oooool2o`0000kooooo0_l0
0002ooooo`;o00001?ooool8o`0000Sooooo0_l000000ooooooo0000o`000008ooooo`;o00006_oo
ool2o`0000Sooooo0ol0000;ooooo`;o0000<_ooool001cooooo00?o0000ooooooooool0<Oooool2
o`00013ooooo1?l00008ooooo`;o00001oooool2o`0000;ooooo0_l00004ooooo`?o00006?ooool2
o`0000[ooooo3_l00002ooooo`;o00001oooool5o`0000Gooooo0_l0000<ooooo`;o00000_ooool2
o`0000Cooooo1Ol000000ooooooo0000o`000008ooooo`;o000000Coooooo`000?l0003o00001ooo
ool2o`0001[ooooo0_l00009ooooo`;o00002oooool2o`0003;ooooo000Looooo`03o`000?oooooo
oooo037ooooo0_l0000@ooooo`Co00006oooool2o`0000Wooooo1?l00007ooooo`Ko00001?ooool2
o`0000Gooooo0_l000000ooooooo0000o`000004o`0000?ooooo0_l00002ooooo`;o00001?ooool2
o`000003ooooool0003o000000Sooooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool2
o`0000Cooooo0_l000000ooooooo0000o`000006o`000003ooooool0003o000000Kooooo0_l00004
ooooo`;o00003oooool2o`0005kooooo000Looooo`;o0000A_ooool2o`0000_ooooo0_l00006oooo
o`;o00001?ooool2o`0000_ooooo1?l00004ooooo`;o000000?oooooo`000?l000001?l00004oooo
o`;o000000?oooooo`000?l000000ol000000ooooooo0000o`00000>ooooo`;o00000_ooool2o`00
00kooooo0_l00002ooooo`Co000000?oooooo`000?l000001oooool8o`000003ooooool0003o0000
00Kooooo0_l000000ooooooo0000o`000003o`0000gooooo1?l0000Looooo`;o0000@?ooool001co
oooo00?o0000ooooooooool0<Oooool2o`0001oooooo1?l00004ooooo`;o00001?ooool2o`0000Oo
oooo0_l000000ooooooo0000o`000002o`0000Gooooo0ol000000ooooooo0000o`000006ooooo`;o
00000_ooool8o`0000Cooooo0_l00008ooooo`Co00000_ooool2o`0000Wooooo1?l00005ooooo`Co
00000oooool3o`0000Gooooo2?l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000Co
00003?ooool2o`0001[ooooo0_l00002ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0
<Oooool6o`0000cooooo0ol0000:ooooo`;o000000Coooooo`000?l0003o00001?ooool3o`0000?o
oooo1Ol00003ooooo`So000000?oooooo`000?l000000oooool2o`0000Wooooo0ol00002ooooo`Go
00000_ooool6o`000003ooooool0003o000000Gooooo1?l00002ooooo`;o00002Oooool4o`0000Oo
oooo1?l000001?oooooo0000o`000?l00003ooooo`;o00000_ooool4o`000004ooooool0003o0000
ooooo`;o00002Oooool4o`000003ooooool0003o000001Sooooo0_l00007ooooo`Co00000_ooool2
o`00043ooooo000Looooo`03o`000?oooooooooo02oooooo0_l000000ooooooo0000o`000003o`00
00cooooo0ol0000:ooooo`;o00002?ooool3o`000003ooooool0003o000001?o00000_ooool2o`00
00;ooooo0_l00007ooooo`;o000000?oooooo`000?l000001?l00002ooooo`Go00000_ooool2o`00
00Gooooo0_l00009ooooo`;o00001_ooool2o`0000Wooooo0_l00007ooooo`Co00000oooool4o`00
0003ooooool0003o000000;o00002Oooool2o`000003ooooool0003o000001Sooooo0_l00007oooo
o`;o00001?ooool2o`00043ooooo000Looooo`03o`000?oooooooooo02oooooo0_l000000ooooooo
0000o`000002o`0000oooooo0_l00004ooooo`;o00001_ooool2o`0000Wooooo0ol000000ooooooo
0000o`00000>o`000003ooooool0003o000000;o00000_ooool5o`0000;ooooo0_l00002ooooo`?o
00001_ooool2o`0000Wooooo0_l0000<ooooo`;o00001_ooool4o`0000Oooooo1?l00002ooooo`?o
000000?oooooo`000?l000000_l00002ooooo`?o00001?ooool2o`0000Kooooo0_l00004ooooo`;o
000000?oooooo`000?l00000I_ooool001cooooo00?o0000ooooooooool0<_ooool4o`0000oooooo
0_l00004ooooo`;o00001_ooool2o`0000Cooooo0_l00003ooooo`Go000000?oooooo`000?l00000
4_l000000ooooooo0000o`000003o`0000;ooooo0_l00002ooooo`;o00001?ooool2o`000003oooo
ool0003o000000Wooooo0_l0000:ooooo`;o00002_ooool2o`0000?ooooo3Ol000000ooooooo0000
o`000002o`000003ooooool0003o000000;o00001?ooool2o`0000Kooooo0_l00002ooooo`Co0000
00?oooooo`000?l000008_ooool2o`0004;ooooo000Looooo`03o`000?oooooooooo037ooooo0ol0
000Kooooo`Co00000ooooolNo`000005ooooool0003o0000o`000?ooool02?l00003ooooo`;o0000
00Coooooo`000?l0003ooooo0_l0000Hooooo`;o00002?ooool2o`0000Gooooo3ol000000ooooooo
0000o`000004o`0000;ooooo1?l00005ooooo`;o00001?ooool4o`0001_ooooo0_l00008ooooo`Co
0000@?ooool001cooooo00?o0000ooooooooool0<Oooool2o`0000;ooooo0_l000001?oooooo0000
o`000?l0000;ooooo`;o00001?ooool2o`000003ooooool0003o000000;o00000oooool>o`0000;o
oooo4Ol000000ooooooo0000o`000007o`0000Gooooo0ol0000=ooooo`;o00001?ooool2o`0000Go
oooo0_l00008ooooo`?o00001oooool?o`000003ooooool0003o000000So00001Oooool3o`0000Go
oooo0_l00005ooooo`?o000000?oooooo`000?l000004?ooool2o`0000[ooooo0_l00010ooooo`00
7?ooool00ol0003oooooooooo`0Yooooo`;o00002_ooool6o`0000_ooooo0_l00004ooooo`;o0000
00?oooooo`000?l000000_l00004ooooo`Go000000Coooooo`000?l0003ooooo4_l000000ooooooo
0000o`000005o`0000Gooooo1?l00003ooooo`?o00003Oooool2o`0000Cooooo0_l00005ooooo`;o
00001Oooool5o`0000?ooooo1Ol000000ooooooo0000o`00000>o`000003ooooool0003o000000Oo
00001Oooool2o`0000cooooo0ol000000ooooooo0000o`00000?ooooo`?o00002?ooool2o`0004;o
oooo000Looooo`03o`000?oooooooooo02Wooooo0_l0000;ooooo`;o00002_ooool3o`0000cooooo
0_l00004ooooo`Ko000000?oooooo`000?l000006_l00007ooooo`;o000000?oooooo`000?l00000
0ol0000:ooooo`;o00001Oooool2o`0000kooooo0ol00005ooooo`Go00000_ooool4o`000003oooo
ool0003o000001;o000000Coooooo`000?l0003o00000_ooool3o`0001oooooo0_l00004ooooo`?o
00000_ooool2o`0004;ooooo000Looooo`03o`000?oooooooooo03;ooooo0_l0000>ooooo`?o0000
1_ooool2o`0000[ooooo4?l000000ooooooo0000o`00000<o`000003ooooool0003o000000?o0000
1?ooool2o`0000;ooooo2?l00007ooooo`Co00000oooool2o`0000oooooo0_l00003ooooo`;o0000
00?oooooo`000?l000000_l00003oooooaSo000000?oooooo`000?l000001_l0000Kooooo`;o0000
0oooool3o`0000;ooooo0ol00016ooooo`007?ooool00ol0003oooooooooo`0booooo`;o00005ooo
ool2o`0000Wooooo8_l00002ooooo`;o00001?ooool2o`0000?ooooo0_l000000ooooooo0000o`00
0002o`0000Wooooo0_l0000Gooooo`Co000000?oooooo`000?l000001Oooool8o`000003ooooool0
003o0000013o000000Coooooo`000?l0003ooooo0_l0000Jooooo`?o00000oooool3o`0000;ooooo
0_l00005ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0<Oooool2o`0000;ooooo0_l0
000Oooooo`?o00000_oooolMo`0000Sooooo0_l00002ooooo`?o00001oooool2o`0000cooooo0_l0
000<ooooo`;o00000_ooool7o`000003ooooool0003o000000;ooooo7ol00009ooooo`;o00002_oo
ool2o`0000Gooooo0_l00003ooooo`;o000000?oooooo`000?l000002?ooool2o`0000gooooo0_l0
000aooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o00001?ooool2o`0000;ooooo0_l00009
ooooo`;o00003oooool2o`0000Kooooo3_l000000ooooooo0000o`00000=o`0000Wooooo1_l00008
ooooo`;o00001oooool2o`0000?ooooo0_l00003ooooo`;o00001oooool4o`000003ooooool0003o
000000;o00000ooooolNo`000003ooooool0003o000000;o00002Oooool2o`0000[ooooo0_l0000:
ooooo`;o000000Coooooo`000?l0003o00005_ooool2o`00037ooooo000Looooo`03o`000?oooooo
oooo02_ooooo0_l00005ooooo`;o00001?ooool2o`0000?ooooo0_l000000ooooooo0000o`000005
ooooo`;o00002?ooool2o`0000Cooooo1ol000000ooooooo0000o`000005o`000003ooooool0003o
000000ko00001oooool2o`000003ooooool0003o000000?o00000_ooool2o`0000Cooooo0_l00007
ooooo`;o00001Oooool5o`0000Sooooo0ol00004ooooo`;o00000ooooolMo`000004ooooool0003o
0000o`0000;ooooo0_l0000Cooooo`;o00002Oooool2o`0000;ooooo0_l000001?oooooo0000o`00
0?l00003ooooo`;o00002_ooool2o`0003Cooooo000Looooo`03o`000?oooooooooo02_ooooo0_l0
0005ooooo`;o00000_ooool4o`0000?ooooo0_l00007ooooo`?o00000oooool2o`0000Oooooo8ol0
0006ooooo`;o00001?ooool2o`0000;ooooo0_l00004ooooo`;o00000_ooool2o`0000Oooooo0_l0
00001?oooooo0000o`000?l00002ooooo`;o00001_ooool4o`0000?ooooo0_l000000ooooooo0000
o`00000Mo`000003ooooool0003o000000;o000000?oooooo`000?l000000_l0000:ooooo`Co0000
0oooool4o`0000Sooooo0_l000001?oooooo0000o`000?ooool3o`0000?ooooo0_l0000:ooooo`;o
0000=?ooool001cooooo0_l0000fooooo`?o00002?ooool2o`0000Cooooo0_l00004ooooo`;o0000
1ooooolUo`0000Sooooo1?l00005ooooo`;o00001Oooool2o`0000Gooooo1?l00006ooooo`;o0000
2?ooool2o`000004ooooool0003o0000o`0000;ooooo4Ol000000ooooooo0000o`00000=o`000004
ooooool0003o0000ooooo`Co00000_ooool2o`0000Kooooo1Ol00004ooooo`;o00001?ooool6o`00
0004ooooool0003o0000ooooo`?o0000AOooool001cooooo00?o0000ooooooooool0<?ooool2o`00
00?ooooo0_l000000ooooooo0000o`000006ooooo`;o00002_ooool2o`0000Oooooo2?l000000ooo
oooo0000o`00000Jo`0000Sooooo1?l00005ooooo`?o00002Oooool6o`0000[ooooo0ol00002oooo
o`;o00000_ooool3o`000003ooooool0003o000001Ko000000?oooooo`000?l000001ol00002oooo
o`?o000000?oooooo`000?l000000_ooool2o`0000Kooooo1Ol0000:ooooo`Co00001Oooool4o`00
0003ooooool0003o000000Kooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o
00000_ooool3o`000003ooooool0003o000000kooooo0_l00004ooooo`;o00000ooooolTo`000003
ooooool0003o000001;ooooo1?l00007ooooo`;o00000_ooool2o`0000Sooooo2Ol00002ooooo`;o
00000_oooolWo`000003ooooool0003o000000;ooooo0_l00006ooooo`?o00003Oooool2o`0000Ko
oooo0_l00003ooooo`;o00001Oooool3o`0000;ooooo0_l0000fooooo`007?ooool00ol0003ooooo
ooooo`0_ooooo`?o00000_ooool3o`00013ooooo0ol00004ooooo`;o00000ooooolQo`000003oooo
ool0003o000001Oooooo0_l0000@ooooo`;o00000oooool9o`0000?ooooo0_l000000ooooooo0000
o`00000Ro`0000;ooooo1Ol000000ooooooo0000o`000003ooooo`;o00000_ooool2o`0000Kooooo
0_l00005ooooo`;o00004_ooool2o`0000?ooooo0_l0000fooooo`007?ooool00ol0003ooooooooo
o`0_ooooo`;o00005_ooool2o`0000Gooooo0_l00006oooooaOo000000?oooooo`000?l000001Ol0
0003ooooo`;o00001_ooool4o`0001_ooooo0ol00005ooooo`Co000000?oooooo`000?l000000ooo
oolOo`000003ooooool0003o000000Co00000oooool5o`0000Kooooo1?l000000ooooooo0000o`00
0005ooooo`Go00000_ooool2o`0000[ooooo0_l00006ooooo`;o00000_ooool2o`0003Oooooo000L
ooooo`03o`000?oooooooooo02_ooooo0_l00005ooooo`;o00006_ooool2o`0000Kooooo8?l00002
ooooo`;o00001_ooool4o`0000Gooooo0_l00008ooooo`;o00002Oooool4o`0000Oooooo1?l00005
ooooob_o00000_ooool2o`0000Kooooo0_l000000ooooooo0000o`000005ooooo`Go00003_ooool2
o`0000Kooooo0_l00002ooooo`;o0000=oooool001cooooo00?o0000ooooooooool0:oooool2o`00
0003ooooool0003o000000;ooooo0_l00009ooooo`;o00002?ooool2o`0000gooooo7?l00002oooo
o`;o00000oooool2o`0000Gooooo1?l00005ooooo`;o00002?ooool2o`0000Wooooo1?l00002oooo
o`;o00001Oooool3o`0000?ooooo<_l00007ooooo`;o00000_ooool2o`000004ooooool0003o0000
ooooo`;o00003Oooool2o`0004Cooooo000Looooo`03o`000?oooooooooo02kooooo0_l00007oooo
o`;o000000Coooooo`000?l0003ooooo0_l00008ooooo`;o00000oooool2o`0000Sooooo5?l00000
0ooooooo0000o`000002o`000003ooooool0003o000000Oooooo0_l00005ooooo`Co00003?ooool2
o`0000;ooooo0_l0000<ooooo`Co00001_ooool2o`0000?ooooo:?l00002ooooo`Go000000?ooooo
o`000?l000001oooool2o`0000;ooooo0_l000000ooooooo0000o`00000@ooooo`;o00001?ooool2
o`0003kooooo000Looooo`03o`000?oooooooooo03Oooooo1ol00003ooooo`;o00001?ooool2o`00
00?ooooo0_l00007ooooo`Ko00000_ooool=o`000003ooooool0003o000000?o00001Oooool4o`00
00_ooooo0_l0000:ooooo`;o00000_ooool2o`0000Wooooo0_l000001?oooooo0000o`000?ooool2
o`000003ooooool0003o000000Oooooo9ol00003ooooo`So00001oooool2o`0001gooooo0_l0000n
ooooo`007?ooool00ol0003oooooooooo`0hooooo`?o000000?oooooo`000?l000000oooool2o`00
00Wooooo0_l00007ooooo`;o00002?ooool4o`0000?ooooo0_l00004ooooo`Co00001Oooool4o`00
00Wooooo1Ol0000Cooooo`;o00000oooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool2
o`0000;ooooo:Ol00004ooooo`Go00001Oooool2o`0000kooooo0_l0001Aooooo`007?ooool00ol0
003oooooooooo`0hooooo`;o000000Coooooo`000?l0003o00000oooool4o`0000Oooooo1?l0000;
ooooo`;o00001?ooool2o`0001Kooooo0_l00007ooooo`;o000000Coooooo`000?l0003ooooo0_l0
00000ooooooo0000o`00000=ooooo`;o00000oooool2o`0000;ooooo0_l00006ooooo`?o000000Go
ooooo`000?l0003o0000ooooo`0So`0000Oooooo1?l00005ooooo`?o000000?oooooo`000?l00000
0_ooool2o`0000Kooooo0_l0000Fooooo`;o0000>Oooool001cooooo00?o0000ooooooooool0>?oo
ool2o`000003ooooool0003o000000?ooooo1Ol00008ooooo`Go00002Oooool4o`0000_ooooo0_l0
0004ooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000Gooooo
0ol000000ooooooo0000o`000004ooooo`;o00003?ooool2o`0000;ooooo0_l00007ooooo`?o0000
00?oooooo`000?l000000_l000000ooooooo0000o`00000So`0000;ooooo0_l00004ooooo`;o0000
0oooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000003ooooo`;o0000
5_ooool2o`0003Wooooo000Looooo`03o`000?oooooooooo03[ooooo0_l00004ooooo`;o00002ooo
ool2o`000003ooooool0003o000000Gooooo0_l00004ooooo`;o00002oooool2o`0000Cooooo0_l0
0004ooooo`;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00000_oo
ool3o`0000?ooooo0ol0000Booooo`;o00001?ooool3o`000003ooooool0003o000000?o000000?o
ooooo`000?l000003Ol000000ooooooo0000o`00000Bo`0000;ooooo0_l00004ooooo`;o00002?oo
ool2o`0000?ooooo0_l000000ooooooo0000o`000007ooooo`;o00000_ooool2o`0004Kooooo000L
ooooo`03o`000?oooooooooo03Cooooo0_l00004ooooo`Go000000Coooooo`000?l0003ooooo0ol0
0007ooooo`;o00002?ooool2o`0000oooooo0_l0000Iooooo`;o00001?ooool5o`0000Cooooo0_l0
000<ooooo`;o00001?ooool2o`0000Cooooo0_l00002ooooo`Go000000?oooooo`000?l000004ol0
00000ooooooo0000o`000005o`000003ooooool0003o000000Go000000?oooooo`000?l000001?oo
ool2o`0000Sooooo0_l000000ooooooo0000o`000003ooooo`;o00001oooool2o`0000;ooooo0_l0
0005ooooo`;o0000?oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo
00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo03Cooooo0_l00005ooooo`Co
000000?oooooo`000?l000001?l0000Kooooo`;o00001Oooool2o`0000;ooooo0_l0000>ooooo`;o
00002Oooool5o`0001Cooooo0_l00003ooooo`;o00002Oooool4o`0000;ooooo9Ol000000ooooooo
0000o`000004o`0000gooooo0_l0000Gooooo`;o0000?oooool00006oooooomgMgOoV9RHoooooonH
V9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooo
oooo043ooooo1?l00005ooooo`Go00002?ooool2o`0000Wooooo0_l00009ooooo`;o00003_ooool3
o`0000Sooooo0_l000000ooooooo0000o`000002ooooo`;o00005Oooool2o`0000Gooooo0_l00000
0ooooooo0000o`00000Vo`0000?ooooo0ol000000ooooooo0000o`000002o`00013ooooo0_l0001E
ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`0eooooo`;o00002Oooool2o`0000Oooooo1Ol00003
ooooo`;o00000oooool2o`0002Gooooo0_l00002ooooo`Co00002Oooool2o`0001Wooooo0_l00000
0ooooooo0000o`00000Jo`000003ooooool0003o000000Ko000000?oooooo`000?l000002Ol0000E
ooooo`;o0000EOooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0
003oV9RHoooooonHV9So8B4Q00Kooooo0ol0000eooooo`;o00003_ooool2o`0000Sooooo1?l0000X
ooooo`;o000000?oooooo`000?l000001Ol00007ooooo`;o00005Oooool2o`0000Cooooo0_l00002
ooooo`So000000?oooooo`000?l000007?l000000ooooooo0000o`000005o`0000Wooooo1?l00000
0ooooooo0000o`000006ooooo`;o00001?ooool2o`0000Gooooo0_l00018ooooo`0000?oooooo`00
0?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool0
0ol0003oooooooooo`0kooooo`;o00002?ooool2o`0000Sooooo0_l0000Wooooo`Go000000?ooooo
o`000?l000000ol00004ooooo`;o00000oooool2o`0001Gooooo0_l00007ooooo`;o000000?ooooo
o`000?l000009_l00002ooooo`?o00002Oooool4o`000003ooooool0003o000000?ooooo0_l00000
1?oooooo0000o`000?l00003ooooo`;o00001Oooool2o`0004Sooooo00000ooooooo410@ooooo`02
ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`0k
ooooo`;o00000_ooool2o`0000Cooooo0_l0000]ooooo`;o00000_ooool5o`0000Cooooo0_l00003
ooooo`Co00001Oooool2o`0001_ooooo0_l00004ooooobWo00000_ooool2o`00013ooooo0_l00000
1?oooooo0000o`000?l0000:ooooo`;o00002Oooool2o`0003gooooo00001_ooooooMgMgoiRHV?oo
ooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0jooooo`Oo0000
1?ooool2o`0002gooooo0ol00009ooooo`;o000000?oooooo`000?l000001Ol00005ooooo`;o0000
7Oooool4o`0000?ooooo9Ol000000ooooooo0000o`000002o`0000gooooo0_l0000Aooooo`;o0000
2Oooool2o`0003gooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0
003o410@1_ooool00ol0003oooooooooo`0jooooo`Ko00001?ooool2o`000003ooooool0003o0000
02cooooo1?l00005ooooo`Co000000?oooooo`000?l000000_l0000Wooooo`Co00000oooool3o`00
00;ooooo9Ol00002ooooo`;o00002Oooool2o`0005_ooooo000Looooo`03o`000?oooooooooo03Go
oooo0_l00006ooooo`;o00001Oooool2o`000003ooooool0003o000000Wooooo0_l0000Kooooo`?o
00001Oooool2o`0000Gooooo0_l0000^ooooo`;o00001Oooool3o`0000Kooooo7_l00005ooooo`;o
00001_ooool2o`000003ooooool0003o000000[ooooo0_l00003ooooo`;o0000B_ooool001cooooo
00?o0000ooooooooool0=Oooool2o`0000?ooooo0_l000001?oooooo0000o`000?l0000Booooo`;o
00006oooool3o`0000_ooooo0_l0000dooooo`;o000000?oooooo`000?l000000_l000000ooooooo
0000o`00000Eo`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`00000:ooooo`;o
000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00001Oooool2o`0000?ooooo0_l0001:oooo
o`007?ooool00ol0003oooooooooo`0jooooo`;o00000_ooool2o`0001Cooooo0_l0000Iooooo`?o
00002oooool2o`0001Gooooo0_l0000;ooooo`;o00002Oooool2o`000003ooooool0003o000000Co
00000_ooool3o`000003ooooool0003o000000Co000000Coooooo`000?l0003ooooo1_l000000ooo
oooo0000o`000002ooooo`;o00000_ooool3o`0000?ooooo0_l0000:ooooo`;o00002Oooool2o`00
05Kooooo000Looooo`03o`000?oooooooooo03Gooooo0_l00002ooooo`;o00003oooool2o`0000Go
oooo0_l000000ooooooo0000o`00000Booooo`;o00001Oooool3o`0000kooooo0_l0000Booooo`;o
00002oooool2o`0000Wooooo0_l000000ooooooo0000o`000005o`000003ooooool0003o000000Go
oooo3?l000000ooooooo0000o`000003ooooo`?o000000Coooooo`000?l0003o00003_ooool2o`00
00gooooo0ol0000:ooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0=Oooool2o`0000;o
oooo0_l0000?ooooo`;o00001Oooool2o`000004ooooool0003o0000o`0000;ooooo0_l0000=oooo
o`;o00001_ooool2o`0000?ooooo0_l00009ooooo`Co0000;_ooool4o`0000Kooooo2Ol000000ooo
oooo0000o`000002o`000004ooooool0003o0000ooooo`Go000000Coooooo`000?l0003o00003_oo
ool2o`0000gooooo0ol00006ooooo`;o000000Coooooo`000?l0003o00003_ooool2o`0003Kooooo
000Looooo`03o`000?oooooooooo04?ooooo0_l0000?ooooo`?o00000_ooool2o`0001[ooooo0_l0
000;ooooo`;o00000_ooool2o`0000_ooooo0_l00006ooooo`?o00003oooool3o`0000Cooooo0_l0
0006ooooo`;o00000_ooool2o`0000;ooooo1_l00004ooooo`Wo00009_ooool2o`000003ooooool0
003o000000oooooo0_l0000fooooo`007?ooool00ol0003oooooooooo`12ooooo`Co00003Oooool2
o`0001Cooooo0_l00009ooooo`;o00001?ooool3o`0000Cooooo0_l00002ooooo`?o00002oooool2
o`0000Kooooo0ol00005ooooo`;o00002?ooool3o`0000Cooooo0_l00005ooooo`;o00001_ooool9
o`0000Cooooo1?l00009ooooo`;o00000_ooool2o`0001gooooo0_l00017ooooo`007?ooool00ol0
003oooooooooo`0mooooo`;o00000oooool4o`0000Oooooo0_l000001?oooooo0000o`000?ooool2
o`0001Cooooo0_l00009ooooo`;o00001?ooool3o`0000Cooooo0_l00002ooooo`;o00002Oooool2
o`000003ooooool0003o000000Gooooo1?l00005ooooo`;o00000_ooool2o`0000_ooooo0ol00004
ooooo`Co00001?ooool;o`0000Cooooo0_l00009ooooo`;o00000_ooool2o`0001_ooooo1?l00017
ooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00003_ooool2o`000003ooooool0003o0000
00Gooooo0_l0000=ooooo`;o00002Oooool2o`0000Oooooo0_l0000Booooo`Co00001oooool5o`00
00Wooooo0_l0000;ooooo`?o00001_ooool4o`000004ooooool0003o0000o`0000Gooooo1?l00004
ooooo`;o00006oooool2o`0000Gooooo0ol00005ooooo`Co0000Aoooool001cooooo00?o0000oooo
ooooool0@oooool2o`000003ooooool0003o000000?ooooo0_l00003ooooo`;o00001Oooool4o`00
00_ooooo0_l00004ooooo`;o00000oooool2o`0001Sooooo0_l000001?oooooo0000o`000?ooool7
o`000003ooooool0003o000000;o00000oooool2o`0000;ooooo0_l0000@ooooo`;o00001oooool5
o`000004ooooool0003o0000o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l000006?oo
ool3o`0000Gooooo0ol00007ooooo`Co0000AOooool001cooooo00?o0000ooooooooool0>_ooool2
o`0000Oooooo0_l000000ooooooo0000o`000003ooooo`;o00002Oooool2o`000004ooooool0003o
0000o`00013ooooo0_l0000Kooooo`Co000000Coooooo`000?l0003ooooo2?l000000ooooooo0000
o`000002o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0000Gooooo0_l00004ooooo`;o0000
1_ooool5o`0000;ooooo0ol00009ooooo`;o000000?oooooo`000?l000001oooool2o`0000oooooo
0_l0000Booooo`;o0000AOooool001cooooo0_l0000hooooo`;o000000?oooooo`000?l000002_oo
ool2o`0000_ooooo0_l000000ooooooo0000o`000002ooooo`Ko00001oooool2o`00023ooooo0_l0
00000ooooooo0000o`00000Ao`0000[ooooo0_l000000ooooooo0000o`000002ooooo`;o00002ooo
ool6o`0000?ooooo1?l00004ooooo`;o00003Oooool2o`0001kooooo0_l0001:ooooo`007?ooool0
0ol0003oooooooooo`0gooooo`;o00003Oooool2o`0000_ooooo0_l000000ooooooo0000o`000004
ooooo`Co00001oooool2o`0000Gooooo0_l0000?ooooo`;o000000?oooooo`000?l000002?oooolC
o`0000[ooooo0_l000000ooooooo0000o`000002o`0000;ooooo1?l00005ooooo`Co00001_ooool5
o`000004ooooool0003o0000ooooo`;o00007oooool2o`0000cooooo0_l0001:ooooo`007?ooool0
0ol0003oooooooooo`12ooooo`Oo00000oooool2o`000005ooooool0003o0000o`000?ooool00_l0
00000ooooooo0000o`00000Fooooo`;o00003_ooool3o`000004ooooool0003o0000ooooo`;o0000
0oooool;o`000003ooooool0003o000000Oo000000?oooooo`000?l000003?ooool2o`0000;ooooo
1?l00005ooooo`;o00002?ooool2o`0000?ooooo0ol0000=ooooo`?o00002oooool2o`0000Gooooo
1Ol0000Oooooo`;o0000=?ooool001cooooo00?o0000ooooooooool0?_ooool2o`0000;ooooo1?l0
00000ooooooo0000o`000003ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`0000Wooooo
0_l00002ooooo`;o00005Oooool4o`000003ooooool0003o000000;ooooo0_l00003oooooaGo0000
00?oooooo`000?l000002oooool2o`0000Cooooo0ol00007ooooo`;o00001?ooool2o`0000Gooooo
0_l00009ooooo`?o00000_ooool3o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo
0_l00002ooooo`?o00007oooool2o`0003Cooooo000Looooo`03o`000?oooooooooo03kooooo0_l0
0009ooooo`;o00004?ooool3o`0000;ooooo0ol000001?oooooo0000o`000?l0000Aooooo`;o0000
00?oooooo`000?l000000ol000000ooooooo0000o`000004oooooaSo000000?oooooo`000?l00000
2oooool2o`0000Cooooo0ol00007ooooo`;o00001?ooool2o`0000cooooo0_l00002ooooo`Ko0000
1?ooool2o`000003ooooool0003o000000;o00000_ooool2o`0000?ooooo0ol00002ooooo`;o0000
EOooool001cooooo00?o0000ooooooooool0>Oooool2o`000003ooooool0003o000000Gooooo0_l0
0004ooooo`;o00002Oooool2o`0000Gooooo0ol000001?oooooo0000o`000?l00002ooooo`;o0000
4_ooool6o`0000Wooooo6?l00009ooooo`;o00002Oooool2o`0000gooooo0_l00009ooooo`;o0000
0_ooool2o`0000Gooooo0ol00007ooooo`;o00002_ooool2o`0000;ooooo0_l0000Kooooo`;o0000
>?ooool001cooooo00?o0000ooooooooool0>Oooool2o`000003ooooool0003o000000Gooooo0_l0
0002ooooo`;o00000oooool2o`0000Kooooo0_l00009ooooo`;o00006Oooool3o`0000cooooo5ol0
0002ooooo`;o00000oooool3o`0001Gooooo0_l000000ooooooo0000o`000005ooooo`;o000000Co
ooooo`000?l0003o00002Oooool2o`00017ooooo0ol00003ooooo`?o00006oooool2o`0003Sooooo
000Looooo`03o`000?oooooooooo04Cooooo1_l00002ooooo`;o00002oooool2o`00023ooooo0_l0
000:oooooa[o000000?oooooo`000?l000000oooool2o`0000;ooooo0_l00009ooooo`;o00001ooo
ool2o`0000Sooooo0_l000001?oooooo0000o`000?ooool2o`0000Oooooo0_l0000Aooooo`?o0000
0oooool2o`0000Cooooo0_l000000ooooooo0000o`00001=ooooo`007?ooool00ol0003ooooooooo
o`14ooooo`?o000000?oooooo`000?l000001_ooool2o`0000Oooooo0_l000000ooooooo0000o`00
0006ooooo`;o00000_ooool2o`0000gooooo0_l0000>oooooa[o00001?ooool8o`0000Wooooo0_l0
000>ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Cooooo0_l0000<ooooo`?o00000_oo
ool2o`000003ooooool0003o000000?o00001oooool2o`000003ooooool0003o000000;o0000Booo
ool001cooooo00?o0000ooooooooool0B?ooool4o`0000Cooooo0_l0000:ooooo`;o00001_ooool2
o`0000;ooooo0_l0000=ooooo`;o00002oooool2o`000003ooooool0003o000001Oo00000_ooool2
o`000003ooooool0003o000000Ko00001_ooool2o`00017ooooo0_l000000ooooooo0000o`000009
ooooo`Co00002_ooool4o`0000;ooooo0ol00002ooooo`?o00001oooool2o`0000?ooooo0_l0001;
ooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00000oooool2o`0000Cooooo1_l00002oooo
o`;o00001?ooool2o`0002?ooooo0_l00007oooooago000000?oooooo`000?l000000oooool3o`00
0005ooooool0003o0000o`000?ooool00_l00002ooooo`;o00001?ooool3o`0000Sooooo0_l0000>
ooooo`Co000000?oooooo`000?l000001Oooool4o`0000Gooooo0_l0000<ooooo`;o0000D?ooool0
01cooooo00?o0000ooooooooool0?Oooool2o`000003ooooool0003o000000;o00001?ooool2o`00
00;ooooo0_l000001?oooooo0000o`000?l00004ooooo`;o00008oooool2o`0000Wooooo6ol0000;
ooooo`;o000000?oooooo`000?l000002?ooool3o`0000Sooooo0_l0000Booooo`?o00000oooool5
o`0000Oooooo0_l00007ooooo`;o0000E?ooool001cooooo00?o0000ooooooooool0@?ooool2o`00
00gooooo0_l00009ooooo`;o0000:Oooool2o`000003ooooool0003o000000So000000?oooooo`00
0?l000001ol000000ooooooo0000o`000009ooooo`;o00001?ooool2o`0000Wooooo0_l00003oooo
o`;o000000Coooooo`000?l0003ooooo0_l0000<ooooo`;o000000?oooooo`000?l000001?l00000
0ooooooo0000o`000004o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000Oooooo0_l0
001Dooooo`007?ooool00ol0003oooooooooo`11ooooo`Co00005Oooool2o`0002Wooooo0_l00000
0ooooooo0000o`00000@o`0000Wooooo0_l00003ooooo`;o00000oooool3o`0000Wooooo0ol00002
ooooo`;o000000Coooooo`000?l0003ooooo0_l0000<ooooo`;o000000?oooooo`000?l000001?l0
00000ooooooo0000o`000007o`000004ooooool0003o0000o`0000Cooooo0_l0001Jooooo`007?oo
ool00ol0003oooooooooo`11ooooo`Co00003?ooool2o`0000cooooo0_l00004ooooo`;o00007_oo
ool2o`0000;ooooo4Ol00007ooooo`Co00002?ooool2o`0000_ooooo0_l000001?oooooo0000o`00
0?l00005ooooo`;o00000_ooool2o`0000Cooooo0_l0000=ooooo`Ko00000oooool2o`0000Cooooo
0_l0001Jooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00003?ooool2o`000004ooooool0
003o0000o`0000Sooooo0_l00004ooooo`Co00007?ooool2o`0000;ooooo4Ol00007ooooo`;o0000
6_ooool2o`0000Kooooo0_l00002ooooo`?o00000oooool2o`0000gooooo1?l00003ooooo`Co0000
0oooool2o`0005_ooooo000Looooo`;o0000EOooool3o`00013ooooo0_l0000;ooooo`;o00003?oo
ool2o`0000Gooooo3ol0000Kooooo`;o00002_ooool2o`000003ooooool0003o000000Kooooo0_l0
0003ooooo`;o00002oooool7o`0000;ooooo1?l00003ooooo`;o0000Foooool001cooooo00?o0000
ooooooooool0A_ooool2o`0000Wooooo0_l000000ooooooo0000o`00000Nooooo`;o00003?ooool2
o`0000Gooooo0_l000001Ooooooo0000o`000?l0003ooooo00So00001oooool2o`0001;ooooo0_l0
000:ooooo`;o000000?oooooo`000?l000002oooool2o`0000Oooooo0_l00002ooooo`;o00000_oo
ool3o`00027ooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`16ooooo`;o00000_ooool2
o`0000Gooooo0_l000000ooooooo0000o`000003ooooo`;o00006_ooool2o`0001;ooooo0_l00002
ooooo`;o000000?oooooo`000?l000000oooool2o`0000Sooooo0_l00003ooooo`;o00005_ooool2
o`0000gooooo0_l00002ooooo`;o00001oooool2o`000003ooooool0003o000002Oooooo0_l00013
ooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o00000_ooool6o`0000Gooooo0_l00003oooo
o`;o000000?oooooo`000?l000004_ooool2o`0000Wooooo0_l00005ooooo`;o00001?ooool3o`00
00Gooooo0_l0000=ooooo`;o00002oooool2o`0000;ooooo0ol00004ooooo`;o00003Oooool2o`00
00;ooooo0_l0000:ooooo`;o000000?oooooo`000?l000002_ooool2o`0005gooooo000Looooo`03
o`000?oooooooooo04kooooo1_l0000:ooooo`;o000000?oooooo`000?l000007Oooool2o`0000Go
oooo0ol00003ooooo`?o00000_ooool2o`0000kooooo0_l00002ooooo`;o00002Oooool2o`0000;o
oooo1Ol000000ooooooo0000o`000002o`00017ooooo0_l00006ooooo`Go000000?oooooo`000?l0
00001?ooool2o`0000Cooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`16ooooo`;o0000
1Oooool2o`0000[ooooo0_l00003ooooo`;o00001?ooool2o`0000cooooo0_l0000:ooooo`;o0000
2?ooool2o`0000Sooooo0_l0000;ooooo`Go00000_ooool2o`0000Sooooo0_l00003ooooo`Go0000
00?oooooo`000?l000000_l0000Aooooo`;o00000oooool2o`000003ooooool0003o000000;o0000
2?ooool2o`0006?ooooo000Looooo`03o`000?oooooooooo04Kooooo0_l00005ooooo`;o00002Ooo
ool3o`0000?ooooo0_l00004ooooo`;o00001_ooool4o`0000;ooooo0_l00005ooooo`?o00000_oo
ool2o`0000[ooooo0_l00003ooooo`;o00003_ooool3o`000004ooooool0003o0000o`0000Oooooo
0_l000000ooooooo0000o`000003ooooo`Co00000_ooool2o`0000Gooooo0_l00002ooooo`;o0000
0_ooool2o`000004ooooool0003o0000ooooo`;o00000oooool2o`000003ooooool0003o000000;o
00001oooool2o`0001Gooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`1=ooooo`?o0000
1?ooool2o`0000;ooooo0_l00008ooooo`;o00002?ooool4o`0000Sooooo1?l00005ooooo`;o0000
1oooool2o`000003ooooool0003o000000;o00004_ooool3o`0000Oooooo1?l0000:ooooo`;o0000
0oooool4o`000003ooooool0003o000000Go000000?oooooo`000?l000000_l000000ooooooo0000
o`000003o`000003ooooool0003o000000;o00001oooool2o`0000Gooooo0_l0000>ooooo`;o0000
COooool001cooooo00?o0000ooooooooool0COooool3o`0000Cooooo0_l0000<ooooo`;o00002?oo
ool2o`0000[ooooo0_l00002ooooo`;o00000oooool2o`0000[ooooo0_l0000Booooo`Co00002?oo
ool4o`0000cooooo0_l000001?oooooo0000o`000?ooool7o`0000Gooooo0_l000001?oooooo0000
o`000?l0000Eooooo`;o0000GOooool001cooooo00?o0000ooooooooool0H_ooool2o`0000Sooooo
0ol00004ooooo`?o00000_ooool2o`0000;ooooo0_l00006ooooo`;o00006oooool2o`0000Kooooo
1?l00007ooooo`;o00001oooool3o`0000?ooooo0_l000001?oooooo0000o`000?l00007ooooo`;o
000000Coooooo`000?l0003o0000Loooool001cooooo00?o0000ooooooooool0B_ooool2o`0000Oo
oooo0_l0000Hooooo`;o000000Coooooo`000?l0003ooooo0ol00002ooooo`;o00000_ooool2o`00
0003ooooool0003o000000?ooooo0_l00009ooooo`;o00000oooool2o`0001?ooooo1?l00004oooo
o`;o000000?oooooo`000?l000001Oooool2o`000005ooooool0003o0000o`000?ooool00_l0000<
ooooo`;o00000_ooool2o`0007?ooooo000Looooo`03o`000?oooooooooo04[ooooo0_l00007oooo
o`;o00003Oooool2o`0000?ooooo0ol00006ooooo`;o00003Oooool2o`0000Cooooo0_l00008oooo
o`;o00000oooool2o`0000Wooooo0_l0000@ooooo`;o00002?ooool2o`000005ooooool0003o0000
o`000?ooool00_l0000@ooooo`;o00008_ooool2o`0004oooooo000Looooo`03o`000?oooooooooo
04_ooooo0_l00008ooooo`;o00002oooool2o`0000?ooooo0ol00007ooooo`;o00001Oooool2o`00
00_ooooo0_l00009ooooo`;o00002?ooool3o`0000;ooooo0_l00008ooooo`Co00000_ooool2o`00
00Gooooo1?l00004ooooo`;o00004oooool3o`00013ooooo0_l0000@ooooo`;o0000Coooool001co
oooo00?o0000ooooooooool0Boooool2o`0000Gooooo0_l000000ooooooo0000o`00000@ooooo`?o
00001?ooool2o`000003ooooool0003o000000Gooooo0_l00003ooooo`;o00000oooool2o`0000co
oooo0_l00008ooooo`?o00003?ooool4o`0000;ooooo0ol00004ooooo`Co00001Oooool5o`0000;o
oooo0_l0000;ooooo`?o00003?ooool2o`0000;ooooo0_l0000;ooooo`;o0000E?ooool001cooooo
00?o0000ooooooooool0C?ooool2o`0000Cooooo0ol00005ooooo`;o00002oooool3o`0000Cooooo
0_l00002ooooo`;o00002Oooool2o`0000?ooooo0ol0000;ooooo`;o00001oooool2o`00017ooooo
0_l00002ooooo`;o00003Oooool9o`0000gooooo0_l000000ooooooo0000o`000008ooooo`;o0000
3oooool2o`0005Cooooo000Looooo`03o`000?oooooooooo04cooooo0_l00005ooooo`?o000000Co
ooooo`000?l0003ooooo0_l0000Fooooo`;o00001Oooool2o`0000Sooooo1Ol00008ooooo`;o0000
1oooool2o`00017ooooo0_l00009ooooo`;o00000_ooool2o`0000Oooooo0_l000001?oooooo0000
o`000?ooool2o`0000Wooooo0_l000000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l0
0000IOooool001cooooo0_l0001?ooooo`;o00001?ooool2o`000003ooooool0003o000001[ooooo
0_l00004ooooo`;o00002Oooool4o`000003ooooool0003o000000Gooooo0_l0000Tooooo`?o0000
0_ooool4o`0000Sooooo0_l000001?oooooo0000o`000?ooool2o`0000Cooooo0ol00009ooooo`;o
00004Oooool2o`0005Gooooo000Looooo`03o`000?oooooooooo04kooooo0_l0000;ooooo`;o0000
5_ooool2o`0000Gooooo0_l00008ooooo`;o000000?oooooo`000?l000000_l00009ooooo`;o0000
8?ooool2o`0000Gooooo0_l000000ooooooo0000o`00000;ooooo`;o00001?ooool3o`0001cooooo
0_l0001Eooooo`007?ooool00ol0003oooooooooo`1Kooooo`;o00003Oooool2o`0000kooooo0_l0
000;ooooo`Co00002Oooool2o`0000Sooooo0_l00004ooooo`;o00004?ooool2o`0000Gooooo0_l0
00000ooooooo0000o`00000;ooooo`Co00004?ooool2o`000003ooooool0003o000006?ooooo000L
ooooo`03o`000?oooooooooo05_ooooo0_l0000=ooooo`?o00004oooool2o`0000Oooooo0_l00009
ooooo`;o00000_ooool2o`0000Cooooo2Ol0000:ooooo`;o00001oooool2o`000004ooooool0003o
0000ooooo`;o00001_ooool2o`0000Gooooo0_l0000@ooooo`;o000000?oooooo`000?l00000Hooo
ool001cooooo00?o0000ooooooooool0DOooool2o`0000gooooo0_l00008ooooo`?o00002oooool2
o`0000Kooooo0_l00005ooooo`Co00002Oooool2o`0000;ooooo1?l00004ooooo`Oo00002_ooool2
o`0000Oooooo0_l000001?oooooo0000o`000?ooool2o`0000Kooooo0_l0000:ooooo`;o0000Looo
ool001cooooo00?o0000ooooooooool0DOooool2o`0000?ooooo0_l00008ooooo`Co00000_ooool3
o`0000oooooo0_l00005ooooo`;o00000_ooool2o`000004ooooool0003o0000o`00017ooooo0_l0
000Iooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0000Cooooo0_l00004ooooo`;o0000
2Oooool2o`0007?ooooo000Looooo`03o`000?oooooooooo05Kooooo0_l00007ooooo`Go00000_oo
ool3o`0000oooooo0_l00005ooooo`;o000000?oooooo`000?l000001_l0000[ooooo`;o000000?o
ooooo`000?l000001?l00005ooooo`Co00000_ooool2o`0000Sooooo0_l0001dooooo`007?ooool0
0ol0003oooooooooo`1Oooooo`Co000000Coooooo`000?l0003o00003Oooool2o`0000;ooooo0_l0
0008ooooo`Co00000_ooool2o`0000Cooooo0_l0000@ooooo`;o00000oooool2o`000003ooooool0
003o000000[ooooo0_l00004ooooo`Co00000oooool2o`0000;ooooo0_l0000<ooooo`;o00002_oo
ool2o`0000Kooooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`1Sooooo`Co00001?ooool2
o`0000Oooooo0_l0000=ooooo`?o00001Oooool2o`000003ooooool0003o0000013ooooo0_l00000
0ooooooo0000o`000002o`000003ooooool0003o000000[ooooo0_l00005ooooo`;o00001?ooool2
o`0000;ooooo0_l0000Hooooo`;o00001_ooool2o`00063ooooo000Looooo`03o`000?oooooooooo
067ooooo1?l00006ooooo`;o00001Oooool6o`0001?ooooo0_l0000Fooooo`;o00003Oooool2o`00
017ooooo0_l0000Fooooo`Co0000J?ooool001cooooo00?o0000ooooooooool0HOooool3o`000003
ooooool0003o000000Wooooo2?l00004ooooo`;o00003?ooool2o`0000Cooooo0_l0000Pooooo`;o
00000_ooool2o`0000gooooo0_l0000Fooooo`Co0000J?ooool001cooooo00?o0000ooooooooool0
IOooool2o`0000Wooooo0_l0000:ooooo`;o00003?ooool2o`0000Cooooo0_l000000ooooooo0000
o`00000Qooooo`;o00003Oooool2o`0001Wooooo0_l0001Wooooo`007?ooool00ol0003ooooooooo
o`1Tooooo`;o00002_ooool2o`00023ooooo0ol0000@ooooo`;o00002?ooool2o`0001[ooooo0_l0
000Cooooo`;o0000Ioooool001cooooo00?o0000ooooooooool0I?ooool2o`0000[ooooo0_l0000<
ooooo`;o00004Oooool3o`0000cooooo0_l00003ooooo`;o00000oooool3o`0000;ooooo0_l00002
ooooo`Co00004Oooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l00000M_oo
ool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o
8B4Qolc<c006ooooo`03o`000?oooooooooo07kooooo0_l00002ooooo`;o000000?oooooo`000?l0
00002_ooool2o`0000gooooo0_l000001?oooooo0000o`000?l00004ooooo`?o00001Oooool5o`00
017ooooo0_l000001?oooooo0000o`000?ooool5o`0007Kooooo00001_ooooooMgMgoiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`1aooooo`?o00002oooool2o`000004ooooool0003o0000ooooo`Co00004Oooool2o`0000?o
oooo0_l00002ooooo`?o00003?ooool2o`0001Oooooo0_l00002ooooo`;o0000N?ooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool0Koooool5o`0000Oooooo0_l00002ooooo`;o00001Oooool3o`00017o
oooo0_l000000ooooooo0000o`000002o`0000Gooooo0_l0000Gooooo`;o0000R?ooool00003oooo
ool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Olb<S;oV9RHoooooonHV9So<S8b00Ko
oooo0ol0001Xooooo`;o00001Oooool8o`0000Cooooo0_l00009ooooo`?o00005?ooool2o`0000Oo
oooo0_l0000Aooooo`;o00001?ooool2o`0000[ooooo0_l0001looooo`0000?oooooo`000?ooool0
0_ooool00ol0003oooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003o
ooooooooo`1Xooooo`;o00002Oooool4o`0001Gooooo0_l0000Gooooo`;o00000_ooool2o`0000co
oooo1?l0000:ooooo`;o000000Coooooo`000?l0003ooooo0_l0001looooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0
003oooooooooo`2<ooooo`;o00005oooool2o`0000;ooooo0_l0000<ooooo`;o00002Oooool2o`00
0004ooooool0003o0000ooooo`;o0000Ooooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2ooo
ool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0POooool2o`0000Wooooo
0_l0000;ooooo`;o00007oooool2o`0000Kooooo0_l00025ooooo`0000Koooooonk^k_lb<S;o0000
oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`21oooo
o`;o00005_ooool2o`0000cooooo0_l0000Aooooo`;o00003_ooool5o`0007[ooooo000Looooo`03
o`000?oooooooooo06oooooo0_l0000=ooooo`;o00007Oooool2o`0000Oooooo1_l0000:ooooo`;o
00004_ooool5o`0007[ooooo000Looooo`03o`000?oooooooooo06oooooo0_l0000=ooooo`;o0000
1_ooool2o`0001Gooooo0_l00003ooooo`;o00000_ooool2o`000004ooooool0003o0000o`0000[o
oooo0_l00006ooooo`;o0000ROooool001cooooo00?o0000ooooooooool0NOooool2o`0000_ooooo
0ol0000Dooooo`;o00000oooool2o`0001[ooooo0_l00029ooooo`007?ooool00ol0003ooooooooo
o`1eooooo`;o00000_ooool4o`0000[ooooo0_l0000Pooooo`;o00005Oooool2o`0008Oooooo000L
ooooo`03o`000?oooooooooo07Gooooo0_l00004ooooo`;o000000?oooooo`000?l000002?ooool2
o`0000Gooooo0_l000000ooooooo0000o`000004ooooo`;o00002?ooool3o`0000Cooooo0_l0000E
ooooo`;o0000Qoooool001cooooo00?o0000ooooooooool0O_ooool2o`0000Kooooo1?l00005oooo
o`;o000000?oooooo`000?l000001?ooool2o`0000Sooooo0ol0000?ooooo`;o00000_ooool2o`00
0003ooooool0003o000008cooooo000Looooo`03o`000?oooooooooo07Kooooo1?l00004ooooo`;o
00001_ooool2o`0001Gooooo1?l00002ooooo`;o00003oooool2o`0000;ooooo0_l000000ooooooo
0000o`00002<ooooo`007?ooool00ol0003oooooooooo`1fooooo`Co00001_ooool2o`00017ooooo
0_l00008ooooo`Co00000_ooool2o`0000Kooooo0_l0002Looooo`007?ooool00ol0003ooooooooo
o`20ooooo`;o00004Oooool2o`0000kooooo0_l00006ooooo`;o0000W?ooool001cooooo00?o0000
ooooooooool0Ooooool2o`0000Wooooo0_l0002mooooo`007?ooool00ol0003oooooooooo`1ooooo
o`;o000000?oooooo`000?l000001_ooool2o`0000Gooooo0_l00004ooooo`?o0000[oooool001co
oooo0_l00023ooooo`;o00000oooool3o`0000?ooooo0_l00002ooooo`;o00001?ooool3o`0000Ko
oooo0_l0002Wooooo`007?ooool00ol0003oooooooooo`27ooooo`?o00000oooool2o`00017ooooo
0_l0002Wooooo`007?ooool00ol0003oooooooooo`2Jooooo`?o0000[?ooool001cooooo00?o0000
ooooooooool0S?ooool2o`0000Sooooo1ol0002/ooooo`007?ooool00ol0003oooooooooo`2<oooo
o`;o00002?ooool4o`000:oooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0YOooool2o`000:;ooooo000Looooo`03o`000?oooooooooo09Cooooo0_l0
000?ooooo`;o0000X_ooool001cooooo00?o0000ooooooooool0U?ooool2o`000;?ooooo000Loooo
o`03o`000?oooooooooo09kooooo0_l0002Yooooo`007?ooool00ol0003oooooooooo`2Nooooo`;o
00000_ooool2o`000:Gooooo000Looooo`03o`000?oooooooooo0:;ooooo0_l0002Uooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`004_ooool4o`000003oa0@
4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool3
o`000?ooooooB_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003o
ooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o
0000ooooooooool0oooooomBooooo`004_ooool00omEEEGoIVIVo`00003ooooooeCooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo002Uooooo`04oa0@4?l0003o0000ooooo`;o0000
00?o410@ooooooooool05oooool00ol0003ok^k^ooooo`03ooooo`05oiRHV?l@413o0000oc8b<_o<
c<`00oooool5o`00093ooooo002Vooooo`05o`000?ooooooooooooooool000002Oooool6o`0000_o
oooo00?oEEEEojVYZOooool00oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoV9RHob4Q
8Oo^k^koooooodA4A02@ooooo`00Y_ooool01Ol0003ooooooooooooooooo000001[ooooo00?oZJVY
oeEEEOooool01oooool00ol0003oooooooooo`02ooooo`03oiRHV?lQ8B7ok^k^097ooooo002Voooo
o`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo00?o8B4Qooooooooool01Oooool0
0onYZJWo410@ooooo`04ooooo`03oiRHV?lQ8B7ok^k^093ooooo002Vooooo`05o`000?n7QhOooooo
ojVYZOl000006oooool00omEEEGoc<c<ooooo`04ooooo`03oa0@4?l0003o^[Zj00Kooooo00?oMgMg
ofIVI_ooool0Soooool00:Gooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Ioooo
o`03ojVYZOmgMgOooooo00Gooooo00?o^[Zjob4Q8Oooool01_ooool00ol0003oooooooooo`2>oooo
o`00`oooool01Ol@413ooooooooooooooooo<S8b00?ooooo00Go410@oiRHV?oooooo^[Zjo`000003
ooooo`05o`000?nj^[[ooooooiRHV?l@4100T?ooool00<?ooooo1Ol00003ooooo`05ojVYZOl@413o
0000oa0@4?nYZJT00oooool01OnHV9So410@o`000?lQ8B7oc<c<093ooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(738) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.6413 .34153 Mdot
.62243 .35422 Mdot
.28325 .49784 Mdot
.63378 .62235 Mdot
.4401 .5834 Mdot
.34186 .51249 Mdot
.43982 .39362 Mdot
.41067 .36139 Mdot
.32029 .50094 Mdot
.6807 .43391 Mdot
.45621 .39778 Mdot
.65592 .53308 Mdot
.4326 .38699 Mdot
.60161 .56735 Mdot
.25436 .29213 Mdot
.55798 .55042 Mdot
.6003 .39561 Mdot
.45998 .63978 Mdot
.53884 .58112 Mdot
.30746 .4882 Mdot
.67142 .33348 Mdot
.59805 .57091 Mdot
.61435 .35515 Mdot
.60125 .56915 Mdot
.634 .60008 Mdot
.63958 .38 Mdot
.62494 .33627 Mdot
.61106 .61652 Mdot
.62488 .57155 Mdot
.42319 .41568 Mdot
.40309 .59355 Mdot
.15658 .43744 Mdot
.57826 .5305 Mdot
.74196 .64241 Mdot
.40167 .38841 Mdot
.34146 .75357 Mdot
.2995 .50876 Mdot
.45279 .36622 Mdot
.40219 .37552 Mdot
.41301 .37045 Mdot
.42755 .36986 Mdot
.6395 .37325 Mdot
.44992 .42135 Mdot
.43387 .32874 Mdot
.62515 .63046 Mdot
.48552 .28618 Mdot
.39628 .73414 Mdot
.6068 .61372 Mdot
.65135 .35833 Mdot
.33087 .4869 Mdot
.79284 .61842 Mdot
.44813 .35895 Mdot
.39524 .2872 Mdot
.22915 .23717 Mdot
.41317 .38873 Mdot
.6236 .62518 Mdot
.31767 .52156 Mdot
.58059 .59215 Mdot
.59633 .58925 Mdot
.78845 .58213 Mdot
.6204 .58979 Mdot
.42292 .66165 Mdot
.58944 .3572 Mdot
.26653 .51488 Mdot
.32987 .50589 Mdot
.40691 .4016 Mdot
.61438 .41426 Mdot
.43954 .37942 Mdot
.63746 .65309 Mdot
.32626 .49075 Mdot
.60519 .61593 Mdot
.45923 .39149 Mdot
.6372 .42174 Mdot
.5977 .54142 Mdot
.52189 .29642 Mdot
.3113 .26492 Mdot
.47563 .67016 Mdot
.76765 .56711 Mdot
.73887 .32326 Mdot
.32021 .31024 Mdot
.61081 .56779 Mdot
.69795 .22667 Mdot
.26882 .28236 Mdot
.61142 .36388 Mdot
.60684 .69215 Mdot
.28397 .46226 Mdot
.59883 .54705 Mdot
.4431 .52998 Mdot
.66273 .57872 Mdot
.58711 .29958 Mdot
.31426 .50176 Mdot
.64659 .3704 Mdot
.63545 .62479 Mdot
.57462 .55093 Mdot
.76462 .43675 Mdot
.64412 .55119 Mdot
.60096 .62631 Mdot
.62997 .32944 Mdot
.43758 .41231 Mdot
.67395 .59408 Mdot
.41656 .32169 Mdot
.38633 .27525 Mdot
.64749 .58381 Mdot
.33888 .50096 Mdot
.59307 .38008 Mdot
.65284 .60141 Mdot
.40919 .39199 Mdot
.61244 .58533 Mdot
.39106 .35386 Mdot
.63704 .34716 Mdot
.57542 .55145 Mdot
.44865 .63724 Mdot
.56807 .28043 Mdot
.64828 .39616 Mdot
.5872 .19502 Mdot
.6142 .5962 Mdot
.59375 .57698 Mdot
.62171 .35712 Mdot
.32789 .5344 Mdot
.42977 .52375 Mdot
.6198 .42045 Mdot
.4073 .37148 Mdot
.61632 .34548 Mdot
.63479 .64507 Mdot
.35223 .52791 Mdot
.38479 .28007 Mdot
.37183 .25493 Mdot
.59656 .77909 Mdot
.609 .54585 Mdot
.40794 .301 Mdot
.34487 .52286 Mdot
.63832 .36167 Mdot
.43633 .37871 Mdot
.57939 .62902 Mdot
.61124 .40103 Mdot
.4493 .37084 Mdot
.43649 .63854 Mdot
.29343 .63973 Mdot
.65552 .3907 Mdot
.53569 .47448 Mdot
.39453 .40666 Mdot
.41309 .37164 Mdot
.75196 .67448 Mdot
.61764 .36098 Mdot
.45034 .65507 Mdot
.44867 .37296 Mdot
.55353 .72004 Mdot
.58003 .62832 Mdot
.67522 .71839 Mdot
.74154 .28072 Mdot
.78187 .64096 Mdot
.46814 .20861 Mdot
.42235 .67666 Mdot
.43831 .36141 Mdot
.64394 .60246 Mdot
.61931 .37368 Mdot
.62707 .36973 Mdot
.55998 .57099 Mdot
.62737 .59961 Mdot
.56615 .60088 Mdot
.5614 .57564 Mdot
.38032 .7262 Mdot
.56267 .59307 Mdot
.35911 .55417 Mdot
.63019 .41056 Mdot
.63309 .58873 Mdot
.28757 .52487 Mdot
.54764 .5878 Mdot
.45379 .36845 Mdot
.5919 .59043 Mdot
.6277 .60855 Mdot
.63853 .55301 Mdot
.4293 .36666 Mdot
.16991 .52315 Mdot
.70573 .26969 Mdot
.23339 .66078 Mdot
.5098 .20963 Mdot
.32891 .52509 Mdot
.59366 .55555 Mdot
.43056 .64956 Mdot
.51923 .62025 Mdot
.59995 .59001 Mdot
.81836 .56566 Mdot
.61977 .60997 Mdot
.72051 .59227 Mdot
.5387 .54377 Mdot
.21321 .6482 Mdot
.44483 .46249 Mdot
.62374 .57438 Mdot
.72836 .39322 Mdot
.69168 .72102 Mdot
.4917 .61458 Mdot
.41823 .37905 Mdot
.30109 .53348 Mdot
.30691 .51971 Mdot
.43295 .42989 Mdot
.67056 .61805 Mdot
.65805 .45293 Mdot
.67445 .62418 Mdot
.37973 .27963 Mdot
.60855 .42366 Mdot
.44813 .6788 Mdot
.65844 .37667 Mdot
.62167 .17348 Mdot
.55336 .36666 Mdot
.39435 .3664 Mdot
.44316 .63233 Mdot
.27425 .50993 Mdot
.37657 .28144 Mdot
.43848 .64901 Mdot
.59378 .6173 Mdot
.64963 .36084 Mdot
.7039 .71704 Mdot
.53539 .57135 Mdot
.55135 .83931 Mdot
.60405 .38218 Mdot
.45089 .48857 Mdot
.42604 .37699 Mdot
.34598 .48889 Mdot
.61015 .55226 Mdot
.56712 .58554 Mdot
.59795 .34831 Mdot
.60772 .60949 Mdot
.64382 .30225 Mdot
.62561 .61231 Mdot
.26383 .51909 Mdot
.4207 .69242 Mdot
.46987 .39947 Mdot
.61448 .77153 Mdot
.65479 .41091 Mdot
.30972 .56769 Mdot
.30213 .49424 Mdot
.67968 .41882 Mdot
.45259 .40568 Mdot
.43504 .6371 Mdot
.28884 .51006 Mdot
.40358 .66897 Mdot
.64287 .57099 Mdot
.30095 .50416 Mdot
.45263 .67001 Mdot
.2564 .61952 Mdot
.61397 .63084 Mdot
.51071 .69102 Mdot
.44496 .39164 Mdot
.6364 .33683 Mdot
.62143 .5892 Mdot
.3725 .2533 Mdot
.60086 .64626 Mdot
.38331 .24036 Mdot
.39326 .27214 Mdot
.39427 .28512 Mdot
.29577 .30182 Mdot
.41173 .65823 Mdot
.49368 .24602 Mdot
.54606 .43957 Mdot
.60948 .41295 Mdot
.63222 .6285 Mdot
.18031 .57687 Mdot
.44708 .37221 Mdot
.59346 .61585 Mdot
.26306 .47503 Mdot
.44896 .37451 Mdot
.57997 .58391 Mdot
.4198 .37169 Mdot
.62169 .37064 Mdot
.3893 .55778 Mdot
.59851 .36793 Mdot
.61489 .62828 Mdot
.41913 .39943 Mdot
.29315 .52176 Mdot
.63786 .38164 Mdot
.60929 .58798 Mdot
.59689 .55851 Mdot
.37373 .2736 Mdot
.63207 .58235 Mdot
.18969 .58083 Mdot
.60853 .617 Mdot
.27297 .51767 Mdot
.64957 .55645 Mdot
.78684 .65844 Mdot
.29818 .63497 Mdot
.63125 .41528 Mdot
.39375 .27732 Mdot
.31503 .5059 Mdot
.38236 .58333 Mdot
.50033 .54418 Mdot
.61131 .57546 Mdot
.38325 .26485 Mdot
.42406 .49786 Mdot
.40867 .40471 Mdot
.66258 .5925 Mdot
.55035 .34252 Mdot
.2913 .50093 Mdot
.37686 .27973 Mdot
.58329 .51871 Mdot
.59356 .37322 Mdot
.63324 .62002 Mdot
.29524 .50873 Mdot
.61971 .34282 Mdot
.59235 .63772 Mdot
.39905 .74657 Mdot
.38567 .25979 Mdot
.4451 .38951 Mdot
.60096 .48138 Mdot
.57098 .61243 Mdot
.30848 .5258 Mdot
.60899 .37854 Mdot
.41415 .40274 Mdot
.64501 .38896 Mdot
.6927 .72697 Mdot
.52285 .21924 Mdot
.31958 .70543 Mdot
.45279 .63422 Mdot
.3718 .22791 Mdot
.24824 .68076 Mdot
.52878 .24051 Mdot
.5486 .76491 Mdot
.33579 .77789 Mdot
.28507 .51995 Mdot
.53388 .67547 Mdot
.31587 .5118 Mdot
.64547 .58966 Mdot
.33782 .50899 Mdot
.1988 .64044 Mdot
.61612 .61588 Mdot
.32479 .52571 Mdot
.36717 .68944 Mdot
.62515 .59488 Mdot
.64029 .40654 Mdot
.20283 .35389 Mdot
.68817 .28663 Mdot
.56298 .4097 Mdot
.32874 .53046 Mdot
.82173 .47638 Mdot
.61622 .60734 Mdot
.54994 .55623 Mdot
.62243 .37785 Mdot
.66399 .58961 Mdot
.46015 .66976 Mdot
.40178 .65994 Mdot
.6762 .70914 Mdot
.62332 .22332 Mdot
.64382 .6575 Mdot
.63476 .37956 Mdot
.74285 .33286 Mdot
.51959 .29899 Mdot
.3614 .26087 Mdot
.3959 .38903 Mdot
.17224 .5188 Mdot
.55234 .64864 Mdot
.53508 .48001 Mdot
.54508 .34073 Mdot
.64328 .35796 Mdot
.22926 .60922 Mdot
.41629 .39116 Mdot
.72857 .35065 Mdot
.70832 .51855 Mdot
.57193 .60658 Mdot
.42979 .42075 Mdot
.66862 .55639 Mdot
.61252 .29649 Mdot
.55581 .70017 Mdot
.3674 .3566 Mdot
.61975 .62943 Mdot
.50046 .25447 Mdot
.59395 .58237 Mdot
.65981 .71984 Mdot
.60085 .62297 Mdot
.64191 .39577 Mdot
.65604 .6547 Mdot
.46909 .54302 Mdot
.67204 .24383 Mdot
.55793 .34922 Mdot
.41736 .67635 Mdot
.59518 .56355 Mdot
.56951 .6001 Mdot
.42786 .67257 Mdot
.63148 .39328 Mdot
.59215 .62493 Mdot
.47001 .78691 Mdot
.5713 .61033 Mdot
.45719 .36915 Mdot
.40869 .56727 Mdot
.60283 .44853 Mdot
.5854 .54643 Mdot
.6038 .35083 Mdot
.41337 .38007 Mdot
.40296 .36999 Mdot
.57047 .65247 Mdot
.43607 .36231 Mdot
.63092 .61918 Mdot
.40335 .5632 Mdot
.6213 .34935 Mdot
.59856 .50899 Mdot
.62729 .39627 Mdot
.78846 .38766 Mdot
.4126 .37638 Mdot
.36381 .26967 Mdot
.51308 .55476 Mdot
.42507 .39367 Mdot
.68595 .29611 Mdot
.57025 .6609 Mdot
.56558 .63385 Mdot
.6874 .29329 Mdot
.30925 .53323 Mdot
.37134 .28158 Mdot
.41212 .39735 Mdot
.56739 .60567 Mdot
.65011 .5779 Mdot
.46032 .39544 Mdot
.78436 .45637 Mdot
.3815 .59512 Mdot
.60383 .62373 Mdot
.63847 .39649 Mdot
.64037 .36488 Mdot
.60023 .63891 Mdot
.60363 .59352 Mdot
.2791 .52429 Mdot
.38049 .26109 Mdot
.38592 .28796 Mdot
.3692 .25541 Mdot
.36566 .51122 Mdot
.40566 .23116 Mdot
.41387 .37081 Mdot
.42986 .26389 Mdot
.26988 .43977 Mdot
.5532 .63697 Mdot
.30636 .52751 Mdot
.57291 .57901 Mdot
.64082 .57638 Mdot
.41829 .40437 Mdot
.47859 .17907 Mdot
.69019 .61038 Mdot
.65848 .35984 Mdot
.4595 .36685 Mdot
.52572 .55355 Mdot
.47195 .43317 Mdot
.46176 .66281 Mdot
.56083 .36241 Mdot
.43622 .4202 Mdot
.65005 .37345 Mdot
.45475 .40767 Mdot
.56882 .60161 Mdot
.55464 .5752 Mdot
.6308 .35071 Mdot
.41081 .65785 Mdot
.65547 .58953 Mdot
.58102 .5832 Mdot
.84305 .58832 Mdot
.52169 .29056 Mdot
.46634 .43484 Mdot
.63771 .5832 Mdot
.56714 .63919 Mdot
.40956 .66984 Mdot
.57818 .61701 Mdot
.60745 .55131 Mdot
.58018 .27517 Mdot
.43762 .43049 Mdot
.46253 .68124 Mdot
.7232 .34464 Mdot
.60495 .38517 Mdot
.19794 .56583 Mdot
.38802 .27563 Mdot
.46664 .413 Mdot
.39041 .55308 Mdot
.36695 .27073 Mdot
.30015 .42942 Mdot
.21438 .58549 Mdot
.3649 .26298 Mdot
.38687 .5155 Mdot
.62482 .68657 Mdot
.55965 .60374 Mdot
.58902 .58995 Mdot
.43318 .64623 Mdot
.61722 .36518 Mdot
.43199 .47552 Mdot
.24587 .58708 Mdot
.59653 .57319 Mdot
.63303 .31945 Mdot
.21104 .55665 Mdot
.37241 .2753 Mdot
.41747 .65624 Mdot
.45097 .67987 Mdot
.59227 .57953 Mdot
.56834 .25318 Mdot
.63788 .37866 Mdot
.60912 .58777 Mdot
.57117 .56209 Mdot
.32429 .53162 Mdot
.65202 .37233 Mdot
.30396 .4937 Mdot
.39203 .2662 Mdot
.423 .8226 Mdot
.83333 .60856 Mdot
.43359 .40571 Mdot
.23582 .6494 Mdot
.4267 .35286 Mdot
.34884 .31461 Mdot
.37119 .25703 Mdot
.60454 .58035 Mdot
.65023 .41296 Mdot
.61224 .58744 Mdot
.58136 .61267 Mdot
.59034 .61793 Mdot
.64884 .65568 Mdot
.81598 .57405 Mdot
.43926 .6569 Mdot
.57811 .64868 Mdot
.31747 .54355 Mdot
.21084 .61803 Mdot
.19219 .39088 Mdot
.5782 .56375 Mdot
.59094 .57474 Mdot
.61395 .4102 Mdot
.58024 .54138 Mdot
.41647 .41325 Mdot
.60896 .36829 Mdot
.65199 .58536 Mdot
.24586 .62724 Mdot
.58071 .62319 Mdot
.26152 .69188 Mdot
.45703 .40332 Mdot
.5611 .37031 Mdot
.60425 .65511 Mdot
.36468 .26187 Mdot
.37002 .28017 Mdot
.35885 .26147 Mdot
.41316 .41527 Mdot
.31715 .52739 Mdot
.23847 .54095 Mdot
.64494 .53443 Mdot
.64175 .60666 Mdot
.57507 .64371 Mdot
.35592 .49181 Mdot
.42364 .55528 Mdot
.47257 .21749 Mdot
.52296 .60927 Mdot
.32121 .54108 Mdot
.65543 .34091 Mdot
.56482 .17522 Mdot
.60895 .37195 Mdot
.45809 .6845 Mdot
.45738 .377 Mdot
.46403 .65884 Mdot
.82624 .51997 Mdot
.63011 .3484 Mdot
.59928 .34633 Mdot
.327 .52601 Mdot
.46977 .46726 Mdot
.1301 .37325 Mdot
.34984 .50714 Mdot
.51559 .78857 Mdot
.6262 .38058 Mdot
.61129 .5372 Mdot
.41745 .5018 Mdot
.47083 .47109 Mdot
.32603 .51628 Mdot
.60849 .56434 Mdot
.62207 .23637 Mdot
.27679 .521 Mdot
.66101 .58949 Mdot
.34093 .5303 Mdot
.43386 .36795 Mdot
.34317 .52534 Mdot
.66705 .37196 Mdot
.64048 .56959 Mdot
.18278 .28864 Mdot
.50457 .3845 Mdot
.61951 .58711 Mdot
.45785 .36598 Mdot
.45416 .79204 Mdot
.5758 .60221 Mdot
.46328 .66627 Mdot
.34393 .54104 Mdot
.36544 .63401 Mdot
.61705 .60308 Mdot
.33685 .51511 Mdot
.6573 .35035 Mdot
.47794 .41018 Mdot
.31208 .28778 Mdot
.38023 .2873 Mdot
.61536 .37324 Mdot
.35838 .27566 Mdot
.40228 .41318 Mdot
.64927 .56474 Mdot
.56572 .57062 Mdot
.63505 .40567 Mdot
.28287 .34464 Mdot
.6088 .53078 Mdot
.61066 .56782 Mdot
.28263 .50082 Mdot
.36151 .49007 Mdot
.22813 .37666 Mdot
.28727 .52171 Mdot
.56969 .64172 Mdot
.63713 .40412 Mdot
.64892 .59865 Mdot
.63735 .40966 Mdot
.63277 .62792 Mdot
.57634 .40169 Mdot
.61122 .36957 Mdot
.56742 .21015 Mdot
.6237 .56131 Mdot
.55855 .51179 Mdot
.58295 .61534 Mdot
.59582 .62124 Mdot
.34921 .53942 Mdot
.43854 .66832 Mdot
.65436 .55757 Mdot
.34795 .56805 Mdot
.42058 .64587 Mdot
.71886 .65039 Mdot
.3233 .53289 Mdot
.44025 .64378 Mdot
.46895 .71359 Mdot
.39345 .27839 Mdot
.4303 .65736 Mdot
.19158 .42603 Mdot
.42987 .40606 Mdot
.6092 .35553 Mdot
.62611 .59447 Mdot
.37127 .80478 Mdot
.39872 .59353 Mdot
.37278 .26638 Mdot
.61601 .59719 Mdot
.57225 .58499 Mdot
.59445 .39039 Mdot
.65764 .19446 Mdot
.29808 .48467 Mdot
.64166 .61695 Mdot
.60032 .39235 Mdot
.73332 .27098 Mdot
.35441 .5224 Mdot
.42731 .6543 Mdot
.4633 .3792 Mdot
.67657 .36883 Mdot
.37873 .28765 Mdot
.40365 .39955 Mdot
.38016 .4908 Mdot
.82961 .47666 Mdot
.61227 .60572 Mdot
.30035 .52178 Mdot
.78524 .63503 Mdot
.67032 .59323 Mdot
.42376 .44142 Mdot
.70719 .58715 Mdot
.64468 .36124 Mdot
.46261 .38586 Mdot
.42899 .68246 Mdot
.61758 .35012 Mdot
.63327 .39262 Mdot
.41392 .35972 Mdot
.30151 .55363 Mdot
.45377 .48722 Mdot
.46099 .37939 Mdot
.59279 .29244 Mdot
.70751 .70241 Mdot
.384 .2637 Mdot
.41566 .659 Mdot
.71234 .72101 Mdot
.64045 .37456 Mdot
.17191 .52009 Mdot
.80991 .58344 Mdot
.60098 .62627 Mdot
.45665 .65577 Mdot
.30249 .43855 Mdot
.23611 .5423 Mdot
.45085 .37895 Mdot
.44037 .54813 Mdot
.46598 .66668 Mdot
.57167 .61953 Mdot
.60333 .4531 Mdot
.62353 .56369 Mdot
.44598 .36844 Mdot
.65518 .29728 Mdot
.65126 .3804 Mdot
.40661 .41858 Mdot
.62599 .29901 Mdot
.63868 .57287 Mdot
.61431 .55946 Mdot
.62062 .73996 Mdot
.65043 .3607 Mdot
.3814 .2892 Mdot
.61535 .57868 Mdot
.58264 .5931 Mdot
.64615 .55867 Mdot
.56259 .50056 Mdot
.55518 .2649 Mdot
.64411 .61491 Mdot
.36316 .51531 Mdot
.55199 .60561 Mdot
.61423 .55744 Mdot
.59661 .37923 Mdot
.83247 .58513 Mdot
.38807 .25852 Mdot
.58902 .59355 Mdot
.60153 .62159 Mdot
.40321 .376 Mdot
.43646 .49199 Mdot
.47759 .46552 Mdot
.3314 .49377 Mdot
.5386 .75068 Mdot
.66907 .63096 Mdot
.61091 .39793 Mdot
.45596 .63998 Mdot
.61877 .54406 Mdot
.60782 .39938 Mdot
.55611 .60655 Mdot
.29085 .5323 Mdot
.38056 .2623 Mdot
.56972 .45352 Mdot
.42702 .66101 Mdot
.39143 .46674 Mdot
.44899 .28962 Mdot
.29101 .5281 Mdot
.63876 .60255 Mdot
.47829 .38761 Mdot
.31 .49511 Mdot
.37408 .27182 Mdot
.57141 .52204 Mdot
.62892 .3723 Mdot
.64965 .3823 Mdot
.6708 .71404 Mdot
.29814 .48077 Mdot
.83783 .41238 Mdot
.43539 .36773 Mdot
.63606 .63924 Mdot
.4279 .30803 Mdot
.64972 .38834 Mdot
.6605 .73319 Mdot
.43684 .64374 Mdot
.45103 .38163 Mdot
.371 .24744 Mdot
.61087 .40424 Mdot
.65543 .3772 Mdot
.61599 .63234 Mdot
.58335 .56385 Mdot
.54567 .77034 Mdot
.67091 .71967 Mdot
.42509 .36989 Mdot
.41712 .66528 Mdot
.3332 .4902 Mdot
.63916 .57947 Mdot
.6119 .36113 Mdot
.7215 .60178 Mdot
.56549 .60553 Mdot
.27575 .52015 Mdot
.63928 .35626 Mdot
.42271 .67177 Mdot
.44945 .64201 Mdot
.59529 .62125 Mdot
.77941 .57162 Mdot
.42912 .39589 Mdot
.6468 .39982 Mdot
.6681 .42371 Mdot
.61988 .5326 Mdot
.58606 .56161 Mdot
.64461 .52399 Mdot
.40362 .39832 Mdot
.58438 .45209 Mdot
.47328 .65431 Mdot
.62788 .36507 Mdot
.61762 .58647 Mdot
.42297 .66124 Mdot
.5685 .4776 Mdot
.36805 .26161 Mdot
.34376 .52887 Mdot
.45883 .6722 Mdot
.44586 .67116 Mdot
.4215 .64346 Mdot
.17502 .5072 Mdot
.61524 .42469 Mdot
.72088 .32039 Mdot
.59568 .62504 Mdot
.67116 .71102 Mdot
.57195 .54656 Mdot
.4098 .41557 Mdot
.29788 .52865 Mdot
.577 .6099 Mdot
.61719 .63246 Mdot
.63545 .48138 Mdot
.53258 .54161 Mdot
.66291 .32363 Mdot
.64349 .35123 Mdot
.54903 .517 Mdot
.31476 .53292 Mdot
.71177 .22525 Mdot
.1464 .53936 Mdot
.62421 .65372 Mdot
.44382 .48012 Mdot
.61027 .36615 Mdot
.41765 .3599 Mdot
.48226 .47106 Mdot
.46613 .38604 Mdot
.6298 .36162 Mdot
.64315 .58543 Mdot
.43462 .26355 Mdot
.40498 .65715 Mdot
.56419 .59429 Mdot
.43072 .37426 Mdot
.56501 .5977 Mdot
.42186 .42235 Mdot
.63043 .31046 Mdot
.55053 .32391 Mdot
.6186 .61146 Mdot
.62001 .53505 Mdot
.62353 .47803 Mdot
.579 .56402 Mdot
.32295 .39737 Mdot
.62304 .39014 Mdot
.62075 .22869 Mdot
.60042 .63735 Mdot
.79295 .5228 Mdot
.56474 .60819 Mdot
.27919 .35784 Mdot
.58844 .55352 Mdot
.48722 .50144 Mdot
.57592 .62409 Mdot
.59597 .55575 Mdot
.41565 .39737 Mdot
.40425 .37291 Mdot
.65838 .35353 Mdot
.37542 .28802 Mdot
.21282 .64403 Mdot
.58245 .57498 Mdot
.36534 .52409 Mdot
.44253 .31627 Mdot
.44311 .6704 Mdot
.63333 .36406 Mdot
.7743 .29608 Mdot
.41549 .37585 Mdot
.26573 .51873 Mdot
.29649 .35535 Mdot
.32801 .48403 Mdot
.40009 .33517 Mdot
.52982 .53672 Mdot
.41784 .67103 Mdot
.5647 .60968 Mdot
.74312 .63373 Mdot
.50871 .27001 Mdot
.65636 .60833 Mdot
.4198 .43061 Mdot
.51787 .62334 Mdot
.72065 .69712 Mdot
.41719 .68271 Mdot
.43118 .68019 Mdot
.41319 .39416 Mdot
.29338 .49221 Mdot
.67818 .60038 Mdot
.4411 .64333 Mdot
.30666 .53692 Mdot
.36952 .28654 Mdot
.49402 .57477 Mdot
.63751 .37534 Mdot
.56332 .41959 Mdot
.49124 .31419 Mdot
.42301 .37122 Mdot
.36196 .56553 Mdot
.66989 .35207 Mdot
.59066 .38452 Mdot
.36548 .27763 Mdot
.346 .54213 Mdot
.63702 .42391 Mdot
.65358 .5794 Mdot
.53379 .57532 Mdot
.59508 .5819 Mdot
.44774 .64741 Mdot
.5851 .55222 Mdot
.32637 .54519 Mdot
.44509 .37453 Mdot
.31039 .50026 Mdot
.43103 .39789 Mdot
.43902 .24679 Mdot
.60506 .59805 Mdot
.59125 .56323 Mdot
.40924 .53413 Mdot
.65797 .36732 Mdot
.79864 .56358 Mdot
.36384 .53253 Mdot
.31608 .51812 Mdot
.64963 .59438 Mdot
.65409 .34658 Mdot
.39487 .67392 Mdot
.40529 .51747 Mdot
.57817 .55717 Mdot
.62183 .39002 Mdot
.64182 .61315 Mdot
.31891 .69638 Mdot
.54157 .32201 Mdot
.64623 .38852 Mdot
.64888 .22399 Mdot
.63083 .57334 Mdot
.58343 .68255 Mdot
.56281 .6365 Mdot
.48225 .76936 Mdot
.63187 .53768 Mdot
.60367 .37952 Mdot
.59352 .58947 Mdot
.6102 .38491 Mdot
.27876 .50892 Mdot
.41973 .36431 Mdot
.61586 .37657 Mdot
.59031 .54403 Mdot
.15799 .48146 Mdot
.43012 .37155 Mdot
.5969 .56054 Mdot
.44032 .41453 Mdot
.59979 .38223 Mdot
.65412 .35852 Mdot
.19505 .42951 Mdot
.44431 .44436 Mdot
.42599 .37258 Mdot
.63632 .61445 Mdot
.50182 .34648 Mdot
.64857 .59955 Mdot
.5564 .77029 Mdot
.62285 .63981 Mdot
.6517 .55912 Mdot
.34067 .22605 Mdot
.46379 .36371 Mdot
.81243 .36901 Mdot
.2492 .59732 Mdot
.17636 .49244 Mdot
.66289 .41354 Mdot
.41731 .68281 Mdot
.22326 .59597 Mdot
.39205 .26848 Mdot
.34597 .53497 Mdot
.57697 .61053 Mdot
.58153 .41914 Mdot
.46053 .37071 Mdot
.44328 .66533 Mdot
.61937 .61079 Mdot
.28444 .52957 Mdot
.2035 .39907 Mdot
.43926 .36165 Mdot
.63895 .37214 Mdot
.65814 .36344 Mdot
.71699 .26759 Mdot
.61688 .59024 Mdot
.59263 .56652 Mdot
.45652 .37407 Mdot
.66671 .63003 Mdot
.41694 .64254 Mdot
.35224 .69619 Mdot
.4229 .37583 Mdot
.50323 .37313 Mdot
.63622 .34629 Mdot
.57208 .58269 Mdot
.41583 .57051 Mdot
.22736 .45949 Mdot
.70922 .41785 Mdot
.43305 .64717 Mdot
.5778 .75496 Mdot
.6037 .38026 Mdot
.43393 .37702 Mdot
.50438 .67584 Mdot
.60719 .64696 Mdot
.57444 .58671 Mdot
.58416 .75258 Mdot
.42813 .49222 Mdot
.39113 .65855 Mdot
.58356 .53841 Mdot
.43083 .49963 Mdot
.64931 .59111 Mdot
.6495 .57774 Mdot
.63474 .65267 Mdot
.59892 .54901 Mdot
.61645 .38751 Mdot
.63873 .48004 Mdot
.3433 .51869 Mdot
.76059 .42313 Mdot
.45317 .53668 Mdot
.62687 .58417 Mdot
.6417 .58143 Mdot
.69623 .40081 Mdot
.4473 .32236 Mdot
.62591 .38748 Mdot
.58361 .40593 Mdot
.40864 .37858 Mdot
.54553 .52808 Mdot
.32179 .48054 Mdot
.68753 .54496 Mdot
.3156 .49774 Mdot
.621 .39079 Mdot
.31276 .52253 Mdot
.40633 .38058 Mdot
.29979 .52071 Mdot
.36526 .51184 Mdot
.44121 .42123 Mdot
.638 .34467 Mdot
.57781 .55919 Mdot
.41489 .37376 Mdot
.61629 .74417 Mdot
.44823 .64716 Mdot
.19474 .42854 Mdot
.54489 .56863 Mdot
.67381 .67359 Mdot
.39887 .74605 Mdot
.30642 .50558 Mdot
.55016 .30467 Mdot
.61139 .36956 Mdot
.42918 .63418 Mdot
.61333 .38571 Mdot
.81486 .55733 Mdot
.42913 .67098 Mdot
.19216 .43074 Mdot
.49269 .6738 Mdot
.34109 .58594 Mdot
.56541 .55805 Mdot
.58046 .35425 Mdot
.30526 .49622 Mdot
.4564 .36764 Mdot
.30274 .4553 Mdot
.61484 .54874 Mdot
.52373 .23814 Mdot
.60526 .41714 Mdot
.39084 .28401 Mdot
.43773 .38034 Mdot
.41258 .42911 Mdot
.6137 .59447 Mdot
.37489 .58017 Mdot
.6509 .61552 Mdot
.50397 .65138 Mdot
.55475 .75802 Mdot
.69067 .54938 Mdot
.63018 .62146 Mdot
.32163 .49393 Mdot
.64087 .61314 Mdot
.56398 .66663 Mdot
.74937 .67613 Mdot
.54314 .5736 Mdot
.53554 .21371 Mdot
.37997 .62955 Mdot
.62677 .35141 Mdot
.60036 .65618 Mdot
.3798 .26989 Mdot
.63494 .57853 Mdot
.49541 .87203 Mdot
.43251 .65977 Mdot
.29167 .47537 Mdot
.57512 .54815 Mdot
.61439 .58311 Mdot
.75044 .60107 Mdot
.56887 .36694 Mdot
.37513 .24827 Mdot
.57675 .59257 Mdot
.55019 .73839 Mdot
.41614 .40748 Mdot
.61483 .64427 Mdot
.59086 .58657 Mdot
.68168 .74017 Mdot
.42509 .41322 Mdot
.30386 .51134 Mdot
.39382 .27472 Mdot
.33826 .49201 Mdot
.43169 .68753 Mdot
.49382 .45267 Mdot
.6698 .72649 Mdot
.53921 .32355 Mdot
.4664 .66068 Mdot
.57045 .55843 Mdot
.63961 .69265 Mdot
.61854 .56894 Mdot
.42895 .68104 Mdot
.42486 .41606 Mdot
.61772 .38418 Mdot
.56158 .44837 Mdot
.37857 .27839 Mdot
.6599 .58597 Mdot
.41341 .67922 Mdot
.62258 .37384 Mdot
.21951 .41477 Mdot
.62226 .36097 Mdot
.42216 .39202 Mdot
.40385 .41182 Mdot
.42912 .66789 Mdot
.61445 .38766 Mdot
.35935 .51155 Mdot
.2502 .59498 Mdot
.62762 .63715 Mdot
.48 .41845 Mdot
.66339 .39177 Mdot
.62018 .33692 Mdot
.63524 .41853 Mdot
.60819 .60217 Mdot
.44009 .48682 Mdot
.62217 .64941 Mdot
.41042 .38772 Mdot
.33668 .53544 Mdot
.67754 .71768 Mdot
.75801 .61444 Mdot
.50663 .38166 Mdot
.6537 .55762 Mdot
.60775 .55399 Mdot
.5924 .57931 Mdot
.6099 .62537 Mdot
.34168 .70378 Mdot
.6035 .59655 Mdot
.42233 .39919 Mdot
.34005 .50494 Mdot
.61843 .59329 Mdot
.38253 .26981 Mdot
.45624 .49852 Mdot
.45953 .64283 Mdot
.47933 .50699 Mdot
.15611 .52404 Mdot
.62248 .37526 Mdot
.29016 .51279 Mdot
.3483 .52996 Mdot
.43643 .63849 Mdot
.43415 .36565 Mdot
.61928 .36421 Mdot
.47133 .75612 Mdot
.41483 .64931 Mdot
.5891 .59469 Mdot
.3986 .55814 Mdot
.61508 .20151 Mdot
.5593 .57631 Mdot
.58626 .61105 Mdot
.39504 .28244 Mdot
.30547 .48325 Mdot
.37414 .82258 Mdot
.41095 .48514 Mdot
.43534 .6682 Mdot
.43962 .6769 Mdot
.63004 .42131 Mdot
.65709 .613 Mdot
.43682 .39429 Mdot
.41423 .50924 Mdot
.48696 .80463 Mdot
.25182 .47902 Mdot
.34257 .31255 Mdot
.58131 .62173 Mdot
.74132 .5786 Mdot
.63717 .62659 Mdot
.59327 .38731 Mdot
.62117 .41702 Mdot
.63071 .38413 Mdot
.41582 .39379 Mdot
.79113 .39611 Mdot
.42508 .40041 Mdot
.15386 .52883 Mdot
.6078 .36383 Mdot
.30864 .61069 Mdot
.31908 .52431 Mdot
.64766 .53882 Mdot
.41609 .66746 Mdot
.46322 .33746 Mdot
.62847 .6573 Mdot
.55936 .25147 Mdot
.30615 .52712 Mdot
.64987 .35193 Mdot
.54876 .65117 Mdot
.23199 .68736 Mdot
.48579 .44737 Mdot
.46295 .61439 Mdot
.79824 .57827 Mdot
.42709 .67191 Mdot
.70763 .40359 Mdot
.41036 .64839 Mdot
.4492 .37229 Mdot
.61278 .54772 Mdot
.6043 .54592 Mdot
.63109 .62502 Mdot
.60303 .59972 Mdot
.41244 .40136 Mdot
.59976 .63314 Mdot
.78691 .65807 Mdot
.38821 .26563 Mdot
.27952 .6425 Mdot
.46011 .65187 Mdot
.4343 .42629 Mdot
.32818 .49931 Mdot
.37423 .28854 Mdot
.62645 .76709 Mdot
.59138 .62778 Mdot
.58038 .61331 Mdot
.36421 .25706 Mdot
.64666 .64618 Mdot
.549 .64842 Mdot
.34171 .51556 Mdot
.51759 .40626 Mdot
.4418 .68246 Mdot
.46373 .65982 Mdot
.44536 .41706 Mdot
.61327 .38625 Mdot
.43231 .64542 Mdot
.2882 .49512 Mdot
.58504 .63335 Mdot
.62942 .54392 Mdot
.66369 .39032 Mdot
.81004 .58332 Mdot
.40312 .67275 Mdot
.5864 .66918 Mdot
.60732 .38494 Mdot
.60808 .42009 Mdot
.57504 .59277 Mdot
.57228 .52614 Mdot
.62237 .33903 Mdot
.45923 .64714 Mdot
.43656 .42552 Mdot
.32944 .5932 Mdot
.4444 .36938 Mdot
.61875 .36897 Mdot
.57189 .63181 Mdot
.63736 .34526 Mdot
.63218 .57823 Mdot
.52042 .11466 Mdot
.59429 .54987 Mdot
.68377 .28864 Mdot
.49292 .77318 Mdot
.35014 .52629 Mdot
.35713 .5067 Mdot
.3827 .26574 Mdot
.60562 .38172 Mdot
.62191 .54578 Mdot
.43052 .67698 Mdot
.1762 .47591 Mdot
.61553 .4325 Mdot
.3249 .54033 Mdot
.31637 .48108 Mdot
.41636 .41154 Mdot
.56033 .59448 Mdot
.57474 .57669 Mdot
.29989 .51898 Mdot
.39162 .73912 Mdot
.61465 .40182 Mdot
.59323 .56669 Mdot
.6111 .55478 Mdot
.34609 .5167 Mdot
.25369 .60104 Mdot
.5977 .3279 Mdot
.60067 .54964 Mdot
.48427 .68372 Mdot
.41167 .41588 Mdot
.61658 .62091 Mdot
.60119 .63231 Mdot
.45195 .66469 Mdot
.271 .65129 Mdot
.72894 .69207 Mdot
.42509 .42682 Mdot
.38331 .28858 Mdot
.59295 .54166 Mdot
.32117 .52347 Mdot
.61314 .53756 Mdot
.3107 .73616 Mdot
.39078 .27297 Mdot
.60423 .58613 Mdot
.62914 .65245 Mdot
.65057 .39809 Mdot
.60732 .58671 Mdot
.6886 .53844 Mdot
.34311 .49819 Mdot
.6049 .58787 Mdot
.78522 .56562 Mdot
.41249 .4063 Mdot
.61414 .65715 Mdot
.44783 .67741 Mdot
.47789 .77158 Mdot
.46553 .29865 Mdot
.36607 .50334 Mdot
.45389 .64561 Mdot
.58108 .55412 Mdot
.29083 .4958 Mdot
.46228 .37104 Mdot
.53945 .24111 Mdot
.55954 .60614 Mdot
.43985 .36842 Mdot
.44326 .37504 Mdot
.43022 .66515 Mdot
.77589 .31965 Mdot
.65097 .64607 Mdot
.57925 .56154 Mdot
.6052 .80029 Mdot
.61161 .41772 Mdot
.57712 .56192 Mdot
.56131 .58169 Mdot
.44236 .39558 Mdot
.51319 .55037 Mdot
.68786 .32498 Mdot
.36723 .69016 Mdot
.42048 .42184 Mdot
.37336 .5256 Mdot
.28988 .49726 Mdot
.45839 .65033 Mdot
.63023 .35252 Mdot
.46938 .65825 Mdot
.33506 .52591 Mdot
.5982 .62329 Mdot
.4494 .39303 Mdot
.71415 .45504 Mdot
.4476 .35844 Mdot
.27363 .52213 Mdot
.60252 .34896 Mdot
.42145 .30398 Mdot
.67079 .79477 Mdot
.48905 .30185 Mdot
.44443 .42516 Mdot
.44383 .67022 Mdot
.39935 .51487 Mdot
.60848 .55476 Mdot
.71893 .36645 Mdot
.56611 .57661 Mdot
.79665 .58247 Mdot
.30025 .53156 Mdot
.36314 .2733 Mdot
.61325 .54751 Mdot
.57018 .75159 Mdot
.43857 .42698 Mdot
.41229 .40885 Mdot
.59624 .61005 Mdot
.42349 .39373 Mdot
.58132 .56845 Mdot
.34827 .51082 Mdot
.78508 .33792 Mdot
.60228 .55598 Mdot
.54464 .60441 Mdot
.44955 .42717 Mdot
.19413 .42866 Mdot
.35618 .54136 Mdot
.74324 .5847 Mdot
.24992 .71484 Mdot
.4267 .39321 Mdot
.56261 .6387 Mdot
.29868 .50523 Mdot
.39501 .28388 Mdot
.32415 .55085 Mdot
.56554 .5908 Mdot
.58606 .62064 Mdot
.65041 .60049 Mdot
.61544 .55964 Mdot
.71431 .36691 Mdot
.5251 .58986 Mdot
.73248 .5383 Mdot
.58245 .61376 Mdot
.6431 .44277 Mdot
.41947 .40153 Mdot
.65995 .32238 Mdot
.41204 .63332 Mdot
.58935 .62355 Mdot
.56715 .38382 Mdot
.43042 .42673 Mdot
.15959 .53668 Mdot
.42079 .41291 Mdot
.31642 .50435 Mdot
.42323 .358 Mdot
.63162 .58085 Mdot
.64167 .36633 Mdot
.34423 .50208 Mdot
.46367 .22406 Mdot
.34417 .53715 Mdot
.61925 .58776 Mdot
.278 .62475 Mdot
.34768 .52838 Mdot
.46444 .50145 Mdot
.63939 .36134 Mdot
.55541 .73262 Mdot
.60563 .41005 Mdot
.60723 .58055 Mdot
.60835 .57487 Mdot
.37798 .29161 Mdot
.4372 .36083 Mdot
.60055 .37767 Mdot
.84649 .58161 Mdot
.45499 .68242 Mdot
.63666 .38594 Mdot
.60645 .52459 Mdot
.43083 .48579 Mdot
.64567 .39833 Mdot
.51419 .74243 Mdot
.44208 .36437 Mdot
.63735 .42208 Mdot
.60861 .52106 Mdot
.52785 .48831 Mdot
.40694 .64757 Mdot
.29599 .53625 Mdot
.51822 .46632 Mdot
.30933 .4931 Mdot
.41712 .42546 Mdot
.28441 .49187 Mdot
.41739 .40719 Mdot
.68949 .29711 Mdot
.65856 .30068 Mdot
.47431 .38021 Mdot
.40356 .41354 Mdot
.33134 .52117 Mdot
.60658 .62448 Mdot
.45758 .55336 Mdot
.62725 .53169 Mdot
.55709 .56968 Mdot
.40503 .39854 Mdot
.60294 .38924 Mdot
.61896 .34589 Mdot
.58961 .34448 Mdot
.65644 .36622 Mdot
.32916 .4982 Mdot
.55695 .30668 Mdot
.82109 .52908 Mdot
.45077 .40789 Mdot
.40673 .35376 Mdot
.6478 .59489 Mdot
.32498 .52304 Mdot
.27923 .51609 Mdot
.44396 .38848 Mdot
.72619 .41526 Mdot
.56781 .63855 Mdot
.59624 .38954 Mdot
.60849 .36271 Mdot
.64287 .39922 Mdot
.64992 .40682 Mdot
.76606 .37552 Mdot
.45628 .36739 Mdot
.60596 .37288 Mdot
.59828 .60138 Mdot
.57586 .6151 Mdot
.38028 .28486 Mdot
.4587 .66691 Mdot
.54779 .57039 Mdot
.54437 .58937 Mdot
.5738 .59166 Mdot
.34456 .52923 Mdot
.62283 .51302 Mdot
.38939 .27724 Mdot
.29464 .48581 Mdot
.3491 .48839 Mdot
.3644 .27161 Mdot
.679 .40699 Mdot
.22681 .69139 Mdot
.64184 .61662 Mdot
.52764 .66037 Mdot
.32192 .51925 Mdot
.61964 .2697 Mdot
.59898 .46244 Mdot
.62857 .62035 Mdot
.49924 .53229 Mdot
.34839 .50724 Mdot
.59962 .41422 Mdot
.5703 .57197 Mdot
.37202 .25606 Mdot
.45436 .63997 Mdot
.61605 .52373 Mdot
.39556 .28037 Mdot
.6202 .39274 Mdot
.41415 .61213 Mdot
.62815 .42388 Mdot
.35563 .52262 Mdot
.61606 .6576 Mdot
.13421 .35964 Mdot
.2996 .49707 Mdot
.19849 .50926 Mdot
.6501 .30265 Mdot
.60211 .55404 Mdot
.30448 .49375 Mdot
.59469 .40679 Mdot
.40948 .41344 Mdot
.43122 .50837 Mdot
.61379 .35939 Mdot
.37107 .28589 Mdot
.37335 .28188 Mdot
.3443 .51754 Mdot
.64419 .3552 Mdot
.61174 .63946 Mdot
.63539 .41229 Mdot
.428 .35691 Mdot
.62807 .60746 Mdot
.21358 .64986 Mdot
.53277 .57897 Mdot
.60687 .3886 Mdot
.271 .51218 Mdot
.40905 .66577 Mdot
.61686 .6117 Mdot
.20417 .54263 Mdot
.56019 .58656 Mdot
.43391 .41604 Mdot
.61251 .2508 Mdot
.70227 .45802 Mdot
.60164 .62316 Mdot
.6452 .58692 Mdot
.44766 .41643 Mdot
.60283 .62504 Mdot
.55915 .58016 Mdot
.43352 .43985 Mdot
.65186 .39114 Mdot
.59698 .57934 Mdot
.29011 .52928 Mdot
.75906 .6398 Mdot
.59465 .54043 Mdot
.51724 .20487 Mdot
.56242 .74166 Mdot
.62542 .25646 Mdot
.60286 .53985 Mdot
.62515 .74539 Mdot
.6059 .56977 Mdot
.60905 .60896 Mdot
.63659 .61989 Mdot
.73065 .56642 Mdot
.33103 .52435 Mdot
.32519 .54261 Mdot
.40865 .6436 Mdot
.55875 .74329 Mdot
.45515 .6555 Mdot
.43213 .42286 Mdot
.29392 .30581 Mdot
.38858 .2678 Mdot
.61211 .38544 Mdot
.64339 .57319 Mdot
.35607 .52879 Mdot
.56988 .58455 Mdot
.63594 .58375 Mdot
.35236 .51501 Mdot
.29601 .49617 Mdot
.28559 .48498 Mdot
.41077 .65106 Mdot
.62322 .38239 Mdot
.61408 .63135 Mdot
.42014 .64639 Mdot
.60934 .64135 Mdot
.41851 .48907 Mdot
.62475 .38447 Mdot
.6378 .41119 Mdot
.60071 .36258 Mdot
.59437 .62434 Mdot
.63035 .58425 Mdot
.42687 .40068 Mdot
.66442 .39047 Mdot
.45853 .39545 Mdot
.31137 .49377 Mdot
.3574 .51328 Mdot
.56565 .59223 Mdot
.56942 .664 Mdot
.44037 .67564 Mdot
.31187 .50524 Mdot
.36667 .25279 Mdot
.41348 .64038 Mdot
.61545 .59805 Mdot
.31746 .49435 Mdot
.46304 .66381 Mdot
.74823 .43333 Mdot
.29299 .75155 Mdot
.40787 .66923 Mdot
.5957 .60816 Mdot
.75444 .60272 Mdot
.52564 .68226 Mdot
.46396 .67648 Mdot
.45075 .40482 Mdot
.56109 .59211 Mdot
.4258 .78138 Mdot
.46034 .67439 Mdot
.80421 .59335 Mdot
.35031 .52152 Mdot
.50775 .57507 Mdot
.6021 .52105 Mdot
.73362 .37124 Mdot
.46832 .66478 Mdot
.62287 .365 Mdot
.66397 .39779 Mdot
.59119 .60201 Mdot
.47455 .63999 Mdot
.40377 .36621 Mdot
.35195 .52767 Mdot
.36488 .52094 Mdot
.64772 .3615 Mdot
.52141 .35383 Mdot
.28114 .52395 Mdot
.66782 .64194 Mdot
.38878 .51297 Mdot
.57165 .50829 Mdot
.73667 .31765 Mdot
.45081 .23034 Mdot
.63567 .54952 Mdot
.4123 .67375 Mdot
.46335 .39505 Mdot
.42525 .39841 Mdot
.4187 .3886 Mdot
.35259 .49983 Mdot
.48169 .47758 Mdot
.30187 .52662 Mdot
.51982 .2465 Mdot
.42267 .66057 Mdot
.54093 .71909 Mdot
.61565 .54412 Mdot
.60514 .55491 Mdot
.59973 .64112 Mdot
.65153 .59582 Mdot
.60438 .5691 Mdot
.42588 .37027 Mdot
.34319 .49007 Mdot
.36467 .64151 Mdot
.63679 .39904 Mdot
.24093 .37326 Mdot
.31867 .52442 Mdot
.39421 .27886 Mdot
.44201 .65816 Mdot
.65511 .72481 Mdot
.37661 .50343 Mdot
.31315 .52168 Mdot
.56957 .62427 Mdot
.60993 .40834 Mdot
.56569 .49549 Mdot
.61046 .56748 Mdot
.30979 .50544 Mdot
.26613 .52621 Mdot
.69567 .42561 Mdot
.68384 .58181 Mdot
.40254 .68498 Mdot
.43559 .48438 Mdot
.4723 .65106 Mdot
.563 .53363 Mdot
.61636 .26951 Mdot
.33558 .52444 Mdot
.32514 .50507 Mdot
.42038 .68178 Mdot
.59793 .68409 Mdot
.63866 .35344 Mdot
.36233 .27101 Mdot
.44095 .4118 Mdot
.6153 .5696 Mdot
.3472 .49721 Mdot
.52448 .65238 Mdot
.39394 .55813 Mdot
.4217 .37873 Mdot
.29605 .48505 Mdot
.56679 .61111 Mdot
.59374 .61065 Mdot
.43049 .67253 Mdot
.43136 .58954 Mdot
.61484 .52558 Mdot
.17638 .4933 Mdot
.54813 .32936 Mdot
.55415 .35142 Mdot
.57448 .58617 Mdot
.65155 .36791 Mdot
.36952 .25725 Mdot
.41522 .6589 Mdot
.59445 .63678 Mdot
.26695 .73464 Mdot
.66239 .34653 Mdot
.43444 .37323 Mdot
.36733 .25776 Mdot
.48054 .47976 Mdot
.5605 .58319 Mdot
.56637 .57617 Mdot
.60571 .60103 Mdot
.28976 .75832 Mdot
.31172 .5391 Mdot
.64166 .41499 Mdot
.43608 .64709 Mdot
.65645 .38917 Mdot
.3332 .54206 Mdot
.55014 .43352 Mdot
.61915 .59577 Mdot
.59516 .38111 Mdot
.62461 .36289 Mdot
.41622 .41171 Mdot
.4035 .40469 Mdot
.30481 .47552 Mdot
.59355 .55096 Mdot
.37827 .25724 Mdot
.61157 .41367 Mdot
.30919 .48542 Mdot
.428 .67118 Mdot
.41049 .37786 Mdot
.58437 .61499 Mdot
.34012 .52056 Mdot
.65802 .59153 Mdot
.63439 .40902 Mdot
.31416 .52181 Mdot
.39323 .26385 Mdot
.44544 .67558 Mdot
.58596 .61882 Mdot
.39132 .63034 Mdot
.36309 .26374 Mdot
.61679 .55526 Mdot
.70654 .65683 Mdot
.42749 .62607 Mdot
.46564 .22067 Mdot
.29243 .51964 Mdot
.38419 .27605 Mdot
.62664 .4179 Mdot
.54555 .48463 Mdot
.32745 .50353 Mdot
.70499 .62786 Mdot
.45023 .57305 Mdot
.61363 .63038 Mdot
.64383 .37979 Mdot
.40809 .70121 Mdot
.16779 .52595 Mdot
.50436 .68552 Mdot
.59428 .57006 Mdot
.30629 .49308 Mdot
.46419 .65557 Mdot
.44648 .41336 Mdot
.5199 .20556 Mdot
.73548 .324 Mdot
.29758 .48248 Mdot
.64079 .61995 Mdot
.61163 .41334 Mdot
.44405 .38625 Mdot
.43125 .25571 Mdot
.28434 .4973 Mdot
.29322 .52706 Mdot
.61481 .60501 Mdot
.42546 .64805 Mdot
.3833 .73072 Mdot
.3223 .54326 Mdot
.33831 .49099 Mdot
.23292 .37986 Mdot
.40405 .67137 Mdot
.59616 .59863 Mdot
.58926 .34479 Mdot
.57645 .62672 Mdot
.18649 .49044 Mdot
.38717 .27382 Mdot
.63421 .40082 Mdot
.56841 .60626 Mdot
.37711 .63059 Mdot
.32146 .49884 Mdot
.44629 .47975 Mdot
.26617 .50721 Mdot
.42953 .36746 Mdot
.34889 .49906 Mdot
.57086 .57473 Mdot
.432 .43001 Mdot
.44338 .67483 Mdot
.60003 .54949 Mdot
.63149 .58562 Mdot
.59228 .39776 Mdot
.45173 .3741 Mdot
.72095 .68002 Mdot
.39379 .39866 Mdot
.45449 .40786 Mdot
.62821 .42895 Mdot
.59002 .59851 Mdot
.31388 .50909 Mdot
.29508 .53701 Mdot
.60696 .63601 Mdot
.62167 .27334 Mdot
.64306 .35759 Mdot
.33325 .47457 Mdot
.37223 .81912 Mdot
.68028 .61107 Mdot
.381 .2556 Mdot
.62437 .70127 Mdot
.41024 .40973 Mdot
.59124 .61447 Mdot
.60997 .39239 Mdot
.32776 .48653 Mdot
.28292 .52537 Mdot
.58715 .63765 Mdot
.44673 .37932 Mdot
.46415 .64847 Mdot
.28436 .51982 Mdot
.39134 .55674 Mdot
.60816 .5913 Mdot
.52284 .23604 Mdot
.28583 .51575 Mdot
.17268 .41707 Mdot
.37142 .63398 Mdot
.64489 .38833 Mdot
.6386 .58846 Mdot
.65822 .35669 Mdot
.44206 .64815 Mdot
.36329 .54502 Mdot
.44687 .3761 Mdot
.68541 .63534 Mdot
.73663 .71451 Mdot
.32726 .52631 Mdot
.61773 .3881 Mdot
.59708 .62484 Mdot
.6776 .64148 Mdot
.58463 .5542 Mdot
.51765 .53946 Mdot
.40623 .62746 Mdot
.40243 .39521 Mdot
.43284 .41807 Mdot
.63918 .57426 Mdot
.4161 .6446 Mdot
.32898 .54738 Mdot
.35078 .51939 Mdot
.70087 .20958 Mdot
.39455 .26651 Mdot
.53158 .77649 Mdot
.58998 .62051 Mdot
.31615 .48344 Mdot
.75625 .61875 Mdot
.45669 .37419 Mdot
.64563 .62626 Mdot
.35671 .4957 Mdot
.23061 .44654 Mdot
.42184 .491 Mdot
.60183 .58069 Mdot
.67074 .62421 Mdot
.43907 .41428 Mdot
.40388 .50481 Mdot
.3018 .52521 Mdot
.62714 .64094 Mdot
.39643 .4059 Mdot
.21407 .40221 Mdot
.77301 .68236 Mdot
.62375 .38246 Mdot
.26872 .51647 Mdot
.42893 .3682 Mdot
.65867 .54802 Mdot
.46056 .65208 Mdot
.33 .49144 Mdot
.34314 .53438 Mdot
.63344 .60441 Mdot
.55111 .5629 Mdot
.68067 .6135 Mdot
.63024 .39347 Mdot
.43228 .40391 Mdot
.62399 .552 Mdot
.52645 .35377 Mdot
.65072 .60418 Mdot
.43495 .40143 Mdot
.30396 .183 Mdot
.55838 .60517 Mdot
.58302 .5575 Mdot
.41506 .72857 Mdot
.62414 .3471 Mdot
.65671 .3799 Mdot
.55255 .31722 Mdot
.5896 .62041 Mdot
.35865 .58567 Mdot
.62083 .38057 Mdot
.6442 .36117 Mdot
.30123 .61622 Mdot
.62759 .61158 Mdot
.39607 .48785 Mdot
.43841 .39433 Mdot
.4229 .36928 Mdot
.64653 .40291 Mdot
.64503 .53543 Mdot
.46381 .38287 Mdot
.70991 .33754 Mdot
.31775 .5272 Mdot
.6159 .26903 Mdot
.62073 .41105 Mdot
.42372 .57945 Mdot
.44624 .36775 Mdot
.14297 .51213 Mdot
.51056 .49875 Mdot
.64231 .62422 Mdot
.59735 .61681 Mdot
.45238 .66655 Mdot
.57038 .65415 Mdot
.38516 .28845 Mdot
.42178 .39363 Mdot
.2949 .69371 Mdot
.63169 .38401 Mdot
.58815 .55573 Mdot
.66311 .71746 Mdot
.45064 .26333 Mdot
.54644 .21446 Mdot
.62545 .3527 Mdot
.64028 .37796 Mdot
.31197 .53233 Mdot
.33023 .5336 Mdot
.59679 .58952 Mdot
.41685 .39641 Mdot
.65386 .41206 Mdot
.43918 .40673 Mdot
.33615 .5254 Mdot
.31431 .51779 Mdot
.39141 .2752 Mdot
.66515 .61194 Mdot
.35389 .52052 Mdot
.20851 .4211 Mdot
.52429 .36074 Mdot
.58951 .39553 Mdot
.66328 .79491 Mdot
.42708 .2539 Mdot
.4293 .74586 Mdot
.44569 .63622 Mdot
.39733 .26272 Mdot
.41058 .36459 Mdot
.64177 .57987 Mdot
.5723 .60305 Mdot
.37187 .27472 Mdot
.4294 .36174 Mdot
.44619 .66143 Mdot
.43702 .36056 Mdot
.41959 .65556 Mdot
.35595 .53836 Mdot
.59447 .54066 Mdot
.5648 .56957 Mdot
.42142 .37476 Mdot
.30305 .51439 Mdot
.35338 .52446 Mdot
.4215 .63774 Mdot
.64027 .72531 Mdot
.34412 .51898 Mdot
.62306 .41172 Mdot
.80923 .48369 Mdot
.37281 .28059 Mdot
.57218 .56946 Mdot
.6666 .72194 Mdot
.71317 .40394 Mdot
.62333 .6296 Mdot
.36609 .25851 Mdot
.72296 .23382 Mdot
.60611 .54407 Mdot
.71979 .24984 Mdot
.38528 .27976 Mdot
.63127 .34345 Mdot
.2947 .50547 Mdot
.38353 .28978 Mdot
.64719 .53324 Mdot
.45214 .68778 Mdot
.54592 .56796 Mdot
.61652 .35549 Mdot
.60138 .35588 Mdot
.61768 .29649 Mdot
.1881 .49234 Mdot
.41139 .66271 Mdot
.43899 .66449 Mdot
.3318 .50494 Mdot
.32773 .25262 Mdot
.59124 .52488 Mdot
.44013 .66649 Mdot
.33494 .72208 Mdot
.64746 .59859 Mdot
.56697 .76887 Mdot
.49815 .53077 Mdot
.65069 .36658 Mdot
.687 .3505 Mdot
.32608 .50129 Mdot
.61815 .38766 Mdot
.5409 .39188 Mdot
.59869 .6406 Mdot
.62723 .38496 Mdot
.43877 .40001 Mdot
.31972 .42733 Mdot
.65445 .35475 Mdot
.42076 .51858 Mdot
.43683 .39346 Mdot
.43535 .62549 Mdot
.47293 .72064 Mdot
.48874 .8818 Mdot
.42026 .39428 Mdot
.30241 .50416 Mdot
.35512 .52043 Mdot
.34737 .51423 Mdot
.61346 .3592 Mdot
.28054 .50577 Mdot
.62814 .39925 Mdot
.23671 .5675 Mdot
.64129 .73951 Mdot
.42672 .66734 Mdot
.45404 .44085 Mdot
.63303 .36725 Mdot
.53657 .27671 Mdot
.68523 .77709 Mdot
.5976 .60888 Mdot
.39482 .40224 Mdot
.42378 .68237 Mdot
.28917 .26113 Mdot
.45274 .66359 Mdot
.29793 .50598 Mdot
.61448 .26785 Mdot
.58272 .56846 Mdot
.70075 .56152 Mdot
.43567 .67832 Mdot
.62099 .35441 Mdot
.61312 .55409 Mdot
.26541 .49144 Mdot
.45409 .64751 Mdot
.45534 .64108 Mdot
.60186 .56643 Mdot
.65004 .35487 Mdot
.3125 .51391 Mdot
.40744 .37074 Mdot
.39455 .65278 Mdot
.6638 .57002 Mdot
.60936 .62656 Mdot
.63805 .63952 Mdot
.47333 .46615 Mdot
.3968 .75602 Mdot
.42858 .39284 Mdot
.56449 .6987 Mdot
.33795 .53006 Mdot
.49263 .68377 Mdot
.51818 .30254 Mdot
.44916 .44051 Mdot
.38721 .27499 Mdot
.38777 .27148 Mdot
.60221 .57599 Mdot
.38579 .75339 Mdot
.60843 .22189 Mdot
.4001 .43172 Mdot
.36761 .27348 Mdot
.35261 .52519 Mdot
.66832 .37156 Mdot
.59997 .30832 Mdot
.55574 .56035 Mdot
.40349 .40035 Mdot
.3437 .52265 Mdot
.31413 .73958 Mdot
.42508 .65923 Mdot
.56991 .28865 Mdot
.62013 .59096 Mdot
.59098 .56463 Mdot
.43613 .38443 Mdot
.42701 .40016 Mdot
.5144 .21799 Mdot
.56976 .31535 Mdot
.24612 .48926 Mdot
.38129 .43135 Mdot
.34113 .75998 Mdot
.64495 .31959 Mdot
.6083 .39271 Mdot
.39315 .27085 Mdot
.45625 .40817 Mdot
.56881 .57022 Mdot
.62655 .34356 Mdot
.5517 .21427 Mdot
.65008 .42647 Mdot
.56499 .76312 Mdot
.37032 .58583 Mdot
.62348 .57712 Mdot
.61268 .41145 Mdot
.62023 .38703 Mdot
.65783 .3924 Mdot
.36425 .26918 Mdot
.57632 .58983 Mdot
.60667 .62406 Mdot
.61557 .54974 Mdot
.61007 .66649 Mdot
.60801 .58802 Mdot
.51566 .3144 Mdot
.50317 .37504 Mdot
.27983 .67196 Mdot
.62747 .62969 Mdot
.43573 .36349 Mdot
.64479 .57358 Mdot
.4206 .64167 Mdot
.64031 .62119 Mdot
.549 .77342 Mdot
.42452 .38344 Mdot
.61037 .68533 Mdot
.37698 .41783 Mdot
.62122 .59066 Mdot
.46562 .66252 Mdot
.3923 .75004 Mdot
.71497 .70788 Mdot
.22829 .38881 Mdot
.6252 .41217 Mdot
.35469 .48577 Mdot
.43368 .35597 Mdot
.31599 .50888 Mdot
.63457 .6333 Mdot
.38697 .25975 Mdot
.3862 .23095 Mdot
.42771 .56822 Mdot
.56362 .58162 Mdot
.54096 .54297 Mdot
.65017 .38386 Mdot
.31187 .49633 Mdot
.6672 .33744 Mdot
.60792 .60609 Mdot
.43976 .64577 Mdot
.43231 .64365 Mdot
.55285 .34122 Mdot
.25191 .67528 Mdot
.55163 .4902 Mdot
.43498 .38674 Mdot
.27935 .5244 Mdot
.46713 .66668 Mdot
.69182 .30441 Mdot
.40261 .36693 Mdot
.41006 .40938 Mdot
.45285 .38135 Mdot
.62081 .5716 Mdot
.38925 .28216 Mdot
.30343 .7113 Mdot
.37457 .28827 Mdot
.62416 .58838 Mdot
.33539 .53719 Mdot
.38507 .29021 Mdot
.45598 .66124 Mdot
.44269 .4181 Mdot
.33023 .5311 Mdot
.60894 .57867 Mdot
.62445 .37682 Mdot
.64127 .7108 Mdot
.48408 .79233 Mdot
.24183 .5977 Mdot
.24593 .60579 Mdot
.60323 .36365 Mdot
.18433 .58329 Mdot
.48024 .41802 Mdot
.72478 .41278 Mdot
.42127 .6958 Mdot
.60978 .63651 Mdot
.82 .40053 Mdot
.2992 .52278 Mdot
.33822 .50035 Mdot
.60172 .5851 Mdot
.30294 .48962 Mdot
.5871 .55496 Mdot
.3122 .53492 Mdot
.22035 .48991 Mdot
.56409 .5546 Mdot
.33578 .50003 Mdot
.58382 .5245 Mdot
.61986 .60642 Mdot
.65207 .3772 Mdot
.32787 .48937 Mdot
.64812 .61741 Mdot
.33558 .22211 Mdot
.41014 .39363 Mdot
.36548 .27364 Mdot
.49471 .39302 Mdot
.44649 .36502 Mdot
.639 .3891 Mdot
.57553 .54428 Mdot
.4336 .67445 Mdot
.62364 .36805 Mdot
.30113 .47686 Mdot
.43183 .67947 Mdot
.5533 .30999 Mdot
.63021 .41188 Mdot
.37611 .28136 Mdot
.43765 .67649 Mdot
.5415 .60545 Mdot
.3502 .50478 Mdot
.50141 .80592 Mdot
.37317 .28657 Mdot
.57458 .57576 Mdot
.34864 .54834 Mdot
.44068 .36223 Mdot
.59129 .58354 Mdot
.30437 .49285 Mdot
.36374 .265 Mdot
.62717 .57122 Mdot
.62087 .55972 Mdot
.57718 .32841 Mdot
.58369 .23515 Mdot
.43258 .67191 Mdot
.60205 .41222 Mdot
.59889 .59979 Mdot
.41285 .64652 Mdot
.32269 .32976 Mdot
.64262 .56274 Mdot
.65407 .34896 Mdot
.67832 .53361 Mdot
.33146 .53443 Mdot
.45681 .39939 Mdot
.27571 .52492 Mdot
.45493 .63971 Mdot
.86462 .56219 Mdot
.39194 .28236 Mdot
.61951 .51792 Mdot
.61195 .64437 Mdot
.28222 .53966 Mdot
.624 .38887 Mdot
.2986 .45236 Mdot
.58718 .61903 Mdot
.53275 .56182 Mdot
.58932 .56062 Mdot
.37012 .631 Mdot
.64094 .35605 Mdot
.57885 .56293 Mdot
.53412 .63913 Mdot
.59551 .53835 Mdot
.46646 .65537 Mdot
.51751 .71334 Mdot
.6472 .57499 Mdot
.10683 .42154 Mdot
.36552 .2555 Mdot
.35154 .51428 Mdot
.35177 .56197 Mdot
.37236 .33636 Mdot
.73885 .31787 Mdot
.62893 .39665 Mdot
.61592 .49519 Mdot
.31384 .51144 Mdot
.77382 .66258 Mdot
.17991 .5546 Mdot
.62145 .60217 Mdot
.56797 .61164 Mdot
.29795 .50593 Mdot
.31547 .48407 Mdot
.38742 .26238 Mdot
.63102 .63017 Mdot
.56693 .52361 Mdot
.28349 .49524 Mdot
.61432 .58241 Mdot
.65072 .47413 Mdot
.40292 .38499 Mdot
.65364 .39162 Mdot
.44699 .413 Mdot
.40759 .40321 Mdot
.78155 .42904 Mdot
.54895 .32856 Mdot
.43217 .40182 Mdot
.39069 .3922 Mdot
.55375 .77625 Mdot
.6948 .56638 Mdot
.46927 .65491 Mdot
.22401 .61648 Mdot
.34088 .51002 Mdot
.57731 .5921 Mdot
.60264 .37456 Mdot
.74501 .38343 Mdot
.28493 .40945 Mdot
.59971 .26512 Mdot
.60262 .6183 Mdot
.33237 .50218 Mdot
.36449 .27408 Mdot
.56303 .55409 Mdot
.4969 .67978 Mdot
.59203 .56734 Mdot
.35662 .52365 Mdot
.80495 .44092 Mdot
.69441 .55391 Mdot
.39431 .50504 Mdot
.59084 .41418 Mdot
.62211 .54855 Mdot
.62482 .40795 Mdot
.43821 .3674 Mdot
.41247 .64895 Mdot
.44045 .67031 Mdot
.6108 .55538 Mdot
.65876 .30038 Mdot
.49645 .54879 Mdot
.61809 .60789 Mdot
.63144 .60701 Mdot
.385 .2776 Mdot
.63055 .6072 Mdot
.61218 .64349 Mdot
.63677 .56615 Mdot
.64949 .56135 Mdot
.45474 .40792 Mdot
.71176 .64481 Mdot
.65397 .57786 Mdot
.67991 .5765 Mdot
.40502 .38783 Mdot
.60704 .50312 Mdot
.4192 .41152 Mdot
.22032 .65457 Mdot
.42929 .41193 Mdot
.43631 .67008 Mdot
.35635 .54418 Mdot
.56137 .50994 Mdot
.64925 .41571 Mdot
.40601 .41249 Mdot
.43255 .65365 Mdot
.41955 .39153 Mdot
.30041 .53573 Mdot
.61825 .8058 Mdot
.6522 .42447 Mdot
.41162 .49733 Mdot
.51569 .51259 Mdot
.52208 .23413 Mdot
.31831 .53052 Mdot
.64857 .3656 Mdot
.68478 .53407 Mdot
.63489 .56545 Mdot
.44727 .67341 Mdot
.60133 .57403 Mdot
.45134 .412 Mdot
.33875 .50614 Mdot
.27099 .6244 Mdot
.4368 .67256 Mdot
.76633 .70478 Mdot
.34901 .53476 Mdot
.55398 .59245 Mdot
.40253 .40043 Mdot
.66846 .79043 Mdot
.43019 .41319 Mdot
.64885 .73625 Mdot
.62226 .33171 Mdot
.82044 .45774 Mdot
.64028 .37212 Mdot
.55137 .20469 Mdot
.21779 .70738 Mdot
.19007 .54173 Mdot
.61688 .37229 Mdot
.36836 .48396 Mdot
.61706 .58952 Mdot
.65217 .58921 Mdot
.67679 .62934 Mdot
.59466 .41058 Mdot
.60175 .59788 Mdot
.38207 .28728 Mdot
.52196 .37517 Mdot
.361 .70539 Mdot
.36529 .4921 Mdot
.58125 .55648 Mdot
.40596 .39287 Mdot
.45717 .36427 Mdot
.3815 .29058 Mdot
.40628 .36489 Mdot
.61967 .61185 Mdot
.63559 .36818 Mdot
.44557 .56238 Mdot
.44943 .65118 Mdot
.2191 .33542 Mdot
.39923 .64756 Mdot
.35439 .48351 Mdot
.6263 .65392 Mdot
.31407 .51857 Mdot
.8626 .42829 Mdot
.64624 .58479 Mdot
.6183 .38128 Mdot
.62044 .56233 Mdot
.63154 .55799 Mdot
.65401 .59799 Mdot
.27883 .50421 Mdot
.32363 .56309 Mdot
.61385 .57936 Mdot
.44761 .37569 Mdot
.27061 .63914 Mdot
.54531 .58068 Mdot
.31103 .46961 Mdot
.54991 .752 Mdot
.52518 .24759 Mdot
.58814 .39759 Mdot
.30673 .50038 Mdot
.63519 .38185 Mdot
.60761 .42553 Mdot
.63893 .3893 Mdot
.27719 .68716 Mdot
.52622 .53683 Mdot
.69139 .22006 Mdot
.80404 .53676 Mdot
.74185 .40242 Mdot
.59643 .38055 Mdot
.32653 .36448 Mdot
.60881 .3874 Mdot
.63348 .39462 Mdot
.46945 .1151 Mdot
.6065 .37801 Mdot
.56639 .59362 Mdot
.55849 .60838 Mdot
.47737 .2956 Mdot
.57753 .77695 Mdot
.63612 .62449 Mdot
.59942 .59464 Mdot
.41157 .65688 Mdot
.58499 .673 Mdot
.39032 .29584 Mdot
.59176 .28537 Mdot
.40173 .26341 Mdot
.60242 .56735 Mdot
.6023 .59083 Mdot
.65291 .54966 Mdot
.22443 .72199 Mdot
.74283 .36496 Mdot
.60574 .35262 Mdot
.55065 .52709 Mdot
.18283 .44005 Mdot
.55916 .60252 Mdot
.56753 .5629 Mdot
.6318 .57799 Mdot
.31369 .50993 Mdot
.66816 .36227 Mdot
.53704 .55613 Mdot
.50145 .25646 Mdot
.61687 .59606 Mdot
.47785 .41751 Mdot
.3953 .64368 Mdot
.56945 .57721 Mdot
.65789 .38622 Mdot
.6433 .61202 Mdot
.61529 .41063 Mdot
.64987 .39843 Mdot
.66632 .589 Mdot
.289 .70324 Mdot
.66356 .37007 Mdot
.6275 .58457 Mdot
.30446 .51033 Mdot
.17098 .52462 Mdot
.57279 .57763 Mdot
.41556 .65419 Mdot
.59409 .61853 Mdot
.46554 .65597 Mdot
.6295 .59699 Mdot
.3715 .286 Mdot
.69263 .46321 Mdot
.32745 .50561 Mdot
.39101 .68169 Mdot
.30057 .48782 Mdot
.56047 .36852 Mdot
.63922 .34196 Mdot
.39283 .29691 Mdot
.71775 .28225 Mdot
.38406 .27827 Mdot
.64253 .70881 Mdot
.27816 .37625 Mdot
.41069 .38648 Mdot
.64632 .40983 Mdot
.57118 .69353 Mdot
.33247 .46949 Mdot
.29643 .48046 Mdot
.34012 .48455 Mdot
.86661 .50598 Mdot
.78023 .32999 Mdot
.61361 .57283 Mdot
.49996 .81774 Mdot
.73072 .52312 Mdot
.62328 .53902 Mdot
.59474 .53262 Mdot
.35756 .5245 Mdot
.61408 .5443 Mdot
.47069 .48937 Mdot
.33073 .52179 Mdot
.43605 .65804 Mdot
.63205 .40207 Mdot
.46149 .64987 Mdot
.26587 .4757 Mdot
.51197 .3836 Mdot
.33607 .52874 Mdot
.64503 .55973 Mdot
.61299 .56302 Mdot
.62702 .41577 Mdot
.57987 .41963 Mdot
.65333 .38863 Mdot
.42679 .68129 Mdot
.33287 .51479 Mdot
.73381 .36199 Mdot
.58783 .61211 Mdot
.62599 .36125 Mdot
.42076 .32991 Mdot
.59372 .61132 Mdot
.42535 .37221 Mdot
.6046 .62048 Mdot
.61449 .36813 Mdot
.6303 .60663 Mdot
.63676 .37046 Mdot
.30159 .52112 Mdot
.56417 .61069 Mdot
.59997 .58829 Mdot
.73288 .68964 Mdot
.4469 .66051 Mdot
.63657 .34204 Mdot
.49792 .47847 Mdot
.56967 .62081 Mdot
.49203 .67837 Mdot
.59755 .54135 Mdot
.64055 .50419 Mdot
.58409 .52317 Mdot
.38172 .28613 Mdot
.65523 .61358 Mdot
.57377 .57539 Mdot
.71552 .62649 Mdot
.77191 .58744 Mdot
.67944 .35872 Mdot
.42562 .42634 Mdot
.65754 .38635 Mdot
.35667 .51052 Mdot
.34016 .48963 Mdot
.28123 .51253 Mdot
.60745 .76845 Mdot
.65096 .54171 Mdot
.58176 .57017 Mdot
.40194 .40652 Mdot
.43593 .66481 Mdot
.62257 .35605 Mdot
.42979 .66516 Mdot
.59726 .28432 Mdot
.43345 .68143 Mdot
.38707 .28753 Mdot
.37173 .63453 Mdot
.70569 .38597 Mdot
.41343 .66345 Mdot
.65364 .38875 Mdot
.38282 .58334 Mdot
.6165 .63664 Mdot
.21593 .44096 Mdot
.4382 .64557 Mdot
.85341 .56894 Mdot
.59137 .54384 Mdot
.44282 .49935 Mdot
.41297 .40308 Mdot
.46223 .6598 Mdot
.45156 .37219 Mdot
.64921 .60098 Mdot
.46861 .21804 Mdot
.61482 .3866 Mdot
.42811 .4306 Mdot
.65581 .60798 Mdot
.46193 .6522 Mdot
.34616 .5259 Mdot
.54023 .4704 Mdot
.42954 .36574 Mdot
.69963 .71119 Mdot
.50414 .6854 Mdot
.33211 .51623 Mdot
.6217 .20736 Mdot
.45409 .39268 Mdot
.63585 .54806 Mdot
.58936 .48618 Mdot
.6299 .62206 Mdot
.35729 .50498 Mdot
.3163 .49497 Mdot
.48944 .33068 Mdot
.61841 .56281 Mdot
.593 .54311 Mdot
.66825 .35108 Mdot
.32476 .52505 Mdot
.64664 .3763 Mdot
.64675 .41265 Mdot
.30008 .50724 Mdot
.64556 .38629 Mdot
.43853 .67832 Mdot
.52066 .38024 Mdot
.45309 .39596 Mdot
.4414 .37377 Mdot
.35227 .52266 Mdot
.3168 .54323 Mdot
.31516 .52048 Mdot
.60577 .61954 Mdot
.63442 .34934 Mdot
.64041 .59578 Mdot
.64749 .57357 Mdot
.61438 .33292 Mdot
.61085 .35688 Mdot
.64431 .59596 Mdot
.39229 .58693 Mdot
.39638 .66881 Mdot
.33313 .49942 Mdot
.43735 .40616 Mdot
.77479 .65204 Mdot
.40084 .40147 Mdot
.58642 .55002 Mdot
.22722 .44804 Mdot
.61853 .35516 Mdot
.45326 .66414 Mdot
.47887 .6403 Mdot
.44721 .67126 Mdot
.43238 .43164 Mdot
.65603 .40356 Mdot
.5506 .31328 Mdot
.58817 .55106 Mdot
.47549 .46483 Mdot
.57178 .69814 Mdot
.51738 .29063 Mdot
.43556 .40203 Mdot
.59661 .60449 Mdot
.38295 .27949 Mdot
.697 .4211 Mdot
.59037 .57075 Mdot
.64429 .62676 Mdot
.34444 .61164 Mdot
.68145 .58387 Mdot
.59081 .39239 Mdot
.60991 .29861 Mdot
.5885 .63325 Mdot
.65253 .31548 Mdot
.60292 .14012 Mdot
.59658 .54451 Mdot
.6083 .59809 Mdot
.57321 .59713 Mdot
.64207 .58242 Mdot
.60586 .34137 Mdot
.40798 .59335 Mdot
.40424 .4041 Mdot
.49948 .42807 Mdot
.4508 .39319 Mdot
.34448 .50069 Mdot
.44726 .50135 Mdot
.64892 .40558 Mdot
.4498 .66993 Mdot
.58552 .81398 Mdot
.616 .28557 Mdot
.31219 .53199 Mdot
.75868 .37298 Mdot
.44721 .64815 Mdot
.60939 .63596 Mdot
.40447 .64784 Mdot
.32111 .48318 Mdot
.44552 .3855 Mdot
.56304 .61578 Mdot
.60072 .38275 Mdot
.65518 .35511 Mdot
.59875 .60619 Mdot
.17756 .47774 Mdot
.44702 .36639 Mdot
.46744 .34352 Mdot
.62191 .57339 Mdot
.64289 .62827 Mdot
.64561 .39763 Mdot
.31838 .49748 Mdot
.28473 .33983 Mdot
.44146 .65559 Mdot
.6518 .55773 Mdot
.64738 .60655 Mdot
.59107 .29168 Mdot
.43766 .42115 Mdot
.37379 .25986 Mdot
.62149 .5696 Mdot
.55275 .32394 Mdot
.623 .56944 Mdot
.55532 .64631 Mdot
.30859 .5164 Mdot
.57538 .63543 Mdot
.57956 .62187 Mdot
.58546 .68924 Mdot
.45633 .38771 Mdot
.62248 .38479 Mdot
.6502 .33373 Mdot
.37202 .25592 Mdot
.42156 .37628 Mdot
.64533 .60167 Mdot
.45532 .40382 Mdot
.6538 .59493 Mdot
.61135 .58136 Mdot
.43637 .40152 Mdot
.64681 .37726 Mdot
.30909 .44691 Mdot
.70261 .64617 Mdot
.63366 .57204 Mdot
.60671 .62804 Mdot
.59066 .77214 Mdot
.68604 .2568 Mdot
.58265 .62082 Mdot
.6227 .3494 Mdot
.59252 .60756 Mdot
.43492 .37031 Mdot
.43274 .68256 Mdot
.6198 .37646 Mdot
.33248 .54524 Mdot
.29876 .51912 Mdot
.37644 .40869 Mdot
.38992 .28521 Mdot
.59837 .62965 Mdot
.66706 .41523 Mdot
.60627 .36311 Mdot
.34682 .23172 Mdot
.3517 .51201 Mdot
.46333 .67009 Mdot
.62509 .56173 Mdot
.53311 .47622 Mdot
.40898 .41195 Mdot
.10634 .42411 Mdot
.5404 .32237 Mdot
.43764 .63141 Mdot
.63045 .25975 Mdot
.3782 .27862 Mdot
.56216 .58641 Mdot
.41892 .64145 Mdot
.29134 .52069 Mdot
.65149 .5907 Mdot
.67473 .58766 Mdot
.37174 .45474 Mdot
.37155 .50653 Mdot
.45767 .39866 Mdot
.30136 .53336 Mdot
.4441 .63382 Mdot
.38625 .28801 Mdot
.65383 .36411 Mdot
.57748 .56864 Mdot
.53709 .53685 Mdot
.34788 .51069 Mdot
.36779 .28273 Mdot
.62409 .57742 Mdot
.65821 .36108 Mdot
.29535 .49642 Mdot
.60134 .56375 Mdot
.72432 .40134 Mdot
.57836 .38837 Mdot
.33978 .51355 Mdot
.61886 .6453 Mdot
.635 .48615 Mdot
.34535 .54093 Mdot
.35387 .52856 Mdot
.60175 .59729 Mdot
.4394 .67709 Mdot
.56021 .59395 Mdot
.41743 .40807 Mdot
.32322 .56312 Mdot
.43082 .37335 Mdot
.54123 .68739 Mdot
.63915 .64601 Mdot
.53891 .22592 Mdot
.61485 .41537 Mdot
.47644 .66602 Mdot
.73319 .61043 Mdot
.62889 .63798 Mdot
.20893 .62316 Mdot
.42239 .57793 Mdot
.25494 .2962 Mdot
.33227 .7797 Mdot
.4265 .65066 Mdot
.41833 .38875 Mdot
.60771 .59869 Mdot
.41397 .3478 Mdot
.41609 .66476 Mdot
.55679 .69459 Mdot
.61781 .64482 Mdot
.64244 .35879 Mdot
.61863 .59049 Mdot
.62353 .41202 Mdot
.59298 .61329 Mdot
.63134 .5187 Mdot
.4034 .68751 Mdot
.65218 .73412 Mdot
.61455 .63578 Mdot
.60769 .81373 Mdot
.5224 .47341 Mdot
.43804 .64747 Mdot
.63493 .58771 Mdot
.37216 .26611 Mdot
.4339 .35967 Mdot
.42049 .77212 Mdot
.31387 .51433 Mdot
.42472 .40307 Mdot
.64026 .39986 Mdot
.29602 .53876 Mdot
.36572 .25706 Mdot
.55052 .515 Mdot
.45767 .64448 Mdot
.41176 .38824 Mdot
.57212 .57586 Mdot
.58418 .55017 Mdot
.37889 .62785 Mdot
.49544 .16519 Mdot
.66836 .38689 Mdot
.75116 .70793 Mdot
.59248 .38224 Mdot
.44327 .66421 Mdot
.31021 .51821 Mdot
.56805 .60482 Mdot
.59379 .5764 Mdot
.34729 .49558 Mdot
.6244 .34628 Mdot
.3798 .52894 Mdot
.77659 .40923 Mdot
.27029 .50239 Mdot
.58787 .73469 Mdot
.61529 .37685 Mdot
.59615 .73345 Mdot
.45142 .63522 Mdot
.28904 .7132 Mdot
.47775 .75852 Mdot
.40888 .40008 Mdot
.57926 .73515 Mdot
.6183 .3585 Mdot
.6121 .56842 Mdot
.37412 .27938 Mdot
.39047 .27429 Mdot
.6316 .40608 Mdot
.29909 .50316 Mdot
.46081 .65325 Mdot
.60955 .59414 Mdot
.54905 .27567 Mdot
.43834 .27261 Mdot
.27784 .52314 Mdot
.53147 .63151 Mdot
.45061 .37377 Mdot
.60008 .62162 Mdot
.41784 .64906 Mdot
.42591 .39623 Mdot
.3896 .25655 Mdot
.52204 .37858 Mdot
.6236 .55922 Mdot
.55535 .34097 Mdot
.41672 .38157 Mdot
.63307 .20843 Mdot
.59768 .58485 Mdot
.45427 .39223 Mdot
.67265 .54674 Mdot
.46733 .22967 Mdot
.47794 .53801 Mdot
.18897 .55961 Mdot
.3649 .49813 Mdot
.29621 .51562 Mdot
.41494 .20045 Mdot
.42181 .69534 Mdot
.40675 .38747 Mdot
.38441 .28895 Mdot
.49449 .72864 Mdot
.45387 .37581 Mdot
.56682 .56214 Mdot
.59749 .54168 Mdot
.77436 .42078 Mdot
.48213 .4907 Mdot
.36363 .27775 Mdot
.59789 .46897 Mdot
.62547 .61609 Mdot
.55326 .61776 Mdot
.59049 .58878 Mdot
.60191 .35543 Mdot
.45086 .3654 Mdot
.61364 .82767 Mdot
.45576 .36978 Mdot
.55704 .27793 Mdot
.3407 .50963 Mdot
.27324 .51854 Mdot
.5706 .57426 Mdot
.57699 .21527 Mdot
.40356 .76844 Mdot
.60073 .62674 Mdot
.45244 .62755 Mdot
.51348 .68596 Mdot
.54429 .58727 Mdot
.6544 .33299 Mdot
.52949 .57533 Mdot
.59443 .3533 Mdot
.43001 .3976 Mdot
.4233 .65187 Mdot
.40284 .67752 Mdot
.41415 .3936 Mdot
.58137 .57312 Mdot
.46083 .62572 Mdot
.58968 .56304 Mdot
.61644 .56958 Mdot
.58565 .28259 Mdot
.4587 .6778 Mdot
.31584 .52316 Mdot
.43973 .67109 Mdot
.63258 .39349 Mdot
.38634 .12779 Mdot
.42321 .66355 Mdot
.58658 .44331 Mdot
.40758 .54307 Mdot
.58391 .73366 Mdot
.6562 .35925 Mdot
.41317 .67109 Mdot
.46034 .38617 Mdot
.25026 .29786 Mdot
.65877 .23426 Mdot
.39702 .39114 Mdot
.59749 .57917 Mdot
.64349 .41064 Mdot
.60143 .36419 Mdot
.3923 .39563 Mdot
.65045 .36366 Mdot
.59373 .65109 Mdot
.62388 .56628 Mdot
.40685 .38744 Mdot
.46628 .29607 Mdot
.45036 .36403 Mdot
.55954 .45238 Mdot
.63075 .5821 Mdot
.61921 .37885 Mdot
.5852 .65389 Mdot
.67306 .36733 Mdot
.39165 .27009 Mdot
.65335 .60231 Mdot
.45613 .66631 Mdot
.47977 .47831 Mdot
.33851 .51177 Mdot
.23039 .4498 Mdot
.63461 .41246 Mdot
.44784 .34121 Mdot
.65235 .37793 Mdot
.61788 .41993 Mdot
.40379 .36699 Mdot
.62301 .39328 Mdot
.60899 .59707 Mdot
.39852 .51429 Mdot
.61214 .40436 Mdot
.43303 .38271 Mdot
.45923 .65522 Mdot
.64627 .38271 Mdot
.29397 .53975 Mdot
.60855 .56202 Mdot
.32664 .53445 Mdot
.47438 .64393 Mdot
.64959 .40584 Mdot
.41569 .67401 Mdot
.34957 .5105 Mdot
.45059 .64035 Mdot
.25106 .60081 Mdot
.46336 .39798 Mdot
.59133 .26508 Mdot
.70825 .60767 Mdot
.60151 .38433 Mdot
.29668 .47994 Mdot
.57414 .61433 Mdot
.61249 .55906 Mdot
.43137 .63487 Mdot
.60169 .36546 Mdot
.17417 .51749 Mdot
.62637 .49132 Mdot
.48796 .34075 Mdot
.45004 .4163 Mdot
.77785 .67136 Mdot
.52193 .3524 Mdot
.23739 .33134 Mdot
.57223 .53365 Mdot
.3776 .27873 Mdot
.58737 .56015 Mdot
.71719 .70707 Mdot
.43768 .68271 Mdot
.3132 .39939 Mdot
.59096 .52514 Mdot
.32194 .51744 Mdot
.58624 .60601 Mdot
.49397 .81417 Mdot
.53019 .58941 Mdot
.41105 .6595 Mdot
.44845 .42626 Mdot
.65018 .41503 Mdot
.44836 .65022 Mdot
.30254 .52491 Mdot
.52597 .73074 Mdot
.60968 .64506 Mdot
.61957 .61564 Mdot
.30346 .4798 Mdot
.64536 .36025 Mdot
.34729 .50216 Mdot
.45309 .39543 Mdot
.42621 .66255 Mdot
.63866 .57572 Mdot
.56514 .63311 Mdot
.26311 .52273 Mdot
.45804 .36831 Mdot
.30007 .53835 Mdot
.44094 .41796 Mdot
.37741 .27961 Mdot
.60527 .63298 Mdot
.30042 .48223 Mdot
.60852 .53791 Mdot
.73887 .63957 Mdot
.59889 .27609 Mdot
.76524 .57024 Mdot
.31676 .52503 Mdot
.56843 .75206 Mdot
.42286 .38162 Mdot
.43213 .41701 Mdot
.82277 .51588 Mdot
.38888 .75121 Mdot
.36144 .58541 Mdot
.60642 .80447 Mdot
.45248 .39679 Mdot
.43003 .37608 Mdot
.28869 .51727 Mdot
.62447 .39856 Mdot
.583 .36223 Mdot
.26855 .51373 Mdot
.6648 .72162 Mdot
.6225 .35627 Mdot
.20028 .60613 Mdot
.3563 .53343 Mdot
.59383 .52336 Mdot
.37322 .29277 Mdot
.42552 .64705 Mdot
.66716 .71712 Mdot
.56641 .80861 Mdot
.56386 .58835 Mdot
.7559 .3241 Mdot
.31224 .50184 Mdot
.39871 .47679 Mdot
.23942 .67084 Mdot
.63845 .63542 Mdot
.58075 .59901 Mdot
.58218 .58016 Mdot
.44532 .68512 Mdot
.73255 .62233 Mdot
.5636 .58468 Mdot
.63264 .74067 Mdot
.56177 .56544 Mdot
.46778 .79176 Mdot
.4385 .67097 Mdot
.52096 .5385 Mdot
.35158 .48666 Mdot
.51221 .26559 Mdot
.67833 .62833 Mdot
.45355 .40091 Mdot
.33653 .46436 Mdot
.44556 .38979 Mdot
.35237 .75147 Mdot
.47933 .75654 Mdot
.59737 .36222 Mdot
.60302 .61829 Mdot
.34951 .48901 Mdot
.63438 .41407 Mdot
.27967 .36535 Mdot
.45924 .11173 Mdot
.4631 .38269 Mdot
.79386 .31849 Mdot
.4311 .41744 Mdot
.39014 .26916 Mdot
.64057 .40279 Mdot
.69151 .3289 Mdot
.47486 .46679 Mdot
.64524 .3803 Mdot
.37095 .39454 Mdot
.6492 .33009 Mdot
.57241 .74402 Mdot
.62974 .42495 Mdot
.42877 .38475 Mdot
.46699 .40593 Mdot
.66551 .55051 Mdot
.58024 .61816 Mdot
.50577 .41102 Mdot
.68557 .5647 Mdot
.59063 .62138 Mdot
.33058 .52171 Mdot
.63245 .23457 Mdot
.31586 .55319 Mdot
.61113 .3962 Mdot
.42503 .42387 Mdot
.58191 .60106 Mdot
.6342 .5744 Mdot
.63029 .54647 Mdot
.73249 .696 Mdot
.20115 .60322 Mdot
.61263 .5781 Mdot
.66541 .59217 Mdot
.30549 .5247 Mdot
.39354 .62538 Mdot
.66603 .76714 Mdot
.49336 .73731 Mdot
.60516 .55189 Mdot
.44814 .66375 Mdot
.44064 .68419 Mdot
.5601 .62014 Mdot
.54188 .2499 Mdot
.38206 .49424 Mdot
.57197 .57637 Mdot
.46687 .76704 Mdot
.30984 .54843 Mdot
.37418 .28904 Mdot
.34833 .51153 Mdot
.65596 .39599 Mdot
.38761 .27661 Mdot
.29075 .49657 Mdot
.69838 .34153 Mdot
.37495 .25689 Mdot
.472 .23975 Mdot
.42657 .68126 Mdot
.59091 .5833 Mdot
.66976 .34454 Mdot
.35202 .49871 Mdot
.41156 .39047 Mdot
.63121 .37286 Mdot
.4624 .36726 Mdot
.38835 .63055 Mdot
.60802 .71233 Mdot
.39135 .28281 Mdot
.44662 .40977 Mdot
.52413 .38166 Mdot
.44692 .6664 Mdot
.40109 .37314 Mdot
.56342 .21223 Mdot
.54697 .57133 Mdot
.38866 .78151 Mdot
.61255 .61591 Mdot
.18109 .42709 Mdot
.4286 .4163 Mdot
.3905 .26117 Mdot
.58141 .56602 Mdot
.34867 .53583 Mdot
.64145 .52002 Mdot
.59323 .56428 Mdot
.31464 .54069 Mdot
.61294 .57215 Mdot
.41785 .64762 Mdot
.58555 .3673 Mdot
.42948 .57583 Mdot
.82011 .60207 Mdot
.44644 .63978 Mdot
.35205 .25091 Mdot
.58879 .62224 Mdot
.29418 .65022 Mdot
.64475 .37645 Mdot
.64369 .62883 Mdot
.80966 .4249 Mdot
.62154 .40366 Mdot
.63725 .38043 Mdot
.63488 .60444 Mdot
.40053 .38626 Mdot
.34996 .52674 Mdot
.44697 .66778 Mdot
.29773 .27983 Mdot
.59885 .56164 Mdot
.59579 .59931 Mdot
.4481 .64864 Mdot
.43014 .3747 Mdot
.63949 .58061 Mdot
.26142 .39678 Mdot
.31578 .24512 Mdot
.40735 .40349 Mdot
.54495 .57743 Mdot
.43201 .82281 Mdot
.59683 .42711 Mdot
.73583 .27585 Mdot
.41336 .69799 Mdot
.30363 .50516 Mdot
.59602 .51746 Mdot
.12384 .38833 Mdot
.42661 .64753 Mdot
.52224 .28507 Mdot
.61673 .5802 Mdot
.58039 .60988 Mdot
.64659 .34875 Mdot
.6428 .60136 Mdot
.61039 .37133 Mdot
.82927 .59083 Mdot
.7358 .76223 Mdot
.6509 .38045 Mdot
.60633 .38794 Mdot
.69114 .36973 Mdot
.70742 .70557 Mdot
.63547 .40105 Mdot
.62475 .64566 Mdot
.2382 .61305 Mdot
.6692 .61192 Mdot
.45956 .63826 Mdot
.48414 .64979 Mdot
.63061 .31624 Mdot
.56796 .18513 Mdot
.58796 .50243 Mdot
.65462 .67205 Mdot
.49948 .55012 Mdot
.42946 .41035 Mdot
.62001 .55185 Mdot
.38962 .28635 Mdot
.2789 .51402 Mdot
.53099 .62173 Mdot
.58953 .57904 Mdot
.6158 .41007 Mdot
.44954 .68446 Mdot
.43113 .35712 Mdot
.59972 .5935 Mdot
.37462 .5256 Mdot
.43843 .65689 Mdot
.60983 .40022 Mdot
.56824 .41523 Mdot
.46908 .65081 Mdot
.57587 .64539 Mdot
.58816 .61828 Mdot
.62434 .57658 Mdot
.6829 .62004 Mdot
.41316 .39601 Mdot
.26905 .52334 Mdot
.6168 .6505 Mdot
.58241 .29187 Mdot
.42826 .49514 Mdot
.58189 .64039 Mdot
.63113 .34793 Mdot
.40354 .40494 Mdot
.37888 .25981 Mdot
.53995 .71868 Mdot
.61706 .55483 Mdot
.20496 .60815 Mdot
.75527 .38151 Mdot
.38433 .27157 Mdot
.59926 .40639 Mdot
.45092 .66772 Mdot
.62492 .61119 Mdot
.26248 .64758 Mdot
.59045 .54561 Mdot
.68591 .54806 Mdot
.30761 .50339 Mdot
.43661 .40931 Mdot
.30166 .25165 Mdot
.27882 .51496 Mdot
.63587 .38146 Mdot
.15519 .52359 Mdot
.65619 .34448 Mdot
.66092 .40132 Mdot
.30633 .71715 Mdot
.4323 .39919 Mdot
.1157 .4065 Mdot
.67768 .24639 Mdot
.58238 .54638 Mdot
.44061 .36823 Mdot
.64089 .40455 Mdot
.60604 .61723 Mdot
.60458 .37066 Mdot
.66678 .37638 Mdot
.64362 .57239 Mdot
.58164 .61443 Mdot
.65077 .72883 Mdot
.19925 .63099 Mdot
.44146 .6743 Mdot
.6311 .3436 Mdot
.75448 .41769 Mdot
.56298 .5886 Mdot
.58763 .5514 Mdot
.36532 .46242 Mdot
.4114 .66026 Mdot
.66275 .48474 Mdot
.6198 .56904 Mdot
.81833 .43597 Mdot
.60178 .62965 Mdot
.67634 .35962 Mdot
.4002 .39211 Mdot
.53915 .25565 Mdot
.3584 .50898 Mdot
.65791 .35393 Mdot
.4648 .65707 Mdot
.63547 .33421 Mdot
.81952 .46867 Mdot
.43679 .39644 Mdot
.61448 .36806 Mdot
.33334 .54883 Mdot
.44116 .3856 Mdot
.40965 .40443 Mdot
.26872 .63751 Mdot
.28867 .53317 Mdot
.41066 .67559 Mdot
.44893 .38497 Mdot
.7266 .41449 Mdot
.42832 .38825 Mdot
.76491 .4219 Mdot
.57607 .62298 Mdot
.63124 .73603 Mdot
.52173 .3406 Mdot
.67491 .62682 Mdot
.4481 .36295 Mdot
.42241 .67129 Mdot
.6376 .61551 Mdot
.64887 .3598 Mdot
.42158 .66111 Mdot
.40101 .43588 Mdot
.32816 .54673 Mdot
.60688 .41029 Mdot
.4024 .39903 Mdot
.61242 .36661 Mdot
.58865 .708 Mdot
.2445 .51904 Mdot
.50218 .55511 Mdot
.4616 .47493 Mdot
.63136 .54377 Mdot
.64699 .31258 Mdot
.57425 .62569 Mdot
.58959 .57428 Mdot
.3405 .51348 Mdot
.60814 .76742 Mdot
.64748 .3793 Mdot
.31303 .23682 Mdot
.44083 .41386 Mdot
.62377 .29835 Mdot
.62716 .48318 Mdot
.65159 .60278 Mdot
.61425 .405 Mdot
.66795 .37596 Mdot
.77257 .58612 Mdot
.34443 .49451 Mdot
.67078 .62517 Mdot
.63137 .65294 Mdot
.63538 .52318 Mdot
.42732 .41737 Mdot
.27085 .41091 Mdot
.31279 .49207 Mdot
.72964 .23639 Mdot
.33015 .49846 Mdot
.31897 .62051 Mdot
.6221 .39357 Mdot
.44509 .67949 Mdot
.58523 .55272 Mdot
.69423 .66073 Mdot
.60872 .34076 Mdot
.38636 .48463 Mdot
.45552 .66337 Mdot
.29425 .43069 Mdot
.42863 .40162 Mdot
.59534 .63809 Mdot
.63431 .55978 Mdot
.63788 .59392 Mdot
.61622 .60531 Mdot
.42825 .42607 Mdot
.56733 .56175 Mdot
.44512 .42232 Mdot
.71805 .39697 Mdot
.82439 .45127 Mdot
.36235 .50627 Mdot
.41366 .76187 Mdot
.60011 .38746 Mdot
.74187 .43349 Mdot
.65042 .46831 Mdot
.59596 .27531 Mdot
.26286 .61906 Mdot
.58694 .62985 Mdot
.2966 .50344 Mdot
.49576 .81669 Mdot
.34791 .48873 Mdot
.79475 .72653 Mdot
.50355 .64883 Mdot
.1821 .56001 Mdot
.60727 .61487 Mdot
.26586 .52406 Mdot
.64056 .47877 Mdot
.55266 .60618 Mdot
.4802 .6317 Mdot
.57717 .44464 Mdot
.48483 .29101 Mdot
.46614 .66637 Mdot
.60632 .56176 Mdot
.65008 .41629 Mdot
.61011 .59698 Mdot
.58862 .5535 Mdot
.5968 .62342 Mdot
.42829 .35327 Mdot
.56444 .54847 Mdot
.56015 .58928 Mdot
.50783 .16173 Mdot
.56621 .76634 Mdot
.32149 .53681 Mdot
.78348 .55592 Mdot
.43566 .66449 Mdot
.62411 .41381 Mdot
.41574 .5705 Mdot
.41807 .40532 Mdot
.76777 .5971 Mdot
.60945 .61572 Mdot
.50932 .33564 Mdot
.40144 .39786 Mdot
.42065 .65663 Mdot
.36845 .25718 Mdot
.21009 .56971 Mdot
.35869 .50118 Mdot
.3807 .25721 Mdot
.33699 .51055 Mdot
.71929 .56823 Mdot
.61614 .40949 Mdot
.635 .55122 Mdot
.45218 .3794 Mdot
.3479 .53197 Mdot
.58298 .78052 Mdot
.58691 .59142 Mdot
.31881 .52683 Mdot
.63419 .54682 Mdot
.41409 .50444 Mdot
.39857 .55221 Mdot
.30616 .48421 Mdot
.46567 .41042 Mdot
.44185 .37996 Mdot
.43814 .67888 Mdot
.62155 .4141 Mdot
.6223 .35122 Mdot
.4296 .39493 Mdot
.75826 .2975 Mdot
.59463 .56013 Mdot
.5939 .62322 Mdot
.57132 .29865 Mdot
.60505 .60812 Mdot
.54167 .74229 Mdot
.39009 .29295 Mdot
.60702 .4063 Mdot
.61173 .60621 Mdot
.63867 .57846 Mdot
.62516 .56101 Mdot
.59192 .71126 Mdot
.34482 .50734 Mdot
.6257 .61536 Mdot
.42462 .6376 Mdot
.51657 .2154 Mdot
.57009 .612 Mdot
.55483 .61646 Mdot
.61591 .36478 Mdot
.78414 .6717 Mdot
.41229 .40382 Mdot
.32701 .52826 Mdot
.35168 .53711 Mdot
.46396 .69752 Mdot
.58663 .39779 Mdot
.38765 .29697 Mdot
.36118 .32497 Mdot
.37232 .2835 Mdot
.44229 .64942 Mdot
.3283 .59649 Mdot
.37738 .52014 Mdot
.3086 .53263 Mdot
.46008 .40496 Mdot
.61491 .60371 Mdot
.59903 .62786 Mdot
.52519 .28403 Mdot
.63116 .62728 Mdot
.458 .65939 Mdot
.40839 .37829 Mdot
.61836 .36399 Mdot
.42833 .64463 Mdot
.44925 .41008 Mdot
.64445 .35791 Mdot
.54752 .58129 Mdot
.54894 .56276 Mdot
.63499 .3747 Mdot
.64861 .40206 Mdot
.56764 .59155 Mdot
.46721 .17377 Mdot
.63106 .42242 Mdot
.61459 .37237 Mdot
.35984 .25648 Mdot
.35848 .49987 Mdot
.56048 .64273 Mdot
.4421 .36778 Mdot
.6233 .57558 Mdot
.36043 .49921 Mdot
.41314 .66626 Mdot
.63958 .36505 Mdot
.63085 .56999 Mdot
.60774 .57235 Mdot
.44924 .66373 Mdot
.46939 .66633 Mdot
.45304 .64588 Mdot
.44682 .3493 Mdot
.62516 .59294 Mdot
.63857 .39835 Mdot
.43408 .40032 Mdot
.44108 .68408 Mdot
.40228 .65671 Mdot
.54225 .16648 Mdot
.56476 .58245 Mdot
.48207 .54207 Mdot
.3332 .16548 Mdot
.51733 .7331 Mdot
.38574 .26231 Mdot
.28408 .49317 Mdot
.61309 .73944 Mdot
.40272 .7043 Mdot
.43707 .36563 Mdot
.41687 .7354 Mdot
.47699 .66406 Mdot
.64713 .57472 Mdot
.60986 .6274 Mdot
.64212 .54399 Mdot
.43321 .65845 Mdot
.57715 .70696 Mdot
.60488 .35908 Mdot
.72106 .49163 Mdot
.43546 .66438 Mdot
.30564 .4846 Mdot
.30007 .48336 Mdot
.32894 .49783 Mdot
.59343 .63452 Mdot
.76563 .58637 Mdot
.73836 .41217 Mdot
.68795 .50696 Mdot
.42435 .40245 Mdot
.66883 .36829 Mdot
.27253 .62471 Mdot
.63847 .37938 Mdot
.28122 .50789 Mdot
.43317 .65504 Mdot
.63888 .34417 Mdot
.41912 .3751 Mdot
.43386 .3736 Mdot
.3333 .546 Mdot
.34994 .51684 Mdot
.34038 .52808 Mdot
.65964 .38766 Mdot
.62294 .39351 Mdot
.63408 .56759 Mdot
.63299 .36394 Mdot
.73164 .30698 Mdot
.43628 .63032 Mdot
.31112 .47944 Mdot
.42001 .37998 Mdot
.62925 .41181 Mdot
.59302 .5829 Mdot
.36363 .61147 Mdot
.38069 .43744 Mdot
.4363 .63865 Mdot
.28012 .55777 Mdot
.84204 .65359 Mdot
.62733 .55091 Mdot
.44755 .41524 Mdot
.54047 .23965 Mdot
.58156 .58689 Mdot
.31165 .5102 Mdot
.72492 .68811 Mdot
.36839 .28166 Mdot
.56088 .59279 Mdot
.6406 .62787 Mdot
.40686 .36387 Mdot
.4041 .56361 Mdot
.64881 .61011 Mdot
.54147 .38395 Mdot
.45655 .36188 Mdot
.30644 .49206 Mdot
.3328 .22184 Mdot
.27359 .49543 Mdot
.66178 .73561 Mdot
.38653 .26554 Mdot
.6358 .56272 Mdot
.33351 .52016 Mdot
.42409 .64063 Mdot
.34045 .5212 Mdot
.59743 .39489 Mdot
.33108 .53435 Mdot
.59344 .60392 Mdot
.63685 .39782 Mdot
.41902 .37797 Mdot
.60259 .30135 Mdot
.5176 .16955 Mdot
.34833 .53668 Mdot
.3744 .24587 Mdot
.56181 .59055 Mdot
.68355 .43931 Mdot
.63748 .51822 Mdot
.58016 .621 Mdot
.44498 .39163 Mdot
.61351 .40318 Mdot
.44788 .41776 Mdot
.54193 .59736 Mdot
.81471 .54561 Mdot
.43188 .41442 Mdot
.47344 .26255 Mdot
.44558 .64816 Mdot
.66247 .72077 Mdot
.59421 .57089 Mdot
.45183 .38512 Mdot
.62582 .59155 Mdot
.62432 .34362 Mdot
.51094 .45688 Mdot
.53389 .21405 Mdot
.45108 .37711 Mdot
.16909 .47645 Mdot
.50462 .47515 Mdot
.5335 .60265 Mdot
.45247 .39175 Mdot
.74585 .5988 Mdot
.37336 .26272 Mdot
.44177 .6545 Mdot
.45199 .68081 Mdot
.45787 .64342 Mdot
.62864 .62871 Mdot
.52336 .58487 Mdot
.40336 .6674 Mdot
.46018 .36257 Mdot
.41054 .65 Mdot
.66011 .71319 Mdot
.17767 .49627 Mdot
.44667 .64198 Mdot
.59943 .57503 Mdot
.5503 .60487 Mdot
.56734 .76812 Mdot
.29801 .49283 Mdot
.21113 .62744 Mdot
.7097 .31122 Mdot
.56978 .60638 Mdot
.56276 .50451 Mdot
.59899 .3911 Mdot
.5777 .23155 Mdot
.60798 .48117 Mdot
.39259 .58271 Mdot
.60803 .38332 Mdot
.38635 .53965 Mdot
.60958 .40953 Mdot
.62159 .5448 Mdot
.61156 .58272 Mdot
.59281 .35232 Mdot
.23054 .43624 Mdot
.44561 .22243 Mdot
.20191 .36443 Mdot
.62095 .35071 Mdot
.45624 .38731 Mdot
.46208 .3908 Mdot
.4335 .40343 Mdot
.35707 .5098 Mdot
.6564 .3894 Mdot
.62532 .59991 Mdot
.29947 .51604 Mdot
.60079 .55268 Mdot
.44447 .38468 Mdot
.29776 .25512 Mdot
.61655 .36523 Mdot
.57376 .57467 Mdot
.6574 .23453 Mdot
.32837 .50236 Mdot
.44572 .66567 Mdot
.40847 .49222 Mdot
.26487 .51762 Mdot
.45194 .36406 Mdot
.59205 .41712 Mdot
.48021 .38438 Mdot
.41971 .59384 Mdot
.65533 .55494 Mdot
.59615 .64131 Mdot
.32334 .25776 Mdot
.59448 .19557 Mdot
.61593 .63063 Mdot
.30249 .52536 Mdot
.32582 .48424 Mdot
.62238 .56309 Mdot
.65515 .36711 Mdot
.42464 .68498 Mdot
.45113 .63757 Mdot
.65634 .60108 Mdot
.4749 .46384 Mdot
.6409 .73416 Mdot
.64392 .59263 Mdot
.64206 .66038 Mdot
.31414 .54521 Mdot
.36816 .25563 Mdot
.54619 .3319 Mdot
.45951 .66951 Mdot
.61789 .57776 Mdot
.43556 .23964 Mdot
.6094 .37484 Mdot
.33452 .53203 Mdot
.40956 .38367 Mdot
.47758 .62908 Mdot
.35339 .5381 Mdot
.62287 .56388 Mdot
.6392 .58 Mdot
.40407 .36771 Mdot
.67583 .35819 Mdot
.43133 .65614 Mdot
.30089 .51675 Mdot
.44774 .67886 Mdot
.62974 .39262 Mdot
.61929 .36794 Mdot
.65113 .64651 Mdot
.68347 .60503 Mdot
.34989 .53761 Mdot
.6603 .5876 Mdot
.28587 .49987 Mdot
.38244 .62698 Mdot
.41112 .41501 Mdot
.64685 .62626 Mdot
.63304 .43091 Mdot
.44229 .38905 Mdot
.57408 .604 Mdot
.34673 .26369 Mdot
.64861 .58665 Mdot
.26641 .52014 Mdot
.82036 .53817 Mdot
.41642 .66863 Mdot
.56384 .36719 Mdot
.56465 .67557 Mdot
.60398 .60768 Mdot
.28537 .49666 Mdot
.59108 .51524 Mdot
.41967 .41116 Mdot
.61445 .39422 Mdot
.86221 .43083 Mdot
.43247 .38569 Mdot
.61143 .5931 Mdot
.4243 .66174 Mdot
.66185 .40282 Mdot
.38618 .28387 Mdot
.54395 .32506 Mdot
.52942 .6126 Mdot
.56681 .5391 Mdot
.61441 .60123 Mdot
.61386 .80447 Mdot
.33169 .52579 Mdot
.63478 .409 Mdot
.42357 .41917 Mdot
.42162 .39516 Mdot
.31724 .49727 Mdot
.49167 .31332 Mdot
.22533 .47022 Mdot
.25532 .21566 Mdot
.325 .54085 Mdot
.41024 .64668 Mdot
.45209 .48903 Mdot
.27914 .51784 Mdot
.32615 .5204 Mdot
.34468 .54397 Mdot
.51979 .32148 Mdot
.63889 .35064 Mdot
.6087 .57165 Mdot
.58828 .39836 Mdot
.64273 .57284 Mdot
.64138 .76375 Mdot
.42913 .39651 Mdot
.61562 .39372 Mdot
.33973 .25964 Mdot
.67399 .54404 Mdot
.58226 .5958 Mdot
.22962 .56201 Mdot
.53746 .55831 Mdot
.56338 .73039 Mdot
.5747 .64632 Mdot
.34589 .51389 Mdot
.54094 .52332 Mdot
.60031 .51809 Mdot
.70172 .29519 Mdot
.42563 .37336 Mdot
.39312 .27646 Mdot
.55064 .57125 Mdot
.55911 .64867 Mdot
.66139 .40266 Mdot
.6389 .34402 Mdot
.40428 .66979 Mdot
.42687 .47192 Mdot
.4217 .37537 Mdot
.25107 .47104 Mdot
.58296 .61888 Mdot
.38339 .40372 Mdot
.82516 .50338 Mdot
.57257 .60018 Mdot
.25424 .63085 Mdot
.76942 .59378 Mdot
.64988 .60625 Mdot
.7127 .52562 Mdot
.42647 .37944 Mdot
.81587 .43257 Mdot
.64214 .54799 Mdot
.31298 .50998 Mdot
.62196 .39796 Mdot
.60066 .39856 Mdot
.43609 .64056 Mdot
.71421 .28791 Mdot
.46929 .3884 Mdot
.62011 .39424 Mdot
.58419 .58341 Mdot
.4113 .39314 Mdot
.39054 .2796 Mdot
.54635 .55467 Mdot
.35651 .73206 Mdot
.62851 .36264 Mdot
.66695 .61103 Mdot
.43996 .31312 Mdot
.42249 .51134 Mdot
.20158 .64733 Mdot
.43641 .40461 Mdot
.46367 .66053 Mdot
.57911 .64949 Mdot
.35799 .32167 Mdot
.61186 .52888 Mdot
.62881 .75143 Mdot
.59364 .3309 Mdot
.43359 .68256 Mdot
.57819 .58127 Mdot
.64742 .61209 Mdot
.4715 .47767 Mdot
.46706 .66835 Mdot
.65253 .60241 Mdot
.66316 .63588 Mdot
.64368 .35856 Mdot
.39277 .29015 Mdot
.62303 .36117 Mdot
.59744 .58023 Mdot
.54618 .51454 Mdot
.64932 .35471 Mdot
.22524 .52069 Mdot
.46299 .68177 Mdot
.41859 .40682 Mdot
.57577 .66358 Mdot
.5781 .62369 Mdot
.41005 .83729 Mdot
.39146 .26973 Mdot
.70163 .738 Mdot
.26722 .5136 Mdot
.38858 .24108 Mdot
.26787 .53716 Mdot
.17674 .54528 Mdot
.56849 .31981 Mdot
.65973 .57013 Mdot
.44644 .75487 Mdot
.70095 .51354 Mdot
.46498 .39155 Mdot
.70943 .42518 Mdot
.57997 .61809 Mdot
.58807 .55668 Mdot
.29019 .5127 Mdot
.4934 .32728 Mdot
.53637 .24405 Mdot
.49401 .43668 Mdot
.42838 .65272 Mdot
.62427 .38837 Mdot
.59505 .61079 Mdot
.24027 .37695 Mdot
.32719 .53755 Mdot
.53544 .46918 Mdot
.57765 .56968 Mdot
.55782 .27012 Mdot
.4976 .28093 Mdot
.41032 .39314 Mdot
.28197 .49617 Mdot
.26938 .52263 Mdot
.60396 .54279 Mdot
.42239 .37023 Mdot
.63973 .57412 Mdot
.52471 .46199 Mdot
.66482 .59958 Mdot
.41847 .65193 Mdot
.57375 .55904 Mdot
.47164 .51481 Mdot
.16419 .57093 Mdot
.53509 .55404 Mdot
.63136 .41863 Mdot
.35567 .50924 Mdot
.33438 .50104 Mdot
.62091 .35168 Mdot
.32857 .49914 Mdot
.72674 .50118 Mdot
.80348 .44639 Mdot
.4329 .64729 Mdot
.66082 .44601 Mdot
.4177 .65722 Mdot
.39342 .27635 Mdot
.56496 .59043 Mdot
.36606 .34261 Mdot
.33128 .54161 Mdot
.75093 .67613 Mdot
.42622 .39045 Mdot
.39119 .2703 Mdot
.5709 .55129 Mdot
.3275 .59883 Mdot
.28638 .50577 Mdot
.28099 .47037 Mdot
.62554 .56088 Mdot
.63464 .34587 Mdot
.64729 .61126 Mdot
.65443 .62348 Mdot
.38007 .25742 Mdot
.61547 .60127 Mdot
.44985 .40933 Mdot
.65766 .38514 Mdot
.1827 .53946 Mdot
.35441 .50139 Mdot
.57635 .56024 Mdot
.5834 .58348 Mdot
.62714 .34137 Mdot
.56351 .56355 Mdot
.43717 .36426 Mdot
.08633 .47157 Mdot
.44498 .64886 Mdot
.36413 .25922 Mdot
.26679 .47513 Mdot
.6086 .62476 Mdot
.64627 .60204 Mdot
.31695 .26048 Mdot
.48722 .19668 Mdot
.45043 .40698 Mdot
.62538 .64967 Mdot
.30702 .52507 Mdot
.42191 .65857 Mdot
.42924 .35891 Mdot
.62703 .57635 Mdot
.58448 .55726 Mdot
.41967 .65038 Mdot
.24004 .60975 Mdot
.39069 .50701 Mdot
.42798 .40329 Mdot
.58273 .48721 Mdot
.37041 .61236 Mdot
.59391 .56194 Mdot
.20188 .40699 Mdot
.61581 .37356 Mdot
.44982 .39826 Mdot
.7244 .62782 Mdot
.63712 .55327 Mdot
.45245 .36554 Mdot
.42147 .3763 Mdot
.58812 .54333 Mdot
.58797 .40173 Mdot
.66251 .38553 Mdot
.61284 .37531 Mdot
.8214 .54787 Mdot
.52979 .7956 Mdot
.34125 .52837 Mdot
.42782 .3773 Mdot
.32747 .48241 Mdot
.42195 .68539 Mdot
.43005 .49381 Mdot
.31795 .48318 Mdot
.60026 .39501 Mdot
.30558 .48015 Mdot
.64284 .58106 Mdot
.42421 .37209 Mdot
.30735 .53263 Mdot
.61471 .62304 Mdot
.65711 .6556 Mdot
.49262 .51346 Mdot
.42387 .68414 Mdot
.40289 .51901 Mdot
.6055 .58916 Mdot
.37795 .25877 Mdot
.56766 .58453 Mdot
.40658 .38807 Mdot
.45828 .52142 Mdot
.61928 .61911 Mdot
.34764 .53907 Mdot
.44282 .59622 Mdot
.30724 .48994 Mdot
.64527 .64054 Mdot
.59846 .58062 Mdot
.59222 .56039 Mdot
.64855 .61164 Mdot
.48032 .27599 Mdot
.44347 .42243 Mdot
.59519 .67142 Mdot
.37085 .51859 Mdot
.64033 .374 Mdot
.61312 .34602 Mdot
.36783 .58393 Mdot
.37398 .25361 Mdot
.43556 .369 Mdot
.59552 .56102 Mdot
.28379 .46938 Mdot
.28931 .26376 Mdot
.19995 .39484 Mdot
.28661 .63448 Mdot
.30407 .52845 Mdot
.63328 .41728 Mdot
.29439 .52987 Mdot
.59994 .54661 Mdot
.56329 .63491 Mdot
.18473 .54928 Mdot
.39045 .39927 Mdot
.43333 .65609 Mdot
.59896 .55189 Mdot
.66859 .72668 Mdot
.30543 .52462 Mdot
.30846 .54346 Mdot
.63319 .5624 Mdot
.66336 .36492 Mdot
.19187 .66706 Mdot
.40867 .38416 Mdot
.68919 .43593 Mdot
.56717 .37289 Mdot
.58012 .44966 Mdot
.41483 .39336 Mdot
.49717 .53096 Mdot
.32598 .4925 Mdot
.71271 .30794 Mdot
.6367 .37207 Mdot
.43701 .65858 Mdot
.58284 .64305 Mdot
.6018 .40018 Mdot
.27924 .49634 Mdot
.60539 .39742 Mdot
.63272 .55161 Mdot
.45892 .40205 Mdot
.31633 .49553 Mdot
.44059 .42788 Mdot
.59437 .35001 Mdot
.41595 .66125 Mdot
.66819 .71093 Mdot
.70073 .42266 Mdot
.76872 .59489 Mdot
.62563 .615 Mdot
.31571 .46937 Mdot
.62765 .59274 Mdot
.66374 .39458 Mdot
.59518 .57157 Mdot
.6523 .31427 Mdot
.27426 .5198 Mdot
.66689 .60609 Mdot
.56087 .57995 Mdot
.71762 .35775 Mdot
.57673 .59588 Mdot
.57459 .54883 Mdot
.64009 .62606 Mdot
.57295 .35144 Mdot
.66582 .62732 Mdot
.6391 .34815 Mdot
.52152 .29372 Mdot
.32687 .51853 Mdot
.39936 .66308 Mdot
.45902 .64121 Mdot
.62985 .74789 Mdot
.66255 .72221 Mdot
.49669 .31665 Mdot
.62705 .35419 Mdot
.45948 .38453 Mdot
.63854 .57234 Mdot
.72085 .61345 Mdot
.47546 .67749 Mdot
.32346 .49299 Mdot
.36074 .52548 Mdot
.68197 .58569 Mdot
.59545 .81667 Mdot
.66613 .62089 Mdot
.54715 .31627 Mdot
.65401 .58212 Mdot
.64592 .62586 Mdot
.33574 .54921 Mdot
.62854 .71106 Mdot
.62542 .61547 Mdot
.66142 .40271 Mdot
.44159 .66048 Mdot
.58039 .49783 Mdot
.49194 .64753 Mdot
.51562 .48968 Mdot
.69582 .32115 Mdot
.62048 .60176 Mdot
.30195 .51092 Mdot
.60912 .4117 Mdot
.57987 .29644 Mdot
.4368 .3995 Mdot
.53214 .35055 Mdot
.7275 .38609 Mdot
.24322 .54626 Mdot
.43818 .65708 Mdot
.25496 .62443 Mdot
.59382 .60399 Mdot
.35712 .51468 Mdot
.63435 .55717 Mdot
.2812 .27106 Mdot
.41567 .67305 Mdot
.6109 .33809 Mdot
.45679 .38682 Mdot
.61808 .34862 Mdot
.768 .56832 Mdot
.49922 .58754 Mdot
.3624 .2307 Mdot
.35494 .49644 Mdot
.69992 .69151 Mdot
.63034 .40555 Mdot
.62908 .57212 Mdot
.28207 .19854 Mdot
.61672 .37549 Mdot
.62522 .34594 Mdot
.39562 .58282 Mdot
.54303 .68831 Mdot
.58135 .51874 Mdot
.60299 .3906 Mdot
.33495 .48208 Mdot
.44009 .67238 Mdot
.63397 .61704 Mdot
.64209 .62263 Mdot
.64438 .34731 Mdot
.28476 .50484 Mdot
.68382 .72691 Mdot
.34832 .51542 Mdot
.64811 .36553 Mdot
.32711 .50526 Mdot
.28716 .46216 Mdot
.3179 .53213 Mdot
.56004 .59841 Mdot
.59724 .56208 Mdot
.35136 .70412 Mdot
.61943 .36788 Mdot
.64221 .61043 Mdot
.61453 .57587 Mdot
.63618 .40166 Mdot
.37574 .51383 Mdot
.71764 .65658 Mdot
.60395 .61711 Mdot
.6053 .56636 Mdot
.4422 .68105 Mdot
.36257 .558 Mdot
.23562 .36886 Mdot
.63735 .61479 Mdot
.43966 .63547 Mdot
.65845 .39287 Mdot
.568 .58807 Mdot
.65578 .7147 Mdot
.34008 .55195 Mdot
.58371 .54904 Mdot
.38633 .28514 Mdot
.60228 .62728 Mdot
.18901 .66075 Mdot
.56909 .56804 Mdot
.64387 .40131 Mdot
.62123 .40221 Mdot
.3927 .48459 Mdot
.63349 .3821 Mdot
.38896 .27007 Mdot
.44329 .38393 Mdot
.18558 .41286 Mdot
.38916 .27489 Mdot
.63263 .63845 Mdot
.678 .2466 Mdot
.6568 .57626 Mdot
.55081 .58483 Mdot
.71055 .70287 Mdot
.38752 .27212 Mdot
.61864 .40763 Mdot
.23378 .43238 Mdot
.65286 .62072 Mdot
.41044 .38058 Mdot
.5569 .61787 Mdot
.57801 .55239 Mdot
.55561 .42211 Mdot
.79991 .578 Mdot
.40478 .38808 Mdot
.55015 .63191 Mdot
.63743 .61391 Mdot
.55366 .19417 Mdot
.58865 .58898 Mdot
.44285 .64096 Mdot
.61291 .36061 Mdot
.29642 .53356 Mdot
.45055 .65575 Mdot
.59966 .61698 Mdot
.43427 .66092 Mdot
.33705 .52958 Mdot
.44713 .39225 Mdot
.58254 .55286 Mdot
.46455 .64154 Mdot
.4286 .65461 Mdot
.63337 .59253 Mdot
.6187 .39563 Mdot
.60252 .5059 Mdot
.56869 .59153 Mdot
.62542 .56803 Mdot
.62225 .35131 Mdot
.64548 .18748 Mdot
.61259 .54377 Mdot
.48465 .53704 Mdot
.59834 .35495 Mdot
.37304 .29032 Mdot
.29662 .52954 Mdot
.6149 .53696 Mdot
.42528 .39848 Mdot
.43628 .39353 Mdot
.35612 .48558 Mdot
.63942 .33912 Mdot
.29429 .49683 Mdot
.53565 .57589 Mdot
.68232 .60314 Mdot
.61249 .65121 Mdot
.86266 .43685 Mdot
.20957 .57725 Mdot
.65612 .3827 Mdot
.31713 .49105 Mdot
.49498 .43302 Mdot
.43661 .37045 Mdot
.32491 .47672 Mdot
.63024 .42994 Mdot
.6438 .40912 Mdot
.60045 .38919 Mdot
.45166 .67444 Mdot
.35058 .50795 Mdot
.66609 .34146 Mdot
.65861 .35371 Mdot
.63206 .56696 Mdot
.6382 .61264 Mdot
.62028 .32163 Mdot
.55581 .76325 Mdot
.41539 .65689 Mdot
.30604 .50799 Mdot
.37657 .83485 Mdot
.40657 .3893 Mdot
.71713 .3541 Mdot
.61239 .62277 Mdot
.46984 .09962 Mdot
.64776 .64482 Mdot
.58558 .58522 Mdot
.65655 .39472 Mdot
.41973 .63596 Mdot
.43025 .66934 Mdot
.62912 .40525 Mdot
.58518 .35809 Mdot
.4609 .65034 Mdot
.28309 .6393 Mdot
.16211 .45954 Mdot
.56216 .31337 Mdot
.64413 .39867 Mdot
.69658 .41978 Mdot
.44126 .36283 Mdot
.59068 .36159 Mdot
.40414 .39288 Mdot
.32475 .51999 Mdot
.35507 .52997 Mdot
.40258 .3714 Mdot
.62053 .55703 Mdot
.32859 .53312 Mdot
.52751 .60805 Mdot
.2034 .54771 Mdot
.34727 .75851 Mdot
.46026 .19308 Mdot
.59983 .62985 Mdot
.54034 .25158 Mdot
.50678 .23944 Mdot
.60399 .59978 Mdot
.68084 .54751 Mdot
.43428 .65767 Mdot
.59549 .35384 Mdot
.43098 .36594 Mdot
.21287 .65821 Mdot
.5945 .56166 Mdot
.64776 .3782 Mdot
.42953 .37068 Mdot
.30959 .45226 Mdot
.54096 .39199 Mdot
.63386 .56115 Mdot
.15716 .32055 Mdot
.60336 .34289 Mdot
.29611 .53353 Mdot
.68112 .26489 Mdot
.58868 .39267 Mdot
.38693 .60449 Mdot
.2808 .53052 Mdot
.21776 .34798 Mdot
.62682 .41366 Mdot
.38304 .51261 Mdot
.63118 .39034 Mdot
.42072 .64647 Mdot
.5919 .41537 Mdot
.31071 .49752 Mdot
.57631 .58636 Mdot
.31841 .49855 Mdot
.41475 .65313 Mdot
.35927 .51611 Mdot
.43213 .36486 Mdot
.38445 .2629 Mdot
.43795 .37531 Mdot
.4227 .49893 Mdot
.80164 .56175 Mdot
.43615 .40917 Mdot
.24362 .50171 Mdot
.61492 .63013 Mdot
.67721 .36449 Mdot
.30098 .53658 Mdot
.36338 .49952 Mdot
.43643 .48354 Mdot
.64375 .38345 Mdot
.31089 .49959 Mdot
.72517 .39631 Mdot
.7263 .24303 Mdot
.53258 .63147 Mdot
.48061 .79049 Mdot
.63853 .40103 Mdot
.27913 .52644 Mdot
.56704 .30166 Mdot
.59927 .36727 Mdot
.32888 .54039 Mdot
.45355 .38802 Mdot
.41913 .39506 Mdot
.61467 .55039 Mdot
.39428 .41606 Mdot
.27861 .50218 Mdot
.44535 .2288 Mdot
.6108 .36179 Mdot
.32402 .4514 Mdot
.44807 .64074 Mdot
.32562 .52454 Mdot
.61752 .51759 Mdot
.59054 .34571 Mdot
.3659 .51776 Mdot
.38071 .74864 Mdot
.41881 .85344 Mdot
.31182 .50026 Mdot
.6124 .36128 Mdot
.6411 .36513 Mdot
.55416 .53105 Mdot
.47021 .46986 Mdot
.29232 .50117 Mdot
.3649 .36171 Mdot
.62855 .75497 Mdot
.37789 .28003 Mdot
.60791 .19617 Mdot
.62381 .61599 Mdot
.62541 .58958 Mdot
.44519 .36935 Mdot
.58615 .60206 Mdot
.66503 .37467 Mdot
.55401 .59251 Mdot
.46171 .37178 Mdot
.31875 .4928 Mdot
.57117 .56971 Mdot
.42519 .67265 Mdot
.43376 .36214 Mdot
.41305 .3585 Mdot
.33129 .51206 Mdot
.60166 .38939 Mdot
.21596 .4398 Mdot
.34919 .51502 Mdot
.6205 .60356 Mdot
.37978 .26957 Mdot
.63034 .54608 Mdot
.32984 .70861 Mdot
.60671 .35781 Mdot
.2936 .53013 Mdot
.6004 .40862 Mdot
.43372 .37909 Mdot
.36122 .49095 Mdot
.59237 .59039 Mdot
.33693 .53986 Mdot
.40827 .7152 Mdot
.29833 .67016 Mdot
.6543 .34499 Mdot
.44369 .62644 Mdot
.63374 .34212 Mdot
.37887 .28104 Mdot
.48151 .71327 Mdot
.43727 .65094 Mdot
.31302 .52605 Mdot
.20649 .58493 Mdot
.33559 .54427 Mdot
.57649 .5982 Mdot
.58233 .61337 Mdot
.28964 .51504 Mdot
.43313 .67736 Mdot
.7857 .66018 Mdot
.49214 .55887 Mdot
.61421 .40725 Mdot
.65779 .29852 Mdot
.30548 .78605 Mdot
.47824 .39183 Mdot
.45596 .37607 Mdot
.60816 .66104 Mdot
.65109 .59694 Mdot
.42321 .35708 Mdot
.42333 .42323 Mdot
.43414 .68404 Mdot
.3547 .52173 Mdot
.66341 .41607 Mdot
.43611 .35954 Mdot
.55464 .67516 Mdot
.67027 .7195 Mdot
.54644 .54009 Mdot
.66918 .58273 Mdot
.58837 .63318 Mdot
.41795 .5147 Mdot
.43951 .42064 Mdot
.60634 .58532 Mdot
.64495 .65016 Mdot
.45008 .40186 Mdot
.41862 .64922 Mdot
.66745 .42227 Mdot
.31827 .50594 Mdot
.60485 .13895 Mdot
.57929 .55479 Mdot
.57296 .58762 Mdot
.42399 .40233 Mdot
.57237 .18515 Mdot
.65351 .38583 Mdot
.60251 .37604 Mdot
.33217 .52663 Mdot
.4325 .48181 Mdot
.55633 .58806 Mdot
.60421 .59596 Mdot
.31363 .52139 Mdot
.38171 .26169 Mdot
.4228 .19993 Mdot
.60671 .57331 Mdot
.42021 .38182 Mdot
.33924 .46331 Mdot
.43665 .422 Mdot
.63039 .55376 Mdot
.57737 .60176 Mdot
.55886 .59403 Mdot
.65138 .60792 Mdot
.41182 .36152 Mdot
.60138 .59541 Mdot
.65571 .5327 Mdot
.60955 .39344 Mdot
.61215 .61449 Mdot
.62565 .74359 Mdot
.60186 .56807 Mdot
.42269 .67066 Mdot
.22454 .39437 Mdot
.59483 .55637 Mdot
.6129 .6122 Mdot
.49114 .55103 Mdot
.57985 .57686 Mdot
.40794 .39436 Mdot
.63893 .36909 Mdot
.42878 .37637 Mdot
.42669 .41712 Mdot
.34542 .48696 Mdot
.43021 .68412 Mdot
.61152 .52819 Mdot
.45152 .6401 Mdot
.64128 .53129 Mdot
.63509 .55454 Mdot
.38924 .53888 Mdot
.54443 .3187 Mdot
.39506 .69575 Mdot
.59437 .58618 Mdot
.33103 .52236 Mdot
.30428 .53608 Mdot
.42827 .74996 Mdot
.52965 .57617 Mdot
.421 .35951 Mdot
.45199 .38463 Mdot
.53458 .74131 Mdot
.54998 .40213 Mdot
.41844 .66523 Mdot
.50884 .41014 Mdot
.60101 .63259 Mdot
.61348 .56795 Mdot
.55422 .61419 Mdot
.32141 .48278 Mdot
.37523 .25668 Mdot
.32984 .49425 Mdot
.35671 .25144 Mdot
.43797 .42294 Mdot
.59709 .62828 Mdot
.31284 .73839 Mdot
.65309 .35411 Mdot
.63799 .36842 Mdot
.45771 .36045 Mdot
.30303 .49063 Mdot
.56527 .52438 Mdot
.86976 .44097 Mdot
.6433 .32154 Mdot
.40481 .64703 Mdot
.60693 .59506 Mdot
.33234 .51523 Mdot
.6571 .35661 Mdot
.47387 .65545 Mdot
.59017 .62446 Mdot
.37181 .52213 Mdot
.59693 .56931 Mdot
.704 .52653 Mdot
.61272 .39841 Mdot
.28991 .25968 Mdot
.65464 .3432 Mdot
.44757 .36221 Mdot
.43715 .41602 Mdot
.57458 .60344 Mdot
.80555 .34831 Mdot
.61619 .33357 Mdot
.43132 .43152 Mdot
.40829 .65771 Mdot
.36429 .2601 Mdot
.41026 .6734 Mdot
.27681 .51271 Mdot
.4408 .65828 Mdot
.35151 .53729 Mdot
.53501 .75409 Mdot
.65428 .3275 Mdot
.44728 .65146 Mdot
.53815 .17419 Mdot
.5717 .54325 Mdot
.44529 .68263 Mdot
.67845 .5722 Mdot
.62017 .3059 Mdot
.31489 .51865 Mdot
.43299 .67662 Mdot
.63195 .57374 Mdot
.23798 .6808 Mdot
.43207 .41707 Mdot
.41898 .36044 Mdot
.60667 .52703 Mdot
.33016 .54774 Mdot
.58221 .36656 Mdot
.41907 .56804 Mdot
.37733 .29337 Mdot
.6034 .59477 Mdot
.59569 .6288 Mdot
.62578 .33874 Mdot
.66782 .3861 Mdot
.57794 .60481 Mdot
.72008 .41747 Mdot
.59481 .60544 Mdot
.41694 .39658 Mdot
.64837 .40307 Mdot
.63888 .36491 Mdot
.28247 .4967 Mdot
.64151 .34021 Mdot
.6704 .59678 Mdot
.40833 .34973 Mdot
.59789 .65082 Mdot
.43491 .38347 Mdot
.46412 .52333 Mdot
.35731 .50712 Mdot
.21266 .64363 Mdot
.63616 .33651 Mdot
.61463 .60509 Mdot
.62986 .3425 Mdot
.45438 .64741 Mdot
.62147 .36678 Mdot
.61458 .41997 Mdot
.58043 .6161 Mdot
.63524 .56211 Mdot
.3838 .26744 Mdot
.46595 .47091 Mdot
.6129 .38706 Mdot
.59853 .60642 Mdot
.65746 .5745 Mdot
.58515 .54085 Mdot
.48865 .48235 Mdot
.64733 .40827 Mdot
.77838 .42674 Mdot
.33775 .72854 Mdot
.61678 .3919 Mdot
.22644 .70013 Mdot
.37956 .28741 Mdot
.36968 .25293 Mdot
.47492 .39671 Mdot
.60808 .57028 Mdot
.30358 .49497 Mdot
.59804 .54673 Mdot
.53228 .62579 Mdot
.58641 .55515 Mdot
.41141 .66217 Mdot
.63568 .5329 Mdot
.36934 .2735 Mdot
.34574 .50981 Mdot
.6035 .61925 Mdot
.57486 .5644 Mdot
.3791 .25495 Mdot
.65013 .33816 Mdot
.63522 .41326 Mdot
.20059 .41441 Mdot
.43549 .64474 Mdot
.44291 .39448 Mdot
.61059 .5522 Mdot
.33134 .52416 Mdot
.32291 .49853 Mdot
.6203 .34734 Mdot
.31245 .50742 Mdot
.40776 .38496 Mdot
.58845 .59366 Mdot
.4195 .35791 Mdot
.41169 .66044 Mdot
.61356 .35992 Mdot
.60963 .55138 Mdot
.63106 .56608 Mdot
.62106 .40235 Mdot
.6142 .63043 Mdot
.44302 .68079 Mdot
.35296 .52907 Mdot
.63549 .41162 Mdot
.44222 .38655 Mdot
.28766 .4927 Mdot
.64044 .57953 Mdot
.47824 .8516 Mdot
.58791 .60475 Mdot
.61824 .56196 Mdot
.16421 .50336 Mdot
.6208 .65815 Mdot
.27687 .52138 Mdot
.60929 .34791 Mdot
.54902 .56441 Mdot
.63035 .76672 Mdot
.32792 .27948 Mdot
.33422 .47806 Mdot
.61059 .59794 Mdot
.20478 .62913 Mdot
.61026 .60688 Mdot
.30054 .45057 Mdot
.39507 .5323 Mdot
.54221 .81077 Mdot
.67128 .58458 Mdot
.40141 .38835 Mdot
.38509 .26715 Mdot
.31039 .54116 Mdot
.74133 .57851 Mdot
.59375 .61714 Mdot
.746 .60587 Mdot
.56753 .56157 Mdot
.41561 .39306 Mdot
.69323 .60572 Mdot
.30735 .50744 Mdot
.70204 .29017 Mdot
.62466 .59927 Mdot
.64856 .40609 Mdot
.31325 .479 Mdot
.36426 .27325 Mdot
.63054 .57006 Mdot
.44025 .63723 Mdot
.45383 .32997 Mdot
.67848 .60392 Mdot
.43676 .38497 Mdot
.6163 .57551 Mdot
.54507 .62847 Mdot
.76635 .31352 Mdot
.61049 .39854 Mdot
.45602 .38008 Mdot
.57063 .22341 Mdot
.61431 .63238 Mdot
.62898 .4135 Mdot
.63804 .37332 Mdot
.4268 .64134 Mdot
.51235 .37966 Mdot
.4022 .3151 Mdot
.38136 .78048 Mdot
.78355 .56566 Mdot
.27606 .50075 Mdot
.47283 .21635 Mdot
.63414 .61334 Mdot
.50309 .56368 Mdot
.40887 .39766 Mdot
.57437 .58528 Mdot
.80374 .5392 Mdot
.61317 .37373 Mdot
.60359 .57551 Mdot
.41734 .65409 Mdot
.48588 .35063 Mdot
.52478 .48834 Mdot
.39771 .82335 Mdot
.3291 .47887 Mdot
.56876 .63656 Mdot
.66751 .56216 Mdot
.36955 .28658 Mdot
.64284 .56821 Mdot
.30233 .53799 Mdot
.22476 .56383 Mdot
.42792 .67754 Mdot
.65086 .34785 Mdot
.3776 .28717 Mdot
.56956 .6238 Mdot
.62402 .53653 Mdot
.39969 .66186 Mdot
.63025 .58079 Mdot
.6941 .28182 Mdot
.40541 .27993 Mdot
.32174 .53405 Mdot
.60567 .40005 Mdot
.59168 .63493 Mdot
.3748 .25691 Mdot
.58166 .61549 Mdot
.6942 .36578 Mdot
.6203 .58975 Mdot
.4609 .3212 Mdot
.62279 .39751 Mdot
.4386 .38121 Mdot
.60655 .52553 Mdot
.5856 .56301 Mdot
.36663 .61488 Mdot
.53345 .62766 Mdot
.57068 .56627 Mdot
.65956 .40727 Mdot
.65343 .36142 Mdot
.63564 .34773 Mdot
.33014 .53518 Mdot
.55225 .32441 Mdot
.42379 .38679 Mdot
.55803 .57226 Mdot
.43528 .35965 Mdot
.54885 .66243 Mdot
.40174 .65373 Mdot
.26916 .73134 Mdot
.60177 .62249 Mdot
.63222 .35012 Mdot
.44182 .24642 Mdot
.65927 .39025 Mdot
.36054 .54791 Mdot
.42184 .37502 Mdot
.61638 .37755 Mdot
.58476 .57409 Mdot
.48803 .44927 Mdot
.43763 .83412 Mdot
.44 .37145 Mdot
.55662 .62209 Mdot
.33989 .48182 Mdot
.36151 .52915 Mdot
.22989 .72761 Mdot
.44288 .41583 Mdot
.50395 .23576 Mdot
.60121 .60747 Mdot
.65127 .35268 Mdot
.43266 .40677 Mdot
.40758 .40143 Mdot
.31203 .51646 Mdot
.62763 .5544 Mdot
.59042 .56418 Mdot
.38521 .2859 Mdot
.44998 .38512 Mdot
.56589 .54468 Mdot
.65024 .57778 Mdot
.17938 .5436 Mdot
.67421 .40698 Mdot
.61413 .169 Mdot
.53583 .57912 Mdot
.78873 .57411 Mdot
.45226 .50157 Mdot
.65705 .38232 Mdot
.60717 .54843 Mdot
.56516 .62335 Mdot
.27302 .50499 Mdot
.58881 .59876 Mdot
.32523 .48746 Mdot
.45686 .37442 Mdot
.28437 .74699 Mdot
.34155 .44649 Mdot
.26709 .62172 Mdot
.58172 .59823 Mdot
.56842 .44903 Mdot
.45484 .65549 Mdot
.44359 .34989 Mdot
.65084 .37195 Mdot
.60175 .63752 Mdot
.27783 .53055 Mdot
.31133 .52626 Mdot
.63153 .3741 Mdot
.50479 .25678 Mdot
.22703 .51699 Mdot
.65329 .60439 Mdot
.28918 .52485 Mdot
.32856 .43497 Mdot
.72653 .43045 Mdot
.39403 .40647 Mdot
.42235 .67647 Mdot
.31802 .49332 Mdot
.40883 .36036 Mdot
.69037 .35787 Mdot
.62527 .3807 Mdot
.61511 .33944 Mdot
.34258 .67322 Mdot
.29615 .49869 Mdot
.45059 .66498 Mdot
.55149 .36503 Mdot
.56919 .32359 Mdot
.41306 .66758 Mdot
.31836 .49242 Mdot
.656 .35989 Mdot
.64852 .37398 Mdot
.64002 .36979 Mdot
.70023 .29099 Mdot
.6059 .36179 Mdot
.76068 .37732 Mdot
.65397 .56844 Mdot
.67975 .44275 Mdot
.61046 .60419 Mdot
.40541 .37239 Mdot
.61368 .39962 Mdot
.44607 .48814 Mdot
.62743 .63706 Mdot
.40165 .82136 Mdot
.60594 .59073 Mdot
.39289 .372 Mdot
.60731 .56813 Mdot
.7015 .39361 Mdot
.59824 .35466 Mdot
.59484 .58823 Mdot
.40773 .41785 Mdot
.42728 .65727 Mdot
.62993 .4414 Mdot
.59393 .55719 Mdot
.49765 .34432 Mdot
.6414 .65097 Mdot
.20805 .54877 Mdot
.41003 .59328 Mdot
.40691 .64414 Mdot
.65942 .64012 Mdot
.29199 .48614 Mdot
.5906 .42587 Mdot
.66407 .45374 Mdot
.44092 .37199 Mdot
.7491 .66111 Mdot
.31601 .52773 Mdot
.69338 .60322 Mdot
.64407 .63564 Mdot
.45405 .67427 Mdot
.58756 .41812 Mdot
.41644 .40152 Mdot
.60517 .62747 Mdot
.58562 .54428 Mdot
.378 .72223 Mdot
.66962 .44441 Mdot
.58852 .53599 Mdot
.4133 .68086 Mdot
.78539 .43374 Mdot
.60633 .55941 Mdot
.37419 .51084 Mdot
.59725 .36343 Mdot
.65049 .54173 Mdot
.77231 .41813 Mdot
.59802 .60899 Mdot
.62075 .37484 Mdot
.63219 .33606 Mdot
.46032 .28872 Mdot
.40867 .64462 Mdot
.62043 .5893 Mdot
.39052 .6125 Mdot
.62425 .59492 Mdot
.42003 .38875 Mdot
.61504 .54374 Mdot
.3208 .52257 Mdot
.56414 .30127 Mdot
.34058 .53396 Mdot
.60705 .54447 Mdot
.6448 .37614 Mdot
.41896 .40501 Mdot
.33574 .69129 Mdot
.3879 .56993 Mdot
.76547 .38542 Mdot
.34326 .26335 Mdot
.44625 .67528 Mdot
.45491 .6808 Mdot
.46274 .40056 Mdot
.59693 .58209 Mdot
.40725 .53689 Mdot
.66143 .62159 Mdot
.6065 .56473 Mdot
.58798 .55211 Mdot
.39018 .41086 Mdot
.42937 .37344 Mdot
.32272 .5021 Mdot
.57933 .60497 Mdot
.59829 .60465 Mdot
.61973 .38893 Mdot
.4269 .65473 Mdot
.33236 .53731 Mdot
.4447 .64604 Mdot
.34524 .51666 Mdot
.19397 .6654 Mdot
.54058 .59303 Mdot
.42604 .65819 Mdot
.4554 .41016 Mdot
.62445 .3492 Mdot
.39125 .26676 Mdot
.27791 .50757 Mdot
.3067 .50531 Mdot
.60281 .59746 Mdot
.61545 .36156 Mdot
.6084 .37294 Mdot
.46167 .65767 Mdot
.44525 .40065 Mdot
.60507 .54509 Mdot
.64515 .57559 Mdot
.43115 .77535 Mdot
.30224 .48614 Mdot
.73343 .41397 Mdot
.47959 .29178 Mdot
.59608 .58212 Mdot
.60589 .39258 Mdot
.56869 .57566 Mdot
.23775 .65647 Mdot
.60091 .39706 Mdot
.65066 .6156 Mdot
.55674 .39457 Mdot
.34165 .48722 Mdot
.4311 .29874 Mdot
.63891 .54257 Mdot
.3124 .26339 Mdot
.63397 .60328 Mdot
.13878 .49772 Mdot
.51081 .19883 Mdot
.55866 .60396 Mdot
.64046 .62179 Mdot
.41363 .80086 Mdot
.60439 .60887 Mdot
.37387 .2807 Mdot
.53435 .57469 Mdot
.64063 .41143 Mdot
.42304 .53496 Mdot
.32414 .56168 Mdot
.40821 .64942 Mdot
.33192 .52715 Mdot
.48998 .68371 Mdot
.42175 .64683 Mdot
.6399 .40285 Mdot
.64251 .62288 Mdot
.67859 .69492 Mdot
.35983 .54587 Mdot
.65642 .62139 Mdot
.41863 .3892 Mdot
.34265 .5609 Mdot
.33931 .49352 Mdot
.44297 .38168 Mdot
.5624 .57117 Mdot
.6786 .74535 Mdot
.37104 .57648 Mdot
.20521 .34929 Mdot
.42756 .40317 Mdot
.41203 .38793 Mdot
.59687 .28654 Mdot
.40861 .649 Mdot
.38635 .72988 Mdot
.57188 .47141 Mdot
.41621 .37388 Mdot
.53507 .71754 Mdot
.3099 .54483 Mdot
.51643 .36829 Mdot
.59478 .35531 Mdot
.54235 .59546 Mdot
.58464 .57067 Mdot
.44689 .40233 Mdot
.70078 .64657 Mdot
.64668 .26254 Mdot
.43912 .37448 Mdot
.65488 .53781 Mdot
.49965 .36512 Mdot
.38222 .27305 Mdot
.38582 .28768 Mdot
.40619 .66011 Mdot
.2354 .53097 Mdot
.63201 .39474 Mdot
.45903 .67202 Mdot
.4356 .31588 Mdot
.62142 .58376 Mdot
.45042 .37778 Mdot
.39336 .26891 Mdot
.43208 .39407 Mdot
.42547 .66718 Mdot
.40459 .64774 Mdot
.60967 .39443 Mdot
.65335 .38515 Mdot
.79229 .5866 Mdot
.55802 .74299 Mdot
.60884 .61188 Mdot
.72753 .64532 Mdot
.61362 .35564 Mdot
.63372 .46194 Mdot
.42898 .63638 Mdot
.42482 .65322 Mdot
.70516 .49636 Mdot
.63381 .56596 Mdot
.34864 .45395 Mdot
.59855 .55761 Mdot
.47673 .7209 Mdot
.63849 .63697 Mdot
.31225 .5129 Mdot
.61953 .61266 Mdot
.21908 .42093 Mdot
.6283 .62336 Mdot
.57693 .55838 Mdot
.34009 .50136 Mdot
.56396 .53171 Mdot
.31921 .52363 Mdot
.62848 .55305 Mdot
.40886 .68188 Mdot
.33167 .52428 Mdot
.50618 .79277 Mdot
.48537 .53504 Mdot
.37005 .25812 Mdot
.41302 .65091 Mdot
.4513 .6411 Mdot
.64591 .74005 Mdot
.65128 .37692 Mdot
.68365 .35041 Mdot
.59774 .58168 Mdot
.309 .54345 Mdot
.44577 .36897 Mdot
.59702 .60572 Mdot
.57091 .632 Mdot
.62072 .53131 Mdot
.6122 .37777 Mdot
.30125 .49248 Mdot
.43059 .66216 Mdot
.30048 .53213 Mdot
.35234 .59136 Mdot
.35296 .53888 Mdot
.62014 .66248 Mdot
.54544 .56113 Mdot
.51841 .57939 Mdot
.74785 .62723 Mdot
.71248 .30195 Mdot
.62994 .3793 Mdot
.37445 .26475 Mdot
.40333 .65434 Mdot
.66164 .30037 Mdot
.64123 .35504 Mdot
.30429 .50301 Mdot
.59674 .56927 Mdot
.64812 .52942 Mdot
.54089 .47711 Mdot
.57291 .35983 Mdot
.60819 .7663 Mdot
.35404 .50833 Mdot
.38014 .27818 Mdot
.56219 .31061 Mdot
.59562 .3235 Mdot
.43736 .49158 Mdot
.57806 .56486 Mdot
.44198 .63695 Mdot
.65705 .35646 Mdot
.3577 .69306 Mdot
.45155 .39321 Mdot
.46938 .46957 Mdot
.58302 .5986 Mdot
.4649 .23287 Mdot
.64449 .37663 Mdot
.41674 .65775 Mdot
.44702 .4029 Mdot
.41283 .64173 Mdot
.38108 .28958 Mdot
.19801 .42721 Mdot
.63143 .58838 Mdot
.56548 .574 Mdot
.43795 .42713 Mdot
.63382 .39245 Mdot
.38898 .49053 Mdot
.36361 .71865 Mdot
.2886 .52252 Mdot
.40299 .53531 Mdot
.65829 .38149 Mdot
.69946 .33326 Mdot
.31415 .53598 Mdot
.45974 .36162 Mdot
.42088 .51784 Mdot
.4624 .37814 Mdot
.59759 .55498 Mdot
.62917 .35593 Mdot
.44559 .41433 Mdot
.36316 .63625 Mdot
.1847 .61069 Mdot
.69106 .39729 Mdot
.60024 .62641 Mdot
.2822 .74294 Mdot
.18069 .52182 Mdot
.69108 .66494 Mdot
.44406 .36334 Mdot
.57041 .5998 Mdot
.65434 .60214 Mdot
.62316 .60294 Mdot
.4596 .39051 Mdot
.30489 .60025 Mdot
.30386 .51451 Mdot
.60958 .5891 Mdot
.45004 .64193 Mdot
.32178 .51541 Mdot
.2928 .48185 Mdot
.32234 .54464 Mdot
.61459 .41828 Mdot
.65117 .61144 Mdot
.5237 .33579 Mdot
.1419 .51732 Mdot
.43069 .37494 Mdot
.36949 .25841 Mdot
.56636 .56678 Mdot
.82966 .47752 Mdot
.63538 .34813 Mdot
.28768 .52062 Mdot
.57297 .58599 Mdot
.346 .60618 Mdot
.36424 .24151 Mdot
.35136 .51546 Mdot
.65005 .37729 Mdot
.68891 .66619 Mdot
.58957 .59972 Mdot
.6354 .60018 Mdot
.63507 .39863 Mdot
.20184 .39123 Mdot
.54925 .31665 Mdot
.57226 .56908 Mdot
.43978 .38047 Mdot
.74577 .27177 Mdot
.61795 .53234 Mdot
.60167 .33252 Mdot
.36444 .25905 Mdot
.48361 .32169 Mdot
.73806 .42108 Mdot
.55598 .64903 Mdot
.30107 .74524 Mdot
.63596 .71013 Mdot
.25525 .72425 Mdot
.47037 .68727 Mdot
.29347 .41324 Mdot
.17141 .64248 Mdot
.40582 .41702 Mdot
.66692 .44055 Mdot
.493 .81673 Mdot
.52091 .26669 Mdot
.41416 .58985 Mdot
.34142 .31886 Mdot
.37726 .59838 Mdot
.4428 .16629 Mdot
.33193 .54206 Mdot
.44911 .73271 Mdot
.60088 .54481 Mdot
.18354 .51233 Mdot
.71268 .39951 Mdot
.70955 .27952 Mdot
.24584 .70795 Mdot
.39677 .60671 Mdot
.46673 .83397 Mdot
.21255 .62883 Mdot
.70069 .69276 Mdot
.54544 .46238 Mdot
.38118 .33859 Mdot
.55515 .34651 Mdot
.50282 .68214 Mdot
.54622 .53399 Mdot
.23969 .38115 Mdot
.23568 .54834 Mdot
.80522 .47134 Mdot
.748 .28935 Mdot
.27445 .51315 Mdot
.59595 .36738 Mdot
.42615 .77815 Mdot
.60617 .44064 Mdot
.44313 .3397 Mdot
.30205 .74623 Mdot
.17585 .54888 Mdot
.70294 .39023 Mdot
.33332 .23249 Mdot
.72821 .54199 Mdot
.81529 .61831 Mdot
.49557 .49898 Mdot
.63003 .33344 Mdot
.31731 .38801 Mdot
.57008 .32312 Mdot
.37248 .39223 Mdot
.69902 .31018 Mdot
.47286 .64148 Mdot
.55281 .77884 Mdot
.64808 .38044 Mdot
.73764 .43359 Mdot
.36118 .2571 Mdot
.41488 .31228 Mdot
.38565 .51409 Mdot
.24852 .67341 Mdot
.35115 .24719 Mdot
.50794 .34896 Mdot
.44154 .22113 Mdot
.45922 .85472 Mdot
.56844 .71136 Mdot
.23726 .63185 Mdot
.39121 .43108 Mdot
.62076 .70975 Mdot
.55994 .28495 Mdot
.58269 .73854 Mdot
.59089 .31048 Mdot
.60308 .82548 Mdot
.17166 .45933 Mdot
.50909 .84283 Mdot
.64199 .43244 Mdot
.58369 .53896 Mdot
.28765 .70003 Mdot
.78119 .56022 Mdot
.40923 .64086 Mdot
.43123 .84083 Mdot
.45433 .63838 Mdot
.65492 .42195 Mdot
.51543 .25841 Mdot
.70926 .3326 Mdot
.24651 .5107 Mdot
.42512 .6897 Mdot
.66815 .61607 Mdot
.75482 .75845 Mdot
.32958 .7687 Mdot
.46779 .29782 Mdot
.17563 .54009 Mdot
.43394 .43336 Mdot
.39173 .47147 Mdot
.45813 .37696 Mdot
.17454 .62157 Mdot
.64072 .35974 Mdot
.13739 .54045 Mdot
.17372 .59884 Mdot
.62592 .23342 Mdot
.8333 .68936 Mdot
.44796 .18549 Mdot
.68661 .43935 Mdot
.67871 .70629 Mdot
.58276 .78704 Mdot
.59271 .27176 Mdot
.61495 .22136 Mdot
.39361 .34391 Mdot
.19265 .3986 Mdot
.19617 .65645 Mdot
.51403 .71945 Mdot
.24288 .56618 Mdot
.53772 .26694 Mdot
.48222 .51798 Mdot
.61572 .3255 Mdot
.47716 .56306 Mdot
.51446 .53156 Mdot
.48558 .8375 Mdot
.82284 .50383 Mdot
.83079 .37386 Mdot
.45826 .7039 Mdot
.58594 .19211 Mdot
.21202 .56915 Mdot
.48615 .78531 Mdot
.6859 .31001 Mdot
.51644 .30257 Mdot
.63602 .65565 Mdot
.54581 .33482 Mdot
.64658 .51928 Mdot
.45891 .62883 Mdot
.58033 .29815 Mdot
.26761 .45149 Mdot
.47498 .70951 Mdot
.36309 .76361 Mdot
.56106 .4303 Mdot
.61815 .41722 Mdot
.61597 .73378 Mdot
.5515 .71327 Mdot
.18634 .5487 Mdot
.56784 .22341 Mdot
.19446 .36787 Mdot
.5892 .22485 Mdot
.66191 .62231 Mdot
.64756 .45449 Mdot
.5614 .52288 Mdot
.57209 .73045 Mdot
.66055 .57907 Mdot
.43465 .23222 Mdot
.1618 .51429 Mdot
.809 .53334 Mdot
.49062 .6917 Mdot
.73864 .64286 Mdot
.18246 .41832 Mdot
.30574 .71357 Mdot
.50772 .20547 Mdot
.65548 .50026 Mdot
.69534 .79264 Mdot
.32531 .5089 Mdot
.53141 .72069 Mdot
.42095 .35177 Mdot
.34386 .67946 Mdot
.55469 .81851 Mdot
.62501 .24083 Mdot
.1605 .5078 Mdot
.52489 .30568 Mdot
.36389 .48247 Mdot
.49019 .42029 Mdot
.27125 .5428 Mdot
.7343 .65704 Mdot
.58406 .52508 Mdot
.52753 .65347 Mdot
.46207 .67196 Mdot
.77651 .54247 Mdot
.32442 .71756 Mdot
.30113 .32225 Mdot
.60445 .66895 Mdot
.29497 .35493 Mdot
.38183 .2818 Mdot
.47836 .45899 Mdot
.22108 .71642 Mdot
.53266 .61217 Mdot
.47957 .18155 Mdot
.17542 .44608 Mdot
.41203 .52131 Mdot
.2452 .62426 Mdot
.47576 .26735 Mdot
.55884 .83825 Mdot
.16384 .56204 Mdot
.21676 .4916 Mdot
.29269 .75429 Mdot
.20412 .32336 Mdot
.62359 .8057 Mdot
.72588 .59445 Mdot
.3979 .37011 Mdot
.10687 .42648 Mdot
.29597 .51659 Mdot
.75958 .65304 Mdot
.78488 .55405 Mdot
.33256 .61629 Mdot
.57928 .39617 Mdot
.68647 .63379 Mdot
.36038 .28994 Mdot
.63971 .324 Mdot
.66826 .61882 Mdot
.40487 .84239 Mdot
.61478 .82598 Mdot
.42136 .84535 Mdot
.19301 .43431 Mdot
.2808 .74733 Mdot
.46475 .81282 Mdot
.75633 .36809 Mdot
.39281 .74729 Mdot
.6207 .54641 Mdot
.51334 .73923 Mdot
.45776 .1859 Mdot
.38564 .50338 Mdot
.40802 .28737 Mdot
.61099 .42442 Mdot
.56791 .82775 Mdot
.23889 .74321 Mdot
.72482 .50282 Mdot
.77467 .44755 Mdot
.50731 .52695 Mdot
.55613 .73367 Mdot
.52614 .65958 Mdot
.25507 .35336 Mdot
.198 .55687 Mdot
.47968 .81928 Mdot
.52527 .70408 Mdot
.3282 .33144 Mdot
.23134 .47381 Mdot
.56344 .19107 Mdot
.22566 .65673 Mdot
.46298 .79615 Mdot
.60489 .22245 Mdot
.67018 .51961 Mdot
.64115 .2565 Mdot
.25578 .33211 Mdot
.36491 .46469 Mdot
.55278 .70066 Mdot
.35926 .50778 Mdot
.51345 .72468 Mdot
.53243 .43347 Mdot
.4046 .76339 Mdot
.64273 .71368 Mdot
.50537 .72122 Mdot
.23135 .48326 Mdot
.36329 .81352 Mdot
.24764 .29116 Mdot
.7051 .7479 Mdot
.29372 .27905 Mdot
.65267 .52202 Mdot
.61114 .53574 Mdot
.16637 .47597 Mdot
.34519 .81099 Mdot
.15229 .52942 Mdot
.46376 .22927 Mdot
.35715 .63625 Mdot
.39243 .39549 Mdot
.72971 .70145 Mdot
.29691 .30112 Mdot
.19135 .57824 Mdot
.63718 .29554 Mdot
.47601 .39497 Mdot
.53171 .30691 Mdot
.74433 .66307 Mdot
.69645 .70665 Mdot
.74844 .45204 Mdot
.54088 .54531 Mdot
.70985 .42426 Mdot
.60332 .35077 Mdot
.47237 .22158 Mdot
.57253 .737 Mdot
.33003 .51199 Mdot
.49087 .80021 Mdot
.52049 .64452 Mdot
.63156 .65781 Mdot
.36335 .46964 Mdot
.62106 .32517 Mdot
.7573 .61552 Mdot
.40034 .3347 Mdot
.18062 .65724 Mdot
.47164 .1949 Mdot
.62954 .69883 Mdot
.60906 .72198 Mdot
.38195 .70531 Mdot
.53616 .33513 Mdot
.46404 .39477 Mdot
.23363 .6871 Mdot
.45743 .56141 Mdot
.61599 .72989 Mdot
.71322 .42529 Mdot
.35164 .71647 Mdot
.57483 .63499 Mdot
.46206 .27515 Mdot
.78675 .40317 Mdot
.46576 .46785 Mdot
.67017 .39792 Mdot
.64033 .3194 Mdot
.43256 .15249 Mdot
.22873 .42361 Mdot
.55528 .21141 Mdot
.23818 .68681 Mdot
.46097 .37288 Mdot
.64844 .41365 Mdot
.49813 .72953 Mdot
.30398 .67245 Mdot
.80793 .45236 Mdot
.26906 .47968 Mdot
.52641 .6655 Mdot
.28877 .31794 Mdot
.28747 .7451 Mdot
.39531 .809 Mdot
.77275 .31731 Mdot
.66307 .357 Mdot
.31886 .70242 Mdot
.33655 .70483 Mdot
.65611 .34944 Mdot
.57969 .34905 Mdot
.54821 .46883 Mdot
.24765 .72677 Mdot
.5413 .3471 Mdot
.26422 .30256 Mdot
.41853 .52017 Mdot
.3293 .60256 Mdot
.36343 .70277 Mdot
.54047 .69133 Mdot
.24189 .68683 Mdot
.73492 .44543 Mdot
.62705 .78525 Mdot
.5522 .52488 Mdot
.79976 .58245 Mdot
.732 .70025 Mdot
.49144 .49454 Mdot
.7041 .34288 Mdot
.28558 .44985 Mdot
.61853 .60582 Mdot
.45384 .85553 Mdot
.19364 .53687 Mdot
.60678 .29161 Mdot
.41077 .3245 Mdot
.64551 .59537 Mdot
.65735 .58211 Mdot
.70339 .62502 Mdot
.48212 .30833 Mdot
.67609 .778 Mdot
.46102 .71524 Mdot
.64463 .51522 Mdot
.71713 .41573 Mdot
.48178 .18218 Mdot
.26272 .68459 Mdot
.20813 .55716 Mdot
.52102 .43917 Mdot
.4594 .18792 Mdot
.42049 .47355 Mdot
.25957 .30172 Mdot
.27308 .36492 Mdot
.45073 .80646 Mdot
.59704 .46164 Mdot
.49908 .3038 Mdot
.37631 .69948 Mdot
.57303 .55928 Mdot
.50455 .25713 Mdot
.21742 .63678 Mdot
.85764 .42779 Mdot
.56307 .27613 Mdot
.38566 .83742 Mdot
.51636 .61046 Mdot
.50562 .31185 Mdot
.57772 .81735 Mdot
.88199 .49879 Mdot
.24478 .36771 Mdot
.47299 .83579 Mdot
.4634 .45331 Mdot
.24622 .69996 Mdot
.39782 .38992 Mdot
.53923 .38754 Mdot
.73912 .62494 Mdot
.24074 .71995 Mdot
.2644 .66485 Mdot
.25952 .69523 Mdot
.71274 .60906 Mdot
.28528 .75734 Mdot
.61574 .30362 Mdot
.46619 .15365 Mdot
.37021 .49763 Mdot
.41345 .22195 Mdot
.70192 .55387 Mdot
.51409 .56587 Mdot
.53071 .71386 Mdot
.55235 .16651 Mdot
.73517 .32367 Mdot
.71825 .61775 Mdot
.48314 .75999 Mdot
.48007 .27788 Mdot
.61092 .7196 Mdot
.1882 .59039 Mdot
.44776 .16276 Mdot
.35165 .70242 Mdot
.51519 .22231 Mdot
.19599 .41738 Mdot
.4765 .30751 Mdot
.26199 .40408 Mdot
.23565 .63201 Mdot
.23094 .34762 Mdot
.51567 .65456 Mdot
.50484 .11338 Mdot
.25579 .56061 Mdot
.54638 .47194 Mdot
.53609 .8382 Mdot
.19839 .55312 Mdot
.65367 .29514 Mdot
.68521 .27466 Mdot
.80019 .60106 Mdot
.53359 .75642 Mdot
.58673 .55522 Mdot
.29429 .76752 Mdot
.52554 .78227 Mdot
.45442 .84397 Mdot
.16878 .4208 Mdot
.70278 .44454 Mdot
.56855 .6535 Mdot
.26591 .51185 Mdot
.51099 .49901 Mdot
.47182 .75743 Mdot
.48108 .82753 Mdot
.77937 .62175 Mdot
.39861 .56612 Mdot
.2953 .40325 Mdot
.27217 .47475 Mdot
.62288 .48899 Mdot
.43983 .19359 Mdot
.48541 .29403 Mdot
.47267 .69709 Mdot
.22571 .47033 Mdot
.55013 .72557 Mdot
.73429 .41793 Mdot
.69118 .71732 Mdot
.60794 .25274 Mdot
.48584 .38249 Mdot
.27164 .50861 Mdot
.39617 .78576 Mdot
.22194 .5303 Mdot
.43366 .23596 Mdot
.67716 .76252 Mdot
.51648 .29624 Mdot
.44317 .73772 Mdot
.35082 .74295 Mdot
.59097 .26765 Mdot
.37639 .34088 Mdot
.70899 .70071 Mdot
.79953 .57971 Mdot
.27998 .46076 Mdot
.61964 .67477 Mdot
.19802 .66844 Mdot
.54448 .69633 Mdot
.38263 .75538 Mdot
.48893 .52728 Mdot
.79056 .51794 Mdot
.6765 .48952 Mdot
.53543 .79419 Mdot
.43773 .4808 Mdot
.73393 .77051 Mdot
.58189 .38092 Mdot
.46216 .85564 Mdot
.44547 .38957 Mdot
.80728 .38152 Mdot
.22909 .50273 Mdot
.51899 .45596 Mdot
.44041 .50434 Mdot
.45936 .27694 Mdot
.49373 .34878 Mdot
.19106 .41686 Mdot
.63686 .25063 Mdot
.35099 .54093 Mdot
.40149 .57295 Mdot
.26213 .31141 Mdot
.36793 .77516 Mdot
.55309 .56014 Mdot
.23499 .53941 Mdot
.4887 .4995 Mdot
.39296 .51448 Mdot
.16904 .47848 Mdot
.30513 .44169 Mdot
.64638 .53428 Mdot
.55837 .73612 Mdot
.5014 .82981 Mdot
.17669 .59232 Mdot
.65183 .272 Mdot
.6451 .51845 Mdot
.40824 .35193 Mdot
.54788 .80848 Mdot
.32825 .76333 Mdot
.34348 .45188 Mdot
.5202 .35746 Mdot
.561 .70931 Mdot
.47585 .87825 Mdot
.61003 .82569 Mdot
.68943 .76118 Mdot
.41103 .53054 Mdot
.67553 .35379 Mdot
.82949 .48942 Mdot
.38019 .75381 Mdot
.40365 .23225 Mdot
.20557 .5147 Mdot
.53739 .72052 Mdot
.86811 .49356 Mdot
.72339 .32424 Mdot
.34651 .58947 Mdot
.67872 .49207 Mdot
.7787 .57676 Mdot
.39998 .40365 Mdot
.5201 .76211 Mdot
.43115 .57627 Mdot
.46945 .37623 Mdot
.4813 .28108 Mdot
.50425 .35524 Mdot
.38478 .75645 Mdot
.79613 .43178 Mdot
.61875 .50348 Mdot
.33983 .75817 Mdot
.65918 .33225 Mdot
.35469 .69361 Mdot
.38442 .71428 Mdot
.41591 .5809 Mdot
.29924 .5284 Mdot
.52608 .57422 Mdot
.49304 .4321 Mdot
.44567 .46649 Mdot
.75132 .7029 Mdot
.46158 .64205 Mdot
.59423 .41283 Mdot
.70664 .29594 Mdot
.66538 .36723 Mdot
.32718 .80223 Mdot
.25509 .35471 Mdot
.71276 .41465 Mdot
.258 .54544 Mdot
.3219 .35855 Mdot
.81874 .63518 Mdot
.72287 .68095 Mdot
.49063 .56549 Mdot
.62364 .30873 Mdot
.62657 .341 Mdot
.25726 .52781 Mdot
.40044 .2984 Mdot
.75397 .44045 Mdot
.47371 .17618 Mdot
.39846 .74296 Mdot
.63976 .33387 Mdot
.32709 .59235 Mdot
.64134 .69308 Mdot
.2072 .69333 Mdot
.3131 .54032 Mdot
.6752 .80165 Mdot
.54404 .5639 Mdot
.59549 .80243 Mdot
.16707 .48497 Mdot
.56816 .29617 Mdot
.40164 .54279 Mdot
.35973 .3213 Mdot
.55161 .58559 Mdot
.60589 .49974 Mdot
.64892 .38838 Mdot
.38395 .73301 Mdot
.43777 .65517 Mdot
.59797 .76043 Mdot
.46311 .36774 Mdot
.60602 .20887 Mdot
.44582 .1969 Mdot
.59375 .36855 Mdot
.45134 .57504 Mdot
.28497 .68803 Mdot
.55356 .43674 Mdot
.48773 .4993 Mdot
.4116 .79795 Mdot
.80965 .46452 Mdot
.63685 .33464 Mdot
.67722 .76539 Mdot
.41436 .72489 Mdot
.16339 .59845 Mdot
.62874 .68755 Mdot
.50549 .49207 Mdot
.55707 .43668 Mdot
.46465 .26902 Mdot
.743 .42303 Mdot
.20303 .56247 Mdot
.60396 .73492 Mdot
.55548 .36237 Mdot
.50505 .72332 Mdot
.6059 .51439 Mdot
.29066 .40421 Mdot
.41411 .21154 Mdot
.86582 .51471 Mdot
.71297 .53382 Mdot
.54788 .2995 Mdot
.63069 .31452 Mdot
.47689 .18186 Mdot
.58612 .40008 Mdot
.30293 .62631 Mdot
.80847 .48108 Mdot
.22637 .50641 Mdot
.18038 .64009 Mdot
.18705 .54663 Mdot
.52899 .50185 Mdot
.31055 .46338 Mdot
.64315 .70652 Mdot
.64668 .68852 Mdot
.47024 .48324 Mdot
.55307 .58392 Mdot
.64487 .50609 Mdot
.63897 .27307 Mdot
.43964 .24533 Mdot
.68855 .62292 Mdot
.22971 .69992 Mdot
.16308 .58861 Mdot
.32595 .782 Mdot
.36943 .4582 Mdot
.61916 .42139 Mdot
.57284 .83479 Mdot
.74091 .3871 Mdot
.18537 .58785 Mdot
.70738 .56163 Mdot
.4088 .16257 Mdot
.53984 .82227 Mdot
.27132 .45363 Mdot
.62361 .22959 Mdot
.41528 .28811 Mdot
.17413 .48207 Mdot
.4647 .15416 Mdot
.51062 .66074 Mdot
.16747 .46498 Mdot
.75361 .75827 Mdot
.72044 .56875 Mdot
.503 .34826 Mdot
.66454 .47638 Mdot
.63212 .70329 Mdot
.47198 .16969 Mdot
.61644 .54263 Mdot
.36655 .51518 Mdot
.3891 .59233 Mdot
.54728 .72041 Mdot
.54427 .65158 Mdot
.48301 .16781 Mdot
.46536 .75542 Mdot
.44479 .73151 Mdot
.32323 .69349 Mdot
.5036 .821 Mdot
.75125 .42847 Mdot
.66352 .55417 Mdot
.65762 .42338 Mdot
.40855 .66676 Mdot
.49561 .66976 Mdot
.64978 .58813 Mdot
.39962 .52456 Mdot
.56015 .4659 Mdot
.40321 .84415 Mdot
.30604 .65093 Mdot
.25788 .61588 Mdot
.63872 .32101 Mdot
.47837 .29767 Mdot
.30289 .72023 Mdot
.51881 .26339 Mdot
.51054 .16558 Mdot
.82046 .51083 Mdot
.29617 .75084 Mdot
.51901 .31354 Mdot
.50634 .69545 Mdot
.78202 .66784 Mdot
.40941 .37123 Mdot
.75492 .60336 Mdot
.46488 .81735 Mdot
.50847 .27428 Mdot
.66578 .40042 Mdot
.25156 .44913 Mdot
.30548 .41625 Mdot
.49794 .27618 Mdot
.17684 .44236 Mdot
.33154 .71417 Mdot
.68735 .47359 Mdot
.38001 .79787 Mdot
.32412 .48002 Mdot
.52437 .70583 Mdot
.24063 .43213 Mdot
.45903 .16655 Mdot
.55611 .42372 Mdot
.2072 .68001 Mdot
.46164 .48676 Mdot
.53567 .78461 Mdot
.63247 .59351 Mdot
.77579 .42159 Mdot
.44851 .25433 Mdot
.23317 .4612 Mdot
.55536 .21688 Mdot
.60402 .40862 Mdot
.45037 .21137 Mdot
.3845 .33998 Mdot
.53361 .76798 Mdot
.50208 .63298 Mdot
.63455 .44755 Mdot
.46066 .68825 Mdot
.35741 .26849 Mdot
.56119 .54575 Mdot
.57164 .78076 Mdot
.24145 .50637 Mdot
.74513 .60899 Mdot
.72705 .59002 Mdot
.39678 .78766 Mdot
.2234 .56342 Mdot
.4256 .2355 Mdot
.71992 .59755 Mdot
.45154 .31702 Mdot
.72981 .33658 Mdot
.52817 .24517 Mdot
.64461 .548 Mdot
.30408 .62402 Mdot
.6522 .40544 Mdot
.37382 .78127 Mdot
.68148 .40635 Mdot
.50118 .79218 Mdot
.49964 .44962 Mdot
.27852 .6937 Mdot
.47238 .53149 Mdot
.16919 .48615 Mdot
.41438 .28621 Mdot
.57487 .73752 Mdot
.46219 .41144 Mdot
.46333 .45182 Mdot
.5692 .27039 Mdot
.20518 .64839 Mdot
.61935 .24811 Mdot
.68629 .69229 Mdot
.53858 .30174 Mdot
.7976 .56031 Mdot
.16461 .43818 Mdot
.56337 .74851 Mdot
.47204 .482 Mdot
.57786 .68771 Mdot
.42262 .3122 Mdot
.38988 .2637 Mdot
.32341 .62917 Mdot
.74838 .40937 Mdot
.26314 .60017 Mdot
.37387 .56864 Mdot
.57141 .5415 Mdot
.82818 .46833 Mdot
.36159 .78392 Mdot
.66281 .29848 Mdot
.50918 .46764 Mdot
.37358 .68243 Mdot
.54166 .77033 Mdot
.67205 .18061 Mdot
.44752 .85659 Mdot
.63313 .59239 Mdot
.42323 .52363 Mdot
.58822 .76023 Mdot
.32782 .48825 Mdot
.7583 .45157 Mdot
.39189 .78652 Mdot
.41301 .38176 Mdot
.35359 .64859 Mdot
.39777 .25486 Mdot
.45273 .27057 Mdot
.52533 .79756 Mdot
.39489 .41803 Mdot
.35139 .8211 Mdot
.20728 .50534 Mdot
.45473 .25028 Mdot
.57789 .12428 Mdot
.45119 .2282 Mdot
.67479 .34162 Mdot
.25372 .65671 Mdot
.35729 .81004 Mdot
.41213 .5266 Mdot
.34259 .67387 Mdot
.72964 .5927 Mdot
.58613 .73728 Mdot
.47206 .71892 Mdot
.51288 .22202 Mdot
.46657 .21037 Mdot
.47647 .15159 Mdot
.32302 .35663 Mdot
.75975 .70141 Mdot
.7264 .43746 Mdot
.39819 .81476 Mdot
.24738 .3626 Mdot
.86629 .47933 Mdot
.17527 .62268 Mdot
.50396 .74399 Mdot
.50499 .17119 Mdot
.24973 .64235 Mdot
.62593 .75512 Mdot
.80603 .41994 Mdot
.22877 .38186 Mdot
.81656 .48724 Mdot
.31178 .35118 Mdot
.54542 .23388 Mdot
.50993 .72349 Mdot
.78683 .57251 Mdot
.456 .48708 Mdot
.44988 .8239 Mdot
.58402 .18356 Mdot
.59669 .72103 Mdot
.36301 .65125 Mdot
.6329 .76169 Mdot
.3344 .76016 Mdot
.22558 .63041 Mdot
.46435 .49983 Mdot
.76104 .7445 Mdot
.48379 .83665 Mdot
.53138 .25778 Mdot
.65081 .56218 Mdot
.16757 .62713 Mdot
.44054 .5348 Mdot
.72329 .60709 Mdot
.18641 .49002 Mdot
.45677 .71333 Mdot
.57461 .45839 Mdot
.61361 .52987 Mdot
.71802 .69317 Mdot
.70042 .35282 Mdot
.77966 .58136 Mdot
.37999 .67027 Mdot
.60909 .72376 Mdot
.59138 .18908 Mdot
.58584 .7919 Mdot
.65552 .68106 Mdot
.6578 .38864 Mdot
.37842 .82769 Mdot
.699 .69182 Mdot
.53227 .54114 Mdot
.67161 .45574 Mdot
.62627 .24921 Mdot
.35935 .29414 Mdot
.65484 .52661 Mdot
.53497 .33853 Mdot
.53362 .71381 Mdot
.37089 .74695 Mdot
.73228 .63131 Mdot
.84506 .67764 Mdot
.16419 .49074 Mdot
.58265 .36403 Mdot
.74958 .5872 Mdot
.40116 .58414 Mdot
.33263 .78356 Mdot
.32524 .32805 Mdot
.38277 .70854 Mdot
.68891 .25842 Mdot
.62464 .74059 Mdot
.60789 .64471 Mdot
.19013 .43849 Mdot
.18621 .6332 Mdot
.61051 .19149 Mdot
.19797 .66722 Mdot
.58012 .65612 Mdot
.54827 .6183 Mdot
.85344 .3744 Mdot
.26492 .72289 Mdot
.55264 .64512 Mdot
.65606 .2564 Mdot
.57881 .39989 Mdot
.60812 .54566 Mdot
.3975 .25673 Mdot
.55575 .69531 Mdot
.46453 .72468 Mdot
.24446 .72283 Mdot
.65628 .333 Mdot
.40033 .53441 Mdot
.41013 .35902 Mdot
.44159 .49858 Mdot
.64021 .52567 Mdot
.44199 .41752 Mdot
.46143 .73267 Mdot
.43094 .54158 Mdot
.44371 .32493 Mdot
.50996 .65127 Mdot
.25263 .29395 Mdot
.52471 .54069 Mdot
.52207 .50748 Mdot
.70015 .56696 Mdot
.73516 .32226 Mdot
.46852 .75584 Mdot
.44063 .75358 Mdot
.16954 .45878 Mdot
.24789 .26557 Mdot
.29791 .56113 Mdot
.67323 .6579 Mdot
.58241 .43393 Mdot
.74125 .40998 Mdot
.67754 .4667 Mdot
.48866 .39971 Mdot
.3895 .27466 Mdot
.61482 .66075 Mdot
.62754 .69852 Mdot
.45096 .36145 Mdot
.44296 .86743 Mdot
.62791 .54406 Mdot
.71785 .46448 Mdot
.20041 .61851 Mdot
.35817 .69414 Mdot
.57743 .48478 Mdot
.55258 .59222 Mdot
.62174 .30139 Mdot
.43344 .5444 Mdot
.66762 .69352 Mdot
.36883 .70763 Mdot
.34397 .78479 Mdot
.55396 .49987 Mdot
.7064 .45766 Mdot
.60452 .59031 Mdot
.43269 .68883 Mdot
.52128 .37459 Mdot
.70967 .7262 Mdot
.49314 .63115 Mdot
.17862 .58315 Mdot
.42419 .7203 Mdot
.46101 .71473 Mdot
.68618 .42815 Mdot
.45057 .84544 Mdot
.55672 .2763 Mdot
.70072 .43994 Mdot
.63 .28103 Mdot
.26317 .41781 Mdot
.48388 .7584 Mdot
.26097 .50718 Mdot
.68837 .62087 Mdot
.58197 .41105 Mdot
.25414 .74438 Mdot
.72639 .67815 Mdot
.46087 .43654 Mdot
.27164 .46553 Mdot
.72977 .34534 Mdot
.44572 .50105 Mdot
.5368 .11668 Mdot
.33668 .31461 Mdot
.35727 .82421 Mdot
.35466 .7272 Mdot
.58017 .43351 Mdot
.48127 .27487 Mdot
.52352 .59518 Mdot
.33286 .50018 Mdot
.33769 .78462 Mdot
.593 .68662 Mdot
.52572 .23741 Mdot
.63199 .55457 Mdot
.58256 .30941 Mdot
.63869 .69755 Mdot
.32061 .45902 Mdot
.36324 .52667 Mdot
.64444 .26496 Mdot
.22686 .64549 Mdot
.43475 .54527 Mdot
.39109 .1812 Mdot
.48292 .82895 Mdot
.23161 .68511 Mdot
.27353 .47504 Mdot
.80672 .37278 Mdot
.63958 .31247 Mdot
.64956 .68931 Mdot
.45884 .42178 Mdot
.68311 .70645 Mdot
.50191 .27304 Mdot
.37173 .74209 Mdot
.45495 .31517 Mdot
.54471 .45354 Mdot
.44008 .11023 Mdot
.50018 .73774 Mdot
.66336 .30644 Mdot
.49377 .252 Mdot
.21865 .68148 Mdot
.40784 .61319 Mdot
.20795 .3455 Mdot
.23181 .39882 Mdot
.63303 .52102 Mdot
.78916 .41357 Mdot
.62957 .77958 Mdot
.33926 .43222 Mdot
.78856 .67484 Mdot
.22242 .53322 Mdot
.50056 .6819 Mdot
.23364 .45499 Mdot
.66402 .36193 Mdot
.58281 .40472 Mdot
.26142 .33559 Mdot
.31118 .24205 Mdot
.69286 .64684 Mdot
.31315 .75543 Mdot
.83351 .58122 Mdot
.389 .72893 Mdot
.29717 .76179 Mdot
.39656 .44072 Mdot
.59276 .33123 Mdot
.45944 .75173 Mdot
.39211 .68888 Mdot
.32183 .48443 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`0009Kooooo0_l0002booooo`007?ooool00ol0003oooooooooo`2Eooooo`;o0000
/_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2;
ooooo`;o0000_?ooool001cooooo00?o0000ooooooooool0Roooool2o`0000Cooooo0_l0000=oooo
o`;o0000Yoooool001cooooo00?o0000ooooooooool0TOooool2o`0000;ooooo0_l00009ooooo`;o
00000oooool2o`0000Cooooo0_l0002Looooo`007?ooool00ol0003oooooooooo`2Eooooo`;o0000
3_ooool2o`0000Cooooo0_l0002Looooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0;Sooooo0_l0002?ooooo`007?ooool00ol0003oooooooooo`1joooo
o`;o0000??ooool2o`0008oooooo000Looooo`03o`000?oooooooooo07[ooooo0_l0003=ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0`?ooool3o`0008Kooooo000Looooo`03o`000?oooooooooo
0<3ooooo0ol00026ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo0_l0002:ooooo`;o00002Oooool2o`000003ooooool0
003o00000;3ooooo000Looooo`03o`000?oooooooooo08Wooooo0_l00008ooooo`?o000000?ooooo
o`000?l00000/?ooool001cooooo00?o0000ooooooooool0Toooool2o`000;Cooooo000Looooo`03
o`000?oooooooooo087ooooo0_l0000;ooooo`;o00004Oooool2o`000:Kooooo000Looooo`03o`00
0?oooooooooo06Wooooo0_l0000Fooooo`;o00002oooool2o`0000gooooo0_l00002ooooo`?o0000
YOooool001cooooo00?o0000ooooooooool0JOooool2o`00027ooooo0_l00003ooooo`;o00001_oo
ool2o`0000;ooooo0_l00003ooooo`;o00002?ooool2o`0000;ooooo0_l0000Booooo`;o0000Pooo
ool001cooooo00?o0000ooooooooool0S?ooool2o`0000?ooooo0_l00003ooooo`;o000000?ooooo
o`000?l000001Oooool2o`0000;ooooo0_l00006ooooo`;o00000_ooool2o`0001;ooooo0_l00023
ooooo`007?ooool00ol0003oooooooooo`2Dooooo`Co00002?ooool2o`0000;ooooo0_l00005oooo
o`;o00001oooool2o`00013ooooo0_l00021ooooo`007?ooool00ol0003oooooooooo`2Dooooo`Co
00004oooool2o`0000Oooooo0_l0000@ooooo`;o0000POooool001cooooo00?o0000ooooooooool0
Noooool2o`0001Wooooo1?l0000mooooo`;o0000L?ooool001cooooo00?o0000ooooooooool0Gooo
ool2o`0001[ooooo0_l0000Jooooo`Co00007oooool2o`0001_ooooo0_l0001`ooooo`007?ooool0
0ol0003oooooooooo`1Oooooo`;o0000;Oooool2o`000003ooooool0003o000000Cooooo1?l0000J
ooooo`?o00000_ooool2o`0001;ooooo0_l0001iooooo`007?ooool00ol0003oooooooooo`2>oooo
o`;o000000?oooooo`000?l000008_ooool3o`0000Cooooo0_l0000@ooooo`;o0000NOooool00006
ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooo
oooo08_ooooo0_l00004ooooo`?o00007oooool2o`0000Kooooo0ol00005ooooo`;o0000Q?ooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A006ooooo`03o`000?oooooooooo08_ooooo1?l00003ooooo`;o000000?oooooo`000?l00000
1?ooool2o`0001?ooooo0_l000000ooooooo0000o`000006ooooo`Co00000oooool3o`0000gooooo
0_l0001eooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ
8B7ok^k^00Oooooo00?o0000ooooooooool0F?ooool2o`0002cooooo0_l00005ooooo`;o00001_oo
ool2o`0000Cooooo0_l00005ooooo`;o00003?ooool2o`0000Wooooo1?l00003ooooo`;o00003_oo
ool2o`0007Gooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RH
ob4Q8Oo^k^h01_ooool3o`0005Sooooo0_l0000Yooooo`;o000000?oooooo`000?l000006_ooool2
o`00023ooooo0_l00023ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<oooo
o`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0Poooool2o`0001cooooo0_l000001?oo
oooo0000o`000?l00008ooooo`;o00004oooool2o`0008?ooooo00000ooooooo410@ooooo`02oooo
o`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Doooo
o`;o00002oooool2o`000004ooooool0003o0000o`0000Sooooo0_l0000@ooooo`;o00000oooool2
o`0000;ooooo0_l0001mooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj
^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`23ooooo`;o00002_ooool2o`0000?ooooo
0_l0000<ooooo`;o00003Oooool6o`0000[ooooo0_l00003ooooo`;o00000_ooool2o`0001Cooooo
0_l0001Wooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01_ooool00ol0003oooooooooo`23ooooo`;o00002_ooool2o`0000?ooooo0_l0000<oooo
o`Co00001?ooool2o`0000;ooooo2Ol000000ooooooo0000o`00000Vooooo`;o0000Ioooool001co
oooo00?o0000ooooooooool0Coooool2o`0004?ooooo1?l0000;ooooo`?o00001?ooool2o`0000;o
oooo1Ol00005ooooo`;o0000Soooool001cooooo00?o0000ooooooooool0Coooool2o`0003_ooooo
0_l00006ooooo`Co00002oooool2o`000003ooooool0003o000000Wooooo0_l0000Aooooo`;o0000
5oooool2o`0006[ooooo000Looooo`03o`000?oooooooooo06Sooooo0ol0000Hooooo`;o00001ooo
ool3o`0000Cooooo1Ol0000;ooooo`Go00003Oooool3o`0000Wooooo1Ol000000ooooooo0000o`00
0006ooooo`;o00003?ooool2o`0006[ooooo000Looooo`03o`000?oooooooooo06Sooooo1Ol0000F
ooooo`;o00002?ooool2o`0000Cooooo0_l0000>ooooo`?o00001Oooool2o`0000Sooooo0ol00004
ooooo`;o00000oooool3o`0000?ooooo0_l00006ooooo`;o00003_ooool2o`0000;ooooo0_l0001T
ooooo`007?ooool00ol0003oooooooooo`1[ooooo`;o00001Oooool2o`000003ooooool0003o0000
01Kooooo1?l00002ooooo`?o00005Oooool2o`0000oooooo0_l00008ooooo`?o00005_ooool2o`00
00;ooooo0_l0001Tooooo`007?ooool00ol0003oooooooooo`1Yooooo`;o00000_ooool2o`0000?o
oooo0_l000000ooooooo0000o`000003ooooo`;o00000oooool3o`0000Oooooo0_l00002ooooo`Co
00000_ooool3o`0001Oooooo0_l00009ooooo`;o00003?ooool4o`0001gooooo0_l0001Pooooo`00
7?ooool00ol0003oooooooooo`1Rooooo`;o00001Oooool2o`0000;ooooo0_l0000;ooooo`;o0000
0oooool3o`0000Gooooo1?l00008ooooo`;o00002oooool2o`0000Cooooo0_l00005ooooo`;o0000
2Oooool4o`0000[ooooo1_l00006ooooo`;o00004oooool4o`0005kooooo000Looooo`03o`000?oo
oooooooo04Oooooo0_l0000Iooooo`;o00008oooool5o`0000[ooooo0_l00008ooooo`?o00000ooo
ool3o`0000?ooooo0_l0000<ooooo`;o00002_ooool2o`0000;ooooo0_l00006ooooo`;o00005Ooo
ool2o`0005kooooo000Looooo`03o`000?oooooooooo04Oooooo0_l0000Hooooo`;o00004?ooool2
o`0000Cooooo0ol0000>ooooo`;o00002_ooool2o`0000Wooooo0_l00003ooooo`Co000000Cooooo
o`000?l0003o00006Oooool2o`0001oooooo0_l0001Oooooo`007?ooool00ol0003oooooooooo`1Q
ooooo`Co00003_ooool2o`000004ooooool0003o0000ooooo`?o00003oooool2o`00013ooooo0_l0
0009ooooo`Go00006_ooool2o`0000kooooo0_l0000?ooooo`;o0000Goooool001cooooo00?o0000
ooooooooool0Hoooool2o`0000Wooooo0_l00005ooooo`?o00004oooool3o`0000oooooo0_l00006
ooooo`Oo00006Oooool2o`000003ooooool0003o000000gooooo0ol0001_ooooo`007?ooool2o`00
05oooooo0_l0000>ooooo`Co00000oooool3o`0001?ooooo0ol00002ooooo`;o00002oooool2o`00
00Kooooo1?l00003ooooo`;o00001?ooool2o`0000oooooo1?l000001?oooooo0000o`000?ooool2
o`0000_ooooo0_l0000<ooooo`;o0000HOooool001cooooo00?o0000ooooooooool0GOooool3o`00
00Oooooo0_l00006ooooo`?o000000?oooooo`000?l000001?l00004ooooo`;o00002?ooool2o`00
00Gooooo1?l0000;ooooo`Co00002oooool2o`0000Cooooo0_l000000ooooooo0000o`00000;oooo
o`?o00001_ooool2o`0001Wooooo0_l0001Qooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o
00001_ooool4o`0000Sooooo3_l00008ooooo`?o00001?ooool2o`0000oooooo0ol00002ooooo`;o
00000oooool4o`0000Sooooo0_l0000;ooooo`;o00000oooool2o`0000?ooooo0_l00003ooooo`;o
00002?ooool3o`0006_ooooo000Looooo`03o`000?oooooooooo05[ooooo0_l00007ooooo`Co0000
1?ooool2o`0000Cooooo3_l00009ooooo`;o00005Oooool3o`0000;ooooo0_l00003ooooo`Co0000
6_ooool4o`000003ooooool0003o000000?ooooo0_l00008ooooo`?o0000Joooool001cooooo00?o
0000ooooooooool0F_ooool2o`0000Kooooo0ol00006ooooo`Co00000_ooool@o`0000Oooooo0ol0
0004ooooo`;o00001Oooool2o`0000gooooo0_l0000Rooooo`;o00000oooool2o`0007Wooooo000L
ooooo`03o`000?oooooooooo04gooooo0_l0000;ooooo`;o00001Oooool3o`0000Sooooo0ol00003
ooooo`oo00001oooool3o`0000Cooooo0_l00005ooooo`?o00002_ooool4o`0000Cooooo0_l00004
ooooo`;o00002Oooool2o`000003ooooool0003o000000gooooo0_l00009ooooo`;o00002_ooool2
o`0006;ooooo000Looooo`03o`000?oooooooooo04gooooo0_l0000Booooo`;o00003Oooool>o`00
017ooooo0_l00002ooooo`;o00000_ooool2o`0000Sooooo1_l00004ooooo`;o00001?ooool2o`00
00;ooooo0_l00005ooooo`;o000000?oooooo`000?l000000oooool3o`0000Oooooo0_l00009oooo
o`;o00001_ooool2o`0000;ooooo0_l0001Rooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o
00005_ooool>o`0000gooooo0_l00002ooooo`;o00000_ooool2o`0000[ooooo1?l0000>ooooo`;o
00000_ooool2o`0000Kooooo0_l00005ooooo`Co00001?ooool2o`0000;ooooo0_l0000?ooooo`;o
00001oooool2o`0000;ooooo0_l0001Iooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o0000
5oooool=o`0000gooooo0_l00004ooooo`?o00001?ooool3o`0000?ooooo1Ol00008ooooo`;o0000
0_ooool6o`0000Cooooo0_l00002ooooo`Co00001Oooool2o`0000Cooooo0_l00002ooooo`;o0000
2Oooool2o`0000gooooo0ol000000ooooooo0000o`00001Iooooo`007?ooool00ol0003ooooooooo
o`1Looooo`?o00002?ooool2o`0000Sooooo3Ol00002ooooo`;o00003oooool3o`0000Cooooo0ol0
0003ooooo`;o000000?oooooo`000?l000002?ooool2o`0000;ooooo1_l00004ooooo`;o00000ooo
ool3o`0001[ooooo0_l00006ooooo`;o00001_ooool2o`0005cooooo000Looooo`03o`000?oooooo
oooo05Cooooo0_l00006ooooo`?o00002?ooool2o`0000Wooooo3Ol000000ooooooo0000o`00000F
ooooo`?o00000oooool2o`00017ooooo0_l00002ooooo`;o00000oooool2o`0000gooooo0_l0000C
ooooo`;o00000oooool4o`0000Kooooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`1Doooo
o`;o00007_ooool;o`0000Cooooo0_l0000Dooooo`?o00000_ooool2o`0000Kooooo0ol00009oooo
o`;o000000?oooooo`000?l000000oooool6o`0000Cooooo0_l00003ooooo`;o00004oooool2o`00
00Gooooo0_l00006ooooo`;o0000F_ooool001cooooo00?o0000ooooooooool0>?ooool2o`0002So
oooo0_l0000@ooooo`_o00000_ooool4o`0000gooooo0_l00006ooooo`;o00002_ooool3o`0000Wo
oooo0_l000000ooooooo0000o`000005ooooo`Co00001?ooool2o`0001Cooooo1?l00006ooooo`;o
00002Oooool2o`0005Sooooo000Looooo`03o`000?oooooooooo03Sooooo0_l0000Cooooo`Co0000
4Oooool2o`0000gooooo0_l000000ooooooo0000o`000009o`0000;ooooo1?l00009ooooo`;o0000
0_ooool2o`0000Cooooo1?l00008ooooo`Co00003Oooool2o`0000;ooooo0_l000000ooooooo0000
o`000002o`000003ooooool0003o000001Oooooo1?l00002ooooo`;o00000_ooool2o`0000Wooooo
0_l0001Hooooo`007?ooool00ol0003oooooooooo`1=ooooo`Co00008?ooool2o`0000;ooooo2Ol0
000@ooooo`;o00002?ooool4o`0000Sooooo1?l0000Aooooo`;o000000Coooooo`000?l0003o0000
0_ooool2o`0000Sooooo0_l00004ooooo`;o00002?ooool2o`0000?ooooo0_l0001Wooooo`007?oo
ool00ol0003oooooooooo`1>ooooo`?o00008?ooool2o`0000;ooooo1?l000000ooooooo0000o`00
0004o`0001Cooooo0_l000000ooooooo0000o`000003o`0000Sooooo1?l0000=ooooo`;o00000_oo
ool2o`0000Oooooo1ol00002ooooo`;o00001?ooool5o`0000Gooooo0ol00002ooooo`Co00003_oo
ool2o`0000Cooooo0_l0001?ooooo`007?ooool2o`0004oooooo0ol0000<ooooo`;o00006oooool6
o`000003ooooool0003o000000Gooooo0_l00009ooooo`?o000000Coooooo`000?l0003o00002_oo
ool4o`0000Kooooo0_l00003ooooo`Go000000?oooooo`000?l000000_l00003ooooo`[o00001ooo
ool5o`0000Gooooo0ol00004ooooo`;o00003_ooool2o`0000Cooooo0_l0001?ooooo`007?ooool0
0ol0003oooooooooo`1Aooooo`?o00002?ooool3o`0002;ooooo0_l00002ooooo`;o000000?ooooo
o`000?l000002Oooool2o`0000Kooooo0_l000000ooooooo0000o`000004ooooo`?o00001?ooool2
o`000004ooooool0003o0000o`0000;ooooo1Ol00003ooooo`;o00000oooool2o`0000;ooooo1_l0
0003ooooo`Co000000Coooooo`000?l0003o00002?ooool2o`0000Gooooo0_l0001Sooooo`007?oo
ool00ol0003oooooooooo`1Aooooo`?o00002?ooool2o`0002Oooooo0_l0000@ooooo`;o00000_oo
ool2o`000003ooooool0003o000000Cooooo2Ol00002ooooo`Co00004Oooool4o`0000Gooooo1?l0
0003ooooo`;o00001oooool2o`0000Gooooo0_l00004ooooo`;o0000GOooool001cooooo00?o0000
ooooooooool0G?ooool2o`0000Kooooo0_l0000Qooooo`;o00003_ooool4o`0000cooooo1?l00005
ooooo`Go00001?ooool2o`000004ooooool0003o0000ooooo`;o00001Oooool5o`0000Wooooo0_l0
0005ooooo`;o00000_ooool2o`0000?ooooo0_l00004ooooo`;o0000GOooool001cooooo00?o0000
ooooooooool0DOooool2o`00017ooooo0_l00006ooooo`;o00005Oooool2o`000004ooooool0003o
0000o`0000;ooooo0_l0000<ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l0
0008ooooo`?o000000?oooooo`000?l000001?ooool2o`000004ooooool0003o0000ooooo`;o0000
1_ooool4o`000003ooooool0003o000000;o00002oooool2o`0000;ooooo0_l00002ooooo`?o0000
3oooool2o`0005;ooooo000Looooo`03o`000?oooooooooo057ooooo0_l0000Gooooo`Ko00003ooo
ool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`Co000000Coooooo`000?l0003o0000
2_ooool6o`0000;ooooo0ol00007ooooo`?o00000_ooool4o`0001;ooooo0_l000000ooooooo0000
o`000004o`00017ooooo0_l0000@ooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0F_oo
ool2o`0000kooooo0ol000000ooooooo0000o`00000?ooooo`;o00002Oooool4o`000004ooooool0
003o0000o`0000[ooooo1?l00004ooooo`;o00001oooool5o`0000?ooooo0_l0000Booooo`Wo0000
6Oooool3o`0000Wooooo0ol00004ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0;ooo
ool2o`0002Wooooo0_l00002ooooo`;o00002oooool2o`0000Cooooo0_l0000Aooooo`;o00002?oo
ool2o`0000;ooooo0_l00005ooooo`;o00002_ooool2o`0000Gooooo0ol000000ooooooo0000o`00
0003ooooo`;o00003oooool2o`0000;ooooo1_l00003ooooo`;o00002Oooool2o`0000Kooooo0_l0
0003ooooo`?o00002Oooool3o`0000Cooooo0_l00019ooooo`007?ooool00ol0003oooooooooo`0_
ooooo`;o00003_ooool2o`0001gooooo0_l0000Aooooo`?o00003_ooool4o`0000Kooooo1?l00002
ooooo`;o00001Oooool2o`0000[ooooo0_l00004ooooo`Oo00000oooool2o`0000Oooooo0_l00004
ooooo`Co00001?ooool3o`0000Cooooo0ol00006ooooo`Co00001_ooool3o`0000;ooooo0ol00004
ooooo`;o0000EOooool001cooooo00?o0000ooooooooool0?oooool2o`0002Gooooo0_l0000:oooo
o`;o00003_ooool2o`0000Gooooo0_l000000ooooooo0000o`00000?ooooo`;o00003?ooool7o`00
00?ooooo0_l000000ooooooo0000o`000004ooooo`;o00001?ooool4o`0000Cooooo0_l00003oooo
o`;o000000?oooooo`000?l000001_ooool3o`0000Sooooo0_l00002ooooo`;o00001Oooool2o`00
05Gooooo000Looooo`03o`000?oooooooooo04Wooooo0_l00004ooooo`;o00005?ooool4o`0001co
oooo0_l00002ooooo`;o00001Oooool2o`0000Wooooo1?l0000?ooooo`?o00001oooool2o`0000?o
oooo0ol00006ooooo`;o000000?oooooo`000?l000001?ooool5o`0000Wooooo0_l0000Kooooo`;o
0000COooool001cooooo00?o0000ooooooooool0@oooool2o`0000Cooooo0_l00004ooooo`;o0000
5?ooool4o`0001Gooooo0_l00005ooooo`;o00002Oooool2o`0000Wooooo0_l0000=ooooo`;o0000
0_ooool2o`0000gooooo0_l000000ooooooo0000o`000002ooooo`Co000000?oooooo`000?l00000
0ol000000ooooooo0000o`000003o`0000;ooooo0_l00007ooooo`;o00000_ooool2o`0000Sooooo
0_l0000;ooooo`;o0000COooool001cooooo00?o0000ooooooooool0@oooool2o`0000cooooo0_l0
000Rooooo`;o000000?oooooo`000?l000001?ooool2o`0001?ooooo0_l0000=ooooo`;o00000_oo
ool2o`0000;ooooo0_l00002ooooo`;o00004?ooool2o`000003ooooool0003o000000Wo000000?o
ooooo`000?l000000_l00002ooooo`?o00001oooool2o`0000;ooooo0_l00004ooooo`;o00000_oo
ool2o`0000cooooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o00001_ooool2
o`0001[ooooo1_l0000Aooooo`Co00000oooool2o`0000Kooooo0_l00005ooooo`;o00000_ooool2
o`0000;ooooo0_l000001?oooooo0000o`000?ooool3o`0000kooooo4_l00002ooooo`Co00001_oo
ool2o`0000;ooooo0_l00004ooooo`;o00004?ooool2o`0004cooooo000Looooo`03o`000?oooooo
oooo05Sooooo0ol0000Hooooo`;o00000_ooool4o`000003ooooool0003o000000kooooo1?l00004
ooooo`;o00001Oooool2o`000003ooooool0003o000000Kooooo0_l00005ooooo`Ko00002Oooool2
o`0000;ooooo3ol00002ooooo`;o00000_ooool4o`0000Kooooo1?l00004ooooo`;o0000H?ooool0
01cooooo00?o0000ooooooooool0@?ooool2o`0000Gooooo0_l0000?ooooo`;o00006Oooool2o`00
00Oooooo0_l00005ooooo`;o00003oooool2o`0000Sooooo0ol0000;ooooo`;o000000?oooooo`00
0?l000000_l00009ooooo`;o000000?oooooo`000?l000005?l000000ooooooo0000o`000009oooo
o`;o00001?ooool4o`0005kooooo000Looooo`;o0000@?ooool3o`000003ooooool0003o000000;o
oooo0_l0000hooooo`Co00001oooool3o`0000_ooooo0_l000000ooooooo0000o`000004o`0000Ko
oooo0_l000000ooooooo0000o`000003ooooo`;o00001_ooool2o`000003ooooool0003o000001Oo
00001Oooool3o`0000cooooo0_l0000Gooooo`;o0000AOooool001cooooo00?o0000ooooooooool0
?_ooool3o`0000;ooooo0_l0000:ooooo`;o00004Oooool2o`0001Oooooo0_l00003ooooo`?o0000
0_ooool4o`0000?ooooo0ol0000;ooooo`;o000000Coooooo`000?l0003ooooo0ol00003ooooo`Go
00001Oooool3o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`Ko00000_ooool?o`000003
ooooool0003o000000Ko00000oooool2o`0000Oooooo0_l0000Gooooo`;o0000AOooool001cooooo
00?o0000ooooooooool0?_ooool2o`0000oooooo0_l0000;ooooo`?o00000oooool2o`000003oooo
ool0003o000000gooooo0_l00005ooooo`;o00000oooool3o`0000;ooooo1_l0000Eooooo`;o0000
1?ooool3o`0000Oooooo0_l00004ooooo`;o000000?oooooo`000?l000000_ooool>o`000003oooo
ool0003o000000co00001_ooool2o`0000?ooooo0_l0001Rooooo`007?ooool00ol0003ooooooooo
o`0Xooooo`;o00009Oooool2o`0000Kooooo0_l00003ooooo`?o00001_ooool2o`0000gooooo0_l0
000;ooooo`_o00000_ooool2o`00013ooooo0_l00003ooooo`;o00003oooool2o`000003ooooool0
003o0000013o000000?oooooo`000?l000002?l00002ooooo`?o000000?oooooo`000?l000001ooo
ool2o`0006;ooooo000Looooo`03o`000?oooooooooo02Sooooo0_l0000Sooooo`;o00002?ooool2
o`0000cooooo0_l0000<ooooo`;o00003?oooolCo`00017ooooo1?l00008ooooo`?o00000_ooool2
o`0000;ooooo4Ol000000ooooooo0000o`000009o`000005ooooool0003o0000o`000?ooool00_l0
0007ooooo`;o00001?ooool2o`0005cooooo000Looooo`03o`000?oooooooooo03kooooo0_l0000=
ooooo`;o00001_ooool4o`0000gooooo0_l0000;ooooo`;o00002_ooool8o`000003ooooool0003o
000000_o00002_ooool2o`0000Kooooo0_l00006ooooo`Go00001OoooolNo`000003ooooool0003o
000000Cooooo0_l0000;ooooo`Co0000F_ooool001cooooo00?o0000ooooooooool0>oooool2o`00
0003ooooool0003o000000Wooooo0_l000000ooooooo0000o`000007ooooo`Co00003Oooool2o`00
01Cooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000ko00002_ooool2o`00
00?ooooo0_l00009ooooo`So00000_ooool3o`000003ooooool0003o000001_o00001?ooool2o`00
00Cooooo1?l00005ooooo`;o00000oooool2o`00013ooooo0_l00013ooooo`007?ooool00ol0003o
ooooooooo`0kooooo`;o00003?ooool2o`000003ooooool0003o000002kooooo6Ol0000?ooooo`;o
00002_ooool7o`0000;ooooo0ol000000ooooooo0000o`00000Ko`0000?ooooo0_l00005ooooo`Co
00000_ooool2o`0000Kooooo0_l0000@ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0
9oooool2o`0002;ooooo0_l0000_oooooaSo00003?ooool2o`0000Cooooo0_l0000:ooooo`Co0000
1oooool2o`000003ooooool0003o0000013o00000_ooool3o`0000Kooooo0_l0000;ooooo`;o0000
1oooool4o`0000_ooooo0_l00006ooooo`;o00001Oooool2o`0003Kooooo000Looooo`03o`000?oo
oooooooo02Oooooo0_l0000Mooooo`;o00000_ooool3o`0000[ooooo0_l0000VoooooaGo000000?o
ooooo`000?l000002Oooool2o`0000Cooooo0_l0000<ooooo`;o00001ooooolJo`0001cooooo1?l0
000;ooooo`;o00001_ooool2o`0000Gooooo0_l0000fooooo`007?ooool00ol0003oooooooooo`16
ooooo`Ko00002oooool2o`0002Kooooo6Ol00009ooooo`Oo00004Oooool2o`0000;ooooo5ol00000
0ooooooo0000o`00000Kooooo`?o00003Oooool2o`0004Gooooo000Looooo`03o`000?oooooooooo
04Oooooo1Ol0000doooooaGo000000?oooooo`000?l000001?l00004ooooo`So00001?ooool2o`00
00Kooooo0_l00003ooooo`;o000000?oooooo`000?l000001_l000000ooooooo0000o`00000=o`00
01[ooooo0_l00002ooooo`;o00003_ooool2o`0004Gooooo000Looooo`03o`000?oooooooooo04Oo
oooo0_l0000eooooo`Ko000000?oooooo`000?l000003ol00002ooooo`Co00001?ooool2o`000003
ooooool0003o000000Kooooo0ol00006ooooo`;o00001_oooolKo`0000[ooooo0_l00006ooooo`;o
00000_ooool3o`0000Gooooo0_l00005ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0
9Oooool2o`0001Cooooo0_l00009ooooo`;o00006oooool2o`0001Sooooo6_l000000ooooooo0000
o`00000Aooooo`;o00002oooool2o`0000?ooooo6_l0000:ooooo`;o00001_ooool2o`0000;ooooo
0_l00006ooooo`;o00001Oooool2o`0004_ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGo
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0Uooooo`;o
00005?ooool2o`000003ooooool0003o000000Kooooo0_l0000Kooooo`;o00004?ooool2o`0000Co
oooo7?l000000ooooooo0000o`000003ooooo`;o00003Oooool2o`0000[ooooo0_l000000ooooooo
0000o`00000Io`0000[ooooo0ol00006ooooo`;o0000G_ooool00006oooooomgMgOoV9RHoooooonH
V9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0moooo
o`?o00001Oooool2o`0000[ooooo0_l0000Rooooo`;o00001?oooolJo`0000;ooooo0ol00003oooo
o`;o00003Oooool2o`0000?ooooo0_l00005ooooo`;o000000?oooooo`000?l000006Ol0000:oooo
o`;o00000oooool2o`000004ooooool0003o0000o`0001;ooooo0_l0001:ooooo`0000?ooooooa0@
4?ooool00_ooool00ol@413oooooooooo`09ooooo`Go00001_ooool00ol0003oooooooooo`0koooo
o`Go00001Oooool2o`000003ooooool0003o000000Oooooo0_l0000?ooooo`;o000000?oooooo`00
0?l000003_ooool2o`0000Cooooo0ol000000ooooooo0000o`00000Ho`0000;ooooo0_l0000Doooo
o`;o00001Oooool2o`000003ooooool0003o000001Ko000000?oooooo`000?l000000_l00005oooo
o`;o00001Oooool3o`000003ooooool0003o000001?ooooo0_l0001:ooooo`0000?oooooo`000?oo
ool00_ooool00ol0003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0000koooo
o`;o000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l0000Booooo`;o00001?ooool2o`00
0003ooooool0003o000001Cooooo7?l00004ooooo`;o00004_ooool2o`0000Kooooo0ol000000ooo
oooo0000o`00000Eo`000003ooooool0003o000000?o00001Oooool3o`0000Cooooo0_l000000ooo
oooo0000o`000004ooooo`;o00003Oooool2o`0000Wooooo0_l00010ooooo`0000?oooooo`000?oo
ool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000oooo
ooooool0@_ooool2o`0000gooooo0_l00008ooooo`?o00006oooool2o`0000;ooooo3ol000000ooo
oooo0000o`000007o`0000kooooo0_l00009ooooo`;o00001_ooool2o`000004ooooool0003o0000
o`0000;ooooo2Ol000000ooooooo0000o`00000;o`0000Cooooo0_l00002ooooo`;o00000_ooool4
o`000003ooooool0003o000000Cooooo0_l0000=ooooo`;o00002Oooool2o`00043ooooo00000ooo
oooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oMgMgolc<c?l000001oooool00ol0
003oooooooooo`0Rooooo`;o00006_ooool2o`00017ooooo0_l00006ooooo`Co00006_ooool4o`00
0003ooooool0003o000000So00000_ooool5o`000003ooooool0003o000000Ko00003_ooool2o`00
01Cooooo0_l000000ooooooo0000o`00000Eo`0000?ooooo1Ol00006ooooo`Co00002Oooool2o`00
00Oooooo0_l0001?ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co
000000Oooooo00?o0000ooooooooool08_ooool2o`0001[ooooo0_l0000Dooooo`;o00000oooool2
o`0001cooooo0_l00002ooooo`?o000000?oooooo`000?l000001_l000000ooooooo0000o`00000<
o`000003ooooool0003o000000Sooooo0ol0000?ooooo`;o00001?ooool2o`0000;ooooo5ol00003
ooooo`Co00004Oooool5o`0000Oooooo0_l0000Booooo`;o0000>oooool00006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo03Wooooo0_l0
0002ooooo`;o00001Oooool2o`0000kooooo0_l00006ooooo`;o00007Oooool2o`0000;ooooo5ol0
00000ooooooo0000o`000008ooooo`?o00003oooool4o`0000;ooooo0_l000000ooooooo0000o`00
000Eo`000004ooooool0003o0000o`0000gooooo0_l00002ooooo`Oo00003_ooool2o`0000gooooo
0_l0000kooooo`007?ooool00ol0003oooooooooo`0dooooo`;o00000_ooool7o`0000Gooooo0_l0
000<ooooo`;o00002?ooool2o`0000;ooooo0_l0000Eooooo`;o00000ooooolDo`0000Cooooo0_l0
00001?oooooo0000o`000?l0000Kooooo`;o00001?oooolFo`0000?ooooo0ol0000<ooooo`[o0000
1?ooool2o`0000Cooooo0_l00004ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool07ooo
ool2o`0001;ooooo0ol00002ooooo`Ko00000_ooool2o`000003ooooool0003o000000gooooo0_l0
000<ooooo`;o00005Oooool2o`0000?ooooo0ol000000ooooooo0000o`000002o`000003ooooool0
003o000000Wo000000?oooooo`000?l000001?ooool3o`000003ooooool0003o000001Kooooo0_l0
0004ooooo`Ko00000_ooool<o`0000;ooooo0_l00003ooooo`;o00000oooool2o`0000?ooooo0ol0
0002ooooo`Go00000oooool3o`0000?ooooo0_l00004ooooo`?o00002?ooool2o`0004Gooooo000L
ooooo`03o`000?oooooooooo01oooooo0_l0000Booooo`;o00002oooool2o`000003ooooool0003o
000000;ooooo0_l0000looooo`_o000000?oooooo`000?l000002?ooool2o`0001Cooooo1?l00004
ooooo`;o00001oooool;o`0000?ooooo1?l000000ooooooo0000o`000002ooooo`;o00000oooool4
o`000003ooooool0003o000000Oooooo1?l00003ooooo`Co000000?oooooo`000?l000002?ooool3
o`0004Cooooo000Looooo`03o`000?oooooooooo01oooooo0_l0000Fooooo`;o00000_ooool4o`00
00Sooooo0_l0000Kooooo`;o00007_ooool<o`00027ooooo0_l00009ooooo`Co00000_ooool4o`00
00;ooooo1Ol00002ooooo`Go000000?oooooo`000?l000001oooool4o`000004ooooool0003o0000
o`0000Sooooo0_l00003ooooo`Co00000_ooool2o`0000Sooooo0_l0000>ooooo`;o0000=?ooool0
01cooooo00?o0000ooooooooool07oooool2o`0001Kooooo0_l00002ooooo`Co00007Oooool4o`00
00Cooooo0_l0000Eooooo`;o00001Oooool>o`0000kooooo0_l0000Booooo`;o00002?ooool4o`00
00;ooooo0_l00004ooooo`Co00000oooool2o`0000[ooooo0_l000000ooooooo0000o`000003oooo
o`?o00000_ooool2o`0000Kooooo0_l00007ooooo`?o00005oooool3o`0003?ooooo000Looooo`03
o`000?oooooooooo03_ooooo0ol0000:ooooo`Co00004?ooool4o`0000[ooooo0_l0000<ooooo`;o
000000Coooooo`000?l0003ooooo0_l00002ooooo`;o000000?oooooo`000?l000001Ol0000:oooo
o`;o00001?ooool4o`0000Wooooo0_l00004ooooo`;o000000?oooooo`000?l000001Oooool2o`00
00Wooooo0_l00002ooooo`Co000000?oooooo`000?l000002_ooool4o`0000_ooooo0_l00002oooo
o`Ko00002?ooool3o`0000;ooooo0_l00004ooooo`;o00003Oooool2o`0003?ooooo000Looooo`03
o`000?oooooooooo03_ooooo0_l0000:ooooo`Go00006oooool2o`000003ooooool0003o000000co
oooo0_l00004ooooo`?o00001oooool3o`0000Oooooo1_l00004ooooo`?o00002_ooool2o`0000Co
oooo1?l00006ooooo`;o00002Oooool2o`0000Oooooo0_l0000:ooooo`;o000000?oooooo`000?l0
00003_ooool5o`0000Cooooo0_l00004ooooo`;o00000_ooool2o`0000Cooooo0ol0000<ooooo`;o
0000<oooool001cooooo00?o0000ooooooooool0;oooool2o`000003ooooool0003o000000Cooooo
1Ol00005ooooo`;o00000oooool2o`0000_ooooo0_l00009ooooo`;o00001_ooool2o`0000oooooo
0_l00005ooooo`;o00002?ooool2o`0000Oooooo1?l00007ooooo`;o00001_ooool2o`0000Oooooo
1Ol0000Wooooo`Co00000_ooool2o`0000Kooooo0_l0000;ooooo`;o00003oooool2o`0000cooooo
0_l0000cooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o000000?oooooo`000?l000000_oo
ool6o`0000Kooooo0_l0000@ooooo`;o00002Oooool2o`0001Oooooo0_l00003ooooo`;o00001ooo
ool2o`000003ooooool0003o000000?ooooo1?l0000Cooooo`;o00001oooool2o`0000_ooooo0_l0
0004ooooo`;o00001_ooool2o`0000;ooooo0_l00006ooooo`;o00000_ooool4o`0000?ooooo0_l0
0006ooooo`;o00001oooool2o`0000oooooo0_l0000Cooooo`;o0000<?ooool001cooooo00?o0000
ooooooooool0=Oooool3o`0000[ooooo0_l0000Kooooo`;o00007?ooool2o`0000Oooooo0_l00005
ooooo`Go00009_ooool2o`000003ooooool0003o000000Cooooo0_l00006ooooo`;o00000_ooool2
o`0000Cooooo1Ol000000ooooooo0000o`000005ooooo`;o00002Oooool2o`0000Cooooo0_l0000>
ooooo`?o00004oooool2o`00033ooooo000Looooo`03o`000?oooooooooo03Gooooo0_l0000?oooo
o`?o00001Oooool2o`00017ooooo0_l00008ooooo`;o00008?ooool2o`0000_ooooo0ol0000Foooo
o`Co000000?oooooo`000?l000001_ooool2o`0000Sooooo0_l00007ooooo`;o000000?oooooo`00
0?l000002?ooool2o`0000Wooooo0_l0000;ooooo`;o00001oooool2o`0004Kooooo000Looooo`;o
0000Aoooool3o`0000Gooooo0_l00003ooooo`;o00001?ooool2o`0000;ooooo0ol000000ooooooo
0000o`000003ooooo`;o00000oooool3o`0002Gooooo0_l00005ooooo`?o00000_ooool2o`00017o
oooo1Ol00002ooooo`?o00001?ooool2o`0000Sooooo0_l0000Sooooo`;o00000_ooool2o`0000?o
oooo0_l00009ooooo`;o00000oooool2o`0003oooooo000Looooo`03o`000?oooooooooo04Oooooo
0ol00009ooooo`?o00000oooool2o`0000;ooooo1_l00003ooooo`;o00001?ooool4o`0000Gooooo
0_l0000Looooo`;o00002?ooool4o`0000cooooo0_l00003ooooo`;o000000?oooooo`000?l00000
0_ooool3o`0000Cooooo0_l0000=ooooo`;o000000?oooooo`000?l000000_l0000>ooooo`;o0000
2Oooool2o`0000;ooooo0_l0000>ooooo`;o00000oooool2o`0003oooooo000Looooo`03o`000?oo
oooooooo03?ooooo0_l0000Cooooo`;o00002_ooool2o`0000Wooooo0_l0000=ooooo`;o00001?oo
ool3o`0001cooooo0_l00008ooooo`;o00000oooool2o`000003ooooool0003o000000Kooooo0_l0
0006ooooo`Co00001oooool2o`0000gooooo0_l000000ooooooo0000o`000004o`0000Sooooo1_l0
000Eooooo`;o00002_ooool2o`00043ooooo000Looooo`03o`000?oooooooooo037ooooo1Ol0000@
ooooo`Co00003Oooool2o`0000_ooooo0_l0000>ooooo`;o00008_ooool2o`0000Sooooo0_l00000
0ooooooo0000o`00000@ooooo`;o00001Oooool2o`0001Kooooo0_l00008ooooo`Co00005oooool2
o`0000[ooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0aooooo`;o000000?oooooo`00
0?l000004?ooool4o`0000gooooo1Ol00005ooooo`;o000000?oooooo`000?l000001?ooool2o`00
00Oooooo0_l0000Hooooo`;o00002?ooool3o`0000gooooo0_l00004ooooo`;o00003oooool3o`00
00Wooooo0_l0000Aooooo`;o00001_ooool2o`0001cooooo0_l00014ooooo`007?ooool00ol0003o
ooooooooo`0cooooo`;o00008?ooool2o`0000;ooooo0ol00005ooooo`;o00001oooool2o`0000Oo
oooo0_l00006ooooo`;o00004?ooool2o`0000Gooooo1Ol00009ooooo`;o000000?oooooo`000?l0
00000_l00004ooooo`;o00000oooool2o`0000_ooooo0_l00009ooooo`;o00003?ooool2o`0000?o
oooo0_l00006ooooo`;o00007?ooool2o`0004Cooooo000Looooo`03o`000?oooooooooo03?ooooo
0_l0000@ooooo`?o00001_ooool2o`0000Gooooo0_l000000ooooooo0000o`000007ooooo`Co0000
0oooool2o`0000Sooooo0_l00007ooooo`;o00004?ooool2o`0000Gooooo1ol00007ooooo`;o0000
00?oooooo`000?l000000oooool6o`0000;ooooo0_l0000:ooooo`;o00003oooool2o`0000Oooooo
0_l0000/ooooo`;o000000?oooooo`000?l00000?_ooool001cooooo00?o0000ooooooooool06?oo
ool2o`0002_ooooo1?l00005ooooo`;o00002?ooool2o`0000Oooooo1?l00003ooooo`;o00002?oo
ool2o`0000Sooooo0_l00007ooooo`Co00002oooool3o`0000;ooooo0_l0000;ooooo`;o00000_oo
ool6o`0000Kooooo0_l00006ooooo`;o00003oooool3o`0000Wooooo0_l0000Uooooo`;o00000_oo
ool2o`000003ooooool0003o000003kooooo000Looooo`03o`000?oooooooooo01Sooooo0_l0000H
ooooo`?o000000?oooooo`000?l000003oooool2o`0000Wooooo1Ol00004ooooo`;o000000Cooooo
o`000?l0003o00001Oooool2o`000003ooooool0003o0000017ooooo1?l00005ooooo`Ko00001ooo
ool2o`0000cooooo0_l00004ooooo`;o000000?oooooo`000?l000001Ol00006ooooo`;o00006?oo
ool2o`0000;ooooo0_l00005ooooo`;o00009Oooool2o`0000?ooooo0_l000000ooooooo0000o`00
000mooooo`007?ooool00ol0003oooooooooo`0booooo`?o000000?oooooo`000?l000005_ooool2
o`0000;ooooo1Ol00004ooooo`Wo00000_ooool5o`0001?ooooo0_l00009ooooo`;o000000Cooooo
o`000?l0003o00000oooool2o`000004ooooool0003o0000ooooo`?o00000oooool4o`0000Oooooo
1Ol00007ooooo`;o00004?ooool2o`0000?ooooo0_l00006ooooo`;o0000<Oooool2o`000003oooo
ool0003o000000[ooooo0_l0000aooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o000000?o
ooooo`000?l000000ol0000?ooooo`;o00001Oooool2o`0000Cooooo0_l00005oooooa;o00001Ooo
ool2o`0001Gooooo1_l00006ooooo`So000000?oooooo`000?l000002_ooool2o`0000Wooooo0_l0
0008ooooo`;o000000?oooooo`000?l000000oooool3o`000004ooooool0003o0000o`0003Gooooo
0_l00005ooooo`;o00002_ooool2o`00037ooooo000Looooo`03o`000?oooooooooo033ooooo0_l0
00000ooooooo0000o`000002o`00013ooooo0_l0000@oooooaCo00000_ooool7o`0000Cooooo1?l0
0004ooooo`;o00001?ooool4o`0000Wooooo0ol00003ooooo`;o00004?ooool2o`0000Wooooo0_l0
0002ooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`Go00001_ooool2o`0002kooooo
0_l00014ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00005oooool2o`0000_ooooo4Ol0
00000ooooooo0000o`000005o`0000;ooooo0_l00004ooooo`Go00000oooool4o`0000;ooooo3?l0
00000ooooooo0000o`00000@ooooo`?o00000oooool2o`0000Wooooo1_l00009ooooo`;o000000?o
ooooo`000?l000001oooool2o`0000?ooooo0_l0000Yooooo`Co00000oooool2o`0003gooooo000L
ooooo`03o`000?oooooooooo03;ooooo0_l00002ooooo`;o000000?oooooo`000?l000002?ooool3
o`0000Kooooo0_l00005ooooo`;o00001?ooool2o`000003ooooool0003o000001Oo00000oooool2
o`000003ooooool0003o000000;o00000_ooool2o`000003ooooool0003o000000?o000000?ooooo
o`000?l000002?l000000ooooooo0000o`000002ooooo`;o00001Oooool2o`0000;ooooo0_l00000
1?oooooo0000o`000?l00005ooooo`;o00002Oooool2o`0000_ooooo0ol0000>ooooo`?o00002ooo
ool2o`0001gooooo0_l00003ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0<_ooool2
o`0000;ooooo0_l000000ooooooo0000o`000008ooooo`?o00003Oooool4o`000003ooooool0003o
000001Go000000?oooooo`000?l000000ol00003ooooo`;o000000?oooooo`000?l000001?ooool2
o`0000;ooooo1ol0000=ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00009
ooooo`;o00000oooool2o`0000kooooo0_l00002ooooo`;o00003oooool2o`0000_ooooo0_l0000^
ooooo`;o0000<Oooool001cooooo00?o0000ooooooooool0:Oooool2o`0000_ooooo0_l0000Moooo
oago000000?oooooo`000?l000000_l000000ooooooo0000o`000008ooooo`;o00000_ooool4o`00
00;ooooo0_l00002ooooo`;o00002_ooool2o`0000Cooooo0_l0000@ooooo`;o00000oooool2o`00
00Wooooo0_l0000Kooooo`;o0000<oooool2o`0000?ooooo0_l0000/ooooo`007?ooool2o`0002[o
oooo0_l0000;ooooo`;o00004oooool2o`0000Wooooo8Ol0000;ooooo`So00000_ooool6o`000003
ooooool0003o000000Kooooo1?l00003ooooo`;o00001?ooool2o`0000Kooooo0_l000000ooooooo
0000o`000004ooooo`;o00001_ooool2o`0000kooooo0_l0000>ooooo`;o00001Oooool2o`00037o
oooo0_l0000/ooooo`007?ooool00ol0003oooooooooo`0booooo`;o00004oooool2o`0000;ooooo
0_l00007ooooob7o00000_ooool2o`000003ooooool0003o000000?ooooo0_l00002ooooo`Oo0000
00?oooooo`000?l000001?l00002ooooo`;o00001_ooool4o`0000?ooooo0_l00004ooooo`;o0000
1_ooool2o`000003ooooool0003o000000Kooooo0_l00004ooooo`;o00000_ooool2o`0000Gooooo
0_l00003ooooo`;o00005Oooool2o`0001gooooo0ol0000oooooo`007?ooool00ol0003ooooooooo
o`0`ooooo`Co000000?oooooo`000?l000002Oooool2o`0000Cooooo0ol00002ooooo`;o00001?oo
ool:o`000003ooooool0003o000001_o000000?oooooo`000?l000000_l000000ooooooo0000o`00
0002ooooo`;o00001_ooool2o`0000_ooooo0_l0000<ooooo`;o00002oooool2o`0000Kooooo0_l0
0003ooooo`?o00000_ooool2o`0000Gooooo1?l0000<ooooo`;o00002_ooool2o`0001gooooo0ol0
000<ooooo`;o0000<Oooool001cooooo00?o0000ooooooooool0<?ooool2o`0000?ooooo0_l00006
ooooo`;o000000?oooooo`000?l000001?ooool2o`0000?ooooo0ol00003oooooaSo000000?ooooo
o`000?l000002?l000001?oooooo0000o`000?l00003ooooo`?o00001Oooool2o`0000?ooooo0_l0
000>ooooo`;o00003?ooool2o`0000_ooooo0_l000000ooooooo0000o`000007ooooo`?o00003?oo
ool2o`0000cooooo0_l0000Yooooo`;o00003Oooool2o`00037ooooo000Looooo`03o`000?oooooo
oooo02_ooooo0_l0000;ooooo`;o00000oooool2o`0000gooooo0_l00005ooooo`ko000000Gooooo
o`000?l0003o0000ooooo`0?o`000004ooooool0003o0000ooooo`Co00001_ooool4o`000003oooo
ool0003o000001;ooooo0_l00006ooooo`;o00003?ooool3o`000003ooooool0003o000000Oooooo
0_l00006ooooo`;o00005oooool2o`0002Gooooo0_l00010ooooo`007?ooool00ol0003ooooooooo
o`0Zooooo`?o00001?ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000_ooooo8_l0
00001?oooooo0000o`000?ooool7o`0000Cooooo0ol0000>ooooo`;o00001Oooool2o`0000Kooooo
0_l00008ooooo`?o000000?oooooo`000?l000002?ooool2o`0000?ooooo0_l00004ooooo`;o0000
1Oooool2o`00013ooooo0_l0000Uooooo`;o00003?ooool2o`0003;ooooo000Looooo`03o`000?oo
oooooooo02[ooooo0_l00005ooooo`;o000000Coooooo`000?l0003o00002?ooool2o`0000Gooooo
0_l00004ooooo`;o00001?oooolWo`000003ooooool0003o000000Ko00000_ooool3o`0000kooooo
0_l00002ooooo`;o00004oooool3o`0000Sooooo2_l00002ooooo`;o00000_ooool7o`0000Kooooo
0_l0000:ooooo`;o00006Oooool2o`0000Sooooo1?l0000:ooooo`;o0000<_ooool001cooooo00?o
0000ooooooooool0<oooool6o`0000cooooo0_l00005ooooo`;o00001?oooolPo`000003ooooool0
003o000000Co00001_ooool8o`0000[ooooo1?l00004ooooo`;o00004Oooool2o`0000Gooooo0_l0
00001?oooooo0000o`000?ooool3o`000003ooooool0003o000000Go000000?oooooo`000?l00000
0_ooool9o`0000Cooooo0_l0000:ooooo`;o00001_ooool2o`00017ooooo0ol00009ooooo`;o0000
?_ooool001cooooo00?o0000ooooooooool0;oooool2o`0000;ooooo0ol000000ooooooo0000o`00
000<ooooo`;o00002ooooolVo`0000Kooooo0_l00002ooooo`;o00000_ooool4o`0000Oooooo1?l0
000Gooooo`;o00000_ooool2o`000003ooooool0003o000000?o00000_ooool5o`000003ooooool0
003o000000Co00001?ooool8o`0000oooooo0_l000000ooooooo0000o`000004ooooo`;o00004_oo
ool2o`0004Wooooo000Looooo`03o`000?oooooooooo02kooooo0ol00002ooooo`?o00006_ooool2
o`000004ooooool0003o0000oooooaoo000000?oooooo`000?l000000_l00004ooooo`;o00000_oo
ool2o`0000;ooooo1?l0000Aooooo`;o00001?ooool2o`0000[ooooo1Ol00002ooooo`Co00000_oo
ool4o`0000?ooooo1Ol00006ooooo`Oo00003_ooool2o`000003ooooool0003o0000027ooooo0_l0
0010ooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00005?ooool2o`0000?ooooo0_l00005
ooooo`;o00001OoooolMo`0000Cooooo0_l00003ooooo`;o00000oooool2o`0000Sooooo0_l00008
ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`Co00002?ooool5o`000003ooooool0
003o000000?ooooo0_l00003ooooo`;o00000_ooool9o`0000?ooooo1_l0000dooooo`;o0000@?oo
ool001cooooo00?o0000ooooooooool0A?ooool3o`0000;ooooo0_l0000<ooooo`;o000000?ooooo
o`000?l000006?l00009ooooo`Oo00000_ooool2o`0000?ooooo0ol00008ooooo`;o00000_ooool2
o`0000;ooooo0_l00003ooooo`;o00002Oooool4o`000004ooooool0003o0000ooooo`Co00000ooo
ool2o`0000?ooooo2?l000000ooooooo0000o`000003o`000003ooooool0003o000000Kooooo1?l0
0007ooooo`;o00007Oooool2o`0004Cooooo000Looooo`03o`000?oooooooooo033ooooo0_l00009
ooooo`;o00002?ooool2o`0000cooooo0_l00005oooooaSo00002Oooool2o`000003ooooool0003o
000000?o00000oooool2o`0000?ooooo0_l00002ooooo`;o00001_ooool2o`000003ooooool0003o
000000Wooooo1Ol000001?oooooo0000o`000?ooool2o`0000?ooooo0_l000000ooooooo0000o`00
0002ooooo`?o000000?oooooo`000?l000000_ooool;o`000003ooooool0003o000000?o00001_oo
ool5o`0000Kooooo0_l00004ooooo`;o00005Oooool4o`0000;ooooo0_l00010ooooo`007?ooool0
0ol0003oooooooooo`0Yooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l00000
0ooooooo0000o`000003o`0000cooooo0ol00007ooooo`;o00000oooool2o`0000;ooooo2?l00000
0ooooooo0000o`00000;o`0000Sooooo0ol00004ooooo`;o00001Oooool2o`0000Gooooo0_l00006
ooooo`;o000000?oooooo`000?l000002?ooool9o`000003ooooool0003o000000Cooooo1?l00000
0ooooooo0000o`00000;o`000003ooooool0003o000000;o00001?ooool4o`0000Wooooo0_l0000<
ooooo`;o00005Oooool2o`0000Cooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0Yoooo
o`;o000000?oooooo`000?l000001oooool7o`0000?ooooo0_l00008ooooo`?o00002?ooool2o`00
00;ooooo0_l00002ooooo`;o00000_oooolDo`0000Kooooo0_l00003ooooo`Co00001Oooool3o`00
00[ooooo0_l00002ooooo`;o00001?ooool2o`0000?ooooo0_l000000ooooooo0000o`000007o`00
00Cooooo5ol000001Ooooooo0000o`000?l0003ooooo00;o00001Oooool2o`0000?ooooo0_l0000;
ooooo`;o00003Oooool2o`0000Oooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`0foooo
o`Go00000oooool3o`0000Sooooo1?l00003ooooo`;o00000_ooool2o`0000[ooooo2ol000001Ooo
oooo0000o`000?l0003ooooo00Co00002oooool4o`0000Kooooo1?l00008ooooo`;o00000_ooool2
o`0000Cooooo0_l0000:ooooo`?o00001OoooolMo`0000;ooooo0_l00003ooooo`Oo00002oooool2
o`0000gooooo0_l0000;ooooo`Co0000@?ooool001cooooo0_l0000fooooo`Ko00000oooool4o`00
00Oooooo1?l00003ooooo`;o00003oooool3o`0000;ooooo1Ol00003ooooo`;o000000?oooooo`00
0?l000005_ooool4o`0000oooooo1?l00003ooooo`;o00001oooool2o`0000?ooooo9Ol000000ooo
oooo0000o`000006o`0002Kooooo1?l00010ooooo`007?ooool00ol0003oooooooooo`0eooooo`;o
000000Coooooo`000?l0003o00000_ooool2o`000003ooooool0003o000000Oooooo0_l0000Coooo
o`;o000000?oooooo`000?l000000_l000001?oooooo0000o`000?ooool4o`000004ooooool0003o
0000ooooo`;o00002?ooool2o`000003ooooool0003o0000017ooooo0_l00009ooooo`Co00000ooo
ool2o`0000;ooooo0_l000000ooooooo0000o`000005oooooako000000?oooooo`000?l000000_oo
ool2o`0000Oooooo1Ol0000Iooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0=oooool2
o`0000Cooooo0_l000001?oooooo0000o`000?l0000Kooooo`;o00000oooool2o`0000Kooooo0_l0
0004ooooo`;o00002?ooool2o`000003ooooool0003o000000Kooooo0_l00009ooooo`;o00003?oo
ool2o`0000;ooooo0_l00002ooooo`;o000000Goooooo`000?l0003o0000ooooo`03o`0000;ooooo
0_l000000ooooooo0000o`00000Fo`000003ooooool0003o000000;o000000Coooooo`000?l0003o
00001oooool4o`0001Wooooo0_l00008ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0
=oooool2o`000004ooooool0003o0000ooooo`;o000000Coooooo`000?l0003o00005?ooool2o`00
01Wooooo0_l00007ooooo`Go00001_ooool2o`0001Cooooo0_l000000ooooooo0000o`000002oooo
o`;o00001_ooool2o`000003ooooool0003o000001go000000?oooooo`000?l000000ol00002oooo
o`;o00008oooool3o`0000;ooooo0_l00004ooooo`;o0000@_ooool001cooooo00?o0000oooooooo
ool0<_ooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o00001Oooool4o`0000Ko
oooo0_l00006ooooo`;o00001?ooool2o`0000Kooooo0ol00004ooooo`;o000000Coooooo`000?l0
003ooooo0_l00007ooooo`Ko00003?ooool2o`0000;ooooo0_l00004ooooo`;o00000oooool2o`00
00_ooooo2_l000000ooooooo0000o`00000Mo`0000;ooooo0_l00009ooooo`Co00005_ooool2o`00
00?ooooo1?l0000Booooo`;o0000<_ooool001cooooo00?o0000ooooooooool0<_ooool2o`0000Wo
oooo0ol00005ooooo`Co00000_ooool2o`0000;ooooo0_l0000<ooooo`;o00001_ooool3o`0000Co
oooo0_l000001?oooooo0000o`000?ooool2o`0000[ooooo1?l0000;ooooo`;o00000_ooool2o`00
00Cooooo0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o000000Cooooo0_l00002oooo
o`Co00000_oooolOo`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l000001?l00006oooo
o`;o00003oooool2o`0000?ooooo0ol00003ooooo`;o00003Oooool2o`0003;ooooo000Looooo`03
o`000?oooooooooo03gooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo1?l0000Dooooo`;o
00002_ooool2o`0000?ooooo0_l00002ooooo`;o00001_ooool5o`000004ooooool0003o0000oooo
o`;o00004oooool2o`0000;ooooo0_l000000ooooooo0000o`000008ooooobKo00002?ooool2o`00
0003ooooool0003o000000;o00001?ooool2o`0000;ooooo0_l0000:ooooo`;o00000oooool2o`00
00?ooooo0_l00004ooooo`;o00002Oooool2o`0003Kooooo000Looooo`03o`000?oooooooooo03;o
oooo0_l0000=ooooo`;o00001_ooool2o`0001Kooooo0_l0000:ooooo`;o00001oooool2o`0000;o
oooo0_l00005ooooo`Go000000?oooooo`000?l000008Oooool2o`000003ooooool0003o0000023o
00000_ooool5o`0000?ooooo0_l00005ooooo`;o00001?ooool2o`0000gooooo0ol000001?oooooo
0000o`000?ooool2o`0001?ooooo0_l0000fooooo`007?ooool00ol0003oooooooooo`0booooo`;o
00003Oooool2o`0003Oooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00004ooooo`?o
00003?ooool2o`0000;ooooo0_l00004ooooo`Go000000?oooooo`000?l000008_l000000ooooooo
0000o`000002o`0000?ooooo0_l0000Jooooo`;o00000_ooool2o`000003ooooool0003o000000Oo
oooo0_l00012ooooo`007?ooool00ol0003oooooooooo`0gooooo`;o000000?oooooo`000?l00000
1?ooool2o`0003?ooooo0_l00008ooooo`;o00001?ooool2o`000003ooooool0003o000000Cooooo
0ol0000<ooooo`;o00000_ooool2o`0000Cooooo1Ol000001?oooooo0000o`000?oooolUo`0000Co
oooo0_l0000Booooo`;o00002_ooool2o`000004ooooool0003o0000ooooo`?o00000oooool2o`00
04;ooooo000Looooo`03o`000?oooooooooo03Oooooo0_l000000ooooooo0000o`000004ooooo`;o
0000<oooool3o`0000_ooooo1ol0000Kooooo`;o000000?oooooo`000?l000001_l00002ooooo`Wo
000000?oooooo`000?l000005ol00004ooooo`?o00004Oooool2o`0000[ooooo0_l00004ooooo`?o
00002Oooool2o`0000;ooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0fooooo`Ko0000
0oooool2o`0003?ooooo1ol000000ooooooo0000o`000003o`0000;ooooo0_l000000ooooooo0000
o`000003ooooo`;o00006?ooool3o`000003ooooool0003o000002[o000000?oooooo`000?l00000
0_ooool2o`0001;ooooo0_l00009ooooo`;o000000Coooooo`000?l0003ooooo0ol000000ooooooo
0000o`000006ooooo`;o00000_ooool2o`0003Sooooo000Looooo`03o`000?oooooooooo03Kooooo
1Ol00004ooooo`;o000000?oooooo`000?l000002?ooool2o`0001gooooo0_l00004ooooo`Ko0000
00Goooooo`000?l0003o0000ooooo`05o`0000[ooooo0_l0000Aooooo`;o00001_ooool2o`0000Go
oooo:?l000001Ooooooo0000o`000?l0003ooooo00;o00001_ooool2o`0000[ooooo1?l00003oooo
o`Co00000oooool6o`000003ooooool0003o000000Kooooo0_l0000looooo`007?ooool00ol0003o
ooooooooo`0aooooo`;o00001_ooool2o`0000Oooooo0_l00008ooooo`;o00007Oooool4o`0000;o
oooo0ol000000ooooooo0000o`000005ooooo`;o00001Oooool2o`0000?ooooo0_l0000Dooooo`;o
00001oooool3o`0000?ooooo;?l000000ooooooo0000o`000006ooooo`;o00001?ooool2o`0000Ko
oooo0_l00003ooooo`Co00001Oooool2o`0000[ooooo0ol000000ooooooo0000o`00000iooooo`00
00Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413o
c<c<00Kooooo00?o0000ooooooooool0<Oooool2o`0000?ooooo0_l000000ooooooo0000o`00000/
ooooo`;o00001?ooool4o`0000[ooooo0_l000000ooooooo0000o`000007o`000003ooooool0003o
000001gooooo0ol00002ooooo`?o000000?oooooo`000?l000009ol0000=ooooo`Go00002oooool2
o`0000Wooooo0_l00007ooooo`;o00000_ooool2o`0003Wooooo00001_ooooooMgMgoiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`0fooooo`;o00003Oooool2o`0000Kooooo0ol0000Gooooo`;o00001_ooool2o`0000Oooooo
0_l000001?oooooo0000o`000?ooool5o`0000;ooooo0_l00005ooooo`;o00006?ooool2o`0000Co
oooo0_l00002ooooo`ko000000?oooooo`000?l000006?l0000=ooooo`Go00002oooool2o`0000Wo
oooo0_l00016ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`0aooooo`;o00000_ooool2o`0000ko
oooo0_l00004ooooo`Go00000_ooool2o`0000_ooooo0_l00006ooooo`;o00003_ooool3o`0001;o
oooo0_l0000Hooooo`;o00001?ooool2o`0000Cooooo8Ol000000ooooooo0000o`000004o`0000co
oooo1?l00004ooooo`;o00001_ooool2o`00057ooooo00000ooooooo0000ooooo`02ooooo`03o`00
0?oooooooooo00Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000<Oooool2o`0000;o
oooo0_l00007ooooo`;o00002oooool2o`000005ooooool0003o0000o`000?ooool00_l0000;oooo
o`;o00001_ooool2o`0000kooooo0_l0000aooooo`;o00001_oooolQo`000003ooooool0003o0000
00;ooooo1?l000000ooooooo0000o`000007ooooo`?o00001Oooool5o`0000gooooo0_l00005oooo
o`;o0000@?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003o
EEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0?Oooool3o`0000cooooo1Ol0000Foooo
o`;o00001?ooool2o`0000_ooooo0_l0000^ooooobWo00000_ooool2o`0000;ooooo0ol000000ooo
oooo0000o`000008ooooo`;o00001_ooool4o`0000gooooo0_l00005ooooo`;o0000@?ooool00003
ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03
o`000?oooooooooo03gooooo1?l00006ooooo`;o00000oooool2o`0001oooooo0_l0000;ooooo`;o
000000?oooooo`000?l000009oooool4o`0000;ooooo3_l000000ooooooo0000o`00000?o`000003
ooooool0003o000000Co00000_ooool2o`0000;ooooo0ol000000ooooooo0000o`000003ooooo`Co
000000?oooooo`000?l000001Oooool3o`0001[ooooo0_l0000looooo`0000KoooooogMgMonHV9So
oooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0>?ooool2o`00
00Gooooo0_l00006ooooo`;o000000?oooooo`000?l000005Oooool2o`0000Wooooo0_l00004oooo
o`;o000000?oooooo`000?l000001?ooool4o`0000Cooooo0_l0000Oooooo`Oo00001ooooolIo`00
0003ooooool0003o000000Go000000?oooooo`000?l000000_l000001?oooooo0000o`000?ooool2
o`0000Cooooo1?l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l0000Kooooo`;o0000??oo
ool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03
o`000?oooooooooo03Sooooo0_l0000@ooooo`;o00001?ooool2o`0000oooooo0_l00009ooooo`;o
00001?ooool5o`0000Cooooo0_l00004ooooo`Co00003_ooool2o`0000Oooooo0_l00006ooooo`;o
00000_ooool3o`0000Gooooo0_l000000ooooooo0000o`00000;o`000003ooooool0003o000001Go
000000Coooooo`000?l0003ooooo0_l00008ooooo`;o00000_ooool2o`0000Kooooo0_l0001Eoooo
o`007?ooool00ol0003oooooooooo`0mooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o
00001?ooool2o`0000cooooo0_l00008ooooo`;o00002Oooool2o`0000cooooo0_l0000@ooooo`;o
00001oooool2o`00013ooooo1ol00002oooooa;o000000?oooooo`000?l000002?l000001Ooooooo
0000o`000?l0003ooooo00;o00002oooool2o`0000[ooooo0_l0000:ooooo`;o00001Oooool2o`00
04;ooooo000Looooo`03o`000?oooooooooo03Gooooo0_l00006ooooo`;o00000_ooool2o`0000;o
oooo0_l00009ooooo`Go00002Oooool2o`0000Cooooo0_l00002ooooo`;o0000>oooool2o`0000;o
oooo0_l00003ooooo`Ko000000?oooooo`000?l000008Ol00002ooooo`Co00002?ooool2o`0000[o
oooo0_l00005ooooo`;o00000oooool2o`0000Gooooo0_l00012ooooo`007?ooool00ol0003ooooo
ooooo`0eooooo`;o00002Oooool2o`0000[ooooo0_l000000ooooooo0000o`000008o`0000Kooooo
0_l00003ooooo`;o0000?_ooool3o`0000;ooooo0_l00006oooooaKo000000?oooooo`000?l00000
1Ol000000ooooooo0000o`000007o`000003ooooool0003o000000;o00000oooool2o`0000Oooooo
1?l0000;ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0<oooool4o`0000Wooooo0ol0
0009ooooo`;o000000?oooooo`000?l000000oooool5o`0000Kooooo0_l0000Fooooo`?o00000_oo
ool2o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l000000_l000001?oooooo0000o`00
0?ooool2o`00013ooooo0_l00003ooooo`?o00001Oooool2o`000003ooooool0003o0000013o0000
00?oooooo`000?l000001ol000000ooooooo0000o`000006o`0000?ooooo0_l00003ooooo`;o0000
0_ooool2o`000003ooooool0003o000000Co000000?oooooo`000?l00000F?ooool001cooooo00?o
0000ooooooooool0<oooool2o`0000Sooooo1_l00003ooooo`;o00001?ooool2o`000003ooooool0
003o000000kooooo0_l00004ooooo`;o00003Oooool2o`000003ooooool0003o000000Go00000_oo
ool2o`0000Gooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000?o00000ooo
ool2o`0000?ooooo0_l0000;ooooo`?o000000?oooooo`000?l000002?oooolIo`0000Cooooo1ol0
0006ooooo`;o00000_ooool2o`000003ooooool0003o000000Gooooo0_l0001Hooooo`007?ooool0
0ol0003oooooooooo`0iooooo`;o00000_ooool6o`0000?ooooo0_l000000ooooooo0000o`000004
ooooo`;o00005?ooool2o`0000cooooo2_l00005ooooo`;o00001?ooool;o`0000Cooooo0ol00002
ooooo`;o000000?oooooo`000?l000002?ooool2o`0000;ooooo1?l00003ooooo`Wo000000?ooooo
o`000?l000000ol000000ooooooo0000o`000006o`000003ooooool0003o000000Kooooo2?l0000=
ooooo`;o00000_ooool2o`0005Wooooo000Looooo`03o`000?oooooooooo03Wooooo0_l00008oooo
o`;o00001?ooool2o`0000kooooo0_l00002ooooo`;o00004Oooool7o`0000_ooooo0_l000001?oo
oooo0000o`000?ooool9o`0000Oooooo0_l00005ooooo`;o00002?ooool2o`0000Cooooo0ol00000
0ooooooo0000o`000004o`000003ooooool0003o000000_o000000?oooooo`000?l000001Ol00005
ooooo`;o00001Oooool2o`0000gooooo0_l00002ooooo`;o00002oooool2o`0000Wooooo0_l00011
ooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00001?ooool2o`0000Cooooo0_l0000?oooo
o`;o00000_ooool3o`000004ooooool0003o0000o`00017ooooo1?l000000ooooooo0000o`00000<
oooooa7o00000_ooool4o`00013ooooo0_l00004ooooo`;o000000?oooooo`000?l000004Ol00000
0ooooooo0000o`000007o`0000;ooooo1?l00005ooooo`;o00003oooool2o`0000Gooooo0_l00006
ooooo`;o00002Oooool2o`00047ooooo000Looooo`03o`000?oooooooooo03Cooooo0_l000000ooo
oooo0000o`000004ooooo`;o00000_ooool2o`0000[ooooo0_l00005ooooo`;o000000Coooooo`00
0?l0003o00000_ooool2o`0001Gooooo0_l0000<ooooo`So000000?oooooo`000?l000002Ol00000
0ooooooo0000o`000002o`00013ooooo0_l00006ooooo`Go00000_ooool<o`0000;ooooo1_l00000
0ooooooo0000o`000002ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Booooo`?o00001?oo
ool2o`0000Gooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`0dooooo`;o00002oooool2
o`0000?ooooo0_l00005ooooo`;o00002?ooool2o`0001[ooooo0_l00008ooooo`;o000000?ooooo
o`000?l000004ol000000ooooooo0000o`00000=ooooo`;o00002Oooool4o`000003ooooool0003o
000000;o000000?oooooo`000?l000000_ooool3o`000003ooooool0003o000000ko00000oooool2
o`000003ooooool0003o000000Kooooo0_l000000ooooooo0000o`000004ooooo`;o000000Cooooo
o`000?l0003o00002oooool2o`0004gooooo000Looooo`03o`000?oooooooooo03kooooo1_l00002
ooooo`;o000000?oooooo`000?l000001oooool2o`0001_ooooo0_l0000<oooooaSo000000?ooooo
o`000?l000000_ooool4o`0000;ooooo0_l00003ooooo`;o00002?ooool5o`0000?ooooo0ol00005
ooooo`[o000000?oooooo`000?l000001_l0000;ooooo`;o000000Coooooo`000?l0003ooooo0_l0
0004ooooo`;o0000G_ooool001cooooo0_l0000oooooo`?o000000?oooooo`000?l000001Oooool2
o`0000Oooooo1?l00006ooooo`;o00000_ooool2o`0000gooooo0_l000000ooooooo0000o`000008
oooooaco00000_ooool4o`0000;ooooo1?l00003ooooo`;o00001?ooool7o`0000;ooooo1?l00003
ooooo`?o000000?oooooo`000?l000002Ol000001?oooooo0000o`000?l0000=ooooo`;o00001ooo
ool2o`00013ooooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`12ooooo`Co00003_ooool2
o`0000Kooooo0_l00002ooooo`;o00004?ooool2o`0000Sooooo0_l000001?oooooo0000o`000?oo
oolFo`0000Sooooo1_l000001?oooooo0000o`000?l00003ooooo`?o00001Oooool3o`0000;ooooo
0_l000000ooooooo0000o`000003o`000003ooooool0003o000000oo00004_ooool2o`0000_ooooo
0_l00003ooooo`;o00005?ooool2o`0003Wooooo000Looooo`03o`000?oooooooooo03Oooooo0_l0
0003ooooo`;o00000oooool2o`000003ooooool0003o000000;o00000_ooool2o`0000?ooooo0_l0
000Zooooo`;o00000_ooool?o`000003ooooool0003o000000Oo00003?ooool2o`0000;ooooo0_l0
000;ooooo`?o000000Coooooo`000?l0003o00000oooool3o`0000;ooooo4?l00003ooooo`;o0000
2Oooool2o`000003ooooool0003o000000Cooooo0_l00006ooooo`;o00001oooool2o`00013ooooo
0_l0000iooooo`007?ooool00ol0003oooooooooo`0gooooo`;o000000?oooooo`000?l000000_l0
0003ooooo`;o00000oooool6o`0000?ooooo0_l0000Zooooo`;o000000?oooooo`000?l000003ol0
00000ooooooo0000o`000005o`0000_ooooo0_l00003ooooo`?o00002oooool2o`0000;ooooo0_l0
0004ooooo`;o000000?oooooo`000?l000001ol00002ooooo`;o00002?ooool2o`0000Gooooo0_l0
0002ooooo`;o000000?oooooo`000?l000001?ooool2o`0000?ooooo0_l00009ooooo`?o0000Booo
ool001cooooo00?o0000ooooooooool0>_ooool2o`0000cooooo0_l00008ooooo`;o0000:_oooolH
o`000003ooooool0003o000000Wooooo0_l00003ooooo`?o00001Oooool2o`0000Cooooo1?l00009
ooooo`Ko00001Oooool2o`0000kooooo0ol0000>ooooo`Co00001_ooool2o`000003ooooool0003o
000004cooooo000Looooo`03o`000?oooooooooo03_ooooo1?l0000Cooooo`;o0000:_oooolKo`00
00kooooo0_l00006ooooo`;o00000_ooool6o`0000Wooooo0_l00002ooooo`;o00005?ooool3o`00
00oooooo0_l00008ooooo`Co0000COooool001cooooo00?o0000ooooooooool0>oooool4o`0000_o
oooo0_l0000Aooooo`;o00006Oooool2o`0000?ooooo7?l00004ooooo`;o00002?ooool2o`0000[o
oooo0_l00006ooooo`;o00001?ooool3o`0001Sooooo0_l0000Looooo`;o0000COooool001cooooo
00?o0000ooooooooool0?Oooool2o`0000_ooooo0_l000000ooooooo0000o`000008ooooo`;o0000
1?ooool4o`0000_ooooo0_l0000:ooooo`;o00000ooooolIo`000003ooooool0003o000000?ooooo
0ol0000Kooooo`?o000000Coooooo`000?l0003ooooo0_l0000>ooooo`;o00001?ooool2o`00023o
oooo1?l0001<ooooo`007?ooool00ol0003oooooooooo`1=ooooo`?o00001oooool2o`0000Kooooo
0_l0000;ooooo`;o00003ooooolHo`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000Sooooo
0_l00004ooooo`;o00000_ooool2o`0000Cooooo0_l00002ooooo`;o00001Oooool2o`0000[ooooo
0_l00004ooooo`;o00005oooool2o`0000Oooooo1Ol0001;ooooo`007?ooool00ol0003ooooooooo
o`10ooooo`;o00003?ooool2o`0001cooooo0_l0000Aooooo`;o000000?oooooo`000?l000004Ol0
0002ooooo`;o00000oooool6o`0000Sooooo0_l00004ooooo`;o00000_ooool2o`0000oooooo0_l0
000Oooooo`Co00001_ooool2o`0000[ooooo0_l0000Aooooo`;o0000>?ooool001cooooo00?o0000
ooooooooool0@?ooool2o`000003ooooool0003o000000Gooooo0_l000000ooooooo0000o`00000M
ooooo`;o00002?ooool2o`0000?ooooo0_l00002oooooaKo00001oooool6o`0000Gooooo0_l0000A
ooooo`;o00005Oooool2o`0001?ooooo1?l0000=ooooo`;o00005_ooool2o`0003Sooooo000Loooo
o`03o`000?oooooooooo04?ooooo0_l00003ooooo`Co000000?oooooo`000?l000000oooool2o`00
02;ooooo0_l00003ooooo`;o00000_oooolFo`0000Gooooo1?l000001Ooooooo0000o`000?l0003o
oooo00;o00000_ooool2o`00017ooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00000ooo
ool2o`0000Sooooo0_l0000Dooooo`;o00003_ooool2o`00053ooooo000Looooo`03o`000?oooooo
oooo04Sooooo1Ol00005ooooo`;o00000_ooool2o`000003ooooool0003o000001Wooooo0_l00006
ooooo`;o000000?oooooo`000?l000001?ooool?o`000003ooooool0003o000000?ooooo1?l00002
ooooo`;o000000?oooooo`000?l000001oooool3o`0000Wooooo1?l000001?oooooo0000o`000?l0
0002ooooo`;o00000oooool3o`0000Cooooo0ol0000Gooooo`Co00007oooool2o`0003cooooo000L
ooooo`03o`000?oooooooooo04Kooooo1ol00004ooooo`;o00000oooool2o`000003ooooool0003o
000000kooooo0_l00009ooooo`;o00001_ooool2o`000003ooooool0003o000000Cooooo1_l00004
ooooo`;o000000Coooooo`000?l0003ooooo0_l00005ooooo`;o00001?ooool2o`0000Sooooo0ol0
0009ooooo`Co00001Oooool2o`0000Gooooo0_l00002ooooo`Go00002_ooool2o`0000;ooooo0ol0
0006ooooo`Co00007oooool2o`0003cooooo000Looooo`03o`000?oooooooooo043ooooo0_l00004
ooooo`;o00002Oooool2o`0000Cooooo0_l00003ooooo`;o00001oooool2o`0000;ooooo0_l00004
ooooo`Co000000?oooooo`000?l000001oooool2o`0000Kooooo0_l0000Eooooo`;o00000oooool3
o`0000Sooooo0_l00003ooooo`;o00000oooool2o`0000Wooooo0_l00009ooooo`?o00001_ooool2
o`0000;ooooo1?l00002ooooo`?o00000oooool2o`0000;ooooo0_l0001Nooooo`007?ooool00ol0
003oooooooooo`10ooooo`;o00003oooool2o`0000Cooooo0_l00003ooooo`;o00001_ooool3o`00
00Sooooo1?l0000:ooooo`;o00001?ooool4o`0000cooooo0_l000000ooooooo0000o`000009oooo
o`;o00002_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`00013ooooo0ol000001?oo
oooo0000o`000?l00006ooooo`;o00000_ooool2o`0000[ooooo0ol00002ooooo`;o0000GOooool0
01cooooo0_l00017ooooo`?o00000oooool2o`0000cooooo0_l00008ooooo`;o00002Oooool2o`00
00Kooooo0_l00008ooooo`Co00003_ooool2o`000003ooooool0003o000001Gooooo0_l000001Ooo
oooo0000o`000?l0003ooooo00Co00003oooool4o`000003ooooool0003o000001Gooooo0_l00000
1?oooooo0000o`000?ooool3o`0000Oooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`16
ooooo`?o00000oooool2o`0000cooooo0_l00008ooooo`;o00001?ooool3o`000003ooooool0003o
000000;ooooo0_l00003ooooo`;o00001_ooool4o`0000kooooo0_l0000Dooooo`;o00001oooool3
o`0001Cooooo0_l000000ooooooo0000o`00000Fooooo`?o00001?ooool3o`0000Cooooo0_l00000
0ooooooo0000o`000002o`0005;ooooo000Looooo`03o`000?oooooooooo04?ooooo0_l00007oooo
o`;o00003?ooool2o`0000Sooooo0_l00004ooooo`?o000000?oooooo`000?l000000_ooool4o`00
00;ooooo0_l00005ooooo`;o00004?ooool2o`0001Cooooo0_l0000?ooooo`;o000000?oooooo`00
0?l000003Oooool2o`000003ooooool0003o000000[ooooo0ol00002ooooo`;o00000_ooool5o`00
00Wooooo0_l00003ooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0@oooool2o`0000Oo
oooo0_l0000Aooooo`;o00000oooool2o`000003ooooool0003o000000Wooooo1?l00002ooooo`?o
00007?ooool2o`0000kooooo0_l00009ooooo`;o000000Coooooo`000?l0003ooooo0_l000001?oo
oooo0000o`000?l00008ooooo`Co000000?oooooo`000?l000000_l00006ooooo`Oo00000_ooool3
o`000003ooooool0003o000000?o00002Oooool2o`0005Oooooo000Looooo`03o`000?oooooooooo
05[ooooo0_l00003ooooo`?o00001Oooool3o`0000oooooo0_l0000Fooooo`;o00000_ooool6o`00
00Wooooo0_l00003ooooo`?o00000oooool2o`000004ooooool0003o0000ooooo`;o00001Oooool2
o`0000Cooooo0_l00002ooooo`Co000000?oooooo`000?l000000_l00004ooooo`Oo00001Oooool2
o`0006Sooooo000Looooo`03o`000?oooooooooo04Cooooo0_l00007ooooo`;o00002oooool2o`00
00Cooooo0_l00004ooooo`Co00001?ooool2o`0000Wooooo0_l00006ooooo`;o00003_ooool3o`00
0003ooooool0003o000000;ooooo0_l00009ooooo`;o00000oooool3o`0000?ooooo0_l0000Aoooo
o`;o00002Oooool2o`0000;ooooo1ol00005ooooo`;o00000_ooool2o`0000Sooooo0_l0001Loooo
o`007?ooool00ol0003oooooooooo`14ooooo`;o00001?ooool2o`000003ooooool0003o0000013o
oooo0ol00004ooooo`;o00001_ooool2o`0000;ooooo0_l0000=ooooo`;o00000oooool2o`0000[o
oooo0_l00002ooooo`;o00002oooool2o`0000Gooooo2?l0000Aooooo`;o00003?ooool9o`0000?o
oooo0_l00002ooooo`;o00002?ooool2o`0005cooooo000Looooo`03o`000?oooooooooo04Gooooo
0_l00003ooooo`Co00001?ooool2o`0000_ooooo0_l00008ooooo`;o00001oooool2o`0000?ooooo
0_l0000=ooooo`;o00003_ooool3o`0000Oooooo1Ol00004ooooo`Wo00003?ooool2o`0000;ooooo
0ol0000>ooooo`Oo00000oooool2o`0000Gooooo0_l0001Sooooo`007?ooool00ol0003ooooooooo
o`15ooooo`;o00001Oooool5o`000003ooooool0003o000001Gooooo0_l0000<ooooo`?o00002Ooo
ool2o`0000kooooo0_l00002ooooo`;o00001oooool5o`0000Cooooo0_l00004ooooo`;o00003Ooo
ool2o`0000;ooooo0_l00008ooooo`;o00000oooool7o`0000Gooooo0_l00004ooooo`?o00006?oo
ool2o`0004Wooooo000Looooo`03o`000?oooooooooo04Oooooo0_l00004ooooo`Co00006Oooool2
o`0000?ooooo0_l00007ooooo`Go00001_ooool2o`0000kooooo0_l00008ooooo`?o00000oooool2
o`0000[ooooo0_l0000Aooooo`;o00002?ooool2o`0000;ooooo0ol00002ooooo`?o00000_ooool2
o`000003ooooool0003o000000Cooooo0_l0000Iooooo`;o0000BOooool001cooooo00?o0000oooo
ooooool0Aoooool2o`0000_ooooo0_l0000Dooooo`;o00000oooool3o`0000Oooooo1?l00006oooo
o`;o00002?ooool3o`0000;ooooo0_l00009ooooo`?o00001oooool2o`0000Sooooo1?l000000ooo
oooo0000o`00000<ooooo`;o00002_ooool2o`0000Sooooo0_l000000ooooooo0000o`00001Zoooo
o`007?ooool00ol0003oooooooooo`1Cooooo`?o00006_ooool2o`0000Oooooo0_l00002ooooo`;o
00001Oooool2o`0000Oooooo0ol00002ooooo`;o00004?ooool2o`000003ooooool0003o000000So
oooo1?l000000ooooooo0000o`000005o`000003ooooool0003o000000;o00000_ooool2o`0000?o
oooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l00000M?ooool001cooooo
00?o0000ooooooooool0Doooool2o`0000cooooo0ol0000Eooooo`Ko00001Oooool2o`0000Kooooo
0_l0000?ooooo`Co00000oooool2o`0000Wooooo1Ol00002ooooo`Oo000000?oooooo`000?l00000
0_l00002ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`?o000000?oooooo`000?l0
00002oooool2o`0006Oooooo000Looooo`03o`000?oooooooooo067ooooo0ol0000Aooooo`;o0000
1?ooool2o`0000oooooo0_l0000?ooooo`Co00000_ooool2o`0000Gooooo0_l00003ooooo`;o0000
00Goooooo`000?l0003o0000ooooo`07o`0000Kooooo0_l000001Ooooooo0000o`000?l0003ooooo
00;o000000?oooooo`000?l000000_l00009ooooo`;o00001?ooool2o`0006Oooooo000Looooo`03
o`000?oooooooooo04[ooooo0_l00003ooooo`;o00001oooool4o`0000;ooooo0_l00002ooooo`;o
00002_ooool2o`0000Gooooo0_l00007ooooo`;o00008?ooool2o`000003ooooool0003o000000Go
oooo1?l00003ooooo`Co000000?oooooo`000?l000002oooool6o`000004ooooool0003o0000oooo
o`?o00002_ooool2o`0001Oooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o
00000oooool2o`0000Kooooo1Ol00002ooooo`;o00003_ooool2o`0000Gooooo0_l00005ooooo`Co
00002?ooool2o`0001Kooooo0_l000000ooooooo0000o`000007ooooo`;o00000oooool3o`0000;o
oooo0_l0000<ooooo`;o000000?oooooo`000?l000000_l0000>ooooo`;o00001_ooool2o`00013o
oooo0_l0001Dooooo`007?ooool2o`0005Sooooo1?l000000ooooooo0000o`000002o`0001Gooooo
0_l000001?oooooo0000o`000?ooool5o`0000Oooooo0ol0000Qooooo`;o00001_ooool2o`0001;o
oooo1?l0000>ooooo`;o00001_ooool2o`0006Kooooo000Looooo`03o`000?oooooooooo05_ooooo
0ol0000=ooooo`;o00000_ooool2o`0000Oooooo1_l00009ooooo`;o00000_ooool2o`0000Cooooo
0_l0000Gooooo`?o00000_ooool2o`0000;ooooo1?l00003ooooo`;o00003?ooool2o`0007oooooo
000Looooo`03o`000?oooooooooo05Wooooo1?l00005ooooo`;o00001oooool2o`0000;ooooo0_l0
0007ooooo`Co000000?oooooo`000?l000003?ooool4o`0000;ooooo2Ol0000@ooooo`;o00000ooo
ool2o`0000Cooooo0_l000000ooooooo0000o`000002o`0000cooooo0_l0001oooooo`007?ooool0
0ol0003oooooooooo`1Iooooo`?o00001_ooool2o`0000Gooooo1_l0000:ooooo`;o00000_ooool2
o`0000kooooo0_l00004ooooo`So00003oooool2o`0000Cooooo0_l00006ooooo`;o000000Cooooo
o`000?l0003ooooo0_l00008ooooo`;o00009oooool2o`0005Kooooo000Looooo`03o`000?oooooo
oooo05[ooooo0_l000000ooooooo0000o`000008ooooo`So00000oooool2o`0000cooooo0_l00000
0ooooooo0000o`00000Booooo`Co00002_ooool2o`0000Wooooo0ol000000ooooooo0000o`000005
ooooo`;o000000?oooooo`000?l000002_ooool2o`000003ooooool0003o000000Wooooo0_l00002
ooooo`;o00003Oooool2o`0000Cooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`1Moooo
o`;o00002?ooool2o`0000Wooooo0_l0000<ooooo`;o000000?oooooo`000?l000008?ooool2o`00
00Oooooo0_l000001?oooooo0000o`000?ooool2o`0000cooooo0_l00005ooooo`?o000000?ooooo
o`000?l000002Oooool2o`0000;ooooo0_l0000=ooooo`;o0000G?ooool001cooooo00?o0000oooo
ooooool0G?ooool2o`0000Wooooo0_l0000Fooooo`;o00004oooool2o`0000?ooooo0_l0000?oooo
o`;o00000_ooool2o`0000Cooooo0ol0000;ooooo`;o00001?ooool3o`0000[ooooo0_l000000ooo
oooo0000o`00001_ooooo`007?ooool00ol0003oooooooooo`1Looooo`;o00002Oooool2o`0001Ko
oooo0_l00004ooooo`;o00003Oooool2o`000003ooooool0003o000000;o00003oooool5o`0000;o
oooo0_l000001?oooooo0000o`000?l00005ooooo`;o00001?ooool4o`0000;ooooo0_l0000;oooo
o`;o00005?ooool2o`0005cooooo000Looooo`03o`000?oooooooooo07Cooooo0_l0000?ooooo`;o
000000?oooooo`000?l000003Oooool2o`0000?ooooo0_l0000>ooooo`Oo00002Oooool2o`0000Ko
oooo0_l0000Uooooo`;o0000G?ooool001cooooo00?o0000ooooooooool0JOooool2o`0000Wooooo
0_l0000Aooooo`?o00004_ooool2o`0000_ooooo0_l00004ooooo`?o00001_ooool2o`0000Cooooo
0_l0000Hooooo`;o000000?oooooo`000?l00000K?ooool001cooooo00?o0000ooooooooool0I_oo
ool5o`0000_ooooo1?l000000ooooooo0000o`00000:ooooo`;o00008?ooool2o`0000Gooooo0_l0
0004ooooo`Ko00000_ooool2o`0000Wooooo0_l0000=ooooo`;o000000?oooooo`000?l00000K?oo
ool001cooooo00?o0000ooooooooool0I_ooool8o`0000Cooooo0_l00002ooooo`Co000000?ooooo
o`000?l000002_ooool2o`00017ooooo0_l0000;ooooo`;o000000?oooooo`000?l000002_ooool2
o`0000;ooooo0_l0000<ooooo`?o0000O_ooool001cooooo00?o0000ooooooooool0H?ooool2o`00
00Kooooo1_l00004ooooo`;o00002?ooool3o`0001Kooooo0_l00003ooooo`;o00002oooool2o`00
0003ooooool0003o000000kooooo0_l0000<ooooo`;o0000Ooooool001cooooo00?o0000oooooooo
ool0H?ooool2o`0001[ooooo0ol0000Fooooo`;o000000?oooooo`000?l000002_ooool2o`0001Co
oooo0_l0000Iooooo`;o0000L_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q
8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo093ooooo0_l00002
ooooo`;o00000_ooool3o`0000Cooooo1?l000000ooooooo0000o`000004ooooo`;o00003oooool2
o`0001Sooooo0_l00007ooooo`;o0000JOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Ooo
ool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo093ooooo
0_l000001?oooooo0000o`000?l00003ooooo`;o00001?ooool4o`0000Cooooo1Ol0000?ooooo`;o
00005oooool4o`0000Kooooo0_l0001Yooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooo
ooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`1hooooo`;o
00002?ooool2o`0000oooooo0_l00007ooooo`;o00002Oooool3o`0001Oooooo0_l0000Aooooo`Co
0000LOooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Olb<S;oV9RH
oooooonHV9So<S8b00Kooooo0ol0001Wooooo`;o00003oooool2o`0000Sooooo0ol0000Gooooo`;o
00008?ooool2o`000003ooooool0003o000001Gooooo0_l0001_ooooo`0000?oooooo`000?ooool0
0_ooool00ol0003oooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003o
ooooooooo`1Wooooo`;o00003?ooool2o`0000cooooo0_l0000:ooooo`;o00002Oooool2o`0000?o
oooo0_l0000Mooooo`;o000000Coooooo`000?l0003ooooo1Ol0000?ooooo`;o0000Koooool00003
ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol@413o^[Zjoooooonj^[[o410@
00Kooooo00?o0000ooooooooool0MOooool2o`0000Kooooo0_l0000@ooooo`;o00002Oooool2o`00
00?ooooo0_l0000=ooooo`;o00001?ooool2o`0000_ooooo0_l000000ooooooo0000o`000003o`00
083ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zjo`00
0006ooooo`03o`000?oooooooooo06cooooo0_l00002ooooo`;o00002oooool2o`0001Cooooo0_l0
000Gooooo`Co00001?ooool2o`0009?ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo
00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo06cooooo0_l00002ooooo`Co
00002_ooool2o`0001?ooooo0_l00008ooooo`;o00003Oooool2o`0000cooooo0_l00006ooooo`;o
0000QOooool001cooooo00?o0000ooooooooool0L_ooool2o`000003ooooool0003o000000Oooooo
0_l0000Cooooo`;o00001oooool5o`0000oooooo0_l00006ooooo`Co00000_ooool2o`0000;ooooo
0_l00025ooooo`007?ooool00ol0003oooooooooo`1^ooooo`;o00001Oooool2o`0000Sooooo0_l0
000Booooo`;o00000oooool2o`0000;ooooo1_l0000:ooooo`;o00000_ooool2o`0000Kooooo0_l0
0004ooooo`;o0000ROooool001cooooo00?o0000ooooooooool0K_ooool4o`0000Cooooo0_l00005
ooooo`Co00001Oooool2o`000003ooooool0003o000000?ooooo0_l00008ooooo`;o00001_ooool2
o`0000[ooooo0_l0002Kooooo`007?ooool00ol0003oooooooooo`1`ooooo`;o00001?ooool3o`00
00Cooooo0_l00007ooooo`;o000000?oooooo`000?l000000oooool2o`0000Wooooo0_l0000Joooo
o`;o00002Oooool6o`0008?ooooo000Looooo`03o`000?oooooooooo07Oooooo0_l0000Pooooo`;o
00001?ooool2o`0001Cooooo0_l00009ooooo`Ko0000Poooool001cooooo00?o0000ooooooooool0
R_ooool2o`0000Sooooo0_l00003ooooo`;o00001?ooool2o`000:Sooooo000Looooo`03o`000?oo
oooooooo07Oooooo0_l000000ooooooo0000o`000005ooooo`;o00001oooool2o`0000Sooooo1?l0
00001?oooooo0000o`000?l0000Jooooo`;o0000TOooool001cooooo00?o0000ooooooooool0Mooo
ool2o`000003ooooool0003o000000Gooooo0_l0000Cooooo`;o000000Coooooo`000?l0003o0000
3_ooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o0000TOooool001cooooo00?o
0000ooooooooool0P?ooool2o`0000Kooooo0_l0000Hooooo`;o00001_ooool2o`0000?ooooo0_l0
00000ooooooo0000o`00002Eooooo`007?ooool00ol0003oooooooooo`1oooooo`?o00000oooool2
o`000003ooooool0003o000000Gooooo0ol0000@ooooo`;o0000YOooool001cooooo00?o0000oooo
ooooool0Ooooool2o`0000Cooooo0_l00008ooooo`?o0000]oooool001cooooo0_l0002Iooooo`;o
0000[oooool001cooooo00?o0000ooooooooool0Q?ooool2o`0000[ooooo1?l00004ooooo`;o0000
[oooool001cooooo00?o0000ooooooooool0Q?ooool2o`0000Sooooo1_l0002eooooo`007?ooool0
0ol0003oooooooooo`2>ooooo`;o0000^Oooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`2<ooooo`;o0000^oooool001cooooo00?o0000ooooooooool0
S?ooool2o`000;_ooooo000Looooo`03o`000?oooooooooo09gooooo0_l0002Zooooo`007?ooool0
0ol0003oooooooooo`2Mooooo`;o0000Z_ooool001cooooo00?o0000ooooooooool0Uoooool2o`00
0;3ooooo000Looooo`03o`000?oooooooooo09Oooooo0_l00002ooooo`;o0000[?ooool001cooooo
00?o0000ooooooooool0Voooool2o`000:cooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Booooo`Co000000?o410@ooooooooool00oooool00ol0003ooooo
ooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooo
oom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`?o0000oooooom:ooooo`005?ooool00ol0
003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo
00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000B
ooooo`03oeEEEOmVIVKo00000?ooooooE?ooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00:Gooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0Gooooo`03o`00
0?o^k^kooooo00?ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05olc<c?lQ8B7o0000ob4Q
8Oo<c<`0T?ooool00:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00002oooool00omE
EEGoZJVYooooo`03ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OlQ8B7oV9RHoooooonH
V9So8B4Q093ooooo002Vooooo`05o`000?ooooooooooooooool000006_ooool00onYZJWoEEEEoooo
o`07ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`2>ooooo`00Y_oo
ool01Ol0003ooooooooooooooooo000000Wooooo1_l0000<ooooo`03ob4Q8Ooooooooooo00Gooooo
00?oZJVYoa0@4?ooool00_ooool01Olb<S;oV9RHoooooonHV9So<S8b093ooooo002Vooooo`05o`00
0?n7QhOoooooojVYZOl000006oooool00omEEEGoc<c<ooooo`04ooooo`03oa0@4?l0003o^[Zj00?o
oooo00Goc<c<o`000?l0003o0000olc<c02@ooooo`00YOooool00ol@413o0000ogMgM`02o`000003
oiRHV?oooooooooo01Wooooo00?oZJVYogMgMoooool01Oooool00onj^[[o8B4Qooooo`02ooooo`05
oa0@4?nj^[[ooooookZj^_l@4100T?ooool00<?ooooo00Go410@oooooooooooooooooc8b<P03oooo
o`05oa0@4?nHV9SooooookZj^_l000000oooool01Ol0003o^[Zjoooooonj^[[o0000093ooooo0033
ooooo`Go00000oooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@2@ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(744) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.67926 .38021 Mdot
.66138 .37772 Mdot
.30399 .45428 Mdot
.58536 .64704 Mdot
.43365 .57189 Mdot
.33773 .49955 Mdot
.45097 .38792 Mdot
.45414 .34334 Mdot
.33309 .47864 Mdot
.67879 .47281 Mdot
.45786 .40364 Mdot
.66186 .58475 Mdot
.45314 .37803 Mdot
.60596 .58959 Mdot
.27542 .26777 Mdot
.57832 .54346 Mdot
.61777 .39028 Mdot
.44502 .64116 Mdot
.54035 .55714 Mdot
.33229 .46102 Mdot
.70216 .37784 Mdot
.60131 .58808 Mdot
.65588 .3713 Mdot
.60436 .59017 Mdot
.59946 .63449 Mdot
.65106 .41057 Mdot
.67075 .36266 Mdot
.57115 .62435 Mdot
.61552 .61244 Mdot
.42582 .38872 Mdot
.39281 .57505 Mdot
.1669 .41076 Mdot
.60437 .54071 Mdot
.71996 .67822 Mdot
.43298 .3542 Mdot
.31428 .73196 Mdot
.31096 .46969 Mdot
.48185 .37912 Mdot
.4401 .34662 Mdot
.45388 .35146 Mdot
.46521 .3641 Mdot
.65605 .40605 Mdot
.44304 .41589 Mdot
.47556 .32554 Mdot
.57361 .64574 Mdot
.52032 .28806 Mdot
.3625 .71393 Mdot
.57077 .61888 Mdot
.67429 .40324 Mdot
.3509 .47373 Mdot
.77824 .65051 Mdot
.48481 .36982 Mdot
.41879 .27754 Mdot
.24726 .21825 Mdot
.44183 .36236 Mdot
.57442 .64065 Mdot
.31153 .48811 Mdot
.57479 .58401 Mdot
.58597 .59606 Mdot
.77861 .61529 Mdot
.59766 .61814 Mdot
.40195 .6348 Mdot
.62907 .3567 Mdot
.27247 .46474 Mdot
.33537 .488 Mdot
.42657 .36636 Mdot
.61398 .41649 Mdot
.46291 .37987 Mdot
.58393 .67409 Mdot
.34523 .47503 Mdot
.56823 .61868 Mdot
.46496 .40125 Mdot
.62761 .44139 Mdot
.62045 .56824 Mdot
.55635 .30052 Mdot
.33688 .2389 Mdot
.43822 .67072 Mdot
.76088 .60217 Mdot
.75944 .35792 Mdot
.34364 .28157 Mdot
.61035 .59834 Mdot
.72453 .24755 Mdot
.29089 .25785 Mdot
.64832 .37489 Mdot
.56055 .70056 Mdot
.31226 .42761 Mdot
.61837 .57421 Mdot
.43785 .52175 Mdot
.64396 .63553 Mdot
.62653 .31056 Mdot
.32811 .47515 Mdot
.6622 .41002 Mdot
.58606 .65005 Mdot
.59729 .55474 Mdot
.76779 .47274 Mdot
.64494 .60569 Mdot
.5589 .62245 Mdot
.67533 .35784 Mdot
.43668 .3986 Mdot
.6488 .64774 Mdot
.4541 .31188 Mdot
.41566 .26318 Mdot
.62397 .6344 Mdot
.34618 .48993 Mdot
.62223 .37412 Mdot
.61683 .64752 Mdot
.43633 .36139 Mdot
.59703 .6087 Mdot
.42628 .32683 Mdot
.67369 .38341 Mdot
.59793 .55577 Mdot
.4387 .63413 Mdot
.60562 .28938 Mdot
.64593 .4288 Mdot
.61729 .20583 Mdot
.58902 .61601 Mdot
.59414 .58725 Mdot
.65919 .37932 Mdot
.30797 .50207 Mdot
.42438 .51617 Mdot
.61491 .42656 Mdot
.44748 .3476 Mdot
.66149 .36494 Mdot
.58042 .66526 Mdot
.33306 .51436 Mdot
.41111 .26452 Mdot
.41344 .23879 Mdot
.56085 .78726 Mdot
.62503 .58202 Mdot
.43689 .29234 Mdot
.3302 .50703 Mdot
.66442 .39716 Mdot
.46199 .37672 Mdot
.54484 .61007 Mdot
.62085 .40124 Mdot
.47577 .38102 Mdot
.42932 .62906 Mdot
.2731 .61182 Mdot
.65449 .43113 Mdot
.54526 .47467 Mdot
.41323 .36617 Mdot
.45341 .35229 Mdot
.72855 .70581 Mdot
.65427 .37837 Mdot
.42432 .65022 Mdot
.47356 .38225 Mdot
.51451 .72063 Mdot
.54574 .60954 Mdot
.6397 .74206 Mdot
.76484 .30903 Mdot
.76479 .67304 Mdot
.50055 .20837 Mdot
.38843 .64533 Mdot
.47763 .36646 Mdot
.60649 .64297 Mdot
.64606 .38788 Mdot
.65268 .39254 Mdot
.57362 .55728 Mdot
.59446 .62914 Mdot
.55701 .57934 Mdot
.57194 .56092 Mdot
.34872 .7028 Mdot
.56039 .57219 Mdot
.33261 .53541 Mdot
.62558 .4242 Mdot
.60744 .6279 Mdot
.2852 .47546 Mdot
.54733 .56361 Mdot
.48065 .38171 Mdot
.58277 .59268 Mdot
.58823 .63412 Mdot
.63958 .60688 Mdot
.46874 .36351 Mdot
.16968 .49328 Mdot
.73406 .29659 Mdot
.21578 .6352 Mdot
.54244 .21304 Mdot
.3162 .49722 Mdot
.61029 .57575 Mdot
.41806 .63385 Mdot
.50145 .60137 Mdot
.58724 .59974 Mdot
.81181 .59607 Mdot
.58122 .62833 Mdot
.70593 .63567 Mdot
.55243 .53227 Mdot
.19731 .62192 Mdot
.44387 .45397 Mdot
.61239 .61313 Mdot
.73822 .43441 Mdot
.65823 .74649 Mdot
.47902 .60214 Mdot
.45288 .3611 Mdot
.28866 .48725 Mdot
.3058 .48034 Mdot
.42732 .41245 Mdot
.63257 .66389 Mdot
.65649 .48529 Mdot
.63643 .66826 Mdot
.40691 .25993 Mdot
.60704 .42522 Mdot
.40457 .66455 Mdot
.66565 .42267 Mdot
.64798 .18621 Mdot
.57916 .36465 Mdot
.43202 .3365 Mdot
.43755 .62635 Mdot
.2852 .46057 Mdot
.40308 .25852 Mdot
.42329 .63885 Mdot
.56183 .60967 Mdot
.67133 .40447 Mdot
.67204 .74374 Mdot
.54026 .55019 Mdot
.52291 .84194 Mdot
.6308 .38122 Mdot
.45012 .48177 Mdot
.45845 .36681 Mdot
.3605 .48138 Mdot
.62174 .58864 Mdot
.56973 .57053 Mdot
.64194 .35429 Mdot
.57475 .61737 Mdot
.6846 .3294 Mdot
.58395 .63451 Mdot
.26659 .46855 Mdot
.37946 .66346 Mdot
.47369 .41076 Mdot
.57822 .78238 Mdot
.6463 .44466 Mdot
.28377 .53076 Mdot
.32423 .46206 Mdot
.67786 .46047 Mdot
.45183 .40608 Mdot
.42893 .6267 Mdot
.30026 .46531 Mdot
.37993 .6307 Mdot
.62968 .6239 Mdot
.31602 .46786 Mdot
.41384 .6615 Mdot
.23993 .59062 Mdot
.56399 .63665 Mdot
.47355 .68801 Mdot
.45549 .39105 Mdot
.67835 .37145 Mdot
.59876 .61873 Mdot
.4148 .23807 Mdot
.54922 .64264 Mdot
.42659 .23208 Mdot
.42403 .26669 Mdot
.41807 .27543 Mdot
.31853 .27498 Mdot
.3957 .62582 Mdot
.52814 .24796 Mdot
.55571 .44007 Mdot
.61202 .41262 Mdot
.58141 .65008 Mdot
.17193 .54763 Mdot
.47329 .38053 Mdot
.56289 .60853 Mdot
.28488 .43416 Mdot
.47239 .3836 Mdot
.58081 .57861 Mdot
.45933 .35825 Mdot
.64949 .38817 Mdot
.37498 .5438 Mdot
.63503 .36817 Mdot
.56622 .63558 Mdot
.43594 .37314 Mdot
.29292 .47526 Mdot
.64892 .41012 Mdot
.5933 .60718 Mdot
.61011 .58063 Mdot
.40563 .25182 Mdot
.61181 .62379 Mdot
.18041 .55142 Mdot
.56934 .62237 Mdot
.27737 .46712 Mdot
.646 .61237 Mdot
.76864 .68868 Mdot
.27775 .60663 Mdot
.62455 .42965 Mdot
.42141 .27015 Mdot
.32495 .4781 Mdot
.36623 .56289 Mdot
.5011 .53142 Mdot
.60451 .60269 Mdot
.41949 .25486 Mdot
.42328 .48921 Mdot
.42517 .36979 Mdot
.63467 .64587 Mdot
.58123 .34401 Mdot
.31018 .46015 Mdot
.40434 .25759 Mdot
.60758 .53242 Mdot
.62664 .36925 Mdot
.58583 .64506 Mdot
.30746 .4673 Mdot
.66512 .36533 Mdot
.54672 .62722 Mdot
.36543 .72863 Mdot
.42393 .25284 Mdot
.45736 .38999 Mdot
.61233 .4979 Mdot
.5516 .59081 Mdot
.30108 .48463 Mdot
.63672 .38234 Mdot
.43028 .37155 Mdot
.64805 .42116 Mdot
.6594 .75177 Mdot
.55639 .22402 Mdot
.2958 .67912 Mdot
.4431 .63143 Mdot
.41279 .21408 Mdot
.22892 .65608 Mdot
.56289 .24638 Mdot
.51132 .76542 Mdot
.30922 .75827 Mdot
.28761 .47076 Mdot
.4972 .67037 Mdot
.31983 .48186 Mdot
.61743 .63676 Mdot
.33809 .49517 Mdot
.1845 .61374 Mdot
.57471 .62843 Mdot
.31269 .49483 Mdot
.34037 .65837 Mdot
.59652 .62489 Mdot
.63453 .42984 Mdot
.22082 .32888 Mdot
.71929 .31591 Mdot
.57659 .4047 Mdot
.31164 .50016 Mdot
.82282 .50502 Mdot
.58095 .62385 Mdot
.56601 .54363 Mdot
.64433 .39339 Mdot
.63838 .64395 Mdot
.42092 .6657 Mdot
.38414 .62304 Mdot
.64102 .73395 Mdot
.65553 .23902 Mdot
.59233 .68147 Mdot
.64883 .40596 Mdot
.76172 .36847 Mdot
.55383 .30285 Mdot
.39921 .2361 Mdot
.4265 .35158 Mdot
.17277 .48876 Mdot
.51672 .63338 Mdot
.5446 .47987 Mdot
.57572 .34248 Mdot
.66987 .39782 Mdot
.21586 .57979 Mdot
.44169 .36618 Mdot
.74605 .39036 Mdot
.70849 .56159 Mdot
.55699 .5866 Mdot
.42742 .39936 Mdot
.66293 .61235 Mdot
.65384 .31375 Mdot
.51585 .69933 Mdot
.39403 .32536 Mdot
.56901 .64041 Mdot
.53508 .25699 Mdot
.59002 .59027 Mdot
.62237 .74041 Mdot
.56107 .6197 Mdot
.64139 .4231 Mdot
.60827 .68454 Mdot
.4652 .53222 Mdot
.70277 .2658 Mdot
.58873 .34935 Mdot
.3854 .64262 Mdot
.60542 .5817 Mdot
.56048 .58052 Mdot
.39496 .64515 Mdot
.63723 .412 Mdot
.55495 .61393 Mdot
.43677 .77906 Mdot
.55349 .58923 Mdot
.48246 .38408 Mdot
.39845 .55377 Mdot
.60365 .45795 Mdot
.60897 .56114 Mdot
.64817 .35959 Mdot
.44901 .35753 Mdot
.44285 .34364 Mdot
.52798 .63982 Mdot
.47574 .36556 Mdot
.58407 .64272 Mdot
.39215 .54968 Mdot
.66335 .37262 Mdot
.61996 .53018 Mdot
.63298 .41025 Mdot
.79915 .42021 Mdot
.45054 .35477 Mdot
.39795 .24313 Mdot
.51535 .539 Mdot
.44388 .37499 Mdot
.71728 .32748 Mdot
.52617 .65219 Mdot
.53281 .61188 Mdot
.71854 .32404 Mdot
.29502 .4902 Mdot
.39847 .25507 Mdot
.43371 .36668 Mdot
.55407 .58363 Mdot
.63119 .63172 Mdot
.46335 .40441 Mdot
.78603 .48932 Mdot
.36573 .57232 Mdot
.5623 .62291 Mdot
.63875 .42059 Mdot
.66298 .40113 Mdot
.55031 .63317 Mdot
.58624 .60492 Mdot
.27808 .47324 Mdot
.41904 .25009 Mdot
.40798 .27069 Mdot
.41045 .23731 Mdot
.36 .50771 Mdot
.44396 .22637 Mdot
.45458 .3524 Mdot
.46449 .26389 Mdot
.29367 .40622 Mdot
.52231 .61633 Mdot
.29798 .48458 Mdot
.57913 .57066 Mdot
.62355 .62636 Mdot
.43128 .37554 Mdot
.50813 .17941 Mdot
.66356 .65835 Mdot
.67782 .40838 Mdot
.48596 .38259 Mdot
.53255 .5378 Mdot
.47156 .43533 Mdot
.42652 .66189 Mdot
.58944 .35976 Mdot
.43215 .40427 Mdot
.66191 .41504 Mdot
.45292 .40914 Mdot
.55864 .5812 Mdot
.56467 .55717 Mdot
.66812 .38205 Mdot
.39513 .6251 Mdot
.62823 .64143 Mdot
.58208 .579 Mdot
.83442 .61499 Mdot
.55627 .29486 Mdot
.46404 .43528 Mdot
.61554 .62831 Mdot
.53088 .61969 Mdot
.38463 .63335 Mdot
.55323 .59808 Mdot
.6209 .58561 Mdot
.61819 .28603 Mdot
.43094 .41647 Mdot
.41704 .6748 Mdot
.74221 .38438 Mdot
.62901 .38419 Mdot
.19008 .53505 Mdot
.41694 .26476 Mdot
.46454 .4191 Mdot
.3766 .5403 Mdot
.40072 .2457 Mdot
.32589 .39925 Mdot
.20339 .55529 Mdot
.40255 .23963 Mdot
.38141 .51091 Mdot
.57765 .70048 Mdot
.54868 .57916 Mdot
.5816 .58981 Mdot
.42233 .63338 Mdot
.6511 .3807 Mdot
.43265 .46559 Mdot
.23255 .5551 Mdot
.59866 .58783 Mdot
.67787 .34683 Mdot
.20409 .52435 Mdot
.40334 .25191 Mdot
.40229 .62833 Mdot
.40636 .66715 Mdot
.59133 .58723 Mdot
.60405 .26335 Mdot
.65112 .40819 Mdot
.59338 .60691 Mdot
.58983 .55927 Mdot
.30745 .49802 Mdot
.66401 .41551 Mdot
.32603 .46286 Mdot
.42626 .26212 Mdot
.39553 .81221 Mdot
.82207 .63582 Mdot
.43811 .38994 Mdot
.21868 .62319 Mdot
.47115 .34844 Mdot
.37155 .28495 Mdot
.41193 .23985 Mdot
.59706 .59889 Mdot
.64107 .44295 Mdot
.59521 .60959 Mdot
.55889 .59675 Mdot
.55956 .60724 Mdot
.59867 .68232 Mdot
.80824 .6048 Mdot
.41599 .64419 Mdot
.5337 .63565 Mdot
.29378 .50329 Mdot
.198 .5898 Mdot
.2089 .36404 Mdot
.59506 .56612 Mdot
.59435 .5835 Mdot
.61633 .41209 Mdot
.60639 .55262 Mdot
.42347 .38178 Mdot
.64352 .37577 Mdot
.62749 .63737 Mdot
.22953 .59901 Mdot
.54995 .60467 Mdot
.24107 .66752 Mdot
.45653 .4079 Mdot
.58722 .36651 Mdot
.55062 .65531 Mdot
.4028 .23877 Mdot
.39809 .25333 Mdot
.39558 .23521 Mdot
.42018 .38256 Mdot
.30579 .491 Mdot
.23236 .50165 Mdot
.6537 .58505 Mdot
.60164 .64375 Mdot
.53358 .62774 Mdot
.3656 .48694 Mdot
.41576 .54479 Mdot
.50549 .21815 Mdot
.50915 .58692 Mdot
.29805 .50287 Mdot
.68833 .38634 Mdot
.5934 .18321 Mdot
.64101 .37815 Mdot
.41156 .67529 Mdot
.47611 .39036 Mdot
.43102 .66019 Mdot
.82396 .54848 Mdot
.66903 .3793 Mdot
.64405 .35356 Mdot
.31403 .49645 Mdot
.47105 .46396 Mdot
.14223 .35447 Mdot
.34899 .49949 Mdot
.48156 .78619 Mdot
.64397 .39866 Mdot
.63082 .57456 Mdot
.41648 .49358 Mdot
.47206 .46772 Mdot
.32247 .49087 Mdot
.61184 .59441 Mdot
.65572 .25248 Mdot
.2786 .47011 Mdot
.63474 .64337 Mdot
.32109 .50843 Mdot
.46995 .368 Mdot
.32674 .50725 Mdot
.67681 .42203 Mdot
.62867 .62177 Mdot
.19901 .26963 Mdot
.52212 .39329 Mdot
.59937 .61596 Mdot
.48547 .38107 Mdot
.42201 .78266 Mdot
.5634 .58639 Mdot
.42614 .66484 Mdot
.31701 .51717 Mdot
.34617 .60265 Mdot
.58482 .6223 Mdot
.33138 .49767 Mdot
.68374 .3983 Mdot
.48125 .42012 Mdot
.3361 .26025 Mdot
.40306 .26555 Mdot
.64434 .3841 Mdot
.38883 .24456 Mdot
.41485 .37564 Mdot
.64021 .62059 Mdot
.57944 .56062 Mdot
.63134 .42452 Mdot
.30491 .31702 Mdot
.63101 .56477 Mdot
.61025 .59821 Mdot
.30141 .45623 Mdot
.37111 .48502 Mdot
.24726 .34935 Mdot
.28792 .47293 Mdot
.53117 .62388 Mdot
.63349 .42512 Mdot
.61426 .64391 Mdot
.63113 .42989 Mdot
.58219 .65009 Mdot
.59255 .39299 Mdot
.64425 .37837 Mdot
.59925 .2197 Mdot
.62309 .60502 Mdot
.57615 .51315 Mdot
.55761 .59975 Mdot
.55963 .61398 Mdot
.3235 .51951 Mdot
.40478 .65022 Mdot
.64923 .6144 Mdot
.32008 .54256 Mdot
.41308 .62457 Mdot
.6922 .68665 Mdot
.30572 .49821 Mdot
.42892 .63655 Mdot
.42663 .70506 Mdot
.42043 .27056 Mdot
.41067 .63789 Mdot
.20499 .39711 Mdot
.43595 .38695 Mdot
.6518 .36726 Mdot
.59754 .62545 Mdot
.34421 .78913 Mdot
.3873 .57414 Mdot
.4092 .24717 Mdot
.58913 .61817 Mdot
.57414 .57378 Mdot
.61681 .38317 Mdot
.68431 .21088 Mdot
.32594 .45241 Mdot
.59581 .64964 Mdot
.6202 .38742 Mdot
.75778 .29813 Mdot
.33907 .51206 Mdot
.41174 .63415 Mdot
.47959 .39441 Mdot
.68815 .42057 Mdot
.40165 .26475 Mdot
.42592 .36296 Mdot
.38577 .48515 Mdot
.83076 .50456 Mdot
.58011 .61944 Mdot
.29895 .47798 Mdot
.76895 .66714 Mdot
.64443 .64711 Mdot
.41989 .42154 Mdot
.69216 .63404 Mdot
.66817 .4015 Mdot
.47353 .39865 Mdot
.38837 .65459 Mdot
.66053 .37002 Mdot
.63861 .41317 Mdot
.45801 .34457 Mdot
.27813 .51042 Mdot
.45315 .48077 Mdot
.47723 .39367 Mdot
.63216 .30497 Mdot
.67678 .73076 Mdot
.42075 .25466 Mdot
.39856 .62858 Mdot
.68151 .74758 Mdot
.65558 .40774 Mdot
.17223 .49008 Mdot
.80047 .61471 Mdot
.55894 .62243 Mdot
.42796 .65421 Mdot
.32931 .40881 Mdot
.22989 .50381 Mdot
.46969 .38803 Mdot
.43408 .5385 Mdot
.42877 .66616 Mdot
.54669 .59719 Mdot
.60514 .46436 Mdot
.62104 .60653 Mdot
.47592 .37681 Mdot
.69327 .32583 Mdot
.65769 .4209 Mdot
.41421 .38389 Mdot
.66805 .3203 Mdot
.62462 .62279 Mdot
.61869 .59728 Mdot
.58168 .75196 Mdot
.67192 .40485 Mdot
.40331 .268 Mdot
.60403 .60799 Mdot
.57544 .58614 Mdot
.64181 .61409 Mdot
.57862 .50452 Mdot
.59117 .27331 Mdot
.5994 .6501 Mdot
.35373 .51085 Mdot
.53991 .57859 Mdot
.6202 .59581 Mdot
.62643 .37468 Mdot
.82375 .61348 Mdot
.42636 .25323 Mdot
.57893 .59174 Mdot
.56237 .61922 Mdot
.44115 .34759 Mdot
.43559 .48379 Mdot
.47997 .46383 Mdot
.34664 .48028 Mdot
.50082 .74917 Mdot
.62693 .67167 Mdot
.62288 .39813 Mdot
.44227 .64007 Mdot
.63192 .5869 Mdot
.61989 .39767 Mdot
.54318 .5806 Mdot
.28134 .48293 Mdot
.41856 .25106 Mdot
.57722 .45693 Mdot
.40517 .6374 Mdot
.39933 .45234 Mdot
.48451 .28858 Mdot
.28513 .47934 Mdot
.60174 .63934 Mdot
.4901 .4031 Mdot
.32989 .46784 Mdot
.40712 .25117 Mdot
.59449 .52852 Mdot
.65158 .39588 Mdot
.65544 .42076 Mdot
.63482 .73744 Mdot
.32722 .44926 Mdot
.84508 .43823 Mdot
.4709 .36904 Mdot
.58215 .66124 Mdot
.46442 .30316 Mdot
.65149 .42484 Mdot
.62309 .75287 Mdot
.4266 .63405 Mdot
.46747 .38988 Mdot
.41423 .23239 Mdot
.61845 .4043 Mdot
.66274 .4216 Mdot
.56457 .63943 Mdot
.59821 .57095 Mdot
.50881 .77059 Mdot
.6348 .74248 Mdot
.46388 .36195 Mdot
.39445 .63322 Mdot
.35059 .47804 Mdot
.6197 .62714 Mdot
.65057 .37352 Mdot
.70454 .64435 Mdot
.55256 .58272 Mdot
.27823 .46933 Mdot
.66897 .39363 Mdot
.39258 .64131 Mdot
.43653 .64015 Mdot
.55936 .61354 Mdot
.77175 .60542 Mdot
.44386 .37981 Mdot
.64286 .4301 Mdot
.66231 .46126 Mdot
.63783 .57403 Mdot
.60161 .57229 Mdot
.65627 .57068 Mdot
.4269 .36207 Mdot
.58947 .45782 Mdot
.44449 .65763 Mdot
.65664 .39031 Mdot
.59887 .61393 Mdot
.40235 .63461 Mdot
.57959 .4834 Mdot
.40687 .24071 Mdot
.32453 .50959 Mdot
.41821 .66664 Mdot
.40744 .65761 Mdot
.41553 .62363 Mdot
.17739 .47685 Mdot
.61125 .43004 Mdot
.74406 .35606 Mdot
.55675 .61687 Mdot
.63528 .73481 Mdot
.59606 .54967 Mdot
.41798 .38158 Mdot
.29031 .48221 Mdot
.55814 .59199 Mdot
.56556 .64057 Mdot
.64347 .51116 Mdot
.54411 .52956 Mdot
.69846 .3631 Mdot
.67483 .3918 Mdot
.56527 .51447 Mdot
.29926 .4929 Mdot
.73684 .24628 Mdot
.14338 .51218 Mdot
.56906 .666 Mdot
.4438 .47219 Mdot
.64597 .37539 Mdot
.46182 .3478 Mdot
.48492 .46931 Mdot
.47704 .40022 Mdot
.66019 .38979 Mdot
.61849 .63302 Mdot
.4692 .26329 Mdot
.38954 .62218 Mdot
.56086 .57369 Mdot
.46307 .36934 Mdot
.55874 .57648 Mdot
.42112 .39404 Mdot
.67442 .33469 Mdot
.58468 .3276 Mdot
.57936 .62813 Mdot
.63713 .57731 Mdot
.63192 .50245 Mdot
.59538 .567 Mdot
.34621 .36698 Mdot
.63525 .40213 Mdot
.65361 .24426 Mdot
.55134 .63173 Mdot
.7911 .55445 Mdot
.54982 .58459 Mdot
.30096 .32994 Mdot
.60822 .56941 Mdot
.48873 .49609 Mdot
.54616 .60338 Mdot
.6115 .57806 Mdot
.43586 .36923 Mdot
.44336 .3464 Mdot
.68227 .40222 Mdot
.39872 .26275 Mdot
.19734 .61747 Mdot
.58911 .57591 Mdot
.34965 .51779 Mdot
.48115 .31451 Mdot
.40598 .65505 Mdot
.66004 .39452 Mdot
.79355 .32353 Mdot
.45331 .35687 Mdot
.26885 .46818 Mdot
.31883 .32689 Mdot
.35024 .46936 Mdot
.43546 .31653 Mdot
.54056 .52571 Mdot
.38998 .63807 Mdot
.54866 .58584 Mdot
.7224 .67048 Mdot
.54329 .27359 Mdot
.61714 .6533 Mdot
.41767 .40449 Mdot
.4991 .60574 Mdot
.69185 .72667 Mdot
.38089 .64929 Mdot
.39111 .6537 Mdot
.43718 .36555 Mdot
.31768 .45527 Mdot
.65135 .65229 Mdot
.42983 .6368 Mdot
.29003 .49223 Mdot
.39437 .25795 Mdot
.48844 .55854 Mdot
.65341 .40568 Mdot
.57408 .41598 Mdot
.5248 .31724 Mdot
.4617 .36085 Mdot
.33745 .54496 Mdot
.69204 .4025 Mdot
.6171 .37696 Mdot
.39526 .24915 Mdot
.31873 .51932 Mdot
.62735 .44361 Mdot
.63362 .63407 Mdot
.53646 .55321 Mdot
.59099 .59104 Mdot
.43023 .64353 Mdot
.60648 .56528 Mdot
.29978 .50962 Mdot
.47012 .38089 Mdot
.32651 .47164 Mdot
.44305 .38265 Mdot
.47398 .24569 Mdot
.58319 .60868 Mdot
.60342 .57791 Mdot
.4015 .52555 Mdot
.67206 .41453 Mdot
.79252 .59587 Mdot
.34428 .52253 Mdot
.31376 .48531 Mdot
.61816 .64171 Mdot
.68414 .39286 Mdot
.3689 .6353 Mdot
.40087 .51038 Mdot
.59853 .56205 Mdot
.63475 .40094 Mdot
.59787 .64745 Mdot
.29585 .66937 Mdot
.57519 .3252 Mdot
.64911 .42193 Mdot
.67973 .24249 Mdot
.61832 .61771 Mdot
.53755 .68318 Mdot
.52941 .61535 Mdot
.44704 .76278 Mdot
.64365 .58658 Mdot
.63226 .37918 Mdot
.58435 .59363 Mdot
.63252 .38777 Mdot
.29124 .46066 Mdot
.46275 .35318 Mdot
.64213 .38666 Mdot
.61392 .56372 Mdot
.16385 .45257 Mdot
.46509 .36727 Mdot
.60863 .58175 Mdot
.43753 .40277 Mdot
.62755 .37845 Mdot
.67586 .40499 Mdot
.20819 .40025 Mdot
.43811 .43479 Mdot
.46207 .36427 Mdot
.59177 .6441 Mdot
.53095 .35201 Mdot
.6132 .64427 Mdot
.51922 .77235 Mdot
.56888 .65171 Mdot
.6461 .61557 Mdot
.37281 .20579 Mdot
.49171 .37948 Mdot
.82405 .39698 Mdot
.23502 .56638 Mdot
.18112 .46216 Mdot
.65516 .45175 Mdot
.38091 .64945 Mdot
.21114 .56582 Mdot
.42501 .26365 Mdot
.32247 .51466 Mdot
.5576 .59243 Mdot
.58952 .41375 Mdot
.48374 .38673 Mdot
.4101 .65193 Mdot
.58035 .62843 Mdot
.27839 .47879 Mdot
.22051 .37138 Mdot
.47793 .36729 Mdot
.65662 .40482 Mdot
.67503 .41132 Mdot
.74362 .29439 Mdot
.59533 .61524 Mdot
.6017 .58084 Mdot
.47788 .38776 Mdot
.62365 .67053 Mdot
.41136 .62 Mdot
.32629 .66741 Mdot
.45784 .36338 Mdot
.52459 .38182 Mdot
.6737 .38191 Mdot
.57571 .57229 Mdot
.4067 .55747 Mdot
.24126 .4243 Mdot
.71233 .45911 Mdot
.42154 .63394 Mdot
.53949 .76055 Mdot
.63184 .37966 Mdot
.46229 .37369 Mdot
.46941 .67402 Mdot
.55405 .64747 Mdot
.57453 .57634 Mdot
.54576 .75914 Mdot
.42799 .48334 Mdot
.3722 .62053 Mdot
.61002 .55289 Mdot
.42918 .49157 Mdot
.62027 .63962 Mdot
.6307 .63138 Mdot
.58071 .67198 Mdot
.61733 .57587 Mdot
.634 .39453 Mdot
.64597 .51056 Mdot
.33283 .50379 Mdot
.76593 .45996 Mdot
.44832 .52742 Mdot
.60647 .6207 Mdot
.62032 .6299 Mdot
.70115 .44537 Mdot
.4864 .32221 Mdot
.63861 .40297 Mdot
.59716 .39741 Mdot
.44574 .35296 Mdot
.56181 .52238 Mdot
.34724 .46257 Mdot
.68502 .59534 Mdot
.3323 .47345 Mdot
.63379 .4007 Mdot
.30719 .48554 Mdot
.44239 .35255 Mdot
.29957 .47702 Mdot
.35904 .50829 Mdot
.43519 .40924 Mdot
.67563 .38153 Mdot
.59748 .56307 Mdot
.45402 .35511 Mdot
.57755 .75536 Mdot
.4308 .64358 Mdot
.20799 .39935 Mdot
.5547 .55001 Mdot
.63526 .7035 Mdot
.36524 .72802 Mdot
.319 .47228 Mdot
.58628 .31009 Mdot
.64437 .3785 Mdot
.426 .62055 Mdot
.6337 .39077 Mdot
.80942 .58795 Mdot
.39707 .64491 Mdot
.20495 .40152 Mdot
.45725 .67364 Mdot
.31614 .5577 Mdot
.58501 .55267 Mdot
.6173 .35302 Mdot
.32544 .46548 Mdot
.48312 .38234 Mdot
.3322 .4263 Mdot
.62673 .58904 Mdot
.55779 .24322 Mdot
.60707 .41495 Mdot
.41455 .27203 Mdot
.46128 .37885 Mdot
.4136 .40021 Mdot
.59019 .61462 Mdot
.35645 .55915 Mdot
.60676 .65477 Mdot
.47699 .6473 Mdot
.51689 .75938 Mdot
.68661 .59967 Mdot
.58222 .64357 Mdot
.33956 .47467 Mdot
.59691 .64678 Mdot
.52134 .65923 Mdot
.72554 .70746 Mdot
.54988 .55275 Mdot
.56867 .21999 Mdot
.36434 .59934 Mdot
.66546 .37932 Mdot
.54755 .65471 Mdot
.41344 .25493 Mdot
.61715 .6237 Mdot
.4724 .87035 Mdot
.40951 .64081 Mdot
.32108 .44137 Mdot
.59883 .55325 Mdot
.59989 .60934 Mdot
.73634 .63925 Mdot
.59828 .36256 Mdot
.41862 .23569 Mdot
.5717 .58148 Mdot
.51176 .73837 Mdot
.42756 .37639 Mdot
.56101 .65005 Mdot
.58514 .58969 Mdot
.64722 .76223 Mdot
.4285 .38834 Mdot
.31186 .47394 Mdot
.42305 .26864 Mdot
.35273 .4817 Mdot
.38821 .66219 Mdot
.49885 .45409 Mdot
.63341 .74842 Mdot
.57233 .32647 Mdot
.43246 .66225 Mdot
.59036 .55642 Mdot
.59618 .71135 Mdot
.61351 .60606 Mdot
.38923 .65313 Mdot
.42659 .39057 Mdot
.63722 .39335 Mdot
.56989 .45003 Mdot
.40672 .25829 Mdot
.63586 .64057 Mdot
.38057 .64406 Mdot
.64747 .39099 Mdot
.2365 .38575 Mdot
.65688 .38252 Mdot
.44397 .37156 Mdot
.41673 .37472 Mdot
.39984 .64291 Mdot
.63281 .39301 Mdot
.35313 .50676 Mdot
.23603 .56375 Mdot
.57408 .65315 Mdot
.48248 .42609 Mdot
.66205 .43619 Mdot
.66701 .35991 Mdot
.62674 .43645 Mdot
.58115 .61378 Mdot
.4397 .47869 Mdot
.5668 .66036 Mdot
.44077 .3597 Mdot
.31398 .50851 Mdot
.64234 .74182 Mdot
.74174 .65119 Mdot
.52522 .38982 Mdot
.64866 .61434 Mdot
.61926 .58779 Mdot
.59157 .58723 Mdot
.56489 .62932 Mdot
.31603 .67642 Mdot
.58374 .60643 Mdot
.43772 .37578 Mdot
.34356 .49359 Mdot
.59365 .61824 Mdot
.41582 .25717 Mdot
.4543 .492 Mdot
.44224 .64401 Mdot
.47902 .50056 Mdot
.15554 .49528 Mdot
.64634 .39179 Mdot
.29894 .46777 Mdot
.3279 .51321 Mdot
.4293 .62897 Mdot
.47202 .36667 Mdot
.65297 .38192 Mdot
.43475 .74762 Mdot
.40507 .62278 Mdot
.57812 .59243 Mdot
.38653 .54502 Mdot
.64514 .21536 Mdot
.5695 .56003 Mdot
.56318 .59959 Mdot
.41986 .27427 Mdot
.33321 .45573 Mdot
.34836 .80824 Mdot
.4139 .47493 Mdot
.40307 .64772 Mdot
.39901 .65704 Mdot
.62216 .43519 Mdot
.61565 .65646 Mdot
.44888 .38576 Mdot
.41178 .50171 Mdot
.45553 .79972 Mdot
.269 .4375 Mdot
.3657 .28272 Mdot
.55144 .60369 Mdot
.73177 .61838 Mdot
.58715 .65261 Mdot
.61798 .37999 Mdot
.61661 .42299 Mdot
.64342 .40515 Mdot
.43912 .36732 Mdot
.80083 .42856 Mdot
.43801 .37895 Mdot
.15247 .50041 Mdot
.64578 .37192 Mdot
.28756 .58017 Mdot
.30994 .49045 Mdot
.65392 .59127 Mdot
.39178 .6343 Mdot
.50063 .34333 Mdot
.57412 .67238 Mdot
.59462 .26088 Mdot
.29819 .48419 Mdot
.67805 .39629 Mdot
.5134 .63721 Mdot
.21307 .66278 Mdot
.48948 .44886 Mdot
.45608 .60669 Mdot
.78937 .61072 Mdot
.39507 .64413 Mdot
.71353 .44644 Mdot
.40119 .61934 Mdot
.47445 .3821 Mdot
.62613 .58661 Mdot
.62224 .57822 Mdot
.58159 .6467 Mdot
.58092 .60773 Mdot
.43042 .36948 Mdot
.55363 .62724 Mdot
.76876 .68833 Mdot
.42325 .25931 Mdot
.25983 .615 Mdot
.43437 .65283 Mdot
.42891 .4092 Mdot
.33999 .48273 Mdot
.39749 .26241 Mdot
.58995 .77989 Mdot
.55252 .61608 Mdot
.55775 .59649 Mdot
.40394 .23526 Mdot
.59487 .67362 Mdot
.51443 .63323 Mdot
.33461 .50116 Mdot
.53046 .41111 Mdot
.3974 .66319 Mdot
.43014 .66073 Mdot
.44042 .40882 Mdot
.63324 .3911 Mdot
.42235 .63221 Mdot
.31087 .4546 Mdot
.54529 .61805 Mdot
.63887 .59306 Mdot
.66312 .43519 Mdot
.80063 .61459 Mdot
.37703 .63407 Mdot
.53819 .66673 Mdot
.63072 .38568 Mdot
.6073 .41985 Mdot
.5703 .58033 Mdot
.59627 .53265 Mdot
.66829 .3638 Mdot
.43824 .64807 Mdot
.43073 .41009 Mdot
.30549 .56306 Mdot
.47422 .37655 Mdot
.64929 .38445 Mdot
.53818 .61065 Mdot
.67493 .38169 Mdot
.61528 .62163 Mdot
.53997 .11738 Mdot
.614 .57222 Mdot
.71564 .31813 Mdot
.45799 .76799 Mdot
.33214 .51219 Mdot
.35527 .50232 Mdot
.41852 .255 Mdot
.63218 .38203 Mdot
.63289 .59051 Mdot
.39308 .65051 Mdot
.1835 .44613 Mdot
.61005 .44085 Mdot
.30135 .50442 Mdot
.34301 .46031 Mdot
.42463 .38008 Mdot
.55684 .57236 Mdot
.58238 .5705 Mdot
.30142 .47587 Mdot
.35867 .71905 Mdot
.62236 .40401 Mdot
.60191 .58148 Mdot
.62047 .59139 Mdot
.33709 .50426 Mdot
.23887 .57047 Mdot
.64255 .33815 Mdot
.61803 .57803 Mdot
.44437 .68202 Mdot
.41891 .38267 Mdot
.57181 .63194 Mdot
.55504 .62765 Mdot
.41657 .65756 Mdot
.25141 .62451 Mdot
.70155 .72232 Mdot
.42199 .40224 Mdot
.40533 .26904 Mdot
.61688 .5641 Mdot
.3122 .49131 Mdot
.63182 .57618 Mdot
.28617 .71302 Mdot
.42116 .2654 Mdot
.59233 .60159 Mdot
.57429 .66804 Mdot
.64687 .43202 Mdot
.59336 .60472 Mdot
.68784 .58755 Mdot
.3514 .48916 Mdot
.59129 .60311 Mdot
.77875 .59881 Mdot
.42629 .37321 Mdot
.55935 .66334 Mdot
.40517 .66334 Mdot
.44293 .76442 Mdot
.50092 .299 Mdot
.36638 .50047 Mdot
.43605 .64487 Mdot
.60238 .56276 Mdot
.31308 .45639 Mdot
.48498 .3874 Mdot
.57358 .24848 Mdot
.54675 .58114 Mdot
.47257 .37276 Mdot
.46868 .3799 Mdot
.40304 .64207 Mdot
.79331 .34954 Mdot
.6006 .6757 Mdot
.59743 .5659 Mdot
.57253 .80932 Mdot
.61032 .41874 Mdot
.59556 .56415 Mdot
.5677 .56441 Mdot
.45074 .39109 Mdot
.51645 .53561 Mdot
.7162 .36485 Mdot
.3403 .65925 Mdot
.42059 .39279 Mdot
.35952 .51998 Mdot
.3112 .45691 Mdot
.43464 .65072 Mdot
.66674 .38323 Mdot
.43705 .6611 Mdot
.32002 .50189 Mdot
.55935 .61764 Mdot
.45672 .39549 Mdot
.71424 .49435 Mdot
.48484 .369 Mdot
.27444 .47125 Mdot
.6472 .35738 Mdot
.45583 .29813 Mdot
.64134 .81059 Mdot
.52322 .30423 Mdot
.43701 .41553 Mdot
.40659 .65547 Mdot
.3955 .50831 Mdot
.6191 .58899 Mdot
.73375 .40904 Mdot
.57533 .56458 Mdot
.78694 .615 Mdot
.28965 .48535 Mdot
.39525 .24516 Mdot
.62653 .58675 Mdot
.53184 .75573 Mdot
.43199 .41322 Mdot
.42415 .37536 Mdot
.56915 .60743 Mdot
.44309 .37367 Mdot
.5934 .57146 Mdot
.34445 .50133 Mdot
.80027 .3681 Mdot
.61484 .58402 Mdot
.53346 .57716 Mdot
.44267 .42102 Mdot
.20733 .39949 Mdot
.33063 .52472 Mdot
.73245 .6241 Mdot
.22909 .69168 Mdot
.44504 .37617 Mdot
.52813 .61862 Mdot
.31335 .46707 Mdot
.41931 .27518 Mdot
.29593 .51424 Mdot
.56466 .57243 Mdot
.55506 .60577 Mdot
.61457 .64578 Mdot
.61917 .5983 Mdot
.72908 .41043 Mdot
.51922 .56608 Mdot
.72923 .57944 Mdot
.55864 .59831 Mdot
.63693 .46822 Mdot
.4343 .37469 Mdot
.69661 .36095 Mdot
.40855 .61053 Mdot
.55452 .6106 Mdot
.59009 .37707 Mdot
.42598 .40664 Mdot
.15686 .5076 Mdot
.42622 .38415 Mdot
.32736 .47814 Mdot
.46735 .35088 Mdot
.6127 .62264 Mdot
.66256 .40318 Mdot
.34918 .49314 Mdot
.49715 .22385 Mdot
.31934 .51478 Mdot
.59869 .61605 Mdot
.25964 .5961 Mdot
.32836 .5119 Mdot
.46271 .49521 Mdot
.66521 .39777 Mdot
.51675 .73352 Mdot
.61155 .40747 Mdot
.59826 .60149 Mdot
.60345 .59965 Mdot
.39943 .2676 Mdot
.47749 .3652 Mdot
.6309 .37589 Mdot
.83877 .60789 Mdot
.40885 .67174 Mdot
.64515 .41185 Mdot
.6296 .55503 Mdot
.43146 .47664 Mdot
.64268 .4281 Mdot
.47602 .73832 Mdot
.47717 .37116 Mdot
.62767 .44187 Mdot
.63124 .55176 Mdot
.53684 .48654 Mdot
.39807 .61688 Mdot
.28223 .48824 Mdot
.52625 .46623 Mdot
.33069 .46594 Mdot
.41726 .39645 Mdot
.30804 .45065 Mdot
.42853 .37698 Mdot
.72006 .32888 Mdot
.69608 .33075 Mdot
.49018 .39692 Mdot
.41545 .37663 Mdot
.32152 .49689 Mdot
.56342 .62586 Mdot
.45207 .54267 Mdot
.64281 .5766 Mdot
.57095 .55493 Mdot
.42778 .36303 Mdot
.62444 .38614 Mdot
.66332 .3675 Mdot
.63195 .34823 Mdot
.67172 .41288 Mdot
.34159 .48258 Mdot
.59339 .31266 Mdot
.81812 .55841 Mdot
.44936 .40621 Mdot
.44975 .33483 Mdot
.61581 .64108 Mdot
.31523 .49352 Mdot
.28558 .466 Mdot
.45762 .38847 Mdot
.73122 .45565 Mdot
.53167 .61886 Mdot
.61905 .38304 Mdot
.64711 .37171 Mdot
.64001 .42634 Mdot
.64282 .43789 Mdot
.77865 .41106 Mdot
.48324 .38204 Mdot
.63818 .37651 Mdot
.57744 .60431 Mdot
.55315 .59533 Mdot
.40431 .26373 Mdot
.42122 .66303 Mdot
.55801 .55193 Mdot
.54245 .5637 Mdot
.57028 .57876 Mdot
.32496 .51034 Mdot
.64116 .54823 Mdot
.41718 .26678 Mdot
.322 .45134 Mdot
.36305 .48177 Mdot
.39752 .24474 Mdot
.67833 .45172 Mdot
.20793 .66698 Mdot
.59616 .64956 Mdot
.49457 .65283 Mdot
.3167 .48959 Mdot
.65715 .28762 Mdot
.60426 .47449 Mdot
.58127 .64157 Mdot
.50125 .52184 Mdot
.34776 .49892 Mdot
.60539 .40885 Mdot
.5824 .5645 Mdot
.41317 .23974 Mdot
.44117 .63951 Mdot
.63667 .55977 Mdot
.42142 .27335 Mdot
.63193 .40127 Mdot
.40982 .59377 Mdot
.62027 .43672 Mdot
.34007 .51277 Mdot
.56125 .66498 Mdot
.14708 .34113 Mdot
.32028 .46237 Mdot
.2011 .47605 Mdot
.68965 .33155 Mdot
.61607 .58258 Mdot
.32641 .46324 Mdot
.60607 .39898 Mdot
.41919 .37903 Mdot
.42813 .50072 Mdot
.6531 .37396 Mdot
.39602 .25829 Mdot
.40006 .25659 Mdot
.33477 .50377 Mdot
.67244 .396 Mdot
.55896 .64253 Mdot
.62866 .43048 Mdot
.47146 .35363 Mdot
.58931 .63382 Mdot
.19752 .62368 Mdot
.53356 .556 Mdot
.62755 .38816 Mdot
.27957 .46236 Mdot
.38734 .62979 Mdot
.5781 .62674 Mdot
.20045 .51007 Mdot
.56306 .56674 Mdot
.43245 .39863 Mdot
.64807 .26608 Mdot
.70226 .49732 Mdot
.56141 .62053 Mdot
.61927 .63503 Mdot
.44282 .41014 Mdot
.56084 .62303 Mdot
.56664 .56229 Mdot
.42797 .42482 Mdot
.65145 .42844 Mdot
.59401 .59143 Mdot
.28334 .48003 Mdot
.73956 .67438 Mdot
.61867 .56456 Mdot
.54965 .20903 Mdot
.52399 .74399 Mdot
.66107 .27442 Mdot
.6245 .57126 Mdot
.58672 .75818 Mdot
.60626 .5948 Mdot
.57582 .61829 Mdot
.58919 .64763 Mdot
.72297 .60856 Mdot
.31838 .49827 Mdot
.30016 .50651 Mdot
.40202 .61548 Mdot
.52041 .74496 Mdot
.42718 .6532 Mdot
.42828 .40358 Mdot
.31652 .27894 Mdot
.42228 .26083 Mdot
.63322 .38962 Mdot
.6284 .62571 Mdot
.33658 .51694 Mdot
.57262 .57186 Mdot
.61367 .62739 Mdot
.34402 .50603 Mdot
.31772 .45954 Mdot
.31207 .44625 Mdot
.39995 .6211 Mdot
.64121 .39714 Mdot
.56375 .6371 Mdot
.41232 .62459 Mdot
.55659 .64265 Mdot
.41989 .47914 Mdot
.64034 .39991 Mdot
.63083 .43158 Mdot
.64076 .36589 Mdot
.55657 .61518 Mdot
.60893 .62349 Mdot
.43866 .38069 Mdot
.66393 .43555 Mdot
.46125 .40367 Mdot
.33184 .46778 Mdot
.34995 .50711 Mdot
.56368 .57331 Mdot
.5253 .65635 Mdot
.40034 .65664 Mdot
.32336 .47565 Mdot
.40821 .23377 Mdot
.40879 .61639 Mdot
.58814 .61813 Mdot
.3361 .47226 Mdot
.42725 .66311 Mdot
.75114 .47111 Mdot
.26923 .72943 Mdot
.38362 .63227 Mdot
.57051 .60587 Mdot
.74016 .64033 Mdot
.48886 .6787 Mdot
.42104 .67197 Mdot
.45061 .40401 Mdot
.55956 .57091 Mdot
.39335 .76924 Mdot
.41835 .66895 Mdot
.79281 .62496 Mdot
.33605 .50946 Mdot
.50376 .55633 Mdot
.62611 .54762 Mdot
.7474 .41135 Mdot
.4324 .6656 Mdot
.65428 .3857 Mdot
.66015 .44086 Mdot
.57365 .59833 Mdot
.45614 .64188 Mdot
.44491 .34173 Mdot
.33292 .51406 Mdot
.35082 .51559 Mdot
.6697 .40376 Mdot
.54842 .35724 Mdot
.28038 .47285 Mdot
.62404 .67882 Mdot
.38468 .50817 Mdot
.5911 .51533 Mdot
.75824 .35166 Mdot
.48499 .229 Mdot
.6397 .60215 Mdot
.38378 .63822 Mdot
.46739 .40527 Mdot
.43982 .37789 Mdot
.44528 .3667 Mdot
.35725 .49482 Mdot
.48382 .4751 Mdot
.29541 .48202 Mdot
.55402 .25108 Mdot
.40275 .63406 Mdot
.50229 .71775 Mdot
.62994 .585 Mdot
.61717 .58597 Mdot
.54921 .63548 Mdot
.61921 .64354 Mdot
.606 .59305 Mdot
.46396 .36286 Mdot
.35765 .48158 Mdot
.34468 .60906 Mdot
.63617 .42092 Mdot
.2608 .34592 Mdot
.30955 .49025 Mdot
.42092 .27141 Mdot
.41623 .64684 Mdot
.61717 .74396 Mdot
.37654 .50062 Mdot
.30827 .48533 Mdot
.54169 .60119 Mdot
.61519 .40802 Mdot
.58092 .50063 Mdot
.61042 .59785 Mdot
.32165 .47439 Mdot
.26403 .47581 Mdot
.69626 .46643 Mdot
.66708 .63562 Mdot
.36975 .64889 Mdot
.4359 .47563 Mdot
.44619 .65415 Mdot
.58558 .53373 Mdot
.65395 .28675 Mdot
.32169 .50149 Mdot
.33276 .48433 Mdot
.38351 .64934 Mdot
.55019 .6888 Mdot
.67064 .39068 Mdot
.39556 .24319 Mdot
.43926 .40104 Mdot
.61128 .60342 Mdot
.35517 .4899 Mdot
.49438 .64288 Mdot
.38077 .54454 Mdot
.45498 .36398 Mdot
.32378 .45153 Mdot
.5493 .58789 Mdot
.56744 .60564 Mdot
.39655 .647 Mdot
.42497 .57674 Mdot
.63574 .56162 Mdot
.18101 .463 Mdot
.58111 .3323 Mdot
.5837 .35136 Mdot
.57497 .57606 Mdot
.66709 .41155 Mdot
.41014 .23884 Mdot
.39827 .62823 Mdot
.54844 .62745 Mdot
.245 .71188 Mdot
.68971 .39498 Mdot
.46578 .37187 Mdot
.4077 .23767 Mdot
.48233 .47698 Mdot
.56591 .5648 Mdot
.57586 .56449 Mdot
.581 .61089 Mdot
.26598 .73658 Mdot
.29225 .4963 Mdot
.63254 .43822 Mdot
.42355 .63597 Mdot
.65602 .4309 Mdot
.30692 .51098 Mdot
.56027 .43329 Mdot
.59199 .62022 Mdot
.62384 .37554 Mdot
.6567 .38592 Mdot
.42442 .38017 Mdot
.42171 .36734 Mdot
.3345 .44809 Mdot
.61294 .57236 Mdot
.41853 .24519 Mdot
.61277 .41445 Mdot
.33528 .4599 Mdot
.39623 .64424 Mdot
.44787 .35392 Mdot
.55875 .60059 Mdot
.32857 .50267 Mdot
.62975 .64371 Mdot
.62925 .4267 Mdot
.30886 .48603 Mdot
.42855 .26112 Mdot
.40437 .66037 Mdot
.55649 .60434 Mdot
.37992 .60111 Mdot
.40007 .23895 Mdot
.62332 .596 Mdot
.67663 .6924 Mdot
.42667 .61205 Mdot
.49897 .22058 Mdot
.2944 .47343 Mdot
.41322 .26183 Mdot
.62026 .42822 Mdot
.55655 .48554 Mdot
.33583 .48498 Mdot
.67835 .66976 Mdot
.44376 .56192 Mdot
.56407 .63603 Mdot
.6537 .41405 Mdot
.36979 .67341 Mdot
.16703 .49622 Mdot
.46745 .68317 Mdot
.5999 .58415 Mdot
.3283 .46393 Mdot
.43416 .65761 Mdot
.44321 .40683 Mdot
.5524 .20999 Mdot
.75635 .35908 Mdot
.32619 .45036 Mdot
.59341 .65087 Mdot
.61301 .41413 Mdot
.45955 .38732 Mdot
.46622 .25528 Mdot
.30549 .45433 Mdot
.28791 .4793 Mdot
.582 .62135 Mdot
.41569 .62936 Mdot
.35134 .70832 Mdot
.29751 .50539 Mdot
.35355 .48079 Mdot
.25216 .35234 Mdot
.37878 .63292 Mdot
.5788 .60086 Mdot
.6314 .34833 Mdot
.54459 .60637 Mdot
.19202 .45912 Mdot
.41732 .26307 Mdot
.63365 .41995 Mdot
.55443 .58455 Mdot
.36063 .59998 Mdot
.33568 .47803 Mdot
.44625 .4722 Mdot
.27744 .45822 Mdot
.46819 .36421 Mdot
.35503 .49242 Mdot
.58073 .56661 Mdot
.42659 .41189 Mdot
.40321 .65833 Mdot
.61774 .57732 Mdot
.60865 .6251 Mdot
.60965 .38943 Mdot
.4745 .38508 Mdot
.6932 .71159 Mdot
.41788 .35862 Mdot
.45262 .40908 Mdot
.61953 .44288 Mdot
.57574 .59536 Mdot
.32109 .4791 Mdot
.28091 .4887 Mdot
.55612 .63518 Mdot
.65959 .29195 Mdot
.67003 .39736 Mdot
.35744 .45978 Mdot
.34627 .80443 Mdot
.64959 .6599 Mdot
.42156 .24577 Mdot
.58077 .71478 Mdot
.42222 .37526 Mdot
.56295 .60582 Mdot
.62655 .39317 Mdot
.34882 .47187 Mdot
.28073 .47433 Mdot
.54387 .62431 Mdot
.46688 .3854 Mdot
.44088 .65062 Mdot
.28709 .47038 Mdot
.37762 .5432 Mdot
.59008 .60788 Mdot
.55686 .24096 Mdot
.29218 .46812 Mdot
.18609 .38958 Mdot
.35319 .60251 Mdot
.6484 .42064 Mdot
.6121 .63175 Mdot
.67992 .40527 Mdot
.4261 .64071 Mdot
.33886 .53038 Mdot
.46975 .38331 Mdot
.65028 .67662 Mdot
.70934 .742 Mdot
.31396 .49678 Mdot
.63422 .396 Mdot
.55767 .61793 Mdot
.63823 .68018 Mdot
.60517 .56625 Mdot
.52378 .52711 Mdot
.40175 .60343 Mdot
.42843 .35927 Mdot
.4308 .39952 Mdot
.6239 .62401 Mdot
.40938 .6208 Mdot
.30099 .51326 Mdot
.33848 .50831 Mdot
.72574 .22867 Mdot
.42835 .26361 Mdot
.49572 .77506 Mdot
.55724 .60861 Mdot
.34172 .46244 Mdot
.73917 .65546 Mdot
.47791 .38793 Mdot
.59642 .65832 Mdot
.36347 .49163 Mdot
.2466 .4131 Mdot
.42251 .48145 Mdot
.59545 .59656 Mdot
.63088 .66776 Mdot
.43679 .40151 Mdot
.40312 .49775 Mdot
.29673 .48099 Mdot
.57279 .65602 Mdot
.41542 .36577 Mdot
.23146 .37415 Mdot
.7515 .7115 Mdot
.64141 .39766 Mdot
.27373 .46609 Mdot
.46728 .36422 Mdot
.65774 .60407 Mdot
.43452 .65319 Mdot
.34747 .47763 Mdot
.32019 .51237 Mdot
.59594 .63635 Mdot
.56588 .54817 Mdot
.64919 .6616 Mdot
.63644 .41099 Mdot
.43872 .38752 Mdot
.63022 .59769 Mdot
.55347 .35644 Mdot
.61259 .64811 Mdot
.44192 .38817 Mdot
.32553 .16681 Mdot
.54636 .58002 Mdot
.60233 .56699 Mdot
.37781 .71002 Mdot
.66623 .37314 Mdot
.6618 .42452 Mdot
.58785 .32188 Mdot
.55713 .60823 Mdot
.33617 .56088 Mdot
.6415 .39372 Mdot
.66796 .40111 Mdot
.28094 .58624 Mdot
.58606 .6357 Mdot
.40054 .47893 Mdot
.44964 .38714 Mdot
.46312 .35963 Mdot
.64121 .43218 Mdot
.65342 .58643 Mdot
.4772 .39704 Mdot
.73182 .37795 Mdot
.30638 .49126 Mdot
.65346 .28615 Mdot
.61956 .41645 Mdot
.41601 .56657 Mdot
.47664 .37643 Mdot
.14417 .48496 Mdot
.51672 .4946 Mdot
.59343 .65478 Mdot
.56392 .61236 Mdot
.41577 .65904 Mdot
.52758 .64229 Mdot
.40705 .27043 Mdot
.44238 .37215 Mdot
.27314 .66796 Mdot
.644 .40598 Mdot
.6068 .57068 Mdot
.62609 .73898 Mdot
.48529 .2632 Mdot
.57926 .22197 Mdot
.66396 .37922 Mdot
.65295 .40983 Mdot
.29772 .49085 Mdot
.31032 .50306 Mdot
.58601 .59662 Mdot
.4374 .36961 Mdot
.64508 .44487 Mdot
.44055 .39555 Mdot
.32129 .50238 Mdot
.31285 .48402 Mdot
.42039 .26716 Mdot
.62722 .65883 Mdot
.34018 .51055 Mdot
.22386 .39203 Mdot
.54971 .36395 Mdot
.60855 .38685 Mdot
.63319 .81007 Mdot
.46236 .25351 Mdot
.39266 .73152 Mdot
.43721 .63186 Mdot
.43275 .26186 Mdot
.45336 .34558 Mdot
.62162 .62904 Mdot
.56018 .58429 Mdot
.4032 .2512 Mdot
.47177 .3598 Mdot
.41535 .65167 Mdot
.47754 .3648 Mdot
.40471 .62936 Mdot
.33179 .52271 Mdot
.61844 .5646 Mdot
.57933 .5594 Mdot
.45795 .36146 Mdot
.30836 .4751 Mdot
.33652 .51291 Mdot
.41843 .61946 Mdot
.60107 .74139 Mdot
.33322 .50446 Mdot
.62035 .41869 Mdot
.8095 .51331 Mdot
.40033 .25533 Mdot
.58595 .56433 Mdot
.62992 .7437 Mdot
.71971 .44615 Mdot
.5722 .64354 Mdot
.40594 .23743 Mdot
.7474 .25597 Mdot
.62427 .578 Mdot
.74542 .27407 Mdot
.41174 .26476 Mdot
.67222 .37531 Mdot
.30971 .46491 Mdot
.40505 .27015 Mdot
.65564 .58383 Mdot
.40506 .67482 Mdot
.55649 .54985 Mdot
.65709 .37345 Mdot
.64427 .36161 Mdot
.6592 .31521 Mdot
.19337 .46078 Mdot
.39188 .62857 Mdot
.40841 .64824 Mdot
.33763 .48876 Mdot
.35663 .22685 Mdot
.61698 .54445 Mdot
.40723 .65028 Mdot
.3086 .69714 Mdot
.61273 .64309 Mdot
.52957 .77272 Mdot
.50011 .52063 Mdot
.66756 .40989 Mdot
.70791 .39884 Mdot
.33681 .48265 Mdot
.63477 .39607 Mdot
.55868 .39162 Mdot
.54872 .63416 Mdot
.64111 .40249 Mdot
.44494 .39068 Mdot
.34449 .39879 Mdot
.67882 .40159 Mdot
.41607 .51106 Mdot
.44959 .3853 Mdot
.43416 .61499 Mdot
.43207 .71246 Mdot
.46735 .87959 Mdot
.44109 .37119 Mdot
.31718 .46882 Mdot
.34139 .51106 Mdot
.34055 .50324 Mdot
.653 .37355 Mdot
.29559 .45902 Mdot
.63141 .41324 Mdot
.22574 .53375 Mdot
.60298 .75546 Mdot
.39895 .64081 Mdot
.44908 .43565 Mdot
.65744 .39635 Mdot
.57185 .28269 Mdot
.6552 .79568 Mdot
.57077 .60795 Mdot
.41649 .36198 Mdot
.38525 .65175 Mdot
.31304 .23662 Mdot
.41798 .65732 Mdot
.31211 .46708 Mdot
.65194 .2846 Mdot
.59425 .57275 Mdot
.69284 .61041 Mdot
.39526 .65517 Mdot
.66046 .37657 Mdot
.62205 .59242 Mdot
.28439 .44607 Mdot
.43436 .64652 Mdot
.44102 .64104 Mdot
.6068 .58936 Mdot
.67605 .39925 Mdot
.31541 .48084 Mdot
.44795 .34723 Mdot
.379 .61653 Mdot
.65053 .62788 Mdot
.56378 .62974 Mdot
.58431 .66287 Mdot
.47512 .4636 Mdot
.36387 .7388 Mdot
.44623 .37763 Mdot
.52337 .699 Mdot
.31886 .50616 Mdot
.45454 .68224 Mdot
.55208 .30616 Mdot
.44314 .4331 Mdot
.41661 .26375 Mdot
.41932 .26225 Mdot
.59939 .5945 Mdot
.35379 .73439 Mdot
.64075 .23565 Mdot
.4055 .40033 Mdot
.39983 .24778 Mdot
.33528 .51293 Mdot
.67821 .4222 Mdot
.64211 .32151 Mdot
.57291 .5486 Mdot
.42516 .36346 Mdot
.32943 .50617 Mdot
.28922 .71676 Mdot
.40565 .63505 Mdot
.60766 .29739 Mdot
.59652 .61852 Mdot
.60218 .57837 Mdot
.45696 .37971 Mdot
.43916 .38048 Mdot
.54775 .22175 Mdot
.60707 .32233 Mdot
.2592 .44625 Mdot
.39316 .40022 Mdot
.31399 .739 Mdot
.68671 .35255 Mdot
.62526 .39232 Mdot
.42467 .26584 Mdot
.45407 .41063 Mdot
.58248 .5624 Mdot
.66934 .37166 Mdot
.58429 .22234 Mdot
.64077 .45493 Mdot
.52721 .76654 Mdot
.35097 .56299 Mdot
.60995 .61433 Mdot
.6148 .41271 Mdot
.63627 .39748 Mdot
.65554 .43406 Mdot
.3987 .24311 Mdot
.57356 .57954 Mdot
.56375 .62563 Mdot
.62649 .59043 Mdot
.55734 .67236 Mdot
.59264 .60603 Mdot
.54853 .31753 Mdot
.52386 .38394 Mdot
.25933 .64607 Mdot
.57618 .64712 Mdot
.4746 .3662 Mdot
.62938 .62659 Mdot
.41567 .62179 Mdot
.59237 .65133 Mdot
.51221 .77435 Mdot
.45253 .36906 Mdot
.5622 .69415 Mdot
.39309 .38122 Mdot
.59743 .61932 Mdot
.43065 .66322 Mdot
.35953 .73155 Mdot
.68488 .73601 Mdot
.24698 .36095 Mdot
.62132 .42098 Mdot
.36873 .47966 Mdot
.47633 .35703 Mdot
.32277 .48036 Mdot
.58217 .65549 Mdot
.42504 .25377 Mdot
.42762 .22209 Mdot
.42006 .55671 Mdot
.56968 .56589 Mdot
.55573 .53229 Mdot
.65473 .42224 Mdot
.33048 .46995 Mdot
.69783 .3833 Mdot
.57772 .61568 Mdot
.42699 .63766 Mdot
.42351 .63084 Mdot
.58437 .34291 Mdot
.23267 .65033 Mdot
.56423 .49166 Mdot
.45446 .37997 Mdot
.27823 .47333 Mdot
.43006 .66652 Mdot
.72144 .33803 Mdot
.44325 .34141 Mdot
.42237 .37481 Mdot
.4689 .39087 Mdot
.61273 .60933 Mdot
.41391 .26954 Mdot
.2804 .68608 Mdot
.39789 .2624 Mdot
.60115 .62065 Mdot
.31178 .50878 Mdot
.40638 .27172 Mdot
.42218 .65776 Mdot
.43766 .4076 Mdot
.31225 .50152 Mdot
.60068 .60212 Mdot
.64604 .39462 Mdot
.60102 .72818 Mdot
.45134 .78659 Mdot
.22827 .56696 Mdot
.23148 .57575 Mdot
.64218 .36843 Mdot
.17509 .55424 Mdot
.48284 .42576 Mdot
.73025 .45341 Mdot
.37923 .6685 Mdot
.55789 .63791 Mdot
.82862 .42884 Mdot
.297 .47827 Mdot
.34621 .48914 Mdot
.59192 .59877 Mdot
.32778 .45924 Mdot
.60654 .56915 Mdot
.29581 .493 Mdot
.2283 .4523 Mdot
.58454 .54961 Mdot
.34474 .48774 Mdot
.60931 .53875 Mdot
.58391 .62652 Mdot
.6604 .4194 Mdot
.34729 .47468 Mdot
.60262 .65424 Mdot
.36615 .20212 Mdot
.4356 .36306 Mdot
.39755 .24662 Mdot
.50812 .40457 Mdot
.47906 .37436 Mdot
.64418 .41604 Mdot
.60071 .55086 Mdot
.39683 .65065 Mdot
.65236 .38834 Mdot
.33092 .44739 Mdot
.39202 .65348 Mdot
.58923 .31531 Mdot
.62502 .42542 Mdot
.40273 .25812 Mdot
.39783 .65524 Mdot
.5296 .57864 Mdot
.35133 .49795 Mdot
.4697 .803 Mdot
.39751 .26007 Mdot
.58297 .56984 Mdot
.32004 .52579 Mdot
.47819 .36861 Mdot
.58768 .58846 Mdot
.32692 .46253 Mdot
.40025 .24017 Mdot
.6174 .61388 Mdot
.62245 .60208 Mdot
.61576 .33377 Mdot
.61756 .24664 Mdot
.39831 .6481 Mdot
.60807 .40787 Mdot
.57905 .604 Mdot
.40484 .61984 Mdot
.34577 .30077 Mdot
.63597 .61741 Mdot
.68258 .3955 Mdot
.6798 .58358 Mdot
.31068 .50442 Mdot
.4577 .40511 Mdot
.2742 .47402 Mdot
.44169 .63936 Mdot
.8592 .58548 Mdot
.41648 .27185 Mdot
.63921 .55352 Mdot
.55851 .64805 Mdot
.269 .49061 Mdot
.63665 .40215 Mdot
.32755 .42213 Mdot
.55699 .60535 Mdot
.54007 .54353 Mdot
.60429 .57479 Mdot
.3519 .60011 Mdot
.67001 .39462 Mdot
.59613 .56629 Mdot
.50659 .62255 Mdot
.62001 .56331 Mdot
.43658 .65785 Mdot
.47934 .70956 Mdot
.63052 .62862 Mdot
.11493 .40359 Mdot
.40605 .23498 Mdot
.344 .50516 Mdot
.32368 .5386 Mdot
.39759 .30914 Mdot
.76012 .35173 Mdot
.63356 .41202 Mdot
.63104 .52119 Mdot
.31878 .48037 Mdot
.7539 .69349 Mdot
.17438 .52419 Mdot
.5882 .62564 Mdot
.54984 .58883 Mdot
.31217 .46706 Mdot
.34089 .46262 Mdot
.42434 .25641 Mdot
.5796 .65035 Mdot
.5892 .5275 Mdot
.30567 .45255 Mdot
.60043 .60891 Mdot
.65501 .50696 Mdot
.43635 .35295 Mdot
.65254 .4302 Mdot
.44382 .40697 Mdot
.42571 .36798 Mdot
.78654 .46315 Mdot
.58215 .33163 Mdot
.44026 .38602 Mdot
.41849 .35287 Mdot
.51699 .77805 Mdot
.68512 .61702 Mdot
.43981 .65787 Mdot
.21042 .58779 Mdot
.33934 .49755 Mdot
.57248 .58161 Mdot
.63448 .3753 Mdot
.75671 .42223 Mdot
.30831 .37904 Mdot
.6372 .27892 Mdot
.56517 .61784 Mdot
.34054 .48745 Mdot
.39627 .24636 Mdot
.58345 .54864 Mdot
.45993 .67852 Mdot
.6007 .5807 Mdot
.3403 .5139 Mdot
.80926 .47186 Mdot
.68884 .60384 Mdot
.39367 .49941 Mdot
.59881 .40783 Mdot
.63129 .59335 Mdot
.62388 .41721 Mdot
.4726 .37082 Mdot
.40295 .62101 Mdot
.40427 .65296 Mdot
.6199 .59158 Mdot
.69622 .33041 Mdot
.49576 .53544 Mdot
.58165 .62578 Mdot
.59237 .63622 Mdot
.41294 .26336 Mdot
.59151 .63564 Mdot
.55883 .64726 Mdot
.62851 .61712 Mdot
.64279 .61744 Mdot
.45282 .40931 Mdot
.6841 .68255 Mdot
.63516 .63304 Mdot
.6649 .63146 Mdot
.43647 .35598 Mdot
.62582 .52732 Mdot
.42633 .38175 Mdot
.20358 .6287 Mdot
.43171 .39099 Mdot
.40201 .64968 Mdot
.32995 .52674 Mdot
.57925 .5126 Mdot
.63948 .44452 Mdot
.41767 .37647 Mdot
.41562 .63756 Mdot
.44315 .36905 Mdot
.2862 .48899 Mdot
.58683 .81655 Mdot
.64296 .45433 Mdot
.41207 .48887 Mdot
.52271 .50615 Mdot
.55604 .23892 Mdot
.30385 .49354 Mdot
.667 .40771 Mdot
.68541 .583 Mdot
.62768 .61537 Mdot
.40719 .66015 Mdot
.60052 .5927 Mdot
.44813 .40964 Mdot
.3415 .49387 Mdot
.25315 .59582 Mdot
.40026 .65172 Mdot
.74338 .73213 Mdot
.32573 .51651 Mdot
.55143 .56895 Mdot
.42438 .36311 Mdot
.63826 .80636 Mdot
.4315 .39286 Mdot
.6107 .75365 Mdot
.6692 .35551 Mdot
.82343 .48673 Mdot
.65733 .40597 Mdot
.58329 .21231 Mdot
.19884 .68407 Mdot
.18667 .51037 Mdot
.64586 .38483 Mdot
.37947 .47726 Mdot
.59602 .61503 Mdot
.62481 .6398 Mdot
.63878 .67191 Mdot
.6038 .40351 Mdot
.58189 .60556 Mdot
.40472 .26701 Mdot
.54307 .37942 Mdot
.33292 .67786 Mdot
.37292 .48741 Mdot
.60149 .56456 Mdot
.43317 .35983 Mdot
.48633 .37899 Mdot
.40286 .2692 Mdot
.44841 .34256 Mdot
.57981 .62927 Mdot
.65798 .39926 Mdot
.43908 .55183 Mdot
.4276 .64706 Mdot
.23841 .31078 Mdot
.38792 .6142 Mdot
.3696 .47667 Mdot
.57127 .66755 Mdot
.31192 .48427 Mdot
.86814 .45071 Mdot
.62197 .63433 Mdot
.63974 .39192 Mdot
.62007 .6036 Mdot
.63106 .60772 Mdot
.62049 .64605 Mdot
.29496 .45728 Mdot
.29469 .5285 Mdot
.60269 .60697 Mdot
.47055 .38353 Mdot
.25165 .61155 Mdot
.54898 .55797 Mdot
.34084 .44496 Mdot
.51198 .75229 Mdot
.55939 .25296 Mdot
.60591 .38868 Mdot
.32361 .46926 Mdot
.64735 .40783 Mdot
.60611 .42739 Mdot
.644 .4161 Mdot
.25633 .66206 Mdot
.53563 .52558 Mdot
.71809 .24 Mdot
.80098 .56763 Mdot
.75034 .44187 Mdot
.62549 .37552 Mdot
.34972 .3344 Mdot
.62972 .38858 Mdot
.63735 .41476 Mdot
.48915 .11343 Mdot
.63532 .38018 Mdot
.56323 .5746 Mdot
.54412 .58279 Mdot
.51216 .29699 Mdot
.54095 .78248 Mdot
.58686 .65036 Mdot
.58344 .60168 Mdot
.3966 .6249 Mdot
.53756 .67139 Mdot
.4114 .28008 Mdot
.63068 .29788 Mdot
.43658 .26364 Mdot
.60637 .59034 Mdot
.58775 .60229 Mdot
.65244 .60533 Mdot
.20479 .69948 Mdot
.75742 .40349 Mdot
.64976 .36232 Mdot
.56846 .52316 Mdot
.19408 .41086 Mdot
.54916 .57804 Mdot
.5857 .55712 Mdot
.61519 .62122 Mdot
.32014 .47944 Mdot
.68392 .41366 Mdot
.5476 .54018 Mdot
.53609 .25909 Mdot
.59052 .61833 Mdot
.47959 .4253 Mdot
.38368 .61078 Mdot
.57767 .56719 Mdot
.65878 .43004 Mdot
.6 .64783 Mdot
.61681 .41323 Mdot
.64612 .43168 Mdot
.64176 .64372 Mdot
.26701 .67814 Mdot
.67488 .41906 Mdot
.60658 .62142 Mdot
.31323 .47376 Mdot
.17052 .49469 Mdot
.58009 .56973 Mdot
.4022 .62598 Mdot
.56094 .61067 Mdot
.43508 .65826 Mdot
.59814 .62944 Mdot
.39634 .25862 Mdot
.69294 .50202 Mdot
.33389 .4862 Mdot
.3621 .64523 Mdot
.32693 .45638 Mdot
.58702 .36507 Mdot
.67778 .37943 Mdot
.41465 .28254 Mdot
.74423 .31153 Mdot
.41166 .26292 Mdot
.60224 .72671 Mdot
.29995 .3477 Mdot
.44202 .35915 Mdot
.63828 .43741 Mdot
.52869 .69399 Mdot
.35789 .45276 Mdot
.32561 .44806 Mdot
.35886 .47483 Mdot
.8655 .52873 Mdot
.79638 .36025 Mdot
.60783 .60349 Mdot
.46934 .81526 Mdot
.72912 .56381 Mdot
.63749 .58395 Mdot
.62029 .55623 Mdot
.34072 .51488 Mdot
.62888 .58413 Mdot
.47075 .48453 Mdot
.3205 .49679 Mdot
.41313 .64247 Mdot
.6317 .41899 Mdot
.43741 .65137 Mdot
.2886 .43481 Mdot
.5302 .39033 Mdot
.31846 .50412 Mdot
.64018 .61499 Mdot
.61522 .59791 Mdot
.62117 .42624 Mdot
.58812 .41429 Mdot
.65395 .42802 Mdot
.38777 .65208 Mdot
.32881 .49479 Mdot
.74911 .40174 Mdot
.56314 .60155 Mdot
.6586 .38611 Mdot
.46179 .32121 Mdot
.56686 .60603 Mdot
.46206 .36349 Mdot
.56481 .62116 Mdot
.6474 .38016 Mdot
.59171 .63514 Mdot
.6568 .4018 Mdot
.30061 .47801 Mdot
.54745 .58655 Mdot
.58857 .59885 Mdot
.70615 .72015 Mdot
.41668 .65158 Mdot
.67613 .37763 Mdot
.50265 .47703 Mdot
.54428 .59767 Mdot
.45481 .67767 Mdot
.62039 .56804 Mdot
.6532 .54231 Mdot
.60933 .53756 Mdot
.40494 .26587 Mdot
.61299 .65593 Mdot
.58262 .56902 Mdot
.69158 .66716 Mdot
.76101 .62254 Mdot
.69671 .40997 Mdot
.4225 .40209 Mdot
.65839 .42992 Mdot
.35169 .50483 Mdot
.35585 .48019 Mdot
.29074 .46408 Mdot
.57077 .7782 Mdot
.65496 .59542 Mdot
.59235 .57277 Mdot
.41924 .36838 Mdot
.40648 .64612 Mdot
.66033 .37928 Mdot
.40279 .64176 Mdot
.63634 .29795 Mdot
.39189 .65641 Mdot
.40927 .27133 Mdot
.35351 .60295 Mdot
.71541 .43092 Mdot
.39302 .6301 Mdot
.65412 .42835 Mdot
.36681 .56298 Mdot
.56368 .64362 Mdot
.23005 .40932 Mdot
.42615 .6364 Mdot
.8472 .59412 Mdot
.61486 .56455 Mdot
.4404 .49198 Mdot
.42927 .37104 Mdot
.42865 .66011 Mdot
.47603 .38349 Mdot
.61287 .64546 Mdot
.50166 .21823 Mdot
.63384 .39256 Mdot
.42354 .40966 Mdot
.61663 .65283 Mdot
.43554 .65374 Mdot
.3288 .50953 Mdot
.54999 .47123 Mdot
.46961 .3631 Mdot
.66745 .73824 Mdot
.46723 .68308 Mdot
.32685 .49498 Mdot
.65222 .22214 Mdot
.45955 .39912 Mdot
.6407 .60053 Mdot
.60288 .49912 Mdot
.58169 .64375 Mdot
.3568 .50117 Mdot
.33478 .47193 Mdot
.52203 .33531 Mdot
.61838 .60256 Mdot
.61641 .56544 Mdot
.69134 .40112 Mdot
.31323 .49444 Mdot
.65786 .41416 Mdot
.63774 .44008 Mdot
.3128 .46919 Mdot
.65022 .41986 Mdot
.39735 .65734 Mdot
.54023 .38491 Mdot
.45638 .4001 Mdot
.46878 .37766 Mdot
.33685 .51122 Mdot
.29349 .5027 Mdot
.31082 .48595 Mdot
.56607 .62154 Mdot
.67096 .38368 Mdot
.60803 .63694 Mdot
.6319 .62769 Mdot
.6621 .35159 Mdot
.65246 .36965 Mdot
.61148 .63968 Mdot
.37883 .56746 Mdot
.37296 .62969 Mdot
.34337 .48585 Mdot
.43984 .39352 Mdot
.75598 .68387 Mdot
.42229 .36326 Mdot
.60852 .5649 Mdot
.24246 .4146 Mdot
.65855 .37497 Mdot
.418 .65801 Mdot
.45943 .64152 Mdot
.40849 .65865 Mdot
.42674 .41418 Mdot
.64966 .44017 Mdot
.58606 .31804 Mdot
.60928 .56733 Mdot
.47764 .46281 Mdot
.5297 .69963 Mdot
.5518 .29465 Mdot
.44176 .38909 Mdot
.57407 .60456 Mdot
.40985 .26262 Mdot
.69837 .46255 Mdot
.5971 .58093 Mdot
.59474 .6578 Mdot
.32259 .58265 Mdot
.66332 .63807 Mdot
.61191 .38413 Mdot
.65144 .31511 Mdot
.54736 .61988 Mdot
.69202 .3493 Mdot
.62495 .1496 Mdot
.61824 .56996 Mdot
.5846 .61165 Mdot
.56554 .58155 Mdot
.61987 .63068 Mdot
.65258 .35389 Mdot
.39883 .5759 Mdot
.42269 .36713 Mdot
.50689 .4332 Mdot
.45735 .39672 Mdot
.3505 .49205 Mdot
.44468 .49429 Mdot
.64235 .43615 Mdot
.41148 .65956 Mdot
.55395 .82012 Mdot
.65567 .30358 Mdot
.29817 .49073 Mdot
.77176 .40952 Mdot
.42918 .64374 Mdot
.55782 .63705 Mdot
.39489 .61597 Mdot
.34558 .465 Mdot
.46094 .38815 Mdot
.54283 .59076 Mdot
.62797 .3794 Mdot
.67904 .40228 Mdot
.57358 .60742 Mdot
.18467 .44779 Mdot
.47823 .37583 Mdot
.50264 .35209 Mdot
.61199 .61115 Mdot
.59267 .65793 Mdot
.64304 .42756 Mdot
.33453 .47509 Mdot
.30685 .31228 Mdot
.41849 .64491 Mdot
.64702 .61412 Mdot
.60753 .64744 Mdot
.63029 .3039 Mdot
.43276 .40634 Mdot
.41351 .24388 Mdot
.61481 .6088 Mdot
.58713 .32782 Mdot
.61597 .60983 Mdot
.51964 .62988 Mdot
.31023 .47967 Mdot
.53819 .61631 Mdot
.55027 .60281 Mdot
.54032 .69171 Mdot
.46579 .39717 Mdot
.63903 .39806 Mdot
.688 .37468 Mdot
.41322 .23964 Mdot
.4568 .36244 Mdot
.60842 .64345 Mdot
.45488 .40693 Mdot
.62244 .64406 Mdot
.59974 .6057 Mdot
.44255 .38948 Mdot
.65726 .41495 Mdot
.33694 .41886 Mdot
.67242 .68417 Mdot
.62149 .61883 Mdot
.56118 .62865 Mdot
.55403 .77957 Mdot
.71622 .28112 Mdot
.55297 .60369 Mdot
.66419 .37391 Mdot
.5695 .60275 Mdot
.46848 .37037 Mdot
.39085 .65712 Mdot
.64419 .39006 Mdot
.30473 .51328 Mdot
.30033 .47554 Mdot
.39568 .36954 Mdot
.41311 .27208 Mdot
.55516 .6231 Mdot
.66073 .45447 Mdot
.64505 .37032 Mdot
.38132 .21103 Mdot
.3462 .50366 Mdot
.42405 .66737 Mdot
.6237 .60623 Mdot
.54246 .47609 Mdot
.41987 .37714 Mdot
.11421 .40614 Mdot
.57384 .32545 Mdot
.43391 .62248 Mdot
.66623 .2789 Mdot
.40624 .2581 Mdot
.56512 .56767 Mdot
.41404 .62055 Mdot
.29241 .47377 Mdot
.62292 .64042 Mdot
.65331 .64251 Mdot
.38553 .43538 Mdot
.36966 .50342 Mdot
.45869 .40533 Mdot
.28898 .48724 Mdot
.4374 .62843 Mdot
.40827 .271 Mdot
.67149 .40971 Mdot
.59073 .5681 Mdot
.55044 .52685 Mdot
.34426 .50107 Mdot
.39466 .25388 Mdot
.61012 .61499 Mdot
.67676 .40932 Mdot
.31696 .45933 Mdot
.60859 .5875 Mdot
.73229 .44269 Mdot
.60137 .37946 Mdot
.33506 .49888 Mdot
.56439 .65405 Mdot
.64447 .51709 Mdot
.31855 .51804 Mdot
.33439 .51565 Mdot
.58237 .60523 Mdot
.39874 .65702 Mdot
.55713 .57193 Mdot
.42786 .37768 Mdot
.29435 .5284 Mdot
.4639 .3689 Mdot
.50282 .68371 Mdot
.5855 .66904 Mdot
.57253 .23294 Mdot
.61356 .41786 Mdot
.44122 .66772 Mdot
.71561 .65045 Mdot
.57517 .65485 Mdot
.19578 .59527 Mdot
.41448 .56501 Mdot
.27594 .2716 Mdot
.30601 .76006 Mdot
.41441 .63164 Mdot
.44496 .36648 Mdot
.58383 .61144 Mdot
.45864 .33479 Mdot
.39408 .63235 Mdot
.51647 .69301 Mdot
.56352 .65278 Mdot
.66879 .39794 Mdot
.59607 .61693 Mdot
.62041 .41936 Mdot
.56482 .60658 Mdot
.64756 .55978 Mdot
.36936 .65242 Mdot
.61414 .75221 Mdot
.56221 .64121 Mdot
.57687 .82286 Mdot
.53066 .47282 Mdot
.42444 .63758 Mdot
.60971 .62872 Mdot
.40874 .24652 Mdot
.47589 .36147 Mdot
.38731 .75889 Mdot
.31594 .48193 Mdot
.43562 .38033 Mdot
.6377 .42457 Mdot
.28028 .49068 Mdot
.40591 .2362 Mdot
.56682 .51322 Mdot
.43958 .64498 Mdot
.4413 .36099 Mdot
.5809 .56818 Mdot
.60656 .56289 Mdot
.3631 .59801 Mdot
.52334 .16718 Mdot
.67025 .43421 Mdot
.72616 .73577 Mdot
.62039 .37557 Mdot
.41109 .65124 Mdot
.30958 .48164 Mdot
.55531 .58326 Mdot
.59463 .58699 Mdot
.35648 .48838 Mdot
.66679 .37258 Mdot
.36712 .52238 Mdot
.78468 .44402 Mdot
.28587 .45433 Mdot
.54848 .74149 Mdot
.64162 .38637 Mdot
.55646 .74149 Mdot
.44165 .63234 Mdot
.26669 .68862 Mdot
.44148 .75102 Mdot
.42921 .36633 Mdot
.54018 .74053 Mdot
.65638 .3773 Mdot
.61053 .59985 Mdot
.4022 .25544 Mdot
.42005 .26594 Mdot
.62891 .42177 Mdot
.31536 .46603 Mdot
.43359 .65427 Mdot
.58842 .61067 Mdot
.58515 .28281 Mdot
.47287 .27191 Mdot
.27782 .47216 Mdot
.50754 .61263 Mdot
.47404 .38416 Mdot
.56152 .61795 Mdot
.40819 .62466 Mdot
.44204 .37718 Mdot
.42831 .25202 Mdot
.54214 .38294 Mdot
.62467 .60344 Mdot
.58737 .34273 Mdot
.45 .36121 Mdot
.66321 .22444 Mdot
.59006 .59497 Mdot
.46002 .39901 Mdot
.6708 .6002 Mdot
.50088 .23003 Mdot
.47542 .52722 Mdot
.18242 .52887 Mdot
.36886 .49472 Mdot
.30172 .47216 Mdot
.44832 .19352 Mdot
.37967 .66803 Mdot
.4382 .3569 Mdot
.40617 .2702 Mdot
.45586 .72283 Mdot
.47448 .38763 Mdot
.58523 .55617 Mdot
.62019 .56828 Mdot
.78052 .45591 Mdot
.48339 .48661 Mdot
.39333 .24834 Mdot
.60524 .48208 Mdot
.58136 .63653 Mdot
.53327 .59142 Mdot
.58327 .59052 Mdot
.64496 .36165 Mdot
.48133 .37726 Mdot
.585 .8371 Mdot
.4809 .38391 Mdot
.59381 .28574 Mdot
.33959 .4972 Mdot
.27695 .4679 Mdot
.58088 .56614 Mdot
.609 .22596 Mdot
.371 .75314 Mdot
.55848 .6226 Mdot
.44626 .62248 Mdot
.47682 .68311 Mdot
.54364 .5622 Mdot
.69089 .37517 Mdot
.5308 .55349 Mdot
.63641 .35601 Mdot
.44282 .38158 Mdot
.41096 .62999 Mdot
.37379 .63946 Mdot
.43828 .36592 Mdot
.58986 .57395 Mdot
.45279 .62177 Mdot
.60265 .57636 Mdot
.6119 .60446 Mdot
.62419 .29409 Mdot
.41467 .67039 Mdot
.30873 .48781 Mdot
.40321 .65294 Mdot
.63765 .41315 Mdot
.4059 .11915 Mdot
.40036 .63604 Mdot
.59021 .44704 Mdot
.39825 .53326 Mdot
.54456 .73976 Mdot
.6767 .40672 Mdot
.38648 .63604 Mdot
.47089 .39801 Mdot
.27095 .27331 Mdot
.68991 .2544 Mdot
.42651 .35346 Mdot
.59442 .59181 Mdot
.63549 .43587 Mdot
.64029 .36749 Mdot
.4183 .35585 Mdot
.66963 .40736 Mdot
.54361 .64516 Mdot
.61917 .60848 Mdot
.4383 .35695 Mdot
.5016 .29646 Mdot
.48215 .37576 Mdot
.56815 .45433 Mdot
.61101 .62266 Mdot
.64206 .3911 Mdot
.53745 .64548 Mdot
.68533 .41917 Mdot
.42372 .26433 Mdot
.61687 .6483 Mdot
.41924 .66115 Mdot
.48154 .47562 Mdot
.33585 .49711 Mdot
.24599 .41587 Mdot
.62802 .42995 Mdot
.48944 .34552 Mdot
.66003 .42017 Mdot
.61377 .42491 Mdot
.44471 .34225 Mdot
.63291 .40422 Mdot
.58577 .61173 Mdot
.39479 .50787 Mdot
.61913 .40515 Mdot
.45706 .37611 Mdot
.43036 .65517 Mdot
.65311 .41811 Mdot
.27794 .49119 Mdot
.61368 .59327 Mdot
.30699 .50131 Mdot
.45341 .64634 Mdot
.64288 .43688 Mdot
.38605 .63979 Mdot
.34581 .50168 Mdot
.4384 .63869 Mdot
.23651 .57025 Mdot
.46586 .40731 Mdot
.62881 .2776 Mdot
.68742 .65241 Mdot
.62733 .38118 Mdot
.32599 .44776 Mdot
.55249 .59387 Mdot
.61804 .59536 Mdot
.42732 .62239 Mdot
.63963 .36855 Mdot
.17493 .48731 Mdot
.63865 .52045 Mdot
.51962 .34699 Mdot
.44507 .41187 Mdot
.75757 .70116 Mdot
.54923 .35567 Mdot
.25764 .30599 Mdot
.59752 .53936 Mdot
.40564 .25764 Mdot
.60351 .57275 Mdot
.68741 .73537 Mdot
.39415 .66052 Mdot
.33674 .36941 Mdot
.61676 .54454 Mdot
.31849 .48869 Mdot
.56747 .5965 Mdot
.46321 .81068 Mdot
.52544 .56497 Mdot
.39409 .62625 Mdot
.44132 .41943 Mdot
.64059 .44462 Mdot
.42787 .6458 Mdot
.2976 .48106 Mdot
.48765 .72765 Mdot
.55643 .64709 Mdot
.57717 .63132 Mdot
.33255 .45149 Mdot
.66932 .40118 Mdot
.35139 .49456 Mdot
.45675 .39982 Mdot
.4032 .63765 Mdot
.62233 .62454 Mdot
.53294 .61081 Mdot
.26343 .47212 Mdot
.48375 .38362 Mdot
.2838 .49131 Mdot
.4364 .40614 Mdot
.40489 .25795 Mdot
.55706 .63138 Mdot
.32907 .45181 Mdot
.6288 .57343 Mdot
.71678 .67599 Mdot
.63742 .29007 Mdot
.75792 .6056 Mdot
.30764 .4894 Mdot
.53013 .75589 Mdot
.45324 .36661 Mdot
.43078 .39794 Mdot
.82082 .54465 Mdot
.3565 .73238 Mdot
.33964 .56115 Mdot
.57434 .8136 Mdot
.45542 .40007 Mdot
.46119 .36978 Mdot
.29336 .4703 Mdot
.62993 .40934 Mdot
.61913 .35887 Mdot
.27561 .46371 Mdot
.62792 .74305 Mdot
.66016 .37939 Mdot
.18868 .57764 Mdot
.33461 .51987 Mdot
.61918 .54458 Mdot
.39504 .26568 Mdot
.41648 .62879 Mdot
.63065 .73949 Mdot
.53382 .81259 Mdot
.5651 .56991 Mdot
.77458 .35702 Mdot
.32655 .47384 Mdot
.4042 .46504 Mdot
.22103 .64566 Mdot
.58563 .66 Mdot
.56951 .58815 Mdot
.58506 .57837 Mdot
.39926 .66813 Mdot
.71236 .66137 Mdot
.56751 .56765 Mdot
.59411 .75495 Mdot
.57831 .55507 Mdot
.43517 .7838 Mdot
.40252 .65189 Mdot
.52832 .52653 Mdot
.36597 .48032 Mdot
.54674 .26945 Mdot
.6413 .6714 Mdot
.45445 .40355 Mdot
.36107 .44662 Mdot
.45737 .39053 Mdot
.32405 .72983 Mdot
.44287 .74922 Mdot
.63758 .36361 Mdot
.56537 .6182 Mdot
.3629 .48255 Mdot
.62731 .43127 Mdot
.30141 .33718 Mdot
.47822 .10906 Mdot
.47663 .39666 Mdot
.81005 .34597 Mdot
.42987 .39743 Mdot
.42287 .26271 Mdot
.63643 .42709 Mdot
.71833 .36968 Mdot
.47681 .46447 Mdot
.65416 .41562 Mdot
.39457 .35606 Mdot
.68839 .36911 Mdot
.53385 .74838 Mdot
.6213 .43928 Mdot
.45337 .37348 Mdot
.46767 .41417 Mdot
.66279 .60599 Mdot
.55368 .6001 Mdot
.51639 .41786 Mdot
.67608 .61775 Mdot
.55687 .60977 Mdot
.32046 .49664 Mdot
.66552 .25214 Mdot
.28898 .5137 Mdot
.62432 .39688 Mdot
.42283 .39856 Mdot
.5687 .59022 Mdot
.61998 .62068 Mdot
.63793 .59626 Mdot
.70532 .72582 Mdot
.18971 .57457 Mdot
.60307 .60523 Mdot
.63857 .64603 Mdot
.30003 .48223 Mdot
.38348 .59827 Mdot
.63262 .78471 Mdot
.45518 .73128 Mdot
.61919 .58388 Mdot
.41451 .65445 Mdot
.39572 .66406 Mdot
.53746 .59414 Mdot
.57637 .25747 Mdot
.38604 .48912 Mdot
.58038 .56839 Mdot
.4315 .75814 Mdot
.28586 .50581 Mdot
.39725 .26282 Mdot
.34386 .50184 Mdot
.65242 .43493 Mdot
.41593 .26498 Mdot
.31251 .45688 Mdot
.72093 .38496 Mdot
.41564 .24244 Mdot
.50584 .24066 Mdot
.38765 .65195 Mdot
.58767 .58798 Mdot
.69635 .39305 Mdot
.35764 .49343 Mdot
.4393 .36218 Mdot
.65223 .39835 Mdot
.48799 .3835 Mdot
.37556 .60071 Mdot
.56593 .72178 Mdot
.41563 .27168 Mdot
.44499 .40423 Mdot
.54347 .38554 Mdot
.41159 .65525 Mdot
.43954 .34442 Mdot
.59549 .22146 Mdot
.5564 .55232 Mdot
.35828 .76563 Mdot
.57245 .62531 Mdot
.1939 .39852 Mdot
.42875 .39416 Mdot
.4275 .25737 Mdot
.59533 .57028 Mdot
.32481 .51695 Mdot
.65465 .56447 Mdot
.60376 .58026 Mdot
.2934 .4992 Mdot
.60802 .60253 Mdot
.40915 .62381 Mdot
.62017 .36306 Mdot
.42214 .56382 Mdot
.80862 .63144 Mdot
.43583 .63638 Mdot
.38832 .22586 Mdot
.55524 .60904 Mdot
.27345 .62278 Mdot
.65666 .41262 Mdot
.5934 .65885 Mdot
.81599 .45536 Mdot
.625 .41074 Mdot
.64946 .4088 Mdot
.59713 .63745 Mdot
.43327 .35214 Mdot
.33165 .51235 Mdot
.4106 .65618 Mdot
.32134 .25375 Mdot
.60888 .58412 Mdot
.57808 .6009 Mdot
.42926 .64457 Mdot
.46242 .36909 Mdot
.61906 .62802 Mdot
.28248 .36745 Mdot
.34321 .22118 Mdot
.42532 .36806 Mdot
.55035 .55573 Mdot
.40429 .81306 Mdot
.59854 .42565 Mdot
.75995 .30368 Mdot
.37368 .66956 Mdot
.31727 .47022 Mdot
.62009 .53916 Mdot
.13496 .3695 Mdot
.41693 .62986 Mdot
.55696 .2896 Mdot
.60353 .60999 Mdot
.56054 .59428 Mdot
.67826 .39119 Mdot
.60619 .6416 Mdot
.64249 .37883 Mdot
.81967 .61948 Mdot
.71067 .78355 Mdot
.65743 .42063 Mdot
.62772 .38729 Mdot
.70411 .41898 Mdot
.67652 .73359 Mdot
.63418 .42126 Mdot
.56979 .65859 Mdot
.22374 .58375 Mdot
.6331 .65979 Mdot
.44564 .63905 Mdot
.45866 .65174 Mdot
.67552 .34169 Mdot
.59761 .1937 Mdot
.60718 .51688 Mdot
.60989 .69801 Mdot
.49908 .53636 Mdot
.43282 .38987 Mdot
.62774 .59517 Mdot
.41233 .2726 Mdot
.28709 .4644 Mdot
.51129 .59995 Mdot
.5902 .58447 Mdot
.61746 .41292 Mdot
.40317 .67018 Mdot
.47406 .35642 Mdot
.58446 .60135 Mdot
.3612 .51998 Mdot
.41556 .64358 Mdot
.62054 .39957 Mdot
.57978 .41018 Mdot
.44329 .65365 Mdot
.53339 .63032 Mdot
.55813 .60568 Mdot
.61098 .61474 Mdot
.65005 .66612 Mdot
.43555 .36662 Mdot
.2689 .47261 Mdot
.5617 .65777 Mdot
.62103 .30246 Mdot
.4276 .48653 Mdot
.53924 .62533 Mdot
.66987 .3797 Mdot
.42155 .36758 Mdot
.41816 .24784 Mdot
.50136 .71718 Mdot
.6238 .59585 Mdot
.19308 .57957 Mdot
.76716 .41884 Mdot
.41624 .25957 Mdot
.60983 .39991 Mdot
.41377 .6589 Mdot
.58419 .63333 Mdot
.24357 .62072 Mdot
.61348 .5652 Mdot
.68248 .59923 Mdot
.32179 .47172 Mdot
.43756 .39531 Mdot
.32706 .22746 Mdot
.28616 .46508 Mdot
.64799 .4082 Mdot
.15469 .49494 Mdot
.68679 .39104 Mdot
.65513 .4421 Mdot
.28282 .6923 Mdot
.44252 .3845 Mdot
.12536 .38791 Mdot
.70802 .26899 Mdot
.6064 .55833 Mdot
.47313 .37315 Mdot
.63586 .42876 Mdot
.56776 .62025 Mdot
.63855 .37409 Mdot
.67386 .42559 Mdot
.62925 .62523 Mdot
.55759 .59818 Mdot
.61249 .74685 Mdot
.18581 .60376 Mdot
.40204 .6565 Mdot
.67205 .37533 Mdot
.76058 .45539 Mdot
.56422 .56946 Mdot
.60872 .56707 Mdot
.38097 .44633 Mdot
.39382 .62692 Mdot
.66786 .5223 Mdot
.61415 .60721 Mdot
.82358 .46535 Mdot
.55716 .62587 Mdot
.69317 .41121 Mdot
.42905 .35576 Mdot
.57375 .26282 Mdot
.35446 .5045 Mdot
.68168 .40241 Mdot
.43324 .6591 Mdot
.67862 .36753 Mdot
.82137 .49762 Mdot
.44703 .38694 Mdot
.64744 .38012 Mdot
.30458 .51726 Mdot
.45852 .3846 Mdot
.42604 .37011 Mdot
.25 .60983 Mdot
.27885 .48314 Mdot
.38118 .63937 Mdot
.46323 .39055 Mdot
.73182 .4549 Mdot
.45011 .37495 Mdot
.7706 .45822 Mdot
.54709 .60234 Mdot
.59235 .75009 Mdot
.55148 .34345 Mdot
.63653 .67002 Mdot
.48168 .37354 Mdot
.39281 .64074 Mdot
.59241 .64572 Mdot
.67169 .40308 Mdot
.40148 .6336 Mdot
.40547 .40716 Mdot
.30056 .51216 Mdot
.61215 .4084 Mdot
.42542 .36187 Mdot
.6471 .37746 Mdot
.54632 .71345 Mdot
.24582 .47362 Mdot
.50139 .54027 Mdot
.46167 .46986 Mdot
.64022 .59391 Mdot
.688 .34359 Mdot
.54388 .60438 Mdot
.59393 .58203 Mdot
.33568 .49932 Mdot
.57135 .77726 Mdot
.65618 .4169 Mdot
.34022 .21408 Mdot
.4382 .40263 Mdot
.66574 .31894 Mdot
.63682 .5103 Mdot
.61447 .64771 Mdot
.61994 .40697 Mdot
.67525 .4257 Mdot
.76194 .62109 Mdot
.3552 .48625 Mdot
.63074 .66838 Mdot
.57689 .66999 Mdot
.65011 .56756 Mdot
.42737 .39398 Mdot
.29315 .38024 Mdot
.33409 .46749 Mdot
.75347 .25885 Mdot
.34207 .48336 Mdot
.2973 .59086 Mdot
.63224 .40357 Mdot
.40167 .66298 Mdot
.60633 .56576 Mdot
.66075 .69534 Mdot
.65566 .35532 Mdot
.39332 .47636 Mdot
.42043 .65887 Mdot
.31989 .39988 Mdot
.43873 .38283 Mdot
.54811 .62936 Mdot
.63169 .611 Mdot
.6073 .63412 Mdot
.58254 .62277 Mdot
.42452 .40401 Mdot
.58593 .55628 Mdot
.43806 .41319 Mdot
.72661 .43917 Mdot
.82806 .47984 Mdot
.36049 .50315 Mdot
.37988 .74719 Mdot
.62387 .38291 Mdot
.74439 .47184 Mdot
.65323 .50004 Mdot
.6344 .28873 Mdot
.24598 .59012 Mdot
.54866 .61513 Mdot
.31303 .46469 Mdot
.46517 .81356 Mdot
.36198 .48184 Mdot
.77535 .74929 Mdot
.47757 .64429 Mdot
.1757 .52962 Mdot
.57012 .61996 Mdot
.26524 .47346 Mdot
.64722 .50954 Mdot
.54017 .57929 Mdot
.46444 .62862 Mdot
.58317 .4471 Mdot
.5195 .29289 Mdot
.42913 .666 Mdot
.61272 .59108 Mdot
.64034 .44561 Mdot
.58636 .61271 Mdot
.60835 .56956 Mdot
.55851 .61653 Mdot
.47241 .35004 Mdot
.58687 .54585 Mdot
.56085 .56857 Mdot
.53517 .16476 Mdot
.52863 .77003 Mdot
.30131 .49972 Mdot
.77881 .5891 Mdot
.40664 .64574 Mdot
.61975 .42147 Mdot
.4066 .55745 Mdot
.4304 .37605 Mdot
.75497 .63297 Mdot
.57076 .62243 Mdot
.54008 .33939 Mdot
.42558 .36051 Mdot
.4047 .63064 Mdot
.40906 .23804 Mdot
.20106 .53857 Mdot
.36107 .4983 Mdot
.42069 .24695 Mdot
.33595 .49544 Mdot
.71062 .61281 Mdot
.61804 .41252 Mdot
.63819 .60386 Mdot
.47017 .38918 Mdot
.32625 .51413 Mdot
.547 .78679 Mdot
.57937 .58869 Mdot
.30746 .49169 Mdot
.64032 .59859 Mdot
.41276 .49671 Mdot
.38677 .54025 Mdot
.33344 .45699 Mdot
.46418 .41694 Mdot
.46365 .38208 Mdot
.3967 .65749 Mdot
.618 .41993 Mdot
.66301 .37513 Mdot
.44491 .37971 Mdot
.77903 .32672 Mdot
.60768 .57945 Mdot
.55715 .61389 Mdot
.60922 .30704 Mdot
.57471 .61418 Mdot
.50341 .74103 Mdot
.41131 .27777 Mdot
.61476 .40426 Mdot
.57942 .61922 Mdot
.62013 .62621 Mdot
.62432 .60578 Mdot
.54997 .71752 Mdot
.3449 .49742 Mdot
.58201 .63629 Mdot
.42099 .62113 Mdot
.54978 .21942 Mdot
.55125 .59002 Mdot
.53545 .59001 Mdot
.6506 .3793 Mdot
.76449 .70099 Mdot
.42823 .37115 Mdot
.31213 .49771 Mdot
.32749 .51959 Mdot
.41868 .68888 Mdot
.60436 .38873 Mdot
.40794 .27907 Mdot
.38389 .29688 Mdot
.39827 .25705 Mdot
.425 .64166 Mdot
.30479 .56632 Mdot
.36721 .51586 Mdot
.29506 .48945 Mdot
.45883 .41112 Mdot
.58312 .62074 Mdot
.55674 .62211 Mdot
.56004 .28882 Mdot
.58083 .64836 Mdot
.4252 .65767 Mdot
.44562 .35261 Mdot
.65259 .38096 Mdot
.42009 .62898 Mdot
.44712 .40659 Mdot
.67056 .39856 Mdot
.55143 .55905 Mdot
.56287 .54733 Mdot
.65263 .40301 Mdot
.64338 .43325 Mdot
.56572 .57432 Mdot
.49629 .17234 Mdot
.62277 .43735 Mdot
.64453 .3829 Mdot
.39827 .23239 Mdot
.3619 .49679 Mdot
.52471 .62445 Mdot
.47431 .37386 Mdot
.6111 .6134 Mdot
.36409 .49606 Mdot
.39043 .63199 Mdot
.66244 .40061 Mdot
.62107 .6156 Mdot
.60515 .59782 Mdot
.41526 .65517 Mdot
.43278 .66699 Mdot
.43521 .64474 Mdot
.48734 .35657 Mdot
.59807 .62389 Mdot
.63759 .422 Mdot
.44241 .38673 Mdot
.39612 .66425 Mdot
.38669 .62103 Mdot
.56986 .17233 Mdot
.57004 .56714 Mdot
.47969 .53046 Mdot
.35543 .15174 Mdot
.47903 .72921 Mdot
.42292 .25502 Mdot
.30715 .4514 Mdot
.57392 .75012 Mdot
.36596 .67717 Mdot
.47351 .36872 Mdot
.38018 .71824 Mdot
.44278 .66626 Mdot
.63066 .62841 Mdot
.56356 .63077 Mdot
.6475 .59694 Mdot
.4112 .64061 Mdot
.53553 .71028 Mdot
.6466 .36647 Mdot
.72143 .53147 Mdot
.40664 .64552 Mdot
.33283 .457 Mdot
.32833 .45252 Mdot
.34174 .48215 Mdot
.54931 .62444 Mdot
.75497 .62223 Mdot
.74482 .45181 Mdot
.69107 .54994 Mdot
.43596 .37961 Mdot
.68064 .41957 Mdot
.25457 .59614 Mdot
.6509 .40918 Mdot
.29461 .46079 Mdot
.41457 .63877 Mdot
.67641 .38166 Mdot
.45639 .35961 Mdot
.46518 .37165 Mdot
.30525 .5145 Mdot
.34022 .50618 Mdot
.3223 .5068 Mdot
.65977 .43187 Mdot
.6327 .40431 Mdot
.62536 .61622 Mdot
.65998 .39414 Mdot
.7549 .3398 Mdot
.43344 .6206 Mdot
.33943 .45563 Mdot
.4532 .36319 Mdot
.62435 .42445 Mdot
.58911 .58969 Mdot
.34446 .58366 Mdot
.3921 .40945 Mdot
.42912 .62905 Mdot
.26205 .51601 Mdot
.8288 .67698 Mdot
.63316 .59877 Mdot
.44328 .40913 Mdot
.57456 .24717 Mdot
.5796 .5816 Mdot
.31845 .47828 Mdot
.69725 .71878 Mdot
.39578 .25346 Mdot
.55877 .57134 Mdot
.59026 .65607 Mdot
.44929 .34226 Mdot
.39304 .55011 Mdot
.60703 .65032 Mdot
.56141 .38375 Mdot
.48772 .37619 Mdot
.32911 .4633 Mdot
.36279 .20173 Mdot
.29369 .44977 Mdot
.62454 .75534 Mdot
.42185 .25789 Mdot
.63051 .61413 Mdot
.32407 .49789 Mdot
.41928 .62333 Mdot
.32821 .50323 Mdot
.61611 .38831 Mdot
.31044 .50412 Mdot
.5731 .60141 Mdot
.63701 .42009 Mdot
.45415 .36117 Mdot
.64395 .3157 Mdot
.54587 .17354 Mdot
.32401 .51726 Mdot
.41808 .23307 Mdot
.5616 .57006 Mdot
.68211 .4779 Mdot
.65193 .56103 Mdot
.55134 .60238 Mdot
.4555 .39106 Mdot
.62074 .40472 Mdot
.44239 .41134 Mdot
.53487 .57057 Mdot
.81049 .57591 Mdot
.43182 .3954 Mdot
.50845 .26344 Mdot
.42816 .64284 Mdot
.62534 .7418 Mdot
.5992 .58451 Mdot
.46487 .3927 Mdot
.59967 .62371 Mdot
.66791 .36992 Mdot
.51837 .4578 Mdot
.56708 .22014 Mdot
.47143 .38692 Mdot
.17603 .44709 Mdot
.51046 .4741 Mdot
.52267 .57709 Mdot
.45944 .3973 Mdot
.73199 .63765 Mdot
.41176 .24545 Mdot
.41973 .64446 Mdot
.40675 .66851 Mdot
.44064 .64402 Mdot
.57774 .64737 Mdot
.51919 .56184 Mdot
.3808 .62927 Mdot
.4897 .37784 Mdot
.40041 .62037 Mdot
.6227 .73456 Mdot
.18184 .46581 Mdot
.43466 .63889 Mdot
.59875 .59144 Mdot
.53879 .57763 Mdot
.52988 .77202 Mdot
.32165 .45843 Mdot
.19744 .59979 Mdot
.73556 .34587 Mdot
.55544 .58532 Mdot
.57971 .50819 Mdot
.62015 .38563 Mdot
.61116 .24252 Mdot
.61885 .50035 Mdot
.37903 .56406 Mdot
.63244 .385 Mdot
.37285 .53014 Mdot
.61423 .40907 Mdot
.63328 .58934 Mdot
.59872 .60657 Mdot
.63455 .35463 Mdot
.24744 .40429 Mdot
.47995 .2199 Mdot
.21971 .33878 Mdot
.66246 .37348 Mdot
.46609 .39685 Mdot
.46876 .40189 Mdot
.43969 .38825 Mdot
.35265 .5045 Mdot
.65586 .431 Mdot
.59266 .62765 Mdot
.30412 .47387 Mdot
.6162 .58039 Mdot
.46108 .38682 Mdot
.32261 .23075 Mdot
.65066 .38015 Mdot
.58316 .56859 Mdot
.68868 .2546 Mdot
.33751 .48486 Mdot
.41134 .65393 Mdot
.41036 .48319 Mdot
.26871 .46718 Mdot
.48308 .37668 Mdot
.59818 .41157 Mdot
.49449 .39994 Mdot
.41285 .57884 Mdot
.65152 .61174 Mdot
.54699 .63358 Mdot
.35105 .2315 Mdot
.62441 .20712 Mdot
.56543 .6381 Mdot
.29712 .48136 Mdot
.34853 .4685 Mdot
.62076 .60535 Mdot
.67013 .41297 Mdot
.3844 .6552 Mdot
.44021 .63531 Mdot
.62133 .64893 Mdot
.47704 .46179 Mdot
.60226 .75011 Mdot
.61361 .6376 Mdot
.5906 .68309 Mdot
.29041 .50359 Mdot
.40921 .23674 Mdot
.57854 .3345 Mdot
.42045 .6652 Mdot
.60614 .60983 Mdot
.47089 .23779 Mdot
.63942 .38032 Mdot
.31474 .50493 Mdot
.44339 .35662 Mdot
.46362 .62508 Mdot
.32895 .52116 Mdot
.62044 .60621 Mdot
.61931 .62749 Mdot
.44485 .34292 Mdot
.69349 .4097 Mdot
.41246 .638 Mdot
.30452 .475 Mdot
.4042 .66434 Mdot
.63679 .40995 Mdot
.65034 .38429 Mdot
.60084 .67612 Mdot
.65652 .6553 Mdot
.32525 .51881 Mdot
.63519 .64185 Mdot
.3055 .45681 Mdot
.36774 .59763 Mdot
.41914 .38146 Mdot
.59782 .65911 Mdot
.62418 .44873 Mdot
.45623 .38741 Mdot
.56072 .58619 Mdot
.3788 .23424 Mdot
.62294 .63663 Mdot
.26856 .46947 Mdot
.81664 .56781 Mdot
.39101 .63539 Mdot
.5917 .36342 Mdot
.52205 .67099 Mdot
.5746 .61296 Mdot
.30697 .45435 Mdot
.61467 .53334 Mdot
.42686 .38179 Mdot
.62777 .39764 Mdot
.86751 .45337 Mdot
.4542 .37722 Mdot
.59019 .61183 Mdot
.40281 .6358 Mdot
.65577 .44364 Mdot
.41013 .26807 Mdot
.57725 .32816 Mdot
.51394 .58909 Mdot
.59146 .54057 Mdot
.58494 .61892 Mdot
.58207 .81465 Mdot
.31762 .49948 Mdot
.62953 .42702 Mdot
.42394 .39219 Mdot
.44096 .37287 Mdot
.33385 .47421 Mdot
.52525 .31634 Mdot
.23745 .43376 Mdot
.27463 .19719 Mdot
.30108 .50491 Mdot
.4021 .61828 Mdot
.45126 .48235 Mdot
.28388 .46734 Mdot
.31851 .49295 Mdot
.31666 .51988 Mdot
.55205 .32436 Mdot
.67269 .38827 Mdot
.60621 .59836 Mdot
.60557 .38943 Mdot
.62808 .62515 Mdot
.60524 .77892 Mdot
.44333 .38017 Mdot
.6288 .39814 Mdot
.3705 .23132 Mdot
.67302 .59678 Mdot
.57306 .58743 Mdot
.22018 .52832 Mdot
.54762 .54163 Mdot
.52446 .73269 Mdot
.53232 .6315 Mdot
.33964 .50235 Mdot
.55561 .51764 Mdot
.62417 .54277 Mdot
.73018 .32684 Mdot
.46123 .36439 Mdot
.4213 .26916 Mdot
.56161 .55328 Mdot
.5214 .63321 Mdot
.65527 .44329 Mdot
.67651 .38151 Mdot
.38004 .63159 Mdot
.42798 .46085 Mdot
.45759 .36206 Mdot
.2692 .4315 Mdot
.55472 .60239 Mdot
.40422 .3629 Mdot
.82404 .53169 Mdot
.56265 .58281 Mdot
.23699 .60284 Mdot
.75725 .62938 Mdot
.61042 .64883 Mdot
.71179 .56895 Mdot
.45675 .36859 Mdot
.82146 .46227 Mdot
.64525 .60167 Mdot
.3196 .47901 Mdot
.62903 .40654 Mdot
.61589 .39308 Mdot
.42802 .63076 Mdot
.74104 .31827 Mdot
.47866 .40316 Mdot
.63076 .40219 Mdot
.58385 .58193 Mdot
.4368 .36359 Mdot
.41669 .26906 Mdot
.56133 .54155 Mdot
.32769 .70818 Mdot
.65878 .3893 Mdot
.63024 .65873 Mdot
.47823 .31076 Mdot
.41926 .50354 Mdot
.18645 .621 Mdot
.44033 .39157 Mdot
.42969 .66117 Mdot
.53414 .63711 Mdot
.38041 .29319 Mdot
.63337 .56428 Mdot
.59091 .76486 Mdot
.63765 .33924 Mdot
.39141 .65765 Mdot
.58148 .57577 Mdot
.60438 .65062 Mdot
.47249 .47395 Mdot
.42907 .66764 Mdot
.61583 .64796 Mdot
.61764 .67336 Mdot
.66965 .3986 Mdot
.41508 .27776 Mdot
.65714 .38335 Mdot
.59356 .59231 Mdot
.5613 .51166 Mdot
.67574 .39869 Mdot
.22562 .48148 Mdot
.41747 .67541 Mdot
.42951 .37756 Mdot
.52983 .65675 Mdot
.5479 .60386 Mdot
.38431 .8264 Mdot
.42374 .26398 Mdot
.66982 .76198 Mdot
.27419 .46362 Mdot
.43114 .23484 Mdot
.25888 .48915 Mdot
.17268 .51489 Mdot
.60544 .32601 Mdot
.64614 .62785 Mdot
.40986 .74309 Mdot
.70214 .55666 Mdot
.47159 .40354 Mdot
.71135 .46579 Mdot
.55357 .59988 Mdot
.60621 .57125 Mdot
.29904 .46772 Mdot
.52588 .33137 Mdot
.57057 .251 Mdot
.49956 .44031 Mdot
.4139 .6341 Mdot
.63715 .40206 Mdot
.56796 .60684 Mdot
.25997 .34947 Mdot
.30515 .50382 Mdot
.54499 .4696 Mdot
.59004 .56881 Mdot
.59426 .27848 Mdot
.53223 .28371 Mdot
.43614 .36289 Mdot
.30351 .45264 Mdot
.26977 .47186 Mdot
.6237 .57503 Mdot
.46212 .35974 Mdot
.62444 .62431 Mdot
.53344 .46247 Mdot
.63327 .65114 Mdot
.4066 .62668 Mdot
.59356 .5594 Mdot
.46997 .5072 Mdot
.15721 .54255 Mdot
.54546 .53854 Mdot
.62372 .43328 Mdot
.35195 .50348 Mdot
.34292 .48781 Mdot
.66196 .37428 Mdot
.34042 .48286 Mdot
.7267 .54104 Mdot
.80711 .47734 Mdot
.42135 .63393 Mdot
.65753 .47923 Mdot
.40171 .62899 Mdot
.42167 .26932 Mdot
.56447 .57183 Mdot
.39138 .31365 Mdot
.30562 .50942 Mdot
.7273 .70737 Mdot
.44724 .37427 Mdot
.42316 .26413 Mdot
.59324 .55208 Mdot
.30432 .56866 Mdot
.30149 .46124 Mdot
.30875 .43342 Mdot
.62468 .60594 Mdot
.67303 .38033 Mdot
.60468 .65005 Mdot
.60794 .66159 Mdot
.42009 .24672 Mdot
.58546 .6199 Mdot
.44796 .40651 Mdot
.65919 .42912 Mdot
.17973 .50865 Mdot
.35744 .49713 Mdot
.59572 .56242 Mdot
.58335 .58125 Mdot
.67063 .3699 Mdot
.58104 .55496 Mdot
.47469 .36779 Mdot
.08985 .45582 Mdot
.42711 .64296 Mdot
.40327 .23669 Mdot
.28991 .43448 Mdot
.56447 .62777 Mdot
.6091 .64425 Mdot
.3435 .23447 Mdot
.51837 .19822 Mdot
.44945 .40529 Mdot
.57004 .66276 Mdot
.30076 .48332 Mdot
.40401 .6325 Mdot
.47223 .35679 Mdot
.61305 .61673 Mdot
.60349 .56822 Mdot
.40896 .62661 Mdot
.22573 .58013 Mdot
.38923 .50205 Mdot
.43707 .38336 Mdot
.59651 .49783 Mdot
.35267 .58497 Mdot
.60591 .5797 Mdot
.21822 .37892 Mdot
.64436 .3847 Mdot
.45263 .39874 Mdot
.70188 .66711 Mdot
.63838 .60681 Mdot
.4822 .37831 Mdot
.45675 .36238 Mdot
.61237 .56112 Mdot
.60324 .3927 Mdot
.66423 .43116 Mdot
.64137 .38333 Mdot
.81678 .57764 Mdot
.49577 .79517 Mdot
.32276 .50756 Mdot
.45909 .36854 Mdot
.35055 .46729 Mdot
.38246 .65435 Mdot
.42946 .48522 Mdot
.34323 .46328 Mdot
.61818 .38974 Mdot
.33443 .45308 Mdot
.62165 .63035 Mdot
.46158 .36241 Mdot
.29415 .4889 Mdot
.56934 .63179 Mdot
.60988 .68564 Mdot
.49467 .50632 Mdot
.38422 .65375 Mdot
.39795 .51201 Mdot
.59055 .60433 Mdot
.41769 .24622 Mdot
.57088 .57032 Mdot
.43757 .35716 Mdot
.45465 .51323 Mdot
.57475 .63313 Mdot
.32198 .51831 Mdot
.43791 .58491 Mdot
.33108 .46223 Mdot
.59282 .66835 Mdot
.59379 .59345 Mdot
.60613 .57734 Mdot
.6059 .65105 Mdot
.51545 .27732 Mdot
.43662 .41209 Mdot
.54541 .67243 Mdot
.36012 .51448 Mdot
.65594 .40726 Mdot
.65853 .36282 Mdot
.34761 .56101 Mdot
.41609 .23928 Mdot
.46991 .37002 Mdot
.60751 .58072 Mdot
.31223 .43352 Mdot
.3131 .23907 Mdot
.21697 .36746 Mdot
.26699 .60637 Mdot
.2954 .48428 Mdot
.62554 .43351 Mdot
.28636 .48203 Mdot
.61929 .57487 Mdot
.53064 .61315 Mdot
.18 .51841 Mdot
.414 .35861 Mdot
.41362 .63944 Mdot
.61565 .57811 Mdot
.63206 .74837 Mdot
.30006 .48215 Mdot
.28717 .49958 Mdot
.62886 .61212 Mdot
.67813 .41467 Mdot
.17576 .64237 Mdot
.44226 .35628 Mdot
.68831 .4753 Mdot
.59394 .3677 Mdot
.58585 .4538 Mdot
.43889 .36631 Mdot
.49891 .52079 Mdot
.34385 .47633 Mdot
.7384 .3419 Mdot
.65551 .40281 Mdot
.41311 .64347 Mdot
.53851 .62932 Mdot
.61549 .39509 Mdot
.3003 .4518 Mdot
.6198 .39466 Mdot
.63635 .60289 Mdot
.45862 .40846 Mdot
.33441 .47236 Mdot
.43345 .41566 Mdot
.63704 .35375 Mdot
.39699 .63004 Mdot
.63191 .7342 Mdot
.70236 .46384 Mdot
.75634 .63061 Mdot
.58219 .63603 Mdot
.34498 .44686 Mdot
.60005 .62579 Mdot
.66124 .4384 Mdot
.59921 .58575 Mdot
.69188 .34753 Mdot
.27697 .46903 Mdot
.63264 .65571 Mdot
.56853 .56312 Mdot
.73435 .40002 Mdot
.56907 .58341 Mdot
.59803 .55328 Mdot
.59033 .65445 Mdot
.60761 .35058 Mdot
.62292 .66856 Mdot
.67434 .38597 Mdot
.55603 .29789 Mdot
.32085 .49253 Mdot
.37942 .62479 Mdot
.44325 .64226 Mdot
.59173 .76156 Mdot
.62541 .74312 Mdot
.52987 .31985 Mdot
.66394 .3819 Mdot
.47149 .3965 Mdot
.62494 .62237 Mdot
.70081 .65507 Mdot
.43424 .67618 Mdot
.34163 .47515 Mdot
.34355 .51699 Mdot
.66312 .63956 Mdot
.56454 .82408 Mdot
.62495 .6646 Mdot
.58206 .32045 Mdot
.63205 .63609 Mdot
.59687 .65824 Mdot
.30674 .51902 Mdot
.58706 .72535 Mdot
.58172 .63613 Mdot
.65529 .44334 Mdot
.41367 .64789 Mdot
.59756 .5085 Mdot
.46739 .64664 Mdot
.5228 .48688 Mdot
.72292 .35903 Mdot
.58788 .6246 Mdot
.31082 .47248 Mdot
.61259 .4111 Mdot
.61842 .30634 Mdot
.44443 .38868 Mdot
.55988 .35246 Mdot
.73865 .42743 Mdot
.23521 .5072 Mdot
.41523 .6435 Mdot
.23817 .59591 Mdot
.57321 .60179 Mdot
.34847 .50797 Mdot
.63365 .60894 Mdot
.30415 .24638 Mdot
.38678 .63889 Mdot
.65837 .35445 Mdot
.46699 .39681 Mdot
.66158 .36917 Mdot
.76102 .60335 Mdot
.49154 .56982 Mdot
.40203 .21364 Mdot
.36153 .49218 Mdot
.66841 .72073 Mdot
.62852 .42023 Mdot
.61804 .61575 Mdot
.3028 .18085 Mdot
.6434 .38672 Mdot
.66744 .37294 Mdot
.38277 .56469 Mdot
.5044 .68477 Mdot
.60548 .53123 Mdot
.6234 .38738 Mdot
.35612 .46998 Mdot
.40246 .6541 Mdot
.58812 .64382 Mdot
.59377 .65356 Mdot
.67793 .38841 Mdot
.30062 .45995 Mdot
.64934 .75089 Mdot
.3402 .50448 Mdot
.66677 .40735 Mdot
.33398 .48576 Mdot
.31608 .42839 Mdot
.30226 .49434 Mdot
.55334 .57511 Mdot
.60767 .58286 Mdot
.32458 .67657 Mdot
.65046 .38438 Mdot
.59984 .64617 Mdot
.60588 .60586 Mdot
.63419 .42236 Mdot
.36945 .51009 Mdot
.69028 .69185 Mdot
.56672 .6183 Mdot
.60862 .5925 Mdot
.39841 .66219 Mdot
.33763 .53946 Mdot
.25541 .34179 Mdot
.59256 .64509 Mdot
.43325 .62799 Mdot
.65587 .43484 Mdot
.56858 .57259 Mdot
.61777 .73493 Mdot
.31041 .5241 Mdot
.60657 .5616 Mdot
.40959 .26903 Mdot
.55904 .62434 Mdot
.17352 .63571 Mdot
.58443 .56124 Mdot
.63972 .42873 Mdot
.62581 .40927 Mdot
.39849 .4754 Mdot
.64632 .40642 Mdot
.42125 .26241 Mdot
.46108 .38544 Mdot
.20029 .38494 Mdot
.41845 .26527 Mdot
.57887 .65805 Mdot
.70832 .26924 Mdot
.63919 .63238 Mdot
.55316 .56251 Mdot
.68018 .73132 Mdot
.41871 .26241 Mdot
.62069 .41196 Mdot
.25145 .40077 Mdot
.60689 .65904 Mdot
.44626 .35547 Mdot
.53631 .59154 Mdot
.60015 .55866 Mdot
.56673 .41981 Mdot
.79113 .61034 Mdot
.43607 .35599 Mdot
.52256 .60951 Mdot
.59313 .64464 Mdot
.58467 .20158 Mdot
.58213 .58896 Mdot
.43263 .63578 Mdot
.65163 .37403 Mdot
.28483 .4859 Mdot
.42378 .65079 Mdot
.56484 .61439 Mdot
.40934 .64272 Mdot
.31854 .50526 Mdot
.45614 .39318 Mdot
.60415 .56331 Mdot
.44696 .64377 Mdot
.41229 .63524 Mdot
.60465 .63007 Mdot
.62901 .40189 Mdot
.62263 .52851 Mdot
.56654 .57504 Mdot
.6188 .61065 Mdot
.66294 .37516 Mdot
.67218 .20269 Mdot
.62829 .58263 Mdot
.48326 .52609 Mdot
.6409 .35914 Mdot
.3958 .26327 Mdot
.28848 .48252 Mdot
.63315 .5766 Mdot
.43978 .37796 Mdot
.44927 .38486 Mdot
.36987 .47952 Mdot
.67929 .37625 Mdot
.31572 .45898 Mdot
.53866 .55351 Mdot
.65576 .65404 Mdot
.55793 .65577 Mdot
.86735 .45946 Mdot
.19965 .54678 Mdot
.65931 .42647 Mdot
.33812 .46958 Mdot
.50105 .43744 Mdot
.4692 .37179 Mdot
.35082 .45949 Mdot
.62144 .44558 Mdot
.63628 .43483 Mdot
.62273 .38468 Mdot
.41031 .6638 Mdot
.34888 .50036 Mdot
.69534 .38877 Mdot
.68229 .40249 Mdot
.6244 .61442 Mdot
.59457 .64449 Mdot
.66698 .3428 Mdot
.51822 .76499 Mdot
.39996 .6273 Mdot
.31655 .47344 Mdot
.3518 .82134 Mdot
.43655 .35793 Mdot
.73469 .3961 Mdot
.56807 .6296 Mdot
.48692 .09794 Mdot
.59622 .67313 Mdot
.58326 .58417 Mdot
.65348 .43456 Mdot
.41724 .61698 Mdot
.39919 .64467 Mdot
.62806 .4189 Mdot
.62308 .35639 Mdot
.43649 .65167 Mdot
.26339 .61156 Mdot
.17072 .43136 Mdot
.59864 .31952 Mdot
.6413 .42702 Mdot
.69803 .4614 Mdot
.47801 .36943 Mdot
.62973 .36006 Mdot
.43175 .35866 Mdot
.31794 .4918 Mdot
.33485 .51715 Mdot
.44201 .34429 Mdot
.62429 .59978 Mdot
.30946 .5017 Mdot
.51407 .5843 Mdot
.19873 .51563 Mdot
.31953 .73756 Mdot
.49151 .19113 Mdot
.55587 .62443 Mdot
.57485 .25895 Mdot
.54099 .24236 Mdot
.58129 .60863 Mdot
.67783 .59973 Mdot
.41255 .64098 Mdot
.63761 .3569 Mdot
.47018 .36438 Mdot
.19614 .63252 Mdot
.60646 .5801 Mdot
.65715 .4164 Mdot
.46553 .36628 Mdot
.33828 .42486 Mdot
.55871 .39171 Mdot
.63031 .61169 Mdot
.17191 .30184 Mdot
.64956 .35344 Mdot
.28461 .48578 Mdot
.71244 .29006 Mdot
.60961 .38403 Mdot
.37313 .58078 Mdot
.27447 .47978 Mdot
.23686 .32266 Mdot
.6218 .42391 Mdot
.37854 .50874 Mdot
.63914 .40971 Mdot
.4128 .62504 Mdot
.599 .40935 Mdot
.32875 .46999 Mdot
.57621 .57748 Mdot
.33372 .47585 Mdot
.40222 .62486 Mdot
.34912 .50996 Mdot
.47166 .36459 Mdot
.42153 .25444 Mdot
.4657 .376 Mdot
.42185 .49031 Mdot
.7958 .59379 Mdot
.43737 .39481 Mdot
.25199 .4572 Mdot
.56508 .63692 Mdot
.69125 .4162 Mdot
.28595 .48995 Mdot
.36657 .4964 Mdot
.43671 .47482 Mdot
.65107 .4164 Mdot
.32739 .47153 Mdot
.73425 .43778 Mdot
.75083 .26634 Mdot
.50848 .61229 Mdot
.44767 .78421 Mdot
.63599 .42394 Mdot
.27625 .47543 Mdot
.60453 .30924 Mdot
.6362 .36819 Mdot
.30435 .50688 Mdot
.46339 .39574 Mdot
.43983 .37069 Mdot
.62552 .59039 Mdot
.40738 .37716 Mdot
.29611 .45575 Mdot
.47982 .22678 Mdot
.64934 .37303 Mdot
.35071 .42707 Mdot
.43644 .63818 Mdot
.31429 .49473 Mdot
.63773 .55204 Mdot
.63294 .34936 Mdot
.35474 .51339 Mdot
.34918 .72844 Mdot
.39453 .84382 Mdot
.32758 .4726 Mdot
.6508 .37403 Mdot
.66318 .40186 Mdot
.57337 .52747 Mdot
.47142 .46647 Mdot
.311 .46084 Mdot
.39125 .32953 Mdot
.59092 .76832 Mdot
.40504 .2586 Mdot
.63758 .20909 Mdot
.58014 .6351 Mdot
.60101 .62232 Mdot
.47469 .37703 Mdot
.57068 .59414 Mdot
.67323 .42349 Mdot
.55142 .569 Mdot
.48392 .38798 Mdot
.3382 .47198 Mdot
.58491 .56375 Mdot
.39334 .64349 Mdot
.4747 .36382 Mdot
.45724 .34289 Mdot
.33038 .49232 Mdot
.62341 .38557 Mdot
.23021 .40831 Mdot
.34131 .5046 Mdot
.58651 .62556 Mdot
.41363 .25474 Mdot
.63819 .5959 Mdot
.30491 .68223 Mdot
.64878 .36694 Mdot
.28548 .48199 Mdot
.60922 .40299 Mdot
.46045 .3747 Mdot
.37033 .48609 Mdot
.58305 .59307 Mdot
.3112 .51163 Mdot
.37064 .69247 Mdot
.2771 .64328 Mdot
.68528 .39103 Mdot
.44099 .61928 Mdot
.67438 .3757 Mdot
.40527 .26005 Mdot
.44087 .707 Mdot
.42078 .63921 Mdot
.30405 .48762 Mdot
.19598 .5552 Mdot
.30783 .5143 Mdot
.56707 .58458 Mdot
.55889 .59796 Mdot
.29633 .46914 Mdot
.39435 .65255 Mdot
.76724 .69038 Mdot
.48903 .54442 Mdot
.61841 .40922 Mdot
.69538 .32785 Mdot
.28133 .76633 Mdot
.48779 .40668 Mdot
.47577 .38899 Mdot
.55443 .66459 Mdot
.61792 .64399 Mdot
.46746 .34997 Mdot
.42179 .39623 Mdot
.39114 .65961 Mdot
.33988 .51175 Mdot
.65578 .45389 Mdot
.47745 .36305 Mdot
.51432 .66963 Mdot
.63409 .74222 Mdot
.56358 .53161 Mdot
.6492 .63889 Mdot
.54733 .61972 Mdot
.41413 .50715 Mdot
.43422 .40734 Mdot
.59399 .60311 Mdot
.59288 .67593 Mdot
.45125 .40138 Mdot
.40885 .62527 Mdot
.66132 .45995 Mdot
.32716 .48026 Mdot
.62663 .14851 Mdot
.60048 .5615 Mdot
.57274 .57582 Mdot
.43588 .37921 Mdot
.6019 .19417 Mdot
.65559 .4264 Mdot
.63346 .37617 Mdot
.31724 .50026 Mdot
.43323 .4725 Mdot
.5574 .56655 Mdot
.58453 .60675 Mdot
.30888 .48547 Mdot
.41979 .25144 Mdot
.45584 .19385 Mdot
.60386 .59735 Mdot
.45179 .36436 Mdot
.36302 .44567 Mdot
.43176 .40639 Mdot
.6333 .60335 Mdot
.56491 .58726 Mdot
.55561 .57159 Mdot
.61119 .65064 Mdot
.45541 .34429 Mdot
.58372 .60388 Mdot
.66182 .58424 Mdot
.62548 .39371 Mdot
.57318 .62414 Mdot
.58711 .7565 Mdot
.60551 .59019 Mdot
.39352 .64043 Mdot
.24285 .36636 Mdot
.61045 .5774 Mdot
.57527 .62352 Mdot
.48918 .53771 Mdot
.58609 .57455 Mdot
.43339 .36207 Mdot
.65897 .40277 Mdot
.46033 .36885 Mdot
.42712 .39319 Mdot
.36148 .47927 Mdot
.38846 .65724 Mdot
.63318 .56314 Mdot
.43917 .6387 Mdot
.65219 .58023 Mdot
.63605 .60719 Mdot
.37685 .5296 Mdot
.57884 .32242 Mdot
.36148 .66453 Mdot
.5873 .59267 Mdot
.32019 .49727 Mdot
.28891 .49058 Mdot
.3922 .73589 Mdot
.53067 .55412 Mdot
.4651 .35033 Mdot
.46542 .39247 Mdot
.49629 .73915 Mdot
.56564 .39942 Mdot
.39551 .63391 Mdot
.52008 .41652 Mdot
.55475 .62774 Mdot
.61162 .60088 Mdot
.53634 .58757 Mdot
.34598 .46474 Mdot
.41597 .24248 Mdot
.34521 .47986 Mdot
.39487 .22768 Mdot
.43237 .40839 Mdot
.55535 .62086 Mdot
.28807 .71547 Mdot
.67846 .40022 Mdot
.65901 .4015 Mdot
.48956 .37486 Mdot
.32725 .46005 Mdot
.58723 .52729 Mdot
.87403 .46261 Mdot
.68544 .35458 Mdot
.39581 .61559 Mdot
.58647 .60875 Mdot
.32799 .49464 Mdot
.67923 .40465 Mdot
.44414 .65886 Mdot
.55426 .61204 Mdot
.35886 .51751 Mdot
.60197 .58622 Mdot
.70368 .57112 Mdot
.62358 .39962 Mdot
.31389 .23525 Mdot
.6866 .38898 Mdot
.48197 .37259 Mdot
.4347 .40138 Mdot
.56153 .58623 Mdot
.81903 .37616 Mdot
.66381 .35348 Mdot
.4259 .41326 Mdot
.39276 .62382 Mdot
.40317 .23739 Mdot
.38249 .63704 Mdot
.28586 .46306 Mdot
.41545 .64608 Mdot
.3272 .5196 Mdot
.49749 .7522 Mdot
.69224 .36719 Mdot
.42597 .64601 Mdot
.56685 .17984 Mdot
.59698 .54721 Mdot
.40014 .66574 Mdot
.66527 .62751 Mdot
.66368 .32566 Mdot
.31241 .48483 Mdot
.39482 .65186 Mdot
.61883 .61872 Mdot
.21913 .656 Mdot
.43071 .39794 Mdot
.46302 .34938 Mdot
.62976 .55839 Mdot
.30193 .5143 Mdot
.61618 .36204 Mdot
.41042 .55572 Mdot
.39831 .26877 Mdot
.58514 .60537 Mdot
.55421 .62017 Mdot
.67085 .36606 Mdot
.66998 .43344 Mdot
.5629 .58946 Mdot
.72423 .4581 Mdot
.57242 .60351 Mdot
.43731 .36978 Mdot
.64278 .43381 Mdot
.66219 .39992 Mdot
.3038 .45318 Mdot
.68005 .37879 Mdot
.64257 .64972 Mdot
.4515 .33274 Mdot
.54648 .64673 Mdot
.45725 .37814 Mdot
.46094 .51479 Mdot
.35508 .5027 Mdot
.19722 .61705 Mdot
.67831 .37089 Mdot
.58183 .62123 Mdot
.67184 .37322 Mdot
.43465 .64656 Mdot
.65228 .38554 Mdot
.61161 .42322 Mdot
.55548 .5986 Mdot
.63057 .61331 Mdot
.4184 .25687 Mdot
.46662 .46672 Mdot
.63241 .39138 Mdot
.57329 .60735 Mdot
.64106 .63108 Mdot
.61076 .55645 Mdot
.49163 .47982 Mdot
.6398 .43696 Mdot
.78364 .46128 Mdot
.31098 .70428 Mdot
.63083 .39778 Mdot
.2072 .6762 Mdot
.40245 .26515 Mdot
.4117 .23587 Mdot
.48131 .41057 Mdot
.60697 .59708 Mdot
.32491 .46352 Mdot
.61807 .57322 Mdot
.51062 .60485 Mdot
.60597 .56863 Mdot
.39233 .6282 Mdot
.64793 .58127 Mdot
.40155 .24881 Mdot
.34335 .49953 Mdot
.56499 .6193 Mdot
.59208 .56359 Mdot
.42021 .24395 Mdot
.68623 .38067 Mdot
.62821 .43123 Mdot
.21608 .38595 Mdot
.42498 .63388 Mdot
.45197 .39094 Mdot
.62202 .58894 Mdot
.31878 .49839 Mdot
.33694 .47874 Mdot
.6637 .36997 Mdot
.32169 .47725 Mdot
.44093 .35611 Mdot
.57854 .59129 Mdot
.46391 .34758 Mdot
.39395 .62718 Mdot
.65258 .37413 Mdot
.62208 .58753 Mdot
.62438 .61317 Mdot
.62563 .40923 Mdot
.56442 .63654 Mdot
.3992 .66253 Mdot
.33312 .51547 Mdot
.62897 .42995 Mdot
.45829 .38598 Mdot
.31135 .45268 Mdot
.62071 .62803 Mdot
.45204 .84776 Mdot
.56953 .59713 Mdot
.61898 .60189 Mdot
.16714 .47377 Mdot
.56607 .66851 Mdot
.27835 .47047 Mdot
.65441 .36142 Mdot
.5624 .5484 Mdot
.59395 .78016 Mdot
.35366 .25018 Mdot
.35699 .46462 Mdot
.58579 .61367 Mdot
.19126 .60167 Mdot
.57813 .61825 Mdot
.32924 .42079 Mdot
.38553 .52435 Mdot
.50983 .81212 Mdot
.65073 .64028 Mdot
.43278 .35399 Mdot
.41968 .25772 Mdot
.28992 .49781 Mdot
.7318 .6183 Mdot
.56194 .60954 Mdot
.73061 .64448 Mdot
.5862 .5563 Mdot
.43962 .36674 Mdot
.66923 .65409 Mdot
.31802 .47397 Mdot
.73071 .32078 Mdot
.59266 .62679 Mdot
.64183 .43626 Mdot
.34133 .45641 Mdot
.39648 .24571 Mdot
.62078 .61543 Mdot
.43273 .63024 Mdot
.49306 .33292 Mdot
.65012 .65485 Mdot
.45682 .38054 Mdot
.60711 .60728 Mdot
.52026 .6055 Mdot
.78512 .34391 Mdot
.62216 .39843 Mdot
.47236 .39186 Mdot
.60342 .23367 Mdot
.56324 .63806 Mdot
.62344 .42578 Mdot
.65523 .40481 Mdot
.42088 .62548 Mdot
.53178 .38629 Mdot
.43162 .30104 Mdot
.3514 .76379 Mdot
.77707 .59898 Mdot
.29413 .454 Mdot
.50566 .21699 Mdot
.5904 .64176 Mdot
.50072 .54725 Mdot
.43127 .36475 Mdot
.57555 .57545 Mdot
.80048 .57018 Mdot
.64269 .38259 Mdot
.60049 .59555 Mdot
.40391 .62711 Mdot
.51574 .35985 Mdot
.53332 .48633 Mdot
.37103 .81102 Mdot
.35308 .46377 Mdot
.53334 .61616 Mdot
.65896 .61915 Mdot
.39438 .258 Mdot
.63186 .62179 Mdot
.28584 .49169 Mdot
.21555 .53093 Mdot
.3911 .64927 Mdot
.68137 .3926 Mdot
.40094 .26355 Mdot
.54201 .60069 Mdot
.63901 .58128 Mdot
.38054 .62393 Mdot
.61171 .62159 Mdot
.72432 .3104 Mdot
.43404 .27759 Mdot
.30367 .49802 Mdot
.61806 .39708 Mdot
.54809 .62374 Mdot
.41549 .24235 Mdot
.55672 .59898 Mdot
.70881 .41429 Mdot
.59763 .61803 Mdot
.49792 .32326 Mdot
.62977 .40698 Mdot
.46093 .38008 Mdot
.62968 .55634 Mdot
.60024 .57259 Mdot
.34814 .58674 Mdot
.51082 .607 Mdot
.58721 .56133 Mdot
.65208 .44538 Mdot
.67323 .40721 Mdot
.67256 .38295 Mdot
.30914 .50406 Mdot
.5865 .32819 Mdot
.44932 .3702 Mdot
.57068 .55695 Mdot
.47687 .36253 Mdot
.51069 .65324 Mdot
.38784 .61894 Mdot
.24723 .70841 Mdot
.56193 .62012 Mdot
.66926 .38269 Mdot
.47665 .24543 Mdot
.6579 .43363 Mdot
.33473 .53141 Mdot
.45795 .36198 Mdot
.64167 .38774 Mdot
.59119 .57755 Mdot
.49212 .45067 Mdot
.41083 .82523 Mdot
.47004 .37504 Mdot
.53335 .59633 Mdot
.35981 .47137 Mdot
.34279 .51957 Mdot
.20983 .70535 Mdot
.43887 .40586 Mdot
.53801 .23845 Mdot
.57358 .61035 Mdot
.67837 .39781 Mdot
.4369 .38989 Mdot
.42717 .36662 Mdot
.31257 .48188 Mdot
.63096 .60212 Mdot
.6022 .57762 Mdot
.4082 .26861 Mdot
.46372 .39141 Mdot
.58984 .54425 Mdot
.63142 .63168 Mdot
.17564 .51301 Mdot
.67171 .45043 Mdot
.64017 .18087 Mdot
.53744 .55588 Mdot
.78056 .60719 Mdot
.44983 .49477 Mdot
.66037 .42668 Mdot
.62247 .58291 Mdot
.53916 .59874 Mdot
.28756 .45659 Mdot
.57487 .59447 Mdot
.34646 .47148 Mdot
.47786 .38819 Mdot
.26132 .72446 Mdot
.36402 .42304 Mdot
.24972 .59297 Mdot
.57079 .58844 Mdot
.57589 .45148 Mdot
.42697 .65303 Mdot
.48496 .35588 Mdot
.66352 .41443 Mdot
.55199 .63279 Mdot
.27176 .48007 Mdot
.30266 .48667 Mdot
.65142 .39944 Mdot
.53937 .25975 Mdot
.2285 .47697 Mdot
.61558 .6495 Mdot
.28658 .47606 Mdot
.35286 .4079 Mdot
.72874 .46997 Mdot
.4129 .36591 Mdot
.38858 .64516 Mdot
.33728 .47187 Mdot
.45224 .34123 Mdot
.70796 .40688 Mdot
.64345 .39788 Mdot
.66209 .35865 Mdot
.31975 .64276 Mdot
.31622 .46134 Mdot
.41529 .65689 Mdot
.57746 .36349 Mdot
.60602 .32911 Mdot
.38928 .63299 Mdot
.33819 .47144 Mdot
.67609 .40722 Mdot
.66062 .41423 Mdot
.65898 .40419 Mdot
.72915 .32174 Mdot
.64569 .36915 Mdot
.77311 .41373 Mdot
.64182 .62496 Mdot
.6782 .48071 Mdot
.58051 .61695 Mdot
.44489 .34689 Mdot
.62328 .4013 Mdot
.44539 .48078 Mdot
.57392 .65293 Mdot
.37465 .80925 Mdot
.58951 .60555 Mdot
.42882 .33952 Mdot
.60828 .59528 Mdot
.70885 .43849 Mdot
.64085 .35889 Mdot
.58598 .59418 Mdot
.41532 .38344 Mdot
.40893 .63563 Mdot
.62385 .45993 Mdot
.60938 .57708 Mdot
.52749 .3501 Mdot
.58851 .67461 Mdot
.20285 .51616 Mdot
.40126 .57627 Mdot
.39982 .61477 Mdot
.61187 .67505 Mdot
.31907 .45015 Mdot
.59429 .42329 Mdot
.6629 .48784 Mdot
.47007 .37607 Mdot
.72627 .69408 Mdot
.30467 .49048 Mdot
.67031 .65204 Mdot
.59191 .66396 Mdot
.4125 .66522 Mdot
.59438 .41268 Mdot
.43267 .37232 Mdot
.56063 .62692 Mdot
.60993 .55963 Mdot
.34668 .69803 Mdot
.66703 .47986 Mdot
.61469 .55465 Mdot
.37942 .64581 Mdot
.78982 .46727 Mdot
.61452 .58983 Mdot
.36965 .50736 Mdot
.63664 .36438 Mdot
.65461 .59537 Mdot
.77887 .45355 Mdot
.57087 .60838 Mdot
.64587 .38993 Mdot
.67596 .36766 Mdot
.49573 .28851 Mdot
.40164 .6161 Mdot
.59807 .61791 Mdot
.37844 .58781 Mdot
.59584 .62418 Mdot
.44585 .36792 Mdot
.62978 .58421 Mdot
.31278 .4906 Mdot
.60143 .3085 Mdot
.31814 .5103 Mdot
.62461 .57912 Mdot
.65691 .41245 Mdot
.43115 .37654 Mdot
.31189 .66279 Mdot
.37296 .55305 Mdot
.77676 .42136 Mdot
.37439 .23406 Mdot
.4052 .66074 Mdot
.40937 .67037 Mdot
.464 .40888 Mdot
.59182 .59283 Mdot
.39889 .52792 Mdot
.61795 .6635 Mdot
.61051 .59277 Mdot
.60863 .56793 Mdot
.40684 .37054 Mdot
.4631 .3677 Mdot
.33375 .48093 Mdot
.56377 .59055 Mdot
.57468 .60615 Mdot
.63458 .39831 Mdot
.41107 .63408 Mdot
.30931 .5069 Mdot
.42969 .64093 Mdot
.33642 .50379 Mdot
.17783 .6405 Mdot
.53588 .5668 Mdot
.40725 .63521 Mdot
.45255 .41139 Mdot
.66536 .37532 Mdot
.42527 .26208 Mdot
.29138 .45944 Mdot
.31945 .4723 Mdot
.5827 .60629 Mdot
.65258 .37683 Mdot
.63995 .37837 Mdot
.42985 .65829 Mdot
.44821 .39645 Mdot
.62313 .57811 Mdot
.62811 .62813 Mdot
.39776 .76328 Mdot
.32928 .45616 Mdot
.73923 .45398 Mdot
.51441 .29328 Mdot
.59135 .59207 Mdot
.62382 .39071 Mdot
.5782 .56572 Mdot
.22013 .63064 Mdot
.61712 .39192 Mdot
.60644 .65467 Mdot
.57483 .39021 Mdot
.35858 .4783 Mdot
.46657 .29541 Mdot
.64596 .5947 Mdot
.33821 .23743 Mdot
.59718 .63615 Mdot
.14187 .47131 Mdot
.54263 .20244 Mdot
.54755 .57907 Mdot
.59231 .65183 Mdot
.384 .78876 Mdot
.57379 .614 Mdot
.40118 .25611 Mdot
.53746 .5527 Mdot
.63288 .43425 Mdot
.41624 .52648 Mdot
.29503 .52697 Mdot
.39836 .61863 Mdot
.31662 .50036 Mdot
.45139 .6822 Mdot
.41351 .62597 Mdot
.63593 .42655 Mdot
.59415 .65402 Mdot
.64359 .72178 Mdot
.33402 .52965 Mdot
.61116 .66133 Mdot
.44471 .36698 Mdot
.31278 .5338 Mdot
.3523 .48347 Mdot
.4628 .38395 Mdot
.57595 .55886 Mdot
.64413 .76645 Mdot
.35115 .55556 Mdot
.22344 .32444 Mdot
.43696 .38291 Mdot
.44176 .36101 Mdot
.63609 .30007 Mdot
.39904 .6186 Mdot
.35397 .70767 Mdot
.58178 .47736 Mdot
.45506 .35634 Mdot
.49662 .71538 Mdot
.28749 .5016 Mdot
.53952 .37332 Mdot
.63642 .35753 Mdot
.53648 .56881 Mdot
.59373 .57566 Mdot
.44849 .39904 Mdot
.66999 .68453 Mdot
.68162 .28444 Mdot
.46698 .37641 Mdot
.6594 .59106 Mdot
.5238 .37365 Mdot
.41343 .25859 Mdot
.40801 .27041 Mdot
.38883 .62458 Mdot
.23244 .49029 Mdot
.63649 .41349 Mdot
.41849 .66663 Mdot
.47432 .3125 Mdot
.60322 .61594 Mdot
.47044 .38695 Mdot
.42597 .26467 Mdot
.44682 .38144 Mdot
.39837 .63981 Mdot
.3951 .61595 Mdot
.62479 .39456 Mdot
.65588 .42584 Mdot
.78168 .61946 Mdot
.51968 .74451 Mdot
.57325 .61971 Mdot
.70299 .68181 Mdot
.65514 .37104 Mdot
.63547 .4867 Mdot
.42476 .62244 Mdot
.41092 .63179 Mdot
.70648 .53729 Mdot
.62647 .61496 Mdot
.3695 .43355 Mdot
.61166 .58163 Mdot
.43628 .71332 Mdot
.58529 .66121 Mdot
.31623 .48014 Mdot
.57915 .6296 Mdot
.23559 .39146 Mdot
.57959 .64332 Mdot
.59692 .56172 Mdot
.34673 .49079 Mdot
.58658 .53268 Mdot
.31067 .49017 Mdot
.63249 .60151 Mdot
.37575 .64565 Mdot
.31891 .49868 Mdot
.47302 .78971 Mdot
.48433 .52437 Mdot
.41037 .23982 Mdot
.4022 .62248 Mdot
.43843 .63984 Mdot
.60781 .75684 Mdot
.66012 .41858 Mdot
.70493 .39948 Mdot
.59258 .59336 Mdot
.28758 .49976 Mdot
.47534 .3771 Mdot
.5732 .60562 Mdot
.53742 .61056 Mdot
.63873 .57276 Mdot
.63923 .38437 Mdot
.3247 .46025 Mdot
.40611 .64067 Mdot
.28934 .48591 Mdot
.3295 .56486 Mdot
.32804 .52141 Mdot
.56623 .67298 Mdot
.55832 .54537 Mdot
.51529 .55801 Mdot
.72866 .66419 Mdot
.73872 .33489 Mdot
.64669 .40131 Mdot
.41174 .24756 Mdot
.38942 .61979 Mdot
.69841 .33084 Mdot
.67092 .39395 Mdot
.31958 .46932 Mdot
.60189 .58603 Mdot
.65739 .57882 Mdot
.55083 .47785 Mdot
.60587 .35661 Mdot
.57129 .77614 Mdot
.35137 .50213 Mdot
.40823 .25951 Mdot
.59882 .31695 Mdot
.63928 .33378 Mdot
.43648 .48343 Mdot
.59409 .56659 Mdot
.43415 .63099 Mdot
.6793 .40448 Mdot
.33156 .66351 Mdot
.45774 .39734 Mdot
.47051 .46605 Mdot
.57139 .58965 Mdot
.4986 .2331 Mdot
.65638 .41252 Mdot
.40046 .62864 Mdot
.44834 .39955 Mdot
.40747 .61686 Mdot
.40288 .26808 Mdot
.21169 .39799 Mdot
.60641 .62647 Mdot
.5767 .56257 Mdot
.4315 .41293 Mdot
.63902 .41356 Mdot
.39365 .4833 Mdot
.3342 .69321 Mdot
.28829 .47406 Mdot
.39437 .52652 Mdot
.66207 .42661 Mdot
.72383 .37421 Mdot
.29645 .49487 Mdot
.49008 .37665 Mdot
.41636 .51029 Mdot
.47956 .39334 Mdot
.61292 .57906 Mdot
.66401 .38519 Mdot
.44196 .40687 Mdot
.3434 .60462 Mdot
.17331 .58303 Mdot
.69544 .44313 Mdot
.55841 .62192 Mdot
.25942 .72021 Mdot
.18085 .49124 Mdot
.65684 .69852 Mdot
.4791 .3715 Mdot
.56138 .58099 Mdot
.61816 .64869 Mdot
.58882 .62747 Mdot
.46619 .40074 Mdot
.2837 .56853 Mdot
.3088 .47568 Mdot
.59253 .60803 Mdot
.43699 .64031 Mdot
.32037 .48757 Mdot
.32124 .44727 Mdot
.2968 .50671 Mdot
.61199 .421 Mdot
.609 .65253 Mdot
.55419 .33846 Mdot
.1423 .49025 Mdot
.46249 .3697 Mdot
.40968 .23963 Mdot
.58259 .55867 Mdot
.83073 .50542 Mdot
.67219 .38317 Mdot
.28932 .47227 Mdot
.57395 .57487 Mdot
.32397 .57769 Mdot
.40599 .22358 Mdot
.34275 .50588 Mdot
.65914 .41777 Mdot
.6541 .69938 Mdot
.57458 .59566 Mdot
.60056 .63558 Mdot
.63552 .41907 Mdot
.2191 .36398 Mdot
.58431 .321 Mdot
.58631 .56417 Mdot
.46213 .38069 Mdot
.7687 .29856 Mdot
.63668 .57255 Mdot
.64827 .34384 Mdot
.40372 .23677 Mdot
.51739 .32525 Mdot
.74266 .46037 Mdot
.51913 .63381 Mdot
.277 .72286 Mdot
.59502 .72631 Mdot
.23397 .70142 Mdot
.42638 .68254 Mdot
.31759 .38292 Mdot
.15834 .61759 Mdot
.41463 .38167 Mdot
.66312 .47545 Mdot
.4625 .81322 Mdot
.55547 .27149 Mdot
.40569 .57412 Mdot
.36448 .28938 Mdot
.3606 .57436 Mdot
.47076 .16162 Mdot
.30589 .5102 Mdot
.40929 .7201 Mdot
.62084 .57421 Mdot
.18523 .48119 Mdot
.7202 .44219 Mdot
.73738 .30817 Mdot
.22538 .6845 Mdot
.38628 .58459 Mdot
.43886 .82786 Mdot
.19864 .60126 Mdot
.6693 .72185 Mdot
.55496 .46387 Mdot
.40904 .31287 Mdot
.58592 .34724 Mdot
.46616 .68019 Mdot
.56296 .52697 Mdot
.25922 .3535 Mdot
.22807 .51122 Mdot
.8064 .50142 Mdot
.77026 .3184 Mdot
.2828 .46315 Mdot
.63276 .36634 Mdot
.39332 .76584 Mdot
.60446 .44833 Mdot
.4862 .34204 Mdot
.27787 .72393 Mdot
.17124 .51862 Mdot
.71127 .43527 Mdot
.36401 .21052 Mdot
.72451 .58407 Mdot
.80198 .64748 Mdot
.4989 .49432 Mdot
.67495 .36293 Mdot
.34052 .35783 Mdot
.60712 .32883 Mdot
.39695 .35358 Mdot
.72673 .34504 Mdot
.45377 .64372 Mdot
.51625 .78058 Mdot
.65573 .41818 Mdot
.73991 .4723 Mdot
.39999 .23349 Mdot
.44948 .30337 Mdot
.38071 .50975 Mdot
.22956 .64836 Mdot
.3875 .22309 Mdot
.5363 .35394 Mdot
.47603 .21808 Mdot
.4339 .84879 Mdot
.52802 .71363 Mdot
.22128 .6042 Mdot
.39982 .3992 Mdot
.57857 .72212 Mdot
.59702 .29266 Mdot
.54368 .74461 Mdot
.63182 .32132 Mdot
.57362 .83371 Mdot
.18079 .43044 Mdot
.4813 .84196 Mdot
.63286 .45615 Mdot
.61004 .55352 Mdot
.26585 .67486 Mdot
.7758 .59366 Mdot
.40365 .61416 Mdot
.40524 .83171 Mdot
.44197 .6374 Mdot
.64582 .45371 Mdot
.54985 .26259 Mdot
.73223 .37198 Mdot
.25169 .46459 Mdot
.38312 .66161 Mdot
.62981 .66212 Mdot
.7318 .78003 Mdot
.30337 .74813 Mdot
.50303 .29839 Mdot
.17246 .50976 Mdot
.42794 .41735 Mdot
.39933 .45862 Mdot
.47675 .39069 Mdot
.16289 .59522 Mdot
.66713 .39756 Mdot
.13438 .51482 Mdot
.16373 .5714 Mdot
.65912 .24996 Mdot
.81791 .71139 Mdot
.47846 .18155 Mdot
.68546 .47819 Mdot
.64392 .73178 Mdot
.54758 .79317 Mdot
.63084 .28457 Mdot
.64715 .2359 Mdot
.42837 .32073 Mdot
.20909 .37124 Mdot
.18057 .63086 Mdot
.4757 .7153 Mdot
.23137 .5315 Mdot
.57269 .27348 Mdot
.48191 .50995 Mdot
.66297 .34453 Mdot
.47192 .54994 Mdot
.52041 .52111 Mdot
.45734 .83398 Mdot
.82169 .53238 Mdot
.84133 .39938 Mdot
.41254 .69261 Mdot
.61579 .20269 Mdot
.20294 .53782 Mdot
.45258 .77961 Mdot
.71642 .34514 Mdot
.55027 .30612 Mdot
.58252 .6755 Mdot
.57761 .33714 Mdot
.65827 .56448 Mdot
.44997 .62574 Mdot
.61897 .30801 Mdot
.29147 .41605 Mdot
.43296 .70253 Mdot
.33386 .74389 Mdot
.57049 .42896 Mdot
.61461 .4216 Mdot
.57642 .74503 Mdot
.51237 .71301 Mdot
.18169 .51773 Mdot
.60066 .23342 Mdot
.21175 .34243 Mdot
.62196 .23669 Mdot
.61839 .66412 Mdot
.64627 .48315 Mdot
.58203 .52421 Mdot
.53294 .73434 Mdot
.64125 .63554 Mdot
.46988 .22958 Mdot
.16295 .4849 Mdot
.80606 .56373 Mdot
.45131 .68894 Mdot
.71611 .67888 Mdot
.19639 .39018 Mdot
.28245 .68845 Mdot
.53998 .20875 Mdot
.66419 .54038 Mdot
.66823 .81039 Mdot
.32925 .48659 Mdot
.493 .71819 Mdot
.46632 .34318 Mdot
.32052 .64926 Mdot
.5235 .82125 Mdot
.65902 .25764 Mdot
.16271 .47848 Mdot
.55888 .30938 Mdot
.37673 .47528 Mdot
.49587 .42733 Mdot
.25904 .49635 Mdot
.7097 .69143 Mdot
.60967 .53952 Mdot
.49652 .64367 Mdot
.42165 .66806 Mdot
.77335 .57631 Mdot
.29933 .69233 Mdot
.32371 .29437 Mdot
.55271 .67278 Mdot
.31727 .32653 Mdot
.40742 .26303 Mdot
.48114 .45815 Mdot
.20174 .69363 Mdot
.5172 .58778 Mdot
.50934 .18209 Mdot
.18588 .41722 Mdot
.40661 .51405 Mdot
.22917 .59578 Mdot
.51084 .26834 Mdot
.53029 .84167 Mdot
.15775 .53323 Mdot
.22397 .45468 Mdot
.26885 .73234 Mdot
.22243 .30033 Mdot
.59239 .81713 Mdot
.71138 .63663 Mdot
.43623 .34064 Mdot
.11458 .40835 Mdot
.30055 .47273 Mdot
.73885 .68608 Mdot
.78047 .5871 Mdot
.31043 .58668 Mdot
.59816 .38722 Mdot
.65203 .67559 Mdot
.38498 .25734 Mdot
.6828 .35629 Mdot
.62887 .66384 Mdot
.37975 .83126 Mdot
.58597 .83561 Mdot
.39609 .83561 Mdot
.20534 .40484 Mdot
.25793 .72481 Mdot
.43472 .80536 Mdot
.77014 .40477 Mdot
.35991 .72854 Mdot
.63175 .59047 Mdot
.47508 .73502 Mdot
.48822 .18327 Mdot
.38559 .49943 Mdot
.43716 .28334 Mdot
.60852 .42754 Mdot
.53804 .83203 Mdot
.21826 .7218 Mdot
.72479 .54296 Mdot
.7768 .48202 Mdot
.51192 .51756 Mdot
.5175 .7347 Mdot
.49356 .65205 Mdot
.27595 .32642 Mdot
.19168 .52561 Mdot
.44985 .814 Mdot
.48737 .70073 Mdot
.35131 .30225 Mdot
.24384 .43601 Mdot
.59385 .19936 Mdot
.20857 .63098 Mdot
.43106 .78779 Mdot
.63728 .23582 Mdot
.67585 .56635 Mdot
.67588 .27704 Mdot
.27668 .30596 Mdot
.3806 .44961 Mdot
.51319 .69943 Mdot
.35618 .50402 Mdot
.4751 .72042 Mdot
.54298 .43465 Mdot
.37155 .74781 Mdot
.60294 .73112 Mdot
.46685 .71637 Mdot
.24212 .44408 Mdot
.33739 .79781 Mdot
.26829 .26709 Mdot
.6745 .77081 Mdot
.31713 .25325 Mdot
.66221 .56944 Mdot
.6313 .5727 Mdot
.17325 .4468 Mdot
.32009 .79405 Mdot
.15079 .50121 Mdot
.49739 .22927 Mdot
.33668 .60484 Mdot
.41854 .35574 Mdot
.70187 .73064 Mdot
.31973 .27424 Mdot
.18226 .54859 Mdot
.67789 .31966 Mdot
.48346 .40933 Mdot
.56605 .31078 Mdot
.72071 .69614 Mdot
.66404 .73392 Mdot
.74918 .48923 Mdot
.5554 .53392 Mdot
.71195 .46493 Mdot
.64767 .35922 Mdot
.50553 .22232 Mdot
.53377 .74119 Mdot
.32955 .49142 Mdot
.45893 .79564 Mdot
.49358 .6335 Mdot
.57773 .67479 Mdot
.37915 .45681 Mdot
.6681 .3472 Mdot
.74081 .6523 Mdot
.43569 .31626 Mdot
.16594 .63251 Mdot
.50283 .19465 Mdot
.58596 .71396 Mdot
.56819 .73187 Mdot
.35054 .67763 Mdot
.56704 .33728 Mdot
.46843 .40536 Mdot
.21464 .66253 Mdot
.45143 .55029 Mdot
.57608 .74117 Mdot
.71541 .46575 Mdot
.3238 .69065 Mdot
.53809 .61551 Mdot
.49712 .27517 Mdot
.79565 .43644 Mdot
.46651 .46377 Mdot
.66825 .44285 Mdot
.68344 .3503 Mdot
.45807 .14696 Mdot
.24625 .39335 Mdot
.58754 .21974 Mdot
.219 .66229 Mdot
.4824 .38886 Mdot
.63905 .44218 Mdot
.45964 .72402 Mdot
.28253 .64531 Mdot
.81107 .4827 Mdot
.29235 .438 Mdot
.49233 .65936 Mdot
.31103 .29087 Mdot
.26432 .7225 Mdot
.36733 .79573 Mdot
.79063 .34735 Mdot
.68324 .40726 Mdot
.29536 .67588 Mdot
.31131 .67778 Mdot
.68357 .39686 Mdot
.61729 .34931 Mdot
.55811 .47059 Mdot
.22662 .70415 Mdot
.57019 .34834 Mdot
.28557 .27734 Mdot
.41347 .51277 Mdot
.30646 .5727 Mdot
.33529 .67474 Mdot
.50211 .68797 Mdot
.22255 .66237 Mdot
.73574 .48389 Mdot
.59302 .79766 Mdot
.57031 .52201 Mdot
.79013 .61474 Mdot
.70453 .72958 Mdot
.49421 .49037 Mdot
.72554 .38549 Mdot
.3128 .41683 Mdot
.58354 .62505 Mdot
.42878 .84905 Mdot
.19116 .50507 Mdot
.64702 .3074 Mdot
.44738 .31211 Mdot
.61309 .64009 Mdot
.63566 .63715 Mdot
.6769 .66776 Mdot
.51641 .31075 Mdot
.64517 .79566 Mdot
.41807 .70471 Mdot
.65704 .55838 Mdot
.72143 .45667 Mdot
.51159 .183 Mdot
.24254 .65992 Mdot
.2013 .52521 Mdot
.53035 .44126 Mdot
.49007 .18562 Mdot
.42229 .46169 Mdot
.28069 .2767 Mdot
.29456 .337 Mdot
.42048 .79736 Mdot
.60236 .4729 Mdot
.53287 .30671 Mdot
.34651 .67031 Mdot
.59276 .55897 Mdot
.53914 .26008 Mdot
.2024 .60976 Mdot
.86329 .45093 Mdot
.60018 .28473 Mdot
.36074 .82468 Mdot
.50237 .59018 Mdot
.53879 .31501 Mdot
.54651 .82259 Mdot
.88166 .51913 Mdot
.26499 .34053 Mdot
.44504 .83057 Mdot
.46264 .45012 Mdot
.22604 .67613 Mdot
.42808 .35308 Mdot
.55804 .3878 Mdot
.71932 .66299 Mdot
.22016 .69707 Mdot
.24484 .63912 Mdot
.23901 .67104 Mdot
.69242 .65268 Mdot
.26182 .73547 Mdot
.65859 .32182 Mdot
.4927 .15188 Mdot
.37387 .49413 Mdot
.44991 .21642 Mdot
.6962 .60203 Mdot
.51399 .54753 Mdot
.49247 .71109 Mdot
.57987 .17317 Mdot
.75612 .35874 Mdot
.69674 .65929 Mdot
.44701 .75332 Mdot
.51521 .27921 Mdot
.56984 .72981 Mdot
.17815 .56161 Mdot
.47535 .15868 Mdot
.32501 .67461 Mdot
.54874 .22615 Mdot
.21082 .38885 Mdot
.51118 .30953 Mdot
.28323 .37412 Mdot
.2198 .60441 Mdot
.25091 .3218 Mdot
.4862 .64797 Mdot
.5243 .11478 Mdot
.24286 .52303 Mdot
.5564 .47349 Mdot
.50748 .83937 Mdot
.19277 .52167 Mdot
.69188 .32294 Mdot
.71662 .30146 Mdot
.78756 .63286 Mdot
.49623 .75439 Mdot
.60615 .56898 Mdot
.27014 .74647 Mdot
.49044 .78045 Mdot
.42806 .83706 Mdot
.18154 .39346 Mdot
.70275 .48416 Mdot
.52649 .64103 Mdot
.27389 .46217 Mdot
.51723 .49483 Mdot
.4354 .74903 Mdot
.452 .82288 Mdot
.76373 .65542 Mdot
.38628 .55146 Mdot
.3189 .37328 Mdot
.2971 .43486 Mdot
.63498 .51604 Mdot
.47152 .18907 Mdot
.51998 .29599 Mdot
.42919 .69105 Mdot
.23788 .4338 Mdot
.51137 .72561 Mdot
.73931 .45767 Mdot
.65773 .74318 Mdot
.64388 .26738 Mdot
.50245 .39707 Mdot
.28316 .45927 Mdot
.36576 .77102 Mdot
.21989 .49309 Mdot
.46905 .23363 Mdot
.64448 .78168 Mdot
.55071 .30003 Mdot
.40439 .72449 Mdot
.32263 .72028 Mdot
.6287 .28015 Mdot
.40333 .31366 Mdot
.67854 .72931 Mdot
.79041 .61206 Mdot
.30733 .42531 Mdot
.56854 .68624 Mdot
.18143 .64361 Mdot
.50568 .6937 Mdot
.35102 .73625 Mdot
.4894 .51783 Mdot
.78901 .5498 Mdot
.68025 .5296 Mdot
.50108 .79431 Mdot
.43797 .47204 Mdot
.70913 .79096 Mdot
.60904 .37292 Mdot
.43687 .85008 Mdot
.4575 .39033 Mdot
.81798 .41093 Mdot
.23484 .46206 Mdot
.52745 .45685 Mdot
.4373 .497 Mdot
.49441 .27673 Mdot
.52298 .35597 Mdot
.20565 .38849 Mdot
.67128 .27002 Mdot
.32477 .52158 Mdot
.38982 .5575 Mdot
.28324 .28584 Mdot
.33874 .75695 Mdot
.56946 .54727 Mdot
.2296 .50056 Mdot
.49064 .49449 Mdot
.38863 .50897 Mdot
.17571 .44904 Mdot
.33232 .4125 Mdot
.65474 .5851 Mdot
.51981 .73756 Mdot
.47201 .82792 Mdot
.16708 .56429 Mdot
.68751 .29571 Mdot
.65728 .563 Mdot
.45163 .33442 Mdot
.51516 .81039 Mdot
.30213 .74234 Mdot
.36569 .43032 Mdot
.54646 .36125 Mdot
.52099 .71015 Mdot
.45382 .87469 Mdot
.58092 .83476 Mdot
.65812 .78162 Mdot
.40395 .52243 Mdot
.6958 .40464 Mdot
.82948 .51727 Mdot
.34881 .73421 Mdot
.44241 .22745 Mdot
.20726 .48007 Mdot
.49885 .71877 Mdot
.86813 .51604 Mdot
.74571 .36042 Mdot
.32265 .56213 Mdot
.6824 .53268 Mdot
.76996 .61073 Mdot
.41999 .36482 Mdot
.48339 .75884 Mdot
.42393 .56435 Mdot
.48779 .39326 Mdot
.51639 .28255 Mdot
.53145 .36152 Mdot
.35299 .73769 Mdot
.80127 .46398 Mdot
.63588 .53338 Mdot
.3128 .73698 Mdot
.6942 .37524 Mdot
.32881 .66431 Mdot
.35219 .68888 Mdot
.40708 .56659 Mdot
.29165 .48245 Mdot
.52675 .55285 Mdot
.49871 .43664 Mdot
.44534 .45832 Mdot
.72644 .73137 Mdot
.44432 .64379 Mdot
.60218 .40619 Mdot
.73425 .32779 Mdot
.67829 .41736 Mdot
.30251 .78413 Mdot
.27595 .32772 Mdot
.71685 .45597 Mdot
.24763 .50283 Mdot
.34494 .32893 Mdot
.8046 .66295 Mdot
.69535 .71243 Mdot
.48625 .55046 Mdot
.66777 .33002 Mdot
.67044 .36906 Mdot
.25445 .47966 Mdot
.4255 .28787 Mdot
.75614 .47747 Mdot
.503 .17576 Mdot
.36475 .72446 Mdot
.68145 .36979 Mdot
.30307 .56184 Mdot
.59831 .71228 Mdot
.1892 .66945 Mdot
.29247 .4981 Mdot
.64705 .81733 Mdot
.5554 .54675 Mdot
.56272 .81005 Mdot
.17276 .45542 Mdot
.60586 .30424 Mdot
.39135 .53279 Mdot
.38205 .293 Mdot
.55359 .5633 Mdot
.62365 .52244 Mdot
.65095 .42417 Mdot
.35194 .71103 Mdot
.41691 .64212 Mdot
.56033 .76885 Mdot
.48822 .38408 Mdot
.63699 .22202 Mdot
.47782 .19323 Mdot
.62958 .36614 Mdot
.44487 .56383 Mdot
.26381 .6626 Mdot
.56312 .43668 Mdot
.48949 .49428 Mdot
.38173 .78551 Mdot
.81162 .49439 Mdot
.67938 .36902 Mdot
.6449 .78429 Mdot
.37672 .7055 Mdot
.15397 .57186 Mdot
.58234 .70287 Mdot
.51092 .48875 Mdot
.56629 .43651 Mdot
.49963 .26935 Mdot
.74749 .46174 Mdot
.19553 .53128 Mdot
.56433 .74419 Mdot
.58285 .36045 Mdot
.46655 .7184 Mdot
.62806 .54138 Mdot
.31409 .37415 Mdot
.44914 .20523 Mdot
.86395 .53764 Mdot
.71099 .57795 Mdot
.58424 .30516 Mdot
.67533 .33965 Mdot
.50671 .18203 Mdot
.60251 .39101 Mdot
.28241 .59724 Mdot
.80892 .51077 Mdot
.23087 .46633 Mdot
.16708 .6142 Mdot
.18276 .51557 Mdot
.5387 .49846 Mdot
.34056 .43768 Mdot
.60269 .72482 Mdot
.60374 .70982 Mdot
.4708 .47894 Mdot
.55656 .56258 Mdot
.65677 .54586 Mdot
.67595 .295 Mdot
.4746 .24416 Mdot
.65732 .66792 Mdot
.21029 .67598 Mdot
.1545 .56138 Mdot
.30022 .7623 Mdot
.38389 .44034 Mdot
.61436 .4275 Mdot
.54396 .83964 Mdot
.75205 .42656 Mdot
.17566 .55904 Mdot
.69972 .60894 Mdot
.4354 .15473 Mdot
.50906 .82354 Mdot
.29612 .41807 Mdot
.65648 .2456 Mdot
.44724 .28538 Mdot
.18048 .45221 Mdot
.49127 .15221 Mdot
.47958 .657 Mdot
.17579 .43619 Mdot
.73044 .77988 Mdot
.71173 .61306 Mdot
.53171 .35385 Mdot
.66796 .51282 Mdot
.58966 .71895 Mdot
.50063 .16891 Mdot
.6313 .584 Mdot
.35773 .51135 Mdot
.37513 .5713 Mdot
.50847 .72004 Mdot
.51003 .63817 Mdot
.5114 .16845 Mdot
.42864 .74606 Mdot
.40494 .71805 Mdot
.3001 .66598 Mdot
.47318 .81912 Mdot
.75517 .46615 Mdot
.65917 .61079 Mdot
.64918 .45661 Mdot
.3861 .63043 Mdot
.46192 .66956 Mdot
.62304 .63806 Mdot
.39261 .51758 Mdot
.56963 .46916 Mdot
.37832 .83296 Mdot
.28479 .62297 Mdot
.2416 .58667 Mdot
.68226 .35172 Mdot
.51307 .29918 Mdot
.27951 .6957 Mdot
.5533 .26798 Mdot
.53833 .16893 Mdot
.81887 .53974 Mdot
.27223 .72873 Mdot
.55202 .31669 Mdot
.46848 .69218 Mdot
.76248 .69765 Mdot
.44983 .34905 Mdot
.74054 .64088 Mdot
.43535 .8101 Mdot
.54308 .2779 Mdot
.66159 .44334 Mdot
.27161 .41415 Mdot
.33001 .38642 Mdot
.53263 .27893 Mdot
.18771 .41348 Mdot
.30602 .68839 Mdot
.68871 .51251 Mdot
.35177 .78242 Mdot
.34912 .46306 Mdot
.48642 .70246 Mdot
.25934 .40021 Mdot
.48729 .16388 Mdot
.56699 .42161 Mdot
.18955 .65539 Mdot
.46113 .48124 Mdot
.50033 .78418 Mdot
.60316 .62992 Mdot
.78185 .45653 Mdot
.48308 .25403 Mdot
.24791 .4252 Mdot
.58799 .22545 Mdot
.61146 .40504 Mdot
.48362 .20888 Mdot
.41407 .31494 Mdot
.49704 .76639 Mdot
.48225 .62359 Mdot
.63053 .46986 Mdot
.41443 .67979 Mdot
.3909 .23921 Mdot
.58381 .54214 Mdot
.53533 .78541 Mdot
.24754 .46204 Mdot
.729 .64757 Mdot
.71378 .63219 Mdot
.36654 .77312 Mdot
.21436 .53061 Mdot
.46164 .23273 Mdot
.70385 .64075 Mdot
.48949 .31713 Mdot
.74949 .37425 Mdot
.56235 .25095 Mdot
.64708 .60202 Mdot
.28351 .59475 Mdot
.64544 .43862 Mdot
.34457 .76402 Mdot
.68152 .45114 Mdot
.46815 .78855 Mdot
.50569 .4516 Mdot
.25733 .66876 Mdot
.46974 .52179 Mdot
.17478 .45645 Mdot
.44605 .28395 Mdot
.53605 .74216 Mdot
.459 .41662 Mdot
.46232 .44879 Mdot
.60634 .27998 Mdot
.18972 .6221 Mdot
.65436 .26441 Mdot
.65241 .72042 Mdot
.57398 .30653 Mdot
.79205 .59259 Mdot
.17534 .41058 Mdot
.52508 .75125 Mdot
.47284 .47802 Mdot
.53365 .68821 Mdot
.45918 .30557 Mdot
.42578 .25921 Mdot
.30168 .59972 Mdot
.75576 .44794 Mdot
.24736 .56935 Mdot
.35429 .54995 Mdot
.59726 .54576 Mdot
.83015 .49642 Mdot
.33352 .76606 Mdot
.69924 .32855 Mdot
.51596 .46741 Mdot
.34709 .64889 Mdot
.50496 .76997 Mdot
.69599 .19639 Mdot
.42276 .8495 Mdot
.60457 .62982 Mdot
.41765 .51613 Mdot
.5504 .76738 Mdot
.3479 .47358 Mdot
.75942 .48785 Mdot
.36181 .77138 Mdot
.44745 .35818 Mdot
.33216 .61649 Mdot
.43564 .25364 Mdot
.48755 .27025 Mdot
.49167 .79677 Mdot
.40676 .37978 Mdot
.32678 .80515 Mdot
.21098 .47015 Mdot
.48915 .25021 Mdot
.59811 .13137 Mdot
.4853 .22674 Mdot
.70163 .38926 Mdot
.2351 .63069 Mdot
.33147 .79371 Mdot
.40568 .51895 Mdot
.31972 .64344 Mdot
.71596 .63429 Mdot
.54695 .74389 Mdot
.43089 .7107 Mdot
.54639 .22561 Mdot
.49916 .21 Mdot
.50276 .1511 Mdot
.34608 .32703 Mdot
.73602 .72959 Mdot
.72769 .47669 Mdot
.37066 .80204 Mdot
.26784 .33555 Mdot
.86755 .50206 Mdot
.16351 .59633 Mdot
.46601 .73901 Mdot
.53349 .17422 Mdot
.23197 .61535 Mdot
.58823 .76798 Mdot
.81289 .45088 Mdot
.24774 .3543 Mdot
.81663 .51627 Mdot
.33456 .32223 Mdot
.57921 .24192 Mdot
.47153 .71894 Mdot
.77898 .60569 Mdot
.45538 .4809 Mdot
.42165 .81557 Mdot
.61305 .19363 Mdot
.55585 .72866 Mdot
.34178 .61799 Mdot
.59609 .77566 Mdot
.30782 .73905 Mdot
.21067 .60285 Mdot
.46277 .4937 Mdot
.73818 .76741 Mdot
.45552 .83287 Mdot
.56579 .26398 Mdot
.64335 .6185 Mdot
.15583 .60173 Mdot
.4349 .52624 Mdot
.70523 .64888 Mdot
.19201 .45872 Mdot
.41298 .70164 Mdot
.58201 .4634 Mdot
.63452 .56672 Mdot
.68913 .72307 Mdot
.71937 .39832 Mdot
.76994 .61534 Mdot
.35597 .63319 Mdot
.5684 .73369 Mdot
.62076 .20007 Mdot
.55136 .79836 Mdot
.61308 .70584 Mdot
.65735 .43164 Mdot
.35288 .81395 Mdot
.66733 .72094 Mdot
.54371 .52918 Mdot
.6711 .49159 Mdot
.66111 .26677 Mdot
.38291 .26187 Mdot
.66281 .57594 Mdot
.56521 .34052 Mdot
.4953 .71133 Mdot
.34047 .7256 Mdot
.71042 .66933 Mdot
.83099 .6991 Mdot
.16897 .46124 Mdot
.61802 .36016 Mdot
.7385 .62555 Mdot
.38968 .56678 Mdot
.30647 .76423 Mdot
.34835 .29898 Mdot
.35102 .68171 Mdot
.71887 .28309 Mdot
.58587 .75334 Mdot
.55495 .64539 Mdot
.20176 .40895 Mdot
.17319 .60649 Mdot
.63959 .20445 Mdot
.18146 .64231 Mdot
.5337 .64703 Mdot
.52858 .59231 Mdot
.86312 .39643 Mdot
.24334 .69978 Mdot
.51823 .62827 Mdot
.68948 .27866 Mdot
.59582 .39094 Mdot
.62462 .58115 Mdot
.43488 .25574 Mdot
.51561 .69372 Mdot
.42365 .7148 Mdot
.22366 .70007 Mdot
.69211 .37564 Mdot
.39142 .52582 Mdot
.45391 .34116 Mdot
.43928 .49109 Mdot
.65293 .57228 Mdot
.43738 .40658 Mdot
.42162 .72233 Mdot
.42417 .53249 Mdot
.48373 .32432 Mdot
.48235 .64538 Mdot
.27355 .26954 Mdot
.53332 .52837 Mdot
.53053 .50247 Mdot
.69052 .61617 Mdot
.75631 .35711 Mdot
.43189 .74694 Mdot
.40417 .74108 Mdot
.17861 .43006 Mdot
.26855 .24325 Mdot
.27471 .52039 Mdot
.63235 .69134 Mdot
.58732 .43387 Mdot
.74827 .44936 Mdot
.67857 .50434 Mdot
.49853 .41157 Mdot
.41891 .26541 Mdot
.56063 .66794 Mdot
.58367 .71305 Mdot
.48457 .37371 Mdot
.41972 .86034 Mdot
.6378 .59228 Mdot
.71805 .50378 Mdot
.18798 .59058 Mdot
.33184 .66474 Mdot
.59047 .49331 Mdot
.55001 .56834 Mdot
.66431 .32148 Mdot
.42671 .53505 Mdot
.63046 .71903 Mdot
.33944 .68046 Mdot
.31709 .76608 Mdot
.56851 .5012 Mdot
.70642 .49695 Mdot
.58919 .60403 Mdot
.38851 .66436 Mdot
.54254 .37896 Mdot
.67856 .75203 Mdot
.47535 .62402 Mdot
.1697 .55443 Mdot
.38402 .70154 Mdot
.41796 .70422 Mdot
.68512 .46824 Mdot
.42449 .8382 Mdot
.59341 .28418 Mdot
.70074 .47981 Mdot
.66874 .30201 Mdot
.2849 .38664 Mdot
.44758 .75178 Mdot
.27105 .45831 Mdot
.65761 .66646 Mdot
.59334 .40374 Mdot
.23258 .72242 Mdot
.69952 .70995 Mdot
.45695 .43513 Mdot
.29685 .42777 Mdot
.74805 .38426 Mdot
.44312 .49391 Mdot
.55648 .12078 Mdot
.35996 .28501 Mdot
.33255 .80878 Mdot
.32608 .70273 Mdot
.58579 .433 Mdot
.51637 .27627 Mdot
.51534 .57158 Mdot
.34257 .48631 Mdot
.31122 .7656 Mdot
.54641 .69043 Mdot
.55977 .24279 Mdot
.63384 .60513 Mdot
.62193 .31874 Mdot
.5961 .71555 Mdot
.34891 .43572 Mdot
.34597 .51872 Mdot
.67988 .28683 Mdot
.21051 .61911 Mdot
.4281 .53585 Mdot
.42063 .17132 Mdot
.45391 .82463 Mdot
.21281 .66042 Mdot
.29885 .43529 Mdot
.81824 .4018 Mdot
.68244 .34085 Mdot
.60744 .71134 Mdot
.45317 .42241 Mdot
.6489 .73252 Mdot
.53655 .27606 Mdot
.34119 .72018 Mdot
.49235 .3157 Mdot
.5542 .45473 Mdot
.4584 .1058 Mdot
.46199 .73235 Mdot
.69975 .3391 Mdot
.52842 .25397 Mdot
.20051 .65663 Mdot
.40217 .5927 Mdot
.22642 .32076 Mdot
.25037 .37038 Mdot
.64869 .56371 Mdot
.79669 .44676 Mdot
.59481 .79251 Mdot
.36165 .40484 Mdot
.76915 .70348 Mdot
.21965 .49629 Mdot
.46373 .68012 Mdot
.24924 .41999 Mdot
.68067 .41235 Mdot
.59707 .39601 Mdot
.28259 .30908 Mdot
.33809 .21866 Mdot
.65934 .68482 Mdot
.28799 .7338 Mdot
.82535 .6095 Mdot
.35619 .70688 Mdot
.27285 .74038 Mdot
.4022 .41434 Mdot
.63654 .33921 Mdot
.42224 .7415 Mdot
.3607 .65479 Mdot
.34553 .46667 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0V_ooool2o`00
0:gooooo000Looooo`;o0000Voooool2o`000:gooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0TOooool2o`000;Kooooo000Looooo`03o`000?oooooo
oooo097ooooo0_l00005ooooo`;o0000[oooool001cooooo00?o0000ooooooooool0V?ooool2o`00
0003ooooool0003o00000:cooooo000Looooo`03o`000?oooooooooo09_ooooo0_l0000:ooooo`;o
0000X?ooool001cooooo00?o0000ooooooooool0P?ooool2o`0002Gooooo0_l00003ooooo`;o0000
Voooool001cooooo00?o0000ooooooooool0P?ooool2o`0002[ooooo0_l00003ooooo`;o0000U_oo
ool001cooooo00?o0000ooooooooool0/Oooool2o`0009Kooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0_oooool2o`0008Sooooo000Looooo`03o`00
0?oooooooooo0;oooooo0_l00028ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`2Aooooo`;o0000]_ooool001cooooo00?o0000ooooooooool0
TOooool2o`0003Cooooo0ol0001oooooo`007?ooool2o`00077ooooo0_l0000Zooooo`;o00000_oo
ool2o`0002Gooooo0ol0001oooooo`007?ooool00ol0003oooooooooo`1`ooooo`;o00006?ooool2
o`00013ooooo0_l00002ooooo`;o0000Yoooool001cooooo00?o0000ooooooooool0R_ooool2o`00
00_ooooo0_l0002`ooooo`007?ooool00ol0003oooooooooo`2Eooooo`Co0000/?ooool001cooooo
00?o0000ooooooooool0UOooool2o`0000Cooooo0_l0000=ooooo`;o0000WOooool001cooooo00?o
0000ooooooooool0I_ooool2o`0003?ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_oo
ool2o`0000;ooooo0ol0002Looooo`007?ooool00ol0003oooooooooo`1Vooooo`;o00007Oooool2
o`0001Sooooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool2o`0009cooooo000Loooo
o`03o`000?oooooooooo08Gooooo0_l0000Fooooo`;o00002oooool2o`0000;ooooo0_l00005oooo
o`;o00000_ooool2o`0008kooooo000Looooo`03o`000?oooooooooo09gooooo0_l000000ooooooo
0000o`000008ooooo`;o00000_ooool2o`0000Gooooo0_l00002ooooo`;o0000S_ooool001cooooo
00?o0000ooooooooool0Goooool2o`0003Oooooo0_l00006ooooo`?o00004Oooool2o`0001Kooooo
0_l0001kooooo`007?ooool00ol0003oooooooooo`1Oooooo`;o0000=oooool2o`000003ooooool0
003o000000Cooooo0ol0000@ooooo`;o00001oooool2o`0000gooooo0_l0001kooooo`007?ooool0
0ol0003oooooooooo`2Kooooo`;o00001?ooool3o`0001Wooooo0_l0000@ooooo`;o0000N?ooool0
01cooooo00?o0000ooooooooool0UOooool2o`0000Cooooo0_l0000booooo`;o0000N?ooool00006
ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooo
oooo08kooooo1?l00003ooooo`Co00000oooool2o`00023ooooo0_l00003ooooo`;o0000Q?ooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A006ooooo`03o`000?oooooooooo08kooooo1?l00005ooooo`;o00000oooool2o`0000;ooooo
0_l0000Looooo`Co000000?oooooo`000?l000006Oooool2o`0006Wooooo00000ooooooo410@oooo
o`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003ooooooooo
o`1Eooooo`;o0000BOooool2o`0000?ooooo0_l0000Fooooo`;o000000?oooooo`000?l000007?oo
ool2o`0006Wooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RH
ob4Q8Oo^k^h01_ooool3o`0005Gooooo0_l0000Kooooo`?o0000<?ooool2o`0000Gooooo0_l0000<
ooooo`;o000000?oooooo`000?l000001Oooool4o`0000oooooo0_l0001`ooooo`0000?oooooo`00
0?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000oooo
ooooool0L_ooool5o`0001Oooooo0_l0000Looooo`;o00003?ooool2o`0000Sooooo1?l00004oooo
o`;o00002Oooool2o`00073ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1eooooo`;o00005oooool2o`0000Wo
oooo0_l00004ooooo`;o00002oooool2o`000003ooooool0003o000001Cooooo1?l00002ooooo`?o
0000Noooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So
410@00Kooooo00?o0000ooooooooool0Loooool2o`0000?ooooo0_l0000Oooooo`;o00000oooool3
o`0000_ooooo0_l000001?oooooo0000o`000?l00008ooooo`;o00002oooool2o`0000;ooooo0_l0
000=ooooo`;o0000KOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@
o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0Joooool2o`0000Kooooo0_l00003ooooo`;o
00001Oooool2o`000003ooooool0003o000001[ooooo0_l0000<ooooo`;o00000_ooool2o`0000So
oooo0_l0000Booooo`;o00002_ooool2o`0006gooooo000Looooo`03o`000?oooooooooo04gooooo
0_l0000Looooo`;o00004_ooool2o`000003ooooool0003o000000[ooooo0_l00007ooooo`;o0000
1_ooool3o`0000[ooooo0_l0000Pooooo`;o0000NOooool001cooooo00?o0000ooooooooool0COoo
ool2o`0001_ooooo1?l0000Pooooo`;o00001oooool3o`0000Cooooo1?l0000=ooooo`;o00000ooo
ool3o`0000Cooooo0_l000001?oooooo0000o`000?l00028ooooo`007?ooool00ol0003ooooooooo
o`1Zooooo`Co00003?ooool2o`0000Cooooo0_l00005ooooo`;o00003oooool2o`0000Cooooo1?l0
000<ooooo`Go000000Goooooo`000?l0003o0000ooooo`05o`000004ooooool0003o0000o`0000[o
oooo0_l00003ooooo`;o00000_ooool2o`0007?ooooo000Looooo`03o`000?oooooooooo06Oooooo
0_l00007ooooo`;o00002?ooool2o`000004ooooool0003o0000ooooo`;o00001Oooool2o`0000?o
oooo0_l0000:ooooo`Co00000_ooool4o`0000cooooo0_l000000ooooooo0000o`000005ooooo`Go
00001Oooool2o`0000Oooooo0_l00003ooooo`;o00000_ooool2o`0007?ooooo000Looooo`03o`00
0?oooooooooo06Gooooo1?l00007ooooo`;o00002?ooool2o`000003ooooool0003o000000gooooo
0_l00007ooooo`;o000000?oooooo`000?l000000_l00002ooooo`?o00003Oooool2o`0000_ooooo
0_l00005ooooo`;o00009?ooool2o`0005oooooo000Looooo`03o`000?oooooooooo06Gooooo0_l0
0007ooooo`;o00001Oooool2o`0000Oooooo0_l000000ooooooo0000o`000003o`000003ooooool0
003o000000Wooooo0_l000000ooooooo0000o`000003ooooo`;o00000_ooool3o`0001Gooooo0_l0
0007ooooo`?o00009_ooool2o`0005oooooo000Looooo`03o`000?oooooooooo06;ooooo0_l00008
ooooo`Co00001Oooool4o`0000Cooooo2Ol000001?oooooo0000o`000?l00008ooooo`;o000000?o
ooooo`000?l000001oooool2o`0001Kooooo0_l00007ooooo`?o00001?ooool2o`0000?ooooo1Ol0
001iooooo`007?ooool00ol0003oooooooooo`1Rooooo`;o00001_ooool4o`0000Sooooo0ol00002
ooooo`_o00000_ooool2o`0000_ooooo0_l0000Dooooo`;o00001?ooool2o`0001?ooooo0_l00003
ooooo`Go000000?oooooo`000?l000004_ooool2o`0006;ooooo000Looooo`03o`000?oooooooooo
06;ooooo0_l00006ooooo`;o00003oooool2o`000003ooooool0003o000000Go00004?ooool2o`00
00[ooooo0_l00008ooooo`?o00000oooool3o`0000Cooooo0_l00009ooooo`;o00003?ooool2o`00
00Kooooo0_l0000:ooooo`;o0000H_ooool001cooooo00?o0000ooooooooool0E?ooool2o`0002Go
oooo3?l0000?ooooo`?o00002?ooool2o`0000Wooooo0_l00003ooooo`?o00001?ooool2o`0000Wo
oooo0_l0000<ooooo`;o00001_ooool2o`0006kooooo000Looooo`03o`000?oooooooooo05Cooooo
0_l00009ooooo`;o00006_ooool<o`0000oooooo0ol0000?ooooo`;o00001oooool4o`0000;ooooo
0_l0000<ooooo`;o00002_ooool2o`0001Gooooo0_l00002ooooo`;o0000Foooool001cooooo0_l0
001Pooooo`;o00003_ooool2o`0000_ooooo3Ol0000Booooo`;o00002oooool2o`0000Kooooo0_l0
00001?oooooo0000o`000?ooool3o`0000cooooo0_l0000;ooooo`Co00004_ooool2o`0000;ooooo
0_l0001Kooooo`007?ooool00ol0003oooooooooo`1Sooooo`Co00002?ooool2o`0000_ooooo3Ol0
00000ooooooo0000o`000006ooooo`Co00000oooool4o`0000_ooooo0_l00006ooooo`Go000000?o
ooooo`000?l000006Oooool5o`0000Kooooo0_l0001[ooooo`007?ooool00ol0003oooooooooo`1K
ooooo`;o00001_ooool4o`0001;ooooo0_l000000ooooooo0000o`000004o`000003ooooool0003o
000000Co000000?oooooo`000?l000001_ooool4o`0000?ooooo0_l0000=ooooo`Co00001_ooool2
o`0000?ooooo0_l0000Hooooo`?o00002?ooool2o`00017ooooo0_l0001Hooooo`007?ooool00ol0
003oooooooooo`1Kooooo`;o00003?ooool2o`0000kooooo0_l000000ooooooo0000o`00000;o`00
0003ooooool0003o000001kooooo0ol0000:ooooo`;o00001?ooool2o`0001?ooooo0_l0000Koooo
o`Co0000E_ooool001cooooo00?o0000ooooooooool0JOooool2o`0000kooooo0_l00002ooooo`oo
00001oooool4o`0000?ooooo0_l00005ooooo`;o00001oooool3o`0000;ooooo0_l00003ooooo`;o
000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000oooooo0_l0000Nooooo`;o
0000E_ooool001cooooo00?o0000ooooooooool0Doooool2o`000003ooooool0003o0000027ooooo
0_l00002ooooo`oo00001oooool4o`0000?ooooo0_l00005ooooo`;o00003?ooool2o`0000?ooooo
0_l000000ooooooo0000o`000007ooooo`;o00002oooool8o`0000_ooooo0_l0000>ooooo`;o0000
Eoooool001cooooo00?o0000ooooooooool0?Oooool2o`0001Cooooo1Ol0000Uooooo`_o00004ooo
ool2o`0000;ooooo0_l000000ooooooo0000o`00000:ooooo`Co00006oooool4o`0000;ooooo0_l0
00000ooooooo0000o`000008ooooo`Co00003?ooool2o`0005Oooooo000Looooo`03o`000?oooooo
oooo03gooooo0_l0000Eooooo`Co00009_ooool:o`0000kooooo0_l00003ooooo`;o00000_ooool2
o`000003ooooool0003o000000Wooooo1_l00003ooooo`;o00001?ooool2o`0001Sooooo0_l0000:
ooooo`;o0000IOooool001cooooo00?o0000ooooooooool0E?ooool5o`0000_ooooo0_l0000Joooo
o`Oo00003oooool2o`0000Gooooo0ol00004ooooo`;o00001Oooool4o`0000;ooooo0_l00003oooo
o`;o00001?ooool2o`0001Gooooo0_l00003ooooo`;o00005?ooool2o`0005Wooooo000Looooo`03
o`000?oooooooooo05Oooooo1?l00008ooooo`?o00006oooool6o`0000;ooooo0_l0000Booooo`?o
00001?ooool2o`0000?ooooo1_l0000>ooooo`;o00000_ooool2o`0000Gooooo0_l000000ooooooo
0000o`000006ooooo`Co000000?oooooo`000?l000000_ooool2o`00013ooooo0_l0001Iooooo`00
7?ooool00ol0003oooooooooo`1Iooooo`;o00002?ooool2o`0000Oooooo0_l00005ooooo`;o0000
3?ooool5o`0000?ooooo0_l0000Iooooo`;o00000oooool2o`0000;ooooo0_l00007ooooo`;o0000
0_ooool2o`000003ooooool0003o000000;ooooo0_l00005ooooo`;o000000?oooooo`000?l00000
2?ooool2o`0000Gooooo0_l00007ooooo`?o0000HOooool001cooooo00?o0000ooooooooool0F?oo
ool2o`0001;ooooo0_l00003ooooo`Ko00003?ooool2o`0000Gooooo0_l000001?oooooo0000o`00
0?l0000Dooooo`;o00000oooool2o`0000_ooooo0_l00002ooooo`;o000000?oooooo`000?l00000
0_l00004ooooo`;o000000Coooooo`000?l0003o00001Oooool2o`0000Sooooo0_l00009ooooo`?o
0000HOooool001cooooo00?o0000ooooooooool0F?ooool2o`0001Oooooo1_l0000?ooooo`;o0000
0_ooool2o`000004ooooool0003o0000o`0000[ooooo0_l000000ooooooo0000o`000006ooooo`;o
00000_ooool2o`0000Oooooo0_l00009ooooo`Ko00000_ooool2o`0000;ooooo0ol00004ooooo`Co
00001Oooool3o`0006gooooo000Looooo`03o`000?oooooooooo067ooooo0_l0000@ooooo`;o0000
4Oooool2o`0000;ooooo0_l0000>ooooo`;o000000?oooooo`000?l000001_ooool2o`0000[ooooo
0ol0000=ooooo`;o00001oooool3o`0000Cooooo0ol00005ooooo`;o00002Oooool2o`0006?ooooo
000Looooo`03o`000?oooooooooo067ooooo0_l00002ooooo`;o00004Oooool2o`00013ooooo0_l0
0008ooooo`;o00003Oooool4o`0000Sooooo1?l0000;ooooo`;o00001oooool2o`0000;ooooo0_l0
0005ooooo`;o00001?ooool2o`0000[ooooo0_l00008ooooo`;o0000FOooool001cooooo00?o0000
ooooooooool0IOooool2o`00017ooooo0ol0000Eooooo`;o00000_ooool2o`0000Wooooo0ol00000
0ooooooo0000o`000002o`0000Sooooo1?l0000;ooooo`;o00000_ooool2o`0000?ooooo1_l0000;
ooooo`;o00000_ooool2o`0000gooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool2
o`00057ooooo000Looooo`;o0000A_ooool2o`0002Kooooo0_l0000:ooooo`;o00003Oooool2o`00
00Kooooo0_l0000=ooooo`?o000000?oooooo`000?l000000_l00008ooooo`Co00003oooool2o`00
00Gooooo1?l0000?ooooo`;o00001oooool2o`0000Cooooo0_l00005ooooo`;o00000_ooool2o`00
057ooooo000Looooo`03o`000?oooooooooo03Cooooo0_l0000?ooooo`;o00009_ooool3o`0001So
oooo0_l00004ooooo`;o00000oooool2o`0000[ooooo0_l00002ooooo`;o000000?oooooo`000?l0
00001oooool4o`0000kooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o
00000_ooool2o`0000kooooo0_l0000<ooooo`;o0000E?ooool001cooooo00?o0000ooooooooool0
=?ooool2o`0001[ooooo0_l00004ooooo`;o00005_ooool2o`0001kooooo0_l000000ooooooo0000
o`000002o`00017ooooo0_l000000ooooooo0000o`000004ooooo`?o00001Oooool2o`000003oooo
ool0003o000000Gooooo0ol000001Ooooooo0000o`000?l0003ooooo00?o00000_ooool2o`000003
ooooool0003o000000;ooooo0_l0000Looooo`;o0000E?ooool001cooooo00?o0000ooooooooool0
B_ooool2o`0000Cooooo0_l00004ooooo`Co00008oooool2o`0001;ooooo0_l00005ooooo`;o0000
2?ooool4o`0000?ooooo0_l00004ooooo`Oo000000Coooooo`000?l0003ooooo0ol00003ooooo`Co
000000Coooooo`000?l0003ooooo1?l00002ooooo`;o00005oooool2o`0000?ooooo0_l00007oooo
o`;o0000D_ooool001cooooo00?o0000ooooooooool0B_ooool2o`0000cooooo0_l00006ooooo`;o
00006Oooool8o`0000_ooooo1?l00004ooooo`Co00002?ooool4o`0000cooooo1?l00005ooooo`Co
000000Coooooo`000?l0003o00000_ooool2o`000003ooooool0003o000000Oooooo0_l0000Doooo
o`;o00000oooool4o`0000Gooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`1Oooooo`?o
00006Oooool2o`0000;ooooo1_l00005ooooo`;o00000_ooool4o`0000Cooooo0_l000001?oooooo
0000o`000?ooool2o`0000Wooooo0_l00002ooooo`;o00000oooool2o`0000[ooooo1Ol0000<oooo
o`;o000000?oooooo`000?l000000_l0000Booooo`;o00001_ooool2o`0005Wooooo000Looooo`03
o`000?oooooooooo05oooooo0_l0000Rooooo`;o00001Oooool2o`0000gooooo1Ol00009ooooo`?o
000000Coooooo`000?l0003ooooo1?l00009ooooo`?o000000?oooooo`000?l000001Oooool2o`00
00Gooooo0_l000000ooooooo0000o`000004o`0000;ooooo0_l0000;ooooo`?o00001Oooool2o`00
00Oooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`16ooooo`;o000000?oooooo`000?l0
00000oooool2o`0001Wooooo0_l0000Looooo`;o00002Oooool2o`0000Kooooo0ol000000ooooooo
0000o`000007ooooo`?o00001?ooool2o`0000Sooooo1Ol00002ooooo`Co00000oooool2o`000003
ooooool0003o000000;ooooo0_l00003ooooo`Go000000?oooooo`000?l000000oooool2o`0000Ko
oooo0_l00002ooooo`?o000000?oooooo`000?l000001oooool2o`00057ooooo000Looooo`03o`00
0?oooooooooo04Gooooo0ol000000ooooooo0000o`000003ooooo`;o00006Oooool2o`00017ooooo
0_l00009ooooo`;o00002Oooool2o`0000?ooooo1Ol00002ooooo`;o00001?ooool2o`0000[ooooo
0_l00005ooooo`Ko00001?ooool2o`0000Kooooo0_l00002ooooo`;o00000oooool5o`0000Kooooo
0_l00007ooooo`;o000000Coooooo`000?l0003o00004_ooool2o`0004Wooooo000Looooo`03o`00
0?oooooooooo04Cooooo0ol0000?ooooo`;o00002oooool3o`0000Kooooo0ol0000=ooooo`;o0000
2Oooool2o`0000kooooo1?l00009ooooo`;o00002_ooool2o`0000Cooooo1ol00004ooooo`;o0000
4Oooool2o`0000Gooooo1_l00004ooooo`?o000000?oooooo`000?l000000_l0000<ooooo`;o0000
0oooool2o`0004Wooooo000Looooo`03o`000?oooooooooo04Cooooo0_l0000@ooooo`;o00001_oo
ool2o`0000?ooooo0ol00006ooooo`?o00003?ooool2o`0000[ooooo0_l0000Nooooo`;o00003Ooo
ool7o`0000Cooooo0_l0000Booooo`;o00001?ooool6o`0000Cooooo0ol000000ooooooo0000o`00
0002o`0000cooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00002Oooool2
o`0000kooooo0_l0000;ooooo`;o00004Oooool5o`0000Wooooo0_l00008ooooo`?o00003oooool3
o`0000Wooooo0_l00006ooooo`;o00001oooool4o`0000?ooooo1Ol0000;ooooo`;o0000Foooool0
01cooooo00?o0000ooooooooool0Doooool2o`0000Oooooo1?l0000>ooooo`;o00006Oooool2o`00
00?ooooo1Ol00009ooooo`;o00002?ooool2o`0000Sooooo0_l00002ooooo`;o00000_ooool2o`00
00[ooooo0_l00006ooooo`?o00002?ooool2o`0000kooooo0_l00003ooooo`;o0000Foooool001co
oooo00?o0000ooooooooool0;?ooool2o`0001Kooooo0_l0000<ooooo`;o00002?ooool4o`0002So
oooo2_l0000Jooooo`;o00000_ooool2o`0000;ooooo0_l00002ooooo`;o00004Oooool4o`0000Wo
oooo1?l00004ooooo`;o00001Oooool2o`0000Sooooo0_l0001Fooooo`007?ooool00ol0003ooooo
ooooo`0/ooooo`;o00004oooool2o`000003ooooool0003o000000Wooooo0_l000000ooooooo0000
o`00000dooooo`_o000000?oooooo`000?l000001?ooool2o`0000?ooooo0_l0000;ooooo`;o0000
00?oooooo`000?l000000oooool2o`000003ooooool0003o000000Co00003_ooool2o`0000;ooooo
0_l00003ooooo`?o000000?oooooo`000?l000001?l00002ooooo`;o00002_ooool2o`0000?ooooo
0_l00008ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0@Oooool2o`0000cooooo1?l0
000;ooooo`;o0000:oooool;o`0000Cooooo0ol00002ooooo`;o00001?ooool2o`0000Sooooo0_l0
0006ooooo`Ko00004_ooool2o`0000?ooooo0ol000000ooooooo0000o`000002ooooo`?o00001_oo
ool2o`000004ooooool0003o0000ooooo`?o00003Oooool4o`0000Cooooo0_l00014ooooo`007?oo
ool2o`0004kooooo0_l00002ooooo`;o00002oooool2o`0002_ooooo3Ol00003ooooo`;o00002?oo
ool2o`000003ooooool0003o000000_ooooo0_l00004ooooo`;o00001Oooool2o`000003ooooool0
003o000000;ooooo0ol00009ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`00
0006ooooo`;o000000Coooooo`000?l0003ooooo0_l0000@ooooo`?o00000oooool2o`0004Cooooo
000Looooo`03o`000?oooooooooo04gooooo1_l0000Zooooo`;o00001Oooool2o`000003ooooool0
003o000000Wo000000?oooooo`000?l000000ol00008ooooo`;o00001_ooool4o`0000Kooooo0_l0
00000ooooooo0000o`000003ooooo`?o00001Oooool2o`000003ooooool0003o000000;ooooo2Ol0
00001?oooooo0000o`000?l00004ooooo`Go00004oooool3o`0000Wooooo0_l00019ooooo`007?oo
ool00ol0003oooooooooo`0[ooooo`;o00008?ooool5o`0002[ooooo0ol00005ooooo`;o000000?o
ooooo`000?l000002Ol000000ooooooo0000o`000004o`000004ooooool0003o0000o`0000?ooooo
0_l00004ooooo`;o000000Coooooo`000?l0003o00000oooool5o`0000Kooooo0_l00005ooooo`;o
00000_oooolCo`0000;ooooo0ol0000Aooooo`;o00000_ooool3o`0000?ooooo0_l0001?ooooo`00
7?ooool00ol0003oooooooooo`0[ooooo`;o00008?ooool2o`0001cooooo0_l0000?ooooo`;o0000
1Oooool3o`000003ooooool0003o0000013o000000Coooooo`000?l0003o00001oooool4o`0000Ko
oooo1?l0000:ooooo`;o00000oooool2o`0000;ooooo6?l0000:ooooo`;o00001Oooool2o`0000;o
oooo0ol00003ooooo`;o0000Coooool001cooooo00?o0000ooooooooool0COooool2o`0001cooooo
0_l0000Cooooo`;o000000?oooooo`000?l000005?l0000;ooooo`;o00000oooool2o`0000?ooooo
0_l0000:ooooo`Co000000?oooooo`000?l000000oooool4o`000003ooooool0003o000000oo0000
1?ooool3o`0000Kooooo0_l00005ooooo`;o00000_ooool3o`0000[ooooo0_l00018ooooo`007?oo
ool00ol0003oooooooooo`10ooooo`;o000000?oooooo`000?l000001_ooool4o`00037ooooo6Ol0
000@ooooo`;o00000oooool3o`0000Oooooo1_l000000ooooooo0000o`000003ooooo`Co000000?o
ooooo`000?l000003_l00005ooooo`?o00001?ooool2o`0000Oooooo0_l0000?ooooo`;o0000B?oo
ool001cooooo00?o0000ooooooooool0@?ooool2o`000003ooooool0003o000000Kooooo0_l0000;
ooooo`;o00004?ooool2o`000003ooooool0003o000001?ooooo6_l0000Cooooo`;o00001oooool2
o`000003ooooool0003o000000;o00002Oooool:o`000003ooooool0003o000000Ko000000Cooooo
o`000?l0003o00001_ooool2o`0000gooooo0_l0000:ooooo`;o0000Aoooool001cooooo00?o0000
ooooooooool0:?ooool2o`0001Kooooo0_l000001?oooooo0000o`000?l00008ooooo`;o00002?oo
ool2o`00013ooooo0_l000000ooooooo0000o`00000>ooooo`;o000000?oooooo`000?l000000_oo
oolHo`0001oooooo1?l00009oooooaOo00001oooool2o`0000;ooooo0_l00008ooooo`;o00002_oo
ool2o`0004Oooooo000Looooo`03o`000?oooooooooo02Sooooo0_l0000Fooooo`;o00000_ooool2
o`000003ooooool0003o000000Gooooo0_l00008ooooo`;o00002?ooool4o`0001Oooooo0_l00000
0ooooooo0000o`000002oooooaWo00002Oooool2o`0000?ooooo0_l0000Eooooo`;o00000_oooolJ
o`0000Kooooo0ol000000ooooooo0000o`000004ooooo`;o0000Eoooool001cooooo00?o0000oooo
ooooool0Aoooool2o`0000oooooo0_l00008ooooo`Co00006ooooolLo`0000Wooooo0_l00003oooo
o`;o00003oooool2o`0000Cooooo0_l000000ooooooo0000o`00000Do`000003ooooool0003o0000
00Co00001Oooool2o`000003ooooool0003o000000Cooooo0_l0000Dooooo`;o0000@Oooool001co
oooo00?o0000ooooooooool0@oooool2o`0001Oooooo0_l00002ooooo`;o00006_ooool2o`0000;o
oooo7_l0000>ooooo`?o00003Oooool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l0
00005Ol000000ooooooo0000o`000008ooooo`;o00006_ooool2o`00047ooooo000Looooo`03o`00
0?oooooooooo04?ooooo0_l0000Gooooo`;o00000_ooool2o`000003ooooool0003o000001Oooooo
0_l00002ooooo`;o000000?oooooo`000?l000001?l000000ooooooo0000o`00000Bo`0000Sooooo
0ol00003ooooo`?o00001?ooool2o`0000_ooooo7Ol00002ooooo`;o00003?ooool4o`0005Sooooo
000Looooo`03o`000?oooooooooo02Gooooo0_l0000Fooooo`;o00000oooool2o`0000Gooooo0_l0
000>ooooo`;o00002?ooool2o`0000;ooooo0_l0000Jooooo`Ko000000?oooooo`000?l000004Ol0
0009ooooo`Go000000Coooooo`000?l0003o00000_ooool4o`0000[ooooo0_l000000ooooooo0000
o`00000Eo`0000?ooooo0_l000000ooooooo0000o`000005ooooo`Co00000oooool4o`0005Sooooo
000Looooo`03o`000?oooooooooo02Gooooo0_l0000Booooo`;o000000?oooooo`000?l000001_l0
0005ooooo`;o00003_ooool2o`0000cooooo0_l0000NoooooaGo00002oooool4o`000004ooooool0
003o0000o`0000;ooooo0_l00004ooooo`;o00001Oooool>o`000003ooooool0003o000000_o0000
00?oooooo`000?l000001Ol00004ooooo`Co00001Oooool2o`0005Sooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003o
ooooooooo`0gooooo`Co000000Coooooo`000?l0003ooooo1?l00002ooooo`;o00000_ooool2o`00
0003ooooool0003o000003Oooooo6?l00009ooooo`Co00002?ooool2o`0000?ooooo0_l00004oooo
oaSo000000?oooooo`000?l000001Ol000000ooooooo0000o`000002o`0000gooooo0_l0001Hoooo
o`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo03Oooooo0_l00006ooooo`;o00001?ooool2o`0000;ooooo0_l00000
0ooooooo0000o`00000fooooo`Wo000000?oooooo`000?l000002_l000000ooooooo0000o`000002
ooooo`;o00001Oooool2o`0000[ooooo0_l00009ooooo`Go00000_oooolLo`0000_ooooo0_l0000K
ooooo`;o00002oooool2o`0003;ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo
00Wooooo1Ol00006ooooo`03o`000?oooooooooo03_ooooo0_l00002ooooo`Co00003_ooool2o`00
017ooooo1?l00004ooooo`;o00003_ooool4o`0000?ooooo2_l000000ooooooo0000o`00000:o`00
0003ooooool0003o000000Co00004oooool2o`0000Sooooo0_l000000ooooooo0000o`00000Ko`00
00?ooooo0ol00002ooooo`;o00000oooool2o`0001_ooooo0_l00003ooooo`;o00001_ooool2o`00
03;ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoo
oooo00001oooool3o`0003_ooooo0_l00002ooooo`Co00002oooool2o`000003ooooool0003o0000
017ooooo1?l00004ooooo`;o00003_ooool6o`000003ooooool0003o000000So000000?oooooo`00
0?l000002_l000000ooooooo0000o`000002o`0001Gooooo0_l00008ooooo`;o000000Coooooo`00
0?l0003o00000_oooolFo`000003ooooool0003o000000;ooooo0ol00002ooooo`;o00000oooool2
o`0000?ooooo0_l0000Dooooo`;o00001Oooool2o`0003[ooooo00000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`0Q
ooooo`?o00006oooool2o`0000cooooo0ol0000<ooooo`;o00005?ooool2o`0000cooooo0_l00002
oooooa?o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o00005Oooool2o`0000?ooooo0_l0
00000ooooooo0000o`00000Jo`000004ooooool0003o0000o`00013ooooo1?l00002ooooo`;o0000
3_ooool2o`00047ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?o
MgMgolc<c?l000001oooool00ol0003oooooooooo`0Qooooo`?o00006_ooool3o`0000Kooooo0_l0
0004ooooo`;o00003Oooool2o`0000Wooooo0_l00006ooooo`;o000000?oooooo`000?l000002?oo
ool2o`0000;ooooo0_l00002oooooa?o00000_ooool4o`0000Cooooo0_l0000Eooooo`;o00000ooo
ool?o`000003ooooool0003o000000Go000000?oooooo`000?l000001Ol00002ooooo`;o00000_oo
ool2o`0000Oooooo0_l00005ooooo`;o00000_ooool2o`00057ooooo00001_ooooooMgMgoiRHV?oo
ooooV9RHogMgM`cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0Rooooo`;o0000
3oooool4o`0000Cooooo0_l000000ooooooo0000o`000007ooooo`;o00007_ooool3o`0000Gooooo
0_l0000;ooooo`;o00000_ooool2o`0000Cooooo4_l000000ooooooo0000o`000002o`000003oooo
ool0003o000000Wooooo0_l0000>ooooo`;o00001?oooolMo`000003ooooool0003o000000;o0000
00?oooooo`000?l000001Oooool4o`0000;ooooo0_l00006ooooo`Co00002oooool2o`00047ooooo
00001_ooooook^k^oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003o
ooooooooo`0cooooo`Co00000_ooool4o`0000kooooo0ol00007ooooo`;o00004Oooool2o`0001Go
oooo0_l00005ooooo`go000000?oooooo`000?l000000_l000000ooooooo0000o`000003ooooo`;o
00002Oooool2o`0000kooooo8ol000000ooooooo0000o`000002o`000003ooooool0003o000000Go
oooo0_l00004ooooo`;o00001_ooool4o`0000_ooooo0_l00011ooooo`007?ooool00ol0003ooooo
ooooo`0iooooo`;o00004?ooool3o`0000Oooooo0_l00004ooooo`?o00001?ooool2o`0001_ooooo
0_l00006ooooo`Oo00000oooool5o`0000kooooo0ol0000@ooooo`;o00000_ooool4o`0000;ooooo
3_l000000ooooooo0000o`00000:o`000003ooooool0003o000000?ooooo0_l0000Cooooo`;o0000
D?ooool001cooooo00?o0000ooooooooool0>Oooool2o`00017ooooo0ol0000<ooooo`?o00001?oo
ool2o`0000?ooooo0_l000000ooooooo0000o`00000Iooooo`Go00000_ooool2o`0000?ooooo1?l0
0004ooooo`;o00002Oooool3o`0000gooooo0_l000000ooooooo0000o`000008oooooaCo00000_oo
ool8o`0000;ooooo0_l0000Booooo`;o00000_ooool2o`0000Gooooo0_l00017ooooo`007?ooool0
0ol0003oooooooooo`1;ooooo`Co00006?ooool2o`000003ooooool0003o000000Oooooo0_l0000@
ooooo`Co00000oooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o00006Oooool2
o`0000Oooooo0_l00002oooooaGo000000?oooooo`000?l000001Ol00003ooooo`;o00003oooool2
o`000003ooooool0003o000000;ooooo0_l00005ooooo`;o0000Aoooool001cooooo00?o0000oooo
ooooool0Boooool4o`0000kooooo0_l000000ooooooo0000o`000002o`0000?ooooo1Ol00002oooo
o`;o00000oooool2o`0001;ooooo0_l00006ooooo`;o00001oooool3o`0000;ooooo0_l0000Noooo
oaWo000000?oooooo`000?l000000_l0000Aooooo`;o00000_ooool4o`0005Gooooo000Looooo`03
o`000?oooooooooo03Kooooo0ol0000Dooooo`;o00003_ooool2o`000003ooooool0003o000000?o
00000oooool2o`0000Cooooo0_l00003ooooo`;o00008oooool3o`0000;ooooo0_l0000Gooooo`;o
00001ooooolFo`0000;ooooo0ol0000;ooooo`;o00001Oooool2o`0000;ooooo0_l0000>ooooo`;o
00001oooool2o`0003kooooo000Looooo`03o`000?oooooooooo03Cooooo1Ol0000@ooooo`?o0000
2?ooool2o`0000?ooooo0_l00006ooooo`Co00003_ooool3o`0001Kooooo0_l0000Cooooo`;o0000
3oooool2o`0000;ooooo0_l00003ooooo`;o00001_ooool2o`000003ooooool0003o0000013o0000
3Oooool2o`0001Wooooo0_l00007ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0=?oo
ool3o`0001;ooooo1?l00007ooooo`;o00000oooool3o`000003ooooool0003o000000;ooooo0ol0
000:ooooo`;o00001?ooool2o`0000?ooooo0_l0000@ooooo`Go000000?oooooo`000?l000001?l0
0007ooooo`;o000000?oooooo`000?l000002_ooool2o`0000?ooooo1?l00005ooooo`;o00002Ooo
oolBo`0000_ooooo0_l00007ooooo`;o00004Oooool2o`0004Sooooo000Looooo`03o`000?oooooo
oooo03Gooooo0_l0000Dooooo`;o00001oooool2o`0000Cooooo1Ol0000<ooooo`;o000000?ooooo
o`000?l000002Oooool2o`00013ooooo0_l000001?oooooo0000o`000?ooool6o`0000Oooooo0ol0
000<ooooo`;o00000_ooool5o`00013ooooo4_l0000:ooooo`?o00000oooool2o`000004ooooool0
003o0000o`00017ooooo0_l0000>ooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0E?oo
ool2o`0000Gooooo0_l00008ooooo`;o00001?ooool2o`0000cooooo0_l0000Tooooo`;o00002?oo
ool2o`0000Kooooo0_l0000?ooooo`;o000000?oooooo`000?l000004?l00007ooooo`;o00000_oo
ool2o`0000;ooooo1ol00003ooooo`;o00007Oooool2o`0003Sooooo000Looooo`03o`000?oooooo
oooo03Sooooo0_l0000Aooooo`;o00000oooool2o`0000Oooooo0_l00007ooooo`;o000000?ooooo
o`000?l000001?ooool2o`0000Gooooo0_l00004ooooo`?o0000;_ooool2o`0001Oooooo0_l00000
0ooooooo0000o`000003o`0000;ooooo2ol00007ooooo`Co00000_ooool4o`0000;ooooo0_l00004
ooooo`;o00002Oooool2o`0004cooooo000Looooo`03o`000?oooooooooo03Gooooo0_l000000ooo
oooo0000o`00000Aooooo`;o00000oooool2o`0000Oooooo0_l00007ooooo`;o000000?oooooo`00
0?l000001ol00004ooooo`;o00001?ooool2o`0001Sooooo0_l00007ooooo`;o00007Oooool4o`00
00?ooooo0_l00003ooooo`Co00000_ooool7o`0000gooooo0_l00002ooooo`Co00001oooool2o`00
0003ooooool0003o000000Oooooo0_l00002ooooo`;o0000B?ooool001cooooo0_l0000cooooo`;o
000000?oooooo`000?l000000ol0000<ooooo`;o00005?ooool6o`0000;ooooo1ol000000ooooooo
0000o`000004ooooo`;o00001?ooool2o`0000Cooooo0_l0000Booooo`?o00001_ooool3o`0000?o
oooo0_l0000Booooo`Co000000?oooooo`000?l000000_l00003ooooo`;o00001?ooool2o`0000So
oooo0_l00003ooooo`;o000000Coooooo`000?l0003o00004_ooool3o`000003ooooool0003o0000
00_ooooo0_l00003ooooo`;o00003oooool3o`00037ooooo000Looooo`03o`000?oooooooooo03;o
oooo1?l000000ooooooo0000o`00000<ooooo`?o00004Oooool2o`000003ooooool0003o000000oo
00001?ooool2o`0000Gooooo0_l00004ooooo`;o00003?ooool2o`0000Gooooo0_l00007ooooo`Co
000000?oooooo`000?l000003Oooool2o`0000?ooooo1?l00002ooooo`;o00003oooool4o`000003
ooooool0003o000000;o000000Coooooo`000?l0003ooooo0ol0000=ooooo`Oo00000oooool2o`00
00Cooooo0_l00009ooooo`?o00003_ooool3o`00037ooooo000Looooo`03o`000?oooooooooo01[o
oooo0_l0000Hooooo`?o00001?ooool2o`0000Sooooo0_l00007ooooo`;o00001?ooool4o`000003
ooooool0003o000001;o00001?ooool2o`0000Cooooo0_l00005ooooo`;o00003?ooool3o`0000[o
oooo0_l00003ooooo`;o00001Oooool2o`000003ooooool0003o000000Kooooo0_l00003ooooo`;o
000000Coooooo`000?l0003ooooo0ol00002ooooo`;o00002?ooool;o`00013ooooo2Ol00005oooo
o`;o00000_ooool5o`0000Wooooo0_l0000?ooooo`;o0000<Oooool001cooooo00?o0000oooooooo
ool06_ooool2o`0001Oooooo1?l00004ooooo`;o00004Oooool2o`0000Cooooo7_l00005ooooo`;o
00001Oooool2o`0000Gooooo1?l00004ooooo`;o00002?ooool4o`0000[ooooo0_l000000ooooooo
0000o`00000>ooooo`;o00000_ooool2o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l0
00000oooool2o`0000;ooooo0_l00003ooooo`;o00001Oooool2o`0000?ooooo1Ol00003ooooo`Go
00001?ooool4o`000004ooooool0003o0000o`0001Wooooo0_l0000aooooo`007?ooool00ol0003o
ooooooooo`0cooooo`;o00000_ooool2o`0000;ooooo0_l0000<ooooo`;o00000_ooool3o`0000Go
oooo2ol000000ooooooo0000o`00000?o`0001?ooooo1?l0000;ooooo`Ko00004?ooool2o`0000Co
oooo0_l00007ooooo`;o00001_ooool2o`0000Cooooo0_l0000:ooooo`;o00000oooool2o`0000Go
oooo0ol000001?oooooo0000o`000?l00007ooooo`Co00001?ooool2o`0000Cooooo0ol00002oooo
o`;o00001Oooool2o`0000gooooo1?l0000_ooooo`007?ooool00ol0003oooooooooo`0gooooo`;o
00003_ooool4o`0000;ooooo0ol00004oooooako00003_ooool2o`0000Oooooo0_l00009ooooo`Ko
00002_ooool2o`000004ooooool0003o0000ooooo`;o00001?ooool2o`0000Oooooo0_l00006oooo
o`;o00006oooool4o`000003ooooool0003o000000;o00002_ooool2o`0000Wooooo0ol000000ooo
oooo0000o`000005ooooo`?o00003_ooool2o`0002oooooo000Looooo`03o`000?oooooooooo03Oo
oooo0_l00008ooooo`;o00001?ooool2o`0000[ooooo6Ol000000ooooooo0000o`000003o`0000ko
oooo0_l00007ooooo`;o00001oooool6o`0000;ooooo0_l00008ooooo`;o000000?oooooo`000?l0
00001?ooool2o`0000?ooooo0_l000000ooooooo0000o`00000Booooo`Co00003_ooool2o`000003
ooooool0003o000000?ooooo1?l00002ooooo`;o00001Oooool3o`0000[ooooo0_l00009ooooo`;o
0000?oooool001cooooo00?o0000ooooooooool0:_ooool2o`0000Oooooo0_l0000<ooooo`;o0000
2Oooool2o`0000Cooooo1ol000000ooooooo0000o`00000@o`000003ooooool0003o000000Co0000
5_ooool6o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`0000Kooooo0_l00005ooooo`;o0000
0_ooool7o`000003ooooool0003o000000Wooooo0_l00007ooooo`Co00003?ooool4o`0000cooooo
0_l00002ooooo`Go00001?ooool2o`0000_ooooo0_l00014ooooo`007?ooool00ol0003ooooooooo
o`0Zooooo`;o00001oooool2o`000003ooooool0003o000000Kooooo0_l00007ooooo`;o00000ooo
ool2o`0000Cooooo7_l000001?oooooo0000o`000?ooool2o`000004ooooool0003o0000o`0000;o
oooo1?l00003ooooo`;o00000oooool7o`0000Oooooo0_l000000ooooooo0000o`000005ooooo`Co
00001Oooool2o`000003ooooool0003o000000Go00003Oooool3o`00017ooooo0_l00003ooooo`;o
000000?oooooo`000?l000002oooool2o`0000;ooooo0ol00006ooooo`;o00002oooool2o`0004Co
oooo000Looooo`03o`000?oooooooooo037ooooo0_l00003ooooo`;o00001_ooool4o`0000Gooooo
0_l00006ooooo`;o000000Coooooo`000?l0003ooooo8Ol000001?oooooo0000o`000?l00002oooo
o`Co00000oooool4o`000003ooooool0003o000000?o00002?ooool3o`000004ooooool0003o0000
ooooo`;o00000_ooool2o`0000[ooooo1Ol00008ooooo`;o00001_ooool2o`0000oooooo1Ol00003
ooooo`Co00000_ooool2o`0000Oooooo0_l00007ooooo`;o00003_ooool2o`0000Gooooo0_l0000n
ooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00001Oooool2o`0000Kooooo0_l00004oooo
o`;o00001oooool2o`0000Cooooo8Ol00006ooooo`Co00000_ooool2o`000003ooooool0003o0000
00;o000000?oooooo`000?l000002?l000001?oooooo0000o`000?l00004ooooo`;o00003oooool4
o`0000Oooooo0ol00006ooooo`;o00002oooool2o`0000;ooooo0_l000000ooooooo0000o`000002
ooooo`Co00000oooool2o`00013ooooo0_l00005ooooo`;o00001oooool4o`0000?ooooo0_l0000n
ooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o00001?ooool2o`0000Gooooo0_l0000<oooo
o`;o00003oooool?o`0000;ooooo1_l000000ooooooo0000o`000003o`000003ooooool0003o0000
00?ooooo1?l00004ooooo`;o00000_ooool6o`000003ooooool0003o000000Go000000?oooooo`00
0?l000004_ooool2o`0000Kooooo0_l00005ooooo`;o00001oooool2o`0000_ooooo0_l000000ooo
oooo0000o`000006ooooo`;o00001Oooool2o`0000Wooooo0_l0000<ooooo`;o00002Oooool2o`00
04?ooooo000Looooo`03o`000?oooooooooo02_ooooo0_l00004ooooo`;o000000Coooooo`000?l0
003o00006Oooool2o`0000Kooooo3_l000000ooooooo0000o`000009o`000003ooooool0003o0000
00;o00000oooool2o`0000Kooooo0_l00002ooooo`Ko00002Oooool2o`0000;ooooo0_l00007oooo
o`;o00000_ooool2o`000003ooooool0003o000000;o00001?ooool2o`0001Sooooo0_l00004oooo
o`;o000000?oooooo`000?l000002_ooool2o`0000Wooooo0_l00003ooooo`;o000000?oooooo`00
0?l000001oooool2o`0000[ooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o
00001oooool5o`0000oooooo0_l00006ooooo`;o00000_ooool2o`000003ooooool0003o000001ko
00000oooool2o`0000Kooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000?o
oooo0_l00007ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000Oo
oooo0_l0000Eooooo`;o00001oooool4o`0001Sooooo0_l000000ooooooo0000o`000007ooooo`;o
00002_ooool2o`0003oooooo000Looooo`03o`000?oooooooooo02_ooooo0_l00002ooooo`;o0000
0_ooool3o`000003ooooool0003o000000_ooooo0_l00002ooooo`;o00002_ooool2o`000003oooo
ool0003o000001oo00003?ooool3o`000004ooooool0003o0000ooooo`Oo000000?oooooo`000?l0
00001_ooool5o`0000Cooooo0_l0000>ooooo`;o00001_ooool2o`0001Sooooo0_l0000<ooooo`;o
00007_ooool2o`0004?ooooo000Looooo`03o`000?oooooooooo02oooooo0_l00002ooooo`?o0000
3_ooool2o`0000[ooooo0_l00008oooooako00001oooool2o`000003ooooool0003o000000;o0000
1?ooool6o`0000?ooooo0_l00006ooooo`Go00001?ooool2o`0000Gooooo0_l0000?ooooo`Co0000
0oooool2o`0001_ooooo1_l0000Nooooo`;o000000Coooooo`000?l0003ooooo0_l0000mooooo`00
7?ooool2o`0002kooooo0ol00003ooooo`;o00003oooool2o`000004ooooool0003o0000o`0000Ko
oooo0_l00008oooooa_o00000_ooool2o`000003ooooool0003o000000;o000000Coooooo`000?l0
003ooooo0_l00003ooooo`;o000000?oooooo`000?l000003?ooool2o`000003ooooool0003o0000
00kooooo0_l00008ooooo`;o00000_ooool2o`0000?ooooo1?l000000ooooooo0000o`000002o`00
00Wooooo0_l0000>ooooo`Co00007_ooool2o`0000?ooooo0_l000000ooooooo0000o`00000moooo
o`007?ooool00ol0003oooooooooo`0]ooooo`?o00005oooool3o`0000?ooooo0_l0000;oooooaco
000000Coooooo`000?l0003ooooo1?l00004ooooo`Co000000?oooooo`000?l000003oooool2o`00
00oooooo0_l0000:ooooo`;o000000Coooooo`000?l0003o00001Oooool2o`0000?ooooo0_l00002
ooooo`;o00001Oooool2o`0000Oooooo0_l00002ooooo`;o00001_ooool2o`0001_ooooo0_l00006
ooooo`;o00002_ooool2o`00037ooooo000Looooo`03o`000?oooooooooo02oooooo0_l00009oooo
o`;o00002oooool4o`0000;ooooo0_l0000:oooooa[o000000?oooooo`000?l000001Oooool4o`00
00Cooooo0ol0000?ooooo`;o00001_ooool2o`0000Oooooo0_l000000ooooooo0000o`00000=oooo
o`;o00003oooool2o`0000Kooooo0_l00006ooooo`;o00000_ooool2o`0000Kooooo0_l0000Poooo
o`;o000000?oooooo`000?l000002_ooool2o`00037ooooo000Looooo`03o`000?oooooooooo02oo
oooo0_l00003ooooo`;o000000?oooooo`000?l000000ol000000ooooooo0000o`00000:ooooo`;o
00003?ooool4o`0000;ooooo5_l000001?oooooo0000o`000?ooool9o`0000?ooooo0ol0000?oooo
o`;o00000_ooool2o`0000;ooooo0_l00007ooooo`;o00004Oooool2o`0000?ooooo0_l0000;oooo
o`Go000000?oooooo`000?l00000<?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000moooo
o`007?ooool00ol0003oooooooooo`0[ooooo`;o00001oooool7o`0000;ooooo0_l00007ooooo`;o
00003oooool2o`000003ooooool0003o0000017o000000?oooooo`000?l000000ol000001?oooooo
0000o`000?ooool;o`000004ooooool0003o0000o`0000[ooooo0_l00007ooooo`;o00006?ooool3
o`000003ooooool0003o000000;o00000oooool2o`0000_ooooo1Ol00005ooooo`;o00001Oooool2
o`0002Gooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0Xooooo`;o000000?oooooo`00
0?l000001oooool3o`000003ooooool0003o000000?ooooo0ol00006ooooo`;o00002Oooool2o`00
00Oooooo6Ol000000ooooooo0000o`000008ooooo`Co000000?oooooo`000?l000000ol00008oooo
o`Co00007oooool3o`000004ooooool0003o0000o`0000;ooooo0_l00003ooooo`;o00001oooool2
o`0000;ooooo0_l00005ooooo`;o00001Oooool2o`0002Gooooo1?l00003ooooo`;o00002_ooool2
o`00037ooooo000Looooo`03o`000?oooooooooo02Sooooo0_l0000:ooooo`;o000000Coooooo`00
0?l0003o00000oooool3o`00017ooooo0_l00003ooooo`;o00001_ooool4o`000003ooooool0003o
000000_o000000?oooooo`000?l000000ol00006ooooo`;o00000_ooool2o`0000;ooooo1?l0000:
ooooo`;o00001oooool2o`0000Kooooo0_l0000<ooooo`;o000000?oooooo`000?l000001_ooool2
o`0000?ooooo0_l00007ooooo`;o00000_ooool2o`0003Gooooo0_l00003ooooo`;o00002_ooool2
o`0000?ooooo0_l0000/ooooo`007?ooool00ol0003oooooooooo`0dooooo`;o000000?oooooo`00
0?l000000_ooool2o`0000kooooo0_l00009ooooo`;o00002?ooool2o`000003ooooool0003o0000
00Ko000000?oooooo`000?l000000_l000000ooooooo0000o`000003o`0000Kooooo0_l000001?oo
oooo0000o`000?l00008ooooo`;o00002Oooool2o`0000Cooooo0_l000001?oooooo0000o`000?l0
0002ooooo`Co00002_ooool6o`00013ooooo1?l000000ooooooo0000o`000007ooooo`;o0000A?oo
ool2o`0002cooooo000Looooo`03o`000?oooooooooo03Gooooo0_l00004ooooo`;o000000Cooooo
o`000?l0003o00002_ooool2o`0001Cooooo0_l000000ooooooo0000o`000004o`0000;ooooo0_l0
0006ooooo`;o00000oooool5o`000003ooooool0003o000000;ooooo0_l00005ooooo`;o00002Ooo
ool2o`0000;ooooo0ol00002ooooo`?o00001?ooool2o`000003ooooool0003o000000Co00001Ooo
ool4o`0000;ooooo0_l0000<ooooo`Co000000?oooooo`000?l000001oooool2o`0007;ooooo000L
ooooo`03o`000?oooooooooo03Gooooo0_l000001?oooooo0000o`000?ooool2o`000004ooooool0
003o0000o`0000?ooooo0_l0000Fooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`Co
00003?ooool:o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`0000Oooooo1Ol0000:ooooo`_o
00000_ooool2o`000004ooooool0003o0000ooooo`Ko00001oooool4o`0000oooooo0_l0000joooo
o`;o0000<_ooool001cooooo00?o0000ooooooooool0=Oooool2o`000003ooooool0003o000000;o
oooo0_l00004ooooo`Co000000?oooooo`000?l000003oooool2o`0000;ooooo0_l00009ooooo`Go
00002Oooool4o`0000Gooooo0_l00006ooooo`;o00001_ooool2o`0000?ooooo0_l00002ooooo`?o
00001Oooool2o`0000Gooooo0_l000000ooooooo0000o`000002ooooo`So000000?oooooo`000?l0
00000oooool5o`000004ooooool0003o0000o`0000;ooooo1?l0000?ooooo`?o00002oooool2o`00
01kooooo0ol0000;ooooo`;o0000<_ooool001cooooo00?o0000ooooooooool0<?ooool2o`0000So
oooo1?l00004ooooo`;o00000_ooool3o`0000oooooo0_l00008ooooo`;o00001?ooool4o`0000Wo
oooo0_l00004ooooo`;o000000?oooooo`000?l000001_ooool3o`0000[ooooo0_l00003ooooo`;o
00000oooool4o`0000?ooooo0_l0000:ooooo`Go00001Oooool3o`000004ooooool0003o0000oooo
o`Oo00000oooool2o`0000gooooo0_l0000;ooooo`;o00007_ooool3o`0003oooooo000Looooo`03
o`000?oooooooooo033ooooo0_l00008ooooo`;o00000_ooool2o`0000Kooooo0_l0000Jooooo`;o
000000Coooooo`000?l0003ooooo0_l0000Aooooo`;o000000?oooooo`000?l000001oooool4o`00
013ooooo1Ol00004ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`;o00001oooool2o`00
00Kooooo1?l00005ooooo`;o00005Oooool2o`00037ooooo0_l0000booooo`007?ooool00ol0003o
ooooooooo`0nooooo`;o00009Oooool2o`0000?ooooo0_l0000;ooooo`;o000000?oooooo`000?l0
00002oooool4o`00013ooooo0_l000001?oooooo0000o`000?l00003ooooo`;o00000oooool2o`00
00;ooooo0ol00003ooooo`;o00001oooool4o`000004ooooool0003o0000o`0000;ooooo1?l0000:
ooooo`;o00003?ooool2o`0000Cooooo0_l0000Looooo`;o00003Oooool2o`0003;ooooo000Loooo
o`03o`000?oooooooooo02oooooo0_l0000cooooo`;o00001?ooool2o`0000[ooooo1_l00007oooo
o`;o00002_ooool2o`0000[ooooo0_l00002ooooo`;o00000oooool2o`0000Kooooo1?l00003oooo
o`?o00000_ooool8o`000005ooooool0003o0000o`000?ooool01Ol00006ooooo`;o00000_ooool2
o`0001;ooooo0_l0000Looooo`?o0000@?ooool001cooooo00?o0000ooooooooool0;oooool2o`00
00?ooooo0_l00007ooooo`;o00009Oooool2o`0000Cooooo0_l0000:ooooo`Ko00001oooool2o`00
00[ooooo0_l0000:ooooo`;o00000_ooool2o`0000;ooooo0_l00007ooooo`;o00000oooool6o`00
0003ooooool0003o000000Ko00001Oooool5o`0000Kooooo1?l0000Dooooo`;o00007Oooool2o`00
043ooooo000Looooo`;o0000=Oooool2o`0000;ooooo0_l00003ooooo`;o0000<?ooool2o`0000_o
oooo0_l0000Aooooo`;o00001Oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000Oo
oooo0_l00002ooooo`So00000_ooool3o`000004ooooool0003o0000o`0000Oooooo0_l00002oooo
o`;o00001?ooool2o`0000Wooooo0_l0000Mooooo`;o00002_ooool2o`0003oooooo000Looooo`03
o`000?oooooooooo03Gooooo1Ol0000eooooo`;o00001?ooool2o`0000?ooooo1_l0000;ooooo`;o
00000_ooool2o`0000Gooooo0_l00002ooooo`;o00002oooool7o`000003ooooool0003o000000Oo
00000_ooool2o`000003ooooool0003o000000Go00001Oooool5o`0000oooooo0_l0000Mooooo`;o
00002_ooool2o`0003oooooo000Looooo`03o`000?oooooooooo03?ooooo1_l00003ooooo`Co0000
2?ooool2o`0002Cooooo0_l00005ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`;o0000
00?oooooo`000?l000001?ooool2o`0001?ooooo0_l00005ooooo`Oo000000?oooooo`000?l00000
5ol000000ooooooo0000o`000003o`0001;ooooo0_l0000Kooooo`;o0000B_ooool001cooooo00?o
0000ooooooooool0<oooool4o`0000Gooooo1?l00008ooooo`;o00006Oooool2o`0000Wooooo1?l0
0009ooooo`;o00000oooool4o`000003ooooool0003o000001Cooooo0_l00003ooooo`;o00000_oo
ool2o`0000Cooooo1?l000000ooooooo0000o`000003oooooaCo000000?oooooo`000?l000000_l0
0002ooooo`;o000000?oooooo`000?l000003?ooool2o`0001_ooooo0_l00007ooooo`;o0000@Ooo
ool001cooooo00?o0000ooooooooool0;_ooool2o`0000Gooooo0ol0000Wooooo`?o000000?ooooo
o`000?l000000_l00002ooooo`Wo000000?oooooo`000?l000001_ooool2o`0000?ooooo0_l0000:
ooooo`;o00003Oooool2o`0000Oooooo0ol00006ooooo`Ko000000?oooooo`000?l000003ol00000
1?oooooo0000o`000?ooool4o`0000;ooooo1Ol0000>ooooo`;o00008_ooool2o`00047ooooo000L
ooooo`03o`000?oooooooooo02kooooo0_l00003ooooo`;o000000?oooooo`000?l000002Oooool2
o`0000Kooooo0_l0000Dooooo`?o00000oooool;o`0000?ooooo0_l00002ooooo`Co00001Oooool2
o`000003ooooool0003o000000?o00001?ooool3o`0001Kooooo1?l00003ooooo`Oo000000?ooooo
o`000?l000004_l000000ooooooo0000o`000002o`0000;ooooo1Ol00004ooooo`;o00002?ooool2
o`0000Gooooo0_l0000Gooooo`;o0000AOooool001cooooo00?o0000ooooooooool0<oooool2o`00
00cooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Wooooo0_l00005oooo
o`;o00001_ooool2o`0000kooooo1_l00003ooooo`;o000000?oooooo`000?l000000ol00005oooo
o`;o00005_ooool4o`000003ooooool0003o000001co000000Coooooo`000?l0003o00000oooool6
o`0000?ooooo0_l00009ooooo`;o00001?ooool2o`0001Gooooo1?l000000ooooooo0000o`000012
ooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o000000?oooooo`000?l000004oooool2o`00
0005ooooool0003o0000o`000?ooool00_l00009ooooo`;o00001Oooool3o`00017ooooo0_l00000
1?oooooo0000o`000?l00002ooooo`;o00003?ooool2o`00017ooooo0_l00006ooooo`;o00001?oo
ool2o`0000?ooooo7ol000000ooooooo0000o`000004o`0000cooooo1?l0000Kooooo`;o00000ooo
ool2o`0004;ooooo000Looooo`03o`000?oooooooooo02kooooo0_l000000ooooooo0000o`000007
ooooo`;o00002oooool5o`0001Cooooo0_l0000?ooooo`Co000000?oooooo`000?l000000_ooool4
o`0000;ooooo0_l00007ooooo`;o00004Oooool2o`0000Kooooo0_l00004ooooo`;o00001?oooolN
o`0000;ooooo0ol0000>ooooo`;o00007Oooool2o`0004Oooooo000Looooo`03o`000?oooooooooo
03[ooooo0_l0000;ooooo`;o00007Oooool2o`0000Wooooo0_l00007ooooo`[o00000_ooool2o`00
01kooooo2?l000000ooooooo0000o`00000>o`000003ooooool0003o000000go00000oooool4o`00
00gooooo0_l0000Booooo`;o00002_ooool4o`0004;ooooo000Looooo`03o`000?oooooooooo03[o
oooo0ol00005ooooo`;o00000_ooool2o`0001;ooooo0_l0000:ooooo`;o00003Oooool2o`0000Oo
oooo0ol000000ooooooo0000o`000002ooooo`;o00007_ooool`o`0000gooooo0_l00004ooooo`;o
00003?ooool2o`0000[ooooo1?l00012ooooo`007?ooool00ol0003oooooooooo`0eooooo`;o0000
1?ooool2o`0000Gooooo0_l000001?oooooo0000o`000?l0000Booooo`;o00002Oooool2o`0000Go
oooo0_l000000ooooooo0000o`000004ooooo`;o00000oooool2o`0000kooooo0_l0000Gooooo`;o
00001ooooolRo`000003ooooool0003o000000Co00001?ooool4o`0000_ooooo0ol0001Nooooo`00
7?ooool00ol0003oooooooooo`0eooooo`;o00002_ooool2o`0000;ooooo0_l00004ooooo`;o0000
2oooool2o`0000Oooooo0_l00002ooooo`;o00001Oooool5o`0000Kooooo0_l000000ooooooo0000
o`00000>ooooo`;o00005_ooool4o`0000Cooooo0_l000000ooooooo0000o`00000:o`000003oooo
ool0003o000001?o000000?oooooo`000?l000000ol00004ooooo`Go00002_ooool2o`00013ooooo
0_l00007ooooo`;o00003_ooool2o`0003Cooooo000Looooo`03o`000?oooooooooo03Wooooo0_l0
0002ooooo`;o00000_ooool2o`0000Oooooo1?l0000:ooooo`;o00000oooool2o`0000;ooooo0_l0
000:ooooo`;o00002?ooool2o`0002Kooooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l0
00000ooooooo0000o`00000Mo`000004ooooool0003o0000ooooo`Co00002?ooool2o`0001_ooooo
0ol00007ooooo`;o00003_ooool2o`0003Cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGo
oooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0ioooo
o`;o00000_ooool2o`0000_ooooo1Ol0000>ooooo`;o00008?ooool4o`0001cooooo0_l00002oooo
o`;o00000ooooolVo`0000?ooooo0ol0000Tooooo`?o00000_ooool4o`0000kooooo0_l0000hoooo
o`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonH
V9So8B4Q00Kooooo00?o0000ooooooooool0<Oooool2o`0000Wooooo0_l00009ooooo`;o000000Co
ooooo`000?l0003ooooo1_l00005ooooo`;o00009Oooool4o`0002Gooooo1Ol000000ooooooo0000
o`000004o`000003ooooool0003o000001co00001?ooool2o`0000;ooooo0_l0000Kooooo`;o0000
0oooool4o`0000?ooooo0_l00009ooooo`;o0000>?ooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
<Oooool2o`0000Wooooo0_l00009ooooo`;o000000?oooooo`000?l000000oooool4o`0000Gooooo
0_l00004ooooo`;o00003oooool7o`0000?ooooo0_l0000Wooooo`;o00001Oooool@o`0000;ooooo
6?l00003ooooo`Oo00007?ooool2o`0000?ooooo0_l00004ooooo`;o0000@oooool00003ooooool0
003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo
0ol0000_ooooo`;o00002Oooool5o`0000;ooooo0_l00004ooooo`Co00004oooool2o`0000gooooo
3_l00004ooooo`;o00005oooool2o`0000Gooooo0_l000000ooooooo0000o`000007ooooobGo0000
1_ooool7o`000003ooooool0003o000001?ooooo0_l00004ooooo`;o0000C_ooool00003ooooool0
003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo
00?o0000ooooooooool0;oooool2o`0000Cooooo0_l00002ooooo`?o000000?oooooo`000?l00000
0_ooool2o`000003ooooool0003o000000?ooooo0_l00008ooooo`;o00000_ooool2o`00017ooooo
1ol00005ooooo`Co00001Oooool2o`0001Oooooo0_l00004ooooo`?o000000Coooooo`000?l0003o
oooo0_l00005ooooob[o00001_ooool4o`0001;ooooo0ol00002ooooo`Co00002?ooool2o`0004Co
oooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qoooool0
2?ooool00ol0003oooooooooo`0eooooo`;o00000_ooool2o`0000Wooooo0_l0000=ooooo`;o0000
0_ooool2o`00017ooooo1?l0000Rooooo`;o00003?ooool2o`0000;ooooo0_l000001?oooooo0000
o`000?l00005ooooobWo00001_ooool2o`000003ooooool0003o000000Kooooo0_l00009ooooo`;o
00000oooool5o`0000Oooooo0_l00003ooooo`;o00000oooool2o`0003[ooooo00001_ooooooMgMg
oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0noooo
o`;o00003Oooool3o`0000;ooooo0_l000000ooooooo0000o`00000Eooooo`;o00002oooool2o`00
00Kooooo0_l00004ooooo`;o00001oooool2o`0000oooooo0ol00002ooooo`;o000000?oooooo`00
0?l000007?l000000ooooooo0000o`00000<o`0000Oooooo1?l00002ooooo`;o00000_ooool2o`00
00gooooo0_l00002ooooo`;o000000?oooooo`000?l000002Oooool2o`0000?ooooo0_l0000joooo
o`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o
0000ooooooooool0<oooool2o`0000?ooooo0_l00004ooooo`;o00002?ooool2o`0000?ooooo0ol0
00001Ooooooo0000o`000?l0003ooooo00;o00008_ooool3o`000003ooooool0003o000000Co0000
1?ooool4o`0001Kooooo0_l00005ooooo`ko000000?oooooo`000?l000004_l000000ooooooo0000
o`000008o`0000Oooooo0_l00004ooooo`;o00004Oooool2o`000004ooooool0003o0000ooooo`?o
000000?oooooo`000?l000001_ooool2o`000003ooooool0003o000003cooooo000Looooo`03o`00
0?oooooooooo033ooooo0_l000000ooooooo0000o`000003ooooo`;o00000_ooool2o`0000[ooooo
0_l00007ooooo`;o00005Oooool2o`000003ooooool0003o000000[ooooo0_l000001?oooooo0000
o`000?ooool6o`000003ooooool0003o000000?ooooo0_l0000Kooooob_o00001oooool2o`000003
ooooool0003o000000;o00001?ooool2o`0000Gooooo0_l0000:ooooo`;o000000Coooooo`000?l0
003ooooo0ol000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l00000??ooool001co
oooo00?o0000ooooooooool0<?ooool2o`0000Oooooo0_l000000ooooooo0000o`000003ooooo`;o
00002?ooool2o`0001_ooooo0_l000000ooooooo0000o`000008ooooo`Co000000?oooooo`000?l0
00004Ol00002ooooo`;o00005OoooolYo`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l0
00000_l0000;ooooo`;o00002?ooool2o`0000Cooooo0_l0000:ooooo`;o0000@Oooool001cooooo
00?o0000ooooooooool0>Oooool5o`0000?ooooo1?l00006ooooo`;o000000?oooooo`000?l00000
1Oooool2o`0000;ooooo0_l0000Jooooo`;o000000?oooooo`000?l000005ol00002ooooo`;o0000
0_ooool4o`0000Kooooo0_l00004ooooo`Co00000_oooolNo`000004ooooool0003o0000o`0000?o
oooo0_l0000Fooooo`;o00001Oooool5o`0000Cooooo0_l00002ooooo`;o00001_ooool2o`00047o
oooo000Looooo`03o`000?oooooooooo03[ooooo1?l00005ooooo`;o00002Oooool2o`0000Gooooo
0_l00002ooooo`;o00007OoooolDo`000004ooooool0003o0000o`0000?ooooo0_l00002ooooo`Co
00001_ooool2o`0000Cooooo9?l00002ooooo`Go00000_ooool2o`0001Cooooo1?l00003ooooo`Co
00002Oooool2o`0004Wooooo000Looooo`03o`000?oooooooooo03Oooooo0_l00005ooooo`Co0000
0_ooool2o`0000?ooooo0_l0000Zooooo`;o000000?oooooo`000?l000004_l00002ooooo`;o0000
0oooool2o`00013ooooo0_l00002ooooo`Co000000?oooooo`000?l000006ol000000ooooooo0000
o`000004o`0000;ooooo0_l0000Fooooo`;o00001?ooool2o`0005Gooooo000Looooo`03o`000?oo
oooooooo03;ooooo0_l00003ooooo`;o00000oooool6o`0000;ooooo0_l00003ooooo`;o00009Ooo
ool2o`0000?ooooo6Ol00005ooooo`;o00002?ooool2o`0000Cooooo1Ol000000ooooooo0000o`00
0002o`000003ooooool0003o000001So000000?oooooo`000?l000000ol00006ooooo`;o00001ooo
ool2o`0000Gooooo0ol0000:ooooo`?o00002?ooool2o`0000Gooooo0_l00014ooooo`007?ooool0
0ol0003oooooooooo`0booooo`;o000000?oooooo`000?l000001Oooool2o`0000Cooooo0_l0000/
ooooo`;o00000_ooool2o`000003ooooool0003o000001Go00003oooool2o`0000Cooooo1Ol00000
1?oooooo0000o`000?l00002ooooob7o00001Oooool3o`0000Kooooo0_l00003ooooo`Go00002_oo
ool2o`0000Wooooo0_l00005ooooo`;o00000_ooool2o`00043ooooo000Looooo`03o`000?oooooo
oooo03Gooooo0ol0000:ooooo`;o00002?ooool2o`0002Kooooo6ol0000Cooooo`?o00000oooool4
o`0000?ooooo2?l00002oooooaWo00000_ooool3o`0000_ooooo0ol00005ooooo`Go00006?ooool2
o`00043ooooo000Looooo`03o`000?oooooooooo03Gooooo1?l0000Cooooo`;o00002?ooool2o`00
00cooooo0_l0000@oooooaWo000000Coooooo`000?l0003o00002_ooool2o`0000?ooooo0_l00003
ooooo`?o00001Oooool?o`0000;ooooo3Ol00002ooooo`?o00000_ooool2o`0000_ooooo0_l00007
ooooo`Go0000F_ooool001cooooo00?o0000ooooooooool0=Oooool4o`0000_ooooo0_l0000;oooo
o`;o00000oooool4o`0000[ooooo0_l0000<ooooo`;o00000_oooolIo`000005ooooool0003o0000
o`000?ooool00_l000000ooooooo0000o`000002o`0000;ooooo0ol00007ooooo`?o000000?ooooo
o`000?l000008_l000000ooooooo0000o`00000?ooooo`;o00001oooool2o`000003ooooool0003o
000005[ooooo000Looooo`03o`000?oooooooooo04Cooooo0_l000000ooooooo0000o`000008oooo
o`;o00001Oooool2o`0000[ooooo0_l00007ooooo`;o00000ooooolMo`000003ooooool0003o0000
00;ooooo0_l000000ooooooo0000o`000003o`0000;ooooo0_l0000:ooooo`[o00000ooooolAo`00
0003ooooool0003o000000Ko00004?ooool2o`0000Kooooo0ol0000Eooooo`;o0000A_ooool001co
oooo0_l00018ooooo`?o00006_ooool2o`0000Oooooo0_l00005ooooo`;o00000_oooolEo`0000Co
oooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l00008ooooo`;o000000?oooooo`00
0?l000000_oooolJo`0000;ooooo0_l000000ooooooo0000o`000003o`0000Cooooo0_l00003oooo
o`Co00000_ooool2o`0000;ooooo0_l00002ooooo`;o00000_ooool2o`0000[ooooo0_l00006oooo
o`;o0000A_ooool001cooooo00?o0000ooooooooool0>_ooool2o`0000cooooo0_l0000Wooooo`;o
000000?oooooo`000?l000000_oooolGo`0000;ooooo0_l0000:ooooo`;o00000oooool2o`0000?o
oooo0_l00005oooooaWo00000oooool2o`0000?ooooo1?l00003ooooo`;o00000oooool4o`000003
ooooool0003o000000?ooooo0_l00005ooooo`?o00001Oooool2o`0000?ooooo0_l0001>ooooo`00
7?ooool00ol0003oooooooooo`0jooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo
0_l0000Rooooo`;o00001?ooool2o`0000Gooooo5ol00009ooooo`;o00002?ooool2o`0000?ooooo
0ol00004ooooo`go000000?oooooo`000?l000002Ol000000ooooooo0000o`000002o`0000?ooooo
1?l000000ooooooo0000o`000002o`0000Sooooo0_l0000:ooooo`;o00001_ooool2o`0005?ooooo
000Looooo`03o`000?oooooooooo03gooooo0_l00002ooooo`Co00000_ooool2o`0000;ooooo0_l0
0003ooooo`;o00006Oooool2o`0000cooooo5_l00009ooooo`;o00000_ooool2o`0000Sooooo1?l0
0009ooooo`go000000?oooooo`000?l000000ol00002ooooo`Co00000oooool2o`0000?ooooo0_l0
0009ooooo`;o00000oooool2o`0006?ooooo000Looooo`03o`000?oooooooooo047ooooo1_l00004
ooooo`;o00000oooool4o`0000kooooo0_l00003ooooo`?o000000?oooooo`000?l000001Oooool2
o`0000Cooooo5?l0000@ooooo`;o00002?ooool2o`0000Sooooo1ol00002ooooo`Oo000000?ooooo
o`000?l000002Ol00003ooooo`;o00003_ooool2o`0000?ooooo1?l000000ooooooo0000o`00000G
ooooo`;o0000AOooool001cooooo00?o0000ooooooooool0@?ooool7o`0000Cooooo0_l00005oooo
o`;o000000?oooooo`000?l000001oooool2o`0000;ooooo0_l00002ooooo`Co00002?ooool2o`00
00Cooooo1?l000000ooooooo0000o`00000<o`000003ooooool0003o000001gooooo0_l00003oooo
o`ko00001oooool8o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`;o00000oooool2o`00
0003ooooool0003o000000Cooooo0_l000000ooooooo0000o`00000;ooooo`;o00002_ooool2o`00
04Gooooo000Looooo`03o`000?oooooooooo03[ooooo0_l00004ooooo`;o00002?ooool3o`0000?o
oooo0_l00003ooooo`;o00001Oooool4o`0000Kooooo0_l00005ooooo`;o00001oooool4o`0000Co
oooo4?l00004ooooo`;o00002_ooool2o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`;o
00001Oooool:o`000003ooooool0003o000000Sooooo1_l00002ooooo`;o000000?oooooo`000?l0
00001?ooool3o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l0000=oooo
o`;o0000DOooool001cooooo00?o0000ooooooooool0>_ooool2o`0000kooooo0_l00004ooooo`;o
00002_ooool2o`0000oooooo0_l00005ooooo`Go00001_ooool8o`0000Cooooo0_l00004ooooo`?o
000000?oooooo`000?l000001oooool2o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`Co
000000Goooooo`000?l0003o0000ooooo`02o`000003ooooool0003o000000?o000000Coooooo`00
0?l0003o00001Oooool:o`0000[ooooo0_l00008ooooo`;o00000_ooool2o`0000?ooooo0_l00007
ooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0@?ooool3o`0000?ooooo0_l0000;oooo
o`;o00001oooool2o`0000Gooooo0_l000001?oooooo0000o`000?ooool2o`0000Sooooo0ol0000:
ooooo`Oo00000_ooool2o`0000Kooooo0_l00002ooooo`;o00005?ooool4o`000005ooooool0003o
0000o`000?ooool00_l000000ooooooo0000o`000008o`0000;ooooo1?l000000ooooooo0000o`00
0002ooooo`Ko00004oooool2o`0000Gooooo0_l00007ooooo`;o00004_ooool2o`0003kooooo000L
ooooo`03o`000?oooooooooo043ooooo0ol00003ooooo`;o00002oooool2o`0000Oooooo0_l00003
ooooo`Co000000?oooooo`000?l000001Ol000000ooooooo0000o`000003ooooo`;o00002oooool6
o`0000?ooooo0_l00005ooooo`Ko00001Oooool2o`0001_ooooo2Ol00002ooooo`;o00000_ooool2
o`0000?ooooo0_l000001?oooooo0000o`000?l0000Cooooo`?o00008Oooool2o`0003kooooo000L
ooooo`03o`000?oooooooooo05?ooooo0_l00007ooooo`;o000000?oooooo`000?l000000_l00005
ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Cooooo`;o00000_ooool2o`0000Cooooo2Ol0
00000ooooooo0000o`000002ooooo`;o00003_ooool2o`0000oooooo1Ol00006ooooo`;o00000ooo
ool2o`0000cooooo0_l00005ooooo`;o00000_ooool3o`00067ooooo000Looooo`03o`000?oooooo
oooo03gooooo0_l00007ooooo`;o00003oooool2o`0000Kooooo0_l0000=ooooo`;o00005oooool2
o`0000Cooooo1Ol00002ooooo`;o000000?oooooo`000?l000001oooool2o`0000Wooooo0_l00008
ooooo`;o00001Oooool5o`000003ooooool0003o000000kooooo0_l00002ooooo`?o000000Cooooo
o`000?l0003ooooo0_l00002ooooo`;o00002Oooool2o`0000Cooooo0_l0001Eooooo`007?ooool0
0ol0003oooooooooo`0mooooo`;o00001oooool2o`0000_ooooo0_l00002ooooo`?o00001_ooool2
o`0000gooooo0_l0000Cooooo`;o00002Oooool2o`0000Gooooo0_l00007ooooo`?o00002?ooool2
o`0000?ooooo0_l00004ooooo`;o00002oooool2o`0000kooooo0_l00002ooooo`?o00001?ooool2
o`0000gooooo0_l00004ooooo`;o00000_ooool2o`00057ooooo000Looooo`03o`000?oooooooooo
04Oooooo0_l0000:ooooo`;o00000oooool2o`0000Cooooo1?l00003ooooo`;o00002?ooool2o`00
00Cooooo0_l0000;ooooo`Co00000_ooool2o`0000Gooooo0_l00003ooooo`Co00001oooool2o`00
00Wooooo1ol0000Iooooo`;o00003?ooool2o`0000;ooooo0_l00005ooooo`;o00004?ooool3o`00
057ooooo000Looooo`03o`000?oooooooooo03kooooo0_l00007ooooo`;o00003_ooool3o`0000Co
oooo0_l00005ooooo`;o00000_ooool2o`0000[ooooo0_l0000;ooooo`;o00001?ooool2o`0000[o
oooo0_l0000:ooooo`;o00000_ooool2o`0000;ooooo0_l00002ooooo`Co00000oooool2o`0001Go
oooo0_l00007ooooo`;o00000oooool2o`0000;ooooo0_l00005ooooo`;o00000oooool2o`0000Oo
oooo0_l00002ooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0?_ooool2o`0000Cooooo
0_l0000Aooooo`;o00002?ooool2o`0000Kooooo0_l00002ooooo`;o0000<Oooool2o`0000;ooooo
1_l00009ooooo`;o00003Oooool2o`0000kooooo0ol0000Aooooo`Co00001oooool2o`000003oooo
ool0003o000005?ooooo000Looooo`;o0000@?ooool2o`0000?ooooo0ol000001?oooooo0000o`00
0?ooool2o`0001Cooooo0_l0000:ooooo`;o00002_ooool2o`0000Oooooo0_l0000Gooooo`;o0000
1_ooool7o`0000Sooooo0_l00004ooooo`;o00002?ooool2o`0000gooooo0ol0000Booooo`;o0000
2_ooool5o`0001?ooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00001?oo
ool5o`000003ooooool0003o000001Cooooo0_l00003ooooo`;o00001_ooool2o`0000Wooooo0_l0
0007ooooo`Co000000?oooooo`000?l000000_l0000?ooooo`?o00001_ooool3o`0000;ooooo0_l0
0008ooooo`;o00001?ooool3o`00013ooooo0_l00004ooooo`;o00007oooool2o`000004ooooool0
003o0000o`0001;ooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00001?oo
ool2o`0001Wooooo0_l00003ooooo`?o00001Oooool4o`0000Gooooo0_l0000;ooooo`;o000000?o
ooooo`000?l000001?l0000=ooooo`;o00007Oooool2o`0000Sooooo0_l00006ooooo`;o00006ooo
ool3o`0000_ooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00002oooool2
o`0001Sooooo0_l00005ooooo`Co00001Oooool2o`0000oooooo0_l000000ooooooo0000o`00000;
ooooo`;o00000_ooool3o`0000Kooooo0_l00003ooooo`;o00004_ooool7o`0001[ooooo0_l00007
ooooo`?o00006oooool2o`00047ooooo000Looooo`03o`000?oooooooooo04cooooo0ol0000:oooo
o`;o00004oooool3o`000003ooooool0003o000000?ooooo0_l0000?ooooo`Co00003?ooool2o`00
00;ooooo0ol00004ooooo`Co000000?oooooo`000?l000000_l00002ooooo`;o00002_ooool3o`00
0003ooooool0003o000000Co00006Oooool4o`0000oooooo0_l0000Dooooo`;o0000@Oooool001co
oooo00?o0000ooooooooool0C?ooool2o`0000_ooooo0ol0000Fooooo`;o00004_ooool2o`000004
ooooool0003o0000o`0000Sooooo0_l000000ooooooo0000o`000005ooooo`?o00000_ooool2o`00
00?ooooo0_l00004ooooo`?o00002?ooool4o`000004ooooool0003o0000o`0001cooooo0ol0000@
ooooo`;o0000Eoooool001cooooo00?o0000ooooooooool0DOooool2o`0000Oooooo0_l00009oooo
o`;o00001?ooool2o`0000Cooooo0_l00005ooooo`;o00001_ooool3o`0000?ooooo0_l0000<oooo
o`Go00000oooool9o`0000[ooooo0_l00008ooooo`;o000000?oooooo`000?l000000_l00009oooo
o`;o00001Oooool2o`0000gooooo0_l000000ooooooo0000o`00001Uooooo`007?ooool00ol0003o
ooooooooo`13ooooo`;o00000oooool2o`0000Oooooo0ol00002ooooo`;o00003Oooool2o`0000Co
oooo0_l00004ooooo`;o00001Oooool2o`0000Kooooo0ol00002ooooo`;o00002Oooool2o`0000;o
oooo1Ol00003ooooo`Wo00003oooool2o`0000;ooooo0_l00002ooooo`;o00002oooool2o`0000;o
oooo0_l000000ooooooo0000o`000003ooooo`?o00001?ooool2o`000003ooooool0003o000000?o
0000IOooool001cooooo00?o0000ooooooooool0@oooool2o`0000?ooooo0_l00006ooooo`Co0000
0_ooool3o`0001;ooooo0_l00006ooooo`;o00002oooool2o`0000?ooooo0_l00009ooooo`Co0000
3_ooool2o`00013ooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo1?l0000;ooooo`;o
00001_ooool3o`0000Cooooo0ol000001?oooooo0000o`000?l0001Vooooo`007?ooool00ol0003o
ooooooooo`1@ooooo`?o000000?oooooo`000?l000000ol0000=ooooo`;o00000oooool2o`000004
ooooool0003o0000ooooo`Co00002oooool2o`00013ooooo0_l00004ooooo`;o000000?oooooo`00
0?l000001Oooool2o`0000gooooo0_l00002ooooo`;o00001?ooool2o`000003ooooool0003o0000
00;o00005oooool2o`0000;ooooo0_l00002ooooo`;o00002?ooool2o`0005cooooo000Looooo`03
o`000?oooooooooo05Cooooo0ol0000;ooooo`;o00000_ooool2o`0000Kooooo1ol00007ooooo`;o
00004_ooool4o`0000Cooooo0_l000000ooooooo0000o`00000:ooooo`;o00002?ooool2o`0000;o
oooo0_l00008ooooo`?o00002oooool4o`0000Oooooo0ol00005ooooo`?o00001Oooool2o`000004
ooooool0003o0000ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0DOooool2o`000003
ooooool0003o000000Cooooo0_l00006ooooo`;o00002_ooool5o`0000Wooooo0_l0000Booooo`Co
00000oooool2o`0000_ooooo0_l000000ooooooo0000o`000002o`0000[ooooo0_l00009ooooo`;o
00000oooool3o`000003ooooool0003o000000Ko00000oooool2o`0000;ooooo1Ol00003ooooo`;o
00001_ooool2o`0000Cooooo0_l0001Iooooo`007?ooool00ol0003oooooooooo`1Aooooo`Co0000
1Oooool2o`0000Cooooo1_l00008ooooo`?o000000?oooooo`000?l000002?ooool2o`0001Kooooo
0_l000000ooooooo0000o`000009ooooo`Go00000_ooool2o`0000[ooooo0_l0000>ooooo`Wo0000
1_ooool3o`000004ooooool0003o0000ooooo`;o00002oooool2o`0005oooooo000Looooo`03o`00
0?oooooooooo05?ooooo1?l00009ooooo`Ko00002?ooool3o`000003ooooool0003o000000cooooo
0_l00003ooooo`;o00003Oooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000
o`000002o`000003ooooool0003o000000?ooooo1_l000000ooooooo0000o`000004ooooo`;o0000
1_ooool2o`0000Gooooo2Ol00006ooooo`;o00003?ooool2o`0006Cooooo000Looooo`03o`000?oo
oooooooo05Gooooo0_l00007ooooo`;o00002Oooool2o`0001Gooooo0ol00002ooooo`;o00005_oo
ool2o`000003ooooool0003o000000?ooooo0ol00002ooooo`Ko000000Coooooo`000?l0003ooooo
0_l000000ooooooo0000o`000006ooooo`;o00001?ooool:o`0000?ooooo0_l00003ooooo`;o0000
2_ooool2o`0006Cooooo000Looooo`03o`000?oooooooooo05Cooooo0_l00008ooooo`?o00002?oo
ool2o`0000[ooooo0_l000000ooooooo0000o`000007ooooo`;o00001?ooool4o`0001[ooooo0ol0
0005ooooo`?o00001?ooool2o`000003ooooool0003o000000[ooooo2Ol00006ooooo`;o00000ooo
ool2o`000003ooooool0003o000006gooooo000Looooo`;o0000EOooool2o`0000Wooooo0_l0000D
ooooo`;o000000?oooooo`000?l000003Oooool7o`00017ooooo0_l00006ooooo`;o000000?ooooo
o`000?l000002oooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0000Gooooo0_l0
0003ooooo`;o000000?oooooo`000?l000001_ooool2o`0001cooooo0_l0001?ooooo`007?ooool0
0ol0003oooooooooo`1eooooo`;o00004oooool6o`0000gooooo1?l00002ooooo`;o00000_ooool2
o`000003ooooool0003o000000_ooooo2?l000001?oooooo0000o`000?ooool3o`000004ooooool0
003o0000ooooo`;o00000oooool2o`000003ooooool0003o000000Gooooo0_l0000Mooooo`;o0000
Coooool001cooooo00?o0000ooooooooool0J_ooool2o`0000Wooooo0_l0000Fooooo`?o00003Ooo
ool3o`0000?ooooo0_l00003ooooo`?o00003Oooool7o`000003ooooool0003o000000Co000000?o
ooooo`000?l000002Oooool2o`0000Gooooo0_l0001^ooooo`007?ooool00ol0003oooooooooo`1P
ooooo`?o00001oooool2o`0000kooooo0_l0000<ooooo`;o00003oooool2o`0000Wooooo0_l00002
ooooo`Go000000?oooooo`000?l000002?ooool2o`000003ooooool0003o000000;o000000?ooooo
o`000?l000000_l00003ooooo`;o0000P?ooool001cooooo00?o0000ooooooooool0G_ooool5o`00
01Oooooo0_l000000ooooooo0000o`000009ooooo`;o00000oooool2o`0000[ooooo0_l00009oooo
o`;o00001Oooool2o`000003ooooool0003o000000_ooooo0ol0000@ooooo`;o00001_ooool2o`00
077ooooo000Looooo`03o`000?oooooooooo05Sooooo0_l00004ooooo`Oo00001?ooool2o`000003
ooooool0003o000000;o000000?oooooo`000?l000002Oooool3o`0000gooooo0ol0000?ooooo`;o
00000_ooool2o`000003ooooool0003o000000;o00004oooool2o`0000oooooo0ol00006ooooo`;o
0000LOooool001cooooo00?o0000ooooooooool0F?ooool2o`0000Kooooo1Ol00004ooooo`;o0000
00?oooooo`000?l000000_l000000ooooooo0000o`000009ooooo`;o00003_ooool2o`0000?ooooo
0_l0000;ooooo`;o00000_ooool2o`000003ooooool0003o000000;o00001_ooool2o`000003oooo
ool0003o000000Oooooo0ol0000?ooooo`;o00007Oooool2o`0005_ooooo000Looooo`03o`000?oo
oooooooo07;ooooo0ol00007ooooo`;o00004oooool2o`0000gooooo1?l000001?oooooo0000o`00
0?ooool2o`0000Gooooo0_l000000ooooooo0000o`000007ooooo`?o00006Oooool2o`0001?ooooo
0_l0001Kooooo`007?ooool00ol0003oooooooooo`1booooo`?o0000:?ooool2o`000003ooooool0
003o000000Go000000?oooooo`000?l000005?ooool2o`0001Oooooo0_l0001`ooooo`007?ooool0
0ol0003oooooooooo`1cooooo`;o00005Oooool2o`00017ooooo0_l00004ooooo`?o00004?ooool2
o`0000Kooooo0_l000000ooooooo0000o`000026ooooo`007?ooool00ol0003oooooooooo`2:oooo
o`;o00000oooool2o`0000_ooooo0_l00006ooooo`;o00002_ooool2o`0000Cooooo0_l00004oooo
o`?o00000_ooool2o`0000_ooooo0_l00002ooooo`;o00005Oooool3o`0005gooooo000Looooo`03
o`000?oooooooooo05oooooo0_l0000>ooooo`;o00005?ooool2o`0000?ooooo0_l00002ooooo`?o
00002oooool2o`000003ooooool0003o000000?ooooo0_l00006ooooo`;o00000_ooool2o`0000Ko
oooo0_l00002ooooo`?o00002oooool2o`0000;ooooo0_l00002ooooo`;o00003oooool2o`0000Co
oooo0ol0001Mooooo`007?ooool00ol0003oooooooooo`1Oooooo`;o00003_ooool2o`0000Oooooo
0_l0000;ooooo`;o000000?oooooo`000?l000000_l00002ooooo`?o00002?ooool2o`0000Cooooo
0_l00009ooooo`Ko00000_ooool2o`0000Cooooo0_l0000@ooooo`;o00000_ooool2o`0001?ooooo
0_l0001Tooooo`007?ooool00ol0003oooooooooo`1/ooooo`;o00002_ooool3o`0000gooooo0_l0
0005ooooo`;o00000oooool4o`000003ooooool0003o000000oooooo0_l00002ooooo`;o00000_oo
ool2o`0002oooooo0_l0001Tooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q
1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0I?ooool2o`0000;o
oooo0_l00002ooooo`;o00002oooool2o`0001Wooooo1?l00007ooooo`;o00003Oooool2o`0000go
oooo0_l0000Tooooo`;o0000I?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q
8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo06Cooooo0_l00002
ooooo`;o00002_ooool2o`0000oooooo0_l0000:ooooo`;o00002Oooool5o`0000gooooo0_l0000=
ooooo`;o00003oooool2o`000003ooooool0003o000007Kooooo00000ooooooo410@ooooo`02oooo
o`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo06[ooooo0_l00008ooooo`;o00003oooool2o`0000Wooooo0ol00009ooooo`?o00004?ooool2
o`0000cooooo0_l0000?ooooo`;o000000?oooooo`000?l00000M_ooool00003ooooool0003ooooo
00;ooooo00?o0000ooooooooool02Oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0001Z
ooooo`;o00002Oooool2o`0001Wooooo0_l00003ooooo`;o00006?ooool2o`0000cooooo0_l0002:
ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05olc<c?l0003o0000
o`000?o<c<`01_ooool00ol0003oooooooooo`1Vooooo`;o00001Oooool2o`0000Kooooo0_l0000B
ooooo`;o00002_ooool2o`0003Gooooo0_l0001kooooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`1V
ooooo`Co00000oooool2o`0000Oooooo0_l0000Aooooo`;o0000:oooool2o`0001Cooooo0_l0001k
ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`1Xooooo`;o00000oooool2o`0000Kooooo0ol00005ooooo`;o0000
2oooool2o`0000Oooooo0_l0000=ooooo`Co00001?ooool2o`0000Oooooo0_l000000ooooooo0000
o`00000Booooo`;o000000?oooooo`000?l000001_ooool2o`0007;ooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo
06oooooo0_l00004ooooo`;o00001_ooool2o`000003ooooool0003o000000?ooooo0_l00003oooo
o`;o00000_ooool2o`0000;ooooo1Ol0000;ooooo`Co00001?ooool2o`0000Oooooo0_l00002oooo
o`Co00003oooool2o`000003ooooool0003o000000Kooooo0_l0001booooo`007?ooool00ol0003o
ooooooooo`1_ooooo`;o00003oooool2o`0000?ooooo0_l00007ooooo`;o00000_ooool6o`0001oo
oooo2?l0000?ooooo`;o0000NOooool001cooooo00?o0000ooooooooool0Koooool2o`0002Gooooo
0_l0000>ooooo`;o00002?ooool2o`0000Wooooo1?l0000?ooooo`;o0000NOooool001cooooo00?o
0000ooooooooool0Koooool4o`0000oooooo0_l0000;ooooo`?o00004?ooool2o`0000;ooooo0_l0
0006ooooo`Co00000_ooool2o`0000;ooooo0_l0002?ooooo`007?ooool00ol0003oooooooooo`1a
ooooo`;o00001_ooool2o`0000Oooooo0_l00007ooooo`;o00000_ooool3o`0000Cooooo0_l0000:
ooooo`;o00002_ooool2o`0000Cooooo0_l00002ooooo`;o0000Soooool001cooooo00?o0000oooo
ooooool0N?ooool3o`00013ooooo1?l00007ooooo`;o0000/Oooool001cooooo00?o0000oooooooo
ool0Moooool3o`0000Kooooo0_l0000;ooooo`;o000000Coooooo`000?l0003o00006?ooool2o`00
00[ooooo0_l0002@ooooo`007?ooool00ol0003oooooooooo`1gooooo`;o00001?ooool2o`000003
ooooool0003o000000Gooooo0_l00007ooooo`?o00006?ooool2o`0000[ooooo1_l0002<ooooo`00
7?ooool00ol0003oooooooooo`1mooooo`;o00001oooool3o`0001Sooooo0_l0000:ooooo`;o0000
2_ooool4o`0008cooooo000Looooo`03o`000?oooooooooo07cooooo0_l00008ooooo`;o00004Ooo
ool2o`0000Kooooo0_l00003ooooo`Co00000oooool2o`0009[ooooo000Looooo`03o`000?oooooo
oooo07cooooo0_l0000Kooooo`;o00002oooool4o`0009oooooo000Looooo`03o`000?oooooooooo
08Kooooo1Ol00004ooooo`;o0000^?ooool001cooooo0_l00027ooooo`Ko00000oooool2o`000;So
oooo000Looooo`03o`000?oooooooooo08[ooooo0_l0002mooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo08Gooooo0_l00032ooooo`007?ooool00ol0
003oooooooooo`25ooooo`;o0000`_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`2Fooooo`;o0000/Oooool001cooooo00?o0000ooooooooool0U_oo
ool2o`000;7ooooo000Looooo`03o`000?oooooooooo093ooooo0_l0002gooooo`007?ooool00ol0
003oooooooooo`2@ooooo`;o00000_ooool2o`000;?ooooo000Looooo`03o`000?oooooooooo09Co
oooo0_l0002cooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Booooo`Co000000?o410@ooooooooool0
0oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`?o0000oooooom:
ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?oo
ooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003ooooooooo
o`3ooooooe;ooooo000Booooo`03oeEEEOmVIVKo00000?ooooooE?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00:Gooooo00Co410@o`000?l0003ooooo0_l000000ol@413ooooo
ooooo`0Gooooo`03o`000?o^k^kooooo00Gooooo0_l000000ol@413oooooooooo`03ooooo`;o0000
00?o410@ooooooooool0S_ooool00:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko0000
2oooool00omEEEGoZJVYooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
Soooool00:Kooooo00Go0000ooooooooooooooooo`00000Jooooo`03ojVYZOmEEEGooooo00?ooooo
1Ol00003ooooo`Go0000T?ooool00:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko0000
3?ooool00olQ8B7oooooooooo`02ooooo`04odA4A?oMgMgoooooo`0000Cooooo00CoA4A4omgMgOoo
oooo0000TOooool00:Kooooo00Go0000ohN7QoooooooZJVYo`00000Kooooo`03oeEEEOo<c<cooooo
00;ooooo00CogMgMoeEEEOoooooo00001?ooool01?oMgMgoEEEEooooool0002Aooooo`00YOooool0
0ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo01Wooooo00?oZJVYogMgMoooool00oooool0
0omgMgOoc<c<o`000005ooooo`03ogMgMoo<c<co0000097ooooo0033ooooo`05oa0@4?oooooooooo
oooooolb<S801?ooool00oo^k^koA4A4o`000005ooooo`03onk^k_m4A4Co0000097ooooo0033oooo
o`Go00001Oooool00omgMgOo0000ooooo`05ooooo`03ogMgMol0003ooooo093ooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(750) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.69531 .43103 Mdot
.68633 .41917 Mdot
.33616 .4268 Mdot
.53914 .63943 Mdot
.42957 .561 Mdot
.3266 .47802 Mdot
.46363 .3748 Mdot
.49763 .34942 Mdot
.34097 .46405 Mdot
.67128 .50796 Mdot
.45607 .39262 Mdot
.64586 .63927 Mdot
.4733 .37185 Mdot
.59414 .62207 Mdot
.29823 .24553 Mdot
.60132 .56168 Mdot
.65105 .39425 Mdot
.41867 .64032 Mdot
.55724 .54741 Mdot
.3542 .4499 Mdot
.71708 .42976 Mdot
.59304 .61719 Mdot
.6884 .40933 Mdot
.59281 .621 Mdot
.55548 .64025 Mdot
.65493 .43419 Mdot
.70206 .40824 Mdot
.54617 .61055 Mdot
.58156 .64232 Mdot
.4485 .35694 Mdot
.38719 .5564 Mdot
.18012 .38374 Mdot
.62185 .57562 Mdot
.69342 .71064 Mdot
.47686 .34122 Mdot
.28883 .70774 Mdot
.33332 .44296 Mdot
.49261 .39446 Mdot
.48648 .34197 Mdot
.49373 .35748 Mdot
.49239 .37546 Mdot
.66064 .43528 Mdot
.4415 .39476 Mdot
.5148 .33478 Mdot
.53195 .63016 Mdot
.55442 .29564 Mdot
.33191 .68911 Mdot
.55083 .60692 Mdot
.67353 .44732 Mdot
.35915 .46932 Mdot
.76026 .68119 Mdot
.50301 .38981 Mdot
.44132 .26531 Mdot
.26582 .20049 Mdot
.47946 .35504 Mdot
.5355 .62538 Mdot
.31788 .45321 Mdot
.58225 .59152 Mdot
.57881 .60813 Mdot
.76467 .64705 Mdot
.56595 .62939 Mdot
.39031 .61161 Mdot
.67363 .37527 Mdot
.29582 .41958 Mdot
.33444 .47067 Mdot
.46478 .34351 Mdot
.62916 .41234 Mdot
.47724 .38117 Mdot
.53061 .66966 Mdot
.35342 .46767 Mdot
.54973 .60485 Mdot
.46204 .39602 Mdot
.62293 .44487 Mdot
.61983 .61797 Mdot
.58993 .31024 Mdot
.36366 .2171 Mdot
.39542 .65901 Mdot
.74896 .63555 Mdot
.77545 .39481 Mdot
.3698 .25639 Mdot
.58922 .63056 Mdot
.74955 .27015 Mdot
.31449 .2359 Mdot
.68212 .40651 Mdot
.51501 .69668 Mdot
.34629 .40286 Mdot
.61363 .62253 Mdot
.43439 .51329 Mdot
.59907 .67615 Mdot
.66399 .32937 Mdot
.34063 .45847 Mdot
.66099 .44318 Mdot
.53826 .64287 Mdot
.61418 .58909 Mdot
.76502 .50936 Mdot
.61369 .65718 Mdot
.54099 .60068 Mdot
.70711 .40316 Mdot
.4479 .37152 Mdot
.6035 .68553 Mdot
.49492 .31188 Mdot
.44303 .25258 Mdot
.5749 .66231 Mdot
.34175 .47845 Mdot
.66367 .38526 Mdot
.56298 .66524 Mdot
.47593 .34906 Mdot
.57316 .62403 Mdot
.46728 .31334 Mdot
.68871 .43148 Mdot
.61413 .59069 Mdot
.41847 .63261 Mdot
.64177 .3045 Mdot
.6399 .44389 Mdot
.64653 .22017 Mdot
.56243 .62066 Mdot
.5902 .61044 Mdot
.68398 .419 Mdot
.30253 .45748 Mdot
.42085 .50791 Mdot
.62278 .42221 Mdot
.49106 .34873 Mdot
.69536 .40622 Mdot
.5288 .65624 Mdot
.31329 .48359 Mdot
.43864 .24944 Mdot
.45501 .23447 Mdot
.52441 .78996 Mdot
.61184 .63189 Mdot
.46835 .28763 Mdot
.3153 .47643 Mdot
.67212 .43551 Mdot
.47934 .37904 Mdot
.54102 .5842 Mdot
.64701 .40368 Mdot
.48499 .39234 Mdot
.41514 .62587 Mdot
.25734 .58195 Mdot
.64434 .45393 Mdot
.55465 .4768 Mdot
.44991 .33502 Mdot
.493 .35794 Mdot
.70195 .73453 Mdot
.68243 .4144 Mdot
.39208 .63646 Mdot
.48217 .39156 Mdot
.47634 .71357 Mdot
.54226 .58422 Mdot
.6014 .76006 Mdot
.78557 .33874 Mdot
.74459 .70339 Mdot
.53299 .21312 Mdot
.37145 .60792 Mdot
.49925 .38454 Mdot
.55636 .65287 Mdot
.67103 .41418 Mdot
.67 .42304 Mdot
.59571 .57191 Mdot
.55602 .63279 Mdot
.57165 .57307 Mdot
.59308 .57354 Mdot
.32027 .6753 Mdot
.57783 .57137 Mdot
.30804 .5034 Mdot
.63163 .4255 Mdot
.56542 .64338 Mdot
.30506 .43042 Mdot
.56635 .5558 Mdot
.48922 .39542 Mdot
.58002 .60352 Mdot
.5486 .63079 Mdot
.60667 .65601 Mdot
.49524 .37741 Mdot
.17268 .46364 Mdot
.75946 .32568 Mdot
.20127 .60893 Mdot
.57467 .22102 Mdot
.313 .46095 Mdot
.60806 .61706 Mdot
.40218 .62298 Mdot
.49502 .57904 Mdot
.57622 .61112 Mdot
.8018 .62562 Mdot
.54859 .62131 Mdot
.68279 .67492 Mdot
.57195 .53375 Mdot
.18461 .59535 Mdot
.44527 .44401 Mdot
.57898 .63992 Mdot
.74 .47634 Mdot
.62232 .76691 Mdot
.47076 .58611 Mdot
.48763 .36504 Mdot
.29869 .43912 Mdot
.32055 .44541 Mdot
.43377 .38404 Mdot
.57925 .68886 Mdot
.65226 .51597 Mdot
.58499 .69439 Mdot
.43814 .24321 Mdot
.61723 .41949 Mdot
.36776 .6324 Mdot
.65597 .45589 Mdot
.6738 .20136 Mdot
.60851 .36849 Mdot
.47714 .32551 Mdot
.42401 .62463 Mdot
.31444 .42162 Mdot
.43587 .23927 Mdot
.40126 .62939 Mdot
.55433 .59493 Mdot
.67074 .44601 Mdot
.6377 .76589 Mdot
.55754 .54249 Mdot
.49423 .84122 Mdot
.66739 .39667 Mdot
.45068 .47493 Mdot
.48589 .37205 Mdot
.36231 .47878 Mdot
.60391 .63419 Mdot
.58669 .57839 Mdot
.68615 .38095 Mdot
.55415 .60926 Mdot
.71827 .36387 Mdot
.54573 .62775 Mdot
.28544 .42122 Mdot
.3511 .62288 Mdot
.46884 .41056 Mdot
.54093 .78777 Mdot
.63422 .4615 Mdot
.27018 .48647 Mdot
.3481 .44618 Mdot
.66829 .49552 Mdot
.45133 .39036 Mdot
.41695 .62385 Mdot
.32789 .43317 Mdot
.37204 .59452 Mdot
.58619 .66062 Mdot
.3384 .44522 Mdot
.376 .63561 Mdot
.2281 .56074 Mdot
.53202 .61549 Mdot
.43698 .67856 Mdot
.46358 .38082 Mdot
.70102 .42185 Mdot
.56619 .63066 Mdot
.45626 .23458 Mdot
.51768 .61729 Mdot
.46677 .23377 Mdot
.45031 .26175 Mdot
.44108 .26321 Mdot
.34353 .25134 Mdot
.39133 .60182 Mdot
.5621 .25512 Mdot
.5661 .44141 Mdot
.63042 .40843 Mdot
.53499 .63963 Mdot
.16703 .5189 Mdot
.48339 .39041 Mdot
.55603 .595 Mdot
.31788 .40075 Mdot
.48026 .3914 Mdot
.58995 .59377 Mdot
.49362 .36802 Mdot
.67228 .41733 Mdot
.36163 .52565 Mdot
.67704 .38948 Mdot
.5342 .61569 Mdot
.46778 .35468 Mdot
.31373 .43442 Mdot
.65428 .43203 Mdot
.57253 .62003 Mdot
.60394 .62016 Mdot
.44235 .23773 Mdot
.57122 .64502 Mdot
.17476 .5224 Mdot
.54695 .6079 Mdot
.30115 .42237 Mdot
.61122 .66212 Mdot
.74779 .71735 Mdot
.26207 .57622 Mdot
.6273 .43 Mdot
.44621 .26209 Mdot
.33602 .4579 Mdot
.35259 .53925 Mdot
.50557 .52178 Mdot
.5823 .62765 Mdot
.4516 .25069 Mdot
.42418 .48076 Mdot
.46133 .34445 Mdot
.58369 .67755 Mdot
.61372 .35167 Mdot
.33937 .4357 Mdot
.43755 .23978 Mdot
.62402 .5652 Mdot
.66935 .38429 Mdot
.54038 .6379 Mdot
.33249 .43909 Mdot
.69722 .40868 Mdot
.52792 .5998 Mdot
.33431 .70637 Mdot
.45683 .25223 Mdot
.46552 .38182 Mdot
.61948 .51926 Mdot
.56037 .57614 Mdot
.31298 .44415 Mdot
.67057 .40219 Mdot
.46468 .34919 Mdot
.64591 .43952 Mdot
.62387 .77176 Mdot
.58921 .23345 Mdot
.27484 .65024 Mdot
.42465 .63057 Mdot
.45469 .20743 Mdot
.21246 .63034 Mdot
.59617 .25721 Mdot
.47417 .75974 Mdot
.28376 .73642 Mdot
.31121 .42906 Mdot
.46411 .65913 Mdot
.3294 .45626 Mdot
.56802 .65809 Mdot
.33033 .47617 Mdot
.17333 .58697 Mdot
.54473 .61614 Mdot
.31258 .45725 Mdot
.31885 .62288 Mdot
.5604 .63212 Mdot
.63287 .43671 Mdot
.24162 .30445 Mdot
.74628 .34864 Mdot
.59595 .40186 Mdot
.30696 .45908 Mdot
.81994 .53402 Mdot
.55172 .6181 Mdot
.58892 .55298 Mdot
.66575 .41651 Mdot
.58908 .67867 Mdot
.37949 .6444 Mdot
.38063 .59132 Mdot
.6026 .75286 Mdot
.68615 .25815 Mdot
.53802 .68315 Mdot
.65745 .42903 Mdot
.77571 .40628 Mdot
.58715 .31228 Mdot
.44156 .22145 Mdot
.47094 .33408 Mdot
.17652 .45893 Mdot
.49582 .60909 Mdot
.55409 .48189 Mdot
.60746 .34985 Mdot
.67465 .4402 Mdot
.20662 .55005 Mdot
.47685 .35693 Mdot
.75666 .43266 Mdot
.70005 .60435 Mdot
.5682 .57741 Mdot
.4416 .36782 Mdot
.63379 .66314 Mdot
.69128 .33908 Mdot
.47781 .69023 Mdot
.4232 .30085 Mdot
.53239 .6219 Mdot
.56914 .26472 Mdot
.58563 .6085 Mdot
.58241 .7546 Mdot
.54482 .60035 Mdot
.64138 .43526 Mdot
.55455 .69472 Mdot
.46334 .52224 Mdot
.73111 .29051 Mdot
.62242 .3569 Mdot
.37065 .60467 Mdot
.60061 .61695 Mdot
.57432 .57676 Mdot
.37679 .6115 Mdot
.64745 .42341 Mdot
.5458 .59301 Mdot
.40433 .76654 Mdot
.56327 .57636 Mdot
.48941 .39763 Mdot
.39135 .53908 Mdot
.60453 .46304 Mdot
.61799 .60437 Mdot
.68982 .39119 Mdot
.48718 .35874 Mdot
.48972 .34163 Mdot
.50235 .61455 Mdot
.4985 .38297 Mdot
.54036 .63431 Mdot
.38356 .53423 Mdot
.69132 .41569 Mdot
.63236 .56682 Mdot
.64666 .41894 Mdot
.80569 .4537 Mdot
.48969 .35772 Mdot
.43839 .22593 Mdot
.52365 .52841 Mdot
.47092 .36253 Mdot
.74346 .36305 Mdot
.49471 .63118 Mdot
.52638 .58401 Mdot
.74488 .35873 Mdot
.30239 .44342 Mdot
.43356 .23371 Mdot
.47071 .34961 Mdot
.5668 .57341 Mdot
.58386 .66637 Mdot
.45958 .39751 Mdot
.78255 .52279 Mdot
.35315 .54707 Mdot
.5426 .60322 Mdot
.64176 .43109 Mdot
.6682 .43717 Mdot
.52563 .60692 Mdot
.57108 .61282 Mdot
.29797 .42632 Mdot
.45422 .24719 Mdot
.43303 .25127 Mdot
.45252 .23068 Mdot
.34454 .49625 Mdot
.48142 .22909 Mdot
.49379 .35893 Mdot
.49852 .26829 Mdot
.32415 .37709 Mdot
.51199 .58835 Mdot
.31044 .44206 Mdot
.59399 .58702 Mdot
.579 .65706 Mdot
.46259 .35208 Mdot
.53788 .18367 Mdot
.62407 .69552 Mdot
.67321 .45326 Mdot
.49458 .39842 Mdot
.54689 .53036 Mdot
.4691 .43216 Mdot
.38599 .64523 Mdot
.62259 .36517 Mdot
.44114 .3752 Mdot
.65728 .44685 Mdot
.45071 .39443 Mdot
.57241 .57558 Mdot
.5874 .56423 Mdot
.68638 .42724 Mdot
.39125 .60094 Mdot
.57677 .67013 Mdot
.59039 .59514 Mdot
.8232 .64132 Mdot
.59007 .30486 Mdot
.46049 .42919 Mdot
.57127 .65104 Mdot
.51897 .59039 Mdot
.37622 .59804 Mdot
.55682 .5819 Mdot
.6058 .63179 Mdot
.65431 .3029 Mdot
.43412 .39094 Mdot
.37349 .65069 Mdot
.7542 .42715 Mdot
.66411 .39745 Mdot
.18597 .50475 Mdot
.44328 .2547 Mdot
.45792 .41224 Mdot
.36358 .52325 Mdot
.44064 .22975 Mdot
.35536 .37367 Mdot
.19656 .5253 Mdot
.4445 .22678 Mdot
.37341 .50261 Mdot
.52959 .70073 Mdot
.56284 .56687 Mdot
.58166 .60087 Mdot
.4056 .62557 Mdot
.67912 .41345 Mdot
.4363 .4558 Mdot
.22456 .52281 Mdot
.59194 .61473 Mdot
.71203 .38732 Mdot
.20145 .49289 Mdot
.4402 .23578 Mdot
.39559 .60868 Mdot
.36771 .63613 Mdot
.58881 .60797 Mdot
.63824 .27866 Mdot
.65676 .43255 Mdot
.57281 .61996 Mdot
.60739 .58792 Mdot
.30569 .4549 Mdot
.65846 .44882 Mdot
.34877 .44803 Mdot
.45413 .2604 Mdot
.36838 .7987 Mdot
.80817 .66268 Mdot
.4555 .36575 Mdot
.20488 .59633 Mdot
.50748 .36442 Mdot
.39765 .25773 Mdot
.45355 .23453 Mdot
.58168 .61917 Mdot
.63128 .45582 Mdot
.5714 .62288 Mdot
.56258 .58491 Mdot
.55482 .59191 Mdot
.54414 .68731 Mdot
.797 .63468 Mdot
.39133 .62699 Mdot
.51014 .60835 Mdot
.28997 .45295 Mdot
.18869 .56142 Mdot
.2289 .33732 Mdot
.60666 .59773 Mdot
.59344 .60857 Mdot
.63459 .40973 Mdot
.6207 .59313 Mdot
.45179 .35039 Mdot
.67888 .40302 Mdot
.57734 .66701 Mdot
.21738 .57 Mdot
.54925 .58393 Mdot
.22332 .64182 Mdot
.45356 .39584 Mdot
.61874 .37 Mdot
.51205 .63379 Mdot
.44492 .22623 Mdot
.43407 .23242 Mdot
.43738 .21856 Mdot
.44838 .3491 Mdot
.31085 .45039 Mdot
.23307 .46276 Mdot
.6369 .64065 Mdot
.55231 .64929 Mdot
.51573 .59882 Mdot
.3644 .48336 Mdot
.41032 .53356 Mdot
.53834 .22389 Mdot
.50892 .56484 Mdot
.29396 .45376 Mdot
.69853 .43919 Mdot
.62159 .19443 Mdot
.67601 .40274 Mdot
.36907 .6483 Mdot
.47753 .39791 Mdot
.39113 .64694 Mdot
.81773 .57679 Mdot
.68921 .42538 Mdot
.68797 .38149 Mdot
.31209 .459 Mdot
.47283 .46006 Mdot
.15605 .33488 Mdot
.33675 .48567 Mdot
.4478 .77865 Mdot
.66122 .41983 Mdot
.62245 .62774 Mdot
.41673 .4855 Mdot
.47368 .46389 Mdot
.32321 .46252 Mdot
.59329 .62973 Mdot
.68741 .2724 Mdot
.30081 .42463 Mdot
.58436 .67601 Mdot
.3074 .4709 Mdot
.49205 .38099 Mdot
.31245 .47404 Mdot
.66634 .46255 Mdot
.5864 .65859 Mdot
.21653 .25097 Mdot
.53596 .40447 Mdot
.56863 .62974 Mdot
.49513 .39731 Mdot
.39062 .76891 Mdot
.57338 .58277 Mdot
.38436 .64728 Mdot
.29878 .47521 Mdot
.33137 .56962 Mdot
.55512 .62046 Mdot
.32339 .47229 Mdot
.68555 .44798 Mdot
.47646 .42216 Mdot
.36224 .23667 Mdot
.43164 .24373 Mdot
.67328 .41002 Mdot
.42655 .22157 Mdot
.44703 .3419 Mdot
.59961 .66527 Mdot
.59925 .57993 Mdot
.63479 .4297 Mdot
.33006 .29216 Mdot
.62963 .6177 Mdot
.58926 .63041 Mdot
.33318 .42698 Mdot
.37194 .482 Mdot
.27005 .3232 Mdot
.30999 .4304 Mdot
.51632 .59461 Mdot
.63558 .43169 Mdot
.56193 .66032 Mdot
.63094 .43455 Mdot
.53553 .6402 Mdot
.61943 .38961 Mdot
.67763 .40575 Mdot
.63016 .23333 Mdot
.59218 .64484 Mdot
.59261 .52512 Mdot
.55925 .58597 Mdot
.54909 .59599 Mdot
.30279 .48141 Mdot
.37896 .6214 Mdot
.61445 .6642 Mdot
.29721 .50642 Mdot
.40644 .61384 Mdot
.66046 .71794 Mdot
.30419 .45369 Mdot
.40787 .63115 Mdot
.38593 .68777 Mdot
.44492 .26161 Mdot
.39359 .61992 Mdot
.222 .36798 Mdot
.45664 .36212 Mdot
.68852 .4021 Mdot
.56062 .63331 Mdot
.31784 .77093 Mdot
.3804 .55402 Mdot
.4483 .238 Mdot
.56075 .62189 Mdot
.58871 .58458 Mdot
.65435 .38876 Mdot
.7101 .22943 Mdot
.3549 .43741 Mdot
.54528 .6497 Mdot
.655 .39373 Mdot
.77991 .32674 Mdot
.31958 .48639 Mdot
.39769 .61892 Mdot
.47773 .40267 Mdot
.67971 .46615 Mdot
.43089 .24201 Mdot
.46615 .341 Mdot
.38807 .48099 Mdot
.82817 .53277 Mdot
.55479 .61475 Mdot
.31706 .43953 Mdot
.74946 .69763 Mdot
.59712 .68353 Mdot
.42579 .39487 Mdot
.6661 .67547 Mdot
.67096 .44148 Mdot
.47046 .40085 Mdot
.36399 .61552 Mdot
.69166 .41125 Mdot
.6472 .42534 Mdot
.49977 .3533 Mdot
.27227 .4601 Mdot
.45372 .47423 Mdot
.47593 .40055 Mdot
.66917 .32484 Mdot
.64288 .75469 Mdot
.45282 .25145 Mdot
.39222 .60577 Mdot
.64844 .77015 Mdot
.65914 .43609 Mdot
.17577 .46029 Mdot
.78748 .64505 Mdot
.54104 .6007 Mdot
.3925 .64131 Mdot
.35922 .38463 Mdot
.23013 .46578 Mdot
.47511 .39149 Mdot
.42995 .52879 Mdot
.38628 .65004 Mdot
.55161 .57704 Mdot
.60619 .47217 Mdot
.58962 .64397 Mdot
.48872 .38999 Mdot
.72492 .36033 Mdot
.65124 .44785 Mdot
.44159 .34818 Mdot
.70466 .34982 Mdot
.582 .65594 Mdot
.59509 .63696 Mdot
.54143 .75702 Mdot
.67088 .4467 Mdot
.43053 .2457 Mdot
.5777 .62987 Mdot
.58098 .59332 Mdot
.60503 .6618 Mdot
.59263 .51593 Mdot
.62591 .28727 Mdot
.5476 .65289 Mdot
.33542 .49526 Mdot
.55247 .56142 Mdot
.5972 .6373 Mdot
.66748 .38851 Mdot
.81215 .64131 Mdot
.4589 .25392 Mdot
.57864 .59959 Mdot
.54602 .60096 Mdot
.48674 .34363 Mdot
.43652 .47569 Mdot
.48215 .46171 Mdot
.35033 .47235 Mdot
.46359 .74103 Mdot
.57265 .69206 Mdot
.6507 .4028 Mdot
.41647 .63912 Mdot
.61352 .63862 Mdot
.64876 .40049 Mdot
.55576 .56456 Mdot
.29454 .43342 Mdot
.45323 .24751 Mdot
.58426 .45979 Mdot
.39046 .61538 Mdot
.40893 .44049 Mdot
.52012 .29326 Mdot
.30191 .43268 Mdot
.55453 .64581 Mdot
.49044 .41304 Mdot
.34779 .45469 Mdot
.44413 .23863 Mdot
.61335 .55308 Mdot
.66674 .42439 Mdot
.65 .44573 Mdot
.59588 .75474 Mdot
.35704 .43443 Mdot
.84954 .46431 Mdot
.49175 .38228 Mdot
.53091 .65209 Mdot
.50269 .30548 Mdot
.64549 .44559 Mdot
.58361 .76666 Mdot
.40831 .62833 Mdot
.47221 .39067 Mdot
.45675 .22812 Mdot
.64271 .40459 Mdot
.65415 .45279 Mdot
.53032 .6186 Mdot
.6053 .60391 Mdot
.47208 .76492 Mdot
.59598 .75941 Mdot
.4934 .37335 Mdot
.38536 .60491 Mdot
.35554 .47254 Mdot
.57522 .65416 Mdot
.68423 .40728 Mdot
.67957 .68242 Mdot
.56564 .57175 Mdot
.30087 .42403 Mdot
.67736 .43662 Mdot
.37808 .60762 Mdot
.41103 .63715 Mdot
.54929 .59555 Mdot
.75954 .63771 Mdot
.46684 .36453 Mdot
.63731 .44249 Mdot
.65111 .49063 Mdot
.62834 .62961 Mdot
.6062 .60758 Mdot
.64759 .6254 Mdot
.46764 .34117 Mdot
.59394 .46151 Mdot
.40705 .65204 Mdot
.67364 .42479 Mdot
.5699 .62826 Mdot
.39076 .61185 Mdot
.58861 .49156 Mdot
.44861 .23117 Mdot
.30917 .47404 Mdot
.37691 .64333 Mdot
.37448 .62813 Mdot
.40896 .61487 Mdot
.18293 .44658 Mdot
.61773 .42584 Mdot
.76182 .39475 Mdot
.54457 .59591 Mdot
.59629 .75241 Mdot
.61478 .58215 Mdot
.44688 .34732 Mdot
.30502 .43663 Mdot
.56562 .58143 Mdot
.53012 .62024 Mdot
.64681 .5458 Mdot
.56123 .52764 Mdot
.72074 .41195 Mdot
.6824 .43923 Mdot
.58226 .52194 Mdot
.3039 .44687 Mdot
.76052 .26871 Mdot
.14312 .48535 Mdot
.52088 .65225 Mdot
.44565 .464 Mdot
.68048 .40486 Mdot
.5011 .35911 Mdot
.48748 .46748 Mdot
.4736 .40461 Mdot
.67577 .42726 Mdot
.57086 .65661 Mdot
.5033 .26773 Mdot
.38698 .59471 Mdot
.57757 .57274 Mdot
.48642 .37679 Mdot
.57446 .57271 Mdot
.44112 .35988 Mdot
.71064 .36912 Mdot
.61923 .33787 Mdot
.54763 .61964 Mdot
.62546 .63238 Mdot
.63626 .53116 Mdot
.60632 .59869 Mdot
.37346 .34003 Mdot
.65445 .41498 Mdot
.68475 .26345 Mdot
.5276 .60569 Mdot
.78456 .58553 Mdot
.56178 .57109 Mdot
.3262 .30471 Mdot
.61189 .6107 Mdot
.4915 .49156 Mdot
.547 .58061 Mdot
.6068 .61961 Mdot
.47062 .35282 Mdot
.48886 .34445 Mdot
.68135 .45068 Mdot
.42943 .23861 Mdot
.18512 .59067 Mdot
.59664 .59954 Mdot
.32812 .49749 Mdot
.51896 .32136 Mdot
.37564 .62529 Mdot
.67181 .43037 Mdot
.81058 .35181 Mdot
.49066 .36217 Mdot
.28882 .42114 Mdot
.34455 .30154 Mdot
.36186 .46542 Mdot
.47531 .30846 Mdot
.5562 .52318 Mdot
.37835 .604 Mdot
.55987 .57117 Mdot
.69693 .70388 Mdot
.57708 .28271 Mdot
.56179 .67 Mdot
.4319 .37023 Mdot
.49085 .58391 Mdot
.65996 .75229 Mdot
.36139 .60829 Mdot
.36681 .61593 Mdot
.47408 .35223 Mdot
.34763 .4359 Mdot
.60667 .6892 Mdot
.4084 .63175 Mdot
.29568 .44306 Mdot
.42766 .23287 Mdot
.48797 .54397 Mdot
.6597 .43275 Mdot
.58933 .41342 Mdot
.55707 .32602 Mdot
.49296 .37135 Mdot
.31402 .51535 Mdot
.69239 .45356 Mdot
.65746 .38445 Mdot
.43292 .2279 Mdot
.29902 .47823 Mdot
.62226 .44789 Mdot
.58576 .66952 Mdot
.55213 .54295 Mdot
.58546 .60977 Mdot
.40256 .63626 Mdot
.61377 .60591 Mdot
.29058 .46058 Mdot
.48092 .38813 Mdot
.34252 .45521 Mdot
.46402 .3652 Mdot
.50828 .25018 Mdot
.56616 .61206 Mdot
.60276 .61291 Mdot
.39502 .51527 Mdot
.66539 .45376 Mdot
.7824 .62698 Mdot
.32046 .49761 Mdot
.32216 .45353 Mdot
.56621 .66212 Mdot
.68995 .44346 Mdot
.35546 .5951 Mdot
.39705 .50224 Mdot
.61114 .5971 Mdot
.65518 .41375 Mdot
.54779 .64939 Mdot
.27594 .63967 Mdot
.60893 .33439 Mdot
.64591 .44107 Mdot
.7089 .26392 Mdot
.57994 .64761 Mdot
.49639 .67148 Mdot
.52033 .5865 Mdot
.41276 .75068 Mdot
.62493 .64194 Mdot
.66981 .39631 Mdot
.58004 .60542 Mdot
.66418 .40262 Mdot
.32128 .42472 Mdot
.49923 .36556 Mdot
.67027 .40989 Mdot
.61917 .61043 Mdot
.17266 .4236 Mdot
.48951 .37718 Mdot
.60223 .61962 Mdot
.44533 .37594 Mdot
.66679 .3922 Mdot
.67362 .4496 Mdot
.22505 .37078 Mdot
.43698 .41915 Mdot
.49025 .37345 Mdot
.54507 .64162 Mdot
.55828 .36202 Mdot
.56095 .65968 Mdot
.48197 .7685 Mdot
.52591 .63434 Mdot
.60973 .66429 Mdot
.40497 .18942 Mdot
.50327 .39878 Mdot
.83272 .42546 Mdot
.22598 .53486 Mdot
.18908 .43158 Mdot
.64215 .47612 Mdot
.36128 .60843 Mdot
.20326 .53567 Mdot
.45223 .2605 Mdot
.30461 .47661 Mdot
.56485 .58128 Mdot
.60656 .40778 Mdot
.48876 .39985 Mdot
.38082 .62648 Mdot
.548 .62066 Mdot
.29431 .42974 Mdot
.24109 .34396 Mdot
.49878 .38525 Mdot
.66186 .43486 Mdot
.66943 .45342 Mdot
.7677 .32298 Mdot
.56678 .62583 Mdot
.59944 .61337 Mdot
.48103 .39767 Mdot
.56838 .68916 Mdot
.40751 .60871 Mdot
.30434 .63488 Mdot
.48848 .36999 Mdot
.54252 .39336 Mdot
.68996 .43018 Mdot
.59068 .58501 Mdot
.40107 .54394 Mdot
.2613 .38969 Mdot
.70701 .49896 Mdot
.40451 .6254 Mdot
.50078 .75959 Mdot
.6692 .39634 Mdot
.48214 .37811 Mdot
.43433 .66657 Mdot
.5182 .62422 Mdot
.58755 .58665 Mdot
.50679 .75907 Mdot
.42966 .47479 Mdot
.36433 .58564 Mdot
.62283 .59572 Mdot
.42921 .48348 Mdot
.56894 .66248 Mdot
.58347 .66582 Mdot
.52837 .66531 Mdot
.61168 .62293 Mdot
.66005 .40862 Mdot
.64864 .54551 Mdot
.31956 .47648 Mdot
.76517 .49744 Mdot
.44532 .5184 Mdot
.56962 .63854 Mdot
.57415 .65636 Mdot
.69504 .48663 Mdot
.52307 .33156 Mdot
.65536 .4183 Mdot
.62371 .39283 Mdot
.48723 .35198 Mdot
.58053 .52874 Mdot
.36427 .45821 Mdot
.66796 .64408 Mdot
.34486 .46014 Mdot
.65491 .4128 Mdot
.31694 .44886 Mdot
.48503 .34853 Mdot
.3184 .43944 Mdot
.34311 .49614 Mdot
.43999 .38263 Mdot
.69158 .43078 Mdot
.6099 .59713 Mdot
.49208 .36115 Mdot
.53766 .75968 Mdot
.40301 .6366 Mdot
.22495 .36997 Mdot
.57615 .5505 Mdot
.59129 .72388 Mdot
.33415 .70566 Mdot
.33696 .45021 Mdot
.62193 .32195 Mdot
.67761 .40596 Mdot
.41922 .61732 Mdot
.66276 .40568 Mdot
.80023 .6177 Mdot
.37851 .61277 Mdot
.2214 .37206 Mdot
.41928 .66613 Mdot
.29612 .52319 Mdot
.60606 .57721 Mdot
.65976 .36612 Mdot
.34655 .44993 Mdot
.49155 .39689 Mdot
.3629 .40625 Mdot
.60742 .63748 Mdot
.59111 .25327 Mdot
.624 .40912 Mdot
.43824 .25778 Mdot
.47708 .37927 Mdot
.43111 .36473 Mdot
.56427 .62099 Mdot
.33982 .53386 Mdot
.55162 .66278 Mdot
.45097 .64008 Mdot
.47921 .7543 Mdot
.66834 .64771 Mdot
.53867 .63374 Mdot
.34912 .46486 Mdot
.54742 .64804 Mdot
.48825 .64141 Mdot
.69848 .73609 Mdot
.57017 .54947 Mdot
.60105 .2307 Mdot
.35394 .56895 Mdot
.68722 .42323 Mdot
.51018 .63263 Mdot
.44666 .24596 Mdot
.57528 .64985 Mdot
.44922 .8662 Mdot
.39029 .62037 Mdot
.35414 .42212 Mdot
.61576 .58853 Mdot
.5742 .62685 Mdot
.71675 .67493 Mdot
.63428 .36826 Mdot
.45992 .23449 Mdot
.58233 .58734 Mdot
.47393 .73137 Mdot
.45897 .34983 Mdot
.52153 .6292 Mdot
.58365 .60391 Mdot
.61103 .77953 Mdot
.45071 .35815 Mdot
.33056 .44613 Mdot
.4486 .26233 Mdot
.35453 .47641 Mdot
.35833 .62297 Mdot
.50291 .45581 Mdot
.59459 .76462 Mdot
.60561 .33524 Mdot
.3913 .64926 Mdot
.60895 .58556 Mdot
.54994 .71906 Mdot
.58506 .63728 Mdot
.36583 .6145 Mdot
.44762 .35892 Mdot
.66263 .41041 Mdot
.57847 .45166 Mdot
.43905 .24217 Mdot
.58647 .67496 Mdot
.36463 .60405 Mdot
.66907 .41755 Mdot
.25803 .35717 Mdot
.68028 .41958 Mdot
.47389 .36126 Mdot
.44968 .34214 Mdot
.38217 .61379 Mdot
.66057 .40657 Mdot
.3365 .49237 Mdot
.22714 .53194 Mdot
.52875 .63866 Mdot
.47953 .42786 Mdot
.64829 .46514 Mdot
.70127 .40286 Mdot
.6241 .43797 Mdot
.56048 .6128 Mdot
.44098 .47045 Mdot
.52105 .64404 Mdot
.48021 .35227 Mdot
.30198 .4661 Mdot
.60433 .76034 Mdot
.72083 .68548 Mdot
.5407 .40051 Mdot
.61371 .6641 Mdot
.603 .63185 Mdot
.58893 .60819 Mdot
.53848 .6095 Mdot
.29372 .64588 Mdot
.56848 .61143 Mdot
.46685 .35739 Mdot
.33621 .47923 Mdot
.56345 .62593 Mdot
.44705 .2492 Mdot
.45373 .48528 Mdot
.41385 .642 Mdot
.47993 .49462 Mdot
.15801 .46668 Mdot
.66792 .41713 Mdot
.32516 .43394 Mdot
.30975 .47912 Mdot
.41521 .62579 Mdot
.49474 .38148 Mdot
.67897 .41589 Mdot
.39956 .73338 Mdot
.40124 .60698 Mdot
.57762 .59926 Mdot
.37664 .52923 Mdot
.67407 .23227 Mdot
.59141 .57082 Mdot
.56347 .59001 Mdot
.44327 .26374 Mdot
.35789 .44453 Mdot
.32299 .79159 Mdot
.41829 .46563 Mdot
.38007 .61873 Mdot
.36959 .62258 Mdot
.62228 .4338 Mdot
.55976 .67148 Mdot
.46441 .37174 Mdot
.41006 .49419 Mdot
.42444 .79043 Mdot
.29762 .40026 Mdot
.39212 .25578 Mdot
.55121 .5843 Mdot
.71555 .65588 Mdot
.53786 .64615 Mdot
.65745 .38716 Mdot
.62655 .4189 Mdot
.65571 .42388 Mdot
.47429 .35497 Mdot
.80633 .46182 Mdot
.4644 .3591 Mdot
.15401 .47219 Mdot
.68245 .40171 Mdot
.27225 .54672 Mdot
.31452 .45314 Mdot
.63326 .64638 Mdot
.38233 .60338 Mdot
.53134 .35807 Mdot
.52357 .66302 Mdot
.62855 .27542 Mdot
.31098 .44201 Mdot
.68125 .44454 Mdot
.49065 .61499 Mdot
.19675 .63745 Mdot
.49187 .44949 Mdot
.44826 .59746 Mdot
.7766 .64191 Mdot
.37771 .61096 Mdot
.70973 .48784 Mdot
.40002 .60187 Mdot
.48298 .3921 Mdot
.60888 .63556 Mdot
.6129 .62773 Mdot
.53664 .63635 Mdot
.56592 .60966 Mdot
.46624 .3482 Mdot
.53313 .60209 Mdot
.74793 .71702 Mdot
.45219 .25632 Mdot
.24445 .58591 Mdot
.39967 .64418 Mdot
.43635 .38025 Mdot
.34251 .47084 Mdot
.42846 .2376 Mdot
.55228 .78739 Mdot
.5423 .59272 Mdot
.56183 .58392 Mdot
.44682 .22404 Mdot
.53934 .67508 Mdot
.49371 .60963 Mdot
.32292 .47646 Mdot
.5421 .41796 Mdot
.36394 .62751 Mdot
.38998 .64675 Mdot
.44322 .38421 Mdot
.66224 .40555 Mdot
.40668 .62488 Mdot
.3423 .43119 Mdot
.53477 .59098 Mdot
.61517 .64608 Mdot
.64941 .46502 Mdot
.78767 .64492 Mdot
.36641 .59607 Mdot
.49931 .64912 Mdot
.66433 .39978 Mdot
.62077 .41381 Mdot
.58224 .58541 Mdot
.6156 .55963 Mdot
.69997 .4085 Mdot
.4069 .64314 Mdot
.43695 .38211 Mdot
.28746 .52789 Mdot
.48754 .38877 Mdot
.67523 .41455 Mdot
.53336 .58355 Mdot
.69096 .4306 Mdot
.57516 .64697 Mdot
.55987 .12207 Mdot
.61285 .61758 Mdot
.74312 .35136 Mdot
.42385 .75728 Mdot
.3137 .48134 Mdot
.34144 .4906 Mdot
.45069 .25006 Mdot
.66781 .39831 Mdot
.61152 .64166 Mdot
.37091 .61416 Mdot
.19411 .416 Mdot
.6112 .43884 Mdot
.29552 .45602 Mdot
.36235 .45415 Mdot
.45392 .35005 Mdot
.57438 .5685 Mdot
.59623 .58994 Mdot
.32087 .44009 Mdot
.32853 .69476 Mdot
.64559 .40685 Mdot
.599 .61394 Mdot
.60087 .63492 Mdot
.32266 .48003 Mdot
.22921 .5391 Mdot
.68534 .36278 Mdot
.61028 .62499 Mdot
.40196 .67001 Mdot
.4471 .34855 Mdot
.54033 .6165 Mdot
.53376 .603 Mdot
.3807 .635 Mdot
.23568 .59632 Mdot
.67103 .74902 Mdot
.43617 .36895 Mdot
.43165 .24802 Mdot
.62064 .6123 Mdot
.31543 .45519 Mdot
.62197 .62958 Mdot
.26366 .68778 Mdot
.44713 .25874 Mdot
.57702 .61642 Mdot
.52407 .6571 Mdot
.63882 .44775 Mdot
.57475 .61886 Mdot
.67375 .63591 Mdot
.34751 .48051 Mdot
.57516 .61627 Mdot
.76797 .63077 Mdot
.46008 .34719 Mdot
.51508 .64568 Mdot
.36891 .63152 Mdot
.40891 .75191 Mdot
.53574 .30555 Mdot
.35602 .49394 Mdot
.40698 .64002 Mdot
.61297 .60061 Mdot
.34351 .43423 Mdot
.4897 .40086 Mdot
.60673 .26082 Mdot
.55977 .56701 Mdot
.48961 .38553 Mdot
.48079 .38638 Mdot
.38509 .61583 Mdot
.80793 .38052 Mdot
.54427 .68066 Mdot
.60819 .59944 Mdot
.53923 .81416 Mdot
.62426 .41321 Mdot
.60813 .59654 Mdot
.58785 .57243 Mdot
.46096 .37681 Mdot
.52513 .52595 Mdot
.73515 .4106 Mdot
.31861 .62389 Mdot
.44162 .35834 Mdot
.34012 .50376 Mdot
.3417 .43352 Mdot
.40144 .64302 Mdot
.68462 .42731 Mdot
.39651 .65103 Mdot
.31173 .46608 Mdot
.54565 .59799 Mdot
.46082 .38498 Mdot
.70777 .53331 Mdot
.50367 .38914 Mdot
.2945 .42412 Mdot
.68986 .38796 Mdot
.49296 .29832 Mdot
.61122 .82353 Mdot
.55639 .31251 Mdot
.43802 .39166 Mdot
.37569 .62601 Mdot
.39113 .50061 Mdot
.60194 .63243 Mdot
.73974 .45347 Mdot
.59413 .57918 Mdot
.77329 .64626 Mdot
.30145 .43826 Mdot
.43448 .22539 Mdot
.60908 .63587 Mdot
.49335 .75319 Mdot
.43613 .38678 Mdot
.45672 .34696 Mdot
.56052 .59943 Mdot
.47163 .36129 Mdot
.60224 .60039 Mdot
.33087 .48386 Mdot
.81238 .39933 Mdot
.60359 .62611 Mdot
.54436 .55808 Mdot
.43997 .40134 Mdot
.22421 .37011 Mdot
.30676 .49092 Mdot
.71525 .66117 Mdot
.21042 .66747 Mdot
.47054 .36403 Mdot
.51684 .58959 Mdot
.33707 .44284 Mdot
.44246 .26397 Mdot
.28479 .46492 Mdot
.58147 .57522 Mdot
.55251 .58804 Mdot
.56149 .66199 Mdot
.59456 .63794 Mdot
.73421 .45575 Mdot
.52653 .54831 Mdot
.7186 .61902 Mdot
.56119 .58571 Mdot
.62999 .48749 Mdot
.46544 .35401 Mdot
.72024 .40921 Mdot
.40909 .59778 Mdot
.54824 .59067 Mdot
.62113 .37777 Mdot
.43602 .37578 Mdot
.15727 .47886 Mdot
.45226 .35368 Mdot
.33757 .45964 Mdot
.50369 .36572 Mdot
.5726 .64519 Mdot
.66642 .43834 Mdot
.34216 .48188 Mdot
.5304 .22904 Mdot
.30203 .47465 Mdot
.56815 .62919 Mdot
.24606 .56582 Mdot
.31087 .47847 Mdot
.46218 .48881 Mdot
.67208 .43655 Mdot
.47866 .72719 Mdot
.63409 .40394 Mdot
.58002 .62153 Mdot
.58424 .62518 Mdot
.42746 .24272 Mdot
.50021 .38363 Mdot
.6706 .39274 Mdot
.82844 .63379 Mdot
.36786 .64267 Mdot
.65124 .43 Mdot
.63411 .60561 Mdot
.43383 .46775 Mdot
.63848 .4405 Mdot
.43893 .72773 Mdot
.49476 .38732 Mdot
.62288 .44562 Mdot
.63641 .6017 Mdot
.5466 .48716 Mdot
.39809 .59753 Mdot
.29108 .43732 Mdot
.53442 .46749 Mdot
.34977 .45361 Mdot
.43647 .36111 Mdot
.34111 .42579 Mdot
.45933 .35085 Mdot
.74556 .36474 Mdot
.72672 .36687 Mdot
.49166 .40901 Mdot
.44716 .34279 Mdot
.3172 .46462 Mdot
.54062 .60599 Mdot
.44877 .5324 Mdot
.63111 .63293 Mdot
.5938 .56745 Mdot
.46794 .34244 Mdot
.65924 .39567 Mdot
.69487 .41019 Mdot
.67622 .3685 Mdot
.66594 .45229 Mdot
.34402 .47148 Mdot
.62937 .32542 Mdot
.81127 .58725 Mdot
.44983 .38856 Mdot
.49516 .33654 Mdot
.56449 .6596 Mdot
.31566 .45848 Mdot
.31196 .42524 Mdot
.46691 .38112 Mdot
.72834 .49594 Mdot
.52034 .58969 Mdot
.65664 .38996 Mdot
.68336 .40268 Mdot
.63833 .43705 Mdot
.63384 .45081 Mdot
.78618 .44788 Mdot
.49191 .39678 Mdot
.67529 .39904 Mdot
.56733 .60501 Mdot
.55877 .58004 Mdot
.43369 .24345 Mdot
.38095 .64238 Mdot
.58004 .55439 Mdot
.55969 .55308 Mdot
.58312 .58437 Mdot
.30905 .47488 Mdot
.64442 .598 Mdot
.44258 .25626 Mdot
.35249 .43421 Mdot
.36485 .47913 Mdot
.43733 .22672 Mdot
.66743 .4877 Mdot
.19155 .6419 Mdot
.54557 .6499 Mdot
.4666 .64035 Mdot
.32036 .4577 Mdot
.69148 .31104 Mdot
.60694 .48594 Mdot
.53919 .63116 Mdot
.50626 .51414 Mdot
.33596 .48464 Mdot
.6268 .40335 Mdot
.59968 .58566 Mdot
.45465 .23531 Mdot
.41585 .63842 Mdot
.63653 .61379 Mdot
.4454 .26428 Mdot
.65346 .41177 Mdot
.40964 .58004 Mdot
.62012 .43478 Mdot
.3201 .48763 Mdot
.51588 .64839 Mdot
.16158 .32191 Mdot
.34532 .44399 Mdot
.20737 .443 Mdot
.72188 .36732 Mdot
.60546 .62625 Mdot
.34878 .44862 Mdot
.63384 .39562 Mdot
.44972 .34614 Mdot
.42643 .493 Mdot
.68516 .40971 Mdot
.42923 .234 Mdot
.43431 .23572 Mdot
.32114 .47797 Mdot
.6775 .44091 Mdot
.52449 .61961 Mdot
.62913 .4335 Mdot
.50495 .37074 Mdot
.54947 .63148 Mdot
.18462 .59721 Mdot
.54794 .54384 Mdot
.66035 .39924 Mdot
.30679 .42018 Mdot
.38117 .59752 Mdot
.54793 .61764 Mdot
.20075 .47828 Mdot
.58268 .57008 Mdot
.44532 .36926 Mdot
.68137 .286 Mdot
.69602 .5363 Mdot
.54426 .6011 Mdot
.5704 .65861 Mdot
.44391 .3876 Mdot
.54166 .6023 Mdot
.58793 .57005 Mdot
.43023 .40251 Mdot
.64355 .4487 Mdot
.58661 .6126 Mdot
.29927 .43238 Mdot
.71604 .70643 Mdot
.62143 .61351 Mdot
.58159 .21757 Mdot
.4858 .73928 Mdot
.69405 .29699 Mdot
.62034 .62228 Mdot
.54701 .76435 Mdot
.58985 .62517 Mdot
.55382 .61061 Mdot
.54157 .64289 Mdot
.70756 .64822 Mdot
.31367 .46305 Mdot
.293 .45759 Mdot
.4022 .59899 Mdot
.48238 .73965 Mdot
.3925 .64019 Mdot
.43927 .37292 Mdot
.34142 .25518 Mdot
.45028 .25662 Mdot
.66332 .40448 Mdot
.5839 .6607 Mdot
.31496 .488 Mdot
.58847 .58188 Mdot
.5704 .64879 Mdot
.32739 .48624 Mdot
.34544 .43997 Mdot
.34592 .42358 Mdot
.39806 .60225 Mdot
.66129 .41643 Mdot
.53152 .61584 Mdot
.40582 .6133 Mdot
.52281 .61909 Mdot
.42304 .46981 Mdot
.65862 .41762 Mdot
.62962 .43595 Mdot
.68226 .39194 Mdot
.54589 .59479 Mdot
.56935 .64226 Mdot
.46333 .36053 Mdot
.65011 .46593 Mdot
.45818 .39522 Mdot
.34917 .4558 Mdot
.33276 .49078 Mdot
.58021 .57494 Mdot
.49243 .63684 Mdot
.3708 .62295 Mdot
.33704 .45534 Mdot
.45113 .2256 Mdot
.40692 .60354 Mdot
.56019 .621 Mdot
.34853 .46142 Mdot
.38603 .64664 Mdot
.74742 .50935 Mdot
.24706 .70563 Mdot
.37577 .59688 Mdot
.56259 .59983 Mdot
.72075 .67556 Mdot
.45452 .66905 Mdot
.37759 .65032 Mdot
.45175 .38732 Mdot
.57764 .56983 Mdot
.36217 .75305 Mdot
.37615 .64559 Mdot
.77793 .65544 Mdot
.31848 .48237 Mdot
.50705 .54127 Mdot
.63449 .59442 Mdot
.75374 .45325 Mdot
.39002 .6518 Mdot
.67643 .41965 Mdot
.64611 .46814 Mdot
.57047 .5986 Mdot
.43062 .64082 Mdot
.49166 .3413 Mdot
.31333 .48326 Mdot
.33021 .49671 Mdot
.67025 .44426 Mdot
.57534 .36481 Mdot
.30114 .42693 Mdot
.5705 .69696 Mdot
.37831 .5008 Mdot
.60696 .53452 Mdot
.77541 .38793 Mdot
.51889 .23329 Mdot
.60977 .65292 Mdot
.37211 .60091 Mdot
.46339 .40153 Mdot
.4663 .36015 Mdot
.47875 .36063 Mdot
.34925 .48683 Mdot
.48606 .47263 Mdot
.31036 .43929 Mdot
.58751 .26081 Mdot
.39151 .61191 Mdot
.46472 .70908 Mdot
.61334 .63635 Mdot
.60328 .62914 Mdot
.52297 .60911 Mdot
.56654 .66432 Mdot
.59121 .624 Mdot
.49266 .37396 Mdot
.35914 .47872 Mdot
.32952 .57505 Mdot
.6401 .42962 Mdot
.28441 .32014 Mdot
.3144 .45276 Mdot
.44529 .26257 Mdot
.38911 .62851 Mdot
.57699 .75679 Mdot
.36974 .49488 Mdot
.31797 .44954 Mdot
.54443 .57647 Mdot
.63695 .4059 Mdot
.59368 .51216 Mdot
.58965 .63037 Mdot
.33696 .45337 Mdot
.27791 .42682 Mdot
.68929 .50465 Mdot
.63249 .6799 Mdot
.35035 .60686 Mdot
.43796 .46691 Mdot
.41154 .65012 Mdot
.60687 .55504 Mdot
.68846 .30954 Mdot
.31327 .46703 Mdot
.33586 .46693 Mdot
.36384 .60914 Mdot
.50574 .67981 Mdot
.68057 .43584 Mdot
.43553 .22432 Mdot
.44754 .37526 Mdot
.5857 .63399 Mdot
.35075 .48277 Mdot
.47021 .62872 Mdot
.36934 .52757 Mdot
.48636 .36802 Mdot
.35372 .43535 Mdot
.55956 .57286 Mdot
.56117 .59702 Mdot
.37639 .61367 Mdot
.4215 .56545 Mdot
.63486 .61568 Mdot
.18883 .4324 Mdot
.6148 .3416 Mdot
.61594 .35803 Mdot
.58802 .58687 Mdot
.66328 .448 Mdot
.452 .23199 Mdot
.39218 .60534 Mdot
.52908 .60051 Mdot
.22489 .68782 Mdot
.69406 .44702 Mdot
.48583 .38007 Mdot
.4499 .22894 Mdot
.48428 .47417 Mdot
.58612 .57118 Mdot
.5946 .5796 Mdot
.56306 .61126 Mdot
.24362 .71325 Mdot
.2942 .4467 Mdot
.62704 .44405 Mdot
.40415 .62783 Mdot
.6455 .45509 Mdot
.29503 .46416 Mdot
.57146 .43402 Mdot
.56096 .62554 Mdot
.6648 .38743 Mdot
.67734 .42179 Mdot
.45368 .34997 Mdot
.45941 .34051 Mdot
.36263 .43616 Mdot
.61218 .61681 Mdot
.45673 .24348 Mdot
.62967 .41022 Mdot
.35696 .45031 Mdot
.37846 .61183 Mdot
.48821 .35462 Mdot
.55954 .58725 Mdot
.31721 .47264 Mdot
.57804 .67275 Mdot
.63205 .43033 Mdot
.31777 .4503 Mdot
.4572 .2613 Mdot
.3704 .62831 Mdot
.55477 .58812 Mdot
.37622 .57447 Mdot
.44199 .22432 Mdot
.59924 .6397 Mdot
.64139 .72199 Mdot
.42272 .60662 Mdot
.5321 .22581 Mdot
.31664 .43432 Mdot
.4419 .24966 Mdot
.6257 .42574 Mdot
.56716 .48928 Mdot
.33738 .46953 Mdot
.64362 .70435 Mdot
.43952 .55141 Mdot
.53255 .61493 Mdot
.6536 .43905 Mdot
.33997 .63716 Mdot
.16951 .46672 Mdot
.43043 .67423 Mdot
.59569 .61381 Mdot
.34957 .45041 Mdot
.396 .64711 Mdot
.44596 .38423 Mdot
.58442 .21878 Mdot
.77241 .39656 Mdot
.3559 .43522 Mdot
.54303 .64903 Mdot
.63013 .41004 Mdot
.46904 .38221 Mdot
.50023 .26013 Mdot
.33753 .42773 Mdot
.30505 .43383 Mdot
.55421 .61745 Mdot
.40468 .61883 Mdot
.32241 .68181 Mdot
.29162 .45594 Mdot
.356 .47617 Mdot
.27523 .32609 Mdot
.36933 .59573 Mdot
.57114 .60447 Mdot
.67565 .36832 Mdot
.54357 .58149 Mdot
.20091 .42782 Mdot
.44448 .25396 Mdot
.63936 .42701 Mdot
.56673 .57424 Mdot
.34914 .56891 Mdot
.34329 .46526 Mdot
.44794 .46435 Mdot
.30589 .41668 Mdot
.49426 .37748 Mdot
.34873 .48426 Mdot
.59737 .58564 Mdot
.43362 .38302 Mdot
.37126 .62597 Mdot
.61072 .62427 Mdot
.5681 .64289 Mdot
.64283 .38998 Mdot
.4805 .39386 Mdot
.66166 .73911 Mdot
.45847 .33275 Mdot
.45053 .39414 Mdot
.61716 .44302 Mdot
.57396 .5988 Mdot
.33261 .45569 Mdot
.28929 .43712 Mdot
.5281 .61078 Mdot
.69409 .31623 Mdot
.67509 .44 Mdot
.37359 .45607 Mdot
.32077 .78742 Mdot
.60351 .69376 Mdot
.45881 .24567 Mdot
.53565 .71775 Mdot
.455 .34563 Mdot
.55839 .59343 Mdot
.65647 .40193 Mdot
.35885 .46689 Mdot
.30049 .42795 Mdot
.52811 .59618 Mdot
.47535 .38767 Mdot
.40785 .646 Mdot
.31091 .42858 Mdot
.36509 .52577 Mdot
.57029 .61757 Mdot
.59017 .25082 Mdot
.31811 .43007 Mdot
.20254 .36188 Mdot
.33983 .57006 Mdot
.64643 .4394 Mdot
.56662 .64999 Mdot
.67673 .45238 Mdot
.40172 .63222 Mdot
.31404 .50146 Mdot
.47881 .38904 Mdot
.60518 .70581 Mdot
.67991 .76652 Mdot
.31174 .45911 Mdot
.65897 .40984 Mdot
.54428 .59711 Mdot
.58911 .70458 Mdot
.61238 .60568 Mdot
.53475 .52059 Mdot
.40363 .58753 Mdot
.47047 .34074 Mdot
.44362 .36928 Mdot
.58067 .65601 Mdot
.40556 .60811 Mdot
.28923 .46471 Mdot
.32119 .48351 Mdot
.74952 .24919 Mdot
.45645 .26276 Mdot
.46012 .76802 Mdot
.5519 .59125 Mdot
.36014 .45599 Mdot
.71744 .68958 Mdot
.4809 .3978 Mdot
.54206 .65828 Mdot
.35864 .48701 Mdot
.26864 .38048 Mdot
.42502 .47246 Mdot
.58291 .61658 Mdot
.5774 .691 Mdot
.44579 .37428 Mdot
.40243 .49057 Mdot
.31253 .43958 Mdot
.52672 .6413 Mdot
.45296 .33574 Mdot
.25286 .34653 Mdot
.72761 .73873 Mdot
.66094 .41697 Mdot
.29679 .42071 Mdot
.49365 .37687 Mdot
.6308 .65686 Mdot
.39956 .64449 Mdot
.35319 .47071 Mdot
.30403 .47316 Mdot
.55185 .63847 Mdot
.58881 .55706 Mdot
.60293 .6948 Mdot
.64787 .42208 Mdot
.45778 .36459 Mdot
.60359 .64512 Mdot
.58085 .36343 Mdot
.55892 .6621 Mdot
.45893 .36763 Mdot
.34646 .15222 Mdot
.55978 .56605 Mdot
.61026 .60407 Mdot
.34449 .68565 Mdot
.69249 .4178 Mdot
.65218 .45452 Mdot
.62312 .33314 Mdot
.55213 .59094 Mdot
.31623 .53072 Mdot
.66427 .41429 Mdot
.67111 .44103 Mdot
.26619 .55384 Mdot
.54615 .6302 Mdot
.40502 .47153 Mdot
.46361 .37319 Mdot
.49493 .37147 Mdot
.63517 .4433 Mdot
.63575 .642 Mdot
.47446 .40255 Mdot
.74581 .42222 Mdot
.31107 .45093 Mdot
.68795 .3088 Mdot
.63358 .41484 Mdot
.41157 .55387 Mdot
.48967 .39021 Mdot
.148 .45787 Mdot
.52436 .49242 Mdot
.54123 .65268 Mdot
.55326 .598 Mdot
.37905 .63533 Mdot
.50059 .61787 Mdot
.43239 .25037 Mdot
.47255 .36004 Mdot
.25434 .64013 Mdot
.6553 .42494 Mdot
.61017 .61052 Mdot
.58637 .75415 Mdot
.51958 .26826 Mdot
.61127 .23386 Mdot
.68649 .42218 Mdot
.65636 .4353 Mdot
.30441 .445 Mdot
.30351 .45984 Mdot
.57835 .60846 Mdot
.47144 .35441 Mdot
.63335 .46089 Mdot
.45241 .37181 Mdot
.31222 .46724 Mdot
.32267 .45224 Mdot
.44575 .25927 Mdot
.57187 .68162 Mdot
.32135 .48624 Mdot
.24336 .36292 Mdot
.57517 .37099 Mdot
.64286 .38778 Mdot
.60243 .82216 Mdot
.49648 .25842 Mdot
.35851 .71195 Mdot
.41918 .63007 Mdot
.46236 .26421 Mdot
.49609 .35122 Mdot
.57578 .65699 Mdot
.57231 .57876 Mdot
.44045 .23525 Mdot
.50061 .37664 Mdot
.38444 .63044 Mdot
.5006 .38337 Mdot
.39669 .61117 Mdot
.30838 .48967 Mdot
.62125 .61346 Mdot
.59971 .57885 Mdot
.49018 .36907 Mdot
.32701 .44438 Mdot
.31692 .48502 Mdot
.41342 .61309 Mdot
.55993 .75056 Mdot
.31941 .47717 Mdot
.63237 .41704 Mdot
.80536 .54313 Mdot
.4353 .23524 Mdot
.60215 .58878 Mdot
.59066 .75948 Mdot
.71711 .48766 Mdot
.53232 .62701 Mdot
.44835 .22743 Mdot
.77032 .27936 Mdot
.61461 .6285 Mdot
.76904 .29983 Mdot
.43901 .25015 Mdot
.6943 .42323 Mdot
.33597 .43895 Mdot
.43088 .24866 Mdot
.6397 .63925 Mdot
.36429 .64462 Mdot
.57829 .55159 Mdot
.68748 .41228 Mdot
.68645 .39057 Mdot
.69634 .34195 Mdot
.20204 .42929 Mdot
.38611 .60035 Mdot
.38294 .62311 Mdot
.33537 .47273 Mdot
.38637 .2061 Mdot
.62967 .58726 Mdot
.38043 .62334 Mdot
.28488 .6694 Mdot
.56115 .65838 Mdot
.49192 .77058 Mdot
.50486 .51305 Mdot
.66469 .44712 Mdot
.71317 .44979 Mdot
.34009 .46904 Mdot
.65919 .41034 Mdot
.57861 .39454 Mdot
.52365 .60756 Mdot
.65686 .42008 Mdot
.45843 .3718 Mdot
.372 .37376 Mdot
.67793 .44922 Mdot
.41285 .50297 Mdot
.46517 .37207 Mdot
.42747 .61093 Mdot
.39271 .6967 Mdot
.44575 .87522 Mdot
.47264 .35848 Mdot
.33849 .4467 Mdot
.3222 .48747 Mdot
.32612 .48211 Mdot
.6854 .40926 Mdot
.32663 .42592 Mdot
.64337 .41998 Mdot
.22046 .50045 Mdot
.56306 .76502 Mdot
.38329 .61213 Mdot
.44644 .42399 Mdot
.66902 .42957 Mdot
.60612 .29443 Mdot
.6243 .8112 Mdot
.56082 .60107 Mdot
.45568 .33401 Mdot
.36362 .61172 Mdot
.33788 .21528 Mdot
.38194 .63594 Mdot
.33616 .44202 Mdot
.68643 .30684 Mdot
.60185 .60201 Mdot
.67258 .65574 Mdot
.36859 .61915 Mdot
.68678 .41755 Mdot
.60114 .63668 Mdot
.31744 .41059 Mdot
.40416 .64027 Mdot
.41452 .63961 Mdot
.59478 .62266 Mdot
.67732 .44589 Mdot
.32731 .45253 Mdot
.49156 .34878 Mdot
.37475 .58502 Mdot
.61081 .67352 Mdot
.53748 .60912 Mdot
.53203 .65533 Mdot
.47706 .46056 Mdot
.333 .71761 Mdot
.46994 .36566 Mdot
.48434 .69031 Mdot
.30742 .46783 Mdot
.41458 .67238 Mdot
.58512 .31533 Mdot
.44046 .41825 Mdot
.44353 .25378 Mdot
.44669 .25516 Mdot
.58659 .61893 Mdot
.32397 .71178 Mdot
.6715 .2531 Mdot
.42416 .36509 Mdot
.43877 .23037 Mdot
.31586 .48413 Mdot
.66762 .46351 Mdot
.68145 .34432 Mdot
.59613 .56284 Mdot
.46509 .34075 Mdot
.31528 .47532 Mdot
.2663 .6918 Mdot
.39277 .61469 Mdot
.64415 .31271 Mdot
.56498 .62858 Mdot
.60174 .6122 Mdot
.47394 .37585 Mdot
.46377 .36083 Mdot
.58052 .23026 Mdot
.6442 .3369 Mdot
.28274 .4058 Mdot
.41364 .3672 Mdot
.28839 .7155 Mdot
.71629 .39688 Mdot
.65602 .40049 Mdot
.45131 .26166 Mdot
.45099 .39688 Mdot
.60072 .58413 Mdot
.6953 .41803 Mdot
.61605 .23473 Mdot
.62995 .47108 Mdot
.48928 .76373 Mdot
.33373 .53595 Mdot
.57648 .63836 Mdot
.63281 .40956 Mdot
.65877 .41256 Mdot
.64392 .45763 Mdot
.43929 .22645 Mdot
.58491 .58783 Mdot
.54101 .60605 Mdot
.6061 .63827 Mdot
.51177 .65791 Mdot
.57323 .61888 Mdot
.58071 .32611 Mdot
.54101 .39553 Mdot
.2423 .61844 Mdot
.53285 .6331 Mdot
.49704 .38278 Mdot
.58443 .66199 Mdot
.41012 .61341 Mdot
.5421 .64871 Mdot
.47546 .76949 Mdot
.48065 .36796 Mdot
.5155 .68873 Mdot
.41967 .34618 Mdot
.56494 .62981 Mdot
.38917 .64887 Mdot
.32908 .7091 Mdot
.65201 .76011 Mdot
.26969 .33418 Mdot
.63128 .4195 Mdot
.37245 .47724 Mdot
.50606 .37604 Mdot
.33263 .45759 Mdot
.53315 .64571 Mdot
.45734 .25355 Mdot
.46874 .22156 Mdot
.41535 .54522 Mdot
.58884 .57515 Mdot
.57585 .53549 Mdot
.64878 .44632 Mdot
.34653 .45664 Mdot
.70967 .43649 Mdot
.55709 .61081 Mdot
.40527 .63084 Mdot
.40882 .62471 Mdot
.61759 .35113 Mdot
.21647 .62426 Mdot
.57576 .49723 Mdot
.47236 .37375 Mdot
.2981 .42642 Mdot
.38745 .65114 Mdot
.74533 .37597 Mdot
.49011 .33962 Mdot
.45542 .34546 Mdot
.47237 .39244 Mdot
.58205 .63829 Mdot
.43853 .25535 Mdot
.25985 .65866 Mdot
.42885 .23785 Mdot
.56628 .63379 Mdot
.30007 .46473 Mdot
.43128 .25095 Mdot
.38506 .63942 Mdot
.44231 .38146 Mdot
.30627 .46033 Mdot
.58069 .62396 Mdot
.66545 .41882 Mdot
.55819 .73762 Mdot
.41916 .77607 Mdot
.21964 .53584 Mdot
.22179 .54508 Mdot
.68206 .39546 Mdot
.16943 .52566 Mdot
.47994 .42767 Mdot
.72764 .49391 Mdot
.3485 .62957 Mdot
.52716 .61419 Mdot
.83402 .45756 Mdot
.31508 .43842 Mdot
.34241 .47799 Mdot
.5793 .61466 Mdot
.35224 .44556 Mdot
.61119 .60917 Mdot
.30054 .4456 Mdot
.24177 .41452 Mdot
.60627 .57342 Mdot
.34222 .47638 Mdot
.62536 .57543 Mdot
.5515 .62232 Mdot
.65366 .44905 Mdot
.35541 .46837 Mdot
.54812 .659 Mdot
.3966 .1857 Mdot
.47444 .34937 Mdot
.43662 .22796 Mdot
.51563 .41599 Mdot
.49368 .39029 Mdot
.64767 .4322 Mdot
.61779 .58703 Mdot
.37344 .61634 Mdot
.67338 .41989 Mdot
.36028 .43378 Mdot
.36765 .61618 Mdot
.62494 .32727 Mdot
.63045 .42628 Mdot
.43582 .23875 Mdot
.37028 .62053 Mdot
.53853 .55849 Mdot
.3405 .48591 Mdot
.43816 .79562 Mdot
.42978 .23599 Mdot
.59701 .59003 Mdot
.29765 .48587 Mdot
.49785 .38627 Mdot
.58595 .60546 Mdot
.34959 .44828 Mdot
.44195 .22544 Mdot
.58184 .64474 Mdot
.59393 .64269 Mdot
.65518 .34914 Mdot
.64993 .2626 Mdot
.37666 .61549 Mdot
.63032 .40314 Mdot
.56841 .60623 Mdot
.40254 .60443 Mdot
.37171 .27528 Mdot
.59647 .66088 Mdot
.68639 .44526 Mdot
.66631 .63401 Mdot
.30266 .46094 Mdot
.45533 .39393 Mdot
.29234 .42577 Mdot
.4165 .63837 Mdot
.85138 .60863 Mdot
.44026 .25928 Mdot
.64128 .60557 Mdot
.5209 .62603 Mdot
.27464 .43961 Mdot
.65511 .41613 Mdot
.35886 .40011 Mdot
.55435 .58909 Mdot
.55751 .53759 Mdot
.6057 .61151 Mdot
.3382 .56793 Mdot
.67719 .4381 Mdot
.60719 .59872 Mdot
.49154 .59935 Mdot
.62317 .61266 Mdot
.39823 .64861 Mdot
.44216 .69893 Mdot
.58457 .66408 Mdot
.12446 .38477 Mdot
.44894 .22526 Mdot
.32788 .48571 Mdot
.29999 .503 Mdot
.42363 .28648 Mdot
.77712 .38775 Mdot
.64555 .42063 Mdot
.63886 .55689 Mdot
.32999 .45473 Mdot
.73106 .72244 Mdot
.1722 .49425 Mdot
.5547 .62539 Mdot
.55965 .57379 Mdot
.33622 .44205 Mdot
.3594 .45584 Mdot
.45508 .2551 Mdot
.53361 .63864 Mdot
.60867 .54905 Mdot
.33826 .42622 Mdot
.57487 .62712 Mdot
.65505 .54272 Mdot
.48021 .34332 Mdot
.64342 .4513 Mdot
.44623 .38489 Mdot
.46294 .3438 Mdot
.78652 .4979 Mdot
.61605 .34114 Mdot
.45983 .36488 Mdot
.46015 .32934 Mdot
.48016 .77421 Mdot
.66107 .6629 Mdot
.40152 .65029 Mdot
.20072 .55877 Mdot
.32946 .47826 Mdot
.58271 .5881 Mdot
.67353 .39503 Mdot
.76166 .46231 Mdot
.33636 .35205 Mdot
.6723 .29822 Mdot
.54889 .6021 Mdot
.33869 .47409 Mdot
.43523 .22688 Mdot
.60557 .57147 Mdot
.42196 .67011 Mdot
.59906 .61249 Mdot
.31973 .48857 Mdot
.80938 .50342 Mdot
.66967 .6509 Mdot
.39142 .49307 Mdot
.62048 .4015 Mdot
.60783 .64288 Mdot
.63568 .41815 Mdot
.49138 .38441 Mdot
.40054 .60426 Mdot
.37627 .62267 Mdot
.60034 .63459 Mdot
.72687 .36642 Mdot
.49866 .52477 Mdot
.55071 .61996 Mdot
.54965 .63549 Mdot
.44078 .25033 Mdot
.54953 .63443 Mdot
.52155 .62517 Mdot
.58894 .65577 Mdot
.60448 .66442 Mdot
.45058 .39454 Mdot
.65059 .71448 Mdot
.58804 .66991 Mdot
.63039 .67701 Mdot
.47871 .34554 Mdot
.63593 .56432 Mdot
.45412 .35218 Mdot
.18996 .60241 Mdot
.45076 .36222 Mdot
.37767 .61901 Mdot
.30571 .49262 Mdot
.59535 .52582 Mdot
.62987 .45685 Mdot
.44969 .34373 Mdot
.39711 .62342 Mdot
.4756 .35955 Mdot
.2946 .43937 Mdot
.55498 .82366 Mdot
.63154 .47145 Mdot
.41356 .48092 Mdot
.53196 .50315 Mdot
.58933 .24862 Mdot
.30704 .45015 Mdot
.66572 .4451 Mdot
.67258 .63201 Mdot
.58928 .65413 Mdot
.37237 .62989 Mdot
.58869 .61897 Mdot
.44742 .39127 Mdot
.3341 .47806 Mdot
.23999 .56581 Mdot
.37483 .61918 Mdot
.71856 .75749 Mdot
.30617 .48025 Mdot
.57008 .56218 Mdot
.46451 .33993 Mdot
.60731 .81921 Mdot
.44917 .36362 Mdot
.57078 .76482 Mdot
.70433 .39767 Mdot
.82253 .5162 Mdot
.66133 .4363 Mdot
.61456 .22409 Mdot
.18199 .66032 Mdot
.18687 .4796 Mdot
.67339 .41186 Mdot
.3848 .47413 Mdot
.56736 .62633 Mdot
.57345 .66638 Mdot
.58864 .69831 Mdot
.62896 .39835 Mdot
.56838 .60943 Mdot
.43218 .24603 Mdot
.56382 .38679 Mdot
.30863 .64649 Mdot
.37271 .484 Mdot
.61137 .60147 Mdot
.47435 .34518 Mdot
.49759 .39652 Mdot
.42956 .24631 Mdot
.49408 .34481 Mdot
.54706 .6208 Mdot
.66694 .43201 Mdot
.43496 .54157 Mdot
.39738 .63681 Mdot
.26032 .28722 Mdot
.38667 .58808 Mdot
.37514 .47411 Mdot
.52208 .65526 Mdot
.32174 .45169 Mdot
.87137 .47321 Mdot
.5731 .66055 Mdot
.66499 .41152 Mdot
.59113 .6416 Mdot
.59736 .65183 Mdot
.56703 .6672 Mdot
.32652 .42419 Mdot
.27866 .48305 Mdot
.57775 .62816 Mdot
.47915 .38983 Mdot
.23696 .58259 Mdot
.56887 .5528 Mdot
.36781 .43369 Mdot
.47442 .74592 Mdot
.5928 .26349 Mdot
.63863 .38831 Mdot
.34249 .45157 Mdot
.65533 .42907 Mdot
.61523 .42199 Mdot
.64754 .43209 Mdot
.23846 .63531 Mdot
.54997 .52161 Mdot
.74337 .26172 Mdot
.79364 .59784 Mdot
.75168 .48199 Mdot
.66632 .38853 Mdot
.3764 .30821 Mdot
.66169 .40108 Mdot
.64535 .42545 Mdot
.50895 .11357 Mdot
.67122 .39948 Mdot
.57923 .57538 Mdot
.55601 .56649 Mdot
.54624 .30431 Mdot
.50397 .78231 Mdot
.53868 .64376 Mdot
.57265 .60884 Mdot
.39275 .60201 Mdot
.49788 .65543 Mdot
.43309 .26194 Mdot
.66722 .3172 Mdot
.46697 .26689 Mdot
.59372 .62284 Mdot
.57418 .61282 Mdot
.62342 .65776 Mdot
.18702 .67639 Mdot
.76564 .44382 Mdot
.68969 .39529 Mdot
.58773 .53287 Mdot
.20875 .38141 Mdot
.56382 .56645 Mdot
.60534 .58244 Mdot
.57535 .64666 Mdot
.33169 .45521 Mdot
.67691 .45998 Mdot
.56738 .53852 Mdot
.57013 .26698 Mdot
.56147 .62321 Mdot
.47579 .42609 Mdot
.38168 .58301 Mdot
.59477 .58321 Mdot
.64776 .45673 Mdot
.54912 .6514 Mdot
.63406 .41087 Mdot
.63851 .44675 Mdot
.59384 .68032 Mdot
.24763 .65113 Mdot
.66561 .45907 Mdot
.56919 .63902 Mdot
.3317 .44699 Mdot
.1733 .465 Mdot
.59517 .58726 Mdot
.3971 .60724 Mdot
.55287 .59491 Mdot
.39643 .64805 Mdot
.5581 .63611 Mdot
.42938 .2344 Mdot
.68749 .54084 Mdot
.335 .46869 Mdot
.34382 .60411 Mdot
.35332 .4421 Mdot
.61868 .36893 Mdot
.6948 .42974 Mdot
.43582 .26642 Mdot
.76755 .34295 Mdot
.44002 .24895 Mdot
.55922 .73651 Mdot
.32568 .32185 Mdot
.48136 .3531 Mdot
.63107 .44706 Mdot
.48899 .68463 Mdot
.37671 .44628 Mdot
.35619 .43223 Mdot
.36545 .47225 Mdot
.86169 .55165 Mdot
.80955 .39165 Mdot
.58357 .631 Mdot
.43884 .80871 Mdot
.72029 .6035 Mdot
.6208 .63826 Mdot
.62756 .60442 Mdot
.31962 .48953 Mdot
.61318 .63523 Mdot
.47146 .47981 Mdot
.31656 .46384 Mdot
.39107 .62396 Mdot
.63894 .42483 Mdot
.40373 .64486 Mdot
.32231 .40238 Mdot
.54631 .39965 Mdot
.30872 .46627 Mdot
.60261 .66162 Mdot
.59247 .63444 Mdot
.62758 .42444 Mdot
.60478 .40854 Mdot
.64539 .45061 Mdot
.36547 .61296 Mdot
.32406 .46901 Mdot
.7574 .44357 Mdot
.56199 .59105 Mdot
.67806 .42345 Mdot
.50388 .32497 Mdot
.56052 .59671 Mdot
.49091 .37303 Mdot
.54563 .60381 Mdot
.67781 .40987 Mdot
.55001 .63426 Mdot
.66434 .43284 Mdot
.31841 .44066 Mdot
.55819 .57087 Mdot
.57764 .61181 Mdot
.67631 .74727 Mdot
.38539 .63142 Mdot
.69501 .42735 Mdot
.5077 .47622 Mdot
.54899 .57583 Mdot
.41547 .66893 Mdot
.61994 .61775 Mdot
.65459 .58945 Mdot
.62542 .57368 Mdot
.433 .2454 Mdot
.55729 .66893 Mdot
.59724 .58911 Mdot
.66065 .70207 Mdot
.74549 .65586 Mdot
.69494 .46008 Mdot
.4366 .36897 Mdot
.64753 .45629 Mdot
.33589 .49038 Mdot
.35854 .47687 Mdot
.31888 .42672 Mdot
.53301 .7822 Mdot
.63204 .64989 Mdot
.60077 .60043 Mdot
.45615 .33952 Mdot
.38362 .62051 Mdot
.68455 .41982 Mdot
.38518 .6155 Mdot
.67274 .31836 Mdot
.36518 .61868 Mdot
.43382 .25283 Mdot
.34024 .57045 Mdot
.71422 .4751 Mdot
.38626 .60213 Mdot
.64535 .45106 Mdot
.35332 .53945 Mdot
.52688 .62271 Mdot
.24905 .37778 Mdot
.40577 .62961 Mdot
.8384 .61902 Mdot
.61911 .61179 Mdot
.43966 .48434 Mdot
.46416 .34816 Mdot
.38899 .64538 Mdot
.48309 .39397 Mdot
.56015 .6603 Mdot
.53464 .22363 Mdot
.66149 .40708 Mdot
.4329 .37881 Mdot
.56139 .66921 Mdot
.40017 .6454 Mdot
.3126 .47704 Mdot
.55944 .47378 Mdot
.49621 .37767 Mdot
.63241 .76052 Mdot
.43018 .67415 Mdot
.32255 .46764 Mdot
.68148 .23999 Mdot
.45962 .38993 Mdot
.61189 .65229 Mdot
.61215 .51784 Mdot
.53823 .63352 Mdot
.34391 .49062 Mdot
.34785 .46051 Mdot
.5526 .34552 Mdot
.59083 .63959 Mdot
.61938 .6135 Mdot
.69232 .45233 Mdot
.31334 .45746 Mdot
.65548 .44278 Mdot
.6299 .44999 Mdot
.33507 .44389 Mdot
.64783 .44039 Mdot
.36823 .62198 Mdot
.55919 .39238 Mdot
.45729 .38828 Mdot
.48267 .38534 Mdot
.31808 .48409 Mdot
.29015 .45232 Mdot
.31934 .45169 Mdot
.54598 .60495 Mdot
.68671 .43027 Mdot
.56058 .64972 Mdot
.58651 .66456 Mdot
.7011 .38897 Mdot
.68761 .40509 Mdot
.56182 .65473 Mdot
.36891 .54612 Mdot
.3629 .59192 Mdot
.34264 .4745 Mdot
.45361 .36969 Mdot
.73405 .71374 Mdot
.4623 .33844 Mdot
.61522 .60722 Mdot
.26351 .38173 Mdot
.68709 .41482 Mdot
.3815 .63641 Mdot
.4344 .64011 Mdot
.37435 .62961 Mdot
.43264 .38624 Mdot
.63766 .45878 Mdot
.62144 .32936 Mdot
.61399 .6099 Mdot
.47971 .46033 Mdot
.48967 .69157 Mdot
.58543 .30433 Mdot
.45811 .36811 Mdot
.56548 .60223 Mdot
.43877 .24722 Mdot
.69153 .50129 Mdot
.59701 .60957 Mdot
.54089 .65651 Mdot
.30481 .55019 Mdot
.62661 .68163 Mdot
.64842 .38706 Mdot
.68924 .33998 Mdot
.535 .5931 Mdot
.72068 .3925 Mdot
.64706 .16105 Mdot
.61703 .61886 Mdot
.56413 .61472 Mdot
.57809 .58185 Mdot
.57331 .65643 Mdot
.69447 .3871 Mdot
.39465 .55902 Mdot
.46056 .34105 Mdot
.51194 .43806 Mdot
.46025 .38641 Mdot
.34437 .48185 Mdot
.44365 .48692 Mdot
.63414 .44845 Mdot
.37563 .6324 Mdot
.52201 .82238 Mdot
.69167 .32837 Mdot
.30493 .44517 Mdot
.77937 .44746 Mdot
.40147 .6358 Mdot
.52778 .61327 Mdot
.39473 .59437 Mdot
.36143 .46011 Mdot
.46929 .38397 Mdot
.55106 .57071 Mdot
.66657 .39322 Mdot
.67769 .44982 Mdot
.56264 .60322 Mdot
.19507 .41751 Mdot
.49166 .39071 Mdot
.53054 .36863 Mdot
.58021 .63856 Mdot
.53933 .65517 Mdot
.63904 .4403 Mdot
.345 .46256 Mdot
.33196 .28754 Mdot
.39229 .62928 Mdot
.61166 .66361 Mdot
.55494 .65726 Mdot
.66721 .32335 Mdot
.44024 .37803 Mdot
.45368 .23932 Mdot
.5838 .63982 Mdot
.62194 .33845 Mdot
.5838 .64135 Mdot
.50074 .60392 Mdot
.32458 .44819 Mdot
.52907 .58829 Mdot
.55087 .58296 Mdot
.49828 .68253 Mdot
.4653 .39371 Mdot
.65956 .41524 Mdot
.70605 .42734 Mdot
.45471 .23523 Mdot
.48869 .36874 Mdot
.55761 .65492 Mdot
.45281 .3936 Mdot
.56958 .66737 Mdot
.57717 .62491 Mdot
.45819 .36902 Mdot
.65464 .44285 Mdot
.36626 .39754 Mdot
.6357 .7152 Mdot
.58172 .65102 Mdot
.53689 .60669 Mdot
.51668 .78111 Mdot
.7436 .30808 Mdot
.55246 .58532 Mdot
.69081 .41746 Mdot
.5647 .59734 Mdot
.4889 .38133 Mdot
.36388 .6188 Mdot
.66844 .41408 Mdot
.292 .46573 Mdot
.32027 .43919 Mdot
.4257 .33532 Mdot
.43687 .2566 Mdot
.53797 .59903 Mdot
.6479 .48255 Mdot
.68288 .39961 Mdot
.41635 .19495 Mdot
.33091 .48634 Mdot
.38158 .648 Mdot
.59183 .64597 Mdot
.55179 .47789 Mdot
.45162 .34525 Mdot
.1235 .38731 Mdot
.6074 .33447 Mdot
.42424 .62031 Mdot
.69909 .30265 Mdot
.43879 .24166 Mdot
.58409 .57246 Mdot
.40938 .61106 Mdot
.31432 .43333 Mdot
.57122 .66524 Mdot
.61104 .68347 Mdot
.40066 .41875 Mdot
.35905 .49641 Mdot
.45588 .39488 Mdot
.29902 .43924 Mdot
.42221 .62672 Mdot
.43314 .25176 Mdot
.66766 .44981 Mdot
.60289 .59572 Mdot
.56862 .5278 Mdot
.33089 .4836 Mdot
.43002 .23051 Mdot
.57611 .63884 Mdot
.67187 .45319 Mdot
.34506 .43932 Mdot
.59732 .62308 Mdot
.73184 .48422 Mdot
.63666 .3806 Mdot
.32503 .47566 Mdot
.52189 .63529 Mdot
.64823 .55406 Mdot
.29952 .47693 Mdot
.31375 .48549 Mdot
.56891 .60967 Mdot
.36942 .62242 Mdot
.57486 .56847 Mdot
.4583 .35075 Mdot
.27843 .48289 Mdot
.48732 .37717 Mdot
.4673 .67297 Mdot
.53227 .66394 Mdot
.60532 .2446 Mdot
.62775 .41334 Mdot
.39933 .65801 Mdot
.69164 .68677 Mdot
.52877 .64116 Mdot
.18604 .56726 Mdot
.40984 .55211 Mdot
.2988 .24914 Mdot
.28081 .73828 Mdot
.40176 .61928 Mdot
.47876 .36025 Mdot
.56394 .61396 Mdot
.50262 .34184 Mdot
.38563 .60416 Mdot
.47872 .68301 Mdot
.52189 .63339 Mdot
.67394 .43945 Mdot
.56589 .62735 Mdot
.6319 .41758 Mdot
.5589 .59532 Mdot
.64537 .61322 Mdot
.34823 .61049 Mdot
.57423 .76412 Mdot
.52754 .61938 Mdot
.54564 .8284 Mdot
.53932 .47377 Mdot
.40334 .62932 Mdot
.5666 .64595 Mdot
.44823 .2372 Mdot
.50216 .38003 Mdot
.35571 .74147 Mdot
.32672 .45347 Mdot
.46188 .3579 Mdot
.63834 .43396 Mdot
.28705 .43841 Mdot
.44856 .22627 Mdot
.58353 .52121 Mdot
.41039 .64173 Mdot
.47987 .35363 Mdot
.59659 .58692 Mdot
.6154 .60397 Mdot
.3522 .56769 Mdot
.5514 .1727 Mdot
.65667 .4688 Mdot
.69907 .76112 Mdot
.66146 .38519 Mdot
.38203 .62685 Mdot
.32235 .44872 Mdot
.56826 .57412 Mdot
.59066 .61073 Mdot
.35319 .48246 Mdot
.69321 .41755 Mdot
.35032 .50796 Mdot
.78757 .47952 Mdot
.31742 .41748 Mdot
.50873 .74091 Mdot
.67028 .40923 Mdot
.51617 .74215 Mdot
.42256 .63137 Mdot
.24668 .66219 Mdot
.40642 .73777 Mdot
.46725 .34549 Mdot
.50099 .73854 Mdot
.68426 .41517 Mdot
.5881 .6315 Mdot
.43702 .23682 Mdot
.44571 .25819 Mdot
.63532 .42549 Mdot
.3393 .4435 Mdot
.39785 .64467 Mdot
.56693 .61752 Mdot
.62014 .29582 Mdot
.50738 .27587 Mdot
.29841 .4256 Mdot
.49726 .58833 Mdot
.48093 .393 Mdot
.54669 .59963 Mdot
.40255 .61048 Mdot
.46808 .36181 Mdot
.46141 .25421 Mdot
.56187 .39019 Mdot
.5946 .64508 Mdot
.6212 .35137 Mdot
.48595 .3627 Mdot
.69207 .24327 Mdot
.58169 .61107 Mdot
.45994 .39021 Mdot
.64896 .65175 Mdot
.53411 .2358 Mdot
.47512 .51755 Mdot
.17939 .49859 Mdot
.36327 .48971 Mdot
.32421 .43829 Mdot
.4824 .1914 Mdot
.34903 .6289 Mdot
.47963 .34779 Mdot
.43176 .24952 Mdot
.41838 .71006 Mdot
.47853 .39518 Mdot
.60531 .5811 Mdot
.61962 .61794 Mdot
.78135 .49171 Mdot
.48528 .48288 Mdot
.43093 .22629 Mdot
.60948 .49621 Mdot
.5427 .62717 Mdot
.5389 .56803 Mdot
.582 .60274 Mdot
.68691 .39111 Mdot
.49354 .39313 Mdot
.55599 .84357 Mdot
.48772 .39683 Mdot
.6294 .29953 Mdot
.32993 .47828 Mdot
.30011 .42273 Mdot
.59773 .58544 Mdot
.63993 .24064 Mdot
.34017 .73394 Mdot
.54059 .60052 Mdot
.43412 .62059 Mdot
.44105 .67408 Mdot
.56152 .55267 Mdot
.70813 .42798 Mdot
.54431 .54135 Mdot
.68101 .37915 Mdot
.46479 .36447 Mdot
.4008 .61599 Mdot
.35961 .59887 Mdot
.47465 .35348 Mdot
.5985 .59898 Mdot
.44031 .61808 Mdot
.6036 .61125 Mdot
.58528 .63506 Mdot
.66063 .31209 Mdot
.37268 .64455 Mdot
.31603 .45104 Mdot
.37564 .62198 Mdot
.64675 .42455 Mdot
.42502 .11183 Mdot
.38813 .61094 Mdot
.5958 .44703 Mdot
.3908 .52145 Mdot
.50503 .73845 Mdot
.67328 .45136 Mdot
.3764 .6007 Mdot
.46822 .39831 Mdot
.29352 .25078 Mdot
.71901 .2774 Mdot
.47048 .33538 Mdot
.58649 .61317 Mdot
.62982 .44331 Mdot
.68123 .39303 Mdot
.45951 .33121 Mdot
.66776 .44679 Mdot
.51204 .61989 Mdot
.58689 .64345 Mdot
.47968 .34792 Mdot
.53642 .30288 Mdot
.49562 .3926 Mdot
.57651 .45656 Mdot
.57135 .64367 Mdot
.66667 .41295 Mdot
.50704 .62058 Mdot
.67643 .46451 Mdot
.45049 .25998 Mdot
.56279 .66587 Mdot
.38037 .63949 Mdot
.48343 .47282 Mdot
.32707 .47541 Mdot
.26774 .38274 Mdot
.62912 .43258 Mdot
.52168 .3624 Mdot
.65302 .44934 Mdot
.62296 .42009 Mdot
.49148 .3417 Mdot
.65155 .41461 Mdot
.56464 .61576 Mdot
.39037 .50027 Mdot
.64249 .40566 Mdot
.47708 .37457 Mdot
.39402 .64344 Mdot
.65044 .44159 Mdot
.28402 .4387 Mdot
.59528 .63065 Mdot
.30241 .45628 Mdot
.42513 .64469 Mdot
.6342 .44967 Mdot
.37347 .60291 Mdot
.33188 .48496 Mdot
.41407 .63676 Mdot
.22703 .53896 Mdot
.4615 .40215 Mdot
.66418 .29565 Mdot
.65707 .69064 Mdot
.66484 .3941 Mdot
.35656 .43204 Mdot
.55928 .57864 Mdot
.59622 .63532 Mdot
.41933 .6196 Mdot
.68031 .39347 Mdot
.17891 .45734 Mdot
.6442 .55779 Mdot
.54795 .35857 Mdot
.44446 .39141 Mdot
.73473 .72914 Mdot
.57652 .3632 Mdot
.28052 .2822 Mdot
.61715 .56959 Mdot
.43859 .24092 Mdot
.60685 .60941 Mdot
.65485 .75974 Mdot
.36362 .62349 Mdot
.36423 .34293 Mdot
.62951 .58732 Mdot
.32247 .45859 Mdot
.56826 .59208 Mdot
.43266 .80307 Mdot
.53558 .5484 Mdot
.38956 .60077 Mdot
.43937 .39853 Mdot
.63053 .45764 Mdot
.39864 .63624 Mdot
.31325 .44016 Mdot
.4502 .71781 Mdot
.52003 .62433 Mdot
.544 .62017 Mdot
.35988 .43948 Mdot
.67187 .44213 Mdot
.3433 .48383 Mdot
.45769 .38833 Mdot
.38891 .61393 Mdot
.579 .65495 Mdot
.52727 .58314 Mdot
.27917 .42403 Mdot
.49128 .39796 Mdot
.2902 .44018 Mdot
.44248 .37917 Mdot
.43777 .24045 Mdot
.5319 .60731 Mdot
.35736 .43828 Mdot
.62179 .62593 Mdot
.6899 .70879 Mdot
.67325 .31019 Mdot
.74526 .63938 Mdot
.31373 .45099 Mdot
.49172 .75304 Mdot
.48315 .36769 Mdot
.4448 .3678 Mdot
.81483 .57322 Mdot
.32639 .70975 Mdot
.32013 .53177 Mdot
.54174 .81876 Mdot
.45682 .38751 Mdot
.4849 .37554 Mdot
.3178 .43198 Mdot
.64571 .41607 Mdot
.66235 .37174 Mdot
.30076 .41972 Mdot
.58847 .75842 Mdot
.68438 .41979 Mdot
.18066 .54922 Mdot
.31183 .4889 Mdot
.63104 .5882 Mdot
.42444 .23883 Mdot
.40571 .61901 Mdot
.59136 .7557 Mdot
.50093 .81228 Mdot
.58303 .57394 Mdot
.78951 .39166 Mdot
.34071 .45659 Mdot
.41146 .4556 Mdot
.20565 .61964 Mdot
.53363 .65263 Mdot
.57581 .58918 Mdot
.59253 .59741 Mdot
.36232 .63373 Mdot
.68627 .6964 Mdot
.58618 .5745 Mdot
.55411 .76259 Mdot
.60024 .57392 Mdot
.40329 .77135 Mdot
.37609 .6208 Mdot
.54066 .52083 Mdot
.36906 .47787 Mdot
.58051 .2788 Mdot
.59207 .69901 Mdot
.45416 .38991 Mdot
.3811 .43754 Mdot
.46509 .38217 Mdot
.29765 .70529 Mdot
.40762 .73606 Mdot
.68063 .38731 Mdot
.54867 .60246 Mdot
.36417 .47977 Mdot
.62783 .43337 Mdot
.32682 .31172 Mdot
.49719 .10805 Mdot
.47403 .40187 Mdot
.82401 .37411 Mdot
.44461 .36686 Mdot
.44995 .2583 Mdot
.63584 .43542 Mdot
.73554 .41603 Mdot
.47877 .46171 Mdot
.65269 .44062 Mdot
.42616 .32511 Mdot
.70981 .42034 Mdot
.49518 .74574 Mdot
.61919 .43797 Mdot
.47731 .37034 Mdot
.46205 .40959 Mdot
.63634 .65805 Mdot
.55573 .58352 Mdot
.52436 .42558 Mdot
.64924 .66526 Mdot
.55068 .59171 Mdot
.31666 .46374 Mdot
.69656 .27318 Mdot
.2797 .46296 Mdot
.65249 .40296 Mdot
.43913 .36522 Mdot
.57374 .58963 Mdot
.57931 .65072 Mdot
.6119 .6481 Mdot
.67526 .75227 Mdot
.18188 .546 Mdot
.57939 .62762 Mdot
.58888 .68007 Mdot
.31431 .44232 Mdot
.38071 .57346 Mdot
.59786 .79816 Mdot
.41829 .7186 Mdot
.60613 .62955 Mdot
.38167 .63143 Mdot
.36228 .62778 Mdot
.54314 .57055 Mdot
.60978 .27026 Mdot
.38679 .4846 Mdot
.59613 .58659 Mdot
.39729 .744 Mdot
.28141 .45317 Mdot
.428 .23775 Mdot
.32995 .48373 Mdot
.64138 .45571 Mdot
.44232 .25397 Mdot
.34283 .43432 Mdot
.7329 .43277 Mdot
.45604 .23963 Mdot
.53937 .24692 Mdot
.36548 .6128 Mdot
.58632 .60518 Mdot
.7022 .44658 Mdot
.3507 .48614 Mdot
.47773 .35239 Mdot
.66501 .42663 Mdot
.49625 .39993 Mdot
.36989 .57291 Mdot
.52309 .72202 Mdot
.43942 .25843 Mdot
.44853 .38301 Mdot
.56268 .39228 Mdot
.37907 .62964 Mdot
.48652 .33958 Mdot
.62666 .23485 Mdot
.57814 .55352 Mdot
.32923 .74652 Mdot
.54603 .61221 Mdot
.21 .36968 Mdot
.44637 .36328 Mdot
.45767 .25788 Mdot
.60413 .60111 Mdot
.30517 .48001 Mdot
.64917 .61832 Mdot
.60098 .61469 Mdot
.29281 .44931 Mdot
.58446 .63068 Mdot
.4038 .61049 Mdot
.6631 .3755 Mdot
.41776 .55229 Mdot
.79413 .66011 Mdot
.41397 .63387 Mdot
.42794 .20826 Mdot
.55003 .59019 Mdot
.25693 .59336 Mdot
.65603 .44059 Mdot
.53962 .6567 Mdot
.81852 .48644 Mdot
.64159 .41384 Mdot
.65554 .43155 Mdot
.55209 .6403 Mdot
.47817 .34006 Mdot
.31322 .4811 Mdot
.37768 .62948 Mdot
.34663 .23115 Mdot
.60034 .62126 Mdot
.57074 .60388 Mdot
.40085 .63634 Mdot
.48624 .37618 Mdot
.57419 .65409 Mdot
.30819 .34044 Mdot
.37106 .20122 Mdot
.46252 .34357 Mdot
.57067 .552 Mdot
.37682 .80008 Mdot
.60984 .4189 Mdot
.78155 .33298 Mdot
.34391 .63142 Mdot
.33743 .44767 Mdot
.63231 .5804 Mdot
.14768 .3498 Mdot
.40505 .61993 Mdot
.59082 .29981 Mdot
.57581 .63042 Mdot
.56575 .58469 Mdot
.68568 .44019 Mdot
.55678 .65152 Mdot
.67637 .40457 Mdot
.80717 .6476 Mdot
.68469 .80291 Mdot
.65122 .4474 Mdot
.66104 .39875 Mdot
.70174 .46675 Mdot
.64259 .75721 Mdot
.63874 .42859 Mdot
.52372 .64304 Mdot
.21368 .55389 Mdot
.57966 .686 Mdot
.42078 .63861 Mdot
.42849 .6489 Mdot
.71104 .37923 Mdot
.6268 .20567 Mdot
.62063 .54286 Mdot
.56039 .70987 Mdot
.50264 .52558 Mdot
.45238 .36199 Mdot
.60335 .64206 Mdot
.43597 .25633 Mdot
.31459 .425 Mdot
.50735 .57551 Mdot
.5905 .60544 Mdot
.63482 .41096 Mdot
.3643 .63804 Mdot
.50486 .37474 Mdot
.57344 .60954 Mdot
.34245 .50442 Mdot
.39161 .62637 Mdot
.64812 .40222 Mdot
.59749 .4064 Mdot
.40845 .6489 Mdot
.51365 .60185 Mdot
.555 .59002 Mdot
.57685 .63948 Mdot
.60433 .69822 Mdot
.47218 .35125 Mdot
.28617 .42415 Mdot
.51863 .63907 Mdot
.65786 .32007 Mdot
.4287 .47815 Mdot
.52303 .59638 Mdot
.68937 .42625 Mdot
.4591 .34055 Mdot
.45488 .24505 Mdot
.46383 .70838 Mdot
.59971 .63994 Mdot
.18478 .55098 Mdot
.77311 .45739 Mdot
.44575 .25094 Mdot
.63765 .3974 Mdot
.37772 .63368 Mdot
.54673 .62711 Mdot
.22852 .59267 Mdot
.61784 .6115 Mdot
.66356 .64827 Mdot
.33929 .45186 Mdot
.45097 .36937 Mdot
.35313 .20678 Mdot
.31313 .42496 Mdot
.65532 .42986 Mdot
.1572 .46644 Mdot
.69385 .44274 Mdot
.64164 .46546 Mdot
.26168 .66526 Mdot
.46222 .36583 Mdot
.1366 .36842 Mdot
.7359 .29421 Mdot
.618 .59955 Mdot
.48969 .38611 Mdot
.63435 .43658 Mdot
.54804 .60541 Mdot
.67688 .39738 Mdot
.66232 .46364 Mdot
.585 .66107 Mdot
.56041 .58493 Mdot
.57221 .75852 Mdot
.17566 .57648 Mdot
.37201 .62385 Mdot
.69417 .42317 Mdot
.76029 .49375 Mdot
.58246 .57288 Mdot
.61387 .60923 Mdot
.39568 .43498 Mdot
.3889 .60095 Mdot
.66665 .56339 Mdot
.58458 .63842 Mdot
.82508 .49524 Mdot
.5368 .60228 Mdot
.68988 .46022 Mdot
.47257 .33896 Mdot
.60732 .27523 Mdot
.33923 .49159 Mdot
.68054 .45069 Mdot
.39397 .6476 Mdot
.70378 .4173 Mdot
.8192 .52697 Mdot
.46248 .37093 Mdot
.67786 .40987 Mdot
.28952 .46997 Mdot
.47063 .37967 Mdot
.46195 .34527 Mdot
.23555 .58083 Mdot
.2915 .43264 Mdot
.36848 .60079 Mdot
.46888 .38743 Mdot
.72913 .49524 Mdot
.47429 .36802 Mdot
.77043 .49519 Mdot
.54852 .58056 Mdot
.55189 .75733 Mdot
.58088 .35094 Mdot
.58532 .6958 Mdot
.49694 .39105 Mdot
.37869 .60745 Mdot
.54474 .64359 Mdot
.67195 .44528 Mdot
.39092 .61067 Mdot
.42116 .3739 Mdot
.28956 .46341 Mdot
.63389 .40495 Mdot
.46624 .33997 Mdot
.67969 .40753 Mdot
.50465 .7094 Mdot
.25638 .42903 Mdot
.50536 .52876 Mdot
.46279 .46408 Mdot
.6159 .64721 Mdot
.71917 .38391 Mdot
.54437 .57976 Mdot
.59445 .60738 Mdot
.32518 .47635 Mdot
.53347 .78133 Mdot
.65277 .44338 Mdot
.36753 .1949 Mdot
.44582 .37618 Mdot
.70254 .34769 Mdot
.64157 .54318 Mdot
.56073 .66338 Mdot
.64153 .40761 Mdot
.66366 .46454 Mdot
.74669 .65428 Mdot
.35344 .48053 Mdot
.57727 .69142 Mdot
.52576 .66088 Mdot
.64357 .62246 Mdot
.44557 .36241 Mdot
.32056 .35254 Mdot
.35097 .45685 Mdot
.77581 .28242 Mdot
.34372 .47225 Mdot
.2808 .55832 Mdot
.65173 .41364 Mdot
.3669 .62931 Mdot
.61337 .6062 Mdot
.62147 .72255 Mdot
.69615 .39074 Mdot
.3988 .46996 Mdot
.38282 .63882 Mdot
.34983 .37384 Mdot
.46161 .36176 Mdot
.52715 .60236 Mdot
.59586 .65425 Mdot
.56158 .64714 Mdot
.55344 .61878 Mdot
.43667 .372 Mdot
.60578 .58178 Mdot
.43963 .38884 Mdot
.72607 .48139 Mdot
.82803 .50893 Mdot
.34704 .49364 Mdot
.34801 .72818 Mdot
.66089 .39298 Mdot
.74002 .51052 Mdot
.65264 .53342 Mdot
.6703 .30822 Mdot
.23386 .56002 Mdot
.5402 .58972 Mdot
.3386 .44098 Mdot
.43474 .8064 Mdot
.36363 .47916 Mdot
.7549 .77114 Mdot
.45277 .6367 Mdot
.17273 .49979 Mdot
.54952 .60701 Mdot
.2808 .42488 Mdot
.64944 .54443 Mdot
.55257 .562 Mdot
.44718 .62308 Mdot
.59013 .44756 Mdot
.55344 .30057 Mdot
.38668 .65013 Mdot
.59657 .62858 Mdot
.6301 .45874 Mdot
.56404 .61675 Mdot
.61184 .61092 Mdot
.5461 .5968 Mdot
.50758 .36687 Mdot
.6086 .5708 Mdot
.57986 .56941 Mdot
.5626 .17121 Mdot
.49086 .76762 Mdot
.29934 .45202 Mdot
.7695 .62114 Mdot
.38407 .62045 Mdot
.62994 .4189 Mdot
.40096 .5439 Mdot
.46151 .35171 Mdot
.73761 .66699 Mdot
.54762 .609 Mdot
.56983 .34792 Mdot
.46717 .33924 Mdot
.39573 .61185 Mdot
.4511 .23034 Mdot
.19613 .50799 Mdot
.35083 .49084 Mdot
.45743 .24611 Mdot
.32855 .47468 Mdot
.69297 .65441 Mdot
.63559 .41093 Mdot
.60708 .65332 Mdot
.47452 .39253 Mdot
.30791 .4787 Mdot
.51056 .78753 Mdot
.5813 .59826 Mdot
.31149 .45191 Mdot
.61278 .65081 Mdot
.41229 .48902 Mdot
.37689 .5254 Mdot
.35732 .44606 Mdot
.45798 .40995 Mdot
.47594 .38301 Mdot
.36767 .62177 Mdot
.62979 .4167 Mdot
.68923 .41786 Mdot
.46748 .36538 Mdot
.7971 .35718 Mdot
.60367 .61739 Mdot
.54742 .59438 Mdot
.64593 .32257 Mdot
.55703 .60753 Mdot
.46583 .73292 Mdot
.43364 .25989 Mdot
.63971 .40263 Mdot
.55466 .61406 Mdot
.57612 .65401 Mdot
.59264 .6462 Mdot
.50833 .71457 Mdot
.33439 .48209 Mdot
.54326 .62748 Mdot
.41488 .61667 Mdot
.58246 .22809 Mdot
.56049 .57543 Mdot
.54244 .56722 Mdot
.67999 .41197 Mdot
.74244 .72867 Mdot
.46318 .34745 Mdot
.30952 .45822 Mdot
.30599 .48402 Mdot
.37504 .66738 Mdot
.63664 .38795 Mdot
.43013 .25864 Mdot
.40879 .27138 Mdot
.43224 .23467 Mdot
.39998 .63208 Mdot
.28708 .53153 Mdot
.35209 .50387 Mdot
.30313 .44297 Mdot
.45457 .4008 Mdot
.55527 .61804 Mdot
.53991 .59913 Mdot
.59401 .29931 Mdot
.53534 .63747 Mdot
.38763 .64156 Mdot
.48732 .35158 Mdot
.67958 .41489 Mdot
.40797 .62156 Mdot
.44834 .38717 Mdot
.6745 .44124 Mdot
.57197 .55524 Mdot
.58557 .5541 Mdot
.66144 .43021 Mdot
.63601 .44606 Mdot
.58152 .57738 Mdot
.52562 .17471 Mdot
.62126 .43631 Mdot
.6743 .40932 Mdot
.44122 .21798 Mdot
.35297 .49019 Mdot
.50942 .59627 Mdot
.49 .38726 Mdot
.57794 .63891 Mdot
.35624 .49032 Mdot
.38269 .60111 Mdot
.6683 .43639 Mdot
.58343 .64888 Mdot
.58671 .62575 Mdot
.38163 .63248 Mdot
.38999 .65313 Mdot
.40625 .63955 Mdot
.51503 .37648 Mdot
.56208 .63289 Mdot
.64013 .43155 Mdot
.46035 .36708 Mdot
.36242 .62814 Mdot
.38416 .59192 Mdot
.59732 .18147 Mdot
.58856 .57634 Mdot
.47971 .52028 Mdot
.37697 .13948 Mdot
.44169 .71862 Mdot
.45458 .25317 Mdot
.34003 .426 Mdot
.53359 .75372 Mdot
.33632 .64279 Mdot
.49398 .3837 Mdot
.34681 .69569 Mdot
.40145 .6575 Mdot
.58481 .66406 Mdot
.53648 .60989 Mdot
.6222 .65091 Mdot
.39152 .6216 Mdot
.49502 .70449 Mdot
.68584 .39729 Mdot
.71495 .57122 Mdot
.38426 .62034 Mdot
.35689 .44577 Mdot
.35651 .43871 Mdot
.34452 .47127 Mdot
.5325 .59781 Mdot
.73938 .65631 Mdot
.74394 .49182 Mdot
.6851 .5945 Mdot
.46268 .35777 Mdot
.67078 .46294 Mdot
.24129 .56609 Mdot
.65591 .43307 Mdot
.32481 .42667 Mdot
.39535 .62328 Mdot
.69205 .4312 Mdot
.49083 .36691 Mdot
.48567 .3795 Mdot
.29159 .46714 Mdot
.32392 .48355 Mdot
.30951 .47063 Mdot
.64774 .45928 Mdot
.65136 .41451 Mdot
.58663 .65281 Mdot
.67208 .43006 Mdot
.77419 .37492 Mdot
.425 .61812 Mdot
.36225 .44715 Mdot
.48605 .36625 Mdot
.63072 .4249 Mdot
.58566 .6074 Mdot
.32867 .55307 Mdot
.41002 .37959 Mdot
.41499 .62581 Mdot
.25644 .47131 Mdot
.81385 .70011 Mdot
.60547 .64746 Mdot
.4447 .38682 Mdot
.60766 .25959 Mdot
.58699 .59442 Mdot
.33156 .45334 Mdot
.66622 .74564 Mdot
.43148 .23093 Mdot
.57671 .56944 Mdot
.53846 .65168 Mdot
.49482 .34514 Mdot
.38464 .53478 Mdot
.5531 .65909 Mdot
.58374 .38707 Mdot
.50111 .39549 Mdot
.35056 .45033 Mdot
.39259 .18509 Mdot
.32738 .41745 Mdot
.58527 .76932 Mdot
.45177 .25436 Mdot
.5927 .65548 Mdot
.3181 .46693 Mdot
.41216 .61742 Mdot
.31651 .47268 Mdot
.65059 .39198 Mdot
.30272 .46058 Mdot
.56779 .59982 Mdot
.64116 .42942 Mdot
.48827 .36608 Mdot
.6822 .33869 Mdot
.57407 .18112 Mdot
.30435 .47974 Mdot
.45987 .23115 Mdot
.57984 .57103 Mdot
.6752 .51401 Mdot
.64842 .61437 Mdot
.55208 .5834 Mdot
.46358 .38085 Mdot
.64397 .40631 Mdot
.44305 .38867 Mdot
.54794 .55412 Mdot
.80245 .60542 Mdot
.44743 .36598 Mdot
.54301 .26971 Mdot
.40139 .6347 Mdot
.58564 .75664 Mdot
.59503 .6134 Mdot
.46825 .39014 Mdot
.56319 .63417 Mdot
.69572 .41538 Mdot
.52566 .4597 Mdot
.59951 .23068 Mdot
.47709 .39234 Mdot
.18617 .4174 Mdot
.51665 .47396 Mdot
.52918 .55657 Mdot
.4609 .38847 Mdot
.71226 .67388 Mdot
.4514 .23901 Mdot
.39354 .63001 Mdot
.36741 .63782 Mdot
.41215 .64147 Mdot
.53373 .63431 Mdot
.52709 .5453 Mdot
.3738 .59386 Mdot
.50209 .39723 Mdot
.39889 .60211 Mdot
.58249 .74917 Mdot
.18922 .43509 Mdot
.41057 .63543 Mdot
.5889 .61675 Mdot
.55134 .56025 Mdot
.49218 .7699 Mdot
.3487 .44127 Mdot
.18721 .57197 Mdot
.75606 .38398 Mdot
.56737 .57546 Mdot
.5946 .52072 Mdot
.65606 .39244 Mdot
.6433 .25792 Mdot
.62548 .52456 Mdot
.36874 .54331 Mdot
.66599 .40061 Mdot
.35808 .51473 Mdot
.63524 .40634 Mdot
.6128 .641 Mdot
.5759 .62446 Mdot
.67926 .37654 Mdot
.27007 .3732 Mdot
.51419 .22298 Mdot
.24051 .31366 Mdot
.69021 .41598 Mdot
.46576 .39375 Mdot
.46531 .3997 Mdot
.45771 .36583 Mdot
.33714 .49071 Mdot
.64535 .45505 Mdot
.55598 .63038 Mdot
.32473 .44082 Mdot
.60736 .62502 Mdot
.47046 .38331 Mdot
.34827 .20978 Mdot
.67938 .41268 Mdot
.59785 .58932 Mdot
.71792 .27757 Mdot
.33865 .47072 Mdot
.37999 .62865 Mdot
.41331 .47509 Mdot
.28917 .42048 Mdot
.49586 .39358 Mdot
.61737 .40504 Mdot
.49719 .41264 Mdot
.40991 .56531 Mdot
.61882 .6625 Mdot
.52281 .60647 Mdot
.37982 .21015 Mdot
.65346 .22207 Mdot
.53185 .61766 Mdot
.31257 .44 Mdot
.36114 .46412 Mdot
.59028 .64311 Mdot
.66462 .45124 Mdot
.36033 .61454 Mdot
.41872 .63414 Mdot
.56711 .66997 Mdot
.47912 .45925 Mdot
.56191 .75948 Mdot
.56457 .6552 Mdot
.53689 .68429 Mdot
.28682 .45227 Mdot
.45146 .22917 Mdot
.61167 .34321 Mdot
.37928 .64363 Mdot
.57752 .63267 Mdot
.50558 .24196 Mdot
.67364 .40301 Mdot
.30529 .46416 Mdot
.48358 .35255 Mdot
.4483 .61902 Mdot
.30648 .48637 Mdot
.58943 .6433 Mdot
.5747 .654 Mdot
.49146 .3425 Mdot
.69097 .45917 Mdot
.39465 .62133 Mdot
.32412 .44171 Mdot
.36764 .63199 Mdot
.64888 .42163 Mdot
.67582 .41534 Mdot
.54461 .68127 Mdot
.61407 .69245 Mdot
.30457 .4819 Mdot
.5853 .67533 Mdot
.33671 .42994 Mdot
.35842 .56827 Mdot
.4481 .3478 Mdot
.54311 .66019 Mdot
.61903 .45332 Mdot
.46694 .37918 Mdot
.57172 .5803 Mdot
.41411 .2121 Mdot
.57286 .66285 Mdot
.28761 .42199 Mdot
.80916 .5968 Mdot
.38097 .60335 Mdot
.62517 .36797 Mdot
.48589 .65616 Mdot
.55808 .60682 Mdot
.33887 .42862 Mdot
.62897 .5697 Mdot
.45451 .35254 Mdot
.65414 .40599 Mdot
.87044 .47599 Mdot
.47457 .37249 Mdot
.56676 .61961 Mdot
.39016 .61277 Mdot
.64222 .46763 Mdot
.43599 .25105 Mdot
.61091 .33732 Mdot
.51436 .56591 Mdot
.61259 .56743 Mdot
.55767 .61858 Mdot
.54982 .82104 Mdot
.31204 .4631 Mdot
.63199 .43083 Mdot
.44451 .35907 Mdot
.47118 .35902 Mdot
.34528 .46156 Mdot
.55758 .32507 Mdot
.25557 .39758 Mdot
.29394 .18018 Mdot
.29493 .45639 Mdot
.40111 .60147 Mdot
.45172 .47565 Mdot
.30921 .42523 Mdot
.3186 .4606 Mdot
.29713 .47761 Mdot
.58371 .33257 Mdot
.68388 .43509 Mdot
.58684 .62696 Mdot
.63784 .38874 Mdot
.58388 .66012 Mdot
.56773 .78906 Mdot
.46626 .36424 Mdot
.65434 .40713 Mdot
.40321 .20945 Mdot
.65313 .64823 Mdot
.57852 .59193 Mdot
.21603 .49531 Mdot
.56759 .53979 Mdot
.486 .72753 Mdot
.51182 .60339 Mdot
.32599 .48093 Mdot
.57271 .52123 Mdot
.63444 .58688 Mdot
.75423 .36184 Mdot
.48962 .37294 Mdot
.44633 .26134 Mdot
.58418 .55832 Mdot
.50044 .60755 Mdot
.64175 .46687 Mdot
.69225 .43111 Mdot
.37169 .59516 Mdot
.43225 .45012 Mdot
.48947 .36914 Mdot
.29776 .39574 Mdot
.55486 .58568 Mdot
.43847 .33073 Mdot
.81892 .56003 Mdot
.57508 .58005 Mdot
.22398 .57385 Mdot
.74053 .66318 Mdot
.5567 .66081 Mdot
.70223 .61151 Mdot
.4834 .37146 Mdot
.8233 .4925 Mdot
.61646 .65429 Mdot
.3317 .45457 Mdot
.64752 .41336 Mdot
.64769 .39511 Mdot
.41251 .62672 Mdot
.76432 .35111 Mdot
.47495 .40795 Mdot
.65209 .41152 Mdot
.58908 .59838 Mdot
.47504 .35083 Mdot
.44127 .25743 Mdot
.58394 .54798 Mdot
.30152 .68109 Mdot
.67548 .42581 Mdot
.57587 .68347 Mdot
.51623 .31666 Mdot
.41722 .4958 Mdot
.17438 .59453 Mdot
.4554 .36864 Mdot
.38928 .64676 Mdot
.50951 .61011 Mdot
.40558 .26688 Mdot
.6316 .61795 Mdot
.55172 .77215 Mdot
.68077 .36188 Mdot
.36385 .61953 Mdot
.59232 .5926 Mdot
.55095 .65718 Mdot
.47382 .46996 Mdot
.38616 .65147 Mdot
.5619 .66472 Mdot
.56176 .68821 Mdot
.67393 .44056 Mdot
.43737 .26272 Mdot
.67971 .42037 Mdot
.58564 .61268 Mdot
.57735 .51732 Mdot
.67753 .44527 Mdot
.23182 .44289 Mdot
.37377 .65162 Mdot
.4597 .35187 Mdot
.4959 .63663 Mdot
.54814 .58206 Mdot
.35871 .81285 Mdot
.45061 .25978 Mdot
.63624 .782 Mdot
.29886 .41927 Mdot
.47008 .23841 Mdot
.26446 .44014 Mdot
.17201 .48498 Mdot
.64252 .34001 Mdot
.60461 .67224 Mdot
.37513 .72596 Mdot
.69454 .60009 Mdot
.46783 .40325 Mdot
.70547 .50513 Mdot
.5558 .5833 Mdot
.60942 .61047 Mdot
.32528 .43397 Mdot
.55681 .34096 Mdot
.60381 .26302 Mdot
.50317 .44356 Mdot
.39917 .62033 Mdot
.65542 .41647 Mdot
.56043 .5981 Mdot
.28351 .32349 Mdot
.29895 .45691 Mdot
.55434 .4717 Mdot
.60205 .59567 Mdot
.62945 .29259 Mdot
.56602 .29204 Mdot
.47494 .34978 Mdot
.33625 .42506 Mdot
.28779 .4237 Mdot
.61669 .62572 Mdot
.49419 .37096 Mdot
.58097 .65664 Mdot
.54239 .46418 Mdot
.58081 .68008 Mdot
.40007 .61089 Mdot
.60966 .59099 Mdot
.46962 .50002 Mdot
.15337 .51483 Mdot
.56432 .53595 Mdot
.62442 .43297 Mdot
.33696 .48971 Mdot
.34049 .47552 Mdot
.68935 .41642 Mdot
.34276 .47112 Mdot
.71971 .58055 Mdot
.80642 .50892 Mdot
.40439 .62526 Mdot
.65165 .50894 Mdot
.39464 .60855 Mdot
.44673 .26173 Mdot
.58158 .57466 Mdot
.41812 .28965 Mdot
.29513 .46212 Mdot
.70049 .73595 Mdot
.47333 .36522 Mdot
.44986 .25945 Mdot
.61225 .583 Mdot
.2868 .53414 Mdot
.33126 .43109 Mdot
.34352 .40809 Mdot
.59283 .64656 Mdot
.69079 .42849 Mdot
.55144 .65694 Mdot
.55172 .67035 Mdot
.45707 .24559 Mdot
.55723 .61959 Mdot
.44886 .38776 Mdot
.64838 .45627 Mdot
.18021 .47838 Mdot
.3477 .48837 Mdot
.60926 .59526 Mdot
.58933 .59755 Mdot
.69731 .41676 Mdot
.60249 .57626 Mdot
.49571 .38385 Mdot
.09443 .43952 Mdot
.40044 .63414 Mdot
.44578 .22477 Mdot
.32382 .40247 Mdot
.53956 .60807 Mdot
.55777 .65614 Mdot
.37117 .21295 Mdot
.54946 .20432 Mdot
.45039 .38769 Mdot
.5224 .64837 Mdot
.31389 .44333 Mdot
.39371 .61219 Mdot
.50333 .37437 Mdot
.57679 .64235 Mdot
.61011 .60596 Mdot
.40187 .61242 Mdot
.21594 .54995 Mdot
.38526 .49584 Mdot
.46024 .36073 Mdot
.60659 .51414 Mdot
.33846 .55533 Mdot
.60255 .6161 Mdot
.23824 .35101 Mdot
.67283 .41046 Mdot
.45635 .38428 Mdot
.67318 .70164 Mdot
.6054 .65537 Mdot
.49364 .39414 Mdot
.48871 .36867 Mdot
.62004 .60686 Mdot
.63333 .3905 Mdot
.65147 .46222 Mdot
.67247 .40686 Mdot
.80858 .60662 Mdot
.46175 .78988 Mdot
.30928 .47146 Mdot
.48475 .37334 Mdot
.3636 .46362 Mdot
.3593 .61312 Mdot
.43066 .47687 Mdot
.36078 .45748 Mdot
.65176 .39411 Mdot
.36023 .4421 Mdot
.57505 .65781 Mdot
.49155 .37212 Mdot
.30274 .44225 Mdot
.53902 .61457 Mdot
.55661 .69673 Mdot
.49849 .50074 Mdot
.36128 .61309 Mdot
.39327 .50366 Mdot
.57371 .61623 Mdot
.45548 .24363 Mdot
.58776 .57927 Mdot
.47901 .34738 Mdot
.45257 .50517 Mdot
.54122 .61965 Mdot
.30216 .47935 Mdot
.43392 .57452 Mdot
.3526 .45046 Mdot
.5382 .6676 Mdot
.58478 .61349 Mdot
.6046 .61473 Mdot
.55187 .65874 Mdot
.55012 .2842 Mdot
.43932 .38687 Mdot
.5034 .65688 Mdot
.34263 .50052 Mdot
.65967 .43605 Mdot
.69484 .40191 Mdot
.32934 .53346 Mdot
.4572 .2368 Mdot
.49019 .38214 Mdot
.60252 .61806 Mdot
.34684 .40948 Mdot
.33794 .21755 Mdot
.23746 .34034 Mdot
.25202 .57651 Mdot
.30829 .4404 Mdot
.62533 .43436 Mdot
.30089 .43486 Mdot
.61366 .6236 Mdot
.52312 .58481 Mdot
.17872 .48806 Mdot
.45312 .33061 Mdot
.39412 .6229 Mdot
.60894 .62309 Mdot
.59309 .7643 Mdot
.3144 .44231 Mdot
.28682 .44766 Mdot
.59233 .65318 Mdot
.67042 .45787 Mdot
.16221 .61774 Mdot
.48295 .35119 Mdot
.68128 .51226 Mdot
.62767 .37122 Mdot
.59149 .4561 Mdot
.47485 .35428 Mdot
.50339 .51309 Mdot
.35123 .46801 Mdot
.7592 .37905 Mdot
.66291 .4325 Mdot
.39015 .62442 Mdot
.51913 .60041 Mdot
.64621 .39624 Mdot
.33354 .42252 Mdot
.65039 .39841 Mdot
.60579 .6518 Mdot
.45491 .39794 Mdot
.34723 .46061 Mdot
.43589 .39064 Mdot
.68169 .37719 Mdot
.38979 .60528 Mdot
.59255 .75108 Mdot
.69591 .50297 Mdot
.73939 .6645 Mdot
.54356 .62744 Mdot
.3701 .43701 Mdot
.56194 .63565 Mdot
.64726 .46657 Mdot
.59398 .61408 Mdot
.72101 .38994 Mdot
.2994 .42344 Mdot
.57925 .68278 Mdot
.58917 .57222 Mdot
.74244 .4447 Mdot
.57919 .58611 Mdot
.61525 .58799 Mdot
.53924 .65017 Mdot
.647 .36118 Mdot
.56724 .687 Mdot
.68699 .43399 Mdot
.58972 .30774 Mdot
.32067 .46209 Mdot
.37368 .59052 Mdot
.41606 .64096 Mdot
.55226 .7689 Mdot
.58576 .75791 Mdot
.56179 .32863 Mdot
.68424 .42441 Mdot
.46972 .39784 Mdot
.58252 .65596 Mdot
.67335 .69171 Mdot
.39041 .66158 Mdot
.35037 .46613 Mdot
.32153 .49305 Mdot
.62601 .68265 Mdot
.5332 .82777 Mdot
.56927 .68486 Mdot
.61697 .33096 Mdot
.58315 .66963 Mdot
.54244 .65852 Mdot
.29017 .47257 Mdot
.54354 .73095 Mdot
.54321 .62714 Mdot
.64177 .46693 Mdot
.38654 .62705 Mdot
.61052 .52826 Mdot
.4409 .64264 Mdot
.53095 .48609 Mdot
.74259 .40177 Mdot
.55526 .62448 Mdot
.331 .44456 Mdot
.63214 .40735 Mdot
.65537 .32352 Mdot
.45978 .36999 Mdot
.58839 .35896 Mdot
.74165 .46979 Mdot
.23434 .46834 Mdot
.39147 .62608 Mdot
.22586 .56643 Mdot
.56754 .60012 Mdot
.33073 .4904 Mdot
.59913 .65416 Mdot
.32836 .22461 Mdot
.37485 .60267 Mdot
.69811 .39115 Mdot
.46641 .39446 Mdot
.6928 .41102 Mdot
.74889 .63669 Mdot
.49051 .55319 Mdot
.44324 .20287 Mdot
.3559 .48702 Mdot
.63307 .74498 Mdot
.63618 .42377 Mdot
.58103 .6463 Mdot
.32313 .16481 Mdot
.67078 .41104 Mdot
.6933 .4183 Mdot
.3735 .54475 Mdot
.46866 .67401 Mdot
.6223 .56241 Mdot
.65764 .39581 Mdot
.36634 .46718 Mdot
.37421 .62231 Mdot
.54259 .6385 Mdot
.54203 .65178 Mdot
.68768 .43764 Mdot
.33111 .42957 Mdot
.61253 .76969 Mdot
.32499 .48254 Mdot
.66583 .44465 Mdot
.33544 .46855 Mdot
.34985 .40487 Mdot
.30508 .44936 Mdot
.56961 .56752 Mdot
.60079 .61951 Mdot
.3014 .64551 Mdot
.67581 .41551 Mdot
.54982 .64987 Mdot
.5805 .63046 Mdot
.63797 .42962 Mdot
.35676 .50075 Mdot
.65813 .72221 Mdot
.54929 .60351 Mdot
.59309 .62596 Mdot
.36528 .62686 Mdot
.31332 .50987 Mdot
.27875 .31615 Mdot
.54515 .64313 Mdot
.41926 .62569 Mdot
.64386 .45867 Mdot
.58476 .57876 Mdot
.57714 .74828 Mdot
.29103 .47999 Mdot
.61623 .60285 Mdot
.43511 .25132 Mdot
.53939 .60203 Mdot
.16065 .61079 Mdot
.60273 .58503 Mdot
.63648 .43903 Mdot
.64334 .41319 Mdot
.40396 .46785 Mdot
.65597 .4272 Mdot
.44841 .25687 Mdot
.47158 .38252 Mdot
.21843 .35684 Mdot
.44439 .25636 Mdot
.52989 .64662 Mdot
.73618 .2945 Mdot
.59344 .67204 Mdot
.57394 .55909 Mdot
.64673 .75552 Mdot
.44606 .25473 Mdot
.63786 .41207 Mdot
.27486 .37023 Mdot
.55101 .66698 Mdot
.48629 .35453 Mdot
.54289 .56847 Mdot
.61411 .59532 Mdot
.58045 .41877 Mdot
.77849 .64142 Mdot
.4784 .34518 Mdot
.51628 .58177 Mdot
.54577 .64317 Mdot
.61503 .21285 Mdot
.58261 .60085 Mdot
.41172 .63225 Mdot
.6844 .40861 Mdot
.29585 .43675 Mdot
.3912 .63639 Mdot
.55188 .59985 Mdot
.38845 .62111 Mdot
.30787 .46701 Mdot
.46227 .38284 Mdot
.6137 .60245 Mdot
.41919 .64251 Mdot
.39705 .61986 Mdot
.56201 .64216 Mdot
.65135 .41 Mdot
.63393 .5651 Mdot
.58189 .57858 Mdot
.58508 .64427 Mdot
.68917 .41784 Mdot
.69815 .22013 Mdot
.61394 .63387 Mdot
.48426 .51667 Mdot
.68479 .38548 Mdot
.42638 .23716 Mdot
.30277 .43601 Mdot
.62272 .63041 Mdot
.46622 .36014 Mdot
.46539 .37155 Mdot
.37375 .47711 Mdot
.69825 .42725 Mdot
.34441 .43826 Mdot
.55514 .54408 Mdot
.61303 .69146 Mdot
.51684 .63546 Mdot
.86964 .48219 Mdot
.1937 .51664 Mdot
.64965 .45405 Mdot
.35222 .46047 Mdot
.50488 .44117 Mdot
.4881 .38262 Mdot
.36859 .45508 Mdot
.61788 .44748 Mdot
.63079 .44271 Mdot
.65885 .39344 Mdot
.3721 .63516 Mdot
.33592 .48611 Mdot
.70376 .44235 Mdot
.68119 .45091 Mdot
.58692 .65103 Mdot
.54687 .64419 Mdot
.70507 .37847 Mdot
.48064 .7605 Mdot
.39433 .60618 Mdot
.33432 .44916 Mdot
.32719 .80565 Mdot
.47786 .34698 Mdot
.7438 .44071 Mdot
.54007 .61196 Mdot
.50402 .09769 Mdot
.54048 .67525 Mdot
.58698 .59914 Mdot
.64227 .45629 Mdot
.41337 .60948 Mdot
.38023 .61417 Mdot
.63686 .42224 Mdot
.66709 .37159 Mdot
.40259 .6446 Mdot
.24815 .58213 Mdot
.18249 .40284 Mdot
.63486 .3328 Mdot
.63853 .43854 Mdot
.69113 .50017 Mdot
.49699 .38668 Mdot
.67404 .37873 Mdot
.47366 .34316 Mdot
.31922 .45964 Mdot
.31338 .48693 Mdot
.48888 .34157 Mdot
.59708 .64264 Mdot
.30399 .45837 Mdot
.5159 .56205 Mdot
.19794 .48424 Mdot
.29343 .71392 Mdot
.52292 .19373 Mdot
.53724 .60048 Mdot
.60829 .27155 Mdot
.57458 .2504 Mdot
.56527 .61041 Mdot
.65778 .64978 Mdot
.39205 .62282 Mdot
.6821 .38088 Mdot
.49547 .37886 Mdot
.18249 .60652 Mdot
.6025 .61681 Mdot
.65361 .44385 Mdot
.49067 .37695 Mdot
.3675 .40536 Mdot
.57863 .39462 Mdot
.59404 .65383 Mdot
.18818 .28292 Mdot
.69226 .38472 Mdot
.29572 .43658 Mdot
.74058 .31818 Mdot
.64578 .38605 Mdot
.36353 .55597 Mdot
.28862 .42952 Mdot
.25882 .29836 Mdot
.62954 .42263 Mdot
.36992 .50079 Mdot
.65017 .42339 Mdot
.4059 .61398 Mdot
.61968 .40297 Mdot
.34533 .45556 Mdot
.58797 .58891 Mdot
.34378 .46261 Mdot
.39785 .60658 Mdot
.33044 .49205 Mdot
.49634 .37988 Mdot
.45367 .25183 Mdot
.48213 .38195 Mdot
.42262 .48185 Mdot
.78596 .62469 Mdot
.45124 .36884 Mdot
.26984 .41402 Mdot
.5325 .61632 Mdot
.68543 .46348 Mdot
.29353 .43998 Mdot
.35918 .49092 Mdot
.4388 .46609 Mdot
.65068 .4385 Mdot
.34319 .45573 Mdot
.73493 .47972 Mdot
.77365 .29092 Mdot
.49846 .58771 Mdot
.41536 .77316 Mdot
.63784 .43226 Mdot
.29405 .4271 Mdot
.64106 .32395 Mdot
.67793 .39042 Mdot
.29598 .45924 Mdot
.46481 .3908 Mdot
.47227 .35711 Mdot
.60536 .63769 Mdot
.4374 .34171 Mdot
.32816 .42358 Mdot
.51404 .23042 Mdot
.68385 .40578 Mdot
.37658 .4092 Mdot
.41281 .63555 Mdot
.31387 .45837 Mdot
.6407 .60347 Mdot
.67735 .37017 Mdot
.33577 .4974 Mdot
.31997 .70466 Mdot
.37007 .83167 Mdot
.34244 .45656 Mdot
.68399 .40791 Mdot
.66777 .43786 Mdot
.59381 .54027 Mdot
.47309 .46256 Mdot
.33966 .43676 Mdot
.42065 .30411 Mdot
.552 .77573 Mdot
.43748 .24092 Mdot
.66626 .22514 Mdot
.543 .6252 Mdot
.56501 .63459 Mdot
.4875 .38935 Mdot
.57193 .5936 Mdot
.66247 .46155 Mdot
.57005 .5622 Mdot
.48794 .40071 Mdot
.35031 .46226 Mdot
.60179 .58741 Mdot
.37695 .60942 Mdot
.49921 .38117 Mdot
.49995 .35099 Mdot
.32727 .46902 Mdot
.65882 .39454 Mdot
.24932 .37692 Mdot
.32584 .48344 Mdot
.55374 .62392 Mdot
.44693 .24601 Mdot
.61241 .64797 Mdot
.28288 .65306 Mdot
.68693 .39944 Mdot
.29996 .43448 Mdot
.63532 .39937 Mdot
.48019 .37695 Mdot
.37043 .48284 Mdot
.57984 .60398 Mdot
.29771 .46676 Mdot
.33841 .66324 Mdot
.2596 .61418 Mdot
.6924 .44225 Mdot
.43135 .61715 Mdot
.69532 .42471 Mdot
.43674 .2419 Mdot
.40104 .69282 Mdot
.39912 .62794 Mdot
.31262 .44758 Mdot
.18942 .52559 Mdot
.29359 .46784 Mdot
.57704 .58499 Mdot
.56167 .58566 Mdot
.32165 .4331 Mdot
.37012 .61652 Mdot
.74613 .71897 Mdot
.48989 .53212 Mdot
.63854 .40852 Mdot
.72642 .36306 Mdot
.25812 .74493 Mdot
.48657 .4146 Mdot
.47833 .39692 Mdot
.51139 .64669 Mdot
.56517 .66355 Mdot
.50423 .36475 Mdot
.44005 .36237 Mdot
.36218 .62128 Mdot
.32046 .48681 Mdot
.64304 .47893 Mdot
.50202 .38199 Mdot
.47969 .65557 Mdot
.59519 .75901 Mdot
.58467 .53931 Mdot
.60574 .68009 Mdot
.53512 .59296 Mdot
.4114 .49935 Mdot
.44049 .37982 Mdot
.57649 .61862 Mdot
.53752 .67672 Mdot
.45373 .38536 Mdot
.40269 .61139 Mdot
.64973 .48871 Mdot
.33562 .4607 Mdot
.64852 .16001 Mdot
.61263 .59812 Mdot
.58654 .58466 Mdot
.46296 .3575 Mdot
.63095 .20654 Mdot
.64724 .45066 Mdot
.67241 .3949 Mdot
.31108 .46324 Mdot
.43601 .46338 Mdot
.5775 .56519 Mdot
.56857 .61226 Mdot
.3183 .45006 Mdot
.45401 .24864 Mdot
.48942 .19257 Mdot
.5864 .62437 Mdot
.4843 .36559 Mdot
.38268 .436 Mdot
.43962 .37771 Mdot
.60246 .65044 Mdot
.57366 .58459 Mdot
.57348 .56702 Mdot
.55682 .66293 Mdot
.49808 .35126 Mdot
.5708 .61016 Mdot
.64608 .63879 Mdot
.65533 .40158 Mdot
.54739 .612 Mdot
.54725 .76269 Mdot
.59339 .62202 Mdot
.37949 .60784 Mdot
.26529 .33923 Mdot
.60679 .61829 Mdot
.54898 .61324 Mdot
.49057 .52655 Mdot
.59587 .59597 Mdot
.47327 .34674 Mdot
.66466 .43529 Mdot
.48519 .37446 Mdot
.446 .36156 Mdot
.36495 .47674 Mdot
.36198 .618 Mdot
.6322 .61661 Mdot
.41474 .63711 Mdot
.63828 .63617 Mdot
.60274 .65435 Mdot
.3637 .5151 Mdot
.61326 .33231 Mdot
.336 .62615 Mdot
.58229 .60745 Mdot
.31589 .46384 Mdot
.29599 .44151 Mdot
.35843 .71676 Mdot
.54408 .54176 Mdot
.50241 .3639 Mdot
.46879 .39048 Mdot
.45884 .73024 Mdot
.58478 .39972 Mdot
.38578 .60611 Mdot
.52893 .42404 Mdot
.53348 .60296 Mdot
.58792 .63298 Mdot
.54464 .56575 Mdot
.36192 .46004 Mdot
.45631 .2399 Mdot
.34945 .47134 Mdot
.43703 .21244 Mdot
.43881 .38047 Mdot
.54012 .59745 Mdot
.26529 .69042 Mdot
.67849 .44804 Mdot
.66569 .43441 Mdot
.50407 .39491 Mdot
.3514 .44612 Mdot
.60686 .54776 Mdot
.87604 .48434 Mdot
.71478 .3998 Mdot
.39587 .59477 Mdot
.56771 .6149 Mdot
.32362 .46833 Mdot
.67642 .45161 Mdot
.40579 .65273 Mdot
.54686 .59139 Mdot
.34003 .5019 Mdot
.59497 .61675 Mdot
.69376 .61522 Mdot
.65006 .40439 Mdot
.3388 .21401 Mdot
.69513 .44087 Mdot
.49801 .39059 Mdot
.44465 .3731 Mdot
.57231 .58102 Mdot
.82985 .40466 Mdot
.70171 .39241 Mdot
.43255 .38464 Mdot
.38965 .59824 Mdot
.44554 .2253 Mdot
.3714 .59964 Mdot
.31391 .42354 Mdot
.38929 .6275 Mdot
.30576 .48385 Mdot
.46051 .74383 Mdot
.71386 .4179 Mdot
.39684 .63516 Mdot
.59535 .18901 Mdot
.61592 .57968 Mdot
.36418 .63134 Mdot
.63193 .67417 Mdot
.70162 .35514 Mdot
.32159 .45231 Mdot
.37101 .61621 Mdot
.57968 .64862 Mdot
.20306 .63038 Mdot
.44476 .36776 Mdot
.50131 .36159 Mdot
.63266 .60998 Mdot
.28929 .46603 Mdot
.65832 .37292 Mdot
.40496 .5429 Mdot
.42588 .243 Mdot
.57013 .6121 Mdot
.53999 .59628 Mdot
.7 .41245 Mdot
.65648 .46798 Mdot
.57076 .58405 Mdot
.72026 .49829 Mdot
.56563 .6003 Mdot
.47126 .3544 Mdot
.63536 .44618 Mdot
.66871 .43571 Mdot
.33633 .42571 Mdot
.69693 .43001 Mdot
.59393 .68443 Mdot
.49646 .33504 Mdot
.51327 .62207 Mdot
.47544 .3755 Mdot
.45925 .50654 Mdot
.34099 .49075 Mdot
.18506 .59022 Mdot
.70138 .4212 Mdot
.55421 .61724 Mdot
.69565 .42093 Mdot
.40442 .64043 Mdot
.67568 .41787 Mdot
.62228 .41781 Mdot
.55833 .58376 Mdot
.59329 .655 Mdot
.44936 .25113 Mdot
.4681 .46187 Mdot
.66155 .40509 Mdot
.56257 .60294 Mdot
.59642 .67215 Mdot
.62162 .60052 Mdot
.49497 .47781 Mdot
.63218 .44754 Mdot
.78375 .49648 Mdot
.28662 .67722 Mdot
.65574 .40843 Mdot
.19028 .65164 Mdot
.43134 .24295 Mdot
.45397 .23019 Mdot
.47691 .4149 Mdot
.58834 .62698 Mdot
.3476 .44793 Mdot
.61428 .62156 Mdot
.50438 .58007 Mdot
.61126 .60831 Mdot
.38674 .6005 Mdot
.63317 .63754 Mdot
.44011 .23242 Mdot
.33125 .48217 Mdot
.54745 .60281 Mdot
.60642 .59335 Mdot
.45874 .24367 Mdot
.70064 .43356 Mdot
.62837 .43392 Mdot
.23533 .35752 Mdot
.40717 .62741 Mdot
.46171 .37771 Mdot
.60387 .63456 Mdot
.31386 .46338 Mdot
.34361 .46648 Mdot
.69337 .41306 Mdot
.33458 .45507 Mdot
.48208 .34979 Mdot
.57877 .59899 Mdot
.50268 .36004 Mdot
.38886 .6012 Mdot
.68479 .40946 Mdot
.60505 .63374 Mdot
.5877 .65031 Mdot
.64325 .41304 Mdot
.53236 .61558 Mdot
.36557 .62757 Mdot
.3128 .48448 Mdot
.62966 .43321 Mdot
.46935 .38026 Mdot
.34342 .42966 Mdot
.57554 .65558 Mdot
.4256 .841 Mdot
.56899 .59426 Mdot
.59171 .63974 Mdot
.17312 .44422 Mdot
.51833 .65465 Mdot
.30024 .42477 Mdot
.69303 .39753 Mdot
.58505 .55469 Mdot
.55638 .78837 Mdot
.38195 .22605 Mdot
.37063 .46182 Mdot
.56287 .61673 Mdot
.18111 .57412 Mdot
.55494 .61249 Mdot
.36016 .39878 Mdot
.37595 .5127 Mdot
.47724 .80919 Mdot
.60767 .6814 Mdot
.47679 .34091 Mdot
.44987 .25268 Mdot
.29077 .44711 Mdot
.7156 .6558 Mdot
.55451 .59494 Mdot
.70958 .68027 Mdot
.60597 .58203 Mdot
.47506 .35518 Mdot
.6325 .6929 Mdot
.33489 .45052 Mdot
.75536 .35446 Mdot
.55662 .62988 Mdot
.63376 .44818 Mdot
.36317 .44876 Mdot
.43572 .22661 Mdot
.58331 .64854 Mdot
.41691 .62777 Mdot
.5275 .34555 Mdot
.60461 .69053 Mdot
.47315 .37605 Mdot
.58012 .63227 Mdot
.51574 .57858 Mdot
.80099 .37549 Mdot
.65001 .40252 Mdot
.4739 .3958 Mdot
.63504 .24824 Mdot
.5305 .61658 Mdot
.62926 .42555 Mdot
.6612 .43368 Mdot
.41167 .61996 Mdot
.54931 .39554 Mdot
.46349 .29258 Mdot
.32278 .74404 Mdot
.76621 .63104 Mdot
.32667 .42114 Mdot
.53845 .2227 Mdot
.54518 .63839 Mdot
.5039 .53423 Mdot
.46995 .34643 Mdot
.58878 .58699 Mdot
.79295 .60044 Mdot
.67366 .40749 Mdot
.58622 .62044 Mdot
.39773 .60929 Mdot
.54056 .37363 Mdot
.54275 .48654 Mdot
.34476 .79602 Mdot
.36802 .46066 Mdot
.52397 .58766 Mdot
.6257 .66831 Mdot
.42764 .23291 Mdot
.58954 .66102 Mdot
.29196 .4412 Mdot
.21123 .49862 Mdot
.37039 .61223 Mdot
.68741 .44245 Mdot
.43097 .24062 Mdot
.54507 .5763 Mdot
.62414 .63659 Mdot
.37554 .59029 Mdot
.57255 .64371 Mdot
.75078 .34198 Mdot
.46146 .27497 Mdot
.30278 .45205 Mdot
.64749 .39901 Mdot
.53215 .59678 Mdot
.45596 .23945 Mdot
.55908 .58485 Mdot
.7091 .46257 Mdot
.56602 .6293 Mdot
.53227 .33333 Mdot
.64758 .41423 Mdot
.47582 .37946 Mdot
.63362 .60737 Mdot
.60526 .60672 Mdot
.33315 .55619 Mdot
.50363 .58203 Mdot
.60459 .5875 Mdot
.63889 .46668 Mdot
.67045 .44927 Mdot
.68834 .43053 Mdot
.30177 .45959 Mdot
.62121 .33868 Mdot
.47792 .36554 Mdot
.59318 .56908 Mdot
.50201 .38131 Mdot
.48117 .63631 Mdot
.38596 .59137 Mdot
.22723 .68416 Mdot
.54493 .6012 Mdot
.68651 .42845 Mdot
.51086 .25001 Mdot
.64576 .45927 Mdot
.30997 .50023 Mdot
.48974 .36935 Mdot
.66921 .41024 Mdot
.5966 .60239 Mdot
.49504 .45165 Mdot
.3841 .81329 Mdot
.48576 .38499 Mdot
.5367 .5717 Mdot
.36873 .46876 Mdot
.31957 .49432 Mdot
.19159 .68242 Mdot
.44409 .38001 Mdot
.57156 .24616 Mdot
.55997 .60465 Mdot
.68032 .44597 Mdot
.45483 .36483 Mdot
.46519 .3441 Mdot
.32438 .45099 Mdot
.60103 .64837 Mdot
.60235 .61172 Mdot
.43416 .24985 Mdot
.46851 .38837 Mdot
.61105 .57094 Mdot
.58414 .66652 Mdot
.17531 .48294 Mdot
.65929 .48397 Mdot
.66581 .19521 Mdot
.55329 .54519 Mdot
.76821 .63893 Mdot
.44886 .48768 Mdot
.65025 .45517 Mdot
.60916 .63111 Mdot
.5429 .57408 Mdot
.31858 .4199 Mdot
.57414 .59752 Mdot
.35724 .46552 Mdot
.48062 .39793 Mdot
.23992 .70041 Mdot
.38655 .40341 Mdot
.23706 .56292 Mdot
.57636 .59048 Mdot
.5837 .45326 Mdot
.39243 .63994 Mdot
.51351 .37569 Mdot
.6588 .44759 Mdot
.52718 .60702 Mdot
.28498 .4295 Mdot
.3124 .44617 Mdot
.66377 .42669 Mdot
.57331 .26798 Mdot
.23605 .43757 Mdot
.56122 .6657 Mdot
.3062 .43143 Mdot
.37892 .38433 Mdot
.72357 .50925 Mdot
.44956 .33473 Mdot
.37172 .60787 Mdot
.3497 .46176 Mdot
.49728 .34606 Mdot
.71031 .45668 Mdot
.66164 .41885 Mdot
.69888 .39868 Mdot
.30146 .60906 Mdot
.34322 .44052 Mdot
.38034 .63359 Mdot
.60659 .3676 Mdot
.64332 .34299 Mdot
.38101 .60076 Mdot
.35074 .46187 Mdot
.67255 .45128 Mdot
.65692 .4452 Mdot
.66357 .43634 Mdot
.75395 .35566 Mdot
.6839 .3991 Mdot
.7801 .45144 Mdot
.59985 .6687 Mdot
.67171 .51609 Mdot
.55724 .6138 Mdot
.48966 .34609 Mdot
.64845 .40545 Mdot
.44621 .47336 Mdot
.52873 .63832 Mdot
.34809 .79441 Mdot
.57211 .61593 Mdot
.47391 .32618 Mdot
.59057 .62716 Mdot
.70491 .48133 Mdot
.68478 .38517 Mdot
.5804 .60713 Mdot
.44301 .34803 Mdot
.39449 .61754 Mdot
.61844 .46995 Mdot
.6065 .61721 Mdot
.55517 .36058 Mdot
.5341 .67266 Mdot
.20185 .48438 Mdot
.39766 .56013 Mdot
.40065 .59721 Mdot
.55578 .68645 Mdot
.35067 .4314 Mdot
.60691 .41646 Mdot
.65839 .52078 Mdot
.48489 .38555 Mdot
.69972 .72419 Mdot
.31047 .44935 Mdot
.63424 .69144 Mdot
.53789 .66172 Mdot
.37306 .63796 Mdot
.6125 .4062 Mdot
.46603 .35151 Mdot
.53807 .60492 Mdot
.61947 .60368 Mdot
.31871 .66968 Mdot
.66066 .51246 Mdot
.62486 .6003 Mdot
.36226 .60505 Mdot
.78937 .50142 Mdot
.59861 .62929 Mdot
.35777 .49903 Mdot
.6796 .3873 Mdot
.63165 .64986 Mdot
.78 .48963 Mdot
.56048 .60136 Mdot
.66927 .41543 Mdot
.70201 .41662 Mdot
.53085 .29413 Mdot
.40165 .59934 Mdot
.56638 .62962 Mdot
.37166 .56324 Mdot
.56049 .63113 Mdot
.47801 .36159 Mdot
.61386 .63571 Mdot
.31652 .45529 Mdot
.6378 .3227 Mdot
.30386 .47026 Mdot
.61395 .62953 Mdot
.65628 .44069 Mdot
.46174 .35251 Mdot
.29173 .63105 Mdot
.3599 .53267 Mdot
.78269 .4584 Mdot
.40811 .21154 Mdot
.37068 .62916 Mdot
.36872 .64144 Mdot
.45934 .40216 Mdot
.58436 .61146 Mdot
.39173 .51699 Mdot
.56126 .67935 Mdot
.59391 .6277 Mdot
.61321 .60987 Mdot
.43965 .33658 Mdot
.48788 .37598 Mdot
.33947 .46586 Mdot
.57049 .58544 Mdot
.56433 .60354 Mdot
.65726 .41177 Mdot
.39731 .61841 Mdot
.2996 .46158 Mdot
.40442 .63439 Mdot
.32244 .47925 Mdot
.1643 .61563 Mdot
.55008 .55198 Mdot
.39372 .61604 Mdot
.44967 .39658 Mdot
.69035 .41944 Mdot
.45291 .25969 Mdot
.32196 .42392 Mdot
.33725 .45055 Mdot
.5681 .61047 Mdot
.68281 .41173 Mdot
.67526 .40199 Mdot
.39138 .64502 Mdot
.4557 .37888 Mdot
.61366 .62805 Mdot
.58232 .66194 Mdot
.36575 .74689 Mdot
.35499 .44307 Mdot
.73748 .49426 Mdot
.54853 .30062 Mdot
.58477 .61064 Mdot
.65588 .39843 Mdot
.59587 .58263 Mdot
.20578 .60408 Mdot
.64949 .39502 Mdot
.55135 .66243 Mdot
.59802 .38976 Mdot
.36262 .47572 Mdot
.50347 .29796 Mdot
.62179 .64897 Mdot
.36517 .21575 Mdot
.55284 .63939 Mdot
.14743 .44486 Mdot
.57397 .21037 Mdot
.56153 .56614 Mdot
.54182 .64913 Mdot
.35519 .77332 Mdot
.55676 .60666 Mdot
.43565 .23637 Mdot
.55354 .54301 Mdot
.62897 .43976 Mdot
.41116 .51714 Mdot
.27922 .481 Mdot
.39768 .59913 Mdot
.31052 .46285 Mdot
.41063 .6718 Mdot
.40581 .61515 Mdot
.63595 .4346 Mdot
.54207 .65247 Mdot
.60458 .74225 Mdot
.30926 .49799 Mdot
.55484 .6725 Mdot
.47821 .36021 Mdot
.29103 .49318 Mdot
.35271 .47739 Mdot
.4739 .38325 Mdot
.59721 .57537 Mdot
.60797 .78288 Mdot
.33251 .52948 Mdot
.2444 .30026 Mdot
.46055 .36039 Mdot
.48019 .35411 Mdot
.67265 .32054 Mdot
.39836 .59966 Mdot
.32468 .6812 Mdot
.58924 .485 Mdot
.49214 .36312 Mdot
.45929 .70607 Mdot
.28565 .44956 Mdot
.56156 .38173 Mdot
.68094 .38073 Mdot
.55053 .55354 Mdot
.59943 .6035 Mdot
.45396 .38117 Mdot
.63257 .71529 Mdot
.71332 .31055 Mdot
.48258 .38322 Mdot
.63963 .64562 Mdot
.54429 .38582 Mdot
.44419 .24802 Mdot
.43318 .25108 Mdot
.38538 .59566 Mdot
.23634 .45031 Mdot
.6459 .42388 Mdot
.37714 .64353 Mdot
.51312 .31801 Mdot
.57101 .63315 Mdot
.47644 .39153 Mdot
.45319 .26186 Mdot
.46702 .36778 Mdot
.3837 .61122 Mdot
.39498 .59452 Mdot
.65429 .40169 Mdot
.64768 .45042 Mdot
.76708 .65096 Mdot
.48168 .73904 Mdot
.5513 .60932 Mdot
.6734 .7139 Mdot
.68821 .40855 Mdot
.63472 .51133 Mdot
.4173 .61929 Mdot
.39924 .61703 Mdot
.70043 .57864 Mdot
.58843 .65296 Mdot
.38936 .41783 Mdot
.60392 .62205 Mdot
.39716 .69831 Mdot
.5331 .65388 Mdot
.32848 .45276 Mdot
.54644 .62048 Mdot
.25674 .36223 Mdot
.53709 .63156 Mdot
.6104 .59561 Mdot
.3416 .47925 Mdot
.60753 .55427 Mdot
.31533 .45353 Mdot
.60294 .64883 Mdot
.35833 .6041 Mdot
.3137 .46363 Mdot
.44017 .78165 Mdot
.48564 .51527 Mdot
.45207 .23319 Mdot
.39922 .60493 Mdot
.41301 .63772 Mdot
.56805 .76743 Mdot
.65394 .44815 Mdot
.70929 .45097 Mdot
.58427 .61239 Mdot
.28706 .44794 Mdot
.48798 .3898 Mdot
.5641 .60201 Mdot
.53256 .58341 Mdot
.62994 .62872 Mdot
.67062 .40574 Mdot
.34958 .4448 Mdot
.38828 .61761 Mdot
.30061 .4385 Mdot
.30992 .53333 Mdot
.30564 .48604 Mdot
.51792 .661 Mdot
.58048 .5492 Mdot
.52218 .54233 Mdot
.70471 .69807 Mdot
.76052 .37089 Mdot
.66022 .42397 Mdot
.45011 .24029 Mdot
.38764 .59311 Mdot
.72845 .36712 Mdot
.6782 .43834 Mdot
.33973 .44873 Mdot
.5951 .61657 Mdot
.64439 .63403 Mdot
.56038 .48071 Mdot
.64508 .36553 Mdot
.53329 .78016 Mdot
.33722 .48857 Mdot
.43948 .24409 Mdot
.63507 .33042 Mdot
.6813 .35663 Mdot
.43738 .47536 Mdot
.60581 .59733 Mdot
.41741 .62872 Mdot
.67658 .45152 Mdot
.3098 .62993 Mdot
.45999 .38718 Mdot
.47216 .46198 Mdot
.5758 .5917 Mdot
.53193 .23883 Mdot
.65598 .44027 Mdot
.39386 .60735 Mdot
.4535 .38146 Mdot
.40571 .60322 Mdot
.43013 .24542 Mdot
.22914 .36861 Mdot
.5656 .64163 Mdot
.59618 .57893 Mdot
.43598 .3862 Mdot
.6471 .42594 Mdot
.39702 .47759 Mdot
.30808 .66418 Mdot
.30961 .4312 Mdot
.38643 .51533 Mdot
.65151 .45654 Mdot
.73928 .41994 Mdot
.2994 .44708 Mdot
.50335 .39641 Mdot
.41325 .50226 Mdot
.47825 .40202 Mdot
.60673 .62146 Mdot
.68151 .42696 Mdot
.44523 .38324 Mdot
.32817 .5712 Mdot
.1653 .55565 Mdot
.6878 .4842 Mdot
.54116 .60004 Mdot
.23837 .69595 Mdot
.18426 .46083 Mdot
.61689 .72447 Mdot
.49616 .38857 Mdot
.57487 .57784 Mdot
.56395 .66724 Mdot
.55375 .62704 Mdot
.46324 .3966 Mdot
.26904 .53359 Mdot
.32689 .44502 Mdot
.57139 .61978 Mdot
.4113 .63745 Mdot
.32473 .45945 Mdot
.35315 .42924 Mdot
.2901 .45706 Mdot
.62408 .41563 Mdot
.5542 .66266 Mdot
.58447 .34588 Mdot
.14527 .46335 Mdot
.48575 .37651 Mdot
.45146 .23243 Mdot
.60252 .58123 Mdot
.82805 .53361 Mdot
.68791 .43054 Mdot
.31202 .43079 Mdot
.58796 .58513 Mdot
.3058 .54537 Mdot
.45007 .2146 Mdot
.32631 .48525 Mdot
.65386 .44666 Mdot
.61354 .7247 Mdot
.57306 .59793 Mdot
.55567 .642 Mdot
.64108 .42751 Mdot
.23985 .33706 Mdot
.61935 .3318 Mdot
.60247 .58896 Mdot
.47609 .38088 Mdot
.78952 .3265 Mdot
.62847 .62781 Mdot
.69103 .37202 Mdot
.44624 .22517 Mdot
.54923 .33493 Mdot
.74001 .49995 Mdot
.4979 .60888 Mdot
.2547 .69864 Mdot
.55167 .73414 Mdot
.21471 .67747 Mdot
.38181 .66364 Mdot
.34609 .35634 Mdot
.14785 .59296 Mdot
.44333 .34642 Mdot
.65581 .50642 Mdot
.43218 .8057 Mdot
.58919 .28182 Mdot
.40194 .55911 Mdot
.39057 .263 Mdot
.34704 .54773 Mdot
.49905 .16031 Mdot
.29479 .46296 Mdot
.37212 .70085 Mdot
.6153 .6238 Mdot
.19021 .45016 Mdot
.71834 .48428 Mdot
.76191 .33921 Mdot
.20718 .66006 Mdot
.38122 .56285 Mdot
.41104 .81836 Mdot
.18821 .57348 Mdot
.63414 .74607 Mdot
.56428 .46645 Mdot
.43759 .29367 Mdot
.6191 .35488 Mdot
.42932 .67173 Mdot
.58289 .53408 Mdot
.28269 .32729 Mdot
.22665 .47456 Mdot
.80312 .53188 Mdot
.7898 .34887 Mdot
.31028 .42214 Mdot
.67575 .38613 Mdot
.36185 .74938 Mdot
.60621 .44912 Mdot
.52029 .35775 Mdot
.25544 .69978 Mdot
.16995 .4888 Mdot
.70832 .47875 Mdot
.39479 .19269 Mdot
.71304 .62441 Mdot
.78578 .67579 Mdot
.50354 .4909 Mdot
.7044 .41031 Mdot
.36765 .33121 Mdot
.64457 .34293 Mdot
.42938 .32346 Mdot
.7486 .38402 Mdot
.42698 .64252 Mdot
.4796 .77679 Mdot
.65173 .44396 Mdot
.73515 .51118 Mdot
.44303 .21987 Mdot
.48719 .30142 Mdot
.37272 .50173 Mdot
.21364 .62229 Mdot
.4266 .20585 Mdot
.56335 .36315 Mdot
.51048 .22068 Mdot
.4083 .84012 Mdot
.48862 .70743 Mdot
.20914 .57589 Mdot
.41985 .36454 Mdot
.53484 .72521 Mdot
.63307 .30659 Mdot
.50435 .74342 Mdot
.671 .34133 Mdot
.54376 .83869 Mdot
.19315 .40119 Mdot
.45347 .83775 Mdot
.62438 .46882 Mdot
.6226 .59656 Mdot
.24676 .64782 Mdot
.76578 .62588 Mdot
.40401 .59868 Mdot
.37927 .8197 Mdot
.41854 .6365 Mdot
.63379 .47231 Mdot
.58354 .27208 Mdot
.74773 .41535 Mdot
.26692 .41966 Mdot
.35493 .62098 Mdot
.57535 .68582 Mdot
.70802 .80007 Mdot
.27849 .72536 Mdot
.5377 .30506 Mdot
.17266 .47989 Mdot
.43202 .3912 Mdot
.40814 .44827 Mdot
.4777 .39857 Mdot
.15419 .56903 Mdot
.67331 .4379 Mdot
.13381 .48962 Mdot
.15696 .54421 Mdot
.69043 .27012 Mdot
.80127 .73309 Mdot
.50923 .18173 Mdot
.67856 .51486 Mdot
.60572 .75145 Mdot
.51191 .79413 Mdot
.66664 .30324 Mdot
.67776 .254 Mdot
.46766 .30892 Mdot
.22884 .34397 Mdot
.16779 .60521 Mdot
.43834 .70438 Mdot
.22589 .49704 Mdot
.60659 .28557 Mdot
.48313 .50287 Mdot
.70224 .37941 Mdot
.46977 .53785 Mdot
.53019 .51535 Mdot
.42913 .82711 Mdot
.81649 .56092 Mdot
.8494 .42516 Mdot
.37027 .66971 Mdot
.64486 .21674 Mdot
.19808 .50711 Mdot
.4197 .76889 Mdot
.74003 .38534 Mdot
.58326 .31523 Mdot
.52942 .67084 Mdot
.61031 .34544 Mdot
.65228 .61794 Mdot
.43527 .62371 Mdot
.65602 .3253 Mdot
.32321 .38595 Mdot
.39188 .68666 Mdot
.30621 .72128 Mdot
.58231 .42793 Mdot
.62589 .41688 Mdot
.53558 .74902 Mdot
.47438 .70504 Mdot
.18053 .4873 Mdot
.63234 .24778 Mdot
.23199 .31731 Mdot
.6533 .25266 Mdot
.56167 .6802 Mdot
.64271 .51011 Mdot
.60125 .54117 Mdot
.49401 .73063 Mdot
.59524 .675 Mdot
.50473 .23291 Mdot
.16729 .45565 Mdot
.79899 .59351 Mdot
.41075 .67754 Mdot
.68889 .71127 Mdot
.21363 .36182 Mdot
.2616 .66111 Mdot
.57184 .21651 Mdot
.66329 .58634 Mdot
.6407 .82585 Mdot
.3315 .46546 Mdot
.45564 .70867 Mdot
.50606 .356 Mdot
.30156 .6157 Mdot
.49202 .82002 Mdot
.69093 .27836 Mdot
.16802 .44925 Mdot
.59215 .31868 Mdot
.38298 .47236 Mdot
.49774 .43248 Mdot
.26114 .44809 Mdot
.68087 .72208 Mdot
.62555 .57676 Mdot
.47194 .62892 Mdot
.37921 .64698 Mdot
.76519 .60905 Mdot
.27684 .66451 Mdot
.34903 .26972 Mdot
.50852 .65797 Mdot
.34293 .30121 Mdot
.43661 .24545 Mdot
.48328 .4566 Mdot
.18436 .67032 Mdot
.5189 .56439 Mdot
.5393 .18663 Mdot
.19961 .38813 Mdot
.40252 .50555 Mdot
.21741 .56656 Mdot
.54552 .27477 Mdot
.50151 .84175 Mdot
.15483 .50502 Mdot
.2364 .41759 Mdot
.24653 .70872 Mdot
.24294 .27802 Mdot
.56079 .82498 Mdot
.68907 .67512 Mdot
.48282 .33297 Mdot
.12371 .38936 Mdot
.32279 .43782 Mdot
.7145 .71669 Mdot
.77143 .619 Mdot
.29303 .55384 Mdot
.62924 .38555 Mdot
.60753 .7055 Mdot
.41726 .22973 Mdot
.71241 .40222 Mdot
.57424 .68665 Mdot
.35473 .81766 Mdot
.55678 .84224 Mdot
.37083 .8232 Mdot
.22141 .37511 Mdot
.23668 .70082 Mdot
.40498 .79408 Mdot
.77848 .44297 Mdot
.32944 .70573 Mdot
.61054 .64109 Mdot
.43792 .72427 Mdot
.5189 .18491 Mdot
.38198 .49392 Mdot
.46603 .28041 Mdot
.61707 .42249 Mdot
.50781 .83271 Mdot
.19916 .6996 Mdot
.7177 .58276 Mdot
.77342 .51706 Mdot
.51943 .51143 Mdot
.47941 .72851 Mdot
.46589 .63977 Mdot
.30009 .30151 Mdot
.18903 .49486 Mdot
.42022 .8049 Mdot
.4508 .69064 Mdot
.37728 .2766 Mdot
.26327 .39886 Mdot
.62368 .21128 Mdot
.1946 .60471 Mdot
.39976 .77513 Mdot
.66813 .25294 Mdot
.66796 .61639 Mdot
.70773 .30173 Mdot
.3003 .28189 Mdot
.39473 .43956 Mdot
.47547 .6902 Mdot
.3415 .49211 Mdot
.43772 .70941 Mdot
.55344 .43735 Mdot
.34037 .72817 Mdot
.56074 .74097 Mdot
.42927 .70477 Mdot
.25996 .40538 Mdot
.31202 .77985 Mdot
.29061 .24494 Mdot
.64241 .79027 Mdot
.34216 .23079 Mdot
.65373 .62306 Mdot
.62424 .62608 Mdot
.1833 .41731 Mdot
.29557 .77508 Mdot
.15218 .47321 Mdot
.5307 .23474 Mdot
.32071 .57127 Mdot
.45986 .33128 Mdot
.67125 .75639 Mdot
.34479 .25059 Mdot
.17678 .51932 Mdot
.71284 .35084 Mdot
.47995 .41489 Mdot
.59996 .32047 Mdot
.69327 .72613 Mdot
.62846 .75628 Mdot
.74343 .52668 Mdot
.5758 .5369 Mdot
.70617 .50434 Mdot
.68959 .3904 Mdot
.5385 .22819 Mdot
.49503 .73809 Mdot
.32749 .46798 Mdot
.42734 .78651 Mdot
.47368 .61733 Mdot
.52593 .66774 Mdot
.39183 .44947 Mdot
.70556 .38518 Mdot
.71966 .68658 Mdot
.47548 .30831 Mdot
.15375 .60792 Mdot
.53418 .19892 Mdot
.54046 .71846 Mdot
.52627 .73364 Mdot
.32385 .64488 Mdot
.59851 .34478 Mdot
.4644 .40239 Mdot
.19828 .63718 Mdot
.44782 .53965 Mdot
.53488 .74505 Mdot
.7098 .50521 Mdot
.29906 .66156 Mdot
.52959 .58761 Mdot
.53194 .2806 Mdot
.80005 .47048 Mdot
.46813 .45892 Mdot
.6544 .47537 Mdot
.71476 .39332 Mdot
.48375 .14417 Mdot
.2689 .36376 Mdot
.61901 .23231 Mdot
.20248 .63691 Mdot
.48535 .40053 Mdot
.63021 .45357 Mdot
.42228 .71162 Mdot
.26479 .61579 Mdot
.81 .5136 Mdot
.32692 .40653 Mdot
.46219 .64829 Mdot
.33584 .26678 Mdot
.24288 .6983 Mdot
.34002 .77961 Mdot
.80568 .3785 Mdot
.67942 .45491 Mdot
.27478 .64675 Mdot
.28926 .6477 Mdot
.68643 .4467 Mdot
.6593 .36297 Mdot
.56739 .47387 Mdot
.20751 .68054 Mdot
.60038 .3548 Mdot
.30899 .2545 Mdot
.4099 .50452 Mdot
.28886 .53873 Mdot
.31122 .64266 Mdot
.46618 .67754 Mdot
.20587 .63697 Mdot
.72973 .52237 Mdot
.55823 .80564 Mdot
.5893 .53253 Mdot
.77665 .6458 Mdot
.6743 .75556 Mdot
.49799 .48714 Mdot
.73742 .43209 Mdot
.34532 .39103 Mdot
.55236 .62109 Mdot
.40344 .83985 Mdot
.19237 .47385 Mdot
.68399 .33065 Mdot
.48792 .30956 Mdot
.56285 .65644 Mdot
.58728 .67273 Mdot
.64182 .70284 Mdot
.54946 .31921 Mdot
.6133 .80999 Mdot
.37765 .68527 Mdot
.65366 .6106 Mdot
.7174 .49701 Mdot
.54156 .18787 Mdot
.22525 .6339 Mdot
.19861 .49407 Mdot
.53931 .44451 Mdot
.52095 .18767 Mdot
.42739 .45072 Mdot
.30385 .25395 Mdot
.31969 .31159 Mdot
.39067 .7844 Mdot
.60522 .48333 Mdot
.56565 .31527 Mdot
.32178 .63612 Mdot
.60938 .58997 Mdot
.57309 .2683 Mdot
.19084 .58242 Mdot
.86647 .47417 Mdot
.63593 .29928 Mdot
.33594 .80964 Mdot
.49949 .5687 Mdot
.57102 .32366 Mdot
.51492 .82399 Mdot
.87905 .53968 Mdot
.28882 .31506 Mdot
.41712 .82197 Mdot
.46227 .44416 Mdot
.20829 .65129 Mdot
.47238 .33639 Mdot
.57881 .39132 Mdot
.69422 .69749 Mdot
.20163 .67332 Mdot
.22874 .61205 Mdot
.2211 .64556 Mdot
.66332 .69043 Mdot
.23978 .7121 Mdot
.69676 .3493 Mdot
.51946 .15321 Mdot
.37001 .4895 Mdot
.48648 .21746 Mdot
.67885 .6477 Mdot
.52146 .53469 Mdot
.45537 .70133 Mdot
.60719 .18303 Mdot
.77226 .3962 Mdot
.66779 .69547 Mdot
.41196 .74082 Mdot
.54985 .28612 Mdot
.5276 .73169 Mdot
.17171 .53322 Mdot
.50318 .15786 Mdot
.30207 .64323 Mdot
.58169 .23479 Mdot
.2293 .36024 Mdot
.54468 .31777 Mdot
.30941 .3466 Mdot
.20774 .57617 Mdot
.2739 .29734 Mdot
.46014 .63757 Mdot
.54409 .11808 Mdot
.23776 .4851 Mdot
.56582 .4768 Mdot
.47867 .83711 Mdot
.19083 .49078 Mdot
.72399 .35652 Mdot
.74444 .33135 Mdot
.77135 .66347 Mdot
.45942 .746 Mdot
.61111 .60873 Mdot
.24724 .72379 Mdot
.45557 .77328 Mdot
.40159 .82708 Mdot
.19727 .36589 Mdot
.6962 .52283 Mdot
.50037 .61639 Mdot
.29918 .41827 Mdot
.52496 .49267 Mdot
.40031 .73493 Mdot
.42301 .81464 Mdot
.74448 .68735 Mdot
.37664 .53451 Mdot
.34679 .34675 Mdot
.3318 .40521 Mdot
.64105 .55065 Mdot
.50351 .18902 Mdot
.55375 .30381 Mdot
.38574 .67368 Mdot
.25609 .39758 Mdot
.47338 .71836 Mdot
.73687 .49764 Mdot
.62164 .76388 Mdot
.67756 .2868 Mdot
.5092 .41115 Mdot
.31255 .41979 Mdot
.33657 .75293 Mdot
.22305 .45651 Mdot
.5039 .23738 Mdot
.61049 .79692 Mdot
.58409 .30943 Mdot
.36825 .70513 Mdot
.29665 .69462 Mdot
.66427 .2983 Mdot
.43113 .29252 Mdot
.64487 .75356 Mdot
.77743 .64316 Mdot
.3412 .39883 Mdot
.5193 .68002 Mdot
.16747 .61869 Mdot
.46908 .68363 Mdot
.3215 .71363 Mdot
.49196 .51003 Mdot
.78266 .58114 Mdot
.67679 .57215 Mdot
.46664 .78952 Mdot
.44029 .46314 Mdot
.68366 .80954 Mdot
.64798 .37801 Mdot
.41129 .84179 Mdot
.46532 .38217 Mdot
.82529 .44096 Mdot
.24704 .42171 Mdot
.53578 .4589 Mdot
.43592 .48936 Mdot
.52927 .28193 Mdot
.54921 .36761 Mdot
.22378 .36 Mdot
.70313 .29342 Mdot
.30292 .48419 Mdot
.38137 .54037 Mdot
.30662 .26259 Mdot
.31084 .73588 Mdot
.59257 .55888 Mdot
.23069 .46222 Mdot
.49376 .49034 Mdot
.38284 .50132 Mdot
.18554 .41929 Mdot
.36209 .38928 Mdot
.63799 .64056 Mdot
.48168 .73182 Mdot
.44264 .82238 Mdot
.16081 .53659 Mdot
.71922 .32374 Mdot
.65207 .61626 Mdot
.49677 .33723 Mdot
.48221 .80794 Mdot
.27747 .71911 Mdot
.38705 .41349 Mdot
.57233 .36889 Mdot
.48221 .70278 Mdot
.43155 .86893 Mdot
.5514 .84074 Mdot
.62559 .79859 Mdot
.3982 .51281 Mdot
.69589 .45608 Mdot
.82562 .54529 Mdot
.31955 .71116 Mdot
.48002 .23041 Mdot
.21302 .44573 Mdot
.46136 .7098 Mdot
.86554 .5387 Mdot
.76248 .39955 Mdot
.30274 .52928 Mdot
.67858 .57559 Mdot
.7567 .64307 Mdot
.45898 .3378 Mdot
.44739 .7495 Mdot
.4196 .55298 Mdot
.48971 .4057 Mdot
.55086 .28966 Mdot
.55634 .37159 Mdot
.32325 .71541 Mdot
.802 .4968 Mdot
.64274 .57605 Mdot
.28737 .71328 Mdot
.71096 .42794 Mdot
.30714 .63113 Mdot
.32388 .65877 Mdot
.40223 .55228 Mdot
.30621 .43744 Mdot
.53866 .54019 Mdot
.50199 .44038 Mdot
.44719 .44919 Mdot
.69932 .75726 Mdot
.41623 .64228 Mdot
.62535 .40029 Mdot
.75757 .36279 Mdot
.66938 .45992 Mdot
.27847 .76421 Mdot
.30011 .30277 Mdot
.71238 .49626 Mdot
.24737 .45975 Mdot
.37134 .30306 Mdot
.78795 .68991 Mdot
.66413 .73996 Mdot
.48604 .53729 Mdot
.70536 .36152 Mdot
.69776 .41572 Mdot
.26402 .43179 Mdot
.44937 .27811 Mdot
.75193 .51497 Mdot
.53254 .17917 Mdot
.33374 .70155 Mdot
.70425 .42068 Mdot
.2853 .52627 Mdot
.55237 .72082 Mdot
.17348 .64527 Mdot
.29288 .44816 Mdot
.61841 .83046 Mdot
.57705 .54838 Mdot
.52938 .81339 Mdot
.18151 .42564 Mdot
.64239 .31923 Mdot
.38256 .52008 Mdot
.40705 .26683 Mdot
.57437 .55997 Mdot
.6339 .55646 Mdot
.64553 .44452 Mdot
.32286 .68497 Mdot
.39384 .62669 Mdot
.52192 .77094 Mdot
.49611 .40039 Mdot
.66672 .2386 Mdot
.51003 .19421 Mdot
.67284 .38374 Mdot
.44063 .55319 Mdot
.24569 .63532 Mdot
.57363 .43723 Mdot
.4924 .49006 Mdot
.35275 .76971 Mdot
.80928 .52471 Mdot
.70331 .41934 Mdot
.61136 .79939 Mdot
.34342 .68006 Mdot
.14747 .54582 Mdot
.53435 .70483 Mdot
.51744 .48687 Mdot
.57669 .43671 Mdot
.53428 .27508 Mdot
.74501 .50085 Mdot
.19189 .5006 Mdot
.5238 .74613 Mdot
.61386 .36531 Mdot
.42903 .70672 Mdot
.63709 .58595 Mdot
.34196 .34748 Mdot
.4848 .2045 Mdot
.85934 .56069 Mdot
.7 .62088 Mdot
.61981 .31705 Mdot
.71107 .37624 Mdot
.53675 .18621 Mdot
.63321 .38911 Mdot
.26695 .56585 Mdot
.80496 .54071 Mdot
.24148 .42659 Mdot
.15656 .58841 Mdot
.18199 .48507 Mdot
.54972 .49873 Mdot
.36868 .42324 Mdot
.55938 .73479 Mdot
.55735 .72011 Mdot
.4718 .47456 Mdot
.57809 .56181 Mdot
.65661 .59419 Mdot
.70907 .32198 Mdot
.50892 .24864 Mdot
.61481 .70126 Mdot
.19323 .65135 Mdot
.14891 .53482 Mdot
.2755 .74058 Mdot
.39879 .42606 Mdot
.62172 .42321 Mdot
.51474 .84118 Mdot
.75602 .46718 Mdot
.16954 .53066 Mdot
.68118 .65306 Mdot
.46234 .14959 Mdot
.47808 .82094 Mdot
.32866 .3887 Mdot
.68758 .26519 Mdot
.48036 .28495 Mdot
.19002 .42203 Mdot
.51808 .15336 Mdot
.45008 .64912 Mdot
.18733 .40703 Mdot
.70649 .79993 Mdot
.69418 .65443 Mdot
.55866 .3638 Mdot
.66624 .55174 Mdot
.54513 .72502 Mdot
.52953 .17179 Mdot
.61531 .63621 Mdot
.34036 .49745 Mdot
.36478 .54845 Mdot
.47061 .71218 Mdot
.48705 .61732 Mdot
.53997 .17272 Mdot
.39341 .73101 Mdot
.36797 .69789 Mdot
.28033 .6356 Mdot
.44284 .81326 Mdot
.75257 .50439 Mdot
.62947 .66206 Mdot
.63713 .478 Mdot
.37962 .59697 Mdot
.42603 .66315 Mdot
.57232 .66383 Mdot
.38575 .50808 Mdot
.57793 .47357 Mdot
.35352 .81936 Mdot
.26789 .59275 Mdot
.23012 .55648 Mdot
.71363 .39534 Mdot
.54699 .3067 Mdot
.25841 .6691 Mdot
.58699 .278 Mdot
.56614 .1758 Mdot
.81318 .56845 Mdot
.24991 .70489 Mdot
.58438 .32532 Mdot
.43111 .68223 Mdot
.74038 .72577 Mdot
.49201 .35195 Mdot
.72107 .67604 Mdot
.40604 .79917 Mdot
.57683 .28708 Mdot
.64753 .4717 Mdot
.29956 .38196 Mdot
.35839 .36038 Mdot
.56654 .28722 Mdot
.20186 .38438 Mdot
.28327 .65983 Mdot
.68416 .55234 Mdot
.32441 .76421 Mdot
.36542 .45927 Mdot
.44972 .6923 Mdot
.28411 .36983 Mdot
.51582 .16477 Mdot
.58031 .42053 Mdot
.17447 .63046 Mdot
.46153 .47561 Mdot
.46498 .77846 Mdot
.56104 .64072 Mdot
.78264 .49214 Mdot
.51711 .2591 Mdot
.26956 .39025 Mdot
.61972 .23835 Mdot
.63599 .40187 Mdot
.51693 .21163 Mdot
.44466 .29732 Mdot
.46083 .75876 Mdot
.46689 .60971 Mdot
.62556 .48728 Mdot
.3705 .65484 Mdot
.43066 .21899 Mdot
.60629 .56423 Mdot
.49873 .78454 Mdot
.2625 .41848 Mdot
.7073 .68321 Mdot
.69271 .67096 Mdot
.33746 .75526 Mdot
.21015 .49839 Mdot
.49697 .23639 Mdot
.67937 .67947 Mdot
.5257 .32537 Mdot
.76321 .41473 Mdot
.59569 .26185 Mdot
.61849 .65482 Mdot
.26808 .56307 Mdot
.63531 .45363 Mdot
.31653 .74385 Mdot
.67117 .48838 Mdot
.43553 .77994 Mdot
.51086 .45388 Mdot
.23895 .64213 Mdot
.46895 .51284 Mdot
.18343 .42649 Mdot
.47848 .28346 Mdot
.49718 .73953 Mdot
.45366 .40659 Mdot
.46172 .44271 Mdot
.64195 .29537 Mdot
.17736 .59562 Mdot
.6871 .28507 Mdot
.61449 .74263 Mdot
.6088 .31721 Mdot
.78239 .62372 Mdot
.18925 .38258 Mdot
.48689 .74717 Mdot
.47398 .47393 Mdot
.49311 .67777 Mdot
.49823 .30678 Mdot
.45479 .25805 Mdot
.2848 .56754 Mdot
.75642 .48717 Mdot
.23714 .5374 Mdot
.33525 .52541 Mdot
.61631 .57797 Mdot
.82838 .5249 Mdot
.30648 .74558 Mdot
.7293 .36419 Mdot
.52294 .46822 Mdot
.32727 .61095 Mdot
.46844 .76367 Mdot
.71939 .21383 Mdot
.39775 .83972 Mdot
.56211 .64194 Mdot
.41381 .50772 Mdot
.51202 .76813 Mdot
.35678 .4678 Mdot
.75439 .52453 Mdot
.33292 .75301 Mdot
.48576 .35785 Mdot
.31552 .58201 Mdot
.46818 .25881 Mdot
.52213 .27519 Mdot
.45806 .79121 Mdot
.4355 .34378 Mdot
.30256 .78719 Mdot
.21906 .43518 Mdot
.52311 .2556 Mdot
.61859 .14037 Mdot
.51919 .23089 Mdot
.71043 .44185 Mdot
.21997 .60362 Mdot
.30622 .77517 Mdot
.40067 .50986 Mdot
.30137 .60976 Mdot
.69483 .67255 Mdot
.5074 .74319 Mdot
.39123 .69465 Mdot
.57933 .23403 Mdot
.53175 .21468 Mdot
.5293 .15366 Mdot
.37246 .3012 Mdot
.71021 .75547 Mdot
.72183 .5157 Mdot
.3437 .78656 Mdot
.29177 .31031 Mdot
.8662 .52495 Mdot
.15471 .57011 Mdot
.42918 .7277 Mdot
.56202 .18095 Mdot
.21808 .58746 Mdot
.54929 .77484 Mdot
.81585 .48239 Mdot
.27054 .32789 Mdot
.81247 .54548 Mdot
.36056 .29675 Mdot
.61204 .25468 Mdot
.4341 .70767 Mdot
.76689 .63755 Mdot
.45587 .47462 Mdot
.39354 .80381 Mdot
.64153 .20695 Mdot
.51459 .72792 Mdot
.32583 .58283 Mdot
.5579 .78426 Mdot
.28278 .71556 Mdot
.19942 .57481 Mdot
.46236 .48743 Mdot
.71432 .78877 Mdot
.42728 .82571 Mdot
.59936 .27544 Mdot
.60463 .66535 Mdot
.14683 .57667 Mdot
.43109 .51745 Mdot
.67963 .68618 Mdot
.20097 .42744 Mdot
.3724 .68049 Mdot
.58829 .46795 Mdot
.63079 .62092 Mdot
.65693 .74891 Mdot
.72666 .44672 Mdot
.75582 .64767 Mdot
.34029 .59436 Mdot
.52669 .7357 Mdot
.64941 .21438 Mdot
.51631 .79996 Mdot
.56621 .71924 Mdot
.64614 .45695 Mdot
.32766 .79792 Mdot
.63183 .74505 Mdot
.56066 .52717 Mdot
.66659 .52674 Mdot
.69354 .28857 Mdot
.41347 .23301 Mdot
.65137 .63019 Mdot
.59606 .34769 Mdot
.45812 .70178 Mdot
.31234 .70086 Mdot
.68307 .70324 Mdot
.81563 .7204 Mdot
.17678 .43159 Mdot
.66087 .37227 Mdot
.72152 .66171 Mdot
.38215 .54827 Mdot
.28131 .7428 Mdot
.37432 .27341 Mdot
.32361 .64999 Mdot
.746 .31033 Mdot
.54573 .75924 Mdot
.51999 .62189 Mdot
.21711 .37911 Mdot
.16319 .57999 Mdot
.66777 .22038 Mdot
.16759 .61732 Mdot
.50314 .62321 Mdot
.53229 .56821 Mdot
.87094 .41841 Mdot
.22385 .67539 Mdot
.50027 .60239 Mdot
.7199 .30451 Mdot
.62455 .38799 Mdot
.61226 .63106 Mdot
.4665 .26064 Mdot
.47793 .6838 Mdot
.38473 .69754 Mdot
.20484 .67637 Mdot
.70887 .42855 Mdot
.38296 .51446 Mdot
.49842 .347 Mdot
.43874 .48339 Mdot
.64363 .62766 Mdot
.44277 .38013 Mdot
.38388 .70524 Mdot
.41962 .52307 Mdot
.52097 .33415 Mdot
.45729 .63606 Mdot
.29625 .24721 Mdot
.54724 .52322 Mdot
.54086 .50106 Mdot
.66811 .66111 Mdot
.77273 .39433 Mdot
.39668 .73231 Mdot
.36968 .72332 Mdot
.19095 .40098 Mdot
.29028 .2228 Mdot
.26546 .47409 Mdot
.58429 .71199 Mdot
.59641 .43058 Mdot
.74811 .48922 Mdot
.67456 .54261 Mdot
.50125 .42113 Mdot
.44475 .25685 Mdot
.51474 .65228 Mdot
.53801 .7167 Mdot
.49973 .39246 Mdot
.3961 .85091 Mdot
.6147 .64511 Mdot
.7117 .54292 Mdot
.17896 .56266 Mdot
.30983 .6313 Mdot
.60021 .50643 Mdot
.56871 .56078 Mdot
.70163 .35032 Mdot
.42225 .52546 Mdot
.58924 .73682 Mdot
.31397 .64917 Mdot
.29122 .74507 Mdot
.58221 .50866 Mdot
.70008 .53596 Mdot
.57331 .61491 Mdot
.35716 .62547 Mdot
.56335 .38647 Mdot
.64531 .77387 Mdot
.46005 .613 Mdot
.16426 .52615 Mdot
.34893 .67569 Mdot
.37745 .68468 Mdot
.67734 .50485 Mdot
.39829 .82795 Mdot
.62889 .29799 Mdot
.69413 .51831 Mdot
.70331 .32896 Mdot
.31219 .35822 Mdot
.41239 .73928 Mdot
.29689 .41516 Mdot
.61524 .7003 Mdot
.61635 .39786 Mdot
.21257 .69938 Mdot
.66895 .738 Mdot
.45348 .4264 Mdot
.33083 .39824 Mdot
.75989 .42591 Mdot
.44212 .48645 Mdot
.57653 .1269 Mdot
.38636 .25867 Mdot
.30817 .79131 Mdot
.30028 .67503 Mdot
.59535 .42979 Mdot
.55103 .28319 Mdot
.52034 .55227 Mdot
.34152 .4744 Mdot
.28575 .74439 Mdot
.50294 .68149 Mdot
.59305 .25309 Mdot
.60181 .65185 Mdot
.66007 .33647 Mdot
.5509 .72352 Mdot
.37461 .4213 Mdot
.32346 .49584 Mdot
.71194 .31312 Mdot
.19749 .59223 Mdot
.42371 .52622 Mdot
.45089 .16444 Mdot
.42497 .81676 Mdot
.19667 .63499 Mdot
.33369 .40627 Mdot
.82652 .43141 Mdot
.71584 .37926 Mdot
.5617 .72297 Mdot
.44809 .40965 Mdot
.61133 .75302 Mdot
.57041 .28462 Mdot
.31314 .69476 Mdot
.52811 .32387 Mdot
.56373 .45683 Mdot
.47655 .10287 Mdot
.42502 .7204 Mdot
.72823 .3783 Mdot
.56259 .26117 Mdot
.18502 .6313 Mdot
.40242 .57647 Mdot
.24758 .29678 Mdot
.27335 .34301 Mdot
.64441 .61803 Mdot
.79966 .48058 Mdot
.55924 .80078 Mdot
.38628 .37976 Mdot
.74754 .73066 Mdot
.22207 .45999 Mdot
.42637 .67157 Mdot
.27155 .38608 Mdot
.67376 .45773 Mdot
.62415 .39179 Mdot
.30657 .2848 Mdot
.36525 .19894 Mdot
.61851 .71408 Mdot
.26441 .71015 Mdot
.81427 .63723 Mdot
.32661 .6804 Mdot
.24989 .71725 Mdot
.41614 .38484 Mdot
.67961 .36137 Mdot
.38671 .72552 Mdot
.33881 .61435 Mdot
.36016 .46138 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0X?ooool2o`00
0:Oooooo000Looooo`;o0000XOooool2o`000:Oooooo000Looooo`03o`000?oooooooooo09Oooooo
0_l0002`ooooo`007?ooool00ol0003oooooooooo`2Gooooo`;o0000/?ooool001cooooo00?o0000
ooooooooool0W_ooool2o`000:Wooooo000Looooo`03o`000?oooooooooo08Kooooo0_l0000Foooo
o`;o00000_ooool2o`000:Gooooo000Looooo`03o`000?oooooooooo08Kooooo0_l0000Jooooo`;o
0000YOooool001cooooo00?o0000ooooooooool0[Oooool2o`0009[ooooo000Looooo`03o`000?oo
oooooooo0:gooooo0_l00003ooooo`;o0000UOooool001cooooo00?o0000ooooooooool0/_ooool2
o`0009Gooooo000Looooo`03o`000?oooooooooo0;Oooooo0_l0002@ooooo`007?ooool00ol0003o
ooooooooo`2gooooo`;o0000T?ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo07Oooooo0_l0001<
ooooo`;o0000P_ooool001cooooo00?o0000ooooooooool0Moooool2o`00023ooooo0_l0000Zoooo
o`;o0000P_ooool001cooooo00?o0000ooooooooool0VOooool2o`000:kooooo000Looooo`03o`00
0?oooooooooo09;ooooo0_l0002eooooo`007?ooool2o`0006kooooo0_l0000Sooooo`;o00004Ooo
ool2o`000003ooooool0003o000009oooooo000Looooo`03o`000?oooooooooo06gooooo0_l0000f
ooooo`;o000000?oooooo`000?l00000Woooool001cooooo00?o0000ooooooooool0X?ooool2o`00
0:Oooooo000Looooo`03o`000?oooooooooo09kooooo1?l0000/ooooo`?o0000N?ooool001cooooo
00?o0000ooooooooool0IOooool2o`0002Sooooo0_l0000=ooooo`;o00001?ooool2o`0002Sooooo
0ol0001hooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o0000:?ooool2o`0001?ooooo0_l0
002Sooooo`007?ooool00ol0003oooooooooo`2Xooooo`;o00002Oooool2o`0009Cooooo000Loooo
o`03o`000?oooooooooo0:Oooooo0ol00002ooooo`;o000000?oooooo`000?l000000_ooool2o`00
09Cooooo000Looooo`03o`000?oooooooooo0:Oooooo0_l00003ooooo`;o000000?oooooo`000?l0
00000oooool2o`0009?ooooo000Looooo`03o`000?oooooooooo05cooooo0_l0001;ooooo`;o0000
2?ooool3o`000003ooooool0003o000000Gooooo0_l00029ooooo`007?ooool00ol0003ooooooooo
o`1Looooo`;o0000A?ooool2o`0000Gooooo1?l00006ooooo`;o00000_ooool2o`0000Gooooo0_l0
00000ooooooo0000o`000026ooooo`007?ooool00ol0003oooooooooo`1looooo`?o00008oooool2
o`000003ooooool0003o000000Cooooo0_l0000Dooooo`;o0000Q_ooool001cooooo00?o0000oooo
ooooool0O?ooool3o`000003ooooool0003o000001kooooo0_l00003ooooo`;o00001?ooool3o`00
013ooooo0_l00029ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5
o`0000Kooooo00?o0000ooooooooool0OOooool2o`000003ooooool0003o000001Oooooo1?l00003
ooooo`;o00001?ooool2o`0000Cooooo0_l0000@ooooo`;o0000ROooool00006oooooomgMgOoV9RH
oooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`00
0?oooooooooo07Cooooo0_l00007ooooo`;o00001Oooool2o`0001?ooooo1?l00005ooooo`;o0000
0_ooool2o`0001kooooo0_l0000<ooooo`;o0000Loooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo07?ooooo0ol0
000>ooooo`;o00007?ooool2o`0000Kooooo0_l0000Jooooo`;o00003?ooool2o`0007?ooooo0000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3
o`0005?ooooo0_l0000Nooooo`Co00005Oooool2o`0001cooooo0_l0000[ooooo`;o0000L?ooool0
0003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`05oooo
o`03o`000?oooooooooo05?ooooo0_l0000Pooooo`;o00000oooool2o`0000_ooooo0_l00003oooo
o`;o00003?ooool2o`0001?ooooo0_l0000Gooooo`;o00003Oooool2o`00073ooooo00000ooooooo
410@ooooo`02ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`1_ooooo`;o00002Oooool2o`0000_ooooo0_l00007ooooo`;o00002?ooool2o`0001?o
oooo0_l0000Gooooo`?o00000_ooool2o`0007[ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMg
M`_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo06gooooo1?l00007
ooooo`;o00001Oooool6o`0000;ooooo0_l00007ooooo`;o00004_ooool2o`00017ooooo0_l0000>
ooooo`Co00000_ooool2o`0007[ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo06[ooooo0_l000000ooooooo0000
o`000006ooooo`;o000000?oooooo`000?l000001Oooool6o`0000Gooooo0_l00002ooooo`;o0000
5?ooool2o`0000?ooooo0_l0000<ooooo`;o00002oooool2o`000003ooooool0003o000000Kooooo
0_l0000Eooooo`;o0000HOooool001cooooo00?o0000ooooooooool0J_ooool2o`0000Kooooo1Ol0
000Cooooo`Ko00002_ooool2o`0000gooooo0_l0000;ooooo`;o000000?oooooo`000?l000002Ooo
ool2o`0000Sooooo0ol0000Eooooo`;o0000HOooool001cooooo00?o0000ooooooooool0J_ooool2
o`0000Kooooo0ol0000Booooo`Oo00001oooool2o`0000?ooooo0_l00006ooooo`;o00004_ooool6
o`0001;ooooo0_l00005ooooo`;o00002?ooool2o`0006Sooooo000Looooo`03o`000?oooooooooo
05_ooooo0_l0000:ooooo`;o00007_ooool8o`0000Kooooo0_l0000;ooooo`?o00001Oooool3o`00
00[ooooo0_l000000ooooooo0000o`000008ooooo`;o00002?ooool4o`0000?ooooo0_l00008oooo
o`;o0000J?ooool001cooooo00?o0000ooooooooool0Foooool2o`0000[ooooo0_l0000?ooooo`;o
00003_ooool9o`0001;ooooo0_l00004ooooo`Co00005oooool2o`0000[ooooo0_l00003ooooo`;o
0000L_ooool001cooooo00?o0000ooooooooool0Joooool2o`0000_ooooo0_l0000:ooooo`;o0000
0_ooool;o`0000Gooooo0ol00008ooooo`;o00001?ooool4o`0000cooooo0_l00004ooooo`;o0000
5?ooool2o`0000cooooo0_l0001Tooooo`007?ooool00ol0003oooooooooo`1[ooooo`Co00005?oo
ool3o`000003ooooool0003o000000Co000000?oooooo`000?l000001_l00002ooooo`?o00001Ooo
ool2o`000003ooooool0003o000000;o00000_ooool4o`0000cooooo0_l000001?oooooo0000o`00
0?ooool2o`0000;ooooo1?l00002ooooo`;o00003?ooool2o`0000[ooooo0_l0001Tooooo`007?oo
ool00ol0003oooooooooo`1Rooooo`;o00002Oooool2o`0000?ooooo0_l0000?ooooo`;o00000_oo
ool6o`000003ooooool0003o000000Ko00002?ooool4o`0000?ooooo0_l00002ooooo`?o00003?oo
ool3o`000003ooooool0003o000000Gooooo1?l000001?oooooo0000o`000?l0000<ooooo`;o0000
L?ooool001cooooo00?o0000ooooooooool0H_ooool2o`0000kooooo0_l0000Booooo`ko000000?o
ooooo`000?l000001oooool4o`0000Oooooo0ol0000<ooooo`?o00002Oooool6o`0000_ooooo0_l0
0003ooooo`;o0000KOooool001cooooo00?o0000ooooooooool0Q_ooool<o`0000?ooooo0_l00009
ooooo`;o00001oooool2o`0001_ooooo0_l00004ooooo`;o00001oooool2o`0000?ooooo0_l0001]
ooooo`007?ooool00ol0003oooooooooo`1Kooooo`Co0000:?ooool<o`0000gooooo0_l0000Doooo
o`;o00002Oooool2o`0000Wooooo0_l0000?ooooo`;o0000J_ooool001cooooo00?o0000oooooooo
ool0Foooool4o`0002Wooooo2ol0000?ooooo`;o00001oooool2o`0000Wooooo0_l00004ooooo`;o
00000oooool2o`0000Oooooo0_l0000Aooooo`;o00004Oooool2o`0005Oooooo000Looooo`;o0000
A?ooool2o`0001Oooooo0ol0000=ooooo`;o00006_ooool;o`0000kooooo0ol00007ooooo`;o0000
2_ooool2o`0000?ooooo0_l0000<ooooo`;o00009?ooool2o`0005Oooooo000Looooo`03o`000?oo
oooooooo04?ooooo0_l0000Gooooo`;o000000?oooooo`000?l000000_l00008ooooo`?o00006_oo
ool<o`0000gooooo0ol0000?ooooo`;o00000_ooool2o`0000?ooooo0ol00004ooooo`;o00002ooo
ool2o`0000?ooooo1Ol0001_ooooo`007?ooool00ol0003oooooooooo`1Oooooo`Co00002?ooool2
o`0000Oooooo0_l00006ooooo`?o00002_ooool;o`0000[ooooo0_l00006ooooo`;o00002oooool2
o`0000Oooooo1?l00003ooooo`;o00002?ooool2o`000003ooooool0003o000000?ooooo1Ol00000
0ooooooo0000o`00001/ooooo`007?ooool00ol0003oooooooooo`1dooooo`;o00001?ooool5o`00
00Wooooo2ol000000ooooooo0000o`000008ooooo`?o00000oooool4o`0000_ooooo0_l00006oooo
o`;o000000Coooooo`000?l0003ooooo0ol00009ooooo`;o00003?ooool2o`0006cooooo000Loooo
o`03o`000?oooooooooo063ooooo0_l0000Hooooo`?o00002oooool>o`0000Wooooo0_l00003oooo
o`;o00003Oooool4o`0000Cooooo2Ol0000;ooooo`;o00002_ooool2o`0000Gooooo0_l0000:oooo
o`;o0000FOooool001cooooo00?o0000ooooooooool0H?ooool2o`0000Oooooo0_l0000@ooooo`;o
00000oooool2o`0000Oooooo3Ol0000:ooooo`;o00004oooool2o`0000Kooooo1Ol0000=ooooo`;o
00002_ooool3o`0000Cooooo0_l0000:ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0
JOooool2o`0000?ooooo0_l0000@ooooo`;o00002?ooool4o`0000Kooooo0_l00008ooooo`Co0000
0oooool2o`0000Kooooo0_l00006ooooo`?o00002_ooool2o`0001Sooooo0_l0000Booooo`;o0000
00?oooooo`000?l00000E?ooool001cooooo00?o0000ooooooooool0K_ooool2o`0000Kooooo0_l0
0009ooooo`;o00006oooool2o`0000Gooooo0_l00006ooooo`;o00001oooool2o`0000;ooooo0_l0
0006ooooo`;o00005oooool5o`00013ooooo0_l000000ooooooo0000o`00001Dooooo`007?ooool0
0ol0003oooooooooo`1eooooo`Co00002?ooool2o`0000oooooo0_l0000=ooooo`;o00000oooool2
o`0000;ooooo0_l000000ooooooo0000o`00000;ooooo`;o00000oooool5o`0000Cooooo0_l0000A
ooooo`;o000000?oooooo`000?l00000JOooool001cooooo00?o0000ooooooooool0Boooool2o`00
02Sooooo1?l0000Eooooo`;o00000_ooool2o`0000gooooo0_l00003ooooo`;o00000_ooool2o`00
0003ooooool0003o000000[ooooo1?l00002ooooo`Co00001Oooool2o`0000;ooooo0_l0000?oooo
o`;o00001_ooool3o`0000kooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`0iooooo`;o
00004?ooool2o`0000[ooooo0_l00005ooooo`;o0000;_ooool2o`0000Cooooo0_l0000Booooo`?o
00001?ooool2o`0000Oooooo1_l0000>ooooo`;o00003oooool2o`0000Kooooo0ol0000>ooooo`Co
0000Coooool001cooooo00?o0000ooooooooool0>Oooool2o`0001cooooo0_l00005ooooo`Co0000
<_ooool2o`0000;ooooo0_l0000>ooooo`?o00001?ooool2o`0000Gooooo1?l00002ooooo`;o0000
0oooool2o`0001Oooooo0ol0000Kooooo`;o0000Coooool001cooooo00?o0000ooooooooool0DOoo
ool2o`0000gooooo0_l00006ooooo`;o00007?ooool2o`0000cooooo0_l00002ooooo`;o00005Ooo
ool2o`0000?ooooo1_l00007ooooo`;o00001Oooool2o`0000kooooo1ol0001Zooooo`007?ooool0
0ol0003oooooooooo`1Aooooo`;o00005?ooool3o`0001[ooooo1?l0000<ooooo`;o00006Oooool2
o`0000?ooooo0_l00002ooooo`;o00003_ooool2o`0000kooooo0_l00003ooooo`;o00002oooool2
o`0000_ooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`1Wooooo`;o00006oooool2o`00
00;ooooo1?l00007ooooo`;o00004?ooool2o`0000;ooooo0_l00004ooooo`;o00000oooool2o`00
00_ooooo0_l00006ooooo`;o00000_ooool2o`0001;ooooo0_l00007ooooo`?o00002_ooool2o`00
053ooooo000Looooo`03o`000?oooooooooo04gooooo0_l000000ooooooo0000o`000003ooooo`;o
00006_ooool2o`0001Gooooo1?l000000ooooooo0000o`000004ooooo`;o00001oooool2o`0000;o
oooo0_l00003ooooo`;o00000_ooool2o`0000Gooooo0_l0000?ooooo`;o00000oooool5o`0000;o
oooo0_l00005ooooo`;o000000?oooooo`000?l000001Oooool2o`000003ooooool0003o000000So
oooo0_l0001Looooo`007?ooool2o`0004gooooo0ol000000ooooooo0000o`000003ooooo`;o0000
1oooool2o`0000cooooo0_l00003ooooo`;o00000_ooool2o`0000oooooo0_l00005ooooo`;o0000
2oooool4o`0000;ooooo0_l0000<ooooo`Co00002_ooool3o`0000Oooooo1ol00007ooooo`;o0000
00?oooooo`000?l000001Oooool2o`0001Kooooo0_l0001Aooooo`007?ooool00ol0003ooooooooo
o`1;ooooo`?o00004?ooool2o`0000Kooooo0_l00004ooooo`;o00001oooool2o`0000kooooo0ol0
000Booooo`;o00003_ooool2o`0000;ooooo1?l00008ooooo`Go00002_ooool6o`0000;ooooo0_l0
0002ooooo`;o00002?ooool2o`000003ooooool0003o000000;ooooo0_l0000>ooooo`;o0000DOoo
ool001cooooo00?o0000ooooooooool0Boooool2o`00017ooooo0_l00006ooooo`;o00003Oooool2
o`0000kooooo0_l0000Gooooo`Co00002?ooool3o`000003ooooool0003o000000;o00002?ooool4
o`0000cooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool2o`0000Cooooo0_l00002
ooooo`;o000000?oooooo`000?l000000_ooool2o`00067ooooo000Looooo`03o`000?oooooooooo
05_ooooo0_l0000Jooooo`;o00006oooool2o`000003ooooool0003o000000;ooooo0_l000000ooo
oooo0000o`000002o`0000Sooooo0ol000000ooooooo0000o`00000:ooooo`Co00003?ooool2o`00
00[ooooo0ol00002ooooo`?o00001_ooool2o`0000Sooooo0ol0001Hooooo`007?ooool00ol0003o
ooooooooo`1:ooooo`;o00003oooool2o`0000Oooooo1?l0000?ooooo`;o00006oooool2o`000003
ooooool0003o000000;ooooo1?l0000Booooo`;o00001oooool4o`0000oooooo0_l00004ooooo`;o
000000Coooooo`000?l0003o00000oooool3o`0000Cooooo0ol00008ooooo`?o0000F?ooool001co
oooo00?o0000ooooooooool0B_ooool2o`0000_ooooo0_l000000ooooooo0000o`000008ooooo`Co
0000;?ooool2o`0000Oooooo0_l00005ooooo`;o00002oooool2o`000003ooooool0003o000000Co
oooo0ol00009ooooo`;o00001Oooool2o`0000Cooooo0_l00008ooooo`?o00000oooool2o`0006Co
oooo000Looooo`03o`000?oooooooooo04Sooooo0_l0000=ooooo`Go0000Aoooool3o`0000Oooooo
1?l00003ooooo`;o00001?ooool2o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o0000
1Oooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`0000Gooooo0_l0000=ooooo`;o0000
F_ooool001cooooo00?o0000ooooooooool0<Oooool2o`0001Gooooo0_l0000:ooooo`;o00000ooo
ool2o`0000_ooooo0_l0000kooooo`Co00001_ooool4o`0000cooooo1?l000000ooooooo0000o`00
0002ooooo`;o00000oooool5o`0000;ooooo0_l000000ooooooo0000o`000002o`0000[ooooo0_l0
0008ooooo`;o00001oooool2o`00057ooooo000Looooo`03o`000?oooooooooo037ooooo0_l0000Q
ooooo`Ko00003?ooool2o`0001oooooo0ol0000<ooooo`?o00001oooool2o`0000?ooooo1Ol00007
ooooo`;o00000oooool2o`000004ooooool0003o0000o`0000?ooooo0_l00005ooooo`;o000000?o
ooooo`000?l000001Ol000000ooooooo0000o`000002ooooo`Co00002_ooool2o`000003ooooool0
003o000000_ooooo0_l000000ooooooo0000o`00001Aooooo`007?ooool00ol0003oooooooooo`1D
ooooo`Ko0000;Oooool3o`0000Sooooo0_l00002ooooo`?o00001oooool2o`0000Gooooo0ol00007
ooooo`Co000000Coooooo`000?l0003ooooo0ol0000:ooooo`Go000000?oooooo`000?l000000ooo
ool2o`000003ooooool0003o000000;o00001Oooool2o`0000;ooooo0_l00003ooooo`;o00002ooo
ool2o`0000Gooooo0_l000000ooooooo0000o`00001:ooooo`007?ooool00ol0003oooooooooo`1D
ooooo`;o00000_ooool2o`0001[ooooo0_l0000Eooooo`;o00000_ooool2o`000003ooooool0003o
000001;ooooo0_l0000;ooooo`;o00003_ooool6o`0000;ooooo0_l00007ooooo`;o00001?ooool2
o`000003ooooool0003o000000;ooooo0_l0000;ooooo`;o00002_ooool2o`000003ooooool0003o
000004[ooooo000Looooo`03o`000?oooooooooo02oooooo0_l0000Sooooo`;o00007_ooool2o`00
017ooooo0_l00002ooooo`;o000000?oooooo`000?l000001?l000000ooooooo0000o`000002oooo
o`;o00000oooool2o`0000?ooooo1Ol000000ooooooo0000o`000004ooooo`;o00002Oooool2o`00
00Gooooo2?l000001?oooooo0000o`000?l0000=ooooo`;o00004_ooool2o`0000[ooooo0_l0001=
ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00005_ooool2o`000003ooooool0003o0000
00Sooooo0_l0000aooooo`;o00000_ooool2o`000003ooooool0003o000000Co000000Goooooo`00
0?l0003o0000ooooo`02o`0000;ooooo0ol00003ooooo`Co00000_ooool2o`0000Cooooo0_l00009
ooooo`;o00001Oooool8o`000004ooooool0003o0000ooooo`;o00001?ooool2o`0002Gooooo0_l0
001=ooooo`007?ooool00ol0003oooooooooo`17ooooo`Go00001_ooool2o`0000cooooo0_l0000D
ooooo`;o00004_ooool3o`0000;ooooo4Ol0000Aooooo`;o00004?ooool5o`0000Gooooo0_l00004
ooooo`;o000000?oooooo`000?l000000_ooool5o`0001Gooooo0_l00005ooooo`;o0000C?ooool0
01cooooo00?o0000ooooooooool0Aoooool6o`0000Gooooo0_l000000ooooooo0000o`000009oooo
o`;o00004Oooool2o`000003ooooool0003o000001;ooooo0_l000000ooooooo0000o`00000@o`00
0003ooooool0003o000000oooooo0_l0000<ooooo`;o00000_ooool5o`0000Gooooo0ol00006oooo
o`;o00000_ooool6o`00013ooooo0_l00002ooooo`Co00000oooool2o`0004cooooo000Looooo`03
o`000?oooooooooo04Oooooo0_l00002ooooo`;o000000?oooooo`000?l000001Oooool2o`0000[o
oooo0_l00008ooooo`Co00001?ooool2o`00013ooooo0_l00003oooooaSo00001_ooool2o`0000Ko
oooo0_l00008ooooo`;o00000_ooool3o`000004ooooool0003o0000o`0000Sooooo0ol0000:oooo
o`;o00000_ooool4o`0000kooooo0_l00004ooooo`;o0000DOooool001cooooo0_l0000]ooooo`;o
00008?ooool2o`00017ooooo0_l00008ooooo`Co00005_ooool2o`0000Gooooo5Ol00007ooooo`;o
00001_ooool2o`0000?ooooo0_l00002ooooo`?o00000_ooool2o`0000;ooooo0_l0000=ooooo`;o
00003?ooool4o`000003ooooool0003o000000Wooooo0_l0000<ooooo`;o0000B_ooool001cooooo
00?o0000ooooooooool0;?ooool2o`0001cooooo0_l0000Hooooo`;o00001?ooool2o`00023ooooo
5Ol0000Dooooo`;o00000_ooool2o`0000Oooooo1_l00009ooooo`;o00003?ooool4o`000003oooo
ool0003o000000Sooooo0ol00003ooooo`;o00001oooool2o`0000Cooooo0_l00014ooooo`007?oo
ool00ol0003oooooooooo`13ooooo`;o00001Oooool2o`0001Sooooo0_l00004ooooo`;o000000?o
ooooo`000?l000007ooooolEo`0001cooooo0_l00003ooooo`Co00004_ooool2o`0000Cooooo0_l0
0005ooooo`;o00001Oooool2o`000003ooooool0003o000000?o00003Oooool2o`0004Cooooo000L
ooooo`03o`000?oooooooooo04?ooooo1?l00002ooooo`;o00001Oooool2o`00013ooooo0_l00009
ooooo`;o00007Oooool5o`000003ooooool0003o000000oo00000_ooool2o`0000;ooooo0_l00003
ooooo`;o00002oooool2o`0000;ooooo0_l00003ooooo`Co00004_ooool2o`0000Cooooo0_l00005
ooooo`;o00001Oooool2o`000004ooooool0003o0000o`0000_ooooo0_l00018ooooo`007?ooool0
0ol0003oooooooooo`0nooooo`;o00000_ooool2o`000003ooooool0003o000000Ko00000oooool2
o`00013ooooo0_l0000=ooooo`;o00005ooooolHo`0000?ooooo0ol000000ooooooo0000o`000003
ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00000_ooool2o`0000Oooooo0_l00008
ooooo`;o00000_ooool2o`0000Gooooo1?l00004ooooo`;o00001Oooool2o`0000Cooooo0_l00000
1?oooooo0000o`000?l0000;ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0??ooool4
o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00006oooool2
o`0001;ooooo7_l00003ooooo`;o00002Oooool4o`0000;ooooo1?l00009ooooo`Co00001_ooool2
o`0000;ooooo0ol00004ooooo`Co00001?ooool2o`0000?ooooo1Ol00003ooooo`;o000000Cooooo
o`000?l0003o0000EOooool001cooooo00?o0000ooooooooool0:Oooool2o`00017ooooo0_l00006
ooooo`;o000000?oooooo`000?l000002oooool2o`0002gooooo8?l00006ooooo`;o00001?ooool2
o`000003ooooool0003o000000;ooooo1Ol00006ooooo`So000000?oooooo`000?l000000_ooool2
o`0000?ooooo0_l00003ooooo`;o00002Oooool2o`000003ooooool0003o000000?o00000oooool2
o`0005Wooooo000Looooo`03o`000?oooooooooo02Wooooo0_l0000Fooooo`;o000000?oooooo`00
0?l000000ol0000=ooooo`;o000000?oooooo`000?l00000:?ooool2o`0000Cooooo5_l000001?oo
oooo0000o`000?l00006ooooo`;o00001?ooool4o`0000?ooooo0ol00008ooooo`?o000000?ooooo
o`000?l000001Ol00007ooooo`Co000000?oooooo`000?l000000oooool2o`0000Cooooo0_l00002
ooooo`Co00002?ooool2o`0005Cooooo000Looooo`03o`000?oooooooooo047ooooo0_l000001?oo
oooo0000o`000?l0000=ooooo`Co000000?oooooo`000?l000004oooool4o`0000?ooooo0_l0000>
ooooo`;o00000_ooool<o`000003ooooool0003o000000Oo000000?oooooo`000?l000002_ooool2
o`0000?ooooo0_l00004ooooo`;o00003?ooool2o`000003ooooool0003o000000Sooooo2?l00003
ooooo`;o00005?ooool2o`0000?ooooo0_l00006ooooo`;o00001_ooool2o`0003oooooo000Loooo
o`03o`000?oooooooooo04Cooooo0_l00007ooooo`;o00001Oooool2o`00013ooooo0_l00006oooo
o`Co00000oooool2o`0000kooooo0_l00003ooooo`Ko00000_ooool3o`000003ooooool0003o0000
00ko00001_ooool2o`0001Sooooo0_l00007ooooo`;o000000?oooooo`000?l000000_l000000ooo
oooo0000o`000003o`0000Gooooo1?l00004ooooo`;o00000oooool2o`0000Sooooo0_l00006oooo
o`Co00001?ooool2o`0003oooooo000Looooo`03o`000?oooooooooo043ooooo0_l000000ooooooo
0000o`000008ooooo`;o00000oooool4o`00013ooooo0_l0000Booooo`;o00001Oooool2o`0000Ko
oooo1_l000000ooooooo0000o`00000Do`0000gooooo0_l0000Aooooo`;o00000oooool2o`0000;o
oooo0_l00006ooooo`Oo00000_ooool7o`0000;ooooo0_l00003ooooo`;o00000oooool2o`0000go
oooo0ol00014ooooo`007?ooool00ol0003oooooooooo`0Uooooo`;o00004?ooool2o`000003oooo
ool0003o000000;ooooo1?l000000ooooooo0000o`00000=ooooo`Co00002?ooool2o`00017ooooo
0_l00004ooooo`;o000000?oooooo`000?l000001Oooool4o`0000Cooooo6?l0000Booooo`;o0000
5_ooool2o`0000Gooooo0_l00002ooooo`Wo000000Coooooo`000?l0003ooooo1Ol00007ooooo`;o
000000Coooooo`000?l0003o00003_ooool2o`0004Cooooo000Looooo`03o`000?oooooooooo02Co
oooo0ol0000@ooooo`;o000000?oooooo`000?l000000_ooool2o`0001?ooooo0ol00008ooooo`;o
00001Oooool2o`0000[ooooo0_l00004ooooo`;o00002_ooool2o`0000Cooooo6?l0000<ooooo`;o
00001?ooool2o`0000Gooooo0_l0000=ooooo`So000000?oooooo`000?l000003?l000000ooooooo
0000o`000002o`000003ooooool0003o000000Gooooo1?l000000ooooooo0000o`000004ooooo`?o
0000C_ooool001cooooo00?o0000ooooooooool09?ooool3o`0001Kooooo0_l0000Booooo`;o0000
00?oooooo`000?l000003oooool4o`0000?ooooo0_l00004ooooo`;o00005OoooolIo`0000_ooooo
0_l00004ooooo`;o00001Oooool2o`0000;ooooo0_l00005oooooa;o000000?oooooo`000?l00000
2ol000000ooooooo0000o`000005ooooo`;o00002Oooool3o`0004kooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003o
ooooooooo`0Uooooo`;o00005_ooool2o`0001;ooooo0_l000000ooooooo0000o`00000Aooooo`;o
00000oooool2o`0000Cooooo0_l0000EoooooaWo00002_ooool2o`0000Cooooo0ol00003ooooo`;o
00001?ooool2o`0000Gooooo1?l000000ooooooo0000o`000003o`000003ooooool0003o0000013o
00000_ooool4o`0001Gooooo0_l00004ooooo`;o0000A?ooool00006oooooomgMgOoV9RHoooooonH
V9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Moooo
o`;o0000:?oooolKo`0000[ooooo0_l000001?oooooo0000o`000?ooool3o`0000?ooooo0_l0000=
ooooo`;o000000?oooooo`000?l000000_ooool@o`000004ooooool0003o0000o`0000;ooooo1?l0
000<ooooo`;o000000Coooooo`000?l0003o00000oooool2o`0000Cooooo0_l00014ooooo`0000?o
oooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`Go00001_ooool00ol0003ooooooooo
o`1?ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Wooooo0_l000000ooooooo0000o`00
0004ooooo`Co00004_ooool2o`0000;ooooo3ol000000ooooooo0000o`000005o`0000[ooooo1Ol0
0007ooooo`Co00002?ooool2o`0000?ooooo1?l000000ooooooo0000o`00000Co`000004ooooool0
003o0000o`0000gooooo0_l000001?oooooo0000o`000?l0000:ooooo`;o0000@oooool00003oooo
ool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?m4A4CogMgMooooool00007ooooo`?o
0000>?ooool5o`0001;ooooo0_l000000ooooooo0000o`000009ooooo`;o00001Oooool3o`000004
ooooool0003o0000ooooo`Co00000_ooool4o`0001?ooooo0_l000000ooooooo0000o`000003oooo
oa;o00002_ooool4o`0000[ooooo0_l00002ooooo`;o00001?ooool:o`000003ooooool0003o0000
01Go00001oooool2o`0000Gooooo0_l0000>ooooo`;o0000@oooool00003ooooool0003ooooo00;o
oooo00?o0000ooooooooool02Oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo
03Sooooo1Ol0000Dooooo`;o00001Oooool2o`0000[ooooo0ol000001?oooooo0000o`000?l00002
ooooo`?o00000_ooool4o`0000Cooooo0_l0000<ooooo`;o000000?oooooo`000?l000000oooool?
o`0000_ooooo1?l0000@ooooo`;o00000ooooolSo`0000Oooooo0_l00009ooooo`;o00004?ooool2
o`0003gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oMgMgolc<
c?l000001oooool00ol0003oooooooooo`0iooooo`;o00005_ooool2o`0000Gooooo0_l0000<oooo
o`Go000000?oooooo`000?l000000_l00002ooooo`Co000000Coooooo`000?l0003ooooo0_l0000D
ooooo`;o00001?ooool3o`0000;ooooo0ol0000<ooooo`;o00004_ooool2o`000003ooooool0003o
000001oo00001?ooool2o`00013ooooo0_l0000@ooooo`;o0000?Oooool00006oooooomgMgOoV9RH
oooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo03Wooooo0_l0
000Xooooo`;o000000?oooooo`000?l000001?ooool3o`0000Sooooo0_l0000Eooooo`Ko000000?o
ooooo`000?l000000_l00003ooooo`;o00001?ooool2o`0001gooooo0_l00004oooooaco00000ooo
ool2o`0000?ooooo0_l0001Looooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMg
Mol0003ooooo00Kooooo00?o0000ooooooooool0Boooool2o`0000Oooooo0_l00007ooooo`;o0000
1?ooool2o`0001Gooooo0_l0000Booooo`;o000000Goooooo`000?l0003o0000ooooo`0;o`0000;o
oooo0_l0000Hooooo`;o00002?oooolMo`0000?ooooo0_l00003ooooo`;o00000_ooool2o`0000?o
oooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`0hooooo`Ko00002oooool4o`0000Gooooo
1?l00007ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00004Oooool3o`000003
ooooool0003o000000_ooooo0_l0000:ooooo`Wo00001?ooool2o`0000Kooooo0_l0000>ooooo`;o
00000oooool2o`0000?ooooo7Ol000000ooooooo0000o`000005ooooo`;o00000_ooool2o`0000?o
oooo0_l0000Qooooo`;o0000<?ooool001cooooo00?o0000ooooooooool0>?ooool6o`0000_ooooo
0_l00002ooooo`;o00000oooool3o`0000Cooooo4?l0000=ooooo`;o00000oooool2o`000003oooo
ool0003o000000[ooooo0ol0000Booooo`;o00000oooool2o`0000Kooooo0_l0000;ooooo`;o0000
1_ooool3o`000003ooooool0003o000001oo00001Oooool3o`0002Wooooo0_l0000`ooooo`007?oo
ool00ol0003oooooooooo`0dooooo`;o00000oooool3o`00017ooooo0_l00004ooooo`;o00000_oo
oolDo`0000;ooooo1?l00003ooooo`Co00004_ooool2o`000003ooooool0003o000000Sooooo0_l0
0006ooooo`;o00001oooool2o`0000oooooo0_l00007ooooob?o00001oooool4o`0005Wooooo000L
ooooo`03o`000?oooooooooo03Cooooo0_l000000ooooooo0000o`000003o`0000;ooooo0_l0000;
ooooo`;o00002_ooool9o`000003ooooool0003o000000ko00000oooool2o`0000Sooooo0_l0000=
ooooo`;o000000?oooooo`000?l000001Oooool3o`0000gooooo0ol0000?ooooo`;o00002OoooolQ
o`0000Wooooo0_l000000ooooooo0000o`000002o`0001Kooooo0_l00003ooooo`;o0000=oooool0
01cooooo00?o0000ooooooooool0=oooool3o`0000Cooooo0_l0000;ooooo`;o00000oooool2o`00
00Gooooo5ol000000ooooooo0000o`00000=ooooo`;o00004?ooool4o`0000?ooooo0ol0000=oooo
o`;o00004?ooool2o`0000?ooooo0_l00005oooooaco000000?oooooo`000?l000000ol0000:oooo
o`Co00005_ooool2o`0000?ooooo0_l0000gooooo`007?ooool00ol0003oooooooooo`0fooooo`;o
00000_ooool2o`0000;ooooo0_l0000@ooooo`Co00001OoooolJo`000003ooooool0003o000001co
oooo0_l000000ooooooo0000o`000007ooooo`;o00005_ooool2o`0000Kooooo0_l00006oooooa?o
00000_ooool9o`000003ooooool0003o000000?ooooo1?l00004ooooo`;o00005Oooool2o`0003ko
oooo000Looooo`03o`000?oooooooooo03Kooooo0_l00002ooooo`;o00001oooool2o`0000gooooo
0_l00006oooooa3o000000?oooooo`000?l000002Ol00003ooooo`;o00000_ooool2o`0001Kooooo
0_l00007ooooo`;o00005_ooool4o`0000cooooo6Ol000001?oooooo0000o`000?ooool2o`0000Go
oooo1?l00004ooooo`;o00005Oooool2o`0003kooooo000Looooo`03o`000?oooooooooo01_ooooo
0_l0000Mooooo`;o00001oooool2o`0000Cooooo0_l00007ooooo`;o000000?oooooo`000?l00000
0_oooolMo`0000;ooooo0ol000001?oooooo0000o`000?l0000Tooooo`;o00002oooool2o`0000Go
oooo0ol00009oooooa_o000000?oooooo`000?l000000_ooool2o`0006Cooooo000Looooo`03o`00
0?oooooooooo01_ooooo0_l0000Sooooo`;o00001_ooool3o`0000Oooooo0_l000000ooooooo0000
o`000002oooooa[o00001Oooool2o`0000;ooooo0_l00003ooooo`;o00003oooool2o`0000_ooooo
0ol000000ooooooo0000o`00000;ooooo`;o00000_ooool2o`0000gooooo8_l00009ooooo`;o0000
2Oooool2o`0000gooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00001ooo
ool2o`0000Wooooo0ol00005ooooo`;o00004OoooolHo`0000Cooooo0_l00008ooooo`;o00002_oo
ool2o`0000?ooooo0_l0000;ooooo`?o00002Oooool2o`0000Oooooo0_l0000?oooooa_o000000?o
ooooo`000?l000000_l00008ooooo`?o00000_ooool2o`000003ooooool0003o000000;ooooo0_l0
000=ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0;?ooool2o`0000Gooooo1?l00000
0ooooooo0000o`000007ooooo`;o00003_ooool2o`0000Kooooo6ol00003ooooo`;o00000oooool2
o`0000?ooooo0_l0000:ooooo`?o00000_ooool2o`0000Sooooo0_l00002ooooo`;o00002Oooool2
o`0000oooooo1?l000000ooooooo0000o`000002oooooago00001_ooool2o`0000?ooooo0_l00003
ooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000004_ooooo000Loooo
o`;o0000=?ooool2o`0000?ooooo1?l0000=ooooo`;o00001_ooool2o`0000Kooooo6ol00008oooo
o`;o00000oooool2o`0000Cooooo1?l00003ooooo`;o00003?ooool3o`0001Wooooo0_l00002oooo
o`Co000000?oooooo`000?l000000_ooool3o`000003ooooool0003o000001Oo000000Coooooo`00
0?l0003o00000_ooool2o`0000oooooo1Ol0001;ooooo`007?ooool00ol0003oooooooooo`0coooo
o`;o00001Oooool2o`0000gooooo0_l0000=oooooako00003?ooool2o`0000?ooooo1?l0000Boooo
o`;o00000oooool2o`0001Cooooo1?l00009ooooo`;o00000_ooool:o`000003ooooool0003o0000
00Ko000000?oooooo`000?l000001?ooool3o`0000Kooooo0_l00003ooooo`;o00001oooool2o`00
00Kooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00001Oooool2o`000003
ooooool0003o000000gooooo0_l0000AoooooaSo000000?oooooo`000?l000001Ol0000:ooooo`;o
00001_ooool2o`0000gooooo0_l00005ooooo`Co00003oooool2o`0000;ooooo0_l000000ooooooo
0000o`000002o`0000Oooooo0_l00002ooooo`[o000000?oooooo`000?l000001Ol00002ooooo`?o
00000oooool2o`0000Kooooo0ol00003ooooo`;o00001?ooool2o`000003ooooool0003o000000Ko
oooo0_l00007ooooo`;o0000??ooool001cooooo00?o0000ooooooooool0;?ooool2o`0000Oooooo
1Ol0000:ooooo`?o00001_ooool2o`0000Kooooo0_l00004oooooago00004_ooool2o`0000Sooooo
1ol00005ooooo`;o00001Oooool2o`000003ooooool0003o000000Oooooo0_l00002ooooo`;o0000
00?oooooo`000?l000000ol0000:oooooa7o00000_ooool4o`0000?ooooo0_l00006ooooo`;o0000
2_ooool2o`000003ooooool0003o000000Kooooo0_l00007ooooo`;o0000??ooool001cooooo00?o
0000ooooooooool0:oooool2o`0000Oooooo1_l0000:ooooo`;o000000Coooooo`000?l0003o0000
0oooool2o`0000Kooooo4ol000000ooooooo0000o`00000<o`0001?ooooo1_l00003ooooo`So0000
3?ooool2o`000003ooooool0003o000000;o00003?ooool2o`000003ooooool0003o000000;ooooo
0_l00007ooooo`;o00000_ooool4o`000003ooooool0003o000000Go000000?oooooo`000?l00000
0ol00003ooooo`;o00003oooool2o`0000cooooo0_l0000<ooooo`;o0000=oooool001cooooo00?o
0000ooooooooool0:oooool2o`0000;ooooo0ol000000ooooooo0000o`000002o`00013ooooo0ol0
000=oooooako00002_ooool2o`0000?ooooo0_l00003ooooo`Oo00000oooool2o`000003ooooool0
003o000000?ooooo0_l0000=ooooo`Co00001_ooool2o`0000Gooooo0_l00004ooooo`;o00002Ooo
oolAo`0000?ooooo0_l000000ooooooo0000o`00000=ooooo`Co00006_ooool2o`0003Oooooo000L
ooooo`03o`000?oooooooooo02oooooo0ol000000ooooooo0000o`000002o`00013ooooo0ol0000@
oooooaco00002?ooool3o`0000?ooooo1?l000000ooooooo0000o`000002o`0000Wooooo0_l00003
ooooo`;o00002Oooool2o`0000;ooooo0_l00008ooooo`;o00001Oooool2o`0000Sooooo1_l00000
0ooooooo0000o`000006o`0000Gooooo0_l00005ooooo`;o00002oooool2o`0000?ooooo0_l0000<
ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0;_ooool2o`0000_ooooo0_l0000;oooo
o`;o00001_ooool2o`000003ooooool0003o000000Gooooo0ol00002oooooaWo000000?oooooo`00
0?l000000oooool4o`0000Cooooo0_l00003ooooo`Co00001oooool2o`000004ooooool0003o0000
o`0000Sooooo1?l00003ooooo`;o00000oooool4o`000004ooooool0003o0000ooooo`;o00001ooo
ool2o`0000;ooooo1ol00002ooooo`?o000000?oooooo`000?l000006Oooool2o`00017ooooo0_l0
000Dooooo`?o0000<?ooool001cooooo00?o0000ooooooooool0;_ooool2o`0000_ooooo0_l00009
ooooo`;o00002?ooool2o`000003ooooool0003o000000Kooooo7Ol000000ooooooo0000o`000005
ooooo`;o000000Coooooo`000?l0003ooooo1_l000000ooooooo0000o`000005o`0000;ooooo0_l0
00001?oooooo0000o`000?l00005ooooo`;o000000?oooooo`000?l000001Oooool2o`0000?ooooo
1ol000000ooooooo0000o`000007ooooo`;o00001_ooool3o`000003ooooool0003o000000Co0000
4Oooool2o`0000Oooooo0_l0000Wooooo`?o0000<?ooool001cooooo00?o0000ooooooooool0;ooo
ool2o`0000?ooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l00006ooooo`;o00004ooo
oolCo`000003ooooool0003o000000Oo00001Oooool2o`0000Cooooo0_l00003ooooo`Co00000ooo
ool5o`000004ooooool0003o0000o`0000Gooooo0_l00002ooooo`;o00003?ooool3o`0000;ooooo
0_l0000Eooooo`Co00000_ooool2o`0000oooooo1?l00005ooooo`Co00003Oooool2o`0001Wooooo
0_l0000`ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00000oooool7o`0000?ooooo0_l0
000Gooooo`;o00000_oooolLo`0000?ooooo0_l000000ooooooo0000o`000004ooooo`;o000000?o
ooooo`000?l000000_l000000ooooooo0000o`000008ooooo`;o00000oooool2o`000003ooooool0
003o0000013ooooo1Ol0000=ooooo`;o00002?ooool6o`00013ooooo0ol00004ooooo`;o000000?o
ooooo`000?l000000oooool2o`0000[ooooo0_l00002ooooo`;o00000oooool2o`00013ooooo0_l0
000`ooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o00001oooool5o`0000Cooooo0ol0000:
ooooo`;o00002?ooool2o`000003ooooool0003o000000Cooooo5?l00002ooooo`Co00000oooool2
o`0000Oooooo1ol000001?oooooo0000o`000?l00002ooooo`;o00002?ooool2o`0000gooooo0_l0
0005ooooo`Co00002?ooool2o`0000?ooooo0_l0000<ooooo`;o000000?oooooo`000?l000002?oo
ool2o`0000?ooooo0_l00003ooooo`Ko00001?ooool2o`0000kooooo0_l00003ooooo`?o00003ooo
ool4o`0002kooooo000Looooo`03o`000?oooooooooo02_ooooo0_l00007ooooo`Go00001?ooool3
o`0000[ooooo0_l00008ooooo`;o00001ooooolFo`000004ooooool0003o0000o`0000?ooooo0_l0
0006ooooo`Co00000_ooool<o`0000[ooooo0_l00004ooooo`;o00000oooool2o`0000;ooooo0ol0
0004ooooo`;o00001_ooool2o`0000?ooooo0_l00004ooooo`Co00001?ooool2o`000004ooooool0
003o0000ooooo`?o00001?ooool4o`0000?ooooo1Ol00002ooooo`;o00000oooool2o`000003oooo
ool0003o000001;ooooo0_l0000Aooooo`;o0000;_ooool001cooooo00?o0000ooooooooool0:?oo
ool2o`0000[ooooo1Ol000000ooooooo0000o`00000Tooooo`Oo000000?oooooo`000?l000003?l0
0009ooooo`;o000000?oooooo`000?l000001_ooool6o`0000;ooooo0_l00008ooooo`Ko00000_oo
ool2o`000003ooooool0003o000000Cooooo0ol00004ooooo`;o00001Oooool2o`0000[ooooo1?l0
0004ooooo`?o00000oooool3o`0000Kooooo0_l00003ooooo`Co00001oooool3o`000003ooooool0
003o000000Kooooo0_l0000<ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0:?ooool2
o`0000[ooooo0_l00004ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0001Oooooo0_l0
0003ooooo`;o00000_ooool3o`000003ooooool0003o000000co00000_ooool2o`000003ooooool0
003o000000;ooooo1?l00004ooooo`;o00003oooool2o`0000;ooooo0ol000000ooooooo0000o`00
0005ooooo`;o00004_ooool2o`0001?ooooo0_l00003ooooo`;o00004_ooool2o`000003ooooool0
003o000000;o00000oooool2o`000003ooooool0003o000000;ooooo0_l0000<ooooo`;o0000?ooo
ool001cooooo00?o0000ooooooooool0=?ooool2o`000004ooooool0003o0000ooooo`;o000000Go
ooooo`000?l0003o0000ooooo`03o`0000;ooooo0_l0000Cooooo`;o00001?ooool2o`000003oooo
ool0003o000000Wo000000Goooooo`000?l0003o0000ooooo`02o`0000;ooooo1Ol00004ooooo`;o
000000Coooooo`000?l0003ooooo0_l0000?ooooo`;o00005Oooool2o`0000Kooooo0_l00009oooo
o`;o00004Oooool2o`0000gooooo1?l000001?oooooo0000o`000?ooool2o`0000Gooooo1Ol00003
ooooo`?o00000oooool2o`0000Gooooo0_l0000oooooo`007?ooool2o`0003Gooooo0_l000000ooo
oooo0000o`000002ooooo`;o00001?ooool2o`000003ooooool0003o000000;o00006Oooool=o`00
00;ooooo0ol000000ooooooo0000o`000007o`0000Gooooo1?l0000?ooooo`;o00001oooool2o`00
00cooooo0_l000000ooooooo0000o`000006ooooo`;o00002Oooool2o`0001Wooooo0_l00003oooo
o`Ko000000Coooooo`000?l0003ooooo1?l00005ooooo`;o00001?ooool4o`0000;ooooo0_l00016
ooooo`007?ooool00ol0003oooooooooo`0dooooo`;o00000oooool4o`0000Oooooo0_l0000Hoooo
o`Ko00001oooool3o`000004ooooool0003o0000o`0000;ooooo2ol00002ooooo`?o00004Oooool2
o`0000;ooooo0_l00003ooooo`;o00002Oooool2o`000003ooooool0003o000002[ooooo0_l00002
ooooo`Co00000_ooool2o`0000Wooooo0ol000000ooooooo0000o`00000:ooooo`;o00001?ooool2
o`0004Cooooo000Looooo`03o`000?oooooooooo02oooooo0_l00008ooooo`;o000000Coooooo`00
0?l0003o00007_ooool5o`0000Wooooo1_l00005ooooo`;o00000_ooool=o`0000Sooooo1?l00006
ooooo`;o00003_ooool2o`0001Cooooo0_l0000@ooooo`;o00000oooool4o`0000;ooooo1?l00000
0ooooooo0000o`000002o`0000cooooo0_l0000@ooooo`;o0000A?ooool001cooooo00?o0000oooo
ooooool0;oooool2o`0000_ooooo0ol0000Nooooo`;o00000oooool2o`0000[ooooo0_l0000:oooo
o`;o00000_ooool3o`0000;ooooo1?l00008ooooo`Co00002Oooool2o`0001_ooooo0_l00004oooo
o`;o00003?ooool2o`000004ooooool0003o0000o`0000?ooooo0_l00009ooooo`Co00000_ooool2
o`0000Cooooo1?l00004ooooo`;o00002oooool2o`0000Gooooo0_l0000nooooo`007?ooool00ol0
003oooooooooo`1Rooooo`;o00004_ooool2o`0000Kooooo0_l00009ooooo`;o00002_ooool2o`00
00Gooooo0_l00002ooooo`?o00000_ooool2o`0001;ooooo0_l00002ooooo`;o00000_ooool2o`00
00Oooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000?ooooo1?l0000;
ooooo`;o00000_ooool6o`0000Cooooo0_l0000;ooooo`?o00001?ooool2o`0003kooooo000Loooo
o`03o`000?oooooooooo02kooooo0_l0000;ooooo`;o00009Oooool2o`0000gooooo0ol00002oooo
o`;o000000?oooooo`000?l000001Ol00002ooooo`;o00001Oooool2o`0000[ooooo0_l00003oooo
o`;o00001?ooool3o`0000;ooooo0_l000000ooooooo0000o`00000>ooooo`;o00000oooool2o`00
00;ooooo0_l00007ooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`Ko00002oooool2
o`0000;ooooo0_l00003ooooo`;o00001Oooool2o`0000[ooooo0_l00002ooooo`;o0000@?ooool0
01cooooo00?o0000ooooooooool0;_ooool2o`0000?ooooo0_l000000ooooooo0000o`000003oooo
o`;o00009Oooool2o`0000gooooo0ol00005ooooo`Ko00000oooool2o`0000Cooooo0_l00003oooo
o`;o00002?ooool5o`0000cooooo0_l0000>ooooo`;o00000oooool2o`0000Cooooo1?l00009oooo
o`;o00001?ooool2o`000003ooooool0003o000000?ooooo0_l00007ooooo`;o00001oooool2o`00
00Gooooo0_l0000>ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0<oooool5o`0000go
oooo0_l0000Eooooo`;o00005?ooool2o`0000Gooooo1?l00008ooooo`;o000000?oooooo`000?l0
00000oooool2o`0000Cooooo0_l00002ooooo`?o00001_ooool2o`0000Sooooo2Ol00003ooooo`;o
000000Goooooo`000?l0003o0000ooooo`02o`0000Cooooo1?l0000;ooooo`;o00002_ooool2o`00
00Wooooo0_l0000?ooooo`;o0000COooool001cooooo00?o0000ooooooooool0<_ooool5o`0000?o
oooo1?l00007ooooo`;o00004_ooool2o`000003ooooool0003o000000_ooooo0_l00007ooooo`?o
00000_ooool2o`0000;ooooo0_l00008ooooo`?o00002oooool2o`0000Oooooo1_l00005ooooo`;o
000000?oooooo`000?l000001ol00003ooooo`;o000000Goooooo`000?l0003o0000ooooo`03o`00
00Oooooo0_l00009ooooo`;o00002_ooool2o`0000Wooooo0_l00006ooooo`;o00001oooool2o`00
00Oooooo0_l00004ooooo`;o00002oooool2o`00037ooooo000Looooo`03o`000?oooooooooo03;o
oooo0ol00005ooooo`Co00006oooool3o`0000?ooooo0_l00007ooooo`?o00001oooool4o`000003
ooooool0003o000000cooooo1Ol0000Booooo`Ko00001?ooool3o`0000Wooooo1Ol00002ooooo`;o
00000_ooool3o`0000?ooooo0_l00002ooooo`;o00003?ooool2o`0001Oooooo0_l000000ooooooo
0000o`00000@ooooo`;o000000Coooooo`000?l0003ooooo0_l0000;ooooo`;o0000<Oooool001co
oooo00?o0000ooooooooool0<oooool2o`00017ooooo0_l0000Booooo`;o00000oooool2o`0000;o
oooo0ol00002ooooo`;o00001oooool2o`000004ooooool0003o0000ooooo`;o00003oooool2o`00
00Cooooo0_l0000;ooooo`;o00000oooool2o`0000Cooooo0_l00006ooooo`;o00000_ooool5o`00
00;ooooo0_l000000ooooooo0000o`000005ooooo`;o00001_ooool2o`0000Sooooo0_l0000Goooo
o`;o00004Oooool2o`0000?ooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o
00001?ooool3o`0000Sooooo0_l00006ooooo`;o00003?ooool2o`0000?ooooo0ol00005ooooo`Go
000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l00004ooooo`Co00001oooool2o`0000[o
oooo0_l0000;ooooo`;o00000oooool2o`0000Cooooo0_l00006ooooo`;o00001_ooool3o`000003
ooooool0003o000000;o00000oooool2o`0000Sooooo0_l00003ooooo`;o00004?ooool2o`0001go
oooo0_l00004ooooo`Co0000?_ooool001cooooo00?o0000ooooooooool0;Oooool2o`0000;ooooo
0_l000000ooooooo0000o`000008ooooo`;o00001?ooool4o`000003ooooool0003o000000Wooooo
0_l00003ooooo`?o00001Oooool2o`0000Cooooo1_l0000:ooooo`Co00001oooool2o`00017ooooo
0_l00003ooooo`;o00001?ooool2o`0000Cooooo0_l00009ooooo`;o000000?oooooo`000?l00000
0ol000001?oooooo0000o`000?l00004ooooo`;o00003Oooool2o`0000cooooo1_l0000Sooooo`Co
00002_ooool2o`0003;ooooo000Looooo`03o`000?oooooooooo037ooooo0_l0000Aooooo`Oo0000
3oooool2o`0000gooooo0_l00004ooooo`;o00001oooool2o`000003ooooool0003o000000gooooo
0_l00002ooooo`;o00001Oooool2o`0000?ooooo0_l00005ooooo`;o00002?ooool4o`0000;ooooo
0_l000000ooooooo0000o`000003o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l0
00006_ooool6o`00023ooooo0_l0000Aooooo`;o00000oooool2o`0002gooooo000Looooo`03o`00
0?oooooooooo02oooooo0_l0000Eooooo`?o00009_ooool2o`0000?ooooo1_l000000ooooooo0000
o`000002ooooo`?o00002?ooool2o`0000;ooooo0_l0000;ooooo`;o00001?ooool2o`0000?ooooo
0_l00003ooooo`So00000_ooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0000Co
oooo0_l00005ooooo`Ko00001?ooool2o`0000?ooooo0_l00005ooooo`;o00007Oooool2o`0001Ko
oooo0_l0000]ooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o000000?oooooo`000?l00000
1_ooool2o`0000_ooooo0_l0000?ooooo`;o00002Oooool2o`0000_ooooo1?l00003ooooo`Co0000
1oooool3o`000003ooooool0003o000001Kooooo0_l00009ooooo`?o00001Oooool5o`0000Oooooo
0_l00005ooooo`;o00000oooool2o`0000Gooooo1_l00004ooooo`;o00002_ooool2o`0001gooooo
1?l00002ooooo`;o0000?oooool001cooooo0_l0000]ooooo`;o00002Oooool3o`0000Gooooo0_l0
00000ooooooo0000o`000002o`0000oooooo0_l00008ooooo`?o00002oooool4o`0000;ooooo0ol0
0002ooooo`;o00002Oooool2o`0002;ooooo0_l000000ooooooo0000o`000004ooooo`?o00000_oo
ool7o`0000Gooooo0ol00008ooooo`Go0000<oooool2o`0000;ooooo0_l0000oooooo`007?ooool0
0ol0003oooooooooo`0gooooo`?o00001Oooool2o`000003ooooool0003o000000oooooo0_l00006
ooooo`;o00000_ooool2o`0000Kooooo0_l0000:ooooo`;o00000oooool2o`0000Gooooo2?l00004
ooooo`;o00003oooool2o`0000Oooooo1?l000000ooooooo0000o`000002ooooo`?o000000?ooooo
o`000?l000002_l00004ooooo`?o00001oooool2o`000003ooooool0003o000000Cooooo0_l00003
ooooo`;o0000>?ooool2o`0003?ooooo000Looooo`03o`000?oooooooooo03;ooooo0_l0000>oooo
o`;o00000oooool2o`0000[ooooo0_l00006ooooo`;o00002_ooool5o`0000Kooooo0_l00004oooo
o`Co00000oooool8o`0000Cooooo0_l0000?ooooo`;o00001oooool2o`000003ooooool0003o0000
00Cooooo0ol000000ooooooo0000o`00000:o`0000?ooooo1?l00005ooooo`Co000000?oooooo`00
0?l000001?ooool2o`0000?ooooo0_l0000hooooo`;o0000<oooool001cooooo00?o0000oooooooo
ool0<_ooool2o`0000[ooooo0_l00007ooooo`?o00003Oooool2o`0000oooooo1?l00006ooooo`;o
00001_ooool7o`0002Oooooo0_l000000ooooooo0000o`000004o`0000?ooooo2ol00002ooooo`;o
000000?oooooo`000?l000001?ooool5o`0003Oooooo0_l00011ooooo`007?ooool00ol0003ooooo
ooooo`0fooooo`;o00000_ooool2o`0000;ooooo0_l00006ooooo`Go00002?ooool2o`0000;ooooo
0_l0000Looooo`;o000000?oooooo`000?l000000_ooool5o`0000Oooooo0_l0000Jooooo`;o0000
1Oooool7o`0000?ooooo1ol000000ooooooo0000o`000003o`0000;ooooo1?l00005ooooo`;o0000
1_ooool2o`0002kooooo0ol0000;ooooo`;o0000=?ooool001cooooo00?o0000ooooooooool0=_oo
ool2o`0000;ooooo0_l00007ooooo`;o000000Coooooo`000?l0003ooooo1Ol00005ooooo`;o0000
8?ooool2o`000003ooooool0003o000000Oooooo0_l00002ooooo`;o000000?oooooo`000?l00000
6?ooool5o`0000Kooooo0_l000000ooooooo0000o`000005o`000004ooooool0003o0000ooooo`;o
000000?oooooo`000?l000000ol00003ooooo`?o000000Coooooo`000?l0003o00002?ooool2o`00
02kooooo0_l0000<ooooo`;o0000=?ooool001cooooo00?o0000ooooooooool0;_ooool2o`0000Wo
oooo0_l00008ooooo`;o000000?oooooo`000?l000000_ooool4o`0000Gooooo0_l00004ooooo`;o
00003Oooool4o`0000;ooooo1Ol0000>ooooo`;o00000_ooool2o`0001Oooooo0_l00002ooooo`Go
00000_ooool6o`0000;ooooo3_l00002ooooo`co0000=oooool2o`0004?ooooo000Looooo`03o`00
0?oooooooooo02kooooo0ol00008ooooo`;o00002?ooool2o`0001Cooooo0_l00009ooooo`;o0000
00?oooooo`000?l000001?l000000ooooooo0000o`000003o`0002_ooooo0_l00009ooooo`So0000
00?oooooo`000?l000003?l000000ooooooo0000o`000004o`0000;ooooo0ol0000<ooooo`;o0000
2_ooool2o`0001kooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00001_oo
ool4o`0000;ooooo0_l00004ooooo`Co00007Oooool2o`000003ooooool0003o000000;ooooo0_l0
0007ooooo`Ko00003oooool2o`0001Kooooo0_l00008ooooo`Ko000000?oooooo`000?l000004Ol0
00001?oooooo0000o`000?l0000?ooooo`?o00002Oooool2o`0001oooooo0_l00012ooooo`007?oo
ool00ol0003oooooooooo`0/ooooo`;o00001oooool6o`0000;ooooo0_l000000ooooooo0000o`00
0003ooooo`;o00001oooool2o`000003ooooool0003o000001Cooooo0_l0000;ooooo`Ko00001Ooo
ool2o`0000Sooooo0_l0000Fooooo`;o000000?oooooo`000?l000001oooool4o`000003ooooool0
003o000000oo000000?oooooo`000?l000000ol00004ooooo`;o00002_ooool2o`0000Gooooo0_l0
000Sooooo`?o0000@Oooool001cooooo00?o0000ooooooooool0;?ooool2o`0000?ooooo0_l00002
ooooo`;o00002Oooool2o`0000Oooooo0_l00003ooooo`Go00004?ooool2o`0001[ooooo1?l0000J
ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Oooooo5_l000001?oooooo0000o`000?oo
ool2o`000004ooooool0003o0000ooooo`;o00004Oooool2o`0000Cooooo0_l0000Booooo`;o0000
2_ooool2o`00047ooooo000Looooo`03o`000?oooooooooo037ooooo0_l00007ooooo`;o00003Ooo
ool2o`0000;ooooo0_l000000ooooooo0000o`00000Aooooo`;o000000?oooooo`000?l000003_oo
ool4o`0000Oooooo0_l0000Iooooo`?o000000?oooooo`000?l000000_ooool7o`000003ooooool0
003o000001So00001?ooool2o`0001Wooooo0ol0000Booooo`;o0000COooool001cooooo00?o0000
ooooooooool0=Oooool2o`0000?ooooo0_l00007ooooo`;o00001?ooool2o`000004ooooool0003o
0000o`0001Oooooo0_l0000;ooooo`;o000000?oooooo`000?l000001?l00003ooooo`;o00005?oo
ool2o`0000Gooooo1_l00003ooooo`Ko000000?oooooo`000?l000006Ol00002ooooo`Co00001ooo
ool2o`0000oooooo0_l0000Dooooo`;o00001oooool2o`0004?ooooo000Looooo`03o`000?oooooo
oooo02oooooo0_l00004ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Oooooo0_l0000U
ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l0000Dooooo`;o00001oooool2
o`0000?ooooo4_l000000ooooooo0000o`00000?o`0000;ooooo1?l00004ooooo`;o000000?ooooo
o`000?l000009Oooool2o`0000Oooooo0_l00013ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^
k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0
;?ooool2o`000003ooooool0003o000000Oooooo0_l00002ooooo`;o00002Oooool2o`0000Oooooo
0_l000000ooooooo0000o`00000Mooooo`;o00000_ooool6o`0002;ooooo0_l00003ooooo`Co0000
00?oooooo`000?l000007_l000000ooooooo0000o`000006ooooo`;o0000;Oooool2o`0004Oooooo
00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRH
V?lQ8B401_ooool00ol0003oooooooooo`0/ooooo`;o00001oooool5o`0000;ooooo0_l000000ooo
oooo0000o`000006ooooo`Co00001Oooool2o`000003ooooool0003o000001Kooooo0_l00003oooo
oa3o00008_oooolWo`000003ooooool0003o000000Gooooo0_l00008ooooo`;o00008oooool2o`00
0003ooooool0003o000004Cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wo
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo03Gooooo1Ol00005oooo
o`;o00002?ooool2o`00023ooooo0_l00003oooooa?o00002oooool2o`0000cooooo0_l00004oooo
obOo000000?oooooo`000?l000000_ooool2o`0000_ooooo0_l000000ooooooo0000o`00000Noooo
o`;o00000oooool2o`0004Cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wo
oooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000>_ooool2o`0003Gooooo0_l000000ooo
oooo0000o`00000=o`0000_ooooo0_l0000<ooooo`;o000000Coooooo`000?l0003ooooo9ol00002
ooooo`Go00003_ooool2o`0000Kooooo0_l0000Fooooo`;o0000BOooool00003ooooool0003ooooo
00;ooooo00?o0000ooooooooool02Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000
ooooooooool0<oooool2o`0000?ooooo1_l000000ooooooo0000o`000003ooooo`;o00009_ooool2
o`0000?ooooo4Ol00004ooooo`;o00005oooool2o`000005ooooool0003o0000o`000?ooool04_l0
00000ooooooo0000o`00000Do`00017ooooo0_l00004ooooo`;o00006Oooool4o`0004Cooooo0000
0ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qoooool02?ooool0
0ol0003oooooooooo`0^ooooo`;o00000oooool2o`0000?ooooo0_l00002ooooo`Go00000oooool2
o`0001Sooooo0_l0000<ooooo`Co000000?oooooo`000?l000004_l000000ooooooo0000o`00000<
ooooo`;o00001oooool4o`000003ooooool0003o000000;ooooo6_l000000ooooooo0000o`000009
o`000003ooooool0003o0000017ooooo0_l0000Cooooo`;o00002_ooool4o`0000cooooo0_l0000f
ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o
0000ooooooooool0;_ooool4o`0000cooooo0_l00007ooooo`;o00005Oooool2o`0000Oooooo0_l0
0004ooooo`?o00000_oooolCo`0000;ooooo0_l0000;ooooo`;o00001oooool4o`000003ooooool0
003o000000;ooooo8ol000000ooooooo0000o`000005ooooo`;o00003Oooool2o`0001?ooooo0_l0
000Jooooo`;o0000=_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4
o`000?l@4106ooooo`03o`000?oooooooooo033ooooo1?l0000Cooooo`;o00002?ooool3o`0000[o
oooo0_l00007ooooo`;o000000Coooooo`000?l0003ooooo0_l00002oooooaCo00000_ooool2o`00
00Wooooo0_l00008ooooo`;o000000Coooooo`000?l0003ooooo0_l00003ooooob;o000000Gooooo
o`000?l0003o0000ooooo`05o`0000_ooooo1?l0001Wooooo`007?ooool00ol0003oooooooooo`0a
ooooo`Co00005_ooool2o`0000Cooooo0ol0000:ooooo`;o00002_ooool2o`0000Gooooo6Ol00000
0ooooooo0000o`000005ooooo`;o00000_ooool2o`0000;ooooo1?l000000ooooooo0000o`000003
ooooo`;o000000?oooooo`000?l000007ol000000ooooooo0000o`000002o`000003ooooool0003o
000000;o00000oooool2o`0000Oooooo0_l0000Pooooo`;o0000Aoooool001cooooo00?o0000oooo
ooooool0<Oooool4o`0000[ooooo0_l0000:ooooo`;o00008ooooolMo`000003ooooool0003o0000
00Kooooo0_l00002ooooo`;o00000oooool<o`000003ooooool0003o000001[o000000Coooooo`00
0?l0003o00000_ooool4o`0000?ooooo0_l00009ooooo`;o00001?ooool2o`0000kooooo0ol00007
ooooo`;o00002oooool2o`0003[ooooo000Looooo`03o`000?oooooooooo03oooooo0_l000001?oo
oooo0000o`000?l0000Oooooo`;o00002?oooolJo`000004ooooool0003o0000o`0000;ooooo0_l0
000@ooooo`_o000000?oooooo`000?l000006_l000000ooooooo0000o`000002ooooo`;o00000_oo
ool2o`0000gooooo0_l00002ooooo`Co00003_ooool3o`000004ooooool0003o0000o`00013ooooo
0_l0000jooooo`007?ooool00ol0003oooooooooo`12ooooo`?o00007oooool2o`0000?ooooo0_l0
0003oooooa[o00000_ooool2o`0000;ooooo0_l0000@ooooo`;o000000?oooooo`000?l000001ol0
00000ooooooo0000o`00000Ko`0000?ooooo1_l0000Aooooo`;o00003oooool2o`0000?ooooo0ol0
0004ooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0=Oooool2o`000003ooooool0003o
000000Cooooo0_l000000ooooooo0000o`00000Hooooo`;o00000oooool3o`0000Kooooo0_l00002
oooooa_o00003Oooool3o`0000Gooooo0_l00006ooooo`?o000000?oooooo`000?l000008?l00002
ooooo`Go00008oooool3o`0000;ooooo0_l00005ooooo`;o0000A_ooool001cooooo00?o0000oooo
ooooool0=Oooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000002oooo
o`;o00005?ooool2o`0000?ooooo0ol00009ooooo`Co00000_oooolFo`0000gooooo0ol00005oooo
o`;o00000oooool3o`000003ooooool0003o000002?o00000oooool4o`0000?ooooo1?l0000Loooo
o`?o00004Oooool2o`0003kooooo000Looooo`03o`000?oooooooooo03cooooo1Ol00004ooooo`;o
00000oooool4o`0000Wooooo0_l00006ooooo`;o00001?ooool2o`0000Cooooo0ol00004oooooaKo
00001oooool4o`0000Kooooo0_l000001?oooooo0000o`000?l00003ooooo`co000000?oooooo`00
0?l000005Ol000000ooooooo0000o`000002o`000003ooooool0003o000000;o00001Oooool4o`00
01Kooooo0_l0000>ooooo`;o00001?ooool2o`0000;ooooo0_l0000nooooo`007?ooool00ol0003o
ooooooooo`0looooo`Go00002Oooool4o`000003ooooool0003o000000Gooooo0ol00006ooooo`;o
00001?ooool2o`0000Cooooo0_l00006oooooaCo00000_ooool2o`0000Cooooo1ol00003ooooo`;o
000000Coooooo`000?l0003o00001OoooolUo`000003ooooool0003o000000Co00001oooool2o`00
01Gooooo0ol00002ooooo`Go00001oooool2o`0000Cooooo0_l00012ooooo`007?ooool00ol0003o
ooooooooo`0kooooo`;o00002?ooool2o`0000?ooooo0_l00003ooooo`;o00001Oooool2o`0000Ko
oooo0_l000000ooooooo0000o`000007ooooo`;o00001oooool;o`000003ooooool0003o000000co
00000_ooool2o`000003ooooool0003o000000;o00001Oooool2o`0000Sooooo9?l000000ooooooo
0000o`000004o`0001kooooo0_l00002ooooo`Wo00002Oooool2o`0000;ooooo0_l0000oooooo`00
7?ooool00ol0003oooooooooo`0eooooo`;o00001?ooool2o`0000Oooooo0ol00003ooooo`;o0000
4?ooool4o`000003ooooool0003o000000;ooooo0_l00003ooooo`;o00001ooooolGo`000003oooo
ool0003o000000kooooo0_l00005ooooobCo000000Coooooo`000?l0003ooooo1?l00007ooooo`;o
00006oooool2o`0000?ooooo1?l000000ooooooo0000o`000006ooooo`;o00000_ooool2o`0003oo
oooo000Looooo`03o`000?oooooooooo03Gooooo0_l0000=ooooo`;o00001_ooool2o`0000Sooooo
0_l00002ooooo`Ko000000Goooooo`000?l0003o0000ooooo`02o`0000cooooo4?l00003ooooo`?o
00001Oooool2o`0000;ooooo0_l0000:ooooo`;o00000_oooolVo`0000;ooooo1?l00002ooooo`Oo
00000_ooool2o`0000Oooooo0_l0000>ooooo`;o000000?oooooo`000?l000000ol00002ooooo`;o
00001?ooool2o`0004Gooooo000Looooo`;o0000>oooool3o`0000?ooooo0_l0000:ooooo`?o0000
1oooool2o`0000;ooooo0_l00006ooooo`;o000000?oooooo`000?l000003Oooool@o`0000?ooooo
0_l00005ooooo`;o00000_ooool2o`0000[ooooo0_l00003ooooo`Go000000?oooooo`000?l00000
4_l000000ooooooo0000o`000008o`000004ooooool0003o0000o`0000?ooooo2Ol000000ooooooo
0000o`000007ooooo`;o00003_ooool2o`000003ooooool0003o000000_ooooo0_l00015ooooo`00
7?ooool00ol0003oooooooooo`0jooooo`?o00000oooool2o`0000_ooooo0_l00007ooooo`Co0000
2oooool2o`0000kooooo1?l000000ooooooo0000o`000008o`0001Cooooo0_l00004ooooo`;o0000
0oooool5o`000003ooooool0003o000001go000000Coooooo`000?l0003o00000oooool2o`0000Go
oooo1Ol00002ooooo`?o00001Oooool2o`0000Oooooo0ol00004ooooo`;o00000_ooool2o`0004ko
oooo000Looooo`03o`000?oooooooooo057ooooo0_l00005ooooo`;o00002oooool2o`0000kooooo
0_l00004ooooo`Ko00005oooool4o`0000;ooooo1_l000000ooooooo0000o`00000Vo`0000[ooooo
1?l00002ooooo`?o00001Oooool2o`0000Gooooo1Ol00008ooooo`;o0000C_ooool001cooooo00?o
0000ooooooooool0=oooool2o`0000Oooooo0_l0000?ooooo`;o00001Oooool2o`0000?ooooo0_l0
0006ooooo`;o00005?ooool6o`0001;ooooo0_l00005ooooo`;o00001?ooool:o`000003ooooool0
003o000001Ko000000Coooooo`000?l0003ooooo1_l00008ooooo`;o00003_ooool4o`0000?ooooo
0_l0000@ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0=oooool2o`0000Oooooo0_l0
000:ooooo`;o00000oooool2o`0000?ooooo1?l00003ooooo`;o000000?oooooo`000?l000002?oo
ool2o`0000cooooo0_l000000ooooooo0000o`00000:ooooo`;o00002_ooool2o`0000oooooo8ol0
0002ooooo`?o00001oooool4o`0000kooooo1?l00003ooooo`?o00002?ooool2o`0000Gooooo0_l0
0003ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0@Oooool2o`0000Wooooo0_l00003
ooooo`;o00000oooool2o`0000Sooooo0_l00008ooooo`;o00002_ooool4o`0000[ooooo0_l00000
0ooooooo0000o`000002o`0001_ooooo1ol00002ooooo`ko00000_ooool8o`0000?ooooo0_l00003
ooooo`;o00000_ooool2o`0001Oooooo0ol00008ooooo`;o00002_ooool2o`0004Cooooo000Loooo
o`03o`000?oooooooooo03Sooooo0_l00007ooooo`;o00003Oooool3o`0000Kooooo0_l00009oooo
o`;o00003oooool3o`0000Oooooo0_l00002ooooo`Co00000_ooool2o`0000Gooooo0_l0000Eoooo
o`Ko00000_ooool>o`0000;ooooo1?l00004ooooo`;o00001_ooool2o`0000cooooo0_l0000=oooo
o`;o0000Foooool001cooooo00?o0000ooooooooool0>?ooool2o`0000Cooooo0_l0000@ooooo`;o
00001oooool2o`0000Wooooo0_l0000?ooooo`;o00000oooool2o`0000?ooooo0_l000000ooooooo
0000o`000006o`0000;ooooo0_l00002ooooo`;o00000_ooool2o`0000Oooooo0_l00009ooooo`Co
00000oooool7o`0000;ooooo3Ol00002ooooo`Co00004_ooool3o`0000Cooooo0_l0001Sooooo`00
7?ooool00ol0003oooooooooo`0iooooo`;o00000oooool3o`000004ooooool0003o0000ooooo`;o
00004_ooool2o`0000?ooooo0_l00004ooooo`;o00002?ooool2o`0000[ooooo0_l00006ooooo`?o
00000_ooool3o`0000;ooooo0_l00006ooooo`;o00001oooool2o`0000_ooooo1?l00002ooooo`Co
00001?ooool=o`0000Cooooo0_l0000:ooooo`;o00000oooool6o`0000Cooooo1?l0000Cooooo`;o
0000C?ooool001cooooo00?o0000ooooooooool0>Oooool2o`0000Cooooo1Ol000000ooooooo0000
o`00000Booooo`;o00000oooool2o`0000Cooooo1?l00004ooooo`Co00001Oooool2o`0000_ooooo
0_l00006ooooo`;o00002?ooool2o`0000Kooooo0_l00003ooooo`;o00000_ooool2o`0000Cooooo
0ol00005ooooo`;o00001?ooool:o`0000Kooooo0ol00009ooooo`;o00000_ooool5o`0000Gooooo
1Ol0000Cooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0>oooool2o`0000?ooooo0_l0
000Looooo`;o00001Oooool3o`0000Cooooo0_l00007ooooo`;o00002oooool2o`0000Cooooo1?l0
0008ooooo`?o000000?oooooo`000?l000000_ooool7o`0000;ooooo0_l00004ooooo`Co00001?oo
ool2o`000003ooooool0003o000000So000000?oooooo`000?l000000_l00003ooooo`Co00003Ooo
ool2o`0000Oooooo0ol0000>ooooo`;o0000E?ooool001cooooo00?o0000ooooooooool0>oooool2
o`0000Wooooo0_l0000Fooooo`;o00001Oooool3o`0000Cooooo0_l00009ooooo`;o00000oooool2
o`0000[ooooo0_l0000;ooooo`Go000000Coooooo`000?l0003ooooo1?l00009ooooo`Co00000_oo
ool2o`0000;ooooo1_l00002ooooo`So00000oooool2o`0000oooooo0_l00007ooooo`;o00000_oo
ool2o`0000_ooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`15ooooo`?o00002_ooool2
o`00017ooooo0_l000000ooooooo0000o`000002ooooo`;o00002Oooool2o`000003ooooool0003o
000000;o00006Oooool2o`0000;ooooo0_l00007ooooo`;o00001Oooool4o`0000;ooooo2_l00002
ooooo`;o000000Coooooo`000?l0003o00005_ooool2o`0000;ooooo0_l00006ooooo`?o00001_oo
ool2o`0005Wooooo000Looooo`03o`000?oooooooooo04Gooooo0_l0000;ooooo`?o00004oooool2
o`00013ooooo0_l00003ooooo`;o00003Oooool3o`0000Kooooo0_l000001?oooooo0000o`000?l0
0007ooooo`;o00001oooool2o`0000Cooooo1ol00007ooooo`Go00001?ooool2o`0000Kooooo1?l0
00000ooooooo0000o`000004ooooo`;o00001_ooool2o`0000Oooooo0_l0000<ooooo`;o0000Booo
ool001cooooo00?o0000ooooooooool0B_ooool2o`0000Kooooo0ol00008ooooo`;o00000oooool2
o`0000?ooooo0_l00004ooooo`;o00003?ooool2o`0000;ooooo0_l0000=ooooo`?o00001_ooool2
o`000004ooooool0003o0000o`0001?ooooo0_l00004ooooo`Ko00001?ooool6o`000004ooooool0
003o0000ooooo`;o00001_ooool7o`0002?ooooo0_l0001;ooooo`007?ooool00ol0003ooooooooo
o`1:ooooo`?o00000_ooool2o`0000cooooo0_l00003ooooo`;o00000oooool2o`0000Cooooo0_l0
0005ooooo`;o00000oooool6o`0000gooooo0_l0000Fooooo`;o00002_ooool3o`0000?ooooo0_l0
0002ooooo`Go000000Coooooo`000?l0003o00001?ooool2o`0000cooooo0_l00004ooooo`;o0000
00Coooooo`000?l0003ooooo0_l0000=ooooo`;o0000Eoooool001cooooo0_l0000nooooo`;o0000
0_ooool2o`0000Kooooo1?l00002ooooo`;o00004Oooool2o`0000Gooooo0_l00009ooooo`?o0000
0_ooool2o`000004ooooool0003o0000o`0000gooooo0_l00002ooooo`?o00004Oooool2o`0000;o
oooo0_l00007ooooo`;o00000oooool2o`0000?ooooo1?l00002ooooo`;o000000?oooooo`000?l0
00003Oooool2o`0000;ooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l0000=oooo
o`;o00004oooool2o`0004;ooooo000Looooo`03o`000?oooooooooo03gooooo0_l00002ooooo`;o
00001_ooool3o`000003ooooool0003o000000;o00004Oooool4o`0000?ooooo0_l00009ooooo`?o
00004Oooool2o`000003ooooool0003o000000?ooooo0ol00003ooooo`;o000000?oooooo`000?l0
00000_ooool2o`0000Wooooo1?l0000@ooooo`;o00001_ooool2o`0000Oooooo0_l00004ooooo`;o
00000_ooool2o`000003ooooool0003o000000?ooooo0_l0000=ooooo`;o00005Oooool2o`0004;o
oooo000Looooo`03o`000?oooooooooo04gooooo0_l0000;ooooo`;o000000?oooooo`000?l00000
1Oooool2o`000003ooooool0003o000000;o00002Oooool2o`0000?ooooo0_l0000=ooooo`Go0000
1?ooool2o`0000?ooooo0_l000000ooooooo0000o`000004o`0000_ooooo0_l0000@ooooo`;o0000
0oooool3o`0000Wooooo0_l0000;ooooo`;o00000oooool2o`0000Cooooo0_l00007ooooo`;o0000
FOooool001cooooo00?o0000ooooooooool0C?ooool3o`0000?ooooo0_l00006ooooo`;o000000?o
ooooo`000?l000001Oooool7o`0000kooooo0_l00009ooooo`;o00000_ooool4o`0000Cooooo1Ol0
0006ooooo`;o00000oooool2o`00013ooooo0_l0000=ooooo`?o00006?ooool3o`0000Kooooo0_l0
001Rooooo`007?ooool00ol0003oooooooooo`1:ooooo`Co00001?ooool2o`0000Kooooo1?l00006
ooooo`Go00002?ooool2o`00017ooooo0ol00003ooooo`;o00001?ooool9o`0000Oooooo0_l0000@
ooooo`;o00001_ooool2o`0000Wooooo0_l00009ooooo`;o00001Oooool2o`0000?ooooo0ol0000<
ooooo`;o0000G?ooool001cooooo00?o0000ooooooooool0B_ooool5o`0000Wooooo1_l00007oooo
o`?o00002Oooool2o`0001;ooooo0_l0000>ooooo`Co00002?ooool2o`0000Sooooo0_l0000=oooo
o`;o00002Oooool2o`0000?ooooo0ol00003ooooo`;o00001Oooool2o`0000_ooooo0_l00005oooo
o`;o00000_ooool2o`0005Sooooo000Looooo`03o`000?oooooooooo04gooooo0_l00007ooooo`Ko
00002Oooool2o`000003ooooool0003o000000Oooooo0_l0000Aooooo`Co00001?ooool4o`0000Ko
oooo0_l00009ooooo`;o00001oooool4o`000003ooooool0003o000000;o000000?oooooo`000?l0
00005?ooool3o`0000Kooooo0_l0000?ooooo`;o00002Oooool2o`0001Cooooo0_l00012ooooo`00
7?ooool00ol0003oooooooooo`1Fooooo`;o00002?ooool2o`0000Kooooo0_l0000:ooooo`;o0000
3_ooool4o`0000Cooooo1?l00006ooooo`;o00003_ooool2o`0000;ooooo1?l000000ooooooo0000
o`000005o`00013ooooo0_l00005ooooo`;o00000oooool3o`0000Cooooo0_l0000?ooooo`;o0000
0oooool2o`0001Cooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00002?oo
ool2o`0000Oooooo0_l0000Booooo`Co00000_ooool2o`0000oooooo0_l0000Iooooo`;o00000_oo
ool2o`000003ooooool0003o000000?o000000?oooooo`000?l000001oooool2o`0000Kooooo1?l0
0005ooooo`;o00000oooool2o`0000Gooooo0_l00002ooooo`Co00002Oooool2o`000003ooooool0
003o000005[ooooo000Looooo`03o`000?oooooooooo04gooooo0_l00008ooooo`;o00004_ooool4
o`0000Oooooo0_l00002ooooo`;o00003?ooool2o`000003ooooool0003o000000_ooooo1?l00007
ooooo`;o00001Oooool2o`000003ooooool0003o000000gooooo0_l00006ooooo`?o00005_ooool4
o`0000[ooooo1?l0001Jooooo`007?ooool00ol0003oooooooooo`1[ooooo`Co00003Oooool3o`00
00Wooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000001_l000000ooo
oooo0000o`000004ooooo`;o00000oooool2o`0000?ooooo0_l0000looooo`Ko0000F?ooool001co
oooo00?o0000ooooooooool0HOooool2o`0000Sooooo0_l0000?ooooo`Co00004Oooool2o`000003
ooooool0003o000000;o000000?oooooo`000?l000000_ooool2o`0000Sooooo0ol00003ooooo`Co
000000?oooooo`000?l00000;?ooool2o`0000gooooo0_l0000?ooooo`;o0000Aoooool001cooooo
00?o0000ooooooooool0F?ooool2o`0000Oooooo0_l00008ooooo`;o00004Oooool5o`0001Kooooo
0_l00002ooooo`Go00001Oooool2o`0000Kooooo0_l000000ooooooo0000o`000008ooooo`;o0000
5Oooool2o`000003ooooool0003o000000Oooooo0ol00007ooooo`;o00005Oooool2o`0004Oooooo
000Looooo`03o`000?oooooooooo05Kooooo1?l0000Fooooo`;o00003_ooool4o`0000oooooo0_l0
0004ooooo`?o000000?oooooo`000?l000001?l000000ooooooo0000o`00000<ooooo`;o00002?oo
ool2o`0001Gooooo1Ol00007ooooo`;o00002?ooool2o`0005kooooo000Looooo`03o`000?oooooo
oooo053ooooo0_l00004ooooo`Oo00001_ooool4o`0000Wooooo0_l0000;ooooo`;o00000oooool2
o`0000kooooo0ol00004ooooo`?o00000_ooool5o`000003ooooool0003o000000Cooooo0_l00006
ooooo`;o00003Oooool2o`000003ooooool0003o000000?ooooo0ol00008ooooo`;o0000Loooool0
01cooooo00?o0000ooooooooool0D?ooool2o`0000Kooooo1Ol00003ooooo`;o000000?oooooo`00
0?l000001?l0000:ooooo`;o00002?ooool2o`0001;ooooo0ol00002ooooo`;o00000_ooool2o`00
0004ooooool0003o0000ooooo`?o00000oooool2o`0000;ooooo0_l0000<ooooo`;o00001oooool2
o`000003ooooool0003o000000?ooooo0ol00009ooooo`;o000000?oooooo`000?l00000Koooool0
01cooooo0_l0001Qooooo`;o00001Oooool2o`0000Wooooo0ol0000=ooooo`;o00002_ooool2o`00
0003ooooool0003o000000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000001oooool2o`00
00;ooooo0_l00006ooooo`;o00001?ooool3o`0000;ooooo0_l0000;ooooo`;o00001_ooool2o`00
0003ooooool0003o000000?o0000Koooool001cooooo00?o0000ooooooooool0J?ooool4o`0000Ko
oooo0_l0000=ooooo`?o00002_ooool2o`0000Sooooo0_l00002ooooo`;o00003?ooool2o`0000Ko
oooo0_l00005ooooo`co00002Oooool2o`0000;ooooo0ol000000ooooooo0000o`000002o`0006oo
oooo000Looooo`03o`000?oooooooooo06Sooooo1?l00006ooooo`;o00003Oooool2o`0000?ooooo
0_l0000@ooooo`;o00000_ooool2o`0000cooooo1?l00002ooooo`;o00001_ooool=o`0000?ooooo
0_l00003ooooo`?o00000oooool2o`000003ooooool0003o000000;o00001Oooool2o`0000;ooooo
0_l000000ooooooo0000o`00001Qooooo`007?ooool00ol0003oooooooooo`1Zooooo`;o00006_oo
ool2o`0000[ooooo0_l00002ooooo`Co00001Oooool4o`0000Sooooo1ol000001?oooooo0000o`00
0?ooool=o`0000Gooooo1?l000000ooooooo0000o`000004o`0000?ooooo0ol00006ooooo`;o0000
0_ooool2o`000003ooooool0003o0000067ooooo000Looooo`03o`000?oooooooooo09;ooooo2?l0
00000ooooooo0000o`000002ooooo`Co00002?ooool2o`000003ooooool0003o000000;o000000Co
ooooo`000?l0003ooooo0_l00002ooooo`Wo00001oooool2o`0000Cooooo0ol0000<ooooo`;o0000
J?ooool001cooooo00?o0000ooooooooool0Eoooool2o`0000gooooo0_l0000Hooooo`;o00004_oo
ool4o`0000?ooooo0_l0000Aooooo`Co000000Coooooo`000?l0003ooooo0ol000001?oooooo0000
o`000?ooool2o`0000Oooooo0_l00003ooooo`;o00003?ooool2o`0000Cooooo0_l0001Xooooo`00
7?ooool00ol0003oooooooooo`1Gooooo`;o00003Oooool2o`0000Oooooo0_l0000:ooooo`;o0000
0oooool2o`0000?ooooo0_l0000;ooooo`;o00000_ooool5o`000003ooooool0003o000000Gooooo
0_l00009ooooo`Co000000?oooooo`000?l000001?l000001?oooooo0000o`000?ooool2o`0000Co
oooo0_l000000ooooooo0000o`000003ooooo`;o00003?ooool2o`0006kooooo000Looooo`03o`00
0?oooooooooo06Cooooo0_l00009ooooo`;o00002_ooool2o`0000;ooooo0_l00004ooooo`;o0000
2oooool2o`0000?ooooo1?l000000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l00000
1oooool3o`0000?ooooo0_l00003ooooo`;o00001oooool2o`000004ooooool0003o0000o`0000Ko
oooo0_l0000Pooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0G?ooool2o`0000;ooooo
0_l00002ooooo`;o00002_ooool2o`0000cooooo0ol00002ooooo`?o00002_ooool2o`0000Kooooo
0_l00002ooooo`;o00002?ooool2o`0000Oooooo0ol0000Eooooo`;o00001Oooool3o`00023ooooo
0_l0001Fooooo`007?ooool00ol0003oooooooooo`1Looooo`;o00000_ooool2o`0000kooooo0_l0
000<ooooo`;o00000oooool3o`0000Sooooo1?l000000ooooooo0000o`000003ooooo`;o00005Ooo
ool3o`0001cooooo0_l0001iooooo`007?ooool00ol0003oooooooooo`1Rooooo`;o00001oooool2
o`0001gooooo0ol000000ooooooo0000o`000003ooooo`;o00000oooool2o`0000[ooooo0_l00003
ooooo`?o00005oooool2o`0000Kooooo0_l0001looooo`007?ooool00ol0003oooooooooo`1Roooo
o`;o00001oooool2o`0000kooooo0_l0000=ooooo`?o00004Oooool4o`0000;ooooo0_l00003oooo
o`?o00001Oooool2o`0000oooooo0ol00006ooooo`;o0000O?ooool001cooooo00?o0000oooooooo
ool0Goooool2o`0000?ooooo0_l00006ooooo`;o00003Oooool2o`0000[ooooo0_l0000Eooooo`Ko
00002?ooool2o`0000;ooooo0ol0000?ooooo`;o0000QOooool001cooooo00?o0000ooooooooool0
Goooool3o`0000;ooooo0_l00006ooooo`;o00006?ooool3o`0000Sooooo1Ol0000<ooooo`;o0000
0oooool2o`0000?ooooo0_l00002ooooo`?o00000_ooool2o`0001Kooooo0_l0000Eooooo`;o0000
Hoooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0
003o8B4Qolc<c006ooooo`03o`000?oooooooooo063ooooo0_l00003ooooo`;o00001_ooool2o`00
017ooooo0_l00004ooooo`;o00002Oooool5o`0000gooooo0_l00002ooooo`;o00003?ooool2o`00
01Kooooo0_l0000Eooooo`;o0000Hoooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo06Gooooo0_l0
0005ooooo`?o00004Oooool2o`0000Wooooo0_l0000Fooooo`;o00007_ooool2o`0008Cooooo0000
0ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo06Oooooo0_l00003ooooo`;o00001_ooool2o`000003ooooool0
003o000000Oooooo0_l00009ooooo`;o00005oooool2o`0001Sooooo0_l00003ooooo`;o00000_oo
ool2o`0001Wooooo0_l0001Uooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09
ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`0006Oooooo0_l0000;ooooo`;o000000?o
ooooo`000?l000000oooool2o`0000;ooooo0_l00007ooooo`;o00006Oooool2o`0000cooooo0_l0
000:ooooo`;o00000oooool2o`0000;ooooo0_l0000Booooo`;o00001Oooool2o`0006Gooooo0000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Goc<c<o`000?l0003o0000olc<
c006ooooo`03o`000?oooooooooo06Oooooo0_l0000Cooooo`;o00001oooool2o`0000;ooooo0_l0
000Wooooo`;o00009oooool2o`0006cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooo
oooo00Wooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo06Oooooo1?l0
000Jooooo`;o00000_ooool4o`0000[ooooo1?l0000Gooooo`;o00009_ooool2o`0006gooooo0000
1_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03
o`000?oooooooooo06Wooooo0_l00006ooooo`;o00006?ooool2o`0000[ooooo1?l00004ooooo`;o
00008_ooool2o`0000;ooooo0_l0000Aooooo`;o0000KOooool00006ooooooo^k^ko<S8bo`000?lb
<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0LOooool2
o`0000Kooooo0_l0000;ooooo`;o00001?ooool2o`00017ooooo0_l00007ooooo`;o000000?ooooo
o`000?l000005_ooool2o`0000;ooooo0_l00020ooooo`007?ooool00ol0003oooooooooo`1_oooo
o`;o00002?ooool2o`0000Oooooo0_l00002ooooo`;o00001?ooool2o`0001[ooooo0_l000001?oo
oooo0000o`000?l0000Cooooo`;o0000Q_ooool001cooooo00?o0000ooooooooool0Koooool2o`00
00Kooooo0_l00009ooooo`Ko00004?ooool2o`0000;ooooo0_l0000>ooooo`;o000000?oooooo`00
0?l000003oooool3o`0008Kooooo000Looooo`03o`000?oooooooooo06oooooo0_l00004ooooo`Co
00002oooool2o`0000Kooooo0_l0000:ooooo`;o00000_ooool2o`0000Gooooo0_l000000ooooooo
0000o`000007ooooo`Go00003?ooool2o`000003ooooool0003o000008Cooooo000Looooo`03o`00
0?oooooooooo07Gooooo0_l00007ooooo`?o00001_ooool3o`0000;ooooo0_l0000Eooooo`;o0000
00Coooooo`000?l0003ooooo0_l00002ooooo`;o00000_ooool3o`0000oooooo0_l00007ooooo`;o
0000Noooool001cooooo00?o0000ooooooooool0O_ooool3o`0000Kooooo0ol0000Oooooo`;o0000
0_ooool2o`0001Kooooo0_l00005ooooo`;o0000Noooool001cooooo00?o0000ooooooooool0M?oo
ool2o`0002_ooooo0_l0000Rooooo`;o0000P_ooool001cooooo00?o0000ooooooooool0M?ooool2
o`0002;ooooo0_l00007ooooo`;o0000Y_ooool001cooooo00?o0000ooooooooool0OOooool6o`00
00gooooo0_l00006ooooo`;o00004oooool4o`0009Sooooo000Looooo`03o`000?oooooooooo07go
oooo1ol00003ooooo`;o00001oooool2o`0000_ooooo1?l00002ooooo`;o00002?ooool6o`0009Ko
oooo000Looooo`03o`000?oooooooooo08;ooooo0_l00003ooooo`;o00005?ooool4o`0000;ooooo
0_l0000<ooooo`;o0000U_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2
o`0007kooooo0_l0003:ooooo`007?ooool00ol0003oooooooooo`1mooooo`;o0000b_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0S_ooool2
o`000;Wooooo000Looooo`03o`000?oooooooooo08Sooooo0_l00004ooooo`;o0000^Oooool001co
oooo00?o0000ooooooooool0R?ooool2o`000;oooooo000Looooo`03o`000?oooooooooo08gooooo
0_l0002jooooo`007?ooool00ol0003oooooooooo`2=ooooo`;o0000^_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Booooo`Co000000?o410@oooo
ooooool00oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`?o0000
oooooom:ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooo
oooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003o
ooooooooo`3ooooooe;ooooo000Booooo`03oeEEEOmVIVKo00000?ooooooE?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00:Gooooo00Co410@o`000?l0003ooooo0_l000000ol@
413oooooooooo`0Gooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@02
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0T?ooool00:Kooooo00Go0000ooooooooooooooooo`00
0009ooooo`Ko00002oooool00omEEEGoZJVYooooo`07ooooo`09ogMgMolb<S;ooooooooooomgMgOo
V9RHoooooonHV9SoMgMg093ooooo002Vooooo`05o`000?ooooooooooooooool000006_ooool00onY
ZJWoEEEEooooo`08ooooo`04o`000?oooooooooooa0@40?ooooo00?o410@ooooooooool0S_ooool0
0:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00003?ooool00olQ8B7oooooooooo`06
ooooo`05ogMgMolb<S;oooooooooool000000oooool00ol0003oooooooooo`2>ooooo`00Y_ooool0
1Ol0003oQhN7oooooonYZJWo000001_ooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`00002@ooooo`00YOooool00ol@413o0000
ogMgM`02o`000003oiRHV?oooooooooo01Wooooo00?oZJVYogMgMoooool00oooool00ol0003ooooo
ooooo`04ooooo`05oa0@4?ooooooooooooooool@4100T?ooool00<?ooooo00Go410@oooooooooooo
oooooc8b<P04ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`2@oooo
o`00`oooool5o`0000Cooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0T?ooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(756) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.68727 .47762 Mdot
.689 .4638 Mdot
.36672 .41731 Mdot
.51751 .6132 Mdot
.42711 .55104 Mdot
.31958 .443 Mdot
.48649 .36178 Mdot
.52642 .37234 Mdot
.34127 .44702 Mdot
.66025 .54018 Mdot
.46734 .36839 Mdot
.60877 .68402 Mdot
.49396 .36901 Mdot
.5633 .64621 Mdot
.32243 .22562 Mdot
.60969 .60285 Mdot
.6887 .41927 Mdot
.3838 .62959 Mdot
.57776 .55616 Mdot
.36388 .44611 Mdot
.71371 .48157 Mdot
.56673 .64302 Mdot
.69878 .45816 Mdot
.56342 .64454 Mdot
.52753 .62378 Mdot
.66025 .4506 Mdot
.71026 .4616 Mdot
.54598 .59769 Mdot
.54088 .64639 Mdot
.48888 .33859 Mdot
.38599 .53903 Mdot
.1961 .3566 Mdot
.61722 .62764 Mdot
.66332 .73895 Mdot
.51802 .35277 Mdot
.26571 .68139 Mdot
.35335 .4295 Mdot
.49016 .39856 Mdot
.52348 .3596 Mdot
.51783 .37802 Mdot
.50245 .38887 Mdot
.66184 .45597 Mdot
.45604 .36564 Mdot
.54712 .3549 Mdot
.51912 .60226 Mdot
.58722 .30873 Mdot
.30504 .66043 Mdot
.5517 .60022 Mdot
.66043 .47572 Mdot
.35457 .46173 Mdot
.73942 .71002 Mdot
.50346 .40361 Mdot
.46481 .25059 Mdot
.28469 .18399 Mdot
.51075 .36614 Mdot
.52557 .60037 Mdot
.33411 .42341 Mdot
.58108 .62009 Mdot
.56624 .62611 Mdot
.74709 .67706 Mdot
.54203 .62464 Mdot
.3814 .59451 Mdot
.71069 .4118 Mdot
.33404 .38666 Mdot
.3311 .44543 Mdot
.50952 .34469 Mdot
.65953 .41763 Mdot
.48837 .37682 Mdot
.49092 .64432 Mdot
.34957 .45727 Mdot
.55259 .59827 Mdot
.46868 .37517 Mdot
.63206 .44088 Mdot
.58508 .66398 Mdot
.62205 .32534 Mdot
.391 .19938 Mdot
.3547 .63162 Mdot
.73255 .66685 Mdot
.78612 .43346 Mdot
.39796 .23534 Mdot
.55363 .64591 Mdot
.77261 .29405 Mdot
.33924 .21665 Mdot
.69755 .452 Mdot
.47425 .68089 Mdot
.37945 .38794 Mdot
.57607 .66253 Mdot
.43259 .50492 Mdot
.54139 .68927 Mdot
.6976 .35497 Mdot
.34577 .44358 Mdot
.65551 .46243 Mdot
.51413 .61606 Mdot
.60318 .6396 Mdot
.75603 .54609 Mdot
.5593 .68412 Mdot
.54957 .58831 Mdot
.71844 .45714 Mdot
.47881 .3481 Mdot
.54764 .70102 Mdot
.53495 .3227 Mdot
.472 .24223 Mdot
.52407 .65639 Mdot
.33123 .45555 Mdot
.70118 .4188 Mdot
.51499 .65024 Mdot
.51263 .35848 Mdot
.55022 .62821 Mdot
.51099 .31385 Mdot
.68115 .47414 Mdot
.602 .64111 Mdot
.38863 .62474 Mdot
.67558 .32517 Mdot
.64513 .44654 Mdot
.67478 .23773 Mdot
.54693 .61655 Mdot
.57079 .63746 Mdot
.68764 .46209 Mdot
.31925 .41361 Mdot
.41889 .49952 Mdot
.6479 .42119 Mdot
.52234 .36891 Mdot
.7062 .45846 Mdot
.497 .6275 Mdot
.30663 .43856 Mdot
.46985 .23613 Mdot
.49091 .23951 Mdot
.48751 .78695 Mdot
.5678 .66641 Mdot
.50198 .28782 Mdot
.31313 .43438 Mdot
.66709 .46529 Mdot
.49124 .3779 Mdot
.55941 .57842 Mdot
.68045 .42369 Mdot
.48604 .39042 Mdot
.38924 .61908 Mdot
.24635 .5508 Mdot
.63941 .45857 Mdot
.56344 .48043 Mdot
.49538 .32387 Mdot
.51697 .37791 Mdot
.673 .75998 Mdot
.69078 .45783 Mdot
.36211 .60876 Mdot
.48455 .38728 Mdot
.44017 .69917 Mdot
.56063 .57946 Mdot
.56122 .77176 Mdot
.8034 .36922 Mdot
.72183 .73152 Mdot
.56525 .2229 Mdot
.3689 .57734 Mdot
.50216 .39869 Mdot
.51878 .63469 Mdot
.68496 .4496 Mdot
.67663 .45472 Mdot
.60207 .61378 Mdot
.53362 .61852 Mdot
.58609 .59652 Mdot
.59965 .61418 Mdot
.29597 .6443 Mdot
.59077 .59987 Mdot
.29409 .4588 Mdot
.6536 .42798 Mdot
.53113 .63341 Mdot
.33973 .40061 Mdot
.58671 .57299 Mdot
.48705 .39603 Mdot
.57062 .62505 Mdot
.53065 .61171 Mdot
.55178 .67834 Mdot
.50331 .39208 Mdot
.17915 .43445 Mdot
.78128 .35623 Mdot
.18998 .58232 Mdot
.60625 .23338 Mdot
.32417 .42323 Mdot
.57597 .65557 Mdot
.37953 .60963 Mdot
.49952 .55946 Mdot
.56235 .62506 Mdot
.78841 .65419 Mdot
.53847 .60502 Mdot
.65306 .70893 Mdot
.58905 .54898 Mdot
.17504 .56868 Mdot
.45008 .43402 Mdot
.54115 .64233 Mdot
.73309 .51758 Mdot
.58481 .78172 Mdot
.46805 .56903 Mdot
.50758 .37902 Mdot
.32894 .40086 Mdot
.3424 .42181 Mdot
.45745 .35237 Mdot
.52277 .68872 Mdot
.64564 .5465 Mdot
.52883 .69859 Mdot
.47287 .23174 Mdot
.64281 .41748 Mdot
.34803 .59059 Mdot
.64478 .47003 Mdot
.69896 .21877 Mdot
.64033 .37924 Mdot
.52183 .33417 Mdot
.40034 .62074 Mdot
.35196 .4004 Mdot
.47296 .22722 Mdot
.37362 .61228 Mdot
.56261 .59688 Mdot
.65931 .47246 Mdot
.60172 .783 Mdot
.57726 .55096 Mdot
.46522 .83709 Mdot
.69782 .43361 Mdot
.45257 .46811 Mdot
.50074 .38135 Mdot
.35309 .46885 Mdot
.55974 .66133 Mdot
.59276 .61367 Mdot
.71711 .42439 Mdot
.55162 .60423 Mdot
.74343 .40378 Mdot
.53125 .6076 Mdot
.31969 .38277 Mdot
.33773 .57835 Mdot
.46652 .39572 Mdot
.50308 .78732 Mdot
.62959 .4642 Mdot
.26987 .43939 Mdot
.36193 .44061 Mdot
.6554 .52488 Mdot
.46594 .36418 Mdot
.39256 .61858 Mdot
.35663 .41869 Mdot
.3743 .56857 Mdot
.53268 .66454 Mdot
.35526 .43428 Mdot
.35192 .59709 Mdot
.22079 .53026 Mdot
.53028 .59184 Mdot
.40161 .66291 Mdot
.48132 .36514 Mdot
.69848 .47385 Mdot
.54117 .6256 Mdot
.49192 .24033 Mdot
.51388 .58866 Mdot
.50177 .24354 Mdot
.47391 .25484 Mdot
.46524 .24841 Mdot
.3701 .23124 Mdot
.38868 .58861 Mdot
.59509 .26723 Mdot
.57704 .44419 Mdot
.66284 .41568 Mdot
.51415 .61192 Mdot
.1656 .4906 Mdot
.4862 .38783 Mdot
.56366 .59851 Mdot
.35696 .37877 Mdot
.4833 .38532 Mdot
.58404 .62794 Mdot
.50921 .38523 Mdot
.68267 .45266 Mdot
.34994 .5029 Mdot
.70769 .43217 Mdot
.53214 .59309 Mdot
.50404 .35488 Mdot
.34503 .41004 Mdot
.66186 .4485 Mdot
.55306 .62559 Mdot
.57058 .65392 Mdot
.47914 .23181 Mdot
.53325 .63939 Mdot
.17273 .49383 Mdot
.54852 .59718 Mdot
.33942 .39215 Mdot
.55577 .68613 Mdot
.72482 .74401 Mdot
.2515 .54449 Mdot
.64625 .4292 Mdot
.47007 .25166 Mdot
.34275 .44018 Mdot
.34171 .51224 Mdot
.51277 .51598 Mdot
.55223 .63826 Mdot
.48052 .24868 Mdot
.42611 .47269 Mdot
.50679 .34221 Mdot
.52554 .67861 Mdot
.64646 .36591 Mdot
.36314 .42726 Mdot
.47415 .22902 Mdot
.62323 .61295 Mdot
.70536 .42133 Mdot
.51963 .61247 Mdot
.35564 .4261 Mdot
.70554 .46133 Mdot
.53704 .5797 Mdot
.3062 .68051 Mdot
.48482 .2538 Mdot
.48151 .36727 Mdot
.62186 .54545 Mdot
.57777 .58895 Mdot
.33787 .41501 Mdot
.69518 .44069 Mdot
.50577 .34841 Mdot
.65157 .44756 Mdot
.58693 .78638 Mdot
.62112 .24723 Mdot
.25739 .61936 Mdot
.39751 .62515 Mdot
.49617 .20901 Mdot
.19896 .60388 Mdot
.62812 .27275 Mdot
.43789 .74784 Mdot
.25991 .71275 Mdot
.34598 .40445 Mdot
.43509 .64347 Mdot
.33948 .43417 Mdot
.52232 .64714 Mdot
.32385 .44506 Mdot
.16526 .5603 Mdot
.54055 .59912 Mdot
.32696 .42103 Mdot
.30379 .58418 Mdot
.53672 .62146 Mdot
.64589 .43677 Mdot
.26502 .28095 Mdot
.76843 .38376 Mdot
.62076 .40462 Mdot
.32133 .41773 Mdot
.81293 .56349 Mdot
.54296 .60607 Mdot
.60344 .58523 Mdot
.68058 .44702 Mdot
.53078 .68388 Mdot
.3482 .60662 Mdot
.38431 .57193 Mdot
.562 .76531 Mdot
.71462 .28016 Mdot
.49203 .66383 Mdot
.66593 .4489 Mdot
.784 .44576 Mdot
.61907 .32711 Mdot
.48582 .2186 Mdot
.51643 .34044 Mdot
.18377 .42952 Mdot
.49125 .58324 Mdot
.5631 .48565 Mdot
.63934 .36324 Mdot
.66524 .47081 Mdot
.20144 .52023 Mdot
.50792 .36516 Mdot
.75932 .47634 Mdot
.68341 .64486 Mdot
.58195 .59756 Mdot
.47606 .34182 Mdot
.58663 .69783 Mdot
.72289 .37067 Mdot
.44321 .67385 Mdot
.45263 .28217 Mdot
.5258 .5962 Mdot
.60198 .27755 Mdot
.56984 .63253 Mdot
.5409 .76168 Mdot
.55244 .59148 Mdot
.65281 .44088 Mdot
.50372 .68417 Mdot
.46324 .51327 Mdot
.75658 .31738 Mdot
.65687 .37258 Mdot
.36992 .57479 Mdot
.57119 .64953 Mdot
.58595 .60229 Mdot
.37122 .58361 Mdot
.66583 .43733 Mdot
.55801 .58801 Mdot
.37302 .74955 Mdot
.57948 .59198 Mdot
.48573 .39742 Mdot
.38758 .52378 Mdot
.60833 .4633 Mdot
.59425 .65438 Mdot
.71401 .43965 Mdot
.51252 .37466 Mdot
.52576 .36083 Mdot
.49666 .58659 Mdot
.50249 .39734 Mdot
.52238 .6096 Mdot
.37821 .51749 Mdot
.69515 .46466 Mdot
.62856 .61514 Mdot
.66922 .43375 Mdot
.80769 .48797 Mdot
.51492 .37573 Mdot
.48183 .22008 Mdot
.53558 .52451 Mdot
.50046 .3626 Mdot
.76383 .40149 Mdot
.47883 .60474 Mdot
.54212 .56879 Mdot
.76582 .39611 Mdot
.32956 .40604 Mdot
.47364 .22166 Mdot
.50913 .35426 Mdot
.58292 .59258 Mdot
.52906 .66789 Mdot
.46612 .37465 Mdot
.77369 .55645 Mdot
.34387 .51951 Mdot
.54899 .59105 Mdot
.65627 .4384 Mdot
.66377 .46345 Mdot
.52988 .58308 Mdot
.55807 .62103 Mdot
.33467 .39274 Mdot
.4846 .24868 Mdot
.46408 .23318 Mdot
.49053 .23422 Mdot
.32671 .46988 Mdot
.51645 .23934 Mdot
.51672 .37913 Mdot
.53237 .27659 Mdot
.35906 .3541 Mdot
.52098 .56701 Mdot
.33739 .41185 Mdot
.59144 .62649 Mdot
.5291 .65508 Mdot
.50251 .34814 Mdot
.56779 .19208 Mdot
.57616 .71899 Mdot
.65701 .48061 Mdot
.49048 .40287 Mdot
.56356 .5331 Mdot
.46786 .424 Mdot
.35209 .61094 Mdot
.65789 .37962 Mdot
.47059 .347 Mdot
.651 .46252 Mdot
.4624 .36797 Mdot
.58539 .59958 Mdot
.59992 .59925 Mdot
.68243 .46958 Mdot
.38907 .58779 Mdot
.52254 .66582 Mdot
.58325 .62923 Mdot
.80952 .66716 Mdot
.62229 .32015 Mdot
.46012 .41717 Mdot
.52906 .64408 Mdot
.52995 .56984 Mdot
.37832 .57459 Mdot
.57286 .59041 Mdot
.56282 .6616 Mdot
.68769 .3251 Mdot
.45297 .35979 Mdot
.34099 .61176 Mdot
.75796 .47159 Mdot
.69551 .43184 Mdot
.18551 .47493 Mdot
.47116 .24389 Mdot
.4585 .3925 Mdot
.35195 .50148 Mdot
.48178 .22461 Mdot
.38708 .35281 Mdot
.19376 .49552 Mdot
.48623 .22528 Mdot
.36335 .48828 Mdot
.48552 .68707 Mdot
.58222 .58228 Mdot
.57367 .62527 Mdot
.3801 .6134 Mdot
.68965 .45499 Mdot
.44196 .44658 Mdot
.22168 .49072 Mdot
.56818 .64095 Mdot
.73147 .43682 Mdot
.20291 .46218 Mdot
.4784 .22857 Mdot
.3873 .59689 Mdot
.34525 .59392 Mdot
.57206 .63507 Mdot
.67044 .29855 Mdot
.66251 .45086 Mdot
.55327 .62582 Mdot
.59932 .63544 Mdot
.32379 .41445 Mdot
.65024 .46515 Mdot
.36099 .44226 Mdot
.47815 .257 Mdot
.34177 .7822 Mdot
.79194 .6889 Mdot
.48874 .34969 Mdot
.19464 .56917 Mdot
.52458 .38844 Mdot
.42707 .23428 Mdot
.48966 .23861 Mdot
.55882 .63373 Mdot
.63059 .45586 Mdot
.55017 .62598 Mdot
.57419 .59784 Mdot
.56499 .59538 Mdot
.49582 .67089 Mdot
.78256 .66345 Mdot
.36908 .60297 Mdot
.50981 .58125 Mdot
.31022 .40417 Mdot
.18297 .53302 Mdot
.25201 .31113 Mdot
.59108 .64339 Mdot
.57416 .63934 Mdot
.66646 .41893 Mdot
.60521 .64636 Mdot
.49518 .33709 Mdot
.69878 .44728 Mdot
.52404 .66311 Mdot
.20934 .54056 Mdot
.56668 .58516 Mdot
.20841 .61519 Mdot
.46323 .37033 Mdot
.65337 .38253 Mdot
.49652 .60338 Mdot
.48682 .22515 Mdot
.47474 .2212 Mdot
.4814 .2126 Mdot
.49195 .33344 Mdot
.33135 .4163 Mdot
.24017 .42474 Mdot
.5951 .68386 Mdot
.51876 .62917 Mdot
.5223 .57442 Mdot
.35372 .47261 Mdot
.4075 .52229 Mdot
.57061 .23469 Mdot
.51981 .55025 Mdot
.31407 .40629 Mdot
.68608 .48521 Mdot
.64934 .20876 Mdot
.69748 .44505 Mdot
.33897 .60752 Mdot
.47735 .38783 Mdot
.35487 .61599 Mdot
.80781 .60487 Mdot
.68603 .47002 Mdot
.71802 .42579 Mdot
.32516 .42152 Mdot
.47511 .45599 Mdot
.17144 .31464 Mdot
.32279 .45619 Mdot
.41472 .76596 Mdot
.67573 .4456 Mdot
.58144 .67091 Mdot
.41782 .47743 Mdot
.47595 .46003 Mdot
.32992 .43218 Mdot
.55664 .64923 Mdot
.71665 .29547 Mdot
.33831 .39355 Mdot
.52622 .67749 Mdot
.3121 .42535 Mdot
.49843 .3913 Mdot
.31306 .43087 Mdot
.64882 .48515 Mdot
.53357 .66296 Mdot
.2352 .23274 Mdot
.54642 .41637 Mdot
.54325 .62723 Mdot
.49128 .40258 Mdot
.36035 .75115 Mdot
.58182 .60645 Mdot
.34991 .61211 Mdot
.30211 .42358 Mdot
.32139 .53526 Mdot
.54294 .61011 Mdot
.32184 .43725 Mdot
.66936 .48498 Mdot
.47194 .41463 Mdot
.3897 .21731 Mdot
.46678 .22684 Mdot
.68975 .44845 Mdot
.46864 .20821 Mdot
.49179 .32727 Mdot
.54242 .68014 Mdot
.59964 .6243 Mdot
.6528 .43278 Mdot
.35775 .27059 Mdot
.59669 .6677 Mdot
.55377 .64587 Mdot
.36443 .41623 Mdot
.36484 .47398 Mdot
.29631 .29876 Mdot
.34423 .40446 Mdot
.52476 .5718 Mdot
.65184 .43463 Mdot
.5172 .64468 Mdot
.64594 .43428 Mdot
.51412 .61263 Mdot
.65457 .39757 Mdot
.69573 .44848 Mdot
.6599 .25076 Mdot
.54504 .65774 Mdot
.60361 .54659 Mdot
.57164 .59546 Mdot
.5583 .59273 Mdot
.30067 .4303 Mdot
.36551 .59028 Mdot
.55972 .68985 Mdot
.28596 .46199 Mdot
.39084 .60714 Mdot
.62486 .74326 Mdot
.32353 .41272 Mdot
.37805 .61803 Mdot
.34927 .66277 Mdot
.46913 .25017 Mdot
.37654 .60147 Mdot
.24251 .33914 Mdot
.49201 .34856 Mdot
.70511 .45193 Mdot
.53594 .62245 Mdot
.29255 .75049 Mdot
.37813 .53459 Mdot
.48376 .23744 Mdot
.54498 .61569 Mdot
.58987 .62026 Mdot
.69326 .41632 Mdot
.73467 .24982 Mdot
.37343 .43463 Mdot
.51382 .6256 Mdot
.69193 .42163 Mdot
.79919 .35615 Mdot
.30909 .44466 Mdot
.38001 .60405 Mdot
.47489 .39216 Mdot
.66086 .49739 Mdot
.46694 .22517 Mdot
.51169 .34393 Mdot
.38696 .47505 Mdot
.82174 .56149 Mdot
.54746 .60726 Mdot
.34438 .41589 Mdot
.72737 .72603 Mdot
.54009 .69503 Mdot
.44366 .36502 Mdot
.63156 .70943 Mdot
.66223 .46894 Mdot
.47115 .38562 Mdot
.35712 .57641 Mdot
.69911 .46173 Mdot
.66405 .43843 Mdot
.52541 .37697 Mdot
.28443 .4093 Mdot
.45559 .46765 Mdot
.47475 .38896 Mdot
.70215 .35097 Mdot
.60688 .77351 Mdot
.48129 .25018 Mdot
.387 .59237 Mdot
.61387 .78827 Mdot
.66048 .45537 Mdot
.18282 .43093 Mdot
.77136 .67413 Mdot
.54959 .58835 Mdot
.35892 .61221 Mdot
.39024 .36551 Mdot
.2364 .42846 Mdot
.47994 .3813 Mdot
.4278 .51937 Mdot
.3501 .61623 Mdot
.57091 .58156 Mdot
.60782 .4759 Mdot
.54418 .65483 Mdot
.49027 .39267 Mdot
.74932 .39896 Mdot
.64739 .45866 Mdot
.48424 .32803 Mdot
.73428 .38515 Mdot
.53156 .65674 Mdot
.55216 .65508 Mdot
.50067 .75468 Mdot
.659 .47315 Mdot
.46469 .22752 Mdot
.54806 .63532 Mdot
.57901 .6203 Mdot
.5486 .68154 Mdot
.60206 .53375 Mdot
.65874 .30617 Mdot
.51306 .62971 Mdot
.31791 .46284 Mdot
.57446 .56775 Mdot
.55315 .65724 Mdot
.70255 .42515 Mdot
.79781 .6684 Mdot
.48624 .25629 Mdot
.57289 .62185 Mdot
.55284 .59287 Mdot
.5227 .36141 Mdot
.43888 .46787 Mdot
.48452 .45951 Mdot
.34364 .45795 Mdot
.42777 .72643 Mdot
.51764 .68889 Mdot
.6838 .42589 Mdot
.38204 .62773 Mdot
.56562 .67153 Mdot
.68379 .42274 Mdot
.57682 .57347 Mdot
.32773 .39472 Mdot
.48355 .24806 Mdot
.59172 .46135 Mdot
.37845 .5967 Mdot
.41973 .43165 Mdot
.55498 .3041 Mdot
.33565 .39959 Mdot
.52274 .62766 Mdot
.48507 .4124 Mdot
.35476 .4458 Mdot
.48009 .23404 Mdot
.6191 .59377 Mdot
.67405 .45307 Mdot
.6485 .45596 Mdot
.55495 .76542 Mdot
.37694 .43155 Mdot
.85105 .49074 Mdot
.49742 .39163 Mdot
.50144 .62348 Mdot
.54044 .31639 Mdot
.64649 .45233 Mdot
.54283 .77396 Mdot
.3804 .61675 Mdot
.47865 .37856 Mdot
.49496 .23394 Mdot
.67647 .4211 Mdot
.6454 .46532 Mdot
.52643 .59294 Mdot
.58496 .64644 Mdot
.43606 .75319 Mdot
.55536 .76988 Mdot
.50486 .38839 Mdot
.38257 .58645 Mdot
.349 .46132 Mdot
.52906 .64971 Mdot
.69811 .45388 Mdot
.64835 .71501 Mdot
.58284 .58989 Mdot
.33857 .39316 Mdot
.66922 .47022 Mdot
.37504 .58249 Mdot
.37733 .62349 Mdot
.55873 .59264 Mdot
.74327 .66821 Mdot
.49671 .3596 Mdot
.64459 .44383 Mdot
.63947 .51313 Mdot
.58788 .67467 Mdot
.58252 .64909 Mdot
.61681 .67442 Mdot
.5126 .34546 Mdot
.60005 .46245 Mdot
.36662 .63175 Mdot
.6767 .4588 Mdot
.54511 .62752 Mdot
.38154 .595 Mdot
.59463 .50056 Mdot
.48728 .23194 Mdot
.31081 .42866 Mdot
.34711 .60445 Mdot
.35668 .59061 Mdot
.39217 .60899 Mdot
.19183 .4165 Mdot
.63975 .42256 Mdot
.7732 .43574 Mdot
.55517 .58868 Mdot
.5552 .76329 Mdot
.60834 .6331 Mdot
.49077 .33105 Mdot
.33624 .40441 Mdot
.57813 .59826 Mdot
.52505 .59391 Mdot
.64285 .58576 Mdot
.57787 .53627 Mdot
.72636 .46541 Mdot
.67081 .47601 Mdot
.59506 .53811 Mdot
.3285 .40901 Mdot
.78244 .29211 Mdot
.1456 .45886 Mdot
.49312 .6224 Mdot
.44956 .45628 Mdot
.69806 .44975 Mdot
.52226 .38279 Mdot
.49008 .46588 Mdot
.47142 .39159 Mdot
.67551 .4622 Mdot
.52496 .64815 Mdot
.5371 .27646 Mdot
.3887 .57902 Mdot
.58999 .60107 Mdot
.49743 .38394 Mdot
.58801 .59851 Mdot
.48026 .33584 Mdot
.73673 .41086 Mdot
.65307 .35451 Mdot
.53932 .60329 Mdot
.58252 .67515 Mdot
.63512 .56472 Mdot
.59005 .64384 Mdot
.40398 .3174 Mdot
.67672 .43711 Mdot
.71362 .28568 Mdot
.5328 .58328 Mdot
.77355 .61582 Mdot
.58044 .58551 Mdot
.35431 .28276 Mdot
.58409 .65472 Mdot
.49499 .48817 Mdot
.56618 .58068 Mdot
.57296 .65599 Mdot
.507 .3564 Mdot
.52362 .36345 Mdot
.66449 .48436 Mdot
.46713 .22188 Mdot
.17611 .56377 Mdot
.58337 .63713 Mdot
.3108 .46038 Mdot
.55325 .33706 Mdot
.35983 .58973 Mdot
.6711 .4613 Mdot
.82515 .38049 Mdot
.51188 .37942 Mdot
.32459 .38407 Mdot
.37295 .27984 Mdot
.35984 .46051 Mdot
.51732 .31216 Mdot
.57195 .52935 Mdot
.37763 .58051 Mdot
.57903 .58373 Mdot
.66767 .73323 Mdot
.60947 .29694 Mdot
.51196 .65472 Mdot
.46458 .33991 Mdot
.49325 .56358 Mdot
.62584 .77343 Mdot
.3583 .57057 Mdot
.35961 .57813 Mdot
.50947 .35926 Mdot
.36894 .43075 Mdot
.55215 .7061 Mdot
.37818 .61872 Mdot
.32335 .40102 Mdot
.46781 .21687 Mdot
.49176 .53244 Mdot
.66362 .45336 Mdot
.60904 .41471 Mdot
.58732 .34022 Mdot
.50606 .38688 Mdot
.29814 .47618 Mdot
.67528 .4931 Mdot
.69685 .41385 Mdot
.4756 .21727 Mdot
.29995 .42661 Mdot
.6296 .444 Mdot
.52938 .67235 Mdot
.5718 .54826 Mdot
.5687 .63296 Mdot
.36978 .61706 Mdot
.58951 .65303 Mdot
.30549 .40957 Mdot
.486 .38416 Mdot
.35009 .44282 Mdot
.49457 .35724 Mdot
.54152 .25965 Mdot
.556 .61616 Mdot
.57583 .64934 Mdot
.3905 .50332 Mdot
.65146 .47525 Mdot
.76846 .65683 Mdot
.30466 .45642 Mdot
.33681 .42703 Mdot
.51874 .64934 Mdot
.67543 .48409 Mdot
.35337 .55983 Mdot
.39364 .49248 Mdot
.59477 .64552 Mdot
.67813 .43688 Mdot
.51575 .62653 Mdot
.25982 .60786 Mdot
.64196 .34935 Mdot
.65033 .44886 Mdot
.73594 .28759 Mdot
.53624 .64879 Mdot
.46321 .6503 Mdot
.53304 .5679 Mdot
.37993 .73346 Mdot
.57766 .68063 Mdot
.69939 .43503 Mdot
.56912 .62598 Mdot
.69159 .43616 Mdot
.35612 .40737 Mdot
.51582 .38664 Mdot
.68844 .44611 Mdot
.59043 .65893 Mdot
.18448 .39451 Mdot
.49922 .38712 Mdot
.56996 .6522 Mdot
.47343 .34974 Mdot
.70034 .42872 Mdot
.65922 .47772 Mdot
.24555 .34161 Mdot
.4439 .39973 Mdot
.50241 .38603 Mdot
.51988 .61819 Mdot
.58319 .37553 Mdot
.51702 .64345 Mdot
.4452 .75861 Mdot
.51045 .60461 Mdot
.55384 .68684 Mdot
.43657 .17705 Mdot
.50038 .40958 Mdot
.8383 .45443 Mdot
.22186 .50322 Mdot
.20019 .40127 Mdot
.63045 .48868 Mdot
.35809 .57064 Mdot
.1995 .50561 Mdot
.4762 .2555 Mdot
.30562 .42729 Mdot
.57779 .59743 Mdot
.63314 .40836 Mdot
.48426 .39845 Mdot
.3627 .59419 Mdot
.53867 .60417 Mdot
.329 .39243 Mdot
.26518 .31733 Mdot
.50108 .39889 Mdot
.66276 .45664 Mdot
.6543 .47797 Mdot
.7886 .35272 Mdot
.54527 .62335 Mdot
.5735 .64684 Mdot
.47962 .3899 Mdot
.51368 .68266 Mdot
.39612 .60407 Mdot
.28738 .59949 Mdot
.50399 .38265 Mdot
.55669 .40628 Mdot
.68312 .47393 Mdot
.59079 .62219 Mdot
.39873 .53088 Mdot
.28752 .3568 Mdot
.69416 .5363 Mdot
.37931 .61256 Mdot
.46249 .75184 Mdot
.69905 .43463 Mdot
.49364 .38028 Mdot
.3985 .65246 Mdot
.50982 .59452 Mdot
.58773 .62087 Mdot
.46813 .75208 Mdot
.43258 .46676 Mdot
.3657 .55652 Mdot
.60528 .64925 Mdot
.43033 .47565 Mdot
.52023 .65177 Mdot
.52895 .66704 Mdot
.49133 .6384 Mdot
.57412 .66139 Mdot
.68479 .4373 Mdot
.64424 .5854 Mdot
.31598 .43715 Mdot
.7579 .53499 Mdot
.44397 .5099 Mdot
.53703 .63332 Mdot
.52695 .65054 Mdot
.68057 .52254 Mdot
.55495 .34969 Mdot
.67436 .44 Mdot
.66029 .40159 Mdot
.51766 .36943 Mdot
.59505 .5465 Mdot
.36735 .45552 Mdot
.63862 .68613 Mdot
.34776 .44726 Mdot
.67876 .43604 Mdot
.33704 .42057 Mdot
.51863 .36493 Mdot
.34544 .41684 Mdot
.32521 .46888 Mdot
.46404 .35242 Mdot
.68412 .47531 Mdot
.59385 .64482 Mdot
.51373 .37963 Mdot
.49733 .75678 Mdot
.36996 .61761 Mdot
.24553 .34088 Mdot
.59434 .57344 Mdot
.54436 .73341 Mdot
.30608 .6797 Mdot
.35002 .43648 Mdot
.65615 .33982 Mdot
.69554 .44862 Mdot
.40004 .61408 Mdot
.68846 .43735 Mdot
.78751 .6465 Mdot
.37175 .58566 Mdot
.2414 .34287 Mdot
.37944 .6492 Mdot
.28445 .48384 Mdot
.6056 .62405 Mdot
.69934 .39413 Mdot
.35769 .4421 Mdot
.48783 .39894 Mdot
.39114 .39339 Mdot
.56041 .66621 Mdot
.62323 .26801 Mdot
.65525 .41307 Mdot
.4653 .2418 Mdot
.48981 .3758 Mdot
.4667 .33526 Mdot
.54769 .61837 Mdot
.32582 .50361 Mdot
.50908 .64142 Mdot
.42583 .62924 Mdot
.44254 .74267 Mdot
.63837 .6888 Mdot
.52158 .6083 Mdot
.34751 .45282 Mdot
.51652 .62508 Mdot
.46677 .6179 Mdot
.66904 .7613 Mdot
.5897 .56789 Mdot
.63245 .24553 Mdot
.34886 .53912 Mdot
.68614 .46726 Mdot
.49524 .60244 Mdot
.47845 .24134 Mdot
.53211 .64644 Mdot
.42568 .85957 Mdot
.37406 .59899 Mdot
.38131 .41582 Mdot
.60471 .63978 Mdot
.54856 .63061 Mdot
.69274 .70736 Mdot
.67294 .38625 Mdot
.49516 .24218 Mdot
.58408 .61717 Mdot
.43757 .71754 Mdot
.50162 .34329 Mdot
.50992 .59921 Mdot
.57241 .62856 Mdot
.57365 .79152 Mdot
.48999 .34115 Mdot
.34883 .42969 Mdot
.47209 .25384 Mdot
.34568 .46289 Mdot
.34573 .58003 Mdot
.50623 .45761 Mdot
.55415 .77447 Mdot
.63818 .34967 Mdot
.3541 .61846 Mdot
.60208 .63389 Mdot
.50387 .71473 Mdot
.54634 .64606 Mdot
.3597 .57667 Mdot
.48699 .33926 Mdot
.68447 .44055 Mdot
.588 .4533 Mdot
.4742 .2319 Mdot
.52817 .67805 Mdot
.36381 .56989 Mdot
.68106 .45032 Mdot
.28404 .32966 Mdot
.68475 .46004 Mdot
.503 .36492 Mdot
.49493 .3295 Mdot
.37398 .58914 Mdot
.6867 .43628 Mdot
.31987 .46118 Mdot
.22323 .50004 Mdot
.50969 .60928 Mdot
.47567 .42256 Mdot
.63643 .47577 Mdot
.71372 .45618 Mdot
.63757 .43472 Mdot
.55228 .61138 Mdot
.44417 .46264 Mdot
.49876 .6133 Mdot
.51315 .36466 Mdot
.312 .41841 Mdot
.56443 .77266 Mdot
.6962 .71661 Mdot
.55296 .41245 Mdot
.55879 .68928 Mdot
.56088 .65921 Mdot
.57195 .63528 Mdot
.54102 .59134 Mdot
.2756 .61276 Mdot
.55778 .61802 Mdot
.50164 .35562 Mdot
.32611 .45156 Mdot
.5433 .62038 Mdot
.47718 .24373 Mdot
.45421 .47888 Mdot
.37734 .62807 Mdot
.48164 .48943 Mdot
.16364 .43819 Mdot
.68095 .44915 Mdot
.35407 .41761 Mdot
.30726 .43257 Mdot
.38936 .61907 Mdot
.49999 .39402 Mdot
.68737 .45657 Mdot
.36642 .7139 Mdot
.39249 .60015 Mdot
.57255 .62074 Mdot
.36923 .5109 Mdot
.70159 .25194 Mdot
.60004 .61005 Mdot
.57141 .60219 Mdot
.46697 .25068 Mdot
.37113 .44258 Mdot
.29831 .7728 Mdot
.42382 .45725 Mdot
.36849 .58983 Mdot
.3572 .58396 Mdot
.63877 .43066 Mdot
.51001 .65529 Mdot
.48949 .36085 Mdot
.40934 .48597 Mdot
.39394 .77678 Mdot
.33654 .37138 Mdot
.42149 .23303 Mdot
.56775 .5871 Mdot
.69396 .69014 Mdot
.51124 .61914 Mdot
.6961 .41674 Mdot
.65372 .4206 Mdot
.66969 .44397 Mdot
.50781 .36138 Mdot
.8073 .49582 Mdot
.49903 .35422 Mdot
.15858 .44413 Mdot
.70194 .44854 Mdot
.26335 .51163 Mdot
.33177 .42062 Mdot
.58812 .68662 Mdot
.38128 .58315 Mdot
.55471 .37784 Mdot
.4888 .63536 Mdot
.66062 .29454 Mdot
.33786 .41227 Mdot
.66726 .47931 Mdot
.48219 .58991 Mdot
.1831 .61171 Mdot
.49339 .4494 Mdot
.44046 .58647 Mdot
.76036 .67161 Mdot
.37241 .58407 Mdot
.69713 .52622 Mdot
.39528 .59589 Mdot
.48477 .38837 Mdot
.56286 .66623 Mdot
.57156 .66494 Mdot
.51806 .6095 Mdot
.55782 .6149 Mdot
.50738 .34925 Mdot
.54122 .58379 Mdot
.725 .74371 Mdot
.47829 .25276 Mdot
.2334 .55576 Mdot
.36277 .62005 Mdot
.46257 .34928 Mdot
.33718 .4519 Mdot
.46658 .22057 Mdot
.51408 .78902 Mdot
.55567 .58486 Mdot
.5744 .59646 Mdot
.48915 .22438 Mdot
.49493 .65255 Mdot
.48837 .58422 Mdot
.31822 .43933 Mdot
.55191 .42633 Mdot
.34835 .58509 Mdot
.35409 .61502 Mdot
.46528 .35505 Mdot
.68832 .43685 Mdot
.38156 .61377 Mdot
.36827 .42399 Mdot
.55011 .57802 Mdot
.56424 .67747 Mdot
.63714 .47633 Mdot
.77157 .67399 Mdot
.36758 .56575 Mdot
.47456 .62271 Mdot
.69397 .43407 Mdot
.64944 .41474 Mdot
.58533 .61564 Mdot
.61929 .60426 Mdot
.70806 .46167 Mdot
.36957 .62453 Mdot
.4618 .35111 Mdot
.27747 .48911 Mdot
.49024 .39092 Mdot
.6866 .45299 Mdot
.5512 .57229 Mdot
.68371 .47482 Mdot
.53407 .64413 Mdot
.58035 .12883 Mdot
.57923 .65927 Mdot
.76548 .38721 Mdot
.39095 .74134 Mdot
.30839 .4369 Mdot
.32515 .46341 Mdot
.48 .24752 Mdot
.69684 .43539 Mdot
.56216 .67197 Mdot
.3643 .58034 Mdot
.20782 .38604 Mdot
.62449 .43348 Mdot
.31405 .40837 Mdot
.36837 .45163 Mdot
.49746 .33873 Mdot
.58971 .59408 Mdot
.59063 .63048 Mdot
.34673 .41905 Mdot
.30178 .66689 Mdot
.67742 .42481 Mdot
.57278 .64672 Mdot
.55714 .65911 Mdot
.31537 .44151 Mdot
.2245 .50742 Mdot
.71946 .39868 Mdot
.57133 .66153 Mdot
.3609 .64684 Mdot
.4907 .33206 Mdot
.53694 .5967 Mdot
.54125 .5847 Mdot
.3557 .59921 Mdot
.22404 .56719 Mdot
.63822 .77152 Mdot
.47003 .34008 Mdot
.46454 .22989 Mdot
.59031 .66094 Mdot
.33071 .42233 Mdot
.57977 .67168 Mdot
.24361 .66093 Mdot
.47245 .24999 Mdot
.55847 .62816 Mdot
.49271 .62811 Mdot
.64125 .44964 Mdot
.55522 .62713 Mdot
.64804 .67893 Mdot
.33562 .46082 Mdot
.55754 .62634 Mdot
.75311 .66111 Mdot
.50417 .34272 Mdot
.49195 .61546 Mdot
.34965 .59032 Mdot
.37634 .73442 Mdot
.56899 .31843 Mdot
.34063 .475 Mdot
.37135 .6225 Mdot
.59328 .64914 Mdot
.36709 .42751 Mdot
.48519 .40036 Mdot
.63835 .27771 Mdot
.57974 .57947 Mdot
.49383 .39122 Mdot
.48708 .38309 Mdot
.37445 .59255 Mdot
.81947 .41219 Mdot
.4968 .66158 Mdot
.59072 .64554 Mdot
.50543 .81462 Mdot
.65371 .41587 Mdot
.5931 .64334 Mdot
.59691 .60891 Mdot
.48337 .36065 Mdot
.53706 .52278 Mdot
.74273 .4597 Mdot
.30334 .58527 Mdot
.48139 .33505 Mdot
.32067 .47361 Mdot
.36628 .42614 Mdot
.36481 .62048 Mdot
.68101 .46851 Mdot
.3576 .62393 Mdot
.319 .42529 Mdot
.55455 .59085 Mdot
.47634 .36571 Mdot
.69498 .57138 Mdot
.50476 .4035 Mdot
.33128 .38901 Mdot
.71595 .43537 Mdot
.53096 .30611 Mdot
.58081 .8334 Mdot
.58793 .32626 Mdot
.45567 .36113 Mdot
.35928 .59015 Mdot
.38682 .49046 Mdot
.55973 .6586 Mdot
.73585 .49777 Mdot
.59692 .62045 Mdot
.75621 .67592 Mdot
.33209 .40249 Mdot
.47791 .2166 Mdot
.56285 .66657 Mdot
.45562 .74372 Mdot
.45766 .35546 Mdot
.50151 .33939 Mdot
.56313 .60553 Mdot
.50184 .36272 Mdot
.58595 .64217 Mdot
.3187 .45015 Mdot
.82112 .43139 Mdot
.56566 .65663 Mdot
.56578 .55863 Mdot
.45091 .37323 Mdot
.2447 .34103 Mdot
.2977 .44227 Mdot
.69293 .69499 Mdot
.19406 .64258 Mdot
.49902 .3629 Mdot
.5273 .56868 Mdot
.35618 .43181 Mdot
.46619 .25024 Mdot
.29616 .41276 Mdot
.59134 .60663 Mdot
.5661 .59074 Mdot
.51586 .64593 Mdot
.55116 .65521 Mdot
.72872 .5003 Mdot
.54197 .54164 Mdot
.70149 .65587 Mdot
.57289 .5971 Mdot
.62367 .50199 Mdot
.50301 .35215 Mdot
.72729 .46255 Mdot
.4043 .59333 Mdot
.56139 .58868 Mdot
.65716 .38948 Mdot
.46541 .34536 Mdot
.1608 .45031 Mdot
.494 .33957 Mdot
.34238 .44226 Mdot
.51993 .38856 Mdot
.5339 .64065 Mdot
.66197 .46291 Mdot
.32956 .45788 Mdot
.56304 .23948 Mdot
.30534 .42414 Mdot
.54341 .62649 Mdot
.23749 .53469 Mdot
.30853 .43285 Mdot
.4627 .48275 Mdot
.6663 .46604 Mdot
.44214 .71372 Mdot
.66899 .41479 Mdot
.55595 .63329 Mdot
.55525 .6388 Mdot
.4631 .22369 Mdot
.50398 .39858 Mdot
.70216 .43194 Mdot
.81561 .6593 Mdot
.34101 .60063 Mdot
.66221 .44465 Mdot
.61041 .6592 Mdot
.43803 .45953 Mdot
.64702 .44268 Mdot
.40353 .71103 Mdot
.49631 .39685 Mdot
.63153 .44169 Mdot
.61547 .65595 Mdot
.55588 .49014 Mdot
.39577 .58979 Mdot
.32144 .39513 Mdot
.54245 .47013 Mdot
.35726 .44637 Mdot
.47453 .33437 Mdot
.37077 .41789 Mdot
.5012 .34425 Mdot
.76525 .40338 Mdot
.74944 .40736 Mdot
.48665 .40956 Mdot
.49187 .32804 Mdot
.32399 .42836 Mdot
.54569 .59071 Mdot
.44746 .52298 Mdot
.58996 .6777 Mdot
.60301 .60744 Mdot
.51201 .34666 Mdot
.69399 .42659 Mdot
.70232 .46217 Mdot
.71297 .40366 Mdot
.65259 .47428 Mdot
.33807 .45331 Mdot
.66365 .34456 Mdot
.80073 .61567 Mdot
.46637 .36187 Mdot
.53195 .35647 Mdot
.51922 .6458 Mdot
.32813 .42409 Mdot
.34846 .402 Mdot
.48285 .36791 Mdot
.71757 .53502 Mdot
.53207 .56993 Mdot
.69454 .41907 Mdot
.70163 .44987 Mdot
.64967 .43994 Mdot
.63564 .45124 Mdot
.78809 .48566 Mdot
.48821 .39922 Mdot
.70017 .44147 Mdot
.56232 .61412 Mdot
.57515 .59087 Mdot
.46884 .22819 Mdot
.35046 .60535 Mdot
.59709 .5814 Mdot
.58101 .56432 Mdot
.58656 .61556 Mdot
.31005 .42913 Mdot
.62611 .65144 Mdot
.46977 .24432 Mdot
.37362 .43032 Mdot
.35618 .47019 Mdot
.48047 .21982 Mdot
.65255 .5155 Mdot
.17774 .61645 Mdot
.51386 .62593 Mdot
.44386 .62441 Mdot
.33207 .42755 Mdot
.72176 .33887 Mdot
.60803 .4953 Mdot
.52395 .60653 Mdot
.51321 .50953 Mdot
.32255 .45482 Mdot
.66129 .41049 Mdot
.59589 .62981 Mdot
.49024 .24008 Mdot
.38181 .62695 Mdot
.60809 .66589 Mdot
.46866 .25288 Mdot
.67882 .43423 Mdot
.40956 .57147 Mdot
.63611 .43079 Mdot
.30879 .44612 Mdot
.491 .61843 Mdot
.17763 .30212 Mdot
.36154 .43757 Mdot
.21745 .41027 Mdot
.74553 .40823 Mdot
.56683 .65828 Mdot
.36053 .44263 Mdot
.67234 .40869 Mdot
.49427 .33248 Mdot
.42624 .48506 Mdot
.69653 .45629 Mdot
.46905 .21871 Mdot
.47332 .22358 Mdot
.31586 .43912 Mdot
.66656 .47358 Mdot
.52025 .59101 Mdot
.64521 .43269 Mdot
.51797 .3925 Mdot
.53066 .61281 Mdot
.17484 .57062 Mdot
.56741 .54686 Mdot
.69225 .43055 Mdot
.34576 .39433 Mdot
.38327 .57776 Mdot
.54118 .6025 Mdot
.20485 .44725 Mdot
.59452 .6023 Mdot
.47836 .34497 Mdot
.71184 .30972 Mdot
.68395 .57456 Mdot
.55155 .59138 Mdot
.52333 .64939 Mdot
.463 .35865 Mdot
.54895 .58974 Mdot
.59812 .60647 Mdot
.44334 .37504 Mdot
.6431 .45342 Mdot
.567 .63528 Mdot
.3333 .3974 Mdot
.6894 .73523 Mdot
.59014 .66211 Mdot
.6129 .23035 Mdot
.44881 .72744 Mdot
.72372 .32333 Mdot
.58246 .66673 Mdot
.50664 .76353 Mdot
.55835 .64381 Mdot
.55032 .60454 Mdot
.51652 .61744 Mdot
.68592 .68421 Mdot
.32287 .42488 Mdot
.31028 .40825 Mdot
.39839 .59375 Mdot
.4456 .72734 Mdot
.35967 .61139 Mdot
.47051 .34439 Mdot
.36801 .23491 Mdot
.47635 .25133 Mdot
.68968 .43689 Mdot
.53096 .66261 Mdot
.30501 .44352 Mdot
.59156 .61797 Mdot
.53014 .64162 Mdot
.31472 .44948 Mdot
.36459 .43413 Mdot
.37504 .41629 Mdot
.39355 .59451 Mdot
.67873 .44344 Mdot
.52956 .5918 Mdot
.39078 .60647 Mdot
.51879 .59034 Mdot
.42741 .46151 Mdot
.6765 .4421 Mdot
.6438 .43477 Mdot
.70912 .43773 Mdot
.55687 .58916 Mdot
.53416 .63572 Mdot
.49744 .35398 Mdot
.63718 .47803 Mdot
.46678 .37179 Mdot
.35496 .44735 Mdot
.31698 .45708 Mdot
.59065 .60536 Mdot
.47346 .61148 Mdot
.35792 .58493 Mdot
.3457 .43946 Mdot
.49163 .22846 Mdot
.39977 .59965 Mdot
.5454 .61474 Mdot
.34971 .4504 Mdot
.35136 .61239 Mdot
.73678 .54728 Mdot
.22683 .68059 Mdot
.37812 .57331 Mdot
.56389 .60757 Mdot
.69712 .70769 Mdot
.42239 .65412 Mdot
.34389 .61257 Mdot
.46872 .36168 Mdot
.59132 .59813 Mdot
.33266 .73321 Mdot
.34521 .60655 Mdot
.75984 .68448 Mdot
.31099 .44073 Mdot
.5159 .53193 Mdot
.6177 .6489 Mdot
.75174 .49568 Mdot
.35232 .62051 Mdot
.68252 .45739 Mdot
.63402 .47873 Mdot
.56905 .61393 Mdot
.39913 .63302 Mdot
.52721 .36128 Mdot
.30686 .4383 Mdot
.31281 .46083 Mdot
.66002 .47063 Mdot
.60167 .37632 Mdot
.33787 .3954 Mdot
.5165 .69396 Mdot
.37048 .48839 Mdot
.61492 .56438 Mdot
.78753 .42593 Mdot
.55209 .24297 Mdot
.55604 .67833 Mdot
.37299 .57348 Mdot
.46616 .38127 Mdot
.49952 .35676 Mdot
.50604 .36911 Mdot
.33452 .466 Mdot
.48849 .47039 Mdot
.33922 .41028 Mdot
.61973 .27539 Mdot
.38199 .5956 Mdot
.42924 .69364 Mdot
.56667 .67005 Mdot
.56313 .65796 Mdot
.52566 .58313 Mdot
.51776 .65178 Mdot
.56007 .64448 Mdot
.50381 .38822 Mdot
.34942 .46701 Mdot
.31948 .53982 Mdot
.65651 .43619 Mdot
.31145 .29654 Mdot
.332 .42035 Mdot
.46909 .25128 Mdot
.36644 .60191 Mdot
.53554 .76241 Mdot
.35911 .48202 Mdot
.33721 .42174 Mdot
.56425 .57497 Mdot
.67071 .41795 Mdot
.6022 .52889 Mdot
.55403 .64621 Mdot
.34732 .4383 Mdot
.30698 .38397 Mdot
.67648 .53974 Mdot
.58533 .70938 Mdot
.34394 .56647 Mdot
.44208 .45872 Mdot
.37179 .63279 Mdot
.61473 .59485 Mdot
.71903 .33682 Mdot
.31928 .42694 Mdot
.3351 .44463 Mdot
.3608 .57224 Mdot
.46893 .65956 Mdot
.67169 .47211 Mdot
.47926 .21656 Mdot
.47572 .35047 Mdot
.54911 .64461 Mdot
.33784 .46432 Mdot
.45278 .61115 Mdot
.3599 .50711 Mdot
.50433 .37971 Mdot
.37384 .43193 Mdot
.57834 .58507 Mdot
.56528 .60465 Mdot
.36928 .58443 Mdot
.41927 .55592 Mdot
.60478 .66711 Mdot
.1998 .40209 Mdot
.64811 .35699 Mdot
.64913 .3719 Mdot
.58786 .62141 Mdot
.6534 .46828 Mdot
.48954 .23508 Mdot
.38726 .59204 Mdot
.53788 .58073 Mdot
.20689 .66289 Mdot
.67874 .48887 Mdot
.49476 .38486 Mdot
.48926 .23078 Mdot
.48651 .47153 Mdot
.59641 .60627 Mdot
.59696 .62122 Mdot
.55497 .61301 Mdot
.22302 .68876 Mdot
.31925 .40224 Mdot
.63579 .44147 Mdot
.37704 .61364 Mdot
.63914 .46046 Mdot
.30746 .41348 Mdot
.5839 .43656 Mdot
.54216 .61791 Mdot
.70117 .42202 Mdot
.68103 .45956 Mdot
.49726 .33846 Mdot
.50579 .33692 Mdot
.38039 .43433 Mdot
.5793 .65838 Mdot
.48868 .24774 Mdot
.66112 .4165 Mdot
.36598 .44732 Mdot
.37241 .58513 Mdot
.51635 .37232 Mdot
.57097 .59661 Mdot
.31736 .43313 Mdot
.52249 .66941 Mdot
.65012 .4317 Mdot
.33646 .42194 Mdot
.48155 .26024 Mdot
.35337 .58844 Mdot
.5675 .59281 Mdot
.37859 .5528 Mdot
.48548 .22147 Mdot
.55262 .6606 Mdot
.60229 .74451 Mdot
.41098 .60449 Mdot
.56464 .23622 Mdot
.34738 .41209 Mdot
.47249 .23925 Mdot
.64804 .4252 Mdot
.57599 .49508 Mdot
.33415 .4472 Mdot
.60307 .73026 Mdot
.4372 .5415 Mdot
.53119 .59175 Mdot
.65553 .45328 Mdot
.32001 .59512 Mdot
.17538 .43766 Mdot
.39363 .65862 Mdot
.57104 .64378 Mdot
.35971 .44425 Mdot
.3586 .61979 Mdot
.46728 .35633 Mdot
.61574 .23179 Mdot
.78284 .43587 Mdot
.37557 .43231 Mdot
.51278 .62395 Mdot
.66172 .41661 Mdot
.48309 .37022 Mdot
.53354 .269 Mdot
.36724 .41884 Mdot
.33785 .40275 Mdot
.54491 .60797 Mdot
.38504 .60907 Mdot
.29738 .65178 Mdot
.30997 .40667 Mdot
.34742 .46365 Mdot
.30193 .30171 Mdot
.37101 .56756 Mdot
.56481 .61731 Mdot
.71255 .40324 Mdot
.56268 .57847 Mdot
.21322 .39667 Mdot
.47257 .24449 Mdot
.65815 .43391 Mdot
.58255 .59332 Mdot
.3426 .53777 Mdot
.3422 .44923 Mdot
.45159 .45686 Mdot
.34534 .39046 Mdot
.50242 .39143 Mdot
.33498 .46397 Mdot
.59447 .62828 Mdot
.45803 .35136 Mdot
.35595 .58717 Mdot
.57225 .66146 Mdot
.53301 .63518 Mdot
.68282 .40976 Mdot
.48179 .38695 Mdot
.62736 .76179 Mdot
.50508 .32857 Mdot
.46249 .3676 Mdot
.62826 .43736 Mdot
.57083 .61716 Mdot
.34219 .43645 Mdot
.3193 .39416 Mdot
.52986 .58678 Mdot
.72422 .34506 Mdot
.66563 .471 Mdot
.37923 .45538 Mdot
.29603 .76827 Mdot
.54929 .70856 Mdot
.48977 .25053 Mdot
.49175 .70939 Mdot
.50018 .33678 Mdot
.56619 .5997 Mdot
.68805 .4297 Mdot
.35554 .46022 Mdot
.33676 .39557 Mdot
.53937 .5775 Mdot
.48261 .37879 Mdot
.3693 .62731 Mdot
.34596 .40387 Mdot
.35429 .50417 Mdot
.55378 .62234 Mdot
.62231 .26535 Mdot
.35103 .41003 Mdot
.22192 .33422 Mdot
.3312 .5368 Mdot
.65191 .44788 Mdot
.52711 .63957 Mdot
.66013 .48242 Mdot
.37186 .61415 Mdot
.29883 .45806 Mdot
.48391 .3826 Mdot
.55454 .72068 Mdot
.6491 .78753 Mdot
.32481 .4213 Mdot
.68324 .43729 Mdot
.55417 .58913 Mdot
.536 .71219 Mdot
.58859 .65208 Mdot
.5477 .5203 Mdot
.40426 .58003 Mdot
.51456 .34749 Mdot
.47685 .34406 Mdot
.53072 .65565 Mdot
.39496 .60297 Mdot
.30103 .41289 Mdot
.31205 .44326 Mdot
.77188 .2708 Mdot
.48072 .26087 Mdot
.42528 .75517 Mdot
.56353 .5923 Mdot
.36453 .4529 Mdot
.692 .72041 Mdot
.47946 .38991 Mdot
.50549 .63282 Mdot
.34547 .47182 Mdot
.29688 .34997 Mdot
.42871 .46425 Mdot
.56166 .6337 Mdot
.52146 .69021 Mdot
.47508 .34882 Mdot
.40203 .48267 Mdot
.34082 .41223 Mdot
.50588 .61142 Mdot
.49889 .32675 Mdot
.27818 .31996 Mdot
.70191 .76357 Mdot
.67811 .44351 Mdot
.33491 .38808 Mdot
.50237 .39064 Mdot
.58265 .69266 Mdot
.36254 .62021 Mdot
.34757 .45883 Mdot
.30794 .42453 Mdot
.5267 .61992 Mdot
.60285 .59095 Mdot
.54885 .70923 Mdot
.6672 .43676 Mdot
.49111 .35101 Mdot
.5531 .66804 Mdot
.60808 .37463 Mdot
.51418 .64431 Mdot
.48967 .35376 Mdot
.36656 .13937 Mdot
.57994 .57852 Mdot
.58834 .6498 Mdot
.31571 .6566 Mdot
.69418 .4669 Mdot
.64328 .46543 Mdot
.65727 .35087 Mdot
.5639 .59231 Mdot
.30178 .49511 Mdot
.68187 .44441 Mdot
.6626 .4687 Mdot
.25741 .51997 Mdot
.52954 .6097 Mdot
.40884 .46488 Mdot
.48785 .36092 Mdot
.50759 .38822 Mdot
.64241 .4436 Mdot
.59295 .68448 Mdot
.47283 .38994 Mdot
.75019 .4688 Mdot
.33107 .41674 Mdot
.71856 .33592 Mdot
.66284 .4217 Mdot
.4099 .54245 Mdot
.49081 .39366 Mdot
.15454 .43087 Mdot
.53253 .49257 Mdot
.50882 .62684 Mdot
.55975 .59779 Mdot
.35431 .59844 Mdot
.49282 .59 Mdot
.46399 .2321 Mdot
.5033 .36302 Mdot
.23892 .61072 Mdot
.66856 .44437 Mdot
.58289 .6535 Mdot
.54494 .7623 Mdot
.55323 .27832 Mdot
.64217 .2498 Mdot
.68651 .46604 Mdot
.65993 .45257 Mdot
.33024 .40844 Mdot
.31812 .41567 Mdot
.56572 .62584 Mdot
.50646 .35826 Mdot
.62926 .46297 Mdot
.48208 .35116 Mdot
.31839 .42634 Mdot
.33823 .42682 Mdot
.47097 .24917 Mdot
.51581 .67507 Mdot
.31041 .44558 Mdot
.26689 .33453 Mdot
.60052 .38196 Mdot
.68327 .40785 Mdot
.57125 .83094 Mdot
.52962 .26723 Mdot
.32744 .68794 Mdot
.39111 .62345 Mdot
.48888 .26586 Mdot
.5241 .37371 Mdot
.5274 .65235 Mdot
.58365 .60235 Mdot
.47888 .22842 Mdot
.50928 .39451 Mdot
.36184 .59916 Mdot
.50464 .39859 Mdot
.386 .5991 Mdot
.2995 .44141 Mdot
.59001 .66199 Mdot
.60059 .62336 Mdot
.50585 .3835 Mdot
.34772 .42606 Mdot
.30819 .44199 Mdot
.39778 .60914 Mdot
.51778 .75198 Mdot
.31535 .4375 Mdot
.66056 .42243 Mdot
.79682 .57313 Mdot
.47443 .22407 Mdot
.59518 .63373 Mdot
.54975 .76862 Mdot
.70568 .52681 Mdot
.5218 .59992 Mdot
.48876 .22839 Mdot
.79137 .30355 Mdot
.57271 .6665 Mdot
.7902 .3266 Mdot
.46978 .23691 Mdot
.6915 .47167 Mdot
.35827 .42811 Mdot
.4635 .22992 Mdot
.59974 .68343 Mdot
.33725 .60189 Mdot
.59589 .57636 Mdot
.69569 .45971 Mdot
.7124 .4376 Mdot
.72732 .37482 Mdot
.21418 .39793 Mdot
.38559 .58349 Mdot
.36697 .5942 Mdot
.33023 .44728 Mdot
.41613 .19002 Mdot
.61727 .64124 Mdot
.36501 .59234 Mdot
.2644 .6395 Mdot
.51803 .64249 Mdot
.45458 .76231 Mdot
.51147 .5084 Mdot
.6548 .46864 Mdot
.70238 .49625 Mdot
.33653 .44913 Mdot
.68294 .4378 Mdot
.60019 .40132 Mdot
.52734 .58249 Mdot
.67355 .44234 Mdot
.48615 .35565 Mdot
.40179 .35216 Mdot
.66259 .48063 Mdot
.41081 .49437 Mdot
.4896 .36169 Mdot
.4133 .60817 Mdot
.3565 .6741 Mdot
.42374 .86864 Mdot
.50446 .36213 Mdot
.35411 .43529 Mdot
.31035 .44722 Mdot
.31631 .44538 Mdot
.69706 .45613 Mdot
.35974 .41152 Mdot
.66643 .43199 Mdot
.22041 .4679 Mdot
.52227 .76765 Mdot
.37611 .58924 Mdot
.44998 .40797 Mdot
.67052 .4585 Mdot
.63882 .31136 Mdot
.59292 .82345 Mdot
.56201 .60661 Mdot
.502 .32744 Mdot
.35921 .57373 Mdot
.36322 .19714 Mdot
.35576 .60067 Mdot
.35615 .43065 Mdot
.71715 .33352 Mdot
.58435 .64281 Mdot
.64247 .6945 Mdot
.359 .58118 Mdot
.69067 .46295 Mdot
.55603 .66043 Mdot
.35659 .3901 Mdot
.36862 .62062 Mdot
.37954 .6269 Mdot
.56318 .64707 Mdot
.66383 .47743 Mdot
.34122 .43071 Mdot
.52264 .36925 Mdot
.37834 .56233 Mdot
.5553 .69491 Mdot
.54034 .59059 Mdot
.5001 .62719 Mdot
.47926 .45732 Mdot
.30476 .69306 Mdot
.49737 .36307 Mdot
.44915 .67381 Mdot
.31455 .42336 Mdot
.37444 .65345 Mdot
.61682 .3299 Mdot
.44631 .39846 Mdot
.47184 .2435 Mdot
.47387 .24724 Mdot
.56172 .63807 Mdot
.29684 .68608 Mdot
.70036 .27381 Mdot
.45788 .33491 Mdot
.47991 .22357 Mdot
.30805 .44061 Mdot
.64978 .48711 Mdot
.71505 .37497 Mdot
.60606 .60258 Mdot
.51099 .3427 Mdot
.31398 .43362 Mdot
.24581 .66518 Mdot
.38052 .59806 Mdot
.67811 .33396 Mdot
.5421 .62329 Mdot
.57582 .64816 Mdot
.49098 .37138 Mdot
.49751 .35461 Mdot
.61245 .24316 Mdot
.679 .35911 Mdot
.31709 .37138 Mdot
.44431 .33711 Mdot
.2649 .68993 Mdot
.73013 .44915 Mdot
.68885 .42826 Mdot
.47489 .25562 Mdot
.46086 .37076 Mdot
.5977 .62898 Mdot
.69598 .46884 Mdot
.64668 .25115 Mdot
.62393 .47696 Mdot
.4518 .7546 Mdot
.31972 .50408 Mdot
.54089 .63905 Mdot
.66475 .41777 Mdot
.68089 .43893 Mdot
.63689 .46262 Mdot
.48232 .22114 Mdot
.58529 .6196 Mdot
.54594 .59106 Mdot
.55878 .66561 Mdot
.48173 .63028 Mdot
.55436 .62569 Mdot
.61148 .33992 Mdot
.55433 .40836 Mdot
.22901 .58956 Mdot
.51758 .60522 Mdot
.50109 .3964 Mdot
.53094 .66425 Mdot
.39447 .60843 Mdot
.51237 .62325 Mdot
.43929 .75874 Mdot
.5011 .3744 Mdot
.47507 .67064 Mdot
.45539 .3201 Mdot
.54113 .62398 Mdot
.35264 .6167 Mdot
.30147 .68333 Mdot
.61728 .77956 Mdot
.29626 .30909 Mdot
.6581 .42349 Mdot
.36772 .47083 Mdot
.51585 .39649 Mdot
.34058 .43742 Mdot
.50789 .61739 Mdot
.48472 .25503 Mdot
.50671 .23029 Mdot
.41308 .53422 Mdot
.59606 .61244 Mdot
.59256 .55331 Mdot
.64746 .45549 Mdot
.35211 .4462 Mdot
.70091 .48617 Mdot
.55199 .60754 Mdot
.37574 .6161 Mdot
.38363 .615 Mdot
.65094 .36629 Mdot
.20342 .59741 Mdot
.58478 .50548 Mdot
.49191 .36898 Mdot
.33478 .3929 Mdot
.35063 .61822 Mdot
.76256 .41694 Mdot
.52715 .35869 Mdot
.50067 .33707 Mdot
.47762 .38003 Mdot
.544 .644 Mdot
.46673 .24023 Mdot
.24221 .62965 Mdot
.46688 .22097 Mdot
.53881 .62755 Mdot
.31167 .41617 Mdot
.46272 .2319 Mdot
.35517 .60524 Mdot
.46674 .35242 Mdot
.31981 .41795 Mdot
.55435 .63505 Mdot
.67842 .44829 Mdot
.5145 .73827 Mdot
.3879 .76095 Mdot
.21564 .50474 Mdot
.21674 .51424 Mdot
.70655 .4418 Mdot
.16727 .49746 Mdot
.47596 .4225 Mdot
.71703 .53315 Mdot
.33162 .58488 Mdot
.52663 .58849 Mdot
.83599 .48672 Mdot
.34363 .41364 Mdot
.33216 .45578 Mdot
.56121 .62951 Mdot
.36565 .4419 Mdot
.58478 .65338 Mdot
.32643 .4057 Mdot
.26088 .37784 Mdot
.60783 .61975 Mdot
.33304 .45475 Mdot
.62003 .6272 Mdot
.53933 .60788 Mdot
.64758 .46152 Mdot
.35119 .45891 Mdot
.50916 .63586 Mdot
.42633 .17286 Mdot
.51154 .35749 Mdot
.47923 .22015 Mdot
.51759 .42544 Mdot
.49363 .39735 Mdot
.65854 .44348 Mdot
.60721 .63927 Mdot
.36495 .58346 Mdot
.68085 .45525 Mdot
.37982 .43124 Mdot
.36018 .57886 Mdot
.65917 .34555 Mdot
.65197 .42791 Mdot
.47316 .22684 Mdot
.35937 .58313 Mdot
.55884 .55542 Mdot
.32606 .45929 Mdot
.407 .78381 Mdot
.46866 .22043 Mdot
.59103 .6312 Mdot
.2937 .43502 Mdot
.49928 .39901 Mdot
.57248 .63134 Mdot
.36143 .44286 Mdot
.4849 .22232 Mdot
.53933 .64838 Mdot
.5475 .65782 Mdot
.69177 .37409 Mdot
.68038 .28251 Mdot
.36822 .58559 Mdot
.66544 .41207 Mdot
.56193 .61565 Mdot
.39559 .59928 Mdot
.39991 .25367 Mdot
.54084 .67382 Mdot
.67121 .48337 Mdot
.63903 .6786 Mdot
.3166 .41571 Mdot
.46586 .36921 Mdot
.3281 .38883 Mdot
.38257 .62729 Mdot
.84113 .63177 Mdot
.46623 .24446 Mdot
.61868 .65907 Mdot
.51161 .59622 Mdot
.29774 .39237 Mdot
.67609 .43838 Mdot
.3889 .38521 Mdot
.5666 .59309 Mdot
.57636 .54553 Mdot
.57888 .65089 Mdot
.32916 .53478 Mdot
.66815 .47119 Mdot
.59062 .64443 Mdot
.48989 .57581 Mdot
.59258 .66247 Mdot
.35983 .62284 Mdot
.40703 .68204 Mdot
.53038 .66632 Mdot
.13547 .36519 Mdot
.49014 .22677 Mdot
.31537 .44937 Mdot
.28843 .45724 Mdot
.45011 .26693 Mdot
.78917 .42545 Mdot
.66714 .43404 Mdot
.63555 .60118 Mdot
.3412 .43392 Mdot
.70597 .74891 Mdot
.17345 .4649 Mdot
.53865 .61237 Mdot
.57811 .58605 Mdot
.35617 .43071 Mdot
.36388 .45261 Mdot
.48167 .25436 Mdot
.51383 .61056 Mdot
.61656 .58641 Mdot
.36854 .41749 Mdot
.5487 .63135 Mdot
.64916 .58184 Mdot
.51878 .35705 Mdot
.641 .45549 Mdot
.46692 .35702 Mdot
.50824 .34326 Mdot
.7811 .53296 Mdot
.64951 .35684 Mdot
.49227 .35301 Mdot
.50703 .32664 Mdot
.44381 .76455 Mdot
.62589 .70023 Mdot
.36201 .62665 Mdot
.19482 .52965 Mdot
.32155 .4455 Mdot
.58378 .61803 Mdot
.70231 .43648 Mdot
.75917 .50289 Mdot
.368 .32939 Mdot
.70422 .32219 Mdot
.55401 .59611 Mdot
.33171 .45069 Mdot
.47832 .2183 Mdot
.60838 .61709 Mdot
.38301 .65341 Mdot
.57404 .64607 Mdot
.30804 .44679 Mdot
.80516 .53551 Mdot
.63948 .69107 Mdot
.38856 .48454 Mdot
.65449 .40644 Mdot
.55802 .66995 Mdot
.66275 .42525 Mdot
.4958 .39232 Mdot
.39414 .5981 Mdot
.36242 .58888 Mdot
.55702 .65845 Mdot
.74965 .40677 Mdot
.50436 .51747 Mdot
.54084 .606 Mdot
.52764 .61607 Mdot
.47117 .23861 Mdot
.52839 .61515 Mdot
.51298 .59547 Mdot
.53662 .66293 Mdot
.54774 .68321 Mdot
.46224 .36805 Mdot
.6127 .73941 Mdot
.53098 .6745 Mdot
.58213 .70667 Mdot
.51652 .35791 Mdot
.63186 .61162 Mdot
.49648 .34022 Mdot
.17944 .5759 Mdot
.48754 .34374 Mdot
.36636 .58813 Mdot
.29613 .44408 Mdot
.60574 .54856 Mdot
.62909 .45653 Mdot
.49476 .33072 Mdot
.37575 .60598 Mdot
.50527 .36568 Mdot
.32446 .39826 Mdot
.5227 .82688 Mdot
.62471 .47806 Mdot
.41552 .4731 Mdot
.542 .50355 Mdot
.62148 .26296 Mdot
.32857 .4131 Mdot
.65677 .46776 Mdot
.6475 .67594 Mdot
.5376 .66193 Mdot
.35368 .59066 Mdot
.56284 .63996 Mdot
.46256 .3636 Mdot
.32526 .44918 Mdot
.23165 .53501 Mdot
.36398 .58599 Mdot
.69243 .78046 Mdot
.30393 .43103 Mdot
.58871 .58356 Mdot
.51067 .34135 Mdot
.57592 .82872 Mdot
.48538 .34351 Mdot
.52986 .76917 Mdot
.71983 .45072 Mdot
.81767 .54629 Mdot
.66128 .45729 Mdot
.64488 .23969 Mdot
.16732 .63636 Mdot
.19065 .44954 Mdot
.68814 .44979 Mdot
.38518 .46977 Mdot
.54521 .62416 Mdot
.52153 .6594 Mdot
.53353 .70495 Mdot
.66616 .40802 Mdot
.55934 .61704 Mdot
.46608 .22875 Mdot
.58393 .39687 Mdot
.2891 .61202 Mdot
.36534 .47549 Mdot
.59136 .64879 Mdot
.51412 .35411 Mdot
.49398 .40424 Mdot
.46346 .22738 Mdot
.52683 .36624 Mdot
.53797 .6036 Mdot
.66751 .45861 Mdot
.43285 .53183 Mdot
.36545 .61326 Mdot
.28457 .26506 Mdot
.39008 .57238 Mdot
.37284 .46926 Mdot
.49223 .62593 Mdot
.33806 .42581 Mdot
.87227 .49598 Mdot
.52374 .65322 Mdot
.6846 .44314 Mdot
.54666 .65452 Mdot
.54484 .66747 Mdot
.51671 .65516 Mdot
.36041 .40972 Mdot
.27931 .43204 Mdot
.54942 .63447 Mdot
.4836 .38337 Mdot
.22653 .55273 Mdot
.58876 .57119 Mdot
.38585 .43131 Mdot
.43809 .73288 Mdot
.62485 .27884 Mdot
.6788 .40567 Mdot
.35312 .44064 Mdot
.66495 .44723 Mdot
.63921 .41896 Mdot
.65857 .4433 Mdot
.22383 .60729 Mdot
.56513 .52563 Mdot
.76685 .28482 Mdot
.78223 .62724 Mdot
.74534 .52187 Mdot
.70177 .42435 Mdot
.40566 .28642 Mdot
.69162 .43309 Mdot
.66292 .43714 Mdot
.52905 .11551 Mdot
.6977 .43892 Mdot
.58979 .605 Mdot
.57668 .57556 Mdot
.57886 .31744 Mdot
.46694 .77616 Mdot
.51373 .61706 Mdot
.56218 .62071 Mdot
.38965 .5899 Mdot
.47025 .63045 Mdot
.45928 .24228 Mdot
.70001 .34231 Mdot
.49559 .27002 Mdot
.56243 .6462 Mdot
.55981 .62391 Mdot
.57189 .69034 Mdot
.17124 .65302 Mdot
.76669 .48519 Mdot
.71118 .4448 Mdot
.60114 .55553 Mdot
.22672 .35211 Mdot
.58308 .58277 Mdot
.60187 .62928 Mdot
.53439 .64407 Mdot
.34196 .43549 Mdot
.6582 .48947 Mdot
.58592 .55245 Mdot
.60293 .27997 Mdot
.54432 .61704 Mdot
.47204 .41917 Mdot
.38567 .56438 Mdot
.59458 .62423 Mdot
.63953 .46409 Mdot
.51514 .62914 Mdot
.66534 .41936 Mdot
.64186 .44849 Mdot
.53609 .68936 Mdot
.23126 .62278 Mdot
.64918 .48081 Mdot
.53643 .63326 Mdot
.34894 .431 Mdot
.17955 .43578 Mdot
.59199 .62768 Mdot
.38945 .59723 Mdot
.56167 .59551 Mdot
.3586 .621 Mdot
.53232 .62251 Mdot
.46902 .21909 Mdot
.67612 .57963 Mdot
.33308 .44485 Mdot
.33567 .56335 Mdot
.3691 .43938 Mdot
.65321 .38162 Mdot
.68764 .47642 Mdot
.46008 .24822 Mdot
.78713 .37566 Mdot
.47128 .23701 Mdot
.51527 .73731 Mdot
.35471 .29943 Mdot
.51327 .36622 Mdot
.63652 .44621 Mdot
.45407 .66713 Mdot
.38752 .44552 Mdot
.37759 .42878 Mdot
.36075 .46587 Mdot
.85518 .57502 Mdot
.81943 .42387 Mdot
.55024 .64102 Mdot
.4085 .7982 Mdot
.70485 .64096 Mdot
.57375 .67621 Mdot
.60378 .6575 Mdot
.30746 .44766 Mdot
.56711 .66929 Mdot
.47273 .47523 Mdot
.32422 .42746 Mdot
.37148 .60131 Mdot
.65966 .43212 Mdot
.36593 .62357 Mdot
.3608 .38215 Mdot
.55998 .41077 Mdot
.31672 .42329 Mdot
.54622 .67951 Mdot
.55249 .65111 Mdot
.65084 .42509 Mdot
.63046 .40892 Mdot
.64247 .45644 Mdot
.36043 .57553 Mdot
.32501 .43609 Mdot
.7577 .48631 Mdot
.56987 .60149 Mdot
.67989 .4613 Mdot
.54122 .34167 Mdot
.56516 .60385 Mdot
.50321 .38634 Mdot
.55062 .59403 Mdot
.69217 .45156 Mdot
.52883 .61532 Mdot
.66562 .45714 Mdot
.34459 .4176 Mdot
.57769 .58182 Mdot
.56259 .62669 Mdot
.64415 .77033 Mdot
.36167 .60048 Mdot
.68931 .47489 Mdot
.51285 .47636 Mdot
.56873 .57818 Mdot
.37506 .65048 Mdot
.58536 .66391 Mdot
.63995 .63986 Mdot
.62087 .62481 Mdot
.46716 .22895 Mdot
.50949 .65098 Mdot
.59185 .63075 Mdot
.62435 .73008 Mdot
.726 .68703 Mdot
.67769 .49933 Mdot
.47046 .34027 Mdot
.63962 .46338 Mdot
.32003 .45912 Mdot
.3498 .4656 Mdot
.35332 .40771 Mdot
.49474 .78006 Mdot
.58558 .68847 Mdot
.58501 .64108 Mdot
.5024 .33292 Mdot
.36961 .59353 Mdot
.68729 .46306 Mdot
.37479 .59247 Mdot
.70512 .34448 Mdot
.35612 .57904 Mdot
.46397 .23486 Mdot
.33171 .53719 Mdot
.70246 .51582 Mdot
.38478 .58502 Mdot
.6421 .45677 Mdot
.34263 .51264 Mdot
.52039 .59412 Mdot
.27286 .34705 Mdot
.37713 .61574 Mdot
.82702 .64364 Mdot
.58929 .65976 Mdot
.44013 .47695 Mdot
.50614 .34726 Mdot
.35398 .61299 Mdot
.48358 .38952 Mdot
.51612 .64344 Mdot
.56706 .23414 Mdot
.68673 .43737 Mdot
.46018 .34739 Mdot
.51205 .65357 Mdot
.36262 .62141 Mdot
.31081 .433 Mdot
.56813 .47762 Mdot
.50402 .39284 Mdot
.59551 .7774 Mdot
.39333 .65851 Mdot
.3251 .43416 Mdot
.7091 .26053 Mdot
.47168 .36835 Mdot
.55855 .67939 Mdot
.61642 .54164 Mdot
.52141 .60791 Mdot
.32758 .46514 Mdot
.34991 .44941 Mdot
.58025 .36048 Mdot
.54788 .65287 Mdot
.58817 .66098 Mdot
.67535 .4921 Mdot
.32733 .42174 Mdot
.65338 .4578 Mdot
.63361 .449 Mdot
.35389 .43127 Mdot
.65177 .4498 Mdot
.35651 .58279 Mdot
.57705 .40239 Mdot
.47157 .36552 Mdot
.4891 .38442 Mdot
.30958 .4419 Mdot
.31084 .40385 Mdot
.3364 .42388 Mdot
.55005 .59491 Mdot
.68033 .47203 Mdot
.52369 .63486 Mdot
.53167 .66838 Mdot
.72261 .43931 Mdot
.70199 .45434 Mdot
.52094 .63988 Mdot
.36262 .5234 Mdot
.3638 .56042 Mdot
.33472 .45402 Mdot
.48452 .35065 Mdot
.70962 .74112 Mdot
.50865 .33764 Mdot
.58958 .65469 Mdot
.2905 .35061 Mdot
.69326 .46123 Mdot
.3551 .60072 Mdot
.40464 .63244 Mdot
.35541 .59154 Mdot
.4549 .35445 Mdot
.63265 .46151 Mdot
.65557 .34688 Mdot
.5864 .6556 Mdot
.48189 .45761 Mdot
.4537 .67513 Mdot
.61752 .3193 Mdot
.48878 .35332 Mdot
.56352 .61121 Mdot
.47119 .23479 Mdot
.67844 .53648 Mdot
.57532 .64289 Mdot
.50588 .63056 Mdot
.29263 .51471 Mdot
.57737 .70895 Mdot
.6887 .41076 Mdot
.72122 .37136 Mdot
.54922 .57944 Mdot
.7362 .44248 Mdot
.66923 .17449 Mdot
.58189 .66267 Mdot
.55273 .61546 Mdot
.58517 .60962 Mdot
.52645 .64992 Mdot
.71926 .43557 Mdot
.39416 .54411 Mdot
.50688 .33856 Mdot
.515 .44252 Mdot
.47484 .36623 Mdot
.3317 .45947 Mdot
.44383 .47977 Mdot
.63759 .44878 Mdot
.35416 .5943 Mdot
.48968 .82056 Mdot
.72261 .35848 Mdot
.33058 .40895 Mdot
.78095 .48641 Mdot
.36912 .61595 Mdot
.52785 .58822 Mdot
.39465 .58397 Mdot
.36257 .45661 Mdot
.48181 .37156 Mdot
.57151 .5753 Mdot
.69959 .4296 Mdot
.66212 .48095 Mdot
.56125 .60915 Mdot
.20861 .38741 Mdot
.49191 .39575 Mdot
.54979 .38835 Mdot
.5428 .6425 Mdot
.50569 .62871 Mdot
.64754 .44285 Mdot
.34585 .44877 Mdot
.3595 .26612 Mdot
.36781 .60492 Mdot
.55625 .68755 Mdot
.51483 .63759 Mdot
.70024 .34902 Mdot
.46772 .3487 Mdot
.48767 .24297 Mdot
.54385 .64663 Mdot
.65596 .35566 Mdot
.54278 .64772 Mdot
.49979 .57777 Mdot
.34294 .4264 Mdot
.54436 .57289 Mdot
.56841 .58589 Mdot
.46231 .66381 Mdot
.47228 .37573 Mdot
.67898 .4413 Mdot
.70102 .47872 Mdot
.49032 .24004 Mdot
.50513 .38212 Mdot
.51815 .63723 Mdot
.46441 .36785 Mdot
.51842 .65731 Mdot
.55168 .63229 Mdot
.48816 .3539 Mdot
.65295 .45721 Mdot
.39479 .38157 Mdot
.59433 .73786 Mdot
.5348 .65283 Mdot
.54168 .58872 Mdot
.47909 .77649 Mdot
.76761 .337 Mdot
.56789 .58887 Mdot
.69336 .46555 Mdot
.56692 .60805 Mdot
.49606 .38847 Mdot
.35469 .57859 Mdot
.68389 .44753 Mdot
.30316 .41401 Mdot
.34698 .41805 Mdot
.46303 .31282 Mdot
.46472 .23983 Mdot
.54819 .58499 Mdot
.63512 .50063 Mdot
.70388 .44679 Mdot
.45126 .18332 Mdot
.31732 .45205 Mdot
.3477 .61154 Mdot
.54406 .65822 Mdot
.56056 .48129 Mdot
.49661 .33342 Mdot
.13428 .36773 Mdot
.64024 .34922 Mdot
.40335 .61745 Mdot
.72834 .33014 Mdot
.47424 .23134 Mdot
.59443 .60596 Mdot
.39579 .60643 Mdot
.34614 .40973 Mdot
.52036 .65639 Mdot
.55669 .7034 Mdot
.41729 .40506 Mdot
.34428 .47842 Mdot
.4655 .37034 Mdot
.32921 .40118 Mdot
.39687 .62209 Mdot
.46393 .23362 Mdot
.65502 .47332 Mdot
.5902 .63954 Mdot
.58493 .53988 Mdot
.3189 .44999 Mdot
.47136 .21697 Mdot
.54034 .63905 Mdot
.6561 .47957 Mdot
.36474 .43328 Mdot
.56428 .64954 Mdot
.72281 .52456 Mdot
.67695 .39817 Mdot
.32029 .44041 Mdot
.50582 .60496 Mdot
.6431 .59692 Mdot
.30139 .42529 Mdot
.30571 .44049 Mdot
.55943 .61764 Mdot
.35718 .58376 Mdot
.59004 .59443 Mdot
.50051 .34322 Mdot
.27916 .43193 Mdot
.49776 .38499 Mdot
.43554 .65643 Mdot
.49488 .63698 Mdot
.63678 .26056 Mdot
.65754 .41757 Mdot
.35825 .63281 Mdot
.66264 .7186 Mdot
.50777 .61172 Mdot
.17981 .53923 Mdot
.40813 .54037 Mdot
.32314 .22904 Mdot
.25714 .71474 Mdot
.38241 .60734 Mdot
.50636 .36894 Mdot
.55324 .61496 Mdot
.53473 .36438 Mdot
.38323 .58612 Mdot
.44506 .66593 Mdot
.50719 .60318 Mdot
.6653 .46968 Mdot
.54358 .62341 Mdot
.65981 .42253 Mdot
.56522 .60143 Mdot
.61961 .66522 Mdot
.33971 .56838 Mdot
.53323 .76923 Mdot
.52337 .59202 Mdot
.51395 .83021 Mdot
.54776 .47625 Mdot
.37522 .61386 Mdot
.52997 .63632 Mdot
.4841 .23672 Mdot
.50877 .39724 Mdot
.3261 .72034 Mdot
.34001 .43068 Mdot
.49822 .35096 Mdot
.65202 .43789 Mdot
.3157 .39395 Mdot
.48942 .22746 Mdot
.59591 .53762 Mdot
.37366 .62588 Mdot
.512 .36545 Mdot
.59309 .6286 Mdot
.59244 .65273 Mdot
.34636 .53758 Mdot
.5797 .18188 Mdot
.64091 .48625 Mdot
.67053 .78346 Mdot
.69965 .41726 Mdot
.36321 .59534 Mdot
.34095 .42487 Mdot
.58354 .59459 Mdot
.57081 .638 Mdot
.34074 .46563 Mdot
.69487 .46719 Mdot
.33262 .48291 Mdot
.78494 .51549 Mdot
.35568 .39783 Mdot
.46963 .73254 Mdot
.68902 .44566 Mdot
.47628 .73497 Mdot
.39438 .62546 Mdot
.22933 .63441 Mdot
.37319 .71918 Mdot
.50968 .34825 Mdot
.46269 .72881 Mdot
.69121 .45958 Mdot
.55231 .64541 Mdot
.47513 .22656 Mdot
.47152 .24842 Mdot
.65657 .43017 Mdot
.35732 .43365 Mdot
.36113 .61908 Mdot
.55198 .61921 Mdot
.65343 .31405 Mdot
.54162 .28475 Mdot
.33539 .39256 Mdot
.50058 .56617 Mdot
.48269 .38688 Mdot
.5542 .59274 Mdot
.39055 .60295 Mdot
.49946 .35947 Mdot
.48895 .25794 Mdot
.58079 .40009 Mdot
.54626 .66011 Mdot
.65513 .36739 Mdot
.50851 .37621 Mdot
.7192 .26457 Mdot
.5655 .63013 Mdot
.47165 .3688 Mdot
.61013 .69245 Mdot
.56666 .24682 Mdot
.47647 .5093 Mdot
.17988 .46889 Mdot
.35075 .47614 Mdot
.35033 .42011 Mdot
.51707 .1946 Mdot
.33247 .58414 Mdot
.51569 .36057 Mdot
.46386 .23108 Mdot
.38301 .69102 Mdot
.47967 .3864 Mdot
.60275 .62795 Mdot
.5849 .66384 Mdot
.7764 .52777 Mdot
.48754 .47971 Mdot
.47368 .21466 Mdot
.61087 .51029 Mdot
.52964 .60537 Mdot
.55964 .56387 Mdot
.57238 .62649 Mdot
.71233 .43847 Mdot
.49169 .39869 Mdot
.52691 .84695 Mdot
.48502 .39545 Mdot
.66307 .3187 Mdot
.32188 .44589 Mdot
.33821 .39171 Mdot
.59484 .62842 Mdot
.66947 .2591 Mdot
.31153 .71138 Mdot
.54939 .58788 Mdot
.41509 .61653 Mdot
.40658 .6592 Mdot
.58264 .56532 Mdot
.70326 .47942 Mdot
.56284 .54264 Mdot
.71453 .42019 Mdot
.49557 .3576 Mdot
.38458 .60481 Mdot
.35906 .56365 Mdot
.50901 .36068 Mdot
.58487 .63835 Mdot
.42356 .61187 Mdot
.57775 .64913 Mdot
.54808 .64487 Mdot
.69384 .33575 Mdot
.34342 .60422 Mdot
.3346 .42086 Mdot
.36247 .58804 Mdot
.66447 .43757 Mdot
.44352 .10575 Mdot
.38043 .59247 Mdot
.60581 .44525 Mdot
.38551 .50783 Mdot
.46631 .72926 Mdot
.65806 .47899 Mdot
.37764 .57673 Mdot
.47129 .38184 Mdot
.31759 .23047 Mdot
.74561 .30273 Mdot
.51598 .3416 Mdot
.56646 .63542 Mdot
.63846 .44167 Mdot
.70782 .43863 Mdot
.50626 .32795 Mdot
.65691 .4708 Mdot
.50538 .59064 Mdot
.54301 .65201 Mdot
.51565 .36071 Mdot
.56974 .31551 Mdot
.49358 .40025 Mdot
.58529 .45867 Mdot
.53428 .63845 Mdot
.6841 .44541 Mdot
.49902 .5912 Mdot
.65758 .49375 Mdot
.4748 .25368 Mdot
.51454 .65076 Mdot
.35205 .60238 Mdot
.48559 .47013 Mdot
.32199 .44195 Mdot
.29579 .35173 Mdot
.6459 .43197 Mdot
.5419 .38512 Mdot
.64704 .46125 Mdot
.64929 .41977 Mdot
.52686 .36166 Mdot
.67551 .43461 Mdot
.55215 .61637 Mdot
.38597 .49011 Mdot
.67567 .42168 Mdot
.49371 .3738 Mdot
.35872 .61502 Mdot
.65203 .45288 Mdot
.31149 .393 Mdot
.55705 .65154 Mdot
.32009 .41286 Mdot
.39018 .63497 Mdot
.63671 .45013 Mdot
.37362 .57587 Mdot
.31886 .45174 Mdot
.38094 .62495 Mdot
.22244 .50745 Mdot
.46455 .38051 Mdot
.69662 .3185 Mdot
.61951 .72076 Mdot
.69809 .42921 Mdot
.37798 .4286 Mdot
.57607 .59014 Mdot
.55402 .6551 Mdot
.39835 .61619 Mdot
.70702 .43877 Mdot
.18639 .42774 Mdot
.63938 .60222 Mdot
.57271 .3741 Mdot
.46044 .36283 Mdot
.70993 .75484 Mdot
.60323 .37475 Mdot
.30572 .26033 Mdot
.61661 .61903 Mdot
.47446 .23068 Mdot
.58144 .65056 Mdot
.62042 .77955 Mdot
.351 .5819 Mdot
.3949 .32055 Mdot
.61709 .64132 Mdot
.33275 .42969 Mdot
.57268 .60805 Mdot
.40239 .79137 Mdot
.55344 .54496 Mdot
.3879 .58636 Mdot
.45211 .36949 Mdot
.62899 .45761 Mdot
.36672 .61395 Mdot
.34101 .41316 Mdot
.41463 .70155 Mdot
.51189 .59463 Mdot
.53648 .60119 Mdot
.37617 .43811 Mdot
.66237 .47018 Mdot
.32968 .45997 Mdot
.47177 .36583 Mdot
.37863 .59475 Mdot
.53054 .65345 Mdot
.54355 .56856 Mdot
.3096 .3825 Mdot
.4872 .39942 Mdot
.31873 .39641 Mdot
.46867 .35069 Mdot
.47401 .22966 Mdot
.53617 .5865 Mdot
.37484 .43619 Mdot
.58181 .66955 Mdot
.65926 .73727 Mdot
.70539 .33551 Mdot
.72812 .6709 Mdot
.33299 .41895 Mdot
.45411 .7433 Mdot
.50277 .37663 Mdot
.47889 .34364 Mdot
.80501 .6016 Mdot
.29907 .68392 Mdot
.30541 .49692 Mdot
.50868 .8198 Mdot
.47189 .36463 Mdot
.49738 .3819 Mdot
.3497 .41127 Mdot
.67099 .43112 Mdot
.70224 .40193 Mdot
.33964 .38985 Mdot
.5474 .76703 Mdot
.6872 .46292 Mdot
.17626 .52096 Mdot
.30233 .44257 Mdot
.61796 .64221 Mdot
.46149 .21936 Mdot
.38572 .60986 Mdot
.55026 .76516 Mdot
.46779 .80751 Mdot
.59301 .60661 Mdot
.80014 .42759 Mdot
.34745 .44253 Mdot
.41907 .44779 Mdot
.19335 .59312 Mdot
.50318 .62464 Mdot
.57892 .61315 Mdot
.58273 .63243 Mdot
.34239 .59006 Mdot
.6555 .72668 Mdot
.59471 .60964 Mdot
.51335 .76311 Mdot
.60378 .61815 Mdot
.37241 .75457 Mdot
.36374 .5878 Mdot
.55449 .52209 Mdot
.36267 .47049 Mdot
.61285 .29323 Mdot
.53754 .70761 Mdot
.46821 .36509 Mdot
.39547 .4345 Mdot
.48099 .36716 Mdot
.27378 .67835 Mdot
.37424 .71747 Mdot
.71095 .43117 Mdot
.55361 .5961 Mdot
.35491 .47031 Mdot
.64418 .43202 Mdot
.35527 .28961 Mdot
.51634 .10867 Mdot
.47288 .38899 Mdot
.83556 .40256 Mdot
.47935 .34286 Mdot
.47521 .25214 Mdot
.64915 .43736 Mdot
.74117 .46521 Mdot
.48098 .45882 Mdot
.65384 .45383 Mdot
.46202 .30491 Mdot
.70966 .47355 Mdot
.45736 .73586 Mdot
.63319 .43321 Mdot
.49732 .37222 Mdot
.46187 .38999 Mdot
.59061 .69507 Mdot
.57115 .59055 Mdot
.52967 .4335 Mdot
.60897 .7017 Mdot
.5624 .5915 Mdot
.32437 .42749 Mdot
.72515 .29711 Mdot
.29185 .41067 Mdot
.68488 .4274 Mdot
.47542 .33857 Mdot
.57744 .61152 Mdot
.53368 .65049 Mdot
.56005 .67651 Mdot
.6431 .77471 Mdot
.17774 .51762 Mdot
.55072 .63565 Mdot
.53071 .68522 Mdot
.34025 .41516 Mdot
.38349 .55389 Mdot
.56231 .80711 Mdot
.38343 .69988 Mdot
.56479 .66062 Mdot
.35917 .59759 Mdot
.34654 .58484 Mdot
.56387 .56895 Mdot
.64158 .28773 Mdot
.3845 .4779 Mdot
.59305 .62796 Mdot
.36486 .72503 Mdot
.29973 .40276 Mdot
.46602 .22041 Mdot
.31809 .44936 Mdot
.63658 .45902 Mdot
.47068 .24251 Mdot
.36655 .42737 Mdot
.73225 .48139 Mdot
.48967 .24468 Mdot
.57214 .25826 Mdot
.36052 .57545 Mdot
.57293 .63153 Mdot
.6883 .49207 Mdot
.33638 .46647 Mdot
.51161 .36263 Mdot
.67133 .45323 Mdot
.49199 .40548 Mdot
.37028 .54826 Mdot
.48162 .71253 Mdot
.46597 .24319 Mdot
.4702 .35654 Mdot
.58126 .40176 Mdot
.35883 .59456 Mdot
.52491 .35718 Mdot
.65666 .25211 Mdot
.59575 .57888 Mdot
.30195 .72458 Mdot
.54458 .59831 Mdot
.22929 .34104 Mdot
.48317 .3415 Mdot
.48303 .25813 Mdot
.58656 .64394 Mdot
.30342 .43017 Mdot
.62208 .66887 Mdot
.57329 .64878 Mdot
.31591 .4031 Mdot
.55097 .64166 Mdot
.39153 .60366 Mdot
.703 .40687 Mdot
.41568 .54175 Mdot
.77688 .6878 Mdot
.38273 .6232 Mdot
.46963 .1981 Mdot
.56299 .58995 Mdot
.24496 .56251 Mdot
.65537 .45643 Mdot
.50485 .63038 Mdot
.817 .51806 Mdot
.67002 .4265 Mdot
.66285 .44915 Mdot
.52541 .62152 Mdot
.51949 .3527 Mdot
.30821 .43639 Mdot
.35796 .59344 Mdot
.37292 .2122 Mdot
.56747 .65137 Mdot
.56507 .61668 Mdot
.36826 .61577 Mdot
.49776 .38349 Mdot
.52854 .64882 Mdot
.33798 .31669 Mdot
.39874 .18513 Mdot
.5081 .34271 Mdot
.59017 .57151 Mdot
.34984 .78395 Mdot
.63353 .41631 Mdot
.80027 .36308 Mdot
.32619 .58759 Mdot
.35251 .43525 Mdot
.62322 .63303 Mdot
.16199 .32939 Mdot
.38439 .60998 Mdot
.62314 .3153 Mdot
.54662 .63393 Mdot
.57616 .60068 Mdot
.67302 .47895 Mdot
.52001 .63384 Mdot
.6961 .44671 Mdot
.79196 .6749 Mdot
.6583 .82002 Mdot
.64774 .45828 Mdot
.69296 .43066 Mdot
.6865 .50702 Mdot
.60668 .77575 Mdot
.65648 .43454 Mdot
.50189 .61266 Mdot
.2078 .52386 Mdot
.52277 .68557 Mdot
.38748 .62949 Mdot
.39363 .63867 Mdot
.73419 .42533 Mdot
.65531 .22093 Mdot
.62457 .57967 Mdot
.51077 .70627 Mdot
.50932 .5187 Mdot
.48895 .3449 Mdot
.55441 .66575 Mdot
.46409 .239 Mdot
.35073 .40356 Mdot
.51694 .55776 Mdot
.57509 .63528 Mdot
.66605 .41987 Mdot
.34113 .59468 Mdot
.51533 .3951 Mdot
.56206 .62177 Mdot
.32323 .47558 Mdot
.36978 .6029 Mdot
.68221 .42349 Mdot
.62143 .40786 Mdot
.36895 .62998 Mdot
.51807 .57646 Mdot
.56638 .5943 Mdot
.54029 .64015 Mdot
.55138 .71314 Mdot
.50896 .35678 Mdot
.31995 .38491 Mdot
.49983 .60827 Mdot
.6914 .34391 Mdot
.43095 .47019 Mdot
.53296 .57527 Mdot
.68552 .47073 Mdot
.50545 .33665 Mdot
.48621 .24768 Mdot
.42842 .69286 Mdot
.55272 .66117 Mdot
.18015 .52251 Mdot
.77249 .4967 Mdot
.47518 .24365 Mdot
.67573 .41246 Mdot
.35467 .59645 Mdot
.53242 .60775 Mdot
.21744 .56386 Mdot
.58839 .65884 Mdot
.63179 .68961 Mdot
.35037 .43891 Mdot
.4828 .34858 Mdot
.37935 .18962 Mdot
.34955 .40255 Mdot
.66424 .44778 Mdot
.16284 .43803 Mdot
.67971 .48556 Mdot
.6325 .47271 Mdot
.24331 .63657 Mdot
.49303 .35584 Mdot
.14939 .34815 Mdot
.76085 .3215 Mdot
.59817 .6507 Mdot
.4935 .39159 Mdot
.64714 .43739 Mdot
.55107 .597 Mdot
.70231 .44099 Mdot
.64566 .48369 Mdot
.53165 .66389 Mdot
.57297 .59582 Mdot
.53087 .76296 Mdot
.1687 .5493 Mdot
.3582 .58626 Mdot
.69145 .47155 Mdot
.75311 .53201 Mdot
.59315 .60509 Mdot
.58683 .65513 Mdot
.40928 .42756 Mdot
.38733 .58602 Mdot
.65663 .60732 Mdot
.54527 .64639 Mdot
.82276 .52574 Mdot
.54486 .58602 Mdot
.67164 .49724 Mdot
.51664 .34741 Mdot
.63928 .29249 Mdot
.32269 .46258 Mdot
.66382 .48379 Mdot
.3568 .6187 Mdot
.705 .47025 Mdot
.81291 .55683 Mdot
.48919 .35873 Mdot
.6922 .4516 Mdot
.29741 .41792 Mdot
.48606 .37017 Mdot
.50666 .34332 Mdot
.22538 .55097 Mdot
.32422 .39254 Mdot
.36909 .57064 Mdot
.47891 .37364 Mdot
.71853 .5344 Mdot
.49765 .36829 Mdot
.76397 .53229 Mdot
.56759 .58196 Mdot
.51075 .75711 Mdot
.60956 .36323 Mdot
.52942 .70033 Mdot
.49553 .40061 Mdot
.3757 .58289 Mdot
.51813 .61966 Mdot
.66052 .47281 Mdot
.38255 .59443 Mdot
.45027 .34243 Mdot
.30237 .41172 Mdot
.66825 .41535 Mdot
.51203 .34299 Mdot
.69526 .45119 Mdot
.46555 .69616 Mdot
.27599 .3873 Mdot
.5129 .52165 Mdot
.46536 .45829 Mdot
.5647 .67873 Mdot
.73852 .43126 Mdot
.56383 .57775 Mdot
.57571 .6396 Mdot
.31983 .4409 Mdot
.49507 .77922 Mdot
.65168 .45619 Mdot
.39451 .17926 Mdot
.47364 .35017 Mdot
.73256 .38239 Mdot
.63902 .58198 Mdot
.51457 .64677 Mdot
.6738 .42229 Mdot
.64655 .48567 Mdot
.72744 .68536 Mdot
.34201 .46461 Mdot
.52141 .69065 Mdot
.49172 .63266 Mdot
.61265 .67259 Mdot
.48301 .34039 Mdot
.35217 .32894 Mdot
.35555 .44915 Mdot
.7963 .30669 Mdot
.33726 .45354 Mdot
.2703 .52389 Mdot
.67639 .43411 Mdot
.34965 .5877 Mdot
.58894 .65298 Mdot
.57827 .74115 Mdot
.71828 .44082 Mdot
.40276 .4642 Mdot
.35416 .60339 Mdot
.38218 .35284 Mdot
.49554 .35299 Mdot
.5345 .58094 Mdot
.54263 .66797 Mdot
.52614 .63351 Mdot
.54338 .60789 Mdot
.46862 .3426 Mdot
.6026 .62883 Mdot
.45896 .35847 Mdot
.7165 .52207 Mdot
.82423 .5386 Mdot
.33003 .46946 Mdot
.31852 .70545 Mdot
.69637 .42521 Mdot
.72863 .54857 Mdot
.64735 .56945 Mdot
.70266 .33292 Mdot
.22646 .52922 Mdot
.55615 .58134 Mdot
.35874 .43132 Mdot
.40453 .79524 Mdot
.35455 .4697 Mdot
.73377 .79176 Mdot
.42954 .6255 Mdot
.17318 .4705 Mdot
.55083 .59908 Mdot
.31184 .38343 Mdot
.64488 .58395 Mdot
.57444 .56838 Mdot
.42909 .61448 Mdot
.60009 .44696 Mdot
.58596 .3138 Mdot
.35037 .61656 Mdot
.55942 .65164 Mdot
.62806 .45869 Mdot
.55102 .61625 Mdot
.58387 .65482 Mdot
.55564 .59054 Mdot
.52313 .39059 Mdot
.61061 .61738 Mdot
.59295 .59941 Mdot
.59016 .18122 Mdot
.45341 .75902 Mdot
.32067 .40839 Mdot
.75603 .65167 Mdot
.36997 .59387 Mdot
.6572 .42233 Mdot
.39861 .53082 Mdot
.50206 .34686 Mdot
.71646 .69853 Mdot
.5481 .59828 Mdot
.59802 .36108 Mdot
.51284 .34306 Mdot
.38482 .59876 Mdot
.48957 .2329 Mdot
.19516 .47784 Mdot
.33501 .46978 Mdot
.48822 .24999 Mdot
.32364 .44277 Mdot
.66818 .69146 Mdot
.66681 .42034 Mdot
.55306 .67664 Mdot
.47891 .38165 Mdot
.3063 .43104 Mdot
.47391 .78249 Mdot
.57549 .62357 Mdot
.33059 .41755 Mdot
.56003 .67899 Mdot
.41259 .48102 Mdot
.36909 .50765 Mdot
.36952 .44379 Mdot
.45912 .38926 Mdot
.48625 .37656 Mdot
.35618 .58236 Mdot
.65813 .4208 Mdot
.692 .4648 Mdot
.49636 .36062 Mdot
.81215 .38837 Mdot
.5727 .65235 Mdot
.55823 .59026 Mdot
.68001 .34456 Mdot
.55466 .60604 Mdot
.42979 .71824 Mdot
.46051 .24066 Mdot
.67505 .4176 Mdot
.54796 .60684 Mdot
.52965 .65033 Mdot
.54437 .65911 Mdot
.46884 .70234 Mdot
.32272 .45185 Mdot
.52979 .60592 Mdot
.39624 .61259 Mdot
.61426 .24111 Mdot
.57813 .58841 Mdot
.56365 .56562 Mdot
.69145 .45457 Mdot
.71854 .75429 Mdot
.50598 .34586 Mdot
.32393 .41913 Mdot
.30121 .4342 Mdot
.33879 .63493 Mdot
.67668 .40422 Mdot
.45814 .23776 Mdot
.43657 .24777 Mdot
.47181 .22134 Mdot
.37061 .61269 Mdot
.277 .49344 Mdot
.33453 .48028 Mdot
.33053 .40638 Mdot
.46063 .37626 Mdot
.54503 .60917 Mdot
.54979 .58654 Mdot
.62641 .31506 Mdot
.51616 .61004 Mdot
.35539 .60865 Mdot
.51799 .36916 Mdot
.68862 .4563 Mdot
.38548 .61272 Mdot
.46649 .35998 Mdot
.66451 .47152 Mdot
.59112 .57669 Mdot
.60102 .58474 Mdot
.66663 .45292 Mdot
.64073 .44686 Mdot
.59013 .60865 Mdot
.55527 .18095 Mdot
.63614 .43246 Mdot
.69087 .4487 Mdot
.48525 .21462 Mdot
.33767 .47061 Mdot
.51465 .57232 Mdot
.49297 .39245 Mdot
.5413 .64072 Mdot
.34165 .47262 Mdot
.38273 .58169 Mdot
.66446 .46293 Mdot
.53726 .65279 Mdot
.55612 .64126 Mdot
.3583 .59818 Mdot
.35188 .62199 Mdot
.37096 .62172 Mdot
.52635 .39894 Mdot
.5371 .62336 Mdot
.65499 .43751 Mdot
.49099 .3547 Mdot
.34643 .58518 Mdot
.38724 .57462 Mdot
.62458 .19383 Mdot
.59519 .61333 Mdot
.48167 .51181 Mdot
.39755 .12886 Mdot
.4062 .70178 Mdot
.48212 .25273 Mdot
.36991 .41784 Mdot
.49295 .74982 Mdot
.31474 .60297 Mdot
.49806 .39438 Mdot
.31732 .66866 Mdot
.36026 .63349 Mdot
.53057 .6665 Mdot
.53877 .59056 Mdot
.57123 .68511 Mdot
.37378 .60058 Mdot
.45732 .69018 Mdot
.70741 .44562 Mdot
.70176 .60986 Mdot
.37019 .59398 Mdot
.36936 .44346 Mdot
.37389 .43655 Mdot
.33868 .45354 Mdot
.54349 .58071 Mdot
.71956 .68808 Mdot
.73541 .53137 Mdot
.66935 .63786 Mdot
.49881 .35168 Mdot
.65248 .48853 Mdot
.23287 .53524 Mdot
.66167 .45055 Mdot
.35798 .41121 Mdot
.37476 .60449 Mdot
.68426 .47589 Mdot
.50806 .38264 Mdot
.49504 .38443 Mdot
.30161 .41532 Mdot
.31385 .445 Mdot
.31377 .42664 Mdot
.63837 .46732 Mdot
.67549 .4344 Mdot
.5363 .65848 Mdot
.67149 .46129 Mdot
.78891 .41168 Mdot
.4058 .61544 Mdot
.37329 .44552 Mdot
.50562 .3784 Mdot
.65332 .42703 Mdot
.57075 .63204 Mdot
.31694 .5196 Mdot
.4362 .3499 Mdot
.38912 .61897 Mdot
.26193 .42674 Mdot
.79733 .72274 Mdot
.55379 .67121 Mdot
.4642 .35812 Mdot
.63923 .27654 Mdot
.58181 .62595 Mdot
.34348 .43444 Mdot
.6327 .7681 Mdot
.47286 .21829 Mdot
.59089 .597 Mdot
.50752 .62488 Mdot
.52714 .36682 Mdot
.37953 .51826 Mdot
.51241 .63844 Mdot
.60794 .39452 Mdot
.49808 .40633 Mdot
.36056 .44479 Mdot
.4217 .17196 Mdot
.36331 .40252 Mdot
.54465 .77695 Mdot
.47887 .25115 Mdot
.53966 .66608 Mdot
.32265 .43027 Mdot
.39295 .61217 Mdot
.31686 .43269 Mdot
.68914 .41684 Mdot
.31694 .41554 Mdot
.56664 .61214 Mdot
.65726 .43684 Mdot
.5071 .38017 Mdot
.71505 .36862 Mdot
.60218 .19229 Mdot
.30306 .42941 Mdot
.49637 .23868 Mdot
.59224 .60111 Mdot
.66443 .54794 Mdot
.62294 .66573 Mdot
.56892 .58724 Mdot
.48129 .36515 Mdot
.67652 .42322 Mdot
.46154 .35947 Mdot
.56913 .55704 Mdot
.79067 .63421 Mdot
.48232 .34403 Mdot
.57664 .28123 Mdot
.36981 .61526 Mdot
.54437 .76455 Mdot
.57101 .64302 Mdot
.47657 .37517 Mdot
.53676 .62514 Mdot
.69835 .46722 Mdot
.53244 .46264 Mdot
.631 .24537 Mdot
.48062 .38331 Mdot
.19931 .38782 Mdot
.52288 .4751 Mdot
.54669 .5493 Mdot
.47357 .36826 Mdot
.68783 .70668 Mdot
.48583 .24102 Mdot
.36801 .6063 Mdot
.34378 .59543 Mdot
.37566 .62678 Mdot
.51735 .60664 Mdot
.54226 .53935 Mdot
.37648 .56935 Mdot
.49889 .40801 Mdot
.39427 .5951 Mdot
.54035 .75633 Mdot
.19977 .40468 Mdot
.37798 .62219 Mdot
.56481 .63917 Mdot
.57352 .56574 Mdot
.45479 .76163 Mdot
.36612 .43685 Mdot
.1804 .5441 Mdot
.77026 .42462 Mdot
.58239 .59503 Mdot
.60436 .54108 Mdot
.69321 .42116 Mdot
.67367 .27731 Mdot
.62681 .55397 Mdot
.36187 .52081 Mdot
.69413 .43598 Mdot
.34354 .49225 Mdot
.66887 .41712 Mdot
.56375 .67247 Mdot
.55136 .63092 Mdot
.71412 .41584 Mdot
.2984 .34402 Mdot
.54771 .2317 Mdot
.26413 .28943 Mdot
.69419 .46413 Mdot
.47253 .37611 Mdot
.4685 .3809 Mdot
.49019 .35168 Mdot
.32108 .46032 Mdot
.63909 .46031 Mdot
.53545 .61673 Mdot
.34884 .42219 Mdot
.56916 .6592 Mdot
.48297 .37202 Mdot
.37421 .19224 Mdot
.69048 .45464 Mdot
.59206 .6314 Mdot
.74463 .30291 Mdot
.3342 .44886 Mdot
.36032 .59469 Mdot
.4166 .46736 Mdot
.3253 .38377 Mdot
.49331 .40097 Mdot
.64889 .40775 Mdot
.49213 .41639 Mdot
.40918 .55415 Mdot
.56541 .69122 Mdot
.52712 .58139 Mdot
.40878 .19339 Mdot
.6814 .24015 Mdot
.52852 .59312 Mdot
.34058 .41252 Mdot
.35965 .45948 Mdot
.54514 .65481 Mdot
.65229 .47225 Mdot
.35362 .57444 Mdot
.38794 .62579 Mdot
.51573 .65829 Mdot
.48116 .45636 Mdot
.52073 .76152 Mdot
.52228 .64224 Mdot
.49106 .66531 Mdot
.30694 .4028 Mdot
.49036 .23206 Mdot
.64453 .35787 Mdot
.34853 .60576 Mdot
.54577 .63663 Mdot
.53913 .25136 Mdot
.69602 .44356 Mdot
.31598 .41956 Mdot
.515 .36738 Mdot
.43227 .60975 Mdot
.30008 .43689 Mdot
.54452 .65418 Mdot
.52889 .64917 Mdot
.52642 .36258 Mdot
.67294 .49689 Mdot
.37599 .60299 Mdot
.34774 .42234 Mdot
.34825 .5902 Mdot
.66814 .43722 Mdot
.68618 .45397 Mdot
.49689 .66253 Mdot
.56237 .71255 Mdot
.30164 .43139 Mdot
.52713 .67753 Mdot
.36527 .4207 Mdot
.35457 .53977 Mdot
.49204 .33234 Mdot
.50491 .63516 Mdot
.62399 .44923 Mdot
.48452 .36684 Mdot
.58239 .60311 Mdot
.45079 .19674 Mdot
.52252 .65528 Mdot
.32262 .38412 Mdot
.79806 .62524 Mdot
.38033 .58218 Mdot
.66153 .38284 Mdot
.4584 .63486 Mdot
.55584 .60667 Mdot
.36763 .42025 Mdot
.62511 .61922 Mdot
.49654 .3408 Mdot
.68374 .43086 Mdot
.87103 .49892 Mdot
.4941 .3705 Mdot
.55019 .61996 Mdot
.38039 .59505 Mdot
.63201 .47611 Mdot
.46675 .23502 Mdot
.64401 .35236 Mdot
.52735 .552 Mdot
.61462 .61441 Mdot
.54595 .61149 Mdot
.51711 .82344 Mdot
.32168 .42373 Mdot
.64968 .43203 Mdot
.48401 .33738 Mdot
.50323 .36097 Mdot
.34691 .44837 Mdot
.58792 .33922 Mdot
.27978 .36294 Mdot
.31313 .16473 Mdot
.31319 .4083 Mdot
.39639 .59611 Mdot
.45347 .46895 Mdot
.34617 .40015 Mdot
.3284 .42749 Mdot
.29875 .42593 Mdot
.61421 .34599 Mdot
.67467 .47388 Mdot
.55519 .64194 Mdot
.67787 .40556 Mdot
.53113 .66204 Mdot
.52961 .79359 Mdot
.4966 .3589 Mdot
.68296 .43179 Mdot
.43637 .19352 Mdot
.61698 .69008 Mdot
.57855 .61736 Mdot
.21686 .46296 Mdot
.5863 .55414 Mdot
.44908 .71494 Mdot
.51477 .57752 Mdot
.31702 .44443 Mdot
.58715 .53356 Mdot
.62177 .64048 Mdot
.77322 .39915 Mdot
.50239 .38523 Mdot
.47046 .25115 Mdot
.59946 .58951 Mdot
.49772 .58088 Mdot
.63204 .4748 Mdot
.6845 .47594 Mdot
.3738 .56882 Mdot
.43893 .44043 Mdot
.50532 .38298 Mdot
.3358 .3673 Mdot
.56918 .59125 Mdot
.47993 .31359 Mdot
.80983 .58846 Mdot
.58459 .60581 Mdot
.21511 .54425 Mdot
.71995 .69462 Mdot
.51359 .64182 Mdot
.68472 .65136 Mdot
.49982 .3786 Mdot
.82125 .52331 Mdot
.56317 .68393 Mdot
.34252 .43517 Mdot
.67418 .43068 Mdot
.68568 .41764 Mdot
.38582 .61829 Mdot
.78349 .38553 Mdot
.47145 .39631 Mdot
.67828 .43299 Mdot
.57996 .63017 Mdot
.51097 .35912 Mdot
.46806 .24402 Mdot
.59987 .57492 Mdot
.27871 .65131 Mdot
.67663 .46096 Mdot
.51922 .68008 Mdot
.55158 .33102 Mdot
.41658 .48762 Mdot
.16539 .56814 Mdot
.48658 .35132 Mdot
.35358 .61458 Mdot
.50802 .58261 Mdot
.43392 .243 Mdot
.5991 .66826 Mdot
.51175 .77285 Mdot
.71613 .39638 Mdot
.35415 .57908 Mdot
.58632 .6291 Mdot
.51226 .63553 Mdot
.47573 .46593 Mdot
.34957 .61785 Mdot
.51456 .64894 Mdot
.50834 .67811 Mdot
.66458 .47054 Mdot
.46239 .24538 Mdot
.68369 .46022 Mdot
.56639 .63445 Mdot
.59026 .53034 Mdot
.66429 .47708 Mdot
.24392 .40547 Mdot
.34081 .613 Mdot
.50078 .3452 Mdot
.47732 .61008 Mdot
.56685 .58286 Mdot
.33345 .79672 Mdot
.47502 .25364 Mdot
.6016 .79763 Mdot
.33757 .38827 Mdot
.50383 .24875 Mdot
.28331 .39428 Mdot
.17467 .45556 Mdot
.67757 .36191 Mdot
.54766 .68981 Mdot
.34296 .70425 Mdot
.67828 .64164 Mdot
.4682 .38626 Mdot
.69258 .54227 Mdot
.57133 .59046 Mdot
.58236 .65298 Mdot
.35414 .41772 Mdot
.58528 .35537 Mdot
.63555 .27966 Mdot
.50502 .44611 Mdot
.37973 .60598 Mdot
.67596 .43885 Mdot
.56409 .60464 Mdot
.31063 .29968 Mdot
.31672 .41077 Mdot
.5633 .47522 Mdot
.58969 .63897 Mdot
.6627 .3118 Mdot
.59855 .30575 Mdot
.51158 .35822 Mdot
.36756 .41539 Mdot
.3224 .38529 Mdot
.57653 .66635 Mdot
.50735 .38746 Mdot
.53053 .65643 Mdot
.55096 .4673 Mdot
.52301 .67925 Mdot
.38841 .6015 Mdot
.5986 .63935 Mdot
.47036 .49353 Mdot
.15264 .48764 Mdot
.58265 .54752 Mdot
.64136 .4306 Mdot
.32128 .45939 Mdot
.33216 .45294 Mdot
.69327 .46387 Mdot
.33718 .45223 Mdot
.70609 .61865 Mdot
.80131 .54096 Mdot
.37932 .61241 Mdot
.64403 .53728 Mdot
.38674 .59607 Mdot
.47065 .2518 Mdot
.5917 .60617 Mdot
.44558 .26915 Mdot
.30914 .41205 Mdot
.67133 .76122 Mdot
.49947 .36613 Mdot
.47453 .2528 Mdot
.60607 .63284 Mdot
.27666 .49646 Mdot
.36055 .41897 Mdot
.3771 .39466 Mdot
.54423 .65953 Mdot
.68501 .4732 Mdot
.51274 .63557 Mdot
.50518 .65026 Mdot
.48809 .24941 Mdot
.54487 .61155 Mdot
.46636 .36074 Mdot
.64014 .4641 Mdot
.18413 .44865 Mdot
.33229 .46606 Mdot
.59493 .64299 Mdot
.58076 .62986 Mdot
.69855 .46893 Mdot
.60386 .62154 Mdot
.49918 .39602 Mdot
.10012 .42276 Mdot
.36947 .6142 Mdot
.48811 .22445 Mdot
.36205 .38272 Mdot
.5432 .59108 Mdot
.51742 .63837 Mdot
.39919 .19574 Mdot
.58033 .21496 Mdot
.46749 .36134 Mdot
.49697 .61805 Mdot
.33918 .41534 Mdot
.38323 .59742 Mdot
.51388 .39418 Mdot
.53825 .6422 Mdot
.58666 .65081 Mdot
.38839 .60361 Mdot
.21046 .51964 Mdot
.38063 .48633 Mdot
.49537 .35105 Mdot
.61187 .53496 Mdot
.32808 .5235 Mdot
.57306 .65079 Mdot
.26175 .32374 Mdot
.68913 .44843 Mdot
.4743 .36196 Mdot
.63958 .73046 Mdot
.55071 .67688 Mdot
.49112 .3993 Mdot
.50521 .38209 Mdot
.59402 .6571 Mdot
.67264 .4044 Mdot
.63942 .47406 Mdot
.69213 .44559 Mdot
.79685 .63493 Mdot
.42798 .77972 Mdot
.31296 .42703 Mdot
.49904 .38079 Mdot
.36294 .45962 Mdot
.35312 .57321 Mdot
.43308 .46893 Mdot
.36401 .45427 Mdot
.68932 .41965 Mdot
.37482 .44088 Mdot
.52644 .6524 Mdot
.50438 .38633 Mdot
.33069 .4057 Mdot
.53742 .59481 Mdot
.5055 .68763 Mdot
.50349 .49708 Mdot
.35564 .57377 Mdot
.38896 .49315 Mdot
.55676 .62496 Mdot
.48742 .24708 Mdot
.59287 .61529 Mdot
.51557 .3597 Mdot
.45172 .49756 Mdot
.53489 .59923 Mdot
.30172 .42802 Mdot
.43052 .56504 Mdot
.3621 .44591 Mdot
.49729 .64251 Mdot
.56525 .63404 Mdot
.57551 .65172 Mdot
.51184 .6375 Mdot
.58353 .29654 Mdot
.46023 .35632 Mdot
.47478 .63067 Mdot
.32372 .47215 Mdot
.66074 .45576 Mdot
.70947 .45396 Mdot
.31459 .50051 Mdot
.49184 .24296 Mdot
.49643 .3901 Mdot
.57143 .65169 Mdot
.37926 .39703 Mdot
.36335 .19927 Mdot
.26128 .31394 Mdot
.24182 .5455 Mdot
.33675 .4092 Mdot
.64118 .43206 Mdot
.33352 .4001 Mdot
.57526 .66314 Mdot
.53737 .56796 Mdot
.1809 .45831 Mdot
.4993 .32246 Mdot
.37429 .60332 Mdot
.57179 .65949 Mdot
.55254 .77383 Mdot
.34033 .41523 Mdot
.30994 .39965 Mdot
.54036 .66395 Mdot
.65301 .48298 Mdot
.15124 .5932 Mdot
.51556 .36583 Mdot
.66964 .54692 Mdot
.66525 .38642 Mdot
.59906 .45634 Mdot
.50861 .36142 Mdot
.5097 .50824 Mdot
.34725 .45604 Mdot
.77427 .41853 Mdot
.66527 .45575 Mdot
.37051 .60076 Mdot
.52619 .57608 Mdot
.68388 .41752 Mdot
.36649 .41134 Mdot
.68625 .42236 Mdot
.55236 .67456 Mdot
.46265 .37303 Mdot
.34932 .44907 Mdot
.45466 .3596 Mdot
.71548 .41764 Mdot
.38554 .59009 Mdot
.55112 .76099 Mdot
.68296 .53888 Mdot
.71861 .696 Mdot
.53004 .60605 Mdot
.38608 .43559 Mdot
.53491 .62513 Mdot
.63528 .47715 Mdot
.56986 .64244 Mdot
.73759 .43903 Mdot
.33719 .39173 Mdot
.52199 .68141 Mdot
.59786 .60975 Mdot
.7406 .48984 Mdot
.583 .61373 Mdot
.60471 .63904 Mdot
.50922 .6236 Mdot
.68587 .38416 Mdot
.51249 .67919 Mdot
.67798 .47503 Mdot
.62189 .32293 Mdot
.32855 .4299 Mdot
.37677 .56647 Mdot
.3804 .62863 Mdot
.51204 .76948 Mdot
.54456 .76583 Mdot
.59183 .34271 Mdot
.68303 .46616 Mdot
.47254 .38251 Mdot
.53188 .65721 Mdot
.64003 .72234 Mdot
.35036 .6322 Mdot
.34772 .45439 Mdot
.30703 .45211 Mdot
.57668 .70954 Mdot
.50145 .8277 Mdot
.51384 .67753 Mdot
.65087 .34755 Mdot
.52738 .67039 Mdot
.50559 .63321 Mdot
.29615 .42052 Mdot
.49989 .72691 Mdot
.53003 .60563 Mdot
.63202 .47491 Mdot
.36602 .59908 Mdot
.61667 .55624 Mdot
.41218 .63386 Mdot
.53936 .48726 Mdot
.75315 .44814 Mdot
.53971 .61232 Mdot
.3504 .42899 Mdot
.6652 .41591 Mdot
.68919 .34717 Mdot
.48841 .35579 Mdot
.61709 .37024 Mdot
.7358 .51172 Mdot
.24002 .43021 Mdot
.36994 .60265 Mdot
.21787 .53633 Mdot
.56627 .61206 Mdot
.31533 .4553 Mdot
.54536 .67077 Mdot
.35337 .20584 Mdot
.37514 .57681 Mdot
.71935 .44177 Mdot
.47249 .37719 Mdot
.70005 .46217 Mdot
.73232 .66795 Mdot
.49501 .53989 Mdot
.48596 .1993 Mdot
.34214 .47021 Mdot
.59509 .76346 Mdot
.65862 .42952 Mdot
.53777 .64881 Mdot
.34291 .15053 Mdot
.68766 .44728 Mdot
.69432 .46778 Mdot
.36786 .52368 Mdot
.43673 .65732 Mdot
.62301 .6089 Mdot
.69281 .42551 Mdot
.36455 .4626 Mdot
.36109 .58709 Mdot
.52067 .6142 Mdot
.51002 .62627 Mdot
.67623 .47826 Mdot
.36139 .41756 Mdot
.5742 .78269 Mdot
.31525 .44493 Mdot
.65713 .46748 Mdot
.33352 .44513 Mdot
.3819 .39108 Mdot
.32757 .41118 Mdot
.58692 .58906 Mdot
.56918 .65091 Mdot
.28268 .61163 Mdot
.68602 .45407 Mdot
.51672 .62811 Mdot
.54906 .63806 Mdot
.65516 .43471 Mdot
.34072 .48025 Mdot
.62236 .74669 Mdot
.55328 .59721 Mdot
.55954 .64713 Mdot
.35006 .58508 Mdot
.2974 .4689 Mdot
.3054 .29248 Mdot
.51875 .61951 Mdot
.39399 .6207 Mdot
.63639 .46399 Mdot
.59131 .61242 Mdot
.53473 .75401 Mdot
.2918 .42809 Mdot
.59401 .65247 Mdot
.46585 .23448 Mdot
.54744 .58771 Mdot
.15046 .586 Mdot
.59834 .63065 Mdot
.64688 .44023 Mdot
.67161 .4274 Mdot
.40862 .46151 Mdot
.66688 .44644 Mdot
.47454 .24988 Mdot
.48421 .37249 Mdot
.23968 .32901 Mdot
.4713 .24603 Mdot
.50457 .61749 Mdot
.76109 .32182 Mdot
.53532 .68093 Mdot
.59218 .58305 Mdot
.61123 .77475 Mdot
.47354 .2464 Mdot
.66825 .42263 Mdot
.304 .34187 Mdot
.50633 .6459 Mdot
.51524 .37084 Mdot
.56393 .567 Mdot
.59844 .64535 Mdot
.59709 .42082 Mdot
.76241 .67108 Mdot
.51655 .35734 Mdot
.52853 .56345 Mdot
.51913 .61989 Mdot
.64476 .22773 Mdot
.57424 .62611 Mdot
.38136 .621 Mdot
.69705 .45497 Mdot
.3274 .39749 Mdot
.36158 .60801 Mdot
.55756 .59764 Mdot
.37228 .59781 Mdot
.31553 .42315 Mdot
.4789 .3654 Mdot
.59235 .65077 Mdot
.38331 .63128 Mdot
.37879 .60409 Mdot
.53002 .62989 Mdot
.679 .43139 Mdot
.63023 .61273 Mdot
.58962 .60998 Mdot
.54145 .65098 Mdot
.69197 .46475 Mdot
.72308 .23957 Mdot
.56862 .66903 Mdot
.48704 .50915 Mdot
.71429 .43026 Mdot
.46443 .2192 Mdot
.33456 .40225 Mdot
.5802 .67256 Mdot
.49947 .35667 Mdot
.49014 .36163 Mdot
.36959 .47104 Mdot
.6922 .47667 Mdot
.36498 .43191 Mdot
.5751 .55121 Mdot
.56081 .71121 Mdot
.50047 .60483 Mdot
.86952 .50524 Mdot
.19178 .48684 Mdot
.64211 .4628 Mdot
.35358 .45223 Mdot
.50678 .44414 Mdot
.49467 .38834 Mdot
.37437 .45357 Mdot
.62633 .44239 Mdot
.63966 .44137 Mdot
.69476 .42414 Mdot
.3494 .59484 Mdot
.32182 .45585 Mdot
.69106 .48955 Mdot
.66428 .48443 Mdot
.53768 .65745 Mdot
.51907 .62142 Mdot
.73026 .42421 Mdot
.44382 .74967 Mdot
.38825 .59434 Mdot
.349 .43412 Mdot
.30302 .78791 Mdot
.5151 .3584 Mdot
.74298 .48614 Mdot
.54052 .59368 Mdot
.52134 .09884 Mdot
.49565 .65303 Mdot
.57816 .6289 Mdot
.63664 .46003 Mdot
.40058 .60589 Mdot
.37218 .58774 Mdot
.66041 .4289 Mdot
.70613 .40403 Mdot
.36507 .62255 Mdot
.23741 .55162 Mdot
.19723 .37429 Mdot
.66934 .35307 Mdot
.64866 .44107 Mdot
.67794 .53524 Mdot
.49831 .39853 Mdot
.7102 .41664 Mdot
.51495 .35193 Mdot
.32965 .42754 Mdot
.30454 .44157 Mdot
.52525 .3604 Mdot
.54936 .66065 Mdot
.31966 .41518 Mdot
.52931 .54946 Mdot
.20101 .45373 Mdot
.26954 .68807 Mdot
.55438 .20104 Mdot
.54655 .58529 Mdot
.64013 .28889 Mdot
.60714 .26318 Mdot
.55686 .61464 Mdot
.62331 .69101 Mdot
.37307 .60159 Mdot
.71469 .42299 Mdot
.50246 .39308 Mdot
.17179 .58039 Mdot
.57244 .65108 Mdot
.65168 .45723 Mdot
.50016 .38813 Mdot
.39466 .39193 Mdot
.6002 .40138 Mdot
.54138 .66601 Mdot
.20586 .26389 Mdot
.71919 .43163 Mdot
.32735 .3973 Mdot
.76483 .34852 Mdot
.68648 .40816 Mdot
.35821 .53051 Mdot
.32167 .38932 Mdot
.2834 .27545 Mdot
.65413 .42474 Mdot
.35853 .48604 Mdot
.66732 .43938 Mdot
.39027 .60692 Mdot
.65282 .40709 Mdot
.35204 .44479 Mdot
.5864 .62289 Mdot
.34479 .44801 Mdot
.39049 .59742 Mdot
.31453 .45661 Mdot
.5025 .39425 Mdot
.4819 .25113 Mdot
.491 .38212 Mdot
.42439 .47374 Mdot
.77237 .65439 Mdot
.48341 .34841 Mdot
.29744 .37512 Mdot
.5301 .59261 Mdot
.66673 .49793 Mdot
.32287 .39799 Mdot
.34525 .47474 Mdot
.44301 .45789 Mdot
.65464 .45053 Mdot
.35018 .44355 Mdot
.72684 .5206 Mdot
.79434 .31632 Mdot
.50231 .56559 Mdot
.38405 .75753 Mdot
.653 .43642 Mdot
.32982 .3907 Mdot
.67527 .34517 Mdot
.70762 .43381 Mdot
.31213 .41052 Mdot
.47404 .37303 Mdot
.50518 .36088 Mdot
.55855 .66464 Mdot
.47943 .32123 Mdot
.36196 .41 Mdot
.54751 .23961 Mdot
.69921 .45257 Mdot
.40071 .39648 Mdot
.38036 .62354 Mdot
.32695 .4226 Mdot
.61914 .65728 Mdot
.71382 .40628 Mdot
.31762 .46496 Mdot
.29364 .67787 Mdot
.34557 .81706 Mdot
.34887 .44357 Mdot
.69742 .45419 Mdot
.66303 .46362 Mdot
.60645 .56889 Mdot
.47543 .45862 Mdot
.36257 .42835 Mdot
.45073 .28474 Mdot
.51229 .77673 Mdot
.47352 .2297 Mdot
.69371 .24401 Mdot
.53148 .6041 Mdot
.53748 .62694 Mdot
.48983 .39119 Mdot
.57362 .61237 Mdot
.64623 .48134 Mdot
.58869 .58356 Mdot
.48337 .39846 Mdot
.35054 .45206 Mdot
.59598 .63239 Mdot
.37285 .5826 Mdot
.50456 .39662 Mdot
.52712 .37462 Mdot
.32727 .43872 Mdot
.69422 .42519 Mdot
.27323 .34634 Mdot
.31524 .44618 Mdot
.53929 .61067 Mdot
.47866 .24162 Mdot
.56062 .67678 Mdot
.26452 .62171 Mdot
.70638 .44854 Mdot
.33289 .39916 Mdot
.67269 .41241 Mdot
.49344 .37785 Mdot
.36237 .47417 Mdot
.57015 .6251 Mdot
.30794 .4164 Mdot
.31231 .6287 Mdot
.2462 .58343 Mdot
.67845 .48444 Mdot
.41388 .6137 Mdot
.69132 .47328 Mdot
.47238 .22967 Mdot
.36381 .6713 Mdot
.37325 .60982 Mdot
.33494 .41641 Mdot
.18674 .49628 Mdot
.30307 .41613 Mdot
.58249 .61119 Mdot
.5732 .59751 Mdot
.35199 .41469 Mdot
.36204 .58094 Mdot
.72292 .74551 Mdot
.49394 .52271 Mdot
.67076 .42077 Mdot
.74998 .40244 Mdot
.23619 .72223 Mdot
.48092 .41122 Mdot
.47846 .38759 Mdot
.48774 .61719 Mdot
.51729 .65002 Mdot
.52108 .3881 Mdot
.47797 .33697 Mdot
.35117 .57974 Mdot
.30948 .44556 Mdot
.63124 .49323 Mdot
.50733 .39835 Mdot
.4524 .63599 Mdot
.55449 .76931 Mdot
.59977 .56307 Mdot
.5495 .69743 Mdot
.54943 .57943 Mdot
.40983 .49088 Mdot
.4666 .35019 Mdot
.55637 .62865 Mdot
.49311 .65451 Mdot
.47171 .36117 Mdot
.38989 .60354 Mdot
.63783 .51002 Mdot
.34007 .44134 Mdot
.67048 .17344 Mdot
.59504 .64709 Mdot
.58848 .61855 Mdot
.49915 .35179 Mdot
.6593 .22215 Mdot
.64331 .45789 Mdot
.70182 .43556 Mdot
.32089 .42313 Mdot
.4409 .4549 Mdot
.59298 .59292 Mdot
.55715 .61846 Mdot
.33703 .42226 Mdot
.48373 .24941 Mdot
.52342 .19655 Mdot
.5571 .64036 Mdot
.50514 .37654 Mdot
.39752 .43204 Mdot
.46742 .34818 Mdot
.54978 .67084 Mdot
.58078 .60805 Mdot
.58969 .59177 Mdot
.51236 .64405 Mdot
.52553 .37437 Mdot
.56008 .61959 Mdot
.60927 .68371 Mdot
.68764 .42855 Mdot
.54555 .59943 Mdot
.50675 .7618 Mdot
.56292 .64553 Mdot
.37617 .58376 Mdot
.29168 .31365 Mdot
.57404 .65528 Mdot
.54542 .60142 Mdot
.49466 .51816 Mdot
.58579 .63429 Mdot
.51251 .35451 Mdot
.66366 .45919 Mdot
.4984 .38171 Mdot
.48392 .34007 Mdot
.35762 .46873 Mdot
.35319 .57735 Mdot
.60071 .66745 Mdot
.38145 .62552 Mdot
.59886 .68123 Mdot
.54853 .67394 Mdot
.35091 .49475 Mdot
.64685 .34813 Mdot
.32013 .58371 Mdot
.56879 .62901 Mdot
.32375 .42697 Mdot
.3247 .40031 Mdot
.32751 .69332 Mdot
.56263 .54292 Mdot
.51995 .3868 Mdot
.47666 .37584 Mdot
.42298 .71486 Mdot
.60687 .40456 Mdot
.38212 .5876 Mdot
.53544 .43221 Mdot
.54098 .58453 Mdot
.55109 .64607 Mdot
.56612 .5659 Mdot
.3632 .45663 Mdot
.4898 .24503 Mdot
.34334 .45681 Mdot
.48054 .20626 Mdot
.46468 .3501 Mdot
.55101 .58578 Mdot
.24496 .66371 Mdot
.66356 .48006 Mdot
.66489 .45937 Mdot
.50262 .40731 Mdot
.36455 .44204 Mdot
.61538 .58398 Mdot
.8758 .50639 Mdot
.72718 .45298 Mdot
.39534 .58521 Mdot
.55454 .61879 Mdot
.32527 .43539 Mdot
.66028 .48154 Mdot
.36527 .63159 Mdot
.55989 .58793 Mdot
.32083 .47182 Mdot
.56818 .64451 Mdot
.67503 .65639 Mdot
.68225 .42652 Mdot
.36417 .19595 Mdot
.68184 .48476 Mdot
.49669 .40131 Mdot
.47501 .34735 Mdot
.58229 .60418 Mdot
.83778 .43367 Mdot
.72111 .44398 Mdot
.45589 .35283 Mdot
.38911 .5841 Mdot
.4877 .22476 Mdot
.37269 .57207 Mdot
.35077 .40182 Mdot
.36738 .60155 Mdot
.30115 .43389 Mdot
.4249 .72907 Mdot
.71564 .47195 Mdot
.36624 .61185 Mdot
.62353 .20157 Mdot
.61066 .63101 Mdot
.34575 .58844 Mdot
.58408 .70502 Mdot
.73172 .39151 Mdot
.33743 .42599 Mdot
.363 .58149 Mdot
.53537 .64929 Mdot
.18983 .60425 Mdot
.47888 .34358 Mdot
.52058 .38479 Mdot
.60576 .66254 Mdot
.30011 .4141 Mdot
.69887 .4014 Mdot
.40257 .53048 Mdot
.46128 .22312 Mdot
.55813 .61984 Mdot
.55165 .585 Mdot
.70476 .46556 Mdot
.64086 .48506 Mdot
.5795 .60502 Mdot
.70849 .53677 Mdot
.56511 .61046 Mdot
.50635 .35808 Mdot
.64019 .44676 Mdot
.6652 .46274 Mdot
.36734 .41615 Mdot
.68937 .47781 Mdot
.53678 .69371 Mdot
.53348 .35474 Mdot
.50544 .59256 Mdot
.49206 .37263 Mdot
.45881 .49888 Mdot
.32466 .4632 Mdot
.1761 .56331 Mdot
.69939 .47334 Mdot
.54509 .60787 Mdot
.69417 .47096 Mdot
.36876 .62092 Mdot
.68379 .4556 Mdot
.64948 .418 Mdot
.57255 .59308 Mdot
.54031 .66623 Mdot
.47827 .24703 Mdot
.47058 .45699 Mdot
.68834 .43597 Mdot
.56144 .60896 Mdot
.53843 .68349 Mdot
.60058 .65297 Mdot
.49852 .47648 Mdot
.63695 .44712 Mdot
.77829 .53196 Mdot
.2654 .64793 Mdot
.68273 .43379 Mdot
.17578 .62673 Mdot
.46691 .22611 Mdot
.49189 .23471 Mdot
.47251 .40593 Mdot
.55601 .6433 Mdot
.36014 .44149 Mdot
.57734 .66245 Mdot
.51219 .56059 Mdot
.58555 .65291 Mdot
.38598 .58405 Mdot
.59086 .68113 Mdot
.48004 .22614 Mdot
.32013 .44934 Mdot
.55255 .59517 Mdot
.59451 .63987 Mdot
.49054 .24904 Mdot
.69089 .4822 Mdot
.64424 .43268 Mdot
.25813 .32964 Mdot
.38003 .61548 Mdot
.48299 .3618 Mdot
.55945 .66152 Mdot
.32272 .4252 Mdot
.34149 .45015 Mdot
.69865 .46416 Mdot
.34413 .43761 Mdot
.51597 .36405 Mdot
.57343 .62165 Mdot
.52298 .38395 Mdot
.38717 .5862 Mdot
.69652 .45586 Mdot
.56083 .66205 Mdot
.53862 .65763 Mdot
.67166 .42723 Mdot
.53053 .59208 Mdot
.3498 .58575 Mdot
.30571 .43903 Mdot
.64589 .43269 Mdot
.48488 .36941 Mdot
.37005 .42272 Mdot
.52824 .65107 Mdot
.39893 .83135 Mdot
.57152 .6101 Mdot
.54827 .65377 Mdot
.18239 .41488 Mdot
.48939 .62543 Mdot
.33767 .39323 Mdot
.71168 .4486 Mdot
.60062 .58521 Mdot
.51827 .79082 Mdot
.41139 .20717 Mdot
.3724 .45971 Mdot
.5504 .6152 Mdot
.17426 .54661 Mdot
.5494 .60638 Mdot
.39 .38349 Mdot
.36696 .49673 Mdot
.4446 .80192 Mdot
.55203 .69977 Mdot
.51817 .35244 Mdot
.47795 .24847 Mdot
.31506 .4008 Mdot
.69403 .69006 Mdot
.56273 .59706 Mdot
.68404 .71249 Mdot
.60256 .62915 Mdot
.50814 .36226 Mdot
.587 .71926 Mdot
.34824 .43529 Mdot
.77536 .39024 Mdot
.53621 .61688 Mdot
.63754 .44836 Mdot
.3731 .44705 Mdot
.47891 .21849 Mdot
.53743 .65244 Mdot
.38998 .62103 Mdot
.55503 .36566 Mdot
.5499 .70619 Mdot
.4904 .37073 Mdot
.54745 .63868 Mdot
.52828 .56118 Mdot
.81358 .4079 Mdot
.68352 .42515 Mdot
.47644 .38376 Mdot
.66516 .2668 Mdot
.52807 .59174 Mdot
.6515 .42676 Mdot
.66348 .45525 Mdot
.39028 .61374 Mdot
.56449 .40677 Mdot
.49763 .29044 Mdot
.29591 .72161 Mdot
.75125 .66145 Mdot
.36164 .40649 Mdot
.5707 .23345 Mdot
.52251 .61558 Mdot
.51138 .52584 Mdot
.5107 .35131 Mdot
.58824 .62213 Mdot
.78138 .62985 Mdot
.69219 .44695 Mdot
.56026 .63842 Mdot
.38824 .59886 Mdot
.56006 .38996 Mdot
.55188 .48901 Mdot
.31912 .7785 Mdot
.36986 .45836 Mdot
.53772 .57019 Mdot
.57505 .69876 Mdot
.46778 .21688 Mdot
.53516 .66787 Mdot
.32024 .39787 Mdot
.21156 .46697 Mdot
.36521 .57893 Mdot
.67349 .4818 Mdot
.4677 .22433 Mdot
.56491 .57534 Mdot
.5788 .67694 Mdot
.37902 .56763 Mdot
.53492 .63948 Mdot
.77287 .37552 Mdot
.48875 .27377 Mdot
.3236 .41084 Mdot
.68362 .42067 Mdot
.54378 .57988 Mdot
.48966 .2445 Mdot
.57227 .59453 Mdot
.69579 .50539 Mdot
.54214 .62465 Mdot
.56269 .35042 Mdot
.67354 .4313 Mdot
.48898 .37469 Mdot
.60868 .66061 Mdot
.58259 .64795 Mdot
.32225 .52332 Mdot
.51075 .56188 Mdot
.59776 .63379 Mdot
.63049 .4735 Mdot
.65715 .475 Mdot
.68148 .47322 Mdot
.317 .41426 Mdot
.65518 .35572 Mdot
.5016 .37071 Mdot
.60196 .60913 Mdot
.50776 .39794 Mdot
.46156 .61498 Mdot
.38893 .57522 Mdot
.20942 .659 Mdot
.55194 .59203 Mdot
.6816 .47055 Mdot
.54408 .2596 Mdot
.63723 .46595 Mdot
.29605 .45499 Mdot
.50532 .38333 Mdot
.68764 .44554 Mdot
.58101 .63871 Mdot
.49697 .45232 Mdot
.35755 .7983 Mdot
.49149 .38727 Mdot
.55666 .56541 Mdot
.36683 .46418 Mdot
.30512 .4524 Mdot
.17525 .65913 Mdot
.46931 .35207 Mdot
.60408 .25866 Mdot
.55868 .60742 Mdot
.66585 .47976 Mdot
.4889 .3486 Mdot
.50939 .34547 Mdot
.34047 .4276 Mdot
.5494 .66815 Mdot
.57657 .64841 Mdot
.46582 .23279 Mdot
.478 .37404 Mdot
.61208 .61847 Mdot
.52921 .66825 Mdot
.17834 .45338 Mdot
.64453 .50779 Mdot
.69095 .21183 Mdot
.57339 .55125 Mdot
.75208 .66903 Mdot
.44907 .48083 Mdot
.64181 .46448 Mdot
.56599 .66392 Mdot
.56307 .57176 Mdot
.35586 .40103 Mdot
.57192 .61665 Mdot
.3546 .45847 Mdot
.4792 .38982 Mdot
.22048 .67524 Mdot
.40959 .38685 Mdot
.22919 .53211 Mdot
.57835 .61451 Mdot
.59255 .45426 Mdot
.35978 .61116 Mdot
.52483 .39838 Mdot
.65124 .46435 Mdot
.53146 .58391 Mdot
.31659 .38781 Mdot
.33591 .41554 Mdot
.67074 .45229 Mdot
.60598 .28126 Mdot
.24986 .39947 Mdot
.51361 .64949 Mdot
.34024 .40216 Mdot
.4067 .36359 Mdot
.7112 .5473 Mdot
.49496 .32338 Mdot
.36917 .57753 Mdot
.35042 .45137 Mdot
.5283 .36861 Mdot
.69761 .50116 Mdot
.67677 .44529 Mdot
.71493 .45126 Mdot
.28854 .57301 Mdot
.36257 .43358 Mdot
.35655 .59796 Mdot
.63797 .37828 Mdot
.6787 .36502 Mdot
.38172 .58028 Mdot
.35121 .45211 Mdot
.65757 .47837 Mdot
.6521 .4609 Mdot
.66229 .45912 Mdot
.77399 .39178 Mdot
.70488 .44673 Mdot
.78108 .49006 Mdot
.54225 .68322 Mdot
.66154 .54985 Mdot
.54963 .60899 Mdot
.52315 .36555 Mdot
.6804 .42602 Mdot
.44855 .46611 Mdot
.50993 .60896 Mdot
.3222 .77696 Mdot
.55611 .62333 Mdot
.51921 .33295 Mdot
.55713 .64543 Mdot
.69131 .5198 Mdot
.71445 .42985 Mdot
.56796 .62712 Mdot
.48603 .32882 Mdot
.37915 .60088 Mdot
.61712 .47243 Mdot
.57474 .65448 Mdot
.58009 .3747 Mdot
.49216 .64862 Mdot
.20484 .45341 Mdot
.39734 .54626 Mdot
.39793 .59121 Mdot
.50392 .6732 Mdot
.37404 .42665 Mdot
.63055 .41458 Mdot
.65091 .5537 Mdot
.49051 .38671 Mdot
.67041 .75086 Mdot
.33191 .41549 Mdot
.58916 .71856 Mdot
.50026 .63535 Mdot
.34798 .59774 Mdot
.64187 .40758 Mdot
.50506 .35119 Mdot
.54418 .58838 Mdot
.5961 .65452 Mdot
.295 .63789 Mdot
.65178 .54359 Mdot
.60399 .65364 Mdot
.36087 .56882 Mdot
.7837 .53591 Mdot
.56004 .65387 Mdot
.34225 .47954 Mdot
.71037 .43072 Mdot
.58502 .68832 Mdot
.77525 .52598 Mdot
.5616 .60644 Mdot
.68305 .44908 Mdot
.70355 .46948 Mdot
.56489 .30567 Mdot
.39782 .59398 Mdot
.54208 .62516 Mdot
.36989 .54007 Mdot
.53753 .62086 Mdot
.50487 .36893 Mdot
.56755 .67005 Mdot
.3314 .42327 Mdot
.67203 .34331 Mdot
.31009 .42246 Mdot
.57135 .66665 Mdot
.6554 .4567 Mdot
.50168 .34757 Mdot
.27612 .59679 Mdot
.3492 .50856 Mdot
.78275 .49624 Mdot
.44275 .19551 Mdot
.35293 .58924 Mdot
.34239 .59954 Mdot
.46308 .37931 Mdot
.56669 .63274 Mdot
.38664 .5042 Mdot
.50863 .666 Mdot
.55861 .64875 Mdot
.5858 .65508 Mdot
.48236 .31851 Mdot
.49898 .38501 Mdot
.33855 .44699 Mdot
.57844 .60571 Mdot
.56188 .61078 Mdot
.6808 .43721 Mdot
.38021 .60348 Mdot
.31373 .41391 Mdot
.37257 .61745 Mdot
.31579 .44083 Mdot
.15346 .5908 Mdot
.57112 .55626 Mdot
.37996 .59949 Mdot
.46021 .37006 Mdot
.69139 .46665 Mdot
.47727 .25552 Mdot
.35699 .40699 Mdot
.34994 .43687 Mdot
.55835 .61725 Mdot
.69336 .45621 Mdot
.69773 .44395 Mdot
.35593 .61436 Mdot
.47855 .35792 Mdot
.57208 .66563 Mdot
.52942 .66241 Mdot
.33559 .72663 Mdot
.36974 .44065 Mdot
.7279 .5336 Mdot
.58128 .31361 Mdot
.56759 .63274 Mdot
.69021 .4265 Mdot
.59569 .62472 Mdot
.19479 .5772 Mdot
.68714 .41883 Mdot
.50911 .64091 Mdot
.62554 .39521 Mdot
.35516 .46721 Mdot
.54031 .30761 Mdot
.57114 .68362 Mdot
.39263 .19817 Mdot
.52659 .62133 Mdot
.15559 .4184 Mdot
.6049 .22251 Mdot
.58133 .58027 Mdot
.51185 .62356 Mdot
.32751 .75476 Mdot
.55522 .60542 Mdot
.47417 .22512 Mdot
.57329 .54912 Mdot
.64045 .43776 Mdot
.40825 .50713 Mdot
.28086 .42934 Mdot
.39479 .59118 Mdot
.32082 .42251 Mdot
.37001 .65168 Mdot
.38918 .60758 Mdot
.64985 .43685 Mdot
.50956 .62697 Mdot
.56287 .75552 Mdot
.29618 .45182 Mdot
.50636 .65423 Mdot
.50609 .36842 Mdot
.28511 .44395 Mdot
.34313 .46232 Mdot
.48492 .37487 Mdot
.60112 .61847 Mdot
.57079 .79417 Mdot
.31702 .49724 Mdot
.26788 .2771 Mdot
.49579 .35115 Mdot
.51184 .36606 Mdot
.70512 .34687 Mdot
.3951 .59232 Mdot
.29938 .65108 Mdot
.59465 .49235 Mdot
.51213 .38101 Mdot
.42407 .6902 Mdot
.30725 .40064 Mdot
.58246 .39286 Mdot
.71402 .42238 Mdot
.57185 .55816 Mdot
.58168 .64168 Mdot
.47545 .35829 Mdot
.59045 .73734 Mdot
.74098 .33991 Mdot
.49046 .38323 Mdot
.59774 .68753 Mdot
.56094 .39956 Mdot
.47529 .24034 Mdot
.46432 .23311 Mdot
.38708 .57883 Mdot
.24698 .41153 Mdot
.66456 .43649 Mdot
.34714 .60474 Mdot
.54896 .33264 Mdot
.54193 .63127 Mdot
.48074 .38227 Mdot
.47681 .25739 Mdot
.49413 .36129 Mdot
.3771 .58912 Mdot
.39477 .5843 Mdot
.68694 .42784 Mdot
.6437 .45803 Mdot
.74899 .68074 Mdot
.44494 .7266 Mdot
.54997 .60172 Mdot
.63991 .74078 Mdot
.69933 .45747 Mdot
.63153 .53699 Mdot
.3965 .61541 Mdot
.38263 .60421 Mdot
.68682 .61911 Mdot
.53751 .66025 Mdot
.40859 .40619 Mdot
.56907 .65484 Mdot
.36091 .67654 Mdot
.50191 .62583 Mdot
.34182 .43176 Mdot
.53785 .60297 Mdot
.28254 .33408 Mdot
.52205 .60582 Mdot
.59546 .64387 Mdot
.33057 .45587 Mdot
.61527 .59389 Mdot
.33202 .42147 Mdot
.55084 .67008 Mdot
.35582 .56688 Mdot
.3224 .42521 Mdot
.40797 .76865 Mdot
.48865 .50808 Mdot
.48907 .23624 Mdot
.39267 .59748 Mdot
.37913 .62494 Mdot
.52735 .77128 Mdot
.64838 .46098 Mdot
.69679 .49687 Mdot
.56587 .63308 Mdot
.31007 .3999 Mdot
.48988 .39188 Mdot
.56297 .60989 Mdot
.55027 .57168 Mdot
.59049 .67479 Mdot
.69216 .44338 Mdot
.36415 .44026 Mdot
.37515 .59603 Mdot
.33118 .40196 Mdot
.29635 .49692 Mdot
.29969 .43621 Mdot
.48534 .63318 Mdot
.59747 .5745 Mdot
.53553 .53566 Mdot
.67694 .72825 Mdot
.77714 .40904 Mdot
.67163 .44759 Mdot
.48416 .24094 Mdot
.38986 .57796 Mdot
.75075 .40759 Mdot
.66862 .47215 Mdot
.35334 .43733 Mdot
.5684 .64455 Mdot
.60861 .68047 Mdot
.56902 .48501 Mdot
.68465 .38779 Mdot
.49477 .77794 Mdot
.32194 .4587 Mdot
.47352 .23349 Mdot
.66947 .35071 Mdot
.71622 .38972 Mdot
.43976 .46755 Mdot
.59083 .64257 Mdot
.38994 .62184 Mdot
.66044 .48159 Mdot
.29356 .59328 Mdot
.47408 .36659 Mdot
.47453 .45786 Mdot
.57715 .61474 Mdot
.56458 .24975 Mdot
.6556 .45613 Mdot
.3871 .59473 Mdot
.47491 .3582 Mdot
.39904 .59916 Mdot
.46446 .22708 Mdot
.25031 .33959 Mdot
.5325 .63222 Mdot
.59837 .62173 Mdot
.45795 .35483 Mdot
.66348 .43876 Mdot
.39882 .47138 Mdot
.286 .63222 Mdot
.34346 .40471 Mdot
.38048 .5018 Mdot
.64184 .46706 Mdot
.74387 .46813 Mdot
.32435 .40565 Mdot
.50106 .408 Mdot
.41132 .49372 Mdot
.4755 .39183 Mdot
.57148 .65687 Mdot
.67892 .46624 Mdot
.46757 .35517 Mdot
.3178 .53625 Mdot
.16051 .52836 Mdot
.67209 .51844 Mdot
.55011 .58811 Mdot
.21935 .67065 Mdot
.19121 .43086 Mdot
.57328 .74173 Mdot
.49651 .3987 Mdot
.58573 .60373 Mdot
.51464 .65304 Mdot
.53677 .61267 Mdot
.46906 .37659 Mdot
.26146 .49687 Mdot
.34712 .42635 Mdot
.55263 .62439 Mdot
.37742 .62381 Mdot
.33357 .43194 Mdot
.37712 .42464 Mdot
.3075 .40692 Mdot
.65244 .41736 Mdot
.51083 .64253 Mdot
.61393 .35837 Mdot
.15092 .43659 Mdot
.49719 .38316 Mdot
.48892 .23509 Mdot
.60085 .62689 Mdot
.82153 .56231 Mdot
.68111 .47296 Mdot
.34575 .4063 Mdot
.58903 .62007 Mdot
.29339 .50968 Mdot
.49282 .21588 Mdot
.31447 .44791 Mdot
.64954 .45971 Mdot
.56947 .74104 Mdot
.571 .61589 Mdot
.52631 .6253 Mdot
.65876 .43548 Mdot
.26387 .31096 Mdot
.65336 .34881 Mdot
.59526 .63406 Mdot
.48796 .37558 Mdot
.8078 .35502 Mdot
.58901 .67367 Mdot
.72261 .41293 Mdot
.48824 .22507 Mdot
.57856 .35009 Mdot
.72991 .53882 Mdot
.49394 .58259 Mdot
.23455 .67303 Mdot
.50772 .73263 Mdot
.19762 .65277 Mdot
.34372 .63153 Mdot
.37779 .33411 Mdot
.13989 .56865 Mdot
.48671 .32788 Mdot
.64693 .535 Mdot
.40212 .79418 Mdot
.6214 .29721 Mdot
.40136 .5464 Mdot
.41932 .24038 Mdot
.33672 .51839 Mdot
.52777 .16248 Mdot
.30815 .41252 Mdot
.33875 .67613 Mdot
.57651 .66438 Mdot
.19854 .41956 Mdot
.70725 .52399 Mdot
.78263 .37164 Mdot
.19138 .63499 Mdot
.38133 .54347 Mdot
.38329 .80556 Mdot
.18118 .54566 Mdot
.59642 .76458 Mdot
.57296 .46996 Mdot
.46505 .27932 Mdot
.65277 .36995 Mdot
.39218 .65627 Mdot
.5977 .55488 Mdot
.3099 .30324 Mdot
.23092 .43857 Mdot
.79533 .56264 Mdot
.80627 .38015 Mdot
.34834 .39825 Mdot
.70872 .42731 Mdot
.33215 .72921 Mdot
.6147 .44582 Mdot
.54265 .38086 Mdot
.23516 .67423 Mdot
.17201 .45951 Mdot
.69523 .51816 Mdot
.42492 .17881 Mdot
.69485 .66171 Mdot
.76697 .70292 Mdot
.50886 .48899 Mdot
.71088 .46388 Mdot
.39788 .30888 Mdot
.67998 .36524 Mdot
.4658 .30432 Mdot
.76347 .42597 Mdot
.39343 .63394 Mdot
.44342 .76729 Mdot
.65073 .45585 Mdot
.72335 .5492 Mdot
.48719 .21802 Mdot
.52631 .30826 Mdot
.36244 .48746 Mdot
.20086 .59551 Mdot
.46754 .19553 Mdot
.58856 .37596 Mdot
.54426 .22908 Mdot
.38243 .82864 Mdot
.45161 .69331 Mdot
.20085 .5473 Mdot
.45264 .33429 Mdot
.49177 .7183 Mdot
.66707 .32617 Mdot
.46571 .73471 Mdot
.70537 .36936 Mdot
.51351 .84033 Mdot
.20871 .37201 Mdot
.42553 .83019 Mdot
.62137 .47162 Mdot
.60446 .64993 Mdot
.23073 .61942 Mdot
.75154 .65647 Mdot
.39993 .59367 Mdot
.3534 .80484 Mdot
.38618 .62714 Mdot
.62569 .4801 Mdot
.61584 .2866 Mdot
.75423 .46142 Mdot
.29241 .37895 Mdot
.34315 .57767 Mdot
.51909 .68267 Mdot
.68389 .81832 Mdot
.25537 .70084 Mdot
.5708 .31795 Mdot
.17621 .45049 Mdot
.45101 .35999 Mdot
.41741 .44071 Mdot
.47704 .38847 Mdot
.14846 .54319 Mdot
.66598 .46801 Mdot
.13572 .46479 Mdot
.15329 .51748 Mdot
.71933 .29329 Mdot
.78358 .75416 Mdot
.54033 .18639 Mdot
.66744 .54944 Mdot
.56523 .76471 Mdot
.47598 .78969 Mdot
.69919 .32699 Mdot
.70642 .27517 Mdot
.50961 .30906 Mdot
.25184 .31719 Mdot
.15791 .57957 Mdot
.40297 .68708 Mdot
.22604 .46323 Mdot
.63893 .30269 Mdot
.48556 .49713 Mdot
.72799 .42555 Mdot
.4703 .52723 Mdot
.54168 .51444 Mdot
.40082 .81695 Mdot
.80728 .58949 Mdot
.85497 .45118 Mdot
.33546 .63717 Mdot
.67304 .23397 Mdot
.19721 .47685 Mdot
.38787 .75336 Mdot
.75553 .42928 Mdot
.61487 .3297 Mdot
.48956 .64581 Mdot
.64286 .35967 Mdot
.62629 .66809 Mdot
.41469 .61911 Mdot
.68988 .34919 Mdot
.35959 .36349 Mdot
.35436 .66266 Mdot
.28069 .69625 Mdot
.59699 .42888 Mdot
.65389 .41898 Mdot
.49441 .74523 Mdot
.43865 .68999 Mdot
.18285 .45747 Mdot
.66255 .26615 Mdot
.25499 .29285 Mdot
.6829 .27228 Mdot
.50867 .66729 Mdot
.63711 .53685 Mdot
.61156 .57266 Mdot
.45643 .71921 Mdot
.53719 .68519 Mdot
.5386 .2421 Mdot
.17485 .42679 Mdot
.78792 .62268 Mdot
.37105 .65745 Mdot
.65801 .73936 Mdot
.23403 .33366 Mdot
.24362 .63213 Mdot
.60321 .22867 Mdot
.64921 .63429 Mdot
.61311 .83877 Mdot
.33321 .44038 Mdot
.42032 .69262 Mdot
.52909 .38031 Mdot
.28786 .57963 Mdot
.46026 .81469 Mdot
.72022 .30227 Mdot
.1765 .42036 Mdot
.62408 .33338 Mdot
.3836 .46855 Mdot
.49638 .43463 Mdot
.27611 .402 Mdot
.64867 .74828 Mdot
.61953 .62895 Mdot
.4546 .6107 Mdot
.34662 .60929 Mdot
.75259 .64028 Mdot
.25745 .63473 Mdot
.37639 .24872 Mdot
.47884 .63093 Mdot
.37128 .27951 Mdot
.47034 .23184 Mdot
.48523 .45455 Mdot
.16903 .64677 Mdot
.53355 .55207 Mdot
.56937 .1954 Mdot
.21656 .3591 Mdot
.39961 .49603 Mdot
.2098 .53692 Mdot
.5792 .28651 Mdot
.47237 .83841 Mdot
.15506 .47737 Mdot
.25411 .38136 Mdot
.22609 .68388 Mdot
.26543 .25666 Mdot
.5288 .82909 Mdot
.66072 .70888 Mdot
.52533 .34733 Mdot
.13436 .36965 Mdot
.34968 .41886 Mdot
.68733 .7442 Mdot
.75827 .64949 Mdot
.28171 .51855 Mdot
.66782 .39851 Mdot
.55733 .72134 Mdot
.45469 .21003 Mdot
.7236 .45621 Mdot
.51826 .68301 Mdot
.32998 .80162 Mdot
.52748 .84574 Mdot
.34562 .80814 Mdot
.24107 .34564 Mdot
.21735 .67578 Mdot
.37576 .77896 Mdot
.78076 .48227 Mdot
.30194 .67953 Mdot
.56141 .67085 Mdot
.4025 .70736 Mdot
.54977 .19099 Mdot
.37686 .48458 Mdot
.49568 .27995 Mdot
.64128 .41959 Mdot
.47727 .82966 Mdot
.18171 .67695 Mdot
.7039 .62107 Mdot
.76427 .55225 Mdot
.52866 .50905 Mdot
.44284 .7152 Mdot
.44331 .62407 Mdot
.32708 .27919 Mdot
.19012 .46477 Mdot
.39094 .79196 Mdot
.41649 .67439 Mdot
.40555 .25484 Mdot
.28971 .36399 Mdot
.65281 .22666 Mdot
.18378 .57817 Mdot
.36939 .75834 Mdot
.69712 .27344 Mdot
.64605 .66342 Mdot
.73599 .32963 Mdot
.32625 .26032 Mdot
.40714 .43362 Mdot
.44101 .67386 Mdot
.32472 .46462 Mdot
.40231 .69205 Mdot
.5638 .44171 Mdot
.31155 .70507 Mdot
.51745 .74245 Mdot
.39363 .6867 Mdot
.28474 .36885 Mdot
.28753 .75984 Mdot
.31428 .22492 Mdot
.60941 .80602 Mdot
.36816 .21181 Mdot
.62608 .67195 Mdot
.58456 .67092 Mdot
.19634 .38787 Mdot
.27197 .75436 Mdot
.15654 .44539 Mdot
.56335 .24547 Mdot
.30968 .5359 Mdot
.50662 .3283 Mdot
.63867 .77811 Mdot
.37141 .23052 Mdot
.17495 .49054 Mdot
.74083 .38699 Mdot
.47483 .40749 Mdot
.63253 .33561 Mdot
.66297 .75237 Mdot
.59081 .77302 Mdot
.73114 .5637 Mdot
.59274 .55516 Mdot
.69329 .54155 Mdot
.71436 .43855 Mdot
.57083 .2392 Mdot
.4573 .72748 Mdot
.32828 .43838 Mdot
.3964 .77281 Mdot
.46155 .598 Mdot
.48834 .64155 Mdot
.40139 .44538 Mdot
.72778 .43397 Mdot
.69478 .71764 Mdot
.51742 .31205 Mdot
.14411 .58368 Mdot
.56543 .20794 Mdot
.49579 .71134 Mdot
.4849 .72662 Mdot
.30317 .60809 Mdot
.6295 .35748 Mdot
.46635 .38289 Mdot
.1846 .6114 Mdot
.44631 .52983 Mdot
.49342 .74093 Mdot
.69702 .54269 Mdot
.27816 .62988 Mdot
.54528 .57275 Mdot
.56587 .29167 Mdot
.79961 .50518 Mdot
.47048 .45386 Mdot
.63924 .49371 Mdot
.7307 .44469 Mdot
.50981 .14414 Mdot
.29668 .33595 Mdot
.64938 .24882 Mdot
.18868 .61101 Mdot
.48111 .39571 Mdot
.6314 .45303 Mdot
.38695 .69297 Mdot
.25122 .58449 Mdot
.80458 .54499 Mdot
.36463 .38882 Mdot
.43604 .63353 Mdot
.36262 .24604 Mdot
.22347 .67296 Mdot
.31373 .76089 Mdot
.81762 .41039 Mdot
.66153 .48657 Mdot
.2578 .61559 Mdot
.27121 .61519 Mdot
.67065 .48453 Mdot
.69841 .39033 Mdot
.57545 .47813 Mdot
.19048 .65631 Mdot
.63094 .36672 Mdot
.33406 .23433 Mdot
.40752 .4956 Mdot
.27828 .50179 Mdot
.29219 .60737 Mdot
.43375 .66116 Mdot
.19196 .61098 Mdot
.71695 .56002 Mdot
.52294 .80901 Mdot
.60226 .55578 Mdot
.75983 .67535 Mdot
.64211 .77756 Mdot
.50234 .4851 Mdot
.73799 .47975 Mdot
.37892 .3726 Mdot
.54085 .60799 Mdot
.37783 .82787 Mdot
.19723 .44345 Mdot
.71595 .35987 Mdot
.52879 .31814 Mdot
.52039 .64203 Mdot
.52944 .67653 Mdot
.60059 .72879 Mdot
.58064 .33333 Mdot
.58085 .82073 Mdot
.3421 .65839 Mdot
.6311 .66146 Mdot
.70547 .53535 Mdot
.5716 .19696 Mdot
.21103 .60691 Mdot
.19988 .46363 Mdot
.54774 .44926 Mdot
.55198 .19424 Mdot
.43454 .44128 Mdot
.32862 .2337 Mdot
.34794 .28935 Mdot
.36163 .76774 Mdot
.60669 .49146 Mdot
.59689 .32918 Mdot
.30342 .5982 Mdot
.59917 .63826 Mdot
.60576 .28157 Mdot
.18263 .55497 Mdot
.8672 .49772 Mdot
.66958 .31918 Mdot
.31153 .79245 Mdot
.50655 .55189 Mdot
.60166 .33753 Mdot
.483 .82137 Mdot
.87421 .56071 Mdot
.31591 .29189 Mdot
.38918 .81009 Mdot
.46422 .43654 Mdot
.19309 .6258 Mdot
.5173 .34436 Mdot
.60107 .39863 Mdot
.66482 .72773 Mdot
.18525 .64904 Mdot
.21624 .58412 Mdot
.20595 .61918 Mdot
.62754 .72091 Mdot
.21948 .68765 Mdot
.72794 .38365 Mdot
.54664 .15773 Mdot
.36026 .47848 Mdot
.52235 .22572 Mdot
.65206 .68766 Mdot
.53366 .5292 Mdot
.42044 .68515 Mdot
.63422 .19597 Mdot
.78278 .43551 Mdot
.63307 .72512 Mdot
.37858 .72293 Mdot
.58321 .29852 Mdot
.48596 .72455 Mdot
.1688 .50512 Mdot
.53143 .16046 Mdot
.28371 .60901 Mdot
.61375 .24788 Mdot
.25128 .33208 Mdot
.57628 .33188 Mdot
.33991 .32258 Mdot
.1995 .54768 Mdot
.29961 .27464 Mdot
.4378 .62383 Mdot
.56442 .12334 Mdot
.23939 .44758 Mdot
.57387 .48123 Mdot
.44963 .83133 Mdot
.19264 .46059 Mdot
.74916 .39419 Mdot
.76804 .36336 Mdot
.75209 .69247 Mdot
.42392 .73127 Mdot
.58509 .65307 Mdot
.2259 .69992 Mdot
.42141 .76064 Mdot
.37507 .81403 Mdot
.21589 .3383 Mdot
.68389 .55996 Mdot
.49329 .58871 Mdot
.33809 .38765 Mdot
.53322 .49287 Mdot
.36723 .71561 Mdot
.39418 .8028 Mdot
.72234 .71697 Mdot
.36996 .51556 Mdot
.37792 .32438 Mdot
.36853 .3885 Mdot
.63805 .59241 Mdot
.53578 .19384 Mdot
.58602 .31718 Mdot
.34721 .64571 Mdot
.28044 .36293 Mdot
.43725 .70395 Mdot
.72677 .53668 Mdot
.58381 .77889 Mdot
.70841 .3102 Mdot
.50813 .42019 Mdot
.35112 .39756 Mdot
.30902 .73189 Mdot
.2313 .42063 Mdot
.53766 .24675 Mdot
.57573 .80784 Mdot
.61598 .32418 Mdot
.33566 .68071 Mdot
.2735 .66654 Mdot
.69683 .32137 Mdot
.45814 .27585 Mdot
.60906 .77274 Mdot
.76105 .67278 Mdot
.37581 .38204 Mdot
.47927 .65869 Mdot
.1562 .59377 Mdot
.43577 .66713 Mdot
.29458 .68805 Mdot
.49604 .50427 Mdot
.77176 .61174 Mdot
.66469 .6158 Mdot
.43241 .77979 Mdot
.44482 .45487 Mdot
.65794 .82601 Mdot
.68936 .40176 Mdot
.38541 .83074 Mdot
.48111 .36733 Mdot
.8291 .47153 Mdot
.26601 .38299 Mdot
.54384 .46224 Mdot
.43592 .48177 Mdot
.56329 .29286 Mdot
.57178 .38241 Mdot
.24527 .33185 Mdot
.73176 .32 Mdot
.29886 .43339 Mdot
.37653 .52232 Mdot
.33185 .24195 Mdot
.28477 .71244 Mdot
.60492 .59553 Mdot
.23785 .42471 Mdot
.49757 .48739 Mdot
.37666 .48995 Mdot
.1984 .38964 Mdot
.39235 .37111 Mdot
.59674 .68403 Mdot
.44498 .71897 Mdot
.4132 .81329 Mdot
.15779 .50922 Mdot
.74626 .35517 Mdot
.62674 .66672 Mdot
.53275 .35769 Mdot
.44919 .80103 Mdot
.25469 .69413 Mdot
.40779 .40064 Mdot
.59761 .38032 Mdot
.44606 .68787 Mdot
.40887 .8609 Mdot
.52168 .84349 Mdot
.59234 .81172 Mdot
.39428 .50176 Mdot
.67922 .49657 Mdot
.81787 .57377 Mdot
.29295 .68519 Mdot
.51493 .24097 Mdot
.22297 .41203 Mdot
.42592 .69416 Mdot
.86036 .56182 Mdot
.77274 .44095 Mdot
.28989 .49154 Mdot
.66589 .61926 Mdot
.73948 .67359 Mdot
.50539 .33387 Mdot
.41265 .73421 Mdot
.41743 .54274 Mdot
.48487 .40492 Mdot
.58409 .30227 Mdot
.57886 .38475 Mdot
.29607 .69011 Mdot
.79809 .53013 Mdot
.63345 .62679 Mdot
.26409 .68753 Mdot
.70684 .47964 Mdot
.29078 .59498 Mdot
.30073 .62471 Mdot
.40084 .53939 Mdot
.33685 .40583 Mdot
.55578 .53901 Mdot
.50318 .44289 Mdot
.45163 .44018 Mdot
.67062 .78007 Mdot
.37992 .62959 Mdot
.66108 .40775 Mdot
.77596 .39995 Mdot
.65165 .48433 Mdot
.25547 .74279 Mdot
.32716 .2804 Mdot
.7 .53423 Mdot
.2562 .41756 Mdot
.40028 .28137 Mdot
.76907 .71572 Mdot
.63019 .7628 Mdot
.48932 .52679 Mdot
.73411 .40014 Mdot
.69982 .46815 Mdot
.28531 .38798 Mdot
.47369 .26932 Mdot
.74107 .55222 Mdot
.56235 .18661 Mdot
.30589 .67498 Mdot
.70309 .4732 Mdot
.27576 .48718 Mdot
.50625 .71766 Mdot
.16006 .62107 Mdot
.31679 .40245 Mdot
.58964 .84089 Mdot
.59494 .57116 Mdot
.49557 .81226 Mdot
.19337 .39589 Mdot
.67649 .34048 Mdot
.37585 .5049 Mdot
.43535 .24279 Mdot
.59236 .58447 Mdot
.63227 .60039 Mdot
.64736 .45147 Mdot
.29756 .65543 Mdot
.37092 .60488 Mdot
.48326 .76644 Mdot
.49183 .40573 Mdot
.69494 .25827 Mdot
.54235 .20017 Mdot
.70781 .42263 Mdot
.43823 .54323 Mdot
.23094 .60663 Mdot
.58569 .43916 Mdot
.49598 .48697 Mdot
.325 .75079 Mdot
.8026 .55544 Mdot
.70299 .47196 Mdot
.57707 .81033 Mdot
.31507 .64973 Mdot
.14389 .52017 Mdot
.48941 .69304 Mdot
.52448 .4868 Mdot
.58902 .43817 Mdot
.56811 .28617 Mdot
.73527 .53957 Mdot
.19201 .47047 Mdot
.48333 .74036 Mdot
.64688 .37745 Mdot
.39345 .68862 Mdot
.6246 .63923 Mdot
.37319 .32499 Mdot
.52048 .2102 Mdot
.85199 .58415 Mdot
.68097 .66057 Mdot
.65402 .33477 Mdot
.73516 .42098 Mdot
.56691 .19467 Mdot
.67262 .40323 Mdot
.25708 .53311 Mdot
.79657 .57083 Mdot
.25852 .38825 Mdot
.14888 .56295 Mdot
.18471 .45519 Mdot
.56005 .5024 Mdot
.39129 .41724 Mdot
.51506 .73543 Mdot
.51043 .71834 Mdot
.47343 .47012 Mdot
.59442 .58944 Mdot
.64046 .64454 Mdot
.73747 .35275 Mdot
.5422 .25812 Mdot
.56531 .72042 Mdot
.17863 .62632 Mdot
.1463 .5087 Mdot
.25221 .71723 Mdot
.41418 .41549 Mdot
.64605 .4215 Mdot
.48518 .83926 Mdot
.75218 .50798 Mdot
.16692 .50261 Mdot
.65407 .69169 Mdot
.48966 .14707 Mdot
.44693 .81437 Mdot
.36489 .36757 Mdot
.71639 .28776 Mdot
.51564 .28938 Mdot
.20264 .39202 Mdot
.54532 .15772 Mdot
.42156 .63734 Mdot
.20192 .37793 Mdot
.68219 .81815 Mdot
.66961 .69133 Mdot
.58322 .37714 Mdot
.65746 .59325 Mdot
.50057 .72049 Mdot
.55874 .17843 Mdot
.56878 .67136 Mdot
.32205 .46813 Mdot
.35812 .52415 Mdot
.43478 .69729 Mdot
.47687 .59317 Mdot
.56887 .1807 Mdot
.3604 .71086 Mdot
.33506 .67226 Mdot
.26454 .60303 Mdot
.4126 .80352 Mdot
.74308 .54238 Mdot
.58037 .69573 Mdot
.62744 .48986 Mdot
.38214 .57629 Mdot
.38796 .64859 Mdot
.52172 .65584 Mdot
.37974 .49563 Mdot
.58502 .47818 Mdot
.32894 .80336 Mdot
.2558 .56092 Mdot
.2233 .52569 Mdot
.72867 .44757 Mdot
.5794 .32 Mdot
.23995 .64094 Mdot
.6192 .2931 Mdot
.59403 .18631 Mdot
.80354 .59705 Mdot
.22957 .67976 Mdot
.61541 .33922 Mdot
.39471 .66566 Mdot
.71632 .75173 Mdot
.52076 .37239 Mdot
.69743 .70811 Mdot
.37717 .78449 Mdot
.60917 .30145 Mdot
.63407 .4846 Mdot
.33483 .35511 Mdot
.38964 .33848 Mdot
.59919 .30081 Mdot
.21921 .35537 Mdot
.26393 .62914 Mdot
.67296 .5928 Mdot
.29832 .7435 Mdot
.36785 .45666 Mdot
.41526 .67597 Mdot
.31489 .34234 Mdot
.54468 .16932 Mdot
.59651 .42241 Mdot
.16199 .60555 Mdot
.46303 .46983 Mdot
.43016 .76736 Mdot
.53053 .62807 Mdot
.77774 .52802 Mdot
.55035 .26912 Mdot
.29819 .3578 Mdot
.65021 .25529 Mdot
.67199 .41458 Mdot
.55002 .21974 Mdot
.47512 .28618 Mdot
.42562 .74511 Mdot
.45686 .59267 Mdot
.62079 .50034 Mdot
.3377 .61643 Mdot
.47377 .20856 Mdot
.61195 .60789 Mdot
.4621 .7779 Mdot
.2864 .37837 Mdot
.68115 .71517 Mdot
.66559 .70525 Mdot
.30996 .73446 Mdot
.21053 .46686 Mdot
.53096 .24588 Mdot
.64833 .71262 Mdot
.55837 .34167 Mdot
.77009 .4572 Mdot
.62765 .2775 Mdot
.56566 .68556 Mdot
.25836 .53 Mdot
.63453 .4548 Mdot
.29016 .72122 Mdot
.65623 .51755 Mdot
.40358 .7664 Mdot
.51517 .45661 Mdot
.22366 .61426 Mdot
.46956 .50495 Mdot
.19522 .39663 Mdot
.51311 .28742 Mdot
.45924 .72937 Mdot
.45744 .38372 Mdot
.46355 .43469 Mdot
.6753 .31589 Mdot
.1681 .56918 Mdot
.71702 .3093 Mdot
.57375 .7582 Mdot
.64238 .33357 Mdot
.76885 .65361 Mdot
.20607 .35464 Mdot
.44972 .73611 Mdot
.47566 .4698 Mdot
.45888 .65853 Mdot
.5369 .31724 Mdot
.47996 .25602 Mdot
.27362 .53347 Mdot
.74984 .52622 Mdot
.23219 .50495 Mdot
.319 .49389 Mdot
.61191 .62926 Mdot
.82282 .55391 Mdot
.28099 .72287 Mdot
.75203 .40378 Mdot
.52967 .47025 Mdot
.31479 .57097 Mdot
.43271 .75131 Mdot
.742 .23272 Mdot
.37247 .82723 Mdot
.53025 .6298 Mdot
.41142 .4988 Mdot
.4736 .7623 Mdot
.35291 .45944 Mdot
.74303 .56094 Mdot
.30565 .73179 Mdot
.51236 .373 Mdot
.3044 .54592 Mdot
.49651 .26439 Mdot
.55608 .28539 Mdot
.42476 .78084 Mdot
.47681 .32184 Mdot
.27904 .76743 Mdot
.23161 .40093 Mdot
.55619 .26606 Mdot
.63942 .15137 Mdot
.55238 .24046 Mdot
.70009 .49026 Mdot
.20842 .57595 Mdot
.28193 .75464 Mdot
.39727 .4996 Mdot
.28839 .57372 Mdot
.66791 .70647 Mdot
.46845 .7349 Mdot
.35488 .67157 Mdot
.6114 .24689 Mdot
.56416 .22443 Mdot
.55631 .15942 Mdot
.40132 .27953 Mdot
.6829 .77863 Mdot
.70904 .55351 Mdot
.31759 .76847 Mdot
.31881 .28745 Mdot
.86228 .54826 Mdot
.14886 .54425 Mdot
.39415 .7104 Mdot
.59054 .19145 Mdot
.208 .55902 Mdot
.50961 .77523 Mdot
.81467 .51446 Mdot
.29696 .30319 Mdot
.80411 .5749 Mdot
.3891 .27516 Mdot
.64334 .27189 Mdot
.39864 .68999 Mdot
.75093 .66774 Mdot
.45761 .46822 Mdot
.36579 .78868 Mdot
.66928 .22331 Mdot
.47461 .71842 Mdot
.31541 .54649 Mdot
.51913 .78685 Mdot
.25979 .69015 Mdot
.19175 .54664 Mdot
.46294 .4815 Mdot
.68989 .80825 Mdot
.39895 .81525 Mdot
.63134 .29187 Mdot
.54784 .68408 Mdot
.14052 .55189 Mdot
.42913 .50872 Mdot
.64815 .71807 Mdot
.21334 .3963 Mdot
.33758 .65172 Mdot
.59432 .47105 Mdot
.59614 .6701 Mdot
.62235 .77003 Mdot
.72095 .49393 Mdot
.73785 .67814 Mdot
.33238 .55625 Mdot
.48537 .72907 Mdot
.67717 .23172 Mdot
.4809 .79646 Mdot
.5181 .72017 Mdot
.6385 .46315 Mdot
.30303 .77972 Mdot
.59367 .76336 Mdot
.57722 .53549 Mdot
.65784 .56219 Mdot
.72301 .31385 Mdot
.44899 .21148 Mdot
.62006 .67754 Mdot
.62652 .35997 Mdot
.42318 .68575 Mdot
.28712 .67337 Mdot
.65138 .73232 Mdot
.79911 .74128 Mdot
.18775 .40199 Mdot
.70104 .40186 Mdot
.69981 .6949 Mdot
.37886 .52976 Mdot
.25758 .71962 Mdot
.40257 .25173 Mdot
.3019 .6142 Mdot
.76972 .33946 Mdot
.50501 .75782 Mdot
.51357 .59251 Mdot
.23591 .34951 Mdot
.15624 .55352 Mdot
.69484 .23902 Mdot
.15645 .59233 Mdot
.49297 .59439 Mdot
.55185 .56023 Mdot
.87689 .44036 Mdot
.20666 .65011 Mdot
.49986 .57661 Mdot
.74672 .33324 Mdot
.66155 .39837 Mdot
.56874 .66627 Mdot
.49429 .26507 Mdot
.44419 .66684 Mdot
.34936 .67382 Mdot
.18816 .65208 Mdot
.70387 .47992 Mdot
.3763 .50031 Mdot
.52855 .36991 Mdot
.43941 .47595 Mdot
.6103 .67613 Mdot
.46817 .35156 Mdot
.34935 .68232 Mdot
.41702 .51341 Mdot
.55249 .35327 Mdot
.43513 .62336 Mdot
.32037 .22716 Mdot
.56247 .52632 Mdot
.55123 .5031 Mdot
.63571 .69876 Mdot
.78363 .43339 Mdot
.36361 .71252 Mdot
.33786 .7011 Mdot
.20642 .37197 Mdot
.31281 .20432 Mdot
.27018 .42648 Mdot
.53321 .7183 Mdot
.61211 .42828 Mdot
.74039 .52875 Mdot
.66491 .58183 Mdot
.49725 .42555 Mdot
.47137 .24668 Mdot
.48755 .62313 Mdot
.49357 .70856 Mdot
.49747 .40366 Mdot
.3721 .83908 Mdot
.56411 .67651 Mdot
.69892 .58128 Mdot
.17339 .53479 Mdot
.2933 .59478 Mdot
.60606 .52268 Mdot
.58795 .58085 Mdot
.73185 .38549 Mdot
.41978 .51588 Mdot
.54584 .74599 Mdot
.29345 .61452 Mdot
.26681 .72214 Mdot
.59241 .52088 Mdot
.68771 .57423 Mdot
.55761 .62401 Mdot
.3428 .58177 Mdot
.58345 .39667 Mdot
.61069 .79129 Mdot
.44803 .59868 Mdot
.16221 .49823 Mdot
.31958 .64415 Mdot
.34189 .65766 Mdot
.66534 .53782 Mdot
.37203 .81471 Mdot
.66247 .31711 Mdot
.68182 .55495 Mdot
.73273 .3604 Mdot
.34422 .3339 Mdot
.37891 .72134 Mdot
.33571 .38374 Mdot
.56563 .71977 Mdot
.64996 .40256 Mdot
.19431 .67562 Mdot
.63559 .76149 Mdot
.45488 .41242 Mdot
.36765 .37935 Mdot
.76429 .46921 Mdot
.44231 .47921 Mdot
.59713 .13509 Mdot
.41525 .23639 Mdot
.28444 .77199 Mdot
.27801 .64469 Mdot
.61118 .42777 Mdot
.58444 .29555 Mdot
.53427 .54305 Mdot
.33381 .45312 Mdot
.26171 .72136 Mdot
.46633 .66203 Mdot
.62511 .26807 Mdot
.54866 .67133 Mdot
.69452 .36181 Mdot
.50538 .72034 Mdot
.39627 .41376 Mdot
.30759 .45608 Mdot
.7398 .34277 Mdot
.18789 .56509 Mdot
.42129 .51666 Mdot
.48153 .16059 Mdot
.39614 .80531 Mdot
.18323 .60918 Mdot
.36999 .39037 Mdot
.83142 .4616 Mdot
.73768 .42511 Mdot
.51481 .72289 Mdot
.45289 .38695 Mdot
.5715 .76734 Mdot
.60296 .29838 Mdot
.28826 .66648 Mdot
.56062 .33964 Mdot
.57301 .45973 Mdot
.49464 .10132 Mdot
.38995 .70236 Mdot
.7476 .42231 Mdot
.59565 .27345 Mdot
.1722 .60577 Mdot
.40374 .56627 Mdot
.2712 .2739 Mdot
.30055 .3175 Mdot
.61597 .66921 Mdot
.7978 .51492 Mdot
.52308 .80417 Mdot
.41384 .35661 Mdot
.7242 .75595 Mdot
.22949 .42432 Mdot
.38854 .65567 Mdot
.3007 .35474 Mdot
.65582 .48518 Mdot
.6609 .40101 Mdot
.33297 .26321 Mdot
.39223 .18285 Mdot
.57282 .73285 Mdot
.24284 .68497 Mdot
.8004 .66426 Mdot
.30107 .65015 Mdot
.22866 .69284 Mdot
.44017 .354 Mdot
.71523 .39538 Mdot
.35362 .7045 Mdot
.32722 .57196 Mdot
.36011 .4574 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`0009kooooo0_l00007ooooo`;o0000XOooool001cooooo00?o0000ooooooooool0
WOooool2o`0000Oooooo0_l0002Qooooo`007?ooool00ol0003oooooooooo`2<ooooo`;o0000^ooo
ool001cooooo00?o0000ooooooooool0S?ooool2o`0001Kooooo0_l0002Sooooo`007?ooool00ol0
003oooooooooo`2Tooooo`;o0000Xoooool001cooooo00?o0000ooooooooool0Z?ooool2o`0009oo
oooo000Looooo`03o`000?oooooooooo0:Sooooo0_l0002Oooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0;Cooooo0_l0002Cooooo`007?ooool00ol0
003oooooooooo`1mooooo`;o0000=Oooool2o`0000?ooooo0_l0002>ooooo`007?ooool00ol0003o
ooooooooo`1mooooo`;o0000>_ooool2o`0008kooooo000Looooo`03o`000?oooooooooo0;kooooo
0_l00029ooooo`007?ooool00ol0003oooooooooo`2nooooo`;o0000ROooool001cooooo00?o0000
ooooooooool0Loooool2o`000=Cooooo000Looooo`03o`000?oooooooooo07?ooooo0_l0000]oooo
o`;o0000YOooool001cooooo00?o0000ooooooooool0Voooool2o`0000Gooooo0_l0002Uooooo`00
7?ooool00ol0003oooooooooo`1/ooooo`;o0000;Oooool2o`000:cooooo000Looooo`;o0000KOoo
ool2o`0005kooooo0_l0001kooooo`007?ooool00ol0003oooooooooo`3<ooooo`;o0000Noooool0
01cooooo00?o0000ooooooooool0[Oooool3o`000003ooooool0003o000009Kooooo000Looooo`03
o`000?oooooooooo09Wooooo0_l0000=ooooo`?o00000_ooool3o`000003ooooool0003o000009Ko
oooo000Looooo`03o`000?oooooooooo06;ooooo0_l0000eooooo`;o00003Oooool3o`0009kooooo
000Looooo`03o`000?oooooooooo06;ooooo0_l0003Uooooo`007?ooool00ol0003oooooooooo`25
ooooo`;o00009_ooool2o`0009[ooooo000Looooo`03o`000?oooooooooo08Gooooo1?l0000Toooo
o`;o00009oooool2o`00077ooooo000Looooo`03o`000?oooooooooo08Oooooo0_l000000ooooooo
0000o`00000Vooooo`;o00008_ooool2o`00077ooooo000Looooo`03o`000?oooooooooo07cooooo
0_l00008ooooo`;o00000_ooool2o`0002Gooooo0ol000000ooooooo0000o`000005ooooo`;o0000
Roooool001cooooo00?o0000ooooooooool0FOooool2o`00027ooooo0_l00008ooooo`;o00001ooo
ool2o`00023ooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o000008_ooooo000L
ooooo`03o`000?oooooooooo05Wooooo0_l0000Qooooo`Co00003oooool2o`0001_ooooo0_l00005
ooooo`;o00001?ooool2o`0000;ooooo0_l0002:ooooo`007?ooool00ol0003oooooooooo`1goooo
o`;o00001Oooool2o`0000?ooooo0_l0000Wooooo`;o00001Oooool2o`0000Sooooo0_l0002:oooo
o`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000
ooooooooool0M_ooool3o`0000Sooooo1?l00005ooooo`;o00007_ooool2o`0000?ooooo0_l00004
ooooo`;o00001Oooool2o`0000;ooooo0_l00005ooooo`;o0000P?ooool00006oooooomgMgOoV9RH
oooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`00
0?oooooooooo07?ooooo0_l000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l00000
1oooool4o`000003ooooool0003o000000?ooooo0_l0000>ooooo`Co00000_ooool2o`0000?ooooo
0ol00002ooooo`Co00001?ooool2o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l00000
OOooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^
kP07ooooo`03o`000?oooooooooo07;ooooo0ol00006ooooo`Go00003?ooool2o`000003ooooool0
003o000000?ooooo0ol00003ooooo`;o00002?ooool4o`0000Sooooo0_l00002ooooo`Co00004_oo
ool2o`0007gooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RH
ob4Q8Oo^k^h01_ooool3o`0007;ooooo0_l00007ooooo`?o00005oooool2o`0000?ooooo0_l0000@
ooooo`;o00000_ooool2o`0001Gooooo0_l00020ooooo`0000?oooooo`000?ooool00_ooool00ol0
003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0H_ooool2o`00
00_ooooo0_l0000kooooo`;o00000_ooool2o`0001Gooooo0_l00020ooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0H_ooool2o`0000_ooooo0_l0000Aooooo`;o00004?ooool6o`0000?ooooo0_l0000Eooooo`;o
00006Oooool2o`0007Sooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj
^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo07Cooooo0ol0000;ooooo`;o00002_ooool4
o`0000;ooooo1_l00003ooooo`;o00001_ooool2o`0000gooooo0_l0000Iooooo`;o00003?ooool2
o`0006[ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c006ooooo`03o`000?oooooooooo07Cooooo0ol0000Gooooo`Co00001?ooool2o`000004oooo
ool0003o0000o`0000Wooooo0_l0000Booooo`;o00008_ooool2o`0006[ooooo000Looooo`03o`00
0?oooooooooo06[ooooo0_l0000?ooooo`;o00005oooool:o`0001_ooooo0_l0002>ooooo`007?oo
ool00ol0003oooooooooo`1Zooooo`;o00003oooool2o`0001Gooooo3?l0000Aooooo`;o00008?oo
ool2o`0000cooooo0_l0001Xooooo`007?ooool00ol0003oooooooooo`2Booooo`_o00004_ooool2
o`0000;ooooo0ol0000;ooooo`;o00003_ooool3o`0000;ooooo0_l00007ooooo`;o0000J?ooool0
01cooooo00?o0000ooooooooool0H_ooool5o`0002_ooooo2ol00009ooooo`;o00002oooool3o`00
00_ooooo0_l0000;ooooo`Ko00000_ooool2o`00077ooooo000Looooo`03o`000?oooooooooo06;o
oooo1Ol0000>ooooo`;o00007?ooool;o`0000?ooooo0_l00003ooooo`;o00001Oooool2o`00017o
oooo0_l000000ooooooo0000o`000009ooooo`Co0000Moooool001cooooo00?o0000ooooooooool0
BOooool2o`0001Sooooo1_l0000;ooooo`?o00003_ooool2o`0000cooooo1ol000001?oooooo0000
o`000?l00003ooooo`;o00002_ooool3o`0000Kooooo0_l00008ooooo`Ko00004_ooool2o`0001?o
oooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00007?ooool4o`0000Wooooo
0_l00008ooooo`;o00000oooool6o`0000[ooooo3?l0000?ooooo`;o00001?ooool4o`0000Wooooo
0_l000000ooooooo0000o`00000Aooooo`?o00004oooool2o`0005[ooooo000Looooo`03o`000?oo
oooooooo06Wooooo0_l00009ooooo`;o00002?ooool2o`0000?ooooo0_l00002ooooo`;o00002?oo
ool>o`0000Gooooo0_l00008ooooo`;o00000oooool5o`0001Kooooo0_l00007ooooo`;o00001Ooo
ool2o`0000Oooooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`1Xooooo`;o00006_ooool2
o`0000?ooooo0ol00005ooooo`ko00001Oooool2o`0000Gooooo0_l000000ooooooo0000o`000002
o`000004ooooool0003o0000ooooo`;o00002oooool3o`0000Sooooo0_l00007ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0000Oooooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`1X
ooooo`;o00002?ooool2o`00013ooooo0_l00003ooooo`?o00001Oooool@o`0000?ooooo0_l00003
ooooo`Co00000oooool2o`000003ooooool0003o000000kooooo0ol00003ooooo`?o00003_ooool2
o`0000;ooooo0_l0001Yooooo`007?ooool00ol0003oooooooooo`1booooo`;o00000oooool2o`00
017ooooo0_l00006ooooo`co000000Coooooo`000?l0003o00001oooool4o`0000Kooooo0ol0000=
ooooo`Go000000Coooooo`000?l0003o00000oooool2o`0000gooooo0_l0001Yooooo`007?ooool2
o`0007Sooooo0_l00006ooooo`;o00002Oooool2o`0000Kooooo3?l00002ooooo`;o00002Oooool2
o`0000Oooooo0_l0000=ooooo`Go00001Oooool4o`000004ooooool0003o0000o`0000_ooooo0_l0
0009ooooo`;o0000G?ooool001cooooo00?o0000ooooooooool0O_ooool4o`00017ooooo2_l0000>
ooooo`;o00001oooool2o`0001Oooooo1?l000001?oooooo0000o`000?l0000;ooooo`;o00002Ooo
ool2o`0005cooooo000Looooo`03o`000?oooooooooo05?ooooo0_l0000Yooooo`Co00004_ooool9
o`0000oooooo0_l00008ooooo`;o00005oooool2o`0000gooooo0_l0001Yooooo`007?ooool00ol0
003oooooooooo`1Cooooo`;o00002oooool2o`0000Cooooo0_l0000_ooooo`Ko00003oooool3o`00
00Oooooo0_l00008ooooo`;o00002Oooool2o`0000Wooooo0_l00006ooooo`;o00000oooool2o`00
06Cooooo000Looooo`03o`000?oooooooooo03oooooo0_l0000Oooooo`;o00001?ooool4o`0002ko
oooo0ol00003ooooo`;o00003?ooool3o`00017ooooo0ol00003ooooo`;o00000oooool2o`0000Wo
oooo0_l0000;ooooo`;o000000?oooooo`000?l00000HOooool001cooooo00?o0000ooooooooool0
?oooool2o`0001Sooooo0_l0000=ooooo`;o00001oooool2o`0001_ooooo0_l0000;ooooo`Go0000
2?ooool2o`0000Oooooo0_l0000;ooooo`;o000000?oooooo`000?l000000oooool2o`0000_ooooo
0ol0000@ooooo`;o0000HOooool001cooooo00?o0000ooooooooool0FOooool2o`0001Gooooo0ol0
000Jooooo`?o00001_ooool2o`0000?ooooo1?l00009ooooo`Co00000oooool4o`0000_ooooo0_l0
0006ooooo`?o00002_ooool3o`00027ooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`1D
ooooo`;o00006_ooool2o`0001_ooooo0_l00007ooooo`;o00000oooool4o`0000_ooooo0_l00003
ooooo`;o00003Oooool2o`0000Oooooo0ol00003ooooo`;o00002oooool2o`0000?ooooo0ol0000E
ooooo`;o0000D?ooool001cooooo00?o0000ooooooooool0E?ooool2o`0000;ooooo0_l00004oooo
o`;o00006oooool2o`0001Cooooo0_l00008ooooo`;o00003?ooool4o`00017ooooo0_l00006oooo
o`Co00000_ooool3o`0000_ooooo0_l00003ooooo`Go0000IOooool001cooooo00?o0000oooooooo
ool0Doooool2o`0000?ooooo0_l00004ooooo`;o00001oooool2o`0000cooooo0_l00004ooooo`;o
00000_ooool2o`00013ooooo1?l00008ooooo`;o00002_ooool4o`0000?ooooo0_l0000>ooooo`;o
00001?ooool4o`000004ooooool0003o0000o`0000Wooooo0_l00009ooooo`;o0000IOooool001co
oooo00?o0000ooooooooool0D_ooool3o`0001;ooooo0_l00006ooooo`;o00001?ooool2o`0000Oo
oooo0ol0000>ooooo`;o00000_ooool2o`0000Sooooo0_l0000Aooooo`;o00001_ooool2o`0000Ko
oooo0ol00004ooooo`?o000000Coooooo`000?l0003o00002Oooool4o`0000Wooooo0_l0001Soooo
o`007?ooool00ol0003oooooooooo`1Booooo`;o00004oooool2o`0000Kooooo0_l0000=ooooo`;o
00003oooool2o`0000Kooooo0_l0000Cooooo`;o00000oooool2o`0000;ooooo0_l000000ooooooo
0000o`000007ooooo`;o00005_ooool2o`0000Wooooo0_l0000?ooooo`;o0000D_ooool001cooooo
00?o0000ooooooooool0I?ooool2o`0000Oooooo0_l0000Aooooo`;o00003Oooool2o`0000Kooooo
0_l00006ooooo`;o00000_ooool3o`0000Kooooo0_l00003ooooo`;o00000_ooool2o`000003oooo
ool0003o000000[ooooo0_l00006ooooo`?o00005Oooool3o`0000Cooooo0_l00008ooooo`;o0000
D_ooool001cooooo00?o0000ooooooooool0D_ooool2o`0000oooooo0ol00007ooooo`;o000000?o
ooooo`000?l000003_ooool2o`0001cooooo0ol00002ooooo`?o00003_ooool2o`0000;ooooo0_l0
000:ooooo`;o00000oooool2o`000004ooooool0003o0000o`0001Kooooo0_l00004ooooo`;o0000
3Oooool2o`0004gooooo000Looooo`03o`000?oooooooooo04oooooo0_l000000ooooooo0000o`00
000;ooooo`;o00000_ooool2o`0000_ooooo0_l0000/ooooo`;o00004oooool3o`0000gooooo1?l0
0002ooooo`;o000000?oooooo`000?l000001Oooool2o`00013ooooo0ol0000?ooooo`;o000000?o
ooooo`000?l00000COooool001cooooo00?o0000ooooooooool0Coooool2o`0000kooooo1?l0001@
ooooo`;o00001Oooool2o`0000Cooooo2?l00004ooooo`;o00001Oooool2o`000003ooooool0003o
000000gooooo1Ol0000=ooooo`;o0000D?ooool001cooooo0_l0001Nooooo`;o00000_ooool2o`00
00cooooo0_l00019ooooo`;o00000oooool5o`0000;ooooo0_l0000>ooooo`;o00004?ooool2o`00
05oooooo000Looooo`03o`000?oooooooooo03Kooooo0_l0000Uooooo`?o000000?oooooo`000?l0
00003?ooool2o`0002?ooooo0_l0000Kooooo`;o00001oooool2o`0000?ooooo0_l000000ooooooo
0000o`000008ooooo`;o00006?ooool2o`0000Kooooo0_l0000=ooooo`;o0000B_ooool001cooooo
00?o0000ooooooooool0=_ooool2o`0002Gooooo0ol000000ooooooo0000o`00000_ooooo`Co0000
4oooool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000004ooooo`;o0000
0oooool2o`0000_ooooo0_l00004ooooo`;o00004_ooool2o`0000Kooooo0_l0000=ooooo`Co0000
B?ooool001cooooo00?o0000ooooooooool0GOooool2o`0001oooooo0_l0000Booooo`;o00003_oo
ool2o`0000?ooooo1?l000000ooooooo0000o`000006ooooo`;o00001Oooool2o`0000;ooooo0_l0
000Aooooo`;o00003_ooool5o`0001Sooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`1>
ooooo`;o000000Coooooo`000?l0003o00001oooool4o`0001oooooo0_l0000Cooooo`;o00000ooo
ool2o`0000Sooooo1?l000000ooooooo0000o`00000@ooooo`Co00003oooool2o`0000Gooooo0_l0
000=ooooo`Oo0000H?ooool001cooooo00?o0000ooooooooool0=?ooool2o`0001Sooooo0_l00000
1?oooooo0000o`000?l00007ooooo`;o00003Oooool2o`0002Oooooo0_l00003ooooo`;o00002?oo
ool4o`0000Kooooo0_l00007ooooo`;o00000_ooool4o`0000[ooooo0ol00002ooooo`;o00000_oo
ool2o`000003ooooool0003o000000?ooooo0_l0000=ooooo`;o00005Oooool2o`0004Wooooo000L
ooooo`03o`000?oooooooooo03Cooooo0_l0000Hooooo`;o00000_ooool2o`0000?ooooo0_l00005
ooooo`;o00002_ooool2o`0001?ooooo0_l0000?ooooo`;o00001oooool2o`0000gooooo0_l00000
1?oooooo0000o`000?l00007ooooo`Go000000?oooooo`000?l000002?ooool5o`0000Kooooo0_l0
00000ooooooo0000o`000005o`0000Cooooo0_l0000:ooooo`;o00001_ooool2o`0000[ooooo0_l0
0019ooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o00000_ooool2o`0000?ooooo0_l00005
ooooo`;o00002oooool2o`00013ooooo1?l0000?ooooo`;o00001Oooool4o`0000?ooooo0_l00008
ooooo`Go00002?ooool5o`000003ooooool0003o000000Sooooo0ol0000;ooooo`Go00001_ooool5
o`0000Oooooo0_l00006ooooo`?o0000E?ooool001cooooo00?o0000ooooooooool0DOooool2o`00
01Sooooo0_l00008ooooo`Co00001?ooool2o`0001Sooooo0ol00003ooooo`?o00002_ooool2o`00
00oooooo0_l00007ooooo`Co00003Oooool2o`000003ooooool0003o000000;ooooo0_l000000ooo
oooo0000o`000002o`0000Cooooo0_l0000:ooooo`;o0000E?ooool001cooooo00?o0000oooooooo
ool0<Oooool2o`0001Oooooo0_l00005ooooo`;o00007?ooool2o`0000?ooooo1Ol0000Qooooo`Wo
00006?ooool2o`000003ooooool0003o000000Cooooo1?l0000=ooooo`;o000000?oooooo`000?l0
00000_ooool2o`000003ooooool0003o000000Kooooo0_l0000Dooooo`;o0000B_ooool001cooooo
00?o0000ooooooooool0<Oooool2o`0001Oooooo2?l00007ooooo`;o00005?ooool2o`0000?ooooo
0_l0000Tooooo`Wo00003?ooool2o`0000Kooooo0_l00005ooooo`;o00001?ooool3o`0001Sooooo
0_l00008ooooo`Co00004?ooool2o`0004[ooooo000Looooo`03o`000?oooooooooo04Cooooo0_l0
0002ooooo`;o00000_ooool6o`000003ooooool0003o000000?ooooo0ol0000Aooooo`;o00002Ooo
ool2o`0001Kooooo1?l000000ooooooo0000o`000002o`000004ooooool0003o0000ooooo`Ko0000
0oooool3o`0000Oooooo0_l00006ooooo`Co00002Oooool5o`0000Cooooo0_l00002ooooo`;o0000
1Oooool2o`0000Kooooo0ol00002ooooo`;o00000_ooool4o`0000;ooooo0_l0001Hooooo`007?oo
ool00ol0003oooooooooo`12ooooo`Co00000_ooool2o`0000Wooooo0_l00003ooooo`;o00000ooo
ool2o`0000gooooo0_l00009ooooo`;o00000_ooool2o`00013ooooo1_l000000ooooooo0000o`00
000=o`0000;ooooo0ol00007ooooo`?o00001oooool2o`0000Gooooo0_l00005ooooo`;o000000Co
ooooo`000?l0003ooooo0_l00002ooooo`;o00001Oooool2o`0000Cooooo1Ol00002ooooo`?o0000
1oooool2o`0000Gooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00000ooo
ool2o`0000;ooooo1Ol0000=ooooo`;o00007?ooool2o`00013ooooo0_l00004oooooa?o00001_oo
ool2o`0000;ooooo1?l00007ooooo`;o00000oooool2o`000004ooooool0003o0000o`0000Cooooo
0_l00005ooooo`;o00001Oooool2o`0000Cooooo0_l00006ooooo`?o00001?ooool2o`0000Oooooo
0_l0001Aooooo`007?ooool00ol0003oooooooooo`17ooooo`;o00000_ooool5o`0000gooooo1?l0
0002ooooo`;o0000:_ooool2o`0000;ooooo4ol00006ooooo`;o00001?ooool2o`0000Oooooo0ol0
0005ooooo`?o00002oooool2o`000004ooooool0003o0000ooooo`Co00000_ooool2o`000004oooo
ool0003o0000o`0000Cooooo0_l00004ooooo`;o00001oooool2o`00057ooooo000Looooo`03o`00
0?oooooooooo04_ooooo0_l00008ooooo`;o00001_ooool4o`0000;ooooo0_l0000Zooooo`;o0000
00?oooooo`000?l000002Ol00002ooooo`Oo000000?oooooo`000?l000004oooool2o`0000Kooooo
0_l0000:ooooo`Ko000000?oooooo`000?l000000_l000001Ooooooo0000o`000?l0003ooooo00?o
00001?ooool2o`0000Cooooo0_l0001Jooooo`007?ooool2o`0002kooooo0_l0000Jooooo`Co0000
2?ooool2o`0000Cooooo1?l0000[ooooo`;o00001_oooolDo`000003ooooool0003o000000Oooooo
0_l000000ooooooo0000o`000003ooooo`;o00002_ooool2o`0000Kooooo2?l00002ooooo`Co0000
0_ooool2o`0000;ooooo0ol00004ooooo`;o00003?ooool2o`0005;ooooo000Looooo`03o`000?oo
oooooooo02gooooo0_l0000Gooooo`;o000000?oooooo`000?l000004?ooool4o`0001Wooooo1?l0
0003ooooo`;o00002Oooool3o`0000?ooooo5ol00009ooooo`;o000000?oooooo`000?l000000ooo
ool2o`0001;ooooo2?l00002ooooo`;o00001?ooool2o`0000;ooooo0_l0000:ooooo`;o00001ooo
ool2o`0000Gooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`0looooo`;o000000?ooooo
o`000?l000000oooool4o`0001;ooooo1_l00009ooooo`;o00001_ooool2o`0000Gooooo1?l00003
ooooo`;o00000_ooool2o`0000Kooooo0_l00003ooooo`Oo00000_ooool>o`0000;ooooo0ol00002
ooooo`Co00002?ooool2o`00017ooooo1_l00003ooooo`;o00001oooool2o`0000_ooooo0_l00000
0ooooooo0000o`000009ooooo`Co00000_ooool2o`000003ooooool0003o000004Cooooo000Loooo
o`03o`000?oooooooooo03cooooo0_l000000ooooooo0000o`000002ooooo`?o00005?ooool2o`00
0004ooooool0003o0000o`0000Wooooo0_l00006ooooo`;o00004?ooool2o`0000[ooooo7Ol00002
ooooo`;o00002_ooool2o`0000Sooooo0_l00002ooooo`?o00000_ooool6o`0000Kooooo0_l00004
ooooo`;o00001?ooool4o`0000Kooooo0_l00009ooooo`;o00001?ooool2o`000003ooooool0003o
000004Cooooo000Looooo`03o`000?oooooooooo04?ooooo0_l0000Booooo`;o00001?ooool2o`00
033ooooo7?l0000>ooooo`;o00000oooool2o`0000;ooooo1?l00002ooooo`?o000000?oooooo`00
0?l000000_l00008ooooo`?o00000oooool2o`0000Gooooo1?l000000ooooooo0000o`00000Doooo
o`;o0000Aoooool001cooooo00?o0000ooooooooool0:?ooool2o`0002gooooo0_l000000ooooooo
0000o`00000Eooooo`;o00002?ooool2o`0000?ooooo0_l0000:ooooo`;o00000_oooolIo`000003
ooooool0003o000000Gooooo0_l00006ooooo`;o00000oooool2o`0000;ooooo0_l00008ooooo`Ko
00001_ooool3o`0000?ooooo0_l0000:ooooo`;o00002_ooool2o`0000Sooooo0_l00017ooooo`00
7?ooool00ol0003oooooooooo`0Xooooo`;o0000;oooool3o`0000gooooo0_l00006ooooo`Co0000
1_ooool2o`0000?ooooo0_l0000:ooooo`;o00000_oooolLo`0000Gooooo0_l0000Fooooo`;o0000
0oooool5o`0000Kooooo0_l00006ooooo`;o000000?oooooo`000?l000004?ooool2o`0000Wooooo
0_l00016ooooo`007?ooool00ol0003oooooooooo`0Xooooo`;o00005Oooool3o`0001Oooooo0_l0
0008ooooo`;o00001?ooool3o`0000Oooooo0_l00007ooooo`;o00004Oooool2o`000003ooooool0
003o000000oo000000?oooooo`000?l000001?l0000Kooooo`;o00000_ooool2o`0000Cooooo1?l0
000>ooooo`;o000000?oooooo`000?l000000ol0000Aooooo`;o00001Oooool2o`0004Kooooo000L
ooooo`03o`000?oooooooooo02Sooooo0_l0000Booooo`;o000000Coooooo`000?l0003o00006ooo
ool2o`0000Cooooo0_l00005ooooo`;o00002oooool2o`0000?ooooo0_l0000>ooooo`;o000000Co
ooooo`000?l0003ooooo3ol00002ooooo`Oo00003?ooool2o`000004ooooool0003o0000o`0000Co
oooo1?l000000ooooooo0000o`000008ooooo`Go00002Oooool2o`0000Gooooo1_l0000=ooooo`;o
000000?oooooo`000?l00000COooool001cooooo00?o0000ooooooooool0??ooool4o`00017ooooo
0_l00006ooooo`;o00000_ooool2o`0001Sooooo0_l0000Cooooo`;o000000Coooooo`000?l0003o
oooo5ol00007ooooo`;o00001?ooool2o`000003ooooool0003o000000;o00000oooool4o`0000Oo
oooo0_l000000ooooooo0000o`000002ooooo`;o00002Oooool2o`0000Gooooo0_l00002ooooo`;o
00003Oooool2o`0000?ooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`0nooooo`;o0000
3oooool4o`0000Kooooo1?l0000Cooooo`;o00000_ooool2o`0000Oooooo0_l0000CoooooaCo0000
00Coooooo`000?l0003o00000oooool2o`000003ooooool0003o000000Sooooo0ol000000ooooooo
0000o`000002o`0000Wooooo2Ol0000Xooooo`;o00001?ooool2o`0000Cooooo0_l0000oooooo`00
7?ooool00ol0003oooooooooo`1?ooooo`;o00000_ooool2o`0000Kooooo0_l00003ooooo`So0000
00?oooooo`000?l000001Oooool8o`0000?ooooo1?l0000BoooooaWo00000oooool2o`0000Oooooo
1?l00004ooooo`?o00002oooool2o`0000;ooooo1Ol00006ooooo`;o00003?ooool3o`0000[ooooo
0_l0000:ooooo`;o00001?ooool2o`0003oooooo000Looooo`03o`000?oooooooooo03cooooo0ol0
00000ooooooo0000o`00000Aooooo`;o000000?oooooo`000?l000002?ooool8o`000004ooooool0
003o0000o`0000Gooooo0ol00002ooooo`Co000000?oooooo`000?l000001?ooool2o`0000cooooo
1?l000000ooooooo0000o`00000Bo`0000Cooooo0_l00008ooooo`Co00001Oooool2o`0000oooooo
0_l000001Ooooooo0000o`000?l0003ooooo00;o00000_ooool2o`0000cooooo1_l00006ooooo`?o
00000oooool2o`0004cooooo000Looooo`03o`000?oooooooooo03cooooo0ol000000ooooooo0000
o`00000>ooooo`;o00001?ooool2o`000003ooooool0003o000000Sooooo2ol00002ooooo`;o0000
00Coooooo`000?l0003o00000_ooool2o`000003ooooool0003o000000Cooooo0_l0000<oooooa[o
00000oooool2o`000004ooooool0003o0000ooooo`;o00007_ooool4o`000003ooooool0003o0000
00;ooooo0_l00002ooooo`;o00001?ooool2o`0000?ooooo1Ol00006ooooo`;o000000Coooooo`00
0?l0003ooooo0_l00007ooooo`;o0000@oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Ooo
ool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo03gooooo0ol0
000@ooooo`;o00001oooool2o`0000;ooooo0_l00002ooooo`go00000_ooool2o`000004ooooool0
003o0000o`0000;ooooo0_l000001?oooooo0000o`000?l0000Cooooo`?o000000?oooooo`000?l0
00003?l000000ooooooo0000o`000003o`0000Kooooo0_l000000ooooooo0000o`000005ooooo`;o
00005oooool2o`0000_ooooo0_l00004ooooo`;o00000oooool2o`0000cooooo0_l0000:ooooo`;o
0000@oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0hooooo`;o000000?oooooo`000?l000000ol00002oooo
o`;o00005?ooool2o`0000?ooooo0_l00002ooooo`ko00002?ooool3o`000003ooooool0003o0000
00?o00004Oooool2o`000003ooooool0003o0000013o00004oooool3o`0000Kooooo0_l00003oooo
o`;o00005_ooool2o`0000Cooooo0_l00003ooooo`;o00001?ooool2o`0000?ooooo0_l000000ooo
oooo0000o`00001?ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`Go
00001_ooool00ol0003oooooooooo`0hooooo`;o000000Coooooo`000?l0003o00001?ooool2o`00
00Wooooo0_l00009ooooo`;o00001oooool2o`000003ooooool0003o000000Ko000000?oooooo`00
0?l000000ol00005ooooo`;o00001Oooool2o`0000cooooo0ol00005ooooo`?o00000_ooool=o`00
0003ooooool0003o000000Wooooo0_l00005ooooo`?o00000oooool2o`000003ooooool0003o0000
00?ooooo0_l00008ooooo`Ko000000?oooooo`000?l000001Oooool2o`0000Cooooo0ol00003oooo
o`;o00000oooool2o`0000?ooooo1Ol0001?ooooo`0000?oooooo`000?ooool00_ooool00ol0003o
ooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0000iooooo`;o00000_ooool2o`00
00?ooooo0_l00004ooooo`;o00000oooool2o`0000Oooooo0_l00006oooooaKo00003Oooool2o`00
00Wooooo0ol0000:ooooo`_o00000oooool2o`0000Wooooo0_l00004ooooo`?o00001?ooool2o`00
00kooooo2ol00002ooooo`;o000000Coooooo`000?l0003o00000_ooool4o`0000?ooooo0_l00003
ooooo`;o00000_ooool2o`000004ooooool0003o0000o`0001;ooooo0_l0000kooooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o
0000ooooooooool0>Oooool2o`0000;ooooo0_l00009ooooo`;o00000_ooool2o`0000Sooooo0_l0
0006oooooaKo00003Oooool2o`000003ooooool0003o0000013ooooo0_l00002ooooo`So00003ooo
ool2o`0000Gooooo0ol00004ooooo`Co00000oooool2o`0000Oooooo0_l00002ooooo`;o00000_oo
ool4o`000004ooooool0003o0000ooooo`Oo00002?ooool4o`0000;ooooo0ol0000Eooooo`;o0000
>oooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00omgMgOoc<c<o`00
0007ooooo`03o`000?oooooooooo03gooooo0_l0000=ooooo`;o00002oooool2o`0000Gooooo5?l0
000=ooooo`;o000000?oooooo`000?l000002?ooool2o`0000Kooooo0_l00002ooooo`So00003_oo
ool3o`000003ooooool0003o000000_ooooo0_l00003ooooo`;o000000Goooooo`000?l0003o0000
ooooo`0@o`0000Cooooo1Ol00008ooooo`Co00000oooool2o`0000;ooooo0_l00009ooooo`;o0000
@oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03
o`000?oooooooooo04?ooooo1?l00006ooooo`;o00002_ooool4o`000003ooooool0003o000001Go
00006Oooool4o`0000Cooooo1_l00002ooooo`Co00003_ooool6o`00013ooooo0_l000001Ooooooo
0000o`000?l0003ooooo017o00000oooool4o`0000Oooooo1_l00007ooooo`;o000000?oooooo`00
0?l000001_ooool4o`00047ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPgooooo00?oMgMg
o`000?ooool01_ooool00ol0003oooooooooo`0hooooo`;o00002Oooool4o`0000Kooooo0_l0000<
oooooa_o00001oooool2o`0000Cooooo0_l0000;ooooo`;o00001?ooool6o`0000?ooooo0_l0000?
ooooo`Co00003_ooool2o`0000Gooooo0_l00004ooooo`oo000000?oooooo`000?l000000_ooool2
o`0000;ooooo0_l00003ooooo`;o00003_ooool2o`0000Sooooo0_l00011ooooo`007?ooool00ol0
003oooooooooo`0_ooooo`;o00001oooool2o`000003ooooool0003o000001?ooooo0_l0000:oooo
oako000000?oooooo`000?l000000_l00004ooooo`;o00003Oooool2o`0000;ooooo0_l00004oooo
o`;o00004?ooool2o`0001;ooooo0_l00005ooooo`?o000000?oooooo`000?l000002_l000000ooo
oooo0000o`000005o`0000;ooooo1_l0000;ooooo`;o00000_ooool2o`0004oooooo000Looooo`03
o`000?oooooooooo02oooooo0_l00005ooooo`;o00000oooool4o`0000Sooooo0_l00007ooooo`;o
00002_oooolNo`000003ooooool0003o000001Gooooo0_l00002ooooo`;o00001?ooool2o`0000?o
oooo0_l0000;ooooo`;o00003_ooool2o`0000[ooooo7Ol00004ooooo`;o00001oooool2o`0000;o
oooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`0Mooooo`;o00005oooool2o`0000Gooooo
0_l00008ooooo`;o000000?oooooo`000?l000004?oooolDo`000003ooooool0003o000000?o0000
00?oooooo`000?l000006oooool5o`0000Sooooo0_l0000Kooooo`;o00003?oooolKo`0000;ooooo
1?l00002ooooo`;o00001Oooool2o`0000kooooo0_l00011ooooo`007?ooool00ol0003ooooooooo
o`0Mooooo`;o00005_ooool2o`0000;ooooo0_l0000<ooooo`;o000000?oooooo`000?l000001Ooo
ool2o`000003ooooool0003o000000Oooooo7?l00008ooooo`;o00004Oooool2o`000003ooooool0
003o000000Gooooo0_l00004ooooo`;o00002_ooool2o`0000cooooo0_l00003ooooo`;o00001ooo
ool2o`000003ooooool0003o000001Ko00000_ooool5o`000003ooooool0003o000000?ooooo1?l0
0004ooooo`?o000000?oooooo`000?l000001?ooool2o`00047ooooo000Looooo`03o`000?oooooo
oooo02oooooo0_l00004ooooo`;o000000?oooooo`000?l000000_l0000=ooooo`?o00001Oooool2
o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`00000Lo`0000Sooooo0_l0000K
ooooo`;o00001?ooool2o`0000[ooooo0_l0000<ooooo`;o00000oooool2o`0000Kooooo2_l00000
0ooooooo0000o`00000?o`0000;ooooo1Ol00004ooooo`Co00001_ooool3o`000003ooooool0003o
000004Oooooo000Looooo`03o`000?oooooooooo02oooooo0_l00007ooooo`Co00003Oooool3o`00
00_ooooo0ol000000ooooooo0000o`00000@o`000003ooooool0003o000000co000000?oooooo`00
0?l000000_ooool2o`0000;ooooo0_l00007ooooo`;o00006?ooool4o`0001;ooooo0_l00003oooo
o`;o00000_ooool2o`000003ooooool0003o000001co000000Coooooo`000?l0003ooooo0_l00004
ooooo`;o00001oooool3o`0000Wooooo0_l00003ooooo`;o0000>oooool001cooooo00?o0000oooo
ooooool0;Oooool2o`0000Oooooo0ol0000Nooooo`;o00000oooool9o`000003ooooool0003o0000
00go000000?oooooo`000?l000001?l000000ooooooo0000o`000002ooooo`;o00000_ooool2o`00
00Oooooo0_l00003ooooo`;o00002?ooool2o`0000Wooooo1?l0000>ooooo`;o00002oooool2o`00
0003ooooool0003o000001co000000?oooooo`000?l000000ol00009ooooo`;o000000?oooooo`00
0?l000000_l00009ooooo`;o00000oooool2o`0003_ooooo000Looooo`03o`000?oooooooooo02go
oooo0_l00002ooooo`;o00000_ooool4o`0000kooooo0_l0000;ooooo`;o00001_ooool=o`0000;o
oooo4Ol000000ooooooo0000o`00000@ooooo`;o00000_ooool2o`0000Sooooo0_l0000Kooooo`Co
00002_ooool2o`000003ooooool0003o000001co000000?oooooo`000?l000000_l00009ooooo`;o
000000?oooooo`000?l00000COooool001cooooo00?o0000ooooooooool0<Oooool2o`0000;ooooo
0_l0000@ooooo`;o00002oooool2o`0000Oooooo6ol0000<ooooo`;o00000oooool4o`0000;ooooo
0_l0000?ooooo`;o00000_ooool2o`0000gooooo0_l00005ooooo`Co00002_oooolQo`0000;ooooo
0ol00009ooooo`;o00008?ooool2o`0002kooooo000Looooo`03o`000?oooooooooo02oooooo0ol0
000:ooooo`;o00006oooool2o`000003ooooool0003o000000Wo000000?oooooo`000?l000003_l0
0002ooooo`;o00000oooool2o`0000?ooooo0_l00003ooooo`Co00004oooool3o`000003ooooool0
003o000000gooooo0_l00003ooooo`;o00001oooool2o`000003ooooool0003o000000;ooooo7Ol0
00000ooooooo0000o`000002ooooo`?o00002_ooool2o`0000;ooooo0_l0000Looooo`;o0000;_oo
ool001cooooo00?o0000ooooooooool0;oooool3o`0000Kooooo1_l000000ooooooo0000o`000009
ooooo`;o00003Oooool2o`000004ooooool0003o0000oooooaWo00000_ooool2o`0000?ooooo0_l0
0003ooooo`;o00001_ooool2o`0000oooooo0_l000001?oooooo0000o`000?l0000;ooooo`;o0000
2?ooool2o`0000Gooooo1?l000001?oooooo0000o`000?oooolNo`000004ooooool0003o0000oooo
o`?o00001Oooool2o`0000Sooooo0_l0001<ooooo`007?ooool2o`0003;ooooo0_l00003ooooo`Ko
00000oooool2o`0000Wooooo0_l0000@ooooo`;o000000?oooooo`000?l000005_l0000=ooooo`;o
00001_ooool2o`0000oooooo0ol0000>ooooo`;o00003oooool2o`0000Kooooo0_l000000ooooooo
0000o`00000<o`000003ooooool0003o000000go000000?oooooo`000?l000001_ooool2o`0001oo
oooo0_l0000eooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00000_ooool5o`0000Cooooo
0ol0000Kooooo`;o000000Goooooo`000?l0003o0000ooooo`0>o`000003ooooool0003o000000Go
00004_ooool4o`0000Kooooo0_l00003ooooo`;o00000_ooool2o`0001_ooooo1?l0000:ooooob7o
00008_ooool2o`0000Cooooo0_l0000eooooo`007?ooool00ol0003oooooooooo`0eooooo`Go0000
1?ooool3o`0001Wooooo7ol0000=ooooo`;o00000oooool6o`0000;ooooo2Ol00005ooooo`;o0000
00?oooooo`000?l000005?ooool7o`0000Oooooo8_l0000<ooooo`;o00005?ooool2o`0003_ooooo
000Looooo`03o`000?oooooooooo02cooooo0_l00006ooooo`;o000000Goooooo`000?l0003o0000
ooooo`02o`0001gooooo4Ol000000ooooooo0000o`000009o`0000[ooooo0_l00003ooooo`?o0000
0_ooool6o`0000;ooooo2Ol00005ooooo`;o000000?oooooo`000?l000004?ooool2o`0000;ooooo
1?l000000ooooooo0000o`000007ooooob7o00001?ooool2o`0000;ooooo0_l00003ooooo`;o0000
4_ooool2o`0003gooooo000Looooo`03o`000?oooooooooo02Sooooo0_l00002ooooo`;o00001_oo
ool3o`0000?ooooo1_l00003ooooo`;o000000?oooooo`000?l000004Oooool2o`0000Kooooo5_l0
0008ooooo`Co00001?ooool3o`000003ooooool0003o000000;o00002?ooool5o`0000gooooo0_l0
0002ooooo`;o00001oooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0000Gooooo
7?l00003ooooo`;o00000oooool2o`0000;ooooo0_l0000Gooooo`;o0000?Oooool001cooooo00?o
0000ooooooooool0:?ooool2o`0000_ooooo0_l00003ooooo`;o000000Goooooo`000?l0003o0000
ooooo`07o`00017ooooo0_l00008oooooa;o00002_ooool4o`000003ooooool0003o000000;ooooo
2_l00005ooooo`;o00000_ooool2o`0000cooooo0_l00002ooooo`Co00003_ooool2o`000003oooo
ool0003o000000Gooooo3_l000000ooooooo0000o`00000;o`0000?ooooo0_l00003ooooo`;o0000
F_ooool001cooooo00?o0000ooooooooool0=Oooool4o`0000;ooooo0_l00004ooooo`;o000000?o
ooooo`000?l000005oooool2o`0000Kooooo2?l000000ooooooo0000o`000007o`0000;ooooo0_l0
0009ooooo`;o00000_ooool5o`000003ooooool0003o000000Go000000Goooooo`000?l0003o0000
ooooo`03o`0000_ooooo0_l00002ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Gooooo
0_l0000<ooooo`go000000?oooooo`000?l000002?l00005ooooo`;o00000oooool5o`0000;ooooo
0_l0001Cooooo`007?ooool00ol0003oooooooooo`0eooooo`Co00000_ooool2o`00023ooooo0_l0
0005ooooo`[o000000?oooooo`000?l000001_l00002ooooo`;o00000oooool2o`0000?ooooo0_l0
00000ooooooo0000o`000003o`0000Cooooo1_l000001Ooooooo0000o`000?l0003ooooo00?o0000
2oooool2o`0000;ooooo0_l00008ooooo`;o00001Oooool2o`0000Kooooo0ol000000ooooooo0000
o`00000Lo`0000Oooooo2?l0000Cooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0>Ooo
ool2o`000003ooooool0003o000001oooooo0_l00005ooooo`?o00001?ooool6o`000004ooooool0
003o0000o`0000Gooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000000;o0000
00?oooooo`000?l000002Oooool2o`0000;ooooo0_l00002ooooo`;o00000oooool2o`000003oooo
ool0003o000000Kooooo0_l00003ooooo`;o00003Oooool2o`000003ooooool0003o000000Oo0000
0_oooolGo`0000_ooooo0ol0000Dooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0;ooo
ool2o`0000Sooooo0_l000000ooooooo0000o`00000Oooooo`;o00001_ooool2o`0000;ooooo1ol0
00000ooooooo0000o`000002o`0000Cooooo0ol00008ooooo`;o00000_ooool2o`000004ooooool0
003o0000o`0000;ooooo0_l00004ooooo`;o00000oooool2o`000003ooooool0003o000000?ooooo
0_l000000ooooooo0000o`000006ooooo`;o00000oooool6o`000003ooooool0003o000000Kooooo
0_l00003ooooo`;o000000Coooooo`000?l0003o00000oooool?o`000003ooooool0003o000000;o
00002?ooool2o`0000Gooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o0000
2oooool2o`0002[ooooo1_l00003ooooo`;o00001_ooool2o`0000Cooooo0_l000000ooooooo0000
o`000002o`0000Cooooo2?l000000ooooooo0000o`000006ooooo`;o00005Oooool7o`000003oooo
ool0003o000000_ooooo0_l000001Ooooooo0000o`000?l0003ooooo00co000000?oooooo`000?l0
00000_l000000ooooooo0000o`000004o`0000Cooooo1?l0000<ooooo`;o0000COooool001cooooo
00?o0000ooooooooool0FOooool2o`0000gooooo0_l00007ooooo`;o00001?ooool5o`0000?ooooo
1Ol00003ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l0000:ooooo`;o0000
4Oooool7o`00017ooooo5Ol000000ooooooo0000o`000002ooooo`;o00001?ooool2o`0000;ooooo
0_l00002ooooo`;o000000?oooooo`000?l000000oooool4o`0004_ooooo000Looooo`03o`000?oo
oooooooo02kooooo0_l0000;ooooo`;o00006Oooool2o`000003ooooool0003o000001Kooooo0ol0
00000ooooooo0000o`000005o`0000Gooooo0_l000001?oooooo0000o`000?ooool2o`00013ooooo
0_l00002ooooo`Co000000?oooooo`000?l000000oooool2o`0000;ooooo0_l00002ooooo`;o0000
0_ooool4o`0001;ooooo5_l000000ooooooo0000o`00000<ooooo`;o00000_ooool2o`000003oooo
ool0003o000000?ooooo1?l00005ooooo`;o00001oooool2o`0003_ooooo000Looooo`03o`000?oo
oooooooo02kooooo0_l00002ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Oooooo0_l0
000@ooooo`;o00000_ooool2o`00013ooooo0_l00004ooooo`;o000000?oooooo`000?l000000_l0
00000ooooooo0000o`000002o`0000?ooooo0_l000000ooooooo0000o`00000Cooooo`;o00000_oo
ool3o`0000;ooooo0_l00003ooooo`Ko00000_ooool4o`0000[ooooo0_l00002ooooo`;o00001Ooo
ool3o`0000Cooooo1_l00003ooooo`?o000000Goooooo`000?l0003o0000ooooo`02o`0000_ooooo
0_l0000;ooooo`;o00001oooool2o`0000Oooooo0_l00003ooooo`;o0000=_ooool001cooooo00?o
0000ooooooooool0<_ooool5o`0000Cooooo0_l00007ooooo`;o00004?ooool2o`0000;ooooo0_l0
0002ooooo`;o00001?ooool2o`0000Kooooo1?l00007ooooo`Oo00000oooool3o`00017ooooo0_l0
000Booooo`;o00001_ooool2o`0000Cooooo0_l00004ooooo`;o00000_ooool3o`0000Cooooo0ol0
00000ooooooo0000o`000004ooooo`;o00001?ooool2o`0000;ooooo0_l00002ooooo`;o00001?oo
ool2o`0000Gooooo0_l000000ooooooo0000o`000008ooooo`;o00005Oooool2o`0003Kooooo000L
ooooo`03o`000?oooooooooo037ooooo1Ol00003ooooo`Co00005?ooool2o`0000?ooooo0_l00005
ooooo`Co00000_ooool3o`0000Sooooo0_l00003ooooo`;o00000oooool2o`000004ooooool0003o
0000ooooo`;o000000Coooooo`000?l0003o00002oooool2o`0000Cooooo0_l00003ooooo`;o0000
1?ooool2o`0000Oooooo0_l0000<ooooo`;o00002Oooool2o`0000Gooooo0_l000000ooooooo0000
o`000004ooooo`Wo00001?ooool3o`0000Cooooo0_l00003ooooo`;o00000oooool2o`0000Gooooo
0_l000000ooooooo0000o`000006ooooo`;o00004_ooool4o`0002oooooo000Looooo`;o0000<_oo
ool4o`0000Cooooo0_l0000:ooooo`;o00002_ooool2o`0000?ooooo0ol00004ooooo`Co000000Co
ooooo`000?l0003o00002_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000;ooooo
1?l00002ooooo`Co00002Oooool4o`0000Oooooo0_l00004ooooo`;o00006oooool2o`0000Oooooo
0_l00003ooooo`;o00001_ooool8o`0000Cooooo0ol00007ooooo`Co00002_ooool2o`000003oooo
ool0003o000000Kooooo0_l0000Booooo`Co0000;oooool001cooooo00?o0000ooooooooool0<ooo
ool2o`0000gooooo1Ol000000ooooooo0000o`00000=ooooo`;o00002Oooool6o`0000Kooooo0ol0
0005ooooo`Wo00001Oooool2o`0000?ooooo0_l00006ooooo`;o00000_ooool2o`0000Kooooo0_l0
000=ooooo`;o000000Coooooo`000?l0003ooooo0_l00009ooooo`;o00001oooool3o`0000;ooooo
0_l0000;ooooo`;o00001Oooool2o`0000Sooooo0_l00008ooooo`;o00008_ooool2o`00033ooooo
000Looooo`03o`000?oooooooooo03?ooooo0_l00008ooooo`;o00000oooool5o`000003ooooool0
003o000001[ooooo1?l00006ooooo`Go000000?oooooo`000?l000000_l000000ooooooo0000o`00
0002o`0000Cooooo0_l00006ooooo`;o00002_ooool2o`0000Cooooo1?l0000=ooooo`;o000000Co
ooooo`000?l0003ooooo0_l00006ooooo`;o00002oooool2o`0000Gooooo0_l0000;ooooo`;o0000
00?oooooo`000?l000004Oooool4o`0000_ooooo0_l0000Eooooo`Co0000;_ooool001cooooo00?o
0000ooooooooool0;?ooool2o`0000;ooooo0_l000000ooooooo0000o`000008ooooo`;o00001_oo
ool2o`0001Gooooo0_l0000@ooooo`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o0000
1_ooool2o`0000Gooooo0_l00002ooooo`;o00002Oooool2o`000004ooooool0003o0000o`0000Go
oooo0ol00003ooooo`;o00004?ooool2o`0000Oooooo0_l00006ooooo`;o000000?oooooo`000?l0
00002oooool2o`000003ooooool0003o0000017ooooo0_l0000=ooooo`;o00005Oooool4o`0002ko
oooo000Looooo`03o`000?oooooooooo02cooooo0_l00002ooooo`;o00004Oooool2o`0000gooooo
0_l00008ooooo`;o00003Oooool5o`0000Cooooo0_l0000>ooooo`;o00000_ooool2o`0000;ooooo
0_l00005ooooo`;o00000_ooool5o`0000Kooooo0ol00003ooooo`;o00006Oooool2o`0000Kooooo
0ol0000Mooooo`;o0000G?ooool001cooooo00?o0000ooooooooool0@oooool2o`0000gooooo0_l0
0007ooooo`;o00003_ooool3o`0000Kooooo0_l0000>ooooo`?o00003?ooool2o`0000Cooooo0_l0
0008ooooo`;o00001oooool2o`0001kooooo0_l00002ooooo`;o00003_ooool2o`0000Wooooo0_l0
000>ooooo`;o00000_ooool2o`0000Cooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`0[
ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Kooooo0_l000000ooooooo0000o`00000=
ooooo`;o00001_ooool2o`000003ooooool0003o000000Kooooo0_l00005ooooo`Co00001_ooool2
o`000004ooooool0003o0000o`0000_ooooo1?l0000Dooooo`;o000000?oooooo`000?l000000ol0
0007ooooo`Co00008?ooool3o`0000Cooooo0_l00004ooooo`Go00002?ooool2o`0000oooooo0_l0
0002ooooo`;o00001?ooool3o`00047ooooo000Looooo`03o`000?oooooooooo02_ooooo0_l00000
0ooooooo0000o`000006ooooo`?o00001Oooool2o`000003ooooool0003o000000gooooo0_l00006
ooooo`;o00002Oooool4o`0000?ooooo1?l00004ooooo`;o00000oooool3o`0000Oooooo0_l00004
ooooo`;o00001Oooool2o`0000gooooo0_l000000ooooooo0000o`000003o`0000Kooooo0_l00000
0ooooooo0000o`000002o`0000_ooooo0_l00002ooooo`;o00003_ooool2o`0000Cooooo1?l00002
ooooo`?o00001Oooool2o`000003ooooool0003o000000;o00000_ooool2o`0001Kooooo0ol00010
ooooo`007?ooool00ol0003oooooooooo`0fooooo`?o00001oooool2o`0000?ooooo0_l0000=oooo
o`;o00003oooool4o`0000Sooooo1Ol000001?oooooo0000o`000?ooool2o`0000Gooooo0_l0000;
ooooo`;o00003Oooool2o`0000?ooooo0ol00005ooooo`?o00000oooool2o`000004ooooool0003o
0000o`0000Oooooo0_l00002ooooo`;o00003_ooool2o`0000Kooooo0_l00004ooooo`;o000000Co
ooooo`000?l0003ooooo1Ol00004ooooo`Co00001_ooool2o`0000gooooo0_l00010ooooo`007?oo
ool00ol0003oooooooooo`0`ooooo`;o00002_ooool2o`0000;ooooo0_l00003ooooo`?o00003?oo
ool2o`00017ooooo0_l00008ooooo`;o000000?oooooo`000?l000001?ooool2o`0001Wooooo0_l0
0004ooooo`;o00001Oooool2o`0000Kooooo0_l00007ooooo`Go00002?ooool2o`0000oooooo0_l0
000<ooooo`Go00000oooool2o`0000Cooooo0_l000000ooooooo0000o`000006ooooo`?o00003?oo
ool2o`00043ooooo000Looooo`03o`000?oooooooooo033ooooo0_l0000:ooooo`;o00001_ooool5
o`0000Oooooo0_l0000Oooooo`;o00001?ooool2o`0000Gooooo0ol00008ooooo`;o00000_ooool2
o`0000Kooooo0_l00004ooooo`?o00001_ooool2o`0000Cooooo0_l0000:ooooo`;o00001?ooool2
o`0000;ooooo0_l0000Oooooo`;o00002?ooool4o`0000;ooooo0_l000000ooooooo0000o`000002
ooooo`?o00001?ooool2o`0004Sooooo000Looooo`03o`000?oooooooooo03Gooooo0_l000000ooo
oooo0000o`00000:ooooo`;o000000?oooooo`000?l000000_l00005ooooo`;o00000oooool2o`00
00kooooo1?l00008ooooo`;o00001?ooool2o`0000Gooooo0ol000000ooooooo0000o`000005oooo
o`;o00000_ooool2o`0000gooooo0_l00006ooooo`;o00001?ooool2o`0000Oooooo0_l00003oooo
o`;o000000Coooooo`000?l0003o00000_ooool2o`000003ooooool0003o000000Wooooo0_l00008
ooooo`;o00001_ooool3o`0000;ooooo0ol000000ooooooo0000o`000002o`0000Cooooo1Ol00003
ooooo`?o00000oooool2o`000003ooooool0003o000004Gooooo000Looooo`03o`000?oooooooooo
03Gooooo0_l000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l000000oooool3o`00
00Gooooo0_l00003ooooo`;o00002_ooool2o`000003ooooool0003o000000Co00000_ooool3o`00
00Sooooo0_l00009ooooo`;o00009_ooool2o`0000Oooooo0_l00003ooooo`;o000000Coooooo`00
0?l0003ooooo1?l000000ooooooo0000o`000004ooooo`Oo00001?ooool2o`0000;ooooo1?l00002
ooooo`Ko000000?oooooo`000?l000001?l00007ooooo`;o00001_ooool3o`0000Gooooo0_l00004
ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0=oooool2o`0000Oooooo0_l000000ooo
oooo0000o`00000Looooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo1Ol00003oooo
o`;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000Gooooo0_l0000Aoooo
o`;o00003Oooool2o`0000?ooooo0_l00005ooooo`Co00000_ooool2o`000004ooooool0003o0000
ooooo`;o00000oooool6o`0000Cooooo0ol00002ooooo`Co000000Coooooo`000?l0003o00000_oo
ool2o`0000Cooooo1Ol0000>ooooo`;o00000oooool2o`0000Kooooo0_l0000oooooo`007?ooool0
0ol0003oooooooooo`0]ooooo`;o00002?ooool2o`0000Oooooo1?l0000:ooooo`;o00005?ooool2
o`0000Sooooo0ol00003ooooo`;o00000_ooool8o`000003ooooool0003o000000?o00001?ooool3
o`00013ooooo0_l0000;ooooo`Co00000_ooool5o`0000Gooooo0_l00005ooooo`;o000000?ooooo
o`000?l000002_ooool2o`000003ooooool0003o000000?ooooo0_l00003ooooo`Co00002_ooool2
o`000003ooooool0003o0000013ooooo1?l00015ooooo`007?ooool00ol0003oooooooooo`0]oooo
o`;o00001_ooool4o`0000;ooooo1Ol00002ooooo`;o00001oooool2o`000003ooooool0003o0000
00oooooo0_l00002ooooo`;o00004oooool2o`0000;ooooo1ol000000ooooooo0000o`000005oooo
o`;o00007Oooool2o`0000Cooooo0_l000000ooooooo0000o`000006o`0000?ooooo1?l00004oooo
o`;o00001_ooool4o`0000;ooooo1?l00005ooooo`Co00000_ooool2o`0000Oooooo1?l00002oooo
o`;o00003_ooool2o`0000;ooooo0_l00011ooooo`007?ooool2o`0003Cooooo1_l00002ooooo`Go
00001_ooool2o`0000?ooooo0ol0000Aooooo`;o00000_ooool2o`00013ooooo0_l00006ooooo`Co
00001_ooool2o`0001cooooo0_l000000ooooooo0000o`000004ooooo`;o00001Oooool6o`000003
ooooool0003o000000Go00000oooool2o`0000Kooooo0_l00003ooooo`Go00002oooool2o`0000;o
oooo1?l000000ooooooo0000o`000004ooooo`;o00004_ooool2o`0000cooooo0_l0000cooooo`00
7?ooool00ol0003oooooooooo`0Zooooo`;o00000oooool2o`0000;ooooo0_l0000Aooooo`;o0000
00Coooooo`000?l0003ooooo0_l0000Wooooo`Ko00001_ooool2o`0000Cooooo0_l0000Hooooo`;o
00000_ooool2o`000003ooooool0003o000000;o00000_ooool2o`0000Kooooo1?l000000ooooooo
0000o`000002o`0000;ooooo0_l00005ooooo`;o00001_ooool2o`000003ooooool0003o000000;o
00003?ooool2o`0000;ooooo1?l00002ooooo`;o00001Oooool2o`00017ooooo0_l0000;ooooo`;o
0000<oooool001cooooo00?o0000ooooooooool0:_ooool2o`0000?ooooo0_l00007ooooo`;o0000
3?ooool5o`0001gooooo0_l00009ooooo`;o00000_ooool4o`0000Kooooo0_l000000ooooooo0000
o`00000Kooooo`;o00001Oooool4o`0000Kooooo0_l000000ooooooo0000o`000003o`000003oooo
ool0003o000000Go00000oooool2o`000003ooooool0003o000000Kooooo0_l00008ooooo`;o0000
1oooool2o`0000Sooooo0_l00005ooooo`;o00000_ooool2o`0000Oooooo0_l000001?oooooo0000
o`000?ooool2o`00043ooooo000Looooo`03o`000?oooooooooo03;ooooo0_l00004ooooo`;o0000
1_ooool2o`0000Kooooo0_l0000Nooooo`;o00001Oooool2o`000004ooooool0003o0000o`0000oo
oooo0_l0000Iooooo`;o00000oooool2o`0000Wooooo0_l000000ooooooo0000o`000006o`0000?o
oooo1Ol00003ooooo`;o00004oooool2o`0000Wooooo0_l0000Aooooo`;o00001oooool2o`000003
ooooool0003o000004?ooooo000Looooo`03o`000?oooooooooo02gooooo0_l00003ooooo`;o0000
0_ooool2o`0000Sooooo0_l0000:ooooo`;o000000?oooooo`000?l000006?ooool2o`0000Cooooo
0_l000000ooooooo0000o`000003ooooo`;o00009_ooool2o`000003ooooool0003o000000;o0000
0_ooool2o`0000Gooooo0_l00003ooooo`Co00001oooool2o`00017ooooo0_l00006ooooo`;o0000
2Oooool2o`0000Oooooo0_l0000?ooooo`;o00000oooool2o`000003ooooool0003o000000_ooooo
0_l00002ooooo`;o0000;oooool001cooooo00?o0000ooooooooool0;Oooool2o`0000Oooooo0_l0
00000ooooooo0000o`000008ooooo`;o00001oooool2o`000003ooooool0003o000001Sooooo0_l0
00000ooooooo0000o`000003ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000
o`000003ooooo`;o00001oooool2o`0001;ooooo0_l000001?oooooo0000o`000?ooool3o`0000?o
oooo0_l00007ooooo`Go000000?oooooo`000?l000000_l00004ooooo`;o00000oooool2o`0000Go
oooo0_l00005ooooo`;o00005_ooool2o`0000;ooooo0_l0000?ooooo`;o00000oooool2o`000003
ooooool0003o000000_ooooo0_l00002ooooo`;o0000;oooool001cooooo00?o0000ooooooooool0
:_ooool2o`0000Kooooo1_l000001?oooooo0000o`000?ooool2o`0000Gooooo1?l0000Tooooo`?o
00000_ooool3o`000003ooooool0003o000000?o000000?oooooo`000?l000000oooool2o`0000Oo
oooo0_l0000:ooooo`;o00001_ooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo
0000o`000005o`0000;ooooo1Ol000000ooooooo0000o`000002o`000003ooooool0003o000000?o
oooo0_l000000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l000006_ooool2o`0005go
oooo000Looooo`03o`000?oooooooooo02[ooooo0_l00006ooooo`Go00001Oooool2o`0000Oooooo
0_l0000Looooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`go00001?ooool2o`00017ooooo
0_l0000=ooooo`ko00000_ooool2o`0000;ooooo0_l00002ooooo`Co00000_ooool4o`0000Wooooo
0_l0000>ooooo`;o00007oooool2o`0004Sooooo000Looooo`03o`000?oooooooooo03Gooooo0_l0
000Sooooo`;o00001oooool2o`0000;ooooo0_l00006ooooo`ko00001?ooool2o`0001Sooooo0_l0
0006ooooo`;o000000?oooooo`000?l000002Ol00002ooooo`Oo000000?oooooo`000?l000001?l0
0002ooooo`;o00005Oooool6o`0001oooooo1?l00003ooooo`;o00002_ooool2o`0003Gooooo000L
ooooo`03o`000?oooooooooo03Oooooo0ol00002ooooo`;o00000_ooool2o`0001Sooooo0_l0000>
ooooo`Co000000?oooooo`000?l000003?l0000Nooooo`;o00000_ooool2o`0000;ooooo3_l00000
0ooooooo0000o`00000=o`0001Wooooo1?l0000Qooooo`Co00000oooool2o`0000[ooooo0_l0000e
ooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00000_ooool2o`000004ooooool0003o0000
o`0000;ooooo0_l00002ooooo`;o00006?ooool2o`0000kooooo4ol00003ooooo`;o00007?ooool3
o`000003ooooool0003o000000Go000000?oooooo`000?l000005?l00007ooooo`;o00000oooool2
o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o00001Oooool2o`0006Sooooo000Loooo
o`03o`000?oooooooooo02_ooooo0_l00003ooooo`;o00000_ooool2o`0000Cooooo0_l00007oooo
o`;o00001oooool4o`0000[ooooo0_l00003ooooo`;o00000oooool2o`0000;ooooo0_l00002oooo
oa;o00000_ooool2o`0001Wooooo1Ol000001?oooooo0000o`000?l00003oooooa[o00000oooool2
o`000003ooooool0003o000000?ooooo1Ol00003ooooo`;o00000_ooool2o`0000Gooooo0_l0000`
ooooo`;o0000=_ooool001cooooo00?o0000ooooooooool0:oooool4o`0000_ooooo0_l00007oooo
o`;o00001oooool4o`0000oooooo0_l00003ooooo`Ko00000ooooolBo`0000cooooo0_l0000>oooo
o`Go000000?oooooo`000?l000001?ooool@o`000003ooooool0003o000000So00000_ooool2o`00
00Oooooo0ol00011ooooo`;o0000=_ooool001cooooo00?o0000ooooooooool0;Oooool3o`0001Oo
oooo0_l0000Fooooo`;o00001Oooool2o`0000?ooooo5Ol0000;ooooo`;o00003?ooool2o`000003
ooooool0003o000000Co000000?oooooo`000?l000007Ol00002ooooo`;o00001oooool2o`0003?o
oooo0ol00014ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^
k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0;Oooool4o`0000[ooooo0_l0000:
ooooo`;o00004oooool2o`0000gooooo5ol0000?ooooo`;o00001?ooool4o`000003ooooool0003o
000000Co000000?oooooo`000?l000007Ol00002ooooo`?o00001?ooool2o`0000Gooooo0_l00003
ooooo`;o0000:Oooool3o`0004Cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ
8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0]ooooo`Co0000
2_ooool2o`000003ooooool0003o000001Kooooo0_l00003ooooo`?o00001_ooool2o`0000Gooooo
5ol0000?ooooo`;o00001?ooool2o`0000?ooooo0_l00002oooooaoo00000_ooool2o`000004oooo
ool0003o0000o`0000Cooooo1?l00003ooooo`;o00000oooool2o`0002Sooooo0_l00016ooooo`00
00?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`0nooooo`;o00005_ooool2o`0000;ooooo1?l000000ooooooo
0000o`000003ooooo`;o00001OoooolEo`0000kooooo0_l00002ooooo`;o00002?ooool2o`0000Co
oooo0ol000001Ooooooo0000o`000?l0003ooooo01Wo000000?oooooo`000?l000001?ooool2o`00
0003ooooool0003o000003;ooooo0_l00016ooooo`0000?oooooo`000?ooool00_ooool00ol0003o
ooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0005;ooooo0_l00006oooo
o`;o00000oooool2o`0000;ooooo0_l00005oooooaKo00003_ooool2o`0000;ooooo0_l00009oooo
o`?o000000Goooooo`000?l0003o0000ooooo`04o`000003ooooool0003o000001So00001_ooool4
o`0003Cooooo0_l00015ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09oooo
o`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0aooooo`;o000000?ooooo
o`000?l000001?ooool2o`000003ooooool0003o000000Sooooo0_l00009ooooo`;o00003oooool2
o`0000Gooooo2?l000000ooooooo0000o`00000;o`0000;ooooo0_l0000Dooooo`;o00000ooooolW
o`000003ooooool0003o000000Cooooo0ol0000dooooo`?o0000A?ooool00003ooooool@413ooooo
00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo
037ooooo0_l000000ooooooo0000o`000002ooooo`Co000000?oooooo`000?l000000_ooool2o`00
00;ooooo1?l00008ooooo`;o00001Oooool2o`000003ooooool0003o000000;ooooo0_l00009oooo
oaKo00000_ooool3o`0001?ooooo0_l00005ooooob?o000000?oooooo`000?l000001?l00009oooo
o`;o0000;oooool2o`0004Cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00?ogMgM
oa0@4?nHV9P02?ooool00ol0003oooooooooo`0hooooo`Go00001?ooool2o`0000;ooooo0_l00003
ooooo`;o00001Oooool2o`0000?ooooo1ol00002ooooo`;o00002OoooolEo`0000Cooooo0_l00000
1?oooooo0000o`000?ooool2o`0000Cooooo0ol00004ooooo`?o00001_oooolSo`000003ooooool0
003o000000;ooooo1?l00007ooooo`;o00003?ooool2o`0001Gooooo0_l0001@ooooo`0000Kooooo
onk^k_lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000oooooooo
ool0>?ooool5o`0000?ooooo0_l00003ooooo`;o00000oooool2o`0000Cooooo0_l00002ooooo`co
00002ooooolGo`000004ooooool0003o0000ooooo`Go00001?ooool5o`0000;ooooo0ol00003oooo
obKo00000_ooool2o`000003ooooool0003o000000;o00002Oooool2o`0000[ooooo0_l0000Eoooo
o`;o00001oooool2o`0004Oooooo000Looooo`03o`000?oooooooooo03Kooooo0_l00008ooooo`;o
00000oooool2o`0000Wooooo0_l00002ooooo`;o00001_ooool4o`0000[ooooo0ol000000ooooooo
0000o`00000Bo`000003ooooool0003o000000?ooooo0_l00008ooooo`Co00001Oooool[o`000004
ooooool0003o0000o`0000[ooooo0_l0000<ooooo`;o00004oooool2o`0000Oooooo0_l00017oooo
o`007?ooool00ol0003oooooooooo`0`ooooo`;o00001?ooool2o`0000Oooooo0_l00006ooooo`;o
00001oooool4o`0001Kooooo0_l00002oooooa?o00000_ooool2o`0000oooooo0_l00005ooooobko
00003?ooool2o`0000Cooooo0_l00004ooooo`?o0000IOooool001cooooo00?o0000ooooooooool0
<?ooool2o`0000gooooo0_l00006ooooo`;o00001oooool4o`0000[ooooo0_l0000?oooooa7o0000
0oooool2o`0000Gooooo1?l00008ooooo`;o00000oooool3o`000003ooooool0003o000002?o0000
00?oooooo`000?l000000_l0000<ooooo`;o00001?ooool2o`0000Cooooo0_l0000Iooooo`;o0000
Boooool001cooooo00?o0000ooooooooool0=Oooool3o`0000?ooooo0_l0000:ooooo`;o00005Ooo
ool2o`00013ooooo3ol00009ooooo`Ko00002?ooool2o`0000?ooooo:?l00002ooooo`?o00000_oo
ool2o`0002kooooo1?l000000ooooooo0000o`000018ooooo`007?ooool00ol0003oooooooooo`0e
ooooo`?o00000oooool2o`0000kooooo0_l00005ooooo`;o00000oooool2o`0000Wooooo0_l0000>
ooooo`go00002?ooool3o`0000_ooooo;Ol000000ooooooo0000o`000003o`0000;ooooo0_l0000^
ooooo`;o00000oooool2o`0004Sooooo000Looooo`03o`000?oooooooooo04_ooooo0_l00005oooo
o`;o00000oooool4o`0000Oooooo0_l00008ooooo`_o000000?oooooo`000?l000002_l00003oooo
o`;o000000?oooooo`000?l000002Oooool9o`0000;ooooo:Ol00006ooooo`;o0000:Oooool2o`00
0003ooooool0003o000000kooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`0cooooo`;o
00001Oooool2o`0000_ooooo0_l00002ooooo`;o00000oooool2o`0000Oooooo0_l0000>ooooo`ko
00001?ooool9o`000003ooooool0003o000000?ooooo0_l00003ooooo`Co00001ooooolCo`000003
ooooool0003o000000Wo000000?oooooo`000?l000002?l00003ooooo`;o00001_ooool2o`0002co
oooo1?l0000<ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0<oooool2o`0000Gooooo
0_l0000;ooooo`;o00000_ooool2o`0000?ooooo1?l00008ooooo`;o00002oooool3o`0000oooooo
0ol00007ooooo`;o00002?ooool4o`0000Sooooo:?l00003ooooo`?o00000oooool2o`0000Sooooo
0_l0000Iooooo`;o00003?ooool2o`0004Sooooo000Looooo`03o`000?oooooooooo03_ooooo0_l0
000=ooooo`;o00001_ooool2o`0000Sooooo0_l0000Nooooo`;o00003?ooool2o`0000oooooo1Ol0
0002ooooob7o00000_ooool4o`0000?ooooo0_l00008ooooo`;o000000?oooooo`000?l000001_oo
ool2o`0000kooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`0kooooo`;o00003Oooool2
o`0000_ooooo0_l00003ooooo`;o00001_ooool2o`0000Oooooo0_l0000Kooooo`;o00003oooool5
o`000003ooooool0003o0000023o00000_ooool2o`0000Gooooo0_l0000;ooooo`?o00001Oooool2
o`0001Wooooo0_l0000;ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0<oooool2o`00
00?ooooo0_l0000Hooooo`;o00000oooool2o`0000?ooooo0_l00005ooooo`?o00001oooool2o`00
00;ooooo0_l00005ooooo`Co00007oooool3o`0000?ooooo8_l00002ooooo`;o00001Oooool2o`00
00cooooo0_l0000Fooooo`;o00002?ooool2o`0000_ooooo0_l0000nooooo`007?ooool2o`0003Co
oooo0_l00003ooooo`?o000000Coooooo`000?l0003ooooo0_l0000Aooooo`;o00000oooool2o`00
00Cooooo0ol00003ooooo`;o00001Oooool2o`0000Gooooo0_l000000ooooooo0000o`000006o`00
00;ooooo0_l0000Cooooo`;o00001oooool3o`000003ooooool0003o0000027o00000_ooool2o`00
0003ooooool0003o0000017ooooo0_l0000Eooooo`;o0000EOooool001cooooo00?o0000oooooooo
ool0=?ooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0001Kooooo0_l00004oooo
o`?o00002_ooool2o`0000Sooooo1?l000001?oooooo0000o`000?l00002ooooo`;o00001Oooool2
o`0000cooooo0_l00007ooooo`?o000000?oooooo`000?l000004_l000000ooooooo0000o`00000<
o`000003ooooool0003o000000;ooooo0_l0000Aooooo`;o00000oooool2o`00013ooooo0_l00002
ooooo`?o00000oooool2o`0004_ooooo000Looooo`03o`000?oooooooooo03Cooooo0_l00004oooo
o`;o00001?ooool2o`0001_ooooo0_l00004ooooo`;o00001_ooool2o`0000Sooooo0ol000000ooo
oooo0000o`000003o`0000Oooooo0_l00003ooooo`;o00001Oooool2o`0000Gooooo0_l00002oooo
o`?o00000_oooolQo`0000;ooooo0ol0000@ooooo`;o00001oooool2o`0000kooooo0_l00004oooo
o`?o00000oooool2o`0004_ooooo000Looooo`03o`000?oooooooooo03Gooooo0_l00003ooooo`;o
00001?ooool2o`0000Wooooo0_l0000Booooo`;o00000_ooool2o`0000Kooooo0_l00008ooooo`;o
00001Oooool2o`0000;ooooo0_l00007ooooo`?o00001Oooool2o`000005ooooool0003o0000o`00
0?ooool00_l00004ooooo`;o00001?ooool4o`000003ooooool0003o000000oo000000?oooooo`00
0?l000000_l000000ooooooo0000o`000002o`000003ooooool0003o000000;ooooo0_l0000<oooo
o`Co00000oooool2o`00013ooooo0ol00003ooooo`;o00003Oooool2o`0004;ooooo000Looooo`03
o`000?oooooooooo03Gooooo0_l00009ooooo`;o00002Oooool3o`00017ooooo0_l0000=ooooo`?o
00003_ooool3o`0000Oooooo0_l00007ooooo`Go00001Oooool4o`0000Kooooo6Ol00002ooooo`?o
000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l00009ooooo`;o00000oooool2o`00013o
oooo0ol00007ooooo`;o00001?ooool2o`0000?ooooo0_l00012ooooo`007?ooool00ol0003ooooo
ooooo`10ooooo`;o00002_ooool2o`0000Oooooo0_l00003ooooo`;o00000_ooool2o`0000kooooo
0ol0000;ooooo`;o000000?oooooo`000?l000002Oooool2o`000004ooooool0003o0000ooooo`Co
00002?ooool4o`000003ooooool0003o000000?ooooo5_l000000ooooooo0000o`000005o`000003
ooooool0003o000000?o00001?ooool2o`0001[ooooo0_l00002ooooo`Co00002?ooool2o`0000Co
oooo0_l000000ooooooo0000o`000014ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o0000
3oooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000gooooo0_l00008ooooo`;o0000
3?ooool2o`000004ooooool0003o0000ooooo`;o00001Oooool2o`0000?ooooo0ol00002ooooo`;o
00000ooooolFo`0000;ooooo3?l0000Oooooo`?o00000_ooool4o`0000;ooooo0_l00009ooooo`;o
00000_ooool2o`0004Cooooo000Looooo`03o`000?oooooooooo04Cooooo0ol000001?oooooo0000
o`000?l0000?ooooo`;o00001oooool2o`0000Cooooo0_l00003ooooo`Ko00004?ooool2o`0000Ko
oooo1?l00007ooooo`;o00001?ooool2o`000003ooooool0003o000000Cooooo1Ol000000ooooooo
0000o`000009o`0000;ooooo1ol00003ooooo`Oo00007oooool2o`000003ooooool0003o000000;o
oooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00001_ooool2o`0004Sooooo000Looooo`03
o`000?oooooooooo03Oooooo0_l00002ooooo`;o00001_ooool4o`000004ooooool0003o0000o`00
00oooooo0_l00004ooooo`;o00001oooool3o`0000;ooooo1_l0000?ooooo`?o00001_ooool6o`00
00kooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`00000@o`00
00Cooooo1Ol000000ooooooo0000o`000005ooooo`;o00006oooool2o`000004ooooool0003o0000
ooooo`?o00000_ooool2o`0000Cooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`0goooo
o`;o00000_ooool2o`0000Kooooo1_l0000<ooooo`;o00001Oooool6o`0000Sooooo0_l00006oooo
o`;o00003oooool2o`0000_ooooo0_l0000?ooooo`[o000000?oooooo`000?l000002?l000000ooo
oooo0000o`000005o`0000Cooooo0_l00002ooooo`;o00001?ooool2o`000003ooooool0003o0000
01_ooooo0_l000001?oooooo0000o`000?ooool3o`0000Sooooo0_l0001:ooooo`007?ooool00ol0
003oooooooooo`16ooooo`?o00002_ooool4o`0000Gooooo1_l00007ooooo`;o00000oooool2o`00
013ooooo0_l0000Dooooo`;o00002OoooolIo`0000;ooooo0_l000001?oooooo0000o`000?ooool2
o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l000006oooool2o`000003ooooool0003o
000005Sooooo000Looooo`03o`000?oooooooooo04Kooooo0_l00003ooooo`;o00001_ooool2o`00
00Kooooo1Ol00009ooooo`;o00000oooool2o`0000cooooo0_l00002ooooo`;o00000oooool3o`00
00kooooo0_l00008ooooo`;o000000?oooooo`000?l000000ol000000ooooooo0000o`000005o`00
0003ooooool0003o000000Oo000000?oooooo`000?l000001?l000000ooooooo0000o`000008oooo
o`;o00003Oooool2o`0000_ooooo0_l00005ooooo`;o00000_ooool2o`0005Cooooo000Looooo`03
o`000?oooooooooo04Cooooo1?l00003ooooo`;o00001Oooool4o`0000Gooooo1?l00008ooooo`;o
00004oooool2o`000003ooooool0003o000000Cooooo0ol00005ooooo`;o00002oooool2o`0000Co
oooo0_l00002ooooo`Co000000?oooooo`000?l000003Ol00002ooooo`Ko00000_ooool2o`0000Go
oooo0_l000000ooooooo0000o`000002ooooo`;o00002Oooool2o`0000Wooooo1?l00009ooooo`;o
00001?ooool2o`0000;ooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`14ooooo`Go0000
2?ooool5o`0000Kooooo0_l00009ooooo`;o00004?ooool2o`000003ooooool0003o000000?o0000
1?ooool4o`0000;ooooo1?l00002ooooo`;o00001oooool2o`0000Cooooo0_l00002ooooo`Co0000
0_ooool>o`000004ooooool0003o0000o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l0
00001?l000000ooooooo0000o`000002ooooo`?o00000_ooool3o`0000Kooooo0_l00006ooooo`Co
00001_ooool2o`0000Oooooo0_l00002ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0
Aoooool2o`0000Kooooo1Ol00008ooooo`;o000000?oooooo`000?l000001_ooool2o`00013ooooo
0ol00002ooooo`?o00001?ooool5o`000003ooooool0003o000000;ooooo1?l00008ooooo`;o0000
1oooool4o`0000?ooooo0ol00003ooooo`Oo000000Coooooo`000?l0003ooooo0_l00004ooooo`;o
000000?oooooo`000?l000000_l00003ooooo`?o00000_ooool2o`0000;ooooo0ol00005ooooo`Go
00001?ooool2o`0000Sooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`1?ooooo`;o0000
1_ooool2o`0000Kooooo0_l00006ooooo`;o00004Oooool2o`0000_ooooo1?l00004ooooo`;o0000
0_ooool2o`0000Kooooo0_l00007ooooo`;o00000_ooool2o`000005ooooool0003o0000o`000?oo
ool01?l00004ooooo`Oo00003Oooool4o`0000kooooo0_l000000ooooooo0000o`000003ooooo`?o
0000HOooool001cooooo0_l00017ooooo`;o00001oooool2o`0000Kooooo0_l0000Aooooo`;o0000
3Oooool2o`0000Gooooo0_l000000ooooooo0000o`000004ooooo`Co00001_ooool2o`0001?ooooo
0_l00004ooooo`Co00001Oooool2o`0000;ooooo0_l00005ooooo`;o00001?ooool2o`000003oooo
ool0003o000001Sooooo0ol0001Qooooo`007?ooool00ol0003oooooooooo`16ooooo`;o00001ooo
ool2o`00013ooooo0_l00007ooooo`Co000000?oooooo`000?l000002?ooool4o`0000?ooooo0_l0
00000ooooooo0000o`000005ooooo`?o00002?ooool2o`00017ooooo1?l00002ooooo`Go00001ooo
ool2o`0000Kooooo0_l00004ooooo`;o0000:oooool2o`0005;ooooo000Looooo`03o`000?oooooo
oooo067ooooo0_l000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l000002_ooool2
o`0000;ooooo0_l00009ooooo`;o00002Oooool2o`0000_ooooo0_l00006ooooo`?o00000_ooool4
o`0000Kooooo0ol0000Hooooo`?o00001Oooool5o`0001Cooooo0_l0001Booooo`007?ooool00ol0
003oooooooooo`1Qooooo`;o000000?oooooo`000?l000002oooool2o`0000Wooooo0_l000000ooo
oooo0000o`00000Kooooo`?o00000oooool2o`0000Oooooo0_l00002ooooo`Go00001?ooool4o`00
00gooooo0_l00005ooooo`;o000000?oooooo`000?l000000_l00005ooooo`Go00002oooool2o`00
05_ooooo000Looooo`03o`000?oooooooooo057ooooo0_l00006ooooo`;o00001_ooool2o`0000ko
oooo1?l00007ooooo`;o000000?oooooo`000?l000002oooool2o`0000_ooooo0_l000001?oooooo
0000o`000?l0000;ooooo`;o00000oooool2o`000004ooooool0003o0000o`0000?ooooo1?l0000=
ooooo`;o00001?ooool3o`000003ooooool0003o000000Gooooo0_l0000@ooooo`;o0000Foooool0
01cooooo00?o0000ooooooooool0C_ooool5o`0000Kooooo0_l0000Gooooo`Ko00003_ooool2o`00
00;ooooo1_l00009ooooo`;o00001Oooool2o`0000Sooooo0_l00003ooooo`;o00000_ooool2o`00
01[ooooo0_l00008ooooo`?o00000_ooool2o`0000Oooooo0_l0000=ooooo`;o0000DOooool001co
oooo00?o0000ooooooooool0C_ooool4o`0001Cooooo0_l0000<ooooo`Co00003_ooool:o`000003
ooooool0003o000000?ooooo0_l00004ooooo`;o000000?oooooo`000?l000000ol000000ooooooo
0000o`000002ooooo`;o00002Oooool2o`000003ooooool0003o000000;ooooo0ol0000Aooooo`;o
00000_ooool2o`0000Cooooo0_l00002ooooo`?o00001oooool2o`0000gooooo0_l0001Aooooo`00
7?ooool00ol0003oooooooooo`19ooooo`;o00001Oooool5o`0000?ooooo0_l000001?oooooo0000
o`000?l00008ooooo`;o00003Oooool4o`0000oooooo0_l00003ooooo`;o00000_ooool2o`0000?o
oooo0_l00004ooooo`;o000000?oooooo`000?l000001_l00002ooooo`;o00001Oooool3o`000004
ooooool0003o0000ooooo`;o00000_ooool3o`0000Oooooo0_l000000ooooooo0000o`000002oooo
o`;o000000?oooooo`000?l000000_ooool2o`0000Sooooo0ol0000Oooooo`;o0000B?ooool001co
oooo00?o0000ooooooooool0BOooool2o`0000Kooooo1?l00003ooooo`;o000000?oooooo`000?l0
00000ol00009ooooo`;o00002?ooool2o`0000;ooooo0_l0000>ooooo`;o00001?ooool2o`0000_o
oooo0_l00007ooooo`;o00002oooool3o`0001;ooooo0_l000000ooooooo0000o`000004o`0000?o
oooo0_l0000Eooooo`;o00005Oooool2o`0004Sooooo000Looooo`03o`000?oooooooooo05kooooo
0_l00008ooooo`?o00002?ooool2o`00017ooooo0ol00004ooooo`?o000000?oooooo`000?l00000
0ol00004ooooo`;o00000oooool2o`0001kooooo0_l00009ooooo`;o00001Oooool2o`000003oooo
ool0003o000000;ooooo0_l0000>ooooo`;o0000Goooool001cooooo00?o0000ooooooooool0H?oo
ool3o`0000Gooooo0_l0000Looooo`;o00000oooool5o`000003ooooool0003o000000Co00000ooo
ool2o`0000?ooooo1?l0000Cooooo`;o00001oooool3o`0000Gooooo0_l00003ooooo`;o00000_oo
ool2o`0000;ooooo0_l00002ooooo`;o00003Oooool2o`00063ooooo000Looooo`03o`000?oooooo
oooo063ooooo0ol00005ooooo`;o00003Oooool3o`0000Sooooo0_l00002ooooo`;o00000oooool2
o`0000Cooooo0_l000000ooooooo0000o`000003o`0000Sooooo0_l000000ooooooo0000o`000007
ooooo`;o00001oooool2o`0000Sooooo0_l00005ooooo`;o00000oooool2o`0000;ooooo0_l00003
ooooo`;o00001Oooool2o`0000Wooooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`1Qoooo
o`;o00001Oooool2o`0000gooooo0ol00008ooooo`;o00002_ooool2o`000004ooooool0003o0000
ooooo`;o000000?oooooo`000?l000002_ooool3o`0000Oooooo0_l0000=ooooo`?o00004oooool5
o`0000Gooooo0_l0001[ooooo`007?ooool00ol0003oooooooooo`1kooooo`;o00004Oooool2o`00
00Wooooo0_l00002ooooo`;o00001?ooool3o`0000oooooo1Ol00002ooooo`?o00001?ooool2o`00
00Oooooo0_l00004ooooo`Co00003Oooool2o`0001_ooooo0_l00017ooooo`007?ooool00ol0003o
ooooooooo`1?ooooo`;o00003?ooool2o`0001cooooo0_l0000:ooooo`;o00000oooool2o`0000;o
oooo0_l00007ooooo`;o00000_ooool2o`0000Gooooo0_l0000?ooooo`Go00001_ooool2o`000003
ooooool0003o000000;ooooo0_l00003ooooo`;o00001?ooool2o`0000Oooooo0_l00006ooooo`;o
00000oooool2o`0001Kooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`1?ooooo`;o0000
3?ooool2o`0002Sooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l0000;ooooo`;o0000
1Oooool2o`0000Sooooo0_l0000@ooooo`;o00001?ooool3o`0000Kooooo0_l0000:ooooo`;o0000
2_ooool3o`0005oooooo000Looooo`;o0000G?ooool2o`0000Wooooo0_l00009ooooo`;o00000_oo
ool2o`0001;ooooo1Ol0000>ooooo`;o00004?ooool2o`0001Kooooo0_l00007ooooo`;o00001Ooo
ool2o`0000[ooooo0_l00003ooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0EOooool2
o`0000Cooooo0_l00009ooooo`;o00002Oooool2o`0000;ooooo0_l00003ooooo`;o00003Oooool5
o`0000Cooooo1?l00006ooooo`;o00001_ooool2o`0000Cooooo0_l0000Xooooo`Co00002_ooool2
o`000004ooooool0003o0000o`0001?ooooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`1E
ooooo`;o000000?oooooo`000?l000003Oooool2o`0000cooooo0_l00002ooooo`?o00002_ooool2
o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l00008ooooo`?o000000?ooooo
o`000?l000000_l00004ooooo`Co00001Oooool2o`0001oooooo0_l0000=ooooo`Ko00004_ooool2
o`0004cooooo000Looooo`03o`000?oooooooooo05Sooooo1?l0000;ooooo`;o00002oooool3o`00
00;ooooo0_l0000:ooooo`?o00000oooool7o`0000cooooo1_l00008ooooo`;o00001Oooool2o`00
00;ooooo0_l0000Nooooo`;o00002_ooool2o`0000;ooooo0_l0001Pooooo`007?ooool00ol0003o
ooooooooo`1Jooooo`;o00001_ooool2o`00013ooooo0_l00004ooooo`;o00002Oooool2o`0000Co
oooo1?l000000ooooooo0000o`000004ooooo`;o00002?ooool7o`0000;ooooo2_l00004ooooo`;o
00001?ooool3o`0000Sooooo1Ol00009ooooo`?o00001oooool2o`0006Oooooo000Looooo`03o`00
0?oooooooooo06;ooooo0_l0000Fooooo`;o00000oooool2o`0000;ooooo0_l00007ooooo`;o0000
0_ooool2o`0000Cooooo0_l000000ooooooo0000o`000006ooooo`Ko00000_ooool=o`0000Oooooo
0ol00008ooooo`Go00002Oooool2o`0000Sooooo0_l0001Wooooo`007?ooool00ol0003ooooooooo
o`1Gooooo`;o00000oooool2o`0000Gooooo0_l0000=ooooo`;o00002oooool6o`0000?ooooo0_l0
0002ooooo`;o00002oooool2o`0000Sooooo0_l000000ooooooo0000o`000003o`0000;ooooo2ol0
0006ooooo`;o00002_ooool2o`0007gooooo000Looooo`03o`000?oooooooooo05Oooooo1?l00000
1?oooooo0000o`000?l00004ooooo`;o00003Oooool2o`0000Wooooo0_l00002ooooo`;o00001Ooo
ool2o`0000;ooooo0_l0000Dooooo`?o000000?oooooo`000?l000000ol00003ooooo`[o00002_oo
ool2o`0000;ooooo0_l00002ooooo`Go0000N_ooool001cooooo00?o0000ooooooooool0FOooool2
o`0000;ooooo0_l0000Nooooo`;o00008oooool2o`0000Cooooo0_l00003ooooo`;o000000Cooooo
o`000?l0003ooooo0ol00006ooooo`;o00000oooool4o`000003ooooool0003o000000;o00000_oo
ool3o`0007[ooooo000Looooo`03o`000?oooooooooo06Cooooo0ol0000?ooooo`;o00001?ooool2
o`0001Cooooo1?l00002ooooo`;o00000oooool2o`0000?ooooo0ol00008ooooo`;o000000?ooooo
o`000?l000002?ooool6o`000003ooooool0003o000000;o00000oooool2o`0000;ooooo0ol0000;
ooooo`;o0000KOooool001cooooo00?o0000ooooooooool0Goooool2o`0000?ooooo0ol00004oooo
o`;o00002Oooool2o`0000Cooooo0_l00008ooooo`Go00001oooool4o`0000;ooooo0_l00003oooo
o`;o00001?ooool2o`0000Sooooo0_l0000;ooooo`;o00000_ooool2o`0000Gooooo0ol00004oooo
o`?o00001oooool2o`0000;ooooo0_l000000ooooooo0000o`00001Zooooo`007?ooool00ol0003o
ooooooooo`1Oooooo`;o00002_ooool2o`000003ooooool0003o000000Oooooo0_l00007ooooo`;o
00001?ooool5o`0000_ooooo0_l00005ooooo`;o00006?ooool2o`000003ooooool0003o000000Co
oooo0_l00003ooooo`?o00003_ooool2o`0000Gooooo0_l0001Zooooo`007?ooool00ol0003ooooo
ooooo`1Oooooo`;o00003Oooool2o`0000Oooooo0_l00007ooooo`;o00005?ooool2o`0000?ooooo
0_l00003ooooo`;o00000oooool2o`00013ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo
0_l00009ooooo`;o00001Oooool2o`00077ooooo000Looooo`03o`000?oooooooooo05oooooo0_l0
000Booooo`;o00002_ooool2o`0001Kooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0
003o000000;o00005?ooool2o`0000Kooooo0ol00009ooooo`;o0000N?ooool00006ooooooo^k^ko
<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03
o`000?oooooooooo067ooooo0_l0000@ooooo`;o00001_ooool2o`0000;ooooo0_l0000Fooooo`;o
00002_ooool4o`000003ooooool0003o000000cooooo0ol0000:ooooo`;o00009_ooool2o`0005co
oooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B401_ooool00ol0003oooooooooo`1Qooooo`;o00001_ooool2o`00013ooooo0_l00002
ooooo`?o00005_ooool2o`0000kooooo0_l0000<ooooo`?o00001oooool2o`0002Wooooo0_l0001L
ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`1Yooooo`;o00001Oooool2o`0000kooooo0ol0000E
ooooo`;o00009_ooool2o`0008Oooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000Ioooool2o`0000Oooooo0_l0000:
ooooo`;o00000oooool3o`0000Wooooo0ol0002iooooo`0000?oooooo`000?ooool00_ooool00ol0
003oooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`1W
ooooo`;o00001_ooool2o`0000Sooooo0_l000001?oooooo0000o`000?l00003ooooo`;o00002Ooo
ool3o`0001Kooooo0_l0000Jooooo`;o0000QOooool00003ooooool@413ooooo00;ooooo00?o410@
ooooooooool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0KOoo
ool4o`0000Sooooo0_l00002ooooo`;o00005Oooool2o`00013ooooo0_l0000;ooooo`;o00000_oo
ool2o`0000Wooooo0_l0000Hooooo`;o0000Joooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0KOooool2o`0000co
oooo0_l0000Gooooo`;o00001oooool2o`0000Oooooo0_l0000;ooooo`;o00000_ooool3o`0000?o
oooo0_l0000Mooooo`;o0000Joooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnY
ZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0MOooool3o`0000?ooooo0_l00000
0ooooooo0000o`000002ooooo`;o00002Oooool2o`0000?ooooo0_l00009ooooo`;o000000?ooooo
o`000?l000005_ooool2o`0000?ooooo0_l0002:ooooo`007?ooool00ol0003oooooooooo`1]oooo
o`;o00001_ooool3o`0000Kooooo0_l00002ooooo`;o00002Oooool2o`0000?ooooo0_l0000<oooo
o`;o0000>?ooool2o`0006gooooo000Looooo`03o`000?oooooooooo06gooooo0_l0000?ooooo`;o
00006Oooool4o`0000Cooooo0_l0000Fooooo`;o00005oooool2o`0000Kooooo0_l0001]ooooo`00
7?ooool00ol0003oooooooooo`2Iooooo`Co00001?ooool2o`000003ooooool0003o000001?ooooo
0_l00002ooooo`;o00004oooool2o`0007Gooooo000Looooo`03o`000?oooooooooo07Gooooo1?l0
000Vooooo`;o00000oooool4o`0001Gooooo0_l0000Cooooo`;o0000MOooool001cooooo00?o0000
ooooooooool0MOooool6o`0000?ooooo0_l00006ooooo`;o00001_ooool2o`0000Oooooo0_l00006
ooooo`;o00000_ooool2o`000003ooooool0003o000000;o00003?ooool3o`0001Wooooo0_l0001e
ooooo`007?ooool00ol0003oooooooooo`1hooooo`?o00000oooool2o`0000Kooooo0_l00006oooo
o`;o00001oooool2o`0000[ooooo0_l00003ooooo`;o00003?ooool5o`0008kooooo000Looooo`03
o`000?oooooooooo09?ooooo0_l0000Tooooo`;o0000S_ooool001cooooo00?o0000ooooooooool0
MOooool2o`0001cooooo0_l000000ooooooo0000o`000002ooooo`;o00001oooool2o`0001kooooo
0_l00024ooooo`007?ooool00ol0003oooooooooo`1eooooo`;o00007oooool2o`0000;ooooo0_l0
0007ooooo`;o000000?oooooo`000?l000005?ooool2o`0000Gooooo0_l00024ooooo`007?ooool0
0ol0003oooooooooo`2Vooooo`Co00004_ooool2o`0008_ooooo000Looooo`03o`000?oooooooooo
0:Oooooo0ol0002Oooooo`007?ooool2o`000:Sooooo0_l0002Pooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0POooool2o`0000Cooooo0_l00030ooooo`007?ooool00ol0003oooooooooo`21oooo
o`;o00001?ooool2o`000<3ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0Q_ooool2o`000<7ooooo000Looooo`03o`000?oooooooooo08Kooooo0_l0
0031ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooo
oom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Booooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooood[ooooo
000Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool0
0ol0003oooooooooo`05ooooo`?o0000oooooom:ooooo`005?ooool00ol0003oooooooooo`3ooooo
oe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0
oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Booooo`03oeEEEOmVIVKo
00000?ooooooE?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Gooooo00Co
410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0Gooooo`03o`000?o^k^kooooo00Cooooo
00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0T?ooool00:Ko
oooo00Go0000ooooooooooooooooo`000009ooooo`Ko00002oooool00omEEEGoZJVYooooo`07oooo
o`09ogMgMolb<S;ooooooooooomEEEGoMgMgoooooonHV9So8B4Q093ooooo002Vooooo`05o`000?oo
ooooooooooooool000006_ooool00onYZJWoEEEEooooo`08ooooo`04o`000?ooooooooooo`0000?o
oooo00?o0000ooooooooool0S_ooool00:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko
00003?ooool00olQ8B7oooooooooo`06ooooo`09ogMgMolb<S;oooooooooool0003oV9RHoooooonH
V9So8B4Q093ooooo002Vooooo`05o`000?n7QhOoooooojVYZOl000006oooool00omEEEGoc<c<oooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003oEEEEo`000?l@413oc<c<093o
oooo002Uooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool06Oooool00onYZJWoMgMg
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?oEEEEohN7Qoooool0T_ooool00<?ooooo00Go
410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Cooooo00?ogMgMoa0@4?nHV9P0
T_ooool00<?ooooo1Ol00004ooooo`Co00001?ooool01?o<c<coA4A4o`000?l@412@ooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(762) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.66606 .50711 Mdot
.67568 .49768 Mdot
.38381 .41737 Mdot
.52385 .59398 Mdot
.42566 .54211 Mdot
.32936 .40038 Mdot
.51746 .35878 Mdot
.53501 .39524 Mdot
.34088 .41963 Mdot
.64661 .57104 Mdot
.49831 .34732 Mdot
.55717 .71067 Mdot
.51515 .36964 Mdot
.52607 .65046 Mdot
.34768 .20819 Mdot
.59105 .65368 Mdot
.71292 .46393 Mdot
.34752 .60427 Mdot
.58958 .58211 Mdot
.36149 .43662 Mdot
.69324 .52489 Mdot
.53038 .652 Mdot
.68619 .50091 Mdot
.52744 .64974 Mdot
.52459 .60759 Mdot
.67154 .46678 Mdot
.69484 .5096 Mdot
.55557 .60659 Mdot
.51416 .6315 Mdot
.53359 .34555 Mdot
.3881 .52434 Mdot
.21479 .32971 Mdot
.58459 .6762 Mdot
.63077 .7627 Mdot
.54155 .37814 Mdot
.24532 .65349 Mdot
.36327 .41982 Mdot
.49165 .38696 Mdot
.54071 .38577 Mdot
.52116 .39568 Mdot
.50451 .38951 Mdot
.66756 .47137 Mdot
.48882 .33979 Mdot
.56975 .38106 Mdot
.5314 .58763 Mdot
.61794 .32698 Mdot
.28255 .62871 Mdot
.55649 .61383 Mdot
.65022 .48564 Mdot
.34484 .43991 Mdot
.71629 .73654 Mdot
.49771 .40268 Mdot
.49356 .23575 Mdot
.3037 .16876 Mdot
.52474 .38291 Mdot
.53841 .59085 Mdot
.35404 .40128 Mdot
.5558 .65274 Mdot
.54309 .64268 Mdot
.72633 .70484 Mdot
.53304 .61911 Mdot
.36794 .58017 Mdot
.7314 .46061 Mdot
.37644 .37125 Mdot
.33474 .41091 Mdot
.5422 .36629 Mdot
.69407 .44306 Mdot
.50625 .36853 Mdot
.47303 .61034 Mdot
.34198 .43284 Mdot
.5584 .61349 Mdot
.49449 .35258 Mdot
.65799 .44254 Mdot
.52919 .68088 Mdot
.65195 .34527 Mdot
.41837 .18563 Mdot
.32531 .59095 Mdot
.71226 .69572 Mdot
.79094 .47334 Mdot
.42735 .21889 Mdot
.52133 .64185 Mdot
.79344 .31878 Mdot
.36479 .20024 Mdot
.69003 .49597 Mdot
.44104 .65574 Mdot
.40848 .38132 Mdot
.52286 .67183 Mdot
.43215 .49683 Mdot
.48854 .67298 Mdot
.72576 .38603 Mdot
.34692 .42137 Mdot
.65842 .47152 Mdot
.51848 .59436 Mdot
.56059 .6801 Mdot
.7407 .58201 Mdot
.50207 .67754 Mdot
.56324 .60317 Mdot
.7068 .50853 Mdot
.52145 .34379 Mdot
.49266 .69207 Mdot
.56956 .34457 Mdot
.50267 .23371 Mdot
.49496 .62735 Mdot
.32802 .4178 Mdot
.72113 .4686 Mdot
.49289 .61858 Mdot
.5329 .37907 Mdot
.53404 .62859 Mdot
.55291 .32823 Mdot
.66344 .49944 Mdot
.55842 .68036 Mdot
.35348 .6034 Mdot
.70612 .3505 Mdot
.66526 .45339 Mdot
.70171 .25813 Mdot
.54179 .61855 Mdot
.53691 .65299 Mdot
.67604 .49542 Mdot
.35232 .38284 Mdot
.41843 .49079 Mdot
.68219 .43753 Mdot
.53264 .39126 Mdot
.69225 .50564 Mdot
.49187 .59668 Mdot
.32303 .39025 Mdot
.50463 .2278 Mdot
.52039 .24795 Mdot
.45052 .778 Mdot
.51508 .66715 Mdot
.53759 .29456 Mdot
.33205 .39084 Mdot
.66192 .48144 Mdot
.50677 .37178 Mdot
.57395 .6024 Mdot
.70475 .46363 Mdot
.49468 .37605 Mdot
.3567 .59983 Mdot
.24051 .51896 Mdot
.65183 .45847 Mdot
.57113 .48507 Mdot
.54094 .33363 Mdot
.5204 .39512 Mdot
.64246 .78173 Mdot
.68133 .49483 Mdot
.34462 .57166 Mdot
.49607 .3722 Mdot
.40737 .67832 Mdot
.5742 .60454 Mdot
.51984 .77653 Mdot
.81795 .39989 Mdot
.69721 .75696 Mdot
.5967 .23748 Mdot
.37154 .5584 Mdot
.4974 .39655 Mdot
.50909 .60943 Mdot
.685 .48514 Mdot
.67612 .48203 Mdot
.57652 .66182 Mdot
.53259 .60876 Mdot
.57681 .63957 Mdot
.57405 .66113 Mdot
.27629 .6106 Mdot
.57752 .64487 Mdot
.29752 .40811 Mdot
.6843 .44662 Mdot
.51947 .61615 Mdot
.37424 .3896 Mdot
.59126 .61167 Mdot
.4916 .382 Mdot
.54616 .64615 Mdot
.53585 .60202 Mdot
.49852 .66569 Mdot
.5028 .39256 Mdot
.18892 .40569 Mdot
.7992 .38753 Mdot
.18187 .55546 Mdot
.63677 .24991 Mdot
.34833 .39285 Mdot
.52672 .66719 Mdot
.35468 .5864 Mdot
.51202 .54801 Mdot
.54199 .63835 Mdot
.77193 .68162 Mdot
.54656 .60388 Mdot
.61882 .73674 Mdot
.59685 .57558 Mdot
.16875 .54204 Mdot
.45724 .42436 Mdot
.5177 .62923 Mdot
.71762 .55662 Mdot
.54645 .79065 Mdot
.47118 .55354 Mdot
.51387 .38769 Mdot
.36707 .38194 Mdot
.36084 .40707 Mdot
.49732 .3314 Mdot
.4763 .66496 Mdot
.63524 .57831 Mdot
.47904 .68084 Mdot
.50957 .22738 Mdot
.67831 .43146 Mdot
.346 .55091 Mdot
.64582 .47146 Mdot
.72325 .23821 Mdot
.67221 .39754 Mdot
.55664 .3592 Mdot
.36829 .60744 Mdot
.3829 .39623 Mdot
.51238 .22448 Mdot
.3492 .58299 Mdot
.56393 .62161 Mdot
.65184 .48185 Mdot
.56486 .79475 Mdot
.58929 .57405 Mdot
.43589 .82943 Mdot
.70675 .48226 Mdot
.45568 .46179 Mdot
.5086 .38286 Mdot
.34145 .44435 Mdot
.51261 .65574 Mdot
.56885 .65688 Mdot
.72847 .47772 Mdot
.55327 .61607 Mdot
.75952 .44712 Mdot
.53949 .59969 Mdot
.36411 .3588 Mdot
.33848 .53785 Mdot
.4786 .37163 Mdot
.465 .78076 Mdot
.63879 .46118 Mdot
.28195 .39304 Mdot
.36279 .43192 Mdot
.6418 .55061 Mdot
.49998 .34379 Mdot
.36053 .6017 Mdot
.37408 .41442 Mdot
.3795 .55523 Mdot
.49427 .639 Mdot
.36135 .42401 Mdot
.34553 .55752 Mdot
.21793 .49965 Mdot
.54674 .58842 Mdot
.36801 .64129 Mdot
.5119 .3558 Mdot
.67732 .51186 Mdot
.53177 .61903 Mdot
.52122 .24926 Mdot
.53052 .57535 Mdot
.53147 .25612 Mdot
.49948 .2462 Mdot
.49472 .23396 Mdot
.39774 .21491 Mdot
.37837 .58124 Mdot
.62664 .28391 Mdot
.5884 .44917 Mdot
.69739 .44377 Mdot
.52098 .59145 Mdot
.16758 .46271 Mdot
.49657 .37406 Mdot
.56313 .62369 Mdot
.39429 .36892 Mdot
.49683 .36962 Mdot
.55198 .65992 Mdot
.51118 .39323 Mdot
.68109 .48537 Mdot
.34092 .47505 Mdot
.71508 .48458 Mdot
.54782 .59072 Mdot
.53125 .37025 Mdot
.3716 .40109 Mdot
.67421 .46673 Mdot
.53744 .6297 Mdot
.52415 .66101 Mdot
.5141 .23281 Mdot
.51562 .62147 Mdot
.17425 .46559 Mdot
.55723 .60875 Mdot
.37858 .38042 Mdot
.4993 .67766 Mdot
.70039 .76821 Mdot
.24631 .51203 Mdot
.67739 .44216 Mdot
.49736 .2404 Mdot
.34687 .41708 Mdot
.33416 .48151 Mdot
.5216 .51389 Mdot
.52672 .63647 Mdot
.50713 .24621 Mdot
.42874 .46501 Mdot
.54223 .36226 Mdot
.4815 .65212 Mdot
.67781 .38667 Mdot
.37375 .42354 Mdot
.51218 .22669 Mdot
.59901 .66367 Mdot
.72207 .47259 Mdot
.52651 .59465 Mdot
.36774 .41913 Mdot
.68979 .50733 Mdot
.55815 .58481 Mdot
.28168 .65191 Mdot
.5097 .25377 Mdot
.51044 .35706 Mdot
.61836 .57635 Mdot
.57727 .6282 Mdot
.36301 .39953 Mdot
.69821 .4871 Mdot
.53728 .36671 Mdot
.66891 .4584 Mdot
.5493 .79543 Mdot
.65164 .26497 Mdot
.24389 .58711 Mdot
.3633 .60897 Mdot
.53552 .22014 Mdot
.18846 .57697 Mdot
.65828 .29247 Mdot
.40326 .72986 Mdot
.23805 .68771 Mdot
.37619 .39713 Mdot
.40965 .62454 Mdot
.34898 .41134 Mdot
.50145 .61954 Mdot
.33033 .40499 Mdot
.16032 .5337 Mdot
.5516 .6022 Mdot
.3517 .39397 Mdot
.29601 .54404 Mdot
.53233 .61301 Mdot
.6734 .44725 Mdot
.29068 .25884 Mdot
.78517 .42034 Mdot
.64969 .415 Mdot
.35082 .38717 Mdot
.80186 .59318 Mdot
.54795 .60876 Mdot
.59585 .63354 Mdot
.68507 .48025 Mdot
.48284 .66107 Mdot
.3357 .56193 Mdot
.38519 .56342 Mdot
.52007 .77044 Mdot
.74066 .30454 Mdot
.46291 .63156 Mdot
.67595 .47016 Mdot
.78608 .48642 Mdot
.64878 .34674 Mdot
.52607 .22761 Mdot
.54958 .36565 Mdot
.19424 .40056 Mdot
.50106 .56409 Mdot
.57077 .49065 Mdot
.67007 .38238 Mdot
.65637 .48411 Mdot
.20027 .49041 Mdot
.52419 .38003 Mdot
.75297 .52008 Mdot
.65966 .68123 Mdot
.57331 .6383 Mdot
.52162 .33689 Mdot
.52986 .71093 Mdot
.74764 .40662 Mdot
.41306 .65199 Mdot
.48172 .26752 Mdot
.54045 .58817 Mdot
.63324 .29499 Mdot
.54017 .64955 Mdot
.49886 .76122 Mdot
.56304 .60842 Mdot
.67521 .45497 Mdot
.46442 .6561 Mdot
.46454 .50551 Mdot
.77884 .34573 Mdot
.68956 .39625 Mdot
.3735 .55716 Mdot
.5277 .65932 Mdot
.57233 .64441 Mdot
.36952 .56514 Mdot
.68579 .46279 Mdot
.56805 .61054 Mdot
.34342 .72846 Mdot
.576 .63206 Mdot
.49003 .38215 Mdot
.38714 .50881 Mdot
.61793 .4614 Mdot
.54281 .68278 Mdot
.71406 .49351 Mdot
.51941 .38949 Mdot
.54208 .3874 Mdot
.50805 .56735 Mdot
.49848 .3957 Mdot
.53065 .59466 Mdot
.37628 .49999 Mdot
.67924 .50281 Mdot
.60386 .66498 Mdot
.69052 .46298 Mdot
.80488 .52287 Mdot
.5202 .39219 Mdot
.52265 .22627 Mdot
.54832 .52709 Mdot
.52313 .3722 Mdot
.77777 .4418 Mdot
.4789 .57939 Mdot
.56325 .57748 Mdot
.78072 .43523 Mdot
.36425 .38656 Mdot
.51612 .22123 Mdot
.53446 .37365 Mdot
.5777 .6343 Mdot
.48973 .64059 Mdot
.49262 .35095 Mdot
.75942 .58989 Mdot
.3381 .48948 Mdot
.5614 .6048 Mdot
.67942 .45594 Mdot
.6619 .47769 Mdot
.5504 .5819 Mdot
.5431 .63191 Mdot
.3751 .3782 Mdot
.51115 .24964 Mdot
.50149 .22146 Mdot
.52198 .24377 Mdot
.31734 .42769 Mdot
.54854 .25424 Mdot
.51943 .39582 Mdot
.56571 .2896 Mdot
.396 .33787 Mdot
.54044 .56241 Mdot
.36512 .39718 Mdot
.55839 .6646 Mdot
.49946 .62916 Mdot
.53568 .36411 Mdot
.59763 .20477 Mdot
.52426 .72716 Mdot
.64549 .48932 Mdot
.48939 .3916 Mdot
.57673 .54471 Mdot
.4708 .4125 Mdot
.33575 .56731 Mdot
.69177 .40372 Mdot
.51458 .33627 Mdot
.65579 .46883 Mdot
.49391 .34434 Mdot
.57403 .64195 Mdot
.58459 .64842 Mdot
.66731 .49683 Mdot
.37934 .58073 Mdot
.48677 .63564 Mdot
.55051 .65998 Mdot
.79347 .6923 Mdot
.65231 .34025 Mdot
.46655 .40113 Mdot
.50889 .62164 Mdot
.55072 .57002 Mdot
.37962 .56425 Mdot
.57367 .62541 Mdot
.51441 .65879 Mdot
.71737 .35163 Mdot
.48856 .33461 Mdot
.32562 .56542 Mdot
.75237 .51622 Mdot
.7069 .47959 Mdot
.18876 .44564 Mdot
.5012 .23432 Mdot
.47456 .36642 Mdot
.34287 .47448 Mdot
.52018 .22972 Mdot
.42038 .33654 Mdot
.19492 .46601 Mdot
.52306 .2334 Mdot
.35337 .46729 Mdot
.44958 .66147 Mdot
.5841 .62242 Mdot
.54769 .64907 Mdot
.35241 .58917 Mdot
.68294 .49211 Mdot
.44923 .43903 Mdot
.22359 .45904 Mdot
.53277 .65232 Mdot
.73418 .49022 Mdot
.20824 .43212 Mdot
.51548 .22994 Mdot
.37032 .58572 Mdot
.34151 .55093 Mdot
.53945 .65294 Mdot
.69996 .3223 Mdot
.67247 .46871 Mdot
.53734 .63003 Mdot
.5591 .67527 Mdot
.35464 .38726 Mdot
.65306 .47055 Mdot
.36068 .43253 Mdot
.50228 .25122 Mdot
.31604 .76291 Mdot
.77358 .71412 Mdot
.52677 .35361 Mdot
.18776 .54173 Mdot
.52435 .40567 Mdot
.4589 .21633 Mdot
.51939 .24641 Mdot
.53358 .63999 Mdot
.64546 .4536 Mdot
.53585 .62718 Mdot
.56877 .6324 Mdot
.56617 .62254 Mdot
.46311 .63953 Mdot
.76515 .69093 Mdot
.3536 .57355 Mdot
.52629 .56805 Mdot
.34954 .36989 Mdot
.18078 .50468 Mdot
.27783 .2861 Mdot
.54648 .67416 Mdot
.53736 .65708 Mdot
.69867 .44952 Mdot
.55939 .68533 Mdot
.5384 .34914 Mdot
.69457 .49386 Mdot
.48967 .63336 Mdot
.2054 .51095 Mdot
.57404 .61516 Mdot
.19647 .58797 Mdot
.49306 .34645 Mdot
.6875 .40494 Mdot
.50399 .57888 Mdot
.52357 .23372 Mdot
.51714 .22178 Mdot
.52383 .21783 Mdot
.53722 .34249 Mdot
.35793 .39492 Mdot
.25314 .38791 Mdot
.53801 .70348 Mdot
.51349 .60575 Mdot
.5419 .56931 Mdot
.34161 .44803 Mdot
.40707 .51149 Mdot
.60203 .25023 Mdot
.53607 .54663 Mdot
.35268 .37395 Mdot
.66318 .51353 Mdot
.67634 .22597 Mdot
.69571 .49152 Mdot
.32616 .56118 Mdot
.49145 .36675 Mdot
.33421 .57304 Mdot
.79413 .63276 Mdot
.66935 .5 Mdot
.72822 .47935 Mdot
.35026 .39272 Mdot
.47804 .45191 Mdot
.18831 .29402 Mdot
.32119 .41173 Mdot
.38272 .74823 Mdot
.68389 .47574 Mdot
.52331 .68264 Mdot
.41955 .46934 Mdot
.47885 .45645 Mdot
.34447 .40252 Mdot
.52024 .64616 Mdot
.74298 .32105 Mdot
.3771 .38122 Mdot
.48249 .65096 Mdot
.33844 .38475 Mdot
.50045 .38753 Mdot
.33487 .3887 Mdot
.63843 .49081 Mdot
.49597 .63795 Mdot
.25479 .21508 Mdot
.55256 .42784 Mdot
.5315 .62176 Mdot
.48995 .39192 Mdot
.3317 .72968 Mdot
.56635 .64462 Mdot
.3332 .56755 Mdot
.33032 .37795 Mdot
.31647 .49946 Mdot
.54485 .61106 Mdot
.33552 .39882 Mdot
.65051 .50162 Mdot
.47456 .39894 Mdot
.41779 .20221 Mdot
.50775 .21901 Mdot
.68857 .48797 Mdot
.51239 .20483 Mdot
.53764 .33519 Mdot
.49162 .66168 Mdot
.56684 .66839 Mdot
.68097 .44946 Mdot
.38747 .25275 Mdot
.54133 .69275 Mdot
.52143 .64195 Mdot
.38253 .41565 Mdot
.3541 .45648 Mdot
.32569 .27662 Mdot
.37496 .39613 Mdot
.54485 .56856 Mdot
.67919 .45003 Mdot
.49949 .61503 Mdot
.67484 .44552 Mdot
.52056 .59194 Mdot
.69172 .42055 Mdot
.69183 .49239 Mdot
.68808 .27152 Mdot
.50719 .64186 Mdot
.60637 .57578 Mdot
.56933 .62843 Mdot
.56505 .61471 Mdot
.32393 .38189 Mdot
.36122 .56388 Mdot
.50228 .68485 Mdot
.28909 .41371 Mdot
.36524 .59387 Mdot
.58656 .76211 Mdot
.35571 .38592 Mdot
.34801 .5905 Mdot
.31864 .63171 Mdot
.49705 .23828 Mdot
.35928 .57934 Mdot
.26627 .31127 Mdot
.52942 .35569 Mdot
.69605 .50033 Mdot
.53106 .61306 Mdot
.26874 .72813 Mdot
.37978 .51718 Mdot
.51424 .24068 Mdot
.54158 .61619 Mdot
.5618 .65955 Mdot
.71754 .46259 Mdot
.75773 .27173 Mdot
.37868 .43365 Mdot
.51154 .60083 Mdot
.71326 .46799 Mdot
.81535 .38584 Mdot
.31999 .39628 Mdot
.35928 .58375 Mdot
.4867 .36942 Mdot
.64241 .51364 Mdot
.50862 .21802 Mdot
.54406 .36707 Mdot
.38401 .46556 Mdot
.81143 .59072 Mdot
.54908 .61378 Mdot
.36678 .40476 Mdot
.70329 .75185 Mdot
.48715 .68021 Mdot
.47492 .33843 Mdot
.59122 .73483 Mdot
.65628 .48063 Mdot
.4885 .36177 Mdot
.36206 .54814 Mdot
.684 .50358 Mdot
.68389 .46211 Mdot
.53097 .39794 Mdot
.31274 .36511 Mdot
.45869 .46153 Mdot
.48879 .36636 Mdot
.72977 .38205 Mdot
.56958 .7867 Mdot
.50737 .24806 Mdot
.37387 .58295 Mdot
.57846 .80159 Mdot
.66742 .46994 Mdot
.19309 .40202 Mdot
.75232 .70168 Mdot
.56323 .60323 Mdot
.33983 .57187 Mdot
.4221 .35083 Mdot
.24816 .39237 Mdot
.49809 .36392 Mdot
.42739 .51056 Mdot
.33047 .57156 Mdot
.57846 .61521 Mdot
.61237 .47607 Mdot
.50905 .63931 Mdot
.49546 .38178 Mdot
.7658 .44038 Mdot
.65709 .46338 Mdot
.53087 .33032 Mdot
.75598 .42438 Mdot
.49969 .63192 Mdot
.51327 .64563 Mdot
.46039 .74476 Mdot
.65115 .4823 Mdot
.50526 .2179 Mdot
.5271 .63092 Mdot
.55438 .65109 Mdot
.49516 .6671 Mdot
.60552 .55639 Mdot
.68906 .32937 Mdot
.50776 .60323 Mdot
.31393 .41669 Mdot
.58596 .5985 Mdot
.51206 .64769 Mdot
.71725 .47585 Mdot
.7809 .69452 Mdot
.51035 .25682 Mdot
.54975 .64642 Mdot
.56233 .60989 Mdot
.5386 .38657 Mdot
.4424 .46063 Mdot
.48719 .45751 Mdot
.33628 .42858 Mdot
.39426 .70568 Mdot
.47289 .66394 Mdot
.70515 .46763 Mdot
.34651 .60139 Mdot
.51078 .66944 Mdot
.70746 .46473 Mdot
.58566 .60836 Mdot
.36906 .37543 Mdot
.51029 .24829 Mdot
.60107 .46307 Mdot
.36429 .57865 Mdot
.43064 .42507 Mdot
.58794 .32139 Mdot
.37214 .3858 Mdot
.51823 .60683 Mdot
.48355 .39989 Mdot
.35294 .42999 Mdot
.51345 .23516 Mdot
.60449 .64326 Mdot
.67632 .47903 Mdot
.66006 .46211 Mdot
.51291 .76876 Mdot
.38444 .43199 Mdot
.84956 .51763 Mdot
.49974 .38697 Mdot
.50036 .59397 Mdot
.57481 .33608 Mdot
.66157 .45831 Mdot
.50144 .77433 Mdot
.35042 .59156 Mdot
.49949 .36115 Mdot
.52641 .24634 Mdot
.7041 .45875 Mdot
.65011 .46772 Mdot
.54261 .58636 Mdot
.53941 .67064 Mdot
.40154 .73563 Mdot
.51365 .77328 Mdot
.50636 .39143 Mdot
.3753 .57697 Mdot
.33936 .43509 Mdot
.50399 .62543 Mdot
.68895 .4976 Mdot
.61282 .74125 Mdot
.57955 .63142 Mdot
.37748 .38097 Mdot
.65902 .48657 Mdot
.37282 .56791 Mdot
.34421 .59408 Mdot
.56531 .61502 Mdot
.72347 .69648 Mdot
.52411 .36715 Mdot
.66707 .4512 Mdot
.62897 .53092 Mdot
.52943 .69097 Mdot
.53569 .66983 Mdot
.56919 .70699 Mdot
.54353 .36902 Mdot
.60945 .46259 Mdot
.33335 .59541 Mdot
.67253 .48464 Mdot
.53219 .62354 Mdot
.36763 .58051 Mdot
.59796 .50885 Mdot
.52031 .23948 Mdot
.33485 .38591 Mdot
.33631 .55969 Mdot
.35417 .55714 Mdot
.36534 .59584 Mdot
.20387 .38697 Mdot
.67337 .4334 Mdot
.77742 .47839 Mdot
.56618 .60862 Mdot
.51301 .76671 Mdot
.57049 .67835 Mdot
.53642 .33878 Mdot
.36962 .39064 Mdot
.57047 .63611 Mdot
.54079 .58608 Mdot
.62817 .62945 Mdot
.58883 .55353 Mdot
.71381 .51537 Mdot
.65604 .49289 Mdot
.60095 .56145 Mdot
.36155 .38777 Mdot
.80233 .31609 Mdot
.15083 .43271 Mdot
.4901 .59248 Mdot
.45454 .44941 Mdot
.69213 .4949 Mdot
.52369 .40091 Mdot
.4929 .46473 Mdot
.48457 .36766 Mdot
.66902 .48596 Mdot
.50253 .62178 Mdot
.57024 .29006 Mdot
.38484 .57257 Mdot
.57607 .6456 Mdot
.50512 .38139 Mdot
.57662 .64234 Mdot
.5264 .33495 Mdot
.75153 .45742 Mdot
.68456 .37716 Mdot
.54837 .60365 Mdot
.52364 .68701 Mdot
.62608 .60333 Mdot
.54532 .67357 Mdot
.43693 .29987 Mdot
.69194 .471 Mdot
.7399 .31038 Mdot
.55318 .58436 Mdot
.75833 .64511 Mdot
.58103 .62556 Mdot
.38471 .2646 Mdot
.53332 .67434 Mdot
.49895 .48598 Mdot
.57649 .6103 Mdot
.52443 .66452 Mdot
.53151 .37357 Mdot
.53797 .38825 Mdot
.64798 .49806 Mdot
.5097 .21577 Mdot
.17037 .53693 Mdot
.54475 .66446 Mdot
.31001 .41176 Mdot
.58211 .35978 Mdot
.35756 .55889 Mdot
.66748 .48192 Mdot
.83701 .40912 Mdot
.5162 .3918 Mdot
.36879 .36299 Mdot
.40341 .26227 Mdot
.3506 .44312 Mdot
.55748 .32793 Mdot
.58334 .5427 Mdot
.37581 .56888 Mdot
.58137 .62286 Mdot
.63584 .75805 Mdot
.63995 .31593 Mdot
.48672 .62174 Mdot
.50939 .32669 Mdot
.50425 .54987 Mdot
.59032 .78961 Mdot
.36483 .54433 Mdot
.36396 .55131 Mdot
.53031 .3774 Mdot
.37689 .42871 Mdot
.49719 .70092 Mdot
.34764 .59108 Mdot
.36316 .37748 Mdot
.5108 .21199 Mdot
.49866 .52441 Mdot
.6708 .47112 Mdot
.63292 .42215 Mdot
.61509 .35911 Mdot
.50812 .3915 Mdot
.29493 .43032 Mdot
.65319 .51519 Mdot
.72124 .46096 Mdot
.51844 .2186 Mdot
.32593 .37887 Mdot
.65271 .44418 Mdot
.48723 .64591 Mdot
.58543 .56774 Mdot
.53922 .64873 Mdot
.34341 .58322 Mdot
.53908 .67813 Mdot
.34183 .37074 Mdot
.49915 .37109 Mdot
.35098 .42447 Mdot
.525 .36373 Mdot
.57376 .27356 Mdot
.5459 .62712 Mdot
.53075 .66364 Mdot
.38814 .48995 Mdot
.6453 .47988 Mdot
.75123 .6851 Mdot
.30791 .40559 Mdot
.35283 .40545 Mdot
.49681 .6192 Mdot
.65492 .5046 Mdot
.36 .5318 Mdot
.39164 .48095 Mdot
.54849 .67816 Mdot
.6929 .47189 Mdot
.51266 .60246 Mdot
.24803 .57452 Mdot
.67299 .36982 Mdot
.66703 .45838 Mdot
.76042 .31307 Mdot
.50938 .62963 Mdot
.43967 .62451 Mdot
.55404 .57016 Mdot
.34922 .71163 Mdot
.51835 .68808 Mdot
.70647 .48421 Mdot
.54468 .64529 Mdot
.70056 .48123 Mdot
.38164 .40479 Mdot
.51487 .39995 Mdot
.68991 .48552 Mdot
.53671 .68227 Mdot
.19909 .36582 Mdot
.50381 .38527 Mdot
.52493 .65948 Mdot
.51624 .3403 Mdot
.71274 .47865 Mdot
.64831 .48711 Mdot
.26947 .31351 Mdot
.45931 .37893 Mdot
.50645 .38754 Mdot
.52302 .59862 Mdot
.60589 .39219 Mdot
.50035 .61415 Mdot
.40971 .74274 Mdot
.52063 .58473 Mdot
.49779 .67726 Mdot
.4671 .16843 Mdot
.49472 .4069 Mdot
.84069 .48392 Mdot
.2225 .4718 Mdot
.21444 .37127 Mdot
.62542 .49236 Mdot
.3646 .54424 Mdot
.19981 .4757 Mdot
.50112 .24845 Mdot
.33119 .38208 Mdot
.57093 .63523 Mdot
.66676 .41994 Mdot
.4886 .38185 Mdot
.35639 .56357 Mdot
.54733 .60357 Mdot
.37085 .37411 Mdot
.2924 .2922 Mdot
.49667 .39587 Mdot
.66742 .4725 Mdot
.64524 .48448 Mdot
.80602 .38303 Mdot
.53578 .62104 Mdot
.53111 .66018 Mdot
.49147 .37003 Mdot
.47194 .65471 Mdot
.37252 .5952 Mdot
.27627 .56201 Mdot
.5096 .38675 Mdot
.56724 .42 Mdot
.66482 .50082 Mdot
.56107 .66142 Mdot
.39898 .51901 Mdot
.31977 .32749 Mdot
.6758 .57044 Mdot
.35249 .58799 Mdot
.42539 .73731 Mdot
.70662 .4837 Mdot
.50596 .37533 Mdot
.36333 .6314 Mdot
.52388 .57745 Mdot
.55978 .6584 Mdot
.43054 .73817 Mdot
.43633 .45933 Mdot
.37239 .53533 Mdot
.55821 .68705 Mdot
.4324 .46809 Mdot
.49598 .62176 Mdot
.49021 .63958 Mdot
.47736 .60479 Mdot
.52213 .66922 Mdot
.69602 .47706 Mdot
.62947 .62877 Mdot
.33184 .39434 Mdot
.7439 .57176 Mdot
.44394 .50205 Mdot
.52293 .62063 Mdot
.50186 .62464 Mdot
.66199 .55298 Mdot
.58004 .37345 Mdot
.68821 .47114 Mdot
.69761 .42774 Mdot
.52727 .3895 Mdot
.60079 .57406 Mdot
.36144 .44457 Mdot
.60072 .71848 Mdot
.34613 .42511 Mdot
.69396 .47178 Mdot
.35813 .4021 Mdot
.53182 .38697 Mdot
.36681 .40612 Mdot
.31655 .42587 Mdot
.50514 .33512 Mdot
.66467 .50275 Mdot
.54807 .67709 Mdot
.51723 .39354 Mdot
.45748 .74652 Mdot
.34313 .58375 Mdot
.2695 .31286 Mdot
.59542 .61547 Mdot
.49706 .73105 Mdot
.28164 .65098 Mdot
.35548 .42103 Mdot
.68771 .36304 Mdot
.69161 .49234 Mdot
.37141 .60323 Mdot
.69786 .47982 Mdot
.77149 .67418 Mdot
.36851 .56688 Mdot
.26472 .31463 Mdot
.34208 .62203 Mdot
.28292 .4416 Mdot
.57297 .67108 Mdot
.72875 .43414 Mdot
.35773 .43026 Mdot
.49021 .38537 Mdot
.41605 .38645 Mdot
.51029 .66054 Mdot
.65367 .28693 Mdot
.6916 .43577 Mdot
.49779 .2285 Mdot
.50779 .36933 Mdot
.51196 .32434 Mdot
.54076 .62031 Mdot
.31691 .46788 Mdot
.49477 .60953 Mdot
.40153 .61456 Mdot
.4076 .72465 Mdot
.60023 .72035 Mdot
.53068 .59326 Mdot
.34256 .42828 Mdot
.51451 .60185 Mdot
.45729 .59281 Mdot
.63799 .78272 Mdot
.59466 .60523 Mdot
.66245 .26415 Mdot
.34866 .51029 Mdot
.67133 .498 Mdot
.50259 .57802 Mdot
.50781 .2386 Mdot
.50881 .62526 Mdot
.40169 .85041 Mdot
.35977 .57589 Mdot
.39816 .4165 Mdot
.5622 .68107 Mdot
.53127 .62853 Mdot
.66553 .73575 Mdot
.70775 .41674 Mdot
.52423 .25277 Mdot
.55991 .65332 Mdot
.40389 .69718 Mdot
.53845 .35953 Mdot
.52233 .58075 Mdot
.54456 .64976 Mdot
.53571 .79799 Mdot
.53311 .34881 Mdot
.3595 .4165 Mdot
.49832 .24393 Mdot
.33558 .43377 Mdot
.34809 .54275 Mdot
.50928 .45953 Mdot
.51274 .77753 Mdot
.66893 .36947 Mdot
.33192 .57515 Mdot
.56288 .67592 Mdot
.46114 .69811 Mdot
.51742 .63567 Mdot
.36449 .55025 Mdot
.53205 .34455 Mdot
.69295 .47901 Mdot
.59891 .45597 Mdot
.51047 .22863 Mdot
.48347 .65238 Mdot
.36989 .54782 Mdot
.68236 .48269 Mdot
.31414 .30427 Mdot
.67589 .49176 Mdot
.52226 .37572 Mdot
.54005 .34015 Mdot
.36751 .5709 Mdot
.69792 .47778 Mdot
.31612 .41541 Mdot
.22417 .46838 Mdot
.51743 .58765 Mdot
.47617 .4117 Mdot
.63559 .47506 Mdot
.70196 .50652 Mdot
.66671 .44048 Mdot
.54801 .62079 Mdot
.44848 .45571 Mdot
.50262 .58619 Mdot
.52756 .38362 Mdot
.34343 .38034 Mdot
.52333 .77813 Mdot
.6688 .74398 Mdot
.56153 .42487 Mdot
.50156 .68355 Mdot
.51462 .65514 Mdot
.53923 .65295 Mdot
.55575 .59725 Mdot
.26237 .57776 Mdot
.54525 .6299 Mdot
.52951 .36884 Mdot
.32687 .41099 Mdot
.53718 .61744 Mdot
.50576 .23926 Mdot
.4557 .47269 Mdot
.34255 .59839 Mdot
.48396 .48517 Mdot
.17231 .41023 Mdot
.68335 .48187 Mdot
.37278 .41215 Mdot
.32858 .38639 Mdot
.35684 .59991 Mdot
.49934 .39099 Mdot
.68032 .49144 Mdot
.33605 .68988 Mdot
.37203 .59085 Mdot
.55037 .64548 Mdot
.36486 .4903 Mdot
.72737 .27399 Mdot
.57733 .65785 Mdot
.56398 .63289 Mdot
.4952 .23721 Mdot
.3712 .438 Mdot
.27467 .75211 Mdot
.42944 .4501 Mdot
.36345 .56629 Mdot
.3589 .55349 Mdot
.66938 .43843 Mdot
.4846 .62181 Mdot
.51988 .36107 Mdot
.40928 .47703 Mdot
.36426 .7589 Mdot
.37931 .35422 Mdot
.45277 .21572 Mdot
.57335 .61793 Mdot
.6682 .72031 Mdot
.51353 .59513 Mdot
.71911 .46426 Mdot
.68789 .44116 Mdot
.68225 .47006 Mdot
.52749 .37756 Mdot
.80349 .53046 Mdot
.52935 .36572 Mdot
.16614 .4163 Mdot
.69602 .49633 Mdot
.26105 .47571 Mdot
.35486 .39781 Mdot
.52945 .70139 Mdot
.37677 .57395 Mdot
.57065 .39894 Mdot
.47639 .60242 Mdot
.69024 .31765 Mdot
.36511 .39782 Mdot
.65209 .49386 Mdot
.48739 .56831 Mdot
.17218 .58579 Mdot
.49489 .44866 Mdot
.4347 .57359 Mdot
.74098 .69951 Mdot
.37002 .56652 Mdot
.67819 .56043 Mdot
.37828 .58909 Mdot
.49542 .37326 Mdot
.51187 .66263 Mdot
.51854 .66948 Mdot
.52661 .59177 Mdot
.54764 .62817 Mdot
.53753 .36856 Mdot
.55975 .59185 Mdot
.70058 .76794 Mdot
.50374 .24767 Mdot
.22701 .52498 Mdot
.33676 .5805 Mdot
.50477 .33212 Mdot
.33477 .41972 Mdot
.50932 .21425 Mdot
.47562 .7845 Mdot
.56871 .6057 Mdot
.56994 .63158 Mdot
.52576 .23464 Mdot
.47213 .61816 Mdot
.49694 .56459 Mdot
.33153 .39717 Mdot
.5596 .43586 Mdot
.34909 .54779 Mdot
.33433 .57182 Mdot
.50515 .3376 Mdot
.69824 .47937 Mdot
.35317 .5906 Mdot
.38083 .42368 Mdot
.56847 .5944 Mdot
.50685 .6737 Mdot
.63569 .47576 Mdot
.75256 .70155 Mdot
.37399 .54671 Mdot
.46543 .59472 Mdot
.70389 .48084 Mdot
.68576 .43334 Mdot
.56189 .65328 Mdot
.59942 .65507 Mdot
.69232 .50876 Mdot
.33847 .58933 Mdot
.50317 .33285 Mdot
.27621 .4487 Mdot
.4966 .38023 Mdot
.68291 .48852 Mdot
.57064 .58853 Mdot
.66468 .50202 Mdot
.51203 .6251 Mdot
.6016 .13767 Mdot
.52688 .67258 Mdot
.78211 .42473 Mdot
.35993 .7205 Mdot
.32597 .38981 Mdot
.31879 .41988 Mdot
.50702 .24484 Mdot
.70441 .48345 Mdot
.50834 .66711 Mdot
.36682 .55684 Mdot
.22477 .35653 Mdot
.65047 .43567 Mdot
.35159 .37531 Mdot
.36435 .44251 Mdot
.53898 .35263 Mdot
.58095 .63876 Mdot
.55493 .66649 Mdot
.36608 .40857 Mdot
.27909 .63625 Mdot
.70208 .46251 Mdot
.5308 .65944 Mdot
.51266 .65187 Mdot
.32763 .39671 Mdot
.2246 .47586 Mdot
.74212 .44211 Mdot
.52018 .66673 Mdot
.32678 .61314 Mdot
.53626 .33987 Mdot
.55009 .59719 Mdot
.5593 .59257 Mdot
.34718 .56144 Mdot
.21649 .53743 Mdot
.60394 .78944 Mdot
.51552 .33062 Mdot
.50384 .21946 Mdot
.53572 .68337 Mdot
.35288 .39787 Mdot
.52137 .68176 Mdot
.22645 .63295 Mdot
.49979 .24064 Mdot
.53783 .63641 Mdot
.48598 .59674 Mdot
.65982 .45333 Mdot
.53718 .63268 Mdot
.61393 .71358 Mdot
.3283 .42503 Mdot
.53882 .63446 Mdot
.7348 .6895 Mdot
.54032 .36085 Mdot
.49228 .5873 Mdot
.34776 .55188 Mdot
.34589 .71246 Mdot
.59975 .33717 Mdot
.32827 .44177 Mdot
.34082 .58873 Mdot
.54491 .67906 Mdot
.37734 .42557 Mdot
.48792 .38445 Mdot
.66801 .29875 Mdot
.58431 .61791 Mdot
.49825 .38361 Mdot
.50053 .37124 Mdot
.36517 .57305 Mdot
.82768 .44421 Mdot
.46856 .62791 Mdot
.5448 .67503 Mdot
.47121 .81051 Mdot
.68956 .43722 Mdot
.54829 .6757 Mdot
.57556 .65547 Mdot
.51628 .35529 Mdot
.54947 .52575 Mdot
.73712 .50904 Mdot
.29535 .54515 Mdot
.52759 .33519 Mdot
.31186 .43 Mdot
.37751 .42424 Mdot
.33782 .58224 Mdot
.6672 .49488 Mdot
.33097 .58226 Mdot
.34362 .38973 Mdot
.56451 .60987 Mdot
.50798 .35183 Mdot
.67639 .60807 Mdot
.49896 .4036 Mdot
.37369 .37221 Mdot
.71889 .49044 Mdot
.56752 .32268 Mdot
.55025 .84005 Mdot
.61711 .34504 Mdot
.49114 .3364 Mdot
.35677 .55874 Mdot
.38363 .47776 Mdot
.51441 .6537 Mdot
.72154 .53965 Mdot
.56724 .66419 Mdot
.73604 .70367 Mdot
.36813 .38577 Mdot
.5206 .21983 Mdot
.51167 .66291 Mdot
.41935 .72746 Mdot
.49623 .33351 Mdot
.54096 .35613 Mdot
.55721 .62777 Mdot
.52362 .37345 Mdot
.54304 .66932 Mdot
.32287 .4048 Mdot
.82632 .46404 Mdot
.51919 .65789 Mdot
.58155 .57977 Mdot
.47863 .3458 Mdot
.26856 .31298 Mdot
.31181 .39025 Mdot
.6667 .72468 Mdot
.18016 .61732 Mdot
.52229 .37106 Mdot
.54779 .56736 Mdot
.36399 .4231 Mdot
.49475 .23625 Mdot
.32873 .36855 Mdot
.57291 .65077 Mdot
.57006 .61973 Mdot
.49729 .61538 Mdot
.51263 .64492 Mdot
.7128 .5416 Mdot
.55849 .54682 Mdot
.67893 .68909 Mdot
.56869 .63072 Mdot
.61859 .51163 Mdot
.53291 .36751 Mdot
.7159 .51328 Mdot
.38947 .58955 Mdot
.56921 .61394 Mdot
.69305 .41354 Mdot
.50936 .33128 Mdot
.16748 .42223 Mdot
.53644 .35068 Mdot
.34508 .41789 Mdot
.51777 .40436 Mdot
.51492 .62275 Mdot
.66146 .47594 Mdot
.32522 .4182 Mdot
.59473 .2547 Mdot
.33321 .37995 Mdot
.53221 .62143 Mdot
.23385 .50313 Mdot
.32949 .38721 Mdot
.4639 .47718 Mdot
.66085 .48132 Mdot
.40845 .69355 Mdot
.70258 .44756 Mdot
.53259 .63702 Mdot
.52777 .63956 Mdot
.50477 .21398 Mdot
.4987 .39799 Mdot
.71128 .48236 Mdot
.80034 .68423 Mdot
.3328 .55506 Mdot
.67769 .4646 Mdot
.56189 .69533 Mdot
.44325 .45221 Mdot
.66979 .45203 Mdot
.37083 .68882 Mdot
.49577 .39042 Mdot
.65673 .44299 Mdot
.57033 .69517 Mdot
.56402 .49498 Mdot
.38352 .58443 Mdot
.36366 .37105 Mdot
.54981 .47414 Mdot
.35477 .43238 Mdot
.52063 .32896 Mdot
.38707 .41876 Mdot
.53756 .36002 Mdot
.77856 .44386 Mdot
.76346 .45076 Mdot
.48493 .39707 Mdot
.53764 .33614 Mdot
.34415 .39558 Mdot
.55935 .60127 Mdot
.44784 .51446 Mdot
.53162 .69498 Mdot
.58176 .65669 Mdot
.54228 .36964 Mdot
.71051 .47386 Mdot
.68618 .50608 Mdot
.73629 .44904 Mdot
.6467 .47966 Mdot
.33456 .42132 Mdot
.6949 .36926 Mdot
.78649 .64361 Mdot
.50193 .3426 Mdot
.55175 .38471 Mdot
.50021 .61686 Mdot
.34998 .39669 Mdot
.37946 .39621 Mdot
.51073 .35861 Mdot
.6997 .57161 Mdot
.553 .57146 Mdot
.71668 .46642 Mdot
.69464 .49714 Mdot
.6739 .45207 Mdot
.65381 .45161 Mdot
.78401 .52399 Mdot
.49024 .38594 Mdot
.70098 .49012 Mdot
.55019 .63204 Mdot
.57451 .62781 Mdot
.50862 .22162 Mdot
.33851 .56182 Mdot
.59338 .62758 Mdot
.59045 .59617 Mdot
.56283 .6541 Mdot
.33382 .38575 Mdot
.58738 .694 Mdot
.49996 .2336 Mdot
.38179 .43041 Mdot
.34454 .44774 Mdot
.52186 .22516 Mdot
.63838 .53709 Mdot
.16651 .59096 Mdot
.51134 .60108 Mdot
.42617 .60614 Mdot
.34948 .40183 Mdot
.74729 .37005 Mdot
.60797 .50162 Mdot
.53379 .59378 Mdot
.52141 .50811 Mdot
.32205 .41048 Mdot
.69744 .43753 Mdot
.55974 .66956 Mdot
.51952 .24788 Mdot
.34653 .60052 Mdot
.55718 .69834 Mdot
.49588 .2406 Mdot
.69555 .47058 Mdot
.40561 .56625 Mdot
.66638 .4371 Mdot
.31856 .39744 Mdot
.48948 .58938 Mdot
.1951 .282 Mdot
.36469 .4297 Mdot
.23121 .37835 Mdot
.75987 .45246 Mdot
.51894 .6601 Mdot
.35996 .43256 Mdot
.70692 .44319 Mdot
.53924 .34322 Mdot
.42682 .47716 Mdot
.68609 .49803 Mdot
.51199 .21464 Mdot
.51481 .22231 Mdot
.33006 .39544 Mdot
.65513 .4875 Mdot
.53733 .5808 Mdot
.67498 .44389 Mdot
.51458 .40553 Mdot
.535 .60277 Mdot
.16832 .54405 Mdot
.58205 .56386 Mdot
.70609 .47675 Mdot
.38161 .38593 Mdot
.38138 .56942 Mdot
.54988 .60499 Mdot
.21276 .41684 Mdot
.57846 .64873 Mdot
.52314 .34146 Mdot
.73894 .3365 Mdot
.66596 .61197 Mdot
.56261 .60751 Mdot
.50026 .62167 Mdot
.50074 .33842 Mdot
.5621 .60374 Mdot
.57827 .65394 Mdot
.46975 .34831 Mdot
.65828 .45708 Mdot
.53653 .64837 Mdot
.37177 .382 Mdot
.66055 .76038 Mdot
.53516 .68397 Mdot
.64317 .24707 Mdot
.41404 .70868 Mdot
.74948 .3525 Mdot
.52566 .68047 Mdot
.46653 .75535 Mdot
.5254 .64485 Mdot
.55246 .61498 Mdot
.52008 .59646 Mdot
.65946 .71555 Mdot
.34627 .3927 Mdot
.3479 .37261 Mdot
.38295 .58842 Mdot
.41108 .70824 Mdot
.34098 .57175 Mdot
.51526 .33433 Mdot
.39575 .21837 Mdot
.50257 .24491 Mdot
.6989 .48041 Mdot
.49457 .63618 Mdot
.31755 .39372 Mdot
.56478 .65911 Mdot
.51174 .62074 Mdot
.32045 .40267 Mdot
.37025 .4289 Mdot
.39198 .41733 Mdot
.37779 .58742 Mdot
.68737 .47662 Mdot
.54611 .58785 Mdot
.36565 .59345 Mdot
.53603 .57938 Mdot
.43218 .45413 Mdot
.68742 .4741 Mdot
.67274 .44441 Mdot
.71153 .49013 Mdot
.56674 .61053 Mdot
.51931 .61985 Mdot
.52875 .36416 Mdot
.63449 .47772 Mdot
.49532 .34927 Mdot
.35221 .43107 Mdot
.31653 .41047 Mdot
.57334 .64942 Mdot
.46897 .58585 Mdot
.3591 .55464 Mdot
.34979 .4191 Mdot
.52576 .23975 Mdot
.37964 .59372 Mdot
.54247 .61606 Mdot
.34588 .4286 Mdot
.33415 .56831 Mdot
.71943 .5838 Mdot
.20879 .65473 Mdot
.3802 .56287 Mdot
.55595 .62968 Mdot
.67044 .73597 Mdot
.39275 .63478 Mdot
.3278 .56653 Mdot
.5043 .34395 Mdot
.57917 .64346 Mdot
.30533 .71018 Mdot
.33303 .56105 Mdot
.73903 .71168 Mdot
.32489 .39378 Mdot
.52775 .52884 Mdot
.57582 .69126 Mdot
.7408 .53732 Mdot
.32928 .57669 Mdot
.67686 .48829 Mdot
.63182 .47827 Mdot
.55362 .63821 Mdot
.36387 .61555 Mdot
.54325 .38814 Mdot
.32346 .39014 Mdot
.31125 .41291 Mdot
.6537 .4807 Mdot
.62731 .39196 Mdot
.3758 .38289 Mdot
.47108 .67095 Mdot
.36259 .47049 Mdot
.61154 .60379 Mdot
.79408 .4651 Mdot
.58414 .25752 Mdot
.5012 .66861 Mdot
.3765 .55869 Mdot
.48775 .35595 Mdot
.52759 .36786 Mdot
.52005 .38072 Mdot
.32506 .42884 Mdot
.49126 .46865 Mdot
.36746 .3975 Mdot
.65022 .29428 Mdot
.36744 .58118 Mdot
.39699 .67228 Mdot
.51227 .66905 Mdot
.51677 .65635 Mdot
.54563 .5788 Mdot
.49396 .62085 Mdot
.52575 .6467 Mdot
.50581 .39033 Mdot
.33798 .43996 Mdot
.31486 .50364 Mdot
.68123 .45467 Mdot
.34151 .27585 Mdot
.35521 .39785 Mdot
.49669 .23933 Mdot
.35285 .57077 Mdot
.49375 .76059 Mdot
.34749 .45957 Mdot
.35732 .40289 Mdot
.57799 .60198 Mdot
.70221 .45183 Mdot
.60541 .54929 Mdot
.5213 .64235 Mdot
.35196 .41981 Mdot
.34885 .35338 Mdot
.65998 .57217 Mdot
.53162 .72168 Mdot
.3479 .53204 Mdot
.44721 .45157 Mdot
.33696 .59967 Mdot
.60015 .64486 Mdot
.74495 .36757 Mdot
.34249 .39092 Mdot
.33799 .41351 Mdot
.36666 .54754 Mdot
.44227 .63267 Mdot
.65908 .49008 Mdot
.52179 .22089 Mdot
.51753 .34262 Mdot
.52002 .63724 Mdot
.32845 .42958 Mdot
.4422 .59148 Mdot
.35321 .48316 Mdot
.51161 .38514 Mdot
.38091 .43183 Mdot
.58013 .62412 Mdot
.55895 .62911 Mdot
.36769 .5639 Mdot
.41728 .54774 Mdot
.55214 .69752 Mdot
.21391 .37208 Mdot
.6794 .37845 Mdot
.68117 .39319 Mdot
.55948 .65883 Mdot
.65214 .47504 Mdot
.52066 .24371 Mdot
.37436 .58291 Mdot
.55866 .58652 Mdot
.19117 .63744 Mdot
.65638 .51231 Mdot
.50314 .37939 Mdot
.52257 .24011 Mdot
.48916 .46937 Mdot
.57706 .65299 Mdot
.56669 .66475 Mdot
.54789 .62432 Mdot
.20444 .66352 Mdot
.35923 .37507 Mdot
.6616 .44445 Mdot
.35034 .58676 Mdot
.65029 .45964 Mdot
.3422 .37431 Mdot
.59745 .44161 Mdot
.53853 .61491 Mdot
.71876 .47214 Mdot
.67413 .48852 Mdot
.53901 .35221 Mdot
.54493 .35653 Mdot
.38655 .43455 Mdot
.52746 .6721 Mdot
.51566 .25223 Mdot
.69575 .44324 Mdot
.3633 .4385 Mdot
.36931 .56716 Mdot
.52378 .39077 Mdot
.56812 .62869 Mdot
.33619 .39299 Mdot
.48448 .63971 Mdot
.67958 .44669 Mdot
.35667 .4024 Mdot
.50428 .25646 Mdot
.35253 .55343 Mdot
.56927 .62271 Mdot
.38393 .53823 Mdot
.52447 .22983 Mdot
.50916 .64941 Mdot
.56059 .75936 Mdot
.39102 .59862 Mdot
.5963 .25144 Mdot
.37176 .404 Mdot
.50474 .23199 Mdot
.68067 .44055 Mdot
.58234 .50173 Mdot
.33553 .41438 Mdot
.55863 .74667 Mdot
.43666 .53232 Mdot
.54761 .58906 Mdot
.66662 .46492 Mdot
.31109 .55088 Mdot
.1846 .40903 Mdot
.35837 .63586 Mdot
.53213 .65638 Mdot
.35811 .43311 Mdot
.33416 .57807 Mdot
.50643 .33965 Mdot
.64601 .2487 Mdot
.78709 .47649 Mdot
.38245 .43252 Mdot
.51177 .59917 Mdot
.69621 .44381 Mdot
.50894 .36008 Mdot
.56627 .28206 Mdot
.38326 .41903 Mdot
.37173 .39034 Mdot
.54739 .61173 Mdot
.35902 .59067 Mdot
.27674 .61904 Mdot
.34834 .3714 Mdot
.33695 .43566 Mdot
.33186 .27991 Mdot
.37679 .55134 Mdot
.54896 .63624 Mdot
.73614 .44841 Mdot
.57578 .60506 Mdot
.2289 .36612 Mdot
.50194 .23593 Mdot
.68385 .4544 Mdot
.57693 .63493 Mdot
.34085 .50668 Mdot
.34022 .4217 Mdot
.45635 .45011 Mdot
.38331 .38129 Mdot
.50269 .39127 Mdot
.32627 .42726 Mdot
.5596 .66771 Mdot
.49842 .33101 Mdot
.35584 .55456 Mdot
.52084 .66754 Mdot
.51911 .61864 Mdot
.71413 .45005 Mdot
.4948 .36957 Mdot
.59117 .77916 Mdot
.54775 .34582 Mdot
.49426 .34414 Mdot
.65444 .43902 Mdot
.55211 .64178 Mdot
.34925 .4147 Mdot
.36188 .36863 Mdot
.54878 .5846 Mdot
.74925 .37719 Mdot
.65644 .48453 Mdot
.37655 .45014 Mdot
.27242 .74724 Mdot
.49525 .70262 Mdot
.51599 .25513 Mdot
.45202 .69007 Mdot
.54165 .35262 Mdot
.56338 .62671 Mdot
.70443 .47354 Mdot
.34639 .4396 Mdot
.37498 .38237 Mdot
.56053 .58458 Mdot
.50158 .36464 Mdot
.33687 .59196 Mdot
.37655 .39657 Mdot
.34617 .47809 Mdot
.54026 .62851 Mdot
.65281 .28403 Mdot
.37593 .40453 Mdot
.24392 .30718 Mdot
.32754 .50299 Mdot
.66887 .45885 Mdot
.51154 .6174 Mdot
.64641 .49327 Mdot
.34676 .58281 Mdot
.3022 .40621 Mdot
.49923 .3682 Mdot
.50287 .71971 Mdot
.61743 .80479 Mdot
.35022 .3923 Mdot
.69522 .47591 Mdot
.56538 .60809 Mdot
.4851 .70206 Mdot
.53883 .67683 Mdot
.5596 .52587 Mdot
.39749 .5778 Mdot
.54325 .37196 Mdot
.52195 .33942 Mdot
.50004 .63059 Mdot
.37214 .59394 Mdot
.33502 .37055 Mdot
.32355 .39622 Mdot
.79254 .29314 Mdot
.50334 .25645 Mdot
.39192 .73678 Mdot
.56775 .61883 Mdot
.35913 .44144 Mdot
.66387 .74736 Mdot
.49136 .36991 Mdot
.49805 .60198 Mdot
.33323 .44161 Mdot
.33086 .32328 Mdot
.43293 .45678 Mdot
.53499 .64263 Mdot
.4751 .66667 Mdot
.51813 .3411 Mdot
.40178 .47363 Mdot
.36706 .39993 Mdot
.51197 .58748 Mdot
.5435 .33961 Mdot
.30708 .29522 Mdot
.67515 .78558 Mdot
.68698 .4762 Mdot
.37679 .37331 Mdot
.50322 .39067 Mdot
.52413 .7035 Mdot
.3365 .58055 Mdot
.33926 .4322 Mdot
.33541 .38165 Mdot
.52687 .60451 Mdot
.59216 .64031 Mdot
.49502 .70325 Mdot
.68704 .46348 Mdot
.52728 .35654 Mdot
.50456 .65625 Mdot
.63483 .39041 Mdot
.49714 .61353 Mdot
.52464 .35702 Mdot
.38577 .12833 Mdot
.58493 .61674 Mdot
.54004 .67538 Mdot
.29196 .62381 Mdot
.67708 .50377 Mdot
.64877 .4665 Mdot
.68874 .37446 Mdot
.56791 .61915 Mdot
.2959 .45478 Mdot
.6881 .47956 Mdot
.65667 .48067 Mdot
.25464 .48552 Mdot
.53663 .59984 Mdot
.41165 .45779 Mdot
.51885 .35957 Mdot
.50824 .3938 Mdot
.66562 .44964 Mdot
.53534 .70263 Mdot
.4867 .36645 Mdot
.74366 .51515 Mdot
.35742 .39494 Mdot
.74457 .36651 Mdot
.69454 .44902 Mdot
.40979 .53272 Mdot
.49509 .38312 Mdot
.16382 .40391 Mdot
.54063 .49494 Mdot
.50586 .59917 Mdot
.56196 .61983 Mdot
.34658 .56001 Mdot
.50227 .56904 Mdot
.50203 .22062 Mdot
.524 .37486 Mdot
.22714 .58024 Mdot
.68131 .46942 Mdot
.53312 .67256 Mdot
.50283 .76295 Mdot
.58582 .29361 Mdot
.67161 .26939 Mdot
.67246 .4974 Mdot
.66965 .46776 Mdot
.36307 .38888 Mdot
.35009 .38322 Mdot
.54303 .64203 Mdot
.52959 .37447 Mdot
.63946 .45972 Mdot
.52163 .34851 Mdot
.3424 .38987 Mdot
.35395 .4065 Mdot
.49882 .23868 Mdot
.4768 .64491 Mdot
.32029 .39759 Mdot
.29423 .30761 Mdot
.62539 .39676 Mdot
.71516 .44788 Mdot
.53988 .83629 Mdot
.56228 .27993 Mdot
.3001 .66057 Mdot
.35653 .60406 Mdot
.51437 .26746 Mdot
.5314 .39518 Mdot
.50063 .62616 Mdot
.57073 .64304 Mdot
.51592 .23025 Mdot
.50529 .39969 Mdot
.35197 .56565 Mdot
.49923 .3986 Mdot
.36748 .58602 Mdot
.3143 .38991 Mdot
.53504 .68378 Mdot
.56836 .66829 Mdot
.51016 .38903 Mdot
.36143 .41369 Mdot
.32149 .39364 Mdot
.37133 .59913 Mdot
.47589 .74516 Mdot
.33109 .39412 Mdot
.69251 .44779 Mdot
.78385 .60321 Mdot
.51529 .22354 Mdot
.55643 .67156 Mdot
.50794 .77061 Mdot
.68708 .56245 Mdot
.53505 .58792 Mdot
.52343 .23777 Mdot
.81026 .32817 Mdot
.51845 .67169 Mdot
.8086 .35392 Mdot
.50411 .22828 Mdot
.67221 .50537 Mdot
.3686 .42188 Mdot
.50284 .21869 Mdot
.54419 .70594 Mdot
.3277 .55601 Mdot
.59505 .62023 Mdot
.68299 .49971 Mdot
.7143 .49119 Mdot
.75117 .41173 Mdot
.22974 .3672 Mdot
.37987 .57606 Mdot
.35924 .5672 Mdot
.33281 .41141 Mdot
.4454 .17836 Mdot
.57798 .6862 Mdot
.35938 .56451 Mdot
.24773 .60798 Mdot
.50199 .61405 Mdot
.41827 .74791 Mdot
.51928 .50678 Mdot
.6526 .47614 Mdot
.67945 .53289 Mdot
.33598 .41738 Mdot
.69461 .47603 Mdot
.62276 .41242 Mdot
.54766 .57951 Mdot
.68569 .47201 Mdot
.52123 .35491 Mdot
.43399 .33446 Mdot
.6487 .49246 Mdot
.41033 .48505 Mdot
.51929 .36164 Mdot
.39252 .60105 Mdot
.32499 .64593 Mdot
.40119 .85983 Mdot
.52526 .37531 Mdot
.35966 .42371 Mdot
.31889 .39901 Mdot
.32501 .39996 Mdot
.68655 .49831 Mdot
.38171 .4099 Mdot
.69018 .45958 Mdot
.22508 .4361 Mdot
.48145 .763 Mdot
.3688 .5729 Mdot
.46132 .38893 Mdot
.66966 .47967 Mdot
.6691 .33297 Mdot
.56138 .83214 Mdot
.55584 .62741 Mdot
.54581 .34253 Mdot
.36487 .54755 Mdot
.38871 .1822 Mdot
.34612 .56236 Mdot
.36483 .42234 Mdot
.7434 .36369 Mdot
.5414 .66823 Mdot
.60555 .7248 Mdot
.36219 .55304 Mdot
.67738 .49833 Mdot
.51113 .65194 Mdot
.391 .3844 Mdot
.34019 .5851 Mdot
.34465 .59885 Mdot
.52533 .65079 Mdot
.65117 .48958 Mdot
.35298 .41093 Mdot
.53274 .3916 Mdot
.38382 .55039 Mdot
.49871 .68845 Mdot
.55565 .59607 Mdot
.49609 .59666 Mdot
.48193 .45401 Mdot
.27962 .66589 Mdot
.52147 .36963 Mdot
.41897 .65145 Mdot
.34192 .38522 Mdot
.33823 .62517 Mdot
.64632 .34927 Mdot
.46178 .37638 Mdot
.50189 .23455 Mdot
.50181 .23933 Mdot
.53161 .64496 Mdot
.27293 .65805 Mdot
.72691 .29721 Mdot
.50125 .31929 Mdot
.51944 .22765 Mdot
.32256 .3924 Mdot
.63808 .49402 Mdot
.7411 .41119 Mdot
.58782 .65297 Mdot
.54451 .36551 Mdot
.33332 .39094 Mdot
.22815 .63739 Mdot
.36447 .58114 Mdot
.7085 .3602 Mdot
.53418 .6183 Mdot
.53159 .66303 Mdot
.51193 .36808 Mdot
.52834 .36465 Mdot
.64312 .26018 Mdot
.70948 .38786 Mdot
.35979 .34695 Mdot
.4831 .31693 Mdot
.24392 .66287 Mdot
.72577 .50192 Mdot
.7061 .47275 Mdot
.50003 .24762 Mdot
.49051 .34555 Mdot
.5619 .67015 Mdot
.67745 .50645 Mdot
.6758 .27113 Mdot
.62575 .47544 Mdot
.41568 .73909 Mdot
.31144 .46734 Mdot
.52028 .62709 Mdot
.69809 .44718 Mdot
.69254 .47529 Mdot
.64673 .46061 Mdot
.52243 .22742 Mdot
.55896 .65582 Mdot
.55934 .60177 Mdot
.50957 .65864 Mdot
.47078 .59934 Mdot
.53792 .63101 Mdot
.64025 .35852 Mdot
.56383 .42173 Mdot
.21957 .55978 Mdot
.52838 .58865 Mdot
.49832 .39381 Mdot
.49338 .6378 Mdot
.36802 .5969 Mdot
.51188 .59849 Mdot
.40441 .74219 Mdot
.51373 .3791 Mdot
.44457 .64362 Mdot
.49559 .30618 Mdot
.53307 .61797 Mdot
.33208 .57281 Mdot
.27725 .65502 Mdot
.58144 .79399 Mdot
.32632 .2864 Mdot
.69014 .44672 Mdot
.35789 .45562 Mdot
.51155 .40664 Mdot
.34727 .4139 Mdot
.51103 .5924 Mdot
.5092 .25465 Mdot
.53963 .24566 Mdot
.41273 .52441 Mdot
.57235 .65786 Mdot
.59884 .58358 Mdot
.65977 .46113 Mdot
.35046 .42805 Mdot
.67722 .5234 Mdot
.55085 .61832 Mdot
.34786 .58731 Mdot
.35394 .59309 Mdot
.68265 .38823 Mdot
.19355 .57013 Mdot
.59036 .51471 Mdot
.51429 .36769 Mdot
.37511 .37843 Mdot
.32953 .57376 Mdot
.77235 .45997 Mdot
.54511 .38604 Mdot
.54181 .35326 Mdot
.49761 .36125 Mdot
.51783 .63255 Mdot
.49976 .22835 Mdot
.22795 .59959 Mdot
.50958 .21483 Mdot
.52878 .61843 Mdot
.34464 .37868 Mdot
.50097 .21951 Mdot
.34225 .56481 Mdot
.5082 .33686 Mdot
.34971 .38602 Mdot
.53039 .63656 Mdot
.68282 .47945 Mdot
.47147 .7292 Mdot
.35792 .7414 Mdot
.21613 .47381 Mdot
.2161 .48345 Mdot
.706 .49262 Mdot
.16858 .4696 Mdot
.47637 .41166 Mdot
.69921 .56979 Mdot
.32851 .54195 Mdot
.54489 .58343 Mdot
.83442 .51636 Mdot
.36794 .40272 Mdot
.32858 .41867 Mdot
.53804 .63983 Mdot
.36572 .43471 Mdot
.53474 .67421 Mdot
.3624 .38364 Mdot
.28566 .3434 Mdot
.57825 .66843 Mdot
.3299 .4186 Mdot
.58824 .67625 Mdot
.54482 .60634 Mdot
.6547 .46586 Mdot
.3426 .43522 Mdot
.49947 .60535 Mdot
.45502 .16358 Mdot
.5331 .37765 Mdot
.52085 .22456 Mdot
.5157 .43143 Mdot
.49415 .38871 Mdot
.67659 .46098 Mdot
.56558 .68188 Mdot
.3654 .55944 Mdot
.67783 .48564 Mdot
.38785 .43175 Mdot
.36422 .55234 Mdot
.69061 .36943 Mdot
.68305 .44532 Mdot
.51277 .2244 Mdot
.36153 .55458 Mdot
.57644 .57125 Mdot
.32161 .41655 Mdot
.3765 .76767 Mdot
.51149 .21586 Mdot
.55473 .6672 Mdot
.31248 .38393 Mdot
.49577 .39457 Mdot
.54252 .65136 Mdot
.36075 .43316 Mdot
.52363 .23011 Mdot
.51159 .63158 Mdot
.50853 .64368 Mdot
.72193 .40705 Mdot
.70843 .30574 Mdot
.36621 .56364 Mdot
.70056 .44215 Mdot
.54886 .63254 Mdot
.37571 .59186 Mdot
.42975 .23641 Mdot
.49349 .65334 Mdot
.65236 .50095 Mdot
.60172 .71317 Mdot
.34896 .38202 Mdot
.49634 .34703 Mdot
.37107 .36994 Mdot
.34709 .60136 Mdot
.82846 .65498 Mdot
.49719 .2312 Mdot
.57439 .69794 Mdot
.5255 .57943 Mdot
.33551 .35587 Mdot
.69051 .47137 Mdot
.41692 .37607 Mdot
.56864 .62214 Mdot
.58852 .56579 Mdot
.53175 .66737 Mdot
.32494 .50057 Mdot
.65771 .48654 Mdot
.54542 .67435 Mdot
.49966 .55863 Mdot
.5378 .68617 Mdot
.33313 .58179 Mdot
.37466 .65963 Mdot
.49159 .63959 Mdot
.14797 .345 Mdot
.52537 .23737 Mdot
.32102 .40281 Mdot
.29321 .40741 Mdot
.47809 .24898 Mdot
.7958 .46427 Mdot
.68908 .46158 Mdot
.61678 .6489 Mdot
.35045 .41258 Mdot
.67936 .77243 Mdot
.17805 .43595 Mdot
.54086 .60851 Mdot
.57938 .62516 Mdot
.3648 .42239 Mdot
.35848 .44091 Mdot
.50635 .25171 Mdot
.52141 .59036 Mdot
.60569 .63441 Mdot
.38531 .41795 Mdot
.53072 .62911 Mdot
.63449 .62363 Mdot
.53857 .38176 Mdot
.6552 .4573 Mdot
.50562 .33987 Mdot
.54243 .36418 Mdot
.76997 .56786 Mdot
.68086 .37863 Mdot
.52663 .35888 Mdot
.54945 .34412 Mdot
.40848 .74919 Mdot
.58289 .72687 Mdot
.33239 .58707 Mdot
.1927 .50051 Mdot
.32854 .40342 Mdot
.55908 .65363 Mdot
.7073 .48654 Mdot
.74867 .54293 Mdot
.40218 .31166 Mdot
.7323 .34986 Mdot
.56065 .61341 Mdot
.33143 .41475 Mdot
.52077 .22204 Mdot
.58058 .66638 Mdot
.34614 .62783 Mdot
.53202 .66031 Mdot
.31742 .39775 Mdot
.79644 .56792 Mdot
.60166 .72207 Mdot
.38564 .47314 Mdot
.69177 .42899 Mdot
.50674 .66193 Mdot
.69239 .45174 Mdot
.49849 .38619 Mdot
.37533 .59032 Mdot
.3602 .56043 Mdot
.51312 .65139 Mdot
.76383 .45 Mdot
.51189 .5136 Mdot
.54702 .60668 Mdot
.53036 .60269 Mdot
.50415 .23053 Mdot
.53158 .60264 Mdot
.5274 .57958 Mdot
.49797 .63985 Mdot
.49409 .66863 Mdot
.49371 .34431 Mdot
.57177 .75672 Mdot
.48702 .64918 Mdot
.52724 .71743 Mdot
.5361 .3811 Mdot
.60898 .66078 Mdot
.53749 .35318 Mdot
.1722 .54934 Mdot
.52994 .34857 Mdot
.36327 .56346 Mdot
.30886 .39163 Mdot
.60762 .57905 Mdot
.64347 .45384 Mdot
.5398 .3415 Mdot
.3552 .58103 Mdot
.52258 .37811 Mdot
.36521 .37614 Mdot
.49011 .82613 Mdot
.62572 .47675 Mdot
.41777 .4652 Mdot
.55137 .50714 Mdot
.65203 .28143 Mdot
.35863 .39053 Mdot
.65443 .47656 Mdot
.61347 .71134 Mdot
.49935 .63966 Mdot
.35149 .55497 Mdot
.53072 .64692 Mdot
.49704 .34146 Mdot
.32809 .40875 Mdot
.22801 .50384 Mdot
.36317 .56015 Mdot
.6656 .80068 Mdot
.32666 .38374 Mdot
.58712 .62666 Mdot
.54522 .36396 Mdot
.54435 .83476 Mdot
.52881 .34659 Mdot
.48874 .76633 Mdot
.71195 .50406 Mdot
.80868 .57678 Mdot
.6661 .47176 Mdot
.67396 .25876 Mdot
.15491 .61241 Mdot
.19803 .42024 Mdot
.68654 .48763 Mdot
.38195 .4614 Mdot
.53507 .62149 Mdot
.49074 .6288 Mdot
.48235 .69152 Mdot
.70202 .43838 Mdot
.54666 .63086 Mdot
.50596 .21982 Mdot
.603 .40986 Mdot
.27528 .57522 Mdot
.3548 .45793 Mdot
.54334 .67732 Mdot
.53766 .37688 Mdot
.49083 .39607 Mdot
.50396 .21689 Mdot
.53941 .39144 Mdot
.54736 .60258 Mdot
.66804 .47741 Mdot
.43244 .52292 Mdot
.34343 .57719 Mdot
.3108 .24467 Mdot
.38906 .5656 Mdot
.36505 .45678 Mdot
.48683 .59502 Mdot
.35464 .40581 Mdot
.87087 .51925 Mdot
.49731 .62461 Mdot
.69065 .48077 Mdot
.51073 .64095 Mdot
.49985 .64952 Mdot
.49038 .62338 Mdot
.38345 .40848 Mdot
.29645 .3832 Mdot
.52848 .63165 Mdot
.49847 .36847 Mdot
.22053 .52237 Mdot
.5931 .60986 Mdot
.39479 .43142 Mdot
.40386 .71343 Mdot
.65507 .29848 Mdot
.7124 .44305 Mdot
.35498 .42574 Mdot
.67691 .46836 Mdot
.67397 .43055 Mdot
.67675 .46089 Mdot
.21264 .57849 Mdot
.57675 .53622 Mdot
.78822 .30885 Mdot
.76705 .65565 Mdot
.73115 .56057 Mdot
.71736 .4748 Mdot
.43674 .26922 Mdot
.70346 .47867 Mdot
.68429 .46037 Mdot
.54965 .11924 Mdot
.70156 .48696 Mdot
.57298 .64866 Mdot
.58468 .61126 Mdot
.60914 .33594 Mdot
.43053 .76404 Mdot
.51744 .59487 Mdot
.54518 .63568 Mdot
.37812 .58255 Mdot
.45606 .60282 Mdot
.49238 .22498 Mdot
.72809 .37203 Mdot
.5242 .2752 Mdot
.52562 .64967 Mdot
.5417 .63524 Mdot
.51297 .69387 Mdot
.15751 .62966 Mdot
.75989 .5267 Mdot
.70755 .4967 Mdot
.60403 .58918 Mdot
.2479 .32347 Mdot
.58429 .62334 Mdot
.56558 .67284 Mdot
.51228 .62529 Mdot
.34982 .41402 Mdot
.64186 .50124 Mdot
.59476 .57964 Mdot
.6341 .2976 Mdot
.54027 .61632 Mdot
.47408 .40597 Mdot
.38899 .55511 Mdot
.56255 .66524 Mdot
.64757 .46302 Mdot
.51012 .60392 Mdot
.69765 .44903 Mdot
.66119 .45286 Mdot
.48493 .67059 Mdot
.21808 .59353 Mdot
.64069 .48498 Mdot
.52264 .62013 Mdot
.35859 .41729 Mdot
.18912 .40699 Mdot
.55799 .66571 Mdot
.37185 .58723 Mdot
.56454 .61977 Mdot
.33341 .57937 Mdot
.52869 .61036 Mdot
.51195 .21496 Mdot
.65854 .61808 Mdot
.33648 .41209 Mdot
.33679 .52664 Mdot
.37095 .43479 Mdot
.68714 .40399 Mdot
.66688 .50636 Mdot
.49062 .2305 Mdot
.80253 .40895 Mdot
.5052 .22952 Mdot
.47202 .72821 Mdot
.38633 .28108 Mdot
.52628 .38473 Mdot
.65849 .44833 Mdot
.4252 .64387 Mdot
.39034 .44353 Mdot
.38695 .42951 Mdot
.35009 .44765 Mdot
.84596 .59906 Mdot
.82581 .45655 Mdot
.52346 .63624 Mdot
.37853 .78375 Mdot
.68363 .67521 Mdot
.51486 .68038 Mdot
.55302 .69116 Mdot
.31627 .39829 Mdot
.51299 .6688 Mdot
.47476 .47089 Mdot
.34501 .39528 Mdot
.35636 .57476 Mdot
.68603 .45433 Mdot
.33656 .58576 Mdot
.39654 .37395 Mdot
.57082 .42314 Mdot
.34362 .38676 Mdot
.49437 .66324 Mdot
.51662 .64363 Mdot
.68335 .44243 Mdot
.66312 .41969 Mdot
.65557 .4588 Mdot
.36544 .54994 Mdot
.33837 .40072 Mdot
.74915 .52875 Mdot
.56374 .6311 Mdot
.6721 .4888 Mdot
.56923 .36807 Mdot
.55954 .62849 Mdot
.50672 .38849 Mdot
.56043 .60863 Mdot
.68721 .49174 Mdot
.53176 .60307 Mdot
.6684 .47502 Mdot
.36562 .40605 Mdot
.58182 .61994 Mdot
.54086 .63952 Mdot
.61049 .78899 Mdot
.35081 .56627 Mdot
.66887 .50631 Mdot
.518 .47763 Mdot
.57921 .60964 Mdot
.3384 .62193 Mdot
.52947 .68108 Mdot
.6091 .68445 Mdot
.59043 .67441 Mdot
.50684 .22074 Mdot
.48739 .61766 Mdot
.55572 .66749 Mdot
.58428 .75056 Mdot
.70331 .71542 Mdot
.65494 .52427 Mdot
.51595 .33108 Mdot
.64825 .46242 Mdot
.31739 .41336 Mdot
.33876 .43909 Mdot
.37927 .4038 Mdot
.45656 .7715 Mdot
.52679 .70141 Mdot
.54308 .66794 Mdot
.54468 .3497 Mdot
.36138 .5692 Mdot
.67511 .49585 Mdot
.36545 .57332 Mdot
.73252 .37502 Mdot
.36011 .54938 Mdot
.50044 .22259 Mdot
.32818 .50348 Mdot
.68281 .55122 Mdot
.37813 .57712 Mdot
.65506 .45882 Mdot
.33521 .4822 Mdot
.53609 .58303 Mdot
.30131 .31832 Mdot
.34896 .58821 Mdot
.8131 .66801 Mdot
.53511 .6818 Mdot
.44186 .46982 Mdot
.53834 .36606 Mdot
.33571 .56993 Mdot
.49397 .37316 Mdot
.49959 .61368 Mdot
.59862 .24943 Mdot
.69696 .47855 Mdot
.50254 .32938 Mdot
.48767 .62072 Mdot
.33581 .5818 Mdot
.33128 .38862 Mdot
.57569 .48219 Mdot
.50273 .39375 Mdot
.55753 .7884 Mdot
.358 .63569 Mdot
.34002 .39972 Mdot
.73473 .28335 Mdot
.50222 .34995 Mdot
.50231 .67139 Mdot
.61498 .57012 Mdot
.53076 .59289 Mdot
.31973 .423 Mdot
.34663 .42815 Mdot
.605 .37911 Mdot
.51273 .64091 Mdot
.53343 .68163 Mdot
.65334 .51399 Mdot
.35136 .39469 Mdot
.66136 .46653 Mdot
.65342 .44923 Mdot
.36241 .42125 Mdot
.66722 .46 Mdot
.35882 .55223 Mdot
.5936 .41494 Mdot
.50419 .34819 Mdot
.50058 .37395 Mdot
.32273 .3941 Mdot
.35033 .37009 Mdot
.35509 .40343 Mdot
.55954 .60869 Mdot
.66435 .4971 Mdot
.51309 .61222 Mdot
.49106 .64249 Mdot
.72294 .49392 Mdot
.69136 .50049 Mdot
.5066 .61392 Mdot
.36024 .49996 Mdot
.371 .53846 Mdot
.33161 .41934 Mdot
.52352 .35042 Mdot
.68346 .76553 Mdot
.54628 .35885 Mdot
.53817 .67912 Mdot
.32311 .32281 Mdot
.68031 .499 Mdot
.34557 .56193 Mdot
.37123 .61695 Mdot
.35242 .55676 Mdot
.49326 .33161 Mdot
.64377 .45849 Mdot
.6871 .37006 Mdot
.53477 .67692 Mdot
.4845 .45489 Mdot
.42315 .65235 Mdot
.64743 .33907 Mdot
.5244 .35592 Mdot
.55295 .63149 Mdot
.50647 .22795 Mdot
.66157 .56862 Mdot
.53527 .65995 Mdot
.5003 .60034 Mdot
.28746 .47724 Mdot
.5226 .71734 Mdot
.71751 .45386 Mdot
.74623 .40735 Mdot
.56737 .59517 Mdot
.73636 .49512 Mdot
.69134 .18986 Mdot
.52716 .67723 Mdot
.54507 .62354 Mdot
.56623 .64916 Mdot
.50206 .6239 Mdot
.72195 .49057 Mdot
.39582 .53217 Mdot
.54467 .35892 Mdot
.51657 .44641 Mdot
.50644 .35091 Mdot
.32596 .42106 Mdot
.44504 .47291 Mdot
.6575 .4507 Mdot
.34938 .55748 Mdot
.45698 .81454 Mdot
.74753 .39242 Mdot
.36292 .38952 Mdot
.77601 .52579 Mdot
.34377 .58189 Mdot
.5462 .58411 Mdot
.38672 .57951 Mdot
.35522 .44263 Mdot
.50713 .35964 Mdot
.58207 .60802 Mdot
.71149 .47921 Mdot
.64827 .49258 Mdot
.55352 .62819 Mdot
.22541 .35778 Mdot
.49431 .38588 Mdot
.56108 .40761 Mdot
.51843 .63069 Mdot
.50152 .59888 Mdot
.67001 .4525 Mdot
.34357 .42443 Mdot
.38898 .24843 Mdot
.35128 .57358 Mdot
.49963 .67977 Mdot
.50319 .60929 Mdot
.72814 .37964 Mdot
.51086 .33521 Mdot
.51606 .24792 Mdot
.51561 .63398 Mdot
.68747 .379 Mdot
.51411 .6338 Mdot
.51296 .56196 Mdot
.35765 .41003 Mdot
.56536 .58383 Mdot
.57445 .61734 Mdot
.43431 .63893 Mdot
.49709 .35499 Mdot
.68943 .47543 Mdot
.67833 .51724 Mdot
.51961 .24792 Mdot
.5106 .38745 Mdot
.50645 .61075 Mdot
.49594 .34536 Mdot
.49006 .62585 Mdot
.53137 .63242 Mdot
.52365 .35572 Mdot
.66165 .46581 Mdot
.42265 .37032 Mdot
.54998 .75147 Mdot
.50505 .63132 Mdot
.55753 .59597 Mdot
.44191 .76558 Mdot
.78793 .36724 Mdot
.57223 .61965 Mdot
.67735 .50218 Mdot
.55705 .63272 Mdot
.50124 .38326 Mdot
.35866 .54799 Mdot
.68631 .48304 Mdot
.33706 .37235 Mdot
.36701 .40803 Mdot
.5026 .30252 Mdot
.49834 .22664 Mdot
.56401 .59915 Mdot
.62581 .51115 Mdot
.69927 .49576 Mdot
.48553 .17628 Mdot
.32041 .40594 Mdot
.3318 .56633 Mdot
.50624 .64145 Mdot
.56841 .48591 Mdot
.5407 .34621 Mdot
.14654 .34753 Mdot
.67116 .36938 Mdot
.37393 .60656 Mdot
.75339 .3604 Mdot
.51084 .22829 Mdot
.57575 .65183 Mdot
.37059 .59649 Mdot
.37261 .40152 Mdot
.49231 .62572 Mdot
.5005 .69985 Mdot
.43508 .39424 Mdot
.33127 .44727 Mdot
.49518 .34762 Mdot
.36706 .38241 Mdot
.36357 .60651 Mdot
.5011 .22167 Mdot
.64879 .48018 Mdot
.54823 .67138 Mdot
.59406 .56071 Mdot
.32314 .40476 Mdot
.51452 .2149 Mdot
.51999 .62664 Mdot
.64547 .48749 Mdot
.37102 .4284 Mdot
.52396 .653 Mdot
.70584 .56236 Mdot
.7121 .43281 Mdot
.33194 .39936 Mdot
.51498 .58307 Mdot
.62529 .64247 Mdot
.32836 .37872 Mdot
.32063 .39142 Mdot
.54625 .63128 Mdot
.35898 .55335 Mdot
.58092 .63924 Mdot
.53784 .3587 Mdot
.29631 .38315 Mdot
.50456 .38242 Mdot
.4077 .63578 Mdot
.48247 .6038 Mdot
.66664 .28042 Mdot
.69241 .44151 Mdot
.32724 .59336 Mdot
.63023 .74523 Mdot
.51395 .5885 Mdot
.177 .51123 Mdot
.40813 .53034 Mdot
.34862 .21148 Mdot
.23542 .68991 Mdot
.35833 .58755 Mdot
.52032 .38091 Mdot
.54567 .62376 Mdot
.54994 .39132 Mdot
.37606 .57716 Mdot
.41634 .64386 Mdot
.51736 .58241 Mdot
.65727 .48322 Mdot
.53489 .61961 Mdot
.69192 .44728 Mdot
.56152 .62699 Mdot
.57468 .70197 Mdot
.34227 .53117 Mdot
.49194 .76716 Mdot
.54 .58363 Mdot
.48193 .82817 Mdot
.5555 .48014 Mdot
.34907 .58537 Mdot
.51631 .61716 Mdot
.51494 .24046 Mdot
.50384 .40128 Mdot
.299 .69613 Mdot
.35211 .40996 Mdot
.53135 .36273 Mdot
.67707 .4524 Mdot
.35817 .36596 Mdot
.52444 .23746 Mdot
.60152 .56097 Mdot
.34057 .59359 Mdot
.52613 .38334 Mdot
.55822 .66702 Mdot
.54196 .68039 Mdot
.34526 .50788 Mdot
.60814 .19481 Mdot
.63307 .48988 Mdot
.64124 .8025 Mdot
.7211 .46626 Mdot
.35588 .5646 Mdot
.35739 .40762 Mdot
.57661 .63662 Mdot
.5365 .65328 Mdot
.33029 .43272 Mdot
.67742 .50448 Mdot
.32043 .44607 Mdot
.77639 .55154 Mdot
.3868 .39436 Mdot
.43239 .71642 Mdot
.69061 .48567 Mdot
.43809 .7198 Mdot
.35955 .60743 Mdot
.215 .60583 Mdot
.34248 .69598 Mdot
.53965 .36939 Mdot
.4265 .71155 Mdot
.68016 .49633 Mdot
.52105 .64042 Mdot
.51433 .22583 Mdot
.49951 .23844 Mdot
.68524 .45052 Mdot
.36363 .42495 Mdot
.33634 .57868 Mdot
.5419 .62497 Mdot
.6842 .33686 Mdot
.57526 .29931 Mdot
.37569 .37844 Mdot
.51412 .55364 Mdot
.49535 .37029 Mdot
.56309 .61104 Mdot
.36803 .59129 Mdot
.52537 .3695 Mdot
.51277 .26009 Mdot
.59858 .41273 Mdot
.50599 .64432 Mdot
.68718 .39051 Mdot
.51616 .38682 Mdot
.74434 .28793 Mdot
.53968 .64424 Mdot
.50186 .35021 Mdot
.55999 .71733 Mdot
.59815 .26247 Mdot
.47903 .50254 Mdot
.18391 .43967 Mdot
.33801 .44904 Mdot
.36799 .4118 Mdot
.55203 .20363 Mdot
.32987 .54148 Mdot
.53306 .38252 Mdot
.5025 .21979 Mdot
.35075 .66653 Mdot
.49401 .3673 Mdot
.56738 .67241 Mdot
.52908 .68064 Mdot
.76535 .56359 Mdot
.49021 .47719 Mdot
.51691 .21442 Mdot
.60979 .52315 Mdot
.53952 .59707 Mdot
.57727 .58338 Mdot
.54607 .64857 Mdot
.71356 .49191 Mdot
.49235 .38833 Mdot
.49766 .84714 Mdot
.49085 .37967 Mdot
.69396 .34245 Mdot
.32843 .40393 Mdot
.37803 .37922 Mdot
.55981 .66802 Mdot
.69722 .28079 Mdot
.28553 .68612 Mdot
.56334 .60265 Mdot
.39118 .60676 Mdot
.37358 .63866 Mdot
.59119 .59835 Mdot
.68064 .51904 Mdot
.57774 .55641 Mdot
.7294 .47235 Mdot
.52519 .36486 Mdot
.36181 .58794 Mdot
.36661 .53867 Mdot
.52878 .378 Mdot
.5449 .66642 Mdot
.40485 .6017 Mdot
.5322 .66537 Mdot
.51928 .6365 Mdot
.7228 .36398 Mdot
.33295 .55856 Mdot
.35638 .40028 Mdot
.36081 .56001 Mdot
.68482 .46187 Mdot
.46123 .10096 Mdot
.36896 .57838 Mdot
.62159 .44555 Mdot
.38295 .49293 Mdot
.42968 .71238 Mdot
.64694 .48793 Mdot
.37789 .56552 Mdot
.49146 .3587 Mdot
.34284 .21256 Mdot
.76926 .3297 Mdot
.54846 .3667 Mdot
.53614 .64795 Mdot
.66402 .44587 Mdot
.70974 .49043 Mdot
.54865 .34552 Mdot
.65191 .47912 Mdot
.5191 .57307 Mdot
.5107 .63661 Mdot
.53289 .3826 Mdot
.60075 .33395 Mdot
.49232 .39126 Mdot
.59509 .46117 Mdot
.51705 .62163 Mdot
.68834 .48185 Mdot
.51049 .57119 Mdot
.64053 .50696 Mdot
.50056 .2458 Mdot
.49206 .61892 Mdot
.34192 .56085 Mdot
.48821 .4679 Mdot
.33171 .40164 Mdot
.3297 .32456 Mdot
.67594 .44385 Mdot
.55031 .40605 Mdot
.65462 .46529 Mdot
.68418 .4374 Mdot
.54259 .38835 Mdot
.69343 .46838 Mdot
.54414 .62351 Mdot
.38262 .4773 Mdot
.70321 .45873 Mdot
.51117 .37195 Mdot
.33765 .57388 Mdot
.66489 .4622 Mdot
.35368 .36258 Mdot
.51863 .64772 Mdot
.35343 .38306 Mdot
.35283 .61287 Mdot
.65564 .45128 Mdot
.37557 .5612 Mdot
.32176 .40618 Mdot
.34651 .59815 Mdot
.22259 .47609 Mdot
.48692 .35469 Mdot
.72553 .34517 Mdot
.57699 .74189 Mdot
.71085 .47823 Mdot
.38749 .42934 Mdot
.5755 .628 Mdot
.51423 .64707 Mdot
.3683 .60364 Mdot
.70897 .49026 Mdot
.19707 .39865 Mdot
.62009 .64919 Mdot
.5938 .39226 Mdot
.4954 .33971 Mdot
.68382 .77781 Mdot
.62925 .39057 Mdot
.33283 .24079 Mdot
.58852 .66932 Mdot
.5114 .22804 Mdot
.53388 .66961 Mdot
.58485 .79445 Mdot
.35328 .5476 Mdot
.42794 .3031 Mdot
.57771 .68622 Mdot
.34816 .40354 Mdot
.56008 .63778 Mdot
.37266 .77566 Mdot
.57027 .55543 Mdot
.37954 .57927 Mdot
.48212 .3423 Mdot
.64268 .45477 Mdot
.34373 .57866 Mdot
.36649 .40066 Mdot
.38191 .67956 Mdot
.52642 .57847 Mdot
.54762 .59976 Mdot
.3791 .43752 Mdot
.65532 .48171 Mdot
.32406 .4199 Mdot
.50414 .34851 Mdot
.36599 .57787 Mdot
.50179 .62895 Mdot
.56452 .57827 Mdot
.35216 .3534 Mdot
.48958 .38527 Mdot
.36078 .3701 Mdot
.51103 .33721 Mdot
.51169 .22698 Mdot
.55447 .58943 Mdot
.37904 .43547 Mdot
.52406 .68192 Mdot
.62604 .76092 Mdot
.73301 .36489 Mdot
.7071 .69983 Mdot
.3569 .39787 Mdot
.41802 .7268 Mdot
.51281 .38181 Mdot
.52411 .34094 Mdot
.79133 .62977 Mdot
.27507 .65565 Mdot
.29892 .45716 Mdot
.4752 .81657 Mdot
.5051 .34787 Mdot
.5065 .37999 Mdot
.37406 .40477 Mdot
.69356 .46248 Mdot
.72951 .44557 Mdot
.37982 .37803 Mdot
.50551 .7684 Mdot
.67516 .49568 Mdot
.17536 .49282 Mdot
.31602 .39187 Mdot
.57858 .68696 Mdot
.50342 .20957 Mdot
.35901 .59165 Mdot
.50823 .76726 Mdot
.43449 .7982 Mdot
.57418 .65169 Mdot
.80615 .4644 Mdot
.34902 .42216 Mdot
.4266 .44149 Mdot
.18411 .56628 Mdot
.50175 .59513 Mdot
.55961 .64653 Mdot
.5478 .66134 Mdot
.34045 .54691 Mdot
.62155 .75154 Mdot
.57328 .65498 Mdot
.47277 .75619 Mdot
.57507 .66598 Mdot
.3431 .73381 Mdot
.36179 .56097 Mdot
.56654 .5295 Mdot
.35163 .45248 Mdot
.6433 .31232 Mdot
.48552 .69654 Mdot
.50145 .34578 Mdot
.40429 .43361 Mdot
.5102 .35653 Mdot
.25293 .64966 Mdot
.34342 .69421 Mdot
.71827 .48486 Mdot
.56047 .61303 Mdot
.34315 .44691 Mdot
.67433 .44274 Mdot
.38613 .2714 Mdot
.53585 .11087 Mdot
.4874 .36556 Mdot
.84448 .43108 Mdot
.52477 .34074 Mdot
.50136 .24472 Mdot
.67546 .44995 Mdot
.73356 .51366 Mdot
.48366 .45601 Mdot
.66516 .46408 Mdot
.49839 .2946 Mdot
.68965 .51768 Mdot
.42132 .71888 Mdot
.66198 .43768 Mdot
.51394 .3745 Mdot
.47852 .364 Mdot
.53413 .71053 Mdot
.57269 .62399 Mdot
.53252 .44053 Mdot
.55981 .72408 Mdot
.56777 .6172 Mdot
.34507 .39542 Mdot
.75078 .32323 Mdot
.32337 .36635 Mdot
.70459 .46961 Mdot
.52128 .33347 Mdot
.55999 .64421 Mdot
.50632 .62902 Mdot
.5046 .66961 Mdot
.60961 .79284 Mdot
.17714 .48936 Mdot
.52812 .63354 Mdot
.48239 .66285 Mdot
.36444 .40141 Mdot
.38773 .54112 Mdot
.52628 .81135 Mdot
.35161 .67585 Mdot
.51624 .65985 Mdot
.35116 .56288 Mdot
.34718 .54636 Mdot
.57932 .59344 Mdot
.6712 .3094 Mdot
.38081 .46741 Mdot
.55863 .6666 Mdot
.33483 .70179 Mdot
.33687 .36347 Mdot
.50877 .21365 Mdot
.32303 .40388 Mdot
.64912 .45757 Mdot
.50156 .23287 Mdot
.37692 .42522 Mdot
.71818 .52683 Mdot
.51761 .25077 Mdot
.6037 .27434 Mdot
.36554 .54995 Mdot
.54262 .65187 Mdot
.6643 .52197 Mdot
.32643 .43058 Mdot
.52843 .3812 Mdot
.6748 .47702 Mdot
.48929 .396 Mdot
.37521 .52867 Mdot
.44369 .69355 Mdot
.49761 .23002 Mdot
.50897 .34183 Mdot
.59893 .41401 Mdot
.3531 .56096 Mdot
.54395 .38431 Mdot
.68506 .2728 Mdot
.59383 .6237 Mdot
.27688 .70033 Mdot
.55443 .60563 Mdot
.25156 .31311 Mdot
.52853 .3432 Mdot
.50646 .25583 Mdot
.54233 .67075 Mdot
.32682 .38293 Mdot
.57788 .70472 Mdot
.52951 .66092 Mdot
.35582 .37311 Mdot
.52332 .63725 Mdot
.36837 .59231 Mdot
.72839 .45277 Mdot
.41512 .53247 Mdot
.75725 .71413 Mdot
.34865 .59797 Mdot
.51253 .19562 Mdot
.56913 .6164 Mdot
.23779 .53085 Mdot
.66372 .46687 Mdot
.4993 .59994 Mdot
.81118 .55016 Mdot
.69627 .45833 Mdot
.67414 .46791 Mdot
.52481 .60458 Mdot
.54269 .37883 Mdot
.32625 .38939 Mdot
.35319 .55974 Mdot
.39975 .19691 Mdot
.52421 .65678 Mdot
.54955 .63611 Mdot
.34336 .58112 Mdot
.5056 .38142 Mdot
.50442 .6245 Mdot
.37116 .29712 Mdot
.42601 .17282 Mdot
.54271 .36358 Mdot
.59376 .61089 Mdot
.32363 .76489 Mdot
.66734 .42604 Mdot
.8157 .39343 Mdot
.32058 .54351 Mdot
.35839 .42239 Mdot
.58963 .68089 Mdot
.17783 .30851 Mdot
.35785 .59068 Mdot
.65324 .33556 Mdot
.52754 .62883 Mdot
.5676 .63607 Mdot
.65565 .49745 Mdot
.5109 .6095 Mdot
.69354 .49155 Mdot
.77423 .70117 Mdot
.63192 .83468 Mdot
.65763 .46331 Mdot
.70641 .47724 Mdot
.6645 .53734 Mdot
.56957 .78876 Mdot
.68236 .45352 Mdot
.50681 .58661 Mdot
.20609 .49378 Mdot
.47712 .66058 Mdot
.35098 .60655 Mdot
.35655 .61763 Mdot
.74306 .47676 Mdot
.68288 .23917 Mdot
.61466 .62489 Mdot
.46622 .6877 Mdot
.51784 .51568 Mdot
.53002 .35055 Mdot
.50674 .65517 Mdot
.49827 .22559 Mdot
.38019 .39903 Mdot
.53417 .55232 Mdot
.54101 .65587 Mdot
.69788 .45003 Mdot
.33651 .55022 Mdot
.51122 .40523 Mdot
.54434 .63617 Mdot
.31327 .43315 Mdot
.35408 .57411 Mdot
.70596 .46453 Mdot
.65054 .41743 Mdot
.33553 .5946 Mdot
.53672 .56842 Mdot
.56763 .62291 Mdot
.51904 .62725 Mdot
.49814 .70931 Mdot
.53222 .37531 Mdot
.36422 .36096 Mdot
.50637 .58292 Mdot
.72043 .37281 Mdot
.43404 .4627 Mdot
.55397 .57713 Mdot
.66853 .50015 Mdot
.54488 .35604 Mdot
.51309 .25024 Mdot
.39622 .67146 Mdot
.50881 .64994 Mdot
.17911 .49415 Mdot
.76477 .53609 Mdot
.50422 .23737 Mdot
.70829 .44953 Mdot
.34827 .5591 Mdot
.54031 .60065 Mdot
.2104 .53457 Mdot
.53468 .68052 Mdot
.59095 .72022 Mdot
.35399 .42259 Mdot
.52381 .34759 Mdot
.40546 .17585 Mdot
.37993 .39737 Mdot
.67606 .46815 Mdot
.17151 .41012 Mdot
.65775 .50933 Mdot
.63485 .47123 Mdot
.22822 .60679 Mdot
.5252 .36141 Mdot
.16372 .32736 Mdot
.78251 .35018 Mdot
.54883 .68369 Mdot
.49784 .38364 Mdot
.67398 .44854 Mdot
.55862 .61115 Mdot
.70321 .49042 Mdot
.6372 .48733 Mdot
.49408 .63782 Mdot
.56971 .62986 Mdot
.48932 .76 Mdot
.16497 .52219 Mdot
.35863 .55568 Mdot
.67223 .50524 Mdot
.73886 .56938 Mdot
.5754 .65053 Mdot
.53541 .67703 Mdot
.42128 .4232 Mdot
.37935 .5788 Mdot
.63597 .65079 Mdot
.51659 .63496 Mdot
.81645 .55679 Mdot
.56121 .59691 Mdot
.65014 .5185 Mdot
.54476 .37276 Mdot
.66901 .31407 Mdot
.31743 .4179 Mdot
.64787 .49699 Mdot
.33367 .57636 Mdot
.68527 .51316 Mdot
.80245 .58696 Mdot
.52108 .35955 Mdot
.68719 .49179 Mdot
.32832 .37219 Mdot
.51054 .3628 Mdot
.54142 .36318 Mdot
.2196 .52063 Mdot
.36686 .37089 Mdot
.37436 .5528 Mdot
.50372 .35831 Mdot
.70076 .5711 Mdot
.51727 .37269 Mdot
.75098 .56885 Mdot
.57649 .61281 Mdot
.46987 .74923 Mdot
.63703 .3801 Mdot
.47937 .68354 Mdot
.49308 .39318 Mdot
.37304 .56884 Mdot
.52018 .59882 Mdot
.65226 .48287 Mdot
.36879 .58104 Mdot
.49061 .3219 Mdot
.33711 .3705 Mdot
.7018 .44757 Mdot
.54493 .36635 Mdot
.6893 .49377 Mdot
.43119 .67462 Mdot
.30433 .34991 Mdot
.52238 .51907 Mdot
.46895 .45301 Mdot
.50681 .67537 Mdot
.74424 .4828 Mdot
.57674 .60515 Mdot
.53804 .65867 Mdot
.33126 .39928 Mdot
.45681 .77063 Mdot
.66182 .46426 Mdot
.42095 .16709 Mdot
.51613 .34072 Mdot
.75489 .421 Mdot
.62591 .62544 Mdot
.49543 .6156 Mdot
.70155 .45786 Mdot
.63682 .49058 Mdot
.70497 .71371 Mdot
.33173 .43267 Mdot
.47498 .66728 Mdot
.48168 .60014 Mdot
.56299 .70436 Mdot
.52872 .34203 Mdot
.38681 .31033 Mdot
.35171 .43263 Mdot
.81465 .33127 Mdot
.33382 .42089 Mdot
.2663 .48849 Mdot
.69432 .46869 Mdot
.34921 .55031 Mdot
.53859 .67763 Mdot
.53265 .75034 Mdot
.71693 .49587 Mdot
.40488 .45759 Mdot
.34284 .56295 Mdot
.416 .33683 Mdot
.52848 .3618 Mdot
.5555 .58381 Mdot
.49815 .64849 Mdot
.51606 .61282 Mdot
.54675 .6102 Mdot
.51356 .33159 Mdot
.56664 .67291 Mdot
.49636 .33607 Mdot
.6988 .55939 Mdot
.81656 .56889 Mdot
.32009 .42919 Mdot
.29192 .67972 Mdot
.71315 .47363 Mdot
.71054 .58497 Mdot
.63492 .60843 Mdot
.73069 .36171 Mdot
.22367 .49821 Mdot
.57071 .60277 Mdot
.36667 .42422 Mdot
.37478 .78013 Mdot
.34284 .44614 Mdot
.71234 .81086 Mdot
.4076 .61093 Mdot
.17707 .44168 Mdot
.55698 .61229 Mdot
.35509 .35519 Mdot
.63037 .62691 Mdot
.58579 .59946 Mdot
.41115 .60222 Mdot
.61413 .44824 Mdot
.61634 .33223 Mdot
.33045 .57196 Mdot
.51977 .64978 Mdot
.64105 .45565 Mdot
.54376 .62234 Mdot
.53308 .67419 Mdot
.56526 .6106 Mdot
.52153 .4068 Mdot
.58278 .66712 Mdot
.57939 .64541 Mdot
.61786 .19474 Mdot
.41716 .74416 Mdot
.3568 .38059 Mdot
.73881 .68041 Mdot
.36134 .56969 Mdot
.69009 .44512 Mdot
.39887 .51891 Mdot
.53632 .36277 Mdot
.69229 .72698 Mdot
.55627 .60908 Mdot
.62452 .37837 Mdot
.54537 .36684 Mdot
.36686 .58497 Mdot
.52171 .24208 Mdot
.19806 .44823 Mdot
.32412 .43287 Mdot
.51448 .25355 Mdot
.33206 .40345 Mdot
.6383 .72274 Mdot
.69814 .45101 Mdot
.50016 .66483 Mdot
.49717 .36332 Mdot
.32895 .38489 Mdot
.4375 .77153 Mdot
.54995 .64977 Mdot
.35652 .39502 Mdot
.5034 .672 Mdot
.4133 .4726 Mdot
.36406 .48717 Mdot
.36888 .43798 Mdot
.47682 .36261 Mdot
.50537 .36647 Mdot
.35871 .55171 Mdot
.69158 .44465 Mdot
.67695 .50065 Mdot
.52311 .36739 Mdot
.82392 .41978 Mdot
.52662 .6622 Mdot
.56669 .61263 Mdot
.71017 .37205 Mdot
.55316 .62005 Mdot
.39633 .69732 Mdot
.49426 .22444 Mdot
.70539 .45456 Mdot
.54963 .61401 Mdot
.50386 .62623 Mdot
.5057 .64227 Mdot
.4336 .68159 Mdot
.32438 .40853 Mdot
.53932 .59753 Mdot
.36779 .6003 Mdot
.64485 .25818 Mdot
.57785 .62788 Mdot
.57972 .58852 Mdot
.68434 .49316 Mdot
.69338 .77744 Mdot
.53928 .36483 Mdot
.35134 .39027 Mdot
.32148 .38497 Mdot
.31321 .59367 Mdot
.71111 .44021 Mdot
.49334 .22093 Mdot
.46765 .22772 Mdot
.51459 .21939 Mdot
.34707 .58082 Mdot
.27522 .45382 Mdot
.32224 .44399 Mdot
.36466 .38765 Mdot
.48651 .34972 Mdot
.54652 .61253 Mdot
.56427 .60191 Mdot
.65657 .3356 Mdot
.52427 .59112 Mdot
.3399 .56726 Mdot
.52781 .38948 Mdot
.68127 .4922 Mdot
.3569 .59316 Mdot
.50332 .34149 Mdot
.65544 .48423 Mdot
.59214 .6187 Mdot
.59424 .63278 Mdot
.67271 .47318 Mdot
.66166 .45099 Mdot
.57053 .65162 Mdot
.58519 .19146 Mdot
.66589 .43822 Mdot
.68897 .48896 Mdot
.52677 .22288 Mdot
.32634 .43549 Mdot
.53259 .56343 Mdot
.497 .38392 Mdot
.51911 .6284 Mdot
.32955 .44 Mdot
.37885 .5734 Mdot
.6627 .47788 Mdot
.50663 .63296 Mdot
.52627 .64159 Mdot
.35002 .56263 Mdot
.3281 .57828 Mdot
.341 .58775 Mdot
.52481 .41341 Mdot
.53108 .61453 Mdot
.67928 .45439 Mdot
.52478 .3588 Mdot
.34693 .5465 Mdot
.38594 .56724 Mdot
.65149 .20934 Mdot
.57102 .65802 Mdot
.48505 .50527 Mdot
.41709 .11999 Mdot
.37351 .67934 Mdot
.50732 .25076 Mdot
.38632 .4186 Mdot
.45304 .73835 Mdot
.30278 .55997 Mdot
.49821 .38974 Mdot
.29228 .63816 Mdot
.32845 .5949 Mdot
.49158 .63987 Mdot
.55451 .59461 Mdot
.51234 .68766 Mdot
.35831 .57644 Mdot
.42428 .66845 Mdot
.70347 .49605 Mdot
.68219 .64634 Mdot
.36139 .56994 Mdot
.36885 .43768 Mdot
.37783 .43524 Mdot
.33488 .42191 Mdot
.56298 .59147 Mdot
.69642 .71686 Mdot
.71931 .56913 Mdot
.64453 .67708 Mdot
.53113 .36373 Mdot
.63898 .49726 Mdot
.22919 .504 Mdot
.67231 .46786 Mdot
.38049 .40885 Mdot
.35577 .57934 Mdot
.66448 .50335 Mdot
.51203 .39047 Mdot
.50358 .37935 Mdot
.33471 .37235 Mdot
.32347 .39843 Mdot
.33884 .38663 Mdot
.64388 .46572 Mdot
.69358 .46822 Mdot
.50131 .63622 Mdot
.66768 .48221 Mdot
.79853 .44942 Mdot
.3784 .60569 Mdot
.3726 .44098 Mdot
.51315 .38551 Mdot
.68459 .4457 Mdot
.54104 .65014 Mdot
.31061 .48355 Mdot
.4708 .32625 Mdot
.35664 .59968 Mdot
.2772 .3839 Mdot
.7794 .7446 Mdot
.50337 .65989 Mdot
.50225 .33886 Mdot
.66885 .2976 Mdot
.55198 .65683 Mdot
.35178 .41469 Mdot
.59756 .78565 Mdot
.51588 .2174 Mdot
.57968 .64215 Mdot
.50604 .59721 Mdot
.53935 .39196 Mdot
.37786 .50123 Mdot
.5004 .60853 Mdot
.63334 .40707 Mdot
.49333 .40167 Mdot
.35865 .43397 Mdot
.44979 .16232 Mdot
.39022 .40157 Mdot
.50339 .7778 Mdot
.50478 .2468 Mdot
.49759 .64466 Mdot
.3418 .39557 Mdot
.36436 .59817 Mdot
.3362 .39238 Mdot
.71464 .4614 Mdot
.34932 .38218 Mdot
.55375 .63493 Mdot
.6812 .45568 Mdot
.5129 .38798 Mdot
.7411 .40364 Mdot
.63005 .20707 Mdot
.32703 .38225 Mdot
.52643 .25069 Mdot
.57764 .64665 Mdot
.64983 .58104 Mdot
.57964 .70288 Mdot
.57385 .61907 Mdot
.51188 .35578 Mdot
.70268 .46061 Mdot
.49871 .33811 Mdot
.58386 .57928 Mdot
.77545 .66203 Mdot
.52657 .34433 Mdot
.60881 .29777 Mdot
.3447 .58193 Mdot
.50241 .7651 Mdot
.53271 .65598 Mdot
.50088 .35745 Mdot
.52947 .61539 Mdot
.68028 .5069 Mdot
.53857 .46671 Mdot
.66107 .26386 Mdot
.49688 .36588 Mdot
.21553 .35856 Mdot
.52887 .47744 Mdot
.56506 .5576 Mdot
.50387 .3512 Mdot
.66005 .73523 Mdot
.51479 .24496 Mdot
.35032 .57456 Mdot
.33918 .55125 Mdot
.34175 .59597 Mdot
.52741 .58946 Mdot
.55821 .54442 Mdot
.38109 .55783 Mdot
.49379 .40415 Mdot
.37797 .58813 Mdot
.4977 .75539 Mdot
.21349 .37458 Mdot
.34538 .59353 Mdot
.53236 .64832 Mdot
.5858 .59489 Mdot
.41845 .74719 Mdot
.36979 .43153 Mdot
.17702 .51625 Mdot
.77748 .46709 Mdot
.57553 .63639 Mdot
.60711 .56758 Mdot
.71441 .46809 Mdot
.70182 .30009 Mdot
.62123 .58871 Mdot
.35871 .49715 Mdot
.70217 .48258 Mdot
.33169 .4614 Mdot
.70136 .4497 Mdot
.50909 .6688 Mdot
.53235 .63129 Mdot
.73176 .4665 Mdot
.33204 .31844 Mdot
.58015 .24573 Mdot
.2902 .26661 Mdot
.67893 .50175 Mdot
.497 .35539 Mdot
.48996 .35658 Mdot
.52631 .35617 Mdot
.31743 .41493 Mdot
.65036 .4595 Mdot
.5352 .60898 Mdot
.36527 .4122 Mdot
.51997 .66298 Mdot
.50737 .36097 Mdot
.40014 .17806 Mdot
.68371 .49249 Mdot
.55542 .66803 Mdot
.76839 .32994 Mdot
.33447 .41546 Mdot
.35423 .56205 Mdot
.41998 .45965 Mdot
.36946 .3631 Mdot
.49178 .39179 Mdot
.68594 .42683 Mdot
.48824 .40999 Mdot
.40848 .54595 Mdot
.50713 .6904 Mdot
.54749 .57842 Mdot
.43748 .18097 Mdot
.70797 .26095 Mdot
.54451 .58799 Mdot
.36668 .39995 Mdot
.35085 .44231 Mdot
.50963 .64 Mdot
.6482 .47775 Mdot
.35859 .5441 Mdot
.35246 .60377 Mdot
.48713 .62603 Mdot
.48374 .45337 Mdot
.47959 .75604 Mdot
.50566 .61623 Mdot
.46131 .63354 Mdot
.34618 .36701 Mdot
.52284 .24198 Mdot
.67562 .37847 Mdot
.33661 .5613 Mdot
.52485 .62973 Mdot
.57137 .26511 Mdot
.69617 .48953 Mdot
.34593 .3839 Mdot
.52663 .38659 Mdot
.41709 .59728 Mdot
.31829 .38657 Mdot
.50978 .63914 Mdot
.50434 .62496 Mdot
.54144 .38889 Mdot
.65115 .51873 Mdot
.3577 .57963 Mdot
.36432 .41152 Mdot
.34642 .55083 Mdot
.6872 .46452 Mdot
.68183 .48884 Mdot
.46813 .62901 Mdot
.50814 .71362 Mdot
.32409 .38305 Mdot
.48306 .65134 Mdot
.38024 .42 Mdot
.35577 .5131 Mdot
.53739 .34128 Mdot
.49553 .60367 Mdot
.64239 .44745 Mdot
.5125 .35959 Mdot
.5693 .64276 Mdot
.48773 .18755 Mdot
.49476 .62569 Mdot
.36693 .36186 Mdot
.78342 .65299 Mdot
.37671 .57265 Mdot
.69617 .40842 Mdot
.43997 .61096 Mdot
.55317 .62156 Mdot
.38268 .42053 Mdot
.59811 .66942 Mdot
.53715 .35368 Mdot
.70108 .47169 Mdot
.86925 .52236 Mdot
.514 .37057 Mdot
.54059 .62365 Mdot
.36684 .57957 Mdot
.63214 .4751 Mdot
.50275 .22474 Mdot
.67512 .37308 Mdot
.54553 .55149 Mdot
.58897 .66508 Mdot
.54516 .61474 Mdot
.48405 .82173 Mdot
.34648 .39104 Mdot
.67905 .44661 Mdot
.52981 .33985 Mdot
.5257 .37359 Mdot
.34472 .42506 Mdot
.61581 .35808 Mdot
.31009 .33148 Mdot
.33207 .15084 Mdot
.35078 .37465 Mdot
.37917 .58964 Mdot
.45643 .46269 Mdot
.37888 .39283 Mdot
.34739 .39874 Mdot
.32501 .37804 Mdot
.64279 .36422 Mdot
.65971 .49403 Mdot
.52526 .64114 Mdot
.71174 .44245 Mdot
.49509 .63575 Mdot
.49115 .79226 Mdot
.52463 .36663 Mdot
.69986 .47182 Mdot
.46901 .18275 Mdot
.56959 .71769 Mdot
.55628 .64885 Mdot
.22227 .4316 Mdot
.59492 .58238 Mdot
.41496 .69528 Mdot
.53266 .56751 Mdot
.32635 .39968 Mdot
.5952 .55249 Mdot
.58456 .68629 Mdot
.78659 .43794 Mdot
.50697 .38697 Mdot
.49782 .24019 Mdot
.59034 .63811 Mdot
.51006 .56359 Mdot
.63304 .4736 Mdot
.66464 .50358 Mdot
.37898 .55504 Mdot
.44742 .43226 Mdot
.51016 .3882 Mdot
.37809 .3493 Mdot
.57122 .62287 Mdot
.52352 .31197 Mdot
.79689 .61694 Mdot
.56868 .64613 Mdot
.21049 .5144 Mdot
.69631 .72311 Mdot
.49871 .61142 Mdot
.66048 .68687 Mdot
.50991 .38026 Mdot
.81512 .55466 Mdot
.5053 .68026 Mdot
.35049 .4143 Mdot
.69581 .46459 Mdot
.71199 .46056 Mdot
.35378 .59687 Mdot
.79806 .42072 Mdot
.48167 .37308 Mdot
.69629 .46929 Mdot
.54771 .65762 Mdot
.53126 .37842 Mdot
.49881 .23213 Mdot
.59815 .61929 Mdot
.25982 .61958 Mdot
.67064 .48601 Mdot
.4767 .6521 Mdot
.582 .353 Mdot
.41682 .47908 Mdot
.15946 .5418 Mdot
.52438 .35271 Mdot
.33426 .57121 Mdot
.52385 .56831 Mdot
.46546 .22348 Mdot
.54429 .69477 Mdot
.47188 .76649 Mdot
.74018 .43887 Mdot
.3579 .54796 Mdot
.5527 .66248 Mdot
.50256 .60662 Mdot
.47836 .46229 Mdot
.32898 .57304 Mdot
.49359 .61735 Mdot
.47005 .64802 Mdot
.65622 .48344 Mdot
.49368 .22946 Mdot
.67513 .49106 Mdot
.53685 .64739 Mdot
.59718 .54883 Mdot
.65163 .4895 Mdot
.26175 .36944 Mdot
.32469 .56664 Mdot
.53668 .36051 Mdot
.47478 .58386 Mdot
.57556 .61308 Mdot
.30873 .77815 Mdot
.50074 .24593 Mdot
.56635 .80861 Mdot
.37878 .37503 Mdot
.53291 .26056 Mdot
.31406 .35497 Mdot
.18077 .4266 Mdot
.7084 .39064 Mdot
.49297 .67711 Mdot
.31401 .67871 Mdot
.65423 .67906 Mdot
.48576 .36129 Mdot
.67437 .57668 Mdot
.57285 .62408 Mdot
.53304 .67179 Mdot
.37276 .41227 Mdot
.61122 .37394 Mdot
.66532 .30054 Mdot
.50618 .4478 Mdot
.35756 .58452 Mdot
.69005 .47158 Mdot
.55838 .62807 Mdot
.34085 .2788 Mdot
.35232 .37894 Mdot
.57119 .47969 Mdot
.54822 .67066 Mdot
.69324 .33539 Mdot
.62901 .32437 Mdot
.53246 .37819 Mdot
.38581 .41557 Mdot
.36659 .36286 Mdot
.52114 .67495 Mdot
.50857 .39306 Mdot
.49928 .63103 Mdot
.55887 .47183 Mdot
.47955 .65211 Mdot
.3674 .58904 Mdot
.55584 .67725 Mdot
.47192 .48782 Mdot
.15503 .46086 Mdot
.59275 .571 Mdot
.67212 .43991 Mdot
.31811 .41407 Mdot
.33036 .41666 Mdot
.67848 .5009 Mdot
.33456 .41994 Mdot
.68632 .65426 Mdot
.7916 .57327 Mdot
.3526 .58789 Mdot
.6342 .56576 Mdot
.37057 .5849 Mdot
.49778 .24095 Mdot
.57352 .65062 Mdot
.47409 .25121 Mdot
.34473 .37437 Mdot
.64061 .78276 Mdot
.51979 .3732 Mdot
.5006 .2448 Mdot
.56796 .67719 Mdot
.27457 .45737 Mdot
.37723 .41654 Mdot
.40418 .39083 Mdot
.50529 .64245 Mdot
.66654 .50169 Mdot
.50296 .6069 Mdot
.48391 .61603 Mdot
.51453 .25302 Mdot
.54464 .61373 Mdot
.50268 .34189 Mdot
.648 .46333 Mdot
.19159 .41954 Mdot
.32318 .4273 Mdot
.5502 .67687 Mdot
.54844 .65815 Mdot
.67963 .50826 Mdot
.57278 .66866 Mdot
.49765 .39199 Mdot
.10707 .40553 Mdot
.34527 .58092 Mdot
.52492 .23402 Mdot
.3973 .37478 Mdot
.5574 .59914 Mdot
.50488 .6111 Mdot
.42706 .18263 Mdot
.61068 .23 Mdot
.50336 .34296 Mdot
.49772 .58956 Mdot
.3636 .40075 Mdot
.36682 .58304 Mdot
.50993 .40338 Mdot
.51617 .62691 Mdot
.53793 .67449 Mdot
.3657 .59017 Mdot
.20923 .48932 Mdot
.37597 .4729 Mdot
.52968 .36034 Mdot
.61204 .55958 Mdot
.32224 .48933 Mdot
.52792 .66171 Mdot
.28855 .29787 Mdot
.68825 .4875 Mdot
.50896 .34816 Mdot
.60261 .75303 Mdot
.49854 .6634 Mdot
.49168 .38841 Mdot
.51066 .38751 Mdot
.54136 .68414 Mdot
.70794 .43831 Mdot
.63911 .47329 Mdot
.6923 .48793 Mdot
.78181 .66239 Mdot
.39495 .76476 Mdot
.33788 .38633 Mdot
.50806 .38089 Mdot
.35429 .44477 Mdot
.3583 .54281 Mdot
.4364 .46151 Mdot
.3579 .44205 Mdot
.71306 .46467 Mdot
.376 .43876 Mdot
.49995 .62557 Mdot
.50743 .38958 Mdot
.36522 .38728 Mdot
.55138 .59634 Mdot
.46484 .66093 Mdot
.50912 .49527 Mdot
.36113 .545 Mdot
.3862 .48058 Mdot
.53954 .63292 Mdot
.51454 .25075 Mdot
.56774 .65811 Mdot
.53376 .38184 Mdot
.45213 .49047 Mdot
.54729 .59711 Mdot
.32672 .3807 Mdot
.42781 .5557 Mdot
.35963 .43556 Mdot
.48132 .60835 Mdot
.53656 .64611 Mdot
.5289 .66458 Mdot
.50063 .60764 Mdot
.61517 .31399 Mdot
.49893 .33534 Mdot
.46163 .60164 Mdot
.31445 .42914 Mdot
.6672 .47038 Mdot
.69881 .50351 Mdot
.30668 .46264 Mdot
.52043 .25108 Mdot
.5003 .38489 Mdot
.52624 .66063 Mdot
.40501 .39377 Mdot
.38898 .18422 Mdot
.28802 .28894 Mdot
.23668 .514 Mdot
.36667 .39482 Mdot
.67143 .44078 Mdot
.37048 .38478 Mdot
.52199 .67152 Mdot
.55851 .5731 Mdot
.1866 .42908 Mdot
.54421 .33439 Mdot
.35642 .5783 Mdot
.52159 .66569 Mdot
.51107 .77651 Mdot
.36445 .40151 Mdot
.35071 .36662 Mdot
.49954 .64318 Mdot
.64201 .49016 Mdot
.14285 .56895 Mdot
.52836 .3859 Mdot
.65413 .58011 Mdot
.70055 .41381 Mdot
.61019 .45682 Mdot
.52788 .37819 Mdot
.51721 .50633 Mdot
.34051 .4301 Mdot
.78296 .45962 Mdot
.66948 .47389 Mdot
.35622 .57362 Mdot
.54643 .57316 Mdot
.71095 .45955 Mdot
.38745 .41117 Mdot
.70923 .46578 Mdot
.50075 .66221 Mdot
.49065 .34811 Mdot
.34631 .42745 Mdot
.49072 .33499 Mdot
.73172 .46904 Mdot
.3746 .5808 Mdot
.50882 .76332 Mdot
.66557 .57194 Mdot
.69477 .7245 Mdot
.53946 .5978 Mdot
.39267 .43538 Mdot
.52832 .61398 Mdot
.63378 .47656 Mdot
.53253 .65462 Mdot
.73958 .49157 Mdot
.37731 .37864 Mdot
.47794 .65464 Mdot
.57574 .65661 Mdot
.72805 .53312 Mdot
.56169 .6503 Mdot
.56263 .68061 Mdot
.50858 .59718 Mdot
.71821 .41806 Mdot
.4725 .64991 Mdot
.66096 .49768 Mdot
.65184 .34292 Mdot
.34552 .40018 Mdot
.38207 .55475 Mdot
.34484 .60109 Mdot
.47194 .76287 Mdot
.50267 .76645 Mdot
.61952 .36132 Mdot
.67019 .49477 Mdot
.49192 .35983 Mdot
.49951 .63246 Mdot
.60269 .74628 Mdot
.32217 .59072 Mdot
.34185 .42944 Mdot
.31269 .4023 Mdot
.52203 .7176 Mdot
.4693 .82369 Mdot
.47422 .6478 Mdot
.68234 .36979 Mdot
.48709 .64274 Mdot
.49785 .60231 Mdot
.32532 .37353 Mdot
.45815 .71307 Mdot
.53971 .59752 Mdot
.63296 .47373 Mdot
.35484 .56888 Mdot
.61398 .59181 Mdot
.38166 .61889 Mdot
.54737 .49043 Mdot
.75311 .49613 Mdot
.5416 .60932 Mdot
.36123 .41739 Mdot
.69923 .4458 Mdot
.71839 .37618 Mdot
.52254 .35708 Mdot
.64519 .38651 Mdot
.72098 .55148 Mdot
.25165 .39324 Mdot
.35437 .57412 Mdot
.21424 .50606 Mdot
.55363 .63453 Mdot
.31657 .40822 Mdot
.49813 .65318 Mdot
.37884 .19014 Mdot
.37609 .56333 Mdot
.71737 .49677 Mdot
.4961 .35606 Mdot
.68436 .50456 Mdot
.71189 .69676 Mdot
.50362 .53116 Mdot
.52821 .20386 Mdot
.3304 .43794 Mdot
.5554 .77543 Mdot
.68701 .45165 Mdot
.5103 .63073 Mdot
.36206 .13802 Mdot
.68846 .48568 Mdot
.67664 .50452 Mdot
.3661 .50219 Mdot
.4089 .63646 Mdot
.60078 .65955 Mdot
.71073 .47228 Mdot
.35507 .44779 Mdot
.36054 .55831 Mdot
.52644 .59642 Mdot
.50743 .59938 Mdot
.65798 .49918 Mdot
.37896 .41569 Mdot
.53512 .78969 Mdot
.32459 .39909 Mdot
.65487 .47653 Mdot
.33657 .4126 Mdot
.40931 .38517 Mdot
.35938 .38841 Mdot
.58259 .63223 Mdot
.5255 .65811 Mdot
.26929 .57567 Mdot
.68166 .48878 Mdot
.51238 .60403 Mdot
.52531 .63346 Mdot
.68138 .45262 Mdot
.32777 .44719 Mdot
.5841 .76477 Mdot
.55951 .61348 Mdot
.52339 .64756 Mdot
.35097 .54899 Mdot
.29629 .42056 Mdot
.33493 .27141 Mdot
.52092 .599 Mdot
.36094 .60389 Mdot
.64511 .46181 Mdot
.56863 .65513 Mdot
.49197 .75137 Mdot
.31469 .37851 Mdot
.54361 .6815 Mdot
.50228 .22372 Mdot
.56214 .60067 Mdot
.14285 .56154 Mdot
.56132 .67164 Mdot
.6717 .45031 Mdot
.69661 .46018 Mdot
.41203 .4549 Mdot
.67861 .46939 Mdot
.50153 .2422 Mdot
.50765 .36235 Mdot
.26391 .30205 Mdot
.50031 .23618 Mdot
.50739 .59097 Mdot
.78272 .35053 Mdot
.48675 .65904 Mdot
.58951 .62752 Mdot
.57445 .78857 Mdot
.50183 .23831 Mdot
.69766 .45395 Mdot
.33831 .31745 Mdot
.48836 .61249 Mdot
.52398 .38909 Mdot
.57973 .5907 Mdot
.55207 .68078 Mdot
.61611 .42755 Mdot
.74321 .69897 Mdot
.53661 .38071 Mdot
.54919 .5634 Mdot
.52101 .59946 Mdot
.67339 .24593 Mdot
.54739 .65007 Mdot
.3485 .59523 Mdot
.68745 .49754 Mdot
.36781 .37778 Mdot
.34485 .57081 Mdot
.56111 .61778 Mdot
.35964 .57371 Mdot
.34282 .38579 Mdot
.51008 .35382 Mdot
.54306 .67922 Mdot
.34668 .60552 Mdot
.35851 .58269 Mdot
.52157 .61321 Mdot
.69802 .46868 Mdot
.60675 .66225 Mdot
.56916 .6523 Mdot
.51066 .63479 Mdot
.67697 .50059 Mdot
.74669 .2607 Mdot
.51416 .66992 Mdot
.49111 .50362 Mdot
.72156 .48466 Mdot
.50705 .21143 Mdot
.36988 .38747 Mdot
.52159 .68285 Mdot
.52764 .36776 Mdot
.51959 .36212 Mdot
.36044 .45664 Mdot
.67062 .50986 Mdot
.37223 .42759 Mdot
.58784 .57347 Mdot
.50626 .71129 Mdot
.50861 .58084 Mdot
.86698 .52883 Mdot
.19368 .45741 Mdot
.6503 .46345 Mdot
.34829 .43291 Mdot
.50781 .44619 Mdot
.50064 .38195 Mdot
.37101 .44669 Mdot
.64988 .44215 Mdot
.66536 .44629 Mdot
.71301 .47185 Mdot
.34493 .55437 Mdot
.32078 .41095 Mdot
.66709 .52103 Mdot
.64782 .49803 Mdot
.50302 .63641 Mdot
.51978 .60052 Mdot
.74016 .47606 Mdot
.40855 .7326 Mdot
.37326 .58482 Mdot
.35637 .41897 Mdot
.2796 .76827 Mdot
.53459 .38064 Mdot
.73146 .53002 Mdot
.55423 .59844 Mdot
.53904 .10135 Mdot
.47256 .61858 Mdot
.54757 .65525 Mdot
.64848 .4583 Mdot
.37632 .59842 Mdot
.36735 .56849 Mdot
.68858 .45261 Mdot
.73152 .44904 Mdot
.33665 .58428 Mdot
.23151 .5205 Mdot
.21486 .34601 Mdot
.7003 .37939 Mdot
.67227 .4521 Mdot
.66109 .56711 Mdot
.49563 .39342 Mdot
.72851 .46738 Mdot
.54002 .37576 Mdot
.34807 .39982 Mdot
.31875 .39186 Mdot
.54188 .38693 Mdot
.50733 .64696 Mdot
.35153 .38416 Mdot
.54715 .54981 Mdot
.20777 .42381 Mdot
.24829 .6606 Mdot
.58555 .21323 Mdot
.56276 .59789 Mdot
.6698 .31047 Mdot
.63821 .28045 Mdot
.54743 .62709 Mdot
.57881 .71978 Mdot
.35707 .57631 Mdot
.72754 .47596 Mdot
.50152 .39247 Mdot
.16423 .55426 Mdot
.52732 .66128 Mdot
.66089 .46503 Mdot
.50363 .38685 Mdot
.4195 .38377 Mdot
.62276 .41247 Mdot
.4987 .64576 Mdot
.22473 .24498 Mdot
.72487 .48627 Mdot
.36785 .37758 Mdot
.78486 .38025 Mdot
.71715 .4496 Mdot
.35724 .50535 Mdot
.36524 .36611 Mdot
.31025 .25434 Mdot
.68645 .44459 Mdot
.34732 .46281 Mdot
.68498 .4653 Mdot
.36489 .59335 Mdot
.69004 .42858 Mdot
.35128 .42718 Mdot
.55732 .65871 Mdot
.34316 .42311 Mdot
.37256 .58797 Mdot
.3151 .40921 Mdot
.50068 .39335 Mdot
.50764 .24931 Mdot
.50328 .37398 Mdot
.42685 .46598 Mdot
.75544 .6826 Mdot
.52432 .34804 Mdot
.33445 .3435 Mdot
.54622 .58881 Mdot
.64648 .51704 Mdot
.36405 .37463 Mdot
.33262 .44426 Mdot
.44822 .45076 Mdot
.66847 .46249 Mdot
.35056 .42495 Mdot
.71047 .55904 Mdot
.81262 .34211 Mdot
.51641 .55374 Mdot
.35415 .73756 Mdot
.67878 .45214 Mdot
.37204 .37295 Mdot
.70581 .372 Mdot
.71364 .4861 Mdot
.3486 .37532 Mdot
.50063 .35439 Mdot
.5267 .37511 Mdot
.50994 .65758 Mdot
.52627 .31999 Mdot
.38453 .40906 Mdot
.57983 .25385 Mdot
.69063 .49754 Mdot
.42317 .38814 Mdot
.34654 .59648 Mdot
.35046 .39486 Mdot
.57554 .69692 Mdot
.73591 .45284 Mdot
.31277 .41901 Mdot
.27079 .64879 Mdot
.32119 .80008 Mdot
.34947 .42389 Mdot
.68827 .4973 Mdot
.66136 .47723 Mdot
.60484 .61023 Mdot
.47835 .45482 Mdot
.37245 .42403 Mdot
.48042 .27005 Mdot
.47262 .77083 Mdot
.5113 .2266 Mdot
.71966 .2654 Mdot
.54189 .59755 Mdot
.52847 .61705 Mdot
.4962 .38011 Mdot
.55724 .64138 Mdot
.63864 .48412 Mdot
.5871 .62665 Mdot
.48809 .38108 Mdot
.34565 .4303 Mdot
.55802 .67125 Mdot
.37124 .56593 Mdot
.50036 .39697 Mdot
.53447 .39702 Mdot
.33756 .40399 Mdot
.71185 .47264 Mdot
.30176 .31775 Mdot
.32352 .40002 Mdot
.54263 .60797 Mdot
.50783 .239 Mdot
.50483 .67032 Mdot
.25033 .58881 Mdot
.70013 .49803 Mdot
.37058 .38341 Mdot
.70626 .44765 Mdot
.50782 .37384 Mdot
.35112 .45519 Mdot
.54587 .64575 Mdot
.34095 .37649 Mdot
.29316 .59001 Mdot
.23718 .55155 Mdot
.65705 .50717 Mdot
.39077 .60485 Mdot
.67123 .50647 Mdot
.51045 .22561 Mdot
.33107 .64351 Mdot
.35078 .58112 Mdot
.36006 .398 Mdot
.18788 .46723 Mdot
.33602 .37363 Mdot
.56325 .64825 Mdot
.56852 .63128 Mdot
.37329 .40871 Mdot
.36478 .55533 Mdot
.69827 .76958 Mdot
.5001 .51637 Mdot
.7006 .45436 Mdot
.76541 .44461 Mdot
.21584 .69865 Mdot
.4809 .395 Mdot
.49237 .36731 Mdot
.48572 .58826 Mdot
.49503 .6192 Mdot
.5195 .40444 Mdot
.52398 .33408 Mdot
.35435 .5463 Mdot
.31956 .39722 Mdot
.62429 .4992 Mdot
.50208 .4009 Mdot
.43248 .61392 Mdot
.51272 .7725 Mdot
.60182 .60092 Mdot
.49411 .68828 Mdot
.56751 .59535 Mdot
.4095 .48168 Mdot
.50908 .33538 Mdot
.5365 .63469 Mdot
.46909 .62068 Mdot
.50734 .34568 Mdot
.36699 .5912 Mdot
.62759 .526 Mdot
.34386 .41552 Mdot
.6924 .18876 Mdot
.54781 .67925 Mdot
.56203 .65744 Mdot
.53122 .36411 Mdot
.68668 .24065 Mdot
.65511 .46029 Mdot
.70776 .48556 Mdot
.34648 .39002 Mdot
.4468 .44758 Mdot
.58391 .639 Mdot
.54464 .62955 Mdot
.35679 .40304 Mdot
.51003 .24948 Mdot
.55755 .20632 Mdot
.52748 .642 Mdot
.5141 .38395 Mdot
.40749 .43075 Mdot
.51073 .33465 Mdot
.50092 .65648 Mdot
.56448 .64488 Mdot
.58251 .63636 Mdot
.49572 .61263 Mdot
.53269 .39622 Mdot
.54507 .63303 Mdot
.55788 .71063 Mdot
.70517 .47229 Mdot
.55423 .60734 Mdot
.46652 .75349 Mdot
.5264 .64978 Mdot
.37277 .56983 Mdot
.32168 .29033 Mdot
.52561 .66516 Mdot
.5527 .60844 Mdot
.50059 .51249 Mdot
.54854 .66497 Mdot
.5363 .37611 Mdot
.6656 .47481 Mdot
.50713 .38088 Mdot
.52955 .34256 Mdot
.34627 .44759 Mdot
.35738 .54601 Mdot
.54655 .69532 Mdot
.34673 .59901 Mdot
.54273 .70369 Mdot
.49854 .65876 Mdot
.34016 .4673 Mdot
.67815 .36958 Mdot
.31428 .54088 Mdot
.54225 .64667 Mdot
.34513 .39461 Mdot
.36453 .37806 Mdot
.30009 .66653 Mdot
.57762 .55668 Mdot
.51848 .40316 Mdot
.50039 .35794 Mdot
.38978 .69348 Mdot
.63104 .41466 Mdot
.37404 .57733 Mdot
.53949 .44019 Mdot
.5592 .59219 Mdot
.51989 .63972 Mdot
.58129 .59067 Mdot
.35591 .44306 Mdot
.51764 .25113 Mdot
.3367 .42758 Mdot
.52359 .20993 Mdot
.50693 .33401 Mdot
.56543 .60237 Mdot
.22749 .63587 Mdot
.64954 .49235 Mdot
.66605 .47587 Mdot
.49669 .40594 Mdot
.36449 .43424 Mdot
.60583 .63138 Mdot
.87332 .52897 Mdot
.71988 .50572 Mdot
.38643 .58069 Mdot
.54328 .62721 Mdot
.3391 .40054 Mdot
.64692 .49225 Mdot
.33242 .59453 Mdot
.56899 .61205 Mdot
.3125 .42786 Mdot
.53 .65408 Mdot
.64887 .69245 Mdot
.70377 .46719 Mdot
.38964 .18112 Mdot
.65963 .51005 Mdot
.49336 .39486 Mdot
.51893 .34014 Mdot
.56841 .64341 Mdot
.84283 .46311 Mdot
.71792 .49862 Mdot
.49519 .33095 Mdot
.38219 .57779 Mdot
.52444 .23401 Mdot
.3769 .55719 Mdot
.38126 .39722 Mdot
.35372 .57135 Mdot
.32167 .38473 Mdot
.39152 .7083 Mdot
.69769 .51847 Mdot
.34496 .57679 Mdot
.65121 .21744 Mdot
.57455 .67755 Mdot
.34482 .54803 Mdot
.52897 .71676 Mdot
.75291 .43238 Mdot
.35407 .4054 Mdot
.36526 .5565 Mdot
.50841 .62938 Mdot
.17951 .57779 Mdot
.52412 .34089 Mdot
.5203 .4019 Mdot
.55445 .69521 Mdot
.33343 .37083 Mdot
.72737 .44433 Mdot
.40264 .51926 Mdot
.5027 .21227 Mdot
.54403 .63129 Mdot
.56622 .60227 Mdot
.68702 .50977 Mdot
.63356 .48808 Mdot
.56605 .64179 Mdot
.69007 .57251 Mdot
.55428 .63252 Mdot
.5297 .37427 Mdot
.66133 .45059 Mdot
.66324 .47832 Mdot
.38511 .41632 Mdot
.66776 .50881 Mdot
.48484 .67691 Mdot
.55461 .38303 Mdot
.51873 .57443 Mdot
.51139 .36977 Mdot
.45951 .49194 Mdot
.31854 .41942 Mdot
.17042 .53645 Mdot
.67835 .51207 Mdot
.54754 .61184 Mdot
.67479 .50675 Mdot
.34008 .58546 Mdot
.67913 .48811 Mdot
.68499 .43612 Mdot
.57156 .62735 Mdot
.49788 .64524 Mdot
.50562 .24292 Mdot
.47384 .45234 Mdot
.69904 .47878 Mdot
.55375 .62825 Mdot
.48785 .66377 Mdot
.55048 .68668 Mdot
.50222 .47593 Mdot
.65819 .44919 Mdot
.76696 .56722 Mdot
.24778 .61698 Mdot
.69805 .47312 Mdot
.16374 .60178 Mdot
.50822 .21863 Mdot
.52309 .24513 Mdot
.4774 .38611 Mdot
.52461 .64255 Mdot
.36034 .43161 Mdot
.5238 .67295 Mdot
.52881 .55294 Mdot
.53568 .67464 Mdot
.37977 .5767 Mdot
.53258 .69842 Mdot
.51808 .22962 Mdot
.32454 .40488 Mdot
.56065 .61135 Mdot
.55171 .67481 Mdot
.51726 .25462 Mdot
.66788 .51382 Mdot
.67412 .44323 Mdot
.28428 .30303 Mdot
.35096 .59042 Mdot
.51528 .35558 Mdot
.51233 .65565 Mdot
.34593 .39276 Mdot
.33908 .42174 Mdot
.68207 .50495 Mdot
.34989 .41687 Mdot
.53021 .38497 Mdot
.55019 .6468 Mdot
.52401 .40201 Mdot
.37908 .5789 Mdot
.68642 .49775 Mdot
.51285 .65729 Mdot
.50347 .63717 Mdot
.69676 .4601 Mdot
.54686 .58877 Mdot
.35038 .54923 Mdot
.32181 .39027 Mdot
.67557 .44436 Mdot
.51056 .36129 Mdot
.38333 .42318 Mdot
.50228 .62583 Mdot
.37211 .81878 Mdot
.55786 .63808 Mdot
.51221 .64176 Mdot
.19468 .38596 Mdot
.48348 .59438 Mdot
.37685 .3805 Mdot
.70521 .49984 Mdot
.59368 .63335 Mdot
.47988 .7872 Mdot
.44114 .1934 Mdot
.36609 .44978 Mdot
.5443 .62113 Mdot
.17071 .51915 Mdot
.55062 .61515 Mdot
.41826 .37362 Mdot
.35938 .47634 Mdot
.41215 .79021 Mdot
.49604 .69279 Mdot
.54191 .37798 Mdot
.50486 .2438 Mdot
.3559 .37084 Mdot
.66828 .72023 Mdot
.56385 .62185 Mdot
.65534 .7404 Mdot
.56639 .6731 Mdot
.52687 .37837 Mdot
.53651 .73182 Mdot
.35491 .41898 Mdot
.79019 .42724 Mdot
.53559 .60966 Mdot
.65777 .45037 Mdot
.37182 .44186 Mdot
.52119 .2227 Mdot
.50703 .63283 Mdot
.35641 .60161 Mdot
.57483 .38884 Mdot
.49527 .69993 Mdot
.51219 .36719 Mdot
.52399 .63241 Mdot
.54881 .56117 Mdot
.82263 .44068 Mdot
.70551 .46678 Mdot
.49385 .36299 Mdot
.69333 .2888 Mdot
.54474 .58671 Mdot
.68325 .44413 Mdot
.66904 .47218 Mdot
.36073 .59731 Mdot
.57713 .41969 Mdot
.53375 .29566 Mdot
.27128 .69706 Mdot
.73279 .68986 Mdot
.38651 .40556 Mdot
.6021 .24895 Mdot
.52702 .59861 Mdot
.5213 .52243 Mdot
.53784 .37249 Mdot
.55923 .65956 Mdot
.76606 .65822 Mdot
.69118 .48882 Mdot
.5306 .64381 Mdot
.36943 .58745 Mdot
.57446 .4072 Mdot
.56006 .49343 Mdot
.29444 .75867 Mdot
.36338 .44768 Mdot
.5589 .57563 Mdot
.51723 .70501 Mdot
.51077 .21198 Mdot
.49355 .6437 Mdot
.36183 .37244 Mdot
.21628 .43615 Mdot
.36812 .55655 Mdot
.65446 .50073 Mdot
.50964 .21807 Mdot
.57825 .60298 Mdot
.51958 .68546 Mdot
.38353 .5572 Mdot
.51655 .62274 Mdot
.79009 .4102 Mdot
.5164 .27491 Mdot
.35712 .38478 Mdot
.70886 .4627 Mdot
.56355 .59099 Mdot
.51766 .25064 Mdot
.57034 .62825 Mdot
.67362 .5391 Mdot
.5331 .6192 Mdot
.58799 .37237 Mdot
.69495 .46454 Mdot
.50829 .36795 Mdot
.55904 .69541 Mdot
.53654 .6693 Mdot
.3162 .4879 Mdot
.52719 .55351 Mdot
.55873 .67324 Mdot
.63276 .47198 Mdot
.64878 .48298 Mdot
.66427 .49896 Mdot
.35023 .38143 Mdot
.68669 .37887 Mdot
.51693 .37757 Mdot
.57966 .6578 Mdot
.50263 .40095 Mdot
.45182 .59197 Mdot
.38688 .56842 Mdot
.194 .63329 Mdot
.56243 .6084 Mdot
.66613 .49693 Mdot
.57626 .27374 Mdot
.64412 .46404 Mdot
.30147 .40309 Mdot
.50995 .38843 Mdot
.69001 .48456 Mdot
.54197 .66317 Mdot
.49868 .45256 Mdot
.33143 .78041 Mdot
.49974 .37826 Mdot
.57516 .58352 Mdot
.35748 .45022 Mdot
.31101 .40188 Mdot
.16092 .63581 Mdot
.51098 .33852 Mdot
.63522 .2756 Mdot
.55378 .62475 Mdot
.65102 .49343 Mdot
.52757 .35302 Mdot
.54155 .36686 Mdot
.35488 .4087 Mdot
.50223 .65354 Mdot
.5319 .66388 Mdot
.50325 .2225 Mdot
.50278 .35783 Mdot
.58374 .66826 Mdot
.4896 .64107 Mdot
.18488 .42431 Mdot
.63177 .52377 Mdot
.71536 .23055 Mdot
.58668 .57277 Mdot
.73262 .6971 Mdot
.45018 .47431 Mdot
.64869 .46474 Mdot
.51526 .66356 Mdot
.57823 .59677 Mdot
.38544 .39856 Mdot
.55307 .64248 Mdot
.34626 .43772 Mdot
.49126 .36962 Mdot
.20327 .6494 Mdot
.43393 .37335 Mdot
.22598 .501 Mdot
.55826 .64689 Mdot
.60358 .45621 Mdot
.34123 .57167 Mdot
.52263 .41268 Mdot
.65432 .47049 Mdot
.55166 .58378 Mdot
.3602 .36146 Mdot
.36133 .39828 Mdot
.67535 .47599 Mdot
.63698 .29919 Mdot
.26971 .363 Mdot
.49228 .61754 Mdot
.37367 .39146 Mdot
.43697 .34594 Mdot
.69246 .58314 Mdot
.54063 .33274 Mdot
.37162 .55878 Mdot
.34595 .42978 Mdot
.53951 .3936 Mdot
.67469 .53556 Mdot
.6847 .47633 Mdot
.70648 .50302 Mdot
.28173 .53552 Mdot
.36867 .42754 Mdot
.34875 .56132 Mdot
.66942 .39609 Mdot
.70975 .39429 Mdot
.37892 .57165 Mdot
.34621 .43088 Mdot
.64699 .48692 Mdot
.65786 .46817 Mdot
.66498 .4737 Mdot
.78871 .42922 Mdot
.70023 .49606 Mdot
.77558 .52907 Mdot
.49044 .66546 Mdot
.64748 .5833 Mdot
.5487 .61686 Mdot
.53597 .38938 Mdot
.70301 .46558 Mdot
.45209 .45952 Mdot
.51789 .58753 Mdot
.29731 .75709 Mdot
.5405 .63134 Mdot
.55531 .35721 Mdot
.5235 .64461 Mdot
.67167 .55253 Mdot
.72202 .48419 Mdot
.54322 .64486 Mdot
.5324 .33254 Mdot
.36134 .58137 Mdot
.62256 .47015 Mdot
.52659 .66537 Mdot
.60241 .39176 Mdot
.47168 .61442 Mdot
.21171 .42309 Mdot
.39856 .53555 Mdot
.38441 .58625 Mdot
.46884 .64159 Mdot
.38465 .42729 Mdot
.66337 .42391 Mdot
.63902 .58795 Mdot
.49964 .37694 Mdot
.63918 .77355 Mdot
.35889 .39489 Mdot
.53888 .73197 Mdot
.4901 .60303 Mdot
.34176 .55509 Mdot
.67781 .42288 Mdot
.53476 .36831 Mdot
.55949 .59807 Mdot
.54476 .68428 Mdot
.27624 .6034 Mdot
.64002 .57478 Mdot
.55462 .68898 Mdot
.36754 .54467 Mdot
.77252 .57029 Mdot
.51832 .65146 Mdot
.32923 .44727 Mdot
.71822 .48418 Mdot
.52614 .70091 Mdot
.76428 .56208 Mdot
.55579 .62694 Mdot
.68449 .48339 Mdot
.68404 .51181 Mdot
.59702 .32323 Mdot
.38223 .58842 Mdot
.53264 .61948 Mdot
.37266 .51959 Mdot
.53331 .61325 Mdot
.51973 .37955 Mdot
.51286 .66979 Mdot
.35254 .39897 Mdot
.70279 .36944 Mdot
.33892 .38167 Mdot
.51743 .67057 Mdot
.66349 .46707 Mdot
.53561 .36306 Mdot
.2657 .56078 Mdot
.34146 .48043 Mdot
.77654 .53441 Mdot
.47711 .18515 Mdot
.35163 .55358 Mdot
.33506 .55426 Mdot
.48651 .35315 Mdot
.53832 .64676 Mdot
.3839 .48984 Mdot
.4763 .63255 Mdot
.52163 .64759 Mdot
.53455 .67608 Mdot
.52847 .31889 Mdot
.50517 .38362 Mdot
.33887 .41756 Mdot
.56495 .64131 Mdot
.55254 .62971 Mdot
.69402 .47408 Mdot
.35988 .58363 Mdot
.34791 .37869 Mdot
.34492 .58572 Mdot
.32852 .39651 Mdot
.14525 .56626 Mdot
.58521 .57914 Mdot
.36295 .5814 Mdot
.49036 .34471 Mdot
.67525 .50154 Mdot
.50201 .24927 Mdot
.38258 .40483 Mdot
.35514 .42118 Mdot
.54607 .63002 Mdot
.68419 .49566 Mdot
.69681 .49099 Mdot
.33614 .57198 Mdot
.5148 .34939 Mdot
.5185 .67047 Mdot
.49373 .63515 Mdot
.30783 .70302 Mdot
.37073 .436 Mdot
.71092 .57098 Mdot
.61184 .33194 Mdot
.5388 .64759 Mdot
.70836 .47186 Mdot
.56312 .66625 Mdot
.18711 .54997 Mdot
.7122 .46263 Mdot
.49521 .60915 Mdot
.65601 .40857 Mdot
.34395 .44456 Mdot
.5752 .32524 Mdot
.51226 .68596 Mdot
.42007 .18457 Mdot
.52575 .60533 Mdot
.16641 .39191 Mdot
.6349 .23865 Mdot
.58476 .61955 Mdot
.51116 .59844 Mdot
.30141 .73343 Mdot
.55389 .62025 Mdot
.51451 .22406 Mdot
.58652 .56963 Mdot
.6684 .44427 Mdot
.40726 .49684 Mdot
.29968 .38052 Mdot
.38158 .58521 Mdot
.34692 .3896 Mdot
.33418 .62166 Mdot
.36349 .59295 Mdot
.67629 .45012 Mdot
.50647 .59962 Mdot
.51991 .76102 Mdot
.30364 .39952 Mdot
.48214 .62001 Mdot
.52064 .38039 Mdot
.29696 .3931 Mdot
.33367 .43155 Mdot
.50606 .36432 Mdot
.57226 .66518 Mdot
.533 .80001 Mdot
.30841 .45913 Mdot
.29356 .25537 Mdot
.52985 .36078 Mdot
.5255 .38362 Mdot
.73247 .37772 Mdot
.38097 .58621 Mdot
.27858 .61812 Mdot
.59825 .49832 Mdot
.51547 .39302 Mdot
.39203 .66861 Mdot
.34731 .36569 Mdot
.60186 .40674 Mdot
.72747 .47515 Mdot
.58569 .58238 Mdot
.54026 .66528 Mdot
.51227 .34699 Mdot
.54538 .74996 Mdot
.76414 .37168 Mdot
.50217 .37424 Mdot
.54199 .70809 Mdot
.57373 .41449 Mdot
.50609 .23503 Mdot
.50174 .22159 Mdot
.38369 .57183 Mdot
.26391 .37424 Mdot
.68573 .46123 Mdot
.33612 .55996 Mdot
.57928 .35539 Mdot
.52737 .62322 Mdot
.49776 .36526 Mdot
.50104 .25058 Mdot
.52161 .36568 Mdot
.36953 .57374 Mdot
.3866 .5798 Mdot
.70537 .47124 Mdot
.65528 .46062 Mdot
.7279 .70835 Mdot
.4105 .70738 Mdot
.55453 .61302 Mdot
.60372 .76192 Mdot
.68705 .50085 Mdot
.62544 .56456 Mdot
.3666 .60213 Mdot
.36089 .58605 Mdot
.66595 .65703 Mdot
.50063 .6383 Mdot
.42701 .39822 Mdot
.52256 .66008 Mdot
.32893 .64914 Mdot
.49939 .59583 Mdot
.35261 .41196 Mdot
.5477 .60208 Mdot
.31261 .30798 Mdot
.53244 .59198 Mdot
.55015 .67777 Mdot
.32731 .41753 Mdot
.60111 .64367 Mdot
.35434 .39849 Mdot
.50202 .65653 Mdot
.36292 .53951 Mdot
.34573 .3925 Mdot
.37681 .75081 Mdot
.49291 .50291 Mdot
.51969 .24424 Mdot
.37449 .58916 Mdot
.34505 .59677 Mdot
.48647 .76799 Mdot
.65564 .46592 Mdot
.67314 .53106 Mdot
.53762 .64618 Mdot
.35079 .36687 Mdot
.49577 .38074 Mdot
.55372 .6302 Mdot
.57006 .58705 Mdot
.53251 .69304 Mdot
.69425 .48656 Mdot
.36528 .43283 Mdot
.3628 .57538 Mdot
.36786 .3846 Mdot
.29132 .45705 Mdot
.31842 .38593 Mdot
.47356 .6011 Mdot
.59677 .61826 Mdot
.55062 .53819 Mdot
.64657 .75408 Mdot
.788 .44862 Mdot
.68004 .4738 Mdot
.51317 .24347 Mdot
.38624 .57177 Mdot
.76452 .45084 Mdot
.65728 .4877 Mdot
.35756 .42416 Mdot
.53009 .6543 Mdot
.55665 .70805 Mdot
.5763 .49023 Mdot
.71766 .42229 Mdot
.45646 .76919 Mdot
.319 .41364 Mdot
.50899 .22908 Mdot
.7004 .37691 Mdot
.74124 .4299 Mdot
.44332 .46036 Mdot
.54678 .67352 Mdot
.35597 .60213 Mdot
.64699 .49241 Mdot
.28375 .55456 Mdot
.50555 .35056 Mdot
.4775 .45386 Mdot
.55741 .646 Mdot
.59612 .26534 Mdot
.66413 .46682 Mdot
.37198 .58436 Mdot
.51191 .34648 Mdot
.37929 .59303 Mdot
.50519 .21742 Mdot
.27495 .31176 Mdot
.52124 .61648 Mdot
.56751 .66592 Mdot
.49685 .33325 Mdot
.68331 .46188 Mdot
.39945 .46384 Mdot
.26881 .59798 Mdot
.37426 .39592 Mdot
.37675 .48605 Mdot
.64654 .46704 Mdot
.73618 .51562 Mdot
.36106 .38184 Mdot
.49536 .40561 Mdot
.41091 .48449 Mdot
.48735 .36936 Mdot
.5229 .66364 Mdot
.66771 .49154 Mdot
.50749 .33909 Mdot
.31284 .50013 Mdot
.15896 .50128 Mdot
.65393 .54592 Mdot
.56369 .60352 Mdot
.20264 .64468 Mdot
.20145 .40155 Mdot
.52754 .74944 Mdot
.49468 .39218 Mdot
.57107 .64536 Mdot
.4903 .62096 Mdot
.53934 .60727 Mdot
.49374 .35376 Mdot
.26102 .45948 Mdot
.36076 .41336 Mdot
.53819 .62858 Mdot
.34414 .59444 Mdot
.34685 .40539 Mdot
.38905 .42571 Mdot
.34548 .37009 Mdot
.68795 .43762 Mdot
.49554 .61095 Mdot
.642 .37562 Mdot
.1592 .40992 Mdot
.50555 .38063 Mdot
.52005 .24327 Mdot
.5662 .67073 Mdot
.81113 .5915 Mdot
.6642 .49847 Mdot
.37479 .39865 Mdot
.56132 .65883 Mdot
.28826 .47174 Mdot
.53196 .22793 Mdot
.3215 .40117 Mdot
.65743 .46558 Mdot
.52345 .74754 Mdot
.55315 .64119 Mdot
.52265 .60763 Mdot
.68313 .45596 Mdot
.29083 .28632 Mdot
.68488 .37154 Mdot
.55628 .67181 Mdot
.50706 .36747 Mdot
.82328 .38365 Mdot
.5309 .6911 Mdot
.73957 .46201 Mdot
.52471 .23464 Mdot
.60474 .36955 Mdot
.71267 .57589 Mdot
.50482 .56395 Mdot
.2169 .64644 Mdot
.46501 .72119 Mdot
.18289 .62764 Mdot
.31784 .5889 Mdot
.41178 .31686 Mdot
.1345 .54462 Mdot
.5331 .33205 Mdot
.63627 .56292 Mdot
.37253 .77874 Mdot
.65155 .31721 Mdot
.40199 .53647 Mdot
.45001 .22266 Mdot
.33035 .4864 Mdot
.55709 .16839 Mdot
.34341 .37411 Mdot
.31001 .6471 Mdot
.5222 .67354 Mdot
.21016 .38949 Mdot
.68864 .55997 Mdot
.79903 .4048 Mdot
.17812 .60959 Mdot
.38474 .52795 Mdot
.35582 .78943 Mdot
.17758 .51783 Mdot
.55701 .77669 Mdot
.58113 .47435 Mdot
.49241 .26837 Mdot
.68493 .39236 Mdot
.35633 .63333 Mdot
.6019 .58769 Mdot
.34035 .28214 Mdot
.2403 .40363 Mdot
.78289 .59358 Mdot
.8194 .41163 Mdot
.38135 .39183 Mdot
.71975 .48016 Mdot
.30475 .70584 Mdot
.63265 .44469 Mdot
.55276 .40305 Mdot
.21735 .64768 Mdot
.17742 .43065 Mdot
.67538 .55178 Mdot
.45419 .1689 Mdot
.67111 .69499 Mdot
.74587 .72845 Mdot
.51457 .48869 Mdot
.69454 .5114 Mdot
.43035 .29148 Mdot
.71091 .39479 Mdot
.50264 .29562 Mdot
.7705 .47003 Mdot
.35671 .61363 Mdot
.40819 .75218 Mdot
.66154 .46342 Mdot
.70492 .58545 Mdot
.52724 .22763 Mdot
.56398 .32469 Mdot
.35214 .46613 Mdot
.19124 .56834 Mdot
.50918 .19208 Mdot
.6121 .39217 Mdot
.57686 .24291 Mdot
.35638 .8144 Mdot
.41867 .67212 Mdot
.19633 .51854 Mdot
.49429 .31676 Mdot
.45167 .70136 Mdot
.69804 .35056 Mdot
.42884 .7185 Mdot
.73298 .40346 Mdot
.48299 .83849 Mdot
.22728 .3433 Mdot
.39743 .81931 Mdot
.62673 .46912 Mdot
.55685 .68702 Mdot
.21798 .59013 Mdot
.73369 .6851 Mdot
.38446 .58894 Mdot
.32782 .78727 Mdot
.35035 .60373 Mdot
.62534 .47922 Mdot
.64628 .30563 Mdot
.75036 .50815 Mdot
.32775 .34522 Mdot
.34547 .53946 Mdot
.4756 .65554 Mdot
.65985 .83458 Mdot
.23434 .67507 Mdot
.60149 .33659 Mdot
.18323 .42156 Mdot
.48608 .33426 Mdot
.42639 .43493 Mdot
.49077 .36711 Mdot
.14566 .51762 Mdot
.65897 .48242 Mdot
.14015 .44022 Mdot
.15278 .49105 Mdot
.7454 .31882 Mdot
.76503 .7743 Mdot
.57168 .19587 Mdot
.65228 .58305 Mdot
.52335 .77064 Mdot
.44011 .77961 Mdot
.72777 .35478 Mdot
.73272 .29889 Mdot
.55115 .32153 Mdot
.27769 .29159 Mdot
.15081 .55422 Mdot
.37044 .66423 Mdot
.23128 .43028 Mdot
.6689 .32432 Mdot
.48875 .49271 Mdot
.7374 .47794 Mdot
.47293 .51837 Mdot
.55262 .51832 Mdot
.37259 .8035 Mdot
.79416 .61807 Mdot
.858 .47759 Mdot
.31019 .59729 Mdot
.69998 .25402 Mdot
.20024 .44716 Mdot
.35757 .73327 Mdot
.7617 .47556 Mdot
.64429 .34897 Mdot
.47061 .61204 Mdot
.67383 .37981 Mdot
.58437 .70495 Mdot
.3894 .60856 Mdot
.71898 .37852 Mdot
.39711 .34905 Mdot
.32267 .63217 Mdot
.25784 .66936 Mdot
.61454 .43385 Mdot
.68873 .44 Mdot
.45412 .73353 Mdot
.40657 .66877 Mdot
.18872 .42822 Mdot
.69083 .28803 Mdot
.28043 .26954 Mdot
.71034 .29504 Mdot
.4756 .63411 Mdot
.62932 .56471 Mdot
.60721 .61587 Mdot
.42147 .70036 Mdot
.48659 .66546 Mdot
.57112 .25596 Mdot
.18569 .39831 Mdot
.77311 .651 Mdot
.33579 .62885 Mdot
.62461 .76261 Mdot
.25732 .30631 Mdot
.22902 .60206 Mdot
.63358 .24496 Mdot
.62174 .67794 Mdot
.58574 .84903 Mdot
.33993 .40959 Mdot
.38807 .67086 Mdot
.53382 .40153 Mdot
.28028 .54192 Mdot
.4283 .80513 Mdot
.74638 .3287 Mdot
.18818 .39182 Mdot
.65391 .35307 Mdot
.37993 .46037 Mdot
.49485 .43345 Mdot
.30249 .36048 Mdot
.61424 .76954 Mdot
.58678 .67755 Mdot
.44467 .5905 Mdot
.33243 .5639 Mdot
.73591 .66973 Mdot
.24181 .60353 Mdot
.40522 .23172 Mdot
.4667 .60071 Mdot
.4017 .26191 Mdot
.5076 .2253 Mdot
.48758 .45231 Mdot
.15582 .62323 Mdot
.55245 .55437 Mdot
.59929 .20849 Mdot
.23657 .33066 Mdot
.39843 .48542 Mdot
.20632 .50715 Mdot
.61133 .30331 Mdot
.44287 .83155 Mdot
.15847 .45012 Mdot
.27715 .34696 Mdot
.20776 .65822 Mdot
.28956 .23654 Mdot
.49655 .82928 Mdot
.62832 .7371 Mdot
.55178 .37487 Mdot
.14651 .34933 Mdot
.36843 .41044 Mdot
.65826 .76824 Mdot
.7413 .67826 Mdot
.27721 .48176 Mdot
.70454 .4288 Mdot
.5057 .72158 Mdot
.49493 .19934 Mdot
.71362 .50859 Mdot
.47494 .65583 Mdot
.30566 .78326 Mdot
.49803 .84599 Mdot
.32069 .79056 Mdot
.26413 .31712 Mdot
.20019 .65012 Mdot
.34742 .76023 Mdot
.77647 .52207 Mdot
.27799 .65073 Mdot
.50844 .6655 Mdot
.36984 .68494 Mdot
.58075 .20182 Mdot
.37081 .46998 Mdot
.52688 .28403 Mdot
.67612 .43217 Mdot
.44637 .82274 Mdot
.16605 .65419 Mdot
.68387 .6568 Mdot
.74929 .58699 Mdot
.53833 .5104 Mdot
.40905 .69514 Mdot
.42561 .60601 Mdot
.3565 .25997 Mdot
.19485 .43528 Mdot
.3622 .7753 Mdot
.38501 .65286 Mdot
.43549 .23738 Mdot
.323 .33355 Mdot
.68086 .24517 Mdot
.17619 .55151 Mdot
.34048 .73771 Mdot
.72382 .29669 Mdot
.61289 .70198 Mdot
.76017 .36002 Mdot
.35413 .24164 Mdot
.41731 .42996 Mdot
.41084 .65214 Mdot
.31791 .42093 Mdot
.36978 .66916 Mdot
.57339 .44806 Mdot
.28552 .6792 Mdot
.47464 .73474 Mdot
.36096 .66303 Mdot
.31667 .33665 Mdot
.26429 .73807 Mdot
.33898 .20717 Mdot
.57604 .81776 Mdot
.39472 .19636 Mdot
.58356 .70744 Mdot
.52655 .68534 Mdot
.21239 .35873 Mdot
.24965 .73217 Mdot
.16384 .41772 Mdot
.59495 .26088 Mdot
.30445 .49916 Mdot
.54879 .34615 Mdot
.6049 .79545 Mdot
.39906 .21425 Mdot
.1767 .46212 Mdot
.76118 .42639 Mdot
.47826 .38863 Mdot
.66301 .35584 Mdot
.63071 .77444 Mdot
.5519 .7835 Mdot
.71261 .59931 Mdot
.59881 .58651 Mdot
.67504 .57596 Mdot
.71519 .4927 Mdot
.60224 .25491 Mdot
.42176 .70956 Mdot
.33846 .4046 Mdot
.36638 .75471 Mdot
.45772 .57778 Mdot
.47191 .60811 Mdot
.40746 .44236 Mdot
.73202 .48773 Mdot
.66714 .7449 Mdot
.55755 .32782 Mdot
.13694 .55971 Mdot
.59626 .22159 Mdot
.45506 .69281 Mdot
.44571 .7109 Mdot
.28966 .56839 Mdot
.65923 .37561 Mdot
.4867 .35747 Mdot
.17368 .58539 Mdot
.44659 .52095 Mdot
.45307 .72855 Mdot
.6786 .57752 Mdot
.26186 .59622 Mdot
.56613 .58441 Mdot
.5984 .30814 Mdot
.79402 .54036 Mdot
.47384 .44894 Mdot
.629 .50083 Mdot
.72885 .4979 Mdot
.53639 .14682 Mdot
.32916 .31109 Mdot
.67827 .26882 Mdot
.17768 .58481 Mdot
.48847 .37638 Mdot
.64822 .45158 Mdot
.35464 .66887 Mdot
.2422 .5519 Mdot
.79476 .57667 Mdot
.39719 .38325 Mdot
.4135 .61601 Mdot
.39085 .22895 Mdot
.20639 .64688 Mdot
.2888 .73982 Mdot
.82615 .44262 Mdot
.64513 .49917 Mdot
.24487 .58303 Mdot
.25779 .58094 Mdot
.65152 .50191 Mdot
.72826 .42882 Mdot
.58264 .48282 Mdot
.17565 .63173 Mdot
.6608 .3843 Mdot
.3604 .21704 Mdot
.40682 .48591 Mdot
.27543 .46334 Mdot
.27923 .56963 Mdot
.40497 .64027 Mdot
.18087 .58461 Mdot
.69793 .59592 Mdot
.48731 .8075 Mdot
.60472 .58966 Mdot
.73993 .70308 Mdot
.60871 .79531 Mdot
.507 .48425 Mdot
.72595 .52525 Mdot
.4117 .36078 Mdot
.5455 .60784 Mdot
.35206 .8132 Mdot
.20571 .41387 Mdot
.74178 .39358 Mdot
.56549 .33806 Mdot
.50437 .615 Mdot
.48502 .651 Mdot
.55533 .74479 Mdot
.60907 .3525 Mdot
.54817 .82768 Mdot
.31304 .62566 Mdot
.5925 .70108 Mdot
.68699 .5708 Mdot
.60147 .21035 Mdot
.19999 .57928 Mdot
.20491 .43383 Mdot
.55503 .45522 Mdot
.58298 .20559 Mdot
.44335 .43348 Mdot
.35466 .21619 Mdot
.37866 .27086 Mdot
.33376 .74759 Mdot
.6077 .49652 Mdot
.62584 .34787 Mdot
.29247 .55791 Mdot
.55709 .67694 Mdot
.63676 .2995 Mdot
.1778 .52752 Mdot
.86544 .52178 Mdot
.70028 .34358 Mdot
.28779 .77323 Mdot
.51991 .54373 Mdot
.63016 .35608 Mdot
.45072 .81456 Mdot
.86714 .58238 Mdot
.34584 .27172 Mdot
.36146 .7949 Mdot
.46847 .42819 Mdot
.18053 .5999 Mdot
.54745 .37007 Mdot
.62421 .41034 Mdot
.63262 .75315 Mdot
.17114 .62452 Mdot
.20749 .5555 Mdot
.19363 .59226 Mdot
.58707 .74334 Mdot
.20118 .66251 Mdot
.75099 .42252 Mdot
.57434 .16557 Mdot
.34866 .45732 Mdot
.55583 .24042 Mdot
.61853 .72009 Mdot
.54729 .5312 Mdot
.38864 .66343 Mdot
.6608 .21191 Mdot
.78711 .47612 Mdot
.59434 .74767 Mdot
.34761 .70034 Mdot
.61477 .31606 Mdot
.44668 .70852 Mdot
.16937 .47729 Mdot
.56023 .16663 Mdot
.27077 .57268 Mdot
.64449 .26509 Mdot
.27651 .30504 Mdot
.60496 .35126 Mdot
.37386 .30303 Mdot
.19498 .51902 Mdot
.32766 .25418 Mdot
.41882 .60745 Mdot
.58552 .13062 Mdot
.24711 .41107 Mdot
.58099 .48626 Mdot
.42033 .82201 Mdot
.19809 .4311 Mdot
.76681 .43455 Mdot
.78688 .39668 Mdot
.73015 .71942 Mdot
.39059 .71058 Mdot
.5352 .67431 Mdot
.20644 .67528 Mdot
.38854 .74266 Mdot
.34863 .79805 Mdot
.23712 .31124 Mdot
.66628 .59581 Mdot
.50316 .5682 Mdot
.37933 .37462 Mdot
.54138 .49531 Mdot
.33684 .69178 Mdot
.36567 .78744 Mdot
.69791 .74377 Mdot
.36664 .49504 Mdot
.41148 .30683 Mdot
.40011 .38284 Mdot
.6221 .63829 Mdot
.56817 .20382 Mdot
.6161 .33573 Mdot
.31731 .60938 Mdot
.31094 .33153 Mdot
.40422 .68315 Mdot
.70946 .57379 Mdot
.54502 .78779 Mdot
.73588 .33681 Mdot
.50241 .4223 Mdot
.38368 .39235 Mdot
.28351 .70836 Mdot
.2444 .38585 Mdot
.57004 .2605 Mdot
.54056 .81422 Mdot
.64568 .34372 Mdot
.30732 .65244 Mdot
.25371 .6367 Mdot
.72573 .34835 Mdot
.48551 .26135 Mdot
.5719 .78635 Mdot
.74155 .70061 Mdot
.40741 .37355 Mdot
.45302 .62876 Mdot
.14761 .56909 Mdot
.40634 .64576 Mdot
.27078 .66022 Mdot
.50114 .50056 Mdot
.7565 .64135 Mdot
.6428 .65755 Mdot
.39893 .76517 Mdot
.4504 .44772 Mdot
.63234 .84019 Mdot
.72073 .44222 Mdot
.35934 .81694 Mdot
.51014 .35674 Mdot
.82913 .50267 Mdot
.29174 .34717 Mdot
.55112 .46684 Mdot
.43678 .47444 Mdot
.5959 .3093 Mdot
.59088 .39933 Mdot
.26987 .30471 Mdot
.75672 .34902 Mdot
.31967 .38358 Mdot
.37529 .50408 Mdot
.35855 .22421 Mdot
.26101 .68712 Mdot
.59117 .64568 Mdot
.25061 .38841 Mdot
.50182 .48566 Mdot
.37098 .47429 Mdot
.21431 .36031 Mdot
.423 .35742 Mdot
.54015 .70465 Mdot
.4109 .69927 Mdot
.38392 .80055 Mdot
.15802 .4822 Mdot
.76809 .38879 Mdot
.58523 .70413 Mdot
.55185 .38579 Mdot
.41634 .78956 Mdot
.23414 .6679 Mdot
.42809 .39143 Mdot
.62214 .39547 Mdot
.41396 .66653 Mdot
.38575 .85054 Mdot
.49174 .84291 Mdot
.55879 .82074 Mdot
.3923 .4894 Mdot
.65609 .52173 Mdot
.80624 .60251 Mdot
.26953 .65701 Mdot
.54677 .25567 Mdot
.237 .37917 Mdot
.39364 .67267 Mdot
.85255 .5856 Mdot
.77562 .48399 Mdot
.28634 .45074 Mdot
.64353 .66065 Mdot
.71881 .7017 Mdot
.54616 .35275 Mdot
.38 .71335 Mdot
.4167 .53366 Mdot
.48541 .38944 Mdot
.61537 .32006 Mdot
.599 .40038 Mdot
.27197 .66254 Mdot
.78926 .56363 Mdot
.60492 .67468 Mdot
.24335 .66028 Mdot
.68478 .52094 Mdot
.28058 .55678 Mdot
.28354 .58751 Mdot
.40133 .52859 Mdot
.36908 .3923 Mdot
.57108 .54915 Mdot
.50367 .44412 Mdot
.45823 .43188 Mdot
.64103 .79951 Mdot
.34416 .60167 Mdot
.69772 .43459 Mdot
.78888 .4385 Mdot
.64052 .49119 Mdot
.23388 .72019 Mdot
.35667 .26116 Mdot
.68149 .56902 Mdot
.27307 .37743 Mdot
.43106 .26414 Mdot
.74827 .74006 Mdot
.5944 .78048 Mdot
.49504 .51933 Mdot
.75291 .44342 Mdot
.6811 .50858 Mdot
.31749 .35072 Mdot
.49779 .26111 Mdot
.72374 .58832 Mdot
.59219 .19832 Mdot
.28189 .64555 Mdot
.68218 .51423 Mdot
.27495 .44668 Mdot
.46303 .70231 Mdot
.14902 .59699 Mdot
.35692 .37331 Mdot
.56094 .8485 Mdot
.59658 .61231 Mdot
.4614 .80652 Mdot
.20818 .36649 Mdot
.70695 .36707 Mdot
.3716 .48713 Mdot
.46704 .22311 Mdot
.58879 .62931 Mdot
.61392 .64874 Mdot
.66289 .45821 Mdot
.27654 .62321 Mdot
.35318 .57619 Mdot
.44512 .75515 Mdot
.48912 .39617 Mdot
.7213 .28058 Mdot
.57443 .21142 Mdot
.72276 .47471 Mdot
.43765 .53396 Mdot
.21976 .57701 Mdot
.59914 .44358 Mdot
.5 .48505 Mdot
.2989 .72915 Mdot
.79148 .58639 Mdot
.68244 .51326 Mdot
.54241 .81688 Mdot
.29212 .61556 Mdot
.14324 .49478 Mdot
.45173 .66878 Mdot
.53154 .48852 Mdot
.60326 .44233 Mdot
.60055 .30251 Mdot
.71844 .57667 Mdot
.19591 .44094 Mdot
.44415 .72667 Mdot
.67937 .39785 Mdot
.36086 .66496 Mdot
.58898 .68553 Mdot
.40691 .30735 Mdot
.55519 .22322 Mdot
.84196 .60821 Mdot
.65538 .69538 Mdot
.6856 .35765 Mdot
.74603 .4711 Mdot
.59694 .20746 Mdot
.70807 .43691 Mdot
.25294 .4996 Mdot
.78371 .60109 Mdot
.28178 .35214 Mdot
.14397 .53774 Mdot
.19101 .42594 Mdot
.56863 .50858 Mdot
.40698 .4167 Mdot
.4716 .72595 Mdot
.46628 .70391 Mdot
.47583 .46603 Mdot
.58706 .63587 Mdot
.60866 .68807 Mdot
.76052 .38623 Mdot
.57439 .2721 Mdot
.51333 .72388 Mdot
.16651 .60121 Mdot
.14668 .48288 Mdot
.23076 .69268 Mdot
.42937 .40802 Mdot
.68022 .43656 Mdot
.45521 .8338 Mdot
.7401 .54791 Mdot
.16774 .47485 Mdot
.62084 .72318 Mdot
.5173 .14713 Mdot
.41571 .80372 Mdot
.40137 .35434 Mdot
.74255 .31273 Mdot
.55204 .30024 Mdot
.21841 .36238 Mdot
.57307 .16539 Mdot
.394 .62142 Mdot
.2195 .34919 Mdot
.65795 .83435 Mdot
.64 .72257 Mdot
.60565 .39356 Mdot
.63973 .63565 Mdot
.45864 .70514 Mdot
.58828 .1891 Mdot
.51296 .67188 Mdot
.31452 .42379 Mdot
.35532 .49908 Mdot
.40221 .67619 Mdot
.47947 .57096 Mdot
.59795 .19258 Mdot
.33035 .68633 Mdot
.30699 .64244 Mdot
.25339 .56879 Mdot
.3826 .78996 Mdot
.72674 .57926 Mdot
.52219 .70514 Mdot
.62309 .49376 Mdot
.38136 .56749 Mdot
.35053 .62453 Mdot
.49374 .62579 Mdot
.37543 .48041 Mdot
.59131 .48201 Mdot
.30477 .78509 Mdot
.24893 .52801 Mdot
.22104 .4948 Mdot
.72486 .50073 Mdot
.60939 .33865 Mdot
.22457 .61172 Mdot
.64943 .31275 Mdot
.62186 .2004 Mdot
.78995 .62548 Mdot
.21147 .65374 Mdot
.6444 .35797 Mdot
.36048 .6427 Mdot
.6909 .77512 Mdot
.5283 .39298 Mdot
.67075 .73634 Mdot
.34903 .76627 Mdot
.63956 .32058 Mdot
.62931 .48671 Mdot
.3747 .33562 Mdot
.42306 .32129 Mdot
.62985 .31925 Mdot
.23963 .32697 Mdot
.24865 .5969 Mdot
.65444 .63283 Mdot
.27388 .72069 Mdot
.36156 .44557 Mdot
.38362 .6543 Mdot
.35087 .31958 Mdot
.57402 .17773 Mdot
.61508 .42885 Mdot
.15214 .58064 Mdot
.46566 .46447 Mdot
.39639 .75097 Mdot
.5233 .61248 Mdot
.76681 .56369 Mdot
.58263 .28395 Mdot
.33338 .3301 Mdot
.67911 .27581 Mdot
.70483 .44952 Mdot
.58225 .23325 Mdot
.50459 .28048 Mdot
.39218 .72565 Mdot
.4533 .5746 Mdot
.6167 .50889 Mdot
.3198 .57004 Mdot
.51749 .20834 Mdot
.59015 .65871 Mdot
.42612 .76548 Mdot
.31922 .34398 Mdot
.65187 .74274 Mdot
.6344 .73421 Mdot
.28443 .71117 Mdot
.21525 .43612 Mdot
.56332 .25959 Mdot
.61283 .73935 Mdot
.58581 .36401 Mdot
.76918 .50083 Mdot
.65777 .2974 Mdot
.5074 .68402 Mdot
.25449 .49618 Mdot
.65016 .4538 Mdot
.26597 .69662 Mdot
.64141 .54087 Mdot
.37275 .74808 Mdot
.5188 .45976 Mdot
.21162 .58561 Mdot
.47125 .49824 Mdot
.20999 .36709 Mdot
.54912 .29756 Mdot
.42339 .71185 Mdot
.47874 .35618 Mdot
.46786 .42576 Mdot
.70561 .3407 Mdot
.16196 .54279 Mdot
.74358 .33637 Mdot
.53148 .76637 Mdot
.67356 .35499 Mdot
.75191 .68194 Mdot
.22569 .32714 Mdot
.41442 .71826 Mdot
.47805 .466 Mdot
.43237 .63409 Mdot
.57186 .3372 Mdot
.50413 .2517 Mdot
.2688 .49827 Mdot
.73578 .56433 Mdot
.23234 .47252 Mdot
.30967 .4554 Mdot
.57714 .67652 Mdot
.81335 .58351 Mdot
.25749 .6984 Mdot
.7668 .446 Mdot
.53596 .4735 Mdot
.31016 .53099 Mdot
.39856 .73317 Mdot
.76356 .25281 Mdot
.34703 .81212 Mdot
.52179 .61332 Mdot
.41071 .4893 Mdot
.43592 .74979 Mdot
.34409 .43699 Mdot
.72546 .59632 Mdot
.2804 .70818 Mdot
.52038 .38842 Mdot
.29925 .50852 Mdot
.52406 .27073 Mdot
.58887 .30111 Mdot
.39214 .76578 Mdot
.5234 .31894 Mdot
.25656 .74614 Mdot
.24869 .36765 Mdot
.58823 .28135 Mdot
.66061 .1644 Mdot
.58448 .25497 Mdot
.67621 .52658 Mdot
.20056 .54784 Mdot
.25896 .73244 Mdot
.39566 .48813 Mdot
.28149 .53622 Mdot
.63706 .73523 Mdot
.43124 .71898 Mdot
.3235 .64284 Mdot
.64217 .26393 Mdot
.5957 .23903 Mdot
.58376 .16851 Mdot
.432 .26229 Mdot
.65482 .79876 Mdot
.69009 .58931 Mdot
.29269 .74801 Mdot
.34856 .26759 Mdot
.85577 .57218 Mdot
.14596 .51865 Mdot
.36189 .68775 Mdot
.61894 .20573 Mdot
.2018 .53032 Mdot
.47002 .7687 Mdot
.80909 .54704 Mdot
.32668 .28087 Mdot
.79156 .60443 Mdot
.41948 .25786 Mdot
.67276 .29302 Mdot
.36609 .66679 Mdot
.73159 .69588 Mdot
.46057 .46224 Mdot
.33866 .77034 Mdot
.69605 .24236 Mdot
.43748 .7004 Mdot
.31099 .50962 Mdot
.48012 .78307 Mdot
.23919 .66337 Mdot
.18764 .51832 Mdot
.46425 .47599 Mdot
.66539 .82563 Mdot
.37074 .80148 Mdot
.66122 .31271 Mdot
.49396 .66979 Mdot
.1369 .52734 Mdot
.42864 .50031 Mdot
.61257 .74369 Mdot
.2291 .36577 Mdot
.30981 .61705 Mdot
.60134 .47321 Mdot
.54018 .69395 Mdot
.58624 .78596 Mdot
.70292 .53578 Mdot
.71657 .70612 Mdot
.33177 .52037 Mdot
.44603 .71386 Mdot
.70375 .25177 Mdot
.44547 .78761 Mdot
.47235 .70784 Mdot
.64758 .46171 Mdot
.27931 .75956 Mdot
.55381 .77508 Mdot
.58828 .55226 Mdot
.644 .59866 Mdot
.74898 .34178 Mdot
.48696 .1987 Mdot
.57396 .70994 Mdot
.65588 .37766 Mdot
.39142 .66413 Mdot
.26542 .64373 Mdot
.6167 .75595 Mdot
.78159 .76149 Mdot
.20162 .37275 Mdot
.72872 .44533 Mdot
.67441 .7243 Mdot
.37939 .51244 Mdot
.2357 .69513 Mdot
.43242 .23441 Mdot
.28694 .57539 Mdot
.78972 .36983 Mdot
.46461 .74891 Mdot
.52916 .57786 Mdot
.2581 .32072 Mdot
.15228 .52739 Mdot
.72052 .26009 Mdot
.148 .56759 Mdot
.50159 .57219 Mdot
.57137 .57372 Mdot
.88103 .46235 Mdot
.19195 .62432 Mdot
.51308 .56114 Mdot
.7695 .36401 Mdot
.69887 .4251 Mdot
.5158 .66789 Mdot
.52132 .27011 Mdot
.41528 .64486 Mdot
.31893 .64497 Mdot
.17372 .62751 Mdot
.68124 .51974 Mdot
.37156 .48315 Mdot
.539 .39454 Mdot
.44134 .46878 Mdot
.55923 .70577 Mdot
.51012 .33736 Mdot
.31914 .65481 Mdot
.41635 .50401 Mdot
.57622 .37787 Mdot
.4156 .60782 Mdot
.34559 .20955 Mdot
.57453 .53633 Mdot
.56043 .50814 Mdot
.59632 .72726 Mdot
.78845 .47375 Mdot
.33339 .68825 Mdot
.30933 .67521 Mdot
.22486 .34338 Mdot
.33588 .18788 Mdot
.28729 .38099 Mdot
.48393 .70926 Mdot
.63448 .43172 Mdot
.72505 .5668 Mdot
.64819 .62168 Mdot
.49295 .42352 Mdot
.50007 .23679 Mdot
.48237 .59254 Mdot
.45351 .68907 Mdot
.49311 .39815 Mdot
.34782 .82494 Mdot
.50722 .67271 Mdot
.68011 .61822 Mdot
.17114 .50703 Mdot
.28314 .55616 Mdot
.60753 .54074 Mdot
.58824 .62301 Mdot
.75395 .42482 Mdot
.41915 .50677 Mdot
.50127 .7457 Mdot
.27887 .57729 Mdot
.24426 .69771 Mdot
.59779 .53608 Mdot
.66947 .61141 Mdot
.54064 .63318 Mdot
.34408 .54192 Mdot
.60243 .40974 Mdot
.57532 .80397 Mdot
.44043 .58211 Mdot
.16353 .47066 Mdot
.29658 .60826 Mdot
.31289 .62472 Mdot
.65059 .56858 Mdot
.34583 .79858 Mdot
.6933 .34077 Mdot
.66454 .59015 Mdot
.7562 .39498 Mdot
.3797 .31474 Mdot
.34786 .69866 Mdot
.37824 .36877 Mdot
.51346 .7233 Mdot
.68703 .42277 Mdot
.178 .65155 Mdot
.60036 .77997 Mdot
.46382 .39431 Mdot
.40188 .37019 Mdot
.76029 .51306 Mdot
.44362 .47224 Mdot
.61845 .14544 Mdot
.44581 .21925 Mdot
.26169 .75104 Mdot
.25982 .61238 Mdot
.63332 .43142 Mdot
.61608 .31298 Mdot
.55098 .54527 Mdot
.33149 .41803 Mdot
.23951 .69693 Mdot
.43883 .63604 Mdot
.65547 .2872 Mdot
.49992 .65612 Mdot
.72333 .39337 Mdot
.46243 .7057 Mdot
.41308 .41115 Mdot
.31033 .40629 Mdot
.76297 .37493 Mdot
.18163 .53784 Mdot
.42069 .50765 Mdot
.5124 .15977 Mdot
.36759 .79039 Mdot
.17256 .58317 Mdot
.40045 .38537 Mdot
.83274 .49238 Mdot
.74635 .47568 Mdot
.47 .71073 Mdot
.47276 .36 Mdot
.53024 .77457 Mdot
.6336 .31697 Mdot
.26712 .63598 Mdot
.58849 .36133 Mdot
.58233 .46375 Mdot
.51272 .10107 Mdot
.35783 .67894 Mdot
.75674 .46958 Mdot
.62723 .29035 Mdot
.1621 .5802 Mdot
.40193 .56094 Mdot
.29696 .2525 Mdot
.33161 .29474 Mdot
.5685 .70341 Mdot
.79077 .54957 Mdot
.48658 .8024 Mdot
.445 .33705 Mdot
.69968 .77896 Mdot
.24166 .3897 Mdot
.3522 .63179 Mdot
.33613 .32802 Mdot
.64257 .49455 Mdot
.69823 .42752 Mdot
.36134 .24471 Mdot
.41881 .17029 Mdot
.52488 .74009 Mdot
.22358 .65871 Mdot
.78392 .69037 Mdot
.28015 .61695 Mdot
.20947 .6676 Mdot
.47468 .32932 Mdot
.73973 .43747 Mdot
.32386 .67926 Mdot
.32513 .53184 Mdot
.35225 .44137 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`0009?ooooo0_l0000?ooooo`;o00001_ooool2o`0009cooooo000Looooo`03o`00
0?oooooooooo09;ooooo0_l0000?ooooo`;o00001_ooool2o`0009cooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`2Zooooo`;o0000WOooool001cooooo00?o0000ooooooooool0Z_ooool2o`0009go
oooo000Looooo`03o`000?oooooooooo0:oooooo0_l0002Hooooo`007?ooool00ol0003ooooooooo
o`24ooooo`;o0000:Oooool2o`0009Sooooo000Looooo`03o`000?oooooooooo08Cooooo0_l00033
ooooo`007?ooool00ol0003oooooooooo`1jooooo`;o0000cOooool001cooooo00?o0000oooooooo
ool0N_ooool2o`0003kooooo0_l0002=ooooo`007?ooool00ol0003oooooooooo`2jooooo`;o0000
SOooool001cooooo00?o0000ooooooooool0L_ooool2o`0004cooooo0_l00027ooooo`007?ooool0
0ol0003oooooooooo`1booooo`;o0000C?ooool2o`0008Oooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0Y?ooool2o`0000Cooooo0_l0000Iooooo`;o
0000P_ooool001cooooo00?o0000ooooooooool0Y?ooool2o`0000Cooooo0_l0000Iooooo`;o0000
P_ooool001cooooo0_l0001Yooooo`;o0000goooool001cooooo00?o0000ooooooooool0J?ooool2
o`000=oooooo000Looooo`03o`000?oooooooooo0:?ooooo0_l0002Tooooo`007?ooool00ol0003o
ooooooooo`2>ooooo`;o00004oooool2o`000:Cooooo000Looooo`03o`000?oooooooooo08kooooo
1?l0000Tooooo`?o00006_ooool2o`0007Cooooo000Looooo`03o`000?oooooooooo05oooooo0_l0
000Tooooo`;o00002Oooool2o`0000;ooooo0_l0000Kooooo`?o00000_ooool3o`000003ooooool0
003o000001Oooooo0_l0001dooooo`007?ooool00ol0003oooooooooo`1Oooooo`;o00008oooool3
o`0000Wooooo0_l00002ooooo`;o00006oooool3o`0000Kooooo0_l0002=ooooo`007?ooool00ol0
003oooooooooo`24ooooo`;o000000?oooooo`000?l00000`?ooool001cooooo00?o0000oooooooo
ool0O_ooool4o`0000Gooooo0_l00004ooooo`;o00002oooool2o`0001_ooooo0_l0002@ooooo`00
7?ooool00ol0003oooooooooo`1kooooo`;o000000?oooooo`000?l000000_l00008ooooo`;o0000
00?oooooo`000?l000002oooool2o`0001_ooooo0_l0002@ooooo`007?ooool00ol0003ooooooooo
o`1kooooo`;o00002?ooool4o`000003ooooool0003o000000Wooooo0_l0002booooo`007?ooool0
0ol0003oooooooooo`1kooooo`;o00001oooool5o`0000cooooo1?l00002ooooo`;o0000[?ooool0
01cooooo00?o0000ooooooooool0JOooool2o`0000cooooo0_l0000;ooooo`;o00004Oooool2o`00
00;ooooo0_l0000Nooooo`;o00008?ooool2o`0006[ooooo00001_ooooook^k^oc8b<_l0003o<S8b
onk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`1Yooooo`;o00003?ooool2
o`0001?ooooo0_l0000Dooooo`;o00005_ooool3o`000003ooooool0003o000001gooooo0_l0001Z
ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^
k_ooooooA4A400Kooooo00?o0000ooooooooool0O?ooool4o`0000cooooo0_l0000Dooooo`?o0000
4Oooool2o`0000;ooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o000008;ooooo
00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00ol0003oooooooooo`1looooo`Co00006_ooool2o`000003ooooool0003o000000Cooooo0_l0
000Aooooo`;o00001Oooool2o`0000?ooooo0_l000000ooooooo0000o`000022ooooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0001c
ooooo`;o00003oooool2o`0001Cooooo0_l000000ooooooo0000o`00000Jooooo`;o00000_ooool2
o`0000Oooooo0_l00021ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<oooo
o`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0Loooool2o`0000oooooo0_l0000Moooo
o`;o00000oooool2o`0000Kooooo0_l00003ooooo`;o00000_ooool3o`0000;ooooo0_l00005oooo
o`?o0000POooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool03Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo06[ooooo0_l000000ooooooo0000o`00000dooooo`?o
00000_ooool2o`0000Kooooo0ol00002ooooo`;o00000oooool2o`0000;ooooo0ol00004ooooo`;o
00000_ooool2o`0007kooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj
^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo06[ooooo0_l000001?oooooo0000o`000?l0
000`ooooo`So00002Oooool2o`0000Cooooo0_l00005ooooo`Co00001oooool2o`0000Gooooo0_l0
00000ooooooo0000o`00001dooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1?ooooo`;o00006oooool4o`0000go
oooo0ol0000Pooooo`So00003oooool2o`000003ooooool0003o000000Cooooo0_l0000>ooooo`;o
000000?oooooo`000?l00000M?ooool001cooooo00?o0000ooooooooool0Coooool2o`0001_ooooo
0_l000000ooooooo0000o`000002o`0000[ooooo0ol0000?ooooo`Co00003Oooool8o`0001;ooooo
0_l0000Dooooo`;o0000Moooool001cooooo00?o0000ooooooooool0Koooool4o`0000[ooooo0_l0
0008ooooo`;o00001?ooool6o`0000Wooooo0_l000000ooooooo0000o`000007o`0000;ooooo0_l0
000Booooo`;o00004?ooool2o`0007Oooooo000Looooo`03o`000?oooooooooo077ooooo0_l0000D
ooooo`;o00001?ooool3o`0000?ooooo0ol00006ooooo`go000000?oooooo`000?l000001Oooool2
o`0000_ooooo0_l00029ooooo`007?ooool00ol0003oooooooooo`1aooooo`;o00006oooool2o`00
00?ooooo0ol00006ooooo`go00002?ooool2o`0002Gooooo0_l0001_ooooo`007?ooool00ol0003o
ooooooooo`1kooooo`;o00005oooool2o`0000Kooooo3ol0000Hooooo`;o00004oooool2o`0000_o
oooo0_l0001Rooooo`007?ooool00ol0003oooooooooo`1kooooo`;o00000oooool2o`0001[ooooo
3ol0000>ooooo`;o00002?ooool2o`00023ooooo0_l0001Rooooo`007?ooool00ol0003ooooooooo
o`1Jooooo`;o00009?ooool2o`0000Kooooo0ol0000Booooo`So000000Coooooo`000?l0003o0000
4?ooool2o`0008kooooo000Looooo`03o`000?oooooooooo05[ooooo0_l0000/ooooo`Co00004Ooo
ool<o`0001Gooooo0_l0000:ooooo`;o00003_ooool2o`0000_ooooo0_l0001Pooooo`007?ooool0
0ol0003oooooooooo`1Xooooo`;o00001Oooool2o`0001Wooooo0_l0000Aooooo`co00002?ooool2
o`0000Gooooo0_l00004ooooo`;o00002_ooool2o`0000kooooo0ol000000ooooooo0000o`000007
ooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0AOooool2o`0001[ooooo0_l00005oooo
o`;o00001Oooool2o`000003ooooool0003o000002Wooooo2ol00004ooooo`;o00000oooool2o`00
00Gooooo0ol0000?ooooo`;o00002oooool6o`000003ooooool0003o000006Wooooo000Looooo`03
o`000?oooooooooo04Gooooo0_l0000Jooooo`;o00003oooool2o`0000Oooooo0_l0000Kooooo`;o
00001?ooool;o`0000?ooooo0_l0000;ooooo`;o00001Oooool2o`0000Sooooo0_l000001?oooooo
0000o`000?l00007ooooo`Co0000K_ooool001cooooo0_l0001looooo`;o00006Oooool4o`0000Go
oooo2_l0000Eooooo`Co00002Oooool5o`00017ooooo0_l0001Vooooo`007?ooool00ol0003ooooo
ooooo`1Looooo`?o00000_ooool2o`0000Cooooo0_l0000Aooooo`;o00006_ooool2o`0000Oooooo
2_l00005ooooo`;o00002Oooool3o`000003ooooool0003o000000?o00002Oooool2o`0001?ooooo
0ol0000Aooooo`;o0000Doooool001cooooo00?o0000ooooooooool0G?ooool3o`0000;ooooo0_l0
0004ooooo`;o00004Oooool2o`0000Wooooo0_l0000Iooooo`Ko000000?oooooo`000?l000000_l0
0003ooooo`;o00001_ooool2o`000005ooooool0003o0000o`000?ooool00_l000000ooooooo0000
o`00000<ooooo`;o00004?ooool2o`0001;ooooo0_l0001Cooooo`007?ooool00ol0003ooooooooo
o`1Kooooo`;o00004oooool2o`0001?ooooo0_l0000Cooooo`;o00000_ooool7o`0000Cooooo0_l0
0003ooooo`;o00000oooool5o`0000;ooooo0_l000000ooooooo0000o`00000>ooooo`?o00001ooo
ool2o`0000Oooooo1?l00002ooooo`;o00001oooool2o`0005Sooooo000Looooo`03o`000?oooooo
oooo05_ooooo0_l0000Cooooo`;o00001oooool2o`0000Cooooo0_l00007ooooo`?o00003oooool2
o`0000;ooooo0_l00003ooooo`;o00001?ooool2o`0000Sooooo1?l00006ooooo`Co00003?ooool2
o`0000Cooooo0_l00002ooooo`;o00002Oooool2o`0000;ooooo0_l00007ooooo`;o0000F?ooool0
01cooooo00?o0000ooooooooool0Foooool2o`00013ooooo0_l0000:ooooo`;o00001?ooool2o`00
00Oooooo0ol0000>ooooo`;o00002?ooool2o`00017ooooo0_l00006ooooo`?o00003?ooool5o`00
0003ooooool0003o0000017ooooo0_l0001Qooooo`007?ooool00ol0003oooooooooo`1Gooooo`;o
00000_ooool2o`00013ooooo0_l00008ooooo`;o00004Oooool2o`0000cooooo0ol000000ooooooo
0000o`000005ooooo`;o000000?oooooo`000?l000003_ooool2o`0000Kooooo0_l0000>ooooo`Co
00001?ooool2o`000003ooooool0003o000000_ooooo0_l0001Qooooo`007?ooool00ol0003ooooo
ooooo`1Gooooo`;o00004?ooool2o`0000;ooooo0_l00008ooooo`;o000000?oooooo`000?l00000
3_ooool2o`0000cooooo0_l00002ooooo`;o00002?ooool2o`0000oooooo0_l0000Mooooo`So0000
5?ooool2o`0005Gooooo000Looooo`03o`000?oooooooooo06Kooooo0_l000000ooooooo0000o`00
0004o`0000_ooooo0_l0000Xooooo`;o000000?oooooo`000?l000003_ooool2o`0000Oooooo0_l0
0009ooooo`;o00002oooool6o`0000[ooooo0_l00008ooooo`;o0000EOooool001cooooo00?o0000
ooooooooool0I_ooool4o`000003ooooool0003o000003Oooooo0_l000000ooooooo0000o`00000:
ooooo`;o00002oooool2o`0000Wooooo0_l0000<ooooo`;o00003Oooool2o`0005oooooo000Loooo
o`03o`000?oooooooooo03cooooo0_l0000Xooooo`Co000000?oooooo`000?l000003Oooool2o`00
02Cooooo0_l0000Aooooo`?o00001Oooool2o`0000oooooo0_l00002ooooo`;o00000oooool2o`00
00Sooooo0_l00005ooooo`;o0000HOooool001cooooo00?o0000ooooooooool0??ooool2o`0001Wo
oooo0_l0000=ooooo`;o00000oooool2o`0000gooooo0_l0000Tooooo`;o00001Oooool2o`0000_o
oooo0_l00003ooooo`Co00002oooool2o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0000So
oooo0_l00005ooooo`;o00000oooool2o`0005cooooo000Looooo`03o`000?oooooooooo05Oooooo
0_l000001?oooooo0000o`000?l00009ooooo`;o0000?oooool2o`00013ooooo0_l0000=ooooo`;o
00001_ooool3o`0000[ooooo0_l0000<ooooo`;o000000?oooooo`000?l00000FOooool001cooooo
00?o0000ooooooooool0E_ooool2o`0000;ooooo0ol00008ooooo`?o00008?ooool2o`0002[ooooo
0ol0000Aooooo`;o00001oooool2o`0000[ooooo0_l0000?ooooo`;o0000FOooool001cooooo00?o
0000ooooooooool0>Oooool2o`0001_ooooo0_l00003ooooo`;o00000oooool2o`0000?ooooo0_l0
00000ooooooo0000o`00000Nooooo`;o00005?ooool2o`0000_ooooo0_l00007ooooo`?o00001?oo
ool2o`0000_ooooo1?l00003ooooo`;o000000?oooooo`000?l000000oooool2o`0000[ooooo0_l0
000Iooooo`;o0000BOooool001cooooo00?o0000ooooooooool0>Oooool2o`0001oooooo0_l00004
ooooo`;o00001_ooool2o`0000_ooooo0_l0000Wooooo`Co00002?ooool3o`0000;ooooo0_l0000:
ooooo`;o00001Oooool2o`0000Kooooo0_l00003ooooo`Go000000?oooooo`000?l000000_l0000:
ooooo`;o00000_ooool3o`0001Cooooo0_l00019ooooo`007?ooool2o`0005_ooooo0_l0000Ioooo
o`;o00004oooool2o`0001Cooooo0_l00008ooooo`;o00000oooool3o`0000Gooooo0_l00003oooo
o`;o00001?ooool2o`0000Kooooo0ol00004ooooo`Ko00002Oooool2o`0000Gooooo1Ol0001Moooo
o`007?ooool00ol0003oooooooooo`1Booooo`Co00000oooool2o`0000Oooooo0_l0000Booooo`;o
00003oooool2o`000003ooooool0003o000001?ooooo0_l0000?ooooo`;o00001Oooool2o`0000?o
oooo0_l000000ooooooo0000o`000002ooooo`;o00001_ooool2o`0000Oooooo0ol00009ooooo`;o
00002?ooool2o`000003ooooool0003o000005[ooooo000Looooo`03o`000?oooooooooo04cooooo
0_l00002ooooo`So000000Coooooo`000?l0003ooooo0_l00004ooooo`;o00004_ooool2o`0000So
oooo1?l00003ooooo`;o00005?ooool4o`0001kooooo0_l00002ooooo`;o00002Oooool2o`0001;o
oooo0_l00009ooooo`;o0000F_ooool001cooooo00?o0000ooooooooool0=_ooool2o`0001Cooooo
0_l00002ooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00005_ooool2o`0000Cooooo
1?l0000Iooooo`;o00007oooool3o`0000gooooo0_l00006ooooo`;o00002_ooool2o`0000Wooooo
0_l0000=ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0=_ooool2o`00017ooooo0_l0
0003ooooo`;o00000oooool5o`0000[ooooo0_l00003ooooo`;o00004Oooool2o`0000?ooooo0_l0
000Uooooo`;o00005_ooool3o`0000?ooooo0_l00007ooooo`Co00000_ooool2o`000003ooooool0
003o000001Gooooo0_l00004ooooo`;o00001oooool2o`0004_ooooo000Looooo`03o`000?oooooo
oooo04Wooooo0_l00003ooooo`;o00000_ooool6o`0000oooooo0_l0000?ooooo`;o00001Oooool2
o`000003ooooool0003o000001Gooooo0_l00002ooooo`;o00001oooool2o`0001cooooo0_l00004
ooooo`Oo00000_ooool2o`000003ooooool0003o000001Gooooo0_l00004ooooo`;o00003?ooool2
o`0004Kooooo000Looooo`03o`000?oooooooooo05;ooooo0_l0000:ooooo`;o00002?ooool4o`00
00;ooooo0_l00008ooooo`;o00002?ooool2o`0001Gooooo0_l00002ooooo`Co00001Oooool4o`00
01[ooooo0_l00003ooooo`Go00000_ooool2o`0000Cooooo0_l00004ooooo`;o00004?ooool2o`00
00kooooo0_l000000ooooooo0000o`000016ooooo`007?ooool00ol0003oooooooooo`1@ooooo`Co
00002_ooool2o`0000Gooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l0000Fooooo`;o
00005?ooool2o`000003ooooool0003o000000Gooooo1?l00005ooooo`;o00001?ooool2o`0000Co
oooo0_l000000ooooooo0000o`000004ooooo`;o00000oooool2o`000003ooooool0003o000000;o
oooo0_l0000:ooooo`;o00000_ooool2o`0000cooooo1?l0000<ooooo`;o0000BOooool001cooooo
00?o0000ooooooooool0COooool2o`000003ooooool0003o000001?ooooo1Ol0000Looooo`;o0000
3Oooool2o`0000Gooooo0_l00005ooooo`;o00002_ooool2o`0000;ooooo1_l00002ooooo`;o0000
00?oooooo`000?l000002Oooool2o`000003ooooool0003o000000Oooooo0_l00009ooooo`;o0000
3?ooool4o`0005Oooooo000Looooo`03o`000?oooooooooo037ooooo0_l0000Cooooo`;o00000_oo
ool2o`000003ooooool0003o000001Gooooo0_l000000ooooooo0000o`000002o`0002[ooooo0ol0
0007ooooo`;o000000?oooooo`000?l000000ol00009ooooo`Go00000_ooool2o`0000cooooo0_l0
0002ooooo`;o00002_ooool2o`0000Gooooo0_l0000Aooooo`;o00004_ooool2o`0004Cooooo000L
ooooo`03o`000?oooooooooo037ooooo0_l0000?ooooo`;o00000_ooool2o`000004ooooool0003o
0000o`0001Gooooo0_l000000ooooooo0000o`000003ooooo`;o0000:oooool2o`0000Cooooo2ol0
0002ooooo`;o00001Oooool3o`00013ooooo1?l0000Eooooo`;o00004Oooool2o`0000Gooooo0_l0
000;ooooo`Co0000@_ooool001cooooo00?o0000ooooooooool0@_ooool2o`0000Gooooo0_l0000F
ooooo`;o00000_ooool2o`0000;ooooo0_l0000Nooooo`;o00003ooooolEo`00013ooooo0_l00002
ooooo`?o00002_ooool2o`0000Cooooo0_l00005ooooo`;o00005oooool2o`0000gooooo0_l00012
ooooo`007?ooool00ol0003oooooooooo`1Sooooo`Co00003oooool2o`0000Gooooo0_l00004oooo
o`Co00000_ooool2o`0000;ooooo0_l00008ooooo`;o000000?oooooo`000?l000004ol00005oooo
o`Go00001_ooool7o`0000[ooooo0ol00003ooooo`;o00000_ooool2o`000003ooooool0003o0000
00cooooo1Ol0001Iooooo`007?ooool00ol0003oooooooooo`1Sooooo`;o00004Oooool2o`0000Go
oooo0_l00004ooooo`Co00001_ooool2o`0000Sooooo0_l00002oooooaCo00001Oooool5o`0000Ko
oooo1ol00009ooooo`Co00001oooool2o`000003ooooool0003o000000;ooooo0_l00008ooooo`Go
0000FOooool001cooooo00?o0000ooooooooool0AOooool3o`00017ooooo0_l00009ooooo`;o0000
0oooool2o`0002kooooo6?l00004ooooo`;o00005oooool4o`0000_ooooo1_l0000<ooooo`;o0000
4oooool2o`0004?ooooo000Looooo`03o`000?oooooooooo02cooooo0_l0000Dooooo`;o000000Co
ooooo`000?l0003o00003_ooool2o`000003ooooool0003o000000;o00001oooool2o`000003oooo
ool0003o000000;o00001_ooool2o`0001Oooooo0_l0000<ooooo`?o000000?oooooo`000?l00000
4ol00004ooooo`;o00003_ooool2o`000003ooooool0003o000000Cooooo1?l0000<ooooo`Co0000
1_ooool2o`0000Gooooo0_l00008ooooo`;o00002Oooool2o`0004?ooooo000Looooo`;o0000;Ooo
ool2o`0001Cooooo1?l0000@ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`;o00000_oo
ool2o`0000Sooooo0_l00004ooooo`;o00001?ooool2o`0000Kooooo0_l00003ooooo`;o00002Ooo
ool2o`000003ooooool0003o000000_o000000?oooooo`000?l000002?l0000Eooooo`;o000000?o
ooooo`000?l000000oooool5o`0000gooooo0_l000000ooooooo0000o`000004ooooo`Co00001_oo
ool2o`0000Gooooo0ol0001=ooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00005_ooool2
o`0001;ooooo0_l00005ooooo`;o00000_ooool2o`0000Wooooo0ol00006ooooo`;o00001?ooool2
o`0000Kooooo0_l0000>ooooo`;o00000oooool;o`000003ooooool0003o000000So00002Oooool2
o`0000Kooooo0ol00009ooooo`?o000000?oooooo`000?l000003?ooool2o`000004ooooool0003o
0000ooooo`;o000000?oooooo`000?l000000_l00004ooooo`Co00001_ooool2o`0000Oooooo0_l0
0014ooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00004Oooool2o`0000Sooooo0_l00005
ooooo`;o00000oooool4o`0000Gooooo0_l00006ooooo`;o00005ooooolBo`000003ooooool0003o
000000?o00002?ooool3o`0000Kooooo0ol00005ooooo`;o00001_ooool2o`000004ooooool0003o
0000ooooo`;o00003?ooool2o`0000;ooooo0_l00005ooooo`;o00004Oooool2o`0004Cooooo000L
ooooo`03o`000?oooooooooo047ooooo0ol000001?oooooo0000o`000?l0000Jooooo`;o00001Ooo
ool2o`0000Gooooo0_l000000ooooooo0000o`000002ooooo`;o00001_ooool2o`0000Gooooo0_l0
000>oooooaCo000000?oooooo`000?l000000ol000000ooooooo0000o`000005ooooo`?o00002Ooo
ool2o`0000?ooooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l000000ooooooo0000o`00
0002ooooo`;o00001Oooool2o`0000Gooooo0_l00008ooooo`;o0000E?ooool001cooooo00?o0000
ooooooooool0@Oooool4o`000003ooooool0003o000000cooooo0_l00009ooooo`;o00003_ooool7
o`0000cooooo0_l00002ooooo`;o00003_ooool3o`000003ooooool0003o000001Co000000?ooooo
o`000?l000001_ooool4o`0000Oooooo0ol00005ooooo`Co00002oooool3o`0000Cooooo0_l00006
ooooo`;o00001Oooool4o`0005Cooooo000Looooo`03o`000?oooooooooo03gooooo0_l00003oooo
o`?o00000_ooool2o`0000_ooooo0_l00009ooooo`;o000000Coooooo`000?l0003ooooo0_l00003
ooooo`;o000000?oooooo`000?l000001ol0000<ooooo`;o00004oooool=o`000003ooooool0003o
000000[o00002_ooool2o`0000Sooooo0_l00006ooooo`;o00003Oooool2o`0000Wooooo0_l00000
0ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000oooool2o`00057ooooo000Loooo
o`03o`000?oooooooooo03gooooo0_l000001?oooooo0000o`000?l00004ooooo`;o00001?ooool2
o`0000;ooooo0_l0000?ooooo`;o000000?oooooo`000?l000000_l000001?oooooo0000o`000?oo
ool3o`000003ooooool0003o000000;o00000_ooool2o`0000?ooooo0_l0000Hooooo`oo000000?o
ooooo`000?l000002Ol00004ooooo`;o00001?ooool2o`00013ooooo0_l00006ooooo`?o00001Ooo
ool7o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o00001_ooool2o`0000Cooooo0_l0
001;ooooo`007?ooool00ol0003oooooooooo`10ooooo`Co00000oooool2o`0000Cooooo0_l00002
ooooo`;o00005?oooolBo`0000?ooooo0_l000000ooooooo0000o`000005ooooo`;o00003_oooolJ
o`0000Gooooo0_l00004ooooo`;o00001?ooool2o`0001;ooooo4?l00004ooooo`;o00000oooool3
o`0000?ooooo0_l00006ooooo`?o0000B_ooool001cooooo00?o0000ooooooooool0?_ooool2o`00
00;ooooo0_l0000>ooooo`;o00004_oooolCo`0000Cooooo1_l000000ooooooo0000o`000002o`00
0003ooooool0003o000000gooooo0ol000000ooooooo0000o`00000Co`0000Sooooo1?l00004oooo
o`Co00002?ooool2o`0000?ooooo0_l00003ooooo`Oo00000oooool4o`000004ooooool0003o0000
ooooo`?o00000oooool2o`0000?ooooo0_l00007ooooo`;o0000B_ooool001cooooo00?o0000oooo
ooooool0?_ooool2o`0000;ooooo0_l00003ooooo`;o00002Oooool2o`000003ooooool0003o0000
00_ooooo0_l00002oooooaCo00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000003oooo
o`;o00001oooool2o`0000Gooooo6?l00006ooooo`Co00002?ooool2o`0000;ooooo0_l00004oooo
o`;o00000_ooool3o`0000Cooooo1_l00002ooooo`;o00001?ooool2o`0000;ooooo0_l00004oooo
o`;o00000_ooool2o`0005?ooooo000Looooo`03o`000?oooooooooo04Oooooo1?l0000:ooooo`;o
00000oooool2o`0000;ooooo0_l00002ooooo`;o00000_oooolEo`0000Kooooo0_l000000ooooooo
0000o`00000;ooooo`?o00001ooooolDo`0000Kooooo1?l00008ooooo`;o00001?ooool2o`0000;o
oooo0_l00004ooooo`;o00001?ooool7o`0000;ooooo0_l00004ooooo`;o000000Coooooo`000?l0
003o00001?ooool2o`0000Wooooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`19ooooo`;o
00002oooool2o`0000;ooooo0_l000001?oooooo0000o`000?l00002oooooako000000?oooooo`00
0?l000000_ooool2o`0000[ooooo0_l00008oooooaOo00000oooool2o`0000[ooooo0_l00008oooo
o`;o00001_ooool2o`000004ooooool0003o0000o`0000;ooooo0ol00002ooooo`;o00001oooool2
o`00013ooooo0_l00005ooooo`;o00001?ooool2o`0003oooooo000Looooo`03o`000?oooooooooo
03cooooo0_l000000ooooooo0000o`00000;ooooo`;o000000?oooooo`000?l000001Oooool2o`00
00Gooooo0_l00003oooooaSo000000?oooooo`000?l000000ol000000ooooooo0000o`000004o`00
013ooooo0_l00002ooooo`_o000000?oooooo`000?l000002Ol0000Looooo`;o00000oooool2o`00
0003ooooool0003o000000;o00002Oooool2o`0000?ooooo0ol00008ooooo`;o00002oooool4o`00
0004ooooool0003o0000ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0??ooool2o`00
0003ooooool0003o000000;o00002?ooool6o`00017ooooo6?l00004ooooo`Oo000000?oooooo`00
0?l000002_ooool2o`0000?ooooo6_l00006ooooo`;o00004?ooool3o`0000;ooooo0_l00008oooo
o`Go00001Oooool3o`0000?ooooo0_l00009ooooo`;o000000?oooooo`000?l000002?ooool2o`00
00?ooooo0_l00012ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool2
o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0<_ooool2o`0000Gooooo0_l00006
ooooo`;o00002?ooool5o`0000Sooooo0_l00003ooooo`;o00000_oooolJo`0000Gooooo0_l00004
ooooo`?o00002Oooool2o`0000Cooooo6Ol00006ooooo`;o00001?ooool2o`000003ooooool0003o
000000?o00000oooool4o`0000gooooo1?l00005ooooo`;o00000oooool2o`0000Cooooo1?l00005
ooooo`;o00003Oooool2o`0004;ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ
8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<_ooool2o`0000Gooooo0_l0
000Booooo`?o00002?ooool2o`0000?ooooo0_l00002oooooa_o00001?ooool2o`0000Gooooo0_l0
00000ooooooo0000o`000007ooooo`;o00000ooooolEo`0000;ooooo0_l0000<ooooo`;o000000?o
ooooo`000?l000000ol000000ooooooo0000o`000002o`0000cooooo0_l000000ooooooo0000o`00
0003o`0000Gooooo0_l00002ooooo`;o00001?ooool4o`000003ooooool0003o000000Sooooo0_l0
0007ooooo`;o0000@_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool5
o`0000Kooooo00?o0000ooooooooool0>Oooool2o`000003ooooool0003o0000027ooooo0_l00002
oooooaWo00002oooool2o`000003ooooool0003o000000Oooooo0_l000000ooooooo0000o`00000:
o`000003ooooool0003o000000?o000000?oooooo`000?l000000_l00009ooooo`;o00001?ooool2
o`0000Sooooo0ol0000=ooooo`Go000000?oooooo`000?l000001Oooool2o`0000gooooo0_l00008
ooooo`;o00002?ooool2o`00047ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`0003Wooooo1ol0000Noooooaoo00002_ooool2
o`0000_ooooo1?l000001?oooooo0000o`000?ooool6o`000003ooooool0003o000000?o000000Co
ooooo`000?l0003o00001?ooool2o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l00000
5_ooool4o`0002_ooooo0_l00011ooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooooooo
o`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool07oooool2o`00017ooooo
0_l00006ooooo`?o000000?oooooo`000?l000002_ooool2o`0001;ooooo7ol0000Gooooo`Co0000
1?ooool=o`000003ooooool0003o000000?ooooo0ol0000=ooooo`;o00006_ooool4o`0000_ooooo
0_l000000ooooooo0000o`00000Aooooo`;o0000Aoooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo01oooooo0_l0
000Aooooo`;o00001?ooool4o`0000kooooo0_l0000@oooooa3o000000?oooooo`000?l000003Ol0
000<ooooo`;o00003?ooool2o`0000Gooooo0ol00002ooooo`Oo00001_ooool2o`000003ooooool0
003o000000?ooooo0_l00007ooooo`;o00002?ooool2o`0000Gooooo0_l00008ooooo`Go00001ooo
ool2o`000004ooooool0003o0000ooooo`Co00003oooool3o`0000Wooooo0_l0000kooooo`0000Ko
ooooogMgMonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000oooooooo
ool0<?ooool2o`0000;ooooo0_l00002ooooo`Co00004Oooool2o`0000gooooo0ol00002ooooo`co
000000?oooooo`000?l000003?l00006ooooo`;o00001?ooool2o`0000_ooooo1?l00002ooooo`Co
00000oooool2o`0000;ooooo0_l0000:ooooo`;o00000oooool2o`0000Oooooo0_l00005ooooo`;o
000000?oooooo`000?l000001Oooool2o`0000_ooooo0_l00007ooooo`;o00001?ooool5o`0000_o
oooo0_l00002ooooo`;o00000oooool2o`0000Cooooo0_l0000kooooo`0000Koooooonk^k_lb<S;o
0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0<?ooool2o`00
00;ooooo0_l00009ooooo`;o00003?ooool2o`0000_ooooo0_l00005oooooa_o00001_ooool2o`00
017ooooo1?l00002ooooo`;o00002Oooool3o`0000kooooo0_l00004ooooo`Go00001Oooool4o`00
00Cooooo0_l0000<ooooo`;o000000?oooooo`000?l000002oooool2o`000003ooooool0003o0000
00_ooooo0_l00007ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0<_ooool2o`0000_o
oooo1?l0000Gooooo`;o00001OoooolCo`0000;ooooo3?l0000Tooooo`?o00003_ooool2o`0000Co
oooo1?l00008ooooo`;o00001?ooool3o`0000_ooooo0_l000000ooooooo0000o`000002o`000003
ooooool0003o000006;ooooo000Looooo`03o`000?oooooooooo03;ooooo0_l00004ooooo`;o0000
00?oooooo`000?l000000_l00002ooooo`;o00006_ooool2o`0000?ooooo5?l000000ooooooo0000
o`000009o`00037ooooo0ol00002ooooo`;o00005_ooool2o`0000;ooooo0ol00006ooooo`;o0000
0oooool2o`000003ooooool0003o000000[ooooo0_l00008ooooo`;o00000_ooool2o`0000Oooooo
0_l0000oooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00000oooool2o`000003ooooool0
003o000000;o000000Coooooo`000?l0003o00006_ooool2o`0000?ooooo6_l00009ooooo`;o0000
2_ooool2o`0000Wooooo0_l000000ooooooo0000o`00000Booooo`Oo00004?ooool2o`0000Sooooo
0ol000001?oooooo0000o`000?ooool4o`0000Kooooo0_l00009ooooo`Co00001_ooool3o`0000;o
oooo0_l00007ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0<oooool2o`0000;ooooo
1Ol00004ooooo`?o00007ooooolKo`0000Sooooo0_l000000ooooooo0000o`000007ooooo`;o0000
00?oooooo`000?l000001_ooool2o`000003ooooool0003o000000oooooo0_l000001?oooooo0000
o`000?ooool2o`0000cooooo0_l00004ooooo`;o00002?ooool3o`000004ooooool0003o0000oooo
o`;o00000_ooool2o`0000Cooooo0_l00009ooooo`Go00001Oooool2o`000003ooooool0003o0000
04[ooooo000Looooo`03o`000?oooooooooo03Kooooo1_l0000;ooooo`;o00004oooool2o`0000Co
oooo1ol000000ooooooo0000o`00000Ao`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o
00002_ooool2o`0001[ooooo0_l0000Booooo`;o00003oooool4o`0000;ooooo2?l00006ooooo`;o
00000_ooool2o`0000Cooooo0_l00007ooooo`?o00003oooool2o`0003Wooooo000Looooo`03o`00
0?oooooooooo02gooooo0_l00007ooooo`;o000000Goooooo`000?l0003o0000ooooo`05o`0000;o
oooo0_l000000ooooooo0000o`00000Cooooo`;o00001?oooolJo`000004ooooool0003o0000oooo
o`?o000000?oooooo`000?l000001_ooool4o`000004ooooool0003o0000ooooo`;o00001oooool2
o`0000Gooooo0_l0000Nooooo`;o00001?ooool2o`0000_ooooo2?l00002ooooo`;o000000?ooooo
o`000?l000000oooool2o`0000;ooooo0_l00002ooooo`;o00002Oooool2o`00013ooooo0_l0000i
ooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o00001oooool2o`0000Cooooo2ol0000Koooo
o`;o00000_oooolIo`000003ooooool0003o000000Gooooo0_l00003ooooo`Co000000?oooooo`00
0?l000002_ooool2o`0000Gooooo0_l0000<ooooo`;o00004?ooool2o`0000Cooooo0_l00004oooo
o`;o00000oooool<o`000003ooooool0003o000000;o00000oooool2o`0000Kooooo0_l00002oooo
o`;o00000oooool2o`0004gooooo000Looooo`03o`000?oooooooooo02[ooooo0_l0000:ooooo`Co
00000_ooool2o`0000Cooooo1Ol0000Oooooo`Wo00000_ooool8o`000003ooooool0003o000000;o
00002Oooool2o`0000Gooooo0_l0000Kooooo`;o00001Oooool2o`0001cooooo5Ol00007ooooo`?o
00001_ooool2o`0000?ooooo1?l0001;ooooo`007?ooool00ol0003oooooooooo`0Zooooo`;o0000
2_ooool4o`0000;ooooo0_l0000Jooooo`;o00003OoooolBo`0000Sooooo0_l00004ooooo`;o0000
1Oooool2o`0001Wooooo1?l0000Aooooo`Co00003OoooolIo`0000Cooooo0ol00006ooooo`;o0000
0_ooool2o`000003ooooool0003o000000Wooooo1?l0000nooooo`007?ooool00ol0003ooooooooo
o`0fooooo`;o00000_ooool4o`0001[ooooo0_l0000:oooooa?o00001?ooool2o`0000Cooooo0_l0
0004ooooo`;o00005oooool3o`000003ooooool0003o000000?ooooo0_l0000Cooooo`Co00001?oo
ool2o`0000;ooooo0_l00003oooooaco00000_ooool2o`0000;ooooo0_l00002ooooo`;o00000_oo
ool2o`0000cooooo1?l0000nooooo`007?ooool00ol0003oooooooooo`0jooooo`;o000000?ooooo
o`000?l000005oooool2o`0000cooooo4?l000000ooooooo0000o`000004ooooo`;o00004?ooool5
o`0000Cooooo0_l00005ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`00013ooooo0_l0
0003ooooo`;o00000_ooool2o`0000?ooooo1?l00002ooooo`;o000000Coooooo`000?l0003ooooo
5?l000001?oooooo0000o`000?ooool5o`0000Cooooo1_l00002ooooo`;o000000?oooooo`000?l0
00000_ooool2o`0000Oooooo0_l0000nooooo`007?ooool2o`00037ooooo0_l0000;ooooo`;o0000
5oooool2o`000003ooooool0003o000000cooooo4_l0000?ooooo`;o00000_ooool6o`0000Cooooo
1?l000000ooooooo0000o`000003o`000003ooooool0003o000001?ooooo0_l00003ooooo`;o0000
1oooool2o`0000Oooooo6_l00003ooooo`?o00001_ooool4o`0000Gooooo0_l00002ooooo`;o0000
Aoooool001cooooo00?o0000ooooooooool0<?ooool2o`0002Cooooo0_l000001?oooooo0000o`00
0?ooool2o`0000?ooooo0_l0000;ooooo`Oo00000_ooool2o`0000Wooooo0_l00004ooooo`?o0000
00?oooooo`000?l000001?l00003ooooo`So000000?oooooo`000?l000004Oooool2o`0001Wooooo
5ol000001?oooooo0000o`000?l00002ooooo`Co00001_ooool4o`0005;ooooo000Looooo`03o`00
0?oooooooooo03_ooooo0_l0000Hooooo`?o00000oooool4o`0000;ooooo0_l0000;ooooo`Oo0000
2oooool4o`0000Gooooo0_l00003ooooo`;o00001Oooool7o`0001Gooooo0_l0000<ooooo`Go0000
2?ooool;o`000003ooooool0003o000000?o000000?oooooo`000?l000000ol00002ooooo`;o0000
0_ooool4o`0000?ooooo0_l0000Fooooo`;o0000?oooool001cooooo00?o0000ooooooooool0;ooo
ool2o`0000[ooooo0_l00008ooooo`;o00002_ooool2o`0000;ooooo0_l00004ooooo`Co000000?o
ooooo`000?l000001_ooool2o`0000?ooooo2?l00003ooooo`;o00001_ooool4o`000003ooooool0
003o000000;ooooo1Ol000000ooooooo0000o`000002o`0000Gooooo1?l00006ooooo`;o000000?o
ooooo`000?l000005oooool6o`000003ooooool0003o000000Gooooo2ol000000ooooooo0000o`00
000>o`0000;ooooo0_l00004ooooo`;o00001Oooool2o`0000;ooooo0_l0000;ooooo`;o0000?ooo
ool001cooooo00?o0000ooooooooool0;oooool2o`0000;ooooo0_l000000ooooooo0000o`00000=
ooooo`;o00002_ooool2o`0000?ooooo0_l00008ooooo`;o00001_ooool2o`0000?ooooo0_l00009
ooooo`;o00001?ooool2o`0000Gooooo0_l00002ooooo`Go000000?oooooo`000?l000001Ol00002
ooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`00000Booooo`;o00000oooool3
o`000004ooooool0003o0000ooooo`;o00001Oooool;o`000003ooooool0003o000000ko00000_oo
ool4o`0000Wooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000Gooooo0_l0
0003ooooo`;o00002_ooool2o`0002gooooo000Looooo`03o`000?oooooooooo03?ooooo1Ol00000
1?oooooo0000o`000?ooool2o`0001Sooooo0_l00008ooooo`Go00001_ooool6o`0000Oooooo0ol0
0003ooooo`;o00001?ooool2o`000003ooooool0003o000000;o00001_ooool5o`000005ooooool0
003o0000o`000?ooool00ol0000=ooooo`;o00000_ooool2o`0000Sooooo0_l00004ooooo`;o0000
00?oooooo`000?l000002OoooolKo`000003ooooool0003o000000?o00002oooool2o`0000?ooooo
0ol000000ooooooo0000o`000005ooooo`;o00000oooool2o`0000[ooooo0_l0000]ooooo`007?oo
ool00ol0003oooooooooo`0aooooo`Ko00000_ooool2o`000003ooooool0003o000000Oooooo0_l0
000Jooooo`Co00001_ooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`000004oooo
ool0003o0000o`0000Wooooo1ol000000ooooooo0000o`000008ooooo`Co000000Coooooo`000?l0
003o00003Oooool2o`0000;ooooo0_l0000Eooooo`Co00000ooooolKo`000004ooooool0003o0000
o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000oooool2
o`0004Wooooo000Looooo`03o`000?oooooooooo037ooooo1?l0000>ooooo`Co000000?oooooo`00
0?l000004?ooool2o`0001Kooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00000oooool2
o`0000;ooooo1?l00002ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000Cooooo0_l0
0003ooooo`?o00003?ooool2o`0000?ooooo0_l000000ooooooo0000o`00000<ooooo`;o00001?oo
oolVo`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o00001?ooool3o`0004[ooooo000L
ooooo`03o`000?oooooooooo03?ooooo0_l00008ooooo`;o00001?ooool4o`000003ooooool0003o
000000Oooooo0_l00007ooooo`;o00003oooool3o`0000?ooooo0_l00002ooooo`?o00000_ooool2
o`0000?ooooo1_l00002ooooo`;o000000?oooooo`000?l000001_l000000ooooooo0000o`000006
ooooo`;o00000_ooool2o`0000Wooooo0_l00003ooooo`;o000000?oooooo`000?l000001Oooool2
o`0000Gooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000007ol00002
ooooo`Co00000oooool2o`0000Kooooo0ol0001:ooooo`007?ooool00ol0003oooooooooo`0coooo
o`;o00002?ooool2o`0000Kooooo0_l0000:ooooo`;o00001oooool2o`0000oooooo1?l00002oooo
o`;o00000_ooool2o`0000;ooooo0_l00006ooooo`;o000000Coooooo`000?l0003ooooo0_l00000
0ooooooo0000o`000002ooooo`;o00000oooool2o`0000Kooooo0_l00002ooooo`;o00000oooool2
o`0000;ooooo0_l00007ooooo`;o00000oooool2o`000003ooooool0003o000000Sooooo0_l00002
ooooo`Ko000000?oooooo`000?l000006ol000000ooooooo0000o`000003o`0000?ooooo0_l00003
ooooo`;o000000?oooooo`000?l000005Oooool2o`0003Cooooo000Looooo`03o`000?oooooooooo
02cooooo0_l00002ooooo`;o000000?oooooo`000?l000008Oooool2o`00017ooooo2?l00004oooo
o`?o000000?oooooo`000?l000000_l00004ooooo`;o000000?oooooo`000?l000007_ooool2o`00
00;ooooo0_l00007ooooo`;o00000oooool5o`000003ooooool0003o000000Wooooo1Ol00002oooo
oa[o000000Coooooo`000?l0003ooooo1?l00009ooooo`;o00006?ooool2o`0003Cooooo000Loooo
o`03o`000?oooooooooo02cooooo0_l00002ooooo`;o00004?ooool2o`0000_ooooo0_l00005oooo
o`;o00002Oooool2o`0000Gooooo1Ol00002ooooo`;o00001?ooool4o`000005ooooool0003o0000
o`000?ooool01_l0000Eooooo`;o00000oooool5o`0001;ooooo1_l000000ooooooo0000o`00000>
oooooako00001?ooool2o`0000Sooooo0_l00002ooooo`;o00003oooool2o`0003[ooooo000Loooo
o`03o`000?oooooooooo03Kooooo0_l00008ooooo`Co00002oooool2o`0000;ooooo0_l0000<oooo
o`Ko000000?oooooo`000?l000000_l00007ooooo`Ko00000oooool8o`0001;ooooo0_l000000ooo
oooo0000o`000003ooooo`Oo00001?ooool2o`0000[ooooo0ol000000ooooooo0000o`00000>oooo
o`_o00000_oooolFo`0000cooooo0_l00002ooooo`;o00003oooool2o`0003[ooooo000Looooo`03
o`000?oooooooooo02kooooo0_l00006ooooo`;o00001Oooool2o`000003ooooool0003o0000017o
oooo0_l0000>ooooo`Co00000oooool2o`0000Oooooo1?l00002ooooo`Ko00000oooool4o`0000Wo
oooo0_l000000ooooooo0000o`000002ooooo`;o00002oooool2o`0000Cooooo0_l00003ooooo`;o
00001_ooool3o`0000kooooo3Ol000000ooooooo0000o`00000Bo`000003ooooool0003o000000;o
00007Oooool2o`0003cooooo000Looooo`03o`000?oooooooooo02_ooooo0_l000000ooooooo0000
o`000005ooooo`?o00001Oooool4o`0000?ooooo0_l0000]ooooo`;o00001?ooool3o`0000Sooooo
0_l00009ooooo`;o000000?oooooo`000?l000001oooool2o`0000Gooooo0_l00008ooooo`Co0000
0_ooool3o`000004ooooool0003o0000o`0000kooooo0_l000000ooooooo0000o`00000Mo`0000;o
oooo0ol0000Mooooo`;o0000??ooool001cooooo00?o0000ooooooooool0:oooool2o`0000Sooooo
0ol00007ooooo`;o00000oooool3o`0000Sooooo0_l00003ooooo`;o00006oooool4o`0000Cooooo
0_l00006ooooo`;o00001_ooool2o`0000[ooooo0_l00004ooooo`;o00001Oooool2o`0000Sooooo
0_l00004ooooo`?o00002_ooool2o`000003ooooool0003o000000?ooooo0_l00002ooooob;o0000
1?ooool2o`0005Kooooo000Looooo`;o0000<Oooool2o`0000Wooooo0_l00006ooooo`Go00001_oo
ool3o`0000?ooooo0_l00009ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000Sooooo
0ol00003ooooo`?o00002?ooool2o`0000Cooooo1?l0000:ooooo`;o00002?ooool2o`0001Sooooo
0_l00004ooooo`;o000000?oooooo`000?l000000oooool4o`000003ooooool0003o000001Ko0000
00Coooooo`000?l0003ooooo0ol00006ooooo`;o00000oooool2o`00057ooooo000Looooo`03o`00
0?oooooooooo033ooooo0_l00005ooooo`;o00000_ooool2o`0000Kooooo0_l000000ooooooo0000
o`000002o`0000Cooooo0_l0000?ooooo`;o000000Goooooo`000?l0003o0000ooooo`03o`0000Oo
oooo1Ol000001?oooooo0000o`000?l0000;ooooo`;o000000?oooooo`000?l000000oooool2o`00
00[ooooo0_l00002ooooo`;o000000?oooooo`000?l000006?ooool2o`0000Oooooo0_l00003oooo
o`Co00000_oooolHo`0000?ooooo0_l0000<ooooo`;o00004_ooool2o`0003gooooo000Looooo`03
o`000?oooooooooo03Cooooo0_l000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l0
00000_ooool4o`0001Wooooo0_l00002ooooo`;o00000_ooool3o`0000;ooooo0_l000001?oooooo
0000o`000?ooool2o`0000cooooo0ol00005ooooo`;o00001Oooool2o`0000?ooooo1_l00006oooo
o`?o00002?ooool2o`0001_ooooo0_l00003oooooaCo000000?oooooo`000?l000008_ooool2o`00
03gooooo000Looooo`03o`000?oooooooooo03Cooooo0_l00009ooooo`;o000000?oooooo`000?l0
00006Oooool2o`0000;ooooo0_l00008ooooo`Oo00002?ooool2o`0000Sooooo1Ol0000:ooooo`;o
00001Oooool2o`0000Sooooo1?l00003ooooo`;o00000_ooool2o`000004ooooool0003o0000oooo
o`;o00001oooool2o`0000Gooooo1?l00003ooooo`;o00001?ooool2o`000003ooooool0003o0000
017o00001?ooool2o`0000;ooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`0fooooo`;o
00001oooool2o`0000Sooooo0_l000000ooooooo0000o`00000?ooooo`;o00000_ooool2o`0000_o
oooo1?l00006ooooo`Co00001?ooool2o`0000Gooooo0_l0000Fooooo`;o00000_ooool2o`000003
ooooool0003o000000?ooooo0_l00005ooooo`;o000000?oooooo`000?l000001oooool2o`0000Go
oooo1?l00004ooooo`;o000000?oooooo`000?l000003_l00002ooooo`Go00000oooool4o`0000;o
oooo0_l000000ooooooo0000o`00001Dooooo`007?ooool00ol0003oooooooooo`0fooooo`;o0000
2Oooool2o`0000Kooooo0_l000000ooooooo0000o`00000Rooooo`;o00001_ooool2o`0000Kooooo
0_l0000<ooooo`;o00003oooool2o`0000;ooooo1Ol0000Dooooo`;o00001oooool2o`0000Kooooo
1_l000001Ooooooo0000o`000?l0003ooooo00Go000000?oooooo`000?l000001?ooool3o`0000?o
oooo0ol000001?oooooo0000o`000?ooool4o`0001Kooooo0_l0000looooo`007?ooool00ol0003o
ooooooooo`0/ooooo`;o00001_ooool4o`000004ooooool0003o0000ooooo`;o00000oooool2o`00
00Oooooo0_l0000Looooo`;o00002oooool2o`000003ooooool0003o000000Cooooo0ol0000=oooo
o`;o00001_ooool2o`0000Gooooo1?l00003ooooo`Co00002?ooool2o`0000[ooooo0_l0000@oooo
o`Co00001oooool2o`000004ooooool0003o0000ooooo`;o00000oooool2o`0000Gooooo0_l00000
1?oooooo0000o`000?ooool2o`0001Sooooo0_l00003ooooo`;o00001Oooool2o`00033ooooo000L
ooooo`03o`000?oooooooooo02cooooo0_l00004ooooo`Ko000000Coooooo`000?l0003ooooo0_l0
0006ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Looooo`;o00002oooool2o`0000Oooooo
0ol00008ooooo`;o00000_ooool2o`0000Oooooo0_l00005ooooo`;o00001oooool2o`0000Sooooo
0_l0000@ooooo`;o00002oooool4o`000005ooooool0003o0000o`000?ooool01_l000000ooooooo
0000o`00000@ooooo`;o00001Oooool2o`0000Sooooo0_l0000<ooooo`;o00000oooool4o`00033o
oooo000Looooo`03o`000?oooooooooo03;ooooo0_l0000@ooooo`Go0000<Oooool2o`0000Kooooo
0_l00005ooooo`;o00000_ooool2o`0000oooooo0_l00006ooooo`;o00001oooool2o`000003oooo
ool0003o000000kooooo0_l00004ooooo`?o00001_ooool2o`000005ooooool0003o0000o`000?oo
ool00_l000000ooooooo0000o`000002o`0000Wooooo0_l0000>ooooo`;o000000?oooooo`000?l0
00001Oooool2o`00017ooooo1?l0000`ooooo`007?ooool00ol0003oooooooooo`0Yooooo`;o0000
0oooool2o`0000Kooooo0_l0000>ooooo`;o00001Oooool2o`0001_ooooo0_l0000:ooooo`;o0000
00Coooooo`000?l0003o00000oooool2o`000003ooooool0003o000001[ooooo0_l00008ooooo`;o
00001?ooool3o`000003ooooool0003o000000;o00004_ooool3o`0000Kooooo0_l00005ooooo`;o
00000oooool2o`0000Kooooo0_l000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l0
00000oooool2o`000003ooooool0003o000001Wooooo1?l0000_ooooo`007?ooool00ol0003ooooo
ooooo`0Yooooo`;o00000oooool2o`0000Kooooo0_l00006ooooo`;o00002_ooool2o`000003oooo
ool0003o000001;ooooo0_l00003ooooo`;o00000_ooool5o`0000;ooooo0_l00003ooooo`;o0000
00?oooooo`000?l000000_ooool8o`0000Gooooo0_l0000Dooooo`;o00001_ooool2o`0000Cooooo
0_l00004ooooo`;o00004oooool2o`0000cooooo0ol0000;ooooo`;o00000oooool2o`0000Cooooo
0_l000000ooooooo0000o`000003ooooo`;o00001oooool2o`0001?ooooo1?l0000_ooooo`007?oo
ool00ol0003oooooooooo`0`ooooo`;o00003?ooool2o`000003ooooool0003o000000Oooooo0_l0
000<ooooo`;o00001oooool2o`0000?ooooo0_l00003ooooo`Co00000_ooool2o`0000;ooooo0_l0
0006ooooo`?o000000?oooooo`000?l000000ol00004ooooo`;o00005?ooool2o`0000cooooo0_l0
000Iooooo`;o00003?ooool4o`0000Kooooo0_l00006ooooo`?o00003?ooool2o`0000Oooooo0_l0
0016ooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o00000oooool2o`0000;ooooo0_l00000
0ooooooo0000o`000008ooooo`Co00004oooool2o`00013ooooo0_l00007ooooo`Co00000_ooool2
o`0000?ooooo0ol00003ooooo`;o00001?ooool2o`0002?ooooo0_l00006ooooo`?o00001?ooool2
o`0000cooooo0_l00006ooooo`;o000000?oooooo`000?l000000_l00006ooooo`;o00001_ooool2
o`0000;ooooo0_l00006ooooo`;o000000?oooooo`000?l00000Coooool001cooooo00?o0000oooo
ooooool0:oooool2o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l00008oooo
o`;o00004_ooool3o`0000Sooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l00004oooo
o`Go00000_ooool3o`0000?ooooo0_l0000^ooooo`;o00001_ooool3o`0000Cooooo0_l00002oooo
o`;o00002?ooool3o`0000Gooooo0_l000000ooooooo0000o`00000;ooooo`;o000000?oooooo`00
0?l000001?ooool2o`0000Kooooo0_l00007ooooo`;o0000BOooool001cooooo00?o0000oooooooo
ool0:?ooool2o`0000Kooooo1Ol00004ooooo`;o00007?ooool2o`0000?ooooo0_l00004ooooo`Co
000000?oooooo`000?l000000oooool3o`0000;ooooo1Ol00004ooooo`;o00002oooool2o`0001co
oooo0_l0000;ooooo`;o00001?ooool4o`0000Kooooo0_l00009ooooo`;o00002?ooool2o`0000_o
oooo0_l000000ooooooo0000o`000006ooooo`;o00003Oooool2o`0004Wooooo000Looooo`03o`00
0?oooooooooo02Sooooo0_l00007ooooo`Co00002?ooool2o`0001gooooo0_l00006ooooo`;o0000
1Oooool=o`0000Wooooo0_l000001?oooooo0000o`000?ooool2o`0001[ooooo1?l00003ooooo`;o
00000oooool2o`000003ooooool0003o000000Cooooo1?l0000Eooooo`;o00006_ooool4o`0001;o
oooo0_l00014ooooo`007?ooool2o`0003Gooooo0_l00003ooooo`;o00000_ooool2o`0001gooooo
0_l00003ooooo`;o00001oooool>o`000003ooooool0003o000000Kooooo0_l000000ooooooo0000
o`00000Jooooo`;o000000?oooooo`000?l000001Oooool2o`0000;ooooo0ol000000ooooooo0000
o`000002ooooo`;o00001_ooool2o`000003ooooool0003o000000[ooooo0_l00002ooooo`;o0000
6_ooool2o`0000kooooo0_l00004ooooo`?o0000@oooool001cooooo00?o0000ooooooooool0;Ooo
ool2o`0000?ooooo1_l000000ooooooo0000o`00000>ooooo`Co00005?ooool2o`0000Kooooo3?l0
00000ooooooo0000o`000003o`0001[ooooo0_l00009ooooo`;o000000Goooooo`000?l0003o0000
ooooo`05o`000004ooooool0003o0000o`0000Kooooo0_l00003ooooo`;o000000Coooooo`000?l0
003ooooo0_l0000:ooooo`;o00001?ooool2o`000003ooooool0003o000000Co00002_ooool2o`00
013ooooo0_l00003ooooo`;o00001Oooool2o`0004?ooooo000Looooo`03o`000?oooooooooo02go
oooo0_l00003ooooo`;o00000_ooool3o`0000Oooooo0_l00007ooooo`Co00002_ooool3o`0000go
oooo5_l0000:ooooo`;o00003?ooool2o`0000cooooo0ol000000ooooooo0000o`000003o`000004
ooooool0003o0000ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`;o000000Cooooo
o`000?l0003ooooo0_l0000@ooooo`;o000000?oooooo`000?l000001?l00009ooooo`?o00004?oo
ool2o`0000_ooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`0Yooooo`;o00003?ooool2
o`0000Oooooo0_l00002ooooo`;o00004Oooool3o`000003ooooool0003o000000;ooooo0_l00006
oooooaKo00002_ooool2o`0001Kooooo0_l0000?ooooo`;o00000_ooool3o`000003ooooool0003o
000000Oooooo1?l0000Dooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`Co00007_oo
ool2o`0004;ooooo000Looooo`03o`000?oooooooooo02Wooooo1?l0000Gooooo`;o00003Oooool2
o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o00001OoooolEo`0000Cooooo0_l0000N
ooooo`;o00000_ooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l0
0007ooooo`Go000000?oooooo`000?l000001_ooool2o`0000cooooo1Ol000000ooooooo0000o`00
0004o`0000Gooooo0_l00008ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0:oooool2
o`0000_ooooo0_l0000Iooooo`;o000000?oooooo`000?l000003_oooolGo`0000;ooooo0ol0000L
ooooo`Oo00001?ooool2o`000004ooooool0003o0000ooooo`;o00002?ooool9o`0000Gooooo1_l0
000>ooooo`;o00001?ooool2o`0000Oooooo0ol00007ooooo`?o00001_ooool2o`0004[ooooo000L
ooooo`03o`000?oooooooooo02_ooooo0ol0000:ooooo`Co00004oooool2o`0000Kooooo0_l00000
0ooooooo0000o`00000:ooooo`Oo000000?oooooo`000?l000003Ol00003ooooo`;o00006Oooool2
o`000003ooooool0003o000000Co00000_ooool:o`0000Wooooo1?l00004ooooo`;o00001?ooool5
o`0000Cooooo0_l000000ooooooo0000o`000005ooooo`;o00002_ooool4o`000004ooooool0003o
0000o`0000;ooooo0_l00003ooooo`?o00001Oooool4o`0000Cooooo0_l00012ooooo`007?ooool0
0ol0003oooooooooo`0[ooooo`?o00003?ooool3o`0001;ooooo0_l00003ooooo`;o000000Cooooo
o`000?l0003ooooo0_l00008ooooo`[o000000?oooooo`000?l000002ol0000Looooo`;o000000?o
ooooo`000?l000000_ooool5o`0000;ooooo3?l00005ooooo`;o000000?oooooo`000?l000000ol0
0002ooooo`;o000000?oooooo`000?l000002?ooool4o`000004ooooool0003o0000o`0000;ooooo
1_l000001Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`000?l000000_l00002ooooo`Ko
00000oooool4o`0000Kooooo0_l00004ooooo`;o00002oooool2o`0003Gooooo000Looooo`03o`00
0?oooooooooo03_ooooo0_l0000@ooooo`;o00001Oooool4o`000003ooooool0003o000000Wooooo
0_l000000ooooooo0000o`00000Co`0000gooooo0_l00004ooooo`;o00001oooool2o`0000Gooooo
0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00003ooooo`Ko00000_ooool3o`0000;o
oooo2?l000000ooooooo0000o`000006ooooo`Co00000oooool3o`0000;ooooo0_l000001Ooooooo
0000o`000?l0003ooooo00?o000000?oooooo`000?l000002Oooool2o`0000Oooooo0_l00004oooo
o`;o00004oooool2o`0003Gooooo000Looooo`03o`000?oooooooooo03Oooooo0_l000000ooooooo
0000o`000005ooooo`;o000000?oooooo`000?l000001oooool2o`0000?ooooo2Ol0000<oooooa?o
00000oooool2o`0000[ooooo0_l00004ooooo`Co00003?ooool3o`0000?ooooo1_l00002ooooo`_o
00000oooool8o`0000;ooooo0_l00004ooooo`?o00002Oooool4o`0000Sooooo1Ol0000Eooooo`?o
00000oooool2o`0004Cooooo000Looooo`03o`000?oooooooooo02kooooo0_l000000ooooooo0000
o`000004ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o000000?oooooo`000?l0
00000_l00008ooooo`Co00000oooool2o`0000kooooo5Ol000000ooooooo0000o`00000Booooo`;o
00001Oooool2o`0000Gooooo1?l00003ooooo`co000000Coooooo`000?l0003o00000oooool3o`00
0003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000004ooooo`;o00000_ooool4o`00
00Cooooo1?l00009ooooo`Ko00000oooool2o`0000oooooo0_l00003ooooo`;o0000A?ooool001co
oooo00?o0000ooooooooool0;_ooool2o`000004ooooool0003o0000ooooo`Go00001?ooool2o`00
00Oooooo0_l00004ooooo`;o00000_ooool2o`0001Kooooo5?l0000?ooooo`;o00002Oooool4o`00
00Oooooo0_l000000ooooooo0000o`00000@o`000003ooooool0003o000000So000000?oooooo`00
0?l000002oooool4o`0000[ooooo0_l00004ooooo`;o000000?oooooo`000?l000000_l00003oooo
o`;o00005Oooool2o`00013ooooo0_l0000aooooo`007?ooool00ol0003oooooooooo`0dooooo`Go
00000oooool2o`0000?ooooo0_l00009ooooo`;o00002_ooool2o`0000kooooo4ol0000@ooooo`;o
00002?ooool3o`0000Cooooo0_l00002ooooo`Oo00000_oooolIo`0000[ooooo0_l000001?oooooo
0000o`000?l0000;ooooo`;o00000_ooool4o`000003ooooool0003o000000Sooooo0_l0000;oooo
o`;o00000_ooool2o`000003ooooool0003o000000_ooooo0_l00003ooooo`;o0000<Oooool001co
oooo00?o0000ooooooooool0<_ooool5o`0000Gooooo0_l00003ooooo`Co00001oooool4o`0000So
oooo0_l00002ooooo`;o00001_oooolIo`00013ooooo0_l00006ooooo`;o00000ooooolNo`000003
ooooool0003o000000Cooooo1?l00003ooooo`;o00001?ooool2o`0000Kooooo0_l00006ooooo`;o
00000oooool2o`0000Cooooo0_l00007ooooo`;o000000?oooooo`000?l000002?ooool2o`0000;o
oooo0_l000000ooooooo0000o`00000;ooooo`;o0000=_ooool00006ooooooo^k^ko<S8bo`000?lb
<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooo
oooo03;ooooo0_l00007ooooo`;o00001_ooool2o`0000Wooooo0_l0000<ooooo`;o00001?ooool7
o`000003ooooool0003o0000017o00003oooool7o`0000Kooooo1?l000000ooooooo0000o`00000=
o`000003ooooool0003o000000Go000000?oooooo`000?l000000ol00005ooooo`?o000000?ooooo
o`000?l000000_l0000<ooooo`;o00001_ooool2o`0000Wooooo0_l0000:ooooo`;o00001Oooool2
o`0000Gooooo0_l000000ooooooo0000o`000013ooooo`0000KoooooogMgMonHV9SooooooiRHV?mg
MgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0
;Oooool2o`0000cooooo0_l00006ooooo`;o00002?ooool2o`0000;ooooo0_l0000>ooooo`?o0000
0ooooolCo`0000[ooooo0_l00006ooooo`;o000000?oooooo`000?l000001?l00004oooooaCo0000
00?oooooo`000?l000001ol000001?oooooo0000o`000?ooool3o`0000Kooooo0_l0000?ooooo`;o
00002?ooool2o`0000Oooooo0_l0000@ooooo`;o00001Oooool2o`000003ooooool0003o000004?o
oooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo02gooooo0_l00008ooooo`;o00003Oooool2o`0000Go
oooo0_l00002ooooo`;o000000?oooooo`000?l000002oooool2o`0000Cooooo4_l00002ooooo`;o
00001oooool2o`0000gooooo1?l00002oooooako000000Coooooo`000?l0003ooooo0ol0000?oooo
o`;o00001_ooool2o`0000Sooooo0_l00003ooooo`;o00000_ooool2o`0002Gooooo0_l0000hoooo
o`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9SooooooiRH
V?lQ8B401_ooool3o`00037ooooo0ol00003ooooo`;o00003Oooool3o`0000;ooooo0_l00007oooo
o`Co00004_ooool?o`0000;ooooo0ol00002ooooo`Co00003?ooool=o`000003ooooool0003o0000
01[o000000Coooooo`000?l0003o00000_ooool2o`0000Kooooo0_l00003ooooo`;o00005Oooool2
o`0001Gooooo0_l00005ooooo`;o00002oooool2o`0003Sooooo00000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooo
oooo037ooooo0ol0000>ooooo`;o00000oooool2o`0000;ooooo0_l00009ooooo`;o00005?ooool=
o`0000;ooooo0ol00002ooooo`Co00000oooool2o`0000Oooooo:_l00003ooooo`;o000000Cooooo
o`000?l0003ooooo0_l00003ooooo`;o0000<Oooool4o`0000?ooooo0_l00015ooooo`0000?ooooo
oa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000
ooooooooool0=_ooool2o`0000[ooooo0_l00002ooooo`;o00001Oooool2o`0000kooooo0_l00004
ooooo`;o00002?ooool<o`0000;ooooo0_l00006ooooo`?o000000?oooooo`000?l000003Oooool5
o`0000;ooooo7ol000000ooooooo0000o`000004ooooo`;o00001Oooool2o`0000cooooo0_l0000S
ooooo`;o00003oooool2o`0003Wooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00?o
gMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0_ooooo`;o00001Oooool2o`0000gooooo0ol0
0005ooooo`;o00000_ooool2o`0000?ooooo0_l00005ooooo`;o00001?ooool2o`0000cooooo1Ol0
0005ooooo`;o00001?ooool5o`0000Gooooo0_l00008ooooo`?o000000?oooooo`000?l000009Ol0
00000ooooooo0000o`000007ooooo`;o00002Oooool5o`0003Cooooo0_l0000iooooo`0000Kooooo
onk^k_lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000oooooooo
ool0;oooool2o`0001Cooooo0_l0000:ooooo`;o00000oooool2o`0000?ooooo0_l00009ooooo`;o
00001oooool5o`0000_ooooo1?l00006ooooo`Co00002?ooool3o`0000?ooooo9Ol000000ooooooo
0000o`00000Booooo`?o0000LOooool001cooooo00?o0000ooooooooool0=oooool2o`0001Cooooo
0_l00008ooooo`;o00000_ooool2o`0000Cooooo0_l00003ooooo`;o00001oooool5o`000004oooo
ool0003o0000ooooo`;o00001Oooool2o`0000;ooooo0_l00004ooooo`;o00002_ooool3o`000003
ooooool0003o0000027o000000Goooooo`000?l0003o0000ooooo`02o`0000oooooo0_l00005oooo
o`;o00008oooool3o`0004Sooooo000Looooo`03o`000?oooooooooo03Oooooo0_l0000Dooooo`;o
00000_ooool2o`0000?ooooo0ol00008ooooo`;o00001_ooool4o`0000?ooooo0_l00003ooooo`;o
000000?oooooo`000?l000000_ooool2o`0000Gooooo0_l0000@ooooo`?o000000?oooooo`000?l0
00008Ol000000ooooooo0000o`000002o`0000kooooo0_l000000ooooooo0000o`000005ooooo`;o
00008oooool3o`0004Sooooo000Looooo`03o`000?oooooooooo02oooooo0_l00003ooooo`;o0000
1Oooool2o`0001Cooooo0_l00003ooooo`;o00000oooool2o`0000Gooooo0_l00005ooooo`Co0000
00?oooooo`000?l000003?ooool2o`0000?ooooo0_l00008ooooo`;o00002?ooool2o`0000;ooooo
6Ol000000ooooooo0000o`00000<o`0000?ooooo0_l00004ooooo`;o00000oooool2o`0007Sooooo
000Looooo`03o`000?oooooooooo02oooooo0_l00003ooooo`?o000000Coooooo`000?l0003ooooo
0_l0000Iooooo`;o00000oooool2o`0000Gooooo0_l00006ooooo`;o000000Coooooo`000?l0003o
00004Oooool2o`0000Sooooo0_l00007ooooo`;o00001?ooool=o`000003ooooool0003o000001Go
00001Oooool2o`0000;ooooo1?l0000aooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0
;oooool2o`0000Cooooo0_l000000ooooooo0000o`00000Nooooo`;o00002?ooool2o`0000Gooooo
0ol000000ooooooo0000o`00000Pooooo`;o00000oooool2o`0000Cooooo9Ol00009ooooo`?o0000
<_ooool2o`0004[ooooo000Looooo`03o`000?oooooooooo02oooooo0_l00004ooooo`;o00001?oo
ool2o`0000Wooooo0_l0000@ooooo`;o00002_ooool3o`0000;ooooo0_l00004ooooo`Go00005Ooo
ool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000
o`000002ooooobGo000000?oooooo`000?l000001Oooool3o`0000Kooooo0_l0000Zooooo`?o0000
BOooool001cooooo00?o0000ooooooooool0<Oooool2o`0000;ooooo0_l00003ooooo`?o00002Ooo
ool2o`0000Oooooo0_l00002ooooo`;o00000_ooool2o`0000_ooooo0ol00008ooooo`Go00002?oo
ool2o`0000?ooooo0_l00006ooooo`Go00001?ooool3o`0000;ooooo0_l000000ooooooo0000o`00
000To`000003ooooool0003o000000Wooooo0_l00003ooooo`;o0000:oooool2o`0004Wooooo000L
ooooo`03o`000?oooooooooo037ooooo0_l00007ooooo`;o00002_ooool2o`0000Oooooo0_l00002
ooooo`;o00000_ooool2o`0000;ooooo0_l0000Dooooo`;o00000oooool2o`0000Cooooo0_l00002
ooooo`?o00001_ooool4o`0000Kooooo0_l00005oooooa[o000000?oooooo`000?l000002?l00002
ooooo`;o00000oooool2o`0000Cooooo0_l0001kooooo`007?ooool00ol0003oooooooooo`1Koooo
o`;o00000oooool2o`0000?ooooo0_l000000ooooooo0000o`000007ooooo`;o000000?oooooo`00
0?l000000_l00008ooooo`;o00001oooool2o`0000;ooooo0_l00004ooooo`Co00000ooooolEo`00
0003ooooool0003o000000go00000_ooool2o`0000?ooooo0ol0000Yooooo`;o00002?ooool2o`00
04_ooooo000Looooo`03o`000?oooooooooo03kooooo0_l00003ooooo`;o00003_ooool2o`0000?o
oooo0_l00006ooooo`;o00000_ooool6o`0000Oooooo0_l000000ooooooo0000o`00000:ooooo`;o
000000Coooooo`000?l0003ooooo0_l00005ooooo`;o00001_ooool4o`000003ooooool0003o0000
01oo000000Coooooo`000?l0003ooooo1?l00004ooooo`;o00004Oooool2o`0001Kooooo0ol00007
ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0?_ooool3o`0000;ooooo0_l00009oooo
o`;o00000oooool3o`0000;ooooo0_l00007ooooo`;o000000?oooooo`000?l000000ol0000Goooo
o`;o000000Coooooo`000?l0003ooooo0_l0000=ooooo`Co000000?oooooo`000?l000008_l00000
0ooooooo0000o`000003ooooo`Co00004_ooool2o`0001Oooooo0_l0001Dooooo`007?ooool2o`00
03Oooooo0_l00005ooooo`Co00000_ooool2o`0000Wooooo0_l00004ooooo`;o000000Coooooo`00
0?l0003o00001_ooool3o`0000Cooooo0_l0000@ooooo`;o00001oooool6o`0000gooooo1ol00002
oooooako00002?ooool4o`0000?ooooo0_l0000Zooooo`;o0000D?ooool001cooooo00?o0000oooo
ooooool0<_ooool2o`0000;ooooo0_l00005ooooo`;o000000Coooooo`000?l0003o00002Oooool2
o`0000Sooooo1?l00006ooooo`;o00000_ooool2o`0001?ooooo0_l00007ooooo`Ko00001?ooool2
o`0000Sooooo1_l000000ooooooo0000o`00000Ko`000005ooooool0003o0000o`000?ooool00_l0
000:ooooo`;o00003_ooool2o`0001Sooooo1?l00002ooooo`;o00003?ooool2o`0003kooooo000L
ooooo`03o`000?oooooooooo03;ooooo0_l0000<ooooo`?o00000_ooool2o`0000Gooooo0_l00006
ooooo`Co00003?ooool2o`0001?ooooo0_l0000Aooooo`;o00001Oooool2o`000004ooooool0003o
0000o`0000Cooooo8Ol000000ooooooo0000o`00000<ooooo`;o00001_ooool2o`0000?ooooo0ol0
000Hooooo`;o00001?ooool2o`0000cooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`10
ooooo`;o00000oooool2o`0000Cooooo1?l00005ooooo`?o00001oooool2o`0001Kooooo0_l0000F
ooooo`;o00000oooool2o`0000;ooooo5_l000000ooooooo0000o`00000;o`000004ooooool0003o
0000ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Kooooo0_l00003ooooo`;o00006Ooo
ool2o`000003ooooool0003o000004oooooo000Looooo`03o`000?oooooooooo03kooooo0ol00009
ooooo`Go00001Oooool3o`0000Oooooo0_l0000Aooooo`?o000000Coooooo`000?l0003o00000ooo
ool2o`00017ooooo0_l00003ooooo`;o000000?oooooo`000?l000008Ol00003ooooo`;o000000?o
ooooo`000?l000000ol00009ooooo`;o0000:Oooool4o`0004gooooo000Looooo`03o`000?oooooo
oooo03kooooo1?l00006ooooo`Ko00001oooool4o`0000Gooooo0_l0000>ooooo`;o000000?ooooo
o`000?l000001?l00004ooooo`;o00001_ooool2o`00017ooooo5Ol000000ooooooo0000o`00000@
o`000003ooooool0003o000000;o0000=oooool2o`0000Sooooo0_l00013ooooo`007?ooool00ol0
003oooooooooo`10ooooo`;o00001_ooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`00
00kooooo0ol00002ooooo`?o00001?ooool4o`0000;ooooo0_l000001?oooooo0000o`000?ooool2
o`0000Oooooo0_l00004ooooo`Co000000?oooooo`000?l000008Ol00002ooooo`;o0000:_ooool2
o`0001Oooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00007Oooool2o`00
00?ooooo0_l00004ooooo`Go000000?oooooo`000?l000000_ooool4o`0000Oooooo0_l00004oooo
o`;o00000ooooolFo`000003ooooool0003o000000Oo000000Goooooo`000?l0003o0000ooooo`02
o`0002[ooooo0_l0000:ooooo`;o0000D?ooool001cooooo00?o0000ooooooooool0?oooool2o`00
00Oooooo0_l0000Gooooo`;o00002oooool2o`0000cooooo1Ol00003ooooo`;o00000_ooool2o`00
013ooooo7Ol000000ooooooo0000o`000004o`0000?ooooo0_l0000;ooooo`;o00002_ooool2o`00
01_ooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00001oooool2o`0000oo
oooo1?l00004ooooo`?o000000?oooooo`000?l000001oooool2o`000003ooooool0003o000000?o
oooo1?l00005ooooo`Co00001Oooool2o`00013ooooo2ol000001Ooooooo0000o`000?l0003ooooo
01?o00001?ooool2o`0000?ooooo0_l00006ooooo`;o000000?oooooo`000?l000001oooool2o`00
013ooooo0ol0001Jooooo`007?ooool00ol0003oooooooooo`1Iooooo`Co00001Oooool2o`000003
ooooool0003o000000[ooooo0_l00003ooooo`Co00001_ooool3o`0000Kooooo0_l0000=ooooo`Co
00000_ooool4o`000004ooooool0003o0000oooooa?o00000_ooool3o`0000Sooooo0_l00009oooo
o`?o00006?ooool3o`000003ooooool0003o000000;o00000oooool2o`00053ooooo000Looooo`03
o`000?oooooooooo05Wooooo0_l0000=ooooo`;o00002_ooool2o`0000[ooooo0_l00007ooooo`;o
00003Oooool2o`0000Gooooo5ol00002ooooo`Ko00001?ooool2o`0000kooooo0_l0000Gooooo`;o
00000oooool4o`0000?ooooo0_l00007ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0
B_ooool2o`0000Gooooo0_l00006ooooo`;o00003Oooool3o`0000Oooooo1Ol0000Iooooo`;o0000
0_ooool2o`0000Oooooo3?l000000ooooooo0000o`000008o`0000Cooooo1_l00004ooooo`;o0000
3oooool2o`0000Cooooo0_l0000@ooooo`;o00000oooool2o`0000kooooo0_l00017ooooo`007?oo
ool00ol0003oooooooooo`17ooooo`Go00001Oooool2o`0001Kooooo0ol00006ooooo`;o000000?o
ooooo`000?l000006?ooool3o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l0
00000ooooooo0000o`000008o`000003ooooool0003o000000;ooooo1?l00003ooooo`?o00002?oo
ool2o`0000_ooooo0_l00002ooooo`;o00001?ooool2o`0000oooooo0ol00008ooooo`;o00001?oo
ool2o`000003ooooool0003o000004Wooooo000Looooo`03o`000?oooooooooo04Oooooo1?l0000N
ooooo`Go00003Oooool2o`0000Cooooo1?l00007ooooo`;o000000Coooooo`000?l0003o00001ooo
ool2o`000004ooooool0003o0000o`0000;ooooo1?l00003ooooo`?o000000?oooooo`000?l00000
2ol00002ooooo`;o00004_ooool4o`0000?ooooo0_l0000<ooooo`;o00001?ooool2o`0000Wooooo
0_l00003ooooo`?o000000?oooooo`000?l00000BOooool001cooooo00?o0000ooooooooool0@_oo
ool2o`0000Gooooo1Ol00002ooooo`;o000000Coooooo`000?l0003o00001oooool2o`0000gooooo
0ol0000<ooooo`[o00001oooool2o`0000Cooooo0_l00006ooooo`;o00001oooool2o`0000Cooooo
0_l000000ooooooo0000o`00000;o`0000;ooooo0_l0000Dooooo`;o00000oooool2o`0000_ooooo
0ol000001?oooooo0000o`000?ooool2o`0000;ooooo0_l0000:ooooo`;o0000COooool001cooooo
0_l00013ooooo`;o00001_ooool4o`0000;ooooo0_l000000ooooooo0000o`000003o`0000Gooooo
0_l0000:ooooo`;o00000_ooool2o`0000kooooo1?l000001?oooooo0000o`000?ooool2o`0000?o
oooo0_l00003ooooo`;o000000?oooooo`000?l000001_ooool2o`000003ooooool0003o000000;o
00001_ooool4o`0000Gooooo0ol00004ooooo`;o00001?ooool2o`0000Cooooo0_l0000Mooooo`?o
000000Goooooo`000?l0003o0000ooooo`02o`000005ooooool0003o0000o`000?ooool00_l00005
ooooo`;o0000Coooool001cooooo00?o0000ooooooooool0E_ooool2o`0000Sooooo0_l00007oooo
o`;o00000_ooool2o`0001?ooooo0_l000000ooooooo0000o`000003ooooo`;o00000oooool7o`00
00Cooooo0_l000000ooooooo0000o`000002o`0000?ooooo2ol00004ooooo`Wo000000?oooooo`00
0?l000001?ooool2o`0001gooooo0_l00002ooooo`Co000000?oooooo`000?l000000_l00002oooo
o`;o00001Oooool2o`0004oooooo000Looooo`03o`000?oooooooooo05Oooooo0_l00006ooooo`?o
00006Oooool3o`0000Cooooo0_l0000=ooooo`Oo00001Oooool2o`0000Gooooo1?l00002ooooo`Go
00000_ooool6o`000003ooooool0003o000000;o0000:Oooool2o`000004ooooool0003o0000oooo
o`Co0000F_ooool001cooooo00?o0000ooooooooool0Eoooool4o`0000Cooooo0_l0000Jooooo`?o
00001?ooool5o`0000Kooooo0_l00003ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`00
00?ooooo0_l000000ooooooo0000o`000005ooooo`Oo00000_ooool3o`000003ooooool0003o0000
00;o000000?oooooo`000?l000001oooool2o`00023ooooo0_l00002ooooo`;o0000G_ooool001co
oooo00?o0000ooooooooool0F?ooool3o`0000Cooooo0_l0000<ooooo`?o00002?ooool2o`000003
ooooool0003o000000;ooooo0_l00002ooooo`Oo00000oooool2o`0000;ooooo0_l00002ooooo`;o
00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000005ooooo`Co00001Oooool2o`0000Co
oooo0_l00007ooooo`;o000000Coooooo`000?l0003o00006oooool2o`0000Kooooo0_l000000ooo
oooo0000o`000004ooooo`;o00000oooool2o`00053ooooo000Looooo`03o`000?oooooooooo06go
oooo0ol00008ooooo`;o00001Oooool2o`0000Gooooo1Ol00002ooooo`;o00000_ooool2o`0000ko
oooo0_l00003ooooo`Co00002?ooool2o`0000cooooo0_l00002ooooo`;o00003?ooool2o`0000[o
oooo0_l000000ooooooo0000o`000009ooooo`;o00001?ooool2o`0000?ooooo0_l0001@ooooo`00
7?ooool00ol0003oooooooooo`18ooooo`;o00009oooool2o`00013ooooo1?l000000ooooooo0000
o`000003o`0001?ooooo0_l00004ooooo`Co00002?ooool2o`000004ooooool0003o0000ooooo`;o
00000_ooool2o`000003ooooool0003o000000Cooooo0_l0000;ooooo`;o000000?oooooo`000?l0
00001oooool2o`000003ooooool0003o000000Kooooo0_l0001Nooooo`007?ooool00ol0003ooooo
ooooo`18ooooo`;o00002oooool2o`0001[ooooo0_l0000@ooooo`Co000000Coooooo`000?l0003o
oooo0_l00006ooooo`;o00002oooool5o`000004ooooool0003o0000ooooo`;o00002_ooool2o`00
0003ooooool0003o000000;ooooo0_l000001?oooooo0000o`000?l00003ooooo`?o00001?ooool2
o`0000Oooooo0_l00007ooooo`;o00002Oooool2o`0005kooooo000Looooo`03o`000?oooooooooo
05Gooooo0_l0000Uooooo`;o00000oooool2o`000003ooooool0003o000000Oooooo0_l00004oooo
o`Co00002_ooool4o`0000Cooooo0_l00007ooooo`;o00003?ooool3o`0000?ooooo0_l00004oooo
o`;o00001oooool4o`0000Gooooo0_l0001Yooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o
00001oooool2o`0000Wooooo0_l00002ooooo`;o00003_ooool2o`000003ooooool0003o000000;o
000000?oooooo`000?l000001oooool4o`0000Cooooo0ol0000;ooooo`;o00000_ooool2o`0000Wo
oooo0_l00006ooooo`;o00000_ooool2o`000003ooooool0003o000001;ooooo1?l00004ooooo`?o
00003_ooool2o`0005Wooooo000Looooo`03o`000?oooooooooo04gooooo0_l000000ooooooo0000
o`000002ooooo`;o00001oooool2o`0000Wooooo0_l00002ooooo`;o00004Oooool4o`000003oooo
ool0003o000000Wooooo0_l00004ooooo`?o00001_ooool2o`0000Oooooo0_l00002ooooo`;o0000
3Oooool2o`0000;ooooo0_l0000Mooooo`;o00003oooool2o`0005Wooooo000Looooo`03o`000?oo
oooooooo04gooooo0_l000000ooooooo0000o`00000<ooooo`;o00003?ooool2o`0000;ooooo0_l0
000<ooooo`Go00003Oooool2o`0000Cooooo0_l00006ooooo`;o00002oooool2o`0000oooooo0_l0
000<ooooo`?o00001_ooool5o`00077ooooo000Looooo`03o`000?oooooooooo05;ooooo0_l0000:
ooooo`;o00002oooool3o`000004ooooool0003o0000o`0000[ooooo1Ol00002ooooo`;o000000?o
ooooo`000?l000000_l00005ooooo`?o00001?ooool2o`0002Cooooo0_l00007ooooo`;o000000?o
ooooo`000?l000000ol00006ooooo`Go00003Oooool2o`0006;ooooo000Looooo`03o`000?oooooo
oooo05;ooooo0_l00006ooooo`;o00003oooool2o`0000;ooooo1?l00009ooooo`;o00000_ooool2
o`000004ooooool0003o0000ooooo`Co00001Oooool2o`0001Kooooo0_l0000?ooooo`;o00002Ooo
ool4o`000003ooooool0003o000000Oooooo0_l00003ooooo`;o00003Oooool2o`0000Sooooo0_l0
001Hooooo`007?ooool00ol0003oooooooooo`1Jooooo`;o00005Oooool2o`0000Oooooo0_l00004
ooooo`?o000000?oooooo`000?l000003?ooool2o`0000?ooooo0_l0000>ooooo`;o00002?ooool2
o`0000Gooooo0_l000000ooooooo0000o`000006ooooo`;o00001?ooool2o`0000Gooooo0ol00002
ooooo`;o00002?ooool2o`0000kooooo0_l00008ooooo`;o0000C_ooool001cooooo00?o0000oooo
ooooool0D?ooool2o`0000?ooooo0_l00004ooooo`;o00003?ooool2o`0000[ooooo0_l00002oooo
o`?o00001Oooool2o`000003ooooool0003o000000_ooooo0ol00003ooooo`;o00001_ooool2o`00
00Gooooo0_l00009ooooo`?o00001oooool4o`000004ooooool0003o0000ooooo`;o00001?ooool2
o`0000Gooooo0_l00002ooooo`?o00002?ooool2o`0001Sooooo0_l0001>ooooo`007?ooool2o`00
057ooooo0ol00002ooooo`;o00001?ooool2o`0000cooooo0_l0000:ooooo`Ko00000_ooool2o`00
00;ooooo0_l000000ooooooo0000o`000004ooooo`;o00001Oooool6o`0000Gooooo0_l000000ooo
oooo0000o`000005ooooo`Go00000_ooool2o`0000?ooooo0_l00006ooooo`;o000000Coooooo`00
0?l0003ooooo0_l0000Booooo`;o0000Loooool001cooooo00?o0000ooooooooool0DOooool2o`00
00?ooooo0_l0000Oooooo`;o00001?ooool2o`0000;ooooo0_l00007ooooo`;o00001oooool4o`00
00Gooooo0_l0000:ooooo`?o00000_ooool4o`0000Wooooo0_l00004ooooo`;o00001?ooool2o`00
00;ooooo0_l00002ooooo`;o00004Oooool2o`0006Kooooo000Looooo`03o`000?oooooooooo05Ko
oooo0_l00005ooooo`;o00005?ooool2o`0000cooooo0_l0000:ooooo`;o00001Oooool6o`0000Co
oooo0_l0000?ooooo`;o00001Oooool2o`0000Sooooo0_l00003ooooo`?o00000_ooool2o`0000;o
oooo0_l0000?ooooo`Co0000I_ooool001cooooo00?o0000ooooooooool0Eoooool2o`0000?ooooo
0ol0000>ooooo`;o00001?ooool2o`0001Sooooo0_l00005ooooo`Ko000000?oooooo`000?l00000
0ol0000Booooo`;o00000_ooool2o`0000gooooo0_l00004ooooo`;o00001_ooool2o`0000[ooooo
0_l0001Xooooo`007?ooool00ol0003oooooooooo`1Gooooo`;o00000oooool2o`0000Gooooo0_l0
0008ooooo`;o00001?ooool2o`00027ooooo0_l000000ooooooo0000o`000009o`000003ooooool0
003o000000_ooooo0_l00007ooooo`;o00000oooool2o`0000Gooooo1_l00006ooooo`;o00009Ooo
ool2o`0004gooooo000Looooo`03o`000?oooooooooo06?ooooo1?l00007ooooo`;o00003?ooool4
o`0000Oooooo0ol00002ooooo`;o00002?ooool2o`000003ooooool0003o000000;o000000?ooooo
o`000?l000001ol00002ooooo`;o00003oooool3o`0000?ooooo0_l00005ooooo`Co00003oooool2
o`0001kooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`1Gooooo`;o00003?ooool2o`00
00Oooooo0_l00007ooooo`;o00000oooool4o`0000Oooooo0ol00002ooooo`;o00000oooool2o`00
00;ooooo0ol00002ooooo`Co000000?oooooo`000?l000001?l00004ooooo`;o00003oooool2o`00
00Sooooo0_l0000<ooooo`;o00001_ooool2o`0000?ooooo0ol0001Wooooo`007?ooool00ol0003o
ooooooooo`1Gooooo`;o00004Oooool2o`0000_ooooo0_l0000Aooooo`;o00001Oooool2o`0000;o
oooo0ol00002ooooo`Co00000_ooool8o`0001cooooo0_l0000<ooooo`;o00001Oooool2o`0000Co
oooo0ol0001Wooooo`007?ooool00ol0003oooooooooo`1Jooooo`;o00003_ooool2o`0000Kooooo
0_l000000ooooooo0000o`00000Cooooo`;o00001Oooool2o`0000?ooooo0_l00007ooooo`_o0000
1_ooool3o`0001Kooooo0_l000000ooooooo0000o`00000;ooooo`;o00000_ooool2o`0001Kooooo
0_l0001Booooo`007?ooool00ol0003oooooooooo`1Jooooo`;o00001Oooool2o`0000oooooo0_l0
00000ooooooo0000o`00000Hooooo`;o00003_ooool;o`0000Kooooo0ol00009ooooo`;o00002ooo
ool2o`000003ooooool0003o000000cooooo0_l000000ooooooo0000o`000002o`0001Cooooo0_l0
001Booooo`007?ooool00ol0003oooooooooo`1Qooooo`;o00001Oooool2o`0000_ooooo0ol0000C
ooooo`;o00000_ooool2o`0000;ooooo0_l0000;ooooo`So00002Oooool2o`0000Wooooo1Ol0000<
ooooo`;o00002oooool2o`000003ooooool0003o000000;o0000J?ooool001cooooo00?o0000oooo
ooooool0Goooool3o`0000Kooooo0_l0000<ooooo`?o00004_ooool2o`0000Kooooo0_l00002oooo
o`?o00005_ooool2o`0000_ooooo1?l0000:ooooo`Co0000N_ooool001cooooo00?o0000oooooooo
ool0Goooool3o`0000Gooooo0_l0000:ooooo`;o00000_ooool2o`0001Cooooo0_l00008ooooo`?o
00004oooool2o`000004ooooool0003o0000o`0000;ooooo0ol00003ooooo`;o000000?oooooo`00
0?l000002oooool3o`0000[ooooo0_l0001_ooooo`007?ooool00ol0003oooooooooo`1Tooooo`;o
000000?oooooo`000?l000001oooool2o`000004ooooool0003o0000o`0000?ooooo0_l00007oooo
o`?o00002?ooool2o`0000Wooooo0_l0000@ooooo`;o000000Goooooo`000?l0003o0000ooooo`02
o`0000;ooooo1?l00002ooooo`Oo000000?oooooo`000?l000004oooool2o`0006oooooo00001_oo
ooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0
1_ooool00ol0003oooooooooo`1Tooooo`;o00002_ooool2o`0000;ooooo0_l00003ooooo`;o0000
1oooool3o`0001Oooooo0_l0000<ooooo`;o00000_ooool2o`0000Gooooo2Ol00002ooooo`Go0000
Q?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?oo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo07;ooooo0_l0000Xooooo`;o00004Oooool2o`00
00?ooooo0_l00003ooooo`?o00001Oooool3o`0008Gooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
06Gooooo0_l00006ooooo`?o00000_ooool2o`0000Gooooo0_l0000>ooooo`;o00007_ooool3o`00
00?ooooo0_l00003ooooo`;o00002oooool3o`0000Sooooo0_l00003ooooo`;o000000?oooooo`00
0?l00000Loooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Olb<S;o
V9RHoooooonHV9So<S8b00Kooooo0ol0001Uooooo`;o00001_ooool3o`0000Gooooo0_l00002oooo
o`;o00002?ooool2o`0000Cooooo0_l0000?ooooo`;o00003Oooool3o`0000cooooo0_l0000Boooo
o`?o00000_ooool2o`000003ooooool0003o000007?ooooo00000ooooooo0000ooooo`02ooooo`03
o`000?oooooooooo00Wooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo
07Gooooo0_l0000<ooooo`;o00000_ooool2o`0000Wooooo0_l00006ooooo`;o00006oooool3o`00
00_ooooo0_l00006ooooo`;o0000N_ooool00003ooooool@413ooooo00;ooooo00?o410@oooooooo
ool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0Qoooool2o`00
00Wooooo0_l00007ooooo`;o00005oooool2o`000003ooooool0003o000000cooooo0_l00022oooo
o`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l000001_oo
ool00ol0003oooooooooo`1]ooooo`;o00009_ooool2o`0000Cooooo0_l0000:ooooo`;o00002ooo
ool2o`0002kooooo0_l0001Sooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`1]ooooo`Go00007Oooool4o`0000;o
oooo0_l0000@ooooo`;o00000oooool2o`0003Kooooo0_l0001Sooooo`007?ooool00ol0003ooooo
ooooo`1_ooooo`Co00000_ooool2o`0001Sooooo1?l00004ooooo`;o00004oooool2o`0000Wooooo
0_l0002@ooooo`007?ooool00ol0003oooooooooo`1aooooo`;o00000_ooool2o`0000Kooooo0_l0
0006ooooo`;o00004?ooool4o`00017ooooo0_l00004ooooo`;o00000oooool2o`00093ooooo000L
ooooo`03o`000?oooooooooo06gooooo0_l0000>ooooo`;o00001_ooool2o`0000Kooooo0_l00006
ooooo`;o00000_ooool2o`0001Oooooo0_l0002Eooooo`007?ooool00ol0003oooooooooo`1]oooo
o`;o00007_ooool2o`0000Kooooo0_l00002ooooo`Co00004Oooool2o`0002Cooooo0_l0001coooo
o`007?ooool00ol0003oooooooooo`2:ooooo`;o00003Oooool4o`000003ooooool0003o000000ko
oooo0_l0000Tooooo`;o0000Loooool001cooooo00?o0000ooooooooool0R_ooool4o`0000;ooooo
0_l0000<ooooo`;o00004oooool2o`0001gooooo0ol0001dooooo`007?ooool00ol0003ooooooooo
o`2<ooooo`;o00000_ooool2o`0001[ooooo0ol00004ooooo`;o00005?ooool2o`0000Oooooo0ol0
001dooooo`007?ooool00ol0003oooooooooo`2Iooooo`;o00004Oooool5o`0001Sooooo0ol0001m
ooooo`007?ooool00ol0003oooooooooo`2Iooooo`;o000000?oooooo`000?l000004Oooool2o`00
01Wooooo0_l0001mooooo`007?ooool00ol0003oooooooooo`2Looooo`Co0000ZOooool001cooooo
00?o0000ooooooooool0W_ooool2o`0001;ooooo0_l00006ooooo`;o0000SOooool001cooooo0_l0
001kooooo`;o00000oooool2o`0001gooooo0_l0000Booooo`;o00001_ooool2o`0008gooooo000L
ooooo`03o`000?oooooooooo07[ooooo0_l00003ooooo`;o0000b?ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`1oooooo`;o0000b?ooool001cooooo
00?o0000ooooooooool0Ooooool2o`000<Sooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooo
od_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001;ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB_ooool0
01Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03
o`000?oooooooooo00Gooooo0ol0003ooooood[ooooo000Dooooo`03o`000?oooooooooo0?oooooo
D_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3o
oooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001;ooooo00?oEEEEofIVI_l0
0000oooooomDooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00YOooool01?l@
413o0000o`000?ooool2o`000003oa0@4?oooooooooo01Oooooo00?o0000onk^k_ooool00oooool0
1Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo1Ol0002@ooooo`00Y_ooool01Ol0003ooooooooooooo
oooo000000Wooooo1_l0000;ooooo`03oeEEEOnYZJWooooo00?ooooo00GoEEEEogMgMoooooooV9RH
ob4Q8@03ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0T?ooool00:Kooooo00Go0000oooooooooooo
ooooo`00000Jooooo`03ojVYZOmEEEGooooo00?ooooo00Go0000ooooooooooooooooo`000004oooo
o`03oiRHV?lQ8B7ok^k^097ooooo002Vooooo`05o`000?ooooooooooooooool000002Oooool6o`00
00cooooo00?o8B4Qooooooooool00_ooool01Ol0003oV9RHoooooonHV9So8B4Q00Gooooo00?oV9RH
ob4Q8Oo^k^h0T?ooool00:Kooooo00Go0000ohN7QoooooooZJVYo`00000Kooooo`03oeEEEOo<c<co
oooo00;ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03ogMgMomVIVKooooo08oooooo002U
ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool06Oooool00onYZJWoMgMgooooo`02
ooooo`03oeEEEOn7QhOooooo00Wooooo00?o0000ooooooooool0S_ooool00<?ooooo00Go410@oooo
oooooooooooooc8b<P03ooooo`03omgMgOl@413oV9RH00Gooooo00Go0000okZj^_ooooooV9RHoa0@
402@ooooo`00`oooool5o`0000Cooooo00Coc<c<odA4A?l0003o410@0oooool01OnHV9So410@o`00
0?lQ8B7oc<c<093ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(768) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.64929 .51708 Mdot
.661 .51426 Mdot
.38648 .41478 Mdot
.53902 .60053 Mdot
.4252 .53363 Mdot
.35867 .36375 Mdot
.54574 .37001 Mdot
.53 .40594 Mdot
.35174 .38357 Mdot
.62969 .60189 Mdot
.54141 .34438 Mdot
.49976 .71571 Mdot
.53504 .37394 Mdot
.49889 .63767 Mdot
.37371 .19341 Mdot
.5448 .69174 Mdot
.71271 .51595 Mdot
.32102 .56413 Mdot
.58484 .6207 Mdot
.35612 .41305 Mdot
.66445 .55445 Mdot
.49978 .6425 Mdot
.6642 .52517 Mdot
.50019 .63851 Mdot
.5321 .61189 Mdot
.68501 .49092 Mdot
.66694 .5395 Mdot
.54958 .63692 Mdot
.50767 .61747 Mdot
.56501 .37178 Mdot
.39195 .51311 Mdot
.23593 .30345 Mdot
.53108 .70397 Mdot
.5969 .78146 Mdot
.54542 .39944 Mdot
.22807 .62462 Mdot
.3665 .40238 Mdot
.5092 .36775 Mdot
.53946 .40376 Mdot
.51739 .39581 Mdot
.51364 .37843 Mdot
.67897 .49066 Mdot
.53385 .33106 Mdot
.58246 .40686 Mdot
.54721 .60011 Mdot
.64589 .34977 Mdot
.26485 .59482 Mdot
.54385 .64277 Mdot
.65558 .48917 Mdot
.34214 .40229 Mdot
.69137 .7603 Mdot
.49995 .38814 Mdot
.52882 .22458 Mdot
.32268 .15483 Mdot
.52933 .38995 Mdot
.55109 .60865 Mdot
.37419 .38368 Mdot
.51238 .66605 Mdot
.51341 .64841 Mdot
.70297 .73006 Mdot
.52924 .62621 Mdot
.34946 .56013 Mdot
.73268 .51414 Mdot
.41083 .37078 Mdot
.35434 .3736 Mdot
.55504 .39246 Mdot
.7155 .48766 Mdot
.53223 .36528 Mdot
.4773 .58216 Mdot
.34371 .39386 Mdot
.5449 .64423 Mdot
.53555 .34462 Mdot
.69067 .46266 Mdot
.47853 .66183 Mdot
.6789 .36947 Mdot
.44554 .17576 Mdot
.31269 .54265 Mdot
.68881 .72162 Mdot
.78942 .51398 Mdot
.45735 .20724 Mdot
.50356 .62893 Mdot
.81181 .34391 Mdot
.39087 .18677 Mdot
.66972 .52423 Mdot
.41742 .62581 Mdot
.43246 .38106 Mdot
.48033 .64945 Mdot
.43313 .48914 Mdot
.45603 .63616 Mdot
.74762 .42092 Mdot
.35435 .38971 Mdot
.67354 .48358 Mdot
.53435 .59662 Mdot
.50217 .68935 Mdot
.71921 .61622 Mdot
.46344 .64416 Mdot
.55604 .63994 Mdot
.67856 .54556 Mdot
.55849 .36205 Mdot
.45029 .66194 Mdot
.5958 .37387 Mdot
.53751 .22963 Mdot
.4954 .60098 Mdot
.34364 .37389 Mdot
.71632 .52263 Mdot
.4994 .59443 Mdot
.53722 .39436 Mdot
.52129 .63254 Mdot
.58708 .35545 Mdot
.65315 .50712 Mdot
.50006 .6876 Mdot
.32526 .56644 Mdot
.73247 .37938 Mdot
.69133 .47678 Mdot
.72695 .28097 Mdot
.53414 .63306 Mdot
.50213 .64905 Mdot
.66292 .51275 Mdot
.38792 .37046 Mdot
.41938 .48215 Mdot
.71117 .47452 Mdot
.52906 .40139 Mdot
.6663 .53406 Mdot
.50812 .5799 Mdot
.36026 .35362 Mdot
.54242 .22718 Mdot
.54579 .25579 Mdot
.41414 .76297 Mdot
.4791 .64001 Mdot
.57362 .30887 Mdot
.36804 .36013 Mdot
.66728 .49247 Mdot
.52959 .36763 Mdot
.56254 .64473 Mdot
.70664 .51188 Mdot
.5205 .36083 Mdot
.32915 .56475 Mdot
.2398 .4868 Mdot
.67827 .4707 Mdot
.5777 .49087 Mdot
.5768 .36101 Mdot
.51735 .39487 Mdot
.61125 .79947 Mdot
.66599 .51657 Mdot
.3432 .53504 Mdot
.52466 .35899 Mdot
.37894 .65222 Mdot
.56098 .6471 Mdot
.478 .77421 Mdot
.82901 .43046 Mdot
.67134 .7793 Mdot
.62701 .25652 Mdot
.36885 .548 Mdot
.50449 .38018 Mdot
.51988 .60104 Mdot
.67597 .51282 Mdot
.67429 .50391 Mdot
.52425 .68945 Mdot
.53663 .61903 Mdot
.53582 .67462 Mdot
.5219 .68718 Mdot
.26184 .57498 Mdot
.53334 .67881 Mdot
.3189 .35953 Mdot
.70735 .48543 Mdot
.52286 .61351 Mdot
.39631 .38925 Mdot
.56888 .65937 Mdot
.51352 .36343 Mdot
.51211 .6533 Mdot
.54341 .61685 Mdot
.46898 .63035 Mdot
.51046 .37978 Mdot
.2019 .37753 Mdot
.813 .41917 Mdot
.17703 .52849 Mdot
.66584 .27014 Mdot
.37776 .37405 Mdot
.48583 .64899 Mdot
.33695 .55224 Mdot
.52785 .54671 Mdot
.51638 .64479 Mdot
.75265 .70765 Mdot
.54774 .62701 Mdot
.5819 .75772 Mdot
.59198 .6112 Mdot
.16563 .5154 Mdot
.46629 .41622 Mdot
.51191 .61935 Mdot
.69475 .59193 Mdot
.50759 .79354 Mdot
.47959 .54166 Mdot
.51943 .3843 Mdot
.39754 .37911 Mdot
.37362 .39271 Mdot
.54367 .33038 Mdot
.45007 .62726 Mdot
.61955 .61218 Mdot
.4444 .6462 Mdot
.54611 .23115 Mdot
.71042 .46501 Mdot
.35492 .5225 Mdot
.66313 .47612 Mdot
.74637 .25936 Mdot
.70084 .4235 Mdot
.57486 .39088 Mdot
.33518 .57981 Mdot
.39819 .39835 Mdot
.5497 .23134 Mdot
.33677 .54556 Mdot
.54053 .6538 Mdot
.66015 .48677 Mdot
.52754 .80093 Mdot
.58778 .60824 Mdot
.40621 .81823 Mdot
.69169 .52678 Mdot
.45947 .45617 Mdot
.52068 .3763 Mdot
.33785 .40482 Mdot
.48671 .63011 Mdot
.51903 .68026 Mdot
.7182 .53077 Mdot
.54069 .64144 Mdot
.76583 .49251 Mdot
.54703 .61792 Mdot
.40767 .35155 Mdot
.34877 .50582 Mdot
.51043 .34967 Mdot
.42729 .76784 Mdot
.66316 .4657 Mdot
.30459 .35071 Mdot
.35918 .41035 Mdot
.62751 .57455 Mdot
.54472 .34348 Mdot
.33063 .56912 Mdot
.37841 .40787 Mdot
.37634 .55015 Mdot
.48618 .60779 Mdot
.36231 .4035 Mdot
.35198 .52718 Mdot
.21959 .46899 Mdot
.55732 .61241 Mdot
.33767 .61376 Mdot
.54508 .36298 Mdot
.6533 .52961 Mdot
.52862 .62514 Mdot
.54629 .25739 Mdot
.5495 .58626 Mdot
.5577 .26896 Mdot
.52875 .23684 Mdot
.53085 .22386 Mdot
.42601 .20251 Mdot
.35701 .56839 Mdot
.65618 .30481 Mdot
.59942 .4568 Mdot
.7171 .49007 Mdot
.53745 .59591 Mdot
.1729 .4351 Mdot
.52329 .36066 Mdot
.53837 .65441 Mdot
.42569 .36831 Mdot
.52719 .35785 Mdot
.50537 .66712 Mdot
.51404 .3869 Mdot
.67384 .50993 Mdot
.3365 .44172 Mdot
.69844 .53228 Mdot
.55686 .61586 Mdot
.54294 .3883 Mdot
.38481 .39743 Mdot
.68647 .49302 Mdot
.52189 .63598 Mdot
.48912 .64245 Mdot
.54588 .23904 Mdot
.5164 .61342 Mdot
.17927 .43758 Mdot
.54846 .63994 Mdot
.40647 .38258 Mdot
.46141 .64356 Mdot
.67501 .78965 Mdot
.24662 .47927 Mdot
.70575 .47627 Mdot
.52972 .23042 Mdot
.35749 .387 Mdot
.33172 .44732 Mdot
.53058 .51538 Mdot
.51098 .63075 Mdot
.53477 .24333 Mdot
.43175 .45736 Mdot
.55818 .38995 Mdot
.46404 .61449 Mdot
.70545 .4134 Mdot
.37276 .41328 Mdot
.54827 .23284 Mdot
.55352 .70061 Mdot
.71421 .52621 Mdot
.54107 .60331 Mdot
.37043 .40561 Mdot
.66378 .53389 Mdot
.56552 .61532 Mdot
.26128 .62134 Mdot
.53467 .25246 Mdot
.54345 .3624 Mdot
.60699 .61134 Mdot
.54393 .66733 Mdot
.3809 .38981 Mdot
.68154 .5242 Mdot
.55031 .39014 Mdot
.69025 .48334 Mdot
.51123 .79867 Mdot
.68034 .28629 Mdot
.23483 .55398 Mdot
.33054 .57843 Mdot
.56982 .23974 Mdot
.18103 .54982 Mdot
.68608 .31589 Mdot
.37125 .70612 Mdot
.21849 .66185 Mdot
.39154 .39669 Mdot
.38738 .60322 Mdot
.3632 .38528 Mdot
.50738 .60058 Mdot
.35576 .36706 Mdot
.1585 .50719 Mdot
.55134 .63005 Mdot
.37887 .37738 Mdot
.29619 .50384 Mdot
.53346 .62168 Mdot
.70034 .47805 Mdot
.31825 .23857 Mdot
.79627 .45755 Mdot
.68041 .43487 Mdot
.38383 .37251 Mdot
.78666 .62306 Mdot
.54464 .63184 Mdot
.55999 .67846 Mdot
.68033 .50976 Mdot
.45882 .62295 Mdot
.34103 .52281 Mdot
.37662 .55949 Mdot
.47764 .76803 Mdot
.76386 .33065 Mdot
.45381 .59803 Mdot
.6845 .49654 Mdot
.78135 .52768 Mdot
.67561 .3707 Mdot
.55853 .24323 Mdot
.56273 .39545 Mdot
.20799 .37226 Mdot
.51915 .5578 Mdot
.57695 .49658 Mdot
.6977 .40724 Mdot
.66146 .49074 Mdot
.20304 .46071 Mdot
.53099 .38772 Mdot
.73694 .56231 Mdot
.63033 .7122 Mdot
.53384 .67131 Mdot
.56247 .35594 Mdot
.47422 .70057 Mdot
.765 .44537 Mdot
.38764 .62643 Mdot
.51065 .25528 Mdot
.5535 .60733 Mdot
.66229 .31658 Mdot
.50649 .64997 Mdot
.45711 .7527 Mdot
.55141 .64436 Mdot
.69643 .48584 Mdot
.44295 .61993 Mdot
.46699 .49901 Mdot
.7976 .37499 Mdot
.71679 .42695 Mdot
.37097 .5481 Mdot
.49239 .64442 Mdot
.52923 .67469 Mdot
.36272 .55231 Mdot
.69575 .49952 Mdot
.55234 .64922 Mdot
.31615 .70371 Mdot
.54016 .66902 Mdot
.51233 .36282 Mdot
.38969 .49508 Mdot
.63459 .46394 Mdot
.48641 .67499 Mdot
.69194 .53789 Mdot
.52084 .38974 Mdot
.5405 .40545 Mdot
.52741 .56422 Mdot
.50578 .37972 Mdot
.54419 .60657 Mdot
.37782 .48252 Mdot
.65902 .52141 Mdot
.56024 .70208 Mdot
.69801 .50328 Mdot
.79706 .55821 Mdot
.51933 .39237 Mdot
.55624 .24021 Mdot
.5587 .53489 Mdot
.5367 .38251 Mdot
.78481 .48314 Mdot
.49192 .56249 Mdot
.5713 .60712 Mdot
.78925 .47523 Mdot
.39222 .38132 Mdot
.55409 .23159 Mdot
.54223 .39261 Mdot
.54005 .67163 Mdot
.48096 .6062 Mdot
.53492 .34193 Mdot
.73974 .6223 Mdot
.3367 .45715 Mdot
.55367 .64027 Mdot
.698 .48989 Mdot
.67046 .49011 Mdot
.56235 .60722 Mdot
.52244 .642 Mdot
.40541 .37902 Mdot
.53702 .24986 Mdot
.54369 .21991 Mdot
.5486 .2536 Mdot
.3279 .37797 Mdot
.57824 .27134 Mdot
.51636 .39481 Mdot
.59805 .30812 Mdot
.4332 .32821 Mdot
.55731 .57577 Mdot
.3841 .38983 Mdot
.50669 .67612 Mdot
.49845 .60467 Mdot
.55126 .38757 Mdot
.62706 .22175 Mdot
.47293 .71934 Mdot
.64898 .49013 Mdot
.50376 .37154 Mdot
.58318 .56295 Mdot
.47921 .39898 Mdot
.33817 .52672 Mdot
.71973 .43636 Mdot
.55798 .34997 Mdot
.67365 .48008 Mdot
.53891 .33841 Mdot
.53208 .6743 Mdot
.53875 .68552 Mdot
.65734 .50697 Mdot
.3583 .56867 Mdot
.48152 .60142 Mdot
.5044 .66582 Mdot
.77522 .71656 Mdot
.67935 .3646 Mdot
.48015 .38368 Mdot
.51135 .60782 Mdot
.56505 .59118 Mdot
.37074 .55817 Mdot
.54337 .66317 Mdot
.4853 .6334 Mdot
.74272 .3814 Mdot
.53366 .32681 Mdot
.32747 .52103 Mdot
.73672 .55932 Mdot
.69406 .52505 Mdot
.19559 .41679 Mdot
.53607 .22886 Mdot
.50842 .34458 Mdot
.33814 .44172 Mdot
.55229 .24154 Mdot
.45502 .32537 Mdot
.19981 .43684 Mdot
.5531 .24631 Mdot
.34689 .43868 Mdot
.42474 .62921 Mdot
.55395 .66722 Mdot
.51053 .65648 Mdot
.33363 .55248 Mdot
.66901 .5159 Mdot
.45706 .43285 Mdot
.22993 .42791 Mdot
.5007 .64487 Mdot
.71898 .54036 Mdot
.21741 .40282 Mdot
.54861 .23804 Mdot
.34713 .56516 Mdot
.35082 .51882 Mdot
.5034 .65135 Mdot
.72619 .34915 Mdot
.6839 .49288 Mdot
.52155 .63609 Mdot
.50204 .68416 Mdot
.38607 .37545 Mdot
.67021 .47939 Mdot
.35721 .40917 Mdot
.5295 .24418 Mdot
.29152 .74107 Mdot
.75329 .73804 Mdot
.55488 .37394 Mdot
.18434 .51419 Mdot
.51814 .4079 Mdot
.49167 .20493 Mdot
.54522 .25384 Mdot
.51122 .63835 Mdot
.67393 .46357 Mdot
.5234 .63323 Mdot
.53458 .66417 Mdot
.54099 .65607 Mdot
.4501 .60469 Mdot
.74508 .71685 Mdot
.3466 .54419 Mdot
.54557 .57526 Mdot
.39402 .35707 Mdot
.18209 .47636 Mdot
.30607 .26283 Mdot
.49292 .67109 Mdot
.49901 .65187 Mdot
.71391 .49659 Mdot
.50003 .69274 Mdot
.56557 .37752 Mdot
.67405 .52613 Mdot
.48588 .60166 Mdot
.20555 .48119 Mdot
.55208 .65641 Mdot
.18761 .56038 Mdot
.53749 .33918 Mdot
.71624 .4365 Mdot
.52381 .57286 Mdot
.55343 .2469 Mdot
.55449 .23276 Mdot
.56131 .23315 Mdot
.56948 .37024 Mdot
.38172 .3829 Mdot
.27135 .35309 Mdot
.47942 .69544 Mdot
.52562 .60223 Mdot
.5587 .58546 Mdot
.33688 .40918 Mdot
.40841 .50172 Mdot
.63206 .27006 Mdot
.55141 .55436 Mdot
.39387 .36288 Mdot
.64388 .52338 Mdot
.70234 .2458 Mdot
.67645 .52537 Mdot
.32994 .51828 Mdot
.52531 .35214 Mdot
.33273 .53014 Mdot
.77691 .66022 Mdot
.65604 .51142 Mdot
.71687 .53217 Mdot
.37905 .37551 Mdot
.48217 .44824 Mdot
.2065 .27332 Mdot
.34281 .36612 Mdot
.3525 .72574 Mdot
.68372 .50609 Mdot
.47393 .65949 Mdot
.42188 .46097 Mdot
.48255 .45324 Mdot
.3675 .37647 Mdot
.49934 .63021 Mdot
.76602 .34837 Mdot
.40481 .38299 Mdot
.46592 .61356 Mdot
.37736 .36123 Mdot
.51351 .37341 Mdot
.37185 .36096 Mdot
.64208 .48895 Mdot
.48847 .60811 Mdot
.27503 .19816 Mdot
.5546 .43856 Mdot
.5261 .62657 Mdot
.50384 .37207 Mdot
.30531 .70502 Mdot
.52456 .67004 Mdot
.33516 .52577 Mdot
.3738 .35056 Mdot
.31734 .46291 Mdot
.54155 .63081 Mdot
.36465 .36729 Mdot
.64324 .5038 Mdot
.48823 .37845 Mdot
.44602 .19141 Mdot
.54958 .22321 Mdot
.67533 .51746 Mdot
.55537 .21165 Mdot
.57389 .36203 Mdot
.46634 .62493 Mdot
.51187 .68626 Mdot
.70365 .48585 Mdot
.41867 .23911 Mdot
.48301 .68465 Mdot
.50353 .62907 Mdot
.38606 .41304 Mdot
.34661 .42714 Mdot
.35768 .2576 Mdot
.39146 .39519 Mdot
.56094 .58611 Mdot
.70221 .48501 Mdot
.50867 .59662 Mdot
.70225 .47762 Mdot
.53693 .59603 Mdot
.72117 .45779 Mdot
.67341 .52303 Mdot
.71426 .29512 Mdot
.49458 .61729 Mdot
.59835 .61146 Mdot
.5381 .66204 Mdot
.54699 .65032 Mdot
.36558 .34905 Mdot
.35831 .54584 Mdot
.45943 .65318 Mdot
.30617 .36675 Mdot
.33829 .56626 Mdot
.54661 .77427 Mdot
.38771 .37525 Mdot
.33012 .55052 Mdot
.29495 .59628 Mdot
.53059 .22864 Mdot
.34489 .55224 Mdot
.29301 .28504 Mdot
.55468 .37755 Mdot
.67128 .53212 Mdot
.53259 .62068 Mdot
.24679 .70423 Mdot
.38411 .50299 Mdot
.54221 .24495 Mdot
.53612 .63141 Mdot
.51204 .67592 Mdot
.71755 .51685 Mdot
.77898 .29477 Mdot
.37473 .42394 Mdot
.5262 .59697 Mdot
.70965 .51924 Mdot
.82812 .41551 Mdot
.35354 .35523 Mdot
.3414 .55461 Mdot
.51954 .35143 Mdot
.63109 .51783 Mdot
.55053 .22299 Mdot
.55629 .39384 Mdot
.38103 .45162 Mdot
.79725 .6202 Mdot
.54104 .6363 Mdot
.37906 .39621 Mdot
.67787 .77468 Mdot
.45096 .64511 Mdot
.51612 .32345 Mdot
.54751 .7509 Mdot
.6645 .48807 Mdot
.52561 .34668 Mdot
.36872 .5326 Mdot
.66141 .52588 Mdot
.69533 .4976 Mdot
.52531 .4051 Mdot
.35432 .33201 Mdot
.46249 .45616 Mdot
.52327 .3503 Mdot
.75135 .4166 Mdot
.53156 .79417 Mdot
.53443 .24526 Mdot
.35187 .56631 Mdot
.54281 .81004 Mdot
.68009 .48964 Mdot
.20666 .37376 Mdot
.73082 .72736 Mdot
.55599 .63999 Mdot
.33934 .53176 Mdot
.45501 .34056 Mdot
.26487 .35808 Mdot
.53187 .35533 Mdot
.42833 .50246 Mdot
.32976 .52744 Mdot
.55507 .65893 Mdot
.62208 .4763 Mdot
.49798 .61715 Mdot
.51604 .36541 Mdot
.77407 .48352 Mdot
.67881 .47752 Mdot
.57115 .35346 Mdot
.76949 .46589 Mdot
.49649 .60648 Mdot
.4955 .62417 Mdot
.42197 .72718 Mdot
.65922 .48681 Mdot
.54782 .22002 Mdot
.5159 .62816 Mdot
.51264 .66373 Mdot
.46525 .63099 Mdot
.60223 .58271 Mdot
.71596 .35607 Mdot
.52194 .59585 Mdot
.33201 .36734 Mdot
.57336 .64446 Mdot
.49302 .62448 Mdot
.70686 .52706 Mdot
.76166 .71946 Mdot
.53432 .25578 Mdot
.51366 .65668 Mdot
.54976 .64502 Mdot
.53663 .40297 Mdot
.44642 .45407 Mdot
.49039 .45581 Mdot
.34218 .3868 Mdot
.3641 .67955 Mdot
.44734 .62665 Mdot
.70334 .5152 Mdot
.32188 .56025 Mdot
.47472 .63939 Mdot
.70775 .51403 Mdot
.56613 .65533 Mdot
.40319 .37328 Mdot
.53672 .24796 Mdot
.61255 .46721 Mdot
.34822 .55631 Mdot
.44052 .4205 Mdot
.61789 .34453 Mdot
.39786 .38499 Mdot
.52829 .6065 Mdot
.49383 .38078 Mdot
.35304 .40092 Mdot
.544 .24016 Mdot
.56655 .68668 Mdot
.67702 .50223 Mdot
.6819 .47888 Mdot
.47064 .76449 Mdot
.3822 .42554 Mdot
.84497 .54509 Mdot
.51369 .37236 Mdot
.51805 .58316 Mdot
.60349 .36311 Mdot
.68578 .47753 Mdot
.46019 .76748 Mdot
.3307 .55297 Mdot
.53444 .35479 Mdot
.55274 .25839 Mdot
.71034 .50756 Mdot
.66976 .47583 Mdot
.55559 .60694 Mdot
.49087 .66245 Mdot
.36943 .7125 Mdot
.47166 .76937 Mdot
.51304 .38163 Mdot
.35774 .56372 Mdot
.34057 .39423 Mdot
.50509 .60575 Mdot
.66799 .52464 Mdot
.57479 .76062 Mdot
.54344 .67098 Mdot
.40527 .38284 Mdot
.66114 .49395 Mdot
.36284 .5564 Mdot
.32509 .55147 Mdot
.54686 .65071 Mdot
.70072 .7221 Mdot
.5417 .38065 Mdot
.69384 .47645 Mdot
.61923 .54485 Mdot
.47474 .67351 Mdot
.48918 .65862 Mdot
.513 .71891 Mdot
.55433 .3948 Mdot
.62288 .46564 Mdot
.31641 .54858 Mdot
.67019 .50272 Mdot
.52486 .62815 Mdot
.34899 .56006 Mdot
.59966 .51573 Mdot
.54804 .24911 Mdot
.37389 .35926 Mdot
.34284 .52152 Mdot
.35878 .53479 Mdot
.33718 .56776 Mdot
.219 .35807 Mdot
.70627 .46423 Mdot
.77383 .52178 Mdot
.55293 .64661 Mdot
.4706 .76239 Mdot
.51293 .69613 Mdot
.57132 .3659 Mdot
.39231 .3877 Mdot
.5331 .66783 Mdot
.55455 .60528 Mdot
.60038 .67156 Mdot
.59131 .57702 Mdot
.68641 .55395 Mdot
.65356 .49778 Mdot
.59831 .59017 Mdot
.38965 .38055 Mdot
.82 .34025 Mdot
.15884 .40676 Mdot
.50686 .57604 Mdot
.46057 .44357 Mdot
.67176 .52504 Mdot
.51763 .40244 Mdot
.49602 .46401 Mdot
.51864 .34905 Mdot
.66724 .50081 Mdot
.50662 .60264 Mdot
.60216 .3091 Mdot
.37022 .56592 Mdot
.53165 .67829 Mdot
.52059 .37239 Mdot
.53405 .67639 Mdot
.56651 .35692 Mdot
.75417 .50629 Mdot
.71171 .40492 Mdot
.54874 .62838 Mdot
.47223 .66483 Mdot
.60578 .64476 Mdot
.49258 .66966 Mdot
.47132 .28802 Mdot
.69188 .50932 Mdot
.76317 .33685 Mdot
.56303 .6121 Mdot
.73921 .67301 Mdot
.5489 .66794 Mdot
.41682 .25077 Mdot
.48494 .65985 Mdot
.50322 .48487 Mdot
.55773 .65368 Mdot
.48652 .64514 Mdot
.54035 .39032 Mdot
.53528 .40349 Mdot
.64385 .49868 Mdot
.55191 .22163 Mdot
.16789 .51009 Mdot
.49804 .66333 Mdot
.33137 .36272 Mdot
.60422 .38658 Mdot
.35989 .53924 Mdot
.66989 .4971 Mdot
.84602 .43751 Mdot
.51759 .3893 Mdot
.41045 .35843 Mdot
.43536 .24922 Mdot
.34525 .41018 Mdot
.59065 .35509 Mdot
.58782 .5609 Mdot
.36441 .55887 Mdot
.5511 .66635 Mdot
.60256 .77782 Mdot
.66776 .33915 Mdot
.49035 .5929 Mdot
.55528 .3353 Mdot
.51948 .54572 Mdot
.5541 .80063 Mdot
.37191 .53014 Mdot
.36854 .5369 Mdot
.53673 .39135 Mdot
.37404 .41928 Mdot
.45127 .67523 Mdot
.32946 .55077 Mdot
.39805 .37241 Mdot
.55327 .21851 Mdot
.50705 .52027 Mdot
.68094 .49304 Mdot
.65966 .43704 Mdot
.63986 .38184 Mdot
.51384 .38307 Mdot
.30606 .3827 Mdot
.63706 .52192 Mdot
.72245 .51515 Mdot
.55708 .23095 Mdot
.36895 .34832 Mdot
.68475 .46071 Mdot
.47454 .60981 Mdot
.587 .59807 Mdot
.50671 .64861 Mdot
.33301 .54192 Mdot
.48602 .66735 Mdot
.38734 .35278 Mdot
.52713 .36064 Mdot
.35488 .39521 Mdot
.5452 .37943 Mdot
.60473 .29184 Mdot
.52796 .64167 Mdot
.49059 .64997 Mdot
.38849 .47563 Mdot
.65684 .48198 Mdot
.73096 .7115 Mdot
.33312 .35749 Mdot
.37013 .38511 Mdot
.50338 .59708 Mdot
.64424 .50932 Mdot
.36998 .51252 Mdot
.39144 .4678 Mdot
.49196 .67579 Mdot
.69161 .51059 Mdot
.52658 .59916 Mdot
.24095 .54026 Mdot
.70068 .39526 Mdot
.68911 .48184 Mdot
.78203 .33969 Mdot
.50582 .61243 Mdot
.42577 .59809 Mdot
.56728 .59293 Mdot
.32139 .68579 Mdot
.46852 .66327 Mdot
.68996 .52787 Mdot
.51208 .65144 Mdot
.68776 .52209 Mdot
.39158 .40468 Mdot
.51106 .3955 Mdot
.67818 .51689 Mdot
.48249 .66913 Mdot
.21638 .33758 Mdot
.51678 .3743 Mdot
.49081 .6421 Mdot
.55716 .35513 Mdot
.70029 .52717 Mdot
.65291 .48953 Mdot
.29652 .28714 Mdot
.48467 .35887 Mdot
.51605 .37832 Mdot
.53665 .60413 Mdot
.62649 .4115 Mdot
.50995 .59678 Mdot
.37636 .72115 Mdot
.5394 .58938 Mdot
.46056 .64278 Mdot
.49658 .1636 Mdot
.49609 .39337 Mdot
.83985 .51392 Mdot
.2276 .44074 Mdot
.2316 .34202 Mdot
.62865 .49118 Mdot
.37178 .5299 Mdot
.20398 .44611 Mdot
.52934 .24038 Mdot
.37293 .35408 Mdot
.53407 .66757 Mdot
.70006 .44579 Mdot
.51161 .36191 Mdot
.35583 .54123 Mdot
.54833 .62743 Mdot
.40523 .37262 Mdot
.32234 .26935 Mdot
.50462 .37909 Mdot
.67793 .49124 Mdot
.65281 .48588 Mdot
.81974 .41353 Mdot
.52892 .6296 Mdot
.49341 .64798 Mdot
.52318 .35449 Mdot
.45193 .61725 Mdot
.34358 .57291 Mdot
.27173 .52326 Mdot
.5181 .38022 Mdot
.57353 .43394 Mdot
.65298 .50941 Mdot
.51041 .67649 Mdot
.40087 .5091 Mdot
.35753 .30357 Mdot
.65379 .60182 Mdot
.33459 .55165 Mdot
.39055 .71633 Mdot
.69048 .52762 Mdot
.52616 .36908 Mdot
.33122 .60274 Mdot
.54374 .58433 Mdot
.51133 .67335 Mdot
.39516 .71762 Mdot
.44055 .45245 Mdot
.37889 .52315 Mdot
.4986 .69323 Mdot
.4351 .46067 Mdot
.50065 .59812 Mdot
.48209 .60582 Mdot
.48579 .57894 Mdot
.48176 .64681 Mdot
.68878 .5161 Mdot
.602 .67065 Mdot
.36526 .36201 Mdot
.72323 .6068 Mdot
.44522 .4949 Mdot
.52215 .61905 Mdot
.50413 .60359 Mdot
.64234 .57956 Mdot
.59801 .39904 Mdot
.68986 .50657 Mdot
.7245 .46997 Mdot
.52624 .39614 Mdot
.59498 .60917 Mdot
.35384 .4199 Mdot
.55756 .74003 Mdot
.35127 .39157 Mdot
.69224 .51133 Mdot
.37589 .38751 Mdot
.53123 .39813 Mdot
.37812 .39708 Mdot
.32831 .37606 Mdot
.5509 .34051 Mdot
.65156 .5115 Mdot
.49213 .6745 Mdot
.51685 .39146 Mdot
.41941 .72883 Mdot
.33238 .54217 Mdot
.29658 .28656 Mdot
.57038 .66335 Mdot
.45177 .71632 Mdot
.26134 .6203 Mdot
.36014 .39666 Mdot
.71517 .39075 Mdot
.67332 .52281 Mdot
.33917 .57802 Mdot
.6874 .51919 Mdot
.75248 .7005 Mdot
.36062 .55291 Mdot
.29112 .288 Mdot
.31301 .58571 Mdot
.29137 .39893 Mdot
.51759 .69293 Mdot
.74431 .48171 Mdot
.35621 .40504 Mdot
.50966 .36566 Mdot
.43756 .38434 Mdot
.48126 .63176 Mdot
.68192 .30959 Mdot
.71779 .4778 Mdot
.53664 .22202 Mdot
.53217 .36709 Mdot
.55765 .33456 Mdot
.53209 .63327 Mdot
.31611 .42767 Mdot
.5067 .59015 Mdot
.37773 .59608 Mdot
.37547 .70061 Mdot
.55714 .74136 Mdot
.54479 .60523 Mdot
.34688 .39087 Mdot
.52841 .60012 Mdot
.4592 .57038 Mdot
.60628 .80002 Mdot
.57613 .65266 Mdot
.6906 .28605 Mdot
.35285 .48291 Mdot
.65855 .511 Mdot
.52216 .57125 Mdot
.53822 .2375 Mdot
.50869 .60968 Mdot
.37719 .83872 Mdot
.34791 .55094 Mdot
.40437 .41793 Mdot
.50363 .69155 Mdot
.52002 .63024 Mdot
.63605 .75963 Mdot
.73285 .45687 Mdot
.54868 .26206 Mdot
.51459 .67015 Mdot
.37395 .67114 Mdot
.55727 .38623 Mdot
.54211 .58682 Mdot
.50843 .65409 Mdot
.49747 .79867 Mdot
.56236 .37452 Mdot
.36598 .3973 Mdot
.52878 .23398 Mdot
.33849 .39135 Mdot
.35917 .51702 Mdot
.51224 .46148 Mdot
.4711 .77357 Mdot
.6965 .39428 Mdot
.32909 .53059 Mdot
.50551 .68811 Mdot
.42558 .67061 Mdot
.50629 .62242 Mdot
.36944 .53622 Mdot
.56475 .36996 Mdot
.68547 .515 Mdot
.61138 .46149 Mdot
.54597 .23283 Mdot
.46588 .61495 Mdot
.37419 .53715 Mdot
.67682 .5092 Mdot
.34797 .28214 Mdot
.6658 .50998 Mdot
.53317 .38363 Mdot
.57295 .36872 Mdot
.35655 .5549 Mdot
.68917 .51796 Mdot
.33517 .36686 Mdot
.22961 .43715 Mdot
.53571 .58974 Mdot
.48345 .39698 Mdot
.65043 .47491 Mdot
.67395 .54131 Mdot
.69896 .46697 Mdot
.53455 .63979 Mdot
.45342 .44963 Mdot
.5223 .57851 Mdot
.53067 .39272 Mdot
.38387 .36196 Mdot
.4817 .77663 Mdot
.63956 .76707 Mdot
.56611 .43739 Mdot
.45959 .65131 Mdot
.48846 .63116 Mdot
.50329 .65115 Mdot
.55712 .62944 Mdot
.25462 .54151 Mdot
.52516 .6427 Mdot
.54313 .38615 Mdot
.34818 .3686 Mdot
.53284 .62854 Mdot
.53648 .23617 Mdot
.45813 .46688 Mdot
.32104 .555 Mdot
.48675 .48183 Mdot
.18404 .38251 Mdot
.67803 .50945 Mdot
.37878 .40548 Mdot
.36817 .35497 Mdot
.32918 .56492 Mdot
.51011 .37553 Mdot
.66825 .51333 Mdot
.30929 .66223 Mdot
.34538 .56967 Mdot
.51471 .65665 Mdot
.36425 .46781 Mdot
.75107 .29799 Mdot
.5266 .68744 Mdot
.53135 .66069 Mdot
.52958 .22665 Mdot
.36548 .42163 Mdot
.25242 .72982 Mdot
.43494 .44369 Mdot
.35777 .54908 Mdot
.3641 .53576 Mdot
.70189 .46688 Mdot
.48787 .5918 Mdot
.54491 .37351 Mdot
.41036 .46745 Mdot
.33596 .73709 Mdot
.41916 .34872 Mdot
.48474 .20448 Mdot
.54928 .65802 Mdot
.63949 .74584 Mdot
.52979 .59357 Mdot
.71767 .51862 Mdot
.71283 .48208 Mdot
.68779 .50135 Mdot
.53485 .3891 Mdot
.79469 .5655 Mdot
.54578 .3842 Mdot
.17664 .3889 Mdot
.67348 .52902 Mdot
.26522 .43992 Mdot
.37753 .38225 Mdot
.47309 .68731 Mdot
.36141 .56265 Mdot
.57985 .41912 Mdot
.48517 .57728 Mdot
.7167 .34401 Mdot
.38357 .39027 Mdot
.65002 .49688 Mdot
.50284 .55623 Mdot
.16406 .55983 Mdot
.49731 .44744 Mdot
.43201 .55939 Mdot
.71893 .72526 Mdot
.36196 .55363 Mdot
.65603 .59069 Mdot
.35208 .57311 Mdot
.52335 .35931 Mdot
.48059 .63434 Mdot
.47945 .64436 Mdot
.54211 .60065 Mdot
.52773 .64378 Mdot
.54895 .39145 Mdot
.56273 .62541 Mdot
.67522 .78941 Mdot
.53168 .24186 Mdot
.22514 .4938 Mdot
.32977 .53673 Mdot
.5508 .33719 Mdot
.34733 .3791 Mdot
.55174 .21971 Mdot
.43722 .77361 Mdot
.55684 .64538 Mdot
.53601 .6645 Mdot
.55529 .24888 Mdot
.47269 .58742 Mdot
.51429 .55643 Mdot
.36288 .3634 Mdot
.56435 .44596 Mdot
.3587 .52248 Mdot
.33365 .52933 Mdot
.55065 .34299 Mdot
.68799 .51918 Mdot
.33299 .55416 Mdot
.37966 .41847 Mdot
.5655 .63274 Mdot
.46917 .64163 Mdot
.65014 .47543 Mdot
.73108 .72723 Mdot
.37745 .53858 Mdot
.47064 .5716 Mdot
.69049 .5241 Mdot
.715 .47158 Mdot
.51598 .67187 Mdot
.55596 .69481 Mdot
.66514 .53702 Mdot
.32449 .54459 Mdot
.54929 .33654 Mdot
.28364 .40821 Mdot
.51798 .36503 Mdot
.67201 .51341 Mdot
.57026 .62602 Mdot
.65206 .51068 Mdot
.51114 .61233 Mdot
.62372 .14868 Mdot
.48218 .65321 Mdot
.79274 .46302 Mdot
.33156 .69536 Mdot
.36345 .35529 Mdot
.33437 .37122 Mdot
.53508 .24196 Mdot
.68871 .52615 Mdot
.47489 .63581 Mdot
.36678 .54357 Mdot
.24466 .32785 Mdot
.68383 .45292 Mdot
.39228 .36341 Mdot
.35691 .42011 Mdot
.56326 .38115 Mdot
.5401 .67677 Mdot
.50321 .6741 Mdot
.37598 .39797 Mdot
.26083 .60364 Mdot
.70562 .50976 Mdot
.49384 .64725 Mdot
.48993 .6276 Mdot
.35996 .36046 Mdot
.2293 .44461 Mdot
.75222 .49011 Mdot
.48247 .64336 Mdot
.30378 .57148 Mdot
.57056 .36708 Mdot
.55434 .62448 Mdot
.56207 .62609 Mdot
.35141 .53139 Mdot
.21317 .50726 Mdot
.56893 .80262 Mdot
.5602 .3445 Mdot
.54631 .22025 Mdot
.48142 .66953 Mdot
.37633 .38068 Mdot
.47315 .65723 Mdot
.21236 .60429 Mdot
.53151 .2322 Mdot
.51616 .64001 Mdot
.50032 .57715 Mdot
.68777 .47251 Mdot
.51913 .63742 Mdot
.57448 .73853 Mdot
.33852 .38006 Mdot
.5183 .63979 Mdot
.71339 .71563 Mdot
.55764 .38814 Mdot
.51028 .57331 Mdot
.35606 .52479 Mdot
.31827 .68663 Mdot
.62697 .36085 Mdot
.32914 .39679 Mdot
.32672 .54506 Mdot
.48912 .67324 Mdot
.37531 .41752 Mdot
.50891 .36387 Mdot
.69507 .32331 Mdot
.55769 .66364 Mdot
.51591 .36862 Mdot
.5276 .3619 Mdot
.35324 .55424 Mdot
.83243 .47637 Mdot
.46316 .5944 Mdot
.49135 .67016 Mdot
.43677 .80173 Mdot
.71584 .4785 Mdot
.49307 .67375 Mdot
.52582 .6846 Mdot
.54784 .36662 Mdot
.55954 .53361 Mdot
.71769 .55405 Mdot
.29534 .50488 Mdot
.56717 .35774 Mdot
.32166 .38026 Mdot
.37592 .41675 Mdot
.32937 .53852 Mdot
.65883 .50521 Mdot
.32337 .53547 Mdot
.37728 .36847 Mdot
.55093 .6465 Mdot
.54505 .35654 Mdot
.65223 .64277 Mdot
.50005 .3897 Mdot
.40833 .37132 Mdot
.69924 .53769 Mdot
.59986 .34758 Mdot
.51965 .84339 Mdot
.64328 .36808 Mdot
.53659 .32995 Mdot
.35953 .5384 Mdot
.38224 .46266 Mdot
.48952 .63007 Mdot
.69791 .57662 Mdot
.51396 .68377 Mdot
.71332 .72909 Mdot
.39525 .38289 Mdot
.558 .23349 Mdot
.48023 .63442 Mdot
.38579 .70475 Mdot
.54234 .33138 Mdot
.56187 .38521 Mdot
.53222 .65188 Mdot
.53588 .3836 Mdot
.49389 .66483 Mdot
.34968 .3623 Mdot
.82788 .49709 Mdot
.48896 .63633 Mdot
.58076 .61657 Mdot
.52041 .32989 Mdot
.29551 .28664 Mdot
.34724 .34779 Mdot
.63768 .74974 Mdot
.16882 .59202 Mdot
.53725 .38116 Mdot
.56317 .58603 Mdot
.36495 .40507 Mdot
.52969 .22563 Mdot
.37443 .34224 Mdot
.52593 .67943 Mdot
.54565 .65708 Mdot
.50624 .59525 Mdot
.49567 .62324 Mdot
.68828 .57698 Mdot
.56993 .5617 Mdot
.65209 .71796 Mdot
.53586 .66303 Mdot
.61535 .51625 Mdot
.5464 .38787 Mdot
.689 .55296 Mdot
.36611 .57852 Mdot
.55002 .65261 Mdot
.72202 .44897 Mdot
.55494 .34027 Mdot
.1772 .39451 Mdot
.56307 .37812 Mdot
.35574 .386 Mdot
.51258 .4025 Mdot
.51497 .61354 Mdot
.6717 .4887 Mdot
.34106 .37285 Mdot
.62494 .27433 Mdot
.37601 .35409 Mdot
.52676 .62693 Mdot
.23521 .47148 Mdot
.36852 .35611 Mdot
.46598 .47199 Mdot
.66679 .49156 Mdot
.37872 .66757 Mdot
.71788 .49624 Mdot
.5133 .63595 Mdot
.5089 .63323 Mdot
.54777 .21588 Mdot
.50406 .38239 Mdot
.69595 .5292 Mdot
.78278 .70845 Mdot
.34022 .51656 Mdot
.69004 .4944 Mdot
.50167 .70336 Mdot
.44892 .44594 Mdot
.69509 .47923 Mdot
.34175 .66195 Mdot
.50867 .37293 Mdot
.68929 .46222 Mdot
.5121 .7091 Mdot
.57036 .50081 Mdot
.36043 .57327 Mdot
.40262 .36595 Mdot
.5561 .47936 Mdot
.35305 .40427 Mdot
.56438 .34629 Mdot
.38955 .41695 Mdot
.55621 .38606 Mdot
.785 .48531 Mdot
.76835 .49589 Mdot
.49666 .37731 Mdot
.57348 .36322 Mdot
.37296 .3723 Mdot
.55563 .63589 Mdot
.44964 .50691 Mdot
.47554 .6803 Mdot
.53194 .68962 Mdot
.55258 .39458 Mdot
.70231 .52254 Mdot
.66169 .52999 Mdot
.74372 .50011 Mdot
.65814 .48247 Mdot
.34599 .38012 Mdot
.72155 .39856 Mdot
.76878 .67083 Mdot
.54672 .34449 Mdot
.55512 .40831 Mdot
.50822 .59814 Mdot
.3756 .37761 Mdot
.39505 .39724 Mdot
.54257 .3637 Mdot
.67625 .60492 Mdot
.56642 .5943 Mdot
.71379 .51961 Mdot
.672 .52861 Mdot
.69764 .48253 Mdot
.68353 .46698 Mdot
.77358 .56233 Mdot
.50919 .36617 Mdot
.68116 .5282 Mdot
.52543 .64826 Mdot
.54207 .66528 Mdot
.54886 .22607 Mdot
.34418 .52428 Mdot
.56047 .67345 Mdot
.57823 .64134 Mdot
.51612 .67323 Mdot
.37317 .35838 Mdot
.53569 .71774 Mdot
.53555 .22732 Mdot
.37911 .42359 Mdot
.33913 .41032 Mdot
.55618 .23881 Mdot
.62512 .55467 Mdot
.15798 .56548 Mdot
.52593 .59701 Mdot
.41336 .58676 Mdot
.37108 .38023 Mdot
.76765 .40353 Mdot
.6093 .50477 Mdot
.54677 .60811 Mdot
.52966 .50968 Mdot
.34454 .36558 Mdot
.72067 .48288 Mdot
.50479 .68066 Mdot
.54493 .25512 Mdot
.32236 .55926 Mdot
.49678 .70282 Mdot
.52842 .22963 Mdot
.69409 .5118 Mdot
.39776 .56057 Mdot
.69967 .46352 Mdot
.35119 .35518 Mdot
.50647 .57351 Mdot
.21379 .26187 Mdot
.36195 .41026 Mdot
.24843 .3475 Mdot
.76419 .49856 Mdot
.48697 .63754 Mdot
.35667 .40861 Mdot
.72374 .49296 Mdot
.57034 .37173 Mdot
.42845 .46932 Mdot
.66595 .52274 Mdot
.55398 .22236 Mdot
.55259 .23156 Mdot
.36297 .36138 Mdot
.65755 .49295 Mdot
.55366 .59697 Mdot
.70324 .47623 Mdot
.50996 .40185 Mdot
.54239 .61674 Mdot
.16496 .51747 Mdot
.58562 .59168 Mdot
.69587 .52263 Mdot
.40486 .38856 Mdot
.36877 .56244 Mdot
.54842 .63073 Mdot
.22437 .38751 Mdot
.532 .68221 Mdot
.56096 .36125 Mdot
.76223 .36539 Mdot
.64184 .64768 Mdot
.55197 .64332 Mdot
.50498 .60079 Mdot
.5466 .33966 Mdot
.55495 .63977 Mdot
.52919 .6856 Mdot
.50829 .32994 Mdot
.68441 .47415 Mdot
.50574 .64596 Mdot
.40054 .38161 Mdot
.63034 .78138 Mdot
.48082 .66974 Mdot
.67198 .26735 Mdot
.3827 .6836 Mdot
.77098 .3836 Mdot
.47657 .65893 Mdot
.4277 .73975 Mdot
.50327 .63397 Mdot
.54131 .64001 Mdot
.53501 .59979 Mdot
.62962 .74163 Mdot
.37661 .37234 Mdot
.39153 .35859 Mdot
.3577 .57546 Mdot
.37997 .68298 Mdot
.34053 .53222 Mdot
.55909 .34846 Mdot
.42424 .20575 Mdot
.53158 .2381 Mdot
.68748 .52033 Mdot
.48852 .60622 Mdot
.3524 .35244 Mdot
.51451 .67827 Mdot
.51408 .60972 Mdot
.34923 .35949 Mdot
.36734 .41422 Mdot
.39634 .41752 Mdot
.35254 .57176 Mdot
.68468 .50928 Mdot
.5572 .61127 Mdot
.33885 .5663 Mdot
.55312 .59452 Mdot
.43717 .44743 Mdot
.68692 .50778 Mdot
.70143 .47499 Mdot
.69102 .53445 Mdot
.55159 .64844 Mdot
.52026 .61567 Mdot
.54681 .38279 Mdot
.64767 .47661 Mdot
.53801 .34308 Mdot
.35195 .40116 Mdot
.33933 .36326 Mdot
.52709 .67884 Mdot
.47744 .5657 Mdot
.36356 .53692 Mdot
.35782 .39067 Mdot
.55364 .2529 Mdot
.35136 .57689 Mdot
.53659 .6321 Mdot
.34888 .39389 Mdot
.33579 .52672 Mdot
.69599 .61788 Mdot
.19321 .62847 Mdot
.37215 .55758 Mdot
.53005 .65191 Mdot
.64155 .75995 Mdot
.36515 .61118 Mdot
.32951 .52272 Mdot
.54744 .34762 Mdot
.53564 .67895 Mdot
.28067 .68462 Mdot
.33835 .52103 Mdot
.71583 .73664 Mdot
.35977 .35692 Mdot
.53964 .53196 Mdot
.51908 .70959 Mdot
.72069 .5764 Mdot
.32547 .53051 Mdot
.6692 .50844 Mdot
.6443 .4767 Mdot
.52199 .655 Mdot
.33048 .58594 Mdot
.54178 .40648 Mdot
.36078 .35382 Mdot
.33193 .36383 Mdot
.66259 .48669 Mdot
.65185 .41176 Mdot
.40263 .38416 Mdot
.44206 .63483 Mdot
.3568 .44661 Mdot
.59207 .64864 Mdot
.79466 .50502 Mdot
.61475 .27632 Mdot
.46883 .63409 Mdot
.37211 .55151 Mdot
.52788 .34184 Mdot
.54291 .38405 Mdot
.5279 .38458 Mdot
.33352 .38203 Mdot
.4944 .46743 Mdot
.38524 .39177 Mdot
.67839 .31709 Mdot
.34835 .56026 Mdot
.3688 .64611 Mdot
.47593 .63984 Mdot
.48879 .6335 Mdot
.5601 .60018 Mdot
.49912 .59639 Mdot
.50188 .63528 Mdot
.51362 .38022 Mdot
.33707 .39861 Mdot
.31609 .46705 Mdot
.69998 .49034 Mdot
.37413 .25871 Mdot
.3777 .38256 Mdot
.52973 .22918 Mdot
.34839 .54204 Mdot
.45242 .75072 Mdot
.34054 .42631 Mdot
.37478 .38733 Mdot
.56522 .64642 Mdot
.71456 .50037 Mdot
.60281 .57226 Mdot
.50312 .62915 Mdot
.35869 .39293 Mdot
.39567 .33842 Mdot
.6403 .60321 Mdot
.47787 .71552 Mdot
.35816 .50589 Mdot
.45295 .44548 Mdot
.31639 .5543 Mdot
.56014 .6876 Mdot
.76581 .40067 Mdot
.3756 .36828 Mdot
.35458 .37759 Mdot
.37212 .53483 Mdot
.42636 .60427 Mdot
.65808 .4968 Mdot
.55835 .235 Mdot
.55664 .35805 Mdot
.50663 .62547 Mdot
.33566 .38425 Mdot
.43836 .5716 Mdot
.3504 .45584 Mdot
.52022 .38053 Mdot
.37766 .42417 Mdot
.54912 .6665 Mdot
.53187 .65417 Mdot
.36245 .55017 Mdot
.4154 .53996 Mdot
.49111 .69811 Mdot
.23094 .34282 Mdot
.70685 .40515 Mdot
.70892 .42124 Mdot
.51086 .67336 Mdot
.66619 .48174 Mdot
.54726 .25264 Mdot
.3523 .56665 Mdot
.56501 .61787 Mdot
.17788 .61177 Mdot
.64033 .51912 Mdot
.52154 .36942 Mdot
.55018 .25113 Mdot
.49224 .46778 Mdot
.52841 .68411 Mdot
.51321 .68369 Mdot
.53131 .64177 Mdot
.18805 .63793 Mdot
.39721 .36786 Mdot
.69325 .46672 Mdot
.33438 .5491 Mdot
.67607 .47057 Mdot
.3863 .3562 Mdot
.6113 .45032 Mdot
.53569 .62803 Mdot
.7111 .52499 Mdot
.66766 .50641 Mdot
.56362 .38077 Mdot
.56496 .38675 Mdot
.38433 .42801 Mdot
.48285 .6533 Mdot
.54012 .25572 Mdot
.71644 .48875 Mdot
.35698 .41595 Mdot
.36094 .55363 Mdot
.52284 .39418 Mdot
.53713 .66131 Mdot
.36965 .36451 Mdot
.47616 .6041 Mdot
.70452 .48223 Mdot
.3748 .3865 Mdot
.52964 .25109 Mdot
.35946 .53038 Mdot
.54269 .65845 Mdot
.38717 .53052 Mdot
.55604 .24427 Mdot
.48968 .62346 Mdot
.51744 .76609 Mdot
.36511 .58435 Mdot
.62653 .27104 Mdot
.38296 .3996 Mdot
.53998 .23023 Mdot
.70873 .47688 Mdot
.58686 .50835 Mdot
.35216 .37627 Mdot
.51205 .75311 Mdot
.43767 .52373 Mdot
.55755 .61382 Mdot
.68379 .48579 Mdot
.31333 .50867 Mdot
.19695 .3809 Mdot
.32723 .60632 Mdot
.49703 .64665 Mdot
.35511 .40757 Mdot
.32928 .5337 Mdot
.55111 .34623 Mdot
.67475 .26912 Mdot
.78463 .51784 Mdot
.37942 .42531 Mdot
.52696 .59575 Mdot
.71634 .48956 Mdot
.54065 .36295 Mdot
.59804 .30003 Mdot
.38476 .41585 Mdot
.39396 .38862 Mdot
.54205 .63344 Mdot
.3363 .5588 Mdot
.26099 .58436 Mdot
.39245 .35775 Mdot
.33848 .3938 Mdot
.36453 .26151 Mdot
.3767 .5447 Mdot
.52133 .64968 Mdot
.74391 .49936 Mdot
.56151 .64842 Mdot
.24784 .33651 Mdot
.5357 .23061 Mdot
.70162 .49217 Mdot
.539 .67152 Mdot
.34355 .47606 Mdot
.34981 .38436 Mdot
.4622 .44436 Mdot
.40962 .38402 Mdot
.51142 .3785 Mdot
.33543 .38109 Mdot
.50558 .67929 Mdot
.54483 .33089 Mdot
.36142 .53432 Mdot
.48225 .6445 Mdot
.52093 .61477 Mdot
.72431 .5026 Mdot
.52592 .3563 Mdot
.554 .79098 Mdot
.57507 .3764 Mdot
.5393 .33856 Mdot
.688 .45767 Mdot
.51845 .65588 Mdot
.3608 .38754 Mdot
.40308 .36256 Mdot
.5603 .60952 Mdot
.76875 .41163 Mdot
.66113 .49111 Mdot
.37013 .43514 Mdot
.2503 .72463 Mdot
.44971 .6775 Mdot
.53959 .25842 Mdot
.41963 .66144 Mdot
.56524 .3822 Mdot
.53603 .65643 Mdot
.6974 .51945 Mdot
.34345 .40333 Mdot
.40242 .38339 Mdot
.56688 .61608 Mdot
.53354 .35886 Mdot
.32137 .54638 Mdot
.39232 .39635 Mdot
.3421 .44733 Mdot
.52427 .63767 Mdot
.68118 .30643 Mdot
.38613 .40232 Mdot
.26832 .28132 Mdot
.32881 .46874 Mdot
.6899 .48363 Mdot
.51621 .60765 Mdot
.64647 .49392 Mdot
.33553 .54369 Mdot
.32565 .35751 Mdot
.52963 .35893 Mdot
.45495 .70261 Mdot
.58556 .81815 Mdot
.37938 .37524 Mdot
.68935 .5148 Mdot
.55295 .64564 Mdot
.4427 .67581 Mdot
.48668 .66623 Mdot
.56837 .53556 Mdot
.38276 .5711 Mdot
.55186 .39648 Mdot
.5614 .35865 Mdot
.49787 .60587 Mdot
.34385 .57177 Mdot
.38078 .34787 Mdot
.35675 .35752 Mdot
.81131 .31583 Mdot
.5289 .25039 Mdot
.36083 .71327 Mdot
.54501 .65491 Mdot
.35248 .41526 Mdot
.63398 .76993 Mdot
.52319 .35434 Mdot
.51339 .58752 Mdot
.33292 .39861 Mdot
.36977 .30258 Mdot
.43747 .44992 Mdot
.50971 .64114 Mdot
.44794 .62935 Mdot
.55791 .35732 Mdot
.40242 .46338 Mdot
.38295 .39329 Mdot
.53095 .58575 Mdot
.57574 .36877 Mdot
.3391 .27323 Mdot
.64786 .80448 Mdot
.68486 .50873 Mdot
.40978 .37346 Mdot
.51213 .3784 Mdot
.46933 .68755 Mdot
.32951 .53665 Mdot
.34209 .39142 Mdot
.37703 .35686 Mdot
.53578 .61158 Mdot
.55172 .68299 Mdot
.44947 .67839 Mdot
.6958 .50091 Mdot
.55278 .37653 Mdot
.48094 .62512 Mdot
.66043 .41081 Mdot
.50716 .59409 Mdot
.55092 .37485 Mdot
.40415 .11908 Mdot
.55916 .66285 Mdot
.48829 .66625 Mdot
.27379 .5884 Mdot
.6573 .52063 Mdot
.66946 .47425 Mdot
.71568 .40297 Mdot
.54483 .65523 Mdot
.30024 .41225 Mdot
.68248 .51165 Mdot
.66473 .48833 Mdot
.2579 .45113 Mdot
.54531 .61579 Mdot
.41408 .44995 Mdot
.54575 .37173 Mdot
.51216 .38521 Mdot
.69377 .47408 Mdot
.47735 .69271 Mdot
.52131 .34924 Mdot
.72567 .55875 Mdot
.38141 .38252 Mdot
.76556 .39946 Mdot
.71168 .49402 Mdot
.41006 .52491 Mdot
.51466 .36623 Mdot
.17581 .37725 Mdot
.54774 .49916 Mdot
.52165 .59124 Mdot
.54101 .65116 Mdot
.3517 .52991 Mdot
.5211 .56286 Mdot
.54438 .21969 Mdot
.5349 .38467 Mdot
.21936 .54903 Mdot
.68785 .50024 Mdot
.48592 .65834 Mdot
.46088 .75568 Mdot
.6167 .31404 Mdot
.69906 .29214 Mdot
.65958 .5114 Mdot
.68316 .49002 Mdot
.38966 .38233 Mdot
.38629 .36915 Mdot
.5139 .64796 Mdot
.5385 .38921 Mdot
.6649 .46484 Mdot
.55563 .36611 Mdot
.37637 .36758 Mdot
.36994 .38665 Mdot
.53183 .2301 Mdot
.46367 .60798 Mdot
.35285 .35622 Mdot
.32503 .28319 Mdot
.64954 .4158 Mdot
.72659 .50006 Mdot
.50833 .83805 Mdot
.59414 .29728 Mdot
.27699 .63079 Mdot
.32693 .56898 Mdot
.53947 .26993 Mdot
.52633 .40319 Mdot
.50192 .60354 Mdot
.52878 .67253 Mdot
.54875 .23863 Mdot
.50614 .38859 Mdot
.35181 .53837 Mdot
.50387 .38331 Mdot
.34484 .56301 Mdot
.35061 .34864 Mdot
.48082 .66944 Mdot
.51347 .68745 Mdot
.51667 .38255 Mdot
.36929 .39721 Mdot
.3567 .35464 Mdot
.34047 .57477 Mdot
.43568 .72986 Mdot
.36482 .36134 Mdot
.71136 .49171 Mdot
.76653 .63294 Mdot
.55223 .23291 Mdot
.50108 .67882 Mdot
.46607 .76515 Mdot
.66413 .59407 Mdot
.54989 .60308 Mdot
.55177 .24988 Mdot
.82684 .35283 Mdot
.47783 .64611 Mdot
.82411 .38139 Mdot
.54175 .22706 Mdot
.65377 .51887 Mdot
.36936 .40803 Mdot
.54537 .21867 Mdot
.48537 .70249 Mdot
.33355 .51523 Mdot
.56689 .66773 Mdot
.66309 .52164 Mdot
.69345 .53643 Mdot
.76745 .45123 Mdot
.24861 .33744 Mdot
.36248 .56591 Mdot
.35461 .54598 Mdot
.35252 .37255 Mdot
.47397 .17082 Mdot
.52179 .70717 Mdot
.35677 .54459 Mdot
.23518 .57548 Mdot
.51135 .59802 Mdot
.38388 .7276 Mdot
.5273 .50803 Mdot
.66568 .48278 Mdot
.65324 .55804 Mdot
.3501 .37843 Mdot
.68893 .51441 Mdot
.64608 .42845 Mdot
.56135 .60245 Mdot
.68784 .50519 Mdot
.55078 .3706 Mdot
.46849 .32196 Mdot
.64877 .49422 Mdot
.41119 .47537 Mdot
.54412 .37332 Mdot
.3665 .58619 Mdot
.29913 .6138 Mdot
.37802 .84876 Mdot
.53526 .38599 Mdot
.3612 .40189 Mdot
.35042 .35633 Mdot
.35532 .36065 Mdot
.66605 .52332 Mdot
.38867 .40847 Mdot
.70073 .5008 Mdot
.23416 .40511 Mdot
.44137 .7507 Mdot
.35578 .55701 Mdot
.48167 .36927 Mdot
.67298 .49739 Mdot
.69629 .35853 Mdot
.52977 .8373 Mdot
.5319 .65048 Mdot
.57566 .37241 Mdot
.37087 .53371 Mdot
.4142 .1704 Mdot
.35012 .53102 Mdot
.36607 .40525 Mdot
.76478 .39622 Mdot
.49359 .66262 Mdot
.56453 .74596 Mdot
.36645 .5374 Mdot
.66135 .51615 Mdot
.48889 .62651 Mdot
.41418 .38754 Mdot
.32908 .54178 Mdot
.32214 .55646 Mdot
.49824 .63719 Mdot
.65291 .4929 Mdot
.36593 .38844 Mdot
.529 .4017 Mdot
.38281 .54537 Mdot
.4556 .65733 Mdot
.55797 .62818 Mdot
.51294 .58236 Mdot
.48557 .45111 Mdot
.25806 .63697 Mdot
.5381 .37966 Mdot
.39423 .62555 Mdot
.37951 .36425 Mdot
.31004 .58924 Mdot
.67302 .37298 Mdot
.4887 .35553 Mdot
.53645 .22959 Mdot
.53369 .23292 Mdot
.50622 .6395 Mdot
.25272 .62843 Mdot
.7508 .32274 Mdot
.54801 .3217 Mdot
.5529 .23929 Mdot
.35849 .3546 Mdot
.63926 .49238 Mdot
.759 .45101 Mdot
.54076 .69007 Mdot
.55786 .39307 Mdot
.36899 .36114 Mdot
.21358 .60889 Mdot
.34643 .55773 Mdot
.73432 .39022 Mdot
.53052 .62664 Mdot
.49148 .65031 Mdot
.53502 .37012 Mdot
.54615 .38276 Mdot
.6721 .28088 Mdot
.73375 .4214 Mdot
.40484 .33503 Mdot
.52458 .30885 Mdot
.22576 .63492 Mdot
.70337 .54753 Mdot
.69953 .51963 Mdot
.52869 .23864 Mdot
.53499 .33655 Mdot
.50653 .68308 Mdot
.65588 .52358 Mdot
.70289 .29424 Mdot
.63845 .47461 Mdot
.38181 .71756 Mdot
.31156 .42696 Mdot
.51543 .62046 Mdot
.71519 .49394 Mdot
.68848 .5124 Mdot
.67195 .46915 Mdot
.55544 .2411 Mdot
.51238 .67091 Mdot
.5552 .63634 Mdot
.48235 .62995 Mdot
.47765 .57486 Mdot
.52094 .63712 Mdot
.66644 .3815 Mdot
.56901 .43509 Mdot
.2142 .52931 Mdot
.54453 .59893 Mdot
.50722 .37761 Mdot
.48625 .60654 Mdot
.33878 .57069 Mdot
.52726 .59525 Mdot
.37169 .72011 Mdot
.52589 .37801 Mdot
.42537 .61321 Mdot
.53568 .30396 Mdot
.53018 .62552 Mdot
.33068 .52903 Mdot
.25696 .62495 Mdot
.54505 .80323 Mdot
.35933 .26708 Mdot
.71072 .48928 Mdot
.35003 .42864 Mdot
.50748 .40127 Mdot
.36015 .3854 Mdot
.52848 .58938 Mdot
.53401 .2529 Mdot
.56833 .26342 Mdot
.41369 .51599 Mdot
.52161 .68375 Mdot
.59021 .62331 Mdot
.68247 .47803 Mdot
.35239 .39737 Mdot
.65059 .54467 Mdot
.53781 .64076 Mdot
.33251 .54782 Mdot
.33179 .55683 Mdot
.71003 .41627 Mdot
.18694 .54248 Mdot
.59276 .52334 Mdot
.53641 .37207 Mdot
.40526 .3793 Mdot
.32746 .52857 Mdot
.77402 .50409 Mdot
.54535 .40605 Mdot
.56487 .38285 Mdot
.53311 .3532 Mdot
.50918 .62118 Mdot
.53847 .22343 Mdot
.21726 .56881 Mdot
.55191 .22054 Mdot
.52736 .62234 Mdot
.38575 .36157 Mdot
.54344 .21783 Mdot
.34591 .5291 Mdot
.55317 .3451 Mdot
.38401 .37088 Mdot
.51269 .63386 Mdot
.67992 .50754 Mdot
.43106 .71028 Mdot
.3299 .71782 Mdot
.22097 .44329 Mdot
.21991 .45288 Mdot
.68384 .53314 Mdot
.17327 .44196 Mdot
.4836 .39689 Mdot
.67579 .60303 Mdot
.33653 .50499 Mdot
.55823 .60525 Mdot
.82915 .54657 Mdot
.38126 .39591 Mdot
.34339 .37483 Mdot
.51336 .64218 Mdot
.36068 .41487 Mdot
.48587 .66092 Mdot
.3934 .37794 Mdot
.31588 .31236 Mdot
.52435 .69499 Mdot
.34449 .37547 Mdot
.53635 .70558 Mdot
.54511 .6274 Mdot
.67505 .47745 Mdot
.34291 .39639 Mdot
.51351 .59084 Mdot
.48279 .15786 Mdot
.53833 .39375 Mdot
.5557 .23766 Mdot
.51334 .43271 Mdot
.5092 .37051 Mdot
.69249 .49122 Mdot
.50692 .69499 Mdot
.36419 .54503 Mdot
.67199 .50751 Mdot
.38678 .42642 Mdot
.36815 .538 Mdot
.71761 .39799 Mdot
.70739 .48331 Mdot
.55001 .23161 Mdot
.3651 .53836 Mdot
.58057 .60241 Mdot
.33933 .36989 Mdot
.3471 .74743 Mdot
.5533 .22324 Mdot
.50263 .67438 Mdot
.35076 .34425 Mdot
.50515 .3772 Mdot
.50616 .6532 Mdot
.35696 .40971 Mdot
.55513 .24405 Mdot
.50584 .61531 Mdot
.49399 .61937 Mdot
.74376 .44572 Mdot
.73356 .33167 Mdot
.36167 .549 Mdot
.72017 .48977 Mdot
.52441 .64739 Mdot
.34822 .573 Mdot
.46068 .22394 Mdot
.47462 .61793 Mdot
.64491 .50382 Mdot
.55832 .7362 Mdot
.3864 .36739 Mdot
.54007 .34243 Mdot
.40806 .36769 Mdot
.32227 .56054 Mdot
.81339 .67822 Mdot
.53457 .22352 Mdot
.51798 .71404 Mdot
.54496 .58763 Mdot
.38241 .33468 Mdot
.69083 .50847 Mdot
.44275 .37174 Mdot
.54277 .65764 Mdot
.5894 .5954 Mdot
.48852 .65344 Mdot
.32583 .46559 Mdot
.66024 .49333 Mdot
.49215 .67026 Mdot
.51625 .55215 Mdot
.48179 .67422 Mdot
.32561 .53608 Mdot
.34605 .63247 Mdot
.48334 .60662 Mdot
.16196 .32438 Mdot
.55392 .25082 Mdot
.34965 .35992 Mdot
.31382 .3598 Mdot
.50953 .23277 Mdot
.79661 .50384 Mdot
.69848 .5013 Mdot
.58114 .69005 Mdot
.36314 .38726 Mdot
.6519 .79266 Mdot
.18609 .40736 Mdot
.54173 .62564 Mdot
.54776 .66672 Mdot
.36602 .40526 Mdot
.35208 .41427 Mdot
.53258 .24791 Mdot
.53817 .59523 Mdot
.57182 .6798 Mdot
.38792 .41573 Mdot
.51925 .63012 Mdot
.60878 .66464 Mdot
.53946 .40016 Mdot
.68189 .47211 Mdot
.55049 .34569 Mdot
.5569 .39123 Mdot
.75297 .60204 Mdot
.70824 .40565 Mdot
.5504 .3777 Mdot
.57747 .37481 Mdot
.37509 .72829 Mdot
.53539 .7419 Mdot
.32121 .54008 Mdot
.19436 .47135 Mdot
.35558 .36495 Mdot
.51386 .6696 Mdot
.68915 .52985 Mdot
.72993 .58123 Mdot
.43799 .29947 Mdot
.75599 .38017 Mdot
.54589 .64613 Mdot
.34878 .37373 Mdot
.55696 .23547 Mdot
.52768 .69519 Mdot
.31587 .59417 Mdot
.49375 .64888 Mdot
.34978 .35476 Mdot
.78294 .60036 Mdot
.55923 .743 Mdot
.38401 .45888 Mdot
.72031 .46914 Mdot
.47786 .63043 Mdot
.70838 .49548 Mdot
.51378 .37082 Mdot
.34863 .57177 Mdot
.36031 .54258 Mdot
.49063 .62762 Mdot
.76898 .49496 Mdot
.52026 .51314 Mdot
.54586 .62954 Mdot
.53943 .61306 Mdot
.54044 .22868 Mdot
.54029 .61399 Mdot
.54648 .58908 Mdot
.48884 .61033 Mdot
.46331 .63229 Mdot
.5387 .3382 Mdot
.52913 .76608 Mdot
.47184 .61266 Mdot
.47331 .70795 Mdot
.53801 .398 Mdot
.56811 .69946 Mdot
.5618 .38085 Mdot
.16815 .52274 Mdot
.56057 .37216 Mdot
.35993 .54697 Mdot
.34243 .34799 Mdot
.59818 .61613 Mdot
.67156 .46274 Mdot
.57191 .3701 Mdot
.34146 .54952 Mdot
.53144 .38522 Mdot
.40024 .37209 Mdot
.45727 .82129 Mdot
.6378 .47565 Mdot
.42036 .45678 Mdot
.55915 .51316 Mdot
.68052 .30361 Mdot
.38573 .38053 Mdot
.6667 .48414 Mdot
.57375 .73675 Mdot
.49019 .61096 Mdot
.35784 .53061 Mdot
.50417 .63984 Mdot
.54267 .33894 Mdot
.35096 .36788 Mdot
.22918 .47257 Mdot
.36231 .54424 Mdot
.63868 .81794 Mdot
.36769 .35202 Mdot
.55408 .67138 Mdot
.55966 .39246 Mdot
.51262 .83718 Mdot
.56132 .3697 Mdot
.44814 .75589 Mdot
.68529 .54444 Mdot
.79554 .60758 Mdot
.67783 .48975 Mdot
.70128 .28085 Mdot
.14476 .58878 Mdot
.20882 .39159 Mdot
.67459 .51566 Mdot
.3779 .44742 Mdot
.52815 .6293 Mdot
.49012 .59941 Mdot
.4432 .66073 Mdot
.72325 .48575 Mdot
.52491 .64448 Mdot
.5481 .22247 Mdot
.6211 .4257 Mdot
.26785 .53676 Mdot
.34719 .42915 Mdot
.48907 .6705 Mdot
.5422 .39661 Mdot
.501 .37748 Mdot
.54668 .21796 Mdot
.53547 .40648 Mdot
.54907 .62668 Mdot
.67406 .49474 Mdot
.43349 .51491 Mdot
.33808 .53748 Mdot
.33866 .22646 Mdot
.37943 .56134 Mdot
.35699 .43422 Mdot
.5019 .57633 Mdot
.37089 .38683 Mdot
.86715 .54317 Mdot
.49986 .60067 Mdot
.68272 .51436 Mdot
.49773 .61941 Mdot
.48289 .61765 Mdot
.49348 .59588 Mdot
.39142 .40797 Mdot
.32753 .341 Mdot
.51597 .62968 Mdot
.52899 .35848 Mdot
.21885 .4917 Mdot
.5718 .65763 Mdot
.39604 .42828 Mdot
.37281 .68812 Mdot
.68282 .32198 Mdot
.72769 .49388 Mdot
.35684 .39947 Mdot
.68651 .49618 Mdot
.70703 .46134 Mdot
.69265 .49129 Mdot
.20501 .54907 Mdot
.58289 .55134 Mdot
.80727 .33338 Mdot
.74837 .68275 Mdot
.70947 .59658 Mdot
.70777 .52634 Mdot
.46898 .25674 Mdot
.69201 .52241 Mdot
.697 .49678 Mdot
.5709 .12472 Mdot
.68386 .52653 Mdot
.52722 .67804 Mdot
.56317 .65785 Mdot
.63636 .35915 Mdot
.39534 .74596 Mdot
.53329 .59628 Mdot
.52006 .64601 Mdot
.35583 .5691 Mdot
.45501 .57766 Mdot
.53262 .21576 Mdot
.7507 .40509 Mdot
.55276 .2831 Mdot
.49932 .63683 Mdot
.51888 .64269 Mdot
.46327 .66906 Mdot
.14588 .60656 Mdot
.74477 .56718 Mdot
.68325 .53687 Mdot
.59163 .63106 Mdot
.27199 .2961 Mdot
.55348 .66798 Mdot
.5091 .68825 Mdot
.51118 .61264 Mdot
.36167 .3876 Mdot
.63736 .50041 Mdot
.58917 .6172 Mdot
.66302 .31936 Mdot
.53544 .63038 Mdot
.48405 .38876 Mdot
.38505 .55064 Mdot
.50931 .68037 Mdot
.67094 .47125 Mdot
.52374 .59825 Mdot
.7136 .49561 Mdot
.68899 .4732 Mdot
.45446 .63308 Mdot
.20839 .56371 Mdot
.64887 .48419 Mdot
.5223 .61852 Mdot
.3648 .39702 Mdot
.2019 .3788 Mdot
.50573 .67647 Mdot
.34734 .56728 Mdot
.5424 .65315 Mdot
.32763 .53432 Mdot
.53292 .61697 Mdot
.55387 .22267 Mdot
.63401 .65484 Mdot
.35464 .37557 Mdot
.34483 .4947 Mdot
.36611 .41905 Mdot
.71577 .43526 Mdot
.65026 .51669 Mdot
.52848 .21887 Mdot
.81363 .44235 Mdot
.54177 .22889 Mdot
.43148 .70913 Mdot
.4199 .26743 Mdot
.52902 .39235 Mdot
.6891 .46765 Mdot
.4027 .61778 Mdot
.38762 .43558 Mdot
.38615 .42456 Mdot
.34362 .41448 Mdot
.83409 .62374 Mdot
.82858 .48956 Mdot
.50946 .62789 Mdot
.34933 .76558 Mdot
.65767 .70538 Mdot
.4699 .65235 Mdot
.49299 .69256 Mdot
.3482 .35448 Mdot
.47657 .64007 Mdot
.4775 .46711 Mdot
.37374 .37282 Mdot
.34707 .54731 Mdot
.70284 .49371 Mdot
.32557 .54086 Mdot
.42503 .37467 Mdot
.57837 .43656 Mdot
.37949 .36657 Mdot
.46745 .62704 Mdot
.49923 .62579 Mdot
.70931 .48057 Mdot
.69638 .44391 Mdot
.6812 .47345 Mdot
.37023 .5365 Mdot
.36511 .37054 Mdot
.73133 .5694 Mdot
.53266 .65942 Mdot
.6664 .50498 Mdot
.58623 .39689 Mdot
.53266 .65431 Mdot
.51545 .37935 Mdot
.54989 .64265 Mdot
.67148 .51899 Mdot
.54011 .61444 Mdot
.6763 .49357 Mdot
.3774 .39604 Mdot
.5538 .66446 Mdot
.5149 .6445 Mdot
.5761 .80304 Mdot
.35068 .53766 Mdot
.65136 .5178 Mdot
.52296 .47987 Mdot
.56006 .65445 Mdot
.31041 .5849 Mdot
.47861 .66224 Mdot
.56651 .71625 Mdot
.53966 .70518 Mdot
.54823 .22396 Mdot
.49339 .5909 Mdot
.5031 .6755 Mdot
.54204 .76314 Mdot
.67803 .74061 Mdot
.63642 .53685 Mdot
.56043 .34538 Mdot
.67205 .47122 Mdot
.338 .36571 Mdot
.33805 .39799 Mdot
.38972 .40319 Mdot
.41919 .75634 Mdot
.47126 .6859 Mdot
.4948 .66399 Mdot
.5699 .38001 Mdot
.35417 .549 Mdot
.66211 .51232 Mdot
.35319 .55461 Mdot
.75429 .40873 Mdot
.36692 .53267 Mdot
.54236 .21986 Mdot
.32954 .46939 Mdot
.65937 .58099 Mdot
.36012 .5655 Mdot
.68077 .47311 Mdot
.33274 .44838 Mdot
.55211 .59859 Mdot
.33405 .29283 Mdot
.33244 .5493 Mdot
.79673 .69204 Mdot
.48172 .66743 Mdot
.44449 .46308 Mdot
.55173 .39033 Mdot
.33637 .52859 Mdot
.52261 .35827 Mdot
.50952 .59594 Mdot
.62879 .26908 Mdot
.68799 .51772 Mdot
.54899 .33266 Mdot
.49206 .59282 Mdot
.32795 .53731 Mdot
.369 .35826 Mdot
.58248 .48796 Mdot
.5095 .38085 Mdot
.51894 .79348 Mdot
.32687 .60606 Mdot
.36702 .3713 Mdot
.75808 .30797 Mdot
.54254 .34979 Mdot
.46765 .63744 Mdot
.60612 .6027 Mdot
.54499 .60493 Mdot
.33306 .37424 Mdot
.34967 .3942 Mdot
.62689 .40057 Mdot
.49903 .62103 Mdot
.48075 .66591 Mdot
.63758 .52018 Mdot
.37808 .37754 Mdot
.67931 .48271 Mdot
.68407 .46493 Mdot
.3649 .40258 Mdot
.68804 .48311 Mdot
.36471 .53456 Mdot
.60858 .42986 Mdot
.54484 .35046 Mdot
.52525 .36362 Mdot
.35756 .35572 Mdot
.39457 .35778 Mdot
.37305 .3858 Mdot
.54945 .64194 Mdot
.65546 .5053 Mdot
.52093 .60592 Mdot
.48083 .6082 Mdot
.70248 .54138 Mdot
.66784 .5288 Mdot
.51495 .60162 Mdot
.36183 .47622 Mdot
.37744 .52654 Mdot
.34523 .37697 Mdot
.55542 .36902 Mdot
.6563 .78661 Mdot
.56439 .38914 Mdot
.48488 .66734 Mdot
.36072 .30026 Mdot
.66228 .519 Mdot
.34993 .53025 Mdot
.33766 .59073 Mdot
.3577 .53287 Mdot
.53926 .32753 Mdot
.67026 .46609 Mdot
.71432 .39801 Mdot
.48423 .66298 Mdot
.4879 .4525 Mdot
.39866 .62594 Mdot
.67444 .36311 Mdot
.55169 .3739 Mdot
.52716 .65035 Mdot
.54362 .22889 Mdot
.64184 .59894 Mdot
.49565 .65163 Mdot
.51615 .58799 Mdot
.28976 .43886 Mdot
.46961 .70584 Mdot
.72433 .50743 Mdot
.76373 .44626 Mdot
.5644 .63316 Mdot
.71992 .54398 Mdot
.71322 .20707 Mdot
.47941 .65718 Mdot
.53089 .63887 Mdot
.5216 .67292 Mdot
.5048 .60337 Mdot
.70285 .53884 Mdot
.39743 .52402 Mdot
.56289 .3887 Mdot
.51737 .44903 Mdot
.54463 .35446 Mdot
.33947 .37552 Mdot
.44731 .46637 Mdot
.68724 .4688 Mdot
.35501 .5306 Mdot
.42402 .80421 Mdot
.76602 .42889 Mdot
.38906 .38271 Mdot
.76408 .56489 Mdot
.33438 .54112 Mdot
.55881 .607 Mdot
.36747 .57137 Mdot
.34899 .41335 Mdot
.53995 .36095 Mdot
.56342 .65408 Mdot
.6986 .52704 Mdot
.64836 .49414 Mdot
.53022 .64893 Mdot
.24519 .32899 Mdot
.51179 .36804 Mdot
.56515 .42468 Mdot
.51114 .62073 Mdot
.51769 .58779 Mdot
.69494 .4798 Mdot
.35005 .38895 Mdot
.41986 .23488 Mdot
.34534 .54211 Mdot
.46034 .6461 Mdot
.51504 .59622 Mdot
.75011 .41376 Mdot
.55562 .34576 Mdot
.54171 .25245 Mdot
.50656 .61999 Mdot
.71438 .40752 Mdot
.50576 .6186 Mdot
.53223 .56141 Mdot
.36943 .39186 Mdot
.56976 .61701 Mdot
.55052 .65826 Mdot
.41458 .6117 Mdot
.53613 .34854 Mdot
.68676 .51012 Mdot
.65228 .53704 Mdot
.54501 .25521 Mdot
.51805 .38159 Mdot
.51698 .59969 Mdot
.54066 .34091 Mdot
.49152 .59718 Mdot
.5167 .63247 Mdot
.55146 .37315 Mdot
.68004 .48248 Mdot
.45047 .36286 Mdot
.50419 .7557 Mdot
.50147 .60962 Mdot
.55894 .62928 Mdot
.40579 .74834 Mdot
.80439 .39818 Mdot
.54708 .65851 Mdot
.65855 .51941 Mdot
.52805 .65466 Mdot
.51748 .37068 Mdot
.36647 .53036 Mdot
.67846 .51249 Mdot
.38229 .3508 Mdot
.377 .39841 Mdot
.54187 .30348 Mdot
.53823 .2211 Mdot
.55972 .63613 Mdot
.62084 .51491 Mdot
.67618 .53098 Mdot
.51876 .17338 Mdot
.34664 .36156 Mdot
.3342 .52428 Mdot
.49424 .61638 Mdot
.57498 .49167 Mdot
.56935 .37537 Mdot
.16031 .32691 Mdot
.69881 .39453 Mdot
.34118 .58241 Mdot
.77388 .39256 Mdot
.54641 .23289 Mdot
.52781 .68234 Mdot
.34119 .57237 Mdot
.38521 .39837 Mdot
.49393 .59841 Mdot
.45368 .67416 Mdot
.45358 .38646 Mdot
.3295 .40454 Mdot
.53884 .34182 Mdot
.39719 .37955 Mdot
.3312 .576 Mdot
.54326 .21974 Mdot
.65932 .48391 Mdot
.49579 .67095 Mdot
.59396 .58833 Mdot
.34995 .36243 Mdot
.55579 .22447 Mdot
.51564 .61998 Mdot
.65047 .48856 Mdot
.36825 .41448 Mdot
.49565 .63728 Mdot
.68258 .59626 Mdot
.73254 .48013 Mdot
.36154 .36495 Mdot
.53509 .58385 Mdot
.59346 .68369 Mdot
.37154 .34979 Mdot
.35709 .35283 Mdot
.52436 .64437 Mdot
.36424 .5357 Mdot
.53978 .67709 Mdot
.5575 .38532 Mdot
.32734 .34096 Mdot
.5195 .3727 Mdot
.38349 .61233 Mdot
.49329 .5802 Mdot
.69426 .30365 Mdot
.7154 .48505 Mdot
.31289 .54542 Mdot
.5958 .76616 Mdot
.53239 .58803 Mdot
.17758 .48329 Mdot
.40879 .52231 Mdot
.37497 .19664 Mdot
.21594 .66429 Mdot
.33808 .55607 Mdot
.52794 .38493 Mdot
.53093 .63951 Mdot
.55032 .41148 Mdot
.35826 .5643 Mdot
.39254 .61879 Mdot
.5374 .58487 Mdot
.66289 .49052 Mdot
.52978 .62803 Mdot
.71138 .4909 Mdot
.53485 .65509 Mdot
.51911 .71761 Mdot
.35182 .50172 Mdot
.45111 .75753 Mdot
.55475 .60197 Mdot
.4496 .82222 Mdot
.56222 .48548 Mdot
.33477 .54712 Mdot
.51988 .61151 Mdot
.54284 .24541 Mdot
.50418 .38923 Mdot
.27494 .6695 Mdot
.36616 .38713 Mdot
.5496 .38383 Mdot
.69932 .48529 Mdot
.40202 .35786 Mdot
.55292 .25031 Mdot
.59879 .58946 Mdot
.32296 .5493 Mdot
.52993 .39137 Mdot
.50507 .67755 Mdot
.48662 .67176 Mdot
.34853 .47901 Mdot
.6365 .21153 Mdot
.63756 .48815 Mdot
.61176 .81806 Mdot
.71815 .52051 Mdot
.35478 .54139 Mdot
.37109 .39021 Mdot
.53761 .67246 Mdot
.5017 .64885 Mdot
.3352 .38809 Mdot
.657 .52153 Mdot
.32181 .39926 Mdot
.76174 .5872 Mdot
.40323 .39773 Mdot
.39844 .69305 Mdot
.67843 .51753 Mdot
.40304 .69717 Mdot
.3278 .57457 Mdot
.2038 .57671 Mdot
.31515 .66893 Mdot
.55014 .39313 Mdot
.39384 .68735 Mdot
.66424 .51678 Mdot
.50458 .62797 Mdot
.55024 .23398 Mdot
.5325 .23044 Mdot
.70527 .48979 Mdot
.36355 .40601 Mdot
.3308 .53516 Mdot
.52825 .63699 Mdot
.7115 .36347 Mdot
.60706 .31971 Mdot
.40567 .37948 Mdot
.53149 .5533 Mdot
.52577 .35716 Mdot
.54915 .6464 Mdot
.34189 .56678 Mdot
.54027 .38305 Mdot
.53564 .26056 Mdot
.61518 .42802 Mdot
.49168 .618 Mdot
.71425 .4199 Mdot
.52114 .38532 Mdot
.76708 .31281 Mdot
.51057 .64632 Mdot
.54216 .34962 Mdot
.50466 .72394 Mdot
.62811 .28252 Mdot
.48245 .49728 Mdot
.19147 .41094 Mdot
.33402 .40913 Mdot
.37536 .40143 Mdot
.58606 .21962 Mdot
.33835 .5051 Mdot
.53509 .39646 Mdot
.54496 .21939 Mdot
.32282 .63756 Mdot
.52691 .35424 Mdot
.51103 .68949 Mdot
.4786 .66153 Mdot
.74802 .59853 Mdot
.49333 .47531 Mdot
.55761 .2256 Mdot
.60696 .53377 Mdot
.54866 .61566 Mdot
.57642 .62163 Mdot
.51012 .65472 Mdot
.69219 .53658 Mdot
.50845 .36933 Mdot
.4682 .84408 Mdot
.51506 .36121 Mdot
.7211 .36992 Mdot
.35508 .36519 Mdot
.40685 .3811 Mdot
.50558 .67969 Mdot
.72275 .30524 Mdot
.26268 .65883 Mdot
.55653 .63952 Mdot
.36329 .58959 Mdot
.34327 .61219 Mdot
.5775 .64433 Mdot
.65332 .54075 Mdot
.58369 .57978 Mdot
.72273 .52599 Mdot
.54429 .38027 Mdot
.33983 .55933 Mdot
.37432 .52431 Mdot
.53534 .39041 Mdot
.49689 .66471 Mdot
.38503 .58716 Mdot
.49013 .65245 Mdot
.50678 .62445 Mdot
.74678 .39561 Mdot
.3392 .51919 Mdot
.37636 .385 Mdot
.36098 .54263 Mdot
.69602 .49817 Mdot
.47814 .09755 Mdot
.35158 .56002 Mdot
.64286 .45256 Mdot
.38345 .47728 Mdot
.39655 .68839 Mdot
.6512 .4896 Mdot
.36849 .55796 Mdot
.52977 .34653 Mdot
.36898 .19723 Mdot
.78968 .35772 Mdot
.56086 .39586 Mdot
.5059 .64536 Mdot
.69452 .46973 Mdot
.68896 .53373 Mdot
.57597 .37625 Mdot
.66267 .48453 Mdot
.53903 .57631 Mdot
.50123 .61709 Mdot
.53492 .39636 Mdot
.62838 .35739 Mdot
.50589 .37225 Mdot
.60585 .4663 Mdot
.51734 .61474 Mdot
.68057 .51328 Mdot
.53024 .56924 Mdot
.63321 .50842 Mdot
.52973 .23723 Mdot
.49823 .59417 Mdot
.34763 .52635 Mdot
.49129 .46624 Mdot
.35952 .3661 Mdot
.3687 .30347 Mdot
.70389 .4769 Mdot
.54919 .42129 Mdot
.67541 .47704 Mdot
.71244 .4756 Mdot
.54075 .4063 Mdot
.69488 .50885 Mdot
.53055 .63804 Mdot
.38104 .46196 Mdot
.70972 .50713 Mdot
.53125 .37161 Mdot
.33569 .53227 Mdot
.68488 .48268 Mdot
.39922 .3515 Mdot
.49708 .62969 Mdot
.38846 .37146 Mdot
.32197 .5775 Mdot
.68545 .46792 Mdot
.36987 .55323 Mdot
.34762 .36254 Mdot
.32381 .55677 Mdot
.22727 .44503 Mdot
.52771 .34039 Mdot
.75014 .37466 Mdot
.53158 .75352 Mdot
.69886 .52601 Mdot
.3869 .42461 Mdot
.5427 .66605 Mdot
.4949 .62579 Mdot
.33599 .57627 Mdot
.68826 .53321 Mdot
.21105 .37022 Mdot
.58531 .68989 Mdot
.61162 .41214 Mdot
.54113 .33607 Mdot
.65703 .79769 Mdot
.65408 .41064 Mdot
.36149 .22393 Mdot
.53767 .70106 Mdot
.54694 .23318 Mdot
.48823 .65688 Mdot
.54873 .80426 Mdot
.36248 .52596 Mdot
.4626 .29116 Mdot
.5214 .70702 Mdot
.3689 .38011 Mdot
.52546 .6604 Mdot
.34384 .75616 Mdot
.57865 .5766 Mdot
.35964 .56781 Mdot
.52542 .3288 Mdot
.67038 .46296 Mdot
.33706 .5387 Mdot
.38202 .39337 Mdot
.35294 .65275 Mdot
.54583 .58718 Mdot
.55129 .62466 Mdot
.37423 .42688 Mdot
.66286 .48834 Mdot
.33879 .37364 Mdot
.54461 .35063 Mdot
.34992 .55735 Mdot
.50075 .60593 Mdot
.57171 .60876 Mdot
.39858 .33988 Mdot
.50934 .36528 Mdot
.40145 .3636 Mdot
.55516 .34798 Mdot
.54777 .23264 Mdot
.56132 .61937 Mdot
.37467 .42543 Mdot
.47476 .65925 Mdot
.59139 .77938 Mdot
.75561 .39721 Mdot
.683 .72565 Mdot
.37867 .38392 Mdot
.38465 .70389 Mdot
.52325 .37901 Mdot
.56192 .3615 Mdot
.77399 .6575 Mdot
.25492 .6257 Mdot
.30248 .41479 Mdot
.44141 .8089 Mdot
.5456 .35111 Mdot
.52232 .37249 Mdot
.38435 .40151 Mdot
.70002 .50526 Mdot
.7398 .49669 Mdot
.40895 .38006 Mdot
.46367 .7622 Mdot
.66227 .51224 Mdot
.1779 .46478 Mdot
.35162 .35058 Mdot
.52265 .7081 Mdot
.54692 .21073 Mdot
.33565 .55953 Mdot
.46615 .76171 Mdot
.40139 .78416 Mdot
.5265 .68102 Mdot
.80718 .50178 Mdot
.35516 .392 Mdot
.43328 .43595 Mdot
.17801 .53928 Mdot
.51898 .58503 Mdot
.51888 .66549 Mdot
.50187 .66419 Mdot
.35089 .51486 Mdot
.58578 .77063 Mdot
.52384 .68258 Mdot
.43332 .74164 Mdot
.5214 .69115 Mdot
.31595 .70944 Mdot
.36087 .54402 Mdot
.5744 .54094 Mdot
.34451 .42101 Mdot
.67112 .33558 Mdot
.44416 .66794 Mdot
.54451 .34622 Mdot
.40784 .43059 Mdot
.54363 .36182 Mdot
.23552 .6199 Mdot
.31606 .66704 Mdot
.70175 .53371 Mdot
.54614 .64574 Mdot
.33831 .40857 Mdot
.70344 .47467 Mdot
.41881 .25767 Mdot
.55579 .11455 Mdot
.52245 .34895 Mdot
.8507 .45936 Mdot
.56248 .3618 Mdot
.53075 .23687 Mdot
.69995 .48199 Mdot
.71229 .55716 Mdot
.48708 .45357 Mdot
.68363 .48409 Mdot
.53356 .29249 Mdot
.66057 .54455 Mdot
.38832 .69524 Mdot
.69567 .4611 Mdot
.53013 .37554 Mdot
.51422 .34352 Mdot
.47762 .70237 Mdot
.54388 .66161 Mdot
.5331 .44614 Mdot
.5066 .73079 Mdot
.54643 .65384 Mdot
.37367 .37295 Mdot
.77311 .35088 Mdot
.36868 .3375 Mdot
.70112 .51649 Mdot
.56363 .35203 Mdot
.5207 .66434 Mdot
.50411 .60953 Mdot
.4705 .63647 Mdot
.57549 .80648 Mdot
.18002 .46122 Mdot
.51417 .63039 Mdot
.45718 .62467 Mdot
.38021 .39217 Mdot
.38972 .53454 Mdot
.49009 .81072 Mdot
.32378 .64755 Mdot
.48554 .63539 Mdot
.3533 .53592 Mdot
.35742 .51963 Mdot
.57194 .63689 Mdot
.69803 .33464 Mdot
.37748 .45222 Mdot
.50561 .67766 Mdot
.30794 .67507 Mdot
.38398 .34272 Mdot
.55131 .21865 Mdot
.35055 .3618 Mdot
.67623 .4684 Mdot
.53718 .22812 Mdot
.37502 .41695 Mdot
.69256 .56476 Mdot
.54232 .256 Mdot
.63357 .29481 Mdot
.37029 .53657 Mdot
.50579 .65361 Mdot
.64249 .53639 Mdot
.33352 .38429 Mdot
.53289 .39196 Mdot
.67798 .49981 Mdot
.50011 .37698 Mdot
.38164 .51565 Mdot
.41174 .66642 Mdot
.5356 .22298 Mdot
.55162 .35026 Mdot
.61551 .42901 Mdot
.35582 .53652 Mdot
.54463 .40443 Mdot
.71145 .29641 Mdot
.56341 .67042 Mdot
.25443 .67432 Mdot
.54987 .63517 Mdot
.27653 .28652 Mdot
.56342 .36648 Mdot
.5315 .25201 Mdot
.49254 .66509 Mdot
.36823 .3516 Mdot
.52394 .72165 Mdot
.492 .64703 Mdot
.39638 .3639 Mdot
.50854 .62829 Mdot
.34156 .56774 Mdot
.73478 .50548 Mdot
.41518 .52455 Mdot
.73549 .73874 Mdot
.32528 .5578 Mdot
.5554 .20102 Mdot
.54791 .65422 Mdot
.23557 .49862 Mdot
.6805 .48477 Mdot
.51533 .58697 Mdot
.8009 .58266 Mdot
.70531 .50353 Mdot
.68546 .49372 Mdot
.53432 .61003 Mdot
.54628 .40044 Mdot
.36399 .35522 Mdot
.35663 .53579 Mdot
.42682 .18527 Mdot
.49265 .63981 Mdot
.52172 .65013 Mdot
.33475 .54029 Mdot
.52075 .37278 Mdot
.50608 .60562 Mdot
.40674 .28268 Mdot
.45271 .16412 Mdot
.55762 .39099 Mdot
.57176 .65872 Mdot
.29862 .74312 Mdot
.7011 .45252 Mdot
.82766 .42373 Mdot
.326 .50343 Mdot
.36117 .39996 Mdot
.53822 .70929 Mdot
.19507 .28744 Mdot
.33563 .55788 Mdot
.68036 .36001 Mdot
.51793 .62739 Mdot
.53116 .66558 Mdot
.64957 .50146 Mdot
.52118 .60254 Mdot
.67507 .52376 Mdot
.75428 .72608 Mdot
.60587 .84679 Mdot
.67924 .47787 Mdot
.69571 .52314 Mdot
.64261 .55914 Mdot
.5318 .79612 Mdot
.70147 .49031 Mdot
.52654 .58156 Mdot
.2085 .46376 Mdot
.45358 .62254 Mdot
.32229 .56865 Mdot
.32426 .585 Mdot
.73617 .529 Mdot
.70918 .26001 Mdot
.58663 .67018 Mdot
.43203 .65665 Mdot
.52694 .51638 Mdot
.55915 .37388 Mdot
.48333 .6257 Mdot
.5388 .22029 Mdot
.39336 .4 Mdot
.5509 .56046 Mdot
.50177 .65453 Mdot
.71303 .49672 Mdot
.34605 .51475 Mdot
.50728 .39929 Mdot
.51926 .64556 Mdot
.32127 .38376 Mdot
.34641 .54492 Mdot
.70676 .51316 Mdot
.68193 .43729 Mdot
.31853 .54831 Mdot
.55463 .58149 Mdot
.54155 .65737 Mdot
.51448 .61949 Mdot
.45117 .68731 Mdot
.53948 .3918 Mdot
.40754 .35441 Mdot
.52654 .57805 Mdot
.74398 .40549 Mdot
.43755 .4555 Mdot
.56605 .60284 Mdot
.6555 .51101 Mdot
.56529 .38631 Mdot
.53849 .25199 Mdot
.36806 .64529 Mdot
.489 .62358 Mdot
.18153 .46588 Mdot
.7497 .57473 Mdot
.53651 .23353 Mdot
.7204 .50064 Mdot
.35342 .53079 Mdot
.54683 .61933 Mdot
.20746 .50496 Mdot
.48206 .66582 Mdot
.54469 .73887 Mdot
.35812 .39645 Mdot
.55757 .36695 Mdot
.43126 .16547 Mdot
.3945 .39845 Mdot
.68626 .49539 Mdot
.1832 .38246 Mdot
.64299 .51602 Mdot
.65183 .47199 Mdot
.21656 .57627 Mdot
.54738 .37815 Mdot
.17954 .30624 Mdot
.80067 .37968 Mdot
.49092 .68145 Mdot
.51568 .36837 Mdot
.6999 .47961 Mdot
.54699 .64286 Mdot
.68274 .52989 Mdot
.64369 .48538 Mdot
.48687 .60695 Mdot
.53721 .66324 Mdot
.44837 .74905 Mdot
.16455 .49515 Mdot
.36264 .53749 Mdot
.65388 .51875 Mdot
.71772 .60476 Mdot
.52825 .68117 Mdot
.48453 .66356 Mdot
.43049 .4204 Mdot
.35985 .56738 Mdot
.60458 .689 Mdot
.50635 .62134 Mdot
.80593 .58818 Mdot
.56001 .63223 Mdot
.63433 .52636 Mdot
.5529 .39776 Mdot
.69591 .33933 Mdot
.33457 .36921 Mdot
.6446 .49772 Mdot
.33004 .53222 Mdot
.65821 .5367 Mdot
.78783 .61734 Mdot
.54688 .37364 Mdot
.67143 .519 Mdot
.37321 .34486 Mdot
.53906 .36593 Mdot
.55674 .39013 Mdot
.21816 .49003 Mdot
.40474 .36728 Mdot
.37424 .54458 Mdot
.53863 .35682 Mdot
.67731 .6045 Mdot
.53324 .37755 Mdot
.73133 .60392 Mdot
.55566 .65594 Mdot
.43053 .7335 Mdot
.66269 .40149 Mdot
.44357 .64976 Mdot
.50471 .37462 Mdot
.36227 .55715 Mdot
.53432 .60201 Mdot
.65954 .48781 Mdot
.34939 .5613 Mdot
.53602 .3176 Mdot
.38291 .34926 Mdot
.71734 .49595 Mdot
.55764 .39384 Mdot
.6709 .52203 Mdot
.40308 .64699 Mdot
.34085 .31875 Mdot
.53203 .52064 Mdot
.47355 .44847 Mdot
.46805 .64344 Mdot
.735 .53404 Mdot
.56203 .64899 Mdot
.49804 .65345 Mdot
.36106 .36443 Mdot
.41937 .75539 Mdot
.68134 .48162 Mdot
.44689 .15827 Mdot
.55685 .35538 Mdot
.76922 .46194 Mdot
.59904 .66829 Mdot
.50411 .59414 Mdot
.70926 .50565 Mdot
.6407 .48872 Mdot
.67988 .73893 Mdot
.3363 .38866 Mdot
.44749 .63005 Mdot
.49346 .5776 Mdot
.50492 .71287 Mdot
.56431 .36555 Mdot
.42336 .29737 Mdot
.35077 .40197 Mdot
.83072 .35581 Mdot
.34574 .37936 Mdot
.26884 .45288 Mdot
.69508 .50971 Mdot
.35797 .52479 Mdot
.48605 .66659 Mdot
.48649 .7497 Mdot
.6941 .5407 Mdot
.40617 .44944 Mdot
.34729 .52846 Mdot
.45089 .32603 Mdot
.5488 .38106 Mdot
.56455 .61267 Mdot
.48236 .61606 Mdot
.5227 .6087 Mdot
.54301 .63183 Mdot
.5585 .34403 Mdot
.5101 .68922 Mdot
.5423 .3337 Mdot
.67541 .59238 Mdot
.80485 .59945 Mdot
.32941 .38007 Mdot
.26873 .65176 Mdot
.70484 .52357 Mdot
.68666 .61871 Mdot
.61281 .64857 Mdot
.75385 .39347 Mdot
.22558 .46718 Mdot
.56041 .64343 Mdot
.36644 .40802 Mdot
.34586 .76128 Mdot
.33828 .40752 Mdot
.69097 .82823 Mdot
.38699 .59326 Mdot
.18436 .41314 Mdot
.54537 .64218 Mdot
.40089 .34327 Mdot
.6035 .6687 Mdot
.57259 .64567 Mdot
.39396 .5868 Mdot
.63203 .45454 Mdot
.64382 .35518 Mdot
.32949 .52772 Mdot
.49606 .63181 Mdot
.66816 .4628 Mdot
.53146 .63703 Mdot
.48489 .65955 Mdot
.55071 .64752 Mdot
.51554 .4075 Mdot
.53023 .69701 Mdot
.53468 .6805 Mdot
.64544 .21191 Mdot
.38296 .72335 Mdot
.39216 .37164 Mdot
.71842 .707 Mdot
.35375 .54922 Mdot
.71174 .48761 Mdot
.40076 .50898 Mdot
.55291 .38711 Mdot
.66588 .75183 Mdot
.54779 .63933 Mdot
.64898 .39954 Mdot
.55773 .39438 Mdot
.34517 .56189 Mdot
.54879 .25209 Mdot
.20465 .41909 Mdot
.33045 .38554 Mdot
.53873 .25594 Mdot
.35833 .36739 Mdot
.60498 .74751 Mdot
.71245 .4978 Mdot
.47089 .63004 Mdot
.53161 .35418 Mdot
.3693 .3543 Mdot
.40203 .7546 Mdot
.5111 .65895 Mdot
.38082 .38186 Mdot
.46799 .63852 Mdot
.41488 .46359 Mdot
.36265 .46424 Mdot
.36298 .41987 Mdot
.51284 .34196 Mdot
.53367 .36332 Mdot
.36489 .53399 Mdot
.71296 .488 Mdot
.65943 .51773 Mdot
.54097 .3799 Mdot
.83222 .45108 Mdot
.48951 .64532 Mdot
.54973 .64994 Mdot
.73505 .40366 Mdot
.53719 .64385 Mdot
.36651 .67104 Mdot
.53501 .21651 Mdot
.71467 .50434 Mdot
.54104 .63693 Mdot
.50441 .60604 Mdot
.49317 .61653 Mdot
.40434 .65405 Mdot
.34807 .36554 Mdot
.54827 .61591 Mdot
.33674 .57305 Mdot
.67377 .2789 Mdot
.54461 .6675 Mdot
.57516 .6301 Mdot
.66886 .51775 Mdot
.66753 .79777 Mdot
.55353 .39007 Mdot
.38169 .37487 Mdot
.36157 .34944 Mdot
.29992 .54744 Mdot
.72848 .49012 Mdot
.53463 .21334 Mdot
.50154 .21381 Mdot
.55407 .22899 Mdot
.33738 .54246 Mdot
.28172 .41403 Mdot
.32384 .39704 Mdot
.39161 .38239 Mdot
.52937 .33661 Mdot
.54106 .63325 Mdot
.55764 .63923 Mdot
.68371 .36028 Mdot
.54034 .59817 Mdot
.34272 .52865 Mdot
.52663 .39656 Mdot
.6681 .51464 Mdot
.33345 .55905 Mdot
.54826 .34495 Mdot
.66067 .4904 Mdot
.56485 .66599 Mdot
.55845 .67768 Mdot
.6802 .49582 Mdot
.6903 .4721 Mdot
.52348 .67809 Mdot
.6152 .20633 Mdot
.69897 .46426 Mdot
.67469 .51843 Mdot
.56133 .2393 Mdot
.33064 .38912 Mdot
.55089 .57323 Mdot
.51499 .36804 Mdot
.51354 .62014 Mdot
.33081 .39526 Mdot
.36362 .56353 Mdot
.67074 .49085 Mdot
.50133 .61178 Mdot
.50645 .63301 Mdot
.35266 .53472 Mdot
.32335 .53112 Mdot
.32761 .54432 Mdot
.51831 .41625 Mdot
.53158 .62166 Mdot
.69912 .4886 Mdot
.54947 .37617 Mdot
.35714 .51955 Mdot
.37499 .56247 Mdot
.67775 .22784 Mdot
.5203 .6828 Mdot
.48938 .50066 Mdot
.43567 .11294 Mdot
.34461 .65221 Mdot
.53362 .24776 Mdot
.38873 .41657 Mdot
.41535 .71921 Mdot
.30091 .51666 Mdot
.51058 .37366 Mdot
.27216 .60517 Mdot
.31291 .54726 Mdot
.48313 .60679 Mdot
.5584 .6257 Mdot
.46489 .6603 Mdot
.34673 .54992 Mdot
.39705 .64156 Mdot
.67961 .53401 Mdot
.65696 .67938 Mdot
.35357 .5494 Mdot
.36304 .41961 Mdot
.37341 .42443 Mdot
.3458 .38075 Mdot
.5646 .62637 Mdot
.6706 .74222 Mdot
.69647 .60402 Mdot
.61239 .70961 Mdot
.54859 .38429 Mdot
.63768 .49583 Mdot
.23035 .47266 Mdot
.68452 .49222 Mdot
.38796 .40734 Mdot
.3431 .54912 Mdot
.65102 .51207 Mdot
.51651 .38518 Mdot
.52174 .36975 Mdot
.37992 .34915 Mdot
.35506 .35879 Mdot
.37631 .36275 Mdot
.66534 .47119 Mdot
.6951 .50887 Mdot
.49452 .61005 Mdot
.66974 .49744 Mdot
.80275 .48777 Mdot
.34621 .58425 Mdot
.36616 .42488 Mdot
.52066 .38203 Mdot
.70808 .48471 Mdot
.50644 .65111 Mdot
.31089 .44548 Mdot
.51081 .31343 Mdot
.3292 .56458 Mdot
.30086 .34454 Mdot
.76027 .76544 Mdot
.47713 .62706 Mdot
.54801 .34152 Mdot
.69589 .32216 Mdot
.50733 .66517 Mdot
.36238 .38965 Mdot
.5616 .79811 Mdot
.55586 .22802 Mdot
.53689 .67836 Mdot
.52238 .58979 Mdot
.53525 .40677 Mdot
.37958 .48446 Mdot
.51296 .59357 Mdot
.65926 .42513 Mdot
.49821 .3857 Mdot
.35509 .40868 Mdot
.47702 .15617 Mdot
.40218 .40493 Mdot
.4622 .77164 Mdot
.53275 .24189 Mdot
.48484 .6132 Mdot
.37149 .37041 Mdot
.33511 .56875 Mdot
.37013 .36417 Mdot
.71611 .51469 Mdot
.38651 .36777 Mdot
.52468 .65311 Mdot
.69917 .49108 Mdot
.51875 .38379 Mdot
.75966 .44198 Mdot
.65741 .22531 Mdot
.36876 .3513 Mdot
.55164 .2618 Mdot
.53241 .68015 Mdot
.63086 .61426 Mdot
.52599 .72104 Mdot
.54862 .65916 Mdot
.54508 .36295 Mdot
.70773 .50851 Mdot
.5446 .33751 Mdot
.58242 .61594 Mdot
.757 .6887 Mdot
.56144 .36619 Mdot
.63889 .31893 Mdot
.33497 .5417 Mdot
.46062 .75789 Mdot
.49765 .64694 Mdot
.53737 .35359 Mdot
.52994 .62092 Mdot
.65733 .52619 Mdot
.54354 .47165 Mdot
.68931 .28568 Mdot
.52983 .35558 Mdot
.23451 .33 Mdot
.53437 .4808 Mdot
.57512 .57828 Mdot
.54284 .3522 Mdot
.6299 .75899 Mdot
.54145 .24895 Mdot
.34406 .54176 Mdot
.34857 .51724 Mdot
.32208 .5521 Mdot
.54349 .599 Mdot
.56943 .55849 Mdot
.37614 .55335 Mdot
.49691 .38925 Mdot
.35231 .57231 Mdot
.45553 .74581 Mdot
.23015 .34525 Mdot
.32622 .55162 Mdot
.50379 .64215 Mdot
.57555 .63961 Mdot
.38405 .72682 Mdot
.36588 .41576 Mdot
.177 .48844 Mdot
.77707 .51033 Mdot
.53686 .6716 Mdot
.60115 .59926 Mdot
.71053 .51985 Mdot
.72722 .32568 Mdot
.60567 .62778 Mdot
.35952 .47264 Mdot
.68773 .5241 Mdot
.32791 .42258 Mdot
.71554 .49793 Mdot
.47411 .63782 Mdot
.51813 .63266 Mdot
.72925 .52013 Mdot
.37018 .29833 Mdot
.61111 .26406 Mdot
.31836 .24572 Mdot
.65962 .52025 Mdot
.53585 .34873 Mdot
.52954 .34391 Mdot
.55254 .37552 Mdot
.33681 .36692 Mdot
.67622 .47051 Mdot
.5382 .6213 Mdot
.37309 .39946 Mdot
.48524 .64036 Mdot
.53924 .36202 Mdot
.42586 .16718 Mdot
.66909 .51678 Mdot
.50256 .67557 Mdot
.78888 .35801 Mdot
.35052 .37618 Mdot
.3557 .53825 Mdot
.42338 .45192 Mdot
.4109 .3588 Mdot
.5051 .37261 Mdot
.71646 .46338 Mdot
.4913 .39637 Mdot
.40676 .53952 Mdot
.46054 .6622 Mdot
.56151 .60093 Mdot
.46563 .1727 Mdot
.73278 .28407 Mdot
.55615 .61021 Mdot
.38271 .39302 Mdot
.34573 .40959 Mdot
.49779 .618 Mdot
.66086 .4817 Mdot
.36767 .52621 Mdot
.32442 .56624 Mdot
.48827 .59562 Mdot
.48726 .45072 Mdot
.43942 .74267 Mdot
.51267 .60216 Mdot
.4507 .60006 Mdot
.39212 .352 Mdot
.55001 .25273 Mdot
.70318 .40436 Mdot
.34242 .5228 Mdot
.51576 .62567 Mdot
.60233 .28294 Mdot
.67831 .52434 Mdot
.3831 .36648 Mdot
.52791 .39379 Mdot
.40344 .58202 Mdot
.35718 .34861 Mdot
.4986 .61764 Mdot
.50569 .60579 Mdot
.53886 .4061 Mdot
.63493 .52696 Mdot
.34386 .55099 Mdot
.37283 .39828 Mdot
.35532 .5228 Mdot
.69499 .50168 Mdot
.6712 .51277 Mdot
.46203 .59523 Mdot
.45828 .69567 Mdot
.36523 .34991 Mdot
.46623 .61396 Mdot
.38042 .41559 Mdot
.36132 .48896 Mdot
.57041 .36901 Mdot
.51013 .58695 Mdot
.67153 .45791 Mdot
.54271 .366 Mdot
.52789 .6712 Mdot
.52404 .18401 Mdot
.49645 .59983 Mdot
.40935 .35638 Mdot
.76547 .67988 Mdot
.36235 .56178 Mdot
.724 .44345 Mdot
.43026 .58723 Mdot
.53588 .64476 Mdot
.38316 .41678 Mdot
.55137 .70429 Mdot
.56116 .38105 Mdot
.69643 .51631 Mdot
.8651 .54646 Mdot
.5337 .3734 Mdot
.52888 .63512 Mdot
.34916 .55892 Mdot
.64639 .47435 Mdot
.54293 .22338 Mdot
.70279 .39884 Mdot
.5603 .5637 Mdot
.53907 .69846 Mdot
.53873 .63357 Mdot
.45068 .8158 Mdot
.37807 .37152 Mdot
.70425 .48177 Mdot
.56637 .36407 Mdot
.53693 .38547 Mdot
.35037 .39034 Mdot
.64072 .38081 Mdot
.34622 .30486 Mdot
.35067 .13846 Mdot
.39218 .36228 Mdot
.35272 .57407 Mdot
.46007 .45712 Mdot
.39731 .39403 Mdot
.37237 .37672 Mdot
.36824 .34713 Mdot
.66894 .38698 Mdot
.65512 .50022 Mdot
.50631 .63193 Mdot
.72757 .49302 Mdot
.48932 .60627 Mdot
.45259 .78488 Mdot
.54244 .38082 Mdot
.69539 .51571 Mdot
.50083 .17688 Mdot
.51621 .7288 Mdot
.51531 .664 Mdot
.23192 .40106 Mdot
.58817 .62136 Mdot
.38491 .66948 Mdot
.55118 .57817 Mdot
.3567 .36133 Mdot
.5957 .5763 Mdot
.53104 .71098 Mdot
.79404 .47732 Mdot
.51672 .37828 Mdot
.5302 .23056 Mdot
.55067 .68087 Mdot
.52932 .56159 Mdot
.64828 .47338 Mdot
.65096 .51241 Mdot
.37608 .54964 Mdot
.45622 .42579 Mdot
.51729 .38186 Mdot
.41891 .34182 Mdot
.54381 .65989 Mdot
.56632 .32576 Mdot
.78011 .64524 Mdot
.52536 .67292 Mdot
.21008 .48437 Mdot
.6703 .74811 Mdot
.50993 .594 Mdot
.63113 .71696 Mdot
.52337 .37545 Mdot
.80471 .58635 Mdot
.4639 .64833 Mdot
.36187 .38832 Mdot
.6994 .50826 Mdot
.71474 .51276 Mdot
.32917 .55998 Mdot
.80785 .45615 Mdot
.51269 .3519 Mdot
.69558 .51156 Mdot
.50417 .66177 Mdot
.53662 .39268 Mdot
.53543 .22541 Mdot
.57078 .6671 Mdot
.24524 .58652 Mdot
.66805 .50209 Mdot
.45886 .61418 Mdot
.60598 .37995 Mdot
.41816 .47037 Mdot
.15657 .51556 Mdot
.55423 .37146 Mdot
.33398 .52886 Mdot
.54333 .57414 Mdot
.49924 .21047 Mdot
.48497 .6893 Mdot
.43279 .75285 Mdot
.75184 .48636 Mdot
.36594 .52981 Mdot
.50427 .66942 Mdot
.51578 .59405 Mdot
.48163 .45935 Mdot
.3273 .52783 Mdot
.50097 .59408 Mdot
.4539 .61103 Mdot
.66196 .49012 Mdot
.53229 .21977 Mdot
.66601 .50889 Mdot
.50669 .64566 Mdot
.59732 .57121 Mdot
.65331 .49304 Mdot
.28466 .33545 Mdot
.32585 .52149 Mdot
.55515 .38587 Mdot
.48604 .56481 Mdot
.55481 .65572 Mdot
.28487 .75734 Mdot
.52983 .23751 Mdot
.53101 .81485 Mdot
.41012 .37603 Mdot
.56014 .27348 Mdot
.35506 .32482 Mdot
.19021 .39805 Mdot
.73278 .42441 Mdot
.45704 .64171 Mdot
.28899 .65024 Mdot
.62396 .71066 Mdot
.52317 .34485 Mdot
.65221 .60882 Mdot
.54391 .66176 Mdot
.48636 .6577 Mdot
.37869 .40553 Mdot
.63442 .39573 Mdot
.69247 .325 Mdot
.50769 .44854 Mdot
.33989 .55354 Mdot
.69041 .50824 Mdot
.5325 .65306 Mdot
.37375 .26154 Mdot
.39049 .36719 Mdot
.57817 .48536 Mdot
.49625 .67048 Mdot
.72022 .36252 Mdot
.6568 .3474 Mdot
.53755 .39353 Mdot
.38994 .41411 Mdot
.40892 .3576 Mdot
.4772 .65078 Mdot
.51288 .3848 Mdot
.49679 .60571 Mdot
.56558 .47769 Mdot
.462 .61429 Mdot
.34282 .5648 Mdot
.49856 .68256 Mdot
.47403 .48292 Mdot
.16054 .43421 Mdot
.59083 .60387 Mdot
.70336 .47034 Mdot
.33815 .3665 Mdot
.3464 .37439 Mdot
.66 .51915 Mdot
.347 .37911 Mdot
.66125 .68631 Mdot
.77709 .6055 Mdot
.33472 .55166 Mdot
.62093 .5956 Mdot
.34788 .56488 Mdot
.52978 .23113 Mdot
.52654 .67979 Mdot
.50536 .2351 Mdot
.38831 .35806 Mdot
.60924 .80026 Mdot
.534 .38011 Mdot
.53015 .23632 Mdot
.51031 .69337 Mdot
.28047 .41808 Mdot
.37963 .41162 Mdot
.42346 .39267 Mdot
.49272 .61635 Mdot
.65334 .5114 Mdot
.51603 .59455 Mdot
.48997 .58815 Mdot
.53893 .25552 Mdot
.53934 .63244 Mdot
.54764 .34468 Mdot
.67112 .4717 Mdot
.20238 .39103 Mdot
.333 .37971 Mdot
.49381 .67647 Mdot
.50428 .66277 Mdot
.65625 .52712 Mdot
.51808 .69115 Mdot
.50837 .37544 Mdot
.11538 .38778 Mdot
.33621 .54129 Mdot
.55466 .24794 Mdot
.42527 .37565 Mdot
.55646 .63261 Mdot
.51549 .59864 Mdot
.45459 .17353 Mdot
.64004 .24917 Mdot
.54743 .34606 Mdot
.51654 .57808 Mdot
.38025 .39106 Mdot
.3465 .56075 Mdot
.50665 .39611 Mdot
.51274 .61683 Mdot
.48759 .66381 Mdot
.34089 .5641 Mdot
.21221 .45912 Mdot
.37285 .45515 Mdot
.55081 .38103 Mdot
.6062 .58746 Mdot
.32197 .45291 Mdot
.49058 .64613 Mdot
.31821 .27423 Mdot
.67558 .51691 Mdot
.54786 .35486 Mdot
.56373 .769 Mdot
.47074 .62821 Mdot
.50797 .3691 Mdot
.51804 .38168 Mdot
.48492 .67508 Mdot
.72725 .4871 Mdot
.65535 .47468 Mdot
.67737 .52033 Mdot
.76363 .68888 Mdot
.36327 .74511 Mdot
.37583 .36182 Mdot
.52213 .37438 Mdot
.34767 .41471 Mdot
.36777 .5246 Mdot
.44021 .45451 Mdot
.3513 .41487 Mdot
.7122 .5166 Mdot
.37051 .42563 Mdot
.50177 .60276 Mdot
.51497 .38086 Mdot
.39224 .38244 Mdot
.55559 .62476 Mdot
.44089 .62478 Mdot
.51502 .49526 Mdot
.36915 .52869 Mdot
.38543 .46597 Mdot
.51999 .63954 Mdot
.53958 .2536 Mdot
.5174 .68016 Mdot
.53598 .39661 Mdot
.45345 .484 Mdot
.55286 .622 Mdot
.36912 .35008 Mdot
.42605 .54567 Mdot
.3551 .41073 Mdot
.48996 .58242 Mdot
.5076 .64464 Mdot
.48893 .64894 Mdot
.5136 .59321 Mdot
.64432 .33606 Mdot
.54502 .33521 Mdot
.46334 .5761 Mdot
.32445 .37923 Mdot
.6796 .48975 Mdot
.67222 .53677 Mdot
.30802 .42125 Mdot
.54493 .25831 Mdot
.51571 .37114 Mdot
.49056 .64393 Mdot
.42274 .39566 Mdot
.41466 .17235 Mdot
.31734 .26608 Mdot
.23657 .48216 Mdot
.38699 .38917 Mdot
.70242 .47065 Mdot
.39755 .38332 Mdot
.48004 .64855 Mdot
.56963 .599 Mdot
.19574 .40042 Mdot
.57878 .3625 Mdot
.34426 .54917 Mdot
.48405 .64365 Mdot
.46942 .77211 Mdot
.38013 .39224 Mdot
.39602 .35437 Mdot
.48761 .61329 Mdot
.6457 .4893 Mdot
.13702 .54485 Mdot
.52959 .39476 Mdot
.63459 .61289 Mdot
.72772 .45154 Mdot
.6254 .46106 Mdot
.53464 .38977 Mdot
.52509 .50724 Mdot
.34434 .39049 Mdot
.78482 .50149 Mdot
.67786 .49372 Mdot
.34792 .54661 Mdot
.56173 .59324 Mdot
.71476 .51142 Mdot
.39434 .41135 Mdot
.70821 .51568 Mdot
.47338 .62788 Mdot
.53439 .33845 Mdot
.34988 .39341 Mdot
.53618 .32852 Mdot
.72756 .52263 Mdot
.35409 .56558 Mdot
.46645 .75771 Mdot
.64493 .60308 Mdot
.66861 .74944 Mdot
.54819 .61626 Mdot
.39229 .43041 Mdot
.53017 .61907 Mdot
.64749 .47565 Mdot
.49869 .64599 Mdot
.72559 .5413 Mdot
.4067 .38019 Mdot
.45846 .61657 Mdot
.52548 .68548 Mdot
.70515 .5718 Mdot
.51773 .66974 Mdot
.50414 .69154 Mdot
.52471 .59165 Mdot
.74032 .45992 Mdot
.45557 .61249 Mdot
.65294 .50401 Mdot
.67882 .36717 Mdot
.37005 .37601 Mdot
.37886 .55029 Mdot
.32095 .55901 Mdot
.43275 .74884 Mdot
.46093 .7594 Mdot
.64439 .38377 Mdot
.66047 .50748 Mdot
.52959 .34767 Mdot
.49589 .60671 Mdot
.56306 .76313 Mdot
.30993 .54254 Mdot
.34566 .39112 Mdot
.34116 .35602 Mdot
.4692 .70596 Mdot
.43679 .81569 Mdot
.45882 .6104 Mdot
.70988 .39685 Mdot
.47676 .60711 Mdot
.51306 .5876 Mdot
.36956 .34401 Mdot
.42081 .68965 Mdot
.5485 .61621 Mdot
.64811 .47346 Mdot
.35093 .54284 Mdot
.59874 .63303 Mdot
.34973 .59631 Mdot
.55421 .49523 Mdot
.74151 .54332 Mdot
.54148 .62683 Mdot
.36666 .39925 Mdot
.71689 .49309 Mdot
.74195 .40913 Mdot
.54974 .37319 Mdot
.67176 .40795 Mdot
.69821 .58745 Mdot
.26859 .35825 Mdot
.34656 .54519 Mdot
.215 .47566 Mdot
.52494 .65277 Mdot
.34108 .36157 Mdot
.47863 .61939 Mdot
.40451 .17749 Mdot
.36874 .55527 Mdot
.69427 .54149 Mdot
.53484 .3484 Mdot
.66116 .52711 Mdot
.68834 .7226 Mdot
.51425 .52783 Mdot
.5674 .21781 Mdot
.33242 .3934 Mdot
.51486 .7806 Mdot
.70539 .492 Mdot
.50561 .61377 Mdot
.38057 .12725 Mdot
.67726 .51587 Mdot
.65657 .52102 Mdot
.36829 .48094 Mdot
.38486 .61285 Mdot
.55677 .69808 Mdot
.70388 .52143 Mdot
.34789 .41841 Mdot
.36199 .54099 Mdot
.54026 .60489 Mdot
.52303 .59262 Mdot
.64987 .50426 Mdot
.38191 .41188 Mdot
.49564 .79047 Mdot
.35559 .35988 Mdot
.66703 .4844 Mdot
.3543 .37595 Mdot
.43146 .38505 Mdot
.38787 .37961 Mdot
.54575 .67329 Mdot
.49224 .64174 Mdot
.26185 .53822 Mdot
.67116 .5126 Mdot
.52565 .60014 Mdot
.51281 .62801 Mdot
.70162 .48884 Mdot
.32696 .40316 Mdot
.54429 .77627 Mdot
.54535 .6452 Mdot
.4999 .6337 Mdot
.36 .52521 Mdot
.31136 .37151 Mdot
.36694 .2536 Mdot
.53486 .60278 Mdot
.32993 .57159 Mdot
.66946 .46908 Mdot
.51986 .67889 Mdot
.45016 .74 Mdot
.35547 .34174 Mdot
.48737 .67441 Mdot
.54322 .22225 Mdot
.55755 .63685 Mdot
.13791 .53724 Mdot
.50539 .68358 Mdot
.69736 .47932 Mdot
.70389 .50528 Mdot
.41478 .44756 Mdot
.68651 .49815 Mdot
.53197 .23484 Mdot
.53821 .36306 Mdot
.29075 .27666 Mdot
.53435 .22945 Mdot
.52564 .58561 Mdot
.80083 .38006 Mdot
.46398 .62153 Mdot
.55612 .67261 Mdot
.537 .79684 Mdot
.53428 .23223 Mdot
.70985 .50034 Mdot
.37685 .29874 Mdot
.49728 .58834 Mdot
.52425 .39324 Mdot
.57387 .63323 Mdot
.49435 .68185 Mdot
.63692 .43951 Mdot
.72133 .72478 Mdot
.53859 .39818 Mdot
.56417 .58124 Mdot
.53475 .60327 Mdot
.70057 .26704 Mdot
.50958 .65683 Mdot
.32706 .55507 Mdot
.6671 .52342 Mdot
.40079 .37523 Mdot
.34395 .53477 Mdot
.54235 .64922 Mdot
.34961 .54972 Mdot
.37968 .36533 Mdot
.54518 .35989 Mdot
.48784 .67169 Mdot
.31984 .56515 Mdot
.34184 .55336 Mdot
.52625 .61326 Mdot
.69701 .51247 Mdot
.5648 .70044 Mdot
.52196 .67745 Mdot
.50266 .61613 Mdot
.65948 .51769 Mdot
.76867 .28319 Mdot
.47648 .64175 Mdot
.49593 .50005 Mdot
.70558 .53478 Mdot
.55004 .21508 Mdot
.39501 .38528 Mdot
.47275 .65861 Mdot
.54302 .38403 Mdot
.54384 .37387 Mdot
.35236 .4313 Mdot
.65005 .52274 Mdot
.3697 .41486 Mdot
.58707 .60723 Mdot
.45688 .6919 Mdot
.52889 .57754 Mdot
.86198 .55311 Mdot
.1993 .42837 Mdot
.67316 .47311 Mdot
.34822 .39934 Mdot
.50903 .44713 Mdot
.51838 .36921 Mdot
.36363 .42858 Mdot
.682 .45767 Mdot
.69531 .4711 Mdot
.70622 .52215 Mdot
.35264 .52427 Mdot
.34306 .36533 Mdot
.64438 .53623 Mdot
.64376 .49858 Mdot
.49579 .61122 Mdot
.53335 .60319 Mdot
.73303 .52883 Mdot
.37582 .70962 Mdot
.35008 .56692 Mdot
.36213 .39612 Mdot
.25722 .74699 Mdot
.53728 .39657 Mdot
.70922 .56965 Mdot
.55549 .6292 Mdot
.55721 .10514 Mdot
.47312 .58771 Mdot
.50567 .6602 Mdot
.67523 .46853 Mdot
.34599 .57771 Mdot
.35848 .55329 Mdot
.70555 .49393 Mdot
.7396 .5008 Mdot
.32677 .5397 Mdot
.23035 .48899 Mdot
.2352 .31841 Mdot
.726 .41055 Mdot
.69661 .48126 Mdot
.64154 .59708 Mdot
.50603 .37589 Mdot
.72522 .52117 Mdot
.54538 .39724 Mdot
.37189 .3779 Mdot
.35479 .35198 Mdot
.54045 .40505 Mdot
.49044 .62062 Mdot
.38651 .37091 Mdot
.56138 .56216 Mdot
.21821 .3947 Mdot
.23003 .63216 Mdot
.61595 .23035 Mdot
.56006 .6341 Mdot
.69668 .33567 Mdot
.66731 .3016 Mdot
.52862 .64298 Mdot
.52843 .73455 Mdot
.34619 .54875 Mdot
.71819 .52933 Mdot
.50992 .37864 Mdot
.1597 .52814 Mdot
.49061 .6453 Mdot
.68016 .4814 Mdot
.5154 .37544 Mdot
.44209 .38022 Mdot
.64609 .42848 Mdot
.48494 .6145 Mdot
.24455 .22642 Mdot
.7088 .53669 Mdot
.40095 .37503 Mdot
.80047 .41277 Mdot
.72701 .5023 Mdot
.36033 .48097 Mdot
.40679 .36128 Mdot
.33898 .23553 Mdot
.70985 .48481 Mdot
.34053 .4301 Mdot
.69319 .50046 Mdot
.33834 .56559 Mdot
.71931 .46777 Mdot
.35347 .39742 Mdot
.50953 .67128 Mdot
.35069 .38772 Mdot
.34747 .56827 Mdot
.33879 .36183 Mdot
.50883 .37878 Mdot
.53429 .24666 Mdot
.52626 .36598 Mdot
.42968 .45817 Mdot
.73549 .70904 Mdot
.55758 .3677 Mdot
.37852 .32261 Mdot
.55681 .61245 Mdot
.63234 .52334 Mdot
.40051 .36991 Mdot
.3315 .40146 Mdot
.45409 .44472 Mdot
.68682 .4857 Mdot
.3543 .3952 Mdot
.68731 .5935 Mdot
.82834 .36792 Mdot
.53392 .55439 Mdot
.32633 .71362 Mdot
.70053 .48643 Mdot
.40676 .37165 Mdot
.73118 .4031 Mdot
.69585 .53277 Mdot
.39033 .36144 Mdot
.53895 .35128 Mdot
.53627 .38711 Mdot
.48347 .62949 Mdot
.56933 .33774 Mdot
.39227 .40878 Mdot
.61067 .27223 Mdot
.66908 .52589 Mdot
.44401 .38381 Mdot
.32495 .55514 Mdot
.37741 .37693 Mdot
.51936 .71392 Mdot
.7414 .50493 Mdot
.32918 .36915 Mdot
.25188 .61812 Mdot
.29716 .78082 Mdot
.35425 .39354 Mdot
.66777 .52388 Mdot
.67056 .48941 Mdot
.58264 .65733 Mdot
.48221 .45142 Mdot
.3714 .41257 Mdot
.50975 .25804 Mdot
.43362 .75779 Mdot
.54773 .23202 Mdot
.74375 .28886 Mdot
.54964 .61798 Mdot
.52814 .6212 Mdot
.51788 .36467 Mdot
.52129 .66015 Mdot
.64777 .48265 Mdot
.55406 .67137 Mdot
.51192 .36104 Mdot
.34772 .39498 Mdot
.50257 .68019 Mdot
.36328 .55401 Mdot
.50579 .38208 Mdot
.52907 .4069 Mdot
.3619 .37175 Mdot
.70454 .52222 Mdot
.33455 .29239 Mdot
.35397 .35975 Mdot
.54292 .62674 Mdot
.538 .2378 Mdot
.47016 .6373 Mdot
.24081 .55491 Mdot
.67556 .53329 Mdot
.39868 .38222 Mdot
.72031 .49785 Mdot
.5282 .36975 Mdot
.34394 .4237 Mdot
.51229 .65279 Mdot
.3843 .35709 Mdot
.28187 .54852 Mdot
.23285 .51882 Mdot
.64393 .51322 Mdot
.36296 .58822 Mdot
.65249 .51938 Mdot
.54775 .23057 Mdot
.30426 .61125 Mdot
.33912 .54563 Mdot
.3804 .38652 Mdot
.1927 .43844 Mdot
.38086 .35113 Mdot
.52013 .66975 Mdot
.5353 .66327 Mdot
.38126 .40377 Mdot
.36653 .54098 Mdot
.67272 .79082 Mdot
.50747 .51317 Mdot
.71146 .50209 Mdot
.77235 .48851 Mdot
.19735 .6746 Mdot
.49561 .37365 Mdot
.52567 .35313 Mdot
.50136 .57113 Mdot
.50143 .59601 Mdot
.51396 .40368 Mdot
.56522 .35452 Mdot
.36377 .52554 Mdot
.35239 .35558 Mdot
.62419 .49857 Mdot
.50351 .38749 Mdot
.41958 .5914 Mdot
.47073 .76833 Mdot
.58454 .64701 Mdot
.45249 .65655 Mdot
.56435 .63344 Mdot
.41039 .47197 Mdot
.55419 .34438 Mdot
.51707 .63796 Mdot
.46727 .58915 Mdot
.5483 .35162 Mdot
.34116 .56585 Mdot
.61891 .53719 Mdot
.35677 .38357 Mdot
.7141 .20589 Mdot
.49104 .67607 Mdot
.5135 .67473 Mdot
.54832 .38459 Mdot
.71277 .26171 Mdot
.67969 .47414 Mdot
.69027 .52946 Mdot
.37886 .3709 Mdot
.4533 .44152 Mdot
.5429 .67868 Mdot
.52522 .64198 Mdot
.37435 .38698 Mdot
.53617 .24881 Mdot
.59073 .22277 Mdot
.50672 .63425 Mdot
.52226 .3816 Mdot
.4125 .42822 Mdot
.55564 .34505 Mdot
.47815 .62319 Mdot
.52311 .66863 Mdot
.54309 .67608 Mdot
.50616 .59261 Mdot
.52742 .40499 Mdot
.5223 .64435 Mdot
.50051 .71607 Mdot
.69917 .51884 Mdot
.5484 .63629 Mdot
.42765 .73772 Mdot
.49963 .63759 Mdot
.36127 .55765 Mdot
.35477 .27023 Mdot
.48669 .64659 Mdot
.54687 .63576 Mdot
.50754 .50971 Mdot
.50007 .66718 Mdot
.54162 .39531 Mdot
.67496 .49124 Mdot
.52178 .37362 Mdot
.56448 .36657 Mdot
.34051 .41139 Mdot
.3662 .52744 Mdot
.48665 .69162 Mdot
.32338 .55775 Mdot
.48347 .69877 Mdot
.47442 .6241 Mdot
.33469 .43237 Mdot
.70586 .39589 Mdot
.31828 .50069 Mdot
.50981 .65011 Mdot
.37436 .37254 Mdot
.39853 .37374 Mdot
.27667 .63738 Mdot
.58359 .58015 Mdot
.5132 .40158 Mdot
.5368 .35347 Mdot
.36022 .66697 Mdot
.65675 .43103 Mdot
.35637 .56318 Mdot
.54063 .44713 Mdot
.56224 .62556 Mdot
.5045 .62662 Mdot
.57493 .63338 Mdot
.34938 .41428 Mdot
.54224 .25632 Mdot
.34314 .38617 Mdot
.56349 .22408 Mdot
.55257 .34099 Mdot
.55787 .64032 Mdot
.21308 .60731 Mdot
.64945 .4945 Mdot
.6743 .49224 Mdot
.49759 .39245 Mdot
.35971 .41351 Mdot
.57336 .67735 Mdot
.86859 .55224 Mdot
.69484 .5487 Mdot
.36624 .5721 Mdot
.52679 .63946 Mdot
.36574 .37103 Mdot
.64765 .49327 Mdot
.31626 .54741 Mdot
.55157 .65099 Mdot
.32337 .37778 Mdot
.49787 .64335 Mdot
.61721 .72206 Mdot
.70267 .5142 Mdot
.41509 .16942 Mdot
.64367 .51751 Mdot
.50347 .37661 Mdot
.55901 .35716 Mdot
.52683 .67091 Mdot
.84485 .49277 Mdot
.69418 .54296 Mdot
.5414 .32839 Mdot
.36346 .56832 Mdot
.55418 .24768 Mdot
.37332 .55034 Mdot
.39586 .39873 Mdot
.3484 .54314 Mdot
.36189 .3494 Mdot
.36137 .68221 Mdot
.66817 .54982 Mdot
.33944 .53823 Mdot
.67804 .23639 Mdot
.51786 .69859 Mdot
.35472 .51913 Mdot
.47459 .70787 Mdot
.76476 .47594 Mdot
.37089 .38612 Mdot
.36604 .5423 Mdot
.50532 .61147 Mdot
.17211 .55126 Mdot
.56196 .36146 Mdot
.51469 .40136 Mdot
.49345 .69757 Mdot
.37909 .34704 Mdot
.73874 .49525 Mdot
.40429 .50972 Mdot
.54589 .21272 Mdot
.5234 .64245 Mdot
.55837 .64062 Mdot
.66069 .5343 Mdot
.63937 .48618 Mdot
.52621 .66795 Mdot
.66685 .6051 Mdot
.5269 .65213 Mdot
.53872 .38919 Mdot
.69026 .47153 Mdot
.67066 .49155 Mdot
.38868 .41444 Mdot
.64904 .51987 Mdot
.45088 .64088 Mdot
.55959 .40864 Mdot
.53875 .5775 Mdot
.53329 .37058 Mdot
.46111 .48575 Mdot
.33448 .37078 Mdot
.16801 .5096 Mdot
.65388 .5306 Mdot
.54202 .63365 Mdot
.65419 .52197 Mdot
.32872 .54201 Mdot
.67048 .51013 Mdot
.71353 .47458 Mdot
.54037 .66298 Mdot
.48466 .61373 Mdot
.53457 .23892 Mdot
.47822 .44826 Mdot
.68893 .51942 Mdot
.53026 .64916 Mdot
.46149 .62624 Mdot
.49171 .68596 Mdot
.50606 .47596 Mdot
.68848 .46812 Mdot
.74958 .60166 Mdot
.23411 .58498 Mdot
.69324 .51522 Mdot
.15419 .57692 Mdot
.55004 .22324 Mdot
.54942 .25535 Mdot
.49945 .36283 Mdot
.5048 .6321 Mdot
.3574 .40818 Mdot
.48012 .65107 Mdot
.54611 .55902 Mdot
.48616 .66203 Mdot
.36189 .56626 Mdot
.47566 .68539 Mdot
.55072 .23989 Mdot
.35108 .3633 Mdot
.54767 .64475 Mdot
.49592 .67642 Mdot
.54091 .25892 Mdot
.64667 .5262 Mdot
.70302 .47496 Mdot
.31348 .27858 Mdot
.33188 .55241 Mdot
.54709 .36592 Mdot
.4866 .62984 Mdot
.37635 .37211 Mdot
.34902 .38347 Mdot
.6595 .52568 Mdot
.35955 .38939 Mdot
.53151 .39567 Mdot
.51358 .65731 Mdot
.51794 .40383 Mdot
.35953 .56727 Mdot
.66634 .52278 Mdot
.48558 .6313 Mdot
.49555 .61195 Mdot
.70406 .5053 Mdot
.55722 .6129 Mdot
.3594 .5249 Mdot
.359 .35288 Mdot
.70337 .47711 Mdot
.54039 .36514 Mdot
.38304 .41893 Mdot
.50357 .60453 Mdot
.34539 .80332 Mdot
.52416 .65864 Mdot
.49801 .62107 Mdot
.20999 .35763 Mdot
.4972 .57456 Mdot
.40516 .38222 Mdot
.67938 .53784 Mdot
.55745 .67799 Mdot
.44141 .77729 Mdot
.47062 .18432 Mdot
.3579 .42808 Mdot
.53279 .63677 Mdot
.1705 .49174 Mdot
.54046 .63853 Mdot
.445 .36828 Mdot
.35498 .45123 Mdot
.38024 .77412 Mdot
.45241 .6632 Mdot
.54597 .39952 Mdot
.53369 .23908 Mdot
.39791 .36173 Mdot
.63958 .74577 Mdot
.54029 .65387 Mdot
.62449 .76339 Mdot
.5098 .68913 Mdot
.53389 .38903 Mdot
.4852 .72972 Mdot
.36118 .39488 Mdot
.79956 .46471 Mdot
.53797 .62208 Mdot
.68762 .46874 Mdot
.3651 .42502 Mdot
.55694 .23629 Mdot
.5017 .61206 Mdot
.328 .56632 Mdot
.5876 .41168 Mdot
.45011 .67359 Mdot
.53592 .36986 Mdot
.513 .62635 Mdot
.56379 .57801 Mdot
.82799 .47365 Mdot
.7044 .51471 Mdot
.52942 .35131 Mdot
.71908 .3137 Mdot
.55682 .60893 Mdot
.70823 .48224 Mdot
.67908 .49232 Mdot
.33318 .56536 Mdot
.58682 .43402 Mdot
.57038 .30906 Mdot
.24928 .6709 Mdot
.71123 .71595 Mdot
.39631 .40683 Mdot
.63214 .26873 Mdot
.53969 .60733 Mdot
.53162 .52377 Mdot
.54592 .39404 Mdot
.51025 .6736 Mdot
.7473 .68522 Mdot
.67601 .52007 Mdot
.50669 .63792 Mdot
.34535 .56548 Mdot
.58427 .42478 Mdot
.56671 .49913 Mdot
.27109 .73678 Mdot
.35529 .42424 Mdot
.56934 .60285 Mdot
.46454 .68659 Mdot
.55325 .21847 Mdot
.48214 .6104 Mdot
.40057 .36653 Mdot
.22511 .40633 Mdot
.36781 .54413 Mdot
.64646 .5045 Mdot
.55126 .2239 Mdot
.56462 .64763 Mdot
.47031 .66053 Mdot
.37879 .55307 Mdot
.51616 .61493 Mdot
.80217 .44537 Mdot
.54367 .27905 Mdot
.38941 .37541 Mdot
.71057 .51306 Mdot
.56517 .626 Mdot
.5424 .25593 Mdot
.53888 .66266 Mdot
.64966 .56414 Mdot
.5292 .62632 Mdot
.608 .39665 Mdot
.69894 .50768 Mdot
.53358 .36675 Mdot
.49835 .70131 Mdot
.49002 .65899 Mdot
.31625 .45061 Mdot
.54469 .55898 Mdot
.5024 .6823 Mdot
.64886 .47214 Mdot
.65682 .48627 Mdot
.65399 .50711 Mdot
.38758 .36782 Mdot
.71367 .40721 Mdot
.52863 .37997 Mdot
.52911 .68906 Mdot
.50377 .38795 Mdot
.45171 .57054 Mdot
.37527 .56349 Mdot
.18109 .60734 Mdot
.55111 .64392 Mdot
.65661 .50627 Mdot
.60711 .29228 Mdot
.6668 .47015 Mdot
.32654 .35497 Mdot
.51702 .38188 Mdot
.67907 .51633 Mdot
.49718 .65993 Mdot
.50102 .45236 Mdot
.3061 .75981 Mdot
.52118 .36593 Mdot
.57521 .62088 Mdot
.3498 .4227 Mdot
.33941 .35532 Mdot
.14864 .61266 Mdot
.55464 .34924 Mdot
.66446 .29643 Mdot
.53332 .64715 Mdot
.64963 .49605 Mdot
.55579 .3741 Mdot
.55397 .39252 Mdot
.36877 .38874 Mdot
.48144 .62185 Mdot
.49103 .65117 Mdot
.54469 .22221 Mdot
.53833 .3556 Mdot
.53128 .69826 Mdot
.4805 .60646 Mdot
.19474 .39577 Mdot
.62187 .53374 Mdot
.73875 .25107 Mdot
.58657 .60604 Mdot
.71034 .72281 Mdot
.45234 .46811 Mdot
.6707 .47304 Mdot
.48196 .63737 Mdot
.5691 .64052 Mdot
.39884 .40122 Mdot
.51839 .65716 Mdot
.34427 .4016 Mdot
.52332 .35407 Mdot
.18853 .62325 Mdot
.46025 .36272 Mdot
.22752 .46984 Mdot
.51784 .66453 Mdot
.61717 .4612 Mdot
.34084 .53228 Mdot
.51628 .41444 Mdot
.67126 .48016 Mdot
.56238 .61043 Mdot
.40451 .3534 Mdot
.38093 .38768 Mdot
.67918 .49961 Mdot
.66567 .3212 Mdot
.29507 .32897 Mdot
.49931 .59347 Mdot
.3944 .39055 Mdot
.47039 .33275 Mdot
.66864 .61628 Mdot
.57694 .35982 Mdot
.36868 .54841 Mdot
.34824 .39484 Mdot
.53494 .40795 Mdot
.64996 .55981 Mdot
.68361 .50706 Mdot
.67962 .54101 Mdot
.28166 .49743 Mdot
.36649 .41196 Mdot
.35258 .53273 Mdot
.69795 .42125 Mdot
.73392 .42886 Mdot
.36497 .56245 Mdot
.34781 .39593 Mdot
.65208 .48876 Mdot
.6757 .4811 Mdot
.67556 .49007 Mdot
.79785 .46718 Mdot
.67677 .53188 Mdot
.76318 .56776 Mdot
.46251 .62838 Mdot
.62854 .61719 Mdot
.53827 .63798 Mdot
.53296 .40271 Mdot
.70357 .5126 Mdot
.45628 .45363 Mdot
.53614 .58996 Mdot
.27378 .73511 Mdot
.52182 .63947 Mdot
.5746 .38905 Mdot
.50246 .63221 Mdot
.64998 .58046 Mdot
.7064 .5346 Mdot
.51173 .64987 Mdot
.57142 .35697 Mdot
.34437 .55513 Mdot
.63692 .47058 Mdot
.48708 .64755 Mdot
.62233 .41125 Mdot
.47363 .5849 Mdot
.22236 .39381 Mdot
.39907 .5284 Mdot
.36059 .57477 Mdot
.45617 .6054 Mdot
.3837 .42227 Mdot
.6971 .44825 Mdot
.62064 .62394 Mdot
.52226 .36495 Mdot
.60703 .79189 Mdot
.3823 .38364 Mdot
.48746 .7308 Mdot
.50391 .58324 Mdot
.34968 .52214 Mdot
.71033 .45439 Mdot
.54698 .3896 Mdot
.5583 .63273 Mdot
.48753 .67839 Mdot
.263 .567 Mdot
.62398 .60713 Mdot
.49493 .6919 Mdot
.37371 .53219 Mdot
.75569 .60403 Mdot
.49379 .63163 Mdot
.32801 .40379 Mdot
.70211 .53323 Mdot
.47085 .68489 Mdot
.74691 .59725 Mdot
.53229 .65016 Mdot
.67725 .5113 Mdot
.65778 .53434 Mdot
.6261 .34604 Mdot
.3568 .57511 Mdot
.52872 .62612 Mdot
.37837 .50326 Mdot
.53393 .62263 Mdot
.52857 .38359 Mdot
.47577 .64085 Mdot
.37523 .38107 Mdot
.72865 .39989 Mdot
.3798 .3595 Mdot
.478 .64446 Mdot
.68019 .48472 Mdot
.55213 .38687 Mdot
.26119 .52358 Mdot
.33799 .44806 Mdot
.76366 .57227 Mdot
.5106 .17998 Mdot
.35864 .52965 Mdot
.34326 .51697 Mdot
.52809 .33898 Mdot
.50789 .64661 Mdot
.38403 .47439 Mdot
.47081 .59804 Mdot
.49892 .63218 Mdot
.48461 .66217 Mdot
.57097 .33714 Mdot
.51871 .37411 Mdot
.35199 .38068 Mdot
.52576 .66674 Mdot
.52847 .64895 Mdot
.69029 .51277 Mdot
.34183 .55506 Mdot
.38788 .36392 Mdot
.33196 .54473 Mdot
.36087 .36095 Mdot
.1397 .54187 Mdot
.58333 .61582 Mdot
.34529 .55655 Mdot
.535 .33582 Mdot
.65795 .5172 Mdot
.52983 .24196 Mdot
.39254 .40498 Mdot
.35982 .39647 Mdot
.52541 .64348 Mdot
.66678 .51945 Mdot
.67762 .52579 Mdot
.33542 .53025 Mdot
.55083 .36104 Mdot
.47872 .64513 Mdot
.48849 .60512 Mdot
.28297 .67677 Mdot
.36553 .41978 Mdot
.68766 .6052 Mdot
.63946 .35494 Mdot
.50744 .64754 Mdot
.70222 .52001 Mdot
.50931 .68154 Mdot
.18281 .52261 Mdot
.71321 .51457 Mdot
.50739 .59021 Mdot
.68645 .43043 Mdot
.33959 .40631 Mdot
.60593 .3501 Mdot
.4655 .65799 Mdot
.44727 .17488 Mdot
.53445 .61127 Mdot
.17975 .36566 Mdot
.66372 .25848 Mdot
.55682 .66516 Mdot
.52664 .59466 Mdot
.27729 .70975 Mdot
.5373 .64459 Mdot
.5514 .23275 Mdot
.58726 .60112 Mdot
.69851 .4716 Mdot
.40828 .48664 Mdot
.33304 .33935 Mdot
.35772 .57278 Mdot
.37947 .37099 Mdot
.30751 .58401 Mdot
.33759 .56413 Mdot
.70036 .48279 Mdot
.52208 .59208 Mdot
.4766 .75831 Mdot
.3314 .35235 Mdot
.48585 .58948 Mdot
.52852 .38488 Mdot
.32496 .34771 Mdot
.3384 .38843 Mdot
.53582 .3627 Mdot
.51867 .68845 Mdot
.49496 .80018 Mdot
.30978 .41691 Mdot
.32108 .23551 Mdot
.55051 .38144 Mdot
.52931 .39103 Mdot
.75402 .41181 Mdot
.35647 .5731 Mdot
.26279 .58315 Mdot
.60149 .50276 Mdot
.51634 .38981 Mdot
.36388 .64235 Mdot
.39333 .35132 Mdot
.61996 .42327 Mdot
.71861 .52864 Mdot
.58222 .62093 Mdot
.49479 .65968 Mdot
.55067 .357 Mdot
.49901 .75289 Mdot
.78246 .40497 Mdot
.5256 .36519 Mdot
.4838 .70372 Mdot
.58258 .43012 Mdot
.53913 .23354 Mdot
.5439 .22023 Mdot
.36946 .56502 Mdot
.28642 .33916 Mdot
.69703 .49846 Mdot
.34254 .52161 Mdot
.60233 .38301 Mdot
.52268 .62411 Mdot
.53081 .35592 Mdot
.52869 .24256 Mdot
.54171 .37763 Mdot
.35565 .55799 Mdot
.36709 .57154 Mdot
.7003 .51812 Mdot
.67955 .47447 Mdot
.70431 .73342 Mdot
.3795 .68203 Mdot
.54378 .64052 Mdot
.56603 .77716 Mdot
.66476 .52578 Mdot
.61462 .59441 Mdot
.33485 .57371 Mdot
.34065 .55738 Mdot
.63869 .69066 Mdot
.49233 .61088 Mdot
.44389 .39377 Mdot
.48901 .64049 Mdot
.30244 .61766 Mdot
.51654 .58391 Mdot
.36494 .38873 Mdot
.5496 .62658 Mdot
.3466 .28522 Mdot
.54656 .6053 Mdot
.49338 .67713 Mdot
.34329 .37334 Mdot
.56185 .68682 Mdot
.37666 .38224 Mdot
.4789 .62381 Mdot
.37164 .52333 Mdot
.37644 .3718 Mdot
.34721 .72848 Mdot
.49785 .49965 Mdot
.54614 .25236 Mdot
.34851 .57044 Mdot
.32378 .55456 Mdot
.44614 .75722 Mdot
.67573 .47814 Mdot
.64817 .55321 Mdot
.50804 .64564 Mdot
.39601 .35469 Mdot
.5171 .36486 Mdot
.52859 .65027 Mdot
.5707 .62364 Mdot
.47651 .67847 Mdot
.67966 .52088 Mdot
.36105 .41308 Mdot
.34996 .55337 Mdot
.396 .38179 Mdot
.29573 .41557 Mdot
.35759 .34829 Mdot
.48136 .57612 Mdot
.56998 .66604 Mdot
.56241 .54852 Mdot
.61469 .77513 Mdot
.79277 .48884 Mdot
.68348 .50197 Mdot
.54051 .2463 Mdot
.37235 .56578 Mdot
.76936 .49577 Mdot
.6589 .49408 Mdot
.35953 .40048 Mdot
.49773 .64357 Mdot
.49858 .7127 Mdot
.58227 .49624 Mdot
.7394 .46573 Mdot
.41899 .75374 Mdot
.33932 .36653 Mdot
.54468 .23187 Mdot
.72617 .40783 Mdot
.75569 .4745 Mdot
.44739 .45387 Mdot
.49352 .67096 Mdot
.32745 .56656 Mdot
.64758 .49344 Mdot
.28106 .51494 Mdot
.54427 .35338 Mdot
.48151 .45027 Mdot
.51796 .6632 Mdot
.6261 .28536 Mdot
.68078 .48505 Mdot
.34937 .56568 Mdot
.55074 .3563 Mdot
.35123 .57624 Mdot
.54781 .2195 Mdot
.30278 .28578 Mdot
.52383 .6151 Mdot
.51349 .68516 Mdot
.54303 .33163 Mdot
.69522 .497 Mdot
.39978 .45416 Mdot
.25699 .5622 Mdot
.39112 .39465 Mdot
.37596 .4682 Mdot
.66698 .47343 Mdot
.71561 .55887 Mdot
.39389 .37555 Mdot
.497 .39169 Mdot
.41179 .4749 Mdot
.52015 .35174 Mdot
.48635 .64324 Mdot
.66187 .50325 Mdot
.55201 .34668 Mdot
.31382 .46328 Mdot
.16068 .47428 Mdot
.63594 .56904 Mdot
.55598 .64052 Mdot
.18849 .61839 Mdot
.21507 .3729 Mdot
.48146 .74719 Mdot
.50653 .37417 Mdot
.52765 .67433 Mdot
.49493 .59441 Mdot
.54189 .62348 Mdot
.53432 .34479 Mdot
.26725 .42251 Mdot
.36903 .39647 Mdot
.52324 .63597 Mdot
.32478 .55178 Mdot
.36662 .38007 Mdot
.38984 .42255 Mdot
.39067 .35462 Mdot
.71465 .47804 Mdot
.50683 .59151 Mdot
.66801 .39756 Mdot
.17013 .38344 Mdot
.5214 .37219 Mdot
.54677 .25187 Mdot
.51035 .68732 Mdot
.79685 .62095 Mdot
.65432 .50656 Mdot
.38918 .39726 Mdot
.51215 .67501 Mdot
.29094 .43272 Mdot
.56391 .24654 Mdot
.35132 .35918 Mdot
.67736 .47917 Mdot
.47731 .74379 Mdot
.51942 .65642 Mdot
.53077 .61041 Mdot
.7 .49278 Mdot
.32033 .26387 Mdot
.71219 .39913 Mdot
.50086 .67885 Mdot
.53349 .36538 Mdot
.8357 .41206 Mdot
.47569 .67477 Mdot
.73991 .51486 Mdot
.55421 .24832 Mdot
.62768 .39217 Mdot
.68928 .61005 Mdot
.52359 .55942 Mdot
.20198 .61935 Mdot
.42578 .69997 Mdot
.17061 .60243 Mdot
.30661 .54125 Mdot
.44727 .30505 Mdot
.13167 .52089 Mdot
.57206 .35661 Mdot
.62285 .59167 Mdot
.3438 .75958 Mdot
.67895 .34131 Mdot
.40203 .52948 Mdot
.48181 .21057 Mdot
.32902 .4518 Mdot
.58716 .17814 Mdot
.38743 .35693 Mdot
.28646 .61511 Mdot
.47877 .65037 Mdot
.22496 .36019 Mdot
.66558 .59159 Mdot
.81094 .43819 Mdot
.16748 .58415 Mdot
.38926 .51702 Mdot
.3289 .77026 Mdot
.17737 .49003 Mdot
.51679 .78215 Mdot
.58883 .47973 Mdot
.51921 .25906 Mdot
.7123 .42134 Mdot
.32501 .6031 Mdot
.59064 .62922 Mdot
.37358 .26477 Mdot
.25435 .37012 Mdot
.76585 .62418 Mdot
.82892 .44301 Mdot
.40021 .39401 Mdot
.70629 .53114 Mdot
.28014 .67993 Mdot
.65875 .45314 Mdot
.553 .42007 Mdot
.20226 .62062 Mdot
.1862 .4021 Mdot
.65298 .58021 Mdot
.4825 .16272 Mdot
.64316 .72351 Mdot
.72289 .75205 Mdot
.52036 .48992 Mdot
.66611 .54104 Mdot
.46418 .27938 Mdot
.73489 .42961 Mdot
.53859 .29566 Mdot
.76889 .51501 Mdot
.32474 .58028 Mdot
.37479 .73163 Mdot
.68182 .48086 Mdot
.68087 .619 Mdot
.55958 .24393 Mdot
.5966 .35042 Mdot
.34547 .43674 Mdot
.18486 .54084 Mdot
.55084 .19562 Mdot
.63392 .41145 Mdot
.60793 .26111 Mdot
.33043 .79756 Mdot
.3909 .64574 Mdot
.1956 .48962 Mdot
.53851 .31441 Mdot
.41717 .67523 Mdot
.72501 .3788 Mdot
.39507 .69527 Mdot
.75283 .44171 Mdot
.45217 .8331 Mdot
.2488 .31547 Mdot
.3693 .80506 Mdot
.64281 .46955 Mdot
.49737 .69203 Mdot
.20877 .56026 Mdot
.71262 .71145 Mdot
.35939 .57643 Mdot
.3029 .76715 Mdot
.3231 .56498 Mdot
.63622 .47763 Mdot
.67423 .32874 Mdot
.73547 .55317 Mdot
.37096 .3217 Mdot
.35662 .51195 Mdot
.45532 .61764 Mdot
.63624 .84872 Mdot
.21577 .64856 Mdot
.62876 .36014 Mdot
.19352 .39311 Mdot
.53071 .32499 Mdot
.43415 .43011 Mdot
.52455 .35196 Mdot
.14581 .49215 Mdot
.66475 .49093 Mdot
.14709 .41583 Mdot
.15539 .46473 Mdot
.76824 .34598 Mdot
.74581 .79328 Mdot
.60305 .21038 Mdot
.6326 .61653 Mdot
.48089 .76901 Mdot
.40486 .76384 Mdot
.75181 .38548 Mdot
.75633 .32459 Mdot
.58722 .34621 Mdot
.30603 .26781 Mdot
.1466 .52905 Mdot
.34181 .63664 Mdot
.24132 .39845 Mdot
.69591 .34978 Mdot
.49251 .48958 Mdot
.72883 .53059 Mdot
.47721 .51139 Mdot
.56132 .52569 Mdot
.3447 .78684 Mdot
.77717 .64639 Mdot
.85848 .50438 Mdot
.29576 .55231 Mdot
.72532 .27649 Mdot
.20702 .41794 Mdot
.32948 .70906 Mdot
.75775 .52272 Mdot
.67094 .37257 Mdot
.47303 .58328 Mdot
.7014 .40537 Mdot
.5329 .72481 Mdot
.36043 .59049 Mdot
.74229 .41184 Mdot
.43351 .34173 Mdot
.29808 .59689 Mdot
.23799 .6413 Mdot
.63451 .44416 Mdot
.71399 .4813 Mdot
.41627 .71382 Mdot
.37892 .64279 Mdot
.19803 .39955 Mdot
.71672 .31285 Mdot
.30795 .24787 Mdot
.73516 .32035 Mdot
.46891 .59928 Mdot
.61744 .59442 Mdot
.58233 .66291 Mdot
.3906 .67493 Mdot
.45921 .62767 Mdot
.60207 .27383 Mdot
.19953 .37038 Mdot
.75477 .6782 Mdot
.30811 .59372 Mdot
.58984 .78071 Mdot
.28325 .28034 Mdot
.21795 .57126 Mdot
.66263 .26501 Mdot
.58366 .71174 Mdot
.55875 .85661 Mdot
.35894 .37682 Mdot
.35965 .6444 Mdot
.52814 .41028 Mdot
.27941 .50352 Mdot
.39641 .7913 Mdot
.76902 .35686 Mdot
.20279 .36386 Mdot
.68079 .37714 Mdot
.37534 .44565 Mdot
.49569 .42966 Mdot
.33914 .3263 Mdot
.57859 .78557 Mdot
.53415 .70586 Mdot
.44202 .57045 Mdot
.33616 .52283 Mdot
.71567 .69697 Mdot
.23012 .57145 Mdot
.43507 .21903 Mdot
.47118 .57563 Mdot
.43362 .2488 Mdot
.54605 .22796 Mdot
.49079 .45022 Mdot
.14477 .59999 Mdot
.56612 .57005 Mdot
.62867 .22587 Mdot
.25939 .30325 Mdot
.39895 .47392 Mdot
.207 .47725 Mdot
.64119 .32476 Mdot
.413 .82114 Mdot
.16501 .42314 Mdot
.3051 .31529 Mdot
.1918 .63216 Mdot
.31504 .21798 Mdot
.46408 .82546 Mdot
.59339 .75908 Mdot
.55937 .40265 Mdot
.16019 .32859 Mdot
.37654 .40098 Mdot
.6281 .78828 Mdot
.72116 .70493 Mdot
.27981 .44456 Mdot
.72873 .47324 Mdot
.45726 .70589 Mdot
.53698 .19701 Mdot
.68668 .54855 Mdot
.45442 .61801 Mdot
.28209 .76277 Mdot
.46835 .84294 Mdot
.29634 .77061 Mdot
.29033 .29022 Mdot
.18543 .62418 Mdot
.32041 .7381 Mdot
.76508 .56163 Mdot
.25811 .62011 Mdot
.47618 .63439 Mdot
.34086 .65789 Mdot
.61137 .21752 Mdot
.36623 .45001 Mdot
.55937 .29371 Mdot
.70862 .46453 Mdot
.41514 .81192 Mdot
.15226 .6316 Mdot
.6585 .68882 Mdot
.72858 .62034 Mdot
.54706 .51489 Mdot
.37917 .66921 Mdot
.41265 .58678 Mdot
.38785 .24448 Mdot
.20313 .40641 Mdot
.3344 .7551 Mdot
.35682 .62689 Mdot
.46663 .22483 Mdot
.36251 .30977 Mdot
.70751 .26641 Mdot
.17185 .52477 Mdot
.31358 .71361 Mdot
.74787 .32216 Mdot
.57238 .72952 Mdot
.77994 .392 Mdot
.3836 .22627 Mdot
.42485 .42677 Mdot
.3852 .62666 Mdot
.33284 .37181 Mdot
.34112 .64158 Mdot
.58162 .45658 Mdot
.26283 .65131 Mdot
.43395 .71731 Mdot
.33238 .63461 Mdot
.35522 .3107 Mdot
.24267 .71489 Mdot
.36443 .19183 Mdot
.54249 .82538 Mdot
.42153 .18444 Mdot
.53221 .72642 Mdot
.47476 .66474 Mdot
.23115 .33025 Mdot
.22894 .70887 Mdot
.17403 .39047 Mdot
.62503 .28071 Mdot
.30554 .46156 Mdot
.57568 .37696 Mdot
.57058 .8083 Mdot
.42733 .20193 Mdot
.182 .43392 Mdot
.77366 .46767 Mdot
.49834 .36564 Mdot
.69035 .38057 Mdot
.59743 .79192 Mdot
.51232 .78769 Mdot
.68846 .63258 Mdot
.58898 .62764 Mdot
.65285 .60803 Mdot
.69366 .53783 Mdot
.6322 .27491 Mdot
.38978 .68496 Mdot
.362 .37279 Mdot
.33782 .73252 Mdot
.46215 .55966 Mdot
.47648 .58067 Mdot
.4102 .43717 Mdot
.71729 .53853 Mdot
.63769 .76784 Mdot
.59074 .35494 Mdot
.13231 .53611 Mdot
.62618 .23974 Mdot
.42164 .66444 Mdot
.41071 .68694 Mdot
.28428 .52701 Mdot
.68634 .39879 Mdot
.52603 .34243 Mdot
.16556 .55935 Mdot
.44849 .5131 Mdot
.41547 .70802 Mdot
.65591 .60987 Mdot
.25067 .56127 Mdot
.56992 .61817 Mdot
.62853 .32975 Mdot
.78297 .57568 Mdot
.47856 .44462 Mdot
.62728 .50039 Mdot
.70875 .54537 Mdot
.5636 .15219 Mdot
.36573 .29086 Mdot
.70521 .29187 Mdot
.16952 .55853 Mdot
.51619 .35751 Mdot
.6777 .46361 Mdot
.32652 .64027 Mdot
.23795 .51851 Mdot
.78028 .60837 Mdot
.42062 .38587 Mdot
.39408 .59642 Mdot
.42009 .2158 Mdot
.19187 .62045 Mdot
.26564 .71676 Mdot
.83115 .475 Mdot
.64103 .49844 Mdot
.23646 .54957 Mdot
.24949 .54554 Mdot
.64373 .50461 Mdot
.74564 .47451 Mdot
.58929 .48803 Mdot
.16316 .60712 Mdot
.68833 .40744 Mdot
.38772 .20284 Mdot
.4076 .47573 Mdot
.28029 .42459 Mdot
.27305 .53042 Mdot
.37977 .61612 Mdot
.17265 .55816 Mdot
.67349 .62936 Mdot
.45148 .801 Mdot
.59198 .63163 Mdot
.71749 .72861 Mdot
.57476 .80864 Mdot
.51177 .48451 Mdot
.70212 .56496 Mdot
.44366 .35416 Mdot
.54432 .62908 Mdot
.32639 .79597 Mdot
.21765 .38494 Mdot
.76094 .43021 Mdot
.59443 .36712 Mdot
.51256 .60043 Mdot
.46853 .61388 Mdot
.50798 .75029 Mdot
.63426 .37578 Mdot
.51531 .83068 Mdot
.29118 .58891 Mdot
.54389 .72474 Mdot
.66396 .60304 Mdot
.63075 .22799 Mdot
.1922 .55126 Mdot
.21371 .40464 Mdot
.56069 .46229 Mdot
.61348 .22184 Mdot
.45213 .42732 Mdot
.38168 .20164 Mdot
.41132 .25673 Mdot
.30757 .72432 Mdot
.6104 .49863 Mdot
.65199 .37084 Mdot
.28992 .5166 Mdot
.49975 .68353 Mdot
.66546 .32151 Mdot
.17637 .50006 Mdot
.86121 .54651 Mdot
.72706 .37156 Mdot
.26503 .7522 Mdot
.53504 .54512 Mdot
.65599 .37885 Mdot
.41821 .80353 Mdot
.85782 .60483 Mdot
.37814 .25512 Mdot
.3342 .7766 Mdot
.47493 .42045 Mdot
.17065 .57398 Mdot
.55758 .3975 Mdot
.64794 .42692 Mdot
.59871 .77323 Mdot
.1594 .59999 Mdot
.20248 .52648 Mdot
.1843 .56502 Mdot
.54394 .75735 Mdot
.18503 .63707 Mdot
.76555 .46413 Mdot
.6026 .1769 Mdot
.34167 .42447 Mdot
.58676 .25929 Mdot
.58081 .74417 Mdot
.55843 .53934 Mdot
.3606 .63716 Mdot
.68667 .23065 Mdot
.78474 .51747 Mdot
.55331 .76271 Mdot
.31985 .67374 Mdot
.64379 .33825 Mdot
.41187 .68409 Mdot
.17334 .44963 Mdot
.58975 .17655 Mdot
.26396 .53485 Mdot
.67343 .286 Mdot
.30468 .27989 Mdot
.6302 .37484 Mdot
.41013 .28889 Mdot
.19422 .49019 Mdot
.3576 .23647 Mdot
.40316 .58923 Mdot
.60751 .13991 Mdot
.26039 .37607 Mdot
.58722 .49178 Mdot
.39084 .80904 Mdot
.2071 .40223 Mdot
.77668 .47652 Mdot
.80078 .43062 Mdot
.70596 .74393 Mdot
.36042 .68459 Mdot
.48608 .66138 Mdot
.18911 .65029 Mdot
.35771 .71969 Mdot
.32256 .77926 Mdot
.2607 .28528 Mdot
.6434 .63039 Mdot
.52206 .56253 Mdot
.41078 .3756 Mdot
.5485 .4996 Mdot
.30999 .66429 Mdot
.33783 .76871 Mdot
.67191 .76727 Mdot
.36718 .47349 Mdot
.4467 .29467 Mdot
.42362 .38505 Mdot
.59074 .68067 Mdot
.60004 .2195 Mdot
.64323 .35878 Mdot
.29778 .56682 Mdot
.34728 .30506 Mdot
.37539 .65702 Mdot
.68606 .60782 Mdot
.5057 .79052 Mdot
.75949 .36565 Mdot
.49956 .41713 Mdot
.40188 .39516 Mdot
.26048 .68288 Mdot
.2619 .35266 Mdot
.60099 .27826 Mdot
.50518 .81589 Mdot
.67252 .36755 Mdot
.28384 .62133 Mdot
.23765 .60569 Mdot
.75025 .3782 Mdot
.51394 .24861 Mdot
.53399 .79427 Mdot
.71943 .72631 Mdot
.43502 .37141 Mdot
.44169 .59812 Mdot
.14168 .54458 Mdot
.38087 .62096 Mdot
.25053 .63089 Mdot
.50671 .49883 Mdot
.73722 .66956 Mdot
.61191 .69374 Mdot
.36676 .74576 Mdot
.45681 .44175 Mdot
.60717 .85199 Mdot
.73453 .49305 Mdot
.33335 .80051 Mdot
.54348 .3619 Mdot
.82527 .53441 Mdot
.32379 .31543 Mdot
.55707 .47266 Mdot
.43876 .46733 Mdot
.62609 .33097 Mdot
.6069 .4179 Mdot
.29728 .27929 Mdot
.7776 .37967 Mdot
.36007 .34751 Mdot
.37763 .48655 Mdot
.3864 .20963 Mdot
.23996 .66047 Mdot
.54793 .68644 Mdot
.26839 .354 Mdot
.50629 .48501 Mdot
.36741 .45429 Mdot
.233 .33166 Mdot
.45448 .34775 Mdot
.48129 .69821 Mdot
.3806 .67351 Mdot
.355 .78436 Mdot
.16147 .45529 Mdot
.78444 .4238 Mdot
.53398 .7245 Mdot
.55487 .40898 Mdot
.38403 .77356 Mdot
.21615 .64095 Mdot
.44764 .38578 Mdot
.64571 .41452 Mdot
.38672 .64037 Mdot
.36216 .83788 Mdot
.46152 .8389 Mdot
.52506 .82557 Mdot
.39277 .4762 Mdot
.63752 .53311 Mdot
.79076 .63146 Mdot
.24976 .62735 Mdot
.57625 .27243 Mdot
.25474 .34762 Mdot
.36532 .64639 Mdot
.84214 .61006 Mdot
.77049 .52764 Mdot
.29248 .40884 Mdot
.61244 .69624 Mdot
.69533 .72704 Mdot
.56888 .38348 Mdot
.35033 .6875 Mdot
.41658 .52574 Mdot
.5029 .36809 Mdot
.64405 .34248 Mdot
.61707 .4183 Mdot
.25139 .63343 Mdot
.77532 .59702 Mdot
.56073 .70891 Mdot
.22549 .63215 Mdot
.6562 .54549 Mdot
.27723 .51755 Mdot
.27311 .54821 Mdot
.4026 .52025 Mdot
.3906 .38873 Mdot
.5792 .56791 Mdot
.50492 .44407 Mdot
.4663 .42472 Mdot
.61117 .81534 Mdot
.32019 .55939 Mdot
.72219 .4793 Mdot
.79604 .47756 Mdot
.64376 .48956 Mdot
.21401 .69678 Mdot
.38813 .24567 Mdot
.6589 .60067 Mdot
.297 .34018 Mdot
.46308 .25158 Mdot
.72586 .76259 Mdot
.55767 .79275 Mdot
.50216 .51492 Mdot
.76111 .48944 Mdot
.65706 .5286 Mdot
.35895 .32264 Mdot
.5234 .25217 Mdot
.70043 .62219 Mdot
.6219 .21437 Mdot
.26217 .61414 Mdot
.65562 .53575 Mdot
.28282 .40624 Mdot
.42627 .67596 Mdot
.14028 .57321 Mdot
.39693 .36474 Mdot
.53238 .85325 Mdot
.57354 .66031 Mdot
.4271 .79604 Mdot
.22576 .33771 Mdot
.7325 .39774 Mdot
.3707 .46724 Mdot
.5011 .21005 Mdot
.55413 .67384 Mdot
.57746 .69024 Mdot
.68666 .47849 Mdot
.26022 .58904 Mdot
.34429 .54519 Mdot
.40846 .73717 Mdot
.49988 .37718 Mdot
.7454 .30506 Mdot
.60567 .22809 Mdot
.71344 .52801 Mdot
.43869 .52522 Mdot
.21238 .54669 Mdot
.61321 .45177 Mdot
.50429 .48416 Mdot
.27488 .70519 Mdot
.77588 .6173 Mdot
.65614 .53481 Mdot
.50751 .81888 Mdot
.27528 .57867 Mdot
.14549 .46953 Mdot
.42461 .63656 Mdot
.53806 .49188 Mdot
.61865 .45057 Mdot
.63079 .32382 Mdot
.69526 .61111 Mdot
.20336 .41195 Mdot
.40779 .70536 Mdot
.7077 .42584 Mdot
.33233 .63659 Mdot
.53747 .71229 Mdot
.44231 .29508 Mdot
.58745 .24243 Mdot
.82922 .63285 Mdot
.62491 .72434 Mdot
.71333 .38486 Mdot
.74222 .52267 Mdot
.62647 .22464 Mdot
.72801 .48523 Mdot
.25466 .46596 Mdot
.76644 .63099 Mdot
.31083 .31929 Mdot
.14191 .51259 Mdot
.20072 .3973 Mdot
.57472 .51615 Mdot
.41534 .41693 Mdot
.4311 .70632 Mdot
.42859 .67799 Mdot
.4789 .4626 Mdot
.54821 .67794 Mdot
.56598 .7188 Mdot
.77794 .42144 Mdot
.60531 .29037 Mdot
.46343 .7113 Mdot
.15694 .57614 Mdot
.14999 .45725 Mdot
.21146 .66742 Mdot
.44324 .40352 Mdot
.71029 .47218 Mdot
.42488 .82478 Mdot
.71975 .58547 Mdot
.17194 .44728 Mdot
.58387 .7469 Mdot
.54515 .1497 Mdot
.38468 .78904 Mdot
.43609 .34808 Mdot
.76563 .33939 Mdot
.58722 .31871 Mdot
.23706 .33348 Mdot
.6014 .17656 Mdot
.36646 .60057 Mdot
.23988 .3212 Mdot
.63414 .84838 Mdot
.60699 .74741 Mdot
.62607 .41264 Mdot
.61179 .67511 Mdot
.42231 .67971 Mdot
.61793 .20398 Mdot
.47431 .64287 Mdot
.32775 .37375 Mdot
.35651 .47343 Mdot
.3739 .65009 Mdot
.49236 .55636 Mdot
.62705 .2085 Mdot
.30403 .65832 Mdot
.2843 .60965 Mdot
.24729 .53352 Mdot
.35323 .77271 Mdot
.70403 .61379 Mdot
.46794 .68892 Mdot
.62577 .4928 Mdot
.37008 .56118 Mdot
.3193 .59128 Mdot
.49534 .59929 Mdot
.37359 .46212 Mdot
.59803 .48624 Mdot
.28131 .76473 Mdot
.2475 .49455 Mdot
.22339 .46393 Mdot
.7024 .5465 Mdot
.63627 .36193 Mdot
.21251 .58185 Mdot
.67701 .33649 Mdot
.6494 .21812 Mdot
.77258 .65348 Mdot
.19591 .62729 Mdot
.67079 .3812 Mdot
.33022 .61392 Mdot
.66474 .79555 Mdot
.52443 .39919 Mdot
.64189 .76029 Mdot
.32206 .74473 Mdot
.6672 .34399 Mdot
.63597 .48491 Mdot
.41549 .32454 Mdot
.45823 .30945 Mdot
.65792 .34212 Mdot
.26285 .29965 Mdot
.2378 .5637 Mdot
.62809 .67011 Mdot
.25151 .6962 Mdot
.3538 .42093 Mdot
.35532 .62816 Mdot
.39045 .30337 Mdot
.60385 .19029 Mdot
.63549 .44045 Mdot
.14488 .55597 Mdot
.46895 .4599 Mdot
.36444 .72952 Mdot
.52789 .61412 Mdot
.7497 .59854 Mdot
.61341 .30362 Mdot
.37405 .30963 Mdot
.70589 .29944 Mdot
.71803 .49913 Mdot
.61315 .25151 Mdot
.53342 .27921 Mdot
.36141 .70091 Mdot
.4565 .55776 Mdot
.61466 .5128 Mdot
.31858 .52297 Mdot
.55905 .2188 Mdot
.54203 .69479 Mdot
.39134 .7473 Mdot
.35987 .31766 Mdot
.62059 .7653 Mdot
.60051 .75703 Mdot
.26132 .68591 Mdot
.22405 .40639 Mdot
.59421 .277 Mdot
.57467 .75903 Mdot
.60734 .38966 Mdot
.75983 .54439 Mdot
.68542 .32108 Mdot
.46319 .65362 Mdot
.25656 .46224 Mdot
.679 .46632 Mdot
.24436 .67053 Mdot
.62713 .56045 Mdot
.34356 .72533 Mdot
.52188 .46297 Mdot
.20303 .55642 Mdot
.47383 .49265 Mdot
.22756 .33822 Mdot
.58435 .31496 Mdot
.39099 .68755 Mdot
.5178 .33762 Mdot
.47458 .41756 Mdot
.732 .3688 Mdot
.15888 .51642 Mdot
.76638 .36533 Mdot
.48844 .76659 Mdot
.70145 .38081 Mdot
.7319 .70844 Mdot
.24787 .3005 Mdot
.38214 .69405 Mdot
.48111 .46283 Mdot
.41363 .60795 Mdot
.60052 .365 Mdot
.53085 .24619 Mdot
.27047 .46275 Mdot
.71448 .60014 Mdot
.2374 .44049 Mdot
.31128 .4121 Mdot
.52116 .69974 Mdot
.79998 .61335 Mdot
.23639 .67264 Mdot
.77321 .48984 Mdot
.54143 .4778 Mdot
.31315 .49241 Mdot
.36688 .70955 Mdot
.78382 .2738 Mdot
.32172 .79449 Mdot
.52632 .61349 Mdot
.4116 .47962 Mdot
.39999 .73074 Mdot
.34302 .3991 Mdot
.70213 .62963 Mdot
.2576 .6827 Mdot
.5223 .38982 Mdot
.30058 .47066 Mdot
.55142 .27871 Mdot
.61966 .32215 Mdot
.36083 .74612 Mdot
.56717 .33509 Mdot
.23547 .72362 Mdot
.26987 .33585 Mdot
.61867 .30132 Mdot
.68209 .17948 Mdot
.61512 .27375 Mdot
.65004 .54847 Mdot
.19632 .51949 Mdot
.23767 .70893 Mdot
.39619 .47583 Mdot
.28134 .49809 Mdot
.60365 .75804 Mdot
.39713 .69592 Mdot
.29803 .61006 Mdot
.67119 .2847 Mdot
.62607 .2581 Mdot
.61172 .18103 Mdot
.46393 .24971 Mdot
.62654 .81561 Mdot
.66603 .62265 Mdot
.26935 .72549 Mdot
.38051 .25132 Mdot
.84661 .59679 Mdot
.146 .49315 Mdot
.33322 .66066 Mdot
.64689 .22378 Mdot
.19947 .50142 Mdot
.43118 .75502 Mdot
.79898 .58003 Mdot
.35914 .26181 Mdot
.77488 .6338 Mdot
.45123 .24516 Mdot
.69967 .31755 Mdot
.33746 .63888 Mdot
.70938 .72163 Mdot
.46422 .45709 Mdot
.31258 .74898 Mdot
.72152 .26381 Mdot
.40512 .67467 Mdot
.31261 .47266 Mdot
.44118 .77271 Mdot
.22129 .63578 Mdot
.18714 .48993 Mdot
.46644 .47088 Mdot
.64121 .84077 Mdot
.3429 .7845 Mdot
.68836 .33739 Mdot
.4624 .63345 Mdot
.13599 .50296 Mdot
.4296 .49231 Mdot
.57466 .76264 Mdot
.24812 .33617 Mdot
.29001 .5781 Mdot
.61045 .47609 Mdot
.48185 .68506 Mdot
.54934 .79651 Mdot
.67647 .56926 Mdot
.69259 .73132 Mdot
.33724 .48707 Mdot
.41059 .69046 Mdot
.72879 .27412 Mdot
.41027 .7733 Mdot
.43267 .68324 Mdot
.67194 .47037 Mdot
.25682 .73772 Mdot
.51309 .77994 Mdot
.59102 .5751 Mdot
.62298 .6359 Mdot
.77103 .37151 Mdot
.52597 .19352 Mdot
.51984 .724 Mdot
.68284 .40037 Mdot
.36349 .63795 Mdot
.24763 .61266 Mdot
.58036 .77379 Mdot
.76322 .78082 Mdot
.21828 .34415 Mdot
.73929 .49642 Mdot
.6463 .74945 Mdot
.38305 .49732 Mdot
.21602 .66983 Mdot
.46338 .22198 Mdot
.27949 .53474 Mdot
.80582 .40086 Mdot
.42584 .73238 Mdot
.54815 .5883 Mdot
.28335 .29341 Mdot
.15135 .50142 Mdot
.74448 .28316 Mdot
.14224 .54302 Mdot
.52056 .56535 Mdot
.57699 .60454 Mdot
.8834 .48437 Mdot
.17988 .59835 Mdot
.53223 .56064 Mdot
.78793 .39608 Mdot
.72589 .46671 Mdot
.47899 .64114 Mdot
.54796 .27675 Mdot
.39116 .61976 Mdot
.29411 .61253 Mdot
.16166 .6029 Mdot
.65355 .54199 Mdot
.36988 .46321 Mdot
.53423 .40824 Mdot
.4441 .462 Mdot
.50082 .71193 Mdot
.55445 .34735 Mdot
.29395 .62391 Mdot
.41729 .49497 Mdot
.59194 .40335 Mdot
.39872 .59009 Mdot
.37162 .19456 Mdot
.58121 .55116 Mdot
.56753 .51515 Mdot
.55289 .74592 Mdot
.78672 .51487 Mdot
.30684 .66043 Mdot
.28477 .64657 Mdot
.2462 .31563 Mdot
.35926 .17355 Mdot
.31506 .34045 Mdot
.44105 .68566 Mdot
.66243 .44452 Mdot
.70268 .60213 Mdot
.62323 .66007 Mdot
.49296 .41693 Mdot
.53384 .22969 Mdot
.49594 .5729 Mdot
.42109 .66004 Mdot
.50075 .38086 Mdot
.32341 .80855 Mdot
.47011 .64072 Mdot
.65556 .6528 Mdot
.17225 .47934 Mdot
.28006 .51656 Mdot
.60463 .55967 Mdot
.5578 .66883 Mdot
.76763 .46663 Mdot
.42 .49812 Mdot
.45769 .73559 Mdot
.27091 .53832 Mdot
.22397 .67227 Mdot
.59814 .55269 Mdot
.64531 .64679 Mdot
.52023 .64061 Mdot
.35507 .51325 Mdot
.62039 .42562 Mdot
.5398 .81182 Mdot
.43796 .56479 Mdot
.16813 .44333 Mdot
.28055 .56917 Mdot
.2912 .58773 Mdot
.63309 .59868 Mdot
.32 .7797 Mdot
.72043 .36812 Mdot
.64234 .62419 Mdot
.77342 .43156 Mdot
.4172 .30166 Mdot
.32011 .67194 Mdot
.41363 .36793 Mdot
.46344 .71057 Mdot
.71755 .45866 Mdot
.16377 .62745 Mdot
.56415 .79324 Mdot
.48125 .37504 Mdot
.43155 .36855 Mdot
.74711 .556 Mdot
.44595 .46561 Mdot
.64052 .15803 Mdot
.47719 .2076 Mdot
.24026 .72876 Mdot
.24617 .5788 Mdot
.66075 .4441 Mdot
.64525 .33502 Mdot
.56382 .55765 Mdot
.34618 .37599 Mdot
.21953 .67161 Mdot
.42097 .60808 Mdot
.68361 .31003 Mdot
.47769 .62243 Mdot
.74517 .42923 Mdot
.42526 .68037 Mdot
.4247 .41082 Mdot
.33556 .35841 Mdot
.78112 .40866 Mdot
.17879 .5106 Mdot
.42152 .49914 Mdot
.5433 .16203 Mdot
.33964 .7721 Mdot
.16472 .55712 Mdot
.42259 .38768 Mdot
.8304 .5238 Mdot
.74046 .52716 Mdot
.43052 .68695 Mdot
.50894 .33922 Mdot
.48833 .77456 Mdot
.66162 .33989 Mdot
.25011 .60396 Mdot
.61098 .38673 Mdot
.59119 .46976 Mdot
.53075 .10211 Mdot
.32954 .65113 Mdot
.7545 .51798 Mdot
.65668 .31151 Mdot
.15481 .55469 Mdot
.39529 .5566 Mdot
.32452 .23304 Mdot
.36598 .27583 Mdot
.51131 .71529 Mdot
.77836 .58425 Mdot
.44997 .79535 Mdot
.47993 .32303 Mdot
.67453 .79938 Mdot
.25815 .35663 Mdot
.32122 .60038 Mdot
.37665 .30841 Mdot
.64271 .49336 Mdot
.72497 .46988 Mdot
.39133 .22975 Mdot
.44488 .16116 Mdot
.47704 .73552 Mdot
.20692 .63184 Mdot
.76503 .71537 Mdot
.2644 .58168 Mdot
.19251 .64194 Mdot
.51596 .31668 Mdot
.75197 .48462 Mdot
.29805 .65069 Mdot
.33121 .4955 Mdot
.34715 .40982 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0V?ooool2o`00
0:oooooo000Looooo`;o0000VOooool2o`000:oooooo000Looooo`03o`000?oooooooooo0:Wooooo
0_l0002Nooooo`007?ooool00ol0003oooooooooo`2Yooooo`;o00001_ooool2o`0009Kooooo000L
ooooo`03o`000?oooooooooo0;7ooooo0_l0002Fooooo`007?ooool00ol0003oooooooooo`2:oooo
o`;o0000_Oooool001cooooo00?o0000ooooooooool0R_ooool2o`0002Gooooo0_l0002Fooooo`00
7?ooool00ol0003oooooooooo`20ooooo`;o0000;oooool2o`0009Kooooo000Looooo`03o`000?oo
oooooooo083ooooo0_l00037ooooo`007?ooool00ol0003oooooooooo`2fooooo`;o0000TOooool0
01cooooo00?o0000ooooooooool0N?ooool2o`0003cooooo0_l0002Aooooo`007?ooool00ol0003o
ooooooooo`1hooooo`;o0000coooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo06kooooo0_l0001B
ooooo`;o0000QOooool001cooooo00?o0000ooooooooool0K_ooool2o`0005;ooooo0_l00025oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0:gooooo
0_l0000Hooooo`;o0000P?ooool001cooooo0_l0002^ooooo`;o00001?ooool2o`0001;ooooo0_l0
0020ooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o0000<?ooool2o`0001[ooooo0_l0002D
ooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o00009_ooool2o`0000Sooooo1?l0000aoooo
o`;o0000Noooool001cooooo00?o0000ooooooooool0SOooool2o`0000[ooooo0_l0000Booooo`;o
00007Oooool2o`0007_ooooo000Looooo`03o`000?oooooooooo08Sooooo0_l00003ooooo`Co0000
2?ooool2o`0000?ooooo0_l0000=ooooo`;o0000V_ooool001cooooo00?o0000ooooooooool0Qooo
ool3o`0000Gooooo0_l0000=ooooo`;o0000ZOooool001cooooo00?o0000ooooooooool0Poooool2
o`0000;ooooo0_l0000=ooooo`;o0000/Oooool001cooooo00?o0000ooooooooool0LOooool2o`00
013ooooo0_l00009ooooo`Co000000Coooooo`000?l0003ooooo0_l0000=ooooo`;o0000X_ooool0
01cooooo00?o0000ooooooooool0LOooool2o`0000gooooo0_l000000ooooooo0000o`000008oooo
o`Go000000?oooooo`000?l000002_ooool2o`0000Cooooo0_l0000Dooooo`?o00000_ooool2o`00
08Oooooo000Looooo`03o`000?oooooooooo083ooooo0_l0000;ooooo`;o00004?ooool2o`000003
ooooool0003o000001Oooooo0ol00002ooooo`;o000000?oooooo`000?l000005Oooool2o`0006go
oooo000Looooo`03o`000?oooooooooo08Gooooo0_l0000>ooooo`;o00002oooool2o`0000;ooooo
0_l0000Kooooo`;o00005Oooool2o`0006gooooo000Looooo`03o`000?oooooooooo07_ooooo0_l0
0008ooooo`Co00003?ooool2o`0000oooooo0_l0002Qooooo`007?ooool00ol0003oooooooooo`1k
ooooo`;o00002_ooool2o`0003Oooooo0_l00027ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^
k^h5ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0Loooool2o`000003ooooool0
003o000001Gooooo0_l0000Hooooo`;o00005oooool2o`0008Oooooo00001_ooooooMgMgoiRHV?oo
ooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`1cooooo`Go00005Oooool2o`0001Sooooo0_l00006ooooo`;o0000V?ooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`00
0?oooooooooo05Kooooo0_l0000Looooo`Co0000<oooool2o`0000;ooooo0_l0002Hooooo`0000?o
ooooo`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0
001Fooooo`;o00007?ooool2o`0000;ooooo1?l0000;ooooo`;o00008_ooool2o`0000Cooooo0_l0
002Fooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKo
oooo00Gooooo00?o0000ooooooooool0N?ooool4o`0000[ooooo0ol0000Aooooo`Co00004oooool2
o`0001;ooooo0_l0000Mooooo`;o0000Hoooool00003ooooool@413ooooo00;ooooo00?o410@oooo
ooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08Kooooo0_l00009oooo
o`;o00001?ooool2o`000003ooooool0003o000000;o00009_ooool3o`000003ooooool0003o0000
01[ooooo0_l0001Sooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`1jooooo`;o00005Oooool2o`0000Cooooo1?l0
0003ooooo`?o00003Oooool2o`000003ooooool0003o000000gooooo0_l00002ooooo`;o00000_oo
ool2o`000004ooooool0003o0000ooooo`;o00005?ooool2o`0006?ooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo
07[ooooo0_l0000Mooooo`;o00000oooool3o`0000Wooooo0_l00002ooooo`Go00003Oooool2o`00
00Cooooo0_l00003ooooo`;o000000?oooooo`000?l00000NOooool001cooooo00?o0000oooooooo
ool0Hoooool2o`00023ooooo0_l0000Hooooo`;o00002?ooool3o`000003ooooool0003o000000?o
00000oooool2o`0000cooooo0_l000000ooooooo0000o`000007ooooo`;o0000N?ooool001cooooo
00?o0000ooooooooool0Hoooool2o`00023ooooo0_l00003ooooo`;o00007?ooool<o`000003oooo
ool0003o000000Cooooo0_l00002ooooo`;o00000_ooool2o`0000[ooooo0_l0001hooooo`007?oo
ool00ol0003oooooooooo`1booooo`;o00005_ooool2o`0000Kooooo0ol0000Cooooo`go00001_oo
ool3o`000003ooooool0003o000000;ooooo0_l00003ooooo`;o00001?ooool2o`0007Wooooo000L
ooooo`03o`000?oooooooooo04cooooo0_l0000Looooo`;o00001_ooool2o`0000Gooooo0_l0000G
ooooo`Co00004_ooool=o`0000Oooooo0_l00005ooooo`;o00000oooool2o`0000Cooooo0_l00002
ooooo`;o0000MOooool001cooooo00?o0000ooooooooool0C?ooool2o`0001cooooo0_l0000=oooo
o`Co00005oooool2o`0001;ooooo2ol0000>ooooo`;o000000?oooooo`000?l000000_ooool3o`00
00Oooooo0_l00004ooooo`;o000000?oooooo`000?l00000K?ooool001cooooo00?o0000oooooooo
ool0I_ooool2o`0001?ooooo0_l0000Uooooo`;o00001?ooool=o`0000cooooo0_l000000ooooooo
0000o`000003ooooo`;o00003Oooool2o`000003ooooool0003o000006cooooo000Looooo`03o`00
0?oooooooooo06Gooooo0ol00002ooooo`;o00001?ooool2o`0001?ooooo0_l0000Iooooo`Co0000
1?ooool=o`0002?ooooo0_l0001_ooooo`007?ooool00ol0003oooooooooo`1Tooooo`?o00000ooo
ool2o`0000Cooooo0_l0000Booooo`?o00006Oooool2o`0000Kooooo1Ol000000ooooooo0000o`00
0007o`00017ooooo0_l0000>ooooo`;o0000Koooool001cooooo00?o0000ooooooooool0I?ooool2
o`0001kooooo0_l0000Rooooo`oo00001?ooool2o`0000_ooooo0_l0001oooooo`007?ooool00ol0
003oooooooooo`1Tooooo`;o00005?ooool2o`0001?ooooo0_l0000Gooooo`Oo000000?oooooo`00
0?l000000_l00007ooooo`;o00008oooool2o`0006Oooooo000Looooo`03o`000?oooooooooo063o
oooo0_l00002ooooo`;o00005?ooool2o`0000gooooo0ol00003ooooo`;o00004_ooool2o`0000?o
oooo3Ol0000Gooooo`;o00004_ooool2o`0006Oooooo000Looooo`;o0000HOooool2o`0001Kooooo
0_l0000:ooooo`;o00000oooool3o`0000Oooooo0_l0000>ooooo`;o000000?oooooo`000?l00000
3Ol0000>ooooo`;o00001oooool2o`0001kooooo0_l0001Kooooo`007?ooool00ol0003ooooooooo
o`1cooooo`;o00000_ooool3o`0000[ooooo0_l0000=ooooo`;o00003Oooool2o`0000;ooooo3?l0
000Aooooo`;o00009oooool2o`0005_ooooo000Looooo`03o`000?oooooooooo073ooooo0_l00000
0ooooooo0000o`000002ooooo`;o00002Oooool4o`0000oooooo0_l0000;ooooo`;o00001_ooool8
o`0001Kooooo0_l0000:ooooo`;o0000Loooool001cooooo00?o0000ooooooooool0L?ooool2o`00
0004ooooool0003o0000ooooo`;o00002_ooool4o`0000oooooo0_l0000;ooooo`;o000000?ooooo
o`000?l000000oooool8o`0000Wooooo0_l00005ooooo`;o00001?ooool2o`0000[ooooo0_l0000=
ooooo`;o00002_ooool2o`0005Sooooo000Looooo`03o`000?oooooooooo04;ooooo0_l0000Loooo
o`;o00000_ooool2o`0000_ooooo1?l000000ooooooo0000o`00000]ooooo`;o00000oooool7o`00
00Cooooo0_l00004ooooo`;o00001Oooool3o`0001kooooo0ol000000ooooooo0000o`000006oooo
o`;o0000F?ooool001cooooo00?o0000ooooooooool0@_ooool2o`0001cooooo0_l000001?oooooo
0000o`000?l0000;ooooo`;o00000oooool2o`0000gooooo0_l0000Wooooo`?o00001?ooool2o`00
00cooooo0_l0000>ooooo`;o000000?oooooo`000?l000002?ooool6o`000003ooooool0003o0000
063ooooo000Looooo`03o`000?oooooooooo063ooooo0_l000000ooooooo0000o`000002o`0000Wo
oooo0ol00003ooooo`;o00003Oooool2o`0002Cooooo0_l00004ooooo`;o00005Oooool4o`0000Oo
oooo1_l00007ooooo`Co0000IOooool001cooooo00?o0000ooooooooool0?oooool2o`0002Cooooo
0_l00003ooooo`;o00001?ooool2o`0003Wooooo0_l00004ooooo`?o00000oooool3o`0000Kooooo
0_l000001?oooooo0000o`000?l00002ooooo`Co00002?ooool2o`000003ooooool0003o000002;o
oooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00006_ooool2o`0000Oooooo
0_l00004ooooo`;o00001oooool2o`0003Wooooo0_l00002ooooo`;o00000oooool3o`0000?ooooo
0_l000001?oooooo0000o`000?ooool3o`000003ooooool0003o000000?o00007?ooool3o`00013o
oooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`1Kooooo`Ko000000?oooooo`000?l00000
0_l0000=ooooo`;o00007_ooool2o`0001Gooooo0_l000000ooooooo0000o`000002o`0000cooooo
1?l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l0000;ooooo`;o00003oooool3o`0005ko
oooo000Looooo`03o`000?oooooooooo05?ooooo0_l00003ooooo`;o00000oooool4o`000003oooo
ool0003o000000;ooooo0_l00005ooooo`;o00004Oooool2o`00017ooooo0_l0000Eooooo`;o0000
00?oooooo`000?l000000ol0000=ooooo`?o00001Oooool3o`0000gooooo0_l00007ooooo`;o0000
1_ooool2o`0000Cooooo0_l00006ooooo`;o0000DOooool001cooooo00?o0000ooooooooool0DOoo
ool4o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o00001Oooool2o`0000Gooooo0_l0
000Aooooo`;o0000;_ooool2o`0000kooooo0_l00005ooooo`?o00003?ooool5o`000005ooooool0
003o0000o`000?ooool00_l00006ooooo`Co00000_ooool2o`0000Kooooo0_l0001Aooooo`007?oo
ool00ol0003oooooooooo`0looooo`;o00004oooool2o`0000?ooooo0_l00003ooooo`Ko00003?oo
ool2o`0001;ooooo0_l0000Booooo`;o0000<Oooool2o`0000cooooo1Ol000001?oooooo0000o`00
0?l0000;ooooo`;o00000_ooool2o`0005Wooooo000Looooo`03o`000?oooooooooo03cooooo0_l0
000Hooooo`;o00000oooool4o`0000[ooooo0_l00008ooooo`;o00003?ooool2o`00013ooooo1?l0
000Zooooo`;o00007?ooool4o`0000_ooooo0_l0001Iooooo`007?ooool00ol0003oooooooooo`1H
ooooo`;o000000?oooooo`000?l000003?ooool2o`0000Sooooo0_l0000Gooooo`?o00001?ooool2
o`0001Gooooo0_l00006ooooo`;o00003Oooool2o`0000Oooooo0_l0000Cooooo`Co000000?ooooo
o`000?l000004oooool2o`0004kooooo000Looooo`03o`000?oooooooooo05Gooooo0_l000000ooo
oooo0000o`00000?ooooo`;o00002_ooool2o`0000oooooo0_l00004ooooo`?o00006oooool3o`00
00Gooooo0_l00009ooooo`;o00002oooool2o`0000Sooooo0_l0000;ooooo`Go00002_ooool2o`00
00Oooooo0_l0001>ooooo`007?ooool2o`0004kooooo0_l00003ooooo`;o000000?oooooo`000?l0
00006_ooool2o`0000;ooooo1?l0000;ooooo`Co00000oooool2o`0001kooooo0_l0000@ooooo`?o
00001Oooool2o`0000gooooo0ol0000:ooooo`Co00002oooool2o`0005Oooooo000Looooo`03o`00
0?oooooooooo04Wooooo0_l00002ooooo`;o00000_ooool3o`0001cooooo0ol000001?oooooo0000
o`000?ooool2o`0000;ooooo0_l00007ooooo`;o00001Oooool2o`0001gooooo1?l0000@ooooo`;o
00000oooool4o`0000kooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000006Ko
oooo000Looooo`03o`000?oooooooooo03Oooooo0_l0000@ooooo`;o00001_ooool2o`0001[ooooo
0_l000000ooooooo0000o`000002ooooo`;o00001Oooool2o`00017ooooo0_l0000Jooooo`Co0000
5Oooool2o`0000cooooo0_l00006ooooo`;o00000oooool2o`0000Oooooo0_l00005ooooo`;o0000
FOooool001cooooo00?o0000ooooooooool0=oooool2o`0003Cooooo0_l000000ooooooo0000o`00
0002o`0000;ooooo0ol0000Eooooo`;o000000?oooooo`000?l000005?ooool2o`0000gooooo0ol0
0005ooooo`Co00003oooool2o`0000Kooooo0ol0000;ooooo`;o00001Oooool2o`0000;ooooo0_l0
001Eooooo`007?ooool00ol0003oooooooooo`1Sooooo`;o00002oooool4o`0000;ooooo0ol0000H
ooooo`;o00003oooool2o`0000?ooooo0_l0000=ooooo`?o00001Oooool4o`00013ooooo0_l00006
ooooo`;o00002Oooool3o`0000[ooooo0_l000000ooooooo0000o`00001Booooo`007?ooool00ol0
003oooooooooo`1<ooooo`?o00004?ooool2o`0000;ooooo1?l0000kooooo`Co00001Oooool2o`00
00gooooo0_l00009ooooo`;o00002oooool3o`0000Cooooo1?l00008ooooo`?o00003Oooool2o`00
00gooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`19ooooo`;o000000Coooooo`000?l0
003o00004?ooool4o`0000;ooooo0_l00004ooooo`;o00001?ooool2o`00037ooooo0_l00004oooo
o`?o00003Oooool3o`0000Cooooo0_l00002ooooo`;o00001Oooool2o`0000Gooooo0ol00003oooo
o`Co00000_ooool2o`0002?ooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`19ooooo`?o
00005Oooool2o`0000Sooooo0_l00004ooooo`;o00000_ooool4o`0001_ooooo0_l00002ooooo`;o
00004?ooool2o`0000;ooooo0_l0000;ooooo`;o00001?ooool2o`0000?ooooo0_l00004ooooo`;o
00001_ooool2o`0000Cooooo0ol000001?oooooo0000o`000?l0000:ooooo`;o00000_ooool3o`00
05Oooooo000Looooo`03o`000?oooooooooo037ooooo0_l0000Gooooo`;o00007_ooool2o`0000Co
oooo0ol00002ooooo`Co00002_ooool2o`0000[ooooo0ol00002ooooo`;o00000_ooool2o`0000[o
oooo0_l00003ooooo`;o00000oooool2o`0000Cooooo0_l0000@ooooo`;o000000Coooooo`000?l0
003ooooo0_l00006ooooo`;o00001?ooool6o`0000Sooooo0_l000000ooooooo0000o`000002oooo
o`Go0000EOooool001cooooo00?o0000ooooooooool0<?ooool3o`0001Wooooo0_l0000>ooooo`;o
00003?ooool2o`0000Cooooo0_l0000Aooooo`;o00001?ooool2o`0000Cooooo0ol0000Booooo`;o
000000?oooooo`000?l000001Ol00006ooooo`;o00004oooool2o`000003ooooool0003o000000Wo
oooo0_l00004ooooo`?o00002?ooool2o`0000Sooooo0_l0001Eooooo`007?ooool00ol0003ooooo
ooooo`0`ooooo`;o00005Oooool3o`0000;ooooo0_l0000>ooooo`;o00004Oooool2o`0001Sooooo
0_l0000Fooooo`;o00000_ooool4o`000003ooooool0003o000000?o00006Oooool2o`0000gooooo
0_l0000Aooooo`;o00002?ooool2o`0005?ooooo000Looooo`03o`000?oooooooooo04Oooooo1?l0
000>ooooo`;o00005?ooool2o`0000Oooooo0_l00006ooooo`;o00004oooool2o`0000[ooooo0_l0
0002ooooo`;o00000oooool9o`000003ooooool0003o000001;ooooo0_l00004ooooo`;o00001_oo
ool2o`0000Oooooo0_l00009ooooo`;o00002?ooool2o`0000cooooo0_l00015ooooo`007?ooool0
0ol0003oooooooooo`13ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00001Ooo
ool2o`0000?ooooo0_l0000Iooooo`;o00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`00
000Cooooo`;o00003Oooool2o`0000;ooooo2ol000000ooooooo0000o`000002o`0001Gooooo0ol0
0006ooooo`Co00000_ooool2o`000003ooooool0003o000001?ooooo0_l0000<ooooo`;o0000AOoo
ool001cooooo00?o0000ooooooooool0@oooool2o`000003ooooool0003o000000Gooooo0_l00005
ooooo`;o00000oooool2o`0000;ooooo0_l00004ooooo`;o00000_ooool3o`0000Kooooo0_l00002
ooooo`;o00001oooool3o`0000Wooooo0_l00005ooooo`;o00004?ooool4o`0000;ooooo2_l00003
ooooo`?o00005Oooool3o`0000?ooooo1?l000001Ooooooo0000o`000?l0003ooooo00Go00004ooo
ool3o`0000?ooooo0_l0000;ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0@oooool2
o`0000;ooooo0ol0000?ooooo`;o00000_ooool3o`0000?ooooo0_l00002ooooo`?o00001?ooool4
o`0000;ooooo1?l000000ooooooo0000o`000003ooooo`;o00001?ooool2o`0000?ooooo0_l00005
ooooo`;o00003oooool4o`0000;ooooo3Ol0000Aooooo`;o00001_ooool2o`0000?ooooo1Ol00002
ooooo`;o00000oooool2o`0000Gooooo0_l0000>ooooo`;o00000oooool2o`0000Sooooo0_l00000
0ooooooo0000o`000010ooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00000_ooool3o`00
00?ooooo1?l0000=ooooo`;o00001_ooool2o`0000Gooooo0ol000001?oooooo0000o`000?ooool7
o`0000?ooooo0_l00004ooooo`;o00002_ooool2o`0000oooooo1?l000000ooooooo0000o`00000>
o`0000Gooooo0_l00002ooooo`;o00001?ooool2o`000003ooooool0003o000000?ooooo0_l00003
ooooo`;o000000?oooooo`000?l000003_ooool2o`0000oooooo0_l0000<ooooo`;o0000@oooool0
01cooooo0_l00018ooooo`;o00001?ooool4o`0000kooooo0_l00005ooooo`;o00001?ooool?o`00
00Wooooo0_l00004ooooo`;o00001?ooool2o`00013ooooo0_l000000ooooooo0000o`00000?o`00
00Gooooo0_l000000ooooooo0000o`000003o`0000Gooooo0_l00004ooooo`;o00000_ooool2o`00
00[ooooo0_l00008ooooo`;o00002oooool4o`00053ooooo000Looooo`03o`000?oooooooooo057o
oooo1Ol00009ooooo`;o00001oooool2o`0000;ooooo5ol000000ooooooo0000o`000004ooooo`;o
00005_oooolCo`000003ooooool0003o000000Kooooo0_l000000ooooooo0000o`00000;ooooo`;o
00003_ooool2o`0000Sooooo0_l0000;ooooo`Co00004?ooool2o`0003kooooo000Looooo`03o`00
0?oooooooooo053ooooo1_l0000@ooooo`Co000000?oooooo`000?l000005_l00009ooooo`;o0000
3Oooool2o`0000Kooooo5Ol00003ooooo`?o00003_ooool3o`0001Kooooo0_l0000?ooooo`;o0000
4Oooool3o`0003gooooo000Looooo`03o`000?oooooooooo047ooooo1_l00009ooooo`Ko00003?oo
oolRo`0000Sooooo0_l0000<ooooo`?o00001ooooolFo`000004ooooool0003o0000o`0000[ooooo
0_l000000ooooooo0000o`000002o`0000[ooooo0_l00003ooooo`;o00001Oooool2o`0000oooooo
0_l00004ooooo`?o00002oooool2o`0003gooooo000Looooo`03o`000?oooooooooo047ooooo1_l0
000;ooooo`Co00003?oooolRo`0000_ooooo0_l000000ooooooo0000o`000006ooooo`;o00000_oo
ool2o`0000;ooooo5?l000001?oooooo0000o`000?l00006ooooo`;o00001_ooool2o`000003oooo
ool0003o000000;o00002?ooool5o`0000;ooooo0_l00006ooooo`;o00005?ooool3o`0004[ooooo
000Looooo`03o`000?oooooooooo03Oooooo0_l00005ooooo`;o0000:?oooolJo`0000gooooo0_l0
00000ooooooo0000o`00000:ooooo`;o00000_oooolHo`0000Gooooo0ol00006ooooo`;o000000?o
ooooo`000?l000002_ooool5o`0000Oooooo0_l000000ooooooo0000o`00000;ooooo`Co0000D_oo
ool001cooooo00?o0000ooooooooool0=oooool2o`0000Gooooo0_l0000Pooooo`;o00001OoooolN
o`0000;ooooo0ol00003ooooo`;o00002_ooool2o`0000?ooooo4_l000000ooooooo0000o`000006
o`0000Cooooo1?l0000<ooooo`;o00002?ooool4o`0000Sooooo0_l000000ooooooo0000o`000002
ooooo`;o00001oooool4o`0001;ooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0moooo
o`;o000000Coooooo`000?l0003o00003?ooool2o`0000oooooo0ol00004ooooo`Go000000?ooooo
o`000?l000005_l00002ooooo`So00002_ooool2o`0000Gooooo3?l00002ooooo`_o00001?ooool2
o`0000kooooo0_l000000ooooooo0000o`000005ooooo`Co00002oooool6o`0000_ooooo0_l0000@
ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0?Oooool7o`0000_ooooo0_l0000@oooo
o`;o00001?ooool:o`000003ooooool0003o0000013o00000_ooool2o`0000;ooooo1?l0000;oooo
o`;o00000_ooool2o`000003ooooool0003o000000[o000000?oooooo`000?l000002ol00004oooo
o`;o00002Oooool2o`0000Gooooo0_l00004ooooo`Co00003?ooool4o`0000Kooooo0_l00005oooo
o`;o00001_ooool2o`0004Sooooo000Looooo`03o`000?oooooooooo03Gooooo0_l00007ooooo`?o
000000?oooooo`000?l000003Oooool2o`0001;ooooo7ol00002ooooo`;o00004OoooolQo`0000Co
oooo0_l00009ooooo`?o00002_ooool5o`0001Gooooo0_l0000=ooooo`;o0000B?ooool001cooooo
00?o0000ooooooooool0=Oooool2o`0000Gooooo1?l0000Aooooo`;o00004_oooolDo`000003oooo
ool0003o000000Oo00000oooool2o`000004ooooool0003o0000ooooo`;o00003OoooolGo`000003
ooooool0003o000000Co00002?ooool2o`0000Oooooo1?l00003ooooo`;o00000_ooool3o`000004
ooooool0003o0000ooooo`;o00000_ooool2o`0000Kooooo1?l000001?oooooo0000o`000?ooool4
o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0003oooooo000Looooo`03o`000?oooooooooo
03Cooooo0_l00002ooooo`;o00000_ooool4o`00023ooooo0_l00003ooooo`Oo000000?oooooo`00
0?l000000ol000000ooooooo0000o`00000>o`0000Kooooo1Ol0000:ooooo`;o00000ooooolDo`00
00;ooooo1?l00009ooooo`?o00002Oooool4o`000003ooooool0003o000000;ooooo0ol00004oooo
o`;o00000_ooool2o`0000;ooooo0_l00002ooooo`Co000000?oooooo`000?l000000oooool2o`00
00?ooooo1?l00005ooooo`;o00001_ooool2o`0003oooooo000Looooo`03o`000?oooooooooo02;o
oooo0_l0000@ooooo`;o00000_ooool2o`0000Wooooo1?l0000Iooooo`;o00000oooool2o`000003
ooooool0003o0000013o000000?oooooo`000?l000005Ol00006ooooo`;o00001?oooolIo`0000Wo
oooo0_l000000ooooooo0000o`000007ooooo`Co00001Oooool2o`0000gooooo0_l0000:ooooo`;o
00001Oooool2o`00053ooooo000Looooo`03o`000?oooooooooo02;ooooo0_l0000Aooooo`?o0000
1_ooool2o`0000?ooooo1?l0000QoooooaOo000000Coooooo`000?l0003ooooo1ol00004ooooo`Co
00001oooool2o`0000?ooooo6?l000000ooooooo0000o`000007ooooo`Go00004?ooool2o`0000ko
oooo0_l00004ooooo`;o00000oooool2o`0005Oooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^
kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0eoooo
o`?o00000oooool2o`000003ooooool0003o000000;o00000oooool2o`00027ooooo6_l00004oooo
o`;o00001?ooool2o`0000_ooooo0_l00002ooooo`Ko000000?oooooo`000?l000004?l000000ooo
oooo0000o`000009ooooo`;o00001?ooool2o`0001_ooooo0_l00004ooooo`;o00001?ooool2o`00
00Gooooo1?l0001=ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Kooooo0_l00003ooooo`?o00000_ooool2
o`000003ooooool0003o000000;o00007_oooolLo`0000Gooooo0_l00004ooooo`;o00002oooool2
o`000003ooooool0003o000000;o000000?oooooo`000?l000004_l00006ooooo`;o00001Oooool2
o`0000Cooooo1?l0000Booooo`Oo00002_ooool4o`0000;ooooo0_l000000ooooooo0000o`000004
o`0004_ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006oooo
o`03o`000?oooooooooo03Kooooo0_l00002ooooo`Ko00000oooool2o`0000Kooooo0_l0000>oooo
o`;o00002?oooolLo`0000Gooooo0_l0000@ooooo`?o000000?oooooo`000?l000000ooooolDo`00
00Kooooo0_l000000ooooooo0000o`000002ooooo`;o00001_ooool2o`0000?ooooo0_l00004oooo
o`;o00001?ooool2o`000003ooooool0003o000000co00000oooool2o`000004ooooool0003o0000
ooooo`;o00001Oooool2o`0000?ooooo0_l00016ooooo`0000?oooooo`000?ooool00_ooool00ol0
003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0000iooooo`Wo000000?ooooo
o`000?l000000oooool2o`000003ooooool0003o000000kooooo0_l00008oooooaco00005oooool2
o`0000Oooooo1Ol000000ooooooo0000o`00000;o`0000Wooooo0ol00008ooooo`;o00001Oooool2
o`0000;ooooo1?l00003ooooo`?o00000oooool2o`0000;ooooo2?l00006ooooo`;o000000?ooooo
o`000?l000002_ooool3o`0004Gooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`0iooooo`;o000000?ooooo
o`000?l000002Ol000000ooooooo0000o`00000>ooooo`;o00003?oooolKo`0000_ooooo0_l0000C
ooooo`Go000000?oooooo`000?l000001ol00002ooooo`;o00002Oooool2o`0000Wooooo0_l00009
ooooo`;o00001Oooool2o`0000Cooooo1ol00003ooooo`?o000000?oooooo`000?l000000_l00003
ooooo`?o00000_ooool2o`0000Kooooo0_l00015ooooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0<?ooool2o`00
00Oooooo0_l00003ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o00003_ooool2
o`000003ooooool0003o000000[ooooo1_l00002oooooa;o00002oooool2o`0001Gooooo3?l00000
0ooooooo0000o`000002o`0000Gooooo0_l0000Kooooo`;o00001?ooool2o`000003ooooool0003o
000000Go00000_ooool2o`000003ooooool0003o000000Ko00000oooool2o`0000;ooooo0_l0001=
ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o
0000ooooooooool0<?ooool2o`0000Oooooo0ol00002ooooo`;o00006?ooool2o`000004ooooool0
003o0000ooooo`;o000000?oooooo`000?l000001_ooool6o`000003ooooool0003o000000go0000
1oooool2o`0001cooooo0ol000000ooooooo0000o`000004o`000003ooooool0003o000000?o0000
1Oooool4o`0000Kooooo0_l000000ooooooo0000o`000004o`0000Cooooo1Ol000000ooooooo0000
o`000004ooooo`;o000000?oooooo`000?l000000oooool2o`0000;ooooo0_l00003ooooo`;o0000
0_ooool2o`0000?ooooo0_l00002ooooo`;o00004?ooool2o`0003_ooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`0hooooo`Co
00000_ooool2o`0001Sooooo0_l00002ooooo`Oo00001oooool=o`000003ooooool0003o000000Co
00002?ooool2o`0001cooooo0_l00002ooooo`;o00001Oooool2o`0000[ooooo0_l00006ooooo`;o
000000?oooooo`000?l000001?l00002ooooo`Oo00003?ooool2o`0000Gooooo0_l00003ooooo`;o
000000Coooooo`000?l0003o00000oooool2o`0000Sooooo0_l00004ooooo`;o000000Coooooo`00
0?l0003ooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00002_ooool2o`00
00;ooooo0_l00002ooooo`;o00005Oooool3o`0000;ooooo0_l000000ooooooo0000o`000002o`00
00Wooooo4ol000001?oooooo0000o`000?ooool2o`0000oooooo1?l00004ooooo`;o000000?ooooo
o`000?l000000oooool3o`0001[ooooo0_l00002ooooo`;o000000?oooooo`000?l000001?ooool3
o`00013ooooo1?l0000;ooooo`;o00003_ooool2o`0000Cooooo0_l000000ooooooo0000o`00000n
ooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00003_ooool2o`000004ooooool0003o0000
o`0001Gooooo0_l00007ooooo`?o00002Oooool9o`000003ooooool0003o000000Oo000000Cooooo
o`000?l0003ooooo0_l00003ooooo`;o000000?oooooo`000?l000001oooool5o`0000?ooooo0_l0
00000ooooooo0000o`000004ooooo`;o00002?ooool3o`0000Oooooo0_l00006ooooo`;o00000_oo
ool2o`0000Sooooo0_l0000>ooooo`;o000000?oooooo`000?l000000_l00005ooooo`;o00000_oo
ool3o`0000Oooooo0_l00009ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0<_ooool2
o`0000_ooooo0_l0000Booooo`;o00000_ooool2o`0000Oooooo0_l00005ooooo`;o00000_ooool:
o`000003ooooool0003o000000Go00002oooool2o`000003ooooool0003o000000Oooooo0_l00000
0ooooooo0000o`00000Fooooo`?o00000_ooool2o`0000?ooooo0ol0000:ooooo`;o00005oooool7
o`0000Cooooo0ol00002ooooo`;o00002?ooool4o`0000Oooooo0_l00003ooooo`;o0000?_ooool0
01cooooo00?o0000ooooooooool0<_ooool2o`0001?ooooo0_l0000:ooooo`;o00000_ooool2o`00
00Sooooo1?l00002ooooo`;o00000_ooool7o`000003ooooool0003o000000So00002Oooool2o`00
00Oooooo0ol00002ooooo`;o00007_ooool2o`0000Cooooo0_l0000:ooooo`;o00001oooool2o`00
0003ooooool0003o000000cooooo1?l000000ooooooo0000o`000003ooooo`;o00003oooool2o`00
00cooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00002?ooool2o`0001So
oooo1?l00006ooooo`Go000000?oooooo`000?l000003?l00002ooooo`?o00000_ooool2o`000003
ooooool0003o000000Cooooo0ol0000;ooooo`;o00006_ooool2o`0000Oooooo1_l00006ooooo`?o
000000?oooooo`000?l000001oooool2o`0000Gooooo0_l000000ooooooo0000o`000004ooooo`;o
000000?oooooo`000?l000000oooool4o`0000Wooooo0_l00007ooooo`;o0000?_ooool001cooooo
00?o0000ooooooooool0=oooool2o`0000Cooooo0_l0000Looooo`;o00003?ooool;o`0000Gooooo
0_l000001?oooooo0000o`000?l00002ooooo`?o00001Oooool2o`0000Kooooo0_l0000:ooooo`;o
00001?ooool2o`0001;ooooo1_l00005ooooo`Co00002?ooool2o`0000;ooooo0_l00007ooooo`;o
00003_ooool2o`000003ooooool0003o000000?ooooo1_l00007ooooo`;o00001oooool2o`0003ko
oooo000Looooo`03o`000?oooooooooo033ooooo0_l00002ooooo`;o000000?oooooo`000?l00000
1?ooool2o`0000Sooooo0_l0000Booooo`;o00003?ooool2o`000004ooooool0003o0000ooooo`?o
00000_ooool2o`0000Cooooo0_l00006ooooo`;o00001Oooool2o`0000Kooooo0_l0000@ooooo`;o
00004?ooool5o`000003ooooool0003o000001Gooooo0_l00005ooooo`;o00002_ooool3o`0000oo
oooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00000_ooool2o`000003oooo
ool0003o000000;ooooo1?l00008ooooo`;o00002Oooool2o`0000Kooooo0_l0000@ooooo`?o0000
00?oooooo`000?l000000_ooool2o`0000Cooooo0_l00006ooooo`;o00001Oooool2o`0002Gooooo
0_l00002ooooo`?o000000?oooooo`000?l000004Oooool2o`0000Gooooo0_l00005ooooo`?o0000
2Oooool3o`0001cooooo0_l00009ooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0<ooo
ool6o`0000;ooooo0_l00007ooooo`Co000000?oooooo`000?l000001oooool2o`0000Kooooo0_l0
000>ooooo`;o000000?oooooo`000?l000008?ooool4o`0001gooooo0_l00002ooooo`;o00005Ooo
ool2o`0000gooooo0_l0000Eooooo`Co00003oooool2o`0000?ooooo0_l00004ooooo`;o0000>?oo
ool001cooooo00?o0000ooooooooool0<oooool4o`0000Sooooo0_l00003ooooo`Oo00003?ooool2
o`0000Sooooo0_l00007ooooo`;o00002_ooool2o`0001;ooooo0_l00002ooooo`Ko00001?ooool2
o`0000Kooooo0_l00007ooooo`;o00002Oooool2o`0001Cooooo0ol00006ooooo`;o00002Oooool4
o`0000Gooooo0_l00005ooooo`;o000000?oooooo`000?l000001?l0000:ooooo`;o000000?ooooo
o`000?l000000oooool2o`0003kooooo000Looooo`03o`000?oooooooooo03Cooooo0_l00009oooo
o`;o00001Oooool3o`0000kooooo0_l00008ooooo`;o00001Oooool5o`0000?ooooo0_l00004oooo
o`?o00001oooool2o`000003ooooool0003o000000Gooooo0_l00002ooooo`Ko00000_ooool5o`00
00?ooooo2?l00003ooooo`;o000000?oooooo`000?l000001_ooool2o`0001Cooooo0_l00007oooo
o`;o00002Oooool4o`0000Gooooo0_l00005ooooo`;o00001?ooool3o`0000[ooooo0_l00016oooo
o`007?ooool2o`0003Gooooo0ol0000Iooooo`;o00004Oooool2o`0000;ooooo1_l00003ooooo`;o
000000?oooooo`000?l000000_ooool3o`0000Kooooo0_l000001?oooooo0000o`000?ooool2o`00
00;ooooo0ol00003ooooo`;o00001?ooool@o`0000Kooooo0_l0000Eooooo`Co00001_ooool2o`00
013ooooo0ol00005ooooo`Co00002?ooool4o`0001Cooooo0_l0000looooo`007?ooool00ol0003o
ooooooooo`0aooooo`;o00000_ooool2o`0000gooooo0_l0000:ooooo`;o00000_ooool2o`0000go
oooo1_l00007ooooo`;o000000?oooooo`000?l000001Ol00004ooooo`;o00000oooool2o`000003
ooooool0003o000000;ooooo2?l00007ooooo`Go000000?oooooo`000?l000008_ooool4o`0000?o
oooo0_l000000ooooooo0000o`000003ooooo`;o00001_ooool2o`0000Cooooo0_l000000ooooooo
0000o`000004ooooo`;o00002?ooool4o`0001Cooooo0_l0000looooo`007?ooool00ol0003ooooo
ooooo`0]ooooo`;o00000_ooool2o`00017ooooo0_l0000>ooooo`;o00003oooool2o`0000?ooooo
0_l00002ooooo`;o00001?ooool3o`0000Oooooo0_l00005ooooo`;o000000?oooooo`000?l00000
2ol00004ooooo`Go00006oooool2o`0000Cooooo0_l00009ooooo`;o00001_ooool2o`0000;ooooo
0_l00002ooooo`Co00001Oooool5o`0000;ooooo0_l0000Cooooo`;o00000_ooool2o`0004Cooooo
000Looooo`03o`000?oooooooooo02gooooo0_l00008ooooo`;o00001Oooool2o`000003ooooool0
003o000001gooooo0_l00008ooooo`;o00000_ooool2o`0000Wooooo0_l0000:ooooo`;o000000?o
ooooo`000?l000000_l00005ooooo`Ko00000_ooool2o`000003ooooool0003o000000Gooooo0_l0
000Dooooo`;o00001?ooool2o`0000;ooooo1_l0000=ooooo`;o00000_ooool6o`0000;ooooo0_l0
00001?oooooo0000o`000?l00002ooooo`;o000000?oooooo`000?l000004?ooool2o`0000;ooooo
0_l0000<ooooo`;o0000=_ooool001cooooo00?o0000ooooooooool0;oooool2o`0000Gooooo0ol0
0005ooooo`Go00000_ooool2o`0000Wooooo0_l00002ooooo`;o00002_ooool5o`0000gooooo2Ol0
0004ooooo`;o00000_ooool4o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`;o000000Co
ooooo`000?l0003o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`00000:ooooo`;o0000
3oooool6o`000003ooooool0003o000000Sooooo3Ol000001?oooooo0000o`000?ooool2o`0000Ko
oooo0_l00006ooooo`?o00001_ooool4o`0000oooooo0_l0000fooooo`007?ooool00ol0003ooooo
ooooo`0_ooooo`;o00001Oooool3o`0000Oooooo0_l00003ooooo`?o00001oooool3o`0000;ooooo
0_l0000<ooooo`?o000000?oooooo`000?l000002_ooool;o`0000;ooooo0_l000001?oooooo0000
o`000?l00006ooooo`Go000000?oooooo`000?l000001?ooool4o`000004ooooool0003o0000o`00
00Oooooo0_l0000:ooooo`;o00003Oooool4o`0000;ooooo0_l000000ooooooo0000o`000008oooo
oaKo00000_ooool2o`0000Oooooo1?l00005ooooo`Co0000Aoooool001cooooo00?o0000oooooooo
ool0;?ooool2o`0000Wooooo0_l0000;ooooo`Co00001oooool2o`0000gooooo0_l00003ooooo`;o
000000Coooooo`000?l0003o00002_ooool5o`000003ooooool0003o000000;o00001Oooool4o`00
0003ooooool0003o000000;ooooo2?l000001?oooooo0000o`000?ooool2o`0000?ooooo0ol0000M
ooooo`;o00000oooool4o`0000;ooooo0_l00002ooooo`Co00001OoooolAo`000003ooooool0003o
000000;o00000_ooool2o`0000Sooooo0ol00006ooooo`;o0000B?ooool001cooooo00?o0000oooo
ooooool0;?ooool2o`0000gooooo0_l00007ooooo`Oo00004oooool2o`0000;ooooo0_l00003oooo
o`;o00001oooool3o`000003ooooool0003o000000;o00001_ooool2o`0000;ooooo1?l000000ooo
oooo0000o`000006ooooo`;o00000oooool2o`0001Oooooo0_l00002ooooo`;o00002Oooool2o`00
00gooooo1ol00002oooooaOo00007_ooool2o`0003kooooo000Looooo`03o`000?oooooooooo037o
oooo0_l00004ooooo`;o00000_ooool2o`0000?ooooo1?l00003ooooo`Co00005oooool2o`0000So
oooo0_l00002ooooo`Ko00000oooool7o`000004ooooool0003o0000o`00013ooooo0_l00006oooo
o`;o00000oooool2o`0000[ooooo0_l00002ooooo`;o00004?ooool2o`000003ooooool0003o0000
00?ooooo2?l000000ooooooo0000o`00000@o`0000?ooooo0_l00003ooooo`;o00000_ooool2o`00
0004ooooool0003o0000ooooo`;o00000oooool2o`0000[ooooo1?l0000looooo`007?ooool00ol0
003oooooooooo`0aooooo`;o000000Coooooo`000?l0003ooooo0_l00007ooooo`Co00002?ooool2
o`0001kooooo0ol00003ooooo`;o00001Oooool6o`0000;ooooo0ol0000Hooooo`;o00000oooool2
o`0000?ooooo0_l00004ooooo`;o00000oooool2o`000003ooooool0003o000000Gooooo0_l00006
ooooo`;o000000?oooooo`000?l000000oooool8o`000003ooooool0003o000001?o000000?ooooo
o`000?l000000_ooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo1?l0
0009ooooo`?o0000??ooool001cooooo00?o0000ooooooooool0=?ooool4o`0000Oooooo0_l00008
ooooo`;o000000?oooooo`000?l000007oooool6o`000004ooooool0003o0000ooooo`;o00002Ooo
ool4o`00013ooooo0_l00002ooooo`;o00002_ooool2o`0000;ooooo1?l00003ooooo`;o000000?o
ooooo`000?l000001Oooool2o`0000kooooo0_l00002ooooo`;o000000?oooooo`000?l000005Ol0
00000ooooooo0000o`000002ooooo`;o00002oooool2o`000004ooooool0003o0000o`0004Sooooo
000Looooo`03o`000?oooooooooo03Kooooo0_l00007ooooo`Co00001_ooool2o`0002Cooooo1?l0
00001?oooooo0000o`000?ooool3o`0000[ooooo0_l0000:ooooo`Co00000_ooool2o`0000;ooooo
0_l00004ooooo`Co00001_ooool2o`0000Oooooo0_l00003ooooo`;o00001?ooool2o`0000_ooooo
8?l00003ooooo`Co00001_ooool2o`000003ooooool0003o000001kooooo0_l0000/ooooo`007?oo
ool00ol0003oooooooooo`0fooooo`;o00002Oooool2o`0000Cooooo0_l000000ooooooo0000o`00
000Nooooo`;o00001_ooool2o`0000?ooooo0ol00007ooooo`;o00001_ooool2o`0000Gooooo1?l0
0008ooooo`;o00000_ooool4o`0000oooooo0_l00003ooooo`?o000000?oooooo`000?l000000_l0
000;ooooob3o00001Oooool2o`000003ooooool0003o000000;ooooo0ol000001?oooooo0000o`00
0?ooool2o`000003ooooool0003o000000Kooooo0_l0000@ooooo`;o0000;?ooool001cooooo00?o
0000ooooooooool0;?ooool2o`0000Kooooo1?l000000ooooooo0000o`000003o`0000Gooooo0_l0
0002ooooo`;o000000?oooooo`000?l000005_ooool2o`0000Kooooo0_l00006ooooo`;o00000ooo
ool2o`0000Sooooo0_l00005ooooo`?o00002oooool2o`0000Cooooo0_l00007ooooo`;o00001?oo
ool2o`0000[ooooo1ol0000:ooooo`;o000000?oooooo`000?l000007_l00006ooooo`So00001Ooo
ool2o`000003ooooool0003o000000Kooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0/
ooooo`;o00001?ooool6o`000003ooooool0003o000000?o00001Oooool4o`0000Kooooo0_l0000C
ooooo`;o00001?ooool2o`0000;ooooo0_l0000=ooooo`;o00001oooool2o`0000;ooooo0_l00003
ooooo`;o00001oooool2o`0000cooooo0ol00004ooooo`;o00000oooool2o`0000Gooooo0ol00000
0ooooooo0000o`00000:ooooo`?o00000_oooolRo`0000?ooooo0_l00002ooooo`Co00005_ooool2
o`0003Sooooo000Looooo`03o`000?oooooooooo02cooooo0_l00004ooooo`;o00004Oooool2o`00
00;ooooo0_l00002ooooo`;o00002Oooool2o`0000kooooo0_l00002ooooo`;o00002oooool4o`00
00Oooooo0ol00006ooooo`;o00002_ooool2o`0000Kooooo0_l000000ooooooo0000o`00000:oooo
o`;o00001_ooool3o`0000Oooooo0_l00003ooooo`;o00000_ooool:o`000003ooooool0003o0000
01Oo00001Oooool4o`00017ooooo0_l00004ooooo`;o0000>?ooool001cooooo0_l0000^ooooo`;o
00001oooool2o`0000Gooooo0_l0000:ooooo`;o00003Oooool2o`0000[ooooo0_l00009ooooo`;o
00002?ooool2o`0000Kooooo0_l00002ooooo`;o00003Oooool2o`0000?ooooo1ol000000ooooooo
0000o`00000;ooooo`;o00001?ooool3o`000004ooooool0003o0000o`0000Oooooo0_l00003oooo
o`?o000000?oooooo`000?l000001ol000000ooooooo0000o`00000;o`000003ooooool0003o0000
00Go00000_ooool4o`0000Cooooo1?l00003ooooo`;o00001Oooool2o`0000Gooooo0_l0000noooo
o`007?ooool00ol0003oooooooooo`0Xooooo`;o00000oooool2o`0000Oooooo0_l00005ooooo`;o
000000?oooooo`000?l000005Oooool2o`0000?ooooo0_l00006ooooo`Co00000_ooool2o`0000?o
oooo0_l00006ooooo`Co00001_ooool2o`0000;ooooo1?l0000;ooooo`;o00001Oooool5o`0000ko
oooo0_l00004ooooo`?o00002Oooool4o`0000Cooooo0_l000000ooooooo0000o`00000Mo`0000;o
oooo1?l00008ooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000oo
oooo0_l0000dooooo`007?ooool00ol0003oooooooooo`0Xooooo`;o00001_ooool2o`0000kooooo
1?l0000Cooooo`;o00000oooool2o`0000Sooooo0_l00002ooooo`;o00000_ooool2o`000003oooo
ool0003o000000Cooooo1?l0000<ooooo`;o00001Oooool2o`0001Oooooo0ol0000Fooooo`Co0000
2OoooolAo`000003ooooool0003o000000Go000000Goooooo`000?l0003o0000ooooo`04o`0000;o
oooo0_l00005ooooo`;o00001?ooool3o`0001;ooooo0_l0000dooooo`007?ooool00ol0003ooooo
ooooo`0`ooooo`;o000000Coooooo`000?l0003ooooo0_l0000:ooooo`;o00007_ooool2o`0000Ko
oooo0_l00002ooooo`;o000000?oooooo`000?l000002oooool4o`0000cooooo0_l0000Aooooo`;o
00001?ooool3o`00017ooooo0_l0000=ooooo`;o000000Coooooo`000?l0003ooooo5Ol00002oooo
o`;o00000_ooool2o`0000Cooooo0_l00006ooooo`;o00000oooool2o`0004Wooooo000Looooo`03
o`000?oooooooooo02[ooooo0_l00007ooooo`;o000000?oooooo`000?l000000_l0000Xooooo`;o
00003?ooool2o`0000;ooooo0_l00006ooooo`Ko00003?ooool2o`0000Oooooo0_l00008ooooo`;o
00000_ooool2o`000003ooooool0003o000000Sooooo0_l00007ooooo`;o00001oooool2o`0000Co
oooo0_l000001?oooooo0000o`000?oooolFo`0000Cooooo0_l0000=ooooo`;o00000_ooool2o`00
00kooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`0Zooooo`;o00000oooool5o`0000Co
oooo0_l0000Mooooo`Go00000_ooool2o`0000Wooooo2_l000000ooooooo0000o`000002ooooo`;o
000000Coooooo`000?l0003o00001Oooool2o`0000Cooooo0_l00003ooooo`;o00001oooool2o`00
00Kooooo1?l00002ooooo`Ko00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`00
00Kooooo0_l00003ooooo`Co00001OoooolLo`000004ooooool0003o0000ooooo`;o00001oooool2
o`0000Cooooo0ol0000>ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0;oooool5o`00
00Sooooo0_l0000:ooooo`Co00002_ooool6o`0000;ooooo0_l00007ooooo`co00001Oooool2o`00
0003ooooool0003o000000;ooooo0_l00002ooooo`;o00001?ooool2o`0001Cooooo1?l00004oooo
o`Co00000oooool2o`0000Gooooo1?l00006ooooo`;o00000oooool4o`000003ooooool0003o0000
023o00000_ooool2o`0000;ooooo0_l00003ooooo`;o00000oooool3o`0004_ooooo000Looooo`03
o`000?oooooooooo02Oooooo0_l00009ooooo`?o00000oooool2o`0000;ooooo0_l0000:ooooo`Co
00002Oooool3o`0000cooooo3ol00002ooooo`Co00001_ooool4o`0001kooooo0_l00006ooooo`;o
00004_ooool2o`0000[ooooo7_l000001?oooooo0000o`000?l00002ooooo`;o00000_ooool3o`00
00Cooooo0_l000000ooooooo0000o`00001<ooooo`007?ooool00ol0003oooooooooo`0Wooooo`;o
00002_ooool3o`0000;ooooo0_l00004ooooo`;o00004Oooool2o`0000;ooooo0_l0000=oooooaGo
00001?ooool2o`0000;ooooo1Ol00004ooooo`?o00007?ooool2o`0000Sooooo0_l00008ooooo`;o
00002ooooolQo`0000;ooooo0_l00003ooooo`;o00001?ooool2o`00013ooooo0_l0000mooooo`00
7?ooool00ol0003oooooooooo`0/ooooo`;o00000_ooool2o`0000;ooooo1?l00006ooooo`;o0000
0_ooool2o`0000gooooo0_l00006ooooo`;o00003?oooolBo`0000Cooooo2Ol00004ooooo`?o0000
5_ooool2o`0000Cooooo0_l00008ooooo`;o00005Oooool2o`0000;ooooo6ol000000ooooooo0000
o`000003o`0000Oooooo0_l00002ooooo`;o00003_ooool2o`0003gooooo000Looooo`03o`000?oo
oooooooo02cooooo0_l00002ooooo`;o00001?ooool2o`0000[ooooo0_l0000Aooooo`;o00000_oo
ool2o`0000[ooooo4ol00002ooooo`;o00000_ooool3o`0002;ooooo0_l00007ooooo`;o00007?oo
ool2o`0000Cooooo6?l000000ooooooo0000o`000004o`0000Oooooo0_l00002ooooo`;o0000COoo
ool001cooooo00?o0000ooooooooool0COooool2o`0000?ooooo0_l000000ooooooo0000o`000002
o`0000cooooo4ol00002ooooo`?o00002Oooool2o`0002Cooooo0_l00004ooooo`;o000000?ooooo
o`000?l000002_ooool2o`0000?ooooo0_l00003ooooo`;o00001?oooolCo`000003ooooool0003o
000000;ooooo1?l0000Kooooo`;o0000?oooool001cooooo00?o0000ooooooooool09oooool4o`00
02;ooooo0_l00002ooooo`Go000000?oooooo`000?l000003?oooolDo`0000;ooooo0_l00009oooo
o`;o0000:_ooool2o`000003ooooool0003o000000[ooooo0_l00002ooooo`?o00000ooooolIo`00
0003ooooool0003o000000Cooooo0_l0000Kooooo`;o0000?oooool001cooooo00?o0000oooooooo
ool09oooool5o`0000[ooooo1?l0000Aooooo`;o00000_ooool7o`0000[ooooo0_l00003oooooaCo
00001oooool2o`000003ooooool0003o000001?ooooo0_l0000Hooooo`;o00000oooool2o`0000co
oooo0_l00004oooooa7o000000?oooooo`000?l000001Ol000000ooooooo0000o`000003o`0005oo
oooo000Looooo`03o`000?oooooooooo02Wooooo1?l00009ooooo`Go00004?ooool2o`0000;ooooo
0_l0000?ooooo`Co000000?oooooo`000?l000004_l00007ooooo`;o000000?oooooo`000?l00000
4oooool2o`0001Sooooo0_l00003ooooo`;o00003?ooool2o`0000Wooooo3Ol000000ooooooo0000
o`000002o`0000Cooooo1?l00003ooooo`;o00001?ooool2o`00027ooooo0_l0000aooooo`007?oo
ool00ol0003oooooooooo`0Yooooo`Co00003?ooool2o`0000Kooooo0_l0000:ooooo`;o00003ooo
ool2o`000003ooooool0003o000001So00003?ooool2o`0001cooooo0_l000000ooooooo0000o`00
0002o`0001Wooooo0_l00009ooooo`Go00001?ooool4o`000003ooooool0003o000000Co00000_oo
ool2o`0000Gooooo0_l00004ooooo`;o00005Oooool2o`0000?ooooo0_l00003ooooo`Co0000<Ooo
ool001cooooo0_l0000hooooo`;o00001_ooool4o`000003ooooool0003o000000?ooooo0_l00002
ooooo`;o00001_ooool2o`000003ooooool0003o000000Cooooo0_l00002oooooaWo00003?ooool2
o`0001cooooo0_l000000ooooooo0000o`000002o`0000Oooooo0_l00004ooooo`;o00005?ooool4
o`0000;ooooo0_l00002ooooo`Co000000?oooooo`000?l000001?l0000Vooooo`;o00000oooool2
o`0000?ooooo0ol0000booooo`007?ooool00ol0003oooooooooo`0dooooo`;o000000?oooooo`00
0?l000000_ooool2o`0000;ooooo0_l00003ooooo`;o00000oooool2o`0000[ooooo0_l000000ooo
oooo0000o`000002ooooo`;o00001OoooolHo`0002Wooooo0_l00003ooooo`;o00002?ooool2o`00
00Cooooo0ol00003ooooo`;o00003_ooool2o`0000Cooooo0_l00004ooooo`Go00001Oooool2o`00
00Cooooo0_l0000Wooooo`Co0000<Oooool001cooooo00?o0000ooooooooool0:oooool2o`0000;o
oooo0_l000000ooooooo0000o`000002o`0000Gooooo0_l000000ooooooo0000o`000009ooooo`Co
00003oooool2o`0000Gooooo5_l00004ooooo`;o00007Oooool2o`0000;ooooo0_l000001?oooooo
0000o`000?l00003ooooo`?o00000oooool2o`0000Wooooo0_l00003ooooo`;o00001_ooool2o`00
00Kooooo0_l00003ooooo`;o00001Oooool3o`0000Kooooo0ol00004ooooo`;o00000_ooool2o`00
02?ooooo1?l0000aooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o00000_ooool2o`000003
ooooool0003o000000;o00000oooool2o`0000?ooooo1?l00009ooooo`;o00005_oooolFo`0000Co
oooo0_l0000:ooooo`;o00001_ooool3o`0000Sooooo0_l00002ooooo`;o000000?oooooo`000?l0
00000ol00002ooooo`;o000000?oooooo`000?l000000_l00002ooooo`Co00002_ooool2o`0000Co
oooo0ol00003ooooo`Go00000_ooool2o`0000kooooo0ol000000ooooooo0000o`000002ooooo`;o
000000?oooooo`000?l000003_ooool2o`0004Sooooo000Looooo`03o`000?oooooooooo03;ooooo
1?l00003ooooo`;o00001Oooool2o`0000cooooo1?l0000BoooooaKo00000oooool2o`0000[ooooo
0_l00006ooooo`?o00002?ooool2o`0000Oooooo1_l00002ooooo`Co00000_ooool4o`0000?ooooo
0ol00004ooooo`;o00001Oooool2o`0000?ooooo1Ol0000Cooooo`;o000000?oooooo`000?l00000
0_ooool2o`0000Oooooo1?l00006ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0<?oo
ool2o`0000Kooooo0_l00006ooooo`;o00002?ooool2o`0000;ooooo1?l0000BoooooaKo00000ooo
ool2o`0000cooooo0_l0000:ooooo`;o000000?oooooo`000?l000000_l00007ooooo`Ko00001?oo
ool2o`000003ooooool0003o000000?o00000oooool3o`0001;ooooo0_l0000<ooooo`;o000000?o
ooooo`000?l000002_ooool2o`0000Kooooo1Ol00005ooooo`;o0000BOooool001cooooo00?o0000
ooooooooool0<?ooool2o`0000Kooooo0_l00006ooooo`;o000000?oooooo`000?l000001Oooool2
o`0000Kooooo0_l00003ooooo`;o00001?ooool2o`0000Gooooo4ol0000Dooooo`;o00002_ooool2
o`000003ooooool0003o000000Wooooo0_l000000ooooooo0000o`000008ooooo`;o00001?ooool2
o`00017ooooo0_l00002ooooo`;o00001oooool2o`0000?ooooo0_l000001?oooooo0000o`000?oo
ool2o`0000Gooooo0_l00002ooooo`;o00001?ooool2o`0000Sooooo0_l00019ooooo`007?ooool0
0ol0003oooooooooo`13ooooo`;o00000_ooool2o`0000Wooooo0_l00003ooooo`;o00001?ooool4
o`0000Cooooo4Ol00003ooooo`;o00004?ooool3o`000003ooooool0003o000000;o00000_ooool2
o`0000Sooooo0_l00005ooooo`Co00002_ooool2o`0000;ooooo0_l00004ooooo`Co00002Oooool2
o`0000_ooooo0_l00007ooooo`Co00001Oooool2o`0000;ooooo0_l00004ooooo`;o0000Doooool0
01cooooo00?o0000ooooooooool0:_ooool2o`0000Sooooo0_l0000=ooooo`;o00000_ooool4o`00
00Kooooo0_l0000<ooooo`;o00001_ooool?o`0000?ooooo0_l0000@ooooo`?o000000?oooooo`00
0?l000000_l00002ooooo`Co00001?ooool7o`0000;ooooo0_l00005ooooo`Ko000000?oooooo`00
0?l000001_ooool6o`0000Kooooo0_l0000Gooooo`;o00003Oooool2o`0000;ooooo0_l00005oooo
o`;o0000C?ooool001cooooo00?o0000ooooooooool0:_ooool2o`0000;ooooo0ol00003ooooo`;o
00002Oooool2o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l000000oooool2o`0000?o
oooo0_l00002ooooo`;o00002Oooool@o`0001_ooooo0_l000000ooooooo0000o`000007o`000003
ooooool0003o000000_o000000?oooooo`000?l000002?l00002ooooo`?o00000_ooool4o`0000So
oooo0_l0000Booooo`;o000000?oooooo`000?l000001Oooool2o`0000Sooooo0_l00009ooooo`;o
0000C?ooool001cooooo00?o0000ooooooooool0;_ooool3o`0000kooooo1_l00007ooooo`;o0000
1?ooool2o`0000;ooooo0_l00002ooooo`;o00002Oooool7o`000005ooooool0003o0000o`000?oo
ool01?l0000:ooooo`;o00003oooool2o`000003ooooool0003o000000;ooooo3?l000000ooooooo
0000o`000004o`000003ooooool0003o000000;ooooo0ol000000ooooooo0000o`000002ooooo`Wo
00003Oooool7o`0000Sooooo0_l000000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l0
00005Oooool2o`0004Oooooo000Looooo`03o`000?oooooooooo03?ooooo0_l0000<ooooo`;o0000
1Oooool2o`0000Oooooo0ol0000<ooooo`?o00000oooool2o`000003ooooool0003o000000Co0000
1?ooool2o`0000[ooooo0_l0000Eooooo`?o00000_ooool3o`0000;ooooo2Ol000000ooooooo0000
o`000003o`000004ooooool0003o0000ooooo`;o00001Oooool2o`0000Cooooo0_l0000;ooooo`Oo
00005Oooool2o`0000kooooo0_l00005ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0
<oooool2o`0001?ooooo0_l00002ooooo`;o00000oooool3o`0000Oooooo0_l00003ooooo`Co0000
0_ooool4o`000003ooooool0003o000000;o00001?ooool2o`0000Cooooo0_l000000ooooooo0000
o`000004ooooo`?o00000oooool2o`0000cooooo0ol00002ooooo`;o00000ooooolAo`000004oooo
ool0003o0000o`0000_ooooo0ol0000Looooo`;o00001Oooool2o`0000cooooo0_l00003ooooo`;o
00001Oooool4o`0004Gooooo000Looooo`03o`000?oooooooooo02_ooooo0_l0000Oooooo`;o0000
0oooool2o`0000;ooooo0_l00004ooooo`;o00001?ooool3o`0000Cooooo1?l00005ooooo`Co0000
1?ooool2o`000003ooooool0003o000000?o000000Coooooo`000?l0003o00000oooool2o`0000[o
oooo1?l00002ooooo`Ko000000?oooooo`000?l000003_l000000ooooooo0000o`000002o`0000Oo
oooo1_l0000>ooooo`;o00003?ooool2o`0000Gooooo0_l0000<ooooo`;o00003?ooool2o`0004Go
oooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000
oa0@4?o<c<`01_ooool00ol0003oooooooooo`0[ooooo`;o00001_ooool2o`0001cooooo0_l00002
ooooo`;o00001?ooool2o`0000?ooooo1_l00004ooooo`;o00001Oooool3o`0000Kooooo0_l00002
ooooo`?o00001?ooool2o`0000gooooo0_l00004oooooa?o000000?oooooo`000?l000000oooool3
o`0000Cooooo0_l000000ooooooo0000o`000002o`0000Kooooo0_l00008ooooo`;o000000?ooooo
o`000?l000000_ooool2o`000004ooooool0003o0000ooooo`;o0000JOooool00006oooooomgMgOo
V9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03
o`000?oooooooooo03?ooooo0_l0000Mooooo`;o00002?ooool3o`000004ooooool0003o0000oooo
o`?o00002?ooool2o`0000Oooooo0_l000000ooooooo0000o`000002o`0000Oooooo0_l0000;oooo
o`?o00001_oooolBo`0000?ooooo0_l000001?oooooo0000o`000?l00004ooooo`Co00001_ooool5
o`0000Cooooo0_l00005ooooo`;o00000_ooool5o`000003ooooool0003o000000?ooooo0_l0000:
ooooo`;o00001oooool2o`0001Gooooo0_l0000hooooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0[
ooooo`;o00000oooool2o`0000Gooooo0_l0000Iooooo`;o00002?ooool3o`0000Kooooo0_l00007
ooooo`;o00001oooool2o`0000?ooooo0_l00009ooooo`;o00000oooool2o`000003ooooool0003o
000000Ko00001?oooolIo`000003ooooool0003o000000Cooooo0ol000000ooooooo0000o`000003
ooooo`Co00000_ooool2o`000003ooooool0003o000000_ooooo0_l00007ooooo`?o00002Oooool3
o`0000Kooooo0_l000000ooooooo0000o`000005ooooo`;o00002oooool2o`0003Sooooo00000ooo
oooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@06
ooooo`?o0000:oooool2o`0000?ooooo0ol000001?oooooo0000o`000?ooool2o`0002cooooo1Ol0
0009ooooo`;o00001Oooool2o`0000_ooooo0_l00003ooooo`;o000000Coooooo`000?l0003o0000
0oooool2o`0000;ooooo7_l00002ooooo`Co00000_ooool4o`0000Kooooo1ol000000ooooooo0000
o`000003o`0000;ooooo0_l00006ooooo`;o00000_ooool2o`0000Wooooo1?l00008ooooo`;o0000
1Oooool2o`0004Gooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go
0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo02cooooo0_l00003ooooo`;o0000
00?oooooo`000?l000002oooool2o`0000Kooooo0_l00003ooooo`;o000000?oooooo`000?l00000
0_ooool2o`0000oooooo1?l00009ooooo`;o00001Oooool2o`0000_ooooo0_l00005ooooo`Co0000
1OoooolPo`000003ooooool0003o000000Co00000oooool2o`0000Kooooo0_l000000ooooooo0000
o`000002o`000003ooooool0003o000000Co000000?oooooo`000?l000000_ooool6o`0000?ooooo
0_l00003ooooo`;o00001?ooool4o`0000Gooooo0_l0000Hooooo`;o0000=?ooool00003ooooool@
413ooooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo02cooooo0_l00003ooooo`;o00001?ooool2o`0000Sooooo0ol00005ooooo`;o00000ooo
ool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o00002oooool3o`0001[ooooo1_l0
0005ooooo`Co000000?oooooo`000?l000000_oooolCo`000003ooooool0003o000000So000000?o
ooooo`000?l000000_l000000ooooooo0000o`000002o`0000Sooooo0_l00007ooooo`;o00000ooo
ool2o`000004ooooool0003o0000ooooo`Go00001Oooool4o`000003ooooool0003o000000Kooooo
0_l00005ooooo`?o00000oooool2o`0001;ooooo0_l0000dooooo`0000KoooooogMgMonHV9Sooooo
oiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0;Oooool2o`0000;o
oooo0_l00003ooooo`?o00002Oooool2o`0000Wooooo0_l0000:ooooo`;o000000?oooooo`000?l0
00000ol0000;ooooo`;o00001Oooool2o`0000Cooooo0_l00008ooooo`Co00002Oooool5o`000003
ooooool0003o0000013o000000?oooooo`000?l000003Ol00003ooooo`So00000_ooool4o`0000Oo
oooo0ol00008ooooo`Go00001oooool2o`00017ooooo0_l00003ooooo`;o00003Oooool2o`0003Wo
oooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool0
0ol0003oooooooooo`0]ooooo`;o00001oooool2o`0001Gooooo0_l00002ooooo`;o00001_ooool2
o`000003ooooool0003o000000?o00001oooool6o`0000Gooooo0_l00004ooooo`;o00002?ooool2
o`000003ooooool0003o000000Sooooo2?l000000ooooooo0000o`00000Eo`000003ooooool0003o
000000?o00001?ooool2o`000003ooooool0003o000000Co00000_ooool2o`0000;ooooo0ol00005
ooooo`;o00002Oooool4o`000003ooooool0003o000001gooooo0_l0000<ooooo`;o0000>Oooool0
01cooooo00?o0000ooooooooool0>_ooool2o`0001;ooooo0_l000000ooooooo0000o`000006oooo
o`;o00000_ooool4o`0000Oooooo1?l0000<ooooo`?o000000Coooooo`000?l0003ooooo0_l00005
ooooo`;o00001oooool9o`000003ooooool0003o000001So000000Coooooo`000?l0003o00000_oo
ool5o`000003ooooool0003o000000Oooooo1?l00009ooooo`;o00001?ooool2o`000004ooooool0
003o0000ooooo`;o00000oooool2o`00013ooooo0_l00002ooooo`;o00000_ooool2o`0004Oooooo
000Looooo`03o`000?oooooooooo03[ooooo0ol000000ooooooo0000o`000009ooooo`;o00000ooo
ool5o`0000Gooooo0_l00005ooooo`;o00005oooool2o`000005ooooool0003o0000o`000?ooool0
0_l0000;ooooo`;o000000?oooooo`000?l000001?l000000ooooooo0000o`000003o`000003oooo
ool0003o000001Co000000?oooooo`000?l000002Ol000000ooooooo0000o`000007ooooo`Co0000
2Oooool2o`0000;ooooo1?l000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l00000
3Oooool2o`0000;ooooo0_l000000ooooooo0000o`000018ooooo`007?ooool00ol0003ooooooooo
o`0iooooo`Co000000?oooooo`000?l000001_ooool2o`000003ooooool0003o000000Gooooo0ol0
0005ooooo`;o00000_ooool2o`0001[ooooo0_l000000ooooooo0000o`00000>ooooo`?o00000_oo
ool@o`000003ooooool0003o000001;o000000?oooooo`000?l000001_l00008ooooo`;o00001Ooo
ool2o`0000Kooooo0_l00002ooooo`;o00001Oooool2o`0000Oooooo0_l000000ooooooo0000o`00
0007ooooo`;o00001Oooool2o`000003ooooool0003o000000[ooooo0_l0000looooo`007?ooool0
0ol0003oooooooooo`0booooo`;o00001Oooool5o`0000Sooooo0_l00005ooooo`Go00002_ooool2
o`0001;ooooo0_l00007ooooo`Oo00001?ooool2o`0000Gooooo0_l000000ooooooo0000o`00000X
o`0000Cooooo0_l00003ooooo`;o00000oooool2o`0000Gooooo0_l00006ooooo`;o00002Oooool2
o`0000[ooooo0_l00007ooooo`;o00001Oooool2o`0000gooooo0_l0000looooo`007?ooool00ol0
003oooooooooo`0booooo`;o00001oooool3o`0000oooooo1?l00005ooooo`;o00006?ooool2o`00
00Oooooo1ol00004ooooo`Co00001_ooool2o`000003ooooool0003o000002Ko00000oooool2o`00
00?ooooo0_l0000:ooooo`;o00002?ooool2o`0000Oooooo0_l0000Cooooo`;o0000D_ooool001co
oooo00?o0000ooooooooool0;_ooool2o`0000_ooooo0_l00003ooooo`;o00001?ooool3o`0000Go
oooo0_l00006ooooo`;o00005Oooool2o`0001Oooooo0_l00006ooooobSo000000?oooooo`000?l0
00000oooool5o`0000cooooo0_l00008ooooo`;o00000oooool2o`0000;ooooo0_l0000Cooooo`;o
000000?oooooo`000?l000000oooool2o`0000_ooooo0_l0000mooooo`007?ooool00ol0003ooooo
ooooo`0^ooooo`;o00002?ooool2o`000003ooooool0003o000000?ooooo0_l00002ooooo`Go0000
1Oooool4o`0000Cooooo0_l0000@ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o0000
4oooool2o`0000Cooooo0_l00002ooooobWo00001?ooool4o`0000Kooooo0_l0000Cooooo`;o0000
5oooool2o`000003ooooool0003o000000?ooooo0_l0000;ooooo`;o0000?Oooool001cooooo00?o
0000ooooooooool0>?ooool3o`0000Wooooo1?l00008ooooo`;o00001?ooool2o`0000gooooo2?l0
0004ooooo`?o00001_ooool2o`0000[ooooo0_l00004ooooo`;o00000_ooool2o`0000;ooooo8?l0
00000ooooooo0000o`000002o`0000kooooo0_l00020ooooo`007?ooool00ol0003oooooooooo`0i
ooooo`Co00001_ooool2o`0000Gooooo0_l0000Iooooo`?o00000_ooool3o`0000Gooooo0_l00003
ooooo`;o000000Coooooo`000?l0003ooooo0_l0000@ooooobGo000000?oooooo`000?l000000ol0
000Fooooo`;o0000Moooool001cooooo00?o0000ooooooooool0>oooool2o`0000Kooooo0_l00005
ooooo`;o00003Oooool2o`00013ooooo0_l00004ooooo`Go000000?oooooo`000?l000000_ooool4
o`0000kooooo;Ol00007ooooo`;o00003Oooool2o`0002Oooooo0ol0001=ooooo`007?ooool00ol0
003oooooooooo`12ooooo`;o00005Oooool2o`0000[ooooo0_l0000:ooooo`Go00001Oooool2o`00
00;ooooo0_l0000;ooooo`Go000000Coooooo`000?l0003o00000_oooolUo`000003ooooool0003o
000000;ooooo1?l00008ooooo`?o0000:Oooool3o`0004gooooo000Looooo`;o0000>oooool2o`00
00Kooooo0_l0000>ooooo`Co00001?ooool2o`000003ooooool0003o000000Kooooo1?l00003oooo
o`;o000000?oooooo`000?l000001Oooool3o`0000Kooooo0_l0000;ooooo`;o00001?oooolCo`00
0003ooooool0003o000000?o000000?oooooo`000?l000002?l000001?oooooo0000o`000?ooool2
o`000003ooooool0003o000000Cooooo0_l00008ooooo`?o000000?oooooo`000?l00000M_ooool0
01cooooo00?o0000ooooooooool0>_ooool2o`0001Kooooo1?l00004ooooo`;o000000?oooooo`00
0?l000002?ooool2o`0000?ooooo0_l000000ooooooo0000o`000005ooooo`?o00001oooool2o`00
00oooooo9Ol000000ooooooo0000o`00000Aooooo`;o00001Oooool2o`0002Cooooo0_l0001@oooo
o`007?ooool00ol0003oooooooooo`1Booooo`;o00002oooool2o`0000[ooooo0_l00009ooooo`;o
00002?ooool2o`0000Oooooo0_l00004ooooo`Ko000000?oooooo`000?l000001Ol000000ooooooo
0000o`00000Ho`000003ooooool0003o000000oooooo0_l0000[ooooo`?o0000Coooool001cooooo
00?o0000ooooooooool0@oooool2o`0000Gooooo0_l00006ooooo`;o00002oooool3o`0000Oooooo
1?l00009ooooo`;o00003Oooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool3o`000003
ooooool0003o000002Ko00003?ooool2o`0002oooooo0ol0001>ooooo`007?ooool00ol0003ooooo
ooooo`12ooooo`?o00001Oooool2o`0001Cooooo0ol00006ooooo`Co00006?ooool2o`0000Gooooo
0_l000001?oooooo0000o`000?oooolRo`000003ooooool0003o000000Co00001oooool2o`0000?o
oooo0_l0000`ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0@Oooool3o`0001gooooo
1?l0000<ooooo`;o00001?ooool2o`0000Wooooo0_l000000ooooooo0000o`000006ooooo`Co0000
00?oooooo`000?l000009?l000000ooooooo0000o`000007ooooo`;o0000QOooool001cooooo00?o
0000ooooooooool0@Oooool3o`0000Sooooo0ol00007ooooo`;o00002oooool2o`0000cooooo1?l0
00000ooooooo0000o`000003o`0000Oooooo0_l00002ooooo`;o00001Oooool2o`0000Cooooo0_l0
0003ooooob3o00000oooool2o`0000;ooooo0ol00006ooooo`;o00008_ooool2o`0000Sooooo0_l0
001Aooooo`007?ooool00ol0003oooooooooo`12ooooo`Go00000_ooool2o`000003ooooool0003o
000000?o00001Oooool2o`0000_ooooo0ol0000=ooooo`;o000000?oooooo`000?l000000ol0000;
ooooo`;o00001_ooool4o`000004ooooool0003o0000ooooo`Wo000000?oooooo`000?l000004ol0
0006ooooo`;o00000_ooool3o`0000Kooooo0_l0000Rooooo`;o00002?ooool2o`00057ooooo000L
ooooo`03o`000?oooooooooo03cooooo0_l00006ooooo`?o00000_ooool2o`0000Cooooo0_l00007
ooooo`;o00001_ooool2o`0000;ooooo0_l0000Booooo`;o000000?oooooo`000?l000000oooool2
o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`Ko00001?oooolNo`0000;ooooo0_l00007
ooooo`;o00000_ooool2o`0002Oooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`0loooo
o`;o00006Oooool3o`0000Kooooo0_l0000Aooooo`;o00001_ooool2o`0000?ooooo0_l00002oooo
o`Go00000oooool5o`0000Kooooo0_l000000ooooooo0000o`00000Do`000004ooooool0003o0000
o`0000;ooooo0_l0000;ooooo`;o00003Oooool2o`0001gooooo0_l00002ooooo`;o00003Oooool2
o`0004?ooooo000Looooo`03o`000?oooooooooo053ooooo0ol00004ooooo`;o00006Oooool3o`00
00?ooooo0ol0000:ooooo`Ko00000oooool2o`0000Oooooo0_l00002oooooaWo00000_ooool2o`00
00Cooooo0_l0000Dooooo`;o00006oooool4o`0000;ooooo0_l0000=ooooo`;o0000@oooool001co
oooo00?o0000ooooooooool0D?ooool3o`0000Cooooo0_l0000;ooooo`?o00002_ooool3o`0000Co
oooo1Ol00005ooooo`;o00001Oooool2o`000003ooooool0003o000000Gooooo2?l000000ooooooo
0000o`00000?o`000004ooooool0003o0000o`0000?ooooo0_l00006ooooo`?o00005?ooool2o`00
01[ooooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o00001?ooool2o`0000_o
oooo0ol00007ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Cooooo1?l00003ooooo`;o
000000Coooooo`000?l0003ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool;o`00
0003ooooool0003o000000co000000?oooooo`000?l000000_ooool4o`0000Oooooo0_l00002oooo
o`;o00003oooool3o`0001[ooooo0_l000000ooooooo0000o`000002o`0005?ooooo000Looooo`03
o`000?oooooooooo06kooooo0_l00005ooooo`;o00001?ooool4o`0000?ooooo0_l000001?oooooo
0000o`000?ooool2o`0000Gooooo1?l000000ooooooo0000o`000003o`000003ooooool0003o0000
00oo000000Coooooo`000?l0003o00000oooool3o`0000?ooooo1?l00005ooooo`;o00002Oooool2
o`0000Cooooo0_l0000Nooooo`Co00002Oooool2o`0004Sooooo000Looooo`03o`000?oooooooooo
06Sooooo0_l0000>ooooo`Co000000Coooooo`000?l0003o00000_ooool2o`0000gooooo0_l00004
oooooa?o00000_ooool3o`0000;ooooo0_l00005ooooo`Co00001oooool2o`0000Oooooo0_l0000a
ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0@_ooool2o`0000[ooooo0_l0000Hoooo
o`;o00003_ooool4o`000003ooooool0003o000000;o00004?ooool2o`0000Gooooo0ol000000ooo
oooo0000o`000002o`000003ooooool0003o000000?o000000?oooooo`000?l000001Ol00003oooo
o`;o00004?ooool2o`00023ooooo0_l0001Rooooo`007?ooool2o`0004?ooooo0_l0000:ooooo`;o
00008_ooool2o`0000;ooooo0_l00007ooooo`;o00001_ooool2o`0000gooooo0_l000001?oooooo
0000o`000?ooool4o`0000?ooooo2_l00003ooooo`Oo00003?ooool2o`00023ooooo0_l0000:oooo
o`;o0000E_ooool001cooooo00?o0000ooooooooool0C?ooool2o`0000Sooooo0_l00007ooooo`;o
00000_ooool2o`0000gooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00002oooool2o`00
00Oooooo0_l00004ooooo`Ko00000_ooool3o`0000Gooooo0_l000000ooooooo0000o`000003o`00
0003ooooool0003o000000Ko0000;oooool2o`0000Wooooo0_l0001Fooooo`007?ooool00ol0003o
ooooooooo`1<ooooo`;o00002?ooool2o`0000Oooooo0_l00002ooooo`;o00004?ooool2o`0000;o
oooo0ol00005ooooo`Co00000oooool2o`0000Kooooo0ol00002ooooo`Oo00000_ooool3o`0000Go
oooo0_l000000ooooooo0000o`000003o`000003ooooool0003o0000027ooooo0_l0000Booooo`;o
00002Oooool2o`0005Kooooo000Looooo`03o`000?oooooooooo04Oooooo1?l0000;ooooo`;o0000
2oooool2o`0000;ooooo0_l0000:ooooo`Go00002Oooool4o`0000?ooooo0_l00007ooooo`Oo0000
2oooool5o`000003ooooool0003o000000;o00001Oooool2o`0000oooooo0_l00002ooooo`;o0000
2Oooool2o`0001;ooooo0_l00002ooooo`?o00001?ooool2o`0000Oooooo0_l0001=ooooo`007?oo
ool00ol0003oooooooooo`17ooooo`Co00002oooool2o`0000[ooooo0ol000001?oooooo0000o`00
0?l00008ooooo`Oo00002oooool2o`0000?ooooo0_l00009ooooo`;o00002Oooool4o`000003oooo
ool0003o000000;o00000_ooool4o`0000Gooooo0_l00006ooooo`;o00001oooool2o`0000;ooooo
1?l0000Iooooo`;o00001?ooool3o`0000gooooo0_l0001=ooooo`007?ooool00ol0003ooooooooo
o`1;ooooo`;o00001_ooool2o`0000gooooo0_l00002ooooo`;o00002Oooool2o`000003ooooool0
003o000000;ooooo0_l000000ooooooo0000o`000006ooooo`;o00001?ooool2o`0000Cooooo0_l0
0006ooooo`;o00001Oooool9o`0000Cooooo0_l00007ooooo`;o00001?ooool2o`0000gooooo0_l0
000Hooooo`?o00001?ooool2o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l00000Cooo
ool001cooooo00?o0000ooooooooool0Boooool2o`0000Kooooo0_l0000Booooo`;o00001oooool2
o`0000?ooooo0_l000001?oooooo0000o`000?ooool4o`0000Cooooo0_l00004ooooo`;o00001?oo
ool2o`0000Gooooo0ol00006ooooo`;o000000?oooooo`000?l000000ol00003ooooo`;o00002?oo
ool2o`0001?ooooo0_l00005ooooo`;o00004Oooool3o`0000Sooooo0_l00004ooooo`?o000000?o
ooooo`000?l00000Coooool001cooooo00?o0000ooooooooool0BOooool2o`0001cooooo0_l00007
ooooo`;o00000oooool6o`0000;ooooo0_l00004ooooo`;o00004Oooool2o`0000_ooooo1_l00000
0ooooooo0000o`000008ooooo`;o00003oooool2o`0000Kooooo0_l000000ooooooo0000o`00000:
ooooo`;o00000_ooool2o`000003ooooool0003o000000oooooo0_l0001Cooooo`007?ooool00ol0
003oooooooooo`19ooooo`;o00000oooool2o`0000Cooooo0_l0000:ooooo`;o00002_ooool2o`00
0003ooooool0003o000000Kooooo1?l0000Uooooo`;o00000oooool7o`000003ooooool0003o0000
01Kooooo1?l00004ooooo`;o00002oooool4o`0000;ooooo0_l000001?oooooo0000o`000?ooool3
o`0000Sooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o00000_ooool2o`00
00Cooooo0_l0000:ooooo`;o00002_ooool5o`0000;ooooo0_l000001?oooooo0000o`000?ooool2
o`0000Wooooo0ol00003ooooo`;o00003_ooool2o`0000Cooooo0_l00002ooooo`?o00000_ooool3
o`000003ooooool0003o000000Oooooo0_l0000?ooooo`;o00004Oooool2o`0000;ooooo0_l00004
ooooo`Go000000?oooooo`000?l000001Oooool2o`0005Kooooo000Looooo`03o`000?oooooooooo
04[ooooo0_l00002ooooo`;o00006_ooool2o`000003ooooool0003o000000Cooooo0_l000001?oo
oooo0000o`000?ooool2o`0000?ooooo0_l00004ooooo`Go000000?oooooo`000?l000003_ooool3
o`0000Cooooo0_l000000ooooooo0000o`00000@ooooo`;o00009Oooool3o`000004ooooool0003o
0000ooooo`?o00000oooool2o`0005gooooo000Looooo`03o`000?oooooooooo05Gooooo0_l0000C
ooooo`;o00002_ooool2o`0000Kooooo0_l00007ooooo`?o00001oooool2o`0000Cooooo0_l00002
ooooo`;o00001?ooool2o`0000Gooooo0_l0000cooooo`;o00000_ooool2o`0006Kooooo000Loooo
o`03o`000?oooooooooo053ooooo0_l00002ooooo`?o00003Oooool2o`0000?ooooo0_l0000Foooo
o`;o00001?ooool3o`0000Oooooo0_l00004ooooo`;o00003oooool2o`0000?ooooo0_l00003oooo
o`;o00000oooool2o`00023ooooo0_l00006ooooo`;o00000_ooool2o`0000Cooooo0_l00004oooo
o`;o0000E_ooool001cooooo00?o0000ooooooooool0D?ooool2o`0000;ooooo0_l00005ooooo`;o
00001oooool2o`0000?ooooo0_l0000Fooooo`;o00001?ooool4o`0000?ooooo0_l0000Jooooo`;o
000000?oooooo`000?l000000_ooool3o`0000?ooooo0_l0000@ooooo`;o00003Oooool3o`0000[o
oooo0_l00004ooooo`;o00001?ooool2o`0005Kooooo000Looooo`03o`000?oooooooooo05_ooooo
1?l00006ooooo`;o00002oooool2o`0001?ooooo1_l000000ooooooo0000o`000007ooooo`;o0000
4Oooool2o`0000Gooooo0ol00005ooooo`;o00003_ooool2o`0000_ooooo1?l00008ooooo`;o0000
IOooool001cooooo00?o0000ooooooooool0D?ooool2o`0000_ooooo0_l00006ooooo`;o00001_oo
ool2o`0000;ooooo1?l00006ooooo`Co000000?oooooo`000?l000002Oooool2o`0000?ooooo0_l0
0005ooooo`Co00005Oooool6o`0000?ooooo0ol00005ooooo`;o00002Oooool2o`0000Sooooo0_l0
000:ooooo`;o0000IOooool001cooooo0_l0001Aooooo`;o00004?ooool2o`0000Wooooo0_l00002
ooooo`Co00001_ooool4o`000003ooooool0003o000000Oooooo0_l000000ooooooo0000o`000004
o`0000Oooooo0ol00005ooooo`;o00002oooool4o`0000;ooooo0_l00004ooooo`;o00001Oooool2
o`0000Sooooo1Ol00005ooooo`?o0000LOooool001cooooo00?o0000ooooooooool0D_ooool2o`00
00kooooo0_l0000Pooooo`;o00000oooool2o`000003ooooool0003o000000Go00001oooool2o`00
00;ooooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l00003ooooo`;o00006oooool2o`00
0003ooooool0003o000000Gooooo0_l0000@ooooo`;o0000H?ooool001cooooo00?o0000oooooooo
ool0D_ooool2o`0000Gooooo0_l0000>ooooo`;o000000?oooooo`000?l000004Oooool2o`0000?o
oooo0_l00002ooooo`?o00000_ooool7o`0000[ooooo1?l000000ooooooo0000o`000004ooooo`;o
00000_ooool2o`00013ooooo0_l0000Dooooo`;o00004?ooool2o`00063ooooo000Looooo`03o`00
0?oooooooooo05Wooooo0_l00005ooooo`;o00001oooool2o`000003ooooool0003o0000017ooooo
0_l00003ooooo`;o00000_ooool3o`0000;ooooo1?l000000ooooooo0000o`000002o`000003oooo
ool0003o000000Oooooo0_l0000;ooooo`;o00002?ooool4o`0000;ooooo1Ol00007ooooo`Ko0000
3_ooool2o`0006[ooooo000Looooo`03o`000?oooooooooo05Sooooo0_l00006ooooo`;o00002_oo
ool3o`0001Cooooo0_l00004ooooo`;o00001oooool7o`0001?ooooo0_l00002ooooo`;o000000?o
ooooo`000?l000000_ooool4o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`So00003_oo
ool2o`0000Wooooo0_l0001Oooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o00004oooool3
o`00013ooooo0_l000000ooooooo0000o`00000>ooooo`Co00001?ooool2o`0000Oooooo0_l00002
ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00001Oooool2
o`0000Kooooo0ol0000Oooooo`;o00002Oooool2o`0005Cooooo000Looooo`03o`000?oooooooooo
05Sooooo0_l00005ooooo`;o00002Oooool2o`0000;ooooo0_l0000@ooooo`;o00001Oooool2o`00
00Wooooo2?l000000ooooooo0000o`000007ooooo`;o00000_ooool2o`0000Wooooo0_l00009oooo
o`;o00001_ooool2o`0000?ooooo0ol00008ooooo`;o00006oooool2o`0005Cooooo000Looooo`03
o`000?oooooooooo05gooooo1?l00006ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`00
01Kooooo0_l00003ooooo`;o00001?ooool2o`000003ooooool0003o000000?o00006Oooool2o`00
00Kooooo0_l0000=ooooo`Co00002?ooool2o`00077ooooo000Looooo`03o`000?oooooooooo05go
oooo0_l00008ooooo`;o00000_ooool2o`0000;ooooo0_l00007ooooo`?o00001oooool2o`0000Ko
oooo1?l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00000Aoooo
o`;o00002Oooool4o`0000;ooooo0_l00003ooooo`;o00001?ooool2o`0000cooooo0_l0001_oooo
o`007?ooool00ol0003oooooooooo`1Yooooo`;o00003Oooool3o`0000Oooooo0_l00006ooooo`Co
00001oooool2o`000003ooooool0003o000000?o00004?ooool3o`0000Cooooo0_l00003ooooo`;o
00001?ooool3o`0000;ooooo0_l0000Booooo`;o0000Koooool001cooooo00?o0000ooooooooool0
GOooool2o`0000Gooooo0ol00002ooooo`;o00008Oooool2o`0000_ooooo0_l00008ooooo`?o0000
1oooool2o`0000Gooooo0_l00006ooooo`Ko00001oooool2o`0000_ooooo0_l0000Looooo`;o0000
Doooool001cooooo00?o0000ooooooooool0GOooool2o`0000Gooooo0ol00005ooooo`;o00000_oo
ool2o`0000gooooo0_l0000>ooooo`;o00004_ooool3o`0001Kooooo1?l00009ooooo`;o00002ooo
ool2o`0001cooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`1/ooooo`;o00000_ooool2
o`0000gooooo0_l0000>ooooo`;o00004_ooool2o`0001?ooooo0_l0000>ooooo`;o00001oooool2
o`0007Kooooo000Looooo`03o`000?oooooooooo06cooooo0_l0000;ooooo`;o00000_ooool2o`00
01kooooo0_l00002ooooo`Co00002oooool2o`0000Kooooo0_l0000>ooooo`;o00001oooool2o`00
00Cooooo0ol0001_ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool0
1Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0IOooool2o`0001;ooooo0_l0
0002ooooo`;o00007_ooool2o`0000;ooooo0_l00002ooooo`;o00000_ooool3o`0000Cooooo1Ol0
0009ooooo`;o000000?oooooo`000?l000003Oooool2o`0000Gooooo0ol0000Dooooo`;o0000FOoo
ool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?oooooo
V9RHob4Q8@06ooooo`03o`000?oooooooooo06Gooooo1Ol0000Mooooo`;o00001Oooool2o`00017o
oooo0_l00002ooooo`;o00000_ooool4o`0000;ooooo1_l00009ooooo`;o000000?oooooo`000?l0
00003Oooool2o`0000;ooooo0_l0000Hooooo`;o0000FOooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool0I_ooool5o`0001cooooo0_l00005ooooo`;o00003Oooool3o`0000;ooooo0_l00005ooooo`Co
00000_ooool3o`000003ooooool0003o000000cooooo1?l0000=ooooo`Oo0000L?ooool00003oooo
ool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Olb<S;oV9RHoooooonHV9So<S8b00Ko
oooo0ol0001Yooooo`;o000000?oooooo`000?l000005_ooool2o`0000Cooooo0_l00003ooooo`;o
00003?ooool3o`0000;ooooo0_l00004ooooo`;o00000oooool2o`000004ooooool0003o0000oooo
o`Ko00002?ooool4o`0000gooooo0_l000000ooooooo0000o`000002o`00073ooooo00000ooooooo
0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Goc<c<o`000?l0003o0000olc<c006oooo
o`03o`000?oooooooooo06cooooo0_l00006ooooo`;o00003_ooool4o`0000;ooooo0_l00003oooo
o`;o00005oooool2o`0000?ooooo0ol00005ooooo`Co00005_ooool2o`0007Sooooo00000ooooooo
410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go410@okZj^_oooooo^[Zjoa0@4006oooo
o`03o`000?oooooooooo06Gooooo0_l0000=ooooo`;o00001Oooool2o`0000Wooooo0_l00004oooo
o`;o00008?ooool2o`0000Kooooo0ol0000Fooooo`;o0000N?ooool00006oooooomgMgOoV9RHoooo
oonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0IOoo
ool2o`0001Cooooo0_l00006ooooo`;o00001oooool2o`0000gooooo0_l0000?ooooo`?o00001ooo
ool3o`00093ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@06ooooo`03o`000?oooooooooo08?ooooo0_l00005ooooo`;o00000oooool2o`0000[o
oooo0_l00003ooooo`;o00001oooool2o`000004ooooool0003o0000o`0001Cooooo0_l00003oooo
o`;o0000Ooooool001cooooo00?o0000ooooooooool0P?ooool2o`0000Sooooo0_l00003ooooo`;o
00003oooool3o`0000Kooooo0_l0000?ooooo`;o00001oooool2o`0000?ooooo0_l00002ooooo`;o
0000Noooool001cooooo00?o0000ooooooooool0P?ooool4o`0000[ooooo0_l000000ooooooo0000
o`00000>ooooo`;o00005oooool2o`0000Oooooo0_l00007ooooo`;o0000Noooool001cooooo00?o
0000ooooooooool0P_ooool2o`0000;ooooo0_l00006ooooo`;o000000?oooooo`000?l00000]_oo
ool001cooooo00?o0000ooooooooool0Q_ooool2o`0000_ooooo0_l0000Booooo`;o00000oooool2
o`0002oooooo0_l0001Zooooo`007?ooool00ol0003oooooooooo`2Cooooo`;o00003oooool2o`00
0003ooooool0003o000000?ooooo0_l0000_ooooo`;o0000J_ooool001cooooo00?o0000oooooooo
ool0Soooool2o`0001?ooooo0_l0002Sooooo`007?ooool00ol0003oooooooooo`2?ooooo`;o0000
4_ooool2o`0000?ooooo0_l0002Oooooo`007?ooool00ol0003oooooooooo`1booooo`;o00000ooo
ool2o`0001Wooooo0_l0000=ooooo`Co00000oooool2o`0002;ooooo0_l0001kooooo`007?ooool0
0ol0003oooooooooo`1booooo`;o00000oooool2o`0001Wooooo1?l0000;ooooo`;o00000_ooool2
o`0002Gooooo0_l0001kooooo`007?ooool00ol0003oooooooooo`2Dooooo`;o00003oooool2o`00
01[ooooo0_l00026ooooo`007?ooool00ol0003oooooooooo`1gooooo`;o00006oooool2o`0002_o
oooo0_l00007ooooo`?o0000O?ooool001cooooo0_l0001hooooo`;o0000B?ooool2o`0000Oooooo
0ol0001looooo`007?ooool00ol0003oooooooooo`2Yooooo`;o00005_ooool2o`0008Kooooo000L
ooooo`03o`000?oooooooooo0:Wooooo0_l00007ooooo`;o0000UOooool001cooooo00?o0000oooo
ooooool0/_ooool2o`0009Gooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooo
oom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o
0000ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Co
oooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo
000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomB
ooooo`004_ooool00omEEEGoIVIVo`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo002Uooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05ooo
ool00ol0003ok^k^ooooo`03ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo<c<co8B4Q
o`000?lQ8B7oc<c<093ooooo002Vooooo`05o`000?ooooooooooooooool000002Oooool6o`0000_o
oooo00?oEEEEojVYZOooool00oooool01OmEEEGoMgMgoooooonHV9So8B4Q00?ooooo00Go8B4QoiRH
V?ooooooV9RHob4Q8@2@ooooo`00Y_ooool01Ol0003ooooooooooooooooo000001[ooooo00?oZJVY
oeEEEOooool00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`00002@ooooo`00Y_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l0000<ooooo`03ob4Q
8Ooooooooooo00;ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05oc8b<_nHV9SooooooiRH
V?lb<S80T?ooool00:Kooooo00Go0000ohN7QoooooooZJVYo`00000Kooooo`03oeEEEOo<c<cooooo
00;ooooo00Go0000oeEEEOl0003o410@olc<c003ooooo`05olc<c?l0003o0000o`000?o<c<`0T?oo
ool00:Gooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Iooooo`03ojVYZOmgMgOo
oooo00;ooooo00?oEEEEohN7Qoooool01Oooool01Ol@413o^[Zjoooooonj^[[o410@093ooooo0033
ooooo`05oa0@4?oooooooooooooooolb<S800oooool00ooMgMgo410@oiRHV005ooooo`05o`000?nj
^[[ooooookZj^_l00000T?ooool00<?ooooo1Ol00004ooooo`04olc<c?m4A4Co0000oa0@40?ooooo
00GoZJVYoa0@4?l0003o410@ojVYZ@2@ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(774) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.64754 .51782 Mdot
.65824 .5212 Mdot
.38373 .4002 Mdot
.53813 .6306 Mdot
.426 .52483 Mdot
.39889 .34387 Mdot
.56289 .38802 Mdot
.52737 .4002 Mdot
.37924 .34993 Mdot
.60788 .63293 Mdot
.58026 .36483 Mdot
.44587 .69853 Mdot
.55405 .38139 Mdot
.48787 .62357 Mdot
.40035 .18138 Mdot
.48409 .70066 Mdot
.68931 .55995 Mdot
.31253 .51569 Mdot
.5584 .66315 Mdot
.36105 .37563 Mdot
.63748 .5712 Mdot
.48437 .62677 Mdot
.65028 .53266 Mdot
.48786 .62507 Mdot
.52619 .63595 Mdot
.69128 .52408 Mdot
.64229 .55026 Mdot
.5155 .66688 Mdot
.50832 .61994 Mdot
.57613 .40132 Mdot
.39524 .50569 Mdot
.25922 .27828 Mdot
.47112 .7029 Mdot
.56251 .79507 Mdot
.54093 .40469 Mdot
.21422 .59526 Mdot
.37422 .37399 Mdot
.54612 .35737 Mdot
.53489 .40432 Mdot
.52609 .38206 Mdot
.53918 .36703 Mdot
.68856 .51941 Mdot
.57966 .34357 Mdot
.58635 .42913 Mdot
.54354 .63314 Mdot
.67039 .37641 Mdot
.25233 .55964 Mdot
.5071 .66556 Mdot
.67492 .50125 Mdot
.35811 .35811 Mdot
.66521 .78103 Mdot
.51969 .36975 Mdot
.56998 .22263 Mdot
.34147 .14218 Mdot
.53765 .38603 Mdot
.54005 .64394 Mdot
.39301 .36751 Mdot
.4719 .65146 Mdot
.4865 .64172 Mdot
.67752 .75235 Mdot
.51373 .64432 Mdot
.33343 .52948 Mdot
.71335 .5644 Mdot
.43184 .37734 Mdot
.38867 .34607 Mdot
.55286 .40829 Mdot
.71289 .5395 Mdot
.56047 .37391 Mdot
.49611 .56953 Mdot
.36535 .35174 Mdot
.50653 .66717 Mdot
.57651 .36006 Mdot
.71502 .5029 Mdot
.45515 .62385 Mdot
.70213 .39731 Mdot
.47252 .16961 Mdot
.31823 .49599 Mdot
.6629 .74423 Mdot
.7812 .55488 Mdot
.48765 .20046 Mdot
.49742 .6231 Mdot
.82757 .36906 Mdot
.41739 .17626 Mdot
.65391 .53502 Mdot
.40306 .59541 Mdot
.45015 .38436 Mdot
.46691 .61605 Mdot
.43515 .48191 Mdot
.4503 .59838 Mdot
.76258 .45809 Mdot
.37637 .35561 Mdot
.69153 .51042 Mdot
.53777 .624 Mdot
.45129 .66439 Mdot
.69215 .64758 Mdot
.45448 .60487 Mdot
.5175 .67308 Mdot
.64788 .56393 Mdot
.57779 .39127 Mdot
.42846 .62096 Mdot
.61248 .40554 Mdot
.57509 .23281 Mdot
.51167 .59682 Mdot
.37977 .33859 Mdot
.68953 .56636 Mdot
.51699 .59474 Mdot
.5382 .39447 Mdot
.5041 .64075 Mdot
.61007 .38993 Mdot
.65874 .51214 Mdot
.45083 .66092 Mdot
.3141 .51904 Mdot
.75395 .41076 Mdot
.70656 .51805 Mdot
.7501 .30575 Mdot
.51051 .65241 Mdot
.48 .63232 Mdot
.66075 .52121 Mdot
.41298 .36911 Mdot
.42161 .47362 Mdot
.72062 .52597 Mdot
.52856 .39422 Mdot
.64435 .54278 Mdot
.52854 .58726 Mdot
.40627 .33833 Mdot
.58 .23507 Mdot
.56882 .26132 Mdot
.37908 .74198 Mdot
.47364 .60967 Mdot
.60802 .33159 Mdot
.40802 .34891 Mdot
.68087 .51191 Mdot
.55731 .37307 Mdot
.51953 .68005 Mdot
.68636 .55379 Mdot
.55922 .36127 Mdot
.31809 .5187 Mdot
.24423 .4545 Mdot
.70317 .50369 Mdot
.58311 .49781 Mdot
.596 .39581 Mdot
.52684 .38121 Mdot
.57987 .81299 Mdot
.65877 .52602 Mdot
.35016 .50882 Mdot
.56248 .36356 Mdot
.35551 .62243 Mdot
.51632 .68071 Mdot
.43656 .76465 Mdot
.83653 .46071 Mdot
.64475 .79832 Mdot
.65557 .27936 Mdot
.35611 .53744 Mdot
.53045 .36373 Mdot
.52627 .61798 Mdot
.66687 .53157 Mdot
.67427 .52477 Mdot
.4665 .68193 Mdot
.52352 .64519 Mdot
.47943 .67836 Mdot
.46525 .67751 Mdot
.25312 .53824 Mdot
.4762 .67961 Mdot
.35471 .32003 Mdot
.70902 .53382 Mdot
.51962 .6305 Mdot
.40389 .38742 Mdot
.51908 .69238 Mdot
.55264 .35751 Mdot
.48177 .64329 Mdot
.52905 .6483 Mdot
.47021 .59823 Mdot
.53557 .36616 Mdot
.21789 .3501 Mdot
.82273 .45082 Mdot
.17542 .50135 Mdot
.69292 .29365 Mdot
.40331 .36477 Mdot
.47125 .61941 Mdot
.33326 .5151 Mdot
.5414 .55483 Mdot
.49114 .6424 Mdot
.7309 .73199 Mdot
.523 .65897 Mdot
.54364 .77168 Mdot
.57079 .6513 Mdot
.16575 .48866 Mdot
.47658 .41019 Mdot
.50927 .62513 Mdot
.6666 .62261 Mdot
.46863 .79035 Mdot
.4915 .53532 Mdot
.53716 .37465 Mdot
.41186 .38063 Mdot
.38553 .37288 Mdot
.58703 .35015 Mdot
.44702 .59163 Mdot
.59581 .64684 Mdot
.4301 .60664 Mdot
.58045 .24138 Mdot
.72655 .51389 Mdot
.36478 .5079 Mdot
.68885 .49747 Mdot
.76801 .28187 Mdot
.72327 .45566 Mdot
.57775 .41786 Mdot
.31235 .53864 Mdot
.39921 .39527 Mdot
.58283 .24475 Mdot
.33868 .5107 Mdot
.49636 .66827 Mdot
.68029 .50276 Mdot
.49013 .80166 Mdot
.56856 .64838 Mdot
.3764 .80348 Mdot
.66539 .55322 Mdot
.46382 .45125 Mdot
.54542 .37056 Mdot
.35317 .35859 Mdot
.48702 .60938 Mdot
.46608 .66805 Mdot
.68912 .5728 Mdot
.50647 .66224 Mdot
.76242 .53871 Mdot
.53034 .6513 Mdot
.44239 .35629 Mdot
.36294 .48402 Mdot
.55556 .3449 Mdot
.39071 .74854 Mdot
.69241 .48894 Mdot
.33584 .31438 Mdot
.36453 .37463 Mdot
.61132 .59811 Mdot
.58264 .36651 Mdot
.31568 .52389 Mdot
.37875 .38832 Mdot
.36311 .5415 Mdot
.50079 .59434 Mdot
.37094 .37142 Mdot
.36054 .51046 Mdot
.22564 .43836 Mdot
.54121 .65052 Mdot
.31274 .58094 Mdot
.56841 .38294 Mdot
.64031 .53255 Mdot
.51426 .64313 Mdot
.56904 .26324 Mdot
.55261 .61664 Mdot
.58252 .28272 Mdot
.56413 .23185 Mdot
.57236 .22347 Mdot
.45475 .19414 Mdot
.3332 .54147 Mdot
.6831 .32936 Mdot
.60968 .46737 Mdot
.71211 .54218 Mdot
.54009 .62487 Mdot
.18159 .40761 Mdot
.56081 .36366 Mdot
.49467 .66661 Mdot
.44965 .37303 Mdot
.56445 .36487 Mdot
.46722 .64653 Mdot
.53142 .37312 Mdot
.66849 .52812 Mdot
.34001 .40368 Mdot
.66752 .56234 Mdot
.5382 .65394 Mdot
.54648 .39558 Mdot
.38972 .38498 Mdot
.69014 .52662 Mdot
.50161 .64304 Mdot
.47904 .61785 Mdot
.57622 .24718 Mdot
.51594 .62515 Mdot
.18777 .40971 Mdot
.5122 .66791 Mdot
.4187 .38652 Mdot
.45244 .60417 Mdot
.64917 .80806 Mdot
.25234 .44653 Mdot
.71571 .52516 Mdot
.56802 .22756 Mdot
.38055 .3562 Mdot
.33609 .41011 Mdot
.53841 .51969 Mdot
.49984 .63052 Mdot
.56625 .24082 Mdot
.43524 .44988 Mdot
.55696 .40939 Mdot
.47239 .58626 Mdot
.72696 .4448 Mdot
.37247 .38859 Mdot
.58103 .24467 Mdot
.49633 .71423 Mdot
.6859 .56771 Mdot
.53747 .63429 Mdot
.37471 .37991 Mdot
.643 .54132 Mdot
.54487 .65615 Mdot
.24529 .5897 Mdot
.56219 .24998 Mdot
.56803 .3813 Mdot
.58449 .64849 Mdot
.48909 .68029 Mdot
.39214 .37668 Mdot
.66004 .54345 Mdot
.55001 .4029 Mdot
.70042 .52267 Mdot
.47305 .7962 Mdot
.70668 .3106 Mdot
.23036 .52024 Mdot
.30995 .53516 Mdot
.59768 .26271 Mdot
.17664 .52253 Mdot
.71092 .34238 Mdot
.34287 .67741 Mdot
.20153 .63556 Mdot
.39522 .38942 Mdot
.3676 .57969 Mdot
.38536 .35963 Mdot
.5198 .60756 Mdot
.39445 .34349 Mdot
.15983 .48068 Mdot
.5225 .66349 Mdot
.40107 .36748 Mdot
.30444 .4649 Mdot
.51967 .64465 Mdot
.71076 .52429 Mdot
.34734 .22058 Mdot
.80171 .49498 Mdot
.70753 .46438 Mdot
.40844 .36795 Mdot
.76741 .65256 Mdot
.51701 .66019 Mdot
.50286 .70042 Mdot
.67174 .53316 Mdot
.46179 .58959 Mdot
.35515 .49715 Mdot
.35807 .54797 Mdot
.43562 .75798 Mdot
.78386 .3579 Mdot
.46258 .57286 Mdot
.68603 .52762 Mdot
.76927 .56882 Mdot
.6988 .39831 Mdot
.58455 .26097 Mdot
.55974 .41552 Mdot
.22467 .34481 Mdot
.53623 .56541 Mdot
.58192 .50331 Mdot
.72028 .43679 Mdot
.6786 .50639 Mdot
.20973 .43116 Mdot
.54035 .38576 Mdot
.71137 .60063 Mdot
.59709 .73688 Mdot
.48032 .6741 Mdot
.58565 .3884 Mdot
.42975 .6691 Mdot
.77493 .48549 Mdot
.36681 .5987 Mdot
.54184 .24487 Mdot
.54251 .64348 Mdot
.68851 .34179 Mdot
.48147 .6366 Mdot
.41687 .73599 Mdot
.51067 .67252 Mdot
.70146 .52864 Mdot
.43979 .58622 Mdot
.47039 .49368 Mdot
.81278 .40462 Mdot
.73645 .46275 Mdot
.35823 .53838 Mdot
.47906 .62158 Mdot
.47543 .67248 Mdot
.34766 .53606 Mdot
.68906 .53798 Mdot
.50758 .67594 Mdot
.29188 .67591 Mdot
.48544 .67813 Mdot
.55193 .35628 Mdot
.39443 .48369 Mdot
.65667 .47521 Mdot
.45047 .63999 Mdot
.65985 .56282 Mdot
.53324 .37948 Mdot
.53518 .40679 Mdot
.543 .57765 Mdot
.53194 .36394 Mdot
.53717 .63893 Mdot
.38264 .46617 Mdot
.65057 .52639 Mdot
.50562 .71898 Mdot
.68705 .54223 Mdot
.78381 .59356 Mdot
.5302 .38024 Mdot
.58361 .25705 Mdot
.56511 .54603 Mdot
.54763 .38735 Mdot
.78483 .5248 Mdot
.51119 .55891 Mdot
.55553 .64759 Mdot
.79127 .51546 Mdot
.40583 .37932 Mdot
.58584 .24855 Mdot
.54244 .3972 Mdot
.48392 .67992 Mdot
.49631 .58946 Mdot
.57749 .35682 Mdot
.71494 .65278 Mdot
.3409 .42276 Mdot
.51552 .67171 Mdot
.69867 .53279 Mdot
.68459 .51269 Mdot
.54848 .64662 Mdot
.49677 .64638 Mdot
.41966 .38367 Mdot
.56499 .24886 Mdot
.58473 .23028 Mdot
.57189 .26168 Mdot
.3599 .33392 Mdot
.60683 .29114 Mdot
.52621 .38075 Mdot
.62807 .33256 Mdot
.46982 .32448 Mdot
.56142 .60347 Mdot
.39435 .37914 Mdot
.46157 .65456 Mdot
.51237 .60238 Mdot
.55247 .40232 Mdot
.65549 .2429 Mdot
.42695 .69598 Mdot
.66767 .49801 Mdot
.53777 .35725 Mdot
.5815 .58532 Mdot
.49341 .38666 Mdot
.35145 .49821 Mdot
.73871 .475 Mdot
.58647 .38115 Mdot
.69432 .508 Mdot
.5817 .35645 Mdot
.4773 .67471 Mdot
.47922 .69051 Mdot
.66229 .51405 Mdot
.33406 .5427 Mdot
.49846 .5865 Mdot
.46766 .6448 Mdot
.75498 .73972 Mdot
.70271 .39248 Mdot
.50237 .36787 Mdot
.51701 .61643 Mdot
.56063 .62653 Mdot
.35176 .54454 Mdot
.49142 .67689 Mdot
.48384 .61003 Mdot
.76304 .41337 Mdot
.5789 .33851 Mdot
.3426 .48616 Mdot
.71104 .59821 Mdot
.66816 .55372 Mdot
.20583 .38837 Mdot
.57436 .23106 Mdot
.55519 .33974 Mdot
.34131 .40389 Mdot
.57991 .2549 Mdot
.49102 .31954 Mdot
.20842 .40802 Mdot
.57858 .25937 Mdot
.34798 .40291 Mdot
.41153 .5967 Mdot
.49866 .6884 Mdot
.47831 .64375 Mdot
.33091 .5129 Mdot
.66079 .52792 Mdot
.46522 .42813 Mdot
.24056 .39758 Mdot
.48284 .6288 Mdot
.68827 .58011 Mdot
.2301 .37443 Mdot
.57863 .24894 Mdot
.32831 .5312 Mdot
.36349 .50098 Mdot
.4787 .63471 Mdot
.74848 .37831 Mdot
.68901 .52462 Mdot
.50133 .64278 Mdot
.45374 .65834 Mdot
.40715 .37132 Mdot
.69255 .50494 Mdot
.36395 .37231 Mdot
.56166 .23828 Mdot
.26865 .71704 Mdot
.73137 .76037 Mdot
.56535 .39725 Mdot
.18444 .48647 Mdot
.51846 .39605 Mdot
.52458 .19976 Mdot
.56918 .25914 Mdot
.49373 .63458 Mdot
.70273 .49376 Mdot
.50472 .64303 Mdot
.48567 .66963 Mdot
.49491 .67001 Mdot
.45555 .57693 Mdot
.72274 .74088 Mdot
.34545 .51776 Mdot
.55402 .59969 Mdot
.42874 .36123 Mdot
.18679 .44805 Mdot
.33624 .24201 Mdot
.45721 .64023 Mdot
.47602 .63131 Mdot
.70431 .54598 Mdot
.44858 .66723 Mdot
.57267 .40546 Mdot
.65442 .53943 Mdot
.50289 .58972 Mdot
.20972 .45136 Mdot
.5022 .67997 Mdot
.1818 .53267 Mdot
.58047 .35617 Mdot
.73608 .47472 Mdot
.54034 .58771 Mdot
.57861 .26012 Mdot
.58555 .24982 Mdot
.59121 .25402 Mdot
.58156 .40248 Mdot
.39801 .37279 Mdot
.2942 .321 Mdot
.43493 .66244 Mdot
.5289 .62298 Mdot
.55884 .61819 Mdot
.34983 .36275 Mdot
.41133 .49326 Mdot
.6602 .29365 Mdot
.56004 .57089 Mdot
.42408 .36677 Mdot
.63901 .52154 Mdot
.72693 .26791 Mdot
.65626 .54048 Mdot
.34558 .48522 Mdot
.56632 .3582 Mdot
.34536 .49681 Mdot
.7563 .68687 Mdot
.65718 .51676 Mdot
.68711 .57313 Mdot
.4028 .36657 Mdot
.48718 .44532 Mdot
.22581 .25288 Mdot
.38392 .33328 Mdot
.32482 .69904 Mdot
.67685 .53358 Mdot
.45325 .62016 Mdot
.42481 .45228 Mdot
.48698 .45057 Mdot
.3951 .35808 Mdot
.49419 .62014 Mdot
.7854 .37681 Mdot
.41674 .38617 Mdot
.47524 .58646 Mdot
.41394 .35632 Mdot
.54403 .36371 Mdot
.41018 .35231 Mdot
.66012 .49426 Mdot
.50276 .59629 Mdot
.29562 .18217 Mdot
.55296 .44696 Mdot
.51166 .64183 Mdot
.53739 .35766 Mdot
.28176 .67763 Mdot
.47603 .66492 Mdot
.34944 .49516 Mdot
.41788 .34493 Mdot
.32436 .4259 Mdot
.51625 .65724 Mdot
.40066 .35078 Mdot
.65277 .50499 Mdot
.5149 .3606 Mdot
.47437 .18476 Mdot
.58696 .23765 Mdot
.66243 .534 Mdot
.59535 .22861 Mdot
.59216 .39642 Mdot
.4705 .59365 Mdot
.45883 .66812 Mdot
.70613 .53233 Mdot
.45102 .23005 Mdot
.44204 .64916 Mdot
.49729 .62315 Mdot
.38363 .39843 Mdot
.34913 .38765 Mdot
.39183 .24232 Mdot
.39615 .38833 Mdot
.56006 .61919 Mdot
.70591 .53098 Mdot
.52256 .60513 Mdot
.71235 .52477 Mdot
.53971 .62477 Mdot
.73707 .50484 Mdot
.65672 .53651 Mdot
.73797 .32107 Mdot
.50109 .60787 Mdot
.57652 .65044 Mdot
.48905 .67132 Mdot
.50299 .67214 Mdot
.41276 .33854 Mdot
.34987 .52879 Mdot
.44363 .61168 Mdot
.33484 .32578 Mdot
.32235 .52573 Mdot
.50619 .77956 Mdot
.40837 .37228 Mdot
.32999 .50924 Mdot
.27861 .55816 Mdot
.56969 .22686 Mdot
.33781 .52095 Mdot
.32222 .26109 Mdot
.56222 .3995 Mdot
.64843 .54331 Mdot
.51999 .64328 Mdot
.22705 .67919 Mdot
.39014 .49252 Mdot
.57095 .24875 Mdot
.51295 .65314 Mdot
.4649 .65875 Mdot
.69382 .56292 Mdot
.79819 .31858 Mdot
.37107 .40035 Mdot
.53259 .61857 Mdot
.68437 .56049 Mdot
.83754 .44491 Mdot
.39938 .33415 Mdot
.33389 .51972 Mdot
.56273 .3526 Mdot
.63079 .51628 Mdot
.58771 .23811 Mdot
.55343 .41017 Mdot
.38021 .43335 Mdot
.77918 .64956 Mdot
.51115 .66 Mdot
.38637 .37977 Mdot
.65159 .79431 Mdot
.43852 .60471 Mdot
.5603 .32435 Mdot
.50233 .75748 Mdot
.6825 .50682 Mdot
.56917 .35346 Mdot
.36802 .52411 Mdot
.64813 .53198 Mdot
.69054 .53633 Mdot
.52432 .39563 Mdot
.40342 .31423 Mdot
.46685 .45153 Mdot
.56585 .35476 Mdot
.76635 .45323 Mdot
.49332 .79578 Mdot
.56512 .24245 Mdot
.33056 .53584 Mdot
.5071 .81369 Mdot
.69 .51953 Mdot
.22315 .34632 Mdot
.70724 .75078 Mdot
.51742 .67308 Mdot
.3497 .50311 Mdot
.48936 .33464 Mdot
.286 .32619 Mdot
.56832 .36684 Mdot
.43067 .49515 Mdot
.34362 .49273 Mdot
.50315 .68389 Mdot
.63745 .48203 Mdot
.50327 .61076 Mdot
.55335 .36064 Mdot
.77409 .52737 Mdot
.69927 .50989 Mdot
.59515 .38809 Mdot
.77496 .50848 Mdot
.50998 .60188 Mdot
.49665 .61334 Mdot
.38688 .7021 Mdot
.67949 .50215 Mdot
.58742 .23346 Mdot
.50458 .63353 Mdot
.47375 .65 Mdot
.46558 .59667 Mdot
.59075 .61215 Mdot
.73882 .3855 Mdot
.53071 .61454 Mdot
.37073 .32808 Mdot
.53172 .68411 Mdot
.49491 .61138 Mdot
.67759 .5641 Mdot
.74036 .74293 Mdot
.5606 .25321 Mdot
.47985 .64649 Mdot
.50903 .67157 Mdot
.53304 .40152 Mdot
.45085 .44808 Mdot
.49413 .45425 Mdot
.3692 .34591 Mdot
.33828 .64891 Mdot
.44343 .59095 Mdot
.68137 .55386 Mdot
.31634 .51175 Mdot
.46983 .60678 Mdot
.68591 .55588 Mdot
.51716 .68868 Mdot
.42221 .37852 Mdot
.56561 .24681 Mdot
.62539 .47539 Mdot
.33601 .52613 Mdot
.44889 .41695 Mdot
.64343 .37233 Mdot
.40828 .385 Mdot
.52765 .6286 Mdot
.51968 .36213 Mdot
.36689 .36267 Mdot
.57438 .24633 Mdot
.51202 .70977 Mdot
.67716 .52585 Mdot
.69997 .51328 Mdot
.42903 .75239 Mdot
.37763 .40711 Mdot
.83728 .57318 Mdot
.5452 .36313 Mdot
.53402 .5976 Mdot
.62503 .39408 Mdot
.70304 .51505 Mdot
.41978 .75321 Mdot
.32851 .51119 Mdot
.56989 .36859 Mdot
.57558 .26935 Mdot
.69274 .55287 Mdot
.69424 .50186 Mdot
.54412 .6439 Mdot
.46273 .63194 Mdot
.34072 .68447 Mdot
.43025 .75802 Mdot
.53564 .36882 Mdot
.33621 .53869 Mdot
.36253 .35049 Mdot
.51508 .60921 Mdot
.65269 .53432 Mdot
.53563 .77294 Mdot
.48707 .68245 Mdot
.41731 .38625 Mdot
.67608 .50831 Mdot
.34503 .53839 Mdot
.32564 .50643 Mdot
.50261 .67225 Mdot
.67564 .74472 Mdot
.55191 .39055 Mdot
.70821 .51928 Mdot
.61002 .55478 Mdot
.44346 .63413 Mdot
.46492 .62803 Mdot
.4572 .70929 Mdot
.55119 .40917 Mdot
.63972 .47457 Mdot
.31916 .50109 Mdot
.67333 .52083 Mdot
.50968 .64164 Mdot
.33322 .52903 Mdot
.60101 .5207 Mdot
.57338 .25744 Mdot
.41269 .35242 Mdot
.35693 .49742 Mdot
.35904 .52205 Mdot
.32062 .52635 Mdot
.23703 .33022 Mdot
.7243 .51176 Mdot
.76184 .56486 Mdot
.51006 .67491 Mdot
.42889 .75003 Mdot
.4563 .68029 Mdot
.58666 .39932 Mdot
.40161 .38388 Mdot
.48232 .67091 Mdot
.54461 .64164 Mdot
.56041 .7045 Mdot
.58433 .60522 Mdot
.65383 .57789 Mdot
.66774 .50556 Mdot
.58547 .6228 Mdot
.40468 .37709 Mdot
.83533 .36427 Mdot
.16954 .38094 Mdot
.52778 .5817 Mdot
.46711 .43897 Mdot
.65422 .53705 Mdot
.521 .38887 Mdot
.49938 .46349 Mdot
.56312 .34984 Mdot
.67357 .51739 Mdot
.51802 .60837 Mdot
.63167 .33383 Mdot
.34703 .54909 Mdot
.47501 .67754 Mdot
.54911 .36825 Mdot
.47746 .67816 Mdot
.58851 .39039 Mdot
.74382 .55506 Mdot
.73311 .4366 Mdot
.52239 .66065 Mdot
.44763 .62461 Mdot
.57209 .68251 Mdot
.45808 .6388 Mdot
.5063 .28194 Mdot
.67838 .54179 Mdot
.78307 .3645 Mdot
.54539 .65215 Mdot
.71659 .69899 Mdot
.49323 .6849 Mdot
.45026 .24177 Mdot
.46125 .6259 Mdot
.5074 .48473 Mdot
.50866 .68276 Mdot
.47515 .6175 Mdot
.5432 .3944 Mdot
.53191 .40114 Mdot
.65738 .50135 Mdot
.58931 .23781 Mdot
.16868 .48317 Mdot
.46606 .63796 Mdot
.37168 .32498 Mdot
.62 .41425 Mdot
.35602 .52608 Mdot
.6783 .51702 Mdot
.85211 .46543 Mdot
.53167 .37686 Mdot
.44112 .3648 Mdot
.46839 .24114 Mdot
.35541 .36737 Mdot
.61391 .38891 Mdot
.58512 .58202 Mdot
.34477 .54093 Mdot
.49609 .68556 Mdot
.56864 .79243 Mdot
.69229 .36592 Mdot
.5099 .58625 Mdot
.5932 .36359 Mdot
.53395 .55091 Mdot
.51776 .80656 Mdot
.37211 .52306 Mdot
.36463 .52802 Mdot
.54035 .39217 Mdot
.37122 .39517 Mdot
.42263 .63599 Mdot
.32932 .50895 Mdot
.41851 .37583 Mdot
.59173 .23569 Mdot
.51558 .51993 Mdot
.68743 .52255 Mdot
.68652 .46083 Mdot
.6614 .40772 Mdot
.53482 .37026 Mdot
.33007 .33874 Mdot
.63407 .51995 Mdot
.70018 .56349 Mdot
.58852 .24989 Mdot
.4158 .34019 Mdot
.71174 .49728 Mdot
.48796 .58789 Mdot
.57328 .63525 Mdot
.48272 .63603 Mdot
.33855 .50561 Mdot
.45593 .63243 Mdot
.42628 .35396 Mdot
.56241 .36692 Mdot
.37249 .35973 Mdot
.55491 .39283 Mdot
.63397 .31469 Mdot
.49993 .65112 Mdot
.47326 .62348 Mdot
.39183 .46125 Mdot
.68025 .49739 Mdot
.70815 .73572 Mdot
.37574 .32243 Mdot
.38952 .36512 Mdot
.51885 .60068 Mdot
.64931 .50968 Mdot
.37815 .50194 Mdot
.39395 .45362 Mdot
.45326 .64394 Mdot
.67713 .54243 Mdot
.53147 .62094 Mdot
.23887 .50532 Mdot
.72361 .42465 Mdot
.70117 .52077 Mdot
.80051 .36692 Mdot
.51085 .61463 Mdot
.4206 .57344 Mdot
.56128 .62894 Mdot
.29714 .65672 Mdot
.44555 .62223 Mdot
.66343 .55274 Mdot
.48327 .64223 Mdot
.66553 .54681 Mdot
.39094 .39541 Mdot
.52194 .37995 Mdot
.66433 .53588 Mdot
.45224 .63226 Mdot
.23608 .31033 Mdot
.54528 .36641 Mdot
.4802 .61902 Mdot
.58212 .38548 Mdot
.67164 .55979 Mdot
.67212 .49982 Mdot
.32618 .26318 Mdot
.52062 .34503 Mdot
.54084 .3685 Mdot
.53422 .63258 Mdot
.64514 .4335 Mdot
.52325 .60642 Mdot
.34617 .69443 Mdot
.5448 .61764 Mdot
.45194 .60347 Mdot
.52514 .16245 Mdot
.51229 .37529 Mdot
.83569 .54442 Mdot
.23707 .41018 Mdot
.25148 .31392 Mdot
.64171 .49282 Mdot
.37217 .52278 Mdot
.21209 .41685 Mdot
.56307 .23488 Mdot
.41513 .34744 Mdot
.48302 .6716 Mdot
.72451 .48407 Mdot
.55174 .35515 Mdot
.35238 .52389 Mdot
.52298 .65967 Mdot
.42472 .3784 Mdot
.35457 .24956 Mdot
.53157 .36298 Mdot
.68754 .51904 Mdot
.67404 .49745 Mdot
.8298 .44391 Mdot
.51076 .64603 Mdot
.47651 .62445 Mdot
.5638 .35836 Mdot
.45412 .58522 Mdot
.32129 .5354 Mdot
.27437 .48415 Mdot
.54022 .37106 Mdot
.57554 .44737 Mdot
.65655 .5138 Mdot
.46357 .65788 Mdot
.40366 .50122 Mdot
.39953 .28698 Mdot
.62871 .63102 Mdot
.33221 .51304 Mdot
.35928 .68946 Mdot
.66397 .55295 Mdot
.55458 .37101 Mdot
.30639 .56748 Mdot
.54982 .61223 Mdot
.46617 .6561 Mdot
.36334 .69097 Mdot
.44507 .44601 Mdot
.38129 .51867 Mdot
.44752 .66705 Mdot
.43829 .45338 Mdot
.51659 .59911 Mdot
.49758 .59 Mdot
.50657 .57141 Mdot
.47029 .61531 Mdot
.67071 .54372 Mdot
.56265 .70376 Mdot
.40481 .34807 Mdot
.69651 .63892 Mdot
.44759 .48839 Mdot
.51519 .63401 Mdot
.51606 .60679 Mdot
.62185 .60421 Mdot
.60955 .424 Mdot
.6797 .53845 Mdot
.73381 .52132 Mdot
.53099 .38811 Mdot
.57456 .64831 Mdot
.3563 .38207 Mdot
.51165 .75057 Mdot
.3728 .3547 Mdot
.67685 .54338 Mdot
.39085 .37125 Mdot
.53211 .39303 Mdot
.38514 .37966 Mdot
.36149 .33267 Mdot
.58802 .36764 Mdot
.65364 .51471 Mdot
.45425 .64281 Mdot
.52934 .37811 Mdot
.38456 .70388 Mdot
.33787 .50534 Mdot
.32625 .26267 Mdot
.52001 .6955 Mdot
.41171 .68973 Mdot
.24549 .58852 Mdot
.3747 .36466 Mdot
.73742 .42186 Mdot
.65686 .53627 Mdot
.3157 .53809 Mdot
.6674 .54458 Mdot
.73082 .72516 Mdot
.34572 .53471 Mdot
.32006 .26364 Mdot
.29531 .54305 Mdot
.30912 .35813 Mdot
.46052 .68018 Mdot
.74503 .53299 Mdot
.36603 .36803 Mdot
.54797 .3563 Mdot
.45475 .38578 Mdot
.48228 .606 Mdot
.70734 .33537 Mdot
.72288 .53099 Mdot
.5784 .22641 Mdot
.55887 .37493 Mdot
.59502 .36367 Mdot
.50928 .65074 Mdot
.32573 .38479 Mdot
.52382 .59699 Mdot
.35422 .57306 Mdot
.34722 .67145 Mdot
.51143 .75164 Mdot
.53849 .63774 Mdot
.37004 .35146 Mdot
.53196 .62312 Mdot
.47077 .55479 Mdot
.5744 .81302 Mdot
.53133 .6904 Mdot
.71637 .31076 Mdot
.36107 .45739 Mdot
.65945 .51764 Mdot
.53933 .58457 Mdot
.57159 .23899 Mdot
.51429 .61532 Mdot
.35228 .82451 Mdot
.3404 .52275 Mdot
.40311 .41237 Mdot
.45128 .66802 Mdot
.50522 .63837 Mdot
.6052 .77872 Mdot
.74566 .50337 Mdot
.57185 .27015 Mdot
.47024 .65636 Mdot
.34875 .64069 Mdot
.55815 .40658 Mdot
.5477 .61512 Mdot
.47912 .64061 Mdot
.45928 .79371 Mdot
.57148 .40184 Mdot
.37763 .36982 Mdot
.56548 .22963 Mdot
.36275 .34731 Mdot
.36959 .50356 Mdot
.51501 .46319 Mdot
.43008 .76245 Mdot
.71953 .42315 Mdot
.34174 .49471 Mdot
.45391 .6652 Mdot
.40021 .63577 Mdot
.50401 .62202 Mdot
.36589 .52774 Mdot
.57721 .39993 Mdot
.66972 .54045 Mdot
.62444 .47108 Mdot
.57947 .24254 Mdot
.47466 .58732 Mdot
.36916 .53047 Mdot
.67057 .53004 Mdot
.38484 .26445 Mdot
.66462 .52182 Mdot
.54489 .385 Mdot
.58641 .40209 Mdot
.34175 .53236 Mdot
.66949 .54519 Mdot
.37504 .32914 Mdot
.23945 .40656 Mdot
.54235 .61671 Mdot
.49823 .38288 Mdot
.67673 .48875 Mdot
.64607 .55611 Mdot
.71808 .51227 Mdot
.50485 .65607 Mdot
.45882 .44437 Mdot
.53832 .59449 Mdot
.53611 .38886 Mdot
.41811 .36094 Mdot
.44034 .76799 Mdot
.6092 .7857 Mdot
.56649 .44862 Mdot
.44505 .61013 Mdot
.48732 .61143 Mdot
.47881 .6345 Mdot
.52683 .66644 Mdot
.25265 .50444 Mdot
.4976 .64912 Mdot
.54836 .39462 Mdot
.38741 .33849 Mdot
.51372 .64873 Mdot
.57094 .23664 Mdot
.46104 .46158 Mdot
.31966 .50687 Mdot
.48983 .47933 Mdot
.19865 .35533 Mdot
.67092 .53115 Mdot
.38018 .38661 Mdot
.41118 .34497 Mdot
.31798 .51888 Mdot
.53942 .36314 Mdot
.66276 .52573 Mdot
.28678 .63177 Mdot
.32421 .53363 Mdot
.48044 .64735 Mdot
.36794 .44411 Mdot
.77237 .32345 Mdot
.46884 .68185 Mdot
.48629 .66416 Mdot
.56971 .22469 Mdot
.36376 .39075 Mdot
.23189 .70622 Mdot
.44032 .43718 Mdot
.34698 .53015 Mdot
.36205 .52522 Mdot
.71996 .51347 Mdot
.50786 .58359 Mdot
.55955 .38936 Mdot
.41295 .45712 Mdot
.30961 .71172 Mdot
.4532 .35154 Mdot
.51685 .19899 Mdot
.499 .67862 Mdot
.60886 .76648 Mdot
.53672 .6176 Mdot
.693 .56421 Mdot
.71564 .53378 Mdot
.68331 .53338 Mdot
.54121 .38942 Mdot
.78055 .60043 Mdot
.55155 .39584 Mdot
.18994 .36173 Mdot
.6518 .54158 Mdot
.27545 .40506 Mdot
.39612 .36924 Mdot
.43411 .65026 Mdot
.33969 .54093 Mdot
.58271 .43744 Mdot
.50555 .56954 Mdot
.73942 .37295 Mdot
.39368 .37903 Mdot
.66507 .50288 Mdot
.52094 .55687 Mdot
.15878 .53395 Mdot
.50096 .44594 Mdot
.43334 .54515 Mdot
.6947 .74848 Mdot
.34612 .53621 Mdot
.6319 .61807 Mdot
.32726 .54167 Mdot
.56164 .36263 Mdot
.47958 .60717 Mdot
.47042 .61244 Mdot
.53997 .63185 Mdot
.498 .65189 Mdot
.54807 .40244 Mdot
.53427 .66582 Mdot
.64938 .80785 Mdot
.56441 .23742 Mdot
.22797 .46235 Mdot
.33907 .49972 Mdot
.58961 .36365 Mdot
.37918 .34422 Mdot
.59015 .23587 Mdot
.39975 .75621 Mdot
.51401 .67696 Mdot
.48623 .67117 Mdot
.57948 .26316 Mdot
.4901 .57142 Mdot
.5319 .56172 Mdot
.40218 .34704 Mdot
.56588 .45585 Mdot
.36735 .50997 Mdot
.34655 .49685 Mdot
.58636 .37015 Mdot
.66778 .54504 Mdot
.32914 .51351 Mdot
.37628 .39869 Mdot
.53097 .673 Mdot
.4627 .60487 Mdot
.67627 .48897 Mdot
.70753 .75066 Mdot
.37105 .5331 Mdot
.48643 .55859 Mdot
.6661 .55033 Mdot
.72545 .52325 Mdot
.46988 .65887 Mdot
.49835 .71063 Mdot
.64216 .54597 Mdot
.32977 .5016 Mdot
.58888 .3618 Mdot
.29885 .36917 Mdot
.55469 .36194 Mdot
.66445 .52878 Mdot
.54055 .66801 Mdot
.65473 .51433 Mdot
.5138 .61949 Mdot
.64674 .16181 Mdot
.46504 .61969 Mdot
.79735 .50153 Mdot
.30657 .66657 Mdot
.40768 .34194 Mdot
.37166 .33152 Mdot
.5671 .23977 Mdot
.66357 .55047 Mdot
.47265 .60479 Mdot
.35761 .53334 Mdot
.26722 .30054 Mdot
.71272 .4872 Mdot
.42249 .36639 Mdot
.35824 .3837 Mdot
.56783 .40659 Mdot
.48219 .68402 Mdot
.46097 .65019 Mdot
.38316 .37854 Mdot
.24734 .56984 Mdot
.68706 .55174 Mdot
.47737 .62437 Mdot
.49079 .61065 Mdot
.40203 .34284 Mdot
.23848 .41385 Mdot
.74898 .53978 Mdot
.47378 .61372 Mdot
.2935 .52444 Mdot
.58499 .40018 Mdot
.52927 .66086 Mdot
.53315 .66627 Mdot
.35754 .5133 Mdot
.2141 .47677 Mdot
.53379 .81095 Mdot
.59164 .37641 Mdot
.58634 .23266 Mdot
.45121 .63215 Mdot
.39676 .36742 Mdot
.45443 .61798 Mdot
.20164 .57531 Mdot
.56879 .23009 Mdot
.49508 .63982 Mdot
.52203 .57867 Mdot
.70779 .51187 Mdot
.49889 .64124 Mdot
.53213 .75382 Mdot
.37069 .33925 Mdot
.49644 .64162 Mdot
.68949 .73912 Mdot
.55735 .40793 Mdot
.5304 .58053 Mdot
.36447 .5111 Mdot
.29418 .65768 Mdot
.65014 .38831 Mdot
.34993 .34928 Mdot
.3313 .50339 Mdot
.45339 .63976 Mdot
.37284 .39453 Mdot
.54832 .35467 Mdot
.719 .35082 Mdot
.50382 .68882 Mdot
.55024 .36243 Mdot
.5615 .36805 Mdot
.34038 .52918 Mdot
.83363 .50846 Mdot
.47636 .5729 Mdot
.45698 .63835 Mdot
.40247 .78834 Mdot
.72076 .53155 Mdot
.45534 .64263 Mdot
.46894 .67828 Mdot
.56687 .38746 Mdot
.56574 .54448 Mdot
.68654 .5905 Mdot
.30343 .46582 Mdot
.58851 .39131 Mdot
.35077 .33466 Mdot
.37357 .3943 Mdot
.33772 .50074 Mdot
.66506 .51379 Mdot
.3339 .4947 Mdot
.408 .36108 Mdot
.50868 .67331 Mdot
.5737 .37834 Mdot
.62253 .6743 Mdot
.5185 .37141 Mdot
.42888 .37766 Mdot
.66636 .56742 Mdot
.62547 .37873 Mdot
.48905 .84341 Mdot
.66603 .39463 Mdot
.58189 .34436 Mdot
.3565 .52517 Mdot
.38389 .44544 Mdot
.48874 .6117 Mdot
.66817 .60701 Mdot
.46128 .66723 Mdot
.68851 .75184 Mdot
.4073 .38219 Mdot
.58808 .25263 Mdot
.47919 .60701 Mdot
.35611 .67637 Mdot
.58596 .3505 Mdot
.56387 .40846 Mdot
.49335 .65951 Mdot
.54631 .38722 Mdot
.46256 .6359 Mdot
.39259 .33588 Mdot
.82563 .53038 Mdot
.48377 .61457 Mdot
.55708 .65885 Mdot
.56631 .33276 Mdot
.32503 .26266 Mdot
.39509 .32405 Mdot
.60688 .76989 Mdot
.16014 .5668 Mdot
.54901 .38712 Mdot
.56161 .61907 Mdot
.37148 .37485 Mdot
.57032 .224 Mdot
.42202 .33716 Mdot
.47066 .67329 Mdot
.49713 .67488 Mdot
.52157 .60163 Mdot
.49745 .61291 Mdot
.65913 .60551 Mdot
.57254 .58322 Mdot
.62222 .74198 Mdot
.48715 .66998 Mdot
.61607 .51722 Mdot
.54899 .39832 Mdot
.65606 .57784 Mdot
.33847 .55539 Mdot
.5034 .67599 Mdot
.73953 .49229 Mdot
.59065 .36962 Mdot
.18981 .36706 Mdot
.56959 .40457 Mdot
.38017 .35427 Mdot
.51765 .38833 Mdot
.51507 .62392 Mdot
.68641 .51264 Mdot
.37811 .33623 Mdot
.65328 .29774 Mdot
.41732 .34931 Mdot
.51176 .64263 Mdot
.24141 .43999 Mdot
.41072 .34609 Mdot
.46876 .46737 Mdot
.68132 .51092 Mdot
.35396 .63723 Mdot
.70778 .54748 Mdot
.49687 .63523 Mdot
.49671 .62996 Mdot
.58903 .22911 Mdot
.52801 .36537 Mdot
.66722 .55817 Mdot
.76312 .73176 Mdot
.35555 .49036 Mdot
.69067 .53021 Mdot
.44696 .68247 Mdot
.45479 .44042 Mdot
.70663 .52252 Mdot
.3171 .63137 Mdot
.54086 .36059 Mdot
.7143 .5016 Mdot
.45469 .69625 Mdot
.57523 .50755 Mdot
.33396 .54782 Mdot
.42829 .37176 Mdot
.56097 .48579 Mdot
.36447 .36548 Mdot
.59379 .37933 Mdot
.3865 .40402 Mdot
.55736 .40562 Mdot
.7844 .52709 Mdot
.7638 .54163 Mdot
.5257 .35896 Mdot
.59089 .39741 Mdot
.40196 .36011 Mdot
.52048 .67014 Mdot
.45279 .50032 Mdot
.43963 .64189 Mdot
.4726 .68855 Mdot
.54963 .40755 Mdot
.67586 .55801 Mdot
.64487 .5363 Mdot
.73434 .55195 Mdot
.68113 .49857 Mdot
.37733 .34394 Mdot
.74247 .43109 Mdot
.74783 .69696 Mdot
.58314 .36904 Mdot
.54832 .41983 Mdot
.52155 .60617 Mdot
.39895 .36513 Mdot
.39752 .39231 Mdot
.5665 .3815 Mdot
.64875 .63467 Mdot
.55994 .63083 Mdot
.68832 .56301 Mdot
.65133 .54029 Mdot
.70518 .52669 Mdot
.70836 .50346 Mdot
.75648 .59982 Mdot
.54725 .3563 Mdot
.6569 .54617 Mdot
.49302 .65198 Mdot
.48921 .67721 Mdot
.58502 .23968 Mdot
.35671 .50106 Mdot
.50432 .6972 Mdot
.53931 .68233 Mdot
.46904 .66004 Mdot
.4127 .35122 Mdot
.47928 .7208 Mdot
.57474 .22952 Mdot
.37495 .40311 Mdot
.351 .36457 Mdot
.58413 .25592 Mdot
.61211 .5691 Mdot
.15213 .54019 Mdot
.5324 .61843 Mdot
.4051 .56681 Mdot
.3941 .36303 Mdot
.78256 .43834 Mdot
.61377 .50718 Mdot
.5377 .6416 Mdot
.53694 .51362 Mdot
.38592 .33414 Mdot
.72126 .53652 Mdot
.45749 .65693 Mdot
.56839 .26002 Mdot
.31755 .51089 Mdot
.44374 .67931 Mdot
.56719 .22609 Mdot
.67754 .54505 Mdot
.38746 .5502 Mdot
.7206 .50854 Mdot
.39711 .33232 Mdot
.52717 .57847 Mdot
.23349 .24207 Mdot
.36646 .37682 Mdot
.26888 .3183 Mdot
.75831 .54522 Mdot
.48178 .61353 Mdot
.36396 .3715 Mdot
.71598 .54632 Mdot
.5814 .40394 Mdot
.43102 .46131 Mdot
.65332 .53133 Mdot
.59039 .23995 Mdot
.58476 .24739 Mdot
.40359 .34582 Mdot
.67436 .505 Mdot
.54963 .63187 Mdot
.71411 .52389 Mdot
.51634 .3872 Mdot
.52855 .64758 Mdot
.1648 .49079 Mdot
.57511 .62668 Mdot
.67088 .55336 Mdot
.41341 .39016 Mdot
.34697 .54601 Mdot
.52015 .66207 Mdot
.23954 .35908 Mdot
.47437 .68151 Mdot
.58038 .39205 Mdot
.78134 .39558 Mdot
.61138 .67993 Mdot
.51187 .67238 Mdot
.51834 .60549 Mdot
.58589 .36394 Mdot
.51683 .67227 Mdot
.47132 .68221 Mdot
.55259 .32691 Mdot
.70479 .51117 Mdot
.48445 .63372 Mdot
.41312 .38367 Mdot
.59954 .79804 Mdot
.45065 .63208 Mdot
.69886 .29074 Mdot
.35602 .65342 Mdot
.78792 .41584 Mdot
.45595 .6206 Mdot
.39145 .71681 Mdot
.49314 .62539 Mdot
.50802 .66209 Mdot
.53618 .62752 Mdot
.59752 .76219 Mdot
.40413 .36294 Mdot
.42596 .36193 Mdot
.33081 .54768 Mdot
.35346 .65274 Mdot
.35018 .50446 Mdot
.5883 .38012 Mdot
.45325 .1972 Mdot
.56605 .23439 Mdot
.66658 .54539 Mdot
.50368 .59501 Mdot
.39929 .33124 Mdot
.46478 .66265 Mdot
.5172 .62033 Mdot
.39361 .33382 Mdot
.36819 .38501 Mdot
.39362 .40867 Mdot
.32824 .54081 Mdot
.67442 .53633 Mdot
.54199 .64926 Mdot
.32266 .52613 Mdot
.55076 .6287 Mdot
.44227 .4409 Mdot
.67702 .53708 Mdot
.71393 .52188 Mdot
.6606 .55897 Mdot
.50762 .6749 Mdot
.51654 .63018 Mdot
.55328 .39596 Mdot
.67303 .48854 Mdot
.57882 .36065 Mdot
.36596 .36221 Mdot
.38153 .32928 Mdot
.47165 .67378 Mdot
.49442 .55613 Mdot
.36066 .52607 Mdot
.3779 .3588 Mdot
.57689 .26511 Mdot
.32516 .54463 Mdot
.51259 .65394 Mdot
.3693 .3548 Mdot
.34963 .49639 Mdot
.66752 .64857 Mdot
.18022 .60219 Mdot
.35374 .54492 Mdot
.49226 .6577 Mdot
.61132 .77938 Mdot
.33998 .58314 Mdot
.34455 .48879 Mdot
.5815 .37255 Mdot
.47799 .68186 Mdot
.25912 .65712 Mdot
.35346 .49342 Mdot
.69076 .75903 Mdot
.40401 .34026 Mdot
.54915 .53972 Mdot
.46072 .70122 Mdot
.69243 .61084 Mdot
.33789 .49243 Mdot
.66767 .52355 Mdot
.66883 .48705 Mdot
.48566 .6525 Mdot
.30716 .54541 Mdot
.53588 .40869 Mdot
.4066 .33888 Mdot
.37201 .32589 Mdot
.68216 .50448 Mdot
.67456 .43597 Mdot
.41374 .3862 Mdot
.43246 .59754 Mdot
.35631 .41665 Mdot
.554 .68776 Mdot
.78899 .54531 Mdot
.64351 .2991 Mdot
.4675 .60037 Mdot
.35743 .54107 Mdot
.573 .35087 Mdot
.54994 .39333 Mdot
.54135 .38142 Mdot
.36406 .33838 Mdot
.49777 .46655 Mdot
.39386 .38134 Mdot
.70365 .34315 Mdot
.33272 .52865 Mdot
.34528 .61628 Mdot
.47068 .60776 Mdot
.48579 .61296 Mdot
.55175 .63799 Mdot
.51608 .59623 Mdot
.49136 .62487 Mdot
.53741 .36818 Mdot
.35648 .35257 Mdot
.32336 .4303 Mdot
.6995 .53422 Mdot
.40885 .24595 Mdot
.39596 .36956 Mdot
.56862 .22666 Mdot
.34806 .51799 Mdot
.41281 .73281 Mdot
.34521 .38387 Mdot
.39036 .37025 Mdot
.52107 .6826 Mdot
.70184 .5493 Mdot
.5937 .59743 Mdot
.49701 .62283 Mdot
.37669 .361 Mdot
.43878 .33887 Mdot
.61673 .63329 Mdot
.43036 .6914 Mdot
.37065 .48892 Mdot
.45907 .4403 Mdot
.31517 .50606 Mdot
.50313 .70729 Mdot
.78131 .43516 Mdot
.40713 .35978 Mdot
.38586 .34846 Mdot
.36908 .5275 Mdot
.42018 .5777 Mdot
.67202 .50795 Mdot
.5877 .25411 Mdot
.57955 .38736 Mdot
.50178 .62395 Mdot
.36489 .34076 Mdot
.44147 .55375 Mdot
.35261 .42542 Mdot
.54108 .37281 Mdot
.37362 .40268 Mdot
.49406 .68409 Mdot
.49135 .66043 Mdot
.34899 .53466 Mdot
.41384 .53129 Mdot
.44127 .67029 Mdot
.2507 .31469 Mdot
.72872 .43604 Mdot
.72989 .45451 Mdot
.46589 .65573 Mdot
.68802 .50371 Mdot
.5712 .25976 Mdot
.33067 .53644 Mdot
.54245 .65875 Mdot
.16722 .58619 Mdot
.63904 .51639 Mdot
.5523 .36734 Mdot
.57414 .2609 Mdot
.4956 .46658 Mdot
.47107 .68004 Mdot
.46087 .66654 Mdot
.50153 .65412 Mdot
.17405 .61241 Mdot
.42208 .37201 Mdot
.71477 .50909 Mdot
.33411 .51128 Mdot
.70161 .50193 Mdot
.4235 .35701 Mdot
.62496 .46266 Mdot
.51564 .65078 Mdot
.6828 .56519 Mdot
.66872 .52113 Mdot
.56846 .40654 Mdot
.56671 .41093 Mdot
.37982 .41082 Mdot
.46543 .62018 Mdot
.56462 .2568 Mdot
.71269 .5408 Mdot
.36018 .37917 Mdot
.34541 .53537 Mdot
.5307 .3842 Mdot
.48901 .66991 Mdot
.40619 .35311 Mdot
.49178 .58492 Mdot
.7099 .52983 Mdot
.39104 .36974 Mdot
.55902 .24568 Mdot
.36311 .51854 Mdot
.49423 .67308 Mdot
.3855 .52583 Mdot
.58189 .26008 Mdot
.49356 .6079 Mdot
.47372 .76457 Mdot
.33661 .55944 Mdot
.65489 .29441 Mdot
.38683 .38515 Mdot
.57666 .23531 Mdot
.71717 .52723 Mdot
.59029 .51469 Mdot
.38506 .34594 Mdot
.46519 .74949 Mdot
.44045 .51591 Mdot
.54028 .65212 Mdot
.69511 .51959 Mdot
.32536 .47025 Mdot
.21243 .35345 Mdot
.30324 .57123 Mdot
.47948 .62666 Mdot
.36361 .36964 Mdot
.34035 .49719 Mdot
.58457 .3738 Mdot
.70153 .29259 Mdot
.775 .55935 Mdot
.37507 .40505 Mdot
.53376 .61789 Mdot
.71196 .54141 Mdot
.56617 .37947 Mdot
.62799 .32322 Mdot
.38174 .39994 Mdot
.4023 .38561 Mdot
.5142 .65927 Mdot
.32721 .51887 Mdot
.25051 .54851 Mdot
.42716 .36141 Mdot
.36101 .34922 Mdot
.3994 .24723 Mdot
.36638 .53793 Mdot
.4897 .64917 Mdot
.73497 .55123 Mdot
.51593 .68186 Mdot
.26966 .30837 Mdot
.57318 .23203 Mdot
.69901 .5365 Mdot
.48313 .67889 Mdot
.35069 .44619 Mdot
.37719 .3491 Mdot
.46856 .43986 Mdot
.4212 .38864 Mdot
.5375 .36585 Mdot
.36682 .33833 Mdot
.45886 .65631 Mdot
.58771 .35159 Mdot
.36124 .52286 Mdot
.47263 .61425 Mdot
.51759 .63006 Mdot
.70967 .55443 Mdot
.5647 .36244 Mdot
.51646 .79721 Mdot
.58411 .40852 Mdot
.5819 .35695 Mdot
.7149 .49527 Mdot
.48308 .65003 Mdot
.38215 .35913 Mdot
.4316 .36861 Mdot
.54531 .64862 Mdot
.78244 .44735 Mdot
.67813 .50639 Mdot
.36681 .40965 Mdot
.22999 .70078 Mdot
.42011 .63908 Mdot
.56311 .25909 Mdot
.39697 .62726 Mdot
.5695 .40823 Mdot
.49185 .6656 Mdot
.67401 .55237 Mdot
.35839 .35976 Mdot
.41399 .38558 Mdot
.54538 .65722 Mdot
.56646 .37102 Mdot
.32606 .50071 Mdot
.39602 .38974 Mdot
.3444 .41231 Mdot
.50145 .64599 Mdot
.7068 .33195 Mdot
.3875 .38955 Mdot
.29468 .25714 Mdot
.33525 .43439 Mdot
.7 .52262 Mdot
.51979 .62076 Mdot
.66283 .49924 Mdot
.33923 .50857 Mdot
.36515 .31996 Mdot
.56478 .36783 Mdot
.41569 .67107 Mdot
.55378 .82753 Mdot
.40323 .36665 Mdot
.67212 .54336 Mdot
.51081 .67439 Mdot
.41452 .63838 Mdot
.45723 .6318 Mdot
.57274 .54724 Mdot
.36302 .55713 Mdot
.54814 .4082 Mdot
.58272 .39032 Mdot
.51121 .6027 Mdot
.32203 .53444 Mdot
.42443 .34617 Mdot
.40132 .33832 Mdot
.82803 .33857 Mdot
.55871 .24455 Mdot
.33296 .68513 Mdot
.49826 .67297 Mdot
.35755 .37629 Mdot
.60308 .7879 Mdot
.56387 .35824 Mdot
.52936 .59942 Mdot
.35259 .35146 Mdot
.41207 .28963 Mdot
.44223 .44331 Mdot
.49059 .63463 Mdot
.44301 .59286 Mdot
.58102 .38755 Mdot
.40466 .45184 Mdot
.3912 .38065 Mdot
.54134 .6093 Mdot
.58964 .40249 Mdot
.37377 .25485 Mdot
.62055 .8201 Mdot
.67502 .53612 Mdot
.42843 .37991 Mdot
.53813 .36617 Mdot
.43138 .65024 Mdot
.33889 .49949 Mdot
.3658 .3491 Mdot
.41635 .35236 Mdot
.52857 .63845 Mdot
.49249 .69829 Mdot
.41948 .64022 Mdot
.68788 .53897 Mdot
.56172 .39749 Mdot
.48674 .60183 Mdot
.68379 .43607 Mdot
.52266 .60132 Mdot
.56191 .39504 Mdot
.42184 .11161 Mdot
.50569 .68935 Mdot
.45819 .63292 Mdot
.26156 .55133 Mdot
.65014 .52481 Mdot
.69483 .50038 Mdot
.73681 .4351 Mdot
.49791 .673 Mdot
.31473 .36994 Mdot
.6711 .53604 Mdot
.68247 .50717 Mdot
.267 .41744 Mdot
.53102 .64846 Mdot
.41671 .44085 Mdot
.56147 .38906 Mdot
.53164 .37091 Mdot
.71009 .51708 Mdot
.43466 .65813 Mdot
.56502 .35215 Mdot
.69687 .59636 Mdot
.39815 .37233 Mdot
.78126 .4338 Mdot
.70472 .54286 Mdot
.41042 .5182 Mdot
.55175 .36009 Mdot
.19038 .35082 Mdot
.55351 .50466 Mdot
.53302 .60947 Mdot
.49868 .66724 Mdot
.3587 .51244 Mdot
.53817 .57288 Mdot
.58531 .23062 Mdot
.54491 .38697 Mdot
.21561 .5174 Mdot
.68434 .53266 Mdot
.46319 .62552 Mdot
.42018 .74011 Mdot
.64478 .33948 Mdot
.72405 .31757 Mdot
.65985 .51841 Mdot
.69117 .52208 Mdot
.40323 .37833 Mdot
.41312 .36723 Mdot
.48714 .6419 Mdot
.54306 .39228 Mdot
.69427 .48927 Mdot
.57232 .39241 Mdot
.40824 .3599 Mdot
.38817 .36591 Mdot
.57011 .22878 Mdot
.47426 .582 Mdot
.39836 .33432 Mdot
.35884 .26229 Mdot
.67221 .43939 Mdot
.714 .55269 Mdot
.47669 .83621 Mdot
.62444 .3198 Mdot
.25854 .59945 Mdot
.31341 .52234 Mdot
.56414 .27286 Mdot
.52591 .39416 Mdot
.51494 .60476 Mdot
.47666 .6705 Mdot
.57845 .24952 Mdot
.52408 .37147 Mdot
.35264 .51855 Mdot
.52702 .36605 Mdot
.32863 .52785 Mdot
.39855 .32702 Mdot
.45087 .6318 Mdot
.4593 .67069 Mdot
.53715 .37159 Mdot
.37966 .37247 Mdot
.40259 .33625 Mdot
.31825 .53519 Mdot
.39858 .70601 Mdot
.40494 .34728 Mdot
.70645 .54084 Mdot
.74498 .66169 Mdot
.5838 .24814 Mdot
.45647 .65254 Mdot
.42495 .752 Mdot
.63855 .62225 Mdot
.54319 .63739 Mdot
.57595 .26119 Mdot
.841 .37722 Mdot
.46754 .61253 Mdot
.83668 .40866 Mdot
.5796 .23443 Mdot
.64935 .5213 Mdot
.37263 .38107 Mdot
.58648 .23047 Mdot
.43641 .67444 Mdot
.34932 .48453 Mdot
.51408 .6969 Mdot
.65277 .52863 Mdot
.66165 .56246 Mdot
.7762 .49195 Mdot
.27039 .30919 Mdot
.3389 .54392 Mdot
.34788 .5257 Mdot
.38807 .34409 Mdot
.5019 .16715 Mdot
.46276 .70011 Mdot
.3501 .52674 Mdot
.22707 .54234 Mdot
.52341 .60878 Mdot
.35246 .70186 Mdot
.53445 .51151 Mdot
.68699 .50406 Mdot
.63012 .57465 Mdot
.38187 .34573 Mdot
.6722 .54278 Mdot
.66931 .45 Mdot
.5511 .64087 Mdot
.67986 .53604 Mdot
.56532 .39222 Mdot
.50525 .31562 Mdot
.66526 .5005 Mdot
.41378 .46546 Mdot
.55926 .3886 Mdot
.33841 .5616 Mdot
.27968 .57904 Mdot
.35429 .83548 Mdot
.54401 .38796 Mdot
.37142 .36927 Mdot
.39594 .33255 Mdot
.39837 .33927 Mdot
.65286 .53192 Mdot
.38718 .39645 Mdot
.69073 .54248 Mdot
.24746 .37531 Mdot
.40314 .73091 Mdot
.33966 .53292 Mdot
.51247 .35357 Mdot
.67963 .51958 Mdot
.71954 .38735 Mdot
.49821 .83887 Mdot
.49438 .6586 Mdot
.58715 .40552 Mdot
.36888 .52596 Mdot
.43965 .16174 Mdot
.35701 .51189 Mdot
.3721 .37596 Mdot
.78099 .43016 Mdot
.46414 .63404 Mdot
.52128 .75779 Mdot
.36254 .52766 Mdot
.65672 .52281 Mdot
.49091 .60912 Mdot
.42448 .392 Mdot
.33546 .50281 Mdot
.31958 .50831 Mdot
.48793 .62279 Mdot
.67032 .50191 Mdot
.38444 .36378 Mdot
.52835 .39449 Mdot
.37294 .54014 Mdot
.43667 .61539 Mdot
.52846 .66589 Mdot
.53096 .59328 Mdot
.49 .44868 Mdot
.24047 .60696 Mdot
.55067 .38707 Mdot
.3746 .59791 Mdot
.41321 .35994 Mdot
.29215 .54794 Mdot
.69612 .4004 Mdot
.52707 .34234 Mdot
.57428 .2319 Mdot
.57035 .23216 Mdot
.49012 .63074 Mdot
.23653 .59788 Mdot
.77166 .34982 Mdot
.59029 .34104 Mdot
.58129 .25365 Mdot
.40422 .33764 Mdot
.65497 .49544 Mdot
.76861 .49277 Mdot
.4801 .6962 Mdot
.55522 .41096 Mdot
.40804 .35032 Mdot
.20232 .58004 Mdot
.33385 .52554 Mdot
.7547 .42293 Mdot
.51408 .64564 Mdot
.47345 .62437 Mdot
.55744 .37914 Mdot
.55291 .39539 Mdot
.69888 .30476 Mdot
.75067 .45809 Mdot
.44576 .33494 Mdot
.56435 .31265 Mdot
.21079 .60657 Mdot
.66968 .57906 Mdot
.67535 .55408 Mdot
.56327 .23323 Mdot
.57978 .35104 Mdot
.45712 .66056 Mdot
.64671 .5272 Mdot
.72751 .31993 Mdot
.66129 .48342 Mdot
.3513 .6906 Mdot
.32176 .38457 Mdot
.51033 .62891 Mdot
.70747 .54442 Mdot
.67373 .54119 Mdot
.69908 .49771 Mdot
.5826 .25715 Mdot
.46845 .65509 Mdot
.5198 .67018 Mdot
.48444 .60577 Mdot
.49578 .56371 Mdot
.50014 .64273 Mdot
.68926 .40829 Mdot
.56982 .4473 Mdot
.21288 .49842 Mdot
.54261 .63083 Mdot
.53511 .36311 Mdot
.5014 .59352 Mdot
.31951 .53003 Mdot
.53424 .6176 Mdot
.34211 .69308 Mdot
.54622 .37584 Mdot
.41654 .5843 Mdot
.57368 .31222 Mdot
.51481 .64467 Mdot
.34397 .49455 Mdot
.24087 .59389 Mdot
.50857 .80739 Mdot
.39475 .25187 Mdot
.70806 .53854 Mdot
.35113 .39107 Mdot
.51508 .38618 Mdot
.38346 .35725 Mdot
.53812 .61204 Mdot
.56154 .25004 Mdot
.59449 .28183 Mdot
.4152 .50868 Mdot
.46615 .67371 Mdot
.56243 .6652 Mdot
.70092 .51305 Mdot
.36911 .35956 Mdot
.63089 .55326 Mdot
.50563 .65939 Mdot
.33383 .50916 Mdot
.32612 .5144 Mdot
.73086 .4489 Mdot
.1836 .51458 Mdot
.59347 .53067 Mdot
.55633 .38149 Mdot
.41934 .38381 Mdot
.34075 .49218 Mdot
.76704 .54853 Mdot
.53904 .41075 Mdot
.56872 .40844 Mdot
.57033 .36609 Mdot
.50646 .62382 Mdot
.57912 .22895 Mdot
.21037 .5378 Mdot
.58986 .23679 Mdot
.5157 .64031 Mdot
.41969 .3617 Mdot
.58546 .22812 Mdot
.35547 .50667 Mdot
.58654 .37387 Mdot
.41005 .367 Mdot
.49824 .63362 Mdot
.67357 .53147 Mdot
.39575 .68207 Mdot
.30446 .69065 Mdot
.23001 .41309 Mdot
.22796 .42253 Mdot
.65588 .55258 Mdot
.18135 .41441 Mdot
.49841 .38273 Mdot
.64848 .63267 Mdot
.35185 .47592 Mdot
.547 .64308 Mdot
.82009 .57742 Mdot
.38817 .38121 Mdot
.37885 .33901 Mdot
.49169 .63841 Mdot
.36319 .38005 Mdot
.46098 .62726 Mdot
.40964 .37762 Mdot
.35081 .28581 Mdot
.4652 .68784 Mdot
.37937 .34013 Mdot
.47712 .70846 Mdot
.52115 .65752 Mdot
.69709 .50704 Mdot
.36285 .35336 Mdot
.52819 .6032 Mdot
.50968 .15556 Mdot
.53925 .39481 Mdot
.5842 .25467 Mdot
.51325 .43024 Mdot
.54374 .3592 Mdot
.69469 .52979 Mdot
.45215 .6744 Mdot
.35423 .53288 Mdot
.66984 .52518 Mdot
.38249 .41071 Mdot
.36343 .52889 Mdot
.73902 .42996 Mdot
.7109 .53213 Mdot
.5829 .24523 Mdot
.36065 .52802 Mdot
.56576 .64166 Mdot
.37813 .33334 Mdot
.31948 .72343 Mdot
.58948 .24037 Mdot
.46045 .64998 Mdot
.39963 .32357 Mdot
.53375 .36189 Mdot
.47861 .63816 Mdot
.36343 .37267 Mdot
.58118 .25922 Mdot
.50885 .6167 Mdot
.49922 .60884 Mdot
.75666 .48768 Mdot
.75529 .35961 Mdot
.34928 .53341 Mdot
.71489 .54308 Mdot
.49322 .65067 Mdot
.3245 .53878 Mdot
.49228 .21652 Mdot
.48457 .59325 Mdot
.65434 .50577 Mdot
.51174 .74741 Mdot
.41482 .36607 Mdot
.58043 .3617 Mdot
.43178 .37403 Mdot
.31647 .51209 Mdot
.79602 .70135 Mdot
.57592 .22592 Mdot
.4606 .70601 Mdot
.54912 .61707 Mdot
.42867 .33107 Mdot
.67853 .54045 Mdot
.46639 .371 Mdot
.49487 .67264 Mdot
.57646 .63128 Mdot
.46901 .62415 Mdot
.33214 .43035 Mdot
.676 .50721 Mdot
.45738 .639 Mdot
.5326 .55743 Mdot
.44803 .6371 Mdot
.33566 .49654 Mdot
.3221 .60132 Mdot
.49852 .59145 Mdot
.17741 .30356 Mdot
.57763 .26363 Mdot
.39382 .33441 Mdot
.34719 .31991 Mdot
.5447 .22277 Mdot
.79135 .54377 Mdot
.68901 .54121 Mdot
.53326 .71667 Mdot
.38375 .3608 Mdot
.62407 .8094 Mdot
.19735 .37927 Mdot
.52078 .65391 Mdot
.49265 .68313 Mdot
.37206 .37593 Mdot
.35777 .37501 Mdot
.56255 .24401 Mdot
.54092 .62436 Mdot
.51933 .70681 Mdot
.38503 .40195 Mdot
.50488 .6376 Mdot
.57209 .69866 Mdot
.53577 .40048 Mdot
.7048 .50758 Mdot
.58456 .37287 Mdot
.55517 .4091 Mdot
.73014 .63457 Mdot
.72995 .43682 Mdot
.55935 .39625 Mdot
.58808 .40753 Mdot
.34459 .70238 Mdot
.48618 .74492 Mdot
.32958 .49649 Mdot
.1997 .44225 Mdot
.39578 .34212 Mdot
.4702 .65533 Mdot
.6616 .55366 Mdot
.70344 .61601 Mdot
.47467 .29323 Mdot
.77497 .41214 Mdot
.5056 .66895 Mdot
.38424 .34204 Mdot
.58629 .25365 Mdot
.46777 .69065 Mdot
.29542 .5547 Mdot
.47591 .62527 Mdot
.39587 .33098 Mdot
.7647 .63229 Mdot
.51429 .75375 Mdot
.38501 .44206 Mdot
.73097 .52045 Mdot
.47987 .60319 Mdot
.70094 .54252 Mdot
.54681 .36218 Mdot
.32538 .53793 Mdot
.35355 .52861 Mdot
.49119 .61125 Mdot
.76482 .54053 Mdot
.52812 .51549 Mdot
.51972 .65956 Mdot
.52961 .6425 Mdot
.57781 .23456 Mdot
.52943 .64393 Mdot
.54937 .61945 Mdot
.50191 .59812 Mdot
.46252 .59651 Mdot
.58165 .35603 Mdot
.48576 .76738 Mdot
.48346 .58839 Mdot
.42773 .67978 Mdot
.53575 .39743 Mdot
.51586 .71997 Mdot
.56637 .4057 Mdot
.16729 .496 Mdot
.57158 .39935 Mdot
.34979 .53083 Mdot
.38967 .32107 Mdot
.57419 .6559 Mdot
.70096 .49144 Mdot
.58428 .40303 Mdot
.33842 .51655 Mdot
.54266 .3845 Mdot
.42061 .37656 Mdot
.42433 .81234 Mdot
.66018 .48391 Mdot
.42343 .44818 Mdot
.56466 .52067 Mdot
.7063 .3289 Mdot
.40235 .37433 Mdot
.68679 .50574 Mdot
.53092 .75213 Mdot
.50267 .5996 Mdot
.36191 .51793 Mdot
.48879 .62913 Mdot
.58379 .36006 Mdot
.39014 .34021 Mdot
.23504 .44137 Mdot
.35348 .53113 Mdot
.61198 .83209 Mdot
.41266 .34233 Mdot
.49744 .69133 Mdot
.55719 .41199 Mdot
.48084 .83598 Mdot
.57419 .39803 Mdot
.40904 .73785 Mdot
.65307 .56588 Mdot
.77818 .63819 Mdot
.68877 .51793 Mdot
.72643 .30552 Mdot
.13697 .56535 Mdot
.22292 .36374 Mdot
.66366 .53224 Mdot
.37621 .42741 Mdot
.5106 .64519 Mdot
.50765 .59124 Mdot
.42172 .62118 Mdot
.72147 .53928 Mdot
.49595 .64972 Mdot
.58635 .23592 Mdot
.63812 .44451 Mdot
.2674 .49747 Mdot
.34909 .3905 Mdot
.45539 .63714 Mdot
.53917 .39938 Mdot
.5299 .36036 Mdot
.5876 .23064 Mdot
.53127 .40467 Mdot
.52407 .65957 Mdot
.68255 .51862 Mdot
.4359 .50752 Mdot
.34551 .50624 Mdot
.36774 .21082 Mdot
.36082 .55013 Mdot
.35563 .40112 Mdot
.52342 .57883 Mdot
.38856 .3668 Mdot
.86112 .56779 Mdot
.51517 .60059 Mdot
.66881 .53789 Mdot
.50151 .61214 Mdot
.49287 .59853 Mdot
.51172 .59106 Mdot
.38995 .39796 Mdot
.36996 .30966 Mdot
.5034 .63439 Mdot
.56485 .36694 Mdot
.22166 .46081 Mdot
.5237 .69237 Mdot
.39311 .41753 Mdot
.34601 .65792 Mdot
.70754 .34864 Mdot
.71963 .54719 Mdot
.37051 .3641 Mdot
.68734 .52886 Mdot
.72634 .50811 Mdot
.6947 .52995 Mdot
.20103 .51941 Mdot
.58283 .56867 Mdot
.82385 .35801 Mdot
.72654 .70818 Mdot
.68163 .6287 Mdot
.6788 .56418 Mdot
.50203 .24918 Mdot
.66827 .55031 Mdot
.69213 .53698 Mdot
.59284 .13186 Mdot
.65988 .54698 Mdot
.47211 .67322 Mdot
.51237 .68877 Mdot
.6599 .38609 Mdot
.36237 .72222 Mdot
.53731 .62288 Mdot
.4921 .64623 Mdot
.33199 .5411 Mdot
.46534 .55921 Mdot
.57568 .21786 Mdot
.76734 .44021 Mdot
.58164 .29527 Mdot
.48879 .6235 Mdot
.49428 .64356 Mdot
.43695 .62722 Mdot
.13638 .58372 Mdot
.72124 .60488 Mdot
.65376 .55603 Mdot
.56014 .6727 Mdot
.29852 .27057 Mdot
.4979 .68853 Mdot
.45616 .66802 Mdot
.51361 .61976 Mdot
.38262 .35985 Mdot
.64909 .50011 Mdot
.56482 .65869 Mdot
.68905 .34476 Mdot
.51349 .65199 Mdot
.50342 .37231 Mdot
.37358 .54401 Mdot
.46042 .66016 Mdot
.69737 .49887 Mdot
.53035 .61812 Mdot
.70486 .54505 Mdot
.70801 .51332 Mdot
.45007 .59607 Mdot
.20224 .53372 Mdot
.67075 .49417 Mdot
.51569 .63379 Mdot
.37717 .36868 Mdot
.21775 .35135 Mdot
.46078 .65408 Mdot
.32695 .53307 Mdot
.49798 .66961 Mdot
.33848 .49657 Mdot
.52299 .64073 Mdot
.59016 .24019 Mdot
.60234 .68747 Mdot
.38743 .34739 Mdot
.35705 .46821 Mdot
.36513 .38859 Mdot
.73571 .47301 Mdot
.64855 .51797 Mdot
.57089 .21791 Mdot
.82026 .47565 Mdot
.57865 .23585 Mdot
.3962 .68065 Mdot
.45478 .25904 Mdot
.53554 .38743 Mdot
.71173 .50774 Mdot
.38593 .59103 Mdot
.38443 .41998 Mdot
.38182 .40858 Mdot
.35192 .37112 Mdot
.81955 .64894 Mdot
.8276 .52268 Mdot
.50133 .62769 Mdot
.32142 .74389 Mdot
.62816 .73078 Mdot
.45541 .61277 Mdot
.44441 .66353 Mdot
.39429 .32962 Mdot
.47112 .60826 Mdot
.4808 .46384 Mdot
.40199 .36101 Mdot
.34307 .51997 Mdot
.69848 .53837 Mdot
.33307 .49984 Mdot
.44487 .38008 Mdot
.58209 .45041 Mdot
.41109 .36141 Mdot
.47066 .59544 Mdot
.49762 .61765 Mdot
.71452 .53081 Mdot
.72172 .48037 Mdot
.70353 .50831 Mdot
.36631 .52831 Mdot
.39843 .35295 Mdot
.7046 .60593 Mdot
.48789 .66445 Mdot
.66936 .5193 Mdot
.59288 .42272 Mdot
.49165 .66121 Mdot
.53945 .36876 Mdot
.51095 .67045 Mdot
.65921 .53195 Mdot
.52899 .64418 Mdot
.6847 .51948 Mdot
.38539 .37833 Mdot
.49945 .68644 Mdot
.49057 .64096 Mdot
.5416 .81232 Mdot
.35264 .51711 Mdot
.64853 .5193 Mdot
.52736 .48277 Mdot
.51046 .6849 Mdot
.29365 .54195 Mdot
.45487 .62424 Mdot
.51734 .73296 Mdot
.48062 .7103 Mdot
.58568 .23735 Mdot
.51334 .58686 Mdot
.45994 .65126 Mdot
.49895 .76771 Mdot
.6509 .76222 Mdot
.62429 .54042 Mdot
.59129 .37743 Mdot
.69824 .49962 Mdot
.37889 .33004 Mdot
.35777 .35238 Mdot
.38994 .39286 Mdot
.3835 .73477 Mdot
.43351 .64827 Mdot
.46372 .63597 Mdot
.57598 .40914 Mdot
.34517 .52702 Mdot
.66068 .5204 Mdot
.34005 .52935 Mdot
.76999 .44435 Mdot
.36661 .52348 Mdot
.58384 .22918 Mdot
.33606 .43523 Mdot
.63502 .60647 Mdot
.33699 .54182 Mdot
.70352 .50771 Mdot
.33693 .41158 Mdot
.54763 .6332 Mdot
.37056 .27176 Mdot
.33259 .51006 Mdot
.77807 .71552 Mdot
.45303 .63029 Mdot
.44751 .45664 Mdot
.55109 .40423 Mdot
.34915 .49829 Mdot
.56169 .36107 Mdot
.5234 .60523 Mdot
.6571 .29249 Mdot
.66893 .54412 Mdot
.58995 .3565 Mdot
.5115 .58745 Mdot
.33713 .49894 Mdot
.40981 .34814 Mdot
.58836 .49482 Mdot
.53382 .36643 Mdot
.48015 .79253 Mdot
.30293 .57087 Mdot
.39907 .35488 Mdot
.77881 .33391 Mdot
.57736 .37082 Mdot
.46399 .60163 Mdot
.58713 .63796 Mdot
.53883 .6375 Mdot
.36846 .33279 Mdot
.36963 .35553 Mdot
.64605 .42446 Mdot
.50111 .61443 Mdot
.45354 .6284 Mdot
.63569 .5178 Mdot
.40047 .36697 Mdot
.69543 .5141 Mdot
.70961 .50161 Mdot
.37313 .37283 Mdot
.69954 .52089 Mdot
.36349 .52436 Mdot
.62182 .4469 Mdot
.57813 .37316 Mdot
.55905 .36712 Mdot
.40287 .3377 Mdot
.4287 .36217 Mdot
.39062 .3679 Mdot
.51123 .66973 Mdot
.66237 .51185 Mdot
.52366 .62286 Mdot
.49545 .59074 Mdot
.66893 .57273 Mdot
.64909 .53809 Mdot
.52313 .61484 Mdot
.36757 .45286 Mdot
.37839 .52178 Mdot
.37895 .34152 Mdot
.56983 .39425 Mdot
.62861 .80417 Mdot
.56481 .41219 Mdot
.4552 .63181 Mdot
.40223 .28467 Mdot
.65465 .52567 Mdot
.35736 .51111 Mdot
.31125 .55379 Mdot
.36003 .5198 Mdot
.584 .34333 Mdot
.69877 .49375 Mdot
.73606 .42952 Mdot
.45825 .62769 Mdot
.49204 .45041 Mdot
.37985 .59803 Mdot
.69786 .39071 Mdot
.56318 .39502 Mdot
.49213 .65448 Mdot
.57992 .23742 Mdot
.61891 .62821 Mdot
.47451 .62845 Mdot
.53102 .60197 Mdot
.29951 .40068 Mdot
.4255 .67619 Mdot
.70677 .55812 Mdot
.77367 .48665 Mdot
.52964 .67289 Mdot
.68927 .58324 Mdot
.73461 .22598 Mdot
.4597 .62053 Mdot
.50383 .65242 Mdot
.47237 .66444 Mdot
.51656 .60724 Mdot
.66968 .57069 Mdot
.39776 .5184 Mdot
.56314 .4112 Mdot
.51846 .45029 Mdot
.57508 .3764 Mdot
.3748 .33687 Mdot
.45009 .46014 Mdot
.70998 .50785 Mdot
.36027 .51593 Mdot
.39118 .78953 Mdot
.77789 .46665 Mdot
.40255 .37816 Mdot
.74502 .60263 Mdot
.34022 .50601 Mdot
.54616 .64529 Mdot
.34197 .55109 Mdot
.35611 .37247 Mdot
.5675 .37762 Mdot
.51451 .68652 Mdot
.67039 .55848 Mdot
.66485 .50024 Mdot
.49486 .65643 Mdot
.26767 .30158 Mdot
.54808 .35916 Mdot
.56259 .43786 Mdot
.50783 .62528 Mdot
.53212 .60285 Mdot
.70607 .52293 Mdot
.37389 .35218 Mdot
.4518 .22588 Mdot
.3465 .51542 Mdot
.44944 .60596 Mdot
.5265 .61001 Mdot
.76564 .44999 Mdot
.5877 .37582 Mdot
.56722 .25502 Mdot
.50595 .6207 Mdot
.73524 .43987 Mdot
.50648 .61896 Mdot
.54648 .5757 Mdot
.38378 .36886 Mdot
.5471 .65862 Mdot
.49974 .67983 Mdot
.40234 .58488 Mdot
.57483 .36443 Mdot
.67479 .53845 Mdot
.63455 .5415 Mdot
.56841 .26018 Mdot
.53889 .37188 Mdot
.52551 .61475 Mdot
.58157 .36059 Mdot
.50959 .59056 Mdot
.50157 .63651 Mdot
.56365 .39437 Mdot
.69602 .51448 Mdot
.4786 .35848 Mdot
.45835 .75041 Mdot
.5105 .60864 Mdot
.52826 .66727 Mdot
.3718 .72502 Mdot
.81696 .4294 Mdot
.49705 .67704 Mdot
.652 .52417 Mdot
.48901 .65737 Mdot
.54912 .36482 Mdot
.36798 .52118 Mdot
.66836 .53335 Mdot
.42379 .3497 Mdot
.38349 .37969 Mdot
.57956 .31456 Mdot
.58019 .22696 Mdot
.52333 .67281 Mdot
.62207 .51463 Mdot
.6521 .54522 Mdot
.55089 .17437 Mdot
.39013 .33317 Mdot
.34892 .49321 Mdot
.50152 .60693 Mdot
.58028 .49855 Mdot
.57803 .40598 Mdot
.17555 .30606 Mdot
.72181 .42368 Mdot
.31541 .54441 Mdot
.78957 .42582 Mdot
.57974 .243 Mdot
.47101 .67774 Mdot
.31993 .53319 Mdot
.38937 .38595 Mdot
.5113 .5935 Mdot
.42535 .63424 Mdot
.47199 .38228 Mdot
.34582 .35689 Mdot
.57997 .36005 Mdot
.41123 .38078 Mdot
.31157 .53219 Mdot
.58453 .22978 Mdot
.6813 .50031 Mdot
.45898 .64212 Mdot
.58277 .62085 Mdot
.39277 .33617 Mdot
.59069 .24317 Mdot
.51081 .62883 Mdot
.67011 .49782 Mdot
.36874 .38601 Mdot
.48653 .62067 Mdot
.65512 .62594 Mdot
.73448 .53328 Mdot
.40017 .34691 Mdot
.54468 .60879 Mdot
.55022 .7134 Mdot
.41674 .34296 Mdot
.40374 .33523 Mdot
.49576 .64918 Mdot
.36221 .52522 Mdot
.48183 .68401 Mdot
.55887 .40626 Mdot
.36969 .30957 Mdot
.54827 .36755 Mdot
.36241 .58662 Mdot
.51531 .57723 Mdot
.71915 .32972 Mdot
.71494 .53742 Mdot
.31689 .49827 Mdot
.56035 .78115 Mdot
.54116 .61294 Mdot
.1815 .45527 Mdot
.40955 .51568 Mdot
.402 .18463 Mdot
.19897 .63826 Mdot
.33063 .51834 Mdot
.54108 .38167 Mdot
.50329 .65276 Mdot
.54253 .41932 Mdot
.33626 .5395 Mdot
.37324 .59225 Mdot
.54568 .61108 Mdot
.6797 .5073 Mdot
.51255 .64588 Mdot
.70716 .54018 Mdot
.49222 .66369 Mdot
.46226 .711 Mdot
.36505 .48048 Mdot
.41165 .74022 Mdot
.54706 .63805 Mdot
.41709 .81231 Mdot
.56746 .4921 Mdot
.336 .51029 Mdot
.51924 .62675 Mdot
.57121 .24973 Mdot
.52203 .37178 Mdot
.25437 .64108 Mdot
.38562 .36315 Mdot
.5542 .39888 Mdot
.70373 .52981 Mdot
.4344 .36383 Mdot
.57682 .26244 Mdot
.58607 .62177 Mdot
.32549 .50362 Mdot
.53681 .38742 Mdot
.45965 .65443 Mdot
.45295 .63687 Mdot
.35603 .45123 Mdot
.66429 .23203 Mdot
.65477 .49211 Mdot
.58245 .83004 Mdot
.69253 .56575 Mdot
.35173 .52309 Mdot
.38601 .36912 Mdot
.48166 .67833 Mdot
.47995 .63184 Mdot
.36177 .34353 Mdot
.64917 .52561 Mdot
.34115 .35148 Mdot
.74091 .62157 Mdot
.40547 .39652 Mdot
.36938 .66358 Mdot
.6639 .53649 Mdot
.3729 .66808 Mdot
.31027 .52928 Mdot
.19595 .5475 Mdot
.2919 .6389 Mdot
.54812 .4045 Mdot
.36605 .65738 Mdot
.65772 .52499 Mdot
.49874 .62351 Mdot
.58182 .24728 Mdot
.57054 .2295 Mdot
.70372 .53632 Mdot
.37001 .37447 Mdot
.34089 .49926 Mdot
.50411 .64921 Mdot
.73459 .39302 Mdot
.63582 .34589 Mdot
.41965 .38409 Mdot
.54546 .56435 Mdot
.56412 .36303 Mdot
.50755 .6718 Mdot
.32412 .52866 Mdot
.54916 .39061 Mdot
.55969 .25896 Mdot
.63047 .44585 Mdot
.49867 .6059 Mdot
.73437 .45385 Mdot
.53716 .37667 Mdot
.78716 .33877 Mdot
.48669 .63813 Mdot
.57728 .37038 Mdot
.45114 .71165 Mdot
.65608 .30642 Mdot
.48653 .49353 Mdot
.20237 .38265 Mdot
.34742 .3622 Mdot
.38038 .38058 Mdot
.61797 .24252 Mdot
.35357 .477 Mdot
.53545 .39446 Mdot
.58587 .23082 Mdot
.30017 .60524 Mdot
.56634 .36153 Mdot
.45689 .67096 Mdot
.45545 .62361 Mdot
.72452 .63155 Mdot
.49669 .47401 Mdot
.59152 .24524 Mdot
.6032 .54113 Mdot
.53317 .65007 Mdot
.54963 .66422 Mdot
.47952 .64241 Mdot
.6606 .56176 Mdot
.54411 .35803 Mdot
.43845 .83771 Mdot
.55502 .3571 Mdot
.74377 .40009 Mdot
.39526 .34186 Mdot
.41993 .38564 Mdot
.45859 .65665 Mdot
.74557 .33191 Mdot
.24339 .6302 Mdot
.51823 .67309 Mdot
.33464 .56316 Mdot
.31765 .58012 Mdot
.53684 .6846 Mdot
.63379 .54753 Mdot
.57796 .60987 Mdot
.69619 .57129 Mdot
.55372 .39252 Mdot
.32887 .5216 Mdot
.37735 .51846 Mdot
.54039 .39061 Mdot
.46434 .6381 Mdot
.36467 .56786 Mdot
.47083 .62469 Mdot
.50266 .62354 Mdot
.76518 .42944 Mdot
.35451 .49231 Mdot
.39315 .37002 Mdot
.35392 .52917 Mdot
.69039 .53723 Mdot
.49444 .09564 Mdot
.33472 .53115 Mdot
.66844 .46928 Mdot
.38721 .46175 Mdot
.36843 .65848 Mdot
.67033 .49888 Mdot
.34943 .54314 Mdot
.5719 .35695 Mdot
.3958 .18467 Mdot
.80667 .38621 Mdot
.55718 .41484 Mdot
.48504 .63352 Mdot
.71358 .51304 Mdot
.65941 .55688 Mdot
.58536 .4085 Mdot
.6836 .50309 Mdot
.54965 .59946 Mdot
.50512 .61367 Mdot
.53543 .39428 Mdot
.65206 .38478 Mdot
.53923 .35864 Mdot
.61709 .47486 Mdot
.51554 .62693 Mdot
.66868 .53551 Mdot
.54506 .58588 Mdot
.63865 .50697 Mdot
.56484 .23268 Mdot
.51619 .59353 Mdot
.35804 .50583 Mdot
.49465 .46496 Mdot
.3979 .34595 Mdot
.41119 .29025 Mdot
.714 .52485 Mdot
.54199 .42806 Mdot
.69763 .50699 Mdot
.72065 .5276 Mdot
.53514 .40785 Mdot
.6805 .54369 Mdot
.50437 .65174 Mdot
.38251 .44432 Mdot
.69252 .55224 Mdot
.55447 .37678 Mdot
.34671 .50061 Mdot
.69831 .51823 Mdot
.43575 .35577 Mdot
.49338 .61797 Mdot
.41241 .37012 Mdot
.30462 .53192 Mdot
.70919 .50573 Mdot
.35389 .54113 Mdot
.39055 .33448 Mdot
.32079 .50902 Mdot
.23635 .41438 Mdot
.5736 .34932 Mdot
.77017 .40595 Mdot
.48531 .75537 Mdot
.67117 .55794 Mdot
.38264 .40908 Mdot
.48907 .67832 Mdot
.49509 .61384 Mdot
.31456 .53453 Mdot
.65916 .55593 Mdot
.22797 .3427 Mdot
.53907 .71715 Mdot
.62649 .43344 Mdot
.58399 .35546 Mdot
.63 .81436 Mdot
.67694 .43518 Mdot
.39133 .21012 Mdot
.47745 .70456 Mdot
.57994 .24371 Mdot
.46585 .62621 Mdot
.51253 .8091 Mdot
.36816 .51537 Mdot
.49802 .28499 Mdot
.46237 .69965 Mdot
.39293 .36121 Mdot
.48324 .65862 Mdot
.31655 .73314 Mdot
.57537 .60548 Mdot
.3355 .5431 Mdot
.57127 .33499 Mdot
.69985 .49091 Mdot
.34397 .50631 Mdot
.39047 .37999 Mdot
.32862 .6221 Mdot
.54988 .61674 Mdot
.52718 .65931 Mdot
.3704 .4031 Mdot
.68119 .5058 Mdot
.37537 .33529 Mdot
.57789 .37315 Mdot
.336 .52816 Mdot
.5127 .60538 Mdot
.55473 .64953 Mdot
.44091 .34113 Mdot
.54793 .35586 Mdot
.42931 .36939 Mdot
.58593 .37781 Mdot
.58079 .24405 Mdot
.53833 .65938 Mdot
.37088 .40187 Mdot
.45418 .62019 Mdot
.55618 .79246 Mdot
.77275 .43134 Mdot
.65653 .74804 Mdot
.39537 .37113 Mdot
.35518 .67539 Mdot
.54404 .37424 Mdot
.581 .39269 Mdot
.75316 .68434 Mdot
.2389 .5948 Mdot
.31618 .37223 Mdot
.40762 .79689 Mdot
.57807 .3743 Mdot
.54979 .36974 Mdot
.3866 .38762 Mdot
.68646 .54507 Mdot
.73152 .54939 Mdot
.42268 .38556 Mdot
.42274 .74813 Mdot
.66085 .52044 Mdot
.18381 .43678 Mdot
.39908 .32926 Mdot
.46377 .70184 Mdot
.58945 .22268 Mdot
.3262 .51889 Mdot
.42492 .74817 Mdot
.36889 .76553 Mdot
.47043 .67529 Mdot
.80301 .53954 Mdot
.37516 .35771 Mdot
.43907 .43037 Mdot
.17505 .51209 Mdot
.53396 .60046 Mdot
.47594 .65655 Mdot
.46751 .64159 Mdot
.36465 .49643 Mdot
.54923 .78372 Mdot
.46812 .67451 Mdot
.39631 .71955 Mdot
.46384 .68132 Mdot
.2916 .68203 Mdot
.3527 .52993 Mdot
.57727 .55459 Mdot
.34962 .37906 Mdot
.6957 .36232 Mdot
.41936 .62886 Mdot
.58082 .36904 Mdot
.40804 .42323 Mdot
.56862 .38105 Mdot
.2218 .58956 Mdot
.29284 .63687 Mdot
.66985 .56569 Mdot
.50608 .66896 Mdot
.35133 .36248 Mdot
.71547 .52248 Mdot
.45282 .24894 Mdot
.57607 .11966 Mdot
.56595 .35285 Mdot
.85412 .48734 Mdot
.58126 .39317 Mdot
.56591 .23298 Mdot
.70708 .52748 Mdot
.6803 .5915 Mdot
.49118 .45145 Mdot
.69648 .51829 Mdot
.56635 .29748 Mdot
.63682 .55515 Mdot
.35968 .66594 Mdot
.71903 .50356 Mdot
.55042 .37805 Mdot
.56174 .34202 Mdot
.4315 .67219 Mdot
.49279 .67625 Mdot
.53238 .44981 Mdot
.45435 .72129 Mdot
.49996 .67362 Mdot
.40182 .36103 Mdot
.79184 .3794 Mdot
.41716 .32815 Mdot
.67875 .55317 Mdot
.58944 .3851 Mdot
.47779 .65731 Mdot
.51195 .611 Mdot
.46763 .60266 Mdot
.54134 .81545 Mdot
.18631 .43312 Mdot
.50185 .63316 Mdot
.45854 .59059 Mdot
.38998 .37779 Mdot
.38628 .52968 Mdot
.45399 .80518 Mdot
.30091 .61591 Mdot
.48252 .61127 Mdot
.35529 .51814 Mdot
.3676 .50599 Mdot
.53472 .67794 Mdot
.7214 .36288 Mdot
.37693 .43244 Mdot
.45991 .65496 Mdot
.28486 .6456 Mdot
.42954 .34201 Mdot
.59035 .23449 Mdot
.39367 .33625 Mdot
.70272 .50002 Mdot
.57561 .23143 Mdot
.37282 .39377 Mdot
.66089 .59281 Mdot
.5661 .25878 Mdot
.66117 .31931 Mdot
.36631 .5284 Mdot
.47808 .63807 Mdot
.6288 .5393 Mdot
.36255 .34008 Mdot
.53788 .38992 Mdot
.67989 .52506 Mdot
.52957 .35963 Mdot
.38593 .50882 Mdot
.38758 .63366 Mdot
.57704 .22632 Mdot
.5821 .37784 Mdot
.63087 .44664 Mdot
.3561 .52069 Mdot
.53884 .40865 Mdot
.73533 .32243 Mdot
.50877 .69694 Mdot
.23499 .64709 Mdot
.51718 .66598 Mdot
.30373 .26177 Mdot
.57855 .39684 Mdot
.56007 .24764 Mdot
.46157 .63512 Mdot
.41331 .34237 Mdot
.46785 .71855 Mdot
.47661 .62278 Mdot
.42504 .36843 Mdot
.50053 .6271 Mdot
.32324 .52926 Mdot
.72053 .55726 Mdot
.41581 .51739 Mdot
.71198 .76133 Mdot
.32111 .51051 Mdot
.5958 .2148 Mdot
.5007 .67513 Mdot
.23834 .46607 Mdot
.69434 .51643 Mdot
.53085 .6002 Mdot
.7861 .6152 Mdot
.69161 .54729 Mdot
.68902 .52636 Mdot
.5288 .63603 Mdot
.54146 .40635 Mdot
.4081 .34226 Mdot
.35711 .52089 Mdot
.454 .17734 Mdot
.48299 .61941 Mdot
.48953 .64973 Mdot
.34114 .5057 Mdot
.5488 .36861 Mdot
.5157 .61001 Mdot
.44388 .2741 Mdot
.47901 .15892 Mdot
.55594 .40954 Mdot
.52323 .69305 Mdot
.27524 .71898 Mdot
.72486 .49384 Mdot
.8361 .45373 Mdot
.34002 .46968 Mdot
.3728 .3678 Mdot
.48 .7136 Mdot
.21353 .26652 Mdot
.32758 .5178 Mdot
.70383 .38794 Mdot
.5063 .63494 Mdot
.48282 .66754 Mdot
.66084 .50607 Mdot
.52605 .62015 Mdot
.65693 .53826 Mdot
.7324 .74933 Mdot
.58039 .85635 Mdot
.69925 .51049 Mdot
.67047 .55359 Mdot
.62311 .57545 Mdot
.49386 .79773 Mdot
.70058 .5349 Mdot
.5401 .60112 Mdot
.21499 .43384 Mdot
.4543 .58883 Mdot
.31028 .52093 Mdot
.30332 .54277 Mdot
.71323 .57558 Mdot
.7338 .28307 Mdot
.54182 .70337 Mdot
.41154 .61967 Mdot
.53498 .52002 Mdot
.56891 .39976 Mdot
.48792 .60407 Mdot
.58109 .22678 Mdot
.39443 .39301 Mdot
.5595 .57941 Mdot
.4752 .63522 Mdot
.7035 .54569 Mdot
.36064 .49277 Mdot
.51638 .38376 Mdot
.49206 .64531 Mdot
.3485 .33745 Mdot
.34476 .51803 Mdot
.68561 .55471 Mdot
.7093 .46758 Mdot
.32188 .50096 Mdot
.55784 .61149 Mdot
.49431 .67136 Mdot
.51056 .6275 Mdot
.41724 .65114 Mdot
.54142 .39441 Mdot
.44089 .35996 Mdot
.54121 .5965 Mdot
.76139 .44048 Mdot
.44151 .44868 Mdot
.55436 .64191 Mdot
.65713 .51619 Mdot
.56734 .41081 Mdot
.5651 .25204 Mdot
.34455 .61545 Mdot
.49305 .6074 Mdot
.18737 .43764 Mdot
.72712 .61115 Mdot
.57232 .23477 Mdot
.70684 .55191 Mdot
.35917 .51464 Mdot
.52906 .65239 Mdot
.2086 .47509 Mdot
.45452 .62892 Mdot
.49603 .74522 Mdot
.37362 .36292 Mdot
.57317 .39411 Mdot
.45689 .15836 Mdot
.39631 .39274 Mdot
.68793 .52811 Mdot
.19777 .35533 Mdot
.64346 .51416 Mdot
.6791 .48736 Mdot
.20862 .5455 Mdot
.5572 .39397 Mdot
.19672 .2851 Mdot
.81522 .40949 Mdot
.4488 .64892 Mdot
.55034 .3621 Mdot
.70915 .52547 Mdot
.50895 .6682 Mdot
.65693 .54883 Mdot
.66403 .49247 Mdot
.50182 .59427 Mdot
.48775 .67136 Mdot
.40929 .73017 Mdot
.16729 .46809 Mdot
.35945 .52623 Mdot
.64952 .52124 Mdot
.69051 .63689 Mdot
.47161 .67701 Mdot
.45797 .62832 Mdot
.43684 .41717 Mdot
.33585 .54295 Mdot
.56484 .71772 Mdot
.50486 .62142 Mdot
.79119 .61972 Mdot
.52659 .6702 Mdot
.62869 .52637 Mdot
.5487 .41 Mdot
.71927 .36766 Mdot
.37303 .33034 Mdot
.65872 .50101 Mdot
.34182 .49656 Mdot
.63822 .54268 Mdot
.76901 .64733 Mdot
.56053 .39108 Mdot
.65917 .53192 Mdot
.42053 .33942 Mdot
.56291 .38009 Mdot
.55557 .40833 Mdot
.22118 .45921 Mdot
.42904 .37328 Mdot
.36391 .53697 Mdot
.57029 .37365 Mdot
.64978 .63427 Mdot
.54999 .38187 Mdot
.70551 .63633 Mdot
.50545 .68254 Mdot
.39412 .70989 Mdot
.68555 .42728 Mdot
.4274 .61011 Mdot
.53584 .35984 Mdot
.34405 .53837 Mdot
.53426 .629 Mdot
.67917 .50302 Mdot
.33251 .53021 Mdot
.5796 .32913 Mdot
.42514 .3485 Mdot
.70757 .547 Mdot
.55471 .41125 Mdot
.65634 .5339 Mdot
.38198 .6162 Mdot
.38401 .29592 Mdot
.54054 .52565 Mdot
.47905 .44481 Mdot
.46027 .6054 Mdot
.71064 .57916 Mdot
.51606 .68253 Mdot
.4742 .63147 Mdot
.4002 .34622 Mdot
.38368 .73371 Mdot
.69741 .51485 Mdot
.47229 .15275 Mdot
.58172 .3855 Mdot
.77566 .50399 Mdot
.55909 .70209 Mdot
.52047 .59862 Mdot
.69324 .55094 Mdot
.65853 .49357 Mdot
.65288 .76061 Mdot
.3625 .34435 Mdot
.44205 .5933 Mdot
.51506 .57466 Mdot
.44948 .69716 Mdot
.58003 .39663 Mdot
.4608 .29072 Mdot
.36456 .36221 Mdot
.84443 .38002 Mdot
.37768 .34331 Mdot
.27774 .41784 Mdot
.67988 .5444 Mdot
.36575 .5122 Mdot
.45654 .63177 Mdot
.44151 .7391 Mdot
.66107 .56696 Mdot
.40775 .43908 Mdot
.35673 .50736 Mdot
.48681 .32048 Mdot
.55581 .39672 Mdot
.54614 .65311 Mdot
.49329 .59709 Mdot
.52283 .62644 Mdot
.51612 .65899 Mdot
.59073 .37522 Mdot
.45638 .66988 Mdot
.58542 .35343 Mdot
.64861 .62109 Mdot
.78905 .63012 Mdot
.36049 .33581 Mdot
.24938 .62232 Mdot
.67749 .5604 Mdot
.65795 .64906 Mdot
.57943 .68469 Mdot
.77169 .42711 Mdot
.23206 .43627 Mdot
.51844 .67803 Mdot
.37071 .37862 Mdot
.31832 .73895 Mdot
.3519 .36138 Mdot
.66993 .84373 Mdot
.36737 .57234 Mdot
.19496 .38509 Mdot
.5085 .66653 Mdot
.44118 .34558 Mdot
.56486 .7022 Mdot
.53008 .68481 Mdot
.37771 .56821 Mdot
.65346 .46818 Mdot
.66782 .38195 Mdot
.34325 .49277 Mdot
.49114 .61821 Mdot
.69781 .48938 Mdot
.50571 .65207 Mdot
.46147 .62566 Mdot
.50773 .67368 Mdot
.51692 .39517 Mdot
.46934 .69443 Mdot
.47685 .68236 Mdot
.67247 .2325 Mdot
.35188 .69711 Mdot
.41478 .37236 Mdot
.69523 .73109 Mdot
.34477 .52679 Mdot
.7102 .53768 Mdot
.40357 .50108 Mdot
.55405 .40345 Mdot
.63799 .77281 Mdot
.5123 .66705 Mdot
.67093 .42443 Mdot
.55458 .41166 Mdot
.32969 .52729 Mdot
.57263 .26056 Mdot
.21489 .39045 Mdot
.35829 .34023 Mdot
.56357 .25607 Mdot
.39612 .34573 Mdot
.56966 .76573 Mdot
.70213 .54631 Mdot
.47255 .59906 Mdot
.56895 .36563 Mdot
.41241 .34522 Mdot
.36837 .73191 Mdot
.47662 .64566 Mdot
.39836 .37149 Mdot
.46365 .60242 Mdot
.41756 .45392 Mdot
.36567 .43939 Mdot
.36243 .38679 Mdot
.56025 .33979 Mdot
.56277 .37395 Mdot
.36408 .52391 Mdot
.71075 .53857 Mdot
.65407 .5231 Mdot
.55207 .38956 Mdot
.83699 .48204 Mdot
.47677 .61982 Mdot
.50519 .67422 Mdot
.75379 .43801 Mdot
.50266 .66024 Mdot
.34125 .64045 Mdot
.57832 .22027 Mdot
.69902 .55241 Mdot
.51061 .66032 Mdot
.51452 .6088 Mdot
.5007 .60612 Mdot
.38224 .62265 Mdot
.38938 .3366 Mdot
.53272 .65012 Mdot
.31672 .53118 Mdot
.70052 .30273 Mdot
.48955 .68099 Mdot
.54258 .67239 Mdot
.65905 .52901 Mdot
.64144 .81509 Mdot
.55275 .40562 Mdot
.40496 .36804 Mdot
.40918 .33599 Mdot
.3001 .49972 Mdot
.7234 .54349 Mdot
.57777 .21702 Mdot
.53622 .20749 Mdot
.58715 .24628 Mdot
.34156 .50907 Mdot
.29571 .37549 Mdot
.34434 .34916 Mdot
.40462 .37969 Mdot
.57569 .34652 Mdot
.51385 .65837 Mdot
.5193 .6736 Mdot
.70712 .38842 Mdot
.54047 .62851 Mdot
.35357 .50355 Mdot
.53087 .38869 Mdot
.6615 .52641 Mdot
.32528 .51704 Mdot
.58376 .37063 Mdot
.67831 .50557 Mdot
.51175 .69484 Mdot
.50104 .69891 Mdot
.6846 .52394 Mdot
.70951 .51304 Mdot
.46993 .67005 Mdot
.64477 .22572 Mdot
.71974 .50911 Mdot
.66127 .53414 Mdot
.58873 .2593 Mdot
.35625 .3431 Mdot
.55787 .59814 Mdot
.55027 .3614 Mdot
.50957 .62706 Mdot
.35257 .34821 Mdot
.34113 .54321 Mdot
.68415 .51341 Mdot
.50892 .61003 Mdot
.49558 .62768 Mdot
.35588 .51678 Mdot
.33539 .49161 Mdot
.33252 .5035 Mdot
.51669 .40847 Mdot
.51865 .64318 Mdot
.70057 .53236 Mdot
.55999 .39464 Mdot
.36745 .50575 Mdot
.35437 .54933 Mdot
.70302 .2491 Mdot
.46567 .67161 Mdot
.49413 .4978 Mdot
.45351 .10768 Mdot
.32037 .6213 Mdot
.5634 .24449 Mdot
.38572 .40319 Mdot
.38143 .69287 Mdot
.30942 .47572 Mdot
.54165 .36213 Mdot
.25728 .57068 Mdot
.31581 .4998 Mdot
.49825 .59142 Mdot
.53088 .66404 Mdot
.44432 .61864 Mdot
.34069 .52117 Mdot
.37593 .6119 Mdot
.6526 .55058 Mdot
.627 .70781 Mdot
.34453 .52674 Mdot
.36259 .3866 Mdot
.36986 .3999 Mdot
.37669 .34422 Mdot
.53507 .66722 Mdot
.64297 .76377 Mdot
.6684 .63502 Mdot
.57524 .73415 Mdot
.55321 .39827 Mdot
.65145 .49719 Mdot
.23624 .4414 Mdot
.68989 .52462 Mdot
.38689 .39499 Mdot
.33962 .51761 Mdot
.65275 .51489 Mdot
.53462 .37326 Mdot
.55209 .3677 Mdot
.42307 .34701 Mdot
.39925 .33784 Mdot
.41215 .35675 Mdot
.69277 .49502 Mdot
.68061 .54386 Mdot
.50624 .60266 Mdot
.67792 .51714 Mdot
.80147 .52632 Mdot
.3186 .5492 Mdot
.36344 .39486 Mdot
.53988 .37412 Mdot
.71015 .5336 Mdot
.48048 .6372 Mdot
.31871 .4062 Mdot
.55117 .31204 Mdot
.31826 .51855 Mdot
.3315 .3101 Mdot
.74016 .78507 Mdot
.48164 .60058 Mdot
.58571 .36693 Mdot
.71981 .34964 Mdot
.46976 .64667 Mdot
.38142 .36173 Mdot
.52541 .8055 Mdot
.58901 .24653 Mdot
.47914 .68248 Mdot
.53418 .60834 Mdot
.53104 .40486 Mdot
.3845 .46894 Mdot
.52662 .60566 Mdot
.68404 .44951 Mdot
.52018 .36701 Mdot
.36287 .37066 Mdot
.50339 .15337 Mdot
.40196 .40181 Mdot
.42181 .75833 Mdot
.56528 .23807 Mdot
.49691 .59705 Mdot
.4027 .35792 Mdot
.31866 .52589 Mdot
.40677 .35325 Mdot
.69352 .56074 Mdot
.41454 .3664 Mdot
.4886 .65375 Mdot
.69829 .5344 Mdot
.53723 .37381 Mdot
.77061 .48209 Mdot
.68383 .24682 Mdot
.41386 .34249 Mdot
.5749 .27204 Mdot
.47511 .67994 Mdot
.6057 .64727 Mdot
.46971 .71895 Mdot
.49771 .67878 Mdot
.56843 .38291 Mdot
.68978 .55213 Mdot
.5856 .35996 Mdot
.55903 .65807 Mdot
.73563 .7139 Mdot
.57698 .39568 Mdot
.66606 .34426 Mdot
.34026 .50683 Mdot
.41998 .74254 Mdot
.47954 .62735 Mdot
.57211 .37 Mdot
.51829 .64139 Mdot
.64545 .53056 Mdot
.54727 .47707 Mdot
.71517 .31031 Mdot
.56719 .36529 Mdot
.256 .30265 Mdot
.53898 .48506 Mdot
.57252 .60784 Mdot
.57581 .37318 Mdot
.59834 .77771 Mdot
.56859 .25161 Mdot
.34608 .5141 Mdot
.36248 .49758 Mdot
.32294 .50483 Mdot
.54191 .63052 Mdot
.57254 .57855 Mdot
.3611 .5436 Mdot
.51611 .37066 Mdot
.32781 .54113 Mdot
.41542 .72767 Mdot
.24959 .31704 Mdot
.32635 .50729 Mdot
.48668 .62999 Mdot
.5371 .6807 Mdot
.35266 .701 Mdot
.36648 .38527 Mdot
.18032 .46056 Mdot
.7685 .5538 Mdot
.48175 .67701 Mdot
.5843 .63446 Mdot
.68486 .56142 Mdot
.74938 .35347 Mdot
.5769 .66683 Mdot
.36467 .44778 Mdot
.66417 .54821 Mdot
.33654 .37829 Mdot
.70451 .54781 Mdot
.4704 .6055 Mdot
.50222 .63791 Mdot
.70637 .5686 Mdot
.4116 .28534 Mdot
.64021 .28627 Mdot
.34819 .22728 Mdot
.65196 .52546 Mdot
.57456 .36437 Mdot
.57307 .35425 Mdot
.5624 .39667 Mdot
.37694 .33009 Mdot
.70175 .50199 Mdot
.52252 .6481 Mdot
.38028 .3772 Mdot
.47845 .61376 Mdot
.56629 .37772 Mdot
.45146 .15955 Mdot
.66003 .52854 Mdot
.45958 .65091 Mdot
.80593 .38658 Mdot
.38387 .34469 Mdot
.35468 .52179 Mdot
.42687 .44389 Mdot
.44128 .36521 Mdot
.53815 .35855 Mdot
.7315 .5126 Mdot
.50587 .37976 Mdot
.40372 .5322 Mdot
.43875 .61992 Mdot
.55226 .63909 Mdot
.49329 .16826 Mdot
.75545 .30904 Mdot
.54211 .6477 Mdot
.39121 .38028 Mdot
.35608 .36699 Mdot
.50256 .61119 Mdot
.68394 .4999 Mdot
.37162 .51774 Mdot
.31364 .51861 Mdot
.50704 .58687 Mdot
.49159 .44845 Mdot
.40159 .72146 Mdot
.52155 .61343 Mdot
.45748 .57395 Mdot
.43017 .3548 Mdot
.57341 .2621 Mdot
.72545 .4346 Mdot
.3561 .49826 Mdot
.50647 .63207 Mdot
.63169 .30492 Mdot
.65806 .54106 Mdot
.41348 .3636 Mdot
.53378 .38764 Mdot
.39188 .56445 Mdot
.4053 .33192 Mdot
.50329 .61165 Mdot
.51537 .60978 Mdot
.53384 .40643 Mdot
.62882 .52711 Mdot
.33838 .51936 Mdot
.38096 .37613 Mdot
.36493 .50849 Mdot
.68678 .5389 Mdot
.66465 .52775 Mdot
.47469 .57309 Mdot
.4201 .66143 Mdot
.41214 .33905 Mdot
.4755 .58684 Mdot
.37753 .3967 Mdot
.37011 .46808 Mdot
.58341 .40176 Mdot
.52738 .59636 Mdot
.70213 .48659 Mdot
.56464 .38311 Mdot
.47708 .66873 Mdot
.55937 .18555 Mdot
.51291 .59683 Mdot
.44139 .36244 Mdot
.74448 .70555 Mdot
.34102 .54113 Mdot
.74155 .48476 Mdot
.42884 .56539 Mdot
.50123 .6595 Mdot
.3799 .39966 Mdot
.49452 .71641 Mdot
.56552 .40553 Mdot
.67555 .54965 Mdot
.85858 .57129 Mdot
.55394 .37991 Mdot
.50605 .64889 Mdot
.33427 .52847 Mdot
.672 .48639 Mdot
.58236 .23249 Mdot
.7254 .42867 Mdot
.5657 .58564 Mdot
.47839 .70288 Mdot
.51238 .65656 Mdot
.41721 .80556 Mdot
.40575 .36348 Mdot
.71013 .52933 Mdot
.583 .39644 Mdot
.54532 .38906 Mdot
.37307 .35331 Mdot
.66236 .40676 Mdot
.38709 .28491 Mdot
.36884 .12756 Mdot
.42344 .36551 Mdot
.32732 .54296 Mdot
.46426 .45224 Mdot
.40144 .39155 Mdot
.3978 .36211 Mdot
.4157 .33864 Mdot
.6917 .41371 Mdot
.66691 .5082 Mdot
.49641 .62702 Mdot
.72015 .54638 Mdot
.50437 .59567 Mdot
.41438 .77147 Mdot
.55221 .39125 Mdot
.6753 .54849 Mdot
.53175 .17527 Mdot
.46241 .723 Mdot
.47503 .65242 Mdot
.24562 .37166 Mdot
.56141 .66343 Mdot
.36002 .63907 Mdot
.55686 .60563 Mdot
.39898 .34078 Mdot
.58769 .60383 Mdot
.47261 .7107 Mdot
.79536 .51691 Mdot
.54131 .3689 Mdot
.56839 .22798 Mdot
.49154 .69586 Mdot
.54433 .57484 Mdot
.67457 .48659 Mdot
.65242 .51511 Mdot
.36308 .54107 Mdot
.46537 .42111 Mdot
.53818 .37154 Mdot
.45573 .34269 Mdot
.49391 .67501 Mdot
.60286 .3537 Mdot
.75968 .67295 Mdot
.47449 .66775 Mdot
.21384 .45421 Mdot
.64268 .76934 Mdot
.52456 .60364 Mdot
.5982 .74093 Mdot
.54746 .37232 Mdot
.79 .61819 Mdot
.45205 .60816 Mdot
.38216 .36048 Mdot
.6837 .5466 Mdot
.69333 .55873 Mdot
.32192 .51464 Mdot
.81286 .49154 Mdot
.55679 .34804 Mdot
.67867 .54597 Mdot
.47062 .64176 Mdot
.53923 .39296 Mdot
.57563 .22801 Mdot
.51964 .69803 Mdot
.23523 .55263 Mdot
.67281 .5188 Mdot
.46552 .58414 Mdot
.62355 .40875 Mdot
.42075 .4613 Mdot
.15677 .48934 Mdot
.56692 .39516 Mdot
.34707 .49673 Mdot
.55286 .59742 Mdot
.53341 .20474 Mdot
.4409 .65575 Mdot
.39553 .73216 Mdot
.7504 .53589 Mdot
.368 .52048 Mdot
.46493 .64738 Mdot
.52807 .60834 Mdot
.4854 .45679 Mdot
.34084 .49152 Mdot
.51826 .5958 Mdot
.45937 .58136 Mdot
.67935 .50635 Mdot
.57552 .22125 Mdot
.66569 .52133 Mdot
.4852 .63438 Mdot
.58997 .59635 Mdot
.67063 .50224 Mdot
.31192 .30432 Mdot
.34062 .48566 Mdot
.55659 .40464 Mdot
.50493 .55873 Mdot
.50484 .68174 Mdot
.26224 .73456 Mdot
.5648 .23295 Mdot
.49565 .81634 Mdot
.4266 .3824 Mdot
.58639 .28818 Mdot
.40264 .30744 Mdot
.20286 .37003 Mdot
.74963 .46157 Mdot
.44818 .60243 Mdot
.26837 .61969 Mdot
.58945 .73542 Mdot
.56843 .34971 Mdot
.62619 .63893 Mdot
.4927 .67639 Mdot
.464 .6254 Mdot
.3801 .38658 Mdot
.65484 .42038 Mdot
.71647 .35246 Mdot
.50994 .44847 Mdot
.33397 .51795 Mdot
.6785 .53999 Mdot
.49254 .66037 Mdot
.40881 .24876 Mdot
.41777 .36824 Mdot
.58399 .49258 Mdot
.45959 .64208 Mdot
.74294 .39233 Mdot
.68121 .3741 Mdot
.53903 .39414 Mdot
.38742 .40193 Mdot
.44033 .36386 Mdot
.46323 .61502 Mdot
.53254 .37095 Mdot
.51068 .60161 Mdot
.57099 .48477 Mdot
.46977 .5853 Mdot
.3261 .52769 Mdot
.45254 .65428 Mdot
.47658 .47875 Mdot
.16903 .40768 Mdot
.57357 .64231 Mdot
.71863 .518 Mdot
.37869 .3306 Mdot
.38177 .34079 Mdot
.65318 .52459 Mdot
.37891 .344 Mdot
.63188 .71378 Mdot
.75774 .63705 Mdot
.33229 .51314 Mdot
.60212 .62646 Mdot
.32894 .53156 Mdot
.56774 .22812 Mdot
.47088 .67415 Mdot
.53956 .22504 Mdot
.42389 .35987 Mdot
.57772 .81352 Mdot
.54819 .38384 Mdot
.56563 .23221 Mdot
.455 .67487 Mdot
.29368 .37992 Mdot
.3781 .39256 Mdot
.43368 .39558 Mdot
.50052 .60561 Mdot
.65512 .51547 Mdot
.52796 .60904 Mdot
.51113 .58211 Mdot
.56388 .25577 Mdot
.51368 .65649 Mdot
.58356 .36989 Mdot
.69731 .49938 Mdot
.21645 .36321 Mdot
.36499 .3365 Mdot
.45386 .64563 Mdot
.4699 .64254 Mdot
.64403 .5311 Mdot
.46131 .67855 Mdot
.53816 .36215 Mdot
.12508 .36952 Mdot
.34153 .50743 Mdot
.57921 .26193 Mdot
.44448 .38108 Mdot
.52376 .66838 Mdot
.52534 .61268 Mdot
.48175 .16816 Mdot
.66787 .27201 Mdot
.58255 .37109 Mdot
.53468 .59043 Mdot
.39078 .37705 Mdot
.33133 .52751 Mdot
.51837 .37992 Mdot
.51153 .62418 Mdot
.45969 .63055 Mdot
.32555 .52579 Mdot
.21933 .42907 Mdot
.3732 .4336 Mdot
.55705 .3984 Mdot
.59242 .61803 Mdot
.32816 .41524 Mdot
.47663 .62113 Mdot
.35026 .25363 Mdot
.66304 .53383 Mdot
.5765 .37909 Mdot
.52413 .77826 Mdot
.47366 .59785 Mdot
.54382 .35764 Mdot
.53879 .37193 Mdot
.44945 .63941 Mdot
.72444 .54052 Mdot
.6823 .49132 Mdot
.66096 .53751 Mdot
.74261 .71405 Mdot
.33363 .72112 Mdot
.41246 .35575 Mdot
.5479 .37067 Mdot
.35455 .37333 Mdot
.37257 .51607 Mdot
.4444 .44797 Mdot
.35695 .37529 Mdot
.68842 .56012 Mdot
.3672 .39905 Mdot
.51539 .60405 Mdot
.53769 .3694 Mdot
.4051 .38012 Mdot
.52984 .66175 Mdot
.43508 .58999 Mdot
.5207 .49683 Mdot
.37106 .52067 Mdot
.3877 .44993 Mdot
.49757 .64302 Mdot
.56517 .25439 Mdot
.4652 .66658 Mdot
.53579 .39516 Mdot
.45543 .47806 Mdot
.5305 .65799 Mdot
.41486 .34175 Mdot
.42621 .53501 Mdot
.36157 .37265 Mdot
.51182 .57718 Mdot
.48652 .63461 Mdot
.47323 .62158 Mdot
.52718 .6058 Mdot
.67014 .36214 Mdot
.58672 .35739 Mdot
.47679 .55997 Mdot
.35483 .33426 Mdot
.68966 .51924 Mdot
.64665 .54931 Mdot
.31975 .37851 Mdot
.56768 .26304 Mdot
.54772 .36374 Mdot
.47854 .61982 Mdot
.43118 .39806 Mdot
.44031 .16369 Mdot
.34876 .24607 Mdot
.24141 .45032 Mdot
.39684 .38091 Mdot
.71782 .51793 Mdot
.40909 .38365 Mdot
.46746 .61529 Mdot
.55954 .63713 Mdot
.20818 .37226 Mdot
.59726 .39725 Mdot
.34014 .51862 Mdot
.47477 .61491 Mdot
.42842 .76048 Mdot
.38987 .37778 Mdot
.43178 .3586 Mdot
.49914 .59921 Mdot
.66438 .49588 Mdot
.13378 .521 Mdot
.5339 .3895 Mdot
.60945 .64519 Mdot
.74311 .49605 Mdot
.64376 .47159 Mdot
.54056 .3897 Mdot
.53219 .51034 Mdot
.3683 .34974 Mdot
.7795 .54375 Mdot
.68533 .52073 Mdot
.34407 .5203 Mdot
.55717 .62934 Mdot
.69418 .5578 Mdot
.39241 .40259 Mdot
.68524 .55726 Mdot
.47686 .59905 Mdot
.57879 .35273 Mdot
.37038 .3551 Mdot
.58143 .34233 Mdot
.70337 .57006 Mdot
.33255 .53706 Mdot
.42506 .74368 Mdot
.62077 .63282 Mdot
.64089 .77059 Mdot
.53239 .6504 Mdot
.38904 .4175 Mdot
.51983 .64023 Mdot
.67307 .4878 Mdot
.48088 .6277 Mdot
.69687 .58287 Mdot
.42028 .38498 Mdot
.46409 .58552 Mdot
.46846 .67888 Mdot
.67464 .60361 Mdot
.47234 .65872 Mdot
.45159 .66833 Mdot
.53467 .61199 Mdot
.75081 .50661 Mdot
.46134 .58247 Mdot
.66147 .50964 Mdot
.70212 .39502 Mdot
.39702 .35988 Mdot
.36597 .54239 Mdot
.31643 .51049 Mdot
.3956 .72764 Mdot
.42027 .74432 Mdot
.66618 .40954 Mdot
.66408 .51629 Mdot
.57122 .35786 Mdot
.50946 .60151 Mdot
.52245 .77277 Mdot
.31476 .49581 Mdot
.3689 .35093 Mdot
.38624 .32579 Mdot
.4252 .6763 Mdot
.40418 .80365 Mdot
.46686 .58178 Mdot
.73211 .42763 Mdot
.49149 .5873 Mdot
.52911 .59927 Mdot
.41756 .33622 Mdot
.39038 .65831 Mdot
.53262 .65051 Mdot
.67436 .48657 Mdot
.34865 .52067 Mdot
.5674 .67333 Mdot
.32154 .56453 Mdot
.55961 .50115 Mdot
.71816 .58625 Mdot
.51963 .65453 Mdot
.37656 .37177 Mdot
.70948 .54452 Mdot
.75913 .4445 Mdot
.56254 .39312 Mdot
.69516 .43443 Mdot
.66962 .61838 Mdot
.29025 .32586 Mdot
.3446 .51832 Mdot
.22 .44519 Mdot
.48901 .6538 Mdot
.38427 .3293 Mdot
.48832 .59658 Mdot
.43034 .16802 Mdot
.35143 .5417 Mdot
.66115 .56789 Mdot
.57415 .36317 Mdot
.64695 .53311 Mdot
.66236 .74514 Mdot
.52487 .52954 Mdot
.60239 .24035 Mdot
.35541 .347 Mdot
.47407 .77883 Mdot
.70186 .5382 Mdot
.5098 .6154 Mdot
.39851 .11816 Mdot
.66476 .5345 Mdot
.64934 .52488 Mdot
.37424 .46087 Mdot
.36412 .58715 Mdot
.50002 .71387 Mdot
.67781 .55832 Mdot
.35296 .37759 Mdot
.35599 .52876 Mdot
.5359 .63551 Mdot
.53315 .61189 Mdot
.65852 .5084 Mdot
.37991 .3945 Mdot
.45618 .78497 Mdot
.39906 .33899 Mdot
.68682 .50616 Mdot
.38691 .34734 Mdot
.44734 .38813 Mdot
.40444 .37527 Mdot
.48831 .68615 Mdot
.4812 .62005 Mdot
.26077 .50001 Mdot
.66479 .52762 Mdot
.53029 .62119 Mdot
.50302 .6307 Mdot
.70204 .53376 Mdot
.34417 .35528 Mdot
.50409 .78099 Mdot
.50601 .66803 Mdot
.49164 .62239 Mdot
.36688 .51362 Mdot
.34048 .32855 Mdot
.40093 .23973 Mdot
.53407 .63007 Mdot
.31357 .52644 Mdot
.69707 .49595 Mdot
.46737 .66762 Mdot
.41074 .71983 Mdot
.40488 .32449 Mdot
.4515 .63983 Mdot
.58315 .23182 Mdot
.52114 .67194 Mdot
.13563 .51313 Mdot
.45614 .66022 Mdot
.70787 .52388 Mdot
.68914 .54766 Mdot
.41749 .4387 Mdot
.68556 .53022 Mdot
.56792 .23232 Mdot
.56496 .37756 Mdot
.31971 .25343 Mdot
.57269 .23011 Mdot
.5381 .60564 Mdot
.81534 .40989 Mdot
.46934 .59052 Mdot
.49932 .69373 Mdot
.49938 .79949 Mdot
.5712 .23208 Mdot
.69784 .54725 Mdot
.41828 .28741 Mdot
.51755 .58764 Mdot
.53224 .38457 Mdot
.53919 .67512 Mdot
.45055 .65121 Mdot
.65908 .45748 Mdot
.69728 .74812 Mdot
.53595 .39796 Mdot
.56422 .61199 Mdot
.53368 .63043 Mdot
.72587 .29064 Mdot
.47751 .64316 Mdot
.32439 .50998 Mdot
.6533 .53267 Mdot
.41819 .37915 Mdot
.35078 .50926 Mdot
.50102 .66744 Mdot
.34227 .52353 Mdot
.41234 .36074 Mdot
.57104 .38095 Mdot
.45377 .63748 Mdot
.31076 .5167 Mdot
.33524 .51925 Mdot
.52179 .63276 Mdot
.67885 .5476 Mdot
.51138 .71955 Mdot
.46951 .66827 Mdot
.50656 .61433 Mdot
.65414 .52309 Mdot
.78874 .30666 Mdot
.46973 .6092 Mdot
.501 .49817 Mdot
.67333 .56899 Mdot
.59081 .22972 Mdot
.40546 .38381 Mdot
.45293 .61903 Mdot
.55001 .39342 Mdot
.55866 .38867 Mdot
.35235 .39546 Mdot
.64369 .52347 Mdot
.36961 .38757 Mdot
.56848 .64726 Mdot
.42024 .65644 Mdot
.54285 .5971 Mdot
.85447 .57816 Mdot
.2085 .39973 Mdot
.69823 .50207 Mdot
.36465 .35852 Mdot
.51102 .44708 Mdot
.55101 .36466 Mdot
.36087 .39725 Mdot
.71069 .49213 Mdot
.71313 .51494 Mdot
.67953 .56034 Mdot
.36247 .50822 Mdot
.38458 .33296 Mdot
.63014 .53915 Mdot
.65734 .50125 Mdot
.50621 .60461 Mdot
.53289 .62935 Mdot
.70907 .57521 Mdot
.34667 .68149 Mdot
.32898 .53491 Mdot
.37629 .3659 Mdot
.23622 .72434 Mdot
.5365 .39599 Mdot
.67872 .60244 Mdot
.5259 .66536 Mdot
.57577 .11016 Mdot
.49066 .57182 Mdot
.47268 .64196 Mdot
.70192 .49944 Mdot
.32068 .54185 Mdot
.34412 .5331 Mdot
.70023 .53987 Mdot
.729 .55304 Mdot
.3348 .49984 Mdot
.23404 .45729 Mdot
.25785 .29197 Mdot
.74505 .44485 Mdot
.70572 .5251 Mdot
.61899 .62602 Mdot
.53576 .36135 Mdot
.70083 .56857 Mdot
.54173 .40287 Mdot
.39652 .36239 Mdot
.40184 .33276 Mdot
.53525 .40635 Mdot
.49604 .60668 Mdot
.41163 .36857 Mdot
.56662 .58341 Mdot
.23212 .36651 Mdot
.21512 .60326 Mdot
.64489 .25193 Mdot
.52513 .67163 Mdot
.72007 .3639 Mdot
.69383 .3262 Mdot
.49915 .6523 Mdot
.47633 .73478 Mdot
.34143 .52004 Mdot
.68957 .57178 Mdot
.53626 .36512 Mdot
.15822 .50197 Mdot
.47737 .62066 Mdot
.697 .51381 Mdot
.54326 .36623 Mdot
.46153 .38044 Mdot
.66933 .45003 Mdot
.49626 .59799 Mdot
.26501 .2085 Mdot
.67653 .57241 Mdot
.41852 .37906 Mdot
.81164 .44558 Mdot
.71297 .55458 Mdot
.36732 .4579 Mdot
.43587 .36758 Mdot
.36917 .21948 Mdot
.71127 .53455 Mdot
.34433 .38883 Mdot
.68689 .53674 Mdot
.32288 .52522 Mdot
.73103 .51866 Mdot
.36982 .3603 Mdot
.46658 .65303 Mdot
.3753 .35181 Mdot
.32642 .53399 Mdot
.3815 .32809 Mdot
.53529 .36465 Mdot
.56439 .2438 Mdot
.55738 .36933 Mdot
.43302 .45044 Mdot
.71293 .7334 Mdot
.57258 .39463 Mdot
.42492 .31453 Mdot
.54085 .65035 Mdot
.62879 .5225 Mdot
.42285 .37495 Mdot
.34947 .35392 Mdot
.4604 .43965 Mdot
.69667 .52177 Mdot
.3721 .35932 Mdot
.65955 .62346 Mdot
.84144 .39346 Mdot
.54743 .56657 Mdot
.30122 .68624 Mdot
.70347 .53132 Mdot
.42706 .37776 Mdot
.75047 .4371 Mdot
.66526 .56091 Mdot
.42292 .36396 Mdot
.57449 .36931 Mdot
.5436 .38937 Mdot
.48546 .60641 Mdot
.60201 .37061 Mdot
.39069 .39918 Mdot
.63969 .29453 Mdot
.65217 .5361 Mdot
.46236 .3832 Mdot
.32285 .5086 Mdot
.4006 .36612 Mdot
.46178 .70667 Mdot
.72903 .55642 Mdot
.36614 .32816 Mdot
.23718 .58655 Mdot
.27385 .7595 Mdot
.37335 .35813 Mdot
.65324 .53349 Mdot
.6852 .51227 Mdot
.53882 .69433 Mdot
.48687 .44863 Mdot
.37181 .38682 Mdot
.54059 .24812 Mdot
.39619 .73783 Mdot
.5811 .24354 Mdot
.76562 .31391 Mdot
.53188 .65273 Mdot
.51705 .64021 Mdot
.55497 .36166 Mdot
.48116 .65481 Mdot
.67034 .49262 Mdot
.49743 .69131 Mdot
.55241 .35473 Mdot
.3676 .35491 Mdot
.45643 .65482 Mdot
.34699 .53741 Mdot
.52974 .36571 Mdot
.52645 .40074 Mdot
.39535 .35103 Mdot
.67797 .55929 Mdot
.37109 .27146 Mdot
.39785 .33762 Mdot
.5205 .65551 Mdot
.57128 .23902 Mdot
.46671 .60295 Mdot
.23619 .52034 Mdot
.65041 .54722 Mdot
.4109 .38334 Mdot
.70873 .54972 Mdot
.55484 .37312 Mdot
.34834 .38213 Mdot
.48228 .64315 Mdot
.4215 .35677 Mdot
.27917 .50603 Mdot
.23332 .48555 Mdot
.64616 .51249 Mdot
.33416 .56179 Mdot
.64807 .52111 Mdot
.58189 .24244 Mdot
.28419 .57593 Mdot
.34029 .51241 Mdot
.3943 .37412 Mdot
.20107 .40996 Mdot
.42257 .34934 Mdot
.4737 .66079 Mdot
.48668 .66964 Mdot
.38291 .38711 Mdot
.35964 .53102 Mdot
.64673 .80902 Mdot
.51503 .51304 Mdot
.69784 .54932 Mdot
.77065 .53307 Mdot
.18096 .65047 Mdot
.52747 .35589 Mdot
.56608 .35941 Mdot
.52221 .57264 Mdot
.51787 .59793 Mdot
.5178 .38996 Mdot
.58908 .38788 Mdot
.36928 .51544 Mdot
.39815 .33352 Mdot
.63349 .4988 Mdot
.52301 .36983 Mdot
.41303 .56943 Mdot
.42932 .75666 Mdot
.54474 .68696 Mdot
.4338 .61502 Mdot
.52939 .67308 Mdot
.41299 .4618 Mdot
.58765 .37366 Mdot
.4973 .63963 Mdot
.48261 .57058 Mdot
.57916 .37673 Mdot
.32435 .52734 Mdot
.61162 .54319 Mdot
.38276 .35355 Mdot
.73535 .22469 Mdot
.45252 .64368 Mdot
.46653 .659 Mdot
.55281 .3982 Mdot
.73715 .28491 Mdot
.7022 .50781 Mdot
.66267 .55419 Mdot
.40679 .36367 Mdot
.4601 .4365 Mdot
.48429 .688 Mdot
.49825 .64884 Mdot
.3904 .36969 Mdot
.56483 .2472 Mdot
.62179 .24541 Mdot
.49471 .62855 Mdot
.54107 .37511 Mdot
.41389 .42219 Mdot
.58817 .37508 Mdot
.4855 .59869 Mdot
.47618 .6626 Mdot
.48508 .68604 Mdot
.52252 .599 Mdot
.52577 .39708 Mdot
.49469 .64737 Mdot
.44651 .69935 Mdot
.67566 .5533 Mdot
.51529 .6657 Mdot
.39148 .71449 Mdot
.48833 .62414 Mdot
.34291 .53786 Mdot
.39041 .2542 Mdot
.47395 .61852 Mdot
.51481 .6643 Mdot
.51462 .50966 Mdot
.46424 .64235 Mdot
.53977 .39807 Mdot
.68604 .51684 Mdot
.54847 .36995 Mdot
.57945 .39742 Mdot
.35144 .36632 Mdot
.36983 .51838 Mdot
.44094 .65952 Mdot
.31963 .50976 Mdot
.43628 .66842 Mdot
.48079 .59713 Mdot
.33951 .39107 Mdot
.72846 .42604 Mdot
.33029 .46443 Mdot
.48314 .63954 Mdot
.4026 .36134 Mdot
.41765 .37706 Mdot
.25769 .60658 Mdot
.57778 .61041 Mdot
.51867 .38727 Mdot
.57192 .36944 Mdot
.33517 .63634 Mdot
.68211 .45449 Mdot
.33555 .53718 Mdot
.53963 .45216 Mdot
.53374 .66582 Mdot
.49978 .62274 Mdot
.54025 .67534 Mdot
.35593 .3737 Mdot
.56591 .25903 Mdot
.37049 .34604 Mdot
.59698 .24613 Mdot
.58872 .3692 Mdot
.5186 .67447 Mdot
.20201 .57843 Mdot
.66585 .50102 Mdot
.68485 .51706 Mdot
.51429 .37423 Mdot
.36323 .37805 Mdot
.52173 .70569 Mdot
.86158 .57629 Mdot
.66135 .57588 Mdot
.34035 .55084 Mdot
.50122 .64906 Mdot
.39846 .35372 Mdot
.66453 .49934 Mdot
.31977 .50008 Mdot
.50574 .67633 Mdot
.35421 .33304 Mdot
.48268 .62562 Mdot
.58189 .74461 Mdot
.68149 .55277 Mdot
.44049 .16084 Mdot
.64299 .51557 Mdot
.53287 .36073 Mdot
.58194 .38806 Mdot
.47669 .66757 Mdot
.84382 .5226 Mdot
.66095 .56939 Mdot
.58566 .34594 Mdot
.33873 .54631 Mdot
.57891 .26134 Mdot
.35952 .54066 Mdot
.39717 .3939 Mdot
.34717 .51867 Mdot
.40948 .33619 Mdot
.33545 .65161 Mdot
.64019 .56557 Mdot
.34594 .50785 Mdot
.70367 .25815 Mdot
.45933 .68683 Mdot
.36597 .50389 Mdot
.4286 .67984 Mdot
.76749 .5209 Mdot
.38914 .36635 Mdot
.35807 .53198 Mdot
.51125 .61349 Mdot
.1677 .52465 Mdot
.58106 .39268 Mdot
.51982 .3872 Mdot
.44288 .67054 Mdot
.42371 .34457 Mdot
.73113 .54813 Mdot
.40682 .50198 Mdot
.58848 .22437 Mdot
.49689 .64744 Mdot
.51876 .67499 Mdot
.64097 .54047 Mdot
.65809 .49139 Mdot
.47839 .66485 Mdot
.63997 .63456 Mdot
.49053 .65514 Mdot
.5432 .39244 Mdot
.70988 .51244 Mdot
.68352 .51383 Mdot
.38605 .40137 Mdot
.64537 .51979 Mdot
.44083 .60132 Mdot
.55312 .42284 Mdot
.54918 .60114 Mdot
.55628 .37793 Mdot
.46335 .48029 Mdot
.37204 .33129 Mdot
.16886 .48266 Mdot
.6399 .53388 Mdot
.514 .65938 Mdot
.647 .52469 Mdot
.335 .50272 Mdot
.66673 .52558 Mdot
.72221 .52669 Mdot
.48969 .67405 Mdot
.49647 .59726 Mdot
.56811 .23708 Mdot
.48359 .44497 Mdot
.6682 .54592 Mdot
.49468 .65657 Mdot
.46382 .59219 Mdot
.44663 .65448 Mdot
.50974 .47651 Mdot
.71111 .50788 Mdot
.72624 .63428 Mdot
.22463 .55235 Mdot
.67427 .54658 Mdot
.14723 .55233 Mdot
.58726 .23801 Mdot
.57226 .26387 Mdot
.53865 .34942 Mdot
.49547 .62577 Mdot
.36471 .37155 Mdot
.46538 .61694 Mdot
.55626 .57616 Mdot
.46026 .62824 Mdot
.3382 .54372 Mdot
.43685 .64807 Mdot
.57934 .25226 Mdot
.39328 .33757 Mdot
.50785 .66971 Mdot
.4551 .64678 Mdot
.56395 .26048 Mdot
.6388 .52593 Mdot
.71497 .52257 Mdot
.34518 .25711 Mdot
.32976 .51164 Mdot
.56704 .38643 Mdot
.48715 .60915 Mdot
.40418 .36262 Mdot
.37724 .34802 Mdot
.64719 .53091 Mdot
.37996 .35932 Mdot
.5342 .39148 Mdot
.47929 .64678 Mdot
.52032 .39062 Mdot
.33565 .54262 Mdot
.65348 .5316 Mdot
.48548 .60912 Mdot
.50553 .60492 Mdot
.68925 .54778 Mdot
.54077 .651 Mdot
.36666 .51301 Mdot
.4055 .33678 Mdot
.7135 .5248 Mdot
.56421 .38068 Mdot
.3793 .40145 Mdot
.51512 .60695 Mdot
.31899 .78516 Mdot
.48382 .65627 Mdot
.50048 .61354 Mdot
.22802 .33024 Mdot
.51856 .57382 Mdot
.41755 .38577 Mdot
.65075 .55471 Mdot
.49974 .69849 Mdot
.40378 .76101 Mdot
.4997 .17967 Mdot
.35658 .39371 Mdot
.5066 .6531 Mdot
.17353 .4643 Mdot
.50889 .66064 Mdot
.47042 .36638 Mdot
.35568 .42153 Mdot
.34944 .75373 Mdot
.42992 .62195 Mdot
.54143 .40526 Mdot
.56733 .23656 Mdot
.42809 .36698 Mdot
.60896 .76643 Mdot
.49615 .66809 Mdot
.59244 .78128 Mdot
.45622 .66954 Mdot
.54077 .38869 Mdot
.43709 .7129 Mdot
.37667 .36427 Mdot
.80345 .5023 Mdot
.52176 .64847 Mdot
.71024 .50803 Mdot
.36249 .39418 Mdot
.5859 .25432 Mdot
.50892 .61057 Mdot
.3161 .51979 Mdot
.59364 .4327 Mdot
.42237 .6342 Mdot
.55806 .37976 Mdot
.50443 .62998 Mdot
.56506 .60715 Mdot
.82961 .50652 Mdot
.68257 .55424 Mdot
.56932 .3611 Mdot
.74187 .34096 Mdot
.54349 .64661 Mdot
.71238 .53166 Mdot
.68717 .52065 Mdot
.32004 .52162 Mdot
.59307 .44907 Mdot
.60548 .3313 Mdot
.2303 .64368 Mdot
.68718 .73933 Mdot
.39506 .40037 Mdot
.66032 .29226 Mdot
.53385 .63756 Mdot
.5407 .52905 Mdot
.54388 .40122 Mdot
.46537 .65541 Mdot
.72542 .71053 Mdot
.6605 .53627 Mdot
.49167 .63037 Mdot
.32705 .53011 Mdot
.5892 .4419 Mdot
.57179 .50566 Mdot
.24943 .71316 Mdot
.35573 .38786 Mdot
.55687 .64213 Mdot
.42829 .64887 Mdot
.59172 .23563 Mdot
.4958 .59317 Mdot
.42596 .37197 Mdot
.23778 .37728 Mdot
.35806 .53421 Mdot
.65521 .507 Mdot
.58776 .2395 Mdot
.51968 .68304 Mdot
.44923 .62 Mdot
.36446 .54425 Mdot
.51476 .62599 Mdot
.80914 .48065 Mdot
.57021 .28596 Mdot
.40934 .37344 Mdot
.68912 .55682 Mdot
.53586 .66703 Mdot
.56619 .25878 Mdot
.48907 .67248 Mdot
.62755 .58328 Mdot
.51362 .64434 Mdot
.62325 .42167 Mdot
.68387 .54588 Mdot
.55977 .37593 Mdot
.44498 .67787 Mdot
.4651 .62888 Mdot
.32337 .41193 Mdot
.55528 .57576 Mdot
.45502 .65669 Mdot
.67548 .486 Mdot
.67772 .50018 Mdot
.65945 .51252 Mdot
.41521 .36706 Mdot
.73464 .43941 Mdot
.54563 .37925 Mdot
.47039 .68556 Mdot
.52281 .37036 Mdot
.46045 .5538 Mdot
.35429 .5501 Mdot
.17096 .58146 Mdot
.51078 .67206 Mdot
.66237 .51317 Mdot
.63616 .31537 Mdot
.69442 .49511 Mdot
.36702 .31854 Mdot
.53798 .37138 Mdot
.66524 .53622 Mdot
.46832 .63491 Mdot
.50417 .45184 Mdot
.28201 .73678 Mdot
.55536 .36504 Mdot
.54905 .66336 Mdot
.35261 .38357 Mdot
.38435 .32425 Mdot
.13846 .58982 Mdot
.5847 .37879 Mdot
.69123 .32074 Mdot
.49792 .65833 Mdot
.66519 .5021 Mdot
.56592 .39793 Mdot
.55187 .40743 Mdot
.38584 .36629 Mdot
.48917 .60017 Mdot
.47245 .62457 Mdot
.58417 .23297 Mdot
.57108 .37245 Mdot
.47018 .69658 Mdot
.49575 .58932 Mdot
.20789 .36778 Mdot
.61514 .53776 Mdot
.7608 .27305 Mdot
.5687 .64581 Mdot
.68579 .74578 Mdot
.4551 .4623 Mdot
.6964 .50024 Mdot
.47837 .60984 Mdot
.52922 .6801 Mdot
.39841 .3978 Mdot
.482 .65069 Mdot
.36015 .35853 Mdot
.56409 .35812 Mdot
.17635 .59709 Mdot
.48922 .3547 Mdot
.2337 .43878 Mdot
.47605 .65496 Mdot
.63216 .47108 Mdot
.35033 .50477 Mdot
.51572 .40549 Mdot
.69276 .50628 Mdot
.54615 .65017 Mdot
.43895 .35852 Mdot
.39374 .37527 Mdot
.68064 .52583 Mdot
.69144 .34682 Mdot
.32493 .29828 Mdot
.51727 .59382 Mdot
.40135 .38728 Mdot
.50681 .3253 Mdot
.64045 .64644 Mdot
.59693 .39476 Mdot
.35564 .53762 Mdot
.36809 .35511 Mdot
.53051 .40602 Mdot
.6279 .57695 Mdot
.67589 .5341 Mdot
.64973 .55864 Mdot
.28869 .45976 Mdot
.36867 .38221 Mdot
.35733 .51534 Mdot
.72065 .45241 Mdot
.75024 .46693 Mdot
.34303 .54348 Mdot
.36693 .35569 Mdot
.6717 .49885 Mdot
.69475 .51026 Mdot
.68734 .51647 Mdot
.80132 .50531 Mdot
.65193 .54652 Mdot
.74375 .60506 Mdot
.4639 .59383 Mdot
.60281 .65091 Mdot
.50827 .65847 Mdot
.53039 .39852 Mdot
.6833 .55233 Mdot
.46106 .4485 Mdot
.5425 .61715 Mdot
.252 .71132 Mdot
.49861 .64464 Mdot
.57803 .41666 Mdot
.49417 .6238 Mdot
.62767 .60543 Mdot
.67423 .56934 Mdot
.48438 .64106 Mdot
.59309 .3915 Mdot
.33504 .52229 Mdot
.65948 .48026 Mdot
.47333 .61939 Mdot
.64004 .4331 Mdot
.49137 .56996 Mdot
.23658 .36536 Mdot
.39806 .52257 Mdot
.33357 .54911 Mdot
.46464 .57801 Mdot
.37934 .40489 Mdot
.72253 .48649 Mdot
.5935 .65959 Mdot
.5567 .36537 Mdot
.57453 .80568 Mdot
.39775 .37368 Mdot
.439 .71498 Mdot
.52444 .58788 Mdot
.36142 .50367 Mdot
.7306 .49875 Mdot
.54795 .39973 Mdot
.52493 .66959 Mdot
.4488 .644 Mdot
.25586 .52949 Mdot
.60139 .64003 Mdot
.44584 .6635 Mdot
.37215 .52565 Mdot
.73321 .63626 Mdot
.49004 .61619 Mdot
.34483 .35599 Mdot
.67034 .56554 Mdot
.43372 .64689 Mdot
.72327 .63044 Mdot
.49484 .6588 Mdot
.66887 .53166 Mdot
.6393 .53946 Mdot
.65131 .37321 Mdot
.33022 .54677 Mdot
.51352 .64383 Mdot
.3854 .49217 Mdot
.51914 .64568 Mdot
.54254 .38129 Mdot
.46973 .60826 Mdot
.39579 .36678 Mdot
.74861 .4333 Mdot
.41679 .35656 Mdot
.46901 .61166 Mdot
.69422 .51617 Mdot
.55362 .40267 Mdot
.26296 .48593 Mdot
.34118 .41203 Mdot
.74404 .60881 Mdot
.54314 .17943 Mdot
.36313 .51748 Mdot
.35811 .4931 Mdot
.5743 .34814 Mdot
.48502 .63594 Mdot
.38743 .45867 Mdot
.48658 .57814 Mdot
.49236 .6208 Mdot
.45915 .62733 Mdot
.60346 .37012 Mdot
.54651 .36774 Mdot
.38163 .34836 Mdot
.47898 .66356 Mdot
.49396 .65492 Mdot
.67444 .54282 Mdot
.33373 .52031 Mdot
.41897 .36452 Mdot
.33571 .50676 Mdot
.40236 .34386 Mdot
.13682 .51762 Mdot
.55997 .65784 Mdot
.33428 .52389 Mdot
.57999 .3502 Mdot
.65355 .52199 Mdot
.56283 .23643 Mdot
.39173 .39634 Mdot
.37465 .36426 Mdot
.49706 .6497 Mdot
.65658 .52885 Mdot
.65649 .54162 Mdot
.34755 .49887 Mdot
.57328 .38585 Mdot
.46912 .61247 Mdot
.5041 .5942 Mdot
.26154 .64852 Mdot
.3644 .38883 Mdot
.65964 .63558 Mdot
.66351 .38174 Mdot
.484 .63606 Mdot
.67719 .55623 Mdot
.45971 .66122 Mdot
.18191 .49511 Mdot
.69067 .55927 Mdot
.52428 .59763 Mdot
.71196 .46077 Mdot
.35366 .36069 Mdot
.63085 .38028 Mdot
.44662 .61664 Mdot
.47424 .16889 Mdot
.528 .63718 Mdot
.19562 .33974 Mdot
.6908 .28157 Mdot
.50237 .68919 Mdot
.5342 .61655 Mdot
.25556 .68412 Mdot
.50208 .66068 Mdot
.58329 .24731 Mdot
.57198 .63929 Mdot
.71472 .51713 Mdot
.41105 .47688 Mdot
.37776 .31026 Mdot
.33181 .54548 Mdot
.40708 .36416 Mdot
.29171 .54087 Mdot
.32362 .52364 Mdot
.70664 .52833 Mdot
.53285 .61066 Mdot
.43394 .74682 Mdot
.37448 .31855 Mdot
.50654 .58041 Mdot
.54142 .38208 Mdot
.3659 .31357 Mdot
.36472 .34498 Mdot
.56422 .37539 Mdot
.46243 .67602 Mdot
.45703 .79483 Mdot
.32262 .37312 Mdot
.35006 .21795 Mdot
.55656 .39837 Mdot
.53676 .38674 Mdot
.76932 .44782 Mdot
.3307 .54483 Mdot
.25244 .54696 Mdot
.60595 .50701 Mdot
.53041 .37655 Mdot
.34026 .61241 Mdot
.43143 .35441 Mdot
.63671 .4425 Mdot
.69031 .57149 Mdot
.55561 .66366 Mdot
.46722 .63293 Mdot
.57647 .38277 Mdot
.4529 .74589 Mdot
.79582 .43903 Mdot
.55781 .36832 Mdot
.43521 .67578 Mdot
.58721 .44576 Mdot
.57429 .23699 Mdot
.5847 .23071 Mdot
.34653 .54806 Mdot
.31375 .30722 Mdot
.69068 .53817 Mdot
.35668 .49727 Mdot
.61831 .41172 Mdot
.51158 .63744 Mdot
.56743 .36642 Mdot
.56159 .23641 Mdot
.55434 .38898 Mdot
.33879 .53338 Mdot
.34149 .55097 Mdot
.67699 .55365 Mdot
.70189 .50799 Mdot
.67873 .7556 Mdot
.35311 .65175 Mdot
.50894 .66443 Mdot
.52781 .78625 Mdot
.65005 .53355 Mdot
.59722 .6259 Mdot
.31523 .531 Mdot
.33103 .52092 Mdot
.60643 .71847 Mdot
.50422 .60134 Mdot
.45843 .39262 Mdot
.48061 .61669 Mdot
.28221 .58346 Mdot
.53277 .5975 Mdot
.38364 .36316 Mdot
.52448 .65981 Mdot
.38379 .26709 Mdot
.53955 .63851 Mdot
.45315 .64603 Mdot
.37985 .33801 Mdot
.50543 .70758 Mdot
.39563 .36857 Mdot
.48582 .59958 Mdot
.3759 .51626 Mdot
.40451 .36249 Mdot
.32001 .70209 Mdot
.50299 .4981 Mdot
.57051 .2586 Mdot
.32594 .53663 Mdot
.32244 .50746 Mdot
.40727 .73896 Mdot
.69701 .50807 Mdot
.62719 .56667 Mdot
.48591 .63554 Mdot
.43159 .35898 Mdot
.55441 .36115 Mdot
.49291 .65566 Mdot
.54275 .66577 Mdot
.44145 .64005 Mdot
.66163 .53967 Mdot
.36438 .37868 Mdot
.33935 .52588 Mdot
.40869 .38179 Mdot
.30944 .3745 Mdot
.4058 .33197 Mdot
.50065 .56653 Mdot
.51878 .69705 Mdot
.56813 .56421 Mdot
.58203 .79114 Mdot
.79118 .52934 Mdot
.68056 .53063 Mdot
.5691 .24841 Mdot
.34968 .55015 Mdot
.76491 .54129 Mdot
.67457 .50673 Mdot
.37145 .36685 Mdot
.48243 .62561 Mdot
.44466 .69393 Mdot
.58737 .50265 Mdot
.74786 .51453 Mdot
.38337 .73181 Mdot
.38002 .33129 Mdot
.57909 .24065 Mdot
.74551 .44185 Mdot
.75929 .52124 Mdot
.45189 .44797 Mdot
.45766 .64053 Mdot
.31554 .51984 Mdot
.66436 .49941 Mdot
.28616 .4755 Mdot
.5757 .37523 Mdot
.48635 .44737 Mdot
.47708 .65411 Mdot
.65409 .30931 Mdot
.69424 .51684 Mdot
.32926 .53336 Mdot
.57707 .38227 Mdot
.32533 .54394 Mdot
.58766 .23293 Mdot
.33331 .26248 Mdot
.51907 .63246 Mdot
.46034 .66829 Mdot
.58639 .35135 Mdot
.69101 .53583 Mdot
.40098 .44255 Mdot
.2509 .52539 Mdot
.39624 .38771 Mdot
.37878 .44922 Mdot
.69323 .49797 Mdot
.68447 .59403 Mdot
.41231 .37613 Mdot
.51434 .37336 Mdot
.41437 .46505 Mdot
.56304 .35335 Mdot
.47674 .61623 Mdot
.66855 .51483 Mdot
.58482 .37479 Mdot
.32109 .42606 Mdot
.16558 .44727 Mdot
.61788 .59002 Mdot
.51698 .67342 Mdot
.17696 .59211 Mdot
.23174 .34522 Mdot
.43703 .73489 Mdot
.53791 .36031 Mdot
.47479 .67082 Mdot
.51346 .59101 Mdot
.52269 .65246 Mdot
.57567 .35917 Mdot
.27965 .3868 Mdot
.38006 .37172 Mdot
.50235 .64426 Mdot
.32518 .50642 Mdot
.3916 .35935 Mdot
.38595 .40896 Mdot
.42765 .3572 Mdot
.72024 .53083 Mdot
.5234 .59847 Mdot
.69081 .42384 Mdot
.18363 .3571 Mdot
.54966 .36881 Mdot
.57119 .2587 Mdot
.45739 .668 Mdot
.77871 .65026 Mdot
.66023 .51226 Mdot
.39307 .38809 Mdot
.46555 .65811 Mdot
.3014 .39391 Mdot
.5894 .26622 Mdot
.39572 .33519 Mdot
.6972 .51008 Mdot
.43327 .72966 Mdot
.48315 .65113 Mdot
.52644 .63373 Mdot
.69731 .53618 Mdot
.35191 .24433 Mdot
.73404 .43041 Mdot
.45632 .65239 Mdot
.56092 .37504 Mdot
.84508 .44016 Mdot
.44333 .63578 Mdot
.72249 .56476 Mdot
.57867 .26187 Mdot
.64747 .41726 Mdot
.66101 .64057 Mdot
.53987 .56941 Mdot
.18994 .59216 Mdot
.39261 .66999 Mdot
.16094 .57729 Mdot
.31111 .49466 Mdot
.48374 .29916 Mdot
.13137 .49728 Mdot
.59397 .39125 Mdot
.60468 .6212 Mdot
.3165 .73697 Mdot
.70295 .36875 Mdot
.40084 .52331 Mdot
.51384 .20435 Mdot
.33396 .41511 Mdot
.61788 .19178 Mdot
.42391 .35828 Mdot
.26861 .5812 Mdot
.46486 .61569 Mdot
.24278 .33199 Mdot
.63993 .61948 Mdot
.81831 .47154 Mdot
.15951 .55881 Mdot
.39215 .51049 Mdot
.30302 .74822 Mdot
.18049 .46217 Mdot
.47627 .7808 Mdot
.5961 .48687 Mdot
.54841 .25027 Mdot
.73273 .45525 Mdot
.30144 .56704 Mdot
.5599 .67106 Mdot
.40905 .252 Mdot
.27259 .33851 Mdot
.74432 .65381 Mdot
.83483 .47404 Mdot
.40449 .39271 Mdot
.67532 .56666 Mdot
.25878 .6521 Mdot
.68834 .4755 Mdot
.54617 .42876 Mdot
.19004 .59347 Mdot
.19812 .37408 Mdot
.63003 .60521 Mdot
.51005 .16025 Mdot
.61238 .74689 Mdot
.69839 .77342 Mdot
.52567 .49237 Mdot
.64127 .55207 Mdot
.49879 .27276 Mdot
.75099 .46789 Mdot
.57281 .30354 Mdot
.75798 .55968 Mdot
.30526 .53617 Mdot
.34415 .70611 Mdot
.6983 .51467 Mdot
.65214 .64921 Mdot
.5853 .26216 Mdot
.62154 .38261 Mdot
.34701 .39977 Mdot
.1817 .51312 Mdot
.5917 .20625 Mdot
.654 .43394 Mdot
.6371 .28317 Mdot
.30491 .77823 Mdot
.36872 .61609 Mdot
.19866 .4606 Mdot
.58095 .32649 Mdot
.39067 .64235 Mdot
.74717 .40974 Mdot
.36589 .66603 Mdot
.76467 .48228 Mdot
.4212 .82418 Mdot
.27274 .28907 Mdot
.34137 .7876 Mdot
.66796 .48155 Mdot
.44726 .66491 Mdot
.20314 .53019 Mdot
.68889 .73514 Mdot
.3319 .54963 Mdot
.27902 .74472 Mdot
.31362 .5169 Mdot
.65753 .48476 Mdot
.69905 .35526 Mdot
.70949 .59329 Mdot
.41791 .31086 Mdot
.3694 .49613 Mdot
.45904 .58579 Mdot
.61329 .86062 Mdot
.19992 .62178 Mdot
.65206 .38748 Mdot
.20705 .36523 Mdot
.57585 .33445 Mdot
.44058 .42543 Mdot
.56591 .35736 Mdot
.14884 .46667 Mdot
.68055 .50896 Mdot
.15654 .39147 Mdot
.16108 .43826 Mdot
.78754 .37419 Mdot
.72611 .81094 Mdot
.63374 .23028 Mdot
.60679 .64954 Mdot
.43874 .75979 Mdot
.37096 .74247 Mdot
.77076 .41809 Mdot
.77686 .35167 Mdot
.61384 .37974 Mdot
.33643 .24657 Mdot
.14527 .50388 Mdot
.318 .60519 Mdot
.25577 .36782 Mdot
.71917 .37838 Mdot
.49654 .48761 Mdot
.70302 .57586 Mdot
.48275 .50635 Mdot
.5669 .53512 Mdot
.31751 .76719 Mdot
.75651 .67403 Mdot
.85644 .53152 Mdot
.29342 .50549 Mdot
.74867 .30092 Mdot
.21749 .38928 Mdot
.3043 .68127 Mdot
.74258 .56859 Mdot
.69404 .39987 Mdot
.49055 .56847 Mdot
.72377 .43538 Mdot
.47832 .72663 Mdot
.33152 .56279 Mdot
.75907 .44757 Mdot
.46846 .33996 Mdot
.28107 .55863 Mdot
.22147 .61266 Mdot
.65624 .46071 Mdot
.71708 .53369 Mdot
.38268 .68664 Mdot
.35612 .61351 Mdot
.21066 .37142 Mdot
.73967 .34008 Mdot
.3371 .22841 Mdot
.75692 .34763 Mdot
.48384 .5782 Mdot
.59956 .62549 Mdot
.53703 .69812 Mdot
.36494 .64443 Mdot
.45982 .59275 Mdot
.63137 .2955 Mdot
.21624 .34317 Mdot
.73325 .70393 Mdot
.28966 .55399 Mdot
.55454 .79347 Mdot
.31133 .25638 Mdot
.2107 .54022 Mdot
.68981 .28836 Mdot
.53912 .73348 Mdot
.53223 .8615 Mdot
.38943 .35142 Mdot
.33581 .61416 Mdot
.52495 .40444 Mdot
.28574 .46538 Mdot
.36496 .77329 Mdot
.78784 .38601 Mdot
.22018 .33669 Mdot
.70387 .40503 Mdot
.37336 .42426 Mdot
.4999 .4244 Mdot
.3837 .30194 Mdot
.54248 .79634 Mdot
.47481 .70722 Mdot
.44666 .55308 Mdot
.3511 .49338 Mdot
.69244 .72159 Mdot
.22272 .53885 Mdot
.46562 .21089 Mdot
.48746 .56185 Mdot
.46664 .24065 Mdot
.58207 .2388 Mdot
.49488 .44829 Mdot
.13594 .57697 Mdot
.56854 .59528 Mdot
.65693 .24735 Mdot
.28461 .2775 Mdot
.40168 .4621 Mdot
.2117 .44732 Mdot
.66796 .35032 Mdot
.3829 .8072 Mdot
.17452 .39645 Mdot
.33737 .28744 Mdot
.17837 .60612 Mdot
.34152 .20123 Mdot
.43155 .81767 Mdot
.55713 .7746 Mdot
.55394 .41844 Mdot
.17537 .30763 Mdot
.38141 .38119 Mdot
.5975 .80416 Mdot
.69817 .72919 Mdot
.28931 .4079 Mdot
.73537 .52541 Mdot
.41678 .67553 Mdot
.57904 .20243 Mdot
.65397 .57149 Mdot
.45754 .58594 Mdot
.25962 .74042 Mdot
.43841 .83654 Mdot
.27293 .74853 Mdot
.31914 .26557 Mdot
.17318 .59826 Mdot
.2953 .71293 Mdot
.74645 .59987 Mdot
.24257 .58846 Mdot
.47503 .60469 Mdot
.31643 .62713 Mdot
.64107 .23813 Mdot
.36565 .42475 Mdot
.5924 .30976 Mdot
.72564 .51283 Mdot
.38389 .79722 Mdot
.14041 .60942 Mdot
.62883 .71612 Mdot
.7025 .65126 Mdot
.55374 .52145 Mdot
.35425 .63886 Mdot
.4041 .56691 Mdot
.42087 .23315 Mdot
.21488 .37808 Mdot
.30805 .7317 Mdot
.33277 .59682 Mdot
.49845 .21744 Mdot
.40642 .29481 Mdot
.7323 .28998 Mdot
.17071 .49787 Mdot
.28934 .68656 Mdot
.76888 .34927 Mdot
.5279 .74566 Mdot
.79511 .42487 Mdot
.41437 .21453 Mdot
.42946 .42229 Mdot
.36398 .59884 Mdot
.36945 .33122 Mdot
.31734 .61019 Mdot
.58782 .46682 Mdot
.24387 .62212 Mdot
.39758 .69066 Mdot
.30901 .6025 Mdot
.39877 .2932 Mdot
.22301 .69063 Mdot
.39044 .17907 Mdot
.50911 .82888 Mdot
.44848 .17609 Mdot
.47803 .72796 Mdot
.44979 .62524 Mdot
.25238 .30293 Mdot
.21017 .68477 Mdot
.18697 .36341 Mdot
.65317 .30439 Mdot
.31321 .42398 Mdot
.58458 .409 Mdot
.53623 .81652 Mdot
.45605 .19367 Mdot
.19079 .40594 Mdot
.77836 .50974 Mdot
.53591 .35098 Mdot
.71364 .40909 Mdot
.56382 .80466 Mdot
.47253 .7854 Mdot
.6595 .66263 Mdot
.55885 .66977 Mdot
.62689 .63801 Mdot
.66137 .5639 Mdot
.6602 .2987 Mdot
.3626 .65484 Mdot
.3946 .35168 Mdot
.31142 .70663 Mdot
.47359 .54722 Mdot
.49493 .56795 Mdot
.41153 .42905 Mdot
.68638 .57797 Mdot
.60714 .78627 Mdot
.61406 .38874 Mdot
.13017 .5127 Mdot
.65454 .26192 Mdot
.39819 .62992 Mdot
.38181 .65616 Mdot
.28767 .48571 Mdot
.70929 .42654 Mdot
.57151 .34984 Mdot
.1603 .53335 Mdot
.45194 .50614 Mdot
.38249 .67997 Mdot
.62938 .63993 Mdot
.24482 .5254 Mdot
.54634 .65991 Mdot
.65537 .35587 Mdot
.76644 .61053 Mdot
.48437 .44125 Mdot
.63672 .49992 Mdot
.6756 .5797 Mdot
.59136 .16006 Mdot
.40549 .27666 Mdot
.72972 .31742 Mdot
.16426 .53224 Mdot
.55737 .35509 Mdot
.70564 .4962 Mdot
.3036 .6082 Mdot
.23872 .48456 Mdot
.76118 .63949 Mdot
.43343 .39042 Mdot
.37708 .57495 Mdot
.45009 .20685 Mdot
.17999 .59399 Mdot
.2446 .69209 Mdot
.83257 .5073 Mdot
.65429 .50007 Mdot
.23277 .51547 Mdot
.24665 .50932 Mdot
.65258 .50584 Mdot
.74987 .52407 Mdot
.59558 .49451 Mdot
.15306 .58264 Mdot
.71143 .43567 Mdot
.41577 .1918 Mdot
.41026 .46531 Mdot
.29236 .38676 Mdot
.27433 .49059 Mdot
.35784 .58947 Mdot
.16736 .53163 Mdot
.64439 .65969 Mdot
.4158 .78956 Mdot
.56027 .6732 Mdot
.69295 .75157 Mdot
.5408 .81738 Mdot
.51629 .48575 Mdot
.67025 .59591 Mdot
.47436 .35144 Mdot
.51925 .65813 Mdot
.30117 .7763 Mdot
.23297 .35702 Mdot
.77319 .46845 Mdot
.61332 .39978 Mdot
.52264 .61196 Mdot
.47857 .58776 Mdot
.46056 .74523 Mdot
.65587 .40221 Mdot
.4824 .82973 Mdot
.27696 .54951 Mdot
.49092 .73173 Mdot
.63755 .63226 Mdot
.65885 .24963 Mdot
.18771 .52295 Mdot
.22599 .37631 Mdot
.56419 .47014 Mdot
.64284 .24284 Mdot
.46086 .42279 Mdot
.40944 .19011 Mdot
.44542 .24753 Mdot
.28363 .69829 Mdot
.61702 .50089 Mdot
.67481 .39734 Mdot
.29616 .47613 Mdot
.45272 .65608 Mdot
.69122 .34714 Mdot
.17829 .47253 Mdot
.85445 .57196 Mdot
.74928 .40205 Mdot
.24355 .72964 Mdot
.54714 .55492 Mdot
.6786 .40518 Mdot
.38584 .78821 Mdot
.84622 .62804 Mdot
.41245 .24287 Mdot
.30785 .75543 Mdot
.48389 .41396 Mdot
.16362 .54805 Mdot
.55335 .41356 Mdot
.67134 .449 Mdot
.56406 .78784 Mdot
.15012 .57569 Mdot
.20128 .49722 Mdot
.17791 .53775 Mdot
.49983 .76255 Mdot
.17124 .61173 Mdot
.77177 .50718 Mdot
.63136 .19181 Mdot
.34655 .38205 Mdot
.61532 .28092 Mdot
.54075 .75987 Mdot
.56502 .55175 Mdot
.33688 .60718 Mdot
.71148 .25196 Mdot
.77521 .55899 Mdot
.51134 .7701 Mdot
.29608 .64397 Mdot
.66945 .36442 Mdot
.38349 .65284 Mdot
.18069 .42203 Mdot
.61993 .19021 Mdot
.26371 .49632 Mdot
.70006 .3101 Mdot
.33533 .25744 Mdot
.65168 .40152 Mdot
.44776 .28101 Mdot
.19721 .46127 Mdot
.38902 .22192 Mdot
.39049 .5695 Mdot
.63041 .15119 Mdot
.27854 .34315 Mdot
.59297 .4981 Mdot
.36143 .79254 Mdot
.21953 .37403 Mdot
.7788 .51907 Mdot
.80976 .46479 Mdot
.68013 .76563 Mdot
.3344 .65406 Mdot
.46074 .62772 Mdot
.17407 .62533 Mdot
.32976 .69226 Mdot
.29732 .75784 Mdot
.28626 .26089 Mdot
.61473 .66276 Mdot
.53888 .57288 Mdot
.42764 .38207 Mdot
.55426 .50519 Mdot
.28732 .63398 Mdot
.31111 .74689 Mdot
.6449 .78725 Mdot
.3718 .45176 Mdot
.48279 .28833 Mdot
.43766 .38941 Mdot
.54656 .71105 Mdot
.63058 .2407 Mdot
.66686 .38557 Mdot
.28967 .52042 Mdot
.38836 .28539 Mdot
.35145 .62694 Mdot
.65794 .63813 Mdot
.46627 .78693 Mdot
.77888 .39591 Mdot
.50411 .40731 Mdot
.40567 .39408 Mdot
.24032 .65598 Mdot
.28338 .32179 Mdot
.63037 .29993 Mdot
.4697 .81286 Mdot
.69579 .39501 Mdot
.26561 .58857 Mdot
.2256 .57404 Mdot
.77003 .4099 Mdot
.5462 .23709 Mdot
.49588 .79637 Mdot
.69516 .74948 Mdot
.45805 .37348 Mdot
.44388 .572 Mdot
.13844 .52013 Mdot
.35919 .59363 Mdot
.23421 .60068 Mdot
.51227 .49886 Mdot
.71432 .69581 Mdot
.57414 .72152 Mdot
.33669 .7219 Mdot
.46368 .43695 Mdot
.58262 .86137 Mdot
.72782 .54621 Mdot
.30772 .7816 Mdot
.56847 .38098 Mdot
.81735 .56671 Mdot
.36147 .28929 Mdot
.56143 .47951 Mdot
.44136 .46036 Mdot
.65292 .35726 Mdot
.61993 .43774 Mdot
.32703 .25624 Mdot
.79424 .41117 Mdot
.40844 .3332 Mdot
.38306 .47088 Mdot
.41516 .19835 Mdot
.22197 .63306 Mdot
.48783 .69844 Mdot
.29064 .32218 Mdot
.51062 .48536 Mdot
.36781 .43019 Mdot
.25418 .30421 Mdot
.48722 .34187 Mdot
.4351 .66693 Mdot
.3552 .64316 Mdot
.32689 .76481 Mdot
.16811 .42841 Mdot
.79533 .45941 Mdot
.47941 .72685 Mdot
.5479 .4202 Mdot
.35282 .75311 Mdot
.20097 .61375 Mdot
.46571 .38383 Mdot
.66782 .43776 Mdot
.36468 .61127 Mdot
.33824 .82292 Mdot
.43112 .83146 Mdot
.49135 .82615 Mdot
.39594 .46297 Mdot
.62718 .53521 Mdot
.77152 .66012 Mdot
.23396 .59683 Mdot
.6048 .29188 Mdot
.27596 .31797 Mdot
.34162 .61639 Mdot
.82908 .63512 Mdot
.75685 .57056 Mdot
.30783 .36801 Mdot
.5748 .72348 Mdot
.66961 .74932 Mdot
.57316 .41074 Mdot
.32455 .65748 Mdot
.41711 .51839 Mdot
.53957 .35448 Mdot
.6693 .36884 Mdot
.63317 .43842 Mdot
.2347 .6034 Mdot
.75619 .62966 Mdot
.50791 .72487 Mdot
.21086 .60362 Mdot
.63397 .55563 Mdot
.28137 .47822 Mdot
.27019 .50763 Mdot
.40359 .51387 Mdot
.39969 .38334 Mdot
.57774 .59275 Mdot
.50741 .44315 Mdot
.47516 .41945 Mdot
.58145 .82749 Mdot
.31543 .51074 Mdot
.72562 .53259 Mdot
.79723 .51683 Mdot
.66189 .4953 Mdot
.19616 .67289 Mdot
.42128 .23439 Mdot
.63334 .62963 Mdot
.32682 .30703 Mdot
.49596 .24398 Mdot
.70218 .78309 Mdot
.52059 .79963 Mdot
.50974 .5137 Mdot
.75871 .53653 Mdot
.64334 .533 Mdot
.40634 .30697 Mdot
.5537 .24393 Mdot
.67205 .65283 Mdot
.65086 .23475 Mdot
.24709 .58154 Mdot
.63717 .54053 Mdot
.29841 .36733 Mdot
.39912 .64171 Mdot
.13396 .54972 Mdot
.4247 .36933 Mdot
.50401 .85507 Mdot
.52515 .69466 Mdot
.39306 .78073 Mdot
.24588 .31002 Mdot
.75227 .43123 Mdot
.37378 .44606 Mdot
.5356 .20448 Mdot
.49682 .6931 Mdot
.52804 .71597 Mdot
.70271 .51644 Mdot
.24898 .55371 Mdot
.34353 .51638 Mdot
.37449 .71276 Mdot
.52916 .3597 Mdot
.76691 .33118 Mdot
.63528 .24983 Mdot
.68442 .56855 Mdot
.4416 .51724 Mdot
.20887 .516 Mdot
.62743 .46387 Mdot
.50845 .48422 Mdot
.25332 .67935 Mdot
.75577 .64751 Mdot
.63804 .53944 Mdot
.47251 .81631 Mdot
.26496 .54001 Mdot
.15058 .44424 Mdot
.40936 .60287 Mdot
.54363 .49653 Mdot
.63474 .46341 Mdot
.65795 .34956 Mdot
.66698 .64194 Mdot
.21441 .38349 Mdot
.37595 .67717 Mdot
.72904 .45983 Mdot
.309 .60456 Mdot
.47987 .71623 Mdot
.47859 .28869 Mdot
.61647 .2658 Mdot
.81381 .65794 Mdot
.5912 .74696 Mdot
.73608 .41539 Mdot
.72284 .57077 Mdot
.65489 .24598 Mdot
.72661 .53866 Mdot
.26211 .43269 Mdot
.74489 .65994 Mdot
.345 .29095 Mdot
.14267 .48745 Mdot
.21376 .36925 Mdot
.57829 .52403 Mdot
.4178 .414 Mdot
.39618 .67723 Mdot
.40061 .64363 Mdot
.48241 .45967 Mdot
.48941 .69174 Mdot
.51726 .73492 Mdot
.78957 .45755 Mdot
.6345 .31315 Mdot
.42057 .6834 Mdot
.14999 .55132 Mdot
.15621 .43154 Mdot
.19457 .6418 Mdot
.45448 .40166 Mdot
.72178 .52297 Mdot
.39421 .81221 Mdot
.69204 .61906 Mdot
.17949 .41979 Mdot
.54481 .76269 Mdot
.57284 .15473 Mdot
.35423 .77038 Mdot
.46882 .34674 Mdot
.78531 .36715 Mdot
.61907 .34518 Mdot
.25831 .30583 Mdot
.63025 .19134 Mdot
.33987 .57392 Mdot
.26272 .29448 Mdot
.61099 .86015 Mdot
.57195 .76579 Mdot
.64458 .43441 Mdot
.57469 .70686 Mdot
.39426 .64663 Mdot
.64723 .22318 Mdot
.46681 .60859 Mdot
.36188 .33099 Mdot
.36209 .44757 Mdot
.35038 .62027 Mdot
.50999 .55291 Mdot
.65561 .22845 Mdot
.28206 .62768 Mdot
.26736 .57497 Mdot
.24651 .49765 Mdot
.32499 .75193 Mdot
.67591 .64497 Mdot
.42978 .65191 Mdot
.63738 .49423 Mdot
.34907 .54604 Mdot
.29838 .55095 Mdot
.5122 .59541 Mdot
.37543 .44155 Mdot
.60531 .49226 Mdot
.2589 .74253 Mdot
.25164 .46086 Mdot
.23024 .43319 Mdot
.66872 .5776 Mdot
.65948 .38882 Mdot
.20391 .55173 Mdot
.70127 .36362 Mdot
.67622 .23923 Mdot
.75161 .68061 Mdot
.18301 .60081 Mdot
.69366 .40827 Mdot
.30615 .58024 Mdot
.63828 .81288 Mdot
.52758 .38907 Mdot
.6117 .77971 Mdot
.29679 .72017 Mdot
.69152 .37093 Mdot
.65416 .48952 Mdot
.45499 .32128 Mdot
.49447 .30361 Mdot
.68264 .36865 Mdot
.28844 .27406 Mdot
.23161 .52982 Mdot
.5946 .70158 Mdot
.23158 .67047 Mdot
.35589 .38326 Mdot
.33129 .59792 Mdot
.43174 .29503 Mdot
.63385 .20718 Mdot
.65726 .45797 Mdot
.1402 .53138 Mdot
.47269 .45589 Mdot
.33514 .70344 Mdot
.52214 .63467 Mdot
.72645 .63154 Mdot
.6419 .32816 Mdot
.41788 .29837 Mdot
.73008 .3256 Mdot
.70579 .54979 Mdot
.64217 .27375 Mdot
.5605 .28138 Mdot
.33431 .6715 Mdot
.46595 .54469 Mdot
.61661 .51393 Mdot
.33185 .48303 Mdot
.59565 .23891 Mdot
.48116 .70144 Mdot
.35871 .72369 Mdot
.40589 .30208 Mdot
.58817 .78271 Mdot
.56521 .77365 Mdot
.24101 .65918 Mdot
.23665 .37741 Mdot
.62372 .29808 Mdot
.5353 .77151 Mdot
.62348 .41629 Mdot
.74156 .58611 Mdot
.71003 .34786 Mdot
.44747 .61245 Mdot
.26444 .42877 Mdot
.70563 .49986 Mdot
.22567 .6435 Mdot
.61268 .57774 Mdot
.31685 .69859 Mdot
.5245 .46591 Mdot
.19793 .52706 Mdot
.47709 .48811 Mdot
.24771 .31043 Mdot
.6168 .34033 Mdot
.36333 .65761 Mdot
.56497 .33871 Mdot
.48414 .41053 Mdot
.75388 .39925 Mdot
.15893 .49003 Mdot
.78507 .39547 Mdot
.44555 .75893 Mdot
.72491 .4102 Mdot
.70923 .73278 Mdot
.27227 .27524 Mdot
.35411 .66453 Mdot
.48459 .4602 Mdot
.40181 .58218 Mdot
.62111 .39652 Mdot
.56193 .24112 Mdot
.27856 .42764 Mdot
.68702 .6324 Mdot
.2472 .40919 Mdot
.3256 .36728 Mdot
.46154 .6905 Mdot
.78262 .64317 Mdot
.21802 .64606 Mdot
.77107 .5343 Mdot
.54588 .48284 Mdot
.32306 .45569 Mdot
.33866 .68109 Mdot
.80256 .2954 Mdot
.29686 .77448 Mdot
.52166 .633 Mdot
.41416 .46993 Mdot
.36702 .70555 Mdot
.36096 .35571 Mdot
.67387 .65987 Mdot
.23762 .65587 Mdot
.53398 .38066 Mdot
.30851 .43332 Mdot
.57828 .28956 Mdot
.64727 .34813 Mdot
.33149 .72224 Mdot
.60145 .36698 Mdot
.21606 .70015 Mdot
.29461 .30619 Mdot
.64681 .32589 Mdot
.70372 .19654 Mdot
.64393 .29647 Mdot
.62931 .5593 Mdot
.19583 .49084 Mdot
.21841 .68447 Mdot
.39914 .46345 Mdot
.2883 .46038 Mdot
.56883 .77485 Mdot
.36769 .66675 Mdot
.27907 .5747 Mdot
.69793 .3087 Mdot
.65468 .28095 Mdot
.64 .19719 Mdot
.4967 .24207 Mdot
.59842 .82906 Mdot
.63743 .65309 Mdot
.24796 .70127 Mdot
.41437 .2393 Mdot
.83482 .62203 Mdot
.14893 .46765 Mdot
.30907 .63003 Mdot
.67395 .24529 Mdot
.201 .47233 Mdot
.39407 .7344 Mdot
.78417 .61301 Mdot
.39386 .24665 Mdot
.75414 .66246 Mdot
.48381 .23745 Mdot
.72354 .34492 Mdot
.31385 .6072 Mdot
.68485 .74462 Mdot
.46841 .45261 Mdot
.28806 .72494 Mdot
.74525 .2872 Mdot
.37919 .64327 Mdot
.32036 .43598 Mdot
.40319 .75568 Mdot
.20645 .60786 Mdot
.1902 .46146 Mdot
.4693 .46633 Mdot
.61758 .85351 Mdot
.31581 .76455 Mdot
.71207 .36526 Mdot
.46062 .59706 Mdot
.13774 .47856 Mdot
.43173 .48488 Mdot
.53572 .77472 Mdot
.27001 .30806 Mdot
.27863 .53644 Mdot
.62184 .4822 Mdot
.44108 .64927 Mdot
.51223 .80165 Mdot
.64771 .59409 Mdot
.66651 .75336 Mdot
.34767 .45635 Mdot
.38099 .66017 Mdot
.75191 .29833 Mdot
.37603 .7536 Mdot
.40261 .64908 Mdot
.69853 .49879 Mdot
.23591 .71449 Mdot
.47215 .77778 Mdot
.58458 .60247 Mdot
.59312 .6713 Mdot
.78892 .40228 Mdot
.56463 .19496 Mdot
.46446 .71909 Mdot
.70581 .42778 Mdot
.33993 .60814 Mdot
.23406 .58078 Mdot
.54337 .78568 Mdot
.74419 .7991 Mdot
.23754 .31649 Mdot
.73108 .54917 Mdot
.61649 .77007 Mdot
.38891 .48535 Mdot
.19877 .64411 Mdot
.49495 .21466 Mdot
.28022 .49355 Mdot
.81802 .43212 Mdot
.39007 .70824 Mdot
.5508 .61896 Mdot
.31123 .26818 Mdot
.15342 .47544 Mdot
.76637 .30776 Mdot
.1392 .51849 Mdot
.53791 .57592 Mdot
.56169 .64437 Mdot
.88399 .50639 Mdot
.17064 .57242 Mdot
.54647 .57462 Mdot
.80191 .42884 Mdot
.73666 .51708 Mdot
.47263 .61027 Mdot
.57381 .28557 Mdot
.37149 .59303 Mdot
.27551 .57778 Mdot
.15202 .57847 Mdot
.63355 .54955 Mdot
.3722 .44123 Mdot
.52992 .40591 Mdot
.44725 .45554 Mdot
.44624 .69389 Mdot
.5859 .37685 Mdot
.27433 .59095 Mdot
.4196 .48676 Mdot
.60057 .4272 Mdot
.38413 .5703 Mdot
.39828 .18231 Mdot
.58164 .56854 Mdot
.57204 .52289 Mdot
.5074 .75447 Mdot
.77803 .55621 Mdot
.28459 .62989 Mdot
.26461 .616 Mdot
.26993 .28926 Mdot
.38273 .16136 Mdot
.35149 .30705 Mdot
.40924 .6506 Mdot
.69108 .46879 Mdot
.67465 .63361 Mdot
.58981 .69335 Mdot
.49913 .40752 Mdot
.57214 .2299 Mdot
.51703 .57132 Mdot
.39888 .62554 Mdot
.52664 .3629 Mdot
.29918 .79002 Mdot
.46428 .60487 Mdot
.62562 .68368 Mdot
.17663 .45161 Mdot
.28473 .47703 Mdot
.59719 .57898 Mdot
.50224 .69231 Mdot
.77301 .50968 Mdot
.42221 .49026 Mdot
.41668 .71543 Mdot
.27028 .49839 Mdot
.20621 .64626 Mdot
.59362 .56941 Mdot
.6151 .67873 Mdot
.49678 .64375 Mdot
.36806 .49696 Mdot
.63721 .44438 Mdot
.50423 .81491 Mdot
.44116 .54881 Mdot
.17598 .41612 Mdot
.27225 .52817 Mdot
.27723 .54805 Mdot
.61157 .62868 Mdot
.29498 .75826 Mdot
.74315 .39818 Mdot
.61458 .65643 Mdot
.78423 .46915 Mdot
.45547 .29514 Mdot
.2964 .64206 Mdot
.43703 .3745 Mdot
.42066 .68236 Mdot
.73431 .50597 Mdot
.15165 .60354 Mdot
.52758 .8013 Mdot
.5087 .35894 Mdot
.45582 .37153 Mdot
.72456 .59601 Mdot
.44876 .45927 Mdot
.66332 .17286 Mdot
.50871 .20148 Mdot
.22047 .70545 Mdot
.2373 .54438 Mdot
.68914 .46778 Mdot
.67111 .36105 Mdot
.56868 .57702 Mdot
.38043 .34159 Mdot
.20203 .64579 Mdot
.41173 .58123 Mdot
.7089 .33595 Mdot
.48555 .5979 Mdot
.75961 .46766 Mdot
.3968 .64693 Mdot
.43064 .40977 Mdot
.37869 .32421 Mdot
.79411 .44322 Mdot
.17934 .48322 Mdot
.42375 .4914 Mdot
.57399 .16729 Mdot
.31274 .75073 Mdot
.15975 .53114 Mdot
.43505 .39165 Mdot
.82431 .55575 Mdot
.71944 .57424 Mdot
.39961 .65382 Mdot
.55528 .33536 Mdot
.4465 .76717 Mdot
.68634 .36645 Mdot
.23753 .57104 Mdot
.6285 .41357 Mdot
.59925 .47815 Mdot
.5487 .10448 Mdot
.30609 .61984 Mdot
.73992 .56524 Mdot
.68339 .33634 Mdot
.15022 .52938 Mdot
.38517 .54755 Mdot
.35347 .21592 Mdot
.403 .26175 Mdot
.4551 .70372 Mdot
.7605 .61831 Mdot
.41354 .78296 Mdot
.51789 .31658 Mdot
.64917 .81696 Mdot
.27855 .3257 Mdot
.29865 .5632 Mdot
.42007 .29777 Mdot
.65866 .49741 Mdot
.73424 .5212 Mdot
.42265 .21869 Mdot
.47056 .15539 Mdot
.43179 .71874 Mdot
.19312 .60484 Mdot
.744 .739 Mdot
.25423 .54514 Mdot
.17793 .6163 Mdot
.55801 .31735 Mdot
.75138 .53394 Mdot
.27683 .61973 Mdot
.34399 .46344 Mdot
.35691 .36793 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0WOooool2o`00
0:[ooooo000Looooo`;o0000W_ooool2o`000:[ooooo000Looooo`03o`000?oooooooooo0:kooooo
0_l0002Iooooo`007?ooool00ol0003oooooooooo`2^ooooo`;o0000VOooool001cooooo00?o0000
ooooooooool0T?ooool2o`0002Gooooo0_l0002@ooooo`007?ooool00ol0003oooooooooo`25oooo
o`;o00002Oooool2o`0002Gooooo0_l0002@ooooo`007?ooool00ol0003oooooooooo`25ooooo`;o
0000`_ooool001cooooo00?o0000ooooooooool0O_ooool2o`0003Oooooo0_l0002@ooooo`007?oo
ool00ol0003oooooooooo`1nooooo`;o0000=oooool2o`00093ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0M?ooool2o`000=?ooooo000Looooo`03
o`000?oooooooooo07Cooooo0_l00017ooooo`;o0000R_ooool001cooooo00?o0000ooooooooool0
_Oooool2o`0008[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`1[ooooo`;o0000g?ooool001co
oooo00?o0000ooooooooool0Joooool2o`000=cooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo0_l0002Gooooo`;o00002?ooool2o`0002Oooooo0_l0001nooooo`007?ooool0
0ol0003oooooooooo`2Eooooo`?o00002?ooool4o`0001;ooooo0_l0000Aooooo`;o0000O_ooool0
01cooooo00?o0000ooooooooool0Soooool4o`0000;ooooo0_l000000ooooooo0000o`000008oooo
o`;o00004_ooool2o`00097ooooo000Looooo`03o`000?oooooooooo07Wooooo0_l0000@ooooo`;o
00000_ooool4o`0000Gooooo0_l00008ooooo`;o00000oooool2o`0001?ooooo0_l0000@ooooo`;o
0000NOooool001cooooo00?o0000ooooooooool0NOooool2o`00013ooooo0_l0000Eooooo`;o0000
0oooool2o`0001?ooooo0_l0000@ooooo`;o0000NOooool001cooooo00?o0000ooooooooool0R?oo
ool2o`000003ooooool0003o000000Wooooo0_l000001?oooooo0000o`000?ooool2o`000003oooo
ool0003o000001Kooooo0_l0002@ooooo`007?ooool00ol0003oooooooooo`28ooooo`;o00003?oo
ool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000005_ooool2o`00093ooooo
000Looooo`03o`000?oooooooooo09Kooooo0_l0000Aooooo`;o00001?ooool2o`0002?ooooo0_l0
001cooooo`007?ooool00ol0003oooooooooo`24ooooo`;o00002?ooool4o`0001Oooooo0_l00004
ooooo`;o00008oooool2o`0007?ooooo000Looooo`03o`000?oooooooooo07_ooooo0_l000000ooo
oooo0000o`000004ooooo`;o00002?ooool4o`0000gooooo0_l0000<ooooo`;o0000V_ooool001co
oooo00?o0000ooooooooool0G?ooool2o`0001gooooo0_l000001?oooooo0000o`000?l0000Noooo
o`;o00003?ooool2o`0009[ooooo000Looooo`03o`000?oooooooooo05cooooo0_l0000Oooooo`Co
00005Oooool2o`0001[ooooo0_l0002Eooooo`007?ooool00ol0003oooooooooo`1mooooo`;o0000
0_ooool2o`0001?ooooo0_l0000Jooooo`;o00004_ooool2o`00087ooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`21ooooo`Co
00002oooool2o`0003?ooooo0ol000000ooooooo0000o`00001nooooo`0000KoooooogMgMonHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000
ooooooooool0Poooool2o`0000_ooooo0_l0000Rooooo`;o00003oooool2o`0000;ooooo0_l0000F
ooooo`;o0000I_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00onH
V9So8B4Qonk^kP07ooooo`03o`000?oooooooooo08?ooooo0_l0000:ooooo`?o00004_ooool2o`00
0003ooooool0003o000000_ooooo0_l0000Fooooo`;o00004oooool2o`0006Kooooo00000ooooooo
0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0006_o
oooo0_l0000Fooooo`;o00002_ooool2o`0000[ooooo0_l00004ooooo`;o000000Coooooo`000?l0
003ooooo0_l0000?ooooo`;o00004_ooool2o`0007_ooooo00000ooooooo0000ooooo`02ooooo`03
o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`1[ooooo`;o
0000;_ooool2o`0000Cooooo1?l00005ooooo`;o00003?ooool2o`0008oooooo00000ooooooo410@
ooooo`02ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1Booooo`;o0000>_ooool2o`0001?ooooo0_l00005ooooo`;o00004?ooool2o`0000cooooo
0_l0001mooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRH
V?l@41001_ooool00ol0003oooooooooo`1Booooo`;o00008?ooool2o`0000Gooooo0_l0000Aoooo
o`;o00000oooool2o`0001Gooooo0_l0000@ooooo`;o00003?ooool2o`0007gooooo00001_oooooo
k^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oo
oooooooo07Cooooo0_l00005ooooo`;o00001_ooool2o`0000kooooo0_l00008ooooo`;o00007ooo
ool2o`0008Wooooo000Looooo`03o`000?oooooooooo06kooooo0ol0000Booooo`;o00005oooool4
o`0001Kooooo1?l00004ooooo`;o0000ROooool001cooooo00?o0000ooooooooool0KOooool4o`00
00?ooooo0_l0000@ooooo`;o00005?ooool4o`0001Kooooo1?l0002?ooooo`007?ooool00ol0003o
ooooooooo`1]ooooo`;o00001Oooool2o`0000Gooooo0_l00009ooooo`;o00009Oooool2o`0000Ko
oooo1Ol000001?oooooo0000o`000?l0000@ooooo`;o00006oooool2o`0005cooooo000Looooo`03
o`000?oooooooooo06gooooo0_l0000<ooooo`;o00004_ooool2o`0001[ooooo1?l00005ooooo`[o
00004?ooool2o`0001_ooooo0_l0001Looooo`007?ooool00ol0003oooooooooo`1Zooooo`;o0000
00?oooooo`000?l000008?ooool2o`0001[ooooo0_l00007ooooo`co00002_ooool2o`0000;ooooo
0_l000000ooooooo0000o`00000Hooooo`;o0000G?ooool001cooooo00?o0000ooooooooool0J_oo
ool2o`0001Wooooo0_l00008ooooo`;o00008_ooool=o`0000[ooooo0_l00005ooooo`;o000000Co
ooooo`000?l0003ooooo0_l0001`ooooo`007?ooool00ol0003oooooooooo`25ooooo`;o0000;?oo
ool;o`0001;ooooo0_l00002ooooo`;o000000?oooooo`000?l00000L?ooool001cooooo00?o0000
ooooooooool0O_ooool2o`0000?ooooo1?l0000Booooo`;o00004oooool2o`0000?ooooo3Ol0000<
ooooo`;o00000_ooool2o`0000Kooooo0_l0001_ooooo`007?ooool00ol0003oooooooooo`18oooo
o`;o00007oooool2o`00017ooooo1?l00002ooooo`?o00002_ooool2o`0000?ooooo0_l00003oooo
o`;o00000oooool2o`0000kooooo0_l00003ooooo`oo00000oooool2o`0000;ooooo0_l000001?oo
oooo0000o`000?l00002ooooo`;o00001Oooool2o`0006oooooo000Looooo`03o`000?oooooooooo
04Sooooo0_l0000Oooooo`;o00000oooool3o`0000_ooooo0_l00003ooooo`?o00002oooool2o`00
00?ooooo0_l00007ooooo`?o00003?ooool2o`0000;ooooo1_l00002ooooo`[o00000oooool3o`00
0003ooooool0003o000000;ooooo0_l00002ooooo`;o00001?ooool2o`00073ooooo000Looooo`03
o`000?oooooooooo06[ooooo0_l00002ooooo`?o00002oooool4o`000003ooooool0003o000000[o
oooo1?l0000<ooooo`Co00002oooool2o`0000;ooooo4?l00006ooooo`;o00002Oooool3o`0000?o
oooo0_l000000ooooooo0000o`000005ooooo`;o0000I_ooool001cooooo0_l0001[ooooo`;o0000
0oooool2o`0000_ooooo1?l000000ooooooo0000o`00000:ooooo`Co00003_ooool2o`0000_ooooo
1?l00002ooooo`co00003Oooool2o`000003ooooool0003o000000;ooooo0_l00006ooooo`;o0000
1Oooool4o`0006Cooooo000Looooo`03o`000?oooooooooo04Kooooo0_l0000Looooo`;o00002?oo
ool3o`0000Gooooo0_l00003ooooo`?o00000oooool2o`0002_ooooo0_l00002ooooo`co00003Ooo
ool2o`000003ooooool0003o000000;ooooo0_l0000?ooooo`;o0000I?ooool001cooooo00?o0000
ooooooooool0A_ooool2o`0001Cooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo1?l0
00000ooooooo0000o`000002o`0000Kooooo0_l00003ooooo`;o0000=Oooool6o`000003ooooool0
003o000000?o00008oooool2o`0006Kooooo000Looooo`03o`000?oooooooooo05Wooooo0_l00000
0ooooooo0000o`000003ooooo`;o00000_ooool6o`000003ooooool0003o000002;ooooo0_l0000P
ooooo`_o00009?ooool2o`0006Kooooo000Looooo`03o`000?oooooooooo05Wooooo0_l00004oooo
o`;o00000oooool4o`000003ooooool0003o000000Kooooo0_l00006ooooo`;o00001?ooool2o`00
00oooooo0_l0000Pooooo`_o000000?oooooo`000?l000004Oooool2o`0007Kooooo000Looooo`03
o`000?oooooooooo04;ooooo0_l0000Kooooo`;o00000oooool4o`000003ooooool0003o000000Ko
oooo0_l00006ooooo`;o00001?ooool2o`0003Cooooo2ol00004ooooo`;o00002oooool2o`0007Ko
oooo000Looooo`03o`000?oooooooooo04;ooooo0_l0000Iooooo`;o00000_ooool2o`000003oooo
ool0003o000001?ooooo0_l0000kooooo`Co00000_ooool2o`0000Kooooo0_l0000Rooooo`;o0000
Goooool001cooooo00?o0000ooooooooool0GOooool2o`0000;ooooo0_l0000Booooo`;o00009ooo
ool2o`0001?ooooo0_l000001?oooooo0000o`000?l0000Dooooo`;o00001_ooool2o`00017ooooo
0_l00009ooooo`;o0000E?ooool001cooooo00?o0000ooooooooool0EOooool2o`0000?ooooo0_l0
000Iooooo`;o00002Oooool2o`0000[ooooo0_l0000@ooooo`;o00004oooool2o`0000;ooooo0_l0
000Dooooo`;o00001_ooool2o`0001cooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`1@
ooooo`;o00000oooool2o`0000;ooooo0ol0000Tooooo`;o00002_ooool2o`0004?ooooo0_l0001f
ooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00001oooool2o`0003?ooooo0_l0000Aoooo
o`;o00003oooool2o`0000Gooooo0_l00002ooooo`;o00001Oooool2o`0000Gooooo0_l00004oooo
o`;o00002_ooool2o`0000cooooo0_l00009ooooo`;o0000DOooool001cooooo00?o0000oooooooo
ool0??ooool2o`00033ooooo0_l0000:ooooo`;o00000oooool2o`000003ooooool0003o000000[o
oooo0_l0000>ooooo`;o000000?oooooo`000?l000003oooool2o`000003ooooool0003o000000Co
00000_ooool2o`0000Gooooo0_l00005ooooo`?o00000oooool2o`0000[ooooo0_l0000<ooooo`?o
00002?ooool2o`00057ooooo000Looooo`03o`000?oooooooooo03cooooo0_l0000Fooooo`?o0000
4oooool2o`0000;ooooo0_l00002ooooo`;o00001_ooool2o`0000;ooooo0ol000000ooooooo0000
o`000002o`0001;ooooo0ol00003ooooo`;o00005Oooool4o`0000;ooooo0_l0000?ooooo`;o0000
3_ooool2o`0000kooooo1?l0001Iooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00000_oo
ool3o`0001?ooooo1?l00004ooooo`;o00002_ooool2o`0000;ooooo1?l0000<ooooo`;o00001?oo
ool3o`0001gooooo0_l000000ooooooo0000o`000004ooooo`;o00004?ooool2o`0000Oooooo0_l0
00000ooooooo0000o`000007ooooo`Co00000_ooool2o`0005Wooooo000Looooo`03o`000?oooooo
oooo053ooooo1?l0000Hooooo`;o00004?ooool6o`0000Cooooo0_l00006ooooo`Co00000_ooool2
o`00023ooooo0ol00006ooooo`;o00001_ooool2o`000003ooooool0003o000000?ooooo1?l00008
ooooo`Go00001_ooool4o`0001Gooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`1Boooo
o`;o00004_ooool2o`00017ooooo0_l00003ooooo`Co00000_ooool3o`000003ooooool0003o0000
00Kooooo0_l00004ooooo`;o00007?ooool2o`0000?ooooo0_l0000<ooooo`Co000000Goooooo`00
0?l0003o0000ooooo`05o`0000Sooooo0_l000000ooooooo0000o`00000>ooooo`;o00003oooool2
o`0004Kooooo000Looooo`;o0000E?ooool2o`00017ooooo0_l0000Aooooo`;o00002Oooool3o`00
01;ooooo0_l0000Iooooo`;o00004Oooool4o`0000;ooooo0_l000001?oooooo0000o`000?ooool2
o`0001[ooooo0ol0001Gooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00005_ooool3o`00
00;ooooo0_l0000=ooooo`;o00005Oooool2o`0000Gooooo0_l0000Gooooo`;o00000_ooool2o`00
01Oooooo0_l0000Aooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o00002_ooool3
o`0000gooooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`0eooooo`?o00005_ooool4o`00
00[ooooo0_l00004ooooo`;o00000_ooool2o`0000Kooooo0_l00009ooooo`;o00001?ooool3o`00
01_ooooo0_l0000Gooooo`;o00004Oooool2o`0000Gooooo0ol0000<ooooo`?o00001_ooool2o`00
00Kooooo0_l00003ooooo`;o00001Oooool2o`0004_ooooo000Looooo`03o`000?oooooooooo03Go
oooo0_l0000Booooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000;ooooo0_l00006oooo
o`;o00001?ooool2o`0000;ooooo1?l00004ooooo`;o00001?ooool2o`000003ooooool0003o0000
00Kooooo0ol00002ooooo`;o0000=oooool2o`0000[ooooo0_l00006ooooo`;o00003?ooool5o`00
0004ooooool0003o0000ooooo`;o00001_ooool4o`000003ooooool0003o000000Gooooo0_l0001;
ooooo`007?ooool00ol0003oooooooooo`19ooooo`;o000000?oooooo`000?l000000_l00004oooo
o`;o00004_ooool2o`0000Wooooo0ol000000ooooooo0000o`00000;ooooo`;o0000:Oooool2o`00
00?ooooo0_l000000ooooooo0000o`000004ooooo`;o00002oooool2o`0000Gooooo0_l0000<oooo
o`Go000000?oooooo`000?l000002oooool2o`000003ooooool0003o000005;ooooo000Looooo`03
o`000?oooooooooo04Wooooo0_l00002ooooo`?o00006Oooool2o`0000Sooooo0_l0000:ooooo`;o
00001Oooool2o`0001Sooooo0_l00002ooooo`;o00002Oooool2o`0000?ooooo0_l000001?oooooo
0000o`000?l0000@ooooo`?o0000:?ooool2o`0005;ooooo000Looooo`03o`000?oooooooooo04Wo
oooo0_l00002ooooo`?o00001?ooool4o`00017ooooo0_l00002ooooo`Co00000_ooool2o`000003
ooooool0003o000000Oooooo0_l00005ooooo`;o00005?ooool2o`0000;ooooo0_l00002ooooo`;o
00002oooool2o`0000Gooooo0_l0000=ooooo`;o000000Coooooo`000?l0003o00001_ooool2o`00
01;ooooo1?l0000Dooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0E?ooool6o`000004
ooooool0003o0000o`0000oooooo1?l00002ooooo`;o000000?oooooo`000?l000000oooool2o`00
01?ooooo0_l00008ooooo`Co00004oooool2o`0001Cooooo0ol00009ooooo`;o00002?ooool2o`00
00Sooooo1ol0000Aooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0Eoooool7o`0000_o
oooo0_l0000:ooooo`go00003_ooool2o`0000?ooooo0_l00003ooooo`;o00001Oooool2o`0000oo
oooo0_l0000Dooooo`;o00001?ooool2o`0000gooooo0ol00009ooooo`Go00002Oooool2o`00053o
oooo000Looooo`03o`000?oooooooooo05Oooooo1_l0000<ooooo`Co00001_ooool9o`000003oooo
ool0003o000000?o00000_ooool2o`0000oooooo0_l0000:ooooo`;o00003Oooool4o`0000Cooooo
0ol0000Booooo`?o00002_ooool2o`0000;ooooo0_l00002ooooo`;o00001Oooool2o`0000cooooo
0_l0001@ooooo`007?ooool00ol0003oooooooooo`16ooooo`;o000000?oooooo`000?l000000_l0
000Nooooo`;o00001Oooool9o`000003ooooool0003o000000Co00000_ooool2o`000003ooooool0
003o000002Oooooo0_l00006ooooo`?o00001_ooool3o`0000Wooooo0_l0000;ooooo`;o00001_oo
ool2o`0000;ooooo0_l00006ooooo`;o00001Oooool2o`0005;ooooo000Looooo`03o`000?oooooo
oooo04Kooooo0_l000000ooooooo0000o`000002o`00027ooooo5Ol00004ooooo`;o00001?ooool2
o`0000cooooo0_l0000Dooooo`;o000000?oooooo`000?l000000ol00008ooooo`?o00001?ooool3
o`0001Oooooo0_l00002ooooo`;o00001_ooool2o`0000Gooooo0_l00002ooooo`;o0000C_ooool0
01cooooo00?o0000ooooooooool0A?ooool2o`0000oooooo0_l0000Foooooa[o00001_ooool2o`00
00cooooo0_l0000Dooooo`;o000000?oooooo`000?l000001?l0000>ooooo`?o00003oooool2o`00
00Kooooo0_l0000Eooooo`;o00003_ooool2o`0003kooooo000Looooo`03o`000?oooooooooo03co
oooo0_l00006ooooo`;o00003oooool2o`00013ooooo0_l00004ooooo`;o00000_oooolFo`0000Co
oooo0_l00007ooooo`;o00006oooool5o`0000;ooooo0_l00002ooooo`;o00001oooool2o`0000Oo
oooo0_l0000:ooooo`;o00001_ooool2o`0000Sooooo0ol0000=ooooo`;o00002oooool2o`0003ko
oooo000Looooo`03o`000?oooooooooo03cooooo0_l00005ooooo`Go00003oooool2o`0000kooooo
0_l00007oooooa[o000000?oooooo`000?l000000oooool2o`0000;ooooo0_l00005ooooo`;o0000
2_ooool2o`0000Sooooo1Ol00003ooooo`Go00001oooool2o`0000Oooooo0_l00005ooooo`;o0000
1Oooool2o`0000?ooooo1?l00007ooooo`?o00003Oooool2o`0004_ooooo000Looooo`03o`000?oo
oooooooo04?ooooo1ol0000=ooooo`;o00005ooooolJo`0000;ooooo0_l00002ooooo`;o00000ooo
ool2o`0000Cooooo0_l00008ooooo`Co00002?ooool4o`0000;ooooo1Ol00009ooooo`;o00001?oo
ool2o`0000Sooooo0_l00005ooooo`?o00000_ooool4o`0000;ooooo0_l00009ooooo`;o0000EOoo
ool001cooooo0_l0000kooooo`;o00001oooool4o`000003ooooool0003o000002;ooooo7?l00004
ooooo`;o00001oooool2o`0000kooooo0_l00003ooooo`?o00001?ooool<o`0000Sooooo0_l00004
ooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000Kooooo0_l00003
ooooo`?o000000Coooooo`000?l0003o00002Oooool2o`0000;ooooo0ol0001@ooooo`007?ooool0
0ol0003oooooooooo`0jooooo`;o00001Oooool4o`0002Kooooo7_l00006ooooo`;o00001Oooool2
o`0000_ooooo0_l00005ooooo`?o00001?ooool<o`0000?ooooo0_l0000<ooooo`;o00000_ooool2
o`000003ooooool0003o000000_ooooo0_l000001?oooooo0000o`000?l00008ooooo`;o00001?oo
ool5o`0004kooooo000Looooo`03o`000?oooooooooo03Sooooo0_l00003ooooo`;o00000_ooool4
o`0000?ooooo0_l0000Qooooob?o000000?oooooo`000?l000001Oooool2o`0000?ooooo0_l00006
ooooo`;o00000oooool2o`0000;ooooo4_l00002ooooo`;o00003oooool2o`0000cooooo0_l00004
ooooo`;o00002Oooool2o`0000Oooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`0hoooo
o`;o00000oooool2o`0000Wooooo1?l0000Eooooo`;o00002OoooolRo`0000[ooooo0_l000000ooo
oooo0000o`000004ooooo`;o00001?oooolGo`0001;ooooo0ol0000<ooooo`;o00004Oooool2o`00
00Oooooo0_l0000;ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0>_ooool2o`0000Oo
oooo0_l00005ooooo`;o00005Oooool2o`0000[ooooo8Ol0000:ooooo`;o00001ooooolMo`0001;o
oooo0_l00004ooooo`;o00001_ooool2o`0000Oooooo0_l00009ooooo`;o00001oooool2o`0000_o
oooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0iooooo`?o00001?ooool2o`000003oooo
ool0003o000000;o00000_ooool2o`0002;ooooo1?l00002oooooa_o00001oooool2o`0000cooooo
7Ol0000Fooooo`;o00001Oooool5o`0000;ooooo1Ol0000Booooo`;o00003oooool2o`0003_ooooo
000Looooo`03o`000?oooooooooo03Wooooo0ol00004ooooo`Co000000Coooooo`000?l0003ooooo
0ol00004ooooo`;o00003?ooool2o`000003ooooool0003o000000Cooooo0_l00006ooooo`Co0000
00?oooooo`000?l000006Ol00007ooooo`;o00002?ooool2o`0000Cooooo7Ol0000Dooooo`;o0000
0_ooool5o`000005ooooool0003o0000o`000?ooool01?l0000Cooooo`;o00000oooool2o`0000Oo
oooo0_l000000ooooooo0000o`00000kooooo`007?ooool00ol0003oooooooooo`0Uooooo`;o0000
4oooool2o`0000;ooooo1_l00004ooooo`;o00000_ooool2o`000003ooooool0003o000000cooooo
0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000Oooooo7Ol00004ooooo`;o
00000_ooool2o`0000Wooooo0ol00002ooooo`Co000000?oooooo`000?l000004ol00002ooooo`;o
00002oooool2o`0000Oooooo0_l00002ooooo`Go00000_ooool2o`0000?ooooo0_l0000Cooooo`;o
00000oooool2o`0000Oooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0Uooooo`;o0000
5_ooool6o`000004ooooool0003o0000ooooo`;o00000oooool3o`0000gooooo0_l00003ooooo`Ko
00002?oooolMo`0000;ooooo1Ol000000ooooooo0000o`00000:ooooo`;o000000?oooooo`000?l0
00000ol000000ooooooo0000o`00000Co`0000;ooooo0_l0000;ooooo`;o000000?oooooo`000?l0
00001oooool2o`0000;ooooo0_l0000=ooooo`;o00003_ooool2o`0004_ooooo000Looooo`03o`00
0?oooooooooo03gooooo0_l00003ooooo`[o000000?oooooo`000?l000003Oooool2o`0000?ooooo
0_l000001?oooooo0000o`000?l00003ooooo`;o00000ooooolMo`0000;ooooo0_l000000ooooooo
0000o`00000@ooooo`;o00000ooooolFo`0001;ooooo0_l00004ooooo`;o000000?oooooo`000?l0
00002oooool2o`0000Cooooo0_l000000ooooooo0000o`00000:ooooo`?o00003oooool2o`0003[o
oooo000Looooo`03o`000?oooooooooo03?ooooo0_l00007ooooo`;o00001?ooool2o`0000;ooooo
0_l000001?oooooo0000o`000?l0000@ooooo`;o00001_ooool2o`0000Cooooo0_l00002oooooago
00000_ooool2o`0000?ooooo0_l0000=ooooo`;o00000_oooolJo`0000Gooooo0_l000000ooooooo
0000o`000002o`0000Wooooo1?l0000>ooooo`;o00001oooool2o`0000[ooooo1?l0000>ooooo`?o
0000>Oooool001cooooo00?o0000ooooooooool0<oooool2o`0000Oooooo1?l00002ooooo`;o0000
6?ooool2o`0000Oooooo0ol00004oooooago00001?ooool3o`0000;ooooo1_l00006ooooo`;o0000
00Coooooo`000?l0003ooooo6ol00005ooooo`Oo00001Oooool2o`0000;ooooo0ol0000Vooooo`;o
00003oooool2o`0003Wooooo000Looooo`03o`000?oooooooooo03cooooo1?l00002ooooo`;o0000
4oooool2o`0000;ooooo0_l00008ooooo`?o00001?ooool;o`000003ooooool0003o000000oo0000
1Oooool:o`0000Gooooo0ol00004ooooo`go00000oooool7o`000003ooooool0003o000000Sooooo
0_l00008ooooo`;o000000?oooooo`000?l000000_l0000:ooooo`;o00000oooool2o`0000Cooooo
0_l0000>ooooo`;o00001?ooool2o`0004Gooooo000Looooo`03o`000?oooooooooo03cooooo0_l0
00001?oooooo0000o`000?ooool3o`0001;ooooo0_l00002ooooo`;o00003ooooolLo`000004oooo
ool0003o0000o`0000;ooooo1?l0000;ooooo`;o00001Oooool3o`000003ooooool0003o000001Ko
00000_ooool4o`0000Wooooo2?l00008ooooo`Go00000_ooool2o`0000Cooooo0_l0000>ooooo`;o
00001?ooool2o`0004Gooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0_ooooo`;o00003_ooool2o`00
0004ooooool0003o0000o`0001Wooooo0_l0000;ooooo`ko000000?oooooo`000?l000001_l00000
0ooooooo0000o`000003o`000004ooooool0003o0000o`0000;ooooo0_l000000ooooooo0000o`00
000Aooooo`?o000000?oooooo`000?l000005_l00002ooooo`Co000000?oooooo`000?l000001_oo
ool2o`000003ooooool0003o000000_ooooo1Ol00007ooooo`;o000000?oooooo`000?l000007Ooo
ool2o`0003[ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0;oooool2o`0000Cooooo0_l0000Wooooo`;o0000
2oooool2o`000003ooooool0003o000000Co000000?oooooo`000?l000002ol00004ooooo`;o0000
00Coooooo`000?l0003o00001Oooool2o`00017ooooo7?l00006ooooo`?o00003?ooool2o`0000Oo
oooo1?l00009ooooo`;o000000?oooooo`000?l000002Oooool4o`00013ooooo0_l0000jooooo`00
00?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`Go00001_ooool00ol0003ooooo
ooooo`0eooooo`;o00002Oooool2o`0000Sooooo0_l0000QoooooaGo00001_ooool3o`0001Wooooo
7?l00003ooooo`;o000000?oooooo`000?l000003Oooool4o`0000Gooooo1?l0000<ooooo`;o0000
00?oooooo`000?l000001_ooool4o`0004cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oo
oooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`00043ooooo0_l00008ooooo`;o0000
4_ooool2o`0000gooooo0_l000001Ooooooo0000o`000?l0003ooooo00go00001oooool2o`0000Ko
oooo0_l0000EoooooaWo00000oooool2o`0000_ooooo0ol00004ooooo`;o00001Oooool4o`0000co
oooo1Ol00009ooooo`;o0000Boooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
2Oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo03[ooooo0_l0000Jooooo`;o
00001_ooool2o`0000Cooooo0_l00005ooooo`Co000000?oooooo`000?l000000oooool<o`0000oo
oooo0_l0000Booooo`;o000000?oooooo`000?l000005Ol00005ooooo`;o00002oooool3o`0000Ko
oooo0_l00003ooooo`;o000000?oooooo`000?l000003Oooool2o`0000Cooooo0_l00004ooooo`;o
00001_ooool2o`0004?ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo
00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0cooooo`;o00000_ooool2o`000003oooo
ool0003o000000Cooooo0_l00008ooooo`;o000000?oooooo`000?l000001oooool2o`0000;ooooo
0_l00008ooooo`;o00001Oooool2o`0000Wooooo2?l0000Pooooo`Co00000_ooool2o`000003oooo
ool0003o000001Co00001_ooool2o`0000;ooooo0_l0000:ooooo`;o00001?ooool2o`000003oooo
ool0003o000000;o000000Coooooo`000?l0003ooooo0_l0000@ooooo`;o00003?ooool3o`0000Go
oooo0_l0000kooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co0000
00Oooooo00?o0000ooooooooool0<oooool2o`0000;ooooo1?l00003ooooo`Co00001oooool3o`00
0003ooooool0003o000000_ooooo0_l00009ooooo`;o00000_ooool5o`0000Gooooo0_l00002oooo
o`Oo000000?oooooo`000?l000001oooool2o`0000gooooo0_l000000ooooooo0000o`000002oooo
o`Co00000_ooool2o`0000Cooooo0ol000000ooooooo0000o`000009o`000004ooooool0003o0000
o`0000Sooooo1?l0000:ooooo`Co00001Oooool4o`0000Cooooo0_l00002ooooo`;o00001Oooool4
o`0000?ooooo1?l00004ooooo`;o00001Oooool2o`0000Gooooo0_l0000kooooo`0000Koooooonk^
k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0=ooo
ool4o`0000?ooooo0_l00007ooooo`Go00006Oooool9o`0000Gooooo0_l00003ooooo`?o00001?oo
ool2o`0000?ooooo0_l00002ooooo`;o00003Oooool5o`0000oooooo0_l000000ooooooo0000o`00
0008o`0000gooooo1Ol0000;ooooo`;o00001_ooool2o`0000Wooooo0_l000000ooooooo0000o`00
0002ooooo`Co000000?oooooo`000?l000001?l00004ooooo`;o00001Oooool2o`0004;ooooo000L
ooooo`03o`000?oooooooooo03Gooooo1?l00008ooooo`;o00001?ooool5o`0000Oooooo0_l00002
ooooo`;o00003_ooool4o`0000Gooooo0_l00009ooooo`?o00001_ooool2o`0000Cooooo0_l00002
ooooo`;o00002Oooool2o`0001Gooooo1?l00004ooooo`;o00003?ooool4o`0000Gooooo0_l0000<
ooooo`;o00003?ooool2o`0000Oooooo0_l000000ooooooo0000o`000003ooooo`;o0000Boooool0
01cooooo00?o0000ooooooooool0=Oooool4o`0000Sooooo0_l0000@ooooo`;o00000_ooool2o`00
01Oooooo0_l00007ooooo`Go00003?ooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`00
01?ooooo1_l00006ooooo`;o00003Oooool2o`0000Kooooo1?l0000Tooooo`;o00000oooool2o`00
04_ooooo000Looooo`03o`000?oooooooooo03Oooooo0_l0000=ooooo`;o00006_ooool2o`0000Oo
oooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000006oooo
o`Co00000oooool2o`0000Sooooo0ol00002ooooo`;o00001_ooool2o`0000_ooooo1_l0000;oooo
o`;o00000oooool2o`0000?ooooo0_l00005ooooo`;o000000?oooooo`000?l000000oooool2o`00
00Gooooo0_l00007ooooo`?o00000oooool2o`0000?ooooo0_l0000;ooooo`;o0000BOooool001co
oooo00?o0000ooooooooool0=oooool2o`0000gooooo0_l0000?ooooo`;o00002Oooool2o`000004
ooooool0003o0000o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o0000
00Wooooo1?l00003ooooo`;o000000?oooooo`000?l000001Oooool2o`0000_ooooo0_l0000?oooo
o`;o00002oooool4o`000003ooooool0003o000000[ooooo0_l00006ooooo`;o00000oooool4o`00
00;ooooo1?l000000ooooooo0000o`000006o`0000?ooooo0_l00004ooooo`;o00001?ooool3o`00
04Wooooo000Looooo`03o`000?oooooooooo03?ooooo0_l0000?ooooo`;o00003?ooool2o`0000?o
oooo0_l0000<ooooo`Go00001Oooool2o`0000?ooooo1?l0000:ooooo`;o00001oooool2o`0000Ko
oooo0_l0000>ooooo`;o00001oooool4o`0000_ooooo0_l00002ooooo`;o00006_ooool2o`0000Co
oooo1?l00003ooooo`Ko00001oooool4o`000004ooooool0003o0000ooooo`;o00000_ooool2o`00
00?ooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00000_ooool2o`0000Co
oooo0_l00005ooooo`Ko000000?oooooo`000?l000002?ooool3o`0000cooooo0_l00003ooooo`;o
000000?oooooo`000?l000002_ooool6o`0000Sooooo0_l00007ooooo`;o00001_ooool2o`0000ko
oooo0_l00007ooooo`Co00002oooool4o`0000Wooooo0_l00002ooooo`Co000000?oooooo`000?l0
00005Oooool2o`000003ooooool0003o000000Ko00000_ooool4o`000003ooooool0003o000000Go
oooo0_l00003ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0;oooool2o`0000Oooooo
0ol00005ooooo`Co00000oooool3o`0000Oooooo0_l0000=ooooo`;o00000_ooool2o`0000?ooooo
0_l0000:ooooo`Go00004Oooool2o`0000Gooooo0ol0000Xooooo`;o00002Oooool2o`0000;ooooo
1?l000000ooooooo0000o`000004ooooo`Go00000_ooool2o`0000?ooooo0_l000000ooooooo0000
o`00000;o`0000Cooooo0_l000000ooooooo0000o`00000:ooooo`;o0000@Oooool001cooooo00?o
0000ooooooooool0<Oooool2o`0000Gooooo0ol0000;ooooo`Co000000?oooooo`000?l000005ooo
ool2o`0000?ooooo0_l00008ooooo`;o00003?ooool2o`000003ooooool0003o000000Gooooo0_l0
0004ooooo`Go00007Oooool2o`0000Gooooo0_l0000:ooooo`;o00000_ooool2o`0000;ooooo0_l0
0005ooooo`Oo00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000006o`0000;ooooo0ol0
0002ooooo`;o00000oooool2o`0000?ooooo0_l0000>ooooo`;o0000>?ooool001cooooo00?o0000
ooooooooool0<Oooool2o`0000Kooooo0_l00002ooooo`;o00001oooool7o`0002Kooooo1Ol00000
0ooooooo0000o`000004ooooo`Co000000?oooooo`000?l000001_ooool2o`0000;ooooo1_l00004
ooooo`;o00001Oooool2o`00013ooooo0_l00005ooooo`Co00002?ooool2o`0000;ooooo0ol00008
ooooo`Co00004_ooool2o`000004ooooool0003o0000ooooo`;o000000Coooooo`000?l0003o0000
0oooool2o`0000;ooooo0ol0000>ooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0;Ooo
ool2o`0000kooooo0_l00005ooooo`;o00000oooool2o`0002?ooooo0_l00004ooooo`Co000000?o
ooooo`000?l000001?ooool2o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`?o000000Co
ooooo`000?l0003o00001Oooool4o`0000?ooooo1?l0000Hooooo`?o00002oooool4o`0001_ooooo
0_l00004ooooo`;o00000oooool5o`0000Kooooo0_l00004ooooo`;o00001?ooool4o`0003_ooooo
000Looooo`03o`000?oooooooooo02gooooo0_l00003ooooo`;o00001Oooool2o`0000Kooooo0_l0
00000ooooooo0000o`000008ooooo`;o00007_ooool2o`0000;ooooo2Ol0000;ooooo`?o00000ooo
ool8o`0000Cooooo2Ol000000ooooooo0000o`00000<ooooo`;o00000_ooool5o`0000;ooooo1?l0
0007ooooo`;o000000?oooooo`000?l000000_l00009ooooo`;o00000_ooool2o`0000cooooo1?l0
0002ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo0_l00008ooooo`;o00001?oo
ool4o`0003_ooooo000Looooo`;o0000<oooool2o`0000;ooooo0_l000000ooooooo0000o`000005
ooooo`?o00002?ooool2o`000003ooooool0003o0000023ooooo2Ol000000ooooooo0000o`000004
ooooo`;o00001?ooool2o`000003ooooool0003o000000Ko000000?oooooo`000?l000000_l00004
ooooo`Go000000?oooooo`000?l000000_l000000ooooooo0000o`000002ooooo`;o000000?ooooo
o`000?l000000_ooool2o`0000;ooooo1ol00002ooooo`;o00001oooool2o`000003ooooool0003o
000000_ooooo0_l00002ooooo`;o00002_ooool2o`0000;ooooo0_l00007ooooo`Go00000_ooool2
o`0000_ooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0fooooo`?o00001oooool4o`00
00Oooooo0ol0000Gooooo`;o00002Oooool2o`0000;ooooo0ol00003ooooo`Co00000_ooool2o`00
00;ooooo1?l000000ooooooo0000o`000002o`000003ooooool0003o000000?ooooo0ol00004oooo
o`Go000000?oooooo`000?l000000oooool2o`0000;ooooo0_l000000ooooooo0000o`00000;oooo
o`;o00006oooool2o`0000;ooooo0_l0000:ooooo`Oo00002?ooool2o`00013ooooo0_l00003oooo
o`;o0000>oooool001cooooo00?o0000ooooooooool0=oooool2o`0000Wooooo0_l00004ooooo`;o
00000_ooool2o`0001Oooooo0_l00006ooooo`;o00000oooool4o`0000Cooooo1?l00004ooooo`Co
00001Oooool2o`000003ooooool0003o000000Kooooo0_l00002ooooo`;o000000?oooooo`000?l0
00005Oooool2o`0001cooooo0_l00006ooooo`;o00002oooool6o`0000?ooooo0_l00002ooooo`?o
00001_ooool2o`0000gooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0gooooo`;o0000
00?oooooo`000?l000000ol00005ooooo`;o00000_ooool2o`0000Cooooo0_l0000:ooooo`;o0000
4Oooool2o`0000?ooooo1_l00002ooooo`Co00001?ooool2o`000004ooooool0003o0000ooooo`;o
00000_ooool4o`0000;ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00006?ooool2o`00
01_ooooo0ol00007ooooo`;o00001_ooool2o`0000Cooooo0_l00005ooooo`;o00000_ooool2o`00
00Oooooo1?l0000;ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0=Oooool4o`000003
ooooool0003o000000?o00001Oooool4o`0000Kooooo0_l0000:ooooo`;o00000oooool2o`0000Oo
oooo0_l00002ooooo`;o00002?ooool2o`0000;ooooo1ol000001?oooooo0000o`000?ooool2o`00
0003ooooool0003o000000;ooooo2?l00004ooooo`Co000000Coooooo`000?l0003o00001?ooool2
o`00027ooooo1Ol00005ooooo`;o00002?ooool2o`0000Gooooo0ol00004ooooo`Co00000oooool2
o`0000gooooo0_l00002ooooo`;o00001oooool2o`0003_ooooo000Looooo`03o`000?oooooooooo
02gooooo0_l00006ooooo`Co00003Oooool2o`0000;ooooo0_l0000=ooooo`;o00001?ooool2o`00
00Oooooo0_l00002ooooo`;o00002oooool2o`0000;ooooo1?l000001?oooooo0000o`000?l0000;
ooooo`;o00000oooool2o`000003ooooool0003o000000?ooooo0ol00004ooooo`;o000000?ooooo
o`000?l000004_ooool2o`0000Gooooo0_l00003ooooo`Go00004?ooool2o`0000Cooooo0ol00006
ooooo`;o00000oooool2o`000003ooooool0003o000000Cooooo0_l00008ooooo`;o00003?ooool2
o`0003Kooooo000Looooo`03o`000?oooooooooo02gooooo0_l00004ooooo`;o00005Oooool2o`00
00gooooo0_l00004ooooo`;o00001Oooool2o`0000?ooooo0_l00003ooooo`;o00000_ooool2o`00
00?ooooo0_l00007ooooo`?o00004?ooool2o`0000Kooooo0ol00007ooooo`;o00002_ooool2o`00
00Kooooo0_l00005ooooo`;o00000oooool2o`000003ooooool0003o000000Cooooo0_l00003oooo
o`;o00001Oooool3o`0000Cooooo0_l0000;ooooo`;o000000?oooooo`000?l000000_ooool6o`00
01Cooooo0_l0000fooooo`007?ooool00ol0003oooooooooo`0cooooo`;o000000?oooooo`000?l0
00001_ooool2o`0002Kooooo0_l00003ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o
00002?ooool4o`0001Oooooo0_l0000Cooooo`;o00004_ooool2o`000004ooooool0003o0000oooo
o`;o000000?oooooo`000?l000000oooool2o`0000Kooooo0_l0000<ooooo`;o00002_ooool2o`00
00;ooooo0_l00009ooooo`;o00000oooool2o`0003cooooo000Looooo`03o`000?oooooooooo02ko
oooo0_l00006ooooo`;o00001_ooool6o`0001Gooooo0_l000000ooooooo0000o`000003ooooo`;o
00003?ooool2o`00017ooooo0_l000000ooooooo0000o`00000Gooooo`;o00000_ooool2o`0000[o
oooo0_l0000Eooooo`Co00000oooool3o`0000?ooooo0_l00008ooooo`;o00003Oooool3o`0001So
oooo0ol00002ooooo`;o0000??ooool001cooooo00?o0000ooooooooool0:Oooool2o`0000?ooooo
0_l0000@ooooo`Co00005?ooool3o`000003ooooool0003o000000?ooooo0_l0000<ooooo`;o0000
4Oooool2o`0000cooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool2o`0000Gooooo
0_l0000:ooooo`;o00000oooool2o`0000[ooooo0_l00004ooooo`Co00000oooool2o`0000Cooooo
0_l00008ooooo`;o00003Oooool3o`0001Wooooo0_l00010ooooo`007?ooool00ol0003ooooooooo
o`0Yooooo`;o00001Oooool2o`000003ooooool0003o000000;ooooo0_l0000Oooooo`;o00003_oo
ool2o`0000Wooooo0_l0000Eooooo`;o00001?ooool2o`000003ooooool0003o000000;ooooo0_l0
0002ooooo`;o00002oooool2o`0000Cooooo0_l00003ooooo`;o00002_ooool2o`0000Gooooo0_l0
0003ooooo`;o00001Oooool5o`00013ooooo0_l0000<ooooo`Co00002_ooool2o`0000Oooooo0_l0
000kooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o000000?oooooo`000?l000000_ooool3
o`0000kooooo1?l00006ooooo`;o000000?oooooo`000?l000000oooool2o`0000cooooo0_l00000
0ooooooo0000o`000003o`0000;ooooo0ol00006ooooo`?o00002_ooool4o`0001Gooooo1Ol00002
ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00000_ooool2o`0000kooooo0_l0
0003ooooo`;o00001Oooool8o`0000gooooo0ol00003ooooo`;o00001_ooool5o`0000Wooooo0_l0
0007ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0:oooool2o`0000;ooooo0_l00000
0ooooooo0000o`000004ooooo`;o00003_ooool4o`0000Kooooo0_l000000ooooooo0000o`000003
ooooo`;o00003oooool5o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`?o00001oooool2
o`000003ooooool0003o000000Cooooo0_l00007ooooo`;o00001Oooool2o`000003ooooool0003o
000000?o00001Oooool2o`0000Gooooo0_l00002ooooo`;o00001_ooool2o`00017ooooo2_l00002
ooooo`Go00000_ooool2o`000004ooooool0003o0000o`0000?ooooo0_l00003ooooo`;o00000ooo
ool3o`0001Sooooo0_l0000eooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o00000_ooool5
o`0000Sooooo0_l0000Gooooo`;o00004_ooool5o`000004ooooool0003o0000o`0000?ooooo0_l0
0002ooooo`Co00002?ooool3o`0000Kooooo0_l00007ooooo`;o00001Oooool2o`0000Oooooo0_l0
000<ooooo`;o00000oooool2o`0000;ooooo0_l000000ooooooo0000o`00000>ooooo`_o000000?o
ooooo`000?l000000ol000001?oooooo0000o`000?l00006ooooo`;o00001?ooool2o`0000?ooooo
0ol0000:ooooo`;o00003?ooool2o`0003Gooooo000Looooo`03o`000?oooooooooo033ooooo1?l0
0003ooooo`;o00000oooool2o`0001Oooooo1?l00008ooooo`;o00001_ooool:o`0000Kooooo1?l0
0005ooooo`;o000000?oooooo`000?l000000ol0000;ooooo`;o00000oooool2o`0000_ooooo0_l0
000<ooooo`;o00000oooool3o`000004ooooool0003o0000ooooo`;o00002?ooool4o`0000;ooooo
1ol00002ooooo`;o000000?oooooo`000?l000000ol000001?oooooo0000o`000?l00002ooooo`;o
00000_ooool2o`0000Sooooo1?l00007ooooo`;o000000?oooooo`000?l00000@oooool001cooooo
00?o0000ooooooooool09oooool2o`0000[ooooo0ol000000ooooooo0000o`000005ooooo`;o0000
00?oooooo`000?l000002Oooool2o`0000Cooooo1?l000000ooooooo0000o`000008ooooo`Go0000
00?oooooo`000?l000003Ol0000<ooooo`;o00001?ooool2o`0000_ooooo0_l00003ooooo`;o0000
00?oooooo`000?l000000ol00003ooooo`;o00001_ooool2o`0000[ooooo1ol0000:ooooo`Go0000
00?oooooo`000?l000002Ol000000ooooooo0000o`000008o`0000;ooooo1?l00002ooooo`;o0000
1_ooool2o`0000Wooooo0_l00016ooooo`007?ooool2o`0002Sooooo0_l0000:ooooo`Co00001ooo
ool2o`000003ooooool0003o000000Wooooo0_l00003ooooo`Go00002?ooool2o`0000?ooooo4ol0
0009ooooo`;o00003_ooool2o`0000cooooo1Ol000000ooooooo0000o`000002o`0000Kooooo0_l0
0003ooooo`;o00001Oooool3o`000003ooooool0003o000000Kooooo0_l00003ooooo`?o00000_oo
oolGo`0000Cooooo0_l00002ooooo`;o00003oooool2o`0004Sooooo000Looooo`03o`000?oooooo
oooo02_ooooo0_l00003ooooo`;o00000oooool2o`0001Oooooo0_l000000ooooooo0000o`00000;
ooooo`;o00000ooooolCo`000003ooooool0003o000000Kooooo0ol0000=ooooo`;o00004_ooool2
o`0000_ooooo1?l00005ooooo`Co00002?ooool2o`0000Cooooo0_l00002oooooaWo00001?ooool4
o`0000Sooooo0_l00005ooooo`Co0000A_ooool001cooooo00?o0000ooooooooool0:oooool2o`00
00?ooooo0_l0000Hooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`000003oooo
o`;o00001OoooolCo`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000008oooo
o`;o00000oooool2o`0000Sooooo0_l0000Eooooo`;o00001?ooool7o`0000Cooooo0_l000000ooo
oooo0000o`000006ooooo`;o00000_oooolHo`0000?ooooo1ol00005ooooo`?o00001_ooool3o`00
00Oooooo0ol0000>ooooo`;o0000;?ooool001cooooo00?o0000ooooooooool0B_ooool4o`0000Ko
oooo0_l000000ooooooo0000o`000003ooooo`;o00001OoooolCo`0000Cooooo1Ol00004ooooo`;o
00001Oooool2o`0000?ooooo0_l00008ooooo`;o00002?ooool2o`0000Cooooo0_l00005ooooo`;o
00001?ooool3o`0000Sooooo0_l000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l0
00006Ol000000ooooooo0000o`000003ooooo`;o00001Oooool4o`0000Gooooo0_l00008ooooo`?o
00003_ooool2o`0002cooooo000Looooo`03o`000?oooooooooo02Oooooo0ol0000;ooooo`Co0000
4oooool2o`0001Gooooo4ol00004ooooo`Co000000?oooooo`000?l000000_ooool2o`0001gooooo
1?l00003ooooo`Co00006?ooool2o`0000Kooooo2_l000000ooooooo0000o`00000Bo`0000_ooooo
1?l0000@ooooo`;o0000??ooool001cooooo00?o0000ooooooooool09oooool3o`0000_ooooo1Ol0
0006ooooo`;o00001_ooool2o`0001Oooooo5ol00007ooooo`Co00002?ooool3o`0001Cooooo1?l0
0002ooooo`Go00003oooool2o`0000Kooooo1?l000001?oooooo0000o`000?ooool;o`000003oooo
ool0003o000000?o000000?oooooo`000?l000003Ol00002ooooo`;o00003?ooool4o`0004Sooooo
000Looooo`03o`000?oooooooooo02Wooooo0ol0000<ooooo`;o00001?ooool6o`0000?ooooo1?l0
000FoooooaWo00000oooool2o`0000;ooooo1Ol00005ooooo`?o00005_ooool2o`0000;ooooo1Ol0
000?ooooo`;o00001_ooool4o`000003ooooool0003o000001go00000_ooool3o`0000;ooooo0_l0
0008ooooo`;o00000_ooool4o`0004Sooooo000Looooo`03o`000?oooooooooo02Sooooo1?l0000:
ooooo`;o000000?oooooo`000?l000000oooool2o`0000;ooooo0_l00003ooooo`Co00003oooool2
o`0000Gooooo6Ol00003ooooo`?o00000_ooool4o`0001kooooo0_l00004ooooo`?o00000oooool2
o`0000;ooooo1?l00007ooooo`;o00001ooooolUo`0000Kooooo1?l00002ooooo`;o00003_ooool2
o`0000?ooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`0Xooooo`;o00002Oooool2o`00
0004ooooool0003o0000ooooo`;o00004Oooool4o`0000[ooooo1?l00003oooooa[o00000oooool2
o`0000Oooooo0_l0000Sooooo`;o00000_ooool2o`0000;ooooo1_l00005ooooo`;o00001oooool2
o`0000;ooooo8Ol00003ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o00001?ooool2
o`0000Kooooo0_l00003ooooo`;o0000>Oooool001cooooo00?o0000ooooooooool0;Oooool2o`00
00Cooooo0_l00008ooooo`;o00003Oooool5o`0000Cooooo0_l00005ooooo`;o00000ooooolFo`00
00;ooooo0_l0000<ooooo`;o00007_ooool2o`0000?ooooo0_l0000:ooooo`;o00003_ooool2o`00
00;ooooo4ol000000ooooooo0000o`000007o`0000;ooooo0_l00003ooooo`;o00001_ooool2o`00
0003ooooool0003o000000;o00000_ooool2o`0004Kooooo000Looooo`03o`000?oooooooooo02[o
oooo0_l000001?oooooo0000o`000?ooool5o`0000;ooooo0_l00004ooooo`?o00002?ooool2o`00
00Gooooo0_l00004ooooo`;o00002?oooolGo`0000Cooooo0_l00003ooooo`;o00000_ooool2o`00
02;ooooo0_l00003ooooo`;o00003oooool2o`0000Wooooo0_l00002oooooako00003_ooool2o`00
0003ooooool0003o000000;o00002Oooool2o`0000Sooooo0_l0000eooooo`007?ooool00ol0003o
ooooooooo`0Zooooo`;o00001?ooool5o`0000;ooooo0_l00005ooooo`;o00002?ooool2o`0001Go
oooo5?l000001?oooooo0000o`000?l00003ooooo`;o00000oooool2o`0000;ooooo0_l00002oooo
o`;o00004oooool2o`0001Kooooo0_l00007ooooo`;o00002Oooool2o`0000;ooooo7_l000001?oo
oooo0000o`000?ooool4o`0000Gooooo0_l0000?ooooo`;o00002?ooool2o`0003Gooooo000Loooo
o`03o`000?oooooooooo033ooooo0_l00004ooooo`;o00001_ooool2o`000003ooooool0003o0000
00;ooooo0_l00008ooooo`;o00001_ooool2o`0000Kooooo6?l0000@ooooo`;o00004oooool2o`00
01Kooooo0_l0000>ooooo`;o00000_ooool2o`0000;ooooo7_l000001?oooooo0000o`000?ooool4
o`000005ooooool0003o0000o`000?ooool00_l0001@ooooo`007?ooool00ol0003oooooooooo`0^
ooooo`;o00001_ooool2o`0000Wooooo0_l00002ooooo`;o00002?ooool2o`000003ooooool0003o
000000?ooooo0_l00002ooooo`?o000000Coooooo`000?l0003ooooo5Ol0000hooooo`;o00003ooo
ool2o`0000;ooooo0_l000000ooooooo0000o`00000Qo`0000Gooooo0ol000000ooooooo0000o`00
0002o`0000[ooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00004Oooool2
o`0000?ooooo0_l000000ooooooo0000o`000007ooooo`;o00001oooool3o`000003ooooool0003o
000000;ooooo5Ol0000Looooo`;o00006Oooool2o`0000?ooooo0_l0000:ooooo`;o000000?ooooo
o`000?l000000_oooolHo`000003ooooool0003o000000Co000000Coooooo`000?l0003o00001Ooo
ool2o`0000?ooooo0ol00002ooooo`;o00000_ooool2o`0000;ooooo0_l00009ooooo`;o0000>ooo
ool001cooooo00?o0000ooooooooool0<Oooool2o`0000Wooooo0_l00002ooooo`;o00001?ooool2
o`000003ooooool0003o000000?ooooo0ol00005ooooo`;o00000oooool3o`000005ooooool0003o
0000o`000?ooool00_l000000ooooooo0000o`00000=o`000004ooooool0003o0000ooooo`;o0000
3_ooool2o`0000Wooooo1?l0000Looooo`Co00002oooool2o`0000Gooooo8_l00007ooooo`;o0000
1?ooool2o`000004ooooool0003o0000o`0000gooooo0_l0000kooooo`007?ooool2o`0002Wooooo
0_l00007ooooo`;o00002Oooool2o`0000;ooooo0_l0000<ooooo`?o00001Oooool2o`0000?ooooo
1?l000000ooooooo0000o`000002ooooo`;o00000_ooool;o`0000Kooooo0ol0000=ooooo`;o0000
00?oooooo`000?l000002?ooool2o`0001;ooooo0_l00008ooooo`Co00004_ooool2o`000003oooo
ool0003o000001Go000000Goooooo`000?l0003o0000ooooo`03o`0000Oooooo1?l00005ooooo`;o
0000Boooool001cooooo00?o0000ooooooooool0:?ooool2o`0000;ooooo0ol0000@ooooo`;o0000
1?ooool2o`0000;ooooo0_l00002ooooo`?o000000?oooooo`000?l000000oooool2o`0000;ooooo
0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000_ooool;o`0000Oooooo
0_l0000@ooooo`?o00000oooool2o`0000kooooo0_l00006ooooo`;o00002?ooool2o`0001?ooooo
0ol000000ooooooo0000o`00000Go`0000?ooooo1?l00008ooooo`?o0000DOooool001cooooo00?o
0000ooooooooool0;?ooool3o`00013ooooo0_l00004ooooo`;o00000_ooool2o`0000;ooooo0_l0
0002ooooo`;o00001oooool4o`0000?ooooo0_l00007ooooo`;o00001_ooool2o`0001Sooooo0ol0
0003ooooo`;o000000?oooooo`000?l000001_ooool2o`0000?ooooo0_l000000ooooooo0000o`00
0005ooooo`Co00001?ooool2o`0000;ooooo0_l00008ooooo`;o00001OoooolHo`000003ooooool0
003o000000Co000000?oooooo`000?l000000_l000000ooooooo0000o`000006ooooo`;o000000Co
ooooo`000?l0003o00003?ooool2o`0003oooooo000Looooo`03o`000?oooooooooo033ooooo0_l0
000Looooo`;o00001oooool3o`0000;ooooo0_l0000<ooooo`;o00001_ooool2o`0001oooooo1_l0
00001?oooooo0000o`000?ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l00000
0_ooool2o`000003ooooool0003o000000;o00002?ooool2o`0000Sooooo0_l00005ooooo`Co0000
00?oooooo`000?l000004?l00002ooooo`Ko000000?oooooo`000?l000000oooool2o`0000;ooooo
0_l00004ooooo`Co00003?ooool2o`0003oooooo000Looooo`03o`000?oooooooooo033ooooo0_l0
000Looooo`;o00001oooool3o`0000?ooooo0_l00009ooooo`Co00009oooool2o`0000;ooooo0_l0
00001?oooooo0000o`000?l00003ooooo`Co00001Oooool2o`0001kooooo0_l00004ooooo`;o0000
0_oooolAo`0000kooooo0_l00004ooooo`;o0000Coooool001cooooo00?o0000ooooooooool0:Ooo
ool2o`0003;ooooo0_l00006ooooo`;o000000?oooooo`000?l000000_l0000@ooooo`;o00002_oo
ool2o`00017ooooo1_l00008ooooo`?o000000Coooooo`000?l0003o00001Oooool2o`0001Gooooo
0_l000001Ooooooo0000o`000?l0003ooooo00oo00000_ooool2o`000003ooooool0003o000000Co
oooo0_l00005ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0:Oooool2o`0000Gooooo
0_l0000/ooooo`Co00000oooool2o`0000cooooo0_l00002ooooo`;o00000_ooool3o`0000;ooooo
1?l00004ooooo`;o00004_ooool6o`0000Sooooo1_l00005ooooo`;o00000_ooool3o`000003oooo
ool0003o000000Cooooo0_l00003ooooo`;o00000_ooool2o`000005ooooool0003o0000o`000?oo
ool03?l000000ooooooo0000o`000004o`000003ooooool0003o000000Cooooo0_l00005ooooo`Co
00003_ooool2o`0000cooooo0_l0000cooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o0000
0_ooool2o`0001?ooooo0_l00002ooooo`;o000000?oooooo`000?l000003?ooool4o`00017ooooo
0ol000000ooooooo0000o`000004o`0000?ooooo1?l00008ooooo`;o00002oooool6o`000005oooo
ool0003o0000o`000?ooool01?l00004ooooo`;o00001?ooool2o`0000Gooooo0ol000000ooooooo
0000o`000004ooooo`;o00000oooool2o`000003ooooool0003o000000Cooooo2Ol000000ooooooo
0000o`000007o`0000?ooooo0_l00004ooooo`;o00000oooool2o`0000;ooooo0_l0000>ooooo`;o
00002_ooool4o`0003?ooooo000Looooo`03o`000?oooooooooo02gooooo0_l00005ooooo`;o0000
2?ooool2o`0000Kooooo0_l000000ooooooo0000o`000002ooooo`;o000000Coooooo`000?l0003o
oooo0_l00002ooooo`;o00001_ooool2o`0000[ooooo0_l00002ooooo`;o00000oooool2o`000003
ooooool0003o000000;o00002_ooool2o`0000Gooooo0_l00003ooooo`Co000000?oooooo`000?l0
00001_l00003ooooo`;o000000?oooooo`000?l000000_l00003ooooo`Go000000Coooooo`000?l0
003o00004oooool6o`0000Cooooo0_l00002ooooo`Go000000?oooooo`000?l000000ol000000ooo
oooo0000o`000006o`0000Wooooo0_l0000Hooooo`;o00001?ooool3o`0003Cooooo000Looooo`03
o`000?oooooooooo02Sooooo0_l00003ooooo`?o000000?oooooo`000?l000002oooool2o`0000Ko
oooo0_l0000;ooooo`;o000000?oooooo`000?l000000ol0000@ooooo`;o00000_ooool2o`0000Ko
oooo0_l0000<ooooo`;o00002Oooool5o`000003ooooool0003o000000Co00001_ooool7o`0000;o
oooo1Ol000000ooooooo0000o`000002ooooo`?o00002oooool2o`0000;ooooo1?l00006ooooo`Ko
00001?ooool3o`0000?ooooo1ol0000Oooooo`;o00000oooool2o`0000Cooooo1?l0000cooooo`00
7?ooool00ol0003oooooooooo`0Xooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`;o
00002?ooool2o`0000Sooooo0_l00003ooooo`;o00001Oooool7o`0000Gooooo1Ol0000?ooooo`;o
00003?ooool2o`000003ooooool0003o000000Wooooo2?l000001?oooooo0000o`000?l00005oooo
o`ko00000_ooool3o`000004ooooool0003o0000o`0000;ooooo0_l00002ooooo`;o00000oooool2
o`0000?ooooo0_l00007ooooo`Wo000000Coooooo`000?l0003o00001Oooool2o`0002;ooooo0_l0
0009ooooo`Co0000<oooool001cooooo00?o0000ooooooooool0:Oooool2o`0000?ooooo0_l00004
ooooo`;o00002?ooool2o`0000Sooooo0_l00003ooooo`;o00001Oooool2o`000004ooooool0003o
0000o`0000Kooooo1Ol00006ooooo`;o00001oooool2o`0000Wooooo0_l000000ooooooo0000o`00
0002o`0000_ooooo1ol00004ooooo`;o00000oooool3o`0000Cooooo1Ol00005ooooo`Ko00000_oo
ool2o`0000;ooooo0_l00008ooooo`;o00003?ooool4o`0000;ooooo0_l000000ooooooo0000o`00
0002ooooo`;o0000I?ooool001cooooo00?o0000ooooooooool0:Oooool2o`0000?ooooo0_l00003
ooooo`;o00005?ooool2o`0000gooooo0_l0000Aooooo`;o00001Oooool3o`0000[ooooo0_l00003
ooooo`;o00001Oooool2o`0000?ooooo2_l000000ooooooo0000o`000003o`000003ooooool0003o
000000?o000000Goooooo`000?l0003o0000ooooo`04o`0000Gooooo1?l000000ooooooo0000o`00
000=ooooo`;o00004_ooool2o`000003ooooool0003o000000Cooooo0_l00006ooooo`;o0000F_oo
ool001cooooo00?o0000ooooooooool0:Oooool2o`0000Sooooo0_l0000?ooooo`;o00000oooool5
o`0000Gooooo1?l0000Jooooo`Co00001Oooool2o`0000kooooo1?l00002oooooaKo000000?ooooo
o`000?l000001_l00005ooooo`;o00000oooool2o`0000[ooooo0_l0000Dooooo`;o00002?ooool2
o`0000Kooooo0_l0001Jooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?oo
ool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0:Oooool2o`0000_ooooo
0ol000000ooooooo0000o`000008ooooo`;o00001Oooool3o`0000Gooooo1?l0000Jooooo`;o0000
0_ooool3o`0000;ooooo0_l0000>ooooo`Go000000?oooooo`000?l000001Ol00002ooooo`?o0000
00?oooooo`000?l000001ol00003ooooo`?o00003?ooool2o`0000_ooooo0_l00008ooooo`;o0000
0_ooool2o`0000Cooooo1?l00006ooooo`;o00005_ooool2o`0004cooooo00001_ooooooMgMgoiRH
V?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0
003oooooooooo`0fooooo`?o000000?oooooo`000?l000001_ooool2o`0000Cooooo1Ol0000Koooo
o`;o00001oooool2o`0000;ooooo0ol00007ooooo`;o000000?oooooo`000?l000002?ooool4o`00
00;ooooo1Ol000000ooooooo0000o`00000Eo`000003ooooool0003o000000?ooooo0_l000000ooo
oooo0000o`000002ooooo`;o00004Oooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool4
o`0000;ooooo0_l00002ooooo`;o00000oooool2o`00017ooooo0_l0001<ooooo`0000?ooooooa0@
4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`0eooooo`?o00002_ooool2o`0000Cooooo1?l00004ooooo`;o00005_ooool2
o`0000Sooooo0ol000000ooooooo0000o`000002o`0000Gooooo0_l000000ooooooo0000o`000005
ooooo`;o00000oooool3o`000003ooooool0003o000001oo00000_ooool2o`0000Gooooo0ol00004
ooooo`;o00004Oooool2o`0000Oooooo0_l00002ooooo`;o00000oooool2o`0000Gooooo0_l00000
0ooooooo0000o`000006ooooo`;o0000COooool00003ooooool0003ooooo00;ooooo00?o0000oooo
ooooool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0000^ooooo`;o00001Oooool5
o`0000Sooooo0_l00004ooooo`?o00001Oooool2o`0000oooooo0_l00002ooooo`;o000000?ooooo
o`000?l000002?ooool3o`000003ooooool0003o000000;o00001oooool2o`0000Kooooo1?l00000
1?oooooo0000o`000?l00002oooooa_o000000?oooooo`000?l000001?l00005ooooo`;o000000?o
ooooo`000?l000001?ooool2o`0001Cooooo0_l00008ooooo`;o00002Oooool3o`000003ooooool0
003o000000Kooooo0_l0001=ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09
ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0^ooooo`;o00001_oo
ool4o`000003ooooool0003o000000Cooooo0ol00004ooooo`?o00001Oooool2o`0000cooooo0_l0
00001?oooooo0000o`000?ooool3o`0001[ooooo0_l00005ooooo`;o000000Coooooo`000?l0003o
oooo3ol000000ooooooo0000o`00000>o`000003ooooool0003o000000Co00000_ooool2o`000004
ooooool0003o0000o`0000Wooooo1_l00006ooooo`;o00000oooool4o`0000Kooooo1?l000000ooo
oooo0000o`000006ooooo`;o0000FOooool00003ooooool@413ooooo00;ooooo00?o410@oooooooo
ool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo02[ooooo0_l0000:ooooo`;o
00000oooool2o`0000;ooooo1?l00007ooooo`;o00001?ooool2o`0000cooooo2?l00004ooooo`?o
00006oooool2o`000004ooooool0003o0000ooooob7o00000_ooool2o`000003ooooool0003o0000
00?o000000Coooooo`000?l0003o00002Oooool6o`0000Kooooo0_l000000ooooooo0000o`000002
o`0000Sooooo0_l00003ooooo`;o00001_ooool2o`0005Wooooo00001_ooooooMgMgoiRHV?oooooo
V9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0Zooooo`;o00002?oo
ool3o`0000Sooooo0_l00003ooooo`;o00001?ooool2o`0001?ooooo0_l000001?oooooo0000o`00
0?l00005ooooo`?o00001_ooool2o`000003ooooool0003o000000oooooo0_l00003ooooo`Ko0000
0_oooolOo`000003ooooool0003o000000Co00000_ooool2o`0001Oooooo0_l00006ooooo`;o0000
2Oooool2o`0000Cooooo0_l00005ooooo`;o0000D_ooool00006ooooooo^k^ko<S8bo`000?lb<S;o
k^k^3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo03Cooooo0ol00007oooo
o`;o00001?ooool2o`0001gooooo0_l00004ooooo`Go00000_ooool2o`000004ooooool0003o0000
ooooo`;o00003oooool;o`000003ooooool0003o000001ko000000?oooooo`000?l000000_ooool2
o`0000;ooooo0_l0000Oooooo`;o00002Oooool2o`0000_ooooo0_l00004ooooo`?o0000Boooool0
01cooooo00?o0000ooooooooool0=_ooool2o`0000Kooooo0_l0000Booooo`;o00002_ooool2o`00
00Wooooo1Ol00002ooooo`;o00000_ooool2o`0000;ooooo0_l0000?ooooo`?o000000Coooooo`00
0?l0003ooooo0_l000000ooooooo0000o`00000Oo`0000Wooooo0_l0000:ooooo`;o00002oooool2
o`0000Wooooo0_l0000@ooooo`;o00001_ooool4o`0004[ooooo000Looooo`03o`000?oooooooooo
03Kooooo0_l00005ooooo`;o00004oooool3o`000003ooooool0003o000000Kooooo1?l00002oooo
o`;o00001Oooool5o`0000Cooooo0_l00002ooooo`;o00002?ooool2o`000003ooooool0003o0000
00?o000000?oooooo`000?l00000:?l00005ooooo`Go00000_ooool2o`0000Kooooo0_l000001?oo
oooo0000o`000?ooool2o`0000Gooooo0_l00005ooooo`;o00000_ooool2o`0000[ooooo0_l00004
ooooo`;o00002?ooool2o`0000cooooo0_l0000looooo`007?ooool00ol0003oooooooooo`0moooo
o`;o00003Oooool3o`0000Cooooo0_l000000ooooooo0000o`000008ooooo`;o00000_ooool2o`00
0003ooooool0003o000000Gooooo1?l00006ooooo`;o00002?ooool2o`000003ooooool0003o0000
00?o000000?oooooo`000?l000008Ol000001?oooooo0000o`000?ooool3o`0000Gooooo0ol00004
ooooo`;o00002Oooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000001_oo
ool2o`0000kooooo0_l0000>ooooo`;o00003?ooool2o`0003cooooo000Looooo`03o`000?oooooo
oooo03Gooooo0_l0000Eooooo`?o00002Oooool2o`0000Wooooo0_l00002ooooo`;o00001Oooool4
o`0000Kooooo0_l00003ooooo`?o00002_ooool2o`000003ooooool0003o000001oo00001?ooool2
o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`Co00000oooool2o`0000Gooooo0_l00003
ooooo`?o000000?oooooo`000?l00000>?ooool2o`0003Sooooo000Looooo`03o`000?oooooooooo
03Gooooo0_l0000Dooooo`;o00002oooool3o`0000Kooooo1?l00009ooooo`;o00003Oooool3o`00
00Cooooo0_l00004ooooo`;o00000_oooolPo`000003ooooool0003o000000Co00000_ooool2o`00
00Gooooo1?l000000ooooooo0000o`000002o`000003ooooool0003o000000;o00001Oooool2o`00
00Oooooo0_l0000;ooooo`;o00002Oooool2o`0000Sooooo0_l0000Aooooo`;o0000>?ooool001co
oooo00?o0000ooooooooool0A?ooool2o`0000Gooooo0_l0000<ooooo`?o00001Oooool4o`0001Go
oooo0_l00002ooooo`;o00001?ooool4o`0000Cooooo0_l000000ooooooo0000o`00000To`0000;o
oooo0_l00009ooooo`_o00000_ooool2o`0000Kooooo0_l000001?oooooo0000o`000?l0000:oooo
o`?o00002?ooool2o`000003ooooool0003o000000Gooooo0_l0001;ooooo`007?ooool00ol0003o
ooooooooo`0nooooo`;o00001?ooool2o`0001?ooooo1?l00006ooooo`;o00001?ooool2o`0000Co
oooo0_l00009ooooo`;o00000_ooool2o`0000Gooooo0ol00004ooooobGo000000?oooooo`000?l0
00000_ooool2o`0000;ooooo0_l00006ooooo`;o000000Coooooo`000?l0003o00000oooool3o`00
0004ooooool0003o0000ooooo`;o000000?oooooo`000?l000000_l00002ooooo`Co00000_ooool2
o`0000Gooooo1?l00006ooooo`;o000000?oooooo`000?l000004_ooool2o`0003kooooo000Loooo
o`03o`000?oooooooooo03gooooo0ol0000Kooooo`;o00003?ooool4o`0000;ooooo1?l0000;oooo
o`;o00000oooool5o`0000Cooooo2_l000000ooooooo0000o`00000Ko`0000;ooooo0_l00002oooo
o`?o00000oooool2o`0000Kooooo0ol000001?oooooo0000o`000?ooool2o`000004ooooool0003o
0000ooooo`;o00001_ooool3o`000003ooooool0003o000000Kooooo0ol00006ooooo`?o00001?oo
ool2o`0000kooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0looooo`?o00001oooool2
o`0000Oooooo0_l0000:ooooo`Co00003?ooool2o`000003ooooool0003o000000?o00001?ooool2
o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`Co00001?oooolXo`000003ooooool0003o
000000?o00000_ooool2o`0000?ooooo0_l00006ooooo`?o00001oooool5o`0000Oooooo0_l0000C
ooooo`;o00001?ooool3o`0004gooooo000Looooo`03o`000?oooooooooo03cooooo1Ol00002oooo
o`;o000000Coooooo`000?l0003o00001_ooool2o`0000Sooooo0_l000001?oooooo0000o`000?l0
000?ooooo`Co000000?oooooo`000?l000000_ooool2o`0000;ooooo1Ol0000;ooooo`;o000000?o
ooooo`000?l000006_l000000ooooooo0000o`00000<o`0000Wooooo0_l00008ooooo`;o00001Ooo
ool4o`000003ooooool0003o0000023ooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`0m
ooooo`Co00000_ooool2o`0000;ooooo1?l00006ooooo`;o00001_ooool2o`000003ooooool0003o
000000cooooo0_l00007ooooo`;o00001oooool5o`0000Kooooo2ol000000ooooooo0000o`000005
o`000003ooooool0003o000000ko000000?oooooo`000?l000002ol000000ooooooo0000o`000002
ooooo`;o000000Coooooo`000?l0003o00002?ooool2o`0000;ooooo1?l000001?oooooo0000o`00
0?ooool2o`0000?ooooo0_l0000Cooooo`;o00000_ooool2o`000003ooooool0003o000000_ooooo
0_l00011ooooo`007?ooool2o`0003Sooooo0_l0000@ooooo`;o00001Oooool3o`0001Kooooo0ol0
0003ooooo`;o00002?ooool2o`0000;ooooo1_l000001?oooooo0000o`000?ooool>o`000003oooo
ool0003o000001?o000000?oooooo`000?l000001Ol00002ooooo`Co000000?oooooo`000?l00000
0_ooool5o`0000gooooo1?l000000ooooooo0000o`000002o`0000Cooooo0_l000000ooooooo0000
o`000002ooooo`;o00003?ooool2o`000005ooooool0003o0000o`000?ooool00_l0000;ooooo`;o
0000@Oooool001cooooo00?o0000ooooooooool0=oooool2o`00013ooooo0_l00005ooooo`;o0000
5oooool2o`0000Cooooo1Ol00005ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`;o
00000_oooolXo`0000Kooooo0ol00007ooooo`;o00002Oooool2o`0000[ooooo0_l00007ooooo`;o
00000_ooool2o`0000Sooooo0_l00005ooooo`;o00000_ooool2o`0004kooooo000Looooo`03o`00
0?oooooooooo04Wooooo0ol00004ooooo`;o00002_ooool3o`0000Oooooo0_l000000ooooooo0000
o`000002ooooo`;o000000?oooooo`000?l000001?l00002ooooo`;o000000Coooooo`000?l0003o
oooo0_l00005ooooo`;o00000_oooolOo`000003ooooool0003o000000Go000000?oooooo`000?l0
00000ol000000ooooooo0000o`00000;ooooo`;o00001Oooool2o`00027ooooo0_l0000Eooooo`;o
0000@_ooool001cooooo00?o0000ooooooooool0B_ooool3o`0000?ooooo0_l0000:ooooo`?o0000
1oooool2o`0000Gooooo0_l00003ooooo`Co00000_ooool2o`000003ooooool0003o000000Sooooo
0_l00002ooooo`Co00000_oooolQo`000003ooooool0003o000000?o00001oooool2o`0000Gooooo
0_l00008ooooo`;o00001oooool2o`0001Gooooo0_l00007ooooo`;o00003?ooool2o`0004;ooooo
000Looooo`03o`000?oooooooooo04_ooooo0_l0000Rooooo`;o00000oooool2o`0000;ooooo0_l0
000;ooooo`;o00000ooooolDo`000003ooooool0003o000000co000000?oooooo`000?l000001Ol0
0008ooooo`;o00001Oooool2o`0000Sooooo0_l00002ooooo`;o00000oooool2o`0001Gooooo0_l0
00000ooooooo0000o`000004ooooo`;o0000D?ooool001cooooo00?o0000ooooooooool0H?ooool2
o`0000gooooo2?l0000Cooooo`;o000000?oooooo`000?l000009_l00003ooooo`;o00002_ooool2
o`0000cooooo0_l0000Mooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0B?ooool2o`00
01Kooooo0_l0000?ooooo`Ko00001Oooool2o`0000Gooooo0_l00003ooooobOo00000oooool3o`00
00?ooooo0_l00003ooooo`;o0000R_ooool001cooooo00?o0000ooooooooool0??ooool2o`0000[o
oooo0_l0000Oooooo`;o00000_ooool2o`0000gooooo0_l00005ooooo`;o00000oooool6o`000003
ooooool0003o000001[o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000Ko
oooo0_l00007ooooo`;o0000:_ooool3o`0005Cooooo000Looooo`03o`000?oooooooooo03cooooo
0_l0000Mooooo`;o00003?ooool2o`000005ooooool0003o0000o`000?ooool00_l00004ooooo`;o
00001Oooool2o`0000Gooooo2?l00003oooooaoo00001?ooool2o`000003ooooool0003o000000oo
oooo0_l0000Zooooo`?o0000E?ooool001cooooo00?o0000ooooooooool0A_ooool2o`0000Oooooo
0_l00007ooooo`;o000000?oooooo`000?l000003oooool2o`0000;ooooo0_l00004ooooo`;o0000
00?oooooo`000?l000000_ooool2o`0000Gooooo1Ol000000ooooooo0000o`000003o`000003oooo
ool0003o000001Go000000?oooooo`000?l000001?l0000Eooooo`?o0000Poooool001cooooo00?o
0000ooooooooool0A_ooool2o`0000Oooooo0_l00007ooooo`;o000000?oooooo`000?l000000_oo
ool2o`0000Wooooo0_l000000ooooooo0000o`00000:ooooo`;o00000_ooool2o`0000Kooooo1?l0
0003ooooo`?o000000?oooooo`000?l000004Ol000001Ooooooo0000o`000?l0003ooooo00Go0000
2Oooool2o`0000_ooooo0ol0000Zooooo`;o0000Eoooool001cooooo00?o0000ooooooooool0@Ooo
ool4o`0000[ooooo0_l00009ooooo`?o000000Coooooo`000?l0003o00001oooool7o`0000[ooooo
0_l00002ooooo`;o00001_ooool2o`0000Kooooo0_l00004oooooaCo000000?oooooo`000?l00000
0ol00009ooooo`Co00003Oooool2o`0002Oooooo0ol0001Fooooo`007?ooool00ol0003ooooooooo
o`11ooooo`Co00002_ooool2o`0000Wooooo0_l00002ooooo`;o00002?ooool2o`000003ooooool0
003o000000Cooooo0_l00006ooooo`;o00001oooool2o`0000gooooo1ol000000ooooooo0000o`00
000;o`0000;ooooo1ol000000ooooooo0000o`000006ooooo`;o00001_ooool2o`0000Gooooo0_l0
000Xooooo`?o0000EOooool001cooooo00?o0000ooooooooool0AOooool2o`0000Gooooo0_l0000A
ooooo`;o00001_ooool2o`0000Gooooo0_l000001?oooooo0000o`000?l00004ooooo`;o00000ooo
ool2o`0000?ooooo0_l00004ooooo`;o00001oooool<o`000003ooooool0003o000000So000000?o
ooooo`000?l000000_ooool2o`000003ooooool0003o000000kooooo0_l0000`ooooo`;o0000EOoo
ool001cooooo00?o0000ooooooooool0AOooool2o`0000Gooooo0_l0000Aooooo`;o00001_ooool2
o`0000;ooooo1Ol00002ooooo`;o00001?ooool2o`0000?ooooo0_l00008ooooo`?o00000oooool2
o`0000?ooooo1Ol000001?oooooo0000o`000?ooool6o`000004ooooool0003o0000ooooo`So0000
3oooool2o`0002Kooooo0_l0001Sooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o00002Ooo
ool2o`000003ooooool0003o000000?ooooo1_l0000Fooooo`;o00001?ooool5o`0000?ooooo0_l0
00001?oooooo0000o`000?ooool>o`0000;ooooo0_l00009ooooo`;o00001?ooool2o`0002Kooooo
0ol00008ooooo`;o0000F?ooool001cooooo0_l00013ooooo`;o00000oooool2o`0000Cooooo0_l0
0009ooooo`;o00002Oooool5o`0000Oooooo0_l00009ooooo`;o00004Oooool:o`000003ooooool0
003o000000Co000000?oooooo`000?l000001_l00004ooooo`;o00001Oooool2o`0000;ooooo0_l0
0005ooooo`;o00009_ooool2o`0000Sooooo0_l0000>ooooo`;o0000B?ooool001cooooo00?o0000
ooooooooool0@_ooool2o`0000?ooooo0_l00004ooooo`;o00005Oooool2o`0000?ooooo0_l00000
1?oooooo0000o`000?ooool2o`0000Sooooo0ol0000Aooooo`;o000000?oooooo`000?l000002Ol0
0005ooooo`;o00002_ooool2o`0000Cooooo1?l00007ooooo`;o0000:oooool2o`0001?ooooo0_l0
0018ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00000_ooool2o`0001Oooooo0_l00006
ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Cooooo1?l000000ooooooo0000o`00000@
ooooo`Co000000?oooooo`000?l000000ol00006ooooo`;o00000oooool3o`0000Cooooo0_l00004
ooooo`Co000000?oooooo`000?l000003oooool2o`0001kooooo1?l00002ooooo`;o0000FOooool0
01cooooo00?o0000ooooooooool0A?ooool2o`0000;ooooo0_l00004ooooo`;o00004Oooool2o`00
00Wooooo0_l00005ooooo`;o00001_ooool5o`00017ooooo0ol00002ooooo`Co00001?ooool4o`00
0003ooooool0003o000000?o00001_ooool2o`0000Oooooo0_l0000?ooooo`;o00007_ooool2o`00
00Cooooo0_l0001Iooooo`007?ooool00ol0003oooooooooo`1=ooooo`?o00003?ooool2o`0000?o
oooo0_l0000Cooooo`;o00001?ooool2o`0000cooooo0_l00003ooooo`Go00000_ooool4o`0000?o
oooo1?l00002ooooo`;o00002Oooool3o`0001Sooooo0_l0000Mooooo`;o000000?oooooo`000?l0
00000_l0001Jooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00000_ooool2o`0000Gooooo
0_l00006ooooo`;o00000oooool2o`0001?ooooo0_l00003ooooo`;o00001oooool2o`0000Cooooo
0ol00002ooooo`;o00001oooool2o`0000?ooooo1?l00007ooooo`Go00000_ooool2o`0001Oooooo
0ol0000Pooooo`Co00002_ooool2o`0004kooooo000Looooo`03o`000?oooooooooo04Wooooo0_l0
0009ooooo`Co00001Oooool2o`0001cooooo1?l00003ooooo`Co00000oooool4o`0000Kooooo1?l0
00000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000001?l00002ooooo`Go00001ooo
ool2o`0000_ooooo0_l00005ooooo`;o0000;oooool2o`0004kooooo000Looooo`03o`000?oooooo
oooo05Kooooo0_l00005ooooo`;o00001Oooool2o`0000;ooooo1?l00005ooooo`?o00002Oooool4
o`000003ooooool0003o000000Gooooo0_l00005ooooo`Oo000000?oooooo`000?l000001_ooool6
o`0000kooooo0_l000000ooooooo0000o`000008ooooo`;o00006_ooool2o`0006[ooooo000Loooo
o`03o`000?oooooooooo04Wooooo0_l0000?ooooo`;o00002?ooool2o`0000;ooooo1?l00005oooo
o`?o000000?oooooo`000?l000002?ooool2o`0000oooooo1?l00004ooooo`;o00001oooool2o`00
01Cooooo0_l0000Tooooo`;o00002oooool2o`0005gooooo000Looooo`03o`000?oooooooooo04Wo
oooo1?l0000=ooooo`;o00006Oooool2o`0000Kooooo0_l00004ooooo`;o00001?ooool2o`0000go
oooo0_l00007ooooo`;o0000??ooool2o`0000Wooooo0_l0001Mooooo`007?ooool00ol0003ooooo
ooooo`1;ooooo`;o00004oooool2o`0001;ooooo0_l00003ooooo`;o00000_ooool8o`0000Cooooo
0_l0000=ooooo`;o00000_ooool2o`0000Kooooo0_l0000Rooooo`;o00005?ooool3o`0000;ooooo
0_l00005ooooo`;o00002?ooool2o`0005?ooooo000Looooo`03o`000?oooooooooo057ooooo0_l0
000=ooooo`;o000000?oooooo`000?l000003oooool2o`0000?ooooo0_l000000ooooooo0000o`00
0008o`0000Cooooo0_l0000;ooooo`;o00000oooool2o`0000Kooooo0_l00005ooooo`;o00002_oo
ool2o`0000?ooooo0_l0000:ooooo`;o00004_ooool4o`0000;ooooo1?l00004ooooo`;o00002?oo
ool2o`0005?ooooo000Looooo`03o`000?oooooooooo057ooooo0_l00005ooooo`;o00002Oooool3
o`0001?ooooo0_l000001?oooooo0000o`000?l00002ooooo`;o000000?oooooo`000?l000001?oo
ool4o`0000Wooooo0_l0000;ooooo`;o00001Oooool2o`0000[ooooo0_l00003ooooo`Co00007?oo
ool2o`0000Cooooo1?l00008ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0DOooool2
o`0000Gooooo0_l00009ooooo`?o00004Oooool2o`0000Cooooo0_l00002ooooo`?o000000?ooooo
o`000?l000001Oooool2o`00033ooooo0ol00005ooooo`;o00004oooool3o`0000Wooooo0_l00005
ooooo`;o000000?oooooo`000?l00000E_ooool001cooooo00?o0000ooooooooool0D?ooool3o`00
00Cooooo0_l0000<ooooo`;o00003_ooool4o`0000Wooooo0_l000001?oooooo0000o`000?l0000:
ooooo`;o00001_ooool2o`000003ooooool0003o000001[ooooo0_l00004ooooo`;o00001Oooool2
o`0000_ooooo0ol00002ooooo`;o000000?oooooo`000?l000002_ooool2o`0000Cooooo0_l00002
ooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0D?ooool2o`0000Gooooo0_l00006oooo
o`Co00000_ooool2o`0000kooooo0_l0000>ooooo`?o000000?oooooo`000?l000001?ooool2o`00
0003ooooool0003o000000Kooooo0_l000000ooooooo0000o`000003ooooo`;o00001?ooool2o`00
00oooooo0_l000000ooooooo0000o`000005ooooo`;o00003?ooool5o`0000;ooooo0_l000000ooo
oooo0000o`000002ooooo`;o00003?ooool2o`0005[ooooo000Looooo`;o0000E_ooool2o`0000So
oooo1Ol0000Gooooo`;o00002Oooool5o`0000Cooooo1_l0000=ooooo`;o00001?ooool2o`0001;o
oooo0_l00005ooooo`;o00003?ooool2o`0000?ooooo0_l00003ooooo`;o000000Goooooo`000?l0
003o0000ooooo`02o`0000Kooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1Eooooo`;o
00002oooool2o`0000;ooooo0_l00006ooooo`?o00001Oooool2o`0000?ooooo0_l00008ooooo`Go
00001oooool4o`0000cooooo1?l00004ooooo`;o0000:_ooool5o`0000;ooooo1?l00002ooooo`;o
00001_ooool2o`0005gooooo000Looooo`03o`000?oooooooooo063ooooo0_l00004ooooo`;o0000
1_ooool3o`0000Gooooo0_l00006ooooo`?o00001?ooool5o`00013ooooo0_l00003ooooo`Ko0000
1?ooool2o`0002[ooooo0_l000001Ooooooo0000o`000?l0003ooooo00?o0000J_ooool001cooooo
00?o0000ooooooooool0EOooool2o`0000Gooooo0ol000000ooooooo0000o`00000Looooo`?o0000
1?ooool:o`0000_ooooo0_l00003ooooo`;o00001Oooool2o`0000Cooooo0_l0000Rooooo`;o0000
1oooool2o`0000;ooooo0_l0000;ooooo`;o0000GOooool001cooooo00?o0000ooooooooool0EOoo
ool2o`0000Gooooo0ol0000Pooooo`;o00001?ooool:o`00013ooooo0_l00005ooooo`;o00001?oo
ool3o`0000oooooo0_l0000@ooooo`;o00002oooool2o`0000Cooooo0_l00005ooooo`;o0000GOoo
ool001cooooo00?o0000ooooooooool0Hoooool2o`000003ooooool0003o000000cooooo0_l00009
ooooo`;o00001oooool4o`0000[ooooo0_l00007ooooo`;o00003?ooool2o`0000Kooooo0ol00006
ooooo`;o00000_ooool2o`0000Wooooo0_l000000ooooooo0000o`000007ooooo`;o00002?ooool2
o`0006Cooooo000Looooo`03o`000?oooooooooo06?ooooo0_l000000ooooooo0000o`00000<oooo
o`;o00005?ooool5o`0000Oooooo0_l00002ooooo`;o00000_ooool2o`0001Gooooo0ol00009oooo
o`?o00002Oooool2o`0000[ooooo0_l0001^ooooo`007?ooool00ol0003oooooooooo`1Sooooo`;o
00002_ooool2o`0001;ooooo0_l00006ooooo`Co00002oooool2o`0000;ooooo0_l00002ooooo`;o
00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000Booooo`;o000000?oooooo`000?l0
00001Oooool4o`0007[ooooo000Looooo`03o`000?oooooooooo05gooooo0_l0000@ooooo`;o0000
0_ooool2o`0000kooooo0_l0000Mooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000
o`000002ooooo`;o000000Coooooo`000?l0003o00003Oooool2o`0000Gooooo0ol0000Aooooo`;o
0000J?ooool001cooooo00?o0000ooooooooool0GOooool4o`0001;ooooo0_l0000Qooooo`;o0000
3_ooool2o`0000;ooooo0_l00005ooooo`;o000000Coooooo`000?l0003o00002?ooool4o`0001co
oooo0_l0001Xooooo`007?ooool00ol0003oooooooooo`1Nooooo`Co00006_ooool2o`0001Sooooo
0ol00007ooooo`?o00000oooool2o`0000[ooooo0_l00009ooooo`So00003oooool2o`0007?ooooo
000Looooo`03o`000?oooooooooo063ooooo0_l00002ooooo`;o00005_ooool2o`0000Gooooo0_l0
000;ooooo`;o00001Oooool2o`0000Oooooo0ol0000<ooooo`;o000000?oooooo`000?l000001ooo
ool4o`0000Cooooo0_l0000?ooooo`;o00002_ooool2o`0000_ooooo0_l0001Jooooo`007?ooool0
0ol0003oooooooooo`1Tooooo`;o00001Oooool2o`0000gooooo0_l00003ooooo`;o00000_ooool2
o`0000_ooooo0_l00002ooooo`Co00004?ooool2o`0000?ooooo1?l00002ooooo`;o00001_ooool2
o`0000?ooooo1?l0000:ooooo`;o00004?ooool2o`0000_ooooo0_l0001Jooooo`007?ooool00ol0
003oooooooooo`1Mooooo`;o00003?ooool2o`0000gooooo0ol00002ooooo`;o00000_ooool2o`00
00oooooo1?l0000@ooooo`;o00000oooool2o`0000Cooooo0_l00004ooooo`;o00001Oooool4o`00
00[ooooo0_l0001iooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool0
1Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0GOooool2o`0001?ooooo0_l0
0007ooooo`;o00001_ooool2o`0000cooooo0_l000000ooooooo0000o`000002ooooo`;o00005_oo
ool3o`0000;ooooo0_l00002ooooo`;o00005Oooool2o`0007Oooooo00001_ooooooMgMgoiRHV?oo
ooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003o
ooooooooo`1booooo`;o00001Oooool2o`0000Kooooo0_l0000>ooooo`;o00000oooool4o`0000;o
oooo0ol00005ooooo`;o00001_ooool2o`0000;ooooo1ol0000Iooooo`;o0000Moooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool0NOooool2o`0000Kooooo0_l0000>ooooo`;o00000oooool2o`0000Co
oooo1?l00004ooooo`?o00001Oooool2o`0000Gooooo0_l0000:ooooo`;o00003Oooool2o`0001ko
oooo0_l0001Iooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05oc8b
<_nHV9SooooooiRHV?lb<S801_ooool3o`0007Oooooo0_l00007ooooo`;o00006Oooool5o`0000?o
oooo1?l000000ooooooo0000o`00000Eooooo`;o00003Oooool2o`0001kooooo0_l0001Iooooo`00
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<
c<`01_ooool00ol0003oooooooooo`1gooooo`;o00001oooool2o`0000;ooooo0_l0000:ooooo`;o
00002Oooool2o`0000Kooooo0ol000001?oooooo0000o`000?l00009ooooo`;o00000_ooool2o`00
00Gooooo0_l00008ooooo`;o0000Ooooool00003ooooool@413ooooo00;ooooo00?o410@oooooooo
ool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0NOooool2o`00
00Wooooo0_l0000:ooooo`;o00003oooool5o`000003ooooool0003o000000[ooooo0_l00002oooo
o`;o00001Oooool2o`0000Oooooo0ol00004ooooo`?o0000N?ooool00006oooooomgMgOoV9RHoooo
oonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0NOoo
ool2o`000003ooooool0003o000000Kooooo1?l0000=ooooo`;o00002_ooool4o`0000Gooooo1?l0
0009ooooo`Co00003?ooool2o`0000?ooooo1Ol0000Gooooo`;o0000Goooool00006ooooooo^k^ko
<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000oooooooo
ool0O?ooool2o`0000Kooooo1?l0000=ooooo`;o00002Oooool3o`0000Oooooo1?l00009ooooo`Co
00003_ooool2o`000004ooooool0003o0000o`0001Wooooo0_l0001Oooooo`007?ooool00ol0003o
ooooooooo`28ooooo`;o00003?ooool2o`0000Gooooo0_l000001?oooooo0000o`000?l00007oooo
o`Co00002_ooool2o`0000oooooo0_l00002ooooo`Co0000N?ooool001cooooo00?o0000oooooooo
ool0R?ooool2o`0000cooooo0_l00005ooooo`;o00002oooool4o`0001Sooooo0_l00007ooooo`;o
0000N?ooool001cooooo00?o0000ooooooooool0J_ooool2o`0000?ooooo0_l0000Dooooo`;o0000
?oooool2o`00087ooooo000Looooo`03o`000?oooooooooo06[ooooo0_l00003ooooo`;o00005?oo
ool2o`0001Gooooo0_l0000Booooo`;o00001oooool2o`0008kooooo000Looooo`03o`000?oooooo
oooo08Sooooo0_l0000?ooooo`;o000000?oooooo`000?l000001?ooool2o`0000cooooo0_l00007
ooooo`;o00001?ooool2o`0008Sooooo000Looooo`03o`000?oooooooooo08Sooooo0_l0000?oooo
o`;o00001oooool2o`0001Gooooo0_l00004ooooo`;o00000_ooool2o`0008Cooooo000Looooo`03
o`000?oooooooooo06oooooo0_l0000Jooooo`;o00002_ooool3o`0002Wooooo0_l00024ooooo`00
7?ooool00ol0003oooooooooo`1_ooooo`;o00006_ooool2o`0000[ooooo0ol00004ooooo`;o0000
ZOooool001cooooo00?o0000ooooooooool0Roooool2o`0000kooooo0_l000000ooooooo0000o`00
000fooooo`;o0000LOooool001cooooo00?o0000ooooooooool0Voooool2o`0003Wooooo0_l0001a
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`00
7?ooool00ol0003oooooooooo`2Pooooo`;o00008oooool2o`0008;ooooo000Looooo`03o`000?oo
oooooooo0:3ooooo0_l0000Gooooo`;o00002_ooool2o`0008;ooooo000Looooo`03o`000?oooooo
oooo0:Wooooo0_l0000>ooooo`;o00002?ooool2o`0008Cooooo000Looooo`03o`000?oooooooooo
0:Wooooo0_l0000>ooooo`;o00002?ooool2o`0008Cooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0
003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001;ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo
B_ooool001Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood[ooooo000D
ooooo`03o`000?oooooooooo00Gooooo0ol0003ooooood[ooooo000Dooooo`03o`000?oooooooooo
0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003ooooo
ooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001;ooooo00?oEEEE
ofIVI_l00000oooooomDooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00YOoo
ool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo01Oooooo00?o0000onk^k_ooool0
1Oooool00ol0003ok^k^ooooo`05ooooo`;o000000?o410@ooooooooool0S_ooool00:Kooooo00Go
0000ooooooooooooooooo`000009ooooo`Ko00002oooool00omEEEGoZJVYooooo`05ooooo`03oeEE
EOnYZJWooooo00Kooooo00?o0000ooooooooool0Soooool00:Kooooo00Go0000oooooooooooooooo
o`00000Jooooo`03ojVYZOmEEEGooooo00Gooooo00?oZJVYoeEEEOooool00oooool5o`00093ooooo
002Vooooo`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo00?o8B4Qooooooooool0
1Oooool00olQ8B7oooooooooo`02ooooo`04odA4A?oMgMgoooooo`00097ooooo002Vooooo`05o`00
0?n7QhOoooooojVYZOl000006oooool00omEEEGoc<c<ooooo`05ooooo`03oeEEEOo<c<cooooo00;o
oooo00CogMgMoeEEEOoooooo0000TOooool00:Gooooo00?o410@o`000?mgMgL00_l000000onHV9So
ooooooooo`0Iooooo`03ojVYZOmgMgOooooo00Gooooo00?oZJVYogMgMoooool00oooool00omgMgOo
c<c<o`00002Aooooo`00`oooool01Ol@413ooooooooooooooooo<S8b00?ooooo00Go410@oooooooo
oooooooooc8b<P04ooooo`03onk^k_m4A4Co0000097ooooo0033ooooo`Go00000oooool5o`0000Go
oooo00?oMgMgo`000?ooool0T?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(780) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.66253 .52537 Mdot
.66844 .53448 Mdot
.38615 .37136 Mdot
.50692 .66265 Mdot
.42881 .51604 Mdot
.43697 .34245 Mdot
.57072 .40108 Mdot
.53927 .38669 Mdot
.41869 .33037 Mdot
.57906 .66233 Mdot
.60234 .39932 Mdot
.4047 .66224 Mdot
.57243 .39026 Mdot
.48441 .62065 Mdot
.42743 .17215 Mdot
.42867 .67783 Mdot
.65518 .58456 Mdot
.32402 .46977 Mdot
.511 .69333 Mdot
.38537 .33476 Mdot
.61678 .57914 Mdot
.4801 .61948 Mdot
.65216 .53707 Mdot
.48315 .62154 Mdot
.49366 .66026 Mdot
.6843 .55997 Mdot
.63178 .54977 Mdot
.46403 .67124 Mdot
.49679 .63557 Mdot
.57236 .41964 Mdot
.39717 .50007 Mdot
.28431 .25473 Mdot
.41991 .67475 Mdot
.528 .80354 Mdot
.54504 .39512 Mdot
.20392 .56594 Mdot
.39639 .34108 Mdot
.58844 .37016 Mdot
.54128 .39253 Mdot
.55401 .37122 Mdot
.57687 .37061 Mdot
.68726 .55518 Mdot
.6159 .37556 Mdot
.58266 .44605 Mdot
.50991 .66703 Mdot
.69077 .40614 Mdot
.24514 .52389 Mdot
.46021 .66263 Mdot
.69362 .53291 Mdot
.39477 .32068 Mdot
.63826 .79857 Mdot
.55694 .36023 Mdot
.61227 .23225 Mdot
.3599 .13083 Mdot
.56003 .37995 Mdot
.49913 .67363 Mdot
.41326 .35098 Mdot
.45303 .62327 Mdot
.46869 .6298 Mdot
.65049 .77143 Mdot
.47978 .65627 Mdot
.32903 .49195 Mdot
.67779 .60187 Mdot
.43872 .38202 Mdot
.42837 .33587 Mdot
.55076 .40803 Mdot
.68671 .58325 Mdot
.58248 .3916 Mdot
.51541 .57642 Mdot
.40573 .32107 Mdot
.45874 .66303 Mdot
.604 .39369 Mdot
.71903 .55593 Mdot
.46185 .59396 Mdot
.72088 .42807 Mdot
.49946 .16709 Mdot
.33831 .45858 Mdot
.63516 .76315 Mdot
.76607 .59548 Mdot
.51807 .19835 Mdot
.48917 .62879 Mdot
.84069 .39396 Mdot
.44428 .1688 Mdot
.65303 .54065 Mdot
.39665 .56744 Mdot
.46161 .38865 Mdot
.47731 .5985 Mdot
.43822 .4753 Mdot
.46643 .5754 Mdot
.77052 .49633 Mdot
.41239 .33134 Mdot
.69747 .55122 Mdot
.51167 .6571 Mdot
.42782 .62188 Mdot
.66064 .67494 Mdot
.47011 .58203 Mdot
.46071 .67674 Mdot
.62699 .56836 Mdot
.57897 .41471 Mdot
.42849 .58419 Mdot
.62078 .43524 Mdot
.6133 .24516 Mdot
.5177 .61888 Mdot
.4259 .32357 Mdot
.65351 .59102 Mdot
.52189 .61982 Mdot
.55237 .38586 Mdot
.47775 .64576 Mdot
.62094 .42441 Mdot
.67539 .52897 Mdot
.4303 .61857 Mdot
.32374 .47256 Mdot
.77005 .44368 Mdot
.69976 .56522 Mdot
.77077 .33201 Mdot
.47169 .6584 Mdot
.47318 .61872 Mdot
.66992 .53632 Mdot
.42533 .36723 Mdot
.42516 .46557 Mdot
.70464 .57726 Mdot
.54562 .38128 Mdot
.63979 .54109 Mdot
.5329 .61451 Mdot
.44601 .34308 Mdot
.61522 .25116 Mdot
.59383 .26474 Mdot
.3465 .71525 Mdot
.48696 .60035 Mdot
.63817 .36202 Mdot
.43863 .35168 Mdot
.68954 .5449 Mdot
.58171 .38857 Mdot
.46 .68396 Mdot
.65657 .57705 Mdot
.59298 .38298 Mdot
.32807 .47398 Mdot
.25384 .4223 Mdot
.71053 .55159 Mdot
.58751 .50562 Mdot
.59821 .42702 Mdot
.55539 .37098 Mdot
.54866 .8223 Mdot
.6646 .53772 Mdot
.35578 .49266 Mdot
.59285 .38688 Mdot
.3375 .59 Mdot
.4571 .68149 Mdot
.39634 .74795 Mdot
.84053 .49066 Mdot
.61787 .81392 Mdot
.68191 .30548 Mdot
.33805 .51417 Mdot
.573 .36232 Mdot
.50777 .64641 Mdot
.6642 .54696 Mdot
.67422 .54849 Mdot
.42566 .6446 Mdot
.48476 .66477 Mdot
.43591 .64802 Mdot
.42791 .63948 Mdot
.25017 .50087 Mdot
.43309 .64706 Mdot
.40114 .29358 Mdot
.68744 .57733 Mdot
.49376 .6517 Mdot
.4056 .37253 Mdot
.4573 .69436 Mdot
.59218 .37534 Mdot
.46501 .62642 Mdot
.48665 .67054 Mdot
.48877 .5892 Mdot
.57511 .36736 Mdot
.23669 .32362 Mdot
.82843 .48228 Mdot
.17701 .47398 Mdot
.71753 .3199 Mdot
.42193 .35773 Mdot
.47802 .60416 Mdot
.34108 .48297 Mdot
.54886 .56936 Mdot
.47039 .6345 Mdot
.70705 .75432 Mdot
.47448 .673 Mdot
.50493 .77882 Mdot
.53128 .68562 Mdot
.169 .46177 Mdot
.48744 .4067 Mdot
.49284 .63998 Mdot
.63526 .64856 Mdot
.42999 .78124 Mdot
.50418 .53527 Mdot
.56918 .37313 Mdot
.4155 .37308 Mdot
.40431 .34832 Mdot
.61796 .38651 Mdot
.46233 .56938 Mdot
.56225 .6783 Mdot
.43489 .5748 Mdot
.61164 .25654 Mdot
.72052 .56783 Mdot
.36684 .4999 Mdot
.70583 .53881 Mdot
.78788 .30535 Mdot
.73751 .49187 Mdot
.57063 .43298 Mdot
.30684 .4904 Mdot
.39858 .37667 Mdot
.61104 .26097 Mdot
.34785 .48453 Mdot
.4526 .65422 Mdot
.69631 .5378 Mdot
.45289 .79699 Mdot
.52971 .68323 Mdot
.3468 .7853 Mdot
.64415 .56153 Mdot
.46857 .44699 Mdot
.57756 .37746 Mdot
.38909 .31879 Mdot
.49512 .6109 Mdot
.43573 .63118 Mdot
.65189 .59745 Mdot
.46226 .66012 Mdot
.74897 .5842 Mdot
.48558 .67336 Mdot
.46608 .36692 Mdot
.3763 .47138 Mdot
.59972 .36428 Mdot
.35639 .72315 Mdot
.71241 .53101 Mdot
.37353 .28522 Mdot
.38883 .33581 Mdot
.5915 .62162 Mdot
.60275 .40163 Mdot
.32151 .47693 Mdot
.38895 .35532 Mdot
.34321 .52175 Mdot
.51355 .60853 Mdot
.39612 .33718 Mdot
.36121 .50081 Mdot
.23601 .40798 Mdot
.49589 .67891 Mdot
.2954 .5443 Mdot
.57838 .4028 Mdot
.64392 .53164 Mdot
.48099 .65598 Mdot
.59375 .26727 Mdot
.53066 .65408 Mdot
.60666 .29801 Mdot
.60406 .23574 Mdot
.61419 .23467 Mdot
.48394 .18982 Mdot
.31939 .50058 Mdot
.70677 .357 Mdot
.61852 .48087 Mdot
.68419 .58473 Mdot
.51289 .65895 Mdot
.19333 .38031 Mdot
.59188 .38573 Mdot
.45301 .65167 Mdot
.46542 .37987 Mdot
.59277 .38916 Mdot
.4543 .61642 Mdot
.56603 .36833 Mdot
.66819 .54615 Mdot
.3537 .36279 Mdot
.64002 .57292 Mdot
.49065 .67993 Mdot
.55555 .39262 Mdot
.39773 .36016 Mdot
.6812 .56082 Mdot
.47477 .64479 Mdot
.48419 .60986 Mdot
.60527 .25748 Mdot
.49605 .64501 Mdot
.19943 .38206 Mdot
.46141 .66876 Mdot
.41933 .3822 Mdot
.46781 .58034 Mdot
.62318 .82339 Mdot
.26351 .41437 Mdot
.7007 .57464 Mdot
.60907 .23505 Mdot
.41501 .33495 Mdot
.34919 .37077 Mdot
.54426 .52625 Mdot
.48405 .63564 Mdot
.60289 .24439 Mdot
.43934 .44233 Mdot
.5529 .4118 Mdot
.49435 .58093 Mdot
.7415 .47932 Mdot
.38458 .35206 Mdot
.60989 .25951 Mdot
.43877 .70341 Mdot
.65013 .59021 Mdot
.50366 .6652 Mdot
.39214 .3456 Mdot
.63995 .53911 Mdot
.49649 .68443 Mdot
.23405 .5575 Mdot
.5944 .24941 Mdot
.57964 .40162 Mdot
.54888 .68169 Mdot
.4401 .65685 Mdot
.40514 .35563 Mdot
.6495 .55055 Mdot
.55172 .40082 Mdot
.69088 .56514 Mdot
.43509 .78819 Mdot
.73015 .3374 Mdot
.23069 .48623 Mdot
.30728 .48643 Mdot
.6203 .28555 Mdot
.17538 .49506 Mdot
.73222 .37135 Mdot
.31924 .64467 Mdot
.1874 .60916 Mdot
.39839 .36807 Mdot
.34991 .55324 Mdot
.41531 .34063 Mdot
.51274 .63416 Mdot
.43433 .33888 Mdot
.16421 .45399 Mdot
.47098 .67543 Mdot
.41825 .3574 Mdot
.32053 .42873 Mdot
.48272 .66148 Mdot
.69715 .57183 Mdot
.37749 .20531 Mdot
.80162 .53218 Mdot
.72542 .50156 Mdot
.42293 .36339 Mdot
.74423 .68103 Mdot
.46966 .66867 Mdot
.4421 .69003 Mdot
.66517 .55159 Mdot
.48223 .57637 Mdot
.36635 .48529 Mdot
.33596 .52338 Mdot
.39515 .74016 Mdot
.80046 .38585 Mdot
.48217 .5625 Mdot
.67788 .55873 Mdot
.74954 .60885 Mdot
.71756 .42888 Mdot
.60633 .27615 Mdot
.55159 .41897 Mdot
.24419 .31845 Mdot
.54445 .58395 Mdot
.58573 .51085 Mdot
.73654 .46957 Mdot
.69245 .53935 Mdot
.22024 .40168 Mdot
.56176 .38174 Mdot
.67783 .63244 Mdot
.56146 .75486 Mdot
.43963 .6453 Mdot
.5894 .41722 Mdot
.4047 .62519 Mdot
.77761 .52599 Mdot
.35017 .56935 Mdot
.57643 .23861 Mdot
.50187 .67437 Mdot
.7112 .37 Mdot
.47036 .6224 Mdot
.37964 .71118 Mdot
.45721 .67005 Mdot
.68602 .56951 Mdot
.45166 .56322 Mdot
.47458 .48953 Mdot
.82429 .4342 Mdot
.74741 .50161 Mdot
.33951 .51636 Mdot
.48139 .61213 Mdot
.438 .64058 Mdot
.33238 .5069 Mdot
.67019 .5673 Mdot
.45299 .66927 Mdot
.27124 .64566 Mdot
.43952 .65224 Mdot
.59255 .37375 Mdot
.40013 .47521 Mdot
.68129 .49798 Mdot
.44624 .60215 Mdot
.63516 .56963 Mdot
.56233 .37327 Mdot
.53972 .39548 Mdot
.54609 .60289 Mdot
.57414 .36347 Mdot
.50007 .66853 Mdot
.39077 .45167 Mdot
.65776 .53306 Mdot
.44855 .71423 Mdot
.66549 .56875 Mdot
.76506 .62843 Mdot
.55916 .37204 Mdot
.60608 .27162 Mdot
.56712 .55832 Mdot
.56377 .38829 Mdot
.77779 .56629 Mdot
.52679 .56882 Mdot
.51394 .68135 Mdot
.78687 .55548 Mdot
.41224 .36785 Mdot
.61116 .26626 Mdot
.55212 .39063 Mdot
.43732 .65257 Mdot
.51267 .60013 Mdot
.60717 .39114 Mdot
.68554 .68014 Mdot
.35172 .387 Mdot
.46056 .6741 Mdot
.68055 .57031 Mdot
.6912 .548 Mdot
.50623 .67883 Mdot
.46989 .64209 Mdot
.42122 .38059 Mdot
.59706 .25034 Mdot
.62075 .25022 Mdot
.59601 .26739 Mdot
.40705 .30583 Mdot
.63423 .3142 Mdot
.55515 .37041 Mdot
.6545 .36247 Mdot
.50548 .32613 Mdot
.54677 .63881 Mdot
.40459 .35891 Mdot
.44393 .61846 Mdot
.51361 .62453 Mdot
.55365 .40224 Mdot
.68222 .26777 Mdot
.39139 .65928 Mdot
.68994 .52517 Mdot
.58251 .36325 Mdot
.57113 .61057 Mdot
.51336 .37734 Mdot
.36352 .48436 Mdot
.74779 .51716 Mdot
.59492 .41322 Mdot
.70134 .55126 Mdot
.61022 .3924 Mdot
.43739 .64364 Mdot
.42875 .66117 Mdot
.67641 .53294 Mdot
.31908 .50233 Mdot
.51516 .59817 Mdot
.456 .61555 Mdot
.73303 .76151 Mdot
.72165 .42322 Mdot
.53426 .3581 Mdot
.50384 .63915 Mdot
.5321 .66414 Mdot
.33066 .51633 Mdot
.44373 .65607 Mdot
.49285 .60876 Mdot
.77808 .44653 Mdot
.61708 .36802 Mdot
.36192 .46418 Mdot
.67714 .63021 Mdot
.64537 .56376 Mdot
.21942 .36044 Mdot
.61353 .24303 Mdot
.60003 .35773 Mdot
.35463 .36312 Mdot
.60351 .26672 Mdot
.52775 .31962 Mdot
.22063 .37947 Mdot
.60134 .26994 Mdot
.36007 .36208 Mdot
.40863 .56801 Mdot
.44153 .67278 Mdot
.4628 .62369 Mdot
.34141 .47973 Mdot
.66422 .54027 Mdot
.47302 .42471 Mdot
.25528 .36839 Mdot
.47766 .61928 Mdot
.65053 .60495 Mdot
.24626 .34707 Mdot
.60558 .26083 Mdot
.32471 .48922 Mdot
.37031 .49282 Mdot
.47045 .61892 Mdot
.76643 .40907 Mdot
.68248 .5588 Mdot
.47484 .64438 Mdot
.43492 .61737 Mdot
.41941 .36426 Mdot
.70289 .54774 Mdot
.39015 .3337 Mdot
.59991 .23887 Mdot
.24787 .69118 Mdot
.70812 .78083 Mdot
.56541 .40845 Mdot
.18796 .45853 Mdot
.53552 .38094 Mdot
.55708 .20012 Mdot
.59438 .26235 Mdot
.47797 .63246 Mdot
.71696 .54077 Mdot
.47626 .64765 Mdot
.44604 .6461 Mdot
.45055 .65412 Mdot
.47373 .56241 Mdot
.6985 .76271 Mdot
.34571 .4943 Mdot
.54299 .63469 Mdot
.44688 .37012 Mdot
.19494 .41964 Mdot
.36779 .22414 Mdot
.45193 .60605 Mdot
.47174 .61478 Mdot
.67473 .58313 Mdot
.42329 .62378 Mdot
.56747 .41992 Mdot
.6495 .54408 Mdot
.51714 .60482 Mdot
.21785 .4214 Mdot
.44738 .66737 Mdot
.17907 .50489 Mdot
.60957 .39171 Mdot
.74572 .51688 Mdot
.53969 .61877 Mdot
.60124 .27074 Mdot
.61034 .26704 Mdot
.61413 .27469 Mdot
.57736 .42419 Mdot
.41194 .35792 Mdot
.321 .29228 Mdot
.41394 .61748 Mdot
.50562 .6518 Mdot
.5356 .65584 Mdot
.38284 .32098 Mdot
.41474 .4861 Mdot
.68586 .32059 Mdot
.55938 .59312 Mdot
.43782 .37187 Mdot
.65113 .52361 Mdot
.74971 .2919 Mdot
.64975 .54606 Mdot
.36426 .46492 Mdot
.59956 .38582 Mdot
.36077 .47847 Mdot
.73258 .71223 Mdot
.67134 .53095 Mdot
.65009 .59671 Mdot
.42014 .35828 Mdot
.49276 .44309 Mdot
.24601 .23309 Mdot
.43171 .32283 Mdot
.30059 .66873 Mdot
.6674 .55571 Mdot
.4619 .59065 Mdot
.42886 .4434 Mdot
.49189 .44844 Mdot
.4225 .34764 Mdot
.4902 .62407 Mdot
.80096 .4058 Mdot
.41752 .38067 Mdot
.49685 .58302 Mdot
.43647 .36036 Mdot
.58249 .37264 Mdot
.43721 .35529 Mdot
.68451 .5167 Mdot
.51344 .61193 Mdot
.31624 .16729 Mdot
.54964 .45202 Mdot
.48066 .65298 Mdot
.58203 .36328 Mdot
.26159 .6481 Mdot
.4444 .63543 Mdot
.36402 .47966 Mdot
.44931 .35387 Mdot
.33752 .3895 Mdot
.4713 .66627 Mdot
.43217 .34781 Mdot
.67352 .51984 Mdot
.55455 .35264 Mdot
.50272 .18219 Mdot
.61823 .25843 Mdot
.65969 .54509 Mdot
.62886 .25452 Mdot
.59305 .42556 Mdot
.49037 .58572 Mdot
.43072 .6278 Mdot
.68621 .57469 Mdot
.48426 .22596 Mdot
.43109 .60635 Mdot
.48907 .62871 Mdot
.38681 .3693 Mdot
.36739 .34382 Mdot
.42757 .23136 Mdot
.3995 .36766 Mdot
.53614 .65687 Mdot
.68718 .57369 Mdot
.51654 .63344 Mdot
.69809 .57289 Mdot
.51265 .65868 Mdot
.73663 .55676 Mdot
.65367 .54333 Mdot
.75876 .34883 Mdot
.50369 .62088 Mdot
.53865 .68442 Mdot
.44655 .65001 Mdot
.45327 .66272 Mdot
.45042 .34654 Mdot
.3392 .50399 Mdot
.45329 .58095 Mdot
.37224 .2933 Mdot
.32576 .48121 Mdot
.46579 .7781 Mdot
.4195 .36571 Mdot
.34364 .47654 Mdot
.2697 .51856 Mdot
.61077 .23568 Mdot
.33876 .49012 Mdot
.35328 .24011 Mdot
.5616 .40738 Mdot
.64218 .54376 Mdot
.48398 .66085 Mdot
.20983 .65333 Mdot
.39521 .48578 Mdot
.60109 .2546 Mdot
.47239 .66104 Mdot
.44264 .62346 Mdot
.65815 .59037 Mdot
.81517 .34283 Mdot
.37758 .36495 Mdot
.51182 .6502 Mdot
.65126 .58175 Mdot
.84361 .474 Mdot
.44292 .33462 Mdot
.33762 .48633 Mdot
.60117 .37796 Mdot
.64256 .5182 Mdot
.61847 .25937 Mdot
.55016 .41018 Mdot
.38432 .41133 Mdot
.75734 .67829 Mdot
.46642 .66318 Mdot
.39936 .35354 Mdot
.6249 .81058 Mdot
.44809 .57463 Mdot
.60132 .34012 Mdot
.45707 .75454 Mdot
.69472 .54236 Mdot
.60458 .38324 Mdot
.35758 .51383 Mdot
.65099 .53543 Mdot
.67251 .56725 Mdot
.54086 .38161 Mdot
.45155 .31427 Mdot
.47163 .44754 Mdot
.60169 .38234 Mdot
.77469 .49077 Mdot
.45521 .79168 Mdot
.601 .24491 Mdot
.32217 .49412 Mdot
.47163 .81255 Mdot
.68797 .55623 Mdot
.24248 .31994 Mdot
.682 .77169 Mdot
.46066 .67667 Mdot
.3596 .48796 Mdot
.52501 .33352 Mdot
.31094 .29729 Mdot
.59312 .39315 Mdot
.43399 .48846 Mdot
.3612 .47273 Mdot
.44613 .67197 Mdot
.65637 .49611 Mdot
.50237 .62475 Mdot
.5902 .37814 Mdot
.76582 .57108 Mdot
.70261 .55535 Mdot
.60034 .42182 Mdot
.7724 .5512 Mdot
.51284 .62232 Mdot
.49706 .62162 Mdot
.35691 .67045 Mdot
.6962 .53678 Mdot
.62087 .25511 Mdot
.48369 .64174 Mdot
.45529 .62372 Mdot
.48471 .58446 Mdot
.56948 .64309 Mdot
.75708 .41682 Mdot
.51371 .6459 Mdot
.42069 .30874 Mdot
.47235 .69672 Mdot
.49776 .6188 Mdot
.64518 .58113 Mdot
.71731 .76466 Mdot
.59155 .2513 Mdot
.46144 .62662 Mdot
.45695 .66796 Mdot
.54228 .38911 Mdot
.45564 .44252 Mdot
.4984 .45296 Mdot
.41287 .32014 Mdot
.31765 .61499 Mdot
.45696 .56761 Mdot
.65323 .57345 Mdot
.33045 .46871 Mdot
.48525 .59525 Mdot
.6549 .57852 Mdot
.45634 .68946 Mdot
.42623 .3781 Mdot
.59869 .24903 Mdot
.63941 .48892 Mdot
.33328 .49179 Mdot
.45549 .41384 Mdot
.66395 .40355 Mdot
.41034 .37376 Mdot
.50037 .65546 Mdot
.56069 .35513 Mdot
.39964 .32888 Mdot
.60472 .25532 Mdot
.45261 .70744 Mdot
.67471 .5513 Mdot
.69988 .55844 Mdot
.38932 .73245 Mdot
.38013 .37638 Mdot
.82644 .60196 Mdot
.58363 .37326 Mdot
.52957 .63027 Mdot
.63947 .42608 Mdot
.70023 .5612 Mdot
.38137 .73167 Mdot
.34114 .47674 Mdot
.59241 .39538 Mdot
.59779 .27894 Mdot
.66172 .58084 Mdot
.70634 .54596 Mdot
.50321 .67536 Mdot
.46309 .60373 Mdot
.31648 .65239 Mdot
.39046 .73917 Mdot
.57296 .36885 Mdot
.32324 .50044 Mdot
.40382 .31838 Mdot
.50911 .63211 Mdot
.65269 .53951 Mdot
.4962 .77838 Mdot
.43754 .65725 Mdot
.41805 .3811 Mdot
.68926 .53898 Mdot
.32893 .50657 Mdot
.34202 .47134 Mdot
.45299 .66244 Mdot
.64875 .7641 Mdot
.56275 .39354 Mdot
.69978 .56696 Mdot
.60204 .5609 Mdot
.44327 .59457 Mdot
.46741 .60348 Mdot
.41025 .67963 Mdot
.54919 .40768 Mdot
.65892 .49119 Mdot
.33821 .46305 Mdot
.67728 .54544 Mdot
.4798 .65118 Mdot
.32928 .4915 Mdot
.60359 .52525 Mdot
.59783 .26378 Mdot
.43895 .35697 Mdot
.36736 .48645 Mdot
.3507 .50722 Mdot
.32411 .48041 Mdot
.25771 .30376 Mdot
.71994 .56577 Mdot
.74106 .60631 Mdot
.45513 .67092 Mdot
.38923 .72968 Mdot
.41993 .63923 Mdot
.58491 .42469 Mdot
.40588 .36781 Mdot
.44322 .64435 Mdot
.50517 .67391 Mdot
.51222 .72362 Mdot
.56627 .63621 Mdot
.62558 .59007 Mdot
.68553 .53107 Mdot
.55999 .65615 Mdot
.41319 .36567 Mdot
.84827 .38791 Mdot
.18284 .35529 Mdot
.53519 .60616 Mdot
.47369 .43537 Mdot
.65151 .54219 Mdot
.54378 .37445 Mdot
.50283 .46315 Mdot
.60293 .37526 Mdot
.68036 .54349 Mdot
.51118 .63357 Mdot
.65755 .36379 Mdot
.3251 .51725 Mdot
.43391 .64455 Mdot
.58159 .37922 Mdot
.43487 .64646 Mdot
.59146 .41996 Mdot
.72006 .60031 Mdot
.74798 .4707 Mdot
.47286 .67358 Mdot
.45293 .59068 Mdot
.52667 .70885 Mdot
.45378 .60554 Mdot
.54109 .28145 Mdot
.66068 .56201 Mdot
.79939 .39284 Mdot
.49929 .68182 Mdot
.69097 .72249 Mdot
.43977 .66465 Mdot
.48464 .23795 Mdot
.46652 .59916 Mdot
.51132 .48547 Mdot
.45018 .67582 Mdot
.48204 .6064 Mdot
.55504 .38943 Mdot
.5418 .38851 Mdot
.67953 .52039 Mdot
.61977 .26027 Mdot
.17265 .45612 Mdot
.46055 .60989 Mdot
.4222 .30686 Mdot
.63016 .44144 Mdot
.34556 .50718 Mdot
.68346 .54662 Mdot
.8553 .49298 Mdot
.56317 .37077 Mdot
.45928 .37397 Mdot
.50216 .23825 Mdot
.38609 .32588 Mdot
.62652 .4234 Mdot
.57498 .60529 Mdot
.32702 .50832 Mdot
.44112 .66765 Mdot
.53451 .8019 Mdot
.71293 .39558 Mdot
.52311 .60515 Mdot
.61407 .40234 Mdot
.54331 .56335 Mdot
.48162 .80742 Mdot
.36305 .51435 Mdot
.3515 .51451 Mdot
.5557 .38586 Mdot
.38013 .35883 Mdot
.41449 .59535 Mdot
.34342 .47582 Mdot
.42447 .37462 Mdot
.62273 .25997 Mdot
.52315 .52277 Mdot
.68357 .55642 Mdot
.70828 .49352 Mdot
.67934 .43635 Mdot
.57116 .36903 Mdot
.36435 .30234 Mdot
.64601 .52104 Mdot
.66386 .59487 Mdot
.61288 .26936 Mdot
.45148 .34907 Mdot
.72091 .5484 Mdot
.50682 .59302 Mdot
.54129 .67124 Mdot
.47149 .6232 Mdot
.35154 .48086 Mdot
.45661 .6001 Mdot
.44973 .36396 Mdot
.58987 .38896 Mdot
.40636 .33079 Mdot
.562 .39722 Mdot
.66056 .34183 Mdot
.46764 .64772 Mdot
.47628 .60817 Mdot
.39823 .44762 Mdot
.69999 .53339 Mdot
.68326 .75739 Mdot
.42677 .30742 Mdot
.41319 .34692 Mdot
.51825 .62749 Mdot
.6681 .52086 Mdot
.38166 .49803 Mdot
.39971 .43944 Mdot
.44581 .60641 Mdot
.65946 .56148 Mdot
.5091 .65159 Mdot
.24194 .47016 Mdot
.74076 .45701 Mdot
.69324 .56441 Mdot
.81566 .39435 Mdot
.50252 .63332 Mdot
.42301 .55219 Mdot
.53131 .66642 Mdot
.27717 .6252 Mdot
.45158 .58824 Mdot
.64342 .55997 Mdot
.46665 .62714 Mdot
.64961 .55648 Mdot
.39293 .37118 Mdot
.5516 .36803 Mdot
.6589 .54763 Mdot
.45317 .59797 Mdot
.2579 .28445 Mdot
.58092 .37513 Mdot
.48397 .61155 Mdot
.58749 .41349 Mdot
.64378 .57243 Mdot
.69244 .5298 Mdot
.35783 .24239 Mdot
.5649 .34399 Mdot
.57668 .37268 Mdot
.50227 .66223 Mdot
.66156 .4584 Mdot
.51584 .63497 Mdot
.32028 .66331 Mdot
.52263 .65396 Mdot
.4674 .57959 Mdot
.55296 .16475 Mdot
.54338 .36284 Mdot
.82826 .57526 Mdot
.25072 .38056 Mdot
.27376 .28746 Mdot
.66313 .50532 Mdot
.36329 .51417 Mdot
.2239 .3878 Mdot
.60217 .23734 Mdot
.44505 .35484 Mdot
.44308 .64541 Mdot
.73568 .52995 Mdot
.5931 .3726 Mdot
.34481 .50313 Mdot
.47396 .67343 Mdot
.42925 .37928 Mdot
.38859 .23352 Mdot
.5746 .36265 Mdot
.68702 .55425 Mdot
.69523 .52912 Mdot
.83622 .47407 Mdot
.47689 .6548 Mdot
.47755 .61152 Mdot
.59795 .38415 Mdot
.47248 .56821 Mdot
.31658 .48865 Mdot
.28451 .44563 Mdot
.57419 .37355 Mdot
.5734 .4587 Mdot
.67281 .52851 Mdot
.44249 .62202 Mdot
.40654 .49493 Mdot
.44383 .2794 Mdot
.59963 .65773 Mdot
.34212 .48083 Mdot
.33282 .65771 Mdot
.64355 .56042 Mdot
.58221 .38523 Mdot
.29099 .52759 Mdot
.53111 .64945 Mdot
.44569 .62244 Mdot
.3364 .65925 Mdot
.44985 .43974 Mdot
.37636 .51363 Mdot
.42253 .62331 Mdot
.44213 .44629 Mdot
.51839 .62473 Mdot
.51342 .60157 Mdot
.52408 .58357 Mdot
.48033 .60096 Mdot
.65503 .55765 Mdot
.5151 .72347 Mdot
.43721 .34899 Mdot
.665 .66689 Mdot
.45089 .48258 Mdot
.48862 .65078 Mdot
.51162 .63088 Mdot
.5989 .62762 Mdot
.61508 .44757 Mdot
.66439 .56089 Mdot
.72305 .57434 Mdot
.55335 .3775 Mdot
.53711 .68279 Mdot
.3769 .33909 Mdot
.46508 .75043 Mdot
.41022 .32812 Mdot
.65845 .56189 Mdot
.40883 .35138 Mdot
.54954 .38167 Mdot
.39874 .3526 Mdot
.40924 .30591 Mdot
.60621 .40468 Mdot
.66999 .52708 Mdot
.44747 .60619 Mdot
.5601 .37029 Mdot
.35463 .67256 Mdot
.35135 .48012 Mdot
.35788 .24194 Mdot
.45766 .69787 Mdot
.38038 .65325 Mdot
.23442 .5562 Mdot
.4042 .33533 Mdot
.7539 .45516 Mdot
.65397 .54325 Mdot
.30991 .49044 Mdot
.65257 .556 Mdot
.70689 .74781 Mdot
.33205 .50451 Mdot
.35092 .24218 Mdot
.28961 .49655 Mdot
.3347 .32131 Mdot
.42294 .6403 Mdot
.72997 .58298 Mdot
.39497 .33188 Mdot
.59013 .37071 Mdot
.46728 .38917 Mdot
.49515 .60486 Mdot
.72937 .36372 Mdot
.70323 .58153 Mdot
.6181 .24193 Mdot
.58076 .39084 Mdot
.61571 .40278 Mdot
.4724 .6563 Mdot
.34617 .34289 Mdot
.52405 .62544 Mdot
.33247 .54388 Mdot
.32397 .63818 Mdot
.46512 .75144 Mdot
.50204 .66832 Mdot
.41014 .32415 Mdot
.50776 .65357 Mdot
.48801 .54915 Mdot
.54267 .82171 Mdot
.4711 .70135 Mdot
.7393 .33773 Mdot
.37293 .43417 Mdot
.67214 .53317 Mdot
.54061 .61389 Mdot
.60775 .24724 Mdot
.50352 .63634 Mdot
.32716 .80791 Mdot
.33859 .49314 Mdot
.40086 .39724 Mdot
.42493 .62529 Mdot
.48015 .64533 Mdot
.57365 .79306 Mdot
.74563 .55283 Mdot
.5949 .27751 Mdot
.448 .62539 Mdot
.32902 .60707 Mdot
.55513 .41012 Mdot
.52711 .65211 Mdot
.46578 .62257 Mdot
.4215 .78319 Mdot
.5681 .41648 Mdot
.40197 .34062 Mdot
.60607 .23491 Mdot
.40598 .31647 Mdot
.37371 .49745 Mdot
.51777 .4647 Mdot
.39045 .74422 Mdot
.737 .45511 Mdot
.3592 .47342 Mdot
.42927 .62349 Mdot
.38606 .59894 Mdot
.49306 .63373 Mdot
.35301 .51505 Mdot
.57387 .41951 Mdot
.65743 .55461 Mdot
.63785 .48549 Mdot
.61027 .25664 Mdot
.49608 .58337 Mdot
.35552 .51831 Mdot
.66749 .54885 Mdot
.42392 .25227 Mdot
.67158 .53954 Mdot
.56468 .38475 Mdot
.58378 .42635 Mdot
.33142 .49998 Mdot
.6531 .55786 Mdot
.42515 .3128 Mdot
.25347 .37696 Mdot
.52111 .65252 Mdot
.52094 .3718 Mdot
.70053 .5225 Mdot
.63011 .55716 Mdot
.71351 .56593 Mdot
.46604 .65512 Mdot
.46445 .43988 Mdot
.53431 .62834 Mdot
.55634 .38083 Mdot
.43637 .36554 Mdot
.40004 .75237 Mdot
.57833 .79984 Mdot
.56364 .45724 Mdot
.45574 .58061 Mdot
.49366 .6125 Mdot
.47068 .6189 Mdot
.47239 .68069 Mdot
.25671 .46715 Mdot
.46812 .64442 Mdot
.55733 .39342 Mdot
.43176 .32954 Mdot
.47627 .65903 Mdot
.60859 .2448 Mdot
.46424 .4567 Mdot
.33643 .46746 Mdot
.49313 .47754 Mdot
.21592 .32871 Mdot
.66664 .54978 Mdot
.39091 .35473 Mdot
.44421 .351 Mdot
.32783 .47404 Mdot
.58033 .36868 Mdot
.66719 .54046 Mdot
.26911 .59939 Mdot
.32028 .48797 Mdot
.46108 .62764 Mdot
.37615 .42006 Mdot
.791 .34996 Mdot
.42716 .64546 Mdot
.45073 .64282 Mdot
.61142 .23385 Mdot
.37724 .35074 Mdot
.21335 .68164 Mdot
.44519 .43086 Mdot
.33626 .50255 Mdot
.35071 .51123 Mdot
.71407 .56758 Mdot
.52269 .6005 Mdot
.5676 .39909 Mdot
.41733 .44679 Mdot
.28593 .68329 Mdot
.48077 .35915 Mdot
.54856 .19873 Mdot
.44658 .66359 Mdot
.57716 .78216 Mdot
.51578 .65125 Mdot
.65707 .59108 Mdot
.69356 .58072 Mdot
.67097 .56039 Mdot
.55869 .38476 Mdot
.76098 .63466 Mdot
.5577 .39657 Mdot
.2059 .33498 Mdot
.6459 .54429 Mdot
.29141 .3717 Mdot
.41366 .3544 Mdot
.42105 .60645 Mdot
.32373 .5047 Mdot
.5793 .45183 Mdot
.52315 .58069 Mdot
.75791 .40373 Mdot
.40425 .35832 Mdot
.6852 .52713 Mdot
.534 .56865 Mdot
.15629 .5082 Mdot
.50554 .44463 Mdot
.43912 .53251 Mdot
.66874 .76886 Mdot
.33126 .50585 Mdot
.60514 .6432 Mdot
.3156 .49734 Mdot
.5932 .38568 Mdot
.49272 .60352 Mdot
.48256 .5994 Mdot
.5075 .66457 Mdot
.46613 .64633 Mdot
.55068 .39879 Mdot
.48031 .68544 Mdot
.6234 .82321 Mdot
.60284 .24024 Mdot
.23537 .43088 Mdot
.35553 .47644 Mdot
.61081 .40158 Mdot
.42238 .32687 Mdot
.62147 .25911 Mdot
.36413 .73256 Mdot
.45621 .67601 Mdot
.44515 .64765 Mdot
.60165 .27475 Mdot
.51031 .57582 Mdot
.54171 .57791 Mdot
.43635 .34663 Mdot
.56494 .46433 Mdot
.36764 .50231 Mdot
.36144 .47942 Mdot
.60272 .40611 Mdot
.65236 .5566 Mdot
.33975 .47876 Mdot
.38183 .36509 Mdot
.47393 .68803 Mdot
.47911 .58812 Mdot
.70008 .52243 Mdot
.6823 .77159 Mdot
.35684 .5207 Mdot
.50519 .55929 Mdot
.64688 .55958 Mdot
.712 .57635 Mdot
.44569 .62687 Mdot
.43968 .7 Mdot
.63518 .54454 Mdot
.34785 .47077 Mdot
.61161 .39974 Mdot
.32087 .33298 Mdot
.58989 .37999 Mdot
.6655 .5435 Mdot
.48657 .69056 Mdot
.67108 .52758 Mdot
.49972 .63918 Mdot
.67049 .17702 Mdot
.47353 .59898 Mdot
.79609 .53984 Mdot
.28574 .63493 Mdot
.44432 .34681 Mdot
.421 .3121 Mdot
.60422 .24417 Mdot
.64541 .55818 Mdot
.48871 .59617 Mdot
.34187 .51269 Mdot
.29209 .27522 Mdot
.72647 .53438 Mdot
.43645 .37089 Mdot
.37747 .34126 Mdot
.56259 .41708 Mdot
.43367 .65523 Mdot
.44712 .61499 Mdot
.39844 .35039 Mdot
.23889 .53553 Mdot
.65846 .57589 Mdot
.47815 .61222 Mdot
.49616 .61484 Mdot
.43984 .34389 Mdot
.25193 .38399 Mdot
.73188 .58791 Mdot
.48398 .60297 Mdot
.29668 .47642 Mdot
.58243 .42442 Mdot
.47814 .67884 Mdot
.47896 .68495 Mdot
.3567 .50109 Mdot
.2192 .44599 Mdot
.49888 .81445 Mdot
.60326 .41267 Mdot
.62058 .25355 Mdot
.45224 .59734 Mdot
.41557 .35392 Mdot
.46439 .58999 Mdot
.19433 .54624 Mdot
.60905 .23769 Mdot
.47428 .63676 Mdot
.53295 .59973 Mdot
.7065 .56082 Mdot
.4749 .6412 Mdot
.48881 .75984 Mdot
.41768 .31695 Mdot
.47347 .63908 Mdot
.66362 .75961 Mdot
.55391 .41076 Mdot
.5372 .60533 Mdot
.36421 .50242 Mdot
.27429 .62637 Mdot
.66887 .41827 Mdot
.38968 .3114 Mdot
.34817 .47336 Mdot
.44898 .60362 Mdot
.38156 .35875 Mdot
.59117 .3695 Mdot
.73918 .38062 Mdot
.4451 .67779 Mdot
.58701 .37683 Mdot
.58837 .38899 Mdot
.33315 .49692 Mdot
.83123 .54031 Mdot
.49742 .56994 Mdot
.45316 .60466 Mdot
.36878 .77036 Mdot
.70044 .58126 Mdot
.44851 .60669 Mdot
.42972 .64189 Mdot
.57364 .40399 Mdot
.56773 .55632 Mdot
.64997 .61587 Mdot
.31945 .4295 Mdot
.59098 .42054 Mdot
.39463 .30218 Mdot
.38217 .35878 Mdot
.35413 .47627 Mdot
.67827 .53482 Mdot
.35342 .46753 Mdot
.42803 .35928 Mdot
.45549 .66868 Mdot
.58563 .40417 Mdot
.58764 .70086 Mdot
.55421 .36093 Mdot
.43485 .38083 Mdot
.63667 .57855 Mdot
.64353 .41296 Mdot
.45846 .8401 Mdot
.68476 .42399 Mdot
.61706 .3773 Mdot
.34657 .50704 Mdot
.38991 .42713 Mdot
.49421 .61385 Mdot
.63606 .63094 Mdot
.43318 .62805 Mdot
.66207 .77162 Mdot
.41117 .37084 Mdot
.61146 .27132 Mdot
.49262 .6031 Mdot
.33159 .64348 Mdot
.61705 .38668 Mdot
.55816 .41546 Mdot
.45792 .64623 Mdot
.56326 .38719 Mdot
.45981 .60613 Mdot
.43694 .33135 Mdot
.81957 .56368 Mdot
.48927 .61165 Mdot
.5106 .69004 Mdot
.6082 .3544 Mdot
.35651 .2418 Mdot
.4447 .32254 Mdot
.57514 .7851 Mdot
.15421 .54177 Mdot
.56463 .38926 Mdot
.53775 .65662 Mdot
.39382 .33993 Mdot
.61218 .23369 Mdot
.4585 .34766 Mdot
.43445 .63832 Mdot
.44821 .65937 Mdot
.51898 .62956 Mdot
.49783 .62201 Mdot
.62856 .62816 Mdot
.56495 .60918 Mdot
.59034 .76083 Mdot
.44657 .64752 Mdot
.62252 .51936 Mdot
.55425 .39622 Mdot
.62702 .59027 Mdot
.31658 .51875 Mdot
.45075 .66561 Mdot
.74431 .54025 Mdot
.60714 .40712 Mdot
.20518 .34006 Mdot
.56519 .41697 Mdot
.41623 .33357 Mdot
.54081 .37347 Mdot
.49661 .64345 Mdot
.69235 .54921 Mdot
.42564 .32058 Mdot
.67911 .3246 Mdot
.44521 .35728 Mdot
.48009 .65354 Mdot
.25245 .40891 Mdot
.44294 .35147 Mdot
.47197 .46323 Mdot
.69067 .54452 Mdot
.33475 .60387 Mdot
.67707 .58622 Mdot
.47884 .63575 Mdot
.48312 .63241 Mdot
.62416 .25199 Mdot
.56946 .3616 Mdot
.64202 .56776 Mdot
.74161 .7539 Mdot
.37005 .47741 Mdot
.6781 .56345 Mdot
.41189 .64022 Mdot
.4607 .4357 Mdot
.69546 .56858 Mdot
.29775 .59798 Mdot
.58333 .36839 Mdot
.71952 .55427 Mdot
.41135 .65994 Mdot
.57852 .51507 Mdot
.31599 .50766 Mdot
.43852 .37695 Mdot
.56403 .49294 Mdot
.39561 .32923 Mdot
.60378 .41538 Mdot
.38715 .37785 Mdot
.55511 .40876 Mdot
.7767 .5687 Mdot
.74956 .58652 Mdot
.56909 .35599 Mdot
.59109 .42555 Mdot
.42498 .35415 Mdot
.46485 .67767 Mdot
.45705 .49473 Mdot
.43334 .60009 Mdot
.42561 .65525 Mdot
.549 .40496 Mdot
.64733 .57339 Mdot
.64506 .53641 Mdot
.70776 .59804 Mdot
.69991 .53502 Mdot
.421 .32519 Mdot
.75716 .46556 Mdot
.72398 .72152 Mdot
.60099 .4038 Mdot
.54185 .41686 Mdot
.51501 .6339 Mdot
.41883 .35445 Mdot
.39847 .3725 Mdot
.57864 .40049 Mdot
.61785 .66081 Mdot
.52874 .6681 Mdot
.65336 .58689 Mdot
.64673 .54289 Mdot
.69049 .57052 Mdot
.7141 .55362 Mdot
.73258 .63523 Mdot
.5897 .37015 Mdot
.64516 .55113 Mdot
.46371 .64172 Mdot
.44226 .65448 Mdot
.61571 .25867 Mdot
.36526 .49062 Mdot
.44377 .68743 Mdot
.48183 .69994 Mdot
.44419 .6271 Mdot
.43999 .35617 Mdot
.42597 .70368 Mdot
.61432 .24195 Mdot
.37922 .37004 Mdot
.38309 .32263 Mdot
.60684 .27102 Mdot
.59914 .58079 Mdot
.14891 .51502 Mdot
.5118 .64999 Mdot
.40124 .54716 Mdot
.4177 .34946 Mdot
.79203 .47366 Mdot
.62165 .51205 Mdot
.49865 .67076 Mdot
.54253 .51948 Mdot
.43278 .32498 Mdot
.69746 .58498 Mdot
.43908 .6178 Mdot
.59366 .26278 Mdot
.33221 .46879 Mdot
.41113 .63611 Mdot
.60872 .23325 Mdot
.65741 .56355 Mdot
.37647 .53534 Mdot
.71892 .56254 Mdot
.44214 .33142 Mdot
.53601 .6011 Mdot
.25393 .22296 Mdot
.38863 .33853 Mdot
.29212 .29119 Mdot
.74167 .59064 Mdot
.48899 .60937 Mdot
.39076 .33311 Mdot
.68619 .58945 Mdot
.57676 .42506 Mdot
.43451 .45352 Mdot
.65568 .53792 Mdot
.61936 .2628 Mdot
.61089 .26449 Mdot
.43833 .34677 Mdot
.69051 .53534 Mdot
.51702 .6676 Mdot
.70039 .57303 Mdot
.54015 .37245 Mdot
.48677 .66974 Mdot
.16777 .46396 Mdot
.5475 .66239 Mdot
.64722 .56529 Mdot
.41336 .3816 Mdot
.32598 .51431 Mdot
.47031 .6726 Mdot
.25795 .332 Mdot
.43071 .64799 Mdot
.58114 .41675 Mdot
.79612 .42644 Mdot
.575 .70634 Mdot
.45802 .67109 Mdot
.51378 .63147 Mdot
.60748 .40071 Mdot
.46091 .67565 Mdot
.42842 .64709 Mdot
.59548 .33983 Mdot
.70509 .55885 Mdot
.47431 .62348 Mdot
.41488 .37623 Mdot
.5685 .81035 Mdot
.45173 .59699 Mdot
.72335 .31671 Mdot
.33487 .61962 Mdot
.80024 .44849 Mdot
.46476 .59245 Mdot
.35946 .68704 Mdot
.48531 .6264 Mdot
.46321 .6615 Mdot
.50767 .65922 Mdot
.56422 .77726 Mdot
.42397 .35738 Mdot
.44336 .36978 Mdot
.31401 .50586 Mdot
.3324 .61892 Mdot
.35897 .48947 Mdot
.59741 .41359 Mdot
.48278 .19275 Mdot
.60528 .2391 Mdot
.65142 .55606 Mdot
.51477 .61127 Mdot
.4443 .33181 Mdot
.43932 .62618 Mdot
.50063 .64227 Mdot
.43876 .33031 Mdot
.38393 .34645 Mdot
.3923 .38798 Mdot
.3168 .49685 Mdot
.6636 .55554 Mdot
.49754 .67832 Mdot
.32562 .48168 Mdot
.52033 .66509 Mdot
.44724 .43447 Mdot
.66425 .55798 Mdot
.70201 .57149 Mdot
.63756 .56477 Mdot
.45376 .66866 Mdot
.49235 .64911 Mdot
.55838 .39795 Mdot
.69732 .51989 Mdot
.60495 .39529 Mdot
.3992 .32801 Mdot
.43154 .31791 Mdot
.43468 .63931 Mdot
.51215 .55953 Mdot
.34894 .51073 Mdot
.4111 .33431 Mdot
.59934 .27502 Mdot
.31224 .49995 Mdot
.47159 .66117 Mdot
.40725 .32558 Mdot
.36344 .48111 Mdot
.63505 .67516 Mdot
.16996 .57606 Mdot
.33241 .51802 Mdot
.45884 .64422 Mdot
.5804 .7942 Mdot
.31954 .55025 Mdot
.36293 .4688 Mdot
.59666 .40524 Mdot
.4326 .65028 Mdot
.24109 .62818 Mdot
.36734 .48006 Mdot
.66427 .77855 Mdot
.44324 .34346 Mdot
.55452 .55022 Mdot
.4138 .66846 Mdot
.65878 .63895 Mdot
.35713 .46809 Mdot
.6718 .54283 Mdot
.69381 .51572 Mdot
.45975 .63527 Mdot
.29893 .49751 Mdot
.53905 .39799 Mdot
.44591 .34379 Mdot
.42243 .30784 Mdot
.69633 .54041 Mdot
.69395 .46456 Mdot
.41462 .37866 Mdot
.43989 .56907 Mdot
.36403 .38113 Mdot
.50185 .70938 Mdot
.77695 .58552 Mdot
.66987 .32536 Mdot
.48557 .58879 Mdot
.33735 .51759 Mdot
.6084 .38244 Mdot
.55925 .39378 Mdot
.56635 .37987 Mdot
.41098 .31157 Mdot
.50124 .46599 Mdot
.40263 .36009 Mdot
.72535 .37187 Mdot
.32933 .49089 Mdot
.32695 .58367 Mdot
.48552 .59662 Mdot
.49162 .61226 Mdot
.51531 .67309 Mdot
.52035 .62114 Mdot
.48493 .6245 Mdot
.57471 .36985 Mdot
.39629 .31623 Mdot
.33656 .39438 Mdot
.67986 .5718 Mdot
.44514 .23811 Mdot
.4133 .35445 Mdot
.60986 .23473 Mdot
.347 .49651 Mdot
.37646 .70692 Mdot
.36586 .33959 Mdot
.40937 .35042 Mdot
.46115 .6875 Mdot
.67072 .5841 Mdot
.57718 .62427 Mdot
.48921 .62826 Mdot
.40852 .33462 Mdot
.47228 .34929 Mdot
.58766 .66145 Mdot
.39512 .65282 Mdot
.38044 .48052 Mdot
.46523 .43602 Mdot
.33193 .46436 Mdot
.44322 .69886 Mdot
.79141 .47026 Mdot
.42858 .35787 Mdot
.42465 .33499 Mdot
.35685 .51644 Mdot
.42232 .55508 Mdot
.68683 .53586 Mdot
.61062 .27227 Mdot
.58342 .41331 Mdot
.49042 .63321 Mdot
.41118 .31374 Mdot
.4509 .54021 Mdot
.36112 .39216 Mdot
.57323 .37515 Mdot
.37845 .36894 Mdot
.44067 .66449 Mdot
.45625 .64492 Mdot
.33427 .50697 Mdot
.41392 .52117 Mdot
.41483 .62553 Mdot
.27287 .28821 Mdot
.74416 .46961 Mdot
.74282 .49102 Mdot
.44583 .62199 Mdot
.70094 .54391 Mdot
.59573 .26459 Mdot
.32174 .49464 Mdot
.49231 .68531 Mdot
.15917 .56079 Mdot
.65347 .52022 Mdot
.58412 .38134 Mdot
.59777 .26819 Mdot
.49907 .46572 Mdot
.42972 .64469 Mdot
.43347 .62724 Mdot
.46603 .65089 Mdot
.16266 .58716 Mdot
.43154 .37404 Mdot
.71376 .56156 Mdot
.34473 .48123 Mdot
.71096 .54936 Mdot
.44453 .36562 Mdot
.63795 .47896 Mdot
.47572 .66191 Mdot
.64841 .58561 Mdot
.67448 .54217 Mdot
.56318 .41752 Mdot
.55924 .41942 Mdot
.38137 .38226 Mdot
.47346 .59959 Mdot
.59247 .2572 Mdot
.68565 .58405 Mdot
.38208 .33756 Mdot
.33138 .50473 Mdot
.55642 .37479 Mdot
.44762 .64899 Mdot
.43378 .35308 Mdot
.51071 .59232 Mdot
.69147 .57518 Mdot
.41021 .35065 Mdot
.5942 .2434 Mdot
.35683 .5078 Mdot
.44794 .65562 Mdot
.37885 .51925 Mdot
.60395 .27321 Mdot
.4999 .61527 Mdot
.4307 .75472 Mdot
.31439 .5227 Mdot
.68077 .32119 Mdot
.3959 .35825 Mdot
.61302 .24859 Mdot
.70034 .57672 Mdot
.59334 .52096 Mdot
.42581 .33284 Mdot
.4198 .73608 Mdot
.44523 .50859 Mdot
.49384 .67969 Mdot
.69083 .55971 Mdot
.34445 .43773 Mdot
.23068 .32683 Mdot
.28796 .53236 Mdot
.47757 .61526 Mdot
.39184 .33158 Mdot
.35742 .47495 Mdot
.5984 .40765 Mdot
.72587 .3186 Mdot
.75792 .60023 Mdot
.3787 .37258 Mdot
.51325 .65021 Mdot
.68454 .5841 Mdot
.5803 .39914 Mdot
.655 .35147 Mdot
.3849 .36963 Mdot
.40531 .36976 Mdot
.46865 .66558 Mdot
.33431 .48065 Mdot
.24544 .51214 Mdot
.44504 .3698 Mdot
.40313 .31656 Mdot
.43597 .23765 Mdot
.34875 .5214 Mdot
.46436 .63703 Mdot
.70887 .59759 Mdot
.45657 .68217 Mdot
.29404 .2823 Mdot
.61226 .24287 Mdot
.67771 .57299 Mdot
.43766 .65117 Mdot
.36226 .41697 Mdot
.41766 .32825 Mdot
.47508 .43636 Mdot
.42188 .38497 Mdot
.57671 .36867 Mdot
.414 .3135 Mdot
.44059 .6181 Mdot
.61761 .38845 Mdot
.3517 .50933 Mdot
.4828 .60233 Mdot
.49301 .64981 Mdot
.67589 .59243 Mdot
.59502 .38769 Mdot
.47911 .79791 Mdot
.57927 .4296 Mdot
.60999 .39299 Mdot
.72429 .54621 Mdot
.46036 .63155 Mdot
.41374 .33781 Mdot
.44465 .37611 Mdot
.5014 .67925 Mdot
.79041 .48348 Mdot
.69213 .53902 Mdot
.37211 .3753 Mdot
.21177 .67599 Mdot
.40981 .59824 Mdot
.59038 .25834 Mdot
.38437 .59218 Mdot
.56321 .41953 Mdot
.45238 .64857 Mdot
.64975 .56663 Mdot
.39408 .32189 Mdot
.41501 .37835 Mdot
.49653 .68538 Mdot
.58828 .39446 Mdot
.34498 .46733 Mdot
.39873 .36894 Mdot
.35525 .37398 Mdot
.47239 .64631 Mdot
.72909 .36004 Mdot
.39367 .36281 Mdot
.32246 .23522 Mdot
.34738 .40004 Mdot
.69066 .56484 Mdot
.50155 .64445 Mdot
.68529 .52275 Mdot
.34978 .48354 Mdot
.41499 .29852 Mdot
.5903 .39126 Mdot
.38999 .63013 Mdot
.52243 .83302 Mdot
.42037 .35866 Mdot
.65607 .5584 Mdot
.45595 .6713 Mdot
.40287 .59865 Mdot
.45831 .60039 Mdot
.57309 .55924 Mdot
.3411 .53349 Mdot
.54767 .40449 Mdot
.5849 .41685 Mdot
.51279 .62394 Mdot
.31801 .48791 Mdot
.4541 .35656 Mdot
.4423 .33981 Mdot
.84261 .3611 Mdot
.59454 .24218 Mdot
.3093 .65328 Mdot
.45017 .65904 Mdot
.38197 .33401 Mdot
.57171 .80133 Mdot
.59809 .3841 Mdot
.5254 .63041 Mdot
.39217 .3138 Mdot
.45567 .28595 Mdot
.44707 .43673 Mdot
.47649 .6296 Mdot
.45619 .56872 Mdot
.58487 .41421 Mdot
.4095 .43968 Mdot
.40154 .35764 Mdot
.5258 .64527 Mdot
.58804 .42816 Mdot
.41057 .24086 Mdot
.59351 .83234 Mdot
.6641 .55587 Mdot
.43338 .38206 Mdot
.57687 .36932 Mdot
.4179 .60631 Mdot
.3555 .47607 Mdot
.4078 .31966 Mdot
.44181 .35914 Mdot
.49339 .66364 Mdot
.43486 .68 Mdot
.40851 .59928 Mdot
.66863 .56712 Mdot
.56241 .40558 Mdot
.501 .6055 Mdot
.70297 .46588 Mdot
.51988 .62968 Mdot
.56423 .40421 Mdot
.43903 .10577 Mdot
.44646 .68002 Mdot
.45836 .60166 Mdot
.25554 .51351 Mdot
.6588 .53174 Mdot
.70783 .54488 Mdot
.7515 .46944 Mdot
.44996 .65875 Mdot
.33854 .33074 Mdot
.66217 .55284 Mdot
.69442 .5426 Mdot
.28154 .38493 Mdot
.48811 .67193 Mdot
.42041 .43041 Mdot
.56895 .40049 Mdot
.56803 .36721 Mdot
.7033 .5661 Mdot
.41654 .61325 Mdot
.60281 .37908 Mdot
.66122 .62521 Mdot
.4124 .35776 Mdot
.79158 .46876 Mdot
.67716 .58107 Mdot
.41101 .51055 Mdot
.58975 .37656 Mdot
.20739 .32483 Mdot
.55759 .5114 Mdot
.51965 .64213 Mdot
.45453 .65569 Mdot
.35811 .50148 Mdot
.54426 .59536 Mdot
.62097 .25096 Mdot
.56282 .38598 Mdot
.21602 .48555 Mdot
.67221 .56068 Mdot
.46812 .60062 Mdot
.38219 .71656 Mdot
.66916 .36928 Mdot
.74609 .34508 Mdot
.6718 .53396 Mdot
.68616 .55863 Mdot
.41121 .36529 Mdot
.42698 .36623 Mdot
.46886 .63049 Mdot
.55693 .38797 Mdot
.71352 .53215 Mdot
.57393 .41112 Mdot
.42919 .35876 Mdot
.41171 .34628 Mdot
.61059 .23763 Mdot
.49635 .57821 Mdot
.44208 .33409 Mdot
.39508 .24566 Mdot
.69192 .46763 Mdot
.68125 .59309 Mdot
.44505 .83077 Mdot
.65207 .34736 Mdot
.24505 .56728 Mdot
.32034 .4752 Mdot
.58908 .27655 Mdot
.5435 .38046 Mdot
.51283 .6284 Mdot
.44028 .63996 Mdot
.60509 .26112 Mdot
.56035 .36339 Mdot
.34936 .50034 Mdot
.56793 .36138 Mdot
.32773 .48726 Mdot
.44579 .32732 Mdot
.45214 .59692 Mdot
.42902 .63031 Mdot
.5717 .37148 Mdot
.40114 .3438 Mdot
.44431 .3387 Mdot
.31427 .48792 Mdot
.36679 .67441 Mdot
.43797 .34858 Mdot
.67996 .58064 Mdot
.71944 .68865 Mdot
.60974 .26434 Mdot
.44195 .61411 Mdot
.38584 .73122 Mdot
.61033 .64751 Mdot
.50664 .67015 Mdot
.59908 .26989 Mdot
.85271 .40114 Mdot
.48002 .59698 Mdot
.84628 .4356 Mdot
.61533 .25029 Mdot
.66136 .52885 Mdot
.38987 .34531 Mdot
.6218 .25162 Mdot
.40784 .63048 Mdot
.36702 .46622 Mdot
.45182 .69458 Mdot
.65759 .53581 Mdot
.63642 .56988 Mdot
.77758 .5329 Mdot
.29477 .28303 Mdot
.3213 .50678 Mdot
.34043 .50064 Mdot
.42922 .33412 Mdot
.52942 .16725 Mdot
.41534 .66751 Mdot
.34099 .50297 Mdot
.2234 .5091 Mdot
.51386 .63716 Mdot
.32522 .67138 Mdot
.54008 .51691 Mdot
.69995 .54345 Mdot
.61062 .58533 Mdot
.42352 .33002 Mdot
.6566 .55805 Mdot
.69036 .47767 Mdot
.51271 .67532 Mdot
.66668 .5595 Mdot
.56881 .40538 Mdot
.5429 .31609 Mdot
.68679 .52549 Mdot
.41804 .45591 Mdot
.56818 .39845 Mdot
.31556 .52603 Mdot
.26682 .54292 Mdot
.3302 .82003 Mdot
.56143 .38594 Mdot
.39817 .33604 Mdot
.44115 .33084 Mdot
.43963 .33864 Mdot
.65481 .53804 Mdot
.39002 .36965 Mdot
.66764 .57153 Mdot
.26459 .34687 Mdot
.36834 .70378 Mdot
.32979 .49882 Mdot
.55235 .34765 Mdot
.68186 .54924 Mdot
.73829 .41862 Mdot
.46676 .83688 Mdot
.45913 .64668 Mdot
.58409 .42897 Mdot
.35744 .5154 Mdot
.46517 .15611 Mdot
.35746 .49991 Mdot
.39339 .3411 Mdot
.79193 .46475 Mdot
.4624 .60609 Mdot
.47753 .7606 Mdot
.34961 .51297 Mdot
.66599 .53439 Mdot
.49747 .61391 Mdot
.42522 .38881 Mdot
.35152 .47618 Mdot
.33571 .46838 Mdot
.48507 .62023 Mdot
.68971 .53016 Mdot
.41124 .34217 Mdot
.5452 .38143 Mdot
.35636 .52577 Mdot
.44239 .58092 Mdot
.47429 .68151 Mdot
.53071 .62373 Mdot
.49505 .44675 Mdot
.2271 .57645 Mdot
.56547 .39055 Mdot
.35948 .56932 Mdot
.4329 .36211 Mdot
.28473 .50359 Mdot
.71483 .43083 Mdot
.57341 .34467 Mdot
.61312 .2437 Mdot
.60984 .24062 Mdot
.47949 .62691 Mdot
.22462 .56697 Mdot
.78917 .37794 Mdot
.62376 .37448 Mdot
.60512 .26677 Mdot
.44487 .34115 Mdot
.67911 .51424 Mdot
.77027 .53508 Mdot
.42718 .66928 Mdot
.55094 .4121 Mdot
.43744 .35259 Mdot
.19453 .55109 Mdot
.33261 .48979 Mdot
.76931 .45722 Mdot
.47892 .6574 Mdot
.47571 .60883 Mdot
.57615 .39189 Mdot
.55873 .39731 Mdot
.72293 .33127 Mdot
.75997 .49644 Mdot
.48042 .34307 Mdot
.60068 .32695 Mdot
.19911 .57829 Mdot
.63597 .59555 Mdot
.64941 .56917 Mdot
.60281 .23622 Mdot
.61258 .38568 Mdot
.4357 .62054 Mdot
.65372 .53149 Mdot
.74914 .34765 Mdot
.68695 .50772 Mdot
.3254 .65905 Mdot
.34209 .34349 Mdot
.49018 .64345 Mdot
.67844 .58381 Mdot
.6588 .55811 Mdot
.7123 .54402 Mdot
.60515 .27092 Mdot
.44795 .62329 Mdot
.46434 .6771 Mdot
.49657 .60641 Mdot
.51454 .56915 Mdot
.47432 .64323 Mdot
.70782 .43827 Mdot
.56699 .45693 Mdot
.21569 .46721 Mdot
.51066 .66486 Mdot
.57732 .36534 Mdot
.51436 .60807 Mdot
.31988 .48315 Mdot
.51385 .6502 Mdot
.31676 .66186 Mdot
.57365 .38085 Mdot
.41685 .55946 Mdot
.60874 .33007 Mdot
.48007 .65741 Mdot
.36081 .47501 Mdot
.22929 .56236 Mdot
.47232 .80649 Mdot
.43202 .24153 Mdot
.68297 .57997 Mdot
.36738 .34778 Mdot
.53944 .37155 Mdot
.41613 .33784 Mdot
.52123 .6467 Mdot
.59388 .24903 Mdot
.61944 .30208 Mdot
.41744 .50156 Mdot
.43134 .63622 Mdot
.51596 .69538 Mdot
.70074 .55867 Mdot
.40375 .32839 Mdot
.62019 .55402 Mdot
.46385 .65768 Mdot
.34614 .47956 Mdot
.33706 .47703 Mdot
.74425 .48443 Mdot
.18349 .48648 Mdot
.59372 .5365 Mdot
.57344 .39221 Mdot
.42077 .38053 Mdot
.35933 .46994 Mdot
.75126 .59197 Mdot
.54017 .40131 Mdot
.5624 .4191 Mdot
.59492 .39406 Mdot
.49265 .63689 Mdot
.6177 .24496 Mdot
.20733 .50667 Mdot
.62075 .25975 Mdot
.484 .65537 Mdot
.43724 .36683 Mdot
.62225 .2486 Mdot
.36057 .49548 Mdot
.60009 .40879 Mdot
.42483 .36403 Mdot
.48077 .63605 Mdot
.66768 .55197 Mdot
.36799 .64661 Mdot
.28234 .66058 Mdot
.24307 .38364 Mdot
.24019 .39273 Mdot
.63919 .55611 Mdot
.19253 .38698 Mdot
.52124 .37159 Mdot
.61786 .65869 Mdot
.3691 .4555 Mdot
.50684 .67575 Mdot
.80712 .60878 Mdot
.39934 .35591 Mdot
.42494 .32314 Mdot
.47389 .63277 Mdot
.38373 .33961 Mdot
.46532 .59968 Mdot
.41623 .36968 Mdot
.38959 .265 Mdot
.42142 .65108 Mdot
.42483 .32434 Mdot
.42343 .68544 Mdot
.47419 .67066 Mdot
.70381 .55192 Mdot
.40238 .32044 Mdot
.52165 .63385 Mdot
.53602 .15658 Mdot
.55268 .38675 Mdot
.60724 .26997 Mdot
.51675 .42539 Mdot
.58594 .36975 Mdot
.68083 .56582 Mdot
.42089 .63188 Mdot
.33938 .50985 Mdot
.67154 .54542 Mdot
.38343 .38372 Mdot
.34976 .51428 Mdot
.75425 .46405 Mdot
.69042 .57723 Mdot
.61078 .26139 Mdot
.3477 .51185 Mdot
.52948 .67771 Mdot
.42699 .31853 Mdot
.29433 .69612 Mdot
.61842 .26254 Mdot
.44694 .61452 Mdot
.4482 .32448 Mdot
.57724 .36359 Mdot
.46754 .62077 Mdot
.38947 .33371 Mdot
.60347 .27181 Mdot
.49982 .63348 Mdot
.50201 .62032 Mdot
.76024 .53112 Mdot
.77324 .38898 Mdot
.33534 .50637 Mdot
.68646 .58673 Mdot
.46484 .64117 Mdot
.31602 .49307 Mdot
.5242 .2143 Mdot
.50249 .59593 Mdot
.67481 .52141 Mdot
.4643 .74725 Mdot
.42933 .36662 Mdot
.60513 .3969 Mdot
.4407 .37997 Mdot
.3304 .46899 Mdot
.7765 .72412 Mdot
.61631 .23953 Mdot
.41281 .67556 Mdot
.52706 .65414 Mdot
.4667 .34099 Mdot
.66196 .56125 Mdot
.48753 .37333 Mdot
.44859 .65586 Mdot
.54669 .6668 Mdot
.47302 .60487 Mdot
.3444 .39507 Mdot
.69006 .53813 Mdot
.45302 .60531 Mdot
.54241 .57196 Mdot
.44587 .59893 Mdot
.35427 .47066 Mdot
.30402 .56709 Mdot
.51362 .60383 Mdot
.19425 .28276 Mdot
.60012 .27391 Mdot
.43862 .33096 Mdot
.39034 .29108 Mdot
.58253 .22141 Mdot
.77993 .5836 Mdot
.66753 .56943 Mdot
.47958 .72528 Mdot
.41332 .34 Mdot
.59633 .82258 Mdot
.21164 .35158 Mdot
.47655 .66814 Mdot
.44036 .66237 Mdot
.39339 .34105 Mdot
.38307 .33294 Mdot
.59814 .24424 Mdot
.51401 .65884 Mdot
.45977 .70898 Mdot
.38642 .37433 Mdot
.48059 .64456 Mdot
.5271 .72104 Mdot
.54517 .38896 Mdot
.70826 .55576 Mdot
.59911 .40705 Mdot
.55187 .41035 Mdot
.70186 .66423 Mdot
.74514 .4706 Mdot
.56146 .40279 Mdot
.58495 .43074 Mdot
.31797 .67209 Mdot
.43773 .73615 Mdot
.34937 .46616 Mdot
.20875 .41309 Mdot
.43617 .33895 Mdot
.44884 .62466 Mdot
.64166 .55977 Mdot
.67084 .64554 Mdot
.51131 .29313 Mdot
.78898 .44498 Mdot
.45695 .66321 Mdot
.42755 .32963 Mdot
.60948 .27078 Mdot
.42175 .65585 Mdot
.28513 .51169 Mdot
.47653 .61144 Mdot
.44188 .32939 Mdot
.74172 .66294 Mdot
.46878 .75448 Mdot
.39038 .42354 Mdot
.72044 .57383 Mdot
.49553 .60093 Mdot
.67446 .57847 Mdot
.58532 .37403 Mdot
.31731 .49255 Mdot
.34191 .50674 Mdot
.49589 .61558 Mdot
.75115 .58537 Mdot
.53439 .52009 Mdot
.47176 .67072 Mdot
.49121 .6671 Mdot
.61414 .24891 Mdot
.49005 .66792 Mdot
.5256 .65645 Mdot
.5118 .61316 Mdot
.48157 .58206 Mdot
.61049 .39195 Mdot
.44276 .76047 Mdot
.50312 .59053 Mdot
.39734 .63814 Mdot
.54801 .38663 Mdot
.45981 .72059 Mdot
.5618 .41529 Mdot
.16957 .46907 Mdot
.56936 .41484 Mdot
.33755 .50514 Mdot
.44027 .31567 Mdot
.53394 .68915 Mdot
.71702 .53733 Mdot
.58072 .42594 Mdot
.34289 .48797 Mdot
.56408 .38272 Mdot
.42607 .37613 Mdot
.39155 .79929 Mdot
.68582 .50754 Mdot
.42762 .43891 Mdot
.56794 .52873 Mdot
.72881 .35676 Mdot
.41373 .36224 Mdot
.69846 .54455 Mdot
.48699 .75792 Mdot
.51108 .61508 Mdot
.35622 .50677 Mdot
.4802 .62477 Mdot
.60897 .39662 Mdot
.433 .33308 Mdot
.24549 .41057 Mdot
.34002 .50819 Mdot
.5857 .84309 Mdot
.44742 .34967 Mdot
.43975 .67519 Mdot
.55172 .41429 Mdot
.44906 .8311 Mdot
.57224 .41602 Mdot
.37284 .7124 Mdot
.6294 .57216 Mdot
.75664 .66811 Mdot
.68881 .55436 Mdot
.74891 .33218 Mdot
.13158 .54234 Mdot
.24015 .33683 Mdot
.66197 .54493 Mdot
.37979 .4024 Mdot
.47747 .65414 Mdot
.51925 .60988 Mdot
.41868 .58424 Mdot
.69578 .58703 Mdot
.46688 .64319 Mdot
.61881 .25648 Mdot
.65363 .46656 Mdot
.27424 .45828 Mdot
.36595 .34701 Mdot
.45261 .60298 Mdot
.54846 .38968 Mdot
.57374 .3597 Mdot
.62244 .25259 Mdot
.53851 .39224 Mdot
.47485 .6742 Mdot
.6845 .55058 Mdot
.43976 .50067 Mdot
.35499 .48697 Mdot
.39772 .19805 Mdot
.33867 .5268 Mdot
.36648 .36033 Mdot
.5337 .60039 Mdot
.4112 .34707 Mdot
.85278 .59309 Mdot
.51647 .62511 Mdot
.6593 .55224 Mdot
.5004 .62457 Mdot
.50658 .60719 Mdot
.5216 .61237 Mdot
.39127 .37323 Mdot
.41932 .2919 Mdot
.48245 .64125 Mdot
.59113 .39075 Mdot
.22891 .42985 Mdot
.46201 .69779 Mdot
.39269 .39809 Mdot
.32441 .62406 Mdot
.72856 .37789 Mdot
.68991 .59167 Mdot
.40149 .33212 Mdot
.67745 .56038 Mdot
.72476 .56143 Mdot
.68069 .56594 Mdot
.20077 .48956 Mdot
.57687 .5869 Mdot
.8379 .38246 Mdot
.70199 .73147 Mdot
.6494 .65609 Mdot
.64592 .58199 Mdot
.53557 .24675 Mdot
.64802 .56088 Mdot
.67292 .56874 Mdot
.61525 .14058 Mdot
.6463 .55331 Mdot
.43539 .63908 Mdot
.45204 .68527 Mdot
.67924 .41578 Mdot
.33272 .69335 Mdot
.51214 .65599 Mdot
.46783 .63759 Mdot
.31891 .49938 Mdot
.48298 .5514 Mdot
.61843 .23136 Mdot
.77783 .47639 Mdot
.61015 .31211 Mdot
.48489 .62141 Mdot
.47095 .63812 Mdot
.43823 .58892 Mdot
.12911 .56135 Mdot
.68995 .63768 Mdot
.63518 .55874 Mdot
.51116 .7003 Mdot
.32694 .24751 Mdot
.441 .67234 Mdot
.42877 .62681 Mdot
.49941 .63925 Mdot
.41342 .33858 Mdot
.67146 .51419 Mdot
.52093 .69102 Mdot
.71148 .37315 Mdot
.47358 .66082 Mdot
.53318 .36156 Mdot
.35614 .52846 Mdot
.43848 .6217 Mdot
.71048 .54455 Mdot
.51053 .64872 Mdot
.6758 .58275 Mdot
.70532 .56212 Mdot
.46636 .57375 Mdot
.19974 .50363 Mdot
.69392 .52389 Mdot
.48906 .65102 Mdot
.4026 .33957 Mdot
.2364 .32482 Mdot
.44379 .61764 Mdot
.32238 .48944 Mdot
.45243 .65654 Mdot
.35634 .47287 Mdot
.48783 .66145 Mdot
.61905 .26284 Mdot
.56451 .71308 Mdot
.42656 .33567 Mdot
.37183 .44702 Mdot
.37948 .34898 Mdot
.74569 .51463 Mdot
.66344 .52603 Mdot
.61438 .22846 Mdot
.82259 .50863 Mdot
.61395 .2507 Mdot
.36871 .64494 Mdot
.4905 .25637 Mdot
.55734 .37951 Mdot
.71277 .55898 Mdot
.37394 .56447 Mdot
.38538 .39666 Mdot
.38303 .38049 Mdot
.38003 .32821 Mdot
.80235 .67437 Mdot
.82285 .55571 Mdot
.48707 .63521 Mdot
.29538 .71902 Mdot
.59618 .75098 Mdot
.46796 .58751 Mdot
.42248 .61926 Mdot
.44138 .3271 Mdot
.48565 .59732 Mdot
.48431 .46103 Mdot
.42423 .35467 Mdot
.34248 .49368 Mdot
.67585 .57392 Mdot
.35123 .47184 Mdot
.45546 .38551 Mdot
.58172 .46313 Mdot
.43006 .36158 Mdot
.48997 .58729 Mdot
.49391 .62542 Mdot
.69482 .57817 Mdot
.7346 .52468 Mdot
.7068 .55583 Mdot
.35318 .51562 Mdot
.42892 .34743 Mdot
.67086 .6362 Mdot
.45131 .64437 Mdot
.6764 .54154 Mdot
.59109 .44333 Mdot
.45577 .64564 Mdot
.5756 .37173 Mdot
.45887 .66909 Mdot
.65959 .54173 Mdot
.48953 .6678 Mdot
.68496 .5526 Mdot
.39992 .35185 Mdot
.44273 .67124 Mdot
.47128 .63316 Mdot
.50729 .81694 Mdot
.35053 .49951 Mdot
.66244 .52697 Mdot
.53098 .48623 Mdot
.4512 .67968 Mdot
.28854 .49563 Mdot
.4613 .59407 Mdot
.46609 .73469 Mdot
.42585 .68972 Mdot
.61755 .25722 Mdot
.52477 .60784 Mdot
.44554 .61511 Mdot
.45592 .76422 Mdot
.6226 .78001 Mdot
.62179 .53872 Mdot
.60221 .41329 Mdot
.71052 .54571 Mdot
.42885 .31655 Mdot
.39779 .31681 Mdot
.39344 .36783 Mdot
.35082 .70713 Mdot
.4216 .60478 Mdot
.46062 .60692 Mdot
.5695 .42496 Mdot
.33765 .49928 Mdot
.67059 .53579 Mdot
.33283 .49678 Mdot
.77948 .48091 Mdot
.35646 .51278 Mdot
.6207 .24855 Mdot
.34813 .40112 Mdot
.60935 .62911 Mdot
.32149 .50363 Mdot
.70731 .5553 Mdot
.34962 .37257 Mdot
.51399 .66834 Mdot
.41003 .25631 Mdot
.34471 .47918 Mdot
.75731 .73821 Mdot
.45531 .59707 Mdot
.45121 .45056 Mdot
.55172 .40291 Mdot
.36215 .48286 Mdot
.59458 .38472 Mdot
.51697 .63394 Mdot
.68296 .31928 Mdot
.65377 .55669 Mdot
.61623 .39464 Mdot
.52344 .60763 Mdot
.35455 .47416 Mdot
.44056 .35229 Mdot
.59341 .50299 Mdot
.57362 .36619 Mdot
.44154 .78574 Mdot
.28776 .53192 Mdot
.42764 .349 Mdot
.79667 .36073 Mdot
.59506 .40171 Mdot
.48159 .58692 Mdot
.55554 .67139 Mdot
.5025 .66831 Mdot
.4172 .31074 Mdot
.40704 .32625 Mdot
.66243 .45075 Mdot
.49829 .62606 Mdot
.45718 .59606 Mdot
.64872 .52 Mdot
.41826 .35664 Mdot
.69636 .5564 Mdot
.71639 .55235 Mdot
.39655 .33957 Mdot
.69208 .56347 Mdot
.35265 .51165 Mdot
.63281 .46612 Mdot
.59349 .4037 Mdot
.58791 .38658 Mdot
.4438 .34028 Mdot
.44616 .37077 Mdot
.41151 .3493 Mdot
.45955 .66892 Mdot
.67794 .53152 Mdot
.50212 .64863 Mdot
.51163 .60096 Mdot
.63642 .58671 Mdot
.64702 .53987 Mdot
.5084 .64207 Mdot
.37726 .4307 Mdot
.37119 .51537 Mdot
.4237 .32492 Mdot
.57083 .41023 Mdot
.60086 .81813 Mdot
.55697 .41908 Mdot
.45637 .59928 Mdot
.44582 .2776 Mdot
.66185 .53487 Mdot
.35829 .49973 Mdot
.29808 .50909 Mdot
.35314 .50669 Mdot
.61881 .37634 Mdot
.71442 .53938 Mdot
.75166 .46331 Mdot
.46244 .59814 Mdot
.49681 .44873 Mdot
.36605 .56972 Mdot
.71697 .42118 Mdot
.56518 .40525 Mdot
.46132 .6423 Mdot
.6138 .25303 Mdot
.59109 .65571 Mdot
.47315 .61194 Mdot
.52442 .63377 Mdot
.31623 .36402 Mdot
.39707 .63405 Mdot
.67168 .59388 Mdot
.77624 .52745 Mdot
.47245 .68707 Mdot
.65172 .60885 Mdot
.75524 .2464 Mdot
.46875 .59499 Mdot
.46844 .65215 Mdot
.44259 .6325 Mdot
.51148 .6316 Mdot
.63745 .58442 Mdot
.39628 .51169 Mdot
.55617 .41721 Mdot
.52059 .45067 Mdot
.58833 .40388 Mdot
.4225 .31845 Mdot
.4534 .45427 Mdot
.71149 .5583 Mdot
.35645 .50459 Mdot
.35892 .77065 Mdot
.78323 .50498 Mdot
.41086 .36467 Mdot
.7187 .63751 Mdot
.35218 .4825 Mdot
.50449 .67711 Mdot
.32035 .51603 Mdot
.38329 .33035 Mdot
.5827 .39917 Mdot
.45443 .68511 Mdot
.64375 .57013 Mdot
.68657 .525 Mdot
.46107 .64592 Mdot
.29251 .27616 Mdot
.5884 .3731 Mdot
.55619 .44479 Mdot
.49204 .63898 Mdot
.52442 .63511 Mdot
.69464 .56856 Mdot
.41288 .32745 Mdot
.48463 .22172 Mdot
.34828 .49376 Mdot
.46331 .57986 Mdot
.51477 .63981 Mdot
.77458 .4872 Mdot
.59972 .41063 Mdot
.59509 .25723 Mdot
.49506 .63432 Mdot
.74935 .47455 Mdot
.49679 .63348 Mdot
.54899 .59994 Mdot
.40657 .34457 Mdot
.49791 .68698 Mdot
.44613 .66508 Mdot
.39645 .55988 Mdot
.59906 .39586 Mdot
.66184 .55715 Mdot
.63145 .53945 Mdot
.59366 .26299 Mdot
.57265 .37294 Mdot
.50998 .64337 Mdot
.60689 .39638 Mdot
.52075 .61042 Mdot
.47989 .64089 Mdot
.56601 .40526 Mdot
.69632 .55704 Mdot
.507 .3571 Mdot
.41405 .73578 Mdot
.50748 .62832 Mdot
.47336 .68228 Mdot
.34111 .6962 Mdot
.82559 .46052 Mdot
.44667 .66083 Mdot
.66102 .53233 Mdot
.45754 .64109 Mdot
.58443 .37735 Mdot
.35967 .51166 Mdot
.6633 .54915 Mdot
.45067 .3597 Mdot
.39775 .35145 Mdot
.61452 .33508 Mdot
.61929 .24391 Mdot
.46599 .68191 Mdot
.63105 .51718 Mdot
.64294 .54761 Mdot
.58196 .17914 Mdot
.43645 .3273 Mdot
.36467 .47715 Mdot
.50465 .62042 Mdot
.58437 .50631 Mdot
.5725 .42417 Mdot
.19219 .28521 Mdot
.73914 .45584 Mdot
.30552 .49762 Mdot
.8004 .45943 Mdot
.61013 .25721 Mdot
.43136 .64255 Mdot
.31746 .48622 Mdot
.39691 .36077 Mdot
.51987 .61506 Mdot
.41893 .59361 Mdot
.48968 .38176 Mdot
.38101 .3159 Mdot
.60619 .39535 Mdot
.41495 .37273 Mdot
.31089 .48386 Mdot
.62086 .2496 Mdot
.69885 .5366 Mdot
.45199 .60828 Mdot
.55813 .65467 Mdot
.43693 .33172 Mdot
.61793 .26553 Mdot
.49048 .64377 Mdot
.69203 .52672 Mdot
.38363 .34768 Mdot
.48602 .6178 Mdot
.62472 .65162 Mdot
.71615 .58454 Mdot
.43516 .34518 Mdot
.529 .64541 Mdot
.50039 .72818 Mdot
.45 .35179 Mdot
.44568 .33846 Mdot
.46721 .64271 Mdot
.35085 .51134 Mdot
.43345 .65494 Mdot
.55576 .41033 Mdot
.41897 .29169 Mdot
.5817 .37817 Mdot
.34437 .55812 Mdot
.52935 .59527 Mdot
.74076 .35805 Mdot
.69018 .58287 Mdot
.33639 .45966 Mdot
.52457 .79039 Mdot
.52293 .6487 Mdot
.1888 .42716 Mdot
.4104 .50829 Mdot
.42951 .17552 Mdot
.18473 .61212 Mdot
.33686 .48296 Mdot
.56598 .37978 Mdot
.46792 .65182 Mdot
.53817 .41331 Mdot
.32266 .50112 Mdot
.35769 .56454 Mdot
.52822 .64784 Mdot
.69248 .54078 Mdot
.47793 .65623 Mdot
.68099 .58059 Mdot
.45407 .64768 Mdot
.41345 .68349 Mdot
.37796 .46698 Mdot
.37491 .71548 Mdot
.51017 .672 Mdot
.38476 .79849 Mdot
.57113 .49953 Mdot
.34662 .4821 Mdot
.49649 .64859 Mdot
.60065 .2556 Mdot
.55793 .36264 Mdot
.23757 .6115 Mdot
.41249 .34276 Mdot
.55656 .40063 Mdot
.68655 .57165 Mdot
.45154 .37296 Mdot
.59962 .27198 Mdot
.56104 .6549 Mdot
.34328 .46915 Mdot
.55816 .38032 Mdot
.44272 .61722 Mdot
.45059 .60145 Mdot
.36774 .42473 Mdot
.69088 .256 Mdot
.67941 .5114 Mdot
.55363 .83848 Mdot
.65633 .59228 Mdot
.34503 .50218 Mdot
.40771 .34641 Mdot
.43724 .64964 Mdot
.47356 .61841 Mdot
.40663 .3134 Mdot
.65724 .53176 Mdot
.37691 .31144 Mdot
.71408 .65334 Mdot
.40404 .38206 Mdot
.34641 .62963 Mdot
.65809 .54774 Mdot
.34899 .63412 Mdot
.31177 .48088 Mdot
.19143 .51824 Mdot
.27333 .60674 Mdot
.54961 .40081 Mdot
.34429 .62344 Mdot
.66478 .53639 Mdot
.48942 .63023 Mdot
.6087 .26213 Mdot
.61077 .23857 Mdot
.68114 .57588 Mdot
.39307 .33878 Mdot
.35691 .47744 Mdot
.47111 .65062 Mdot
.75287 .42466 Mdot
.66003 .37701 Mdot
.42108 .3809 Mdot
.55089 .58306 Mdot
.59419 .3877 Mdot
.45596 .66672 Mdot
.32444 .48438 Mdot
.56142 .39148 Mdot
.58813 .25632 Mdot
.64408 .46645 Mdot
.50412 .61757 Mdot
.74659 .4906 Mdot
.56754 .37421 Mdot
.80437 .36539 Mdot
.47174 .62798 Mdot
.59539 .40137 Mdot
.40602 .68203 Mdot
.68132 .33388 Mdot
.49098 .49121 Mdot
.21642 .35486 Mdot
.38031 .32015 Mdot
.39526 .34988 Mdot
.64588 .27027 Mdot
.37041 .45778 Mdot
.55059 .3843 Mdot
.62123 .25153 Mdot
.28351 .57063 Mdot
.59673 .38823 Mdot
.42701 .62982 Mdot
.46234 .59396 Mdot
.69534 .66134 Mdot
.50011 .47322 Mdot
.61766 .26771 Mdot
.60042 .54576 Mdot
.48879 .67431 Mdot
.49913 .69163 Mdot
.46454 .62394 Mdot
.63612 .56848 Mdot
.58687 .36913 Mdot
.40861 .82809 Mdot
.59381 .37672 Mdot
.76133 .43208 Mdot
.43594 .33835 Mdot
.42101 .38219 Mdot
.44011 .61818 Mdot
.76526 .36021 Mdot
.22789 .60074 Mdot
.46121 .67744 Mdot
.31248 .52658 Mdot
.29948 .54375 Mdot
.47848 .70026 Mdot
.62631 .54685 Mdot
.55849 .64334 Mdot
.65874 .59983 Mdot
.56175 .39611 Mdot
.3331 .48361 Mdot
.37197 .51235 Mdot
.55718 .38489 Mdot
.45931 .60876 Mdot
.3443 .54271 Mdot
.47379 .60674 Mdot
.49117 .63367 Mdot
.77773 .46448 Mdot
.36856 .47931 Mdot
.41123 .35248 Mdot
.34175 .50735 Mdot
.67164 .56773 Mdot
.51043 .09528 Mdot
.32834 .49398 Mdot
.69302 .4972 Mdot
.39435 .44719 Mdot
.34646 .62447 Mdot
.6916 .52775 Mdot
.32917 .51351 Mdot
.60378 .38841 Mdot
.42311 .17487 Mdot
.82011 .41471 Mdot
.55026 .41691 Mdot
.47476 .62391 Mdot
.70955 .56447 Mdot
.63805 .56172 Mdot
.58101 .43016 Mdot
.69839 .54037 Mdot
.53968 .63475 Mdot
.50075 .6284 Mdot
.55075 .38417 Mdot
.67129 .41481 Mdot
.58324 .3656 Mdot
.62834 .48748 Mdot
.49439 .64604 Mdot
.66144 .55068 Mdot
.54395 .61568 Mdot
.6558 .51394 Mdot
.60455 .23688 Mdot
.52234 .61793 Mdot
.36294 .4961 Mdot
.49813 .46399 Mdot
.43459 .34295 Mdot
.455 .28648 Mdot
.69945 .57367 Mdot
.53713 .42505 Mdot
.70417 .55215 Mdot
.70342 .57841 Mdot
.53903 .39677 Mdot
.66027 .5649 Mdot
.46924 .65228 Mdot
.38849 .42536 Mdot
.66197 .58018 Mdot
.57694 .38818 Mdot
.3594 .48325 Mdot
.69396 .56099 Mdot
.45868 .3668 Mdot
.49162 .6219 Mdot
.42407 .36743 Mdot
.30468 .48237 Mdot
.71278 .55608 Mdot
.3339 .51511 Mdot
.43611 .32869 Mdot
.33632 .46968 Mdot
.24966 .38462 Mdot
.60957 .3808 Mdot
.78522 .43829 Mdot
.43956 .74737 Mdot
.64454 .57009 Mdot
.38365 .38168 Mdot
.44143 .65524 Mdot
.49585 .62062 Mdot
.31168 .48667 Mdot
.63852 .56059 Mdot
.24774 .31635 Mdot
.48705 .72797 Mdot
.63839 .45621 Mdot
.61254 .39204 Mdot
.60309 .82768 Mdot
.69626 .46409 Mdot
.42198 .19962 Mdot
.42383 .6799 Mdot
.6098 .25792 Mdot
.46939 .60328 Mdot
.47658 .80896 Mdot
.36446 .50697 Mdot
.53345 .28457 Mdot
.41521 .6667 Mdot
.41855 .34755 Mdot
.45364 .63685 Mdot
.29136 .70702 Mdot
.55816 .63854 Mdot
.3197 .50372 Mdot
.61206 .35991 Mdot
.71655 .53631 Mdot
.35406 .48575 Mdot
.40157 .3566 Mdot
.30968 .58855 Mdot
.52801 .65392 Mdot
.47743 .67639 Mdot
.37612 .36814 Mdot
.69464 .54071 Mdot
.42361 .31776 Mdot
.59332 .40355 Mdot
.33156 .49305 Mdot
.51126 .62727 Mdot
.51188 .6827 Mdot
.4731 .35131 Mdot
.59035 .37029 Mdot
.44141 .37598 Mdot
.59664 .41089 Mdot
.61013 .25885 Mdot
.48754 .68362 Mdot
.37686 .36678 Mdot
.46298 .59115 Mdot
.5209 .80022 Mdot
.78424 .46647 Mdot
.62834 .76663 Mdot
.41164 .35486 Mdot
.33086 .64242 Mdot
.57372 .37828 Mdot
.58147 .41747 Mdot
.72912 .70979 Mdot
.2273 .56348 Mdot
.33958 .33256 Mdot
.37423 .78054 Mdot
.5924 .40441 Mdot
.58073 .38058 Mdot
.39421 .3603 Mdot
.6629 .57033 Mdot
.70472 .596 Mdot
.4246 .38336 Mdot
.38403 .72634 Mdot
.67064 .53594 Mdot
.19307 .40872 Mdot
.44511 .3298 Mdot
.41556 .67041 Mdot
.62713 .24504 Mdot
.33365 .47989 Mdot
.38589 .72677 Mdot
.3377 .74248 Mdot
.4328 .63996 Mdot
.79361 .57724 Mdot
.40992 .33159 Mdot
.4439 .42454 Mdot
.17521 .4847 Mdot
.52743 .63343 Mdot
.45124 .62973 Mdot
.45852 .61331 Mdot
.37329 .48772 Mdot
.51254 .791 Mdot
.432 .63792 Mdot
.36346 .69027 Mdot
.42438 .64283 Mdot
.27068 .65214 Mdot
.34029 .50686 Mdot
.57562 .56829 Mdot
.37273 .33498 Mdot
.71641 .39189 Mdot
.41295 .59025 Mdot
.59916 .40255 Mdot
.40863 .41039 Mdot
.58016 .40196 Mdot
.21201 .55904 Mdot
.2744 .60455 Mdot
.63968 .57833 Mdot
.45721 .66366 Mdot
.38476 .32103 Mdot
.70278 .57261 Mdot
.48776 .24564 Mdot
.59658 .12624 Mdot
.60299 .38051 Mdot
.85465 .51506 Mdot
.58147 .41791 Mdot
.60554 .23788 Mdot
.69124 .5721 Mdot
.64454 .61507 Mdot
.49586 .44973 Mdot
.69287 .55979 Mdot
.59686 .3089 Mdot
.62377 .55602 Mdot
.33648 .63232 Mdot
.72165 .55697 Mdot
.57384 .38547 Mdot
.60481 .36469 Mdot
.40464 .62846 Mdot
.44493 .6567 Mdot
.53205 .45151 Mdot
.40785 .69665 Mdot
.4506 .66097 Mdot
.42411 .35455 Mdot
.8068 .4083 Mdot
.45865 .33591 Mdot
.65205 .57086 Mdot
.59557 .41719 Mdot
.45169 .63165 Mdot
.50614 .63126 Mdot
.48488 .59056 Mdot
.50736 .81989 Mdot
.19596 .40499 Mdot
.48276 .6391 Mdot
.47812 .57489 Mdot
.40297 .35473 Mdot
.37889 .52182 Mdot
.41816 .79483 Mdot
.28356 .582 Mdot
.49116 .60851 Mdot
.35137 .50212 Mdot
.37054 .49911 Mdot
.47692 .69405 Mdot
.74082 .39335 Mdot
.38134 .40895 Mdot
.44248 .61773 Mdot
.26611 .61415 Mdot
.46184 .35325 Mdot
.62236 .25799 Mdot
.43756 .33244 Mdot
.71315 .54795 Mdot
.61423 .24436 Mdot
.38192 .35786 Mdot
.62933 .61209 Mdot
.59239 .25986 Mdot
.68568 .34738 Mdot
.35313 .51568 Mdot
.46732 .62026 Mdot
.62696 .53755 Mdot
.40887 .31166 Mdot
.55645 .38265 Mdot
.67686 .55287 Mdot
.5735 .35895 Mdot
.38644 .50403 Mdot
.37169 .59892 Mdot
.61707 .24077 Mdot
.59301 .40883 Mdot
.64463 .46713 Mdot
.34983 .50421 Mdot
.54111 .39852 Mdot
.75622 .35032 Mdot
.44733 .69053 Mdot
.2188 .61917 Mdot
.4657 .67224 Mdot
.33261 .2396 Mdot
.57655 .41859 Mdot
.59406 .24582 Mdot
.45965 .60501 Mdot
.44785 .35 Mdot
.41721 .69632 Mdot
.47894 .61069 Mdot
.43756 .37334 Mdot
.48721 .63412 Mdot
.32343 .48411 Mdot
.68758 .59908 Mdot
.41727 .50948 Mdot
.68711 .78158 Mdot
.3357 .47087 Mdot
.63331 .23704 Mdot
.44992 .66265 Mdot
.24601 .43354 Mdot
.69346 .55715 Mdot
.52571 .6319 Mdot
.76665 .64724 Mdot
.66475 .57567 Mdot
.68081 .55991 Mdot
.49544 .66192 Mdot
.54422 .39719 Mdot
.44434 .34728 Mdot
.35033 .50509 Mdot
.48136 .173 Mdot
.48515 .61407 Mdot
.46384 .63719 Mdot
.3529 .48301 Mdot
.58111 .37917 Mdot
.50871 .63319 Mdot
.48179 .27215 Mdot
.50506 .15713 Mdot
.55215 .41126 Mdot
.46137 .69803 Mdot
.25397 .69285 Mdot
.7324 .54383 Mdot
.84107 .48344 Mdot
.35835 .44224 Mdot
.40034 .33597 Mdot
.42556 .69406 Mdot
.23303 .24611 Mdot
.33537 .48028 Mdot
.72295 .41867 Mdot
.48338 .64415 Mdot
.44614 .64236 Mdot
.68032 .5263 Mdot
.50584 .648 Mdot
.65219 .54471 Mdot
.70891 .77064 Mdot
.55549 .86326 Mdot
.70206 .55584 Mdot
.64682 .56522 Mdot
.60546 .58768 Mdot
.45606 .79376 Mdot
.68003 .57294 Mdot
.53095 .63657 Mdot
.22541 .40398 Mdot
.47269 .57099 Mdot
.31797 .47346 Mdot
.29721 .49417 Mdot
.67724 .61101 Mdot
.75631 .30789 Mdot
.48739 .71737 Mdot
.40495 .58435 Mdot
.54115 .52618 Mdot
.5669 .41301 Mdot
.4999 .60802 Mdot
.61995 .24432 Mdot
.39617 .37108 Mdot
.55649 .60564 Mdot
.46808 .6162 Mdot
.67423 .58242 Mdot
.37221 .48222 Mdot
.54271 .36951 Mdot
.46853 .63702 Mdot
.39102 .30324 Mdot
.34509 .49391 Mdot
.65541 .57727 Mdot
.72687 .50599 Mdot
.34093 .46472 Mdot
.53887 .6486 Mdot
.44925 .65451 Mdot
.49144 .64266 Mdot
.40068 .60934 Mdot
.55415 .38811 Mdot
.46206 .37029 Mdot
.53503 .6313 Mdot
.77243 .47678 Mdot
.44585 .44194 Mdot
.51586 .67672 Mdot
.67168 .53054 Mdot
.55987 .4198 Mdot
.59534 .2532 Mdot
.3262 .58283 Mdot
.50003 .61449 Mdot
.19661 .40934 Mdot
.69749 .64361 Mdot
.61045 .24446 Mdot
.67393 .58903 Mdot
.3567 .50307 Mdot
.48377 .67325 Mdot
.21376 .44494 Mdot
.45779 .59695 Mdot
.44737 .73961 Mdot
.40477 .33352 Mdot
.57357 .41279 Mdot
.48243 .15448 Mdot
.39751 .37212 Mdot
.6785 .56031 Mdot
.21497 .32872 Mdot
.65961 .5208 Mdot
.70287 .52253 Mdot
.20436 .51464 Mdot
.562 .39969 Mdot
.21513 .26429 Mdot
.82612 .43924 Mdot
.43836 .60774 Mdot
.58733 .37671 Mdot
.69475 .57186 Mdot
.45934 .6659 Mdot
.64292 .55338 Mdot
.68841 .51778 Mdot
.51417 .60917 Mdot
.44583 .64898 Mdot
.3737 .70344 Mdot
.17318 .44091 Mdot
.34791 .5099 Mdot
.66156 .5289 Mdot
.65864 .66474 Mdot
.43227 .64221 Mdot
.46167 .59842 Mdot
.44076 .41273 Mdot
.32002 .50383 Mdot
.51985 .73502 Mdot
.49396 .63398 Mdot
.77212 .65092 Mdot
.47022 .683 Mdot
.63454 .52631 Mdot
.54709 .40671 Mdot
.73858 .39828 Mdot
.42275 .31221 Mdot
.68093 .5211 Mdot
.35861 .47546 Mdot
.63421 .54066 Mdot
.74613 .67634 Mdot
.5665 .40083 Mdot
.65959 .54169 Mdot
.45574 .34978 Mdot
.57804 .39683 Mdot
.55253 .40993 Mdot
.22861 .42833 Mdot
.43819 .37823 Mdot
.34627 .51938 Mdot
.58795 .39886 Mdot
.61888 .6604 Mdot
.57006 .38713 Mdot
.67446 .66478 Mdot
.44816 .67271 Mdot
.36249 .67908 Mdot
.70426 .45706 Mdot
.42994 .57693 Mdot
.57996 .36382 Mdot
.32831 .50584 Mdot
.50502 .65942 Mdot
.69533 .53722 Mdot
.3279 .49172 Mdot
.61763 .35469 Mdot
.45294 .35884 Mdot
.67708 .58576 Mdot
.55046 .41205 Mdot
.65576 .54134 Mdot
.36763 .58455 Mdot
.4311 .28401 Mdot
.54661 .53317 Mdot
.48503 .44206 Mdot
.47642 .58654 Mdot
.67431 .61329 Mdot
.45658 .6829 Mdot
.47054 .6133 Mdot
.43577 .3448 Mdot
.35106 .70594 Mdot
.69676 .55822 Mdot
.49746 .15039 Mdot
.58704 .41329 Mdot
.77431 .5462 Mdot
.51013 .72144 Mdot
.52086 .62598 Mdot
.66336 .57964 Mdot
.6831 .51504 Mdot
.62464 .77851 Mdot
.40709 .3144 Mdot
.45472 .56866 Mdot
.52971 .59149 Mdot
.40758 .66057 Mdot
.57801 .41952 Mdot
.49818 .29064 Mdot
.39799 .32716 Mdot
.85574 .40369 Mdot
.42165 .32506 Mdot
.29263 .38409 Mdot
.65931 .56491 Mdot
.36454 .50368 Mdot
.45767 .59999 Mdot
.39939 .71869 Mdot
.63376 .57575 Mdot
.41132 .42676 Mdot
.36083 .49681 Mdot
.52333 .32069 Mdot
.55896 .40034 Mdot
.4995 .68281 Mdot
.50762 .60611 Mdot
.49881 .65083 Mdot
.46998 .66717 Mdot
.60308 .41153 Mdot
.42747 .62864 Mdot
.61491 .39004 Mdot
.61939 .64611 Mdot
.76914 .66039 Mdot
.40747 .30747 Mdot
.23412 .59196 Mdot
.64698 .57701 Mdot
.62535 .67544 Mdot
.53642 .71098 Mdot
.78396 .46178 Mdot
.24297 .40579 Mdot
.45956 .68129 Mdot
.39035 .34225 Mdot
.29275 .71351 Mdot
.38606 .32033 Mdot
.64937 .85731 Mdot
.34854 .54718 Mdot
.20858 .35735 Mdot
.46028 .6645 Mdot
.47094 .35609 Mdot
.51784 .72265 Mdot
.47028 .69625 Mdot
.36225 .5462 Mdot
.67605 .49032 Mdot
.68768 .41167 Mdot
.36092 .47248 Mdot
.4903 .62013 Mdot
.71582 .53361 Mdot
.46961 .65373 Mdot
.46684 .59922 Mdot
.4547 .66802 Mdot
.53468 .37999 Mdot
.42126 .66175 Mdot
.43161 .65018 Mdot
.69838 .25635 Mdot
.3252 .66618 Mdot
.42409 .3703 Mdot
.66984 .75232 Mdot
.33761 .49883 Mdot
.68547 .58059 Mdot
.40648 .49478 Mdot
.55407 .40447 Mdot
.60924 .78969 Mdot
.46208 .66835 Mdot
.6896 .45287 Mdot
.55016 .41234 Mdot
.3288 .48771 Mdot
.59667 .26659 Mdot
.22858 .36238 Mdot
.4037 .30922 Mdot
.59215 .25587 Mdot
.43369 .34152 Mdot
.53328 .77753 Mdot
.6728 .58202 Mdot
.4907 .59169 Mdot
.59455 .3928 Mdot
.44486 .35182 Mdot
.33762 .70394 Mdot
.46036 .62337 Mdot
.4132 .35744 Mdot
.48096 .5872 Mdot
.42167 .44412 Mdot
.37348 .41347 Mdot
.37862 .34597 Mdot
.60396 .36084 Mdot
.58362 .39341 Mdot
.35352 .51175 Mdot
.68534 .58149 Mdot
.66373 .53284 Mdot
.56377 .39309 Mdot
.83814 .5127 Mdot
.48135 .60916 Mdot
.45295 .66603 Mdot
.76607 .47399 Mdot
.46176 .65531 Mdot
.32133 .6067 Mdot
.61995 .23571 Mdot
.66665 .58471 Mdot
.46588 .66287 Mdot
.5092 .63137 Mdot
.50492 .61918 Mdot
.36728 .58988 Mdot
.43414 .32957 Mdot
.48836 .67408 Mdot
.31632 .48384 Mdot
.7246 .32916 Mdot
.43991 .65784 Mdot
.48779 .69454 Mdot
.66215 .53974 Mdot
.61536 .82937 Mdot
.55208 .40546 Mdot
.42047 .36078 Mdot
.44938 .3421 Mdot
.31398 .45643 Mdot
.69604 .5905 Mdot
.62026 .23174 Mdot
.57074 .20782 Mdot
.61338 .26546 Mdot
.3507 .48579 Mdot
.31629 .33951 Mdot
.38211 .31018 Mdot
.41109 .36716 Mdot
.61226 .37804 Mdot
.4691 .66475 Mdot
.46184 .6788 Mdot
.72613 .41929 Mdot
.51047 .66207 Mdot
.36163 .49141 Mdot
.55271 .37786 Mdot
.6659 .53992 Mdot
.33447 .47804 Mdot
.60017 .40519 Mdot
.69289 .53856 Mdot
.45016 .69064 Mdot
.44083 .68681 Mdot
.68059 .55542 Mdot
.70663 .56258 Mdot
.43653 .63504 Mdot
.67313 .24954 Mdot
.71761 .56325 Mdot
.65888 .54442 Mdot
.61053 .2776 Mdot
.40014 .31006 Mdot
.5469 .63239 Mdot
.58786 .37622 Mdot
.49134 .64157 Mdot
.39358 .31168 Mdot
.3232 .50769 Mdot
.69028 .54819 Mdot
.50558 .62828 Mdot
.4845 .62999 Mdot
.35286 .50179 Mdot
.35538 .46543 Mdot
.34904 .4744 Mdot
.5255 .39465 Mdot
.48332 .65966 Mdot
.68209 .57126 Mdot
.56312 .40238 Mdot
.37057 .49886 Mdot
.33196 .52219 Mdot
.72686 .27283 Mdot
.43263 .63401 Mdot
.49904 .49649 Mdot
.47092 .10417 Mdot
.30157 .58759 Mdot
.5985 .2453 Mdot
.38668 .37629 Mdot
.35308 .6604 Mdot
.32749 .43899 Mdot
.58249 .36988 Mdot
.2479 .53549 Mdot
.33487 .46028 Mdot
.51344 .60361 Mdot
.4777 .68199 Mdot
.45166 .58548 Mdot
.34013 .49245 Mdot
.36066 .58106 Mdot
.6388 .55266 Mdot
.59348 .73061 Mdot
.33751 .49862 Mdot
.37886 .34583 Mdot
.37694 .36389 Mdot
.42031 .32486 Mdot
.48061 .6869 Mdot
.61425 .78129 Mdot
.63656 .66177 Mdot
.53517 .75019 Mdot
.55631 .39938 Mdot
.67495 .51343 Mdot
.24676 .41054 Mdot
.68298 .55939 Mdot
.39051 .36791 Mdot
.34265 .48955 Mdot
.66913 .5266 Mdot
.5685 .37055 Mdot
.58371 .38137 Mdot
.45215 .35713 Mdot
.44097 .33795 Mdot
.43475 .35947 Mdot
.70984 .53827 Mdot
.6602 .5651 Mdot
.51038 .62026 Mdot
.68313 .54643 Mdot
.79474 .56467 Mdot
.30513 .50402 Mdot
.37486 .35525 Mdot
.57146 .37487 Mdot
.68861 .5778 Mdot
.46934 .62186 Mdot
.33435 .36728 Mdot
.5886 .32119 Mdot
.32834 .47398 Mdot
.3675 .28173 Mdot
.7193 .80329 Mdot
.49791 .60025 Mdot
.60488 .40317 Mdot
.74003 .37939 Mdot
.45571 .61839 Mdot
.4111 .33865 Mdot
.48942 .80778 Mdot
.61483 .26702 Mdot
.43282 .65157 Mdot
.52138 .6415 Mdot
.53821 .39241 Mdot
.39244 .45554 Mdot
.51861 .6357 Mdot
.7045 .48025 Mdot
.55935 .35857 Mdot
.39047 .33194 Mdot
.52928 .15383 Mdot
.39931 .38519 Mdot
.38312 .73795 Mdot
.60349 .2414 Mdot
.50981 .60861 Mdot
.42731 .35347 Mdot
.32271 .47936 Mdot
.43405 .35357 Mdot
.65849 .58814 Mdot
.42882 .36664 Mdot
.46021 .63865 Mdot
.67895 .57112 Mdot
.56992 .37274 Mdot
.77421 .52276 Mdot
.70876 .27127 Mdot
.44818 .35032 Mdot
.59693 .28161 Mdot
.4322 .64678 Mdot
.57292 .67713 Mdot
.4186 .69755 Mdot
.44581 .66263 Mdot
.57841 .40281 Mdot
.6601 .57818 Mdot
.61042 .39707 Mdot
.51346 .68985 Mdot
.71175 .73721 Mdot
.57578 .41668 Mdot
.6895 .3731 Mdot
.35162 .48312 Mdot
.38191 .71938 Mdot
.47705 .61567 Mdot
.59241 .39782 Mdot
.48454 .6582 Mdot
.64988 .53304 Mdot
.54978 .48276 Mdot
.73819 .33724 Mdot
.59388 .39133 Mdot
.27966 .27698 Mdot
.54246 .48994 Mdot
.55444 .64209 Mdot
.59181 .4023 Mdot
.56608 .79144 Mdot
.59787 .25527 Mdot
.34916 .49265 Mdot
.37117 .48845 Mdot
.34035 .46828 Mdot
.51025 .66432 Mdot
.5665 .60249 Mdot
.34029 .52197 Mdot
.55176 .35976 Mdot
.31631 .497 Mdot
.379 .70097 Mdot
.27149 .29045 Mdot
.34212 .47247 Mdot
.47851 .62339 Mdot
.47923 .69756 Mdot
.32549 .67043 Mdot
.38253 .34603 Mdot
.18703 .43251 Mdot
.75151 .59632 Mdot
.43825 .64863 Mdot
.55381 .6685 Mdot
.65123 .58302 Mdot
.76786 .38282 Mdot
.53486 .69743 Mdot
.37411 .42341 Mdot
.64767 .55673 Mdot
.36013 .33414 Mdot
.67381 .58464 Mdot
.48634 .59483 Mdot
.47907 .64235 Mdot
.66942 .60254 Mdot
.45458 .28079 Mdot
.66704 .31181 Mdot
.37923 .21176 Mdot
.65978 .5332 Mdot
.59895 .39565 Mdot
.60644 .38641 Mdot
.56348 .40563 Mdot
.42688 .31506 Mdot
.711 .54947 Mdot
.48198 .66584 Mdot
.39779 .34743 Mdot
.48695 .60683 Mdot
.58195 .39828 Mdot
.47701 .15511 Mdot
.66325 .54008 Mdot
.44556 .61467 Mdot
.81939 .41517 Mdot
.42571 .33106 Mdot
.34801 .50373 Mdot
.43111 .43507 Mdot
.45923 .37428 Mdot
.58239 .36464 Mdot
.72655 .56596 Mdot
.53211 .36714 Mdot
.4012 .52227 Mdot
.44393 .58411 Mdot
.51519 .67409 Mdot
.52064 .16759 Mdot
.77563 .33538 Mdot
.49867 .67724 Mdot
.40181 .35736 Mdot
.38702 .32583 Mdot
.50168 .62458 Mdot
.70101 .53809 Mdot
.36624 .50998 Mdot
.32349 .47211 Mdot
.52109 .60421 Mdot
.49661 .44665 Mdot
.36788 .69266 Mdot
.50867 .63997 Mdot
.47592 .56089 Mdot
.45318 .36542 Mdot
.59709 .26903 Mdot
.74141 .46768 Mdot
.36638 .48708 Mdot
.48576 .64242 Mdot
.65873 .33085 Mdot
.65038 .54756 Mdot
.43021 .36437 Mdot
.55591 .37864 Mdot
.38247 .54517 Mdot
.44837 .33582 Mdot
.50163 .62547 Mdot
.50875 .63278 Mdot
.53905 .39479 Mdot
.63422 .52695 Mdot
.34046 .48961 Mdot
.39904 .34719 Mdot
.36655 .50043 Mdot
.66802 .56631 Mdot
.66653 .54305 Mdot
.49572 .56919 Mdot
.39892 .61868 Mdot
.44963 .3467 Mdot
.49696 .58353 Mdot
.38364 .36339 Mdot
.38114 .45107 Mdot
.57993 .42467 Mdot
.52657 .62615 Mdot
.71973 .5313 Mdot
.57622 .39984 Mdot
.44193 .63894 Mdot
.59358 .19152 Mdot
.51833 .61981 Mdot
.46113 .37216 Mdot
.72079 .72955 Mdot
.32443 .5058 Mdot
.74826 .52977 Mdot
.43476 .54724 Mdot
.46165 .65351 Mdot
.38377 .36803 Mdot
.4377 .7052 Mdot
.56116 .4145 Mdot
.65261 .56547 Mdot
.84964 .59683 Mdot
.57375 .38938 Mdot
.47229 .65225 Mdot
.33034 .49194 Mdot
.6968 .51704 Mdot
.61811 .25066 Mdot
.74204 .46137 Mdot
.55875 .6138 Mdot
.42459 .67788 Mdot
.46956 .6624 Mdot
.38403 .79117 Mdot
.42457 .35894 Mdot
.6921 .57496 Mdot
.58166 .42096 Mdot
.56104 .38762 Mdot
.41141 .3275 Mdot
.68039 .43548 Mdot
.43101 .27334 Mdot
.38654 .11805 Mdot
.43811 .37083 Mdot
.31476 .49884 Mdot
.46888 .44799 Mdot
.40165 .37451 Mdot
.42071 .35194 Mdot
.45256 .34759 Mdot
.71008 .44382 Mdot
.68324 .53236 Mdot
.48543 .63033 Mdot
.69086 .59133 Mdot
.51471 .61243 Mdot
.37743 .75213 Mdot
.56223 .39418 Mdot
.65335 .56437 Mdot
.56184 .17768 Mdot
.41364 .70093 Mdot
.45406 .62633 Mdot
.26301 .34358 Mdot
.51499 .69403 Mdot
.34092 .60565 Mdot
.54165 .64179 Mdot
.43933 .34042 Mdot
.56981 .6337 Mdot
.42038 .68685 Mdot
.79065 .55626 Mdot
.57662 .37328 Mdot
.60929 .23567 Mdot
.43464 .67618 Mdot
.54781 .59857 Mdot
.69909 .51885 Mdot
.66871 .52654 Mdot
.34336 .52145 Mdot
.474 .41793 Mdot
.57246 .37222 Mdot
.48719 .34886 Mdot
.44641 .6567 Mdot
.62854 .39227 Mdot
.7358 .69945 Mdot
.44118 .63636 Mdot
.22166 .42392 Mdot
.61414 .78657 Mdot
.51905 .63281 Mdot
.56315 .75848 Mdot
.57727 .38004 Mdot
.77087 .64963 Mdot
.46584 .58263 Mdot
.41261 .33856 Mdot
.65993 .56939 Mdot
.65906 .5862 Mdot
.33404 .47403 Mdot
.81305 .52659 Mdot
.59964 .36886 Mdot
.65729 .56506 Mdot
.46019 .6159 Mdot
.55437 .38555 Mdot
.61546 .24127 Mdot
.45765 .70006 Mdot
.22984 .51862 Mdot
.67875 .5438 Mdot
.48685 .57442 Mdot
.63542 .43741 Mdot
.42463 .45235 Mdot
.15996 .46293 Mdot
.56798 .40843 Mdot
.3618 .47969 Mdot
.54343 .63185 Mdot
.56727 .20523 Mdot
.42499 .61164 Mdot
.36157 .70471 Mdot
.73542 .58438 Mdot
.36025 .51111 Mdot
.45213 .61547 Mdot
.51726 .63895 Mdot
.48953 .4546 Mdot
.35956 .46927 Mdot
.52179 .62171 Mdot
.47915 .56813 Mdot
.69298 .53984 Mdot
.61738 .23473 Mdot
.6726 .54004 Mdot
.47412 .62453 Mdot
.5744 .62368 Mdot
.68973 .53064 Mdot
.34269 .27701 Mdot
.36056 .46227 Mdot
.55512 .40737 Mdot
.52169 .56647 Mdot
.44811 .67139 Mdot
.24122 .71014 Mdot
.60443 .23706 Mdot
.46053 .81314 Mdot
.43046 .38291 Mdot
.61257 .30579 Mdot
.45043 .30495 Mdot
.21852 .34267 Mdot
.75861 .50046 Mdot
.46268 .57701 Mdot
.25251 .58781 Mdot
.55232 .75292 Mdot
.60623 .37846 Mdot
.59552 .6663 Mdot
.44478 .65674 Mdot
.46876 .60126 Mdot
.39087 .35463 Mdot
.67216 .44776 Mdot
.73669 .3823 Mdot
.51312 .44797 Mdot
.33916 .48532 Mdot
.66236 .56093 Mdot
.45686 .64596 Mdot
.44552 .24104 Mdot
.4302 .3696 Mdot
.58862 .50088 Mdot
.45253 .60858 Mdot
.76083 .42391 Mdot
.70162 .40388 Mdot
.55317 .38617 Mdot
.3882 .37597 Mdot
.45885 .37328 Mdot
.47477 .59481 Mdot
.56873 .36784 Mdot
.51341 .6226 Mdot
.5744 .4929 Mdot
.49165 .57829 Mdot
.32641 .48524 Mdot
.43745 .61351 Mdot
.47976 .47525 Mdot
.18042 .38126 Mdot
.53844 .67767 Mdot
.70924 .57069 Mdot
.42849 .31685 Mdot
.42635 .32674 Mdot
.66163 .53328 Mdot
.42228 .3265 Mdot
.59931 .73593 Mdot
.73368 .66707 Mdot
.34209 .48096 Mdot
.5754 .65648 Mdot
.32476 .48993 Mdot
.60866 .2353 Mdot
.43393 .6392 Mdot
.57578 .22262 Mdot
.44277 .36771 Mdot
.54635 .82255 Mdot
.56735 .38673 Mdot
.60549 .23708 Mdot
.42272 .63313 Mdot
.31337 .34411 Mdot
.38614 .3592 Mdot
.43623 .39471 Mdot
.50525 .61865 Mdot
.67072 .52863 Mdot
.51657 .6396 Mdot
.52529 .60029 Mdot
.59251 .2558 Mdot
.47035 .66353 Mdot
.60063 .40459 Mdot
.7101 .54506 Mdot
.23357 .33626 Mdot
.41251 .31092 Mdot
.4451 .6079 Mdot
.45916 .61577 Mdot
.64825 .53262 Mdot
.42458 .63884 Mdot
.58029 .36715 Mdot
.13623 .3507 Mdot
.35188 .48459 Mdot
.60157 .2732 Mdot
.45468 .3862 Mdot
.46851 .67945 Mdot
.51167 .64155 Mdot
.50875 .16648 Mdot
.69359 .29794 Mdot
.59879 .40484 Mdot
.53462 .62143 Mdot
.40405 .35485 Mdot
.32953 .48911 Mdot
.54775 .36685 Mdot
.49469 .64103 Mdot
.46166 .60083 Mdot
.32764 .48364 Mdot
.23048 .39923 Mdot
.37855 .40904 Mdot
.55865 .4025 Mdot
.56885 .64942 Mdot
.34172 .37714 Mdot
.48024 .60978 Mdot
.38425 .23672 Mdot
.66019 .5454 Mdot
.58706 .40643 Mdot
.48455 .78088 Mdot
.49203 .59154 Mdot
.58691 .36858 Mdot
.57255 .3729 Mdot
.4457 .60121 Mdot
.69882 .58871 Mdot
.70443 .52875 Mdot
.65544 .54653 Mdot
.7191 .73754 Mdot
.30689 .69321 Mdot
.43587 .35901 Mdot
.57888 .37954 Mdot
.38121 .33067 Mdot
.36843 .50888 Mdot
.44894 .4416 Mdot
.38215 .33293 Mdot
.65438 .5841 Mdot
.37549 .36176 Mdot
.51363 .62815 Mdot
.57388 .37072 Mdot
.41108 .36778 Mdot
.47806 .67981 Mdot
.44447 .56451 Mdot
.52567 .49969 Mdot
.36346 .51222 Mdot
.39391 .4335 Mdot
.47291 .64095 Mdot
.5941 .25535 Mdot
.43635 .62948 Mdot
.55017 .38498 Mdot
.45836 .47272 Mdot
.48111 .67786 Mdot
.44952 .35013 Mdot
.42935 .52412 Mdot
.38798 .33273 Mdot
.52716 .59375 Mdot
.47458 .62587 Mdot
.47771 .60709 Mdot
.51885 .63608 Mdot
.69195 .39149 Mdot
.61318 .39475 Mdot
.49586 .55666 Mdot
.40028 .30356 Mdot
.68805 .5558 Mdot
.63589 .54925 Mdot
.34173 .33783 Mdot
.59279 .26606 Mdot
.58455 .37563 Mdot
.48243 .61066 Mdot
.43236 .39557 Mdot
.46605 .15811 Mdot
.3818 .22954 Mdot
.25124 .41864 Mdot
.40477 .36197 Mdot
.70862 .57028 Mdot
.41165 .37328 Mdot
.47823 .59853 Mdot
.5246 .67359 Mdot
.22376 .34483 Mdot
.59948 .4284 Mdot
.34207 .49056 Mdot
.48374 .60452 Mdot
.38892 .74164 Mdot
.40292 .35465 Mdot
.45221 .36873 Mdot
.50964 .61226 Mdot
.68782 .52105 Mdot
.13306 .49724 Mdot
.55423 .37999 Mdot
.57735 .67457 Mdot
.7462 .54439 Mdot
.66414 .49002 Mdot
.55811 .38443 Mdot
.53786 .51533 Mdot
.40971 .32182 Mdot
.76678 .58576 Mdot
.68411 .55384 Mdot
.34275 .49466 Mdot
.52668 .6665 Mdot
.6602 .58596 Mdot
.39183 .38007 Mdot
.65365 .57931 Mdot
.4945 .59507 Mdot
.61092 .3873 Mdot
.40796 .32655 Mdot
.61754 .3743 Mdot
.66607 .60244 Mdot
.32235 .49652 Mdot
.38615 .72154 Mdot
.5917 .66041 Mdot
.61227 .7877 Mdot
.48788 .67407 Mdot
.38907 .39601 Mdot
.4863 .65874 Mdot
.69751 .51915 Mdot
.47752 .617 Mdot
.65935 .61162 Mdot
.42165 .38185 Mdot
.48518 .57465 Mdot
.42899 .64224 Mdot
.64124 .62802 Mdot
.44732 .62849 Mdot
.42494 .62568 Mdot
.5187 .64526 Mdot
.74925 .5551 Mdot
.48172 .57027 Mdot
.67875 .52931 Mdot
.72096 .42576 Mdot
.42213 .35014 Mdot
.34634 .52401 Mdot
.33129 .46793 Mdot
.36204 .69956 Mdot
.38208 .7215 Mdot
.68435 .43827 Mdot
.67584 .53573 Mdot
.60263 .38872 Mdot
.51289 .62161 Mdot
.48173 .77527 Mdot
.33438 .45683 Mdot
.40949 .32299 Mdot
.43673 .31834 Mdot
.39675 .63424 Mdot
.3718 .78769 Mdot
.48828 .57317 Mdot
.74834 .46091 Mdot
.50973 .59468 Mdot
.52537 .63014 Mdot
.45549 .34567 Mdot
.36863 .62203 Mdot
.48801 .67428 Mdot
.6989 .51869 Mdot
.34514 .49846 Mdot
.52104 .70173 Mdot
.30257 .52503 Mdot
.56337 .50811 Mdot
.68431 .62134 Mdot
.47533 .66759 Mdot
.39971 .34115 Mdot
.68022 .58498 Mdot
.76968 .48126 Mdot
.56613 .40361 Mdot
.71357 .46516 Mdot
.638 .6442 Mdot
.31595 .29671 Mdot
.34476 .49395 Mdot
.22927 .41474 Mdot
.46037 .63906 Mdot
.43398 .32001 Mdot
.50439 .60194 Mdot
.45639 .16156 Mdot
.33152 .51379 Mdot
.63334 .57705 Mdot
.59976 .39457 Mdot
.64914 .53551 Mdot
.63458 .764 Mdot
.53325 .53537 Mdot
.63021 .2682 Mdot
.39771 .31213 Mdot
.43352 .7701 Mdot
.67826 .57599 Mdot
.50138 .63316 Mdot
.41597 .11065 Mdot
.66043 .54709 Mdot
.65804 .53134 Mdot
.38344 .44293 Mdot
.34642 .5589 Mdot
.44187 .705 Mdot
.64833 .5751 Mdot
.37685 .33409 Mdot
.34357 .5087 Mdot
.50145 .66534 Mdot
.51769 .64453 Mdot
.67732 .52621 Mdot
.38628 .36238 Mdot
.41731 .77327 Mdot
.44029 .33889 Mdot
.69815 .54489 Mdot
.42622 .33521 Mdot
.45665 .39126 Mdot
.41446 .36442 Mdot
.43624 .66203 Mdot
.48373 .613 Mdot
.26635 .46166 Mdot
.66672 .54307 Mdot
.50804 .65115 Mdot
.48533 .63859 Mdot
.68194 .57312 Mdot
.37965 .31447 Mdot
.46387 .77908 Mdot
.45784 .66305 Mdot
.48714 .62323 Mdot
.36454 .50517 Mdot
.3803 .29573 Mdot
.43644 .23031 Mdot
.50406 .66016 Mdot
.31719 .47885 Mdot
.71205 .54121 Mdot
.43691 .63151 Mdot
.37577 .69105 Mdot
.45136 .32756 Mdot
.44726 .60261 Mdot
.61897 .2506 Mdot
.4643 .67938 Mdot
.13594 .48906 Mdot
.43522 .61987 Mdot
.69515 .57014 Mdot
.66278 .57421 Mdot
.42093 .42848 Mdot
.67515 .56002 Mdot
.60767 .23882 Mdot
.58141 .39713 Mdot
.35025 .23294 Mdot
.61248 .24082 Mdot
.5262 .64041 Mdot
.8262 .43965 Mdot
.49022 .58236 Mdot
.44061 .67947 Mdot
.46192 .79664 Mdot
.6106 .24126 Mdot
.66906 .5799 Mdot
.46073 .28465 Mdot
.52666 .61089 Mdot
.55737 .37584 Mdot
.48287 .69474 Mdot
.43816 .61024 Mdot
.68063 .48232 Mdot
.67149 .76869 Mdot
.54766 .38711 Mdot
.54443 .64859 Mdot
.50348 .66025 Mdot
.74884 .31622 Mdot
.46285 .62266 Mdot
.33879 .47286 Mdot
.65452 .53879 Mdot
.42122 .37651 Mdot
.35579 .49345 Mdot
.4556 .658 Mdot
.3389 .49504 Mdot
.43156 .36203 Mdot
.58163 .40381 Mdot
.45091 .60231 Mdot
.32129 .47017 Mdot
.33879 .48709 Mdot
.49327 .65493 Mdot
.65609 .56639 Mdot
.45473 .71787 Mdot
.4377 .63341 Mdot
.50083 .62996 Mdot
.66379 .53288 Mdot
.80671 .33077 Mdot
.48391 .59677 Mdot
.506 .49789 Mdot
.64048 .58428 Mdot
.6251 .25372 Mdot
.40881 .3707 Mdot
.4621 .5898 Mdot
.5592 .3939 Mdot
.5678 .39799 Mdot
.36624 .35292 Mdot
.65414 .52734 Mdot
.38325 .34968 Mdot
.53012 .68232 Mdot
.40162 .61369 Mdot
.5359 .63209 Mdot
.84446 .60396 Mdot
.22122 .37145 Mdot
.70871 .54808 Mdot
.40068 .32486 Mdot
.51409 .44647 Mdot
.58562 .37878 Mdot
.37191 .35699 Mdot
.72303 .54115 Mdot
.70752 .56582 Mdot
.64824 .57832 Mdot
.36463 .49953 Mdot
.43237 .32308 Mdot
.62842 .53737 Mdot
.67954 .52029 Mdot
.5088 .62189 Mdot
.50368 .65898 Mdot
.67221 .60933 Mdot
.32225 .64908 Mdot
.322 .49222 Mdot
.4043 .33719 Mdot
.21685 .70058 Mdot
.54987 .38593 Mdot
.6446 .62744 Mdot
.47229 .6793 Mdot
.59463 .11645 Mdot
.51086 .57657 Mdot
.46117 .6178 Mdot
.71301 .54702 Mdot
.31102 .49536 Mdot
.33225 .50223 Mdot
.67576 .57609 Mdot
.70001 .59819 Mdot
.35255 .47319 Mdot
.2424 .42569 Mdot
.28244 .26722 Mdot
.75716 .48102 Mdot
.69234 .5698 Mdot
.59173 .65333 Mdot
.57918 .36483 Mdot
.66367 .59981 Mdot
.54682 .3941 Mdot
.41969 .35106 Mdot
.44545 .33484 Mdot
.54007 .39496 Mdot
.50217 .61626 Mdot
.42473 .36601 Mdot
.56032 .61044 Mdot
.24933 .33945 Mdot
.20364 .5744 Mdot
.67163 .27728 Mdot
.46822 .68269 Mdot
.7395 .39439 Mdot
.71715 .35362 Mdot
.46634 .64764 Mdot
.42628 .72085 Mdot
.34153 .49241 Mdot
.65244 .59662 Mdot
.57646 .36732 Mdot
.15973 .47564 Mdot
.48107 .61016 Mdot
.69754 .55728 Mdot
.57995 .3734 Mdot
.47742 .38336 Mdot
.69038 .47771 Mdot
.5089 .60908 Mdot
.2858 .19152 Mdot
.64188 .59018 Mdot
.42162 .37664 Mdot
.8184 .47833 Mdot
.67953 .59404 Mdot
.37783 .43689 Mdot
.45066 .37596 Mdot
.40044 .20659 Mdot
.68886 .57904 Mdot
.36262 .345 Mdot
.66995 .565 Mdot
.3265 .48129 Mdot
.72179 .5721 Mdot
.4038 .3293 Mdot
.44849 .62057 Mdot
.41429 .32831 Mdot
.3213 .48964 Mdot
.43182 .31686 Mdot
.57617 .36632 Mdot
.59964 .24549 Mdot
.58511 .38656 Mdot
.43709 .4426 Mdot
.68825 .75532 Mdot
.57279 .41265 Mdot
.46766 .31938 Mdot
.49563 .67864 Mdot
.63728 .52296 Mdot
.42999 .3762 Mdot
.38725 .31426 Mdot
.46668 .43552 Mdot
.68961 .56211 Mdot
.40636 .33027 Mdot
.62887 .64908 Mdot
.8519 .41853 Mdot
.55186 .58639 Mdot
.27956 .65605 Mdot
.685 .57244 Mdot
.43252 .38001 Mdot
.76327 .47282 Mdot
.63936 .56976 Mdot
.43874 .36969 Mdot
.59451 .39892 Mdot
.55991 .38653 Mdot
.49663 .60765 Mdot
.61901 .40954 Mdot
.39125 .37505 Mdot
.66641 .32028 Mdot
.65085 .54035 Mdot
.4776 .38544 Mdot
.33834 .47085 Mdot
.41905 .35629 Mdot
.41351 .67691 Mdot
.6991 .60056 Mdot
.41549 .30566 Mdot
.22696 .55461 Mdot
.25161 .73642 Mdot
.4082 .3305 Mdot
.65378 .53928 Mdot
.69195 .54813 Mdot
.48158 .70877 Mdot
.49203 .44646 Mdot
.38526 .34999 Mdot
.57437 .24198 Mdot
.36167 .71121 Mdot
.61067 .25869 Mdot
.78498 .34015 Mdot
.48587 .67528 Mdot
.48481 .6564 Mdot
.59027 .38003 Mdot
.45559 .63277 Mdot
.69406 .52217 Mdot
.43974 .67516 Mdot
.59375 .3727 Mdot
.40566 .32452 Mdot
.44006 .61571 Mdot
.33095 .50732 Mdot
.5707 .36297 Mdot
.53812 .38707 Mdot
.4287 .34398 Mdot
.64787 .57618 Mdot
.41056 .25614 Mdot
.44003 .33676 Mdot
.47517 .66891 Mdot
.60753 .247 Mdot
.48389 .59003 Mdot
.23663 .48546 Mdot
.64018 .54841 Mdot
.41324 .37437 Mdot
.6769 .58839 Mdot
.58046 .38657 Mdot
.36971 .3379 Mdot
.46538 .6268 Mdot
.4427 .36478 Mdot
.28567 .46383 Mdot
.23859 .45209 Mdot
.66353 .52093 Mdot
.31225 .5247 Mdot
.66035 .52802 Mdot
.6119 .25846 Mdot
.27126 .53892 Mdot
.34736 .48693 Mdot
.40853 .35574 Mdot
.21294 .38168 Mdot
.44981 .35907 Mdot
.44641 .6309 Mdot
.44658 .64691 Mdot
.39229 .35719 Mdot
.34495 .51285 Mdot
.62062 .8241 Mdot
.52179 .51548 Mdot
.66771 .5815 Mdot
.76029 .57734 Mdot
.16684 .62642 Mdot
.57159 .35488 Mdot
.59841 .38658 Mdot
.53447 .59091 Mdot
.51998 .62406 Mdot
.53973 .37494 Mdot
.59353 .4187 Mdot
.36553 .50737 Mdot
.44232 .3332 Mdot
.65097 .50704 Mdot
.56058 .36175 Mdot
.41234 .54917 Mdot
.38961 .73742 Mdot
.48901 .70576 Mdot
.43822 .58052 Mdot
.47211 .68703 Mdot
.41736 .45181 Mdot
.60124 .40921 Mdot
.47543 .63876 Mdot
.50329 .571 Mdot
.59124 .40655 Mdot
.32566 .48369 Mdot
.60781 .54566 Mdot
.41861 .33527 Mdot
.75587 .24498 Mdot
.44538 .60582 Mdot
.44349 .62467 Mdot
.55615 .39901 Mdot
.75941 .30979 Mdot
.70636 .55483 Mdot
.64185 .56082 Mdot
.42513 .35983 Mdot
.46671 .43253 Mdot
.43287 .66123 Mdot
.46865 .64487 Mdot
.40987 .35012 Mdot
.59791 .24878 Mdot
.64935 .27253 Mdot
.48339 .62973 Mdot
.57134 .37633 Mdot
.41464 .41123 Mdot
.60068 .41044 Mdot
.50155 .60174 Mdot
.4464 .63392 Mdot
.43433 .65956 Mdot
.52172 .62716 Mdot
.54077 .38333 Mdot
.46815 .64068 Mdot
.40491 .66348 Mdot
.6501 .56868 Mdot
.46476 .67035 Mdot
.35971 .68438 Mdot
.48414 .62139 Mdot
.32796 .50464 Mdot
.42796 .24306 Mdot
.48049 .60597 Mdot
.46549 .66908 Mdot
.52102 .51194 Mdot
.45578 .61156 Mdot
.54999 .3892 Mdot
.68824 .55179 Mdot
.57981 .37962 Mdot
.57705 .41962 Mdot
.38252 .32411 Mdot
.36387 .50995 Mdot
.4222 .6149 Mdot
.33489 .46934 Mdot
.41139 .62367 Mdot
.49824 .59649 Mdot
.3575 .34764 Mdot
.74518 .45889 Mdot
.34801 .43292 Mdot
.46878 .62551 Mdot
.42433 .35532 Mdot
.42257 .3749 Mdot
.24344 .57493 Mdot
.55807 .64403 Mdot
.54268 .37267 Mdot
.59281 .39732 Mdot
.31544 .60265 Mdot
.70337 .48532 Mdot
.32401 .49882 Mdot
.53853 .45498 Mdot
.47977 .68507 Mdot
.49053 .63069 Mdot
.48414 .69544 Mdot
.38228 .33133 Mdot
.59215 .25997 Mdot
.41394 .32118 Mdot
.62259 .27157 Mdot
.60557 .40624 Mdot
.46083 .67874 Mdot
.19439 .54945 Mdot
.68692 .52631 Mdot
.68733 .55112 Mdot
.54677 .36198 Mdot
.38524 .33785 Mdot
.46229 .70932 Mdot
.8523 .60112 Mdot
.63074 .58835 Mdot
.31906 .5147 Mdot
.46987 .64782 Mdot
.42827 .34788 Mdot
.68669 .52405 Mdot
.33919 .46267 Mdot
.45173 .66785 Mdot
.39964 .30247 Mdot
.4802 .61743 Mdot
.54451 .76004 Mdot
.65402 .57259 Mdot
.46592 .15531 Mdot
.65857 .52152 Mdot
.57697 .36211 Mdot
.58554 .41501 Mdot
.44263 .63781 Mdot
.83972 .55251 Mdot
.63247 .57902 Mdot
.61888 .3804 Mdot
.31987 .509 Mdot
.60138 .27233 Mdot
.33963 .51882 Mdot
.39763 .37389 Mdot
.34591 .4962 Mdot
.44949 .34246 Mdot
.31462 .61777 Mdot
.62101 .57044 Mdot
.35408 .48852 Mdot
.72763 .28235 Mdot
.41822 .64784 Mdot
.37058 .4967 Mdot
.39806 .6381 Mdot
.76109 .56599 Mdot
.41193 .34728 Mdot
.34307 .5122 Mdot
.50368 .63272 Mdot
.16629 .49797 Mdot
.58155 .4175 Mdot
.54396 .37273 Mdot
.41605 .62594 Mdot
.45467 .35497 Mdot
.70462 .59509 Mdot
.40962 .49558 Mdot
.62583 .24657 Mdot
.46912 .64281 Mdot
.46078 .67928 Mdot
.63871 .5381 Mdot
.68305 .5129 Mdot
.44585 .63709 Mdot
.60955 .6608 Mdot
.46004 .6412 Mdot
.55684 .38818 Mdot
.70743 .56226 Mdot
.68951 .54804 Mdot
.38732 .37435 Mdot
.65897 .52565 Mdot
.45213 .57334 Mdot
.54595 .42355 Mdot
.53821 .63688 Mdot
.57672 .3903 Mdot
.46633 .47559 Mdot
.42147 .31221 Mdot
.1729 .4556 Mdot
.64248 .53253 Mdot
.46847 .66546 Mdot
.65613 .52994 Mdot
.35125 .47574 Mdot
.66954 .54333 Mdot
.70579 .57826 Mdot
.44484 .65253 Mdot
.50944 .60851 Mdot
.60636 .24274 Mdot
.48936 .4425 Mdot
.6518 .55753 Mdot
.46087 .64583 Mdot
.48425 .57977 Mdot
.43181 .61177 Mdot
.51316 .47755 Mdot
.71223 .55883 Mdot
.6974 .66383 Mdot
.21946 .51969 Mdot
.65432 .56219 Mdot
.14286 .52789 Mdot
.61823 .25894 Mdot
.59599 .27027 Mdot
.58473 .35708 Mdot
.48605 .62872 Mdot
.39133 .33354 Mdot
.47552 .59771 Mdot
.55536 .60082 Mdot
.46397 .59974 Mdot
.32096 .50612 Mdot
.42572 .60492 Mdot
.60418 .26402 Mdot
.43662 .33329 Mdot
.45763 .66576 Mdot
.44525 .6094 Mdot
.5904 .26032 Mdot
.64734 .52659 Mdot
.70227 .57246 Mdot
.37889 .2392 Mdot
.34166 .47801 Mdot
.57462 .40357 Mdot
.49538 .61085 Mdot
.42427 .35724 Mdot
.41839 .32763 Mdot
.65108 .53421 Mdot
.41214 .33617 Mdot
.55255 .38154 Mdot
.46092 .62631 Mdot
.54174 .37588 Mdot
.32012 .5034 Mdot
.65556 .53819 Mdot
.49448 .60948 Mdot
.50822 .62165 Mdot
.66278 .57437 Mdot
.49511 .67908 Mdot
.36479 .50461 Mdot
.44626 .3411 Mdot
.69906 .57342 Mdot
.57818 .39819 Mdot
.38272 .36987 Mdot
.51105 .63032 Mdot
.29334 .7645 Mdot
.45585 .6359 Mdot
.49875 .62491 Mdot
.24858 .30408 Mdot
.53205 .59153 Mdot
.41839 .3809 Mdot
.63433 .55642 Mdot
.43997 .68542 Mdot
.36769 .73851 Mdot
.52846 .17922 Mdot
.37041 .3515 Mdot
.46922 .65514 Mdot
.17983 .43669 Mdot
.4647 .66147 Mdot
.49428 .36753 Mdot
.36344 .38763 Mdot
.32036 .72939 Mdot
.43025 .58494 Mdot
.54491 .39607 Mdot
.6059 .24172 Mdot
.44187 .37393 Mdot
.57726 .78212 Mdot
.45263 .65393 Mdot
.55982 .79414 Mdot
.42761 .62827 Mdot
.55916 .38395 Mdot
.39628 .6823 Mdot
.4059 .33648 Mdot
.80194 .53959 Mdot
.48119 .6655 Mdot
.71152 .55857 Mdot
.37452 .35404 Mdot
.60888 .27103 Mdot
.50511 .62871 Mdot
.3253 .47379 Mdot
.59333 .45114 Mdot
.41498 .59395 Mdot
.57587 .39274 Mdot
.48656 .63936 Mdot
.54794 .64275 Mdot
.82742 .53909 Mdot
.65375 .57466 Mdot
.59878 .39001 Mdot
.76129 .36996 Mdot
.50081 .67703 Mdot
.69214 .57768 Mdot
.68526 .55503 Mdot
.32756 .47695 Mdot
.59537 .46425 Mdot
.63626 .36163 Mdot
.21456 .61588 Mdot
.66118 .75967 Mdot
.39425 .37929 Mdot
.68603 .31913 Mdot
.49824 .66586 Mdot
.54699 .53701 Mdot
.54926 .39438 Mdot
.44576 .62142 Mdot
.70088 .73366 Mdot
.65635 .54538 Mdot
.4805 .62808 Mdot
.32492 .48755 Mdot
.58902 .45742 Mdot
.57528 .51312 Mdot
.22977 .68817 Mdot
.37287 .3449 Mdot
.51866 .67731 Mdot
.41508 .60536 Mdot
.62275 .25992 Mdot
.51107 .60383 Mdot
.43581 .37593 Mdot
.25408 .34948 Mdot
.34174 .51358 Mdot
.67515 .52286 Mdot
.61769 .26056 Mdot
.45968 .6867 Mdot
.45716 .58861 Mdot
.34402 .52445 Mdot
.49476 .64477 Mdot
.81109 .51567 Mdot
.59623 .29616 Mdot
.41927 .36708 Mdot
.65664 .58165 Mdot
.48155 .68728 Mdot
.59245 .25991 Mdot
.44568 .65086 Mdot
.60686 .59855 Mdot
.4797 .65619 Mdot
.63409 .44701 Mdot
.66061 .569 Mdot
.58027 .39211 Mdot
.41301 .63441 Mdot
.46691 .6041 Mdot
.33779 .37342 Mdot
.55482 .60022 Mdot
.43738 .61652 Mdot
.70001 .5188 Mdot
.69641 .53403 Mdot
.67564 .52977 Mdot
.42886 .36743 Mdot
.7489 .47398 Mdot
.57045 .38214 Mdot
.42584 .6505 Mdot
.55993 .36202 Mdot
.47558 .54478 Mdot
.33174 .52282 Mdot
.16354 .55572 Mdot
.45761 .66989 Mdot
.67708 .53241 Mdot
.66249 .34268 Mdot
.71085 .53911 Mdot
.41713 .29836 Mdot
.57246 .37198 Mdot
.65905 .54851 Mdot
.4643 .61014 Mdot
.50789 .45128 Mdot
.25963 .71167 Mdot
.58773 .38243 Mdot
.49861 .69086 Mdot
.37276 .33988 Mdot
.43518 .31541 Mdot
.13049 .56742 Mdot
.59477 .41081 Mdot
.71492 .34791 Mdot
.46101 .64978 Mdot
.68574 .52664 Mdot
.56547 .40937 Mdot
.55055 .4065 Mdot
.40998 .34467 Mdot
.50349 .60601 Mdot
.47493 .60807 Mdot
.61901 .25234 Mdot
.58953 .39868 Mdot
.42105 .66518 Mdot
.5123 .5996 Mdot
.22409 .34053 Mdot
.61357 .5382 Mdot
.78119 .29613 Mdot
.53107 .68112 Mdot
.65946 .76569 Mdot
.45818 .45685 Mdot
.70892 .54553 Mdot
.48993 .60427 Mdot
.46992 .69205 Mdot
.39741 .37877 Mdot
.45928 .631 Mdot
.39657 .32208 Mdot
.5983 .38415 Mdot
.16683 .57112 Mdot
.52099 .35054 Mdot
.24439 .40814 Mdot
.45259 .62878 Mdot
.64812 .4867 Mdot
.35884 .48984 Mdot
.52625 .39112 Mdot
.7019 .54898 Mdot
.50137 .68068 Mdot
.46061 .36916 Mdot
.40724 .35599 Mdot
.67654 .55388 Mdot
.71357 .37536 Mdot
.35848 .2722 Mdot
.5227 .61884 Mdot
.40363 .37048 Mdot
.54545 .32506 Mdot
.60822 .67299 Mdot
.59977 .42672 Mdot
.33752 .51394 Mdot
.40596 .32497 Mdot
.53703 .39366 Mdot
.60849 .58917 Mdot
.66642 .5553 Mdot
.63079 .56089 Mdot
.30287 .42344 Mdot
.38624 .34417 Mdot
.35495 .50207 Mdot
.73561 .48767 Mdot
.75844 .50678 Mdot
.32433 .50927 Mdot
.40454 .32457 Mdot
.69267 .5287 Mdot
.69956 .5533 Mdot
.68937 .55243 Mdot
.79921 .54315 Mdot
.64173 .54866 Mdot
.7172 .6395 Mdot
.48383 .58107 Mdot
.56889 .68108 Mdot
.46591 .65967 Mdot
.54308 .38562 Mdot
.65546 .57355 Mdot
.46614 .44407 Mdot
.52091 .65296 Mdot
.23229 .6861 Mdot
.47212 .64286 Mdot
.57092 .43214 Mdot
.48711 .62633 Mdot
.60348 .62842 Mdot
.641 .58521 Mdot
.46816 .62749 Mdot
.59625 .42299 Mdot
.33607 .48876 Mdot
.68518 .50392 Mdot
.47943 .60594 Mdot
.65549 .45744 Mdot
.51129 .5747 Mdot
.25415 .3382 Mdot
.39551 .5154 Mdot
.31511 .50893 Mdot
.48527 .56829 Mdot
.38163 .3742 Mdot
.73353 .53354 Mdot
.5565 .69026 Mdot
.5882 .3837 Mdot
.54214 .8149 Mdot
.41106 .35823 Mdot
.39748 .68536 Mdot
.53028 .61382 Mdot
.3671 .49512 Mdot
.73449 .54999 Mdot
.5525 .39633 Mdot
.46892 .68121 Mdot
.44198 .60397 Mdot
.25489 .49134 Mdot
.57024 .67072 Mdot
.42382 .61953 Mdot
.36164 .51617 Mdot
.70544 .66583 Mdot
.49133 .61788 Mdot
.38017 .31509 Mdot
.64005 .57841 Mdot
.42269 .6037 Mdot
.69388 .66029 Mdot
.45919 .6472 Mdot
.66512 .54852 Mdot
.63774 .53725 Mdot
.67195 .40359 Mdot
.31409 .50447 Mdot
.48005 .65578 Mdot
.39115 .4856 Mdot
.48162 .6617 Mdot
.56708 .38075 Mdot
.4844 .59616 Mdot
.41553 .35281 Mdot
.76226 .46851 Mdot
.43862 .36221 Mdot
.48185 .59772 Mdot
.69365 .55691 Mdot
.55421 .40344 Mdot
.27129 .44856 Mdot
.35282 .37336 Mdot
.71761 .64262 Mdot
.57465 .18304 Mdot
.35775 .50706 Mdot
.37039 .4818 Mdot
.6106 .37961 Mdot
.47273 .62524 Mdot
.39434 .44361 Mdot
.50785 .58183 Mdot
.48881 .62289 Mdot
.46361 .59847 Mdot
.621 .40918 Mdot
.58052 .37685 Mdot
.42161 .33141 Mdot
.44725 .63661 Mdot
.46183 .64425 Mdot
.6577 .55971 Mdot
.33702 .48656 Mdot
.43436 .36807 Mdot
.34906 .4794 Mdot
.43918 .34475 Mdot
.13655 .49344 Mdot
.51478 .68987 Mdot
.33426 .48913 Mdot
.61318 .38471 Mdot
.66433 .53181 Mdot
.60154 .23834 Mdot
.3931 .37272 Mdot
.40447 .33505 Mdot
.46741 .64423 Mdot
.66042 .53814 Mdot
.64889 .54715 Mdot
.3609 .48223 Mdot
.57925 .4082 Mdot
.48145 .5983 Mdot
.51548 .61069 Mdot
.24386 .61885 Mdot
.37882 .34894 Mdot
.62809 .66199 Mdot
.68336 .41149 Mdot
.47211 .62438 Mdot
.64916 .57256 Mdot
.43708 .6222 Mdot
.18435 .46735 Mdot
.6566 .5849 Mdot
.52382 .62634 Mdot
.72867 .49735 Mdot
.38845 .32041 Mdot
.6492 .41325 Mdot
.45535 .58533 Mdot
.50114 .16654 Mdot
.49396 .66234 Mdot
.2139 .31431 Mdot
.71567 .30739 Mdot
.44388 .67689 Mdot
.51466 .64929 Mdot
.23662 .65699 Mdot
.46114 .65501 Mdot
.6098 .26329 Mdot
.53794 .67517 Mdot
.70676 .5683 Mdot
.41525 .46822 Mdot
.42839 .29645 Mdot
.31586 .50383 Mdot
.42495 .36031 Mdot
.28717 .49483 Mdot
.32825 .48087 Mdot
.69012 .5724 Mdot
.51852 .64323 Mdot
.39351 .72686 Mdot
.42548 .30282 Mdot
.52281 .59563 Mdot
.56582 .38028 Mdot
.41508 .29339 Mdot
.40919 .31628 Mdot
.58304 .39533 Mdot
.42716 .63679 Mdot
.41954 .78406 Mdot
.34656 .33197 Mdot
.38006 .20311 Mdot
.55835 .4021 Mdot
.55879 .37984 Mdot
.77828 .48473 Mdot
.31561 .50256 Mdot
.24762 .51019 Mdot
.61215 .51273 Mdot
.56232 .36988 Mdot
.32185 .5796 Mdot
.45484 .36524 Mdot
.65176 .46469 Mdot
.65313 .59672 Mdot
.50716 .69297 Mdot
.46517 .60811 Mdot
.58404 .40864 Mdot
.40894 .72931 Mdot
.80421 .47339 Mdot
.58622 .38631 Mdot
.40598 .6322 Mdot
.58724 .46022 Mdot
.61064 .24796 Mdot
.62053 .25062 Mdot
.32498 .51594 Mdot
.34485 .27931 Mdot
.67101 .56853 Mdot
.36727 .48615 Mdot
.62813 .43961 Mdot
.48406 .65018 Mdot
.59301 .39225 Mdot
.60029 .23744 Mdot
.56539 .39459 Mdot
.32893 .49851 Mdot
.31998 .51559 Mdot
.65067 .56999 Mdot
.706 .55486 Mdot
.65167 .77459 Mdot
.3322 .61792 Mdot
.46205 .6637 Mdot
.48954 .78947 Mdot
.65126 .53752 Mdot
.57068 .65686 Mdot
.31511 .4834 Mdot
.33494 .48484 Mdot
.57072 .73946 Mdot
.51045 .61768 Mdot
.46998 .39389 Mdot
.48593 .61042 Mdot
.26854 .54778 Mdot
.52889 .62964 Mdot
.41126 .3412 Mdot
.475 .67467 Mdot
.42333 .25466 Mdot
.50243 .66942 Mdot
.44424 .60778 Mdot
.42624 .32322 Mdot
.44546 .70072 Mdot
.41393 .35365 Mdot
.50154 .60285 Mdot
.37179 .51005 Mdot
.42458 .35743 Mdot
.29602 .67223 Mdot
.508 .49815 Mdot
.59546 .26277 Mdot
.31876 .49154 Mdot
.33867 .4698 Mdot
.37123 .71348 Mdot
.70285 .55274 Mdot
.61134 .57363 Mdot
.47351 .62583 Mdot
.45172 .36901 Mdot
.59037 .37927 Mdot
.46076 .64368 Mdot
.48996 .69018 Mdot
.43683 .59881 Mdot
.65383 .54852 Mdot
.38564 .33895 Mdot
.33532 .49416 Mdot
.41244 .37158 Mdot
.33147 .3361 Mdot
.4487 .33609 Mdot
.51892 .5747 Mdot
.45652 .69843 Mdot
.56696 .58251 Mdot
.54915 .80221 Mdot
.78324 .56964 Mdot
.67204 .55673 Mdot
.60012 .25292 Mdot
.3273 .51999 Mdot
.751 .58602 Mdot
.68945 .53678 Mdot
.4001 .33447 Mdot
.48007 .61722 Mdot
.40519 .65558 Mdot
.59164 .51009 Mdot
.74266 .56492 Mdot
.35093 .70379 Mdot
.42953 .31841 Mdot
.61127 .25489 Mdot
.75807 .47768 Mdot
.75226 .5684 Mdot
.45673 .44254 Mdot
.45209 .60649 Mdot
.32467 .47364 Mdot
.68652 .52399 Mdot
.29926 .43744 Mdot
.58982 .40355 Mdot
.4917 .44513 Mdot
.45387 .62904 Mdot
.6793 .33685 Mdot
.69301 .55735 Mdot
.32344 .49136 Mdot
.58492 .40871 Mdot
.31281 .49919 Mdot
.6213 .2548 Mdot
.36586 .24253 Mdot
.49194 .65267 Mdot
.43168 .62857 Mdot
.61685 .38781 Mdot
.67323 .56725 Mdot
.40517 .42897 Mdot
.25073 .48805 Mdot
.39992 .36715 Mdot
.38586 .43001 Mdot
.70837 .54163 Mdot
.64854 .61919 Mdot
.41924 .37077 Mdot
.54746 .36137 Mdot
.41859 .45555 Mdot
.60093 .37897 Mdot
.484 .60695 Mdot
.67956 .5381 Mdot
.59786 .40841 Mdot
.33461 .38952 Mdot
.17355 .42027 Mdot
.59831 .6097 Mdot
.46018 .67647 Mdot
.16815 .56601 Mdot
.25133 .31876 Mdot
.39583 .71254 Mdot
.58147 .36583 Mdot
.43892 .63888 Mdot
.52256 .61331 Mdot
.47893 .6687 Mdot
.60422 .3925 Mdot
.29767 .35311 Mdot
.40198 .3436 Mdot
.47417 .64617 Mdot
.34164 .47101 Mdot
.41934 .3455 Mdot
.38625 .38364 Mdot
.4487 .36689 Mdot
.70044 .58056 Mdot
.52266 .62692 Mdot
.70922 .45397 Mdot
.19953 .33113 Mdot
.58144 .37998 Mdot
.59592 .26338 Mdot
.42973 .62718 Mdot
.75679 .67893 Mdot
.67633 .53018 Mdot
.39784 .36533 Mdot
.44362 .62341 Mdot
.31912 .3568 Mdot
.61084 .28449 Mdot
.43966 .33301 Mdot
.70117 .5545 Mdot
.393 .70521 Mdot
.45954 .63227 Mdot
.49555 .65871 Mdot
.67688 .57168 Mdot
.38508 .22831 Mdot
.74972 .46407 Mdot
.44196 .61393 Mdot
.58167 .39256 Mdot
.85146 .46778 Mdot
.44202 .59572 Mdot
.6889 .60521 Mdot
.60115 .27274 Mdot
.66401 .44459 Mdot
.62902 .6671 Mdot
.54619 .59024 Mdot
.18096 .565 Mdot
.3678 .63378 Mdot
.15394 .55234 Mdot
.33008 .45471 Mdot
.52024 .29936 Mdot
.13357 .47363 Mdot
.59741 .42328 Mdot
.57959 .65038 Mdot
.29119 .71129 Mdot
.72297 .39889 Mdot
.39879 .51568 Mdot
.54571 .20352 Mdot
.34674 .37695 Mdot
.64889 .20944 Mdot
.44398 .36665 Mdot
.25663 .54638 Mdot
.47585 .59656 Mdot
.2634 .30528 Mdot
.61198 .64433 Mdot
.82126 .50461 Mdot
.15435 .53367 Mdot
.39246 .50492 Mdot
.27872 .72364 Mdot
.18702 .43413 Mdot
.43601 .7727 Mdot
.60215 .49631 Mdot
.58179 .24449 Mdot
.74507 .49215 Mdot
.28707 .52716 Mdot
.51118 .69912 Mdot
.44625 .24446 Mdot
.29446 .30919 Mdot
.7185 .68155 Mdot
.83706 .50477 Mdot
.40406 .37781 Mdot
.64263 .58265 Mdot
.24105 .62288 Mdot
.7115 .51226 Mdot
.54059 .42765 Mdot
.18087 .56633 Mdot
.21307 .34655 Mdot
.60544 .62794 Mdot
.53705 .16129 Mdot
.57982 .76475 Mdot
.67276 .79231 Mdot
.53016 .49579 Mdot
.62956 .55196 Mdot
.53349 .27151 Mdot
.75893 .50793 Mdot
.60487 .31892 Mdot
.73724 .60256 Mdot
.30262 .48657 Mdot
.31722 .67622 Mdot
.69746 .55866 Mdot
.61953 .67555 Mdot
.60692 .27791 Mdot
.6379 .41714 Mdot
.36027 .35805 Mdot
.18174 .4852 Mdot
.63053 .22406 Mdot
.67181 .45987 Mdot
.66403 .30848 Mdot
.28023 .75663 Mdot
.35202 .58466 Mdot
.20539 .43145 Mdot
.61827 .3514 Mdot
.37321 .60633 Mdot
.76395 .44246 Mdot
.34252 .63227 Mdot
.76869 .52371 Mdot
.39018 .81172 Mdot
.2988 .26472 Mdot
.31406 .76712 Mdot
.6936 .50974 Mdot
.42396 .62123 Mdot
.20124 .49999 Mdot
.66311 .7558 Mdot
.31376 .50874 Mdot
.25661 .72031 Mdot
.32453 .47095 Mdot
.68294 .50678 Mdot
.72005 .38454 Mdot
.67468 .62549 Mdot
.46235 .31376 Mdot
.37687 .48881 Mdot
.47891 .57152 Mdot
.59107 .87029 Mdot
.18697 .59502 Mdot
.67098 .41738 Mdot
.22358 .33808 Mdot
.6153 .36096 Mdot
.4457 .42025 Mdot
.59994 .38482 Mdot
.1547 .441 Mdot
.69174 .54258 Mdot
.1684 .367 Mdot
.16975 .41176 Mdot
.80311 .4029 Mdot
.70613 .82717 Mdot
.66265 .25528 Mdot
.57352 .6792 Mdot
.39798 .74284 Mdot
.33941 .71586 Mdot
.78448 .45169 Mdot
.79406 .37963 Mdot
.62944 .41622 Mdot
.36835 .22841 Mdot
.14676 .47866 Mdot
.30014 .57088 Mdot
.27417 .33883 Mdot
.73812 .40937 Mdot
.50055 .48669 Mdot
.66545 .60751 Mdot
.48884 .5035 Mdot
.56935 .54465 Mdot
.29153 .74477 Mdot
.73239 .70033 Mdot
.85179 .5589 Mdot
.30347 .46057 Mdot
.76966 .32683 Mdot
.2314 .36125 Mdot
.28277 .65061 Mdot
.71615 .61046 Mdot
.7128 .43018 Mdot
.51041 .57255 Mdot
.7398 .46837 Mdot
.42619 .71111 Mdot
.3101 .52508 Mdot
.76907 .48467 Mdot
.50146 .34253 Mdot
.27182 .51874 Mdot
.20859 .58382 Mdot
.67793 .48447 Mdot
.69502 .58135 Mdot
.35509 .65334 Mdot
.3384 .58175 Mdot
.22644 .34405 Mdot
.75924 .36911 Mdot
.36742 .21155 Mdot
.77527 .37629 Mdot
.50532 .58032 Mdot
.57318 .65595 Mdot
.47979 .71095 Mdot
.34539 .61067 Mdot
.47947 .57735 Mdot
.65849 .32072 Mdot
.23569 .31691 Mdot
.70891 .72767 Mdot
.28053 .51175 Mdot
.51921 .80091 Mdot
.34096 .23504 Mdot
.20726 .50906 Mdot
.71461 .31451 Mdot
.49173 .74278 Mdot
.50616 .86376 Mdot
.4248 .33953 Mdot
.31724 .58099 Mdot
.53419 .39076 Mdot
.29941 .42862 Mdot
.33456 .75122 Mdot
.80265 .41568 Mdot
.24018 .31059 Mdot
.72231 .43589 Mdot
.37699 .39739 Mdot
.50684 .41902 Mdot
.43254 .29045 Mdot
.50649 .80177 Mdot
.42196 .68268 Mdot
.45776 .54069 Mdot
.36597 .47871 Mdot
.66676 .74318 Mdot
.21966 .50617 Mdot
.49672 .20744 Mdot
.50685 .5634 Mdot
.50042 .23766 Mdot
.6143 .2558 Mdot
.49981 .44675 Mdot
.12938 .55442 Mdot
.557 .62688 Mdot
.68338 .27241 Mdot
.3118 .25397 Mdot
.40693 .45044 Mdot
.22041 .41727 Mdot
.69091 .37932 Mdot
.35293 .78982 Mdot
.18699 .36986 Mdot
.37301 .26434 Mdot
.16763 .58026 Mdot
.3686 .1866 Mdot
.39905 .80582 Mdot
.52042 .78386 Mdot
.54634 .41858 Mdot
.19197 .28667 Mdot
.39542 .35111 Mdot
.56686 .81582 Mdot
.67294 .75065 Mdot
.30519 .37273 Mdot
.72219 .57779 Mdot
.38926 .63507 Mdot
.61941 .21496 Mdot
.62725 .58051 Mdot
.47699 .5707 Mdot
.23859 .7165 Mdot
.40838 .82683 Mdot
.25087 .72463 Mdot
.34994 .24384 Mdot
.16352 .57255 Mdot
.27271 .68519 Mdot
.7204 .63525 Mdot
.23171 .55633 Mdot
.49084 .59805 Mdot
.29736 .59362 Mdot
.66886 .26313 Mdot
.37108 .39522 Mdot
.62413 .33259 Mdot
.72043 .5668 Mdot
.35302 .77872 Mdot
.13058 .5878 Mdot
.59603 .73798 Mdot
.67188 .67856 Mdot
.55806 .52946 Mdot
.33489 .60542 Mdot
.39984 .54721 Mdot
.45527 .22655 Mdot
.2299 .3505 Mdot
.28376 .70545 Mdot
.31404 .56334 Mdot
.53057 .2154 Mdot
.45164 .29058 Mdot
.75483 .31536 Mdot
.17275 .47077 Mdot
.26833 .65707 Mdot
.78656 .37748 Mdot
.48184 .75087 Mdot
.80563 .45799 Mdot
.44631 .20673 Mdot
.43251 .41537 Mdot
.34694 .56916 Mdot
.41864 .31028 Mdot
.29932 .57605 Mdot
.59156 .4784 Mdot
.2289 .59215 Mdot
.36803 .65629 Mdot
.29181 .5677 Mdot
.44458 .28638 Mdot
.20557 .66559 Mdot
.41683 .16891 Mdot
.47602 .82835 Mdot
.47562 .17126 Mdot
.42621 .71274 Mdot
.45504 .59215 Mdot
.27575 .27721 Mdot
.19358 .66016 Mdot
.20255 .33675 Mdot
.67868 .33161 Mdot
.32753 .38714 Mdot
.57985 .43016 Mdot
.50208 .82019 Mdot
.4852 .18946 Mdot
.20276 .3782 Mdot
.7754 .55182 Mdot
.58171 .35652 Mdot
.73192 .44049 Mdot
.53031 .81268 Mdot
.43308 .77679 Mdot
.62648 .68862 Mdot
.50999 .69798 Mdot
.59639 .66529 Mdot
.63551 .57172 Mdot
.68563 .32589 Mdot
.34127 .62099 Mdot
.42769 .34376 Mdot
.28785 .67757 Mdot
.48906 .54271 Mdot
.51423 .57395 Mdot
.41358 .41741 Mdot
.64887 .6017 Mdot
.57608 .80019 Mdot
.62678 .42325 Mdot
.13047 .48934 Mdot
.68076 .28747 Mdot
.38526 .59423 Mdot
.36047 .62112 Mdot
.30007 .44593 Mdot
.7269 .45785 Mdot
.60802 .38032 Mdot
.15788 .50747 Mdot
.45675 .50029 Mdot
.35603 .64605 Mdot
.59841 .66708 Mdot
.24451 .48914 Mdot
.49643 .6876 Mdot
.67809 .38569 Mdot
.74429 .64403 Mdot
.4906 .43877 Mdot
.65536 .50863 Mdot
.64022 .59887 Mdot
.61933 .17038 Mdot
.44722 .26981 Mdot
.75134 .34496 Mdot
.16192 .506 Mdot
.5965 .37669 Mdot
.71749 .54477 Mdot
.28654 .57373 Mdot
.2445 .45049 Mdot
.73756 .66926 Mdot
.4372 .39119 Mdot
.36191 .55118 Mdot
.48075 .20221 Mdot
.17091 .56768 Mdot
.226 .66617 Mdot
.83031 .53933 Mdot
.6771 .51738 Mdot
.23394 .48111 Mdot
.24947 .47283 Mdot
.67299 .5203 Mdot
.74029 .57394 Mdot
.60138 .50287 Mdot
.14554 .55841 Mdot
.72858 .46757 Mdot
.44451 .18418 Mdot
.41482 .45526 Mdot
.3109 .35105 Mdot
.28338 .45126 Mdot
.33938 .55981 Mdot
.16504 .50512 Mdot
.61094 .68599 Mdot
.38073 .77327 Mdot
.51124 .70067 Mdot
.66678 .77166 Mdot
.50701 .82167 Mdot
.52042 .48788 Mdot
.63676 .6178 Mdot
.50423 .35188 Mdot
.47249 .66945 Mdot
.2768 .75443 Mdot
.25134 .33027 Mdot
.77866 .50733 Mdot
.6229 .43136 Mdot
.51059 .63944 Mdot
.49932 .58647 Mdot
.41513 .73 Mdot
.6737 .4311 Mdot
.44954 .82479 Mdot
.27044 .50865 Mdot
.43844 .72238 Mdot
.60768 .65849 Mdot
.68512 .27478 Mdot
.18653 .49442 Mdot
.24173 .34889 Mdot
.56572 .47808 Mdot
.67019 .26799 Mdot
.46903 .41951 Mdot
.43783 .1818 Mdot
.48055 .2437 Mdot
.26247 .67002 Mdot
.62717 .50732 Mdot
.6936 .42678 Mdot
.31104 .43795 Mdot
.43603 .61508 Mdot
.71334 .37571 Mdot
.18354 .44483 Mdot
.84513 .5981 Mdot
.76635 .43422 Mdot
.22367 .70583 Mdot
.55301 .56984 Mdot
.69724 .4346 Mdot
.35409 .76873 Mdot
.83235 .6519 Mdot
.44824 .23551 Mdot
.28292 .73163 Mdot
.4941 .40928 Mdot
.15942 .52229 Mdot
.54836 .41338 Mdot
.69226 .47712 Mdot
.52914 .79708 Mdot
.14342 .55156 Mdot
.20388 .46764 Mdot
.17458 .5104 Mdot
.45576 .75909 Mdot
.15999 .58667 Mdot
.76964 .55047 Mdot
.66036 .21041 Mdot
.36808 .33772 Mdot
.64187 .30503 Mdot
.49982 .76748 Mdot
.56659 .56564 Mdot
.3185 .57421 Mdot
.73481 .27552 Mdot
.75824 .59989 Mdot
.46928 .7699 Mdot
.27691 .61192 Mdot
.69105 .39386 Mdot
.36298 .61754 Mdot
.19121 .39447 Mdot
.65043 .20773 Mdot
.27032 .45782 Mdot
.72385 .33679 Mdot
.36782 .23824 Mdot
.66926 .4305 Mdot
.48592 .27987 Mdot
.20384 .43223 Mdot
.42159 .21102 Mdot
.38045 .54868 Mdot
.65407 .16435 Mdot
.30076 .31276 Mdot
.59823 .50594 Mdot
.33251 .77257 Mdot
.23527 .34667 Mdot
.77323 .56161 Mdot
.8139 .49882 Mdot
.65303 .78424 Mdot
.31338 .6203 Mdot
.46478 .59977 Mdot
.16154 .60068 Mdot
.30567 .66117 Mdot
.27332 .73416 Mdot
.31331 .23865 Mdot
.57985 .69081 Mdot
.54473 .59542 Mdot
.43186 .38316 Mdot
.5583 .51202 Mdot
.26942 .60171 Mdot
.28605 .72227 Mdot
.61739 .80354 Mdot
.38044 .43079 Mdot
.51899 .28793 Mdot
.44305 .39172 Mdot
.49518 .72519 Mdot
.65857 .26679 Mdot
.68638 .41522 Mdot
.29395 .4737 Mdot
.43243 .27422 Mdot
.33298 .59408 Mdot
.62624 .66458 Mdot
.42726 .77716 Mdot
.79387 .42691 Mdot
.51474 .39633 Mdot
.40486 .37991 Mdot
.22333 .62817 Mdot
.30831 .29365 Mdot
.65755 .32531 Mdot
.43431 .80516 Mdot
.71473 .42541 Mdot
.25292 .55489 Mdot
.21768 .54219 Mdot
.78475 .44264 Mdot
.58249 .23245 Mdot
.45789 .7928 Mdot
.6692 .76984 Mdot
.47604 .37825 Mdot
.45689 .55459 Mdot
.13785 .49577 Mdot
.34124 .56384 Mdot
.22203 .57014 Mdot
.51742 .50045 Mdot
.68831 .7195 Mdot
.53211 .73956 Mdot
.30954 .69399 Mdot
.47038 .43317 Mdot
.55869 .86832 Mdot
.7008 .59327 Mdot
.28288 .76039 Mdot
.58015 .4018 Mdot
.8053 .59948 Mdot
.40356 .27029 Mdot
.5641 .48688 Mdot
.44463 .45365 Mdot
.6755 .38729 Mdot
.62981 .45882 Mdot
.3585 .23622 Mdot
.80649 .44297 Mdot
.45008 .33864 Mdot
.39131 .45784 Mdot
.44471 .19061 Mdot
.20731 .60525 Mdot
.43156 .67695 Mdot
.31674 .29354 Mdot
.51464 .4866 Mdot
.37362 .40285 Mdot
.27757 .2784 Mdot
.52186 .34045 Mdot
.41118 .62215 Mdot
.33543 .60954 Mdot
.30005 .74221 Mdot
.17776 .40157 Mdot
.80066 .49521 Mdot
.42712 .7118 Mdot
.54147 .41707 Mdot
.32335 .72857 Mdot
.18883 .58659 Mdot
.48159 .38515 Mdot
.68722 .46536 Mdot
.3477 .58026 Mdot
.31418 .80577 Mdot
.40065 .82062 Mdot
.45776 .82251 Mdot
.40177 .45046 Mdot
.62748 .53405 Mdot
.74864 .68788 Mdot
.22236 .56599 Mdot
.6323 .31467 Mdot
.30015 .29068 Mdot
.32315 .58355 Mdot
.81339 .66058 Mdot
.73422 .61136 Mdot
.33117 .33033 Mdot
.5332 .74125 Mdot
.64225 .76817 Mdot
.56602 .4241 Mdot
.30352 .62427 Mdot
.41866 .51032 Mdot
.58483 .36231 Mdot
.69046 .39841 Mdot
.64719 .46089 Mdot
.22211 .57304 Mdot
.73199 .66061 Mdot
.45281 .72196 Mdot
.19954 .57516 Mdot
.62124 .55676 Mdot
.29346 .44 Mdot
.27519 .46696 Mdot
.40407 .50698 Mdot
.40485 .36591 Mdot
.56558 .62148 Mdot
.51116 .44187 Mdot
.48463 .41609 Mdot
.55221 .83599 Mdot
.33006 .46761 Mdot
.70532 .58333 Mdot
.79257 .55585 Mdot
.68583 .5188 Mdot
.18051 .6488 Mdot
.45581 .22789 Mdot
.60424 .65591 Mdot
.36128 .27922 Mdot
.52936 .2416 Mdot
.6776 .80133 Mdot
.48371 .80113 Mdot
.51677 .51526 Mdot
.74533 .58307 Mdot
.64622 .53348 Mdot
.45328 .30554 Mdot
.58984 .23915 Mdot
.63961 .67941 Mdot
.67831 .25918 Mdot
.23695 .5484 Mdot
.63477 .53834 Mdot
.3207 .33136 Mdot
.38302 .60432 Mdot
.13007 .52665 Mdot
.43651 .37371 Mdot
.47579 .85409 Mdot
.4637 .70081 Mdot
.35985 .76078 Mdot
.26824 .28387 Mdot
.76587 .46642 Mdot
.38119 .4245 Mdot
.56977 .20521 Mdot
.43896 .67683 Mdot
.47279 .72244 Mdot
.69863 .56216 Mdot
.24302 .51794 Mdot
.34582 .49196 Mdot
.34457 .68266 Mdot
.57302 .35873 Mdot
.78551 .35848 Mdot
.66238 .27547 Mdot
.64872 .5902 Mdot
.44662 .50991 Mdot
.20931 .48509 Mdot
.64126 .48026 Mdot
.51235 .48512 Mdot
.23466 .65208 Mdot
.73135 .67628 Mdot
.63642 .53734 Mdot
.43763 .80924 Mdot
.26151 .50053 Mdot
.15845 .41872 Mdot
.40485 .57242 Mdot
.54797 .50207 Mdot
.65081 .48119 Mdot
.68118 .379 Mdot
.63482 .66866 Mdot
.22875 .3557 Mdot
.35027 .64358 Mdot
.74173 .49751 Mdot
.29172 .56988 Mdot
.42577 .69766 Mdot
.51496 .2883 Mdot
.64235 .29118 Mdot
.79575 .68317 Mdot
.55562 .76309 Mdot
.75339 .44812 Mdot
.68923 .60991 Mdot
.6815 .271 Mdot
.70266 .58788 Mdot
.27518 .40025 Mdot
.71928 .68705 Mdot
.38319 .26834 Mdot
.14613 .46223 Mdot
.22995 .34201 Mdot
.58007 .53195 Mdot
.41711 .40489 Mdot
.36948 .64112 Mdot
.38415 .60581 Mdot
.4862 .45712 Mdot
.43445 .66935 Mdot
.46669 .73664 Mdot
.7955 .49383 Mdot
.66108 .34013 Mdot
.38976 .64393 Mdot
.14567 .52665 Mdot
.16528 .40561 Mdot
.18024 .6161 Mdot
.46281 .4014 Mdot
.70817 .57549 Mdot
.36364 .79623 Mdot
.6593 .64724 Mdot
.19019 .39234 Mdot
.50486 .77086 Mdot
.60023 .16221 Mdot
.32489 .748 Mdot
.49963 .34906 Mdot
.80139 .39554 Mdot
.64499 .3787 Mdot
.28184 .27993 Mdot
.65937 .20978 Mdot
.3178 .54046 Mdot
.28759 .26958 Mdot
.58855 .86965 Mdot
.53584 .77786 Mdot
.66093 .4591 Mdot
.5312 .72783 Mdot
.37603 .60975 Mdot
.67548 .24665 Mdot
.48152 .59392 Mdot
.41006 .30499 Mdot
.37199 .42225 Mdot
.33218 .58775 Mdot
.52493 .56077 Mdot
.68302 .25225 Mdot
.26498 .59529 Mdot
.25644 .53938 Mdot
.25127 .46162 Mdot
.2984 .72797 Mdot
.64373 .67196 Mdot
.41504 .60793 Mdot
.65686 .50487 Mdot
.32781 .5158 Mdot
.28905 .50614 Mdot
.51902 .61783 Mdot
.38183 .41961 Mdot
.6133 .50089 Mdot
.23788 .71879 Mdot
.26134 .42748 Mdot
.24143 .40289 Mdot
.63546 .59316 Mdot
.67854 .41843 Mdot
.19889 .52157 Mdot
.72162 .39345 Mdot
.70173 .26354 Mdot
.72732 .70625 Mdot
.1729 .57443 Mdot
.71214 .43851 Mdot
.28981 .54325 Mdot
.61183 .82703 Mdot
.54964 .37668 Mdot
.58084 .79453 Mdot
.27384 .69305 Mdot
.71187 .40081 Mdot
.67896 .50889 Mdot
.4919 .32493 Mdot
.53093 .30392 Mdot
.70346 .39824 Mdot
.31593 .25076 Mdot
.23025 .4957 Mdot
.55561 .7249 Mdot
.21438 .64388 Mdot
.37579 .34019 Mdot
.31267 .56431 Mdot
.47276 .29531 Mdot
.66343 .22864 Mdot
.67861 .48226 Mdot
.13816 .50693 Mdot
.47697 .45236 Mdot
.30941 .67341 Mdot
.49203 .65655 Mdot
.69755 .66141 Mdot
.66713 .35705 Mdot
.46169 .29753 Mdot
.75115 .35375 Mdot
.67399 .58685 Mdot
.6689 .29921 Mdot
.58682 .28598 Mdot
.31185 .63849 Mdot
.47974 .5382 Mdot
.62387 .51686 Mdot
.35341 .45408 Mdot
.62419 .26516 Mdot
.42658 .67724 Mdot
.32929 .6951 Mdot
.45249 .299 Mdot
.55525 .79503 Mdot
.52929 .78419 Mdot
.2238 .6315 Mdot
.25286 .34968 Mdot
.65123 .32292 Mdot
.49559 .77699 Mdot
.63462 .44301 Mdot
.71416 .62403 Mdot
.73096 .37717 Mdot
.45813 .58313 Mdot
.27795 .39622 Mdot
.71518 .54897 Mdot
.21013 .61597 Mdot
.59723 .59328 Mdot
.29337 .66852 Mdot
.52679 .46851 Mdot
.19641 .49748 Mdot
.48087 .48457 Mdot
.27012 .28423 Mdot
.64397 .37289 Mdot
.34152 .62375 Mdot
.60753 .36216 Mdot
.49498 .40552 Mdot
.77078 .4312 Mdot
.16202 .46347 Mdot
.7995 .42615 Mdot
.40395 .74315 Mdot
.7431 .44216 Mdot
.68441 .75459 Mdot
.29843 .25192 Mdot
.33137 .63085 Mdot
.48827 .45793 Mdot
.39589 .55795 Mdot
.634 .42841 Mdot
.59941 .2412 Mdot
.29278 .39365 Mdot
.65489 .66017 Mdot
.26143 .37894 Mdot
.35188 .32588 Mdot
.41785 .65331 Mdot
.76139 .67244 Mdot
.20259 .61909 Mdot
.76034 .57843 Mdot
.54897 .48844 Mdot
.33884 .42192 Mdot
.31496 .64873 Mdot
.81961 .31732 Mdot
.27287 .7524 Mdot
.49302 .65501 Mdot
.41829 .46086 Mdot
.33833 .67499 Mdot
.39909 .32077 Mdot
.64154 .68615 Mdot
.22077 .6282 Mdot
.56195 .37442 Mdot
.32289 .39723 Mdot
.60476 .30407 Mdot
.6708 .37827 Mdot
.30496 .69452 Mdot
.6203 .40648 Mdot
.19858 .67602 Mdot
.32244 .27951 Mdot
.67183 .35451 Mdot
.72525 .21551 Mdot
.67036 .32262 Mdot
.61579 .56208 Mdot
.19898 .46194 Mdot
.20145 .65936 Mdot
.40461 .45158 Mdot
.30242 .42401 Mdot
.53339 .78574 Mdot
.34415 .63297 Mdot
.26691 .53793 Mdot
.72185 .33535 Mdot
.68102 .3071 Mdot
.66826 .21706 Mdot
.53 .23965 Mdot
.57073 .83911 Mdot
.60441 .67983 Mdot
.22884 .67573 Mdot
.44967 .2321 Mdot
.82031 .64778 Mdot
.1547 .44196 Mdot
.29015 .59682 Mdot
.69947 .27 Mdot
.20633 .44299 Mdot
.3601 .70719 Mdot
.76457 .64542 Mdot
.43029 .23603 Mdot
.72958 .68966 Mdot
.51702 .23495 Mdot
.74383 .37442 Mdot
.29616 .57279 Mdot
.65852 .76453 Mdot
.47308 .44875 Mdot
.26564 .6986 Mdot
.76688 .31208 Mdot
.36055 .60863 Mdot
.33408 .4004 Mdot
.36708 .73224 Mdot
.19481 .58002 Mdot
.1968 .43285 Mdot
.47254 .46225 Mdot
.59458 .86387 Mdot
.28999 .74183 Mdot
.73179 .39559 Mdot
.47941 .58104 Mdot
.14213 .45388 Mdot
.43489 .47814 Mdot
.4966 .78003 Mdot
.29446 .28202 Mdot
.27612 .49328 Mdot
.63479 .49364 Mdot
.42993 .6063 Mdot
.47534 .80146 Mdot
.61986 .61281 Mdot
.63892 .77189 Mdot
.36176 .42851 Mdot
.3587 .62531 Mdot
.77276 .32395 Mdot
.34366 .72874 Mdot
.38463 .6105 Mdot
.71127 .54496 Mdot
.21684 .69018 Mdot
.4315 .76859 Mdot
.56758 .63272 Mdot
.55441 .70007 Mdot
.80245 .43347 Mdot
.60214 .20221 Mdot
.41481 .69598 Mdot
.72352 .4589 Mdot
.32157 .57541 Mdot
.22485 .54862 Mdot
.50632 .79184 Mdot
.72469 .81617 Mdot
.25908 .29028 Mdot
.70419 .5958 Mdot
.58567 .78604 Mdot
.39549 .47726 Mdot
.18415 .61823 Mdot
.52678 .21258 Mdot
.28979 .45314 Mdot
.82628 .46329 Mdot
.35909 .67729 Mdot
.52733 .65616 Mdot
.34109 .24569 Mdot
.1584 .44925 Mdot
.7859 .33349 Mdot
.13883 .49401 Mdot
.54326 .60006 Mdot
.52318 .67973 Mdot
.88278 .5284 Mdot
.16414 .54656 Mdot
.54929 .5983 Mdot
.81145 .46165 Mdot
.72896 .57002 Mdot
.48576 .5999 Mdot
.59926 .29732 Mdot
.35556 .565 Mdot
.26328 .54185 Mdot
.14499 .55425 Mdot
.62473 .54933 Mdot
.37914 .41807 Mdot
.53669 .39341 Mdot
.45106 .44945 Mdot
.40633 .65558 Mdot
.5973 .41028 Mdot
.26062 .5568 Mdot
.42289 .47938 Mdot
.6024 .44878 Mdot
.37149 .54875 Mdot
.4254 .17283 Mdot
.57599 .58696 Mdot
.57453 .53093 Mdot
.46158 .75302 Mdot
.76213 .59709 Mdot
.26719 .59749 Mdot
.24921 .58424 Mdot
.29574 .26487 Mdot
.40627 .15132 Mdot
.39468 .2826 Mdot
.39159 .61055 Mdot
.71325 .50435 Mdot
.64267 .66066 Mdot
.54952 .71807 Mdot
.51026 .39797 Mdot
.61206 .24018 Mdot
.53142 .58747 Mdot
.38711 .59054 Mdot
.56929 .3592 Mdot
.27549 .76955 Mdot
.48071 .5894 Mdot
.59101 .70923 Mdot
.1843 .4238 Mdot
.29748 .43882 Mdot
.58515 .59837 Mdot
.44314 .68026 Mdot
.77015 .55292 Mdot
.42542 .48311 Mdot
.38087 .68555 Mdot
.27728 .45866 Mdot
.19118 .62 Mdot
.58495 .58554 Mdot
.57923 .70516 Mdot
.47197 .64062 Mdot
.37554 .4894 Mdot
.6525 .4663 Mdot
.46889 .81326 Mdot
.44974 .53633 Mdot
.18691 .38894 Mdot
.27209 .48618 Mdot
.27111 .50689 Mdot
.58395 .65727 Mdot
.27117 .73461 Mdot
.76083 .43006 Mdot
.58042 .68495 Mdot
.78887 .50693 Mdot
.4934 .2956 Mdot
.27734 .60989 Mdot
.44713 .3813 Mdot
.3902 .64261 Mdot
.73354 .5583 Mdot
.14183 .5801 Mdot
.49119 .80406 Mdot
.54619 .35075 Mdot
.47419 .37714 Mdot
.69313 .63057 Mdot
.45217 .45328 Mdot
.68667 .18988 Mdot
.54013 .20052 Mdot
.20256 .68139 Mdot
.23325 .50976 Mdot
.71153 .5026 Mdot
.693 .39036 Mdot
.56408 .60083 Mdot
.42486 .32616 Mdot
.18718 .61978 Mdot
.41011 .55735 Mdot
.7308 .3644 Mdot
.50182 .60105 Mdot
.76643 .50738 Mdot
.37877 .60957 Mdot
.4322 .40495 Mdot
.42971 .31123 Mdot
.80194 .47806 Mdot
.18323 .45568 Mdot
.42696 .48436 Mdot
.60423 .17555 Mdot
.28742 .72653 Mdot
.15762 .50526 Mdot
.43898 .39259 Mdot
.81444 .58807 Mdot
.68489 .61176 Mdot
.37968 .61574 Mdot
.59994 .35204 Mdot
.40563 .75255 Mdot
.70719 .396 Mdot
.22945 .53782 Mdot
.64155 .44106 Mdot
.60611 .48898 Mdot
.56662 .10829 Mdot
.28809 .58609 Mdot
.71282 .6079 Mdot
.70671 .36426 Mdot
.14838 .50413 Mdot
.37326 .53338 Mdot
.38343 .20154 Mdot
.44182 .25344 Mdot
.40961 .67102 Mdot
.73721 .65081 Mdot
.37792 .76546 Mdot
.55672 .31822 Mdot
.62386 .8317 Mdot
.30234 .29733 Mdot
.28556 .52242 Mdot
.4634 .29722 Mdot
.68229 .51831 Mdot
.72361 .57418 Mdot
.45516 .21183 Mdot
.49601 .15285 Mdot
.39214 .69031 Mdot
.18224 .57787 Mdot
.72114 .76097 Mdot
.24976 .50796 Mdot
.16604 .59091 Mdot
.59679 .3303 Mdot
.73752 .58249 Mdot
.26062 .58724 Mdot
.36021 .43604 Mdot
.38722 .32688 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0:;ooooo0_l0002Uooooo`007?ooool00ol0003oooooooooo`2Roooo
o`;o0000YOooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo09Gooooo
0_l0002booooo`007?ooool00ol0003oooooooooo`2;ooooo`;o00002?ooool2o`000;;ooooo000L
ooooo`03o`000?oooooooooo08?ooooo0_l00006ooooo`;o00009oooool2o`0009?ooooo000Loooo
o`03o`000?oooooooooo08?ooooo0_l0000_ooooo`;o0000Toooool001cooooo00?o0000oooooooo
ool0_Oooool2o`0008[ooooo000Looooo`03o`000?oooooooooo07[ooooo0_l00011ooooo`;o0000
R_ooool001cooooo00?o0000ooooooooool0N_ooool2o`000<gooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0__ooool2o`0008Wooooo000Looooo`03
o`000?oooooooooo077ooooo0_l0001;ooooo`;o0000ROooool001cooooo00?o0000ooooooooool0
LOooool2o`000=Kooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0a?ooool2o`0008?ooooo000Looooo`03o`000?oooooooooo0<Cooooo0_l00023oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo09kooooo
0_l0002Yooooo`007?ooool2o`00087ooooo0_l0000Kooooo`?o00002?ooool2o`0009oooooo000L
ooooo`03o`000?oooooooooo083ooooo0_l0000Aooooo`?o000000?oooooo`000?l000000_l00002
ooooo`;o00002Oooool4o`0009gooooo000Looooo`03o`000?oooooooooo09?ooooo0ol000000ooo
oooo0000o`000002o`0000Gooooo0_l00008ooooo`;o0000WOooool001cooooo00?o0000oooooooo
ool0T?ooool2o`0000;ooooo0_l0000:ooooo`;o00002Oooool2o`0001;ooooo0_l00028ooooo`00
7?ooool00ol0003oooooooooo`2@ooooo`;o00006Oooool2o`0000?ooooo0_l0000=ooooo`;o0000
4?ooool2o`0007Kooooo000Looooo`03o`000?oooooooooo06?ooooo0_l0000Oooooo`;o00001ooo
ool2o`0000oooooo1Ol00002ooooo`;o000000?oooooo`000?l000001_ooool2o`0001oooooo0_l0
001fooooo`007?ooool00ol0003oooooooooo`1Sooooo`;o00007oooool2o`000003ooooool0003o
000000Cooooo0_l00008ooooo`;o00001Oooool5o`0000;ooooo0_l000000ooooooo0000o`00000K
ooooo`;o0000P_ooool001cooooo00?o0000ooooooooool0Q_ooool3o`0000kooooo1?l0000Zoooo
o`;o0000P_ooool001cooooo00?o0000ooooooooool0Q_ooool4o`0000oooooo0_l0000Hooooo`;o
00002oooool2o`0001Cooooo0_l0001aooooo`007?ooool00ol0003oooooooooo`28ooooo`;o0000
7_ooool2o`0000Wooooo0_l00004ooooo`;o00001Oooool2o`0001Cooooo0_l0001aooooo`007?oo
ool00ol0003oooooooooo`2:ooooo`;o000000?oooooo`000?l000004Oooool2o`0000Kooooo0_l0
000=ooooo`Co0000S_ooool001cooooo00?o0000ooooooooool0M?ooool2o`0001Cooooo0_l00000
0ooooooo0000o`00000Aooooo`;o00005Oooool2o`00093ooooo000Looooo`03o`000?oooooooooo
07Cooooo0_l0000Gooooo`;o00002_ooool3o`0003oooooo0_l0001/ooooo`0000Koooooonk^k_lb
<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0FOooool2
o`0003;ooooo0_l0000:ooooo`?o00008Oooool2o`0001cooooo0_l0001/ooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo
00?o0000ooooooooool0FOooool2o`0003kooooo0_l0000Rooooo`;o0000R_ooool00003ooooool@
413ooooo00;ooooo00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oo
oooooooo07gooooo0_l00006ooooo`;o00007_ooool2o`0000Oooooo0_l0002Iooooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0001h
ooooo`?o00000_ooool2o`0000Kooooo0_l0000Aooooo`;o00002oooool2o`0000Gooooo1?l00000
0ooooooo0000o`00000=ooooo`;o0000Qoooool00003ooooool0003ooooo00;ooooo00?o0000oooo
ooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo07Oooooo1?l0000Moooo
o`;o00004_ooool3o`0000;ooooo0_l000001?oooooo0000o`000?l00009ooooo`;o0000Qoooool0
0003ooooool@413ooooo00;ooooo00?o410@ooooooooool03Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo07Oooooo0_l00005ooooo`;o00003Oooool2o`0000oooooo0_l0000=oooo
o`;o00001Oooool4o`0001Oooooo0_l0001hooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;
ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`1dooooo`;o000000?o
ooooo`000?l000001Oooool2o`0000Gooooo0_l00006ooooo`;o000000?oooooo`000?l000003?oo
ool2o`0001Kooooo0_l0000Gooooo`;o000000Coooooo`000?l0003o0000M?ooool00006ooooooo^
k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000oooo
ooooool0M?ooool2o`000003ooooool0003o000000cooooo0_l00009ooooo`;o00005Oooool4o`00
01[ooooo0_l00008ooooo`;o000000Coooooo`000?l0003o0000M?ooool001cooooo00?o0000oooo
ooooool0Yoooool4o`0001[ooooo0_l0000>ooooo`;o00004Oooool2o`0005oooooo000Looooo`03
o`000?oooooooooo0;Wooooo0_l0000Jooooo`;o00004Oooool2o`0005oooooo000Looooo`03o`00
0?oooooooooo04oooooo0_l0000Sooooo`;o00009?ooool2o`0001_ooooo1?l0000>ooooo`;o0000
O_ooool001cooooo00?o0000ooooooooool0Coooool2o`0002?ooooo0_l0000Jooooo`;o00002?oo
ool2o`0001_ooooo0_l0000@ooooo`;o0000O_ooool001cooooo00?o0000ooooooooool0M?ooool2
o`0000;ooooo0ol0000?ooooo`;o00001?ooool2o`0000Sooooo0_l0000Xooooo`;o00003_ooool2
o`0007?ooooo000Looooo`03o`000?oooooooooo04cooooo0_l0000Pooooo`;o00001?ooool2o`00
00;ooooo1?l0000;ooooo`;o000000?oooooo`000?l000000_ooool4o`0002Oooooo0_l00007oooo
o`Ko00003?ooool2o`0007?ooooo000Looooo`03o`000?oooooooooo04cooooo0_l0000Gooooo`;o
00001?ooool2o`000004ooooool0003o0000ooooo`;o00001_ooool3o`0000_ooooo0ol00004oooo
o`;o00005?ooool2o`0001?ooooo0_l00005ooooo`So0000POooool001cooooo00?o0000oooooooo
ool0H_ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000001?ooool2o`00
0004ooooool0003o0000ooooo`Co00003Oooool4o`000004ooooool0003o0000o`0000[ooooo0_l0
0003ooooo`;o00000oooool2o`0000;ooooo0_l0000=ooooo`;o00000oooool2o`000003ooooool0
003o000000Oo00000_ooool2o`0007gooooo000Looooo`03o`000?oooooooooo06;ooooo0_l00004
ooooo`;o00001?ooool8o`000003ooooool0003o000000Wooooo0_l00003ooooo`Go000000?ooooo
o`000?l000002oooool2o`0000?ooooo0_l00007ooooo`;o00003Oooool2o`0000?ooooo2ol00003
ooooo`;o0000OOooool001cooooo00?o0000ooooooooool0B?ooool2o`00027ooooo0_l000000ooo
oooo0000o`000005o`0000Sooooo0_l00003ooooo`;o00000oooool4o`0000;ooooo0_l00009oooo
o`;o000000?oooooo`000?l000002oooool2o`0000gooooo1?l00002ooooo`go0000:?ooool2o`00
05Gooooo000Looooo`03o`000?oooooooooo04Sooooo0_l0000Looooo`;o00000oooool2o`000003
ooooool0003o000000gooooo0_l0000>ooooo`;o00002Oooool2o`000003ooooool0003o000000go
oooo0_l0000=ooooo`;o00000_ooool=o`0000kooooo0_l0000Hooooo`;o0000EOooool001cooooo
0_l0001Nooooo`;o00001?ooool2o`000003ooooool0003o000001kooooo0_l0000Rooooo`;o0000
4?ooool5o`000003ooooool0003o000000Ko00003Oooool5o`0001Kooooo0_l0001Eooooo`007?oo
ool00ol0003oooooooooo`1Iooooo`;o00000_ooool2o`0000?ooooo0ol0000Qooooo`;o00001?oo
ool2o`0002kooooo3_l00009ooooo`;o00000_ooool2o`000003ooooool0003o000006gooooo000L
ooooo`03o`000?oooooooooo05Wooooo0_l00007ooooo`;o00007Oooool3o`0000;ooooo0_l00004
ooooo`;o00003_ooool2o`0001gooooo3ol00009ooooo`;o00002?ooool4o`0006Sooooo000Loooo
o`03o`000?oooooooooo087ooooo0ol0000Hooooo`;o00007Oooool>o`00013ooooo0_l00002oooo
o`Co0000J?ooool001cooooo00?o0000ooooooooool0@_ooool2o`0001Wooooo0_l0000Fooooo`;o
0000AOooool=o`0000cooooo0_l00002ooooo`;o00001Oooool2o`0006Oooooo000Looooo`03o`00
0?oooooooooo04;ooooo0_l0000Dooooo`;o00000_ooool3o`0001Kooooo0_l00004ooooo`;o0000
@?ooool<o`0000Wooooo0_l000000ooooooo0000o`000003ooooo`;o00001?ooool2o`0006Oooooo
000Looooo`03o`000?oooooooooo05Sooooo1_l0000Kooooo`Co00000_ooool2o`0000gooooo0_l0
000]ooooo`ko00000oooool2o`0000;ooooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo0_l0
001Xooooo`007?ooool00ol0003oooooooooo`1Jooooo`;o00005Oooool2o`0000Kooooo0_l00004
ooooo`;o00001oooool2o`0000Cooooo0_l00009ooooo`;o00003oooool2o`0001;ooooo1ol00000
1?oooooo0000o`000?ooool2o`0000?ooooo0ol00005ooooo`;o00000_ooool2o`0000?ooooo0_l0
00000ooooooo0000o`000004ooooo`;o0000Goooool001cooooo00?o0000ooooooooool0Eoooool2
o`0000;ooooo0_l0000?ooooo`;o00000oooool2o`0001Gooooo0ol0000>ooooo`;o00003oooool2
o`00013ooooo0_l000000ooooooo0000o`000007o`0000Oooooo0_l00002ooooo`;o00001Oooool3
o`0000Gooooo0_l00004ooooo`;o000000?oooooo`000?l00000G?ooool001cooooo00?o0000oooo
ooooool0E_ooool4o`000003ooooool0003o000000Sooooo0_l00005ooooo`;o00001?ooool2o`00
01Gooooo0_l000001?oooooo0000o`000?l0000;ooooo`;o00008?ooool:o`0000gooooo0_l00000
0ooooooo0000o`000003ooooo`;o00003_ooool2o`0005cooooo000Looooo`03o`000?oooooooooo
03_ooooo0_l0000Iooooo`Co00000_ooool2o`0000Oooooo0_l00005ooooo`;o00001?ooool4o`00
00Kooooo0_l0000>ooooo`?o000000?oooooo`000?l000002?ooool2o`00013ooooo0_l0000?oooo
o`?o000000?oooooo`000?l000000_l0000Aooooo`;o00004Oooool2o`0005kooooo000Looooo`03
o`000?oooooooooo03_ooooo0_l0000Cooooo`;o000000Coooooo`000?l0003o00001_ooool2o`00
01Kooooo1?l00004ooooo`;o00002_ooool2o`0000Kooooo1?l0000Fooooo`Co00003Oooool2o`00
0003ooooool0003o000000?ooooo0_l000000ooooooo0000o`00000Qooooo`;o0000G_ooool001co
oooo00?o0000ooooooooool0>oooool2o`0001?ooooo0_l000000ooooooo0000o`000002o`0001oo
oooo0_l0000@ooooo`;o00000oooool2o`000003ooooool0003o000000;o00004?ooool3o`0000?o
oooo0_l0000?ooooo`;o00001_ooool2o`000003ooooool0003o0000017ooooo0_l0001^ooooo`00
7?ooool00ol0003oooooooooo`0kooooo`;o00004oooool2o`0000;ooooo0ol00004ooooo`;o0000
00?oooooo`000?l000001Oooool2o`0001Cooooo0_l00007ooooo`;o00000oooool2o`0000;ooooo
1Ol0000<ooooo`;o00001?ooool3o`0002Kooooo0_l0000:ooooo`;o00005Oooool2o`0005Oooooo
000Looooo`03o`000?oooooooooo053ooooo0_l00002ooooo`;o00001Oooool2o`000003ooooool0
003o000000;o000000?oooooo`000?l000000_l0000>ooooo`;o00001?ooool2o`0000;ooooo0_l0
0002ooooo`?o00000oooool2o`0000Cooooo0_l00005ooooo`;o00001_ooool2o`0000;ooooo0_l0
000Yooooo`;o00008Oooool2o`0005Oooooo000Looooo`03o`000?oooooooooo05kooooo1ol0000@
ooooo`;o000000?oooooo`000?l000001Oooool2o`0000;ooooo0ol000000ooooooo0000o`000009
ooooo`?o000000?oooooo`000?l000001Oooool2o`0000?ooooo0_l0000Jooooo`Go00006oooool2
o`0001[ooooo0_l0001=ooooo`007?ooool2o`0005oooooo0_l000000ooooooo0000o`000002o`00
01?ooooo0_l00009ooooo`?o000000?oooooo`000?l000001_ooool2o`000004ooooool0003o0000
o`0000Sooooo0_l00006ooooo`;o00005oooool5o`0001;ooooo0_l00007ooooo`;o00006_ooool2
o`0004gooooo000Looooo`03o`000?oooooooooo04gooooo0_l000000ooooooo0000o`00000Qoooo
o`;o00001_ooool5o`0000Kooooo0_l00007ooooo`;o00005?ooool2o`0000;ooooo0_l0000Foooo
o`;o00000_ooool2o`0000kooooo0_l0001booooo`007?ooool00ol0003oooooooooo`1=ooooo`;o
000000?oooooo`000?l000000_l0000Oooooo`;o00001_ooool>o`0000Kooooo0_l0000Hooooo`;o
00005_ooool6o`0000Kooooo0_l0000:ooooo`?o00002Oooool2o`0001Gooooo0_l0001;ooooo`00
7?ooool00ol0003oooooooooo`1:ooooo`;o00001_ooool2o`0000Sooooo0_l0000Jooooo`;o0000
1?ooool;o`0000Kooooo0_l0000]ooooo`;o00000oooool2o`0000Sooooo0_l00005ooooo`;o0000
0oooool3o`0000Wooooo0_l0000;ooooo`?o00001oooool2o`0004_ooooo000Looooo`03o`000?oo
oooooooo04[ooooo0_l0000@ooooo`Co00005oooool3o`000003ooooool0003o000000go00002?oo
ool2o`0002[ooooo0_l00002ooooo`;o00004?ooool3o`0001_ooooo1Ol0001Booooo`007?ooool0
0ol0003oooooooooo`12ooooo`;o00001Oooool2o`0000;ooooo0_l0000?ooooo`;o00005ooooolF
o`0000;ooooo0_l000000ooooooo0000o`00000Iooooo`;o00004oooool2o`0000Kooooo0_l00009
ooooo`;o00003Oooool2o`000003ooooool0003o000000Kooooo1?l00002ooooo`;o0000D_ooool0
01cooooo00?o0000ooooooooool0@_ooool2o`0000Gooooo1ol0000XoooooaGo00000_ooool2o`00
00?ooooo0_l0000Booooo`;o00000oooool2o`0000;ooooo0_l0000>ooooo`;o00001oooool2o`00
00kooooo0ol00007ooooo`Ko00001Oooool4o`0001?ooooo0_l00011ooooo`007?ooool00ol0003o
ooooooooo`1;ooooo`Go00006Oooool2o`0000gooooo5?l000000ooooooo0000o`000005ooooo`;o
00004?ooool4o`0000Oooooo0_l00008ooooo`;o00001?ooool2o`0000gooooo1?l000001Ooooooo
0000o`000?l0003ooooo00Co00002?ooool2o`000003ooooool0003o000001cooooo0_l00011oooo
o`007?ooool00ol0003oooooooooo`10ooooo`;o00001oooool2o`0001kooooo0_l00004ooooo`;o
00002?oooolBo`0000;ooooo0ol0000<ooooo`;o00000_ooool2o`0000Cooooo0_l00005ooooo`;o
00003?ooool2o`0001?ooooo1?l000001Ooooooo0000o`000?l0003ooooo00Co00006_ooool2o`00
053ooooo000Looooo`03o`000?oooooooooo043ooooo1?l00003ooooo`Co00009?ooool2o`0000Oo
oooo1?l000000ooooooo0000o`00000Bo`0000_ooooo0_l00002ooooo`;o00002oooool2o`00013o
oooo0_l0000Aooooo`;o00000_ooool2o`000003ooooool0003o000000;o00002oooool2o`0000co
oooo0ol0001@ooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00000oooool2o`0000?ooooo
0_l00005ooooo`Co00004_ooool2o`0000;ooooo1?l000000ooooooo0000o`000009oooooaWo0000
;Oooool3o`000003ooooool0003o000000kooooo0_l00005ooooo`;o00003?ooool3o`0000Gooooo
0_l00005ooooo`?o00002Oooool2o`0004Gooooo000Looooo`03o`000?oooooooooo03gooooo1?l0
000=ooooo`Co00004_ooool3o`000003ooooool0003o000000Go00000_ooool2o`0000;ooooo6_l0
000Hooooo`;o00005Oooool2o`0000;ooooo1?l000000ooooooo0000o`000009ooooo`;o00001Ooo
ool3o`0000_ooooo0_l00006ooooo`;o00001_ooool3o`000003ooooool0003o000000Gooooo0_l0
0015ooooo`007?ooool00ol0003oooooooooo`0nooooo`?o00001?ooool2o`000003ooooool0003o
000000;o00000oooool2o`0001Cooooo0_l000001?oooooo0000o`000?ooool2o`0000Cooooo0_l0
00000ooooooo0000o`00000Jo`000003ooooool0003o000001Cooooo0_l0000Kooooo`;o000000?o
ooooo`000?l000004?ooool3o`0000_ooooo1?l000000ooooooo0000o`00000:ooooo`;o000000?o
ooooo`000?l00000C?ooool001cooooo00?o0000ooooooooool0?_ooool3o`0000Cooooo0_l00000
0ooooooo0000o`000002o`000003ooooool0003o000000;o00001?ooool2o`0000cooooo0_l00003
ooooo`;o000000?oooooo`000?l000001_oooolBo`000003ooooool0003o000000So000000Cooooo
o`000?l0003ooooo0_l0000@ooooo`;o00005_ooool4o`00017ooooo0_l00004ooooo`;o00003?oo
ool4o`000003ooooool0003o000000gooooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`0o
ooooo`;o00000_ooool6o`0000Cooooo0_l00003ooooo`;o000000?oooooo`000?l000002oooool3
o`0000Kooooo1?l00004oooooa;o000000?oooooo`000?l000002?l00004ooooo`;o00000_ooool2
o`0000Gooooo0_l00005ooooo`;o00003?ooool4o`0000Kooooo1?l0000Aooooo`;o00009_ooool2
o`0000Sooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`12ooooo`Wo000000?oooooo`00
0?l000001?ooool2o`0000kooooo0_l00007ooooo`Co000000?oooooo`000?l000008Ol00005oooo
o`;o00001Oooool2o`0000oooooo0_l00002ooooo`Co00006?ooool2o`000003ooooool0003o0000
00Kooooo0_l00007ooooo`;o00002Oooool3o`0001?ooooo0_l00012ooooo`007?ooool2o`0002[o
oooo0_l0000Gooooo`;o000000?oooooo`000?l000002_l000000ooooooo0000o`00000Looooob?o
00000oooool2o`0000;ooooo0_l00003ooooo`;o00001?ooool2o`0000Oooooo1?l0000Nooooo`;o
00002Oooool2o`0000Oooooo0_l00009ooooo`Ko00002?ooool2o`0004[ooooo000Looooo`03o`00
0?oooooooooo02Wooooo0_l0000Fooooo`;o00001?ooool2o`0000;ooooo0_l000001?oooooo0000
o`000?l0000<ooooo`;o00000_ooool2o`00013ooooo2?l00002oooooaOo00000_ooool2o`0000;o
oooo0_l00003ooooo`?o00000oooool2o`0000Oooooo1?l0000=ooooo`;o00001?ooool2o`0000[o
oooo0_l0000Booooo`;o00002Oooool5o`0000Sooooo0_l0001:ooooo`007?ooool00ol0003ooooo
ooooo`0hooooo`;o00001oooool4o`0000;ooooo0_l0000Dooooo`;o00000_ooool2o`000003oooo
ool0003o000000gooooo1Ol000000ooooooo0000o`00000Io`000004ooooool0003o0000o`0000So
oooo0ol0000=ooooo`Co000000Goooooo`000?l0003o0000ooooo`03o`0000?ooooo0_l000001?oo
oooo0000o`000?ooool2o`0000[ooooo0_l00002ooooo`?o00002_ooool2o`000003ooooool0003o
000000;ooooo0_l00005ooooo`;o0000Eoooool001cooooo00?o0000ooooooooool0>?ooool2o`00
00Kooooo0_l000000ooooooo0000o`000002ooooo`;o00006oooool2o`0000_ooooo0_l00002oooo
oago00000oooool2o`000003ooooool0003o000000Oooooo0_l00007ooooo`;o00000oooool5o`00
0003ooooool0003o000000Go00000oooool2o`000003ooooool0003o000000?o00003_ooool3o`00
00[ooooo0_l00005ooooo`;o00000_ooool2o`0000Kooooo0_l00004ooooo`;o0000C?ooool001co
oooo00?o0000ooooooooool0@?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000Vooooo`Ko
000000?oooooo`000?l000006Ol00007ooooo`;o00003oooool3o`000003ooooool0003o000000Go
000000?oooooo`000?l000001Ol00003ooooo`Oo00001Oooool3o`0000?ooooo0_l0000Fooooo`;o
00000_ooool2o`0000Kooooo0_l00004ooooo`;o00000_ooool2o`0000gooooo0_l0000iooooo`00
7?ooool00ol0003oooooooooo`14ooooo`;o000000?oooooo`000?l000006_ooool2o`0000[ooooo
1_l000000ooooooo0000o`000007o`000003ooooool0003o0000013o00005oooool2o`0000;ooooo
1ol000000ooooooo0000o`000005o`0000?ooooo1ol00005ooooo`?o00000oooool3o`0000kooooo
0_l00005ooooo`?o00004oooool4o`0000_ooooo0_l0000iooooo`007?ooool00ol0003ooooooooo
o`0cooooo`;o00006_ooool2o`0001;ooooo0_l00004ooooo`;o00002ooooolPo`0000Oooooo0_l0
000:ooooo`;o00000oooool3o`000003ooooool0003o000000Wo00000_ooool4o`0000;ooooo0_l0
000;ooooo`;o00000_ooool2o`0000[ooooo0_l00005ooooo`?o00001oooool2o`0000cooooo0_l0
0016ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00001?ooool2o`0000Wooooo0_l00009
ooooo`;o00002_ooool2o`0000cooooo0_l00003ooooo`;o00001_oooolPo`0000Oooooo0_l00006
ooooo`?o000000?oooooo`000?l000004ol000000ooooooo0000o`000004ooooo`;o00003oooool2
o`0000_ooooo0_l00003ooooo`Co00001oooool2o`0005Cooooo000Looooo`03o`000?oooooooooo
03Wooooo0_l00009ooooo`;o00005Oooool2o`0000;ooooo0_l00009ooooo`;o00000_ooool4o`00
00?ooooo7ol00007ooooo`;o00002?ooool3o`0000?ooooo1?l000000ooooooo0000o`00000=o`00
0003ooooool0003o000000;ooooo1Ol00004ooooo`;o00003Oooool2o`0000Gooooo0ol00002oooo
o`Co00000_ooool2o`0000?ooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`0nooooo`;o
00003oooool2o`0000kooooo0_l00009ooooo`So00000ooooolNo`0000?ooooo0ol00002ooooo`;o
00001_ooool2o`0000Oooooo7Ol00004ooooo`?o00000oooool2o`000003ooooool0003o000000Co
oooo0_l00005ooooo`?o00000oooool3o`0000;ooooo0_l00008ooooo`;o00000_ooool3o`0004[o
oooo000Looooo`03o`000?oooooooooo03Oooooo0_l00002ooooo`;o000000Coooooo`000?l0003o
oooo0_l000000ooooooo0000o`000008ooooo`Go00006?ooool4o`0000Cooooo0_l00003ooooo`[o
000000?oooooo`000?l000003?l00002ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`00
00Kooooo0_l00005oooooago00001oooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool2
o`0000;ooooo0_l00005ooooo`;o00000oooool6o`0000Wooooo0_l00002ooooo`Co0000BOooool0
01cooooo00?o0000ooooooooool0=oooool2o`0000;ooooo1?l00002ooooo`;o000000?oooooo`00
0?l000001Oooool5o`000003ooooool0003o000000Sooooo0_l0000Fooooo`;o00000oooool7o`00
0004ooooool0003o0000ooooo`co00001?ooool2o`0000;ooooo0_l00002ooooo`;o00003OoooolM
o`0001;ooooo0_l00002ooooo`;o00001oooool2o`0000?ooooo1?l00007ooooo`;o00001_ooool2
o`0000cooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0kooooo`Co00001_ooool2o`00
00Cooooo1Ol00008ooooo`;o000000?oooooo`000?l000002_ooool2o`0000Kooooo0_l000000ooo
oooo0000o`000004ooooo`Co00000_ooool4o`0000;ooooo2Ol00003ooooo`;o00001Oooool4o`00
013ooooo7?l0000Aooooo`;o00003?ooool2o`0000?ooooo0_l00009ooooo`;o00002?ooool2o`00
00[ooooo0_l00002ooooo`;o0000=oooool001cooooo00?o0000ooooooooool0>Oooool4o`0000So
oooo0_l0000Aooooo`;o00003Oooool5o`0000?ooooo0_l000000ooooooo0000o`000008ooooo`Co
00001Oooool3o`0000Sooooo1_l000000ooooooo0000o`000002o`0000oooooo7Ol0000Aooooo`;o
00000oooool2o`0001Sooooo0_l00007ooooo`;o00003_ooool2o`0003Oooooo00001_ooooook^k^
oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0
003oooooooooo`0iooooo`?o00003_ooool2o`0000oooooo0_l0000<ooooo`?o00001_ooool2o`00
00Sooooo0_l00008ooooo`;o00000_ooool4o`0000?ooooo1_l0000@ooooo`;o000000?oooooo`00
0?l000006ol000000ooooooo0000o`00000Cooooo`;o00001_ooool4o`0000Cooooo0_l00008oooo
o`;o00001oooool2o`0000_ooooo0_l0000jooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5
ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03[ooooo0_l0000>
ooooo`;o00002oooool2o`0000;ooooo0_l0000=ooooo`Co00001?ooool2o`000003ooooool0003o
000000;ooooo1?l0000<ooooo`Go00000oooool2o`0000;ooooo0_l0000<ooooo`;o00000_ooool2
o`0000;ooooo6ol00002ooooo`;o00004oooool2o`0000?ooooo1ol000000ooooooo0000o`000003
o`00017ooooo0_l00003ooooo`;o00001_ooool2o`0003[ooooo00000ooooooo410@ooooo`02oooo
o`03oa0@4?oooooooooo00Wooooo1Ol00006ooooo`03o`000?oooooooooo03[ooooo0_l0000;oooo
o`;o00003Oooool3o`0000cooooo0_l00003ooooo`Go00001_ooool;o`0000Wooooo0ol0000Foooo
o`?o00000_ooool2o`0000;ooooo6ol0000Fooooo`;o00000oooool5o`000004ooooool0003o0000
ooooo`Co00004_ooool2o`0000?ooooo0_l00012ooooo`0000?oooooo`000?ooool00_ooool00ol0
003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0000fooooo`;o00003?ooool2
o`000003ooooool0003o000000;ooooo0_l00009ooooo`;o00003Oooool2o`0000;ooooo0_l00002
ooooo`;o00001oooool4o`0000;ooooo1?l0000Cooooo`;o00003Oooool2o`0000Oooooo0ol00000
0ooooooo0000o`00000Eo`0001Kooooo0_l00003ooooo`Co00000_ooool2o`0000?ooooo0_l0000C
ooooo`;o00003_ooool2o`0003Kooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`0booooo`;o00000_ooool2
o`0000Cooooo0_l00006ooooo`Co00000oooool2o`0001cooooo0_l00002ooooo`;o00001oooool4
o`0000[ooooo0_l00003ooooo`;o00002?ooool2o`0000Sooooo0_l0000=oooooa[o00003_ooool4
o`0000Gooooo0_l000001?oooooo0000o`000?ooool2o`0000gooooo0_l0000<ooooo`?o00003_oo
ool3o`0003Gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oMgMg
olc<c?l000001oooool00ol0003oooooooooo`0booooo`;o00001oooool3o`0000Sooooo0_l00000
0ooooooo0000o`000005o`0002Oooooo0ol0000:ooooo`;o00000oooool2o`00013ooooo1?l0000?
oooooaGo00000oooool2o`0000cooooo1?l00005ooooo`;o000000?oooooo`000?l000002_ooool2
o`0000Cooooo0_l000000ooooooo0000o`000009ooooo`Co00003_ooool2o`0003Gooooo00001_oo
ooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l000001oooool00ol0003ooooooooo
o`0cooooo`;o00001_ooool3o`0000_ooooo0_l000000ooooooo0000o`000002o`0002Oooooo1?l0
0006ooooo`Co00005_ooool4o`0000oooooo5Ol00002ooooo`?o00004_ooool4o`0000kooooo0_l0
0007ooooo`;o00002oooool2o`0004Gooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPgooooo
00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`0cooooo`;o00002oooool2o`0000Gooooo
0_l00003ooooo`;o00001?ooool2o`0002;ooooo0_l000000ooooooo0000o`000006ooooo`Co0000
1?ooool4o`0000?ooooo0_l0000Iooooo`;o000000?oooooo`000?l000004_l00003ooooo`;o0000
1_ooool4o`0000Gooooo0_l00002ooooo`Co0000:?ooool3o`00043ooooo000Looooo`03o`000?oo
oooooooo033ooooo0_l0000>ooooo`;o00000_ooool2o`000003ooooool0003o000000Gooooo0_l0
0002ooooo`;o00007_ooool2o`0000;ooooo0ol0000:ooooo`;o00001?ooool4o`0000?ooooo0_l0
0004ooooo`;o00000_ooool2o`0000oooooo5ol00007ooooo`So00001?ooool3o`000003ooooool0
003o000000;o00002_ooool2o`0000?ooooo0_l00004ooooo`;o00003Oooool2o`0000?ooooo0ol0
0008ooooo`;o0000=_ooool001cooooo00?o0000ooooooooool0<?ooool2o`0000?ooooo0_l00005
ooooo`;o00001Oooool3o`0000Sooooo0_l0000Rooooo`;o00000_ooool4o`0000Wooooo0_l00008
ooooo`;o00001_ooool3o`0000;ooooo0_l00005ooooo`;o00002OoooolEo`0000Sooooo1?l00008
ooooo`?o000000?oooooo`000?l000002_ooool5o`0000;ooooo0_l00004ooooo`;o00003Oooool2
o`0000kooooo0_l0000fooooo`007?ooool00ol0003oooooooooo`0eooooo`;o000000?oooooo`00
0?l000000_ooool2o`0000Gooooo0ol00009ooooo`;o00003_ooool2o`0000Wooooo0_l00008oooo
o`Ko000000?oooooo`000?l000003oooool3o`0000Kooooo0ol00009ooooo`;o00002ooooolCo`00
00Gooooo1?l0000Aooooo`;o00002?ooool5o`0000Oooooo1?l0001Dooooo`007?ooool00ol0003o
ooooooooo`0hooooo`Co00002?ooool2o`0000Gooooo0_l00002ooooo`Co00003?ooool2o`0000Wo
oooo0_l00008ooooo`Wo00001Oooool2o`0000Sooooo0_l00008ooooo`;o00003?ooool2o`0000Go
oooo1Ol00004ooooo`go00001Oooool4o`0000;ooooo0_l0000=ooooo`;o000000?oooooo`000?l0
00001?ooool5o`0000Sooooo1?l00009ooooo`Co0000Aoooool001cooooo00?o0000ooooooooool0
>_ooool2o`0000_ooooo1_l00004ooooo`;o00002oooool2o`0000Cooooo0_l0000<ooooo`;o0000
0oooool6o`0000?ooooo1?l000000ooooooo0000o`000006ooooo`;o00005Oooool2o`0000Gooooo
0ol00007ooooo`;o000000?oooooo`000?l000001ol00009ooooo`Co00002?ooool2o`0000Kooooo
0_l00004ooooo`Co00002oooool2o`0000Wooooo1?l00017ooooo`007?ooool00ol0003ooooooooo
o`0iooooo`;o000000Coooooo`000?l0003ooooo0_l00006ooooo`Co000000?oooooo`000?l00000
4?ooool2o`0000Cooooo0_l00007ooooo`;o00000oooool2o`0000?ooooo1ol00002ooooo`;o0000
0oooool2o`0000Kooooo0_l00005ooooo`?o00007oooool7o`0000;ooooo0_l00006ooooo`;o0000
00?oooooo`000?l000002_ooool3o`0000_ooooo1?l0000;ooooo`;o00000_ooool2o`0000Sooooo
0_l00016ooooo`007?ooool00ol0003oooooooooo`0gooooo`Co000000Coooooo`000?l0003ooooo
0_l0000;ooooo`;o00007oooool2o`0000;ooooo0_l00002ooooo`Co00000oooool2o`0000[ooooo
0_l00003ooooo`?o00000_ooool7o`0001gooooo0_l0000>ooooo`?o00003_ooool4o`0000Cooooo
0_l00006ooooo`;o00002_ooool6o`0000Sooooo0_l00005ooooo`;o00001Oooool2o`0003Sooooo
000Looooo`03o`000?oooooooooo03Oooooo0_l0000Sooooo`?o00000_ooool2o`0000Cooooo0_l0
0003ooooo`;o00000oooool2o`0000;ooooo1?l00005ooooo`;o000000?oooooo`000?l000001?oo
ool3o`0000?ooooo0ol00002ooooo`Oo00000oooool2o`0002Sooooo1?l000000ooooooo0000o`00
000<ooooo`Co00000_ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000003?oo
ool2o`0000Cooooo0_l0000;ooooo`?o00001?ooool2o`0003Sooooo000Looooo`03o`000?oooooo
oooo02oooooo0_l00004ooooo`;o00002?ooool2o`0001_ooooo0ol00002ooooo`;o00001?ooool2
o`0000?ooooo0_l00003ooooo`;o00001_ooool2o`0000?ooooo0_l000000ooooooo0000o`000004
ooooo`ko00001Oooool4o`0000Cooooo0_l0000Hooooo`;o00002_ooool7o`0000cooooo0_l00005
ooooo`Co00001?ooool2o`0000;ooooo0_l00004ooooo`;o00001Oooool2o`0000Gooooo0_l00005
ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0;oooool2o`0000Cooooo0_l000000ooo
oooo0000o`000005ooooo`;o000000Coooooo`000?l0003o00005?ooool2o`0000?ooooo0_l0000A
ooooo`;o00001_ooool2o`000003ooooool0003o000000Oooooo0_l000000ooooooo0000o`000009
o`000003ooooool0003o000000Cooooo1?l00002ooooo`Go00003?ooool2o`0000Kooooo0_l00000
0ooooooo0000o`00000;ooooo`?o000000?oooooo`000?l000001Oooool2o`0000gooooo0_l00005
ooooo`;o00000_ooool2o`0000Cooooo1?l00003ooooo`?o00001?ooool2o`0004Gooooo000Loooo
o`03o`000?oooooooooo033ooooo0_l00006ooooo`;o00002?ooool3o`0000oooooo0_l00003oooo
o`;o00000oooool2o`0001Gooooo0_l00005ooooo`Co00001?ooool3o`0000Gooooo0_l000000ooo
oooo0000o`000003ooooo`Co00001?ooool6o`000003ooooool0003o000000cooooo0_l00006oooo
o`;o00001Oooool2o`0000;ooooo0_l00004ooooo`;o00002?ooool2o`000003ooooool0003o0000
00[ooooo0_l0000<ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2
o`0004Oooooo000Looooo`;o0000<Oooool2o`0001Sooooo1?l00006ooooo`;o00000_ooool2o`00
01_ooooo0_l000001?oooooo0000o`000?ooool7o`0000;ooooo1?l00007ooooo`;o00000oooool5
o`0000?ooooo2ol00002ooooo`;o00001?ooool2o`0000Oooooo0_l00003ooooo`;o000000?ooooo
o`000?l000000_ooool2o`0000Cooooo0_l00007ooooo`;o00000_ooool2o`0001Sooooo0_l00006
ooooo`Co00000oooool2o`0004Oooooo000Looooo`03o`000?oooooooooo02[ooooo0_l00006oooo
o`Co00000_ooool2o`00013ooooo1?l0000:ooooo`Co00002oooool2o`0000Kooooo0_l00003oooo
o`;o00000_ooool2o`000005ooooool0003o0000o`000?ooool00ol000000ooooooo0000o`000003
o`000003ooooool0003o000000;ooooo1Ol00005ooooo`;o00000_ooool5o`000003ooooool0003o
000000;ooooo0_l00002ooooo`Co00000_ooool2o`0000Oooooo0_l00003ooooo`;o00005?ooool2
o`0000Oooooo0_l00005ooooo`;o00001oooool2o`0000?ooooo0_l00008ooooo`;o0000C?ooool0
01cooooo00?o0000ooooooooool0:_ooool2o`0000Kooooo1?l00002ooooo`?o00006Oooool4o`00
00;ooooo0_l00006ooooo`;o00000oooool5o`0000?ooooo0_l00003ooooo`?o00001?ooool3o`00
00Gooooo0ol00003ooooo`;o00000_ooool8o`0000Gooooo0ol000000ooooooo0000o`00000;oooo
o`;o00001_ooool5o`0000Cooooo0_l0000>ooooo`;o00000oooool4o`0000Oooooo0_l00003oooo
o`Co00000oooool2o`0000;ooooo0ol00002ooooo`;o00000oooool2o`0000[ooooo0_l00015oooo
o`007?ooool00ol0003oooooooooo`0cooooo`?o00000oooool2o`0001?ooooo0_l00003ooooo`Go
00001oooool2o`000003ooooool0003o000000Gooooo0ol00009ooooo`;o00001?ooool2o`0000Oo
oooo0_l0000;ooooo`Co00001Oooool3o`0001Kooooo1Ol00003ooooo`?o00002oooool2o`000003
ooooool0003o000000;o000000?oooooo`000?l000000_l000000ooooooo0000o`000009ooooo`;o
00001?ooool3o`0000;ooooo1Ol00005ooooo`;o00000oooool2o`0000?ooooo1_l00002ooooo`;o
0000?oooool001cooooo00?o0000ooooooooool0;?ooool2o`0000;ooooo1Ol00008ooooo`;o0000
3oooool2o`0000?ooooo0_l00004ooooo`;o00001?ooool2o`0000Oooooo1Ol00004ooooo`Co0000
3oooool2o`00013ooooo0_l00002ooooo`;o00000_ooool4o`0000;ooooo0_l0000>ooooo`;o0000
0oooool4o`000003ooooool0003o000000Wooooo0_l00003ooooo`Co000000Coooooo`000?l0003o
oooo0_l00006ooooo`;o00001oooool2o`0000Cooooo1_l00006ooooo`Ko000000?oooooo`000?l0
00000_ooool2o`0000;ooooo0ol0000nooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o0000
0_ooool5o`0000?ooooo0_l00003ooooo`Co000000?oooooo`000?l000003?ooool2o`0000Cooooo
0_l000000ooooooo0000o`00000<ooooo`ko00000_ooool2o`0000gooooo0_l0000>ooooo`;o0000
1_ooool4o`0000;ooooo0_l0000>ooooo`;o00000oooool2o`0000?ooooo0_l0000:ooooo`;o0000
00?oooooo`000?l000001?l00008ooooo`Go000000Coooooo`000?l0003ooooo0_l00003ooooo`;o
00000_ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000000_ooool6o`0000[o
oooo0_l00006ooooo`;o0000=_ooool001cooooo00?o0000ooooooooool0<oooool3o`0000;ooooo
0_l00005ooooo`;o000000?oooooo`000?l000001oooool2o`0000?ooooo0_l00004ooooo`;o0000
3Oooool@o`0000;ooooo0_l0000:ooooo`;o000000?oooooo`000?l000005_ooool3o`0000Kooooo
0_l0000Qooooo`;o000000?oooooo`000?l000001?l00008ooooo`Co00000_ooool2o`000003oooo
ool0003o000000?ooooo3_l00004ooooo`Co00004_ooool2o`0003Kooooo000Looooo`03o`000?oo
oooooooo02Sooooo0_l00009ooooo`Go00004oooool4o`0000gooooo0_l00006oooooa3o00000_oo
ool2o`0000_ooooo0_l0000<ooooo`;o00003?ooool2o`0000Kooooo0_l00012ooooo`Oo00000_oo
ool3o`0000Kooooo0_l00002ooooo`;o00002Oooool4o`0003Wooooo000Looooo`03o`000?oooooo
oooo02Sooooo0_l00006ooooo`;o00001?ooool2o`0001Gooooo0_l0000=ooooo`?o00001OoooolA
o`000003ooooool0003o000000Gooooo0ol0000;ooooo`;o00001?ooool2o`000003ooooool0003o
000000;ooooo0_l00005ooooo`;o0000??ooool2o`00013ooooo0ol00002ooooo`Oo00000_ooool2
o`0000;ooooo0_l00009ooooo`Co0000>Oooool001cooooo00?o0000ooooooooool0;?ooool2o`00
00;ooooo0_l0000[ooooo`;o00001?oooolCo`0000Oooooo0ol00006ooooo`;o00000_ooool3o`00
00Oooooo0_l00002ooooo`;o00000_ooool2o`0000Gooooo0_l0000?ooooo`;o00001_ooool2o`00
00gooooo1?l0000=ooooo`?o00000_ooool2o`0000[ooooo0_l000000ooooooo0000o`000002o`00
00?ooooo1?l00006ooooo`;o00000oooool2o`00047ooooo000Looooo`03o`000?oooooooooo02co
oooo0_l0000Jooooo`;o00005Oooool2o`000003ooooool0003o000001?o000000?oooooo`000?l0
00003?ooool2o`0000;ooooo0_l00003ooooo`;o00002oooool2o`0000Gooooo0_l0000:ooooo`;o
00000oooool2o`0000Kooooo0_l00007ooooo`;o00001?ooool4o`000003ooooool0003o000000Oo
oooo0_l000000ooooooo0000o`000003ooooo`;o00002_ooool2o`0000?ooooo0_l00002ooooo`;o
000000?oooooo`000?l000001_ooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o
0000>_ooool001cooooo00?o0000ooooooooool0=Oooool5o`0000Kooooo1?l00003ooooo`Co0000
2_ooool2o`0000Sooooo6?l000001?oooooo0000o`000?ooool4o`0000Cooooo0_l000001?oooooo
0000o`000?l00006ooooo`;o00001oooool2o`0000Sooooo0ol00004ooooo`;o00001?ooool2o`00
01Cooooo0_l00004ooooo`;o00000oooool2o`0000Kooooo0ol00006ooooo`;o00002oooool2o`00
00;ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000[ooooo0_l00002oooo
o`;o0000>_ooool001cooooo00?o0000ooooooooool09oooool3o`0000_ooooo1Ol00004ooooo`Ko
00000oooool4o`000003ooooool0003o000000;o00001Oooool2o`0000Sooooo6_l00002ooooo`Co
00001?ooool2o`0000;ooooo1?l0000;ooooo`Co00001Oooool2o`000003ooooool0003o000000?o
00000_ooool2o`0000Cooooo0_l00002ooooo`;o00003?ooool2o`0000Gooooo0_l000001Ooooooo
0000o`000?l0003ooooo00;o00001oooool2o`0000Oooooo0_l00008ooooo`;o000000?oooooo`00
0?l000001_ooool5o`0000;ooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`0Wooooo`?o
00005?ooool2o`0000cooooo1Ol0000>oooooa[o00004?ooool2o`0000_ooooo0_l00004ooooo`;o
000000?oooooo`000?l000000_ooool4o`0000Gooooo0_l000000ooooooo0000o`000002ooooo`;o
00003?ooool2o`0000Gooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo1?l00002oooo
o`;o00004Oooool6o`0000Oooooo0_l0000Cooooo`;o0000>_ooool001cooooo00?o0000oooooooo
ool0:Oooool2o`0000[ooooo0_l00002ooooo`;o00003?ooool2o`0000Kooooo0_l00005ooooo`;o
00000_ooool2o`000004ooooool0003o0000oooooaOo00002Oooool3o`0000kooooo0_l00009oooo
o`;o00003_ooool2o`0000Gooooo0_l00002ooooo`;o00004Oooool2o`0000Kooooo1?l00002oooo
o`;o00002?ooool2o`0000Sooooo1Ol00007ooooo`;o00001Oooool3o`0000_ooooo0_l00003oooo
o`;o0000=Oooool001cooooo00?o0000ooooooooool0:?ooool3o`0000Oooooo0_l000000ooooooo
0000o`000002ooooo`;o000000?oooooo`000?l000002Oooool2o`0000gooooo0_l00002ooooo`;o
000000Coooooo`000?l0003ooooo3ol000000ooooooo0000o`000008o`0000Kooooo0ol0000>oooo
o`;o00002oooool2o`000003ooooool0003o000000Gooooo0_l00009ooooo`;o00000_ooool2o`00
00Oooooo0_l00008ooooo`;o00001Oooool2o`0000Oooooo0_l000000ooooooo0000o`000003oooo
o`;o00001Oooool2o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l000001oooool3o`00
00?ooooo0_l0000;ooooo`;o0000=Oooool001cooooo0_l0000Yooooo`;o00002?ooool2o`0000So
oooo1?l0000>ooooo`;o000000?oooooo`000?l000001oooool2o`000004ooooool0003o0000oooo
oa[o00000oooool2o`0000Gooooo0_l00005ooooo`;o00001?ooool2o`0000_ooooo0_l000001?oo
oooo0000o`000?ooool2o`000004ooooool0003o0000o`0000cooooo0_l00003ooooo`;o00000ooo
ool2o`000003ooooool0003o000000cooooo0_l00007ooooo`;o000000?oooooo`000?l000002Ooo
ool3o`0000;ooooo1?l00002ooooo`;o000000?oooooo`000?l000003Oooool2o`0004;ooooo000L
ooooo`03o`000?oooooooooo02gooooo0_l00007ooooo`;o00001Oooool3o`0000kooooo0_l00000
0ooooooo0000o`000006ooooo`;o00001?ooool2o`000003ooooool0003o000001?o00000oooool5
o`0000Gooooo0_l00005ooooo`;o00001?ooool2o`0000Sooooo0_l00007ooooo`;o000000?ooooo
o`000?l000001Oooool2o`0000Kooooo0_l00003ooooo`Co000000Coooooo`000?l0003ooooo0_l0
000=ooooo`;o00001oooool2o`0000Kooooo0ol00002ooooo`;o00001Oooool2o`0000;ooooo0_l0
0006ooooo`;o00002_ooool2o`0000?ooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0Y
ooooo`;o00000_ooool2o`000003ooooool0003o000000;o00000_ooool2o`0000Gooooo0_l00000
0ooooooo0000o`000002ooooo`;o00001oooool2o`0000Gooooo0_l00003ooooo`?o00000oooool2
o`000003ooooool0003o000000ko000000Coooooo`000?l0003o00001?ooool4o`0000;ooooo0_l0
000Iooooo`;o00004Oooool2o`0000[ooooo2?l00006ooooo`;o00001_ooool6o`0000Cooooo0ol0
0006ooooo`?o00000_ooool2o`0000Wooooo1?l00002ooooo`Go00002Oooool2o`0000?ooooo0_l0
000kooooo`007?ooool00ol0003oooooooooo`0Yooooo`;o00001?ooool5o`000003ooooool0003o
000000Wooooo0_l00002ooooo`?o000000?oooooo`000?l000000oooool2o`0000Gooooo0_l00004
ooooo`;o000000?oooooo`000?l000000ooooolEo`0000Wooooo1_l00007ooooo`;o00009?ooool2
o`0000Gooooo1?l000000ooooooo0000o`000007ooooo`;o00001_ooool3o`000003ooooool0003o
000000?ooooo1?l000000ooooooo0000o`000008ooooo`;o00002Oooool4o`0000;ooooo0_l00000
0ooooooo0000o`000009ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0;oooool2o`00
00Cooooo0_l00009ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo1Ol00003oooo
o`;o000000?oooooo`000?l000000_l00002ooooo`;o00000ooooolGo`0000Cooooo0_l00003oooo
o`Co00001oooool2o`0001Kooooo0_l0000:ooooo`Co00000_ooool2o`000003ooooool0003o0000
00;o00001Oooool2o`000003ooooool0003o000000Wooooo0_l00003ooooo`Ko00000_ooool2o`00
00?ooooo0_l0000Rooooo`;o00000oooool2o`0003_ooooo000Looooo`03o`000?oooooooooo02go
oooo0_l0000@ooooo`;o00002oooool2o`000003ooooool0003o000000Kooooo1?l00009oooooa3o
000000?oooooo`000?l000000_l00004ooooo`?o00002?ooool2o`0001[ooooo1?l00003ooooo`?o
00000oooool3o`0000?ooooo0ol00009ooooo`;o000000?oooooo`000?l000000ol00006ooooo`;o
00000oooool7o`000004ooooool0003o0000o`0000;ooooo0_l00009ooooo`?o00004oooool2o`00
00Kooooo0_l00004ooooo`;o0000=Oooool001cooooo00?o0000ooooooooool0;Oooool2o`0000_o
oooo0_l00003ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo0_l00007ooooo`?o
00003?oooolAo`000003ooooool0003o000000;o00001?ooool3o`0000Sooooo0_l0000Jooooo`Co
00000_ooool4o`0000[ooooo0_l0000<ooooo`Go00000_ooool5o`0000Gooooo2ol0000<ooooo`?o
00004oooool2o`0000cooooo0_l0000eooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o0000
2?ooool2o`000003ooooool0003o000000Gooooo0_l000000ooooooo0000o`000002ooooo`;o0000
1oooool3o`0000;ooooo0_l00007ooooo`?o00000_ooool;o`0000Gooooo0_l00006ooooo`;o0000
0_ooool2o`00027ooooo0_l00002ooooo`Co00003oooool2o`0000Oooooo0_l00003oooooaSo0000
5Oooool2o`0004oooooo000Looooo`03o`000?oooooooooo033ooooo0_l0000;ooooo`;o00003Ooo
ool2o`0000_ooooo0_l00004ooooo`Ko00000oooool:o`0000Gooooo0_l00006ooooo`;o00000_oo
ool2o`0000?ooooo0_l0000Looooo`;o00001?ooool3o`0000kooooo0_l000000ooooooo0000o`00
0008ooooo`?o000000?oooooo`000?l000004ol00008ooooo`;o00002Oooool5o`0004kooooo000L
ooooo`03o`000?oooooooooo02Oooooo0_l00002ooooo`?o00007_ooool2o`0000cooooo0ol00002
ooooo`Ko00001Oooool5o`000003ooooool0003o000001Kooooo0_l0000Rooooo`?o00000oooool2
o`000003ooooool0003o000000Wooooo0_l00008ooooo`;o00000_oooolBo`000003ooooool0003o
000000Sooooo0_l00009ooooo`Go00002Oooool2o`0001Gooooo0_l0000/ooooo`007?ooool00ol0
003oooooooooo`0Wooooo`;o00000_ooool3o`0002cooooo0ol00005ooooo`;o00001_ooool2o`00
00Cooooo0_l0000Iooooo`;o00009Oooool2o`000003ooooool0003o000000Co00003oooool2o`00
0003ooooool0003o0000017o000000Coooooo`000?l0003ooooo1?l00003ooooo`;o00000_ooool2
o`0000;ooooo0_l00003ooooo`;o00001oooool2o`000003ooooool0003o000001Gooooo0_l0000/
ooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00006_ooool2o`000003ooooool0003o0000
00_ooooo0_l0000?ooooo`;o00002Oooool3o`0001;ooooo0_l0000Cooooo`;o00001oooool2o`00
00?ooooo0_l00007ooooo`Co00003Oooool2o`0000?ooooo5Ol00002ooooo`Wo00000_ooool2o`00
00;ooooo0_l000001?oooooo0000o`000?ooool2o`0000Kooooo0_l00016ooooo`007?ooool00ol0
003oooooooooo`0^ooooo`;o00005oooool2o`000004ooooool0003o0000ooooo`;o00001?ooool2
o`0001Kooooo0_l00009ooooo`?o00005Oooool2o`0000Sooooo0_l00006ooooo`;o00001oooool2
o`0000?ooooo0_l0000=ooooo`;o00001OoooolSo`000003ooooool0003o000000;o00002_ooool2
o`000003ooooool0003o000004kooooo000Looooo`03o`000?oooooooooo02kooooo0_l0000Goooo
o`;o00001oooool6o`0000kooooo0_l0000Xooooo`Go00001Oooool2o`0001Cooooo0_l0000=oooo
o`;o00001OoooolUo`0000Gooooo0_l0000?ooooo`Co00001_ooool3o`0003gooooo000Looooo`03
o`000?oooooooooo02Oooooo0_l00005ooooo`;o00004oooool2o`0000_ooooo1_l00004ooooo`Ko
00001?ooool2o`0000;ooooo0_l00002ooooo`;o00008Oooool4o`0000Cooooo0_l00002ooooo`;o
00006?ooool2o`0001;ooooo4_l000000ooooooo0000o`00000;o`000003ooooool0003o000000;o
oooo0ol0000>ooooo`Co00001_ooool3o`0003gooooo000Looooo`03o`000?oooooooooo02Oooooo
0_l00009ooooo`;o00001oooool2o`0000Kooooo0_l0000;ooooo`;o000000Coooooo`000?l0003o
00001?ooool6o`0000Sooooo0_l00002ooooo`?o00000oooool2o`0000Gooooo0_l00003ooooo`?o
00002?ooool2o`0000cooooo0_l00002ooooo`;o00006?ooool2o`0000Sooooo0_l000000ooooooo
0000o`000004ooooo`;o000000?oooooo`000?l000007?l000000ooooooo0000o`000003ooooo`;o
00001oooool2o`0000Kooooo0_l00017ooooo`007?ooool2o`0003?ooooo0_l00007ooooo`;o0000
2?ooool2o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`0000kooooo0_l00007ooooo`;o0000
0oooool2o`000004ooooool0003o0000ooooo`?o00000oooool3o`000003ooooool0003o000000Go
oooo0_l0000@ooooo`;o00004oooool2o`0000gooooo0_l000000ooooooo0000o`000003oooooaSo
000000?oooooo`000?l000001ol00002ooooo`;o00002Oooool4o`0004oooooo000Looooo`03o`00
0?oooooooooo02_ooooo0_l000000ooooooo0000o`00000;ooooo`;o00002?ooool2o`0000;ooooo
0_l0000Iooooo`;o00002?ooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000So
oooo0_l00002ooooo`;o00004Oooool4o`0001?ooooo0_l0000Dooooob;o00000oooool2o`000003
ooooool0003o000000Kooooo1?l0000Cooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0
9_ooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0001?ooooo1?l00004ooooo`;o
000000?oooooo`000?l000006oooool2o`00017ooooo0_l00002ooooo`?o00002Oooool2o`0000Ko
oooo0_l00002ooooo`;o00005_ooool2o`0000oooooo8ol00002ooooo`;o000000?oooooo`000?l0
00000_l00004ooooo`Co00000_ooool4o`0000Oooooo0_l00004ooooo`;o0000>_ooool001cooooo
00?o0000ooooooooool09_ooool2o`0000Cooooo0_l00003ooooo`;o00003_ooool2o`0000?ooooo
1?l00004ooooo`;o000000?oooooo`000?l000006?ooool4o`0000kooooo0_l00002ooooo`;o0000
00Coooooo`000?l0003o00002_ooool2o`0000[ooooo0_l000001?oooooo0000o`000?ooool2o`00
00oooooo1?l0000>ooooob?o000000Coooooo`000?l0003o00000oooool2o`0000[ooooo1?l00007
ooooo`;o00002?ooool2o`0003Kooooo000Looooo`03o`000?oooooooooo02Kooooo0_l00004oooo
o`;o00000_ooool2o`0000oooooo0_l00003ooooo`Co00006?ooool2o`0000Oooooo1?l0000>oooo
o`;o00001Oooool2o`0000Wooooo0_l00005ooooo`Go00001Oooool5o`0000;ooooo0_l00004oooo
o`;o00001Oooool4o`0000Sooooo0_l00002ooooo`;o00000ooooolSo`0000_ooooo0_l0000Hoooo
o`;o0000=_ooool001cooooo00?o0000ooooooooool09_ooool2o`0000Sooooo0_l000000ooooooo
0000o`000002ooooo`;o00001_ooool2o`0000Cooooo1?l0000Iooooo`;o00001oooool2o`0000?o
oooo0_l00004ooooo`;o00005Oooool4o`0000Gooooo1Ol00006ooooo`;o00000oooool3o`0000Co
oooo0_l00005ooooo`;o00002_ooool2o`0000;ooooo0_l00003oooooa;o000000?oooooo`000?l0
00003?l00003ooooo`;o00001?ooool2o`0000;ooooo1?l00003ooooo`;o00001_ooool2o`00047o
oooo000Looooo`03o`000?oooooooooo02Oooooo0_l0000:ooooo`?o000000?oooooo`000?l00000
1_ooool2o`0000Cooooo0_l00005ooooo`;o00003Oooool2o`0000;ooooo0_l000000ooooooo0000
o`000007ooooo`So00000oooool2o`0000Gooooo0_l00002ooooo`;o00002?ooool4o`000003oooo
ool0003o000000;o00000_ooool6o`000003ooooool0003o000000Cooooo0_l000001Ooooooo0000
o`000?l0003ooooo00;o00000oooool2o`0000?ooooo0_l000000ooooooo0000o`00000?ooooo`;o
000000?oooooo`000?l000007Ol00003ooooo`;o00000_ooool4o`0000?ooooo1Ol000000ooooooo
0000o`000006ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool09oooool2o`0000Sooooo
1Ol0000>ooooo`?o00001Oooool2o`0000[ooooo0_l000001?oooooo0000o`000?ooool3o`0000co
oooo0ol000000ooooooo0000o`000002o`0000Sooooo0_l000001?oooooo0000o`000?l00008oooo
o`;o00000oooool4o`0000;ooooo1_l000000ooooooo0000o`000006o`0000;ooooo0_l000000ooo
oooo0000o`000002o`000004ooooool0003o0000o`0000Gooooo0_l0000=ooooobGo00001_ooool2
o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0004cooooo000Looooo`03o`000?oooooo
oooo037ooooo1Ol00007ooooo`?o00001?ooool2o`0000Gooooo0_l0000;ooooo`So00001?ooool3
o`0000cooooo0_l0000;ooooo`;o00002?ooool2o`0000;ooooo0ol00003ooooo`Wo000000?ooooo
o`000?l000001ol00005ooooo`;o00000_ooool2o`00017ooooo0_l000001?oooooo0000o`000?oo
ool>o`000003ooooool0003o000000_o000000?oooooo`000?l000000ol00002ooooo`;o00001_oo
ool2o`0001;ooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0dooooo`;o00000_ooool2
o`0000?ooooo0ol00004ooooo`Co00000oooool2o`0000cooooo0_l000000ooooooo0000o`000002
o`0000Cooooo0ol0000Qooooo`Co00000_ooool3o`0000;ooooo0ol00002ooooo`Oo00000oooool5
o`0000Gooooo0_l0000Eooooo`;o00001Oooool<o`000003ooooool0003o000000co000000Cooooo
o`000?l0003o00001?ooool2o`0000Cooooo0_l00009ooooo`;o00002Oooool2o`0003kooooo000L
ooooo`03o`000?oooooooooo02[ooooo0_l00007ooooo`?o00000_ooool2o`0000;ooooo0ol00007
ooooo`;o00004?ooool2o`0000Cooooo0_l00003ooooo`Co00000oooool2o`000003ooooool0003o
000000;ooooo0_l0000Eooooo`;o000000Goooooo`000?l0003o0000ooooo`03o`000004ooooool0
003o0000o`0000;ooooo1ol000000ooooooo0000o`000006o`0000Cooooo0_l0000Aooooo`;o0000
1?ooool2o`000003ooooool0003o000001_o00000_ooool2o`0000[ooooo0_l00009ooooo`;o0000
BOooool001cooooo00?o0000ooooooooool0:_ooool2o`0000Oooooo0_l00007ooooo`;o00000_oo
ool2o`0000_ooooo0_l00009ooooo`;o00002Oooool5o`0000;ooooo0_l000000ooooooo0000o`00
0004o`000003ooooool0003o000000[ooooo0_l00002ooooo`;o000000Goooooo`000?l0003o0000
ooooo`03o`000003ooooool0003o000000Ko000000?oooooo`000?l000002Ol00003ooooo`;o0000
1Oooool4o`0000?ooooo0_l00009ooooo`;o00001?ooool2o`000003ooooool0003o000001Wo0000
0_ooool2o`0000;ooooo2?l00009ooooo`;o0000COooool001cooooo00?o0000ooooooooool09ooo
ool2o`0000Oooooo0ol00007ooooo`;o00001?ooool2o`0000_ooooo0ol000000ooooooo0000o`00
0007ooooo`;o00000_ooool2o`0000Gooooo1Ol00005ooooo`;o00000oooool2o`0000[ooooo0_l0
0002ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`000003ooooool0003o000000;o0000
00?oooooo`000?l000002_l00006ooooo`;o000000?oooooo`000?l000000_ooool4o`0000?ooooo
0_l000000ooooooo0000o`000003o`0000Gooooo1?l00006oooooaSo00000_ooool2o`0000;ooooo
2Ol00003ooooo`;o00000_ooool3o`0000Wooooo0_l00012ooooo`007?ooool00ol0003ooooooooo
o`0Wooooo`;o00001oooool4o`0000Kooooo0_l0000Booooo`;o000000?oooooo`000?l000001ooo
ool2o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`Co00002?ooool2o`0000Cooooo0_l0
0006ooooo`;o00001oooool2o`0000;ooooo1ol000000ooooooo0000o`000009o`0000Oooooo0ol0
0002ooooo`?o00001_ooool5o`0000Gooooo1?l00002ooooo`ko00000_ooool3o`000004ooooool0
003o0000ooooo`Co00002?ooool2o`000004ooooool0003o0000ooooo`;o00000oooool2o`0000;o
oooo0_l0000:ooooo`;o0000@_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q
8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo03;ooooo0_l0000C
ooooo`?o00004oooool2o`0000;ooooo0_l00005ooooo`Co00002?ooool2o`0000?ooooo0ol00006
ooooo`Co00001Oooool2o`0000;ooooo1_l00003ooooo`Ko00000_ooool4o`0000?ooooo1Ol00002
ooooo`;o00000_ooool2o`0000[ooooo0_l00002ooooo`;o00000oooool=o`0000;ooooo3?l0000;
ooooo`;o000000?oooooo`000?l000007oooool2o`0003Kooooo00001_ooooooMgMgoiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`0iooooo`;o00003?ooool3o`0000Sooooo0_l00007ooooo`Co00002Oooool2o`0000oooooo
0_l00008ooooo`?o00001_ooool2o`000003ooooool0003o000001?o00000_ooool5o`0000;ooooo
0_l00003ooooo`;o00002_ooool2o`0000_ooooo0_l00002ooooo`Co000000?oooooo`000?l00000
1Ol000001Ooooooo0000o`000?l0003ooooo00?o00003Oooool2o`0000;ooooo0ol0000Iooooo`?o
0000=_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool0>Oooool2o`0001Oooooo1?l00005ooooo`Co
00005_ooool2o`0000?ooooo0_l00003ooooo`Ko00001?oooolHo`000003ooooool0003o000000So
000000?oooooo`000?l000000ol00008ooooo`;o00001Oooool2o`0000Sooooo0ol000000ooooooo
0000o`000005o`0000Kooooo0_l00002ooooo`Co00000_ooool2o`0000Sooooo1ol0000;ooooo`;o
00002oooool3o`0003Oooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo
00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000<Oooool2o`0001?ooooo0_l0000;ooooo`?o
00001oooool2o`0000Cooooo0_l0000@ooooo`;o00000oooool2o`0000?ooooo1?l00006ooooo`?o
000000?oooooo`000?l000007Ol000000ooooooo0000o`000007o`0000Cooooo0_l00005ooooo`;o
00002Oooool2o`000003ooooool0003o000000Wo00000_ooool2o`000003ooooool0003o000000?o
00000_ooool2o`0000Cooooo0_l00004ooooo`;o00003_ooool2o`0000Gooooo0_l00004ooooo`Co
0000=_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oEEEE
o`000?l@413oc<c<00Kooooo00?o0000ooooooooool0<Oooool2o`0000gooooo0_l00004ooooo`;o
00003?ooool3o`0000cooooo0_l00004ooooo`Co00002?ooool2o`0000;ooooo0_l00008ooooo`Oo
00000_oooolLo`0000;ooooo0ol000001?oooooo0000o`000?ooool5o`000003ooooool0003o0000
01Kooooo0ol00003ooooo`Go00000_ooool2o`000003ooooool0003o000000_ooooo0ol0000Joooo
o`;o00000oooool2o`000003ooooool0003o000003Kooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`0iooooo`;o
00001Oooool2o`0001?ooooo0_l0000>ooooo`So00001?ooool2o`0000;ooooo1_l00003ooooo`;o
00000oooool7o`000003ooooool0003o000001co000000Coooooo`000?l0003o00001?ooool2o`00
0004ooooool0003o0000ooooo`;o00001_ooool2o`0000oooooo0_l00002ooooo`;o000000?ooooo
o`000?l000000oooool2o`0000Kooooo0_l00007ooooo`;o000000?oooooo`000?l000004?ooool2
o`0000[ooooo0_l0000iooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@
413oV9RH00Sooooo00?o0000ooooooooool0>?ooool3o`0000kooooo0_l0000:ooooo`?o00003Ooo
ool6o`000003ooooool0003o000000?ooooo0_l00003ooooo`Oo000000?oooooo`000?l000000ooo
ool2o`000004ooooool0003o0000ooooo`co000000?oooooo`000?l000004Ol00009ooooo`Ko0000
1oooool2o`0000Gooooo0_l000000ooooooo0000o`000005ooooo`Ko000000Goooooo`000?l0003o
0000ooooo`03o`0000Kooooo0ol00004ooooo`;o00000oooool2o`00013ooooo0_l00015ooooo`00
00Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000
ooooooooool0>?ooool2o`0000Sooooo0_l00005ooooo`;o00002?ooool2o`000003ooooool0003o
000000_ooooo0_l00007ooooo`;o00002?ooool7o`0000;ooooo0_l00003ooooo`Co000000?ooooo
o`000?l000005_l000000ooooooo0000o`000007o`000004ooooool0003o0000o`0000?ooooo0_l0
0002ooooo`;o00003_ooool2o`000003ooooool0003o000000?ooooo0ol000000ooooooo0000o`00
0003ooooo`?o000000Coooooo`000?l0003o00001oooool2o`0000Cooooo0_l0001Looooo`007?oo
ool00ol0003oooooooooo`0gooooo`?o00001oooool3o`0000Sooooo0_l00005ooooo`;o00003Ooo
ool3o`0000?ooooo0_l00008ooooo`;o00001?ooool2o`0000Cooooo0ol00002ooooo`Co000000?o
ooooo`000?l000008Ol000001?oooooo0000o`000?l00003ooooo`;o00005oooool2o`000004oooo
ool0003o0000o`0000Kooooo0_l0001`ooooo`007?ooool00ol0003oooooooooo`0gooooo`Go0000
0_ooool2o`000003ooooool0003o000000;o00001oooool2o`0001Cooooo0_l00004ooooo`Go0000
1?ooool5o`0000Sooooo0_l00003ooooobGo00000_ooool4o`0000Kooooo0_l00006ooooo`;o0000
3Oooool2o`0000;ooooo0_l00009ooooo`;o0000KOooool001cooooo00?o0000ooooooooool0>Ooo
ool3o`0000;ooooo0_l00003ooooo`;o00001_ooool2o`0001;ooooo0_l000000ooooooo0000o`00
0002ooooo`;o000000?oooooo`000?l000001?l00002ooooo`;o000000?oooooo`000?l000003?oo
ool2o`000003ooooool0003o0000027o000000Coooooo`000?l0003o00002?ooool2o`000004oooo
ool0003o0000o`0000;ooooo0_l0000Aooooo`;o00002Oooool2o`0000Sooooo0_l0001Sooooo`00
7?ooool00ol0003oooooooooo`0cooooo`;o00003oooool3o`0000Cooooo0_l00008ooooo`?o0000
1oooool2o`0000Gooooo0_l00003ooooo`Co00000_ooool2o`0000gooooo1Ol000000ooooooo0000
o`00000Io`000003ooooool0003o000000Oo00001_ooool2o`0000Cooooo0ol00005ooooo`Co0000
1Oooool2o`0000?ooooo0ol00003ooooo`;o00000_ooool2o`0000_ooooo0_l0001Sooooo`007?oo
ool00ol0003oooooooooo`0cooooo`;o00003oooool3o`0000Cooooo0_l00008ooooo`?o00004?oo
ool2o`0000?ooooo0_l00002ooooo`;o00002?ooool2o`0000?ooooo1Ol000000ooooooo0000o`00
000To`0000Gooooo0_l0000<ooooo`Go00001?ooool2o`000003ooooool0003o000000?o00000ooo
ool2o`0000;ooooo0ol00003ooooo`;o00005_ooool2o`0005;ooooo000Looooo`03o`000?oooooo
oooo04Gooooo0_l0000Qooooo`So00001?ooool2o`0000Gooooo1?l000001?oooooo0000o`000?l0
0002ooooobOo000000Coooooo`000?l0003o00001Oooool2o`0000Wooooo1?l00007ooooo`;o0000
2oooool2o`0000?ooooo0_l0000Fooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0AOoo
ool2o`0001;ooooo0_l0000?ooooo`Ko00001?ooool2o`0000Gooooo1?l000000ooooooo0000o`00
0002o`000003ooooool0003o000002Wo00001?ooool3o`0001oooooo1?l0000<ooooo`;o00000_oo
ool2o`0000Oooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o00001oooool2
o`0000;ooooo0_l0000Cooooo`Go00000_ooool2o`000003ooooool0003o000002Wo00000_ooool4
o`0001cooooo0_l00002ooooo`;o00001?ooool2o`0000Oooooo0ol00002ooooo`;o00001oooool2
o`0005Cooooo000Looooo`03o`000?oooooooooo06;ooooo0_l00002ooooo`Co00001?ooool2o`00
00Cooooo0_l00005ooooo`Go00000_ooool2o`000003ooooool0003o000002;o00000oooool8o`00
0003ooooool0003o000000[ooooo0_l0000?ooooo`;o00002?ooool2o`000003ooooool0003o0000
00Cooooo0ol0001Qooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00004?ooool2o`0000ko
oooo0_l00002ooooo`;o00001?ooool4o`0000;ooooo0_l00005ooooo`;o00002OoooolTo`0000;o
oooo2?l000000ooooooo0000o`00000:ooooo`Ko00001?ooool2o`0000Wooooo0_l00007ooooo`;o
00001?ooool2o`0000Oooooo0_l00005ooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0
=oooool2o`0000Wooooo0_l0000=ooooo`;o000000?oooooo`000?l000003Oooool4o`0000Wooooo
0_l00002ooooo`;o00001Oooool2o`0000Oooooo0_l000000ooooooo0000o`00000Bo`000003oooo
ool0003o0000017o00000oooool2o`000003ooooool0003o000000_ooooo1Ol000001?oooooo0000
o`000?ooool2o`0000Gooooo0_l00002ooooo`;o00005_ooool2o`0000Gooooo1?l0000>ooooo`;o
0000@?ooool001cooooo0_l0000hooooo`;o00004?ooool2o`0000Kooooo0_l000000ooooooo0000
o`000002ooooo`;o00002Oooool4o`0001Kooooo0_l00005ooooob_o00001_ooool2o`000003oooo
ool0003o000000Sooooo0_l00003ooooo`?o000000?oooooo`000?l000001Oooool2o`0001Sooooo
0_l00007ooooo`Co00003_ooool2o`0000;ooooo0_l0000looooo`007?ooool00ol0003ooooooooo
o`10ooooo`;o00001oooool2o`0000Wooooo0_l00002ooooo`;o00001oooool4o`0000_ooooo0_l0
0006ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo:?l00006ooooo`;o00000_oo
ool4o`0000;ooooo0_l00002ooooo`;o00001Oooool2o`0001_ooooo0_l00006ooooo`;o00002Ooo
ool2o`0001;ooooo0_l0000looooo`007?ooool00ol0003oooooooooo`10ooooo`;o00001oooool2
o`0000Sooooo0_l00002ooooo`;o00002?ooool2o`0000Gooooo0_l00006ooooo`;o00000_ooool2
o`0000;ooooo0_l00006ooooo`;o00000_oooolYo`0000Gooooo0_l00002ooooo`?o000000?ooooo
o`000?l000000_l000000ooooooo0000o`000003o`000003ooooool0003o000000Sooooo0_l0000C
ooooo`;o0000Hoooool001cooooo00?o0000ooooooooool0>oooool2o`000003ooooool0003o0000
00Wooooo0_l00008ooooo`;o00000_ooool3o`0000Kooooo0_l000001?oooooo0000o`000?ooool6
o`0000?ooooo0_l00003ooooo`;o00001Oooool2o`0000Cooooo0ol000001?oooooo0000o`000?oo
oolGo`000003ooooool0003o000000?o00000_ooool6o`0000Gooooo0_l00002ooooo`?o000000?o
ooooo`000?l000000_l000001?oooooo0000o`000?ooool2o`000004ooooool0003o0000ooooo`;o
000000?oooooo`000?l000001_l0000;ooooo`?o00002Oooool2o`0000[ooooo0_l0000<ooooo`;o
0000@oooool001cooooo00?o0000ooooooooool0>oooool2o`000003ooooool0003o000001Sooooo
0_l00006ooooo`;o000000?oooooo`000?l000000ol00002ooooo`;o00000oooool2o`0000[ooooo
0_l00003ooooo`Co000000Coooooo`000?l0003ooooo7?l000000ooooooo0000o`000002ooooo`;o
00000oooool2o`0000Sooooo0_l000001?oooooo0000o`000?l00004ooooo`;o000000Coooooo`00
0?l0003ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0ol00003ooooo`;o00001Oooool4
o`0000Sooooo0_l000000ooooooo0000o`000007ooooo`;o00003?ooool2o`0004?ooooo000Loooo
o`03o`000?oooooooooo03oooooo0_l00005ooooo`;o00007?ooool4o`0001Sooooo0_l000000ooo
oooo0000o`000002o`0000Cooooo8?l00003ooooo`;o00002?ooool2o`0000Cooooo0ol00007oooo
o`?o00001oooool4o`000003ooooool0003o000000Kooooo1?l00008ooooo`Co00000oooool2o`00
05Gooooo000Looooo`03o`000?oooooooooo03oooooo0_l00005ooooo`;o00002_ooool2o`0000So
oooo1?l00006ooooo`;o00002?ooool2o`0000oooooo1?l00002ooooo`Co000000?oooooo`000?l0
00006?l000000ooooooo0000o`000002o`000003ooooool0003o000000Co00000oooool2o`0000Oo
oooo0ol00008ooooo`?o00002?ooool2o`0000_ooooo0_l00008ooooo`?o00001?ooool2o`0005Go
oooo000Looooo`03o`000?oooooooooo05;ooooo0_l00008ooooo`Co000000Coooooo`000?l0003o
oooo1?l00007ooooo`?o000000?oooooo`000?l000003?ooool4o`0000;ooooo1?l000000ooooooo
0000o`00000?o`000003ooooool0003o000000Ko000000?oooooo`000?l000000oooool2o`0000;o
oooo0ol00002ooooo`;o00002oooool2o`0000Kooooo0_l000000ooooooo0000o`00000Mooooo`;o
00001_ooool2o`0000_ooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`0mooooo`;o0000
0_ooool2o`0000Cooooo0_l0000Cooooo`;o00000oooool7o`0000;ooooo0_l00003ooooo`Ko0000
3OoooolKo`000003ooooool0003o000000Wo00000_ooool2o`0000Cooooo0_l00003ooooo`Co0000
2?ooool2o`000003ooooool0003o000000;o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o
00005Oooool2o`0000?ooooo0_l00003ooooo`;o00002oooool2o`0004Kooooo000Looooo`03o`00
0?oooooooooo03gooooo0_l00002ooooo`;o00001?ooool2o`00017ooooo0_l00007ooooo`;o0000
1Oooool2o`0000Gooooo0ol0000>ooooobSo000000?oooooo`000?l000001_ooool2o`000003oooo
ool0003o000000;o00001oooool2o`0000;ooooo1?l000000ooooooo0000o`000002o`0000Gooooo
0_l000000ooooooo0000o`000003ooooo`;o00003Oooool2o`0000?ooooo0_l000000ooooooo0000
o`00001Eooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00000_ooool2o`0001Gooooo0ol0
000@ooooo`;o00001?ooool2o`0000Wooooo0_l000000ooooooo0000o`000007o`000003ooooool0
003o000001Wo000000?oooooo`000?l000001Ol00002ooooo`;o00000_ooool6o`0000Sooooo0_l0
0009ooooo`;o00002?ooool2o`0000?ooooo0_l00009ooooo`;o00001_ooool2o`0000;ooooo0_l0
000;ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0?_ooool2o`0000;ooooo0_l00004
ooooo`;o00002oooool2o`0000;ooooo0_l0000Aooooo`;o00000oooool2o`0000Gooooo0_l00003
ooooo`;o000000Coooooo`000?l0003ooooo1Ol00003ooooo`;o00000_ooool;o`000003ooooool0
003o000000Co00000_ooool2o`0000?ooooo1Ol00002ooooo`;o00001?ooool2o`0000;ooooo0_l0
0008ooooo`;o00002?ooool2o`0001Oooooo0_l00006ooooo`;o00003oooool2o`0004Sooooo000L
ooooo`03o`000?oooooooooo04Oooooo0ol0000;ooooo`;o00006_ooool2o`0000Gooooo0_l00003
ooooo`;o00001_ooool4o`0000;ooooo0ol000000ooooooo0000o`000003o`0000;ooooo1Ol00000
0ooooooo0000o`000002o`0000Wooooo1?l0000<ooooo`;o00002?ooool2o`0000?ooooo0_l00003
ooooo`;o00005oooool2o`000003ooooool0003o000000Cooooo0_l0001Hooooo`007?ooool00ol0
003oooooooooo`13ooooo`;o00000_ooool2o`0000Cooooo1?l0000Pooooo`Oo00001?ooool2o`00
00Oooooo1?l00002ooooo`Wo000000?oooooo`000?l000002Ol00002ooooo`Go00000oooool2o`00
00Gooooo0_l00006ooooo`;o00003Oooool2o`0001cooooo0_l000000ooooooo0000o`000004oooo
o`;o0000F?ooool001cooooo00?o0000ooooooooool0@oooool2o`0000Sooooo1?l00004ooooo`;o
00002?ooool4o`0000Cooooo0ol00008ooooo`Ko00001?ooool2o`0000Gooooo0_l000000ooooooo
0000o`000004ooooo`Oo00000_ooool8o`000004ooooool0003o0000ooooo`Ko00002_ooool2o`00
00Kooooo0_l0002>ooooo`007?ooool00ol0003oooooooooo`1Cooooo`Co00001Oooool2o`000003
ooooool0003o000000;o00001?ooool3o`000003ooooool0003o000001Cooooo2?l00003ooooo`;o
000000?oooooo`000?l000000ol000000ooooooo0000o`000006o`0000Cooooo1Ol00004ooooo`;o
0000WOooool001cooooo0_l00014ooooo`;o00003_ooool2o`0000Oooooo0_l0000=ooooo`;o0000
1Oooool2o`0000?ooooo0_l00008ooooo`Go000000?oooooo`000?l000000_ooool4o`0000;ooooo
2_l00007ooooo`;o000000?oooooo`000?l000000oooool2o`0000Cooooo0_l00009ooooo`;o0000
;Oooool3o`0005cooooo000Looooo`03o`000?oooooooooo04?ooooo0_l0000Uooooo`;o00000_oo
ool2o`0000;ooooo1ol00003ooooo`;o00001Oooool2o`0000;ooooo0_l000000ooooooo0000o`00
0003o`0000;ooooo1_l000001?oooooo0000o`000?l00007ooooo`;o000000?oooooo`000?l00000
2Oooool2o`0000Kooooo0_l000000ooooooo0000o`00000]ooooo`?o0000G?ooool001cooooo00?o
0000ooooooooool0AOooool2o`00017ooooo0_l000000ooooooo0000o`00000=ooooo`;o00000_oo
ool2o`000003ooooool0003o000000Ko00000oooool2o`0000Wooooo0_l000000ooooooo0000o`00
0002o`000003ooooool0003o000000[ooooo0_l0000Jooooo`?o0000;_ooool2o`0005oooooo000L
ooooo`03o`000?oooooooooo04Gooooo0_l00004ooooo`;o00002oooool2o`000003ooooool0003o
0000017ooooo0_l000001?oooooo0000o`000?l00003ooooo`?o00003Oooool2o`0000Kooooo0_l0
00000ooooooo0000o`000004ooooo`Go00000_ooool2o`0000Kooooo0_l000000ooooooo0000o`00
000;ooooo`;o00000oooool2o`0002[ooooo0ol0001Nooooo`007?ooool00ol0003oooooooooo`1;
ooooo`;o00001?ooool2o`0000Sooooo0_l0000Eooooo`;o000000Coooooo`000?l0003ooooo0_l0
0003ooooo`;o00002?ooool2o`0000Gooooo0_l00002ooooo`;o00001?ooool3o`0000Cooooo0_l0
0006ooooo`;o000000?oooooo`000?l000002?ooool2o`0000Kooooo0_l0000[ooooo`?o0000GOoo
ool001cooooo00?o0000ooooooooool0B_ooool2o`0000Gooooo0_l00008ooooo`;o00003_ooool4
o`0000Kooooo1Ol00003ooooo`;o00002?ooool2o`0000Gooooo0_l0000;ooooo`;o00005oooool2
o`0003Cooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o00001?ooool2o`00
00[ooooo0_l0000=ooooo`Co00001oooool4o`0000Cooooo0_l0000@ooooo`Co00001oooool2o`00
01;ooooo0_l0000[ooooo`;o0000Joooool001cooooo00?o0000ooooooooool0B_ooool2o`0000Co
oooo0_l00005ooooo`Co000000?oooooo`000?l000004_ooool2o`0000Kooooo1?l00002ooooo`;o
00001oooool2o`0000;ooooo0_l00002ooooo`Go00000_ooool2o`0000[ooooo1?l000000ooooooo
0000o`000006ooooo`;o0000:oooool3o`0000Sooooo0_l0001Pooooo`007?ooool00ol0003ooooo
ooooo`1>ooooo`;o00001oooool5o`0001Cooooo0_l00006ooooo`Co00002oooool2o`0000;ooooo
0_l00002ooooo`;o00001Oooool4o`0000?ooooo0_l00003ooooo`Co000000?oooooo`000?l00000
2?ooool2o`0002[ooooo0_l00008ooooo`;o00003oooool2o`0004oooooo000Looooo`03o`000?oo
oooooooo04kooooo0_l0000:ooooo`;o000000?oooooo`000?l000001Oooool3o`0000Gooooo0_l0
000;ooooo`Go00000oooool2o`0001Gooooo1?l000000ooooooo0000o`000002o`0000Sooooo0_l0
0006ooooo`;o0000;oooool2o`0000;ooooo0_l0000@ooooo`;o0000Coooool001cooooo00?o0000
ooooooooool0F?ooool2o`0000?ooooo0_l00005ooooo`?o00001Oooool2o`0000Gooooo0ol00002
ooooo`Ko00000oooool4o`0001Gooooo0_l00003ooooo`;o00002?ooool2o`0001;ooooo0_l0000Q
ooooo`Co00000_ooool2o`00067ooooo000Looooo`03o`000?oooooooooo05Cooooo0ol000000ooo
oooo0000o`00000Iooooo`?o00000_ooool5o`0000Kooooo0_l0000?ooooo`;o00003oooool2o`00
01Kooooo1?l0000Oooooo`;o0000Ioooool001cooooo00?o0000ooooooooool0C_ooool2o`0000Co
oooo0ol0000Mooooo`;o00000oooool4o`0000Kooooo1?l00003ooooo`;o00002?ooool2o`0000oo
oooo0_l0000Gooooo`?o00007oooool2o`000004ooooool0003o0000ooooo`;o00002_ooool2o`00
05Gooooo000Looooo`03o`000?oooooooooo04kooooo0_l0000:ooooo`;o00006?ooool2o`0000?o
oooo1_l00006ooooo`;o00000oooool2o`0000;ooooo0_l00004ooooo`;o00004oooool2o`0000_o
oooo0_l00006ooooo`;o00008oooool2o`000003ooooool0003o000000[ooooo0_l0001Eooooo`00
7?ooool00ol0003oooooooooo`1Jooooo`?o000000?oooooo`000?l000002_ooool2o`0000oooooo
1_l0000=ooooo`;o00003?ooool2o`0000_ooooo0_l0000;ooooo`;o00007Oooool2o`0007;ooooo
000Looooo`03o`000?oooooooooo05_ooooo0_l000000ooooooo0000o`000006ooooo`;o00000_oo
ool2o`0000oooooo1_l0000:ooooo`;o00001_ooool2o`0000Oooooo0_l0000gooooo`;o00002ooo
ool2o`0006Gooooo000Looooo`;o0000Ioooool2o`000003ooooool0003o000001;ooooo0_l0000<
ooooo`;o00001_ooool2o`0000Cooooo0_l0000?ooooo`;o00004_ooool2o`0001Oooooo0_l00009
ooooo`;o0000IOooool001cooooo00?o0000ooooooooool0EOooool3o`00017ooooo0_l0000<oooo
o`;o00001Oooool4o`00013ooooo1Ol00002ooooo`;o00003oooool2o`0000Cooooo0_l0000<oooo
o`;o00005_ooool3o`0000Wooooo0_l00009ooooo`;o0000F_ooool001cooooo00?o0000oooooooo
ool0EOooool4o`0001kooooo0_l00005ooooo`Co00001_ooool2o`0000Oooooo0ol000000ooooooo
0000o`00000Iooooo`;o000000?oooooo`000?l000007oooool4o`0000;ooooo1?l00004ooooo`;o
00002Oooool2o`0005[ooooo000Looooo`03o`000?oooooooooo05Oooooo0ol0000^ooooo`;o0000
0_ooool2o`0000;ooooo0ol00004ooooo`;o000000Coooooo`000?l0003o00004?ooool2o`0000Co
oooo0_l0000Nooooo`?o00001?ooool4o`0006_ooooo000Looooo`03o`000?oooooooooo05Sooooo
0_l0000Gooooo`;o00006Oooool2o`0000;ooooo0_l00005ooooo`;o000000Coooooo`000?l0003o
00004?ooool2o`0000;ooooo1?l00007ooooo`;o00003Oooool2o`0000Kooooo0ol00009ooooo`;o
00001Oooool2o`0000;ooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1Looooo`;o0000
4oooool2o`0000Cooooo0_l0000Gooooo`;o00007oooool2o`0000Kooooo0_l000000ooooooo0000
o`00000:ooooo`Go00000_ooool2o`000003ooooool0003o000000_ooooo0_l00004ooooo`?o0000
0_ooool2o`0005gooooo000Looooo`03o`000?oooooooooo05Kooooo0_l00004ooooo`;o00001?oo
ool2o`0000_ooooo0_l00006ooooo`;o00003oooool2o`0000Kooooo0_l00003ooooo`;o00002?oo
ool2o`0001Sooooo0_l0000=ooooo`Co000000?oooooo`000?l000000_l000001?oooooo0000o`00
0?ooool3o`0000gooooo0_l0001Rooooo`007?ooool00ol0003oooooooooo`1Fooooo`;o00002_oo
ool2o`0000Cooooo0_l00005ooooo`Co000000?oooooo`000?l000004_ooool4o`0000Wooooo0_l0
0008ooooo`?o0000:_ooool3o`000004ooooool0003o0000ooooo`Go00000_ooool2o`0000Kooooo
0_l0001Uooooo`007?ooool00ol0003oooooooooo`1Xooooo`;o00001oooool2o`000003ooooool0
003o000000;ooooo0_l0000:ooooo`;o00000oooool3o`0000gooooo0_l00005ooooo`;o0000:_oo
ool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l00006ooooo`;o0000IOoo
ool001cooooo00?o0000ooooooooool0Koooool2o`0000Oooooo0_l0000:ooooo`;o000000?ooooo
o`000?l000000_l00008ooooo`?o00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000007
ooooo`?o00002?ooool2o`00017ooooo0_l00007ooooo`;o00000_ooool2o`0007?ooooo000Loooo
o`03o`000?oooooooooo06oooooo0_l00005ooooo`;o00003oooool4o`0000Sooooo0ol00004oooo
o`;o000000?oooooo`000?l000000ol00007ooooo`?o00002?ooool2o`0000;ooooo0_l0000:oooo
o`Go00002oooool2o`0000Gooooo0_l00005ooooo`;o0000IOooool001cooooo00?o0000oooooooo
ool0KOooool2o`0000Oooooo0_l0000=ooooo`;o000000?oooooo`000?l000004?ooool2o`0000;o
oooo0_l00005ooooo`;o000000?oooooo`000?l000003Oooool3o`0000[ooooo1?l00008ooooo`;o
00002Oooool2o`0000Gooooo0_l0001Uooooo`007?ooool00ol0003oooooooooo`1]ooooo`;o0000
1_ooool2o`0000kooooo0_l00003ooooo`Co00005oooool2o`000004ooooool0003o0000o`0000co
oooo0_l000000ooooooo0000o`000007ooooo`?o00002_ooool2o`0007Oooooo000Looooo`03o`00
0?oooooooooo06oooooo0_l00004ooooo`;o00000_ooool2o`0000oooooo1?l0000=ooooo`;o0000
1_ooool2o`0000;ooooo1?l00009ooooo`;o00001?ooool2o`0000Kooooo1?l00023ooooo`0000Ko
ooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<
00Kooooo00?o0000ooooooooool0Koooool2o`0000Sooooo0_l0000Eooooo`?o00002?ooool2o`00
00Cooooo1?l00002ooooo`;o00002Oooool4o`000003ooooool0003o000000;o00001oooool2o`00
01?ooooo0_l0001`ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool0
1OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0L_ooool2o`00013ooooo0_l0
0009ooooo`Go00003Oooool2o`0000Gooooo0_l00007ooooo`?o00000oooool4o`0001cooooo0_l0
001`ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`1booooo`;o00001Oooool4o`0000Oooooo0_l0
0009ooooo`;o000000?oooooo`000?l000001?ooool2o`0000_ooooo0_l000000ooooooo0000o`00
0007ooooo`;o00001?ooool3o`0001;ooooo0_l0001kooooo`0000?oooooo`000?ooool00_ooool0
0ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`0007Wooooo1?l0
000Jooooo`Co00001_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l0
0005ooooo`Co00002oooool2o`0000Gooooo0_l0000:ooooo`;o00003?ooool2o`00067ooooo0000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Goc<c<o`000?l0003o0000olc<
c006ooooo`03o`000?oooooooooo06;ooooo0_l0000Jooooo`;o00002Oooool2o`0000_ooooo1Ol0
00000ooooooo0000o`000003ooooo`;o00000_ooool2o`000003ooooool0003o000000;o00000ooo
ool2o`0000Gooooo0_l0000=ooooo`;o00004Oooool2o`0000cooooo0_l0001Qooooo`0000?ooooo
oa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_oo
ool00ol0003oooooooooo`1Rooooo`;o00000oooool2o`0001Gooooo0_l00009ooooo`?o00002_oo
ool8o`000:_ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo
^[Zjo`000006ooooo`03o`000?oooooooooo06Oooooo0_l0000Booooo`;o00003Oooool2o`0000Wo
oooo2?l0000;ooooo`;o00002oooool2o`00013ooooo0_l00020ooooo`0000Koooooonk^k_lb<S;o
0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`1k
ooooo`;o00005Oooool2o`000003ooooool0003o000000Oooooo0_l00008ooooo`;o00000_ooool2
o`0000Kooooo0ol0000>ooooo`Co0000P?ooool001cooooo00?o0000ooooooooool0T_ooool2o`00
0003ooooool0003o000000Oooooo0_l000000ooooooo0000o`000009ooooo`;o00001_ooool2o`00
00Wooooo0_l00004ooooo`;o00008Oooool2o`0005oooooo000Looooo`03o`000?oooooooooo06So
oooo0_l0000Dooooo`;o00007oooool4o`0000[ooooo0_l0000@ooooo`;o00009oooool2o`0005oo
oooo000Looooo`03o`000?oooooooooo06Sooooo0_l0000Dooooo`;o00003_ooool2o`000003oooo
ool0003o000000cooooo1?l0000:ooooo`?o00003_ooool2o`0000Kooooo0ol00020ooooo`007?oo
ool00ol0003oooooooooo`21ooooo`;o00002oooool2o`000003ooooool0003o000000Cooooo0_l0
000Eooooo`;o00003_ooool4o`000004ooooool0003o0000ooooo`?o00006Oooool2o`0006Gooooo
000Looooo`03o`000?oooooooooo087ooooo0_l0000:ooooo`?o00001oooool2o`0002Oooooo0_l0
00001?oooooo0000o`000?l0000Looooo`;o0000IOooool001cooooo00?o0000ooooooooool0SOoo
ool3o`0001Kooooo0_l0000Eooooo`;o00001Oooool2o`000003ooooool0003o0000083ooooo000L
ooooo`03o`000?oooooooooo09Cooooo0_l0000@ooooo`;o00002?ooool2o`0000_ooooo0_l00008
ooooo`;o0000P?ooool001cooooo00?o0000ooooooooool0TOooool2o`000003ooooool0003o0000
01[ooooo0_l00004ooooo`;o0000TOooool001cooooo00?o0000ooooooooool0TOooool2o`0001go
oooo0_l00004ooooo`;o00000_ooool2o`0008gooooo000Looooo`03o`000?oooooooooo0;[ooooo
0_l0002=ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;
ooooo`007?ooool00ol0003oooooooooo`2Gooooo`;o0000/?ooool001cooooo00?o0000oooooooo
ool0Uoooool2o`0003Kooooo0_l0001hooooo`007?ooool00ol0003oooooooooo`3?ooooo`;o0000
N?ooool001cooooo00?o0000ooooooooool0XOooool2o`0000kooooo0_l0000:ooooo`;o0000R_oo
ool001cooooo00?o0000ooooooooool0XOooool2o`0000kooooo0ol00009ooooo`;o0000R_ooool0
01cooooo00?o0000ooooooooool0/_ooool2o`0000Oooooo0ol0002;ooooo`007?ooool00ol0003o
ooooooooo`2kooooo`?o0000Roooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooo
ooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB_ooool001Cooooo00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o
0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Doooo
o`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`00
4_ooool00omEEEGoIVIVo`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo002Uooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05oooool00ol0
003ok^k^ooooo`03ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^093ooooo002Vooooo`05o`000?ooooooooooooooool000002Oooool6o`0000_ooooo00?o
EEEEojVYZOooool00oooool01OlQ8B7oV9RHoooooonHV9So8B4Q00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`2@ooooo`00Y_ooool01Ol0003ooooooooooooooooo000001[ooooo00?oZJVYoeEEEOoo
ool00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@402@
ooooo`00Y_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l0000<ooooo`03ob4Q8Ooooooo
oooo00;ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P03ooooo`05o`000?ooooooooooooooool00000
T?ooool00:Kooooo00Go0000ohN7QoooooooZJVYo`00000Kooooo`03oeEEEOo<c<cooooo00;ooooo
00Goc<c<o`000?l0003o0000olc<c003ooooo`05o`000?ooooooooooooooool00000T?ooool00:Go
oooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Iooooo`03ojVYZOmgMgOooooo00;o
oooo00Go410@okZj^_oooooo^[Zjoa0@4003ooooo`05oa0@4?ooooooooooooooool@4100T?ooool0
0<?ooooo00Go410@oooooooooooooooooc8b<P03ooooo`05o`000?nj^[[ooooookZj^_l000000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg093ooooo0033ooooo`Go00000oooool01OnYZJWo410@o`00
0?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP2@ooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(786) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.68029 .5522 Mdot
.67866 .56379 Mdot
.40356 .33412 Mdot
.45459 .67229 Mdot
.43418 .50743 Mdot
.46134 .34999 Mdot
.58027 .40581 Mdot
.56969 .37817 Mdot
.45749 .32882 Mdot
.54228 .68687 Mdot
.60441 .42957 Mdot
.38286 .61515 Mdot
.59097 .4019 Mdot
.47324 .62829 Mdot
.45488 .1658 Mdot
.39484 .63194 Mdot
.62817 .59126 Mdot
.34945 .43661 Mdot
.45192 .69866 Mdot
.42794 .30569 Mdot
.60299 .58085 Mdot
.47228 .62413 Mdot
.66578 .55285 Mdot
.4718 .62777 Mdot
.44475 .6608 Mdot
.66573 .5898 Mdot
.63626 .5508 Mdot
.42003 .64372 Mdot
.46597 .64648 Mdot
.56758 .42053 Mdot
.39738 .49292 Mdot
.31068 .23326 Mdot
.39005 .62766 Mdot
.49373 .8071 Mdot
.56767 .38634 Mdot
.19738 .53653 Mdot
.43439 .31704 Mdot
.61837 .40375 Mdot
.56654 .38298 Mdot
.59398 .37738 Mdot
.61098 .39582 Mdot
.67194 .58925 Mdot
.63566 .41814 Mdot
.57478 .45547 Mdot
.4553 .67755 Mdot
.70641 .43812 Mdot
.24332 .48824 Mdot
.42526 .63402 Mdot
.6958 .57968 Mdot
.44434 .30286 Mdot
.61083 .81277 Mdot
.60184 .37196 Mdot
.65231 .25256 Mdot
.37782 .12071 Mdot
.59409 .38754 Mdot
.44213 .67465 Mdot
.438 .33599 Mdot
.45504 .60448 Mdot
.45791 .62084 Mdot
.62238 .787 Mdot
.43908 .64694 Mdot
.33927 .45557 Mdot
.63674 .62193 Mdot
.4379 .37526 Mdot
.46016 .33985 Mdot
.56107 .39862 Mdot
.64976 .60752 Mdot
.59569 .41067 Mdot
.52219 .59888 Mdot
.45377 .31191 Mdot
.42425 .63308 Mdot
.6104 .42757 Mdot
.69817 .60692 Mdot
.47975 .59102 Mdot
.73457 .46088 Mdot
.52655 .1681 Mdot
.36456 .43478 Mdot
.60616 .77825 Mdot
.74414 .63476 Mdot
.54854 .20086 Mdot
.46793 .63673 Mdot
.85112 .41844 Mdot
.47156 .16426 Mdot
.66362 .55569 Mdot
.39733 .54265 Mdot
.46682 .39087 Mdot
.48771 .60834 Mdot
.44235 .46933 Mdot
.48833 .57611 Mdot
.77161 .53475 Mdot
.45263 .32436 Mdot
.68231 .59388 Mdot
.46148 .67139 Mdot
.43427 .5866 Mdot
.62575 .69746 Mdot
.49103 .58616 Mdot
.41439 .64567 Mdot
.61914 .56635 Mdot
.5751 .42062 Mdot
.44507 .56191 Mdot
.62099 .46143 Mdot
.64727 .2665 Mdot
.49522 .64963 Mdot
.46728 .32971 Mdot
.62291 .59855 Mdot
.49763 .65212 Mdot
.58309 .38475 Mdot
.44729 .63842 Mdot
.62098 .45423 Mdot
.68688 .56477 Mdot
.43905 .5859 Mdot
.34801 .43866 Mdot
.78068 .47735 Mdot
.67166 .6038 Mdot
.78865 .3593 Mdot
.43373 .64137 Mdot
.46958 .61795 Mdot
.67825 .56624 Mdot
.43338 .35481 Mdot
.4298 .45858 Mdot
.66831 .61459 Mdot
.58045 .37814 Mdot
.65193 .54728 Mdot
.51204 .64909 Mdot
.4687 .35518 Mdot
.64473 .27318 Mdot
.62376 .26819 Mdot
.31772 .6835 Mdot
.49157 .61672 Mdot
.66112 .39878 Mdot
.45498 .3561 Mdot
.68272 .58496 Mdot
.59795 .40882 Mdot
.4094 .65267 Mdot
.63412 .58337 Mdot
.61036 .41501 Mdot
.35094 .44273 Mdot
.26844 .39079 Mdot
.69287 .60113 Mdot
.59037 .51472 Mdot
.5894 .44562 Mdot
.59536 .37827 Mdot
.51781 .82749 Mdot
.67379 .56281 Mdot
.35421 .47716 Mdot
.60663 .41683 Mdot
.32507 .55595 Mdot
.40941 .64805 Mdot
.3586 .72443 Mdot
.84104 .52027 Mdot
.59093 .82608 Mdot
.70525 .33433 Mdot
.32689 .47737 Mdot
.61384 .38595 Mdot
.46444 .66134 Mdot
.66552 .56759 Mdot
.66993 .57618 Mdot
.41645 .59959 Mdot
.43552 .65694 Mdot
.42323 .60697 Mdot
.42276 .59683 Mdot
.25309 .46353 Mdot
.42162 .60461 Mdot
.45258 .28264 Mdot
.65356 .60312 Mdot
.45086 .6549 Mdot
.41641 .34494 Mdot
.40425 .66486 Mdot
.61671 .41011 Mdot
.45925 .61573 Mdot
.43372 .66257 Mdot
.49979 .60706 Mdot
.61218 .39193 Mdot
.25811 .29844 Mdot
.83023 .5135 Mdot
.18172 .44637 Mdot
.73915 .34831 Mdot
.4381 .34645 Mdot
.4838 .61306 Mdot
.35389 .45959 Mdot
.54834 .58714 Mdot
.45436 .62524 Mdot
.68146 .77434 Mdot
.42409 .65416 Mdot
.4665 .7795 Mdot
.47798 .70226 Mdot
.17531 .4347 Mdot
.49777 .40573 Mdot
.45998 .64629 Mdot
.60171 .66996 Mdot
.39224 .76636 Mdot
.51464 .54069 Mdot
.60467 .39136 Mdot
.42243 .35138 Mdot
.43432 .32745 Mdot
.63055 .42842 Mdot
.48424 .5669 Mdot
.51908 .70113 Mdot
.45281 .5573 Mdot
.63934 .27446 Mdot
.69207 .61538 Mdot
.35916 .48832 Mdot
.70015 .58946 Mdot
.80569 .32946 Mdot
.74338 .5304 Mdot
.56334 .43486 Mdot
.32009 .44359 Mdot
.40927 .34458 Mdot
.63649 .27769 Mdot
.35618 .46611 Mdot
.42913 .62258 Mdot
.69355 .58498 Mdot
.41614 .78715 Mdot
.47594 .69998 Mdot
.31796 .7639 Mdot
.64066 .56277 Mdot
.47365 .44335 Mdot
.60582 .40072 Mdot
.43904 .29745 Mdot
.48774 .63052 Mdot
.43635 .59684 Mdot
.61901 .6066 Mdot
.42833 .63418 Mdot
.72532 .6271 Mdot
.43136 .66372 Mdot
.4789 .37646 Mdot
.38511 .46634 Mdot
.62964 .40326 Mdot
.32551 .69228 Mdot
.71143 .58306 Mdot
.4161 .26458 Mdot
.43093 .30854 Mdot
.5665 .64439 Mdot
.60337 .43116 Mdot
.34409 .44041 Mdot
.4174 .32155 Mdot
.32694 .48749 Mdot
.5016 .63837 Mdot
.43682 .31458 Mdot
.35258 .48565 Mdot
.25052 .37806 Mdot
.43707 .67616 Mdot
.28617 .50558 Mdot
.58379 .41258 Mdot
.66049 .54371 Mdot
.43992 .64777 Mdot
.62238 .27104 Mdot
.48297 .67937 Mdot
.62981 .31591 Mdot
.64536 .25066 Mdot
.65287 .2566 Mdot
.51356 .18957 Mdot
.32532 .4542 Mdot
.72658 .38704 Mdot
.62522 .497 Mdot
.64711 .60721 Mdot
.46171 .67353 Mdot
.20813 .35323 Mdot
.60701 .41557 Mdot
.43161 .62138 Mdot
.47297 .38502 Mdot
.60445 .41788 Mdot
.46121 .60112 Mdot
.60578 .38539 Mdot
.66856 .5703 Mdot
.37875 .32307 Mdot
.62681 .57322 Mdot
.43195 .6727 Mdot
.57875 .39044 Mdot
.42027 .3298 Mdot
.66296 .58804 Mdot
.4469 .63536 Mdot
.48253 .62148 Mdot
.63523 .26969 Mdot
.45781 .65205 Mdot
.21427 .35468 Mdot
.42072 .63956 Mdot
.42081 .36197 Mdot
.48978 .58272 Mdot
.59731 .83561 Mdot
.27996 .38305 Mdot
.66592 .61039 Mdot
.64926 .25353 Mdot
.45168 .32857 Mdot
.37168 .33212 Mdot
.54772 .5341 Mdot
.45905 .63685 Mdot
.64062 .25734 Mdot
.44429 .43492 Mdot
.55976 .40323 Mdot
.50698 .59942 Mdot
.74881 .51543 Mdot
.41621 .31707 Mdot
.63664 .27543 Mdot
.39099 .67092 Mdot
.62134 .59648 Mdot
.45049 .67187 Mdot
.42756 .31668 Mdot
.65337 .54612 Mdot
.43712 .68165 Mdot
.22757 .52524 Mdot
.63132 .25498 Mdot
.58549 .41295 Mdot
.50161 .7031 Mdot
.4193 .61491 Mdot
.4289 .33227 Mdot
.6527 .55928 Mdot
.56796 .39292 Mdot
.66566 .59756 Mdot
.39782 .77483 Mdot
.75024 .36609 Mdot
.23577 .45216 Mdot
.32316 .44052 Mdot
.63969 .30764 Mdot
.17718 .46749 Mdot
.74951 .40217 Mdot
.30127 .60904 Mdot
.17623 .58286 Mdot
.41473 .33636 Mdot
.33501 .52284 Mdot
.44768 .33209 Mdot
.47791 .6568 Mdot
.46224 .34624 Mdot
.17149 .4272 Mdot
.42065 .65309 Mdot
.43594 .34335 Mdot
.343 .39623 Mdot
.43631 .6529 Mdot
.6648 .60612 Mdot
.40834 .19302 Mdot
.79617 .56873 Mdot
.73256 .54343 Mdot
.43423 .35039 Mdot
.71739 .70766 Mdot
.42459 .64664 Mdot
.39666 .65174 Mdot
.66176 .5708 Mdot
.50078 .58715 Mdot
.36869 .47761 Mdot
.32088 .48496 Mdot
.35747 .7151 Mdot
.81352 .41413 Mdot
.50112 .56927 Mdot
.66275 .58441 Mdot
.72209 .64619 Mdot
.73126 .46159 Mdot
.62709 .28874 Mdot
.55376 .41069 Mdot
.26623 .29356 Mdot
.54031 .60813 Mdot
.5884 .5194 Mdot
.746 .50421 Mdot
.68963 .58351 Mdot
.23442 .37261 Mdot
.5933 .38973 Mdot
.63972 .65612 Mdot
.5246 .76608 Mdot
.42846 .60764 Mdot
.58303 .43094 Mdot
.40113 .58242 Mdot
.77331 .56613 Mdot
.33771 .53814 Mdot
.61367 .24023 Mdot
.44423 .67725 Mdot
.72982 .40048 Mdot
.46521 .61776 Mdot
.34728 .67897 Mdot
.41771 .63712 Mdot
.65866 .59678 Mdot
.472 .555 Mdot
.47928 .4866 Mdot
.83213 .46344 Mdot
.75017 .542 Mdot
.32664 .48017 Mdot
.47912 .62086 Mdot
.43088 .60386 Mdot
.32808 .46757 Mdot
.65028 .58407 Mdot
.4162 .63313 Mdot
.25477 .61359 Mdot
.42272 .61171 Mdot
.61828 .40921 Mdot
.40551 .46929 Mdot
.70034 .5327 Mdot
.46342 .58516 Mdot
.62537 .56911 Mdot
.60015 .38549 Mdot
.56233 .38474 Mdot
.5317 .63376 Mdot
.61391 .38779 Mdot
.44564 .67167 Mdot
.40098 .44031 Mdot
.67264 .55431 Mdot
.39744 .6898 Mdot
.64624 .58192 Mdot
.7408 .66204 Mdot
.59833 .38198 Mdot
.62802 .28356 Mdot
.56517 .56985 Mdot
.58802 .39419 Mdot
.76393 .60695 Mdot
.53223 .58804 Mdot
.45641 .69091 Mdot
.7763 .59478 Mdot
.42378 .3452 Mdot
.63366 .28248 Mdot
.57813 .38723 Mdot
.42074 .61059 Mdot
.50783 .62929 Mdot
.61567 .42816 Mdot
.65238 .7033 Mdot
.37011 .35079 Mdot
.41624 .64323 Mdot
.6543 .59335 Mdot
.681 .58786 Mdot
.44793 .68396 Mdot
.44739 .62969 Mdot
.42297 .3617 Mdot
.63327 .25746 Mdot
.64904 .27615 Mdot
.62393 .27222 Mdot
.46005 .2993 Mdot
.65963 .34116 Mdot
.5954 .37772 Mdot
.6757 .39672 Mdot
.53997 .33278 Mdot
.51111 .67109 Mdot
.42583 .33378 Mdot
.45256 .59461 Mdot
.48706 .65138 Mdot
.56813 .3948 Mdot
.70646 .29568 Mdot
.37035 .61499 Mdot
.69908 .5706 Mdot
.61925 .3934 Mdot
.55108 .63693 Mdot
.53826 .37292 Mdot
.36686 .47585 Mdot
.74737 .56084 Mdot
.58953 .43253 Mdot
.68501 .59641 Mdot
.61793 .4307 Mdot
.4279 .6053 Mdot
.40657 .61416 Mdot
.68467 .56869 Mdot
.32345 .45547 Mdot
.51092 .62788 Mdot
.46297 .60188 Mdot
.70968 .78166 Mdot
.73559 .45597 Mdot
.57476 .35891 Mdot
.46742 .6539 Mdot
.48147 .68697 Mdot
.32038 .47432 Mdot
.42235 .61697 Mdot
.48828 .62732 Mdot
.78773 .48028 Mdot
.64092 .40974 Mdot
.37848 .45405 Mdot
.63874 .65365 Mdot
.63928 .56552 Mdot
.23606 .33321 Mdot
.64864 .26477 Mdot
.6331 .39492 Mdot
.37959 .32328 Mdot
.629 .2768 Mdot
.56424 .32584 Mdot
.23626 .35154 Mdot
.62593 .27837 Mdot
.3856 .32159 Mdot
.41458 .545 Mdot
.40709 .62978 Mdot
.4604 .6123 Mdot
.35665 .45773 Mdot
.6715 .56401 Mdot
.48054 .42253 Mdot
.27378 .34067 Mdot
.47133 .622 Mdot
.61642 .6168 Mdot
.26557 .32102 Mdot
.6335 .27293 Mdot
.3386 .45086 Mdot
.36797 .48442 Mdot
.46806 .61579 Mdot
.77974 .44078 Mdot
.6656 .58784 Mdot
.4473 .63515 Mdot
.44502 .58773 Mdot
.43115 .3481 Mdot
.68942 .59513 Mdot
.43336 .30813 Mdot
.64101 .25053 Mdot
.22957 .6639 Mdot
.68385 .79918 Mdot
.57104 .40705 Mdot
.1949 .43038 Mdot
.56824 .37339 Mdot
.5888 .20526 Mdot
.62549 .26573 Mdot
.45938 .63007 Mdot
.70834 .59392 Mdot
.44502 .63844 Mdot
.43247 .61258 Mdot
.42817 .62086 Mdot
.49426 .56517 Mdot
.67272 .78203 Mdot
.34665 .46975 Mdot
.50857 .66787 Mdot
.45237 .37204 Mdot
.20626 .39125 Mdot
.4002 .20974 Mdot
.46635 .59231 Mdot
.47203 .61443 Mdot
.64122 .59978 Mdot
.42798 .58529 Mdot
.5635 .41729 Mdot
.65786 .55541 Mdot
.50712 .63592 Mdot
.22984 .39163 Mdot
.41488 .62763 Mdot
.17949 .47708 Mdot
.61774 .42993 Mdot
.74562 .56084 Mdot
.51526 .65363 Mdot
.62544 .27911 Mdot
.63275 .28253 Mdot
.63345 .29276 Mdot
.57082 .42893 Mdot
.4314 .3387 Mdot
.35096 .26741 Mdot
.41813 .57876 Mdot
.45914 .66356 Mdot
.48852 .68216 Mdot
.43112 .29503 Mdot
.41872 .47977 Mdot
.70838 .3502 Mdot
.5483 .61782 Mdot
.44153 .36752 Mdot
.67091 .5426 Mdot
.77033 .31735 Mdot
.65643 .55676 Mdot
.37974 .4558 Mdot
.61288 .42072 Mdot
.36901 .46941 Mdot
.70611 .7357 Mdot
.68302 .56355 Mdot
.61803 .60513 Mdot
.43646 .34532 Mdot
.49893 .44181 Mdot
.26685 .21426 Mdot
.47183 .33258 Mdot
.28063 .63555 Mdot
.65918 .57475 Mdot
.48133 .58818 Mdot
.43443 .4347 Mdot
.49725 .44709 Mdot
.44678 .34168 Mdot
.47294 .63482 Mdot
.81258 .43501 Mdot
.4201 .35948 Mdot
.50772 .60326 Mdot
.44622 .35933 Mdot
.61275 .40154 Mdot
.45072 .35707 Mdot
.70003 .55797 Mdot
.49856 .64166 Mdot
.33662 .1537 Mdot
.54752 .45332 Mdot
.44241 .64552 Mdot
.61894 .39314 Mdot
.24527 .61697 Mdot
.44029 .60513 Mdot
.37074 .47174 Mdot
.46333 .36408 Mdot
.35722 .35429 Mdot
.4271 .64629 Mdot
.45325 .34938 Mdot
.69104 .55489 Mdot
.60005 .36314 Mdot
.5313 .18358 Mdot
.64234 .28145 Mdot
.66453 .56301 Mdot
.65365 .28404 Mdot
.58427 .44093 Mdot
.5025 .60385 Mdot
.43379 .59177 Mdot
.65461 .60033 Mdot
.51817 .22706 Mdot
.44597 .57839 Mdot
.46796 .6366 Mdot
.40539 .33224 Mdot
.40274 .30577 Mdot
.46451 .22544 Mdot
.41577 .33673 Mdot
.48882 .68304 Mdot
.65607 .60035 Mdot
.48147 .65866 Mdot
.66478 .60745 Mdot
.46161 .67318 Mdot
.71992 .60737 Mdot
.66177 .5577 Mdot
.77624 .37784 Mdot
.48355 .64314 Mdot
.4879 .70354 Mdot
.42945 .61527 Mdot
.42193 .62844 Mdot
.47032 .35942 Mdot
.33445 .47028 Mdot
.47582 .57281 Mdot
.41586 .27063 Mdot
.34529 .44642 Mdot
.4259 .77007 Mdot
.43016 .34909 Mdot
.36012 .45707 Mdot
.26823 .47862 Mdot
.6502 .25541 Mdot
.34657 .46187 Mdot
.38558 .22258 Mdot
.56943 .40347 Mdot
.65202 .55048 Mdot
.43749 .65352 Mdot
.19531 .62695 Mdot
.39854 .48072 Mdot
.63446 .26373 Mdot
.43173 .64364 Mdot
.44831 .59671 Mdot
.62612 .59923 Mdot
.82978 .36726 Mdot
.40095 .32537 Mdot
.46534 .6666 Mdot
.62762 .58639 Mdot
.84639 .50268 Mdot
.4725 .3478 Mdot
.34927 .45883 Mdot
.62113 .41716 Mdot
.66194 .53375 Mdot
.64198 .28241 Mdot
.55898 .40075 Mdot
.39462 .38682 Mdot
.7319 .70566 Mdot
.42742 .63985 Mdot
.42672 .32665 Mdot
.59807 .8235 Mdot
.46945 .56368 Mdot
.63607 .36896 Mdot
.41301 .74236 Mdot
.68845 .58688 Mdot
.61959 .42219 Mdot
.34297 .49107 Mdot
.66584 .55092 Mdot
.65176 .58565 Mdot
.57477 .37583 Mdot
.49098 .32902 Mdot
.47674 .44422 Mdot
.61783 .42011 Mdot
.77645 .52853 Mdot
.41764 .78207 Mdot
.63899 .25624 Mdot
.33284 .452 Mdot
.43665 .80681 Mdot
.67145 .59032 Mdot
.26439 .29499 Mdot
.65548 .78986 Mdot
.41442 .64557 Mdot
.36052 .47724 Mdot
.56196 .33858 Mdot
.33892 .27185 Mdot
.60104 .42004 Mdot
.43841 .48242 Mdot
.37335 .46364 Mdot
.41043 .63126 Mdot
.67596 .52065 Mdot
.47906 .64442 Mdot
.61289 .41057 Mdot
.74945 .61359 Mdot
.68235 .59962 Mdot
.5919 .44292 Mdot
.76218 .59323 Mdot
.48852 .64957 Mdot
.47899 .63866 Mdot
.33389 .63369 Mdot
.69435 .5842 Mdot
.64619 .28048 Mdot
.45347 .64051 Mdot
.45605 .60649 Mdot
.49942 .59862 Mdot
.53695 .67125 Mdot
.77043 .44936 Mdot
.46966 .66491 Mdot
.46991 .31127 Mdot
.41418 .67716 Mdot
.48207 .63755 Mdot
.62412 .58346 Mdot
.69285 .78438 Mdot
.6278 .25483 Mdot
.45729 .61303 Mdot
.41924 .6352 Mdot
.57077 .38109 Mdot
.46076 .43745 Mdot
.50306 .45226 Mdot
.45987 .31714 Mdot
.30289 .579 Mdot
.47873 .56191 Mdot
.63514 .57839 Mdot
.35532 .44 Mdot
.49421 .61097 Mdot
.63206 .58415 Mdot
.40514 .65759 Mdot
.42861 .36356 Mdot
.6352 .25768 Mdot
.65326 .50831 Mdot
.342 .45856 Mdot
.46032 .41045 Mdot
.67901 .4368 Mdot
.41872 .34895 Mdot
.4527 .66246 Mdot
.60637 .36966 Mdot
.44498 .31236 Mdot
.63621 .26744 Mdot
.39987 .68162 Mdot
.66765 .57802 Mdot
.67749 .59976 Mdot
.35301 .70516 Mdot
.39642 .33845 Mdot
.81252 .63109 Mdot
.61294 .40277 Mdot
.49608 .66247 Mdot
.64808 .45748 Mdot
.67537 .60168 Mdot
.34636 .70337 Mdot
.35856 .45521 Mdot
.59867 .42047 Mdot
.62055 .28681 Mdot
.63455 .58992 Mdot
.69409 .59549 Mdot
.44529 .67902 Mdot
.47606 .60027 Mdot
.29762 .61731 Mdot
.35356 .71328 Mdot
.60989 .39143 Mdot
.32809 .45656 Mdot
.45323 .3081 Mdot
.47701 .65323 Mdot
.66435 .55477 Mdot
.45716 .77722 Mdot
.41704 .61387 Mdot
.42032 .36019 Mdot
.68785 .58119 Mdot
.32624 .46483 Mdot
.36241 .4513 Mdot
.42203 .62803 Mdot
.62057 .77986 Mdot
.58234 .3959 Mdot
.67033 .6049 Mdot
.59712 .56385 Mdot
.46331 .57742 Mdot
.47892 .604 Mdot
.37939 .63497 Mdot
.56015 .39781 Mdot
.67759 .51681 Mdot
.36349 .43985 Mdot
.67449 .57694 Mdot
.44355 .64363 Mdot
.33983 .45548 Mdot
.60776 .5316 Mdot
.62712 .26956 Mdot
.45075 .35919 Mdot
.36886 .47885 Mdot
.34008 .48111 Mdot
.34454 .44471 Mdot
.28067 .27909 Mdot
.69249 .61393 Mdot
.71147 .64407 Mdot
.416 .63619 Mdot
.35314 .70184 Mdot
.41395 .59421 Mdot
.577 .43419 Mdot
.41979 .34106 Mdot
.43199 .60952 Mdot
.44773 .67936 Mdot
.46053 .72748 Mdot
.53578 .66564 Mdot
.60454 .59458 Mdot
.6919 .57298 Mdot
.52087 .68347 Mdot
.42598 .34429 Mdot
.85881 .41105 Mdot
.19856 .32992 Mdot
.52029 .63913 Mdot
.4802 .43278 Mdot
.66107 .55557 Mdot
.58142 .37312 Mdot
.50624 .46307 Mdot
.62471 .4157 Mdot
.67809 .57822 Mdot
.47727 .65544 Mdot
.67831 .3978 Mdot
.31594 .47247 Mdot
.42422 .60366 Mdot
.60658 .40485 Mdot
.42357 .60541 Mdot
.58404 .43486 Mdot
.68323 .63731 Mdot
.75612 .5061 Mdot
.42286 .65322 Mdot
.47414 .58108 Mdot
.47459 .71934 Mdot
.46812 .59342 Mdot
.57509 .28582 Mdot
.64961 .57406 Mdot
.812 .42148 Mdot
.44017 .68146 Mdot
.66285 .74293 Mdot
.4124 .62106 Mdot
.51962 .23967 Mdot
.48084 .59978 Mdot
.51499 .48699 Mdot
.40979 .63768 Mdot
.48414 .61749 Mdot
.58153 .38841 Mdot
.5709 .38046 Mdot
.69486 .55919 Mdot
.64238 .28416 Mdot
.17975 .42891 Mdot
.47012 .60208 Mdot
.47159 .30998 Mdot
.63505 .46769 Mdot
.33622 .47705 Mdot
.67723 .58198 Mdot
.85558 .52021 Mdot
.60226 .38458 Mdot
.46564 .38005 Mdot
.53632 .2408 Mdot
.43314 .30038 Mdot
.6295 .45435 Mdot
.55676 .62947 Mdot
.32369 .46482 Mdot
.41084 .62445 Mdot
.50059 .8064 Mdot
.72901 .42742 Mdot
.51123 .63783 Mdot
.61662 .43839 Mdot
.54518 .57971 Mdot
.44595 .8034 Mdot
.34852 .49544 Mdot
.33699 .48691 Mdot
.5856 .38693 Mdot
.40736 .32035 Mdot
.42436 .56482 Mdot
.36046 .45631 Mdot
.42874 .35948 Mdot
.64523 .28569 Mdot
.52897 .52833 Mdot
.66843 .58733 Mdot
.7206 .53253 Mdot
.69283 .46727 Mdot
.60868 .39012 Mdot
.40605 .2758 Mdot
.66569 .53765 Mdot
.62791 .60705 Mdot
.63366 .28663 Mdot
.46937 .36168 Mdot
.70624 .60129 Mdot
.50877 .61906 Mdot
.49255 .69447 Mdot
.46509 .61916 Mdot
.36117 .46671 Mdot
.47309 .59164 Mdot
.45845 .37014 Mdot
.60265 .4156 Mdot
.44911 .31916 Mdot
.57837 .39724 Mdot
.68334 .37279 Mdot
.4415 .63131 Mdot
.4797 .61439 Mdot
.40722 .43586 Mdot
.69992 .58302 Mdot
.65675 .77626 Mdot
.47473 .31299 Mdot
.44131 .33377 Mdot
.48794 .65587 Mdot
.68669 .55233 Mdot
.37836 .49189 Mdot
.40868 .42611 Mdot
.46098 .58794 Mdot
.64941 .57289 Mdot
.46217 .66577 Mdot
.25022 .4351 Mdot
.75177 .49107 Mdot
.66788 .59878 Mdot
.82747 .4218 Mdot
.47141 .64942 Mdot
.43228 .5362 Mdot
.47995 .68832 Mdot
.26198 .59198 Mdot
.47352 .57809 Mdot
.6417 .56102 Mdot
.4594 .6175 Mdot
.64826 .56293 Mdot
.4087 .33642 Mdot
.59301 .3737 Mdot
.66175 .5638 Mdot
.47119 .58716 Mdot
.28154 .26032 Mdot
.60975 .40199 Mdot
.48103 .62244 Mdot
.58284 .42645 Mdot
.63006 .57364 Mdot
.69742 .57637 Mdot
.39079 .22523 Mdot
.60902 .35961 Mdot
.60929 .39716 Mdot
.45074 .6687 Mdot
.67494 .4865 Mdot
.47959 .6592 Mdot
.29963 .62879 Mdot
.47362 .67581 Mdot
.48946 .58157 Mdot
.58027 .17033 Mdot
.58635 .36572 Mdot
.81753 .60611 Mdot
.26835 .3521 Mdot
.29804 .26308 Mdot
.68462 .53307 Mdot
.34885 .49548 Mdot
.23928 .35936 Mdot
.64334 .2508 Mdot
.4583 .36208 Mdot
.43099 .61004 Mdot
.73252 .57915 Mdot
.61958 .40869 Mdot
.33848 .47378 Mdot
.42354 .65405 Mdot
.43067 .36668 Mdot
.42395 .2217 Mdot
.61465 .38736 Mdot
.67262 .58858 Mdot
.69979 .57733 Mdot
.8391 .5039 Mdot
.4391 .64354 Mdot
.47761 .61743 Mdot
.61308 .41885 Mdot
.49337 .57145 Mdot
.33242 .44523 Mdot
.30243 .40897 Mdot
.60719 .39572 Mdot
.56897 .46642 Mdot
.68549 .56254 Mdot
.44917 .59574 Mdot
.4091 .48818 Mdot
.48812 .28196 Mdot
.56572 .6807 Mdot
.35614 .45904 Mdot
.31233 .62231 Mdot
.64135 .56147 Mdot
.60134 .40791 Mdot
.28522 .48558 Mdot
.48575 .67631 Mdot
.45109 .59838 Mdot
.31555 .62374 Mdot
.45502 .43391 Mdot
.36683 .50081 Mdot
.42735 .58462 Mdot
.44694 .4394 Mdot
.49049 .65411 Mdot
.5072 .6311 Mdot
.5255 .60917 Mdot
.4875 .61248 Mdot
.65038 .56736 Mdot
.46386 .72838 Mdot
.45609 .35367 Mdot
.62992 .68982 Mdot
.4551 .47766 Mdot
.44857 .65038 Mdot
.47991 .6541 Mdot
.57199 .64951 Mdot
.61473 .46912 Mdot
.65269 .57576 Mdot
.69218 .62014 Mdot
.59037 .38082 Mdot
.48582 .70193 Mdot
.41653 .30449 Mdot
.41965 .74006 Mdot
.45358 .32076 Mdot
.64847 .57256 Mdot
.4348 .3327 Mdot
.58453 .38061 Mdot
.42703 .32562 Mdot
.46203 .30089 Mdot
.60577 .43511 Mdot
.68455 .55928 Mdot
.46255 .589 Mdot
.60002 .38156 Mdot
.33135 .63618 Mdot
.36164 .46598 Mdot
.39082 .22483 Mdot
.4037 .66996 Mdot
.3609 .61139 Mdot
.22812 .52382 Mdot
.44426 .31998 Mdot
.76439 .48974 Mdot
.66206 .55787 Mdot
.32374 .44398 Mdot
.65044 .56463 Mdot
.68106 .7681 Mdot
.32982 .46562 Mdot
.38307 .22422 Mdot
.29645 .44973 Mdot
.3664 .29016 Mdot
.41677 .59559 Mdot
.69905 .62655 Mdot
.43903 .31051 Mdot
.61909 .40531 Mdot
.47464 .39199 Mdot
.49276 .62628 Mdot
.74754 .39397 Mdot
.66502 .6168 Mdot
.65215 .26682 Mdot
.59527 .40894 Mdot
.61849 .43954 Mdot
.43586 .64068 Mdot
.37668 .30609 Mdot
.49463 .65718 Mdot
.31676 .50791 Mdot
.3066 .60213 Mdot
.41991 .7412 Mdot
.44749 .67296 Mdot
.45592 .31809 Mdot
.4599 .66627 Mdot
.50401 .55462 Mdot
.51135 .82622 Mdot
.41302 .68216 Mdot
.75891 .3664 Mdot
.3878 .41369 Mdot
.682 .56586 Mdot
.51949 .64827 Mdot
.64268 .26371 Mdot
.46951 .65192 Mdot
.30218 .78905 Mdot
.34376 .46334 Mdot
.40543 .37217 Mdot
.42901 .58703 Mdot
.44872 .64009 Mdot
.5419 .80269 Mdot
.73266 .6015 Mdot
.61869 .28345 Mdot
.4503 .60195 Mdot
.31524 .57151 Mdot
.56267 .4021 Mdot
.47964 .67661 Mdot
.4628 .61408 Mdot
.38471 .76724 Mdot
.56646 .4149 Mdot
.43878 .32121 Mdot
.64719 .25131 Mdot
.45559 .30815 Mdot
.36898 .48895 Mdot
.52078 .46618 Mdot
.35348 .71927 Mdot
.74845 .48892 Mdot
.37149 .4637 Mdot
.43495 .58837 Mdot
.38216 .56465 Mdot
.46537 .64259 Mdot
.33807 .48844 Mdot
.56892 .42148 Mdot
.6545 .56702 Mdot
.65062 .50492 Mdot
.6385 .27336 Mdot
.50709 .60343 Mdot
.33926 .49277 Mdot
.66566 .57117 Mdot
.4646 .24649 Mdot
.67646 .56944 Mdot
.59194 .39338 Mdot
.57558 .43509 Mdot
.33336 .46215 Mdot
.64911 .5662 Mdot
.47198 .31853 Mdot
.27145 .34868 Mdot
.47272 .674 Mdot
.55089 .36727 Mdot
.70797 .57138 Mdot
.62987 .5563 Mdot
.68472 .61164 Mdot
.43431 .63445 Mdot
.4701 .43601 Mdot
.50271 .66182 Mdot
.59097 .38505 Mdot
.44346 .36244 Mdot
.36202 .73003 Mdot
.54738 .8096 Mdot
.5598 .46192 Mdot
.47842 .57418 Mdot
.48554 .63047 Mdot
.46819 .61597 Mdot
.41851 .65876 Mdot
.26687 .43019 Mdot
.44463 .62969 Mdot
.57922 .392 Mdot
.46726 .3379 Mdot
.43509 .64574 Mdot
.6445 .26241 Mdot
.46815 .45233 Mdot
.36048 .44317 Mdot
.49659 .47648 Mdot
.23572 .30297 Mdot
.66431 .57099 Mdot
.41943 .32219 Mdot
.46051 .35941 Mdot
.35072 .4426 Mdot
.61443 .39694 Mdot
.67311 .56648 Mdot
.25663 .5658 Mdot
.33631 .44704 Mdot
.45623 .61339 Mdot
.38918 .39608 Mdot
.80673 .37709 Mdot
.41735 .60068 Mdot
.43808 .61431 Mdot
.65126 .25383 Mdot
.41023 .31301 Mdot
.19704 .65633 Mdot
.45038 .42447 Mdot
.33393 .46728 Mdot
.33783 .48385 Mdot
.68431 .61289 Mdot
.5146 .63225 Mdot
.57989 .40223 Mdot
.42372 .43705 Mdot
.26561 .65239 Mdot
.50214 .36886 Mdot
.57976 .20325 Mdot
.41761 .62393 Mdot
.54498 .79295 Mdot
.46825 .66987 Mdot
.62501 .59969 Mdot
.65653 .60997 Mdot
.65697 .58019 Mdot
.5886 .38867 Mdot
.73598 .6674 Mdot
.5764 .39389 Mdot
.22427 .30895 Mdot
.65475 .55319 Mdot
.31248 .34069 Mdot
.43543 .33813 Mdot
.4324 .57394 Mdot
.32472 .45983 Mdot
.57278 .4607 Mdot
.52614 .60511 Mdot
.77179 .43573 Mdot
.42609 .33319 Mdot
.69461 .56944 Mdot
.53738 .58776 Mdot
.15663 .48253 Mdot
.51077 .44381 Mdot
.44892 .52321 Mdot
.64148 .78612 Mdot
.32822 .46596 Mdot
.57455 .66543 Mdot
.32454 .45053 Mdot
.608 .41649 Mdot
.49243 .62343 Mdot
.48988 .61284 Mdot
.45422 .67411 Mdot
.44214 .6292 Mdot
.56907 .39119 Mdot
.42207 .66994 Mdot
.59753 .83545 Mdot
.64266 .25394 Mdot
.24724 .39957 Mdot
.36687 .46512 Mdot
.61291 .43608 Mdot
.46253 .32946 Mdot
.64441 .28427 Mdot
.3316 .70323 Mdot
.41272 .6418 Mdot
.43056 .61283 Mdot
.62399 .28373 Mdot
.519 .597 Mdot
.54052 .60009 Mdot
.45738 .35181 Mdot
.56227 .47027 Mdot
.35852 .49032 Mdot
.36886 .4706 Mdot
.60069 .43383 Mdot
.6498 .56487 Mdot
.35641 .45566 Mdot
.40436 .32654 Mdot
.41679 .66787 Mdot
.49426 .59899 Mdot
.7077 .57125 Mdot
.65581 .78979 Mdot
.33986 .49553 Mdot
.51813 .57229 Mdot
.64403 .56314 Mdot
.67698 .61764 Mdot
.44772 .60108 Mdot
.39219 .66594 Mdot
.64415 .54737 Mdot
.36638 .45503 Mdot
.61487 .43553 Mdot
.34825 .30111 Mdot
.61101 .4114 Mdot
.66939 .56675 Mdot
.42687 .68015 Mdot
.68495 .56049 Mdot
.46473 .65094 Mdot
.69469 .19414 Mdot
.48537 .6058 Mdot
.7892 .57743 Mdot
.26967 .60127 Mdot
.46404 .35694 Mdot
.46907 .31522 Mdot
.64169 .25824 Mdot
.64429 .56118 Mdot
.49558 .6144 Mdot
.33037 .47863 Mdot
.31875 .25233 Mdot
.72187 .58683 Mdot
.44079 .3659 Mdot
.41602 .30621 Mdot
.56234 .41163 Mdot
.41555 .61072 Mdot
.45715 .59475 Mdot
.4286 .32408 Mdot
.2354 .50127 Mdot
.63612 .5832 Mdot
.47734 .61833 Mdot
.48485 .6339 Mdot
.46243 .35274 Mdot
.26947 .35528 Mdot
.7009 .63007 Mdot
.48791 .61648 Mdot
.31347 .43238 Mdot
.57494 .43231 Mdot
.42312 .66183 Mdot
.42122 .66837 Mdot
.34879 .48227 Mdot
.22844 .41519 Mdot
.46439 .81333 Mdot
.59786 .43835 Mdot
.6469 .27897 Mdot
.47067 .58594 Mdot
.43707 .33939 Mdot
.48348 .58965 Mdot
.19054 .51717 Mdot
.64828 .25632 Mdot
.45391 .62983 Mdot
.52306 .63095 Mdot
.68094 .6052 Mdot
.45016 .63315 Mdot
.44574 .75709 Mdot
.4648 .31796 Mdot
.45149 .63066 Mdot
.63628 .7768 Mdot
.56129 .4024 Mdot
.52251 .63797 Mdot
.35454 .48861 Mdot
.25908 .59343 Mdot
.68285 .45007 Mdot
.44081 .29227 Mdot
.36495 .45784 Mdot
.46515 .58828 Mdot
.40863 .32087 Mdot
.62066 .40494 Mdot
.7552 .41207 Mdot
.40553 .63708 Mdot
.61204 .40752 Mdot
.60168 .41444 Mdot
.33715 .46154 Mdot
.82528 .57187 Mdot
.51208 .58528 Mdot
.46811 .59228 Mdot
.33645 .74808 Mdot
.66233 .61494 Mdot
.46318 .59013 Mdot
.42264 .59938 Mdot
.57983 .4098 Mdot
.5661 .56729 Mdot
.61472 .63157 Mdot
.342 .39686 Mdot
.58347 .43499 Mdot
.44679 .28752 Mdot
.40912 .32113 Mdot
.36615 .46419 Mdot
.6843 .57136 Mdot
.37162 .45487 Mdot
.44084 .3521 Mdot
.41796 .63455 Mdot
.5875 .41932 Mdot
.54847 .72057 Mdot
.59889 .37063 Mdot
.43479 .37172 Mdot
.61981 .57846 Mdot
.65425 .44729 Mdot
.42791 .83353 Mdot
.6989 .45561 Mdot
.63567 .41995 Mdot
.33704 .4777 Mdot
.40048 .40892 Mdot
.48465 .63176 Mdot
.60342 .64981 Mdot
.43617 .59338 Mdot
.63442 .78816 Mdot
.42105 .34689 Mdot
.63196 .2874 Mdot
.49269 .62302 Mdot
.31319 .60742 Mdot
.62938 .42851 Mdot
.56066 .40839 Mdot
.43873 .62227 Mdot
.58881 .3933 Mdot
.47237 .59898 Mdot
.46994 .34241 Mdot
.80968 .59669 Mdot
.48386 .62654 Mdot
.45178 .6958 Mdot
.6397 .39115 Mdot
.38928 .22452 Mdot
.48178 .33733 Mdot
.54298 .79545 Mdot
.15116 .51687 Mdot
.58757 .39529 Mdot
.49105 .6833 Mdot
.43304 .31449 Mdot
.65185 .25419 Mdot
.47874 .36245 Mdot
.42954 .60031 Mdot
.42219 .62229 Mdot
.48665 .65768 Mdot
.47903 .63948 Mdot
.59759 .64654 Mdot
.54584 .63696 Mdot
.55734 .77439 Mdot
.4316 .61381 Mdot
.63391 .52802 Mdot
.5743 .39159 Mdot
.60551 .5947 Mdot
.30892 .47299 Mdot
.41812 .62859 Mdot
.73657 .58902 Mdot
.60565 .43712 Mdot
.22307 .31367 Mdot
.56415 .41333 Mdot
.4535 .32874 Mdot
.5783 .37105 Mdot
.45941 .65143 Mdot
.68067 .58932 Mdot
.46913 .32726 Mdot
.70167 .35439 Mdot
.45688 .36352 Mdot
.44162 .64542 Mdot
.26812 .37863 Mdot
.45896 .35885 Mdot
.47542 .4595 Mdot
.68381 .58548 Mdot
.32154 .56873 Mdot
.64102 .60415 Mdot
.45669 .63282 Mdot
.46164 .63414 Mdot
.65077 .27949 Mdot
.61152 .38255 Mdot
.63295 .5684 Mdot
.71856 .77459 Mdot
.37701 .47153 Mdot
.65863 .5873 Mdot
.40311 .59385 Mdot
.46642 .43159 Mdot
.66601 .6029 Mdot
.28432 .56275 Mdot
.61643 .39871 Mdot
.70003 .60577 Mdot
.3909 .61161 Mdot
.58046 .52318 Mdot
.31605 .46031 Mdot
.43963 .37134 Mdot
.56562 .50041 Mdot
.44114 .30936 Mdot
.59735 .44046 Mdot
.4006 .34195 Mdot
.56374 .40082 Mdot
.76214 .60941 Mdot
.72554 .62884 Mdot
.61316 .37655 Mdot
.58244 .43952 Mdot
.44304 .347 Mdot
.4159 .64988 Mdot
.46245 .49024 Mdot
.45078 .57538 Mdot
.40824 .60814 Mdot
.56217 .39512 Mdot
.63162 .57579 Mdot
.65976 .54763 Mdot
.66693 .63185 Mdot
.69852 .58458 Mdot
.46279 .32737 Mdot
.76545 .50106 Mdot
.69757 .74401 Mdot
.5999 .43133 Mdot
.5484 .40602 Mdot
.47986 .65804 Mdot
.43876 .34226 Mdot
.41178 .34044 Mdot
.5857 .41151 Mdot
.58359 .68284 Mdot
.47626 .68862 Mdot
.62551 .59343 Mdot
.65658 .55286 Mdot
.66093 .60063 Mdot
.69467 .60393 Mdot
.70208 .66707 Mdot
.61922 .40457 Mdot
.649 .55685 Mdot
.4452 .62442 Mdot
.42278 .61494 Mdot
.64052 .27965 Mdot
.36411 .4811 Mdot
.39891 .64876 Mdot
.42198 .68707 Mdot
.4466 .60008 Mdot
.45231 .35948 Mdot
.38262 .6693 Mdot
.64976 .26436 Mdot
.39917 .33097 Mdot
.43098 .29629 Mdot
.62875 .28353 Mdot
.58669 .58894 Mdot
.14843 .49 Mdot
.46545 .66644 Mdot
.40197 .52848 Mdot
.44214 .33876 Mdot
.79608 .50912 Mdot
.63273 .52261 Mdot
.44325 .67221 Mdot
.54615 .52646 Mdot
.47115 .33496 Mdot
.65827 .61601 Mdot
.44904 .59068 Mdot
.62469 .26589 Mdot
.35671 .44133 Mdot
.40454 .59079 Mdot
.64949 .25128 Mdot
.64639 .5731 Mdot
.36595 .51583 Mdot
.69319 .61158 Mdot
.4741 .34488 Mdot
.52448 .63258 Mdot
.27487 .20486 Mdot
.42914 .31006 Mdot
.31765 .26669 Mdot
.7142 .63229 Mdot
.48561 .62478 Mdot
.4343 .30818 Mdot
.64671 .6129 Mdot
.57011 .4295 Mdot
.43916 .44619 Mdot
.66787 .55596 Mdot
.6412 .28588 Mdot
.63449 .28071 Mdot
.45884 .35324 Mdot
.69174 .57944 Mdot
.46225 .68256 Mdot
.66656 .6091 Mdot
.57795 .37014 Mdot
.43426 .66209 Mdot
.17377 .43694 Mdot
.50275 .68861 Mdot
.63897 .56791 Mdot
.41682 .35824 Mdot
.31853 .46953 Mdot
.42214 .65023 Mdot
.27932 .3066 Mdot
.41881 .60394 Mdot
.57594 .42387 Mdot
.80648 .45753 Mdot
.5341 .72473 Mdot
.41729 .63863 Mdot
.48101 .6558 Mdot
.60945 .43359 Mdot
.41528 .64487 Mdot
.41731 .60237 Mdot
.63201 .36702 Mdot
.68134 .6032 Mdot
.4661 .62167 Mdot
.42028 .3538 Mdot
.53761 .81841 Mdot
.47038 .58527 Mdot
.74495 .34474 Mdot
.31993 .58358 Mdot
.80792 .48119 Mdot
.48263 .59221 Mdot
.33358 .65141 Mdot
.46828 .6323 Mdot
.42752 .6359 Mdot
.45685 .67028 Mdot
.53045 .78689 Mdot
.43972 .34788 Mdot
.44862 .36969 Mdot
.31578 .45821 Mdot
.31746 .58287 Mdot
.35878 .47802 Mdot
.59159 .43476 Mdot
.51278 .19246 Mdot
.64504 .25486 Mdot
.64971 .56388 Mdot
.50006 .64157 Mdot
.47568 .34591 Mdot
.44381 .596 Mdot
.46284 .65362 Mdot
.4721 .34246 Mdot
.41956 .31275 Mdot
.40017 .35631 Mdot
.32615 .45059 Mdot
.65712 .5718 Mdot
.43876 .677 Mdot
.34487 .44663 Mdot
.46663 .68265 Mdot
.45245 .42837 Mdot
.65524 .57377 Mdot
.66903 .60914 Mdot
.63172 .56452 Mdot
.4171 .63322 Mdot
.45216 .65209 Mdot
.57552 .39505 Mdot
.70729 .56762 Mdot
.61022 .42902 Mdot
.44509 .31144 Mdot
.47476 .328 Mdot
.42898 .60103 Mdot
.52302 .5741 Mdot
.33669 .48215 Mdot
.4496 .32502 Mdot
.62234 .28264 Mdot
.31902 .4521 Mdot
.43128 .64303 Mdot
.45292 .31663 Mdot
.36925 .47298 Mdot
.59942 .69696 Mdot
.16253 .55025 Mdot
.32063 .47709 Mdot
.44088 .62186 Mdot
.54925 .80457 Mdot
.3063 .51312 Mdot
.37702 .46006 Mdot
.59501 .42896 Mdot
.41867 .60652 Mdot
.22685 .59833 Mdot
.37316 .47338 Mdot
.63671 .79494 Mdot
.46579 .35423 Mdot
.55572 .56172 Mdot
.38828 .62082 Mdot
.62274 .66042 Mdot
.37366 .45734 Mdot
.67366 .57137 Mdot
.70671 .56108 Mdot
.44902 .6171 Mdot
.30666 .44858 Mdot
.55949 .38661 Mdot
.46803 .35562 Mdot
.47147 .31124 Mdot
.69128 .58675 Mdot
.7081 .49701 Mdot
.41888 .35591 Mdot
.45847 .55483 Mdot
.38174 .34318 Mdot
.4446 .70909 Mdot
.75864 .62476 Mdot
.69298 .35487 Mdot
.49809 .60429 Mdot
.32445 .47993 Mdot
.62369 .42337 Mdot
.58008 .39351 Mdot
.5975 .39265 Mdot
.4614 .3075 Mdot
.50468 .46579 Mdot
.4236 .3331 Mdot
.74301 .40258 Mdot
.34041 .45513 Mdot
.31439 .54895 Mdot
.49346 .61249 Mdot
.48463 .62874 Mdot
.45903 .68551 Mdot
.49519 .65259 Mdot
.46988 .6309 Mdot
.61026 .3936 Mdot
.44734 .30057 Mdot
.35605 .35982 Mdot
.65265 .59389 Mdot
.48251 .23577 Mdot
.43515 .33787 Mdot
.64991 .25374 Mdot
.3455 .47197 Mdot
.34518 .67384 Mdot
.40273 .30238 Mdot
.43594 .33261 Mdot
.40863 .65791 Mdot
.63801 .59832 Mdot
.5518 .65076 Mdot
.46846 .63645 Mdot
.44768 .3231 Mdot
.4953 .36276 Mdot
.55215 .68531 Mdot
.37691 .60755 Mdot
.38456 .47723 Mdot
.4712 .43242 Mdot
.35827 .43696 Mdot
.39467 .66534 Mdot
.79613 .50551 Mdot
.44235 .3518 Mdot
.45817 .33632 Mdot
.34133 .49239 Mdot
.43188 .53827 Mdot
.6889 .57746 Mdot
.63108 .28771 Mdot
.57945 .42272 Mdot
.46439 .64029 Mdot
.46077 .3097 Mdot
.46476 .53302 Mdot
.37711 .35727 Mdot
.60541 .39596 Mdot
.39921 .32964 Mdot
.41314 .62135 Mdot
.43906 .6201 Mdot
.32918 .46897 Mdot
.41655 .51022 Mdot
.41556 .58413 Mdot
.29705 .26379 Mdot
.75288 .5047 Mdot
.74802 .52932 Mdot
.45151 .59821 Mdot
.69142 .59173 Mdot
.62526 .26891 Mdot
.33213 .45201 Mdot
.43279 .6792 Mdot
.15398 .53562 Mdot
.67438 .54158 Mdot
.60612 .40777 Mdot
.62466 .27408 Mdot
.50257 .46529 Mdot
.42051 .6011 Mdot
.43705 .59307 Mdot
.43806 .63187 Mdot
.15386 .5622 Mdot
.43512 .36449 Mdot
.6879 .60908 Mdot
.35719 .46139 Mdot
.69531 .59967 Mdot
.45198 .36789 Mdot
.64962 .49939 Mdot
.43239 .64718 Mdot
.62324 .59016 Mdot
.67579 .57311 Mdot
.56238 .41239 Mdot
.55843 .41276 Mdot
.3946 .34609 Mdot
.48497 .60631 Mdot
.6265 .25973 Mdot
.64855 .60753 Mdot
.42305 .30574 Mdot
.32924 .4653 Mdot
.59454 .38151 Mdot
.431 .61546 Mdot
.44999 .35338 Mdot
.51173 .61935 Mdot
.65807 .60442 Mdot
.43629 .33339 Mdot
.63371 .25023 Mdot
.34494 .48643 Mdot
.42534 .61977 Mdot
.36949 .50524 Mdot
.62607 .28369 Mdot
.48652 .63703 Mdot
.38942 .73672 Mdot
.30559 .47785 Mdot
.7035 .35083 Mdot
.42046 .32742 Mdot
.64505 .26929 Mdot
.66448 .61159 Mdot
.59618 .52843 Mdot
.46057 .33588 Mdot
.37779 .71326 Mdot
.4517 .50256 Mdot
.43494 .67514 Mdot
.67025 .5943 Mdot
.36712 .41099 Mdot
.25154 .30139 Mdot
.28155 .49182 Mdot
.47457 .61961 Mdot
.43624 .30796 Mdot
.3692 .46456 Mdot
.59518 .43177 Mdot
.74729 .34661 Mdot
.73343 .63923 Mdot
.39729 .33359 Mdot
.46657 .66754 Mdot
.64766 .60684 Mdot
.58783 .4122 Mdot
.67759 .38414 Mdot
.40373 .33198 Mdot
.41809 .34235 Mdot
.42644 .64349 Mdot
.35181 .45264 Mdot
.24586 .47592 Mdot
.45047 .37074 Mdot
.45325 .30599 Mdot
.47369 .23355 Mdot
.33173 .49063 Mdot
.44959 .62199 Mdot
.66832 .6319 Mdot
.40872 .64851 Mdot
.32045 .25881 Mdot
.64792 .26365 Mdot
.65032 .59325 Mdot
.42211 .60995 Mdot
.3782 .38886 Mdot
.45834 .32672 Mdot
.48157 .43387 Mdot
.42211 .36652 Mdot
.61225 .39417 Mdot
.4631 .31164 Mdot
.45018 .59193 Mdot
.62893 .42995 Mdot
.33973 .48334 Mdot
.48775 .61517 Mdot
.45198 .65306 Mdot
.63755 .61001 Mdot
.6075 .41875 Mdot
.44225 .79324 Mdot
.57105 .43581 Mdot
.61725 .43089 Mdot
.71178 .59958 Mdot
.45253 .61527 Mdot
.44873 .32918 Mdot
.44683 .37445 Mdot
.44266 .6808 Mdot
.79273 .51966 Mdot
.68971 .58309 Mdot
.39064 .33603 Mdot
.19588 .65051 Mdot
.41698 .56586 Mdot
.62413 .2598 Mdot
.38048 .55971 Mdot
.56082 .41404 Mdot
.43403 .61901 Mdot
.63923 .5705 Mdot
.44315 .30319 Mdot
.41929 .35583 Mdot
.43708 .68254 Mdot
.59685 .41669 Mdot
.3663 .44932 Mdot
.41433 .33732 Mdot
.37648 .33489 Mdot
.44462 .63437 Mdot
.74759 .39003 Mdot
.41526 .32946 Mdot
.35119 .21612 Mdot
.36521 .36648 Mdot
.66577 .59723 Mdot
.4617 .65572 Mdot
.69748 .56522 Mdot
.35805 .46709 Mdot
.46701 .29621 Mdot
.60086 .41696 Mdot
.37952 .58807 Mdot
.49151 .83471 Mdot
.43629 .34571 Mdot
.65029 .56854 Mdot
.41611 .63713 Mdot
.40611 .56501 Mdot
.47427 .59331 Mdot
.57016 .56983 Mdot
.32363 .49907 Mdot
.56151 .39432 Mdot
.5791 .42675 Mdot
.487 .65054 Mdot
.33434 .44557 Mdot
.46732 .36764 Mdot
.46796 .35138 Mdot
.85499 .38328 Mdot
.63455 .24952 Mdot
.29071 .61859 Mdot
.42355 .6236 Mdot
.42469 .30333 Mdot
.54038 .81023 Mdot
.61324 .41891 Mdot
.49167 .66138 Mdot
.44351 .29574 Mdot
.49787 .29227 Mdot
.45224 .43055 Mdot
.4614 .62712 Mdot
.478 .56258 Mdot
.58021 .42465 Mdot
.41702 .42792 Mdot
.42486 .33074 Mdot
.48174 .67138 Mdot
.57889 .43965 Mdot
.44881 .232 Mdot
.56682 .84131 Mdot
.6571 .57236 Mdot
.43314 .37181 Mdot
.6119 .39483 Mdot
.42797 .57268 Mdot
.36714 .46475 Mdot
.45598 .31249 Mdot
.45223 .36231 Mdot
.4428 .663 Mdot
.3977 .63586 Mdot
.41484 .56633 Mdot
.64951 .58289 Mdot
.5714 .40277 Mdot
.49577 .63064 Mdot
.71618 .49914 Mdot
.48727 .65826 Mdot
.57367 .40316 Mdot
.4559 .10145 Mdot
.40477 .64034 Mdot
.47369 .59435 Mdot
.25566 .47571 Mdot
.67419 .55419 Mdot
.69645 .59525 Mdot
.75953 .50495 Mdot
.4237 .62326 Mdot
.36988 .29731 Mdot
.65884 .56917 Mdot
.68804 .58682 Mdot
.30121 .35435 Mdot
.43407 .66474 Mdot
.42634 .41942 Mdot
.57962 .40412 Mdot
.60778 .38617 Mdot
.67388 .60666 Mdot
.42378 .57655 Mdot
.62157 .41876 Mdot
.62382 .64507 Mdot
.43183 .33897 Mdot
.79657 .50387 Mdot
.6441 .59938 Mdot
.41297 .50148 Mdot
.61402 .40931 Mdot
.22671 .29956 Mdot
.55992 .51884 Mdot
.47731 .66608 Mdot
.42881 .62504 Mdot
.34963 .48361 Mdot
.53456 .62411 Mdot
.64875 .27694 Mdot
.58975 .39241 Mdot
.22058 .45357 Mdot
.65745 .58128 Mdot
.48128 .60255 Mdot
.3487 .68552 Mdot
.68877 .40239 Mdot
.7647 .37415 Mdot
.68122 .56618 Mdot
.66813 .59039 Mdot
.425 .34266 Mdot
.43524 .35547 Mdot
.45736 .62142 Mdot
.58431 .38889 Mdot
.71158 .58456 Mdot
.57445 .41484 Mdot
.44202 .35274 Mdot
.44087 .33223 Mdot
.64935 .25737 Mdot
.50933 .59646 Mdot
.47216 .34702 Mdot
.43315 .23403 Mdot
.70638 .50009 Mdot
.64152 .61375 Mdot
.41347 .82172 Mdot
.67538 .37952 Mdot
.23667 .53485 Mdot
.34387 .43837 Mdot
.615 .27995 Mdot
.57846 .37651 Mdot
.48302 .65333 Mdot
.43334 .60494 Mdot
.63307 .2728 Mdot
.60349 .37682 Mdot
.34378 .47595 Mdot
.61042 .38116 Mdot
.3424 .45176 Mdot
.47985 .34234 Mdot
.47075 .58552 Mdot
.4303 .59225 Mdot
.60733 .39232 Mdot
.43574 .32235 Mdot
.47065 .35146 Mdot
.3305 .44366 Mdot
.3426 .63665 Mdot
.45705 .35397 Mdot
.64617 .60079 Mdot
.69036 .71291 Mdot
.63391 .27962 Mdot
.45351 .59036 Mdot
.35018 .70331 Mdot
.57863 .66952 Mdot
.45068 .67767 Mdot
.62458 .27672 Mdot
.86198 .4245 Mdot
.49018 .60893 Mdot
.85296 .46195 Mdot
.64536 .2725 Mdot
.6776 .55403 Mdot
.42585 .31507 Mdot
.64901 .27797 Mdot
.40313 .58644 Mdot
.38106 .45848 Mdot
.40096 .66258 Mdot
.67076 .55606 Mdot
.62625 .56961 Mdot
.77193 .5734 Mdot
.32121 .25948 Mdot
.32129 .46002 Mdot
.33792 .46896 Mdot
.46209 .33936 Mdot
.5567 .1709 Mdot
.39027 .6195 Mdot
.33633 .47085 Mdot
.22422 .47601 Mdot
.47625 .65936 Mdot
.30317 .63713 Mdot
.54388 .52349 Mdot
.69106 .59094 Mdot
.59467 .5914 Mdot
.46103 .33233 Mdot
.6509 .56867 Mdot
.70567 .51093 Mdot
.45571 .68551 Mdot
.65525 .57647 Mdot
.57566 .40734 Mdot
.57961 .32361 Mdot
.69677 .5689 Mdot
.42375 .44743 Mdot
.5808 .40229 Mdot
.30525 .48235 Mdot
.26061 .50632 Mdot
.30603 .80257 Mdot
.58905 .39131 Mdot
.43925 .31552 Mdot
.47367 .34399 Mdot
.46658 .34935 Mdot
.66713 .5554 Mdot
.40757 .33371 Mdot
.64513 .58532 Mdot
.28521 .32027 Mdot
.33859 .67015 Mdot
.33345 .46026 Mdot
.59662 .35709 Mdot
.67384 .58229 Mdot
.752 .45155 Mdot
.43551 .83136 Mdot
.43891 .62355 Mdot
.57517 .43787 Mdot
.3423 .49208 Mdot
.49087 .15354 Mdot
.3502 .48222 Mdot
.43184 .31488 Mdot
.79761 .49948 Mdot
.47413 .60131 Mdot
.43427 .75479 Mdot
.33605 .4843 Mdot
.67715 .56175 Mdot
.48641 .63431 Mdot
.4246 .37312 Mdot
.36469 .46253 Mdot
.35954 .44351 Mdot
.47397 .62859 Mdot
.69533 .5749 Mdot
.44382 .32962 Mdot
.57991 .37799 Mdot
.33876 .49948 Mdot
.46326 .56604 Mdot
.41934 .66112 Mdot
.50255 .65745 Mdot
.5007 .44569 Mdot
.21805 .54573 Mdot
.58679 .3965 Mdot
.34846 .53979 Mdot
.4422 .35759 Mdot
.28812 .45846 Mdot
.72848 .46346 Mdot
.61674 .36481 Mdot
.64801 .26507 Mdot
.64746 .25975 Mdot
.46517 .62793 Mdot
.21706 .53596 Mdot
.8032 .4067 Mdot
.64384 .41663 Mdot
.6299 .27813 Mdot
.4692 .35337 Mdot
.69723 .55192 Mdot
.76414 .57697 Mdot
.39938 .62181 Mdot
.55813 .40304 Mdot
.45323 .35576 Mdot
.19019 .52215 Mdot
.34342 .45688 Mdot
.77814 .49218 Mdot
.4377 .64695 Mdot
.47888 .61429 Mdot
.59153 .40559 Mdot
.57635 .39497 Mdot
.7437 .35984 Mdot
.76181 .53535 Mdot
.50799 .35479 Mdot
.63327 .35052 Mdot
.19092 .5501 Mdot
.60902 .6019 Mdot
.63671 .57262 Mdot
.6442 .2502 Mdot
.62516 .4271 Mdot
.44397 .59023 Mdot
.67032 .55015 Mdot
.76734 .37684 Mdot
.70449 .54759 Mdot
.30507 .62405 Mdot
.37158 .30724 Mdot
.45559 .64662 Mdot
.64326 .60268 Mdot
.65209 .57014 Mdot
.70137 .59562 Mdot
.62769 .28212 Mdot
.45187 .60062 Mdot
.41601 .64896 Mdot
.49233 .6285 Mdot
.52353 .58824 Mdot
.44811 .63399 Mdot
.72124 .47067 Mdot
.56276 .46259 Mdot
.22254 .4359 Mdot
.45703 .67642 Mdot
.61482 .39183 Mdot
.50254 .63823 Mdot
.33917 .44368 Mdot
.46712 .6679 Mdot
.29653 .62739 Mdot
.60054 .39907 Mdot
.42522 .54035 Mdot
.64012 .3566 Mdot
.43821 .64794 Mdot
.37152 .46587 Mdot
.22227 .53076 Mdot
.43659 .80066 Mdot
.47042 .23681 Mdot
.6486 .60213 Mdot
.40086 .30891 Mdot
.57743 .36932 Mdot
.45027 .33115 Mdot
.47608 .67 Mdot
.63099 .25438 Mdot
.64317 .32524 Mdot
.42066 .49412 Mdot
.42833 .59709 Mdot
.45839 .70321 Mdot
.67795 .60045 Mdot
.44863 .31549 Mdot
.62027 .55265 Mdot
.43118 .63408 Mdot
.35926 .46137 Mdot
.35588 .45213 Mdot
.75035 .5215 Mdot
.18664 .45817 Mdot
.59477 .54198 Mdot
.58967 .40351 Mdot
.4226 .36129 Mdot
.37393 .46018 Mdot
.72646 .63298 Mdot
.55784 .38949 Mdot
.56063 .41327 Mdot
.6015 .42184 Mdot
.46241 .64418 Mdot
.65011 .26948 Mdot
.20816 .47563 Mdot
.64345 .28439 Mdot
.44204 .64982 Mdot
.44361 .36389 Mdot
.65118 .27542 Mdot
.35586 .4823 Mdot
.59608 .43374 Mdot
.43509 .35232 Mdot
.45722 .63455 Mdot
.66286 .57296 Mdot
.34961 .60727 Mdot
.26422 .62819 Mdot
.26002 .3551 Mdot
.25634 .36369 Mdot
.64048 .55685 Mdot
.20679 .3597 Mdot
.55141 .36711 Mdot
.58396 .6807 Mdot
.385 .44328 Mdot
.44908 .68197 Mdot
.79041 .64031 Mdot
.42479 .32809 Mdot
.46692 .32883 Mdot
.45738 .62697 Mdot
.42361 .30801 Mdot
.47974 .59912 Mdot
.42512 .34927 Mdot
.4312 .25102 Mdot
.40708 .60383 Mdot
.46603 .32966 Mdot
.38686 .64206 Mdot
.42546 .6521 Mdot
.68642 .59823 Mdot
.45131 .30864 Mdot
.48525 .66192 Mdot
.56213 .16081 Mdot
.58244 .38543 Mdot
.62945 .28281 Mdot
.524 .42007 Mdot
.61706 .40161 Mdot
.65832 .59072 Mdot
.42023 .58927 Mdot
.33025 .47463 Mdot
.67115 .57251 Mdot
.39545 .34847 Mdot
.33559 .48544 Mdot
.76309 .49931 Mdot
.65593 .60515 Mdot
.63612 .27786 Mdot
.33513 .48206 Mdot
.47589 .69585 Mdot
.47123 .3261 Mdot
.27237 .666 Mdot
.64054 .28498 Mdot
.45729 .5943 Mdot
.48351 .34015 Mdot
.6158 .39016 Mdot
.46513 .61446 Mdot
.43268 .30768 Mdot
.62624 .28183 Mdot
.46956 .64753 Mdot
.48305 .64163 Mdot
.75519 .57458 Mdot
.78714 .41924 Mdot
.33028 .46927 Mdot
.64807 .61052 Mdot
.44615 .62501 Mdot
.32845 .44779 Mdot
.55622 .21716 Mdot
.50406 .62125 Mdot
.69103 .55726 Mdot
.41821 .73626 Mdot
.43684 .35762 Mdot
.60923 .43001 Mdot
.44025 .37472 Mdot
.35516 .44022 Mdot
.75504 .74622 Mdot
.6523 .26332 Mdot
.38354 .62943 Mdot
.47857 .67801 Mdot
.49279 .35645 Mdot
.651 .57436 Mdot
.50578 .37819 Mdot
.4255 .62042 Mdot
.50071 .6918 Mdot
.48072 .60963 Mdot
.36293 .36058 Mdot
.6891 .58112 Mdot
.46764 .59264 Mdot
.54279 .59168 Mdot
.46444 .58249 Mdot
.37034 .45883 Mdot
.29271 .53067 Mdot
.50551 .63355 Mdot
.21236 .26223 Mdot
.62321 .28175 Mdot
.47153 .34292 Mdot
.43953 .27518 Mdot
.62045 .22766 Mdot
.7624 .62255 Mdot
.64683 .58373 Mdot
.42628 .71627 Mdot
.44686 .33011 Mdot
.56882 .8323 Mdot
.22882 .32459 Mdot
.42836 .65233 Mdot
.41473 .61932 Mdot
.43187 .31485 Mdot
.42643 .30321 Mdot
.63688 .25361 Mdot
.4628 .67417 Mdot
.40494 .68665 Mdot
.40208 .33764 Mdot
.44958 .63994 Mdot
.47775 .72998 Mdot
.57369 .38243 Mdot
.68693 .60294 Mdot
.59608 .43197 Mdot
.56011 .40141 Mdot
.66882 .68968 Mdot
.75359 .50582 Mdot
.57304 .40005 Mdot
.57546 .44014 Mdot
.29625 .63829 Mdot
.39237 .71607 Mdot
.36963 .45081 Mdot
.22125 .38412 Mdot
.46361 .34754 Mdot
.45139 .60215 Mdot
.64043 .56012 Mdot
.63446 .66871 Mdot
.54716 .29913 Mdot
.79796 .47809 Mdot
.42327 .63174 Mdot
.46416 .33513 Mdot
.63067 .28533 Mdot
.40402 .60787 Mdot
.28529 .46748 Mdot
.47716 .61651 Mdot
.47527 .34301 Mdot
.71425 .6914 Mdot
.42411 .74564 Mdot
.40055 .40449 Mdot
.68885 .61915 Mdot
.49606 .62361 Mdot
.64416 .59541 Mdot
.61337 .40449 Mdot
.33013 .44807 Mdot
.33395 .47407 Mdot
.48402 .63415 Mdot
.72783 .62784 Mdot
.53878 .52647 Mdot
.42414 .65002 Mdot
.43921 .66374 Mdot
.6455 .27045 Mdot
.43784 .66341 Mdot
.47586 .67901 Mdot
.49632 .64213 Mdot
.49849 .59377 Mdot
.61853 .43061 Mdot
.40108 .74558 Mdot
.50783 .61487 Mdot
.38592 .59342 Mdot
.57865 .38254 Mdot
.40716 .70237 Mdot
.56323 .40966 Mdot
.1749 .44193 Mdot
.56857 .4145 Mdot
.33255 .46991 Mdot
.48213 .32901 Mdot
.48157 .70581 Mdot
.71091 .59066 Mdot
.57312 .43282 Mdot
.35062 .46405 Mdot
.59357 .39202 Mdot
.42941 .36191 Mdot
.35937 .78223 Mdot
.70366 .54685 Mdot
.43325 .42978 Mdot
.56933 .53692 Mdot
.74759 .38653 Mdot
.42899 .3425 Mdot
.68903 .59063 Mdot
.44332 .75459 Mdot
.49405 .64347 Mdot
.34495 .4853 Mdot
.46746 .62724 Mdot
.61374 .43224 Mdot
.46566 .34143 Mdot
.26043 .38033 Mdot
.33174 .47381 Mdot
.55993 .85099 Mdot
.46461 .36041 Mdot
.40423 .63167 Mdot
.55709 .4056 Mdot
.41737 .82263 Mdot
.56955 .41726 Mdot
.34121 .68023 Mdot
.61857 .5707 Mdot
.73111 .69656 Mdot
.67368 .58988 Mdot
.76828 .36034 Mdot
.12857 .51959 Mdot
.26019 .31122 Mdot
.66605 .56473 Mdot
.39065 .37352 Mdot
.43993 .64361 Mdot
.50438 .64205 Mdot
.43078 .5586 Mdot
.65602 .61664 Mdot
.44521 .62792 Mdot
.64382 .28029 Mdot
.66704 .49247 Mdot
.28853 .42019 Mdot
.39955 .30816 Mdot
.4685 .59059 Mdot
.57603 .38456 Mdot
.61556 .38392 Mdot
.64898 .27916 Mdot
.5639 .38188 Mdot
.42359 .65542 Mdot
.67429 .58485 Mdot
.44498 .49461 Mdot
.35818 .47348 Mdot
.42834 .18844 Mdot
.32202 .49029 Mdot
.39299 .31987 Mdot
.52318 .63177 Mdot
.43989 .33225 Mdot
.84212 .61894 Mdot
.48866 .65334 Mdot
.65776 .56682 Mdot
.47801 .6429 Mdot
.49807 .63442 Mdot
.50396 .64536 Mdot
.40622 .33791 Mdot
.46978 .29015 Mdot
.45326 .63922 Mdot
.60184 .41739 Mdot
.24047 .39902 Mdot
.40651 .6722 Mdot
.39964 .3708 Mdot
.30877 .58779 Mdot
.74545 .40905 Mdot
.64919 .61728 Mdot
.44453 .31589 Mdot
.66098 .58502 Mdot
.70151 .61184 Mdot
.65812 .59069 Mdot
.20415 .45956 Mdot
.56535 .60453 Mdot
.84933 .40657 Mdot
.67515 .75211 Mdot
.61448 .67836 Mdot
.62404 .5848 Mdot
.56925 .24965 Mdot
.64349 .56492 Mdot
.65073 .58694 Mdot
.63788 .1509 Mdot
.6483 .55886 Mdot
.42978 .60136 Mdot
.40459 .64978 Mdot
.69387 .44763 Mdot
.30762 .66006 Mdot
.46244 .67089 Mdot
.45054 .62516 Mdot
.32598 .45313 Mdot
.5002 .55568 Mdot
.65664 .25495 Mdot
.78225 .51304 Mdot
.6374 .33425 Mdot
.47277 .6291 Mdot
.45134 .62803 Mdot
.45814 .57001 Mdot
.12405 .53933 Mdot
.6529 .66354 Mdot
.63438 .55831 Mdot
.45314 .70499 Mdot
.35671 .22751 Mdot
.4071 .62905 Mdot
.43242 .59006 Mdot
.46449 .65074 Mdot
.44796 .32936 Mdot
.69168 .54743 Mdot
.46445 .70221 Mdot
.72981 .40379 Mdot
.43239 .64456 Mdot
.57322 .36126 Mdot
.33847 .50175 Mdot
.44609 .59273 Mdot
.69921 .59562 Mdot
.46512 .66473 Mdot
.64214 .60008 Mdot
.6788 .60534 Mdot
.4882 .5742 Mdot
.20086 .47355 Mdot
.70257 .57127 Mdot
.44862 .65088 Mdot
.44002 .32112 Mdot
.25769 .2996 Mdot
.45295 .59398 Mdot
.33673 .44939 Mdot
.42699 .62384 Mdot
.37003 .46197 Mdot
.43962 .65708 Mdot
.64093 .28569 Mdot
.52232 .72968 Mdot
.45902 .33827 Mdot
.3876 .43116 Mdot
.41365 .31244 Mdot
.74612 .55807 Mdot
.68057 .55344 Mdot
.65455 .24911 Mdot
.82072 .54129 Mdot
.64427 .27178 Mdot
.35076 .60553 Mdot
.52652 .25969 Mdot
.59264 .38511 Mdot
.68869 .60709 Mdot
.36625 .53791 Mdot
.39464 .3669 Mdot
.39647 .34422 Mdot
.42525 .29838 Mdot
.7826 .6997 Mdot
.81433 .58841 Mdot
.46085 .63893 Mdot
.27182 .69138 Mdot
.56271 .76573 Mdot
.48711 .59011 Mdot
.42933 .58225 Mdot
.47634 .34073 Mdot
.49307 .61324 Mdot
.48789 .45868 Mdot
.44212 .34667 Mdot
.34538 .46678 Mdot
.6484 .59266 Mdot
.36776 .45836 Mdot
.45855 .3871 Mdot
.57779 .47328 Mdot
.44043 .355 Mdot
.5015 .60558 Mdot
.47362 .63846 Mdot
.65895 .6089 Mdot
.73369 .57282 Mdot
.6855 .60225 Mdot
.33796 .48899 Mdot
.45129 .34667 Mdot
.63355 .65888 Mdot
.43711 .61566 Mdot
.67747 .57427 Mdot
.58333 .45662 Mdot
.43821 .62012 Mdot
.60941 .39566 Mdot
.41927 .63769 Mdot
.66735 .56115 Mdot
.43749 .66292 Mdot
.67276 .58625 Mdot
.42847 .32603 Mdot
.40898 .62883 Mdot
.45594 .6251 Mdot
.47336 .81704 Mdot
.34527 .47646 Mdot
.67936 .55341 Mdot
.53385 .49 Mdot
.40756 .64247 Mdot
.29564 .44915 Mdot
.47929 .59063 Mdot
.4165 .72217 Mdot
.38663 .64833 Mdot
.64255 .27993 Mdot
.5104 .6411 Mdot
.45583 .59365 Mdot
.41386 .75294 Mdot
.59364 .79376 Mdot
.62946 .54098 Mdot
.59634 .43808 Mdot
.69819 .59661 Mdot
.47351 .32511 Mdot
.44859 .30215 Mdot
.41137 .3335 Mdot
.3225 .67412 Mdot
.43355 .57314 Mdot
.47244 .60028 Mdot
.56405 .4247 Mdot
.33758 .46617 Mdot
.67908 .56645 Mdot
.3371 .46122 Mdot
.78287 .5178 Mdot
.34234 .48949 Mdot
.65002 .2746 Mdot
.36584 .36778 Mdot
.58117 .64947 Mdot
.32427 .45746 Mdot
.68642 .60219 Mdot
.3716 .334 Mdot
.45877 .68119 Mdot
.45156 .24744 Mdot
.35878 .45994 Mdot
.73473 .75978 Mdot
.47332 .58812 Mdot
.45566 .44489 Mdot
.56606 .39441 Mdot
.36685 .4741 Mdot
.60992 .41695 Mdot
.48138 .65922 Mdot
.7057 .34882 Mdot
.65053 .56588 Mdot
.62341 .4345 Mdot
.50949 .64071 Mdot
.36799 .4624 Mdot
.45611 .35774 Mdot
.59689 .51277 Mdot
.61202 .38987 Mdot
.4036 .77332 Mdot
.28148 .4913 Mdot
.4491 .34648 Mdot
.81151 .38804 Mdot
.5958 .42569 Mdot
.49637 .59936 Mdot
.51157 .69568 Mdot
.4479 .67329 Mdot
.46661 .31119 Mdot
.45239 .3169 Mdot
.67538 .47961 Mdot
.47538 .64217 Mdot
.47524 .5888 Mdot
.66921 .53848 Mdot
.43657 .34296 Mdot
.67689 .5962 Mdot
.69821 .6035 Mdot
.43556 .31631 Mdot
.66788 .5974 Mdot
.3393 .4857 Mdot
.64124 .48745 Mdot
.59336 .42549 Mdot
.60357 .41302 Mdot
.46893 .35234 Mdot
.45124 .372 Mdot
.43826 .33369 Mdot
.41972 .63813 Mdot
.68669 .56859 Mdot
.45868 .65893 Mdot
.50649 .62983 Mdot
.61445 .58934 Mdot
.65936 .55118 Mdot
.46825 .65892 Mdot
.39082 .41022 Mdot
.35898 .5003 Mdot
.46483 .32919 Mdot
.57314 .41214 Mdot
.57326 .82846 Mdot
.55721 .41195 Mdot
.47325 .59077 Mdot
.48952 .28022 Mdot
.67416 .55878 Mdot
.35097 .48278 Mdot
.29925 .46084 Mdot
.34239 .48277 Mdot
.63797 .41898 Mdot
.70713 .59202 Mdot
.76087 .49838 Mdot
.47829 .59515 Mdot
.50215 .44783 Mdot
.35636 .54115 Mdot
.73115 .45377 Mdot
.57344 .40461 Mdot
.44366 .62278 Mdot
.64272 .2735 Mdot
.55724 .67964 Mdot
.47503 .61395 Mdot
.48789 .66322 Mdot
.33913 .33019 Mdot
.38729 .59009 Mdot
.63386 .60934 Mdot
.77169 .56788 Mdot
.41599 .66557 Mdot
.61645 .62251 Mdot
.77481 .26813 Mdot
.48429 .59795 Mdot
.4379 .63469 Mdot
.44142 .60206 Mdot
.47918 .65444 Mdot
.61662 .58618 Mdot
.39463 .50182 Mdot
.55803 .40979 Mdot
.52378 .45077 Mdot
.58948 .42137 Mdot
.46806 .32327 Mdot
.45751 .44886 Mdot
.68796 .60606 Mdot
.34636 .48412 Mdot
.3279 .7478 Mdot
.78219 .54314 Mdot
.42527 .34199 Mdot
.68563 .66768 Mdot
.36022 .46842 Mdot
.44629 .68132 Mdot
.31338 .47 Mdot
.42799 .30156 Mdot
.58939 .41424 Mdot
.40592 .65082 Mdot
.63209 .57132 Mdot
.69698 .56831 Mdot
.44042 .62473 Mdot
.31915 .25321 Mdot
.61609 .40606 Mdot
.55182 .44511 Mdot
.46034 .64504 Mdot
.48685 .66411 Mdot
.66543 .60231 Mdot
.45581 .32248 Mdot
.51812 .22263 Mdot
.34861 .4716 Mdot
.48583 .57898 Mdot
.47476 .66159 Mdot
.77703 .52468 Mdot
.59485 .43462 Mdot
.62877 .26128 Mdot
.46601 .64443 Mdot
.75661 .51039 Mdot
.46776 .64525 Mdot
.53605 .62932 Mdot
.43883 .32717 Mdot
.43833 .68502 Mdot
.41606 .62485 Mdot
.39649 .53715 Mdot
.60356 .42567 Mdot
.65465 .57154 Mdot
.64282 .54271 Mdot
.62457 .26613 Mdot
.6068 .39408 Mdot
.46836 .66083 Mdot
.61155 .43083 Mdot
.50501 .64314 Mdot
.45241 .63695 Mdot
.57397 .40521 Mdot
.67628 .59655 Mdot
.53652 .35934 Mdot
.37316 .71221 Mdot
.47922 .64993 Mdot
.41839 .66112 Mdot
.31513 .66248 Mdot
.83047 .4913 Mdot
.42005 .62206 Mdot
.6753 .55634 Mdot
.44293 .61889 Mdot
.60998 .40598 Mdot
.3458 .49121 Mdot
.66297 .56803 Mdot
.46142 .36829 Mdot
.42725 .32421 Mdot
.64518 .36431 Mdot
.65176 .26946 Mdot
.41387 .65476 Mdot
.64629 .5282 Mdot
.64978 .55333 Mdot
.61205 .18739 Mdot
.47235 .33868 Mdot
.37295 .46933 Mdot
.48463 .64349 Mdot
.58692 .51517 Mdot
.56676 .4258 Mdot
.21012 .26459 Mdot
.7504 .48978 Mdot
.31376 .44931 Mdot
.80646 .49303 Mdot
.63808 .27371 Mdot
.42358 .60082 Mdot
.33491 .44418 Mdot
.4192 .32975 Mdot
.50027 .64728 Mdot
.43099 .56495 Mdot
.50586 .38445 Mdot
.42954 .29044 Mdot
.6115 .42983 Mdot
.42227 .35074 Mdot
.32917 .43968 Mdot
.6495 .27564 Mdot
.69635 .58563 Mdot
.46517 .59395 Mdot
.519 .68248 Mdot
.46966 .3427 Mdot
.63902 .28708 Mdot
.45549 .64707 Mdot
.69938 .57339 Mdot
.41844 .31348 Mdot
.47672 .62795 Mdot
.5917 .67324 Mdot
.67921 .62478 Mdot
.45766 .3502 Mdot
.48539 .67278 Mdot
.44859 .72774 Mdot
.46559 .36303 Mdot
.47211 .35177 Mdot
.44577 .6279 Mdot
.33789 .48404 Mdot
.4156 .61042 Mdot
.56296 .40255 Mdot
.46946 .28973 Mdot
.60759 .40437 Mdot
.33012 .52621 Mdot
.52319 .62518 Mdot
.75866 .388 Mdot
.65269 .60947 Mdot
.36292 .43488 Mdot
.48877 .79409 Mdot
.47673 .67225 Mdot
.19923 .39898 Mdot
.41225 .49965 Mdot
.45746 .1694 Mdot
.17335 .58608 Mdot
.35167 .4562 Mdot
.59737 .39231 Mdot
.43798 .63405 Mdot
.5477 .40115 Mdot
.32715 .45659 Mdot
.34601 .53529 Mdot
.48311 .67413 Mdot
.68838 .58444 Mdot
.4383 .64535 Mdot
.64689 .60141 Mdot
.43564 .6199 Mdot
.38026 .63985 Mdot
.38836 .46118 Mdot
.34257 .6839 Mdot
.4536 .6814 Mdot
.35306 .78082 Mdot
.57314 .50772 Mdot
.3575 .46352 Mdot
.45514 .65481 Mdot
.63363 .26414 Mdot
.60164 .37444 Mdot
.22483 .58117 Mdot
.44419 .33096 Mdot
.57172 .39533 Mdot
.65728 .59855 Mdot
.45625 .37642 Mdot
.62381 .27929 Mdot
.52262 .68238 Mdot
.36434 .45006 Mdot
.59261 .38622 Mdot
.45236 .59293 Mdot
.46753 .58788 Mdot
.38313 .40001 Mdot
.71552 .28309 Mdot
.69826 .54861 Mdot
.52519 .84346 Mdot
.62384 .60096 Mdot
.33941 .47339 Mdot
.43812 .32909 Mdot
.42301 .60877 Mdot
.47002 .61808 Mdot
.45725 .30597 Mdot
.67305 .55299 Mdot
.42417 .28551 Mdot
.68173 .68104 Mdot
.41003 .3535 Mdot
.33034 .59321 Mdot
.66113 .56328 Mdot
.33222 .59744 Mdot
.33192 .43796 Mdot
.19033 .48913 Mdot
.25988 .57319 Mdot
.56629 .39201 Mdot
.32918 .58734 Mdot
.67493 .56212 Mdot
.46669 .63776 Mdot
.63456 .27678 Mdot
.64905 .25845 Mdot
.65033 .59774 Mdot
.43314 .31327 Mdot
.367 .4668 Mdot
.44028 .63602 Mdot
.76599 .4576 Mdot
.67868 .41159 Mdot
.42272 .36187 Mdot
.54572 .60566 Mdot
.60686 .41818 Mdot
.4198 .63344 Mdot
.34209 .44758 Mdot
.58359 .39388 Mdot
.62261 .25747 Mdot
.65545 .49021 Mdot
.48701 .64135 Mdot
.7513 .5288 Mdot
.60286 .39062 Mdot
.81854 .39229 Mdot
.46087 .62224 Mdot
.59626 .42578 Mdot
.37498 .63869 Mdot
.70304 .36425 Mdot
.49549 .49019 Mdot
.23348 .32779 Mdot
.42822 .29303 Mdot
.42666 .32146 Mdot
.66912 .2999 Mdot
.38545 .44704 Mdot
.58327 .38274 Mdot
.6486 .27759 Mdot
.27323 .53467 Mdot
.60832 .4202 Mdot
.42853 .59081 Mdot
.48011 .59145 Mdot
.66144 .68646 Mdot
.50351 .47297 Mdot
.63812 .28875 Mdot
.59972 .54948 Mdot
.43327 .66699 Mdot
.4391 .69002 Mdot
.46106 .61387 Mdot
.62715 .56811 Mdot
.61809 .40172 Mdot
.37874 .81523 Mdot
.61662 .41208 Mdot
.77363 .46509 Mdot
.4639 .347 Mdot
.42214 .36301 Mdot
.44975 .59164 Mdot
.78152 .38963 Mdot
.21638 .57085 Mdot
.41414 .6467 Mdot
.30288 .4828 Mdot
.28977 .50466 Mdot
.41913 .68542 Mdot
.6313 .54775 Mdot
.52376 .67331 Mdot
.62305 .61177 Mdot
.57929 .39649 Mdot
.34884 .45357 Mdot
.36071 .49857 Mdot
.58751 .38758 Mdot
.47034 .60032 Mdot
.32728 .51044 Mdot
.4796 .61142 Mdot
.46436 .64113 Mdot
.78453 .50007 Mdot
.37464 .47302 Mdot
.43544 .33519 Mdot
.33345 .4744 Mdot
.6508 .58536 Mdot
.52645 .09645 Mdot
.33699 .45631 Mdot
.70943 .53531 Mdot
.40409 .43483 Mdot
.3313 .5883 Mdot
.69835 .57403 Mdot
.32115 .47066 Mdot
.61442 .42459 Mdot
.45082 .16802 Mdot
.82997 .44303 Mdot
.55425 .40811 Mdot
.4659 .6223 Mdot
.68126 .60897 Mdot
.63507 .56141 Mdot
.57229 .43734 Mdot
.69272 .5881 Mdot
.50446 .66773 Mdot
.47464 .64533 Mdot
.58353 .38276 Mdot
.68571 .44677 Mdot
.61824 .39612 Mdot
.63887 .50439 Mdot
.45597 .65151 Mdot
.66045 .56738 Mdot
.52156 .64981 Mdot
.67766 .53754 Mdot
.64538 .25217 Mdot
.49968 .65065 Mdot
.35771 .48407 Mdot
.50166 .46344 Mdot
.45909 .3486 Mdot
.49733 .29287 Mdot
.66539 .60891 Mdot
.54062 .41605 Mdot
.68651 .59856 Mdot
.66649 .61466 Mdot
.56049 .38564 Mdot
.64677 .57584 Mdot
.43809 .63545 Mdot
.39922 .4063 Mdot
.63513 .58933 Mdot
.59547 .40475 Mdot
.36426 .47348 Mdot
.67122 .59724 Mdot
.46835 .3753 Mdot
.47577 .63469 Mdot
.43229 .35391 Mdot
.32209 .43721 Mdot
.69118 .60513 Mdot
.32344 .47545 Mdot
.47114 .33972 Mdot
.35943 .44524 Mdot
.26701 .35593 Mdot
.62606 .42239 Mdot
.79531 .47097 Mdot
.39598 .72985 Mdot
.63268 .57154 Mdot
.39639 .34589 Mdot
.42157 .61484 Mdot
.47929 .63717 Mdot
.32835 .44185 Mdot
.63667 .56029 Mdot
.26999 .29154 Mdot
.43455 .72234 Mdot
.64727 .48052 Mdot
.62066 .43178 Mdot
.5765 .83773 Mdot
.71018 .49672 Mdot
.45331 .19275 Mdot
.39005 .63432 Mdot
.63749 .27401 Mdot
.48013 .60558 Mdot
.44111 .80402 Mdot
.35262 .49158 Mdot
.56813 .28952 Mdot
.39063 .61859 Mdot
.44426 .33846 Mdot
.44448 .61315 Mdot
.26898 .67821 Mdot
.52531 .66934 Mdot
.32275 .4568 Mdot
.64066 .3991 Mdot
.71123 .58956 Mdot
.35864 .47202 Mdot
.42573 .33016 Mdot
.29681 .55292 Mdot
.47982 .67824 Mdot
.42401 .65931 Mdot
.39772 .32838 Mdot
.68988 .58582 Mdot
.46916 .32328 Mdot
.59333 .42527 Mdot
.3398 .45807 Mdot
.48286 .6517 Mdot
.45394 .69072 Mdot
.49539 .36432 Mdot
.61955 .40511 Mdot
.4432 .37246 Mdot
.59202 .43235 Mdot
.63715 .27508 Mdot
.42849 .67379 Mdot
.39917 .32703 Mdot
.4819 .58953 Mdot
.4859 .80286 Mdot
.79018 .50186 Mdot
.59908 .78122 Mdot
.43374 .3368 Mdot
.31264 .60635 Mdot
.60296 .398 Mdot
.57592 .42475 Mdot
.70223 .73321 Mdot
.22019 .53208 Mdot
.37083 .29865 Mdot
.34193 .7601 Mdot
.5921 .425 Mdot
.60483 .4048 Mdot
.41761 .32783 Mdot
.64337 .5814 Mdot
.66326 .62892 Mdot
.42499 .36688 Mdot
.34908 .69734 Mdot
.67899 .56659 Mdot
.20542 .38072 Mdot
.47772 .3444 Mdot
.3888 .62283 Mdot
.65697 .27418 Mdot
.3519 .45159 Mdot
.35061 .69803 Mdot
.30864 .71542 Mdot
.42682 .6002 Mdot
.77905 .61434 Mdot
.45084 .3225 Mdot
.44902 .418 Mdot
.17844 .4571 Mdot
.4912 .6643 Mdot
.44886 .60705 Mdot
.46629 .60248 Mdot
.374 .48177 Mdot
.47607 .79268 Mdot
.42764 .5985 Mdot
.33669 .65475 Mdot
.41646 .59787 Mdot
.25373 .62037 Mdot
.33288 .47303 Mdot
.57018 .58043 Mdot
.41329 .30028 Mdot
.73264 .4236 Mdot
.4223 .56115 Mdot
.59864 .4294 Mdot
.41315 .3928 Mdot
.58557 .41358 Mdot
.20618 .52858 Mdot
.26114 .57085 Mdot
.62225 .57867 Mdot
.42299 .63225 Mdot
.43345 .29621 Mdot
.66895 .61034 Mdot
.52318 .24806 Mdot
.61724 .13437 Mdot
.62052 .41979 Mdot
.85229 .54253 Mdot
.57578 .42517 Mdot
.64578 .25393 Mdot
.66019 .60219 Mdot
.61072 .62993 Mdot
.50106 .44878 Mdot
.67152 .59577 Mdot
.62498 .32612 Mdot
.62345 .55446 Mdot
.3197 .59598 Mdot
.70046 .60829 Mdot
.5963 .4011 Mdot
.63306 .40468 Mdot
.39965 .58472 Mdot
.42258 .61819 Mdot
.53327 .45162 Mdot
.37166 .6588 Mdot
.42207 .62519 Mdot
.44213 .34651 Mdot
.81792 .43729 Mdot
.4866 .35287 Mdot
.63674 .57546 Mdot
.58865 .4359 Mdot
.44758 .60854 Mdot
.47565 .65076 Mdot
.49672 .60577 Mdot
.47375 .81994 Mdot
.20877 .37695 Mdot
.45525 .63803 Mdot
.49812 .58284 Mdot
.42819 .33012 Mdot
.36917 .50696 Mdot
.38302 .77976 Mdot
.27222 .54667 Mdot
.48752 .62584 Mdot
.34398 .47858 Mdot
.36414 .48904 Mdot
.41808 .67713 Mdot
.75575 .42546 Mdot
.3922 .3828 Mdot
.45187 .59307 Mdot
.25215 .5814 Mdot
.47957 .36695 Mdot
.64579 .28384 Mdot
.46964 .3436 Mdot
.69873 .59908 Mdot
.64829 .26649 Mdot
.40958 .32031 Mdot
.60007 .62582 Mdot
.62526 .26197 Mdot
.70644 .37829 Mdot
.33789 .48899 Mdot
.46542 .61398 Mdot
.637 .54084 Mdot
.45965 .30603 Mdot
.58925 .38599 Mdot
.6675 .58047 Mdot
.61564 .38293 Mdot
.38245 .49641 Mdot
.36348 .56471 Mdot
.65216 .26507 Mdot
.58998 .42809 Mdot
.65621 .49093 Mdot
.34136 .47854 Mdot
.561 .38756 Mdot
.77374 .37953 Mdot
.39957 .65459 Mdot
.20605 .59083 Mdot
.4201 .64596 Mdot
.36259 .22044 Mdot
.57146 .42243 Mdot
.63252 .25201 Mdot
.4729 .59803 Mdot
.46476 .36085 Mdot
.37841 .65792 Mdot
.479 .61809 Mdot
.44055 .36829 Mdot
.46194 .63837 Mdot
.34144 .44672 Mdot
.64528 .62341 Mdot
.42045 .50087 Mdot
.66123 .79929 Mdot
.35837 .44584 Mdot
.66517 .26784 Mdot
.42024 .62581 Mdot
.25868 .4013 Mdot
.67425 .59467 Mdot
.49074 .66251 Mdot
.74259 .67813 Mdot
.64008 .58671 Mdot
.66353 .58724 Mdot
.4453 .66337 Mdot
.56503 .38739 Mdot
.46367 .35725 Mdot
.34117 .47949 Mdot
.50907 .17221 Mdot
.47954 .62498 Mdot
.44921 .62167 Mdot
.36021 .46937 Mdot
.60635 .40444 Mdot
.47577 .65362 Mdot
.51965 .27708 Mdot
.53115 .1586 Mdot
.55963 .40246 Mdot
.40604 .67215 Mdot
.23524 .66516 Mdot
.72236 .59588 Mdot
.8426 .5128 Mdot
.37824 .42094 Mdot
.44105 .31719 Mdot
.38481 .65474 Mdot
.25334 .22656 Mdot
.35275 .45324 Mdot
.73709 .45136 Mdot
.45132 .64186 Mdot
.43571 .61048 Mdot
.69185 .56555 Mdot
.46179 .66111 Mdot
.65943 .55755 Mdot
.68411 .78978 Mdot
.53119 .86765 Mdot
.68146 .59959 Mdot
.63879 .56764 Mdot
.5893 .59633 Mdot
.41877 .78438 Mdot
.65185 .59483 Mdot
.4929 .66755 Mdot
.2397 .37458 Mdot
.49364 .57488 Mdot
.3422 .43572 Mdot
.3064 .44588 Mdot
.63642 .63237 Mdot
.77633 .33402 Mdot
.43149 .71048 Mdot
.41018 .55583 Mdot
.54493 .5339 Mdot
.5684 .41146 Mdot
.49291 .63213 Mdot
.65197 .27025 Mdot
.4111 .33783 Mdot
.53966 .63485 Mdot
.46902 .61221 Mdot
.64136 .59882 Mdot
.37593 .47726 Mdot
.5824 .36957 Mdot
.45134 .62536 Mdot
.4425 .28634 Mdot
.34664 .46904 Mdot
.63326 .58306 Mdot
.73287 .54935 Mdot
.36479 .4436 Mdot
.49602 .67778 Mdot
.42707 .6201 Mdot
.45698 .64704 Mdot
.4007 .57174 Mdot
.58219 .38712 Mdot
.47152 .37804 Mdot
.5013 .66434 Mdot
.77718 .51346 Mdot
.4509 .43549 Mdot
.45907 .68855 Mdot
.6835 .56346 Mdot
.55856 .41326 Mdot
.6306 .25844 Mdot
.31366 .54807 Mdot
.48729 .63664 Mdot
.20902 .38114 Mdot
.66199 .67026 Mdot
.64596 .26369 Mdot
.63737 .60513 Mdot
.34748 .48341 Mdot
.43013 .66219 Mdot
.22286 .4147 Mdot
.47534 .59004 Mdot
.40119 .72245 Mdot
.44602 .31941 Mdot
.57292 .41579 Mdot
.50809 .15367 Mdot
.41137 .33953 Mdot
.66171 .58576 Mdot
.23469 .30299 Mdot
.68021 .54624 Mdot
.70961 .57169 Mdot
.20394 .48395 Mdot
.57602 .39848 Mdot
.23464 .24409 Mdot
.8334 .4686 Mdot
.45353 .58359 Mdot
.61234 .40768 Mdot
.66289 .60449 Mdot
.42208 .63563 Mdot
.6457 .55678 Mdot
.70223 .56153 Mdot
.50148 .63926 Mdot
.42989 .61411 Mdot
.34335 .6697 Mdot
.18217 .41363 Mdot
.33636 .48077 Mdot
.67771 .55423 Mdot
.62345 .6875 Mdot
.42463 .6012 Mdot
.47761 .59468 Mdot
.44329 .40562 Mdot
.32294 .45697 Mdot
.4726 .74059 Mdot
.46566 .64341 Mdot
.74882 .68117 Mdot
.41602 .65924 Mdot
.64965 .53532 Mdot
.55929 .39625 Mdot
.75327 .43059 Mdot
.47034 .31644 Mdot
.69543 .56081 Mdot
.36964 .46554 Mdot
.64582 .54434 Mdot
.71942 .70352 Mdot
.57782 .40254 Mdot
.66738 .56112 Mdot
.47385 .36343 Mdot
.58827 .40921 Mdot
.56092 .40115 Mdot
.24033 .3976 Mdot
.43875 .372 Mdot
.3303 .48716 Mdot
.59304 .41846 Mdot
.58468 .6824 Mdot
.59263 .39869 Mdot
.63954 .6882 Mdot
.41103 .6331 Mdot
.33775 .64238 Mdot
.71731 .48973 Mdot
.44638 .55706 Mdot
.61738 .39239 Mdot
.32649 .46388 Mdot
.45445 .66861 Mdot
.69339 .58394 Mdot
.33876 .45462 Mdot
.64633 .39182 Mdot
.46459 .36872 Mdot
.64126 .6037 Mdot
.55782 .40285 Mdot
.66506 .55804 Mdot
.359 .55324 Mdot
.47834 .2844 Mdot
.54978 .54184 Mdot
.49119 .44016 Mdot
.49323 .59538 Mdot
.63405 .63399 Mdot
.40828 .64935 Mdot
.4726 .61255 Mdot
.45845 .35042 Mdot
.32286 .67279 Mdot
.67551 .59755 Mdot
.52271 .15109 Mdot
.58256 .42592 Mdot
.76549 .58781 Mdot
.45741 .72458 Mdot
.49135 .65626 Mdot
.63633 .5895 Mdot
.6998 .55519 Mdot
.59571 .7924 Mdot
.45724 .3072 Mdot
.47642 .56171 Mdot
.52562 .61993 Mdot
.38669 .61283 Mdot
.57241 .42437 Mdot
.53467 .29708 Mdot
.44444 .30989 Mdot
.86465 .42679 Mdot
.46332 .32776 Mdot
.31299 .35251 Mdot
.64622 .57525 Mdot
.35419 .48959 Mdot
.47398 .59244 Mdot
.36221 .68913 Mdot
.61958 .5751 Mdot
.41811 .41345 Mdot
.35514 .48319 Mdot
.55952 .32675 Mdot
.57361 .39667 Mdot
.44033 .6825 Mdot
.49966 .63372 Mdot
.45471 .65807 Mdot
.42582 .64579 Mdot
.59815 .43749 Mdot
.4298 .59039 Mdot
.62473 .43089 Mdot
.58749 .66749 Mdot
.74528 .6896 Mdot
.46007 .30117 Mdot
.22317 .56116 Mdot
.62827 .57927 Mdot
.58941 .69704 Mdot
.48738 .72382 Mdot
.79079 .49673 Mdot
.25821 .37592 Mdot
.41077 .64938 Mdot
.42837 .31346 Mdot
.26981 .68535 Mdot
.43518 .29657 Mdot
.62935 .86893 Mdot
.33231 .51648 Mdot
.22515 .33024 Mdot
.42369 .6354 Mdot
.49039 .36869 Mdot
.46688 .72856 Mdot
.41248 .6751 Mdot
.34813 .52036 Mdot
.69483 .52184 Mdot
.70278 .44367 Mdot
.37332 .46331 Mdot
.47677 .63264 Mdot
.71249 .58664 Mdot
.43696 .63667 Mdot
.48104 .60014 Mdot
.41811 .63343 Mdot
.56752 .37261 Mdot
.39951 .61306 Mdot
.41788 .60599 Mdot
.72249 .2831 Mdot
.30385 .63162 Mdot
.43059 .35594 Mdot
.64278 .77032 Mdot
.33796 .46587 Mdot
.65009 .60436 Mdot
.40905 .48805 Mdot
.56652 .39664 Mdot
.58008 .80243 Mdot
.42135 .6398 Mdot
.7035 .48441 Mdot
.55739 .40309 Mdot
.34278 .45281 Mdot
.6248 .27169 Mdot
.24549 .33519 Mdot
.45644 .30015 Mdot
.62669 .25858 Mdot
.45961 .34718 Mdot
.49671 .78322 Mdot
.6407 .59757 Mdot
.49954 .61125 Mdot
.60239 .42095 Mdot
.46042 .36032 Mdot
.31099 .67122 Mdot
.45936 .61016 Mdot
.43261 .33942 Mdot
.49585 .59924 Mdot
.42778 .43459 Mdot
.38668 .38681 Mdot
.41466 .30994 Mdot
.63446 .39967 Mdot
.59479 .41237 Mdot
.34005 .48647 Mdot
.64951 .60505 Mdot
.67676 .55887 Mdot
.58334 .39639 Mdot
.83578 .54303 Mdot
.48154 .61886 Mdot
.41889 .6306 Mdot
.7719 .51035 Mdot
.43246 .63084 Mdot
.30734 .57096 Mdot
.65629 .26124 Mdot
.635 .59658 Mdot
.42746 .63917 Mdot
.47772 .65284 Mdot
.48599 .6429 Mdot
.35842 .55748 Mdot
.46901 .3394 Mdot
.43306 .66648 Mdot
.33531 .44202 Mdot
.74544 .35762 Mdot
.41831 .61548 Mdot
.42773 .6851 Mdot
.67064 .56207 Mdot
.58954 .84057 Mdot
.56416 .3966 Mdot
.43461 .34692 Mdot
.47278 .35579 Mdot
.33943 .4207 Mdot
.6551 .61978 Mdot
.65776 .25645 Mdot
.60451 .21367 Mdot
.63555 .28356 Mdot
.3567 .46925 Mdot
.34225 .30735 Mdot
.4313 .28692 Mdot
.42353 .3439 Mdot
.6306 .42034 Mdot
.42729 .64328 Mdot
.41354 .64845 Mdot
.74014 .45209 Mdot
.45808 .67423 Mdot
.35987 .48039 Mdot
.58956 .38058 Mdot
.67286 .56517 Mdot
.35355 .45083 Mdot
.5981 .43163 Mdot
.69061 .58326 Mdot
.40119 .65612 Mdot
.39753 .64674 Mdot
.66744 .58462 Mdot
.6796 .60637 Mdot
.43398 .59971 Mdot
.69927 .27727 Mdot
.69122 .61154 Mdot
.66457 .56204 Mdot
.63016 .29337 Mdot
.45286 .29831 Mdot
.51465 .66583 Mdot
.61311 .40778 Mdot
.45782 .64623 Mdot
.44549 .29505 Mdot
.32187 .46162 Mdot
.68022 .58736 Mdot
.47792 .64865 Mdot
.46454 .63377 Mdot
.34534 .4796 Mdot
.3738 .4532 Mdot
.36468 .45936 Mdot
.54579 .38407 Mdot
.43793 .65215 Mdot
.65455 .5951 Mdot
.57444 .40104 Mdot
.36435 .48887 Mdot
.31838 .48129 Mdot
.74875 .29866 Mdot
.43124 .5966 Mdot
.50379 .49659 Mdot
.48818 .10232 Mdot
.28892 .55195 Mdot
.63671 .25469 Mdot
.40113 .33999 Mdot
.33176 .62354 Mdot
.35207 .40814 Mdot
.61484 .39938 Mdot
.24401 .50022 Mdot
.36156 .43464 Mdot
.50556 .63326 Mdot
.42134 .66431 Mdot
.47396 .5758 Mdot
.34522 .46421 Mdot
.35048 .54989 Mdot
.64249 .55422 Mdot
.55755 .74714 Mdot
.3381 .46567 Mdot
.41499 .30995 Mdot
.40106 .32424 Mdot
.46256 .32665 Mdot
.42197 .67174 Mdot
.58488 .79461 Mdot
.60187 .68386 Mdot
.49393 .7579 Mdot
.57276 .39449 Mdot
.69446 .54857 Mdot
.2618 .38028 Mdot
.66539 .58853 Mdot
.40915 .33231 Mdot
.34912 .46473 Mdot
.68429 .55825 Mdot
.60608 .38909 Mdot
.60585 .40747 Mdot
.46455 .36736 Mdot
.46828 .34949 Mdot
.4453 .35749 Mdot
.70401 .58989 Mdot
.64655 .57593 Mdot
.48869 .64685 Mdot
.67719 .58166 Mdot
.78273 .60229 Mdot
.30906 .4552 Mdot
.40483 .316 Mdot
.60464 .39433 Mdot
.65416 .60429 Mdot
.46516 .6166 Mdot
.35768 .33076 Mdot
.62211 .33946 Mdot
.35116 .44292 Mdot
.40748 .2605 Mdot
.69792 .81997 Mdot
.49805 .62462 Mdot
.60491 .4334 Mdot
.75611 .41078 Mdot
.46054 .60345 Mdot
.44638 .32752 Mdot
.45386 .80516 Mdot
.63598 .28604 Mdot
.41781 .6076 Mdot
.47941 .66661 Mdot
.56339 .38196 Mdot
.4018 .44561 Mdot
.48117 .66135 Mdot
.71769 .51561 Mdot
.60461 .3722 Mdot
.43468 .30725 Mdot
.555 .15742 Mdot
.40554 .35464 Mdot
.34743 .71095 Mdot
.64253 .25539 Mdot
.49901 .63701 Mdot
.44516 .34852 Mdot
.34399 .443 Mdot
.44978 .35384 Mdot
.62779 .59674 Mdot
.43641 .35723 Mdot
.44631 .61961 Mdot
.65259 .59277 Mdot
.60541 .39175 Mdot
.77061 .56318 Mdot
.73162 .29823 Mdot
.46481 .36122 Mdot
.61993 .29005 Mdot
.42108 .60387 Mdot
.53226 .70008 Mdot
.37904 .65972 Mdot
.41796 .62273 Mdot
.58381 .41261 Mdot
.6354 .58626 Mdot
.61513 .43336 Mdot
.4552 .6973 Mdot
.6857 .75821 Mdot
.57154 .42008 Mdot
.70858 .40465 Mdot
.35941 .46837 Mdot
.34807 .68889 Mdot
.47398 .61941 Mdot
.59672 .42161 Mdot
.43984 .65215 Mdot
.66614 .54852 Mdot
.55103 .48825 Mdot
.75789 .36589 Mdot
.60325 .41974 Mdot
.30505 .25344 Mdot
.54491 .49509 Mdot
.51926 .67288 Mdot
.59302 .42337 Mdot
.53362 .80025 Mdot
.63188 .26168 Mdot
.35007 .47173 Mdot
.37145 .48157 Mdot
.36291 .447 Mdot
.45689 .67575 Mdot
.55028 .62837 Mdot
.32461 .48595 Mdot
.59693 .36822 Mdot
.32556 .4505 Mdot
.34841 .66662 Mdot
.29546 .26592 Mdot
.36183 .45241 Mdot
.46801 .62506 Mdot
.41985 .68275 Mdot
.30355 .63611 Mdot
.4185 .31178 Mdot
.19689 .4044 Mdot
.72599 .63636 Mdot
.42463 .60877 Mdot
.50985 .69342 Mdot
.62676 .58792 Mdot
.78238 .4132 Mdot
.48338 .71251 Mdot
.38788 .3999 Mdot
.64684 .56177 Mdot
.39711 .29808 Mdot
.63966 .60066 Mdot
.4951 .61135 Mdot
.45078 .63727 Mdot
.63026 .61918 Mdot
.49698 .2856 Mdot
.69092 .3404 Mdot
.41101 .19947 Mdot
.67395 .55599 Mdot
.60361 .42548 Mdot
.61858 .42508 Mdot
.57204 .40361 Mdot
.47263 .32224 Mdot
.69525 .59976 Mdot
.433 .65537 Mdot
.43048 .32184 Mdot
.48652 .62145 Mdot
.58962 .41317 Mdot
.50271 .15373 Mdot
.67106 .56314 Mdot
.45612 .59337 Mdot
.82924 .44361 Mdot
.4618 .33468 Mdot
.34028 .47674 Mdot
.43642 .4263 Mdot
.4654 .38024 Mdot
.61832 .39466 Mdot
.70137 .61505 Mdot
.56927 .36445 Mdot
.4005 .50996 Mdot
.46527 .56961 Mdot
.45872 .68617 Mdot
.54787 .1705 Mdot
.793 .36265 Mdot
.44011 .67703 Mdot
.42527 .33078 Mdot
.43416 .30097 Mdot
.47879 .64384 Mdot
.69675 .58761 Mdot
.35362 .49456 Mdot
.34797 .43814 Mdot
.51041 .63649 Mdot
.50226 .4457 Mdot
.34021 .65721 Mdot
.47007 .65775 Mdot
.49608 .56438 Mdot
.46164 .3729 Mdot
.62377 .27466 Mdot
.75071 .50246 Mdot
.36754 .47897 Mdot
.45398 .64257 Mdot
.68242 .36047 Mdot
.6557 .55808 Mdot
.43881 .35686 Mdot
.59212 .38345 Mdot
.3756 .52447 Mdot
.47654 .3507 Mdot
.47792 .6443 Mdot
.47616 .6534 Mdot
.56221 .38405 Mdot
.64911 .5356 Mdot
.34791 .46298 Mdot
.43158 .32263 Mdot
.35843 .48859 Mdot
.64987 .58193 Mdot
.67039 .56733 Mdot
.51106 .5837 Mdot
.39558 .5782 Mdot
.46935 .35924 Mdot
.50758 .604 Mdot
.40701 .32562 Mdot
.39401 .4386 Mdot
.57279 .43103 Mdot
.4964 .6585 Mdot
.71728 .58464 Mdot
.58468 .40918 Mdot
.4355 .60546 Mdot
.62643 .20161 Mdot
.49485 .65067 Mdot
.46924 .37914 Mdot
.69474 .75146 Mdot
.3242 .4611 Mdot
.74427 .57588 Mdot
.44674 .53489 Mdot
.434 .62969 Mdot
.40392 .33002 Mdot
.39003 .67337 Mdot
.56343 .40858 Mdot
.64192 .57144 Mdot
.83835 .62293 Mdot
.59254 .40262 Mdot
.43935 .63804 Mdot
.34008 .45651 Mdot
.7082 .56375 Mdot
.64692 .2748 Mdot
.75231 .49574 Mdot
.53757 .64417 Mdot
.39183 .6316 Mdot
.4294 .64207 Mdot
.35166 .77269 Mdot
.43884 .34919 Mdot
.65872 .60471 Mdot
.57508 .42828 Mdot
.58718 .39177 Mdot
.45481 .32135 Mdot
.69391 .46647 Mdot
.4761 .27167 Mdot
.40373 .10988 Mdot
.44235 .36704 Mdot
.32245 .45145 Mdot
.47385 .44435 Mdot
.41262 .3443 Mdot
.44205 .34245 Mdot
.47179 .36092 Mdot
.72315 .47641 Mdot
.68942 .57258 Mdot
.46465 .6347 Mdot
.65012 .61751 Mdot
.49897 .64266 Mdot
.3427 .72726 Mdot
.58142 .39586 Mdot
.64334 .5711 Mdot
.59118 .18384 Mdot
.37479 .66475 Mdot
.45323 .60715 Mdot
.28375 .31732 Mdot
.45701 .70151 Mdot
.32792 .57067 Mdot
.503 .67318 Mdot
.46489 .35031 Mdot
.54067 .6624 Mdot
.38404 .64396 Mdot
.78012 .59487 Mdot
.60879 .39751 Mdot
.64918 .25435 Mdot
.40012 .63119 Mdot
.53579 .62774 Mdot
.70897 .56666 Mdot
.68404 .55789 Mdot
.32714 .48727 Mdot
.482 .41638 Mdot
.60725 .39346 Mdot
.51405 .35787 Mdot
.4235 .61925 Mdot
.64065 .43318 Mdot
.70878 .72401 Mdot
.43703 .60343 Mdot
.23354 .39383 Mdot
.58508 .7997 Mdot
.48394 .65978 Mdot
.52699 .76958 Mdot
.60335 .40176 Mdot
.74742 .6801 Mdot
.48778 .58376 Mdot
.44744 .32869 Mdot
.64254 .57887 Mdot
.62942 .5947 Mdot
.35547 .44725 Mdot
.80863 .56113 Mdot
.62685 .4086 Mdot
.64495 .57412 Mdot
.46518 .60545 Mdot
.58492 .38588 Mdot
.65087 .26453 Mdot
.40326 .67305 Mdot
.22912 .4848 Mdot
.67682 .57723 Mdot
.50425 .58713 Mdot
.64235 .46563 Mdot
.43008 .44403 Mdot
.166 .43628 Mdot
.57271 .40888 Mdot
.36896 .471 Mdot
.51075 .66559 Mdot
.60035 .21096 Mdot
.43576 .5789 Mdot
.33243 .67125 Mdot
.70668 .62774 Mdot
.34658 .49129 Mdot
.46056 .59886 Mdot
.47744 .6626 Mdot
.49397 .45298 Mdot
.37452 .45958 Mdot
.49587 .65358 Mdot
.49884 .57494 Mdot
.68956 .58419 Mdot
.65493 .25852 Mdot
.67663 .57055 Mdot
.46505 .62213 Mdot
.54918 .65083 Mdot
.69499 .57532 Mdot
.37606 .25426 Mdot
.3782 .45094 Mdot
.56488 .39955 Mdot
.52907 .58473 Mdot
.41201 .63175 Mdot
.22215 .68443 Mdot
.64522 .25227 Mdot
.42584 .80542 Mdot
.43033 .3706 Mdot
.63779 .32742 Mdot
.49234 .3166 Mdot
.23699 .31611 Mdot
.75989 .54001 Mdot
.48499 .57537 Mdot
.2416 .5552 Mdot
.51394 .76312 Mdot
.62494 .41941 Mdot
.55961 .68918 Mdot
.42245 .61812 Mdot
.48131 .60367 Mdot
.41948 .3221 Mdot
.68562 .47783 Mdot
.7527 .41384 Mdot
.51734 .4476 Mdot
.35096 .4595 Mdot
.65151 .57439 Mdot
.43846 .62122 Mdot
.48323 .23896 Mdot
.43612 .36036 Mdot
.59162 .51052 Mdot
.46541 .59458 Mdot
.77365 .45658 Mdot
.71734 .43588 Mdot
.58339 .38543 Mdot
.40239 .33998 Mdot
.46536 .37953 Mdot
.48844 .60282 Mdot
.60785 .38722 Mdot
.48867 .65006 Mdot
.57599 .50157 Mdot
.50633 .59466 Mdot
.34305 .44953 Mdot
.44972 .58682 Mdot
.48341 .4725 Mdot
.19455 .35486 Mdot
.4879 .69853 Mdot
.67678 .61271 Mdot
.4731 .32522 Mdot
.46538 .33234 Mdot
.6751 .55751 Mdot
.46272 .32915 Mdot
.56462 .75228 Mdot
.70519 .69457 Mdot
.35603 .4591 Mdot
.53953 .68214 Mdot
.33806 .45132 Mdot
.64889 .25351 Mdot
.4284 .60048 Mdot
.61212 .22737 Mdot
.44902 .36804 Mdot
.51539 .82746 Mdot
.59152 .39634 Mdot
.64604 .2531 Mdot
.42175 .59048 Mdot
.33846 .31187 Mdot
.41213 .32307 Mdot
.43577 .38588 Mdot
.48671 .64277 Mdot
.68407 .56113 Mdot
.47637 .66259 Mdot
.51676 .63206 Mdot
.62704 .25872 Mdot
.4288 .64353 Mdot
.59894 .43157 Mdot
.69839 .59595 Mdot
.25345 .31049 Mdot
.46286 .30801 Mdot
.45958 .58847 Mdot
.46471 .60452 Mdot
.66479 .54714 Mdot
.4198 .59494 Mdot
.61544 .39561 Mdot
.1488 .3314 Mdot
.35835 .4695 Mdot
.62443 .28192 Mdot
.45756 .38725 Mdot
.41674 .65436 Mdot
.47099 .66077 Mdot
.53581 .16834 Mdot
.71654 .32645 Mdot
.59694 .43043 Mdot
.50829 .65598 Mdot
.42881 .331 Mdot
.34211 .45418 Mdot
.58949 .37057 Mdot
.46023 .64837 Mdot
.47652 .59668 Mdot
.34508 .44941 Mdot
.24548 .36993 Mdot
.39015 .38217 Mdot
.57147 .39778 Mdot
.53409 .6769 Mdot
.36304 .34022 Mdot
.48043 .61847 Mdot
.41964 .22402 Mdot
.66458 .56357 Mdot
.58672 .42169 Mdot
.44549 .77714 Mdot
.50039 .61194 Mdot
.6185 .40126 Mdot
.60678 .39397 Mdot
.46335 .58408 Mdot
.65826 .6199 Mdot
.70675 .57896 Mdot
.6603 .5608 Mdot
.69344 .75893 Mdot
.2839 .66199 Mdot
.44652 .35809 Mdot
.60471 .40283 Mdot
.42549 .30067 Mdot
.3567 .49498 Mdot
.45404 .4356 Mdot
.42543 .3027 Mdot
.628 .59042 Mdot
.40109 .32197 Mdot
.48384 .65364 Mdot
.60916 .39357 Mdot
.42308 .34436 Mdot
.42254 .66256 Mdot
.46351 .55297 Mdot
.52971 .50359 Mdot
.34965 .49431 Mdot
.40395 .41782 Mdot
.44959 .6314 Mdot
.62865 .25929 Mdot
.4383 .59618 Mdot
.5822 .38288 Mdot
.46206 .468 Mdot
.4257 .6635 Mdot
.46636 .3617 Mdot
.43562 .51447 Mdot
.43172 .30605 Mdot
.52244 .62319 Mdot
.46402 .62331 Mdot
.4813 .61479 Mdot
.48106 .66173 Mdot
.7091 .42329 Mdot
.61966 .43375 Mdot
.51149 .56653 Mdot
.45328 .29242 Mdot
.67189 .59015 Mdot
.64159 .55098 Mdot
.37244 .30259 Mdot
.62228 .26924 Mdot
.61156 .40507 Mdot
.4809 .62068 Mdot
.43202 .38475 Mdot
.49202 .15562 Mdot
.41593 .21699 Mdot
.26588 .3876 Mdot
.42348 .33589 Mdot
.67633 .61216 Mdot
.41985 .34929 Mdot
.48818 .60905 Mdot
.46999 .69098 Mdot
.24222 .31832 Mdot
.59072 .44754 Mdot
.34793 .46479 Mdot
.48656 .61741 Mdot
.35218 .71602 Mdot
.42823 .33003 Mdot
.45898 .37434 Mdot
.49568 .64043 Mdot
.70026 .56511 Mdot
.13481 .47345 Mdot
.58997 .38296 Mdot
.53785 .69773 Mdot
.73685 .59286 Mdot
.68301 .51755 Mdot
.58855 .38808 Mdot
.54181 .52159 Mdot
.45665 .31589 Mdot
.7468 .62648 Mdot
.6711 .58632 Mdot
.34466 .46751 Mdot
.47392 .68671 Mdot
.63026 .59487 Mdot
.40265 .34576 Mdot
.63073 .58444 Mdot
.49965 .61739 Mdot
.62228 .42788 Mdot
.45293 .31788 Mdot
.63797 .41684 Mdot
.62778 .61773 Mdot
.33099 .45351 Mdot
.35138 .69179 Mdot
.55674 .684 Mdot
.58317 .80069 Mdot
.43269 .6661 Mdot
.39722 .36691 Mdot
.44037 .65395 Mdot
.70776 .5667 Mdot
.47314 .62058 Mdot
.62181 .6278 Mdot
.42283 .36318 Mdot
.50308 .58657 Mdot
.42173 .59912 Mdot
.60766 .6463 Mdot
.44747 .60329 Mdot
.42882 .58727 Mdot
.47444 .6676 Mdot
.7359 .6027 Mdot
.50083 .57902 Mdot
.6889 .56734 Mdot
.73477 .45853 Mdot
.44447 .34265 Mdot
.32887 .49162 Mdot
.35634 .43989 Mdot
.33372 .6654 Mdot
.34795 .69142 Mdot
.69794 .46941 Mdot
.68213 .57037 Mdot
.61308 .42409 Mdot
.48921 .64913 Mdot
.4415 .77084 Mdot
.36116 .43039 Mdot
.45597 .31665 Mdot
.47827 .33071 Mdot
.38678 .59031 Mdot
.3403 .76794 Mdot
.50543 .58612 Mdot
.75824 .49562 Mdot
.50963 .62197 Mdot
.49186 .66118 Mdot
.47658 .36032 Mdot
.35601 .58439 Mdot
.43267 .66635 Mdot
.70892 .5664 Mdot
.34265 .47145 Mdot
.46607 .71121 Mdot
.29601 .48042 Mdot
.56551 .51576 Mdot
.64425 .64601 Mdot
.42808 .65084 Mdot
.43678 .31969 Mdot
.64397 .60492 Mdot
.7737 .51826 Mdot
.57536 .40416 Mdot
.72559 .49898 Mdot
.60441 .66515 Mdot
.34485 .27127 Mdot
.34642 .46879 Mdot
.24258 .38464 Mdot
.44603 .62 Mdot
.4753 .33117 Mdot
.50089 .62841 Mdot
.48277 .15811 Mdot
.3225 .47256 Mdot
.61835 .57637 Mdot
.60529 .42545 Mdot
.66417 .5497 Mdot
.60558 .77901 Mdot
.53833 .54391 Mdot
.65106 .29597 Mdot
.45 .29834 Mdot
.39413 .75458 Mdot
.64837 .59588 Mdot
.47082 .64849 Mdot
.43304 .10457 Mdot
.66319 .56466 Mdot
.67387 .55331 Mdot
.39598 .42761 Mdot
.33238 .52746 Mdot
.39278 .67413 Mdot
.63076 .57785 Mdot
.41874 .30109 Mdot
.33384 .47667 Mdot
.4485 .67036 Mdot
.47401 .6665 Mdot
.68987 .56353 Mdot
.40989 .3257 Mdot
.37978 .75562 Mdot
.46692 .34986 Mdot
.6885 .59063 Mdot
.45911 .3377 Mdot
.45994 .39187 Mdot
.42775 .34439 Mdot
.41196 .61729 Mdot
.47968 .62321 Mdot
.27876 .42398 Mdot
.67048 .56749 Mdot
.46154 .66475 Mdot
.45693 .63969 Mdot
.65297 .59629 Mdot
.42783 .28874 Mdot
.42419 .77069 Mdot
.42381 .63237 Mdot
.47217 .63193 Mdot
.35347 .4905 Mdot
.42756 .27495 Mdot
.47314 .22594 Mdot
.45325 .66848 Mdot
.33902 .43913 Mdot
.70355 .59311 Mdot
.43718 .5978 Mdot
.34748 .65469 Mdot
.48447 .34414 Mdot
.46412 .58625 Mdot
.64754 .27535 Mdot
.41445 .65097 Mdot
.13882 .46492 Mdot
.44389 .58951 Mdot
.66452 .60366 Mdot
.64004 .58429 Mdot
.42675 .41741 Mdot
.65986 .5831 Mdot
.64686 .25644 Mdot
.5902 .41216 Mdot
.3818 .2157 Mdot
.64912 .26194 Mdot
.48505 .66833 Mdot
.83343 .46904 Mdot
.50381 .59939 Mdot
.40173 .63701 Mdot
.42495 .78845 Mdot
.64763 .2609 Mdot
.6397 .59324 Mdot
.50197 .29108 Mdot
.50945 .64475 Mdot
.59491 .38295 Mdot
.42321 .68201 Mdot
.45213 .58513 Mdot
.69755 .5141 Mdot
.64438 .78621 Mdot
.57786 .38261 Mdot
.50344 .67835 Mdot
.45272 .66813 Mdot
.76911 .34327 Mdot
.46125 .61172 Mdot
.35945 .45005 Mdot
.66634 .55564 Mdot
.42497 .35835 Mdot
.35366 .47757 Mdot
.42726 .6273 Mdot
.3422 .4646 Mdot
.44121 .35646 Mdot
.58514 .41582 Mdot
.4674 .58877 Mdot
.34682 .43516 Mdot
.34923 .4602 Mdot
.44782 .65676 Mdot
.64307 .57436 Mdot
.40253 .69697 Mdot
.4364 .59945 Mdot
.47328 .64627 Mdot
.67678 .55895 Mdot
.8224 .3552 Mdot
.49246 .61147 Mdot
.51066 .49905 Mdot
.61887 .58634 Mdot
.65061 .2815 Mdot
.41966 .34534 Mdot
.48188 .58759 Mdot
.57993 .39354 Mdot
.58097 .40176 Mdot
.39688 .31315 Mdot
.67261 .54743 Mdot
.41676 .31471 Mdot
.4765 .69944 Mdot
.40092 .57464 Mdot
.50176 .66508 Mdot
.83202 .63033 Mdot
.23727 .34383 Mdot
.69432 .59789 Mdot
.448 .31054 Mdot
.51837 .44597 Mdot
.60941 .40763 Mdot
.40062 .31715 Mdot
.71407 .59496 Mdot
.67821 .6088 Mdot
.62804 .58107 Mdot
.35692 .48708 Mdot
.47214 .33314 Mdot
.63911 .54091 Mdot
.69492 .55909 Mdot
.48606 .64693 Mdot
.45354 .66735 Mdot
.63204 .6286 Mdot
.30355 .61359 Mdot
.33421 .4508 Mdot
.44293 .32114 Mdot
.19936 .67603 Mdot
.58096 .38324 Mdot
.61034 .64574 Mdot
.4192 .65743 Mdot
.61372 .12412 Mdot
.51912 .59822 Mdot
.46421 .60742 Mdot
.69942 .59829 Mdot
.32133 .44806 Mdot
.3319 .46423 Mdot
.64668 .59427 Mdot
.65775 .62866 Mdot
.36753 .46036 Mdot
.25546 .3944 Mdot
.3086 .2446 Mdot
.76222 .51791 Mdot
.66282 .60149 Mdot
.55851 .6773 Mdot
.61627 .39274 Mdot
.62652 .61344 Mdot
.57027 .38643 Mdot
.44211 .34118 Mdot
.47459 .34883 Mdot
.56316 .3844 Mdot
.48699 .63927 Mdot
.4337 .35352 Mdot
.54081 .63974 Mdot
.26953 .31384 Mdot
.19587 .54554 Mdot
.69545 .30552 Mdot
.41488 .65732 Mdot
.75441 .42655 Mdot
.73677 .38324 Mdot
.44107 .63017 Mdot
.38185 .69424 Mdot
.346 .46533 Mdot
.61963 .60561 Mdot
.613 .39287 Mdot
.16417 .4491 Mdot
.48057 .61933 Mdot
.67691 .5975 Mdot
.61062 .40017 Mdot
.48945 .38801 Mdot
.70569 .51097 Mdot
.49799 .63712 Mdot
.30665 .17573 Mdot
.61609 .59449 Mdot
.42526 .35878 Mdot
.82086 .5109 Mdot
.63984 .6138 Mdot
.39159 .41852 Mdot
.4538 .37773 Mdot
.43244 .19724 Mdot
.65356 .6054 Mdot
.39636 .30645 Mdot
.65218 .58239 Mdot
.34581 .44702 Mdot
.6915 .61841 Mdot
.44815 .31613 Mdot
.45431 .59934 Mdot
.45609 .32409 Mdot
.33577 .44877 Mdot
.47549 .32701 Mdot
.61349 .39183 Mdot
.63762 .25565 Mdot
.60188 .41081 Mdot
.44208 .43488 Mdot
.66188 .77451 Mdot
.57253 .41517 Mdot
.5029 .33351 Mdot
.43689 .67571 Mdot
.654 .53433 Mdot
.43276 .36491 Mdot
.43752 .2929 Mdot
.47277 .43211 Mdot
.66735 .59482 Mdot
.44946 .31885 Mdot
.59587 .67048 Mdot
.85971 .44303 Mdot
.54513 .61009 Mdot
.26195 .62369 Mdot
.65557 .59796 Mdot
.43311 .3695 Mdot
.76957 .50903 Mdot
.62894 .56989 Mdot
.44358 .36674 Mdot
.59726 .42383 Mdot
.58762 .3904 Mdot
.49133 .62943 Mdot
.62032 .4446 Mdot
.40512 .33987 Mdot
.69007 .34925 Mdot
.66218 .55401 Mdot
.4893 .38956 Mdot
.36022 .44787 Mdot
.43738 .3434 Mdot
.38342 .63103 Mdot
.6568 .63036 Mdot
.46703 .30475 Mdot
.22127 .52267 Mdot
.23085 .71189 Mdot
.45053 .32048 Mdot
.66537 .55541 Mdot
.68138 .58843 Mdot
.42329 .69762 Mdot
.49768 .44512 Mdot
.41835 .31587 Mdot
.61083 .24276 Mdot
.33157 .67862 Mdot
.63753 .27541 Mdot
.80158 .36712 Mdot
.43053 .66537 Mdot
.44157 .65116 Mdot
.61123 .41169 Mdot
.44887 .61227 Mdot
.70379 .5694 Mdot
.40425 .63163 Mdot
.61994 .40919 Mdot
.4522 .31449 Mdot
.4511 .59003 Mdot
.32688 .46687 Mdot
.6119 .38478 Mdot
.56801 .37799 Mdot
.454 .34472 Mdot
.62955 .57873 Mdot
.45206 .24739 Mdot
.46839 .34822 Mdot
.42713 .65167 Mdot
.64267 .26332 Mdot
.49642 .60448 Mdot
.24212 .45055 Mdot
.64691 .55208 Mdot
.42021 .35117 Mdot
.63986 .60624 Mdot
.59904 .407 Mdot
.40829 .30153 Mdot
.4591 .61627 Mdot
.45042 .36621 Mdot
.3017 .42364 Mdot
.24864 .41882 Mdot
.6832 .54922 Mdot
.30335 .4803 Mdot
.67734 .55261 Mdot
.63838 .27626 Mdot
.26532 .50138 Mdot
.35391 .46715 Mdot
.431 .33491 Mdot
.22811 .35389 Mdot
.46078 .36747 Mdot
.44506 .60402 Mdot
.43213 .61346 Mdot
.4186 .32461 Mdot
.33251 .48086 Mdot
.59466 .83607 Mdot
.52711 .51989 Mdot
.6378 .59398 Mdot
.74129 .62014 Mdot
.15507 .60258 Mdot
.61529 .37691 Mdot
.61124 .4204 Mdot
.52941 .61889 Mdot
.49228 .65457 Mdot
.5763 .37144 Mdot
.58632 .43548 Mdot
.35367 .49249 Mdot
.473 .34641 Mdot
.67182 .5285 Mdot
.60445 .37576 Mdot
.41743 .53178 Mdot
.35293 .71111 Mdot
.42972 .69811 Mdot
.45792 .56343 Mdot
.41576 .66526 Mdot
.42342 .44274 Mdot
.59709 .43479 Mdot
.45256 .63202 Mdot
.51572 .58829 Mdot
.58987 .42526 Mdot
.34355 .44797 Mdot
.60871 .54791 Mdot
.45384 .33167 Mdot
.77536 .26655 Mdot
.4609 .58721 Mdot
.448 .59809 Mdot
.573 .3942 Mdot
.77918 .33593 Mdot
.68599 .60139 Mdot
.63966 .56116 Mdot
.43847 .3501 Mdot
.47304 .42926 Mdot
.40994 .61548 Mdot
.44443 .63041 Mdot
.43651 .33284 Mdot
.63465 .25692 Mdot
.67275 .30172 Mdot
.46427 .63274 Mdot
.60335 .39503 Mdot
.4181 .39566 Mdot
.59589 .43517 Mdot
.49918 .6273 Mdot
.44271 .60577 Mdot
.4125 .61447 Mdot
.49105 .65749 Mdot
.57375 .37677 Mdot
.44794 .62739 Mdot
.38245 .61647 Mdot
.63757 .5725 Mdot
.42102 .64363 Mdot
.33427 .64847 Mdot
.47241 .62849 Mdot
.32731 .46281 Mdot
.46672 .23755 Mdot
.48364 .61609 Mdot
.42232 .64329 Mdot
.52616 .51604 Mdot
.46596 .59919 Mdot
.57779 .38518 Mdot
.67562 .58807 Mdot
.60516 .40361 Mdot
.57158 .42382 Mdot
.42986 .29694 Mdot
.35082 .4931 Mdot
.43085 .57956 Mdot
.3585 .44382 Mdot
.41155 .58239 Mdot
.50094 .62063 Mdot
.38906 .30861 Mdot
.75563 .49329 Mdot
.36904 .40586 Mdot
.46181 .61829 Mdot
.44165 .34709 Mdot
.42694 .35816 Mdot
.23414 .54288 Mdot
.52296 .67393 Mdot
.58095 .37146 Mdot
.59738 .4217 Mdot
.30164 .56699 Mdot
.71695 .52166 Mdot
.32998 .45611 Mdot
.53875 .45581 Mdot
.42176 .66912 Mdot
.46683 .63889 Mdot
.42434 .68364 Mdot
.4264 .30169 Mdot
.625 .26197 Mdot
.4603 .31897 Mdot
.64188 .29525 Mdot
.60416 .43566 Mdot
.41307 .64764 Mdot
.19025 .52047 Mdot
.6963 .56975 Mdot
.67564 .58708 Mdot
.59065 .36693 Mdot
.42615 .30768 Mdot
.40694 .68834 Mdot
.84079 .62657 Mdot
.60936 .59167 Mdot
.31331 .46834 Mdot
.44228 .63323 Mdot
.45047 .34641 Mdot
.69765 .56744 Mdot
.36433 .44011 Mdot
.41673 .63109 Mdot
.45247 .2909 Mdot
.47407 .62305 Mdot
.50624 .76844 Mdot
.63635 .57802 Mdot
.49153 .15281 Mdot
.67897 .54608 Mdot
.61645 .38854 Mdot
.58045 .42586 Mdot
.437 .60527 Mdot
.83256 .58239 Mdot
.61634 .57845 Mdot
.63556 .42307 Mdot
.31829 .4621 Mdot
.62467 .28083 Mdot
.32549 .48248 Mdot
.41032 .34131 Mdot
.34509 .47091 Mdot
.4726 .35609 Mdot
.2996 .58174 Mdot
.612 .56945 Mdot
.35639 .47358 Mdot
.7494 .30861 Mdot
.40576 .60068 Mdot
.3658 .48731 Mdot
.38686 .59324 Mdot
.7456 .60985 Mdot
.44019 .33294 Mdot
.33149 .47906 Mdot
.47267 .64991 Mdot
.16784 .47127 Mdot
.57598 .42483 Mdot
.5824 .37218 Mdot
.4171 .58458 Mdot
.46902 .36674 Mdot
.6632 .62812 Mdot
.41239 .4887 Mdot
.65514 .27515 Mdot
.44645 .62951 Mdot
.41269 .64813 Mdot
.65245 .54473 Mdot
.70041 .55246 Mdot
.4399 .60719 Mdot
.57525 .68306 Mdot
.44404 .62105 Mdot
.58405 .38894 Mdot
.68065 .60658 Mdot
.67984 .58678 Mdot
.40271 .33789 Mdot
.67749 .5497 Mdot
.47393 .56476 Mdot
.54744 .41494 Mdot
.50139 .66912 Mdot
.59335 .40541 Mdot
.47009 .47165 Mdot
.46938 .31563 Mdot
.18007 .42838 Mdot
.65854 .54343 Mdot
.42646 .64324 Mdot
.6731 .55082 Mdot
.36487 .46196 Mdot
.67191 .56987 Mdot
.66897 .61591 Mdot
.42619 .61553 Mdot
.49885 .63677 Mdot
.64394 .25884 Mdot
.49555 .44094 Mdot
.64865 .5651 Mdot
.44041 .62451 Mdot
.50113 .59273 Mdot
.44434 .58233 Mdot
.51639 .47905 Mdot
.68827 .60675 Mdot
.66389 .68894 Mdot
.21862 .48718 Mdot
.64588 .57012 Mdot
.14111 .50359 Mdot
.64205 .28187 Mdot
.62243 .27545 Mdot
.62387 .38797 Mdot
.46646 .63423 Mdot
.43463 .30884 Mdot
.48724 .60623 Mdot
.54117 .62902 Mdot
.47872 .59791 Mdot
.32162 .4593 Mdot
.43927 .57497 Mdot
.63091 .27478 Mdot
.46828 .34376 Mdot
.42139 .63411 Mdot
.45894 .58962 Mdot
.62334 .26157 Mdot
.66589 .54234 Mdot
.66858 .60992 Mdot
.41403 .22552 Mdot
.358 .45662 Mdot
.58078 .4102 Mdot
.48793 .63068 Mdot
.44004 .34805 Mdot
.45926 .32693 Mdot
.66663 .55016 Mdot
.44889 .32693 Mdot
.58747 .38257 Mdot
.45726 .61243 Mdot
.57836 .37293 Mdot
.32343 .45663 Mdot
.66759 .55605 Mdot
.48859 .62905 Mdot
.48588 .64645 Mdot
.6399 .58442 Mdot
.43629 .67566 Mdot
.35401 .49031 Mdot
.47055 .35389 Mdot
.66522 .60847 Mdot
.58723 .40997 Mdot
.40194 .33169 Mdot
.47999 .6534 Mdot
.26883 .7416 Mdot
.44642 .61436 Mdot
.47675 .64186 Mdot
.27139 .27951 Mdot
.5273 .61988 Mdot
.42063 .36017 Mdot
.63492 .55638 Mdot
.39772 .64443 Mdot
.33442 .71032 Mdot
.55701 .18271 Mdot
.40236 .31224 Mdot
.43557 .63721 Mdot
.18927 .40899 Mdot
.42817 .6372 Mdot
.51656 .37142 Mdot
.3796 .35154 Mdot
.29377 .70154 Mdot
.44758 .56316 Mdot
.56667 .38692 Mdot
.64413 .2576 Mdot
.44481 .3714 Mdot
.54509 .79292 Mdot
.42941 .62243 Mdot
.5271 .80201 Mdot
.4302 .59025 Mdot
.58969 .38865 Mdot
.36683 .64075 Mdot
.44453 .32203 Mdot
.7952 .57619 Mdot
.43273 .65445 Mdot
.68776 .60625 Mdot
.40532 .31489 Mdot
.63016 .28511 Mdot
.47722 .64858 Mdot
.3488 .44064 Mdot
.58773 .46534 Mdot
.42516 .56403 Mdot
.59059 .4057 Mdot
.45695 .64113 Mdot
.51071 .67406 Mdot
.82151 .57131 Mdot
.63438 .57974 Mdot
.60844 .42244 Mdot
.77697 .40015 Mdot
.44235 .67853 Mdot
.657 .60668 Mdot
.67077 .58778 Mdot
.34913 .44467 Mdot
.59357 .47831 Mdot
.65956 .39864 Mdot
.2022 .58776 Mdot
.63371 .77664 Mdot
.40474 .3456 Mdot
.70864 .34867 Mdot
.44551 .66835 Mdot
.55003 .54624 Mdot
.5721 .38781 Mdot
.45191 .5978 Mdot
.67412 .75414 Mdot
.66195 .56074 Mdot
.46451 .62945 Mdot
.34013 .44997 Mdot
.58451 .46988 Mdot
.57731 .52122 Mdot
.21242 .66213 Mdot
.40882 .30737 Mdot
.4623 .69065 Mdot
.42399 .57133 Mdot
.64527 .28566 Mdot
.5038 .63264 Mdot
.43784 .36884 Mdot
.27372 .32321 Mdot
.32978 .47928 Mdot
.69044 .55892 Mdot
.64083 .28279 Mdot
.40803 .65585 Mdot
.47863 .58255 Mdot
.3268 .49069 Mdot
.45724 .65093 Mdot
.80824 .55028 Mdot
.62044 .30955 Mdot
.429 .34978 Mdot
.63099 .58846 Mdot
.4227 .67289 Mdot
.62528 .26205 Mdot
.42818 .61512 Mdot
.58638 .61113 Mdot
.43912 .64683 Mdot
.64098 .47266 Mdot
.64327 .57901 Mdot
.59382 .40906 Mdot
.40799 .5899 Mdot
.47815 .60394 Mdot
.36002 .33663 Mdot
.54102 .62835 Mdot
.44809 .58872 Mdot
.70962 .56678 Mdot
.69676 .58233 Mdot
.68655 .56566 Mdot
.43603 .35779 Mdot
.75632 .50974 Mdot
.59757 .39694 Mdot
.41207 .60432 Mdot
.60376 .37546 Mdot
.49203 .54532 Mdot
.31797 .48191 Mdot
.15901 .53019 Mdot
.41803 .63732 Mdot
.68548 .56872 Mdot
.68503 .37375 Mdot
.70421 .59091 Mdot
.46888 .29722 Mdot
.60743 .39331 Mdot
.66103 .56441 Mdot
.4719 .60539 Mdot
.51215 .451 Mdot
.23943 .68482 Mdot
.60733 .411 Mdot
.43866 .68899 Mdot
.41125 .30369 Mdot
.47855 .32682 Mdot
.12471 .54542 Mdot
.59046 .43079 Mdot
.73499 .37733 Mdot
.43703 .62695 Mdot
.6953 .56932 Mdot
.57035 .40778 Mdot
.56212 .39703 Mdot
.44102 .32996 Mdot
.49701 .63216 Mdot
.47909 .61317 Mdot
.64649 .27688 Mdot
.5942 .41966 Mdot
.397 .61658 Mdot
.50798 .62857 Mdot
.24309 .31425 Mdot
.61855 .5406 Mdot
.79964 .31996 Mdot
.47779 .69887 Mdot
.63179 .78225 Mdot
.46198 .45187 Mdot
.69685 .59606 Mdot
.49023 .62186 Mdot
.41287 .66954 Mdot
.40721 .34622 Mdot
.45241 .61408 Mdot
.44549 .30524 Mdot
.61336 .41907 Mdot
.16015 .54544 Mdot
.55618 .35213 Mdot
.25949 .37809 Mdot
.45041 .60752 Mdot
.66386 .50907 Mdot
.35842 .47815 Mdot
.54909 .3808 Mdot
.68749 .59536 Mdot
.44247 .682 Mdot
.46995 .37714 Mdot
.42996 .33407 Mdot
.66638 .58076 Mdot
.73159 .40612 Mdot
.39454 .25134 Mdot
.49919 .65153 Mdot
.41652 .34189 Mdot
.58407 .33294 Mdot
.57192 .69483 Mdot
.59107 .44639 Mdot
.32666 .47684 Mdot
.45221 .31507 Mdot
.56095 .38276 Mdot
.59119 .59745 Mdot
.65898 .57377 Mdot
.6285 .55933 Mdot
.32384 .38965 Mdot
.42325 .3124 Mdot
.34675 .48144 Mdot
.74245 .52526 Mdot
.75869 .54729 Mdot
.3213 .46366 Mdot
.45129 .31357 Mdot
.69838 .57555 Mdot
.68189 .59648 Mdot
.67578 .5892 Mdot
.79173 .58025 Mdot
.64803 .5532 Mdot
.68406 .6692 Mdot
.50032 .59402 Mdot
.52693 .70339 Mdot
.43024 .6371 Mdot
.57477 .37931 Mdot
.63633 .5796 Mdot
.47147 .44024 Mdot
.47228 .67421 Mdot
.21496 .65979 Mdot
.44758 .63198 Mdot
.56374 .43403 Mdot
.46922 .63368 Mdot
.57605 .64956 Mdot
.61863 .58768 Mdot
.45978 .61896 Mdot
.58781 .44102 Mdot
.3463 .45897 Mdot
.70336 .54181 Mdot
.48311 .6153 Mdot
.66824 .48469 Mdot
.51997 .59567 Mdot
.27475 .3126 Mdot
.39326 .50453 Mdot
.31435 .46157 Mdot
.5035 .57824 Mdot
.39867 .33627 Mdot
.72898 .58406 Mdot
.51126 .71039 Mdot
.60645 .41192 Mdot
.51 .81968 Mdot
.43057 .3382 Mdot
.36687 .64449 Mdot
.5102 .64824 Mdot
.36295 .48495 Mdot
.72111 .60151 Mdot
.57286 .39065 Mdot
.41603 .65634 Mdot
.45866 .58348 Mdot
.26017 .45325 Mdot
.53006 .69476 Mdot
.43084 .58309 Mdot
.34639 .4957 Mdot
.6729 .69142 Mdot
.47945 .63208 Mdot
.42853 .28941 Mdot
.62246 .57881 Mdot
.43534 .57292 Mdot
.65976 .68535 Mdot
.43849 .62391 Mdot
.6646 .56914 Mdot
.65159 .54368 Mdot
.68757 .43608 Mdot
.317 .45679 Mdot
.43964 .64686 Mdot
.39416 .4809 Mdot
.43553 .65213 Mdot
.59706 .39362 Mdot
.49314 .61124 Mdot
.43796 .33877 Mdot
.76954 .50435 Mdot
.44734 .362 Mdot
.49069 .61088 Mdot
.6746 .59466 Mdot
.56749 .39593 Mdot
.28634 .41219 Mdot
.37442 .33446 Mdot
.68485 .67198 Mdot
.60517 .19038 Mdot
.34611 .48668 Mdot
.37461 .47621 Mdot
.62792 .42158 Mdot
.46381 .6214 Mdot
.40423 .43031 Mdot
.51527 .60477 Mdot
.47335 .63305 Mdot
.47901 .59648 Mdot
.62342 .44452 Mdot
.60805 .40276 Mdot
.4587 .33174 Mdot
.44112 .60799 Mdot
.44219 .62438 Mdot
.65002 .57052 Mdot
.34875 .45849 Mdot
.44039 .36251 Mdot
.36094 .46362 Mdot
.4612 .35275 Mdot
.13886 .46921 Mdot
.45678 .69805 Mdot
.34496 .45776 Mdot
.62649 .42647 Mdot
.67782 .55859 Mdot
.64248 .25125 Mdot
.40786 .33807 Mdot
.44466 .32004 Mdot
.44451 .62899 Mdot
.67087 .55977 Mdot
.65489 .55686 Mdot
.3663 .47313 Mdot
.58013 .41631 Mdot
.49007 .61114 Mdot
.50106 .64131 Mdot
.23027 .58832 Mdot
.41299 .31219 Mdot
.59359 .68395 Mdot
.69843 .44349 Mdot
.46433 .62037 Mdot
.6335 .57572 Mdot
.44435 .59213 Mdot
.19015 .43933 Mdot
.62881 .59223 Mdot
.49363 .65782 Mdot
.73565 .53763 Mdot
.43793 .29819 Mdot
.66121 .44696 Mdot
.47786 .57833 Mdot
.52819 .1677 Mdot
.44392 .66251 Mdot
.23431 .28975 Mdot
.73776 .3354 Mdot
.40549 .63546 Mdot
.46839 .66779 Mdot
.22076 .62875 Mdot
.43248 .63014 Mdot
.63453 .27874 Mdot
.48745 .69659 Mdot
.67579 .60993 Mdot
.42039 .46106 Mdot
.4776 .29981 Mdot
.31915 .45636 Mdot
.43796 .35023 Mdot
.29441 .4488 Mdot
.34742 .44803 Mdot
.65916 .60159 Mdot
.47557 .66615 Mdot
.35687 .6989 Mdot
.47508 .30681 Mdot
.5181 .62599 Mdot
.59682 .39239 Mdot
.46625 .28992 Mdot
.45821 .31052 Mdot
.59278 .41273 Mdot
.42403 .59481 Mdot
.38302 .76794 Mdot
.37982 .29734 Mdot
.41075 .19124 Mdot
.57163 .39732 Mdot
.59339 .38647 Mdot
.78096 .52197 Mdot
.32002 .45508 Mdot
.24844 .47353 Mdot
.61988 .52194 Mdot
.60206 .3832 Mdot
.30936 .54453 Mdot
.46385 .37338 Mdot
.66467 .49042 Mdot
.62007 .60596 Mdot
.44759 .69617 Mdot
.47399 .6049 Mdot
.58297 .4204 Mdot
.36903 .70356 Mdot
.80778 .50759 Mdot
.60279 .41157 Mdot
.39971 .58746 Mdot
.58324 .47205 Mdot
.64403 .26676 Mdot
.64861 .2764 Mdot
.31671 .47095 Mdot
.37882 .2563 Mdot
.64972 .58546 Mdot
.36896 .4786 Mdot
.632 .46593 Mdot
.44655 .64642 Mdot
.60178 .41953 Mdot
.6418 .2495 Mdot
.58282 .3983 Mdot
.33322 .45946 Mdot
.3134 .46943 Mdot
.63672 .57399 Mdot
.68565 .60122 Mdot
.62359 .79015 Mdot
.31737 .58192 Mdot
.42514 .63635 Mdot
.45175 .78686 Mdot
.66474 .5525 Mdot
.5339 .68301 Mdot
.33432 .4411 Mdot
.34908 .45583 Mdot
.53291 .75328 Mdot
.49116 .6451 Mdot
.47774 .39573 Mdot
.48305 .62318 Mdot
.26147 .51153 Mdot
.49585 .66182 Mdot
.44458 .3291 Mdot
.42343 .65591 Mdot
.46452 .24891 Mdot
.44727 .67405 Mdot
.45888 .58776 Mdot
.46776 .32963 Mdot
.39564 .66894 Mdot
.43622 .33794 Mdot
.49829 .62839 Mdot
.36093 .49699 Mdot
.44008 .3484 Mdot
.27599 .63965 Mdot
.51261 .49961 Mdot
.62608 .26682 Mdot
.33227 .44825 Mdot
.36102 .44718 Mdot
.33965 .68143 Mdot
.68488 .59819 Mdot
.60071 .57579 Mdot
.4636 .6224 Mdot
.4583 .37421 Mdot
.61198 .41135 Mdot
.44221 .62315 Mdot
.43001 .68213 Mdot
.45528 .57644 Mdot
.65747 .5609 Mdot
.42592 .30861 Mdot
.34098 .46145 Mdot
.4214 .34829 Mdot
.36033 .30255 Mdot
.47666 .35104 Mdot
.52516 .59657 Mdot
.40289 .67025 Mdot
.55862 .60141 Mdot
.51637 .80845 Mdot
.76907 .60913 Mdot
.66102 .57889 Mdot
.63464 .26164 Mdot
.31591 .4765 Mdot
.7275 .62836 Mdot
.68984 .57977 Mdot
.44191 .31613 Mdot
.47419 .62283 Mdot
.38684 .60812 Mdot
.59491 .51893 Mdot
.72384 .61295 Mdot
.32305 .6704 Mdot
.47309 .32748 Mdot
.64012 .27281 Mdot
.76375 .51424 Mdot
.73451 .6139 Mdot
.46187 .43763 Mdot
.46625 .59276 Mdot
.34833 .4401 Mdot
.69757 .56726 Mdot
.3202 .4022 Mdot
.59074 .42241 Mdot
.49754 .44376 Mdot
.45095 .60866 Mdot
.70092 .36741 Mdot
.67378 .59447 Mdot
.33594 .45127 Mdot
.58353 .42117 Mdot
.32019 .45151 Mdot
.64672 .28047 Mdot
.39982 .22654 Mdot
.44893 .6542 Mdot
.43424 .59279 Mdot
.62843 .4294 Mdot
.65221 .58616 Mdot
.41311 .41475 Mdot
.25649 .45076 Mdot
.41642 .33657 Mdot
.3975 .41152 Mdot
.69991 .59259 Mdot
.61356 .63568 Mdot
.42651 .3523 Mdot
.59167 .36691 Mdot
.42427 .44706 Mdot
.62008 .41771 Mdot
.48477 .61933 Mdot
.68234 .57442 Mdot
.59433 .4318 Mdot
.35457 .35445 Mdot
.18449 .39305 Mdot
.57596 .62835 Mdot
.41432 .64499 Mdot
.16222 .54018 Mdot
.27353 .29391 Mdot
.36011 .68095 Mdot
.61701 .3952 Mdot
.43307 .60344 Mdot
.50392 .64654 Mdot
.42934 .65481 Mdot
.61158 .42706 Mdot
.3205 .32228 Mdot
.43648 .32292 Mdot
.44544 .63575 Mdot
.36234 .45067 Mdot
.44648 .33803 Mdot
.39737 .34903 Mdot
.45594 .37121 Mdot
.66257 .61439 Mdot
.49206 .6578 Mdot
.72191 .48676 Mdot
.21764 .30569 Mdot
.6058 .4051 Mdot
.62605 .26778 Mdot
.43319 .59083 Mdot
.73129 .70622 Mdot
.68672 .56647 Mdot
.41633 .33373 Mdot
.44902 .59741 Mdot
.34313 .32293 Mdot
.63048 .30172 Mdot
.47089 .34512 Mdot
.68199 .59823 Mdot
.35892 .67144 Mdot
.45148 .61507 Mdot
.44707 .66117 Mdot
.65081 .59171 Mdot
.41932 .21631 Mdot
.75894 .49909 Mdot
.45361 .59024 Mdot
.59431 .4104 Mdot
.85483 .49494 Mdot
.46169 .57748 Mdot
.64668 .63047 Mdot
.62434 .28111 Mdot
.67685 .47413 Mdot
.59394 .68901 Mdot
.53882 .61659 Mdot
.17513 .53814 Mdot
.35248 .59517 Mdot
.14975 .52753 Mdot
.35701 .42579 Mdot
.55585 .30552 Mdot
.13825 .44979 Mdot
.58884 .44207 Mdot
.54613 .67614 Mdot
.26854 .68296 Mdot
.73831 .43106 Mdot
.39771 .50485 Mdot
.57721 .20767 Mdot
.36778 .33941 Mdot
.67962 .23118 Mdot
.45088 .36816 Mdot
.25053 .51113 Mdot
.48812 .6054 Mdot
.28637 .28045 Mdot
.58081 .66606 Mdot
.81993 .5374 Mdot
.15201 .50865 Mdot
.39023 .4969 Mdot
.25647 .69694 Mdot
.19671 .40602 Mdot
.39673 .75797 Mdot
.60701 .50785 Mdot
.61935 .24594 Mdot
.74975 .53066 Mdot
.28197 .48563 Mdot
.4529 .70389 Mdot
.48447 .24282 Mdot
.31925 .28265 Mdot
.68882 .70639 Mdot
.83568 .53518 Mdot
.41222 .34899 Mdot
.62139 .58474 Mdot
.22722 .59282 Mdot
.71985 .55935 Mdot
.54258 .41938 Mdot
.17484 .53952 Mdot
.23081 .31974 Mdot
.5779 .6487 Mdot
.56374 .16561 Mdot
.54633 .77714 Mdot
.64631 .80848 Mdot
.53375 .49999 Mdot
.63225 .55219 Mdot
.56782 .27536 Mdot
.7589 .54855 Mdot
.63468 .34119 Mdot
.7066 .64101 Mdot
.31715 .44017 Mdot
.29503 .64277 Mdot
.6756 .59827 Mdot
.58337 .69711 Mdot
.62734 .29124 Mdot
.64674 .45089 Mdot
.38766 .31772 Mdot
.185 .45706 Mdot
.66599 .2494 Mdot
.686 .48945 Mdot
.68804 .33681 Mdot
.25681 .73309 Mdot
.34061 .55223 Mdot
.21573 .4022 Mdot
.64745 .38725 Mdot
.36451 .5706 Mdot
.77518 .47608 Mdot
.32585 .59587 Mdot
.76509 .565 Mdot
.35949 .7958 Mdot
.32652 .24291 Mdot
.28782 .74391 Mdot
.70854 .55276 Mdot
.43017 .58416 Mdot
.20298 .46977 Mdot
.63577 .7731 Mdot
.31336 .46121 Mdot
.23611 .69425 Mdot
.34941 .43788 Mdot
.70151 .54456 Mdot
.73678 .41591 Mdot
.63577 .64806 Mdot
.49986 .32779 Mdot
.37715 .48377 Mdot
.49869 .57908 Mdot
.56953 .87775 Mdot
.17716 .56847 Mdot
.68517 .44919 Mdot
.24284 .31191 Mdot
.64265 .40064 Mdot
.45046 .41419 Mdot
.61411 .42044 Mdot
.16337 .41501 Mdot
.68628 .58504 Mdot
.18258 .34251 Mdot
.18125 .3851 Mdot
.81483 .4318 Mdot
.68604 .84191 Mdot
.68857 .28439 Mdot
.53269 .70182 Mdot
.35989 .71865 Mdot
.3114 .68458 Mdot
.79293 .48563 Mdot
.8078 .40813 Mdot
.63462 .4499 Mdot
.40121 .21386 Mdot
.15095 .45337 Mdot
.28886 .53465 Mdot
.29605 .31196 Mdot
.75225 .44201 Mdot
.50443 .48675 Mdot
.62661 .62417 Mdot
.49488 .50267 Mdot
.56915 .5538 Mdot
.26721 .71991 Mdot
.70515 .72459 Mdot
.84453 .58644 Mdot
.32582 .42159 Mdot
.78793 .3538 Mdot
.24856 .33416 Mdot
.26554 .61775 Mdot
.67894 .64445 Mdot
.72653 .46272 Mdot
.51997 .59237 Mdot
.74914 .50309 Mdot
.38199 .68026 Mdot
.30169 .4806 Mdot
.77245 .52198 Mdot
.53296 .34839 Mdot
.2702 .47842 Mdot
.19935 .55502 Mdot
.69547 .51582 Mdot
.6575 .61145 Mdot
.33497 .61598 Mdot
.32601 .54824 Mdot
.24512 .31766 Mdot
.77508 .39937 Mdot
.39841 .1977 Mdot
.78992 .40586 Mdot
.51425 .60196 Mdot
.53708 .68194 Mdot
.42217 .69928 Mdot
.33217 .57543 Mdot
.49874 .58677 Mdot
.68263 .34936 Mdot
.25755 .29197 Mdot
.68217 .74892 Mdot
.28089 .46874 Mdot
.48418 .80326 Mdot
.3716 .21679 Mdot
.20773 .47801 Mdot
.73654 .34287 Mdot
.44411 .74009 Mdot
.48048 .86343 Mdot
.4549 .33924 Mdot
.30479 .54567 Mdot
.55992 .38012 Mdot
.32014 .3943 Mdot
.30591 .72551 Mdot
.81345 .44543 Mdot
.26251 .2859 Mdot
.73553 .46887 Mdot
.3888 .36597 Mdot
.51614 .41467 Mdot
.48017 .29341 Mdot
.47091 .80207 Mdot
.38719 .63816 Mdot
.4726 .53539 Mdot
.37293 .47143 Mdot
.6392 .76136 Mdot
.22091 .4736 Mdot
.52826 .20872 Mdot
.51901 .57848 Mdot
.53461 .24012 Mdot
.64133 .27613 Mdot
.50528 .44594 Mdot
.12508 .53217 Mdot
.52939 .65861 Mdot
.70725 .30041 Mdot
.34044 .23322 Mdot
.41446 .44025 Mdot
.23299 .3875 Mdot
.70939 .41095 Mdot
.32364 .76924 Mdot
.20219 .34353 Mdot
.41121 .24689 Mdot
.1596 .5547 Mdot
.39599 .17431 Mdot
.367 .79008 Mdot
.48366 .78722 Mdot
.55048 .40908 Mdot
.20989 .26595 Mdot
.4258 .32235 Mdot
.53631 .82342 Mdot
.64598 .76895 Mdot
.32679 .34009 Mdot
.68954 .62213 Mdot
.37691 .59236 Mdot
.658 .23385 Mdot
.61133 .58049 Mdot
.49716 .57698 Mdot
.21935 .69134 Mdot
.37834 .81384 Mdot
.23054 .69922 Mdot
.38206 .22562 Mdot
.15664 .54714 Mdot
.25319 .65539 Mdot
.68742 .66594 Mdot
.22552 .52415 Mdot
.49549 .6177 Mdot
.28432 .55829 Mdot
.69383 .2916 Mdot
.38464 .36214 Mdot
.65251 .36191 Mdot
.69249 .61472 Mdot
.3231 .75672 Mdot
.12282 .5668 Mdot
.56118 .75394 Mdot
.63773 .70126 Mdot
.55997 .53806 Mdot
.32156 .57019 Mdot
.40005 .5283 Mdot
.49072 .22498 Mdot
.24799 .32392 Mdot
.26218 .67682 Mdot
.30207 .52716 Mdot
.56271 .21853 Mdot
.4947 .29775 Mdot
.77472 .34211 Mdot
.17787 .44345 Mdot
.25108 .62572 Mdot
.80071 .40638 Mdot
.43614 .74565 Mdot
.81165 .49095 Mdot
.47907 .20301 Mdot
.43553 .40597 Mdot
.33417 .5374 Mdot
.4679 .31173 Mdot
.2877 .54003 Mdot
.59245 .49046 Mdot
.21807 .56186 Mdot
.34746 .61705 Mdot
.28129 .53135 Mdot
.4891 .29123 Mdot
.19059 .64005 Mdot
.44352 .16145 Mdot
.44324 .82387 Mdot
.50313 .16987 Mdot
.38192 .68264 Mdot
.47526 .58387 Mdot
.30083 .25355 Mdot
.17933 .63528 Mdot
.22052 .31073 Mdot
.70073 .36183 Mdot
.34809 .35233 Mdot
.57136 .43671 Mdot
.46834 .81947 Mdot
.51476 .18933 Mdot
.2179 .35084 Mdot
.76516 .59328 Mdot
.62216 .38549 Mdot
.74475 .47385 Mdot
.49707 .81612 Mdot
.39455 .76194 Mdot
.59019 .70955 Mdot
.45114 .70219 Mdot
.56073 .68817 Mdot
.624 .57132 Mdot
.70778 .35577 Mdot
.3264 .58501 Mdot
.45349 .34381 Mdot
.26787 .64602 Mdot
.50354 .54691 Mdot
.52213 .59514 Mdot
.41845 .40286 Mdot
.61599 .61186 Mdot
.54498 .80967 Mdot
.62989 .45429 Mdot
.13318 .46591 Mdot
.70426 .31577 Mdot
.38151 .56123 Mdot
.34707 .58441 Mdot
.32133 .40963 Mdot
.73845 .4914 Mdot
.62503 .4216 Mdot
.15831 .48169 Mdot
.46272 .49579 Mdot
.33725 .60847 Mdot
.56255 .68971 Mdot
.24972 .45286 Mdot
.43677 .68449 Mdot
.69589 .41815 Mdot
.71658 .67515 Mdot
.49733 .43726 Mdot
.67695 .53221 Mdot
.61082 .60667 Mdot
.64717 .18303 Mdot
.48947 .27135 Mdot
.7696 .37393 Mdot
.1625 .47986 Mdot
.61859 .41369 Mdot
.70565 .59754 Mdot
.27582 .53778 Mdot
.25536 .41667 Mdot
.70966 .69674 Mdot
.43649 .38297 Mdot
.34871 .52461 Mdot
.51198 .20199 Mdot
.16472 .54166 Mdot
.21013 .63936 Mdot
.82447 .57106 Mdot
.69466 .55441 Mdot
.24001 .44673 Mdot
.25797 .43651 Mdot
.69042 .55502 Mdot
.7171 .62028 Mdot
.60617 .51329 Mdot
.14054 .53427 Mdot
.73905 .50184 Mdot
.47373 .17988 Mdot
.42092 .44647 Mdot
.33497 .31863 Mdot
.30054 .41375 Mdot
.32549 .52683 Mdot
.16567 .47866 Mdot
.57377 .70702 Mdot
.34704 .75236 Mdot
.45335 .70539 Mdot
.63937 .78862 Mdot
.47368 .82165 Mdot
.52401 .49067 Mdot
.60482 .63327 Mdot
.53415 .35566 Mdot
.42538 .64969 Mdot
.25372 .7307 Mdot
.27257 .30505 Mdot
.77741 .5462 Mdot
.62398 .45915 Mdot
.47185 .65873 Mdot
.50763 .60867 Mdot
.37385 .70509 Mdot
.68718 .46203 Mdot
.41682 .81598 Mdot
.27176 .46754 Mdot
.39089 .69837 Mdot
.57382 .68086 Mdot
.70878 .3028 Mdot
.18862 .46579 Mdot
.2606 .32268 Mdot
.56549 .48545 Mdot
.6947 .29634 Mdot
.47642 .41724 Mdot
.46671 .1767 Mdot
.51629 .24562 Mdot
.24458 .63996 Mdot
.64007 .51997 Mdot
.70771 .45858 Mdot
.33396 .40388 Mdot
.44741 .58694 Mdot
.73133 .40648 Mdot
.19209 .41694 Mdot
.83333 .62478 Mdot
.77818 .46721 Mdot
.20564 .68108 Mdot
.55139 .58718 Mdot
.71103 .46643 Mdot
.3236 .74542 Mdot
.81623 .67622 Mdot
.48513 .23354 Mdot
.2599 .70558 Mdot
.50502 .40744 Mdot
.15805 .4967 Mdot
.55535 .40375 Mdot
.70729 .51061 Mdot
.49434 .8011 Mdot
.13923 .52754 Mdot
.2102 .43782 Mdot
.17439 .48311 Mdot
.41272 .74715 Mdot
.15131 .56195 Mdot
.75949 .59301 Mdot
.68902 .23278 Mdot
.40628 .30115 Mdot
.66611 .33222 Mdot
.45883 .76734 Mdot
.56313 .57923 Mdot
.30617 .53884 Mdot
.75621 .30098 Mdot
.73389 .63895 Mdot
.42787 .76232 Mdot
.26284 .57832 Mdot
.70796 .42571 Mdot
.35047 .58099 Mdot
.2048 .36701 Mdot
.68074 .22914 Mdot
.28395 .42019 Mdot
.74423 .36553 Mdot
.40159 .22291 Mdot
.68255 .46136 Mdot
.52362 .28571 Mdot
.21404 .40308 Mdot
.45487 .20411 Mdot
.37316 .52673 Mdot
.67819 .17928 Mdot
.32626 .28544 Mdot
.60227 .51565 Mdot
.30464 .74948 Mdot
.25401 .32044 Mdot
.76023 .60329 Mdot
.81336 .5326 Mdot
.62515 .79959 Mdot
.29814 .58425 Mdot
.4793 .59868 Mdot
.15149 .5763 Mdot
.28628 .62716 Mdot
.25103 .70854 Mdot
.34139 .21903 Mdot
.53944 .71165 Mdot
.53492 .62411 Mdot
.43153 .3718 Mdot
.56059 .51953 Mdot
.25666 .56819 Mdot
.26321 .69525 Mdot
.58966 .81613 Mdot
.3933 .41114 Mdot
.5545 .29338 Mdot
.44307 .3864 Mdot
.44205 .72257 Mdot
.68314 .2959 Mdot
.70115 .44716 Mdot
.31041 .43049 Mdot
.47755 .27308 Mdot
.32022 .55943 Mdot
.59144 .68649 Mdot
.38926 .76138 Mdot
.80436 .45819 Mdot
.53192 .38888 Mdot
.41161 .35159 Mdot
.20972 .59981 Mdot
.33603 .26878 Mdot
.68158 .35434 Mdot
.39938 .79297 Mdot
.72871 .45798 Mdot
.24584 .52076 Mdot
.21407 .51041 Mdot
.79436 .47572 Mdot
.62114 .23646 Mdot
.42043 .78373 Mdot
.64194 .7871 Mdot
.48861 .38433 Mdot
.47558 .5488 Mdot
.13987 .47137 Mdot
.32782 .53124 Mdot
.21409 .5395 Mdot
.52189 .50341 Mdot
.65972 .73999 Mdot
.48808 .74768 Mdot
.28623 .66266 Mdot
.47689 .4303 Mdot
.53539 .8729 Mdot
.65901 .62478 Mdot
.25922 .73721 Mdot
.58568 .41348 Mdot
.78922 .63228 Mdot
.44847 .25992 Mdot
.56496 .49421 Mdot
.44894 .44734 Mdot
.69309 .41994 Mdot
.63635 .481 Mdot
.39111 .21967 Mdot
.81445 .47467 Mdot
.47613 .35348 Mdot
.4007 .44864 Mdot
.47492 .18642 Mdot
.19605 .57734 Mdot
.39743 .6314 Mdot
.34589 .26858 Mdot
.51833 .48862 Mdot
.38622 .37286 Mdot
.30272 .25469 Mdot
.55817 .3445 Mdot
.41201 .58135 Mdot
.32175 .57408 Mdot
.275 .71692 Mdot
.19031 .37458 Mdot
.80062 .53088 Mdot
.3826 .68138 Mdot
.548 .40617 Mdot
.29647 .70039 Mdot
.17988 .55969 Mdot
.49451 .38872 Mdot
.70183 .49706 Mdot
.33563 .54785 Mdot
.2903 .78658 Mdot
.3703 .80639 Mdot
.42441 .81485 Mdot
.41002 .43978 Mdot
.63838 .53857 Mdot
.72241 .71407 Mdot
.21506 .53509 Mdot
.6579 .34146 Mdot
.32675 .26626 Mdot
.31057 .54857 Mdot
.79512 .68616 Mdot
.70252 .64762 Mdot
.36088 .29777 Mdot
.48974 .74945 Mdot
.61376 .78327 Mdot
.56122 .42124 Mdot
.28798 .58883 Mdot
.42211 .50163 Mdot
.62125 .39394 Mdot
.70689 .43033 Mdot
.65868 .48612 Mdot
.21375 .54254 Mdot
.70298 .6888 Mdot
.40188 .70183 Mdot
.19179 .54676 Mdot
.62028 .5548 Mdot
.31335 .40419 Mdot
.28821 .42738 Mdot
.40478 .49842 Mdot
.42053 .33889 Mdot
.54097 .65083 Mdot
.51615 .44087 Mdot
.49377 .4146 Mdot
.52331 .84091 Mdot
.35548 .43875 Mdot
.66657 .61933 Mdot
.78224 .59412 Mdot
.7 .56129 Mdot
.16716 .62468 Mdot
.49139 .22648 Mdot
.57086 .67853 Mdot
.39903 .25753 Mdot
.56293 .24463 Mdot
.6524 .81715 Mdot
.44729 .79742 Mdot
.5225 .51906 Mdot
.72086 .62652 Mdot
.66236 .54639 Mdot
.49438 .31759 Mdot
.63069 .24454 Mdot
.60398 .70114 Mdot
.70342 .287 Mdot
.23169 .51521 Mdot
.64758 .54302 Mdot
.34825 .29973 Mdot
.37722 .56867 Mdot
.12859 .50381 Mdot
.43948 .3678 Mdot
.44782 .85029 Mdot
.40743 .67728 Mdot
.32825 .73645 Mdot
.29246 .25967 Mdot
.77326 .50215 Mdot
.39344 .40322 Mdot
.60309 .21119 Mdot
.40253 .63332 Mdot
.41909 .71002 Mdot
.67345 .60117 Mdot
.24233 .48234 Mdot
.34874 .46863 Mdot
.32023 .64768 Mdot
.61538 .38237 Mdot
.80099 .38653 Mdot
.68628 .30391 Mdot
.62046 .59609 Mdot
.4534 .50395 Mdot
.21368 .45403 Mdot
.65396 .50141 Mdot
.51598 .48677 Mdot
.21913 .62377 Mdot
.70291 .70255 Mdot
.64996 .54308 Mdot
.40313 .79775 Mdot
.26488 .46107 Mdot
.16905 .39293 Mdot
.4094 .54745 Mdot
.55081 .50838 Mdot
.66591 .5049 Mdot
.69975 .41125 Mdot
.59961 .69065 Mdot
.24626 .32883 Mdot
.33177 .6066 Mdot
.74604 .53726 Mdot
.28104 .53365 Mdot
.38387 .66022 Mdot
.55066 .29386 Mdot
.66536 .31852 Mdot
.77519 .70816 Mdot
.51912 .77285 Mdot
.76483 .48218 Mdot
.64745 .6355 Mdot
.70553 .29901 Mdot
.66243 .62137 Mdot
.29357 .36932 Mdot
.69008 .71144 Mdot
.42443 .25253 Mdot
.15218 .43686 Mdot
.24901 .31585 Mdot
.58065 .53954 Mdot
.41882 .38846 Mdot
.35249 .60173 Mdot
.37844 .56975 Mdot
.49028 .45508 Mdot
.40484 .62378 Mdot
.41762 .72471 Mdot
.79581 .53003 Mdot
.68395 .37086 Mdot
.37427 .60024 Mdot
.14401 .50212 Mdot
.17704 .37961 Mdot
.16866 .59053 Mdot
.46779 .40051 Mdot
.67294 .61533 Mdot
.33364 .77691 Mdot
.62362 .6695 Mdot
.20392 .36499 Mdot
.46485 .77174 Mdot
.62722 .17211 Mdot
.29733 .72227 Mdot
.52909 .35435 Mdot
.81373 .42415 Mdot
.66332 .41644 Mdot
.30723 .25623 Mdot
.68817 .232 Mdot
.30468 .50131 Mdot
.31412 .24697 Mdot
.5668 .87691 Mdot
.49951 .7839 Mdot
.67433 .48705 Mdot
.48439 .73706 Mdot
.36745 .57323 Mdot
.70171 .27397 Mdot
.49291 .60697 Mdot
.46294 .30054 Mdot
.38617 .39786 Mdot
.31965 .55336 Mdot
.53205 .5766 Mdot
.70841 .27945 Mdot
.25308 .56183 Mdot
.25147 .50349 Mdot
.26159 .42589 Mdot
.27406 .7012 Mdot
.60842 .69409 Mdot
.42328 .57291 Mdot
.67817 .52932 Mdot
.31867 .47194 Mdot
.29148 .46003 Mdot
.49715 .64931 Mdot
.39352 .39705 Mdot
.62097 .51268 Mdot
.21858 .69382 Mdot
.27658 .3949 Mdot
.25683 .37323 Mdot
.60992 .59848 Mdot
.69294 .45015 Mdot
.19744 .49155 Mdot
.73743 .42535 Mdot
.72527 .29054 Mdot
.70008 .72977 Mdot
.16571 .54839 Mdot
.72541 .47111 Mdot
.28143 .50468 Mdot
.58563 .83798 Mdot
.58701 .37771 Mdot
.54974 .80493 Mdot
.25377 .66384 Mdot
.7276 .43284 Mdot
.69834 .54528 Mdot
.52561 .33384 Mdot
.56654 .3102 Mdot
.71963 .43011 Mdot
.34479 .2303 Mdot
.23362 .46159 Mdot
.51335 .7389 Mdot
.20008 .61675 Mdot
.41473 .30478 Mdot
.30082 .52812 Mdot
.51161 .30404 Mdot
.69166 .25488 Mdot
.6957 .51354 Mdot
.13871 .48259 Mdot
.48163 .44943 Mdot
.2882 .64016 Mdot
.44571 .65694 Mdot
.66386 .68673 Mdot
.68811 .38955 Mdot
.50227 .30704 Mdot
.76871 .38333 Mdot
.63847 .60291 Mdot
.69273 .3275 Mdot
.61287 .29233 Mdot
.29489 .60288 Mdot
.4942 .53899 Mdot
.63602 .52651 Mdot
.37543 .43625 Mdot
.64505 .29073 Mdot
.39371 .63092 Mdot
.30422 .66226 Mdot
.49494 .30871 Mdot
.52227 .80233 Mdot
.49315 .78893 Mdot
.20993 .60322 Mdot
.2724 .32341 Mdot
.6758 .35155 Mdot
.45624 .77573 Mdot
.64146 .46972 Mdot
.67833 .65543 Mdot
.74778 .40833 Mdot
.48087 .5784 Mdot
.29678 .36531 Mdot
.69987 .60041 Mdot
.19789 .58821 Mdot
.58021 .60681 Mdot
.27392 .63579 Mdot
.529 .47071 Mdot
.19839 .46783 Mdot
.48492 .48216 Mdot
.29442 .26002 Mdot
.66377 .4104 Mdot
.32624 .58763 Mdot
.63638 .40179 Mdot
.50656 .40359 Mdot
.78258 .4639 Mdot
.16801 .43672 Mdot
.80964 .45698 Mdot
.36499 .71982 Mdot
.75554 .47573 Mdot
.6579 .77361 Mdot
.32598 .231 Mdot
.31479 .59453 Mdot
.49224 .45613 Mdot
.39553 .53568 Mdot
.64057 .45894 Mdot
.63948 .2521 Mdot
.31279 .36169 Mdot
.61974 .68281 Mdot
.2799 .35018 Mdot
.38796 .29222 Mdot
.40172 .60516 Mdot
.73641 .70049 Mdot
.19027 .59197 Mdot
.74103 .62108 Mdot
.55082 .49414 Mdot
.35927 .39112 Mdot
.29669 .61349 Mdot
.83486 .33931 Mdot
.25017 .72852 Mdot
.4476 .65662 Mdot
.42363 .45303 Mdot
.31526 .64009 Mdot
.4484 .30626 Mdot
.60609 .70756 Mdot
.20724 .60003 Mdot
.59919 .3859 Mdot
.34319 .36333 Mdot
.63022 .3227 Mdot
.68937 .41143 Mdot
.28207 .66357 Mdot
.62335 .44277 Mdot
.18325 .65149 Mdot
.35272 .25644 Mdot
.69275 .38655 Mdot
.74637 .23625 Mdot
.69361 .35195 Mdot
.61162 .56116 Mdot
.20572 .43288 Mdot
.18697 .63384 Mdot
.41236 .44142 Mdot
.32337 .39017 Mdot
.49772 .79098 Mdot
.32739 .59652 Mdot
.26152 .50074 Mdot
.7424 .36408 Mdot
.70437 .33602 Mdot
.69595 .24076 Mdot
.5635 .24265 Mdot
.54346 .84581 Mdot
.56711 .70139 Mdot
.21228 .6492 Mdot
.48607 .23013 Mdot
.80317 .67379 Mdot
.16327 .41596 Mdot
.277 .56193 Mdot
.72281 .29744 Mdot
.21538 .41345 Mdot
.33074 .67404 Mdot
.74021 .67659 Mdot
.46792 .23075 Mdot
.70157 .71456 Mdot
.55045 .23783 Mdot
.76011 .40549 Mdot
.28497 .53668 Mdot
.63083 .78106 Mdot
.47808 .44555 Mdot
.24582 .67039 Mdot
.78608 .33806 Mdot
.34911 .5732 Mdot
.35354 .3666 Mdot
.33414 .70294 Mdot
.1865 .55233 Mdot
.2067 .40417 Mdot
.47601 .45857 Mdot
.57221 .87185 Mdot
.26589 .71668 Mdot
.74691 .42778 Mdot
.49757 .59124 Mdot
.14901 .42906 Mdot
.43913 .47214 Mdot
.45789 .77893 Mdot
.32093 .25857 Mdot
.28253 .4504 Mdot
.64827 .51095 Mdot
.44455 .57776 Mdot
.43896 .79608 Mdot
.59284 .62768 Mdot
.61033 .78667 Mdot
.37899 .40344 Mdot
.34436 .58837 Mdot
.79099 .35055 Mdot
.31417 .6992 Mdot
.37811 .57328 Mdot
.69957 .59617 Mdot
.19989 .66508 Mdot
.3921 .75253 Mdot
.5386 .66194 Mdot
.50889 .71799 Mdot
.81172 .46471 Mdot
.63839 .21429 Mdot
.37684 .65749 Mdot
.73515 .49242 Mdot
.30913 .54026 Mdot
.2202 .51646 Mdot
.46957 .7924 Mdot
.70493 .83195 Mdot
.28258 .26588 Mdot
.66266 .62852 Mdot
.55443 .79746 Mdot
.40075 .47195 Mdot
.1723 .59241 Mdot
.55866 .21556 Mdot
.3082 .41509 Mdot
.83077 .4941 Mdot
.33487 .6408 Mdot
.478 .67956 Mdot
.37228 .22651 Mdot
.16621 .42281 Mdot
.80281 .35995 Mdot
.1411 .4695 Mdot
.53097 .63062 Mdot
.46763 .69476 Mdot
.87971 .55046 Mdot
.16064 .52091 Mdot
.53722 .62707 Mdot
.81663 .49426 Mdot
.70273 .61787 Mdot
.49126 .61552 Mdot
.62316 .3121 Mdot
.34358 .53526 Mdot
.25751 .50548 Mdot
.14049 .53012 Mdot
.62794 .54946 Mdot
.39131 .39427 Mdot
.56076 .38253 Mdot
.45561 .44376 Mdot
.38807 .60793 Mdot
.59289 .43249 Mdot
.25285 .52203 Mdot
.42722 .47299 Mdot
.59767 .46654 Mdot
.3607 .52501 Mdot
.45289 .16625 Mdot
.5646 .60486 Mdot
.57544 .53884 Mdot
.4169 .74192 Mdot
.73913 .63644 Mdot
.25499 .56395 Mdot
.23872 .55187 Mdot
.32319 .24295 Mdot
.42972 .14344 Mdot
.44244 .2691 Mdot
.38774 .57296 Mdot
.72301 .54804 Mdot
.60786 .68289 Mdot
.50491 .73222 Mdot
.52592 .392 Mdot
.64917 .26103 Mdot
.52896 .61428 Mdot
.38444 .55862 Mdot
.61241 .38018 Mdot
.25274 .74743 Mdot
.49471 .60153 Mdot
.5528 .72807 Mdot
.19505 .39589 Mdot
.31811 .40332 Mdot
.56824 .61751 Mdot
.40271 .63905 Mdot
.75935 .59537 Mdot
.42965 .47692 Mdot
.35305 .64748 Mdot
.29214 .42023 Mdot
.17902 .5937 Mdot
.5726 .60028 Mdot
.53898 .72395 Mdot
.44952 .63044 Mdot
.37546 .48375 Mdot
.66571 .49201 Mdot
.43404 .80705 Mdot
.4624 .52908 Mdot
.20079 .36188 Mdot
.28015 .44462 Mdot
.27296 .46548 Mdot
.54908 .68185 Mdot
.24903 .70908 Mdot
.77328 .46299 Mdot
.54033 .70659 Mdot
.78742 .54448 Mdot
.53009 .30283 Mdot
.26345 .5762 Mdot
.44791 .37952 Mdot
.37528 .59891 Mdot
.71519 .60931 Mdot
.1343 .55698 Mdot
.45525 .80176 Mdot
.58995 .35719 Mdot
.48636 .38371 Mdot
.65508 .65726 Mdot
.45639 .44775 Mdot
.71028 .20897 Mdot
.5712 .20437 Mdot
.18672 .6568 Mdot
.23405 .4753 Mdot
.72205 .54542 Mdot
.71025 .4221 Mdot
.54885 .62693 Mdot
.46475 .33088 Mdot
.17513 .59377 Mdot
.41542 .53752 Mdot
.74882 .39472 Mdot
.49992 .62669 Mdot
.76598 .54728 Mdot
.37088 .57293 Mdot
.43296 .39461 Mdot
.47585 .31915 Mdot
.80475 .51284 Mdot
.19047 .42784 Mdot
.43118 .47821 Mdot
.63366 .18663 Mdot
.26422 .6999 Mdot
.15834 .47945 Mdot
.43835 .38525 Mdot
.80079 .62038 Mdot
.64347 .63592 Mdot
.37066 .5778 Mdot
.63482 .38673 Mdot
.36694 .73091 Mdot
.72346 .42781 Mdot
.22602 .50466 Mdot
.65036 .46904 Mdot
.61111 .50207 Mdot
.58469 .11364 Mdot
.27609 .55077 Mdot
.67426 .64161 Mdot
.726 .39459 Mdot
.14927 .47894 Mdot
.361 .51353 Mdot
.41405 .19015 Mdot
.48183 .25178 Mdot
.38309 .62433 Mdot
.70859 .68062 Mdot
.34393 .74311 Mdot
.59369 .32787 Mdot
.59875 .84357 Mdot
.32886 .27199 Mdot
.28199 .48014 Mdot
.50368 .30662 Mdot
.69777 .55853 Mdot
.69302 .62019 Mdot
.48859 .20943 Mdot
.52155 .15343 Mdot
.36124 .65181 Mdot
.17451 .55126 Mdot
.69678 .78102 Mdot
.25108 .47086 Mdot
.15678 .56579 Mdot
.63106 .354 Mdot
.71021 .62645 Mdot
.2497 .55386 Mdot
.37883 .41296 Mdot
.43387 .30178 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0Yoooool2o`00
0:3ooooo000Looooo`;o0000TOooool2o`0001Gooooo0_l0002Pooooo`007?ooool00ol0003ooooo
ooooo`2@ooooo`;o00002Oooool2o`000:cooooo000Looooo`03o`000?oooooooooo08Wooooo0_l0
000@ooooo`;o0000[?ooool001cooooo00?o0000ooooooooool0Ooooool2o`0000Sooooo0_l0002n
ooooo`007?ooool00ol0003oooooooooo`1oooooo`;o0000>Oooool2o`0008gooooo000Looooo`03
o`000?oooooooooo0;[ooooo0_l0002=ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo07Oooooo0_l0003@ooooo`007?ooool00ol0003oooooooooo`1g
ooooo`;o0000Boooool2o`0008?ooooo000Looooo`03o`000?oooooooooo0<Cooooo0_l00023oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0<Gooooo
0_l00022ooooo`007?ooool00ol0003oooooooooo`35ooooo`;o0000P_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`28ooooo`;o0000_oooool001co
oooo00?o0000ooooooooool0R?ooool2o`000;oooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo0_l0001[ooooo`;o0000<?ooool2o`0000;ooooo0ol00003ooooo`;o00008ooo
ool2o`0007cooooo000Looooo`03o`000?oooooooooo06[ooooo0_l0000`ooooo`;o00000_ooool3
o`0000?ooooo0_l0000Sooooo`;o0000O?ooool001cooooo00?o0000ooooooooool0VOooool2o`00
0003ooooool0003o000000_ooooo0_l00006ooooo`;o0000U_ooool001cooooo00?o0000oooooooo
ool0S?ooool2o`0000_ooooo0_l0000>ooooo`;o00001_ooool4o`0009Cooooo000Looooo`03o`00
0?oooooooooo08cooooo0_l00002ooooo`;o00000oooool2o`0001cooooo0_l0002Dooooo`007?oo
ool00ol0003oooooooooo`2?ooooo`?o00000oooool2o`00013ooooo1Ol00007ooooo`;o0000U?oo
ool001cooooo00?o0000ooooooooool0Soooool4o`0000gooooo1?l00003ooooo`Go00000_ooool2
o`000003ooooool0003o000000Kooooo0_l0000=ooooo`;o0000Ooooool001cooooo00?o0000oooo
ooooool0OOooool2o`0001;ooooo0_l0000=ooooo`Co00002_ooool2o`000003ooooool0003o0000
00Kooooo0_l0000=ooooo`;o0000Ooooool001cooooo00?o0000ooooooooool0H?ooool2o`0001_o
oooo0_l0000Eooooo`;o0000/oooool001cooooo00?o0000ooooooooool0H?ooool2o`0003;ooooo
1?l00011ooooo`;o0000K_ooool001cooooo00?o0000ooooooooool0U_ooool2o`00017ooooo0_l0
0006ooooo`;o00002Oooool2o`00013ooooo0_l00009ooooo`;o0000K_ooool001cooooo00?o0000
ooooooooool0Uoooool2o`00013ooooo0_l00006ooooo`;o00002Oooool2o`0000Gooooo0_l00005
ooooo`;o00000_ooool2o`0007Wooooo000Looooo`03o`000?oooooooooo08?ooooo0_l00002oooo
o`;o00003_ooool2o`0000[ooooo0_l0000Looooo`Co00001Oooool2o`0007gooooo00001_oooooo
k^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`21
ooooo`Co00000_ooool2o`0000Kooooo0_l0000Booooo`;o00007?ooool2o`0008Kooooo00001_oo
ooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1_ooool00ol0003oooooooooo`21ooooo`?o00002oooool2o`0001;ooooo0_l0000iooooo`;o0000
JOooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^
kP07ooooo`03o`000?oooooooooo07kooooo0_l00002ooooo`;o00001Oooool2o`0005?ooooo0_l0
001Yooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7o
k^k^00Kooooo0ol0001nooooo`;o00000_ooool2o`0000Gooooo0_l0000=ooooo`;o00002Oooool2
o`0000Wooooo0_l0000Hooooo`;o0000Ooooool00003ooooool0003ooooo00;ooooo00?o0000oooo
ooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo05Kooooo0_l0000hoooo
o`;o00001_ooool2o`0000Wooooo0_l00009ooooo`;o00001_ooool2o`000003ooooool0003o0000
00;o00002oooool2o`0007oooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Fooooo`;o0000>?ooool2o`0001Ko
oooo0_l0000<ooooo`Oo00009_ooool2o`0006Cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMg
M`_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo07kooooo0_l0000K
ooooo`;o00002oooool2o`0000kooooo0_l00005ooooo`?o00008Oooool2o`0006Cooooo00001_oo
ooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`00
0?oooooooooo05?ooooo0_l0000Yooooo`?o00006_ooool2o`0002;ooooo1?l00009ooooo`;o0000
Noooool001cooooo00?o0000ooooooooool0Doooool2o`0001Wooooo0_l00005ooooo`;o000000?o
ooooo`000?l000001Oooool2o`0000;ooooo0ol0000[ooooo`Co00003?ooool2o`0000Wooooo0_l0
001kooooo`007?ooool00ol0003oooooooooo`1[ooooo`;o000000?oooooo`000?l000000_ooool2
o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000001_ooool3o`0002_ooooo1?l0
002Dooooo`007?ooool00ol0003oooooooooo`1[ooooo`;o00001Oooool2o`0000Gooooo1?l00002
ooooo`;o00001?ooool3o`0001gooooo0_l0002Rooooo`007?ooool00ol0003oooooooooo`1?oooo
o`;o00007oooool2o`0000?ooooo0_l000000ooooooo0000o`000003o`000004ooooool0003o0000
o`0000;ooooo1Ol0000;ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Oooooo0_l0000L
ooooo`;o000000?oooooo`000?l00000POooool001cooooo00?o0000ooooooooool0Coooool2o`00
01_ooooo0_l00002ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`;o000000?ooooo
o`000?l000000oooool2o`0000kooooo1Ol00002ooooo`Co00001oooool2o`0001cooooo0_l00000
0ooooooo0000o`00000Aooooo`;o0000K_ooool001cooooo00?o0000ooooooooool0HOooool2o`00
00?ooooo0_l00003ooooo`?o00008?ooool2o`0000Cooooo1?l00002ooooo`;o0000=_ooool2o`00
00Gooooo0_l000000ooooooo0000o`00001[ooooo`007?ooool00ol0003oooooooooo`1Qooooo`;o
00000oooool2o`0000?ooooo0_l0000Looooo`;o00000oooool2o`0000Gooooo0ol000001?oooooo
0000o`000?l0000Zooooo`;o00002_ooool2o`0000Gooooo0_l000000ooooooo0000o`00000Aoooo
o`;o0000F?ooool001cooooo00?o0000ooooooooool0ROooool2o`0000Wooooo0ol00002ooooo`;o
00002_ooool2o`0000Sooooo0_l0000Eooooo`;o00009oooool2o`0005Sooooo000Looooo`03o`00
0?oooooooooo06Gooooo0ol0000/ooooo`;o00000oooool3o`0000Wooooo0_l00003ooooo`;o0000
0oooool2o`0000;ooooo0_l0000>ooooo`?o00006?ooool2o`0006Wooooo000Looooo`03o`000?oo
oooooooo04Wooooo0_l0000Fooooo`;o00000_ooool3o`0003;ooooo0_l00008ooooo`;o00001?oo
ool2o`0000Oooooo0_l0000>ooooo`Co00000_ooool2o`0001?ooooo0_l0001Yooooo`007?ooool0
0ol0003oooooooooo`19ooooo`;o00005_ooool3o`0001kooooo0_l0000;ooooo`;o00000_ooool2
o`0000oooooo1?l0000;ooooo`;o00004?ooool2o`0000;ooooo0_l00006ooooo`;o0000M_ooool0
01cooooo0_l0001Sooooo`Co00005_ooool2o`0000Cooooo0_l00004ooooo`;o00001Oooool2o`00
00;ooooo0_l00004ooooo`;o00002oooool2o`0000gooooo0_l0000Cooooo`Wo00000_ooool2o`00
07;ooooo000Looooo`03o`000?oooooooooo05kooooo0ol00003ooooo`;o00004?ooool2o`0000Co
oooo0_l00008ooooo`Co00003oooool2o`0001[ooooo0_l0000Aooooo`co000000?oooooo`000?l0
00001_ooool2o`0006[ooooo000Looooo`03o`000?oooooooooo05kooooo1?l00002ooooo`?o0000
2?ooool2o`0000Gooooo0ol00005ooooo`;o00001_ooool2o`0003kooooo3_l00009ooooo`;o0000
J_ooool001cooooo00?o0000ooooooooool0F?ooool2o`000004ooooool0003o0000o`0000;ooooo
0_l00002ooooo`?o00002?ooool2o`0000Kooooo0_l00005ooooo`;o000000?oooooo`000?l00000
2oooool2o`0001Oooooo0_l0000Mooooo`ko0000MOooool001cooooo00?o0000ooooooooool0@Ooo
ool2o`0001Gooooo0_l000000ooooooo0000o`000002o`0000Gooooo0ol0000Jooooo`Co00002Ooo
ool2o`0001Oooooo0_l0000Nooooo`Go000000?oooooo`000?l000001?l0001fooooo`007?ooool0
0ol0003oooooooooo`10ooooo`?o00005Oooool2o`0000;ooooo0ol00004ooooo`;o000000?ooooo
o`000?l000001_ooool2o`0001?ooooo0_l00012ooooo`_o00009_ooool2o`0004oooooo000Loooo
o`03o`000?oooooooooo043ooooo0_l0000Fooooo`;o00000_ooool2o`0000Gooooo0_l000001?oo
oooo0000o`000?ooool2o`0000;ooooo0ol0000Cooooo`;o00001oooool2o`0003Sooooo1?l00000
0ooooooo0000o`000005o`0000;ooooo0_l0000Rooooo`;o0000Coooool001cooooo00?o0000oooo
ooooool0Ioooool8o`0001Cooooo0_l00007ooooo`;o00002Oooool2o`0000;ooooo0_l0000Yoooo
o`co00000_ooool2o`0000[ooooo0_l0000Fooooo`;o0000Coooool001cooooo00?o0000oooooooo
ool0Ioooool2o`000003ooooool0003o000000;o00004_ooool2o`0000Gooooo0_l00002ooooo`;o
00002_ooool2o`0000;ooooo0_l0000Hooooo`;o00003oooool>o`0000cooooo0_l0001Wooooo`00
7?ooool00ol0003oooooooooo`1Dooooo`;o000000?oooooo`000?l000009oooool2o`0000Gooooo
0_l00002ooooo`;o00006?ooool2o`0000kooooo0_l0000=oooooa3o00002oooool2o`000003oooo
ool0003o000006Gooooo000Looooo`03o`000?oooooooooo05Cooooo0_l000000ooooooo0000o`00
0002o`0000Wooooo0_l0000Yooooo`;o00002_ooool2o`0000Sooooo0_l0000Mooooo`ko00003Ooo
ool2o`000004ooooool0003o0000ooooo`Co0000H?ooool001cooooo00?o0000ooooooooool0D_oo
ool2o`0000Gooooo0_l00009ooooo`Co00007_ooool2o`0000Oooooo0_l00007ooooo`;o000000Co
ooooo`000?l0003ooooo0_l00006ooooo`;o00003oooool2o`0000cooooo3_l00009ooooo`;o0000
1oooool4o`00063ooooo000Looooo`03o`000?oooooooooo05;ooooo0_l0000Booooo`;o00007_oo
ool4o`0000;ooooo0ol00009ooooo`;o00001?ooool2o`0000Kooooo0_l0000?ooooo`;o00003?oo
ool;o`000003ooooool0003o000000Wooooo0_l00003ooooo`;o0000I_ooool001cooooo00?o0000
ooooooooool0B?ooool2o`0000Kooooo0_l00002ooooo`;o00007Oooool2o`0000Gooooo0_l0000;
ooooo`?o000000?oooooo`000?l000001?l00003ooooo`?o00001?ooool2o`000004ooooool0003o
0000o`0001Cooooo0_l0000<ooooo`;o000000?oooooo`000?l000002?l0000>ooooo`;o000000?o
ooooo`000?l000001Oooool2o`0005oooooo000Looooo`03o`000?oooooooooo04Sooooo0_l00006
ooooo`Oo00007?ooool2o`0000Gooooo0_l0000;ooooo`[o00000oooool3o`000004ooooool0003o
0000ooooo`;o000000Coooooo`000?l0003o00003_ooool3o`0000?ooooo0_l0000<ooooo`;o0000
00?oooooo`000?l000001?l000001?oooooo0000o`000?l0000>ooooo`;o00002?ooool2o`0005oo
oooo000Looooo`03o`000?oooooooooo053ooooo1ol0000Jooooo`;o000000?oooooo`000?l00000
0_ooool2o`0000?ooooo0_l00007ooooo`_o00000oooool3o`000003ooooool0003o000000?ooooo
0ol0000:ooooo`;o00000oooool3o`0001Oooooo0ol000001?oooooo0000o`000?ooool2o`0000So
oooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`00001Mooooo`00
7?ooool2o`0004Oooooo0_l00006ooooo`Co00006oooool2o`0000;ooooo0_l000001Ooooooo0000
o`000?l0003ooooo00;o00000oooool2o`000003ooooool0003o000001Oo00001?ooool2o`0000_o
oooo0_l00002ooooo`;o00008?ooool2o`0000Cooooo0_l00002ooooo`;o00000_ooool2o`000004
ooooool0003o0000o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`00
0?l00000EOooool001cooooo00?o0000ooooooooool0A_ooool2o`000003ooooool0003o000000?o
oooo1?l0000Kooooo`;o00000_ooool2o`0000;ooooo0_l00008ooooo`co000000?oooooo`000?l0
00000_l000000ooooooo0000o`000003o`000003ooooool0003o000000Wooooo0_l00004ooooo`;o
00001?ooool2o`0001Wooooo0_l0000;ooooo`?o00000_ooool2o`0000Cooooo0ol0000;ooooo`;o
000000?oooooo`000?l00000EOooool001cooooo00?o0000ooooooooool0@oooool2o`0000Cooooo
0_l0000:ooooo`Co00004_ooool2o`0000Cooooo0_l00002ooooo`Co00001?ooool>o`000003oooo
ool0003o000000So000000?oooooo`000?l000001_ooool5o`0000Cooooo0_l00007ooooo`;o0000
5_ooool2o`000003ooooool0003o000000Wooooo0_l00002ooooo`;o000000?oooooo`000?l00000
0_ooool2o`0006Gooooo000Looooo`03o`000?oooooooooo04?ooooo1?l00008ooooo`;o00001?oo
ool4o`0001;ooooo0_l00008ooooo`Co00000_ooool:o`000003ooooool0003o0000017o00001?oo
ool5o`0000oooooo0_l000000ooooooo0000o`00000@ooooo`;o00001?ooool2o`00013ooooo0_l0
000@ooooo`;o0000Eoooool001cooooo00?o0000ooooooooool0A?ooool3o`0000Cooooo0_l00002
ooooo`Co000000?oooooo`000?l000000_l00004ooooo`;o00003?ooool2o`0000oooooo1_l00000
0ooooooo0000o`00000Do`0000Gooooo0_l0000Eooooo`;o00004?ooool3o`0002Oooooo0_l0001G
ooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00000_ooool6o`0000;ooooo0_l000000ooo
oooo0000o`000002o`0000Cooooo0_l0000<ooooo`;o00004OoooolKo`0000Cooooo0_l0000Yoooo
o`Co00005_ooool2o`0006Kooooo000Looooo`03o`000?oooooooooo04Oooooo2?l00009ooooo`;o
00003oooool2o`0000oooooo2?l000001Ooooooo0000o`000?l0003ooooo01;o00000oooool3o`00
02[ooooo0_l00009ooooo`;o00002oooool2o`0001?ooooo0_l00008ooooo`;o0000Aoooool001co
oooo00?o0000ooooooooool0Aoooool2o`0000;ooooo0ol000000ooooooo0000o`000006o`000004
ooooool0003o0000o`0000Wooooo0_l00003ooooo`;o000000?oooooo`000?l000002Oooool2o`00
0003ooooool0003o000001Wo000000Coooooo`000?l0003o00001?ooool2o`0002[ooooo0_l00009
ooooo`;o00008?ooool2o`0000Sooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`17oooo
o`;o00001?ooool:o`0000;ooooo0_l00009ooooo`;o00001_ooool2o`0000Wooooo1Ol00003oooo
oa?o00000_ooool4o`0001cooooo0_l00002ooooo`;o00003Oooool4o`0000;ooooo0_l0001joooo
o`007?ooool00ol0003oooooooooo`17ooooo`?o00000_ooool3o`0000Kooooo0_l0000Qooooo`;o
00000oooool6o`000003ooooool0003o000001Go000000Coooooo`000?l0003ooooo0_l0000Aoooo
o`Co00000_ooool2o`0000?ooooo0_l00008ooooo`;o00000_ooool4o`0000kooooo0_l00006oooo
o`;o0000H_ooool001cooooo00?o0000ooooooooool0;Oooool2o`0000kooooo0_l00006ooooo`;o
000000?oooooo`000?l000000_ooool2o`0001cooooo0_l00004ooooo`;o00000oooool2o`0000Ko
oooo7_l000001?oooooo0000o`000?ooool2o`00017ooooo0_l00009ooooo`;o00003?ooool2o`00
00Sooooo0_l00006ooooo`;o00001_ooool2o`0001_ooooo0_l00015ooooo`007?ooool00ol0003o
ooooooooo`0]ooooo`;o00003_ooool2o`0000Kooooo0_l00002ooooo`;o000000Coooooo`000?l0
003o00006oooool2o`0000Cooooo0_l00003ooooo`Co00001?oooolMo`0000Kooooo0_l00005oooo
o`;o00000oooool2o`0000cooooo0_l0000?ooooo`;o00002?ooool2o`0000[ooooo0_l00009oooo
o`;o00002_ooool2o`0000Sooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`19ooooo`;o
000000Coooooo`000?l0003o00008_ooool2o`0000;ooooo1?l00002oooooaCo00000_ooool7o`00
0003ooooool0003o000000Gooooo0_l00005ooooo`;o00000oooool2o`0000Gooooo0_l00005oooo
o`;o00003oooool2o`0000oooooo0_l00003ooooo`;o00002Oooool2o`0000[ooooo0ol000000ooo
oooo0000o`00001;ooooo`007?ooool00ol0003oooooooooo`1Eooooo`;o00002oooool2o`0000;o
oooo0_l00009ooooo`Go00001OoooolDo`000003ooooool0003o000000Wo00006?ooool2o`00017o
oooo0_l00002ooooo`;o00001_ooool2o`0000Sooooo0ol00002ooooo`;o00005_ooool2o`000003
ooooool0003o000000gooooo0_l0000looooo`007?ooool00ol0003oooooooooo`0hooooo`;o0000
1?ooool2o`0000Wooooo0_l0000:ooooo`;o00002oooool2o`0000;ooooo0_l0000:ooooo`Co0000
0_ooool2o`0000?ooooo4_l000000ooooooo0000o`00000:o`0001Kooooo0_l0000Booooo`;o0000
0_ooool2o`0000Kooooo0_l00009ooooo`;o00003?ooool2o`000003ooooool0003o000000Kooooo
1?l0000Aooooo`;o0000??ooool001cooooo00?o0000ooooooooool0>?ooool2o`0000Cooooo0_l0
0009ooooo`;o0000;Oooool2o`0000;ooooo8?l0000Fooooo`;o0000=oooool2o`000004ooooool0
003o0000o`0000Gooooo1?l0001?ooooo`007?ooool2o`0004Cooooo0_l0000?ooooo`;o000000?o
ooooo`000?l000006oooool2o`0000Kooooo7Ol0000@ooooo`;o00007oooool2o`0000kooooo1?l0
0003ooooo`?o00002?ooool2o`000003ooooool0003o000000cooooo0_l0001:ooooo`007?ooool0
0ol0003oooooooooo`10ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00
0008ooooo`?o000000?oooooo`000?l000002Oooool2o`0000Wooooo0_l00005ooooo`;o00000_oo
ool2o`0000?ooooo0_l00002oooooaSo000000?oooooo`000?l000003Oooool2o`0000Kooooo0_l0
000Fooooo`?o00003?ooool8o`000004ooooool0003o0000o`0000Sooooo0_l0000>ooooo`?o0000
B_ooool001cooooo00?o0000ooooooooool0>oooool2o`0000?ooooo1?l00002ooooo`;o000000?o
ooooo`000?l000001_ooool5o`0000Sooooo0_l00002ooooo`;o00002Oooool5o`0000Kooooo0_l0
0004oooooa_o000000?oooooo`000?l000000_l00003ooooo`;o00001Oooool4o`0000Gooooo0_l0
000;ooooo`;o00002Oooool2o`000003ooooool0003o000000[ooooo1?l000000ooooooo0000o`00
0005o`0001Sooooo0_l00009ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0>oooool2
o`0000;ooooo0_l000000ooooooo0000o`000006ooooo`;o00001Oooool5o`0000Sooooo0_l0000?
ooooo`?o00001Oooool2o`0000Gooooo1?l00002oooooaCo00001?ooool2o`0000?ooooo1?l00003
ooooo`Go00002_ooool2o`0000?ooooo1?l00002ooooo`;o00002?ooool2o`0000cooooo0_l00000
1?oooooo0000o`000?ooool4o`0000[ooooo0_l0000<ooooo`;o00000oooool2o`0000Cooooo0_l0
0010ooooo`007?ooool00ol0003oooooooooo`0nooooo`?o00002Oooool2o`0001Kooooo0_l0000<
ooooo`Co00000oooool4o`0000Wooooo5_l00003ooooo`;o00001?ooool2o`0000Kooooo0_l00009
ooooo`?o00000oooool2o`000004ooooool0003o0000ooooo`;o00003?ooool2o`0000Sooooo0_l0
0004ooooo`;o00003?ooool2o`0000Kooooo0_l00004ooooo`Co000000?oooooo`000?l00000A_oo
ool001cooooo00?o0000ooooooooool0?_ooool3o`0000oooooo0_l0000;ooooo`;o00000oooool2
o`0000Sooooo0_l00004ooooo`;o00001Oooool4o`0000Sooooo5Ol00003ooooo`;o00005_ooool3
o`0000?ooooo0_l00002ooooo`;o00001?ooool2o`0000Oooooo1?l00008ooooo`;o00001?ooool3
o`0000[ooooo1ol00002ooooo`;o00001_ooool2o`0004Wooooo000Looooo`03o`000?oooooooooo
03oooooo0_l0000?ooooo`;o00002_ooool3o`0000gooooo0_l000000ooooooo0000o`000002oooo
o`;o00001_ooool4o`0000Kooooo5Ol00002ooooo`Go00003_ooool2o`0000Cooooo0_l000001?oo
oooo0000o`000?ooool5o`0000Gooooo0_l00003ooooo`?o000000?oooooo`000?l000004?ooool3
o`0000[ooooo2?l0000<ooooo`;o00001oooool2o`0003gooooo000Looooo`03o`000?oooooooooo
03oooooo0_l0000;ooooo`;o00003_ooool2o`00017ooooo0_l00002ooooo`;o00001oooool6o`00
00?ooooo4_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000oooool2o`00
00Wooooo0_l00006ooooo`Co000000?oooooo`000?l000001Ol00007ooooo`?o00003Oooool2o`00
00Cooooo0_l0000Aooooo`;o00003?ooool2o`0000Oooooo0_l0000mooooo`007?ooool00ol0003o
ooooooooo`0jooooo`;o00003?ooool6o`0000;ooooo0_l0000Xooooo`?o000000?oooooo`000?l0
00000_l00004oooooa3o00003_ooool2o`0000Gooooo0_l00008ooooo`Ko000000?oooooo`000?l0
00001Ol0000Gooooo`?o00006?ooool3o`00057ooooo000Looooo`03o`000?oooooooooo03[ooooo
0_l00004ooooo`;o00001_ooool4o`0000;ooooo1ol0000Uooooo`?o00002Oooool2o`0000;ooooo
1Ol000000ooooooo0000o`000005o`000003ooooool0003o000000Oooooo0_l00008ooooo`;o0000
2?oooolAo`0001Cooooo0ol00005ooooo`;o00001oooool2o`0000Sooooo1Ol00008ooooo`;o0000
AOooool001cooooo00?o0000ooooooooool0=_ooool2o`0000Oooooo0ol0000<ooooo`Oo0000>Ooo
ool4o`000003ooooool0003o000000;o000000?oooooo`000?l000001oooool2o`0000cooooo0_l0
00001?oooooo0000o`000?oooolAo`0001;ooooo0_l00008ooooo`;o00001oooool2o`0000Sooooo
0_l000000ooooooo0000o`000008ooooo`;o0000AOooool001cooooo00?o0000ooooooooool0=_oo
ool2o`0000Oooooo0ol00002ooooo`;o00001Oooool2o`0000Cooooo0_l00004ooooo`;o00008_oo
ool3o`0000_ooooo0ol00002ooooo`;o00000oooool4o`0000?ooooo0ol00004ooooo`;o00002ooo
ool3o`000003ooooool0003o000000ko000000Coooooo`000?l0003o00004_ooool2o`0001;ooooo
0_l00008ooooo`Co00006?ooool2o`0003Gooooo000Looooo`03o`000?oooooooooo03Oooooo0_l0
000;ooooo`;o00000_ooool2o`000003ooooool0003o000000Kooooo0_l00002ooooo`;o00008Ooo
ool4o`0000_ooooo1Ol00003ooooo`;o00000oooool2o`0000;ooooo0ol00004ooooo`;o00002ooo
ool2o`0000;ooooo5_l00002ooooo`;o00000oooool2o`0000Oooooo0_l00003ooooo`;o00002Ooo
ool2o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`;o00002?ooool2o`00013ooooo0_l0
000eooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00003oooool2o`0000Wooooo0_l0000@
ooooo`;o00004?ooool2o`000003ooooool0003o000000;o00001_ooool2o`0000Cooooo1?l00003
ooooo`;o000000?oooooo`000?l000000_l00003ooooo`Co00002_ooool2o`0000Kooooo6?l00000
0ooooooo0000o`000003ooooo`;o00002oooool3o`0000Wooooo0_l00005ooooo`;o00000_ooool2
o`0000Gooooo0_l00004ooooo`;o00000_ooool2o`0004?ooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003ooooooooo
o`0cooooo`;o00000oooool2o`0000Gooooo0_l00006ooooo`?o00002Oooool2o`00013ooooo0_l0
000:ooooo`;o00001?ooool2o`0000Wooooo1?l0000<ooooo`Ko00000oooool4o`0000Sooooo1?l0
0006ooooo`;o000000?oooooo`000?l000004ol00003ooooo`Co00003?ooool2o`00017ooooo0_l0
0002ooooo`;o00001Oooool2o`0000Sooooo1?l00011ooooo`0000KoooooogMgMonHV9SooooooiRH
V?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03?ooooo
0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o000000Kooooo0ol00005ooooo`;o0000
1Oooool2o`0000cooooo0_l00005ooooo`?o00000oooool2o`0000Sooooo0ol00004ooooo`Co0000
0oooool2o`0000Oooooo0_l00002ooooo`?o00003_ooool2o`0000Wooooo5_l00002ooooo`Ko0000
2?ooool2o`0000kooooo0_l00005ooooo`;o00005Oooool2o`00047ooooo00000ooooooo410@oooo
o`02ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006ooooo`03o`000?oooooooooo03cooooo0ol0
000;ooooo`;o000000?oooooo`000?l000000_l00005ooooo`;o00003?ooool2o`0000Gooooo0ol0
000;ooooo`Go00001_ooool2o`0000?ooooo0_l0000<ooooo`;o00006OoooolEo`0000?ooooo1?l0
0004ooooo`?o00000oooool3o`0000gooooo0_l00005ooooo`;o00001oooool3o`0004kooooo0000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001ooo
ool3o`0003gooooo0_l00003ooooo`;o00001_ooool2o`000004ooooool0003o0000ooooo`;o0000
4_ooool2o`0001?ooooo1Ol00006ooooo`;o00003_ooool2o`0001Sooooo0_l000000ooooooo0000
o`00000Do`0000;ooooo1_l00003ooooo`?o00001?ooool2o`000003ooooool0003o000000_ooooo
0_l00003ooooo`Co00001_ooool3o`0004kooooo00000ooooooo0000ooooo`02ooooo`03o`000?oo
oooooooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`0looooo`;o0000
00Coooooo`000?l0003ooooo0_l0000<ooooo`;o00004?ooool4o`0000?ooooo0_l00009ooooo`;o
000000?oooooo`000?l000000oooool4o`0000Cooooo0_l00004ooooo`Co00001_ooool2o`0000So
oooo0_l000000ooooooo0000o`00000;ooooo`;o000000?oooooo`000?l000002?l000000ooooooo
0000o`00000:o`000003ooooool0003o000000Co00003Oooool2o`0000Cooooo0_l00005ooooo`?o
00000_ooool4o`000003ooooool0003o000000Sooooo0_l000000ooooooo0000o`000017ooooo`00
00?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo
00?o0000ooooooooool0>_ooool4o`000003ooooool0003o000001kooooo0_l000000ooooooo0000
o`000005ooooo`;o00001?ooool2o`0000?ooooo0_l000000ooooooo0000o`000005ooooo`;o0000
2_ooool4o`00013ooooo1Ol0000;oooooako00005_ooool2o`0000Gooooo0ol00002ooooo`?o0000
0_ooool2o`0000Sooooo0_l000000ooooooo0000o`000003o`0000_ooooo0_l0000gooooo`0000Ko
ooooogMgMonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000oooooooo
ool0>_ooool2o`0001gooooo0_l00004ooooo`;o00001?ooool2o`0000Sooooo0_l00003ooooo`;o
00001Oooool5o`0001;ooooo0_l0000<ooooo`;o00003OoooolKo`0000;ooooo0_l00006ooooo`;o
00000oooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000005ooooo`;o
00000_ooool3o`000003ooooool0003o000000gooooo1?l0000;ooooo`;o000000?oooooo`000?l0
0000=?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06oooo
o`03o`000?oooooooooo037ooooo0_l00004ooooo`;o00002Oooool2o`000004ooooool0003o0000
o`00017ooooo0_l00003ooooo`Co00000oooool2o`0000gooooo0_l000001?oooooo0000o`000?oo
ool5o`0000?ooooo1?l00009ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Gooooo0_l0
0008oooooaWo00001Oooool2o`0000Kooooo0_l00003ooooo`;o000000?oooooo`000?l000000_oo
ool2o`000003ooooool0003o000000cooooo0ol00006ooooo`;o00002?ooool2o`0000gooooo0_l0
000dooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00001?ooool2o`0000;ooooo0_l00005
ooooo`;o000000Coooooo`000?l0003o00001oooool2o`0000gooooo1?l0000Eooooo`;o000000Co
ooooo`000?l0003o00000_ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l00000
1Oooool3o`0000Kooooo1?l00002ooooo`;o00001Oooool2o`0000Kooooo1?l00002oooooa;o0000
00?oooooo`000?l000000_l00002ooooo`Co00001Oooool2o`0000Sooooo0_l0000<ooooo`;o0000
0oooool2o`0000Oooooo0_l00008ooooo`;o00002oooool2o`0003Kooooo000Looooo`03o`000?oo
oooooooo037ooooo0_l00008ooooo`;o00004?ooool4o`0000Sooooo1?l00009ooooo`;o00000ooo
ool2o`0000[ooooo0_l00002ooooo`;o00000_ooool2o`0000Kooooo0_l00005ooooo`;o00001ooo
ool4o`0000_ooooo0_l00004ooooo`;o00001OoooolLo`0000Gooooo0_l00007ooooo`?o00003?oo
ool2o`0000kooooo0_l00006ooooo`;o00000oooool2o`0000Kooooo0_l0000fooooo`007?ooool0
0ol0003oooooooooo`0booooo`;o00006Oooool2o`0000Sooooo1_l000000ooooooo0000o`000006
ooooo`;o00000oooool2o`0000[ooooo0_l0000>ooooo`;o00001_ooool2o`0000Oooooo0_l0000<
ooooo`;o00001?ooool2o`0000Gooooo6_l0000@ooooo`;o00001?ooool2o`0000Gooooo0_l0000@
ooooo`;o00001_ooool3o`0000;ooooo0_l00009ooooo`;o0000<oooool001cooooo00?o0000oooo
ooooool0<_ooool4o`0000Cooooo0_l0000Eooooo`;o00001?ooool2o`000003ooooool0003o0000
00;ooooo0_l0000@ooooo`;o00002oooool2o`0000;ooooo0_l000000ooooooo0000o`000004oooo
o`;o00000oooool2o`0000Oooooo0_l0000IoooooaOo000000?oooooo`000?l000005Oooool3o`00
00;ooooo1ol000000ooooooo0000o`000003o`00017ooooo0_l0000=ooooo`?o0000<_ooool001co
oooo00?o0000ooooooooool0;Oooool2o`0000Gooooo0_l000001?oooooo0000o`000?ooool4o`00
01?ooooo1?l00005ooooo`;o00001Oooool2o`0000gooooo1?l00009ooooo`;o000000Goooooo`00
0?l0003o0000ooooo`02o`0000?ooooo0ol00003ooooo`;o00001Oooool3o`0001_ooooo5ol0000G
ooooo`;o00000_ooool5o`000004ooooool0003o0000ooooo`Go00008Oooool2o`0003;ooooo000L
ooooo`03o`000?oooooooooo02gooooo0_l00008ooooo`;o00000oooool2o`000003ooooool0003o
000001;ooooo0_l0000<ooooo`?o00003_ooool2o`0000Kooooo0_l00004ooooo`;o00001oooool2
o`0000Cooooo0ol00002ooooo`Oo00006?ooool6o`000003ooooool0003o000000oo000000?ooooo
o`000?l000005?ooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l0
000Booooo`;o0000@_ooool001cooooo00?o0000ooooooooool0;_ooool2o`0000;ooooo1Ol00008
ooooo`;o00001?ooool2o`0000Oooooo1?l0000@ooooo`;o000000?oooooo`000?l000001?ooool5
o`000003ooooool0003o000000;o000000?oooooo`000?l000000_ooool2o`0000Cooooo0ol00003
ooooo`Go000000?oooooo`000?l000001?l00002ooooo`Oo00006?ooool2o`000003ooooool0003o
0000017o00000oooool2o`0000_ooooo0_l000000ooooooo0000o`000007ooooo`;o00000_ooool2
o`0000cooooo0_l0000;ooooo`?o0000@_ooool001cooooo00?o0000ooooooooool0;_ooool2o`00
00;ooooo1Ol00003ooooo`;o00001Oooool2o`0000;ooooo0_l00007ooooo`Co00004OoooolBo`00
0003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000004o`000003ooooool0003o0000
00?o000000?oooooo`000?l000001_l000000ooooooo0000o`000005ooooo`Co00004oooool2o`00
0003ooooool0003o0000017o00004?ooool2o`000003ooooool0003o000000Cooooo0_l000000ooo
oooo0000o`00000@ooooo`;o00002oooool4o`00047ooooo000Looooo`03o`000?oooooooooo03Go
oooo0_l00003ooooo`;o00001Oooool2o`00023ooooo4_l00004ooooo`;o000000Coooooo`000?l0
003ooooo1_l000000ooooooo0000o`000005ooooo`;o00000oooool2o`000004ooooool0003o0000
o`0000Cooooo1?l00004ooooo`;o00004?ooool;o`0000Cooooo1?l0000Iooooo`;o00003Oooool2
o`0000Kooooo0_l0000;ooooo`;o00000_ooool2o`0000Oooooo0_l0000dooooo`007?ooool00ol0
003oooooooooo`0eooooo`Co00007_ooool2o`0000Oooooo0_l00002oooooa7o00001?ooool2o`00
00Cooooo0_l000001?oooooo0000o`000?ooool5o`000003ooooool0003o000000?ooooo0_l00004
ooooo`Co00000oooool:o`0000Sooooo0_l00009ooooo`Ko00001_ooool3o`0001Kooooo0ol0000?
ooooo`;o00001_ooool2o`0000Wooooo0_l00004ooooo`;o00001oooool2o`0003Cooooo000Loooo
o`03o`000?oooooooooo03;ooooo0_l00002ooooo`?o00004Oooool2o`0000_ooooo0_l00003oooo
o`;o00000_oooolEo`0000Cooooo0_l00003ooooo`?o00001?ooool5o`000004ooooool0003o0000
ooooo`Go00000oooool5o`0000?ooooo2Ol00008ooooo`;o00002oooool2o`0000Sooooo0ol00008
ooooo`Co00001_ooool2o`000003ooooool0003o000000;o00005?ooool2o`0000cooooo0_l00004
ooooo`;o0000?Oooool001cooooo0_l0000Zooooo`;o00001oooool2o`0001Gooooo1?l00003oooo
o`;o00001_ooool2o`0000;ooooo0ol000000ooooooo0000o`00000Do`000003ooooool0003o0000
00;o00000oooool2o`0000Kooooo0_l00006ooooo`So00000oooool2o`0000?ooooo1?l000000ooo
oooo0000o`000003o`000003ooooool0003o0000017ooooo0_l0000<ooooo`;o00000_ooool2o`00
0003ooooool0003o000000;o00001Oooool8o`0000[ooooo0ol000000ooooooo0000o`000004oooo
o`;o0000DOooool001cooooo00?o0000ooooooooool0:Oooool2o`0000;ooooo0_l0000Cooooo`Co
00000oooool6o`000004ooooool0003o0000o`0000Gooooo0_l00003ooooo`;o00000_ooool2o`00
0003ooooool0003o000001?o00003Oooool2o`0000[ooooo1?l00006ooooo`?o000000Coooooo`00
0?l0003ooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l00007ooooo`;o00003Ooo
ool2o`000004ooooool0003o0000o`0000;ooooo0_l0000:ooooo`;o000000?oooooo`000?l00000
0_l00009ooooo`Go000000?oooooo`000?l00000Eoooool001cooooo00?o0000ooooooooool0;Ooo
ool2o`0000Oooooo1Ol00007ooooo`Co00001oooool2o`0000;ooooo0_l00007ooooo`;o00001Ooo
oolIo`0000cooooo1?l0000=ooooo`;o00000_ooool4o`0000cooooo0_l000000ooooooo0000o`00
0007ooooo`;o000000?oooooo`000?l000002_ooool2o`000003ooooool0003o000000Cooooo0_l0
000>ooooo`;o000000?oooooo`000?l000001Oooool4o`0000Sooooo1?l00008ooooo`Co0000A?oo
ool001cooooo00?o0000ooooooooool0=_ooool5o`0000Cooooo0_l00007ooooo`;o00002?ooool2
o`0000Kooooo1Ol00003oooooa[o00002Oooool2o`000003ooooool0003o000000gooooo0_l00002
ooooo`?o00003Oooool2o`0000Wooooo0_l00002ooooo`;o00002_ooool3o`0000?ooooo0_l00000
0ooooooo0000o`000009ooooo`;o00001_ooool2o`0000Gooooo1?l00008ooooo`Co00002?ooool4
o`0004Cooooo000Looooo`03o`000?oooooooooo02Wooooo0_l0000Dooooo`;o00001oooool2o`00
00Gooooo0_l000000ooooooo0000o`000007ooooo`Co00000ooooolGo`000003ooooool0003o0000
00Wooooo0_l0000@ooooo`;o00001_ooool4o`0000oooooo0ol000000ooooooo0000o`00000>oooo
o`?o00000oooool2o`0000cooooo0ol0000;ooooo`Go00002_ooool2o`000003ooooool0003o0000
00Sooooo0_l00004ooooo`;o00001Oooool2o`0003Kooooo000Looooo`03o`000?oooooooooo02So
oooo0ol0000;ooooo`;o00000_ooool2o`000003ooooool0003o0000013ooooo0_l00004ooooo`;o
00000_ooool2o`0000Wooooo5?l000000ooooooo0000o`00000Gooooo`;o00002oooool4o`0000;o
oooo0_l0000;ooooo`Go00001?ooool2o`000003ooooool0003o000000[ooooo0_l000000ooooooo
0000o`00000<ooooo`Go00000oooool2o`0000?ooooo0ol0000<ooooo`Go00002?ooool2o`0000Co
oooo0_l00005ooooo`;o0000=_ooool001cooooo00?o0000ooooooooool0:?ooool4o`0000[ooooo
0_l00002ooooo`;o000000Coooooo`000?l0003o00003_ooool2o`0000Gooooo0_l000001?oooooo
0000o`000?l00007oooooaGo00000_ooool2o`0000Gooooo0_l0000:ooooo`;o00001?ooool2o`00
00_ooooo0ol00003ooooo`;o000000?oooooo`000?l000002Oooool4o`0000?ooooo0ol000000ooo
oooo0000o`000004ooooo`;o00001?ooool2o`000003ooooool0003o000000;o00003?ooool4o`00
00;ooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000[ooooo1?l00004oooo
o`;o00002_ooool2o`0003cooooo000Looooo`03o`000?oooooooooo02Sooooo1?l00007ooooo`;o
00002Oooool2o`0000Cooooo0_l00007ooooo`?o00002?ooool2o`0000Oooooo6?l00005ooooo`Co
00001Oooool2o`0000;ooooo0ol00007ooooo`;o00000_ooool2o`0000Gooooo0_l00006ooooo`;o
00002Oooool2o`0000?ooooo1?l00008ooooo`;o00001_ooool5o`0000Oooooo0_l00005ooooo`;o
00001Oooool4o`000004ooooool0003o0000ooooo`;o00003oooool2o`0000[ooooo0_l0000loooo
o`007?ooool00ol0003oooooooooo`0Xooooo`Co00001oooool2o`0000;ooooo0_l00005ooooo`Co
00000_ooool3o`000003ooooool0003o000000;ooooo1Ol0000@oooooa[o00000oooool2o`0000Oo
oooo0ol000000ooooooo0000o`000008ooooo`;o00000_ooool2o`0000?ooooo1?l0000Fooooo`Co
00004?ooool2o`0000[ooooo0_l0000=ooooo`;o00001Oooool2o`0000;ooooo0_l00004ooooo`;o
00001?ooool2o`0000Gooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o0000
00?oooooo`000?l000000_l00003ooooo`;o00001oooool2o`0000?ooooo0_l000000ooooooo0000
o`000002ooooo`;o000000?oooooo`000?l000000_ooool3o`0000;ooooo0_l00005ooooo`?o0000
00?oooooo`000?l000002Ol000000ooooooo0000o`000007o`000003ooooool0003o000000Wooooo
0_l00002ooooo`;o00001_ooool2o`0000cooooo0_l00004ooooo`;o00005oooool2o`0001Wooooo
0_l000000ooooooo0000o`00000:ooooo`;o00002Oooool2o`0000Cooooo2Ol00004ooooo`;o0000
@_ooool001cooooo00?o0000ooooooooool0:Oooool2o`0000;ooooo1ol000000ooooooo0000o`00
0009ooooo`;o00002Oooool2o`0000Kooooo0ol00002ooooo`;o00000_ooool6o`0000;ooooo5?l0
0004ooooo`Co00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o00002?oo
ool2o`0000Sooooo0_l0000Gooooo`;o00003?ooool2o`000003ooooool0003o000000Sooooo0_l0
00000ooooooo0000o`00000Hooooo`;o00000oooool4o`000003ooooool0003o000000;ooooo0_l0
0014ooooo`007?ooool00ol0003oooooooooo`0Yooooo`;o00001?ooool3o`0000?ooooo0_l00008
ooooo`;o00001_ooool2o`0000;ooooo0_l0000;ooooo`?o000000?oooooo`000?l000000ol00003
oooooaGo00000oooool4o`0000_ooooo0_l0000=ooooo`;o00006?ooool2o`0001Gooooo0_l00000
0ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000_l00008ooooo`;o00004_ooool2
o`0000Oooooo0_l00003ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0>_ooool2o`00
00?ooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo0_l0000;ooooo`?o00002_oooolDo`00
00Sooooo0ol0000Dooooo`;o00001_ooool2o`0000;ooooo0ol00008ooooo`;o00000oooool2o`00
01Oooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00001?ooool2o`00
00Cooooo0_l00006ooooo`;o00003Oooool2o`0004Wooooo000Looooo`03o`000?oooooooooo02go
oooo0_l0000;ooooo`Co00001Oooool2o`0000Kooooo0_l0000;ooooo`;o00002ooooolAo`000003
ooooool0003o000000Sooooo0ol0000>ooooo`;o00001?ooool2o`0000?ooooo0_l000000ooooooo
0000o`000002ooooo`Co00000_ooool2o`0000?ooooo0_l0000<ooooo`;o00003_ooool2o`0000;o
oooo0_l000000ooooooo0000o`000003o`0000;ooooo0_l00008ooooo`Co00000_ooool3o`000004
ooooool0003o0000o`0000;ooooo0_l00003ooooo`;o00002Oooool2o`0000Cooooo0_l0000moooo
o`007?ooool00ol0003oooooooooo`0]ooooo`;o00003Oooool2o`0001[ooooo0_l0000;ooooo`ko
00001?ooool2o`0000Cooooo0_l00006ooooo`;o00001_ooool2o`0000?ooooo0_l00009ooooo`;o
00001oooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l00007ooooo`;o
00004_ooool2o`000004ooooool0003o0000o`0000kooooo0_l00004ooooo`?o00000_ooool6o`00
00?ooooo0_l00007ooooo`Go00000oooool2o`0000Kooooo0_l0000eooooo`007?ooool00ol0003o
ooooooooo`0`ooooo`;o0000>?ooool:o`0000Cooooo0_l000000ooooooo0000o`000002o`000003
ooooool0003o000000?ooooo0_l00006ooooo`;o00001?ooool2o`0000_ooooo0_l0000;ooooo`Co
00000oooool2o`00017ooooo0_l0000Gooooo`Go00003?ooool4o`0000Sooooo0_l00003ooooo`;o
000000?oooooo`000?l000000oooool2o`0000Kooooo0_l0000eooooo`007?ooool2o`00037ooooo
0_l0000Gooooo`;o000000?oooooo`000?l000000oooool3o`0000_ooooo0_l00004ooooo`;o0000
0oooool2o`0000Gooooo1?l00003ooooo`;o000000Coooooo`000?l0003o00000_ooool4o`000003
ooooool0003o000000cooooo0_l0000;ooooo`Go00001Oooool2o`0000Sooooo0_l000000ooooooo
0000o`00000>ooooo`;o00001_ooool4o`0000gooooo1ol000000ooooooo0000o`000002ooooo`;o
00001Oooool4o`0000Cooooo1_l00018ooooo`007?ooool00ol0003oooooooooo`0Vooooo`;o0000
0_ooool3o`0001Wooooo0_l000001?oooooo0000o`000?ooool4o`000004ooooool0003o0000o`00
00Cooooo1?l00003ooooo`;o00001?ooool2o`0000?ooooo0_l00005ooooo`Co00001oooool3o`00
00?ooooo0_l000000ooooooo0000o`000008ooooo`?o00002oooool2o`0000?ooooo0ol000000ooo
oooo0000o`000004o`0000Sooooo0_l000000ooooooo0000o`00000:ooooo`;o00001oooool2o`00
0003ooooool0003o000000;o00000_ooool2o`0000_ooooo0_l000001?oooooo0000o`000?ooool2
o`0000;ooooo0_l000000ooooooo0000o`000008o`0000;ooooo1_l0000<ooooo`Co0000>?ooool0
01cooooo00?o0000ooooooooool09_ooool2o`0000;ooooo0ol0000Iooooo`;o00001_ooool5o`00
00Gooooo1?l00007ooooo`;o00003oooool2o`0000Kooooo0ol0000:ooooo`;o00001?ooool3o`00
00_ooooo0_l00007ooooo`Co00003?ooool2o`0000Wooooo1?l00007ooooo`;o00000_ooool2o`00
00?ooooo0_l0000Hooooo`Ko000000Coooooo`000?l0003o00001_ooool2o`0000;ooooo0_l00008
ooooo`Co0000>?ooool001cooooo00?o0000ooooooooool0;_ooool2o`0001;ooooo0_l0000:oooo
o`Go00001_ooool2o`0000Sooooo0_l00002ooooo`;o00002oooool2o`0000Sooooo0_l00004oooo
o`;o00000oooool2o`0002Cooooo0_l00005ooooo`;o00001?ooool2o`0000?ooooo0_l0000<oooo
o`?o00000_ooool2o`0000_ooooo0ol0000=ooooo`?o00000_ooool3o`0000Kooooo0_l00002oooo
o`;o00000_ooool2o`00043ooooo000Looooo`03o`000?oooooooooo02kooooo0_l0000Booooo`;o
00002_ooool2o`000003ooooool0003o000000gooooo0_l00005ooooo`;o00002Oooool2o`0000[o
oooo0_l00004ooooo`;o0000:Oooool2o`0000_ooooo1?l000000ooooooo0000o`000003ooooo`;o
00001oooool3o`0000;ooooo0_l00008ooooo`Ko00003_ooool:o`0000?ooooo0_l000000ooooooo
0000o`000003ooooo`;o000000?oooooo`000?l000000_ooool2o`0003Wooooo000Looooo`03o`00
0?oooooooooo02gooooo0_l0000;ooooo`;o00002?ooool2o`0000;ooooo0_l00007ooooo`;o0000
3Oooool2o`0000Kooooo0_l00008ooooo`?o00005Oooool2o`0001_ooooo0_l0000;ooooo`;o0000
1Oooool8o`0000?ooooo0_l0000@ooooo`;o00001?ooool3o`0000Cooooo0_l00008ooooo`;o0000
0oooool2o`0000?ooooo0ol00006ooooo`;o00001_ooool2o`0000;ooooo0_l0000iooooo`007?oo
ool00ol0003oooooooooo`0Vooooo`;o00001Oooool2o`0000_ooooo0_l00008ooooo`;o00000_oo
ool2o`0001kooooo0_l00003ooooo`;o00001?ooool2o`0001Gooooo0_l0000Jooooo`?o00002Ooo
ool4o`0000Gooooo1?l000000ooooooo0000o`00000:ooooo`;o00002_ooool4o`0000;ooooo0_l0
0005ooooo`;o00002?ooool2o`0000?ooooo0_l00002ooooo`Co00000_ooool2o`0000gooooo0_l0
0003ooooo`;o0000=Oooool001cooooo00?o0000ooooooooool09_ooool2o`0000Sooooo0_l00008
ooooo`;o00002?ooool2o`0000Kooooo1?l0000Iooooo`;o00000_ooool2o`0001oooooo0_l0000F
ooooo`?o00000oooool3o`0000?ooooo0_l00004ooooo`Oo00001oooool2o`0000;ooooo1?l0000:
ooooo`Co00000_ooool2o`0000Gooooo0_l00009ooooo`;o00000_ooool2o`000003ooooool0003o
000000?o00000_ooool2o`0000gooooo0_l00003ooooo`;o0000=Oooool001cooooo00?o0000oooo
ooooool0<?ooool2o`0000Sooooo0_l00008ooooo`Co00001?ooool4o`0001Sooooo0ol00003oooo
o`;o000000?oooooo`000?l000000oooool2o`0001Kooooo0_l0000Kooooo`Go00002?ooool3o`00
00_ooooo0_l00002ooooo`?o00002oooool2o`0000Cooooo0_l00005ooooo`;o00001_ooool2o`00
0003ooooool0003o000000Gooooo1Ol0001=ooooo`007?ooool00ol0003oooooooooo`0Zooooo`;o
000000?oooooo`000?l000004?ooool2o`0000Gooooo0_l0000Fooooo`;o00001_ooool4o`0000Co
oooo0_l000000ooooooo0000o`000002ooooo`?o00001_ooool3o`00017ooooo0_l0000Dooooo`;o
000000Coooooo`000?l0003ooooo0_l0000>ooooo`;o00002_ooool3o`000003ooooool0003o0000
00Kooooo1?l0000Cooooo`Go00001_ooool3o`0004kooooo000Looooo`03o`000?oooooooooo02Go
oooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l0000=ooooo`;o00000oooool2o`00
01;ooooo0_l000001?oooooo0000o`000?ooool2o`0000Kooooo1?l0000;ooooo`;o00001oooool3
o`0000?ooooo0_l0000<ooooo`;o00005?ooool2o`0001Cooooo0_l00002ooooo`;o00001_ooool2
o`0000;ooooo0_l00006ooooo`Co00001_ooool2o`0000Cooooo0_l00006ooooo`Co00001_ooool2
o`0000Gooooo0ol00002ooooo`;o0000@oooool001cooooo00?o0000ooooooooool09Oooool2o`00
00?ooooo0_l00002ooooo`Co00004?ooool4o`0000?ooooo0_l0000:ooooo`;o000000?oooooo`00
0?l000000ol0000:ooooo`;o00000oooool3o`0000kooooo0_l00005ooooo`;o00001oooool2o`00
00Cooooo0_l000000ooooooo0000o`00000Eooooo`?o00004_ooool2o`0000_ooooo1_l00003oooo
o`;o000000?oooooo`000?l000000oooool2o`000004ooooool0003o0000ooooo`;o00001_ooool4
o`0000;ooooo0_l000000ooooooo0000o`000006ooooo`?o00000_ooool2o`0000Kooooo0_l0000k
ooooo`007?ooool00ol0003oooooooooo`0Zooooo`;o00000_ooool2o`0000Gooooo0_l00005oooo
o`;o00001?ooool3o`0000Cooooo0_l0000:ooooo`Oo00001?ooool2o`0000Oooooo1_l00004oooo
o`;o00002?ooool2o`0000Cooooo0_l00004ooooo`;o00000_ooool2o`0000Cooooo0_l000000ooo
oooo0000o`00000Eooooo`?o00000_ooool2o`000003ooooool0003o000000;o00004oooool2o`00
0003ooooool0003o000000Wo000000?oooooo`000?l000001_ooool2o`0000Kooooo0_l00002oooo
o`;o00000oooool2o`000003ooooool0003o000000kooooo0_l00003ooooo`;o0000>oooool001co
oooo00?o0000ooooooooool09Oooool2o`0000[ooooo0ol000000ooooooo0000o`000005ooooo`;o
00001?ooool3o`00017ooooo0_l000001?oooooo0000o`000?l00004ooooo`?o00001_ooool3o`00
0004ooooool0003o0000ooooo`;o000000?oooooo`000?l000002?ooool2o`0000Cooooo0_l00000
1?oooooo0000o`000?ooool2o`0001;ooooo0_l00004ooooo`;o00002_ooool2o`000004ooooool0
003o0000ooooo`Ko00002_ooool2o`0000;ooooo1Ol00006ooooo`Ko00001oooool2o`0000Sooooo
0_l00002ooooo`;o00000_ooool2o`0001;ooooo0_l00010ooooo`007?ooool00ol0003ooooooooo
o`0Uooooo`;o00002_ooool3o`000003ooooool0003o000000_ooooo0_l00004ooooo`;o00004?oo
ool2o`0000Gooooo0_l0000:ooooo`;o000000?oooooo`000?l000002oooool2o`0000Cooooo0_l0
00000ooooooo0000o`00000Eooooo`;o00001?ooool2o`0000Kooooo0_l00002ooooo`;o00002?oo
ool2o`0000;ooooo0_l00006ooooo`;o00000_ooool@o`0000Oooooo0ol00007ooooo`;o00001?oo
ool2o`000003ooooool0003o000000Gooooo1?l00009ooooo`;o00000oooool2o`0000?ooooo0_l0
000fooooo`007?ooool00ol0003oooooooooo`0Uooooo`;o00002?ooool3o`0000Wooooo0ol00004
ooooo`?o00000oooool2o`0000_ooooo0_l00008ooooo`Go00001Oooool2o`0001;ooooo0_l00002
ooooo`Co00005oooool2o`0000;ooooo0_l00009ooooo`;o00000_ooool2o`0000cooooo0_l00003
ooooo`;o00001Oooool2o`0000;ooooo3_l00002ooooo`Ko00001?ooool2o`000003ooooool0003o
000000Cooooo0_l000000ooooooo0000o`000002o`0000;ooooo1Ol0000>ooooo`;o00000oooool2
o`0003Kooooo000Looooo`;o00009_ooool2o`0000Sooooo1Ol00006ooooo`Co00001Oooool2o`00
013ooooo0ol00007ooooo`Go00000_ooool2o`000003ooooool0003o000000?ooooo0_l0000Aoooo
o`;o00005?ooool2o`0000?ooooo0_l00002ooooo`;o00003Oooool2o`0000kooooo0_l000000ooo
oooo0000o`000004ooooo`Oo000000?oooooo`000?l000002_l000000ooooooo0000o`000004o`00
00Cooooo0_l000000ooooooo0000o`000007ooooo`Co00000_ooool2o`0000Sooooo0_l0000Eoooo
o`;o0000;Oooool001cooooo00?o0000ooooooooool0<Oooool3o`000003ooooool0003o000000;o
oooo0ol0000>ooooo`;o000000?oooooo`000?l000001oooool2o`0000;ooooo0_l000000ooooooo
0000o`000002ooooo`Oo00000oooool2o`000004ooooool0003o0000ooooo`;o00008?ooool2o`00
00;ooooo0_l0000Looooo`;o00002?ooool2o`0000Gooooo5ol000000ooooooo0000o`000004o`00
00Kooooo0_l00007ooooo`;o00003_ooool2o`0001Gooooo0_l0000]ooooo`007?ooool00ol0003o
ooooooooo`0Xooooo`;o00001_ooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`0000_o
oooo1Ol0000;ooooo`;o000000?oooooo`000?l000001Oooool4o`0000?ooooo0_l00004ooooo`;o
00003_ooool2o`0000[ooooo2?l000000ooooooo0000o`000007ooooo`?o00004oooool2o`0000oo
oooo7_l0001Uooooo`007?ooool00ol0003oooooooooo`0Xooooo`;o00001_ooool2o`0000Gooooo
0_l00004ooooo`;o00003?ooool2o`0000cooooo0_l00009ooooo`Co00002Oooool2o`0000Gooooo
0ol00006ooooo`;o00001Oooool2o`0000?ooooo1_l00003ooooo`;o00001oooool3o`0002Cooooo
7?l00004ooooo`;o00001oooool2o`0005Sooooo000Looooo`03o`000?oooooooooo02gooooo0ol0
0007ooooo`;o00002_ooool4o`0000Oooooo0_l00006ooooo`;o000000?oooooo`000?l000002Ooo
ool2o`0000_ooooo0_l00005ooooo`?o00002_ooool2o`000003ooooool0003o000000?ooooo0ol0
00000ooooooo0000o`000004ooooo`?o00005oooool2o`00013ooooo0_l00003oooooaco00000_oo
ool2o`0000Kooooo0ol00006ooooo`;o00002_ooool2o`0004Cooooo000Looooo`03o`000?oooooo
oooo02gooooo1?l0000Booooo`Co00001oooool4o`0000Cooooo0_l000000ooooooo0000o`00000G
ooooo`;o00001?ooool2o`0000Kooooo0_l000000ooooooo0000o`000005o`0000?ooooo0ol00000
0ooooooo0000o`000007o`0000?ooooo0_l00003ooooo`;o00003Oooool2o`0000_ooooo0_l00003
ooooo`Co00000_oooolKo`0000[ooooo0ol00004ooooo`Co00002_ooool2o`0004Cooooo000Loooo
o`03o`000?oooooooooo02Cooooo0_l00009ooooo`;o00001Oooool2o`0001Oooooo0ol0000<oooo
o`;o00001Oooool2o`0000_ooooo0_l00003ooooo`?o00001_ooool2o`000003ooooool0003o0000
00Go00002Oooool5o`0000;ooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o0000
013ooooo0_l00008ooooo`;o00000ooooolRo`00013ooooo1?l00006ooooo`;o0000B?ooool001co
oooo00?o0000ooooooooool09?ooool2o`00013ooooo0_l0000;ooooo`;o00002oooool3o`0000_o
oooo1?l000000ooooooo0000o`000004o`0000[ooooo0_l00002ooooo`;o00001Oooool2o`0000Ko
oooo0ol00008ooooo`Co00001Oooool2o`000003ooooool0003o000000;o00001?ooool2o`0000go
oooo0ol0000<ooooob;o00004_ooool2o`0000Kooooo0_l00006ooooo`?o0000?oooool001cooooo
00?o0000ooooooooool0@oooool2o`0000cooooo0_l0000=ooooo`;o000000?oooooo`000?l00000
1Ol00004ooooo`;o00000oooool6o`000003ooooool0003o000000;ooooo0_l00006ooooo`Oo0000
0_ooool4o`0000?ooooo2_l00005ooooo`?o00003?ooool3o`0000Sooooo0_l00004ooooob3o0000
1_ooool2o`0000Cooooo0_l00004ooooo`;o00003_ooool3o`0003oooooo000Looooo`03o`000?oo
oooooooo02kooooo0_l0000<ooooo`;o00004oooool3o`00017ooooo0_l000000ooooooo0000o`00
0004ooooo`;o00001?ooool5o`000004ooooool0003o0000ooooo`?o00001?ooool4o`000003oooo
ool0003o000000[o000000?oooooo`000?l000002_l00003ooooo`?o000000?oooooo`000?l00000
5?ooool2o`0000?ooooo7_l00009ooooo`;o000000Coooooo`000?l0003ooooo0_l000001?oooooo
0000o`000?ooool2o`0000Cooooo0ol00019ooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o
00003?ooool2o`0000Oooooo0_l00007ooooo`;o00000_ooool2o`0000[ooooo0ol00002ooooo`;o
00002Oooool2o`0000Gooooo0_l00006ooooo`;o00000oooool:o`000004ooooool0003o0000oooo
o`Go000000?oooooo`000?l000001Ol000000ooooooo0000o`000002o`0000?ooooo0_l00002oooo
o`;o00000_ooool2o`0000Cooooo1?l00009ooooo`;o000000?oooooo`000?l000005Ol00002oooo
o`So00001_ooool2o`0000;ooooo0_l00004ooooo`;o00001oooool3o`0004Wooooo000Looooo`03
o`000?oooooooooo03Kooooo0_l0000=ooooo`;o00001oooool2o`0000gooooo1?l00002ooooo`Go
00001Oooool5o`0000cooooo0ol000000ooooooo0000o`000002o`000004ooooool0003o0000o`00
00?ooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000Go000000Goooooo`00
0?l0003o0000ooooo`02o`0000Cooooo0_l00003ooooo`;o00001?ooool4o`0000Wooooo0_l00000
1?oooooo0000o`000?oooolQo`0000;ooooo0ol0000Aooooo`;o00003?ooool2o`0003cooooo000L
ooooo`03o`000?oooooooooo03Gooooo0ol00006ooooo`;o00007Oooool2o`0000;ooooo2?l00004
ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Cooooo0ol000000ooooooo0000o`000002
o`000003ooooool0003o000001co00000oooool5o`000004ooooool0003o0000o`0001Cooooo7Ol0
00000ooooooo0000o`000006o`0000[ooooo0_l0000Dooooo`;o00000_ooool2o`0003Sooooo000L
ooooo`03o`000?oooooooooo03?ooooo1?l00006ooooo`Co00001_ooool2o`00017ooooo0_l00005
ooooo`;o00000oooool4o`0000;ooooo0_l0000:ooooo`Co00000_ooool5o`0000;ooooo7Ol00000
0ooooooo0000o`000003o`000003ooooool0003o000000;o000000Coooooo`000?l0003o00002_oo
ool2o`0000Oooooo8_l000000ooooooo0000o`000002ooooo`;o00002?ooool2o`0000kooooo0_l0
0008ooooo`;o0000>?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo
00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo03?ooooo1Ol00002ooooo`;o
000000?oooooo`000?l000000_l00005ooooo`?o00001oooool3o`0000Oooooo0_l0000<ooooo`;o
00000_ooool2o`0000Wooooo0_l000000ooooooo0000o`000003oooooago00000_ooool3o`0000?o
oooo1?l00005ooooo`;o00003?ooool4o`0000?ooooo1?l000000ooooooo0000o`00000Fo`000003
ooooool0003o000000?o00001_ooool3o`0000Gooooo1?l00003ooooo`;o00002Oooool2o`0004;o
oooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B401_ooool00ol0003oooooooooo`0dooooo`Co00000_ooool2o`0000[ooooo0_l00008
ooooo`?o00004?ooool7o`0000Gooooo0_l00006ooooo`;o000000?oooooo`000?l000000oooool2
o`0000;ooooo6?l000000ooooooo0000o`000006o`000003ooooool0003o000000;o00001?ooool2
o`0000gooooo0ol00002ooooobGo000000?oooooo`000?l000000oooool2o`0000Gooooo1?l00000
0ooooooo0000o`000002o`0000Oooooo0_l00014ooooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`10
ooooo`;o00001?ooool2o`0001_ooooo1ol00005ooooo`;o00001Oooool2o`0000cooooo8?l00000
0ooooooo0000o`000002o`0000?ooooo0_l00008ooooo`;o00001?ooool2o`0000?ooooo9Ol00000
0ooooooo0000o`00000:ooooo`;o00000oooool4o`0000Oooooo0_l00014ooooo`0000?oooooo`00
0?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3
o`0002oooooo0_l0000?ooooo`;o00001?ooool2o`0000cooooo0_l00006ooooo`;o00000_ooool2
o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Sooooo0_l00002ooooobCo00001?ooool2
o`0000Cooooo0_l00002ooooo`;o00001?ooool2o`0000Cooooo0_l00003ooooo`?o000000?ooooo
o`000?l000006?l000000ooooooo0000o`000002ooooo`?o00001_ooool2o`0000Gooooo0_l0001=
ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?mEEEGo0000
oa0@4?o<c<`01_ooool00ol0003oooooooooo`0_ooooo`;o00003oooool2o`0001;ooooo0_l00006
ooooo`;o00000_ooool4o`0000Cooooo0_l00004ooooo`?o00003_oooolWo`000003ooooool0003o
000000Cooooo0_l00003ooooo`Co00003?ooool2o`000003ooooool0003o000000;o00000_oooolI
o`0000;ooooo0_l00002ooooo`?o00001_ooool2o`0000Gooooo0_l0000:ooooo`;o0000@Oooool0
0003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08oooo
o`03o`000?oooooooooo05kooooo0_l00002ooooo`;o00001?ooool4o`0000;ooooo0_l00007oooo
o`;o000000?oooooo`000?l000000ooooolCo`000004ooooool0003o0000ooooo`go000000Cooooo
o`000?l0003ooooo0_l00003ooooo`?o00001Oooool2o`0000?ooooo0_l00008oooooaSo000000?o
ooooo`000?l000001?l00003ooooo`?o00003?ooool4o`0000kooooo0_l00011ooooo`0000Kooooo
ogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0
G_ooool2o`0000;ooooo0_l00006ooooo`;o00000_ooool2o`000003ooooool0003o000000Cooooo
0_l000001?oooooo0000o`000?l00002oooooa_o000000?oooooo`000?l000001_l00004ooooo`;o
00000oooool3o`0000[ooooo1?l00006ooooo`?o000000?oooooo`000?l000001?l000000ooooooo
0000o`00000Bo`0000?ooooo0ol00006ooooo`;o00001?ooool4o`00057ooooo00001_ooooook^k^
oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`1?
ooooo`;o00003?ooool4o`00013ooooo0_l00002ooooo`;o00000_ooool4o`000003ooooool0003o
000002?o00001Oooool2o`0000?ooooo0_l0000<ooooo`;o00001oooool2o`000005ooooool0003o
0000o`000?ooool05?l000000ooooooo0000o`000005ooooo`;o00000_ooool2o`000003ooooool0
003o000000;o00001oooool2o`0004kooooo000Looooo`03o`000?oooooooooo03gooooo0_l0000=
ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Kooooo1_l00008ooooo`;o00000_ooool2
o`0000Kooooo0_l000000ooooooo0000o`00000Yo`0000Gooooo0_l000001?oooooo0000o`000?oo
ool2o`0000Gooooo0_l0000=ooooo`;o00000_ooool2o`0000;ooooo4?l000001?oooooo0000o`00
0?ooool2o`0000Gooooo0_l00002ooooo`;o00000oooool2o`0000Oooooo0_l0000Cooooo`;o0000
>Oooool001cooooo00?o0000ooooooooool0?Oooool2o`0000gooooo0_l000000ooooooo0000o`00
0002ooooo`;o00001_ooool4o`0000[ooooo0_l00002ooooo`;o00002Oooool8o`0000;ooooo3_l0
00000ooooooo0000o`00000Ao`0000?ooooo0ol000001?oooooo0000o`000?ooool2o`0000Gooooo
0_l0000=ooooo`;o00000_ooool5o`0000;ooooo2ol00002ooooo`?o000000?oooooo`000?l00000
0oooool2o`0000Kooooo0_l0000Aooooo`;o00003?ooool2o`0003Wooooo000Looooo`03o`000?oo
oooooooo03?ooooo0_l0000>ooooo`;o00002_ooool4o`0000cooooo0_l000001?oooooo0000o`00
0?l00003ooooo`;o00003oooool4o`000003ooooool0003o000002Co00000_ooool6o`0001Sooooo
0_l00002ooooo`Go000000Coooooo`000?l0003ooooo1_l00002ooooo`;o000000Coooooo`000?l0
003o00001_ooool2o`0000Kooooo0_l00004ooooo`?o00002_ooool2o`0000Wooooo0ol0000koooo
o`007?ooool00ol0003oooooooooo`0cooooo`;o00001oooool2o`0000Gooooo0_l00009ooooo`;o
000000Coooooo`000?l0003o00001Oooool2o`0000;ooooo1?l000001?oooooo0000o`000?l00003
ooooo`;o00003oooool4o`0000?ooooo8Ol000001?oooooo0000o`000?ooool3o`0000;ooooo0ol0
0002ooooo`;o00003?ooool4o`0000?ooooo1_l00004ooooo`;o00000_ooool4o`0000?ooooo0_l0
00001?oooooo0000o`000?ooool2o`000005ooooool0003o0000o`000?ooool01Ol00004ooooo`;o
00000_ooool3o`0001Gooooo1?l0000jooooo`007?ooool00ol0003oooooooooo`0looooo`;o0000
1_ooool2o`0000Sooooo0_l00002ooooo`;o00001Oooool2o`0000;ooooo0ol0000Iooooob_o0000
00Goooooo`000?l0003o0000ooooo`05o`000003ooooool0003o000000;o00001?ooool2o`0000Co
oooo1?l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00002ooooo`Co
00002Oooool6o`000003ooooool0003o000000?o00001?ooool2o`0001?ooooo0_l00004ooooo`;o
000000?oooooo`000?l00000>_ooool001cooooo00?o0000ooooooooool0>Oooool2o`0000Wooooo
0_l0000Hooooo`?o00002?ooool2o`0000kooooo=Ol000000ooooooo0000o`000002o`0000Cooooo
0_l00008ooooo`Go00001?ooool3o`000003ooooool0003o000000;ooooo1Ol00009ooooo`;o0000
0_ooool2o`0000;ooooo0ol0000Booooo`;o00001Oooool2o`0000Cooooo0_l0000mooooo`007?oo
ool00ol0003oooooooooo`0gooooo`Co00006_ooool4o`0000Kooooo0_l00007ooooo`?o000000?o
ooooo`000?l000002_ooool2o`000003ooooool0003o000002ko000000?oooooo`000?l000000ol0
000@ooooo`;o000000?oooooo`000?l000001?ooool7o`0000Cooooo0_l00003ooooo`;o00002?oo
ool2o`0000;ooooo0_l00002ooooo`Co00003Oooool2o`0004[ooooo000Looooo`03o`000?oooooo
oooo03Oooooo0_l000000ooooooo0000o`000005ooooo`;o00002Oooool2o`0000Oooooo1?l00000
1?oooooo0000o`000?ooool4o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000Sooooo1_l0
00000ooooooo0000o`00000Uo`000004ooooool0003o0000o`0000Cooooo1Ol0000Cooooo`;o0000
1oooool4o`0000Wooooo0_l0000<ooooo`So00003Oooool2o`0004[ooooo000Looooo`03o`000?oo
oooooooo03[ooooo0_l00005ooooo`;o00002Oooool2o`0000Sooooo0_l00002ooooo`Go00001?oo
ool2o`0000Cooooo0ol00007ooooo`;o000000?oooooo`000?l000001?l00003oooooago000000?o
ooooo`000?l000001Ol000001?oooooo0000o`000?l00004ooooo`;o0000:Oooool2o`0000Wooooo
0_l00006ooooo`?o00004?ooool2o`0004[ooooo000Looooo`03o`000?oooooooooo05?ooooo0_l0
0007ooooo`;o00002oooool3o`0000Oooooo0_l00004ooooo`?o000000?oooooo`000?l000000_oo
oolSo`0000Oooooo0_l00007ooooo`;o00002?ooool2o`0000;ooooo0_l00003ooooo`;o00001?oo
ool2o`0000Sooooo1?l00007ooooo`?o00000_ooool2o`00063ooooo000Looooo`03o`000?oooooo
oooo047ooooo0_l0000@ooooo`;o00003oooool2o`0000?ooooo0_l00004ooooo`;o00000_ooool2
o`0000Cooooo0ol000000ooooooo0000o`00000@o`000003ooooool0003o000001Go00001?ooool2
o`0000Oooooo1ol00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`Co00002_ooool2
o`0000Gooooo0_l000000ooooooo0000o`000002ooooo`;o0000H?ooool001cooooo0_l0000ioooo
o`;o00000_ooool2o`0000?ooooo0_l0000@ooooo`;o00003oooool2o`0000?ooooo0_l00004oooo
o`;o000000?oooooo`000?l000001_ooool2o`000003ooooool0003o000002;o000000?oooooo`00
0?l000001?l00004ooooo`;o000000?oooooo`000?l000001Oooool5o`0000Gooooo0_l00009oooo
o`;o00004oooool2o`0006Oooooo000Looooo`03o`000?oooooooooo03Sooooo0_l00002ooooo`;o
00004Oooool2o`0000;ooooo0_l0000Dooooo`?o000000?oooooo`000?l000000oooool2o`0000Go
oooo0_l00002ooooobCo00000oooool4o`0000Cooooo0_l000000ooooooo0000o`00000?ooooo`;o
00002_ooool2o`0000_ooooo0_l0001^ooooo`007?ooool00ol0003oooooooooo`0iooooo`;o0000
00?oooooo`000?l000004Oooool2o`0001Wooooo1Ol00006ooooo`Ko00000ooooolUo`000003oooo
ool0003o000000;ooooo0_l0000Pooooo`Co00000oooool2o`0000Kooooo0_l0001^ooooo`007?oo
ool00ol0003oooooooooo`0iooooo`;o000000?oooooo`000?l000001?ooool2o`0001Gooooo0_l0
0005ooooo`;o00002Oooool2o`0000Sooooo1_l00004ooooo`Wo000000?oooooo`000?l000006?l0
0005ooooo`;o000000?oooooo`000?l000006_ooool2o`000003ooooool0003o000000;o00000ooo
ool2o`0001[ooooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00000_ooool3
o`0000?ooooo1?l00004ooooo`;o00001oooool3o`0000Cooooo0ol000000ooooooo0000o`00000A
ooooo`Go00001?ooool3o`000003ooooool0003o000001go00002Oooool3o`0001?ooooo0_l00004
ooooo`;o00001oooool2o`0001_ooooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`0moooo
o`;o00000_ooool2o`0000Cooooo1?l00004ooooo`;o00001?ooool2o`000004ooooool0003o0000
o`0000Cooooo0_l00002ooooo`;o00001?ooool2o`0000;ooooo0_l00007ooooo`;o00001?ooool2
o`000005ooooool0003o0000o`000?ooool08_l00005ooooo`Co00002Oooool6o`0000Cooooo0_l0
000=ooooo`;o00002Oooool2o`0000?ooooo0_l00009ooooo`;o0000G?ooool001cooooo00?o0000
ooooooooool0C?ooool2o`0000Oooooo0_l0000:ooooo`;o00000_ooool2o`000003ooooool0003o
000000Go00002_ooool8o`000003ooooool0003o000000?o000000Coooooo`000?l0003o00000_oo
oolAo`000003ooooool0003o000000Co00000_ooool2o`000004ooooool0003o0000o`0000[ooooo
1_l000000ooooooo0000o`000002o`0000Gooooo0_l000000ooooooo0000o`000007ooooo`;o0000
1Oooool3o`0000?ooooo0_l00009ooooo`;o0000G?ooool001cooooo00?o0000ooooooooool0C?oo
ool2o`0001?ooooo0_l00002ooooo`;o000000?oooooo`000?l000001?l00003ooooo`;o00001_oo
ool;o`000003ooooool0003o000000Co000000?oooooo`000?l000003_l00003ooooo`Go000000?o
ooooo`000?l000000_l00002ooooo`;o00002oooool2o`0000;ooooo1_l00005ooooo`;o000000?o
ooooo`000?l000001oooool2o`0000Gooooo0ol0000Tooooo`;o0000A_ooool001cooooo00?o0000
ooooooooool0?Oooool2o`0001;ooooo0_l0000Booooo`;o000000?oooooo`000?l000000_ooool2
o`0000?ooooo0_l00008ooooo`?o000000?oooooo`000?l000005?l000000ooooooo0000o`000004
o`0000Cooooo1?l000001?oooooo0000o`000?l00002ooooo`;o00000_ooool2o`0000;ooooo0_l0
0008ooooo`;o00007Oooool2o`0000Sooooo0_l00006ooooo`;o00004_ooool2o`0000;ooooo0_l0
0012ooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00004_ooool2o`000003ooooool0003o
000001;ooooo0_l000000ooooooo0000o`000002o`0000Wooooo0_l00007ooooo`Go000000?ooooo
o`000?l000002_l00003ooooo`Ko000000Coooooo`000?l0003ooooo0_l00008ooooo`;o00000_oo
ool2o`000004ooooool0003o0000o`0000;ooooo0_l0000<ooooo`;o00007oooool2o`0000Kooooo
1?l0000Dooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0?oooool2o`0001?ooooo0_l0
000=ooooo`;o00000oooool2o`000003ooooool0003o000000;o00000_ooool2o`0000Gooooo0ol0
0003ooooo`;o00000_ooool2o`000003ooooool0003o000000oo000000?oooooo`000?l000001_l0
00000ooooooo0000o`000003ooooo`?o00000_ooool3o`0000;ooooo1?l000000ooooooo0000o`00
0003o`000003ooooool0003o000000Kooooo1_l0000Booooo`;o00001_ooool2o`0000Wooooo1?l0
001Hooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00000oooool2o`0000Cooooo0_l00008
ooooo`;o00002oooool4o`0000Kooooo1Ol000000ooooooo0000o`000005ooooo`?o00000ooooolJ
o`0000?ooooo0ol00007ooooo`?o00000_ooool3o`0000;ooooo1?l000001?oooooo0000o`000?oo
ool2o`000003ooooool0003o000000?o000000?oooooo`000?l000000_l00002ooooo`;o00002ooo
ool3o`0000Cooooo0_l00006ooooo`;o00002oooool2o`0000gooooo0_l00019ooooo`007?ooool0
0ol0003oooooooooo`14ooooo`;o00001?ooool2o`0000Sooooo0_l0000;ooooo`;o00002Oooool4
o`0000;ooooo0_l00009ooooo`;o000000?oooooo`000?l000000_ooool5o`000005ooooool0003o
0000o`000?ooool01Ol00003ooooo`Go00001Oooool2o`0000[ooooo0_l00002ooooo`Go00001ooo
ool3o`000003ooooool0003o000000Gooooo1?l000000ooooooo0000o`000005ooooo`Co00002_oo
ool2o`0000_ooooo0_l0000>ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0A?ooool2
o`0000oooooo0_l0000?ooooo`;o00001Oooool3o`0000;ooooo0_l00009ooooo`;o000000?ooooo
o`000?l000000oooool2o`0000Cooooo0_l00003ooooo`Co000000?oooooo`000?l000001?l00004
ooooo`?o00002_ooool2o`0000Cooooo0ol00008ooooo`Co00001_ooool4o`000003ooooool0003o
000000Kooooo1Ol00008ooooo`;o000000?oooooo`000?l000002?ooool2o`0005Wooooo000Loooo
o`03o`000?oooooooooo04?ooooo0ol00003ooooo`;o00001oooool2o`000003ooooool0003o0000
00oooooo0_l00005ooooo`?o00002?ooool2o`00017ooooo0_l00002ooooo`[o00000oooool2o`00
0004ooooool0003o0000ooooo`;o00001?ooool2o`0000cooooo0_l00007ooooo`;o000000?ooooo
o`000?l000004oooool2o`0000Sooooo0_l000000ooooooo0000o`00001Sooooo`007?ooool00ol0
003oooooooooo`13ooooo`;o00001?ooool2o`0000Gooooo1?l0000Jooooo`Co00001_ooool2o`00
0003ooooool0003o000000;ooooo0_l00005ooooo`Co00001?ooool5o`000004ooooool0003o0000
ooooo`;o00000_ooool3o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l000002Oooool2
o`0000;ooooo1?l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l0000Hooooo`Co00001Ooo
ool2o`0005gooooo000Looooo`;o0000B?ooool2o`0000Oooooo1?l000000ooooooo0000o`000005
ooooo`?o00000oooool2o`0000[ooooo1?l00009ooooo`;o00000_ooool2o`0000Cooooo1Ol00004
ooooo`Go00001?ooool2o`000004ooooool0003o0000o`0000Sooooo0_l00002ooooo`Co00001ooo
ool2o`0000Cooooo1?l000001?oooooo0000o`000?l00005ooooo`;o00000_ooool2o`0001Kooooo
0_l00005ooooo`?o00003Oooool2o`0004gooooo000Looooo`03o`000?oooooooooo04Oooooo0_l0
0009ooooo`;o000000?oooooo`000?l000001Oooool3o`0000?ooooo0_l00004ooooo`?o00000_oo
ool4o`0000?ooooo1?l00007ooooo`Co00000_ooool2o`0000Sooooo1_l00002ooooo`Ko00000_oo
ool2o`0000Cooooo1_l00009ooooo`;o00002_ooool2o`0000Wooooo0_l00003ooooo`;o00003ooo
ool2o`0000?ooooo0_l00003ooooo`;o00003Oooool2o`0004gooooo000Looooo`03o`000?oooooo
oooo057ooooo0_l0000Eooooo`?o00000_ooool4o`0000?ooooo1?l00009ooooo`;o00003?ooool6
o`0000?ooooo1Ol00002ooooo`;o00001_ooool2o`0000?ooooo0_l00009ooooo`;o00002?ooool2
o`0000gooooo0_l0000:ooooo`;o00000oooool2o`0000;ooooo0ol00002ooooo`;o00003?ooool2
o`0004oooooo000Looooo`03o`000?oooooooooo04gooooo0ol000000ooooooo0000o`00000Foooo
o`;o00000_ooool4o`0001?ooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o0000
00;ooooo0_l00003ooooo`;o00001oooool2o`0000Sooooo0_l00009ooooo`;o00000oooool2o`00
00?ooooo0_l0000Iooooo`;o00001oooool2o`0000?ooooo0_l0000<ooooo`;o0000Coooool001co
oooo00?o0000ooooooooool0Aoooool2o`0000Cooooo0ol0000Iooooo`;o00000_ooool4o`0000Co
oooo1?l0000;ooooo`;o00000_ooool2o`0000?ooooo0_l00005ooooo`;o00000oooool2o`0000Oo
oooo0_l00007ooooo`;o00003oooool2o`0001kooooo0_l00009ooooo`;o0000H?ooool001cooooo
00?o0000ooooooooool0Aoooool2o`0000[ooooo0_l000000ooooooo0000o`000009ooooo`;o0000
3?ooool3o`0000?ooooo1?l00003ooooo`;o00002Oooool2o`00013ooooo0_l0000@ooooo`;o0000
;oooool2o`0000;ooooo0_l00005ooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0Dooo
ool2o`000003ooooool0003o000000Wooooo0_l0000<ooooo`Ko00001oooool2o`0000Wooooo0_l0
000=ooooo`;o00002_ooool2o`0000[ooooo0_l0000`ooooo`;o0000Ioooool001cooooo00?o0000
ooooooooool0Doooool2o`0000Sooooo0_l0000@ooooo`Ko00002_ooool2o`0000?ooooo0_l00003
ooooo`;o000000?oooooo`000?l000002?ooool2o`0000[ooooo0_l0000:ooooo`;o0000VOooool0
01cooooo00?o0000ooooooooool0GOooool2o`000003ooooool0003o000000oooooo0_l0000<oooo
o`;o00000oooool2o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`;o00002?ooool2o`00
00gooooo0ol0000dooooo`?o0000IOooool001cooooo00?o0000ooooooooool0C_ooool2o`00013o
oooo0_l0000:ooooo`;o00000oooool2o`0000[ooooo0_l00005ooooo`;o00002?ooool2o`000003
ooooool0003o000000?o00001Oooool2o`0000Wooooo0_l00002ooooo`?o00000oooool2o`0002ko
oooo1?l0001Uooooo`007?ooool00ol0003oooooooooo`1>ooooo`?o00006oooool2o`0000Cooooo
0ol00008ooooo`;o00003oooool2o`0000;ooooo1?l000000ooooooo0000o`000007ooooo`;o0000
1?ooool2o`0000Sooooo0_l0000^ooooo`;o0000Ioooool001cooooo00?o0000ooooooooool0Cooo
ool3o`00023ooooo0ol0000Rooooo`;o00001oooool2o`0003kooooo1?l0001Uooooo`007?ooool0
0ol0003oooooooooo`1@ooooo`;o00005Oooool2o`0001;ooooo0_l00007ooooo`;o00005?ooool2
o`0000Oooooo0_l0000kooooo`Co0000IOooool001cooooo00?o0000ooooooooool0D?ooool2o`00
00;ooooo0_l0000Aooooo`;o00004_ooool2o`0000Oooooo0ol00006ooooo`;o00001oooool2o`00
00;ooooo0_l00007ooooo`;o0000;_ooool2o`0007Cooooo000Looooo`03o`000?oooooooooo05Co
oooo0_l00004ooooo`;o00004?ooool2o`0001Cooooo1Ol00006ooooo`;o00001oooool2o`0003_o
oooo0ol00009ooooo`;o0000J?ooool001cooooo00?o0000ooooooooool0C_ooool2o`0000[ooooo
0_l00009ooooo`Co000000?oooooo`000?l000000_l0000Aooooo`;o000000?oooooo`000?l00000
0_ooool2o`0000;ooooo0_l0000?ooooo`;o00005?ooool2o`00027ooooo0_l00009ooooo`;o0000
4?ooool2o`0005Kooooo000Looooo`;o0000Coooool2o`0000oooooo0_l00004ooooo`Co000000?o
ooooo`000?l000004oooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o00003ooo
ool2o`0001Cooooo0_l0000Wooooo`;o00005Oooool2o`0005Kooooo000Looooo`03o`000?oooooo
oooo05oooooo0_l0000<ooooo`;o00003Oooool2o`0000Gooooo0_l0000Fooooo`;o00003?ooool2
o`0000Sooooo0ol0000Qooooo`Go00000_ooool2o`0006Wooooo000Looooo`03o`000?oooooooooo
06Gooooo0_l00006ooooo`;o00002Oooool2o`0000;ooooo0_l00005ooooo`;o00001?ooool2o`00
0004ooooool0003o0000o`0001[ooooo0_l00008ooooo`?o00008Oooool3o`0000Cooooo0_l0001Y
ooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o00001?ooool2o`0000_ooooo0_l00002oooo
o`?o00002_ooool2o`000004ooooool0003o0000o`0000kooooo0_l0000looooo`Co00003?ooool2
o`0005cooooo000Looooo`03o`000?oooooooooo06_ooooo0_l0000>ooooo`Co00002?ooool2o`00
01Cooooo0_l00004ooooo`;o00009oooool2o`0000gooooo1?l0000<ooooo`;o0000G?ooool001co
oooo00?o0000ooooooooool0I?ooool2o`0001Gooooo0ol00009ooooo`;o00006_ooool2o`0000;o
oooo0_l0000:ooooo`;o00005oooool2o`0007_ooooo000Looooo`03o`000?oooooooooo06Cooooo
0ol00004ooooo`;o00003?ooool2o`000003ooooool0003o000001?ooooo0_l0000>ooooo`;o0000
1?ooool2o`0000[ooooo0_l0000Iooooo`;o00002Oooool2o`0006kooooo000Looooo`03o`000?oo
oooooooo06Gooooo0_l00004ooooo`;o00000_ooool2o`0000Sooooo0_l0000;ooooo`?o00000ooo
ool2o`0000?ooooo1?l0000<ooooo`;o00000_ooool4o`0002Cooooo0ol00009ooooo`;o0000K_oo
ool001cooooo00?o0000ooooooooool0Koooool2o`0000cooooo1?l00005ooooo`?o00000oooool2
o`0000;ooooo0_l000000ooooooo0000o`00000@ooooo`;o00002_ooool2o`0001Sooooo1?l00003
ooooo`?o00001Oooool2o`0000[ooooo0_l0001Qooooo`007?ooool00ol0003oooooooooo`1Yoooo
o`;o00004_ooool4o`0000cooooo0_l000001?oooooo0000o`000?l0000Kooooo`;o000000?ooooo
o`000?l000003_ooool2o`0000Oooooo0ol00005ooooo`?o00001Oooool2o`0000[ooooo0_l0001Q
ooooo`007?ooool00ol0003oooooooooo`1Yooooo`;o00001?ooool4o`0000Kooooo0_l00009oooo
o`;o00001oooool2o`0000;ooooo0_l000000ooooooo0000o`00000Hooooo`;o00003oooool4o`00
00?ooooo0_l000000ooooooo0000o`000002o`0000Gooooo0_l00003ooooo`;o00001_ooool2o`00
00;ooooo0_l0001Tooooo`007?ooool00ol0003oooooooooo`1_ooooo`Co00001_ooool2o`0000Wo
oooo0ol0000=ooooo`;o00002?ooool2o`0001oooooo0_l00003ooooo`Co000000?oooooo`000?l0
00003?ooool2o`0000Cooooo1?l00002ooooo`;o0000I?ooool001cooooo00?o0000ooooooooool0
Foooool2o`0002Kooooo1?l00008ooooo`;o00002?ooool2o`0000?ooooo0_l00009ooooo`;o0000
5oooool6o`000005ooooool0003o0000o`000?ooool00ol0000=ooooo`;o0000J_ooool001cooooo
00?o0000ooooooooool0Foooool2o`000003ooooool0003o000001?ooooo0_l0000>ooooo`;o0000
00?oooooo`000?l000001oooool2o`0000Sooooo0_l000000ooooooo0000o`000002o`0000Wooooo
0_l0000Gooooo`;o00000_ooool3o`000003ooooool0003o000000Co000000?oooooo`000?l00000
1oooool2o`0006gooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Nooooo`;o00004oooool2o`00
00Wooooo0_l00006ooooo`;o00001?ooool2o`0000Oooooo1?l00002ooooo`Go00003Oooool2o`00
00kooooo0ol00007ooooo`;o00000oooool2o`0000?ooooo0_l00007ooooo`;o0000KOooool00006
oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q
8@06ooooo`03o`000?oooooooooo077ooooo0_l0000;ooooo`;o00002oooool5o`0000Gooooo1?l0
0002ooooo`;o00004?ooool2o`000003ooooool0003o000000Sooooo0_l000001?oooooo0000o`00
0?l0000;ooooo`;o0000O?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0LOooool2o`0000cooooo
0_l00009ooooo`?o000000?oooooo`000?l000006_ooool2o`000004ooooool0003o0000ooooo`;o
00002?ooool2o`0000_ooooo0_l00002ooooo`;o00001_ooool2o`0000Gooooo0_l0001]ooooo`00
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb
<S801_ooool3o`00063ooooo0_l0000Mooooo`;o00002Oooool2o`000004ooooool0003o0000oooo
o`;o00000oooool2o`0000?ooooo0_l000000ooooooo0000o`000007ooooo`?o000000?oooooo`00
0?l000000_l0000;ooooo`?o00002oooool2o`0000[ooooo0_l00005ooooo`;o0000KOooool00003
ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Oo<c<co0000o`000?l0003oc<c<
00Kooooo00?o0000ooooooooool0H?ooool2o`0001?ooooo0_l0000@ooooo`;o000000?oooooo`00
0?l000000ol000000ooooooo0000o`000003ooooo`;o00000oooool2o`000003ooooool0003o0000
00;o00001Oooool3o`0000?ooooo0_l000000ooooooo0000o`000008ooooo`;o0000S_ooool00003
ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol@413o^[Zjoooooonj^[[o410@
00Kooooo00?o0000ooooooooool0MOooool2o`00013ooooo1ol00002ooooo`;o00002oooool4o`00
00?ooooo0_l00007ooooo`Co00007Oooool2o`0007Wooooo00001_ooooooMgMgoiRHV?ooooooV9RH
ogMgM`_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo08Wooooo0_l0
000Booooo`;o00001Oooool2o`0000Kooooo1?l0000Cooooo`;o00002Oooool2o`0007Wooooo0000
1_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03
o`000?oooooooooo07Oooooo0_l0000;ooooo`Co00002oooool2o`0000Wooooo0_l0000<ooooo`;o
00003_ooool2o`0000Gooooo0_l00024ooooo`007?ooool00ol0003oooooooooo`1gooooo`;o0000
2oooool4o`0000_ooooo0_l000000ooooooo0000o`000006ooooo`;o00002oooool2o`0000oooooo
0_l0000Booooo`;o0000Moooool001cooooo00?o0000ooooooooool0Poooool2o`0000oooooo1?l0
000:ooooo`;o00001oooool2o`0002?ooooo0_l0000=ooooo`;o0000J?ooool001cooooo00?o0000
ooooooooool0Poooool3o`0000Kooooo0_l00006ooooo`Co00002_ooool2o`0000Kooooo0_l0000B
ooooo`;o00007oooool2o`0006Sooooo000Looooo`03o`000?oooooooooo08Cooooo0_l00006oooo
o`;o00005?ooool4o`0000Cooooo0_l0000@ooooo`Co0000ROooool001cooooo00?o0000oooooooo
ool0R_ooool2o`0001Kooooo1?l0000@ooooo`;o00001?ooool2o`0008_ooooo000Looooo`03o`00
0?oooooooooo08Oooooo0_l000000ooooooo0000o`00000Yooooo`?o0000:Oooool2o`0006Kooooo
000Looooo`03o`000?oooooooooo08Oooooo0_l0000Cooooo`;o00005oooool2o`0000Kooooo0ol0
000Qooooo`;o0000I_ooool001cooooo00?o0000ooooooooool0W?ooool2o`0001Wooooo0_l00000
0ooooooo0000o`000004o`0008Wooooo000Looooo`03o`000?oooooooooo0:Kooooo0ol0000;oooo
o`;o000000Coooooo`000?l0003ooooo1?l000000ooooooo0000o`00000Jooooo`;o0000K?ooool0
01cooooo00?o0000ooooooooool0Y_ooool3o`0000Cooooo0_l00005ooooo`;o00002Oooool2o`00
01[ooooo0_l0001/ooooo`007?ooool00ol0003oooooooooo`2]ooooo`;o0000V_ooool001cooooo
0_l0002?ooooo`;o00008_ooool2o`0009Gooooo000Looooo`03o`000?oooooooooo08kooooo0_l0
000Rooooo`;o0000UOooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo09Sooooo0_l0002_ooooo`00
7?ooool00ol0003oooooooooo`2Hooooo`;o00003oooool2o`0009kooooo000Looooo`03o`000?oo
oooooooo0:Wooooo0_l0000Nooooo`;o0000O_ooool001cooooo00?o0000ooooooooool0Z_ooool2
o`0000[ooooo0_l0000Aooooo`;o0000O_ooool001cooooo00?o0000ooooooooool0Z_ooool2o`00
00Sooooo1?l0002Aooooo`007?ooool00ol0003oooooooooo`2dooooo`?o0000T_ooool001cooooo
00?o0000ooooooooool0]Oooool2o`0009;ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001;ooooo1?l0
00000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo
00Gooooo0ol0003ooooood[ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo
00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000D
ooooo`03o`000?oooooooooo0?ooooooD_ooool001;ooooo00?oEEEEofIVI_l00000oooooomDoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00YOooool01?l@413o0000o`000?oo
ool2o`000003oa0@4?oooooooooo01Oooooo00?o0000onk^k_ooool00oooool01Oo<c<co8B4Qo`00
0?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o410@olc<c02@ooooo`00Y_ooool01Ol0003ooooo
oooooooooooo000000Wooooo1_l0000;ooooo`03oeEEEOnYZJWooooo00?ooooo00Go8B4QoiRHV?oo
ooooV9RHob4Q8@03ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40T?ooool00:Kooooo00Go0000oooo
ooooooooooooo`00000Jooooo`03ojVYZOmEEEGooooo00?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool00000T?ooool00:Kooooo00Go0000oooooooooooooooo
o`000009ooooo`Ko00003?ooool00olQ8B7oooooooooo`02ooooo`05oc8b<_nHV9SooooooiRHV?lb
<S800oooool01Ol0003oV9RHoooooonHV9So8B4Q093ooooo002Vooooo`05o`000?n7QhOoooooojVY
ZOl000006oooool00omEEEGoc<c<ooooo`02ooooo`05olc<c?l0003o0000o`000?o<c<`00oooool0
1Ol0003oEEEEo`000?l@413oc<c<093ooooo002Uooooo`03oa0@4?l0003oMgMg00;o000000?oV9RH
ooooooooool06Oooool00onYZJWoMgMgooooo`02ooooo`05oa0@4?nj^[[ooooookZj^_l@41000ooo
ool00omEEEGoQhN7ooooo`2Booooo`00`oooool01Ol@413ooooooooooooooooo<S8b00?ooooo00Go
0000okZj^_oooooo^[Zjo`000003ooooo`03omgMgOl@413oV9RH09;ooooo0033ooooo`Go00000ooo
ool01OnYZJWo410@o`000?l@413oZJVY00Cooooo00Coc<c<odA4A?l0003o410@T?ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(792) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.68472 .59632 Mdot
.67417 .60484 Mdot
.43948 .30187 Mdot
.40367 .6481 Mdot
.44212 .50049 Mdot
.47366 .35298 Mdot
.59942 .4113 Mdot
.61032 .3888 Mdot
.48582 .33828 Mdot
.49852 .70265 Mdot
.59688 .44388 Mdot
.38185 .57025 Mdot
.60985 .41859 Mdot
.448 .63408 Mdot
.48267 .16233 Mdot
.39005 .58349 Mdot
.61625 .59006 Mdot
.37718 .41905 Mdot
.39586 .67715 Mdot
.4797 .2987 Mdot
.59761 .57944 Mdot
.45114 .63118 Mdot
.67524 .58743 Mdot
.44768 .63266 Mdot
.40398 .63081 Mdot
.64355 .60994 Mdot
.65052 .56442 Mdot
.40408 .60134 Mdot
.42824 .63742 Mdot
.57678 .4132 Mdot
.39801 .48277 Mdot
.33796 .21425 Mdot
.38633 .57973 Mdot
.45989 .80598 Mdot
.60334 .39222 Mdot
.19458 .5073 Mdot
.47843 .31181 Mdot
.62641 .44221 Mdot
.60445 .38961 Mdot
.63033 .40754 Mdot
.62763 .43284 Mdot
.64778 .61425 Mdot
.63774 .45926 Mdot
.56838 .45716 Mdot
.40176 .65399 Mdot
.71672 .47167 Mdot
.24684 .45312 Mdot
.41635 .59898 Mdot
.67274 .62545 Mdot
.49368 .30854 Mdot
.58323 .8235 Mdot
.63784 .40615 Mdot
.68581 .28206 Mdot
.39511 .11185 Mdot
.62367 .41511 Mdot
.39409 .64217 Mdot
.46737 .32577 Mdot
.45966 .60626 Mdot
.44626 .6181 Mdot
.59353 .79892 Mdot
.41144 .6169 Mdot
.35931 .42813 Mdot
.60189 .62704 Mdot
.44229 .35407 Mdot
.47962 .34675 Mdot
.58839 .39481 Mdot
.61897 .61343 Mdot
.60522 .42575 Mdot
.5096 .62761 Mdot
.49518 .32325 Mdot
.4167 .59773 Mdot
.60333 .44812 Mdot
.65771 .64344 Mdot
.48393 .61157 Mdot
.74267 .49488 Mdot
.55395 .17248 Mdot
.38722 .42341 Mdot
.57643 .78923 Mdot
.71569 .67133 Mdot
.57903 .20783 Mdot
.43755 .63388 Mdot
.8589 .44249 Mdot
.49922 .16275 Mdot
.67192 .58795 Mdot
.40405 .52191 Mdot
.4685 .38831 Mdot
.47365 .63182 Mdot
.44725 .46413 Mdot
.49806 .59651 Mdot
.76626 .57274 Mdot
.48585 .33188 Mdot
.65059 .62486 Mdot
.40883 .65224 Mdot
.45565 .57715 Mdot
.58853 .71436 Mdot
.49397 .61042 Mdot
.39864 .59941 Mdot
.62409 .56802 Mdot
.58281 .4156 Mdot
.46786 .55965 Mdot
.6138 .48252 Mdot
.67471 .29284 Mdot
.44593 .6634 Mdot
.49284 .34503 Mdot
.6056 .59663 Mdot
.44695 .66665 Mdot
.61797 .40379 Mdot
.42373 .61848 Mdot
.61213 .47633 Mdot
.67888 .61007 Mdot
.46039 .58045 Mdot
.37536 .42059 Mdot
.78587 .51118 Mdot
.63584 .62308 Mdot
.80345 .38722 Mdot
.41364 .60942 Mdot
.45518 .62575 Mdot
.67179 .6059 Mdot
.44995 .33258 Mdot
.43526 .45267 Mdot
.62699 .63 Mdot
.61986 .39719 Mdot
.66714 .57242 Mdot
.46575 .67177 Mdot
.47663 .36164 Mdot
.66886 .29664 Mdot
.65796 .27717 Mdot
.29392 .64756 Mdot
.46881 .64043 Mdot
.67521 .43904 Mdot
.46434 .35102 Mdot
.65827 .62004 Mdot
.60824 .42719 Mdot
.38852 .60373 Mdot
.62827 .58623 Mdot
.61106 .44139 Mdot
.37508 .42706 Mdot
.28791 .36049 Mdot
.65491 .63656 Mdot
.59177 .52503 Mdot
.58048 .44925 Mdot
.63068 .40927 Mdot
.48738 .82869 Mdot
.67222 .60051 Mdot
.35024 .45252 Mdot
.60722 .43873 Mdot
.31857 .52087 Mdot
.3927 .59937 Mdot
.32469 .69476 Mdot
.83818 .54963 Mdot
.56409 .8348 Mdot
.72513 .36537 Mdot
.3323 .4334 Mdot
.63742 .42694 Mdot
.41629 .64553 Mdot
.66332 .59692 Mdot
.65818 .60519 Mdot
.4336 .57221 Mdot
.40134 .6214 Mdot
.43616 .58224 Mdot
.44095 .57538 Mdot
.26169 .42687 Mdot
.43633 .57943 Mdot
.50286 .28869 Mdot
.62493 .61146 Mdot
.41213 .63088 Mdot
.44468 .31454 Mdot
.37509 .61565 Mdot
.61916 .44508 Mdot
.45169 .61627 Mdot
.39586 .6248 Mdot
.48314 .6359 Mdot
.63171 .43084 Mdot
.28179 .27498 Mdot
.82823 .54441 Mdot
.18955 .4186 Mdot
.75718 .37834 Mdot
.45925 .33141 Mdot
.46696 .63315 Mdot
.36392 .44249 Mdot
.5396 .6055 Mdot
.44019 .61758 Mdot
.65447 .79176 Mdot
.39696 .61139 Mdot
.42859 .77413 Mdot
.42022 .69631 Mdot
.18462 .40745 Mdot
.50698 .40739 Mdot
.42459 .63249 Mdot
.56606 .68646 Mdot
.35607 .74599 Mdot
.5209 .55021 Mdot
.62728 .42553 Mdot
.4446 .32292 Mdot
.47172 .31818 Mdot
.62686 .46291 Mdot
.49833 .58233 Mdot
.46945 .71087 Mdot
.47405 .55789 Mdot
.66485 .29347 Mdot
.64768 .64564 Mdot
.34866 .46443 Mdot
.66954 .63396 Mdot
.82126 .3539 Mdot
.74151 .56973 Mdot
.56539 .42714 Mdot
.34901 .40671 Mdot
.43825 .3114 Mdot
.66122 .29412 Mdot
.35958 .44806 Mdot
.42888 .59597 Mdot
.66653 .62745 Mdot
.3803 .77238 Mdot
.41767 .69262 Mdot
.29048 .7396 Mdot
.64957 .57561 Mdot
.47896 .44051 Mdot
.6201 .43147 Mdot
.49127 .2993 Mdot
.45452 .64666 Mdot
.45207 .58643 Mdot
.59688 .6063 Mdot
.41781 .60131 Mdot
.69191 .66476 Mdot
.39362 .62453 Mdot
.48157 .3817 Mdot
.38747 .4619 Mdot
.63825 .44733 Mdot
.29963 .65686 Mdot
.68726 .63303 Mdot
.46167 .25336 Mdot
.48086 .30314 Mdot
.53529 .66465 Mdot
.59519 .44417 Mdot
.37213 .41998 Mdot
.46213 .30131 Mdot
.32521 .44264 Mdot
.45964 .66048 Mdot
.48166 .31215 Mdot
.34401 .45688 Mdot
.26897 .34905 Mdot
.39007 .64095 Mdot
.28519 .46605 Mdot
.59589 .41713 Mdot
.67552 .57517 Mdot
.4112 .61805 Mdot
.65545 .27872 Mdot
.42277 .67608 Mdot
.65179 .33694 Mdot
.68213 .27566 Mdot
.68426 .28719 Mdot
.54368 .19336 Mdot
.34945 .41677 Mdot
.74193 .41883 Mdot
.62921 .5155 Mdot
.61743 .61188 Mdot
.40798 .65449 Mdot
.22565 .3266 Mdot
.60841 .43848 Mdot
.43128 .59738 Mdot
.47487 .38583 Mdot
.60498 .43714 Mdot
.46586 .60847 Mdot
.63248 .42177 Mdot
.66268 .60082 Mdot
.41411 .29034 Mdot
.62878 .57568 Mdot
.38846 .63438 Mdot
.6108 .40307 Mdot
.45931 .30825 Mdot
.64346 .60689 Mdot
.42636 .61666 Mdot
.45888 .6376 Mdot
.66575 .28614 Mdot
.4187 .63428 Mdot
.23195 .3278 Mdot
.40838 .59916 Mdot
.43634 .3313 Mdot
.49545 .60575 Mdot
.57161 .84481 Mdot
.3015 .35351 Mdot
.62743 .62447 Mdot
.68345 .28145 Mdot
.482 .33354 Mdot
.40311 .29856 Mdot
.54896 .54247 Mdot
.43224 .62684 Mdot
.67641 .27984 Mdot
.45064 .42832 Mdot
.584 .39682 Mdot
.49555 .62932 Mdot
.74914 .55207 Mdot
.4635 .29764 Mdot
.66271 .29217 Mdot
.36111 .62391 Mdot
.60579 .5945 Mdot
.40115 .64486 Mdot
.47348 .30602 Mdot
.6688 .57242 Mdot
.38767 .64734 Mdot
.22589 .49304 Mdot
.67083 .27086 Mdot
.59667 .41859 Mdot
.44784 .70789 Mdot
.42811 .5837 Mdot
.46428 .3163 Mdot
.66181 .58214 Mdot
.5992 .39593 Mdot
.63692 .61458 Mdot
.36178 .75629 Mdot
.76654 .39615 Mdot
.24545 .4184 Mdot
.35343 .40628 Mdot
.65776 .32985 Mdot
.18198 .43985 Mdot
.76237 .43422 Mdot
.28962 .5716 Mdot
.16799 .55665 Mdot
.44953 .30825 Mdot
.326 .48837 Mdot
.47661 .33206 Mdot
.42777 .65347 Mdot
.477 .35169 Mdot
.18173 .40024 Mdot
.39592 .60853 Mdot
.46021 .32794 Mdot
.37007 .36804 Mdot
.40501 .61895 Mdot
.62963 .62024 Mdot
.43948 .18401 Mdot
.7857 .60441 Mdot
.72918 .58732 Mdot
.45374 .3305 Mdot
.68728 .73169 Mdot
.40398 .60619 Mdot
.37798 .60021 Mdot
.65834 .5959 Mdot
.49964 .61427 Mdot
.36314 .46333 Mdot
.3224 .43721 Mdot
.32437 .68358 Mdot
.8231 .4425 Mdot
.50907 .58898 Mdot
.6466 .6046 Mdot
.6873 .67891 Mdot
.73937 .49554 Mdot
.64979 .29971 Mdot
.57139 .40131 Mdot
.29045 .27055 Mdot
.52217 .63374 Mdot
.58979 .52908 Mdot
.74875 .53969 Mdot
.6645 .62409 Mdot
.25203 .34419 Mdot
.62147 .41559 Mdot
.60043 .67176 Mdot
.48722 .77081 Mdot
.43957 .58707 Mdot
.58185 .42899 Mdot
.41497 .55283 Mdot
.76252 .60533 Mdot
.33025 .50519 Mdot
.65144 .24997 Mdot
.39427 .64626 Mdot
.74382 .43256 Mdot
.45307 .62225 Mdot
.32174 .64075 Mdot
.40863 .59589 Mdot
.63325 .60932 Mdot
.49003 .56235 Mdot
.48418 .48503 Mdot
.83641 .49228 Mdot
.7451 .58273 Mdot
.3299 .43553 Mdot
.45755 .63469 Mdot
.44381 .58679 Mdot
.34152 .42683 Mdot
.63943 .59559 Mdot
.41105 .59269 Mdot
.24291 .58026 Mdot
.4328 .58465 Mdot
.62142 .44549 Mdot
.40998 .46419 Mdot
.70694 .57639 Mdot
.4779 .59586 Mdot
.62959 .5723 Mdot
.6289 .41835 Mdot
.59879 .3879 Mdot
.49863 .66137 Mdot
.63614 .42859 Mdot
.39794 .64134 Mdot
.41187 .43323 Mdot
.67854 .59401 Mdot
.35878 .64978 Mdot
.63893 .59143 Mdot
.71142 .69331 Mdot
.63021 .41441 Mdot
.653 .29435 Mdot
.56038 .57971 Mdot
.61445 .41305 Mdot
.74351 .64575 Mdot
.52501 .61137 Mdot
.39954 .67023 Mdot
.75989 .63279 Mdot
.45034 .3196 Mdot
.65698 .2969 Mdot
.61235 .4008 Mdot
.43203 .58231 Mdot
.47287 .65676 Mdot
.60819 .45319 Mdot
.6164 .72122 Mdot
.39673 .31692 Mdot
.40209 .59876 Mdot
.63345 .60424 Mdot
.65464 .62042 Mdot
.39433 .65627 Mdot
.432 .61428 Mdot
.43803 .33213 Mdot
.67147 .27454 Mdot
.66979 .30253 Mdot
.65621 .28056 Mdot
.50614 .31362 Mdot
.68189 .3721 Mdot
.63102 .40877 Mdot
.69051 .43378 Mdot
.57337 .34425 Mdot
.45782 .68578 Mdot
.46083 .31473 Mdot
.46506 .59706 Mdot
.43777 .65803 Mdot
.59813 .39701 Mdot
.72741 .326 Mdot
.36513 .57102 Mdot
.68325 .62029 Mdot
.63584 .43572 Mdot
.52026 .66086 Mdot
.56751 .37484 Mdot
.3621 .46117 Mdot
.73766 .60435 Mdot
.5851 .43516 Mdot
.65079 .62834 Mdot
.6095 .45665 Mdot
.44073 .58518 Mdot
.41533 .57539 Mdot
.67379 .61166 Mdot
.34679 .41639 Mdot
.47741 .65615 Mdot
.46608 .61023 Mdot
.68523 .79995 Mdot
.74407 .4899 Mdot
.61715 .37486 Mdot
.42354 .64309 Mdot
.42189 .6827 Mdot
.32971 .42767 Mdot
.429 .58734 Mdot
.45752 .6451 Mdot
.79216 .51399 Mdot
.64806 .45328 Mdot
.38696 .45022 Mdot
.59949 .66885 Mdot
.64656 .57634 Mdot
.25561 .30696 Mdot
.67667 .29227 Mdot
.64722 .44078 Mdot
.41512 .29047 Mdot
.6573 .2878 Mdot
.59925 .33826 Mdot
.255 .32445 Mdot
.65439 .28732 Mdot
.42343 .28924 Mdot
.4278 .52917 Mdot
.40611 .58528 Mdot
.45551 .61519 Mdot
.36714 .44311 Mdot
.66985 .59944 Mdot
.48768 .42147 Mdot
.29574 .31485 Mdot
.45251 .62932 Mdot
.58877 .6203 Mdot
.28774 .29673 Mdot
.66253 .28757 Mdot
.36239 .42466 Mdot
.3588 .46757 Mdot
.45632 .62331 Mdot
.78839 .47306 Mdot
.6452 .60869 Mdot
.42678 .61687 Mdot
.46391 .58631 Mdot
.45336 .32679 Mdot
.65543 .6307 Mdot
.48294 .30476 Mdot
.67944 .27289 Mdot
.21409 .63553 Mdot
.65878 .81526 Mdot
.59135 .40528 Mdot
.205 .40223 Mdot
.60991 .38396 Mdot
.61973 .21475 Mdot
.66062 .27628 Mdot
.43866 .62384 Mdot
.67668 .64001 Mdot
.42237 .6167 Mdot
.43881 .59336 Mdot
.42976 .59429 Mdot
.50535 .58248 Mdot
.64576 .7986 Mdot
.35153 .44184 Mdot
.45471 .6827 Mdot
.45525 .36147 Mdot
.22074 .36307 Mdot
.43317 .19902 Mdot
.47539 .6047 Mdot
.45951 .62543 Mdot
.61903 .60196 Mdot
.44963 .57113 Mdot
.57593 .40928 Mdot
.66816 .58327 Mdot
.46726 .66127 Mdot
.24545 .36226 Mdot
.41462 .58863 Mdot
.18305 .44937 Mdot
.60955 .456 Mdot
.73592 .60475 Mdot
.46813 .67566 Mdot
.65364 .28783 Mdot
.65643 .29631 Mdot
.65245 .30802 Mdot
.57406 .42265 Mdot
.4609 .32174 Mdot
.38313 .24675 Mdot
.4394 .55888 Mdot
.41145 .64324 Mdot
.42883 .68259 Mdot
.48409 .29097 Mdot
.42351 .47325 Mdot
.72701 .38201 Mdot
.52553 .64225 Mdot
.44798 .34837 Mdot
.68402 .58121 Mdot
.78843 .3439 Mdot
.66631 .5832 Mdot
.38701 .45219 Mdot
.60907 .44645 Mdot
.36806 .45831 Mdot
.67724 .75672 Mdot
.67724 .60731 Mdot
.59695 .60452 Mdot
.45903 .32943 Mdot
.50534 .44168 Mdot
.28809 .19668 Mdot
.4949 .34951 Mdot
.26567 .60031 Mdot
.65323 .59637 Mdot
.48691 .60898 Mdot
.44154 .42696 Mdot
.50286 .44681 Mdot
.46848 .33637 Mdot
.44207 .63706 Mdot
.82025 .46419 Mdot
.43731 .32844 Mdot
.49317 .63345 Mdot
.45601 .34582 Mdot
.62379 .43752 Mdot
.46065 .34809 Mdot
.69413 .61042 Mdot
.45424 .66094 Mdot
.35655 .14151 Mdot
.5482 .45173 Mdot
.41452 .61853 Mdot
.63579 .43538 Mdot
.23319 .5847 Mdot
.44968 .59528 Mdot
.3687 .46073 Mdot
.46789 .36324 Mdot
.38343 .32213 Mdot
.40567 .60769 Mdot
.46769 .346 Mdot
.68988 .60349 Mdot
.63827 .39337 Mdot
.5602 .18883 Mdot
.66257 .30221 Mdot
.66665 .59345 Mdot
.67105 .31217 Mdot
.57718 .43969 Mdot
.488 .63353 Mdot
.45313 .58076 Mdot
.62779 .60959 Mdot
.55235 .23355 Mdot
.46788 .57819 Mdot
.43768 .63384 Mdot
.44274 .30125 Mdot
.45087 .28236 Mdot
.50225 .22496 Mdot
.45026 .30909 Mdot
.42927 .68363 Mdot
.62872 .61046 Mdot
.42906 .6578 Mdot
.62857 .62123 Mdot
.40808 .65408 Mdot
.68794 .65076 Mdot
.66928 .58794 Mdot
.79011 .40771 Mdot
.44186 .65045 Mdot
.43141 .70267 Mdot
.43482 .59231 Mdot
.4196 .59344 Mdot
.47654 .36546 Mdot
.34393 .43232 Mdot
.49164 .58768 Mdot
.46321 .25888 Mdot
.3694 .42655 Mdot
.38717 .75576 Mdot
.45192 .32665 Mdot
.37003 .44468 Mdot
.27401 .43923 Mdot
.6832 .28421 Mdot
.35818 .43778 Mdot
.41856 .20891 Mdot
.59321 .40229 Mdot
.66604 .57515 Mdot
.40518 .62023 Mdot
.1836 .60023 Mdot
.40046 .47383 Mdot
.66884 .28072 Mdot
.41053 .60931 Mdot
.4608 .59559 Mdot
.6078 .59754 Mdot
.84195 .3916 Mdot
.4419 .29478 Mdot
.41381 .65067 Mdot
.62015 .58547 Mdot
.846 .53099 Mdot
.48495 .36009 Mdot
.36217 .43845 Mdot
.61876 .45149 Mdot
.67894 .56552 Mdot
.66188 .30288 Mdot
.58474 .39499 Mdot
.41144 .36024 Mdot
.70324 .73093 Mdot
.41189 .60387 Mdot
.46677 .31149 Mdot
.57126 .83303 Mdot
.48816 .57292 Mdot
.66138 .4084 Mdot
.37164 .72136 Mdot
.66079 .62528 Mdot
.61431 .4531 Mdot
.33417 .45438 Mdot
.67643 .58587 Mdot
.63889 .59759 Mdot
.61592 .39072 Mdot
.51718 .35 Mdot
.48201 .44175 Mdot
.61368 .45052 Mdot
.772 .56586 Mdot
.38107 .76718 Mdot
.67588 .27755 Mdot
.35741 .42075 Mdot
.40232 .7966 Mdot
.64656 .6145 Mdot
.28849 .27188 Mdot
.628 .80495 Mdot
.39875 .59935 Mdot
.35474 .45791 Mdot
.59876 .35066 Mdot
.3691 .2503 Mdot
.60104 .43492 Mdot
.44391 .47712 Mdot
.37566 .45715 Mdot
.40792 .58811 Mdot
.68958 .55536 Mdot
.438 .64739 Mdot
.61623 .44185 Mdot
.7253 .65356 Mdot
.64646 .62827 Mdot
.58291 .44759 Mdot
.74471 .63351 Mdot
.44024 .65819 Mdot
.44241 .64414 Mdot
.31902 .59384 Mdot
.66782 .62748 Mdot
.66556 .30421 Mdot
.42551 .62432 Mdot
.45838 .60827 Mdot
.48975 .62767 Mdot
.49364 .69032 Mdot
.77874 .4825 Mdot
.41767 .65275 Mdot
.5072 .33054 Mdot
.37475 .63313 Mdot
.44519 .64612 Mdot
.61976 .58167 Mdot
.66727 .80186 Mdot
.66787 .26837 Mdot
.45306 .61314 Mdot
.4115 .59569 Mdot
.60983 .3915 Mdot
.4663 .43298 Mdot
.50783 .45221 Mdot
.49606 .33177 Mdot
.29447 .54164 Mdot
.49505 .57375 Mdot
.63374 .58295 Mdot
.37926 .42668 Mdot
.47577 .63721 Mdot
.62583 .58584 Mdot
.38102 .60744 Mdot
.44088 .33676 Mdot
.67272 .27615 Mdot
.66537 .53424 Mdot
.35853 .43217 Mdot
.46459 .40565 Mdot
.68838 .47096 Mdot
.44357 .31887 Mdot
.40795 .63768 Mdot
.64143 .40521 Mdot
.48875 .31715 Mdot
.66776 .2851 Mdot
.36306 .63797 Mdot
.65521 .6045 Mdot
.64274 .6247 Mdot
.32167 .67154 Mdot
.42892 .30307 Mdot
.79567 .66023 Mdot
.62284 .43833 Mdot
.4411 .67226 Mdot
.65105 .48782 Mdot
.63993 .62438 Mdot
.31626 .66925 Mdot
.37058 .44246 Mdot
.59922 .43317 Mdot
.64656 .2941 Mdot
.62259 .59143 Mdot
.65961 .63395 Mdot
.39422 .64888 Mdot
.47412 .61865 Mdot
.28488 .58026 Mdot
.32124 .68123 Mdot
.63056 .42909 Mdot
.35023 .42005 Mdot
.49691 .31922 Mdot
.42994 .65063 Mdot
.67302 .58781 Mdot
.41879 .7699 Mdot
.42676 .58141 Mdot
.43701 .32921 Mdot
.66513 .62147 Mdot
.34223 .42399 Mdot
.37649 .44151 Mdot
.42005 .59326 Mdot
.59156 .79184 Mdot
.60931 .40884 Mdot
.63415 .6229 Mdot
.59636 .56639 Mdot
.48193 .58768 Mdot
.47218 .62352 Mdot
.36914 .58587 Mdot
.5879 .39388 Mdot
.69043 .55102 Mdot
.38446 .43024 Mdot
.66017 .60913 Mdot
.41676 .61828 Mdot
.35972 .42855 Mdot
.61321 .54153 Mdot
.66007 .28035 Mdot
.45929 .34937 Mdot
.3626 .46422 Mdot
.33837 .44343 Mdot
.37004 .4245 Mdot
.30557 .25665 Mdot
.6485 .6448 Mdot
.6733 .67542 Mdot
.40829 .59431 Mdot
.32229 .66758 Mdot
.4319 .56698 Mdot
.57566 .43004 Mdot
.45052 .31422 Mdot
.44076 .5912 Mdot
.39574 .65079 Mdot
.40971 .71671 Mdot
.49306 .68607 Mdot
.59094 .59431 Mdot
.67535 .61869 Mdot
.47108 .69747 Mdot
.45266 .32066 Mdot
.86697 .43365 Mdot
.21652 .30498 Mdot
.48136 .66624 Mdot
.48654 .4312 Mdot
.67036 .58589 Mdot
.62252 .3935 Mdot
.50977 .46334 Mdot
.62433 .45241 Mdot
.66119 .61263 Mdot
.42841 .65215 Mdot
.69294 .43447 Mdot
.32682 .42493 Mdot
.4389 .58102 Mdot
.617 .4337 Mdot
.43739 .58157 Mdot
.58002 .43306 Mdot
.63784 .66105 Mdot
.75771 .54184 Mdot
.39707 .60989 Mdot
.487 .59751 Mdot
.42132 .71305 Mdot
.47565 .60702 Mdot
.60785 .29455 Mdot
.64803 .58903 Mdot
.82094 .45022 Mdot
.38974 .64866 Mdot
.6327 .75976 Mdot
.41728 .58307 Mdot
.55472 .24715 Mdot
.47717 .62116 Mdot
.51826 .48916 Mdot
.40244 .59136 Mdot
.46326 .63632 Mdot
.61436 .40447 Mdot
.61036 .39123 Mdot
.68931 .60934 Mdot
.66153 .30486 Mdot
.18992 .40151 Mdot
.46951 .61554 Mdot
.50915 .32962 Mdot
.63498 .49295 Mdot
.33916 .43816 Mdot
.65736 .61413 Mdot
.85304 .54722 Mdot
.63087 .41902 Mdot
.46553 .37722 Mdot
.57039 .24887 Mdot
.4858 .29814 Mdot
.62431 .48024 Mdot
.52952 .65224 Mdot
.34002 .42265 Mdot
.41329 .58427 Mdot
.46698 .80624 Mdot
.74014 .46069 Mdot
.47071 .66401 Mdot
.60603 .46088 Mdot
.53957 .59689 Mdot
.41095 .79472 Mdot
.33716 .4624 Mdot
.33236 .44718 Mdot
.61829 .4073 Mdot
.45216 .29434 Mdot
.44572 .55108 Mdot
.37096 .4443 Mdot
.44339 .33294 Mdot
.66308 .30834 Mdot
.53249 .53561 Mdot
.64734 .6105 Mdot
.72187 .57511 Mdot
.7012 .50014 Mdot
.63084 .42737 Mdot
.45242 .26017 Mdot
.68169 .57242 Mdot
.60373 .60709 Mdot
.65475 .30125 Mdot
.47494 .36623 Mdot
.67013 .64398 Mdot
.48163 .64871 Mdot
.43499 .6962 Mdot
.45175 .62294 Mdot
.36253 .45191 Mdot
.47978 .60891 Mdot
.46091 .36412 Mdot
.60556 .43433 Mdot
.48742 .32586 Mdot
.60548 .40601 Mdot
.70124 .40698 Mdot
.42722 .61038 Mdot
.46345 .63119 Mdot
.41792 .42727 Mdot
.6738 .6299 Mdot
.62897 .79197 Mdot
.50996 .33367 Mdot
.47123 .32744 Mdot
.43586 .66147 Mdot
.6888 .59901 Mdot
.37121 .478 Mdot
.42056 .41512 Mdot
.47466 .59692 Mdot
.64888 .58816 Mdot
.41213 .64744 Mdot
.26347 .40067 Mdot
.75671 .5259 Mdot
.6373 .61698 Mdot
.83587 .44905 Mdot
.42944 .64373 Mdot
.44696 .52735 Mdot
.42042 .68308 Mdot
.25195 .55768 Mdot
.48821 .59359 Mdot
.65162 .57525 Mdot
.45015 .61741 Mdot
.65561 .58118 Mdot
.44343 .30534 Mdot
.63118 .403 Mdot
.66437 .59179 Mdot
.48175 .60298 Mdot
.30664 .23837 Mdot
.62141 .43548 Mdot
.45721 .63705 Mdot
.58466 .42514 Mdot
.63186 .57737 Mdot
.67696 .6239 Mdot
.42451 .21212 Mdot
.64453 .39156 Mdot
.62533 .43253 Mdot
.40297 .64193 Mdot
.68423 .51784 Mdot
.42738 .65657 Mdot
.28509 .59187 Mdot
.41613 .6659 Mdot
.49596 .60419 Mdot
.60724 .17913 Mdot
.62795 .3891 Mdot
.80358 .63664 Mdot
.28965 .32534 Mdot
.32387 .24123 Mdot
.69598 .5741 Mdot
.33744 .46267 Mdot
.25799 .33176 Mdot
.68081 .27459 Mdot
.46333 .35745 Mdot
.4397 .59065 Mdot
.7155 .62751 Mdot
.62321 .44586 Mdot
.34361 .43713 Mdot
.39674 .61099 Mdot
.44075 .34109 Mdot
.46018 .21461 Mdot
.63698 .42865 Mdot
.64879 .61439 Mdot
.67824 .62576 Mdot
.83853 .53338 Mdot
.41435 .61479 Mdot
.45973 .63151 Mdot
.61039 .44571 Mdot
.5031 .59141 Mdot
.36135 .41582 Mdot
.32793 .37549 Mdot
.62525 .43011 Mdot
.56471 .46976 Mdot
.67985 .60771 Mdot
.46201 .5955 Mdot
.41236 .48015 Mdot
.52952 .29507 Mdot
.52699 .6977 Mdot
.36568 .44372 Mdot
.29865 .58452 Mdot
.65102 .57529 Mdot
.61114 .43 Mdot
.28903 .44314 Mdot
.42591 .67526 Mdot
.46177 .59897 Mdot
.3017 .58577 Mdot
.46082 .42862 Mdot
.35521 .47935 Mdot
.44913 .57012 Mdot
.45287 .43332 Mdot
.43907 .66242 Mdot
.47089 .65789 Mdot
.50626 .63856 Mdot
.46982 .63497 Mdot
.65397 .58547 Mdot
.41318 .71892 Mdot
.46684 .35067 Mdot
.5925 .707 Mdot
.46016 .47361 Mdot
.41417 .62619 Mdot
.43099 .65356 Mdot
.53987 .66853 Mdot
.60879 .48715 Mdot
.64841 .59231 Mdot
.64688 .64934 Mdot
.6259 .40768 Mdot
.42864 .70005 Mdot
.46817 .28902 Mdot
.37689 .71999 Mdot
.48915 .3303 Mdot
.64855 .58728 Mdot
.46795 .32134 Mdot
.62163 .40247 Mdot
.46771 .31114 Mdot
.50674 .3162 Mdot
.59574 .44931 Mdot
.68201 .60464 Mdot
.47503 .59895 Mdot
.63155 .41523 Mdot
.31593 .59664 Mdot
.36354 .45172 Mdot
.4245 .21175 Mdot
.37151 .62218 Mdot
.35379 .56931 Mdot
.22663 .49151 Mdot
.48372 .32248 Mdot
.76891 .52471 Mdot
.66933 .58827 Mdot
.35301 .40914 Mdot
.65611 .58383 Mdot
.65369 .78574 Mdot
.34456 .42654 Mdot
.41594 .21008 Mdot
.31536 .40654 Mdot
.40239 .26559 Mdot
.43503 .56986 Mdot
.65532 .65783 Mdot
.4857 .31102 Mdot
.62568 .44355 Mdot
.47774 .39254 Mdot
.4616 .64736 Mdot
.7614 .42555 Mdot
.62358 .63048 Mdot
.67769 .29645 Mdot
.60645 .42475 Mdot
.60782 .46307 Mdot
.41535 .61065 Mdot
.41487 .27783 Mdot
.44157 .66763 Mdot
.31069 .46685 Mdot
.29576 .56435 Mdot
.37729 .72143 Mdot
.39856 .6439 Mdot
.49268 .32996 Mdot
.41036 .64619 Mdot
.51333 .56814 Mdot
.48047 .82669 Mdot
.37182 .63979 Mdot
.7748 .39624 Mdot
.40552 .39629 Mdot
.67448 .60826 Mdot
.4761 .67285 Mdot
.67387 .28704 Mdot
.42634 .6436 Mdot
.27778 .76816 Mdot
.35548 .43614 Mdot
.42111 .34048 Mdot
.45029 .57331 Mdot
.42302 .62042 Mdot
.51024 .80785 Mdot
.70734 .64608 Mdot
.64674 .2892 Mdot
.45898 .60098 Mdot
.30782 .53507 Mdot
.58782 .39756 Mdot
.42044 .67114 Mdot
.45516 .61815 Mdot
.34952 .74609 Mdot
.58047 .40834 Mdot
.47914 .31845 Mdot
.68307 .2776 Mdot
.49855 .32076 Mdot
.3589 .4714 Mdot
.52388 .46759 Mdot
.32066 .68836 Mdot
.75375 .52359 Mdot
.37391 .45608 Mdot
.45574 .57914 Mdot
.38681 .53554 Mdot
.43097 .63473 Mdot
.33224 .44927 Mdot
.57715 .41443 Mdot
.65709 .5883 Mdot
.66163 .52999 Mdot
.6651 .29185 Mdot
.49245 .63361 Mdot
.33095 .45431 Mdot
.66025 .5991 Mdot
.50582 .248 Mdot
.66797 .60637 Mdot
.61768 .41614 Mdot
.57415 .43065 Mdot
.35019 .42701 Mdot
.65397 .58382 Mdot
.50442 .33857 Mdot
.29306 .3222 Mdot
.41615 .66352 Mdot
.5872 .37176 Mdot
.69149 .62334 Mdot
.64183 .56516 Mdot
.64177 .63833 Mdot
.42053 .60615 Mdot
.47588 .43293 Mdot
.44873 .67605 Mdot
.62343 .41097 Mdot
.45208 .34566 Mdot
.3276 .70158 Mdot
.51652 .81512 Mdot
.55728 .46263 Mdot
.49283 .59048 Mdot
.45308 .64504 Mdot
.45623 .62352 Mdot
.38959 .61283 Mdot
.28298 .39436 Mdot
.43045 .61209 Mdot
.61006 .40427 Mdot
.48699 .35065 Mdot
.41035 .61311 Mdot
.67576 .28724 Mdot
.47266 .44873 Mdot
.38087 .43322 Mdot
.50011 .47619 Mdot
.25779 .27849 Mdot
.65963 .59796 Mdot
.46366 .30313 Mdot
.46649 .35741 Mdot
.37501 .42677 Mdot
.62912 .43569 Mdot
.66863 .60209 Mdot
.24951 .53162 Mdot
.36336 .42011 Mdot
.45212 .61251 Mdot
.40707 .37238 Mdot
.81935 .40456 Mdot
.43422 .57357 Mdot
.44082 .599 Mdot
.68458 .28304 Mdot
.45836 .29115 Mdot
.18315 .63054 Mdot
.45696 .41832 Mdot
.34624 .43021 Mdot
.3349 .44473 Mdot
.6408 .63901 Mdot
.47858 .66021 Mdot
.6023 .40941 Mdot
.43189 .42896 Mdot
.24929 .61955 Mdot
.51768 .37896 Mdot
.61036 .21213 Mdot
.41991 .58803 Mdot
.51274 .79896 Mdot
.41432 .65601 Mdot
.60653 .59789 Mdot
.62145 .61894 Mdot
.64695 .59802 Mdot
.61913 .41089 Mdot
.7059 .69755 Mdot
.60649 .40277 Mdot
.24487 .28391 Mdot
.66701 .57927 Mdot
.33799 .31287 Mdot
.46402 .32472 Mdot
.45537 .56423 Mdot
.34496 .41982 Mdot
.56694 .46359 Mdot
.50953 .63396 Mdot
.78097 .46846 Mdot
.46147 .31461 Mdot
.68059 .61728 Mdot
.52962 .60963 Mdot
.15979 .45693 Mdot
.51666 .44386 Mdot
.46082 .51902 Mdot
.61326 .80005 Mdot
.34297 .42579 Mdot
.53932 .68331 Mdot
.35089 .41397 Mdot
.60838 .43987 Mdot
.4637 .64535 Mdot
.47109 .63657 Mdot
.40257 .6497 Mdot
.42956 .60986 Mdot
.60147 .39578 Mdot
.38381 .62665 Mdot
.57182 .84468 Mdot
.67921 .27765 Mdot
.26345 .3689 Mdot
.36876 .45427 Mdot
.60262 .45619 Mdot
.48911 .34213 Mdot
.6629 .30642 Mdot
.30353 .66919 Mdot
.40105 .59567 Mdot
.43738 .59189 Mdot
.6503 .29229 Mdot
.50789 .62577 Mdot
.52648 .62427 Mdot
.46913 .35077 Mdot
.55978 .47309 Mdot
.34752 .46553 Mdot
.36726 .45896 Mdot
.59188 .44425 Mdot
.65544 .58351 Mdot
.36882 .4415 Mdot
.44529 .29693 Mdot
.38172 .62238 Mdot
.4861 .62592 Mdot
.69129 .62319 Mdot
.62834 .80491 Mdot
.33049 .45764 Mdot
.52008 .59321 Mdot
.65206 .57824 Mdot
.63239 .63831 Mdot
.45771 .59836 Mdot
.36471 .61729 Mdot
.65964 .5671 Mdot
.37644 .44647 Mdot
.60481 .45739 Mdot
.3797 .27453 Mdot
.61436 .44046 Mdot
.66625 .5994 Mdot
.38162 .6409 Mdot
.68125 .60584 Mdot
.42404 .63911 Mdot
.71889 .21292 Mdot
.47442 .62851 Mdot
.77702 .61409 Mdot
.25886 .56625 Mdot
.47121 .35886 Mdot
.50423 .33437 Mdot
.67659 .28146 Mdot
.65363 .57721 Mdot
.47375 .64078 Mdot
.33377 .43629 Mdot
.34671 .23235 Mdot
.69869 .63615 Mdot
.44822 .34626 Mdot
.46719 .28997 Mdot
.57953 .4043 Mdot
.42729 .57838 Mdot
.46806 .60037 Mdot
.46989 .31153 Mdot
.23689 .46733 Mdot
.63006 .58706 Mdot
.4588 .63185 Mdot
.44985 .64638 Mdot
.47272 .35529 Mdot
.2908 .32828 Mdot
.65784 .66128 Mdot
.46654 .63808 Mdot
.3425 .39613 Mdot
.57525 .42748 Mdot
.39004 .61817 Mdot
.38425 .62447 Mdot
.34304 .45101 Mdot
.24166 .38459 Mdot
.43052 .80785 Mdot
.58832 .4465 Mdot
.66679 .30339 Mdot
.48213 .60132 Mdot
.46406 .32676 Mdot
.48708 .61146 Mdot
.19029 .48822 Mdot
.68157 .28401 Mdot
.4357 .61946 Mdot
.4896 .65971 Mdot
.64193 .63095 Mdot
.43036 .61814 Mdot
.40359 .74597 Mdot
.49919 .33487 Mdot
.43348 .61798 Mdot
.60787 .79047 Mdot
.58619 .39698 Mdot
.48487 .66547 Mdot
.34452 .46095 Mdot
.24896 .55943 Mdot
.69167 .48307 Mdot
.49306 .29451 Mdot
.37306 .44785 Mdot
.47716 .60003 Mdot
.45335 .29535 Mdot
.62756 .4441 Mdot
.76666 .44462 Mdot
.39919 .58906 Mdot
.61815 .43981 Mdot
.60588 .4329 Mdot
.35331 .42967 Mdot
.81582 .603 Mdot
.50965 .61124 Mdot
.47646 .60594 Mdot
.30635 .72195 Mdot
.62244 .62693 Mdot
.47476 .60043 Mdot
.43988 .57698 Mdot
.59567 .41276 Mdot
.56186 .57669 Mdot
.58266 .6408 Mdot
.36925 .36865 Mdot
.57959 .43288 Mdot
.49812 .29216 Mdot
.45378 .2958 Mdot
.36883 .45322 Mdot
.67115 .61312 Mdot
.38058 .44924 Mdot
.45699 .33693 Mdot
.41121 .59453 Mdot
.59278 .42346 Mdot
.50646 .73214 Mdot
.6362 .4029 Mdot
.44138 .34856 Mdot
.61857 .57697 Mdot
.65899 .48077 Mdot
.39757 .82373 Mdot
.70777 .48879 Mdot
.63704 .46036 Mdot
.33913 .4391 Mdot
.41496 .3917 Mdot
.45145 .64506 Mdot
.57002 .66433 Mdot
.45399 .58379 Mdot
.60595 .80126 Mdot
.44696 .31878 Mdot
.65336 .30099 Mdot
.46423 .64525 Mdot
.30166 .56955 Mdot
.62509 .46239 Mdot
.58075 .40103 Mdot
.4342 .60364 Mdot
.61568 .41335 Mdot
.47342 .61494 Mdot
.48627 .35514 Mdot
.79609 .62916 Mdot
.45529 .64153 Mdot
.39564 .67348 Mdot
.65591 .43626 Mdot
.42278 .21124 Mdot
.50221 .35695 Mdot
.51085 .80107 Mdot
.15092 .49201 Mdot
.61327 .41313 Mdot
.43194 .68524 Mdot
.47896 .30894 Mdot
.68479 .28384 Mdot
.48554 .37236 Mdot
.445 .58334 Mdot
.42502 .59012 Mdot
.43386 .66158 Mdot
.4418 .64462 Mdot
.5654 .66124 Mdot
.51416 .66196 Mdot
.52392 .78268 Mdot
.4373 .59331 Mdot
.64737 .54519 Mdot
.60618 .39986 Mdot
.59185 .59417 Mdot
.31892 .42531 Mdot
.41649 .59116 Mdot
.71659 .63517 Mdot
.59503 .45096 Mdot
.24325 .28827 Mdot
.57975 .4063 Mdot
.48309 .33517 Mdot
.62034 .38907 Mdot
.4202 .63512 Mdot
.65321 .621 Mdot
.49611 .34428 Mdot
.72023 .38652 Mdot
.46151 .3573 Mdot
.41415 .61787 Mdot
.28828 .34971 Mdot
.46549 .35581 Mdot
.47925 .45647 Mdot
.65858 .62114 Mdot
.31453 .53287 Mdot
.61555 .60633 Mdot
.43457 .62307 Mdot
.43626 .62757 Mdot
.66961 .30656 Mdot
.63827 .42258 Mdot
.63817 .57503 Mdot
.69426 .79356 Mdot
.37576 .464 Mdot
.64154 .6034 Mdot
.4169 .56105 Mdot
.4724 .42807 Mdot
.6329 .61857 Mdot
.277 .52645 Mdot
.62913 .43804 Mdot
.66034 .64375 Mdot
.3949 .56897 Mdot
.58098 .53185 Mdot
.33582 .41593 Mdot
.44487 .35062 Mdot
.56562 .50799 Mdot
.48787 .31181 Mdot
.58751 .44843 Mdot
.43133 .30673 Mdot
.58981 .39741 Mdot
.74097 .6482 Mdot
.69203 .66604 Mdot
.64301 .41699 Mdot
.57629 .4371 Mdot
.46208 .33593 Mdot
.39577 .60359 Mdot
.46855 .48725 Mdot
.4723 .57784 Mdot
.42018 .57244 Mdot
.59179 .3935 Mdot
.63215 .57951 Mdot
.67349 .57831 Mdot
.62163 .64886 Mdot
.6714 .63005 Mdot
.49087 .34083 Mdot
.76761 .53671 Mdot
.669 .76389 Mdot
.59246 .44163 Mdot
.56822 .39703 Mdot
.42817 .65594 Mdot
.46287 .32971 Mdot
.44369 .30929 Mdot
.59805 .41811 Mdot
.54607 .69937 Mdot
.41689 .6809 Mdot
.61204 .59171 Mdot
.66861 .58037 Mdot
.63155 .61358 Mdot
.65537 .63942 Mdot
.66557 .69361 Mdot
.62647 .44316 Mdot
.66035 .57775 Mdot
.43573 .60995 Mdot
.43063 .58655 Mdot
.66239 .29909 Mdot
.35592 .46291 Mdot
.38247 .5975 Mdot
.37598 .64844 Mdot
.45755 .59678 Mdot
.46018 .35076 Mdot
.355 .62287 Mdot
.67761 .29271 Mdot
.43649 .29816 Mdot
.48385 .29216 Mdot
.65346 .29479 Mdot
.57534 .59406 Mdot
.15067 .46506 Mdot
.41397 .65062 Mdot
.40721 .51166 Mdot
.46779 .33077 Mdot
.79494 .54432 Mdot
.64471 .54007 Mdot
.39605 .64033 Mdot
.54774 .53412 Mdot
.49262 .35089 Mdot
.61902 .62598 Mdot
.46498 .59143 Mdot
.65986 .27589 Mdot
.37944 .42901 Mdot
.41945 .55971 Mdot
.68456 .27894 Mdot
.64675 .58608 Mdot
.35655 .49204 Mdot
.65009 .64357 Mdot
.48872 .35899 Mdot
.49038 .66107 Mdot
.29607 .18803 Mdot
.47859 .3028 Mdot
.34485 .24525 Mdot
.67607 .66666 Mdot
.45786 .64175 Mdot
.48361 .30554 Mdot
.61295 .6175 Mdot
.5732 .42306 Mdot
.44502 .43973 Mdot
.67435 .59145 Mdot
.66001 .3057 Mdot
.65838 .29561 Mdot
.46931 .35272 Mdot
.66959 .62291 Mdot
.40527 .66437 Mdot
.62869 .62374 Mdot
.62018 .38792 Mdot
.39654 .62473 Mdot
.18274 .40973 Mdot
.44691 .69593 Mdot
.64467 .57764 Mdot
.43559 .3259 Mdot
.33172 .42337 Mdot
.39934 .60714 Mdot
.30333 .28339 Mdot
.43431 .57668 Mdot
.5811 .41888 Mdot
.81253 .48852 Mdot
.49055 .73399 Mdot
.40696 .59653 Mdot
.43039 .65547 Mdot
.59983 .4513 Mdot
.39997 .59927 Mdot
.43349 .57457 Mdot
.65888 .40575 Mdot
.64342 .62986 Mdot
.45004 .62502 Mdot
.44129 .32367 Mdot
.50689 .82237 Mdot
.48234 .60041 Mdot
.7631 .37427 Mdot
.31152 .54668 Mdot
.81116 .51358 Mdot
.48466 .61397 Mdot
.31526 .61168 Mdot
.44172 .63204 Mdot
.41573 .60168 Mdot
.40621 .64773 Mdot
.49653 .79125 Mdot
.45926 .33356 Mdot
.45265 .35625 Mdot
.33687 .41443 Mdot
.30907 .54589 Mdot
.35291 .45691 Mdot
.58494 .43838 Mdot
.54329 .19631 Mdot
.68024 .28018 Mdot
.65607 .58283 Mdot
.45569 .6618 Mdot
.48973 .36044 Mdot
.45796 .59159 Mdot
.42081 .63922 Mdot
.48835 .35637 Mdot
.46902 .29715 Mdot
.4229 .3205 Mdot
.35252 .41506 Mdot
.65465 .59312 Mdot
.39078 .64278 Mdot
.36901 .42642 Mdot
.40861 .66756 Mdot
.45871 .42264 Mdot
.65175 .59295 Mdot
.63044 .62543 Mdot
.63943 .57177 Mdot
.41169 .59326 Mdot
.41504 .62993 Mdot
.60495 .40261 Mdot
.69366 .61994 Mdot
.6025 .44888 Mdot
.48936 .31647 Mdot
.50062 .34747 Mdot
.44412 .58334 Mdot
.52336 .59472 Mdot
.33539 .44264 Mdot
.48336 .32982 Mdot
.64976 .28998 Mdot
.34407 .41177 Mdot
.41087 .6086 Mdot
.49164 .32686 Mdot
.36639 .46067 Mdot
.56131 .71307 Mdot
.15798 .52467 Mdot
.32776 .42986 Mdot
.43571 .60518 Mdot
.51815 .81053 Mdot
.30201 .47314 Mdot
.38137 .4564 Mdot
.59097 .43644 Mdot
.43289 .57817 Mdot
.21658 .56797 Mdot
.37054 .46308 Mdot
.60842 .80804 Mdot
.47456 .3588 Mdot
.55333 .5726 Mdot
.38748 .57474 Mdot
.58586 .67574 Mdot
.38041 .45245 Mdot
.66465 .60532 Mdot
.698 .61372 Mdot
.44459 .60898 Mdot
.32962 .40585 Mdot
.59432 .38734 Mdot
.47574 .36136 Mdot
.50838 .33098 Mdot
.66324 .62708 Mdot
.71537 .53183 Mdot
.43875 .32473 Mdot
.47856 .55725 Mdot
.41079 .30753 Mdot
.39122 .6873 Mdot
.7343 .66198 Mdot
.71202 .38703 Mdot
.48421 .63259 Mdot
.3285 .43414 Mdot
.61887 .45645 Mdot
.6096 .40576 Mdot
.62183 .4207 Mdot
.50307 .32332 Mdot
.50818 .46601 Mdot
.45963 .31263 Mdot
.75617 .43464 Mdot
.36033 .42884 Mdot
.30807 .51304 Mdot
.4739 .63817 Mdot
.45393 .64337 Mdot
.40222 .66547 Mdot
.44425 .66517 Mdot
.44386 .63266 Mdot
.62902 .43088 Mdot
.49691 .30828 Mdot
.38151 .32801 Mdot
.63193 .60357 Mdot
.52043 .23946 Mdot
.46405 .32436 Mdot
.68377 .2821 Mdot
.34908 .44203 Mdot
.32106 .63499 Mdot
.45133 .27998 Mdot
.46875 .32225 Mdot
.38343 .60872 Mdot
.61783 .59927 Mdot
.51665 .67299 Mdot
.4381 .63418 Mdot
.48358 .32716 Mdot
.50954 .37567 Mdot
.51058 .70179 Mdot
.37591 .56514 Mdot
.38259 .46991 Mdot
.47722 .42964 Mdot
.38243 .42423 Mdot
.36712 .6163 Mdot
.79568 .54051 Mdot
.45827 .33808 Mdot
.4806 .34326 Mdot
.33255 .45491 Mdot
.44713 .52924 Mdot
.66911 .61986 Mdot
.65268 .3008 Mdot
.58469 .41938 Mdot
.43227 .63273 Mdot
.50139 .32529 Mdot
.47899 .5335 Mdot
.40185 .32321 Mdot
.62394 .42889 Mdot
.43734 .29722 Mdot
.4178 .58369 Mdot
.43632 .6028 Mdot
.34114 .42842 Mdot
.42251 .49973 Mdot
.43573 .56121 Mdot
.3228 .24187 Mdot
.75503 .54031 Mdot
.74579 .56816 Mdot
.46217 .59915 Mdot
.65962 .63004 Mdot
.65885 .27871 Mdot
.35682 .42022 Mdot
.38588 .64234 Mdot
.15151 .51058 Mdot
.68688 .58185 Mdot
.61425 .43441 Mdot
.65589 .28253 Mdot
.5061 .46532 Mdot
.43719 .57633 Mdot
.45484 .58425 Mdot
.4249 .60789 Mdot
.1478 .53762 Mdot
.4449 .34106 Mdot
.64599 .63854 Mdot
.36422 .44601 Mdot
.65818 .63719 Mdot
.45598 .35719 Mdot
.65915 .52429 Mdot
.40767 .61207 Mdot
.6128 .5882 Mdot
.66435 .60795 Mdot
.57893 .40493 Mdot
.57489 .40387 Mdot
.42286 .30961 Mdot
.47371 .62874 Mdot
.66478 .27189 Mdot
.61815 .61288 Mdot
.4749 .29477 Mdot
.34437 .42598 Mdot
.62815 .41137 Mdot
.43565 .59372 Mdot
.46258 .34537 Mdot
.48454 .64928 Mdot
.62679 .615 Mdot
.46835 .32296 Mdot
.67406 .2678 Mdot
.33784 .45106 Mdot
.42891 .59137 Mdot
.3591 .4842 Mdot
.65167 .29341 Mdot
.44851 .64943 Mdot
.3514 .71099 Mdot
.31244 .43041 Mdot
.72229 .38275 Mdot
.46114 .30702 Mdot
.67156 .29359 Mdot
.62572 .62478 Mdot
.59847 .53763 Mdot
.48279 .34494 Mdot
.34127 .68202 Mdot
.45949 .49861 Mdot
.38915 .63868 Mdot
.64246 .61593 Mdot
.39118 .38925 Mdot
.27475 .27753 Mdot
.28378 .45103 Mdot
.45627 .63053 Mdot
.48517 .3069 Mdot
.37125 .45529 Mdot
.58915 .43862 Mdot
.76525 .37607 Mdot
.70179 .67452 Mdot
.43272 .29958 Mdot
.4142 .65251 Mdot
.61808 .6118 Mdot
.59884 .42004 Mdot
.69443 .42005 Mdot
.44109 .30041 Mdot
.44808 .31387 Mdot
.40792 .60544 Mdot
.36872 .43638 Mdot
.25169 .44025 Mdot
.45395 .35875 Mdot
.49806 .31716 Mdot
.51209 .23545 Mdot
.32682 .44844 Mdot
.4405 .61212 Mdot
.62285 .64944 Mdot
.3917 .59959 Mdot
.34832 .23833 Mdot
.67696 .29076 Mdot
.63103 .60171 Mdot
.43344 .58309 Mdot
.39896 .36165 Mdot
.488 .33757 Mdot
.48792 .43238 Mdot
.43496 .33692 Mdot
.6299 .43257 Mdot
.50195 .32832 Mdot
.46502 .59321 Mdot
.62396 .46306 Mdot
.33649 .4452 Mdot
.4676 .63706 Mdot
.4142 .63044 Mdot
.60882 .61198 Mdot
.60635 .44047 Mdot
.40627 .7835 Mdot
.57055 .43027 Mdot
.60875 .45622 Mdot
.67858 .64447 Mdot
.44827 .61068 Mdot
.47956 .33139 Mdot
.44991 .35975 Mdot
.39166 .64931 Mdot
.78964 .55549 Mdot
.66491 .62388 Mdot
.42362 .30066 Mdot
.18249 .6246 Mdot
.43621 .54784 Mdot
.66252 .27049 Mdot
.38411 .53145 Mdot
.57614 .40574 Mdot
.43461 .59813 Mdot
.64317 .57943 Mdot
.4927 .30807 Mdot
.43913 .32487 Mdot
.38731 .64842 Mdot
.60091 .42941 Mdot
.38072 .4419 Mdot
.44844 .30857 Mdot
.4078 .30045 Mdot
.426 .61437 Mdot
.76184 .42137 Mdot
.455 .30452 Mdot
.38044 .20012 Mdot
.38925 .33463 Mdot
.63726 .61444 Mdot
.41852 .63965 Mdot
.68639 .61543 Mdot
.35982 .45016 Mdot
.51197 .31158 Mdot
.60331 .43322 Mdot
.38269 .5516 Mdot
.46108 .83273 Mdot
.45863 .3295 Mdot
.65298 .58614 Mdot
.40751 .59494 Mdot
.42078 .5423 Mdot
.47916 .61138 Mdot
.56535 .57837 Mdot
.31759 .45512 Mdot
.59161 .39267 Mdot
.58172 .42287 Mdot
.4384 .6575 Mdot
.36281 .41752 Mdot
.47103 .36888 Mdot
.47834 .35899 Mdot
.86522 .40502 Mdot
.67488 .26761 Mdot
.27794 .58196 Mdot
.42484 .59194 Mdot
.47708 .29411 Mdot
.50916 .81488 Mdot
.61048 .44588 Mdot
.43713 .66817 Mdot
.49517 .30035 Mdot
.53627 .30813 Mdot
.45839 .42484 Mdot
.44251 .624 Mdot
.49448 .57446 Mdot
.58399 .42151 Mdot
.42719 .4179 Mdot
.46235 .31234 Mdot
.42434 .66827 Mdot
.5739 .43631 Mdot
.48808 .22896 Mdot
.54056 .84702 Mdot
.65414 .59344 Mdot
.44028 .34802 Mdot
.62909 .43282 Mdot
.45091 .5602 Mdot
.36926 .45418 Mdot
.49637 .3252 Mdot
.45849 .35266 Mdot
.40118 .63127 Mdot
.39102 .58668 Mdot
.43338 .5471 Mdot
.64004 .59433 Mdot
.59546 .40327 Mdot
.46048 .65193 Mdot
.72234 .53454 Mdot
.43416 .6625 Mdot
.59694 .40506 Mdot
.47259 .09854 Mdot
.39561 .59131 Mdot
.47801 .61195 Mdot
.26179 .43856 Mdot
.67959 .59515 Mdot
.66212 .63524 Mdot
.76115 .54067 Mdot
.42521 .59188 Mdot
.40663 .27114 Mdot
.65806 .59277 Mdot
.66051 .62497 Mdot
.32555 .32643 Mdot
.39455 .6271 Mdot
.43516 .40881 Mdot
.60045 .41003 Mdot
.63318 .42363 Mdot
.63559 .62679 Mdot
.44611 .56081 Mdot
.61835 .4526 Mdot
.58766 .65753 Mdot
.46097 .32223 Mdot
.79641 .53874 Mdot
.62143 .60299 Mdot
.41714 .49163 Mdot
.61796 .44237 Mdot
.24808 .27532 Mdot
.5607 .52655 Mdot
.42281 .66024 Mdot
.42662 .59697 Mdot
.34272 .4527 Mdot
.50726 .65199 Mdot
.66917 .303 Mdot
.61702 .41377 Mdot
.22914 .42182 Mdot
.64626 .59901 Mdot
.47483 .62374 Mdot
.32152 .64829 Mdot
.70283 .43767 Mdot
.77956 .40422 Mdot
.67368 .60799 Mdot
.64449 .61204 Mdot
.45324 .31898 Mdot
.45078 .33441 Mdot
.44541 .61797 Mdot
.61599 .40722 Mdot
.68651 .63413 Mdot
.58729 .41166 Mdot
.4574 .33835 Mdot
.47216 .32625 Mdot
.68168 .28579 Mdot
.49986 .62572 Mdot
.48516 .35939 Mdot
.47252 .2281 Mdot
.71376 .53521 Mdot
.60894 .61705 Mdot
.38214 .80923 Mdot
.69307 .41523 Mdot
.23342 .50225 Mdot
.37297 .41766 Mdot
.64534 .28349 Mdot
.61893 .39424 Mdot
.43357 .65574 Mdot
.4449 .58954 Mdot
.66235 .28714 Mdot
.63667 .41267 Mdot
.34482 .44267 Mdot
.63849 .42071 Mdot
.36404 .42841 Mdot
.49693 .35972 Mdot
.48242 .60091 Mdot
.44985 .57829 Mdot
.62817 .42805 Mdot
.47626 .3165 Mdot
.48059 .36118 Mdot
.36019 .41324 Mdot
.3275 .59543 Mdot
.46738 .35164 Mdot
.62178 .60536 Mdot
.65816 .7335 Mdot
.65863 .29407 Mdot
.46826 .59417 Mdot
.31954 .66926 Mdot
.54295 .68687 Mdot
.39854 .65097 Mdot
.65439 .28488 Mdot
.86881 .44731 Mdot
.47477 .63358 Mdot
.8567 .48786 Mdot
.66966 .29656 Mdot
.68169 .59691 Mdot
.4731 .30357 Mdot
.66879 .30409 Mdot
.41793 .55631 Mdot
.38664 .45506 Mdot
.37411 .61242 Mdot
.67606 .59381 Mdot
.63025 .57301 Mdot
.7597 .61278 Mdot
.34914 .23897 Mdot
.34156 .41814 Mdot
.34748 .43402 Mdot
.48157 .34798 Mdot
.58389 .17799 Mdot
.39099 .5741 Mdot
.34475 .43387 Mdot
.22945 .44333 Mdot
.42501 .65375 Mdot
.28722 .60014 Mdot
.54573 .53078 Mdot
.65992 .62934 Mdot
.58246 .59399 Mdot
.48579 .34308 Mdot
.6533 .58667 Mdot
.71279 .54783 Mdot
.39976 .6633 Mdot
.6493 .59458 Mdot
.59479 .40851 Mdot
.61378 .33752 Mdot
.68278 .61787 Mdot
.4307 .4406 Mdot
.60285 .41018 Mdot
.30969 .43533 Mdot
.26081 .46982 Mdot
.28216 .78325 Mdot
.61743 .41264 Mdot
.48287 .31486 Mdot
.48889 .35819 Mdot
.47856 .3568 Mdot
.67432 .59047 Mdot
.4441 .30309 Mdot
.63499 .59309 Mdot
.30896 .296 Mdot
.31587 .63144 Mdot
.3518 .42607 Mdot
.63602 .38339 Mdot
.65504 .61171 Mdot
.76042 .48544 Mdot
.40452 .82242 Mdot
.43314 .60443 Mdot
.57235 .43356 Mdot
.33335 .45507 Mdot
.51693 .1539 Mdot
.34402 .45222 Mdot
.47783 .30824 Mdot
.79823 .53401 Mdot
.47221 .61794 Mdot
.39235 .7407 Mdot
.33342 .44424 Mdot
.67508 .60251 Mdot
.45058 .64782 Mdot
.4342 .34618 Mdot
.36893 .45122 Mdot
.38005 .43313 Mdot
.44813 .63482 Mdot
.67644 .6218 Mdot
.47606 .32741 Mdot
.61951 .39662 Mdot
.32853 .46167 Mdot
.48324 .57333 Mdot
.3882 .61559 Mdot
.45001 .67319 Mdot
.50649 .44557 Mdot
.21335 .51496 Mdot
.61176 .41296 Mdot
.34156 .50903 Mdot
.45431 .34142 Mdot
.302 .41488 Mdot
.73652 .49736 Mdot
.64903 .40139 Mdot
.67609 .29208 Mdot
.67918 .2869 Mdot
.4439 .6274 Mdot
.21389 .50495 Mdot
.81362 .43568 Mdot
.64919 .4583 Mdot
.65707 .28971 Mdot
.47811 .36106 Mdot
.69628 .60323 Mdot
.75078 .61755 Mdot
.40279 .57687 Mdot
.58223 .39621 Mdot
.46329 .34936 Mdot
.18944 .49331 Mdot
.36064 .43241 Mdot
.78122 .52744 Mdot
.41069 .61585 Mdot
.46311 .6305 Mdot
.60699 .42035 Mdot
.60568 .40325 Mdot
.76075 .38998 Mdot
.75683 .57404 Mdot
.52956 .36783 Mdot
.6608 .38231 Mdot
.18629 .52216 Mdot
.59097 .60183 Mdot
.63923 .57962 Mdot
.68157 .27441 Mdot
.61943 .45944 Mdot
.46164 .58747 Mdot
.68 .58873 Mdot
.78179 .40701 Mdot
.70458 .59734 Mdot
.29117 .5867 Mdot
.40798 .27866 Mdot
.42157 .62928 Mdot
.61827 .60575 Mdot
.65289 .58844 Mdot
.66703 .63833 Mdot
.65355 .29254 Mdot
.46098 .60128 Mdot
.39669 .60284 Mdot
.45947 .64848 Mdot
.51726 .61397 Mdot
.42835 .61694 Mdot
.729 .50451 Mdot
.55967 .46373 Mdot
.23338 .40471 Mdot
.40344 .65399 Mdot
.63365 .43228 Mdot
.46069 .66088 Mdot
.36733 .41958 Mdot
.41441 .65329 Mdot
.2823 .59064 Mdot
.6183 .42611 Mdot
.43982 .52887 Mdot
.66583 .39093 Mdot
.41013 .61687 Mdot
.37261 .45752 Mdot
.21983 .49916 Mdot
.40158 .79013 Mdot
.50948 .23832 Mdot
.62241 .6079 Mdot
.44774 .2837 Mdot
.61978 .38671 Mdot
.47904 .33378 Mdot
.42031 .66261 Mdot
.67073 .27006 Mdot
.66539 .35187 Mdot
.42586 .4863 Mdot
.44582 .5801 Mdot
.40172 .68629 Mdot
.64257 .62548 Mdot
.48946 .3226 Mdot
.62974 .55895 Mdot
.41933 .60345 Mdot
.36563 .44729 Mdot
.3715 .43869 Mdot
.74931 .55896 Mdot
.19303 .42981 Mdot
.59658 .54892 Mdot
.60761 .41803 Mdot
.43801 .33154 Mdot
.37852 .45501 Mdot
.69294 .6692 Mdot
.5904 .38818 Mdot
.5766 .40502 Mdot
.60004 .43641 Mdot
.42783 .63323 Mdot
.67459 .29749 Mdot
.21287 .44487 Mdot
.6622 .30584 Mdot
.41076 .62099 Mdot
.45136 .34692 Mdot
.67176 .30339 Mdot
.3482 .45718 Mdot
.5885 .44077 Mdot
.45292 .33231 Mdot
.43329 .62431 Mdot
.65704 .59799 Mdot
.34101 .56743 Mdot
.25066 .59417 Mdot
.28057 .32803 Mdot
.27631 .3359 Mdot
.65301 .57159 Mdot
.22386 .33282 Mdot
.58794 .37178 Mdot
.54677 .69736 Mdot
.39832 .43817 Mdot
.39568 .6546 Mdot
.77006 .67139 Mdot
.46419 .3108 Mdot
.49316 .34419 Mdot
.44035 .62078 Mdot
.47481 .29696 Mdot
.47714 .62004 Mdot
.44817 .32318 Mdot
.47471 .24455 Mdot
.42028 .56915 Mdot
.49182 .34429 Mdot
.37415 .59097 Mdot
.39953 .61064 Mdot
.65075 .63042 Mdot
.49526 .3185 Mdot
.43095 .6635 Mdot
.5882 .16812 Mdot
.61703 .40362 Mdot
.65427 .29445 Mdot
.53406 .41648 Mdot
.62713 .44023 Mdot
.63827 .60521 Mdot
.4405 .56819 Mdot
.33706 .43307 Mdot
.66218 .60405 Mdot
.42251 .31199 Mdot
.33232 .44504 Mdot
.7658 .53481 Mdot
.62485 .61445 Mdot
.66091 .29398 Mdot
.33441 .44175 Mdot
.41721 .68825 Mdot
.49872 .34438 Mdot
.25423 .63362 Mdot
.65987 .30435 Mdot
.46843 .6001 Mdot
.50263 .35935 Mdot
.63567 .43147 Mdot
.45603 .62021 Mdot
.48271 .3039 Mdot
.65276 .29138 Mdot
.42973 .64107 Mdot
.44268 .64919 Mdot
.74193 .61697 Mdot
.79687 .45001 Mdot
.34173 .42922 Mdot
.61555 .61549 Mdot
.43573 .611 Mdot
.3563 .41479 Mdot
.58813 .22485 Mdot
.47516 .64958 Mdot
.68809 .6058 Mdot
.37513 .71498 Mdot
.45041 .33697 Mdot
.60109 .44861 Mdot
.44419 .35483 Mdot
.37904 .42684 Mdot
.73192 .76731 Mdot
.67997 .29336 Mdot
.37682 .5807 Mdot
.41908 .6716 Mdot
.50766 .37166 Mdot
.64862 .59023 Mdot
.52054 .38509 Mdot
.42852 .59186 Mdot
.44462 .69771 Mdot
.46817 .62875 Mdot
.38789 .3283 Mdot
.66612 .62227 Mdot
.47592 .60594 Mdot
.53262 .61309 Mdot
.48018 .59387 Mdot
.37654 .45173 Mdot
.28854 .49316 Mdot
.46724 .659 Mdot
.23159 .24222 Mdot
.65079 .2895 Mdot
.48746 .35636 Mdot
.49055 .27389 Mdot
.65745 .24027 Mdot
.739 .65964 Mdot
.63762 .59302 Mdot
.37844 .69102 Mdot
.47762 .33028 Mdot
.54165 .83852 Mdot
.24859 .29853 Mdot
.40095 .61278 Mdot
.42081 .58333 Mdot
.47787 .30824 Mdot
.47882 .2954 Mdot
.6755 .27337 Mdot
.40855 .65598 Mdot
.36482 .64531 Mdot
.43559 .30388 Mdot
.42367 .62101 Mdot
.42778 .72554 Mdot
.61167 .39447 Mdot
.64831 .63372 Mdot
.58957 .4394 Mdot
.58562 .39579 Mdot
.63206 .70962 Mdot
.75544 .54153 Mdot
.59918 .40311 Mdot
.57137 .43611 Mdot
.28031 .60188 Mdot
.35274 .68597 Mdot
.38201 .4447 Mdot
.23713 .35551 Mdot
.47729 .35344 Mdot
.45958 .60197 Mdot
.65122 .57377 Mdot
.59633 .68539 Mdot
.58139 .31079 Mdot
.80218 .51114 Mdot
.41742 .59627 Mdot
.4863 .3469 Mdot
.65368 .29797 Mdot
.41485 .57022 Mdot
.29552 .42396 Mdot
.46029 .6306 Mdot
.49129 .3583 Mdot
.68265 .71663 Mdot
.3816 .72779 Mdot
.4151 .3857 Mdot
.64319 .64673 Mdot
.46631 .6476 Mdot
.62493 .59985 Mdot
.62161 .43958 Mdot
.35774 .41616 Mdot
.34022 .43467 Mdot
.44912 .64587 Mdot
.69523 .6655 Mdot
.54097 .5339 Mdot
.40067 .60829 Mdot
.39842 .62949 Mdot
.67108 .29493 Mdot
.3978 .62828 Mdot
.41662 .67053 Mdot
.452 .65973 Mdot
.49294 .62215 Mdot
.61015 .45708 Mdot
.36195 .72298 Mdot
.48393 .64499 Mdot
.39154 .55629 Mdot
.61576 .39857 Mdot
.36372 .66841 Mdot
.58206 .40304 Mdot
.18318 .4146 Mdot
.58264 .40873 Mdot
.34287 .43089 Mdot
.50739 .35011 Mdot
.42501 .70194 Mdot
.68201 .63833 Mdot
.57364 .42754 Mdot
.35841 .44231 Mdot
.61982 .41695 Mdot
.44234 .33551 Mdot
.32829 .76136 Mdot
.70433 .59639 Mdot
.44089 .42148 Mdot
.56934 .54517 Mdot
.76217 .41765 Mdot
.45622 .32191 Mdot
.6584 .62782 Mdot
.40073 .74264 Mdot
.44913 .65891 Mdot
.3385 .45002 Mdot
.44579 .6289 Mdot
.6047 .45416 Mdot
.48315 .35172 Mdot
.27963 .35122 Mdot
.33886 .43326 Mdot
.53464 .8559 Mdot
.4703 .36158 Mdot
.40214 .58486 Mdot
.57923 .39771 Mdot
.38591 .81067 Mdot
.58112 .41122 Mdot
.31603 .64262 Mdot
.62107 .57103 Mdot
.70192 .72272 Mdot
.64831 .61593 Mdot
.78425 .38953 Mdot
.12798 .49692 Mdot
.28288 .28728 Mdot
.66608 .59565 Mdot
.40998 .34203 Mdot
.41474 .61548 Mdot
.46005 .66429 Mdot
.45183 .54864 Mdot
.61714 .62561 Mdot
.43245 .61169 Mdot
.6641 .30222 Mdot
.6767 .52217 Mdot
.31036 .38443 Mdot
.44612 .28274 Mdot
.47787 .60463 Mdot
.61231 .39755 Mdot
.64005 .4259 Mdot
.66826 .30507 Mdot
.6024 .38729 Mdot
.39559 .6122 Mdot
.65306 .61353 Mdot
.45168 .48971 Mdot
.35533 .45378 Mdot
.45933 .18215 Mdot
.32016 .44357 Mdot
.43394 .28887 Mdot
.48926 .6604 Mdot
.47154 .32542 Mdot
.82921 .64504 Mdot
.43783 .66048 Mdot
.65939 .59057 Mdot
.43855 .64565 Mdot
.45943 .6558 Mdot
.45765 .66618 Mdot
.43981 .30542 Mdot
.51523 .30412 Mdot
.42658 .62351 Mdot
.60362 .43438 Mdot
.25612 .36871 Mdot
.37226 .62538 Mdot
.41723 .33828 Mdot
.29962 .55018 Mdot
.75773 .44145 Mdot
.61208 .6235 Mdot
.48639 .31969 Mdot
.64501 .6037 Mdot
.66014 .6483 Mdot
.63818 .60506 Mdot
.21109 .4296 Mdot
.54815 .62102 Mdot
.8582 .43027 Mdot
.64645 .76966 Mdot
.57757 .69514 Mdot
.61843 .58296 Mdot
.60266 .25775 Mdot
.6504 .57896 Mdot
.63709 .5977 Mdot
.66051 .16284 Mdot
.65854 .57861 Mdot
.44453 .58423 Mdot
.38705 .59958 Mdot
.7033 .48091 Mdot
.28805 .62337 Mdot
.40972 .65246 Mdot
.4381 .61454 Mdot
.35076 .41655 Mdot
.51059 .56946 Mdot
.68764 .28692 Mdot
.78082 .54946 Mdot
.66221 .36169 Mdot
.44703 .6341 Mdot
.43587 .61659 Mdot
.47889 .57566 Mdot
.1212 .5175 Mdot
.61296 .68144 Mdot
.64636 .56874 Mdot
.39758 .6859 Mdot
.38729 .2109 Mdot
.40663 .58486 Mdot
.45271 .57838 Mdot
.42403 .63879 Mdot
.47892 .33083 Mdot
.69527 .5956 Mdot
.40704 .68848 Mdot
.74345 .43602 Mdot
.41003 .61036 Mdot
.61562 .37629 Mdot
.32789 .46428 Mdot
.46166 .59092 Mdot
.66469 .63714 Mdot
.41469 .64887 Mdot
.61946 .60269 Mdot
.64009 .62945 Mdot
.49879 .59383 Mdot
.20558 .44365 Mdot
.68589 .6222 Mdot
.41382 .62655 Mdot
.48009 .31948 Mdot
.2813 .27607 Mdot
.4657 .59681 Mdot
.36209 .42209 Mdot
.42662 .59487 Mdot
.37384 .45401 Mdot
.40365 .62441 Mdot
.65989 .30532 Mdot
.47792 .73649 Mdot
.47983 .345 Mdot
.40353 .42119 Mdot
.46261 .29286 Mdot
.73721 .60158 Mdot
.684 .59765 Mdot
.68861 .27862 Mdot
.81479 .57363 Mdot
.66948 .2951 Mdot
.34271 .56581 Mdot
.56213 .26907 Mdot
.6245 .41243 Mdot
.64776 .63768 Mdot
.36212 .51137 Mdot
.41435 .33317 Mdot
.42574 .30788 Mdot
.47811 .29002 Mdot
.76051 .72449 Mdot
.80215 .62058 Mdot
.43139 .62926 Mdot
.2513 .6615 Mdot
.5285 .77506 Mdot
.48888 .61344 Mdot
.45156 .56963 Mdot
.49398 .35727 Mdot
.47296 .63855 Mdot
.49179 .45707 Mdot
.46172 .33495 Mdot
.35337 .43924 Mdot
.63033 .60017 Mdot
.37484 .44986 Mdot
.4585 .38046 Mdot
.57281 .47998 Mdot
.45475 .3383 Mdot
.48572 .63503 Mdot
.43931 .63944 Mdot
.62381 .61918 Mdot
.71944 .62098 Mdot
.64737 .63226 Mdot
.33187 .44978 Mdot
.46812 .34291 Mdot
.59527 .67442 Mdot
.43911 .59891 Mdot
.66431 .6099 Mdot
.57433 .46093 Mdot
.43585 .60212 Mdot
.62671 .43168 Mdot
.40918 .59716 Mdot
.66991 .59451 Mdot
.39793 .62762 Mdot
.6509 .61316 Mdot
.46852 .31255 Mdot
.40848 .58582 Mdot
.44122 .61875 Mdot
.43998 .81284 Mdot
.34528 .44428 Mdot
.68325 .59712 Mdot
.536 .49385 Mdot
.39636 .59389 Mdot
.31449 .40616 Mdot
.48396 .61094 Mdot
.37186 .69671 Mdot
.37013 .59733 Mdot
.66347 .3009 Mdot
.46773 .66597 Mdot
.46785 .59853 Mdot
.37368 .73414 Mdot
.56426 .80346 Mdot
.64287 .55392 Mdot
.58718 .44512 Mdot
.66302 .63711 Mdot
.50135 .34468 Mdot
.49689 .31052 Mdot
.44825 .30462 Mdot
.29997 .63688 Mdot
.4566 .56424 Mdot
.47229 .61596 Mdot
.57102 .41598 Mdot
.34968 .43234 Mdot
.67209 .60666 Mdot
.35353 .42946 Mdot
.78039 .55437 Mdot
.33442 .45242 Mdot
.67142 .30186 Mdot
.3897 .33608 Mdot
.54944 .66685 Mdot
.34618 .41811 Mdot
.64823 .63288 Mdot
.40252 .30029 Mdot
.40301 .66036 Mdot
.49408 .24595 Mdot
.36657 .44603 Mdot
.71064 .77993 Mdot
.48239 .60526 Mdot
.46078 .43983 Mdot
.59631 .39544 Mdot
.36311 .46004 Mdot
.60932 .44189 Mdot
.42875 .65814 Mdot
.72456 .3806 Mdot
.65524 .58467 Mdot
.6145 .463 Mdot
.46686 .6654 Mdot
.37178 .45309 Mdot
.46405 .35284 Mdot
.5987 .52407 Mdot
.63325 .42918 Mdot
.36687 .75542 Mdot
.28385 .45046 Mdot
.46667 .34091 Mdot
.8232 .41557 Mdot
.59375 .43467 Mdot
.48716 .62716 Mdot
.45902 .70445 Mdot
.39868 .64451 Mdot
.50478 .32945 Mdot
.4911 .32669 Mdot
.68417 .51095 Mdot
.43752 .64299 Mdot
.48301 .60704 Mdot
.68419 .57543 Mdot
.46093 .32825 Mdot
.64507 .62209 Mdot
.65934 .64132 Mdot
.47971 .31229 Mdot
.63842 .61609 Mdot
.33458 .44711 Mdot
.64673 .5111 Mdot
.59234 .4327 Mdot
.60825 .43411 Mdot
.47851 .36029 Mdot
.45429 .36058 Mdot
.46936 .32478 Mdot
.40909 .59769 Mdot
.67532 .61272 Mdot
.41423 .63938 Mdot
.47105 .65673 Mdot
.60436 .58747 Mdot
.67153 .58107 Mdot
.42036 .64686 Mdot
.40782 .39194 Mdot
.34622 .47439 Mdot
.49116 .34333 Mdot
.58859 .40938 Mdot
.54591 .83528 Mdot
.57424 .40293 Mdot
.48051 .6081 Mdot
.53079 .29285 Mdot
.67585 .59832 Mdot
.34418 .45329 Mdot
.31476 .41493 Mdot
.33856 .44614 Mdot
.6406 .46048 Mdot
.67618 .63841 Mdot
.76393 .53378 Mdot
.47983 .6154 Mdot
.5076 .44774 Mdot
.35078 .51204 Mdot
.7399 .4876 Mdot
.59547 .40561 Mdot
.43639 .60788 Mdot
.66743 .29536 Mdot
.51734 .69702 Mdot
.46144 .62738 Mdot
.43286 .66664 Mdot
.36712 .30067 Mdot
.39396 .55431 Mdot
.60662 .61065 Mdot
.76053 .60732 Mdot
.38276 .61946 Mdot
.58683 .62819 Mdot
.79303 .29097 Mdot
.48087 .62073 Mdot
.42211 .60916 Mdot
.45257 .59413 Mdot
.4303 .65315 Mdot
.60919 .58422 Mdot
.39397 .48889 Mdot
.57691 .40128 Mdot
.52798 .45073 Mdot
.59269 .42662 Mdot
.49801 .34064 Mdot
.46232 .44406 Mdot
.64761 .6365 Mdot
.34016 .45016 Mdot
.29899 .72143 Mdot
.77511 .58074 Mdot
.45396 .31879 Mdot
.64694 .6912 Mdot
.36032 .45248 Mdot
.39392 .65209 Mdot
.32586 .42249 Mdot
.48058 .29515 Mdot
.59809 .42215 Mdot
.38731 .60092 Mdot
.63538 .57667 Mdot
.68343 .61751 Mdot
.43284 .60625 Mdot
.34711 .23318 Mdot
.62228 .44229 Mdot
.55274 .44052 Mdot
.42582 .63207 Mdot
.43155 .66648 Mdot
.633 .61776 Mdot
.48939 .333 Mdot
.55192 .2288 Mdot
.35108 .44451 Mdot
.49516 .59942 Mdot
.42287 .65425 Mdot
.77333 .56177 Mdot
.58717 .4406 Mdot
.66592 .27461 Mdot
.42988 .63629 Mdot
.75718 .54644 Mdot
.43035 .63821 Mdot
.5062 .65666 Mdot
.47486 .32185 Mdot
.38727 .65212 Mdot
.41779 .58765 Mdot
.4018 .51728 Mdot
.59864 .44058 Mdot
.65335 .59116 Mdot
.65898 .56247 Mdot
.65964 .27602 Mdot
.62639 .42882 Mdot
.41912 .64826 Mdot
.60298 .45126 Mdot
.4601 .66529 Mdot
.42818 .62173 Mdot
.59535 .40628 Mdot
.64439 .62184 Mdot
.56736 .36585 Mdot
.33761 .68065 Mdot
.4338 .6506 Mdot
.38758 .61527 Mdot
.29499 .62511 Mdot
.83164 .52163 Mdot
.42364 .58839 Mdot
.67851 .59755 Mdot
.43949 .6053 Mdot
.61815 .43729 Mdot
.33627 .45628 Mdot
.66148 .59522 Mdot
.46456 .36495 Mdot
.46881 .3105 Mdot
.66908 .40104 Mdot
.67574 .29859 Mdot
.38991 .60729 Mdot
.6623 .55126 Mdot
.66285 .57575 Mdot
.64116 .19887 Mdot
.49121 .35404 Mdot
.37234 .46046 Mdot
.44228 .65155 Mdot
.58804 .52501 Mdot
.57258 .41795 Mdot
.22919 .24446 Mdot
.75555 .52453 Mdot
.33889 .40797 Mdot
.80794 .52625 Mdot
.66463 .29181 Mdot
.44005 .57867 Mdot
.36407 .41687 Mdot
.4584 .30746 Mdot
.45228 .66554 Mdot
.45365 .55498 Mdot
.51953 .38976 Mdot
.48281 .28521 Mdot
.60338 .45057 Mdot
.44495 .32232 Mdot
.36017 .4092 Mdot
.67042 .3024 Mdot
.6686 .62949 Mdot
.47355 .60535 Mdot
.46853 .6963 Mdot
.48582 .35515 Mdot
.658 .30539 Mdot
.42115 .62947 Mdot
.68117 .62256 Mdot
.46752 .29684 Mdot
.45016 .63669 Mdot
.55586 .69003 Mdot
.63288 .64668 Mdot
.47046 .35015 Mdot
.42695 .67213 Mdot
.39894 .71287 Mdot
.47058 .36427 Mdot
.48183 .36236 Mdot
.43278 .61213 Mdot
.3348 .44492 Mdot
.42754 .57823 Mdot
.58782 .39796 Mdot
.51506 .30348 Mdot
.61803 .43446 Mdot
.32212 .49095 Mdot
.49332 .65476 Mdot
.77247 .41904 Mdot
.61939 .61663 Mdot
.38618 .42308 Mdot
.45334 .79252 Mdot
.41992 .6651 Mdot
.21276 .37088 Mdot
.41623 .48998 Mdot
.48576 .16629 Mdot
.16484 .56017 Mdot
.36564 .43865 Mdot
.62204 .42044 Mdot
.42277 .60891 Mdot
.5701 .39343 Mdot
.34941 .41942 Mdot
.33808 .50403 Mdot
.42444 .67158 Mdot
.66278 .62378 Mdot
.41237 .61529 Mdot
.6218 .60632 Mdot
.4347 .59991 Mdot
.36784 .59 Mdot
.39301 .45796 Mdot
.31647 .64672 Mdot
.39918 .65707 Mdot
.32249 .75951 Mdot
.57328 .51621 Mdot
.36252 .4476 Mdot
.41487 .63394 Mdot
.66803 .28042 Mdot
.6367 .40907 Mdot
.21623 .55053 Mdot
.47525 .32845 Mdot
.60128 .39979 Mdot
.63093 .60978 Mdot
.45737 .36826 Mdot
.65243 .28704 Mdot
.47346 .69698 Mdot
.3788 .4415 Mdot
.62366 .41304 Mdot
.46593 .59554 Mdot
.47897 .60129 Mdot
.40251 .37684 Mdot
.73742 .31275 Mdot
.69912 .59932 Mdot
.49717 .84512 Mdot
.60464 .59919 Mdot
.34455 .43756 Mdot
.4729 .32226 Mdot
.43485 .58313 Mdot
.45528 .62616 Mdot
.50088 .31951 Mdot
.67973 .59325 Mdot
.47735 .27714 Mdot
.64481 .70316 Mdot
.43299 .31932 Mdot
.3214 .55591 Mdot
.66444 .59101 Mdot
.32286 .55975 Mdot
.3633 .40943 Mdot
.1927 .46024 Mdot
.25188 .53884 Mdot
.59813 .39435 Mdot
.32092 .55053 Mdot
.67348 .60101 Mdot
.4359 .63335 Mdot
.66067 .29179 Mdot
.68087 .28669 Mdot
.62708 .60499 Mdot
.47975 .30819 Mdot
.36768 .45545 Mdot
.42205 .61175 Mdot
.77377 .49117 Mdot
.691 .44793 Mdot
.43776 .33218 Mdot
.52875 .62923 Mdot
.60635 .4396 Mdot
.41356 .595 Mdot
.36675 .42505 Mdot
.61173 .40904 Mdot
.66196 .26758 Mdot
.66427 .51732 Mdot
.44551 .65227 Mdot
.74876 .56735 Mdot
.62675 .42379 Mdot
.82966 .41927 Mdot
.44665 .62117 Mdot
.59398 .43508 Mdot
.36225 .59004 Mdot
.72056 .39689 Mdot
.4998 .49042 Mdot
.25327 .30169 Mdot
.48132 .28692 Mdot
.47007 .30838 Mdot
.68775 .33005 Mdot
.39707 .44248 Mdot
.61933 .4027 Mdot
.66871 .30346 Mdot
.26941 .4982 Mdot
.60582 .44197 Mdot
.4487 .5758 Mdot
.48381 .61221 Mdot
.62405 .70569 Mdot
.50691 .4733 Mdot
.65682 .3065 Mdot
.60185 .55461 Mdot
.39261 .62896 Mdot
.38681 .6591 Mdot
.45443 .61665 Mdot
.63212 .57237 Mdot
.62794 .44083 Mdot
.34917 .79923 Mdot
.61763 .44587 Mdot
.78053 .49856 Mdot
.4779 .35339 Mdot
.43669 .33304 Mdot
.4649 .59269 Mdot
.79402 .41978 Mdot
.20895 .54075 Mdot
.39749 .60014 Mdot
.30728 .43604 Mdot
.2886 .46452 Mdot
.37459 .64525 Mdot
.64476 .55961 Mdot
.47559 .6906 Mdot
.59693 .61278 Mdot
.60673 .40646 Mdot
.36631 .43483 Mdot
.34822 .47403 Mdot
.6192 .40937 Mdot
.47119 .61445 Mdot
.31877 .47114 Mdot
.46599 .62917 Mdot
.43154 .63314 Mdot
.78575 .53557 Mdot
.37239 .46365 Mdot
.46638 .32318 Mdot
.33957 .43465 Mdot
.63857 .59674 Mdot
.54277 .09908 Mdot
.35731 .42667 Mdot
.7129 .57961 Mdot
.41551 .42605 Mdot
.32314 .55145 Mdot
.67976 .62257 Mdot
.33325 .42541 Mdot
.60853 .45 Mdot
.47885 .1641 Mdot
.8363 .47105 Mdot
.574 .3991 Mdot
.44937 .62518 Mdot
.64002 .63389 Mdot
.64523 .57121 Mdot
.57064 .43228 Mdot
.66351 .62876 Mdot
.4491 .68086 Mdot
.43461 .64411 Mdot
.61952 .40295 Mdot
.69485 .48003 Mdot
.63284 .43715 Mdot
.64768 .52565 Mdot
.41793 .63251 Mdot
.66058 .59291 Mdot
.47826 .67413 Mdot
.69035 .57802 Mdot
.68161 .27743 Mdot
.4498 .66722 Mdot
.34893 .45999 Mdot
.50522 .46335 Mdot
.47272 .35046 Mdot
.53572 .3089 Mdot
.62799 .62282 Mdot
.55329 .40818 Mdot
.65061 .63069 Mdot
.62561 .62902 Mdot
.59613 .38735 Mdot
.64473 .58806 Mdot
.42148 .6097 Mdot
.41409 .38794 Mdot
.62358 .59125 Mdot
.61022 .42353 Mdot
.36064 .45816 Mdot
.64064 .61845 Mdot
.46986 .37517 Mdot
.44375 .63932 Mdot
.44984 .33123 Mdot
.35277 .40308 Mdot
.65114 .63803 Mdot
.33123 .43008 Mdot
.48931 .35409 Mdot
.37893 .43491 Mdot
.28813 .32886 Mdot
.6226 .45706 Mdot
.80062 .50374 Mdot
.35631 .70339 Mdot
.63585 .57708 Mdot
.42477 .30942 Mdot
.42987 .58548 Mdot
.44377 .64359 Mdot
.35867 .41041 Mdot
.64764 .57138 Mdot
.29441 .2687 Mdot
.38596 .70149 Mdot
.65289 .50655 Mdot
.61204 .45947 Mdot
.55018 .84448 Mdot
.71722 .5316 Mdot
.48514 .1896 Mdot
.3824 .58449 Mdot
.66411 .29159 Mdot
.47143 .62548 Mdot
.40632 .79448 Mdot
.34189 .46195 Mdot
.6013 .29926 Mdot
.39195 .57354 Mdot
.46938 .33246 Mdot
.44555 .60325 Mdot
.24993 .64727 Mdot
.47829 .688 Mdot
.34523 .41677 Mdot
.65291 .44415 Mdot
.68309 .63763 Mdot
.35659 .45333 Mdot
.46345 .3127 Mdot
.29046 .51622 Mdot
.41997 .67272 Mdot
.39254 .61602 Mdot
.43627 .2959 Mdot
.66275 .62564 Mdot
.49891 .34117 Mdot
.59248 .43252 Mdot
.35769 .43001 Mdot
.43473 .65468 Mdot
.39765 .66846 Mdot
.50926 .37669 Mdot
.62629 .44367 Mdot
.44733 .35473 Mdot
.5868 .43682 Mdot
.66322 .29226 Mdot
.38568 .63394 Mdot
.43883 .29536 Mdot
.48625 .61072 Mdot
.45136 .8007 Mdot
.79074 .53707 Mdot
.56916 .79168 Mdot
.46397 .32263 Mdot
.30125 .56848 Mdot
.62071 .4278 Mdot
.58053 .41979 Mdot
.67289 .754 Mdot
.21757 .50069 Mdot
.40783 .27219 Mdot
.31147 .73587 Mdot
.59187 .43137 Mdot
.61597 .43206 Mdot
.45826 .30522 Mdot
.63756 .58927 Mdot
.61867 .64397 Mdot
.43682 .33872 Mdot
.31958 .66219 Mdot
.67192 .60667 Mdot
.22084 .35295 Mdot
.49311 .36027 Mdot
.3872 .5762 Mdot
.67735 .30576 Mdot
.36963 .43569 Mdot
.32077 .66301 Mdot
.28267 .68498 Mdot
.44298 .581 Mdot
.75947 .65022 Mdot
.48608 .32934 Mdot
.455 .41112 Mdot
.18467 .42935 Mdot
.4357 .66994 Mdot
.45368 .60303 Mdot
.46722 .61303 Mdot
.36722 .46889 Mdot
.44011 .78904 Mdot
.44453 .58051 Mdot
.31758 .61482 Mdot
.4341 .57111 Mdot
.2412 .58724 Mdot
.34036 .43327 Mdot
.56223 .59008 Mdot
.46488 .2837 Mdot
.74399 .4567 Mdot
.44219 .54664 Mdot
.5929 .43935 Mdot
.42412 .3713 Mdot
.59619 .41895 Mdot
.2044 .49811 Mdot
.25342 .53637 Mdot
.62125 .57731 Mdot
.41676 .59637 Mdot
.48626 .29392 Mdot
.62969 .62644 Mdot
.55851 .25636 Mdot
.63798 .14416 Mdot
.61644 .4525 Mdot
.84703 .56988 Mdot
.58016 .42018 Mdot
.68111 .27965 Mdot
.62988 .61436 Mdot
.58005 .63904 Mdot
.50638 .44865 Mdot
.64202 .61777 Mdot
.65061 .34882 Mdot
.6339 .5614 Mdot
.30972 .55838 Mdot
.65998 .64555 Mdot
.61392 .42305 Mdot
.64118 .4495 Mdot
.41266 .55374 Mdot
.42832 .58822 Mdot
.53647 .45077 Mdot
.34978 .61229 Mdot
.42263 .59162 Mdot
.46185 .33488 Mdot
.82518 .46614 Mdot
.50012 .36872 Mdot
.63738 .5816 Mdot
.58234 .43722 Mdot
.45156 .60294 Mdot
.43101 .64806 Mdot
.48203 .63344 Mdot
.44068 .81578 Mdot
.22462 .34921 Mdot
.42889 .62447 Mdot
.50056 .60849 Mdot
.46539 .31459 Mdot
.35892 .48551 Mdot
.34901 .76016 Mdot
.2671 .51067 Mdot
.45822 .64371 Mdot
.34277 .44435 Mdot
.35325 .46861 Mdot
.37732 .63403 Mdot
.76591 .45858 Mdot
.40994 .35451 Mdot
.46551 .59532 Mdot
.24321 .54787 Mdot
.48531 .37555 Mdot
.66409 .307 Mdot
.48517 .3557 Mdot
.66213 .63892 Mdot
.67534 .29358 Mdot
.45474 .29554 Mdot
.57261 .63561 Mdot
.66239 .27302 Mdot
.72259 .41137 Mdot
.33182 .44974 Mdot
.45661 .62014 Mdot
.65237 .55742 Mdot
.50255 .32088 Mdot
.62157 .41001 Mdot
.65291 .60581 Mdot
.64079 .42497 Mdot
.3769 .48279 Mdot
.36164 .53251 Mdot
.67877 .29488 Mdot
.58836 .43206 Mdot
.66521 .51817 Mdot
.34125 .44206 Mdot
.59542 .38871 Mdot
.78758 .40962 Mdot
.37867 .6032 Mdot
.19689 .56225 Mdot
.40205 .60283 Mdot
.39319 .20469 Mdot
.57852 .41608 Mdot
.67268 .26881 Mdot
.47451 .61457 Mdot
.47034 .36202 Mdot
.35661 .6096 Mdot
.45987 .63295 Mdot
.44686 .34826 Mdot
.43256 .62985 Mdot
.36693 .42386 Mdot
.60742 .63063 Mdot
.42591 .49228 Mdot
.6346 .81424 Mdot
.37785 .4349 Mdot
.68856 .30237 Mdot
.42072 .59076 Mdot
.27603 .37 Mdot
.64463 .61915 Mdot
.43585 .6683 Mdot
.71429 .70704 Mdot
.62998 .59147 Mdot
.64451 .60683 Mdot
.4025 .63329 Mdot
.59987 .39109 Mdot
.47068 .35872 Mdot
.34033 .44267 Mdot
.53719 .1749 Mdot
.45422 .63738 Mdot
.44058 .61166 Mdot
.35953 .45308 Mdot
.61721 .43333 Mdot
.42889 .64983 Mdot
.55637 .28879 Mdot
.55753 .16322 Mdot
.58437 .39627 Mdot
.37196 .62525 Mdot
.21941 .63627 Mdot
.69533 .64305 Mdot
.8408 .54186 Mdot
.39864 .40538 Mdot
.48315 .3176 Mdot
.36454 .60465 Mdot
.27426 .20814 Mdot
.36875 .43745 Mdot
.74592 .48522 Mdot
.42297 .62335 Mdot
.44252 .5949 Mdot
.68183 .61301 Mdot
.41473 .64329 Mdot
.66798 .58606 Mdot
.65828 .80651 Mdot
.50738 .86953 Mdot
.64577 .62759 Mdot
.64468 .57736 Mdot
.57476 .60147 Mdot
.38245 .76983 Mdot
.63059 .60372 Mdot
.43617 .67354 Mdot
.25753 .3459 Mdot
.50191 .59644 Mdot
.37248 .41362 Mdot
.33014 .40398 Mdot
.59857 .64176 Mdot
.79357 .36107 Mdot
.38147 .68459 Mdot
.4246 .53655 Mdot
.54641 .54224 Mdot
.58515 .40648 Mdot
.45703 .65109 Mdot
.67538 .29943 Mdot
.4449 .30723 Mdot
.50773 .66115 Mdot
.45997 .62172 Mdot
.61991 .60116 Mdot
.37178 .46699 Mdot
.62415 .39063 Mdot
.43836 .61527 Mdot
.49474 .28853 Mdot
.35211 .44146 Mdot
.62785 .58559 Mdot
.72755 .59469 Mdot
.38348 .43562 Mdot
.43736 .68341 Mdot
.42974 .59299 Mdot
.42211 .6306 Mdot
.41358 .54523 Mdot
.61576 .40437 Mdot
.47249 .37903 Mdot
.44634 .67688 Mdot
.77587 .55001 Mdot
.45685 .42972 Mdot
.40183 .66906 Mdot
.67766 .60748 Mdot
.57461 .40433 Mdot
.66888 .27351 Mdot
.30738 .51209 Mdot
.44935 .64981 Mdot
.22454 .3532 Mdot
.62273 .68966 Mdot
.67578 .28937 Mdot
.61219 .60638 Mdot
.3414 .45066 Mdot
.39403 .62231 Mdot
.23576 .38464 Mdot
.48219 .60848 Mdot
.35987 .69477 Mdot
.48524 .32362 Mdot
.58521 .41146 Mdot
.53408 .15586 Mdot
.44394 .30849 Mdot
.64477 .60466 Mdot
.25667 .27849 Mdot
.6885 .58986 Mdot
.69305 .62374 Mdot
.20727 .45353 Mdot
.60276 .40468 Mdot
.25509 .22481 Mdot
.83712 .49757 Mdot
.47231 .58829 Mdot
.61821 .44015 Mdot
.62975 .61781 Mdot
.41292 .59776 Mdot
.6576 .57529 Mdot
.69341 .61404 Mdot
.45884 .66101 Mdot
.43598 .59204 Mdot
.32038 .63046 Mdot
.19405 .38622 Mdot
.33618 .44124 Mdot
.6816 .59714 Mdot
.58602 .70454 Mdot
.44065 .57979 Mdot
.47984 .61459 Mdot
.44798 .39582 Mdot
.34528 .41699 Mdot
.42567 .73505 Mdot
.43048 .63542 Mdot
.7216 .70978 Mdot
.38752 .61245 Mdot
.66702 .56016 Mdot
.58787 .39261 Mdot
.76307 .46394 Mdot
.50446 .33603 Mdot
.68845 .61098 Mdot
.37099 .4562 Mdot
.66213 .56579 Mdot
.68927 .72812 Mdot
.60057 .40792 Mdot
.66994 .59452 Mdot
.47914 .37061 Mdot
.60171 .41905 Mdot
.58664 .39608 Mdot
.25611 .36739 Mdot
.44396 .35075 Mdot
.3277 .44402 Mdot
.59711 .42744 Mdot
.54729 .69895 Mdot
.61369 .41892 Mdot
.60203 .70571 Mdot
.40697 .58953 Mdot
.32131 .60187 Mdot
.72405 .52422 Mdot
.46786 .55479 Mdot
.63515 .43403 Mdot
.34324 .42347 Mdot
.40548 .64439 Mdot
.66718 .62674 Mdot
.35968 .42712 Mdot
.66242 .43559 Mdot
.4678 .36769 Mdot
.61606 .60593 Mdot
.58199 .39599 Mdot
.67105 .5907 Mdot
.35527 .52272 Mdot
.52183 .29764 Mdot
.55033 .55101 Mdot
.49758 .43943 Mdot
.48843 .62173 Mdot
.59661 .64376 Mdot
.39056 .60025 Mdot
.46145 .62464 Mdot
.47095 .35091 Mdot
.30056 .63539 Mdot
.6431 .62185 Mdot
.54826 .15473 Mdot
.58482 .42448 Mdot
.74964 .62784 Mdot
.40598 .71214 Mdot
.43883 .66445 Mdot
.62438 .59193 Mdot
.69601 .60757 Mdot
.56631 .80227 Mdot
.50024 .32081 Mdot
.49344 .57278 Mdot
.49939 .64961 Mdot
.38825 .56922 Mdot
.57798 .41827 Mdot
.56937 .30955 Mdot
.4898 .31469 Mdot
.87119 .4493 Mdot
.49099 .34143 Mdot
.33825 .32397 Mdot
.64489 .58729 Mdot
.34391 .4615 Mdot
.47966 .61029 Mdot
.33229 .6519 Mdot
.62003 .57439 Mdot
.4283 .40032 Mdot
.34716 .45718 Mdot
.5945 .33877 Mdot
.60212 .40192 Mdot
.38946 .65 Mdot
.46133 .65631 Mdot
.41226 .63585 Mdot
.40544 .60644 Mdot
.58873 .44581 Mdot
.45009 .57651 Mdot
.61742 .46156 Mdot
.55251 .68442 Mdot
.71769 .71713 Mdot
.50525 .31575 Mdot
.21654 .53012 Mdot
.62688 .58033 Mdot
.55073 .7128 Mdot
.43646 .72245 Mdot
.79231 .53154 Mdot
.27752 .34717 Mdot
.39253 .60112 Mdot
.476 .30452 Mdot
.25001 .65502 Mdot
.48784 .29558 Mdot
.60985 .87868 Mdot
.32304 .48018 Mdot
.24437 .30397 Mdot
.41413 .59868 Mdot
.50073 .3794 Mdot
.41622 .72022 Mdot
.37468 .63016 Mdot
.33753 .48939 Mdot
.70394 .56108 Mdot
.71259 .47713 Mdot
.37584 .4569 Mdot
.44608 .63913 Mdot
.68642 .63574 Mdot
.41972 .6094 Mdot
.47696 .62157 Mdot
.41231 .59397 Mdot
.60923 .38285 Mdot
.40696 .57137 Mdot
.43246 .57719 Mdot
.74408 .31224 Mdot
.28877 .59448 Mdot
.44721 .33142 Mdot
.61447 .78485 Mdot
.35017 .4325 Mdot
.62166 .61069 Mdot
.4123 .48004 Mdot
.59532 .3969 Mdot
.5508 .81093 Mdot
.40854 .59972 Mdot
.7114 .51821 Mdot
.58134 .39603 Mdot
.3635 .42944 Mdot
.65717 .28063 Mdot
.26545 .30914 Mdot
.50327 .31286 Mdot
.66556 .271 Mdot
.47412 .35014 Mdot
.46032 .78309 Mdot
.6205 .59983 Mdot
.47945 .63967 Mdot
.60129 .43675 Mdot
.46601 .35796 Mdot
.28961 .63483 Mdot
.4569 .6131 Mdot
.46113 .32311 Mdot
.48691 .62682 Mdot
.43571 .42641 Mdot
.40557 .35963 Mdot
.4646 .29178 Mdot
.64572 .44535 Mdot
.60318 .4256 Mdot
.33464 .44823 Mdot
.62072 .61103 Mdot
.67729 .60043 Mdot
.60957 .40992 Mdot
.82996 .57311 Mdot
.46056 .63533 Mdot
.41535 .59281 Mdot
.77156 .54665 Mdot
.42307 .60285 Mdot
.29969 .53402 Mdot
.684 .29375 Mdot
.61705 .59688 Mdot
.41257 .60349 Mdot
.43065 .651 Mdot
.44362 .65234 Mdot
.35497 .52612 Mdot
.48751 .3527 Mdot
.39281 .62832 Mdot
.36537 .41539 Mdot
.76262 .3876 Mdot
.42685 .5833 Mdot
.38032 .64767 Mdot
.67103 .59763 Mdot
.56404 .84874 Mdot
.59291 .39547 Mdot
.4566 .32881 Mdot
.48042 .36516 Mdot
.37117 .39495 Mdot
.6153 .62902 Mdot
.68766 .28905 Mdot
.6371 .22444 Mdot
.6575 .29935 Mdot
.35742 .45016 Mdot
.37229 .28012 Mdot
.48481 .28274 Mdot
.45119 .3186 Mdot
.62973 .4581 Mdot
.40856 .6059 Mdot
.39545 .60137 Mdot
.74884 .48598 Mdot
.40516 .65253 Mdot
.35238 .45925 Mdot
.62555 .40691 Mdot
.66961 .60113 Mdot
.37118 .43628 Mdot
.59106 .44057 Mdot
.66548 .62458 Mdot
.37891 .60504 Mdot
.38258 .59547 Mdot
.64917 .60819 Mdot
.64016 .6308 Mdot
.44868 .58659 Mdot
.7222 .30815 Mdot
.6481 .64237 Mdot
.66752 .5929 Mdot
.6501 .3069 Mdot
.50162 .30898 Mdot
.46372 .6834 Mdot
.61861 .44089 Mdot
.42328 .63077 Mdot
.49682 .30075 Mdot
.34092 .41952 Mdot
.65455 .61953 Mdot
.43401 .64877 Mdot
.43827 .62972 Mdot
.34274 .44613 Mdot
.3835 .44847 Mdot
.37158 .44889 Mdot
.57642 .38221 Mdot
.40653 .61957 Mdot
.63207 .60559 Mdot
.59939 .40464 Mdot
.35351 .46862 Mdot
.32258 .43314 Mdot
.76825 .32626 Mdot
.44834 .58214 Mdot
.50805 .49805 Mdot
.50549 .10199 Mdot
.28272 .51528 Mdot
.67502 .27435 Mdot
.43309 .30529 Mdot
.31842 .58429 Mdot
.37958 .38303 Mdot
.62729 .43756 Mdot
.24552 .4653 Mdot
.38547 .42235 Mdot
.46753 .65881 Mdot
.38712 .61994 Mdot
.48945 .59084 Mdot
.35548 .43781 Mdot
.34506 .51864 Mdot
.65593 .57117 Mdot
.52036 .75723 Mdot
.35042 .43252 Mdot
.46499 .292 Mdot
.4426 .29405 Mdot
.49122 .34018 Mdot
.38265 .62872 Mdot
.55524 .8037 Mdot
.56478 .70051 Mdot
.45266 .75766 Mdot
.6028 .40017 Mdot
.69648 .59813 Mdot
.28115 .35118 Mdot
.64447 .60894 Mdot
.4468 .30272 Mdot
.35706 .44138 Mdot
.68268 .60364 Mdot
.62996 .42492 Mdot
.61433 .43403 Mdot
.46818 .36664 Mdot
.47988 .35824 Mdot
.45659 .34396 Mdot
.67358 .63607 Mdot
.64451 .58796 Mdot
.44247 .65677 Mdot
.65762 .61391 Mdot
.76561 .6388 Mdot
.33002 .41071 Mdot
.45077 .29023 Mdot
.62484 .42737 Mdot
.62439 .61279 Mdot
.4541 .62153 Mdot
.38763 .29921 Mdot
.6513 .36556 Mdot
.37511 .42742 Mdot
.45012 .24716 Mdot
.67621 .83502 Mdot
.4671 .64932 Mdot
.59554 .44717 Mdot
.76766 .44324 Mdot
.46347 .60958 Mdot
.47934 .32847 Mdot
.419 .79792 Mdot
.65641 .30219 Mdot
.43144 .57814 Mdot
.42427 .66245 Mdot
.60181 .38701 Mdot
.41136 .4398 Mdot
.42777 .65963 Mdot
.72208 .55392 Mdot
.63955 .40776 Mdot
.48444 .30516 Mdot
.58085 .1641 Mdot
.42839 .31946 Mdot
.31627 .6782 Mdot
.67848 .27911 Mdot
.45824 .65811 Mdot
.46245 .33861 Mdot
.37065 .42246 Mdot
.46212 .34545 Mdot
.61122 .59527 Mdot
.45037 .3364 Mdot
.44079 .60829 Mdot
.63291 .60278 Mdot
.62744 .42631 Mdot
.76033 .60271 Mdot
.75178 .32728 Mdot
.4703 .36234 Mdot
.64472 .29777 Mdot
.43632 .57852 Mdot
.48578 .71236 Mdot
.35633 .61152 Mdot
.42121 .58748 Mdot
.59587 .41716 Mdot
.62662 .58904 Mdot
.60576 .4561 Mdot
.3985 .67732 Mdot
.65787 .77652 Mdot
.58039 .41404 Mdot
.72259 .43809 Mdot
.35968 .45194 Mdot
.32028 .65225 Mdot
.45615 .62996 Mdot
.59721 .43248 Mdot
.40761 .62096 Mdot
.67782 .58389 Mdot
.55138 .49318 Mdot
.77389 .39573 Mdot
.60274 .4369 Mdot
.33177 .23254 Mdot
.54633 .50034 Mdot
.46928 .68946 Mdot
.59362 .4309 Mdot
.5013 .80435 Mdot
.6681 .27714 Mdot
.35176 .44583 Mdot
.36418 .46743 Mdot
.38008 .43833 Mdot
.40365 .65321 Mdot
.52288 .65274 Mdot
.32454 .4399 Mdot
.63535 .39858 Mdot
.35196 .41461 Mdot
.32577 .62629 Mdot
.32105 .24388 Mdot
.37519 .44208 Mdot
.44803 .62826 Mdot
.37604 .64183 Mdot
.28776 .59907 Mdot
.46829 .29572 Mdot
.20984 .37629 Mdot
.69217 .6717 Mdot
.43604 .5845 Mdot
.45651 .70214 Mdot
.61802 .58657 Mdot
.79271 .44423 Mdot
.4288 .70965 Mdot
.40599 .37739 Mdot
.65529 .57942 Mdot
.44389 .27502 Mdot
.61722 .60212 Mdot
.47608 .63792 Mdot
.4269 .62063 Mdot
.5981 .62265 Mdot
.53637 .29987 Mdot
.71118 .3716 Mdot
.44325 .19077 Mdot
.67801 .59625 Mdot
.59881 .44051 Mdot
.61227 .45387 Mdot
.59524 .40414 Mdot
.50249 .34197 Mdot
.65807 .63721 Mdot
.40113 .6184 Mdot
.47272 .31173 Mdot
.46132 .64038 Mdot
.59915 .42184 Mdot
.52872 .15535 Mdot
.67036 .59859 Mdot
.46821 .59849 Mdot
.83554 .47172 Mdot
.48467 .34505 Mdot
.34214 .44014 Mdot
.4439 .41803 Mdot
.46526 .37726 Mdot
.63409 .43617 Mdot
.65915 .65035 Mdot
.61126 .37705 Mdot
.4026 .49631 Mdot
.48461 .57885 Mdot
.40186 .66603 Mdot
.57514 .17687 Mdot
.8073 .39049 Mdot
.39165 .64356 Mdot
.46264 .31268 Mdot
.48669 .29954 Mdot
.43829 .64683 Mdot
.66755 .63091 Mdot
.34203 .46546 Mdot
.37557 .41997 Mdot
.47057 .66285 Mdot
.50803 .44561 Mdot
.32043 .61698 Mdot
.42234 .64761 Mdot
.50671 .5816 Mdot
.46335 .36881 Mdot
.65492 .2825 Mdot
.75349 .53787 Mdot
.36098 .46357 Mdot
.42398 .62579 Mdot
.70172 .39324 Mdot
.66491 .58356 Mdot
.45235 .33806 Mdot
.62529 .41089 Mdot
.37149 .5023 Mdot
.48759 .36397 Mdot
.4374 .64635 Mdot
.4293 .65002 Mdot
.59913 .38743 Mdot
.66645 .56013 Mdot
.35793 .43947 Mdot
.47307 .31313 Mdot
.34795 .46406 Mdot
.64113 .59401 Mdot
.66633 .6005 Mdot
.5098 .6092 Mdot
.40653 .54804 Mdot
.4756 .3646 Mdot
.49244 .63424 Mdot
.44893 .29742 Mdot
.40652 .4314 Mdot
.57439 .42551 Mdot
.44282 .66981 Mdot
.69385 .63465 Mdot
.5994 .41628 Mdot
.44607 .59166 Mdot
.65793 .21524 Mdot
.44499 .66375 Mdot
.46969 .37856 Mdot
.66674 .77079 Mdot
.34353 .42037 Mdot
.72989 .6208 Mdot
.462 .53066 Mdot
.42493 .60352 Mdot
.44254 .29914 Mdot
.35918 .62728 Mdot
.58321 .40226 Mdot
.6448 .5818 Mdot
.82475 .64926 Mdot
.61023 .42022 Mdot
.41963 .61201 Mdot
.35907 .42936 Mdot
.69748 .61637 Mdot
.66922 .29975 Mdot
.75637 .5308 Mdot
.50135 .66935 Mdot
.38632 .58282 Mdot
.41081 .60663 Mdot
.32073 .75033 Mdot
.45772 .33355 Mdot
.62697 .6156 Mdot
.57771 .42324 Mdot
.6158 .41121 Mdot
.48955 .33155 Mdot
.7023 .49941 Mdot
.52008 .28058 Mdot
.42038 .10292 Mdot
.44883 .34862 Mdot
.34819 .41329 Mdot
.47907 .44152 Mdot
.44167 .3124 Mdot
.46483 .33262 Mdot
.47766 .36754 Mdot
.73044 .51041 Mdot
.67381 .617 Mdot
.4375 .63025 Mdot
.61263 .62414 Mdot
.4539 .66185 Mdot
.31134 .69748 Mdot
.60873 .40802 Mdot
.64613 .58261 Mdot
.61981 .19349 Mdot
.35012 .61879 Mdot
.45613 .60647 Mdot
.30752 .29332 Mdot
.40033 .68346 Mdot
.32113 .53516 Mdot
.4464 .68384 Mdot
.47647 .35596 Mdot
.5 .68349 Mdot
.36993 .59325 Mdot
.76406 .63231 Mdot
.62472 .43235 Mdot
.68304 .28234 Mdot
.39754 .58359 Mdot
.50673 .65522 Mdot
.69612 .61916 Mdot
.6828 .60319 Mdot
.32548 .44252 Mdot
.48907 .41586 Mdot
.62718 .42877 Mdot
.53698 .36865 Mdot
.42813 .58957 Mdot
.64101 .46995 Mdot
.67909 .74595 Mdot
.44856 .59159 Mdot
.24918 .36416 Mdot
.55583 .80863 Mdot
.43062 .66076 Mdot
.49042 .77446 Mdot
.61768 .42959 Mdot
.71995 .70882 Mdot
.49362 .60624 Mdot
.47911 .33002 Mdot
.63942 .58697 Mdot
.61428 .5936 Mdot
.37504 .43454 Mdot
.79973 .595 Mdot
.63164 .44921 Mdot
.64499 .58566 Mdot
.46404 .61428 Mdot
.61856 .40609 Mdot
.67824 .29356 Mdot
.36946 .62627 Mdot
.23306 .45145 Mdot
.66129 .61108 Mdot
.50239 .61404 Mdot
.64447 .49327 Mdot
.43685 .43705 Mdot
.17491 .40953 Mdot
.59112 .4073 Mdot
.36715 .45927 Mdot
.45827 .68195 Mdot
.63231 .22133 Mdot
.45839 .57135 Mdot
.30986 .63309 Mdot
.66557 .66146 Mdot
.33685 .45688 Mdot
.46738 .60628 Mdot
.42431 .65743 Mdot
.49866 .45223 Mdot
.37947 .45485 Mdot
.44445 .66629 Mdot
.50537 .59716 Mdot
.66387 .62444 Mdot
.68454 .29035 Mdot
.6671 .60712 Mdot
.44906 .62442 Mdot
.5135 .67344 Mdot
.67578 .62196 Mdot
.41114 .2365 Mdot
.38867 .44684 Mdot
.59178 .3974 Mdot
.52389 .60785 Mdot
.40883 .58934 Mdot
.20529 .65776 Mdot
.68147 .27743 Mdot
.39175 .79323 Mdot
.43888 .34544 Mdot
.6612 .35338 Mdot
.52414 .33765 Mdot
.25799 .29076 Mdot
.75426 .57942 Mdot
.49636 .5943 Mdot
.23573 .52232 Mdot
.47516 .76634 Mdot
.62242 .45471 Mdot
.51886 .70517 Mdot
.42829 .58807 Mdot
.47384 .62466 Mdot
.46375 .30311 Mdot
.69411 .51019 Mdot
.76407 .44652 Mdot
.52253 .44789 Mdot
.36247 .44018 Mdot
.64891 .59062 Mdot
.43499 .60289 Mdot
.52146 .24311 Mdot
.44805 .33826 Mdot
.59275 .52127 Mdot
.47325 .6061 Mdot
.78134 .48977 Mdot
.72786 .4694 Mdot
.61778 .40448 Mdot
.43441 .3057 Mdot
.46535 .3766 Mdot
.47905 .62718 Mdot
.63248 .42455 Mdot
.43997 .65859 Mdot
.57557 .51037 Mdot
.49865 .62366 Mdot
.36603 .42735 Mdot
.46776 .58872 Mdot
.48729 .4707 Mdot
.21123 .32875 Mdot
.43007 .69768 Mdot
.63443 .63376 Mdot
.50093 .34457 Mdot
.48935 .34579 Mdot
.67743 .59818 Mdot
.48949 .34203 Mdot
.52881 .76266 Mdot
.67273 .71846 Mdot
.36556 .44368 Mdot
.4956 .69879 Mdot
.36168 .4245 Mdot
.68323 .28121 Mdot
.44402 .58251 Mdot
.64766 .23821 Mdot
.45356 .355 Mdot
.48485 .82837 Mdot
.61498 .41703 Mdot
.68164 .2789 Mdot
.44183 .57022 Mdot
.36765 .28432 Mdot
.45603 .29871 Mdot
.43938 .36728 Mdot
.44421 .65285 Mdot
.6801 .60593 Mdot
.4235 .65649 Mdot
.48131 .66024 Mdot
.66583 .27132 Mdot
.40913 .60711 Mdot
.59167 .44112 Mdot
.66363 .63684 Mdot
.27591 .28625 Mdot
.50385 .32453 Mdot
.47344 .59649 Mdot
.46462 .61331 Mdot
.67744 .58155 Mdot
.4386 .57174 Mdot
.63101 .43539 Mdot
.16274 .31171 Mdot
.3582 .4517 Mdot
.65151 .29044 Mdot
.45762 .38015 Mdot
.39226 .60794 Mdot
.42084 .65041 Mdot
.56306 .1736 Mdot
.73611 .357 Mdot
.59115 .43888 Mdot
.45783 .6749 Mdot
.46519 .31554 Mdot
.36204 .42972 Mdot
.62946 .39685 Mdot
.4231 .63391 Mdot
.47755 .61604 Mdot
.3673 .42888 Mdot
.26411 .34154 Mdot
.40848 .35357 Mdot
.59941 .40085 Mdot
.48915 .6944 Mdot
.3918 .30722 Mdot
.46029 .63428 Mdot
.45596 .21612 Mdot
.66621 .59382 Mdot
.5906 .4246 Mdot
.40725 .76737 Mdot
.47952 .64063 Mdot
.62871 .44076 Mdot
.62646 .42873 Mdot
.4785 .59476 Mdot
.61749 .63064 Mdot
.68438 .62921 Mdot
.666 .58885 Mdot
.66601 .77784 Mdot
.26529 .6281 Mdot
.45705 .34533 Mdot
.6176 .43123 Mdot
.47823 .29237 Mdot
.34485 .46814 Mdot
.4598 .43021 Mdot
.47792 .29416 Mdot
.61684 .58923 Mdot
.44378 .29254 Mdot
.43386 .65661 Mdot
.62832 .43012 Mdot
.45048 .31857 Mdot
.38915 .61866 Mdot
.48251 .55694 Mdot
.53257 .50822 Mdot
.33839 .46206 Mdot
.41728 .404 Mdot
.43166 .61685 Mdot
.66692 .27287 Mdot
.45389 .58748 Mdot
.61842 .40184 Mdot
.46628 .4641 Mdot
.39038 .62118 Mdot
.47178 .36392 Mdot
.44512 .5074 Mdot
.48295 .30199 Mdot
.49371 .65303 Mdot
.44744 .62419 Mdot
.46396 .63262 Mdot
.42754 .65985 Mdot
.72103 .45682 Mdot
.61035 .45994 Mdot
.517 .5852 Mdot
.50315 .30182 Mdot
.64697 .61472 Mdot
.65613 .56811 Mdot
.40967 .27518 Mdot
.65618 .27719 Mdot
.61991 .43839 Mdot
.45865 .63594 Mdot
.43692 .36459 Mdot
.51834 .15614 Mdot
.45088 .20867 Mdot
.28519 .35773 Mdot
.45742 .31407 Mdot
.63434 .63297 Mdot
.44421 .31973 Mdot
.47333 .63264 Mdot
.41107 .67911 Mdot
.26333 .29307 Mdot
.58123 .45254 Mdot
.35638 .4404 Mdot
.46485 .63786 Mdot
.31983 .68442 Mdot
.46548 .31457 Mdot
.46017 .36811 Mdot
.45277 .65818 Mdot
.68868 .61662 Mdot
.13899 .44955 Mdot
.62415 .40876 Mdot
.4926 .71119 Mdot
.71561 .63842 Mdot
.69479 .55308 Mdot
.61954 .41055 Mdot
.54387 .52861 Mdot
.49468 .32864 Mdot
.71987 .66449 Mdot
.64983 .61194 Mdot
.35237 .43899 Mdot
.41447 .67724 Mdot
.61482 .59396 Mdot
.43103 .31042 Mdot
.62448 .58544 Mdot
.47426 .64511 Mdot
.61521 .45823 Mdot
.49079 .32785 Mdot
.64141 .45895 Mdot
.59686 .6205 Mdot
.35479 .42029 Mdot
.32257 .65558 Mdot
.51616 .70072 Mdot
.55391 .80946 Mdot
.39283 .62771 Mdot
.41635 .3331 Mdot
.40649 .62262 Mdot
.69484 .61914 Mdot
.45469 .62996 Mdot
.58929 .63488 Mdot
.43708 .33356 Mdot
.50186 .61333 Mdot
.43915 .57607 Mdot
.57425 .65978 Mdot
.45602 .59966 Mdot
.45004 .57334 Mdot
.42 .65916 Mdot
.71122 .64655 Mdot
.50487 .60309 Mdot
.67804 .61295 Mdot
.74306 .4925 Mdot
.46623 .33485 Mdot
.32437 .44809 Mdot
.37994 .42707 Mdot
.31233 .6266 Mdot
.31967 .65523 Mdot
.7062 .50254 Mdot
.67057 .6111 Mdot
.60757 .44853 Mdot
.44107 .65849 Mdot
.40227 .75987 Mdot
.38677 .41618 Mdot
.4937 .32884 Mdot
.50233 .3509 Mdot
.39319 .55437 Mdot
.31033 .74464 Mdot
.50398 .61264 Mdot
.76209 .53083 Mdot
.48037 .65121 Mdot
.43739 .66818 Mdot
.48319 .37017 Mdot
.35197 .54805 Mdot
.39266 .62796 Mdot
.69626 .61893 Mdot
.34797 .43928 Mdot
.41055 .70001 Mdot
.30162 .43447 Mdot
.56623 .52372 Mdot
.60377 .66032 Mdot
.40209 .61152 Mdot
.47864 .31569 Mdot
.61703 .60823 Mdot
.7715 .55503 Mdot
.59734 .40679 Mdot
.73083 .53416 Mdot
.56912 .68126 Mdot
.37605 .24992 Mdot
.3522 .44114 Mdot
.25982 .35521 Mdot
.44029 .60829 Mdot
.49912 .35009 Mdot
.46654 .65343 Mdot
.50952 .1577 Mdot
.33284 .42752 Mdot
.61783 .57542 Mdot
.60009 .44207 Mdot
.67578 .58345 Mdot
.57585 .78992 Mdot
.53987 .55391 Mdot
.66671 .3217 Mdot
.4996 .30739 Mdot
.35681 .73261 Mdot
.62737 .60244 Mdot
.42978 .64269 Mdot
.44974 .0998 Mdot
.66447 .5934 Mdot
.68 .59413 Mdot
.41034 .41651 Mdot
.32422 .49288 Mdot
.36097 .62804 Mdot
.6301 .58051 Mdot
.47108 .28778 Mdot
.33785 .43661 Mdot
.40055 .64197 Mdot
.42011 .65783 Mdot
.68212 .61053 Mdot
.45198 .29906 Mdot
.34444 .73222 Mdot
.47849 .35735 Mdot
.65796 .62747 Mdot
.48031 .34478 Mdot
.46063 .38615 Mdot
.45386 .32204 Mdot
.41931 .58039 Mdot
.45582 .63647 Mdot
.29789 .38803 Mdot
.66624 .60066 Mdot
.41229 .64607 Mdot
.42834 .62658 Mdot
.63005 .60544 Mdot
.48124 .28245 Mdot
.38565 .7561 Mdot
.41714 .59701 Mdot
.4442 .63503 Mdot
.34299 .4617 Mdot
.4781 .26801 Mdot
.51058 .22708 Mdot
.40474 .64344 Mdot
.36931 .41527 Mdot
.67106 .63785 Mdot
.45214 .58779 Mdot
.32808 .61308 Mdot
.50155 .36242 Mdot
.47771 .59737 Mdot
.66927 .3007 Mdot
.39379 .60393 Mdot
.1442 .44065 Mdot
.46203 .58688 Mdot
.6314 .61821 Mdot
.63226 .58966 Mdot
.43537 .40645 Mdot
.64607 .60177 Mdot
.68064 .28314 Mdot
.60038 .42181 Mdot
.41385 .202 Mdot
.67878 .29012 Mdot
.42837 .66834 Mdot
.83712 .49803 Mdot
.49277 .62915 Mdot
.39507 .5881 Mdot
.3889 .7752 Mdot
.67856 .2881 Mdot
.62365 .59615 Mdot
.53995 .30637 Mdot
.46459 .66806 Mdot
.6274 .41267 Mdot
.37851 .64198 Mdot
.47043 .5888 Mdot
.70619 .55133 Mdot
.61628 .80043 Mdot
.61506 .39795 Mdot
.44691 .68797 Mdot
.4046 .64275 Mdot
.78624 .37134 Mdot
.4565 .61552 Mdot
.37544 .43916 Mdot
.67365 .59003 Mdot
.44153 .33004 Mdot
.34957 .45228 Mdot
.42378 .59686 Mdot
.35359 .43544 Mdot
.45435 .33988 Mdot
.594 .41964 Mdot
.47834 .60206 Mdot
.37591 .41578 Mdot
.36098 .43917 Mdot
.40887 .62995 Mdot
.64357 .58443 Mdot
.36104 .66023 Mdot
.45061 .58836 Mdot
.43304 .64347 Mdot
.67724 .60049 Mdot
.83571 .37969 Mdot
.47409 .63684 Mdot
.5146 .50143 Mdot
.61158 .58428 Mdot
.66876 .30819 Mdot
.44709 .31675 Mdot
.48764 .60852 Mdot
.60947 .40565 Mdot
.60344 .41009 Mdot
.44119 .28536 Mdot
.68308 .58762 Mdot
.46517 .29647 Mdot
.41815 .69237 Mdot
.41417 .54737 Mdot
.44664 .67763 Mdot
.81719 .65692 Mdot
.2563 .31715 Mdot
.65828 .63551 Mdot
.49188 .31785 Mdot
.52373 .44608 Mdot
.61642 .43741 Mdot
.44506 .28916 Mdot
.68402 .64179 Mdot
.63764 .63161 Mdot
.62532 .58153 Mdot
.34708 .46164 Mdot
.49481 .35006 Mdot
.65487 .55869 Mdot
.68943 .60928 Mdot
.44056 .65468 Mdot
.40557 .64258 Mdot
.59655 .63605 Mdot
.29124 .57613 Mdot
.35926 .42104 Mdot
.48207 .32207 Mdot
.18398 .65094 Mdot
.61723 .40098 Mdot
.57658 .65892 Mdot
.39115 .61181 Mdot
.63305 .1333 Mdot
.5072 .62719 Mdot
.46181 .61491 Mdot
.66331 .63886 Mdot
.34875 .41045 Mdot
.34736 .4271 Mdot
.6277 .60036 Mdot
.61448 .64157 Mdot
.37302 .45133 Mdot
.27298 .36392 Mdot
.33587 .22459 Mdot
.76064 .55462 Mdot
.63204 .61546 Mdot
.5192 .69498 Mdot
.634 .43376 Mdot
.59852 .61496 Mdot
.60589 .39406 Mdot
.46585 .33201 Mdot
.48644 .36188 Mdot
.59993 .38822 Mdot
.4471 .65106 Mdot
.4511 .332 Mdot
.50696 .66527 Mdot
.29249 .29009 Mdot
.19177 .51688 Mdot
.71588 .33597 Mdot
.38838 .61014 Mdot
.76451 .45974 Mdot
.75215 .41444 Mdot
.42808 .60948 Mdot
.34658 .65694 Mdot
.35493 .43904 Mdot
.59803 .60497 Mdot
.63151 .43203 Mdot
.17148 .42241 Mdot
.45962 .6349 Mdot
.64403 .62289 Mdot
.62357 .43524 Mdot
.49699 .39266 Mdot
.7128 .54789 Mdot
.45725 .65756 Mdot
.32733 .16131 Mdot
.60221 .59266 Mdot
.44145 .33056 Mdot
.81919 .54314 Mdot
.60778 .61674 Mdot
.40793 .40353 Mdot
.45503 .36796 Mdot
.46494 .19156 Mdot
.62312 .61345 Mdot
.44207 .28067 Mdot
.64209 .59593 Mdot
.36934 .42746 Mdot
.64633 .64761 Mdot
.48874 .32275 Mdot
.46341 .60213 Mdot
.48839 .33424 Mdot
.3618 .42089 Mdot
.50192 .34699 Mdot
.6327 .43152 Mdot
.67522 .27595 Mdot
.60902 .43161 Mdot
.44857 .428 Mdot
.63418 .79068 Mdot
.58542 .41088 Mdot
.52952 .35193 Mdot
.39016 .64034 Mdot
.67146 .56164 Mdot
.44303 .34017 Mdot
.49016 .29311 Mdot
.47884 .42958 Mdot
.64024 .61411 Mdot
.48785 .32589 Mdot
.56034 .68716 Mdot
.86488 .46705 Mdot
.52604 .63453 Mdot
.24893 .58979 Mdot
.63032 .6083 Mdot
.44114 .34531 Mdot
.76965 .54521 Mdot
.63296 .57434 Mdot
.4499 .34936 Mdot
.596 .43446 Mdot
.61714 .41092 Mdot
.458 .64839 Mdot
.61018 .46826 Mdot
.43732 .30646 Mdot
.70978 .38099 Mdot
.67203 .58553 Mdot
.49676 .39379 Mdot
.37762 .43781 Mdot
.46111 .32916 Mdot
.37589 .58201 Mdot
.61352 .6434 Mdot
.50845 .32223 Mdot
.22015 .49084 Mdot
.21188 .68626 Mdot
.48738 .32783 Mdot
.67321 .5891 Mdot
.65443 .62103 Mdot
.37516 .66403 Mdot
.5036 .4449 Mdot
.4663 .29834 Mdot
.64801 .25145 Mdot
.30753 .64126 Mdot
.66323 .29286 Mdot
.81515 .39451 Mdot
.39197 .6257 Mdot
.40941 .62155 Mdot
.61427 .44079 Mdot
.44891 .6061 Mdot
.68863 .62095 Mdot
.40219 .58484 Mdot
.6232 .44633 Mdot
.49252 .32454 Mdot
.46681 .5923 Mdot
.34111 .42571 Mdot
.63692 .42479 Mdot
.60873 .38746 Mdot
.47147 .34422 Mdot
.62842 .58055 Mdot
.49455 .24602 Mdot
.48084 .35764 Mdot
.40084 .61144 Mdot
.67412 .2867 Mdot
.48291 .63207 Mdot
.2525 .41602 Mdot
.66088 .57275 Mdot
.44311 .32145 Mdot
.61319 .60817 Mdot
.61049 .42756 Mdot
.45856 .28198 Mdot
.45112 .61647 Mdot
.45535 .35444 Mdot
.32709 .38748 Mdot
.2634 .38613 Mdot
.68857 .59424 Mdot
.30894 .43317 Mdot
.68258 .59541 Mdot
.66316 .29429 Mdot
.26618 .46401 Mdot
.35754 .44668 Mdot
.46367 .31939 Mdot
.24635 .32676 Mdot
.46414 .3638 Mdot
.45381 .59827 Mdot
.43791 .59356 Mdot
.46135 .30403 Mdot
.33349 .43929 Mdot
.56889 .84496 Mdot
.53068 .52578 Mdot
.6215 .59591 Mdot
.71405 .65977 Mdot
.14576 .57912 Mdot
.64419 .41809 Mdot
.60794 .4448 Mdot
.50437 .64794 Mdot
.44051 .66413 Mdot
.61841 .38795 Mdot
.58112 .43521 Mdot
.34253 .46359 Mdot
.48646 .35945 Mdot
.68709 .56398 Mdot
.63784 .41199 Mdot
.42781 .51862 Mdot
.32091 .67861 Mdot
.37949 .66668 Mdot
.47911 .56752 Mdot
.38283 .61902 Mdot
.43097 .43544 Mdot
.58879 .44245 Mdot
.43285 .61946 Mdot
.51071 .615 Mdot
.59024 .42984 Mdot
.36737 .42654 Mdot
.61428 .55387 Mdot
.48105 .33709 Mdot
.79354 .28921 Mdot
.47505 .59619 Mdot
.45974 .59638 Mdot
.60322 .4002 Mdot
.79617 .36292 Mdot
.64833 .63206 Mdot
.64985 .57387 Mdot
.4568 .33375 Mdot
.47929 .4269 Mdot
.41832 .57807 Mdot
.42966 .61228 Mdot
.46893 .32286 Mdot
.67268 .27504 Mdot
.69204 .33205 Mdot
.43905 .62901 Mdot
.62348 .42675 Mdot
.4275 .3764 Mdot
.58773 .44189 Mdot
.46587 .6518 Mdot
.45088 .59756 Mdot
.42177 .57883 Mdot
.43802 .66503 Mdot
.61471 .3907 Mdot
.43449 .6136 Mdot
.38085 .57114 Mdot
.64018 .57993 Mdot
.40475 .60193 Mdot
.31655 .60856 Mdot
.44737 .63351 Mdot
.34483 .42327 Mdot
.50617 .23835 Mdot
.46419 .63508 Mdot
.40581 .60256 Mdot
.5297 .52139 Mdot
.46994 .61043 Mdot
.61338 .39937 Mdot
.65108 .61639 Mdot
.6172 .43193 Mdot
.57767 .41745 Mdot
.4827 .292 Mdot
.3398 .46185 Mdot
.45345 .56839 Mdot
.3792 .43287 Mdot
.43055 .55754 Mdot
.47269 .64813 Mdot
.43141 .28055 Mdot
.76008 .52832 Mdot
.39225 .38268 Mdot
.45078 .61981 Mdot
.46111 .33479 Mdot
.44304 .33091 Mdot
.22979 .51065 Mdot
.47442 .69094 Mdot
.62253 .39148 Mdot
.59756 .43305 Mdot
.29416 .53008 Mdot
.72074 .56143 Mdot
.35216 .42109 Mdot
.54082 .45529 Mdot
.38412 .62557 Mdot
.43497 .63399 Mdot
.37859 .64448 Mdot
.479 .294 Mdot
.66216 .27286 Mdot
.4951 .33344 Mdot
.65856 .31602 Mdot
.59413 .44851 Mdot
.39586 .60044 Mdot
.18968 .49159 Mdot
.68168 .61832 Mdot
.65195 .61583 Mdot
.63104 .39326 Mdot
.47739 .29879 Mdot
.36572 .64785 Mdot
.82709 .65231 Mdot
.59751 .59007 Mdot
.32698 .42111 Mdot
.4258 .61195 Mdot
.4677 .34205 Mdot
.68469 .61718 Mdot
.38488 .43088 Mdot
.41318 .59182 Mdot
.50255 .29942 Mdot
.45302 .63201 Mdot
.46785 .77022 Mdot
.6351 .58327 Mdot
.51748 .15324 Mdot
.68781 .58919 Mdot
.63739 .43044 Mdot
.58337 .4227 Mdot
.44727 .59276 Mdot
.82235 .61201 Mdot
.61437 .57705 Mdot
.63593 .46214 Mdot
.33704 .41803 Mdot
.65223 .28933 Mdot
.32743 .43701 Mdot
.44161 .30935 Mdot
.34974 .44112 Mdot
.48011 .3652 Mdot
.29087 .54444 Mdot
.61322 .57008 Mdot
.35409 .4523 Mdot
.76856 .3365 Mdot
.41946 .56654 Mdot
.35545 .46836 Mdot
.39296 .55633 Mdot
.72154 .65091 Mdot
.47118 .32604 Mdot
.3342 .43723 Mdot
.42985 .64507 Mdot
.17232 .44454 Mdot
.58053 .41989 Mdot
.62359 .39337 Mdot
.43763 .56256 Mdot
.4731 .36945 Mdot
.61871 .64298 Mdot
.41624 .48082 Mdot
.67522 .30562 Mdot
.43164 .61345 Mdot
.39512 .60073 Mdot
.66847 .5706 Mdot
.69841 .60431 Mdot
.44788 .59627 Mdot
.53712 .69964 Mdot
.43819 .6073 Mdot
.61577 .40701 Mdot
.64091 .63173 Mdot
.65482 .61891 Mdot
.4361 .30426 Mdot
.68463 .59249 Mdot
.49141 .57606 Mdot
.56121 .40569 Mdot
.44489 .68011 Mdot
.6083 .42186 Mdot
.47431 .46856 Mdot
.50422 .33488 Mdot
.1903 .40097 Mdot
.67407 .57356 Mdot
.40817 .60529 Mdot
.68123 .59128 Mdot
.36956 .45093 Mdot
.66497 .60314 Mdot
.62688 .63174 Mdot
.43256 .58974 Mdot
.45828 .65785 Mdot
.67763 .28356 Mdot
.50204 .44065 Mdot
.65438 .58281 Mdot
.43304 .60614 Mdot
.49578 .62134 Mdot
.46607 .58127 Mdot
.51941 .48094 Mdot
.64754 .63717 Mdot
.62683 .70836 Mdot
.22207 .45507 Mdot
.64869 .58386 Mdot
.14201 .47938 Mdot
.66219 .3024 Mdot
.65351 .28239 Mdot
.64351 .43265 Mdot
.43895 .6315 Mdot
.48346 .30627 Mdot
.47524 .62981 Mdot
.51235 .65543 Mdot
.47767 .61843 Mdot
.34237 .41783 Mdot
.462 .56995 Mdot
.65978 .28722 Mdot
.48382 .35494 Mdot
.41395 .59642 Mdot
.47232 .59711 Mdot
.66085 .27149 Mdot
.68032 .57765 Mdot
.62966 .62581 Mdot
.4501 .21654 Mdot
.36897 .44316 Mdot
.59596 .4137 Mdot
.45451 .64689 Mdot
.45934 .33392 Mdot
.4885 .33835 Mdot
.67742 .58584 Mdot
.48141 .33029 Mdot
.62267 .40638 Mdot
.4536 .61277 Mdot
.61995 .39092 Mdot
.34597 .41708 Mdot
.6741 .59129 Mdot
.4563 .64636 Mdot
.44081 .65425 Mdot
.63202 .58969 Mdot
.38979 .63998 Mdot
.34352 .46197 Mdot
.47911 .3624 Mdot
.62815 .62234 Mdot
.60038 .41859 Mdot
.43927 .29956 Mdot
.43157 .65322 Mdot
.24589 .71687 Mdot
.44558 .60542 Mdot
.43859 .64399 Mdot
.29611 .25695 Mdot
.50135 .64928 Mdot
.43724 .32936 Mdot
.64766 .56769 Mdot
.38459 .59345 Mdot
.30526 .6774 Mdot
.58545 .18999 Mdot
.44881 .28656 Mdot
.4185 .60856 Mdot
.20165 .38123 Mdot
.41483 .60288 Mdot
.5371 .37803 Mdot
.40586 .31645 Mdot
.27041 .67077 Mdot
.47038 .56227 Mdot
.6019 .39189 Mdot
.67839 .28245 Mdot
.44899 .35493 Mdot
.51285 .79895 Mdot
.42916 .59612 Mdot
.49453 .80514 Mdot
.45053 .57674 Mdot
.61988 .41185 Mdot
.35229 .59396 Mdot
.48241 .32393 Mdot
.78355 .61189 Mdot
.40172 .61751 Mdot
.64732 .6365 Mdot
.45176 .28974 Mdot
.65349 .29742 Mdot
.43364 .64813 Mdot
.37489 .42334 Mdot
.57982 .4731 Mdot
.44654 .55081 Mdot
.60629 .41958 Mdot
.42704 .62732 Mdot
.45699 .68773 Mdot
.81191 .60302 Mdot
.63192 .5836 Mdot
.6045 .44333 Mdot
.78859 .43115 Mdot
.39241 .64652 Mdot
.62432 .6163 Mdot
.64836 .61252 Mdot
.37283 .42777 Mdot
.5888 .48975 Mdot
.67362 .43928 Mdot
.1934 .55945 Mdot
.6052 .79004 Mdot
.43316 .31084 Mdot
.72739 .38039 Mdot
.39967 .638 Mdot
.55022 .5559 Mdot
.60668 .39618 Mdot
.46268 .59913 Mdot
.64555 .77156 Mdot
.66705 .59009 Mdot
.44217 .62762 Mdot
.36405 .42536 Mdot
.57792 .47746 Mdot
.57782 .52981 Mdot
.19763 .6353 Mdot
.45824 .28648 Mdot
.4043 .67371 Mdot
.44629 .55655 Mdot
.66312 .30835 Mdot
.46613 .65768 Mdot
.4446 .34685 Mdot
.29639 .29889 Mdot
.33283 .43649 Mdot
.68636 .60704 Mdot
.66099 .3024 Mdot
.38468 .60642 Mdot
.48886 .60125 Mdot
.32341 .44602 Mdot
.4192 .63314 Mdot
.80073 .58436 Mdot
.6434 .3256 Mdot
.45058 .32624 Mdot
.62104 .58866 Mdot
.38245 .63038 Mdot
.66237 .2731 Mdot
.43414 .59118 Mdot
.56546 .62131 Mdot
.41156 .61685 Mdot
.64372 .4986 Mdot
.63978 .58751 Mdot
.60543 .42351 Mdot
.42467 .56067 Mdot
.47185 .62289 Mdot
.38924 .30428 Mdot
.5125 .65482 Mdot
.46549 .5892 Mdot
.69671 .61925 Mdot
.67143 .62769 Mdot
.67785 .61059 Mdot
.44971 .33648 Mdot
.75706 .54573 Mdot
.61829 .42263 Mdot
.42667 .57213 Mdot
.63756 .41131 Mdot
.50409 .55454 Mdot
.32177 .4338 Mdot
.15737 .50479 Mdot
.40868 .5962 Mdot
.67434 .61213 Mdot
.70268 .40789 Mdot
.67315 .6368 Mdot
.5129 .31333 Mdot
.62742 .4288 Mdot
.66343 .5916 Mdot
.46745 .61921 Mdot
.51697 .45133 Mdot
.22175 .65667 Mdot
.6123 .43682 Mdot
.38667 .65751 Mdot
.46198 .28516 Mdot
.50497 .34771 Mdot
.12114 .52371 Mdot
.58685 .43449 Mdot
.75092 .40838 Mdot
.42902 .6046 Mdot
.68125 .61751 Mdot
.59012 .40527 Mdot
.59052 .3945 Mdot
.47405 .32519 Mdot
.46031 .65364 Mdot
.46419 .62994 Mdot
.6677 .30123 Mdot
.59697 .42915 Mdot
.40215 .57302 Mdot
.47358 .65623 Mdot
.26465 .28927 Mdot
.62799 .54995 Mdot
.81593 .34425 Mdot
.41936 .69254 Mdot
.60323 .79526 Mdot
.46655 .4476 Mdot
.66201 .63597 Mdot
.46341 .64306 Mdot
.3781 .62327 Mdot
.43515 .31203 Mdot
.44929 .6099 Mdot
.49314 .31142 Mdot
.61047 .44606 Mdot
.15631 .51998 Mdot
.59422 .3618 Mdot
.27876 .34917 Mdot
.45415 .6045 Mdot
.67633 .53835 Mdot
.35255 .45668 Mdot
.5832 .38035 Mdot
.65359 .6295 Mdot
.39108 .65062 Mdot
.47106 .37748 Mdot
.46365 .31809 Mdot
.65199 .60514 Mdot
.74489 .43841 Mdot
.43228 .23632 Mdot
.44884 .6674 Mdot
.44707 .31258 Mdot
.6196 .34896 Mdot
.53209 .71033 Mdot
.5817 .45133 Mdot
.33257 .43284 Mdot
.49217 .32506 Mdot
.5986 .38597 Mdot
.5761 .60209 Mdot
.65401 .59564 Mdot
.63913 .56678 Mdot
.35076 .3595 Mdot
.4726 .29976 Mdot
.34225 .4486 Mdot
.74169 .56371 Mdot
.75178 .58764 Mdot
.3388 .42062 Mdot
.49247 .32309 Mdot
.67849 .62373 Mdot
.64836 .62606 Mdot
.6502 .61715 Mdot
.77922 .61643 Mdot
.66138 .57439 Mdot
.64551 .69236 Mdot
.4941 .62284 Mdot
.47953 .71427 Mdot
.41597 .60435 Mdot
.61453 .39346 Mdot
.63369 .58444 Mdot
.47701 .43721 Mdot
.41573 .66336 Mdot
.20028 .63264 Mdot
.42995 .61555 Mdot
.56607 .42629 Mdot
.441 .63348 Mdot
.54414 .66785 Mdot
.61017 .58565 Mdot
.44903 .61854 Mdot
.57988 .44211 Mdot
.3605 .43604 Mdot
.70659 .58932 Mdot
.46456 .63422 Mdot
.67715 .51476 Mdot
.5096 .62411 Mdot
.29812 .28901 Mdot
.39221 .49067 Mdot
.33295 .41629 Mdot
.50721 .60184 Mdot
.43269 .30187 Mdot
.70915 .6327 Mdot
.4612 .7169 Mdot
.61099 .43638 Mdot
.47821 .82015 Mdot
.46074 .32081 Mdot
.35086 .59781 Mdot
.46377 .67061 Mdot
.35315 .46474 Mdot
.69136 .64696 Mdot
.60549 .39825 Mdot
.39002 .60958 Mdot
.47582 .59128 Mdot
.27153 .41595 Mdot
.48287 .70764 Mdot
.45298 .57149 Mdot
.33532 .46129 Mdot
.6366 .71174 Mdot
.44803 .64106 Mdot
.48188 .28355 Mdot
.6214 .57748 Mdot
.45837 .56522 Mdot
.62221 .70442 Mdot
.4326 .60427 Mdot
.66143 .59711 Mdot
.66794 .56909 Mdot
.69761 .46997 Mdot
.33923 .41394 Mdot
.41181 .61726 Mdot
.39435 .47353 Mdot
.4052 .61782 Mdot
.62075 .42075 Mdot
.47476 .637 Mdot
.46513 .32718 Mdot
.7707 .54028 Mdot
.45514 .34853 Mdot
.47339 .63543 Mdot
.64485 .61941 Mdot
.59676 .39715 Mdot
.30812 .37794 Mdot
.40557 .3003 Mdot
.64683 .69512 Mdot
.6347 .20129 Mdot
.33846 .45212 Mdot
.37075 .46562 Mdot
.62552 .4575 Mdot
.44904 .62307 Mdot
.41644 .4203 Mdot
.49908 .6349 Mdot
.44386 .63654 Mdot
.47908 .61709 Mdot
.61417 .47004 Mdot
.61971 .43428 Mdot
.48447 .34104 Mdot
.44808 .5977 Mdot
.43411 .60751 Mdot
.65123 .58715 Mdot
.36219 .43784 Mdot
.44978 .34309 Mdot
.36496 .44976 Mdot
.47164 .35434 Mdot
.14368 .44488 Mdot
.39987 .67912 Mdot
.36078 .43423 Mdot
.62163 .45972 Mdot
.67816 .60096 Mdot
.68011 .27457 Mdot
.44139 .30615 Mdot
.48394 .32287 Mdot
.43105 .61166 Mdot
.67313 .59641 Mdot
.66508 .58211 Mdot
.36307 .4591 Mdot
.59032 .41604 Mdot
.47274 .63532 Mdot
.45694 .66214 Mdot
.2209 .55731 Mdot
.46193 .29225 Mdot
.55634 .70049 Mdot
.70827 .47691 Mdot
.45025 .62296 Mdot
.63405 .58031 Mdot
.46075 .58915 Mdot
.19915 .41128 Mdot
.61592 .59112 Mdot
.44035 .66727 Mdot
.73332 .57941 Mdot
.49025 .29935 Mdot
.66757 .4806 Mdot
.49073 .5957 Mdot
.55552 .17223 Mdot
.40223 .63161 Mdot
.25666 .26637 Mdot
.75661 .36507 Mdot
.40049 .58787 Mdot
.41536 .65424 Mdot
.20817 .59969 Mdot
.42374 .60251 Mdot
.65949 .29366 Mdot
.4293 .69559 Mdot
.63508 .63074 Mdot
.42591 .45526 Mdot
.51818 .31809 Mdot
.34191 .4146 Mdot
.45637 .3334 Mdot
.31298 .40601 Mdot
.36966 .42959 Mdot
.6297 .61329 Mdot
.42145 .65884 Mdot
.32598 .66409 Mdot
.5134 .32661 Mdot
.4869 .65536 Mdot
.62163 .42 Mdot
.5128 .30304 Mdot
.49911 .32476 Mdot
.60157 .42408 Mdot
.44287 .57503 Mdot
.34809 .74673 Mdot
.41973 .2716 Mdot
.44174 .1826 Mdot
.59986 .40073 Mdot
.62399 .41387 Mdot
.77764 .55884 Mdot
.34377 .41414 Mdot
.25481 .43746 Mdot
.62771 .5358 Mdot
.63169 .41779 Mdot
.30336 .50814 Mdot
.46558 .37075 Mdot
.67401 .5196 Mdot
.59818 .60539 Mdot
.39237 .67157 Mdot
.46893 .62042 Mdot
.58886 .42042 Mdot
.33522 .66989 Mdot
.8067 .54143 Mdot
.60895 .43276 Mdot
.41264 .55555 Mdot
.57724 .47972 Mdot
.67264 .29067 Mdot
.66937 .30243 Mdot
.32878 .42387 Mdot
.41463 .23854 Mdot
.63782 .59607 Mdot
.36287 .46412 Mdot
.63037 .49048 Mdot
.41614 .6222 Mdot
.60193 .43538 Mdot
.68027 .2722 Mdot
.60764 .41026 Mdot
.35227 .42545 Mdot
.32629 .42201 Mdot
.63833 .58058 Mdot
.64813 .63171 Mdot
.59482 .80207 Mdot
.30908 .54499 Mdot
.41401 .60024 Mdot
.4149 .77877 Mdot
.67474 .58633 Mdot
.48834 .69899 Mdot
.36484 .41391 Mdot
.36457 .43646 Mdot
.49415 .75991 Mdot
.44565 .65769 Mdot
.48184 .39665 Mdot
.45771 .63897 Mdot
.26082 .47524 Mdot
.44107 .67165 Mdot
.47696 .32778 Mdot
.39507 .61254 Mdot
.5062 .25078 Mdot
.39787 .64486 Mdot
.47341 .59538 Mdot
.49329 .34525 Mdot
.36588 .62091 Mdot
.46468 .32528 Mdot
.46431 .65196 Mdot
.34868 .47287 Mdot
.45912 .33415 Mdot
.26064 .60501 Mdot
.51646 .50225 Mdot
.66058 .27752 Mdot
.35942 .41783 Mdot
.37866 .43758 Mdot
.31436 .64405 Mdot
.64946 .6293 Mdot
.59673 .57564 Mdot
.44803 .62341 Mdot
.45965 .36757 Mdot
.61502 .44134 Mdot
.43526 .60691 Mdot
.38284 .64471 Mdot
.4761 .58179 Mdot
.66412 .58676 Mdot
.4768 .29928 Mdot
.3556 .43282 Mdot
.44614 .31998 Mdot
.39429 .27531 Mdot
.48754 .36424 Mdot
.51391 .62424 Mdot
.37075 .62251 Mdot
.54307 .61965 Mdot
.48382 .8101 Mdot
.74893 .64698 Mdot
.65054 .60011 Mdot
.67014 .27916 Mdot
.32366 .42838 Mdot
.69472 .66586 Mdot
.66784 .62191 Mdot
.4844 .31757 Mdot
.45328 .63198 Mdot
.39001 .5661 Mdot
.59693 .52932 Mdot
.69215 .65479 Mdot
.30119 .63279 Mdot
.49944 .34632 Mdot
.66637 .29271 Mdot
.76293 .55065 Mdot
.70652 .65527 Mdot
.46742 .43331 Mdot
.47501 .60504 Mdot
.37489 .42246 Mdot
.68477 .61701 Mdot
.3481 .37128 Mdot
.59281 .42842 Mdot
.50366 .44355 Mdot
.45342 .60559 Mdot
.71822 .40031 Mdot
.6445 .61868 Mdot
.36026 .42275 Mdot
.58874 .42152 Mdot
.34577 .41193 Mdot
.66597 .30459 Mdot
.43457 .21487 Mdot
.41145 .62897 Mdot
.45288 .58185 Mdot
.62339 .46247 Mdot
.6387 .59822 Mdot
.42442 .40121 Mdot
.26797 .41424 Mdot
.45096 .30942 Mdot
.41265 .39474 Mdot
.66723 .63575 Mdot
.58081 .64633 Mdot
.44691 .3262 Mdot
.63182 .3939 Mdot
.43122 .44022 Mdot
.61714 .45118 Mdot
.46206 .63791 Mdot
.66716 .61364 Mdot
.58861 .43804 Mdot
.38079 .32253 Mdot
.19818 .3659 Mdot
.5496 .6454 Mdot
.39922 .59886 Mdot
.15919 .51452 Mdot
.29794 .27111 Mdot
.33243 .64195 Mdot
.63259 .43591 Mdot
.44568 .58835 Mdot
.4569 .66691 Mdot
.39947 .61542 Mdot
.60469 .4489 Mdot
.3473 .29507 Mdot
.4764 .31749 Mdot
.42515 .61571 Mdot
.37693 .44099 Mdot
.47114 .33418 Mdot
.42407 .31257 Mdot
.45849 .36328 Mdot
.62287 .62648 Mdot
.43886 .66601 Mdot
.72853 .52112 Mdot
.23777 .28108 Mdot
.61631 .43307 Mdot
.66008 .27828 Mdot
.45312 .5796 Mdot
.70259 .73142 Mdot
.67724 .61127 Mdot
.45296 .30772 Mdot
.46088 .59666 Mdot
.37218 .2937 Mdot
.64988 .31831 Mdot
.48527 .35744 Mdot
.64714 .62717 Mdot
.3339 .63038 Mdot
.44785 .60974 Mdot
.40516 .63271 Mdot
.63277 .60093 Mdot
.45441 .20857 Mdot
.76198 .53448 Mdot
.4684 .59414 Mdot
.60458 .42441 Mdot
.85533 .52173 Mdot
.48077 .58679 Mdot
.60621 .64074 Mdot
.65187 .28946 Mdot
.68542 .50568 Mdot
.55611 .70536 Mdot
.51613 .64352 Mdot
.17237 .51144 Mdot
.34645 .55705 Mdot
.14829 .5028 Mdot
.38467 .4081 Mdot
.58974 .31707 Mdot
.14538 .42574 Mdot
.58058 .44428 Mdot
.50449 .69425 Mdot
.24908 .6525 Mdot
.74876 .46444 Mdot
.39844 .49177 Mdot
.60817 .21638 Mdot
.39702 .30577 Mdot
.70923 .25699 Mdot
.455 .35659 Mdot
.25022 .47601 Mdot
.47655 .62949 Mdot
.31133 .25798 Mdot
.54589 .68339 Mdot
.81446 .56988 Mdot
.15248 .4837 Mdot
.38785 .48455 Mdot
.23675 .66853 Mdot
.20948 .3779 Mdot
.35932 .73696 Mdot
.60975 .52137 Mdot
.65864 .25631 Mdot
.74705 .56961 Mdot
.28587 .44397 Mdot
.39719 .68434 Mdot
.52308 .24769 Mdot
.3462 .25948 Mdot
.65573 .7273 Mdot
.83076 .56535 Mdot
.43795 .31597 Mdot
.61579 .58262 Mdot
.21746 .56228 Mdot
.71117 .61049 Mdot
.55365 .41118 Mdot
.17189 .51287 Mdot
.25108 .29397 Mdot
.54625 .66665 Mdot
.59029 .17314 Mdot
.51262 .7841 Mdot
.61935 .82182 Mdot
.53624 .5047 Mdot
.6456 .56327 Mdot
.60137 .28377 Mdot
.75172 .58898 Mdot
.66107 .37006 Mdot
.66652 .67176 Mdot
.3465 .40296 Mdot
.27842 .60663 Mdot
.64257 .62235 Mdot
.5443 .71266 Mdot
.64884 .30275 Mdot
.64889 .48264 Mdot
.42731 .28652 Mdot
.19148 .42885 Mdot
.69667 .2815 Mdot
.69502 .52216 Mdot
.70856 .36778 Mdot
.23507 .70798 Mdot
.33422 .51927 Mdot
.22946 .37322 Mdot
.66524 .43014 Mdot
.36306 .53729 Mdot
.78083 .51003 Mdot
.31609 .55835 Mdot
.75436 .6054 Mdot
.3295 .77654 Mdot
.35535 .22408 Mdot
.26324 .71841 Mdot
.70499 .60373 Mdot
.45213 .57189 Mdot
.20837 .4397 Mdot
.60728 .78684 Mdot
.33203 .41575 Mdot
.21788 .66696 Mdot
.37658 .42054 Mdot
.70392 .59343 Mdot
.74872 .44863 Mdot
.59697 .66193 Mdot
.52779 .34753 Mdot
.37055 .47183 Mdot
.5033 .60319 Mdot
.54855 .88308 Mdot
.17033 .54209 Mdot
.69413 .48229 Mdot
.26463 .28706 Mdot
.65446 .44518 Mdot
.45575 .40727 Mdot
.61024 .44741 Mdot
.1746 .38892 Mdot
.6607 .62268 Mdot
.19891 .31816 Mdot
.19541 .35846 Mdot
.82272 .46067 Mdot
.66599 .85511 Mdot
.71042 .31611 Mdot
.48645 .71389 Mdot
.3261 .68795 Mdot
.28801 .64947 Mdot
.79624 .51947 Mdot
.81801 .43679 Mdot
.63164 .47909 Mdot
.43468 .20311 Mdot
.15779 .42791 Mdot
.28452 .49738 Mdot
.32096 .28776 Mdot
.76127 .47567 Mdot
.50811 .48774 Mdot
.59397 .62955 Mdot
.50037 .50373 Mdot
.5676 .56195 Mdot
.24499 .69309 Mdot
.67523 .74614 Mdot
.83471 .61403 Mdot
.35735 .39115 Mdot
.80321 .38141 Mdot
.26878 .30829 Mdot
.25313 .58336 Mdot
.63474 .66686 Mdot
.73467 .49657 Mdot
.51167 .61997 Mdot
.7519 .53852 Mdot
.35017 .63768 Mdot
.30722 .43365 Mdot
.76951 .55898 Mdot
.56384 .35771 Mdot
.27608 .43866 Mdot
.19395 .52628 Mdot
.70451 .55329 Mdot
.62094 .62072 Mdot
.32308 .57672 Mdot
.31949 .51342 Mdot
.26645 .2926 Mdot
.78684 .43047 Mdot
.42973 .18713 Mdot
.8007 .43595 Mdot
.5002 .63181 Mdot
.49253 .69849 Mdot
.37424 .66615 Mdot
.32535 .53981 Mdot
.49834 .61381 Mdot
.70283 .38105 Mdot
.28153 .26873 Mdot
.65346 .76719 Mdot
.29025 .4264 Mdot
.44963 .80082 Mdot
.40278 .20197 Mdot
.21206 .44726 Mdot
.755 .37289 Mdot
.39815 .72636 Mdot
.45512 .86055 Mdot
.47595 .34214 Mdot
.2989 .50896 Mdot
.59894 .38381 Mdot
.34731 .3637 Mdot
.2798 .69672 Mdot
.82014 .47508 Mdot
.28688 .26301 Mdot
.74296 .503 Mdot
.40986 .33239 Mdot
.52691 .41337 Mdot
.52199 .30993 Mdot
.43593 .79755 Mdot
.37671 .58746 Mdot
.48672 .53809 Mdot
.37127 .46174 Mdot
.61018 .77579 Mdot
.22643 .44137 Mdot
.56014 .21471 Mdot
.5184 .60179 Mdot
.56875 .24811 Mdot
.66494 .29651 Mdot
.51095 .44592 Mdot
.12307 .51005 Mdot
.48605 .68081 Mdot
.72784 .33074 Mdot
.37002 .21561 Mdot
.42335 .43238 Mdot
.24923 .3582 Mdot
.72274 .44441 Mdot
.29565 .74567 Mdot
.21992 .31764 Mdot
.451 .23567 Mdot
.15442 .52944 Mdot
.42335 .16446 Mdot
.33576 .77058 Mdot
.44727 .78491 Mdot
.56871 .39969 Mdot
.22897 .2457 Mdot
.46886 .30823 Mdot
.50614 .82702 Mdot
.61769 .78382 Mdot
.35321 .31106 Mdot
.64377 .64966 Mdot
.37864 .55448 Mdot
.69355 .25852 Mdot
.60749 .5787 Mdot
.5033 .60004 Mdot
.20215 .66528 Mdot
.34862 .79768 Mdot
.21226 .67268 Mdot
.41495 .21124 Mdot
.15254 .52197 Mdot
.23726 .624 Mdot
.6486 .68991 Mdot
.22406 .49206 Mdot
.47079 .64325 Mdot
.27746 .52188 Mdot
.71509 .32245 Mdot
.40729 .32811 Mdot
.67526 .39721 Mdot
.64831 .64539 Mdot
.29488 .73149 Mdot
.11708 .54627 Mdot
.5253 .76387 Mdot
.60107 .71842 Mdot
.55992 .54664 Mdot
.31447 .53425 Mdot
.40471 .51102 Mdot
.52678 .22883 Mdot
.2689 .29864 Mdot
.2438 .64628 Mdot
.29757 .48918 Mdot
.59462 .22656 Mdot
.53243 .31516 Mdot
.79161 .36977 Mdot
.186 .41595 Mdot
.23805 .59299 Mdot
.81121 .43557 Mdot
.39226 .73078 Mdot
.81327 .52353 Mdot
.51253 .2036 Mdot
.4414 .39413 Mdot
.32682 .50378 Mdot
.50544 .33043 Mdot
.28286 .503 Mdot
.59065 .50207 Mdot
.21147 .53136 Mdot
.33666 .57626 Mdot
.27768 .49412 Mdot
.52929 .30718 Mdot
.17819 .61416 Mdot
.47043 .15663 Mdot
.41075 .81559 Mdot
.53107 .17189 Mdot
.3494 .64097 Mdot
.4861 .60136 Mdot
.32722 .23241 Mdot
.16754 .61025 Mdot
.24066 .28561 Mdot
.7186 .3944 Mdot
.37454 .32094 Mdot
.57031 .43135 Mdot
.43517 .81456 Mdot
.5448 .19324 Mdot
.23591 .32403 Mdot
.74798 .63307 Mdot
.6438 .42979 Mdot
.75177 .5081 Mdot
.46426 .81517 Mdot
.35775 .74125 Mdot
.55138 .72447 Mdot
.39548 .68119 Mdot
.52025 .70429 Mdot
.62688 .57322 Mdot
.72592 .38788 Mdot
.31816 .54829 Mdot
.47171 .34331 Mdot
.25209 .61251 Mdot
.51286 .55776 Mdot
.51192 .62311 Mdot
.42818 .38664 Mdot
.59121 .61379 Mdot
.51397 .81492 Mdot
.6249 .48035 Mdot
.13827 .44232 Mdot
.72431 .34626 Mdot
.38564 .53283 Mdot
.34131 .5483 Mdot
.35035 .37851 Mdot
.74355 .5259 Mdot
.62146 .45606 Mdot
.16158 .45597 Mdot
.46946 .49304 Mdot
.32677 .56958 Mdot
.52213 .70565 Mdot
.26023 .41718 Mdot
.38643 .65072 Mdot
.70826 .45238 Mdot
.68375 .70253 Mdot
.50429 .43714 Mdot
.69086 .5707 Mdot
.58983 .60783 Mdot
.67443 .19784 Mdot
.53079 .28174 Mdot
.78422 .40386 Mdot
.16595 .45375 Mdot
.61813 .44815 Mdot
.6712 .64146 Mdot
.2716 .50121 Mdot
.2711 .38367 Mdot
.67794 .72092 Mdot
.44001 .36349 Mdot
.33906 .49409 Mdot
.54371 .20629 Mdot
.16146 .51582 Mdot
.19718 .61189 Mdot
.81505 .60234 Mdot
.69276 .60468 Mdot
.25083 .41268 Mdot
.27194 .401 Mdot
.68936 .60335 Mdot
.68086 .65883 Mdot
.6096 .52608 Mdot
.1381 .51025 Mdot
.74267 .53698 Mdot
.50339 .17902 Mdot
.42822 .43952 Mdot
.36332 .29058 Mdot
.32566 .37931 Mdot
.3181 .49059 Mdot
.16923 .45224 Mdot
.53371 .72147 Mdot
.31563 .72718 Mdot
.39782 .68652 Mdot
.61107 .80223 Mdot
.44081 .81748 Mdot
.52684 .49384 Mdot
.57439 .6442 Mdot
.56458 .36334 Mdot
.40166 .60887 Mdot
.23232 .70547 Mdot
.29634 .28183 Mdot
.77 .58438 Mdot
.61705 .48179 Mdot
.42272 .64965 Mdot
.48878 .63898 Mdot
.3388 .67177 Mdot
.69568 .49462 Mdot
.38452 .80337 Mdot
.28074 .42735 Mdot
.35258 .66231 Mdot
.53589 .69766 Mdot
.72923 .33311 Mdot
.19402 .43715 Mdot
.28233 .29811 Mdot
.56395 .49158 Mdot
.71555 .32696 Mdot
.48293 .41603 Mdot
.49599 .17488 Mdot
.55204 .25351 Mdot
.2304 .60857 Mdot
.65309 .54056 Mdot
.71637 .49194 Mdot
.36265 .37514 Mdot
.46607 .5873 Mdot
.7446 .43879 Mdot
.20364 .38904 Mdot
.81911 .65161 Mdot
.78467 .50058 Mdot
.18965 .65566 Mdot
.54235 .60452 Mdot
.71927 .49994 Mdot
.29524 .71865 Mdot
.79801 .70066 Mdot
.52257 .23743 Mdot
.23922 .67775 Mdot
.51532 .40826 Mdot
.15955 .47121 Mdot
.57843 .39602 Mdot
.71413 .54752 Mdot
.45993 .80024 Mdot
.13764 .50364 Mdot
.22011 .40798 Mdot
.17726 .45596 Mdot
.37198 .72706 Mdot
.14532 .53759 Mdot
.74178 .63379 Mdot
.7168 .25884 Mdot
.45607 .28072 Mdot
.68748 .36243 Mdot
.41863 .76001 Mdot
.55574 .59102 Mdot
.30063 .50197 Mdot
.77528 .32802 Mdot
.70239 .67433 Mdot
.38778 .74768 Mdot
.2542 .54379 Mdot
.7196 .45928 Mdot
.34562 .54531 Mdot
.22125 .33986 Mdot
.71009 .25435 Mdot
.30464 .38458 Mdot
.76079 .39582 Mdot
.43609 .2118 Mdot
.69102 .49372 Mdot
.55959 .29824 Mdot
.2276 .37416 Mdot
.48871 .20143 Mdot
.36875 .50354 Mdot
.70233 .19577 Mdot
.3542 .26185 Mdot
.60519 .52747 Mdot
.27843 .72363 Mdot
.27552 .29569 Mdot
.74015 .64302 Mdot
.80833 .56605 Mdot
.59674 .81148 Mdot
.28916 .54699 Mdot
.47729 .61942 Mdot
.14414 .55232 Mdot
.27237 .5911 Mdot
.23088 .68138 Mdot
.37008 .20238 Mdot
.49507 .72318 Mdot
.50767 .65192 Mdot
.43923 .34736 Mdot
.56135 .5273 Mdot
.24926 .53404 Mdot
.24309 .6663 Mdot
.5619 .82498 Mdot
.40958 .39359 Mdot
.58851 .30427 Mdot
.44488 .37122 Mdot
.39207 .70411 Mdot
.70353 .32685 Mdot
.71067 .48054 Mdot
.33852 .39404 Mdot
.52142 .28257 Mdot
.31361 .52385 Mdot
.55379 .70291 Mdot
.3531 .73987 Mdot
.81049 .4894 Mdot
.55356 .38713 Mdot
.4356 .318 Mdot
.1996 .57108 Mdot
.36575 .24761 Mdot
.70152 .38648 Mdot
.36527 .77642 Mdot
.73716 .49182 Mdot
.24427 .48673 Mdot
.21462 .47882 Mdot
.7991 .50882 Mdot
.66023 .24887 Mdot
.38394 .76941 Mdot
.61374 .80104 Mdot
.49586 .38975 Mdot
.49183 .55546 Mdot
.14441 .44693 Mdot
.32046 .49598 Mdot
.21043 .50886 Mdot
.52528 .50735 Mdot
.62907 .7567 Mdot
.44386 .74634 Mdot
.26738 .62858 Mdot
.4832 .42847 Mdot
.51259 .8751 Mdot
.61656 .63713 Mdot
.23717 .71241 Mdot
.59634 .41898 Mdot
.76923 .6645 Mdot
.49428 .2592 Mdot
.5645 .50134 Mdot
.45424 .44177 Mdot
.70517 .45429 Mdot
.6393 .50431 Mdot
.42434 .20697 Mdot
.81818 .50612 Mdot
.48551 .36557 Mdot
.4096 .44336 Mdot
.50565 .1859 Mdot
.18831 .54938 Mdot
.39381 .58345 Mdot
.37724 .24765 Mdot
.5215 .49124 Mdot
.40657 .34131 Mdot
.32921 .23356 Mdot
.59546 .35539 Mdot
.43123 .55706 Mdot
.31432 .53791 Mdot
.25227 .68941 Mdot
.20558 .34774 Mdot
.79552 .5661 Mdot
.35029 .63915 Mdot
.56762 .39716 Mdot
.27294 .66917 Mdot
.17408 .53303 Mdot
.50386 .39383 Mdot
.70983 .53163 Mdot
.32901 .51448 Mdot
.267 .76557 Mdot
.34039 .78893 Mdot
.39154 .80317 Mdot
.41963 .43201 Mdot
.65417 .55643 Mdot
.69318 .73802 Mdot
.21207 .5042 Mdot
.68037 .37239 Mdot
.35515 .24515 Mdot
.30435 .51235 Mdot
.77445 .71147 Mdot
.66254 .67646 Mdot
.39523 .27152 Mdot
.4461 .74848 Mdot
.58455 .79464 Mdot
.57089 .41182 Mdot
.27842 .55215 Mdot
.42779 .4932 Mdot
.63711 .43697 Mdot
.718 .4639 Mdot
.66726 .51425 Mdot
.20964 .51204 Mdot
.66965 .71306 Mdot
.36004 .66725 Mdot
.1876 .51862 Mdot
.62966 .56046 Mdot
.3406 .3723 Mdot
.30925 .39018 Mdot
.40722 .48792 Mdot
.45282 .31347 Mdot
.50336 .6744 Mdot
.52234 .44079 Mdot
.50227 .41533 Mdot
.4948 .84241 Mdot
.37992 .42517 Mdot
.62376 .63413 Mdot
.76651 .63129 Mdot
.69154 .61346 Mdot
.15624 .60058 Mdot
.52755 .23058 Mdot
.53304 .69562 Mdot
.43904 .24256 Mdot
.59618 .25295 Mdot
.6268 .83043 Mdot
.41163 .78879 Mdot
.5265 .5245 Mdot
.68575 .66377 Mdot
.67597 .57907 Mdot
.52575 .33842 Mdot
.67155 .2604 Mdot
.56604 .71717 Mdot
.72526 .31747 Mdot
.23132 .48221 Mdot
.66423 .56586 Mdot
.37975 .27337 Mdot
.38015 .53752 Mdot
.12953 .48104 Mdot
.44628 .34693 Mdot
.42004 .84374 Mdot
.37019 .63222 Mdot
.29921 .70831 Mdot
.31813 .23787 Mdot
.77469 .53806 Mdot
.40994 .38278 Mdot
.63526 .22185 Mdot
.39895 .58556 Mdot
.37239 .68071 Mdot
.63894 .6226 Mdot
.24689 .44727 Mdot
.35357 .44305 Mdot
.30263 .60928 Mdot
.641 .42431 Mdot
.8131 .41498 Mdot
.70659 .33442 Mdot
.60529 .59408 Mdot
.46149 .50028 Mdot
.22182 .42315 Mdot
.66456 .52759 Mdot
.51921 .48904 Mdot
.2069 .59468 Mdot
.67093 .72541 Mdot
.66653 .56747 Mdot
.36935 .78202 Mdot
.27497 .42242 Mdot
.18216 .36701 Mdot
.42151 .52946 Mdot
.55211 .51498 Mdot
.67755 .53459 Mdot
.71297 .44539 Mdot
.56185 .70707 Mdot
.26668 .30319 Mdot
.32099 .56819 Mdot
.74243 .57762 Mdot
.27717 .49652 Mdot
.36056 .61117 Mdot
.58486 .30499 Mdot
.68554 .34787 Mdot
.75238 .73245 Mdot
.48242 .77647 Mdot
.77044 .51668 Mdot
.60624 .6476 Mdot
.72624 .32937 Mdot
.62005 .63441 Mdot
.31703 .34059 Mdot
.65769 .73211 Mdot
.46774 .24423 Mdot
.16075 .41117 Mdot
.27073 .29109 Mdot
.58052 .54727 Mdot
.42796 .36597 Mdot
.34546 .56244 Mdot
.38182 .53848 Mdot
.49464 .45385 Mdot
.40795 .58044 Mdot
.37309 .70021 Mdot
.79084 .56574 Mdot
.702 .40479 Mdot
.37384 .56 Mdot
.14503 .47769 Mdot
.19134 .35354 Mdot
.15982 .56512 Mdot
.47114 .39769 Mdot
.63018 .63362 Mdot
.30484 .75454 Mdot
.58643 .68586 Mdot
.22048 .33797 Mdot
.42543 .76581 Mdot
.65359 .18438 Mdot
.27226 .69374 Mdot
.55797 .36303 Mdot
.82237 .45285 Mdot
.6732 .45522 Mdot
.334 .23524 Mdot
.71611 .25787 Mdot
.30231 .45859 Mdot
.34183 .22712 Mdot
.54559 .88199 Mdot
.4633 .78419 Mdot
.68366 .51829 Mdot
.43703 .73476 Mdot
.36696 .5397 Mdot
.72495 .30457 Mdot
.47837 .63297 Mdot
.50753 .31607 Mdot
.4048 .37438 Mdot
.31315 .51784 Mdot
.52975 .59611 Mdot
.73092 .30955 Mdot
.24645 .5279 Mdot
.25232 .46786 Mdot
.27741 .39117 Mdot
.25248 .67215 Mdot
.57077 .71064 Mdot
.44557 .55745 Mdot
.69198 .5672 Mdot
.33004 .42522 Mdot
.30547 .41546 Mdot
.448 .66463 Mdot
.41018 .37431 Mdot
.62747 .52841 Mdot
.20127 .66798 Mdot
.29717 .36382 Mdot
.27622 .34469 Mdot
.59379 .59741 Mdot
.70215 .48333 Mdot
.19968 .46178 Mdot
.74843 .4585 Mdot
.74616 .3198 Mdot
.67029 .75051 Mdot
.16143 .52255 Mdot
.73299 .50506 Mdot
.28107 .46563 Mdot
.55968 .84576 Mdot
.62519 .4025 Mdot
.51869 .81093 Mdot
.23709 .63299 Mdot
.73824 .46629 Mdot
.70114 .59473 Mdot
.55663 .34689 Mdot
.60005 .32204 Mdot
.73069 .46352 Mdot
.37455 .21303 Mdot
.24164 .4278 Mdot
.46962 .74329 Mdot
.18882 .58928 Mdot
.466 .28805 Mdot
.29635 .49023 Mdot
.54637 .32008 Mdot
.7174 .28601 Mdot
.7047 .55046 Mdot
.14179 .45819 Mdot
.48651 .44736 Mdot
.27226 .60448 Mdot
.40743 .62859 Mdot
.62657 .70621 Mdot
.7038 .42464 Mdot
.53681 .32525 Mdot
.78241 .41384 Mdot
.61465 .60418 Mdot
.71312 .35821 Mdot
.63891 .29936 Mdot
.28403 .56574 Mdot
.50512 .54646 Mdot
.64967 .54473 Mdot
.39365 .428 Mdot
.66175 .31314 Mdot
.38922 .5826 Mdot
.28444 .62608 Mdot
.52943 .32849 Mdot
.48946 .80487 Mdot
.45729 .78813 Mdot
.19949 .57454 Mdot
.29496 .29907 Mdot
.69639 .38355 Mdot
.4176 .76816 Mdot
.64389 .49634 Mdot
.63668 .67777 Mdot
.76002 .44071 Mdot
.49249 .59692 Mdot
.32057 .33679 Mdot
.66266 .64039 Mdot
.18906 .56027 Mdot
.56147 .61818 Mdot
.25914 .60116 Mdot
.53127 .47251 Mdot
.20387 .43831 Mdot
.48907 .48089 Mdot
.32019 .23824 Mdot
.67502 .44966 Mdot
.31765 .5507 Mdot
.64653 .4472 Mdot
.5175 .40464 Mdot
.78923 .4969 Mdot
.1769 .40985 Mdot
.81553 .48766 Mdot
.3303 .68961 Mdot
.76246 .51006 Mdot
.63006 .78948 Mdot
.3544 .21286 Mdot
.30495 .55689 Mdot
.49647 .4551 Mdot
.40025 .51588 Mdot
.64122 .48775 Mdot
.67787 .27363 Mdot
.33794 .33269 Mdot
.58246 .69972 Mdot
.30224 .32349 Mdot
.43082 .26878 Mdot
.41253 .56746 Mdot
.70801 .72651 Mdot
.18112 .56473 Mdot
.71358 .66052 Mdot
.5516 .49977 Mdot
.38371 .3633 Mdot
.28451 .57641 Mdot
.8482 .36115 Mdot
.22914 .70321 Mdot
.40883 .62969 Mdot
.42997 .44663 Mdot
.29884 .60209 Mdot
.49455 .31431 Mdot
.56831 .7233 Mdot
.19715 .57152 Mdot
.62803 .41799 Mdot
.36889 .33252 Mdot
.6539 .34573 Mdot
.70228 .44647 Mdot
.26342 .63001 Mdot
.61392 .46868 Mdot
.17018 .62667 Mdot
.38466 .23725 Mdot
.70861 .42101 Mdot
.76675 .25864 Mdot
.71288 .38391 Mdot
.61672 .56366 Mdot
.21594 .40369 Mdot
.1751 .60804 Mdot
.42136 .43385 Mdot
.35033 .35998 Mdot
.46228 .79085 Mdot
.31766 .55895 Mdot
.26265 .46379 Mdot
.75913 .39441 Mdot
.72421 .36714 Mdot
.7223 .2683 Mdot
.59667 .25097 Mdot
.51661 .84933 Mdot
.52652 .71616 Mdot
.19852 .62191 Mdot
.52306 .23382 Mdot
.78356 .69968 Mdot
.17441 .38984 Mdot
.26996 .52611 Mdot
.74328 .3271 Mdot
.22795 .38409 Mdot
.3077 .63627 Mdot
.71146 .7056 Mdot
.50632 .23129 Mdot
.6705 .73633 Mdot
.58369 .24605 Mdot
.77203 .43754 Mdot
.28061 .49952 Mdot
.60223 .79401 Mdot
.48326 .44319 Mdot
.22902 .64074 Mdot
.80258 .36476 Mdot
.34433 .53867 Mdot
.37855 .33539 Mdot
.30576 .6688 Mdot
.18165 .52493 Mdot
.2199 .3756 Mdot
.47991 .45562 Mdot
.5504 .87755 Mdot
.24397 .68961 Mdot
.75723 .46105 Mdot
.49429 .61895 Mdot
.15828 .40396 Mdot
.44423 .46677 Mdot
.41982 .77183 Mdot
.34887 .23813 Mdot
.29775 .40925 Mdot
.6604 .53512 Mdot
.46663 .57656 Mdot
.40337 .78581 Mdot
.56561 .63982 Mdot
.5811 .79769 Mdot
.39946 .38085 Mdot
.33768 .55178 Mdot
.80635 .37775 Mdot
.28874 .66578 Mdot
.38136 .54097 Mdot
.66471 .63768 Mdot
.18525 .63941 Mdot
.35492 .7299 Mdot
.49743 .68323 Mdot
.45983 .72299 Mdot
.8167 .49574 Mdot
.67279 .23068 Mdot
.3553 .60949 Mdot
.74027 .52694 Mdot
.30333 .50369 Mdot
.22001 .48448 Mdot
.43342 .78768 Mdot
.68507 .84638 Mdot
.30769 .24372 Mdot
.61823 .64324 Mdot
.52311 .80431 Mdot
.40451 .46671 Mdot
.16328 .56672 Mdot
.5904 .22333 Mdot
.33529 .38125 Mdot
.83157 .5245 Mdot
.31869 .6007 Mdot
.41824 .67266 Mdot
.40427 .21097 Mdot
.17681 .39628 Mdot
.81688 .38679 Mdot
.1459 .44498 Mdot
.49942 .65867 Mdot
.40922 .68181 Mdot
.87472 .57264 Mdot
.16015 .49538 Mdot
.50876 .65432 Mdot
.81757 .5265 Mdot
.66055 .65288 Mdot
.46965 .63937 Mdot
.64586 .32995 Mdot
.33555 .50343 Mdot
.25792 .46928 Mdot
.13857 .50608 Mdot
.64021 .55949 Mdot
.40868 .37019 Mdot
.59854 .38573 Mdot
.46081 .43866 Mdot
.39191 .56614 Mdot
.58725 .43755 Mdot
.25093 .48723 Mdot
.43231 .46712 Mdot
.5894 .47817 Mdot
.35241 .49855 Mdot
.48071 .16255 Mdot
.54729 .62171 Mdot
.57529 .54682 Mdot
.37485 .72164 Mdot
.70927 .67262 Mdot
.2481 .52988 Mdot
.23323 .51927 Mdot
.35174 .22392 Mdot
.45314 .1377 Mdot
.49144 .26796 Mdot
.39496 .54266 Mdot
.71914 .59552 Mdot
.57085 .69963 Mdot
.45863 .73534 Mdot
.54432 .39103 Mdot
.6794 .28931 Mdot
.50671 .64335 Mdot
.38939 .5315 Mdot
.64043 .42076 Mdot
.23129 .72395 Mdot
.48425 .62859 Mdot
.51236 .73933 Mdot
.20878 .36807 Mdot
.34595 .37206 Mdot
.5458 .63551 Mdot
.39451 .58985 Mdot
.74105 .63598 Mdot
.43478 .47109 Mdot
.3355 .60433 Mdot
.3149 .38442 Mdot
.16982 .56745 Mdot
.55687 .613 Mdot
.49605 .734 Mdot
.43253 .61632 Mdot
.36841 .47097 Mdot
.67527 .52139 Mdot
.39983 .79639 Mdot
.47576 .52851 Mdot
.21741 .33511 Mdot
.29627 .40484 Mdot
.28262 .42512 Mdot
.50734 .6989 Mdot
.229 .68206 Mdot
.7804 .4964 Mdot
.4959 .71897 Mdot
.78018 .58145 Mdot
.56452 .31607 Mdot
.25507 .5416 Mdot
.44968 .36593 Mdot
.37543 .55904 Mdot
.68031 .65128 Mdot
.1292 .53439 Mdot
.42 .79468 Mdot
.63083 .38061 Mdot
.49266 .38884 Mdot
.61418 .67499 Mdot
.4613 .44282 Mdot
.7338 .2299 Mdot
.60187 .21271 Mdot
.17313 .63188 Mdot
.23969 .44134 Mdot
.71931 .59222 Mdot
.72232 .45559 Mdot
.52194 .65164 Mdot
.48987 .34443 Mdot
.16596 .56786 Mdot
.42687 .523 Mdot
.76253 .42634 Mdot
.46698 .65178 Mdot
.75869 .58673 Mdot
.37159 .53987 Mdot
.43788 .37857 Mdot
.5073 .34015 Mdot
.80275 .5473 Mdot
.20081 .39997 Mdot
.43636 .47245 Mdot
.66223 .20037 Mdot
.24361 .67132 Mdot
.1619 .4537 Mdot
.44111 .36716 Mdot
.78353 .65228 Mdot
.60328 .64745 Mdot
.37124 .5435 Mdot
.65351 .43187 Mdot
.33182 .70285 Mdot
.73467 .46114 Mdot
.22723 .47177 Mdot
.65527 .49759 Mdot
.61348 .5169 Mdot
.60308 .12061 Mdot
.27036 .51465 Mdot
.6294 .66241 Mdot
.7407 .42663 Mdot
.15286 .4538 Mdot
.35019 .48795 Mdot
.44502 .18199 Mdot
.52195 .25748 Mdot
.37861 .5768 Mdot
.67514 .70647 Mdot
.3126 .71638 Mdot
.62677 .34466 Mdot
.57399 .85259 Mdot
.35742 .25019 Mdot
.28758 .4379 Mdot
.53828 .32449 Mdot
.69195 .61009 Mdot
.64785 .64982 Mdot
.52271 .21166 Mdot
.54742 .15701 Mdot
.34237 .60706 Mdot
.16984 .52485 Mdot
.67124 .7989 Mdot
.25807 .43437 Mdot
.15028 .54103 Mdot
.65938 .3869 Mdot
.67054 .66156 Mdot
.24404 .52017 Mdot
.39935 .39392 Mdot
.48633 .30013 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`0008oooooo0_l00006ooooo`;o00005Oooool2o`0009[ooooo000Looooo`03o`00
0?oooooooooo08Gooooo0_l00007ooooo`;o00001_ooool2o`0000Sooooo0_l0000;ooooo`;o0000
V_ooool001cooooo00?o0000ooooooooool0QOooool2o`0001Wooooo0_l0002Wooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo07gooooo0_l0003:oooo
o`007?ooool00ol0003oooooooooo`1mooooo`;o0000b_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`30ooooo`;o0000Qoooool001cooooo00?o0000
ooooooooool0`?ooool2o`0008Oooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3:ooooo`;o0000
OOooool001cooooo00?o0000ooooooooool0Soooool2o`0003Wooooo0_l0001mooooo`007?ooool0
0ol0003oooooooooo`1`ooooo`;o00007Oooool2o`000;Sooooo000Looooo`03o`000?oooooooooo
073ooooo0_l0001Iooooo`;o0000O?ooool001cooooo00?o0000ooooooooool0boooool2o`0007co
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0002Uooooo`;o0000Xooo
ool001cooooo00?o0000ooooooooool0UOooool2o`0000gooooo0ol000000ooooooo0000o`000002
o`0000;ooooo0_l0002Iooooo`007?ooool00ol0003oooooooooo`2Eooooo`;o00002oooool5o`00
0003ooooool0003o000000;o00000_ooool2o`0009Wooooo000Looooo`03o`000?oooooooooo06Oo
oooo0_l0000_ooooo`?o00000oooool2o`0000;ooooo0_l0000:ooooo`;o00008oooool2o`0007Co
oooo000Looooo`03o`000?oooooooooo06Oooooo0_l0000Mooooo`;o00004?ooool3o`0000?ooooo
0_l0000Aooooo`;o00001_ooool2o`0001Sooooo0_l0001dooooo`007?ooool00ol0003ooooooooo
o`26ooooo`;o00004?ooool4o`0001Gooooo0_l00006ooooo`Co0000S?ooool001cooooo00?o0000
ooooooooool0V_ooool2o`0000gooooo0_l00006ooooo`;o00002?ooool2o`0008cooooo000Loooo
o`03o`000?oooooooooo09gooooo0_l0000:ooooo`Co00000oooool5o`0000Oooooo0_l0002;oooo
o`007?ooool00ol0003oooooooooo`2Mooooo`;o00003?ooool2o`0000?ooooo0_l000000ooooooo
0000o`000002ooooo`;o000000?oooooo`000?l000000_l0002;ooooo`007?ooool00ol0003ooooo
ooooo`2Pooooo`;o00005Oooool2o`000003ooooool0003o000000Gooooo0_l00026ooooo`007?oo
ool00ol0003oooooooooo`2;ooooo`Co00000_ooool2o`0000gooooo0_l0000Oooooo`;o00003_oo
ool2o`0007Kooooo000Looooo`03o`000?oooooooooo08Sooooo0_l000000ooooooo0000o`000002
o`0000;ooooo0_l0000=ooooo`;o0000;oooool2o`0007Kooooo000Looooo`03o`000?oooooooooo
05cooooo0_l0000Zooooo`;o00000_ooool2o`0000cooooo0_l00004ooooo`;o00004?ooool2o`00
00Kooooo0_l0002=ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5
o`0000Kooooo00?o0000ooooooooool0G?ooool2o`0002kooooo0_l00005ooooo`;o00001Oooool2
o`00017ooooo0_l00003ooooo`;o00001_ooool2o`0000[ooooo0_l00021ooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo
00?o0000ooooooooool0F_ooool2o`0003Oooooo0_l0000Hooooo`;o00005oooool2o`0001Sooooo
0_l0001Wooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ
8B7ok^k^00Oooooo00?o0000ooooooooool0F_ooool2o`0002gooooo0_l0000Rooooo`;o00007Ooo
ool2o`0000Wooooo0_l00007ooooo`;o0000Ioooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool02oooool00onHV9So8B4Qonk^kP06ooooo`?o0000M?ooool2o`0000;ooooo0_l00005
ooooo`;o00000_ooool2o`0000Cooooo0_l0000@ooooo`;o0000;Oooool4o`0000Gooooo0_l00002
ooooo`;o0000L?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00omg
MgOoIVIVooooo`05ooooo`03o`000?oooooooooo07Cooooo0_l00002ooooo`;o00000_ooool2o`00
0003ooooool0003o000000;ooooo0_l00004ooooo`;o00004?ooool2o`0000Kooooo0_l0000Uoooo
o`;o00001oooool2o`0007Cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Eooooo`;o00009Oooool2o`0000Ko
oooo1?l00007ooooo`?o00004Oooool2o`0000Sooooo0_l00009ooooo`;o0000Soooool00006oooo
oomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000
ooooooooool0EOooool2o`0002?ooooo0_l00004ooooo`;o000000?oooooo`000?l000000ol00002
ooooo`;o00000oooool3o`0001Cooooo0_l00005ooooo`;o00002Oooool2o`0000Sooooo0_l00025
ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
1_ooool00ol0003oooooooooo`1Zooooo`;o00000oooool2o`0000Gooooo0_l00002ooooo`;o0000
1?ooool2o`000004ooooool0003o0000ooooo`;o000000Coooooo`000?l0003o00001_ooool2o`00
01;ooooo0_l0000:ooooo`;o00003?ooool4o`0000;ooooo0_l0000:ooooo`;o00004_ooool2o`00
067ooooo000Looooo`03o`000?oooooooooo06[ooooo0_l00003ooooo`;o00000oooool4o`00017o
oooo0_l00003ooooo`Ko00007_ooool2o`0000cooooo1?l00002ooooo`;o00002_ooool2o`0001;o
oooo0_l0001Qooooo`007?ooool00ol0003oooooooooo`1dooooo`;o00006?ooool4o`00033ooooo
0_l00006ooooo`;o0000OOooool001cooooo00?o0000ooooooooool0JOooool2o`0000Cooooo0ol0
001:ooooo`;o00003?ooool3o`0007cooooo000Looooo`03o`000?oooooooooo04oooooo0_l0000H
ooooo`Co00000_ooool3o`0002gooooo0_l000000ooooooo0000o`00000Gooooo`Co00003?ooool2
o`0007cooooo000Looooo`03o`000?oooooooooo04oooooo0_l0000Jooooo`;o0000:Oooool2o`00
00?ooooo0_l00002ooooo`;o000000?oooooo`000?l000000oooool3o`0000Kooooo0_l00009oooo
o`Co00006?ooool2o`0001;ooooo0_l0001Looooo`007?ooool00ol0003oooooooooo`1Wooooo`?o
00000oooool2o`0002Oooooo0_l00003ooooo`;o00001?ooool2o`0000?ooooo1?l00006ooooo`;o
00009Oooool2o`0001;ooooo0_l0001Looooo`007?ooool00ol0003oooooooooo`1Wooooo`Co0000
0_ooool2o`0001?ooooo0_l00005ooooo`;o00001?ooool2o`00013ooooo1?l000000ooooooo0000
o`000008ooooo`;o0000Uoooool001cooooo00?o0000ooooooooool0H?ooool2o`0000;ooooo0_l0
0003ooooo`;o00000_ooool3o`0000Wooooo0_l00007ooooo`?o00001?ooool2o`0000Cooooo0_l0
000@ooooo`Oo00009oooool2o`0007Sooooo000Looooo`03o`000?oooooooooo04Sooooo0_l0000F
ooooo`;o00000_ooool3o`0000Kooooo0ol00009ooooo`;o00002?ooool2o`0000Kooooo0_l0000D
ooooo`?o000000Coooooo`000?l0003o00009oooool2o`000003ooooool0003o000007Gooooo000L
ooooo`03o`000?oooooooooo04Oooooo0ol0000Fooooo`;o00000oooool2o`0000Gooooo0_l00002
ooooo`;o00006Oooool2o`0000Oooooo1?l00005ooooo`;o00001oooool2o`0001;ooooo0_l0000F
ooooo`;o0000MOooool001cooooo00?o0000ooooooooool0Aoooool2o`0001Oooooo0_l00003oooo
o`;o00001Oooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`Co00004oooool2o`00
00Cooooo1?l00005ooooo`;o00000_ooool2o`0000?ooooo0_l00008ooooo`;o00000oooool3o`00
00;ooooo0_l0000Gooooo`;o0000M?ooool001cooooo0_l0001aooooo`;o000000?oooooo`000?l0
00001_l0000Cooooo`;o00004Oooool2o`0000?ooooo0_l00008ooooo`;o00000oooool3o`0000Ko
oooo0_l0000?ooooo`?o000000?oooooo`000?l00000M?ooool001cooooo00?o0000ooooooooool0
L?ooool2o`0000;ooooo1?l0000Jooooo`;o00003Oooool2o`0000gooooo0_l0000<ooooo`;o0000
3oooool3o`00017ooooo0_l0001Tooooo`007?ooool00ol0003oooooooooo`1Looooo`;o00000_oo
ool3o`0002oooooo0_l0000Booooo`;o00002?ooool4o`0000[ooooo1?l0000@ooooo`;o00002Ooo
ool2o`0000Cooooo1?l0001Rooooo`007?ooool00ol0003oooooooooo`1Looooo`;o00000_ooool3
o`0000[ooooo0_l0000Pooooo`;o00000_ooool2o`0000Sooooo0_l00007ooooo`;o00002_ooool2
o`0000cooooo0_l0000@ooooo`;o00000_ooool2o`0000Gooooo0_l00004ooooo`Co00003_ooool2
o`0005;ooooo000Looooo`03o`000?oooooooooo05Wooooo0_l0000Booooo`Co00007_ooool2o`00
00;ooooo0_l00008ooooo`;o0000=oooool2o`0000gooooo0_l0000>ooooo`;o0000D_ooool001co
oooo00?o0000ooooooooool0D?ooool2o`0000Oooooo0_l0000Dooooo`;o00003_ooool2o`0005;o
oooo0_l00002ooooo`;o0000L?ooool001cooooo00?o0000ooooooooool0D?ooool2o`0000Kooooo
0_l000001?oooooo0000o`000?l0000Qooooo`;o00001oooool2o`0000kooooo0_l00002ooooo`;o
00005Oooool2o`0001kooooo1_l0000>ooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0
F?ooool7o`0001Wooooo0_l00003ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`000003
ooooool0003o000000kooooo0_l00002ooooo`;o00005Oooool2o`0001kooooo2?l0000<ooooo`;o
0000H?ooool001cooooo00?o0000ooooooooool0COooool2o`0000Wooooo1?l000000ooooooo0000
o`00000Iooooo`;o00000_ooool3o`000004ooooool0003o0000o`0000;ooooo0_l00005ooooo`;o
00003_ooool2o`0003Cooooo2_l0001]ooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o0000
00?oooooo`000?l000001?ooool4o`0001_ooooo0_l000000ooooooo0000o`000002ooooo`;o0000
0oooool4o`0000Oooooo0_l000000ooooooo0000o`000006ooooo`;o0000>?ooool=o`0006_ooooo
000Looooo`03o`000?oooooooooo04[ooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo0_l0
000Fooooo`;o00002_ooool4o`0000?ooooo0_l00002ooooo`Oo00001?ooool5o`0000Wooooo0ol0
00000ooooooo0000o`00000Uooooo`ko000000?oooooo`000?l00000J?ooool001cooooo00?o0000
ooooooooool0B_ooool4o`0000Sooooo0_l00005ooooo`Co00004oooool2o`0001;ooooo0_l00002
ooooo`Wo00001?ooool3o`0000Wooooo0ol000000ooooooo0000o`00000Eooooo`;o00003?ooool9
o`000003ooooool0003o000000?o00000_ooool2o`0000Cooooo0_l0001Rooooo`007?ooool00ol0
003oooooooooo`1:ooooo`Co00001?ooool2o`0000;ooooo1?l00003ooooo`Co00001?ooool2o`00
00gooooo0_l0000@ooooo`Go000000?oooooo`000?l000000_l000000ooooooo0000o`000004o`00
00;ooooo0_l00002ooooo`;o000000?oooooo`000?l000003oooool2o`0000gooooo0_l0000<oooo
oa3o00001oooool2o`0001Oooooo0_l00019ooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o
00000oooool6o`0000;ooooo0_l000000ooooooo0000o`000002o`0000Kooooo0_l0000;ooooo`;o
00003oooool2o`000003ooooool0003o000000?o00000_ooool:o`000004ooooool0003o0000o`00
00;ooooo1Ol0000?ooooo`;o00006oooool8o`000003ooooool0003o000000Go00008?ooool2o`00
04Wooooo000Looooo`03o`000?oooooooooo04kooooo2?l00005ooooo`;o00000oooool2o`0000_o
oooo0_l00003ooooo`;o000000?oooooo`000?l000003?ooool2o`0000Kooooo0ol000000ooooooo
0000o`000005o`000003ooooool0003o000000Oo00002?ooool3o`0001Oooooo0_l0000:ooooo`oo
00008Oooool2o`0004Wooooo000Looooo`03o`000?oooooooooo04gooooo0ol00002ooooo`?o0000
00?oooooo`000?l000001?l00004ooooo`?o00002_ooool2o`0000Kooooo0_l00008ooooo`;o0000
2Oooool8o`000003ooooool0003o000000Wo00002?ooool5o`0000Oooooo0_l0000>ooooo`;o0000
2_ooool>o`0006gooooo000Looooo`;o0000C_ooool4o`0000?ooooo2ol00002ooooo`;o00004Ooo
ool2o`0000Cooooo0_l00003ooooo`Co00000oooool2o`000003ooooool0003o000001Ko00001Ooo
ool2o`0000;ooooo0_l00006ooooo`;o00003?ooool2o`0000[ooooo3_l0001_ooooo`007?ooool0
0ol0003oooooooooo`1<ooooo`;o000000?oooooo`000?l000000_ooool3o`0000Kooooo0ol0000E
ooooo`;o00001?ooool3o`0000;ooooo1?l00003ooooo`oo000000?oooooo`000?l000002_l00000
1?oooooo0000o`000?l00004ooooo`;o00003oooool2o`0000?ooooo0_l0000:ooooo`;o000000?o
ooooo`000?l000002Ol00002ooooo`;o00002_ooool2o`0005oooooo000Looooo`03o`000?oooooo
oooo04?ooooo0_l00007ooooo`;o000000?oooooo`000?l000000_ooool2o`0002Kooooo1?l00003
ooooo`;o00001?ooool=o`000003ooooool0003o000000Co00000oooool3o`000004ooooool0003o
0000o`0000;ooooo0_l00002ooooo`;o00003?ooool3o`0001;ooooo2ol00002ooooo`;o00002_oo
ool2o`0005oooooo000Looooo`03o`000?oooooooooo04?ooooo0_l0000:ooooo`;o00000_ooool3
o`0002Kooooo0ol00003ooooo`;o00000_oooolKo`0000Gooooo2?l00007ooooo`;o00000_ooool3
o`0001?ooooo2ol0000=ooooo`;o000000?oooooo`000?l00000GOooool001cooooo00?o0000oooo
ooooool0<Oooool2o`00023ooooo0ol0000Dooooo`;o00000oooool2o`0001Gooooo7ol000000ooo
oooo0000o`000002ooooo`;o00002Oooool2o`0000;ooooo0_l0000Eooooo`;o000000?oooooo`00
0?l000000ol0000?ooooo`;o000000?oooooo`000?l000001?l0001Iooooo`007?ooool00ol0003o
ooooooooo`0aooooo`;o0000:Oooool2o`0000cooooo0_l00003ooooo`;o00003?ooool2o`000003
ooooool0003o000000Cooooo0_l00002oooooaGo000000?oooooo`000?l000000ol00004ooooo`;o
00002Oooool2o`0000Kooooo0_l0000Dooooo`?o000000?oooooo`000?l000002oooool2o`0000Oo
oooo1?l0001Iooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00001Oooool2o`0000[ooooo
0_l0000:ooooo`;o00007oooool2o`000003ooooool0003o000000Gooooo7?l00002ooooo`;o0000
0_ooool2o`0000?ooooo0_l00004ooooo`;o00001_ooool2o`00017ooooo0_l000000ooooooo0000
o`00000?ooooo`;o00000oooool2o`0000Gooooo0_l0001Hooooo`007?ooool00ol0003ooooooooo
o`0mooooo`;o00001Oooool2o`0000[ooooo0_l00009ooooo`;o00006Oooool5o`0000Cooooo0_l0
0005oooooago00000_ooool2o`0000Oooooo0_l0000?ooooo`;o00003_ooool2o`0000Cooooo0_l0
000=ooooo`;o00000_ooool2o`0000Gooooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`19
ooooo`;o00001?ooool2o`0000Wooooo0ol000000ooooooo0000o`00000:ooooo`;o00002_ooool5
o`0000Cooooo0_l00005ooooo`;o00000_ooool>o`000003ooooool0003o000000So00002?ooool2
o`0001;ooooo0_l0000<ooooo`;o00001_ooool2o`0000gooooo0_l00002ooooo`;o00003?ooool2
o`00057ooooo000Looooo`03o`000?oooooooooo047ooooo0_l00003ooooo`Go000000Coooooo`00
0?l0003ooooo0_l00006ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000Kooooo0_l0
0002ooooo`;o00003?ooool4o`0000Gooooo0_l00007oooooaSo000000?oooooo`000?l000000ooo
ool2o`000003ooooool0003o0000023ooooo0_l0000Booooo`;o00000_ooool2o`000003ooooool0
003o000000Cooooo1?l00004ooooo`Co0000Coooool001cooooo00?o0000ooooooooool0@Oooool2
o`0000?ooooo1?l00002ooooo`;o00000_ooool2o`0000Gooooo0_l000001?oooooo0000o`000?l0
0009ooooo`;o00004?ooool4o`0000Gooooo0_l00007oooooa_o00000oooool2o`0002Cooooo0_l0
0002ooooo`;o00002?ooool3o`0000;ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o0000
0oooool4o`0000Kooooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`13ooooo`Co00002Ooo
ool2o`0001Sooooo0_l00008ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Cooooo1Ol0
0004oooooa[o0000:_ooool2o`0000;ooooo0_l00008ooooo`?o00000oooool2o`0000Gooooo0_l0
001Nooooo`007?ooool00ol0003oooooooooo`13ooooo`Co00003oooool2o`0000cooooo0_l00004
ooooo`;o00002?ooool2o`000003ooooool0003o000000;ooooo0_l00006ooooo`?o00001?ooool=
o`000003ooooool0003o000000[o00000_ooool3o`0001Kooooo0_l00003ooooo`;o00002_ooool2
o`00013ooooo0_l000000ooooooo0000o`000002ooooo`;o00002oooool2o`00057ooooo000Loooo
o`03o`000?oooooooooo04Cooooo0_l0000<ooooo`;o00000_ooool2o`0000_ooooo0ol0000Eoooo
o`;o00000oooool2o`0000;ooooo0ol00003ooooo`co00000oooool:o`0000?ooooo0ol0000Doooo
o`Co00000oooool2o`0000[ooooo0_l0000Cooooo`;o00003oooool2o`00057ooooo000Looooo`03
o`000?oooooooooo04Cooooo0_l00008ooooo`;o00000_ooool2o`0000;ooooo0_l0000;ooooo`;o
00006oooool3o`0000;ooooo0_l00003ooooo`Wo000000?oooooo`000?l000003Ol0000Cooooo`;o
00001Oooool2o`0000Wooooo0_l0000booooo`;o00001oooool2o`0004;ooooo000Looooo`03o`00
0?oooooooooo03oooooo0_l0000=ooooo`Co00001?ooool2o`0002Wooooo0_l00006oooooaWo0000
1_ooool2o`0000Oooooo0_l00003ooooo`;o00004?ooool2o`0000Oooooo0_l00008ooooo`;o0000
2_ooool2o`0001?ooooo0_l00007ooooo`;o0000@_ooool001cooooo0_l00010ooooo`;o00001?oo
ool2o`0000Wooooo0_l00002ooooo`Go000000?oooooo`000?l00000;OoooolJo`000003ooooool0
003o000000;ooooo0_l00007ooooo`;o00003?ooool2o`0000Cooooo0_l00009ooooo`?o00002?oo
ool2o`0000[ooooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`0jooooo`;o00002?ooool3
o`0000gooooo0_l000000ooooooo0000o`000003o`0000;ooooo0_l0000Qooooo`;o00002?oooolH
o`000003ooooool0003o000000;ooooo0_l0000Eooooo`;o00001?ooool2o`0000Wooooo0_l00000
1?oooooo0000o`000?l0000aooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0>_ooool2
o`0000Sooooo0ol00002ooooo`;o00001_ooool2o`0000Cooooo0ol00004ooooo`;o00008Oooool2
o`0000Wooooo4_l000000ooooooo0000o`000007ooooo`;o00005?ooool2o`0001?ooooo0ol0000E
ooooo`;o00006_ooool2o`00043ooooo000Looooo`03o`000?oooooooooo03cooooo0_l0000;oooo
o`;o00000_ooool2o`0000;ooooo0_l00006ooooo`;o00004oooool2o`00013ooooo0ol0000:oooo
oaGo00004Oooool2o`0000Wooooo0_l0000Tooooo`;o00001Oooool2o`0005cooooo000Looooo`03
o`000?oooooooooo03cooooo0_l00006ooooo`;o00001_ooool3o`0000[ooooo0ol0000Booooo`;o
00002Oooool2o`0000?ooooo1_l0000:oooooaCo00003oooool4o`0000Sooooo0_l0000Dooooo`;o
00001oooool2o`0000Kooooo0_l0000Hooooo`?o00003oooool2o`0003Oooooo000Looooo`03o`00
0?oooooooooo03gooooo0_l00005ooooo`;o00001_ooool3o`0000Kooooo0_l00003ooooo`;o0000
00?oooooo`000?l000003_ooool2o`0000[ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo
0_l000001Ooooooo0000o`000?l0003ooooo013o000000?oooooo`000?l000004?ooool2o`000004
ooooool0003o0000o`0000Kooooo0_l0000Aooooo`;o000000?oooooo`000?l000001oooool2o`00
00[ooooo0_l00008ooooo`;o00002_ooool5o`0000gooooo0_l0000gooooo`007?ooool00ol0003o
ooooooooo`0gooooo`;o00001?ooool2o`000003ooooool0003o000000_ooooo1?l000001?oooooo
0000o`000?ooool2o`0000Kooooo0_l0000>ooooo`;o00001Oooool2o`00017ooooo0_l000000ooo
oooo0000o`00000Ao`0000;ooooo0_l00007ooooo`;o000000?oooooo`000?l000001oooool3o`00
01Wooooo0_l0000@ooooo`;o00000oooool3o`0000Sooooo0_l0000=ooooo`;o0000A_ooool001co
oooo00?o0000ooooooooool0=oooool2o`0000Oooooo0ol0000<ooooo`;o000000?oooooo`000?l0
00000_ooool2o`0001?ooooo1?l00005ooooo`;o00002_ooool3o`0000?ooooo0_l00003ooooo`Co
000000?oooooo`000?l000002_l00003ooooo`Co00001Oooool2o`000003ooooool0003o000000ko
oooo0_l0000Fooooo`;o00001?ooool3o`0000Kooooo0ol00002ooooo`;o00004oooool3o`0004[o
oooo000Looooo`03o`000?oooooooooo047ooooo0_l000000ooooooo0000o`000003o`0000gooooo
0_l0000?ooooo`;o00000_ooool4o`0000?ooooo0_l0000<ooooo`?o00000oooool2o`0000Gooooo
0_l00004ooooo`Co000000?oooooo`000?l000000_l00005ooooo`;o00004_ooool2o`0000Cooooo
0_l00008ooooo`;o00003?ooool2o`0000Cooooo0ol00007ooooo`;o00003?ooool2o`000003oooo
ool0003o000000Kooooo0ol0001:ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00000_oo
ool5o`0001Oooooo0_l00005ooooo`;o00001Oooool2o`0000;ooooo0_l0000;ooooo`Co00001?oo
ool2o`000003ooooool0003o000000Oooooo1?l00003ooooo`;o00001_ooool2o`0000Oooooo0_l0
0008ooooo`;o00003?ooool4o`0002[ooooo1_l0000;ooooo`;o0000AOooool001cooooo00?o0000
ooooooooool0?_ooool4o`0001kooooo0_l00004ooooo`;o000000?oooooo`000?l000000oooool2
o`0000kooooo1?l00005ooooo`;o000000?oooooo`000?l000001Oooool7o`000003ooooool0003o
000000Cooooo0_l000000ooooooo0000o`000002o`0000Gooooo0_l0000=ooooo`;o00001oooool3
o`0000?ooooo0_l0000Fooooo`Co00000oooool2o`0000Sooooo0_l000000ooooooo0000o`00000:
ooooo`?o00002?ooool2o`0003_ooooo000Looooo`03o`000?oooooooooo03kooooo0_l00006oooo
o`;o000000?oooooo`000?l000000_l00007ooooo`;o00002Oooool6o`000004ooooool0003o0000
ooooo`;o00003Oooool2o`0000;ooooo1?l000000ooooooo0000o`00000>ooooo`;o00000oooool2
o`000003ooooool0003o000000Cooooo0_l00003ooooo`;o00004Oooool2o`000003ooooool0003o
000000?ooooo0_l000000ooooooo0000o`000005ooooo`Co00001_ooool2o`0000Wooooo0_l00000
0ooooooo0000o`000003o`000004ooooool0003o0000o`0001Oooooo0_l00009ooooo`;o0000>ooo
ool001cooooo00?o0000ooooooooool0>oooool2o`0000Wooooo0_l000000ooooooo0000o`000002
o`0000Gooooo1?l00009ooooo`Ko00000_ooool2o`0000oooooo0_l00002ooooo`;o00000oooool4
o`0000;ooooo0_l00009ooooo`;o00000_ooool2o`0000gooooo0_l00009ooooo`;o00001Oooool2
o`0000Cooooo1ol000001?oooooo0000o`000?l00003ooooo`;o00001Oooool3o`0000Wooooo1?l0
00000ooooooo0000o`000005o`0000[ooooo0_l0000;ooooo`;o00000oooool2o`00047ooooo000L
ooooo`03o`000?oooooooooo03Gooooo0_l00004ooooo`;o000000?oooooo`000?l000004_ooool2
o`0000Wooooo0_l00002ooooo`;o00001?ooool2o`0001;ooooo0_l00006ooooo`;o00000_ooool2
o`0000Wooooo1_l00004ooooo`?o00001_ooool2o`0000Kooooo0_l000000ooooooo0000o`00000:
ooooo`ko00002?ooool4o`0000[ooooo0_l000001?oooooo0000o`000?ooool4o`0000Wooooo0ol0
0005ooooo`;o00001?ooool3o`0000;ooooo0_l00011ooooo`0000Koooooonk^k_lb<S;o0000oc8b
<_o^k^h5ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0
=Oooool2o`0000Oooooo0_l0000Fooooo`;o00001Oooool2o`0000;ooooo0_l00007ooooo`;o0000
1?ooool2o`0000Wooooo0_l000001?oooooo0000o`000?ooool4o`0000oooooo0_l000000ooooooo
0000o`000003ooooo`Ko00000oooool2o`0000Kooooo0_l00006ooooo`;o00001?ooool@o`000003
ooooool0003o000000;o00001?ooool2o`0000[ooooo0_l0000Aooooo`;o00001_ooool2o`0000Go
oooo0_l0000:ooooo`;o0000>Oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q
8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0fooooo`;o00007_ooool4o`00
013ooooo1?l00002ooooo`;o00000oooool2o`0000Oooooo1ol00007ooooo`Co00001oooool4o`00
00?ooooo1?l0000Cooooo`;o000000?oooooo`000?l000004Ol000000ooooooo0000o`000002o`00
013ooooo0_l00004ooooo`;o00002oooool4o`000003ooooool0003o000000_ooooo0_l00007oooo
o`;o0000>Oooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool5o`0000Ko
oooo00?o0000ooooooooool0=_ooool3o`0000Gooooo0_l0000Hooooo`;o00004_ooool2o`0000Oo
oooo0_l00009ooooo`Co00002?ooool4o`0000Gooooo0_l00002ooooo`;o00006_oooolCo`000003
ooooool0003o000000;o00002oooool2o`0000cooooo0_l0000;ooooo`Co000000?oooooo`000?l0
00002oooool2o`0004;ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo
00CoA4A4omgMgOoooooo00001oooool3o`0003Oooooo0_l000000ooooooo0000o`000002ooooo`?o
00004Oooool2o`000003ooooool0003o000001Kooooo1?l0000Eooooo`?o00003?ooool2o`0001ko
oooo6?l00002ooooo`;o00001Oooool4o`0000_ooooo0_l0001Rooooo`0000?oooooo`000?ooool0
0_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000oooooooo
ool0<?ooool2o`0000Sooooo0_l00003ooooo`;o000000?oooooo`000?l000001?ooool2o`0000So
oooo0_l000000ooooooo0000o`000006ooooo`;o00000oooool2o`0000?ooooo0ol00003ooooo`Co
00003Oooool2o`000004ooooool0003o0000ooooo`Go00002_ooool2o`0000oooooo0_l0000=oooo
o`;o000000?oooooo`000?l000006Ol000000ooooooo0000o`000002ooooo`;o00002?ooool2o`00
00?ooooo0_l0000Booooo`Co00002Oooool2o`0000gooooo0_l0000booooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooooooo
ool0<?ooool2o`0000Kooooo0_l00008ooooo`Co00000_ooool2o`0001?ooooo0_l00003ooooo`?o
00000_ooool5o`0000;ooooo1_l00005ooooo`;o00000oooool2o`000004ooooool0003o0000oooo
o`;o00001?ooool2o`0000Cooooo0_l000000ooooooo0000o`00000<ooooo`;o000000?oooooo`00
0?l000002_ooool2o`000003ooooool0003o000000;ooooo6?l00003ooooo`?o00002oooool2o`00
00kooooo0_l00007ooooo`Ko00001oooool2o`0000gooooo0_l0000booooo`0000KoooooogMgMonH
V9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0<Oooool2
o`0000;ooooo1Ol00003ooooo`;o00001Oooool2o`0001Oooooo0_l00004ooooo`;o00000_ooool2
o`000003ooooool0003o000000So00001Oooool2o`0000oooooo0_l00004ooooo`;o00003oooool2
o`000003ooooool0003o000000[ooooo0_l00004oooooaSo00001Oooool2o`0000_ooooo0_l00005
ooooo`;o00001oooool2o`0000Sooooo1Ol0001:ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^
k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0<Oooool2o`0000;ooooo1Ol0
0003ooooo`;o00003oooool2o`0000?ooooo0_l00009ooooo`Co000000?oooooo`000?l000000_oo
ool2o`000003ooooool0003o000000_o00003_ooool2o`0000Wooooo0_l0000=ooooo`;o00001_oo
ool2o`0000Oooooo0_l00004ooooo`Oo000000?oooooo`000?l000003Ol0000@ooooo`;o00002?oo
ool2o`0000Sooooo0_l00007ooooo`Co00001_ooool2o`0000;ooooo0_l0000oooooo`007?ooool0
0ol0003oooooooooo`0hooooo`Co00004?ooool4o`000003ooooool0003o000000?o00002?ooool4
o`000003ooooool0003o000000?ooooo4?l00002ooooo`;o00001_ooool2o`000003ooooool0003o
000000;o00000oooool2o`0000?ooooo0_l00006ooooo`Co00000_ooool2o`0000Kooooo0_l00000
0ooooooo0000o`00000:ooooo`_o000000?oooooo`000?l000002ol0000>ooooo`;o00004_ooool2
o`000003ooooool0003o000000Cooooo0_l00008ooooo`;o00000_ooool2o`0003oooooo000Loooo
o`03o`000?oooooooooo03Wooooo0ol0000;ooooo`;o00000oooool4o`000004ooooool0003o0000
ooooo`;o00004?oooolCo`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000002
o`000003ooooool0003o000000;ooooo0ol00003ooooo`;o00001_ooool4o`0000gooooo0_l0000:
oooooaWo00003oooool2o`0000;ooooo0_l00009ooooo`;o00001Oooool2o`000003ooooool0003o
000000Gooooo0_l0000:ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0=?ooool2o`00
00kooooo0_l000000ooooooo0000o`00000=ooooo`;o00001?ooool2o`0000Sooooo5_l00003oooo
o`;o00000oooool2o`0000Gooooo0_l00004ooooo`;o00002?ooool2o`0001Wooooo6?l0000@oooo
o`;o000000Coooooo`000?l0003o00002Oooool2o`0000Gooooo0_l000000ooooooo0000o`000005
ooooo`;o00002_ooool2o`0003gooooo000Looooo`03o`000?oooooooooo02cooooo0_l00002oooo
o`;o00000_ooool2o`0000kooooo0_l00005ooooo`;o00001?ooool2o`0000?ooooo1?l000001?oo
oooo0000o`000?l00006oooooa[o00001Oooool3o`0000Cooooo1_l000000ooooooo0000o`000005
ooooo`;o00006_oooolJo`0001?ooooo0_l0000:ooooo`;o00001Oooool2o`0005?ooooo000Loooo
o`03o`000?oooooooooo02cooooo0_l00002ooooo`;o00001_ooool2o`000003ooooool0003o0000
00Cooooo0_l00008ooooo`;o00001?ooool2o`0000Cooooo0ol000000ooooooo0000o`000005oooo
oaWo000000?oooooo`000?l000001Oooool3o`0000?ooooo2ol00002ooooo`Go00006OoooolKo`00
00Gooooo0_l0000Gooooo`;o00001Oooool2o`0000Kooooo0_l0000Eooooo`;o0000=?ooool001co
oooo00?o0000ooooooooool0>?ooool2o`000003ooooool0003o000000Cooooo0_l0000Mooooo`Co
000000?oooooo`000?l000003ol000000ooooooo0000o`000002o`0000Gooooo1?l000001Ooooooo
0000o`000?l0003ooooo00;o00001?ooool>o`0001Sooooo6_l000000ooooooo0000o`000002oooo
o`;o00001oooool2o`0000oooooo0_l0000<ooooo`;o00005Oooool2o`000003ooooool0003o0000
037ooooo000Looooo`03o`000?oooooooooo03_ooooo0_l0000Cooooo`;o00003?ooool5o`0000;o
oooo5_l00005ooooo`Co000000?oooooo`000?l000001Ol00003ooooo`;o00000oooool2o`000004
ooooool0003o0000ooooo`?o00000oooool2o`0001?ooooo6_l000000ooooooo0000o`000003o`00
00Sooooo0_l0000?ooooo`;o00000_ooool4o`0000Kooooo0_l00002ooooo`;o00000_ooool4o`00
00kooooo0_l0000aooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00000_ooool2o`0000;o
oooo0ol0000<ooooo`Go00000_ooool3o`0000;ooooo0_l00002ooooo`Go00000_oooolFo`0000?o
oooo0_l00002ooooo`;o00000oooool5o`000003ooooool0003o000000?ooooo0_l00003ooooo`;o
00001Oooool4o`0001Cooooo5ol00004ooooo`Co00000_ooool3o`0000?ooooo0_l00002ooooo`;o
00001?ooool2o`0000Gooooo0_l00002ooooo`Co000000?oooooo`000?l000001oooool2o`0000;o
oooo1?l00011ooooo`007?ooool00ol0003oooooooooo`0Yooooo`Co00002_ooool2o`0000Kooooo
0ol00004ooooo`?o000000?oooooo`000?l000000_ooool5o`0000;ooooo0ol00002ooooo`;o0000
2_ooool2o`000003ooooool0003o000000oo00000oooool3o`000004ooooool0003o0000o`0000?o
oooo0ol00003ooooo`;o000000?oooooo`000?l000000_l00004ooooo`?o00000oooool4o`0000Co
oooo0_l00008ooooo`;o00001_oooolCo`0000?ooooo0_l00007ooooo`?o00001oooool2o`0000Co
oooo0_l00005ooooo`;o00000_ooool3o`000004ooooool0003o0000o`0000oooooo0_l00009oooo
o`;o0000=?ooool001cooooo00?o0000ooooooooool0:Oooool5o`0000Kooooo0_l00009ooooo`Co
00000oooool3o`000003ooooool0003o000000gooooo0ol00008oooooaKo00000oooool2o`0000;o
oooo0_l00005ooooo`;o00001_ooool4o`0000Cooooo0ol00004ooooo`Wo00002?ooool2o`0000Oo
oooo4Ol00004ooooo`Go00003Oooool2o`0000;ooooo0_l000000ooooooo0000o`000009ooooo`Ko
00001_ooool2o`0000Sooooo0_l00009ooooo`;o0000=?ooool001cooooo00?o0000ooooooooool0
:Oooool5o`0000Kooooo0_l00002ooooo`;o00001Oooool4o`0000Wooooo0_l0000;ooooo`;o0000
2OoooolIo`0000_ooooo0_l00008ooooo`Ko00000_ooool2o`0000Cooooo2?l0000Aoooooa;o0000
00?oooooo`000?l000001Ol0000:ooooo`;o000000?oooooo`000?l000000_ooool2o`000003oooo
ool0003o000000Kooooo0_l00003ooooo`?o00001oooool2o`0000cooooo0_l00008ooooo`?o0000
<?ooool001cooooo0_l0000Zooooo`Co00001_ooool2o`0000?ooooo0_l00007ooooo`;o00001Ooo
ool2o`0000;ooooo0_l0000:ooooo`;o00003?oooolGo`0000_ooooo0_l0000:ooooo`Co00000_oo
ool2o`0000;ooooo1Ol000000ooooooo0000o`000006o`0000;ooooo0_l00009oooooa;o000000?o
ooooo`000?l000000_l00007ooooo`;o00001?ooool2o`0000?ooooo0_l0000;ooooo`;o00000ooo
ool2o`0000Wooooo0_l00006ooooo`;o00000oooool2o`0000Sooooo0ol0000`ooooo`007?ooool0
0ol0003oooooooooo`0^ooooo`;o000000?oooooo`000?l000000_l0000;ooooo`;o00000_ooool2
o`0000;ooooo0_l00002ooooo`;o00002_ooool2o`0000Wooooo0_l00003oooooaCo00002oooool2
o`000003ooooool0003o000000cooooo0_l00003ooooo`?o000000Coooooo`000?l0003ooooo0_l0
0002ooooo`So00002Oooool2o`0000?ooooo2ol00006ooooo`;o00001_ooool2o`0000Sooooo0ol0
0003ooooo`;o00005_ooool2o`0000Kooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0Z
ooooo`;o00000_ooool6o`0000;ooooo0_l00008ooooo`;o00000_ooool2o`0000Kooooo0_l0000@
ooooo`;o00000oooool2o`0000?ooooo2ol000000ooooooo0000o`000008o`0000Wooooo0_l00000
0ooooooo0000o`00000<ooooo`;o00000_ooool4o`0000cooooo0_l00007ooooo`;o00002Oooool;
o`0000Cooooo0_l00006ooooo`;o00002?ooool2o`0000?ooooo0ol00005ooooo`?o00001?ooool2
o`00013ooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0Zooooo`;o00001?ooool3o`00
00?ooooo0_l00003ooooo`Co00007oooool2o`0000Oooooo4ol00002ooooo`;o00006_ooool2o`00
00;ooooo0_l0000Gooooo`Co00001ooooolAo`0001Gooooo0_l00003ooooo`Ko000000Coooooo`00
0?l0003ooooo0_l0000@ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0>oooool4o`00
01?ooooo0ol00005ooooo`;o00002ooooolAo`0000;ooooo0_l00005ooooo`;o00002oooool2o`00
00Cooooo0_l0000:ooooo`Co00003Oooool5o`000003ooooool0003o000000Sooooo2Ol000000ooo
oooo0000o`000002o`0001Kooooo0ol00002ooooo`Oo000000?oooooo`000?l000000ol0000@oooo
o`;o0000@?ooool001cooooo00?o0000ooooooooool0;Oooool2o`0001[ooooo0_l000000ooooooo
0000o`000002o`0000;ooooo0ol00003ooooo`Co00001Oooool2o`0000Cooooo0_l000000ooooooo
0000o`00000<o`0000;ooooo0_l00004ooooo`?o00001_ooool2o`0000;ooooo0ol00004ooooo`;o
00002_ooool4o`0000;ooooo0_l00009ooooo`Go00003?ooool4o`000005ooooool0003o0000o`00
0?ooool00_l0000Hooooo`;o00000oooool4o`000003ooooool0003o000000?ooooo0_l0000Aoooo
o`?o00002oooool2o`0003;ooooo000Looooo`03o`000?oooooooooo02gooooo0_l0000Jooooo`;o
000000?oooooo`000?l000001Ol00005ooooo`?o00001_ooool2o`0000Sooooo3?l00002ooooo`;o
00001Oooool2o`0000Oooooo0_l00002ooooo`;o00001oooool2o`0000?ooooo0_l00004ooooo`;o
00000oooool2o`0000cooooo0_l0000<ooooo`Co00001_ooool2o`0000kooooo0_l000000ooooooo
0000o`000008ooooo`;o000000?oooooo`000?l000003?ooool2o`0000cooooo0_l00002ooooo`;o
00001oooool2o`0003;ooooo000Looooo`03o`000?oooooooooo033ooooo0_l0000Dooooo`;o0000
2?ooool3o`0000_ooooo0_l00004ooooo`;o00001_ooool7o`000004ooooool0003o0000o`0000;o
oooo0_l000000ooooooo0000o`000002o`0000Kooooo0_l000001?oooooo0000o`000?l00006oooo
o`;o00000_ooool2o`0000?ooooo0_l00004ooooo`;o00001_ooool2o`0000Oooooo1?l00003oooo
o`;o00001oooool4o`0000Kooooo0_l0000>ooooo`;o000000?oooooo`000?l000001?ooool2o`00
00;ooooo0_l0000?ooooo`Co00003_ooool2o`0003_ooooo000Looooo`03o`000?oooooooooo033o
oooo0_l0000Dooooo`;o00001_ooool2o`000003ooooool0003o000000_ooooo0_l00004ooooo`;o
00001oooool3o`000003ooooool0003o000000;ooooo0_l00005ooooo`Co00001_ooool2o`0000;o
oooo1?l00004ooooo`;o00002oooool4o`0000Kooooo0_l00007ooooo`;o00001Oooool2o`0000So
oooo0_l0000Mooooo`Go00003?ooool2o`0000Oooooo0_l00009ooooo`;o00000oooool2o`0003_o
oooo000Looooo`03o`000?oooooooooo02[ooooo0ol0000Eooooo`;o00002_ooool2o`000003oooo
ool0003o000001;ooooo0_l00006ooooo`;o000000?oooooo`000?l000000oooool2o`0000_ooooo
0_l00008ooooo`;o00004Oooool2o`0001Gooooo1?l00002ooooo`;o00001Oooool2o`0000;ooooo
1?l0000Cooooo`;o00000_ooool4o`0000gooooo0_l0000Booooo`;o0000@?ooool001cooooo00?o
0000ooooooooool09_ooool2o`0000;ooooo0ol0000Eooooo`;o00000oooool2o`0001cooooo0_l0
0009ooooo`;o00000oooool4o`0000Gooooo0_l00002ooooo`?o00005_ooool2o`0000Sooooo0_l0
000?ooooo`Co00000_ooool2o`0000Kooooo1ol00004ooooo`;o000000Coooooo`000?l0003ooooo
0_l00006ooooo`So00005?ooool2o`0004kooooo000Looooo`03o`000?oooooooooo02Kooooo0_l0
0006ooooo`;o00005?ooool2o`000003ooooool0003o000002Sooooo0_l00004ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0000?ooooo0_l00002ooooo`;o00004Oooool3o`0000Sooooo0_l0
000Mooooo`?o00002?ooool2o`000004ooooool0003o0000ooooo`;o00001_ooool8o`0000Wooooo
0ol00002ooooo`;o00001?ooool2o`0004kooooo000Looooo`03o`000?oooooooooo02kooooo0_l0
000:ooooo`;o00002?ooool2o`0000Kooooo1?l0000=ooooo`;o00001oooool2o`0000;ooooo0_l0
0002ooooo`;o000000?oooooo`000?l000001oooool4o`0000?ooooo0_l00004ooooo`;o00002ooo
ool2o`0000Cooooo0_l00005ooooo`;o00000_ooool2o`0001_ooooo0_l00009ooooo`;o000000?o
ooooo`000?l000004?ooool2o`0000Wooooo1?l00002ooooo`;o00003_ooool4o`0000_ooooo0_l0
000eooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o00002oooool2o`0000Sooooo1?l00004
ooooo`Co00003Oooool2o`0000Gooooo1?l00002ooooo`;o00000_ooool4o`0000[ooooo1?l00000
0ooooooo0000o`000003o`000003ooooool0003o000000Kooooo0_l00003ooooo`;o00002Oooool4
o`0000;ooooo0ol0000;ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00000_ooool2
o`000003ooooool0003o0000013ooooo0_l000000ooooooo0000o`000005ooooo`Co00002?ooool4
o`0000Oooooo1?l00005ooooo`;o00001?ooool2o`0003Gooooo000Looooo`03o`000?oooooooooo
02gooooo0_l000000ooooooo0000o`000008ooooo`;o00002?ooool4o`0000kooooo0_l00002oooo
o`;o000000?oooooo`000?l000001Oooool4o`0000;ooooo0_l00004ooooo`;o00002_ooool4o`00
00?ooooo0ol000000ooooooo0000o`000006ooooo`;o00001?ooool2o`0000Sooooo0_l00005oooo
o`?o000000?oooooo`000?l000000oooool2o`0000;ooooo0_l00006ooooo`;o00003?ooool3o`00
00;ooooo0_l0000=ooooo`?o00001Oooool2o`0000Gooooo1?l00008ooooo`Co00002Oooool2o`00
00Gooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0Vooooo`;o00002?ooool2o`0000So
oooo0_l00003ooooo`;o00001Oooool2o`0000cooooo1?l000001?oooooo0000o`000?l00008oooo
o`Co00000_ooool2o`0000?ooooo0_l0000>ooooo`;o00001_ooool2o`0000Wooooo0_l000000ooo
oooo0000o`00000:ooooo`;o00001?ooool2o`000003ooooool0003o000000?ooooo0_l0000Ioooo
o`;o000000Goooooo`000?l0003o0000ooooo`02o`0000[ooooo0ol0000;ooooo`Co00002oooool2
o`000003ooooool0003o000000Kooooo0_l00005ooooo`;o0000>oooool001cooooo0_l0000Woooo
o`;o00005oooool2o`0000;ooooo0ol0000>ooooo`Oo00002Oooool2o`0000Wooooo0_l0000>oooo
o`;o00001Oooool2o`0000Cooooo0_l00004ooooo`;o00003Oooool4o`0000Wooooo0ol00003oooo
o`;o00005oooool2o`0000;ooooo0_l0000=ooooo`;o00001?ooool2o`0000?ooooo0_l0000=oooo
o`Go00003Oooool2o`0003_ooooo000Looooo`03o`000?oooooooooo02Wooooo0_l000001?oooooo
0000o`000?ooool2o`00013ooooo1Ol00002ooooo`;o00002oooool5o`0000Cooooo0ol00005oooo
o`;o000000Coooooo`000?l0003o00002?ooool3o`0000oooooo0_l00004ooooo`;o00001?ooool2
o`0000_ooooo0_l00002ooooo`?o00001?ooool2o`0000;ooooo0ol00003ooooo`;o00001_ooool2
o`0000kooooo0_l0000Booooo`Co00000_ooool2o`000003ooooool0003o000000?ooooo0_l0000;
ooooo`;o00000oooool2o`0004Oooooo000Looooo`03o`000?oooooooooo02Wooooo0_l000001?oo
oooo0000o`000?ooool2o`0000_ooooo0_l00003ooooo`?o00001?ooool2o`0000kooooo0_l00004
ooooo`?o00001Oooool6o`0000Sooooo0ol0000Fooooo`;o00004?ooool2o`0000?ooooo0_l00000
1?oooooo0000o`000?ooool2o`0000Sooooo0_l00006ooooo`;o00003_ooool2o`0000;ooooo0_l0
0009ooooo`;o00001Oooool2o`0000Gooooo0ol00002ooooo`;o00004?ooool2o`0000Cooooo0_l0
0011ooooo`007?ooool00ol0003oooooooooo`0Tooooo`;o00000oooool2o`0000?ooooo0_l0000<
ooooo`;o00000oooool2o`0000Cooooo0_l0000:ooooo`;o00002?ooool4o`0000Oooooo0_l00000
0ooooooo0000o`00000Cooooo`;o00002oooool2o`0001Sooooo1?l00009ooooo`;o000000?ooooo
o`000?l000005Oooool4o`0000Sooooo0ol000000ooooooo0000o`000009ooooo`?o00001?ooool2
o`0000;ooooo0_l00004ooooo`;o00001?ooool3o`0000?ooooo0_l00011ooooo`007?ooool00ol0
003oooooooooo`0Tooooo`;o00000oooool2o`0000?ooooo0_l00004ooooo`;o00002_ooool3o`00
00Cooooo0_l0000:ooooo`;o00002?ooool5o`0000;ooooo0_l00005ooooo`;o000000?oooooo`00
0?l000000_ooool2o`0000cooooo0ol0000Vooooo`;o00003?ooool2o`0001Gooooo0_l00005oooo
o`;o00000oooool2o`0000;ooooo0_l00009ooooo`;o00001Oooool2o`0000;ooooo0_l00004oooo
o`?o000000?oooooo`000?l000000ol000000ooooooo0000o`000013ooooo`007?ooool00ol0003o
ooooooooo`0`ooooo`?o000000?oooooo`000?l000001Oooool2o`0000?ooooo1?l0000@ooooo`;o
00000_ooool2o`000003ooooool0003o000000;ooooo0ol00002ooooo`;o000000?oooooo`000?l0
00001Oooool2o`0000;ooooo0_l0000:ooooo`Go0000;Oooool2o`0000Cooooo0_l0000;ooooo`;o
00001?ooool2o`0000Wooooo0ol000000ooooooo0000o`00000Looooo`;o00000oooool2o`000003
ooooool0003o000000Cooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`0Tooooo`;o0000
2Oooool4o`0000Kooooo1?l00005ooooo`;o00001?ooool2o`0000;ooooo0_l00006ooooo`;o0000
0_ooool2o`000003ooooool0003o000000Gooooo0_l00003ooooo`Co000000?oooooo`000?l00000
4?ooool3o`0000Kooooo0_l00009ooooo`;o00007?ooool2o`0000Cooooo0_l0000;ooooo`;o0000
1?ooool2o`0000Wooooo0_l000000ooooooo0000o`000003o`0000Oooooo0_l0000Aooooo`;o0000
1oooool2o`0004Sooooo000Looooo`03o`000?oooooooooo02Cooooo0_l00008ooooo`Go00001_oo
ool2o`0000gooooo0ol000000ooooooo0000o`000008ooooo`;o00002_ooool4o`0000?ooooo0_l0
00000ooooooo0000o`000002ooooo`;o00003_ooool2o`0000Gooooo0_l00009ooooo`;o00005?oo
ool2o`0001?ooooo0_l00003ooooo`;o00004?ooool2o`000003ooooool0003o000000?o00000_oo
ool2o`0000?ooooo0_l00004ooooo`;o00005?ooool2o`0000Wooooo0_l00006ooooo`;o0000=Ooo
ool001cooooo00?o0000ooooooooool09?ooool2o`0000Sooooo1ol00002ooooo`Ko00003?ooool2
o`0000Wooooo1?l0000:ooooo`Co00002_ooool2o`0000kooooo0_l00005ooooo`;o00007_ooool4
o`0000Oooooo1?l00005ooooo`Ko000000?oooooo`000?l000002oooool2o`000003ooooool0003o
000000Cooooo0_l00004ooooo`;o00001oooool4o`0000?ooooo0_l000001?oooooo0000o`000?l0
0002ooooo`;o00002oooool5o`0000;ooooo0_l00006ooooo`;o0000=Oooool001cooooo00?o0000
ooooooooool09?ooool2o`0000Sooooo1?l000000ooooooo0000o`000002ooooo`;o00000_ooool2
o`0000oooooo0_l00006ooooo`Co00002_ooool2o`0000cooooo0_l0000Cooooo`Co00000_ooool4
o`0000Sooooo0_l0000>ooooo`Co00000_ooool2o`0000?ooooo1?l00005ooooo`Wo00001?ooool2
o`0000Gooooo0_l000000ooooooo0000o`000002o`00017ooooo0_l00004ooooo`?o000000?ooooo
o`000?l000000_l000000ooooooo0000o`000002ooooo`;o00001oooool5o`0000;ooooo0_l0000m
ooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00004Oooool4o`0000Oooooo0ol0000=oooo
o`;o00005?ooool2o`0000Gooooo1?l00008ooooo`Co00000_ooool4o`0000?ooooo0_l00003oooo
o`;o00005?ooool3o`0000?ooooo0_l00003ooooo`?o000000?oooooo`000?l000000_l000000ooo
oooo0000o`000005ooooo`;o00002Oooool3o`0000gooooo1?l00006ooooo`;o00000oooool4o`00
00Cooooo0_l00002ooooo`;o00003oooool2o`0003Sooooo000Looooo`03o`000?oooooooooo02Ko
oooo0_l0000=ooooo`;o00002_ooool4o`0000Sooooo0_l0000=ooooo`So000000?oooooo`000?l0
00002oooool2o`0000Gooooo1?l0000Eooooo`;o00001?ooool2o`0000oooooo0_l000000ooooooo
0000o`000002o`0000Sooooo0ol0000=ooooo`;o00002Oooool3o`0000;ooooo0_l00009ooooo`Ko
000000?oooooo`000?l000001_ooool5o`0000Cooooo0_l000001?oooooo0000o`000?l0000<oooo
o`Co0000>?ooool001cooooo00?o0000ooooooooool09_ooool2o`0000Cooooo0_l00007ooooo`;o
00005_ooool4o`0000gooooo1_l000000ooooooo0000o`000005ooooo`;o00001?ooool2o`0000Co
oooo1?l0000:ooooo`;o00004?ooool4o`0000gooooo0_l000000ooooooo0000o`000002o`0000oo
oooo0_l00007ooooo`;o00002Oooool3o`0000;ooooo0_l0000:ooooo`;o000000Coooooo`000?l0
003ooooo0_l000001?oooooo0000o`000?ooool3o`000003ooooool0003o000000Co000000?ooooo
o`000?l000001?l0000<ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0;?ooool3o`00
017ooooo0_l0000<ooooo`?o00002oooool2o`0000Cooooo0_l00002ooooo`;o00001?ooool2o`00
00Cooooo1Ol000000ooooooo0000o`00000<ooooo`;o00004_ooool2o`0002?ooooo0_l00002oooo
o`;o00002Oooool4o`0000Kooooo0_l0000Cooooo`So000000?oooooo`000?l000000_l00003oooo
o`Co000000?oooooo`000?l000002Oooool2o`0003[ooooo000Looooo`03o`000?oooooooooo02go
oooo0_l00005ooooo`;o00002_ooool2o`0000gooooo0_l0000:ooooo`?o00000oooool2o`0000?o
oooo0_l0000;ooooo`Co000000?oooooo`000?l000000oooool2o`0000Kooooo0_l0000Wooooo`?o
00004_ooool2o`0000Wooooo1?l0000Mooooo`Ko00000_ooool2o`0000Gooooo0ol000000ooooooo
0000o`000002ooooo`;o000000?oooooo`000?l000000_ooool2o`0003[ooooo000Looooo`03o`00
0?oooooooooo02;ooooo0_l0000@ooooo`;o00005Oooool2o`0000;ooooo0_l00009ooooo`?o0000
1?ooool2o`0000[ooooo1?l00004ooooo`;o00001_ooool2o`000004ooooool0003o0000ooooo`Co
00000_ooool5o`0001;ooooo0_l0000<ooooo`?o000000Coooooo`000?l0003ooooo1_l0000Coooo
o`?o00004oooool2o`0000cooooo0_l00002ooooo`?o00001Oooool2o`000003ooooool0003o0000
00?ooooo0_l000000ooooooo0000o`000006ooooo`;o0000=_ooool001cooooo0_l0000Sooooo`;o
00005Oooool2o`0000Sooooo0_l00006ooooo`;o00003Oooool2o`0000;ooooo0_l000000ooooooo
0000o`000004o`0000Cooooo1_l0000?ooooo`;o000000?oooooo`000?l000001?ooool8o`0000oo
oooo0_l00003ooooo`;o00002?ooool2o`000004ooooool0003o0000ooooo`Ko00000oooool2o`00
00Sooooo0_l00004ooooo`;o00003?ooool2o`0000?ooooo0_l000000ooooooo0000o`00000<oooo
o`[o00001Oooool2o`0000Wooooo0_l00003ooooo`;o0000=_ooool001cooooo00?o0000oooooooo
ool0:oooool2o`0000cooooo0_l00008ooooo`;o00004_ooool2o`0000Gooooo0_l00003ooooo`Co
00000oooool3o`0000cooooo0_l00007ooooo`?o00002?ooool4o`0001Cooooo0_l00005ooooo`;o
000000?oooooo`000?l000003Oooool2o`0000Cooooo0_l00002ooooo`;o00000oooool2o`0000Co
oooo0_l00007ooooo`Co000000Coooooo`000?l0003o00000oooool2o`0000Oooooo0_l00002oooo
o`;o00000_ooool4o`00013ooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o
00001_ooool2o`0000oooooo0_l0000Aooooo`;o00001_ooool2o`0000Cooooo0_l00003ooooo`;o
000000?oooooo`000?l000002?ooool7o`0000Cooooo1?l00002ooooo`;o00000oooool2o`000003
ooooool0003o000000;ooooo0_l00002ooooo`?o000000?oooooo`000?l000000_ooool2o`0000[o
oooo0_l000000ooooooo0000o`00000?ooooo`;o00000_ooool2o`0000Oooooo0_l00002ooooo`Co
00001oooool4o`000004ooooool0003o0000o`0000?ooooo0_l00007ooooo`;o000000?oooooo`00
0?l000000_ooool2o`000004ooooool0003o0000ooooo`;o0000B_ooool001cooooo00?o0000oooo
ooooool0<_ooool3o`0000Gooooo0ol00007ooooo`;o00001oooool3o`0000oooooo2?l00006oooo
o`;o00001oooool3o`0000;ooooo0ol00004ooooo`Go000000Coooooo`000?l0003ooooo1ol00002
ooooo`Oo000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000[ooooo0_l0000?
ooooo`;o00001oooool2o`000003ooooool0003o000000Go00000_ooool2o`0000Gooooo0_l0000B
ooooo`;o000000Coooooo`000?l0003ooooo1_l000000ooooooo0000o`00001:ooooo`007?ooool0
0ol0003oooooooooo`0booooo`;o00001_ooool4o`0000Gooooo0_l00008ooooo`?o00004Oooool6
o`0000Gooooo0_l00008ooooo`;o00003?ooool=o`0000?ooooo1?l00003ooooo`;o00001_ooool2
o`00013ooooo0_l0000Booooo`_o000000Coooooo`000?l0003o00002Oooool2o`0000?ooooo0_l0
0008ooooo`;o00001?ooool5o`0004kooooo000Looooo`03o`000?oooooooooo033ooooo0_l00005
ooooo`;o00000oooool2o`0000Gooooo0_l0000;ooooo`;o00001oooool2o`000003ooooool0003o
000000kooooo0_l00008ooooo`;o00000oooool3o`0000Kooooo1?l00002ooooo`;o000000Cooooo
o`000?l0003ooooo0ol00002ooooo`;o00001?ooool2o`0001Sooooo0_l00007ooooo`;o00001Ooo
ool2o`0000;ooooo0ol000000ooooooo0000o`000009o`000003ooooool0003o000000;o00001?oo
ool2o`0000?ooooo0_l00005ooooo`;o00002?ooool2o`0000Cooooo1?l00002ooooo`;o00001Ooo
ool2o`0003gooooo000Looooo`03o`000?oooooooooo033ooooo1Ol00002ooooo`;o00002_ooool2
o`0000_ooooo0_l00007ooooo`;o000000?oooooo`000?l000000_l00005ooooo`?o00000oooool3
o`000003ooooool0003o000000Gooooo0_l00002ooooo`Go00000oooool2o`000003ooooool0003o
000000;ooooo1?l00002ooooo`Co00001Oooool2o`0000Sooooo0ol0000Iooooo`;o00001Oooool4
o`0000?ooooo2ol00002ooooo`Ko00003_ooool4o`0000Kooooo0_l00004ooooo`Co00000_ooool2
o`0000Gooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0aooooo`Co00001oooool3o`00
00Cooooo0_l0000Eooooo`;o00000_ooool2o`0000Gooooo0ol00003ooooo`;o00000_ooool2o`00
00;ooooo0_l00003ooooo`Co000000Coooooo`000?l0003ooooo5?l00004ooooo`;o00000oooool2
o`0000?ooooo0ol0000;ooooo`;o00004Oooool2o`000003ooooool0003o000000oo00000oooool2
o`000003ooooool0003o000000kooooo1?l00004ooooo`;o00003_ooool2o`0000Sooooo0_l00007
ooooo`;o0000;oooool001cooooo00?o0000ooooooooool0??ooool3o`0001_ooooo0_l0000Goooo
o`;o00000oooool6o`000005ooooool0003o0000o`000?ooool04Ol00004ooooo`Oo00004Oooool2
o`0000cooooo0_l00003oooooaWo000000Coooooo`000?l0003o00001oooool2o`0000Cooooo0_l0
0003ooooo`;o000000?oooooo`000?l000003_ooool2o`0000?ooooo0_l00003ooooo`;o00001ooo
ool2o`0002oooooo000Looooo`03o`000?oooooooooo03gooooo0_l0000Jooooo`Co00002?ooool2
o`0000?ooooo0_l0000;ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000002
ooooo`oo00000_ooool;o`0001Cooooo0ol00008ooooo`;o00000_oooolNo`0000;ooooo0_l00003
ooooo`;o00001?ooool2o`0000?ooooo0_l0000Aooooo`;o00000oooool2o`0003gooooo000Loooo
o`03o`000?oooooooooo02cooooo0_l0000Mooooo`;o00002_ooool6o`0000Sooooo0_l00003oooo
o`;o00002_ooool3o`000003ooooool0003o000000?ooooo1?l000000ooooooo0000o`00000Co`00
0003ooooool0003o000000;o00000oooool2o`0000oooooo1?l00008ooooo`;o00000_oooolLo`00
00Cooooo1?l00004ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Gooooo1?l0001=oooo
o`007?ooool00ol0003oooooooooo`0/ooooo`;o00006_ooool2o`000003ooooool0003o000000;o
oooo0_l00006ooooo`Co00000_ooool2o`0000Gooooo0_l0000@ooooob3o000000?oooooo`000?l0
00001Oooool5o`0000oooooo0_l0000:ooooo`;o00000_oooolKo`0000Oooooo0_l00004ooooo`;o
00000_ooool2o`000003ooooool0003o000000?ooooo1_l00004ooooo`;o0000Aoooool001cooooo
00?o0000ooooooooool0B?ooool2o`000003ooooool0003o000000;ooooo0_l0000:ooooo`Go0000
1?ooool2o`0000kooooo0_l000000ooooooo0000o`00000Mo`0000;ooooo0ol000000ooooooo0000
o`000004o`0000;ooooo0_l0000Koooooa_o00003Oooool2o`0000?ooooo1?l000001?oooooo0000
o`000?ooool2o`0000Sooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`0jooooo`;o0000
3oooool4o`0000Kooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000001;o
oooo1ol00002ooooob?o00001?ooool4o`0000_ooooo1?l00009ooooo`;o000000?oooooo`000?l0
00006ol00004ooooo`;o00001Oooool2o`0000Gooooo0_l000000ooooooo0000o`00001Dooooo`00
00Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413o
c<c<00Kooooo00?o0000ooooooooool0>_ooool2o`0000kooooo0_l000001?oooooo0000o`000?l0
0005ooooo`;o000000Coooooo`000?l0003o00002Oooool2o`0000Wooooo0_l000000ooooooo0000
o`000004o`000004ooooool0003o0000oooooako000000?oooooo`000?l000001ol000000ooooooo
0000o`00000:ooooo`Co00000_ooool4o`000003ooooool0003o0000013o000000?oooooo`000?l0
00003Ol00003ooooo`?o00000_ooool2o`0000Sooooo0_l0001Gooooo`0000KoooooogMgMonHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000
ooooooooool0@?ooool2o`0000Sooooo0_l00002ooooo`;o00002Oooool3o`0000Oooooo0ol00000
0ooooooo0000o`000006ooooo`;o00000oooool2o`0000?ooooo0_l00002oooooago000000?ooooo
o`000?l000001Ol00003ooooo`Go00000_ooool2o`0000Wooooo1?l000001Ooooooo0000o`000?l0
003ooooo02?o00000oooool2o`000003ooooool0003o000001Gooooo0_l00017ooooo`0000?ooooo
oa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`0hooooo`;o00001_ooool2o`00017ooooo0_l00005ooooo`;o00001ooo
ool2o`0000;ooooo0_l00005ooooo`;o00001?ooool2o`000003ooooool0003o000002Wo00001?oo
ool4o`0000;ooooo0_l0000?ooooo`;o00000_oooolRo`0000?ooooo0_l000000ooooooo0000o`00
000Eooooo`;o0000Aoooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool0
1Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0000_ooooo`;o00001oooool2o`0000Kooooo0_l0
000>ooooo`;o000000?oooooo`000?l000000_ooool2o`000004ooooool0003o0000ooooo`;o0000
1Oooool3o`0000Oooooo0_l00007oooooa7o000000?oooooo`000?l000005?l000001?oooooo0000
o`000?l00002ooooo`;o00004?ooool2o`0000?ooooo0_l00003ooooo`?o000000?oooooo`000?l0
00006_l0000;ooooo`;o00001Oooool2o`0000oooooo0ol00012ooooo`0000?oooooo`000?ooool0
0_ooool00ol0003oooooooooo`09ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003o
ooooooooo`0_ooooo`;o00007oooool3o`0000;ooooo1?l00004ooooo`;o00001Oooool3o`0000;o
oooo0_l00008ooooo`;o00000_oooolXo`000004ooooool0003o0000o`0000;ooooo0_l00005oooo
o`;o00002Oooool2o`0000?ooooo1Ol00002ooooob3o00002?ooool3o`0000?ooooo1Ol00005oooo
o`;o00001oooool3o`0004;ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wo
oooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`0eooooo`;o00004?ooool2o`0000So
oooo0_l00002ooooo`Co00001_ooool2o`0000;ooooo0_l00004ooooo`Co00000oooool2o`000003
ooooool0003o000000;ooooo:_l000000ooooooo0000o`000002ooooo`Co00000_ooool2o`0000ko
oooo1_l000000ooooooo0000o`00000No`0000Sooooo0ol00003ooooo`Go00001Oooool2o`0004co
oooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0
003oooooooooo`0cooooo`Co00001Oooool2o`0000Wooooo0_l00005ooooo`;o00003oooool2o`00
00;ooooo0_l00006ooooo`;o000000?oooooo`000?l000000ol00003ooooobko00000_ooool4o`00
01;ooooo4?l000000ooooooo0000o`00000Ao`0000?ooooo0_l0000>ooooo`;o00001_ooool2o`00
00[ooooo0_l00010ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co
0000oa0@40Kooooo00?o0000ooooooooool0<oooool2o`000003ooooool0003o000000Cooooo0_l0
000@ooooo`;o00004oooool2o`0000;ooooo0_l00005ooooo`Go00000oooool2o`0000;ooooo4ol0
00000ooooooo0000o`00000Fo`000003ooooool0003o000000;o00001_ooool2o`0000Wooooo9Ol0
0002ooooo`;o00003_ooool2o`0000Cooooo1?l0000:ooooo`;o00000_ooool2o`0003cooooo000L
ooooo`03o`000?oooooooooo03Kooooo0_l0000[ooooo`?o000000?oooooo`000?l000001Oooool2
o`0000?ooooo1Ol00002ooooobOo000000?oooooo`000?l000000_l00003ooooo`;o00001_ooool4
o`0000Oooooo0_l000001?oooooo0000o`000?oooolBo`000003ooooool0003o000000[o00003?oo
ool2o`000003ooooool0003o000000Oooooo0_l0000@ooooo`;o0000??ooool001cooooo00?o0000
ooooooooool0?Oooool2o`0000kooooo0_l0000Eooooo`;o00002?ooool2o`0000?ooooo0ol00003
ooooo`Go000000?oooooo`000?l000006Ol000000ooooooo0000o`000002o`0000?ooooo0_l00009
ooooo`?o00000oooool3o`0000Gooooo0_l000000ooooooo0000o`000002oooooaoo00001Oooool2
o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000007ooooo`;o00001_ooool2
o`0004Kooooo000Looooo`03o`000?oooooooooo03Sooooo0_l00003ooooo`;o00002_ooool2o`00
00;ooooo0_l0000;ooooo`Co00004_oooolEo`000003ooooool0003o000001;o000000?oooooo`00
0?l000000ol00002ooooo`?o00000_ooool2o`0000Cooooo0ol00004ooooo`;o00001Oooool2o`00
0004ooooool0003o0000o`0000;ooooo0_l000000ooooooo0000o`00000Io`0000Gooooo0_l00000
0ooooooo0000o`00000Fooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0=?ooool2o`00
00;ooooo0_l0000?ooooo`;o00001oooool2o`0000Gooooo1Ol00004ooooo`;o00000_ooool2o`00
00Sooooo2ol000000ooooooo0000o`000004o`000004ooooool0003o0000ooooo`ko000000?ooooo
o`000?l000003_l00002ooooo`;o00004_ooool2o`0000;ooooo0ol000000ooooooo0000o`00000J
o`0000Kooooo0_l00009ooooo`;o0000Eoooool001cooooo00?o0000ooooooooool0=?ooool2o`00
00;ooooo0_l0000Hooooo`?o00001?ooool2o`0000Oooooo1_l000000ooooooo0000o`000006oooo
o`[o000000?oooooo`000?l000009_l00004ooooo`;o00004Oooool4o`000003ooooool0003o0000
01_o00002?ooool2o`0000Wooooo0_l00003ooooo`;o00002?ooool2o`0004Sooooo000Looooo`03
o`000?oooooooooo03Gooooo0_l000000ooooooo0000o`000003ooooo`;o00002_ooool2o`0000Co
oooo0_l000001?oooooo0000o`000?l00009ooooo`;o000000?oooooo`000?l000000ol00003oooo
o`;o00002_ooool/o`000003ooooool0003o000000;ooooo1?l0000Cooooo`;o00000ooooolGo`00
00;ooooo0_l00006ooooo`;o00002?ooool4o`0000;ooooo1?l00008ooooo`;o0000B?ooool001co
oooo00?o0000ooooooooool0=Oooool2o`0000Gooooo0ol00003ooooo`Co00000oooool2o`0000Co
oooo0_l00009ooooo`;o00000_ooool9o`0000kooooo1?l000000ooooooo0000o`000003ooooob;o
000000?oooooo`000?l000000_ooool3o`0000Gooooo0_l00006ooooo`;o00001?ooool4o`0000Co
oooo5Ol00002ooooo`;o000000Coooooo`000?l0003o00000_ooool4o`0000Kooooo1?l00002oooo
o`?o00002oooool2o`0004Kooooo000Looooo`03o`000?oooooooooo03Sooooo0_l00002ooooo`;o
00001?ooool4o`0001Cooooo0_l00002ooooo`Co00000oooool2o`0000Oooooo0_l00002ooooo`;o
000000?oooooo`000?l000001?ooool5o`000003ooooool0003o000000Oo000000?oooooo`000?l0
00004?l000001?oooooo0000o`000?ooool2o`0000Cooooo0_l00005ooooo`;o00001?ooool4o`00
0004ooooool0003o0000ooooo`Co00001?ooool4o`0000;ooooo4ol000001?oooooo0000o`000?l0
0004ooooo`;o00001_ooool2o`0000Kooooo0_l0000:ooooo`;o0000A_ooool001cooooo00?o0000
ooooooooool0>?ooool2o`0000gooooo0_l0000Gooooo`;o000000?oooooo`000?l000000_l00000
0ooooooo0000o`000004ooooo`;o00000_ooool2o`000003ooooool0003o000002?o000000?ooooo
o`000?l000001?ooool2o`000004ooooool0003o0000ooooo`;o00002oooool2o`0000?ooooo0_l0
0004ooooo`Co000000Coooooo`000?l0003o00000ooooolBo`0000;ooooo0_l00005ooooo`;o0000
1_ooool2o`0000Kooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`17ooooo`;o00000_oo
ool2o`0001?ooooo1ol000000ooooooo0000o`000004ooooo`;o00000oooool2o`000003ooooool0
003o000000go000000?oooooo`000?l000004ol00006ooooo`;o000000Coooooo`000?l0003ooooo
0_l00006ooooo`;o00001_ooool4o`0000?ooooo1Ol000001?oooooo0000o`000?l00003ooooo`;o
00000oooool2o`000005ooooool0003o0000o`000?ooool00_l000001?oooooo0000o`000?l00002
ooooo`;o00000_ooool3o`0000Sooooo0ol0000Jooooo`;o0000?Oooool001cooooo00?o0000oooo
ooooool0Boooool4o`0000_ooooo1?l00004ooooo`Go00002_ooool4o`000003ooooool0003o0000
02Co00000_ooool4o`0000gooooo0_l00006ooooo`Co00000oooool5o`0000;ooooo1?l000001?oo
oooo0000o`000?ooool4o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l0
0003ooooo`?o00002?ooool4o`0001Oooooo1?l0000mooooo`007?ooool2o`0003Wooooo0_l0000C
ooooo`;o00002oooool4o`0000Gooooo1?l000000ooooooo0000o`000007ooooo`Co000000?ooooo
o`000?l000009?l00002ooooo`Go00000oooool4o`0001Kooooo0ol00003ooooo`?o00001?ooool4
o`000004ooooool0003o0000o`0000Cooooo0_l000001?oooooo0000o`000?l00008ooooo`;o0000
1?ooool4o`0000;ooooo0_l00006ooooo`;o00002Oooool5o`0003kooooo000Looooo`03o`000?oo
oooooooo03Sooooo1?l0000Aooooo`?o00005?ooool3o`000003ooooool0003o0000013ooooo5_l0
00000ooooooo0000o`000003o`0000;ooooo1ol00002ooooo`Co000000?oooooo`000?l000000_l0
000Uooooo`;o000000Coooooo`000?l0003o00001?ooool2o`000004ooooool0003o0000o`0000?o
oooo0_l00003ooooo`?o00002Oooool2o`0000Kooooo0_l00009ooooo`;o000000?oooooo`000?l0
0000?_ooool001cooooo00?o0000ooooooooool0>_ooool2o`0000?ooooo0_l00003ooooo`;o0000
2?ooool2o`0000kooooo0_l00004ooooo`?o00001_ooool2o`0000_ooooo7ol000000ooooooo0000
o`000004o`000003ooooool0003o000000;o00004oooool2o`000003ooooool0003o000001Cooooo
1?l00004ooooo`;o00000_ooool2o`0000?ooooo0_l00004ooooo`;o00007?ooool2o`00047ooooo
000Looooo`03o`000?oooooooooo03oooooo0_l00003ooooo`;o00002?ooool2o`0000kooooo0_l0
000=ooooo`;o00000oooool2o`0000Kooooo9_l000000ooooooo0000o`000004o`0000gooooo0_l0
00001Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`000?l000000_l00009ooooo`;o0000
1?ooool7o`000003ooooool0003o000000Wooooo0_l00005ooooo`?o00004Oooool2o`0000Gooooo
0_l00011ooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o00005?ooool4o`0000Oooooo0_l0
00000ooooooo0000o`000002ooooo`;o00000_ooool2o`0000;ooooo1?l000000ooooooo0000o`00
000Bo`000003ooooool0003o000000Ko000000?oooooo`000?l000001?l00003ooooo`;o00002?oo
ool5o`0000Gooooo1?l00007ooooo`Co00001Oooool6o`0000?ooooo1?l00005ooooo`Co00000ooo
ool3o`0000Sooooo0_l00007ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0?_ooool2
o`0000?ooooo0_l00006ooooo`;o00003Oooool2o`0000Sooooo1?l00007ooooo`Co00000oooool4
o`0000Cooooo6Ol00002ooooo`?o00001Oooool2o`0000Oooooo0_l000000ooooooo0000o`000002
o`0000Cooooo0_l0000Booooo`?o00003?ooool2o`000003ooooool0003o000000?o00001_ooool2
o`0000kooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00000oooool2o`00
00Cooooo1?l00007ooooo`?o00000oooool2o`0000?ooooo0ol000000ooooooo0000o`000002o`00
00;ooooo0_l00006ooooo`?o00000_ooool4o`0000?ooooo6Ol00003ooooo`?o00000oooool4o`00
00Wooooo1Ol0000>ooooo`;o00002Oooool2o`0000cooooo0_l00003ooooo`?o00001Oooool2o`00
06;ooooo000Looooo`03o`000?oooooooooo047ooooo0_l00006ooooo`Co000000?oooooo`000?l0
00001?ooool3o`0000Sooooo0ol000000ooooooo0000o`000002o`0000;ooooo0ol00006ooooo`;o
00002?ooool6o`0000;ooooo1Ol000000ooooooo0000o`000004o`0000?ooooo0ol000001?oooooo
0000o`000?l00005ooooo`?o000000Coooooo`000?l0003o00001_ooool2o`00013ooooo0ol0000D
ooooo`;o00001_ooool2o`000004ooooool0003o0000ooooo`Co00003oooool2o`00057ooooo000L
ooooo`03o`000?oooooooooo047ooooo0_l0000;ooooo`;o00003oooool2o`0000Cooooo0_l00003
ooooo`;o00004?ooool6o`000003ooooool0003o000000Co000000?oooooo`000?l000001?l00000
1?oooooo0000o`000?ooool2o`000004ooooool0003o0000o`0000Kooooo0_l000001?oooooo0000
o`000?l0000Eooooo`;o000000Coooooo`000?l0003o00000oooool2o`0000gooooo1_l00004oooo
o`;o000000Coooooo`000?l0003ooooo0_l0000Aooooo`;o0000DOooool001cooooo00?o0000oooo
ooooool0B_ooool2o`0001?ooooo0_l00002ooooo`Co00005_ooool3o`0000;ooooo0ol000001?oo
oooo0000o`000?l00004ooooo`?o000000Coooooo`000?l0003ooooo0_l0000Uooooo`;o00001ooo
ool2o`0000Gooooo0_l00006ooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o0000Iooo
ool001cooooo00?o0000ooooooooool0Aoooool2o`000003ooooool0003o000001Oooooo1Ol00002
ooooo`?o00002?ooool2o`0000Kooooo0ol000000ooooooo0000o`000004o`000003ooooool0003o
000000;o000000?oooooo`000?l000001_l00005ooooo`;o00000_ooool3o`0000[ooooo0_l00000
0ooooooo0000o`000005ooooo`;o00003?ooool2o`0000Kooooo0_l0000>ooooo`;o0000K?ooool0
01cooooo00?o0000ooooooooool0@Oooool2o`0000Cooooo0_l0000?ooooo`;o00002_ooool4o`00
00;ooooo0ol00002ooooo`;o00001?ooool2o`000003ooooool0003o000000?ooooo1_l000001Ooo
oooo0000o`000?l0003ooooo00Co000000?oooooo`000?l000001_l00005ooooo`Oo00002_ooool2
o`000003ooooool0003o000000;o00000_ooool3o`0000Cooooo0_l000000ooooooo0000o`000003
ooooo`;o0000Q?ooool001cooooo00?o0000ooooooooool0@Oooool2o`0000Wooooo1?l00008oooo
o`;o00002_ooool6o`0000Gooooo0_l00007ooooo`;o000000?oooooo`000?l000001Ol00002oooo
o`;o00000oooool2o`0000;ooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o0000
00;ooooo0_l0000?ooooo`;o000000?oooooo`000?l000001?l00005ooooo`;o000000?oooooo`00
0?l000001_ooool2o`00087ooooo000Looooo`03o`000?oooooooooo04cooooo1?l0000Dooooo`Ko
00003Oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000Oooooo0_l00002ooooo`;o
00000_ooool5o`0000?ooooo0_l0000>ooooo`;o00000_ooool3o`0001;ooooo0_l00006ooooo`?o
0000N?ooool001cooooo00?o0000ooooooooool0C?ooool2o`0000Oooooo0_l0000?ooooo`;o0000
2Oooool2o`0000Cooooo0_l0000;ooooo`;o00000_ooool2o`0000?ooooo0_l00007ooooo`?o0000
0_ooool4o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o00001_ooool2o`0000Gooooo
0_l0000Dooooo`?o00000oooool2o`0000gooooo0_l0001Tooooo`007?ooool00ol0003ooooooooo
o`1<ooooo`;o00001oooool4o`0000Sooooo0_l00003ooooo`;o00002Oooool2o`0000;ooooo0_l0
000>ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000005ooooo`Co00000ooo
ool4o`000005ooooool0003o0000o`000?ooool02?l00002ooooo`;o00002?ooool2o`0001Cooooo
0_l00004ooooo`;o00002oooool4o`0006Cooooo000Looooo`;o0000F?ooool2o`0000Sooooo0_l0
0004ooooo`;o00003?ooool2o`0000?ooooo0_l00006ooooo`;o000000?oooooo`000?l000001Ol0
00000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000_l00003ooooo`Co00000_oo
ool5o`000004ooooool0003o0000ooooo`?o000000Coooooo`000?l0003ooooo0_l000000ooooooo
0000o`000002o`000003ooooool0003o000002Kooooo0_l0000Hooooo`;o00000_ooool2o`0004So
oooo000Looooo`03o`000?oooooooooo04Oooooo0_l0000Nooooo`?o00001_ooool2o`0000?ooooo
0_l00003ooooo`Co00001?ooool2o`0000;ooooo1?l00007ooooo`;o00002oooool2o`0000;ooooo
1Ol00004ooooo`;o000000?oooooo`000?l000000ol000000ooooooo0000o`000002o`000003oooo
ool0003o000000;o00002Oooool2o`0000Kooooo0_l0000:ooooo`;o00007oooool2o`0000;ooooo
0_l00018ooooo`007?ooool00ol0003oooooooooo`17ooooo`Co00004_ooool2o`0000Wooooo0_l0
0006ooooo`;o00002_ooool2o`0000[ooooo0_l00004ooooo`;o000000?oooooo`000?l000001_oo
ool2o`0000?ooooo0_l00005ooooo`?o00002?ooool5o`0000Kooooo1?l000000ooooooo0000o`00
0004ooooo`Co00001?ooool2o`0000Sooooo1?l00007ooooo`?o0000Hoooool001cooooo00?o0000
ooooooooool0B?ooool3o`0001;ooooo0_l0000?ooooo`;o00006?ooool2o`0000Cooooo0_l00005
ooooo`;o00000_ooool2o`000003ooooool0003o000000Sooooo0_l000000ooooooo0000o`000006
ooooo`Co000000?oooooo`000?l000001Oooool2o`000003ooooool0003o000000Gooooo1Ol0000<
ooooo`;o00002Oooool6o`00063ooooo000Looooo`03o`000?oooooooooo04Wooooo0_l0000Soooo
o`;o00003_ooool4o`0000?ooooo0_l000000ooooooo0000o`00000;ooooo`;o000000?oooooo`00
0?l000001?l0000;ooooo`;o00000_ooool4o`0000;ooooo0_l000000ooooooo0000o`000003oooo
o`;o00002oooool5o`0000Wooooo0_l0000>ooooo`?o00003oooool2o`0004oooooo000Looooo`03
o`000?oooooooooo04Wooooo0_l000000ooooooo0000o`00000Dooooo`;o00004_ooool2o`0000Ko
oooo1Ol00002ooooo`;o00002oooool2o`0000Cooooo1?l0000;ooooo`;o00001?ooool4o`0000;o
oooo0ol00005ooooo`;o00003_ooool2o`0000Wooooo0_l00002ooooo`;o00002Oooool2o`00017o
oooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00001?ooool2o`0000Sooooo
0_l00004ooooo`;o00004_ooool3o`0000Sooooo1?l0000=ooooo`;o00002Oooool2o`0000Sooooo
0_l0000;ooooo`;o00002Oooool2o`0001Kooooo0_l000000ooooooo0000o`000009ooooo`;o0000
H_ooool001cooooo00?o0000ooooooooool0D_ooool2o`0000?ooooo0_l00003ooooo`?o000000?o
ooooo`000?l000004?ooool2o`000003ooooool0003o000000;o00002Oooool3o`0000Gooooo0_l0
0006ooooo`;o00002Oooool2o`0000_ooooo0_l00009ooooo`;o00002?ooool2o`0000?ooooo0_l0
000Aooooo`?o00001_ooool2o`0006Oooooo000Looooo`03o`000?oooooooooo04Oooooo0_l0000>
ooooo`;o00001?ooool2o`000003ooooool0003o0000013ooooo0_l000000ooooooo0000o`000002
o`0000Gooooo0_l00007ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Wooooo0_l0000;
ooooo`;o00000oooool2o`0000Cooooo0_l0000=ooooo`;o00004?ooool4o`0000Kooooo1?l0000?
ooooo`;o0000E?ooool001cooooo00?o0000ooooooooool0Aoooool2o`0001[ooooo0_l0000@oooo
o`;o000000?oooooo`000?l000001?ooool2o`0000Oooooo0_l0000Vooooo`;o00008?ooool2o`00
00?ooooo0_l00004ooooo`;o00001?ooool2o`0000oooooo0_l0001Dooooo`007?ooool00ol0003o
ooooooooo`1Looooo`;o00001Oooool2o`0000Oooooo0_l00002ooooo`;o00000oooool2o`000003
ooooool0003o000000;ooooo0_l0000Sooooo`;o0000;_ooool3o`0000Oooooo0ol00002ooooo`?o
00003_ooool2o`0005Kooooo000Looooo`03o`000?oooooooooo05cooooo0_l00003ooooo`;o0000
2Oooool2o`0000;ooooo0_l00004ooooo`;o00001?ooool2o`0000Wooooo0_l000000ooooooo0000
o`000005ooooo`;o00002Oooool3o`0000;ooooo0_l0000_ooooo`;o00001oooool2o`0000?ooooo
0ol0000>ooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0HOooool2o`0000kooooo0_l0
0003ooooo`;o00003oooool2o`000003ooooool0003o000000Gooooo0_l00004ooooo`;o00000ooo
ool3o`0003?ooooo0_l00002ooooo`;o00001Oooool2o`0006[ooooo000Looooo`03o`000?oooooo
oooo05_ooooo0_l0000Booooo`Co00002Oooool2o`0001Wooooo0_l0000:ooooo`;o0000<Oooool2
o`0000Gooooo0_l0001Zooooo`007?ooool00ol0003oooooooooo`1Kooooo`;o00001?ooool2o`00
00cooooo0ol0000:ooooo`Co00005Oooool2o`0000cooooo0_l0002Tooooo`007?ooool00ol0003o
ooooooooo`1Looooo`;o00000oooool2o`0000[ooooo1Ol00008ooooo`;o00000_ooool3o`0000_o
oooo0_l00007ooooo`;o0000@Oooool3o`0006kooooo000Looooo`;o0000GOooool2o`0000Kooooo
0_l00007ooooo`Go00002?ooool2o`0000?ooooo0_l0000;ooooo`?o0000Aoooool5o`0006kooooo
000Looooo`03o`000?oooooooooo06Cooooo0_l0000Wooooo`;o0000Aoooool3o`00073ooooo000L
ooooo`03o`000?oooooooooo05oooooo0_l0000Aooooo`?o00001Oooool2o`0002Wooooo0_l0000R
ooooo`;o00003?ooool3o`0006oooooo000Looooo`03o`000?oooooooooo05oooooo0_l00004oooo
o`;o00001oooool2o`0000;ooooo0ol00005ooooo`;o00000oooool2o`0000?ooooo0_l00009oooo
o`;o00003?ooool2o`0000Kooooo0_l0000Rooooo`?o00003?ooool2o`0006oooooo000Looooo`03
o`000?oooooooooo06Gooooo1?l00005ooooo`;o00003oooool2o`0000?ooooo0_l00009ooooo`;o
00003?ooool2o`0000Wooooo0_l0000Pooooo`;o0000OOooool001cooooo00?o0000ooooooooool0
Doooool2o`0001;ooooo0_l0000Mooooo`;o00003oooool2o`0000kooooo0ol0000/ooooo`;o0000
LOooool001cooooo00?o0000ooooooooool0Doooool2o`0000;ooooo0_l0000Oooooo`?o00001_oo
ool2o`000003ooooool0003o000000;o00003oooool2o`0000kooooo0_l0000Uooooo`Co00001?oo
ool2o`0001;ooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1Gooooo`;o00004?ooool2
o`0000gooooo0ol00006ooooo`;o000000Coooooo`000?l0003o00003Oooool2o`0000Gooooo0_l0
000aooooo`Co00000oooool2o`0001?ooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1Y
ooooo`;o00003Oooool2o`000003ooooool0003o000000Sooooo1?l0000;ooooo`;o00001Oooool3
o`0000[ooooo0_l0000Hooooo`;o00002_ooool2o`0000Gooooo0_l0001booooo`007?ooool00ol0
003oooooooooo`1Wooooo`;o00002_ooool2o`0000Kooooo0_l00006ooooo`;o00000_ooool2o`00
013ooooo0_l000000ooooooo0000o`00000:ooooo`;o00006?ooool2o`0000kooooo0_l000000ooo
oooo0000o`00001booooo`007?ooool00ol0003oooooooooo`1Wooooo`;o00002_ooool3o`0000go
oooo0_l0000Dooooo`;o0000=oooool2o`000003ooooool0003o000000cooooo0_l0001Tooooo`00
7?ooool00ol0003oooooooooo`1Hooooo`;o00006_ooool2o`0000[ooooo0_l0000<ooooo`;o0000
0_ooool3o`0000kooooo0_l000000ooooooo0000o`00000Looooo`?o00007?ooool2o`0006Cooooo
000Looooo`03o`000?oooooooooo05Sooooo0_l0000Uooooo`?o00001oooool2o`0000?ooooo0_l0
00000ooooooo0000o`000002o`0000kooooo0_l000000ooooooo0000o`00000Iooooo`;o000000Co
ooooo`000?l0003o00002_ooool2o`0007Kooooo000Looooo`03o`000?oooooooooo06_ooooo0_l0
000Booooo`;o000000?oooooo`000?l000001Oooool4o`0000Cooooo0ol0000:ooooo`;o00005ooo
ool2o`0000Sooooo0ol00005ooooo`?o00001Oooool2o`0007Kooooo00001_ooooook^k^oc8b<_l0
003o<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003o
ooooooooo`1[ooooo`;o00003oooool2o`000003ooooool0003o000000?o00001oooool2o`0000?o
oooo1?l0000:ooooo`;o00005Oooool4o`0000?ooooo0_l00002ooooo`Co00001Oooool3o`0000Go
oooo0_l0000;ooooo`;o0000JOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q
8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo07cooooo2?l00000
0ooooooo0000o`000003ooooo`;o00001?ooool2o`0002?ooooo0_l00003ooooo`Co00000_ooool2
o`0000Oooooo0_l00006ooooo`;o00002oooool2o`0006Wooooo00000ooooooo410@ooooo`02oooo
o`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo06kooooo0_l0000>ooooo`?o000000?oooooo`000?l000000ol00003ooooo`;o00000oooool2
o`000003ooooool0003o000000oooooo0_l0000Dooooo`?o000000Coooooo`000?l0003ooooo0_l0
00001?oooooo0000o`000?l00008ooooo`;o00001_ooool2o`0000?ooooo0_l0001/ooooo`0000?o
ooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80
1_ooool3o`0006kooooo0_l00009ooooo`Co00001oooool2o`0000Sooooo0ol000000ooooooo0000
o`00000>ooooo`?o00003?ooool2o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o0000
0_ooool5o`0000Sooooo0_l00005ooooo`?o00000oooool2o`0006cooooo00000ooooooo0000oooo
o`02ooooo`03o`000?oooooooooo00Wooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`00
0?oooooooooo07Wooooo1?l0000Aooooo`;o00000_ooool4o`0000Gooooo1_l000000ooooooo0000
o`000002ooooo`;o00002Oooool2o`000003ooooool0003o000000Oooooo0_l00002ooooo`Go0000
0_ooool2o`0000Sooooo0_l000000ooooooo0000o`00001booooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooo
ooooo`1hooooo`;o00003_ooool2o`0000Sooooo1?l00005ooooo`Ko000000?oooooo`000?l00000
0_ooool2o`0000Sooooo0ol0000?ooooo`;o00001?ooool2o`0000Sooooo0_l0001eooooo`0000Ko
ooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0
003oooooooooo`1hooooo`Co00003?ooool2o`000003ooooool0003o000000cooooo0_l00007oooo
o`;o000000?oooooo`000?l000002?ooool4o`0000_ooooo0_l00002ooooo`;o0000QOooool00006
ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o
0000ooooooooool0N_ooool2o`0000Kooooo0_l00006ooooo`?o00001_ooool2o`0000Cooooo0_l0
0007ooooo`Go00002?ooool2o`0000gooooo0_l0000:ooooo`;o00001_ooool2o`0007Gooooo000L
ooooo`03o`000?oooooooooo08;ooooo0_l00006ooooo`?o00001_ooool2o`0000gooooo1?l0000T
ooooo`;o00001_ooool2o`0007Gooooo000Looooo`03o`000?oooooooooo08_ooooo0_l0000;oooo
o`;o0000:oooool2o`0008;ooooo000Looooo`03o`000?oooooooooo07gooooo0_l000000ooooooo
0000o`00000Fooooo`;o00001oooool2o`00013ooooo0_l00005ooooo`;o00002Oooool2o`0008;o
oooo000Looooo`03o`000?oooooooooo07gooooo0_l000000ooooooo0000o`00000Fooooo`Co0000
1Oooool2o`00013ooooo0_l00005ooooo`;o0000SOooool001cooooo00?o0000ooooooooool0V?oo
ool5o`0000Cooooo0_l0000Uooooo`;o0000Ooooool001cooooo00?o0000ooooooooool0T_ooool2
o`0000Oooooo0_l0000Iooooo`;o00004?ooool2o`0007oooooo000Looooo`03o`000?oooooooooo
09;ooooo0_l0000Jooooo`;o00000oooool2o`000003ooooool0003o0000023ooooo0_l0001_oooo
o`007?ooool00ol0003oooooooooo`2/ooooo`Co00000oooool2o`0002?ooooo0_l0001_ooooo`00
7?ooool00ol0003oooooooooo`25ooooo`;o00005_ooool2o`0000gooooo0_l0002Kooooo`007?oo
ool00ol0003oooooooooo`25ooooo`;o00005_ooool3o`0000oooooo0_l000001?oooooo0000o`00
0?ooool3o`0002?ooooo0_l0001/ooooo`007?ooool00ol0003oooooooooo`2Nooooo`;o00001?oo
ool2o`0000Kooooo0_l000001?oooooo0000o`000?ooool6o`0002?ooooo0_l0001/ooooo`007?oo
ool2o`000:Gooooo0_l00006ooooo`;o00001Oooool2o`0000;ooooo0_l0002@ooooo`007?ooool0
0ol0003oooooooooo`2Zooooo`;o00002oooool2o`0001cooooo0_l0001booooo`007?ooool00ol0
003oooooooooo`2Zooooo`;o0000:Oooool2o`0007;ooooo000Looooo`03o`000?oooooooooo093o
oooo0_l0002gooooo`007?ooool00ol0003oooooooooo`2@ooooo`;o0000]oooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Qooooo`;o0000Y_ooool0
01cooooo00?o0000ooooooooool0XOooool2o`000:Kooooo000Looooo`03o`000?oooooooooo0:?o
oooo0_l0000:ooooo`;o0000V?ooool001cooooo00?o0000ooooooooool0Xoooool2o`0000[ooooo
0_l0000Aooooo`;o0000QOooool001cooooo00?o0000ooooooooool0[Oooool3o`0001;ooooo0_l0
0025ooooo`007?ooool00ol0003oooooooooo`2]ooooo`?o0000VOooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2
o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001;ooooo1?l000000ol@413oooooooooo`03
ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo0ol0003ooooood[o
oooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooo
oomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo
0?ooooooD_ooool001;ooooo00?oEEEEofIVI_l00000oooooomDooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00YOooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooo
oooo01Oooooo00?o0000onk^k_ooool00oooool01?l@413o0000odA4A?o<c<`4ooooo`Go0000T?oo
ool00:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00002oooool00omEEEGoZJVYoooo
o`05ooooo`03oiRHV?l@413ogMgM00?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A02@ooooo`00Y_oo
ool01Ol0003ooooooooooooooooo000001[ooooo00?oZJVYoeEEEOooool01_ooool00on7QhOoEEEE
ooooo`03ooooo`03oiRHV?lQ8B7ok^k^097ooooo002Vooooo`05o`000?ooooooooooooooool00000
2Oooool6o`0000cooooo00?o8B4Qooooooooool00_ooool01Oo<c<co8B4Qo`000?mEEEGo000000Go
oooo00?oV9RHob4Q8Oo^k^h0T?ooool00:Kooooo00Go0000ohN7QoooooooZJVYo`00000Kooooo`03
oeEEEOo<c<cooooo00;ooooo00Go8B4QohN7QoooooooV9RHo`000006ooooo`03ogMgMomVIVKooooo
08oooooo002Uooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool06Oooool00onYZJWo
MgMgooooo`02ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`2>oooo
o`00`oooool01Ol@413ooooooooooooooooo<S8b00?ooooo00Go8B4QoiRHV?ooooooMgMgoeEEE@03
ooooo`05o`000?nj^[[ooooooiRHV?l@4100T?ooool00<?ooooo1Ol00003ooooo`05olc<c?l@413o
0000oc8b<_o^k^h00oooool01OnHV9So410@o`000?lQ8B7oc<c<093ooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(798) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.66495 .64435 Mdot
.6488 .64335 Mdot
.48896 .28577 Mdot
.3771 .60146 Mdot
.45174 .49617 Mdot
.48467 .34537 Mdot
.62418 .42842 Mdot
.64466 .42139 Mdot
.50224 .3466 Mdot
.45031 .70669 Mdot
.59708 .4443 Mdot
.39724 .53811 Mdot
.62469 .44206 Mdot
.41468 .6252 Mdot
.51078 .16176 Mdot
.40845 .5515 Mdot
.6188 .59459 Mdot
.39781 .4135 Mdot
.3551 .63327 Mdot
.52536 .31439 Mdot
.60044 .58149 Mdot
.41884 .6263 Mdot
.6653 .63281 Mdot
.41571 .62415 Mdot
.39093 .58813 Mdot
.6255 .62396 Mdot
.66155 .59672 Mdot
.41526 .57142 Mdot
.40153 .61003 Mdot
.60236 .41234 Mdot
.40003 .47015 Mdot
.3657 .19801 Mdot
.40383 .54689 Mdot
.42648 .80043 Mdot
.63828 .41928 Mdot
.19555 .47815 Mdot
.51614 .32437 Mdot
.61777 .46864 Mdot
.64012 .41768 Mdot
.64591 .45122 Mdot
.62459 .4646 Mdot
.62412 .62951 Mdot
.62622 .48907 Mdot
.56824 .45258 Mdot
.37142 .60616 Mdot
.72136 .50608 Mdot
.25554 .41893 Mdot
.42655 .5806 Mdot
.6323 .65459 Mdot
.52909 .33098 Mdot
.55552 .83079 Mdot
.65286 .45239 Mdot
.71043 .31716 Mdot
.41172 .1042 Mdot
.63563 .45214 Mdot
.37421 .59262 Mdot
.49918 .32337 Mdot
.44546 .61862 Mdot
.42732 .61523 Mdot
.56423 .80704 Mdot
.40766 .58477 Mdot
.37983 .41131 Mdot
.57778 .6237 Mdot
.46247 .32607 Mdot
.49261 .34659 Mdot
.62493 .40922 Mdot
.60382 .61198 Mdot
.61629 .44086 Mdot
.47637 .65185 Mdot
.51985 .3436 Mdot
.4278 .58022 Mdot
.5985 .45147 Mdot
.61064 .65814 Mdot
.45877 .63526 Mdot
.74516 .52939 Mdot
.58173 .18011 Mdot
.40289 .4209 Mdot
.54615 .79599 Mdot
.68125 .70326 Mdot
.60934 .21908 Mdot
.40938 .61591 Mdot
.86402 .46618 Mdot
.52728 .16423 Mdot
.66267 .6312 Mdot
.41582 .50673 Mdot
.4712 .3804 Mdot
.43259 .6439 Mdot
.45262 .45975 Mdot
.48552 .62411 Mdot
.75492 .60982 Mdot
.50662 .34257 Mdot
.61665 .638 Mdot
.3777 .60756 Mdot
.46629 .59473 Mdot
.54976 .72507 Mdot
.47 .63696 Mdot
.41161 .56612 Mdot
.6354 .58304 Mdot
.60738 .4172 Mdot
.48146 .57576 Mdot
.6026 .49709 Mdot
.69521 .32072 Mdot
.39235 .64318 Mdot
.50318 .35695 Mdot
.60269 .59525 Mdot
.3916 .6472 Mdot
.64062 .44056 Mdot
.41409 .59572 Mdot
.59915 .48899 Mdot
.64786 .64945 Mdot
.46729 .59989 Mdot
.3956 .41474 Mdot
.78589 .54475 Mdot
.60863 .62737 Mdot
.81504 .41546 Mdot
.41561 .58319 Mdot
.42581 .62663 Mdot
.64621 .64225 Mdot
.48206 .31191 Mdot
.44141 .44739 Mdot
.59645 .62885 Mdot
.64629 .43647 Mdot
.67057 .61451 Mdot
.40741 .6669 Mdot
.48146 .35433 Mdot
.68934 .31951 Mdot
.69502 .29487 Mdot
.27631 .60867 Mdot
.42278 .64591 Mdot
.68026 .47923 Mdot
.47972 .33614 Mdot
.62535 .64054 Mdot
.61682 .44438 Mdot
.39744 .56235 Mdot
.63288 .59915 Mdot
.6077 .45405 Mdot
.39066 .4207 Mdot
.3119 .33221 Mdot
.61145 .64971 Mdot
.591 .53608 Mdot
.5814 .44144 Mdot
.64485 .45294 Mdot
.45731 .82608 Mdot
.65148 .6396 Mdot
.35453 .4185 Mdot
.6073 .44876 Mdot
.31828 .48547 Mdot
.40498 .56207 Mdot
.29611 .65991 Mdot
.83208 .5787 Mdot
.53736 .84016 Mdot
.74073 .39809 Mdot
.35693 .39386 Mdot
.63708 .46976 Mdot
.38787 .60667 Mdot
.64915 .63124 Mdot
.63848 .63188 Mdot
.45413 .5745 Mdot
.39663 .57988 Mdot
.45125 .58649 Mdot
.45816 .58365 Mdot
.27578 .39145 Mdot
.45318 .58428 Mdot
.54545 .31057 Mdot
.61085 .61307 Mdot
.39663 .59326 Mdot
.48927 .29737 Mdot
.37446 .56603 Mdot
.61027 .46379 Mdot
.43208 .61858 Mdot
.38929 .57966 Mdot
.43874 .65179 Mdot
.62952 .46706 Mdot
.30745 .2536 Mdot
.8226 .57495 Mdot
.20041 .3909 Mdot
.77133 .40951 Mdot
.48978 .31879 Mdot
.4263 .64015 Mdot
.37056 .42293 Mdot
.52325 .62217 Mdot
.42422 .60979 Mdot
.62634 .80636 Mdot
.401 .57124 Mdot
.39162 .7631 Mdot
.36877 .66842 Mdot
.19677 .38023 Mdot
.51451 .41043 Mdot
.40325 .60404 Mdot
.52844 .69744 Mdot
.32225 .72061 Mdot
.52247 .56175 Mdot
.6299 .46062 Mdot
.48395 .3022 Mdot
.50739 .32319 Mdot
.61222 .48467 Mdot
.49518 .60711 Mdot
.41792 .70563 Mdot
.48608 .57427 Mdot
.68946 .31358 Mdot
.60234 .65459 Mdot
.34595 .42727 Mdot
.62479 .6583 Mdot
.83446 .37846 Mdot
.73228 .60864 Mdot
.58041 .41971 Mdot
.38465 .38535 Mdot
.48381 .29102 Mdot
.68713 .3113 Mdot
.36339 .42256 Mdot
.43593 .58929 Mdot
.62596 .65148 Mdot
.34584 .75295 Mdot
.36682 .66222 Mdot
.26501 .71279 Mdot
.65702 .60723 Mdot
.48451 .43861 Mdot
.62001 .4574 Mdot
.53292 .32062 Mdot
.40842 .63834 Mdot
.45735 .6008 Mdot
.58635 .60323 Mdot
.42544 .583 Mdot
.64961 .6937 Mdot
.38763 .57834 Mdot
.48076 .37836 Mdot
.38426 .45121 Mdot
.62874 .48136 Mdot
.27997 .6181 Mdot
.64382 .66868 Mdot
.5088 .25232 Mdot
.52342 .31905 Mdot
.49742 .67923 Mdot
.59565 .4437 Mdot
.39381 .4126 Mdot
.51209 .3039 Mdot
.34266 .39739 Mdot
.40303 .65246 Mdot
.51807 .32697 Mdot
.34745 .41703 Mdot
.29104 .32149 Mdot
.37175 .59033 Mdot
.2921 .42685 Mdot
.61753 .42813 Mdot
.67456 .62208 Mdot
.40652 .58511 Mdot
.69235 .29461 Mdot
.37272 .64112 Mdot
.67183 .3613 Mdot
.71169 .3089 Mdot
.70588 .3216 Mdot
.57416 .20113 Mdot
.38153 .39529 Mdot
.75238 .45185 Mdot
.63003 .53612 Mdot
.60371 .61037 Mdot
.37551 .60913 Mdot
.24565 .30077 Mdot
.60817 .44978 Mdot
.43604 .59207 Mdot
.47584 .38008 Mdot
.60715 .4457 Mdot
.44756 .62396 Mdot
.63653 .46315 Mdot
.64518 .63285 Mdot
.45623 .26839 Mdot
.63889 .59223 Mdot
.37557 .58399 Mdot
.63683 .43407 Mdot
.50566 .30611 Mdot
.62822 .62212 Mdot
.41713 .59712 Mdot
.41744 .63636 Mdot
.69513 .30816 Mdot
.39825 .60036 Mdot
.2522 .3018 Mdot
.42057 .57397 Mdot
.4707 .30281 Mdot
.47556 .63317 Mdot
.54613 .85091 Mdot
.32786 .32643 Mdot
.60135 .62407 Mdot
.70903 .31566 Mdot
.50281 .34047 Mdot
.44119 .27385 Mdot
.54817 .55089 Mdot
.41212 .60736 Mdot
.70543 .31065 Mdot
.45838 .42308 Mdot
.61967 .40727 Mdot
.45736 .65167 Mdot
.74294 .58835 Mdot
.51425 .30158 Mdot
.68933 .31075 Mdot
.35306 .57281 Mdot
.60392 .59389 Mdot
.37771 .59752 Mdot
.51663 .3161 Mdot
.67168 .61539 Mdot
.36483 .59593 Mdot
.22887 .46104 Mdot
.70663 .2973 Mdot
.61693 .42954 Mdot
.39439 .69465 Mdot
.44559 .5814 Mdot
.50373 .31527 Mdot
.66087 .62092 Mdot
.63361 .41897 Mdot
.61695 .62209 Mdot
.3277 .73295 Mdot
.77869 .42721 Mdot
.25957 .38549 Mdot
.38837 .3875 Mdot
.67489 .35328 Mdot
.18997 .41224 Mdot
.77048 .46694 Mdot
.2848 .53343 Mdot
.16272 .53055 Mdot
.4975 .29777 Mdot
.32496 .45034 Mdot
.50044 .33508 Mdot
.38884 .62056 Mdot
.48769 .34748 Mdot
.19467 .37331 Mdot
.40226 .56894 Mdot
.49296 .3178 Mdot
.40052 .34412 Mdot
.40154 .58036 Mdot
.60666 .62151 Mdot
.47083 .17828 Mdot
.77061 .63894 Mdot
.71582 .63057 Mdot
.48646 .31346 Mdot
.6544 .75226 Mdot
.41149 .57354 Mdot
.38629 .55524 Mdot
.6471 .62696 Mdot
.47284 .64107 Mdot
.35687 .43644 Mdot
.34342 .39247 Mdot
.29725 .64679 Mdot
.82903 .47084 Mdot
.50102 .61321 Mdot
.63223 .62302 Mdot
.64601 .70428 Mdot
.74181 .53005 Mdot
.67605 .3105 Mdot
.60269 .40268 Mdot
.31659 .24985 Mdot
.48954 .65551 Mdot
.58935 .53971 Mdot
.7452 .57495 Mdot
.62657 .64771 Mdot
.27282 .31686 Mdot
.63383 .45069 Mdot
.56186 .68033 Mdot
.44995 .76942 Mdot
.44927 .59219 Mdot
.59669 .42521 Mdot
.43754 .54163 Mdot
.74584 .64292 Mdot
.32882 .47082 Mdot
.68835 .26637 Mdot
.37118 .5965 Mdot
.75279 .46576 Mdot
.4277 .62298 Mdot
.30487 .5986 Mdot
.42309 .5725 Mdot
.61912 .61652 Mdot
.49659 .58071 Mdot
.48905 .4849 Mdot
.83717 .5208 Mdot
.73271 .62244 Mdot
.35296 .39394 Mdot
.41926 .63361 Mdot
.45199 .59502 Mdot
.36979 .3961 Mdot
.63553 .61271 Mdot
.42724 .57275 Mdot
.2359 .54614 Mdot
.44752 .58567 Mdot
.61177 .46619 Mdot
.41371 .45718 Mdot
.69861 .62383 Mdot
.4684 .6209 Mdot
.64072 .59003 Mdot
.63659 .45828 Mdot
.63639 .41161 Mdot
.4498 .67437 Mdot
.63491 .46956 Mdot
.37799 .59319 Mdot
.42148 .42904 Mdot
.66191 .63954 Mdot
.33708 .60048 Mdot
.63844 .60981 Mdot
.67758 .7209 Mdot
.64051 .45701 Mdot
.68176 .3063 Mdot
.55417 .58711 Mdot
.63163 .44339 Mdot
.71719 .68175 Mdot
.50423 .63398 Mdot
.36023 .62432 Mdot
.73815 .66884 Mdot
.49117 .3047 Mdot
.68275 .31097 Mdot
.63939 .43395 Mdot
.4489 .58348 Mdot
.41693 .65951 Mdot
.59797 .45903 Mdot
.5785 .7331 Mdot
.43065 .28944 Mdot
.4153 .56856 Mdot
.62375 .61372 Mdot
.62286 .63813 Mdot
.36418 .60653 Mdot
.42229 .60098 Mdot
.47189 .3042 Mdot
.70552 .30191 Mdot
.68647 .32569 Mdot
.69206 .29662 Mdot
.53642 .33913 Mdot
.69984 .40655 Mdot
.64548 .45265 Mdot
.69821 .47196 Mdot
.60538 .36042 Mdot
.39905 .67523 Mdot
.50241 .31123 Mdot
.45751 .61599 Mdot
.39083 .63182 Mdot
.63225 .41887 Mdot
.74456 .35816 Mdot
.37312 .53369 Mdot
.64475 .65823 Mdot
.6306 .47292 Mdot
.47893 .67688 Mdot
.60065 .38486 Mdot
.35683 .43384 Mdot
.71958 .64614 Mdot
.59452 .43123 Mdot
.61378 .64035 Mdot
.59756 .46349 Mdot
.45146 .59173 Mdot
.43877 .56363 Mdot
.64263 .64685 Mdot
.37951 .39289 Mdot
.42231 .66209 Mdot
.44615 .6252 Mdot
.65999 .81619 Mdot
.74701 .52437 Mdot
.65255 .40681 Mdot
.39439 .60987 Mdot
.37027 .64987 Mdot
.35786 .38899 Mdot
.44331 .58454 Mdot
.41138 .63996 Mdot
.79161 .54734 Mdot
.64102 .48963 Mdot
.3874 .44279 Mdot
.56139 .67692 Mdot
.65428 .60549 Mdot
.2777 .28208 Mdot
.69683 .32166 Mdot
.64271 .48126 Mdot
.45762 .26865 Mdot
.68905 .30313 Mdot
.63109 .35645 Mdot
.27655 .29862 Mdot
.68704 .30089 Mdot
.46938 .2695 Mdot
.44461 .52264 Mdot
.42681 .56427 Mdot
.43526 .62086 Mdot
.37216 .42595 Mdot
.65092 .63733 Mdot
.49471 .4215 Mdot
.32092 .29149 Mdot
.42121 .62642 Mdot
.5688 .6189 Mdot
.31255 .27456 Mdot
.69246 .30679 Mdot
.38443 .41128 Mdot
.35231 .43759 Mdot
.4286 .62618 Mdot
.79226 .50538 Mdot
.62766 .6244 Mdot
.4172 .59759 Mdot
.46564 .60655 Mdot
.48879 .3111 Mdot
.6153 .64538 Mdot
.52386 .32181 Mdot
.71137 .30454 Mdot
.20165 .60638 Mdot
.63312 .82893 Mdot
.62181 .41804 Mdot
.2183 .37421 Mdot
.64589 .41542 Mdot
.64965 .22827 Mdot
.69748 .29584 Mdot
.41818 .61155 Mdot
.62963 .66758 Mdot
.41479 .59376 Mdot
.44362 .59579 Mdot
.43785 .58911 Mdot
.5012 .60585 Mdot
.61783 .81223 Mdot
.3637 .4124 Mdot
.39558 .66988 Mdot
.46768 .33873 Mdot
.23813 .33543 Mdot
.46609 .19219 Mdot
.4581 .62646 Mdot
.42852 .62997 Mdot
.61436 .60391 Mdot
.46575 .58474 Mdot
.60375 .40951 Mdot
.66405 .6254 Mdot
.40993 .65917 Mdot
.26449 .33378 Mdot
.43278 .57326 Mdot
.1899 .42172 Mdot
.59778 .46284 Mdot
.71758 .64691 Mdot
.40952 .67172 Mdot
.68616 .30086 Mdot
.68282 .31003 Mdot
.67329 .32146 Mdot
.59353 .41732 Mdot
.49781 .3152 Mdot
.41658 .23071 Mdot
.46257 .56322 Mdot
.38635 .60192 Mdot
.37476 .6533 Mdot
.53158 .30793 Mdot
.42928 .46648 Mdot
.74121 .4154 Mdot
.49053 .66204 Mdot
.46992 .32259 Mdot
.6769 .63131 Mdot
.80369 .37128 Mdot
.6629 .62426 Mdot
.38683 .4442 Mdot
.60309 .45536 Mdot
.36362 .43648 Mdot
.64646 .77476 Mdot
.64888 .64681 Mdot
.58773 .60154 Mdot
.49106 .3175 Mdot
.51166 .44253 Mdot
.30953 .18059 Mdot
.50203 .36167 Mdot
.25629 .5636 Mdot
.64358 .62335 Mdot
.46409 .63421 Mdot
.45033 .42105 Mdot
.50842 .44739 Mdot
.49224 .33005 Mdot
.40917 .62163 Mdot
.82406 .49326 Mdot
.47341 .30118 Mdot
.45189 .65403 Mdot
.47734 .32547 Mdot
.61813 .46367 Mdot
.47908 .33078 Mdot
.664 .657 Mdot
.39902 .6482 Mdot
.37592 .13081 Mdot
.55246 .44889 Mdot
.40829 .58812 Mdot
.63073 .4727 Mdot
.22552 .5517 Mdot
.44874 .60498 Mdot
.36319 .43872 Mdot
.47523 .34939 Mdot
.41535 .29513 Mdot
.41161 .57561 Mdot
.48505 .33513 Mdot
.66411 .65118 Mdot
.66068 .43828 Mdot
.58936 .19792 Mdot
.6825 .3203 Mdot
.65443 .63169 Mdot
.68429 .33656 Mdot
.58431 .4311 Mdot
.44562 .65232 Mdot
.46222 .59705 Mdot
.61489 .61329 Mdot
.58646 .24561 Mdot
.47427 .60011 Mdot
.40948 .61601 Mdot
.49282 .28774 Mdot
.50495 .27852 Mdot
.54039 .23029 Mdot
.49778 .29886 Mdot
.37502 .65498 Mdot
.6148 .61438 Mdot
.38636 .62503 Mdot
.60501 .62183 Mdot
.37586 .60879 Mdot
.6431 .68145 Mdot
.66098 .62962 Mdot
.80018 .43798 Mdot
.39853 .62966 Mdot
.37837 .68165 Mdot
.44227 .59213 Mdot
.4331 .5803 Mdot
.48004 .35806 Mdot
.3671 .40119 Mdot
.48647 .61386 Mdot
.51205 .2589 Mdot
.38719 .41748 Mdot
.35034 .73559 Mdot
.48776 .30981 Mdot
.37293 .42926 Mdot
.28644 .40148 Mdot
.70699 .31835 Mdot
.37092 .41569 Mdot
.45172 .19924 Mdot
.62533 .41798 Mdot
.66832 .61684 Mdot
.40056 .58126 Mdot
.17488 .57326 Mdot
.40271 .46388 Mdot
.70051 .30603 Mdot
.41362 .58049 Mdot
.45565 .61284 Mdot
.60483 .59665 Mdot
.85168 .41579 Mdot
.49337 .28249 Mdot
.38229 .60914 Mdot
.62576 .59336 Mdot
.8425 .55898 Mdot
.48879 .36049 Mdot
.37281 .41925 Mdot
.60697 .46789 Mdot
.68164 .61088 Mdot
.68174 .32059 Mdot
.62104 .40657 Mdot
.4358 .33262 Mdot
.67182 .75343 Mdot
.41936 .57915 Mdot
.5086 .31452 Mdot
.54449 .83922 Mdot
.49196 .59525 Mdot
.67386 .45363 Mdot
.33448 .69228 Mdot
.62305 .64574 Mdot
.60272 .4649 Mdot
.34198 .40985 Mdot
.66742 .6324 Mdot
.63346 .61355 Mdot
.64766 .42726 Mdot
.5309 .36961 Mdot
.48757 .44022 Mdot
.60336 .46223 Mdot
.7618 .60222 Mdot
.34603 .74735 Mdot
.70658 .30794 Mdot
.38434 .40464 Mdot
.36886 .78233 Mdot
.62315 .62878 Mdot
.31452 .25102 Mdot
.59984 .81683 Mdot
.41176 .56618 Mdot
.35373 .42595 Mdot
.63279 .37012 Mdot
.40063 .23303 Mdot
.60662 .44087 Mdot
.45035 .47271 Mdot
.37168 .44172 Mdot
.42711 .56747 Mdot
.69163 .59681 Mdot
.3989 .62433 Mdot
.61038 .45916 Mdot
.69405 .68945 Mdot
.61116 .63748 Mdot
.58423 .44059 Mdot
.7207 .67113 Mdot
.39202 .6339 Mdot
.40368 .62601 Mdot
.31276 .5531 Mdot
.627 .65244 Mdot
.68305 .32444 Mdot
.41032 .60016 Mdot
.44294 .61888 Mdot
.45131 .6491 Mdot
.44324 .695 Mdot
.78203 .51581 Mdot
.38329 .61317 Mdot
.52675 .35393 Mdot
.36256 .58084 Mdot
.40356 .6297 Mdot
.62744 .59069 Mdot
.64083 .8169 Mdot
.70539 .29267 Mdot
.43554 .61787 Mdot
.42562 .57479 Mdot
.64327 .42393 Mdot
.47265 .42959 Mdot
.51272 .45295 Mdot
.51475 .34978 Mdot
.29263 .50419 Mdot
.49677 .59599 Mdot
.63979 .60073 Mdot
.39418 .42187 Mdot
.43077 .64859 Mdot
.63086 .59728 Mdot
.38665 .56079 Mdot
.47168 .30903 Mdot
.70557 .30453 Mdot
.67223 .566 Mdot
.37598 .41298 Mdot
.47077 .40019 Mdot
.69179 .50541 Mdot
.48561 .29902 Mdot
.38828 .5956 Mdot
.65662 .45207 Mdot
.51945 .33538 Mdot
.69691 .30888 Mdot
.34726 .58627 Mdot
.63737 .62928 Mdot
.61184 .63265 Mdot
.29718 .63295 Mdot
.47488 .28093 Mdot
.77603 .6888 Mdot
.6168 .46324 Mdot
.38562 .6486 Mdot
.64921 .51702 Mdot
.61029 .63069 Mdot
.29282 .63066 Mdot
.37492 .42839 Mdot
.60692 .43844 Mdot
.67667 .30341 Mdot
.62486 .59865 Mdot
.61651 .65104 Mdot
.36922 .59902 Mdot
.44424 .63549 Mdot
.27884 .5421 Mdot
.29493 .64419 Mdot
.62965 .46525 Mdot
.38036 .39857 Mdot
.52422 .3417 Mdot
.39217 .62009 Mdot
.6635 .63176 Mdot
.38174 .75683 Mdot
.44568 .57827 Mdot
.47263 .30159 Mdot
.62878 .64648 Mdot
.37207 .39489 Mdot
.37956 .43268 Mdot
.4335 .58057 Mdot
.56192 .79987 Mdot
.63184 .4363 Mdot
.60759 .62631 Mdot
.59935 .57192 Mdot
.47854 .61396 Mdot
.43846 .6376 Mdot
.37772 .54441 Mdot
.62475 .40816 Mdot
.69284 .59104 Mdot
.39625 .42619 Mdot
.63604 .63553 Mdot
.40995 .58987 Mdot
.37972 .41189 Mdot
.61862 .55595 Mdot
.69518 .29905 Mdot
.47735 .33067 Mdot
.35617 .43689 Mdot
.35424 .40356 Mdot
.38924 .4161 Mdot
.33205 .23682 Mdot
.60328 .65411 Mdot
.62867 .69706 Mdot
.42379 .57136 Mdot
.29858 .62837 Mdot
.45487 .56771 Mdot
.58995 .42321 Mdot
.49477 .30193 Mdot
.44658 .59578 Mdot
.36907 .60127 Mdot
.36358 .69288 Mdot
.44215 .69139 Mdot
.5854 .59359 Mdot
.63862 .65202 Mdot
.41662 .69313 Mdot
.49239 .30723 Mdot
.87277 .45582 Mdot
.23651 .28074 Mdot
.4264 .67166 Mdot
.49296 .43068 Mdot
.66339 .62876 Mdot
.65014 .43376 Mdot
.51347 .46417 Mdot
.61149 .47372 Mdot
.63352 .63827 Mdot
.3902 .62002 Mdot
.70074 .47219 Mdot
.35578 .38587 Mdot
.45372 .58759 Mdot
.6165 .45558 Mdot
.45245 .58691 Mdot
.59193 .42707 Mdot
.59228 .66953 Mdot
.75322 .57725 Mdot
.40232 .57037 Mdot
.47481 .62474 Mdot
.37213 .69136 Mdot
.45612 .62829 Mdot
.63907 .30662 Mdot
.64639 .61519 Mdot
.82611 .47893 Mdot
.36567 .59772 Mdot
.60097 .77248 Mdot
.43774 .57151 Mdot
.58921 .26042 Mdot
.44427 .63891 Mdot
.52094 .49189 Mdot
.41996 .56499 Mdot
.42126 .63919 Mdot
.63796 .43806 Mdot
.64376 .42406 Mdot
.65895 .65461 Mdot
.68034 .32255 Mdot
.20295 .37424 Mdot
.44373 .63074 Mdot
.5295 .35362 Mdot
.6303 .51656 Mdot
.35913 .40093 Mdot
.62992 .63634 Mdot
.84775 .57401 Mdot
.63741 .46031 Mdot
.46956 .36444 Mdot
.60377 .26232 Mdot
.52976 .31694 Mdot
.61272 .49972 Mdot
.49265 .66975 Mdot
.37111 .39229 Mdot
.43387 .56918 Mdot
.43378 .80164 Mdot
.74595 .49482 Mdot
.41366 .66374 Mdot
.59412 .46596 Mdot
.52718 .61241 Mdot
.37689 .78171 Mdot
.339 .41906 Mdot
.34607 .40309 Mdot
.63823 .44314 Mdot
.50432 .28968 Mdot
.46646 .55634 Mdot
.37383 .42979 Mdot
.47633 .30786 Mdot
.67985 .32757 Mdot
.53365 .54364 Mdot
.6273 .62699 Mdot
.7126 .6183 Mdot
.70378 .53403 Mdot
.63111 .46461 Mdot
.50136 .25624 Mdot
.68055 .6203 Mdot
.59389 .60327 Mdot
.67857 .31456 Mdot
.47869 .35772 Mdot
.62202 .66666 Mdot
.42989 .65952 Mdot
.38004 .67497 Mdot
.42634 .62231 Mdot
.36272 .42746 Mdot
.4576 .63161 Mdot
.47028 .34492 Mdot
.60962 .44494 Mdot
.51211 .34007 Mdot
.63159 .43115 Mdot
.71332 .44345 Mdot
.42286 .59503 Mdot
.42572 .63638 Mdot
.42882 .42207 Mdot
.63077 .65836 Mdot
.60018 .80439 Mdot
.52813 .357 Mdot
.5004 .3278 Mdot
.38739 .6332 Mdot
.66658 .64782 Mdot
.36373 .45569 Mdot
.43376 .40741 Mdot
.46494 .62025 Mdot
.64764 .61533 Mdot
.38358 .6056 Mdot
.28154 .36753 Mdot
.75572 .56076 Mdot
.61499 .62383 Mdot
.84096 .47623 Mdot
.39728 .61485 Mdot
.46254 .52728 Mdot
.36925 .64968 Mdot
.24741 .52286 Mdot
.47919 .62066 Mdot
.65875 .60853 Mdot
.4302 .61799 Mdot
.65757 .6162 Mdot
.49227 .29098 Mdot
.6498 .44741 Mdot
.65447 .62913 Mdot
.46488 .62801 Mdot
.33284 .21902 Mdot
.6178 .46049 Mdot
.41704 .63463 Mdot
.60231 .42408 Mdot
.64122 .59558 Mdot
.63684 .65647 Mdot
.45847 .20326 Mdot
.66609 .436 Mdot
.62304 .46245 Mdot
.38131 .59608 Mdot
.68779 .55142 Mdot
.38634 .62283 Mdot
.2772 .55357 Mdot
.37325 .62462 Mdot
.47739 .6317 Mdot
.63395 .19104 Mdot
.65573 .43025 Mdot
.78656 .66648 Mdot
.31432 .30079 Mdot
.35085 .22237 Mdot
.69036 .62242 Mdot
.33906 .41943 Mdot
.27965 .30542 Mdot
.71142 .30718 Mdot
.47538 .34067 Mdot
.4464 .59466 Mdot
.68565 .67032 Mdot
.6131 .46807 Mdot
.36295 .40363 Mdot
.40111 .57088 Mdot
.46884 .31237 Mdot
.49703 .21227 Mdot
.63564 .47026 Mdot
.62461 .63031 Mdot
.63694 .65857 Mdot
.83461 .56249 Mdot
.4114 .58625 Mdot
.42326 .63361 Mdot
.6044 .45613 Mdot
.49383 .6178 Mdot
.38977 .40238 Mdot
.36023 .34688 Mdot
.62485 .46116 Mdot
.56312 .46897 Mdot
.65062 .64877 Mdot
.45663 .61339 Mdot
.41722 .47097 Mdot
.56561 .31722 Mdot
.48412 .70654 Mdot
.37074 .42509 Mdot
.29229 .54572 Mdot
.65828 .60809 Mdot
.61612 .44836 Mdot
.30167 .4022 Mdot
.37498 .64188 Mdot
.45335 .61562 Mdot
.29525 .54679 Mdot
.46779 .42443 Mdot
.34797 .44832 Mdot
.46585 .58318 Mdot
.45981 .42837 Mdot
.3887 .63661 Mdot
.41441 .659 Mdot
.46657 .65992 Mdot
.4272 .64326 Mdot
.65311 .61764 Mdot
.36672 .69667 Mdot
.48158 .33789 Mdot
.55369 .71787 Mdot
.46586 .47068 Mdot
.40171 .59185 Mdot
.39053 .62311 Mdot
.50235 .68208 Mdot
.59896 .50008 Mdot
.64402 .61742 Mdot
.60031 .65837 Mdot
.64273 .44899 Mdot
.37559 .67701 Mdot
.51977 .2962 Mdot
.33855 .69118 Mdot
.51013 .34413 Mdot
.64809 .61452 Mdot
.50278 .32162 Mdot
.64381 .44221 Mdot
.50945 .31508 Mdot
.53535 .34173 Mdot
.59266 .44887 Mdot
.65505 .64837 Mdot
.46333 .62202 Mdot
.64084 .45844 Mdot
.30897 .55589 Mdot
.3636 .4282 Mdot
.45842 .20291 Mdot
.36628 .57096 Mdot
.35765 .53126 Mdot
.22983 .45943 Mdot
.512 .33533 Mdot
.76766 .55954 Mdot
.66073 .62989 Mdot
.38732 .39046 Mdot
.65582 .61829 Mdot
.62504 .80042 Mdot
.37201 .39836 Mdot
.44904 .19994 Mdot
.34558 .36993 Mdot
.44088 .24805 Mdot
.45607 .57304 Mdot
.60653 .67189 Mdot
.52164 .32881 Mdot
.61644 .46882 Mdot
.47967 .38881 Mdot
.4127 .64487 Mdot
.77058 .45791 Mdot
.59356 .62841 Mdot
.69494 .32585 Mdot
.61779 .4416 Mdot
.59535 .47006 Mdot
.41564 .58519 Mdot
.4575 .25938 Mdot
.38766 .6439 Mdot
.31598 .42302 Mdot
.29178 .52615 Mdot
.33891 .69308 Mdot
.37647 .59563 Mdot
.51313 .3464 Mdot
.3833 .60356 Mdot
.51322 .58552 Mdot
.45 .82327 Mdot
.35506 .58702 Mdot
.78671 .42691 Mdot
.42541 .38237 Mdot
.64596 .64545 Mdot
.4193 .67398 Mdot
.69883 .31522 Mdot
.39565 .61229 Mdot
.25438 .74551 Mdot
.37081 .4126 Mdot
.45052 .30875 Mdot
.46512 .58777 Mdot
.41203 .59602 Mdot
.47881 .80863 Mdot
.67075 .68338 Mdot
.679 .29932 Mdot
.44967 .61506 Mdot
.30685 .49841 Mdot
.62326 .41074 Mdot
.37311 .63318 Mdot
.4325 .62231 Mdot
.3167 .72024 Mdot
.60953 .4115 Mdot
.51187 .32947 Mdot
.71117 .31145 Mdot
.52448 .34365 Mdot
.35174 .44166 Mdot
.52704 .46901 Mdot
.29333 .65252 Mdot
.75317 .55835 Mdot
.37032 .43969 Mdot
.46503 .59681 Mdot
.3984 .51288 Mdot
.40515 .61071 Mdot
.34432 .40475 Mdot
.60204 .41328 Mdot
.65283 .62174 Mdot
.66832 .56024 Mdot
.69075 .3124 Mdot
.45089 .65393 Mdot
.33936 .4092 Mdot
.64533 .63011 Mdot
.54658 .25741 Mdot
.6433 .63975 Mdot
.63107 .4479 Mdot
.58787 .42333 Mdot
.37526 .40315 Mdot
.65436 .61657 Mdot
.51905 .35876 Mdot
.31802 .29806 Mdot
.37471 .62195 Mdot
.62606 .38887 Mdot
.65278 .66445 Mdot
.65377 .5915 Mdot
.60076 .64304 Mdot
.42284 .58756 Mdot
.48196 .43086 Mdot
.39057 .65844 Mdot
.63867 .44947 Mdot
.47465 .32266 Mdot
.29803 .66787 Mdot
.48589 .8165 Mdot
.55802 .46042 Mdot
.48549 .61715 Mdot
.40865 .63598 Mdot
.42836 .62623 Mdot
.39261 .56844 Mdot
.30463 .36066 Mdot
.42321 .59857 Mdot
.63555 .43421 Mdot
.49544 .35573 Mdot
.4102 .5821 Mdot
.69978 .31679 Mdot
.47765 .44603 Mdot
.39064 .42779 Mdot
.5036 .47673 Mdot
.28182 .25561 Mdot
.646 .62904 Mdot
.51201 .30639 Mdot
.47748 .34314 Mdot
.39083 .42044 Mdot
.62409 .46733 Mdot
.64764 .6379 Mdot
.24784 .49734 Mdot
.38825 .40791 Mdot
.43551 .61682 Mdot
.43005 .34898 Mdot
.82882 .43213 Mdot
.45406 .57642 Mdot
.43999 .60088 Mdot
.70886 .31768 Mdot
.51095 .29152 Mdot
.17181 .60443 Mdot
.46466 .41292 Mdot
.37028 .40183 Mdot
.35034 .40241 Mdot
.59974 .64329 Mdot
.42318 .66572 Mdot
.62728 .43012 Mdot
.44126 .42294 Mdot
.23741 .58529 Mdot
.52752 .38891 Mdot
.64021 .22504 Mdot
.43723 .57736 Mdot
.48072 .80031 Mdot
.37871 .61388 Mdot
.60318 .59642 Mdot
.60129 .61672 Mdot
.63825 .61953 Mdot
.63604 .44612 Mdot
.67143 .72386 Mdot
.63443 .43007 Mdot
.26739 .26018 Mdot
.66629 .6214 Mdot
.36729 .28906 Mdot
.49781 .31969 Mdot
.47193 .57833 Mdot
.37658 .39426 Mdot
.56544 .46092 Mdot
.47307 .65681 Mdot
.78531 .50139 Mdot
.50293 .31174 Mdot
.64406 .65474 Mdot
.51035 .63054 Mdot
.16571 .43132 Mdot
.52293 .44516 Mdot
.4728 .52056 Mdot
.58439 .81049 Mdot
.37153 .39665 Mdot
.49977 .69481 Mdot
.38387 .39389 Mdot
.60717 .45053 Mdot
.41562 .64522 Mdot
.42715 .64511 Mdot
.37511 .60241 Mdot
.42457 .59678 Mdot
.63536 .42081 Mdot
.3772 .57602 Mdot
.54633 .85081 Mdot
.70851 .30995 Mdot
.28368 .33939 Mdot
.36625 .43432 Mdot
.59277 .45832 Mdot
.50218 .35196 Mdot
.68047 .32522 Mdot
.28135 .63141 Mdot
.41612 .56615 Mdot
.44404 .59378 Mdot
.68089 .30315 Mdot
.47518 .6505 Mdot
.4991 .64618 Mdot
.48303 .33984 Mdot
.55893 .47319 Mdot
.34462 .42754 Mdot
.36251 .43626 Mdot
.59314 .44202 Mdot
.65561 .61755 Mdot
.37451 .42639 Mdot
.4966 .28652 Mdot
.37815 .57195 Mdot
.44852 .64652 Mdot
.65259 .66428 Mdot
.6002 .81682 Mdot
.33671 .41248 Mdot
.50916 .6153 Mdot
.6572 .61128 Mdot
.59381 .6389 Mdot
.4512 .61262 Mdot
.36082 .56651 Mdot
.66779 .6048 Mdot
.37658 .43565 Mdot
.59372 .46078 Mdot
.4137 .25399 Mdot
.6102 .45658 Mdot
.64866 .63472 Mdot
.364 .5886 Mdot
.65336 .64864 Mdot
.39779 .60759 Mdot
.74257 .23307 Mdot
.43575 .64225 Mdot
.75997 .64935 Mdot
.25367 .53052 Mdot
.47963 .34794 Mdot
.52121 .35583 Mdot
.7044 .31233 Mdot
.65903 .61174 Mdot
.42678 .64952 Mdot
.35613 .39643 Mdot
.37549 .21561 Mdot
.65929 .67502 Mdot
.47142 .32087 Mdot
.51879 .29653 Mdot
.61109 .40857 Mdot
.44719 .57585 Mdot
.45666 .61987 Mdot
.51064 .3172 Mdot
.24321 .43402 Mdot
.63405 .6009 Mdot
.42245 .63304 Mdot
.40584 .63399 Mdot
.48265 .34625 Mdot
.3156 .30352 Mdot
.60916 .67686 Mdot
.42248 .6428 Mdot
.37925 .37053 Mdot
.59149 .42115 Mdot
.3893 .57205 Mdot
.37931 .57419 Mdot
.35116 .4119 Mdot
.25862 .35476 Mdot
.39734 .79814 Mdot
.58903 .44237 Mdot
.6842 .32444 Mdot
.46682 .62688 Mdot
.49635 .3208 Mdot
.46196 .63618 Mdot
.19354 .45934 Mdot
.70589 .31744 Mdot
.4201 .60672 Mdot
.43763 .67035 Mdot
.60601 .63674 Mdot
.41817 .60134 Mdot
.36365 .72734 Mdot
.51566 .35367 Mdot
.42007 .60404 Mdot
.57857 .80043 Mdot
.62186 .40909 Mdot
.43095 .67273 Mdot
.34507 .42082 Mdot
.24418 .52491 Mdot
.69495 .51669 Mdot
.53648 .31567 Mdot
.37316 .43373 Mdot
.46397 .62387 Mdot
.5053 .29146 Mdot
.61798 .4708 Mdot
.77335 .47768 Mdot
.41783 .56113 Mdot
.61278 .45973 Mdot
.61092 .44461 Mdot
.37505 .4073 Mdot
.803 .63357 Mdot
.48672 .63776 Mdot
.45777 .62787 Mdot
.27937 .6924 Mdot
.59549 .62437 Mdot
.46172 .62304 Mdot
.45666 .58452 Mdot
.62054 .42572 Mdot
.55655 .58385 Mdot
.55329 .64563 Mdot
.39984 .34478 Mdot
.59168 .42672 Mdot
.54097 .31419 Mdot
.50563 .29217 Mdot
.36687 .43367 Mdot
.6395 .64581 Mdot
.37959 .44018 Mdot
.48421 .32004 Mdot
.42617 .57392 Mdot
.61028 .4286 Mdot
.46327 .73499 Mdot
.65368 .44885 Mdot
.46484 .31968 Mdot
.62813 .58674 Mdot
.65824 .513 Mdot
.36758 .81088 Mdot
.71093 .52273 Mdot
.62531 .48945 Mdot
.35837 .40145 Mdot
.43286 .37609 Mdot
.40771 .63455 Mdot
.53526 .67461 Mdot
.46054 .60012 Mdot
.57692 .81076 Mdot
.4888 .30149 Mdot
.67782 .31356 Mdot
.4161 .64557 Mdot
.29716 .53109 Mdot
.61024 .48293 Mdot
.61444 .40756 Mdot
.43234 .59783 Mdot
.63211 .44466 Mdot
.44708 .6326 Mdot
.49215 .35808 Mdot
.779 .66067 Mdot
.41244 .63569 Mdot
.35623 .62807 Mdot
.65672 .47979 Mdot
.45651 .20213 Mdot
.50799 .37029 Mdot
.47894 .80211 Mdot
.15347 .46713 Mdot
.63089 .44238 Mdot
.37688 .65876 Mdot
.51843 .32261 Mdot
.70852 .31853 Mdot
.48667 .37172 Mdot
.45541 .59349 Mdot
.43884 .58291 Mdot
.38627 .63179 Mdot
.403 .62578 Mdot
.53125 .67206 Mdot
.47068 .67741 Mdot
.4904 .78586 Mdot
.4428 .59464 Mdot
.65796 .57256 Mdot
.63623 .42798 Mdot
.5866 .5934 Mdot
.34548 .38329 Mdot
.43269 .57642 Mdot
.68532 .67579 Mdot
.59113 .45016 Mdot
.26544 .26416 Mdot
.61006 .40987 Mdot
.50241 .34231 Mdot
.65113 .42763 Mdot
.39854 .60206 Mdot
.62149 .63746 Mdot
.50664 .35858 Mdot
.73414 .4204 Mdot
.47425 .33907 Mdot
.40861 .5875 Mdot
.31258 .32279 Mdot
.47772 .34101 Mdot
.48353 .45436 Mdot
.62464 .64145 Mdot
.31387 .49694 Mdot
.60675 .60575 Mdot
.41649 .6075 Mdot
.41375 .61133 Mdot
.68473 .32965 Mdot
.64099 .46717 Mdot
.64788 .59802 Mdot
.66906 .81058 Mdot
.36955 .44659 Mdot
.63009 .61876 Mdot
.44144 .55137 Mdot
.47896 .42563 Mdot
.61049 .62216 Mdot
.27617 .48986 Mdot
.62265 .46858 Mdot
.61254 .66007 Mdot
.41587 .54433 Mdot
.58011 .54102 Mdot
.36975 .38458 Mdot
.46627 .32333 Mdot
.56412 .51496 Mdot
.52263 .33081 Mdot
.58727 .44398 Mdot
.47694 .28434 Mdot
.62524 .41222 Mdot
.71379 .68405 Mdot
.64995 .69479 Mdot
.65047 .46324 Mdot
.58532 .42889 Mdot
.48838 .32395 Mdot
.40564 .56618 Mdot
.47494 .48596 Mdot
.47775 .60131 Mdot
.44392 .56471 Mdot
.62856 .41093 Mdot
.64041 .59733 Mdot
.67124 .62423 Mdot
.58235 .65103 Mdot
.62855 .6568 Mdot
.50432 .35248 Mdot
.76397 .57204 Mdot
.63869 .78073 Mdot
.59533 .43981 Mdot
.59887 .39915 Mdot
.38724 .62286 Mdot
.49342 .32125 Mdot
.49092 .2936 Mdot
.6182 .43057 Mdot
.50573 .70918 Mdot
.3675 .64502 Mdot
.61282 .59422 Mdot
.66657 .62332 Mdot
.61405 .61808 Mdot
.61046 .65268 Mdot
.62442 .71283 Mdot
.61737 .46928 Mdot
.66302 .61637 Mdot
.42797 .60217 Mdot
.44483 .58529 Mdot
.68433 .31687 Mdot
.35174 .43107 Mdot
.39332 .5556 Mdot
.35367 .59608 Mdot
.45244 .61156 Mdot
.47711 .33248 Mdot
.34624 .57302 Mdot
.69717 .32267 Mdot
.48623 .28143 Mdot
.53101 .30925 Mdot
.68182 .30695 Mdot
.56662 .59662 Mdot
.15559 .44014 Mdot
.38244 .6092 Mdot
.41661 .49807 Mdot
.49582 .3264 Mdot
.78893 .57892 Mdot
.65414 .56563 Mdot
.37728 .59161 Mdot
.54759 .54198 Mdot
.49931 .36084 Mdot
.59355 .62253 Mdot
.46235 .61143 Mdot
.69706 .29495 Mdot
.3926 .42387 Mdot
.44396 .55167 Mdot
.71143 .31345 Mdot
.64777 .61238 Mdot
.35081 .46325 Mdot
.60495 .65366 Mdot
.49262 .36296 Mdot
.43859 .67159 Mdot
.31732 .17269 Mdot
.52208 .31724 Mdot
.37322 .22723 Mdot
.6299 .68985 Mdot
.41385 .63808 Mdot
.52385 .32293 Mdot
.59489 .61334 Mdot
.59227 .41734 Mdot
.45171 .43458 Mdot
.66127 .63521 Mdot
.67901 .32251 Mdot
.68449 .31055 Mdot
.48198 .34152 Mdot
.6312 .65066 Mdot
.36714 .61846 Mdot
.60292 .62405 Mdot
.65143 .42604 Mdot
.38992 .57993 Mdot
.19455 .38254 Mdot
.3904 .68045 Mdot
.65205 .60504 Mdot
.47315 .29856 Mdot
.36236 .38727 Mdot
.40685 .57027 Mdot
.32962 .26277 Mdot
.45291 .57979 Mdot
.60368 .418 Mdot
.81434 .51923 Mdot
.44612 .73377 Mdot
.42116 .57144 Mdot
.3888 .62413 Mdot
.59415 .4525 Mdot
.41306 .5671 Mdot
.45314 .57691 Mdot
.67239 .45138 Mdot
.60788 .63678 Mdot
.42357 .62202 Mdot
.48038 .30033 Mdot
.47655 .82235 Mdot
.46789 .62624 Mdot
.7775 .40489 Mdot
.30987 .50974 Mdot
.81007 .54551 Mdot
.45723 .63734 Mdot
.30552 .56996 Mdot
.41307 .61861 Mdot
.42386 .58141 Mdot
.37922 .6024 Mdot
.46283 .79062 Mdot
.48821 .32002 Mdot
.46866 .3324 Mdot
.37125 .38411 Mdot
.30737 .50878 Mdot
.3532 .42383 Mdot
.59193 .43337 Mdot
.57416 .20424 Mdot
.70754 .31316 Mdot
.65658 .61762 Mdot
.3997 .65024 Mdot
.49328 .36493 Mdot
.45702 .60852 Mdot
.39573 .6052 Mdot
.4931 .36075 Mdot
.51867 .30535 Mdot
.46083 .29128 Mdot
.38467 .39612 Mdot
.64726 .62263 Mdot
.37094 .59223 Mdot
.38706 .41712 Mdot
.36759 .62339 Mdot
.46636 .41802 Mdot
.64559 .62032 Mdot
.60278 .62635 Mdot
.65008 .5961 Mdot
.42743 .57362 Mdot
.3993 .59476 Mdot
.63358 .42859 Mdot
.65741 .663 Mdot
.59747 .4516 Mdot
.52039 .33527 Mdot
.50962 .36323 Mdot
.45489 .59287 Mdot
.51164 .61601 Mdot
.35249 .40129 Mdot
.50641 .33943 Mdot
.68157 .30096 Mdot
.37883 .38687 Mdot
.41447 .58045 Mdot
.51448 .34369 Mdot
.36089 .43677 Mdot
.5213 .72265 Mdot
.15634 .49921 Mdot
.35423 .38945 Mdot
.43187 .59986 Mdot
.48722 .81226 Mdot
.30687 .43197 Mdot
.37789 .44526 Mdot
.59816 .43519 Mdot
.45135 .5802 Mdot
.21047 .53715 Mdot
.36427 .442 Mdot
.57964 .81768 Mdot
.48171 .35037 Mdot
.54868 .58166 Mdot
.40559 .54411 Mdot
.54852 .6854 Mdot
.37818 .44223 Mdot
.6422 .63674 Mdot
.6668 .66033 Mdot
.43392 .60918 Mdot
.36506 .37372 Mdot
.63272 .40772 Mdot
.48103 .35339 Mdot
.52781 .35459 Mdot
.62362 .64878 Mdot
.71542 .56774 Mdot
.47718 .29945 Mdot
.4894 .57363 Mdot
.44927 .28074 Mdot
.34957 .64774 Mdot
.7044 .69594 Mdot
.7262 .42126 Mdot
.44192 .65016 Mdot
.35235 .39246 Mdot
.6055 .4722 Mdot
.63422 .43472 Mdot
.62999 .45366 Mdot
.52697 .34713 Mdot
.51179 .46682 Mdot
.50297 .30897 Mdot
.76451 .46753 Mdot
.37985 .41255 Mdot
.3083 .47655 Mdot
.42853 .64797 Mdot
.41032 .63566 Mdot
.36443 .6188 Mdot
.39047 .64355 Mdot
.41368 .62083 Mdot
.62713 .46483 Mdot
.53179 .33184 Mdot
.41267 .3009 Mdot
.6233 .61229 Mdot
.55828 .2497 Mdot
.49809 .31952 Mdot
.70885 .31643 Mdot
.36212 .4106 Mdot
.30578 .59259 Mdot
.50507 .2764 Mdot
.50261 .32283 Mdot
.38869 .56279 Mdot
.61544 .60157 Mdot
.47254 .68584 Mdot
.40943 .61656 Mdot
.5085 .33802 Mdot
.51583 .3852 Mdot
.46461 .70826 Mdot
.38838 .53195 Mdot
.37704 .45539 Mdot
.48352 .42786 Mdot
.3985 .42058 Mdot
.36427 .56592 Mdot
.79039 .57496 Mdot
.48426 .32182 Mdot
.4955 .34519 Mdot
.34025 .41008 Mdot
.46319 .52959 Mdot
.63283 .64834 Mdot
.67749 .31299 Mdot
.60693 .42051 Mdot
.40744 .61067 Mdot
.52397 .34817 Mdot
.49007 .54122 Mdot
.43517 .29451 Mdot
.62482 .45942 Mdot
.48749 .28128 Mdot
.4379 .57243 Mdot
.4342 .59925 Mdot
.3683 .39674 Mdot
.43123 .4911 Mdot
.45969 .56386 Mdot
.34972 .22293 Mdot
.75104 .57563 Mdot
.7366 .60641 Mdot
.45347 .61596 Mdot
.61889 .64811 Mdot
.69507 .29682 Mdot
.38437 .40379 Mdot
.36694 .59066 Mdot
.15185 .48558 Mdot
.67877 .63206 Mdot
.61444 .45331 Mdot
.6907 .29804 Mdot
.50975 .46595 Mdot
.45513 .58173 Mdot
.46075 .60097 Mdot
.4237 .59196 Mdot
.14452 .5132 Mdot
.47225 .31458 Mdot
.60384 .64578 Mdot
.36802 .42521 Mdot
.61366 .65263 Mdot
.47047 .33501 Mdot
.6651 .55342 Mdot
.40927 .57933 Mdot
.61564 .59206 Mdot
.63961 .63796 Mdot
.60999 .40858 Mdot
.60586 .40562 Mdot
.46464 .28338 Mdot
.43499 .64197 Mdot
.702 .29441 Mdot
.60353 .61131 Mdot
.52384 .30715 Mdot
.37231 .39787 Mdot
.64141 .45335 Mdot
.44154 .59365 Mdot
.4821 .33037 Mdot
.43322 .66125 Mdot
.60914 .61639 Mdot
.50184 .32282 Mdot
.70988 .29552 Mdot
.34765 .40841 Mdot
.43987 .5868 Mdot
.35149 .45568 Mdot
.68135 .30478 Mdot
.40288 .63484 Mdot
.31809 .6784 Mdot
.33442 .38651 Mdot
.73659 .41635 Mdot
.5078 .30695 Mdot
.69288 .31898 Mdot
.59982 .6235 Mdot
.59993 .54893 Mdot
.496 .34821 Mdot
.31218 .644 Mdot
.46807 .49724 Mdot
.37272 .58802 Mdot
.6193 .6267 Mdot
.41621 .37193 Mdot
.29995 .2556 Mdot
.29394 .41126 Mdot
.42222 .63021 Mdot
.52405 .32513 Mdot
.36801 .43707 Mdot
.59504 .43572 Mdot
.77947 .40658 Mdot
.66366 .70392 Mdot
.48099 .28038 Mdot
.38118 .61084 Mdot
.6044 .61053 Mdot
.61717 .43221 Mdot
.70469 .45783 Mdot
.49121 .28595 Mdot
.49288 .29972 Mdot
.4152 .57648 Mdot
.37868 .4234 Mdot
.26273 .40566 Mdot
.46816 .33539 Mdot
.52666 .3405 Mdot
.55064 .24369 Mdot
.33997 .40282 Mdot
.42889 .60737 Mdot
.58305 .65195 Mdot
.40369 .56159 Mdot
.37715 .22117 Mdot
.69807 .32058 Mdot
.62432 .61061 Mdot
.44912 .58511 Mdot
.42526 .33562 Mdot
.50426 .34798 Mdot
.49431 .43199 Mdot
.46602 .30664 Mdot
.62678 .4664 Mdot
.52254 .35063 Mdot
.46087 .61292 Mdot
.60909 .48275 Mdot
.35128 .40357 Mdot
.42399 .64296 Mdot
.39835 .59445 Mdot
.59533 .60796 Mdot
.60558 .44895 Mdot
.3714 .76899 Mdot
.58418 .4225 Mdot
.59707 .46234 Mdot
.63136 .6722 Mdot
.43474 .61292 Mdot
.50277 .33727 Mdot
.46481 .33472 Mdot
.36684 .59879 Mdot
.78146 .5907 Mdot
.62701 .64789 Mdot
.46821 .27732 Mdot
.17172 .59838 Mdot
.45788 .54769 Mdot
.70076 .29146 Mdot
.3939 .50838 Mdot
.60626 .40738 Mdot
.43721 .5953 Mdot
.64989 .60525 Mdot
.52866 .33012 Mdot
.47748 .29976 Mdot
.36377 .59695 Mdot
.61089 .43837 Mdot
.3833 .43493 Mdot
.49625 .29706 Mdot
.44679 .27527 Mdot
.41885 .59577 Mdot
.77149 .45353 Mdot
.50461 .30016 Mdot
.40981 .18738 Mdot
.41979 .30678 Mdot
.6173 .62223 Mdot
.39393 .60385 Mdot
.65124 .65707 Mdot
.36201 .42404 Mdot
.5431 .33787 Mdot
.60923 .44229 Mdot
.39633 .52452 Mdot
.43113 .82723 Mdot
.49073 .31718 Mdot
.65193 .61727 Mdot
.4227 .57106 Mdot
.44117 .5338 Mdot
.45476 .63316 Mdot
.56007 .58467 Mdot
.32722 .40791 Mdot
.62866 .41012 Mdot
.60163 .42087 Mdot
.39154 .6319 Mdot
.38955 .4049 Mdot
.47524 .35787 Mdot
.484 .35362 Mdot
.87329 .4263 Mdot
.71048 .2957 Mdot
.27149 .54428 Mdot
.43719 .58376 Mdot
.52564 .30786 Mdot
.47822 .81534 Mdot
.60434 .45631 Mdot
.38468 .64103 Mdot
.53523 .32309 Mdot
.56851 .33098 Mdot
.46588 .42025 Mdot
.42022 .61504 Mdot
.49605 .59695 Mdot
.60483 .42123 Mdot
.43892 .41062 Mdot
.50506 .3112 Mdot
.37681 .63208 Mdot
.58347 .42797 Mdot
.52783 .23214 Mdot
.51462 .84956 Mdot
.64666 .62242 Mdot
.46431 .31867 Mdot
.62589 .46584 Mdot
.47025 .57087 Mdot
.36672 .43468 Mdot
.51951 .34558 Mdot
.47481 .3327 Mdot
.38846 .587 Mdot
.40895 .55405 Mdot
.45511 .54536 Mdot
.637 .61235 Mdot
.62654 .42045 Mdot
.40884 .647 Mdot
.72138 .57046 Mdot
.3858 .63285 Mdot
.62657 .42275 Mdot
.4892 .0969 Mdot
.41264 .55972 Mdot
.45331 .63301 Mdot
.27364 .40263 Mdot
.66164 .64095 Mdot
.61779 .6539 Mdot
.75677 .57604 Mdot
.43744 .58403 Mdot
.44653 .25298 Mdot
.64969 .62504 Mdot
.62307 .64533 Mdot
.35403 .30198 Mdot
.3864 .5807 Mdot
.44664 .39971 Mdot
.62572 .4287 Mdot
.63568 .46471 Mdot
.60525 .63016 Mdot
.46691 .56934 Mdot
.60619 .46836 Mdot
.5527 .66478 Mdot
.49752 .31552 Mdot
.79143 .57308 Mdot
.61576 .60558 Mdot
.42421 .48236 Mdot
.61103 .46104 Mdot
.27118 .25247 Mdot
.55988 .53428 Mdot
.38101 .62279 Mdot
.43385 .58795 Mdot
.34965 .4128 Mdot
.46329 .66944 Mdot
.68585 .32571 Mdot
.63256 .44605 Mdot
.24165 .3906 Mdot
.63697 .61958 Mdot
.4402 .63935 Mdot
.30264 .60677 Mdot
.71074 .47406 Mdot
.79037 .43497 Mdot
.64561 .64474 Mdot
.62414 .62585 Mdot
.49396 .30682 Mdot
.48145 .31366 Mdot
.42692 .61447 Mdot
.63691 .4412 Mdot
.64261 .66905 Mdot
.61413 .41819 Mdot
.48347 .32128 Mdot
.50185 .32802 Mdot
.70477 .31914 Mdot
.46494 .64995 Mdot
.48916 .36011 Mdot
.51262 .22831 Mdot
.71364 .57153 Mdot
.59147 .61254 Mdot
.35137 .79337 Mdot
.70414 .45314 Mdot
.23522 .46979 Mdot
.39577 .41013 Mdot
.68003 .29409 Mdot
.64754 .43294 Mdot
.39027 .62676 Mdot
.45044 .59767 Mdot
.69263 .30629 Mdot
.64718 .45834 Mdot
.35902 .40782 Mdot
.64273 .46571 Mdot
.38242 .41519 Mdot
.50043 .36996 Mdot
.46748 .62665 Mdot
.46197 .59295 Mdot
.62859 .46266 Mdot
.51144 .32596 Mdot
.4846 .35741 Mdot
.39076 .39919 Mdot
.32201 .55364 Mdot
.48136 .3391 Mdot
.61381 .6074 Mdot
.62343 .74958 Mdot
.68571 .30934 Mdot
.46249 .61512 Mdot
.29577 .63048 Mdot
.50351 .69792 Mdot
.37115 .60217 Mdot
.68825 .29897 Mdot
.87327 .46969 Mdot
.43228 .64568 Mdot
.85759 .51344 Mdot
.68981 .32005 Mdot
.66171 .64335 Mdot
.51793 .31393 Mdot
.68511 .32653 Mdot
.4415 .54699 Mdot
.38536 .44611 Mdot
.37503 .56348 Mdot
.66034 .63788 Mdot
.64124 .59105 Mdot
.74151 .65041 Mdot
.37804 .2218 Mdot
.37446 .39027 Mdot
.36794 .40492 Mdot
.49324 .34913 Mdot
.61116 .18846 Mdot
.41058 .54573 Mdot
.36634 .40268 Mdot
.23897 .41135 Mdot
.38705 .61887 Mdot
.27799 .56154 Mdot
.5458 .53833 Mdot
.61957 .64783 Mdot
.57499 .59456 Mdot
.49926 .34967 Mdot
.65171 .61783 Mdot
.71115 .58644 Mdot
.36391 .61554 Mdot
.64267 .61939 Mdot
.62271 .42271 Mdot
.64358 .35701 Mdot
.64573 .65648 Mdot
.43795 .43535 Mdot
.62707 .43106 Mdot
.32854 .39039 Mdot
.26708 .43408 Mdot
.25898 .76229 Mdot
.63368 .44574 Mdot
.51698 .32979 Mdot
.49298 .36251 Mdot
.48552 .35233 Mdot
.6621 .6345 Mdot
.49381 .29004 Mdot
.63424 .60813 Mdot
.33547 .27455 Mdot
.30155 .58955 Mdot
.37698 .4039 Mdot
.66291 .42425 Mdot
.63071 .63324 Mdot
.7635 .51965 Mdot
.37396 .81025 Mdot
.43109 .59731 Mdot
.58381 .42549 Mdot
.34079 .41039 Mdot
.54344 .15713 Mdot
.35081 .41345 Mdot
.51811 .32117 Mdot
.79407 .56801 Mdot
.44347 .63392 Mdot
.35301 .71915 Mdot
.34942 .4014 Mdot
.6516 .64267 Mdot
.4052 .63558 Mdot
.46024 .31522 Mdot
.368 .43243 Mdot
.38992 .42751 Mdot
.41412 .62571 Mdot
.63752 .65474 Mdot
.50344 .33211 Mdot
.64645 .4357 Mdot
.33288 .41664 Mdot
.48812 .59605 Mdot
.38932 .56949 Mdot
.39207 .65641 Mdot
.5123 .44639 Mdot
.21305 .48415 Mdot
.63017 .44092 Mdot
.33943 .47688 Mdot
.47912 .32096 Mdot
.32558 .37556 Mdot
.73879 .53185 Mdot
.66529 .44825 Mdot
.69657 .32111 Mdot
.70219 .31881 Mdot
.41811 .61805 Mdot
.21505 .47402 Mdot
.82036 .46486 Mdot
.64254 .49339 Mdot
.6877 .30454 Mdot
.48273 .35503 Mdot
.6716 .65274 Mdot
.73088 .65608 Mdot
.42597 .55591 Mdot
.61799 .40552 Mdot
.48003 .33397 Mdot
.19216 .46455 Mdot
.37701 .41481 Mdot
.77882 .56239 Mdot
.40806 .58365 Mdot
.42614 .63571 Mdot
.62169 .44015 Mdot
.63361 .42964 Mdot
.77369 .42118 Mdot
.74573 .61194 Mdot
.54576 .38106 Mdot
.68107 .42124 Mdot
.18518 .49444 Mdot
.58222 .59972 Mdot
.6466 .60237 Mdot
.71202 .30725 Mdot
.60539 .47556 Mdot
.46306 .60671 Mdot
.66748 .63669 Mdot
.79221 .43775 Mdot
.68492 .648 Mdot
.2843 .54816 Mdot
.44856 .25901 Mdot
.40395 .59964 Mdot
.61001 .60633 Mdot
.65001 .61857 Mdot
.6205 .65995 Mdot
.68334 .30491 Mdot
.4507 .61657 Mdot
.40717 .56641 Mdot
.41042 .64386 Mdot
.49385 .63886 Mdot
.41803 .599 Mdot
.73073 .53897 Mdot
.56 .46148 Mdot
.24795 .3741 Mdot
.37264 .60675 Mdot
.63033 .46937 Mdot
.40378 .65366 Mdot
.391 .40965 Mdot
.38075 .6116 Mdot
.27456 .55255 Mdot
.62323 .45333 Mdot
.45641 .5267 Mdot
.68349 .43157 Mdot
.4068 .58365 Mdot
.36847 .43962 Mdot
.22185 .46773 Mdot
.36757 .77526 Mdot
.54865 .24652 Mdot
.61199 .60944 Mdot
.50149 .27773 Mdot
.65157 .42426 Mdot
.50074 .33812 Mdot
.37789 .62344 Mdot
.70684 .29631 Mdot
.68511 .38227 Mdot
.43273 .47908 Mdot
.45837 .59181 Mdot
.35666 .64789 Mdot
.61106 .63309 Mdot
.51596 .33947 Mdot
.6422 .57843 Mdot
.42448 .58532 Mdot
.36808 .42717 Mdot
.37854 .42696 Mdot
.74169 .59594 Mdot
.20252 .40158 Mdot
.59901 .5583 Mdot
.62389 .43965 Mdot
.47222 .30374 Mdot
.37533 .4425 Mdot
.65152 .6976 Mdot
.62875 .40553 Mdot
.60723 .40724 Mdot
.60489 .44057 Mdot
.40455 .60719 Mdot
.69209 .32459 Mdot
.22137 .41456 Mdot
.6803 .3241 Mdot
.40374 .5862 Mdot
.47332 .32321 Mdot
.68742 .32791 Mdot
.34993 .42045 Mdot
.5929 .43691 Mdot
.48455 .31392 Mdot
.41476 .60697 Mdot
.64443 .62711 Mdot
.34122 .52968 Mdot
.24205 .55909 Mdot
.3044 .30284 Mdot
.29963 .30986 Mdot
.66164 .60618 Mdot
.24346 .30668 Mdot
.62687 .38921 Mdot
.50666 .7074 Mdot
.40525 .43597 Mdot
.36635 .60508 Mdot
.74638 .70129 Mdot
.50737 .31191 Mdot
.504 .35659 Mdot
.42167 .61151 Mdot
.5229 .30941 Mdot
.44523 .63814 Mdot
.48702 .30486 Mdot
.51878 .24632 Mdot
.44518 .56175 Mdot
.50285 .35565 Mdot
.38377 .54851 Mdot
.40416 .57217 Mdot
.61212 .64179 Mdot
.52338 .3404 Mdot
.38343 .63153 Mdot
.61433 .17845 Mdot
.64019 .4397 Mdot
.68262 .30705 Mdot
.54574 .41669 Mdot
.61945 .46807 Mdot
.62622 .61758 Mdot
.4606 .57509 Mdot
.36161 .39651 Mdot
.64188 .63422 Mdot
.46337 .28502 Mdot
.34777 .40148 Mdot
.76268 .57004 Mdot
.60807 .61507 Mdot
.68707 .31095 Mdot
.35239 .40017 Mdot
.36654 .65578 Mdot
.50927 .36011 Mdot
.24046 .59955 Mdot
.67975 .32092 Mdot
.45721 .61984 Mdot
.50807 .37207 Mdot
.63271 .47061 Mdot
.43117 .62418 Mdot
.52422 .3209 Mdot
.68344 .30349 Mdot
.39951 .61342 Mdot
.39992 .62951 Mdot
.72116 .65694 Mdot
.80227 .48093 Mdot
.36807 .39767 Mdot
.59888 .61228 Mdot
.42711 .60267 Mdot
.38746 .39842 Mdot
.61951 .23724 Mdot
.42273 .65619 Mdot
.66035 .6519 Mdot
.33706 .6845 Mdot
.47937 .31511 Mdot
.59676 .4506 Mdot
.46344 .32751 Mdot
.39389 .42194 Mdot
.70751 .78707 Mdot
.69839 .32479 Mdot
.38952 .54281 Mdot
.37208 .63307 Mdot
.51338 .38189 Mdot
.64582 .61635 Mdot
.53136 .3934 Mdot
.43925 .58674 Mdot
.38871 .68143 Mdot
.43093 .63839 Mdot
.41925 .30069 Mdot
.62898 .64773 Mdot
.45736 .62762 Mdot
.51191 .63312 Mdot
.47197 .62011 Mdot
.37453 .43899 Mdot
.29153 .45541 Mdot
.41013 .65731 Mdot
.25175 .22295 Mdot
.68274 .30099 Mdot
.49231 .35995 Mdot
.53832 .28769 Mdot
.69251 .25801 Mdot
.71018 .69378 Mdot
.63627 .6099 Mdot
.34016 .65233 Mdot
.50236 .335 Mdot
.51471 .84122 Mdot
.27066 .27382 Mdot
.40372 .57415 Mdot
.44041 .57473 Mdot
.51814 .32121 Mdot
.52636 .31041 Mdot
.70862 .30304 Mdot
.37482 .61076 Mdot
.34502 .59387 Mdot
.48346 .28476 Mdot
.41193 .59688 Mdot
.38059 .70873 Mdot
.64304 .42825 Mdot
.60812 .64265 Mdot
.59476 .43647 Mdot
.62169 .40782 Mdot
.59278 .72305 Mdot
.75115 .57692 Mdot
.6295 .42369 Mdot
.58106 .42784 Mdot
.27068 .56387 Mdot
.32107 .64758 Mdot
.3832 .43739 Mdot
.25606 .32774 Mdot
.48678 .34892 Mdot
.44917 .61606 Mdot
.65928 .6069 Mdot
.55758 .69554 Mdot
.61309 .32737 Mdot
.80174 .54375 Mdot
.42946 .58003 Mdot
.49726 .35263 Mdot
.67988 .31027 Mdot
.43982 .55886 Mdot
.31497 .38349 Mdot
.42438 .63355 Mdot
.49522 .36461 Mdot
.64754 .73757 Mdot
.34272 .70172 Mdot
.43382 .36763 Mdot
.59864 .6536 Mdot
.41619 .6487 Mdot
.62166 .60539 Mdot
.61501 .46279 Mdot
.38743 .40059 Mdot
.36275 .39966 Mdot
.4058 .63299 Mdot
.65413 .69524 Mdot
.54124 .54162 Mdot
.40715 .57176 Mdot
.3877 .58431 Mdot
.69169 .31973 Mdot
.38814 .58312 Mdot
.37103 .63048 Mdot
.39818 .64522 Mdot
.459 .64593 Mdot
.59797 .46452 Mdot
.32673 .69338 Mdot
.43468 .65811 Mdot
.40959 .53225 Mdot
.643 .43507 Mdot
.33408 .62308 Mdot
.61447 .40965 Mdot
.19438 .38728 Mdot
.61148 .41324 Mdot
.36753 .39956 Mdot
.51717 .3678 Mdot
.37305 .67802 Mdot
.63618 .66954 Mdot
.58967 .42074 Mdot
.36724 .4183 Mdot
.6317 .45012 Mdot
.47375 .30901 Mdot
.29877 .73709 Mdot
.68522 .64711 Mdot
.45041 .41503 Mdot
.56823 .55336 Mdot
.77222 .44964 Mdot
.49431 .31101 Mdot
.61948 .64563 Mdot
.36055 .72292 Mdot
.39691 .64214 Mdot
.349 .40799 Mdot
.41787 .6205 Mdot
.59531 .45754 Mdot
.49203 .35302 Mdot
.30276 .32383 Mdot
.36291 .39787 Mdot
.50965 .85783 Mdot
.47756 .3496 Mdot
.42297 .56095 Mdot
.61412 .40443 Mdot
.355 .79534 Mdot
.60839 .41358 Mdot
.29886 .60126 Mdot
.63177 .58368 Mdot
.66962 .7458 Mdot
.62292 .63088 Mdot
.79647 .41935 Mdot
.12975 .4742 Mdot
.30789 .2654 Mdot
.65204 .63254 Mdot
.43902 .31153 Mdot
.41105 .58688 Mdot
.40238 .65619 Mdot
.47092 .55561 Mdot
.59226 .62192 Mdot
.42468 .60014 Mdot
.68328 .32133 Mdot
.68116 .55531 Mdot
.33942 .35254 Mdot
.49956 .27578 Mdot
.46012 .62755 Mdot
.64154 .43144 Mdot
.64078 .46994 Mdot
.68437 .32719 Mdot
.63939 .41374 Mdot
.39903 .57105 Mdot
.62793 .63287 Mdot
.4595 .48667 Mdot
.35677 .42323 Mdot
.49061 .17937 Mdot
.33672 .39722 Mdot
.48434 .27355 Mdot
.43711 .67073 Mdot
.50206 .32701 Mdot
.81411 .6711 Mdot
.38913 .63384 Mdot
.65241 .62484 Mdot
.40053 .62366 Mdot
.4055 .64877 Mdot
.39991 .65591 Mdot
.48819 .2883 Mdot
.54974 .32972 Mdot
.41162 .60064 Mdot
.60849 .4431 Mdot
.27559 .33939 Mdot
.36512 .57374 Mdot
.44743 .3068 Mdot
.29713 .51229 Mdot
.76513 .47463 Mdot
.58952 .61902 Mdot
.51592 .33545 Mdot
.63205 .62136 Mdot
.61117 .66429 Mdot
.6263 .61743 Mdot
.22155 .40004 Mdot
.52548 .63553 Mdot
.86452 .4536 Mdot
.6162 .78371 Mdot
.53913 .70605 Mdot
.62536 .59074 Mdot
.63526 .27091 Mdot
.65551 .61052 Mdot
.63209 .61239 Mdot
.68298 .17647 Mdot
.66132 .61619 Mdot
.45444 .59377 Mdot
.39807 .55917 Mdot
.70702 .51491 Mdot
.27489 .58442 Mdot
.37815 .60826 Mdot
.42553 .60645 Mdot
.38261 .39609 Mdot
.51067 .58771 Mdot
.70891 .32264 Mdot
.77382 .58524 Mdot
.68329 .39419 Mdot
.41414 .62437 Mdot
.42258 .60549 Mdot
.48379 .59937 Mdot
.12053 .49575 Mdot
.57267 .69143 Mdot
.65689 .59827 Mdot
.35402 .6464 Mdot
.41818 .19794 Mdot
.4275 .56439 Mdot
.46364 .59462 Mdot
.39802 .60739 Mdot
.50278 .33641 Mdot
.67606 .64651 Mdot
.35974 .65259 Mdot
.75203 .46933 Mdot
.41237 .58054 Mdot
.65141 .40827 Mdot
.33121 .41967 Mdot
.46028 .60963 Mdot
.61905 .65733 Mdot
.38424 .60827 Mdot
.61412 .60458 Mdot
.60608 .63456 Mdot
.48814 .62109 Mdot
.21386 .41401 Mdot
.6466 .66097 Mdot
.40119 .59177 Mdot
.51173 .33084 Mdot
.30688 .25462 Mdot
.45821 .61609 Mdot
.38613 .40895 Mdot
.43564 .58681 Mdot
.37104 .4383 Mdot
.39591 .58326 Mdot
.67917 .32202 Mdot
.43307 .73349 Mdot
.49386 .34564 Mdot
.41777 .41743 Mdot
.51441 .29624 Mdot
.71986 .64355 Mdot
.66307 .64499 Mdot
.71466 .31437 Mdot
.80494 .60552 Mdot
.69071 .31863 Mdot
.34352 .52841 Mdot
.59638 .28434 Mdot
.63824 .45119 Mdot
.60555 .64593 Mdot
.36145 .48438 Mdot
.44616 .30217 Mdot
.46905 .28288 Mdot
.52769 .30385 Mdot
.73644 .74822 Mdot
.78651 .65192 Mdot
.40971 .60793 Mdot
.23432 .62991 Mdot
.49417 .77897 Mdot
.46197 .63823 Mdot
.46765 .5839 Mdot
.49806 .36608 Mdot
.42746 .64761 Mdot
.49599 .45633 Mdot
.48885 .32306 Mdot
.36696 .41247 Mdot
.6252 .60924 Mdot
.37363 .43647 Mdot
.4639 .36479 Mdot
.56847 .48261 Mdot
.48164 .31917 Mdot
.44202 .65244 Mdot
.40587 .62054 Mdot
.60305 .61784 Mdot
.69286 .66493 Mdot
.60842 .64083 Mdot
.3436 .40504 Mdot
.48739 .33345 Mdot
.5571 .68358 Mdot
.43903 .59957 Mdot
.63782 .63901 Mdot
.57127 .45707 Mdot
.43452 .5985 Mdot
.62475 .46323 Mdot
.42267 .57362 Mdot
.65556 .63452 Mdot
.38877 .58268 Mdot
.62697 .6311 Mdot
.50906 .31671 Mdot
.42881 .56646 Mdot
.42385 .61127 Mdot
.40728 .80455 Mdot
.35795 .40914 Mdot
.66288 .64426 Mdot
.53739 .49769 Mdot
.41223 .56164 Mdot
.3444 .36958 Mdot
.45939 .63479 Mdot
.33495 .66019 Mdot
.37654 .55222 Mdot
.68376 .31951 Mdot
.41003 .66341 Mdot
.45825 .61838 Mdot
.33661 .70841 Mdot
.53479 .80894 Mdot
.6552 .58028 Mdot
.589 .44031 Mdot
.61765 .65609 Mdot
.51208 .36159 Mdot
.5303 .33403 Mdot
.49771 .29445 Mdot
.28441 .59679 Mdot
.47274 .57886 Mdot
.44534 .63263 Mdot
.59355 .41213 Mdot
.37068 .40579 Mdot
.64571 .64288 Mdot
.37535 .40736 Mdot
.77234 .59019 Mdot
.34374 .40817 Mdot
.68781 .3262 Mdot
.42005 .30819 Mdot
.51363 .67971 Mdot
.37834 .39387 Mdot
.60861 .6419 Mdot
.44026 .27519 Mdot
.36796 .61305 Mdot
.53648 .25256 Mdot
.36962 .42719 Mdot
.68538 .79837 Mdot
.46329 .62994 Mdot
.46659 .43572 Mdot
.63163 .41618 Mdot
.35815 .43361 Mdot
.60637 .45273 Mdot
.38594 .62508 Mdot
.73902 .41402 Mdot
.65457 .61812 Mdot
.6009 .47538 Mdot
.40919 .66231 Mdot
.36943 .43604 Mdot
.47845 .33737 Mdot
.59813 .53631 Mdot
.63195 .46752 Mdot
.33214 .73247 Mdot
.29416 .41067 Mdot
.48781 .33093 Mdot
.83163 .44311 Mdot
.60174 .43546 Mdot
.44876 .64777 Mdot
.40482 .69526 Mdot
.37609 .59622 Mdot
.52477 .35242 Mdot
.51418 .34322 Mdot
.6876 .54406 Mdot
.4021 .62111 Mdot
.46217 .63151 Mdot
.68077 .62425 Mdot
.49322 .31863 Mdot
.61555 .63237 Mdot
.61268 .65713 Mdot
.51665 .32575 Mdot
.61655 .624 Mdot
.3481 .40393 Mdot
.64888 .5369 Mdot
.60228 .43339 Mdot
.61131 .44743 Mdot
.48336 .35472 Mdot
.46745 .33737 Mdot
.50115 .32471 Mdot
.42222 .57382 Mdot
.64292 .64849 Mdot
.39127 .6008 Mdot
.41486 .65825 Mdot
.60556 .58864 Mdot
.66796 .62561 Mdot
.38951 .6103 Mdot
.42766 .37623 Mdot
.34112 .43702 Mdot
.50295 .35446 Mdot
.61674 .418 Mdot
.51878 .83852 Mdot
.60561 .40477 Mdot
.45897 .63133 Mdot
.5672 .31442 Mdot
.65603 .64072 Mdot
.35016 .41439 Mdot
.34317 .37574 Mdot
.35215 .40537 Mdot
.6303 .49185 Mdot
.62947 .66608 Mdot
.76114 .56895 Mdot
.45153 .63639 Mdot
.51312 .44857 Mdot
.34941 .48223 Mdot
.74311 .52207 Mdot
.62512 .42176 Mdot
.43005 .60175 Mdot
.68947 .31726 Mdot
.47256 .7051 Mdot
.42792 .63261 Mdot
.38281 .63622 Mdot
.39899 .27655 Mdot
.41235 .53178 Mdot
.59416 .6066 Mdot
.74337 .64511 Mdot
.38133 .56967 Mdot
.56272 .62928 Mdot
.80966 .31472 Mdot
.44754 .64067 Mdot
.42113 .5902 Mdot
.45151 .60633 Mdot
.39047 .62225 Mdot
.6133 .58804 Mdot
.39553 .47393 Mdot
.60994 .40523 Mdot
.53309 .4511 Mdot
.6076 .43018 Mdot
.51084 .35704 Mdot
.46776 .44021 Mdot
.60602 .64468 Mdot
.35006 .40917 Mdot
.27297 .69204 Mdot
.76264 .61717 Mdot
.49467 .30734 Mdot
.60479 .70644 Mdot
.36071 .42595 Mdot
.36671 .60213 Mdot
.35572 .38389 Mdot
.52766 .31116 Mdot
.615 .4325 Mdot
.39765 .56008 Mdot
.64474 .5974 Mdot
.64664 .65666 Mdot
.4294 .59791 Mdot
.37592 .21641 Mdot
.61403 .46497 Mdot
.56025 .43457 Mdot
.40431 .60482 Mdot
.38213 .6351 Mdot
.61131 .62164 Mdot
.50841 .34605 Mdot
.5857 .24039 Mdot
.36117 .41363 Mdot
.4806 .62707 Mdot
.38542 .61778 Mdot
.76386 .59791 Mdot
.592 .43608 Mdot
.70178 .29801 Mdot
.40333 .61071 Mdot
.75161 .58211 Mdot
.40208 .61223 Mdot
.4608 .67257 Mdot
.5067 .328 Mdot
.36126 .60079 Mdot
.43588 .57529 Mdot
.41186 .50159 Mdot
.60069 .44225 Mdot
.64811 .62054 Mdot
.66849 .59896 Mdot
.69683 .29492 Mdot
.62668 .4615 Mdot
.38764 .61051 Mdot
.59618 .45399 Mdot
.40231 .65712 Mdot
.41398 .60114 Mdot
.6246 .422 Mdot
.61534 .63176 Mdot
.59977 .37801 Mdot
.30928 .64263 Mdot
.39425 .62302 Mdot
.38893 .56897 Mdot
.28171 .58538 Mdot
.82919 .55152 Mdot
.43957 .58083 Mdot
.65867 .64186 Mdot
.43393 .60316 Mdot
.61454 .45843 Mdot
.34224 .41212 Mdot
.64958 .62895 Mdot
.47231 .34865 Mdot
.5106 .31558 Mdot
.68378 .44305 Mdot
.69239 .32633 Mdot
.39672 .56518 Mdot
.67189 .58593 Mdot
.66589 .61579 Mdot
.66923 .21335 Mdot
.49661 .36165 Mdot
.36696 .4414 Mdot
.39794 .63079 Mdot
.58709 .53543 Mdot
.59442 .41385 Mdot
.24919 .22503 Mdot
.75482 .55933 Mdot
.37501 .3801 Mdot
.80497 .55893 Mdot
.69055 .31199 Mdot
.45585 .58636 Mdot
.39069 .40486 Mdot
.50551 .30486 Mdot
.39587 .65071 Mdot
.47283 .56482 Mdot
.52984 .39685 Mdot
.53192 .30018 Mdot
.59688 .4536 Mdot
.48466 .30209 Mdot
.39258 .39462 Mdot
.68692 .32601 Mdot
.62641 .6544 Mdot
.45606 .62608 Mdot
.41333 .69103 Mdot
.49181 .35769 Mdot
.67807 .32104 Mdot
.40354 .59941 Mdot
.64147 .65838 Mdot
.51765 .3039 Mdot
.41362 .62847 Mdot
.51733 .70093 Mdot
.59123 .6499 Mdot
.4843 .34055 Mdot
.37677 .63851 Mdot
.35484 .68518 Mdot
.4765 .35246 Mdot
.48537 .35965 Mdot
.4245 .60064 Mdot
.35009 .40249 Mdot
.44742 .5759 Mdot
.62309 .41101 Mdot
.54987 .329 Mdot
.61649 .4569 Mdot
.32189 .45283 Mdot
.44345 .66817 Mdot
.78182 .45077 Mdot
.60147 .61434 Mdot
.40225 .42046 Mdot
.41854 .78594 Mdot
.37605 .62574 Mdot
.22917 .34321 Mdot
.42292 .48063 Mdot
.5144 .16625 Mdot
.1592 .53432 Mdot
.37483 .42218 Mdot
.63033 .4537 Mdot
.4217 .59064 Mdot
.60231 .39736 Mdot
.38019 .39743 Mdot
.33567 .47093 Mdot
.37544 .63626 Mdot
.62553 .64624 Mdot
.40966 .58481 Mdot
.61291 .60809 Mdot
.43576 .59637 Mdot
.37514 .54706 Mdot
.39314 .45014 Mdot
.29823 .60561 Mdot
.36738 .60841 Mdot
.29359 .7349 Mdot
.57184 .52466 Mdot
.36573 .42474 Mdot
.39603 .59738 Mdot
.70026 .30514 Mdot
.6498 .45497 Mdot
.21194 .5196 Mdot
.50218 .33195 Mdot
.63306 .42359 Mdot
.61707 .61528 Mdot
.46614 .34739 Mdot
.68546 .29965 Mdot
.41936 .69366 Mdot
.3815 .43401 Mdot
.63723 .45092 Mdot
.45952 .61519 Mdot
.46418 .62563 Mdot
.42593 .35509 Mdot
.75585 .34444 Mdot
.6775 .65004 Mdot
.46946 .84359 Mdot
.60038 .59661 Mdot
.3632 .40457 Mdot
.5052 .32657 Mdot
.44984 .58615 Mdot
.4255 .62695 Mdot
.52746 .34351 Mdot
.66344 .63976 Mdot
.52883 .2876 Mdot
.60462 .71832 Mdot
.47376 .29307 Mdot
.31943 .51894 Mdot
.65522 .62871 Mdot
.32071 .52247 Mdot
.39457 .39636 Mdot
.1985 .43157 Mdot
.24934 .50427 Mdot
.6335 .4168 Mdot
.31941 .51406 Mdot
.65189 .64073 Mdot
.40891 .61417 Mdot
.68851 .30884 Mdot
.70353 .31962 Mdot
.61862 .60986 Mdot
.51946 .32257 Mdot
.3647 .43421 Mdot
.41886 .59128 Mdot
.7763 .52484 Mdot
.69668 .48478 Mdot
.47159 .30411 Mdot
.49957 .65014 Mdot
.60618 .44841 Mdot
.42774 .57614 Mdot
.38675 .41456 Mdot
.63309 .43863 Mdot
.70091 .2881 Mdot
.6689 .54724 Mdot
.39916 .63413 Mdot
.73951 .60527 Mdot
.63088 .45931 Mdot
.8376 .44618 Mdot
.42498 .61713 Mdot
.60157 .43585 Mdot
.36723 .54645 Mdot
.73317 .43122 Mdot
.50367 .49189 Mdot
.27548 .27697 Mdot
.53058 .30166 Mdot
.51283 .31518 Mdot
.70255 .3608 Mdot
.40212 .43995 Mdot
.64224 .44096 Mdot
.68535 .32584 Mdot
.27195 .46183 Mdot
.60427 .44942 Mdot
.46281 .58967 Mdot
.45807 .6357 Mdot
.58454 .71808 Mdot
.5103 .47427 Mdot
.67675 .32163 Mdot
.60641 .56412 Mdot
.38337 .58112 Mdot
.35648 .60841 Mdot
.43338 .62087 Mdot
.64327 .59173 Mdot
.61997 .46914 Mdot
.32025 .78031 Mdot
.60876 .46287 Mdot
.78221 .532 Mdot
.48722 .34944 Mdot
.47001 .30428 Mdot
.46122 .61244 Mdot
.80267 .45022 Mdot
.20566 .51057 Mdot
.40996 .56563 Mdot
.3252 .39127 Mdot
.29575 .4246 Mdot
.35431 .59262 Mdot
.65728 .58771 Mdot
.42072 .6889 Mdot
.5819 .60937 Mdot
.63203 .43255 Mdot
.37845 .42061 Mdot
.3428 .4379 Mdot
.63724 .44525 Mdot
.44592 .63099 Mdot
.32205 .42705 Mdot
.42914 .63707 Mdot
.40672 .61028 Mdot
.78167 .57068 Mdot
.36606 .44386 Mdot
.50044 .3211 Mdot
.3623 .39918 Mdot
.63395 .61282 Mdot
.55957 .1031 Mdot
.37985 .40879 Mdot
.70286 .62621 Mdot
.42694 .42106 Mdot
.32178 .51507 Mdot
.64005 .65749 Mdot
.36306 .38948 Mdot
.60032 .45711 Mdot
.50721 .16312 Mdot
.83919 .49886 Mdot
.60707 .40231 Mdot
.42305 .62155 Mdot
.60235 .63795 Mdot
.65517 .59982 Mdot
.58287 .42426 Mdot
.62275 .65015 Mdot
.39032 .66393 Mdot
.39971 .61938 Mdot
.64217 .44128 Mdot
.69843 .51388 Mdot
.62683 .47123 Mdot
.65346 .55143 Mdot
.39913 .59866 Mdot
.65111 .62703 Mdot
.42187 .6761 Mdot
.68405 .62752 Mdot
.71025 .31071 Mdot
.3934 .65017 Mdot
.34857 .42329 Mdot
.50895 .46384 Mdot
.48561 .34277 Mdot
.56775 .33191 Mdot
.60318 .6229 Mdot
.57266 .40601 Mdot
.61184 .64189 Mdot
.59622 .62736 Mdot
.6343 .40907 Mdot
.64494 .61207 Mdot
.42032 .58991 Mdot
.43275 .37078 Mdot
.62586 .59919 Mdot
.62091 .44468 Mdot
.35743 .43039 Mdot
.61587 .62697 Mdot
.4731 .36458 Mdot
.4082 .62432 Mdot
.48291 .31096 Mdot
.38843 .38336 Mdot
.60795 .64854 Mdot
.35795 .39128 Mdot
.49498 .36006 Mdot
.38743 .42862 Mdot
.31268 .30395 Mdot
.60861 .47604 Mdot
.80124 .53618 Mdot
.32235 .66907 Mdot
.64498 .59805 Mdot
.46726 .28362 Mdot
.4453 .58403 Mdot
.4048 .62685 Mdot
.39109 .39526 Mdot
.65718 .60183 Mdot
.32071 .24827 Mdot
.34485 .66753 Mdot
.65504 .53431 Mdot
.59912 .46899 Mdot
.52417 .84806 Mdot
.71709 .56744 Mdot
.5173 .19037 Mdot
.39711 .54785 Mdot
.69044 .31139 Mdot
.43616 .63843 Mdot
.37244 .78071 Mdot
.34271 .41975 Mdot
.63254 .31286 Mdot
.41191 .54591 Mdot
.49562 .32878 Mdot
.43936 .60679 Mdot
.23476 .61473 Mdot
.42362 .68781 Mdot
.37806 .39202 Mdot
.65001 .48449 Mdot
.63767 .66962 Mdot
.35784 .42383 Mdot
.50559 .3124 Mdot
.29078 .47918 Mdot
.3722 .63503 Mdot
.39323 .5719 Mdot
.48645 .27974 Mdot
.62424 .64744 Mdot
.51146 .3579 Mdot
.60254 .43334 Mdot
.37733 .4111 Mdot
.39166 .62683 Mdot
.35972 .62165 Mdot
.5154 .38585 Mdot
.61696 .46944 Mdot
.46573 .32856 Mdot
.5946 .43327 Mdot
.68951 .31124 Mdot
.37332 .58295 Mdot
.48974 .28086 Mdot
.46182 .63536 Mdot
.41733 .79389 Mdot
.78622 .57183 Mdot
.53885 .79779 Mdot
.49925 .31854 Mdot
.29686 .53005 Mdot
.62343 .45616 Mdot
.60253 .41823 Mdot
.64158 .77155 Mdot
.21936 .46944 Mdot
.44811 .25397 Mdot
.28359 .70814 Mdot
.60302 .43227 Mdot
.61716 .45385 Mdot
.50689 .3034 Mdot
.63899 .60751 Mdot
.58179 .64423 Mdot
.46676 .30867 Mdot
.29736 .62245 Mdot
.64558 .64276 Mdot
.23901 .32579 Mdot
.49657 .36751 Mdot
.40518 .54497 Mdot
.6912 .33377 Mdot
.37982 .42374 Mdot
.29826 .62328 Mdot
.26059 .6519 Mdot
.45604 .59042 Mdot
.73528 .68416 Mdot
.5086 .34122 Mdot
.46275 .40443 Mdot
.19402 .40164 Mdot
.38303 .64198 Mdot
.44461 .61247 Mdot
.44443 .62769 Mdot
.35955 .44453 Mdot
.40498 .78037 Mdot
.4573 .59118 Mdot
.3073 .57267 Mdot
.45491 .5737 Mdot
.23335 .55325 Mdot
.36401 .39894 Mdot
.55296 .59685 Mdot
.51804 .28857 Mdot
.75005 .4907 Mdot
.46287 .54907 Mdot
.59731 .43814 Mdot
.44286 .34678 Mdot
.61633 .42929 Mdot
.20661 .46777 Mdot
.25122 .5017 Mdot
.63082 .58865 Mdot
.42898 .57955 Mdot
.53198 .31236 Mdot
.60137 .62688 Mdot
.59292 .27045 Mdot
.65886 .1557 Mdot
.60469 .46649 Mdot
.83895 .59715 Mdot
.60191 .41826 Mdot
.7085 .31298 Mdot
.6121 .61761 Mdot
.55143 .64423 Mdot
.51175 .44939 Mdot
.61735 .62749 Mdot
.67297 .37654 Mdot
.64672 .58295 Mdot
.30685 .52055 Mdot
.6116 .66152 Mdot
.62328 .44798 Mdot
.63177 .48471 Mdot
.43519 .54127 Mdot
.44223 .58453 Mdot
.54149 .45029 Mdot
.34423 .56468 Mdot
.43627 .58178 Mdot
.48899 .32314 Mdot
.82873 .49481 Mdot
.50309 .37767 Mdot
.64384 .60236 Mdot
.59072 .43121 Mdot
.44338 .61091 Mdot
.39474 .61904 Mdot
.43913 .64965 Mdot
.4083 .80765 Mdot
.24325 .32214 Mdot
.41216 .60316 Mdot
.47849 .63593 Mdot
.50563 .31528 Mdot
.35159 .45703 Mdot
.31677 .73647 Mdot
.26813 .47465 Mdot
.41278 .63966 Mdot
.35637 .40731 Mdot
.34772 .43497 Mdot
.36468 .58185 Mdot
.77113 .49215 Mdot
.43586 .32576 Mdot
.4594 .61483 Mdot
.23939 .514 Mdot
.4857 .37446 Mdot
.68097 .32663 Mdot
.49101 .35748 Mdot
.61603 .65695 Mdot
.69508 .3218 Mdot
.50663 .29271 Mdot
.54539 .64254 Mdot
.69991 .29392 Mdot
.73363 .44594 Mdot
.34358 .40499 Mdot
.43157 .62459 Mdot
.66418 .58974 Mdot
.52812 .34505 Mdot
.63822 .44748 Mdot
.63483 .62831 Mdot
.64231 .46937 Mdot
.37142 .46283 Mdot
.3652 .50298 Mdot
.69656 .32526 Mdot
.59965 .43083 Mdot
.66993 .54834 Mdot
.35731 .40481 Mdot
.63334 .40979 Mdot
.79752 .44012 Mdot
.3858 .55735 Mdot
.19129 .53358 Mdot
.41241 .57044 Mdot
.42395 .19248 Mdot
.6026 .41495 Mdot
.70859 .29597 Mdot
.44821 .63298 Mdot
.47737 .35005 Mdot
.35396 .56135 Mdot
.42206 .63456 Mdot
.46916 .32191 Mdot
.40989 .60927 Mdot
.38777 .41363 Mdot
.58038 .62767 Mdot
.43372 .48479 Mdot
.60737 .82625 Mdot
.38645 .42824 Mdot
.7033 .3363 Mdot
.43594 .57976 Mdot
.29778 .34027 Mdot
.61779 .63019 Mdot
.38386 .64026 Mdot
.68228 .73299 Mdot
.63141 .60365 Mdot
.62894 .62283 Mdot
.38784 .58923 Mdot
.63622 .41547 Mdot
.47938 .34743 Mdot
.35623 .40448 Mdot
.56573 .18092 Mdot
.41519 .63227 Mdot
.42932 .60721 Mdot
.35984 .42581 Mdot
.61689 .45561 Mdot
.39223 .61869 Mdot
.59063 .3067 Mdot
.58429 .17094 Mdot
.62024 .40718 Mdot
.36486 .5736 Mdot
.20676 .6065 Mdot
.65346 .67865 Mdot
.8358 .57064 Mdot
.41906 .39582 Mdot
.51518 .33188 Mdot
.3663 .55695 Mdot
.29562 .1911 Mdot
.37781 .42403 Mdot
.74926 .51963 Mdot
.40959 .59749 Mdot
.44456 .59949 Mdot
.64818 .653 Mdot
.38856 .60402 Mdot
.66173 .62747 Mdot
.63167 .82065 Mdot
.48392 .8689 Mdot
.61131 .63657 Mdot
.65221 .60483 Mdot
.56299 .60393 Mdot
.34756 .75044 Mdot
.62223 .61147 Mdot
.382 .64653 Mdot
.27869 .3184 Mdot
.48915 .62393 Mdot
.39794 .40505 Mdot
.36582 .37244 Mdot
.56686 .64315 Mdot
.80773 .38869 Mdot
.34337 .64323 Mdot
.44351 .52939 Mdot
.54575 .55069 Mdot
.61534 .41383 Mdot
.40707 .64351 Mdot
.6917 .3268 Mdot
.49316 .29333 Mdot
.46218 .67602 Mdot
.4321 .62817 Mdot
.61606 .60366 Mdot
.36477 .44618 Mdot
.65263 .43092 Mdot
.42508 .60704 Mdot
.53967 .30867 Mdot
.36436 .41265 Mdot
.63286 .59846 Mdot
.7117 .63893 Mdot
.39136 .43048 Mdot
.38085 .65952 Mdot
.43895 .58838 Mdot
.40323 .60088 Mdot
.43408 .53332 Mdot
.63886 .43915 Mdot
.4742 .37073 Mdot
.38854 .65768 Mdot
.76882 .5858 Mdot
.4639 .42501 Mdot
.36231 .62328 Mdot
.64906 .64718 Mdot
.6052 .40582 Mdot
.70429 .29899 Mdot
.30769 .47552 Mdot
.40309 .63584 Mdot
.24288 .32592 Mdot
.58193 .70112 Mdot
.69825 .31861 Mdot
.60333 .60451 Mdot
.35044 .41044 Mdot
.38971 .57694 Mdot
.25223 .35522 Mdot
.46009 .63229 Mdot
.32585 .65798 Mdot
.51223 .33711 Mdot
.61227 .41657 Mdot
.56057 .16104 Mdot
.49155 .29332 Mdot
.63105 .62175 Mdot
.2806 .25557 Mdot
.67396 .64032 Mdot
.6547 .66524 Mdot
.2144 .42351 Mdot
.63083 .42784 Mdot
.27628 .20665 Mdot
.83734 .5262 Mdot
.47044 .61176 Mdot
.61258 .45997 Mdot
.6089 .6198 Mdot
.42524 .57708 Mdot
.66284 .61265 Mdot
.66065 .65915 Mdot
.40224 .65225 Mdot
.44314 .59284 Mdot
.3063 .58799 Mdot
.20873 .35899 Mdot
.35434 .4008 Mdot
.66142 .64346 Mdot
.54723 .71536 Mdot
.45557 .58786 Mdot
.45228 .63583 Mdot
.45655 .3844 Mdot
.37803 .39225 Mdot
.38104 .71932 Mdot
.40435 .61069 Mdot
.69099 .73594 Mdot
.39077 .56717 Mdot
.67469 .59932 Mdot
.62514 .4072 Mdot
.76785 .49772 Mdot
.52049 .35706 Mdot
.65669 .65531 Mdot
.36739 .43746 Mdot
.66984 .60432 Mdot
.65621 .7492 Mdot
.62726 .42767 Mdot
.65558 .63455 Mdot
.48078 .36523 Mdot
.61967 .43448 Mdot
.62267 .4088 Mdot
.27567 .33818 Mdot
.46552 .32305 Mdot
.34413 .39906 Mdot
.61011 .43405 Mdot
.50711 .70888 Mdot
.62655 .44582 Mdot
.56308 .71675 Mdot
.42545 .56757 Mdot
.31388 .56013 Mdot
.72416 .55933 Mdot
.48232 .56873 Mdot
.63074 .47148 Mdot
.37314 .39537 Mdot
.38124 .59935 Mdot
.62695 .65147 Mdot
.38088 .41099 Mdot
.66532 .47881 Mdot
.47336 .35412 Mdot
.60762 .60566 Mdot
.61777 .4052 Mdot
.65972 .63265 Mdot
.35623 .49325 Mdot
.55813 .32141 Mdot
.54877 .55991 Mdot
.50395 .43995 Mdot
.45415 .64449 Mdot
.56454 .64618 Mdot
.40196 .56136 Mdot
.43038 .631 Mdot
.48416 .34153 Mdot
.28532 .59521 Mdot
.61451 .63092 Mdot
.57432 .16132 Mdot
.603 .42371 Mdot
.72748 .66555 Mdot
.36004 .68583 Mdot
.38746 .63839 Mdot
.62621 .60014 Mdot
.66824 .6557 Mdot
.53679 .80792 Mdot
.52592 .3444 Mdot
.49594 .59478 Mdot
.45309 .66642 Mdot
.40666 .54061 Mdot
.60067 .41605 Mdot
.6014 .32728 Mdot
.522 .33425 Mdot
.87541 .4714 Mdot
.50404 .353 Mdot
.36772 .29939 Mdot
.64562 .61171 Mdot
.34435 .42088 Mdot
.4562 .63258 Mdot
.31167 .60933 Mdot
.63022 .58566 Mdot
.44194 .38845 Mdot
.34927 .41967 Mdot
.62674 .35656 Mdot
.63228 .42562 Mdot
.3645 .59904 Mdot
.40655 .65066 Mdot
.39275 .59695 Mdot
.41245 .57486 Mdot
.58977 .44188 Mdot
.46323 .59125 Mdot
.60349 .47614 Mdot
.51447 .69571 Mdot
.687 .74214 Mdot
.53421 .34105 Mdot
.21432 .49902 Mdot
.63497 .5944 Mdot
.50992 .72167 Mdot
.38769 .70757 Mdot
.78879 .56591 Mdot
.3006 .32013 Mdot
.40375 .56291 Mdot
.51926 .31682 Mdot
.2339 .62306 Mdot
.53238 .31497 Mdot
.5908 .8866 Mdot
.32343 .43934 Mdot
.26594 .27889 Mdot
.42542 .57857 Mdot
.50331 .3857 Mdot
.36943 .69907 Mdot
.36456 .57819 Mdot
.33374 .45375 Mdot
.7012 .6042 Mdot
.71666 .51142 Mdot
.37195 .4417 Mdot
.40953 .62623 Mdot
.64217 .67009 Mdot
.41952 .58831 Mdot
.44375 .63908 Mdot
.42745 .57453 Mdot
.64573 .41369 Mdot
.43109 .5544 Mdot
.45137 .57883 Mdot
.76246 .34335 Mdot
.28056 .55589 Mdot
.48061 .30927 Mdot
.58504 .79565 Mdot
.37084 .40628 Mdot
.60873 .61109 Mdot
.41715 .47086 Mdot
.63015 .41642 Mdot
.52154 .81532 Mdot
.42031 .57438 Mdot
.7128 .55316 Mdot
.61701 .40475 Mdot
.38123 .41535 Mdot
.69277 .29731 Mdot
.28812 .28466 Mdot
.53424 .33797 Mdot
.70286 .29401 Mdot
.48674 .3438 Mdot
.42458 .77756 Mdot
.61793 .60295 Mdot
.43265 .6524 Mdot
.60533 .44191 Mdot
.47685 .34323 Mdot
.27446 .59585 Mdot
.43788 .62063 Mdot
.49701 .31613 Mdot
.44874 .64745 Mdot
.44516 .42018 Mdot
.43106 .33251 Mdot
.51631 .29663 Mdot
.6391 .48389 Mdot
.61524 .43886 Mdot
.34726 .4048 Mdot
.60758 .61094 Mdot
.65511 .64296 Mdot
.63119 .43717 Mdot
.82085 .60291 Mdot
.42035 .63645 Mdot
.43067 .57642 Mdot
.76538 .58234 Mdot
.427 .58811 Mdot
.2986 .49678 Mdot
.70171 .32734 Mdot
.61592 .59962 Mdot
.42016 .57956 Mdot
.39228 .62091 Mdot
.39808 .63251 Mdot
.35643 .49623 Mdot
.49455 .35755 Mdot
.38402 .58074 Mdot
.39242 .40396 Mdot
.77576 .41863 Mdot
.44489 .57999 Mdot
.35812 .59505 Mdot
.65339 .6371 Mdot
.53881 .85391 Mdot
.62878 .41334 Mdot
.48978 .315 Mdot
.48334 .36096 Mdot
.40221 .37852 Mdot
.58813 .62569 Mdot
.70761 .32473 Mdot
.66815 .23916 Mdot
.68143 .31389 Mdot
.36056 .4222 Mdot
.40507 .2586 Mdot
.53369 .29773 Mdot
.49251 .30488 Mdot
.6156 .48259 Mdot
.41528 .57724 Mdot
.40689 .56485 Mdot
.75205 .52037 Mdot
.37492 .6061 Mdot
.35132 .42527 Mdot
.64306 .44814 Mdot
.64918 .63808 Mdot
.38032 .42532 Mdot
.59501 .4381 Mdot
.62695 .64876 Mdot
.38524 .55859 Mdot
.39433 .55449 Mdot
.63051 .62695 Mdot
.60499 .63562 Mdot
.45511 .59842 Mdot
.74095 .34121 Mdot
.60391 .65118 Mdot
.65548 .63193 Mdot
.67238 .31925 Mdot
.53522 .33386 Mdot
.40499 .67626 Mdot
.61234 .46077 Mdot
.40382 .60194 Mdot
.53625 .32406 Mdot
.3734 .39084 Mdot
.62355 .63752 Mdot
.39577 .62192 Mdot
.41311 .61428 Mdot
.35487 .40839 Mdot
.38358 .44052 Mdot
.37143 .43315 Mdot
.61292 .39253 Mdot
.40208 .58189 Mdot
.6216 .61356 Mdot
.6287 .42475 Mdot
.34793 .43515 Mdot
.34606 .38966 Mdot
.78493 .35521 Mdot
.45832 .59506 Mdot
.51151 .50067 Mdot
.52301 .10307 Mdot
.28314 .47825 Mdot
.70787 .30392 Mdot
.47976 .28428 Mdot
.31338 .54452 Mdot
.40824 .36294 Mdot
.62124 .46675 Mdot
.25226 .43113 Mdot
.40213 .41963 Mdot
.41046 .65738 Mdot
.38534 .57178 Mdot
.48239 .61756 Mdot
.36937 .41348 Mdot
.34441 .48736 Mdot
.66389 .60752 Mdot
.48276 .76079 Mdot
.37098 .40649 Mdot
.5166 .29714 Mdot
.49434 .28244 Mdot
.505 .3523 Mdot
.37435 .57769 Mdot
.52549 .80852 Mdot
.52579 .71105 Mdot
.41223 .75004 Mdot
.63391 .42521 Mdot
.67546 .6489 Mdot
.30447 .32385 Mdot
.62698 .62402 Mdot
.49683 .29199 Mdot
.36722 .41668 Mdot
.65652 .64813 Mdot
.63231 .4626 Mdot
.61476 .45321 Mdot
.47401 .35324 Mdot
.48554 .35448 Mdot
.47898 .32449 Mdot
.62751 .66264 Mdot
.64487 .61183 Mdot
.39428 .63472 Mdot
.63027 .6364 Mdot
.74377 .67355 Mdot
.36464 .37755 Mdot
.50381 .28528 Mdot
.6267 .45945 Mdot
.60919 .61372 Mdot
.42892 .62341 Mdot
.42253 .2746 Mdot
.67514 .3988 Mdot
.3904 .42101 Mdot
.49439 .24212 Mdot
.65437 .84837 Mdot
.41568 .65043 Mdot
.5939 .44671 Mdot
.77448 .47621 Mdot
.44498 .62316 Mdot
.50474 .33546 Mdot
.38495 .7863 Mdot
.67907 .31648 Mdot
.45031 .57898 Mdot
.38034 .62584 Mdot
.63904 .41302 Mdot
.41875 .43593 Mdot
.38427 .62561 Mdot
.71786 .59299 Mdot
.65323 .45431 Mdot
.52466 .32316 Mdot
.60684 .17375 Mdot
.46808 .2914 Mdot
.29112 .64091 Mdot
.70715 .31108 Mdot
.40314 .6494 Mdot
.48669 .32583 Mdot
.39116 .41451 Mdot
.48174 .33005 Mdot
.60997 .59636 Mdot
.47974 .31471 Mdot
.43221 .60574 Mdot
.62468 .61251 Mdot
.62941 .46114 Mdot
.74399 .6407 Mdot
.76874 .35795 Mdot
.47719 .35032 Mdot
.67315 .30654 Mdot
.4536 .58335 Mdot
.4367 .7121 Mdot
.35283 .56299 Mdot
.43848 .57812 Mdot
.6175 .42813 Mdot
.62982 .59983 Mdot
.59482 .45995 Mdot
.3568 .63397 Mdot
.62856 .79181 Mdot
.60593 .41469 Mdot
.73109 .4727 Mdot
.36064 .42508 Mdot
.30043 .61126 Mdot
.42265 .62979 Mdot
.60612 .4365 Mdot
.40165 .58353 Mdot
.67 .63174 Mdot
.55104 .49744 Mdot
.78588 .42643 Mdot
.60604 .44339 Mdot
.35935 .21464 Mdot
.54662 .50536 Mdot
.41274 .68502 Mdot
.60477 .43314 Mdot
.46927 .80396 Mdot
.7021 .30215 Mdot
.36049 .415 Mdot
.35677 .44098 Mdot
.38557 .43185 Mdot
.37335 .60608 Mdot
.48397 .67063 Mdot
.34394 .39497 Mdot
.65576 .44402 Mdot
.38445 .39528 Mdot
.31284 .5829 Mdot
.34786 .22479 Mdot
.37828 .43196 Mdot
.41965 .62208 Mdot
.3579 .58897 Mdot
.27873 .56044 Mdot
.51857 .30334 Mdot
.22569 .34854 Mdot
.65089 .69944 Mdot
.44938 .58793 Mdot
.40155 .69176 Mdot
.62291 .59289 Mdot
.79875 .47544 Mdot
.37765 .68957 Mdot
.42845 .35579 Mdot
.6587 .61477 Mdot
.4954 .26702 Mdot
.61231 .60337 Mdot
.4306 .64924 Mdot
.41415 .59947 Mdot
.57688 .61891 Mdot
.57073 .32184 Mdot
.7271 .40491 Mdot
.47555 .18566 Mdot
.65949 .6407 Mdot
.60086 .44229 Mdot
.60074 .4635 Mdot
.62584 .42074 Mdot
.51498 .36018 Mdot
.61356 .65255 Mdot
.399 .57774 Mdot
.5124 .3198 Mdot
.4171 .64011 Mdot
.61591 .43333 Mdot
.55523 .15992 Mdot
.65205 .63721 Mdot
.45855 .61852 Mdot
.83838 .49962 Mdot
.49726 .34997 Mdot
.35949 .40429 Mdot
.45325 .41128 Mdot
.46936 .36433 Mdot
.62861 .47174 Mdot
.61003 .66579 Mdot
.64832 .40737 Mdot
.40792 .48278 Mdot
.48651 .60321 Mdot
.36387 .6194 Mdot
.6026 .18663 Mdot
.81844 .41857 Mdot
.37107 .59322 Mdot
.50504 .31167 Mdot
.5296 .31881 Mdot
.39948 .62421 Mdot
.62473 .65466 Mdot
.34084 .42364 Mdot
.39614 .41412 Mdot
.41359 .66272 Mdot
.51386 .44651 Mdot
.30977 .57443 Mdot
.39015 .61224 Mdot
.50288 .60436 Mdot
.46999 .35213 Mdot
.68991 .29741 Mdot
.75013 .57306 Mdot
.355 .43515 Mdot
.40823 .59966 Mdot
.71572 .42861 Mdot
.66171 .62374 Mdot
.48007 .31716 Mdot
.63992 .45086 Mdot
.37031 .47876 Mdot
.49055 .36604 Mdot
.3994 .62315 Mdot
.3923 .61914 Mdot
.63682 .41143 Mdot
.67429 .59905 Mdot
.36932 .41638 Mdot
.51171 .32108 Mdot
.34562 .42638 Mdot
.63801 .61291 Mdot
.64769 .63537 Mdot
.48835 .63575 Mdot
.42667 .53261 Mdot
.47966 .35649 Mdot
.45053 .65434 Mdot
.5003 .2897 Mdot
.41679 .42791 Mdot
.59206 .4194 Mdot
.38767 .64727 Mdot
.65238 .67257 Mdot
.62047 .43094 Mdot
.44945 .59995 Mdot
.68784 .23202 Mdot
.39159 .64274 Mdot
.47231 .36863 Mdot
.63712 .78721 Mdot
.37516 .39352 Mdot
.70603 .66267 Mdot
.47613 .53504 Mdot
.42743 .58998 Mdot
.49315 .28612 Mdot
.34894 .57635 Mdot
.61612 .41004 Mdot
.64946 .60811 Mdot
.80892 .6755 Mdot
.62361 .4432 Mdot
.41717 .58938 Mdot
.37867 .41184 Mdot
.66455 .6619 Mdot
.6875 .32259 Mdot
.75447 .56577 Mdot
.45268 .68066 Mdot
.40324 .54885 Mdot
.41618 .5795 Mdot
.29185 .72445 Mdot
.48715 .31862 Mdot
.60874 .61688 Mdot
.59734 .41902 Mdot
.63382 .44353 Mdot
.50955 .34522 Mdot
.70489 .53329 Mdot
.55993 .30011 Mdot
.43645 .09716 Mdot
.47039 .3233 Mdot
.38194 .39126 Mdot
.48454 .4396 Mdot
.48727 .29388 Mdot
.49258 .32466 Mdot
.48039 .36104 Mdot
.73161 .54497 Mdot
.63856 .64994 Mdot
.41225 .61387 Mdot
.58952 .61981 Mdot
.39841 .64871 Mdot
.28457 .66366 Mdot
.63211 .4353 Mdot
.64986 .60968 Mdot
.64783 .2064 Mdot
.34214 .57022 Mdot
.44314 .61622 Mdot
.33393 .27208 Mdot
.35632 .64334 Mdot
.32055 .49974 Mdot
.38809 .66574 Mdot
.48466 .3499 Mdot
.45082 .69127 Mdot
.37728 .54947 Mdot
.74292 .66793 Mdot
.62272 .46182 Mdot
.70812 .31642 Mdot
.41834 .55667 Mdot
.46182 .67164 Mdot
.66117 .6633 Mdot
.65703 .64792 Mdot
.34302 .39734 Mdot
.49566 .41618 Mdot
.62731 .46216 Mdot
.55635 .38088 Mdot
.44099 .58516 Mdot
.63236 .49942 Mdot
.64717 .76463 Mdot
.45106 .60175 Mdot
.26836 .33543 Mdot
.52653 .81343 Mdot
.38509 .6287 Mdot
.45395 .77351 Mdot
.62001 .45437 Mdot
.689 .73502 Mdot
.47331 .63337 Mdot
.50347 .33614 Mdot
.64207 .60736 Mdot
.61447 .59633 Mdot
.38449 .42664 Mdot
.78667 .62803 Mdot
.62033 .47752 Mdot
.6469 .61077 Mdot
.44122 .62645 Mdot
.63927 .44255 Mdot
.69702 .3238 Mdot
.36139 .57422 Mdot
.24155 .41886 Mdot
.63494 .63746 Mdot
.47615 .64099 Mdot
.64208 .52002 Mdot
.44449 .43141 Mdot
.18651 .38268 Mdot
.62035 .41892 Mdot
.36225 .43638 Mdot
.39897 .67141 Mdot
.6629 .2357 Mdot
.4713 .58905 Mdot
.29517 .59194 Mdot
.61694 .68049 Mdot
.34227 .41289 Mdot
.45061 .62345 Mdot
.38394 .62141 Mdot
.50345 .45238 Mdot
.37635 .44309 Mdot
.39009 .64483 Mdot
.49214 .62417 Mdot
.62587 .64748 Mdot
.70409 .32466 Mdot
.64205 .63952 Mdot
.42353 .62088 Mdot
.46836 .68581 Mdot
.63688 .65438 Mdot
.44722 .22386 Mdot
.39066 .44092 Mdot
.62696 .41382 Mdot
.50495 .63066 Mdot
.4273 .56897 Mdot
.19095 .63043 Mdot
.71016 .31067 Mdot
.35862 .77706 Mdot
.46467 .31547 Mdot
.68187 .38367 Mdot
.54475 .36047 Mdot
.28127 .26698 Mdot
.74229 .61787 Mdot
.48569 .62159 Mdot
.23491 .48941 Mdot
.43673 .76296 Mdot
.60901 .47386 Mdot
.47457 .71231 Mdot
.44234 .58442 Mdot
.43862 .63939 Mdot
.51208 .30645 Mdot
.69675 .54421 Mdot
.77063 .47973 Mdot
.52817 .44873 Mdot
.37153 .42045 Mdot
.64569 .6168 Mdot
.4334 .59815 Mdot
.55943 .25407 Mdot
.47664 .31436 Mdot
.59157 .53258 Mdot
.45511 .6265 Mdot
.78392 .523 Mdot
.73287 .50378 Mdot
.63998 .44085 Mdot
.48131 .28527 Mdot
.46954 .36352 Mdot
.44066 .64404 Mdot
.63446 .46458 Mdot
.3916 .63401 Mdot
.57345 .51861 Mdot
.4648 .64819 Mdot
.38446 .41589 Mdot
.46665 .61024 Mdot
.49136 .46988 Mdot
.23023 .30319 Mdot
.37634 .67455 Mdot
.59869 .6354 Mdot
.51164 .36132 Mdot
.50009 .35461 Mdot
.6573 .64161 Mdot
.50252 .35221 Mdot
.49259 .76704 Mdot
.63692 .73762 Mdot
.37069 .42496 Mdot
.44637 .70252 Mdot
.38413 .41067 Mdot
.70902 .31534 Mdot
.45548 .59221 Mdot
.68152 .25408 Mdot
.46999 .33164 Mdot
.45469 .82545 Mdot
.6288 .44603 Mdot
.70936 .31237 Mdot
.46078 .57841 Mdot
.39975 .26222 Mdot
.50726 .29653 Mdot
.45465 .34155 Mdot
.39802 .63339 Mdot
.65228 .64797 Mdot
.38416 .62006 Mdot
.42663 .66721 Mdot
.70295 .29454 Mdot
.41459 .57828 Mdot
.59508 .43891 Mdot
.6183 .65632 Mdot
.30063 .26395 Mdot
.52695 .3483 Mdot
.46438 .61935 Mdot
.44245 .62623 Mdot
.67158 .62959 Mdot
.45791 .57776 Mdot
.62601 .46877 Mdot
.17798 .29182 Mdot
.35994 .42385 Mdot
.68295 .30208 Mdot
.46336 .36404 Mdot
.39884 .56674 Mdot
.38708 .61328 Mdot
.59064 .18213 Mdot
.75176 .38906 Mdot
.59636 .43693 Mdot
.39903 .66419 Mdot
.50485 .31566 Mdot
.38013 .41438 Mdot
.65261 .44022 Mdot
.40124 .60368 Mdot
.44918 .6356 Mdot
.38396 .41785 Mdot
.28608 .31449 Mdot
.43479 .32485 Mdot
.63106 .42255 Mdot
.43807 .69701 Mdot
.42652 .28127 Mdot
.42113 .63564 Mdot
.49291 .21298 Mdot
.65381 .63161 Mdot
.60768 .42757 Mdot
.37053 .7519 Mdot
.43217 .65307 Mdot
.62077 .46976 Mdot
.6268 .46153 Mdot
.46984 .62025 Mdot
.58873 .6277 Mdot
.64167 .66465 Mdot
.65814 .62833 Mdot
.63711 .79396 Mdot
.2517 .59225 Mdot
.4784 .32584 Mdot
.61868 .45501 Mdot
.52708 .30666 Mdot
.34169 .42851 Mdot
.46664 .42588 Mdot
.52621 .30845 Mdot
.61999 .59422 Mdot
.49601 .28215 Mdot
.38978 .62767 Mdot
.62716 .46384 Mdot
.49193 .30427 Mdot
.38812 .57193 Mdot
.4923 .57314 Mdot
.53411 .51327 Mdot
.34009 .41888 Mdot
.43308 .39318 Mdot
.41998 .60189 Mdot
.70322 .29695 Mdot
.4577 .6029 Mdot
.64231 .43961 Mdot
.47091 .46113 Mdot
.3874 .57428 Mdot
.47742 .35299 Mdot
.45611 .50418 Mdot
.52556 .31938 Mdot
.44434 .66711 Mdot
.42281 .6194 Mdot
.42475 .6376 Mdot
.38398 .62563 Mdot
.72736 .4913 Mdot
.59762 .46799 Mdot
.51023 .60638 Mdot
.54062 .32653 Mdot
.62319 .62921 Mdot
.66501 .60423 Mdot
.4506 .25657 Mdot
.69356 .29375 Mdot
.61475 .46062 Mdot
.41876 .63523 Mdot
.45387 .3375 Mdot
.54513 .15959 Mdot
.4862 .20478 Mdot
.30883 .32974 Mdot
.50035 .30782 Mdot
.59927 .63469 Mdot
.48568 .3 Mdot
.43172 .64423 Mdot
.36438 .6402 Mdot
.2868 .26947 Mdot
.58031 .44573 Mdot
.36764 .41558 Mdot
.42136 .64136 Mdot
.29318 .64795 Mdot
.50572 .31536 Mdot
.46808 .34883 Mdot
.39969 .64476 Mdot
.65298 .659 Mdot
.14556 .42553 Mdot
.6408 .44864 Mdot
.44437 .7128 Mdot
.68331 .6782 Mdot
.69581 .59392 Mdot
.63655 .44626 Mdot
.54413 .53592 Mdot
.51569 .34684 Mdot
.68659 .69809 Mdot
.62745 .62962 Mdot
.36661 .41152 Mdot
.36714 .63878 Mdot
.61492 .59677 Mdot
.47518 .28657 Mdot
.62983 .59613 Mdot
.4247 .65264 Mdot
.60207 .47065 Mdot
.51309 .34377 Mdot
.63134 .4912 Mdot
.57691 .6168 Mdot
.38308 .4023 Mdot
.30171 .61472 Mdot
.47123 .70813 Mdot
.52461 .8141 Mdot
.38451 .58029 Mdot
.44837 .30197 Mdot
.39949 .58374 Mdot
.65944 .66291 Mdot
.42185 .62859 Mdot
.56171 .63669 Mdot
.47008 .30485 Mdot
.4761 .64036 Mdot
.45666 .58302 Mdot
.53999 .66921 Mdot
.44902 .61219 Mdot
.46495 .58766 Mdot
.3801 .62001 Mdot
.67615 .68403 Mdot
.48729 .63048 Mdot
.64486 .65048 Mdot
.74577 .52699 Mdot
.49188 .32716 Mdot
.33789 .40204 Mdot
.39445 .42241 Mdot
.29919 .58503 Mdot
.29912 .61462 Mdot
.70857 .53663 Mdot
.64075 .64427 Mdot
.60075 .45528 Mdot
.39231 .63484 Mdot
.36473 .74274 Mdot
.40634 .4115 Mdot
.51474 .34633 Mdot
.51022 .36625 Mdot
.41135 .53145 Mdot
.28254 .71809 Mdot
.47909 .63965 Mdot
.76005 .56588 Mdot
.4273 .66043 Mdot
.38483 .64123 Mdot
.48481 .36799 Mdot
.35513 .51458 Mdot
.38418 .58039 Mdot
.66149 .66319 Mdot
.36382 .40815 Mdot
.3621 .67035 Mdot
.31899 .39111 Mdot
.56527 .53176 Mdot
.56585 .66658 Mdot
.40571 .57436 Mdot
.51355 .32728 Mdot
.60652 .60766 Mdot
.76338 .59098 Mdot
.62583 .42407 Mdot
.72931 .56955 Mdot
.53206 .69214 Mdot
.40862 .23308 Mdot
.36468 .41254 Mdot
.28059 .32696 Mdot
.43192 .60531 Mdot
.50643 .36438 Mdot
.41245 .65277 Mdot
.53671 .16021 Mdot
.3614 .39056 Mdot
.62761 .58517 Mdot
.60068 .44429 Mdot
.66897 .63013 Mdot
.54561 .79662 Mdot
.53831 .5639 Mdot
.68039 .34588 Mdot
.53448 .33182 Mdot
.32261 .70473 Mdot
.62111 .60854 Mdot
.39828 .61448 Mdot
.46612 .09626 Mdot
.65308 .63014 Mdot
.66285 .64053 Mdot
.42494 .41005 Mdot
.32348 .45554 Mdot
.3506 .57673 Mdot
.63789 .59664 Mdot
.52243 .29682 Mdot
.3594 .39912 Mdot
.3795 .59484 Mdot
.38113 .61893 Mdot
.65031 .65175 Mdot
.50318 .29345 Mdot
.31223 .70359 Mdot
.48513 .35264 Mdot
.61941 .64506 Mdot
.49434 .34592 Mdot
.46495 .37398 Mdot
.49244 .30899 Mdot
.4405 .57106 Mdot
.41681 .63313 Mdot
.32344 .35497 Mdot
.64748 .63539 Mdot
.38475 .6046 Mdot
.41014 .60381 Mdot
.62033 .61209 Mdot
.53119 .29599 Mdot
.34901 .73574 Mdot
.42868 .58021 Mdot
.41192 .62239 Mdot
.3436 .42036 Mdot
.52789 .27595 Mdot
.54833 .23406 Mdot
.38144 .59821 Mdot
.39493 .4057 Mdot
.62437 .66229 Mdot
.45634 .6018 Mdot
.3188 .56951 Mdot
.50613 .37375 Mdot
.46687 .62203 Mdot
.68695 .32352 Mdot
.40324 .56517 Mdot
.15194 .41634 Mdot
.4638 .60633 Mdot
.60975 .62102 Mdot
.63446 .60407 Mdot
.447 .39685 Mdot
.63443 .62101 Mdot
.7058 .31618 Mdot
.61667 .43448 Mdot
.44597 .19198 Mdot
.69972 .32128 Mdot
.37929 .63486 Mdot
.83729 .52667 Mdot
.45402 .65091 Mdot
.41364 .55758 Mdot
.35413 .75718 Mdot
.70097 .31941 Mdot
.62328 .60224 Mdot
.5726 .32844 Mdot
.40659 .66292 Mdot
.63992 .45374 Mdot
.36022 .58923 Mdot
.46861 .61143 Mdot
.70509 .59124 Mdot
.58751 .81124 Mdot
.643 .43404 Mdot
.38887 .67105 Mdot
.38186 .59759 Mdot
.79998 .40008 Mdot
.43556 .62179 Mdot
.38074 .43037 Mdot
.66203 .63376 Mdot
.47654 .30467 Mdot
.35429 .41781 Mdot
.43241 .58556 Mdot
.37034 .41067 Mdot
.48022 .3199 Mdot
.61428 .42771 Mdot
.46294 .6259 Mdot
.39888 .40898 Mdot
.37144 .4187 Mdot
.39513 .59043 Mdot
.64677 .60888 Mdot
.33464 .61296 Mdot
.45493 .60106 Mdot
.3994 .61764 Mdot
.65501 .64297 Mdot
.84654 .40414 Mdot
.42952 .64727 Mdot
.51754 .50487 Mdot
.6163 .5889 Mdot
.68358 .33085 Mdot
.49019 .30048 Mdot
.46523 .63406 Mdot
.63423 .43453 Mdot
.62749 .43157 Mdot
.49389 .27492 Mdot
.67094 .63708 Mdot
.51591 .30175 Mdot
.36715 .66204 Mdot
.43534 .53573 Mdot
.38868 .65872 Mdot
.80006 .68334 Mdot
.27808 .29178 Mdot
.61457 .65127 Mdot
.52126 .33787 Mdot
.52967 .44676 Mdot
.61348 .45687 Mdot
.49819 .2805 Mdot
.63821 .67307 Mdot
.60263 .63504 Mdot
.6328 .59416 Mdot
.3464 .42344 Mdot
.50163 .362 Mdot
.66612 .59252 Mdot
.65914 .65462 Mdot
.39472 .63153 Mdot
.38271 .59797 Mdot
.56764 .6363 Mdot
.28585 .53782 Mdot
.38521 .40616 Mdot
.51118 .33385 Mdot
.17082 .6255 Mdot
.6422 .43804 Mdot
.54235 .66789 Mdot
.39491 .5686 Mdot
.65267 .14405 Mdot
.4735 .65166 Mdot
.43926 .62533 Mdot
.61706 .65773 Mdot
.38342 .389 Mdot
.37341 .40091 Mdot
.62318 .60756 Mdot
.57946 .64108 Mdot
.37138 .43592 Mdot
.29464 .33496 Mdot
.36377 .20751 Mdot
.75292 .59076 Mdot
.61272 .61957 Mdot
.47484 .70358 Mdot
.62975 .47041 Mdot
.58223 .61118 Mdot
.63927 .42309 Mdot
.49369 .32527 Mdot
.48988 .36334 Mdot
.63723 .4128 Mdot
.4009 .6347 Mdot
.48338 .31234 Mdot
.46066 .67883 Mdot
.31789 .26864 Mdot
.19137 .4884 Mdot
.73231 .36808 Mdot
.39319 .56616 Mdot
.76964 .49339 Mdot
.76296 .44671 Mdot
.42409 .59535 Mdot
.32311 .61238 Mdot
.36801 .41366 Mdot
.58874 .60181 Mdot
.62856 .46748 Mdot
.18147 .3956 Mdot
.4202 .63545 Mdot
.61423 .63225 Mdot
.6196 .46228 Mdot
.50077 .39593 Mdot
.71116 .58651 Mdot
.40288 .64816 Mdot
.34766 .1484 Mdot
.60047 .59142 Mdot
.47613 .30498 Mdot
.81356 .57492 Mdot
.59059 .6122 Mdot
.42611 .39264 Mdot
.4647 .34613 Mdot
.49767 .18976 Mdot
.60752 .61361 Mdot
.49449 .27136 Mdot
.63705 .61475 Mdot
.3864 .41812 Mdot
.60059 .65615 Mdot
.51533 .33906 Mdot
.4516 .61854 Mdot
.50681 .34608 Mdot
.38679 .4077 Mdot
.51152 .36343 Mdot
.62997 .46821 Mdot
.70722 .30587 Mdot
.61368 .44704 Mdot
.45655 .42261 Mdot
.60541 .80359 Mdot
.61284 .41642 Mdot
.5483 .37021 Mdot
.37228 .5898 Mdot
.67754 .60317 Mdot
.47131 .31282 Mdot
.53497 .31295 Mdot
.48515 .42805 Mdot
.61956 .62405 Mdot
.51239 .34041 Mdot
.52246 .6982 Mdot
.86752 .4907 Mdot
.4941 .65555 Mdot
.24088 .55488 Mdot
.61797 .61397 Mdot
.46658 .31629 Mdot
.76387 .58084 Mdot
.64343 .59391 Mdot
.47072 .32456 Mdot
.6036 .43669 Mdot
.63484 .44448 Mdot
.40951 .64254 Mdot
.59664 .47824 Mdot
.48473 .28738 Mdot
.72485 .41489 Mdot
.66478 .62949 Mdot
.50072 .39685 Mdot
.3837 .43051 Mdot
.49267 .31928 Mdot
.38797 .54329 Mdot
.57815 .6436 Mdot
.53321 .34739 Mdot
.22345 .45924 Mdot
.19498 .65989 Mdot
.51061 .34129 Mdot
.66254 .63282 Mdot
.62222 .63836 Mdot
.3448 .61547 Mdot
.50943 .44557 Mdot
.51626 .30449 Mdot
.68474 .26696 Mdot
.29092 .60064 Mdot
.68909 .31176 Mdot
.82564 .42207 Mdot
.38534 .57837 Mdot
.40237 .58536 Mdot
.60994 .45669 Mdot
.43901 .61083 Mdot
.65045 .66161 Mdot
.42304 .56098 Mdot
.61285 .46837 Mdot
.51683 .34275 Mdot
.46299 .61293 Mdot
.37019 .39509 Mdot
.63793 .4683 Mdot
.64403 .41875 Mdot
.48871 .33733 Mdot
.63629 .59555 Mdot
.53689 .25273 Mdot
.48663 .35492 Mdot
.40473 .5734 Mdot
.69921 .31512 Mdot
.44089 .6492 Mdot
.26752 .38248 Mdot
.66629 .61171 Mdot
.48354 .30022 Mdot
.60279 .60617 Mdot
.61775 .44668 Mdot
.5129 .28306 Mdot
.43158 .61824 Mdot
.47157 .33215 Mdot
.36068 .3575 Mdot
.28255 .35472 Mdot
.67041 .64414 Mdot
.32853 .3888 Mdot
.66381 .6428 Mdot
.68803 .31295 Mdot
.27345 .42751 Mdot
.36323 .42005 Mdot
.50125 .31648 Mdot
.26734 .30071 Mdot
.47255 .3471 Mdot
.44883 .60979 Mdot
.44293 .59525 Mdot
.50988 .30515 Mdot
.3535 .39812 Mdot
.54337 .85075 Mdot
.53225 .53263 Mdot
.62152 .60067 Mdot
.67907 .69403 Mdot
.13886 .55582 Mdot
.65104 .46436 Mdot
.60357 .45326 Mdot
.46049 .66616 Mdot
.38863 .63943 Mdot
.65028 .4252 Mdot
.59122 .42917 Mdot
.34222 .42188 Mdot
.49036 .36133 Mdot
.68796 .60877 Mdot
.64878 .45796 Mdot
.44159 .51147 Mdot
.29512 .64117 Mdot
.34718 .61842 Mdot
.48728 .58844 Mdot
.3817 .56934 Mdot
.4392 .42987 Mdot
.59196 .43854 Mdot
.41848 .60419 Mdot
.48535 .64111 Mdot
.60301 .43034 Mdot
.38594 .41617 Mdot
.62292 .5669 Mdot
.49973 .34167 Mdot
.81019 .31277 Mdot
.4659 .61985 Mdot
.4542 .6128 Mdot
.63418 .42561 Mdot
.8101 .39042 Mdot
.60925 .64134 Mdot
.65808 .60589 Mdot
.48637 .3179 Mdot
.4858 .42552 Mdot
.44046 .56825 Mdot
.42261 .59797 Mdot
.50228 .3233 Mdot
.70607 .30326 Mdot
.70744 .3633 Mdot
.41412 .6146 Mdot
.62623 .45798 Mdot
.44414 .35414 Mdot
.59151 .43745 Mdot
.41301 .65118 Mdot
.44759 .60726 Mdot
.44294 .57177 Mdot
.38668 .63834 Mdot
.64688 .42651 Mdot
.42426 .60283 Mdot
.39576 .53824 Mdot
.64721 .60331 Mdot
.41541 .57225 Mdot
.30752 .56683 Mdot
.41482 .62435 Mdot
.37449 .39651 Mdot
.54576 .24592 Mdot
.42282 .6392 Mdot
.41582 .57341 Mdot
.53142 .52768 Mdot
.44868 .62761 Mdot
.64101 .43381 Mdot
.62418 .63313 Mdot
.61793 .45495 Mdot
.60082 .41539 Mdot
.53028 .30855 Mdot
.34125 .41884 Mdot
.46934 .58321 Mdot
.38937 .42702 Mdot
.45447 .55615 Mdot
.42137 .65357 Mdot
.48054 .26606 Mdot
.75864 .56328 Mdot
.41757 .36285 Mdot
.42854 .61978 Mdot
.48856 .3224 Mdot
.47733 .30624 Mdot
.23034 .47845 Mdot
.41936 .68869 Mdot
.65121 .43136 Mdot
.6059 .43705 Mdot
.29326 .49302 Mdot
.71513 .60214 Mdot
.38083 .4008 Mdot
.54471 .45445 Mdot
.37835 .57513 Mdot
.4079 .61371 Mdot
.35861 .59163 Mdot
.52704 .30899 Mdot
.69978 .29361 Mdot
.51277 .3503 Mdot
.67486 .33472 Mdot
.59203 .44733 Mdot
.40797 .56465 Mdot
.19258 .46279 Mdot
.64438 .65605 Mdot
.6252 .63343 Mdot
.65574 .4365 Mdot
.52374 .31293 Mdot
.34452 .59669 Mdot
.81128 .67804 Mdot
.59562 .5897 Mdot
.35778 .38346 Mdot
.42077 .59452 Mdot
.4877 .33255 Mdot
.64816 .6572 Mdot
.3962 .42685 Mdot
.4296 .57403 Mdot
.54138 .32379 Mdot
.41915 .62832 Mdot
.43 .76566 Mdot
.64084 .60187 Mdot
.5439 .1565 Mdot
.67386 .63957 Mdot
.63493 .47147 Mdot
.60325 .42167 Mdot
.4493 .60158 Mdot
.80921 .64124 Mdot
.62316 .58473 Mdot
.62402 .49017 Mdot
.37037 .38696 Mdot
.68413 .30148 Mdot
.34924 .39382 Mdot
.48866 .29201 Mdot
.36329 .41056 Mdot
.48303 .36073 Mdot
.28871 .50695 Mdot
.62211 .57907 Mdot
.35705 .42125 Mdot
.78464 .36566 Mdot
.44478 .5587 Mdot
.34951 .4362 Mdot
.4115 .53299 Mdot
.68955 .68741 Mdot
.50138 .32702 Mdot
.35578 .39724 Mdot
.39645 .61607 Mdot
.1797 .41781 Mdot
.60247 .41828 Mdot
.65088 .43407 Mdot
.46065 .56663 Mdot
.47664 .35999 Mdot
.58215 .64287 Mdot
.42187 .47234 Mdot
.68935 .33235 Mdot
.42276 .60026 Mdot
.40696 .5643 Mdot
.67232 .61307 Mdot
.67337 .65394 Mdot
.44677 .6043 Mdot
.4957 .70892 Mdot
.43154 .60301 Mdot
.63694 .44089 Mdot
.60471 .63676 Mdot
.62425 .63734 Mdot
.48401 .2853 Mdot
.66821 .64155 Mdot
.49306 .59923 Mdot
.58532 .40354 Mdot
.38694 .66029 Mdot
.62121 .4421 Mdot
.47882 .46644 Mdot
.5209 .35617 Mdot
.20341 .3737 Mdot
.67455 .6195 Mdot
.41551 .57662 Mdot
.66632 .63922 Mdot
.36867 .43276 Mdot
.6444 .63579 Mdot
.595 .63054 Mdot
.44321 .58877 Mdot
.40334 .64924 Mdot
.70354 .31491 Mdot
.50841 .44137 Mdot
.65544 .61626 Mdot
.4296 .59803 Mdot
.46296 .64591 Mdot
.47091 .60262 Mdot
.52213 .48317 Mdot
.60561 .64526 Mdot
.58749 .72113 Mdot
.22965 .42354 Mdot
.65074 .61247 Mdot
.14562 .45517 Mdot
.68218 .32026 Mdot
.68874 .2965 Mdot
.64114 .47519 Mdot
.41204 .61584 Mdot
.52328 .32347 Mdot
.43543 .64356 Mdot
.46937 .67248 Mdot
.44708 .63733 Mdot
.37526 .39066 Mdot
.47437 .58842 Mdot
.69112 .30436 Mdot
.4905 .35576 Mdot
.42701 .57725 Mdot
.46297 .61933 Mdot
.69925 .29139 Mdot
.67645 .62698 Mdot
.60188 .62632 Mdot
.48678 .21226 Mdot
.37333 .42748 Mdot
.62009 .42646 Mdot
.40826 .63849 Mdot
.48801 .32029 Mdot
.50413 .34891 Mdot
.66813 .63297 Mdot
.50477 .33816 Mdot
.64161 .44592 Mdot
.43618 .61806 Mdot
.64993 .42963 Mdot
.37856 .39285 Mdot
.66124 .63495 Mdot
.40976 .63971 Mdot
.39517 .63145 Mdot
.63425 .60393 Mdot
.37225 .58936 Mdot
.34381 .42104 Mdot
.48293 .35715 Mdot
.60373 .62256 Mdot
.61927 .43298 Mdot
.48936 .28409 Mdot
.39109 .6233 Mdot
.22497 .69071 Mdot
.43753 .60805 Mdot
.40186 .62263 Mdot
.32246 .2368 Mdot
.4559 .66659 Mdot
.47279 .3018 Mdot
.65833 .59817 Mdot
.39768 .55436 Mdot
.2816 .6406 Mdot
.61382 .20097 Mdot
.50261 .28096 Mdot
.4195 .58693 Mdot
.21691 .3537 Mdot
.42223 .5812 Mdot
.55528 .38738 Mdot
.44126 .2882 Mdot
.251 .63775 Mdot
.48253 .58015 Mdot
.63739 .41782 Mdot
.7048 .3143 Mdot
.46681 .32943 Mdot
.48084 .80032 Mdot
.43596 .58961 Mdot
.4623 .80384 Mdot
.46335 .59175 Mdot
.63575 .44731 Mdot
.35297 .54966 Mdot
.51006 .33521 Mdot
.76733 .64638 Mdot
.40026 .57746 Mdot
.60581 .64449 Mdot
.50494 .28558 Mdot
.68011 .3096 Mdot
.39607 .62119 Mdot
.39336 .41746 Mdot
.57414 .47368 Mdot
.46707 .55634 Mdot
.62191 .43912 Mdot
.4088 .60309 Mdot
.39857 .67683 Mdot
.79881 .63409 Mdot
.63774 .59991 Mdot
.60254 .44903 Mdot
.79608 .46235 Mdot
.36946 .59624 Mdot
.606 .61607 Mdot
.62605 .62891 Mdot
.38849 .42026 Mdot
.58231 .49724 Mdot
.67823 .47973 Mdot
.18807 .53111 Mdot
.57584 .79967 Mdot
.47774 .28782 Mdot
.74175 .4137 Mdot
.38197 .59131 Mdot
.54818 .56504 Mdot
.63882 .42564 Mdot
.45386 .61624 Mdot
.61549 .78551 Mdot
.6577 .62981 Mdot
.41697 .61664 Mdot
.38488 .41298 Mdot
.57235 .4797 Mdot
.57681 .53875 Mdot
.18556 .60795 Mdot
.51176 .2871 Mdot
.3619 .63017 Mdot
.46757 .56373 Mdot
.67988 .3276 Mdot
.40952 .65541 Mdot
.46833 .31953 Mdot
.32179 .27699 Mdot
.35509 .39604 Mdot
.65745 .65194 Mdot
.68154 .31947 Mdot
.3914 .56202 Mdot
.47315 .62837 Mdot
.33837 .40002 Mdot
.39945 .60005 Mdot
.78892 .61769 Mdot
.66456 .34401 Mdot
.48697 .30847 Mdot
.6249 .59593 Mdot
.37286 .57917 Mdot
.69986 .29398 Mdot
.44286 .59089 Mdot
.54402 .62916 Mdot
.40778 .58484 Mdot
.64242 .52452 Mdot
.64197 .60797 Mdot
.61821 .44007 Mdot
.44941 .55611 Mdot
.43879 .63698 Mdot
.42394 .27885 Mdot
.46972 .67206 Mdot
.46455 .60973 Mdot
.66192 .66353 Mdot
.62988 .65518 Mdot
.64663 .64904 Mdot
.47917 .31431 Mdot
.75167 .58137 Mdot
.62613 .45169 Mdot
.44899 .56923 Mdot
.649 .45727 Mdot
.50872 .56892 Mdot
.34472 .38986 Mdot
.15861 .47941 Mdot
.42291 .5727 Mdot
.64265 .64749 Mdot
.71457 .44428 Mdot
.62683 .6629 Mdot
.54304 .33972 Mdot
.62747 .46238 Mdot
.65404 .62837 Mdot
.43904 .63183 Mdot
.52209 .45261 Mdot
.20696 .62758 Mdot
.61156 .45263 Mdot
.35732 .60654 Mdot
.51534 .28827 Mdot
.51501 .36521 Mdot
.1197 .5021 Mdot
.59646 .4317 Mdot
.76232 .44058 Mdot
.42871 .59391 Mdot
.64452 .65529 Mdot
.62074 .41701 Mdot
.62706 .41069 Mdot
.50379 .32916 Mdot
.40757 .64802 Mdot
.4273 .63621 Mdot
.68578 .32288 Mdot
.60864 .43473 Mdot
.42537 .55243 Mdot
.41785 .65962 Mdot
.2885 .26601 Mdot
.63867 .5689 Mdot
.82986 .36881 Mdot
.36799 .66275 Mdot
.57399 .80456 Mdot
.47174 .44428 Mdot
.61735 .65442 Mdot
.41692 .64351 Mdot
.37333 .5724 Mdot
.47971 .28965 Mdot
.43601 .61327 Mdot
.52675 .33341 Mdot
.6042 .45642 Mdot
.15534 .49461 Mdot
.63124 .38117 Mdot
.3019 .32197 Mdot
.44363 .61366 Mdot
.68182 .57391 Mdot
.35312 .42338 Mdot
.62168 .3946 Mdot
.6148 .64313 Mdot
.36543 .6 Mdot
.47349 .36809 Mdot
.50209 .31572 Mdot
.63492 .62724 Mdot
.75314 .47175 Mdot
.47126 .22733 Mdot
.39263 .64952 Mdot
.49275 .29819 Mdot
.65006 .37212 Mdot
.48965 .718 Mdot
.58129 .44425 Mdot
.35757 .39367 Mdot
.51618 .34287 Mdot
.63678 .40961 Mdot
.56425 .60411 Mdot
.64471 .62355 Mdot
.65108 .59126 Mdot
.38252 .33383 Mdot
.52 .31054 Mdot
.35259 .40967 Mdot
.73374 .60181 Mdot
.73817 .62676 Mdot
.37102 .39004 Mdot
.51787 .34176 Mdot
.63825 .65741 Mdot
.61421 .63722 Mdot
.62298 .63295 Mdot
.76203 .65124 Mdot
.66579 .61373 Mdot
.60362 .70737 Mdot
.45987 .64669 Mdot
.42993 .71212 Mdot
.42166 .58288 Mdot
.64535 .42935 Mdot
.63885 .60168 Mdot
.48276 .43516 Mdot
.37455 .6216 Mdot
.18841 .60497 Mdot
.42008 .59976 Mdot
.58176 .41888 Mdot
.41152 .61874 Mdot
.50748 .68113 Mdot
.61377 .58937 Mdot
.42859 .61772 Mdot
.58513 .43359 Mdot
.37379 .41664 Mdot
.69185 .63927 Mdot
.42372 .63899 Mdot
.68122 .54732 Mdot
.4783 .64902 Mdot
.32393 .26791 Mdot
.39354 .4749 Mdot
.36656 .3831 Mdot
.49072 .62885 Mdot
.4803 .28186 Mdot
.67534 .67439 Mdot
.41051 .70906 Mdot
.61114 .45116 Mdot
.44687 .81651 Mdot
.49832 .31455 Mdot
.35028 .55276 Mdot
.40547 .66455 Mdot
.34895 .43083 Mdot
.64777 .67999 Mdot
.63683 .42621 Mdot
.39532 .56663 Mdot
.47073 .616 Mdot
.28856 .38029 Mdot
.43253 .70692 Mdot
.46772 .58698 Mdot
.33821 .41741 Mdot
.59757 .72578 Mdot
.40895 .62901 Mdot
.53149 .29766 Mdot
.63092 .58887 Mdot
.47364 .58085 Mdot
.58265 .71659 Mdot
.43093 .59677 Mdot
.64783 .62993 Mdot
.67266 .61103 Mdot
.70202 .50437 Mdot
.37372 .38527 Mdot
.4076 .58524 Mdot
.39425 .46199 Mdot
.40263 .57994 Mdot
.62923 .45282 Mdot
.43002 .6478 Mdot
.49673 .32203 Mdot
.76609 .57576 Mdot
.475 .32696 Mdot
.42985 .64596 Mdot
.61771 .6305 Mdot
.63115 .41782 Mdot
.33644 .34712 Mdot
.44404 .27518 Mdot
.60537 .71049 Mdot
.6632 .2154 Mdot
.34729 .40952 Mdot
.36386 .44425 Mdot
.6113 .47884 Mdot
.4247 .62013 Mdot
.42919 .41427 Mdot
.4587 .65636 Mdot
.4105 .62291 Mdot
.4494 .63716 Mdot
.60005 .48311 Mdot
.61754 .45839 Mdot
.4996 .34717 Mdot
.44569 .60534 Mdot
.42906 .5996 Mdot
.64998 .61653 Mdot
.37334 .41893 Mdot
.47467 .31908 Mdot
.3659 .42813 Mdot
.48252 .34464 Mdot
.1509 .42055 Mdot
.35713 .63684 Mdot
.37553 .41589 Mdot
.60723 .47765 Mdot
.65525 .64382 Mdot
.71097 .30691 Mdot
.48972 .28992 Mdot
.51187 .33572 Mdot
.42391 .5989 Mdot
.65594 .63779 Mdot
.66296 .62271 Mdot
.35868 .43288 Mdot
.61413 .42283 Mdot
.42936 .64547 Mdot
.40048 .65162 Mdot
.21591 .52594 Mdot
.51394 .29515 Mdot
.51683 .71071 Mdot
.71231 .51113 Mdot
.42548 .62108 Mdot
.64169 .59917 Mdot
.46106 .60782 Mdot
.21127 .38332 Mdot
.61781 .59521 Mdot
.38705 .64254 Mdot
.72223 .62092 Mdot
.53217 .32026 Mdot
.66831 .51346 Mdot
.47968 .62306 Mdot
.58322 .18001 Mdot
.38897 .58782 Mdot
.28071 .24453 Mdot
.77168 .39592 Mdot
.41982 .56147 Mdot
.38069 .61299 Mdot
.19903 .57013 Mdot
.42765 .5885 Mdot
.68651 .30959 Mdot
.37548 .67136 Mdot
.6016 .63314 Mdot
.43179 .44977 Mdot
.5459 .34447 Mdot
.37601 .38771 Mdot
.48632 .31732 Mdot
.34231 .36933 Mdot
.38487 .41985 Mdot
.61295 .6168 Mdot
.38121 .62068 Mdot
.30269 .62406 Mdot
.5361 .35173 Mdot
.4346 .66634 Mdot
.63042 .45315 Mdot
.54808 .32857 Mdot
.52218 .34685 Mdot
.61553 .43664 Mdot
.45958 .58472 Mdot
.3155 .72089 Mdot
.46346 .25556 Mdot
.47293 .17722 Mdot
.63147 .42288 Mdot
.63681 .45169 Mdot
.76872 .59476 Mdot
.3778 .38871 Mdot
.2665 .40252 Mdot
.63429 .55523 Mdot
.63892 .4603 Mdot
.30419 .47112 Mdot
.47088 .35614 Mdot
.67849 .55186 Mdot
.58861 .60218 Mdot
.35471 .62515 Mdot
.43895 .63354 Mdot
.60978 .42403 Mdot
.3095 .62995 Mdot
.80118 .57477 Mdot
.61274 .44748 Mdot
.43554 .54307 Mdot
.57191 .48262 Mdot
.69551 .31735 Mdot
.68624 .32529 Mdot
.35864 .3861 Mdot
.45153 .2262 Mdot
.63398 .6119 Mdot
.35642 .43698 Mdot
.62379 .51245 Mdot
.40625 .5913 Mdot
.60676 .44192 Mdot
.71222 .30405 Mdot
.62983 .4356 Mdot
.37775 .40389 Mdot
.35651 .38374 Mdot
.64529 .60237 Mdot
.60936 .64094 Mdot
.56565 .81032 Mdot
.30746 .50794 Mdot
.42401 .57927 Mdot
.37909 .76553 Mdot
.6659 .6317 Mdot
.43763 .70064 Mdot
.39305 .4021 Mdot
.37599 .4201 Mdot
.45527 .75965 Mdot
.39559 .63819 Mdot
.48491 .39476 Mdot
.41572 .63616 Mdot
.26628 .43957 Mdot
.38581 .6479 Mdot
.50374 .33308 Mdot
.39825 .57101 Mdot
.54721 .2608 Mdot
.37517 .59628 Mdot
.46534 .61842 Mdot
.50341 .35745 Mdot
.36033 .56951 Mdot
.49783 .32061 Mdot
.41166 .65008 Mdot
.34332 .43678 Mdot
.48769 .32023 Mdot
.25055 .56892 Mdot
.51923 .5059 Mdot
.69694 .29694 Mdot
.38738 .40328 Mdot
.38485 .43074 Mdot
.29689 .60296 Mdot
.61215 .64014 Mdot
.5995 .57874 Mdot
.42383 .61947 Mdot
.46795 .34781 Mdot
.61001 .45773 Mdot
.4302 .60031 Mdot
.36242 .59244 Mdot
.47812 .60691 Mdot
.65868 .6257 Mdot
.52307 .31301 Mdot
.37374 .41094 Mdot
.48731 .30154 Mdot
.43133 .25522 Mdot
.49044 .36622 Mdot
.48367 .64866 Mdot
.36519 .57118 Mdot
.52045 .63602 Mdot
.45165 .80735 Mdot
.72336 .68231 Mdot
.63861 .62337 Mdot
.70228 .30559 Mdot
.35022 .38685 Mdot
.65348 .6954 Mdot
.63052 .64874 Mdot
.51607 .3327 Mdot
.41932 .62852 Mdot
.40903 .53929 Mdot
.59705 .54109 Mdot
.64888 .68594 Mdot
.28651 .59248 Mdot
.50881 .3619 Mdot
.69077 .31414 Mdot
.75597 .58648 Mdot
.66908 .68986 Mdot
.4737 .43007 Mdot
.45749 .62654 Mdot
.39402 .41658 Mdot
.64836 .65714 Mdot
.3811 .34579 Mdot
.60621 .43121 Mdot
.50968 .44427 Mdot
.44223 .61377 Mdot
.73045 .43493 Mdot
.61812 .62981 Mdot
.3846 .40832 Mdot
.60878 .42453 Mdot
.38025 .38823 Mdot
.68313 .32513 Mdot
.46971 .20766 Mdot
.39769 .59146 Mdot
.46127 .59786 Mdot
.60853 .48177 Mdot
.63279 .6138 Mdot
.4389 .38954 Mdot
.28482 .37917 Mdot
.49826 .29963 Mdot
.43079 .38027 Mdot
.62187 .65806 Mdot
.5498 .65267 Mdot
.48387 .30581 Mdot
.65593 .43749 Mdot
.43853 .43493 Mdot
.60579 .46611 Mdot
.41929 .63917 Mdot
.63629 .64322 Mdot
.59507 .43505 Mdot
.41249 .29568 Mdot
.21451 .339 Mdot
.5183 .65956 Mdot
.41253 .56629 Mdot
.15905 .48897 Mdot
.3243 .2508 Mdot
.31479 .5982 Mdot
.62723 .47036 Mdot
.45188 .59743 Mdot
.39915 .65597 Mdot
.40018 .5749 Mdot
.59878 .45305 Mdot
.37716 .27229 Mdot
.51082 .32672 Mdot
.41726 .59566 Mdot
.38025 .43269 Mdot
.4955 .33131 Mdot
.46523 .28574 Mdot
.46903 .34225 Mdot
.59618 .62401 Mdot
.38672 .64002 Mdot
.72872 .55597 Mdot
.25963 .2576 Mdot
.61659 .45464 Mdot
.69625 .29726 Mdot
.46305 .596 Mdot
.67115 .75381 Mdot
.64561 .64898 Mdot
.50109 .30035 Mdot
.45476 .61362 Mdot
.40485 .2703 Mdot
.66901 .33478 Mdot
.48999 .35874 Mdot
.61252 .63717 Mdot
.31996 .58543 Mdot
.43528 .6121 Mdot
.39028 .59023 Mdot
.62623 .61134 Mdot
.48988 .2053 Mdot
.75911 .56965 Mdot
.46263 .61516 Mdot
.61699 .43966 Mdot
.85299 .54815 Mdot
.47823 .61298 Mdot
.57342 .6405 Mdot
.68374 .30142 Mdot
.68867 .5387 Mdot
.51624 .7152 Mdot
.47781 .66374 Mdot
.17279 .48482 Mdot
.34852 .5215 Mdot
.14962 .47806 Mdot
.40879 .40002 Mdot
.62095 .33351 Mdot
.15473 .40154 Mdot
.58431 .43581 Mdot
.45682 .70075 Mdot
.23334 .62044 Mdot
.75386 .49855 Mdot
.40203 .4777 Mdot
.63841 .2293 Mdot
.43283 .2798 Mdot
.73691 .28646 Mdot
.47013 .3339 Mdot
.25546 .44146 Mdot
.43675 .64414 Mdot
.33788 .23832 Mdot
.50729 .69484 Mdot
.80504 .60192 Mdot
.15576 .45873 Mdot
.38622 .46845 Mdot
.21997 .63884 Mdot
.22518 .35011 Mdot
.32475 .71017 Mdot
.6098 .53645 Mdot
.69752 .27506 Mdot
.73746 .60789 Mdot
.29803 .4037 Mdot
.35407 .64403 Mdot
.56114 .25954 Mdot
.37479 .24013 Mdot
.61991 .7433 Mdot
.82253 .59522 Mdot
.48122 .29362 Mdot
.62253 .58924 Mdot
.21195 .53136 Mdot
.6861 .65812 Mdot
.5721 .4082 Mdot
.1721 .48631 Mdot
.27361 .26963 Mdot
.51009 .67986 Mdot
.61688 .18385 Mdot
.47884 .78583 Mdot
.59209 .8322 Mdot
.53752 .50961 Mdot
.65746 .5921 Mdot
.63358 .2966 Mdot
.73783 .62814 Mdot
.68252 .40492 Mdot
.62016 .69125 Mdot
.38307 .3798 Mdot
.26801 .56878 Mdot
.61375 .63093 Mdot
.50296 .72105 Mdot
.6737 .3138 Mdot
.64538 .51205 Mdot
.47509 .26898 Mdot
.20106 .40074 Mdot
.72002 .31908 Mdot
.6975 .55718 Mdot
.7248 .40091 Mdot
.21537 .6817 Mdot
.33349 .48608 Mdot
.24645 .3448 Mdot
.67035 .47375 Mdot
.36778 .50736 Mdot
.78114 .54382 Mdot
.31358 .52086 Mdot
.73721 .64411 Mdot
.30064 .75427 Mdot
.38481 .20857 Mdot
.24088 .69105 Mdot
.6817 .65353 Mdot
.46699 .58704 Mdot
.21732 .40995 Mdot
.57782 .79676 Mdot
.36566 .38221 Mdot
.20224 .63883 Mdot
.39648 .41514 Mdot
.68657 .64423 Mdot
.75553 .48229 Mdot
.56005 .66895 Mdot
.54686 .36728 Mdot
.36296 .44962 Mdot
.48552 .63078 Mdot
.52793 .88629 Mdot
.1666 .51584 Mdot
.69757 .51602 Mdot
.28864 .26394 Mdot
.65199 .48545 Mdot
.46329 .40014 Mdot
.60313 .45704 Mdot
.18842 .36274 Mdot
.62484 .64398 Mdot
.2172 .29413 Mdot
.21206 .33204 Mdot
.82682 .48942 Mdot
.64606 .86679 Mdot
.72747 .34917 Mdot
.43771 .71368 Mdot
.29808 .65182 Mdot
.27033 .61155 Mdot
.7947 .55285 Mdot
.82459 .46556 Mdot
.62169 .50233 Mdot
.46817 .1965 Mdot
.1672 .40231 Mdot
.28713 .45996 Mdot
.34841 .2668 Mdot
.76509 .50969 Mdot
.5114 .48962 Mdot
.56881 .62884 Mdot
.50487 .50663 Mdot
.56527 .56924 Mdot
.22537 .66483 Mdot
.64312 .76426 Mdot
.82231 .64141 Mdot
.39213 .3702 Mdot
.81534 .40934 Mdot
.29172 .28407 Mdot
.24597 .54802 Mdot
.59022 .6763 Mdot
.73703 .53103 Mdot
.48327 .6454 Mdot
.74845 .57373 Mdot
.33396 .58897 Mdot
.32614 .38937 Mdot
.76059 .59515 Mdot
.5945 .37153 Mdot
.28881 .40056 Mdot
.19227 .49775 Mdot
.70339 .59386 Mdot
.59939 .61781 Mdot
.31928 .53757 Mdot
.31918 .47784 Mdot
.29015 .26925 Mdot
.79445 .46179 Mdot
.46112 .17989 Mdot
.80747 .46624 Mdot
.46182 .65439 Mdot
.44261 .70139 Mdot
.34324 .61844 Mdot
.32489 .50463 Mdot
.47183 .64044 Mdot
.71831 .41525 Mdot
.30736 .24758 Mdot
.62308 .78208 Mdot
.30798 .38649 Mdot
.41561 .79374 Mdot
.43401 .19075 Mdot
.22021 .41696 Mdot
.76962 .40408 Mdot
.35592 .70273 Mdot
.42997 .85514 Mdot
.49303 .34019 Mdot
.29989 .47174 Mdot
.63756 .40768 Mdot
.37945 .33783 Mdot
.25707 .66547 Mdot
.82296 .50449 Mdot
.31297 .24233 Mdot
.74468 .53753 Mdot
.4416 .30202 Mdot
.53772 .41511 Mdot
.55364 .33545 Mdot
.40165 .78838 Mdot
.38829 .54702 Mdot
.49628 .54751 Mdot
.36543 .44152 Mdot
.58023 .78615 Mdot
.23608 .40978 Mdot
.59211 .22538 Mdot
.50261 .6258 Mdot
.60222 .2615 Mdot
.68739 .31633 Mdot
.5168 .44698 Mdot
.1233 .48795 Mdot
.43246 .68483 Mdot
.74461 .36283 Mdot
.40004 .20143 Mdot
.43263 .42708 Mdot
.26886 .32989 Mdot
.73053 .47897 Mdot
.26956 .71951 Mdot
.23992 .29246 Mdot
.49211 .23104 Mdot
.15213 .50432 Mdot
.45054 .1572 Mdot
.30581 .74773 Mdot
.41172 .77729 Mdot
.59922 .4009 Mdot
.249 .22617 Mdot
.51212 .31407 Mdot
.47632 .8268 Mdot
.58827 .79499 Mdot
.38356 .28667 Mdot
.59795 .65731 Mdot
.39109 .52505 Mdot
.72506 .28861 Mdot
.61375 .5836 Mdot
.48791 .62763 Mdot
.18726 .6386 Mdot
.3196 .77856 Mdot
.19634 .64539 Mdot
.4481 .20089 Mdot
.15126 .49689 Mdot
.22532 .59144 Mdot
.60617 .70542 Mdot
.22718 .46019 Mdot
.42275 .64911 Mdot
.27712 .48522 Mdot
.73212 .35494 Mdot
.44 .29833 Mdot
.69042 .43713 Mdot
.60291 .65465 Mdot
.26905 .70355 Mdot
.11335 .52612 Mdot
.48908 .76781 Mdot
.56278 .72941 Mdot
.55839 .55486 Mdot
.31373 .49825 Mdot
.41352 .49668 Mdot
.56299 .23843 Mdot
.29231 .27507 Mdot
.22911 .61433 Mdot
.30071 .45059 Mdot
.62589 .23923 Mdot
.56247 .33905 Mdot
.80522 .39801 Mdot
.1971 .38847 Mdot
.22949 .5594 Mdot
.81797 .46495 Mdot
.35169 .70717 Mdot
.81065 .55558 Mdot
.54646 .20866 Mdot
.45173 .38115 Mdot
.32575 .46865 Mdot
.52488 .35336 Mdot
.2848 .46576 Mdot
.58619 .51204 Mdot
.20914 .50086 Mdot
.33535 .5368 Mdot
.28085 .45698 Mdot
.56191 .33119 Mdot
.16844 .58808 Mdot
.49759 .15456 Mdot
.37903 .80373 Mdot
.55943 .17721 Mdot
.3318 .59279 Mdot
.47044 .62795 Mdot
.35451 .21422 Mdot
.15824 .58509 Mdot
.26271 .26169 Mdot
.73155 .42875 Mdot
.40599 .29461 Mdot
.58316 .4234 Mdot
.40274 .8057 Mdot
.57521 .20111 Mdot
.25648 .29818 Mdot
.72456 .67037 Mdot
.64314 .47323 Mdot
.75317 .54264 Mdot
.43195 .81004 Mdot
.32352 .71519 Mdot
.51113 .73264 Mdot
.3537 .63916 Mdot
.4762 .7117 Mdot
.63768 .58904 Mdot
.7395 .42154 Mdot
.31669 .51178 Mdot
.48946 .33696 Mdot
.24102 .57763 Mdot
.515 .5721 Mdot
.48179 .64797 Mdot
.44299 .36941 Mdot
.57498 .61141 Mdot
.48322 .81599 Mdot
.61343 .50014 Mdot
.14567 .4185 Mdot
.74047 .37845 Mdot
.39621 .51011 Mdot
.34233 .51388 Mdot
.38425 .35389 Mdot
.74253 .56059 Mdot
.60779 .47415 Mdot
.16761 .43021 Mdot
.47642 .49236 Mdot
.32433 .53127 Mdot
.4784 .71305 Mdot
.27581 .38269 Mdot
.36148 .59916 Mdot
.71471 .48755 Mdot
.64646 .7248 Mdot
.51104 .4381 Mdot
.68806 .61796 Mdot
.57701 .6057 Mdot
.7008 .21472 Mdot
.56866 .3009 Mdot
.79491 .43433 Mdot
.17225 .42763 Mdot
.60793 .46484 Mdot
.62347 .66521 Mdot
.27379 .46468 Mdot
.29144 .3522 Mdot
.64297 .74078 Mdot
.45642 .33655 Mdot
.33539 .45966 Mdot
.57582 .21511 Mdot
.16115 .4901 Mdot
.18725 .58391 Mdot
.80224 .63304 Mdot
.66648 .65284 Mdot
.26613 .3796 Mdot
.29113 .36711 Mdot
.66366 .65089 Mdot
.63434 .68485 Mdot
.61067 .54095 Mdot
.13831 .48629 Mdot
.7399 .57201 Mdot
.53338 .18161 Mdot
.43573 .43433 Mdot
.39483 .26775 Mdot
.35802 .35003 Mdot
.31857 .45211 Mdot
.1757 .42585 Mdot
.49184 .72832 Mdot
.2873 .69817 Mdot
.35408 .64736 Mdot
.5822 .81234 Mdot
.40863 .8094 Mdot
.52886 .49727 Mdot
.5443 .65181 Mdot
.59576 .37581 Mdot
.40749 .57283 Mdot
.21296 .67914 Mdot
.32231 .26106 Mdot
.75692 .62138 Mdot
.60563 .49785 Mdot
.3888 .61403 Mdot
.44349 .65621 Mdot
.31219 .63184 Mdot
.69862 .52813 Mdot
.3529 .78717 Mdot
.29675 .38908 Mdot
.3266 .61767 Mdot
.49442 .70711 Mdot
.74582 .36515 Mdot
.20259 .40864 Mdot
.30668 .27551 Mdot
.56188 .49609 Mdot
.73236 .35927 Mdot
.48931 .41528 Mdot
.52564 .17642 Mdot
.58697 .26734 Mdot
.2202 .5763 Mdot
.66258 .56967 Mdot
.71922 .52608 Mdot
.39468 .35182 Mdot
.46651 .6083 Mdot
.75281 .47216 Mdot
.21821 .3613 Mdot
.80254 .67829 Mdot
.78604 .53384 Mdot
.17593 .62981 Mdot
.52662 .61996 Mdot
.72153 .5342 Mdot
.26975 .68903 Mdot
.77792 .72481 Mdot
.56001 .24763 Mdot
.22133 .6486 Mdot
.52424 .41179 Mdot
.16391 .44568 Mdot
.61355 .4028 Mdot
.71231 .58598 Mdot
.42593 .79473 Mdot
.13869 .47974 Mdot
.23348 .37854 Mdot
.18326 .42893 Mdot
.33492 .69946 Mdot
.14205 .51338 Mdot
.71724 .67173 Mdot
.74272 .28833 Mdot
.51032 .28018 Mdot
.70502 .3955 Mdot
.38002 .74603 Mdot
.54599 .59992 Mdot
.30223 .46443 Mdot
.79164 .35626 Mdot
.66442 .70389 Mdot
.34992 .72653 Mdot
.25113 .50896 Mdot
.72565 .49376 Mdot
.34744 .5117 Mdot
.24031 .31338 Mdot
.73771 .28294 Mdot
.33214 .35238 Mdot
.77313 .42714 Mdot
.47089 .20503 Mdot
.69405 .52694 Mdot
.59286 .31661 Mdot
.24439 .34578 Mdot
.5229 .20318 Mdot
.36736 .47906 Mdot
.72602 .21366 Mdot
.3838 .2424 Mdot
.60596 .54116 Mdot
.25455 .69552 Mdot
.29957 .27279 Mdot
.71365 .67976 Mdot
.79911 .59903 Mdot
.5679 .81984 Mdot
.28675 .50944 Mdot
.44589 .63781 Mdot
.13936 .52842 Mdot
.26446 .55379 Mdot
.21325 .65311 Mdot
.39899 .18886 Mdot
.449 .7244 Mdot
.46387 .66945 Mdot
.46385 .31764 Mdot
.5605 .53511 Mdot
.24726 .49976 Mdot
.22612 .63589 Mdot
.5342 .83015 Mdot
.42871 .3786 Mdot
.62024 .3198 Mdot
.457 .34823 Mdot
.34919 .672 Mdot
.71955 .35902 Mdot
.71444 .51473 Mdot
.37484 .36681 Mdot
.56085 .30263 Mdot
.31329 .48802 Mdot
.51393 .71283 Mdot
.31959 .71318 Mdot
.81231 .52033 Mdot
.57804 .39176 Mdot
.4775 .2935 Mdot
.19309 .54217 Mdot
.39673 .23049 Mdot
.71641 .42124 Mdot
.33251 .75583 Mdot
.73997 .5263 Mdot
.24805 .453 Mdot
.21939 .4476 Mdot
.79909 .54159 Mdot
.6976 .26775 Mdot
.3489 .75019 Mdot
.58492 .81152 Mdot
.49899 .39301 Mdot
.49926 .57104 Mdot
.15139 .42251 Mdot
.32041 .45857 Mdot
.21105 .47824 Mdot
.52738 .51199 Mdot
.59684 .76909 Mdot
.40098 .73611 Mdot
.25364 .59247 Mdot
.4897 .42758 Mdot
.49013 .87494 Mdot
.58335 .63537 Mdot
.21712 .68642 Mdot
.61641 .42944 Mdot
.74567 .69544 Mdot
.53891 .26889 Mdot
.56276 .50754 Mdot
.4601 .43714 Mdot
.71125 .48952 Mdot
.63857 .52855 Mdot
.45768 .19838 Mdot
.81779 .53714 Mdot
.48817 .36572 Mdot
.41586 .43951 Mdot
.53672 .18908 Mdot
.184 .52151 Mdot
.41358 .55395 Mdot
.40987 .23117 Mdot
.52393 .49425 Mdot
.43585 .31132 Mdot
.3566 .21543 Mdot
.63081 .37463 Mdot
.45502 .55599 Mdot
.31341 .50173 Mdot
.23233 .66025 Mdot
.22334 .32131 Mdot
.78577 .60056 Mdot
.33346 .59052 Mdot
.59794 .39908 Mdot
.25353 .63562 Mdot
.17149 .50645 Mdot
.50962 .39824 Mdot
.71051 .56763 Mdot
.32816 .48038 Mdot
.24467 .74303 Mdot
.31136 .76847 Mdot
.3594 .78785 Mdot
.42923 .42689 Mdot
.66569 .58939 Mdot
.66147 .75889 Mdot
.21336 .47339 Mdot
.69848 .40699 Mdot
.38465 .22771 Mdot
.30479 .47555 Mdot
.75166 .73601 Mdot
.61704 .69473 Mdot
.43238 .2522 Mdot
.40364 .73892 Mdot
.55488 .80186 Mdot
.59571 .40941 Mdot
.27528 .51494 Mdot
.43587 .48606 Mdot
.6313 .47459 Mdot
.72351 .49837 Mdot
.67147 .54473 Mdot
.20979 .48153 Mdot
.6327 .73205 Mdot
.33141 .62229 Mdot
.18698 .49067 Mdot
.64212 .57976 Mdot
.37375 .34569 Mdot
.33799 .35705 Mdot
.41192 .47654 Mdot
.49719 .30345 Mdot
.455 .68485 Mdot
.52918 .44151 Mdot
.50976 .41728 Mdot
.4666 .84062 Mdot
.39578 .42082 Mdot
.59091 .63237 Mdot
.74584 .6667 Mdot
.6587 .65808 Mdot
.14779 .57658 Mdot
.56383 .2405 Mdot
.49127 .70515 Mdot
.48049 .2347 Mdot
.62862 .26633 Mdot
.60101 .8411 Mdot
.37698 .77556 Mdot
.52851 .53114 Mdot
.64145 .69091 Mdot
.6724 .62646 Mdot
.54663 .36085 Mdot
.70968 .28512 Mdot
.52636 .7268 Mdot
.74313 .34987 Mdot
.23572 .44961 Mdot
.67129 .60535 Mdot
.41374 .25302 Mdot
.3902 .51216 Mdot
.13288 .45822 Mdot
.46956 .32039 Mdot
.39251 .83448 Mdot
.35831 .5797 Mdot
.27368 .67695 Mdot
.34486 .21889 Mdot
.77046 .57352 Mdot
.43052 .36338 Mdot
.66596 .23643 Mdot
.41929 .55894 Mdot
.33753 .63836 Mdot
.61117 .62881 Mdot
.25655 .41316 Mdot
.36383 .4147 Mdot
.29265 .56906 Mdot
.643 .46893 Mdot
.82185 .44363 Mdot
.72283 .36637 Mdot
.60352 .59343 Mdot
.47008 .49928 Mdot
.23372 .39273 Mdot
.67061 .55834 Mdot
.52182 .49181 Mdot
.19817 .56516 Mdot
.63596 .74384 Mdot
.67245 .60845 Mdot
.33674 .7624 Mdot
.29126 .3856 Mdot
.19766 .34121 Mdot
.43796 .52048 Mdot
.55201 .5216 Mdot
.68261 .56958 Mdot
.72046 .48055 Mdot
.52226 .71708 Mdot
.28969 .27916 Mdot
.31782 .52998 Mdot
.73134 .61728 Mdot
.28002 .45945 Mdot
.35839 .56203 Mdot
.61672 .32091 Mdot
.70255 .37944 Mdot
.72765 .75555 Mdot
.44597 .77435 Mdot
.77042 .5511 Mdot
.57117 .64976 Mdot
.74309 .36151 Mdot
.58796 .6322 Mdot
.34512 .31501 Mdot
.62272 .74817 Mdot
.5119 .24412 Mdot
.17181 .38543 Mdot
.29481 .26814 Mdot
.57989 .55531 Mdot
.44701 .33912 Mdot
.34717 .52579 Mdot
.39259 .51358 Mdot
.49921 .45353 Mdot
.43053 .56231 Mdot
.33565 .66495 Mdot
.78097 .60071 Mdot
.71436 .44103 Mdot
.38508 .52755 Mdot
.14878 .45326 Mdot
.20799 .32767 Mdot
.15375 .53981 Mdot
.47519 .39262 Mdot
.59583 .63353 Mdot
.27778 .72935 Mdot
.54834 .69622 Mdot
.2396 .31161 Mdot
.38743 .7537 Mdot
.67931 .19895 Mdot
.25041 .66301 Mdot
.58659 .37527 Mdot
.82725 .48146 Mdot
.67514 .4927 Mdot
.36167 .21732 Mdot
.74225 .28715 Mdot
.31063 .41507 Mdot
.37023 .21036 Mdot
.52473 .88492 Mdot
.4277 .77916 Mdot
.68729 .55186 Mdot
.39149 .72172 Mdot
.37329 .5103 Mdot
.74422 .33759 Mdot
.43582 .64746 Mdot
.53619 .34175 Mdot
.42802 .35175 Mdot
.313 .4819 Mdot
.51749 .61529 Mdot
.74972 .34179 Mdot
.2452 .49393 Mdot
.25877 .433 Mdot
.29828 .35831 Mdot
.2342 .64139 Mdot
.5314 .72088 Mdot
.46705 .56458 Mdot
.69024 .61323 Mdot
.3595 .3876 Mdot
.3301 .37583 Mdot
.39312 .6461 Mdot
.43208 .35148 Mdot
.63177 .54806 Mdot
.1862 .64153 Mdot
.32287 .33522 Mdot
.29928 .31785 Mdot
.58772 .59578 Mdot
.70571 .51724 Mdot
.20552 .43234 Mdot
.75411 .4925 Mdot
.76381 .35088 Mdot
.63843 .7678 Mdot
.16011 .49682 Mdot
.73457 .53956 Mdot
.28813 .42712 Mdot
.53402 .85046 Mdot
.64605 .44412 Mdot
.48782 .81271 Mdot
.22419 .60095 Mdot
.74359 .50055 Mdot
.68271 .6458 Mdot
.58529 .36298 Mdot
.63063 .33849 Mdot
.73634 .49783 Mdot
.40469 .19923 Mdot
.25416 .39481 Mdot
.42603 .73851 Mdot
.18072 .56156 Mdot
.51816 .29376 Mdot
.29941 .45183 Mdot
.57628 .34123 Mdot
.73911 .32075 Mdot
.704 .59026 Mdot
.14739 .43389 Mdot
.49167 .44628 Mdot
.26221 .5672 Mdot
.39522 .58851 Mdot
.58703 .71887 Mdot
.71345 .46124 Mdot
.56426 .34784 Mdot
.79203 .44481 Mdot
.60776 .60386 Mdot
.72947 .39081 Mdot
.66754 .30675 Mdot
.27981 .52782 Mdot
.51024 .55834 Mdot
.66013 .5731 Mdot
.40588 .42582 Mdot
.67758 .33263 Mdot
.40745 .55043 Mdot
.27081 .58758 Mdot
.55458 .35215 Mdot
.45699 .80292 Mdot
.42206 .78215 Mdot
.19262 .54564 Mdot
.32024 .27709 Mdot
.71198 .41833 Mdot
.38039 .75473 Mdot
.64209 .52256 Mdot
.59307 .68972 Mdot
.76743 .4738 Mdot
.48023 .62442 Mdot
.34891 .31154 Mdot
.61581 .65857 Mdot
.18361 .53237 Mdot
.54109 .62732 Mdot
.24962 .56517 Mdot
.5337 .47407 Mdot
.21276 .40898 Mdot
.49326 .48075 Mdot
.34702 .21933 Mdot
.67815 .48803 Mdot
.31595 .51397 Mdot
.63981 .48523 Mdot
.52689 .40865 Mdot
.79094 .52979 Mdot
.18852 .38289 Mdot
.8173 .51805 Mdot
.30148 .6536 Mdot
.76365 .54449 Mdot
.60115 .80202 Mdot
.38328 .19781 Mdot
.30196 .51888 Mdot
.50089 .45494 Mdot
.40964 .49976 Mdot
.63668 .51433 Mdot
.71002 .3047 Mdot
.36765 .30759 Mdot
.54377 .7106 Mdot
.32813 .29947 Mdot
.47778 .25635 Mdot
.43739 .55475 Mdot
.67675 .74982 Mdot
.17514 .53758 Mdot
.67845 .69458 Mdot
.55129 .50499 Mdot
.41212 .33847 Mdot
.27899 .53832 Mdot
.85958 .38273 Mdot
.21014 .67686 Mdot
.39532 .59022 Mdot
.43651 .44142 Mdot
.28985 .56251 Mdot
.52583 .33658 Mdot
.52914 .73272 Mdot
.19059 .54285 Mdot
.63627 .45734 Mdot
.39953 .30617 Mdot
.67497 .37305 Mdot
.70909 .48237 Mdot
.24965 .5945 Mdot
.59976 .48142 Mdot
.15946 .60171 Mdot
.41756 .22231 Mdot
.71874 .45708 Mdot
.78613 .28244 Mdot
.72742 .41791 Mdot
.62664 .57562 Mdot
.22948 .37485 Mdot
.16589 .5821 Mdot
.43042 .42872 Mdot
.38212 .33429 Mdot
.42735 .78567 Mdot
.31518 .52149 Mdot
.2699 .42773 Mdot
.77166 .42578 Mdot
.73977 .39996 Mdot
.7463 .29953 Mdot
.62904 .26433 Mdot
.49018 .84969 Mdot
.48344 .72269 Mdot
.18768 .5941 Mdot
.56017 .24358 Mdot
.76173 .72495 Mdot
.18814 .36364 Mdot
.26918 .4901 Mdot
.76032 .35844 Mdot
.24392 .35521 Mdot
.29226 .59543 Mdot
.67884 .73149 Mdot
.54502 .23799 Mdot
.63692 .75414 Mdot
.61626 .25934 Mdot
.77931 .47017 Mdot
.28306 .46226 Mdot
.57294 .8032 Mdot
.48873 .44179 Mdot
.21563 .61004 Mdot
.81608 .39183 Mdot
.34559 .50574 Mdot
.409 .30842 Mdot
.28344 .6308 Mdot
.18019 .49776 Mdot
.23617 .34749 Mdot
.48426 .4536 Mdot
.5289 .88099 Mdot
.22468 .66111 Mdot
.76233 .49498 Mdot
.46301 .64383 Mdot
.16992 .37861 Mdot
.44989 .4622 Mdot
.38295 .75907 Mdot
.37776 .22103 Mdot
.32118 .37162 Mdot
.66811 .56566 Mdot
.47431 .59786 Mdot
.36887 .77094 Mdot
.53696 .64936 Mdot
.55153 .80455 Mdot
.42311 .36052 Mdot
.33811 .51655 Mdot
.81869 .40523 Mdot
.26844 .62939 Mdot
.39253 .5155 Mdot
.61882 .65778 Mdot
.17302 .61338 Mdot
.32101 .70133 Mdot
.44753 .69037 Mdot
.41072 .715 Mdot
.8176 .5264 Mdot
.70505 .2506 Mdot
.35232 .56146 Mdot
.7391 .56161 Mdot
.30453 .46642 Mdot
.2242 .45281 Mdot
.39817 .77798 Mdot
.66528 .85946 Mdot
.33405 .22418 Mdot
.5817 .64323 Mdot
.49187 .80682 Mdot
.40723 .45879 Mdot
.15704 .5411 Mdot
.6216 .23572 Mdot
.36944 .35354 Mdot
.82875 .55443 Mdot
.31128 .55933 Mdot
.37115 .63408 Mdot
.43651 .19935 Mdot
.19001 .36969 Mdot
.828 .41377 Mdot
.15315 .42047 Mdot
.45119 .67271 Mdot
.36245 .64345 Mdot
.86781 .59501 Mdot
.16249 .46981 Mdot
.46478 .67129 Mdot
.81442 .5582 Mdot
.61117 .6691 Mdot
.42415 .64584 Mdot
.66656 .35066 Mdot
.33338 .46982 Mdot
.26423 .43386 Mdot
.13932 .48207 Mdot
.65315 .58478 Mdot
.43167 .34597 Mdot
.63678 .40932 Mdot
.46673 .43455 Mdot
.41165 .54038 Mdot
.59439 .434 Mdot
.25464 .45273 Mdot
.43804 .46156 Mdot
.58108 .48277 Mdot
.34834 .46892 Mdot
.50885 .16174 Mdot
.52424 .63656 Mdot
.57439 .55491 Mdot
.33701 .69303 Mdot
.67314 .70369 Mdot
.24662 .49575 Mdot
.23273 .48664 Mdot
.38091 .20815 Mdot
.47646 .13402 Mdot
.53828 .27995 Mdot
.41076 .52224 Mdot
.70233 .64233 Mdot
.53211 .71039 Mdot
.41275 .72773 Mdot
.56378 .39534 Mdot
.70066 .32102 Mdot
.46524 .6633 Mdot
.4007 .51028 Mdot
.64484 .46614 Mdot
.21147 .69946 Mdot
.44459 .64759 Mdot
.47087 .74266 Mdot
.2253 .34064 Mdot
.37906 .34627 Mdot
.51708 .65108 Mdot
.41208 .55814 Mdot
.71597 .67368 Mdot
.44086 .46571 Mdot
.32947 .56025 Mdot
.34523 .35288 Mdot
.16353 .54127 Mdot
.5384 .62351 Mdot
.45212 .73489 Mdot
.4209 .60241 Mdot
.36058 .44733 Mdot
.67979 .55415 Mdot
.3665 .78171 Mdot
.48685 .53475 Mdot
.23651 .30898 Mdot
.32002 .36829 Mdot
.29943 .38674 Mdot
.46053 .70519 Mdot
.21142 .65397 Mdot
.78231 .52981 Mdot
.44912 .72056 Mdot
.76771 .61735 Mdot
.59602 .33453 Mdot
.25227 .50672 Mdot
.46194 .34208 Mdot
.38721 .52734 Mdot
.63325 .67848 Mdot
.12644 .51203 Mdot
.38561 .7831 Mdot
.66031 .41905 Mdot
.49521 .39098 Mdot
.57357 .68427 Mdot
.46683 .43882 Mdot
.75675 .2523 Mdot
.63199 .2252 Mdot
.16189 .60681 Mdot
.24999 .40822 Mdot
.7039 .63877 Mdot
.7288 .49005 Mdot
.48303 .6698 Mdot
.50128 .35417 Mdot
.15962 .54202 Mdot
.44177 .51569 Mdot
.77156 .45871 Mdot
.41394 .65198 Mdot
.74523 .62501 Mdot
.37944 .51153 Mdot
.45071 .3578 Mdot
.5214 .36121 Mdot
.79616 .58122 Mdot
.21424 .37224 Mdot
.44257 .46723 Mdot
.68969 .21659 Mdot
.22607 .64129 Mdot
.16822 .42791 Mdot
.45584 .34181 Mdot
.76288 .68321 Mdot
.56885 .64991 Mdot
.37954 .51436 Mdot
.65505 .47634 Mdot
.30161 .66923 Mdot
.74059 .49536 Mdot
.23289 .43943 Mdot
.65619 .52671 Mdot
.61282 .53307 Mdot
.62197 .12923 Mdot
.2709 .47844 Mdot
.58585 .66978 Mdot
.75037 .45983 Mdot
.15913 .4287 Mdot
.34421 .4561 Mdot
.47617 .1771 Mdot
.56085 .27099 Mdot
.39232 .54098 Mdot
.63759 .72688 Mdot
.28486 .68579 Mdot
.65469 .36759 Mdot
.54946 .85879 Mdot
.38725 .23227 Mdot
.30162 .39748 Mdot
.56616 .34685 Mdot
.66154 .65609 Mdot
.60082 .65935 Mdot
.55735 .21871 Mdot
.5738 .16361 Mdot
.33674 .5615 Mdot
.16828 .49854 Mdot
.64479 .81439 Mdot
.2705 .3991 Mdot
.1466 .51646 Mdot
.67907 .42774 Mdot
.6224 .68279 Mdot
.24374 .48654 Mdot
.42134 .37892 Mdot
.52902 .31926 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0R_ooool2o`00
00Sooooo0_l00005ooooo`;o0000[?ooool001cooooo0_l0002;ooooo`;o00002?ooool2o`0000Go
oooo0_l0002/ooooo`007?ooool00ol0003oooooooooo`22ooooo`;o00008_ooool2o`0000[ooooo
0_l0002Eooooo`007?ooool00ol0003oooooooooo`22ooooo`;o00008_ooool2o`0000[ooooo0_l0
002Eooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo07Kooooo0_l0001>ooooo`;o0000POooool001cooooo00?o0000ooooooooool0
M_ooool2o`0001oooooo0_l0000]ooooo`;o0000POooool001cooooo00?o0000ooooooooool0Uooo
ool2o`000;3ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0d?ooool2o`0007Oooooo000Looooo`03o`000?oooooooooo0=3ooooo0_l0001gooooo`00
7?ooool00ol0003oooooooooo`1]ooooo`;o0000f_ooool001cooooo0_l0001^ooooo`;o0000f_oo
ool001cooooo00?o0000ooooooooool0W_ooool2o`0000gooooo0_l0000Sooooo`;o0000MOooool0
01cooooo00?o0000ooooooooool0Soooool2o`0000gooooo0_l0000=ooooo`;o00000_ooool2o`00
01oooooo0_l0001eooooo`007?ooool00ol0003oooooooooo`2?ooooo`;o00004Oooool2o`0000Oo
oooo1?l00002ooooo`?o00000oooool2o`00093ooooo000Looooo`03o`000?oooooooooo0:7ooooo
0ol00004ooooo`;o000000?oooooo`000?l000001Oooool2o`0000?ooooo0_l0002@ooooo`007?oo
ool00ol0003oooooooooo`2Qooooo`Co00000oooool2o`0000gooooo0_l0002@ooooo`007?ooool0
0ol0003oooooooooo`2Sooooo`;o00005Oooool2o`0008gooooo000Looooo`03o`000?oooooooooo
06?ooooo0_l0001Eooooo`;o00001Oooool2o`0008Kooooo000Looooo`03o`000?oooooooooo06?o
oooo0_l0000`ooooo`Co00003_ooool2o`0000Wooooo0_l0000=ooooo`;o000000?oooooo`000?l0
00005?ooool2o`0006gooooo000Looooo`03o`000?oooooooooo067ooooo0_l0000_ooooo`;o0000
00?oooooo`000?l000000_l00003ooooo`;o00002Oooool2o`0000Wooooo1?l00003ooooo`?o0000
2?ooool2o`0001Cooooo0_l0001]ooooo`007?ooool00ol0003oooooooooo`1Qooooo`;o0000;ooo
ool2o`0000Sooooo0_l0000;ooooo`;o00002Oooool2o`0000?ooooo1Ol00007ooooo`;o0000P_oo
ool001cooooo00?o0000ooooooooool0POooool2o`0001Cooooo0_l0000@ooooo`;o00004Oooool2
o`0000;ooooo0_l00003ooooo`;o0000P_ooool001cooooo00?o0000ooooooooool0O_ooool2o`00
0003ooooool0003o000000Kooooo0_l0000<ooooo`;o00001Oooool2o`0000Cooooo0_l00005oooo
o`;o00004oooool2o`000003ooooool0003o000008Cooooo00001_ooooook^k^oc8b<_l0003o<S8b
onk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`1Looooo`;o00008?ooool2
o`0000Kooooo0_l000000ooooooo0000o`000002ooooo`;o00001Oooool2o`0000Sooooo0_l00004
ooooo`;o00001Oooool2o`0001Kooooo0_l00005ooooo`;o0000OOooool00006oooooomgMgOoV9RH
oooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`00
0?oooooooooo05cooooo0_l0000Xooooo`;o00001Oooool2o`0000Gooooo0_l0000dooooo`;o0000
OOooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^
kP07ooooo`03o`000?oooooooooo07?ooooo0_l00004ooooo`;o00001Oooool2o`0000;ooooo0_l0
0004ooooo`;o00000_ooool5o`000003ooooool0003o000002Kooooo0_l0000Kooooo`;o0000K_oo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06
ooooo`?o0000Loooool2o`0000Cooooo0_l00003ooooo`Co00000_ooool2o`0000Cooooo0_l00002
ooooo`Go00009?ooool2o`0000?ooooo0_l00006ooooo`;o00004oooool2o`0006kooooo00000ooo
oooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0
003oooooooooo`1nooooo`;o00003_ooool2o`000003ooooool0003o000000;ooooo0_l00003oooo
o`?o00002Oooool2o`0000oooooo0_l0000;ooooo`;o0000Poooool00003ooooool@413ooooo00;o
oooo00?o410@ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Ko
oooo0_l0000Jooooo`;o00001?ooool3o`0001Kooooo0_l00002ooooo`;o00000oooool3o`0000Wo
oooo0_l00006ooooo`;o00001oooool2o`0001Kooooo0_l0001hooooo`0000KoooooogMgMonHV9So
oooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`1F
ooooo`;o00006_ooool2o`000004ooooool0003o0000ooooo`?o00006_ooool2o`0000?ooooo0_l0
0002ooooo`;o00003_ooool2o`0001oooooo0_l0001hooooo`0000Koooooonk^k_lb<S;o0000oc8b
<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1_ooooo`Co
00000_ooool2o`0002?ooooo1_l0000Gooooo`;o00006oooool4o`0000Sooooo0_l00006ooooo`;o
0000Goooool001cooooo00?o0000ooooooooool0Koooool5o`0000;ooooo0_l0000Tooooo`;o0000
6Oooool2o`0001_ooooo1?l00004ooooo`;o00000_ooool2o`0000Kooooo0_l0001Oooooo`007?oo
ool00ol0003oooooooooo`1Xooooo`;o00000_ooool3o`0000?ooooo0_l00002ooooo`?o0000>?oo
ool2o`0000oooooo0_l0000Hooooo`;o0000Joooool001cooooo00?o0000ooooooooool0C_ooool2
o`0001Sooooo0ol000000ooooooo0000o`000002o`0000Oooooo0_l0000;ooooo`;o00002?ooool2
o`00027ooooo0_l0000?ooooo`;o0000QOooool001cooooo00?o0000ooooooooool0COooool3o`00
01Wooooo0_l00002ooooo`?o00001Oooool6o`0000Wooooo0_l00008ooooo`?o00001?ooool2o`00
02Kooooo0_l0000;ooooo`Co0000Noooool001cooooo00?o0000ooooooooool0COooool2o`0001ko
oooo0_l00006ooooo`;o00000_ooool2o`0000;ooooo0_l00005ooooo`;o00002Oooool2o`0000Co
oooo0_l0000<ooooo`;o00001oooool2o`0000oooooo0_l0000;ooooo`Co000000?oooooo`000?l0
0000N?ooool001cooooo00?o0000ooooooooool0N_ooool2o`000005ooooool0003o0000o`000?oo
ool00_l000000ooooooo0000o`00000Fooooo`;o00001Oooool2o`0000?ooooo0_l00002ooooo`;o
00007_ooool2o`000003ooooool0003o000000_ooooo0_l0000?ooooo`;o0000F_ooool001cooooo
00?o0000ooooooooool0IOooool2o`000003ooooool0003o0000013ooooo0_l00002ooooo`;o0000
00?oooooo`000?l000005Oooool2o`0000;ooooo0_l0000:ooooo`;o00001?ooool2o`0001Kooooo
0_l0000<ooooo`?o00001Oooool2o`0000oooooo0_l0001Jooooo`007?ooool00ol0003ooooooooo
o`1Uooooo`;o000000?oooooo`000?l000000_l0000/ooooo`;o00004oooool3o`0000?ooooo0_l0
000@ooooo`Go00002_ooool3o`0007;ooooo000Looooo`03o`000?oooooooooo06;ooooo0_l00006
ooooo`;o00002_ooool2o`000003ooooool0003o000002;ooooo0_l0000>ooooo`;o00001?ooool2
o`0000Gooooo0_l00009ooooo`;o000000?oooooo`000?l000002oooool2o`0007;ooooo000Loooo
o`03o`000?oooooooooo05Oooooo0_l00009ooooo`;o00004_ooool2o`000003ooooool0003o0000
02;ooooo0_l00004ooooo`;o00002Oooool3o`000004ooooool0003o0000o`0000Gooooo0ol0002<
ooooo`007?ooool00ol0003oooooooooo`1Gooooo`;o00001oooool2o`0000;ooooo0_l0000Uoooo
o`;o00005_ooool4o`0000Oooooo0ol000000ooooooo0000o`000007ooooo`;o0000S?ooool001co
oooo0_l0001Qooooo`So00008Oooool4o`0001Gooooo0_l000000ooooooo0000o`000007ooooo`;o
00000_ooool2o`0002gooooo0_l0000?ooooo`;o0000EOooool001cooooo00?o0000ooooooooool0
E?ooool2o`0000[ooooo1Ol000000ooooooo0000o`00000Kooooo`;o00000oooool3o`0000;ooooo
0ol0000Booooo`;o00001_ooool3o`0000Gooooo0_l0000Vooooo`;o00001Oooool2o`0000oooooo
0_l0001Eooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o000000Coooooo`000?l0003ooooo
0ol00004ooooo`Co00008Oooool2o`0000?ooooo0_l00003ooooo`Co00000_ooool2o`0000;ooooo
0_l00006ooooo`;o00002Oooool3o`000003ooooool0003o000000;ooooo0_l0000Vooooo`;o0000
00?oooooo`000?l00000J_ooool001cooooo00?o0000ooooooooool0DOooool4o`0000;ooooo0ol0
0004ooooo`;o00001Oooool2o`0001Wooooo0_l0000<ooooo`Oo00000_ooool2o`0000Kooooo0_l0
0002ooooo`;o00002Oooool2o`0000?ooooo0_l00007ooooo`;o00000_ooool2o`0000;ooooo0_l0
000Gooooo`;o0000J_ooool001cooooo00?o0000ooooooooool0D_ooool3o`0000Gooooo0_l00002
ooooo`;o00001Oooool4o`0001Gooooo1?l0000<ooooo`;o000000?oooooo`000?l000004?ooool2
o`0000Wooooo0_l00003ooooo`;o00001oooool2o`0000;ooooo0_l00002ooooo`;o00000oooool2
o`0007kooooo000Looooo`03o`000?oooooooooo05;ooooo0ol00003ooooo`Co00000_ooool4o`00
00Gooooo0_l00004ooooo`;o00003_ooool3o`0001Sooooo0_l00003ooooo`;o00007?ooool2o`00
00?ooooo0_l00006ooooo`?o00004?ooool3o`000003ooooool0003o000006Sooooo000Looooo`03
o`000?oooooooooo05Gooooo0_l000000ooooooo0000o`000004o`0000;ooooo0_l00002ooooo`?o
00001_ooool2o`0000kooooo0_l000000ooooooo0000o`00000>ooooo`?o00000_ooool5o`0000?o
oooo0_l0000<ooooo`;o00003_ooool4o`0000Wooooo0_l0000Aooooo`?o000000?oooooo`000?l0
0000J?ooool001cooooo00?o0000ooooooooool0E?ooool3o`0000;ooooo1ol00004ooooo`?o0000
0_ooool2o`0000cooooo0_l00007ooooo`;o00002_ooool2o`0000;ooooo0ol00002ooooo`Co0000
00Coooooo`000?l0003ooooo0_l0000<ooooo`;o00001Oooool2o`0000Wooooo0_l0000<ooooo`;o
0000O?ooool001cooooo00?o0000ooooooooool0E?ooool4o`0000?ooooo0_l000000ooooooo0000
o`000004o`000003ooooool0003o000000;ooooo0_l0000<ooooo`;o00001Oooool2o`0000Kooooo
0_l00003ooooo`Co00002oooool2o`000003ooooool0003o000000?o00001_ooool2o`0000Sooooo
0_l0000Gooooo`;o00004_ooool2o`0006Sooooo000Looooo`03o`000?oooooooooo05?ooooo0_l0
00000ooooooo0000o`000002ooooo`?o00000oooool7o`0000;ooooo0_l0000Cooooo`;o00001_oo
ool2o`000003ooooool0003o000000Co00001Oooool2o`0000Cooooo0_l000000ooooooo0000o`00
0003o`0000Kooooo0_l000000ooooooo0000o`00000booooo`;o0000J?ooool001cooooo00?o0000
ooooooooool0BOooool2o`0000Sooooo0_l000000ooooooo0000o`000002ooooo`;o00002?ooool2
o`00023ooooo1Ol00003ooooo`;o00001?oooolAo`0000Kooooo0_l0000oooooo`;o00003_ooool2
o`0004_ooooo000Looooo`03o`000?oooooooooo04Wooooo0_l0000;ooooo`;o00000_ooool3o`00
02[ooooo0_l00005ooooo`;o00000ooooolBo`0001Wooooo0_l0000Sooooo`;o00001oooool2o`00
00kooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`1Jooooo`?o00005oooool2o`0000?o
oooo0_l0000Aooooo`;o00001Oooool3o`000003ooooool0003o000000ko000000Coooooo`000?l0
003ooooo0_l0000Aooooo`;o00008?ooool2o`000003ooooool0003o000000?ooooo0_l00002oooo
o`?o0000F_ooool001cooooo00?o0000ooooooooool0=_ooool2o`0001;ooooo0_l0000;ooooo`;o
00003?ooool2o`0000gooooo0_l00003ooooo`;o00003Oooool2o`0000;ooooo0_l00004ooooo`Co
000000?oooooo`000?l000003_l000001?oooooo0000o`000?ooool2o`0003;ooooo0ol00006oooo
o`;o00000_ooool3o`0005[ooooo000Looooo`03o`000?oooooooooo03Kooooo0_l0000;ooooo`;o
00001Oooool2o`0000_ooooo0_l0000<ooooo`;o00006Oooool2o`000003ooooool0003o000000?o
oooo1?l00006oooooaGo0000<_ooool2o`0000;ooooo2?l0001Tooooo`007?ooool00ol0003ooooo
ooooo`13ooooo`;o00002oooool2o`0000Cooooo0_l0000<ooooo`;o00006_ooool5o`0000Gooooo
0ol00009oooooa;o000000Coooooo`000?l0003o00007_ooool2o`0000gooooo0_l000000ooooooo
0000o`000007o`0006Cooooo000Looooo`;o0000COooool2o`0000;ooooo0_l000001?oooooo0000
o`000?ooool2o`0000[ooooo1?l000000ooooooo0000o`00000;ooooo`;o00003?ooool4o`0000Go
oooo0_l00009oooooa;o000000Coooooo`000?l0003o00001_ooool2o`000003ooooool0003o0000
01?ooooo0_l0000=ooooo`co00002_ooool2o`0005Sooooo000Looooo`03o`000?oooooooooo04Oo
oooo0_l00003ooooo`Co00000oooool2o`0000[ooooo0_l000001?oooooo0000o`000?l00002oooo
o`;o00001_ooool2o`0000?ooooo0_l0000<ooooo`Co00001_ooool4o`0000Gooooo4_l000001?oo
oooo0000o`000?l00007ooooo`;o000000?oooooo`000?l000008Oooool>o`0000Wooooo0_l0001H
ooooo`007?ooool00ol0003oooooooooo`17ooooo`;o00000_ooool2o`000003ooooool0003o0000
00Oooooo0_l00006ooooo`;o000000Coooooo`000?l0003o00002_ooool2o`0000?ooooo0_l00008
ooooo`;o00001Oooool2o`0000Gooooo1?l00004oooooaKo00002?ooool2o`0000Sooooo0_l0000>
ooooo`;o00001oooool:o`000003ooooool0003o000000Co0000Hoooool001cooooo00?o0000oooo
ooooool0BOooool4o`0000[ooooo0_l00005ooooo`;o00005?ooool2o`0000Sooooo0_l000000ooo
oooo0000o`000002ooooo`;o00001oooool3o`0000?ooooo5ol000001?oooooo0000o`000?l0000=
ooooo`;o00003_ooool2o`0000Oooooo4?l0001Tooooo`007?ooool00ol0003oooooooooo`19oooo
o`?o00004_ooool2o`0000kooooo0_l0000Aooooo`;o00000_ooool2o`0000?ooooo0ol00002oooo
o`;o00000oooool?o`000003ooooool0003o000000Wo00006oooool2o`0000_ooooo3_l0000Noooo
o`;o0000A?ooool001cooooo00?o0000ooooooooool0B_ooool2o`0000Wooooo0_l00002ooooo`;o
00004Oooool4o`0001[ooooo0ol00005oooooaco00001_ooool2o`0000Oooooo0_l0000;ooooo`;o
00002oooool?o`0001gooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`1Eooooo`Ko0000
0_ooool3o`0000cooooo0_l0000Toooooaco00001_ooool2o`0000Oooooo0_l00007ooooo`;o0000
3ooooolAo`0001_ooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00001?oo
ool2o`0000[ooooo0_l00002ooooo`Go00000_ooool2o`0002oooooo6Ol00006ooooo`Ko00003Ooo
ool3o`0000oooooo3_l000000ooooooo0000o`000004ooooo`;o0000Foooool001cooooo00?o0000
ooooooooool0AOooool2o`0000?ooooo0ol0000>ooooo`;o000000Goooooo`000?l0003o0000oooo
o`02o`0002Gooooo0ol00006oooooaco00001?ooool2o`0000;ooooo0_l0000=ooooo`;o00004?oo
ool=o`0000Sooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00002?ooool3
o`0000;ooooo0_l00006ooooo`;o00001_ooool2o`0000Kooooo0_l0000Pooooo`?o00001_oooolF
o`0000;ooooo1ol00005ooooo`;o00002?ooool2o`000003ooooool0003o000001Cooooo2ol0001U
ooooo`007?ooool00ol0003oooooooooo`10ooooo`?o00003?ooool2o`0000?ooooo0_l000000ooo
oooo0000o`000008ooooo`?o00000oooool2o`0002[ooooo7_l00002ooooo`Go00002?ooool2o`00
0003ooooool0003o000001Cooooo1_l000000ooooooo0000o`00001Wooooo`007?ooool00ol0003o
ooooooooo`11ooooo`;o00001oooool2o`0000Kooooo1?l00006ooooo`;o00000oooool3o`000003
ooooool0003o0000017ooooo0ol0000=ooooo`Co00001ooooolIo`0000?ooooo0ol000000ooooooo
0000o`000002o`0000Oooooo0_l00006ooooo`;o00003_ooool9o`0006[ooooo000Looooo`03o`00
0?oooooooooo04[ooooo0_l00006ooooo`?o000000?oooooo`000?l000001?ooool2o`0000Oooooo
0_l0000Aooooo`?o00001oooool2o`0000;ooooo1_l00004ooooo`go00000_ooool=o`000004oooo
ool0003o0000ooooo`;o00003?ooool2o`0000Kooooo0_l000000ooooooo0000o`00000;ooooo`Ko
000000?oooooo`000?l000000_ooool2o`0000_ooooo0_l0001Iooooo`007?ooool00ol0003ooooo
ooooo`0mooooo`;o00000oooool2o`000003ooooool0003o000000oooooo1?l00003ooooo`;o0000
6Oooool2o`0000Sooooo0_l00002ooooo`;o00001Oooool2o`000005ooooool0003o0000o`000?oo
ool02_l000000ooooooo0000o`000008o`000004ooooool0003o0000ooooo`;o00001?ooool2o`00
00;ooooo0_l0000@ooooo`;o00003oooool2o`0000Gooooo0_l0000:ooooo`?o0000FOooool001co
oooo00?o0000ooooooooool0?Oooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`0000?o
oooo0_l00008ooooo`Co00000oooool2o`0001oooooo0_l0000=ooooo`;o000000?oooooo`000?l0
00003?l000000ooooooo0000o`00000;o`000004ooooool0003o0000o`0000?ooooo0_l00002oooo
o`;o00006oooool2o`0001Oooooo0_l000000ooooooo0000o`000004o`0005?ooooo000Looooo`03
o`000?oooooooooo04Oooooo1?l000000ooooooo0000o`00000Looooo`;o00001Oooool2o`0000?o
oooo1?l00004ooooo`;o00002?ooool2o`0000;ooooo0_l00002oooooaco00000_ooool2o`0000Co
oooo0_l0000Nooooo`;o00000oooool2o`0001Gooooo1_l0001Cooooo`007?ooool2o`0004Kooooo
0ol000001?oooooo0000o`000?ooool2o`0001cooooo0_l00005ooooo`;o00000oooool4o`0000ko
oooo0_l00002ooooo`;o00000ooooolJo`0000Wooooo0_l0000Oooooo`;o00000_ooool2o`0000go
oooo0_l00004ooooo`;o00001?ooool2o`0005?ooooo000Looooo`03o`000?oooooooooo04?ooooo
1Ol0000Cooooo`;o00002oooool2o`000004ooooool0003o0000o`0000?ooooo0_l000000ooooooo
0000o`000003ooooo`;o000000?oooooo`000?l000002Oooool4o`0000Kooooo0_l000000ooooooo
0000o`00000<o`000003ooooool0003o000000Oo00001?ooool2o`0002?ooooo1?l0000?ooooo`;o
00001?ooool2o`0000Cooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`13ooooo`;o0000
1oooool6o`0000Kooooo0_l000000ooooooo0000o`000008ooooo`;o000000?oooooo`000?l00000
1?l00006ooooo`;o00000oooool2o`000003ooooool0003o000000Wooooo1?l00002ooooo`;o0000
1_oooolGo`0000Cooooo0_l0000Fooooo`?o00000_ooool2o`0000Sooooo0_l0000Aooooo`;o0000
3oooool4o`0004[ooooo000Looooo`03o`000?oooooooooo043ooooo0_l0000:ooooo`Ko00001_oo
ool2o`0000?ooooo0_l00006ooooo`;o00000oooool2o`0000Gooooo0_l0000Dooooo`;o00001?oo
ool4o`0000Cooooo5Ol0000Nooooo`?o00000_ooool2o`0001Oooooo0_l00002ooooo`;o00000_oo
ool2o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`Co0000B_ooool001cooooo00?o0000
ooooooooool0>_ooool2o`0000Cooooo0_l000000ooooooo0000o`00000Hooooo`Co00004?ooool2
o`0000kooooo0_l000000ooooooo0000o`000002o`0000Oooooo0_l00006oooooa7o00001Oooool3
o`0000[ooooo0_l00005ooooo`;o00004oooool2o`0000Sooooo1?l00002ooooo`;o00000_ooool2
o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l00000DOooool001cooooo00?o0000oooo
ooooool0>Oooool3o`0000Oooooo0_l0000Jooooo`;o00008?ooool2o`000003ooooool0003o0000
00Co00002OoooolEo`0000Gooooo0ol0000:ooooo`;o00001Oooool2o`0001?ooooo0_l00008oooo
o`Co00000oooool2o`0000Gooooo0_l0000;ooooo`;o0000C?ooool001cooooo00?o0000oooooooo
ool0>Oooool2o`0001gooooo0_l000000ooooooo0000o`000007ooooo`;o00001Oooool2o`0000Wo
oooo0_l0000@ooooo`?o000000?oooooo`000?l000001Oooool=o`000003ooooool0003o000000?o
00002?ooool2o`00027ooooo0_l0000Dooooo`;o000000?oooooo`000?l000000_ooool2o`0000_o
oooo0_l0000=ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0>_ooool2o`0000Kooooo
0_l0000Dooooo`;o000000?oooooo`000?l000001oooool3o`0000Cooooo1?l00004ooooo`;o0000
00Coooooo`000?l0003o00000oooool2o`0000Gooooo0_l00004ooooo`;o000000?oooooo`000?l0
00002?ooool2o`0000;ooooo0_l00002ooooo`Go000000?oooooo`000?l000000oooool2o`0000?o
oooo0_l0000=ooooo`;o00002oooool2o`0000?ooooo1?l0000Gooooo`;o00005Oooool2o`0000Oo
oooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0jooooo`Ko00000_ooool3o`0000;ooooo
0_l00004ooooo`;o00005_ooool3o`0000Cooooo0ol00004ooooo`;o00000_ooool2o`0000?ooooo
0_l00005ooooo`;o00001?ooool2o`0000Sooooo0_l000000ooooooo0000o`000002ooooo`;o0000
0oooool4o`0000Kooooo0_l00003ooooo`;o00002oooool4o`0000[ooooo0ol00003ooooo`;o0000
1_ooool2o`0002Sooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`0dooooo`;o00001_oo
ool4o`0000?ooooo0_l00002ooooo`?o00000oooool2o`0001Oooooo1?l00002ooooo`;o00001Ooo
ool2o`0000[ooooo0_l00006ooooo`Co00002?ooool2o`0000?ooooo1?l00004ooooo`?o00006?oo
ool2o`000004ooooool0003o0000o`0000Sooooo0_l0000<ooooo`;o00005?ooool2o`0001cooooo
0_l0000looooo`007?ooool00ol0003oooooooooo`0dooooo`;o00001_ooool2o`0000[ooooo0_l0
0009ooooo`;o00001?ooool3o`0000cooooo0_l00002ooooo`;o00001Oooool2o`000004ooooool0
003o0000ooooo`;o00001?ooool2o`0000Cooooo1_l00004ooooo`;o00001?ooool5o`0000Kooooo
0_l0000<ooooo`;o000000?oooooo`000?l000002oooool3o`0000Sooooo0_l0000<ooooo`;o0000
1oooool2o`0000_ooooo0_l0000Looooo`;o0000??ooool001cooooo00?o0000ooooooooool0>Ooo
ool5o`0000?ooooo0_l0000@ooooo`;o000000Coooooo`000?l0003ooooo0ol00007ooooo`;o0000
1oooool2o`0000;ooooo0_l000000ooooooo0000o`000003o`000004ooooool0003o0000o`0000Wo
oooo1Ol00005ooooo`Co00000_ooool4o`0000[ooooo0_l00009ooooo`;o000000?oooooo`000?l0
00003?ooool2o`0000Sooooo0_l0000?ooooo`?o00000oooool2o`00037ooooo0_l0000dooooo`00
7?ooool00ol0003oooooooooo`0dooooo`;o00000oooool4o`0000Cooooo0_l0000>ooooo`Co0000
00?oooooo`000?l000000oooool2o`000003ooooool0003o000000;o000000?oooooo`000?l00000
1?ooool2o`000003ooooool0003o000000ko00002_ooool2o`0000Wooooo0_l0000=ooooo`;o0000
00Coooooo`000?l0003o00002oooool2o`0000cooooo0_l0000Iooooo`?o0000=_ooool2o`0003Co
oooo000Looooo`03o`000?oooooooooo03Cooooo0_l00005ooooo`Co00003?ooool2o`0000Cooooo
0_l00008ooooo`Oo00001?ooool5o`000003ooooool0003o000000Ko000000?oooooo`000?l00000
1Ol0000?ooooo`?o00002_ooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o0000
0_ooool2o`0000Oooooo0_l0000Eooooo`;o00007oooool2o`0000Gooooo0_l0000Aooooo`;o0000
A?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413o
ooooooooo`04ooooo`03o`000?oooooooooo03cooooo0ol00009ooooo`;o000000?oooooo`000?l0
00002Oooool2o`0000Gooooo0_l00005ooooo`Go00000oooool8o`000003ooooool0003o000000Go
00002oooool7o`0000Wooooo0ol00003ooooo`?o00002?ooool3o`0000gooooo0_l00009ooooo`;o
00000oooool2o`0001oooooo0_l00005ooooo`;o00004Oooool4o`0004;ooooo00001_ooooooMgMg
oiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0=oooool2o`0000oooooo0_l00005ooooo`;o00001Oooool2o`0000cooooo1?l00004oooo
oa;o00001_ooool2o`000003ooooool0003o000000;o00000_ooool2o`0000Sooooo0_l000000ooo
oooo0000o`000002ooooo`?o00001oooool3o`0000Sooooo0_l00003ooooo`;o00002Oooool2o`00
0003ooooool0003o000001;ooooo0_l00005ooooo`;o00005?ooool2o`0000cooooo0_l00012oooo
o`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`Go00001_ooool00ol0003o
ooooooooo`0gooooo`;o00002oooool2o`0000Wooooo0_l00003ooooo`;o00002?ooool2o`0000[o
oooo1?l000000ooooooo0000o`00000=o`0000?ooooo0_l000000ooooooo0000o`000007ooooo`;o
00001?ooool4o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Wo
oooo0_l00009ooooo`Co00001?ooool2o`00013ooooo1?l00005ooooo`;o00002Oooool3o`0000So
oooo0_l00007ooooo`Co0000AOooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
2Oooool01?m4A4CogMgMooooool00007ooooo`?o0000;oooool2o`0000;ooooo0_l00006ooooo`;o
000000?oooooo`000?l000001?ooool2o`0000gooooo1?l00002ooooo`?o00000_ooool2o`0000[o
oooo5?l00003ooooo`;o00002_ooool2o`0000Cooooo1?l0000;ooooo`;o00006_ooool5o`000003
ooooool0003o000001;ooooo0_l0000>ooooo`;o00000_ooool3o`00017ooooo1?l00015ooooo`00
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oo
oooo00?o0000ooooooooool0;oooool2o`0000;ooooo0_l00006ooooo`;o000000?oooooo`000?l0
00004_ooool5o`0000;ooooo0ol000001?oooooo0000o`000?l0000:oooooaKo00004oooool2o`00
027ooooo0_l00002ooooo`;o00000oooool8o`000003ooooool0003o0000013ooooo0_l0000<oooo
o`;o00003?ooool2o`000003ooooool0003o000000_ooooo0_l00007ooooo`;o0000>?ooool00003
ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00omgMgOoc<c<o`000007ooooo`03
o`000?oooooooooo03kooooo0_l000000ooooooo0000o`00000:ooooo`;o00000oooool2o`0000Wo
oooo0_l00008ooooo`;o00000_oooolEo`0000Wooooo0_l00008ooooo`;o00004_ooool2o`0000go
oooo0_l00002ooooo`;o00000_ooool?o`0000;ooooo0ol00008ooooo`;o00000oooool3o`0000Ko
oooo0_l0000<ooooo`Go00002_ooool3o`0000Oooooo0_l0000hooooo`0000KoooooogMgMonHV9So
oooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0>_ooool2o`00
00;ooooo0_l000000ooooooo0000o`000002o`0000Cooooo0ol000000ooooooo0000o`00000=oooo
o`;o00002Oooool2o`000003ooooool0003o000001Ko00001?ooool2o`000003ooooool0003o0000
00;o00000_ooool2o`0001;ooooo0_l00002ooooo`;o00003Oooool2o`0000Gooooo4?l00002oooo
o`?o00003Oooool3o`0001Gooooo1?l0000:ooooo`;o0000@_ooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo03[ooooo0_l00006
ooooo`Co00000oooool3o`0000Cooooo0_l0000:ooooo`;o00000oooool2o`0000Oooooo5Ol00000
0ooooooo0000o`000004ooooo`Co000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00006
ooooo`;o00001_ooool2o`0000;ooooo0_l00002ooooo`;o00004?ooool9o`000003ooooool0003o
000000Oo00005_ooool4o`0000;ooooo0ol0000Fooooo`;o00000_ooool2o`0003kooooo000Loooo
o`03o`000?oooooooooo02cooooo1?l00007ooooo`;o00002Oooool4o`0000[ooooo0_l0000?oooo
o`;o00001OoooolGo`0000Gooooo0_l00002ooooo`;o00001Oooool2o`0000;ooooo0ol00005oooo
o`Co00000oooool2o`0000Oooooo0_l000000ooooooo0000o`00000=oooooa?o00004oooool2o`00
0003ooooool0003o000000;o000000?oooooo`000?l000000_l00009ooooo`;o00002oooool3o`00
0003ooooool0003o000000Kooooo0_l0000fooooo`007?ooool00ol0003oooooooooo`0/ooooo`Co
00001oooool2o`000003ooooool0003o000000Sooooo0_l00005ooooo`;o00000_ooool2o`0001Oo
oooo6Ol00003ooooo`;o000000?oooooo`000?l000001?ooool4o`0000?ooooo0_l00007ooooo`;o
00000oooool2o`0000[ooooo0_l00009ooooo`;o000000?oooooo`000?l000004_l00003ooooo`;o
00001?ooool2o`0000Sooooo1?l000001?oooooo0000o`000?ooool3o`0000[ooooo0_l00005oooo
o`;o00001Oooool2o`0000Wooooo0_l0000fooooo`007?ooool00ol0003oooooooooo`0]ooooo`?o
00002_ooool2o`0000Kooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo0_l0000;ooooo`;o
00001Oooool2o`0000?ooooo6Ol00006ooooo`?o00000_ooool7o`000003ooooool0003o000000Oo
oooo0_l0000JoooooaWo000000Coooooo`000?l0003o00000oooool2o`0000[ooooo0_l000001?oo
oooo0000o`000?ooool3o`0000[ooooo0_l00005ooooo`;o00001oooool2o`0003oooooo000Loooo
o`03o`000?oooooooooo02cooooo0ol00004ooooo`Co00002oooool2o`0000?ooooo0_l0000;oooo
o`?o00000oooool4o`0000Gooooo1?l00004oooooaCo000000?oooooo`000?l000000_ooool2o`00
00;ooooo0ol000000ooooooo0000o`000003ooooo`Go00000_ooool5o`0001cooooo6Ol00002oooo
o`;o00000oooool2o`0001cooooo1ol0000:ooooo`;o00003_ooool2o`0002oooooo000Looooo`03
o`000?oooooooooo02cooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l000000ooooooo
0000o`00000Jooooo`?o00000oooool3o`0000Sooooo0_l00004oooooaCo000000?oooooo`000?l0
00000_ooool3o`000003ooooool0003o000000?o00001Oooool<o`0001_ooooo6_l00006ooooo`;o
00002_ooool2o`0000?ooooo0_l0000;ooooo`Oo00006_ooool2o`0002oooooo000Looooo`03o`00
0?oooooooooo02cooooo0_l00002ooooo`Go00000oooool2o`0000?ooooo1?l0000:ooooo`;o0000
00?oooooo`000?l000001Ol0000;ooooo`;o00002Oooool2o`000003ooooool0003o000000go0000
2?ooool2o`000004ooooool0003o0000ooooo`Co00000oooool2o`0000;ooooo0_l000000ooooooo
0000o`000004o`0001_ooooo6Ol00007ooooo`;o00002Oooool2o`0000?ooooo0_l0000Mooooo`;o
0000?_ooool001cooooo00?o0000ooooooooool0;?ooool2o`0000Cooooo0_l00009ooooo`Co0000
2_ooool2o`000003ooooool0003o000000Go00002oooool2o`0000Wooooo4Ol00004ooooo`;o0000
0_ooool2o`0000Cooooo1ol000000ooooooo0000o`000002o`0000?ooooo0_l00002ooooo`;o0000
4oooool2o`0000Kooooo6Ol00002ooooo`;o00000oooool4o`0000_ooooo0ol0000Aooooo`?o0000
2Oooool2o`0003kooooo000Looooo`03o`000?oooooooooo02oooooo0_l0000Gooooo`;o00002Ooo
ool2o`00013ooooo0_l00004oooooa3o00001?ooool3o`000004ooooool0003o0000o`0000Cooooo
0ol00002ooooo`;o000000?oooooo`000?l000000_l00003ooooo`Co00000oooool4o`0000kooooo
0_l00006oooooago00001Oooool2o`0000_ooooo0_l0000Booooo`Go0000Aoooool001cooooo00?o
0000ooooooooool0;oooool2o`0001Oooooo0_l00005ooooo`;o00000_ooool2o`00013ooooo0_l0
0005ooooo`;o000000?oooooo`000?l000003?l00002ooooo`;o00000_ooool2o`0000Gooooo0_l0
0008ooooo`;o00001?ooool3o`0000?ooooo1?l00004ooooo`;o00003ooooolFo`000003ooooool0
003o000000?o00001Oooool2o`0000Sooooo0_l0000>ooooo`;o00002?ooool4o`0000Sooooo0_l0
000mooooo`007?ooool00ol0003oooooooooo`0booooo`;o00006oooool2o`0001kooooo3_l0000=
ooooo`;o00002Oooool4o`0000;ooooo0ol00003ooooo`Co000000?oooooo`000?l000000_l0000?
oooooaOo000000?oooooo`000?l000001oooool2o`0000Sooooo0_l00004ooooo`;o00002?ooool2
o`0000Oooooo0_l00008ooooo`;o000000?oooooo`000?l000000_l0000kooooo`007?ooool00ol0
003oooooooooo`0booooo`;o00004?ooool2o`0002Oooooo0_l00002ooooo`Go000000?oooooo`00
0?l000000ol0000@ooooo`;o00001oooool4o`0000?ooooo0_l00003ooooo`Wo00001_ooool2o`00
00Oooooo6_l000000ooooooo0000o`00000>ooooo`;o00001?ooool2o`0000Sooooo0_l00007oooo
o`;o00002?ooool2o`0000?ooooo0_l0000kooooo`007?ooool2o`0004Gooooo0_l00003ooooo`;o
00004oooool2o`0000Cooooo1?l00005ooooo`;o00000_ooool5o`0000?ooooo0_l000000ooooooo
0000o`00000;ooooo`;o000000?oooooo`000?l000004_ooool;o`000003ooooool0003o000000;o
oooo0_l00003ooooo`;o00001OoooolGo`000004ooooool0003o0000ooooo`;o00006?ooool2o`00
0004ooooool0003o0000ooooo`;o000000?oooooo`000?l000001Oooool2o`0004Kooooo000Loooo
o`03o`000?oooooooooo02cooooo0ol0000Fooooo`;o00000_ooool2o`0000;ooooo1?l0000:oooo
o`;o000000?oooooo`000?l000001?ooool4o`000003ooooool0003o000000?ooooo0_l00002oooo
o`;o00000oooool4o`000003ooooool0003o000000_ooooo0_l0000>ooooo`?o00000_ooool4o`00
0004ooooool0003o0000ooooo`;o000000Coooooo`000?l0003ooooo0ol00006ooooo`;o00001Ooo
oolGo`0000Cooooo0_l00008ooooo`;o00003_ooool2o`0000Cooooo0_l000000ooooooo0000o`00
0005ooooo`;o00004_ooool2o`0003;ooooo000Looooo`03o`000?oooooooooo02Oooooo0_l00003
ooooo`Go00005?ooool2o`0000Kooooo1?l00007ooooo`;o000000?oooooo`000?l000001oooool3
o`0000;ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00003ooooo`;o00002?ooool4
o`0001Cooooo0ol000000ooooooo0000o`000002o`0000;ooooo0_l00008ooooo`;o00001oooool2
o`0000Gooooo5Ol00005ooooo`;o00002?ooool2o`0000?ooooo0_l0000>ooooo`?o00007?ooool2
o`000003ooooool0003o000002oooooo000Looooo`03o`000?oooooooooo02Oooooo0_l00006oooo
o`;o00002_ooool2o`0000Sooooo1?l0000<ooooo`Oo00002?ooool2o`0000?ooooo0_l000000ooo
oooo0000o`000002o`00017ooooo1?l00006ooooo`;o00000_ooool2o`0000Cooooo0_l00006oooo
o`;o00004_ooool7o`0000Gooooo5?l0000@ooooo`;o000000?oooooo`000?l000000_l00008oooo
o`;o00001?ooool3o`0000Gooooo0_l0000Hooooo`;o0000;oooool001cooooo00?o0000oooooooo
ool0>oooool2o`0000Sooooo1?l0000<ooooo`Oo00000_ooool2o`0000Wooooo0_l00003ooooo`;o
00001Oooool2o`0000Gooooo0_l000000ooooooo0000o`00000:ooooo`;o000000Coooooo`000?l0
003o00001?ooool2o`0000_ooooo0ol0000<ooooo`Go00001ooooolAo`0000;ooooo0_l0000Boooo
o`;o00002_ooool2o`0000cooooo0ol00005ooooo`?o0000@?ooool001cooooo00?o0000oooooooo
ool0;_ooool2o`0000_ooooo0_l00002ooooo`;o00000oooool2o`0000oooooo0_l000001?oooooo
0000o`000?l00003ooooo`?o00003Oooool2o`0000Gooooo0_l00005ooooo`;o000000?oooooo`00
0?l000001oooool2o`000003ooooool0003o000000?o00002?ooool2o`0000Sooooo0ol0000Hoooo
oaGo00007oooool2o`0000;ooooo0ol00007ooooo`;o000000?oooooo`000?l000000_ooool4o`00
00_ooooo0_l0000booooo`007?ooool00ol0003oooooooooo`0^ooooo`;o000000?oooooo`000?l0
00003?ooool2o`0000?ooooo0_l00003ooooo`;o00003_ooool2o`0000Cooooo0_l00005ooooo`Go
00000_ooool2o`0000_ooooo0_l00002ooooo`;o00001?ooool2o`0000;ooooo0_l000001?oooooo
0000o`000?l00006ooooo`;o00000_ooool2o`0000;ooooo0_l00004ooooo`;o00000oooool2o`00
00[ooooo0_l00008oooooa?o00008?ooool3o`0000;ooooo0ol000000ooooooo0000o`000007oooo
o`;o00001?ooool3o`0000[ooooo0_l000000ooooooo0000o`00000_ooooo`007?ooool00ol0003o
ooooooooo`0Vooooo`;o00002Oooool2o`0000oooooo1?l00003ooooo`;o00004oooool3o`0000Go
oooo1Ol00002ooooo`;o00002oooool2o`000004ooooool0003o0000o`0000Cooooo0ol00008oooo
o`;o00000oooool2o`0000Kooooo0_l00009ooooo`;o000000?oooooo`000?l000001_ooool3o`00
00;ooooo0_l00005oooooa7o00001oooool2o`0000Oooooo0ol000000ooooooo0000o`000005oooo
o`;o00001?ooool3o`0000;ooooo0_l00002ooooo`;o00003_ooool2o`0000gooooo0ol0000^oooo
o`007?ooool00ol0003oooooooooo`0Vooooo`;o00006_ooool2o`0000oooooo0_l00009ooooo`Co
00002Oooool2o`0000oooooo0ol00003ooooo`;o000000?oooooo`000?l000002?ooool2o`0000oo
oooo1?l00006ooooo`;o00001_ooool2o`0000?ooooo0_l00006ooooo`Ko00000oooool7o`0000;o
oooo0_l00003ooooo`;o00001oooool3o`000003ooooool0003o000000Gooooo0_l00005ooooo`;o
00000_ooool2o`000003ooooool0003o000000Kooooo0_l0000;ooooo`;o00002_ooool2o`0002ko
oooo000Looooo`03o`000?oooooooooo02Wooooo0_l00002ooooo`;o000000?oooooo`000?l00000
2_ooool2o`0000?ooooo0_l00004ooooo`;o00002_ooool3o`0000;ooooo0_l000000ooooooo0000
o`000002ooooo`?o00000_ooool2o`0000Gooooo0_l00007ooooo`?o00001Oooool2o`000004oooo
ool0003o0000ooooo`;o00001Oooool2o`0001Gooooo1?l0000Booooo`;o00001_ooool7o`000004
ooooool0003o0000ooooo`;o000000?oooooo`000?l000000oooool5o`0000?ooooo0_l0000>oooo
o`;o00002_ooool5o`0000Kooooo0_l00007ooooo`;o00000_ooool2o`0003[ooooo000Looooo`03
o`000?oooooooooo02Wooooo0ol000001?oooooo0000o`000?ooool2o`0000[ooooo0_l00002oooo
o`?o00001?ooool2o`0000_ooooo0_l00002ooooo`;o000000?oooooo`000?l000001Oooool4o`00
0003ooooool0003o000000Gooooo0_l00004ooooo`?o00002?ooool4o`0000?ooooo0_l000000ooo
oooo0000o`00000Aooooo`;o00002?ooool2o`0000gooooo0ol000000ooooooo0000o`000003oooo
o`co00000oooool2o`0000?ooooo1?l00003ooooo`;o00002?ooool2o`000004ooooool0003o0000
ooooo`;o00001oooool2o`0000?ooooo0_l00008ooooo`;o00001_ooool2o`0003kooooo000Loooo
o`03o`000?oooooooooo02Wooooo0ol00002ooooo`;o00001?ooool2o`0000[ooooo1?l0000Boooo
o`;o00002_ooool4o`000003ooooool0003o000000;o00000oooool2o`0000;ooooo0_l0000=oooo
o`;o00000oooool2o`000004ooooool0003o0000o`0000_ooooo0_l00002ooooo`?o00002?ooool2
o`0000gooooo0ol000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000000_l00002
ooooo`?o000000?oooooo`000?l000001?l0000=ooooo`;o00000_ooool2o`000003ooooool0003o
000000[ooooo0_l0000=ooooo`;o00001_ooool2o`0003kooooo000Looooo`03o`000?oooooooooo
02Cooooo0_l00003ooooo`;o00000oooool4o`0000;ooooo0_l00004ooooo`;o00001_ooool2o`00
00Cooooo1Ol00009ooooo`;o00002_ooool4o`0000?ooooo0_l000000ooooooo0000o`000004oooo
o`;o00005Oooool3o`0000Kooooo0_l00003ooooo`;o00000_ooool2o`0002;ooooo0_l00002oooo
o`;o00000_ooool4o`000004ooooool0003o0000ooooo`?o00001_ooool2o`0000Gooooo0_l00002
ooooo`?o00008oooool2o`0003kooooo000Looooo`03o`000?oooooooooo02Cooooo0_l0000:oooo
o`?o00001_ooool3o`0000cooooo1Ol00007ooooo`Co00002_ooool2o`0000Sooooo0_l0000Joooo
o`;o00002?ooool2o`0000?ooooo0_l00007ooooo`Co000000Coooooo`000?l0003o00005oooool2
o`0000Kooooo1?l000000ooooooo0000o`00000:ooooo`;o00002Oooool3o`0000;ooooo0ol00005
ooooo`?o00001?ooool2o`00013ooooo0_l0000;ooooo`;o0000<Oooool001cooooo00?o0000oooo
ooooool08oooool2o`0000[ooooo1?l00005ooooo`?o00004Oooool2o`0000Kooooo1?l00004oooo
o`;o00004_ooool2o`0001Kooooo0_l0000=ooooo`;o00001oooool4o`000004ooooool0003o0000
o`0001oooooo1?l000001?oooooo0000o`000?l00009ooooo`;o00003_ooool3o`0000;ooooo1_l0
00000ooooooo0000o`000003o`0000oooooo0ol0000;ooooo`;o0000<Oooool001cooooo00?o0000
ooooooooool08oooool2o`0000Sooooo1Ol000000ooooooo0000o`000002ooooo`?o000000?ooooo
o`000?l000003oooool3o`0000gooooo0ol000000ooooooo0000o`000002o`0000cooooo0_l0000A
ooooo`?o00002Oooool2o`0000?ooooo0_l0000@ooooo`Co000000?oooooo`000?l000000_ooool2
o`0000;ooooo0_l00004ooooo`;o00001Oooool3o`0000[ooooo0_l00009ooooo`;o00003Oooool3
o`000003ooooool0003o000000?o000000Coooooo`000?l0003ooooo1?l0000@ooooo`?o0000?_oo
ool001cooooo0_l0000^ooooo`Go000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00003
ooooo`Co00002Oooool3o`0000gooooo0_l000000ooooooo0000o`000004o`0000[ooooo0_l0000?
ooooo`Go00002Oooool2o`0000?ooooo0ol0000;ooooo`;o00001?ooool2o`000003ooooool0003o
000000;ooooo0_l00002ooooo`;o00001?ooool2o`0000Cooooo1_l00005ooooo`;o00006oooool2
o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l00003ooooo`;o00004?oo
ool2o`0003[ooooo000Looooo`03o`000?oooooooooo02?ooooo0_l00009ooooo`?o00003oooool4
o`0000Wooooo0ol0000;ooooo`;o00001Oooool6o`0000_ooooo0_l0000<ooooo`?o00003?ooool2
o`0000?ooooo0_l0000;ooooo`Co00002Oooool2o`0000kooooo0_l00002ooooo`;o000000?ooooo
o`000?l000000_ooool2o`0001Cooooo0_l00008ooooo`;o00000_ooool2o`0000_ooooo0_l0000:
ooooo`;o00001?ooool2o`0003[ooooo000Looooo`03o`000?oooooooooo02?ooooo0_l00009oooo
o`;o00001?ooool2o`0001Oooooo0ol0000:ooooo`?o00000oooool2o`0000Cooooo0_l00005oooo
o`;o00001?ooool3o`0000gooooo0_l0000;ooooo`;o00003_ooool2o`0000;ooooo0ol00007oooo
o`?o00000_ooool2o`00017ooooo0_l0000Eooooo`;o000000?oooooo`000?l000001Oooool2o`00
0003ooooool0003o000001;ooooo0_l00007ooooo`;o0000@?ooool001cooooo00?o0000oooooooo
ool0=?ooool2o`0000Wooooo0_l0000=ooooo`;o00002Oooool3o`0000Cooooo0ol0000:ooooo`;o
00001Oooool4o`0000Cooooo1?l00003ooooo`;o00006oooool2o`0000?ooooo0_l00004ooooo`;o
000000?oooooo`000?l000000oooool2o`0002Sooooo0_l00005ooooo`;o000000?oooooo`000?l0
00003?ooool2o`0000Oooooo0_l00019ooooo`007?ooool00ol0003oooooooooo`0Uooooo`;o0000
0oooool3o`0001;ooooo0_l00009ooooo`;o00000_ooool2o`0000Wooooo0_l00002ooooo`;o0000
00?oooooo`000?l000001?l00005ooooo`Co00001oooool4o`000003ooooool0003o000000?o0000
3?ooool2o`0001[ooooo1Ol0000>ooooo`;o00002_ooool2o`0000Gooooo0_l00002ooooo`;o0000
00?oooooo`000?l000002?ooool2o`0000?ooooo0ol0000>ooooo`;o00007?ooool2o`0003Cooooo
000Looooo`03o`000?oooooooooo02Gooooo0_l00003ooooo`Co00001?ooool2o`0001Kooooo0_l0
000:ooooo`;o00001Oooool2o`0000Cooooo1?l00003ooooo`Go000000?oooooo`000?l000001_oo
ool2o`000003ooooool0003o000000?o00003?ooool2o`0001[ooooo1?l00007ooooo`;o00001_oo
ool2o`0000[ooooo1_l000001Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`000?l00000
1oooool9o`0001?ooooo0_l0000Gooooo`;o0000=?ooool001cooooo00?o0000ooooooooool0;?oo
ool2o`0000Cooooo0_l0000=ooooo`;o00004oooool2o`0000Kooooo0_l00004ooooo`?o00000ooo
ool2o`0000Cooooo0_l00006ooooo`;o00000_ooool2o`0000kooooo0_l0000Uooooo`;o00000_oo
ool2o`00013ooooo2?l0000=ooooo`So00002_ooool2o`0000;ooooo0_l00004ooooo`;o00002?oo
ool4o`00047ooooo000Looooo`03o`000?oooooooooo03Sooooo0_l00007ooooo`;o00002_ooool2
o`0000oooooo2?l00007ooooo`;o00004oooool2o`0000Oooooo1?l00007ooooo`;o00006?ooool2
o`0000Gooooo0_l0000Dooooo`;o00005?ooool2o`0000Wooooo1?l00002ooooo`;o00001Oooool2
o`0000Oooooo1?l00004ooooo`;o0000>oooool001cooooo00?o0000ooooooooool08Oooool2o`00
01Gooooo0_l00008ooooo`;o00002?ooool3o`0000cooooo0_l00003ooooo`Ko00001oooool2o`00
00cooooo1?l00003ooooo`;o00001oooool4o`0000Oooooo0_l0000Hooooo`;o00001?ooool2o`00
01Gooooo0_l0000Dooooo`;o000000?oooooo`000?l000001Oooool4o`0000Oooooo0_l000000ooo
oooo0000o`000009ooooo`;o00001?ooool2o`0003_ooooo000Looooo`03o`000?oooooooooo027o
oooo0_l00007ooooo`;o00005_ooool2o`0000Sooooo0_l00009ooooo`;o00000_ooool2o`0000oo
oooo0ol0000:ooooo`Ko00003Oooool2o`0000?ooooo1?l0000Dooooo`;o00002oooool2o`0001Co
oooo0ol00002ooooo`;o00002oooool3o`0000Gooooo0_l00005ooooo`Co00001oooool2o`0000co
oooo0_l00004ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0:_ooool2o`0000Gooooo
0_l00005ooooo`?o00001_ooool2o`0000cooooo0_l00006ooooo`;o00001?ooool2o`0000Gooooo
1?l00003ooooo`?o00000_ooool2o`0000Oooooo0ol00005ooooo`?o00000oooool2o`0000?ooooo
0_l00003ooooo`Co00004oooool3o`0000Wooooo0_l00006ooooo`;o00003_ooool2o`0000?ooooo
0_l0000;ooooo`?o00002oooool4o`0000[ooooo0_l000000ooooooo0000o`00000=ooooo`;o0000
>oooool001cooooo00?o0000ooooooooool0<?ooool3o`0000Gooooo1?l00005ooooo`;o00003?oo
ool2o`0000Sooooo0_l00002ooooo`;o00001Oooool4o`0000?ooooo0_l00003ooooo`;o00000ooo
ool2o`0000?ooooo0_l00005ooooo`?o00000oooool7o`0000Wooooo0_l000000ooooooo0000o`00
000<ooooo`?o00001oooool4o`0000Gooooo0ol00005ooooo`;o00003?ooool2o`0000kooooo0_l0
0004ooooo`;o00000oooool3o`0000_ooooo1Ol0001:ooooo`007?ooool00ol0003oooooooooo`0`
ooooo`;o00000oooool2o`0000?ooooo0_l00005ooooo`;o00005?ooool4o`0000Wooooo0_l00003
ooooo`;o00002_ooool2o`0000Kooooo0_l00003ooooo`;o00001Oooool5o`0000Wooooo0_l00000
0ooooooo0000o`00000Aooooo`?o00000_ooool2o`0000Cooooo0_l000001Ooooooo0000o`000?l0
003ooooo00;o000000Coooooo`000?l0003o00001?ooool2o`0000Cooooo1?l00009ooooo`;o0000
0oooool3o`0000?ooooo0_l00005ooooo`;o00003?ooool2o`0000;ooooo0_l00004ooooo`;o0000
@Oooool001cooooo00?o0000ooooooooool0;_ooool5o`0000;ooooo0_l0000:ooooo`;o00005?oo
ool4o`0000Wooooo0_l00003ooooo`;o00004Oooool3o`000003ooooool0003o000000;o00001_oo
ool2o`0000oooooo0_l0000?ooooo`Co00002?ooool3o`000003ooooool0003o000000Oo00001?oo
ool2o`0000Cooooo0_l0000;ooooo`;o00001?ooool2o`0000Kooooo0ol000000ooooooo0000o`00
000@ooooo`;o00001?ooool2o`00047ooooo000Looooo`03o`000?oooooooooo02kooooo1Ol00007
ooooo`?o00005oooool2o`000003ooooool0003o000000Wooooo0_l0000Cooooo`;o000000?ooooo
o`000?l000000_l00002ooooo`Go00001Oooool2o`0000oooooo0_l0000=ooooo`Ko00002Oooool2
o`000003ooooool0003o000000;o000000?oooooo`000?l000000_l0000Aooooo`;o00001?ooool2
o`000003ooooool0003o000000Wooooo0ol00004ooooo`;o000000?oooooo`000?l000001?ooool3
o`0000?ooooo0ol00016ooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00002?ooool3o`00
00cooooo0_l000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l000000_ooool3o`00
00Cooooo0_l0000@ooooo`Go000000?oooooo`000?l000002Ol00005ooooo`Co00000_ooool3o`00
00[ooooo0_l0000;ooooo`;o00000_ooool2o`0001Wooooo0_l0000:ooooo`?o000000Coooooo`00
0?l0003ooooo0_l000000ooooooo0000o`000009ooooo`;o00001Oooool2o`000003ooooool0003o
000000Cooooo1Ol00002ooooo`Co0000A?ooool001cooooo0_l0000looooo`;o00003?ooool2o`00
0003ooooool0003o000000_ooooo1Ol0000Aooooo`;o00000oooool8o`000003ooooool0003o0000
00Go00002?ooool2o`0000;ooooo1Ol00008ooooo`;o00003oooool2o`0000oooooo0_l00008oooo
o`;o00002_ooool3o`000003ooooool0003o000001_ooooo0_l00005ooooo`;o00001?ooool2o`00
00cooooo0_l0000fooooo`007?ooool00ol0003oooooooooo`16ooooo`Co00002?ooool2o`000005
ooooool0003o0000o`000?ooool00_l00007ooooo`;o000000?oooooo`000?l000001oooool3o`00
00Kooooo1?l00004ooooo`Ko000000?oooooo`000?l000001?ooool2o`0000Gooooo0_l0000Ioooo
o`;o00001Oooool2o`0000Sooooo0_l0000?ooooo`;o00000_ooool4o`000003ooooool0003o0000
00?o00001_ooool2o`00013ooooo0_l00006ooooo`;o00002_ooool2o`0000Gooooo0_l0000foooo
o`007?ooool00ol0003oooooooooo`0Yooooo`;o00006oooool4o`000003ooooool0003o000000Go
oooo0_l000000ooooooo0000o`000002o`0000Sooooo0ol000000ooooooo0000o`000007ooooo`;o
00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000003o`0000;ooooo4Ol00002ooooo`?o
00006oooool2o`000003ooooool0003o000000Co00002_ooool2o`0000?ooooo0_l00004ooooo`;o
00000_ooool2o`0000?ooooo1Ol000000ooooooo0000o`000003ooooo`;o00000oooool2o`0001?o
oooo0_l00004ooooo`;o00000oooool3o`0003gooooo000Looooo`03o`000?oooooooooo02Wooooo
0_l0000Looooo`;o00000_ooool2o`0000[ooooo0_l00008ooooo`?o00000oooool2o`0000[ooooo
0_l00004ooooo`Oo00000_ooool4o`000003ooooool0003o000000Wo00000_ooool3o`0000_ooooo
0_l0000:ooooo`;o00000_ooool2o`0000?ooooo1?l00004ooooo`;o00001?ooool2o`0000?ooooo
0_l00009ooooo`?o000000?oooooo`000?l000001?ooool2o`0000Kooooo1?l00006ooooo`;o0000
0oooool2o`0000[ooooo1Ol00002ooooo`;o00000oooool2o`0003Wooooo000Looooo`03o`000?oo
oooooooo03Oooooo0_l0000>ooooo`;o00000_ooool2o`0000[ooooo0_l000000ooooooo0000o`00
0005ooooo`?o00000oooool2o`000003ooooool0003o000000?ooooo1?l00003ooooo`;o000000?o
ooooo`000?l000003ol000000ooooooo0000o`000002o`0000Cooooo0_l0000=ooooo`;o00000_oo
ool2o`0000Kooooo0_l0000?ooooo`;o00005?ooool3o`0000oooooo0_l00003ooooo`?o00000_oo
ool4o`000004ooooool0003o0000ooooo`;o00001oooool2o`000003ooooool0003o000000Cooooo
0_l000000ooooooo0000o`00000iooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00001?oo
ool2o`0000kooooo0_l000000ooooooo0000o`000002ooooo`;o000000Coooooo`000?l0003ooooo
0_l0000>ooooo`Co000000?oooooo`000?l000001?l000000ooooooo0000o`000002oooooa3o0000
00?oooooo`000?l000000_l00003ooooo`Ko00003_ooool2o`0000?ooooo0_l000000ooooooo0000
o`00000Aooooo`;o00003_ooool2o`0000;ooooo1?l0000Cooooo`?o00000_ooool4o`0000Cooooo
0_l000000ooooooo0000o`00000=ooooo`;o0000??ooool001cooooo00?o0000ooooooooool0?Ooo
ool2o`0000kooooo2Ol00005ooooo`;o00000oooool2o`0000;ooooo0_l00006ooooo`;o00000ooo
ool4o`000003ooooool0003o000000;o000000?oooooo`000?l000006ol000000ooooooo0000o`00
0006ooooo`;o00002?ooool2o`000003ooooool0003o000000Cooooo0_l0000;ooooo`;o00001?oo
ool2o`0000?ooooo0_l00003ooooo`So000000?oooooo`000?l000001oooool4o`0000;ooooo0_l0
0006ooooo`Co00001oooool4o`0004Wooooo000Looooo`03o`000?oooooooooo03gooooo0_l0000?
ooooo`;o000000?oooooo`000?l000000_l00006ooooo`;o00000oooool2o`0000;ooooo0_l00005
ooooo`;o00001?ooool4o`000003ooooool0003o000001oo00000_ooool2o`0000?ooooo0_l00000
1?oooooo0000o`000?ooool2o`0000kooooo0_l00009ooooo`;o00001_ooool2o`0000?ooooo0_l0
0004ooooo`?o00001Oooool2o`0000Oooooo2?l00002ooooo`;o00001?ooool3o`0000Cooooo1_l0
000<ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0=Oooool2o`0000Kooooo0_l0000Q
ooooo`?o00002?ooool6o`000005ooooool0003o0000o`000?ooool07_l000000ooooooo0000o`00
0002ooooo`Oo00001?ooool2o`0001Wooooo0_l00007ooooo`;o00002?ooool3o`0000Gooooo0_l0
0008ooooo`;o000000?oooooo`000?l000001?ooool5o`0000;ooooo1?l00002ooooo`Go000000?o
ooooo`000?l000000_ooool2o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o0000=ooo
ool001cooooo00?o0000ooooooooool0;?ooool2o`0000Oooooo0_l0000=ooooo`;o00001Oooool2
o`0001Cooooo0_l0000:ooooo`Co000000Goooooo`000?l0003o0000ooooo`07o`000003ooooool0
003o000001Co00000_ooool2o`000003ooooool0003o000000?o00008Oooool2o`0000Oooooo0_l0
0003ooooo`;o00001?ooool2o`0000Gooooo0_l0000Booooo`Ko000000Coooooo`000?l0003o0000
1?ooool3o`000003ooooool0003o000000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000Co
oooo0_l0000gooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00005_ooool2o`0000Gooooo
0_l0000Qooooo`;o000000?oooooo`000?l000008Ol00002ooooo`;o000000?oooooo`000?l00000
0oooool2o`0000kooooo0_l0000?ooooo`;o00001Oooool2o`0000Gooooo0_l00002ooooo`;o0000
7Oooool6o`0000Kooooo0_l000000ooooooo0000o`000009ooooo`;o0000?Oooool001cooooo00?o
0000ooooooooool0<?ooool4o`0000Gooooo0_l0000Kooooo`;o00001Oooool2o`0000?ooooo0_l0
000=ooooo`Oo000000?oooooo`000?l000007Ol000000ooooooo0000o`000003ooooo`;o00003_oo
ool2o`000004ooooool0003o0000o`0000_ooooo0_l00003ooooo`oo00007Oooool2o`0000;ooooo
0ol00008ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0<?ooool5o`0000Cooooo0_l0
000>ooooo`;o00002Oooool6o`0000?ooooo0_l000000ooooooo0000o`000004o`0000Oooooo0_l0
00000ooooooo0000o`000003ooooo`?o00000_oooolMo`0000_ooooo0ol0000;ooooo`Co00003ooo
ool3o`000003ooooool0003o000000Co000000?oooooo`000?l000001?l00002ooooo`;o00002ooo
ool3o`0000[ooooo1?l000000ooooooo0000o`000003o`0004oooooo000Looooo`03o`000?oooooo
oooo03?ooooo0_l0000Dooooo`;o00002Oooool2o`0000;ooooo0_l00004ooooo`Co00000_ooool2
o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000001Ol00003oooooako00000oooool2
o`0000Gooooo0ol0000;ooooo`;o00003?ooool2o`000003ooooool0003o000000co000000?ooooo
o`000?l000001_l00005ooooo`;o00000_ooool5o`0000Sooooo0_l000000ooooooo0000o`000009
o`0004gooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0iooooo`;o00002_ooool2o`0000Oooooo
0ol00008ooooo`;o000000?oooooo`000?l000001?l00006ooooo`?o000000Coooooo`000?l0003o
oooo:Ol00003ooooo`;o00007Oooool3o`000003ooooool0003o000000oo000000?oooooo`000?l0
00001Ol00006ooooo`?o000000?oooooo`000?l000000_ooool2o`0000Oooooo0_l000001?oooooo
0000o`000?ooool2o`000004ooooool0003o0000ooooo`;o0000COooool00006oooooomgMgOoV9RH
oooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`00
0?oooooooooo03Wooooo0_l0000:ooooo`;o00001_ooool4o`0000Cooooo0_l00002ooooo`Go0000
0_ooool2o`0000Kooooo0_l00002ooooo`;o000000?oooooo`000?l000009Ol00005ooooo`Go0000
4?ooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool3o`0000;ooooo6?l00006ooooo`?o
000000?oooooo`000?l000000_ooool2o`0000Kooooo0_l00004ooooo`;o000000?oooooo`000?l0
00003oooool2o`0000Cooooo0_l00007ooooo`;o0000<Oooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool0=?ooool2o`0001Cooooo0_l000000ooooooo0000o`000006ooooo`;o00000_ooool4o`0000;o
oooo0_l00002ooooo`;o00001Oooool4o`000003ooooool0003o000002Oo000000?oooooo`000?l0
00001Ol0000>ooooo`Co00000_ooool2o`000003ooooool0003o000000Co00000_oooolJo`0000Co
oooo0_l0000>ooooo`;o00001?ooool5o`0000Sooooo0_l00005ooooo`;o00001?ooool2o`0000Oo
oooo0_l0000aooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`00
0?nHV9SooooooiRHV?lQ8B401_ooool3o`00033ooooo0_l00002ooooo`;o00003oooool2o`0000?o
oooo0_l0000?ooooo`Ko00000_ooool2o`0000Gooooo0_l00006ooooo`_o000000?oooooo`000?l0
00007_l0000@ooooo`;o00002Oooool6o`0000Cooooo4Ol000000ooooooo0000o`000003o`0000[o
oooo0_l00005ooooo`;o00001oooool2o`0000Cooooo0ol00003ooooo`Co00000oooool2o`00043o
oooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oeEEEOl0003o
410@olc<c006ooooo`03o`000?oooooooooo033ooooo0_l00002ooooo`;o00001?ooool2o`0000;o
oooo0ol00004ooooo`;o00005?ooool4o`00017ooooo:Ol000000ooooooo0000o`000003ooooo`Go
00003oooool3o`0000;ooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000001So
00001_ooool2o`0000;ooooo0_l00005ooooo`?o00001_ooool2o`0000Cooooo0ol00005ooooo`;o
00000oooool2o`00043ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo
00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`0aooooo`;o000000?oooooo`000?l00000
0oooool3o`0000;ooooo0ol0000Eooooo`;o00001Oooool4o`000003ooooool0003o000000cooooo
0_l000000ooooooo0000o`00000Qo`0000;ooooo0_l00003ooooo`Oo00003oooool3o`0000;ooooo
0ol00002oooooaco00000oooool2o`0000;ooooo0_l00008ooooo`Co00005?ooool2o`0004Gooooo
00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003o
ooooooooo`0aooooo`;o00001_ooool2o`0000Oooooo0_l0000@ooooo`Co00001_ooool3o`000004
ooooool0003o0000ooooo`;o00002Oooool2o`0000;ooooo8ol000000ooooooo0000o`000003oooo
o`;o00002?ooool2o`0000kooooo1?l000000ooooooo0000o`00000Ko`000003ooooool0003o0000
00;o00003?ooool6o`000003ooooool0003o000005Kooooo00001_ooooook^k^oc8b<_l0003o<S8b
onk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`0eooooo`;o00002ooo
ool2o`0000?ooooo1?l00009ooooo`;o00001oooool3o`0000Gooooo0_l00002ooooo`;o000000?o
ooooo`000?l000001?oooolUo`000003ooooool0003o000000;o00000oooool2o`000003ooooool0
003o000000;o000000?oooooo`000?l000003_ooool4o`000003ooooool0003o000001_o000000?o
ooooo`000?l000000_l0000@ooooo`;o000000?oooooo`000?l00000E_ooool001cooooo00?o0000
ooooooooool0=Oooool2o`00013ooooo1?l0000<ooooo`;o00001?ooool3o`0000Kooooo0_l00000
1?oooooo0000o`000?ooool3o`0000?ooooo1?l000000ooooooo0000o`000007o`000003ooooool0
003o000001Co000000?oooooo`000?l000000_l000000ooooooo0000o`000002o`000003ooooool0
003o000000;o00003oooool2o`000003ooooool0003o000000?ooooo7?l00003ooooo`;o00001_oo
ool2o`0000Cooooo0_l000000ooooooo0000o`000005ooooo`Co00001?ooool2o`0004_ooooo000L
ooooo`03o`000?oooooooooo04Sooooo0_l0000=ooooo`;o00003Oooool2o`0000Cooooo0ol00002
ooooobko00000oooool2o`0000?ooooo0_l0000<ooooo`;o000000?oooooo`000?l000000_ooool;
o`000003ooooool0003o0000017o000000?oooooo`000?l000001_ooool2o`000004ooooool0003o
0000ooooo`;o000000?oooooo`000?l000000oooool6o`0000Cooooo0_l0001;ooooo`007?ooool0
0ol0003oooooooooo`18ooooo`;o00004oooool4o`0000Oooooo0ol00006oooooa_o000000?ooooo
o`000?l000003ol00008ooooo`?o00000_ooool2o`0000_ooooo0_l00002oooooaKo000000?ooooo
o`000?l000001_l000001?oooooo0000o`000?ooool2o`0000Kooooo0_l000000ooooooo0000o`00
0002ooooo`;o00000_ooool2o`0005Gooooo000Looooo`03o`000?oooooooooo03Cooooo0_l0000:
ooooo`;o00001_ooool2o`0001?ooooo1?l00007ooooo`?o00001?ooool_o`0000;ooooo0_l00004
ooooo`;o00000oooool3o`0000[ooooo9_l000000ooooooo0000o`000002o`0000Oooooo1_l0000<
ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0=?ooool3o`0000?ooooo0_l00004oooo
o`;o00001_ooool2o`0000Wooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l00002oooo
o`;o00003?ooool5o`000003ooooool0003o000000Ko000000?oooooo`000?l000007_l00002oooo
o`Co00002?ooool3o`0000Cooooo1?l00002oooooaCo000000?oooooo`000?l000003?l00005oooo
o`;o00000_ooool2o`0000Gooooo0_l0000>ooooo`;o0000Boooool001cooooo00?o0000oooooooo
ool0=Oooool2o`0000?ooooo0_l0000<ooooo`;o00002Oooool2o`0000?ooooo0_l000000ooooooo
0000o`000002o`0000;ooooo0ol0000<ooooo`Co000000?oooooo`000?l000004ol000000ooooooo
0000o`000008o`000005ooooool0003o0000o`000?ooool01?l00002ooooo`Go00002?ooool2o`00
00Cooooo1?l00004ooooob3o00002_ooool2o`0001Wooooo0ol00016ooooo`007?ooool00ol0003o
ooooooooo`16ooooo`;o00001oooool2o`0000Oooooo0_l00003ooooo`;o00000oooool2o`0000co
oooo0_l00003oooooaGo000000?oooooo`000?l000003Ol000000ooooooo0000o`000003ooooo`;o
000000?oooooo`000?l000001?l0000:ooooo`Co00000ooooolQo`0002Gooooo0ol00016ooooo`00
7?ooool00ol0003oooooooooo`0iooooo`;o00000oooool2o`0000Cooooo1?l00006ooooo`?o0000
6Oooool2o`0000?ooooo0ol000000ooooooo0000o`00000Oo`000003ooooool0003o000000So0000
1_ooool4o`0000[ooooo1Ol00002ooooo`;o000000?oooooo`000?l000006_l00004ooooo`;o0000
0_ooool4o`0001;ooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00000ooo
ool2o`0000Cooooo1_l00004ooooo`;o00002?ooool2o`000004ooooool0003o0000o`0000?ooooo
0_l00007ooooo`Co000000?oooooo`000?l000003_l000000ooooooo0000o`00000>o`0000;ooooo
0_l00002ooooo`Ko000000?oooooo`000?l000003_ooool2o`0000Gooooo1ol00002ooooo`co0000
00?oooooo`000?l000003Ol00004ooooo`;o000000?oooooo`000?l000000ol000000ooooooo0000
o`000006ooooo`;o00001oooool2o`0000[ooooo0_l00002ooooo`;o0000@?ooool001cooooo00?o
0000ooooooooool0>Oooool2o`000003ooooool0003o000000Sooooo1?l0000>ooooo`;o000000Co
ooooo`000?l0003o00000oooool3o`0000Sooooo0_l000000ooooooo0000o`00000Lo`000003oooo
ool0003o000000Go000000?oooooo`000?l000001?l00002ooooo`;o00003Oooool5o`0000;ooooo
0_l00002ooooo`?o00001?ooool;o`000003ooooool0003o0000013o00000oooool2o`0000Cooooo
0_l00004ooooo`Co00001Oooool2o`0000cooooo0_l00002ooooo`;o0000@?ooool001cooooo00?o
0000ooooooooool0??ooool2o`0000Kooooo0_l0000Fooooo`?o00000oooool2o`000003ooooool0
003o000000Oooooo1?l00002ooooo`;o00000_ooool=o`000003ooooool0003o000000go00000ooo
ool3o`0000?ooooo0_l0000;ooooo`;o00000_ooool3o`0000;ooooo1?l000000ooooooo0000o`00
0005oooooago00002?ooool3o`0000Cooooo1?l00003ooooo`Co0000D_ooool001cooooo0_l00015
ooooo`;o00002oooool2o`0000Wooooo0ol00006ooooo`;o00001?ooool2o`000003ooooool0003o
000000?o000000Coooooo`000?l0003o00000oooool;o`000003ooooool0003o000000go000000?o
ooooo`000?l000000ol00004ooooo`;o00000oooool2o`0000Gooooo1_l00004ooooo`?o000000?o
ooooo`000?l000000ol00002oooooa[o000000?oooooo`000?l000002?ooool2o`0000Kooooo0_l0
0004ooooo`?o00001_ooool2o`0004_ooooo000Looooo`03o`000?oooooooooo047ooooo0ol0000=
ooooo`;o00002Oooool4o`0000_ooooo0_l00004ooooo`Oo00001?ooool<o`000003ooooool0003o
000000[o000000Coooooo`000?l0003o00000_ooool6o`0000?ooooo0_l00007ooooo`Co00001?oo
ool2o`0000;ooooo1Ol000000ooooooo0000o`00000@o`000003ooooool0003o000000So00004Ooo
ool2o`0000Gooooo0_l00006ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0@Oooool3
o`0001[ooooo0_l00006ooooo`;o00002oooool2o`000005ooooool0003o0000o`000?ooool03_l0
00001?oooooo0000o`000?ooool2o`000003ooooool0003o000000?o00000_ooool2o`0000?ooooo
1?l0000Ooooooa_o000000Coooooo`000?l0003o00002Oooool2o`0000;ooooo0_l0001Mooooo`00
7?ooool00ol0003oooooooooo`0looooo`;o00001oooool2o`000003ooooool0003o000001;ooooo
0_l00008ooooo`;o000000?oooooo`000?l000002Oooool2o`000003ooooool0003o000001;o0000
00?oooooo`000?l000000oooool2o`000003ooooool0003o000000;o00001?ooool2o`0000Oooooo
0_l0000Gooooo`?o00000_oooolDo`0000Cooooo0_l00009ooooo`;o00000_ooool2o`0000gooooo
0_l0001>ooooo`007?ooool00ol0003oooooooooo`0looooo`;o00001oooool5o`0000Cooooo0_l0
0009ooooo`;o000000?oooooo`000?l000002oooool2o`0000Sooooo0ol00002ooooo`Go000000?o
ooooo`000?l000002ol00008ooooo`?o000000?oooooo`000?l000000oooool2o`0000Oooooo0_l0
0009ooooo`;o00003Oooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000?ooooo2_l0
0006ooooo`;o00000oooool2o`0001Gooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`16
ooooo`;o00001_ooool4o`0000Oooooo0_l00002ooooo`;o00002_ooool2o`000003ooooool0003o
000000Gooooo0ol00004ooooo`?o000000?oooooo`000?l000001Ol000000ooooooo0000o`000003
o`000003ooooool0003o000000Oo00000_ooool2o`0001?ooooo0_l00002ooooo`;o00000_ooool2
o`0000cooooo0ol000000ooooooo0000o`000003o`0000;ooooo0_l000000ooooooo0000o`000003
o`0000Sooooo0_l00003ooooo`;o00001Oooool2o`0000?ooooo0_l0000<ooooo`;o0000Boooool0
01cooooo00?o0000ooooooooool0D?ooool2o`0000_ooooo0ol00005ooooo`;o00001Oooool2o`00
00Cooooo1?l00004ooooo`Go00000_ooool2o`0000?ooooo3ol00004ooooo`;o000000?oooooo`00
0?l000003_ooool2o`0000Cooooo1?l00005ooooo`Co00000oooool3o`000003ooooool0003o0000
00Oo00000_ooool2o`0000Sooooo0_l00009ooooo`Go000000?oooooo`000?l000000_l0000<oooo
o`;o00001oooool2o`0004;ooooo000Looooo`03o`000?oooooooooo05kooooo0_l00005ooooo`;o
00001oooool2o`0000;ooooo1_l00003ooooo`Go000000Coooooo`000?l0003ooooo0_l000000ooo
oooo0000o`000004o`000005ooooool0003o0000o`000?ooool01Ol00002ooooo`;o000000?ooooo
o`000?l000002oooool2o`000003ooooool0003o000000Cooooo0_l00007ooooo`Co00000_ooool4
o`0000Cooooo1_l000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l000002?ooool5
o`0000;ooooo1?l0000Eooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0@Oooool2o`00
01;ooooo0_l0000Gooooo`;o00001_ooool4o`0000Cooooo1Ol000000ooooooo0000o`000004o`00
0004ooooool0003o0000ooooo`?o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00
000?ooooo`?o00001oooool2o`0000Oooooo0_l00003ooooo`?o00001Oooool2o`000003ooooool0
003o000000;ooooo1?l00004ooooo`;o000000?oooooo`000?l000002?ooool2o`0000Oooooo0_l0
000Cooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0@Oooool2o`0001;ooooo0_l0000=
ooooo`;o00003oooool5o`000004ooooool0003o0000ooooo`Co00000oooool2o`0000_ooooo0_l0
00001?oooooo0000o`000?ooool2o`0000Cooooo0_l00002ooooo`?o00001Oooool2o`0000Oooooo
0_l00007ooooo`;o00001?ooool2o`000003ooooool0003o000000?ooooo0_l00003ooooo`Go0000
1_ooool3o`0000Oooooo0_l0000Kooooo`Go0000@oooool001cooooo00?o0000ooooooooool0@Ooo
ool3o`00023ooooo0_l0000?ooooo`Co00000_ooool2o`0001;ooooo0_l000000ooooooo0000o`00
000:ooooo`Oo00003?ooool4o`00013ooooo0ol00002ooooo`;o000000?oooooo`000?l000000ol0
0004ooooo`;o00000_ooool2o`0000Sooooo1Ol0000;ooooo`;o00002_ooool3o`000003ooooool0
003o000004?ooooo000Looooo`03o`000?oooooooooo04;ooooo0ol0000Dooooo`;o00003oooool2
o`0000Cooooo0ol00004ooooo`;o00000_ooool2o`0000Gooooo0_l00005ooooo`;o00001?ooool3
o`0000;ooooo1?l00007ooooo`Co00002oooool2o`000003ooooool0003o000000Cooooo0_l0000=
ooooo`;o00000_ooool2o`000003ooooool0003o000000;o00001Oooool4o`0000[ooooo1Ol00002
ooooo`;o00001oooool2o`0000[ooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`13oooo
o`;o00003oooool2o`0000?ooooo0_l0000?ooooo`;o00001?ooool3o`0000Cooooo0_l00009oooo
o`Ko000000?oooooo`000?l000001Oooool2o`0000;ooooo1?l0000Fooooo`;o00001oooool2o`00
00Cooooo0_l0000;ooooo`;o00000oooool2o`0000Oooooo0_l00002ooooo`Co00001?ooool2o`00
00Gooooo0_l0000;ooooo`;o0000Coooool001cooooo00?o0000ooooooooool0AOooool2o`0000Co
oooo0_l00007ooooo`Go00004?ooool3o`0000Kooooo0_l000000ooooooo0000o`000002o`0000Ko
oooo0_l00002ooooo`Go00001?ooool5o`0001Sooooo0_l0000;ooooo`;o00001Oooool2o`0000Oo
oooo0_l000000ooooooo0000o`000002ooooo`;o00001oooool2o`0000Cooooo1?l0000Hooooo`;o
0000Coooool001cooooo00?o0000ooooooooool0AOooool2o`0000Cooooo0_l00002ooooo`;o0000
1?ooool4o`0000gooooo0_l000001?oooooo0000o`000?l00006ooooo`;o000000?oooooo`000?l0
00001Oooool2o`000005ooooool0003o0000o`000?ooool00ol00006ooooo`Go00003_ooool6o`00
00Cooooo0_l00006ooooo`;o00000oooool2o`0000gooooo0ol000000ooooooo0000o`000002oooo
o`Ko00000oooool2o`000003ooooool0003o000000Kooooo1?l00009ooooo`;o0000FOooool001co
oooo00?o0000ooooooooool0Coooool2o`0000Wooooo0_l0000:ooooo`;o00000_ooool2o`0000Oo
oooo0ol00006ooooo`;o00000_ooool2o`0000;ooooo0_l00005ooooo`?o00004Oooool6o`000003
ooooool0003o000000;o00001?ooool2o`000003ooooool0003o000001;ooooo0_l000000ooooooo
0000o`000005ooooo`Co00001_ooool4o`0000Cooooo1?l00009ooooo`;o0000FOooool001cooooo
0_l00012ooooo`;o00005oooool2o`0000Wooooo0_l00002ooooo`;o000000?oooooo`000?l00000
1Oooool3o`0001Cooooo1?l00003ooooo`;o00003Oooool2o`0000;ooooo1_l00004ooooo`;o0000
2Oooool2o`0000gooooo0_l00006ooooo`;o00002Oooool2o`0001;ooooo0_l0001Hooooo`007?oo
ool00ol0003oooooooooo`11ooooo`;o00004Oooool2o`0000cooooo0_l000000ooooooo0000o`00
0002ooooo`;o000000?oooooo`000?l000000_ooool2o`0001Sooooo1Ol00002ooooo`?o00000_oo
ool2o`0000Cooooo0_l00006ooooo`;o00004oooool2o`0001?ooooo1?l00002ooooo`;o000000?o
ooooo`000?l000000_l0000Dooooo`;o0000F?ooool001cooooo00?o0000ooooooooool0E?ooool2
o`0000;ooooo0_l00008ooooo`;o000000?oooooo`000?l000002?ooool3o`0000Sooooo0_l00008
ooooo`;o00000oooool2o`0000;ooooo1?l000000ooooooo0000o`000004o`0000;ooooo1Ol00002
ooooo`;o00002?ooool2o`0001?ooooo0ol0000;ooooo`;o00001?ooool2o`000003ooooool0003o
000000;o0000K_ooool001cooooo00?o0000ooooooooool0F?ooool2o`0000cooooo0_l00002oooo
o`;o00000oooool2o`0000Oooooo1?l00006ooooo`Co00000oooool2o`0000Cooooo0_l00002oooo
o`Co00000oooool2o`000003ooooool0003o000000;ooooo0_l000001?oooooo0000o`000?ooool8
o`00017ooooo0ol00026ooooo`007?ooool00ol0003oooooooooo`1Booooo`;o00004?ooool4o`00
00;ooooo0_l0000<ooooo`;o00002?ooool2o`0000Cooooo1?l000000ooooooo0000o`000007oooo
o`Co00000oooool2o`0000;ooooo1Ol000000ooooooo0000o`000002o`0000;ooooo0_l0000Boooo
o`;o00001?ooool2o`00083ooooo000Looooo`03o`000?oooooooooo05;ooooo0_l0000@ooooo`?o
00006oooool2o`0000Cooooo1?l000000ooooooo0000o`000007ooooo`Co00002Oooool5o`0000Ko
oooo0_l00003ooooo`;o00001?ooool2o`0000cooooo0_l00020ooooo`007?ooool00ol0003ooooo
ooooo`1Dooooo`;o00000_ooool2o`0000Wooooo1?l00008ooooo`;o00001oooool2o`0000Sooooo
0_l0000:ooooo`;o00002oooool2o`0000Oooooo1?l00006ooooo`Co000000?oooooo`000?l00000
1?ooool4o`0000Cooooo0_l00026ooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o00000_oo
ool2o`0000Wooooo1?l00008ooooo`Co00001Oooool2o`000003ooooool0003o0000017ooooo0_l0
0009ooooo`Co00000oooool4o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`;o00002?oo
ool5o`0000;ooooo0_l0000Eooooo`;o0000Koooool001cooooo00?o0000ooooooooool0Foooool2
o`0000Kooooo0_l00009ooooo`;o000000?oooooo`000?l000002?ooool2o`00017ooooo0_l00009
ooooo`;o00001Oooool4o`0000;ooooo1Ol00004ooooo`;o00002_ooool5o`0000kooooo0_l00006
ooooo`Co00006_ooool2o`0000?ooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`1Goooo
o`;o00000_ooool2o`00017ooooo0_l00002ooooo`;o00003_ooool2o`0000[ooooo0_l0000<oooo
o`;o00002Oooool2o`0000Kooooo0_l00002ooooo`;o00002Oooool2o`0000_ooooo0_l000000ooo
oooo0000o`000006ooooo`;o00007?ooool2o`0000?ooooo0_l0001>ooooo`007?ooool00ol0003o
ooooooooo`1Gooooo`;o00003_ooool3o`0000Sooooo0_l0000>ooooo`;o00006?ooool2o`0000Co
oooo0_l00004ooooo`;o00002Oooool2o`0001Gooooo0ol0000<ooooo`;o0000K_ooool001cooooo
00?o0000ooooooooool0G?ooool2o`0000Wooooo0ol00004ooooo`;o00006Oooool2o`0000;ooooo
1?l00002ooooo`;o00003Oooool2o`0000Cooooo0_l0000>ooooo`;o00004?ooool2o`0000gooooo
1_l0000Aooooo`;o0000Eoooool001cooooo00?o0000ooooooooool0G?ooool3o`0000Cooooo0_l0
0009ooooo`;o00003oooool2o`0000Kooooo1?l00002ooooo`Co00000_ooool2o`0002?ooooo0_l0
000Aooooo`;o00000_ooool2o`0000Wooooo1Ol0000Aooooo`;o0000Eoooool001cooooo00?o0000
ooooooooool0GOooool2o`0000Cooooo0_l0000Jooooo`;o00001_ooool2o`0004;ooooo1_l0000:
ooooo`;o0000K?ooool001cooooo00?o0000ooooooooool0C?ooool2o`0002Gooooo0_l0000Poooo
o`;o0000;oooool2o`0000?ooooo1?l0000<ooooo`;o0000K?ooool001cooooo00?o0000oooooooo
ool0C?ooool2o`000003ooooool0003o000000oooooo0_l0000;ooooo`;o00001?ooool2o`0000?o
oooo0_l0000Kooooo`;o0000;oooool2o`0000?ooooo0_l00009ooooo`;o00004oooool2o`0005co
oooo000Looooo`;o0000D?ooool2o`0000oooooo0_l0000;ooooo`?o00002?ooool2o`0000Sooooo
0_l00012ooooo`?o00002?ooool2o`0000?ooooo1?l0000Aooooo`;o0000G?ooool001cooooo00?o
0000ooooooooool0G_ooool2o`0000gooooo0ol00005ooooo`;o00000oooool2o`0000Kooooo0_l0
0013ooooo`;o00000_ooool2o`0000Cooooo0_l00003ooooo`Co0000Koooool001cooooo00?o0000
ooooooooool0G_ooool2o`0000Sooooo0_l00003ooooo`Co00001?ooool2o`000003ooooool0003o
000000;o0000Coooool2o`0000Cooooo0_l00003ooooo`;o00004Oooool2o`0005kooooo000Loooo
o`03o`000?oooooooooo06Sooooo0_l00005ooooo`;o00001oooool3o`0001Gooooo0_l00011oooo
o`;o00005?ooool2o`0005kooooo000Looooo`03o`000?oooooooooo053ooooo0_l0000Hooooo`;o
00003Oooool4o`0000gooooo0_l00004ooooo`;o00001oooool2o`0003Sooooo0_l0001dooooo`00
7?ooool00ol0003oooooooooo`1@ooooo`;o00006?ooool2o`0000_ooooo0_l00002ooooo`;o0000
2oooool4o`0000gooooo0_l0000booooo`?o0000NOooool001cooooo00?o0000ooooooooool0HOoo
ool2o`0001;ooooo1?l0000?ooooo`;o00001?ooool2o`0000_ooooo0ol0000Pooooo`;o00003?oo
ool4o`0007Wooooo000Looooo`03o`000?oooooooooo067ooooo0_l0000Aooooo`?o00005oooool2
o`0000_ooooo0ol0000Pooooo`?o00002oooool3o`0007[ooooo000Looooo`03o`000?oooooooooo
07Cooooo0_l000000ooooooo0000o`00000Dooooo`;o000000?oooooo`000?l00000;Oooool2o`00
00cooooo0ol0001iooooo`007?ooool00ol0003oooooooooo`1Tooooo`;o00002oooool2o`000004
ooooool0003o0000ooooo`;o00001Oooool2o`0000;ooooo0_l00002ooooo`?o00001?ooool2o`00
0003ooooool0003o000000_ooooo0_l0000_ooooo`;o0000NOooool001cooooo00?o0000oooooooo
ool0I?ooool2o`0000_ooooo2?l00005ooooo`Ko000000?oooooo`000?l000000_l0000Dooooo`;o
0000:?ooool2o`0000?ooooo0_l0001kooooo`007?ooool00ol0003oooooooooo`1Tooooo`;o0000
3Oooool6o`000003ooooool0003o000000Cooooo0_l00003ooooo`;o0000?Oooool2o`000003oooo
ool0003o000000?ooooo0_l0001kooooo`007?ooool00ol0003oooooooooo`1_ooooo`Co000000?o
ooooo`000?l000000oooool3o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000003ooo
ool2o`0000;ooooo0_l0000Kooooo`;o00002Oooool2o`0000Gooooo0_l0000Eooooo`;o0000IOoo
ool001cooooo00?o0000ooooooooool0Koooool4o`0000Kooooo0_l00004ooooo`;o00000oooool2
o`000003ooooool0003o000000[ooooo0_l00003ooooo`;o00000_ooool2o`0001_ooooo0_l00009
ooooo`;o00001Oooool2o`0001Gooooo0_l0001Uooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^
k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0
K_ooool2o`0001?ooooo0ol0000=ooooo`;o0000<oooool2o`000003ooooool0003o000007cooooo
00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRH
V?lQ8B401_ooool00ol0003oooooooooo`1^ooooo`Co00004Oooool3o`000003ooooool0003o0000
02Cooooo0ol00008ooooo`Go00002oooool2o`000003ooooool0003o000007cooooo00000ooooooo
410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo073ooooo0_l0000;ooooo`;o00002?ooool2o`0000oooooo0_l0000Aoooo
o`Go00000oooool2o`0000;ooooo1_l0000:ooooo`;o00004_ooool2o`0006cooooo00000ooooooo
0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06oooo
o`?o0000Moooool2o`0000Cooooo0_l00008ooooo`Co00001_ooool2o`0000Gooooo0_l0000Aoooo
o`;o00000oooool2o`000004ooooool0003o0000ooooo`Co00001Oooool4o`0000Cooooo0_l0000B
ooooo`;o0000K?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Oo<
c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0Moooool2o`0000Kooooo1?l00006
ooooo`;o00001_ooool3o`000004ooooool0003o0000ooooo`;o00000_ooool2o`00017ooooo0ol0
0004ooooo`?o00001_ooool4o`0000Gooooo0_l0001oooooo`0000?ooooooa0@4?ooool00_ooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`1oooooo`Co00003?ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l00000
0_ooool2o`0000Wooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00000oooool2o`000003
ooooool0003o000000Kooooo0_l00007ooooo`;o0000Ooooool00006oooooomgMgOoV9RHoooooonH
V9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0M?ooool4
o`0000Wooooo0_l00006ooooo`;o00001?ooool2o`0000Oooooo0_l000000ooooooo0000o`00000:
ooooo`;o000000Coooooo`000?l0003o00001oooool2o`0000;ooooo1Ol00008ooooo`;o00003ooo
ool2o`00077ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@06ooooo`03o`000?oooooooooo07Cooooo1?l0000Aooooo`;o00003Oooool5o`0000Wo
oooo0ol0000;ooooo`;o00000_ooool5o`0000Sooooo0_l00007ooooo`;o00001_ooool2o`00077o
oooo000Looooo`03o`000?oooooooooo08gooooo0_l00009ooooo`Co00002_ooool3o`00013ooooo
0_l00004ooooo`;o00002oooool4o`0000?ooooo0_l0001dooooo`007?ooool00ol0003ooooooooo
o`2=ooooo`;o00002oooool2o`0001Wooooo0_l00002ooooo`;o00001?ooool2o`0000Sooooo0_l0
00000ooooooo0000o`000005ooooo`;o0000M?ooool001cooooo00?o0000ooooooooool0S_ooool2
o`0000Oooooo0_l0000Looooo`;o00004_ooool2o`0007kooooo000Looooo`03o`000?oooooooooo
08Sooooo0_l00004ooooo`Go00001?ooool2o`0002Wooooo0_l00025ooooo`007?ooool00ol0003o
ooooooooo`28ooooo`;o00001_ooool3o`0000Cooooo0_l0000Aooooo`;o00001Oooool2o`0000oo
oooo0_l00006ooooo`;o0000OOooool001cooooo00?o0000ooooooooool0O?ooool2o`0002cooooo
0_l00005ooooo`;o00002_ooool2o`0000_ooooo0_l0001mooooo`007?ooool00ol0003ooooooooo
o`1looooo`;o0000?oooool2o`0008[ooooo000Looooo`03o`000?oooooooooo09Cooooo0_l0000?
ooooo`;o00001?ooool4o`0009[ooooo000Looooo`03o`000?oooooooooo09Cooooo0ol0000<oooo
o`Co00001?ooool4o`00013ooooo0_l00028ooooo`007?ooool00ol0003oooooooooo`2Eooooo`;o
00003?ooool2o`0001[ooooo0_l00028ooooo`007?ooool00ol0003oooooooooo`2Kooooo`;o0000
1_ooool2o`0000;ooooo0_l0000Xooooo`;o0000M_ooool001cooooo0_l0002Looooo`;o00001_oo
ool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool3o`00027ooooo0_l0001fooooo`007?oo
ool00ol0003oooooooooo`28ooooo`;o00008?ooool6o`0009Wooooo000Looooo`03o`000?oooooo
oooo08Sooooo0_l0000Hooooo`;o00001oooool2o`0000;ooooo0_l0002Hooooo`007?ooool00ol0
003oooooooooo`2Rooooo`;o00002oooool2o`0002?ooooo0_l0001cooooo`007?ooool00ol0003o
ooooooooo`3Dooooo`;o0000Loooool001cooooo00?o0000ooooooooool0c_ooool2o`0007Wooooo
000Looooo`03o`000?oooooooooo09Wooooo0_l0000cooooo`;o0000NOooool001cooooo00?o0000
ooooooooool0VOooool2o`000:kooooo000Looooo`03o`000?oooooooooo09_ooooo0_l0002/oooo
o`007?ooool00ol0003oooooooooo`2Kooooo`;o0000[?ooool001cooooo00?o0000ooooooooool0
Z?ooool2o`0009oooooo000Looooo`03o`000?oooooooooo0:Oooooo0ol0000Booooo`;o0000Rooo
ool001cooooo00?o0000ooooooooool0Yoooool3o`0001;ooooo0_l0002;ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003o
oooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001;ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB_oo
ool001Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood[ooooo000Doooo
o`03o`000?oooooooooo00Gooooo0ol0003ooooood[ooooo000Dooooo`03o`000?oooooooooo0?oo
ooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003ooooooooo
o`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001;ooooo00?oEEEEofIV
I_l00000oooooomDooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00YOooool0
1?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo01Oooooo00?o0000onk^k_ooool00ooo
ool01?l@413o0000odA4A?o<c<`4ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0T?ooool00:Kooooo
00Go0000ooooooooooooooooo`000009ooooo`Ko00002oooool00omEEEGoZJVYooooo`05ooooo`03
oiRHV?l@413ogMgM00?ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@2@ooooo`00Y_ooool01Ol0003o
oooooooooooooooo000001[ooooo00?oZJVYoeEEEOooool01_ooool00on7QhOoEEEEooooo`02oooo
o`05o`000?ooooooooooooooool00000T?ooool00:Kooooo00Go0000ooooooooooooooooo`000009
ooooo`Ko00003?ooool00olQ8B7oooooooooo`02ooooo`05olc<c?lQ8B7o0000oeEEEOl000000ooo
ool01Olb<S;oV9RHoooooonHV9So<S8b093ooooo002Vooooo`05o`000?n7QhOoooooojVYZOl00000
6oooool00omEEEGoc<c<ooooo`02ooooo`05ob4Q8On7QhOooooooiRHV?l000000oooool01Oo<c<co
0000o`000?l0003oc<c<093ooooo002Uooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHoooooooo
ool06Oooool00onYZJWoMgMgooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol@
413o^[Zjoooooonj^[[o410@093ooooo0033ooooo`05oa0@4?oooooooooooooooolb<S800oooool0
1OlQ8B7oV9RHoooooomgMgOoEEEE00?ooooo00Go0000okZj^_oooooo^[Zjo`00002@ooooo`00`ooo
ool5o`0000?ooooo00Goc<c<oa0@4?l0003o<S8bonk^kP03ooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT0T?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(804) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.62326 .67921 Mdot
.61066 .66621 Mdot
.54131 .29143 Mdot
.38254 .55755 Mdot
.46194 .49559 Mdot
.50557 .33133 Mdot
.64173 .45992 Mdot
.65934 .46762 Mdot
.51469 .34696 Mdot
.40105 .69754 Mdot
.61291 .44484 Mdot
.42088 .52344 Mdot
.63134 .46785 Mdot
.38804 .59936 Mdot
.53914 .16412 Mdot
.4333 .54569 Mdot
.626 .61474 Mdot
.40757 .41081 Mdot
.33825 .57823 Mdot
.55393 .34185 Mdot
.60718 .59253 Mdot
.38899 .60337 Mdot
.63157 .67315 Mdot
.38945 .59959 Mdot
.4035 .55863 Mdot
.61128 .6389 Mdot
.65648 .64211 Mdot
.4318 .5693 Mdot
.39477 .57987 Mdot
.63573 .42946 Mdot
.40421 .45585 Mdot
.39358 .18483 Mdot
.42962 .53753 Mdot
.3937 .79075 Mdot
.65664 .46268 Mdot
.20017 .44908 Mdot
.53912 .34395 Mdot
.60779 .47773 Mdot
.6589 .46208 Mdot
.63814 .49122 Mdot
.61429 .48037 Mdot
.60545 .64073 Mdot
.60875 .50561 Mdot
.57636 .44707 Mdot
.37301 .55772 Mdot
.72018 .54062 Mdot
.26911 .3861 Mdot
.43333 .58523 Mdot
.58965 .66103 Mdot
.54583 .356 Mdot
.52775 .83453 Mdot
.64563 .49508 Mdot
.72496 .35305 Mdot
.42761 .09777 Mdot
.62891 .48356 Mdot
.38492 .55043 Mdot
.52912 .32896 Mdot
.41128 .61991 Mdot
.40302 .60373 Mdot
.53455 .81117 Mdot
.41802 .57059 Mdot
.39465 .39891 Mdot
.56536 .61811 Mdot
.50075 .30284 Mdot
.50912 .33857 Mdot
.65438 .44408 Mdot
.60332 .6165 Mdot
.62823 .45946 Mdot
.42602 .65966 Mdot
.52906 .35894 Mdot
.43437 .58613 Mdot
.60838 .44986 Mdot
.57194 .65363 Mdot
.41032 .63863 Mdot
.74208 .56373 Mdot
.60988 .19102 Mdot
.40812 .41774 Mdot
.51561 .79836 Mdot
.64172 .72901 Mdot
.63932 .23446 Mdot
.39386 .58968 Mdot
.86657 .48959 Mdot
.55561 .16872 Mdot
.6305 .67058 Mdot
.43095 .49837 Mdot
.47987 .36816 Mdot
.38339 .62528 Mdot
.4588 .45621 Mdot
.44972 .64455 Mdot
.73837 .64524 Mdot
.51992 .34788 Mdot
.5926 .64017 Mdot
.37869 .56182 Mdot
.44872 .61907 Mdot
.51037 .72914 Mdot
.42244 .64686 Mdot
.43265 .56281 Mdot
.64275 .61402 Mdot
.63817 .43739 Mdot
.47689 .60088 Mdot
.59042 .50353 Mdot
.71145 .3461 Mdot
.36061 .59601 Mdot
.50843 .3557 Mdot
.60979 .60484 Mdot
.35706 .59959 Mdot
.64103 .48095 Mdot
.4133 .58207 Mdot
.58868 .49119 Mdot
.60558 .66906 Mdot
.44519 .62316 Mdot
.40436 .41119 Mdot
.78096 .57783 Mdot
.59621 .62878 Mdot
.82316 .44389 Mdot
.4244 .57674 Mdot
.39217 .60916 Mdot
.60963 .66357 Mdot
.52586 .30572 Mdot
.44784 .44264 Mdot
.58339 .62424 Mdot
.64925 .48065 Mdot
.65154 .66223 Mdot
.35652 .63212 Mdot
.49771 .33757 Mdot
.70896 .34089 Mdot
.72897 .32299 Mdot
.26584 .56805 Mdot
.37557 .61926 Mdot
.6768 .51727 Mdot
.50925 .32008 Mdot
.59651 .6474 Mdot
.62575 .46162 Mdot
.42121 .54652 Mdot
.63531 .62907 Mdot
.61251 .45867 Mdot
.39558 .41213 Mdot
.33993 .30677 Mdot
.57906 .64622 Mdot
.5879 .54756 Mdot
.59764 .43633 Mdot
.63586 .49174 Mdot
.42754 .81978 Mdot
.6154 .66629 Mdot
.37388 .38227 Mdot
.61646 .45556 Mdot
.32427 .45041 Mdot
.42836 .55329 Mdot
.27396 .62111 Mdot
.82287 .60745 Mdot
.5107 .84212 Mdot
.75188 .43192 Mdot
.39292 .36906 Mdot
.62156 .49593 Mdot
.38816 .56766 Mdot
.62092 .66044 Mdot
.61332 .6525 Mdot
.45566 .59793 Mdot
.41339 .558 Mdot
.44354 .6058 Mdot
.451 .60773 Mdot
.29478 .35807 Mdot
.44684 .60533 Mdot
.57551 .34158 Mdot
.60908 .62213 Mdot
.40451 .56604 Mdot
.53863 .30239 Mdot
.39505 .53294 Mdot
.60687 .46762 Mdot
.40267 .60943 Mdot
.40679 .55206 Mdot
.38475 .63646 Mdot
.61616 .4867 Mdot
.33478 .23468 Mdot
.81348 .60507 Mdot
.21419 .36347 Mdot
.78122 .44136 Mdot
.52679 .31722 Mdot
.38166 .6177 Mdot
.37978 .39778 Mdot
.49992 .63502 Mdot
.40621 .59812 Mdot
.59728 .81786 Mdot
.4215 .55654 Mdot
.35634 .7469 Mdot
.33173 .62335 Mdot
.21171 .35329 Mdot
.52048 .41429 Mdot
.40092 .57765 Mdot
.48911 .70214 Mdot
.29173 .69093 Mdot
.51936 .57315 Mdot
.61984 .48269 Mdot
.53282 .30119 Mdot
.5342 .33615 Mdot
.59837 .49072 Mdot
.47255 .62988 Mdot
.36926 .68561 Mdot
.48211 .59766 Mdot
.71347 .33597 Mdot
.56848 .64809 Mdot
.36023 .38477 Mdot
.58164 .65964 Mdot
.84512 .40305 Mdot
.71637 .64613 Mdot
.60681 .4217 Mdot
.41668 .3779 Mdot
.53561 .29176 Mdot
.71389 .33244 Mdot
.37615 .39158 Mdot
.4308 .59733 Mdot
.58769 .65498 Mdot
.31349 .72938 Mdot
.33232 .61413 Mdot
.24211 .68392 Mdot
.64643 .65047 Mdot
.49041 .43758 Mdot
.61697 .47137 Mdot
.55671 .34963 Mdot
.37352 .60238 Mdot
.43551 .61884 Mdot
.58646 .60392 Mdot
.43058 .5854 Mdot
.60132 .71043 Mdot
.40576 .54999 Mdot
.48661 .36711 Mdot
.37995 .43177 Mdot
.61115 .49896 Mdot
.26757 .57721 Mdot
.59316 .68145 Mdot
.55545 .26154 Mdot
.54886 .34481 Mdot
.45372 .685 Mdot
.61214 .44352 Mdot
.40437 .40881 Mdot
.55079 .32629 Mdot
.37662 .3622 Mdot
.36006 .61145 Mdot
.53868 .34691 Mdot
.36924 .37709 Mdot
.31628 .29603 Mdot
.38331 .54769 Mdot
.30626 .38934 Mdot
.63843 .45365 Mdot
.64951 .66964 Mdot
.41701 .56977 Mdot
.72713 .3211 Mdot
.34866 .58716 Mdot
.6891 .38889 Mdot
.7309 .34634 Mdot
.71902 .354 Mdot
.60491 .21288 Mdot
.40821 .38791 Mdot
.75778 .48555 Mdot
.62746 .55841 Mdot
.60404 .61547 Mdot
.37522 .56174 Mdot
.26783 .2761 Mdot
.61619 .45683 Mdot
.42834 .59874 Mdot
.48296 .36822 Mdot
.61884 .45382 Mdot
.409 .62439 Mdot
.62352 .49082 Mdot
.61694 .65809 Mdot
.50179 .25817 Mdot
.64321 .62652 Mdot
.3909 .54576 Mdot
.64384 .47392 Mdot
.54502 .32351 Mdot
.61479 .64001 Mdot
.41364 .58535 Mdot
.37966 .60823 Mdot
.72061 .33578 Mdot
.40054 .57158 Mdot
.27471 .27708 Mdot
.43378 .57551 Mdot
.51937 .29042 Mdot
.43122 .64751 Mdot
.52069 .85395 Mdot
.35858 .30282 Mdot
.59296 .62279 Mdot
.72451 .35116 Mdot
.51898 .34299 Mdot
.4829 .25929 Mdot
.54556 .55889 Mdot
.4026 .58694 Mdot
.72498 .34489 Mdot
.46703 .41954 Mdot
.65154 .43845 Mdot
.40357 .64918 Mdot
.73073 .62331 Mdot
.55381 .32541 Mdot
.71551 .33358 Mdot
.36475 .52928 Mdot
.61128 .60451 Mdot
.38592 .55545 Mdot
.54568 .3389 Mdot
.65188 .66327 Mdot
.37161 .54797 Mdot
.23644 .42953 Mdot
.73514 .33166 Mdot
.63711 .45396 Mdot
.34776 .66558 Mdot
.44407 .59899 Mdot
.53777 .32807 Mdot
.63795 .66337 Mdot
.65398 .45965 Mdot
.60679 .63174 Mdot
.29648 .7055 Mdot
.78649 .45873 Mdot
.27781 .35401 Mdot
.41781 .38162 Mdot
.69051 .37853 Mdot
.20093 .38481 Mdot
.77374 .50002 Mdot
.28692 .49546 Mdot
.16043 .50446 Mdot
.54441 .31034 Mdot
.3331 .4101 Mdot
.52131 .33735 Mdot
.37774 .5764 Mdot
.5058 .33541 Mdot
.21029 .34665 Mdot
.42363 .55618 Mdot
.5294 .31964 Mdot
.43404 .32453 Mdot
.41673 .56262 Mdot
.60007 .624 Mdot
.50202 .17595 Mdot
.75136 .67181 Mdot
.69367 .67107 Mdot
.52788 .31079 Mdot
.61941 .76858 Mdot
.42787 .56737 Mdot
.41002 .53194 Mdot
.62339 .65681 Mdot
.42467 .65097 Mdot
.36234 .39778 Mdot
.3795 .35938 Mdot
.27753 .60611 Mdot
.83143 .49915 Mdot
.47638 .63398 Mdot
.61688 .64352 Mdot
.60021 .71983 Mdot
.73864 .56443 Mdot
.70679 .32485 Mdot
.63778 .42167 Mdot
.34435 .23182 Mdot
.44388 .6662 Mdot
.58678 .55091 Mdot
.73577 .6091 Mdot
.59126 .65278 Mdot
.29631 .29117 Mdot
.62903 .48103 Mdot
.52431 .68296 Mdot
.41335 .7623 Mdot
.43702 .6085 Mdot
.62466 .43375 Mdot
.45658 .55013 Mdot
.72396 .67813 Mdot
.33392 .43554 Mdot
.72258 .28807 Mdot
.37905 .55137 Mdot
.75657 .4995 Mdot
.39635 .60853 Mdot
.29776 .55507 Mdot
.43642 .57666 Mdot
.61308 .63031 Mdot
.48898 .60241 Mdot
.49369 .48622 Mdot
.83448 .54899 Mdot
.71379 .66011 Mdot
.38921 .3662 Mdot
.38288 .60802 Mdot
.43652 .61197 Mdot
.4007 .38091 Mdot
.62769 .64039 Mdot
.43917 .58054 Mdot
.23401 .51166 Mdot
.44161 .6031 Mdot
.60608 .47086 Mdot
.41846 .44809 Mdot
.67616 .66922 Mdot
.43016 .63676 Mdot
.64519 .62488 Mdot
.62578 .48783 Mdot
.66042 .45371 Mdot
.39462 .66475 Mdot
.61962 .49375 Mdot
.38883 .55297 Mdot
.42904 .42553 Mdot
.62347 .67439 Mdot
.33425 .55013 Mdot
.63198 .64083 Mdot
.64006 .74354 Mdot
.62949 .49082 Mdot
.71369 .32468 Mdot
.54789 .5924 Mdot
.6335 .4751 Mdot
.68569 .71385 Mdot
.47043 .6507 Mdot
.34915 .56893 Mdot
.71184 .7021 Mdot
.53626 .30966 Mdot
.71149 .32916 Mdot
.64572 .4753 Mdot
.44452 .60232 Mdot
.36502 .62852 Mdot
.60198 .45446 Mdot
.53942 .73836 Mdot
.46978 .27085 Mdot
.43363 .56748 Mdot
.61858 .63211 Mdot
.59684 .64427 Mdot
.36479 .55432 Mdot
.41288 .59161 Mdot
.52029 .29221 Mdot
.73145 .33633 Mdot
.70319 .34519 Mdot
.72626 .3231 Mdot
.54949 .36443 Mdot
.71215 .44383 Mdot
.63672 .49194 Mdot
.69876 .50967 Mdot
.63473 .38171 Mdot
.35003 .64007 Mdot
.53963 .32425 Mdot
.42316 .62718 Mdot
.36928 .58571 Mdot
.65326 .45868 Mdot
.75722 .39146 Mdot
.39035 .50625 Mdot
.59798 .67296 Mdot
.61468 .49239 Mdot
.42949 .67976 Mdot
.63434 .40408 Mdot
.36399 .39514 Mdot
.69419 .68417 Mdot
.61879 .43578 Mdot
.58852 .64002 Mdot
.59847 .45866 Mdot
.43906 .60949 Mdot
.4521 .57925 Mdot
.60336 .66341 Mdot
.4087 .38453 Mdot
.36792 .63499 Mdot
.40693 .62404 Mdot
.63426 .83025 Mdot
.7444 .55871 Mdot
.67335 .45139 Mdot
.39026 .5743 Mdot
.34097 .59744 Mdot
.39584 .36592 Mdot
.43974 .59995 Mdot
.37361 .60574 Mdot
.78626 .58014 Mdot
.6255 .51607 Mdot
.38383 .42587 Mdot
.52439 .67929 Mdot
.64588 .64738 Mdot
.30196 .25895 Mdot
.71191 .34807 Mdot
.62607 .50969 Mdot
.50363 .25874 Mdot
.72054 .32707 Mdot
.65803 .37951 Mdot
.30054 .27449 Mdot
.72049 .32377 Mdot
.51915 .26363 Mdot
.46014 .52638 Mdot
.44393 .57337 Mdot
.4025 .61325 Mdot
.37853 .40117 Mdot
.61687 .66474 Mdot
.50149 .42241 Mdot
.3489 .27107 Mdot
.39002 .60535 Mdot
.55612 .61565 Mdot
.33961 .25495 Mdot
.72015 .33265 Mdot
.39802 .40213 Mdot
.35848 .39754 Mdot
.3941 .61113 Mdot
.79145 .53764 Mdot
.61242 .64074 Mdot
.41328 .58566 Mdot
.43801 .62678 Mdot
.53081 .31151 Mdot
.58538 .64468 Mdot
.54724 .34699 Mdot
.73368 .34169 Mdot
.19251 .57669 Mdot
.60704 .84013 Mdot
.64785 .45038 Mdot
.23456 .34674 Mdot
.66423 .46163 Mdot
.67841 .24544 Mdot
.73031 .32557 Mdot
.40183 .59426 Mdot
.58214 .67241 Mdot
.41531 .5816 Mdot
.42971 .60666 Mdot
.43205 .59885 Mdot
.4806 .6271 Mdot
.58908 .82276 Mdot
.38468 .3861 Mdot
.34833 .63106 Mdot
.49854 .31572 Mdot
.2581 .30882 Mdot
.49893 .1891 Mdot
.41603 .63326 Mdot
.39093 .61329 Mdot
.61737 .61881 Mdot
.45667 .61063 Mdot
.63777 .42826 Mdot
.63656 .66804 Mdot
.36081 .62362 Mdot
.28652 .30676 Mdot
.44249 .58548 Mdot
.19985 .39429 Mdot
.59907 .45799 Mdot
.6916 .68516 Mdot
.35758 .63981 Mdot
.71979 .32317 Mdot
.71215 .32844 Mdot
.69756 .33473 Mdot
.62537 .42665 Mdot
.53412 .32264 Mdot
.45049 .21944 Mdot
.46894 .58518 Mdot
.39043 .56385 Mdot
.34216 .6023 Mdot
.56362 .33817 Mdot
.43629 .45977 Mdot
.75057 .4499 Mdot
.4449 .67112 Mdot
.50996 .30346 Mdot
.64546 .67689 Mdot
.81586 .39923 Mdot
.63651 .66676 Mdot
.38297 .42674 Mdot
.60858 .45552 Mdot
.36678 .40245 Mdot
.61416 .78937 Mdot
.6082 .66826 Mdot
.5892 .60326 Mdot
.52838 .31764 Mdot
.51775 .44465 Mdot
.33104 .16611 Mdot
.50528 .35897 Mdot
.25291 .5263 Mdot
.62428 .65235 Mdot
.41666 .64159 Mdot
.45973 .41714 Mdot
.51381 .44896 Mdot
.5205 .32665 Mdot
.38861 .5928 Mdot
.8241 .52221 Mdot
.52283 .29117 Mdot
.39721 .64738 Mdot
.51455 .31049 Mdot
.61147 .47427 Mdot
.51251 .31552 Mdot
.61597 .68612 Mdot
.36072 .60456 Mdot
.39466 .12163 Mdot
.56009 .44752 Mdot
.41604 .57299 Mdot
.61485 .49232 Mdot
.22251 .51829 Mdot
.42532 .6152 Mdot
.3652 .40414 Mdot
.49707 .32907 Mdot
.45169 .27527 Mdot
.42662 .56874 Mdot
.51299 .32377 Mdot
.61852 .68255 Mdot
.66197 .48714 Mdot
.61867 .21071 Mdot
.70461 .33729 Mdot
.62394 .66477 Mdot
.69734 .35802 Mdot
.60655 .4303 Mdot
.39125 .64176 Mdot
.44287 .6192 Mdot
.61224 .62526 Mdot
.61974 .26314 Mdot
.45238 .62514 Mdot
.39383 .58982 Mdot
.54407 .29662 Mdot
.55531 .29465 Mdot
.5785 .24168 Mdot
.54405 .31151 Mdot
.34135 .60455 Mdot
.61143 .62586 Mdot
.37211 .57802 Mdot
.59855 .62311 Mdot
.37585 .5617 Mdot
.59238 .69448 Mdot
.63045 .66859 Mdot
.80632 .46859 Mdot
.37582 .58919 Mdot
.33589 .64409 Mdot
.43208 .6038 Mdot
.43727 .59074 Mdot
.49452 .34038 Mdot
.39547 .38251 Mdot
.45729 .63699 Mdot
.55932 .27092 Mdot
.39533 .40767 Mdot
.31639 .71024 Mdot
.53092 .30972 Mdot
.37681 .40426 Mdot
.30491 .36607 Mdot
.72137 .35217 Mdot
.3858 .39398 Mdot
.48474 .19353 Mdot
.64992 .45305 Mdot
.64763 .66364 Mdot
.41546 .56225 Mdot
.16906 .54613 Mdot
.40585 .45095 Mdot
.72526 .33771 Mdot
.42493 .57347 Mdot
.42398 .62424 Mdot
.61177 .60729 Mdot
.85889 .43974 Mdot
.54581 .29183 Mdot
.38207 .56514 Mdot
.63218 .61854 Mdot
.83602 .58671 Mdot
.49784 .34859 Mdot
.38387 .39747 Mdot
.60207 .46815 Mdot
.66425 .65948 Mdot
.70397 .33709 Mdot
.65274 .43865 Mdot
.46906 .30798 Mdot
.63824 .77242 Mdot
.42969 .57781 Mdot
.54139 .33178 Mdot
.51777 .84204 Mdot
.47598 .61955 Mdot
.67254 .49787 Mdot
.30321 .65643 Mdot
.59051 .64929 Mdot
.60143 .46173 Mdot
.36904 .36972 Mdot
.63398 .67413 Mdot
.62556 .63931 Mdot
.65719 .474 Mdot
.53506 .383 Mdot
.49335 .43957 Mdot
.60368 .45994 Mdot
.74631 .63712 Mdot
.31331 .72314 Mdot
.72779 .34293 Mdot
.40298 .39818 Mdot
.33669 .76423 Mdot
.6054 .63965 Mdot
.34219 .23278 Mdot
.57103 .82542 Mdot
.43272 .56297 Mdot
.36734 .38673 Mdot
.66111 .39641 Mdot
.43289 .22029 Mdot
.62247 .45078 Mdot
.45764 .46965 Mdot
.36954 .41405 Mdot
.44228 .57633 Mdot
.68067 .64104 Mdot
.38071 .58616 Mdot
.6102 .46396 Mdot
.65664 .71963 Mdot
.58904 .63665 Mdot
.60159 .43635 Mdot
.69101 .70494 Mdot
.36822 .58802 Mdot
.38186 .59091 Mdot
.31508 .51348 Mdot
.5876 .65623 Mdot
.70201 .34205 Mdot
.4077 .58135 Mdot
.40915 .61815 Mdot
.39809 .6432 Mdot
.39137 .68284 Mdot
.78038 .54892 Mdot
.37969 .56826 Mdot
.53192 .3701 Mdot
.37576 .53748 Mdot
.37853 .59298 Mdot
.63437 .61711 Mdot
.61373 .82939 Mdot
.7366 .32538 Mdot
.40531 .61177 Mdot
.43673 .58052 Mdot
.6565 .46916 Mdot
.47976 .4273 Mdot
.5175 .45469 Mdot
.52053 .35978 Mdot
.29741 .46725 Mdot
.48102 .61883 Mdot
.63939 .63535 Mdot
.39776 .41542 Mdot
.37958 .62772 Mdot
.63488 .626 Mdot
.41028 .53675 Mdot
.51837 .29534 Mdot
.72963 .339 Mdot
.67117 .60224 Mdot
.39084 .39682 Mdot
.47938 .39483 Mdot
.68933 .53952 Mdot
.53513 .30027 Mdot
.39628 .56144 Mdot
.65036 .49646 Mdot
.53396 .35311 Mdot
.72105 .33768 Mdot
.35265 .53814 Mdot
.61488 .65044 Mdot
.59382 .63401 Mdot
.28083 .59089 Mdot
.52811 .27635 Mdot
.75397 .71628 Mdot
.61104 .47283 Mdot
.35242 .59866 Mdot
.64295 .54491 Mdot
.59444 .63185 Mdot
.27725 .58893 Mdot
.37849 .40522 Mdot
.62461 .44976 Mdot
.71049 .31955 Mdot
.62926 .62257 Mdot
.58158 .64972 Mdot
.3752 .55199 Mdot
.39772 .62849 Mdot
.2797 .50387 Mdot
.276 .60349 Mdot
.61718 .48553 Mdot
.40506 .3906 Mdot
.53459 .36035 Mdot
.3803 .57845 Mdot
.63072 .67145 Mdot
.34658 .73838 Mdot
.44687 .59672 Mdot
.52187 .29088 Mdot
.5938 .6534 Mdot
.40293 .38165 Mdot
.37899 .41226 Mdot
.43725 .5912 Mdot
.53194 .80377 Mdot
.63922 .47161 Mdot
.59639 .62748 Mdot
.60457 .58376 Mdot
.44708 .63625 Mdot
.39169 .62546 Mdot
.39847 .51758 Mdot
.65464 .44278 Mdot
.68363 .63357 Mdot
.39827 .4197 Mdot
.60839 .65246 Mdot
.41578 .57538 Mdot
.39412 .39914 Mdot
.62203 .57556 Mdot
.72708 .32758 Mdot
.51135 .31419 Mdot
.36157 .39801 Mdot
.38535 .37343 Mdot
.39798 .40836 Mdot
.35981 .21996 Mdot
.56956 .64773 Mdot
.5814 .7065 Mdot
.43762 .57648 Mdot
.28333 .5858 Mdot
.46091 .5906 Mdot
.61819 .42828 Mdot
.54029 .3111 Mdot
.43183 .60882 Mdot
.37365 .55335 Mdot
.32513 .6583 Mdot
.38953 .67859 Mdot
.58719 .59687 Mdot
.59638 .66361 Mdot
.36551 .67034 Mdot
.53552 .31243 Mdot
.87629 .47766 Mdot
.25823 .25754 Mdot
.3708 .6488 Mdot
.49932 .43105 Mdot
.63312 .66978 Mdot
.65452 .48051 Mdot
.51716 .46582 Mdot
.60087 .47687 Mdot
.60422 .65202 Mdot
.37911 .57696 Mdot
.70154 .50966 Mdot
.3951 .36186 Mdot
.44437 .60799 Mdot
.61647 .46716 Mdot
.44404 .60679 Mdot
.61832 .43172 Mdot
.55331 .6662 Mdot
.74314 .6116 Mdot
.42307 .55723 Mdot
.43508 .642 Mdot
.33127 .65713 Mdot
.41298 .63287 Mdot
.66865 .32214 Mdot
.63325 .65005 Mdot
.82764 .50762 Mdot
.37169 .54947 Mdot
.56809 .78061 Mdot
.44682 .58683 Mdot
.62226 .27938 Mdot
.39513 .63051 Mdot
.52295 .495 Mdot
.43899 .56884 Mdot
.37934 .61307 Mdot
.64112 .47762 Mdot
.65674 .46949 Mdot
.61157 .68093 Mdot
.7018 .33856 Mdot
.21874 .34734 Mdot
.40091 .62537 Mdot
.53541 .37135 Mdot
.62157 .53786 Mdot
.39092 .37573 Mdot
.60339 .64838 Mdot
.83975 .60065 Mdot
.62542 .48983 Mdot
.48404 .34415 Mdot
.63569 .28092 Mdot
.55609 .34568 Mdot
.59916 .51092 Mdot
.44759 .67715 Mdot
.40431 .37886 Mdot
.44578 .58245 Mdot
.4012 .79282 Mdot
.74626 .5292 Mdot
.36145 .6316 Mdot
.5942 .46084 Mdot
.50883 .62445 Mdot
.34411 .7647 Mdot
.35971 .37528 Mdot
.37761 .36768 Mdot
.63695 .48131 Mdot
.55238 .30735 Mdot
.47442 .5757 Mdot
.377 .4054 Mdot
.52357 .29812 Mdot
.69825 .34405 Mdot
.53228 .5518 Mdot
.60991 .64178 Mdot
.69373 .65989 Mdot
.70036 .56811 Mdot
.61859 .48651 Mdot
.55024 .26401 Mdot
.65698 .66909 Mdot
.59652 .60635 Mdot
.70623 .32956 Mdot
.49392 .33921 Mdot
.57653 .66769 Mdot
.37468 .63725 Mdot
.3377 .63432 Mdot
.39622 .60706 Mdot
.37204 .39427 Mdot
.41179 .63574 Mdot
.49648 .32261 Mdot
.62106 .45549 Mdot
.52501 .35075 Mdot
.64331 .46805 Mdot
.71897 .48115 Mdot
.41831 .589 Mdot
.38414 .6149 Mdot
.43827 .41892 Mdot
.58641 .66331 Mdot
.57058 .81315 Mdot
.53286 .37294 Mdot
.52655 .33277 Mdot
.36584 .58482 Mdot
.62297 .68229 Mdot
.36124 .42467 Mdot
.44726 .40312 Mdot
.42692 .63437 Mdot
.63396 .651 Mdot
.3857 .56399 Mdot
.30389 .33647 Mdot
.74913 .59499 Mdot
.60388 .63124 Mdot
.84278 .5033 Mdot
.38791 .57942 Mdot
.47436 .53568 Mdot
.34033 .59709 Mdot
.2484 .48799 Mdot
.44334 .64098 Mdot
.64663 .65259 Mdot
.40214 .60761 Mdot
.63974 .65792 Mdot
.5428 .29928 Mdot
.64492 .49032 Mdot
.62621 .66353 Mdot
.42135 .63861 Mdot
.35988 .20249 Mdot
.61349 .47157 Mdot
.38093 .60685 Mdot
.63033 .43757 Mdot
.64323 .63117 Mdot
.59222 .66564 Mdot
.49226 .19863 Mdot
.66985 .48409 Mdot
.61494 .47748 Mdot
.3903 .55687 Mdot
.68486 .58625 Mdot
.374 .57642 Mdot
.27635 .51494 Mdot
.36176 .57111 Mdot
.43446 .64734 Mdot
.66036 .20593 Mdot
.6618 .4796 Mdot
.76674 .6952 Mdot
.34197 .27906 Mdot
.37863 .20671 Mdot
.6671 .66985 Mdot
.35952 .37559 Mdot
.30387 .28087 Mdot
.73188 .34448 Mdot
.50316 .321 Mdot
.43271 .60809 Mdot
.64504 .70435 Mdot
.60556 .4735 Mdot
.39129 .38057 Mdot
.42175 .55639 Mdot
.51394 .29574 Mdot
.53407 .21486 Mdot
.62006 .49497 Mdot
.60509 .6415 Mdot
.59134 .66759 Mdot
.82751 .59119 Mdot
.41941 .57468 Mdot
.385 .61125 Mdot
.60883 .457 Mdot
.46453 .63933 Mdot
.40857 .39923 Mdot
.39761 .32457 Mdot
.61676 .4782 Mdot
.56557 .46593 Mdot
.60822 .67083 Mdot
.42439 .6252 Mdot
.42447 .46164 Mdot
.59435 .34521 Mdot
.43884 .7059 Mdot
.37833 .39939 Mdot
.29345 .50709 Mdot
.64664 .65194 Mdot
.62222 .46288 Mdot
.32214 .36446 Mdot
.34986 .58834 Mdot
.41992 .62409 Mdot
.29648 .50805 Mdot
.47576 .42177 Mdot
.35104 .40947 Mdot
.45803 .6091 Mdot
.46768 .42489 Mdot
.36377 .58825 Mdot
.36363 .62631 Mdot
.41241 .66083 Mdot
.38007 .62061 Mdot
.63555 .65619 Mdot
.32742 .66374 Mdot
.50908 .32294 Mdot
.51406 .72216 Mdot
.47194 .46904 Mdot
.4091 .56937 Mdot
.37664 .57925 Mdot
.46001 .68771 Mdot
.58826 .50667 Mdot
.62977 .64961 Mdot
.56425 .65185 Mdot
.63631 .48797 Mdot
.33456 .63672 Mdot
.56087 .32269 Mdot
.3065 .655 Mdot
.52109 .35199 Mdot
.63493 .65078 Mdot
.53256 .33117 Mdot
.64255 .48375 Mdot
.54155 .33286 Mdot
.54699 .36594 Mdot
.60507 .4452 Mdot
.61199 .67402 Mdot
.42407 .63434 Mdot
.62908 .49195 Mdot
.31057 .51599 Mdot
.37205 .39559 Mdot
.49216 .19829 Mdot
.38357 .53244 Mdot
.3701 .49956 Mdot
.23761 .42787 Mdot
.52815 .34751 Mdot
.76118 .59377 Mdot
.63002 .66856 Mdot
.41526 .38477 Mdot
.63677 .65835 Mdot
.59535 .8119 Mdot
.40034 .3844 Mdot
.48197 .1938 Mdot
.38485 .34291 Mdot
.48033 .23766 Mdot
.45815 .59737 Mdot
.56345 .66995 Mdot
.54031 .35044 Mdot
.60693 .4768 Mdot
.48517 .38132 Mdot
.3705 .61064 Mdot
.77498 .49072 Mdot
.58072 .6228 Mdot
.70839 .35065 Mdot
.62843 .46121 Mdot
.59274 .4659 Mdot
.42292 .57782 Mdot
.50209 .25094 Mdot
.35716 .59415 Mdot
.33265 .38033 Mdot
.29477 .48842 Mdot
.30665 .65745 Mdot
.3858 .55356 Mdot
.52161 .35607 Mdot
.38692 .56263 Mdot
.50385 .60228 Mdot
.41988 .81612 Mdot
.3631 .53907 Mdot
.79445 .45801 Mdot
.44652 .37267 Mdot
.607 .66516 Mdot
.36495 .6478 Mdot
.71731 .34424 Mdot
.38908 .57667 Mdot
.23239 .72146 Mdot
.38833 .39228 Mdot
.49231 .28683 Mdot
.45356 .61323 Mdot
.41199 .58051 Mdot
.44773 .80525 Mdot
.62463 .70976 Mdot
.71448 .31743 Mdot
.41734 .62116 Mdot
.31235 .46247 Mdot
.65271 .44465 Mdot
.35503 .57889 Mdot
.39963 .61193 Mdot
.28707 .69041 Mdot
.64231 .43464 Mdot
.5323 .34379 Mdot
.72894 .34842 Mdot
.53371 .36185 Mdot
.35602 .40217 Mdot
.53032 .47079 Mdot
.27277 .61298 Mdot
.74696 .59253 Mdot
.36944 .41096 Mdot
.44569 .62019 Mdot
.4147 .49767 Mdot
.39626 .58319 Mdot
.37474 .36774 Mdot
.63516 .42995 Mdot
.63176 .65847 Mdot
.66816 .59443 Mdot
.71505 .33595 Mdot
.3962 .64665 Mdot
.36664 .36802 Mdot
.61944 .65694 Mdot
.58556 .27508 Mdot
.60969 .66001 Mdot
.62974 .47688 Mdot
.61553 .4272 Mdot
.39855 .39059 Mdot
.63728 .6562 Mdot
.52108 .3695 Mdot
.34594 .27685 Mdot
.36498 .5699 Mdot
.65863 .41922 Mdot
.60255 .68383 Mdot
.65353 .63273 Mdot
.57596 .63595 Mdot
.42504 .58533 Mdot
.48858 .42967 Mdot
.34936 .61279 Mdot
.6325 .48509 Mdot
.5141 .30652 Mdot
.27454 .63005 Mdot
.45552 .81392 Mdot
.56292 .4576 Mdot
.4539 .63964 Mdot
.37563 .60096 Mdot
.39393 .61096 Mdot
.41448 .547 Mdot
.33145 .33016 Mdot
.41539 .59111 Mdot
.64292 .47319 Mdot
.50456 .34839 Mdot
.42153 .57134 Mdot
.71688 .34617 Mdot
.48303 .44414 Mdot
.39183 .41687 Mdot
.50699 .47814 Mdot
.30744 .23469 Mdot
.62083 .65695 Mdot
.54917 .3283 Mdot
.50285 .32439 Mdot
.39591 .41209 Mdot
.61219 .48189 Mdot
.61418 .6624 Mdot
.2516 .46337 Mdot
.40335 .40269 Mdot
.40623 .61115 Mdot
.45915 .32669 Mdot
.835 .45971 Mdot
.45411 .59968 Mdot
.42284 .60629 Mdot
.72327 .35272 Mdot
.55644 .31328 Mdot
.16306 .57806 Mdot
.4738 .40899 Mdot
.39678 .38559 Mdot
.38245 .36997 Mdot
.57488 .63593 Mdot
.3682 .63986 Mdot
.642 .46377 Mdot
.45073 .41898 Mdot
.23036 .55015 Mdot
.53256 .39725 Mdot
.66913 .2417 Mdot
.44213 .59165 Mdot
.44904 .7973 Mdot
.37489 .56636 Mdot
.61009 .60607 Mdot
.59826 .6179 Mdot
.62404 .64634 Mdot
.63356 .48075 Mdot
.63338 .74508 Mdot
.64576 .46929 Mdot
.2915 .23811 Mdot
.64196 .66643 Mdot
.39958 .26995 Mdot
.53108 .32546 Mdot
.467 .60422 Mdot
.40602 .38417 Mdot
.57022 .45615 Mdot
.42088 .66162 Mdot
.78479 .53426 Mdot
.53964 .32505 Mdot
.5992 .66973 Mdot
.47981 .64649 Mdot
.17435 .40573 Mdot
.52906 .44752 Mdot
.48187 .52786 Mdot
.55484 .81718 Mdot
.4013 .38265 Mdot
.45678 .69794 Mdot
.41071 .38738 Mdot
.61496 .45639 Mdot
.37174 .61311 Mdot
.37889 .62203 Mdot
.37966 .55716 Mdot
.41767 .59134 Mdot
.65369 .46245 Mdot
.39578 .54145 Mdot
.52088 .85387 Mdot
.72768 .34594 Mdot
.30747 .31181 Mdot
.36971 .40279 Mdot
.59799 .45291 Mdot
.51113 .35096 Mdot
.70004 .3416 Mdot
.26612 .59111 Mdot
.43569 .56657 Mdot
.43182 .60593 Mdot
.71448 .3216 Mdot
.42488 .65826 Mdot
.45948 .66026 Mdot
.50852 .32561 Mdot
.56064 .47163 Mdot
.35897 .38461 Mdot
.3662 .40129 Mdot
.61115 .44091 Mdot
.63728 .65768 Mdot
.37951 .4034 Mdot
.54741 .29848 Mdot
.39807 .53923 Mdot
.39597 .63927 Mdot
.60241 .68355 Mdot
.57139 .82545 Mdot
.36144 .36968 Mdot
.48556 .63342 Mdot
.64351 .65394 Mdot
.57255 .63135 Mdot
.42051 .62101 Mdot
.37682 .52733 Mdot
.65636 .65216 Mdot
.37567 .41239 Mdot
.59708 .4552 Mdot
.44914 .23969 Mdot
.61205 .46214 Mdot
.61755 .6617 Mdot
.37431 .54303 Mdot
.61047 .67288 Mdot
.39445 .57554 Mdot
.76523 .25427 Mdot
.38658 .62647 Mdot
.73862 .68261 Mdot
.25431 .49468 Mdot
.50089 .33014 Mdot
.52448 .36845 Mdot
.72304 .34575 Mdot
.64439 .65543 Mdot
.37618 .62549 Mdot
.39102 .3703 Mdot
.40471 .20238 Mdot
.60877 .69727 Mdot
.51224 .3032 Mdot
.55998 .32265 Mdot
.64456 .43332 Mdot
.44986 .59548 Mdot
.41957 .62865 Mdot
.54078 .33522 Mdot
.25421 .40174 Mdot
.63512 .63134 Mdot
.38501 .61025 Mdot
.37594 .59749 Mdot
.5038 .33064 Mdot
.34347 .28164 Mdot
.56387 .67697 Mdot
.3774 .61655 Mdot
.41667 .35583 Mdot
.62133 .42792 Mdot
.40984 .54696 Mdot
.39871 .54152 Mdot
.37656 .37615 Mdot
.279 .32619 Mdot
.36512 .78453 Mdot
.60638 .43906 Mdot
.70265 .34257 Mdot
.4242 .63919 Mdot
.52944 .32475 Mdot
.41332 .64139 Mdot
.20034 .43052 Mdot
.72099 .35076 Mdot
.40691 .59306 Mdot
.38121 .65387 Mdot
.58562 .63351 Mdot
.4106 .58848 Mdot
.32711 .70204 Mdot
.5193 .36327 Mdot
.4092 .59151 Mdot
.54873 .80644 Mdot
.65237 .44186 Mdot
.37505 .65263 Mdot
.36416 .37871 Mdot
.24482 .49029 Mdot
.69251 .55022 Mdot
.56347 .34657 Mdot
.37438 .40805 Mdot
.4234 .63576 Mdot
.55244 .30989 Mdot
.60643 .47955 Mdot
.77519 .51098 Mdot
.43971 .56419 Mdot
.61119 .46657 Mdot
.62216 .45642 Mdot
.39507 .39295 Mdot
.78703 .66334 Mdot
.44482 .65383 Mdot
.41471 .63379 Mdot
.2562 .66007 Mdot
.5863 .62071 Mdot
.42183 .63382 Mdot
.44916 .60752 Mdot
.64183 .45493 Mdot
.55127 .58928 Mdot
.52559 .64745 Mdot
.4334 .32532 Mdot
.61823 .43137 Mdot
.56894 .34553 Mdot
.55241 .31087 Mdot
.37049 .40276 Mdot
.60193 .66048 Mdot
.37619 .41846 Mdot
.5225 .31285 Mdot
.43768 .58041 Mdot
.6337 .44726 Mdot
.42024 .72918 Mdot
.64842 .49303 Mdot
.50644 .29869 Mdot
.63588 .61348 Mdot
.65252 .54358 Mdot
.33821 .7951 Mdot
.70824 .55676 Mdot
.60793 .50542 Mdot
.39 .37542 Mdot
.45384 .36256 Mdot
.37638 .59928 Mdot
.49851 .68 Mdot
.4387 .62033 Mdot
.54733 .81645 Mdot
.53664 .30539 Mdot
.70635 .3283 Mdot
.37178 .61377 Mdot
.29987 .49316 Mdot
.59718 .48697 Mdot
.64755 .43491 Mdot
.42103 .59843 Mdot
.63275 .47621 Mdot
.40216 .6289 Mdot
.50119 .3483 Mdot
.75872 .6908 Mdot
.37778 .60379 Mdot
.3426 .57277 Mdot
.64516 .51522 Mdot
.49008 .19718 Mdot
.50908 .37214 Mdot
.44739 .79882 Mdot
.15882 .44218 Mdot
.63395 .47389 Mdot
.34057 .60989 Mdot
.54211 .34452 Mdot
.72255 .35321 Mdot
.49207 .36101 Mdot
.44048 .61301 Mdot
.43825 .59646 Mdot
.36629 .58306 Mdot
.3817 .59024 Mdot
.49464 .67812 Mdot
.41913 .67732 Mdot
.45719 .78408 Mdot
.43017 .60546 Mdot
.66034 .60905 Mdot
.64855 .46884 Mdot
.58887 .59707 Mdot
.38469 .35394 Mdot
.44019 .58799 Mdot
.64445 .70813 Mdot
.60252 .44563 Mdot
.28928 .24166 Mdot
.64328 .43364 Mdot
.51757 .34396 Mdot
.65955 .47607 Mdot
.39942 .57282 Mdot
.59647 .64295 Mdot
.50994 .3599 Mdot
.74289 .45557 Mdot
.50348 .31896 Mdot
.41671 .57293 Mdot
.34053 .29871 Mdot
.50451 .32264 Mdot
.48832 .45323 Mdot
.59524 .64749 Mdot
.31953 .46171 Mdot
.60929 .6147 Mdot
.40455 .59058 Mdot
.39998 .59057 Mdot
.70009 .34912 Mdot
.62607 .49765 Mdot
.64632 .63691 Mdot
.64329 .82552 Mdot
.3668 .41766 Mdot
.619 .63971 Mdot
.45843 .56513 Mdot
.48619 .42414 Mdot
.60218 .62712 Mdot
.28164 .45371 Mdot
.61053 .48159 Mdot
.57187 .65613 Mdot
.44055 .54318 Mdot
.57758 .55041 Mdot
.40697 .3701 Mdot
.50604 .30215 Mdot
.56147 .52104 Mdot
.53986 .3523 Mdot
.60329 .4395 Mdot
.53075 .28071 Mdot
.65329 .44749 Mdot
.68145 .71581 Mdot
.60195 .71164 Mdot
.63828 .50134 Mdot
.60908 .42932 Mdot
.52272 .31911 Mdot
.42774 .55737 Mdot
.48121 .48661 Mdot
.45528 .62661 Mdot
.45507 .58262 Mdot
.65601 .44839 Mdot
.64179 .63252 Mdot
.64443 .67027 Mdot
.55302 .64464 Mdot
.58537 .66043 Mdot
.51213 .35319 Mdot
.75497 .60657 Mdot
.60696 .79412 Mdot
.6148 .44105 Mdot
.63389 .41633 Mdot
.37464 .57697 Mdot
.52748 .32221 Mdot
.54101 .30052 Mdot
.63703 .45572 Mdot
.46354 .71125 Mdot
.34187 .59104 Mdot
.62059 .61051 Mdot
.64059 .66788 Mdot
.60816 .6275 Mdot
.57598 .64833 Mdot
.58065 .72314 Mdot
.60714 .4779 Mdot
.64352 .66121 Mdot
.4147 .59695 Mdot
.44009 .6013 Mdot
.70817 .33518 Mdot
.36212 .39034 Mdot
.41822 .53738 Mdot
.35722 .5455 Mdot
.42236 .62136 Mdot
.51003 .31536 Mdot
.35499 .52872 Mdot
.71161 .34922 Mdot
.54012 .28521 Mdot
.56231 .33925 Mdot
.71336 .32525 Mdot
.56146 .59833 Mdot
.16311 .41515 Mdot
.38215 .56527 Mdot
.42945 .48918 Mdot
.52502 .32767 Mdot
.77835 .6129 Mdot
.65709 .59858 Mdot
.38895 .55156 Mdot
.54562 .54958 Mdot
.5035 .35578 Mdot
.58558 .61868 Mdot
.43091 .62797 Mdot
.73036 .3243 Mdot
.39536 .4156 Mdot
.46007 .56635 Mdot
.72791 .35033 Mdot
.63645 .64909 Mdot
.35144 .43026 Mdot
.57118 .64758 Mdot
.49857 .35365 Mdot
.38226 .65575 Mdot
.33849 .15895 Mdot
.54906 .34281 Mdot
.4023 .21297 Mdot
.5813 .69856 Mdot
.37642 .60641 Mdot
.54641 .34778 Mdot
.59223 .61333 Mdot
.62382 .42589 Mdot
.45903 .43058 Mdot
.62613 .67173 Mdot
.70098 .33793 Mdot
.71284 .33003 Mdot
.50674 .32611 Mdot
.59192 .65762 Mdot
.36026 .56398 Mdot
.59454 .62348 Mdot
.66094 .47468 Mdot
.40728 .5527 Mdot
.20913 .35558 Mdot
.34401 .64502 Mdot
.64467 .64567 Mdot
.52316 .28904 Mdot
.40027 .36768 Mdot
.42679 .56134 Mdot
.35783 .24519 Mdot
.45054 .60189 Mdot
.63482 .43487 Mdot
.81211 .54965 Mdot
.40239 .72439 Mdot
.43579 .5743 Mdot
.3746 .57883 Mdot
.60363 .44839 Mdot
.43303 .56466 Mdot
.45308 .59962 Mdot
.67126 .49628 Mdot
.5871 .63445 Mdot
.39505 .60468 Mdot
.53019 .29633 Mdot
.44647 .8185 Mdot
.42584 .63944 Mdot
.78783 .43611 Mdot
.31476 .47377 Mdot
.80486 .57691 Mdot
.40779 .63885 Mdot
.30485 .52852 Mdot
.39323 .59423 Mdot
.43111 .58327 Mdot
.38414 .55931 Mdot
.4296 .78515 Mdot
.52507 .31649 Mdot
.50325 .31059 Mdot
.4082 .37044 Mdot
.31224 .47258 Mdot
.36859 .38495 Mdot
.61469 .43537 Mdot
.60527 .21631 Mdot
.72485 .34826 Mdot
.63786 .65834 Mdot
.35967 .60706 Mdot
.49814 .35632 Mdot
.42858 .62292 Mdot
.39493 .57259 Mdot
.5 .35153 Mdot
.55465 .33117 Mdot
.50917 .2767 Mdot
.40963 .39011 Mdot
.62736 .65481 Mdot
.38119 .54854 Mdot
.3955 .40736 Mdot
.35728 .56843 Mdot
.47499 .41485 Mdot
.62831 .65238 Mdot
.59219 .62497 Mdot
.64886 .63607 Mdot
.43876 .58135 Mdot
.40544 .56901 Mdot
.64649 .46761 Mdot
.60738 .68594 Mdot
.60739 .44932 Mdot
.53486 .35368 Mdot
.51179 .3666 Mdot
.44064 .61229 Mdot
.48832 .63329 Mdot
.38522 .37079 Mdot
.52176 .34547 Mdot
.71606 .32025 Mdot
.41228 .37773 Mdot
.42553 .5742 Mdot
.52438 .35521 Mdot
.36485 .40033 Mdot
.48047 .72526 Mdot
.15756 .4738 Mdot
.39239 .36374 Mdot
.41892 .59904 Mdot
.45658 .8099 Mdot
.32057 .3917 Mdot
.37389 .42211 Mdot
.6202 .44058 Mdot
.44909 .60133 Mdot
.20859 .50609 Mdot
.36421 .40834 Mdot
.5503 .82367 Mdot
.50046 .33387 Mdot
.5426 .58852 Mdot
.4311 .53585 Mdot
.51086 .6895 Mdot
.37459 .41935 Mdot
.61155 .65767 Mdot
.61856 .6902 Mdot
.41196 .60564 Mdot
.40545 .35482 Mdot
.66019 .44725 Mdot
.49807 .33633 Mdot
.53306 .37111 Mdot
.58835 .65176 Mdot
.70839 .60347 Mdot
.52728 .29286 Mdot
.48554 .59591 Mdot
.49343 .26599 Mdot
.32523 .59642 Mdot
.66978 .72552 Mdot
.73512 .45694 Mdot
.38829 .63739 Mdot
.38928 .36472 Mdot
.59838 .47112 Mdot
.64171 .47263 Mdot
.62484 .47884 Mdot
.5347 .36565 Mdot
.51536 .46841 Mdot
.54145 .3232 Mdot
.76789 .5008 Mdot
.39369 .39959 Mdot
.31516 .44032 Mdot
.37822 .62547 Mdot
.37674 .60208 Mdot
.35719 .56393 Mdot
.35917 .59535 Mdot
.39152 .59601 Mdot
.61566 .48283 Mdot
.54817 .3577 Mdot
.4484 .2804 Mdot
.61935 .63092 Mdot
.59509 .26676 Mdot
.53136 .32563 Mdot
.72388 .35172 Mdot
.3853 .3838 Mdot
.30032 .54925 Mdot
.5556 .29197 Mdot
.53156 .33174 Mdot
.41211 .53975 Mdot
.61974 .61799 Mdot
.42254 .68531 Mdot
.39331 .5901 Mdot
.52397 .34634 Mdot
.51741 .39056 Mdot
.41674 .70336 Mdot
.40891 .51191 Mdot
.37318 .4321 Mdot
.49036 .42698 Mdot
.40276 .41685 Mdot
.38169 .52819 Mdot
.78054 .60877 Mdot
.52147 .31402 Mdot
.51165 .33994 Mdot
.36706 .369 Mdot
.47499 .53878 Mdot
.59501 .6572 Mdot
.70646 .32764 Mdot
.63608 .4393 Mdot
.3975 .58503 Mdot
.53081 .36459 Mdot
.49497 .55381 Mdot
.47483 .27523 Mdot
.61795 .47701 Mdot
.54121 .28603 Mdot
.44627 .58775 Mdot
.42082 .60068 Mdot
.39937 .38023 Mdot
.44208 .48593 Mdot
.46653 .58608 Mdot
.37746 .20718 Mdot
.74137 .6099 Mdot
.72106 .64328 Mdot
.41976 .62435 Mdot
.58566 .64861 Mdot
.7283 .32517 Mdot
.40367 .39755 Mdot
.37703 .54567 Mdot
.15497 .46054 Mdot
.64716 .67802 Mdot
.61715 .46404 Mdot
.72464 .32361 Mdot
.5134 .46735 Mdot
.45044 .60461 Mdot
.43811 .62096 Mdot
.42155 .58821 Mdot
.14395 .48878 Mdot
.51642 .29936 Mdot
.57641 .6394 Mdot
.3767 .39718 Mdot
.57831 .64966 Mdot
.50326 .31358 Mdot
.66523 .58575 Mdot
.42273 .56894 Mdot
.62385 .61041 Mdot
.60874 .65632 Mdot
.64362 .43242 Mdot
.64057 .42655 Mdot
.51465 .27263 Mdot
.38621 .62568 Mdot
.73377 .32618 Mdot
.60339 .61591 Mdot
.55757 .33492 Mdot
.40086 .38424 Mdot
.63215 .48954 Mdot
.4302 .604 Mdot
.51468 .31777 Mdot
.37725 .6413 Mdot
.60567 .62288 Mdot
.5311 .33105 Mdot
.73819 .33085 Mdot
.37588 .37185 Mdot
.43533 .59935 Mdot
.35223 .42044 Mdot
.71416 .32319 Mdot
.37369 .59583 Mdot
.29109 .6402 Mdot
.36951 .35164 Mdot
.74588 .45122 Mdot
.54594 .32573 Mdot
.71124 .34293 Mdot
.59193 .62174 Mdot
.59949 .56236 Mdot
.50992 .34272 Mdot
.2921 .60093 Mdot
.47617 .49877 Mdot
.38568 .54675 Mdot
.60448 .63582 Mdot
.44227 .35878 Mdot
.32688 .23596 Mdot
.31129 .37398 Mdot
.38728 .60839 Mdot
.54501 .34942 Mdot
.3693 .40671 Mdot
.61677 .43864 Mdot
.7896 .43768 Mdot
.62012 .72514 Mdot
.53514 .28014 Mdot
.37967 .56563 Mdot
.60459 .61604 Mdot
.63528 .45572 Mdot
.70777 .49628 Mdot
.5432 .29352 Mdot
.54034 .30786 Mdot
.42851 .57242 Mdot
.3841 .40483 Mdot
.2786 .37261 Mdot
.50102 .31299 Mdot
.53766 .36112 Mdot
.58847 .25883 Mdot
.37095 .36419 Mdot
.41069 .60054 Mdot
.55316 .64558 Mdot
.42731 .55167 Mdot
.40652 .20771 Mdot
.71335 .34802 Mdot
.62128 .6306 Mdot
.44323 .60362 Mdot
.45789 .31254 Mdot
.51504 .34975 Mdot
.50057 .43252 Mdot
.51281 .29015 Mdot
.6145 .48362 Mdot
.52803 .36544 Mdot
.42838 .62783 Mdot
.59638 .48596 Mdot
.38268 .37132 Mdot
.37822 .61787 Mdot
.40496 .56808 Mdot
.59577 .60997 Mdot
.6152 .45423 Mdot
.33818 .75011 Mdot
.61104 .42496 Mdot
.59882 .45734 Mdot
.58183 .67824 Mdot
.4092 .60836 Mdot
.52105 .34082 Mdot
.4984 .31115 Mdot
.37248 .55069 Mdot
.76848 .62492 Mdot
.59141 .65318 Mdot
.51876 .26956 Mdot
.16361 .5719 Mdot
.47043 .56351 Mdot
.73394 .32194 Mdot
.40836 .49114 Mdot
.64057 .42841 Mdot
.42609 .60126 Mdot
.64305 .64459 Mdot
.54598 .35518 Mdot
.52751 .29335 Mdot
.36978 .54809 Mdot
.62713 .45328 Mdot
.3815 .41684 Mdot
.54388 .30864 Mdot
.48999 .26132 Mdot
.41564 .58605 Mdot
.77639 .48616 Mdot
.54788 .31799 Mdot
.43909 .17808 Mdot
.45587 .28553 Mdot
.60693 .63207 Mdot
.3947 .57046 Mdot
.60394 .67687 Mdot
.37423 .39136 Mdot
.55908 .36468 Mdot
.62299 .45377 Mdot
.41607 .50878 Mdot
.40157 .8183 Mdot
.52837 .31713 Mdot
.6351 .65514 Mdot
.43707 .57533 Mdot
.459 .54047 Mdot
.4082 .63463 Mdot
.5552 .58944 Mdot
.35195 .3653 Mdot
.65653 .44762 Mdot
.63163 .43506 Mdot
.36965 .58622 Mdot
.40657 .40112 Mdot
.49161 .33775 Mdot
.4996 .33859 Mdot
.87925 .44723 Mdot
.73851 .33127 Mdot
.27166 .50641 Mdot
.43648 .5958 Mdot
.55859 .33619 Mdot
.44761 .81179 Mdot
.60865 .45704 Mdot
.35748 .58997 Mdot
.55755 .35216 Mdot
.594 .35738 Mdot
.4744 .4173 Mdot
.39969 .59793 Mdot
.47964 .62001 Mdot
.63398 .43798 Mdot
.45121 .40606 Mdot
.54138 .32654 Mdot
.35896 .57878 Mdot
.60708 .42806 Mdot
.5676 .2418 Mdot
.48877 .84892 Mdot
.62715 .65424 Mdot
.50636 .29769 Mdot
.61425 .48241 Mdot
.4705 .59514 Mdot
.3698 .40351 Mdot
.52744 .36012 Mdot
.50821 .31394 Mdot
.40214 .55617 Mdot
.43329 .54873 Mdot
.46866 .55988 Mdot
.62901 .6413 Mdot
.64888 .45606 Mdot
.36697 .60973 Mdot
.71353 .60581 Mdot
.36508 .58363 Mdot
.6472 .45785 Mdot
.50573 .09644 Mdot
.43568 .55805 Mdot
.40708 .63354 Mdot
.29071 .36858 Mdot
.62227 .67494 Mdot
.58016 .6526 Mdot
.74691 .61046 Mdot
.43638 .59614 Mdot
.4876 .24286 Mdot
.62677 .65786 Mdot
.59087 .64903 Mdot
.3861 .2818 Mdot
.40352 .55067 Mdot
.46 .39331 Mdot
.64229 .46146 Mdot
.62218 .49104 Mdot
.59087 .62875 Mdot
.46887 .59318 Mdot
.60128 .46789 Mdot
.51863 .66767 Mdot
.53373 .32257 Mdot
.78192 .60677 Mdot
.61769 .62094 Mdot
.4334 .47454 Mdot
.60926 .46604 Mdot
.29572 .23132 Mdot
.55765 .54185 Mdot
.3699 .57346 Mdot
.43083 .59494 Mdot
.37459 .37568 Mdot
.40937 .66737 Mdot
.70283 .34488 Mdot
.6319 .47736 Mdot
.25785 .36044 Mdot
.62313 .64539 Mdot
.39161 .6278 Mdot
.29317 .5632 Mdot
.71215 .51061 Mdot
.79707 .46608 Mdot
.60727 .66448 Mdot
.60867 .63887 Mdot
.53679 .3136 Mdot
.52439 .30628 Mdot
.40349 .60297 Mdot
.63774 .47905 Mdot
.59197 .681 Mdot
.6429 .44406 Mdot
.52128 .31294 Mdot
.52723 .33422 Mdot
.71923 .35133 Mdot
.4124 .65257 Mdot
.49827 .34843 Mdot
.55298 .23487 Mdot
.70621 .60776 Mdot
.58835 .61159 Mdot
.32153 .77449 Mdot
.7079 .49198 Mdot
.24188 .43777 Mdot
.40807 .40748 Mdot
.71691 .31332 Mdot
.65299 .47855 Mdot
.37329 .58163 Mdot
.43299 .61254 Mdot
.7206 .33236 Mdot
.63584 .49652 Mdot
.38572 .37965 Mdot
.62829 .49814 Mdot
.39352 .40284 Mdot
.50217 .36649 Mdot
.4251 .63944 Mdot
.44623 .61627 Mdot
.61782 .4827 Mdot
.53467 .34128 Mdot
.49751 .34279 Mdot
.41167 .39623 Mdot
.32566 .51381 Mdot
.5081 .3237 Mdot
.61488 .62072 Mdot
.58669 .7603 Mdot
.71443 .32986 Mdot
.42826 .63005 Mdot
.2801 .58839 Mdot
.46118 .70093 Mdot
.37541 .55498 Mdot
.72237 .32286 Mdot
.87539 .49179 Mdot
.38217 .62644 Mdot
.85565 .53878 Mdot
.70881 .34168 Mdot
.62085 .67631 Mdot
.54822 .33807 Mdot
.70191 .34547 Mdot
.45893 .55898 Mdot
.38111 .42758 Mdot
.39604 .53139 Mdot
.62337 .67239 Mdot
.64523 .6263 Mdot
.7181 .68545 Mdot
.40749 .20837 Mdot
.40767 .37919 Mdot
.39309 .3856 Mdot
.50777 .34116 Mdot
.63841 .20214 Mdot
.43608 .54118 Mdot
.39393 .38287 Mdot
.25257 .3804 Mdot
.37795 .57412 Mdot
.27601 .52244 Mdot
.54416 .54573 Mdot
.58637 .64877 Mdot
.57301 .59642 Mdot
.51083 .34668 Mdot
.63446 .65535 Mdot
.70113 .62504 Mdot
.35874 .56114 Mdot
.62717 .64966 Mdot
.64514 .45471 Mdot
.66813 .38092 Mdot
.59963 .67232 Mdot
.44552 .43081 Mdot
.64115 .4642 Mdot
.36017 .35318 Mdot
.27914 .39963 Mdot
.23687 .74 Mdot
.63268 .47828 Mdot
.5358 .34786 Mdot
.499 .35336 Mdot
.50131 .33833 Mdot
.6274 .67194 Mdot
.54431 .29974 Mdot
.6302 .63649 Mdot
.36432 .25646 Mdot
.2965 .54687 Mdot
.39896 .39242 Mdot
.673 .47263 Mdot
.60671 .64741 Mdot
.76126 .55367 Mdot
.3441 .79497 Mdot
.42081 .59712 Mdot
.60889 .42664 Mdot
.36743 .36947 Mdot
.57043 .16318 Mdot
.37504 .37685 Mdot
.54294 .34344 Mdot
.78544 .6013 Mdot
.39831 .62701 Mdot
.31756 .69115 Mdot
.3821 .36876 Mdot
.61322 .66803 Mdot
.37424 .59807 Mdot
.50302 .29353 Mdot
.37194 .4027 Mdot
.39123 .41615 Mdot
.38733 .5992 Mdot
.59374 .66474 Mdot
.52513 .33817 Mdot
.64999 .48014 Mdot
.35445 .37232 Mdot
.47099 .62123 Mdot
.41078 .54516 Mdot
.35131 .6107 Mdot
.5179 .44839 Mdot
.21701 .45345 Mdot
.63478 .47246 Mdot
.34314 .44378 Mdot
.51848 .30893 Mdot
.35802 .34235 Mdot
.73541 .5662 Mdot
.66305 .4947 Mdot
.71207 .34741 Mdot
.71743 .34936 Mdot
.39603 .59798 Mdot
.22048 .44324 Mdot
.82342 .49405 Mdot
.62828 .5204 Mdot
.71877 .32733 Mdot
.49797 .33914 Mdot
.62688 .68815 Mdot
.7053 .69151 Mdot
.4469 .564 Mdot
.65083 .43541 Mdot
.511 .31861 Mdot
.1984 .4358 Mdot
.38999 .39863 Mdot
.77138 .5965 Mdot
.41905 .57032 Mdot
.38489 .61483 Mdot
.63147 .46412 Mdot
.64564 .46842 Mdot
.78226 .45298 Mdot
.72897 .64808 Mdot
.55657 .3942 Mdot
.69178 .46519 Mdot
.1876 .46677 Mdot
.58235 .60038 Mdot
.64284 .64033 Mdot
.73229 .34481 Mdot
.59622 .47475 Mdot
.43532 .62565 Mdot
.6309 .67662 Mdot
.79852 .46883 Mdot
.64789 .68969 Mdot
.28466 .50951 Mdot
.49092 .24848 Mdot
.40475 .57571 Mdot
.612 .61731 Mdot
.63272 .65463 Mdot
.57761 .65905 Mdot
.71561 .3246 Mdot
.41702 .62268 Mdot
.42899 .559 Mdot
.37008 .60804 Mdot
.45443 .6552 Mdot
.41251 .58709 Mdot
.72662 .57326 Mdot
.56465 .45817 Mdot
.26605 .34456 Mdot
.37391 .55873 Mdot
.61578 .48924 Mdot
.35986 .61331 Mdot
.40422 .40531 Mdot
.37867 .5659 Mdot
.27374 .51414 Mdot
.62176 .47205 Mdot
.4697 .53429 Mdot
.69088 .47583 Mdot
.41821 .56921 Mdot
.36818 .40937 Mdot
.22837 .43658 Mdot
.33505 .75635 Mdot
.58694 .26194 Mdot
.61209 .6207 Mdot
.5529 .29183 Mdot
.66235 .47295 Mdot
.51932 .33955 Mdot
.36672 .57242 Mdot
.73581 .33054 Mdot
.70101 .41627 Mdot
.44139 .47341 Mdot
.44423 .61363 Mdot
.33126 .59526 Mdot
.59286 .63379 Mdot
.5283 .35334 Mdot
.64847 .6112 Mdot
.42797 .58568 Mdot
.37537 .39864 Mdot
.38148 .40711 Mdot
.72801 .6316 Mdot
.21509 .37362 Mdot
.60074 .57114 Mdot
.63288 .46591 Mdot
.52081 .29212 Mdot
.37222 .41757 Mdot
.60439 .71502 Mdot
.65828 .4423 Mdot
.64153 .42904 Mdot
.62156 .44917 Mdot
.39897 .5806 Mdot
.70723 .34749 Mdot
.23352 .38493 Mdot
.7007 .34027 Mdot
.41439 .56793 Mdot
.51264 .30604 Mdot
.70254 .34828 Mdot
.36867 .3807 Mdot
.6138 .43794 Mdot
.52634 .30931 Mdot
.40419 .58887 Mdot
.62151 .65481 Mdot
.34944 .49548 Mdot
.23872 .52344 Mdot
.33112 .28011 Mdot
.32593 .2861 Mdot
.65044 .65202 Mdot
.2653 .28166 Mdot
.65928 .42001 Mdot
.46462 .70976 Mdot
.4073 .42912 Mdot
.36811 .55446 Mdot
.71978 .72928 Mdot
.54239 .32899 Mdot
.50921 .3561 Mdot
.40348 .59705 Mdot
.55529 .33661 Mdot
.39649 .63075 Mdot
.53343 .3059 Mdot
.56237 .25682 Mdot
.4574 .57974 Mdot
.5091 .3544 Mdot
.40655 .52456 Mdot
.42371 .56012 Mdot
.58609 .64017 Mdot
.53452 .35892 Mdot
.36448 .58137 Mdot
.64058 .19174 Mdot
.64138 .48011 Mdot
.71387 .32587 Mdot
.55728 .42063 Mdot
.60908 .47861 Mdot
.61727 .63617 Mdot
.46004 .60023 Mdot
.3953 .37472 Mdot
.61355 .65619 Mdot
.51294 .27327 Mdot
.38031 .36776 Mdot
.75416 .60453 Mdot
.60554 .62131 Mdot
.71411 .3321 Mdot
.3858 .37002 Mdot
.33498 .605 Mdot
.51193 .36344 Mdot
.23145 .56438 Mdot
.70256 .33641 Mdot
.42006 .62902 Mdot
.50884 .37391 Mdot
.61721 .49242 Mdot
.39725 .61198 Mdot
.54824 .34652 Mdot
.71643 .32348 Mdot
.39057 .5803 Mdot
.37674 .59008 Mdot
.69387 .69314 Mdot
.80342 .51203 Mdot
.39858 .38076 Mdot
.59786 .61409 Mdot
.41382 .59649 Mdot
.40982 .39396 Mdot
.65004 .25401 Mdot
.37029 .62893 Mdot
.61435 .68028 Mdot
.30598 .6464 Mdot
.52203 .30535 Mdot
.60757 .4483 Mdot
.50101 .3044 Mdot
.39748 .41526 Mdot
.6822 .80519 Mdot
.71146 .35197 Mdot
.41282 .52305 Mdot
.35424 .57859 Mdot
.51413 .38629 Mdot
.63189 .65033 Mdot
.53808 .4017 Mdot
.43498 .59889 Mdot
.34281 .64598 Mdot
.38597 .6202 Mdot
.45575 .28015 Mdot
.59288 .65433 Mdot
.41454 .63337 Mdot
.48077 .64827 Mdot
.43479 .638 Mdot
.37272 .41366 Mdot
.30145 .41843 Mdot
.36188 .62163 Mdot
.27259 .20464 Mdot
.71704 .32099 Mdot
.50007 .35023 Mdot
.57768 .31511 Mdot
.72467 .27979 Mdot
.67675 .72385 Mdot
.63034 .6392 Mdot
.31528 .60433 Mdot
.52242 .33903 Mdot
.48787 .84056 Mdot
.2947 .2508 Mdot
.42211 .56091 Mdot
.44621 .59111 Mdot
.54293 .34347 Mdot
.55753 .33876 Mdot
.73275 .33898 Mdot
.37331 .56247 Mdot
.34675 .54366 Mdot
.53694 .28606 Mdot
.41122 .58089 Mdot
.33881 .68129 Mdot
.65303 .47254 Mdot
.58234 .63871 Mdot
.61606 .43886 Mdot
.65272 .4404 Mdot
.55234 .72915 Mdot
.74118 .61121 Mdot
.6481 .4608 Mdot
.60382 .4271 Mdot
.26796 .52522 Mdot
.29949 .60322 Mdot
.38055 .41871 Mdot
.27772 .30129 Mdot
.50431 .33596 Mdot
.41616 .62131 Mdot
.64819 .65152 Mdot
.51869 .69947 Mdot
.64148 .34803 Mdot
.79682 .57588 Mdot
.43546 .58748 Mdot
.50767 .34729 Mdot
.71007 .32667 Mdot
.4552 .57437 Mdot
.34261 .34779 Mdot
.38566 .61212 Mdot
.49944 .35711 Mdot
.60966 .75314 Mdot
.30909 .66874 Mdot
.45682 .35036 Mdot
.5662 .64656 Mdot
.36993 .61671 Mdot
.62285 .62515 Mdot
.61035 .47096 Mdot
.40824 .39636 Mdot
.39414 .37789 Mdot
.37679 .5968 Mdot
.60669 .71372 Mdot
.53951 .5491 Mdot
.42605 .56252 Mdot
.40293 .55391 Mdot
.71005 .34271 Mdot
.40399 .55346 Mdot
.35532 .57579 Mdot
.36244 .60113 Mdot
.40702 .64609 Mdot
.59812 .45991 Mdot
.29696 .65785 Mdot
.37932 .63925 Mdot
.43238 .52463 Mdot
.64766 .47787 Mdot
.32132 .57251 Mdot
.64691 .43697 Mdot
.20835 .36017 Mdot
.6432 .43775 Mdot
.39693 .38174 Mdot
.51804 .37564 Mdot
.33271 .63801 Mdot
.58656 .67786 Mdot
.61932 .42663 Mdot
.38166 .39224 Mdot
.62835 .47865 Mdot
.52054 .29683 Mdot
.2715 .70993 Mdot
.64861 .68915 Mdot
.46082 .41056 Mdot
.56596 .56177 Mdot
.77754 .48211 Mdot
.53445 .31665 Mdot
.58815 .64713 Mdot
.32408 .69641 Mdot
.36417 .5976 Mdot
.37747 .37245 Mdot
.39372 .59921 Mdot
.6008 .45272 Mdot
.50448 .34352 Mdot
.32938 .2989 Mdot
.39537 .37675 Mdot
.48478 .85678 Mdot
.49849 .33045 Mdot
.44336 .56797 Mdot
.64822 .43157 Mdot
.32499 .77698 Mdot
.64055 .43541 Mdot
.29074 .55822 Mdot
.63961 .61258 Mdot
.63484 .76496 Mdot
.60338 .64057 Mdot
.80496 .44962 Mdot
.13388 .45127 Mdot
.33486 .24597 Mdot
.62162 .66333 Mdot
.47733 .28883 Mdot
.41872 .57472 Mdot
.35768 .61543 Mdot
.47777 .57476 Mdot
.58444 .61778 Mdot
.41478 .59313 Mdot
.70432 .33884 Mdot
.67878 .59042 Mdot
.37507 .32623 Mdot
.5516 .28823 Mdot
.41701 .63524 Mdot
.64938 .47441 Mdot
.62505 .49942 Mdot
.70112 .34591 Mdot
.66105 .45767 Mdot
.41975 .5545 Mdot
.6051 .64518 Mdot
.46764 .48603 Mdot
.37169 .38672 Mdot
.52195 .18002 Mdot
.36934 .35934 Mdot
.53748 .27546 Mdot
.38075 .65397 Mdot
.52809 .3338 Mdot
.79693 .69679 Mdot
.36643 .5863 Mdot
.6287 .6598 Mdot
.38225 .58704 Mdot
.36391 .60918 Mdot
.35633 .61361 Mdot
.54002 .29313 Mdot
.57148 .35859 Mdot
.40795 .5827 Mdot
.62185 .45356 Mdot
.29843 .31176 Mdot
.38142 .53387 Mdot
.48864 .28507 Mdot
.3014 .47497 Mdot
.76757 .50805 Mdot
.58266 .61495 Mdot
.53098 .35065 Mdot
.61818 .64255 Mdot
.56924 .66098 Mdot
.61745 .63614 Mdot
.23542 .37112 Mdot
.49701 .64651 Mdot
.86833 .47664 Mdot
.58463 .79398 Mdot
.49973 .71045 Mdot
.6326 .61569 Mdot
.66639 .28861 Mdot
.64296 .65228 Mdot
.6255 .63757 Mdot
.70513 .19177 Mdot
.64236 .66022 Mdot
.43949 .61262 Mdot
.42259 .54442 Mdot
.70489 .54893 Mdot
.26899 .54436 Mdot
.37864 .56248 Mdot
.40974 .59729 Mdot
.40831 .38921 Mdot
.50033 .60554 Mdot
.72108 .35666 Mdot
.76174 .61977 Mdot
.69922 .43109 Mdot
.38853 .59844 Mdot
.40914 .59435 Mdot
.46358 .62498 Mdot
.122 .47396 Mdot
.53337 .69425 Mdot
.65233 .64206 Mdot
.32975 .59383 Mdot
.44904 .18879 Mdot
.4443 .57392 Mdot
.4463 .6181 Mdot
.39478 .5756 Mdot
.52164 .34029 Mdot
.63551 .68649 Mdot
.33145 .60103 Mdot
.75537 .50314 Mdot
.42403 .57238 Mdot
.6719 .45336 Mdot
.35077 .37483 Mdot
.43041 .62569 Mdot
.57828 .65594 Mdot
.3843 .56594 Mdot
.61677 .61908 Mdot
.58759 .63209 Mdot
.45498 .64256 Mdot
.2256 .38496 Mdot
.59831 .67657 Mdot
.40882 .56887 Mdot
.53118 .3445 Mdot
.33416 .23561 Mdot
.42368 .62772 Mdot
.401 .40206 Mdot
.43286 .59592 Mdot
.37062 .41028 Mdot
.41071 .55943 Mdot
.70142 .33743 Mdot
.38948 .7212 Mdot
.51045 .33888 Mdot
.42794 .41581 Mdot
.55687 .32023 Mdot
.69511 .68188 Mdot
.6211 .67821 Mdot
.7304 .35227 Mdot
.79148 .6368 Mdot
.71034 .34108 Mdot
.35218 .49479 Mdot
.6282 .30495 Mdot
.63113 .48556 Mdot
.57767 .64019 Mdot
.36485 .45711 Mdot
.48775 .28154 Mdot
.52064 .27457 Mdot
.56275 .33302 Mdot
.71074 .7704 Mdot
.76769 .68204 Mdot
.40095 .58529 Mdot
.22133 .59709 Mdot
.46013 .77763 Mdot
.41252 .64271 Mdot
.45905 .60987 Mdot
.50104 .36052 Mdot
.37763 .62432 Mdot
.50031 .45638 Mdot
.52358 .31897 Mdot
.3864 .38891 Mdot
.62288 .63038 Mdot
.37329 .41076 Mdot
.48011 .344 Mdot
.56671 .48112 Mdot
.52131 .30993 Mdot
.38773 .63938 Mdot
.38792 .5895 Mdot
.59957 .61946 Mdot
.65578 .70137 Mdot
.58407 .63745 Mdot
.37379 .36753 Mdot
.51547 .32454 Mdot
.51944 .68688 Mdot
.42341 .60484 Mdot
.60658 .65555 Mdot
.57775 .45074 Mdot
.42166 .60058 Mdot
.61531 .47955 Mdot
.43542 .57707 Mdot
.62239 .66701 Mdot
.4048 .55364 Mdot
.60603 .64361 Mdot
.54011 .3336 Mdot
.44398 .57664 Mdot
.40474 .59866 Mdot
.37526 .79243 Mdot
.38395 .37953 Mdot
.62137 .67767 Mdot
.53811 .50139 Mdot
.43494 .55965 Mdot
.38333 .34219 Mdot
.41118 .63878 Mdot
.30834 .61548 Mdot
.39777 .52343 Mdot
.70589 .33731 Mdot
.35922 .62896 Mdot
.42203 .62896 Mdot
.30396 .67683 Mdot
.50518 .8103 Mdot
.65765 .61882 Mdot
.60755 .43776 Mdot
.57831 .65433 Mdot
.51426 .36693 Mdot
.54517 .35874 Mdot
.54599 .30749 Mdot
.27667 .55515 Mdot
.46732 .60483 Mdot
.40075 .62765 Mdot
.62649 .42296 Mdot
.39389 .38844 Mdot
.60878 .66352 Mdot
.39518 .39323 Mdot
.75915 .62473 Mdot
.37205 .36952 Mdot
.7037 .34654 Mdot
.45604 .28678 Mdot
.47382 .68608 Mdot
.40732 .38481 Mdot
.58333 .63836 Mdot
.48175 .26021 Mdot
.36465 .56053 Mdot
.57745 .26767 Mdot
.37623 .39994 Mdot
.65935 .81486 Mdot
.41837 .63863 Mdot
.47321 .43278 Mdot
.65476 .45574 Mdot
.36506 .39563 Mdot
.61271 .45687 Mdot
.37177 .5778 Mdot
.74858 .44864 Mdot
.63608 .65745 Mdot
.59354 .47305 Mdot
.35906 .62704 Mdot
.3708 .407 Mdot
.50757 .32011 Mdot
.59504 .54927 Mdot
.61788 .48939 Mdot
.30033 .70521 Mdot
.31166 .3734 Mdot
.51748 .32321 Mdot
.83674 .47063 Mdot
.62312 .44363 Mdot
.39584 .64041 Mdot
.35602 .66914 Mdot
.38501 .5537 Mdot
.53 .36798 Mdot
.52446 .35464 Mdot
.68496 .57809 Mdot
.38537 .58682 Mdot
.4161 .63878 Mdot
.65465 .67252 Mdot
.52905 .3204 Mdot
.59675 .63622 Mdot
.57409 .65324 Mdot
.53849 .34515 Mdot
.60485 .63246 Mdot
.37924 .36946 Mdot
.64718 .56455 Mdot
.6249 .44291 Mdot
.62008 .45824 Mdot
.49853 .33926 Mdot
.49918 .31443 Mdot
.52928 .33158 Mdot
.43499 .57681 Mdot
.60235 .66462 Mdot
.39499 .56672 Mdot
.36424 .62575 Mdot
.61334 .60114 Mdot
.64004 .66996 Mdot
.38653 .5709 Mdot
.44984 .36348 Mdot
.35073 .39322 Mdot
.50995 .35355 Mdot
.64487 .44621 Mdot
.49168 .83825 Mdot
.6405 .4256 Mdot
.4132 .63654 Mdot
.59675 .342 Mdot
.61792 .67051 Mdot
.37373 .37698 Mdot
.3821 .34686 Mdot
.38227 .37301 Mdot
.61332 .51126 Mdot
.58257 .6707 Mdot
.75287 .6034 Mdot
.40305 .63419 Mdot
.51846 .45055 Mdot
.35272 .452 Mdot
.74073 .55647 Mdot
.64714 .45593 Mdot
.4162 .59847 Mdot
.7107 .33903 Mdot
.42528 .70231 Mdot
.38843 .61438 Mdot
.36012 .58483 Mdot
.43342 .25868 Mdot
.43493 .52564 Mdot
.59501 .60866 Mdot
.72095 .68041 Mdot
.40224 .53968 Mdot
.54353 .6275 Mdot
.82451 .33921 Mdot
.39703 .63412 Mdot
.42171 .58513 Mdot
.42619 .61792 Mdot
.37736 .57861 Mdot
.62218 .60531 Mdot
.39983 .45787 Mdot
.64449 .4293 Mdot
.53872 .45281 Mdot
.63083 .44576 Mdot
.51404 .36206 Mdot
.47378 .43731 Mdot
.57905 .63932 Mdot
.37763 .37382 Mdot
.2505 .66018 Mdot
.74515 .65199 Mdot
.53693 .31459 Mdot
.56181 .71237 Mdot
.37204 .39152 Mdot
.37039 .55272 Mdot
.39563 .36009 Mdot
.55813 .33995 Mdot
.63387 .45387 Mdot
.42201 .54487 Mdot
.6446 .63471 Mdot
.6003 .67315 Mdot
.41931 .59599 Mdot
.40517 .20316 Mdot
.60824 .47181 Mdot
.57282 .43282 Mdot
.40083 .579 Mdot
.36057 .58357 Mdot
.6032 .62743 Mdot
.51883 .3519 Mdot
.61888 .2573 Mdot
.38225 .38466 Mdot
.44133 .6455 Mdot
.37766 .57242 Mdot
.74906 .63268 Mdot
.61327 .43693 Mdot
.73167 .33028 Mdot
.39524 .58172 Mdot
.74044 .61656 Mdot
.39317 .58161 Mdot
.40678 .66888 Mdot
.53012 .33851 Mdot
.36464 .54936 Mdot
.44294 .58916 Mdot
.42554 .49131 Mdot
.61733 .44656 Mdot
.62977 .65437 Mdot
.6606 .64533 Mdot
.73021 .32413 Mdot
.61748 .48012 Mdot
.38506 .56965 Mdot
.60434 .45022 Mdot
.35712 .6165 Mdot
.40872 .58493 Mdot
.64668 .45572 Mdot
.59714 .63572 Mdot
.63197 .39751 Mdot
.28973 .59988 Mdot
.37903 .58183 Mdot
.41053 .5445 Mdot
.27604 .5445 Mdot
.82331 .58096 Mdot
.44057 .59546 Mdot
.61911 .67319 Mdot
.41721 .60246 Mdot
.61316 .46723 Mdot
.3678 .37134 Mdot
.62321 .65969 Mdot
.49551 .32709 Mdot
.54193 .33412 Mdot
.68763 .487 Mdot
.70644 .34945 Mdot
.41973 .54812 Mdot
.6684 .62854 Mdot
.64638 .66194 Mdot
.69612 .23061 Mdot
.50143 .35463 Mdot
.36636 .40995 Mdot
.37448 .58955 Mdot
.58395 .54608 Mdot
.6272 .42477 Mdot
.26989 .20653 Mdot
.74847 .59354 Mdot
.41198 .36742 Mdot
.79778 .591 Mdot
.71525 .33547 Mdot
.44701 .60835 Mdot
.40751 .40154 Mdot
.54568 .32245 Mdot
.35713 .60543 Mdot
.47564 .58735 Mdot
.53663 .40424 Mdot
.56832 .33016 Mdot
.60527 .45027 Mdot
.53343 .30182 Mdot
.41615 .39136 Mdot
.70326 .34579 Mdot
.58559 .65734 Mdot
.41456 .63161 Mdot
.36233 .6666 Mdot
.50126 .3477 Mdot
.70136 .33584 Mdot
.4047 .57523 Mdot
.59516 .67065 Mdot
.55483 .32933 Mdot
.38463 .60041 Mdot
.47685 .70489 Mdot
.56217 .64241 Mdot
.50874 .32714 Mdot
.3538 .58499 Mdot
.31925 .64721 Mdot
.49589 .33271 Mdot
.49649 .34554 Mdot
.41426 .59325 Mdot
.38215 .36987 Mdot
.44998 .59564 Mdot
.65249 .44481 Mdot
.57196 .35799 Mdot
.61543 .46797 Mdot
.3301 .41333 Mdot
.38692 .655 Mdot
.78674 .48276 Mdot
.59983 .61642 Mdot
.40753 .41731 Mdot
.38471 .77483 Mdot
.36332 .57328 Mdot
.24821 .31635 Mdot
.43184 .47247 Mdot
.54331 .16927 Mdot
.15649 .50852 Mdot
.38272 .40087 Mdot
.62499 .4792 Mdot
.42163 .58584 Mdot
.63774 .41677 Mdot
.40578 .38938 Mdot
.33973 .43636 Mdot
.35455 .58239 Mdot
.59179 .65117 Mdot
.41931 .57237 Mdot
.61367 .62051 Mdot
.42429 .60058 Mdot
.39552 .51852 Mdot
.39098 .43549 Mdot
.28895 .5625 Mdot
.36712 .55716 Mdot
.26694 .70756 Mdot
.56863 .53241 Mdot
.3757 .39488 Mdot
.40112 .5681 Mdot
.72578 .33675 Mdot
.64073 .49551 Mdot
.21198 .48862 Mdot
.52452 .33696 Mdot
.65017 .46324 Mdot
.61251 .62808 Mdot
.49166 .32365 Mdot
.71981 .32166 Mdot
.368 .67194 Mdot
.38 .41479 Mdot
.63065 .48446 Mdot
.42546 .62817 Mdot
.42236 .63685 Mdot
.45401 .33481 Mdot
.77021 .37766 Mdot
.63621 .68921 Mdot
.44192 .83888 Mdot
.60712 .60448 Mdot
.39073 .38136 Mdot
.5303 .3363 Mdot
.44282 .60475 Mdot
.39174 .6091 Mdot
.53691 .36359 Mdot
.62464 .67563 Mdot
.57066 .31431 Mdot
.5629 .72568 Mdot
.52512 .2853 Mdot
.32425 .48337 Mdot
.62706 .6639 Mdot
.32554 .48674 Mdot
.41651 .39403 Mdot
.20778 .4032 Mdot
.25235 .46994 Mdot
.65542 .45751 Mdot
.32444 .47886 Mdot
.61483 .66721 Mdot
.39518 .5883 Mdot
.71644 .33145 Mdot
.71801 .35088 Mdot
.61752 .62587 Mdot
.54293 .3452 Mdot
.36884 .4014 Mdot
.4195 .5837 Mdot
.77372 .55823 Mdot
.69576 .52104 Mdot
.51998 .29194 Mdot
.459 .66313 Mdot
.61602 .45445 Mdot
.43731 .58341 Mdot
.39725 .40567 Mdot
.63795 .47405 Mdot
.73484 .3177 Mdot
.66812 .57949 Mdot
.37232 .59269 Mdot
.72412 .64175 Mdot
.62127 .48287 Mdot
.84236 .473 Mdot
.40013 .60296 Mdot
.62274 .44372 Mdot
.3853 .51474 Mdot
.74034 .46674 Mdot
.50698 .49453 Mdot
.29975 .25401 Mdot
.56643 .33152 Mdot
.54368 .33568 Mdot
.7142 .39204 Mdot
.40209 .43142 Mdot
.64217 .48201 Mdot
.70246 .34478 Mdot
.28062 .42622 Mdot
.61397 .45339 Mdot
.44982 .61415 Mdot
.40939 .6384 Mdot
.54416 .72324 Mdot
.51354 .47599 Mdot
.70006 .33599 Mdot
.61074 .57923 Mdot
.40034 .54891 Mdot
.35443 .55517 Mdot
.40139 .61178 Mdot
.64634 .62797 Mdot
.60861 .47981 Mdot
.29245 .75875 Mdot
.60661 .4655 Mdot
.77888 .56507 Mdot
.5042 .33675 Mdot
.51816 .29098 Mdot
.42909 .62779 Mdot
.80728 .48089 Mdot
.20646 .48048 Mdot
.43172 .56103 Mdot
.35518 .3535 Mdot
.31051 .38648 Mdot
.35962 .54301 Mdot
.65741 .62977 Mdot
.36825 .66675 Mdot
.57754 .60689 Mdot
.64238 .46939 Mdot
.38614 .40295 Mdot
.35153 .39479 Mdot
.63483 .48147 Mdot
.40244 .62714 Mdot
.33754 .38322 Mdot
.38579 .61801 Mdot
.39747 .58422 Mdot
.7726 .60506 Mdot
.36471 .41186 Mdot
.53155 .32876 Mdot
.39419 .37719 Mdot
.62648 .63925 Mdot
.57697 .10845 Mdot
.39667 .39755 Mdot
.68013 .67026 Mdot
.4365 .41821 Mdot
.32697 .48011 Mdot
.59439 .66885 Mdot
.39992 .37021 Mdot
.60545 .45416 Mdot
.53582 .16511 Mdot
.83863 .52649 Mdot
.64235 .42444 Mdot
.39522 .60399 Mdot
.58143 .63272 Mdot
.65026 .64274 Mdot
.60825 .42552 Mdot
.58662 .65226 Mdot
.34692 .62053 Mdot
.38553 .58392 Mdot
.64184 .48221 Mdot
.69622 .54764 Mdot
.61224 .48749 Mdot
.65462 .58117 Mdot
.40247 .5712 Mdot
.6259 .65993 Mdot
.36725 .65176 Mdot
.65648 .67515 Mdot
.72861 .3474 Mdot
.35603 .60364 Mdot
.3653 .38222 Mdot
.5127 .46511 Mdot
.50792 .3299 Mdot
.59289 .35832 Mdot
.5959 .62284 Mdot
.59595 .41194 Mdot
.58579 .64009 Mdot
.58444 .62312 Mdot
.66052 .44976 Mdot
.63484 .64703 Mdot
.42153 .58429 Mdot
.45513 .35493 Mdot
.62981 .62376 Mdot
.62751 .46558 Mdot
.36671 .39235 Mdot
.60175 .63354 Mdot
.48628 .34503 Mdot
.3857 .59356 Mdot
.52703 .3059 Mdot
.41986 .37629 Mdot
.57741 .6436 Mdot
.39496 .36784 Mdot
.50142 .35197 Mdot
.38832 .41511 Mdot
.34026 .2818 Mdot
.59777 .4769 Mdot
.79738 .56825 Mdot
.29596 .62851 Mdot
.64439 .63546 Mdot
.51826 .27418 Mdot
.44155 .6007 Mdot
.38171 .59229 Mdot
.41464 .39172 Mdot
.65034 .64578 Mdot
.34858 .23059 Mdot
.31466 .62341 Mdot
.65304 .56342 Mdot
.59617 .46527 Mdot
.49821 .8484 Mdot
.70998 .603 Mdot
.54971 .19506 Mdot
.42251 .53331 Mdot
.71565 .3349 Mdot
.38945 .62423 Mdot
.33991 .76298 Mdot
.36277 .37705 Mdot
.6614 .32971 Mdot
.43714 .5423 Mdot
.5232 .32896 Mdot
.41733 .60879 Mdot
.22386 .58103 Mdot
.37065 .66661 Mdot
.40849 .38284 Mdot
.6362 .51646 Mdot
.58769 .67876 Mdot
.37194 .38785 Mdot
.54091 .3278 Mdot
.29766 .44268 Mdot
.35284 .58057 Mdot
.41381 .54994 Mdot
.5405 .28366 Mdot
.58989 .65117 Mdot
.51433 .36325 Mdot
.62511 .44311 Mdot
.3932 .39689 Mdot
.37412 .58257 Mdot
.35025 .56646 Mdot
.51709 .39102 Mdot
.6068 .4777 Mdot
.50271 .3062 Mdot
.6177 .43698 Mdot
.71525 .33411 Mdot
.38875 .54382 Mdot
.5432 .28739 Mdot
.41353 .6408 Mdot
.38417 .78281 Mdot
.77691 .60598 Mdot
.50838 .79948 Mdot
.53275 .32611 Mdot
.29965 .49216 Mdot
.61966 .47372 Mdot
.63376 .43407 Mdot
.60868 .78542 Mdot
.22555 .43842 Mdot
.48963 .24404 Mdot
.25891 .67755 Mdot
.62616 .44293 Mdot
.61824 .46673 Mdot
.5475 .3222 Mdot
.63408 .63975 Mdot
.55647 .63683 Mdot
.513 .29198 Mdot
.28366 .57967 Mdot
.60877 .66336 Mdot
.25964 .29966 Mdot
.49973 .36132 Mdot
.4308 .53649 Mdot
.70249 .3573 Mdot
.38466 .40595 Mdot
.28432 .58044 Mdot
.24314 .61688 Mdot
.44365 .61131 Mdot
.70713 .71532 Mdot
.52196 .34865 Mdot
.47283 .39934 Mdot
.2062 .37407 Mdot
.35564 .59034 Mdot
.41583 .61597 Mdot
.40374 .62417 Mdot
.35993 .40817 Mdot
.37099 .76705 Mdot
.44396 .61257 Mdot
.3064 .53078 Mdot
.45682 .59759 Mdot
.23046 .51884 Mdot
.39536 .37843 Mdot
.54447 .60104 Mdot
.56258 .31308 Mdot
.75073 .52496 Mdot
.47368 .5656 Mdot
.6177 .44155 Mdot
.47136 .32202 Mdot
.63695 .45325 Mdot
.21277 .4377 Mdot
.25462 .46731 Mdot
.63781 .61742 Mdot
.43557 .58677 Mdot
.56122 .34241 Mdot
.59032 .62473 Mdot
.62544 .29015 Mdot
.67987 .16902 Mdot
.60161 .46491 Mdot
.82815 .62426 Mdot
.63323 .43358 Mdot
.72573 .34858 Mdot
.60709 .6258 Mdot
.52411 .64657 Mdot
.51697 .4512 Mdot
.60237 .63486 Mdot
.69124 .40877 Mdot
.65105 .61878 Mdot
.31087 .48367 Mdot
.57053 .65759 Mdot
.62599 .46943 Mdot
.61382 .50484 Mdot
.45496 .54882 Mdot
.43901 .59935 Mdot
.54776 .45104 Mdot
.35355 .52264 Mdot
.43773 .59411 Mdot
.52362 .31914 Mdot
.82862 .52335 Mdot
.50308 .37661 Mdot
.641 .63884 Mdot
.61451 .43342 Mdot
.41634 .61418 Mdot
.38276 .57987 Mdot
.38576 .63491 Mdot
.37657 .79579 Mdot
.26435 .29618 Mdot
.40613 .58457 Mdot
.43396 .65042 Mdot
.53896 .32973 Mdot
.35216 .4223 Mdot
.28709 .70923 Mdot
.27513 .43928 Mdot
.37455 .60659 Mdot
.38436 .37723 Mdot
.3567 .39309 Mdot
.37818 .53902 Mdot
.77138 .52584 Mdot
.47079 .30138 Mdot
.42562 .62789 Mdot
.24084 .48016 Mdot
.49085 .36417 Mdot
.69945 .3435 Mdot
.50096 .34699 Mdot
.57653 .65434 Mdot
.71072 .34696 Mdot
.55292 .31209 Mdot
.51808 .64681 Mdot
.7326 .32461 Mdot
.73904 .48141 Mdot
.3738 .36749 Mdot
.39714 .61254 Mdot
.66158 .63328 Mdot
.53693 .36497 Mdot
.63365 .48359 Mdot
.614 .64807 Mdot
.62679 .50029 Mdot
.36895 .43729 Mdot
.37343 .47657 Mdot
.70987 .35119 Mdot
.62417 .43925 Mdot
.66911 .58083 Mdot
.38696 .37654 Mdot
.65954 .44999 Mdot
.80344 .47098 Mdot
.40946 .53337 Mdot
.18929 .50484 Mdot
.43048 .56624 Mdot
.45455 .18402 Mdot
.63513 .4317 Mdot
.73712 .33089 Mdot
.40282 .62992 Mdot
.49806 .33079 Mdot
.36774 .52166 Mdot
.38357 .61085 Mdot
.50962 .30249 Mdot
.3999 .58621 Mdot
.39872 .40587 Mdot
.56596 .62131 Mdot
.44321 .47964 Mdot
.57975 .8353 Mdot
.38753 .4141 Mdot
.71186 .36587 Mdot
.43935 .59268 Mdot
.32342 .31298 Mdot
.6003 .63658 Mdot
.35754 .58889 Mdot
.6473 .7551 Mdot
.63125 .63126 Mdot
.61469 .64091 Mdot
.40018 .55715 Mdot
.65797 .45778 Mdot
.50108 .32951 Mdot
.3864 .37548 Mdot
.59466 .19033 Mdot
.38204 .60393 Mdot
.41106 .6008 Mdot
.37165 .39067 Mdot
.61667 .46752 Mdot
.3815 .5777 Mdot
.62129 .32961 Mdot
.6114 .18159 Mdot
.65197 .43875 Mdot
.38109 .53368 Mdot
.19756 .57616 Mdot
.60266 .69729 Mdot
.82771 .59906 Mdot
.43738 .39212 Mdot
.53292 .34783 Mdot
.38481 .52245 Mdot
.31724 .17558 Mdot
.38306 .40453 Mdot
.74707 .55395 Mdot
.40952 .57926 Mdot
.4271 .60925 Mdot
.60359 .67167 Mdot
.39058 .56664 Mdot
.63283 .66797 Mdot
.60447 .83214 Mdot
.46059 .86574 Mdot
.58994 .63615 Mdot
.64492 .64558 Mdot
.55445 .60467 Mdot
.31488 .72674 Mdot
.61916 .62959 Mdot
.35151 .59514 Mdot
.30267 .29263 Mdot
.45478 .64461 Mdot
.41369 .40374 Mdot
.40613 .35373 Mdot
.54124 .64015 Mdot
.81866 .41669 Mdot
.32174 .59215 Mdot
.46015 .53516 Mdot
.54315 .55871 Mdot
.64591 .4415 Mdot
.3686 .60533 Mdot
.70576 .34951 Mdot
.54295 .30235 Mdot
.40872 .67258 Mdot
.39452 .61507 Mdot
.61909 .61986 Mdot
.36298 .4135 Mdot
.65855 .4795 Mdot
.409 .59725 Mdot
.57062 .3399 Mdot
.38484 .38678 Mdot
.63571 .62848 Mdot
.6865 .67948 Mdot
.39178 .41925 Mdot
.34278 .61151 Mdot
.43333 .59943 Mdot
.4034 .57581 Mdot
.4536 .53767 Mdot
.64081 .47897 Mdot
.48418 .35372 Mdot
.34849 .61101 Mdot
.75653 .62043 Mdot
.472 .42196 Mdot
.35197 .56797 Mdot
.60809 .66863 Mdot
.6399 .42621 Mdot
.73264 .33262 Mdot
.31466 .4392 Mdot
.37294 .59667 Mdot
.26373 .29975 Mdot
.5414 .70477 Mdot
.7147 .34653 Mdot
.60674 .61166 Mdot
.37709 .3748 Mdot
.40837 .55058 Mdot
.27196 .32694 Mdot
.41348 .63783 Mdot
.30109 .61453 Mdot
.52707 .34885 Mdot
.64233 .44115 Mdot
.58746 .16913 Mdot
.54162 .30085 Mdot
.61714 .64198 Mdot
.30611 .23458 Mdot
.63599 .68187 Mdot
.60434 .68588 Mdot
.22512 .39404 Mdot
.64559 .46501 Mdot
.29804 .1898 Mdot
.83415 .55444 Mdot
.43911 .63207 Mdot
.61091 .46656 Mdot
.60312 .62471 Mdot
.43501 .58176 Mdot
.64647 .65818 Mdot
.61143 .68525 Mdot
.35975 .61075 Mdot
.43204 .60479 Mdot
.30207 .54482 Mdot
.22599 .33229 Mdot
.38723 .37186 Mdot
.62051 .67616 Mdot
.50755 .71963 Mdot
.44551 .60926 Mdot
.40412 .6344 Mdot
.46944 .37288 Mdot
.4083 .38305 Mdot
.34063 .6946 Mdot
.39583 .58253 Mdot
.65767 .75875 Mdot
.41304 .54461 Mdot
.66522 .64601 Mdot
.65525 .44195 Mdot
.76757 .53158 Mdot
.5232 .36899 Mdot
.60932 .67973 Mdot
.36867 .40655 Mdot
.65836 .65172 Mdot
.62089 .76596 Mdot
.64385 .46205 Mdot
.62237 .66704 Mdot
.49069 .3489 Mdot
.63487 .4593 Mdot
.65303 .44214 Mdot
.29857 .31066 Mdot
.50541 .30163 Mdot
.37768 .3641 Mdot
.62987 .45023 Mdot
.46509 .71113 Mdot
.6292 .47147 Mdot
.52341 .72106 Mdot
.44113 .57514 Mdot
.31563 .51945 Mdot
.7178 .594 Mdot
.48144 .59152 Mdot
.61525 .49129 Mdot
.4032 .38285 Mdot
.38812 .55877 Mdot
.58836 .65551 Mdot
.39566 .39948 Mdot
.65716 .51679 Mdot
.49271 .33303 Mdot
.61015 .61523 Mdot
.65076 .43492 Mdot
.62686 .66931 Mdot
.36144 .46474 Mdot
.58485 .35063 Mdot
.54547 .56799 Mdot
.51008 .44136 Mdot
.40241 .64173 Mdot
.53739 .64436 Mdot
.42578 .54984 Mdot
.39121 .61538 Mdot
.50796 .32781 Mdot
.27796 .55352 Mdot
.59729 .63469 Mdot
.6008 .17071 Mdot
.63108 .43794 Mdot
.6999 .69989 Mdot
.32292 .64826 Mdot
.36148 .58901 Mdot
.62962 .6248 Mdot
.62149 .68804 Mdot
.50711 .80945 Mdot
.53483 .36324 Mdot
.48077 .61785 Mdot
.39726 .65898 Mdot
.43155 .53267 Mdot
.63305 .43097 Mdot
.63 .34918 Mdot
.53702 .35405 Mdot
.87734 .49319 Mdot
.51162 .35335 Mdot
.4006 .27959 Mdot
.63558 .64722 Mdot
.36346 .37853 Mdot
.40987 .63531 Mdot
.30195 .56426 Mdot
.63791 .61374 Mdot
.45789 .37911 Mdot
.36873 .37979 Mdot
.65432 .37938 Mdot
.64811 .46435 Mdot
.36953 .54973 Mdot
.36317 .61176 Mdot
.39889 .56546 Mdot
.42768 .56902 Mdot
.60754 .43906 Mdot
.44883 .61551 Mdot
.59472 .47466 Mdot
.47393 .70001 Mdot
.65381 .76392 Mdot
.5458 .36518 Mdot
.21649 .46802 Mdot
.63955 .62652 Mdot
.46814 .72312 Mdot
.34431 .68097 Mdot
.78053 .5996 Mdot
.32699 .29547 Mdot
.42704 .55288 Mdot
.54707 .34111 Mdot
.22189 .58988 Mdot
.55988 .34489 Mdot
.57206 .89279 Mdot
.33454 .39677 Mdot
.2895 .25539 Mdot
.43411 .58292 Mdot
.50433 .38573 Mdot
.32947 .66731 Mdot
.37937 .53659 Mdot
.3396 .41412 Mdot
.68678 .64771 Mdot
.71488 .54579 Mdot
.36974 .41423 Mdot
.38464 .59577 Mdot
.59137 .68176 Mdot
.42254 .58281 Mdot
.39459 .63022 Mdot
.43819 .58202 Mdot
.66521 .4595 Mdot
.4508 .56495 Mdot
.45026 .60025 Mdot
.77704 .37591 Mdot
.27954 .51691 Mdot
.52644 .30269 Mdot
.55501 .80252 Mdot
.39359 .38886 Mdot
.60824 .61939 Mdot
.42437 .46151 Mdot
.65374 .45505 Mdot
.49232 .81557 Mdot
.43335 .57556 Mdot
.70764 .58822 Mdot
.65033 .43394 Mdot
.39248 .4021 Mdot
.72649 .32425 Mdot
.31309 .26215 Mdot
.54733 .36302 Mdot
.73449 .32609 Mdot
.50783 .3316 Mdot
.38964 .76698 Mdot
.6212 .62071 Mdot
.37935 .63251 Mdot
.62074 .45026 Mdot
.50238 .3241 Mdot
.26644 .55548 Mdot
.40432 .6152 Mdot
.53301 .32248 Mdot
.39591 .64014 Mdot
.45498 .41619 Mdot
.46424 .30852 Mdot
.55809 .32163 Mdot
.62211 .5095 Mdot
.62923 .4575 Mdot
.37788 .36945 Mdot
.60728 .61849 Mdot
.61565 .67098 Mdot
.63822 .47146 Mdot
.80853 .63235 Mdot
.38109 .61064 Mdot
.43898 .58628 Mdot
.75387 .61698 Mdot
.42685 .58918 Mdot
.30411 .46009 Mdot
.71315 .35636 Mdot
.62136 .61696 Mdot
.42998 .5788 Mdot
.37967 .57902 Mdot
.37307 .59082 Mdot
.36224 .46774 Mdot
.50284 .34935 Mdot
.40116 .54909 Mdot
.40955 .40147 Mdot
.78463 .45025 Mdot
.44486 .59764 Mdot
.36357 .54496 Mdot
.61877 .66659 Mdot
.51365 .85609 Mdot
.65479 .45106 Mdot
.52909 .31487 Mdot
.49455 .3456 Mdot
.43041 .37017 Mdot
.57697 .61916 Mdot
.71928 .35756 Mdot
.69742 .25754 Mdot
.70864 .33069 Mdot
.37488 .38898 Mdot
.43955 .24312 Mdot
.5709 .3276 Mdot
.53703 .31101 Mdot
.60114 .49055 Mdot
.42809 .57297 Mdot
.42929 .55748 Mdot
.74978 .55465 Mdot
.37682 .55946 Mdot
.36601 .38502 Mdot
.63722 .48766 Mdot
.61505 .66372 Mdot
.38392 .40738 Mdot
.61541 .43991 Mdot
.59064 .65371 Mdot
.40881 .53401 Mdot
.41939 .53719 Mdot
.6122 .64416 Mdot
.58575 .63226 Mdot
.43587 .61602 Mdot
.75481 .37561 Mdot
.57225 .64481 Mdot
.62448 .66569 Mdot
.69822 .33192 Mdot
.5509 .36027 Mdot
.3542 .64394 Mdot
.61021 .46699 Mdot
.4029 .57691 Mdot
.55807 .35313 Mdot
.40667 .37908 Mdot
.59787 .64443 Mdot
.38091 .58235 Mdot
.39712 .59176 Mdot
.38234 .37673 Mdot
.37985 .42148 Mdot
.37361 .40614 Mdot
.64826 .41787 Mdot
.41611 .56399 Mdot
.61718 .63039 Mdot
.64683 .46104 Mdot
.35675 .39337 Mdot
.38359 .3589 Mdot
.7984 .38525 Mdot
.44137 .61577 Mdot
.51404 .50434 Mdot
.5408 .10548 Mdot
.28999 .44191 Mdot
.7316 .33955 Mdot
.53364 .28275 Mdot
.31641 .50598 Mdot
.43816 .34698 Mdot
.61096 .47907 Mdot
.26397 .39815 Mdot
.40794 .4166 Mdot
.36204 .62193 Mdot
.40587 .5439 Mdot
.44955 .63961 Mdot
.38684 .39149 Mdot
.34871 .45639 Mdot
.65117 .65398 Mdot
.44539 .75809 Mdot
.3935 .38911 Mdot
.55805 .32231 Mdot
.54658 .2925 Mdot
.51268 .35362 Mdot
.39196 .54093 Mdot
.49574 .80908 Mdot
.48546 .71478 Mdot
.37343 .73565 Mdot
.64937 .46511 Mdot
.63375 .68771 Mdot
.33131 .29904 Mdot
.61226 .64004 Mdot
.54623 .30432 Mdot
.38301 .39131 Mdot
.61333 .67504 Mdot
.62045 .48636 Mdot
.61742 .46427 Mdot
.49372 .33238 Mdot
.49992 .34048 Mdot
.51632 .31114 Mdot
.58227 .66589 Mdot
.63499 .64683 Mdot
.3689 .59004 Mdot
.60358 .64867 Mdot
.71784 .70583 Mdot
.40477 .35896 Mdot
.55318 .30204 Mdot
.61889 .47882 Mdot
.60725 .62131 Mdot
.39665 .60975 Mdot
.4605 .25797 Mdot
.69208 .43798 Mdot
.39514 .41212 Mdot
.53914 .24548 Mdot
.63257 .86004 Mdot
.36866 .61803 Mdot
.60803 .44434 Mdot
.77647 .50944 Mdot
.40753 .62205 Mdot
.52342 .34143 Mdot
.3521 .77067 Mdot
.70526 .33152 Mdot
.44941 .59978 Mdot
.36686 .57534 Mdot
.66128 .45671 Mdot
.42479 .43115 Mdot
.3701 .57723 Mdot
.70592 .63146 Mdot
.64526 .49651 Mdot
.54698 .34832 Mdot
.63309 .18629 Mdot
.51875 .28048 Mdot
.27322 .60028 Mdot
.72589 .34625 Mdot
.36218 .60826 Mdot
.52047 .31878 Mdot
.40066 .40881 Mdot
.51468 .31724 Mdot
.61704 .61038 Mdot
.52257 .30539 Mdot
.41397 .60239 Mdot
.62015 .63207 Mdot
.61922 .48253 Mdot
.72229 .67628 Mdot
.78196 .38983 Mdot
.49776 .33096 Mdot
.70577 .3205 Mdot
.44795 .6049 Mdot
.38836 .69885 Mdot
.36597 .52253 Mdot
.44226 .59293 Mdot
.63842 .45362 Mdot
.63259 .62728 Mdot
.59859 .45466 Mdot
.3395 .57877 Mdot
.59804 .8038 Mdot
.63804 .43425 Mdot
.73381 .50779 Mdot
.37266 .39087 Mdot
.28969 .56788 Mdot
.38786 .60848 Mdot
.62553 .44801 Mdot
.41474 .56455 Mdot
.63725 .67483 Mdot
.55025 .50075 Mdot
.7937 .45756 Mdot
.62 .45166 Mdot
.38747 .19994 Mdot
.54608 .50977 Mdot
.36078 .65882 Mdot
.6269 .44494 Mdot
.43768 .7992 Mdot
.72912 .33486 Mdot
.38073 .38485 Mdot
.35971 .40295 Mdot
.38506 .41614 Mdot
.37515 .55865 Mdot
.43592 .67628 Mdot
.37909 .36131 Mdot
.65325 .49073 Mdot
.41009 .38912 Mdot
.31055 .5393 Mdot
.37557 .20887 Mdot
.3785 .41068 Mdot
.3931 .60158 Mdot
.36613 .54092 Mdot
.27695 .52135 Mdot
.55586 .32931 Mdot
.24422 .32154 Mdot
.60418 .71661 Mdot
.44092 .60571 Mdot
.35284 .66362 Mdot
.62993 .61605 Mdot
.80042 .50684 Mdot
.33513 .65537 Mdot
.45592 .3353 Mdot
.64171 .65755 Mdot
.54709 .27483 Mdot
.61579 .61699 Mdot
.37913 .62815 Mdot
.41019 .58415 Mdot
.56656 .61442 Mdot
.59868 .34859 Mdot
.73812 .43973 Mdot
.50783 .18416 Mdot
.62058 .6732 Mdot
.61742 .44672 Mdot
.601 .45925 Mdot
.64828 .45573 Mdot
.51703 .36782 Mdot
.5783 .64956 Mdot
.4165 .55875 Mdot
.54 .33829 Mdot
.37638 .61032 Mdot
.63377 .45519 Mdot
.58217 .1674 Mdot
.61775 .66557 Mdot
.42219 .62924 Mdot
.83776 .52733 Mdot
.50946 .34518 Mdot
.38877 .37803 Mdot
.46398 .40642 Mdot
.48396 .34397 Mdot
.61342 .48954 Mdot
.56791 .66258 Mdot
.67023 .45171 Mdot
.4164 .47023 Mdot
.46425 .62799 Mdot
.35619 .56441 Mdot
.63015 .19965 Mdot
.82614 .4468 Mdot
.38078 .54922 Mdot
.54105 .32683 Mdot
.55465 .34714 Mdot
.38116 .58654 Mdot
.58424 .65665 Mdot
.35836 .37984 Mdot
.40539 .41086 Mdot
.36173 .63028 Mdot
.51949 .44866 Mdot
.30887 .53211 Mdot
.38545 .57245 Mdot
.48343 .62516 Mdot
.49158 .32978 Mdot
.7243 .32248 Mdot
.74104 .60726 Mdot
.36185 .3957 Mdot
.40704 .57932 Mdot
.72378 .46546 Mdot
.63603 .66573 Mdot
.52138 .30725 Mdot
.63246 .48696 Mdot
.3725 .45402 Mdot
.49607 .356 Mdot
.38203 .58586 Mdot
.38116 .57801 Mdot
.66079 .45373 Mdot
.66504 .64565 Mdot
.38437 .39296 Mdot
.53858 .33849 Mdot
.36057 .38385 Mdot
.62929 .64242 Mdot
.61637 .66124 Mdot
.44789 .65271 Mdot
.44758 .53386 Mdot
.49528 .33853 Mdot
.3957 .64673 Mdot
.54952 .3047 Mdot
.42406 .42479 Mdot
.62294 .42717 Mdot
.35464 .59786 Mdot
.60135 .69082 Mdot
.63795 .45803 Mdot
.43023 .6131 Mdot
.71582 .25147 Mdot
.3605 .59518 Mdot
.48382 .35037 Mdot
.60621 .80036 Mdot
.40575 .38265 Mdot
.67404 .69927 Mdot
.48465 .54672 Mdot
.42541 .59045 Mdot
.54474 .29529 Mdot
.35817 .53124 Mdot
.64797 .43861 Mdot
.64085 .6468 Mdot
.791 .70129 Mdot
.62993 .46739 Mdot
.42028 .58128 Mdot
.39346 .39832 Mdot
.61556 .68991 Mdot
.70578 .34257 Mdot
.74686 .60003 Mdot
.39864 .67226 Mdot
.42911 .53907 Mdot
.4273 .57517 Mdot
.26553 .69567 Mdot
.52522 .31466 Mdot
.60506 .62289 Mdot
.62879 .43053 Mdot
.63445 .47728 Mdot
.52006 .35228 Mdot
.70151 .56735 Mdot
.59312 .32805 Mdot
.45192 .09257 Mdot
.51001 .30425 Mdot
.41134 .38379 Mdot
.49035 .43856 Mdot
.53784 .29738 Mdot
.52454 .32352 Mdot
.49284 .34374 Mdot
.72689 .5793 Mdot
.59783 .6622 Mdot
.39707 .59082 Mdot
.58228 .61543 Mdot
.36 .60474 Mdot
.26329 .62672 Mdot
.64015 .47132 Mdot
.63991 .64826 Mdot
.67511 .22241 Mdot
.34973 .52639 Mdot
.41154 .61685 Mdot
.36258 .25412 Mdot
.33345 .58952 Mdot
.32613 .46533 Mdot
.34488 .62243 Mdot
.50246 .33541 Mdot
.39861 .68213 Mdot
.39846 .52155 Mdot
.71745 .70096 Mdot
.6152 .47675 Mdot
.7233 .35132 Mdot
.4409 .55946 Mdot
.40787 .66857 Mdot
.61131 .68875 Mdot
.61388 .67531 Mdot
.37706 .36237 Mdot
.50208 .41702 Mdot
.61737 .48116 Mdot
.57196 .39472 Mdot
.43761 .59911 Mdot
.61776 .52064 Mdot
.61351 .77947 Mdot
.42985 .6152 Mdot
.29066 .30821 Mdot
.49722 .81408 Mdot
.36806 .57999 Mdot
.41805 .76703 Mdot
.61938 .46953 Mdot
.65527 .75775 Mdot
.4282 .6465 Mdot
.52222 .34074 Mdot
.63639 .64185 Mdot
.62152 .61339 Mdot
.38662 .41148 Mdot
.76976 .65984 Mdot
.60529 .48794 Mdot
.63717 .6474 Mdot
.40221 .62107 Mdot
.63818 .48172 Mdot
.71094 .35015 Mdot
.37616 .53272 Mdot
.25435 .38733 Mdot
.60593 .65262 Mdot
.42901 .65259 Mdot
.63564 .54579 Mdot
.45251 .42724 Mdot
.20074 .35601 Mdot
.64645 .44994 Mdot
.36596 .40117 Mdot
.35026 .63451 Mdot
.69188 .25371 Mdot
.45833 .61512 Mdot
.28911 .54961 Mdot
.56942 .68297 Mdot
.36732 .37184 Mdot
.41186 .62633 Mdot
.37344 .57402 Mdot
.50819 .45327 Mdot
.3729 .41887 Mdot
.35794 .59639 Mdot
.45869 .64452 Mdot
.59098 .6522 Mdot
.71626 .35541 Mdot
.60905 .65894 Mdot
.39605 .60399 Mdot
.41745 .68391 Mdot
.5934 .66396 Mdot
.48324 .21656 Mdot
.38801 .42633 Mdot
.65342 .45027 Mdot
.47274 .64791 Mdot
.44154 .57772 Mdot
.17926 .60266 Mdot
.72855 .34732 Mdot
.32692 .75717 Mdot
.50813 .29547 Mdot
.69841 .41802 Mdot
.55556 .38005 Mdot
.30644 .24511 Mdot
.72448 .65441 Mdot
.45138 .64287 Mdot
.23904 .45681 Mdot
.39933 .75348 Mdot
.59935 .47503 Mdot
.42855 .70937 Mdot
.43918 .59933 Mdot
.39046 .62666 Mdot
.54918 .32839 Mdot
.69319 .57878 Mdot
.77228 .51315 Mdot
.53398 .45074 Mdot
.38221 .39704 Mdot
.63142 .6505 Mdot
.42134 .59948 Mdot
.59606 .27204 Mdot
.52028 .30264 Mdot
.58789 .54399 Mdot
.41344 .63117 Mdot
.78157 .55597 Mdot
.73222 .53829 Mdot
.64023 .48087 Mdot
.53485 .28478 Mdot
.48449 .34293 Mdot
.38946 .63154 Mdot
.62123 .48978 Mdot
.36787 .58784 Mdot
.56978 .52594 Mdot
.41278 .65128 Mdot
.3945 .40475 Mdot
.43612 .62954 Mdot
.49554 .47008 Mdot
.25128 .27852 Mdot
.33538 .63312 Mdot
.58017 .62956 Mdot
.5139 .36637 Mdot
.50801 .35124 Mdot
.61823 .67199 Mdot
.51118 .35145 Mdot
.45654 .76557 Mdot
.59848 .75097 Mdot
.37839 .39926 Mdot
.39612 .69188 Mdot
.39827 .40158 Mdot
.72469 .35087 Mdot
.44166 .61219 Mdot
.71297 .2739 Mdot
.50492 .31048 Mdot
.42482 .81884 Mdot
.6301 .47373 Mdot
.72682 .34847 Mdot
.45759 .60405 Mdot
.43369 .246 Mdot
.55164 .31638 Mdot
.48507 .31519 Mdot
.37229 .59141 Mdot
.61007 .67164 Mdot
.37478 .57319 Mdot
.37093 .64367 Mdot
.73429 .32678 Mdot
.42698 .573 Mdot
.61504 .44039 Mdot
.57857 .6548 Mdot
.32727 .24392 Mdot
.5342 .36641 Mdot
.427 .63354 Mdot
.40331 .62187 Mdot
.6406 .67404 Mdot
.4558 .60286 Mdot
.61273 .48473 Mdot
.19441 .27194 Mdot
.37324 .38948 Mdot
.71666 .32202 Mdot
.48011 .34288 Mdot
.42125 .55125 Mdot
.38252 .57076 Mdot
.61849 .19394 Mdot
.76303 .42212 Mdot
.61744 .44022 Mdot
.35199 .62409 Mdot
.5382 .32931 Mdot
.39243 .40078 Mdot
.6522 .48669 Mdot
.40002 .57582 Mdot
.40167 .6321 Mdot
.39256 .4055 Mdot
.31087 .2894 Mdot
.46984 .30064 Mdot
.64984 .46106 Mdot
.38657 .68295 Mdot
.46519 .26379 Mdot
.38217 .61076 Mdot
.53005 .2148 Mdot
.62359 .66426 Mdot
.63258 .44428 Mdot
.33592 .73119 Mdot
.3787 .63276 Mdot
.60866 .48093 Mdot
.61752 .48026 Mdot
.43215 .63722 Mdot
.57601 .62098 Mdot
.59285 .67638 Mdot
.62937 .66589 Mdot
.60705 .80702 Mdot
.24367 .55518 Mdot
.5151 .31158 Mdot
.61814 .46874 Mdot
.56054 .3356 Mdot
.35595 .38462 Mdot
.47449 .42308 Mdot
.55868 .33693 Mdot
.62712 .61523 Mdot
.54797 .29343 Mdot
.37219 .58197 Mdot
.61623 .48216 Mdot
.53702 .31008 Mdot
.4087 .546 Mdot
.48845 .5945 Mdot
.53436 .51847 Mdot
.36094 .37543 Mdot
.44996 .38603 Mdot
.411 .59024 Mdot
.73317 .32976 Mdot
.43392 .62031 Mdot
.64332 .48103 Mdot
.47598 .45912 Mdot
.40708 .54708 Mdot
.49614 .33369 Mdot
.46688 .50569 Mdot
.55053 .34598 Mdot
.38777 .65445 Mdot
.39703 .60255 Mdot
.38263 .61489 Mdot
.36985 .5771 Mdot
.72786 .52604 Mdot
.59566 .46388 Mdot
.4913 .62469 Mdot
.56168 .35595 Mdot
.60506 .6399 Mdot
.6545 .65106 Mdot
.49301 .24679 Mdot
.72828 .32087 Mdot
.6117 .46901 Mdot
.38126 .60859 Mdot
.48621 .31112 Mdot
.57237 .16594 Mdot
.52155 .20532 Mdot
.3363 .30446 Mdot
.54038 .32012 Mdot
.58133 .62926 Mdot
.53497 .30119 Mdot
.38259 .62486 Mdot
.34247 .58531 Mdot
.31226 .24788 Mdot
.59407 .43934 Mdot
.38415 .39111 Mdot
.37772 .6146 Mdot
.27356 .60787 Mdot
.53896 .32985 Mdot
.49225 .32575 Mdot
.36368 .60156 Mdot
.60448 .67959 Mdot
.15446 .40147 Mdot
.63466 .48646 Mdot
.39613 .70197 Mdot
.64165 .70946 Mdot
.68536 .63657 Mdot
.63371 .48133 Mdot
.54271 .54313 Mdot
.52319 .35838 Mdot
.64773 .72566 Mdot
.60769 .64322 Mdot
.387 .38811 Mdot
.34581 .58388 Mdot
.62176 .61404 Mdot
.52838 .28124 Mdot
.63453 .62416 Mdot
.37317 .62679 Mdot
.59721 .46787 Mdot
.5233 .35417 Mdot
.61431 .51125 Mdot
.56752 .61283 Mdot
.404 .39559 Mdot
.29003 .5712 Mdot
.42419 .70481 Mdot
.49534 .81458 Mdot
.40186 .54913 Mdot
.49071 .28161 Mdot
.4131 .56273 Mdot
.60949 .68728 Mdot
.38846 .60713 Mdot
.53872 .63518 Mdot
.51806 .29141 Mdot
.42911 .65216 Mdot
.45043 .6064 Mdot
.50458 .67426 Mdot
.41921 .61919 Mdot
.45349 .6131 Mdot
.37142 .571 Mdot
.63213 .71217 Mdot
.4488 .64906 Mdot
.60248 .6674 Mdot
.74292 .56134 Mdot
.52236 .32445 Mdot
.36879 .36285 Mdot
.39772 .41597 Mdot
.29497 .54281 Mdot
.28746 .57138 Mdot
.70489 .57087 Mdot
.60414 .66056 Mdot
.60713 .45355 Mdot
.36759 .58893 Mdot
.32969 .72011 Mdot
.41834 .41024 Mdot
.5228 .3573 Mdot
.51184 .36983 Mdot
.43389 .52467 Mdot
.2575 .68886 Mdot
.43338 .65301 Mdot
.75243 .60026 Mdot
.37223 .6364 Mdot
.35743 .59022 Mdot
.49182 .35494 Mdot
.36414 .48465 Mdot
.40148 .54897 Mdot
.61171 .68888 Mdot
.38823 .38392 Mdot
.32666 .62608 Mdot
.34648 .35324 Mdot
.56276 .53955 Mdot
.53108 .667 Mdot
.42338 .56281 Mdot
.53511 .34376 Mdot
.60805 .61573 Mdot
.74989 .62569 Mdot
.64582 .45824 Mdot
.72129 .60429 Mdot
.49337 .69713 Mdot
.44182 .22093 Mdot
.3851 .387 Mdot
.30449 .30045 Mdot
.41417 .60192 Mdot
.50871 .36529 Mdot
.36548 .61811 Mdot
.56429 .16563 Mdot
.39816 .36989 Mdot
.63571 .61145 Mdot
.61567 .44766 Mdot
.63737 .67336 Mdot
.51513 .79892 Mdot
.53429 .57284 Mdot
.69381 .3695 Mdot
.55126 .35854 Mdot
.29275 .67182 Mdot
.62038 .62688 Mdot
.38887 .57997 Mdot
.48216 .09388 Mdot
.62441 .66298 Mdot
.62363 .67561 Mdot
.43808 .40732 Mdot
.331 .41666 Mdot
.36043 .53163 Mdot
.64049 .63056 Mdot
.56261 .32428 Mdot
.39225 .37477 Mdot
.38952 .55491 Mdot
.37316 .57083 Mdot
.60608 .67247 Mdot
.55021 .31067 Mdot
.28411 .67066 Mdot
.50089 .33838 Mdot
.58858 .64669 Mdot
.51052 .33951 Mdot
.47723 .35756 Mdot
.53448 .31362 Mdot
.44892 .58777 Mdot
.3821 .60576 Mdot
.35509 .32625 Mdot
.61621 .66109 Mdot
.38729 .56425 Mdot
.4046 .58328 Mdot
.61732 .62854 Mdot
.56973 .32525 Mdot
.31524 .71027 Mdot
.43487 .58689 Mdot
.38926 .59547 Mdot
.36315 .37785 Mdot
.57188 .29846 Mdot
.5859 .24717 Mdot
.38902 .55823 Mdot
.4105 .4036 Mdot
.5799 .6638 Mdot
.43383 .61881 Mdot
.31982 .52714 Mdot
.50671 .37436 Mdot
.42773 .63649 Mdot
.70484 .3432 Mdot
.4259 .55428 Mdot
.16211 .3919 Mdot
.43637 .62577 Mdot
.60265 .62597 Mdot
.6332 .63388 Mdot
.46069 .3896 Mdot
.62015 .64419 Mdot
.72165 .34974 Mdot
.63333 .45654 Mdot
.47787 .18572 Mdot
.71415 .34976 Mdot
.3587 .58204 Mdot
.83406 .55492 Mdot
.40033 .64641 Mdot
.43678 .5565 Mdot
.32136 .73492 Mdot
.71611 .34904 Mdot
.626 .62412 Mdot
.59928 .3544 Mdot
.35718 .6263 Mdot
.63069 .48847 Mdot
.36913 .54175 Mdot
.43732 .63112 Mdot
.69436 .6316 Mdot
.55804 .81833 Mdot
.64849 .47709 Mdot
.34393 .63059 Mdot
.38977 .55815 Mdot
.81018 .42922 Mdot
.40191 .61404 Mdot
.38113 .41136 Mdot
.62789 .6715 Mdot
.52506 .29611 Mdot
.37425 .38171 Mdot
.43218 .59259 Mdot
.38971 .39086 Mdot
.51992 .30914 Mdot
.63684 .45039 Mdot
.42096 .63619 Mdot
.41195 .40721 Mdot
.38355 .396 Mdot
.40533 .56317 Mdot
.63851 .64587 Mdot
.32625 .56238 Mdot
.43339 .61746 Mdot
.38686 .58267 Mdot
.61557 .6709 Mdot
.85486 .42837 Mdot
.37932 .62564 Mdot
.51932 .50911 Mdot
.6251 .60792 Mdot
.6989 .35012 Mdot
.53814 .30597 Mdot
.41803 .64223 Mdot
.64187 .4725 Mdot
.64096 .46488 Mdot
.54701 .28359 Mdot
.63437 .67865 Mdot
.5549 .32644 Mdot
.33262 .61386 Mdot
.45495 .54131 Mdot
.34806 .61249 Mdot
.78086 .70916 Mdot
.30221 .26814 Mdot
.58004 .64898 Mdot
.534 .35592 Mdot
.53585 .44882 Mdot
.61374 .46525 Mdot
.54999 .29307 Mdot
.58738 .68262 Mdot
.58416 .63084 Mdot
.63778 .62457 Mdot
.36336 .38146 Mdot
.50486 .35896 Mdot
.66194 .63702 Mdot
.61174 .68108 Mdot
.37192 .58794 Mdot
.3902 .55897 Mdot
.54553 .63282 Mdot
.28755 .49966 Mdot
.4024 .39978 Mdot
.52863 .34591 Mdot
.15998 .59988 Mdot
.64452 .47979 Mdot
.50733 .67263 Mdot
.41673 .54904 Mdot
.67263 .15646 Mdot
.42235 .6582 Mdot
.40159 .61896 Mdot
.57661 .65543 Mdot
.41377 .38188 Mdot
.39924 .38749 Mdot
.62256 .62776 Mdot
.5559 .63404 Mdot
.37209 .40847 Mdot
.31997 .30822 Mdot
.39211 .19361 Mdot
.73976 .62554 Mdot
.60599 .62735 Mdot
.42771 .70143 Mdot
.61487 .48951 Mdot
.57713 .60818 Mdot
.65438 .46658 Mdot
.52469 .32495 Mdot
.49684 .3524 Mdot
.66029 .45553 Mdot
.37278 .59432 Mdot
.52651 .30721 Mdot
.40727 .67437 Mdot
.34538 .24989 Mdot
.19461 .45997 Mdot
.74432 .40138 Mdot
.41585 .5458 Mdot
.76978 .52715 Mdot
.76886 .47967 Mdot
.41868 .59021 Mdot
.31331 .56492 Mdot
.38597 .39042 Mdot
.59041 .60374 Mdot
.61524 .4861 Mdot
.19417 .3689 Mdot
.38182 .6099 Mdot
.59592 .63526 Mdot
.61323 .47443 Mdot
.50407 .39619 Mdot
.70112 .62512 Mdot
.36291 .60686 Mdot
.36754 .13708 Mdot
.60743 .60046 Mdot
.52453 .296 Mdot
.80416 .60617 Mdot
.58741 .61106 Mdot
.44436 .38647 Mdot
.49131 .32193 Mdot
.53055 .19176 Mdot
.60582 .62005 Mdot
.54701 .27962 Mdot
.62716 .64278 Mdot
.39421 .40746 Mdot
.56599 .64949 Mdot
.52808 .35259 Mdot
.41628 .62436 Mdot
.51782 .35055 Mdot
.40242 .40171 Mdot
.51349 .36818 Mdot
.61597 .48799 Mdot
.72972 .34121 Mdot
.62186 .46006 Mdot
.46537 .41894 Mdot
.5758 .81294 Mdot
.64284 .44153 Mdot
.56021 .38696 Mdot
.38424 .54764 Mdot
.66535 .65073 Mdot
.51636 .29756 Mdot
.56364 .34382 Mdot
.49191 .42739 Mdot
.607 .63463 Mdot
.52499 .35122 Mdot
.48264 .70267 Mdot
.86763 .51415 Mdot
.45029 .66686 Mdot
.23808 .5195 Mdot
.61414 .62796 Mdot
.50987 .29704 Mdot
.75273 .61546 Mdot
.64549 .63045 Mdot
.50961 .30536 Mdot
.62369 .44591 Mdot
.63422 .47875 Mdot
.37064 .60629 Mdot
.58915 .4758 Mdot
.53737 .28941 Mdot
.73478 .45035 Mdot
.63377 .67098 Mdot
.50422 .39719 Mdot
.38384 .41372 Mdot
.52831 .32028 Mdot
.41104 .52251 Mdot
.553 .63703 Mdot
.54195 .36916 Mdot
.23109 .42808 Mdot
.18035 .63312 Mdot
.52321 .35039 Mdot
.62904 .67135 Mdot
.59619 .64396 Mdot
.33698 .56205 Mdot
.51507 .44732 Mdot
.55344 .32912 Mdot
.71901 .28789 Mdot
.28262 .55829 Mdot
.71463 .33422 Mdot
.83287 .44967 Mdot
.40352 .5484 Mdot
.41404 .56625 Mdot
.6118 .46197 Mdot
.41359 .61066 Mdot
.60128 .67985 Mdot
.44338 .56804 Mdot
.60522 .47353 Mdot
.52689 .35628 Mdot
.43036 .62918 Mdot
.40168 .38042 Mdot
.62285 .49564 Mdot
.66078 .46487 Mdot
.51345 .3284 Mdot
.63998 .6286 Mdot
.57778 .26795 Mdot
.50024 .34164 Mdot
.42331 .56136 Mdot
.71761 .34444 Mdot
.38756 .63583 Mdot
.28686 .35059 Mdot
.65 .65856 Mdot
.53305 .29925 Mdot
.60536 .61233 Mdot
.62443 .46357 Mdot
.56033 .30413 Mdot
.40269 .60884 Mdot
.50596 .31164 Mdot
.39982 .33552 Mdot
.30567 .32529 Mdot
.6294 .68254 Mdot
.36054 .35208 Mdot
.62314 .67754 Mdot
.71317 .33441 Mdot
.28671 .39256 Mdot
.37806 .38988 Mdot
.53539 .32667 Mdot
.29072 .27622 Mdot
.49671 .32566 Mdot
.42118 .61778 Mdot
.42972 .60587 Mdot
.54849 .32575 Mdot
.38785 .36948 Mdot
.51789 .85347 Mdot
.53185 .5398 Mdot
.62548 .62168 Mdot
.63758 .72092 Mdot
.13439 .53266 Mdot
.63871 .50231 Mdot
.61051 .45482 Mdot
.40574 .66301 Mdot
.36136 .59051 Mdot
.66065 .47355 Mdot
.61626 .43254 Mdot
.36081 .37872 Mdot
.49819 .35046 Mdot
.67181 .65624 Mdot
.63797 .4971 Mdot
.45578 .5117 Mdot
.27687 .60012 Mdot
.33819 .56435 Mdot
.47494 .61383 Mdot
.40275 .53969 Mdot
.44764 .4256 Mdot
.61189 .43827 Mdot
.40832 .59031 Mdot
.44172 .6557 Mdot
.62727 .44183 Mdot
.39539 .40599 Mdot
.62971 .58873 Mdot
.51637 .3411 Mdot
.82511 .33705 Mdot
.42823 .63471 Mdot
.4228 .62322 Mdot
.64921 .46562 Mdot
.82085 .41826 Mdot
.58429 .63825 Mdot
.64815 .64998 Mdot
.52514 .31351 Mdot
.49274 .42502 Mdot
.45072 .58495 Mdot
.41561 .5903 Mdot
.531 .33173 Mdot
.73086 .33803 Mdot
.71915 .39528 Mdot
.39731 .59276 Mdot
.61973 .47753 Mdot
.46963 .3306 Mdot
.61198 .4374 Mdot
.36668 .61682 Mdot
.42249 .61552 Mdot
.45005 .58957 Mdot
.36102 .58853 Mdot
.65718 .47301 Mdot
.41224 .59424 Mdot
.41922 .52259 Mdot
.6426 .64146 Mdot
.43138 .56995 Mdot
.30761 .5256 Mdot
.38887 .59898 Mdot
.40312 .38482 Mdot
.58452 .26085 Mdot
.38021 .61432 Mdot
.43091 .57105 Mdot
.53129 .53437 Mdot
.40721 .62723 Mdot
.64707 .476 Mdot
.60226 .64262 Mdot
.61777 .46805 Mdot
.63341 .4306 Mdot
.56211 .33835 Mdot
.36205 .37583 Mdot
.4611 .60926 Mdot
.39089 .4154 Mdot
.46612 .575 Mdot
.37053 .6253 Mdot
.53211 .26569 Mdot
.75157 .59759 Mdot
.44539 .34605 Mdot
.39963 .60733 Mdot
.52383 .3183 Mdot
.52526 .29785 Mdot
.23568 .44654 Mdot
.36699 .66594 Mdot
.65709 .47915 Mdot
.62499 .44811 Mdot
.29892 .4564 Mdot
.70099 .64211 Mdot
.40372 .393 Mdot
.55039 .4544 Mdot
.39736 .54155 Mdot
.39508 .5872 Mdot
.36582 .54282 Mdot
.55902 .33772 Mdot
.73262 .32415 Mdot
.51892 .35856 Mdot
.69197 .3518 Mdot
.60569 .44385 Mdot
.43033 .55836 Mdot
.19901 .43402 Mdot
.59872 .67094 Mdot
.6027 .6435 Mdot
.65756 .4854 Mdot
.55358 .34001 Mdot
.34501 .54578 Mdot
.79348 .70339 Mdot
.6014 .59687 Mdot
.39762 .36098 Mdot
.41766 .58697 Mdot
.51628 .32421 Mdot
.60129 .67471 Mdot
.39806 .42009 Mdot
.44001 .58365 Mdot
.56412 .35385 Mdot
.38736 .6048 Mdot
.39329 .75524 Mdot
.63933 .63685 Mdot
.57079 .16258 Mdot
.63631 .68136 Mdot
.61901 .49525 Mdot
.63246 .43691 Mdot
.4287 .61383 Mdot
.79326 .66981 Mdot
.63183 .60813 Mdot
.60686 .50544 Mdot
.40656 .37315 Mdot
.7179 .3223 Mdot
.38553 .36362 Mdot
.53947 .29695 Mdot
.38597 .38477 Mdot
.49451 .34515 Mdot
.29315 .46996 Mdot
.63112 .6017 Mdot
.37345 .38568 Mdot
.79733 .39577 Mdot
.45858 .57596 Mdot
.35731 .39507 Mdot
.43441 .5266 Mdot
.65072 .71759 Mdot
.52769 .33319 Mdot
.39032 .3706 Mdot
.38634 .57948 Mdot
.19002 .39128 Mdot
.63368 .43406 Mdot
.65492 .48112 Mdot
.46573 .58972 Mdot
.49118 .34061 Mdot
.55768 .63538 Mdot
.42954 .46403 Mdot
.70178 .35467 Mdot
.41373 .59162 Mdot
.42953 .5571 Mdot
.65426 .66122 Mdot
.62884 .68984 Mdot
.42449 .61337 Mdot
.45223 .70977 Mdot
.41594 .60039 Mdot
.63799 .47891 Mdot
.58452 .63289 Mdot
.59853 .64483 Mdot
.53728 .28697 Mdot
.62847 .67974 Mdot
.47478 .62314 Mdot
.61571 .41322 Mdot
.34623 .61418 Mdot
.6297 .46461 Mdot
.48364 .46543 Mdot
.52399 .36854 Mdot
.21927 .3468 Mdot
.65141 .66758 Mdot
.42864 .57278 Mdot
.62788 .67727 Mdot
.37212 .40352 Mdot
.61386 .65887 Mdot
.58045 .62487 Mdot
.4358 .60262 Mdot
.3624 .60823 Mdot
.72076 .34722 Mdot
.51454 .44319 Mdot
.63826 .65665 Mdot
.41932 .59622 Mdot
.41136 .64859 Mdot
.44672 .62612 Mdot
.52447 .48567 Mdot
.57827 .63963 Mdot
.54718 .72664 Mdot
.24125 .39282 Mdot
.6383 .65097 Mdot
.15187 .4309 Mdot
.70446 .33704 Mdot
.72376 .32084 Mdot
.6241 .50359 Mdot
.39523 .5918 Mdot
.5455 .3479 Mdot
.38559 .6272 Mdot
.41713 .67274 Mdot
.3986 .63162 Mdot
.40786 .37999 Mdot
.46175 .61465 Mdot
.72109 .32963 Mdot
.5018 .34499 Mdot
.43607 .5835 Mdot
.42563 .63264 Mdot
.73296 .32114 Mdot
.64793 .67375 Mdot
.59134 .62456 Mdot
.5236 .21289 Mdot
.37815 .40323 Mdot
.64106 .45499 Mdot
.37332 .60236 Mdot
.52478 .31648 Mdot
.51435 .35033 Mdot
.63428 .67483 Mdot
.52161 .34317 Mdot
.63736 .48537 Mdot
.40553 .61238 Mdot
.65725 .47711 Mdot
.40818 .38394 Mdot
.6263 .67158 Mdot
.37303 .60433 Mdot
.37227 .58815 Mdot
.63314 .63361 Mdot
.38442 .54734 Mdot
.36286 .37849 Mdot
.49673 .34143 Mdot
.59673 .62289 Mdot
.63581 .4581 Mdot
.54207 .29018 Mdot
.37684 .57975 Mdot
.20638 .66355 Mdot
.41512 .60796 Mdot
.3839 .5875 Mdot
.35011 .21934 Mdot
.40045 .66079 Mdot
.52199 .29115 Mdot
.65339 .64278 Mdot
.42306 .53977 Mdot
.26444 .60108 Mdot
.642 .2155 Mdot
.55317 .29633 Mdot
.42378 .58212 Mdot
.23476 .32682 Mdot
.43026 .58168 Mdot
.57046 .39919 Mdot
.48286 .2706 Mdot
.23612 .6031 Mdot
.47524 .60597 Mdot
.65709 .46074 Mdot
.72202 .34763 Mdot
.50324 .30736 Mdot
.44917 .79732 Mdot
.43053 .5975 Mdot
.43055 .79811 Mdot
.44851 .61594 Mdot
.6325 .4811 Mdot
.36626 .51298 Mdot
.5269 .34584 Mdot
.74703 .67907 Mdot
.41761 .55972 Mdot
.57905 .63905 Mdot
.55396 .30307 Mdot
.71069 .32624 Mdot
.38173 .58215 Mdot
.40021 .41212 Mdot
.57416 .46918 Mdot
.47485 .5757 Mdot
.63238 .46379 Mdot
.40451 .58175 Mdot
.34965 .64218 Mdot
.78244 .66424 Mdot
.63857 .6335 Mdot
.61314 .45175 Mdot
.79923 .49377 Mdot
.37711 .55037 Mdot
.60318 .62042 Mdot
.60734 .64183 Mdot
.39415 .41026 Mdot
.57604 .50002 Mdot
.6741 .51766 Mdot
.18626 .50274 Mdot
.54597 .80532 Mdot
.53071 .28412 Mdot
.75132 .4481 Mdot
.39374 .55441 Mdot
.54433 .57298 Mdot
.65208 .46844 Mdot
.41988 .62477 Mdot
.58414 .79574 Mdot
.62781 .66634 Mdot
.3968 .59624 Mdot
.39706 .40342 Mdot
.57052 .47689 Mdot
.57417 .54788 Mdot
.17635 .58026 Mdot
.55849 .30859 Mdot
.34701 .57466 Mdot
.47231 .58587 Mdot
.69825 .3441 Mdot
.36239 .61902 Mdot
.5101 .30029 Mdot
.34956 .2579 Mdot
.39032 .36924 Mdot
.6118 .6781 Mdot
.70466 .33584 Mdot
.41515 .54122 Mdot
.4307 .64353 Mdot
.37044 .36175 Mdot
.40168 .57227 Mdot
.77308 .64999 Mdot
.68341 .36413 Mdot
.53121 .30814 Mdot
.6305 .62026 Mdot
.3897 .5411 Mdot
.73255 .32465 Mdot
.43362 .60356 Mdot
.52184 .63416 Mdot
.41804 .57073 Mdot
.63724 .55044 Mdot
.63588 .64222 Mdot
.62984 .46087 Mdot
.46266 .57405 Mdot
.39239 .62533 Mdot
.46216 .26162 Mdot
.41753 .67253 Mdot
.43437 .62823 Mdot
.61216 .68943 Mdot
.58735 .65988 Mdot
.60488 .66785 Mdot
.52236 .30466 Mdot
.74067 .61579 Mdot
.62441 .47403 Mdot
.45589 .58994 Mdot
.63861 .49672 Mdot
.50511 .58491 Mdot
.38193 .35833 Mdot
.16269 .45401 Mdot
.43617 .57665 Mdot
.6029 .66381 Mdot
.72013 .48177 Mdot
.58164 .66581 Mdot
.55826 .36595 Mdot
.61731 .48146 Mdot
.6266 .66283 Mdot
.39652 .62251 Mdot
.52711 .45465 Mdot
.1953 .59786 Mdot
.61602 .46118 Mdot
.35653 .5536 Mdot
.56071 .31163 Mdot
.51641 .37213 Mdot
.12041 .48051 Mdot
.62056 .43737 Mdot
.76889 .4735 Mdot
.42256 .59345 Mdot
.59924 .67048 Mdot
.64788 .4487 Mdot
.65523 .44714 Mdot
.52751 .33665 Mdot
.36556 .60983 Mdot
.38524 .61605 Mdot
.70463 .34187 Mdot
.62845 .44928 Mdot
.44689 .55914 Mdot
.36557 .62926 Mdot
.31426 .24481 Mdot
.6451 .59785 Mdot
.84132 .3935 Mdot
.33296 .61495 Mdot
.54424 .80992 Mdot
.47738 .4418 Mdot
.57944 .65282 Mdot
.37361 .61263 Mdot
.39233 .5368 Mdot
.5322 .28713 Mdot
.40965 .60957 Mdot
.54195 .35654 Mdot
.60848 .45699 Mdot
.15721 .46929 Mdot
.66162 .41046 Mdot
.32842 .2972 Mdot
.4141 .61584 Mdot
.67778 .61306 Mdot
.36888 .38459 Mdot
.65578 .42495 Mdot
.58691 .6427 Mdot
.37011 .55077 Mdot
.48481 .34984 Mdot
.53643 .32694 Mdot
.61501 .64762 Mdot
.75618 .50554 Mdot
.51037 .22444 Mdot
.35601 .60256 Mdot
.54092 .30643 Mdot
.67417 .40122 Mdot
.44586 .71701 Mdot
.59606 .43839 Mdot
.39355 .3694 Mdot
.52627 .3559 Mdot
.66176 .45161 Mdot
.55599 .60455 Mdot
.62486 .65331 Mdot
.65178 .63112 Mdot
.41796 .31336 Mdot
.55217 .33641 Mdot
.37955 .37578 Mdot
.71923 .63876 Mdot
.71856 .66368 Mdot
.40558 .37678 Mdot
.52842 .35631 Mdot
.59291 .66744 Mdot
.59152 .63825 Mdot
.60158 .64168 Mdot
.74068 .68413 Mdot
.64797 .66019 Mdot
.56086 .71328 Mdot
.40772 .64721 Mdot
.38184 .69676 Mdot
.42861 .58206 Mdot
.65391 .47456 Mdot
.63814 .6356 Mdot
.48897 .43398 Mdot
.3651 .56957 Mdot
.1795 .57688 Mdot
.41286 .58917 Mdot
.60899 .42169 Mdot
.39238 .59305 Mdot
.46638 .6872 Mdot
.6225 .6068 Mdot
.40149 .60617 Mdot
.60631 .43214 Mdot
.38656 .39695 Mdot
.66084 .68354 Mdot
.38094 .61493 Mdot
.67915 .58135 Mdot
.42945 .65869 Mdot
.35182 .24964 Mdot
.39773 .4581 Mdot
.40503 .36647 Mdot
.45434 .64816 Mdot
.53456 .28104 Mdot
.62989 .70446 Mdot
.36349 .68772 Mdot
.61695 .46006 Mdot
.41606 .80903 Mdot
.53486 .32271 Mdot
.36269 .51478 Mdot
.35594 .62788 Mdot
.36021 .38924 Mdot
.59684 .69545 Mdot
.65035 .46779 Mdot
.41782 .54797 Mdot
.4363 .63489 Mdot
.31079 .34715 Mdot
.38324 .69179 Mdot
.45663 .61295 Mdot
.36003 .37371 Mdot
.55714 .73253 Mdot
.38187 .59693 Mdot
.5692 .32723 Mdot
.63784 .61772 Mdot
.46667 .607 Mdot
.54229 .72153 Mdot
.42121 .59672 Mdot
.62123 .6588 Mdot
.65606 .65924 Mdot
.70046 .53873 Mdot
.40957 .37329 Mdot
.41763 .5708 Mdot
.3948 .44635 Mdot
.41777 .56336 Mdot
.62509 .47766 Mdot
.37942 .62647 Mdot
.52875 .32584 Mdot
.75617 .61036 Mdot
.51189 .3098 Mdot
.38026 .6248 Mdot
.59996 .63669 Mdot
.65334 .45699 Mdot
.3708 .32116 Mdot
.48649 .26076 Mdot
.5627 .7171 Mdot
.69056 .23251 Mdot
.37472 .37232 Mdot
.363 .41051 Mdot
.59844 .48205 Mdot
.3973 .60449 Mdot
.44104 .41095 Mdot
.4036 .65347 Mdot
.38812 .59462 Mdot
.40068 .63316 Mdot
.59006 .48281 Mdot
.61489 .46987 Mdot
.51269 .34506 Mdot
.4228 .61309 Mdot
.41758 .59654 Mdot
.63447 .65334 Mdot
.38444 .39776 Mdot
.5161 .30414 Mdot
.37344 .3975 Mdot
.50485 .32908 Mdot
.16055 .3961 Mdot
.33805 .58176 Mdot
.38819 .39801 Mdot
.59602 .47787 Mdot
.61516 .67156 Mdot
.73172 .344 Mdot
.54091 .29597 Mdot
.52778 .34766 Mdot
.41547 .59185 Mdot
.62004 .66893 Mdot
.63797 .66574 Mdot
.36589 .39524 Mdot
.64 .44719 Mdot
.38019 .62403 Mdot
.35915 .60898 Mdot
.21543 .49439 Mdot
.55704 .31881 Mdot
.47578 .71378 Mdot
.71051 .54539 Mdot
.39685 .60566 Mdot
.64159 .63491 Mdot
.43256 .6252 Mdot
.22643 .35589 Mdot
.62494 .61463 Mdot
.35785 .59247 Mdot
.70321 .66034 Mdot
.55621 .34911 Mdot
.6639 .54552 Mdot
.44245 .64268 Mdot
.61128 .19104 Mdot
.40207 .55704 Mdot
.30614 .22452 Mdot
.78278 .4275 Mdot
.44102 .56618 Mdot
.3775 .56675 Mdot
.19345 .54016 Mdot
.42686 .58992 Mdot
.71476 .33062 Mdot
.33547 .62823 Mdot
.58487 .62912 Mdot
.43802 .4441 Mdot
.56074 .36956 Mdot
.41006 .37735 Mdot
.52546 .3131 Mdot
.38068 .34126 Mdot
.39162 .40733 Mdot
.60832 .62595 Mdot
.37183 .57204 Mdot
.28844 .58073 Mdot
.54446 .37294 Mdot
.37816 .64768 Mdot
.62544 .47899 Mdot
.56991 .35773 Mdot
.52949 .36262 Mdot
.63108 .45663 Mdot
.45119 .60926 Mdot
.28604 .69116 Mdot
.50866 .2492 Mdot
.50398 .17519 Mdot
.64981 .46162 Mdot
.62987 .48446 Mdot
.75452 .62937 Mdot
.41065 .37938 Mdot
.28306 .36924 Mdot
.63756 .58019 Mdot
.62661 .49125 Mdot
.3117 .43448 Mdot
.48973 .33437 Mdot
.67667 .58611 Mdot
.59005 .60395 Mdot
.34274 .57005 Mdot
.39515 .62344 Mdot
.63626 .44401 Mdot
.29345 .58594 Mdot
.79148 .60749 Mdot
.62092 .45948 Mdot
.45507 .55145 Mdot
.56956 .48065 Mdot
.71386 .34351 Mdot
.70331 .34463 Mdot
.39758 .36398 Mdot
.48835 .21944 Mdot
.62721 .63872 Mdot
.36169 .39819 Mdot
.6131 .5308 Mdot
.41241 .57298 Mdot
.62169 .45147 Mdot
.73468 .34145 Mdot
.63886 .46934 Mdot
.39942 .39301 Mdot
.39638 .36044 Mdot
.64197 .63962 Mdot
.58471 .638 Mdot
.53609 .8146 Mdot
.31238 .47178 Mdot
.43275 .58211 Mdot
.34499 .74757 Mdot
.63299 .67293 Mdot
.38689 .68669 Mdot
.41137 .40015 Mdot
.38502 .40064 Mdot
.417 .75302 Mdot
.36669 .59348 Mdot
.49014 .3905 Mdot
.37898 .60672 Mdot
.27755 .40506 Mdot
.35303 .59791 Mdot
.52459 .33904 Mdot
.41904 .55374 Mdot
.5861 .27949 Mdot
.38394 .55322 Mdot
.42868 .63359 Mdot
.50825 .35628 Mdot
.37567 .52918 Mdot
.53041 .32604 Mdot
.36652 .61474 Mdot
.35248 .39368 Mdot
.52461 .31615 Mdot
.2461 .53213 Mdot
.52079 .51026 Mdot
.72936 .32644 Mdot
.40613 .39887 Mdot
.38486 .41477 Mdot
.28825 .56004 Mdot
.58749 .63893 Mdot
.606 .58987 Mdot
.39747 .6034 Mdot
.4928 .32466 Mdot
.61104 .46265 Mdot
.41757 .59786 Mdot
.37039 .54471 Mdot
.45155 .63097 Mdot
.63206 .66488 Mdot
.55295 .33983 Mdot
.39128 .39389 Mdot
.53563 .30405 Mdot
.46986 .24242 Mdot
.49594 .35616 Mdot
.43698 .66017 Mdot
.38201 .53216 Mdot
.49059 .64845 Mdot
.42002 .80041 Mdot
.69309 .71415 Mdot
.62094 .64854 Mdot
.72669 .33834 Mdot
.38926 .35918 Mdot
.606 .71362 Mdot
.59307 .65595 Mdot
.53301 .34902 Mdot
.38727 .60505 Mdot
.43357 .53267 Mdot
.59487 .55389 Mdot
.59878 .70234 Mdot
.27977 .5508 Mdot
.51129 .36475 Mdot
.71375 .33738 Mdot
.74369 .62112 Mdot
.62369 .71457 Mdot
.48071 .42787 Mdot
.41545 .63287 Mdot
.40143 .41193 Mdot
.60149 .67481 Mdot
.41716 .3261 Mdot
.62919 .44511 Mdot
.51549 .4461 Mdot
.41309 .6148 Mdot
.73718 .47073 Mdot
.60088 .63661 Mdot
.40037 .40062 Mdot
.63519 .44342 Mdot
.41239 .37992 Mdot
.7016 .34286 Mdot
.5048 .20505 Mdot
.40658 .56578 Mdot
.44131 .61927 Mdot
.5961 .48424 Mdot
.62489 .63894 Mdot
.45534 .38072 Mdot
.30661 .34643 Mdot
.54395 .31254 Mdot
.45118 .36887 Mdot
.5796 .65782 Mdot
.51916 .65578 Mdot
.53078 .30351 Mdot
.65712 .48624 Mdot
.44617 .43041 Mdot
.60255 .46557 Mdot
.37831 .61148 Mdot
.60192 .65675 Mdot
.61718 .43829 Mdot
.44846 .27575 Mdot
.23323 .3127 Mdot
.4815 .66879 Mdot
.43318 .5637 Mdot
.16179 .46343 Mdot
.35226 .23334 Mdot
.30878 .55303 Mdot
.61291 .48713 Mdot
.43428 .61338 Mdot
.35583 .61327 Mdot
.41896 .55809 Mdot
.60736 .45095 Mdot
.40924 .25445 Mdot
.53368 .34125 Mdot
.41494 .58467 Mdot
.37947 .41281 Mdot
.52133 .33046 Mdot
.51553 .27473 Mdot
.4973 .31954 Mdot
.58737 .62074 Mdot
.35965 .58996 Mdot
.72276 .59043 Mdot
.28289 .23559 Mdot
.61728 .46668 Mdot
.72875 .32635 Mdot
.44455 .61886 Mdot
.63755 .77269 Mdot
.6041 .66703 Mdot
.5454 .31547 Mdot
.42264 .62404 Mdot
.43989 .25336 Mdot
.68808 .35082 Mdot
.49961 .34759 Mdot
.59032 .63721 Mdot
.31788 .54069 Mdot
.41023 .60833 Mdot
.40154 .55949 Mdot
.62212 .6325 Mdot
.52546 .20651 Mdot
.75069 .60405 Mdot
.42836 .63015 Mdot
.62954 .45953 Mdot
.84789 .57428 Mdot
.44739 .63546 Mdot
.54962 .63518 Mdot
.71762 .322 Mdot
.68609 .5723 Mdot
.47491 .7178 Mdot
.4275 .66917 Mdot
.17638 .45828 Mdot
.3575 .48968 Mdot
.1537 .45324 Mdot
.42664 .39963 Mdot
.64859 .35381 Mdot
.16649 .37722 Mdot
.60413 .43318 Mdot
.40676 .6938 Mdot
.22171 .5872 Mdot
.7536 .53282 Mdot
.40855 .46354 Mdot
.66764 .2461 Mdot
.47273 .26308 Mdot
.76119 .31956 Mdot
.50364 .31248 Mdot
.2659 .40791 Mdot
.38628 .62867 Mdot
.36574 .22178 Mdot
.46569 .69871 Mdot
.79191 .63338 Mdot
.16185 .43368 Mdot
.3867 .44916 Mdot
.20645 .60831 Mdot
.24358 .32307 Mdot
.29421 .67845 Mdot
.60679 .55256 Mdot
.73293 .3003 Mdot
.72161 .64474 Mdot
.31756 .36641 Mdot
.33105 .59076 Mdot
.59746 .27866 Mdot
.40439 .2249 Mdot
.582 .75341 Mdot
.811 .62477 Mdot
.53258 .29165 Mdot
.63054 .61227 Mdot
.21076 .50022 Mdot
.64694 .69637 Mdot
.59485 .41327 Mdot
.17547 .45982 Mdot
.29803 .24706 Mdot
.46957 .68617 Mdot
.64344 .1976 Mdot
.44546 .78255 Mdot
.56448 .83953 Mdot
.5377 .51446 Mdot
.65585 .63538 Mdot
.66407 .31336 Mdot
.71793 .66508 Mdot
.69715 .44479 Mdot
.57307 .69716 Mdot
.41739 .36981 Mdot
.26436 .53016 Mdot
.59674 .63419 Mdot
.46056 .72167 Mdot
.70275 .32688 Mdot
.63713 .53914 Mdot
.5263 .26571 Mdot
.21365 .37288 Mdot
.73421 .35727 Mdot
.69302 .59303 Mdot
.73632 .43561 Mdot
.198 .65461 Mdot
.33827 .45312 Mdot
.26633 .31749 Mdot
.66401 .51311 Mdot
.37743 .48128 Mdot
.77639 .57713 Mdot
.31794 .48456 Mdot
.71438 .68016 Mdot
.2735 .72941 Mdot
.41457 .19661 Mdot
.22116 .66229 Mdot
.64133 .69259 Mdot
.45591 .61295 Mdot
.22976 .38084 Mdot
.54784 .80269 Mdot
.40454 .36487 Mdot
.1894 .61011 Mdot
.40493 .4118 Mdot
.65145 .68742 Mdot
.75716 .51623 Mdot
.52497 .67075 Mdot
.55821 .3848 Mdot
.36089 .41632 Mdot
.44617 .64905 Mdot
.50744 .88741 Mdot
.16599 .48958 Mdot
.69524 .54969 Mdot
.31451 .24289 Mdot
.63916 .51799 Mdot
.47344 .39415 Mdot
.60732 .45642 Mdot
.2047 .3368 Mdot
.59324 .64927 Mdot
.23719 .27072 Mdot
.23097 .30623 Mdot
.82725 .51809 Mdot
.62639 .87702 Mdot
.73933 .3828 Mdot
.38966 .70086 Mdot
.27721 .61167 Mdot
.25924 .57185 Mdot
.78853 .58557 Mdot
.82756 .49429 Mdot
.60771 .51843 Mdot
.50157 .19379 Mdot
.17911 .37673 Mdot
.29635 .42337 Mdot
.37797 .24949 Mdot
.76371 .54364 Mdot
.51415 .49234 Mdot
.55094 .62504 Mdot
.50808 .51113 Mdot
.56282 .57614 Mdot
.20862 .63552 Mdot
.60925 .77842 Mdot
.80744 .66848 Mdot
.42542 .35749 Mdot
.82411 .43748 Mdot
.31698 .26189 Mdot
.24433 .51231 Mdot
.54982 .6754 Mdot
.73372 .56537 Mdot
.43749 .65795 Mdot
.73924 .6079 Mdot
.33422 .5411 Mdot
.35696 .35222 Mdot
.74632 .62997 Mdot
.62453 .39055 Mdot
.30773 .36495 Mdot
.19431 .4693 Mdot
.69211 .63501 Mdot
.59537 .61787 Mdot
.32328 .50002 Mdot
.32539 .44233 Mdot
.31587 .24797 Mdot
.7977 .49332 Mdot
.49236 .17606 Mdot
.81025 .49669 Mdot
.40758 .65388 Mdot
.39203 .68933 Mdot
.33376 .56527 Mdot
.33046 .47075 Mdot
.42355 .65004 Mdot
.72845 .45108 Mdot
.33474 .22887 Mdot
.5913 .79318 Mdot
.33319 .35064 Mdot
.38249 .78241 Mdot
.46502 .18318 Mdot
.232 .3873 Mdot
.78003 .43598 Mdot
.31931 .67091 Mdot
.40493 .84723 Mdot
.51375 .33408 Mdot
.30754 .43503 Mdot
.66327 .44969 Mdot
.41528 .3174 Mdot
.23825 .63245 Mdot
.82196 .53371 Mdot
.34051 .22418 Mdot
.74082 .57183 Mdot
.48196 .28128 Mdot
.54728 .41992 Mdot
.57419 .36298 Mdot
.3685 .7749 Mdot
.41193 .52613 Mdot
.49909 .56119 Mdot
.36523 .40881 Mdot
.54928 .79221 Mdot
.2497 .37918 Mdot
.6238 .24078 Mdot
.47184 .64436 Mdot
.63425 .2801 Mdot
.71026 .3368 Mdot
.52244 .44935 Mdot
.12574 .46575 Mdot
.37846 .66707 Mdot
.75699 .39606 Mdot
.43017 .19095 Mdot
.44148 .42315 Mdot
.29148 .30312 Mdot
.73253 .51395 Mdot
.2459 .69116 Mdot
.2619 .26836 Mdot
.53365 .23316 Mdot
.15265 .47923 Mdot
.47734 .15256 Mdot
.27784 .72198 Mdot
.37717 .76477 Mdot
.63414 .41796 Mdot
.26975 .20756 Mdot
.54402 .33436 Mdot
.44676 .8229 Mdot
.55816 .80227 Mdot
.41686 .2677 Mdot
.56303 .65066 Mdot
.4102 .5066 Mdot
.75158 .32365 Mdot
.62278 .60148 Mdot
.4511 .6472 Mdot
.17482 .61152 Mdot
.29174 .75679 Mdot
.18297 .61762 Mdot
.48107 .19458 Mdot
.15277 .47184 Mdot
.21769 .55807 Mdot
.56292 .71139 Mdot
.2348 .42878 Mdot
.37364 .622 Mdot
.28308 .44905 Mdot
.7444 .38839 Mdot
.48038 .2784 Mdot
.69662 .47941 Mdot
.56887 .64825 Mdot
.24618 .67334 Mdot
.11158 .50618 Mdot
.45309 .7659 Mdot
.52372 .73376 Mdot
.55567 .56282 Mdot
.31933 .46302 Mdot
.426 .48662 Mdot
.59878 .25397 Mdot
.3179 .25359 Mdot
.21848 .5814 Mdot
.31112 .41259 Mdot
.65618 .25623 Mdot
.58464 .36501 Mdot
.81544 .4266 Mdot
.21104 .36124 Mdot
.2257 .5253 Mdot
.82102 .4944 Mdot
.31607 .67626 Mdot
.80403 .58702 Mdot
.58059 .21824 Mdot
.46667 .36819 Mdot
.33142 .43272 Mdot
.52978 .36869 Mdot
.29323 .42931 Mdot
.58018 .51951 Mdot
.21102 .47045 Mdot
.34252 .50053 Mdot
.29041 .42076 Mdot
.58611 .35861 Mdot
.16143 .56178 Mdot
.52492 .15521 Mdot
.34807 .78842 Mdot
.58813 .18578 Mdot
.33033 .54477 Mdot
.42762 .64186 Mdot
.38237 .19915 Mdot
.15156 .55988 Mdot
.28631 .23934 Mdot
.73913 .46435 Mdot
.4413 .27481 Mdot
.60913 .42509 Mdot
.37099 .79307 Mdot
.60588 .21296 Mdot
.27928 .27367 Mdot
.69575 .70411 Mdot
.62666 .50365 Mdot
.74895 .57683 Mdot
.40027 .80103 Mdot
.29298 .68447 Mdot
.47022 .73372 Mdot
.33342 .58502 Mdot
.4303 .70913 Mdot
.64324 .62226 Mdot
.74802 .45635 Mdot
.3217 .47644 Mdot
.51411 .32879 Mdot
.235 .54195 Mdot
.5101 .58683 Mdot
.43455 .65926 Mdot
.46327 .35153 Mdot
.56732 .60899 Mdot
.45275 .8131 Mdot
.59989 .51182 Mdot
.15532 .3946 Mdot
.75224 .41178 Mdot
.41145 .49386 Mdot
.3495 .48189 Mdot
.42016 .33555 Mdot
.73578 .59466 Mdot
.59847 .4745 Mdot
.1764 .40452 Mdot
.48296 .49404 Mdot
.32944 .49496 Mdot
.43293 .71079 Mdot
.29602 .35015 Mdot
.36581 .54837 Mdot
.71506 .52284 Mdot
.60575 .74043 Mdot
.51758 .44036 Mdot
.66688 .66604 Mdot
.5726 .60458 Mdot
.72596 .23346 Mdot
.60113 .32716 Mdot
.80162 .46521 Mdot
.18138 .40169 Mdot
.60473 .4664 Mdot
.57815 .66666 Mdot
.28216 .42884 Mdot
.31593 .32307 Mdot
.6054 .75533 Mdot
.48929 .31052 Mdot
.34012 .42217 Mdot
.60802 .22849 Mdot
.16377 .4644 Mdot
.18054 .55562 Mdot
.78625 .66292 Mdot
.62029 .68515 Mdot
.28562 .3481 Mdot
.31502 .33577 Mdot
.61823 .68205 Mdot
.58467 .69431 Mdot
.60886 .55751 Mdot
.14113 .46216 Mdot
.73119 .60624 Mdot
.56374 .18771 Mdot
.44345 .42981 Mdot
.42842 .25069 Mdot
.39584 .32733 Mdot
.32751 .41262 Mdot
.18507 .39968 Mdot
.4494 .72721 Mdot
.26279 .66598 Mdot
.32931 .59506 Mdot
.55268 .81871 Mdot
.37708 .79766 Mdot
.53014 .50082 Mdot
.51355 .65638 Mdot
.62682 .39455 Mdot
.42559 .56345 Mdot
.19594 .65204 Mdot
.35015 .24307 Mdot
.73877 .65657 Mdot
.59289 .50548 Mdot
.38315 .57243 Mdot
.38806 .64356 Mdot
.29554 .58748 Mdot
.69574 .56185 Mdot
.32242 .76775 Mdot
.31907 .35398 Mdot
.31523 .56919 Mdot
.45071 .70798 Mdot
.7581 .39835 Mdot
.21434 .38044 Mdot
.33329 .2553 Mdot
.55986 .49874 Mdot
.74454 .39258 Mdot
.49604 .41497 Mdot
.55554 .1813 Mdot
.62009 .28708 Mdot
.21428 .54338 Mdot
.66385 .60575 Mdot
.71621 .56029 Mdot
.42864 .33362 Mdot
.43748 .62827 Mdot
.7558 .50597 Mdot
.23553 .3342 Mdot
.78381 .70437 Mdot
.78249 .56671 Mdot
.16461 .60375 Mdot
.50498 .63181 Mdot
.71782 .5684 Mdot
.24783 .65708 Mdot
.75624 .74822 Mdot
.59651 .26448 Mdot
.20656 .61856 Mdot
.53151 .41656 Mdot
.17104 .42008 Mdot
.6481 .42949 Mdot
.7023 .62434 Mdot
.39266 .7849 Mdot
.14236 .45561 Mdot
.25016 .34985 Mdot
.19241 .40206 Mdot
.30304 .66556 Mdot
.14144 .48917 Mdot
.6867 .70561 Mdot
.76572 .32108 Mdot
.55892 .29929 Mdot
.71807 .43093 Mdot
.34375 .72598 Mdot
.53511 .60557 Mdot
.31062 .4274 Mdot
.80496 .38547 Mdot
.62103 .72534 Mdot
.31543 .69967 Mdot
.25369 .4743 Mdot
.72584 .52847 Mdot
.35503 .48076 Mdot
.26168 .28796 Mdot
.76236 .31473 Mdot
.36605 .32499 Mdot
.781 .45902 Mdot
.5056 .20274 Mdot
.69137 .56039 Mdot
.62243 .33955 Mdot
.26406 .31847 Mdot
.55738 .20943 Mdot
.36953 .45337 Mdot
.74884 .23276 Mdot
.41449 .22747 Mdot
.60406 .5563 Mdot
.23354 .66567 Mdot
.32575 .25212 Mdot
.68151 .7123 Mdot
.7859 .6313 Mdot
.53879 .82443 Mdot
.29094 .47238 Mdot
.39728 .63104 Mdot
.13716 .50462 Mdot
.26294 .516 Mdot
.19843 .62411 Mdot
.42787 .17869 Mdot
.40322 .71521 Mdot
.41004 .66767 Mdot
.50629 .29673 Mdot
.55824 .54276 Mdot
.2507 .46575 Mdot
.2127 .6045 Mdot
.50648 .8316 Mdot
.45002 .36675 Mdot
.64894 .33911 Mdot
.48367 .32255 Mdot
.31702 .62904 Mdot
.73097 .39174 Mdot
.71236 .54897 Mdot
.41342 .34998 Mdot
.59336 .33071 Mdot
.31933 .45262 Mdot
.4725 .71543 Mdot
.28979 .682 Mdot
.81002 .55098 Mdot
.60485 .4033 Mdot
.52906 .28843 Mdot
.19018 .51313 Mdot
.42836 .21774 Mdot
.7257 .45756 Mdot
.30177 .73172 Mdot
.73716 .56071 Mdot
.25691 .41989 Mdot
.22817 .41687 Mdot
.79449 .57385 Mdot
.73158 .29173 Mdot
.31607 .7266 Mdot
.5554 .81826 Mdot
.50158 .39226 Mdot
.49558 .59008 Mdot
.16083 .39798 Mdot
.32806 .42041 Mdot
.21581 .44776 Mdot
.52815 .51705 Mdot
.56343 .77667 Mdot
.3606 .71785 Mdot
.24561 .5551 Mdot
.49634 .42759 Mdot
.46776 .87241 Mdot
.56401 .62814 Mdot
.19935 .65958 Mdot
.63689 .45341 Mdot
.71894 .72434 Mdot
.57994 .2897 Mdot
.56031 .51227 Mdot
.46677 .4336 Mdot
.7112 .52476 Mdot
.63423 .5533 Mdot
.49089 .19371 Mdot
.81358 .56774 Mdot
.49477 .35416 Mdot
.42059 .4337 Mdot
.5681 .19605 Mdot
.18317 .49367 Mdot
.43726 .55239 Mdot
.44307 .21934 Mdot
.52566 .49752 Mdot
.47358 .2888 Mdot
.38457 .20046 Mdot
.66026 .40175 Mdot
.46655 .57485 Mdot
.31884 .46642 Mdot
.21559 .6299 Mdot
.24339 .29564 Mdot
.77153 .6341 Mdot
.33311 .5425 Mdot
.63282 .41576 Mdot
.23885 .60034 Mdot
.17209 .47991 Mdot
.5137 .40125 Mdot
.70386 .6038 Mdot
.33328 .44622 Mdot
.22368 .71929 Mdot
.28373 .7454 Mdot
.32838 .76911 Mdot
.43782 .42322 Mdot
.6628 .63289 Mdot
.62779 .77616 Mdot
.21885 .44275 Mdot
.71083 .44452 Mdot
.41482 .21429 Mdot
.31188 .43912 Mdot
.72712 .75926 Mdot
.57087 .70077 Mdot
.47083 .23998 Mdot
.36348 .72157 Mdot
.52492 .80503 Mdot
.62934 .42235 Mdot
.27862 .47805 Mdot
.44555 .48154 Mdot
.61475 .49446 Mdot
.72316 .533 Mdot
.67032 .57711 Mdot
.21408 .45115 Mdot
.593 .74453 Mdot
.3187 .57248 Mdot
.1899 .46277 Mdot
.64831 .61288 Mdot
.41057 .32531 Mdot
.37388 .32984 Mdot
.41958 .46549 Mdot
.54095 .31433 Mdot
.4019 .67754 Mdot
.53614 .44387 Mdot
.51658 .42022 Mdot
.43863 .83557 Mdot
.39974 .4159 Mdot
.57466 .62533 Mdot
.72092 .69963 Mdot
.60984 .68313 Mdot
.14178 .55254 Mdot
.59958 .25645 Mdot
.44701 .70577 Mdot
.52244 .23395 Mdot
.65964 .28431 Mdot
.57497 .84908 Mdot
.34377 .75811 Mdot
.52847 .5383 Mdot
.59212 .70416 Mdot
.6439 .67218 Mdot
.55834 .38055 Mdot
.74133 .31679 Mdot
.48606 .72964 Mdot
.75636 .38353 Mdot
.24473 .41766 Mdot
.65884 .65294 Mdot
.44913 .23885 Mdot
.40527 .49336 Mdot
.13869 .43513 Mdot
.51079 .30168 Mdot
.36526 .82261 Mdot
.37046 .53509 Mdot
.25236 .64314 Mdot
.37237 .203 Mdot
.76101 .60808 Mdot
.45547 .345 Mdot
.69497 .25462 Mdot
.44144 .56303 Mdot
.31828 .58803 Mdot
.59678 .63125 Mdot
.271 .38045 Mdot
.38284 .38745 Mdot
.29079 .52854 Mdot
.62764 .50051 Mdot
.82703 .47235 Mdot
.73471 .3994 Mdot
.61089 .60389 Mdot
.47805 .50133 Mdot
.24912 .3632 Mdot
.67 .59247 Mdot
.52379 .49491 Mdot
.19301 .53527 Mdot
.59859 .75691 Mdot
.65767 .65644 Mdot
.30594 .73929 Mdot
.31322 .35152 Mdot
.21542 .31571 Mdot
.4546 .52175 Mdot
.5505 .5279 Mdot
.67892 .60763 Mdot
.72191 .51603 Mdot
.48131 .72008 Mdot
.31491 .25716 Mdot
.32198 .49321 Mdot
.71352 .65512 Mdot
.28924 .42325 Mdot
.37385 .52335 Mdot
.64548 .34078 Mdot
.71598 .41302 Mdot
.70142 .77696 Mdot
.41013 .76684 Mdot
.76514 .58501 Mdot
.5425 .64633 Mdot
.75552 .39478 Mdot
.57156 .62499 Mdot
.37733 .29351 Mdot
.58572 .75878 Mdot
.55606 .2526 Mdot
.18524 .35961 Mdot
.32089 .24734 Mdot
.57846 .56442 Mdot
.47849 .31314 Mdot
.35639 .49315 Mdot
.40845 .49579 Mdot
.50377 .45398 Mdot
.4474 .57379 Mdot
.30785 .62142 Mdot
.76642 .63458 Mdot
.7204 .47855 Mdot
.40374 .50604 Mdot
.1552 .42876 Mdot
.22681 .30235 Mdot
.15048 .51455 Mdot
.48226 .38543 Mdot
.57885 .62729 Mdot
.25298 .70184 Mdot
.50958 .70059 Mdot
.261 .2863 Mdot
.35137 .7358 Mdot
.70421 .21569 Mdot
.23229 .63069 Mdot
.61496 .39247 Mdot
.82851 .51005 Mdot
.67004 .52792 Mdot
.38994 .2027 Mdot
.76549 .31963 Mdot
.32917 .37399 Mdot
.39906 .19694 Mdot
.50399 .8857 Mdot
.39287 .76914 Mdot
.68438 .58672 Mdot
.34978 .69917 Mdot
.38466 .48545 Mdot
.7587 .37209 Mdot
.38391 .63059 Mdot
.54808 .36617 Mdot
.45664 .33034 Mdot
.31936 .44622 Mdot
.49594 .63068 Mdot
.76415 .37563 Mdot
.24925 .4603 Mdot
.27053 .39938 Mdot
.32379 .32823 Mdot
.21962 .60941 Mdot
.49115 .72438 Mdot
.47153 .58699 Mdot
.67188 .66064 Mdot
.3978 .36591 Mdot
.36437 .34308 Mdot
.35879 .59921 Mdot
.46021 .32934 Mdot
.63281 .57154 Mdot
.17351 .61468 Mdot
.3532 .30999 Mdot
.32552 .2933 Mdot
.59032 .59916 Mdot
.70342 .55117 Mdot
.21504 .40332 Mdot
.75449 .52671 Mdot
.77761 .38324 Mdot
.60494 .78115 Mdot
.16172 .47116 Mdot
.73042 .57385 Mdot
.30208 .39023 Mdot
.50844 .85202 Mdot
.6431 .48632 Mdot
.45723 .8104 Mdot
.21542 .5681 Mdot
.74337 .53498 Mdot
.64536 .68798 Mdot
.61198 .38247 Mdot
.65717 .35853 Mdot
.73641 .53235 Mdot
.43489 .18913 Mdot
.27085 .36321 Mdot
.38393 .72527 Mdot
.17574 .5337 Mdot
.56076 .31926 Mdot
.3097 .41403 Mdot
.60139 .36513 Mdot
.75551 .35788 Mdot
.69361 .63065 Mdot
.15545 .40959 Mdot
.49696 .44608 Mdot
.25849 .52917 Mdot
.40671 .56207 Mdot
.54658 .72425 Mdot
.71663 .49842 Mdot
.58531 .37152 Mdot
.79745 .47608 Mdot
.61126 .61418 Mdot
.74134 .42482 Mdot
.69946 .3196 Mdot
.28234 .49011 Mdot
.50916 .57182 Mdot
.66193 .61014 Mdot
.41058 .42183 Mdot
.69445 .3497 Mdot
.43265 .54384 Mdot
.2641 .54787 Mdot
.57126 .37512 Mdot
.42504 .79658 Mdot
.38776 .77143 Mdot
.18932 .5166 Mdot
.34788 .2579 Mdot
.72191 .45497 Mdot
.34514 .73584 Mdot
.63636 .54835 Mdot
.55121 .69177 Mdot
.7699 .50714 Mdot
.44236 .6437 Mdot
.38121 .29047 Mdot
.5751 .65561 Mdot
.18156 .50447 Mdot
.51917 .63348 Mdot
.24572 .52855 Mdot
.53639 .47574 Mdot
.22503 .38021 Mdot
.49732 .48183 Mdot
.37462 .20355 Mdot
.67377 .52426 Mdot
.32081 .47839 Mdot
.62317 .51127 Mdot
.53422 .41402 Mdot
.78787 .56236 Mdot
.20281 .35612 Mdot
.81511 .54815 Mdot
.27994 .61327 Mdot
.75935 .57855 Mdot
.57142 .8109 Mdot
.41223 .18613 Mdot
.30587 .48163 Mdot
.50533 .4555 Mdot
.42275 .4885 Mdot
.62796 .5381 Mdot
.73258 .34127 Mdot
.40107 .28732 Mdot
.50424 .71491 Mdot
.35723 .27875 Mdot
.52639 .2549 Mdot
.45498 .56822 Mdot
.64322 .7697 Mdot
.17235 .5104 Mdot
.63684 .72121 Mdot
.55023 .50932 Mdot
.44503 .31727 Mdot
.28034 .50023 Mdot
.86896 .40402 Mdot
.19348 .64983 Mdot
.40562 .56318 Mdot
.44308 .4365 Mdot
.28869 .52268 Mdot
.53914 .35801 Mdot
.48925 .73546 Mdot
.18754 .51409 Mdot
.62611 .487 Mdot
.43419 .28559 Mdot
.69258 .40438 Mdot
.70954 .51831 Mdot
.24126 .5578 Mdot
.59009 .48032 Mdot
.15113 .57665 Mdot
.45076 .21185 Mdot
.72271 .49383 Mdot
.80423 .30732 Mdot
.7368 .45337 Mdot
.63513 .60034 Mdot
.2462 .34666 Mdot
.15947 .55598 Mdot
.43878 .4248 Mdot
.41761 .31381 Mdot
.39327 .77589 Mdot
.31959 .48529 Mdot
.28296 .39316 Mdot
.7797 .45779 Mdot
.7508 .43392 Mdot
.76692 .33408 Mdot
.66001 .28227 Mdot
.46398 .84696 Mdot
.4396 .72049 Mdot
.17993 .56592 Mdot
.59653 .25974 Mdot
.73806 .74914 Mdot
.20433 .33767 Mdot
.27449 .45454 Mdot
.77335 .39104 Mdot
.26295 .32733 Mdot
.28524 .55316 Mdot
.64317 .75323 Mdot
.58337 .25129 Mdot
.60133 .76725 Mdot
.64747 .27746 Mdot
.7819 .50304 Mdot
.29194 .42589 Mdot
.54315 .80845 Mdot
.49439 .44128 Mdot
.20587 .57866 Mdot
.82655 .41915 Mdot
.35229 .475 Mdot
.44407 .28739 Mdot
.26825 .59017 Mdot
.18212 .47066 Mdot
.25522 .3203 Mdot
.48909 .45253 Mdot
.50751 .88219 Mdot
.20834 .63159 Mdot
.7623 .52903 Mdot
.41204 .64719 Mdot
.18379 .35323 Mdot
.45623 .45844 Mdot
.34792 .74107 Mdot
.40717 .20763 Mdot
.35216 .33904 Mdot
.66802 .60128 Mdot
.45421 .6234 Mdot
.33598 .75185 Mdot
.50607 .6559 Mdot
.5217 .80741 Mdot
.45033 .34226 Mdot
.34494 .48365 Mdot
.82779 .43287 Mdot
.25411 .59088 Mdot
.40897 .49769 Mdot
.57776 .65622 Mdot
.16333 .58713 Mdot
.29167 .66768 Mdot
.39492 .67981 Mdot
.3649 .69488 Mdot
.81456 .55673 Mdot
.73457 .27318 Mdot
.36541 .52137 Mdot
.73221 .59576 Mdot
.31255 .42951 Mdot
.23256 .42166 Mdot
.36412 .76365 Mdot
.64574 .87117 Mdot
.3614 .20751 Mdot
.55698 .6358 Mdot
.46093 .80506 Mdot
.41054 .44779 Mdot
.15364 .51551 Mdot
.65195 .25243 Mdot
.40751 .3332 Mdot
.82251 .58393 Mdot
.31281 .51888 Mdot
.35268 .57943 Mdot
.46859 .19159 Mdot
.20578 .34336 Mdot
.83601 .44079 Mdot
.16289 .39582 Mdot
.39594 .66389 Mdot
.33873 .58899 Mdot
.85898 .61759 Mdot
.1677 .44413 Mdot
.4113 .6697 Mdot
.80746 .58928 Mdot
.56772 .6672 Mdot
.37648 .62028 Mdot
.68465 .37384 Mdot
.33778 .43483 Mdot
.27616 .39969 Mdot
.14271 .45786 Mdot
.65524 .62397 Mdot
.46142 .32289 Mdot
.66192 .45127 Mdot
.4735 .43164 Mdot
.43636 .5357 Mdot
.61707 .43725 Mdot
.26366 .419 Mdot
.44477 .45639 Mdot
.57714 .47955 Mdot
.34988 .43661 Mdot
.53724 .16387 Mdot
.49513 .64783 Mdot
.57255 .56368 Mdot
.30516 .65738 Mdot
.63164 .72759 Mdot
.25051 .46193 Mdot
.23709 .45431 Mdot
.41042 .19587 Mdot
.49965 .13236 Mdot
.57903 .30482 Mdot
.43078 .51371 Mdot
.67382 .68419 Mdot
.49219 .71448 Mdot
.3694 .7103 Mdot
.58307 .4047 Mdot
.71502 .35016 Mdot
.41112 .66305 Mdot
.41637 .49599 Mdot
.63047 .5 Mdot
.19354 .6743 Mdot
.39163 .63719 Mdot
.42953 .73818 Mdot
.24436 .31396 Mdot
.41541 .32647 Mdot
.48169 .66187 Mdot
.43538 .5558 Mdot
.68492 .70727 Mdot
.44786 .461 Mdot
.33447 .51895 Mdot
.3821 .3276 Mdot
.16015 .51505 Mdot
.51758 .63085 Mdot
.40874 .72685 Mdot
.411 .59127 Mdot
.35964 .41209 Mdot
.67768 .58895 Mdot
.33447 .76322 Mdot
.49306 .54574 Mdot
.25782 .28385 Mdot
.35075 .33643 Mdot
.32265 .35172 Mdot
.41162 .69932 Mdot
.19662 .62519 Mdot
.77923 .56287 Mdot
.40254 .71128 Mdot
.75039 .65171 Mdot
.62408 .35698 Mdot
.25514 .47206 Mdot
.49156 .31698 Mdot
.40625 .50689 Mdot
.58295 .68625 Mdot
.126 .48973 Mdot
.35245 .76739 Mdot
.6734 .46723 Mdot
.49797 .38882 Mdot
.53474 .68621 Mdot
.47305 .43586 Mdot
.77862 .27575 Mdot
.66128 .24158 Mdot
.15301 .5816 Mdot
.26472 .37636 Mdot
.67695 .68102 Mdot
.72949 .5248 Mdot
.43465 .67545 Mdot
.50909 .35191 Mdot
.15614 .51618 Mdot
.45676 .51686 Mdot
.77583 .49149 Mdot
.36677 .6183 Mdot
.7262 .66117 Mdot
.39229 .48862 Mdot
.47364 .33434 Mdot
.52365 .37263 Mdot
.78537 .6144 Mdot
.23053 .34504 Mdot
.44966 .4628 Mdot
.7158 .23503 Mdot
.21193 .61027 Mdot
.17728 .4022 Mdot
.48612 .31543 Mdot
.73926 .71259 Mdot
.54008 .64723 Mdot
.3932 .49128 Mdot
.64268 .51212 Mdot
.27753 .63122 Mdot
.74097 .52982 Mdot
.24293 .40784 Mdot
.65284 .5562 Mdot
.6089 .54986 Mdot
.64146 .13952 Mdot
.27751 .4428 Mdot
.54803 .6671 Mdot
.75483 .49369 Mdot
.16801 .40353 Mdot
.34708 .41887 Mdot
.50724 .17557 Mdot
.59704 .29254 Mdot
.41583 .52311 Mdot
.59694 .74044 Mdot
.26149 .65208 Mdot
.67717 .39564 Mdot
.52499 .86223 Mdot
.41787 .2186 Mdot
.32314 .36044 Mdot
.58797 .37059 Mdot
.61348 .68382 Mdot
.56397 .65298 Mdot
.59205 .23071 Mdot
.60054 .17305 Mdot
.34355 .51971 Mdot
.16983 .47229 Mdot
.61766 .82737 Mdot
.28785 .36562 Mdot
.14568 .49189 Mdot
.68757 .47306 Mdot
.57406 .68729 Mdot
.24864 .45329 Mdot
.44431 .36828 Mdot
.55379 .34727 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo08oooooo0_l00008ooooo`;o0000[_ooool001cooooo00?o0000oooo
ooooool0Qoooool2o`0000Kooooo0_l00008ooooo`;o00001_ooool2o`000:Kooooo000Looooo`;o
0000R?ooool2o`0001Sooooo0_l0002Vooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0:cooooo0_l0002Kooooo`007?ooool00ol0003oooooooooo`2/
ooooo`;o00002_ooool2o`0008oooooo000Looooo`03o`000?oooooooooo0;Sooooo0_l0002?oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0O?ooool2o`000<_ooooo000Looooo`03o`000?oooooo
oooo07cooooo0_l0003;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0Woooool2o`000:Sooooo
000Looooo`03o`000?oooooooooo07Cooooo0_l0000Yooooo`;o0000Z?ooool001cooooo00?o0000
ooooooooool0M?ooool2o`0005Oooooo0_l0001jooooo`007?ooool00ol0003oooooooooo`3=oooo
o`;o0000N_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`;o0000V?ooool2o`000;3ooooo000Looooo`03o`000?oooooo
oooo09Oooooo0_l0000>ooooo`;o0000;_ooool2o`00073ooooo000Looooo`03o`000?oooooooooo
06[ooooo0_l0000kooooo`;o0000;_ooool2o`00073ooooo000Looooo`03o`000?oooooooooo06[o
oooo0_l0001:ooooo`;o0000TOooool001cooooo00?o0000ooooooooool0J?ooool2o`00043ooooo
0ol00007ooooo`Co0000TOooool001cooooo00?o0000ooooooooool0J?ooool2o`00043ooooo0ol0
0004ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000002o`0001cooooo0_l0
001^ooooo`007?ooool00ol0003oooooooooo`2]ooooo`;o00000_ooool2o`0000Kooooo1?l00002
ooooo`;o00006?ooool2o`0006kooooo000Looooo`03o`000?oooooooooo0:3ooooo0_l0000;oooo
o`;o00004?ooool2o`0008Sooooo000Looooo`03o`000?oooooooooo06?ooooo0_l0000Vooooo`;o
00003oooool2o`000003ooooool0003o000000;o00007?ooool2o`0008Sooooo000Looooo`03o`00
0?oooooooooo06?ooooo0_l0000Rooooo`;o00000_ooool2o`0000oooooo0_l000000ooooooo0000
o`000002o`0000?ooooo0_l00009ooooo`;o0000U_ooool001cooooo00?o0000ooooooooool0Qooo
ool2o`0000Oooooo0_l000000ooooooo0000o`00000<ooooo`;o00000oooool2o`0000Wooooo0_l0
000@ooooo`;o0000Q?ooool001cooooo00?o0000ooooooooool0O?ooool2o`0000Cooooo0_l0000<
ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Sooooo0_l0000@ooooo`;o00001_ooool2
o`0000Kooooo0_l00005ooooo`;o0000OOooool001cooooo00?o0000ooooooooool0GOooool2o`00
01gooooo0_l00004ooooo`;o00001_ooool2o`0000;ooooo0_l00007ooooo`;o00001Oooool2o`00
01?ooooo0_l00006ooooo`Co00002oooool2o`0007gooooo00001_ooooook^k^oc8b<_l0003o<S8b
onk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`1Mooooo`;o00007Oooool2
o`0000[ooooo1?l00002ooooo`;o00001?ooool2o`0000?ooooo2?l00008ooooo`;o00004_ooool2
o`0000?ooooo0ol00007ooooo`;o00004oooool2o`0006Kooooo00001_ooooooMgMgoiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003ooooo
ooooo`1looooo`Co00000_ooool3o`0000?ooooo0_l0000:ooooo`;o00000oooool5o`000003oooo
ool0003o000000Sooooo0_l00004ooooo`;o00001?ooool2o`0000_ooooo1Ol00005ooooo`;o0000
4oooool2o`0006Kooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?o
V9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`1hooooo`Co00000_ooool2o`0000;ooooo0ol0
000Dooooo`Go00004Oooool2o`0000Cooooo0_l0000>ooooo`;o00000_ooool2o`0000;ooooo0_l0
001jooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7o
k^k^00Kooooo0ol0001aooooo`;o00000_ooool2o`000003ooooool0003o000000?o00000oooool2
o`0001Wooooo0ol00002ooooo`;o00009oooool2o`000004ooooool0003o0000o`0007[ooooo0000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool0
0ol0003oooooooooo`1Eooooo`;o00006_ooool2o`0000;ooooo0ol000000ooooooo0000o`000002
o`0000?ooooo0_l0000Nooooo`;o00001?ooool2o`0002Cooooo0_l00005ooooo`;o0000M?ooool0
0003ooooool@413ooooo00;ooooo00?o410@ooooooooool03Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo05Cooooo0ol0000Kooooo`;o00000_ooool3o`0000Oooooo0ol0000Moooo
o`;o00001?ooool3o`0002[ooooo0_l0001dooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;
ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`1Dooooo`;o00007?oo
ool2o`0000;ooooo0ol00007ooooo`?o00003?ooool2o`0001Kooooo0_l00008ooooo`;o00004_oo
ool2o`0008;ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c006ooooo`03o`000?oooooooooo07oooooo0_l00002ooooo`;o00002_ooool2o`0001Go
oooo1_l00005ooooo`;o00003_ooool2o`0000;ooooo0_l00022ooooo`007?ooool00ol0003ooooo
ooooo`1oooooo`;o00000_ooool2o`0000;ooooo0_l0000@ooooo`;o00002oooool6o`0000gooooo
0_l00006ooooo`;o00002_ooool2o`0001;ooooo0_l0001Vooooo`007?ooool00ol0003ooooooooo
o`1^ooooo`;o000000?oooooo`000?l000004Oooool2o`000003ooooool0003o000000;o000000Co
ooooo`000?l0003ooooo0_l00008ooooo`Co00007?ooool2o`0000Kooooo0_l0000:ooooo`;o0000
4_ooool2o`0006Kooooo000Looooo`03o`000?oooooooooo063ooooo0_l00009ooooo`;o000000Co
ooooo`000?l0003ooooo1?l0000?ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`;o
00002_ooool2o`0000Gooooo0_l0000dooooo`;o0000Koooool001cooooo00?o0000ooooooooool0
H?ooool2o`0000Wooooo0_l00006ooooo`;o00002oooool2o`000003ooooool0003o000001gooooo
0_l0000dooooo`;o0000Koooool001cooooo00?o0000ooooooooool0JOooool2o`0000?ooooo0_l0
000@ooooo`;o000000?oooooo`000?l00000>?ooool2o`0000?ooooo0_l0000Jooooo`;o0000JOoo
ool001cooooo00?o0000ooooooooool0G?ooool2o`0000_ooooo2?l0000iooooo`;o00004Oooool2
o`0000?ooooo0_l0000Iooooo`?o00002?ooool2o`0000Gooooo0_l0001Hooooo`007?ooool00ol0
003oooooooooo`1Hooooo`;o00000_ooool2o`0000;ooooo0_l00004ooooo`;o000000?oooooo`00
0?l000000ol000000ooooooo0000o`00000eooooo`;o00000_ooool2o`0000Cooooo0_l0000Joooo
o`;o00003oooool2o`0000Kooooo0_l000000ooooooo0000o`000005ooooo`;o0000F?ooool001co
oooo00?o0000ooooooooool0F?ooool5o`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l0
00008oooool2o`0000Gooooo0_l000000ooooooo0000o`00000<ooooo`;o00002?ooool2o`0001[o
oooo0_l0000Gooooo`;o0000H_ooool001cooooo00?o0000ooooooooool0FOooool4o`0000Gooooo
0_l0000:ooooo`;o00006oooool2o`000003ooooool0003o000000Gooooo0_l000001?oooooo0000
o`000?ooool2o`0001Sooooo0_l000000ooooooo0000o`00000=ooooo`;o00002_ooool2o`000003
ooooool0003o0000077ooooo000Looooo`03o`000?oooooooooo05[ooooo0_l00004ooooo`Co0000
0oooool4o`0000?ooooo0_l000000ooooooo0000o`00000Fooooo`Co00002?ooool2o`0000Cooooo
0_l0000>ooooo`;o00002?ooool2o`000003ooooool0003o000000gooooo0_l0000:ooooo`Go0000
00?oooooo`000?l00000K_ooool001cooooo00?o0000ooooooooool0GOooool2o`000003ooooool0
003o000000Wo00001_ooool2o`0001Kooooo0_l0000@ooooo`?o00000oooool2o`0000Sooooo0_l0
000>ooooo`;o00006?ooool2o`0000;ooooo0_l0001^ooooo`007?ooool2o`0005gooooo0ol00003
ooooo`Ko00001?ooool2o`000003ooooool0003o000000Kooooo0_l0000>ooooo`;o00004oooool2
o`000003ooooool0003o000000;o00005oooool3o`0002Sooooo0_l0001Rooooo`007?ooool00ol0
003oooooooooo`1Jooooo`Ko00001?ooool4o`000003ooooool0003o000000?o000000Coooooo`00
0?l0003ooooo0_l00003ooooo`;o00002?ooool2o`0000Cooooo0_l00002ooooo`;o00004_ooool2
o`0000Kooooo0_l00008ooooo`;o00001oooool2o`0000?ooooo0_l0000>ooooo`?o00002oooool3
o`0000Gooooo0_l0000>ooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0D?ooool2o`00
00Sooooo0_l00002ooooo`;o00000oooool3o`0000?ooooo1ol00002ooooo`?o00003?ooool2o`00
00Sooooo0_l00005ooooo`;o00002oooool2o`0000Kooooo0_l00008ooooo`Co00002_ooool2o`00
00Cooooo0_l00008ooooo`Co00002_ooool4o`0001Cooooo0_l0001Booooo`007?ooool00ol0003o
ooooooooo`1@ooooo`;o00003?ooool2o`0000?ooooo0_l00008ooooo`?o00000oooool2o`0001Co
oooo0_l00007ooooo`;o00001Oooool4o`0000;ooooo0ol0000?ooooo`Co00001Oooool3o`000004
ooooool0003o0000o`0000Cooooo0_l0000:ooooo`;o00003?ooool2o`0006Sooooo000Looooo`03
o`000?oooooooooo05kooooo0_l00002ooooo`?o00009?ooool2o`0000Oooooo0ol000001?oooooo
0000o`000?ooool4o`0000?ooooo0_l00003ooooo`;o00002?ooool4o`0000Oooooo0ol000000ooo
oooo0000o`000006ooooo`;o0000POooool001cooooo00?o0000ooooooooool0H_ooool3o`0001oo
oooo0_l0000=ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Kooooo1_l00004ooooo`;o
00001oooool2o`000004ooooool0003o0000ooooo`;o00001_ooool2o`00087ooooo000Looooo`03
o`000?oooooooooo04Wooooo0_l00006ooooo`;o00002oooool2o`0001kooooo0_l00004ooooo`;o
00003oooool2o`0000;ooooo0_l00002ooooo`;o00001_ooool6o`0000gooooo0_l00004ooooo`;o
0000ROooool001cooooo00?o0000ooooooooool0>oooool2o`0000cooooo0_l00006ooooo`;o0000
1?ooool2o`0000Gooooo0_l0000>ooooo`;o00003_ooool2o`0001Gooooo0_l00002ooooo`;o0000
2?ooool4o`0000_ooooo0_l00004ooooo`;o00001?ooool2o`0002Cooooo0_l00005ooooo`;o0000
G?ooool001cooooo00?o0000ooooooooool0>oooool2o`0001Kooooo0_l00002ooooo`;o00000_oo
ool2o`000003ooooool0003o000000gooooo0ol0000Looooo`Go00001Oooool2o`0000[ooooo1Ol0
00001?oooooo0000o`000?ooool2o`000003ooooool0003o000000;ooooo0_l00006ooooo`;o0000
0_ooool2o`0002Cooooo0_l00005ooooo`;o00003?ooool2o`0004kooooo000Looooo`03o`000?oo
oooooooo04kooooo0_l00003ooooo`;o000000?oooooo`000?l000000oooool2o`000003ooooool0
003o000000Sooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000cooooo0_l0
000<ooooo`Go00001Oooool4o`0000Sooooo1Ol000000ooooooo0000o`000003o`000003ooooool0
003o000000[ooooo0ol000000ooooooo0000o`000006ooooo`;o00000_ooool2o`0000?ooooo0_l0
000Gooooo`;o00003oooool2o`0004kooooo000Looooo`03o`000?oooooooooo04kooooo0_l00002
ooooo`;o00000_ooool2o`0000Oooooo0_l00007ooooo`;o000000Coooooo`000?l0003o00000_oo
ool2o`0000Sooooo0_l00002ooooo`;o00003_ooool4o`0000Kooooo1_l00007ooooo`;o000000?o
ooooo`000?l000000_l00002ooooo`;o00002oooool2o`000003ooooool0003o000000Kooooo0_l0
0002ooooo`?o00000_ooool2o`0000;ooooo0_l0000Cooooo`;o0000Goooool001cooooo00?o0000
ooooooooool0D?ooool4o`0000_ooooo0_l00005ooooo`;o00000oooool3o`0000cooooo0_l0000=
ooooo`;o00000oooool4o`0000Oooooo1Ol00007ooooo`_o00006oooool2o`0000Gooooo0ol0001d
ooooo`007?ooool00ol0003oooooooooo`1@ooooo`?o00004oooool2o`0001Oooooo0_l00008oooo
o`;o000000?oooooo`000?l000000_ooool2o`0000Cooooo0ol00002ooooo`?o00002?ooool;o`00
01Gooooo0_l0000:ooooo`;o000000?oooooo`000?l000003oooool3o`00063ooooo000Looooo`03
o`000?oooooooooo057ooooo0_l0000:ooooo`;o00000_ooool2o`0001Gooooo0_l00005ooooo`;o
00002oooool2o`0000;ooooo0_l00004ooooo`?o00000oooool2o`0000Gooooo4?l00006ooooo`;o
00002oooool3o`0000cooooo0_l0000?ooooo`?o000000?oooooo`000?l00000GOooool001cooooo
00?o0000ooooooooool0GOooool6o`0000?ooooo0_l0000?ooooo`?o00009_oooolCo`0000Kooooo
0_l00003ooooo`;o00001oooool2o`00027ooooo0_l0001Mooooo`007?ooool00ol0003ooooooooo
o`1;ooooo`;o00001Oooool2o`0000_ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o0000
3_ooool2o`0002Oooooo2_l000000ooooooo0000o`000006o`0000?ooooo0_l00006ooooo`;o0000
ROooool001cooooo0_l0001<ooooo`;o00001?ooool3o`0000;ooooo0_l00007ooooo`;o00000_oo
ool2o`0000;ooooo0ol000000ooooooo0000o`00000Xooooo`;o00002OoooolDo`0000;ooooo0_l0
000booooo`;o0000GOooool001cooooo00?o0000ooooooooool0A_ooool2o`0000Wooooo0ol00002
ooooo`;o00000oooool2o`0000;ooooo0_l00006ooooo`Ko00001?ooool2o`0002;ooooo0_l00008
oooooaGo0000=_ooool2o`0005gooooo000Looooo`03o`000?oooooooooo04Kooooo0ol0000@oooo
o`Co00003Oooool3o`0000Cooooo0_l0000/oooooaGo00001?ooool2o`0000kooooo0_l0000goooo
o`;o0000A_ooool001cooooo00?o0000ooooooooool0Aoooool2o`0000Oooooo0_l00007ooooo`Ko
00001Oooool2o`0000Gooooo0_l00002ooooo`;o00008_ooool4o`0000Cooooo0_l00003oooooaCo
00001?ooool2o`0000kooooo0_l0000gooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0
B?ooool2o`0000;ooooo0_l00002ooooo`;o00002Oooool4o`000003ooooool0003o000000;ooooo
0ol00008ooooo`;o00004oooool2o`0000_ooooo1_l000000ooooooo0000o`000003o`000003oooo
ool0003o000001Go00007oooool2o`0000oooooo0_l0001Rooooo`007?ooool00ol0003ooooooooo
o`12ooooo`;o00001?ooool2o`0000;ooooo0ol0000>ooooo`;o000000?oooooo`000?l000000ooo
ool2o`0001gooooo0_l0000;ooooo`;o00001OoooolMo`000003ooooool0003o000000;o00006_oo
ool2o`0000oooooo0_l00006ooooo`;o00001Oooool2o`0005?ooooo000Looooo`03o`000?oooooo
oooo04;ooooo0_l00009ooooo`;o00000oooool3o`0002kooooo0_l00008ooooo`;o00002ooooolJ
o`0000;ooooo1?l0000Uooooo`;o00000_ooool3o`0000Gooooo1?l00004ooooo`Co0000D_ooool0
01cooooo00?o0000ooooooooool0Boooool3o`000004ooooool0003o0000ooooo`?o00003_ooool2
o`00013ooooo0_l0000<ooooo`;o00002?ooool2o`0000?ooooo0_l000000ooooooo0000o`000002
ooooo`;o000000?oooooo`000?l000004_l000001?oooooo0000o`000?l0000Qooooo`;o00002?oo
ool>o`0000Kooooo1?l0001Booooo`007?ooool00ol0003oooooooooo`1;ooooo`?o000000?ooooo
o`000?l000001_ooool2o`0000Oooooo0_l000000ooooooo0000o`00000;ooooo`;o000000?ooooo
o`000?l000000ol00005ooooo`;o00000oooool4o`0000?ooooo0_l00007ooooo`;o000000?ooooo
o`000?l000000_ooool2o`000003ooooool0003o000001Wo00007_ooool2o`0000[ooooo3?l00003
ooooo`;o00000oooool2o`0005;ooooo000Looooo`03o`000?oooooooooo04Wooooo0_l00007oooo
o`;o000000?oooooo`000?l000000_l00007ooooo`;o00000oooool2o`0000Wooooo0_l000001?oo
oooo0000o`000?ooool4o`0000?ooooo0_l00003ooooo`Co00000oooool2o`0000Kooooo0ol00008
oooooaco00001Oooool4o`0001oooooo3Ol00003ooooo`;o0000Eoooool001cooooo00?o0000oooo
ooooool0A_ooool2o`000003ooooool0003o000000Oooooo0_l000000ooooooo0000o`00000>oooo
o`;o000000?oooooo`000?l000003?ooool4o`0000?ooooo0_l00004ooooo`;o00003?ooool3o`00
0003ooooool0003o000000Gooooo4_l000000ooooooo0000o`000002o`000003ooooool0003o0000
00;o00001Oooool4o`0000Gooooo0_l0000;ooooo`;o00002_ooool?o`0005_ooooo000Looooo`03
o`000?oooooooooo04Kooooo0_l000000ooooooo0000o`00000Mooooo`;o00003?ooool2o`0000Ko
oooo0_l000000ooooooo0000o`000002ooooo`Co00001oooool3o`0000;ooooo0ol00003ooooo`[o
000000?oooooo`000?l000001ol000000ooooooo0000o`000005o`0000Kooooo0_l00007ooooo`;o
00002oooool2o`0000[ooooo2Ol000000ooooooo0000o`000003o`0000Oooooo0_l0001Booooo`00
7?ooool00ol0003oooooooooo`0oooooo`;o00002?ooool2o`0001Cooooo0_l00002ooooo`;o0000
2Oooool2o`0000kooooo0_l000000ooooooo0000o`000002ooooo`Co00001oooool2o`0000Cooooo
0_l00003ooooo`[o000000?oooooo`000?l000003Ol0000Zooooo`go00002Oooool2o`00017ooooo
0_l0000oooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00007_ooool2o`0000;ooooo0_l0
0009ooooo`?o00001oooool2o`0002;ooooo6Ol000001?oooooo0000o`000?l0000=ooooo`;o0000
1_ooool3o`0000oooooo3Ol0000Kooooo`;o0000?oooool001cooooo00?o0000ooooooooool0?ooo
ool2o`0001;ooooo0_l0000Jooooo`Ko00000oooool3o`0001Cooooo0_l00007oooooago000000Co
ooooo`000?l0003o00001Oooool2o`0000Kooooo0_l00006ooooo`?o00003_ooool8o`0000;ooooo
1?l0000Kooooo`;o0000?oooool001cooooo00?o0000ooooooooool0?oooool7o`000004ooooool0
003o0000o`0000;ooooo0_l00005ooooo`;o00002oooool3o`0000Wooooo0_l00003ooooo`Co0000
0oooool3o`00013ooooo1ol00006oooooaoo00001_ooool3o`0001oooooo3Ol0001Mooooo`007?oo
ool2o`0004;ooooo1Ol000001?oooooo0000o`000?l00002ooooo`Co00002Oooool2o`000003oooo
ool0003o000000;ooooo0ol00006ooooo`;o000000?oooooo`000?l000002_ooool2o`0000Wooooo
0_l00006ooooo`Co000000Coooooo`000?l0003o00001_oooolNo`0000?ooooo0_l000000ooooooo
0000o`000002o`0000Sooooo0_l00002ooooo`;o00003Oooool@o`0005gooooo000Looooo`03o`00
0?oooooooooo03Sooooo0_l00007ooooo`;o00002oooool2o`0000Oooooo1?l000000ooooooo0000
o`000004ooooo`Go00000_ooool2o`0000;ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o
00000oooool2o`0000Gooooo0_l000000ooooooo0000o`00000<ooooo`Co00001?oooolGo`000003
ooooool0003o000000;o00001Oooool2o`0000?ooooo0_l00008ooooo`;o00000_ooool4o`0000_o
oooo3ol0001Nooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00001?ooool5o`0000?ooooo
0_l0000?ooooo`;o00002Oooool5o`0000Kooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o
00000oooool2o`0000Gooooo0_l00002ooooo`;o00002_ooool2o`000003ooooool0003o000000Go
oooo5_l000000ooooooo0000o`000002o`0000[ooooo0_l00006ooooo`;o00001_ooool2o`0000co
oooo0_l000001?oooooo0000o`000?ooool8o`0005kooooo000Looooo`03o`000?oooooooooo03So
oooo0_l00004ooooo`Co00001?ooool2o`0001Cooooo0_l0000Fooooo`;o00000_ooool7o`000003
ooooool0003o000000;ooooo1?l00004ooooo`;o00000_ooool2o`0000Gooooo0_l00003ooooo`So
000000?oooooo`000?l000002_l00002ooooo`Go00000oooool6o`0000Kooooo0_l00009ooooo`;o
00002oooool3o`0000;ooooo1?l00003ooooo`;o00001Oooool2o`0005Gooooo000Looooo`03o`00
0?oooooooooo03Sooooo0_l00006ooooo`?o00002_ooool2o`000003ooooool0003o000000;ooooo
0_l00006ooooo`;o00001oooool2o`0000gooooo2ol000000ooooooo0000o`000004ooooo`;o0000
1?ooool2o`0000;ooooo0_l00005ooooo`;o00000oooool2o`000003ooooool0003o0000013o0000
1?ooool4o`0000;ooooo1?l0000Cooooo`;o00002oooool3o`0000Cooooo0_l00003ooooo`;o0000
1Oooool2o`0005Gooooo000Looooo`03o`000?oooooooooo047ooooo0ol00009ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0000Cooooo0_l00003ooooo`?o00000oooool2o`0000Sooooo0_l0
0003ooooo`_o000000?oooooo`000?l000003?ooool4o`0000[ooooo0_l000000ooooooo0000o`00
0006o`000003ooooool0003o000000?o000000Goooooo`000?l0003o0000ooooo`02o`0000?ooooo
0_l000000ooooooo0000o`000004ooooo`;o00006?ooool2o`0000Oooooo0_l0001Tooooo`007?oo
ool00ol0003oooooooooo`0kooooo`;o00001Oooool2o`0001Cooooo1Ol00002ooooo`?o000000?o
ooooo`000?l000000_l00008ooooo`;o00000_oooolAo`0000Wooooo1?l00003ooooo`;o00000_oo
ool6o`000003ooooool0003o0000013o000000?oooooo`000?l000001_ooool2o`0000Cooooo0_l0
000Hooooo`;o00001oooool2o`0006Cooooo000Looooo`03o`000?oooooooooo03_ooooo0_l0000<
ooooo`;o00003Oooool2o`000003ooooool0003o000000Kooooo0_l0000:ooooo`;o000000?ooooo
o`000?l000004_l00002ooooo`;o00000oooool4o`0000?ooooo0_l00002ooooo`Co00000oooool2
o`000003ooooool0003o000000[o00001?ooool2o`0000Kooooo0ol0000Qooooo`;o00004oooool2
o`0005Cooooo000Looooo`03o`000?oooooooooo03oooooo0_l000000ooooooo0000o`000005oooo
o`;o00003?ooool2o`0000Sooooo0ol00003ooooo`;o00001OoooolEo`000003ooooool0003o0000
00;ooooo0_l00003ooooo`;o00001_ooool2o`0000[ooooo1ol000001Ooooooo0000o`000?l0003o
oooo00;o00000oooool2o`0000;ooooo0_l00002ooooo`?o00007_ooool2o`000003ooooool0003o
0000017ooooo1Ol0001Cooooo`007?ooool00ol0003oooooooooo`0booooo`;o00000_ooool2o`00
00Oooooo0_l000000ooooooo0000o`00000>ooooo`;o00000oooool2o`0000Sooooo0ol00003oooo
o`;o00001Oooool2o`000003ooooool0003o000000co000000?oooooo`000?l000001Ol00006oooo
o`;o00001_ooool2o`0000Wooooo1?l000001Ooooooo0000o`000?l0003ooooo00;o00000_ooool2
o`0000Oooooo0_l0000Sooooo`Co00004_ooool2o`000003ooooool0003o000000;o000000?ooooo
o`000?l00000C_ooool001cooooo00?o0000ooooooooool0<_ooool2o`0000;ooooo0_l0000:oooo
o`;o000000?oooooo`000?l000000_l00004ooooo`?o00000_ooool4o`0001;ooooo0_l00007oooo
oaKo00002Oooool3o`0000Oooooo0_l00004ooooo`;o00000oooool2o`0000[ooooo0ol0000Foooo
o`;o00001Oooool3o`000003ooooool0003o000000Kooooo0_l0000Gooooo`;o000000?oooooo`00
0?l00000C_ooool001cooooo00?o0000ooooooooool0?_ooool2o`0000;ooooo0_l000000ooooooo
0000o`000002o`0000Cooooo0ol00004ooooo`;o00004_ooool4o`0000Cooooo5_l0000:ooooo`?o
00001oooool2o`0000kooooo0_l00005ooooo`?o00003oooool2o`0000Gooooo0_l00005ooooo`?o
000000?oooooo`000?l000005Oooool2o`0000Cooooo0_l00005ooooo`;o0000C_ooool001cooooo
00?o0000ooooooooool0?_ooool2o`0000Kooooo1?l00005ooooo`;o00000oooool2o`0000_ooooo
0_l00007ooooo`;o00001?oooolEo`0000Sooooo0ol00009ooooo`;o00001Oooool2o`000003oooo
ool0003o000000Gooooo0_l00006ooooo`;o00003oooool2o`0002Oooooo0_l00004ooooo`;o0000
1Oooool2o`0000Gooooo1?l00015ooooo`007?ooool00ol0003oooooooooo`16ooooo`Co00001Ooo
ool2o`0000?ooooo0_l00008ooooo`Go00003_oooolCo`0000Wooooo0ol00002ooooo`;o00001Ooo
ool4o`000003ooooool0003o000000;o000000Coooooo`000?l0003o00003?ooool2o`0001?ooooo
0_l0000Cooooo`;o00004?ooool2o`0000[ooooo0_l00004ooooo`Co0000AOooool00006ooooooo^
k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03
o`000?oooooooooo037ooooo0_l00007ooooo`;o00002Oooool2o`0000Cooooo0_l0000;ooooo`?o
00000oooool4o`0000;ooooo0_l00008oooooaSo00001?ooool2o`0000Kooooo0_l00007ooooo`;o
000000Coooooo`000?l0003o00000oooool2o`0001kooooo0_l000000ooooooo0000o`00000Coooo
o`;o00001_ooool2o`0000Cooooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo0_l000000ooo
oooo0000o`00000Aooooo`;o0000>_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0_ooooo`Co00001oooool2
o`000003ooooool0003o000000Kooooo0_l00004ooooo`;o00002oooool3o`0000Wooooo0_l00003
ooooo`;o00000ooooolHo`0000Cooooo0_l00006ooooo`;o00000_ooool4o`0000Gooooo0ol0000?
ooooo`;o00000oooool2o`0000cooooo0_l00002ooooo`;o00002Oooool2o`0000?ooooo0_l0000:
ooooo`Co00000_ooool2o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0000Kooooo0_l0000<
ooooo`;o0000>_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool5o`00
00Kooooo00?o0000ooooooooool0;oooool4o`0000Gooooo0_l00003ooooo`;o00004oooool7o`00
013ooooo0_l00003oooooaKo00000oooool2o`0000gooooo1?l00006ooooo`;o00001oooool2o`00
00Kooooo0_l00003ooooo`;o00004?ooool3o`0000Sooooo0_l00003ooooo`;o00003?ooool2o`00
00?ooooo0_l00005ooooo`;o00002oooool2o`0000Cooooo0_l00012ooooo`0000?oooooo`000?oo
ool00_ooool00ol0003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0000^oooo
o`;o000000?oooooo`000?l000000oooool4o`000003ooooool0003o000000?ooooo1?l0000;oooo
o`;o000000?oooooo`000?l000001Ol0000GoooooaCo00000oooool2o`0000Gooooo0_l00006oooo
o`;o00002oooool2o`0000Cooooo1?l00009ooooo`;o00002Oooool2o`0000Kooooo0_l00008oooo
o`;o00000_ooool2o`0001;ooooo0_l000000ooooooo0000o`000002ooooo`;o00004Oooool2o`00
00Sooooo0_l0000hooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04
omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0;_ooool2o`0000?ooooo1_l00002oooo
o`;o00000oooool4o`0000_ooooo0_l00005ooooo`;o00006?oooolEo`0000Wooooo0ol00002oooo
o`;o00003_ooool2o`0000Kooooo0_l0000=ooooo`;o00001Oooool2o`0000Oooooo0_l00007oooo
o`;o00000_ooool2o`0000Cooooo0_l0000?ooooo`;o00007oooool2o`0000Gooooo0_l0000aoooo
o`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oo
oooo00?o0000ooooooooool0<oooool5o`0001?ooooo0_l00006ooooo`;o000000?oooooo`000?l0
00005_ooool2o`000003ooooool0003o000001;o00001_ooool2o`0000;ooooo0_l00002ooooo`;o
000000?oooooo`000?l000004oooool2o`0000gooooo0_l0000>ooooo`;o00004Oooool2o`0003Oo
oooo0_l0000aooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co0000
00Oooooo00?o0000ooooooooool0;oooool2o`0001[ooooo0_l00006ooooo`;o00003?ooool2o`00
00Gooooo0_l00004ooooo`;o000000?oooooo`000?l000004ol00005ooooo`?o00001?ooool2o`00
00;ooooo0_l0000Vooooo`;o00004oooool2o`0000Sooooo0_l0000Booooo`;o0000E_ooool00006
ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooo
oooo02oooooo1?l0000^ooooo`;o00001?ooool3o`000003ooooool0003o000000Cooooo4_l00000
0ooooooo0000o`000006ooooo`;o00001?ooool2o`0000?ooooo0_l00004ooooo`;o00001_ooool2
o`0000?ooooo0_l0000Aooooo`?o00001?ooool2o`0000gooooo0_l0000@ooooo`;o00002_ooool2
o`0005Kooooo000Looooo`03o`000?oooooooooo037ooooo0_l0000Cooooo`;o00001?ooool2o`00
013ooooo0_l000000ooooooo0000o`000004ooooo`?o000000?oooooo`000?l000001?oooolBo`00
00Cooooo0_l000000ooooooo0000o`000004ooooo`Co00000_ooool3o`0000Cooooo1?l00004oooo
o`;o00000_ooool3o`00017ooooo0_l00005ooooo`;o00001?ooool3o`0000;ooooo0_l0000>oooo
o`?o00000oooool2o`0001oooooo0ol00010ooooo`007?ooool00ol0003oooooooooo`0dooooo`;o
00004?ooool4o`0000;ooooo0_l00002ooooo`Co00001oooool2o`000003ooooool0003o000000Oo
oooo0ol00003oooooaOo00000oooool2o`000004ooooool0003o0000o`0000;ooooo2_l00006oooo
o`;o00000oooool2o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000003_ooool3o`00
00Kooooo0ol00002ooooo`;o000000?oooooo`000?l000002oooool3o`0002Cooooo1Ol0000noooo
o`007?ooool00ol0003oooooooooo`0dooooo`;o00004_ooool2o`0000Kooooo1?l00006ooooo`Go
00002?ooool2o`0000;ooooo1_l000001?oooooo0000o`000?ooool5o`0000;ooooo1?l00002oooo
o`;o00000_ooool2o`0000;ooooo1?l000000ooooooo0000o`000002ooooo`Ko000000?oooooo`00
0?l000000oooool2o`0000?ooooo0_l00008ooooo`;o000000?oooooo`000?l000003_ooool3o`00
00Cooooo1ol00003ooooo`;o00006Oooool2o`0000Gooooo0_l0000Cooooo`;o0000?_ooool001co
oooo00?o0000ooooooooool0BOooool2o`0000cooooo0_l000000ooooooo0000o`000003o`0000;o
oooo0_l00008ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo1_l0000:ooooo`_o
00000oooool=o`0001oooooo2ol000001?oooooo0000o`000?l00002ooooo`;o00006_ooool2o`00
00Gooooo0_l00004ooooo`;o00002Oooool2o`0004;ooooo000Looooo`03o`000?oooooooooo02ko
oooo0ol0000<ooooo`;o00002?ooool4o`0000cooooo0ol000001?oooooo0000o`000?l00003oooo
o`?o00002_ooool2o`0000Sooooo1?l00005ooooo`;o00001Oooool2o`0000;ooooo1ol00005oooo
o`;o000000?oooooo`000?l000000ol0000Poooooa?o00004_ooool2o`0001?ooooo0_l00007oooo
o`Co00002oooool2o`0003Gooooo000Looooo`03o`000?oooooooooo02kooooo1Ol0000:ooooo`;o
00002?ooool4o`0000gooooo0_l00002ooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`;o
00001Oooool2o`000003ooooool0003o000000Gooooo1?l00002ooooo`?o00001?ooool3o`0000;o
oooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l000001?oooooo0000o`000?l0000Eoooo
o`;o00002?oooolAo`0000kooooo0_l00004ooooo`;o00002Oooool2o`00017ooooo0_l00004oooo
o`;o00001oooool2o`0003Gooooo000Looooo`03o`000?oooooooooo02Wooooo0_l00006ooooo`;o
00002_ooool2o`0000Oooooo0_l0000Hooooo`Co00001?ooool5o`000003ooooool0003o000000Go
oooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00004ooooo`?o00001?ooool2o`00
00Kooooo1?l00003ooooo`;o00000_ooool2o`0001Gooooo0_l00006oooooaCo00003Oooool2o`00
00[ooooo0_l00003ooooo`;o00002?ooool4o`0000_ooooo0_l0000nooooo`007?ooool00ol0003o
ooooooooo`0Yooooo`;o00004_ooool2o`0000;ooooo0_l00003ooooo`;o00000oooool2o`0000Wo
oooo0_l00008ooooo`Go00001?ooool4o`000003ooooool0003o000000Cooooo0_l00005ooooo`;o
00003oooool2o`0000Sooooo0_l00004ooooo`;o00007ooooolEo`0000_ooooo0_l0000<ooooo`?o
00003?ooool5o`0000Wooooo0_l00009ooooo`;o0000=?ooool001cooooo00?o0000ooooooooool0
<?ooool2o`0000oooooo1ol00003ooooo`;o00002Oooool2o`0000;ooooo0_l000000ooooooo0000
o`000003ooooo`?o000000?oooooo`000?l000003?ooool2o`0001Sooooo0_l00006ooooo`?o0000
0oooool3o`0000?ooooo1?l0000GoooooaOo00002Oooool2o`0000gooooo0_l0000<ooooo`;o0000
00?oooooo`000?l000002Oooool2o`0000;ooooo0_l00005ooooo`;o0000=?ooool001cooooo00?o
0000ooooooooool0<?ooool2o`000003ooooool0003o000000kooooo0ol0000@ooooo`;o00000_oo
ool2o`000003ooooool0003o000000Gooooo1?l000001?oooooo0000o`000?ooool2o`0000oooooo
0_l0000<ooooo`;o000000?oooooo`000?l000001oooool4o`0000;ooooo0ol00002ooooo`Co0000
1?ooool2o`0001Cooooo5?l0000;ooooo`;o00000_ooool3o`0001Cooooo0_l0000<ooooo`;o0000
0_ooool2o`0003_ooooo000Looooo`03o`000?oooooooooo03?ooooo0_l00008ooooo`;o00000ooo
ool2o`0000Gooooo0_l0000=ooooo`;o00002_ooool2o`0000?ooooo0_l000000ooooooo0000o`00
000<ooooo`;o000000?oooooo`000?l000000oooool4o`0000Gooooo0_l0000<ooooo`;o00000ooo
ool2o`0000?ooooo2Ol00006ooooo`;o00000oooool2o`0000Oooooo5Ol0000:ooooo`;o00000_oo
ool3o`0000Wooooo0ol0000Fooooo`?o00003oooool2o`0002gooooo000Looooo`;o0000:Oooool2
o`0001?ooooo0_l00003ooooo`;o00001Oooool2o`0000gooooo0_l0000:ooooo`Co00001oooool2
o`0000Wooooo0_l00004ooooo`Ko00005Oooool2o`0000Kooooo2Ol00002ooooo`;o00000_ooool2
o`0000?ooooo0ol00006oooooaWo00004?ooool4o`000003ooooool0003o000000;o00002Oooool2
o`0000Gooooo0_l00005ooooo`Co00003Oooool2o`0002gooooo000Looooo`03o`000?oooooooooo
02Sooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000oooooo0ol00004
ooooo`;o00000_ooool2o`0000Kooooo0_l000000ooooooo0000o`00000:ooooo`Co00000_ooool2
o`0000?ooooo0_l00003ooooo`?o00002Oooool2o`0001Wooooo0_l00003ooooo`?o000000?ooooo
o`000?l000000ol000001Ooooooo0000o`000?l0003ooooo00?o00001oooool2o`0000Cooooo6ol0
000>ooooo`_o00002?ooool3o`0000Gooooo0_l00007ooooo`;o0000??ooool001cooooo00?o0000
ooooooooool0:oooool2o`000004ooooool0003o0000ooooo`;o00000oooool2o`0000_ooooo0_l0
0004ooooo`?o000000?oooooo`000?l000001_ooool2o`000003ooooool0003o000000?ooooo0_l0
000;ooooo`;o00000_ooool2o`0000?ooooo1?l00006ooooo`Go00002oooool2o`000004ooooool0
003o0000o`0000Sooooo0_l00002ooooo`Co000000Coooooo`000?l0003ooooo0_l00002ooooo`;o
00000_ooool2o`0000;ooooo1?l00007oooooaOo000000?oooooo`000?l000003oooool3o`000003
ooooool0003o000000Co00002?ooool7o`0004Wooooo000Looooo`03o`000?oooooooooo02_ooooo
0_l00002ooooo`;o00001?ooool3o`0000Cooooo0_l0000<ooooo`;o000000?oooooo`000?l00000
3_ooool4o`0000?ooooo0_l00008ooooo`;o00000oooool2o`0000Sooooo1Ol00004ooooo`;o0000
0_ooool2o`000003ooooool0003o000000Co00001?ooool2o`0000Kooooo0_l0000Booooo`Co0000
1_oooolIo`0001;ooooo0_l000000ooooooo0000o`000002ooooo`;o00002?ooool7o`0000_ooooo
0_l0000looooo`007?ooool00ol0003oooooooooo`0Zooooo`;o00000oooool5o`000003ooooool0
003o000000?ooooo1?l0000?ooooo`?o00003oooool2o`000003ooooool0003o000000;o00003?oo
ool2o`0000gooooo0_l00003ooooo`Ko00000_ooool2o`0000Oooooo0_l0000ToooooaWo00005_oo
ool2o`0000cooooo0_l0000?ooooo`;o0000??ooool001cooooo00?o0000ooooooooool09Oooool2
o`0000?ooooo0_l00005ooooo`?o00001Oooool3o`0000Oooooo0_l00009ooooo`?o00003?ooool2
o`0000?ooooo1_l0000:ooooo`;o00003Oooool2o`0000;ooooo0_l000000ooooooo0000o`000004
ooooo`;o00002Oooool2o`0000Sooooo0ol0000>ooooo`;o00001ooooolHo`0000;ooooo0_l00004
ooooo`;o00002?ooool2o`0000?ooooo0ol0000@ooooo`Co0000A_ooool001cooooo00?o0000oooo
ooooool09Oooool2o`0000Sooooo0_l00006ooooo`Ko00001?ooool4o`0000Wooooo0ol0000;oooo
o`?o00001Oooool6o`0000Sooooo0_l0000@ooooo`?o00002_ooool2o`0000?ooooo0_l000000ooo
oooo0000o`000002ooooo`;o00001?ooool3o`0000;ooooo0_l0000:ooooo`;o000000?oooooo`00
0?l000001?ooool:o`000003ooooool0003o000000[o00000oooool2o`0000Cooooo0_l00008oooo
o`;o00000oooool3o`00013ooooo1Ol00008ooooo`;o0000>oooool001cooooo00?o0000oooooooo
ool09?ooool2o`0000Sooooo1ol00002ooooo`;o00000_ooool2o`0000Cooooo0_l0000;ooooo`?o
00002_ooool3o`0000Cooooo0ol00003ooooo`;o00006_ooool2o`0000?ooooo0_l000000ooooooo
0000o`000003ooooo`;o00000oooool2o`0000Gooooo0_l00005ooooo`;o00000_ooool2o`0000So
oooo0_l00003ooooo`;o00001?oooolHo`0000;ooooo0_l00003ooooo`;o00003_ooool2o`0000So
oooo0_l00008ooooo`Co00001Oooool2o`000003ooooool0003o000000;o0000>Oooool001cooooo
00?o0000ooooooooool09?ooool2o`0000Sooooo1ol0000Jooooo`;o00002_ooool2o`000003oooo
ool0003o000000;ooooo1Ol00008ooooo`;o00001Oooool2o`00017ooooo0_l000000ooooooo0000
o`00000Eooooo`;o00001Oooool2o`0000Kooooo0_l00002ooooo`;o00001?oooolIo`0000;ooooo
0_l00003ooooo`?o00005oooool2o`0000Oooooo0_l00008ooooo`;o00000oooool2o`0000Kooooo
0_l0000aooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00001?ooool2o`0001Gooooo0_l0
0002ooooo`;o00001_ooool2o`0000Gooooo0_l00004ooooo`Co00001oooool2o`0000Gooooo0_l0
000Aooooo`;o000000?oooooo`000?l000004oooool4o`0000Gooooo0_l0000:ooooo`Co00000_oo
oolIo`0000Sooooo0ol00006ooooo`;o00003_ooool2o`0000Oooooo0_l0000Eooooo`;o000000?o
ooooo`000?l00000;_ooool001cooooo00?o0000ooooooooool08oooool2o`0000Wooooo0_l00004
ooooo`;o00002Oooool2o`0000[ooooo0_l0000:ooooo`;o00001oooool2o`0000;ooooo1?l00006
ooooo`Co00001Oooool2o`0001?ooooo0ol0000?ooooo`;o000000?oooooo`000?l000004Oooool3
o`000003ooooool0003o000000;ooooo6Ol00009ooooo`;o00001_ooool2o`0000Cooooo0_l00008
ooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o00005Oooool2o`0002kooooo000L
ooooo`03o`000?oooooooooo02?ooooo0_l0000Jooooo`;o00007oooool3o`000003ooooool0003o
000000;o00001?ooool6o`000003ooooool0003o000000;ooooo1?l0000Aooooo`?o00001Oooool2
o`0000Oooooo0ol00007ooooo`;o00002oooool3o`0000Gooooo1Ol000000ooooooo0000o`000004
o`000003ooooool0003o000000Wo00000_ooool2o`0000kooooo0_l00004ooooo`;o00001?ooool2
o`0000Cooooo0ol000000ooooooo0000o`000004ooooo`;o0000AOooool001cooooo00?o0000oooo
ooooool0:_ooool3o`0000Gooooo0_l0000=ooooo`;o00002_ooool2o`0000gooooo0_l00003oooo
o`;o000000?oooooo`000?l000000_l00004ooooo`;o00001Oooool2o`0000Cooooo0_l000000ooo
oooo0000o`000008ooooo`Co00000_ooool2o`0000Kooooo0_l00003ooooo`;o00000_ooool2o`00
00Sooooo0_l0000Eooooo`;o000000?oooooo`000?l000003?l000000ooooooo0000o`000003o`00
0003ooooool0003o000000Cooooo0_l0000Dooooo`;o00001?ooool2o`0001cooooo0_l0000aoooo
o`007?ooool00ol0003oooooooooo`0Uooooo`;o00000oooool4o`0000Cooooo0_l0000=ooooo`;o
00002Oooool3o`0000Wooooo0_l00002ooooo`Co00001_ooool2o`0000Sooooo0_l0000:ooooo`;o
00000oooool2o`0000?ooooo1?l0000?ooooo`;o00002?ooool2o`0001Kooooo0_l000000ooooooo
0000o`00000Bo`000003ooooool0003o000000Oooooo0_l00004ooooo`;o00005?ooool2o`0001co
oooo0_l000000ooooooo0000o`00000^ooooo`007?ooool00ol0003oooooooooo`0Uooooo`;o0000
1Oooool2o`0000[ooooo0_l00008ooooo`;o00002?ooool2o`000003ooooool0003o000000Oooooo
0ol00003ooooo`;o00001Oooool4o`0000Gooooo1?l0000:ooooo`;o00000_ooool4o`0000;ooooo
0_l0000:ooooo`;o00001Oooool2o`0000Kooooo1?l000000ooooooo0000o`00000Cooooo`;o0000
0_ooool2o`0000?ooooo3_l00002ooooo`;o00003?ooool2o`0000?ooooo0_l00008ooooo`;o0000
1Oooool2o`0000Gooooo0ol00005ooooo`Co00003_ooool2o`0002kooooo000Looooo`03o`000?oo
oooooooo03Sooooo0_l00008ooooo`;o00002oooool2o`0000Sooooo0_l00003ooooo`;o00001Ooo
ool4o`0000Gooooo1?l0000>ooooo`Ko00000_ooool2o`0000Sooooo0_l00003ooooo`Co00001_oo
ool2o`0000?ooooo0ol00009ooooo`;o00004?ooool6o`000003ooooool0003o000000Co00000ooo
ool5o`0000Wooooo0_l000000ooooooo0000o`000002o`0000Sooooo0_l0000<ooooo`?o000000?o
ooooo`000?l000000_ooool4o`0000kooooo0_l0000^ooooo`007?ooool2o`0004;ooooo0_l0000D
ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Gooooo0_l00006ooooo`;o00002oooool5
o`0000;ooooo0_l0000=ooooo`?o00003Oooool3o`000003ooooool0003o000000;ooooo0_l00000
0ooooooo0000o`000003ooooo`;o00002_ooool2o`000003ooooool0003o000000Wo00001Oooool3
o`0000Wooooo0_l000000ooooooo0000o`00000;ooooo`;o00000_ooool4o`0000Wooooo0_l00005
ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0:Oooool2o`0000Gooooo0_l00005oooo
o`Go00001Oooool2o`0001Cooooo0_l000000ooooooo0000o`000009ooooo`;o00001Oooool2o`00
00Kooooo0_l0000Rooooo`;o00002Oooool2o`0000?ooooo0_l000000ooooooo0000o`000002oooo
o`;o00001_ooool2o`0000?ooooo0_l00005ooooo`?o000000?oooooo`000?l000000_l000000ooo
oooo0000o`00000Tooooo`;o00000_ooool6o`0000kooooo0_l00002ooooo`;o0000>Oooool001co
oooo00?o0000ooooooooool08Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool5o`0000Co
oooo0_l0000Cooooo`Co00000oooool3o`0000Cooooo0_l0000Fooooo`;o00000_ooool5o`00013o
oooo0_l0000=ooooo`;o00005_ooool4o`0000;ooooo1Ol000001?oooooo0000o`000?l00002oooo
o`;o00007Oooool2o`0000Gooooo0_l00002ooooo`;o00000_ooool2o`0000Cooooo0_l00007oooo
o`;o00000oooool2o`0003Wooooo000Looooo`03o`000?oooooooooo027ooooo0_l0000<ooooo`;o
00000oooool2o`0000[ooooo0_l0000Cooooo`;o00000_ooool2o`000004ooooool0003o0000o`00
00Cooooo0_l0000Fooooo`;o00000_ooool6o`0000oooooo0_l0000;ooooo`;o00000_ooool2o`00
00Oooooo0ol0000:ooooo`Wo00000_ooool4o`0001Gooooo0ol00002ooooo`;o00001Oooool2o`00
00Gooooo0_l00002ooooo`Co00001_ooool2o`0000Oooooo0_l0000nooooo`007?ooool00ol0003o
ooooooooo`0_ooooo`;o00000oooool2o`0000?ooooo0ol0000<ooooo`;o00000_ooool2o`0000Oo
oooo0_l00002ooooo`;o00002?ooool2o`000003ooooool0003o000000_ooooo0_l0000<ooooo`Co
00000oooool2o`0000Kooooo0_l0000?ooooo`;o00000_ooool2o`0000Oooooo0ol000000ooooooo
0000o`00000;ooooo`;o00000_ooool7o`0000?ooooo0_l00005ooooo`;o00002Oooool3o`0000;o
oooo0_l00004ooooo`;o00002oooool3o`0000Oooooo0_l00006ooooo`;o00002oooool2o`00037o
oooo000Looooo`03o`000?oooooooooo02gooooo1Ol00007ooooo`?o00003?ooool2o`0000;ooooo
0_l00004ooooo`;o000000?oooooo`000?l000000_l00008ooooo`Co000000?oooooo`000?l00000
2_ooool3o`0000Cooooo0_l00006ooooo`;o00001Oooool2o`0000Kooooo0ol0000Eooooo`;o0000
00?oooooo`000?l000001Oooool2o`0000_ooooo0_l00002ooooo`?o000000?oooooo`000?l00000
0_ooool5o`0000;ooooo1?l00002ooooo`;o00003Oooool2o`000003ooooool0003o000000Kooooo
0_l00003ooooo`;o00002?ooool2o`0001?ooooo0_l0000aooooo`007?ooool00ol0003ooooooooo
o`0]ooooo`Go00002?ooool2o`0000Wooooo1?l000000ooooooo0000o`000006ooooo`;o00000_oo
ool3o`0000Sooooo1?l00004ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Gooooo0_l0
0002ooooo`?o00004Oooool2o`0001Gooooo1Ol0000<ooooo`;o00001oooool2o`0000?ooooo0ol0
00000ooooooo0000o`000003o`0000;ooooo0_l00003ooooo`?o00002Oooool2o`0000;ooooo0_l0
0009ooooo`;o00005Oooool2o`0003kooooo000Looooo`03o`000?oooooooooo04Gooooo1?l00000
0ooooooo0000o`00000:ooooo`;o00000_ooool2o`0000Kooooo0ol00004ooooo`;o000000Cooooo
o`000?l0003ooooo0_l00002ooooo`Go000000?oooooo`000?l000000_ooool3o`0000;ooooo1Ol0
0009ooooo`;o00006?ooool2o`0000Oooooo0_l00004ooooo`;o00001oooool2o`000004ooooool0
003o0000ooooo`;o00000_ooool2o`0000Wooooo0_l00005ooooo`;o00000oooool3o`0002;ooooo
0ol0000nooooo`007?ooool00ol0003oooooooooo`16ooooo`;o00000_ooool2o`0000;ooooo0_l0
0003ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l0000<ooooo`?o00000_oo
ool5o`000003ooooool0003o000000;ooooo2_l00002ooooo`?o00001?ooool4o`0001oooooo1?l0
000>ooooo`;o00004?ooool2o`0000Gooooo0_l00003ooooo`?o00000oooool2o`0000Gooooo0_l0
0005ooooo`;o00003oooool3o`0000;ooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`16
ooooo`;o00001?ooool6o`000003ooooool0003o000000Kooooo0_l00002ooooo`?o00000_ooool2
o`0000Sooooo1?l000001?oooooo0000o`000?ooool4o`0000Kooooo1?l00005ooooo`?o00001_oo
ool2o`0000Gooooo0_l0000Dooooo`;o00001?ooool2o`0001oooooo0ol0000:ooooo`;o00000ooo
ool3o`0000Cooooo1?l000000ooooooo0000o`000003o`0001?ooooo0ol0000jooooo`007?ooool0
0ol0003oooooooooo`0Xooooo`;o00008_ooool2o`0000;ooooo1?l00007ooooo`;o00000_ooool4
o`000003ooooool0003o000000[ooooo1Ol000000ooooooo0000o`000003o`0000;ooooo0_l00002
ooooo`;o00001Oooool3o`0000kooooo0_l0000Dooooo`;o00001?ooool2o`0000cooooo0_l0000A
ooooo`;o00004?ooool2o`000003ooooool0003o000000Ko000000?oooooo`000?l000000_l0000D
ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0:?ooool2o`0000_ooooo0_l00004oooo
o`;o00003oooool2o`0000Cooooo0_l0000<ooooo`?o00003_ooool2o`0000;ooooo1_l00002oooo
o`;o00000_ooool2o`0000?ooooo1_l00002ooooo`;o00000_ooool2o`000004ooooool0003o0000
o`00017ooooo0_l0000:ooooo`;o00003?ooool2o`0002;ooooo0_l00002ooooo`Go000000?ooooo
o`000?l000000oooool2o`0000?ooooo0_l0000:ooooo`;o0000@?ooool001cooooo00?o0000oooo
ooooool0=Oooool2o`0000Cooooo0_l0000booooo`;o00001?ooool5o`0000;ooooo0ol00002oooo
o`_o00000_ooool6o`000003ooooool0003o000000;o00003oooool3o`0001_ooooo1?l0000Foooo
o`;o00001Oooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000008oooo
o`Co00002?ooool2o`0000Wooooo0_l0000eooooo`007?ooool00ol0003oooooooooo`0kooooo`;o
00003?ooool2o`0001Kooooo0_l000000ooooooo0000o`000003ooooo`;o00001?ooool2o`000003
ooooool0003o000000Go00000_ooool6o`000003ooooool0003o000000So00001?ooool3o`0000Co
oooo0_l0000?ooooo`?o00001_ooool4o`00017ooooo1?l000000ooooooo0000o`00000?ooooo`;o
00000_ooool2o`0000Cooooo0_l00002ooooo`;o00004Oooool2o`0001?ooooo0_l0000eooooo`00
7?ooool00ol0003oooooooooo`0kooooo`;o00001Oooool2o`0000Gooooo0_l00009ooooo`Co0000
1?ooool4o`000004ooooool0003o0000ooooo`;o00000_ooool3o`0000;ooooo0_l00002ooooo`So
00000_oooolBo`0000?ooooo0ol0000Fooooo`;o00000_ooool2o`0000;ooooo1?l00006ooooo`;o
00003_ooool4o`000003ooooool0003o000000[ooooo0_l00008ooooo`;o00003?ooool2o`0005?o
oooo000Looooo`03o`000?oooooooooo03?ooooo0_l0000=ooooo`;o00003_ooool6o`0000Cooooo
1?l00008ooooo`;o00000_ooool3o`000003ooooool0003o000000_o00000oooool8o`000003oooo
ool0003o000000;o00003Oooool4o`0000oooooo0_l00003ooooo`;o00000oooool2o`000004oooo
ool0003o0000o`0000kooooo1?l000000ooooooo0000o`000002ooooo`;o00002?ooool2o`0000?o
oooo0ol0000>ooooo`;o0000Doooool001cooooo0_l0000dooooo`;o00004_ooool2o`0000Wooooo
0_l00003ooooo`;o000000Coooooo`000?l0003ooooo0ol00009ooooo`;o000000?oooooo`000?l0
00000_ooool2o`000003ooooool0003o000000So000000?oooooo`000?l000002ol00005ooooo`?o
00001oooool4o`0000gooooo1?l00008ooooo`Ko000000?oooooo`000?l000000_ooool2o`0000Oo
oooo0_l00007ooooo`;o00001oooool3o`000003ooooool0003o000000?o00005?ooool2o`0000Oo
oooo1?l00004ooooo`;o0000??ooool001cooooo00?o0000ooooooooool0:_ooool2o`0001_ooooo
0_l0000>ooooo`Go00000_ooool2o`000003ooooool0003o000000Kooooo0_l00005ooooo`;o0000
00?oooooo`000?l000002?l000000ooooooo0000o`00000<o`0000Cooooo0ol0000:ooooo`;o0000
2_ooool6o`0000Wooooo0_l000000ooooooo0000o`000003o`000004ooooool0003o0000o`0000Ko
oooo0ol0000@ooooo`?o000000Coooooo`000?l0003ooooo0_l00009ooooo`;o00000_ooool2o`00
00Gooooo0_l00007ooooo`Co00001?ooool2o`0003cooooo000Looooo`03o`000?oooooooooo02[o
oooo0_l00004ooooo`;o00001Oooool2o`0001;ooooo0ol00005ooooo`;o000000?oooooo`000?l0
00000ol00002ooooo`;o00000_ooool2o`0000cooooo0ol000000ooooooo0000o`00000>o`000003
ooooool0003o000000Ko00001?ooool2o`0000_ooooo0_l0000:ooooo`;o00004_ooool2o`000004
ooooool0003o0000o`0000Oooooo0_l00004ooooo`;o00004?ooool2o`0000Wooooo1Ol000000ooo
oooo0000o`000005ooooo`;o00002Oooool2o`0000Cooooo0_l0000looooo`007?ooool00ol0003o
ooooooooo`0^ooooo`Co00001Oooool2o`0000[ooooo0_l00006ooooo`?o00001Oooool2o`000003
ooooool0003o000000Oo00004?ooool2o`0000;ooooo3_l000000ooooooo0000o`00000;o`0000;o
oooo0_l000000ooooooo0000o`00000Gooooo`;o00004Oooool4o`0000Cooooo0_l00006ooooo`;o
00002oooool2o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`Go00001_ooool4o`0000Wo
oooo0_l00004ooooo`;o0000??ooool001cooooo00?o0000ooooooooool0;_ooool2o`000003oooo
ool0003o0000013ooooo0_l00006ooooo`;o00002oooool6o`0000Sooooo0_l00002ooooo`;o0000
1OoooolNo`0000;ooooo0_l000001?oooooo0000o`000?l00007ooooo`;o00003Oooool2o`0000;o
oooo0_l000000ooooooo0000o`000009ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Ko
oooo0_l0000;ooooo`?o00001Oooool2o`0000Gooooo1?l00008ooooo`?o000000?oooooo`000?l0
0000Boooool001cooooo00?o0000ooooooooool0<Oooool2o`0000Cooooo0_l0000>ooooo`;o0000
4Oooool6o`0000;ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00000_ooool7o`000003
ooooool0003o000001co000000Coooooo`000?l0003o00001_ooool2o`00017ooooo0_l000000ooo
oooo0000o`000004o`0000Gooooo0_l0000=ooooo`Co00003?ooool2o`0000_ooooo1Ol00009oooo
o`;o000000?oooooo`000?l00000Boooool001cooooo00?o0000ooooooooool0=oooool2o`0000Wo
oooo0_l00003ooooo`;o00002_ooool2o`0000Gooooo0_l00002ooooo`;o00000_ooool3o`0000Co
oooo0ol00002ooooo`Oo000000?oooooo`000?l000007?l00002ooooo`;o00005Oooool2o`0000Oo
oooo1?l0000Dooooo`;o00004?ooool2o`0000?ooooo0_l00004ooooo`Co00002_ooool3o`0000?o
oooo0_l00003ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0<Oooool2o`0000oooooo
0_l0000<ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Oooooo1?l00005ooooob;o0000
0_ooool2o`00013ooooo0_l00009ooooo`;o00004?ooool2o`0000Wooooo0_l0000?ooooo`;o0000
0oooool3o`0000;ooooo0_l00006ooooo`;o00002oooool2o`0000?ooooo0_l00003ooooo`;o0000
@oooool001cooooo00?o0000ooooooooool0<Oooool2o`0001gooooo0_l00008ooooo`;o00002?oo
ool3o`0000Gooooo0ol000000ooooooo0000o`00000Po`000003ooooool0003o000000Co00002Ooo
ool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`00000@ooooo`;o00001Ooo
ool2o`0000;ooooo0_l0000?ooooo`;o00001?ooool2o`0000Gooooo0ol00002ooooo`;o00003ooo
ool2o`00013ooooo0_l0000gooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o00000_ooool2
o`0000Cooooo0_l00002ooooo`?o000000?oooooo`000?l000004_ooool2o`0001Gooooo4?l00000
0ooooooo0000o`00000Lo`0000cooooo0_l00003ooooo`;o000000?oooooo`000?l000001?ooool2
o`00017ooooo0_l0000>ooooo`;o00000oooool4o`0000Wooooo0ol00004ooooo`;o00000_ooool2
o`0000?ooooo1?l00002ooooo`?o000000?oooooo`000?l000003?ooool2o`0003Oooooo000Loooo
o`03o`000?oooooooooo02gooooo0ol000000ooooooo0000o`000003ooooo`?o00000_ooool3o`00
0003ooooool0003o000000;ooooo1?l0000<ooooo`;o00000oooool4o`0000kooooo0ol00002oooo
oaoo000000?oooooo`000?l000000_l0000Pooooo`;o00003_ooool2o`0000Kooooo0_l00004oooo
o`;o00000_ooool3o`000003ooooool0003o000000Co00002Oooool2o`0000Gooooo0_l00002oooo
o`;o00000oooool6o`000004ooooool0003o0000ooooo`;o00001?ooool2o`0003oooooo000Loooo
o`03o`000?oooooooooo02kooooo0_l00006ooooo`;o00002oooool4o`00017ooooo1?l0000=oooo
o`?o000000?oooooo`000?l000009?l0000=ooooo`;o00007oooool4o`0000Kooooo0_l00004oooo
o`;o00000_ooool3o`000003ooooool0003o000000gooooo0_l0000;ooooo`;o00001Oooool2o`00
00Wooooo0ol0000oooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00004Oooool2o`0001;o
oooo0_l00002ooooo`;o00001_ooool2o`0000?ooooo0_l000000ooooooo0000o`00000>o`000003
ooooool0003o000001?o00000_ooool5o`0000Oooooo1?l0000Mooooo`;o00004Oooool2o`0000;o
oooo0_l000000ooooooo0000o`00000Hooooo`;o00001Oooool2o`0000?ooooo0_l00004ooooo`;o
00000oooool2o`0003_ooooo000Looooo`03o`000?oooooooooo037ooooo0_l0000Aooooo`;o0000
2Oooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00006ooooo`;o0000
0_oooolao`0000Cooooo0_l00003ooooo`;o00002?ooool2o`000003ooooool0003o000000;o0000
3_ooool2o`0000Kooooo0_l00009ooooo`;o00000_ooool5o`0000Gooooo0_l00003ooooo`;o0000
4oooool2o`000003ooooool0003o000000?o00001Oooool2o`000003ooooool0003o000003_ooooo
00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@
4?o<c<`01_ooool00ol0003oooooooooo`14ooooo`;o00002Oooool2o`0000;ooooo0_l000000ooo
oooo0000o`000002o`0000_ooooo2?l000000ooooooo0000o`00000Wo`0000;ooooo0_l00002oooo
o`;o00003Oooool7o`0000kooooo0_l00006ooooo`;o00002oooool5o`0000;ooooo0_l00003oooo
o`;o000000?oooooo`000?l000000_l00006ooooo`;o00000_ooool2o`0000[ooooo0_l000000ooo
oooo0000o`000005ooooo`;o0000?_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo04Cooooo0_l0
000Oooooo`Go000000Coooooo`000?l0003ooooo8_l000000ooooooo0000o`000002ooooo`;o0000
0_ooool4o`00017ooooo0_l00006ooooo`;o00000oooool3o`0000;ooooo0ol0000Booooo`?o0000
1Oooool2o`0000Kooooo0_l00003ooooo`?o00000_ooool3o`000003ooooool0003o000000;ooooo
0_l0001@ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`0`ooooo`;o00002_ooool2o`0000Kooooo
0_l00004ooooo`;o00002Oooool3o`0000;ooooo0_l0000:ooooo`Co000000Coooooo`000?l0003o
oooo9_l000000ooooooo0000o`000002ooooo`Co00005_ooool2o`000004ooooool0003o0000oooo
o`Go00000_ooool4o`0000Oooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`00
0?l000004oooool3o`0000;ooooo1?l00004ooooo`;o000000?oooooo`000?l000003Oooool2o`00
03kooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oiRHV?oo
ooooV9RHob4Q8@06ooooo`?o0000<?ooool2o`0000Gooooo0_l00003ooooo`;o00002oooool3o`00
00Kooooo0_l000001?oooooo0000o`000?l00002ooooo`?o000000?oooooo`000?l000002?ooool2
o`000003ooooool0003o000000;ooooo1_l000000ooooooo0000o`00000Lo`0000?ooooo1_l00003
ooooo`;o00002oooool2o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l000001?ooool3
o`0000;ooooo1_l000000ooooooo0000o`000002ooooo`;o000000Coooooo`000?l0003o00002_oo
ool3o`0000[ooooo1?l00007ooooo`?o00003?ooool2o`0000;ooooo0_l0000jooooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_oo
ool00ol0003oooooooooo`0booooo`;o00000oooool2o`0000Sooooo0_l00006ooooo`;o00001ooo
ool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo1Ol0
0003oooooa7o000000?oooooo`000?l000003ol000001?oooooo0000o`000?ooool2o`0000;ooooo
0_l00002ooooo`?o00002?ooool2o`000004ooooool0003o0000ooooo`?o00000oooool2o`0000?o
oooo1Ol000000ooooooo0000o`000002o`000003ooooool0003o000000?o00002Oooool4o`0000Wo
oooo1ol00002ooooo`;o00001?ooool3o`0000Cooooo1_l00004ooooo`;o000000?oooooo`000?l0
00001oooool2o`0003[ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo
00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`0booooo`;o00002oooool4o`000003oooo
ool0003o000000oooooo0ol0000;ooooo`;o00001?ooool4o`0000?ooooo9_l000000ooooooo0000
o`000006ooooo`;o00002Oooool2o`0000Cooooo0ol00002ooooo`Go000000?oooooo`000?l00000
0ol000000ooooooo0000o`000002o`000003ooooool0003o000000?o00002?ooool3o`0000?ooooo
0_l00006ooooo`Oo00000_ooool5o`000003ooooool0003o000000?o00000_ooool5o`000003oooo
ool0003o000000;ooooo0_l000001?oooooo0000o`000?ooool2o`00043ooooo00001_ooooooMgMg
oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0eoooo
o`;o00000oooool2o`0000?ooooo1?l000000ooooooo0000o`00000?ooooo`?o00004oooool5o`00
0003ooooool0003o000001?o000000?oooooo`000?l000003Ol0000Oooooo`;o000000Coooooo`00
0?l0003ooooo1Ol000000ooooooo0000o`00000;o`000003ooooool0003o000000;ooooo0_l00004
ooooo`;o00001oooool2o`0000Oooooo1_l000001?oooooo0000o`000?l00005ooooo`;o000000?o
ooooo`000?l000002?ooool2o`00043ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo
00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`0eooooo`;o00000oooool2o`0000Go
oooo0_l0000Booooo`Co00001Oooool4o`0000Kooooo0_l000000ooooooo0000o`00000Wo`0000?o
oooo0_l0000Hooooo`;o000000Coooooo`000?l0003o00000_oooolHo`0000;ooooo0_l00003oooo
o`;o00004oooool7o`0000Gooooo1?l0001<ooooo`007?ooool00ol0003oooooooooo`0eooooo`;o
000000?oooooo`000?l000001Oooool2o`0000[ooooo0_l00008ooooo`Co00001Oooool4o`0000Ko
oooo0_l00003ooooo`;o000000?oooooo`000?l000003?l000000ooooooo0000o`00000Co`0000?o
oooo0ol0000Gooooo`;o000000Coooooo`000?l0003o00000_ooool3o`000003ooooool0003o0000
01Go00001?ooool2o`0001?ooooo0_l00002ooooo`;o00001_ooool4o`0001Kooooo0_l0000doooo
o`007?ooool00ol0003oooooooooo`0hooooo`;o00001Oooool2o`0000[ooooo0_l00008ooooo`;o
00002Oooool2o`0000_ooooo0_l000000ooooooo0000o`00000:o`0000?ooooo4Ol00005ooooo`Go
00006_ooool2o`000003ooooool0003o000001Co00000oooool4o`0001Wooooo0ol000000ooooooo
0000o`000003o`0001gooooo0_l0000dooooo`007?ooool00ol0003oooooooooo`0mooooo`;o0000
5_ooool2o`0000Wooooo1?l00004ooooo`;o00000_ooool8o`0000;ooooo7?l000000ooooooo0000
o`000005o`0000;ooooo0_l00004ooooo`;o00002oooool2o`0000?ooooo7?l000000ooooooo0000
o`00000=ooooo`;o00002?ooool2o`0000;ooooo0_l00002ooooo`Ko00003?ooool2o`0000?ooooo
0_l0000nooooo`007?ooool00ol0003oooooooooo`0looooo`?o00004oooool2o`0000kooooo0_l0
0002ooooo`Co00000_ooool2o`000003ooooool0003o0000027o000000Coooooo`000?l0003ooooo
1Ol000000ooooooo0000o`000004ooooo`;o00002Oooool4o`0000;ooooo0_l000000ooooooo0000
o`00000Ho`000003ooooool0003o000000gooooo0_l00008ooooo`Co00000_ooool2o`000004oooo
ool0003o0000ooooo`;o00003?ooool2o`0000?ooooo0_l0000nooooo`007?ooool00ol0003ooooo
ooooo`0looooo`;o00001?ooool2o`0000Cooooo0_l00008ooooo`;o000000Coooooo`000?l0003o
00001?ooool2o`0000Gooooo0_l000001?oooooo0000o`000?ooool2o`000005ooooool0003o0000
o`000?ooool08_l000001?oooooo0000o`000?ooool5o`0000;ooooo0_l00005ooooo`;o00001ooo
ool2o`0000Cooooo0_l00002oooooago000000?oooooo`000?l000001oooool2o`0000cooooo0_l0
00000ooooooo0000o`000002o`0000Sooooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`0g
ooooo`;o00001oooool4o`0000Cooooo1?l00009ooooo`?o00001?ooool2o`0000Gooooo0_l00004
ooooo`Ko000000?oooooo`000?l000006ol00002ooooo`;o00001Oooool3o`000003ooooool0003o
000000?o000000?oooooo`000?l000000_ooool4o`0000Gooooo0_l00002ooooo`;o00000oooool2
o`000003ooooool0003o000001co00000oooool2o`0000;ooooo0_l00002ooooo`;o00001Oooool2
o`0000Cooooo1?l00004ooooo`;o00000_ooool4o`0000Cooooo0_l00014ooooo`007?ooool00ol0
003oooooooooo`0gooooo`;o00001oooool2o`0000Sooooo0_l0000Mooooo`?o00000_oooolRo`00
0003ooooool0003o000000Cooooo0_l000001?oooooo0000o`000?l00002ooooo`?o00000oooool3
o`0000?ooooo2?l00003ooooo`go00000_ooool3o`000003ooooool0003o000000_o00001?ooool6
o`0000;ooooo0_l00005ooooo`;o00001?ooool3o`0000?ooooo1?l00004ooooo`;o00001?ooool2
o`0004Cooooo000Looooo`03o`000?oooooooooo043ooooo0_l0000Iooooo`;o00002oooool3o`00
00?ooooo1?l00002ooooo`_o000000?oooooo`000?l000002_l000000ooooooo0000o`000006o`00
00[ooooo0_l0000:ooooo`?o000000?oooooo`000?l000000_l00004oooooako00001_ooool4o`00
00Oooooo0_l00007ooooo`;o00001?ooool2o`0000Kooooo0_l0001:ooooo`007?ooool00ol0003o
ooooooooo`1>ooooo`;o00002oooool2o`0000_ooooo0_l00004ooooo`Co00000_ooool2o`000004
ooooool0003o0000oooooaSo000000?oooooo`000?l000005oooool2o`0000Gooooo0_l00002oooo
oaco00001_ooool2o`0000Gooooo0_l00004ooooo`?o0000H?ooool001cooooo00?o0000oooooooo
ool0C_ooool2o`00013ooooo0_l00007ooooo`;o000000?oooooo`000?l000000ol00004ooooo`Co
000000?oooooo`000?l000002_l000000ooooooo0000o`00000:o`0000?ooooo1?l00004ooooo`;o
00001_ooool2o`0000?ooooo0ol00002ooooo`;o000000?oooooo`000?l000002?l000000ooooooo
0000o`00000Fo`0000?ooooo0_l00005ooooo`;o00000oooool4o`0000?ooooo0_l0001Kooooo`00
7?ooool00ol0003oooooooooo`1Pooooo`;o00000_ooool3o`0000;ooooo0_l000001?oooooo0000
o`000?ooool2o`0000;ooooo1_l00004ooooo`Oo000000?oooooo`000?l000001?l000000ooooooo
0000o`000005o`0000?ooooo1?l00002ooooo`Co00001Oooool4o`0000;ooooo0ol00002ooooo`;o
00000_oooolMo`0000;ooooo0ol00005ooooo`;o00002?ooool6o`000003ooooool0003o000005_o
oooo000Looooo`;o0000??ooool3o`0001?ooooo0_l0000Aooooo`?o00003?ooool6o`0000Cooooo
1ol000000ooooooo0000o`000004o`0000;ooooo1Ol00003ooooo`Go00000_ooool3o`0000Kooooo
1?l00003ooooo`;o00001OoooolSo`0000Gooooo0_l0000<ooooo`;o00000oooool4o`0000Gooooo
0_l0001@ooooo`007?ooool00ol0003oooooooooo`0kooooo`Co00004_ooool2o`0000gooooo0_l0
0007ooooo`;o00002Oooool8o`0000?ooooo1Ol00002ooooo`Go000000?oooooo`000?l000001?l0
0003ooooo`;o00002_ooool2o`0000;ooooo0_l0000<ooooo`co000000?oooooo`000?l000005?l0
000>ooooo`;o00000_ooool2o`0000Cooooo1?l00005ooooo`;o0000D?ooool001cooooo00?o0000
ooooooooool0?Oooool2o`0000kooooo0_l0000>ooooo`Go00001?ooool5o`0000Kooooo0_l00005
ooooo`Co000000?oooooo`000?l000001?l00002ooooo`[o000000?oooooo`000?l000003oooool6
o`0000cooooo0_l000000ooooooo0000o`000007o`000003ooooool0003o000001;o00000_ooool2
o`0000cooooo0_l00002ooooo`;o00000_ooool2o`0005_ooooo000Looooo`03o`000?oooooooooo
03gooooo0_l0000>ooooo`Go00002oooool5o`0000Cooooo1?l00007ooooo`;o00002_ooool3o`00
00;ooooo0_l000000ooooooo0000o`000005o`0000Kooooo0_l00005ooooo`;o00002?ooool2o`00
013ooooo2_l000000ooooooo0000o`00000Fo`0000Kooooo0_l000001?oooooo0000o`000?ooool2
o`0000;ooooo0_l00002ooooo`;o00002?ooool2o`00057ooooo000Looooo`03o`000?oooooooooo
03gooooo1?l00003ooooo`;o00002?ooool4o`0001Gooooo0_l00006ooooo`;o00002oooool8o`00
0003ooooool0003o000000Go00001Oooool3o`0000Gooooo0_l0000Jooooo`;o000000?oooooo`00
0?l000006Ol000000ooooooo0000o`000002o`0000Kooooo0_l000001?oooooo0000o`000?ooool6
o`0000cooooo0_l00002ooooo`Co0000Boooool001cooooo00?o0000ooooooooool0?oooool2o`00
00?ooooo0_l00002ooooo`;o00002?ooool2o`0000Oooooo0_l00002ooooo`;o00001_ooool2o`00
00Cooooo1?l000000ooooooo0000o`000005o`0000?ooooo0ol000000ooooooo0000o`000002o`00
00Sooooo0_l000000ooooooo0000o`000002o`0001;ooooo0_l00002ooooo`;o00000oooool4o`00
00?ooooo7Ol00003ooooo`;o00003_ooool3o`0001;ooooo1?l0001;ooooo`007?ooool00ol0003o
ooooooooo`18ooooo`;o00002?ooool2o`0000Gooooo1?l00002ooooo`Co000000Coooooo`000?l0
003ooooo0_l00004ooooo`;o000000?oooooo`000?l000001ol00007ooooo`Co00000oooool2o`00
00?ooooo1Ol00008ooooo`;o00002_ooool6o`0000?ooooo1?l000000ooooooo0000o`000006o`00
0003ooooool0003o000001Ko000000Coooooo`000?l0003ooooo0ol00003ooooo`;o00007_ooool2
o`0000;ooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`0kooooo`;o00003oooool2o`00
00_ooooo1?l00004ooooo`;o000000?oooooo`000?l000002_ooool2o`000004ooooool0003o0000
o`0000Sooooo2?l000000ooooooo0000o`000004ooooo`;o00002_ooool2o`0000Gooooo0ol00004
ooooo`;o00002_ooool2o`0000Cooooo0_l00002oooooaOo000000Coooooo`000?l0003ooooo0ol0
0003ooooo`;o00004?ooool2o`0000cooooo0_l00002ooooo`;o0000AOooool001cooooo00?o0000
ooooooooool0>oooool2o`0000oooooo0_l0000=ooooo`;o00000_ooool2o`0000;ooooo0_l0000?
ooooo`;o00002?ooool2o`000004ooooool0003o0000ooooo`;o00000oooool3o`0000;ooooo0_l0
000@ooooo`?o00003?ooool2o`0000;ooooo0_l00004ooooo`;o00000_oooolFo`0001Cooooo0_l0
0007ooooo`;o0000Eoooool001cooooo00?o0000ooooooooool0D?ooool2o`0000[ooooo0_l00000
0ooooooo0000o`000002ooooo`;o00005_ooool6o`0000?ooooo0_l00002ooooo`Co00000_ooool2
o`0000gooooo0ol00007ooooo`;o00001_ooool2o`0000;ooooo0_l00004oooooaCo000000Cooooo
o`000?l0003ooooo0_l00008ooooo`;o00001oooool5o`0000Kooooo0_l0001Hooooo`007?ooool0
0ol0003oooooooooo`1@ooooo`;o00002?ooool4o`0000cooooo1?l0000<ooooo`Oo00001oooool2
o`0001?ooooo0ol00007ooooo`;o00003?ooool2o`0000;ooooo1_l000000ooooooo0000o`00000;
o`000003ooooool0003o000000?ooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l0
0004ooooo`Go00000oooool2o`000003ooooool0003o000000Gooooo0_l0001Aooooo`007?ooool0
0ol0003oooooooooo`1;ooooo`;o00003Oooool3o`0000gooooo1?l00006ooooo`;o00001?ooool3
o`000003ooooool0003o000000Cooooo1?l00008ooooo`;o00000oooool3o`0000oooooo0_l00000
0ooooooo0000o`000009ooooo`;o00000oooool5o`000003ooooool0003o000000_o00001_ooool2
o`0000;ooooo0ol00003ooooo`?o00001Oooool2o`0000Gooooo0ol00007ooooo`;o0000DOooool0
01cooooo00?o0000ooooooooool0Boooool2o`0000?ooooo0_l00009ooooo`;o00005Oooool4o`00
00Cooooo1?l00006ooooo`Co00002?ooool8o`0000[ooooo0_l000000ooooooo0000o`000003oooo
o`;o00002oooool2o`000003ooooool0003o000000Cooooo3Ol000000ooooooo0000o`000002o`00
00Gooooo0_l00004ooooo`?o00001Oooool2o`0000Kooooo0_l0001Jooooo`007?ooool00ol0003o
ooooooooo`1<ooooo`;o00000_ooool2o`0000Oooooo1?l00006ooooo`;o00003Oooool2o`0000Go
oooo0_l000001?oooooo0000o`000?l0000Cooooo`Co00003?ooool2o`000003ooooool0003o0000
00Sooooo0_l00006ooooo`;o00001ooooolBo`0000oooooo0_l0000@ooooo`;o0000E?ooool001co
oooo00?o0000ooooooooool0C?ooool2o`0000Gooooo0_l00004ooooo`Co00001_ooool2o`0000Ko
oooo0_l00006ooooo`;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000Wooooo`;o
00001?ooool2o`0000Wooooo0_l000000ooooooo0000o`000003o`0000;ooooo0ol000000ooooooo
0000o`000003ooooo`;o00003oooool2o`000003ooooool0003o0000013ooooo1?l0001Booooo`00
7?ooool00ol0003oooooooooo`1Cooooo`;o00004Oooool2o`0000?ooooo0_l00006ooooo`;o0000
0oooool4o`0000?ooooo0ol0000?ooooo`;o000000?oooooo`000?l000001oooool2o`0000[ooooo
0_l0000;ooooo`;o000000Goooooo`000?l0003o0000ooooo`07o`0000[ooooo0_l0000>ooooo`;o
00005Oooool2o`0000Sooooo0_l00018ooooo`007?ooool2o`0004oooooo0_l0000Cooooo`;o0000
00Coooooo`000?l0003o00001Oooool2o`0000Sooooo2Ol000000ooooooo0000o`000003ooooo`;o
00002?ooool7o`0000?ooooo1?l00003ooooo`;o000000?oooooo`000?l000003oooool2o`000003
ooooool0003o000000Gooooo1?l0000:ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Oo
oooo0_l000000ooooooo0000o`000003o`0001Gooooo1?l00018ooooo`007?ooool00ol0003ooooo
ooooo`1>ooooo`;o00003_ooool2o`0000?ooooo0_l00002ooooo`;o00001Oooool2o`0000_ooooo
1?l00003ooooo`Oo00002Oooool2o`0000;ooooo1ol00005ooooo`;o000000?oooooo`000?l00000
1Oooool2o`0000Sooooo0_l00005ooooo`Co00002?ooool2o`0000?ooooo0_l000000ooooooo0000
o`000004ooooo`;o00001?ooool5o`000003ooooool0003o000000?o00004oooool5o`0004Wooooo
000Looooo`03o`000?oooooooooo05?ooooo0_l00008ooooo`?o00009?ooool4o`0000?ooooo1_l0
0006ooooo`Co00004Oooool2o`0000_ooooo0_l00002ooooo`Co00002?ooool2o`0000?ooooo0_l0
000;ooooo`Go00001Oooool2o`0001Cooooo0_l000000ooooooo0000o`000019ooooo`007?ooool0
0ol0003oooooooooo`1Cooooo`?o00001?ooool2o`000003ooooool0003o000000Cooooo0_l0000?
ooooo`;o00002Oooool2o`0000Kooooo2_l00002ooooo`;o00002_ooool2o`0001;ooooo0_l00004
ooooo`;o00001Oooool2o`0000Gooooo0_l00004ooooo`?o00002oooool2o`0000Sooooo0_l0000C
ooooo`;o0000COooool001cooooo00?o0000ooooooooool0E?ooool2o`0000Cooooo0_l00007oooo
o`;o00003oooool2o`0000Wooooo0_l00006ooooo`Co00001?ooool2o`0000;ooooo0_l00002oooo
o`;o00000oooool2o`000003ooooool0003o0000017ooooo0ol0000;ooooo`?o00001?ooool2o`00
0004ooooool0003o0000ooooo`;o00002oooool5o`0000gooooo0_l0000<ooooo`;o0000COooool0
01cooooo00?o0000ooooooooool0Ooooool2o`0000cooooo0_l00007ooooo`?o000000?oooooo`00
0?l000000_l00002ooooo`;o00004?ooool3o`0000_ooooo0ol00004ooooo`;o000000?oooooo`00
0?l000003_ooool5o`0000?ooooo0_l00008ooooo`;o00000oooool2o`0005Kooooo000Looooo`03
o`000?oooooooooo04Gooooo0_l0000Pooooo`;o00002?ooool2o`0000cooooo0_l0000:ooooo`Co
00001oooool6o`0000Cooooo0ol0000@ooooo`;o00002_ooool4o`0000Cooooo0_l00007ooooo`Co
00001_ooool2o`0000Kooooo0_l0000=ooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0
AOooool2o`000003ooooool0003o000000gooooo0_l00009ooooo`;o00000oooool2o`0000Sooooo
0ol00007ooooo`;o00003_ooool2o`0000Gooooo1?l000000ooooooo0000o`000002o`0000Kooooo
1?l000000ooooooo0000o`000004ooooo`?o00002_ooool2o`0000Cooooo0_l0000:ooooo`;o0000
0oooool4o`0007Gooooo000Looooo`03o`000?oooooooooo04Sooooo0_l0000=ooooo`;o00002Ooo
ool3o`0000Oooooo0_l00004ooooo`;o00001Oooool4o`0000;ooooo0_l0000Aooooo`Co00000_oo
ool2o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l000001?ooool4o`0000?ooooo0_l0
0004ooooo`;o00002oooool2o`0000?ooooo0_l00002ooooo`;o00001Oooool4o`0000cooooo0_l0
001Qooooo`007?ooool00ol0003oooooooooo`1Eooooo`;o00002oooool3o`0000Oooooo0_l0000;
ooooo`;o00001?ooool4o`0000;ooooo0_l00007ooooo`;o00002?ooool6o`0000Cooooo0_l0000:
ooooo`Co000000?oooooo`000?l000004Oooool2o`000003ooooool0003o000000;ooooo1?l00005
ooooo`Co00003?ooool2o`00067ooooo000Looooo`03o`000?oooooooooo05Gooooo0_l00007oooo
o`;o00000_ooool2o`0000Gooooo0_l0000Fooooo`;o00000_ooool2o`0000Oooooo0_l0000:oooo
o`;o00001_ooool2o`0000cooooo0ol0000Fooooo`;o00000_ooool2o`0001Oooooo0_l0001Qoooo
o`007?ooool00ol0003oooooooooo`1Nooooo`;o00001Oooool2o`0000;ooooo0_l000000ooooooo
0000o`000002o`0000Kooooo0_l0000Mooooo`;o00001?ooool2o`0000Wooooo0_l00009ooooo`;o
0000U_ooool001cooooo00?o0000ooooooooool0IOooool2o`0000Gooooo1?l00006ooooo`;o0000
4?ooool2o`0000_ooooo0_l00004ooooo`;o00002Oooool2o`0000?ooooo0_l0002Looooo`007?oo
ool00ol0003oooooooooo`19ooooo`;o00005Oooool2o`0000_ooooo0_l0000Iooooo`;o00008Ooo
ool2o`00017ooooo0_l000000ooooooo0000o`000026ooooo`007?ooool00ol0003oooooooooo`19
ooooo`;o00005Oooool2o`0000_ooooo0_l0001>ooooo`?o000000?oooooo`000?l000001oooool4
o`0007_ooooo000Looooo`03o`000?oooooooooo05Sooooo0_l0000Booooo`;o00000_ooool2o`00
04_ooooo0_l0000;ooooo`Co00009?ooool2o`0005Gooooo000Looooo`;o0000FOooool2o`00013o
oooo1?l00002ooooo`;o0000COooool2o`0002_ooooo0_l00004ooooo`;o0000EOooool001cooooo
00?o0000ooooooooool0JOooool3o`0001;ooooo0_l00004ooooo`;o0000<oooool2o`0000Cooooo
0_l000000ooooooo0000o`000009ooooo`;o00007Oooool2o`0005_ooooo000Looooo`03o`000?oo
oooooooo05_ooooo0_l00009ooooo`;o000000?oooooo`000?l000004Oooool4o`0000Cooooo0_l0
000cooooo`;o00001?ooool5o`0000Wooooo0ol0001iooooo`007?ooool00ol0003oooooooooo`1K
ooooo`;o00002Oooool2o`000004ooooool0003o0000ooooo`;o00003_ooool2o`0000oooooo0_l0
000[ooooo`?o00000_ooool4o`0000_ooooo0_l000001?oooooo0000o`000?l0000Dooooo`;o0000
Goooool001cooooo00?o0000ooooooooool0Foooool2o`0000cooooo1Ol00005ooooo`;o00003_oo
ool2o`0000Sooooo0_l0000[ooooo`?o00005?ooool3o`0001Cooooo0_l0001Oooooo`007?ooool0
0ol0003oooooooooo`1Yooooo`Go00001Oooool2o`0000;ooooo0_l00008ooooo`Co00002_ooool4
o`0003?ooooo0_l00002ooooo`;o00001Oooool2o`0007Kooooo000Looooo`03o`000?oooooooooo
06Gooooo1?l000000ooooooo0000o`000002o`000003ooooool0003o000000Cooooo1?l00002oooo
o`?o00000oooool2o`000003ooooool0003o000000Wooooo1?l0000]ooooo`;o00000oooool3o`00
00;ooooo0_l000000ooooooo0000o`000002ooooo`;o0000M_ooool001cooooo00?o0000oooooooo
ool0IOooool4o`0000Kooooo0_l00004ooooo`;o00000oooool4o`0000Kooooo0_l0000jooooo`;o
00000oooool2o`0000Cooooo1?l0000Dooooo`;o0000I?ooool001cooooo00?o0000ooooooooool0
IOooool2o`0000Sooooo0_l00003ooooo`;o00000oooool5o`0004gooooo0ol0000Eooooo`;o0000
I?ooool001cooooo00?o0000ooooooooool0IOooool3o`0000cooooo0_l00003ooooo`;o000000?o
ooooo`000?l000005?ooool2o`0001oooooo0_l0000=ooooo`;o00001?ooool2o`0001Kooooo0_l0
001Wooooo`007?ooool00ol0003oooooooooo`1Vooooo`;o0000:_ooool2o`0001oooooo1?l0000:
ooooo`Go00000_ooool2o`0001Kooooo0_l0001Wooooo`007?ooool00ol0003oooooooooo`1coooo
o`;o00001?ooool2o`000003ooooool0003o000000[ooooo0_l00003ooooo`;o00000_ooool2o`00
02;ooooo0_l0000:ooooo`;o000000?oooooo`000?l00000Poooool001cooooo00?o0000oooooooo
ool0Loooool2o`0000Cooooo0_l000000ooooooo0000o`00000:ooooo`;o00000oooool2o`0000;o
oooo0_l0000_ooooo`;o0000QOooool001cooooo00?o0000ooooooooool0KOooool2o`0000gooooo
0_l00014ooooo`Co0000Poooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Co
oooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo06gooooo0_l00006oooo
o`?o00001?ooool2o`000003ooooool0003o000002kooooo0_l00009ooooo`Co00000oooool2o`00
0003ooooool0003o000008?ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44
ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1Zooooo`Co00001ooo
ool4o`0000Kooooo0_l00005ooooo`;o00001_ooool2o`0001oooooo0_l00009ooooo`Co00000ooo
ool2o`0008Kooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo06[ooooo1?l00009ooooo`;o00003?oo
ool7o`0000;ooooo0_l0000Aooooo`;o000000?oooooo`000?l000005?ooool2o`0000Gooooo0_l0
0026ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9So
oooooiRHV?lb<S801_ooool3o`0007Oooooo0_l00005ooooo`;o00001Oooool2o`000003ooooool0
003o000000;o00000_ooool2o`00017ooooo0_l000000ooooooo0000o`000003ooooo`;o00000ooo
ool2o`000004ooooool0003o0000o`0000[ooooo0_l000000ooooooo0000o`000026ooooo`0000?o
ooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<c<`0
1_ooool00ol0003oooooooooo`1nooooo`;o00003_ooool2o`0000;ooooo0_l0000Cooooo`Co0000
0oooool2o`000004ooooool0003o0000o`0000[ooooo0_l0000Jooooo`;o0000KOooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00Ko
oooo00?o0000ooooooooool0Poooool2o`0000Wooooo0_l000001?oooooo0000o`000?l00009oooo
o`;o00000_ooool2o`0000?ooooo0ol00004ooooo`?o00004Oooool2o`0001Oooooo0_l0001]oooo
o`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l000001_oo
ool00ol0003oooooooooo`23ooooo`;o00002Oooool2o`000003ooooool0003o000000[ooooo0_l0
00001?oooooo0000o`000?l00003ooooo`;o00000_ooool2o`000003ooooool0003o000000Oooooo
0ol00005ooooo`;o000000?oooooo`000?l00000Q_ooool00006ooooooo^k^ko<S8bo`000?lb<S;o
k^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0QOooool2o`00
00Oooooo1Ol00009ooooo`Ko00002?ooool2o`0000[ooooo0ol00005ooooo`;o00004_ooool2o`00
07Gooooo000Looooo`03o`000?oooooooooo07oooooo0_l00004ooooo`?o00001Oooool5o`0000[o
oooo1?l0000:ooooo`;o00000_ooool5o`0000?ooooo0_l00006ooooo`;o00004_ooool2o`0007Go
oooo000Looooo`03o`000?oooooooooo07oooooo0_l00005ooooo`?o00001?ooool2o`0001oooooo
1Ol0000;ooooo`;o0000ROooool001cooooo00?o0000ooooooooool0Loooool2o`0001;ooooo0_l0
0004ooooo`;o00007?ooool2o`0000;ooooo0_l0000;ooooo`;o0000Roooool001cooooo00?o0000
ooooooooool0Loooool2o`0001Sooooo0_l0000Looooo`;o00000_ooool2o`0000Gooooo0_l00004
ooooo`;o00001oooool2o`0000Kooooo0_l0001jooooo`007?ooool00ol0003oooooooooo`2foooo
o`;o00003?ooool3o`0000?ooooo0_l000000ooooooo0000o`00001jooooo`007?ooool00ol0003o
ooooooooo`2Qooooo`;o00001Oooool2o`0001Oooooo0_l000000ooooooo0000o`000004ooooo`;o
0000OOooool001cooooo00?o0000ooooooooool0Roooool2o`0001Cooooo0_l00005ooooo`;o0000
3oooool2o`0000Kooooo0_l00026ooooo`007?ooool00ol0003oooooooooo`2;ooooo`?o00003Ooo
ool3o`0001Kooooo0_l00003ooooo`;o00001_ooool2o`0008Kooooo000Looooo`03o`000?oooooo
oooo08cooooo0_l0000=ooooo`?o00001?ooool4o`0000kooooo0_l0000;ooooo`;o0000Q_ooool0
01cooooo00?o0000ooooooooool0X_ooool4o`000:?ooooo000Looooo`03o`000?oooooooooo083o
oooo0_l0000Aooooo`;o00001_ooool2o`000003ooooool0003o000001Oooooo0_l0002@ooooo`00
7?ooool2o`00087ooooo0_l0000Aooooo`;o00001_ooool2o`000004ooooool0003o0000ooooo`;o
00005?ooool2o`00093ooooo000Looooo`03o`000?oooooooooo0:7ooooo1_l0002Rooooo`007?oo
ool00ol0003oooooooooo`2Jooooo`;o00001oooool4o`000:;ooooo000Looooo`03o`000?oooooo
oooo09[ooooo0_l0000;ooooo`;o00008Oooool2o`0007gooooo000Looooo`03o`000?oooooooooo
0:Oooooo0_l0000Qooooo`;o0000OOooool001cooooo00?o0000ooooooooool0T_ooool2o`000;Go
oooo000Looooo`03o`000?oooooooooo09;ooooo0_l0000jooooo`;o0000NOooool001cooooo00?o
0000ooooooooool0U?ooool2o`0003Sooooo0_l0001iooooo`007?ooool00ol0003oooooooooo`2D
ooooo`;o0000<_ooool2o`0007oooooo000Looooo`03o`000?oooooooooo0<Sooooo0_l0001ooooo
o`007?ooool00ol0003oooooooooo`2Qooooo`;o0000Y_ooool001cooooo00?o0000ooooooooool0
X?ooool3o`000:Kooooo000Looooo`03o`000?oooooooooo0:3ooooo0ol0002Vooooo`007?ooool0
0ol0003oooooooooo`2Qooooo`;o00004oooool2o`00097ooooo000Looooo`03o`000?oooooooooo
0;Kooooo0_l0002Aooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000
oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo
00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool0
01Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;o
oooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooo
oomBooooo`004_ooool00omEEEGoIVIVo`00003ooooooeCooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo002Uooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool0
5Oooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o000000?o410@ooooooooool0S_ooool00:Kooooo00Go0000ooooooooooooooooo`000009oooo
o`Ko00002Oooool01OlQ8B7oV9RHoooooonHV9So8B4Q00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`06ooooo`03o`000?oooooooooo08oooooo002Vooooo`05o`000?ooooooooooooooool000006?oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@4003ooooo`Go
0000T?ooool00:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00002Oooool01Olb<S;o
V9RHoooooonHV9So<S8b00?ooooo00Go0000ooooooooooooooooo`000003ooooo`04odA4A?oMgMgo
ooooo`00097ooooo002Vooooo`05o`000?n7QhOoooooojVYZOl000006?ooool01Oo<c<co0000o`00
0?l0003oc<c<00?ooooo00Go0000ooooooooooooooooo`000003ooooo`04omgMgOmEEEGoooooo`00
097ooooo002Uooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool05_ooool01Ol@413o
^[Zjoooooonj^[[o410@00?ooooo00Go410@oooooooooooooooooa0@4004ooooo`03ogMgMoo<c<co
0000097ooooo0033ooooo`05o`000?nj^[[ooooookZj^_l000000oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Cooooo00?ok^k^odA4A?l00000TOooool00<?ooooo00GoZJVYoa0@4?l0003o410@ojVY
Z@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00omgMgOo0000ooooo`2@ooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(810) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.57377 .68985 Mdot
.57346 .67109 Mdot
.58578 .31758 Mdot
.40472 .53786 Mdot
.47113 .49886 Mdot
.54076 .32265 Mdot
.64238 .49569 Mdot
.65007 .51222 Mdot
.53346 .34104 Mdot
.35458 .67564 Mdot
.63761 .46081 Mdot
.442 .52733 Mdot
.6304 .49099 Mdot
.37814 .56689 Mdot
.5676 .16949 Mdot
.4458 .56252 Mdot
.62283 .65064 Mdot
.41012 .40093 Mdot
.34736 .52664 Mdot
.5643 .36741 Mdot
.61204 .61484 Mdot
.37508 .56971 Mdot
.58378 .69264 Mdot
.37875 .56813 Mdot
.41987 .55614 Mdot
.59572 .65826 Mdot
.6293 .68673 Mdot
.42973 .58583 Mdot
.39921 .56295 Mdot
.66111 .46693 Mdot
.41086 .44081 Mdot
.42168 .17479 Mdot
.44657 .55033 Mdot
.36184 .77726 Mdot
.6508 .50757 Mdot
.2085 .42016 Mdot
.54988 .35812 Mdot
.61 .47739 Mdot
.65309 .50861 Mdot
.61904 .51261 Mdot
.61197 .48399 Mdot
.59017 .65444 Mdot
.59521 .50829 Mdot
.59096 .44722 Mdot
.39632 .5298 Mdot
.71319 .57455 Mdot
.28716 .35509 Mdot
.41765 .59715 Mdot
.56102 .65396 Mdot
.54949 .37119 Mdot
.49975 .83467 Mdot
.62444 .52238 Mdot
.73231 .38388 Mdot
.44284 .09258 Mdot
.61715 .49785 Mdot
.40922 .53406 Mdot
.55464 .34035 Mdot
.37565 .59643 Mdot
.38339 .58122 Mdot
.50452 .81118 Mdot
.42077 .57647 Mdot
.40541 .3833 Mdot
.56314 .61634 Mdot
.55162 .29675 Mdot
.53695 .33067 Mdot
.66348 .49181 Mdot
.60538 .63734 Mdot
.63593 .48384 Mdot
.37111 .64272 Mdot
.53328 .36119 Mdot
.41751 .59843 Mdot
.63107 .46008 Mdot
.55059 .64254 Mdot
.36345 .60929 Mdot
.73368 .59738 Mdot
.63818 .205 Mdot
.40905 .40624 Mdot
.48489 .79625 Mdot
.59832 .74695 Mdot
.66855 .25378 Mdot
.39037 .56704 Mdot
.86657 .51291 Mdot
.58417 .17622 Mdot
.58433 .69015 Mdot
.4463 .49761 Mdot
.49641 .35373 Mdot
.35293 .57958 Mdot
.46584 .45364 Mdot
.39785 .64455 Mdot
.71722 .67839 Mdot
.53563 .34578 Mdot
.58141 .64399 Mdot
.39979 .53766 Mdot
.40435 .62662 Mdot
.47103 .72649 Mdot
.36928 .62685 Mdot
.435 .58127 Mdot
.6351 .65636 Mdot
.65793 .47659 Mdot
.45238 .62121 Mdot
.58278 .50223 Mdot
.72729 .36904 Mdot
.36318 .54514 Mdot
.52307 .34423 Mdot
.6142 .63042 Mdot
.35638 .54663 Mdot
.6258 .50762 Mdot
.40871 .57947 Mdot
.58611 .48642 Mdot
.56778 .66912 Mdot
.39886 .62679 Mdot
.40637 .39912 Mdot
.77141 .61007 Mdot
.59215 .64046 Mdot
.82781 .47237 Mdot
.41962 .5856 Mdot
.37187 .57536 Mdot
.57482 .66881 Mdot
.56917 .31968 Mdot
.45473 .43775 Mdot
.58385 .62809 Mdot
.63293 .51425 Mdot
.61041 .69952 Mdot
.33009 .57764 Mdot
.53073 .32235 Mdot
.72972 .36298 Mdot
.75449 .3586 Mdot
.26305 .52661 Mdot
.35299 .57004 Mdot
.66548 .55202 Mdot
.55082 .31681 Mdot
.5783 .65053 Mdot
.63303 .4826 Mdot
.43756 .55695 Mdot
.62018 .66835 Mdot
.62875 .4689 Mdot
.39776 .39348 Mdot
.37139 .28509 Mdot
.56448 .63925 Mdot
.5822 .55844 Mdot
.62524 .44377 Mdot
.617 .51085 Mdot
.39818 .80999 Mdot
.57656 .67492 Mdot
.40723 .35585 Mdot
.63337 .47065 Mdot
.33601 .41659 Mdot
.43885 .56919 Mdot
.25921 .57979 Mdot
.81064 .63578 Mdot
.48386 .84059 Mdot
.75808 .46638 Mdot
.42832 .36102 Mdot
.60551 .503 Mdot
.40348 .55005 Mdot
.58492 .67665 Mdot
.58628 .66642 Mdot
.4265 .61787 Mdot
.42714 .5634 Mdot
.40789 .61578 Mdot
.41354 .6217 Mdot
.31811 .32742 Mdot
.4112 .61787 Mdot
.59234 .37341 Mdot
.60642 .64608 Mdot
.41616 .56264 Mdot
.57832 .32748 Mdot
.42096 .52443 Mdot
.61736 .47023 Mdot
.37829 .58385 Mdot
.42537 .55287 Mdot
.34637 .59116 Mdot
.60842 .49092 Mdot
.36341 .21849 Mdot
.80106 .63457 Mdot
.23077 .33667 Mdot
.78673 .47357 Mdot
.56228 .32999 Mdot
.35811 .57248 Mdot
.39843 .36983 Mdot
.4698 .6427 Mdot
.39039 .58106 Mdot
.56741 .82625 Mdot
.43286 .56777 Mdot
.32314 .72609 Mdot
.31428 .56882 Mdot
.22927 .32696 Mdot
.52589 .41799 Mdot
.40475 .56671 Mdot
.44889 .69988 Mdot
.26561 .65788 Mdot
.5127 .58294 Mdot
.61338 .48992 Mdot
.57573 .32175 Mdot
.55205 .34927 Mdot
.59431 .48614 Mdot
.43248 .64158 Mdot
.32773 .65273 Mdot
.46106 .61736 Mdot
.73617 .36201 Mdot
.55125 .6374 Mdot
.39301 .34845 Mdot
.55521 .64934 Mdot
.85324 .42761 Mdot
.69462 .68099 Mdot
.63751 .43866 Mdot
.43804 .37947 Mdot
.58218 .3141 Mdot
.739 .35936 Mdot
.40145 .36327 Mdot
.40565 .60108 Mdot
.56463 .64912 Mdot
.28399 .70225 Mdot
.31985 .55828 Mdot
.22214 .65354 Mdot
.61237 .68998 Mdot
.4965 .43741 Mdot
.6208 .47968 Mdot
.5639 .37384 Mdot
.36695 .55759 Mdot
.39207 .6162 Mdot
.59156 .61495 Mdot
.41584 .59519 Mdot
.55234 .71242 Mdot
.4256 .5502 Mdot
.50157 .3519 Mdot
.38095 .40269 Mdot
.59791 .4997 Mdot
.26301 .53525 Mdot
.55029 .67268 Mdot
.59926 .28098 Mdot
.55767 .36595 Mdot
.40693 .67936 Mdot
.6377 .45929 Mdot
.407 .39739 Mdot
.5712 .35495 Mdot
.41909 .34318 Mdot
.349 .55673 Mdot
.5474 .35972 Mdot
.40624 .3491 Mdot
.34412 .27326 Mdot
.40857 .53038 Mdot
.32685 .3546 Mdot
.64564 .48924 Mdot
.60417 .70293 Mdot
.42083 .57514 Mdot
.75442 .35549 Mdot
.35625 .53519 Mdot
.70285 .41917 Mdot
.74056 .38192 Mdot
.72696 .38114 Mdot
.6356 .22846 Mdot
.42387 .3858 Mdot
.75799 .51955 Mdot
.62147 .58187 Mdot
.60639 .63697 Mdot
.39688 .53462 Mdot
.29176 .25304 Mdot
.63229 .47113 Mdot
.40296 .5996 Mdot
.49853 .35372 Mdot
.63591 .47186 Mdot
.37087 .5974 Mdot
.60933 .49935 Mdot
.58418 .67212 Mdot
.54791 .25901 Mdot
.62797 .66969 Mdot
.4157 .53481 Mdot
.63219 .50585 Mdot
.56836 .34929 Mdot
.59727 .66164 Mdot
.40605 .58127 Mdot
.36539 .56532 Mdot
.74045 .36692 Mdot
.40933 .56286 Mdot
.29903 .25409 Mdot
.42607 .59173 Mdot
.57123 .29945 Mdot
.37682 .63449 Mdot
.49509 .85394 Mdot
.39318 .2837 Mdot
.59323 .63423 Mdot
.73298 .38194 Mdot
.53876 .34157 Mdot
.52595 .25456 Mdot
.54155 .56611 Mdot
.39817 .57292 Mdot
.73704 .37702 Mdot
.47606 .41707 Mdot
.66567 .48499 Mdot
.35449 .61537 Mdot
.71325 .65644 Mdot
.57457 .35595 Mdot
.73913 .36147 Mdot
.3892 .50079 Mdot
.61548 .63106 Mdot
.40827 .53903 Mdot
.55844 .35992 Mdot
.61028 .70028 Mdot
.39734 .52106 Mdot
.24833 .39877 Mdot
.75316 .37072 Mdot
.64465 .48849 Mdot
.31258 .62434 Mdot
.41376 .61261 Mdot
.56009 .34703 Mdot
.59521 .69207 Mdot
.65102 .50385 Mdot
.59815 .6508 Mdot
.26903 .67473 Mdot
.78994 .49066 Mdot
.29965 .32467 Mdot
.43673 .38332 Mdot
.70357 .40555 Mdot
.21489 .3577 Mdot
.77213 .53317 Mdot
.29587 .45872 Mdot
.16109 .47827 Mdot
.57696 .33849 Mdot
.35106 .36999 Mdot
.54427 .33948 Mdot
.3904 .54648 Mdot
.53763 .3259 Mdot
.22841 .3206 Mdot
.43432 .56887 Mdot
.56178 .3341 Mdot
.47064 .30987 Mdot
.42603 .56969 Mdot
.59867 .64058 Mdot
.53287 .17704 Mdot
.72848 .70256 Mdot
.66414 .70669 Mdot
.56717 .32583 Mdot
.58279 .78006 Mdot
.42887 .58138 Mdot
.43325 .53283 Mdot
.5895 .67699 Mdot
.37031 .63281 Mdot
.38603 .35861 Mdot
.42247 .34247 Mdot
.2661 .56317 Mdot
.8303 .52749 Mdot
.43686 .64442 Mdot
.59593 .66507 Mdot
.55284 .72354 Mdot
.73009 .59803 Mdot
.73855 .34815 Mdot
.66514 .45847 Mdot
.37331 .2167 Mdot
.39141 .65954 Mdot
.58163 .56196 Mdot
.72104 .64188 Mdot
.56957 .64988 Mdot
.32204 .26768 Mdot
.619 .49614 Mdot
.48767 .68038 Mdot
.37801 .75002 Mdot
.40096 .61193 Mdot
.65174 .46276 Mdot
.45988 .57257 Mdot
.69769 .71018 Mdot
.34592 .40027 Mdot
.75296 .31353 Mdot
.40383 .52992 Mdot
.75509 .53336 Mdot
.37499 .57832 Mdot
.30072 .51226 Mdot
.42674 .59443 Mdot
.60349 .65471 Mdot
.46771 .61951 Mdot
.49776 .48892 Mdot
.82851 .57687 Mdot
.68916 .69458 Mdot
.42765 .35595 Mdot
.36744 .56759 Mdot
.39788 .61331 Mdot
.42371 .37653 Mdot
.60586 .67181 Mdot
.42526 .59884 Mdot
.23744 .47718 Mdot
.40851 .6129 Mdot
.61416 .47183 Mdot
.42472 .43765 Mdot
.64188 .70724 Mdot
.37917 .62425 Mdot
.63072 .66866 Mdot
.61256 .49856 Mdot
.66109 .50236 Mdot
.34596 .6313 Mdot
.60535 .49936 Mdot
.41165 .53944 Mdot
.43445 .41936 Mdot
.57637 .68636 Mdot
.34847 .50693 Mdot
.60853 .67505 Mdot
.59982 .76015 Mdot
.6128 .50413 Mdot
.74383 .35219 Mdot
.54261 .59641 Mdot
.62559 .49687 Mdot
.64999 .74098 Mdot
.42595 .65571 Mdot
.36569 .52279 Mdot
.68178 .73171 Mdot
.57234 .33208 Mdot
.7397 .35485 Mdot
.6328 .50818 Mdot
.4115 .61468 Mdot
.33854 .57445 Mdot
.62261 .45825 Mdot
.50006 .73666 Mdot
.51153 .26185 Mdot
.43218 .5858 Mdot
.60596 .66013 Mdot
.58111 .6493 Mdot
.3886 .52085 Mdot
.40014 .58347 Mdot
.5718 .30199 Mdot
.74706 .37386 Mdot
.72276 .36372 Mdot
.75268 .35746 Mdot
.55139 .37984 Mdot
.71797 .48279 Mdot
.61763 .51187 Mdot
.69206 .54612 Mdot
.65973 .40775 Mdot
.32083 .58845 Mdot
.56396 .34602 Mdot
.3787 .61105 Mdot
.3776 .54535 Mdot
.65124 .50271 Mdot
.7651 .42551 Mdot
.41219 .4907 Mdot
.55933 .6673 Mdot
.60369 .4951 Mdot
.3781 .6663 Mdot
.6631 .43379 Mdot
.38946 .35755 Mdot
.66265 .71725 Mdot
.64687 .45958 Mdot
.57854 .64072 Mdot
.61697 .45876 Mdot
.40155 .61415 Mdot
.43754 .60318 Mdot
.57043 .66407 Mdot
.42673 .38336 Mdot
.3362 .58303 Mdot
.36965 .59551 Mdot
.60828 .84197 Mdot
.73648 .59242 Mdot
.67626 .50111 Mdot
.40057 .5561 Mdot
.3404 .54096 Mdot
.43229 .35954 Mdot
.40956 .60985 Mdot
.364 .55953 Mdot
.77643 .6121 Mdot
.60681 .53144 Mdot
.38442 .39776 Mdot
.48834 .6768 Mdot
.6142 .68768 Mdot
.32793 .23796 Mdot
.7261 .37112 Mdot
.60625 .52377 Mdot
.55018 .26019 Mdot
.74663 .3588 Mdot
.67924 .40642 Mdot
.32647 .25251 Mdot
.74869 .35532 Mdot
.56906 .27099 Mdot
.46942 .53949 Mdot
.43493 .59609 Mdot
.37504 .58576 Mdot
.39493 .37082 Mdot
.57878 .67537 Mdot
.50849 .42395 Mdot
.37922 .2541 Mdot
.37392 .57158 Mdot
.55049 .61386 Mdot
.3685 .23825 Mdot
.7425 .36398 Mdot
.40483 .38808 Mdot
.38283 .35691 Mdot
.37141 .57798 Mdot
.78619 .56967 Mdot
.59506 .6601 Mdot
.40558 .58111 Mdot
.39039 .62369 Mdot
.56819 .32905 Mdot
.57191 .64146 Mdot
.55502 .36614 Mdot
.7454 .37954 Mdot
.1868 .54661 Mdot
.58066 .84882 Mdot
.65413 .49328 Mdot
.25355 .32026 Mdot
.65944 .50965 Mdot
.7057 .26586 Mdot
.75366 .36218 Mdot
.39114 .57572 Mdot
.54679 .66116 Mdot
.41029 .58092 Mdot
.39763 .60476 Mdot
.40524 .60288 Mdot
.44544 .63968 Mdot
.55966 .83002 Mdot
.41072 .36728 Mdot
.32444 .57627 Mdot
.54461 .30573 Mdot
.28035 .28365 Mdot
.53138 .18985 Mdot
.37028 .60942 Mdot
.36762 .57676 Mdot
.61447 .65 Mdot
.41856 .62597 Mdot
.66296 .4669 Mdot
.5911 .69367 Mdot
.33923 .56782 Mdot
.31111 .28177 Mdot
.42354 .60385 Mdot
.21294 .36722 Mdot
.6179 .45868 Mdot
.65934 .71816 Mdot
.32636 .58807 Mdot
.74863 .3543 Mdot
.7406 .35466 Mdot
.72569 .35151 Mdot
.65476 .45615 Mdot
.56194 .34034 Mdot
.48454 .21308 Mdot
.45171 .60918 Mdot
.40742 .54933 Mdot
.33854 .54512 Mdot
.57804 .36896 Mdot
.44506 .45386 Mdot
.75484 .48493 Mdot
.39366 .66443 Mdot
.56026 .30396 Mdot
.59628 .70521 Mdot
.82488 .42765 Mdot
.59188 .69291 Mdot
.3836 .39819 Mdot
.62827 .46367 Mdot
.38593 .36443 Mdot
.58073 .80016 Mdot
.57022 .67045 Mdot
.59468 .61602 Mdot
.56274 .33174 Mdot
.52343 .44788 Mdot
.35248 .15329 Mdot
.51881 .34607 Mdot
.25586 .48899 Mdot
.59376 .67557 Mdot
.36655 .61689 Mdot
.4693 .41417 Mdot
.51896 .45154 Mdot
.55225 .33107 Mdot
.38442 .56421 Mdot
.82042 .55111 Mdot
.57404 .30307 Mdot
.35036 .60942 Mdot
.55954 .31348 Mdot
.61502 .4777 Mdot
.55539 .31578 Mdot
.56564 .69088 Mdot
.3558 .55142 Mdot
.41278 .11396 Mdot
.56954 .44935 Mdot
.41774 .57651 Mdot
.60383 .49515 Mdot
.2243 .48471 Mdot
.38831 .60552 Mdot
.38344 .36516 Mdot
.53663 .3154 Mdot
.49072 .26346 Mdot
.42713 .5815 Mdot
.55083 .32257 Mdot
.56886 .68913 Mdot
.64512 .52615 Mdot
.64788 .22712 Mdot
.7295 .35738 Mdot
.58339 .68135 Mdot
.71138 .37669 Mdot
.63694 .44518 Mdot
.34829 .59994 Mdot
.39825 .62252 Mdot
.60652 .65072 Mdot
.65139 .28609 Mdot
.40608 .63256 Mdot
.39022 .56708 Mdot
.58504 .32533 Mdot
.5936 .32732 Mdot
.61574 .2593 Mdot
.57595 .3393 Mdot
.33605 .54728 Mdot
.60554 .65051 Mdot
.38513 .54285 Mdot
.59793 .63879 Mdot
.39744 .53512 Mdot
.54576 .68935 Mdot
.5856 .68898 Mdot
.80845 .49927 Mdot
.37963 .55228 Mdot
.3087 .59524 Mdot
.40138 .60536 Mdot
.41539 .60319 Mdot
.52605 .32302 Mdot
.41936 .374 Mdot
.40818 .64263 Mdot
.60218 .29484 Mdot
.3997 .38978 Mdot
.28626 .68048 Mdot
.56943 .32767 Mdot
.39141 .37158 Mdot
.32865 .33392 Mdot
.72992 .38088 Mdot
.40475 .37281 Mdot
.51728 .19191 Mdot
.6534 .49661 Mdot
.60499 .69844 Mdot
.42561 .56851 Mdot
.16628 .51879 Mdot
.4112 .43629 Mdot
.74183 .37162 Mdot
.42254 .58373 Mdot
.38106 .60976 Mdot
.61518 .63445 Mdot
.86356 .46358 Mdot
.58842 .32026 Mdot
.4005 .54298 Mdot
.62498 .65724 Mdot
.82663 .61408 Mdot
.52202 .33183 Mdot
.40084 .37318 Mdot
.61344 .46733 Mdot
.62858 .70082 Mdot
.72921 .35685 Mdot
.66635 .48563 Mdot
.51073 .29208 Mdot
.60311 .78738 Mdot
.42176 .59019 Mdot
.55991 .3522 Mdot
.49085 .84139 Mdot
.44164 .63489 Mdot
.6588 .53648 Mdot
.27955 .61543 Mdot
.57205 .64734 Mdot
.61825 .46257 Mdot
.4093 .34393 Mdot
.58534 .69525 Mdot
.60526 .66965 Mdot
.6444 .51492 Mdot
.53475 .38888 Mdot
.4992 .43974 Mdot
.62149 .46286 Mdot
.7262 .66999 Mdot
.28369 .69521 Mdot
.74011 .37735 Mdot
.41196 .38903 Mdot
.3062 .7428 Mdot
.591 .6539 Mdot
.3711 .21742 Mdot
.54169 .8305 Mdot
.43492 .58146 Mdot
.39866 .35397 Mdot
.68229 .42829 Mdot
.46553 .21218 Mdot
.63991 .4735 Mdot
.46551 .46845 Mdot
.37973 .37708 Mdot
.43112 .59783 Mdot
.65738 .68297 Mdot
.38542 .55448 Mdot
.62283 .47008 Mdot
.61443 .74239 Mdot
.58107 .63928 Mdot
.63032 .44622 Mdot
.65673 .73394 Mdot
.37515 .5459 Mdot
.38211 .55778 Mdot
.32533 .47668 Mdot
.56345 .64985 Mdot
.72427 .3601 Mdot
.40593 .57436 Mdot
.37558 .59372 Mdot
.35245 .60505 Mdot
.34456 .65435 Mdot
.77401 .58159 Mdot
.39694 .54296 Mdot
.53255 .37418 Mdot
.40305 .51526 Mdot
.37825 .55635 Mdot
.62735 .65673 Mdot
.58619 .83922 Mdot
.75827 .36425 Mdot
.3781 .5872 Mdot
.42375 .59702 Mdot
.64651 .51144 Mdot
.4874 .42594 Mdot
.52201 .45736 Mdot
.52703 .35509 Mdot
.30857 .43159 Mdot
.4493 .63406 Mdot
.61846 .67562 Mdot
.39831 .39783 Mdot
.34873 .57972 Mdot
.62202 .66546 Mdot
.43315 .53906 Mdot
.56968 .30353 Mdot
.74386 .37534 Mdot
.66074 .64057 Mdot
.40504 .37884 Mdot
.49036 .39019 Mdot
.68095 .57261 Mdot
.57761 .32277 Mdot
.41311 .55241 Mdot
.62947 .52673 Mdot
.53972 .36032 Mdot
.73928 .36871 Mdot
.374 .50209 Mdot
.58901 .66676 Mdot
.58675 .64162 Mdot
.27333 .54722 Mdot
.57991 .29014 Mdot
.72981 .74212 Mdot
.61589 .47649 Mdot
.35229 .5445 Mdot
.63289 .57156 Mdot
.58866 .64087 Mdot
.27022 .54569 Mdot
.39167 .37352 Mdot
.6417 .47492 Mdot
.74409 .34531 Mdot
.62038 .65979 Mdot
.56383 .64267 Mdot
.40001 .52717 Mdot
.36008 .59171 Mdot
.28759 .4666 Mdot
.26526 .56067 Mdot
.60982 .49058 Mdot
.41948 .3857 Mdot
.53725 .3667 Mdot
.39087 .54992 Mdot
.584 .69086 Mdot
.31394 .71519 Mdot
.41819 .61299 Mdot
.57329 .30196 Mdot
.5711 .65184 Mdot
.42455 .37837 Mdot
.38709 .37969 Mdot
.41499 .60343 Mdot
.50159 .80344 Mdot
.63107 .50047 Mdot
.59316 .63982 Mdot
.60758 .60327 Mdot
.39501 .63675 Mdot
.3581 .58513 Mdot
.4227 .50846 Mdot
.6647 .49055 Mdot
.66321 .67462 Mdot
.39763 .40166 Mdot
.58286 .6623 Mdot
.41565 .57775 Mdot
.40492 .38299 Mdot
.62128 .60031 Mdot
.75026 .36296 Mdot
.55533 .31378 Mdot
.38524 .35839 Mdot
.42068 .3592 Mdot
.40103 .39246 Mdot
.38857 .20628 Mdot
.5528 .63723 Mdot
.53629 .70296 Mdot
.42763 .59521 Mdot
.27724 .54186 Mdot
.43807 .61405 Mdot
.64888 .45231 Mdot
.5737 .33645 Mdot
.39731 .6077 Mdot
.39812 .52695 Mdot
.29683 .61578 Mdot
.34279 .64813 Mdot
.59247 .6093 Mdot
.5647 .65967 Mdot
.3249 .63183 Mdot
.57004 .33385 Mdot
.87755 .49935 Mdot
.28129 .2357 Mdot
.33192 .60213 Mdot
.50582 .43218 Mdot
.58706 .69188 Mdot
.63837 .51761 Mdot
.52064 .46833 Mdot
.606 .47223 Mdot
.58021 .6587 Mdot
.39106 .54801 Mdot
.69537 .54603 Mdot
.43352 .35446 Mdot
.40681 .61755 Mdot
.62405 .47685 Mdot
.4075 .61667 Mdot
.64803 .4556 Mdot
.52232 .65647 Mdot
.72788 .64444 Mdot
.43334 .56951 Mdot
.38133 .63256 Mdot
.30173 .61366 Mdot
.36839 .60666 Mdot
.69663 .34085 Mdot
.60172 .68126 Mdot
.82553 .53631 Mdot
.39708 .52231 Mdot
.53417 .78376 Mdot
.42623 .60693 Mdot
.65283 .30374 Mdot
.3569 .59141 Mdot
.52434 .49845 Mdot
.43448 .59061 Mdot
.36087 .56795 Mdot
.62781 .50563 Mdot
.64651 .51179 Mdot
.56431 .68208 Mdot
.72664 .35684 Mdot
.23716 .32115 Mdot
.36447 .59178 Mdot
.5351 .37745 Mdot
.60981 .55647 Mdot
.4221 .36526 Mdot
.58255 .65634 Mdot
.82915 .62711 Mdot
.61096 .49988 Mdot
.51385 .32387 Mdot
.66537 .30428 Mdot
.56491 .37096 Mdot
.58782 .51362 Mdot
.39811 .67071 Mdot
.42774 .37633 Mdot
.4289 .60361 Mdot
.36944 .78018 Mdot
.74129 .56332 Mdot
.334 .5774 Mdot
.61103 .4582 Mdot
.4853 .63193 Mdot
.31297 .74414 Mdot
.39677 .34204 Mdot
.41804 .34864 Mdot
.62294 .50392 Mdot
.5846 .34038 Mdot
.46388 .59858 Mdot
.39062 .37254 Mdot
.57225 .31089 Mdot
.72005 .36056 Mdot
.5288 .55951 Mdot
.59248 .65856 Mdot
.6666 .69728 Mdot
.69109 .60155 Mdot
.60988 .49236 Mdot
.59576 .28316 Mdot
.61433 .70559 Mdot
.60274 .62349 Mdot
.73577 .35189 Mdot
.52649 .32177 Mdot
.5446 .6556 Mdot
.33933 .5879 Mdot
.31413 .5816 Mdot
.37618 .57743 Mdot
.39643 .36188 Mdot
.36598 .60797 Mdot
.5396 .31015 Mdot
.63575 .47492 Mdot
.53633 .35187 Mdot
.63638 .50204 Mdot
.71808 .51908 Mdot
.40555 .58677 Mdot
.36209 .57257 Mdot
.44641 .41512 Mdot
.55645 .65383 Mdot
.54017 .81818 Mdot
.53256 .37752 Mdot
.55043 .34078 Mdot
.37561 .54225 Mdot
.57233 .69235 Mdot
.36912 .38743 Mdot
.45926 .40128 Mdot
.37771 .61967 Mdot
.60142 .68233 Mdot
.40382 .54536 Mdot
.32994 .30833 Mdot
.73739 .62816 Mdot
.59648 .64818 Mdot
.8413 .53037 Mdot
.39529 .557 Mdot
.47872 .55065 Mdot
.33982 .54074 Mdot
.25493 .45352 Mdot
.38994 .63797 Mdot
.61093 .69139 Mdot
.37948 .58247 Mdot
.60049 .69031 Mdot
.58278 .32729 Mdot
.62521 .51794 Mdot
.58591 .68268 Mdot
.37135 .61817 Mdot
.38763 .18882 Mdot
.61849 .47738 Mdot
.36736 .56547 Mdot
.65323 .47091 Mdot
.6247 .6739 Mdot
.55972 .65872 Mdot
.52558 .19821 Mdot
.65631 .52653 Mdot
.61454 .48219 Mdot
.41088 .54379 Mdot
.67496 .62115 Mdot
.38759 .54338 Mdot
.2828 .47693 Mdot
.37985 .53066 Mdot
.38003 .63689 Mdot
.68635 .22365 Mdot
.64686 .52109 Mdot
.74442 .72236 Mdot
.37213 .26064 Mdot
.40702 .19443 Mdot
.62879 .70786 Mdot
.39642 .34216 Mdot
.33019 .25864 Mdot
.74233 .381 Mdot
.54601 .31299 Mdot
.39845 .60807 Mdot
.59634 .72602 Mdot
.61173 .47319 Mdot
.41863 .36927 Mdot
.43309 .56779 Mdot
.56568 .30026 Mdot
.57073 .22234 Mdot
.60492 .50082 Mdot
.5893 .6545 Mdot
.55761 .65977 Mdot
.8173 .61952 Mdot
.41844 .58041 Mdot
.36579 .57102 Mdot
.62753 .46479 Mdot
.41841 .64659 Mdot
.41576 .39362 Mdot
.43774 .30956 Mdot
.61501 .48404 Mdot
.57249 .46374 Mdot
.56832 .67199 Mdot
.38074 .61076 Mdot
.43366 .45281 Mdot
.61574 .37491 Mdot
.39353 .6951 Mdot
.39627 .36955 Mdot
.30193 .46977 Mdot
.61144 .691 Mdot
.63039 .47989 Mdot
.34923 .33141 Mdot
.35691 .53637 Mdot
.37847 .60618 Mdot
.30511 .47075 Mdot
.48431 .42008 Mdot
.36826 .36718 Mdot
.42128 .62562 Mdot
.47597 .42242 Mdot
.37161 .54272 Mdot
.33916 .57152 Mdot
.35944 .63537 Mdot
.35462 .57364 Mdot
.59841 .68632 Mdot
.29761 .62278 Mdot
.54916 .31883 Mdot
.47452 .71968 Mdot
.4782 .46885 Mdot
.41635 .56843 Mdot
.38775 .54731 Mdot
.41489 .68328 Mdot
.58083 .50651 Mdot
.5997 .6784 Mdot
.54329 .64047 Mdot
.61901 .50814 Mdot
.31044 .58541 Mdot
.58332 .35699 Mdot
.28254 .6133 Mdot
.53322 .3497 Mdot
.6023 .6829 Mdot
.55476 .34478 Mdot
.62562 .51096 Mdot
.55929 .35299 Mdot
.5482 .37955 Mdot
.63031 .45465 Mdot
.56842 .6766 Mdot
.37551 .61714 Mdot
.61204 .50482 Mdot
.32025 .47859 Mdot
.39535 .36269 Mdot
.52544 .19785 Mdot
.41077 .516 Mdot
.38844 .47553 Mdot
.24973 .39708 Mdot
.54044 .35199 Mdot
.74962 .6271 Mdot
.58526 .68859 Mdot
.43234 .38559 Mdot
.59769 .68842 Mdot
.56473 .82006 Mdot
.42062 .37885 Mdot
.51444 .19173 Mdot
.42842 .32746 Mdot
.51974 .23414 Mdot
.42982 .61835 Mdot
.53102 .6582 Mdot
.5464 .36327 Mdot
.61014 .47623 Mdot
.49613 .37291 Mdot
.35765 .56058 Mdot
.77454 .52368 Mdot
.58235 .6254 Mdot
.72219 .37192 Mdot
.63459 .48493 Mdot
.6061 .46136 Mdot
.4179 .5852 Mdot
.54656 .25206 Mdot
.36093 .54274 Mdot
.35947 .34256 Mdot
.30452 .45197 Mdot
.2822 .61635 Mdot
.40891 .5374 Mdot
.53045 .35312 Mdot
.40546 .54543 Mdot
.48669 .61476 Mdot
.39033 .80546 Mdot
.38797 .50797 Mdot
.79802 .48948 Mdot
.46787 .36735 Mdot
.57175 .66775 Mdot
.3283 .59986 Mdot
.73226 .37134 Mdot
.39807 .55645 Mdot
.21215 .69641 Mdot
.40745 .37405 Mdot
.54135 .28052 Mdot
.41301 .6261 Mdot
.40921 .57752 Mdot
.41711 .79781 Mdot
.57343 .72163 Mdot
.74799 .34518 Mdot
.37877 .60217 Mdot
.32402 .42804 Mdot
.66181 .49178 Mdot
.36908 .53165 Mdot
.37424 .58276 Mdot
.26167 .65744 Mdot
.66229 .47666 Mdot
.54548 .3527 Mdot
.73788 .38237 Mdot
.53622 .36747 Mdot
.37729 .36034 Mdot
.53358 .47332 Mdot
.25983 .57119 Mdot
.73561 .62569 Mdot
.38149 .3735 Mdot
.40058 .62524 Mdot
.43251 .49119 Mdot
.39745 .56588 Mdot
.41551 .34651 Mdot
.66051 .46707 Mdot
.59376 .6847 Mdot
.65967 .63084 Mdot
.73711 .36312 Mdot
.3499 .60807 Mdot
.40747 .34113 Mdot
.58681 .6737 Mdot
.62111 .30128 Mdot
.57766 .66696 Mdot
.62245 .49426 Mdot
.64688 .44925 Mdot
.41467 .38134 Mdot
.59972 .68762 Mdot
.52385 .36618 Mdot
.37636 .25907 Mdot
.38365 .53208 Mdot
.67929 .46095 Mdot
.55639 .67931 Mdot
.63287 .67772 Mdot
.56788 .63173 Mdot
.41261 .5907 Mdot
.49557 .42942 Mdot
.33828 .55511 Mdot
.61792 .50222 Mdot
.56152 .30987 Mdot
.25812 .58952 Mdot
.4256 .80745 Mdot
.57144 .45701 Mdot
.40333 .64295 Mdot
.36946 .55839 Mdot
.37144 .57775 Mdot
.43293 .55319 Mdot
.36245 .30389 Mdot
.40203 .58531 Mdot
.63201 .50467 Mdot
.52643 .3353 Mdot
.42221 .57962 Mdot
.73057 .37263 Mdot
.4887 .44305 Mdot
.39319 .39457 Mdot
.51014 .4804 Mdot
.3343 .21602 Mdot
.58772 .67489 Mdot
.56842 .35537 Mdot
.54399 .31542 Mdot
.39801 .39372 Mdot
.60965 .48381 Mdot
.57885 .67195 Mdot
.26077 .43017 Mdot
.40887 .39227 Mdot
.37921 .58761 Mdot
.49553 .30867 Mdot
.83789 .48725 Mdot
.42339 .61831 Mdot
.39361 .59859 Mdot
.73114 .38256 Mdot
.58448 .34765 Mdot
.15702 .55152 Mdot
.4841 .40637 Mdot
.41752 .37701 Mdot
.42087 .3543 Mdot
.56661 .63126 Mdot
.33357 .5893 Mdot
.63919 .4984 Mdot
.45975 .41558 Mdot
.22848 .51447 Mdot
.53483 .4028 Mdot
.69681 .26175 Mdot
.41816 .6072 Mdot
.41774 .78996 Mdot
.39443 .53755 Mdot
.61414 .63195 Mdot
.60096 .63494 Mdot
.59852 .67224 Mdot
.62141 .5003 Mdot
.59274 .76002 Mdot
.63714 .50464 Mdot
.31678 .218 Mdot
.59722 .69664 Mdot
.43416 .25611 Mdot
.55827 .33963 Mdot
.43658 .62467 Mdot
.42486 .38189 Mdot
.58067 .45452 Mdot
.36645 .64157 Mdot
.77969 .56695 Mdot
.56339 .34657 Mdot
.56254 .66557 Mdot
.43952 .6534 Mdot
.18569 .38029 Mdot
.53472 .45115 Mdot
.48606 .5397 Mdot
.52472 .82005 Mdot
.42266 .37831 Mdot
.41229 .69166 Mdot
.42635 .38648 Mdot
.63193 .46975 Mdot
.35619 .56314 Mdot
.3527 .57419 Mdot
.40253 .53504 Mdot
.40315 .58729 Mdot
.64865 .50549 Mdot
.42077 .53439 Mdot
.49526 .85388 Mdot
.7384 .3796 Mdot
.33429 .28682 Mdot
.38782 .36615 Mdot
.61891 .4549 Mdot
.52834 .34165 Mdot
.7232 .35871 Mdot
.25846 .54926 Mdot
.43407 .58663 Mdot
.39956 .60621 Mdot
.74614 .34961 Mdot
.3701 .64053 Mdot
.41072 .66049 Mdot
.54711 .32032 Mdot
.56522 .47026 Mdot
.39167 .34777 Mdot
.3864 .36319 Mdot
.63829 .45674 Mdot
.59857 .68844 Mdot
.3937 .37311 Mdot
.58622 .3289 Mdot
.42301 .53375 Mdot
.35274 .59982 Mdot
.55636 .67887 Mdot
.54206 .83057 Mdot
.40094 .33919 Mdot
.45035 .64374 Mdot
.6068 .69052 Mdot
.56655 .62748 Mdot
.38095 .60472 Mdot
.40338 .50632 Mdot
.62241 .69426 Mdot
.38482 .37777 Mdot
.61682 .45589 Mdot
.48526 .23155 Mdot
.6256 .47046 Mdot
.58168 .67441 Mdot
.40107 .51907 Mdot
.56828 .67484 Mdot
.40238 .5603 Mdot
.78647 .2762 Mdot
.35402 .58251 Mdot
.71359 .71331 Mdot
.26071 .45925 Mdot
.53891 .31847 Mdot
.52693 .36749 Mdot
.73516 .37642 Mdot
.60663 .69189 Mdot
.34825 .57599 Mdot
.42634 .36096 Mdot
.43416 .19292 Mdot
.55678 .69915 Mdot
.56217 .30555 Mdot
.58239 .35678 Mdot
.66449 .47631 Mdot
.42216 .61381 Mdot
.37536 .60897 Mdot
.55711 .35386 Mdot
.26946 .37077 Mdot
.61836 .67015 Mdot
.36669 .57046 Mdot
.37269 .55678 Mdot
.54033 .32084 Mdot
.37395 .26317 Mdot
.52837 .66635 Mdot
.35656 .56898 Mdot
.45004 .35052 Mdot
.65144 .45437 Mdot
.42981 .55011 Mdot
.42333 .53681 Mdot
.41301 .35409 Mdot
.30231 .29958 Mdot
.33402 .76734 Mdot
.63478 .45167 Mdot
.72432 .36094 Mdot
.37324 .62105 Mdot
.55798 .33768 Mdot
.36419 .61402 Mdot
.21053 .40203 Mdot
.73042 .37935 Mdot
.39535 .57926 Mdot
.33759 .61147 Mdot
.58011 .63494 Mdot
.40156 .58019 Mdot
.29524 .67111 Mdot
.52434 .35766 Mdot
.39808 .58041 Mdot
.51825 .80825 Mdot
.66373 .48891 Mdot
.33373 .60821 Mdot
.40029 .34689 Mdot
.25096 .45597 Mdot
.68431 .58302 Mdot
.57425 .37428 Mdot
.38692 .37304 Mdot
.3743 .61766 Mdot
.58313 .34291 Mdot
.60779 .47763 Mdot
.77217 .54423 Mdot
.43862 .58648 Mdot
.62123 .47252 Mdot
.63553 .47648 Mdot
.41055 .38013 Mdot
.76816 .69199 Mdot
.39154 .64932 Mdot
.36907 .60877 Mdot
.23739 .62568 Mdot
.58864 .62805 Mdot
.37403 .61474 Mdot
.41161 .62063 Mdot
.64664 .49243 Mdot
.54696 .59393 Mdot
.4986 .64658 Mdot
.46994 .31075 Mdot
.64807 .45521 Mdot
.58204 .37545 Mdot
.58252 .34377 Mdot
.38839 .36655 Mdot
.57158 .66123 Mdot
.38152 .38453 Mdot
.56305 .32254 Mdot
.42443 .59766 Mdot
.64812 .48113 Mdot
.37868 .71533 Mdot
.62775 .52269 Mdot
.55794 .29725 Mdot
.63038 .65343 Mdot
.64236 .57241 Mdot
.30981 .77669 Mdot
.69975 .59009 Mdot
.59469 .50764 Mdot
.42181 .36432 Mdot
.47771 .35173 Mdot
.3714 .55805 Mdot
.45985 .6795 Mdot
.39387 .6199 Mdot
.51723 .81817 Mdot
.57534 .32864 Mdot
.73651 .35089 Mdot
.35559 .56369 Mdot
.30955 .45684 Mdot
.59564 .48147 Mdot
.66535 .4794 Mdot
.39894 .59323 Mdot
.62439 .49679 Mdot
.36304 .59524 Mdot
.52447 .3332 Mdot
.73565 .71906 Mdot
.36823 .5615 Mdot
.35529 .52383 Mdot
.62636 .5413 Mdot
.52318 .19638 Mdot
.51484 .36407 Mdot
.41623 .79129 Mdot
.16699 .41708 Mdot
.62676 .49665 Mdot
.33156 .55246 Mdot
.55188 .36075 Mdot
.73028 .38256 Mdot
.50881 .3438 Mdot
.39976 .61714 Mdot
.41134 .60687 Mdot
.37719 .54154 Mdot
.3826 .55732 Mdot
.45554 .67802 Mdot
.36712 .65903 Mdot
.42458 .77759 Mdot
.39886 .60455 Mdot
.65013 .65043 Mdot
.63974 .50621 Mdot
.59438 .61036 Mdot
.42799 .3397 Mdot
.41969 .6038 Mdot
.59643 .72904 Mdot
.62749 .45306 Mdot
.31436 .22111 Mdot
.66352 .47606 Mdot
.53729 .34112 Mdot
.6458 .51761 Mdot
.40766 .5627 Mdot
.58191 .64839 Mdot
.52079 .34918 Mdot
.74636 .4913 Mdot
.54725 .31158 Mdot
.41819 .57705 Mdot
.3716 .27819 Mdot
.54617 .31523 Mdot
.49337 .45294 Mdot
.57728 .64963 Mdot
.33108 .42803 Mdot
.61065 .64012 Mdot
.39614 .57621 Mdot
.39334 .57248 Mdot
.71803 .36649 Mdot
.60803 .50847 Mdot
.62306 .67982 Mdot
.61723 .83818 Mdot
.3758 .38033 Mdot
.60042 .66482 Mdot
.45339 .59054 Mdot
.4939 .4237 Mdot
.59825 .64429 Mdot
.29316 .41888 Mdot
.60888 .4823 Mdot
.54848 .64468 Mdot
.4516 .56107 Mdot
.57294 .55979 Mdot
.4363 .36786 Mdot
.55726 .29983 Mdot
.55791 .52564 Mdot
.54489 .36422 Mdot
.63137 .44969 Mdot
.58167 .29727 Mdot
.65991 .49468 Mdot
.64483 .74231 Mdot
.55302 .71418 Mdot
.61652 .52257 Mdot
.63994 .44622 Mdot
.55902 .32768 Mdot
.43596 .57293 Mdot
.48694 .48919 Mdot
.40903 .63498 Mdot
.43777 .60655 Mdot
.66127 .49648 Mdot
.62253 .67451 Mdot
.59782 .70048 Mdot
.53372 .63545 Mdot
.55785 .65131 Mdot
.5272 .34413 Mdot
.7409 .63979 Mdot
.57413 .80381 Mdot
.64123 .46003 Mdot
.66354 .44954 Mdot
.38772 .54425 Mdot
.55893 .33417 Mdot
.58093 .32737 Mdot
.64312 .48961 Mdot
.4209 .70513 Mdot
.34555 .53602 Mdot
.62095 .64373 Mdot
.59489 .69658 Mdot
.60214 .64911 Mdot
.55941 .63932 Mdot
.53652 .7233 Mdot
.60945 .47706 Mdot
.60187 .69464 Mdot
.39654 .58736 Mdot
.40874 .61082 Mdot
.73342 .3578 Mdot
.39138 .35322 Mdot
.43908 .54465 Mdot
.38031 .50953 Mdot
.38188 .60649 Mdot
.55376 .31367 Mdot
.37632 .49573 Mdot
.72514 .37207 Mdot
.58741 .30913 Mdot
.57582 .36922 Mdot
.74327 .35251 Mdot
.55999 .60172 Mdot
.17328 .39015 Mdot
.4005 .54314 Mdot
.44332 .48579 Mdot
.55362 .33582 Mdot
.76355 .64564 Mdot
.65031 .63622 Mdot
.4123 .53838 Mdot
.54207 .5566 Mdot
.52011 .34189 Mdot
.58899 .62618 Mdot
.38401 .61843 Mdot
.75452 .36074 Mdot
.39627 .39618 Mdot
.45414 .59194 Mdot
.73611 .38331 Mdot
.60482 .683 Mdot
.36063 .39382 Mdot
.5548 .63736 Mdot
.51864 .33714 Mdot
.33805 .61446 Mdot
.35947 .14685 Mdot
.55894 .36488 Mdot
.43194 .20264 Mdot
.53667 .69279 Mdot
.36508 .56197 Mdot
.5538 .36603 Mdot
.59711 .62675 Mdot
.65383 .45421 Mdot
.46685 .42721 Mdot
.58006 .68705 Mdot
.7265 .35583 Mdot
.73999 .35654 Mdot
.54562 .31946 Mdot
.56588 .65314 Mdot
.38101 .52476 Mdot
.59417 .63587 Mdot
.64797 .51751 Mdot
.42541 .55382 Mdot
.2263 .32918 Mdot
.31453 .59564 Mdot
.61434 .68603 Mdot
.57458 .30108 Mdot
.43366 .36323 Mdot
.43263 .57573 Mdot
.38758 .23099 Mdot
.41774 .61797 Mdot
.65756 .47191 Mdot
.80601 .57977 Mdot
.36091 .70674 Mdot
.42825 .5924 Mdot
.38652 .54539 Mdot
.62725 .45558 Mdot
.43389 .58312 Mdot
.42227 .61784 Mdot
.65702 .53523 Mdot
.5808 .63658 Mdot
.3775 .57524 Mdot
.5769 .3148 Mdot
.41683 .81098 Mdot
.37438 .62265 Mdot
.79393 .4677 Mdot
.32582 .43951 Mdot
.79573 .60777 Mdot
.36152 .60752 Mdot
.31309 .48923 Mdot
.38589 .56866 Mdot
.41798 .59439 Mdot
.40515 .54058 Mdot
.3971 .77524 Mdot
.56197 .32785 Mdot
.55115 .30466 Mdot
.4369 .36864 Mdot
.32333 .43807 Mdot
.40096 .35371 Mdot
.64391 .45572 Mdot
.63627 .23234 Mdot
.7349 .37967 Mdot
.59858 .68922 Mdot
.3526 .553 Mdot
.51639 .33981 Mdot
.38494 .61285 Mdot
.405 .55901 Mdot
.5212 .33567 Mdot
.57165 .36052 Mdot
.56121 .27942 Mdot
.42342 .38817 Mdot
.59375 .67931 Mdot
.40651 .52935 Mdot
.39996 .38969 Mdot
.37613 .52601 Mdot
.48445 .4127 Mdot
.59641 .67877 Mdot
.59114 .635 Mdot
.62605 .67987 Mdot
.42432 .59898 Mdot
.41438 .56522 Mdot
.63908 .50403 Mdot
.55939 .68488 Mdot
.63044 .45896 Mdot
.54002 .36141 Mdot
.51812 .35785 Mdot
.40045 .61688 Mdot
.45431 .64338 Mdot
.42236 .35711 Mdot
.53844 .34554 Mdot
.74789 .34908 Mdot
.43449 .37823 Mdot
.4223 .5847 Mdot
.53268 .35462 Mdot
.38611 .36173 Mdot
.43964 .72072 Mdot
.16169 .44828 Mdot
.43096 .35533 Mdot
.39719 .59175 Mdot
.42634 .80356 Mdot
.34235 .3545 Mdot
.37831 .38822 Mdot
.64549 .46463 Mdot
.41667 .61689 Mdot
.21098 .47494 Mdot
.37971 .36892 Mdot
.52068 .826 Mdot
.53567 .32107 Mdot
.53637 .59321 Mdot
.448 .54857 Mdot
.47279 .68796 Mdot
.38002 .38505 Mdot
.58084 .66735 Mdot
.56596 .69684 Mdot
.38745 .58934 Mdot
.44246 .34815 Mdot
.66585 .49609 Mdot
.532 .32157 Mdot
.53322 .37586 Mdot
.56807 .64749 Mdot
.69476 .63798 Mdot
.57657 .30865 Mdot
.46636 .61491 Mdot
.53949 .26338 Mdot
.32134 .54229 Mdot
.63147 .74942 Mdot
.73833 .49337 Mdot
.34829 .59378 Mdot
.42834 .35447 Mdot
.60813 .46709 Mdot
.63162 .50332 Mdot
.61868 .49073 Mdot
.53602 .3717 Mdot
.5187 .47082 Mdot
.56595 .34664 Mdot
.76625 .53416 Mdot
.4043 .38288 Mdot
.32842 .40526 Mdot
.34956 .57692 Mdot
.36915 .55981 Mdot
.37749 .52288 Mdot
.36225 .54414 Mdot
.38324 .56811 Mdot
.61095 .48717 Mdot
.55147 .37399 Mdot
.48715 .26773 Mdot
.60738 .66 Mdot
.62963 .29072 Mdot
.55829 .33999 Mdot
.73218 .38205 Mdot
.4129 .36643 Mdot
.30489 .5071 Mdot
.59492 .32395 Mdot
.55378 .34432 Mdot
.43431 .54404 Mdot
.61666 .65113 Mdot
.37214 .66943 Mdot
.38965 .56678 Mdot
.53901 .34791 Mdot
.51938 .39032 Mdot
.37035 .68683 Mdot
.43069 .50668 Mdot
.37611 .40113 Mdot
.49756 .42701 Mdot
.40297 .40234 Mdot
.40863 .5104 Mdot
.76646 .64142 Mdot
.56178 .32251 Mdot
.53725 .33357 Mdot
.40756 .34209 Mdot
.47851 .55452 Mdot
.56877 .65477 Mdot
.73693 .3504 Mdot
.65537 .47682 Mdot
.39666 .56781 Mdot
.53315 .36803 Mdot
.49267 .56836 Mdot
.51784 .26648 Mdot
.61663 .48404 Mdot
.58783 .31073 Mdot
.42496 .60726 Mdot
.39688 .59405 Mdot
.42345 .37515 Mdot
.45355 .48474 Mdot
.44814 .61027 Mdot
.40584 .19479 Mdot
.72648 .64272 Mdot
.70004 .67771 Mdot
.37819 .60621 Mdot
.56858 .64405 Mdot
.75262 .36078 Mdot
.41303 .38912 Mdot
.40337 .52351 Mdot
.16089 .43533 Mdot
.59813 .70691 Mdot
.62701 .47578 Mdot
.75135 .35724 Mdot
.51687 .46959 Mdot
.41543 .61954 Mdot
.39311 .61983 Mdot
.40808 .58909 Mdot
.14609 .46428 Mdot
.56707 .30578 Mdot
.56633 .63403 Mdot
.39713 .367 Mdot
.56066 .64116 Mdot
.54966 .30708 Mdot
.65809 .6202 Mdot
.42471 .57873 Mdot
.62329 .64488 Mdot
.57995 .66438 Mdot
.66439 .47481 Mdot
.66539 .46627 Mdot
.56657 .27818 Mdot
.35437 .5816 Mdot
.75568 .36429 Mdot
.60571 .63689 Mdot
.57236 .36457 Mdot
.42109 .37909 Mdot
.61521 .50541 Mdot
.40002 .60384 Mdot
.55556 .31942 Mdot
.33887 .59359 Mdot
.60351 .64404 Mdot
.55406 .34348 Mdot
.75624 .37068 Mdot
.41468 .35051 Mdot
.40702 .60591 Mdot
.36407 .38058 Mdot
.74505 .35103 Mdot
.37277 .55422 Mdot
.27179 .598 Mdot
.4132 .32952 Mdot
.75001 .48664 Mdot
.56753 .35145 Mdot
.72958 .36615 Mdot
.593 .6328 Mdot
.59633 .57764 Mdot
.53409 .33434 Mdot
.2823 .55527 Mdot
.48281 .50334 Mdot
.41088 .53147 Mdot
.59339 .65123 Mdot
.46935 .34973 Mdot
.3551 .21892 Mdot
.33481 .34031 Mdot
.36966 .57114 Mdot
.55157 .36608 Mdot
.38446 .36924 Mdot
.64411 .46014 Mdot
.79556 .46915 Mdot
.57317 .73596 Mdot
.58507 .29943 Mdot
.39849 .54119 Mdot
.60654 .63786 Mdot
.64222 .48823 Mdot
.70365 .53414 Mdot
.58601 .32123 Mdot
.57587 .33371 Mdot
.42541 .58568 Mdot
.39514 .37813 Mdot
.29885 .34175 Mdot
.54814 .30501 Mdot
.53952 .36955 Mdot
.62463 .28086 Mdot
.41319 .34106 Mdot
.391 .58579 Mdot
.53337 .63625 Mdot
.43912 .5667 Mdot
.43626 .19815 Mdot
.72703 .37193 Mdot
.60897 .66131 Mdot
.40939 .61441 Mdot
.49694 .29614 Mdot
.53152 .3434 Mdot
.50696 .4338 Mdot
.56515 .29424 Mdot
.60971 .48703 Mdot
.53067 .36689 Mdot
.38206 .61612 Mdot
.59557 .4802 Mdot
.42028 .35552 Mdot
.35588 .57044 Mdot
.41482 .56426 Mdot
.60144 .62635 Mdot
.63361 .4687 Mdot
.30702 .72737 Mdot
.64262 .444 Mdot
.61791 .45814 Mdot
.54323 .66711 Mdot
.38344 .58853 Mdot
.54147 .34172 Mdot
.54659 .30192 Mdot
.39764 .52391 Mdot
.7513 .65769 Mdot
.56935 .6502 Mdot
.57019 .27707 Mdot
.1583 .54523 Mdot
.46601 .58625 Mdot
.75844 .35928 Mdot
.4251 .48075 Mdot
.66469 .46865 Mdot
.39956 .59886 Mdot
.61379 .68453 Mdot
.54997 .37071 Mdot
.57654 .30937 Mdot
.39535 .51974 Mdot
.64029 .47941 Mdot
.38598 .38603 Mdot
.57771 .33664 Mdot
.53461 .25834 Mdot
.40659 .58323 Mdot
.77649 .51898 Mdot
.57439 .34712 Mdot
.46804 .17227 Mdot
.49579 .2728 Mdot
.598 .6511 Mdot
.4064 .55752 Mdot
.561 .67332 Mdot
.40036 .36167 Mdot
.56303 .38489 Mdot
.63795 .47577 Mdot
.43613 .50583 Mdot
.37265 .80619 Mdot
.5631 .33134 Mdot
.59888 .68543 Mdot
.42821 .59403 Mdot
.46543 .55905 Mdot
.36407 .60432 Mdot
.55182 .59419 Mdot
.38959 .33237 Mdot
.66232 .49585 Mdot
.65553 .46964 Mdot
.37751 .54593 Mdot
.41265 .39347 Mdot
.52564 .31972 Mdot
.53128 .3242 Mdot
.88317 .46791 Mdot
.75625 .37119 Mdot
.27865 .46918 Mdot
.41065 .60512 Mdot
.57285 .36583 Mdot
.41748 .80437 Mdot
.62737 .46466 Mdot
.36459 .53996 Mdot
.56395 .37587 Mdot
.61339 .38472 Mdot
.48359 .41527 Mdot
.38646 .5757 Mdot
.44681 .63501 Mdot
.6551 .47412 Mdot
.46285 .40362 Mdot
.56353 .34885 Mdot
.3736 .53367 Mdot
.6378 .44379 Mdot
.60652 .25814 Mdot
.46286 .84509 Mdot
.59408 .67885 Mdot
.55789 .29634 Mdot
.61046 .48578 Mdot
.44726 .61751 Mdot
.38731 .36676 Mdot
.53164 .361 Mdot
.5532 .31113 Mdot
.42002 .55287 Mdot
.44438 .56642 Mdot
.46611 .5824 Mdot
.60603 .67327 Mdot
.65031 .49796 Mdot
.35605 .55805 Mdot
.69944 .63986 Mdot
.37585 .54098 Mdot
.64772 .49804 Mdot
.52216 .09718 Mdot
.4403 .57863 Mdot
.36387 .60259 Mdot
.31246 .33714 Mdot
.57511 .68566 Mdot
.55995 .64385 Mdot
.73192 .6434 Mdot
.41031 .6052 Mdot
.52881 .24068 Mdot
.59084 .68033 Mdot
.57258 .64741 Mdot
.42099 .26663 Mdot
.4237 .54916 Mdot
.47394 .38949 Mdot
.6414 .49709 Mdot
.60851 .49862 Mdot
.58758 .63624 Mdot
.44639 .61607 Mdot
.61306 .46663 Mdot
.48451 .6667 Mdot
.56179 .33994 Mdot
.76819 .63932 Mdot
.61333 .65194 Mdot
.44437 .46958 Mdot
.62036 .47083 Mdot
.32135 .21213 Mdot
.55387 .54889 Mdot
.38622 .53817 Mdot
.40766 .59999 Mdot
.41167 .35219 Mdot
.35729 .64177 Mdot
.72276 .36322 Mdot
.62312 .49664 Mdot
.27749 .33179 Mdot
.59867 .67104 Mdot
.35639 .58689 Mdot
.29381 .51958 Mdot
.70709 .54654 Mdot
.79954 .49746 Mdot
.57247 .66755 Mdot
.59393 .65616 Mdot
.56994 .33584 Mdot
.56803 .31884 Mdot
.38434 .58121 Mdot
.62479 .50324 Mdot
.54961 .67188 Mdot
.65594 .48527 Mdot
.5623 .32147 Mdot
.54965 .34236 Mdot
.72872 .37874 Mdot
.36044 .62557 Mdot
.52245 .33187 Mdot
.59275 .24777 Mdot
.69191 .64274 Mdot
.59335 .62252 Mdot
.29301 .75287 Mdot
.70434 .53036 Mdot
.25315 .40646 Mdot
.41148 .39893 Mdot
.75053 .34172 Mdot
.63769 .51538 Mdot
.3836 .546 Mdot
.39515 .61062 Mdot
.74298 .36403 Mdot
.61551 .51545 Mdot
.4163 .36405 Mdot
.60948 .51084 Mdot
.4017 .38479 Mdot
.51225 .35346 Mdot
.37381 .62202 Mdot
.40299 .62331 Mdot
.61225 .48858 Mdot
.54869 .35292 Mdot
.52642 .32638 Mdot
.42062 .39379 Mdot
.33774 .47795 Mdot
.54808 .3186 Mdot
.61148 .64956 Mdot
.5485 .76491 Mdot
.7411 .35748 Mdot
.38089 .61762 Mdot
.27325 .54482 Mdot
.41768 .69518 Mdot
.39938 .52969 Mdot
.7504 .35526 Mdot
.87519 .51377 Mdot
.35128 .57992 Mdot
.85093 .56398 Mdot
.72905 .36355 Mdot
.57321 .68535 Mdot
.56097 .36136 Mdot
.72172 .36341 Mdot
.45746 .58378 Mdot
.38193 .39785 Mdot
.42196 .52341 Mdot
.57749 .68494 Mdot
.6298 .67003 Mdot
.69039 .71705 Mdot
.43731 .19887 Mdot
.42982 .37822 Mdot
.41551 .37411 Mdot
.53412 .33163 Mdot
.66552 .21896 Mdot
.4494 .5574 Mdot
.41823 .373 Mdot
.26998 .35088 Mdot
.39201 .54524 Mdot
.28154 .48387 Mdot
.54088 .55253 Mdot
.56904 .64455 Mdot
.57536 .60318 Mdot
.5315 .33799 Mdot
.59824 .68507 Mdot
.68345 .6619 Mdot
.38011 .52181 Mdot
.5979 .67644 Mdot
.64895 .49451 Mdot
.68714 .40833 Mdot
.56105 .66766 Mdot
.45303 .42628 Mdot
.63825 .49809 Mdot
.40168 .32647 Mdot
.29638 .36707 Mdot
.21616 .71674 Mdot
.6228 .49795 Mdot
.54466 .35814 Mdot
.51914 .33705 Mdot
.53259 .32508 Mdot
.58093 .6883 Mdot
.58346 .3287 Mdot
.61077 .67115 Mdot
.3951 .24199 Mdot
.30092 .50517 Mdot
.41349 .38274 Mdot
.66473 .51864 Mdot
.58573 .65858 Mdot
.75385 .58717 Mdot
.31522 .77689 Mdot
.39994 .59246 Mdot
.64005 .44389 Mdot
.40778 .34267 Mdot
.59769 .17199 Mdot
.41143 .35334 Mdot
.5533 .36067 Mdot
.77259 .6336 Mdot
.36153 .59105 Mdot
.28736 .65776 Mdot
.42119 .353 Mdot
.57374 .67401 Mdot
.37115 .55581 Mdot
.5545 .29065 Mdot
.38945 .36735 Mdot
.39305 .39347 Mdot
.37787 .56624 Mdot
.56165 .65894 Mdot
.54558 .34326 Mdot
.63386 .51443 Mdot
.39121 .33782 Mdot
.43361 .63606 Mdot
.43125 .54893 Mdot
.34178 .55349 Mdot
.52316 .45144 Mdot
.22525 .423 Mdot
.62828 .49668 Mdot
.35286 .41074 Mdot
.56298 .31566 Mdot
.39819 .31724 Mdot
.72663 .59975 Mdot
.64574 .53186 Mdot
.72668 .3706 Mdot
.72872 .37577 Mdot
.38417 .57274 Mdot
.23013 .41285 Mdot
.82281 .52325 Mdot
.61043 .53824 Mdot
.74542 .35797 Mdot
.52966 .32373 Mdot
.57331 .70057 Mdot
.67507 .72285 Mdot
.44455 .58739 Mdot
.66717 .48122 Mdot
.55272 .31704 Mdot
.20806 .40728 Mdot
.40311 .37913 Mdot
.75929 .62963 Mdot
.42157 .57704 Mdot
.36262 .57308 Mdot
.63354 .48925 Mdot
.63776 .50399 Mdot
.7864 .48516 Mdot
.7073 .68178 Mdot
.56191 .40653 Mdot
.69117 .51007 Mdot
.1935 .43911 Mdot
.58712 .60986 Mdot
.61723 .68125 Mdot
.74249 .38147 Mdot
.60315 .46918 Mdot
.38867 .62065 Mdot
.58141 .69438 Mdot
.80061 .50015 Mdot
.59837 .7155 Mdot
.29233 .47191 Mdot
.53345 .24666 Mdot
.40861 .56867 Mdot
.61149 .64458 Mdot
.59753 .68339 Mdot
.55191 .64792 Mdot
.74516 .35329 Mdot
.37749 .60283 Mdot
.43559 .57535 Mdot
.35981 .55837 Mdot
.4038 .65479 Mdot
.40388 .58112 Mdot
.71697 .60661 Mdot
.57345 .45713 Mdot
.2873 .3167 Mdot
.39684 .53131 Mdot
.60643 .49294 Mdot
.34717 .5582 Mdot
.40826 .39474 Mdot
.39759 .54049 Mdot
.28005 .4763 Mdot
.62274 .48397 Mdot
.47542 .54935 Mdot
.68706 .51948 Mdot
.42193 .57562 Mdot
.38175 .37142 Mdot
.2391 .40603 Mdot
.30442 .73394 Mdot
.6233 .28462 Mdot
.60951 .64737 Mdot
.59308 .3231 Mdot
.65044 .51706 Mdot
.54152 .33942 Mdot
.38409 .535 Mdot
.75443 .36978 Mdot
.71182 .45333 Mdot
.45138 .47001 Mdot
.40248 .62039 Mdot
.32944 .5405 Mdot
.58608 .64072 Mdot
.53629 .35625 Mdot
.6406 .65303 Mdot
.41404 .59324 Mdot
.39507 .36684 Mdot
.39204 .37755 Mdot
.70906 .66528 Mdot
.23059 .34628 Mdot
.60007 .58765 Mdot
.63269 .49148 Mdot
.57224 .30235 Mdot
.37943 .38212 Mdot
.55553 .71926 Mdot
.66796 .49078 Mdot
.66493 .46983 Mdot
.64059 .47163 Mdot
.40125 .5668 Mdot
.72366 .368 Mdot
.24915 .35629 Mdot
.72465 .35771 Mdot
.42073 .57186 Mdot
.5608 .30823 Mdot
.72015 .36674 Mdot
.40376 .3511 Mdot
.64207 .45696 Mdot
.56731 .3232 Mdot
.39744 .57512 Mdot
.58991 .67444 Mdot
.36376 .46567 Mdot
.24097 .4877 Mdot
.36019 .26038 Mdot
.35466 .26526 Mdot
.61551 .69258 Mdot
.28901 .25822 Mdot
.67955 .46222 Mdot
.42203 .70393 Mdot
.40735 .41542 Mdot
.39216 .52342 Mdot
.69092 .75467 Mdot
.56254 .35122 Mdot
.52322 .345 Mdot
.38964 .57837 Mdot
.56882 .36465 Mdot
.35775 .5926 Mdot
.57322 .32653 Mdot
.60397 .27587 Mdot
.44238 .60452 Mdot
.52446 .34338 Mdot
.431 .52172 Mdot
.43176 .57256 Mdot
.57627 .63917 Mdot
.5376 .36539 Mdot
.37682 .53917 Mdot
.66684 .20786 Mdot
.62646 .50737 Mdot
.74326 .35343 Mdot
.56668 .42802 Mdot
.61017 .47882 Mdot
.60197 .6615 Mdot
.42989 .62097 Mdot
.42539 .36759 Mdot
.58342 .66834 Mdot
.56478 .27795 Mdot
.42032 .35083 Mdot
.74053 .63774 Mdot
.60437 .6428 Mdot
.73938 .35923 Mdot
.42321 .35695 Mdot
.32829 .54866 Mdot
.51965 .35402 Mdot
.22768 .52842 Mdot
.72871 .35541 Mdot
.37547 .60965 Mdot
.51421 .36637 Mdot
.60502 .49674 Mdot
.37268 .58093 Mdot
.55621 .36656 Mdot
.74632 .35264 Mdot
.39627 .55969 Mdot
.37952 .55347 Mdot
.6611 .7244 Mdot
.80034 .54306 Mdot
.42257 .37502 Mdot
.60222 .63146 Mdot
.39642 .58643 Mdot
.42074 .39107 Mdot
.67925 .2749 Mdot
.34186 .57698 Mdot
.56658 .68351 Mdot
.28382 .60279 Mdot
.56725 .31591 Mdot
.63113 .45848 Mdot
.55168 .29814 Mdot
.39811 .39749 Mdot
.65642 .82139 Mdot
.7232 .37484 Mdot
.43598 .52301 Mdot
.36828 .5311 Mdot
.51637 .38424 Mdot
.60055 .68039 Mdot
.54113 .40857 Mdot
.40716 .60539 Mdot
.31333 .5971 Mdot
.35859 .57722 Mdot
.49553 .26809 Mdot
.56955 .65179 Mdot
.36917 .60829 Mdot
.44056 .65468 Mdot
.38236 .62902 Mdot
.38206 .37778 Mdot
.31768 .38319 Mdot
.34161 .56625 Mdot
.29381 .18745 Mdot
.74818 .3504 Mdot
.52225 .33443 Mdot
.60486 .35065 Mdot
.75327 .30439 Mdot
.63965 .74867 Mdot
.6087 .67294 Mdot
.30632 .55264 Mdot
.54353 .3416 Mdot
.46102 .83647 Mdot
.32024 .22979 Mdot
.43029 .57209 Mdot
.42218 .60926 Mdot
.55327 .36069 Mdot
.57016 .36709 Mdot
.74629 .37681 Mdot
.39486 .53352 Mdot
.36617 .50431 Mdot
.58509 .30812 Mdot
.40843 .57708 Mdot
.30463 .64524 Mdot
.64104 .51145 Mdot
.5735 .63618 Mdot
.64346 .45965 Mdot
.66509 .48756 Mdot
.51191 .72755 Mdot
.72601 .64401 Mdot
.64592 .50064 Mdot
.63368 .44097 Mdot
.27239 .48689 Mdot
.28948 .55594 Mdot
.38426 .38699 Mdot
.3017 .27667 Mdot
.53627 .32534 Mdot
.37788 .60127 Mdot
.61336 .69147 Mdot
.48005 .69716 Mdot
.6657 .37181 Mdot
.7877 .60725 Mdot
.41703 .60001 Mdot
.52918 .33632 Mdot
.74018 .35171 Mdot
.44433 .59919 Mdot
.37736 .31853 Mdot
.36541 .57202 Mdot
.51666 .34124 Mdot
.56986 .76242 Mdot
.2823 .63029 Mdot
.48502 .33454 Mdot
.54963 .63599 Mdot
.35165 .56505 Mdot
.61402 .65865 Mdot
.61696 .47481 Mdot
.41768 .39153 Mdot
.42224 .36944 Mdot
.37382 .55705 Mdot
.55734 .71852 Mdot
.53613 .55611 Mdot
.43136 .57615 Mdot
.42172 .55158 Mdot
.72903 .3652 Mdot
.42272 .55203 Mdot
.37085 .52978 Mdot
.36042 .54947 Mdot
.35789 .61411 Mdot
.61607 .45933 Mdot
.27401 .61786 Mdot
.34122 .59184 Mdot
.45016 .53324 Mdot
.63297 .51128 Mdot
.32593 .52361 Mdot
.6636 .48139 Mdot
.225 .33359 Mdot
.66075 .4802 Mdot
.42083 .37454 Mdot
.51983 .37194 Mdot
.3084 .58746 Mdot
.54725 .66745 Mdot
.65023 .4516 Mdot
.4041 .36819 Mdot
.62045 .49397 Mdot
.57084 .3069 Mdot
.24709 .68055 Mdot
.59935 .71542 Mdot
.47151 .40772 Mdot
.56254 .57009 Mdot
.77814 .51477 Mdot
.5665 .33631 Mdot
.57204 .64459 Mdot
.2927 .66418 Mdot
.36495 .54809 Mdot
.41571 .35221 Mdot
.38164 .57144 Mdot
.6222 .45638 Mdot
.5303 .33121 Mdot
.35889 .27715 Mdot
.42383 .36944 Mdot
.45982 .85277 Mdot
.5369 .31724 Mdot
.43872 .59089 Mdot
.66778 .47573 Mdot
.29624 .75584 Mdot
.6607 .4764 Mdot
.29224 .51535 Mdot
.63346 .654 Mdot
.59828 .77956 Mdot
.58883 .65269 Mdot
.8094 .48007 Mdot
.14036 .42795 Mdot
.36338 .22933 Mdot
.58305 .67867 Mdot
.52173 .27818 Mdot
.41799 .57988 Mdot
.34345 .55934 Mdot
.46797 .59669 Mdot
.58815 .62471 Mdot
.39991 .58572 Mdot
.72819 .3585 Mdot
.66919 .62592 Mdot
.41587 .30733 Mdot
.59359 .31787 Mdot
.36988 .6118 Mdot
.63649 .51034 Mdot
.60692 .50984 Mdot
.72089 .3635 Mdot
.65861 .50604 Mdot
.43296 .56453 Mdot
.58636 .65624 Mdot
.47529 .48791 Mdot
.4023 .35693 Mdot
.55312 .1841 Mdot
.41273 .33609 Mdot
.58722 .29452 Mdot
.33725 .61148 Mdot
.55041 .3428 Mdot
.77785 .72175 Mdot
.37501 .54355 Mdot
.59052 .68289 Mdot
.38568 .55621 Mdot
.35425 .55623 Mdot
.34381 .55747 Mdot
.58424 .31881 Mdot
.58183 .38456 Mdot
.40497 .57527 Mdot
.63756 .47456 Mdot
.32412 .28642 Mdot
.40875 .51591 Mdot
.53639 .278 Mdot
.31217 .43938 Mdot
.76498 .5415 Mdot
.58673 .62131 Mdot
.53977 .35636 Mdot
.59759 .66562 Mdot
.54199 .64872 Mdot
.60211 .66163 Mdot
.25252 .34328 Mdot
.46285 .65219 Mdot
.86966 .49955 Mdot
.55207 .80005 Mdot
.45999 .70818 Mdot
.62692 .65446 Mdot
.69555 .31034 Mdot
.60758 .6892 Mdot
.60659 .66859 Mdot
.7269 .20869 Mdot
.60133 .69333 Mdot
.39935 .61613 Mdot
.43937 .55542 Mdot
.69693 .58228 Mdot
.27068 .50427 Mdot
.39943 .53808 Mdot
.3933 .5835 Mdot
.42301 .38681 Mdot
.48104 .61874 Mdot
.72736 .38502 Mdot
.74507 .65289 Mdot
.70817 .47125 Mdot
.37925 .56683 Mdot
.39554 .58165 Mdot
.42118 .63702 Mdot
.12562 .4521 Mdot
.49553 .69077 Mdot
.62494 .68581 Mdot
.32829 .5395 Mdot
.47961 .18351 Mdot
.4348 .59665 Mdot
.40214 .62442 Mdot
.40254 .5606 Mdot
.54218 .34184 Mdot
.58277 .70551 Mdot
.32647 .5455 Mdot
.75339 .53706 Mdot
.42288 .58229 Mdot
.6736 .50287 Mdot
.3854 .33848 Mdot
.3847 .61638 Mdot
.55521 .64557 Mdot
.40168 .5455 Mdot
.61387 .64976 Mdot
.58267 .63564 Mdot
.40478 .64565 Mdot
.24067 .35667 Mdot
.55713 .67016 Mdot
.41658 .56789 Mdot
.54432 .3523 Mdot
.36275 .21932 Mdot
.37876 .6119 Mdot
.40723 .39019 Mdot
.40815 .60217 Mdot
.38275 .37321 Mdot
.42469 .56272 Mdot
.72717 .35564 Mdot
.34869 .7007 Mdot
.53744 .33189 Mdot
.43423 .41167 Mdot
.5808 .35363 Mdot
.66409 .71536 Mdot
.57249 .68712 Mdot
.73734 .38636 Mdot
.77461 .66717 Mdot
.73045 .36399 Mdot
.36674 .46564 Mdot
.65655 .33012 Mdot
.61678 .50128 Mdot
.56732 .63502 Mdot
.37269 .42988 Mdot
.53487 .27488 Mdot
.5733 .28352 Mdot
.57954 .36525 Mdot
.68386 .79058 Mdot
.74601 .71051 Mdot
.3986 .57079 Mdot
.21255 .56351 Mdot
.42659 .77135 Mdot
.3631 .6147 Mdot
.42211 .6265 Mdot
.51516 .34567 Mdot
.35009 .57556 Mdot
.50469 .45709 Mdot
.55952 .32837 Mdot
.4093 .37043 Mdot
.61027 .66231 Mdot
.38424 .37493 Mdot
.51035 .32305 Mdot
.56906 .47771 Mdot
.56409 .31903 Mdot
.34688 .59559 Mdot
.38694 .56207 Mdot
.60116 .63707 Mdot
.61018 .72734 Mdot
.5761 .63631 Mdot
.41476 .34565 Mdot
.55147 .32521 Mdot
.48212 .68476 Mdot
.39508 .59829 Mdot
.57903 .66225 Mdot
.59197 .44978 Mdot
.39746 .59471 Mdot
.61316 .48403 Mdot
.4258 .59396 Mdot
.58056 .68111 Mdot
.42321 .55281 Mdot
.58829 .65625 Mdot
.55772 .35235 Mdot
.43227 .59879 Mdot
.38898 .58014 Mdot
.34422 .77688 Mdot
.41542 .3625 Mdot
.57296 .68692 Mdot
.53835 .50482 Mdot
.43866 .58013 Mdot
.42696 .32615 Mdot
.36398 .61008 Mdot
.29461 .56642 Mdot
.42329 .51534 Mdot
.73036 .35816 Mdot
.33413 .57369 Mdot
.37689 .61133 Mdot
.27713 .64055 Mdot
.47549 .80736 Mdot
.64437 .66267 Mdot
.63643 .45165 Mdot
.55661 .64436 Mdot
.51967 .35935 Mdot
.54789 .37277 Mdot
.57987 .33695 Mdot
.27728 .51347 Mdot
.43664 .62511 Mdot
.36279 .59326 Mdot
.65655 .45293 Mdot
.41354 .37651 Mdot
.57427 .66814 Mdot
.41039 .38039 Mdot
.74148 .65764 Mdot
.41232 .34592 Mdot
.72211 .36535 Mdot
.49599 .2739 Mdot
.43129 .68414 Mdot
.42542 .38297 Mdot
.57474 .63648 Mdot
.52473 .25512 Mdot
.387 .52536 Mdot
.61545 .29165 Mdot
.39454 .36827 Mdot
.63293 .82919 Mdot
.36913 .61571 Mdot
.48035 .43061 Mdot
.65457 .50171 Mdot
.38998 .35844 Mdot
.63022 .46802 Mdot
.38501 .54244 Mdot
.75305 .4838 Mdot
.59783 .68741 Mdot
.60155 .46747 Mdot
.33533 .57126 Mdot
.38529 .37024 Mdot
.54967 .31551 Mdot
.58895 .56206 Mdot
.60745 .49443 Mdot
.27239 .67435 Mdot
.33532 .33978 Mdot
.55346 .32598 Mdot
.83853 .49808 Mdot
.64517 .46942 Mdot
.3521 .60089 Mdot
.31819 .62943 Mdot
.40819 .53686 Mdot
.53157 .37083 Mdot
.53315 .35426 Mdot
.67596 .61202 Mdot
.38772 .55867 Mdot
.36739 .61394 Mdot
.60982 .70696 Mdot
.56104 .33432 Mdot
.58747 .64523 Mdot
.55321 .64258 Mdot
.54854 .35842 Mdot
.59625 .64968 Mdot
.41863 .35135 Mdot
.64104 .59371 Mdot
.64661 .47052 Mdot
.63317 .47551 Mdot
.52997 .32413 Mdot
.5458 .30506 Mdot
.55271 .3423 Mdot
.42575 .59348 Mdot
.56872 .66416 Mdot
.40912 .55527 Mdot
.34001 .57113 Mdot
.61784 .62865 Mdot
.59319 .69744 Mdot
.40025 .55075 Mdot
.47403 .35408 Mdot
.37725 .35199 Mdot
.52562 .34312 Mdot
.65551 .48822 Mdot
.46457 .8345 Mdot
.66567 .46499 Mdot
.36655 .60976 Mdot
.6192 .3719 Mdot
.57483 .67907 Mdot
.41025 .3524 Mdot
.42619 .33076 Mdot
.41902 .35649 Mdot
.59727 .51881 Mdot
.54817 .65951 Mdot
.73949 .63658 Mdot
.36059 .60007 Mdot
.52347 .45352 Mdot
.36143 .42144 Mdot
.73295 .59022 Mdot
.64926 .49669 Mdot
.3961 .58927 Mdot
.73219 .36258 Mdot
.37868 .6881 Mdot
.36516 .5755 Mdot
.37101 .53808 Mdot
.46932 .24722 Mdot
.45187 .5354 Mdot
.60093 .62465 Mdot
.69411 .7124 Mdot
.42649 .53733 Mdot
.52911 .62405 Mdot
.83747 .36431 Mdot
.35621 .59579 Mdot
.41086 .58784 Mdot
.38679 .60774 Mdot
.38869 .54753 Mdot
.62364 .638 Mdot
.40666 .44144 Mdot
.66659 .47138 Mdot
.5443 .45616 Mdot
.64776 .47771 Mdot
.52167 .35334 Mdot
.48029 .43509 Mdot
.56947 .63506 Mdot
.41508 .35331 Mdot
.23214 .62651 Mdot
.72339 .68459 Mdot
.56933 .33675 Mdot
.52029 .70905 Mdot
.39871 .36015 Mdot
.39498 .52385 Mdot
.43442 .35245 Mdot
.57021 .36813 Mdot
.64304 .48588 Mdot
.4388 .55559 Mdot
.62322 .67741 Mdot
.56098 .66861 Mdot
.40005 .59072 Mdot
.43467 .19371 Mdot
.61488 .47391 Mdot
.5877 .43729 Mdot
.40365 .56741 Mdot
.37218 .53765 Mdot
.59876 .6453 Mdot
.53201 .34786 Mdot
.65074 .27953 Mdot
.4106 .36433 Mdot
.38759 .64033 Mdot
.39289 .54392 Mdot
.7296 .6655 Mdot
.64205 .45573 Mdot
.75148 .36805 Mdot
.39801 .56429 Mdot
.72412 .64935 Mdot
.3968 .56252 Mdot
.35534 .64232 Mdot
.54799 .34752 Mdot
.38938 .51696 Mdot
.42088 .60626 Mdot
.44039 .48715 Mdot
.63993 .46594 Mdot
.59571 .68099 Mdot
.63177 .68996 Mdot
.75454 .36047 Mdot
.61395 .48608 Mdot
.4 .54865 Mdot
.62706 .45721 Mdot
.34209 .56008 Mdot
.40355 .57701 Mdot
.64913 .49623 Mdot
.58813 .64527 Mdot
.65994 .42498 Mdot
.28007 .55473 Mdot
.38759 .55077 Mdot
.43139 .54811 Mdot
.27846 .50384 Mdot
.8141 .61001 Mdot
.41378 .60827 Mdot
.57371 .68158 Mdot
.39329 .59197 Mdot
.62197 .47433 Mdot
.40741 .34423 Mdot
.58701 .67823 Mdot
.53644 .31303 Mdot
.55873 .35406 Mdot
.68063 .52882 Mdot
.72178 .36972 Mdot
.4359 .55778 Mdot
.64952 .67276 Mdot
.60447 .69681 Mdot
.72173 .25037 Mdot
.51971 .33965 Mdot
.38011 .37136 Mdot
.37841 .55147 Mdot
.57851 .55591 Mdot
.65661 .45542 Mdot
.29098 .18914 Mdot
.73697 .62671 Mdot
.44164 .366 Mdot
.7866 .62223 Mdot
.73759 .36287 Mdot
.40894 .61959 Mdot
.41321 .39441 Mdot
.56959 .34902 Mdot
.35159 .55102 Mdot
.45857 .60976 Mdot
.54012 .41071 Mdot
.58775 .36427 Mdot
.62796 .45791 Mdot
.57571 .32282 Mdot
.4287 .39145 Mdot
.72237 .36438 Mdot
.56075 .64945 Mdot
.3702 .60698 Mdot
.3229 .62634 Mdot
.52499 .33268 Mdot
.7282 .35425 Mdot
.40896 .56835 Mdot
.55868 .66411 Mdot
.57302 .35932 Mdot
.37526 .56476 Mdot
.43546 .70129 Mdot
.54716 .6327 Mdot
.54599 .32167 Mdot
.36397 .53511 Mdot
.29472 .60183 Mdot
.53323 .31751 Mdot
.52346 .32841 Mdot
.3995 .58534 Mdot
.4207 .35397 Mdot
.42214 .61397 Mdot
.66152 .49185 Mdot
.58265 .38425 Mdot
.62275 .47648 Mdot
.34718 .37413 Mdot
.34142 .61498 Mdot
.78713 .51487 Mdot
.60288 .63482 Mdot
.40846 .40558 Mdot
.35203 .75948 Mdot
.3804 .53316 Mdot
.26959 .29076 Mdot
.44264 .46681 Mdot
.57233 .17537 Mdot
.15667 .48267 Mdot
.39742 .37424 Mdot
.61848 .49112 Mdot
.4102 .58809 Mdot
.6662 .45187 Mdot
.42091 .38542 Mdot
.35066 .40139 Mdot
.36655 .53368 Mdot
.57144 .64925 Mdot
.42015 .57871 Mdot
.61077 .64846 Mdot
.39901 .59695 Mdot
.42022 .50793 Mdot
.39115 .41377 Mdot
.2893 .51927 Mdot
.39047 .5247 Mdot
.24313 .67809 Mdot
.56384 .53907 Mdot
.39842 .3649 Mdot
.41244 .56123 Mdot
.74286 .37116 Mdot
.61981 .51883 Mdot
.21637 .45773 Mdot
.54619 .34195 Mdot
.64542 .50364 Mdot
.60471 .65283 Mdot
.5344 .30861 Mdot
.74958 .35267 Mdot
.32664 .63429 Mdot
.38614 .38275 Mdot
.61734 .50007 Mdot
.37976 .61379 Mdot
.37296 .61759 Mdot
.48786 .31767 Mdot
.7799 .4118 Mdot
.58338 .70822 Mdot
.41461 .83112 Mdot
.61205 .62827 Mdot
.4177 .36939 Mdot
.54969 .34624 Mdot
.40816 .61469 Mdot
.37166 .575 Mdot
.53835 .37126 Mdot
.57661 .68827 Mdot
.59791 .35023 Mdot
.52128 .72442 Mdot
.57666 .29857 Mdot
.33532 .45015 Mdot
.58626 .68358 Mdot
.33671 .45354 Mdot
.42713 .39384 Mdot
.22038 .37534 Mdot
.26086 .4363 Mdot
.65369 .50337 Mdot
.33553 .44582 Mdot
.57546 .6749 Mdot
.3924 .56747 Mdot
.74124 .3603 Mdot
.72808 .37752 Mdot
.60975 .65525 Mdot
.55209 .36181 Mdot
.3883 .3646 Mdot
.41084 .58534 Mdot
.76625 .59108 Mdot
.68809 .55602 Mdot
.57157 .30146 Mdot
.4105 .66268 Mdot
.63394 .4696 Mdot
.42166 .59906 Mdot
.40199 .38989 Mdot
.62855 .50056 Mdot
.76116 .35418 Mdot
.66096 .61285 Mdot
.37438 .55152 Mdot
.70343 .67592 Mdot
.61399 .49109 Mdot
.84393 .49972 Mdot
.38222 .5785 Mdot
.6449 .46913 Mdot
.40958 .4978 Mdot
.74196 .5027 Mdot
.50954 .49818 Mdot
.32564 .23312 Mdot
.58476 .3651 Mdot
.55901 .35635 Mdot
.72263 .42413 Mdot
.40118 .41513 Mdot
.62614 .50941 Mdot
.72259 .36295 Mdot
.29482 .39207 Mdot
.63342 .46707 Mdot
.40808 .62449 Mdot
.36291 .60836 Mdot
.50411 .72086 Mdot
.51644 .47847 Mdot
.72711 .35366 Mdot
.612 .60055 Mdot
.42226 .54518 Mdot
.37596 .51527 Mdot
.3755 .58407 Mdot
.62958 .67186 Mdot
.60899 .47926 Mdot
.26624 .73493 Mdot
.61895 .46865 Mdot
.77081 .59754 Mdot
.53556 .32588 Mdot
.57009 .29905 Mdot
.38264 .61671 Mdot
.80788 .51158 Mdot
.21141 .4505 Mdot
.43572 .57908 Mdot
.39488 .32494 Mdot
.33197 .3514 Mdot
.38352 .50891 Mdot
.6383 .67496 Mdot
.3271 .62718 Mdot
.58117 .61242 Mdot
.63466 .50208 Mdot
.39765 .37857 Mdot
.37735 .35329 Mdot
.62154 .50198 Mdot
.36435 .59418 Mdot
.36489 .3441 Mdot
.36037 .57568 Mdot
.39734 .56739 Mdot
.75903 .6382 Mdot
.37772 .37277 Mdot
.55602 .34233 Mdot
.4228 .36891 Mdot
.60594 .67028 Mdot
.59495 .11511 Mdot
.40775 .38414 Mdot
.64712 .70766 Mdot
.44453 .41448 Mdot
.33815 .44741 Mdot
.55929 .66234 Mdot
.43157 .36572 Mdot
.62623 .46041 Mdot
.5645 .17014 Mdot
.83474 .55401 Mdot
.66725 .46422 Mdot
.3782 .57502 Mdot
.57647 .63199 Mdot
.62227 .68581 Mdot
.63926 .44257 Mdot
.56613 .64685 Mdot
.33012 .5633 Mdot
.39025 .55736 Mdot
.62579 .50925 Mdot
.68814 .58069 Mdot
.60569 .48895 Mdot
.64948 .61375 Mdot
.4108 .56416 Mdot
.58856 .68062 Mdot
.32875 .60571 Mdot
.61163 .70934 Mdot
.73823 .38134 Mdot
.35194 .54938 Mdot
.39957 .34985 Mdot
.51634 .46722 Mdot
.54326 .32323 Mdot
.61188 .38548 Mdot
.59578 .63652 Mdot
.6215 .42629 Mdot
.57604 .63894 Mdot
.58548 .62818 Mdot
.6643 .49856 Mdot
.60538 .68065 Mdot
.41148 .58731 Mdot
.48175 .34104 Mdot
.61993 .66107 Mdot
.63057 .48624 Mdot
.39395 .35719 Mdot
.59322 .64776 Mdot
.51528 .32511 Mdot
.382 .56218 Mdot
.56971 .32088 Mdot
.44198 .37796 Mdot
.56473 .63696 Mdot
.43038 .36103 Mdot
.52172 .3369 Mdot
.39143 .39016 Mdot
.3704 .26295 Mdot
.60312 .4712 Mdot
.78922 .59965 Mdot
.27867 .58381 Mdot
.62246 .67796 Mdot
.57085 .28173 Mdot
.41035 .61163 Mdot
.38082 .55836 Mdot
.42685 .39142 Mdot
.62004 .68809 Mdot
.37764 .21594 Mdot
.29803 .57343 Mdot
.64638 .59338 Mdot
.6105 .46198 Mdot
.47215 .8455 Mdot
.69641 .63732 Mdot
.58208 .2035 Mdot
.44263 .54152 Mdot
.73824 .36269 Mdot
.35756 .58261 Mdot
.30905 .74179 Mdot
.39957 .34493 Mdot
.68776 .34923 Mdot
.44967 .55918 Mdot
.55175 .33512 Mdot
.38825 .59531 Mdot
.2176 .54659 Mdot
.32882 .62737 Mdot
.42773 .38195 Mdot
.61704 .53779 Mdot
.54763 .66852 Mdot
.40157 .35781 Mdot
.56231 .34934 Mdot
.31069 .40748 Mdot
.36555 .5318 Mdot
.43117 .55575 Mdot
.58811 .30725 Mdot
.56987 .64807 Mdot
.52117 .35484 Mdot
.64659 .47086 Mdot
.40627 .38091 Mdot
.38352 .54721 Mdot
.36794 .52148 Mdot
.5192 .39081 Mdot
.60938 .47671 Mdot
.55296 .30067 Mdot
.64556 .45963 Mdot
.73858 .36174 Mdot
.41423 .53123 Mdot
.58856 .31344 Mdot
.36458 .61362 Mdot
.352 .76784 Mdot
.76323 .63885 Mdot
.4778 .7967 Mdot
.55866 .34153 Mdot
.30937 .45586 Mdot
.62034 .48308 Mdot
.65738 .47028 Mdot
.57458 .79513 Mdot
.23596 .40795 Mdot
.53125 .24224 Mdot
.23798 .64481 Mdot
.64729 .47164 Mdot
.6254 .47812 Mdot
.57122 .35 Mdot
.61094 .67577 Mdot
.54233 .62905 Mdot
.56515 .29607 Mdot
.27919 .53584 Mdot
.57439 .66804 Mdot
.2824 .27501 Mdot
.51382 .34593 Mdot
.44763 .54934 Mdot
.71493 .3776 Mdot
.39467 .37946 Mdot
.2797 .5365 Mdot
.23077 .58065 Mdot
.40356 .61875 Mdot
.6757 .74293 Mdot
.53621 .34797 Mdot
.48446 .39574 Mdot
.2213 .34697 Mdot
.36221 .53952 Mdot
.38171 .59801 Mdot
.36728 .59314 Mdot
.37672 .36709 Mdot
.33847 .74956 Mdot
.4029 .61963 Mdot
.31466 .49119 Mdot
.42809 .61807 Mdot
.23275 .48432 Mdot
.42252 .3708 Mdot
.53729 .60337 Mdot
.59037 .34871 Mdot
.74616 .55903 Mdot
.46818 .58781 Mdot
.64315 .46302 Mdot
.51073 .3034 Mdot
.64514 .48788 Mdot
.22281 .4079 Mdot
.26359 .4337 Mdot
.62964 .65863 Mdot
.41771 .59969 Mdot
.57298 .37087 Mdot
.58966 .63342 Mdot
.65503 .31499 Mdot
.70101 .18409 Mdot
.61572 .46486 Mdot
.81475 .65113 Mdot
.65734 .46939 Mdot
.73536 .3805 Mdot
.60258 .64715 Mdot
.49714 .64622 Mdot
.52188 .45401 Mdot
.59264 .64899 Mdot
.7043 .44478 Mdot
.63915 .66257 Mdot
.32139 .44872 Mdot
.54593 .64579 Mdot
.62673 .4867 Mdot
.5987 .50987 Mdot
.45921 .57081 Mdot
.40953 .60895 Mdot
.55463 .45363 Mdot
.37359 .49033 Mdot
.41291 .60529 Mdot
.55941 .32852 Mdot
.82489 .55182 Mdot
.50967 .36794 Mdot
.61692 .67922 Mdot
.64443 .45395 Mdot
.38342 .59744 Mdot
.39157 .55287 Mdot
.34798 .59007 Mdot
.34577 .78057 Mdot
.28754 .2718 Mdot
.40231 .57469 Mdot
.37945 .63934 Mdot
.55966 .34904 Mdot
.36337 .38306 Mdot
.26077 .67915 Mdot
.2877 .40513 Mdot
.3638 .56071 Mdot
.4173 .36118 Mdot
.38417 .35281 Mdot
.40557 .5185 Mdot
.76676 .55929 Mdot
.51337 .28693 Mdot
.38003 .61374 Mdot
.24752 .44669 Mdot
.50604 .34779 Mdot
.72138 .36041 Mdot
.52537 .33186 Mdot
.55482 .6439 Mdot
.7262 .36939 Mdot
.58216 .34514 Mdot
.48965 .64812 Mdot
.75585 .36199 Mdot
.73866 .51719 Mdot
.41478 .34562 Mdot
.37215 .58116 Mdot
.64021 .67869 Mdot
.538 .37251 Mdot
.61954 .50229 Mdot
.59033 .66491 Mdot
.60794 .51222 Mdot
.3731 .40681 Mdot
.38543 .45332 Mdot
.72274 .37321 Mdot
.64864 .46715 Mdot
.66176 .61447 Mdot
.41923 .36276 Mdot
.66315 .49871 Mdot
.80526 .50192 Mdot
.43271 .53428 Mdot
.1909 .47601 Mdot
.43124 .58246 Mdot
.48484 .17934 Mdot
.65956 .4689 Mdot
.75528 .37049 Mdot
.3629 .59653 Mdot
.53633 .31725 Mdot
.39177 .49568 Mdot
.36532 .56974 Mdot
.56053 .3029 Mdot
.39716 .57037 Mdot
.40291 .39123 Mdot
.56355 .6187 Mdot
.45365 .47741 Mdot
.55154 .8412 Mdot
.39144 .38863 Mdot
.71859 .39203 Mdot
.4152 .60582 Mdot
.35244 .28891 Mdot
.58981 .64824 Mdot
.3655 .53927 Mdot
.6102 .7725 Mdot
.61562 .66812 Mdot
.5965 .66201 Mdot
.41811 .55209 Mdot
.65536 .50524 Mdot
.5395 .31812 Mdot
.41971 .36153 Mdot
.62378 .203 Mdot
.37062 .5647 Mdot
.391 .58622 Mdot
.3991 .35936 Mdot
.62386 .47721 Mdot
.3922 .55051 Mdot
.64737 .35624 Mdot
.63875 .19513 Mdot
.66575 .48547 Mdot
.40841 .51548 Mdot
.19196 .54536 Mdot
.55236 .69636 Mdot
.81663 .62712 Mdot
.45221 .39202 Mdot
.5429 .35588 Mdot
.41081 .50622 Mdot
.33897 .16163 Mdot
.39478 .37699 Mdot
.7396 .58769 Mdot
.4087 .57471 Mdot
.39397 .60383 Mdot
.56443 .66959 Mdot
.40588 .55145 Mdot
.58799 .69062 Mdot
.57674 .84087 Mdot
.43721 .86 Mdot
.58214 .63972 Mdot
.61466 .68607 Mdot
.54993 .60603 Mdot
.28515 .69934 Mdot
.60822 .659 Mdot
.3539 .54172 Mdot
.32898 .26927 Mdot
.40447 .64707 Mdot
.41856 .40009 Mdot
.44322 .34675 Mdot
.52085 .63486 Mdot
.82618 .44493 Mdot
.31902 .53935 Mdot
.46786 .55157 Mdot
.53911 .56583 Mdot
.65977 .48528 Mdot
.36137 .55556 Mdot
.72131 .36949 Mdot
.58103 .3303 Mdot
.35728 .64811 Mdot
.36838 .58057 Mdot
.61506 .65226 Mdot
.37556 .37399 Mdot
.64318 .51925 Mdot
.39289 .58289 Mdot
.58636 .37192 Mdot
.41025 .36783 Mdot
.6209 .66805 Mdot
.65374 .71409 Mdot
.3923 .39663 Mdot
.33273 .55392 Mdot
.40563 .60425 Mdot
.4077 .56763 Mdot
.4623 .55531 Mdot
.62674 .50614 Mdot
.50758 .3341 Mdot
.3389 .55326 Mdot
.73954 .65345 Mdot
.48062 .41992 Mdot
.36971 .52317 Mdot
.56987 .67059 Mdot
.66507 .4655 Mdot
.75053 .37085 Mdot
.32807 .40407 Mdot
.37157 .55409 Mdot
.28674 .27513 Mdot
.5023 .70105 Mdot
.72895 .37147 Mdot
.60989 .63535 Mdot
.41411 .35356 Mdot
.42715 .55261 Mdot
.29453 .30043 Mdot
.36607 .61106 Mdot
.28753 .56729 Mdot
.53888 .35211 Mdot
.65781 .48266 Mdot
.61466 .17993 Mdot
.5811 .32807 Mdot
.59733 .6645 Mdot
.33285 .21581 Mdot
.58393 .70224 Mdot
.5571 .68289 Mdot
.23936 .36534 Mdot
.64063 .50169 Mdot
.32012 .17435 Mdot
.82772 .58236 Mdot
.3889 .62825 Mdot
.62104 .47231 Mdot
.60051 .6434 Mdot
.42163 .59642 Mdot
.60693 .69463 Mdot
.56268 .68683 Mdot
.34936 .55604 Mdot
.40059 .60582 Mdot
.3078 .50319 Mdot
.24564 .30646 Mdot
.42296 .35951 Mdot
.57303 .68493 Mdot
.46782 .71716 Mdot
.4068 .61903 Mdot
.36125 .60105 Mdot
.48693 .36217 Mdot
.42745 .38203 Mdot
.306 .66225 Mdot
.39772 .56519 Mdot
.62241 .77751 Mdot
.43303 .54981 Mdot
.63692 .69052 Mdot
.6658 .48985 Mdot
.76231 .56518 Mdot
.52573 .36715 Mdot
.56301 .67901 Mdot
.38414 .36877 Mdot
.62509 .69444 Mdot
.58384 .77776 Mdot
.64194 .49855 Mdot
.58053 .68111 Mdot
.51628 .32986 Mdot
.63904 .49003 Mdot
.66399 .48942 Mdot
.32429 .28543 Mdot
.55669 .29895 Mdot
.41947 .34567 Mdot
.64391 .48 Mdot
.4226 .70528 Mdot
.62649 .49081 Mdot
.48392 .71851 Mdot
.43114 .59645 Mdot
.3259 .48188 Mdot
.70557 .62751 Mdot
.46339 .61211 Mdot
.60474 .49446 Mdot
.42374 .37949 Mdot
.40836 .5435 Mdot
.56474 .64982 Mdot
.4055 .38447 Mdot
.64105 .54757 Mdot
.53015 .31631 Mdot
.61106 .64126 Mdot
.66744 .48062 Mdot
.58221 .68629 Mdot
.37105 .43763 Mdot
.60258 .37997 Mdot
.54105 .57488 Mdot
.51601 .4438 Mdot
.35621 .60631 Mdot
.51419 .63985 Mdot
.43912 .56361 Mdot
.36604 .5782 Mdot
.545 .32164 Mdot
.27901 .51186 Mdot
.58901 .64482 Mdot
.62759 .18279 Mdot
.65344 .47185 Mdot
.66781 .72992 Mdot
.29741 .60268 Mdot
.36931 .54147 Mdot
.61907 .66189 Mdot
.56898 .69669 Mdot
.47734 .80667 Mdot
.53677 .36955 Mdot
.44935 .6334 Mdot
.34825 .62458 Mdot
.44895 .54434 Mdot
.65863 .46659 Mdot
.65431 .3744 Mdot
.54144 .36332 Mdot
.877 .51489 Mdot
.52677 .34393 Mdot
.4361 .26532 Mdot
.60574 .68128 Mdot
.39966 .34632 Mdot
.36486 .60614 Mdot
.30349 .51975 Mdot
.63171 .65464 Mdot
.47542 .37302 Mdot
.40433 .35056 Mdot
.67623 .40618 Mdot
.64301 .50297 Mdot
.39474 .52083 Mdot
.35126 .55812 Mdot
.41277 .55766 Mdot
.42754 .58253 Mdot
.63591 .45258 Mdot
.40626 .62461 Mdot
.60164 .46895 Mdot
.43212 .69647 Mdot
.61887 .78173 Mdot
.54705 .37824 Mdot
.22301 .43732 Mdot
.6251 .66826 Mdot
.42637 .71693 Mdot
.30886 .64485 Mdot
.76791 .63224 Mdot
.35611 .27383 Mdot
.43828 .56782 Mdot
.55814 .36238 Mdot
.21426 .55596 Mdot
.57009 .37201 Mdot
.55351 .89731 Mdot
.35696 .35619 Mdot
.3146 .23383 Mdot
.4201 .5964 Mdot
.5091 .3809 Mdot
.29862 .62734 Mdot
.40678 .51707 Mdot
.35588 .37341 Mdot
.66192 .68782 Mdot
.70734 .57947 Mdot
.37976 .37737 Mdot
.37941 .56239 Mdot
.54878 .67255 Mdot
.41335 .58747 Mdot
.35671 .5908 Mdot
.42339 .59893 Mdot
.66202 .50798 Mdot
.4471 .58907 Mdot
.41875 .61686 Mdot
.78729 .40956 Mdot
.28604 .4787 Mdot
.57128 .31756 Mdot
.52422 .80514 Mdot
.41302 .37653 Mdot
.60755 .64341 Mdot
.43354 .45265 Mdot
.6544 .50055 Mdot
.46308 .81169 Mdot
.42577 .59144 Mdot
.69619 .62235 Mdot
.66777 .47933 Mdot
.40169 .38341 Mdot
.75208 .3589 Mdot
.33989 .24203 Mdot
.54928 .37748 Mdot
.75625 .36445 Mdot
.54183 .32448 Mdot
.35611 .75182 Mdot
.61596 .65429 Mdot
.34529 .58449 Mdot
.63942 .47153 Mdot
.54381 .31487 Mdot
.26598 .51469 Mdot
.37466 .58826 Mdot
.56149 .33925 Mdot
.35227 .60065 Mdot
.46474 .41308 Mdot
.50482 .29245 Mdot
.58112 .3552 Mdot
.60324 .52117 Mdot
.63796 .48376 Mdot
.41749 .35025 Mdot
.60732 .64194 Mdot
.57301 .67747 Mdot
.6307 .49944 Mdot
.79326 .66125 Mdot
.36406 .56778 Mdot
.42029 .60194 Mdot
.73751 .65003 Mdot
.41032 .59399 Mdot
.31583 .42505 Mdot
.72172 .38053 Mdot
.61843 .65102 Mdot
.42111 .59101 Mdot
.39005 .54971 Mdot
.37641 .55108 Mdot
.37236 .44104 Mdot
.52463 .33509 Mdot
.42278 .546 Mdot
.41509 .39579 Mdot
.78912 .48227 Mdot
.41559 .61232 Mdot
.38851 .51288 Mdot
.57854 .67785 Mdot
.48835 .85522 Mdot
.65818 .49845 Mdot
.56504 .33026 Mdot
.52189 .32778 Mdot
.45485 .36828 Mdot
.57944 .62124 Mdot
.7254 .38493 Mdot
.72462 .27894 Mdot
.73678 .35435 Mdot
.40273 .36073 Mdot
.47486 .23365 Mdot
.59208 .36229 Mdot
.57187 .33384 Mdot
.59668 .48601 Mdot
.42474 .58575 Mdot
.4368 .57414 Mdot
.74225 .58834 Mdot
.39925 .53435 Mdot
.39858 .35205 Mdot
.61986 .50878 Mdot
.57839 .67335 Mdot
.39325 .37989 Mdot
.64241 .45982 Mdot
.56825 .65004 Mdot
.43215 .5347 Mdot
.43994 .54508 Mdot
.59221 .66156 Mdot
.58098 .63435 Mdot
.39431 .61489 Mdot
.76343 .41052 Mdot
.55812 .63556 Mdot
.58306 .68227 Mdot
.72786 .3495 Mdot
.55378 .37757 Mdot
.3222 .59383 Mdot
.62019 .47211 Mdot
.40653 .56787 Mdot
.56429 .37673 Mdot
.42918 .37766 Mdot
.58173 .65017 Mdot
.38849 .55264 Mdot
.3905 .57069 Mdot
.41655 .35918 Mdot
.38245 .38953 Mdot
.38785 .37099 Mdot
.67288 .45693 Mdot
.42467 .57027 Mdot
.60626 .65795 Mdot
.64484 .49993 Mdot
.38406 .35303 Mdot
.4259 .34459 Mdot
.80834 .41603 Mdot
.39855 .61932 Mdot
.51541 .50886 Mdot
.55885 .10922 Mdot
.30287 .40688 Mdot
.74496 .37682 Mdot
.58355 .30175 Mdot
.32687 .47017 Mdot
.46977 .33482 Mdot
.61098 .4804 Mdot
.28025 .36672 Mdot
.40913 .40531 Mdot
.34149 .56659 Mdot
.42846 .5445 Mdot
.39765 .64066 Mdot
.40736 .3723 Mdot
.35823 .42594 Mdot
.61506 .69412 Mdot
.40881 .74949 Mdot
.41276 .3766 Mdot
.58067 .35568 Mdot
.58864 .32142 Mdot
.52718 .34485 Mdot
.4175 .53086 Mdot
.46595 .8054 Mdot
.44475 .71137 Mdot
.33703 .7153 Mdot
.6433 .50433 Mdot
.58067 .70521 Mdot
.36108 .27748 Mdot
.5955 .65963 Mdot
.58196 .33417 Mdot
.40555 .36885 Mdot
.5685 .67814 Mdot
.61098 .49345 Mdot
.62697 .47614 Mdot
.53154 .31624 Mdot
.52996 .32587 Mdot
.56031 .31556 Mdot
.55098 .65478 Mdot
.60565 .68063 Mdot
.37414 .54753 Mdot
.58246 .65663 Mdot
.68858 .73477 Mdot
.4409 .35376 Mdot
.58825 .33524 Mdot
.61572 .48605 Mdot
.60565 .64411 Mdot
.37417 .57921 Mdot
.49984 .24919 Mdot
.70014 .48104 Mdot
.39746 .39313 Mdot
.58298 .25723 Mdot
.61095 .87001 Mdot
.34957 .56561 Mdot
.63363 .45638 Mdot
.77362 .54264 Mdot
.37146 .59471 Mdot
.5423 .34406 Mdot
.32078 .75141 Mdot
.73385 .35297 Mdot
.41825 .61614 Mdot
.38259 .53707 Mdot
.65964 .50517 Mdot
.42959 .42357 Mdot
.38405 .54075 Mdot
.68686 .6678 Mdot
.62379 .52336 Mdot
.55407 .36679 Mdot
.65944 .20158 Mdot
.57192 .28891 Mdot
.26333 .55772 Mdot
.73691 .3787 Mdot
.35367 .55485 Mdot
.55819 .32536 Mdot
.40321 .39479 Mdot
.55586 .31899 Mdot
.61838 .64171 Mdot
.56753 .31643 Mdot
.3914 .58932 Mdot
.60708 .66134 Mdot
.61316 .48937 Mdot
.69606 .70861 Mdot
.79098 .42254 Mdot
.53597 .3172 Mdot
.73949 .34375 Mdot
.41257 .61839 Mdot
.34407 .6737 Mdot
.38975 .49557 Mdot
.4172 .60802 Mdot
.64566 .48921 Mdot
.61949 .66549 Mdot
.61883 .45633 Mdot
.34887 .52713 Mdot
.56646 .81221 Mdot
.65991 .47357 Mdot
.73068 .54286 Mdot
.39969 .36018 Mdot
.28883 .52406 Mdot
.36991 .57163 Mdot
.64341 .47463 Mdot
.42349 .56969 Mdot
.58796 .69831 Mdot
.5496 .50293 Mdot
.79732 .48906 Mdot
.63809 .47168 Mdot
.41596 .18875 Mdot
.5449 .51347 Mdot
.32279 .61521 Mdot
.64627 .47372 Mdot
.40655 .79036 Mdot
.74639 .37142 Mdot
.40964 .36313 Mdot
.38009 .36201 Mdot
.38876 .3884 Mdot
.398 .5323 Mdot
.38429 .66551 Mdot
.42157 .34409 Mdot
.6336 .52406 Mdot
.42456 .38759 Mdot
.31867 .49832 Mdot
.40396 .19629 Mdot
.38778 .3779 Mdot
.37911 .57209 Mdot
.3918 .51139 Mdot
.2827 .48284 Mdot
.57406 .35982 Mdot
.26517 .29571 Mdot
.55565 .72107 Mdot
.40586 .61374 Mdot
.31652 .62172 Mdot
.62486 .6537 Mdot
.7978 .53818 Mdot
.305 .61092 Mdot
.48962 .3178 Mdot
.60258 .69142 Mdot
.59379 .29746 Mdot
.61445 .64725 Mdot
.34813 .57994 Mdot
.40509 .57787 Mdot
.56524 .61423 Mdot
.6204 .37725 Mdot
.74403 .47539 Mdot
.53974 .18632 Mdot
.57482 .68293 Mdot
.63987 .46613 Mdot
.61939 .46066 Mdot
.65018 .49732 Mdot
.52126 .36166 Mdot
.56074 .64109 Mdot
.4286 .56639 Mdot
.55442 .35517 Mdot
.36156 .5642 Mdot
.64192 .48665 Mdot
.6094 .17761 Mdot
.57869 .67651 Mdot
.37684 .61168 Mdot
.83377 .55493 Mdot
.53189 .33589 Mdot
.41915 .36535 Mdot
.47521 .4036 Mdot
.5139 .32368 Mdot
.60493 .49164 Mdot
.53953 .65016 Mdot
.67285 .50117 Mdot
.42757 .4598 Mdot
.42088 .63903 Mdot
.37613 .52267 Mdot
.6577 .21581 Mdot
.83047 .47504 Mdot
.40599 .5296 Mdot
.56309 .34881 Mdot
.56248 .37122 Mdot
.3854 .55505 Mdot
.56015 .64838 Mdot
.39344 .34433 Mdot
.40762 .39956 Mdot
.33507 .57577 Mdot
.52475 .4518 Mdot
.3174 .49236 Mdot
.39846 .55078 Mdot
.45031 .63815 Mdot
.53112 .31332 Mdot
.75182 .35579 Mdot
.72672 .64011 Mdot
.38721 .35685 Mdot
.40715 .57267 Mdot
.72551 .50315 Mdot
.5921 .69196 Mdot
.56572 .3169 Mdot
.61677 .50358 Mdot
.37874 .42819 Mdot
.51518 .33875 Mdot
.3865 .55544 Mdot
.39176 .55041 Mdot
.66147 .50239 Mdot
.6369 .69023 Mdot
.40488 .37098 Mdot
.55327 .35419 Mdot
.39384 .34807 Mdot
.60531 .67409 Mdot
.58126 .67319 Mdot
.39539 .65001 Mdot
.45927 .5493 Mdot
.52815 .32182 Mdot
.34952 .60793 Mdot
.58405 .33636 Mdot
.42813 .41783 Mdot
.65283 .45486 Mdot
.35527 .54462 Mdot
.55329 .68744 Mdot
.64164 .49184 Mdot
.39295 .60857 Mdot
.74172 .27322 Mdot
.36377 .54456 Mdot
.50947 .33024 Mdot
.57423 .80999 Mdot
.42575 .38059 Mdot
.6351 .72866 Mdot
.4849 .56258 Mdot
.40837 .59336 Mdot
.58612 .32414 Mdot
.3808 .49902 Mdot
.66318 .48369 Mdot
.61007 .68463 Mdot
.77119 .72624 Mdot
.63015 .48943 Mdot
.41339 .58488 Mdot
.40524 .38195 Mdot
.56392 .69459 Mdot
.72643 .36256 Mdot
.73416 .63309 Mdot
.34925 .64299 Mdot
.44575 .55221 Mdot
.42254 .5867 Mdot
.24249 .66469 Mdot
.56328 .32655 Mdot
.60305 .64357 Mdot
.65587 .46285 Mdot
.62441 .49906 Mdot
.53241 .34908 Mdot
.69223 .60078 Mdot
.61791 .36002 Mdot
.46684 .08915 Mdot
.55985 .30465 Mdot
.42945 .38371 Mdot
.49634 .43835 Mdot
.58081 .32197 Mdot
.55655 .33246 Mdot
.52199 .32546 Mdot
.71662 .61256 Mdot
.56696 .65958 Mdot
.39131 .57021 Mdot
.58628 .62141 Mdot
.35499 .5513 Mdot
.24822 .58775 Mdot
.63176 .50119 Mdot
.60805 .68497 Mdot
.70148 .24127 Mdot
.36911 .49215 Mdot
.37819 .59495 Mdot
.39308 .2397 Mdot
.33544 .53543 Mdot
.33733 .43259 Mdot
.32699 .56563 Mdot
.53561 .32364 Mdot
.35019 .6559 Mdot
.42358 .51346 Mdot
.68834 .73062 Mdot
.61528 .48188 Mdot
.73195 .38132 Mdot
.44305 .58156 Mdot
.35618 .64249 Mdot
.56133 .6907 Mdot
.56865 .6787 Mdot
.41944 .34364 Mdot
.50909 .41836 Mdot
.61313 .48692 Mdot
.58344 .40991 Mdot
.40876 .60768 Mdot
.60168 .53367 Mdot
.57857 .78989 Mdot
.39112 .60937 Mdot
.31561 .28312 Mdot
.46785 .81055 Mdot
.38067 .54099 Mdot
.38323 .75556 Mdot
.62371 .48052 Mdot
.61956 .77624 Mdot
.3741 .63109 Mdot
.54217 .34262 Mdot
.61089 .67857 Mdot
.62044 .64736 Mdot
.39224 .38555 Mdot
.74935 .69007 Mdot
.60132 .48447 Mdot
.60675 .68252 Mdot
.36855 .59 Mdot
.62347 .50537 Mdot
.72409 .37266 Mdot
.40321 .51108 Mdot
.27117 .35724 Mdot
.58096 .66037 Mdot
.37422 .63771 Mdot
.62593 .57026 Mdot
.4606 .42345 Mdot
.21747 .32978 Mdot
.6536 .49201 Mdot
.38631 .36297 Mdot
.3239 .58081 Mdot
.71899 .27481 Mdot
.41815 .62935 Mdot
.29214 .50783 Mdot
.53079 .67267 Mdot
.40667 .34428 Mdot
.37157 .60099 Mdot
.38869 .5414 Mdot
.51286 .45498 Mdot
.37918 .38392 Mdot
.36002 .54456 Mdot
.40981 .64864 Mdot
.56986 .64936 Mdot
.72418 .38096 Mdot
.57806 .6659 Mdot
.37873 .57569 Mdot
.36691 .66584 Mdot
.56194 .65818 Mdot
.51899 .21438 Mdot
.38797 .40133 Mdot
.65785 .49696 Mdot
.42945 .65404 Mdot
.42935 .59849 Mdot
.17036 .57467 Mdot
.73824 .38125 Mdot
.29713 .73397 Mdot
.55983 .29573 Mdot
.7094 .45571 Mdot
.55842 .39487 Mdot
.33307 .2255 Mdot
.70162 .68824 Mdot
.40002 .64411 Mdot
.24791 .42472 Mdot
.36344 .73854 Mdot
.60607 .47025 Mdot
.38339 .69618 Mdot
.40967 .60908 Mdot
.35641 .58517 Mdot
.56837 .35545 Mdot
.68351 .61279 Mdot
.76902 .54652 Mdot
.53947 .45432 Mdot
.40033 .37149 Mdot
.60009 .68013 Mdot
.39822 .59395 Mdot
.62998 .29708 Mdot
.56786 .31204 Mdot
.58172 .55441 Mdot
.3697 .60576 Mdot
.77457 .58844 Mdot
.72594 .57235 Mdot
.62524 .5068 Mdot
.58409 .30513 Mdot
.51512 .32277 Mdot
.35245 .58876 Mdot
.60892 .4969 Mdot
.37502 .54553 Mdot
.56485 .53144 Mdot
.36097 .62434 Mdot
.40092 .38693 Mdot
.38751 .62403 Mdot
.49962 .47118 Mdot
.27402 .25514 Mdot
.31275 .58048 Mdot
.57717 .62941 Mdot
.51957 .35847 Mdot
.52627 .33991 Mdot
.57388 .68007 Mdot
.52798 .34207 Mdot
.4212 .75856 Mdot
.55816 .75748 Mdot
.39641 .36953 Mdot
.34949 .66728 Mdot
.40539 .3879 Mdot
.73328 .38181 Mdot
.40132 .61764 Mdot
.74157 .29688 Mdot
.55257 .30577 Mdot
.39543 .80873 Mdot
.62509 .49286 Mdot
.73625 .3811 Mdot
.42416 .62242 Mdot
.46859 .2357 Mdot
.57849 .34802 Mdot
.52989 .29969 Mdot
.3754 .55082 Mdot
.56894 .67382 Mdot
.39024 .54198 Mdot
.33376 .59506 Mdot
.75569 .36521 Mdot
.42408 .58495 Mdot
.64183 .45981 Mdot
.55647 .64478 Mdot
.35539 .22654 Mdot
.53541 .37208 Mdot
.37819 .61912 Mdot
.3687 .59134 Mdot
.59157 .7003 Mdot
.42287 .62098 Mdot
.60791 .48677 Mdot
.21187 .25232 Mdot
.40119 .35978 Mdot
.74736 .35127 Mdot
.51105 .32196 Mdot
.43552 .56213 Mdot
.39747 .54714 Mdot
.64647 .20882 Mdot
.76968 .45569 Mdot
.64375 .46189 Mdot
.3319 .56745 Mdot
.55949 .34816 Mdot
.40268 .38253 Mdot
.63368 .52045 Mdot
.40564 .56492 Mdot
.36077 .59739 Mdot
.39937 .38586 Mdot
.33799 .26686 Mdot
.51222 .28628 Mdot
.64694 .50199 Mdot
.34084 .65299 Mdot
.50576 .255 Mdot
.36458 .56866 Mdot
.5668 .22154 Mdot
.58358 .6808 Mdot
.64976 .47806 Mdot
.30407 .70585 Mdot
.3447 .5845 Mdot
.60823 .48028 Mdot
.61388 .48623 Mdot
.3806 .62624 Mdot
.57766 .62218 Mdot
.55304 .66778 Mdot
.58658 .68658 Mdot
.576 .81677 Mdot
.24148 .51751 Mdot
.55927 .31484 Mdot
.62368 .47907 Mdot
.5755 .36621 Mdot
.38816 .3465 Mdot
.4829 .42124 Mdot
.57255 .36636 Mdot
.62334 .65164 Mdot
.5891 .32314 Mdot
.38253 .54534 Mdot
.61177 .48698 Mdot
.57249 .33306 Mdot
.42947 .54841 Mdot
.4707 .61281 Mdot
.53327 .52355 Mdot
.39813 .34281 Mdot
.46644 .38311 Mdot
.40025 .58131 Mdot
.75292 .36809 Mdot
.39011 .61575 Mdot
.62754 .50977 Mdot
.48145 .45817 Mdot
.42785 .54836 Mdot
.53272 .3184 Mdot
.47544 .51179 Mdot
.55871 .36786 Mdot
.3421 .61451 Mdot
.38063 .57577 Mdot
.36119 .57145 Mdot
.38395 .54047 Mdot
.72257 .56053 Mdot
.61107 .46076 Mdot
.46159 .63655 Mdot
.56836 .37981 Mdot
.59056 .65374 Mdot
.62089 .69308 Mdot
.53549 .24561 Mdot
.75529 .35574 Mdot
.61947 .47447 Mdot
.36599 .56671 Mdot
.5325 .29688 Mdot
.59986 .17509 Mdot
.55664 .2102 Mdot
.367 .28273 Mdot
.56741 .34375 Mdot
.57874 .62973 Mdot
.57696 .32349 Mdot
.35277 .57877 Mdot
.34965 .53221 Mdot
.33928 .22864 Mdot
.6197 .44434 Mdot
.40631 .36973 Mdot
.35852 .56778 Mdot
.26179 .56562 Mdot
.55957 .34911 Mdot
.53398 .31048 Mdot
.36112 .55029 Mdot
.55957 .67561 Mdot
.16574 .37722 Mdot
.61857 .50535 Mdot
.35109 .67944 Mdot
.59317 .72912 Mdot
.66404 .67726 Mdot
.62108 .50083 Mdot
.53965 .54978 Mdot
.52963 .35607 Mdot
.60471 .74555 Mdot
.58978 .65742 Mdot
.41027 .37049 Mdot
.35468 .53211 Mdot
.62027 .64816 Mdot
.57973 .29624 Mdot
.62303 .66366 Mdot
.34531 .57586 Mdot
.60951 .46429 Mdot
.53284 .35303 Mdot
.59792 .51931 Mdot
.56675 .61344 Mdot
.41486 .38811 Mdot
.28837 .52704 Mdot
.37807 .6904 Mdot
.46602 .81092 Mdot
.42326 .54655 Mdot
.53875 .27583 Mdot
.42393 .56717 Mdot
.5605 .68782 Mdot
.37145 .57134 Mdot
.51965 .63154 Mdot
.56996 .29941 Mdot
.37434 .63737 Mdot
.41392 .62063 Mdot
.46742 .67427 Mdot
.38147 .60259 Mdot
.41301 .626 Mdot
.38889 .53776 Mdot
.5825 .7275 Mdot
.3966 .64759 Mdot
.56674 .66605 Mdot
.73474 .59502 Mdot
.55481 .33117 Mdot
.41137 .33859 Mdot
.39814 .39824 Mdot
.29991 .50165 Mdot
.28549 .5275 Mdot
.69523 .60444 Mdot
.5732 .66292 Mdot
.62811 .46129 Mdot
.374 .54593 Mdot
.29797 .69263 Mdot
.4229 .40645 Mdot
.53021 .35496 Mdot
.51728 .3621 Mdot
.45121 .53374 Mdot
.23574 .65762 Mdot
.37879 .6413 Mdot
.73971 .63346 Mdot
.33823 .58614 Mdot
.36432 .54011 Mdot
.51282 .33646 Mdot
.37778 .4591 Mdot
.42307 .54613 Mdot
.56156 .69109 Mdot
.41435 .36899 Mdot
.30831 .57333 Mdot
.38268 .32293 Mdot
.55866 .54668 Mdot
.49845 .66354 Mdot
.42961 .57447 Mdot
.54721 .35488 Mdot
.60925 .64013 Mdot
.73171 .65855 Mdot
.64648 .49736 Mdot
.70741 .63755 Mdot
.45357 .69545 Mdot
.47533 .21364 Mdot
.41022 .36819 Mdot
.331 .27648 Mdot
.39192 .58925 Mdot
.5168 .35485 Mdot
.34728 .56426 Mdot
.5921 .17392 Mdot
.43075 .36458 Mdot
.63115 .65091 Mdot
.63816 .46509 Mdot
.58881 .69748 Mdot
.48446 .79677 Mdot
.52872 .58039 Mdot
.70624 .39286 Mdot
.55463 .37656 Mdot
.26837 .63509 Mdot
.61103 .65816 Mdot
.3955 .55811 Mdot
.49785 .09268 Mdot
.58514 .68087 Mdot
.57581 .68735 Mdot
.44856 .40568 Mdot
.34715 .37788 Mdot
.38388 .50039 Mdot
.62293 .67222 Mdot
.58429 .3586 Mdot
.4236 .36552 Mdot
.41122 .54156 Mdot
.39039 .53907 Mdot
.56563 .67166 Mdot
.58095 .34234 Mdot
.26115 .6344 Mdot
.5323 .32482 Mdot
.57279 .6446 Mdot
.53698 .33241 Mdot
.49971 .33914 Mdot
.56865 .33395 Mdot
.42747 .60846 Mdot
.36901 .56573 Mdot
.39218 .30322 Mdot
.58127 .67298 Mdot
.40486 .54692 Mdot
.40248 .57278 Mdot
.6077 .65687 Mdot
.59183 .36018 Mdot
.28527 .68049 Mdot
.41717 .59924 Mdot
.38239 .566 Mdot
.39967 .34569 Mdot
.60526 .33309 Mdot
.62241 .26654 Mdot
.40928 .54382 Mdot
.41512 .3979 Mdot
.55035 .65232 Mdot
.39092 .61469 Mdot
.3307 .48861 Mdot
.51267 .36617 Mdot
.37731 .62198 Mdot
.72535 .36263 Mdot
.43679 .56851 Mdot
.17461 .36748 Mdot
.38948 .62162 Mdot
.59939 .64393 Mdot
.61504 .67121 Mdot
.47526 .38522 Mdot
.59763 .66805 Mdot
.73155 .37885 Mdot
.6406 .4871 Mdot
.50932 .18325 Mdot
.72633 .37406 Mdot
.37137 .53554 Mdot
.82758 .58286 Mdot
.35285 .60996 Mdot
.4421 .57721 Mdot
.2912 .70883 Mdot
.72807 .37462 Mdot
.617 .65963 Mdot
.62033 .38208 Mdot
.33441 .57022 Mdot
.61479 .50314 Mdot
.39541 .51415 Mdot
.3878 .62614 Mdot
.67497 .67004 Mdot
.52799 .82172 Mdot
.63416 .5114 Mdot
.32118 .57587 Mdot
.40988 .54439 Mdot
.81658 .45857 Mdot
.37401 .58572 Mdot
.38899 .38071 Mdot
.58161 .68846 Mdot
.574 .31019 Mdot
.40789 .35581 Mdot
.41051 .60005 Mdot
.40933 .37444 Mdot
.56375 .31711 Mdot
.64739 .48584 Mdot
.3722 .61584 Mdot
.41591 .40125 Mdot
.40191 .37204 Mdot
.41887 .56142 Mdot
.60903 .6825 Mdot
.33553 .5158 Mdot
.3916 .61357 Mdot
.39207 .55783 Mdot
.57302 .67737 Mdot
.86063 .45246 Mdot
.35013 .57763 Mdot
.5198 .51387 Mdot
.62493 .64231 Mdot
.71657 .36717 Mdot
.57581 .33034 Mdot
.36732 .61863 Mdot
.63182 .50339 Mdot
.63752 .49835 Mdot
.5922 .30983 Mdot
.58357 .69863 Mdot
.57495 .35727 Mdot
.32032 .55795 Mdot
.46207 .5605 Mdot
.33729 .55475 Mdot
.75981 .73397 Mdot
.32818 .24666 Mdot
.56303 .64145 Mdot
.53829 .36248 Mdot
.54159 .45262 Mdot
.62401 .4736 Mdot
.59058 .3236 Mdot
.54535 .6726 Mdot
.58049 .63239 Mdot
.62514 .66562 Mdot
.39802 .34819 Mdot
.51857 .34586 Mdot
.63839 .68249 Mdot
.56438 .68237 Mdot
.37795 .54865 Mdot
.40982 .54541 Mdot
.52945 .62777 Mdot
.29624 .46272 Mdot
.41016 .38964 Mdot
.54186 .35125 Mdot
.15151 .57416 Mdot
.62914 .50997 Mdot
.4708 .67263 Mdot
.43352 .5568 Mdot
.69293 .17047 Mdot
.36782 .63879 Mdot
.36979 .58826 Mdot
.55397 .64481 Mdot
.43285 .38278 Mdot
.41753 .37997 Mdot
.61194 .66031 Mdot
.54294 .62708 Mdot
.38507 .3722 Mdot
.34842 .28446 Mdot
.42057 .18312 Mdot
.72166 .65847 Mdot
.60075 .64736 Mdot
.381 .68786 Mdot
.60575 .49258 Mdot
.58051 .61323 Mdot
.6463 .50852 Mdot
.55553 .3336 Mdot
.51838 .3352 Mdot
.65945 .50407 Mdot
.37341 .55273 Mdot
.56865 .32155 Mdot
.35628 .64966 Mdot
.37455 .23418 Mdot
.20149 .43166 Mdot
.75163 .43523 Mdot
.43438 .55285 Mdot
.765 .56066 Mdot
.76978 .51294 Mdot
.40471 .58762 Mdot
.31763 .51875 Mdot
.40782 .37092 Mdot
.59603 .61718 Mdot
.60834 .48976 Mdot
.20947 .34245 Mdot
.36516 .56789 Mdot
.58755 .64403 Mdot
.61598 .47902 Mdot
.50952 .39435 Mdot
.68342 .66198 Mdot
.35561 .554 Mdot
.38694 .12733 Mdot
.61293 .62418 Mdot
.57373 .30961 Mdot
.7912 .63669 Mdot
.59231 .62144 Mdot
.46104 .38487 Mdot
.53475 .30711 Mdot
.56325 .19748 Mdot
.60537 .64209 Mdot
.59326 .30432 Mdot
.60354 .67272 Mdot
.39915 .38871 Mdot
.5472 .63842 Mdot
.53671 .35555 Mdot
.37586 .60328 Mdot
.53246 .34608 Mdot
.4087 .39094 Mdot
.51882 .36064 Mdot
.60741 .49194 Mdot
.7425 .37721 Mdot
.63251 .47815 Mdot
.47452 .41634 Mdot
.54533 .81862 Mdot
.65783 .48328 Mdot
.56579 .4017 Mdot
.40939 .53108 Mdot
.63448 .69447 Mdot
.56754 .30399 Mdot
.57559 .37257 Mdot
.49901 .42762 Mdot
.59608 .65262 Mdot
.53598 .35218 Mdot
.44186 .69988 Mdot
.86523 .53755 Mdot
.39966 .66273 Mdot
.24082 .48407 Mdot
.60594 .65403 Mdot
.5615 .29835 Mdot
.73667 .64851 Mdot
.62713 .67397 Mdot
.55892 .30525 Mdot
.64393 .47152 Mdot
.6232 .4997 Mdot
.36173 .55763 Mdot
.59493 .46993 Mdot
.58419 .31253 Mdot
.73913 .48667 Mdot
.58691 .69314 Mdot
.5097 .39568 Mdot
.38923 .38513 Mdot
.56077 .33358 Mdot
.43461 .52146 Mdot
.53747 .62944 Mdot
.54166 .3792 Mdot
.24291 .39762 Mdot
.16822 .60616 Mdot
.5356 .3502 Mdot
.58264 .68936 Mdot
.58089 .64865 Mdot
.35058 .51557 Mdot
.52042 .45014 Mdot
.5718 .35843 Mdot
.74984 .31279 Mdot
.28321 .51588 Mdot
.73814 .36138 Mdot
.83685 .47724 Mdot
.42475 .5471 Mdot
.42182 .57041 Mdot
.62558 .47016 Mdot
.38441 .59327 Mdot
.55714 .6741 Mdot
.43869 .59096 Mdot
.61148 .47298 Mdot
.53333 .35734 Mdot
.38299 .61882 Mdot
.42474 .37662 Mdot
.60644 .5036 Mdot
.65323 .51124 Mdot
.54742 .32635 Mdot
.62394 .67028 Mdot
.61569 .29204 Mdot
.52922 .327 Mdot
.43063 .57328 Mdot
.7323 .3717 Mdot
.34863 .59186 Mdot
.30993 .32112 Mdot
.61062 .69663 Mdot
.57701 .32011 Mdot
.60859 .63502 Mdot
.63084 .48232 Mdot
.59288 .33925 Mdot
.3788 .58355 Mdot
.55275 .30752 Mdot
.44045 .32235 Mdot
.33217 .29866 Mdot
.57765 .69773 Mdot
.40215 .32577 Mdot
.57445 .6884 Mdot
.73714 .36052 Mdot
.30534 .3598 Mdot
.40405 .36379 Mdot
.55967 .34418 Mdot
.31599 .25368 Mdot
.53828 .31262 Mdot
.38378 .60346 Mdot
.39825 .60436 Mdot
.56958 .35315 Mdot
.425 .35814 Mdot
.49226 .85309 Mdot
.52943 .54685 Mdot
.61831 .65726 Mdot
.59128 .7381 Mdot
.13235 .50955 Mdot
.61699 .52396 Mdot
.63014 .46487 Mdot
.35419 .63414 Mdot
.36813 .54223 Mdot
.64818 .51665 Mdot
.64613 .45462 Mdot
.39672 .34491 Mdot
.5208 .3338 Mdot
.64038 .69812 Mdot
.61709 .51792 Mdot
.46709 .5193 Mdot
.26697 .55705 Mdot
.35174 .5173 Mdot
.44269 .63108 Mdot
.42691 .53772 Mdot
.4556 .42153 Mdot
.64029 .45556 Mdot
.39863 .57915 Mdot
.38789 .64911 Mdot
.64868 .47182 Mdot
.4007 .38859 Mdot
.63026 .61891 Mdot
.53881 .33812 Mdot
.8382 .36192 Mdot
.37858 .62106 Mdot
.38093 .60806 Mdot
.64276 .50455 Mdot
.82819 .4463 Mdot
.57579 .63693 Mdot
.61452 .69037 Mdot
.56401 .32555 Mdot
.50003 .42541 Mdot
.43149 .60724 Mdot
.40286 .58513 Mdot
.55349 .34386 Mdot
.74544 .37512 Mdot
.72733 .42808 Mdot
.3897 .57132 Mdot
.6172 .48567 Mdot
.50587 .31074 Mdot
.64073 .45498 Mdot
.34927 .56368 Mdot
.38631 .60331 Mdot
.42714 .61013 Mdot
.36929 .54087 Mdot
.64489 .51428 Mdot
.39747 .58412 Mdot
.44083 .52544 Mdot
.61607 .68199 Mdot
.42898 .58601 Mdot
.31647 .4868 Mdot
.37895 .56737 Mdot
.42224 .38086 Mdot
.62139 .28314 Mdot
.36026 .56932 Mdot
.42787 .58647 Mdot
.52929 .54107 Mdot
.36773 .5979 Mdot
.63349 .50966 Mdot
.58638 .65274 Mdot
.62405 .47839 Mdot
.65904 .46646 Mdot
.57603 .36856 Mdot
.39924 .34371 Mdot
.42521 .62691 Mdot
.39312 .39252 Mdot
.45517 .59999 Mdot
.3447 .57323 Mdot
.58183 .27912 Mdot
.73937 .63079 Mdot
.47636 .33206 Mdot
.37809 .58029 Mdot
.56012 .32808 Mdot
.57335 .31212 Mdot
.24552 .41528 Mdot
.32626 .62592 Mdot
.64172 .51819 Mdot
.64307 .4742 Mdot
.31083 .42107 Mdot
.67917 .67928 Mdot
.41665 .38628 Mdot
.55717 .45626 Mdot
.42214 .53575 Mdot
.39329 .56686 Mdot
.39138 .5127 Mdot
.57253 .36702 Mdot
.75616 .36145 Mdot
.52701 .35294 Mdot
.71043 .36747 Mdot
.63161 .45426 Mdot
.43681 .57575 Mdot
.20885 .40551 Mdot
.56131 .6662 Mdot
.58598 .65351 Mdot
.64013 .52266 Mdot
.56493 .36602 Mdot
.36376 .50541 Mdot
.77389 .72797 Mdot
.60739 .61683 Mdot
.43552 .35443 Mdot
.40694 .58531 Mdot
.55211 .32565 Mdot
.56063 .67029 Mdot
.39734 .40184 Mdot
.42317 .6012 Mdot
.57249 .37922 Mdot
.37288 .5692 Mdot
.35808 .73962 Mdot
.61721 .67678 Mdot
.59796 .1714 Mdot
.58437 .70211 Mdot
.60416 .50045 Mdot
.65489 .47199 Mdot
.39145 .60766 Mdot
.77474 .69743 Mdot
.62972 .64524 Mdot
.59396 .50723 Mdot
.43376 .37114 Mdot
.74797 .35228 Mdot
.42604 .35096 Mdot
.58201 .32271 Mdot
.41246 .36761 Mdot
.52222 .32735 Mdot
.30402 .43411 Mdot
.63088 .63656 Mdot
.40441 .35763 Mdot
.80631 .42656 Mdot
.44636 .60128 Mdot
.3835 .35452 Mdot
.45144 .53663 Mdot
.60658 .73923 Mdot
.55067 .34206 Mdot
.42573 .36079 Mdot
.39421 .55571 Mdot
.20321 .36494 Mdot
.65734 .47021 Mdot
.6386 .51826 Mdot
.44467 .61342 Mdot
.52301 .3221 Mdot
.54474 .62792 Mdot
.43909 .45667 Mdot
.7158 .37392 Mdot
.40062 .58417 Mdot
.43719 .57395 Mdot
.61439 .6998 Mdot
.57504 .70349 Mdot
.38919 .60382 Mdot
.40846 .70168 Mdot
.39428 .58995 Mdot
.62504 .50339 Mdot
.57954 .6338 Mdot
.58188 .65086 Mdot
.58504 .3095 Mdot
.57782 .69467 Mdot
.43847 .63724 Mdot
.64745 .43607 Mdot
.33419 .5565 Mdot
.63234 .48782 Mdot
.48869 .46555 Mdot
.5265 .36723 Mdot
.23775 .32063 Mdot
.60755 .70258 Mdot
.4252 .58602 Mdot
.57846 .69233 Mdot
.38892 .36806 Mdot
.58145 .66989 Mdot
.58076 .62648 Mdot
.40479 .60791 Mdot
.35388 .5549 Mdot
.73253 .37614 Mdot
.52035 .44616 Mdot
.60015 .68857 Mdot
.39986 .59083 Mdot
.36051 .62022 Mdot
.39914 .62978 Mdot
.52642 .48859 Mdot
.56836 .63493 Mdot
.50705 .72459 Mdot
.25665 .36325 Mdot
.60464 .68543 Mdot
.16072 .40649 Mdot
.72958 .35709 Mdot
.75248 .35367 Mdot
.60562 .51462 Mdot
.38931 .56916 Mdot
.55286 .36544 Mdot
.35286 .58255 Mdot
.36444 .65267 Mdot
.35881 .59482 Mdot
.42932 .37919 Mdot
.42311 .6303 Mdot
.74525 .36172 Mdot
.52748 .33074 Mdot
.42081 .59818 Mdot
.37755 .61722 Mdot
.75821 .35793 Mdot
.60035 .70462 Mdot
.59066 .63409 Mdot
.56006 .21832 Mdot
.39305 .37189 Mdot
.64611 .49196 Mdot
.36684 .55743 Mdot
.56184 .32757 Mdot
.53069 .34334 Mdot
.58521 .69593 Mdot
.54005 .34381 Mdot
.62108 .50718 Mdot
.37775 .5877 Mdot
.64288 .51695 Mdot
.42673 .38267 Mdot
.58029 .68711 Mdot
.36491 .55831 Mdot
.37804 .54904 Mdot
.6152 .67098 Mdot
.40963 .53097 Mdot
.39904 .34594 Mdot
.52695 .32486 Mdot
.59648 .63721 Mdot
.64046 .4902 Mdot
.58678 .31648 Mdot
.38754 .54778 Mdot
.19037 .63569 Mdot
.38753 .59307 Mdot
.38626 .55779 Mdot
.37874 .20484 Mdot
.35038 .62847 Mdot
.57335 .30234 Mdot
.6255 .68664 Mdot
.44164 .55035 Mdot
.25447 .55987 Mdot
.66977 .23344 Mdot
.59125 .32885 Mdot
.41467 .58815 Mdot
.25502 .30094 Mdot
.41884 .59286 Mdot
.5819 .41295 Mdot
.52723 .26432 Mdot
.22615 .56727 Mdot
.44723 .62537 Mdot
.65251 .50664 Mdot
.73322 .3773 Mdot
.55281 .30201 Mdot
.41786 .79 Mdot
.40533 .60093 Mdot
.39931 .78835 Mdot
.40567 .62464 Mdot
.62064 .49953 Mdot
.38775 .48687 Mdot
.54097 .34986 Mdot
.72319 .70952 Mdot
.42863 .56806 Mdot
.56962 .6349 Mdot
.58827 .33657 Mdot
.74085 .35171 Mdot
.38918 .55323 Mdot
.4014 .39701 Mdot
.58137 .46473 Mdot
.46434 .59848 Mdot
.63421 .48994 Mdot
.40368 .57192 Mdot
.31963 .59138 Mdot
.76308 .69316 Mdot
.6193 .67371 Mdot
.6339 .46531 Mdot
.79804 .52521 Mdot
.40232 .52747 Mdot
.6032 .64039 Mdot
.59064 .65649 Mdot
.39766 .39084 Mdot
.57221 .49831 Mdot
.66214 .55206 Mdot
.18799 .4743 Mdot
.5155 .80675 Mdot
.58114 .30134 Mdot
.75581 .48304 Mdot
.41463 .54457 Mdot
.53955 .57964 Mdot
.64306 .50823 Mdot
.37799 .60658 Mdot
.55184 .80183 Mdot
.58503 .68549 Mdot
.38622 .57254 Mdot
.40329 .38817 Mdot
.5744 .47276 Mdot
.56952 .55667 Mdot
.1701 .55228 Mdot
.58895 .34363 Mdot
.36065 .52613 Mdot
.45541 .60921 Mdot
.72001 .36062 Mdot
.34417 .56396 Mdot
.56152 .30137 Mdot
.37928 .24205 Mdot
.42675 .35958 Mdot
.56557 .67925 Mdot
.73054 .35622 Mdot
.43593 .54757 Mdot
.37705 .63033 Mdot
.41338 .33874 Mdot
.40947 .56417 Mdot
.75361 .68078 Mdot
.69968 .385 Mdot
.5706 .32658 Mdot
.62276 .65822 Mdot
.41549 .52928 Mdot
.75578 .36203 Mdot
.40257 .60656 Mdot
.49871 .63596 Mdot
.42068 .57659 Mdot
.6287 .57585 Mdot
.61019 .67849 Mdot
.6355 .48609 Mdot
.45195 .59955 Mdot
.35867 .58553 Mdot
.5021 .25265 Mdot
.36475 .65262 Mdot
.38668 .62162 Mdot
.56169 .69199 Mdot
.56004 .65198 Mdot
.56818 .6679 Mdot
.56784 .31562 Mdot
.72451 .64858 Mdot
.62228 .48751 Mdot
.43294 .6125 Mdot
.61771 .51812 Mdot
.49407 .59828 Mdot
.4247 .34289 Mdot
.16962 .42844 Mdot
.4266 .59424 Mdot
.56976 .66401 Mdot
.71923 .51951 Mdot
.55048 .65456 Mdot
.56169 .3855 Mdot
.61288 .48713 Mdot
.58673 .68266 Mdot
.36359 .58661 Mdot
.53196 .45769 Mdot
.18691 .56776 Mdot
.62873 .47331 Mdot
.37886 .51514 Mdot
.5893 .34713 Mdot
.5197 .36688 Mdot
.12324 .45887 Mdot
.64744 .46248 Mdot
.77049 .5068 Mdot
.40413 .59229 Mdot
.56205 .66614 Mdot
.65547 .49208 Mdot
.66164 .49505 Mdot
.54796 .34421 Mdot
.3549 .5575 Mdot
.36176 .57408 Mdot
.72617 .36135 Mdot
.64392 .47812 Mdot
.44787 .58211 Mdot
.33843 .57548 Mdot
.34153 .22599 Mdot
.64167 .63457 Mdot
.85025 .41828 Mdot
.32003 .55903 Mdot
.51397 .81115 Mdot
.48322 .4399 Mdot
.55905 .64368 Mdot
.35781 .56388 Mdot
.41822 .52669 Mdot
.58163 .30607 Mdot
.38275 .58953 Mdot
.54515 .36885 Mdot
.62728 .4645 Mdot
.16196 .44382 Mdot
.68255 .44815 Mdot
.35777 .27553 Mdot
.38067 .59651 Mdot
.66395 .653 Mdot
.40146 .35367 Mdot
.67576 .46902 Mdot
.57501 .64117 Mdot
.39513 .5221 Mdot
.51068 .32975 Mdot
.56009 .34521 Mdot
.59139 .66553 Mdot
.75392 .53942 Mdot
.54909 .22752 Mdot
.3528 .54856 Mdot
.57717 .33277 Mdot
.69171 .43535 Mdot
.40244 .70743 Mdot
.62274 .44445 Mdot
.42843 .36172 Mdot
.53326 .35658 Mdot
.66417 .50041 Mdot
.55201 .60596 Mdot
.59335 .67652 Mdot
.6323 .67591 Mdot
.45616 .29893 Mdot
.56567 .36284 Mdot
.4154 .35623 Mdot
.69902 .67342 Mdot
.69379 .69739 Mdot
.43027 .37472 Mdot
.53419 .3585 Mdot
.55905 .66047 Mdot
.58208 .64213 Mdot
.58664 .65176 Mdot
.7158 .71453 Mdot
.60729 .69659 Mdot
.51945 .7101 Mdot
.3581 .61588 Mdot
.33852 .6695 Mdot
.41754 .59186 Mdot
.64082 .5133 Mdot
.61732 .67515 Mdot
.49548 .43369 Mdot
.38393 .53193 Mdot
.17366 .54853 Mdot
.40226 .58235 Mdot
.64024 .43996 Mdot
.38644 .56741 Mdot
.42251 .68402 Mdot
.62342 .63995 Mdot
.38029 .58121 Mdot
.63646 .44644 Mdot
.40267 .37518 Mdot
.61696 .71598 Mdot
.36015 .57023 Mdot
.67049 .61551 Mdot
.37454 .64402 Mdot
.38139 .23462 Mdot
.40446 .44096 Mdot
.43757 .36326 Mdot
.40382 .6495 Mdot
.58448 .30022 Mdot
.578 .71876 Mdot
.32342 .6548 Mdot
.63016 .47357 Mdot
.38587 .79784 Mdot
.56228 .34103 Mdot
.38379 .48703 Mdot
.33235 .57209 Mdot
.39025 .35146 Mdot
.54874 .69185 Mdot
.64202 .5067 Mdot
.43471 .55637 Mdot
.38511 .628 Mdot
.33744 .31752 Mdot
.3391 .66351 Mdot
.41708 .62734 Mdot
.39776 .34117 Mdot
.51648 .73153 Mdot
.37678 .56086 Mdot
.59025 .36185 Mdot
.62949 .65896 Mdot
.43441 .6266 Mdot
.50231 .71899 Mdot
.40051 .59262 Mdot
.58646 .67612 Mdot
.61773 .69906 Mdot
.69288 .57225 Mdot
.43578 .37232 Mdot
.4204 .57634 Mdot
.39759 .42736 Mdot
.42607 .57098 Mdot
.61969 .49017 Mdot
.34954 .57844 Mdot
.55682 .33784 Mdot
.7413 .64358 Mdot
.55812 .31069 Mdot
.35137 .57738 Mdot
.58948 .64803 Mdot
.6526 .50162 Mdot
.41017 .30172 Mdot
.53039 .25685 Mdot
.52085 .7147 Mdot
.71661 .2523 Mdot
.4135 .34995 Mdot
.37741 .37074 Mdot
.6 .47582 Mdot
.37908 .57696 Mdot
.45101 .40857 Mdot
.35366 .62071 Mdot
.38248 .56466 Mdot
.35944 .59753 Mdot
.59166 .47641 Mdot
.62079 .47726 Mdot
.5338 .33814 Mdot
.38836 .60223 Mdot
.39858 .58954 Mdot
.59982 .68401 Mdot
.40089 .37384 Mdot
.56427 .30961 Mdot
.39474 .3648 Mdot
.54217 .32043 Mdot
.17257 .37163 Mdot
.34551 .52908 Mdot
.40265 .37721 Mdot
.60063 .47188 Mdot
.57226 .67743 Mdot
.74247 .38053 Mdot
.58339 .32258 Mdot
.54013 .35181 Mdot
.40142 .58571 Mdot
.57745 .68004 Mdot
.5938 .69343 Mdot
.39096 .35863 Mdot
.65172 .48578 Mdot
.35193 .57667 Mdot
.3504 .55439 Mdot
.21941 .46288 Mdot
.58179 .35261 Mdot
.43431 .70934 Mdot
.7029 .57898 Mdot
.37778 .57719 Mdot
.62053 .67636 Mdot
.38665 .61792 Mdot
.2444 .32925 Mdot
.62215 .65008 Mdot
.36305 .54173 Mdot
.6774 .69602 Mdot
.56349 .37328 Mdot
.6544 .57658 Mdot
.38892 .63875 Mdot
.6395 .20514 Mdot
.41955 .55356 Mdot
.33257 .20662 Mdot
.78947 .45949 Mdot
.43815 .58873 Mdot
.39621 .54005 Mdot
.19158 .50992 Mdot
.40968 .59435 Mdot
.74081 .35838 Mdot
.31518 .57404 Mdot
.58215 .63195 Mdot
.44502 .43802 Mdot
.56507 .38881 Mdot
.43306 .37709 Mdot
.56444 .32552 Mdot
.42433 .32417 Mdot
.39773 .38646 Mdot
.60333 .64819 Mdot
.3886 .53878 Mdot
.28413 .53612 Mdot
.54401 .38378 Mdot
.33714 .60212 Mdot
.61884 .49139 Mdot
.5797 .38358 Mdot
.53263 .36513 Mdot
.63951 .48505 Mdot
.41265 .62268 Mdot
.26074 .65836 Mdot
.55345 .25235 Mdot
.53471 .17656 Mdot
.64647 .50234 Mdot
.61698 .49938 Mdot
.73579 .66216 Mdot
.43191 .3796 Mdot
.30403 .33829 Mdot
.63526 .61008 Mdot
.61077 .50207 Mdot
.32579 .3991 Mdot
.52644 .3162 Mdot
.66786 .62091 Mdot
.59561 .61713 Mdot
.35642 .52203 Mdot
.36196 .5862 Mdot
.65199 .4807 Mdot
.28817 .54025 Mdot
.77791 .63922 Mdot
.63255 .47695 Mdot
.45815 .57416 Mdot
.57213 .47652 Mdot
.73069 .36836 Mdot
.72326 .36318 Mdot
.43441 .35811 Mdot
.52485 .21809 Mdot
.60688 .67049 Mdot
.38519 .35859 Mdot
.60043 .54501 Mdot
.4155 .57341 Mdot
.63904 .47317 Mdot
.74644 .37973 Mdot
.63266 .49891 Mdot
.41334 .38343 Mdot
.43483 .35321 Mdot
.61707 .68031 Mdot
.57636 .63703 Mdot
.50617 .81481 Mdot
.32352 .4373 Mdot
.41996 .59494 Mdot
.31303 .72538 Mdot
.58516 .69368 Mdot
.34145 .65795 Mdot
.41748 .39616 Mdot
.39881 .37607 Mdot
.38004 .74055 Mdot
.36988 .54775 Mdot
.49884 .38509 Mdot
.36632 .56397 Mdot
.29403 .37228 Mdot
.35351 .54415 Mdot
.54465 .34339 Mdot
.43292 .56326 Mdot
.62101 .30694 Mdot
.40747 .53557 Mdot
.37949 .62061 Mdot
.52253 .34473 Mdot
.40234 .50739 Mdot
.55749 .33944 Mdot
.35106 .56189 Mdot
.37905 .35251 Mdot
.56198 .32716 Mdot
.24767 .49515 Mdot
.52108 .51507 Mdot
.75248 .36274 Mdot
.41399 .39169 Mdot
.38935 .38697 Mdot
.28908 .51711 Mdot
.57834 .63936 Mdot
.61045 .61108 Mdot
.38015 .57655 Mdot
.53511 .30984 Mdot
.62449 .46996 Mdot
.39744 .59012 Mdot
.39666 .51748 Mdot
.40253 .6358 Mdot
.58936 .68829 Mdot
.56436 .36555 Mdot
.40763 .37754 Mdot
.57561 .32662 Mdot
.50889 .23674 Mdot
.51498 .33888 Mdot
.38245 .6502 Mdot
.40928 .51465 Mdot
.45385 .65444 Mdot
.389 .7895 Mdot
.65893 .74158 Mdot
.59465 .67092 Mdot
.74232 .37305 Mdot
.43007 .34815 Mdot
.55673 .71813 Mdot
.56828 .65286 Mdot
.54209 .35676 Mdot
.3726 .56926 Mdot
.45031 .545 Mdot
.58974 .5672 Mdot
.54942 .70144 Mdot
.2815 .50925 Mdot
.51861 .35532 Mdot
.73527 .36334 Mdot
.72638 .65395 Mdot
.57381 .72625 Mdot
.48823 .42663 Mdot
.37008 .60864 Mdot
.40284 .3977 Mdot
.5607 .67047 Mdot
.45507 .31242 Mdot
.64735 .47585 Mdot
.52098 .44903 Mdot
.38079 .5951 Mdot
.7381 .50698 Mdot
.5902 .64873 Mdot
.40775 .3888 Mdot
.65186 .47946 Mdot
.43291 .38075 Mdot
.7234 .36067 Mdot
.53951 .20692 Mdot
.41766 .56414 Mdot
.39669 .62137 Mdot
.59641 .47812 Mdot
.60508 .66896 Mdot
.47266 .37572 Mdot
.33264 .31694 Mdot
.57519 .34012 Mdot
.47323 .36101 Mdot
.5549 .64733 Mdot
.48808 .65574 Mdot
.57321 .32216 Mdot
.63935 .523 Mdot
.45373 .42597 Mdot
.61589 .46593 Mdot
.36167 .56626 Mdot
.57459 .6592 Mdot
.64458 .46023 Mdot
.48706 .26362 Mdot
.25409 .28745 Mdot
.44013 .6704 Mdot
.43467 .58242 Mdot
.16748 .43777 Mdot
.38146 .21901 Mdot
.31449 .5097 Mdot
.60631 .48908 Mdot
.39535 .61214 Mdot
.34366 .55704 Mdot
.43044 .56751 Mdot
.62959 .45992 Mdot
.44284 .2419 Mdot
.54811 .35212 Mdot
.40739 .58203 Mdot
.38706 .38055 Mdot
.54969 .33453 Mdot
.56811 .28082 Mdot
.54177 .30817 Mdot
.58958 .62884 Mdot
.36695 .54091 Mdot
.71104 .62364 Mdot
.30717 .21538 Mdot
.62491 .47726 Mdot
.75214 .36236 Mdot
.40005 .62358 Mdot
.60242 .78752 Mdot
.56823 .66686 Mdot
.57424 .34353 Mdot
.38029 .60845 Mdot
.47609 .24293 Mdot
.7077 .3661 Mdot
.52403 .3317 Mdot
.5818 .6406 Mdot
.32737 .49944 Mdot
.38413 .58935 Mdot
.41802 .55524 Mdot
.60813 .6631 Mdot
.56074 .21206 Mdot
.73715 .63718 Mdot
.38092 .61779 Mdot
.63647 .48512 Mdot
.84004 .60026 Mdot
.3957 .6364 Mdot
.5338 .62866 Mdot
.74798 .3518 Mdot
.67745 .60568 Mdot
.43338 .71294 Mdot
.37364 .65409 Mdot
.1831 .43181 Mdot
.37169 .46216 Mdot
.16052 .42827 Mdot
.43605 .39965 Mdot
.67187 .37703 Mdot
.18042 .35296 Mdot
.63376 .44572 Mdot
.35903 .67313 Mdot
.21451 .55323 Mdot
.74818 .56677 Mdot
.41774 .45019 Mdot
.69557 .26642 Mdot
.51446 .25569 Mdot
.78127 .35578 Mdot
.5505 .30647 Mdot
.28121 .37579 Mdot
.3523 .58427 Mdot
.39457 .20858 Mdot
.42266 .69402 Mdot
.77536 .66394 Mdot
.17068 .4085 Mdot
.39055 .42732 Mdot
.19648 .57722 Mdot
.26442 .29718 Mdot
.26881 .64299 Mdot
.60062 .56891 Mdot
.76289 .33009 Mdot
.70034 .67909 Mdot
.34334 .33337 Mdot
.3316 .53678 Mdot
.63048 .30495 Mdot
.43467 .21392 Mdot
.54276 .75676 Mdot
.79649 .6538 Mdot
.58036 .31164 Mdot
.62715 .64972 Mdot
.21391 .46904 Mdot
.59747 .72017 Mdot
.62006 .42698 Mdot
.18197 .4334 Mdot
.3239 .22654 Mdot
.42624 .68363 Mdot
.66991 .21428 Mdot
.41273 .77455 Mdot
.5364 .84369 Mdot
.53675 .51906 Mdot
.63332 .68054 Mdot
.69254 .33364 Mdot
.69288 .69872 Mdot
.70306 .4874 Mdot
.53064 .69057 Mdot
.44413 .36969 Mdot
.26776 .49165 Mdot
.58895 .64409 Mdot
.41825 .71435 Mdot
.73433 .34762 Mdot
.62555 .56344 Mdot
.57656 .27648 Mdot
.22915 .3456 Mdot
.73971 .39238 Mdot
.68165 .62828 Mdot
.74278 .47124 Mdot
.18322 .62704 Mdot
.34871 .4209 Mdot
.28875 .2918 Mdot
.64888 .54655 Mdot
.39089 .45943 Mdot
.76694 .60961 Mdot
.32867 .4504 Mdot
.68677 .71261 Mdot
.24863 .7025 Mdot
.44429 .1883 Mdot
.20443 .63255 Mdot
.58973 .71429 Mdot
.41617 .627 Mdot
.24551 .35263 Mdot
.51724 .80434 Mdot
.43836 .36135 Mdot
.17953 .58111 Mdot
.40685 .39994 Mdot
.60332 .71547 Mdot
.75355 .55011 Mdot
.49089 .66854 Mdot
.56266 .39955 Mdot
.37257 .37661 Mdot
.39328 .64623 Mdot
.48683 .88646 Mdot
.16844 .46326 Mdot
.68709 .58262 Mdot
.34185 .22423 Mdot
.62065 .54116 Mdot
.48563 .38943 Mdot
.62672 .46322 Mdot
.22322 .31138 Mdot
.57423 .64915 Mdot
.2586 .2483 Mdot
.2519 .28142 Mdot
.82401 .54672 Mdot
.60705 .88579 Mdot
.74586 .41636 Mdot
.34544 .67648 Mdot
.26444 .56908 Mdot
.25532 .53117 Mdot
.77796 .61746 Mdot
.82694 .52304 Mdot
.59356 .52655 Mdot
.53457 .19503 Mdot
.19349 .35134 Mdot
.31173 .38839 Mdot
.40915 .23624 Mdot
.75723 .57723 Mdot
.51622 .49579 Mdot
.54042 .62086 Mdot
.50964 .51678 Mdot
.56039 .58358 Mdot
.19507 .60559 Mdot
.57409 .78799 Mdot
.79028 .69494 Mdot
.45619 .35169 Mdot
.82945 .46566 Mdot
.34411 .24218 Mdot
.24843 .4767 Mdot
.51554 .66773 Mdot
.72497 .5989 Mdot
.38304 .64853 Mdot
.72477 .64072 Mdot
.349 .50032 Mdot
.39731 .32461 Mdot
.7273 .66284 Mdot
.65158 .41565 Mdot
.33204 .33278 Mdot
.20008 .44092 Mdot
.67168 .67404 Mdot
.59843 .63276 Mdot
.33454 .46554 Mdot
.33757 .40786 Mdot
.34316 .22909 Mdot
.79659 .52485 Mdot
.5231 .17575 Mdot
.80901 .52714 Mdot
.3566 .62376 Mdot
.34584 .66284 Mdot
.34529 .51758 Mdot
.3416 .43867 Mdot
.36952 .63099 Mdot
.73274 .48808 Mdot
.36334 .21285 Mdot
.55848 .80022 Mdot
.36461 .32015 Mdot
.35037 .7672 Mdot
.49563 .17945 Mdot
.24731 .3586 Mdot
.78608 .46826 Mdot
.29022 .63249 Mdot
.37996 .83685 Mdot
.54305 .33084 Mdot
.32158 .39974 Mdot
.66712 .49859 Mdot
.45356 .30315 Mdot
.22385 .59821 Mdot
.81722 .56278 Mdot
.36918 .2088 Mdot
.7317 .60534 Mdot
.52727 .27305 Mdot
.55479 .4267 Mdot
.58538 .38792 Mdot
.33664 .75755 Mdot
.43511 .52652 Mdot
.49468 .57546 Mdot
.38011 .36978 Mdot
.51766 .79368 Mdot
.26702 .34993 Mdot
.65476 .26069 Mdot
.42858 .65142 Mdot
.66405 .30352 Mdot
.73359 .36049 Mdot
.52771 .45256 Mdot
.13038 .44336 Mdot
.3343 .62935 Mdot
.7646 .43003 Mdot
.46016 .18413 Mdot
.44921 .41882 Mdot
.31661 .27848 Mdot
.7287 .54883 Mdot
.22513 .66121 Mdot
.28546 .24573 Mdot
.57453 .24199 Mdot
.156 .45406 Mdot
.50367 .15059 Mdot
.25245 .69389 Mdot
.34414 .74786 Mdot
.6635 .45182 Mdot
.2909 .19008 Mdot
.56014 .35579 Mdot
.41747 .81544 Mdot
.52727 .80532 Mdot
.45217 .25469 Mdot
.54269 .63945 Mdot
.43068 .5004 Mdot
.77155 .36275 Mdot
.62497 .63342 Mdot
.3996 .64727 Mdot
.16495 .58429 Mdot
.26553 .73276 Mdot
.17231 .58959 Mdot
.5136 .19236 Mdot
.1571 .44668 Mdot
.21457 .52418 Mdot
.52126 .70791 Mdot
.2467 .39813 Mdot
.34941 .57148 Mdot
.29502 .41425 Mdot
.75166 .42212 Mdot
.52495 .27029 Mdot
.69332 .52121 Mdot
.55159 .63757 Mdot
.22679 .64149 Mdot
.11174 .48631 Mdot
.41784 .75848 Mdot
.48466 .73132 Mdot
.55195 .5703 Mdot
.33083 .42934 Mdot
.43982 .48147 Mdot
.63332 .27551 Mdot
.34519 .23456 Mdot
.21219 .54774 Mdot
.3285 .37631 Mdot
.68504 .27722 Mdot
.60031 .39024 Mdot
.82201 .45538 Mdot
.2277 .33458 Mdot
.22685 .491 Mdot
.82036 .52386 Mdot
.28705 .63941 Mdot
.79353 .6178 Mdot
.61444 .23231 Mdot
.48619 .35622 Mdot
.34413 .39692 Mdot
.5312 .3714 Mdot
.3077 .39436 Mdot
.57341 .52367 Mdot
.21713 .44027 Mdot
.3565 .46892 Mdot
.30586 .38622 Mdot
.60287 .38577 Mdot
.15725 .5353 Mdot
.5523 .15856 Mdot
.31826 .77005 Mdot
.61713 .19762 Mdot
.34356 .50275 Mdot
.37483 .62623 Mdot
.41062 .18748 Mdot
.14746 .53454 Mdot
.31106 .21888 Mdot
.74109 .50042 Mdot
.47901 .26232 Mdot
.64036 .4428 Mdot
.34024 .7771 Mdot
.63648 .22863 Mdot
.30385 .25094 Mdot
.66253 .73337 Mdot
.60737 .51647 Mdot
.73951 .61021 Mdot
.36933 .78834 Mdot
.26717 .65024 Mdot
.42969 .72772 Mdot
.33775 .53184 Mdot
.38514 .69634 Mdot
.63084 .66562 Mdot
.75141 .49168 Mdot
.33275 .44306 Mdot
.54745 .32718 Mdot
.23439 .50586 Mdot
.49918 .5986 Mdot
.37989 .64787 Mdot
.49035 .33429 Mdot
.56689 .61072 Mdot
.42274 .8063 Mdot
.58819 .51499 Mdot
.16729 .37054 Mdot
.75923 .44581 Mdot
.42867 .48526 Mdot
.36184 .45288 Mdot
.45681 .32332 Mdot
.72381 .62765 Mdot
.60564 .46955 Mdot
.18793 .37898 Mdot
.4885 .49778 Mdot
.34123 .46167 Mdot
.38814 .69863 Mdot
.32021 .32037 Mdot
.3909 .51703 Mdot
.70927 .55761 Mdot
.56293 .74799 Mdot
.52376 .44381 Mdot
.62961 .70535 Mdot
.57457 .6092 Mdot
.74965 .25385 Mdot
.62682 .3575 Mdot
.80419 .49624 Mdot
.19334 .37589 Mdot
.61683 .46797 Mdot
.54677 .65472 Mdot
.29615 .39451 Mdot
.34396 .29714 Mdot
.56602 .7637 Mdot
.53654 .29738 Mdot
.35371 .38347 Mdot
.6399 .2463 Mdot
.16937 .43861 Mdot
.177 .52706 Mdot
.76732 .69167 Mdot
.56919 .69304 Mdot
.30874 .31894 Mdot
.34286 .30792 Mdot
.56882 .68841 Mdot
.54008 .68753 Mdot
.60385 .57514 Mdot
.14655 .43787 Mdot
.71698 .63902 Mdot
.59432 .19728 Mdot
.45094 .42518 Mdot
.46319 .23955 Mdot
.43643 .31229 Mdot
.34483 .3738 Mdot
.19733 .37366 Mdot
.4074 .71809 Mdot
.24271 .63143 Mdot
.32709 .5406 Mdot
.52265 .82127 Mdot
.34643 .78259 Mdot
.53079 .50445 Mdot
.48113 .6574 Mdot
.65462 .4204 Mdot
.43041 .57657 Mdot
.18148 .62451 Mdot
.37947 .22824 Mdot
.71625 .68938 Mdot
.58424 .50517 Mdot
.39682 .54873 Mdot
.34533 .60053 Mdot
.29002 .54134 Mdot
.6871 .59487 Mdot
.29349 .74536 Mdot
.34663 .32309 Mdot
.31895 .52184 Mdot
.40665 .69967 Mdot
.76563 .43227 Mdot
.22909 .35278 Mdot
.36172 .23787 Mdot
.55868 .49949 Mdot
.75188 .42628 Mdot
.50354 .41518 Mdot
.58571 .18951 Mdot
.65019 .31228 Mdot
.21273 .51013 Mdot
.65382 .6459 Mdot
.70753 .59373 Mdot
.46434 .32038 Mdot
.38926 .62428 Mdot
.75348 .53987 Mdot
.25537 .30809 Mdot
.76317 .72947 Mdot
.7743 .59896 Mdot
.15565 .57753 Mdot
.47768 .63897 Mdot
.70846 .60183 Mdot
.23003 .62344 Mdot
.73333 .77043 Mdot
.63101 .288 Mdot
.19515 .58797 Mdot
.53726 .42194 Mdot
.18086 .39453 Mdot
.66876 .47302 Mdot
.68478 .66095 Mdot
.36034 .77111 Mdot
.1486 .43136 Mdot
.26983 .32245 Mdot
.20461 .37549 Mdot
.27784 .62671 Mdot
.14352 .46488 Mdot
.65141 .73433 Mdot
.78489 .3566 Mdot
.59415 .33365 Mdot
.72562 .46801 Mdot
.31058 .70059 Mdot
.52453 .60853 Mdot
.32567 .39174 Mdot
.81495 .41532 Mdot
.57419 .7365 Mdot
.28544 .66801 Mdot
.26185 .44031 Mdot
.72021 .56285 Mdot
.36743 .45289 Mdot
.28498 .26405 Mdot
.78342 .34931 Mdot
.40541 .30427 Mdot
.78439 .49127 Mdot
.53992 .20478 Mdot
.68297 .59319 Mdot
.64744 .36588 Mdot
.28626 .29275 Mdot
.59175 .22009 Mdot
.376 .42672 Mdot
.77047 .25289 Mdot
.44579 .21706 Mdot
.59909 .5723 Mdot
.21579 .6346 Mdot
.35363 .23407 Mdot
.64487 .73946 Mdot
.7691 .66253 Mdot
.50943 .82526 Mdot
.30156 .43648 Mdot
.35817 .59341 Mdot
.13751 .48079 Mdot
.26806 .47856 Mdot
.18657 .59467 Mdot
.45653 .17193 Mdot
.35991 .69651 Mdot
.35788 .64255 Mdot
.55787 .29548 Mdot
.55442 .54986 Mdot
.25953 .43246 Mdot
.20305 .57239 Mdot
.47861 .82924 Mdot
.473 .35849 Mdot
.67393 .36122 Mdot
.52577 .30511 Mdot
.29827 .57946 Mdot
.73816 .42478 Mdot
.70453 .58251 Mdot
.44938 .34211 Mdot
.61757 .36247 Mdot
.33135 .41849 Mdot
.43077 .7104 Mdot
.26471 .64744 Mdot
.80381 .58131 Mdot
.63214 .42228 Mdot
.5791 .30512 Mdot
.1909 .48397 Mdot
.46036 .2094 Mdot
.72886 .49498 Mdot
.27367 .70455 Mdot
.7289 .59436 Mdot
.2705 .38801 Mdot
.24087 .38694 Mdot
.78561 .60537 Mdot
.76103 .31914 Mdot
.2862 .69923 Mdot
.52534 .82124 Mdot
.50738 .38868 Mdot
.48123 .60649 Mdot
.17267 .37343 Mdot
.34346 .38266 Mdot
.22475 .41751 Mdot
.52749 .52223 Mdot
.52913 .77899 Mdot
.32387 .69252 Mdot
.24357 .51714 Mdot
.50322 .42839 Mdot
.44528 .86745 Mdot
.55747 .62262 Mdot
.18408 .6322 Mdot
.64497 .48795 Mdot
.68976 .75049 Mdot
.61425 .32105 Mdot
.55758 .51541 Mdot
.47402 .43083 Mdot
.705 .5594 Mdot
.62654 .5781 Mdot
.52366 .19308 Mdot
.80568 .59783 Mdot
.51559 .33633 Mdot
.42483 .425 Mdot
.59954 .20669 Mdot
.18579 .4658 Mdot
.44498 .57238 Mdot
.47652 .21227 Mdot
.52678 .50102 Mdot
.51699 .27751 Mdot
.41296 .18895 Mdot
.68181 .43559 Mdot
.45575 .59976 Mdot
.33021 .43275 Mdot
.20236 .5988 Mdot
.26536 .27117 Mdot
.75328 .66617 Mdot
.34744 .50126 Mdot
.6628 .44819 Mdot
.22933 .56388 Mdot
.17589 .45337 Mdot
.51778 .40245 Mdot
.69028 .63886 Mdot
.34439 .41273 Mdot
.20436 .69473 Mdot
.25803 .72013 Mdot
.2989 .74735 Mdot
.44526 .41864 Mdot
.64167 .67821 Mdot
.59267 .78924 Mdot
.22851 .41245 Mdot
.71656 .48383 Mdot
.44541 .205 Mdot
.32539 .40396 Mdot
.70127 .78079 Mdot
.52826 .69521 Mdot
.50961 .23465 Mdot
.32669 .69737 Mdot
.49469 .8039 Mdot
.65889 .45421 Mdot
.28838 .44236 Mdot
.45589 .48003 Mdot
.60235 .49708 Mdot
.71697 .5672 Mdot
.66299 .61025 Mdot
.22253 .42097 Mdot
.55151 .74936 Mdot
.32245 .52386 Mdot
.19635 .43493 Mdot
.63983 .65522 Mdot
.44925 .31141 Mdot
.4153 .31051 Mdot
.42962 .45556 Mdot
.57193 .3396 Mdot
.3523 .65126 Mdot
.54239 .44809 Mdot
.5228 .4237 Mdot
.41094 .82744 Mdot
.39984 .39963 Mdot
.573 .62452 Mdot
.6924 .72937 Mdot
.56226 .68331 Mdot
.13822 .52838 Mdot
.63397 .27849 Mdot
.40237 .69679 Mdot
.56374 .24025 Mdot
.68861 .30639 Mdot
.54874 .85433 Mdot
.31236 .73692 Mdot
.5263 .54546 Mdot
.54448 .70199 Mdot
.5962 .70131 Mdot
.56216 .39627 Mdot
.76613 .35408 Mdot
.44586 .72558 Mdot
.76467 .4179 Mdot
.25806 .38673 Mdot
.62495 .69542 Mdot
.48515 .23079 Mdot
.42279 .48219 Mdot
.1469 .41172 Mdot
.56184 .30312 Mdot
.33847 .8083 Mdot
.39677 .50934 Mdot
.23589 .60757 Mdot
.40047 .19028 Mdot
.74669 .64145 Mdot
.48577 .32846 Mdot
.72204 .27584 Mdot
.44085 .58551 Mdot
.31654 .53658 Mdot
.59103 .6424 Mdot
.28982 .34965 Mdot
.40867 .3665 Mdot
.29719 .48916 Mdot
.60851 .51317 Mdot
.82873 .50103 Mdot
.74207 .433 Mdot
.61529 .63012 Mdot
.48433 .50655 Mdot
.26788 .33497 Mdot
.66149 .62839 Mdot
.52516 .49833 Mdot
.19157 .50518 Mdot
.55953 .76381 Mdot
.62144 .69757 Mdot
.27754 .71315 Mdot
.33991 .32118 Mdot
.23521 .29098 Mdot
.46583 .53296 Mdot
.54767 .5335 Mdot
.66626 .64639 Mdot
.71727 .55124 Mdot
.44026 .71584 Mdot
.3419 .23757 Mdot
.33296 .45909 Mdot
.68979 .68995 Mdot
.30431 .38868 Mdot
.39936 .5006 Mdot
.67034 .36356 Mdot
.72487 .44839 Mdot
.67415 .79626 Mdot
.37551 .75445 Mdot
.75477 .61815 Mdot
.5196 .64006 Mdot
.76315 .42878 Mdot
.5692 .62311 Mdot
.41301 .27699 Mdot
.5473 .76311 Mdot
.59864 .26944 Mdot
.20095 .33408 Mdot
.34855 .22905 Mdot
.57576 .57445 Mdot
.52197 .29681 Mdot
.37115 .46514 Mdot
.42641 .48639 Mdot
.50837 .45515 Mdot
.43764 .59729 Mdot
.2921 .57299 Mdot
.74768 .66687 Mdot
.71997 .51639 Mdot
.42479 .49675 Mdot
.16425 .40412 Mdot
.24752 .27795 Mdot
.15 .48927 Mdot
.49327 .37847 Mdot
.57705 .62744 Mdot
.23092 .67257 Mdot
.47057 .69863 Mdot
.28431 .26248 Mdot
.3179 .7128 Mdot
.72817 .23445 Mdot
.21832 .59731 Mdot
.64201 .41544 Mdot
.82615 .53863 Mdot
.65853 .56061 Mdot
.41861 .19165 Mdot
.78503 .35486 Mdot
.35641 .33821 Mdot
.42798 .18706 Mdot
.4831 .88435 Mdot
.35935 .75458 Mdot
.67448 .62169 Mdot
.31346 .66846 Mdot
.39968 .46604 Mdot
.768 .40727 Mdot
.34949 .58482 Mdot
.54938 .38035 Mdot
.49186 .31261 Mdot
.33179 .41171 Mdot
.46581 .64013 Mdot
.77359 .41019 Mdot
.25857 .42741 Mdot
.28714 .36744 Mdot
.35321 .30191 Mdot
.209 .57666 Mdot
.45087 .72094 Mdot
.45375 .61036 Mdot
.63869 .70146 Mdot
.43347 .36035 Mdot
.40652 .31989 Mdot
.35854 .54683 Mdot
.49593 .31103 Mdot
.62958 .59842 Mdot
.16332 .58772 Mdot
.38769 .28928 Mdot
.35441 .27173 Mdot
.59614 .61311 Mdot
.69529 .58443 Mdot
.22794 .37488 Mdot
.7497 .56068 Mdot
.78713 .41661 Mdot
.57016 .79001 Mdot
.16633 .4454 Mdot
.72082 .60722 Mdot
.32217 .35597 Mdot
.48273 .85042 Mdot
.6251 .51334 Mdot
.42704 .80413 Mdot
.211 .53464 Mdot
.73782 .56907 Mdot
.59495 .71296 Mdot
.63648 .4058 Mdot
.6792 .38116 Mdot
.7309 .56652 Mdot
.4649 .18274 Mdot
.29138 .33351 Mdot
.34454 .70457 Mdot
.17399 .50572 Mdot
.58518 .35415 Mdot
.32683 .37797 Mdot
.62238 .39071 Mdot
.76569 .39547 Mdot
.67446 .66921 Mdot
.166 .38511 Mdot
.50225 .44662 Mdot
.26147 .49112 Mdot
.42053 .56176 Mdot
.50642 .722 Mdot
.71327 .53535 Mdot
.60096 .39495 Mdot
.79855 .50751 Mdot
.61237 .64111 Mdot
.7483 .45965 Mdot
.73352 .33998 Mdot
.29148 .45365 Mdot
.50226 .58417 Mdot
.65102 .65176 Mdot
.41113 .41063 Mdot
.71352 .36538 Mdot
.44612 .55982 Mdot
.26469 .50787 Mdot
.58057 .39569 Mdot
.39366 .78618 Mdot
.3547 .7563 Mdot
.18962 .48744 Mdot
.37747 .24186 Mdot
.72556 .49274 Mdot
.3125 .71211 Mdot
.62731 .5733 Mdot
.51307 .68581 Mdot
.76742 .54051 Mdot
.38881 .63954 Mdot
.41679 .27445 Mdot
.55227 .6447 Mdot
.18291 .47649 Mdot
.49556 .63624 Mdot
.24779 .49182 Mdot
.5392 .47799 Mdot
.24051 .35221 Mdot
.50101 .48407 Mdot
.4028 .191 Mdot
.66247 .55774 Mdot
.33179 .44484 Mdot
.60408 .52405 Mdot
.53953 .41983 Mdot
.78029 .59436 Mdot
.21962 .32983 Mdot
.80912 .57798 Mdot
.26668 .57034 Mdot
.74978 .61175 Mdot
.54083 .81596 Mdot
.44129 .17783 Mdot
.31636 .44625 Mdot
.50978 .4568 Mdot
.4374 .48272 Mdot
.61592 .55904 Mdot
.74464 .37877 Mdot
.43732 .27273 Mdot
.46455 .71254 Mdot
.38901 .26196 Mdot
.57376 .26418 Mdot
.44846 .59314 Mdot
.60804 .78559 Mdot
.17274 .48313 Mdot
.5905 .73811 Mdot
.54872 .51267 Mdot
.48238 .30151 Mdot
.28861 .4632 Mdot
.87635 .42501 Mdot
.17933 .62241 Mdot
.41906 .56168 Mdot
.45021 .43139 Mdot
.29547 .48394 Mdot
.54165 .368 Mdot
.44954 .73149 Mdot
.18805 .4852 Mdot
.61332 .49815 Mdot
.47174 .27186 Mdot
.70552 .43911 Mdot
.70363 .55352 Mdot
.23854 .52043 Mdot
.59311 .47398 Mdot
.14526 .55153 Mdot
.48394 .20585 Mdot
.72042 .5306 Mdot
.82084 .33285 Mdot
.74062 .48956 Mdot
.63405 .63614 Mdot
.26579 .31966 Mdot
.15581 .52971 Mdot
.44625 .42015 Mdot
.45581 .29941 Mdot
.36025 .76175 Mdot
.33038 .45132 Mdot
.30123 .36069 Mdot
.78324 .49011 Mdot
.7569 .46851 Mdot
.78279 .37135 Mdot
.68898 .30435 Mdot
.43796 .8411 Mdot
.3964 .7097 Mdot
.17533 .53749 Mdot
.6313 .28231 Mdot
.71297 .77174 Mdot
.22277 .31222 Mdot
.28566 .42011 Mdot
.78192 .42454 Mdot
.28467 .30099 Mdot
.28716 .51113 Mdot
.60529 .76995 Mdot
.62046 .27129 Mdot
.56417 .77503 Mdot
.67676 .29998 Mdot
.7798 .5359 Mdot
.30679 .39109 Mdot
.51285 .80952 Mdot
.50009 .44157 Mdot
.20001 .54672 Mdot
.83374 .4466 Mdot
.3638 .44645 Mdot
.48252 .2738 Mdot
.26082 .54804 Mdot
.18741 .4435 Mdot
.27675 .29451 Mdot
.49415 .4523 Mdot
.48598 .88116 Mdot
.19523 .60148 Mdot
.7572 .56283 Mdot
.36137 .61915 Mdot
.19983 .32816 Mdot
.46354 .45575 Mdot
.31529 .71842 Mdot
.43695 .19815 Mdot
.39002 .31318 Mdot
.65827 .63959 Mdot
.40904 .63246 Mdot
.3051 .72905 Mdot
.47216 .65832 Mdot
.49165 .80597 Mdot
.48197 .32652 Mdot
.3572 .45376 Mdot
.83359 .46053 Mdot
.2463 .55118 Mdot
.42738 .4889 Mdot
.55447 .64565 Mdot
.15624 .5607 Mdot
.268 .63021 Mdot
.34705 .65158 Mdot
.325 .66421 Mdot
.80782 .58667 Mdot
.76113 .29778 Mdot
.38883 .49426 Mdot
.71994 .62869 Mdot
.32725 .39386 Mdot
.24508 .39131 Mdot
.33168 .74522 Mdot
.62658 .88157 Mdot
.38953 .19381 Mdot
.54356 .62827 Mdot
.43033 .79924 Mdot
.41563 .43473 Mdot
.1531 .48991 Mdot
.68101 .27318 Mdot
.44658 .32038 Mdot
.81294 .613 Mdot
.32268 .48121 Mdot
.36595 .531 Mdot
.50027 .1879 Mdot
.22395 .31755 Mdot
.84093 .4678 Mdot
.17501 .37123 Mdot
.34693 .63067 Mdot
.34276 .53434 Mdot
.84823 .64031 Mdot
.17584 .41838 Mdot
.35911 .64583 Mdot
.79676 .61972 Mdot
.53654 .65471 Mdot
.35266 .57135 Mdot
.69952 .3989 Mdot
.34927 .39941 Mdot
.29316 .36735 Mdot
.14869 .43354 Mdot
.63977 .66864 Mdot
.49895 .30489 Mdot
.66459 .50008 Mdot
.48078 .42951 Mdot
.45146 .55001 Mdot
.64498 .4593 Mdot
.27768 .38655 Mdot
.45273 .45178 Mdot
.58048 .47362 Mdot
.35875 .40225 Mdot
.56571 .16901 Mdot
.46003 .65344 Mdot
.56951 .57288 Mdot
.28099 .6164 Mdot
.58639 .74244 Mdot
.25976 .42888 Mdot
.24611 .4225 Mdot
.4399 .18717 Mdot
.52261 .13275 Mdot
.60952 .33941 Mdot
.44872 .51772 Mdot
.63576 .71784 Mdot
.45192 .71164 Mdot
.33017 .68428 Mdot
.60093 .41855 Mdot
.7266 .37497 Mdot
.35845 .63732 Mdot
.43358 .48975 Mdot
.61061 .51474 Mdot
.17775 .6488 Mdot
.35073 .59541 Mdot
.38945 .7265 Mdot
.2657 .2885 Mdot
.4535 .31283 Mdot
.44036 .66488 Mdot
.44163 .57589 Mdot
.64915 .73559 Mdot
.45595 .45716 Mdot
.34871 .48324 Mdot
.42347 .31018 Mdot
.15972 .48878 Mdot
.49443 .63453 Mdot
.36729 .71067 Mdot
.39934 .58177 Mdot
.37406 .37121 Mdot
.66843 .6242 Mdot
.30415 .74145 Mdot
.49267 .55947 Mdot
.28099 .26014 Mdot
.38783 .3108 Mdot
.35126 .32116 Mdot
.36464 .68093 Mdot
.18469 .59599 Mdot
.77142 .59535 Mdot
.35853 .69188 Mdot
.72891 .68395 Mdot
.6479 .38269 Mdot
.26364 .43813 Mdot
.53693 .30331 Mdot
.42727 .49896 Mdot
.54061 .67642 Mdot
.12785 .46739 Mdot
.32092 .74795 Mdot
.66775 .51459 Mdot
.5046 .38338 Mdot
.49795 .68224 Mdot
.47979 .4336 Mdot
.79895 .2998 Mdot
.68944 .26153 Mdot
.1466 .55634 Mdot
.28348 .34623 Mdot
.64053 .71561 Mdot
.72439 .55931 Mdot
.38269 .66413 Mdot
.52639 .34115 Mdot
.15556 .49032 Mdot
.46786 .52623 Mdot
.77528 .52443 Mdot
.34802 .56501 Mdot
.70238 .69449 Mdot
.40858 .47191 Mdot
.50891 .31387 Mdot
.52504 .37153 Mdot
.77059 .64659 Mdot
.2495 .31874 Mdot
.45775 .45945 Mdot
.74039 .25548 Mdot
.20148 .57857 Mdot
.18909 .37666 Mdot
.5311 .3002 Mdot
.71318 .73976 Mdot
.5162 .64172 Mdot
.41035 .47512 Mdot
.62285 .53688 Mdot
.26072 .59029 Mdot
.73592 .56402 Mdot
.25704 .37737 Mdot
.6451 .58555 Mdot
.60184 .56647 Mdot
.66155 .15143 Mdot
.28983 .40841 Mdot
.51648 .65898 Mdot
.75397 .52774 Mdot
.17944 .37845 Mdot
.36047 .37877 Mdot
.538 .17742 Mdot
.62839 .32151 Mdot
.43828 .52457 Mdot
.55443 .74584 Mdot
.24316 .61609 Mdot
.69403 .42786 Mdot
.50042 .8629 Mdot
.44894 .20922 Mdot
.35102 .32811 Mdot
.60472 .39449 Mdot
.5647 .68666 Mdot
.54211 .64149 Mdot
.62623 .2477 Mdot
.62761 .18524 Mdot
.36028 .4854 Mdot
.17454 .44603 Mdot
.5901 .83771 Mdot
.30967 .33461 Mdot
.14749 .46722 Mdot
.68373 .51799 Mdot
.53336 .67757 Mdot
.2587 .42083 Mdot
.46763 .36211 Mdot
.56142 .37084 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0U?ooool2o`000;?ooooo000Looooo`03o`000?oooooooooo09Cooooo0_l0
002cooooo`007?ooool00ol0003oooooooooo`2<ooooo`;o00004?ooool2o`000:Wooooo000Loooo
o`03o`000?oooooooooo08cooooo0_l0000@ooooo`;o00001_ooool2o`000:7ooooo000Looooo`;o
0000Yoooool2o`000:7ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2booooo`;o0000UOooool0
01cooooo00?o0000ooooooooool0/_ooool2o`0009Gooooo000Looooo`03o`000?oooooooooo08;o
oooo0_l0000iooooo`;o0000R_ooool001cooooo00?o0000ooooooooool0P_ooool2o`0003Wooooo
0_l0002:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0N_ooool2o`000<gooooo000Looooo`03
o`000?oooooooooo07[ooooo0_l0003=ooooo`007?ooool00ol0003oooooooooo`2Vooooo`;o0000
XOooool001cooooo00?o0000ooooooooool0Y_ooool2o`000:7ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`1aooooo`;o0000e_ooool001cooooo00?o0000ooooooooool0LOooool2o`0002gooooo
0_l0002Wooooo`007?ooool2o`00073ooooo0_l0000_ooooo`;o0000<Oooool2o`0007Cooooo000L
ooooo`03o`000?oooooooooo06oooooo0_l0001Rooooo`;o0000M?ooool001cooooo00?o0000oooo
ooooool0/?ooool2o`0009Oooooo000Looooo`03o`000?oooooooooo06[ooooo0_l00014ooooo`;o
0000Uoooool001cooooo00?o0000ooooooooool0J_ooool2o`000=gooooo000Looooo`03o`000?oo
oooooooo0;Cooooo0_l0002Cooooo`007?ooool00ol0003oooooooooo`2Aooooo`;o000000?ooooo
o`000?l000007_ooool3o`0000Oooooo0_l0000Mooooo`;o0000J_ooool001cooooo00?o0000oooo
ooooool0I?ooool2o`0001oooooo0_l0000:ooooo`;o000000?oooooo`000?l000007_ooool4o`00
00Gooooo1?l0000Looooo`;o0000J_ooool001cooooo00?o0000ooooooooool0I?ooool2o`0001oo
oooo0_l00005ooooo`;o00006?ooool2o`000003ooooool0003o000000;o00002Oooool2o`0000;o
oooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000008Gooooo000Looooo`03o`00
0?oooooooooo08cooooo0_l0000<ooooo`;o000000?oooooo`000?l000001oooool2o`000003oooo
ool0003o000000;o00003Oooool2o`0000Kooooo1?l00023ooooo`007?ooool00ol0003ooooooooo
o`25ooooo`;o00002oooool3o`0000?ooooo1?l000000ooooooo0000o`000003ooooo`;o00003?oo
ool2o`0001;ooooo0_l00002ooooo`;o00005_ooool2o`0006Oooooo000Looooo`03o`000?oooooo
oooo05cooooo0_l0000Tooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00001Oooool3
o`0000?ooooo0_l00008ooooo`;o00002?ooool2o`0000;ooooo0_l0000Fooooo`;o00005_ooool2
o`0006Oooooo000Looooo`03o`000?oooooooooo05_ooooo0ol0000Looooo`;o00000_ooool2o`00
00;ooooo0ol00002ooooo`;o00000_ooool4o`00013ooooo0_l00008ooooo`;o000000?oooooo`00
0?l000003?ooool2o`0000cooooo0_l0001oooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5
ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0Foooool2o`0001gooooo0ol00000
1Ooooooo0000o`000?l0003ooooo00Co00000oooool2o`0000;ooooo0_l0000@ooooo`;o00000_oo
ool5o`000003ooooool0003o000000oooooo0_l0002=ooooo`0000KoooooogMgMonHV9SooooooiRH
V?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000oooooooo
ool0Noooool2o`0000;ooooo0ol00002ooooo`;o00000oooool2o`0001Sooooo1Ol00002ooooo`;o
00008?ooool2o`0007_ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo
00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`1oooooo`?o00002?ooool2o`0001[ooooo
0ol000000ooooooo0000o`000007ooooo`;o00002?ooool2o`0000Kooooo0_l00005ooooo`;o0000
Noooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^
kP06ooooo`?o0000ROooool3o`0001_ooooo0_l0000:ooooo`;o00002?ooool2o`0000Kooooo1?l0
0009ooooo`;o0000MOooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool0
0omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo07Oooooo0_l0000@ooooo`;o00000_ooool2
o`0000[ooooo0_l0000Aooooo`;o00002oooool2o`0000cooooo0_l00003ooooo`;o00001?ooool2
o`0007Gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`1Xooooo`;o00002_ooool2o`000004ooooool0003o0000
ooooo`Co00003oooool3o`0000Wooooo0_l0000@ooooo`?o00002oooool2o`0000Cooooo0_l0000;
ooooo`Co00001Oooool2o`00017ooooo0_l0001Oooooo`0000KoooooogMgMonHV9SooooooiRHV?mg
MgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`1Uooooo`;o0000
00?oooooo`000?l000002_ooool2o`0000Cooooo1?l0000@ooooo`;o00000_ooool3o`0000;ooooo
0_l0000Booooo`;o00001?ooool3o`0000_ooooo0_l0000=ooooo`;o00001Oooool2o`00017ooooo
0_l0001Oooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01_ooool00ol0003oooooooooo`1Pooooo`;o00000oooool2o`0000_ooooo0_l0000Eoooo
o`;o00001oooool3o`0000;ooooo0_l000000ooooooo0000o`000009ooooo`;o00002_ooool3o`00
02;ooooo0_l0001aooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o000000?oooooo`000?l0
00000oooool3o`0000Oooooo0_l000000ooooooo0000o`000002o`00013ooooo0_l00002ooooo`;o
00002?ooool2o`000003ooooool0003o000000Wooooo1?l00009ooooo`;o00007_ooool2o`0000;o
oooo0_l0001aooooo`007?ooool00ol0003oooooooooo`1Qooooo`Co00000oooool3o`0000Gooooo
1?l000000ooooooo0000o`000003o`0001?ooooo0_l0000Hooooo`;o00002Oooool4o`0000Kooooo
0_l0000Dooooo`Co0000Loooool001cooooo00?o0000ooooooooool0HOooool3o`0000Oooooo0_l0
0003ooooo`Co00001?ooool2o`0003[ooooo1?l00004ooooo`;o00005_ooool2o`0000Gooooo0_l0
001/ooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o000000Coooooo`000?l0003ooooo0_l0
0003ooooo`;o0000?Oooool2o`0000Gooooo0_l0000Gooooo`;o00002_ooool2o`0006cooooo000L
ooooo`03o`000?oooooooooo06Cooooo0ol000000ooooooo0000o`000005o`000003ooooool0003o
000000;o00001?ooool2o`00023ooooo0_l0000Cooooo`;o00006_ooool2o`0000;ooooo0_l0001h
ooooo`007?ooool00ol0003oooooooooo`1Rooooo`Ko00000_ooool5o`0000?ooooo0_l00004oooo
o`Co00006_ooool2o`0000;ooooo0_l0000Xooooo`;o00001Oooool2o`0000Wooooo0_l0001aoooo
o`007?ooool00ol0003oooooooooo`1Hooooo`;o00002?ooool2o`0000;ooooo0_l00004ooooo`;o
000000?oooooo`000?l000001Oooool6o`0000Gooooo0_l0000Aooooo`Co00000_ooool2o`0000Ko
oooo0_l000000ooooooo0000o`00000Mooooo`;o00001Oooool2o`0000Wooooo0_l0000Aooooo`;o
0000G_ooool001cooooo00?o0000ooooooooool0F?ooool2o`0000gooooo0_l00002ooooo`?o0000
00Coooooo`000?l0003ooooo2?l00002ooooo`;o00000oooool2o`00013ooooo0ol0000<ooooo`;o
000000?oooooo`000?l00000@_ooool2o`0005kooooo000Looooo`03o`000?oooooooooo06Oooooo
0_l00002ooooo`?o00001?ooool4o`000003ooooool0003o000000?ooooo0ol0000=ooooo`;o0000
1Oooool2o`0000;ooooo0_l0000?ooooo`?o00002?ooool2o`0000;ooooo0_l0000Wooooo`;o0000
Ioooool001cooooo00?o0000ooooooooool0FOooool2o`00013ooooo0ol00009ooooo`;o00001?oo
ool2o`0000gooooo0_l00009ooooo`;o00003oooool4o`0000Oooooo0_l00002ooooo`;o00009ooo
ool2o`0006Oooooo000Looooo`03o`000?oooooooooo053ooooo0_l00007ooooo`;o00003?ooool2
o`0002cooooo0_l00008ooooo`;o00002Oooool2o`00017ooooo0_l00009ooooo`;o00000_ooool2
o`0007_ooooo000Looooo`;o0000@_ooool2o`0000gooooo0_l0000=ooooo`;o00001_ooool2o`00
02cooooo0_l00008ooooo`;o00002Oooool2o`0000;ooooo1?l0000;ooooo`;o00002Oooool2o`00
00;ooooo0_l0000Gooooo`Co0000H?ooool001cooooo00?o0000ooooooooool0@Oooool2o`0001;o
oooo0_l00004ooooo`Ko00000_ooool2o`000003ooooool0003o000000oooooo0_l0000Fooooo`;o
00003_ooool4o`0000Cooooo0_l00005ooooo`Co00008oooool2o`0000kooooo1?l00004ooooo`;o
000000?oooooo`000?l000001?ooool2o`00057ooooo000Looooo`03o`000?oooooooooo05Gooooo
0_l00003ooooo`Go00001?ooool2o`000003ooooool0003o000000oooooo0_l0000@ooooo`;o0000
1?ooool2o`0000kooooo1_l00002ooooo`Go00003_ooool2o`0000Gooooo0_l0000Booooo`;o0000
5_ooool2o`000003ooooool0003o000000Cooooo0_l0001Aooooo`007?ooool00ol0003ooooooooo
o`1Hooooo`Co00003?ooool2o`0000Oooooo0_l00002ooooo`Co00004?ooool2o`0001Sooooo0_l0
0004ooooo`?o00000_ooool3o`0000Wooooo0_l00005ooooo`;o000000?oooooo`000?l000002ooo
ool2o`0000Wooooo0_l0001[ooooo`007?ooool00ol0003oooooooooo`1Hooooo`?o00003Oooool2
o`0000Oooooo0_l00002ooooo`Co00000_ooool2o`0001_ooooo1_l00004ooooo`;o00000oooool2
o`0000;ooooo0_l000001?oooooo0000o`000?l00006ooooo`;o00002oooool2o`0000_ooooo0_l0
0009ooooo`;o000000?oooooo`000?l00000J?ooool001cooooo00?o0000ooooooooool0FOooool2
o`0000[ooooo0_l00003ooooo`;o00000oooool2o`0000Cooooo0ol00003ooooo`;o00002?ooool2
o`0000?ooooo0_l0000<ooooo`Ko00001?ooool4o`000003ooooool0003o000000;ooooo0_l0000:
ooooo`;o00003Oooool2o`0001Kooooo1Ol0001Vooooo`007?ooool00ol0003oooooooooo`1Uoooo
o`Co000000?oooooo`000?l000000oooool2o`0001Cooooo0_l00003ooooo`;o00003_ooool2o`00
0003ooooool0003o000000Gooooo0_l000000ooooooo0000o`00000Fooooo`;o00001Oooool2o`00
01Kooooo0_l000000ooooooo0000o`00001Vooooo`007?ooool00ol0003oooooooooo`1Booooo`;o
00001_ooool2o`0000_ooooo0_l00003ooooo`;o000000Coooooo`000?l0003o00006?ooool2o`00
00Wooooo0_l00002ooooo`;o00000_ooool2o`0000Sooooo0ol0000;ooooo`;o00002?ooool2o`00
00Gooooo0_l0000Aooooo`;o00004_ooool2o`0005[ooooo000Looooo`03o`000?oooooooooo05;o
oooo0_l00004ooooo`Co00000_ooool2o`0000Sooooo0_l00002ooooo`;o000000Coooooo`000?l0
003o00004?ooool4o`0000Cooooo0_l00009ooooo`;o00000_ooool2o`0000;ooooo0_l00009oooo
o`Go00002?ooool2o`000003ooooool0003o000000Kooooo0_l00004ooooo`;o00000_ooool2o`00
00gooooo0_l0000;ooooo`?o00001?ooool2o`0000gooooo0_l0001;ooooo`007?ooool00ol0003o
ooooooooo`1=ooooo`;o00002Oooool3o`0000?ooooo0_l00003ooooo`;o00000oooool2o`0000Ko
oooo1?l000000ooooooo0000o`00000;ooooo`Co00007_ooool4o`0000;ooooo0ol00006ooooo`Co
000000Coooooo`000?l0003o00001Oooool2o`0000Sooooo0_l00004ooooo`;o00001oooool4o`00
00Wooooo1?l0000Booooo`;o0000Boooool001cooooo00?o0000ooooooooool0COooool3o`00017o
oooo1?l0000<ooooo`Ko0000;Oooool4o`0000;ooooo1?l00005ooooo`Go000000?oooooo`000?l0
00000oooool3o`0000Gooooo1_l00004ooooo`;o00002Oooool2o`0000_ooooo0_l0001Oooooo`00
7?ooool00ol0003oooooooooo`1>ooooo`;o00001oooool2o`0000Sooooo1?l000000ooooooo0000
o`000005ooooo`;o00001?ooool4o`0000Gooooo0_l0000Uooooo`;o00001oooool2o`0000Oooooo
0ol00006ooooo`?o00001Oooool5o`0000Gooooo0_l0001gooooo`007?ooool00ol0003ooooooooo
o`1?ooooo`;o00000_ooool2o`0000;ooooo0_l0000=ooooo`;o000000?oooooo`000?l000000_oo
ool4o`0000Cooooo0_l00003ooooo`Co00009Oooool2o`00017ooooo0_l0000?ooooo`Co00001Ooo
ool2o`0007Oooooo000Looooo`03o`000?oooooooooo04Wooooo0_l00004ooooo`;o00000_ooool3
o`0000Cooooo0_l0000:ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Wooooo0_l0000T
ooooo`Go00002oooool2o`0000Cooooo0_l000000ooooooo0000o`000009ooooo`;o00000oooool2
o`0007kooooo000Looooo`03o`000?oooooooooo04Wooooo0_l00009ooooo`Co000000Coooooo`00
0?l0003o0000A?ooool4o`0000cooooo0ol000000ooooooo0000o`000003ooooo`Co00000oooool2
o`0000;ooooo0_l00003ooooo`;o0000O_ooool001cooooo00?o0000ooooooooool0D_ooool2o`00
00;ooooo0_l000000ooooooo0000o`00000Aooooo`;o0000<?ooool2o`0000Kooooo0_l000000ooo
oooo0000o`000002o`0000;ooooo1ol00002ooooo`Oo000000?oooooo`000?l000001oooool2o`00
02;ooooo0_l00004ooooo`;o0000E?ooool001cooooo0_l0001@ooooo`;o000000?oooooo`000?l0
00001Oooool2o`000003ooooool0003o000000;o00002?ooool2o`0000;ooooo0_l0000Rooooo`;o
00001oooool2o`0000?ooooo0_l00006ooooo`Oo00000_ooool=o`000003ooooool0003o000000Oo
oooo0_l000000ooooooo0000o`00000=ooooo`;o00004oooool2o`0000Cooooo0_l0000;ooooo`;o
0000Aoooool001cooooo00?o0000ooooooooool0Coooool2o`0000Sooooo0_l000000ooooooo0000
o`000002o`0000Sooooo0_l00005ooooo`;o000000?oooooo`000?l000002?ooool2o`0000;ooooo
0ol0000=ooooo`;o00001oooool2o`0000Oooooo0_l00004ooooo`Go000000?oooooo`000?l00000
3?l000000ooooooo0000o`000007ooooo`;o00002?ooool2o`0000;ooooo0_l00002ooooo`;o0000
0_ooool2o`0001?ooooo0_l0000=ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0C?oo
ool2o`00027ooooo0_l000000ooooooo0000o`000008ooooo`;o00000_ooool5o`0000_ooooo0_l0
000<ooooo`;o00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`00000Co`0000Oooooo0_l0
00000ooooooo0000o`000005ooooo`;o00000_ooool2o`0000Kooooo0_l0000Cooooo`;o0000E_oo
ool001cooooo00?o0000ooooooooool0C?ooool2o`000003ooooool0003o000001Kooooo0_l00003
ooooo`;o00003?ooool2o`0000Oooooo0_l000000ooooooo0000o`000002ooooo`;o00002Oooool2
o`0000Kooooo0ol000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000004ol00007
ooooo`;o000000?oooooo`000?l000004Oooool4o`0006Wooooo000Looooo`03o`000?oooooooooo
04Gooooo0_l00008ooooo`;o00005_ooool2o`0000?ooooo0_l0000<ooooo`?o00001_ooool2o`00
0003ooooool0003o000000;ooooo0_l00002ooooo`Co00000oooool2o`0000Gooooo0ol00002oooo
o`?o00001OoooolFo`00013ooooo0_l0000=ooooo`;o00004?ooool3o`0005Kooooo000Looooo`03
o`000?oooooooooo04Gooooo0_l0000Cooooo`;o00003?ooool2o`00017ooooo0_l0000=ooooo`;o
00000_ooool4o`0000[ooooo0ol00003ooooo`;o00000ooooolFo`0001;ooooo1?l0000Mooooo`?o
0000E_ooool001cooooo00?o0000ooooooooool0AOooool2o`0000Kooooo0_l00004ooooo`;o0000
1Oooool2o`0000Gooooo0_l00005ooooo`Co00001oooool2o`0000;ooooo0_l00005ooooo`Co0000
6Oooool2o`0000[ooooo6?l0000Booooo`;o00008?ooool2o`0005Cooooo000Looooo`03o`000?oo
oooooooo04Gooooo0ol000001Ooooooo0000o`000?l0003ooooo00Co00000_ooool3o`0000_ooooo
0_l000000ooooooo0000o`000004ooooo`Ko00000oooool2o`0000;ooooo1?l00003ooooo`Co0000
2Oooool4o`0000Cooooo0_l00006ooooo`;o00001OoooolMo`0000Gooooo0_l00002ooooo`;o0000
:Oooool2o`0005Cooooo000Looooo`03o`000?oooooooooo04Kooooo0_l000001?oooooo0000o`00
0?l00003ooooo`;o00000oooool2o`0000Sooooo0_l000001?oooooo0000o`000?ooool2o`0000Go
oooo1Ol00009ooooo`;o00000_ooool4o`0000Gooooo0ol00002ooooo`Co00000_ooool4o`0000go
oooo7Ol00005ooooo`;o00000_ooool2o`0007oooooo000Looooo`03o`000?oooooooooo03gooooo
0_l00007ooooo`?o00000oooool2o`00013ooooo0_l00004ooooo`;o00002?ooool2o`0000gooooo
1?l00005ooooo`?o00002?ooool2o`0000Kooooo0ol00007oooooaco0000R_ooool001cooooo00?o
0000ooooooooool0?Oooool2o`0000Cooooo1_l00003ooooo`;o00002?ooool2o`0000cooooo0_l0
0008ooooo`;o00002oooool2o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o00003_oo
ool5o`0000Kooooo7Ol0000Booooo`;o00008Oooool2o`0005?ooooo000Looooo`03o`000?oooooo
oooo03kooooo0_l00003ooooo`Go00002oooool2o`000003ooooool0003o000000?ooooo0_l00004
ooooo`;o00001?ooool3o`0000;ooooo1?l0000;ooooo`;o00001Oooool2o`0000?ooooo0_l0000<
ooooo`Co000000?oooooo`000?l000000_l00003oooooako00000_ooool2o`0000kooooo0_l0000:
ooooo`;o00005Oooool2o`00017ooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0noooo
o`;o00001Oooool4o`0000[ooooo0_l00006ooooo`;o00000_ooool5o`0000?ooooo0ol00002oooo
o`;o00000_ooool2o`0000Oooooo1?l00005ooooo`;o00004Oooool2o`0000?ooooo1?l00003oooo
o`co00000_ooool@o`0000;ooooo0_l0000Jooooo`;o0000:?ooool2o`00043ooooo000Looooo`03
o`000?oooooooooo04Oooooo0_l0000Fooooo`;o000000?oooooo`000?l000001Oooool2o`0000Go
oooo0_l00007ooooo`Oo000000?oooooo`000?l000000_l00002ooooo`;o00004?ooool2o`0000Co
oooo0_l00002oooooaco00000oooool2o`0001[ooooo0_l0000:ooooo`;o00001?ooool2o`0005Oo
oooo000Looooo`03o`000?oooooooooo043ooooo0_l0000<ooooo`;o00003Oooool2o`0000[ooooo
0_l00006ooooo`Co00001oooool=o`0000Gooooo0_l00009ooooo`;o00001?ooool2o`000003oooo
ool0003o000001_o00000oooool2o`0001[ooooo0_l0000:ooooo`Co00000_ooool2o`0005Oooooo
000Looooo`03o`000?oooooooooo043ooooo0_l00002ooooo`;o000000?oooooo`000?l000001Ooo
ool2o`0000Sooooo0_l00003ooooo`;o00004_ooool4o`0000Gooooo3ol00003ooooo`Co00004Ooo
oolMo`0002gooooo1_l0001Hooooo`007?ooool2o`0004Gooooo0_l000000ooooooo0000o`00000:
ooooo`?o00000_ooool4o`0001kooooo4?l00002ooooo`Co00001Oooool2o`0000[ooooo7ol00000
0ooooooo0000o`00000Iooooo`;o00002oooool8o`0000[ooooo0_l0001<ooooo`007?ooool00ol0
003oooooooooo`0gooooo`;o00000_ooool2o`0000[ooooo0_l000000ooooooo0000o`000002o`00
00Gooooo0ol00004ooooo`;o00003?ooool2o`0000gooooo6ol00003ooooo`Co00001?ooool4o`00
00;ooooo6?l000000ooooooo0000o`000002o`000003ooooool0003o000001Wooooo0_l0000:oooo
o`_o00002?ooool2o`0004cooooo000Looooo`03o`000?oooooooooo03Oooooo0_l00002ooooo`;o
00002_ooool2o`000003ooooool0003o000000?o00002oooool2o`0000Wooooo1Ol000000ooooooo
0000o`000003ooooo`;o00001Oooool6o`000003ooooool0003o000000go00000oooool2o`0000Co
oooo0ol000001?oooooo0000o`000?ooool4o`0000;ooooo6Ol0000Booooo`;o00006?ooool?o`00
00?ooooo0ol0001<ooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00001_ooool2o`000003
ooooool0003o000000Gooooo0_l00004ooooo`;o00000oooool2o`0000Cooooo0ol00003ooooo`;o
00000oooool2o`0000Oooooo4ol0000:ooooo`;o00000_ooool2o`0000Sooooo4?l000000ooooooo
0000o`000007o`0000Oooooo0_l000000ooooooo0000o`000004ooooo`;o00005oooool@o`0000?o
oooo0ol0001<ooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00002Oooool2o`000003oooo
ool0003o000000;ooooo0_l00008ooooo`?o00005_oooolFo`0000Oooooo1?l00002ooooo`;o0000
2?oooolEo`000003ooooool0003o000000?o00001_ooool2o`000003ooooool0003o000000gooooo
0_l0000=ooooo`oo00000_ooool2o`0001?ooooo0_l0000kooooo`007?ooool00ol0003ooooooooo
o`0nooooo`;o00002_ooool2o`0000Cooooo0_l0000<ooooo`;o00005ooooolGo`0000Kooooo1?l0
0002ooooo`;o00001oooool5o`000003ooooool0003o000001Co00001_ooool2o`0000Sooooo0_l0
0005ooooo`?o00002OoooolBo`0000?ooooo0_l0000Cooooo`;o0000>oooool001cooooo00?o0000
ooooooooool0=Oooool2o`0000Oooooo0_l000000ooooooo0000o`000007ooooo`;o00002oooool2
o`000003ooooool0003o000000?o00005Oooool2o`000003ooooool0003o000001Go00000_ooool2
o`0000;ooooo0_l0000<oooooa_o00004_ooool2o`0000Gooooo0_l0000:oooooa;o00006?ooool2
o`0003_ooooo000Looooo`03o`000?oooooooooo03?ooooo1?l0000:ooooo`;o00004Oooool2o`00
0004ooooool0003o0000ooooo`Go00003oooool2o`0000Cooooo5?l000001Ooooooo0000o`000?l0
003ooooo00;o000000?oooooo`000?l000000_ooool2o`0000cooooo0_l000000ooooooo0000o`00
000Co`000003ooooool0003o000000Sooooo0_l0000=ooooo`;o00003OoooolAo`0000Kooooo0_l0
001=ooooo`007?ooool00ol0003oooooooooo`0cooooo`Co00001Oooool2o`000003ooooool0003o
000000?ooooo1?l0000<ooooo`;o00001_ooool2o`0000kooooo1_l00004oooooaKo000000?ooooo
o`000?l000002?ooool2o`0000Cooooo0_l00006ooooo`So000000Coooooo`000?l0003o00000_oo
ool<o`0000Gooooo0ol0000:ooooo`;o000000?oooooo`000?l000003oooool7o`000003ooooool0
003o000000Go00001_ooool2o`0004gooooo000Looooo`03o`000?oooooooooo03;ooooo1?l00000
1?oooooo0000o`000?ooool4o`000003ooooool0003o000000?ooooo1?l00008ooooo`;o00001_oo
ool2o`0000cooooo0ol00003ooooo`?o000000?oooooo`000?l000000ooooolFo`000003ooooool0
003o000000Sooooo0ol00003ooooo`?o00002_ooool3o`0000;ooooo1?l000001Ooooooo0000o`00
0?l0003ooooo00Co00000_ooool2o`0000Gooooo1?l00009ooooo`;o00000oooool2o`0000_ooooo
3_l0001Hooooo`007?ooool00ol0003oooooooooo`0booooo`;o00000oooool6o`0001?ooooo0_l0
0006ooooo`;o00003?ooool3o`0000Cooooo0_l00002oooooago00002?ooool2o`0000Cooooo0_l0
0004ooooo`;o00001Oooool9o`000003ooooool0003o000000?o00002?ooool2o`0000Cooooo0_l0
000>ooooo`;o000000?oooooo`000?l000002?ooool3o`000003ooooool0003o000000So0000F?oo
ool001cooooo00?o0000ooooooooool0>Oooool2o`0002Sooooo0_l00007ooooo`;o000000?ooooo
o`000?l000001?l000000ooooooo0000o`000006o`000003ooooool0003o000000co00001Oooool4
o`0000[ooooo1_l00006ooooo`Go00001?ooool3o`000003ooooool0003o000000Gooooo0_l00000
1?oooooo0000o`000?ooool2o`0000Oooooo0_l00008ooooo`;o00003?ooool:o`0005Sooooo000L
ooooo`03o`000?oooooooooo03;ooooo0_l0000Gooooo`;o00000oooool2o`0000Cooooo0_l00008
ooooo`;o000000?oooooo`000?l000001oooool2o`000004ooooool0003o0000ooooo`Co000000?o
ooooo`000?l000004ol00006ooooo`Co000000?oooooo`000?l000001Oooool4o`0000;ooooo0_l0
0007ooooo`;o00001?ooool2o`0000Cooooo0ol00004ooooo`;o000000Coooooo`000?l0003ooooo
0_l00007ooooo`;o00003_ooool2o`0000Oooooo1ol0001Jooooo`007?ooool00ol0003ooooooooo
o`0booooo`;o000000?oooooo`000?l000005?ooool2o`0000?ooooo0_l00002ooooo`Co00001ooo
ool5o`00013ooooo0_l000000ooooooo0000o`00000Bo`0000_ooooo0ol000000ooooooo0000o`00
0004o`000003ooooool0003o000000;ooooo0_l00003ooooo`;o00001oooool3o`0000Cooooo0_l0
0003ooooo`?o000000Coooooo`000?l0003ooooo0_l0000Gooooo`;o00001oooool2o`0000;ooooo
0_l0001Kooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool2o`000003
oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0=Oooool2o`0001Gooooo0_l00006ooooo`;o
00001_ooool2o`000003ooooool0003o000000?o00000_ooool3o`0000Sooooo0_l00004ooooo`?o
000000?oooooo`000?l000003Ol00005ooooo`;o00001Oooool2o`0000;ooooo1?l00003ooooo`;o
00000_ooool2o`0000?ooooo0_l00008ooooo`;o00002Oooool2o`0000Gooooo0_l0000Jooooo`;o
00000_ooool2o`0000Cooooo0_l0001Kooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5oooo
o`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Oooooo0_l0000Coooo
o`?o00003Oooool2o`0000;ooooo0_l00004ooooo`?o00000oooool2o`0000?ooooo0_l00009oooo
o`ko00001Oooool2o`0000Wooooo0_l00006ooooo`;o00003_ooool3o`0000Cooooo0_l00004oooo
o`Co00007oooool2o`0000;ooooo0_l00004ooooo`;o00001oooool2o`0005;ooooo00000ooooooo
410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006ooooo`03o`000?oooooooooo03Oo
oooo0_l0000Booooo`Co00003Oooool2o`0000;ooooo0_l00003ooooo`?o00001?ooool4o`0000So
oooo0ol000000ooooooo0000o`000008o`0000Cooooo0_l0000>ooooo`;o00001_ooool2o`0000ko
oooo0ol00004ooooo`;o00001?ooool4o`0001cooooo0_l0000Dooooo`;o0000D_ooool00003oooo
ool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?m4A4CogMgMooooool00007ooooo`?o
0000@Oooool2o`0000Sooooo1?l0000Fooooo`?o00001Oooool3o`000003ooooool0003o000000?o
oooo1_l000000ooooooo0000o`000007o`0000Cooooo0_l00005ooooo`;o00004Oooool2o`0000Co
oooo0_l00007ooooo`?o0000:Oooool2o`0006Sooooo00000ooooooo0000ooooo`02ooooo`03o`00
0?oooooooooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`0booooo`;o
00003?ooool3o`0000Oooooo0_l0000>ooooo`;o00002_ooool3o`0000Gooooo0_l000000ooooooo
0000o`000003ooooo`Ko000000?oooooo`000?l000001_l00009ooooo`;o000000?oooooo`000?l0
00000_l00002ooooo`Co00002Oooool2o`0000Cooooo0_l00008ooooo`;o00005Oooool2o`0000_o
oooo0ol00006ooooo`;o0000I_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool0
2_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo037ooooo1Ol0000:ooooo`;o0000
0oooool2o`0000;ooooo0ol00003ooooo`;o00002Oooool2o`0000?ooooo1?l00003ooooo`?o0000
00?oooooo`000?l000002Oooool2o`0000[ooooo0_l00003ooooo`;o00001_ooool3o`0000;ooooo
2?l0000Aooooo`;o00001Oooool2o`0001Kooooo0_l00006ooooo`;o00000oooool5o`0000Cooooo
0_l0000Cooooo`;o0000DOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg3?ooool00oo^k^ko
A4A4o`000007ooooo`03o`000?oooooooooo02cooooo0_l00003ooooo`;o000000?oooooo`000?l0
00002_ooool2o`0000?ooooo1_l00004ooooo`;o00002Oooool2o`0000?ooooo1?l00005ooooo`Co
00000oooool2o`0000Cooooo0_l0000;ooooo`;o00000_ooool2o`000003ooooool0003o000000Co
oooo0_l00004ooooo`;o00005Oooool2o`0000Gooooo0_l00005ooooo`;o00005oooool2o`0000Ko
oooo0_l0000Gooooo`Go000000?oooooo`000?l000000_l0001;ooooo`0000Koooooonk^k_lb<S;o
0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0;?ooool2o`00
01Wooooo0_l00003ooooo`;o00003_ooool2o`0000[ooooo0_l00002ooooo`;o000000?oooooo`00
0?l000002_ooool2o`0000;ooooo1Ol00005ooooo`;o00000_ooool2o`0000?ooooo1Ol00002oooo
o`?o00001?ooool2o`0000[ooooo0_l0000;ooooo`?o00004Oooool2o`000003ooooool0003o0000
02;ooooo0_l000001?oooooo0000o`000?ooool4o`0000Oooooo0_l00012ooooo`007?ooool00ol0
003oooooooooo`0cooooo`Co00003_ooool4o`0000?ooooo0_l0000>ooooo`;o00002_ooool3o`00
0003ooooool0003o000000gooooo0_l00002ooooo`Co00001?ooool2o`0000Cooooo0_l00003oooo
o`[o00001?ooool4o`0000?ooooo0_l0000@ooooo`;o00001?ooool2o`0000cooooo0_l000000ooo
oooo0000o`00000Looooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`Co00002Oooool2o`00
03Oooooo000Looooo`03o`000?oooooooooo03?ooooo1?l00009ooooo`;o00000oooool2o`0000Wo
oooo0_l00007ooooo`;o000000?oooooo`000?l000000oooool2o`0000Gooooo0ol00003ooooo`;o
00000_ooool2o`0001?ooooo1?l00002ooooo`Go00001?ooool6o`0000Kooooo0_l00003ooooo`;o
00000_ooool2o`0001;ooooo0_l0000@ooooo`;o00003_ooool2o`0000_ooooo0_l00005ooooo`;o
00001Oooool2o`0000Gooooo0_l0000;ooooo`;o0000=oooool001cooooo00?o0000ooooooooool0
@?ooool2o`0000?ooooo0_l00005ooooo`?o000000?oooooo`000?l000001oooool2o`000003oooo
ool0003o000000?ooooo0_l0000;ooooo`;o00000_ooool2o`0001Cooooo0ol00002ooooo`Oo0000
0oooool5o`000003ooooool0003o000000;ooooo0_l00003ooooo`;o00000oooool2o`0001gooooo
0_l00005ooooo`;o00003_ooool2o`0000Cooooo0_l00003ooooo`;o00000_ooool2o`0000Sooooo
0_l000000ooooooo0000o`00001:ooooo`007?ooool00ol0003oooooooooo`0Zooooo`;o00006Ooo
ool2o`0000Gooooo0ol000000ooooooo0000o`00000Aooooo`;o00003?ooool2o`0000?ooooo0_l0
0003ooooo`Co00001oooool4o`0000Gooooo1ol000000ooooooo0000o`000002ooooo`So00000ooo
ool2o`0000?ooooo0_l00003ooooo`;o00005?ooool2o`0000;ooooo0_l00007ooooo`;o00002Ooo
ool2o`0000Oooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00003ooooo`;o000000?o
ooooo`000?l000000oooool2o`0000Cooooo0_l00007ooooo`;o00001_ooool2o`0002kooooo000L
ooooo`03o`000?oooooooooo02[ooooo0_l00004ooooo`;o000000?oooooo`000?l000006oooool3
o`00013ooooo0_l000000ooooooo0000o`000002o`0000Oooooo0_l00002ooooo`Co00000_ooool4
o`0000Oooooo0_l00007ooooo`?o00000_ooool6o`000003ooooool0003o000000Go00003_ooool2
o`0000;ooooo0_l0000@ooooo`;o00002oooool2o`0000Gooooo0_l00002ooooo`;o00002?ooool2
o`0000Kooooo0_l00002ooooo`?o00002oooool2o`0000Cooooo0_l00007ooooo`;o00001_ooool2
o`0002kooooo000Looooo`03o`000?oooooooooo02gooooo0_l000001?oooooo0000o`000?ooool2
o`0000;ooooo0ol00004ooooo`;o00004Oooool3o`0000_ooooo1?l00003ooooo`Ko00002Oooool4
o`0001Gooooo0_l00006ooooo`Co00000oooool2o`000004ooooool0003o0000o`00017ooooo0_l0
000Nooooo`;o00001?ooool2o`0000cooooo0_l00003ooooo`;o00001Oooool3o`0005;ooooo000L
ooooo`03o`000?oooooooooo02gooooo0_l00002ooooo`;o00001?ooool3o`0000;ooooo1?l0000A
ooooo`?o00002_ooool5o`0000Gooooo1?l0000Fooooo`?o00002Oooool2o`0000Sooooo0_l00003
ooooo`;o00000_ooool2o`0002cooooo0_l00003ooooo`;o00001?ooool2o`000003ooooool0003o
000000kooooo0_l000000ooooooo0000o`000003ooooo`;o0000D_ooool001cooooo00?o0000oooo
ooooool0;?ooool2o`0000?ooooo1?l00006ooooo`?o00001Oooool4o`0000[ooooo0ol0000:oooo
o`;o00000_ooool2o`000004ooooool0003o0000o`0000?ooooo0_l00008ooooo`;o00002oooool3
o`000003ooooool0003o000000Gooooo0_l000000ooooooo0000o`000006ooooo`?o00000_ooool3
o`0001_ooooo0_l0000>ooooo`?o000000?oooooo`000?l000002Oooool2o`000003ooooool0003o
000000;ooooo0_l0000=ooooo`;o0000Eoooool001cooooo00?o0000ooooooooool09oooool2o`00
00?ooooo0_l00005ooooo`;o00001_ooool4o`0000Cooooo1?l0000:ooooo`?o00001_ooool2o`00
00Kooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000Sooooo0_l00009oooo
o`Co00000_ooool2o`0000Gooooo0_l000000ooooooo0000o`000007ooooo`So00006_ooool2o`00
00gooooo1?l0000Cooooo`;o0000I_ooool001cooooo00?o0000ooooooooool09oooool2o`0000So
oooo0ol000000ooooooo0000o`000002ooooo`;o00000_ooool2o`0001_ooooo0_l00007ooooo`;o
00000oooool3o`0000Oooooo0_l000000ooooooo0000o`000009ooooo`Co00005oooool2o`0000;o
oooo0_l00003ooooo`Co00007_ooool9o`0001;ooooo0_l0000@ooooo`;o00005?ooool2o`0003ko
oooo000Looooo`03o`000?oooooooooo02oooooo1Ol000000ooooooo0000o`000002ooooo`;o0000
4_ooool2o`0001Cooooo1?l000000ooooooo0000o`000002o`0000Kooooo0_l0000[ooooo`;o0000
0oooool4o`0000Cooooo0_l00007ooooo`;o00001Oooool2o`0000Sooooo2_l00004ooooo`;o0000
1?ooool2o`0000Gooooo0_l00005ooooo`;o00002Oooool2o`0001Cooooo1?l0000looooo`007?oo
ool2o`0002Kooooo0_l00008ooooo`Co00003_ooool2o`0000[ooooo0_l0000@ooooo`;o00001?oo
ool7o`0001Sooooo0_l00009ooooo`;o00003?ooool4o`0000Cooooo2Ol00007ooooo`;o00001Ooo
ool3o`0000[ooooo1?l000001?oooooo0000o`000?l00003ooooo`?o00000oooool2o`0000cooooo
0_l0000Qooooo`;o00001oooool2o`0003?ooooo000Looooo`03o`000?oooooooooo02Gooooo0_l0
0008ooooo`;o00001?ooool2o`0000[ooooo0_l0000<ooooo`;o00002_ooool2o`0000;ooooo0_l0
0006ooooo`Go00001?ooool6o`0000?ooooo0_l00009ooooo`;o00000_ooool3o`0000;ooooo1?l0
0003ooooo`;o00001oooool2o`0000;ooooo3Ol00002ooooo`;o00001oooool2o`0000;ooooo0_l0
0006ooooo`;o000000?oooooo`000?l000003Ol0000<ooooo`;o00004Oooool2o`0000oooooo0_l0
000;ooooo`;o0000<oooool001cooooo00?o0000ooooooooool0;oooool2o`0000Cooooo0_l0000<
ooooo`;o00002Oooool3o`0000[ooooo0ol00003ooooo`;o00001oooool2o`0000Cooooo1_l00003
ooooo`;o00003Oooool7o`000004ooooool0003o0000ooooo`?o00000oooool2o`0000;ooooo0_l0
00000ooooooo0000o`000003o`000004ooooool0003o0000ooooo`Ko000000Coooooo`000?l0003o
00000oooool5o`0000Sooooo4ol000000ooooooo0000o`00000:ooooo`;o00004Oooool2o`0000go
oooo1?l00010ooooo`007?ooool00ol0003oooooooooo`0Tooooo`;o00007Oooool2o`0000Wooooo
0_l000000ooooooo0000o`000009ooooo`;o00000oooool2o`0000Gooooo0_l000000ooooooo0000
o`00000:ooooo`;o00000_ooool2o`0000[ooooo0_l00002ooooo`;o00000oooool5o`0000Cooooo
0_l00005ooooo`Co00000_ooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o0000
0oooool3o`0000Sooooo3ol000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000;o
00005?ooool2o`0000cooooo0_l00006ooooo`;o00001?ooool2o`0003cooooo000Looooo`03o`00
0?oooooooooo02Cooooo0_l00005ooooo`?o00001Oooool2o`0000oooooo0_l0000;ooooo`;o0000
1oooool2o`000003ooooool0003o000000Wooooo0_l000000ooooooo0000o`000008ooooo`Co0000
0_ooool2o`0000[ooooo0_l00008ooooo`;o00008oooool2o`000003ooooool0003o000000Kooooo
4_l00002ooooo`;o00000_ooool2o`0001Cooooo0_l0000<ooooo`;o00003?ooool2o`0000Sooooo
0_l0000booooo`007?ooool00ol0003oooooooooo`0Vooooo`;o00000oooool3o`0000Gooooo0_l0
0004ooooo`;o00002Oooool2o`0001Cooooo0_l000000ooooooo0000o`00000:ooooo`;o00001ooo
ool5o`0000Oooooo0_l0000<ooooo`;o00003Oooool2o`0000Oooooo0_l0000@ooooo`;o000000?o
ooooo`000?l000001OoooolGo`0000;ooooo0_l0000=ooooo`;o00002?ooool2o`0000[ooooo0_l0
000:ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Cooooo0_l0000/ooooo`007?ooool0
0ol0003oooooooooo`0Vooooo`;o00001?ooool2o`0000_ooooo0_l00007ooooo`;o00004oooool2
o`000003ooooool0003o000000;ooooo0ol00005ooooo`;o000000?oooooo`000?l000001Oooool7
o`0000Oooooo0_l0000<ooooo`Go00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000007
ooooo`?o00003Oooool2o`0000Oooooo0_l000000ooooooo0000o`00000Do`0000;ooooo0_l0000>
ooooo`;o00002?ooool2o`0000Sooooo1Ol00009ooooo`;o000000?oooooo`000?l000003?ooool2
o`0002cooooo000Looooo`03o`000?oooooooooo04;ooooo0_l0000Cooooo`;o00000_ooool2o`00
0004ooooool0003o0000o`0000Gooooo0_l00008ooooo`;o00003oooool2o`0000[ooooo1?l00002
ooooo`;o00000oooool2o`0000Gooooo0_l00003ooooo`?o00000oooool2o`0000Sooooo0_l00000
0ooooooo0000o`000002o`0000;ooooo6_l000000ooooooo0000o`000008ooooo`;o00002Oooool2
o`0000?ooooo0_l00008ooooo`;o000000?oooooo`000?l000002?ooool2o`0003kooooo000Loooo
o`03o`000?oooooooooo03Sooooo1?l00005ooooo`;o00001_ooool2o`0000;ooooo0_l00008oooo
o`?o000000?oooooo`000?l000002Oooool2o`0001;ooooo0_l00005ooooo`?o00006oooool2o`00
00Wooooo0_l0000:ooooo`Go000000?oooooo`000?l000006Ol0000;ooooo`;o00002Oooool3o`00
00cooooo0_l0000;ooooo`Go0000>oooool001cooooo00?o0000ooooooooool0<Oooool2o`0000Go
oooo1?l00005ooooo`;o00001_ooool2o`0000;ooooo0_l00004ooooo`;o00000_ooool4o`0000Wo
oooo1?l00002ooooo`;o00003_ooool2o`0000Kooooo0_l0000<ooooo`;o00004_ooool2o`0000Go
oooo0_l00008ooooo`?o00001?ooool5o`000003ooooool0003o000001?o00005oooool2o`0001?o
oooo0_l00005ooooo`Co0000>oooool001cooooo00?o0000ooooooooool0:Oooool2o`0000Cooooo
1?l000000ooooooo0000o`00000Mooooo`;o00000oooool3o`0000Wooooo1?l00002ooooo`;o0000
0_ooool2o`0001Kooooo0_l00002ooooo`?o00000oooool2o`00013ooooo1?l00005ooooo`;o0000
2?ooool2o`0000Oooooo0_l00002oooooaGo00002Oooool2o`0000?ooooo0_l0000;ooooo`;o0000
2Oooool2o`0000Cooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0Qooooo`;o00001_oo
ool2o`0000Cooooo0_l00003ooooo`;o00000oooool3o`0000Wooooo0_l000001?oooooo0000o`00
0?ooool2o`0000_ooooo0_l00002ooooo`;o00001oooool3o`0000Kooooo0_l000000ooooooo0000
o`00000Cooooo`?o000000?oooooo`000?l000000_l00002ooooo`;o00003Oooool2o`000003oooo
ool0003o000001Oooooo7?l00009ooooo`;o00000oooool2o`0000[ooooo0ol00008ooooo`?o0000
B_ooool001cooooo00?o0000ooooooooool08Oooool2o`0000[ooooo0_l000000ooooooo0000o`00
0007ooooo`?o00002Oooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000Cooooo
0_l000000ooooooo0000o`000002ooooo`?o00000oooool3o`0000?ooooo0_l00007ooooo`;o0000
1_ooool3o`0000_ooooo0_l00002ooooo`?o00000_ooool2o`0000Gooooo0_l000000ooooooo0000
o`000002ooooo`?o00001_ooool2o`0001;ooooo7?l0000:ooooo`;o00000_ooool2o`0000?ooooo
1Ol000001?oooooo0000o`000?l00009ooooo`;o000000?oooooo`000?l000002oooool2o`0003_o
oooo000Looooo`03o`000?oooooooooo02gooooo1Ol00008ooooo`;o00002_ooool2o`0000?ooooo
3?l00006ooooo`;o00000oooool3o`0000?ooooo0_l0000:ooooo`Co000000Coooooo`000?l0003o
00001_ooool2o`0000?ooooo1_l0000:ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Oo
oooo0_l0000Hooooo`oo000000?oooooo`000?l000001?l0000:ooooo`;o00001oooool8o`0000Wo
oooo1_l0000;ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0;_ooool3o`0001Gooooo
0_l00005ooooo`;o00000_ooool4o`0000gooooo0ol0000?ooooo`Go00000_ooool3o`0000Cooooo
0_l00005ooooo`;o0000=OoooolGo`00017ooooo0ol000001?oooooo0000o`000?ooool3o`0000Wo
oooo1?l0001:ooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00005Oooool2o`00017ooooo
0_l00002ooooo`?o00000oooool2o`0000?ooooo0_l00005ooooo`;o00003?ooool2o`0000Gooooo
1?l000000ooooooo0000o`00000=ooooo`;o00002?ooool:o`000003ooooool0003o000000[o0000
4Oooool3o`000003ooooool0003o000001;ooooo0ol0000:ooooo`;o0000>_ooool001cooooo0_l0
001Oooooo`;o00001?ooool2o`000003ooooool0003o000000Cooooo0ol00008ooooo`Go000000Co
ooooo`000?l0003ooooo0_l00003ooooo`Co00000oooool2o`0000Kooooo0_l00004ooooo`;o0000
1Oooool4o`000003ooooool0003o000000Wooooo0_l00002ooooo`;o00001_oooolLo`0001?ooooo
0_l0000Aooooo`Go00001?ooool2o`0000;ooooo0ol00007ooooo`Co0000;_ooool001cooooo00?o
0000ooooooooool0E?ooool2o`000003ooooool0003o000000Gooooo1?l00005ooooo`;o00000ooo
ool4o`0000?ooooo0_l000000ooooooo0000o`000005o`000003ooooool0003o000000Oooooo0ol0
000;ooooo`;o00000_ooool2o`0000cooooo1_l00002ooooo`;o000000?oooooo`000?l000001_oo
ool2o`0000;ooooo6?l000001?oooooo0000o`000?l0000>ooooo`;o00000oooool2o`00017ooooo
1Ol00004ooooo`;o00000oooool2o`0000Oooooo1?l0000^ooooo`007?ooool00ol0003ooooooooo
o`0eooooo`;o00001?ooool2o`0000_ooooo0_l00008ooooo`Co000000?oooooo`000?l000000_oo
ool2o`000003ooooool0003o000000;o00002_ooool3o`0000?ooooo0ol000000ooooooo0000o`00
0002ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l00000
0_l0000=ooooo`?o00003Oooool4o`0000;ooooo0_l00008ooooo`?o000000?oooooo`000?l00000
0_oooolDo`0000;ooooo0_l0000?ooooo`;o00000_ooool3o`0000Oooooo0_l00008ooooo`;o0000
Aoooool001cooooo00?o0000ooooooooool09oooool2o`0000cooooo0_l00004ooooo`;o00001?oo
ool2o`0000Gooooo0_l00008ooooo`;o00001?ooool5o`000005ooooool0003o0000o`000?ooool0
0_l00009ooooo`;o00000oooool2o`0000Cooooo1?l000000ooooooo0000o`000005o`000003oooo
ool0003o000000Go00003_ooool2o`0000Sooooo0_l0000Cooooo`?o000000?oooooo`000?l00000
5_l00008ooooo`;o00003Oooool2o`0000Sooooo0_l00008ooooo`;o0000Aoooool001cooooo00?o
0000ooooooooool09oooool2o`0001;ooooo0_l00004ooooo`;o00004oooool6o`0000;ooooo0_l0
0002ooooo`;o00005?ooool;o`0000?ooooo0_l0000?ooooo`;o00002oooool3o`0000Kooooo0ol0
000;ooooo`;o000000?oooooo`000?l000001?l000000ooooooo0000o`00000=o`0000Wooooo0_l0
000Gooooo`;o00002oooool2o`00017ooooo1?l0000_ooooo`007?ooool00ol0003oooooooooo`17
ooooo`;o00000_ooool2o`0000Kooooo0_l000000ooooooo0000o`000005o`000003ooooool0003o
000000Wooooo0_l00003ooooo`?o00001Oooool3o`000003ooooool0003o000000So00000_ooool2
o`0000oooooo0_l00009ooooo`;o000000?oooooo`000?l000001_ooool3o`000003ooooool0003o
000000Sooooo0_l00004ooooo`So000000?oooooo`000?l000001_l00003ooooo`;o00003oooool2
o`0000Cooooo0_l00008ooooo`;o000000Coooooo`000?l0003ooooo0_l00005ooooo`;o00004Ooo
ool5o`0002kooooo000Looooo`03o`000?oooooooooo03;ooooo0_l0000Cooooo`;o00000_ooool2
o`0000Kooooo0_l00003ooooo`Ko000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l00000
0ooooooo0000o`000003o`0000Gooooo0ol00002ooooo`Wo00000_ooool2o`0000Kooooo0_l00004
ooooo`;o00003?ooool2o`000003ooooool0003o000000Cooooo0_l00004ooooo`;o00002?ooool2
o`000004ooooool0003o0000ooooo`So000000?oooooo`000?l000001Ol00003ooooo`?o00000ooo
ool3o`0000Sooooo0ol00004ooooo`;o00001?ooool2o`0000Cooooo0ol000000ooooooo0000o`00
000Kooooo`;o0000;_ooool001cooooo00?o0000ooooooooool0<_ooool2o`0001Kooooo0ol0000=
ooooo`Co000000?oooooo`000?l000000_ooool3o`0000Kooooo0_l00002ooooo`;o000000?ooooo
o`000?l000003Ol00003ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00001?ooool2
o`0001;ooooo0_l000000ooooooo0000o`00000Aooooo`Co00000_ooool=o`0000?ooooo0_l00004
ooooo`Go00001_ooool3o`0000[ooooo0_l00004ooooo`;o00003Oooool4o`0003kooooo000Loooo
o`03o`000?oooooooooo04;ooooo0_l00006ooooo`;o00003_ooool2o`0000Sooooo1?l00008oooo
oa7o00001?ooool2o`000003ooooool0003o000000?o00001oooool2o`0001;ooooo0ol00006oooo
o`;o00000oooool2o`0000Gooooo0_l000001Ooooooo0000o`000?l0003ooooo00co000000?ooooo
o`000?l000002_ooool2o`0001Wooooo0_l00005ooooo`;o00001_ooool4o`0003kooooo000Loooo
o`03o`000?oooooooooo02Wooooo0_l0000;ooooo`;o00002_ooool2o`0000;ooooo0_l0000:oooo
o`;o00001Oooool3o`0000Wooooo0ol00005ooooo`Ko00000oooool<o`000003ooooool0003o0000
00;o00000oooool4o`0000Kooooo0_l0000Cooooo`;o00001_ooool2o`0000?ooooo0_l00005oooo
o`;o000000Coooooo`000?l0003o00000_ooool2o`0000;ooooo0ol00002ooooo`;o000000?ooooo
o`000?l000001_ooool2o`0001Kooooo0_l00005ooooo`;o00001Oooool2o`0000;ooooo0_l00002
ooooo`;o000000?oooooo`000?l00000?Oooool001cooooo00?o0000ooooooooool0:Oooool2o`00
00Cooooo0_l00005ooooo`;o00003_ooool2o`0000Oooooo0_l000000ooooooo0000o`000005oooo
o`?o00003_ooool2o`000003ooooool0003o000000;o00000_ooool4o`000004ooooool0003o0000
o`0000;ooooo2Ol00006ooooo`;o00009_ooool2o`0000_ooooo0_l00006ooooo`;o00000oooool2
o`0000Wooooo0_l00006ooooo`;o00000oooool2o`0000Wooooo0_l0000@ooooo`;o00001Oooool2
o`000003ooooool0003o000003[ooooo000Looooo`03o`000?oooooooooo02cooooo0_l000000ooo
oooo0000o`00000@ooooo`;o00003?ooool2o`000003ooooool0003o000001Gooooo4_l00002oooo
o`_o000000?oooooo`000?l000000oooool3o`0000?ooooo0_l0000Hooooo`;o00001?ooool2o`00
00[ooooo0ol0000;ooooo`;o00000_ooool2o`0000gooooo0_l000000ooooooo0000o`000002o`00
00Wooooo0_l00002ooooo`Co00005?ooool2o`0003[ooooo000Looooo`03o`000?oooooooooo02co
oooo0_l000000ooooooo0000o`000004ooooo`;o00002_ooool2o`0000oooooo0_l00003ooooo`Co
00002?ooool2o`0000?ooooo0ol000001Ooooooo0000o`000?l0003ooooo01_o00000oooool3o`00
00?ooooo0_l0000Hooooo`;o00004?ooool2o`000003ooooool0003o000000Co00002Oooool2o`00
00gooooo0_l000000ooooooo0000o`00000;ooooo`;o00000_ooool6o`0000Cooooo0_l00007oooo
o`?o00002_ooool2o`0003;ooooo000Looooo`03o`000?oooooooooo03Gooooo0_l0000Oooooo`Ko
00001oooool3o`000005ooooool0003o0000o`000?ooool06Ol00002ooooo`Go000000Coooooo`00
0?l0003ooooo0_l00004ooooo`;o00000oooool2o`0000cooooo0_l00009ooooo`;o00003_ooool7
o`0000Sooooo0_l0000Mooooo`;o00000_ooool2o`0000;ooooo0_l00004ooooo`;o00001oooool3
o`0000[ooooo0_l0000booooo`007?ooool00ol0003oooooooooo`1Eooooo`?o00000_ooool2o`00
00Sooooo1Ol00002ooooo`;o00000_oooolFo`0000;ooooo2_l00004ooooo`;o00000oooool2o`00
00cooooo0_l00009ooooo`;o00002_ooool2o`0000Gooooo1?l0000Pooooo`;o00001Oooool2o`00
00;ooooo1?l00007ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0<?ooool2o`0000Oo
oooo1_l00002ooooo`Co00003?ooool2o`000004ooooool0003o0000o`0000kooooo0ol000001?oo
oooo0000o`000?l00003oooooako000000Coooooo`000?l0003o00005_ooool3o`0000Sooooo0_l0
000;ooooo`;o00002oooool2o`000003ooooool0003o000000cooooo0ol00002ooooo`;o00001_oo
ool2o`0000[ooooo0ol00007ooooo`;o00001_ooool2o`0003oooooo000Looooo`;o0000<Oooool2
o`0000?ooooo0_l00002ooooo`Ko00000_ooool4o`0000Oooooo0_l00002ooooo`?o000000Cooooo
o`000?l0003o00003oooool6o`0000;ooooo5Ol00002ooooo`ko00001?ooool3o`0000gooooo0ol0
0002ooooo`;o00000_ooool4o`0001Sooooo0_l000000ooooooo0000o`00000<ooooo`?o00000_oo
ool2o`0000Gooooo0_l00006ooooo`;o00000oooool2o`0000oooooo0ol0000oooooo`007?ooool0
0ol0003oooooooooo`0[ooooo`;o00000_ooool2o`0000?ooooo0ol0000;ooooo`;o00002?ooool2
o`0000;ooooo0_l0000>ooooo`;o00001Oooool6o`000003ooooool0003o000000Co000000?ooooo
o`000?l000005?l000000ooooooo0000o`000005o`000004ooooool0003o0000ooooo`?o00004_oo
ool2o`0000;ooooo0_l0000Qooooo`?o00002oooool2o`0000;ooooo0_l00002ooooo`;o00001_oo
ool2o`0001Cooooo0ol000000ooooooo0000o`00000looooo`007?ooool00ol0003oooooooooo`0[
ooooo`?o000000?oooooo`000?l000000oooool2o`0000cooooo0_l0000?ooooo`;o00000_ooool5
o`0000Cooooo0_l00006ooooo`co000000?oooooo`000?l000006?l00003ooooo`Co00000_ooool2
o`00013ooooo1?l00007ooooo`;o000000Coooooo`000?l0003o00001oooool2o`0000oooooo0ol0
0006ooooo`;o00000oooool2o`0000;ooooo0_l0000Qooooo`;o000000?oooooo`000?l00000??oo
ool001cooooo00?o0000ooooooooool0;?ooool2o`0001Cooooo0_l0000;ooooo`;o000000Cooooo
o`000?l0003o00000_ooool5o`0000Sooooo0_l00003oooooako000000?oooooo`000?l000001_l0
0002ooooo`?o00000oooool2o`0000;ooooo0_l0000:ooooo`Ko00001oooool6o`0000Oooooo1?l0
000=ooooo`;o00001oooool2o`0000?ooooo1?l00002ooooo`;o00001_ooool2o`0000Cooooo0_l0
000Dooooo`;o0000??ooool001cooooo00?o0000ooooooooool0;oooool2o`00013ooooo0_l0000<
ooooo`;o000000Coooooo`000?l0003o00003oooool2o`0000;ooooo0_l000000ooooooo0000o`00
000Oo`000003ooooool0003o000000;o000000Coooooo`000?l0003o00001Oooool4o`0000[ooooo
0_l0000<ooooo`;o000000Coooooo`000?l0003ooooo0_l00006ooooo`;o000000?oooooo`000?l0
00002Oooool3o`0000cooooo1?l000001?oooooo0000o`000?l00004ooooo`Oo000000?oooooo`00
0?l000003oooool2o`00047ooooo000Looooo`03o`000?oooooooooo02oooooo0_l0000@ooooo`;o
00001?ooool2o`0000Sooooo1?l00007ooooo`;o00002?ooool4o`000003ooooool0003o000000oo
000000?oooooo`000?l000004_l000000ooooooo0000o`000006ooooo`;o00003oooool3o`0000_o
oooo0_l000000ooooooo0000o`000002ooooo`;o00001Oooool2o`0000Wooooo0_l0000Booooo`?o
000000?oooooo`000?l000000ol000000ooooooo0000o`000005o`0000oooooo0_l00009ooooo`;o
0000=_ooool001cooooo00?o0000ooooooooool0>Oooool2o`0000_ooooo0ol00008ooooo`?o0000
1_ooool4o`0000Cooooo0_l00002ooooobWo00003Oooool2o`0000gooooo0ol0000>ooooo`;o0000
00Coooooo`000?l0003o00008oooool2o`0000?ooooo1?l000000ooooooo0000o`000003ooooo`;o
00000oooool2o`000003ooooool0003o000001?ooooo0_l0000fooooo`007?ooool00ol0003ooooo
ooooo`0iooooo`;o00000oooool2o`0000Kooooo0_l00009ooooo`Co00001Oooool2o`0000Kooooo
0_l00004ooooo`Go000000?oooooo`000?l000004ol000000ooooooo0000o`000009o`0000;ooooo
0ol00008ooooo`;o00004_ooool2o`000003ooooool0003o000000Oooooo0_l000000ooooooo0000
o`000007ooooo`Co000000?oooooo`000?l000002_ooool2o`0000;ooooo0_l00006ooooo`;o0000
00?oooooo`000?l000000_ooool2o`000003ooooool0003o000000Sooooo0_l000000ooooooo0000
o`00001;ooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00001?ooool2o`0000Sooooo0_l0
000Aooooo`Co00001_ooool4o`000004ooooool0003o0000ooooo`;o00000ooooolTo`000003oooo
ool0003o000000;ooooo0ol00009ooooo`;o00003Oooool2o`0000;ooooo0_l000000ooooooo0000
o`000004o`0000Kooooo0ol00006ooooo`Co000000?oooooo`000?l000002_ooool2o`0000;ooooo
0_l00005ooooo`;o00000_ooool2o`0005oooooo000Looooo`03o`000?oooooooooo02kooooo0ol0
0003ooooo`;o00001_ooool6o`0001Wooooo1?l000001?oooooo0000o`000?ooool[o`0000?ooooo
0_l0000:ooooo`;o00003Oooool2o`0000Oooooo1?l00005ooooo`Co00001_ooool2o`0000Oooooo
0_l0000Aooooo`;o00003?ooool2o`0000oooooo0_l00004ooooo`;o0000?_ooool001cooooo00?o
0000ooooooooool0;oooool2o`0000Kooooo0_l00003ooooo`Ko00001Oooool2o`0000Oooooo0_l0
000;ooooo`;o00000oooool2o`000003ooooool0003o000002Oo00006_ooool2o`000003ooooool0
003o0000017ooooo0_l00006ooooo`Co00001oooool2o`0000Wooooo0_l00003ooooo`?o00003_oo
ool2o`0000Cooooo0_l00007ooooo`Co00001?ooool2o`0003kooooo000Looooo`03o`000?oooooo
oooo03;ooooo0_l00003ooooo`;o00003_ooool2o`0000Oooooo0_l00005ooooo`;o00001?ooool2
o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000001?l00002
oooooaco000000Coooooo`000?l0003ooooo0_l00009ooooo`;o00000_ooool2o`0000?ooooo0_l0
00000ooooooo0000o`000005ooooo`;o00004_ooool2o`0001;ooooo2_l0000Dooooo`;o00001ooo
ool3o`0000Gooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0aooooo`?o00002?ooool2
o`0000oooooo0_l00008ooooo`;o00001oooool3o`0000?ooooo0_l000000ooooooo0000o`000009
o`0000;ooooo1?l000000ooooooo0000o`00000Co`000004ooooool0003o0000ooooo`;o00002Ooo
ool2o`0000;ooooo0_l0000=ooooo`;o00002oooool2o`0000gooooo0_l0000:ooooo`?o000000?o
ooooo`000?l000000ol00009ooooo`;o00000oooool2o`00013ooooo0_l00004ooooo`;o0000?_oo
ool001cooooo00?o0000ooooooooool0<Oooool2o`000003ooooool0003o000000Kooooo0_l0000?
ooooo`;o000000Coooooo`000?l0003o00003Oooool3o`000003ooooool0003o000000;o000000Go
ooooo`000?l0003o0000ooooo`0Ro`000003ooooool0003o000000;ooooo0_l0000Yooooo`;o0000
3Oooool2o`00013ooooo0_l00008ooooo`Go00000_ooool2o`0000;ooooo0_l000000ooooooo0000
o`000009ooooo`;o0000A?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Co
oooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo03Cooooo0_l0000Joooo
o`?o00004Oooool3o`0000;ooooo3ol000000ooooooo0000o`00000Go`0001Sooooo0_l00002oooo
o`?o00006oooool4o`0000[ooooo0_l00004ooooo`Co00001_ooool5o`0000Kooooo0_l000000ooo
oooo0000o`00001?ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0>?ooool3o`0000Sooooo0_l0
000Looooo`Ko00000_oooolSo`0000;ooooo1?l00002ooooo`;o00005?ooool7o`0001_ooooo1?l0
000:ooooo`?o00001Oooool2o`0000Gooooo1?l0000:ooooo`;o000000?oooooo`000?l00000COoo
ool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool0>?ooool3o`0000?ooooo0_l00003ooooo`Co00003_oo
ool2o`0000[ooooo0ol00003ooooo`Co00000_oooolOo`000003ooooool0003o000000?o000000Co
ooooo`000?l0003o00001oooool3o`0000cooooo0_l0000Hooooo`;o000000?oooooo`000?l00000
4?ooool2o`0000_ooooo1Ol0000:ooooo`Go000000?oooooo`000?l000000oooool2o`0000Wooooo
0_l0000jooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?nH
V9SooooooiRHV?lQ8B401_ooool3o`0003cooooo1?l00005ooooo`;o00003_ooool2o`000003oooo
ool0003o000000;ooooo0ol00008ooooobGo000000?oooooo`000?l000000ol000000ooooooo0000
o`000008ooooo`?o00002oooool2o`0000Gooooo0_l00003ooooo`;o00002Oooool3o`000004oooo
ool0003o0000ooooo`;o00004_ooool2o`0000?ooooo0_l00004ooooo`?o00003?ooool3o`0000?o
oooo0_l00003ooooo`;o00002Oooool2o`0003[ooooo00000ooooooo0000ooooo`02ooooo`03o`00
0?oooooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo03?o
oooo0_l00007ooooo`;o00006_ooool2o`0000;ooooo0ol00008ooooo`Oo000000?oooooo`000?l0
00007_l0000:ooooo`;o00004?ooool2o`0000;ooooo1Ol00003ooooo`;o00002Oooool3o`0001?o
oooo0_l00003ooooo`?o00000_ooool2o`000003ooooool0003o000000?ooooo0_l0000?ooooo`;o
0000C?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7
ooooo`08ooooo`03o`000?oooooooooo03?ooooo0_l00007ooooo`;o00002oooool2o`0001cooooo
1?l00003ooooob3o000000Coooooo`000?l0003o00001oooool2o`0000cooooo0_l00006ooooo`?o
00001Oooool2o`0000Cooooo0_l0000Iooooo`;o00001?ooool2o`0000Gooooo0ol00002ooooo`;o
00002Oooool2o`0000Cooooo0ol000000ooooooo0000o`000018ooooo`0000KoooooogMgMonHV9So
oooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0BOooool2o`00
01Cooooo0_l00008ooooo`?o00000_ooool3o`000003ooooool0003o000001Oo00000oooool9o`00
013ooooo0_l0000;ooooo`;o000000?oooooo`000?l000001_l00004ooooo`;o00001_ooool2o`00
00Oooooo0_l00002ooooo`Co00002Oooool3o`0000Cooooo0_l00002ooooo`;o00000oooool5o`00
00;ooooo0_l000000ooooooo0000o`000004ooooo`;o0000@_ooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo05Oooooo0ol0
0003ooooo`Co00001?ooool2o`0000?ooooo0ol00002ooooobSo00000oooool2o`0001?ooooo0_l0
0003ooooo`;o00000oooool7o`0000?ooooo0_l00006ooooo`;o00000_ooool2o`0000;ooooo2Ol0
0009ooooo`;o00001Oooool2o`0000;ooooo0_l00005ooooo`?o00002_ooool3o`0000;ooooo0_l0
000nooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o00002?ooool5o`0000?ooooo0ol00005
ooooo`;o00000oooool3o`0000;ooooo6ol000000ooooooo0000o`000003o`0000;ooooo1?l00003
ooooo`?o00004oooool2o`0000;ooooo0ol00003ooooo`;o000000?oooooo`000?l000000_l00002
ooooo`?o00001?ooool2o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l000006Oooool2
o`0000Kooooo0_l00003ooooo`;o00001?ooool2o`0000?ooooo0_l0000nooooo`007?ooool00ol0
003oooooooooo`1;ooooo`;o00002?ooool2o`000003ooooool0003o000000Wooooo0_l0000:oooo
oa_o00000oooool4o`000003ooooool0003o000000;o00000oooool2o`00017ooooo0_l00005oooo
o`;o00000oooool2o`000003ooooool0003o000000?o00000_ooool2o`0000Gooooo0_l00007oooo
o`;o000000?oooooo`000?l000000_l0000Hooooo`;o00001_ooool2o`0000?ooooo0ol00005oooo
o`;o0000@Oooool001cooooo00?o0000ooooooooool0=oooool2o`0000kooooo0_l0000Dooooo`;o
00000oooool3o`0000Sooooo1ol00002ooooo`oo000000?oooooo`000?l000001?l00003ooooo`;o
00000oooool2o`0001;ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo1Ol000000ooooooo
0000o`000005o`000003ooooool0003o000000gooooo0_l000000ooooooo0000o`000002o`0000Go
oooo0_l00003ooooo`;o00005oooool2o`000003ooooool0003o000000Gooooo0_l00011ooooo`00
7?ooool00ol0003oooooooooo`0gooooo`?o00003Oooool4o`0000cooooo0_l00004ooooo`;o0000
0oooool2o`000003ooooool0003o000000;o00001?ooool2o`000003ooooool0003o000000_o0000
00?oooooo`000?l000002?l000001?oooooo0000o`000?l00002ooooo`;o00006?ooool2o`0000?o
oooo0_l00002ooooo`;o000000?oooooo`000?l000003?l000000ooooooo0000o`00000@ooooo`?o
00001_ooool2o`000003ooooool0003o000000;o00000_ooool2o`0000;ooooo0ol00002ooooo`;o
00002_ooool2o`0000Oooooo0_l00003ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0
>?ooool2o`0000kooooo0ol00008ooooo`;o00000_ooool3o`0000?ooooo0_l00005ooooo`Oo0000
0_ooool3o`000004ooooool0003o0000ooooo`Wo000000?oooooo`000?l000002?l000001?oooooo
0000o`000?ooool4o`0001Sooooo1ol00005ooooo`;o00000_ooool:o`000003ooooool0003o0000
00;o00002oooool3o`000003ooooool0003o000000;ooooo0_l00005ooooo`;o00000oooool3o`00
00;ooooo0ol00002ooooo`;o000000?oooooo`000?l000004?ooool2o`0000?ooooo0_l0000moooo
o`007?ooool00ol0003oooooooooo`0hooooo`;o00001Oooool2o`0000[ooooo0_l00006ooooo`;o
00000oooool2o`000003ooooool0003o000000Oooooo1?l000000ooooooo0000o`000002ooooo`Co
00000oooool6o`000004ooooool0003o0000ooooo`Go000000?oooooo`000?l000000_l00004oooo
o`Co00002_ooool2o`0000Wooooo0_l00003ooooo`Ko00001?ooool7o`000003ooooool0003o0000
00Co000000?oooooo`000?l000001?l00009ooooo`?o00001Oooool2o`0000[ooooo0_l00003oooo
o`?o00001Oooool2o`000004ooooool0003o0000o`00053ooooo000Looooo`03o`000?oooooooooo
03Sooooo1?l00003ooooo`;o000000?oooooo`000?l000001oooool2o`0000Cooooo1?l00006oooo
o`;o00002Oooool2o`0000Oooooo1?l00002ooooo`Go00000oooool6o`0000;ooooo0_l00002oooo
o`Oo00000_ooool2o`0000Kooooo0_l000001?oooooo0000o`000?l00005ooooo`;o00000_ooool3
o`0000;ooooo6?l000000ooooooo0000o`000003o`000003ooooool0003o000000;o00003Oooool2
o`0000_ooooo0ol00008ooooo`?o00001?ooool2o`000004ooooool0003o0000ooooo`;o0000A?oo
ool001cooooo00?o0000ooooooooool0>_ooool2o`0000Kooooo0_l0000=ooooo`Co000000?ooooo
o`000?l000000_ooool2o`0001Gooooo0_l000000ooooooo0000o`00000=o`0000;ooooo0_l00002
ooooo`So000000?oooooo`000?l000000_l000000ooooooo0000o`000004ooooo`?o00000oooool4
o`0000;ooooo0ol000000ooooooo0000o`00000Go`000003ooooool0003o000000?o000000?ooooo
o`000?l000000_l000000ooooooo0000o`000008ooooo`Go000000Coooooo`000?l0003ooooo0_l0
00000ooooooo0000o`000002ooooo`?o00001?ooool5o`000003ooooool0003o000000;ooooo0_l0
00001?oooooo0000o`000?ooool2o`0000_ooooo0_l0000gooooo`007?ooool00ol0003ooooooooo
o`16ooooo`;o00003?ooool4o`0000;ooooo0_l0000BoooooaGo00000_ooool2o`0000;ooooo0_l0
0002ooooo`Go00000_ooool5o`0000[ooooo1?l00005oooooago00002Oooool3o`0000Oooooo1Ol0
00001?oooooo0000o`000?ooool7o`000003ooooool0003o000000;o00000_ooool5o`000003oooo
ool0003o000001Gooooo0_l0000gooooo`007?ooool00ol0003oooooooooo`16ooooo`;o00000_oo
ool2o`0000Sooooo0_l00009ooooo`Co00002oooool;o`0000?ooooo1ol000000ooooooo0000o`00
0003ooooo`?o00000oooool3o`0000?ooooo0_l00007ooooo`;o00001?ooool2o`0000Kooooo4_l0
00000ooooooo0000o`00000:o`0000Kooooo1_l00006ooooo`;o00001oooool6o`000003ooooool0
003o000000;o00000oooool4o`00057ooooo000Looooo`03o`000?oooooooooo03Kooooo0_l0000B
ooooo`;o00001_ooool2o`0000_ooooo1?l00009ooooo`;o00000_ooool3o`0000?ooooo3Ol00000
0ooooooo0000o`000004ooooo`;o00000oooool2o`0000[ooooo0_l000000ooooooo0000o`00000<
oooooaoo00001_ooool2o`0000;ooooo0_l0000@ooooo`Ko00001oooool4o`00057ooooo000Loooo
o`;o0000=oooool2o`0001[ooooo0ol0000Booooo`;o00000oooool6o`000003ooooool0003o0000
00?ooooo2ol00004ooooo`;o00002_ooool2o`0000Kooooo0_l0000>ooooo`?o000000?oooooo`00
0?l000006_l00004ooooo`?o00005Oooool3o`000004ooooool0003o0000o`0001Oooooo0_l00012
ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00003Oooool2o`00013ooooo1?l00002oooo
o`Ko00000_ooool2o`000003ooooool0003o000000;o00000oooool4o`0000Kooooo0ol000000ooo
oooo0000o`000003ooooo`Go00001_ooool2o`0000kooooo8ol000001?oooooo0000o`000?l00002
ooooo`;o00004_ooool2o`0000;ooooo1?l0000?ooooo`;o00001?ooool2o`0004;ooooo000Loooo
o`03o`000?oooooooooo04Cooooo0_l00003ooooo`;o00001_ooool4o`0000Gooooo0_l00009oooo
o`;o00001?ooool5o`0000Cooooo1?l00007ooooo`;o00001_ooool3o`000003ooooool0003o0000
00?ooooo1?l00002ooooo`;o000000?oooooo`000?l000000_l00007ooooo`Co000000?oooooo`00
0?l000003?l00002oooooaGo00001_ooool2o`0000kooooo0_l000000ooooooo0000o`000009o`00
00gooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00000_ooool2o`0000Ko
oooo1?l00005ooooo`;o00003oooool2o`0000Oooooo0_l00005ooooo`;o00001Oooool2o`0001;o
oooo0_l000000ooooooo0000o`000009ooooo`Co000000?oooooo`000?l000000oooool2o`000003
ooooool0003o000001[o00003Oooool3o`0000Oooooo0_l000001?oooooo0000o`000?ooool2o`00
0004ooooool0003o0000ooooo`;o00003?ooool2o`0004Wooooo000Looooo`03o`000?oooooooooo
04Gooooo0_l00004ooooo`;o00003_ooool2o`0000?ooooo0_l00004ooooo`;o00000_ooool2o`00
0003ooooool0003o000000[ooooo1ol00002ooooo`;o00001oooool2o`00017ooooo0_l0000>oooo
o`;o000000?oooooo`000?l000005_l00003ooooo`Co00002_ooool3o`0000_ooooo0_l000000ooo
oooo0000o`000009ooooo`Co00001?ooool2o`0004Wooooo000Looooo`03o`000?oooooooooo04_o
oooo0_l0000<ooooo`Co00000oooool2o`0000Cooooo0_l00002ooooo`;o000000Coooooo`000?l0
003o00000oooool2o`0000;ooooo1?l000000ooooooo0000o`000002o`0000;ooooo0_l00007oooo
o`;o00003Oooool2o`0000;ooooo0_l00004ooooo`;o00000_ooool2o`0000?ooooo5?l000000ooo
oooo0000o`000007o`000003ooooool0003o000000;o00002oooool2o`0000Kooooo0_l00003oooo
o`Go00000_ooool4o`0000?ooooo1?l0001?ooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o
000000?oooooo`000?l000001?ooool2o`0000Kooooo0_l00002ooooo`;o00000oooool8o`0000?o
oooo0_l0000;ooooo`;o00003Oooool4o`0000Kooooo0_l00002ooooo`;o00000ooooolNo`000003
ooooool0003o000000Wooooo0_l00002ooooo`;o00001_ooool2o`0000?ooooo0ol00004ooooo`Co
00001Oooool2o`0004oooooo000Looooo`03o`000?oooooooooo04Oooooo0_l0000<ooooo`;o0000
1Oooool2o`0000Cooooo0_l00006ooooo`Co00000oooool2o`0000;ooooo0_l00007ooooo`;o0000
2oooool2o`0000Oooooo0ol00005ooooo`;o00002oooool2o`0000;ooooo7_l000001?oooooo0000
o`000?ooool2o`0000Gooooo0ol00006ooooo`;o00001oooool2o`0005oooooo000Looooo`03o`00
0?oooooooooo04Oooooo0_l0000;ooooo`?o00005Oooool2o`000003ooooool0003o000000;o0000
8Oooool3o`0000Cooooo0_l0000<ooooo`;o000000?oooooo`000?l000008?l000000ooooooo0000
o`000003ooooo`Co00001oooool4o`0006Kooooo000Looooo`03o`000?oooooooooo04_ooooo1?l0
0002ooooo`;o000000?oooooo`000?l000000oooool2o`00017ooooo1Ol0000?ooooo`;o00003_oo
ool4o`0000Oooooo0_l0000<ooooo`;o000000?oooooo`000?l000000oooool@o`000003ooooool0
003o000000_o00001Oooool2o`0000?ooooo0_l00005ooooo`?o00000_ooool2o`0006;ooooo000L
ooooo`03o`000?oooooooooo04_ooooo1?l00002ooooo`;o00001_ooool2o`0001?ooooo0_l00003
ooooo`;o00002oooool2o`000003ooooool0003o000000;ooooo0_l00007ooooo`Co00001oooool2
o`000003ooooool0003o000000Wooooo0_l00006oooooako00000oooool2o`0000Gooooo0_l00003
ooooo`Ko000000?oooooo`000?l000002_ooool2o`0005Kooooo000Looooo`03o`000?oooooooooo
06Sooooo0_l00009ooooo`;o00003_ooool2o`000003ooooool0003o000000;o00003oooool2o`00
00?ooooo0_l00003ooooo`;o00003?oooolJo`000003ooooool0003o000000Cooooo0_l0000:oooo
o`;o00000_ooool2o`0000?ooooo1?l00006ooooo`;o0000E_ooool001cooooo00?o0000oooooooo
ool0J?ooool2o`0000_ooooo1Ol0000<ooooo`Co00003?ooool2o`000003ooooool0003o000000So
oooo0_l00007oooooaoo00002?ooool2o`0000_ooooo0_l00003ooooo`Ko0000G_ooool001cooooo
00?o0000ooooooooool0GOooool2o`0000Kooooo0_l0000:ooooo`;o00000_ooool5o`0000Sooooo
0_l0000Booooo`;o00001Oooool2o`0000[ooooo7ol000000ooooooo0000o`000002o`0000Kooooo
0_l00007ooooo`;o00000_ooool2o`0000?ooooo0_l00009ooooo`;o00000oooool3o`00057ooooo
000Looooo`03o`000?oooooooooo03oooooo0_l0000=ooooo`;o00002?ooool2o`0000?ooooo0_l0
0006ooooo`;o00002_ooool2o`0000Cooooo0_l00003ooooo`;o00001?ooool6o`0000Sooooo0_l0
000;ooooo`;o00002Oooool5o`000003ooooool0003o000000?ooooo6_l0000?ooooo`;o00000_oo
ool2o`0000kooooo0_l00002ooooo`Co00001Oooool2o`0004[ooooo000Looooo`03o`000?oooooo
oooo03oooooo1?l0000;ooooo`;o00002?ooool2o`0000cooooo0_l00009ooooo`;o00001_ooool5
o`000003ooooool0003o000000?ooooo1?l000000ooooooo0000o`000005ooooo`;o00000oooool2
o`000003ooooool0003o000000kooooo0_l00006ooooo`;o000000?oooooo`000?l000000_l00000
0ooooooo0000o`00000?o`000003ooooool0003o000000;o00001oooool2o`000003ooooool0003o
000000;ooooo1_l0000Booooo`;o00000_ooool2o`0000?ooooo0_l0001:ooooo`007?ooool2o`00
04;ooooo0_l0000Fooooo`;o00001_ooool2o`0000?ooooo0_l00006ooooo`;o000000?oooooo`00
0?l000001_ooool3o`0000?ooooo1?l00006ooooo`Oo00001Oooool2o`000003ooooool0003o0000
00Gooooo0_l0000<ooooo`Ko000000?oooooo`000?l000002_l000000ooooooo0000o`000007o`00
00;ooooo0_l00007ooooo`;o000000?oooooo`000?l000000oooool3o`0001Sooooo0_l0001?oooo
o`007?ooool00ol0003oooooooooo`1=ooooo`;o00001_ooool2o`0000;ooooo0_l00006ooooo`;o
00002Oooool4o`00013ooooo0ol00002ooooo`;o00000oooool6o`0000oooooo0_l00009ooooo`;o
000000?oooooo`000?l000001?l00003oooooa3o00000_ooool2o`0000;ooooo0_l0000Kooooo`;o
0000G_ooool001cooooo00?o0000ooooooooool0COooool2o`0000Kooooo0_l00002ooooo`;o0000
1?ooool2o`0000_ooooo0_l00004ooooo`;o00002oooool2o`0000Cooooo0ol0000:ooooo`;o0000
4_ooool2o`0000;ooooo0_l0000;ooooo`Go00000_ooool8o`0000;ooooo0ol00002ooooo`?o0000
1?ooool2o`0001?ooooo0_l0001Nooooo`007?ooool00ol0003oooooooooo`1Kooooo`;o00000_oo
ool2o`00017ooooo1?l00007ooooo`Co00001Oooool5o`0000;ooooo0_l00003ooooo`;o00004Ooo
ool3o`0001;ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l00002ooooo`?o00000_oo
ool3o`0000Cooooo0_l00008ooooo`?o00001_ooool2o`0000Kooooo0_l0001Hooooo`007?ooool0
0ol0003oooooooooo`1Fooooo`;o00000oooool2o`0000Gooooo1?l0000>ooooo`;o00001oooool2
o`0000Gooooo0_l00002ooooo`?o00000_ooool4o`0000;ooooo0_l0000@ooooo`;o00002Oooool2
o`0000[ooooo0ol00004ooooo`;o00003?ooool2o`0000Sooooo0_l000001?oooooo0000o`000?l0
0003ooooo`;o000000?oooooo`000?l000001_ooool2o`0005Sooooo000Looooo`03o`000?oooooo
oooo04?ooooo0_l0000Aooooo`;o00002_ooool4o`0000Cooooo0_l0000;ooooo`;o00002oooool2
o`000003ooooool0003o000000Co00000_ooool2o`0000;ooooo0ol0000?ooooo`;o00002Oooool2
o`0000[ooooo1_l00003ooooo`;o00001Oooool2o`0000?ooooo1Ol00005ooooo`Go00001?ooool3
o`0006;ooooo000Looooo`03o`000?oooooooooo04?ooooo0_l0000;ooooo`;o00004?ooool3o`00
00Gooooo0_l0000;ooooo`;o00002?ooool2o`0000Cooooo0_l00002ooooo`;o00001oooool4o`00
0003ooooool0003o000000Cooooo0_l00004ooooo`;o00002_ooool2o`0000Gooooo0_l00004oooo
o`Co00000oooool2o`0000Cooooo0ol00004ooooo`Co00001_ooool2o`0000Oooooo0_l00004oooo
o`;o0000G?ooool001cooooo00?o0000ooooooooool0D?ooool2o`00017ooooo0_l0000Looooo`;o
00002?ooool2o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l000001?ooool4o`0000So
oooo0_l00003ooooo`?o00000oooool4o`0000Cooooo0_l0000;ooooo`;o00001Oooool2o`0000?o
oooo0_l0000Booooo`;o000000?oooooo`000?l000002Oooool2o`0004kooooo000Looooo`03o`00
0?oooooooooo06;ooooo0_l000000ooooooo0000o`00000Dooooo`;o00003_ooool6o`0000Cooooo
0_l00009ooooo`?o00000oooool2o`0000?ooooo0_l00003ooooo`?o00000oooool3o`0000Gooooo
0_l0000Cooooo`;o00000_ooool2o`0001Gooooo0_l00007ooooo`Co0000C_ooool001cooooo00?o
0000ooooooooool0Goooool5o`000003ooooool0003o000001Cooooo0_l0000;ooooo`;o00000ooo
ool2o`0000Kooooo0_l0000:ooooo`Co000000?oooooo`000?l000003oooool4o`0000;ooooo0ol0
0002ooooo`;o00001oooool2o`0000Kooooo0_l00008ooooo`;o00005Oooool2o`000004ooooool0
003o0000o`0004oooooo000Looooo`03o`000?oooooooooo05?ooooo0_l0000:ooooo`?o00009_oo
ool2o`0000Cooooo0_l0000:ooooo`;o00001oooool3o`0001?ooooo0_l00002ooooo`?o00000_oo
ool2o`0000Oooooo0_l00008ooooo`;o00000oooool5o`0001Gooooo0_l00002ooooo`;o0000Cooo
ool001cooooo00?o0000ooooooooool0Doooool2o`0000Sooooo1?l0000]ooooo`;o00002_ooool2
o`0000Sooooo0_l0000@ooooo`;o00005oooool8o`0000?ooooo1?l0000Eooooo`;o0000E?ooool0
01cooooo00?o0000ooooooooool0Doooool2o`0000Sooooo1?l000000ooooooo0000o`00000>oooo
o`;o0000:oooool2o`0001Gooooo0ol00003ooooo`;o00004Oooool6o`0000Oooooo0_l0000Eoooo
o`;o0000E?ooool001cooooo00?o0000ooooooooool0Goooool5o`0000gooooo0ol00004ooooo`;o
00009Oooool2o`0001Kooooo0_l00003ooooo`;o00000oooool2o`0000_ooooo0ol000000ooooooo
0000o`00000@ooooo`;o00000oooool2o`0005kooooo000Looooo`03o`000?oooooooooo05oooooo
1Ol00004ooooo`;o00001oooool2o`0000Gooooo0_l00011ooooo`;o00001?ooool2o`000003oooo
ool0003o000000Sooooo0ol000000ooooooo0000o`000004ooooo`;o00002_ooool2o`0000?ooooo
0_l0001Nooooo`007?ooool00ol0003oooooooooo`1Looooo`?o000000?oooooo`000?l000000_l0
00001?oooooo0000o`000?ooool2o`0000;ooooo0_l00012ooooo`;o000000?oooooo`000?l00000
1_ooool2o`0000;ooooo1?l000000ooooooo0000o`000008ooooo`;o00002?ooool2o`0006oooooo
000Looooo`;o0000GOooool3o`0000Gooooo0ol00003ooooo`Co00002Oooool2o`0000Sooooo0_l0
000/ooooo`?o000000?oooooo`000?l000002_ooool4o`0000Kooooo0_l000000ooooooo0000o`00
000>ooooo`;o0000Joooool001cooooo00?o0000ooooooooool0Foooool2o`0000Oooooo0_l00004
ooooo`;o00001?ooool2o`0000Cooooo0ol00008ooooo`;o0000;?ooool2o`0001Sooooo0_l00000
0ooooooo0000o`00000>ooooo`;o0000Joooool001cooooo00?o0000ooooooooool0Foooool4o`00
00_ooooo0_l00003ooooo`Co00000oooool2o`000003ooooool0003o000003;ooooo0_l00003oooo
o`;o0000:Oooool2o`0006[ooooo000Looooo`03o`000?oooooooooo05gooooo0_l0000;ooooo`;o
00000oooool4o`0000Kooooo0_l00009ooooo`?o00009_ooool2o`0000?ooooo0_l00009ooooo`Co
00007?ooool2o`0006[ooooo000Looooo`03o`000?oooooooooo06oooooo1?l0000Aooooo`?o0000
9oooool2o`0000Cooooo0ol00006ooooo`Co0000R?ooool001cooooo00?o0000ooooooooool0LOoo
ool2o`0003_ooooo0_l00002ooooo`Go0000T_ooool001cooooo00?o0000ooooooooool0JOooool2
o`0000?ooooo0ol0000mooooo`;o00000_ooool2o`0009Gooooo000Looooo`03o`000?oooooooooo
06Cooooo0_l00003ooooo`;o00000oooool5o`0001Cooooo0_l0000hooooo`?o00008?ooool2o`00
00Cooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1Tooooo`;o00002oooool2o`0000[o
oooo0_l00003ooooo`;o00000oooool2o`0002[ooooo0_l0000<ooooo`?o00008?ooool2o`0000Co
oooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1Qooooo`Co00001_ooool3o`0000Cooooo
0_l00009ooooo`;o00000oooool2o`0000;ooooo0_l0000Pooooo`;o00002Oooool2o`0000Gooooo
0_l00009ooooo`?o0000POooool001cooooo00?o0000ooooooooool0HOooool4o`0000Kooooo1?l0
0003ooooo`Co00004?ooool2o`00023ooooo0_l0000@ooooo`;o00000oooool2o`0000Cooooo0ol0
000Hooooo`;o0000Ioooool001cooooo00?o0000ooooooooool0KOooool2o`0000Gooooo0_l0000d
ooooo`;o00003_ooool2o`0000?ooooo0_l00004ooooo`;o00006Oooool2o`0006Oooooo000Loooo
o`03o`000?oooooooooo06gooooo0_l00005ooooo`;o00001_ooool4o`0002[ooooo0_l0000;oooo
o`;o00001oooool4o`0008Gooooo000Looooo`03o`000?oooooooooo07Cooooo0_l00005ooooo`Oo
000000Coooooo`000?l0003o0000;oooool5o`0000?ooooo0_l000000ooooooo0000o`000002o`00
01Kooooo0_l0001]ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool0
1Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0Noooool2o`0000?ooooo0_l0
00001?oooooo0000o`000?l0000Nooooo`;o00003oooool2o`000003ooooool0003o000000?ooooo
0_l0000Kooooo`;o0000KOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Co
oooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo09Oooooo0_l000000ooo
oooo0000o`000008ooooo`;o00004Oooool2o`0001kooooo0_l0001`ooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`1jooooo`;o00002?ooool2o`0000;ooooo0_l0000=ooooo`;o000000?oooooo`00
0?l000005?ooool4o`0000?ooooo1?l0000Looooo`;o0000L?ooool00003ooooool0003ooooo00;o
oooo00?o0000ooooooooool02Oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0001joooo
o`;o00002?ooool2o`000004ooooool0003o0000o`0001Gooooo0_l0000>ooooo`Go00000oooool4
o`0008kooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Goc<c<o`00
0?l0003o0000olc<c006ooooo`03o`000?oooooooooo07Gooooo0_l00004ooooo`;o00001oooool5
o`0000_ooooo0_l000000ooooooo0000o`000003ooooo`Go00000oooool2o`000004ooooool0003o
0000o`0000Gooooo0_l00006ooooo`;o0000T?ooool00003ooooool@413ooooo00;ooooo00?o410@
ooooooooool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0J_oo
ool2o`0000Wooooo0_l00004ooooo`Co00001Oooool5o`0000_ooooo0_l000000ooooooo0000o`00
0003ooooo`?o00001?ooool7o`0009oooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo
00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo06[ooooo0_l0000Aooooo`?o
00001?ooool2o`000003ooooool0003o000000[ooooo0ol000000ooooooo0000o`000007ooooo`;o
000000?oooooo`000?l000000_l0000=ooooo`;o000000?oooooo`000?l00000T?ooool00006oooo
ooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000
ooooooooool0O_ooool2o`0000Cooooo0_l0000=ooooo`?o00002_ooool5o`0000Oooooo0_l00006
ooooo`;o000000?oooooo`000?l00000T?ooool001cooooo00?o0000ooooooooool0Q?ooool2o`00
01_ooooo0_l000000ooooooo0000o`000006ooooo`?o00002?ooool2o`00093ooooo000Looooo`03
o`000?oooooooooo0:Cooooo1_l00002ooooo`?o00001Oooool2o`000003ooooool0003o000001So
oooo0_l0001fooooo`007?ooool00ol0003oooooooooo`2Rooooo`;o00000_ooool4o`0000[ooooo
0_l0000Kooooo`;o0000M_ooool001cooooo00?o0000ooooooooool0P_ooool2o`0001kooooo0_l0
00000ooooooo0000o`00000>ooooo`;o0000T_ooool001cooooo00?o0000ooooooooool0P_ooool3
o`0001?ooooo0_l0000;ooooo`;o00001Oooool2o`0000Cooooo0_l000000ooooooo0000o`00000C
ooooo`;o0000OOooool001cooooo00?o0000ooooooooool0Poooool2o`0000kooooo0_l00003oooo
o`;o00004_ooool2o`0000Cooooo0_l0000Fooooo`;o0000OOooool001cooooo00?o0000oooooooo
ool0N?ooool2o`0001Sooooo0ol0000:ooooo`;o0000Z?ooool001cooooo00?o0000ooooooooool0
N?ooool2o`0001Sooooo0_l00005ooooo`;o00001?ooool2o`0001[ooooo0ol00007ooooo`;o0000
P_ooool001cooooo00?o0000ooooooooool0Roooool2o`0000cooooo0_l000000ooooooo0000o`00
000<ooooo`;o00000oooool2o`0000Oooooo0_l000001?oooooo0000o`000?l00004ooooo`;o0000
00?oooooo`000?l00000P_ooool001cooooo00?o0000ooooooooool0Roooool2o`0000Kooooo0_l0
00000ooooooo0000o`000004ooooo`;o00003?ooool2o`0000?ooooo0_l00007ooooo`;o00002?oo
ool2o`0008Gooooo000Looooo`03o`000?oooooooooo09?ooooo0_l000000ooooooo0000o`00000Q
ooooo`;o0000S_ooool001cooooo0_l0002Cooooo`;o00001Oooool2o`000003ooooool0003o0000
01_ooooo0_l0002>ooooo`007?ooool00ol0003oooooooooo`2Booooo`;o00001Oooool6o`0000oo
oooo0_l0002Iooooo`007?ooool00ol0003oooooooooo`2Kooooo`Co00003oooool2o`0009Wooooo
000Looooo`03o`000?oooooooooo08[ooooo0_l0002mooooo`007?ooool00ol0003oooooooooo`2:
ooooo`;o00004oooool2o`000:Sooooo000Looooo`03o`000?oooooooooo08gooooo0_l0000@oooo
o`;o0000Z?ooool001cooooo00?o0000ooooooooool0SOooool2o`0003Cooooo0_l00024ooooo`00
7?ooool00ol0003oooooooooo`33ooooo`;o0000Q?ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
09[ooooo0_l0000/ooooo`;o0000Ooooool001cooooo00?o0000ooooooooool0VOooool3o`0002Go
oooo0_l00005ooooo`;o0000Ooooool001cooooo00?o0000ooooooooool0VOooool3o`0002Gooooo
0_l00026ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0/?ooool2o`0009Oooooo000Looooo`;o
0000/Oooool2o`0009Oooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Booooo`Co000000?o410@oooooooo
ool00oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`?o0000oooo
oom:ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo
0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003ooooo
ooooo`3ooooooe;ooooo000Booooo`03oeEEEOmVIVKo00000?ooooooE?ooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00:Gooooo00Co410@o`000?l0003ooooo0_l000000ol@413o
ooooooooo`0Eooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^j@ooooo`00Y_ooool01Ol0003ooooooooooooooooo000000Wooooo
1_l00009ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0T?ooool00:Kooooo00Go0000ooooooooooooooooo`00000Hoooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@4100T?ooool00:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00002Ooo
ool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo0000093ooooo002Vooooo`05o`000?n7QhOoooooojVYZOl000006?ooool01Oo<c<co
0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
0000093ooooo002Uooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool05_ooool01Ol@
413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@093ooooo0033ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0T?ooool00<?ooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@04ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP2@ooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(816) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.53296 .67923 Mdot
.54735 .66677 Mdot
.61291 .35554 Mdot
.41919 .54535 Mdot
.47773 .50591 Mdot
.58306 .33013 Mdot
.62915 .52234 Mdot
.62647 .54015 Mdot
.56381 .33722 Mdot
.31489 .64291 Mdot
.65534 .49603 Mdot
.45051 .54524 Mdot
.62705 .50874 Mdot
.38314 .54222 Mdot
.596 .1778 Mdot
.43272 .58557 Mdot
.59893 .69067 Mdot
.4136 .38033 Mdot
.37576 .49227 Mdot
.56527 .3801 Mdot
.6082 .64724 Mdot
.3791 .54098 Mdot
.53811 .68813 Mdot
.38252 .54338 Mdot
.41681 .5707 Mdot
.57207 .67863 Mdot
.58409 .71776 Mdot
.39946 .59673 Mdot
.39826 .55987 Mdot
.66508 .51505 Mdot
.42029 .42597 Mdot
.44957 .16801 Mdot
.4422 .57269 Mdot
.33128 .7604 Mdot
.62903 .53719 Mdot
.22045 .39162 Mdot
.55909 .36172 Mdot
.62786 .48404 Mdot
.63067 .53971 Mdot
.60462 .51627 Mdot
.62368 .48949 Mdot
.57163 .67192 Mdot
.59133 .50325 Mdot
.60888 .45579 Mdot
.41852 .53042 Mdot
.70073 .60734 Mdot
.30911 .32638 Mdot
.38139 .5933 Mdot
.54995 .64852 Mdot
.55215 .37334 Mdot
.47135 .83107 Mdot
.60405 .53097 Mdot
.73723 .40972 Mdot
.45752 .08862 Mdot
.6146 .50192 Mdot
.4241 .54437 Mdot
.57594 .35329 Mdot
.35913 .55603 Mdot
.37533 .55396 Mdot
.47415 .80685 Mdot
.40101 .58521 Mdot
.42007 .36104 Mdot
.56683 .62441 Mdot
.60264 .31352 Mdot
.57426 .33276 Mdot
.64884 .53564 Mdot
.59474 .67214 Mdot
.63556 .51021 Mdot
.32814 .60132 Mdot
.54683 .35273 Mdot
.3802 .59382 Mdot
.65235 .49022 Mdot
.54479 .63605 Mdot
.34151 .55773 Mdot
.72024 .62976 Mdot
.66629 .22193 Mdot
.41182 .38547 Mdot
.45402 .78949 Mdot
.55258 .7557 Mdot
.69666 .27665 Mdot
.39002 .5536 Mdot
.864 .53627 Mdot
.61273 .18661 Mdot
.54021 .68682 Mdot
.45841 .50434 Mdot
.52239 .34022 Mdot
.35548 .52967 Mdot
.47347 .45195 Mdot
.34607 .61784 Mdot
.69211 .7087 Mdot
.56125 .34211 Mdot
.57349 .65892 Mdot
.4163 .54139 Mdot
.35493 .60233 Mdot
.43237 .71722 Mdot
.3336 .57862 Mdot
.4079 .597 Mdot
.60763 .69777 Mdot
.65451 .52277 Mdot
.41136 .62759 Mdot
.58284 .49628 Mdot
.74429 .39168 Mdot
.38906 .51673 Mdot
.5539 .33343 Mdot
.60504 .668 Mdot
.38218 .5124 Mdot
.6118 .51594 Mdot
.39174 .57661 Mdot
.59419 .48194 Mdot
.54483 .6614 Mdot
.35119 .59794 Mdot
.41122 .37567 Mdot
.75764 .64128 Mdot
.58335 .66513 Mdot
.82894 .50085 Mdot
.39247 .58922 Mdot
.37273 .54106 Mdot
.55021 .66659 Mdot
.60029 .34912 Mdot
.46265 .4332 Mdot
.58433 .64886 Mdot
.61206 .52737 Mdot
.55764 .7146 Mdot
.33301 .52127 Mdot
.57684 .3226 Mdot
.75091 .38813 Mdot
.76976 .3987 Mdot
.26825 .48564 Mdot
.3632 .52366 Mdot
.64787 .58318 Mdot
.59302 .33336 Mdot
.56663 .65986 Mdot
.63537 .50694 Mdot
.42938 .57862 Mdot
.5831 .70189 Mdot
.64483 .49503 Mdot
.40868 .36343 Mdot
.40561 .26813 Mdot
.56335 .64262 Mdot
.5742 .56814 Mdot
.65318 .46925 Mdot
.60474 .51356 Mdot
.36939 .79683 Mdot
.54631 .67122 Mdot
.44309 .34517 Mdot
.64555 .5002 Mdot
.35348 .38459 Mdot
.42096 .58975 Mdot
.25253 .53732 Mdot
.79557 .66354 Mdot
.45668 .83557 Mdot
.75918 .50103 Mdot
.45266 .36251 Mdot
.60349 .49881 Mdot
.41037 .554 Mdot
.5503 .67902 Mdot
.55955 .67495 Mdot
.37595 .61328 Mdot
.41625 .58015 Mdot
.36289 .59622 Mdot
.36339 .60565 Mdot
.34499 .30018 Mdot
.36387 .60066 Mdot
.59828 .40033 Mdot
.58904 .67918 Mdot
.40925 .57272 Mdot
.5999 .36129 Mdot
.43638 .53779 Mdot
.63779 .48562 Mdot
.37024 .55096 Mdot
.42324 .56989 Mdot
.34114 .53447 Mdot
.61461 .492 Mdot
.39293 .20528 Mdot
.78553 .66334 Mdot
.24988 .31083 Mdot
.78773 .50584 Mdot
.58839 .35205 Mdot
.36581 .5283 Mdot
.42755 .34717 Mdot
.43348 .64358 Mdot
.37969 .56035 Mdot
.53683 .8312 Mdot
.41711 .58626 Mdot
.29267 .70147 Mdot
.31823 .51491 Mdot
.24921 .30158 Mdot
.53133 .42147 Mdot
.39893 .5663 Mdot
.40867 .69034 Mdot
.24457 .62226 Mdot
.50363 .58992 Mdot
.61912 .49432 Mdot
.60246 .35516 Mdot
.56728 .35715 Mdot
.60498 .48168 Mdot
.38177 .63457 Mdot
.29661 .60966 Mdot
.42526 .62603 Mdot
.75564 .39163 Mdot
.54727 .63333 Mdot
.43696 .32853 Mdot
.54656 .64257 Mdot
.85873 .45223 Mdot
.668 .71221 Mdot
.66399 .47097 Mdot
.4477 .38105 Mdot
.61251 .35099 Mdot
.75942 .39145 Mdot
.43447 .3457 Mdot
.37213 .58465 Mdot
.55712 .64818 Mdot
.25787 .67224 Mdot
.33004 .50596 Mdot
.20554 .62223 Mdot
.56285 .70935 Mdot
.50279 .43795 Mdot
.63275 .49441 Mdot
.56268 .38491 Mdot
.38354 .52757 Mdot
.3537 .58295 Mdot
.59316 .63925 Mdot
.38215 .59069 Mdot
.5083 .70027 Mdot
.42528 .56746 Mdot
.52855 .33709 Mdot
.3928 .36802 Mdot
.59932 .49354 Mdot
.26674 .49352 Mdot
.52537 .65591 Mdot
.63801 .30982 Mdot
.56045 .37392 Mdot
.36108 .66144 Mdot
.65651 .49479 Mdot
.41247 .37448 Mdot
.57694 .3763 Mdot
.4594 .3409 Mdot
.36899 .51341 Mdot
.55652 .36114 Mdot
.4475 .33915 Mdot
.374 .25383 Mdot
.42558 .53958 Mdot
.35275 .32372 Mdot
.63627 .52146 Mdot
.55072 .71288 Mdot
.40215 .58447 Mdot
.77202 .39537 Mdot
.38562 .50401 Mdot
.71222 .45175 Mdot
.74375 .41128 Mdot
.73504 .40417 Mdot
.66569 .24769 Mdot
.43062 .37746 Mdot
.75296 .55348 Mdot
.61174 .60614 Mdot
.59573 .67227 Mdot
.41623 .5359 Mdot
.317 .23198 Mdot
.64468 .49963 Mdot
.37202 .58148 Mdot
.52447 .33966 Mdot
.64572 .50314 Mdot
.35538 .55306 Mdot
.60856 .49815 Mdot
.55359 .67607 Mdot
.59266 .27008 Mdot
.59066 .70657 Mdot
.42796 .54856 Mdot
.61633 .51955 Mdot
.57786 .37025 Mdot
.57029 .68178 Mdot
.38886 .5751 Mdot
.37656 .53042 Mdot
.75407 .39822 Mdot
.40476 .56751 Mdot
.32469 .23322 Mdot
.39131 .59763 Mdot
.61487 .32899 Mdot
.33417 .59202 Mdot
.4691 .8508 Mdot
.43091 .27005 Mdot
.58796 .66116 Mdot
.73838 .40768 Mdot
.56661 .34136 Mdot
.56874 .25886 Mdot
.53659 .57219 Mdot
.39034 .56374 Mdot
.7437 .40444 Mdot
.48528 .41539 Mdot
.65564 .53195 Mdot
.33087 .56039 Mdot
.69108 .68696 Mdot
.57929 .37959 Mdot
.75778 .39318 Mdot
.41674 .48975 Mdot
.60563 .66914 Mdot
.42064 .54906 Mdot
.564 .3697 Mdot
.55734 .71511 Mdot
.42325 .52144 Mdot
.2644 .36922 Mdot
.75998 .4092 Mdot
.63624 .52023 Mdot
.29178 .57496 Mdot
.36873 .59923 Mdot
.57362 .36216 Mdot
.54634 .69644 Mdot
.6309 .53475 Mdot
.57961 .67621 Mdot
.24597 .64135 Mdot
.78895 .5226 Mdot
.32461 .29802 Mdot
.44508 .38345 Mdot
.71311 .43413 Mdot
.23162 .33126 Mdot
.76571 .56614 Mdot
.31136 .42409 Mdot
.16478 .45201 Mdot
.59118 .36877 Mdot
.37811 .33387 Mdot
.57125 .34433 Mdot
.40555 .5414 Mdot
.57852 .33002 Mdot
.24882 .29552 Mdot
.41742 .58775 Mdot
.5848 .35466 Mdot
.51012 .30162 Mdot
.41023 .58439 Mdot
.58766 .67026 Mdot
.56341 .18153 Mdot
.70263 .73058 Mdot
.62913 .73595 Mdot
.59433 .3525 Mdot
.54513 .7861 Mdot
.40258 .59358 Mdot
.44156 .55203 Mdot
.55303 .68315 Mdot
.33113 .5869 Mdot
.42579 .33122 Mdot
.46204 .34125 Mdot
.26366 .51948 Mdot
.82574 .55586 Mdot
.38802 .63882 Mdot
.56661 .68251 Mdot
.50782 .71495 Mdot
.71651 .63036 Mdot
.76606 .38037 Mdot
.67431 .5067 Mdot
.40317 .2047 Mdot
.342 .63325 Mdot
.57414 .57212 Mdot
.70171 .67248 Mdot
.56055 .65236 Mdot
.34946 .24688 Mdot
.61718 .50188 Mdot
.45154 .67298 Mdot
.34446 .73316 Mdot
.36148 .58737 Mdot
.66171 .5079 Mdot
.4424 .59404 Mdot
.66798 .73834 Mdot
.36461 .36625 Mdot
.77871 .34145 Mdot
.42289 .536 Mdot
.74833 .56699 Mdot
.37237 .54524 Mdot
.31363 .47234 Mdot
.38957 .59955 Mdot
.58013 .68265 Mdot
.43474 .62755 Mdot
.50093 .49288 Mdot
.81924 .60461 Mdot
.65991 .72473 Mdot
.45593 .35724 Mdot
.37608 .53331 Mdot
.35885 .58569 Mdot
.4368 .37105 Mdot
.56824 .69407 Mdot
.38544 .60076 Mdot
.24628 .44309 Mdot
.36502 .5947 Mdot
.63449 .48388 Mdot
.43302 .42646 Mdot
.59894 .7349 Mdot
.34101 .58099 Mdot
.5946 .70673 Mdot
.61125 .49955 Mdot
.64102 .54098 Mdot
.31624 .57936 Mdot
.60587 .49583 Mdot
.42249 .55148 Mdot
.43971 .41065 Mdot
.53718 .67815 Mdot
.37463 .4763 Mdot
.56796 .69784 Mdot
.5579 .76971 Mdot
.60718 .50469 Mdot
.76739 .38747 Mdot
.53905 .60042 Mdot
.61994 .50731 Mdot
.61114 .76228 Mdot
.37622 .64447 Mdot
.39688 .49975 Mdot
.64897 .75702 Mdot
.59242 .36099 Mdot
.76319 .38804 Mdot
.61499 .52178 Mdot
.36597 .59864 Mdot
.34534 .5193 Mdot
.64796 .48158 Mdot
.46153 .72801 Mdot
.55404 .26215 Mdot
.40156 .59824 Mdot
.57753 .68764 Mdot
.56957 .66155 Mdot
.41681 .51453 Mdot
.38372 .5707 Mdot
.61385 .33245 Mdot
.75333 .40798 Mdot
.74529 .38476 Mdot
.76926 .39694 Mdot
.55043 .38317 Mdot
.71662 .52231 Mdot
.60437 .51485 Mdot
.67859 .58059 Mdot
.67859 .43777 Mdot
.31606 .53145 Mdot
.57693 .36456 Mdot
.35 .56876 Mdot
.39897 .52907 Mdot
.63159 .53413 Mdot
.76798 .45954 Mdot
.43348 .48685 Mdot
.53883 .65487 Mdot
.60773 .49203 Mdot
.33209 .63663 Mdot
.68182 .47211 Mdot
.42967 .33268 Mdot
.62649 .74421 Mdot
.66134 .50181 Mdot
.57363 .65475 Mdot
.64332 .4774 Mdot
.36023 .58943 Mdot
.3963 .61129 Mdot
.55116 .66048 Mdot
.43432 .37774 Mdot
.33645 .52616 Mdot
.35601 .55088 Mdot
.58222 .85128 Mdot
.72349 .62497 Mdot
.66078 .54578 Mdot
.40422 .55623 Mdot
.3649 .49898 Mdot
.45692 .36262 Mdot
.36774 .59359 Mdot
.38009 .52622 Mdot
.76254 .64305 Mdot
.59092 .53608 Mdot
.39731 .36286 Mdot
.45279 .66983 Mdot
.56577 .70932 Mdot
.35515 .21955 Mdot
.74175 .39304 Mdot
.59197 .52448 Mdot
.59526 .27204 Mdot
.76426 .39558 Mdot
.69434 .43625 Mdot
.35382 .23316 Mdot
.76821 .39317 Mdot
.61541 .29026 Mdot
.46875 .5572 Mdot
.39686 .60573 Mdot
.36676 .54923 Mdot
.42456 .34507 Mdot
.54743 .67322 Mdot
.51562 .42592 Mdot
.41135 .24104 Mdot
.37693 .54093 Mdot
.55044 .61686 Mdot
.39884 .22474 Mdot
.75774 .39727 Mdot
.41633 .36428 Mdot
.42311 .32817 Mdot
.37039 .54198 Mdot
.77669 .60123 Mdot
.57016 .67911 Mdot
.3887 .57459 Mdot
.34775 .58807 Mdot
.59235 .3557 Mdot
.56803 .64979 Mdot
.55853 .37236 Mdot
.749 .4118 Mdot
.18464 .51624 Mdot
.55407 .85499 Mdot
.63943 .53029 Mdot
.27501 .29519 Mdot
.63657 .54495 Mdot
.73126 .28912 Mdot
.76639 .40197 Mdot
.38407 .55849 Mdot
.5286 .64655 Mdot
.39148 .57875 Mdot
.36515 .57982 Mdot
.37048 .58534 Mdot
.39934 .63797 Mdot
.52951 .83387 Mdot
.43614 .35589 Mdot
.32705 .51995 Mdot
.5943 .31811 Mdot
.30445 .26042 Mdot
.56323 .19444 Mdot
.34597 .56192 Mdot
.36899 .5381 Mdot
.59229 .68648 Mdot
.36609 .61363 Mdot
.6667 .51525 Mdot
.54246 .69426 Mdot
.3509 .51501 Mdot
.33771 .25933 Mdot
.3813 .60222 Mdot
.22897 .34069 Mdot
.64418 .47809 Mdot
.6223 .74474 Mdot
.32234 .53024 Mdot
.76891 .39206 Mdot
.76385 .38837 Mdot
.75458 .37655 Mdot
.66839 .5018 Mdot
.57996 .35913 Mdot
.5183 .21146 Mdot
.41344 .61977 Mdot
.41333 .55641 Mdot
.36112 .50087 Mdot
.57903 .39112 Mdot
.45508 .44917 Mdot
.75393 .5201 Mdot
.34476 .64014 Mdot
.60619 .32767 Mdot
.54313 .70917 Mdot
.83033 .45641 Mdot
.54351 .69435 Mdot
.39654 .36313 Mdot
.64833 .49074 Mdot
.42236 .33501 Mdot
.54644 .80678 Mdot
.54558 .66391 Mdot
.59567 .6426 Mdot
.58722 .35369 Mdot
.52864 .45174 Mdot
.37372 .14212 Mdot
.5491 .3328 Mdot
.26518 .45237 Mdot
.55692 .68607 Mdot
.33824 .56617 Mdot
.47872 .41195 Mdot
.52383 .45483 Mdot
.58235 .34503 Mdot
.38875 .54662 Mdot
.81312 .57992 Mdot
.61451 .33481 Mdot
.33154 .55311 Mdot
.59997 .33686 Mdot
.63142 .48825 Mdot
.59617 .33587 Mdot
.52644 .6761 Mdot
.37898 .51492 Mdot
.43038 .10776 Mdot
.5791 .45478 Mdot
.39921 .58274 Mdot
.6078 .49214 Mdot
.23102 .4514 Mdot
.35962 .5723 Mdot
.41947 .33402 Mdot
.58447 .32117 Mdot
.53092 .25976 Mdot
.40112 .59253 Mdot
.58853 .33785 Mdot
.52994 .67582 Mdot
.61971 .54952 Mdot
.67657 .24686 Mdot
.75473 .3836 Mdot
.54575 .68037 Mdot
.72667 .39412 Mdot
.66244 .47879 Mdot
.33625 .5431 Mdot
.35276 .59308 Mdot
.58552 .68229 Mdot
.68054 .31376 Mdot
.35426 .60985 Mdot
.38991 .55349 Mdot
.60687 .36258 Mdot
.61368 .3668 Mdot
.65117 .28274 Mdot
.5898 .36874 Mdot
.35695 .50127 Mdot
.58497 .68151 Mdot
.40494 .53393 Mdot
.58841 .66841 Mdot
.41629 .53686 Mdot
.51075 .67108 Mdot
.5419 .68703 Mdot
.80656 .52993 Mdot
.39535 .53551 Mdot
.29952 .54165 Mdot
.36661 .58346 Mdot
.37565 .59464 Mdot
.57242 .3199 Mdot
.43564 .36649 Mdot
.35479 .62202 Mdot
.63728 .32944 Mdot
.41229 .3615 Mdot
.26066 .64724 Mdot
.59413 .35555 Mdot
.42146 .34311 Mdot
.35663 .30581 Mdot
.73701 .40515 Mdot
.42843 .35405 Mdot
.54928 .19424 Mdot
.63677 .53187 Mdot
.55234 .70948 Mdot
.41089 .58331 Mdot
.16659 .49126 Mdot
.41938 .42092 Mdot
.75113 .40284 Mdot
.39588 .5906 Mdot
.35233 .56946 Mdot
.60367 .67288 Mdot
.86569 .48737 Mdot
.61326 .35903 Mdot
.41345 .54662 Mdot
.59623 .69662 Mdot
.81445 .64114 Mdot
.56252 .32369 Mdot
.42612 .35102 Mdot
.63593 .48049 Mdot
.5795 .72648 Mdot
.75483 .38299 Mdot
.65597 .53263 Mdot
.55756 .28892 Mdot
.56693 .79787 Mdot
.38976 .59336 Mdot
.56973 .36546 Mdot
.46351 .83726 Mdot
.39433 .63353 Mdot
.63641 .56687 Mdot
.26483 .57099 Mdot
.56412 .65304 Mdot
.64252 .48123 Mdot
.45211 .33623 Mdot
.53742 .69108 Mdot
.56941 .69245 Mdot
.62047 .53783 Mdot
.53682 .38709 Mdot
.50518 .44065 Mdot
.6449 .48423 Mdot
.70218 .7002 Mdot
.25782 .66425 Mdot
.74573 .40664 Mdot
.41973 .3708 Mdot
.27786 .71859 Mdot
.57258 .67232 Mdot
.40091 .20515 Mdot
.51166 .83197 Mdot
.40768 .59708 Mdot
.43926 .337 Mdot
.69596 .4646 Mdot
.49817 .20868 Mdot
.64633 .50738 Mdot
.47357 .46916 Mdot
.40733 .34039 Mdot
.39165 .60451 Mdot
.62403 .71809 Mdot
.39686 .54202 Mdot
.64105 .49051 Mdot
.56903 .75625 Mdot
.57656 .656 Mdot
.65718 .47538 Mdot
.61895 .75723 Mdot
.39706 .52729 Mdot
.39247 .54096 Mdot
.34267 .44408 Mdot
.55547 .64777 Mdot
.74901 .38269 Mdot
.39391 .57148 Mdot
.36112 .55434 Mdot
.33621 .54916 Mdot
.30854 .61218 Mdot
.76314 .6135 Mdot
.41145 .54401 Mdot
.53899 .36764 Mdot
.42762 .51706 Mdot
.39147 .53667 Mdot
.59905 .69685 Mdot
.55835 .84631 Mdot
.76891 .40507 Mdot
.3676 .55265 Mdot
.38525 .59855 Mdot
.62364 .53669 Mdot
.49537 .42548 Mdot
.52632 .46067 Mdot
.54785 .3445 Mdot
.32553 .39826 Mdot
.40523 .63525 Mdot
.57638 .70526 Mdot
.40646 .36816 Mdot
.35165 .52744 Mdot
.58707 .70109 Mdot
.43805 .55926 Mdot
.61173 .33305 Mdot
.74996 .40722 Mdot
.64079 .67797 Mdot
.42347 .35775 Mdot
.50285 .38705 Mdot
.66701 .60406 Mdot
.60289 .35714 Mdot
.41491 .56308 Mdot
.60653 .53983 Mdot
.55144 .35571 Mdot
.75184 .39887 Mdot
.40247 .48307 Mdot
.56094 .6775 Mdot
.57883 .66177 Mdot
.27535 .50361 Mdot
.62336 .32001 Mdot
.70404 .76578 Mdot
.63287 .48826 Mdot
.3785 .50808 Mdot
.61956 .59663 Mdot
.58066 .66272 Mdot
.27234 .5025 Mdot
.42005 .34452 Mdot
.64613 .50964 Mdot
.77097 .37947 Mdot
.58978 .69653 Mdot
.56095 .64412 Mdot
.42207 .53033 Mdot
.35204 .54212 Mdot
.30216 .43128 Mdot
.2634 .51717 Mdot
.61595 .49261 Mdot
.42664 .3742 Mdot
.54589 .36036 Mdot
.40328 .5441 Mdot
.53949 .68704 Mdot
.2843 .68813 Mdot
.37158 .6034 Mdot
.61474 .33312 Mdot
.56038 .6546 Mdot
.4359 .3728 Mdot
.41151 .34587 Mdot
.37524 .59441 Mdot
.47093 .79861 Mdot
.61977 .51473 Mdot
.58449 .66548 Mdot
.60465 .63006 Mdot
.34523 .60643 Mdot
.3555 .53634 Mdot
.44121 .51605 Mdot
.65096 .53541 Mdot
.63338 .71044 Mdot
.40413 .37212 Mdot
.56081 .66989 Mdot
.39701 .58173 Mdot
.42007 .36043 Mdot
.61439 .62962 Mdot
.76329 .40125 Mdot
.59751 .334 Mdot
.42503 .3306 Mdot
.44848 .35743 Mdot
.41131 .36498 Mdot
.41804 .1959 Mdot
.5494 .63404 Mdot
.49713 .68887 Mdot
.38986 .60061 Mdot
.2808 .49837 Mdot
.39151 .61817 Mdot
.66718 .49467 Mdot
.59004 .36523 Mdot
.36271 .58142 Mdot
.42108 .52869 Mdot
.28059 .56795 Mdot
.30854 .60317 Mdot
.5937 .63238 Mdot
.54957 .654 Mdot
.29966 .58213 Mdot
.58964 .3607 Mdot
.87655 .52107 Mdot
.3053 .21554 Mdot
.31946 .54422 Mdot
.5125 .43402 Mdot
.5409 .69005 Mdot
.61484 .53536 Mdot
.52387 .47153 Mdot
.62595 .47823 Mdot
.56208 .66576 Mdot
.40478 .54297 Mdot
.68245 .58058 Mdot
.46152 .35764 Mdot
.36112 .59658 Mdot
.63649 .49577 Mdot
.36209 .59654 Mdot
.66469 .49815 Mdot
.49909 .64515 Mdot
.70818 .67515 Mdot
.41609 .58791 Mdot
.33771 .59211 Mdot
.2858 .56438 Mdot
.34675 .55846 Mdot
.72304 .36289 Mdot
.55837 .69574 Mdot
.81992 .56502 Mdot
.42279 .52284 Mdot
.49954 .78149 Mdot
.38195 .60622 Mdot
.67999 .33275 Mdot
.34971 .54025 Mdot
.52525 .50223 Mdot
.39987 .60241 Mdot
.37155 .52799 Mdot
.61432 .51579 Mdot
.6235 .53698 Mdot
.53156 .66742 Mdot
.75283 .38146 Mdot
.25793 .29611 Mdot
.35528 .54478 Mdot
.53904 .37237 Mdot
.59627 .57187 Mdot
.44471 .36288 Mdot
.5654 .6665 Mdot
.81602 .65326 Mdot
.60922 .49947 Mdot
.55874 .31417 Mdot
.69213 .33177 Mdot
.56448 .38331 Mdot
.58237 .50986 Mdot
.35018 .64917 Mdot
.44002 .37379 Mdot
.38645 .60619 Mdot
.3389 .76406 Mdot
.73103 .59671 Mdot
.33782 .52124 Mdot
.63756 .47257 Mdot
.45716 .63421 Mdot
.28404 .72065 Mdot
.44235 .32574 Mdot
.45484 .3458 Mdot
.61313 .51079 Mdot
.59738 .37415 Mdot
.43583 .61369 Mdot
.42005 .34324 Mdot
.60853 .34287 Mdot
.74518 .38081 Mdot
.52367 .56609 Mdot
.5698 .67612 Mdot
.63314 .72841 Mdot
.6762 .63341 Mdot
.61447 .49384 Mdot
.6352 .31267 Mdot
.56093 .72227 Mdot
.59971 .65603 Mdot
.76237 .3827 Mdot
.57332 .31933 Mdot
.52925 .64228 Mdot
.3365 .5305 Mdot
.31191 .5264 Mdot
.37378 .54582 Mdot
.4325 .34073 Mdot
.34419 .55802 Mdot
.58878 .31867 Mdot
.64308 .5051 Mdot
.55651 .3471 Mdot
.62132 .52069 Mdot
.71038 .55636 Mdot
.38408 .57732 Mdot
.36876 .5313 Mdot
.45339 .40976 Mdot
.5449 .64584 Mdot
.50901 .8193 Mdot
.53738 .37188 Mdot
.57339 .35017 Mdot
.3996 .52497 Mdot
.53039 .68081 Mdot
.39032 .34855 Mdot
.46952 .39951 Mdot
.34317 .57543 Mdot
.55743 .69607 Mdot
.41382 .55076 Mdot
.35899 .2838 Mdot
.7209 .65975 Mdot
.58055 .67331 Mdot
.8366 .55757 Mdot
.40041 .55262 Mdot
.47368 .5676 Mdot
.36417 .49859 Mdot
.26688 .41997 Mdot
.34151 .60456 Mdot
.56075 .70912 Mdot
.372 .55123 Mdot
.55119 .69961 Mdot
.6035 .36348 Mdot
.60552 .52566 Mdot
.54654 .68329 Mdot
.34036 .57019 Mdot
.41585 .17823 Mdot
.63366 .49107 Mdot
.3777 .53216 Mdot
.65608 .51544 Mdot
.58418 .70784 Mdot
.54523 .65035 Mdot
.55825 .20199 Mdot
.63193 .55668 Mdot
.6272 .49036 Mdot
.41921 .55477 Mdot
.65859 .65466 Mdot
.40602 .53656 Mdot
.29633 .44071 Mdot
.40831 .5184 Mdot
.33529 .59702 Mdot
.71167 .24391 Mdot
.62127 .54549 Mdot
.72004 .74758 Mdot
.40415 .24614 Mdot
.43582 .1857 Mdot
.57991 .73157 Mdot
.44199 .3256 Mdot
.35802 .23915 Mdot
.7457 .41139 Mdot
.5925 .32618 Mdot
.36302 .58264 Mdot
.5444 .73213 Mdot
.63166 .48277 Mdot
.4391 .36314 Mdot
.41728 .58637 Mdot
.61126 .32681 Mdot
.60656 .23477 Mdot
.60455 .4966 Mdot
.57103 .67122 Mdot
.5422 .64973 Mdot
.80416 .64734 Mdot
.39629 .58551 Mdot
.37235 .53364 Mdot
.64718 .49096 Mdot
.36536 .63235 Mdot
.42016 .37765 Mdot
.4789 .30228 Mdot
.62579 .49175 Mdot
.58208 .46566 Mdot
.54282 .66344 Mdot
.3514 .56999 Mdot
.44465 .44567 Mdot
.63053 .40448 Mdot
.35093 .67468 Mdot
.4265 .34529 Mdot
.31736 .43498 Mdot
.56145 .70926 Mdot
.63658 .50317 Mdot
.38157 .30406 Mdot
.38608 .5054 Mdot
.3535 .56488 Mdot
.32075 .43613 Mdot
.49304 .41931 Mdot
.4004 .33046 Mdot
.36872 .61546 Mdot
.48446 .42059 Mdot
.39666 .52191 Mdot
.34821 .51742 Mdot
.32346 .58687 Mdot
.36178 .52682 Mdot
.55251 .69571 Mdot
.27914 .57613 Mdot
.59064 .33377 Mdot
.43578 .7106 Mdot
.4844 .47038 Mdot
.4048 .57659 Mdot
.40356 .53972 Mdot
.37028 .66773 Mdot
.57932 .50131 Mdot
.55887 .69257 Mdot
.53541 .63181 Mdot
.60781 .51211 Mdot
.30586 .53096 Mdot
.58858 .3852 Mdot
.26817 .56804 Mdot
.55645 .34344 Mdot
.55771 .6971 Mdot
.57244 .35635 Mdot
.60925 .51867 Mdot
.56876 .36548 Mdot
.54765 .38095 Mdot
.65484 .48447 Mdot
.53909 .66617 Mdot
.34364 .57179 Mdot
.60621 .50486 Mdot
.33721 .44509 Mdot
.43121 .34039 Mdot
.55807 .20159 Mdot
.43274 .52237 Mdot
.40922 .45934 Mdot
.266 .36756 Mdot
.55875 .35011 Mdot
.73348 .65897 Mdot
.54194 .68651 Mdot
.43944 .38306 Mdot
.55057 .69631 Mdot
.53329 .82469 Mdot
.43242 .37032 Mdot
.54639 .19365 Mdot
.47026 .32283 Mdot
.55846 .23718 Mdot
.3795 .61594 Mdot
.5097 .64453 Mdot
.55404 .36368 Mdot
.62861 .48343 Mdot
.51277 .3646 Mdot
.37465 .52161 Mdot
.76932 .55658 Mdot
.58416 .64521 Mdot
.73847 .39207 Mdot
.63406 .50953 Mdot
.63067 .47163 Mdot
.39187 .58751 Mdot
.58968 .26227 Mdot
.38822 .51325 Mdot
.39461 .31273 Mdot
.32057 .41797 Mdot
.26706 .57153 Mdot
.42202 .54785 Mdot
.55178 .34453 Mdot
.41477 .55202 Mdot
.46332 .62132 Mdot
.36142 .79147 Mdot
.41687 .49785 Mdot
.79729 .52092 Mdot
.48842 .36631 Mdot
.54897 .66357 Mdot
.31726 .54213 Mdot
.74545 .3965 Mdot
.40243 .55454 Mdot
.19397 .67072 Mdot
.42873 .35701 Mdot
.59132 .29021 Mdot
.36148 .60916 Mdot
.39348 .57602 Mdot
.38712 .7865 Mdot
.52345 .7169 Mdot
.77361 .38077 Mdot
.35672 .56227 Mdot
.34123 .39587 Mdot
.64711 .53468 Mdot
.39885 .51057 Mdot
.36852 .54692 Mdot
.24115 .62212 Mdot
.65837 .52445 Mdot
.56086 .35442 Mdot
.74137 .41024 Mdot
.54479 .36072 Mdot
.41518 .32776 Mdot
.53656 .47677 Mdot
.25511 .52849 Mdot
.71944 .65729 Mdot
.41167 .33863 Mdot
.35292 .5977 Mdot
.4483 .49368 Mdot
.39505 .55968 Mdot
.45485 .34244 Mdot
.66444 .51513 Mdot
.55049 .691 Mdot
.64241 .66708 Mdot
.75526 .3931 Mdot
.33206 .55155 Mdot
.45152 .33202 Mdot
.55392 .67916 Mdot
.65084 .33512 Mdot
.55368 .66788 Mdot
.62074 .50299 Mdot
.66757 .48976 Mdot
.42642 .3673 Mdot
.55252 .69751 Mdot
.53734 .35502 Mdot
.40865 .2453 Mdot
.41 .52281 Mdot
.68431 .51022 Mdot
.52677 .66259 Mdot
.59245 .71351 Mdot
.56874 .6398 Mdot
.38433 .58562 Mdot
.50293 .42993 Mdot
.35685 .5069 Mdot
.61164 .50615 Mdot
.60347 .33479 Mdot
.2495 .54753 Mdot
.39611 .79722 Mdot
.58161 .46073 Mdot
.35055 .61929 Mdot
.38458 .53016 Mdot
.37059 .54189 Mdot
.42862 .5732 Mdot
.39705 .28301 Mdot
.38336 .57336 Mdot
.61713 .51853 Mdot
.56327 .32884 Mdot
.39924 .58811 Mdot
.74333 .39672 Mdot
.4947 .44267 Mdot
.40505 .36209 Mdot
.51288 .48361 Mdot
.36195 .19988 Mdot
.5535 .68056 Mdot
.57445 .37442 Mdot
.58994 .32683 Mdot
.40868 .36381 Mdot
.62204 .48785 Mdot
.55032 .67149 Mdot
.27501 .39828 Mdot
.41612 .37115 Mdot
.36798 .55382 Mdot
.53863 .29983 Mdot
.83743 .51475 Mdot
.37266 .61123 Mdot
.36796 .57269 Mdot
.73696 .40766 Mdot
.59383 .37915 Mdot
.15376 .52488 Mdot
.49455 .40514 Mdot
.43183 .36695 Mdot
.45241 .35276 Mdot
.56757 .63848 Mdot
.32929 .53167 Mdot
.62541 .52101 Mdot
.46855 .41228 Mdot
.23197 .47878 Mdot
.53723 .4048 Mdot
.72293 .28477 Mdot
.37503 .59965 Mdot
.3873 .77862 Mdot
.41318 .53692 Mdot
.60422 .66971 Mdot
.59309 .66771 Mdot
.56261 .68841 Mdot
.61507 .5066 Mdot
.55055 .76768 Mdot
.61999 .52312 Mdot
.34281 .20012 Mdot
.54544 .70128 Mdot
.4702 .24798 Mdot
.57846 .35573 Mdot
.38797 .62441 Mdot
.43343 .37533 Mdot
.59429 .45946 Mdot
.32555 .59795 Mdot
.77014 .59905 Mdot
.57616 .36447 Mdot
.54321 .65585 Mdot
.39264 .64715 Mdot
.1997 .35505 Mdot
.53965 .45585 Mdot
.48419 .55344 Mdot
.49394 .81884 Mdot
.4345 .3714 Mdot
.36902 .67551 Mdot
.43293 .3797 Mdot
.64561 .49835 Mdot
.37151 .52191 Mdot
.35959 .5261 Mdot
.41942 .54074 Mdot
.38236 .57538 Mdot
.62812 .53399 Mdot
.43172 .55002 Mdot
.46926 .85076 Mdot
.74303 .40767 Mdot
.3635 .26507 Mdot
.4229 .33729 Mdot
.64615 .47558 Mdot
.55981 .33444 Mdot
.74894 .38102 Mdot
.25886 .50712 Mdot
.4026 .59982 Mdot
.36502 .5824 Mdot
.77039 .38563 Mdot
.32808 .59771 Mdot
.3603 .64287 Mdot
.58837 .33335 Mdot
.57199 .4713 Mdot
.43585 .32708 Mdot
.42358 .33449 Mdot
.65853 .49285 Mdot
.55115 .69704 Mdot
.42181 .34563 Mdot
.6054 .36623 Mdot
.43368 .54998 Mdot
.34013 .54435 Mdot
.52706 .66225 Mdot
.51204 .83209 Mdot
.44675 .3258 Mdot
.40635 .64238 Mdot
.55697 .7052 Mdot
.56841 .63555 Mdot
.35608 .56571 Mdot
.42861 .50463 Mdot
.57245 .71908 Mdot
.41124 .34332 Mdot
.64408 .47487 Mdot
.52142 .22932 Mdot
.6422 .49329 Mdot
.55012 .6751 Mdot
.426 .52124 Mdot
.54043 .66506 Mdot
.40226 .56065 Mdot
.80598 .29854 Mdot
.35415 .53224 Mdot
.68566 .74079 Mdot
.27295 .42495 Mdot
.58496 .32555 Mdot
.53858 .35755 Mdot
.743 .40278 Mdot
.55618 .70595 Mdot
.35408 .52478 Mdot
.45116 .36169 Mdot
.46374 .18709 Mdot
.5153 .68316 Mdot
.60647 .33076 Mdot
.58748 .38461 Mdot
.66083 .52451 Mdot
.37428 .60728 Mdot
.3495 .56488 Mdot
.56666 .36432 Mdot
.28862 .34165 Mdot
.58007 .70186 Mdot
.37335 .53412 Mdot
.38782 .53202 Mdot
.5843 .32852 Mdot
.40635 .24878 Mdot
.50278 .6519 Mdot
.36729 .52534 Mdot
.47862 .35191 Mdot
.66749 .49838 Mdot
.42845 .56901 Mdot
.4322 .55345 Mdot
.44774 .34799 Mdot
.32806 .27549 Mdot
.30453 .74713 Mdot
.65906 .48486 Mdot
.74852 .38335 Mdot
.33955 .57407 Mdot
.57986 .35417 Mdot
.33868 .56228 Mdot
.22413 .37398 Mdot
.7381 .40359 Mdot
.384 .56416 Mdot
.31941 .55427 Mdot
.57855 .65229 Mdot
.38705 .57044 Mdot
.26879 .63566 Mdot
.5439 .34579 Mdot
.38479 .56729 Mdot
.4872 .80569 Mdot
.65088 .53391 Mdot
.31772 .55073 Mdot
.44406 .33264 Mdot
.26245 .42246 Mdot
.6705 .6144 Mdot
.57411 .39257 Mdot
.41674 .34127 Mdot
.34253 .57147 Mdot
.5946 .37516 Mdot
.62562 .4826 Mdot
.76443 .57714 Mdot
.40722 .60213 Mdot
.63857 .49061 Mdot
.64165 .50591 Mdot
.42524 .36312 Mdot
.74677 .71916 Mdot
.3413 .62027 Mdot
.34565 .56063 Mdot
.22339 .58984 Mdot
.58772 .65207 Mdot
.34447 .56879 Mdot
.36258 .60309 Mdot
.63433 .52411 Mdot
.54387 .59912 Mdot
.47141 .64293 Mdot
.50925 .30251 Mdot
.66498 .49773 Mdot
.58358 .39767 Mdot
.59354 .37546 Mdot
.42306 .33792 Mdot
.55435 .65983 Mdot
.40339 .34738 Mdot
.59481 .34702 Mdot
.38541 .59945 Mdot
.64462 .5184 Mdot
.34022 .6944 Mdot
.6062 .53348 Mdot
.60726 .31833 Mdot
.60448 .69474 Mdot
.62826 .59977 Mdot
.28274 .75601 Mdot
.68572 .62199 Mdot
.59126 .50243 Mdot
.44524 .36208 Mdot
.50474 .34421 Mdot
.38607 .53163 Mdot
.41981 .67236 Mdot
.35205 .58731 Mdot
.48663 .81576 Mdot
.59696 .36036 Mdot
.76342 .38219 Mdot
.37058 .52177 Mdot
.32564 .42309 Mdot
.60966 .47869 Mdot
.65925 .52747 Mdot
.37519 .57453 Mdot
.61944 .50618 Mdot
.35155 .54641 Mdot
.56338 .32617 Mdot
.71026 .74501 Mdot
.38139 .53082 Mdot
.38573 .49414 Mdot
.60566 .55751 Mdot
.55566 .19971 Mdot
.53233 .35054 Mdot
.38588 .77978 Mdot
.17786 .39186 Mdot
.62067 .5083 Mdot
.34868 .50316 Mdot
.55904 .36546 Mdot
.73643 .40731 Mdot
.54095 .32872 Mdot
.35716 .59007 Mdot
.37077 .59326 Mdot
.40104 .5258 Mdot
.3931 .54113 Mdot
.41473 .67078 Mdot
.32358 .62339 Mdot
.39286 .76663 Mdot
.36595 .58076 Mdot
.62676 .69093 Mdot
.62075 .52666 Mdot
.59533 .63485 Mdot
.46688 .33929 Mdot
.37812 .59894 Mdot
.54531 .73563 Mdot
.65337 .48061 Mdot
.34026 .20278 Mdot
.66007 .52411 Mdot
.56615 .33993 Mdot
.62085 .54141 Mdot
.40382 .56613 Mdot
.57078 .66173 Mdot
.54837 .33629 Mdot
.74438 .52717 Mdot
.594 .32582 Mdot
.39902 .58343 Mdot
.40513 .26206 Mdot
.59136 .32836 Mdot
.4985 .45336 Mdot
.56649 .65854 Mdot
.3481 .39652 Mdot
.59673 .6769 Mdot
.38671 .56343 Mdot
.38776 .55901 Mdot
.73928 .38518 Mdot
.60119 .50595 Mdot
.57907 .71046 Mdot
.59113 .84847 Mdot
.40119 .34204 Mdot
.56974 .68607 Mdot
.42406 .60828 Mdot
.50206 .42408 Mdot
.58461 .67225 Mdot
.31022 .38601 Mdot
.62287 .48632 Mdot
.54103 .63609 Mdot
.4399 .58401 Mdot
.56618 .56852 Mdot
.45452 .3708 Mdot
.60596 .32092 Mdot
.55402 .52849 Mdot
.55251 .36343 Mdot
.65718 .48001 Mdot
.62224 .33059 Mdot
.64364 .53526 Mdot
.60508 .76264 Mdot
.50865 .70265 Mdot
.59896 .52687 Mdot
.66424 .48203 Mdot
.58858 .34791 Mdot
.41553 .59169 Mdot
.49156 .4937 Mdot
.35611 .61467 Mdot
.39495 .61343 Mdot
.64394 .53731 Mdot
.58142 .70698 Mdot
.54512 .70541 Mdot
.5229 .62789 Mdot
.54827 .64521 Mdot
.55707 .33556 Mdot
.72247 .67125 Mdot
.54047 .80936 Mdot
.65789 .49811 Mdot
.67793 .49508 Mdot
.40555 .53738 Mdot
.58322 .35251 Mdot
.60191 .36274 Mdot
.63439 .51961 Mdot
.37942 .69074 Mdot
.37259 .49826 Mdot
.60216 .68409 Mdot
.54334 .69914 Mdot
.58361 .67825 Mdot
.55778 .63906 Mdot
.49451 .7137 Mdot
.62755 .48342 Mdot
.55044 .70376 Mdot
.37854 .56927 Mdot
.36659 .5935 Mdot
.75721 .38644 Mdot
.43344 .331 Mdot
.43916 .56658 Mdot
.41021 .49496 Mdot
.35527 .56769 Mdot
.59673 .33274 Mdot
.40317 .47715 Mdot
.74033 .39355 Mdot
.61965 .34707 Mdot
.57656 .38983 Mdot
.76684 .38756 Mdot
.56061 .60945 Mdot
.18603 .36516 Mdot
.41333 .54673 Mdot
.45614 .48821 Mdot
.57911 .34941 Mdot
.74496 .67687 Mdot
.63236 .67501 Mdot
.42359 .55075 Mdot
.53729 .56275 Mdot
.55334 .33002 Mdot
.58874 .65044 Mdot
.34769 .57864 Mdot
.76815 .4009 Mdot
.40614 .3653 Mdot
.42443 .60927 Mdot
.73985 .41054 Mdot
.55957 .6992 Mdot
.37975 .35664 Mdot
.55206 .63519 Mdot
.55544 .32587 Mdot
.31816 .55773 Mdot
.38017 .13639 Mdot
.56194 .37398 Mdot
.46176 .19621 Mdot
.50074 .6764 Mdot
.37893 .52841 Mdot
.55774 .37146 Mdot
.59447 .65691 Mdot
.66906 .4991 Mdot
.47486 .42415 Mdot
.53937 .6814 Mdot
.75326 .38057 Mdot
.76211 .3897 Mdot
.58829 .33156 Mdot
.55533 .65126 Mdot
.41049 .51315 Mdot
.5877 .66328 Mdot
.62279 .54299 Mdot
.42259 .57079 Mdot
.24588 .30368 Mdot
.30541 .54063 Mdot
.56665 .70843 Mdot
.61603 .33267 Mdot
.45548 .36615 Mdot
.41042 .59213 Mdot
.41855 .22038 Mdot
.36829 .60639 Mdot
.65808 .5191 Mdot
.79623 .60943 Mdot
.32331 .68211 Mdot
.39233 .59967 Mdot
.40416 .53721 Mdot
.65231 .48292 Mdot
.40542 .59752 Mdot
.37194 .61003 Mdot
.63399 .56494 Mdot
.5781 .65402 Mdot
.37628 .54586 Mdot
.60845 .34945 Mdot
.3877 .79988 Mdot
.33921 .57644 Mdot
.79565 .49938 Mdot
.34248 .40779 Mdot
.78292 .6378 Mdot
.34141 .55511 Mdot
.32945 .45369 Mdot
.38621 .55021 Mdot
.38396 .5922 Mdot
.4178 .54814 Mdot
.36565 .76117 Mdot
.58996 .35024 Mdot
.59968 .3218 Mdot
.45455 .37159 Mdot
.34007 .406 Mdot
.4411 .33863 Mdot
.66235 .49585 Mdot
.66658 .25213 Mdot
.74066 .4059 Mdot
.55062 .69748 Mdot
.37483 .51359 Mdot
.55142 .32689 Mdot
.35224 .57473 Mdot
.40491 .56173 Mdot
.55882 .32608 Mdot
.57476 .38056 Mdot
.61042 .29793 Mdot
.42936 .37891 Mdot
.55419 .68797 Mdot
.42481 .53707 Mdot
.41251 .36163 Mdot
.40628 .51062 Mdot
.49411 .41171 Mdot
.55636 .68996 Mdot
.58606 .66023 Mdot
.58257 .71213 Mdot
.38457 .60007 Mdot
.4061 .57296 Mdot
.62155 .52449 Mdot
.52553 .66796 Mdot
.65269 .4887 Mdot
.55082 .35688 Mdot
.53937 .34405 Mdot
.35773 .59049 Mdot
.41179 .64295 Mdot
.45126 .35619 Mdot
.56307 .34394 Mdot
.77183 .38573 Mdot
.44421 .37907 Mdot
.39487 .59096 Mdot
.55194 .34695 Mdot
.4242 .33336 Mdot
.39986 .70917 Mdot
.16882 .42259 Mdot
.45889 .35781 Mdot
.37541 .57217 Mdot
.3966 .79336 Mdot
.37076 .32234 Mdot
.39832 .3501 Mdot
.65667 .50501 Mdot
.36817 .60473 Mdot
.21762 .44381 Mdot
.41328 .33447 Mdot
.49049 .82444 Mdot
.58122 .32523 Mdot
.53124 .59721 Mdot
.44461 .57068 Mdot
.4344 .68036 Mdot
.40184 .34733 Mdot
.55543 .67075 Mdot
.52326 .68266 Mdot
.37166 .56195 Mdot
.47316 .3503 Mdot
.64916 .53959 Mdot
.57831 .32292 Mdot
.53861 .36993 Mdot
.56101 .64993 Mdot
.67533 .67016 Mdot
.61259 .3426 Mdot
.43388 .6245 Mdot
.58511 .27191 Mdot
.33716 .49513 Mdot
.59047 .76667 Mdot
.73575 .52993 Mdot
.34087 .53739 Mdot
.45753 .35597 Mdot
.63052 .47651 Mdot
.61793 .5172 Mdot
.62193 .49818 Mdot
.54248 .36552 Mdot
.52168 .47398 Mdot
.57783 .36656 Mdot
.75971 .56735 Mdot
.41983 .35986 Mdot
.34744 .37235 Mdot
.35456 .52609 Mdot
.38331 .53069 Mdot
.40779 .50829 Mdot
.38872 .51529 Mdot
.3851 .54748 Mdot
.61987 .49096 Mdot
.55214 .37724 Mdot
.52733 .26316 Mdot
.5787 .68858 Mdot
.66048 .32109 Mdot
.57818 .35599 Mdot
.73783 .40748 Mdot
.43802 .35713 Mdot
.3192 .46828 Mdot
.61705 .36393 Mdot
.57228 .35525 Mdot
.4358 .56479 Mdot
.59324 .68843 Mdot
.32787 .63892 Mdot
.3898 .55281 Mdot
.56138 .34607 Mdot
.52571 .38611 Mdot
.32881 .66017 Mdot
.44672 .51553 Mdot
.38996 .36503 Mdot
.50514 .42779 Mdot
.40766 .37656 Mdot
.43178 .51313 Mdot
.7486 .6727 Mdot
.59418 .34609 Mdot
.57212 .33491 Mdot
.45135 .33313 Mdot
.4721 .57173 Mdot
.55662 .65427 Mdot
.76397 .38196 Mdot
.65269 .52103 Mdot
.39317 .55987 Mdot
.54242 .36009 Mdot
.48334 .58138 Mdot
.56188 .268 Mdot
.62681 .49301 Mdot
.61898 .34893 Mdot
.38064 .60541 Mdot
.37338 .57311 Mdot
.43775 .37001 Mdot
.46386 .48837 Mdot
.40764 .6196 Mdot
.43464 .18594 Mdot
.70712 .67343 Mdot
.67438 .70879 Mdot
.3533 .56471 Mdot
.56371 .64854 Mdot
.76665 .40029 Mdot
.42031 .37172 Mdot
.42581 .52823 Mdot
.16965 .40993 Mdot
.54449 .71231 Mdot
.63863 .49783 Mdot
.7685 .3962 Mdot
.52001 .47261 Mdot
.36571 .60554 Mdot
.35169 .58665 Mdot
.38341 .58076 Mdot
.15098 .43964 Mdot
.60897 .33403 Mdot
.56661 .64034 Mdot
.42903 .34447 Mdot
.55888 .64101 Mdot
.59768 .3232 Mdot
.64337 .65473 Mdot
.4017 .58938 Mdot
.6034 .68584 Mdot
.55731 .66845 Mdot
.66194 .5231 Mdot
.66923 .51502 Mdot
.61459 .29847 Mdot
.35515 .53182 Mdot
.76645 .40457 Mdot
.59528 .67188 Mdot
.57403 .38402 Mdot
.43259 .37079 Mdot
.60765 .5074 Mdot
.36711 .58132 Mdot
.59351 .33906 Mdot
.33189 .5359 Mdot
.58846 .67597 Mdot
.57312 .35491 Mdot
.76279 .41041 Mdot
.45141 .34586 Mdot
.36909 .58878 Mdot
.38865 .34188 Mdot
.7689 .38675 Mdot
.38975 .53057 Mdot
.26141 .55355 Mdot
.45851 .3214 Mdot
.74881 .52223 Mdot
.57593 .37105 Mdot
.74821 .39056 Mdot
.5886 .65976 Mdot
.58952 .59407 Mdot
.56952 .33313 Mdot
.2832 .50989 Mdot
.487 .51058 Mdot
.42654 .54227 Mdot
.57618 .67277 Mdot
.49748 .34479 Mdot
.38424 .20472 Mdot
.36331 .31112 Mdot
.37467 .537 Mdot
.55618 .36999 Mdot
.41756 .33734 Mdot
.6594 .50031 Mdot
.79722 .50069 Mdot
.52592 .73463 Mdot
.62344 .33444 Mdot
.41351 .54382 Mdot
.59524 .67312 Mdot
.63499 .5181 Mdot
.69274 .57045 Mdot
.61054 .3592 Mdot
.5935 .36464 Mdot
.39619 .59377 Mdot
.41859 .34969 Mdot
.32283 .31364 Mdot
.59725 .31997 Mdot
.54598 .36475 Mdot
.65777 .30937 Mdot
.45594 .33541 Mdot
.37649 .56329 Mdot
.52214 .62838 Mdot
.42309 .5878 Mdot
.4661 .19236 Mdot
.74168 .39425 Mdot
.5789 .6904 Mdot
.3647 .59657 Mdot
.54064 .28957 Mdot
.56067 .33761 Mdot
.51349 .43582 Mdot
.61286 .31881 Mdot
.61904 .49012 Mdot
.54135 .35792 Mdot
.34826 .57528 Mdot
.61004 .47791 Mdot
.45107 .35368 Mdot
.36552 .5257 Mdot
.40713 .5727 Mdot
.59777 .65912 Mdot
.6472 .499 Mdot
.2785 .70147 Mdot
.66659 .48059 Mdot
.64437 .47764 Mdot
.52068 .65055 Mdot
.36988 .55795 Mdot
.56793 .3436 Mdot
.59718 .31572 Mdot
.42239 .52505 Mdot
.73017 .68857 Mdot
.56016 .65235 Mdot
.61729 .29834 Mdot
.15581 .51841 Mdot
.44379 .60425 Mdot
.77257 .40033 Mdot
.44198 .47727 Mdot
.66688 .51724 Mdot
.37091 .57807 Mdot
.56682 .70711 Mdot
.55273 .37319 Mdot
.6121 .34342 Mdot
.42197 .51823 Mdot
.64143 .51149 Mdot
.40574 .35042 Mdot
.59304 .36787 Mdot
.57873 .26525 Mdot
.38758 .57653 Mdot
.77186 .55177 Mdot
.5838 .3733 Mdot
.49672 .17 Mdot
.53752 .26898 Mdot
.57928 .67628 Mdot
.40691 .56173 Mdot
.53573 .65963 Mdot
.43506 .34374 Mdot
.56121 .39488 Mdot
.64338 .5074 Mdot
.4506 .51514 Mdot
.34443 .79109 Mdot
.58774 .35367 Mdot
.55347 .69563 Mdot
.39116 .60044 Mdot
.456 .5801 Mdot
.34553 .55393 Mdot
.54949 .60047 Mdot
.43582 .31295 Mdot
.64537 .53755 Mdot
.65849 .51617 Mdot
.39853 .5294 Mdot
.41797 .37518 Mdot
.57312 .31724 Mdot
.57577 .32426 Mdot
.885 .48846 Mdot
.76249 .41084 Mdot
.29232 .4335 Mdot
.3716 .59154 Mdot
.57415 .38528 Mdot
.38787 .79321 Mdot
.64718 .49073 Mdot
.39258 .51414 Mdot
.56239 .38673 Mdot
.62777 .41207 Mdot
.49295 .4143 Mdot
.38131 .55409 Mdot
.40162 .63523 Mdot
.65468 .51904 Mdot
.47317 .40175 Mdot
.57466 .36611 Mdot
.40234 .51607 Mdot
.66333 .47765 Mdot
.64353 .28071 Mdot
.43667 .83795 Mdot
.55474 .68801 Mdot
.60745 .31719 Mdot
.6208 .48971 Mdot
.40422 .62393 Mdot
.42197 .33738 Mdot
.54593 .35183 Mdot
.59798 .32989 Mdot
.41932 .56784 Mdot
.42837 .58892 Mdot
.44564 .60114 Mdot
.56728 .69499 Mdot
.63338 .53033 Mdot
.37504 .51899 Mdot
.67982 .67151 Mdot
.40053 .5242 Mdot
.63125 .52827 Mdot
.53852 .09921 Mdot
.41499 .59769 Mdot
.34666 .55245 Mdot
.33805 .30896 Mdot
.53677 .67668 Mdot
.55626 .64218 Mdot
.71253 .67432 Mdot
.37136 .59129 Mdot
.56929 .2458 Mdot
.55152 .68607 Mdot
.56448 .6535 Mdot
.45798 .25707 Mdot
.42458 .56574 Mdot
.48762 .38811 Mdot
.62755 .52227 Mdot
.60856 .49719 Mdot
.58287 .65859 Mdot
.40321 .62275 Mdot
.63589 .47974 Mdot
.44964 .66142 Mdot
.58017 .35875 Mdot
.75069 .67058 Mdot
.58985 .68726 Mdot
.45609 .46772 Mdot
.63932 .48872 Mdot
.34764 .19517 Mdot
.54873 .55489 Mdot
.40817 .53068 Mdot
.374 .58585 Mdot
.4484 .34541 Mdot
.3198 .59578 Mdot
.74566 .38435 Mdot
.61895 .50504 Mdot
.30007 .3052 Mdot
.56364 .68792 Mdot
.35271 .53669 Mdot
.3043 .47822 Mdot
.6959 .58122 Mdot
.79772 .52879 Mdot
.54965 .66402 Mdot
.57264 .676 Mdot
.58803 .36214 Mdot
.60034 .34763 Mdot
.37591 .55481 Mdot
.61462 .51154 Mdot
.52515 .65516 Mdot
.64645 .52675 Mdot
.5953 .34567 Mdot
.5717 .35059 Mdot
.73754 .4022 Mdot
.32888 .57367 Mdot
.56283 .32398 Mdot
.63088 .26678 Mdot
.67162 .67527 Mdot
.59323 .64955 Mdot
.26625 .72908 Mdot
.69385 .56723 Mdot
.26892 .37641 Mdot
.41526 .37934 Mdot
.77679 .37709 Mdot
.61502 .53248 Mdot
.40209 .53502 Mdot
.35938 .5815 Mdot
.75799 .39761 Mdot
.60072 .5172 Mdot
.44192 .35834 Mdot
.60043 .50923 Mdot
.417 .35913 Mdot
.53774 .33852 Mdot
.33927 .57543 Mdot
.35544 .59798 Mdot
.61954 .49272 Mdot
.5624 .35697 Mdot
.57044 .32248 Mdot
.42456 .38135 Mdot
.35645 .44746 Mdot
.59021 .33275 Mdot
.59023 .68457 Mdot
.50952 .76266 Mdot
.76205 .39121 Mdot
.34649 .57566 Mdot
.27581 .50142 Mdot
.37502 .68028 Mdot
.42037 .5326 Mdot
.76937 .39378 Mdot
.87267 .53583 Mdot
.35376 .52898 Mdot
.84345 .58927 Mdot
.75 .38816 Mdot
.53563 .67509 Mdot
.56535 .37284 Mdot
.74474 .38391 Mdot
.43328 .60354 Mdot
.39555 .36218 Mdot
.43746 .53676 Mdot
.53898 .67797 Mdot
.59262 .70751 Mdot
.65932 .74447 Mdot
.46722 .19317 Mdot
.44011 .37647 Mdot
.43309 .36367 Mdot
.57172 .33132 Mdot
.69218 .23861 Mdot
.44019 .58028 Mdot
.43574 .36507 Mdot
.29077 .32317 Mdot
.40727 .54184 Mdot
.29445 .44701 Mdot
.53632 .55851 Mdot
.56373 .64917 Mdot
.57747 .61705 Mdot
.56489 .33382 Mdot
.55328 .6949 Mdot
.65929 .69547 Mdot
.41009 .5091 Mdot
.55904 .69003 Mdot
.63454 .52715 Mdot
.70051 .43836 Mdot
.54024 .6561 Mdot
.46083 .42119 Mdot
.62518 .51994 Mdot
.44867 .31317 Mdot
.31813 .33706 Mdot
.19714 .69286 Mdot
.61769 .50572 Mdot
.55593 .35777 Mdot
.55597 .32603 Mdot
.57597 .32577 Mdot
.53912 .68295 Mdot
.60308 .36499 Mdot
.57264 .69742 Mdot
.42738 .23166 Mdot
.3146 .46641 Mdot
.42469 .36725 Mdot
.64177 .55436 Mdot
.5656 .67041 Mdot
.74174 .61966 Mdot
.2877 .7564 Mdot
.37635 .57503 Mdot
.6649 .4791 Mdot
.45137 .3339 Mdot
.6251 .18353 Mdot
.44741 .34624 Mdot
.56004 .36643 Mdot
.75597 .66469 Mdot
.35363 .54249 Mdot
.26341 .62016 Mdot
.45359 .35164 Mdot
.54509 .66861 Mdot
.38758 .53013 Mdot
.60561 .30811 Mdot
.42331 .33911 Mdot
.40565 .36088 Mdot
.38349 .54165 Mdot
.54708 .65165 Mdot
.5688 .34791 Mdot
.61265 .52833 Mdot
.43762 .31846 Mdot
.38327 .63091 Mdot
.43032 .56844 Mdot
.36204 .50754 Mdot
.52804 .45511 Mdot
.23758 .39309 Mdot
.62136 .50976 Mdot
.36903 .37811 Mdot
.60017 .34129 Mdot
.44352 .30247 Mdot
.7128 .63196 Mdot
.62103 .556 Mdot
.74257 .39277 Mdot
.73965 .39898 Mdot
.38216 .55055 Mdot
.24374 .3831 Mdot
.81862 .55247 Mdot
.59323 .54713 Mdot
.76419 .39413 Mdot
.57497 .32283 Mdot
.5262 .68931 Mdot
.64128 .74928 Mdot
.41358 .60506 Mdot
.65993 .52929 Mdot
.59387 .33498 Mdot
.2211 .37919 Mdot
.42222 .35636 Mdot
.74293 .66135 Mdot
.40102 .58617 Mdot
.3687 .53199 Mdot
.62994 .51076 Mdot
.62078 .52325 Mdot
.78605 .51738 Mdot
.68144 .71227 Mdot
.56322 .41609 Mdot
.67952 .55218 Mdot
.20291 .41158 Mdot
.58941 .63029 Mdot
.57189 .70775 Mdot
.74567 .41196 Mdot
.62382 .47474 Mdot
.34873 .58387 Mdot
.53531 .68778 Mdot
.79842 .53139 Mdot
.54375 .7213 Mdot
.30698 .43636 Mdot
.57522 .25297 Mdot
.39984 .5705 Mdot
.59407 .68086 Mdot
.55396 .69339 Mdot
.5436 .63982 Mdot
.76745 .38927 Mdot
.35543 .56175 Mdot
.41328 .5933 Mdot
.37791 .52209 Mdot
.35205 .63345 Mdot
.38772 .57304 Mdot
.70219 .63847 Mdot
.58423 .46086 Mdot
.31124 .29108 Mdot
.41801 .5324 Mdot
.61146 .49218 Mdot
.36608 .51316 Mdot
.41453 .37294 Mdot
.41342 .54249 Mdot
.29336 .44006 Mdot
.62982 .49829 Mdot
.47083 .56707 Mdot
.67288 .55935 Mdot
.40246 .58559 Mdot
.41347 .33731 Mdot
.25395 .37635 Mdot
.27622 .70861 Mdot
.65608 .31414 Mdot
.5904 .68188 Mdot
.61576 .36277 Mdot
.62536 .54441 Mdot
.56989 .34206 Mdot
.40864 .52592 Mdot
.76161 .40904 Mdot
.71643 .4927 Mdot
.46178 .4696 Mdot
.35663 .59494 Mdot
.3495 .49503 Mdot
.579 .6607 Mdot
.5528 .35035 Mdot
.61541 .69508 Mdot
.38289 .58814 Mdot
.42786 .34275 Mdot
.41697 .3473 Mdot
.68552 .69609 Mdot
.24882 .31991 Mdot
.59542 .60743 Mdot
.62769 .51112 Mdot
.61389 .3331 Mdot
.40338 .34447 Mdot
.51012 .70964 Mdot
.65461 .53679 Mdot
.66624 .51844 Mdot
.64829 .50661 Mdot
.39668 .56356 Mdot
.74263 .38892 Mdot
.26796 .32902 Mdot
.75067 .38107 Mdot
.40476 .58239 Mdot
.60408 .33258 Mdot
.74099 .38613 Mdot
.4446 .33885 Mdot
.6605 .49586 Mdot
.59649 .35059 Mdot
.38829 .56412 Mdot
.55526 .68222 Mdot
.38213 .44117 Mdot
.24897 .45242 Mdot
.39111 .24409 Mdot
.38532 .24781 Mdot
.56512 .71344 Mdot
.31411 .23676 Mdot
.68389 .51167 Mdot
.38048 .68979 Mdot
.41058 .3954 Mdot
.41915 .52044 Mdot
.66042 .7769 Mdot
.57234 .3669 Mdot
.55342 .33411 Mdot
.38123 .55835 Mdot
.57057 .38146 Mdot
.3495 .54156 Mdot
.59726 .35728 Mdot
.64194 .30304 Mdot
.40195 .61431 Mdot
.5556 .33353 Mdot
.44422 .53702 Mdot
.41231 .58946 Mdot
.57297 .65201 Mdot
.54683 .35915 Mdot
.40217 .52357 Mdot
.69282 .22654 Mdot
.61232 .51622 Mdot
.76622 .38851 Mdot
.57369 .43711 Mdot
.62707 .48504 Mdot
.57351 .68549 Mdot
.37917 .61788 Mdot
.44527 .36633 Mdot
.55623 .67346 Mdot
.61313 .29749 Mdot
.45465 .34911 Mdot
.72249 .66924 Mdot
.59003 .6757 Mdot
.75974 .3916 Mdot
.45197 .35643 Mdot
.34548 .50006 Mdot
.54359 .34042 Mdot
.22933 .49219 Mdot
.75522 .3815 Mdot
.34907 .5655 Mdot
.53045 .35331 Mdot
.60752 .4939 Mdot
.36893 .54461 Mdot
.55915 .3735 Mdot
.7686 .38911 Mdot
.39896 .55526 Mdot
.39439 .53612 Mdot
.62436 .74987 Mdot
.79321 .57381 Mdot
.43718 .36931 Mdot
.59604 .66512 Mdot
.3792 .56869 Mdot
.4256 .37927 Mdot
.70664 .29945 Mdot
.3473 .52195 Mdot
.53225 .66965 Mdot
.27223 .55613 Mdot
.60219 .34457 Mdot
.65339 .48884 Mdot
.60236 .31515 Mdot
.40654 .3677 Mdot
.63047 .83541 Mdot
.73693 .39553 Mdot
.44737 .53938 Mdot
.39824 .50945 Mdot
.52422 .37772 Mdot
.55808 .69432 Mdot
.54344 .41271 Mdot
.36954 .58857 Mdot
.30347 .54249 Mdot
.36232 .53128 Mdot
.53675 .26468 Mdot
.55925 .65332 Mdot
.34607 .56029 Mdot
.39412 .64847 Mdot
.34008 .58841 Mdot
.40887 .34202 Mdot
.33953 .35078 Mdot
.35457 .51516 Mdot
.31511 .17155 Mdot
.77125 .38741 Mdot
.56067 .32573 Mdot
.61878 .38612 Mdot
.77812 .331 Mdot
.59981 .76741 Mdot
.56966 .69683 Mdot
.31364 .50348 Mdot
.56911 .34515 Mdot
.43402 .82888 Mdot
.34681 .21114 Mdot
.41151 .5884 Mdot
.377 .6044 Mdot
.56001 .36642 Mdot
.57102 .38425 Mdot
.75109 .40995 Mdot
.41566 .53316 Mdot
.3947 .48147 Mdot
.61859 .34517 Mdot
.39335 .57511 Mdot
.27963 .60267 Mdot
.61911 .53193 Mdot
.57247 .64774 Mdot
.65939 .49938 Mdot
.65325 .53357 Mdot
.4725 .71843 Mdot
.70636 .67467 Mdot
.62832 .52837 Mdot
.66074 .47156 Mdot
.28401 .44971 Mdot
.29166 .50914 Mdot
.40375 .35065 Mdot
.3275 .25441 Mdot
.57813 .32863 Mdot
.35685 .56097 Mdot
.56326 .71107 Mdot
.44198 .68889 Mdot
.68494 .3979 Mdot
.77469 .6378 Mdot
.37874 .59424 Mdot
.56457 .33118 Mdot
.76544 .38513 Mdot
.40687 .612 Mdot
.41815 .29729 Mdot
.37132 .53382 Mdot
.55066 .3281 Mdot
.52879 .76438 Mdot
.26371 .58788 Mdot
.5193 .32291 Mdot
.54547 .63164 Mdot
.36585 .51991 Mdot
.58515 .69201 Mdot
.63466 .48817 Mdot
.4224 .3774 Mdot
.44147 .36571 Mdot
.38832 .53316 Mdot
.51157 .70883 Mdot
.53132 .56244 Mdot
.409 .59177 Mdot
.42147 .56727 Mdot
.74864 .38947 Mdot
.42188 .56806 Mdot
.40094 .51024 Mdot
.3844 .51731 Mdot
.33425 .55986 Mdot
.64227 .47712 Mdot
.25912 .57479 Mdot
.33557 .53434 Mdot
.45456 .55249 Mdot
.61337 .52453 Mdot
.34612 .48284 Mdot
.65594 .52871 Mdot
.2441 .30787 Mdot
.65394 .52685 Mdot
.43624 .36784 Mdot
.53169 .36124 Mdot
.30264 .53353 Mdot
.52527 .65131 Mdot
.66836 .49436 Mdot
.43195 .3509 Mdot
.62001 .50132 Mdot
.61039 .33763 Mdot
.22604 .6495 Mdot
.54471 .72182 Mdot
.48198 .40603 Mdot
.55765 .57826 Mdot
.77404 .54744 Mdot
.58566 .3599 Mdot
.566 .65158 Mdot
.26721 .62744 Mdot
.38865 .52012 Mdot
.45075 .34803 Mdot
.38166 .54759 Mdot
.64835 .47956 Mdot
.56941 .32839 Mdot
.3907 .25922 Mdot
.44265 .36674 Mdot
.4346 .84572 Mdot
.58407 .32296 Mdot
.40427 .60478 Mdot
.66454 .52454 Mdot
.26919 .73251 Mdot
.657 .52391 Mdot
.30311 .47467 Mdot
.60735 .69557 Mdot
.56057 .789 Mdot
.57213 .66983 Mdot
.80984 .51051 Mdot
.14924 .40439 Mdot
.39311 .21573 Mdot
.54745 .67847 Mdot
.56846 .28015 Mdot
.3965 .58486 Mdot
.3611 .51189 Mdot
.44241 .61174 Mdot
.58864 .64834 Mdot
.38181 .57159 Mdot
.75307 .38368 Mdot
.65224 .66029 Mdot
.45929 .29705 Mdot
.61937 .35783 Mdot
.34398 .56368 Mdot
.61626 .5268 Mdot
.59958 .50673 Mdot
.74401 .38356 Mdot
.63699 .54182 Mdot
.41981 .58354 Mdot
.56785 .66968 Mdot
.48162 .49266 Mdot
.43955 .34203 Mdot
.58392 .19165 Mdot
.45666 .32918 Mdot
.62693 .32809 Mdot
.31911 .55428 Mdot
.57174 .3515 Mdot
.75712 .74565 Mdot
.39843 .52544 Mdot
.54956 .68728 Mdot
.39564 .54326 Mdot
.37465 .51665 Mdot
.36258 .51094 Mdot
.61077 .35636 Mdot
.58352 .4045 Mdot
.39267 .57111 Mdot
.64423 .50631 Mdot
.35208 .26406 Mdot
.43139 .52116 Mdot
.58533 .2856 Mdot
.32883 .40608 Mdot
.75751 .57469 Mdot
.58858 .6438 Mdot
.55474 .3528 Mdot
.56724 .68419 Mdot
.52986 .63711 Mdot
.57351 .68567 Mdot
.27251 .31685 Mdot
.42334 .65038 Mdot
.86852 .5225 Mdot
.51871 .80174 Mdot
.42066 .69915 Mdot
.60022 .69492 Mdot
.72237 .33547 Mdot
.55833 .70502 Mdot
.57126 .69288 Mdot
.74814 .22709 Mdot
.55044 .70232 Mdot
.35763 .58897 Mdot
.4319 .57789 Mdot
.68335 .61423 Mdot
.28006 .46516 Mdot
.41585 .54154 Mdot
.37961 .56429 Mdot
.42936 .37759 Mdot
.45434 .62543 Mdot
.73362 .40914 Mdot
.7242 .68401 Mdot
.7091 .51334 Mdot
.38382 .54318 Mdot
.38234 .5655 Mdot
.36787 .62496 Mdot
.13139 .43002 Mdot
.45918 .68181 Mdot
.57881 .71511 Mdot
.34806 .49413 Mdot
.50992 .18209 Mdot
.39639 .60598 Mdot
.35435 .59827 Mdot
.40214 .56098 Mdot
.5682 .34424 Mdot
.5314 .69978 Mdot
.34385 .4977 Mdot
.74615 .57067 Mdot
.39738 .59005 Mdot
.65637 .54667 Mdot
.431 .31598 Mdot
.34955 .57739 Mdot
.5492 .64041 Mdot
.41243 .54932 Mdot
.59199 .686 Mdot
.57992 .65466 Mdot
.35185 .62332 Mdot
.25879 .32956 Mdot
.53444 .65582 Mdot
.40537 .57643 Mdot
.56058 .35326 Mdot
.39226 .20601 Mdot
.3494 .56945 Mdot
.41631 .368 Mdot
.37248 .58751 Mdot
.413 .33914 Mdot
.41498 .57838 Mdot
.75389 .3808 Mdot
.3123 .67346 Mdot
.57359 .33394 Mdot
.43845 .40384 Mdot
.58683 .38164 Mdot
.62839 .74278 Mdot
.53386 .6761 Mdot
.73961 .41449 Mdot
.75474 .69624 Mdot
.75056 .38938 Mdot
.38512 .44188 Mdot
.68055 .35886 Mdot
.6117 .5046 Mdot
.56738 .64186 Mdot
.38509 .40286 Mdot
.58282 .28186 Mdot
.61987 .3081 Mdot
.58164 .38925 Mdot
.65627 .80843 Mdot
.7219 .73688 Mdot
.39216 .56311 Mdot
.20835 .5294 Mdot
.39406 .76032 Mdot
.33748 .56238 Mdot
.36947 .61682 Mdot
.54613 .33114 Mdot
.35611 .52553 Mdot
.50909 .45861 Mdot
.58828 .34879 Mdot
.43275 .35652 Mdot
.57914 .69185 Mdot
.41294 .34111 Mdot
.55468 .31246 Mdot
.57542 .47659 Mdot
.59816 .34502 Mdot
.33821 .53869 Mdot
.39183 .54782 Mdot
.59182 .66956 Mdot
.55966 .74019 Mdot
.57453 .64996 Mdot
.45503 .34122 Mdot
.58674 .34026 Mdot
.4449 .67719 Mdot
.369 .57383 Mdot
.55844 .66658 Mdot
.61069 .45784 Mdot
.37317 .57399 Mdot
.62452 .49036 Mdot
.38912 .5986 Mdot
.54396 .67779 Mdot
.4217 .56898 Mdot
.56902 .67132 Mdot
.56812 .36379 Mdot
.39237 .60577 Mdot
.37952 .55857 Mdot
.31455 .75826 Mdot
.4427 .35669 Mdot
.53433 .67618 Mdot
.53824 .50808 Mdot
.41225 .59802 Mdot
.46951 .32088 Mdot
.34131 .55871 Mdot
.29474 .51725 Mdot
.44085 .52634 Mdot
.75492 .38475 Mdot
.34046 .51828 Mdot
.34869 .56776 Mdot
.25715 .60084 Mdot
.44571 .80009 Mdot
.6147 .70351 Mdot
.66019 .4861 Mdot
.55179 .64055 Mdot
.53934 .346 Mdot
.55022 .37383 Mdot
.59466 .36933 Mdot
.28628 .47298 Mdot
.38803 .62474 Mdot
.3529 .54483 Mdot
.67156 .49842 Mdot
.42992 .3635 Mdot
.5504 .66577 Mdot
.42495 .36315 Mdot
.71961 .68842 Mdot
.45339 .34025 Mdot
.74358 .38577 Mdot
.53786 .27 Mdot
.38819 .67261 Mdot
.43332 .37651 Mdot
.57333 .64897 Mdot
.56753 .25907 Mdot
.41496 .51863 Mdot
.64836 .32383 Mdot
.42638 .3432 Mdot
.60642 .8412 Mdot
.34071 .56665 Mdot
.48787 .42918 Mdot
.63499 .53602 Mdot
.42975 .33365 Mdot
.64617 .49568 Mdot
.40511 .53347 Mdot
.75229 .51912 Mdot
.55136 .69585 Mdot
.62243 .47291 Mdot
.34367 .51642 Mdot
.41755 .33847 Mdot
.59324 .33133 Mdot
.5803 .5737 Mdot
.61103 .49379 Mdot
.24896 .64072 Mdot
.36395 .31066 Mdot
.58716 .34238 Mdot
.83693 .52554 Mdot
.65267 .50841 Mdot
.33883 .54511 Mdot
.2949 .58025 Mdot
.42188 .54683 Mdot
.53999 .36315 Mdot
.55253 .34694 Mdot
.66088 .64478 Mdot
.39488 .5466 Mdot
.34086 .56402 Mdot
.55574 .72045 Mdot
.58423 .35426 Mdot
.57681 .66453 Mdot
.54827 .63754 Mdot
.55802 .36094 Mdot
.57924 .67405 Mdot
.45319 .34875 Mdot
.62987 .62384 Mdot
.65257 .51024 Mdot
.64147 .50328 Mdot
.57487 .32331 Mdot
.59546 .31832 Mdot
.57336 .35303 Mdot
.38952 .5983 Mdot
.5498 .65924 Mdot
.41029 .56217 Mdot
.34952 .51742 Mdot
.60846 .66711 Mdot
.54158 .69848 Mdot
.40789 .55212 Mdot
.50009 .34843 Mdot
.41801 .32221 Mdot
.55669 .33395 Mdot
.6441 .52818 Mdot
.43727 .82716 Mdot
.67039 .5138 Mdot
.34329 .5599 Mdot
.63498 .40214 Mdot
.54167 .67219 Mdot
.44744 .34464 Mdot
.4678 .327 Mdot
.44951 .35394 Mdot
.58705 .51648 Mdot
.53137 .64564 Mdot
.72165 .66807 Mdot
.34608 .54857 Mdot
.52816 .45713 Mdot
.37532 .3914 Mdot
.72005 .62282 Mdot
.6333 .52871 Mdot
.37677 .56985 Mdot
.75281 .38941 Mdot
.33614 .66351 Mdot
.36843 .53533 Mdot
.3987 .51779 Mdot
.50594 .24223 Mdot
.455 .55511 Mdot
.59807 .65693 Mdot
.66381 .74035 Mdot
.43419 .55509 Mdot
.51962 .62017 Mdot
.84845 .3898 Mdot
.34584 .54309 Mdot
.38588 .58264 Mdot
.35709 .57245 Mdot
.40391 .54069 Mdot
.60813 .67918 Mdot
.41658 .42544 Mdot
.66662 .52024 Mdot
.54962 .46069 Mdot
.64728 .51595 Mdot
.5456 .3405 Mdot
.48729 .43358 Mdot
.5694 .64361 Mdot
.44954 .34863 Mdot
.21829 .59158 Mdot
.69801 .71431 Mdot
.58696 .36237 Mdot
.48178 .69763 Mdot
.4352 .34142 Mdot
.42091 .52311 Mdot
.46362 .35569 Mdot
.57081 .38506 Mdot
.63748 .51745 Mdot
.43133 .57784 Mdot
.58054 .70911 Mdot
.53945 .6566 Mdot
.37784 .57424 Mdot
.4643 .18791 Mdot
.63385 .4858 Mdot
.6031 .44806 Mdot
.39772 .56585 Mdot
.3998 .51839 Mdot
.58421 .67328 Mdot
.55726 .34128 Mdot
.68047 .30645 Mdot
.43855 .35402 Mdot
.3392 .60609 Mdot
.40864 .54161 Mdot
.70621 .69576 Mdot
.66132 .49465 Mdot
.76018 .40625 Mdot
.39655 .55944 Mdot
.70333 .67982 Mdot
.39715 .5574 Mdot
.31842 .59622 Mdot
.56655 .35271 Mdot
.41763 .51017 Mdot
.37765 .60146 Mdot
.45398 .48962 Mdot
.65255 .50191 Mdot
.55434 .69054 Mdot
.58636 .72074 Mdot
.76837 .40065 Mdot
.62314 .49215 Mdot
.40923 .55041 Mdot
.65157 .48434 Mdot
.35909 .51165 Mdot
.39055 .57071 Mdot
.63351 .52833 Mdot
.57721 .66508 Mdot
.67983 .45951 Mdot
.28073 .50978 Mdot
.40091 .54179 Mdot
.43098 .5677 Mdot
.28893 .46459 Mdot
.80173 .63849 Mdot
.37131 .59634 Mdot
.53886 .6728 Mdot
.37302 .56872 Mdot
.63757 .49241 Mdot
.45057 .33528 Mdot
.55045 .68163 Mdot
.58506 .31899 Mdot
.56765 .36576 Mdot
.66389 .56579 Mdot
.73991 .38968 Mdot
.42747 .57871 Mdot
.61677 .71124 Mdot
.55224 .70769 Mdot
.74584 .27229 Mdot
.55463 .32818 Mdot
.412 .33638 Mdot
.39525 .53392 Mdot
.57073 .56471 Mdot
.67006 .50153 Mdot
.31216 .17302 Mdot
.72068 .65832 Mdot
.46138 .37005 Mdot
.77172 .65249 Mdot
.75574 .39323 Mdot
.36132 .59998 Mdot
.41797 .37645 Mdot
.57894 .37104 Mdot
.37479 .51173 Mdot
.42371 .62085 Mdot
.54285 .41493 Mdot
.5928 .39221 Mdot
.65187 .48572 Mdot
.60163 .35599 Mdot
.434 .38481 Mdot
.7445 .38507 Mdot
.55294 .64584 Mdot
.34771 .55985 Mdot
.29992 .57535 Mdot
.5642 .32611 Mdot
.75539 .38024 Mdot
.40031 .57058 Mdot
.54041 .65271 Mdot
.57646 .38075 Mdot
.38315 .5386 Mdot
.39441 .68978 Mdot
.54309 .62848 Mdot
.58672 .33349 Mdot
.39328 .50966 Mdot
.2831 .55248 Mdot
.5808 .32051 Mdot
.56643 .32205 Mdot
.38187 .57102 Mdot
.45253 .35236 Mdot
.37417 .60737 Mdot
.64677 .53455 Mdot
.58467 .40456 Mdot
.63623 .49439 Mdot
.3725 .33837 Mdot
.32074 .55831 Mdot
.78302 .54691 Mdot
.59456 .66867 Mdot
.41141 .38431 Mdot
.32106 .7405 Mdot
.40757 .5212 Mdot
.29294 .2669 Mdot
.45447 .46393 Mdot
.60132 .18446 Mdot
.15977 .4567 Mdot
.4233 .34897 Mdot
.62145 .49826 Mdot
.38533 .58218 Mdot
.67868 .49859 Mdot
.42805 .37503 Mdot
.36865 .3671 Mdot
.39603 .5104 Mdot
.56237 .65354 Mdot
.39874 .586 Mdot
.59053 .6834 Mdot
.37219 .57656 Mdot
.43964 .51448 Mdot
.3978 .3862 Mdot
.29914 .47797 Mdot
.41768 .52065 Mdot
.22265 .64708 Mdot
.55805 .54396 Mdot
.43149 .34423 Mdot
.408 .56889 Mdot
.75218 .40313 Mdot
.60175 .52337 Mdot
.22512 .42713 Mdot
.57021 .34753 Mdot
.62633 .52995 Mdot
.58251 .68239 Mdot
.58461 .31377 Mdot
.77064 .39056 Mdot
.30024 .58511 Mdot
.40837 .34773 Mdot
.61293 .50383 Mdot
.34862 .57168 Mdot
.34176 .5706 Mdot
.52754 .30695 Mdot
.78439 .4463 Mdot
.53167 .70357 Mdot
.38749 .82037 Mdot
.60446 .66475 Mdot
.4384 .36253 Mdot
.56852 .35323 Mdot
.36372 .59567 Mdot
.37288 .5407 Mdot
.54427 .36595 Mdot
.53604 .67977 Mdot
.6093 .38552 Mdot
.48112 .71497 Mdot
.61854 .33047 Mdot
.35179 .41991 Mdot
.54614 .68413 Mdot
.35328 .42349 Mdot
.43161 .38558 Mdot
.23624 .34811 Mdot
.27459 .40393 Mdot
.63348 .53649 Mdot
.35192 .4156 Mdot
.54556 .67038 Mdot
.39089 .55572 Mdot
.75996 .39364 Mdot
.73802 .40059 Mdot
.58438 .68727 Mdot
.55868 .36655 Mdot
.4245 .33656 Mdot
.388 .5814 Mdot
.75421 .62304 Mdot
.67426 .58906 Mdot
.61403 .33169 Mdot
.36061 .64508 Mdot
.64665 .49992 Mdot
.38238 .59786 Mdot
.41354 .3635 Mdot
.61846 .51246 Mdot
.77837 .39518 Mdot
.64705 .64612 Mdot
.39273 .53035 Mdot
.6782 .70689 Mdot
.61848 .49548 Mdot
.84224 .52644 Mdot
.37667 .55155 Mdot
.65276 .50801 Mdot
.43257 .49562 Mdot
.73799 .53861 Mdot
.51123 .50268 Mdot
.35267 .21476 Mdot
.58866 .39146 Mdot
.56642 .36757 Mdot
.72796 .45722 Mdot
.40516 .39168 Mdot
.61066 .51768 Mdot
.74573 .38402 Mdot
.31405 .36022 Mdot
.64841 .49766 Mdot
.35836 .60347 Mdot
.34178 .55662 Mdot
.46536 .71136 Mdot
.51886 .48172 Mdot
.75481 .37914 Mdot
.60758 .62753 Mdot
.42615 .56141 Mdot
.40676 .49866 Mdot
.36832 .5487 Mdot
.59127 .70861 Mdot
.62574 .48447 Mdot
.24204 .70933 Mdot
.63981 .486 Mdot
.75835 .6291 Mdot
.57725 .32848 Mdot
.61439 .32787 Mdot
.34814 .57618 Mdot
.80441 .54219 Mdot
.22052 .42082 Mdot
.41038 .5959 Mdot
.44121 .30867 Mdot
.35891 .32059 Mdot
.41302 .49624 Mdot
.60102 .71264 Mdot
.30308 .5757 Mdot
.58482 .63033 Mdot
.6204 .51914 Mdot
.41979 .35174 Mdot
.41767 .32313 Mdot
.61388 .50817 Mdot
.35335 .54643 Mdot
.40232 .31417 Mdot
.36508 .53151 Mdot
.39388 .5603 Mdot
.74138 .66987 Mdot
.40848 .33642 Mdot
.57511 .35572 Mdot
.44231 .36577 Mdot
.56945 .69331 Mdot
.61345 .1231 Mdot
.42067 .36357 Mdot
.60647 .73599 Mdot
.45115 .40886 Mdot
.35454 .4176 Mdot
.54228 .65207 Mdot
.45176 .36761 Mdot
.64935 .48644 Mdot
.5931 .17818 Mdot
.82757 .58148 Mdot
.67223 .5133 Mdot
.37688 .54636 Mdot
.57698 .64697 Mdot
.5755 .71368 Mdot
.66463 .47693 Mdot
.55995 .64807 Mdot
.34176 .51011 Mdot
.39729 .54815 Mdot
.6106 .51731 Mdot
.67445 .61225 Mdot
.61415 .48902 Mdot
.63676 .64762 Mdot
.40468 .56947 Mdot
.54979 .68429 Mdot
.3145 .5486 Mdot
.55773 .72363 Mdot
.74205 .40935 Mdot
.37606 .51099 Mdot
.44221 .33458 Mdot
.51971 .47015 Mdot
.58396 .33247 Mdot
.62587 .41251 Mdot
.58847 .66508 Mdot
.64628 .44953 Mdot
.57295 .65169 Mdot
.58543 .65002 Mdot
.64616 .54041 Mdot
.56155 .69838 Mdot
.38666 .58294 Mdot
.51335 .33043 Mdot
.58835 .69715 Mdot
.6312 .50651 Mdot
.43384 .33564 Mdot
.57872 .67053 Mdot
.56 .31562 Mdot
.38897 .54332 Mdot
.59963 .35047 Mdot
.45334 .38041 Mdot
.56428 .64122 Mdot
.45427 .36334 Mdot
.55832 .32727 Mdot
.40668 .35671 Mdot
.40244 .24803 Mdot
.62293 .47598 Mdot
.77718 .63034 Mdot
.27179 .53744 Mdot
.57936 .70901 Mdot
.61821 .30471 Mdot
.36702 .59549 Mdot
.39132 .54013 Mdot
.43202 .38362 Mdot
.57183 .71376 Mdot
.40758 .20445 Mdot
.2964 .52275 Mdot
.63448 .62391 Mdot
.63539 .47486 Mdot
.44576 .83934 Mdot
.67711 .66932 Mdot
.61407 .21569 Mdot
.44418 .5628 Mdot
.75627 .39352 Mdot
.35705 .53431 Mdot
.28043 .71773 Mdot
.4441 .33035 Mdot
.71159 .37118 Mdot
.43921 .58218 Mdot
.57873 .34743 Mdot
.36752 .56608 Mdot
.21621 .51173 Mdot
.30442 .57565 Mdot
.43584 .37746 Mdot
.59794 .54882 Mdot
.52506 .65219 Mdot
.43853 .34208 Mdot
.57347 .36546 Mdot
.3293 .37457 Mdot
.39552 .50801 Mdot
.42543 .5749 Mdot
.62126 .34494 Mdot
.56199 .65167 Mdot
.54401 .34182 Mdot
.65229 .51048 Mdot
.42241 .36009 Mdot
.40123 .5358 Mdot
.39917 .49997 Mdot
.52553 .38675 Mdot
.62767 .48315 Mdot
.60249 .31886 Mdot
.66057 .50094 Mdot
.75725 .39302 Mdot
.42888 .54373 Mdot
.61784 .35211 Mdot
.33923 .56214 Mdot
.3214 .74944 Mdot
.74562 .67038 Mdot
.44713 .78937 Mdot
.57717 .35731 Mdot
.32548 .4221 Mdot
.62959 .4957 Mdot
.6593 .51753 Mdot
.53965 .80035 Mdot
.25042 .37825 Mdot
.5721 .24794 Mdot
.22125 .61062 Mdot
.65204 .51154 Mdot
.636 .49769 Mdot
.57961 .37297 Mdot
.56943 .70007 Mdot
.53746 .62457 Mdot
.61238 .32119 Mdot
.28432 .4928 Mdot
.55056 .66582 Mdot
.30685 .25232 Mdot
.54463 .33118 Mdot
.4438 .57155 Mdot
.72915 .39555 Mdot
.41719 .35017 Mdot
.28475 .49335 Mdot
.22384 .54377 Mdot
.35831 .59459 Mdot
.64196 .76625 Mdot
.55974 .34411 Mdot
.49645 .39381 Mdot
.23905 .32066 Mdot
.39058 .5119 Mdot
.36164 .56206 Mdot
.35623 .54758 Mdot
.41102 .33204 Mdot
.30795 .72851 Mdot
.35735 .59469 Mdot
.33126 .4556 Mdot
.37758 .61457 Mdot
.24035 .4501 Mdot
.44059 .36671 Mdot
.53256 .60557 Mdot
.59997 .38283 Mdot
.73642 .59244 Mdot
.44613 .60501 Mdot
.65665 .50199 Mdot
.5591 .29851 Mdot
.63707 .52027 Mdot
.23657 .37878 Mdot
.2778 .40145 Mdot
.60015 .69886 Mdot
.37934 .59468 Mdot
.57318 .38911 Mdot
.58591 .65782 Mdot
.68075 .34412 Mdot
.72217 .20078 Mdot
.6392 .48069 Mdot
.7989 .67754 Mdot
.66 .51666 Mdot
.74051 .40702 Mdot
.58543 .67732 Mdot
.46958 .64292 Mdot
.52651 .45746 Mdot
.57741 .67083 Mdot
.71116 .48385 Mdot
.60847 .7034 Mdot
.33781 .41641 Mdot
.537 .63573 Mdot
.62917 .50323 Mdot
.5934 .50519 Mdot
.44256 .59253 Mdot
.36833 .59298 Mdot
.56095 .45819 Mdot
.39874 .4701 Mdot
.37273 .59366 Mdot
.58809 .34882 Mdot
.81764 .58024 Mdot
.52599 .35552 Mdot
.57264 .70633 Mdot
.6637 .49419 Mdot
.36309 .56317 Mdot
.40146 .54663 Mdot
.34335 .5343 Mdot
.31625 .76235 Mdot
.31239 .24945 Mdot
.39153 .56844 Mdot
.33414 .60003 Mdot
.57183 .36314 Mdot
.38673 .34442 Mdot
.23834 .6469 Mdot
.3054 .37299 Mdot
.37905 .52669 Mdot
.44488 .35704 Mdot
.42611 .32609 Mdot
.42894 .52308 Mdot
.7573 .59227 Mdot
.56002 .28528 Mdot
.34882 .57182 Mdot
.25928 .4141 Mdot
.53556 .33246 Mdot
.7464 .38138 Mdot
.56516 .32575 Mdot
.54976 .63923 Mdot
.74327 .3914 Mdot
.59251 .37624 Mdot
.45939 .64581 Mdot
.76835 .40243 Mdot
.73258 .55268 Mdot
.45506 .34121 Mdot
.36842 .54427 Mdot
.60204 .71554 Mdot
.54339 .3672 Mdot
.61253 .50717 Mdot
.56327 .67767 Mdot
.59858 .5099 Mdot
.386 .37243 Mdot
.40024 .43332 Mdot
.73785 .3936 Mdot
.65645 .50935 Mdot
.64756 .64791 Mdot
.44473 .35954 Mdot
.64481 .53986 Mdot
.80294 .53281 Mdot
.44042 .55371 Mdot
.19618 .44712 Mdot
.40362 .59563 Mdot
.51478 .17841 Mdot
.66218 .51676 Mdot
.76197 .40995 Mdot
.35047 .54727 Mdot
.58362 .32253 Mdot
.41787 .48467 Mdot
.37305 .5326 Mdot
.60691 .32669 Mdot
.3916 .56157 Mdot
.41319 .36542 Mdot
.5673 .6268 Mdot
.4639 .47909 Mdot
.52283 .84398 Mdot
.40778 .35527 Mdot
.72546 .41529 Mdot
.37376 .59608 Mdot
.38412 .26885 Mdot
.57613 .66815 Mdot
.39361 .51431 Mdot
.57175 .78452 Mdot
.5791 .69882 Mdot
.56949 .68134 Mdot
.41851 .56631 Mdot
.63421 .53901 Mdot
.58557 .32569 Mdot
.44603 .35893 Mdot
.6527 .21881 Mdot
.38038 .53453 Mdot
.37617 .56351 Mdot
.436 .34118 Mdot
.63611 .49581 Mdot
.40355 .54561 Mdot
.66797 .38548 Mdot
.66603 .21138 Mdot
.65541 .53232 Mdot
.4312 .52035 Mdot
.19011 .51426 Mdot
.51307 .67945 Mdot
.80274 .65466 Mdot
.46297 .39206 Mdot
.55684 .35482 Mdot
.4336 .50813 Mdot
.36061 .14928 Mdot
.41931 .34875 Mdot
.72709 .62039 Mdot
.3953 .57406 Mdot
.36398 .5761 Mdot
.54175 .65934 Mdot
.41089 .55684 Mdot
.54241 .68991 Mdot
.54867 .84678 Mdot
.41362 .85162 Mdot
.57701 .65711 Mdot
.56696 .70869 Mdot
.54877 .61019 Mdot
.25897 .66895 Mdot
.58017 .68853 Mdot
.38138 .5073 Mdot
.35707 .2488 Mdot
.35168 .62481 Mdot
.4204 .3852 Mdot
.47463 .34844 Mdot
.50475 .62865 Mdot
.8301 .47336 Mdot
.33444 .49293 Mdot
.46221 .57152 Mdot
.53405 .57196 Mdot
.64943 .52948 Mdot
.381 .52178 Mdot
.73975 .38925 Mdot
.59993 .36509 Mdot
.31822 .60508 Mdot
.3665 .5407 Mdot
.59104 .68839 Mdot
.40531 .33665 Mdot
.61811 .54089 Mdot
.37982 .5636 Mdot
.58996 .39692 Mdot
.43543 .35582 Mdot
.58403 .70212 Mdot
.6152 .74126 Mdot
.40324 .36399 Mdot
.34977 .50437 Mdot
.36961 .58651 Mdot
.40007 .56916 Mdot
.45448 .57698 Mdot
.6134 .5154 Mdot
.54571 .32019 Mdot
.35847 .50604 Mdot
.71826 .68438 Mdot
.48941 .4187 Mdot
.40075 .50288 Mdot
.5452 .66373 Mdot
.66952 .5142 Mdot
.75785 .40774 Mdot
.34724 .37112 Mdot
.38907 .52945 Mdot
.31146 .25256 Mdot
.46523 .69103 Mdot
.7433 .39476 Mdot
.59929 .672 Mdot
.44878 .34826 Mdot
.42474 .57035 Mdot
.31948 .27624 Mdot
.34205 .56071 Mdot
.28606 .51966 Mdot
.55778 .34904 Mdot
.64972 .52655 Mdot
.64195 .19354 Mdot
.60154 .36339 Mdot
.56798 .68338 Mdot
.36037 .19955 Mdot
.53277 .69645 Mdot
.52485 .66574 Mdot
.25681 .33775 Mdot
.62397 .52437 Mdot
.34225 .16036 Mdot
.81802 .61011 Mdot
.3443 .59184 Mdot
.63862 .4903 Mdot
.5868 .67345 Mdot
.38421 .59642 Mdot
.55543 .70813 Mdot
.52683 .67097 Mdot
.36973 .51323 Mdot
.36585 .58305 Mdot
.32293 .46516 Mdot
.26743 .28191 Mdot
.44982 .35883 Mdot
.53581 .67466 Mdot
.42889 .70808 Mdot
.36024 .5977 Mdot
.34588 .54972 Mdot
.50886 .35367 Mdot
.43555 .37731 Mdot
.27835 .62391 Mdot
.39572 .5596 Mdot
.58584 .79164 Mdot
.43105 .56999 Mdot
.59351 .72275 Mdot
.65262 .5354 Mdot
.75224 .59815 Mdot
.53799 .35677 Mdot
.53291 .66459 Mdot
.41763 .33684 Mdot
.57585 .72062 Mdot
.54574 .78392 Mdot
.62682 .52362 Mdot
.54394 .67776 Mdot
.55854 .31938 Mdot
.63185 .51622 Mdot
.65085 .53435 Mdot
.35225 .26318 Mdot
.60584 .3195 Mdot
.45787 .34359 Mdot
.64304 .51456 Mdot
.3812 .69123 Mdot
.6255 .50503 Mdot
.44542 .70939 Mdot
.39247 .60376 Mdot
.34367 .44898 Mdot
.68799 .65896 Mdot
.43027 .62261 Mdot
.60901 .49221 Mdot
.43433 .37292 Mdot
.41782 .5527 Mdot
.55671 .64864 Mdot
.41925 .362 Mdot
.62056 .57147 Mdot
.57828 .31747 Mdot
.59623 .67807 Mdot
.66063 .52884 Mdot
.54142 .68255 Mdot
.38458 .41193 Mdot
.61279 .40701 Mdot
.5359 .58085 Mdot
.52171 .4471 Mdot
.33833 .55155 Mdot
.49418 .63382 Mdot
.42543 .58519 Mdot
.36688 .53746 Mdot
.58621 .33269 Mdot
.28846 .47157 Mdot
.57812 .66548 Mdot
.65439 .19748 Mdot
.65546 .51626 Mdot
.63243 .75488 Mdot
.28544 .55276 Mdot
.39579 .51909 Mdot
.58694 .69718 Mdot
.52548 .68357 Mdot
.44747 .79954 Mdot
.54409 .36331 Mdot
.40538 .63484 Mdot
.32088 .57043 Mdot
.44795 .56587 Mdot
.66331 .51427 Mdot
.6734 .40206 Mdot
.5506 .35986 Mdot
.8744 .53666 Mdot
.55692 .33516 Mdot
.47329 .25713 Mdot
.56141 .69902 Mdot
.44372 .33166 Mdot
.34476 .55586 Mdot
.31623 .47843 Mdot
.60509 .69592 Mdot
.49371 .37026 Mdot
.44533 .33888 Mdot
.69195 .43604 Mdot
.62487 .52738 Mdot
.42141 .5192 Mdot
.37047 .51568 Mdot
.41096 .56674 Mdot
.40056 .59338 Mdot
.65949 .48674 Mdot
.35705 .602 Mdot
.62195 .47387 Mdot
.39042 .68457 Mdot
.58275 .79508 Mdot
.54686 .37877 Mdot
.23391 .40712 Mdot
.58826 .70444 Mdot
.38607 .70349 Mdot
.28316 .60155 Mdot
.75135 .66362 Mdot
.38741 .25583 Mdot
.42153 .58841 Mdot
.56261 .3714 Mdot
.2113 .52157 Mdot
.5698 .38795 Mdot
.53503 .90027 Mdot
.38888 .32234 Mdot
.34078 .21455 Mdot
.38331 .5951 Mdot
.51978 .37366 Mdot
.27873 .58149 Mdot
.42997 .52177 Mdot
.38262 .33612 Mdot
.62884 .72132 Mdot
.69423 .61193 Mdot
.40714 .34061 Mdot
.38737 .54106 Mdot
.52379 .65557 Mdot
.38749 .58467 Mdot
.35 .53971 Mdot
.38385 .59927 Mdot
.64003 .54535 Mdot
.41597 .60666 Mdot
.36969 .60648 Mdot
.79253 .44358 Mdot
.29976 .4424 Mdot
.60308 .34876 Mdot
.49277 .8033 Mdot
.42962 .36309 Mdot
.59195 .678 Mdot
.4445 .44546 Mdot
.63534 .53512 Mdot
.43389 .8036 Mdot
.39133 .59724 Mdot
.67912 .65457 Mdot
.66186 .52781 Mdot
.41804 .35811 Mdot
.76773 .3982 Mdot
.36805 .22465 Mdot
.54884 .37931 Mdot
.76685 .40486 Mdot
.58216 .33223 Mdot
.32443 .73269 Mdot
.5902 .6903 Mdot
.34506 .52881 Mdot
.64774 .50567 Mdot
.59013 .32619 Mdot
.27332 .4747 Mdot
.36464 .55035 Mdot
.58055 .35804 Mdot
.33915 .54494 Mdot
.47407 .41051 Mdot
.55018 .28775 Mdot
.5865 .38292 Mdot
.59039 .51993 Mdot
.63653 .51201 Mdot
.45331 .34709 Mdot
.59288 .6768 Mdot
.54172 .66996 Mdot
.62037 .51372 Mdot
.77523 .68928 Mdot
.37378 .53057 Mdot
.37967 .59835 Mdot
.71685 .68101 Mdot
.38038 .5852 Mdot
.33326 .39219 Mdot
.7322 .40119 Mdot
.5948 .68926 Mdot
.38863 .59324 Mdot
.403 .54327 Mdot
.39431 .53187 Mdot
.38616 .41618 Mdot
.56202 .32764 Mdot
.42601 .56238 Mdot
.41902 .37907 Mdot
.78918 .51433 Mdot
.37014 .60068 Mdot
.4172 .50435 Mdot
.54521 .67432 Mdot
.46271 .85131 Mdot
.63994 .53643 Mdot
.58965 .3543 Mdot
.56565 .32065 Mdot
.47429 .37091 Mdot
.58279 .63914 Mdot
.73239 .40823 Mdot
.74946 .30294 Mdot
.76173 .38567 Mdot
.43708 .3451 Mdot
.51048 .23005 Mdot
.5989 .39276 Mdot
.59075 .36202 Mdot
.60803 .48217 Mdot
.39565 .59333 Mdot
.4153 .59294 Mdot
.72974 .62102 Mdot
.4178 .53747 Mdot
.44027 .33551 Mdot
.60782 .51315 Mdot
.54885 .67186 Mdot
.41587 .34954 Mdot
.65868 .49878 Mdot
.55944 .65139 Mdot
.43979 .55411 Mdot
.43961 .56708 Mdot
.56717 .6775 Mdot
.57947 .65245 Mdot
.35581 .58374 Mdot
.76626 .44493 Mdot
.55705 .63582 Mdot
.54486 .68067 Mdot
.75723 .37592 Mdot
.55265 .38209 Mdot
.31452 .53682 Mdot
.63834 .48939 Mdot
.39916 .56838 Mdot
.56266 .38774 Mdot
.44006 .37566 Mdot
.56941 .66253 Mdot
.39996 .54372 Mdot
.38739 .55549 Mdot
.44597 .35481 Mdot
.40068 .35272 Mdot
.41914 .3405 Mdot
.68096 .50599 Mdot
.40875 .58401 Mdot
.57952 .68656 Mdot
.62787 .52697 Mdot
.4259 .32618 Mdot
.46283 .34456 Mdot
.81431 .44732 Mdot
.35499 .59067 Mdot
.51552 .51388 Mdot
.57715 .11434 Mdot
.32122 .3741 Mdot
.74999 .40917 Mdot
.62123 .33695 Mdot
.34389 .43818 Mdot
.50341 .32721 Mdot
.62637 .48662 Mdot
.30059 .33737 Mdot
.41199 .38445 Mdot
.35422 .51531 Mdot
.43117 .56304 Mdot
.34612 .61293 Mdot
.43018 .35596 Mdot
.37264 .39657 Mdot
.56409 .71412 Mdot
.37362 .73551 Mdot
.42942 .36292 Mdot
.58576 .38306 Mdot
.61267 .36019 Mdot
.5565 .33608 Mdot
.43127 .5447 Mdot
.43624 .79733 Mdot
.40479 .70081 Mdot
.30393 .68999 Mdot
.62436 .52857 Mdot
.52975 .6982 Mdot
.39318 .25984 Mdot
.57082 .67923 Mdot
.59829 .36841 Mdot
.43217 .3525 Mdot
.5379 .66712 Mdot
.61434 .49523 Mdot
.63832 .498 Mdot
.57962 .31831 Mdot
.57345 .32451 Mdot
.59888 .33931 Mdot
.53798 .64329 Mdot
.56176 .69859 Mdot
.39533 .52753 Mdot
.56512 .66658 Mdot
.65685 .75979 Mdot
.46826 .35759 Mdot
.60366 .37213 Mdot
.62439 .4934 Mdot
.58999 .67739 Mdot
.37116 .54498 Mdot
.53946 .24797 Mdot
.69789 .52527 Mdot
.40872 .3629 Mdot
.62428 .27668 Mdot
.58962 .8783 Mdot
.36337 .51899 Mdot
.65612 .48886 Mdot
.76608 .5755 Mdot
.3578 .55163 Mdot
.5664 .34586 Mdot
.29145 .72912 Mdot
.7604 .38251 Mdot
.36976 .60556 Mdot
.4067 .5266 Mdot
.63836 .54193 Mdot
.43504 .41294 Mdot
.40554 .5312 Mdot
.66184 .7006 Mdot
.60345 .53189 Mdot
.55755 .3723 Mdot
.68565 .21946 Mdot
.61838 .31503 Mdot
.26207 .51458 Mdot
.74256 .40595 Mdot
.37498 .51542 Mdot
.59006 .34557 Mdot
.41129 .36897 Mdot
.59399 .33894 Mdot
.6015 .68127 Mdot
.60196 .34524 Mdot
.374 .56553 Mdot
.5774 .68914 Mdot
.61947 .49381 Mdot
.66627 .73697 Mdot
.79541 .45557 Mdot
.58333 .32223 Mdot
.76853 .37581 Mdot
.36448 .60221 Mdot
.30685 .63879 Mdot
.41601 .48353 Mdot
.37385 .5993 Mdot
.63631 .52145 Mdot
.58459 .69968 Mdot
.64572 .4768 Mdot
.3777 .49342 Mdot
.53399 .81685 Mdot
.65863 .52129 Mdot
.72185 .57734 Mdot
.43578 .34223 Mdot
.29779 .48203 Mdot
.37443 .53747 Mdot
.64734 .51072 Mdot
.40838 .58288 Mdot
.53716 .69509 Mdot
.54958 .50439 Mdot
.79664 .52055 Mdot
.64693 .50475 Mdot
.4447 .18099 Mdot
.54336 .51644 Mdot
.30437 .56125 Mdot
.64972 .51224 Mdot
.37628 .77762 Mdot
.75434 .40564 Mdot
.43899 .35246 Mdot
.41771 .33012 Mdot
.40604 .35379 Mdot
.41816 .53433 Mdot
.33697 .63782 Mdot
.46034 .34268 Mdot
.60999 .53919 Mdot
.43072 .37927 Mdot
.33611 .46225 Mdot
.43282 .18727 Mdot
.41351 .34501 Mdot
.37968 .54567 Mdot
.41986 .50464 Mdot
.29581 .44609 Mdot
.57714 .3819 Mdot
.28816 .27154 Mdot
.51007 .71208 Mdot
.36294 .59296 Mdot
.29613 .57081 Mdot
.59869 .69378 Mdot
.79106 .56928 Mdot
.2898 .56039 Mdot
.5296 .30695 Mdot
.55247 .7021 Mdot
.6302 .3332 Mdot
.59438 .68442 Mdot
.35095 .52725 Mdot
.39082 .57253 Mdot
.56888 .62352 Mdot
.63624 .40649 Mdot
.74456 .51139 Mdot
.57114 .19212 Mdot
.53859 .67454 Mdot
.65237 .50202 Mdot
.64447 .48082 Mdot
.63366 .52983 Mdot
.53867 .34902 Mdot
.55901 .64101 Mdot
.41489 .58329 Mdot
.56397 .36303 Mdot
.37485 .52666 Mdot
.63615 .51698 Mdot
.63676 .19062 Mdot
.54643 .67374 Mdot
.34841 .56801 Mdot
.82649 .58246 Mdot
.56682 .33262 Mdot
.4426 .3612 Mdot
.48637 .40214 Mdot
.55888 .31406 Mdot
.61134 .49042 Mdot
.52555 .63794 Mdot
.65592 .54539 Mdot
.44044 .45212 Mdot
.36742 .62649 Mdot
.40666 .50704 Mdot
.68486 .23489 Mdot
.83132 .50328 Mdot
.42436 .53705 Mdot
.57438 .36573 Mdot
.56187 .38165 Mdot
.3964 .54234 Mdot
.55308 .64487 Mdot
.43866 .32548 Mdot
.41204 .37707 Mdot
.34019 .51998 Mdot
.5296 .45559 Mdot
.33444 .45696 Mdot
.40681 .55079 Mdot
.40619 .63818 Mdot
.58007 .31566 Mdot
.76992 .39487 Mdot
.7079 .6709 Mdot
.42783 .33069 Mdot
.3959 .57163 Mdot
.72071 .54065 Mdot
.54431 .69391 Mdot
.60065 .34438 Mdot
.60993 .50667 Mdot
.3897 .40187 Mdot
.55098 .32563 Mdot
.3967 .54356 Mdot
.40339 .54517 Mdot
.64142 .54125 Mdot
.59358 .72256 Mdot
.43004 .35314 Mdot
.56393 .36143 Mdot
.43786 .32882 Mdot
.56611 .69488 Mdot
.55087 .67411 Mdot
.3443 .62322 Mdot
.45448 .57107 Mdot
.57486 .32046 Mdot
.33184 .55132 Mdot
.59896 .37103 Mdot
.43235 .40703 Mdot
.66802 .49954 Mdot
.38179 .51024 Mdot
.51853 .66936 Mdot
.63176 .51955 Mdot
.35977 .57825 Mdot
.76526 .29684 Mdot
.38984 .5168 Mdot
.55039 .31742 Mdot
.54144 .81581 Mdot
.435 .37508 Mdot
.59103 .74941 Mdot
.47627 .57791 Mdot
.37993 .58314 Mdot
.60863 .36192 Mdot
.4085 .48315 Mdot
.65383 .5302 Mdot
.56313 .70431 Mdot
.74975 .75 Mdot
.62828 .50772 Mdot
.38971 .58343 Mdot
.42105 .35997 Mdot
.52301 .67946 Mdot
.74892 .38584 Mdot
.71685 .66443 Mdot
.31429 .59629 Mdot
.4402 .5748 Mdot
.39328 .59223 Mdot
.22317 .63214 Mdot
.5917 .35024 Mdot
.58848 .67537 Mdot
.6643 .50975 Mdot
.61761 .50781 Mdot
.55647 .34247 Mdot
.6774 .63262 Mdot
.63437 .39271 Mdot
.48131 .08693 Mdot
.60557 .32813 Mdot
.43692 .3799 Mdot
.50252 .43886 Mdot
.60574 .35807 Mdot
.5834 .34942 Mdot
.56732 .31905 Mdot
.70134 .64427 Mdot
.55173 .65551 Mdot
.38822 .55602 Mdot
.58819 .64361 Mdot
.37823 .51425 Mdot
.24007 .54761 Mdot
.61957 .51586 Mdot
.56105 .7029 Mdot
.72674 .26262 Mdot
.39451 .47018 Mdot
.36183 .55728 Mdot
.42502 .22927 Mdot
.35898 .49343 Mdot
.35385 .402 Mdot
.33639 .51166 Mdot
.57909 .32697 Mdot
.31222 .61514 Mdot
.44136 .52374 Mdot
.65659 .75623 Mdot
.62795 .49078 Mdot
.73804 .40653 Mdot
.41576 .60067 Mdot
.31891 .59664 Mdot
.5233 .67428 Mdot
.53756 .66754 Mdot
.45929 .34151 Mdot
.51645 .42012 Mdot
.62176 .49213 Mdot
.59087 .42543 Mdot
.36876 .59144 Mdot
.58713 .53829 Mdot
.54266 .79559 Mdot
.35819 .57723 Mdot
.34262 .26069 Mdot
.43848 .80276 Mdot
.40351 .52844 Mdot
.34995 .7396 Mdot
.63323 .49745 Mdot
.58253 .78996 Mdot
.33414 .58628 Mdot
.56755 .34476 Mdot
.56744 .70156 Mdot
.59915 .68709 Mdot
.41061 .35304 Mdot
.72594 .71822 Mdot
.61418 .48332 Mdot
.56137 .70051 Mdot
.35948 .54627 Mdot
.6123 .51241 Mdot
.73917 .39367 Mdot
.42809 .51125 Mdot
.29156 .32901 Mdot
.5612 .66727 Mdot
.33144 .59539 Mdot
.61309 .59337 Mdot
.46874 .41955 Mdot
.23651 .30427 Mdot
.6399 .52911 Mdot
.42363 .3343 Mdot
.32383 .52368 Mdot
.74397 .29857 Mdot
.36514 .61628 Mdot
.30401 .46828 Mdot
.50298 .65704 Mdot
.44999 .33483 Mdot
.35311 .55616 Mdot
.4078 .5358 Mdot
.51739 .45746 Mdot
.4019 .34607 Mdot
.38663 .51377 Mdot
.35688 .62972 Mdot
.56111 .65233 Mdot
.73344 .40277 Mdot
.55482 .66766 Mdot
.37668 .54714 Mdot
.32349 .63273 Mdot
.54791 .65141 Mdot
.55399 .2172 Mdot
.39795 .36838 Mdot
.64051 .53525 Mdot
.38015 .64427 Mdot
.38955 .60361 Mdot
.1644 .54654 Mdot
.74209 .40925 Mdot
.26969 .70818 Mdot
.60896 .31763 Mdot
.7138 .49592 Mdot
.55685 .40287 Mdot
.36072 .20847 Mdot
.67455 .71849 Mdot
.34779 .61864 Mdot
.26151 .39365 Mdot
.32991 .71885 Mdot
.62686 .4771 Mdot
.34166 .67373 Mdot
.36832 .59319 Mdot
.35406 .53547 Mdot
.57437 .37443 Mdot
.66784 .64545 Mdot
.76098 .57954 Mdot
.5444 .45909 Mdot
.42727 .34964 Mdot
.55791 .6938 Mdot
.3742 .57426 Mdot
.65964 .32861 Mdot
.60535 .34132 Mdot
.5734 .56325 Mdot
.34829 .55856 Mdot
.76312 .62011 Mdot
.71434 .60548 Mdot
.61214 .51484 Mdot
.61966 .34126 Mdot
.56069 .31392 Mdot
.34802 .53582 Mdot
.61014 .4963 Mdot
.39722 .52692 Mdot
.55955 .53481 Mdot
.3299 .57226 Mdot
.41499 .36016 Mdot
.34592 .58632 Mdot
.50345 .47325 Mdot
.29806 .23344 Mdot
.31085 .52564 Mdot
.57864 .64534 Mdot
.53997 .34507 Mdot
.55963 .33199 Mdot
.54019 .67202 Mdot
.55922 .33454 Mdot
.38701 .74634 Mdot
.51699 .7562 Mdot
.4266 .34539 Mdot
.31083 .63099 Mdot
.41676 .36459 Mdot
.73862 .40765 Mdot
.3577 .5918 Mdot
.76685 .32219 Mdot
.60033 .32401 Mdot
.36662 .79529 Mdot
.62311 .50475 Mdot
.74075 .40806 Mdot
.37222 .61501 Mdot
.50399 .23128 Mdot
.58713 .37643 Mdot
.58251 .30339 Mdot
.39388 .53081 Mdot
.54177 .66493 Mdot
.40834 .53767 Mdot
.32563 .53724 Mdot
.76574 .40544 Mdot
.39588 .5924 Mdot
.65837 .49834 Mdot
.5513 .64071 Mdot
.38463 .21204 Mdot
.54188 .36575 Mdot
.34384 .57522 Mdot
.35856 .54729 Mdot
.53955 .70005 Mdot
.37118 .61285 Mdot
.61785 .48885 Mdot
.23021 .23319 Mdot
.43693 .34318 Mdot
.77015 .38809 Mdot
.55591 .31186 Mdot
.42373 .58249 Mdot
.40883 .54743 Mdot
.67421 .22659 Mdot
.77162 .4894 Mdot
.65788 .50154 Mdot
.3418 .51325 Mdot
.57239 .36242 Mdot
.41926 .3583 Mdot
.61073 .53483 Mdot
.40085 .56593 Mdot
.34822 .54667 Mdot
.41492 .35805 Mdot
.36688 .24735 Mdot
.55851 .28439 Mdot
.62841 .53014 Mdot
.30616 .60997 Mdot
.54668 .25445 Mdot
.37343 .53144 Mdot
.60271 .23323 Mdot
.54626 .68018 Mdot
.64819 .51767 Mdot
.27565 .67681 Mdot
.34454 .5285 Mdot
.62427 .48458 Mdot
.62295 .49219 Mdot
.34061 .58404 Mdot
.58107 .63898 Mdot
.53172 .65281 Mdot
.54425 .68625 Mdot
.54421 .82308 Mdot
.24551 .4799 Mdot
.59888 .33792 Mdot
.63447 .49666 Mdot
.57682 .38744 Mdot
.43259 .32386 Mdot
.49151 .4203 Mdot
.5737 .38545 Mdot
.5987 .69165 Mdot
.61197 .3619 Mdot
.4019 .53354 Mdot
.62067 .49134 Mdot
.59177 .36184 Mdot
.42935 .56725 Mdot
.44092 .6226 Mdot
.53105 .52824 Mdot
.44343 .32739 Mdot
.48104 .38312 Mdot
.38543 .56976 Mdot
.7613 .40701 Mdot
.35297 .58104 Mdot
.6111 .51899 Mdot
.48733 .45825 Mdot
.42819 .56658 Mdot
.5801 .32088 Mdot
.47992 .52175 Mdot
.56024 .37619 Mdot
.32157 .55782 Mdot
.37778 .54882 Mdot
.36906 .53001 Mdot
.40565 .53087 Mdot
.71173 .59415 Mdot
.63659 .47444 Mdot
.42252 .63886 Mdot
.5671 .39335 Mdot
.57241 .67186 Mdot
.57098 .71745 Mdot
.57712 .25244 Mdot
.77249 .39588 Mdot
.63633 .49022 Mdot
.37585 .53164 Mdot
.58505 .302 Mdot
.6275 .18705 Mdot
.59106 .21944 Mdot
.40031 .26541 Mdot
.58078 .36579 Mdot
.57994 .64692 Mdot
.60193 .35731 Mdot
.35598 .52906 Mdot
.37823 .49768 Mdot
.36742 .21208 Mdot
.64799 .46617 Mdot
.43181 .35364 Mdot
.3699 .52608 Mdot
.25847 .52257 Mdot
.57172 .36312 Mdot
.58363 .31512 Mdot
.38438 .51839 Mdot
.53262 .66065 Mdot
.1793 .35304 Mdot
.60964 .50933 Mdot
.31244 .64729 Mdot
.54219 .73418 Mdot
.63375 .71251 Mdot
.6145 .50684 Mdot
.53527 .55567 Mdot
.54875 .34657 Mdot
.55906 .75635 Mdot
.56902 .67323 Mdot
.4332 .35736 Mdot
.38429 .50056 Mdot
.59844 .6877 Mdot
.62148 .32862 Mdot
.58946 .70041 Mdot
.35142 .52311 Mdot
.63328 .47567 Mdot
.55338 .3458 Mdot
.58726 .51711 Mdot
.57041 .62355 Mdot
.42195 .37234 Mdot
.29673 .48459 Mdot
.33598 .66603 Mdot
.43671 .803 Mdot
.426 .56309 Mdot
.58739 .28434 Mdot
.41076 .58136 Mdot
.52448 .67109 Mdot
.37561 .53866 Mdot
.50404 .62648 Mdot
.61414 .32824 Mdot
.33164 .59496 Mdot
.36413 .60507 Mdot
.42858 .66825 Mdot
.35799 .56468 Mdot
.36151 .60906 Mdot
.40991 .53255 Mdot
.53197 .72737 Mdot
.34515 .62087 Mdot
.54661 .65888 Mdot
.72151 .62748 Mdot
.58359 .34715 Mdot
.45512 .33149 Mdot
.40611 .36849 Mdot
.31371 .46334 Mdot
.29332 .48509 Mdot
.68009 .63639 Mdot
.55407 .66205 Mdot
.64984 .48874 Mdot
.3963 .52631 Mdot
.27033 .66127 Mdot
.42429 .39381 Mdot
.55006 .34593 Mdot
.53552 .34849 Mdot
.45519 .55308 Mdot
.21772 .62502 Mdot
.33319 .60247 Mdot
.72244 .66503 Mdot
.33652 .52894 Mdot
.3923 .51405 Mdot
.55004 .32319 Mdot
.39443 .43773 Mdot
.42613 .56261 Mdot
.52324 .67478 Mdot
.43669 .35977 Mdot
.30874 .52023 Mdot
.42604 .30227 Mdot
.55325 .55253 Mdot
.46699 .6568 Mdot
.409 .5897 Mdot
.55999 .3573 Mdot
.59567 .67632 Mdot
.70931 .68902 Mdot
.63077 .52684 Mdot
.6884 .66856 Mdot
.41346 .68663 Mdot
.50873 .21104 Mdot
.43511 .356 Mdot
.35951 .2555 Mdot
.37436 .56597 Mdot
.54065 .34059 Mdot
.36197 .51692 Mdot
.62002 .18501 Mdot
.45193 .36636 Mdot
.60691 .69259 Mdot
.65232 .49991 Mdot
.5383 .6951 Mdot
.45365 .78999 Mdot
.52228 .58595 Mdot
.71641 .41655 Mdot
.55352 .38156 Mdot
.2505 .59557 Mdot
.58305 .68988 Mdot
.3997 .55353 Mdot
.51327 .09274 Mdot
.54728 .68154 Mdot
.53609 .67847 Mdot
.45604 .40211 Mdot
.37146 .3419 Mdot
.41174 .48641 Mdot
.58326 .70584 Mdot
.58934 .38676 Mdot
.44559 .36388 Mdot
.42087 .55313 Mdot
.41006 .53508 Mdot
.54102 .66134 Mdot
.59264 .3737 Mdot
.24415 .5958 Mdot
.57598 .32539 Mdot
.56656 .65219 Mdot
.57289 .33394 Mdot
.53371 .32439 Mdot
.58874 .35977 Mdot
.38234 .60807 Mdot
.37854 .53369 Mdot
.43361 .28752 Mdot
.55106 .67401 Mdot
.41338 .5527 Mdot
.39303 .56764 Mdot
.5815 .6869 Mdot
.59882 .39125 Mdot
.25982 .64728 Mdot
.37937 .59393 Mdot
.38623 .54564 Mdot
.44394 .33111 Mdot
.62451 .37236 Mdot
.65678 .29183 Mdot
.41818 .55362 Mdot
.41843 .38098 Mdot
.53883 .64146 Mdot
.35414 .58085 Mdot
.34974 .45586 Mdot
.52936 .35308 Mdot
.3414 .57753 Mdot
.7481 .38526 Mdot
.41975 .58841 Mdot
.18946 .34315 Mdot
.34854 .58538 Mdot
.58564 .6729 Mdot
.57632 .70029 Mdot
.48971 .38353 Mdot
.56531 .6855 Mdot
.73909 .40353 Mdot
.63502 .51611 Mdot
.54029 .18459 Mdot
.73952 .39613 Mdot
.39989 .5159 Mdot
.81785 .61061 Mdot
.33318 .55432 Mdot
.41796 .59717 Mdot
.26422 .67978 Mdot
.74016 .3975 Mdot
.58691 .69445 Mdot
.63624 .41045 Mdot
.34324 .51551 Mdot
.6091 .50503 Mdot
.4224 .51074 Mdot
.34487 .58879 Mdot
.64817 .70437 Mdot
.49729 .82108 Mdot
.61413 .52565 Mdot
.32333 .51958 Mdot
.41818 .5545 Mdot
.8191 .488 Mdot
.36614 .54833 Mdot
.41215 .34762 Mdot
.53948 .68357 Mdot
.61 .34312 Mdot
.4435 .34568 Mdot
.37535 .58841 Mdot
.42939 .35882 Mdot
.59947 .34314 Mdot
.64025 .52073 Mdot
.34255 .56861 Mdot
.41805 .3846 Mdot
.42764 .35126 Mdot
.41192 .57407 Mdot
.56334 .70231 Mdot
.35907 .47929 Mdot
.35531 .58052 Mdot
.39797 .55013 Mdot
.54181 .66991 Mdot
.86378 .47653 Mdot
.35452 .52685 Mdot
.51902 .51885 Mdot
.6066 .68375 Mdot
.7375 .3853 Mdot
.59601 .36198 Mdot
.33752 .56822 Mdot
.61797 .51743 Mdot
.62462 .51943 Mdot
.62288 .34897 Mdot
.53397 .69247 Mdot
.57904 .38079 Mdot
.3308 .50576 Mdot
.45143 .58238 Mdot
.35571 .50629 Mdot
.7372 .75738 Mdot
.35551 .2278 Mdot
.56114 .64287 Mdot
.54904 .35665 Mdot
.5468 .45745 Mdot
.63905 .49382 Mdot
.61304 .36273 Mdot
.51996 .6551 Mdot
.5801 .65048 Mdot
.59019 .7027 Mdot
.44159 .33203 Mdot
.54906 .33253 Mdot
.59815 .71784 Mdot
.5314 .66769 Mdot
.39699 .5317 Mdot
.41747 .55523 Mdot
.51899 .6226 Mdot
.31157 .42793 Mdot
.41834 .36989 Mdot
.56014 .35065 Mdot
.14558 .54847 Mdot
.61175 .5203 Mdot
.43263 .66692 Mdot
.42642 .57684 Mdot
.71347 .18599 Mdot
.3272 .59432 Mdot
.36158 .54617 Mdot
.54815 .63926 Mdot
.44068 .38155 Mdot
.42924 .36873 Mdot
.5821 .69177 Mdot
.53895 .62346 Mdot
.41582 .3397 Mdot
.37934 .26442 Mdot
.44921 .17602 Mdot
.69917 .68878 Mdot
.584 .67613 Mdot
.33815 .66378 Mdot
.61123 .49154 Mdot
.58434 .63093 Mdot
.62469 .53423 Mdot
.58193 .34941 Mdot
.55663 .32432 Mdot
.63864 .54105 Mdot
.39123 .53024 Mdot
.59851 .35027 Mdot
.31728 .60716 Mdot
.40511 .22177 Mdot
.21203 .40357 Mdot
.75434 .46936 Mdot
.42995 .57346 Mdot
.75537 .59368 Mdot
.76582 .54625 Mdot
.38293 .57698 Mdot
.33468 .47831 Mdot
.43158 .35558 Mdot
.5967 .64501 Mdot
.61555 .49116 Mdot
.22718 .31662 Mdot
.37439 .53154 Mdot
.57773 .66389 Mdot
.63098 .48982 Mdot
.51781 .39132 Mdot
.65925 .69555 Mdot
.37735 .51631 Mdot
.40586 .11913 Mdot
.60653 .65986 Mdot
.61023 .34232 Mdot
.77491 .66631 Mdot
.5928 .64763 Mdot
.47472 .38559 Mdot
.58543 .31268 Mdot
.59543 .20698 Mdot
.59131 .67581 Mdot
.62661 .3423 Mdot
.56581 .69274 Mdot
.41269 .36013 Mdot
.54152 .63186 Mdot
.55364 .3501 Mdot
.35408 .56091 Mdot
.55907 .34019 Mdot
.41676 .36985 Mdot
.53774 .34715 Mdot
.613 .49208 Mdot
.74777 .40799 Mdot
.63896 .50418 Mdot
.48382 .41452 Mdot
.5141 .82051 Mdot
.6493 .52693 Mdot
.56657 .41269 Mdot
.42576 .54096 Mdot
.58889 .72458 Mdot
.61028 .33228 Mdot
.57578 .39214 Mdot
.50644 .42856 Mdot
.57685 .67571 Mdot
.55603 .3471 Mdot
.40117 .68945 Mdot
.86032 .56108 Mdot
.34977 .64063 Mdot
.24923 .44911 Mdot
.58244 .68399 Mdot
.60937 .32193 Mdot
.71631 .6795 Mdot
.58705 .70894 Mdot
.60468 .32811 Mdot
.65025 .50896 Mdot
.61649 .50737 Mdot
.37981 .52326 Mdot
.61243 .47165 Mdot
.61511 .34985 Mdot
.7378 .5232 Mdot
.53994 .69078 Mdot
.51779 .39305 Mdot
.40883 .35111 Mdot
.58467 .35352 Mdot
.44685 .53714 Mdot
.53023 .62435 Mdot
.54248 .37653 Mdot
.25872 .36826 Mdot
.1586 .57915 Mdot
.55748 .34537 Mdot
.53958 .68497 Mdot
.56987 .66102 Mdot
.37879 .48463 Mdot
.52543 .45363 Mdot
.57581 .37919 Mdot
.77601 .34036 Mdot
.29268 .47509 Mdot
.75729 .39246 Mdot
.83749 .5048 Mdot
.42674 .56418 Mdot
.40664 .58224 Mdot
.6424 .49308 Mdot
.36686 .56154 Mdot
.53143 .65876 Mdot
.40419 .6048 Mdot
.63151 .48245 Mdot
.55006 .34949 Mdot
.34684 .57823 Mdot
.43751 .37184 Mdot
.60366 .50001 Mdot
.62978 .54177 Mdot
.58367 .33793 Mdot
.58562 .7052 Mdot
.64847 .32432 Mdot
.572 .32479 Mdot
.4108 .58943 Mdot
.74517 .39685 Mdot
.34259 .53603 Mdot
.33616 .29467 Mdot
.55863 .71254 Mdot
.60453 .35449 Mdot
.59857 .67122 Mdot
.63468 .5048 Mdot
.60686 .37653 Mdot
.37077 .55123 Mdot
.59964 .32595 Mdot
.4805 .31694 Mdot
.36144 .27545 Mdot
.53065 .68837 Mdot
.44906 .31266 Mdot
.53438 .67829 Mdot
.75743 .39113 Mdot
.32854 .32994 Mdot
.43547 .34821 Mdot
.57565 .3599 Mdot
.34264 .23353 Mdot
.58681 .31994 Mdot
.35866 .56717 Mdot
.36579 .58011 Mdot
.57658 .37381 Mdot
.45231 .35843 Mdot
.46626 .84958 Mdot
.52528 .55315 Mdot
.5899 .69363 Mdot
.54287 .74364 Mdot
.13274 .48635 Mdot
.59897 .52909 Mdot
.64842 .49324 Mdot
.32061 .58425 Mdot
.39451 .51867 Mdot
.62322 .54238 Mdot
.66429 .49602 Mdot
.44155 .32827 Mdot
.55993 .32447 Mdot
.59714 .7285 Mdot
.60029 .52073 Mdot
.47215 .53232 Mdot
.26614 .51347 Mdot
.3806 .48667 Mdot
.39613 .63135 Mdot
.43427 .55565 Mdot
.4636 .41698 Mdot
.66041 .4932 Mdot
.38605 .56719 Mdot
.33849 .61801 Mdot
.65269 .51271 Mdot
.41366 .36128 Mdot
.62063 .65511 Mdot
.56942 .33911 Mdot
.84939 .38714 Mdot
.34276 .57737 Mdot
.35354 .56809 Mdot
.62383 .52824 Mdot
.83201 .47451 Mdot
.57394 .65015 Mdot
.56489 .71125 Mdot
.59288 .35002 Mdot
.50765 .42647 Mdot
.38725 .61013 Mdot
.38398 .57404 Mdot
.57251 .35471 Mdot
.75134 .40801 Mdot
.73199 .46176 Mdot
.38646 .55504 Mdot
.62568 .49432 Mdot
.55154 .30266 Mdot
.66103 .49294 Mdot
.3645 .51763 Mdot
.36022 .5692 Mdot
.38107 .60883 Mdot
.39613 .51862 Mdot
.62112 .53768 Mdot
.38162 .56852 Mdot
.45024 .54278 Mdot
.57036 .70734 Mdot
.39869 .59636 Mdot
.33328 .45198 Mdot
.38324 .54318 Mdot
.43203 .37271 Mdot
.65473 .31239 Mdot
.37011 .52818 Mdot
.39736 .59592 Mdot
.52561 .54717 Mdot
.35289 .55128 Mdot
.61456 .52356 Mdot
.57054 .6678 Mdot
.6352 .49663 Mdot
.66374 .51425 Mdot
.5769 .38949 Mdot
.44421 .32902 Mdot
.37299 .61934 Mdot
.4063 .35991 Mdot
.42233 .61452 Mdot
.35273 .52115 Mdot
.62604 .3047 Mdot
.72252 .6624 Mdot
.51099 .32259 Mdot
.37279 .5489 Mdot
.58881 .34904 Mdot
.60826 .34481 Mdot
.25989 .38491 Mdot
.30287 .57418 Mdot
.61724 .53868 Mdot
.64751 .51017 Mdot
.32843 .38803 Mdot
.65106 .712 Mdot
.42416 .37241 Mdot
.56386 .46043 Mdot
.43195 .55194 Mdot
.39187 .55627 Mdot
.41945 .50607 Mdot
.57351 .38592 Mdot
.76901 .402 Mdot
.54966 .34257 Mdot
.73116 .38443 Mdot
.65589 .48511 Mdot
.41402 .59417 Mdot
.22208 .37742 Mdot
.54157 .65543 Mdot
.56972 .66789 Mdot
.61492 .54215 Mdot
.56651 .37952 Mdot
.3923 .48141 Mdot
.75275 .75144 Mdot
.60472 .6487 Mdot
.46317 .35813 Mdot
.38604 .57788 Mdot
.58672 .34109 Mdot
.53786 .65735 Mdot
.40387 .3722 Mdot
.38243 .60035 Mdot
.57181 .39545 Mdot
.37817 .5388 Mdot
.32519 .7195 Mdot
.57445 .70509 Mdot
.62529 .18293 Mdot
.53315 .6966 Mdot
.60428 .49587 Mdot
.65624 .51744 Mdot
.35966 .57636 Mdot
.75395 .72378 Mdot
.60912 .68723 Mdot
.59086 .50192 Mdot
.44948 .37287 Mdot
.76986 .38948 Mdot
.45847 .35135 Mdot
.60615 .35921 Mdot
.43679 .35748 Mdot
.56627 .32053 Mdot
.32073 .4006 Mdot
.61512 .67794 Mdot
.44022 .34423 Mdot
.81123 .45775 Mdot
.40884 .61384 Mdot
.42472 .3269 Mdot
.4541 .55663 Mdot
.55916 .75059 Mdot
.57248 .35122 Mdot
.45083 .36131 Mdot
.40078 .55081 Mdot
.21915 .33908 Mdot
.65932 .51745 Mdot
.61481 .53622 Mdot
.40129 .62048 Mdot
.5698 .31733 Mdot
.54118 .62458 Mdot
.4502 .45124 Mdot
.73223 .39158 Mdot
.38345 .57149 Mdot
.41581 .59293 Mdot
.56177 .7177 Mdot
.52618 .69344 Mdot
.36142 .57197 Mdot
.36644 .68475 Mdot
.3752 .56852 Mdot
.61462 .51186 Mdot
.57873 .65097 Mdot
.56902 .66303 Mdot
.61771 .34679 Mdot
.53266 .68572 Mdot
.38976 .63391 Mdot
.6712 .47175 Mdot
.35072 .50634 Mdot
.63061 .50893 Mdot
.49374 .46675 Mdot
.53845 .3571 Mdot
.25858 .29561 Mdot
.55414 .71511 Mdot
.39573 .59382 Mdot
.53463 .68418 Mdot
.4223 .33925 Mdot
.55372 .67258 Mdot
.58264 .64523 Mdot
.36645 .58807 Mdot
.37515 .51561 Mdot
.74164 .4011 Mdot
.52575 .44981 Mdot
.55216 .69837 Mdot
.37765 .57413 Mdot
.33211 .56717 Mdot
.35018 .6014 Mdot
.52805 .49203 Mdot
.56843 .64262 Mdot
.46799 .71526 Mdot
.27552 .33522 Mdot
.55781 .70037 Mdot
.17218 .38189 Mdot
.75497 .38341 Mdot
.77191 .39285 Mdot
.59551 .512 Mdot
.38783 .55364 Mdot
.55739 .3703 Mdot
.35312 .53163 Mdot
.32207 .61355 Mdot
.34864 .54372 Mdot
.43893 .37673 Mdot
.37036 .62062 Mdot
.76115 .39731 Mdot
.56778 .32617 Mdot
.38233 .59664 Mdot
.34481 .57316 Mdot
.77333 .39884 Mdot
.5469 .71169 Mdot
.58623 .65912 Mdot
.59571 .22861 Mdot
.42237 .34443 Mdot
.63436 .5234 Mdot
.38358 .52738 Mdot
.59012 .34993 Mdot
.56014 .33707 Mdot
.53687 .69149 Mdot
.56543 .34389 Mdot
.60966 .51245 Mdot
.367 .55264 Mdot
.61856 .53845 Mdot
.43461 .37725 Mdot
.53949 .68162 Mdot
.38159 .52627 Mdot
.39677 .53202 Mdot
.57663 .70025 Mdot
.42596 .54096 Mdot
.4433 .33086 Mdot
.57205 .32178 Mdot
.5885 .66613 Mdot
.6324 .51761 Mdot
.61446 .35473 Mdot
.40312 .53985 Mdot
.17709 .60747 Mdot
.36885 .56414 Mdot
.39475 .54473 Mdot
.40817 .19342 Mdot
.32053 .57595 Mdot
.61455 .3336 Mdot
.57918 .71591 Mdot
.43762 .57291 Mdot
.25219 .51811 Mdot
.69683 .25446 Mdot
.61039 .36768 Mdot
.38759 .58618 Mdot
.27739 .27651 Mdot
.38572 .59221 Mdot
.58952 .42754 Mdot
.572 .26879 Mdot
.22147 .53098 Mdot
.40325 .62903 Mdot
.63098 .53785 Mdot
.74117 .40261 Mdot
.60189 .32019 Mdot
.38742 .77867 Mdot
.3721 .58429 Mdot
.36902 .77477 Mdot
.35663 .60152 Mdot
.61526 .50543 Mdot
.4119 .4722 Mdot
.56082 .34896 Mdot
.69654 .73706 Mdot
.41354 .58459 Mdot
.5696 .64361 Mdot
.603 .37317 Mdot
.76587 .38548 Mdot
.39988 .54469 Mdot
.40891 .36964 Mdot
.5942 .46654 Mdot
.43654 .61355 Mdot
.62967 .51174 Mdot
.39438 .56827 Mdot
.31312 .53482 Mdot
.74111 .72043 Mdot
.57841 .70466 Mdot
.64999 .49671 Mdot
.79268 .55642 Mdot
.42325 .53219 Mdot
.59098 .67334 Mdot
.5703 .67344 Mdot
.41035 .36092 Mdot
.57332 .49464 Mdot
.64413 .58256 Mdot
.19328 .44578 Mdot
.48451 .80376 Mdot
.61988 .33575 Mdot
.75516 .51812 Mdot
.42113 .55771 Mdot
.53438 .5853 Mdot
.6222 .5312 Mdot
.35291 .56484 Mdot
.51868 .8036 Mdot
.54395 .68432 Mdot
.38351 .55236 Mdot
.41541 .36309 Mdot
.58277 .47212 Mdot
.56292 .56461 Mdot
.16693 .52404 Mdot
.60042 .37863 Mdot
.39162 .49947 Mdot
.41908 .62021 Mdot
.74511 .38083 Mdot
.35887 .51509 Mdot
.60828 .32561 Mdot
.41051 .22976 Mdot
.45248 .36063 Mdot
.53478 .666 Mdot
.75623 .38329 Mdot
.43472 .56892 Mdot
.33625 .58681 Mdot
.4566 .33271 Mdot
.40384 .56843 Mdot
.73091 .70963 Mdot
.71346 .406 Mdot
.59565 .35553 Mdot
.59325 .69665 Mdot
.43065 .54189 Mdot
.76826 .40245 Mdot
.36629 .58526 Mdot
.47433 .63457 Mdot
.40085 .58521 Mdot
.61672 .60065 Mdot
.56692 .70098 Mdot
.63348 .51095 Mdot
.41771 .61393 Mdot
.35565 .53694 Mdot
.54234 .25159 Mdot
.32228 .61358 Mdot
.34698 .58339 Mdot
.5228 .67576 Mdot
.55033 .64682 Mdot
.54619 .66097 Mdot
.60272 .34471 Mdot
.70389 .67908 Mdot
.62656 .49959 Mdot
.38606 .61423 Mdot
.60061 .52132 Mdot
.47735 .60686 Mdot
.46319 .34237 Mdot
.17943 .4028 Mdot
.38957 .59935 Mdot
.55072 .65993 Mdot
.71163 .55662 Mdot
.53751 .64295 Mdot
.55969 .39465 Mdot
.62137 .49212 Mdot
.54712 .68394 Mdot
.35865 .54055 Mdot
.53642 .46185 Mdot
.18195 .53744 Mdot
.64141 .49796 Mdot
.40928 .50044 Mdot
.5994 .3812 Mdot
.53419 .3546 Mdot
.12822 .43706 Mdot
.65946 .50479 Mdot
.76725 .54017 Mdot
.37869 .57877 Mdot
.54231 .65585 Mdot
.64134 .5305 Mdot
.64511 .53664 Mdot
.56928 .35047 Mdot
.37437 .51784 Mdot
.36737 .53176 Mdot
.74967 .38472 Mdot
.64467 .51336 Mdot
.42137 .60195 Mdot
.34447 .52003 Mdot
.36985 .20987 Mdot
.62518 .67457 Mdot
.85656 .44317 Mdot
.33 .5065 Mdot
.48321 .80808 Mdot
.48959 .43869 Mdot
.55527 .64157 Mdot
.37233 .5235 Mdot
.43362 .53972 Mdot
.61743 .3417 Mdot
.36871 .55792 Mdot
.5503 .36812 Mdot
.64724 .49052 Mdot
.16967 .41819 Mdot
.69251 .49232 Mdot
.38935 .25761 Mdot
.36217 .56028 Mdot
.64043 .69048 Mdot
.44144 .33899 Mdot
.67653 .5195 Mdot
.57062 .65212 Mdot
.42155 .52115 Mdot
.55212 .31738 Mdot
.57507 .36093 Mdot
.56341 .6789 Mdot
.74643 .57296 Mdot
.58695 .2365 Mdot
.37746 .51108 Mdot
.59519 .36471 Mdot
.70223 .47335 Mdot
.36125 .68953 Mdot
.65087 .46827 Mdot
.45222 .36312 Mdot
.55065 .34883 Mdot
.64519 .54154 Mdot
.55138 .61075 Mdot
.55593 .6862 Mdot
.59256 .71217 Mdot
.49629 .29133 Mdot
.56863 .37768 Mdot
.44752 .35143 Mdot
.67393 .7048 Mdot
.66473 .72707 Mdot
.44333 .37431 Mdot
.54962 .35088 Mdot
.5433 .65091 Mdot
.57527 .65844 Mdot
.57144 .66749 Mdot
.68809 .7418 Mdot
.55514 .70989 Mdot
.48089 .69889 Mdot
.33321 .56174 Mdot
.30273 .6327 Mdot
.38591 .59054 Mdot
.61818 .53334 Mdot
.57556 .70421 Mdot
.50229 .43414 Mdot
.41023 .5229 Mdot
.171 .51986 Mdot
.38583 .57214 Mdot
.66587 .47407 Mdot
.38747 .55012 Mdot
.37861 .67047 Mdot
.6068 .68122 Mdot
.37345 .55126 Mdot
.66176 .47999 Mdot
.42536 .35367 Mdot
.56483 .73259 Mdot
.36932 .52855 Mdot
.65534 .64872 Mdot
.3299 .60458 Mdot
.41232 .22306 Mdot
.41442 .42424 Mdot
.45907 .3671 Mdot
.35134 .62729 Mdot
.62267 .33529 Mdot
.52672 .71473 Mdot
.29298 .61265 Mdot
.6418 .49939 Mdot
.35652 .78328 Mdot
.57963 .35987 Mdot
.40812 .47076 Mdot
.33934 .51693 Mdot
.43304 .32893 Mdot
.51215 .67386 Mdot
.62215 .52911 Mdot
.42764 .57692 Mdot
.34225 .58901 Mdot
.36765 .29212 Mdot
.30357 .62461 Mdot
.36447 .61366 Mdot
.44349 .32561 Mdot
.4768 .72278 Mdot
.38712 .5379 Mdot
.59651 .39167 Mdot
.59975 .6991 Mdot
.38489 .62461 Mdot
.46375 .70946 Mdot
.37654 .57564 Mdot
.5517 .68009 Mdot
.56568 .71945 Mdot
.67956 .60431 Mdot
.45054 .37446 Mdot
.40089 .58484 Mdot
.40438 .40573 Mdot
.40919 .58531 Mdot
.62306 .4986 Mdot
.35337 .52705 Mdot
.57912 .35335 Mdot
.72211 .67494 Mdot
.60107 .33315 Mdot
.35583 .52738 Mdot
.57608 .66776 Mdot
.63325 .53446 Mdot
.45274 .29018 Mdot
.57393 .26246 Mdot
.48165 .70401 Mdot
.74117 .27442 Mdot
.45112 .34466 Mdot
.40956 .33482 Mdot
.61727 .47717 Mdot
.37594 .54807 Mdot
.45907 .40503 Mdot
.32696 .56637 Mdot
.38731 .54506 Mdot
.34709 .54603 Mdot
.60581 .47468 Mdot
.63479 .49307 Mdot
.56632 .33544 Mdot
.3622 .57028 Mdot
.37797 .57229 Mdot
.55513 .69566 Mdot
.42559 .35143 Mdot
.6051 .33648 Mdot
.42925 .34127 Mdot
.58566 .32964 Mdot
.18695 .34723 Mdot
.37322 .49322 Mdot
.42362 .35482 Mdot
.61951 .47515 Mdot
.54123 .66935 Mdot
.74599 .41101 Mdot
.60738 .35958 Mdot
.55874 .34974 Mdot
.38269 .57299 Mdot
.54267 .67467 Mdot
.54444 .69613 Mdot
.43049 .33448 Mdot
.64312 .52394 Mdot
.3569 .52725 Mdot
.37171 .51294 Mdot
.22792 .43165 Mdot
.58849 .38137 Mdot
.39373 .69732 Mdot
.68967 .61128 Mdot
.37495 .54708 Mdot
.57808 .70697 Mdot
.34954 .58009 Mdot
.26491 .30385 Mdot
.59871 .68998 Mdot
.39053 .51424 Mdot
.64622 .72663 Mdot
.56235 .38412 Mdot
.6403 .60607 Mdot
.34056 .60487 Mdot
.66752 .22217 Mdot
.41849 .56828 Mdot
.35967 .19109 Mdot
.79169 .49157 Mdot
.4051 .60324 Mdot
.41287 .54096 Mdot
.19344 .47954 Mdot
.37975 .5848 Mdot
.76121 .39181 Mdot
.31684 .51928 Mdot
.58146 .65122 Mdot
.45324 .43171 Mdot
.56355 .39991 Mdot
.44379 .37755 Mdot
.59313 .3503 Mdot
.46785 .31798 Mdot
.4135 .35726 Mdot
.58517 .67852 Mdot
.4092 .5333 Mdot
.29003 .49266 Mdot
.54404 .38367 Mdot
.32443 .54428 Mdot
.62142 .49867 Mdot
.58035 .40297 Mdot
.54367 .35651 Mdot
.63614 .51408 Mdot
.36239 .60575 Mdot
.24022 .62325 Mdot
.59655 .26445 Mdot
.56517 .18128 Mdot
.62785 .52997 Mdot
.61326 .503 Mdot
.71302 .69259 Mdot
.44065 .37884 Mdot
.32871 .31028 Mdot
.62549 .64349 Mdot
.60748 .5014 Mdot
.34565 .36607 Mdot
.5747 .31503 Mdot
.65201 .65482 Mdot
.59636 .64466 Mdot
.38697 .49325 Mdot
.35773 .53927 Mdot
.64743 .52102 Mdot
.2939 .49584 Mdot
.76077 .66982 Mdot
.63999 .50357 Mdot
.43944 .59562 Mdot
.5793 .47519 Mdot
.74706 .39304 Mdot
.74607 .3846 Mdot
.45964 .3619 Mdot
.56055 .22198 Mdot
.57002 .69412 Mdot
.4249 .33071 Mdot
.58694 .55409 Mdot
.40038 .57899 Mdot
.64616 .5065 Mdot
.74985 .41256 Mdot
.62175 .51525 Mdot
.42409 .36759 Mdot
.46343 .35662 Mdot
.57219 .70708 Mdot
.57435 .65069 Mdot
.4759 .81076 Mdot
.34029 .40525 Mdot
.3845 .59424 Mdot
.28376 .69975 Mdot
.53836 .68985 Mdot
.30585 .61706 Mdot
.42075 .38109 Mdot
.42256 .35113 Mdot
.34519 .72296 Mdot
.39235 .52401 Mdot
.51075 .37994 Mdot
.37822 .53051 Mdot
.31507 .34194 Mdot
.38003 .50867 Mdot
.5682 .34726 Mdot
.42079 .58242 Mdot
.64929 .34193 Mdot
.42217 .54498 Mdot
.3436 .57747 Mdot
.55312 .3335 Mdot
.42783 .50562 Mdot
.57819 .35497 Mdot
.36759 .51771 Mdot
.42015 .32328 Mdot
.59053 .34973 Mdot
.2554 .45863 Mdot
.5201 .52002 Mdot
.76504 .40206 Mdot
.41965 .37464 Mdot
.40752 .35277 Mdot
.29922 .47615 Mdot
.57444 .65381 Mdot
.60721 .64161 Mdot
.37689 .54878 Mdot
.58488 .3153 Mdot
.64199 .49195 Mdot
.37685 .57153 Mdot
.42303 .5161 Mdot
.35081 .6107 Mdot
.54497 .68951 Mdot
.56624 .37873 Mdot
.42592 .35917 Mdot
.59869 .35893 Mdot
.54748 .2377 Mdot
.55068 .32567 Mdot
.33449 .61674 Mdot
.43185 .51961 Mdot
.41128 .65114 Mdot
.35897 .77501 Mdot
.62191 .76386 Mdot
.56109 .68449 Mdot
.75031 .40432 Mdot
.46332 .34965 Mdot
.51114 .70824 Mdot
.55755 .65288 Mdot
.55568 .35485 Mdot
.37796 .5386 Mdot
.44876 .56658 Mdot
.58168 .58 Mdot
.50856 .68588 Mdot
.29167 .46933 Mdot
.54172 .34151 Mdot
.75401 .39204 Mdot
.7047 .68438 Mdot
.52453 .72277 Mdot
.4961 .42626 Mdot
.34641 .56115 Mdot
.40951 .37149 Mdot
.53778 .6575 Mdot
.49427 .30529 Mdot
.64858 .51444 Mdot
.52609 .45261 Mdot
.36332 .55955 Mdot
.73329 .54306 Mdot
.57602 .66874 Mdot
.41747 .36725 Mdot
.64834 .52015 Mdot
.44126 .38021 Mdot
.74792 .38266 Mdot
.57361 .21325 Mdot
.409 .57489 Mdot
.35263 .59082 Mdot
.61181 .47698 Mdot
.56981 .69194 Mdot
.48996 .37403 Mdot
.36204 .29137 Mdot
.58867 .36885 Mdot
.49622 .35723 Mdot
.54759 .64124 Mdot
.45583 .6521 Mdot
.60061 .35386 Mdot
.61428 .54198 Mdot
.46156 .42101 Mdot
.63885 .48155 Mdot
.37336 .52781 Mdot
.55801 .6612 Mdot
.6596 .50075 Mdot
.52687 .25938 Mdot
.27676 .26364 Mdot
.39582 .66185 Mdot
.40668 .59752 Mdot
.1761 .41201 Mdot
.4116 .20798 Mdot
.33085 .47108 Mdot
.61454 .48948 Mdot
.35835 .5827 Mdot
.36261 .5106 Mdot
.41539 .58508 Mdot
.65162 .48885 Mdot
.47748 .2348 Mdot
.56275 .35596 Mdot
.389 .57669 Mdot
.4108 .34647 Mdot
.57816 .34537 Mdot
.61606 .30244 Mdot
.5912 .31839 Mdot
.58808 .65352 Mdot
.39421 .51674 Mdot
.69422 .65501 Mdot
.3321 .19722 Mdot
.63652 .49678 Mdot
.76507 .40158 Mdot
.35337 .59564 Mdot
.56623 .79788 Mdot
.54712 .66041 Mdot
.58583 .37065 Mdot
.35287 .56791 Mdot
.51284 .23897 Mdot
.729 .38304 Mdot
.56423 .32481 Mdot
.57615 .65736 Mdot
.34691 .4645 Mdot
.36968 .55901 Mdot
.41617 .56895 Mdot
.57679 .69089 Mdot
.59529 .22202 Mdot
.71915 .66854 Mdot
.34638 .57582 Mdot
.63472 .51134 Mdot
.82955 .62606 Mdot
.34579 .6065 Mdot
.52509 .62355 Mdot
.77019 .38894 Mdot
.66285 .63788 Mdot
.39299 .70068 Mdot
.32826 .61856 Mdot
.19294 .40523 Mdot
.38926 .43946 Mdot
.17014 .40307 Mdot
.43999 .39459 Mdot
.69019 .40232 Mdot
.19655 .32888 Mdot
.65994 .47722 Mdot
.31809 .64049 Mdot
.21199 .51881 Mdot
.73774 .59997 Mdot
.42922 .43859 Mdot
.7218 .28982 Mdot
.55636 .257 Mdot
.79601 .39469 Mdot
.59854 .32321 Mdot
.30082 .34573 Mdot
.35132 .53251 Mdot
.42413 .19885 Mdot
.38012 .68027 Mdot
.75573 .69323 Mdot
.18218 .38328 Mdot
.39875 .40375 Mdot
.19016 .54581 Mdot
.28733 .27293 Mdot
.2495 .60471 Mdot
.59123 .58472 Mdot
.78743 .36268 Mdot
.67448 .71008 Mdot
.37414 .30544 Mdot
.3533 .49315 Mdot
.6585 .33758 Mdot
.46552 .20733 Mdot
.50303 .75253 Mdot
.77914 .68202 Mdot
.61293 .34773 Mdot
.60372 .69092 Mdot
.22136 .43796 Mdot
.54385 .72598 Mdot
.64484 .44964 Mdot
.19158 .40688 Mdot
.35077 .20849 Mdot
.3826 .67099 Mdot
.69599 .23363 Mdot
.3809 .7621 Mdot
.50793 .84468 Mdot
.53484 .52318 Mdot
.59174 .71548 Mdot
.71883 .35711 Mdot
.66356 .72829 Mdot
.69935 .53046 Mdot
.49571 .67514 Mdot
.46175 .37346 Mdot
.27829 .45418 Mdot
.57861 .66499 Mdot
.37764 .69952 Mdot
.76328 .37759 Mdot
.61112 .5851 Mdot
.62209 .29967 Mdot
.24735 .31928 Mdot
.7397 .4221 Mdot
.66373 .66175 Mdot
.74386 .50727 Mdot
.1711 .59922 Mdot
.36451 .39008 Mdot
.31328 .26823 Mdot
.6281 .57326 Mdot
.40694 .4418 Mdot
.75315 .64102 Mdot
.34514 .41914 Mdot
.65551 .74062 Mdot
.22647 .67401 Mdot
.47404 .18371 Mdot
.1909 .60225 Mdot
.53633 .71486 Mdot
.36376 .6126 Mdot
.26431 .32571 Mdot
.48607 .80152 Mdot
.46109 .36562 Mdot
.17279 .55198 Mdot
.41131 .37687 Mdot
.54884 .72427 Mdot
.74484 .58352 Mdot
.45702 .66235 Mdot
.56227 .40928 Mdot
.40021 .33842 Mdot
.34256 .61725 Mdot
.46583 .88343 Mdot
.17399 .43685 Mdot
.67331 .61412 Mdot
.3702 .20827 Mdot
.60121 .55496 Mdot
.49863 .38669 Mdot
.64775 .48905 Mdot
.24377 .28685 Mdot
.56454 .65577 Mdot
.28109 .2272 Mdot
.27452 .25798 Mdot
.81724 .57534 Mdot
.58811 .89322 Mdot
.74819 .44929 Mdot
.30795 .64261 Mdot
.26039 .52555 Mdot
.25894 .49063 Mdot
.76346 .64826 Mdot
.82281 .55182 Mdot
.5827 .5272 Mdot
.56692 .20031 Mdot
.21016 .32634 Mdot
.33255 .35607 Mdot
.44159 .22719 Mdot
.74606 .60994 Mdot
.51762 .49986 Mdot
.537 .61912 Mdot
.50931 .52309 Mdot
.5574 .59184 Mdot
.18488 .57523 Mdot
.53796 .79267 Mdot
.77107 .72051 Mdot
.48379 .35184 Mdot
.83132 .49387 Mdot
.37262 .22528 Mdot
.25827 .44174 Mdot
.48658 .65654 Mdot
.71114 .63111 Mdot
.33491 .61476 Mdot
.70577 .67143 Mdot
.37388 .47063 Mdot
.44391 .30941 Mdot
.7042 .69314 Mdot
.67264 .44626 Mdot
.36062 .30483 Mdot
.20957 .41275 Mdot
.64348 .70849 Mdot
.59253 .66389 Mdot
.35162 .43497 Mdot
.35579 .37503 Mdot
.37158 .21296 Mdot
.79127 .55619 Mdot
.55344 .17884 Mdot
.80377 .55742 Mdot
.32726 .57053 Mdot
.30847 .62434 Mdot
.37235 .48411 Mdot
.35777 .40903 Mdot
.33156 .58412 Mdot
.73093 .52538 Mdot
.39273 .19975 Mdot
.52482 .80288 Mdot
.40147 .29657 Mdot
.31984 .74858 Mdot
.5258 .17943 Mdot
.26581 .33122 Mdot
.78753 .5006 Mdot
.2701 .58926 Mdot
.35516 .82408 Mdot
.57765 .33756 Mdot
.34132 .36682 Mdot
.64952 .54176 Mdot
.49376 .29558 Mdot
.21425 .56329 Mdot
.80886 .59168 Mdot
.39864 .19638 Mdot
.7176 .63745 Mdot
.57383 .27725 Mdot
.55966 .43409 Mdot
.58898 .40832 Mdot
.3066 .73687 Mdot
.44563 .54415 Mdot
.48381 .58738 Mdot
.41317 .33523 Mdot
.48548 .79022 Mdot
.28763 .32242 Mdot
.68439 .28471 Mdot
.37853 .64161 Mdot
.69091 .33114 Mdot
.75531 .38872 Mdot
.53251 .45658 Mdot
.13726 .42067 Mdot
.3081 .57751 Mdot
.76734 .46404 Mdot
.49002 .18114 Mdot
.45663 .41345 Mdot
.34368 .25649 Mdot
.71923 .58306 Mdot
.20758 .6302 Mdot
.31017 .22494 Mdot
.6139 .25738 Mdot
.16226 .42865 Mdot
.52957 .15144 Mdot
.23017 .66405 Mdot
.31314 .72717 Mdot
.67684 .49813 Mdot
.31215 .17387 Mdot
.56761 .36809 Mdot
.38868 .80452 Mdot
.49569 .80391 Mdot
.48864 .24789 Mdot
.53485 .63109 Mdot
.44717 .50625 Mdot
.78366 .40439 Mdot
.61175 .67425 Mdot
.34754 .62223 Mdot
.15777 .55694 Mdot
.24138 .70694 Mdot
.16449 .5615 Mdot
.54559 .19415 Mdot
.16431 .42125 Mdot
.21615 .49006 Mdot
.48281 .69626 Mdot
.26272 .36865 Mdot
.35863 .52261 Mdot
.31248 .38145 Mdot
.75432 .45572 Mdot
.57064 .27375 Mdot
.68087 .56039 Mdot
.54767 .63361 Mdot
.21123 .60854 Mdot
.1138 .46634 Mdot
.38374 .7459 Mdot
.44637 .72225 Mdot
.54705 .5773 Mdot
.3478 .39788 Mdot
.45341 .48182 Mdot
.66553 .30265 Mdot
.37375 .2183 Mdot
.2105 .51368 Mdot
.35191 .34322 Mdot
.71201 .30175 Mdot
.61055 .41426 Mdot
.82488 .48423 Mdot
.24685 .30882 Mdot
.23309 .45695 Mdot
.81602 .55329 Mdot
.26589 .59813 Mdot
.77947 .64768 Mdot
.64745 .25066 Mdot
.51096 .34667 Mdot
.36367 .36263 Mdot
.53946 .36377 Mdot
.32756 .36193 Mdot
.56754 .52418 Mdot
.22748 .41054 Mdot
.37534 .44272 Mdot
.3265 .35426 Mdot
.61364 .41135 Mdot
.15584 .50864 Mdot
.57971 .1647 Mdot
.29 .74902 Mdot
.64593 .21252 Mdot
.36772 .47109 Mdot
.33721 .5806 Mdot
.4392 .17916 Mdot
.14597 .50904 Mdot
.33655 .20058 Mdot
.73743 .53649 Mdot
.51785 .25724 Mdot
.66534 .47785 Mdot
.31086 .75815 Mdot
.66648 .24793 Mdot
.32973 .23041 Mdot
.62602 .75734 Mdot
.5954 .51474 Mdot
.72523 .64227 Mdot
.3395 .77239 Mdot
.24693 .61328 Mdot
.39045 .71484 Mdot
.36247 .49175 Mdot
.34329 .67427 Mdot
.59668 .7045 Mdot
.74949 .52713 Mdot
.34921 .41237 Mdot
.58301 .33853 Mdot
.23937 .46991 Mdot
.48388 .60586 Mdot
.33271 .61227 Mdot
.52526 .32134 Mdot
.57004 .62091 Mdot
.39319 .79577 Mdot
.58206 .51156 Mdot
.18148 .34654 Mdot
.76139 .48007 Mdot
.44516 .48442 Mdot
.37809 .4273 Mdot
.49435 .31679 Mdot
.70702 .65882 Mdot
.62665 .47641 Mdot
.20214 .35371 Mdot
.49244 .50347 Mdot
.35836 .43236 Mdot
.34641 .67738 Mdot
.34773 .29398 Mdot
.41878 .51134 Mdot
.69764 .5912 Mdot
.51945 .7462 Mdot
.52932 .44787 Mdot
.58101 .73008 Mdot
.57822 .62325 Mdot
.77172 .27563 Mdot
.6453 .38971 Mdot
.80261 .52724 Mdot
.20804 .35045 Mdot
.63871 .48367 Mdot
.53267 .64201 Mdot
.31525 .36247 Mdot
.37487 .27513 Mdot
.52544 .76488 Mdot
.58938 .30468 Mdot
.37672 .34622 Mdot
.67074 .2683 Mdot
.17794 .41274 Mdot
.17682 .4982 Mdot
.74584 .71891 Mdot
.52776 .67981 Mdot
.3349 .29274 Mdot
.37396 .28435 Mdot
.5304 .67513 Mdot
.50623 .66974 Mdot
.59543 .5931 Mdot
.15457 .41345 Mdot
.69807 .66969 Mdot
.62456 .21019 Mdot
.45857 .41964 Mdot
.49863 .23436 Mdot
.47767 .30533 Mdot
.36996 .33849 Mdot
.21238 .34804 Mdot
.36739 .70165 Mdot
.22757 .59525 Mdot
.34605 .49461 Mdot
.49202 .81979 Mdot
.31701 .76456 Mdot
.53087 .50816 Mdot
.44673 .65406 Mdot
.67558 .45263 Mdot
.4079 .59151 Mdot
.16968 .59677 Mdot
.40997 .21682 Mdot
.69009 .71905 Mdot
.58303 .49948 Mdot
.40734 .54807 Mdot
.33318 .54316 Mdot
.29584 .49657 Mdot
.67281 .62645 Mdot
.26653 .7207 Mdot
.37862 .29735 Mdot
.33636 .48071 Mdot
.36437 .68232 Mdot
.76833 .46626 Mdot
.2467 .32607 Mdot
.39159 .22346 Mdot
.55925 .49912 Mdot
.75459 .46006 Mdot
.51162 .41595 Mdot
.61562 .20094 Mdot
.67628 .34208 Mdot
.21574 .47682 Mdot
.63232 .68534 Mdot
.69338 .62573 Mdot
.50206 .3126 Mdot
.34677 .58785 Mdot
.74593 .57341 Mdot
.27745 .28343 Mdot
.74088 .75321 Mdot
.76183 .63033 Mdot
.14932 .55132 Mdot
.44493 .6402 Mdot
.6937 .63369 Mdot
.2167 .58863 Mdot
.70957 .79104 Mdot
.66209 .31768 Mdot
.1873 .55706 Mdot
.54173 .42692 Mdot
.1935 .36903 Mdot
.66747 .52218 Mdot
.66091 .69438 Mdot
.32942 .75385 Mdot
.15745 .40694 Mdot
.29216 .29683 Mdot
.2198 .34933 Mdot
.26058 .58436 Mdot
.14829 .44046 Mdot
.61243 .75693 Mdot
.79927 .39449 Mdot
.61095 .37229 Mdot
.72728 .50619 Mdot
.28111 .67092 Mdot
.51537 .60889 Mdot
.34665 .35863 Mdot
.82131 .44571 Mdot
.52689 .73561 Mdot
.26076 .63255 Mdot
.27536 .40759 Mdot
.70903 .59632 Mdot
.38344 .42842 Mdot
.30979 .24208 Mdot
.80004 .3862 Mdot
.44843 .29169 Mdot
.78325 .52354 Mdot
.57368 .21114 Mdot
.6689 .62464 Mdot
.66711 .39464 Mdot
.31056 .26907 Mdot
.62544 .23504 Mdot
.3874 .39948 Mdot
.79068 .27383 Mdot
.47761 .21136 Mdot
.59065 .5884 Mdot
.20159 .60275 Mdot
.38283 .21888 Mdot
.60479 .76021 Mdot
.74902 .69235 Mdot
.47965 .8221 Mdot
.31811 .40285 Mdot
.34921 .54236 Mdot
.1404 .45676 Mdot
.27989 .44228 Mdot
.17798 .56504 Mdot
.48496 .16868 Mdot
.32119 .6698 Mdot
.31996 .59704 Mdot
.60765 .31612 Mdot
.54922 .55598 Mdot
.27348 .40043 Mdot
.19742 .53994 Mdot
.45045 .82302 Mdot
.49712 .35422 Mdot
.69482 .38545 Mdot
.57704 .30588 Mdot
.29453 .52825 Mdot
.74112 .45788 Mdot
.69111 .61478 Mdot
.48242 .34143 Mdot
.63372 .39467 Mdot
.34897 .38642 Mdot
.39011 .69775 Mdot
.24518 .61031 Mdot
.79386 .61114 Mdot
.6566 .4492 Mdot
.61636 .33972 Mdot
.19533 .45476 Mdot
.49239 .20557 Mdot
.72561 .53253 Mdot
.2487 .67498 Mdot
.71555 .62678 Mdot
.28839 .35784 Mdot
.25728 .35812 Mdot
.77276 .63609 Mdot
.7857 .34865 Mdot
.2599 .66882 Mdot
.49464 .82018 Mdot
.51684 .38401 Mdot
.45804 .61628 Mdot
.18689 .34895 Mdot
.36635 .34731 Mdot
.23762 .38786 Mdot
.52557 .52723 Mdot
.49426 .77556 Mdot
.2918 .6615 Mdot
.24789 .47928 Mdot
.51034 .42984 Mdot
.42243 .85999 Mdot
.55983 .62659 Mdot
.17144 .60459 Mdot
.63691 .52017 Mdot
.65878 .77327 Mdot
.63863 .35924 Mdot
.55508 .51684 Mdot
.48164 .42864 Mdot
.69292 .59274 Mdot
.61529 .60281 Mdot
.55582 .19645 Mdot
.79423 .6274 Mdot
.55309 .32395 Mdot
.43014 .41284 Mdot
.63063 .22097 Mdot
.19184 .43785 Mdot
.42473 .594 Mdot
.50982 .20984 Mdot
.52736 .50479 Mdot
.56277 .278 Mdot
.44164 .18087 Mdot
.6948 .47467 Mdot
.4233 .61441 Mdot
.34706 .40137 Mdot
.19285 .56727 Mdot
.28888 .24829 Mdot
.73148 .69634 Mdot
.37219 .47098 Mdot
.67801 .49314 Mdot
.22533 .52688 Mdot
.18284 .42679 Mdot
.52368 .40199 Mdot
.67061 .67157 Mdot
.3614 .38052 Mdot
.18695 .66971 Mdot
.23466 .6932 Mdot
.27137 .72314 Mdot
.45213 .41255 Mdot
.60427 .71535 Mdot
.55655 .79775 Mdot
.24209 .38281 Mdot
.71488 .52369 Mdot
.4761 .19993 Mdot
.34461 .37104 Mdot
.67461 .80024 Mdot
.49206 .68096 Mdot
.54786 .23577 Mdot
.29427 .66762 Mdot
.46422 .79834 Mdot
.67234 .50055 Mdot
.30413 .40853 Mdot
.46574 .48261 Mdot
.60531 .49258 Mdot
.70525 .60039 Mdot
.64914 .64313 Mdot
.23496 .39133 Mdot
.50966 .74549 Mdot
.34117 .48254 Mdot
.20634 .40724 Mdot
.6134 .69711 Mdot
.489 .30443 Mdot
.45922 .30041 Mdot
.44146 .44781 Mdot
.5866 .3663 Mdot
.31438 .60877 Mdot
.54784 .45322 Mdot
.52871 .42719 Mdot
.38344 .81625 Mdot
.40647 .37103 Mdot
.57575 .63772 Mdot
.66127 .75518 Mdot
.52899 .66765 Mdot
.13717 .50412 Mdot
.66585 .30618 Mdot
.35973 .67844 Mdot
.60355 .25337 Mdot
.71521 .33198 Mdot
.52214 .85685 Mdot
.28335 .71265 Mdot
.52228 .55188 Mdot
.50436 .68683 Mdot
.54357 .70495 Mdot
.56093 .40574 Mdot
.78278 .39538 Mdot
.40655 .71469 Mdot
.76768 .45201 Mdot
.27542 .35729 Mdot
.57543 .7212 Mdot
.52121 .22859 Mdot
.44042 .47847 Mdot
.1575 .38815 Mdot
.60755 .32779 Mdot
.31233 .79176 Mdot
.42379 .50516 Mdot
.22471 .57082 Mdot
.42901 .1809 Mdot
.72809 .67306 Mdot
.52254 .31675 Mdot
.74689 .29966 Mdot
.41034 .60254 Mdot
.33133 .49087 Mdot
.58119 .6655 Mdot
.31245 .32126 Mdot
.43574 .35372 Mdot
.31143 .45225 Mdot
.59828 .51123 Mdot
.82687 .52974 Mdot
.74515 .46695 Mdot
.60596 .668 Mdot
.48797 .51429 Mdot
.28951 .30851 Mdot
.64464 .66398 Mdot
.52607 .50205 Mdot
.19384 .47498 Mdot
.51942 .76358 Mdot
.57037 .72075 Mdot
.25201 .68459 Mdot
.37051 .29536 Mdot
.25676 .26734 Mdot
.46781 .55007 Mdot
.54382 .53808 Mdot
.64463 .68315 Mdot
.70673 .58543 Mdot
.40028 .70454 Mdot
.37022 .22072 Mdot
.34965 .4284 Mdot
.66129 .72059 Mdot
.32455 .35665 Mdot
.4254 .4949 Mdot
.69078 .3886 Mdot
.72892 .48517 Mdot
.64625 .81312 Mdot
.34259 .73768 Mdot
.73992 .64992 Mdot
.50155 .63269 Mdot
.76587 .46279 Mdot
.57217 .63386 Mdot
.45131 .26634 Mdot
.50812 .76044 Mdot
.63791 .29432 Mdot
.21881 .3091 Mdot
.37734 .21357 Mdot
.57039 .58537 Mdot
.57257 .29693 Mdot
.38941 .44251 Mdot
.44355 .48538 Mdot
.51292 .45711 Mdot
.39929 .6079 Mdot
.28965 .5238 Mdot
.72527 .69707 Mdot
.71282 .55368 Mdot
.44312 .49948 Mdot
.1759 .37938 Mdot
.26982 .25484 Mdot
.15231 .46388 Mdot
.50816 .37247 Mdot
.57922 .6435 Mdot
.21198 .64211 Mdot
.43179 .69039 Mdot
.3091 .24059 Mdot
.28762 .68563 Mdot
.75104 .25497 Mdot
.20888 .56327 Mdot
.66444 .44433 Mdot
.8203 .56724 Mdot
.64193 .59018 Mdot
.44753 .18412 Mdot
.79992 .39249 Mdot
.39064 .30945 Mdot
.45712 .18074 Mdot
.4618 .88085 Mdot
.32759 .73605 Mdot
.65804 .65526 Mdot
.28373 .63126 Mdot
.41689 .45191 Mdot
.77131 .4421 Mdot
.34851 .53132 Mdot
.54868 .3826 Mdot
.5333 .30273 Mdot
.35 .37918 Mdot
.42812 .64165 Mdot
.77755 .44492 Mdot
.27286 .3958 Mdot
.30801 .33776 Mdot
.3858 .28025 Mdot
.20269 .54343 Mdot
.41142 .71064 Mdot
.41609 .62074 Mdot
.59434 .73037 Mdot
.45735 .36368 Mdot
.45245 .30817 Mdot
.3842 .51416 Mdot
.53864 .30164 Mdot
.62075 .62826 Mdot
.15576 .56067 Mdot
.42556 .27423 Mdot
.38541 .25368 Mdot
.59688 .63962 Mdot
.68156 .61626 Mdot
.24418 .34724 Mdot
.73984 .594 Mdot
.79178 .45023 Mdot
.53446 .79402 Mdot
.17396 .41953 Mdot
.70617 .6391 Mdot
.34738 .3253 Mdot
.45668 .84565 Mdot
.6073 .52045 Mdot
.39733 .794 Mdot
.21111 .50088 Mdot
.72692 .6023 Mdot
.54085 .71654 Mdot
.65728 .43323 Mdot
.69642 .40548 Mdot
.71999 .59988 Mdot
.49476 .18016 Mdot
.31514 .30632 Mdot
.30924 .67774 Mdot
.17549 .47759 Mdot
.59177 .38413 Mdot
.3499 .34498 Mdot
.63922 .41781 Mdot
.76841 .43152 Mdot
.64778 .70369 Mdot
.17894 .36067 Mdot
.50763 .44794 Mdot
.27125 .454 Mdot
.41277 .57541 Mdot
.46751 .71252 Mdot
.70352 .57119 Mdot
.612 .41795 Mdot
.79535 .53884 Mdot
.59732 .67844 Mdot
.75024 .49492 Mdot
.76525 .36911 Mdot
.30696 .41916 Mdot
.49094 .59296 Mdot
.62716 .69212 Mdot
.41345 .39182 Mdot
.73561 .38302 Mdot
.43509 .583 Mdot
.2728 .4687 Mdot
.5833 .41284 Mdot
.36329 .77204 Mdot
.32339 .73738 Mdot
.19361 .45823 Mdot
.40857 .22934 Mdot
.72259 .53074 Mdot
.283 .68447 Mdot
.61496 .59731 Mdot
.47888 .67416 Mdot
.76009 .57361 Mdot
.34022 .6058 Mdot
.45482 .26429 Mdot
.546 .63822 Mdot
.18766 .44843 Mdot
.47002 .63543 Mdot
.25596 .45559 Mdot
.54186 .48111 Mdot
.25894 .3254 Mdot
.50418 .48746 Mdot
.4314 .18186 Mdot
.64558 .58808 Mdot
.34825 .41404 Mdot
.59044 .52439 Mdot
.5437 .42507 Mdot
.76853 .62561 Mdot
.23878 .3043 Mdot
.79951 .60739 Mdot
.26246 .52642 Mdot
.73555 .64373 Mdot
.50945 .81704 Mdot
.47018 .17313 Mdot
.33279 .41329 Mdot
.51416 .45888 Mdot
.45161 .48303 Mdot
.60187 .5769 Mdot
.74868 .41067 Mdot
.47547 .26451 Mdot
.42547 .70353 Mdot
.42292 .24967 Mdot
.618 .28322 Mdot
.41561 .60951 Mdot
.5718 .79699 Mdot
.17634 .45579 Mdot
.54211 .74335 Mdot
.54713 .51505 Mdot
.52369 .29342 Mdot
.30344 .42812 Mdot
.88176 .44588 Mdot
.16783 .59482 Mdot
.41184 .57439 Mdot
.45804 .42587 Mdot
.30981 .4475 Mdot
.54829 .36472 Mdot
.41088 .721 Mdot
.19218 .45626 Mdot
.61205 .49973 Mdot
.51084 .26557 Mdot
.71299 .47662 Mdot
.69169 .58734 Mdot
.24186 .48301 Mdot
.60857 .47354 Mdot
.14187 .52631 Mdot
.51677 .20434 Mdot
.71188 .56658 Mdot
.83574 .3585 Mdot
.7388 .52593 Mdot
.61804 .67722 Mdot
.28793 .29433 Mdot
.15495 .50328 Mdot
.45327 .41401 Mdot
.49596 .2918 Mdot
.32884 .74389 Mdot
.34687 .4203 Mdot
.32399 .33098 Mdot
.78223 .52247 Mdot
.75788 .50329 Mdot
.79268 .41016 Mdot
.7156 .32993 Mdot
.41199 .83204 Mdot
.35577 .69089 Mdot
.174 .50868 Mdot
.66315 .31085 Mdot
.68693 .7923 Mdot
.24326 .28764 Mdot
.30228 .38757 Mdot
.78564 .45826 Mdot
.30869 .27672 Mdot
.29787 .47103 Mdot
.56598 .78091 Mdot
.65506 .29761 Mdot
.526 .77678 Mdot
.70352 .32632 Mdot
.77305 .56858 Mdot
.32695 .35883 Mdot
.48207 .80625 Mdot
.50592 .44261 Mdot
.19821 .51447 Mdot
.83762 .4742 Mdot
.37912 .42075 Mdot
.5227 .26825 Mdot
.26171 .50559 Mdot
.19605 .41631 Mdot
.30036 .27058 Mdot
.49927 .45275 Mdot
.46409 .87788 Mdot
.18554 .57095 Mdot
.74725 .59597 Mdot
.33336 .56628 Mdot
.21791 .30356 Mdot
.47153 .45411 Mdot
.28556 .69197 Mdot
.46682 .19243 Mdot
.4332 .29597 Mdot
.63875 .67735 Mdot
.35666 .61211 Mdot
.27681 .70318 Mdot
.4351 .65514 Mdot
.46138 .80016 Mdot
.51892 .3157 Mdot
.37376 .42732 Mdot
.83606 .48826 Mdot
.24534 .51099 Mdot
.44444 .48918 Mdot
.54825 .64002 Mdot
.15188 .53423 Mdot
.2511 .58998 Mdot
.31079 .60843 Mdot
.29308 .6252 Mdot
.79747 .61613 Mdot
.78449 .32367 Mdot
.41486 .48147 Mdot
.70283 .65978 Mdot
.34793 .36068 Mdot
.26146 .36216 Mdot
.30137 .72334 Mdot
.60795 .89066 Mdot
.41815 .18342 Mdot
.53948 .62434 Mdot
.40028 .78933 Mdot
.42313 .42054 Mdot
.15541 .4642 Mdot
.70828 .2975 Mdot
.48572 .3144 Mdot
.80023 .64149 Mdot
.34004 .44787 Mdot
.39609 .50761 Mdot
.53148 .1882 Mdot
.24427 .29263 Mdot
.84264 .49479 Mdot
.18954 .34672 Mdot
.3172 .57853 Mdot
.36924 .4957 Mdot
.83559 .66313 Mdot
.18681 .39261 Mdot
.31988 .60213 Mdot
.78261 .64932 Mdot
.51878 .64114 Mdot
.36182 .52431 Mdot
.71055 .42533 Mdot
.36783 .36493 Mdot
.31459 .33744 Mdot
.15729 .40904 Mdot
.60596 .70821 Mdot
.54342 .29714 Mdot
.6458 .54155 Mdot
.48842 .42816 Mdot
.44691 .57213 Mdot
.66048 .50018 Mdot
.29611 .35599 Mdot
.46169 .44828 Mdot
.59081 .47252 Mdot
.37551 .36727 Mdot
.59412 .17711 Mdot
.41952 .65112 Mdot
.56433 .58247 Mdot
.26593 .57182 Mdot
.53936 .74667 Mdot
.27402 .39712 Mdot
.25979 .39164 Mdot
.46948 .18217 Mdot
.54538 .13525 Mdot
.62775 .37717 Mdot
.45818 .53201 Mdot
.59043 .74107 Mdot
.41227 .70185 Mdot
.29648 .65145 Mdot
.61702 .4366 Mdot
.73898 .39721 Mdot
.32201 .58949 Mdot
.44902 .49192 Mdot
.59845 .51393 Mdot
.16416 .62322 Mdot
.34172 .53984 Mdot
.35175 .70837 Mdot
.28893 .26468 Mdot
.49272 .30584 Mdot
.39519 .65691 Mdot
.41844 .59604 Mdot
.6097 .75763 Mdot
.46497 .45489 Mdot
.36973 .45492 Mdot
.46648 .30163 Mdot
.16228 .46242 Mdot
.46894 .63438 Mdot
.32939 .68752 Mdot
.38454 .56913 Mdot
.40545 .33414 Mdot
.65188 .65845 Mdot
.276 .71694 Mdot
.4858 .57279 Mdot
.30558 .23827 Mdot
.43003 .29325 Mdot
.38432 .29612 Mdot
.32329 .65174 Mdot
.17597 .56662 Mdot
.7592 .62696 Mdot
.31953 .66401 Mdot
.70389 .71348 Mdot
.6667 .41092 Mdot
.27751 .40552 Mdot
.58868 .31064 Mdot
.44491 .5033 Mdot
.51245 .65853 Mdot
.13201 .44486 Mdot
.29145 .72543 Mdot
.64606 .55269 Mdot
.51551 .37736 Mdot
.46291 .6735 Mdot
.48697 .43205 Mdot
.81738 .32402 Mdot
.71609 .28464 Mdot
.14267 .53102 Mdot
.3058 .31831 Mdot
.59704 .74052 Mdot
.71377 .593 Mdot
.33545 .63548 Mdot
.55877 .33294 Mdot
.15788 .46435 Mdot
.47132 .5412 Mdot
.76997 .55729 Mdot
.36222 .51777 Mdot
.67455 .7242 Mdot
.42646 .46155 Mdot
.55486 .30562 Mdot
.53535 .36221 Mdot
.75225 .67737 Mdot
.27086 .29378 Mdot
.46669 .45772 Mdot
.76328 .27761 Mdot
.19492 .54653 Mdot
.20356 .3514 Mdot
.58386 .30448 Mdot
.68517 .76414 Mdot
.49637 .63474 Mdot
.4288 .46603 Mdot
.60198 .54996 Mdot
.25192 .54783 Mdot
.7254 .59743 Mdot
.27495 .34844 Mdot
.63262 .61495 Mdot
.59175 .58207 Mdot
.68215 .16489 Mdot
.30742 .37603 Mdot
.49063 .64875 Mdot
.74777 .56163 Mdot
.19343 .3535 Mdot
.38564 .3404 Mdot
.56849 .18263 Mdot
.65299 .35611 Mdot
.44859 .54162 Mdot
.51163 .74191 Mdot
.23042 .57855 Mdot
.70481 .46336 Mdot
.47552 .86075 Mdot
.48023 .20428 Mdot
.38393 .30157 Mdot
.61704 .41832 Mdot
.52852 .6716 Mdot
.53332 .63229 Mdot
.65915 .26937 Mdot
.65465 .2001 Mdot
.38306 .46017 Mdot
.18233 .41974 Mdot
.56223 .84529 Mdot
.33514 .30677 Mdot
.15208 .44241 Mdot
.66849 .55819 Mdot
.50369 .66118 Mdot
.27359 .3897 Mdot
.49024 .36064 Mdot
.56098 .38054 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0TOooool2o`0000Kooooo0_l0002^ooooo`007?ooool00ol0003ooooooooo
o`2Aooooo`;o00001_ooool2o`000:kooooo000Looooo`03o`000?oooooooooo0:?ooooo0_l0002T
ooooo`007?ooool00ol0003oooooooooo`2Sooooo`;o0000Y?ooool001cooooo0_l0002/ooooo`;o
0000W?ooool001cooooo00?o0000ooooooooool0Zoooool2o`0009cooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0R?ooool2o`000;oooooo000Loooo
o`03o`000?oooooooooo08Sooooo0_l0002oooooo`007?ooool00ol0003oooooooooo`2hooooo`;o
0000Soooool001cooooo00?o0000ooooooooool0P?ooool2o`0003Kooooo0_l0002?ooooo`007?oo
ool00ol0003oooooooooo`20ooooo`;o0000aoooool001cooooo00?o0000ooooooooool0`oooool2
o`0008Cooooo000Looooo`03o`000?oooooooooo0<?ooooo0_l00024ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0:gooooo0_l0002Jooooo`007?oo
ool00ol0003oooooooooo`1hooooo`;o0000<oooool2o`0009[ooooo000Looooo`03o`000?oooooo
oooo07Sooooo0_l0003?ooooo`007?ooool00ol0003oooooooooo`1fooooo`;o0000dOooool001co
oooo00?o0000ooooooooool0M_ooool2o`000=7ooooo000Looooo`03o`000?oooooooooo077ooooo
0_l0003Fooooo`007?ooool2o`0007;ooooo0_l0000eooooo`;o0000Woooool001cooooo00?o0000
ooooooooool0Z?ooool2o`0009oooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0Joooool2o`000=cooooo000Looooo`03o`000?oooooooooo06_ooooo
0_l0001<ooooo`;o00007oooool2o`0006gooooo000Looooo`03o`000?oooooooooo08kooooo0_l0
000:ooooo`;o00007Oooool2o`0001oooooo0_l0001]ooooo`007?ooool00ol0003oooooooooo`1S
ooooo`;o0000:Oooool2o`0000[ooooo0_l00002ooooo`;o0000ZOooool001cooooo00?o0000oooo
ooooool0H_ooool3o`00033ooooo0_l00007ooooo`;o0000ZOooool001cooooo00?o0000oooooooo
ool0H_ooool2o`0001oooooo0_l00009ooooo`;o00001Oooool2o`0000cooooo0_l0000Hooooo`?o
0000ROooool001cooooo00?o0000ooooooooool0Poooool2o`0000?ooooo0_l000000ooooooo0000
o`000003o`000003ooooool0003o000000Sooooo1?l00004ooooo`;o00000_ooool2o`0000Oooooo
0_l000001?oooooo0000o`000?l00007ooooo`?o0000ROooool001cooooo00?o0000ooooooooool0
Q?ooool2o`0000;ooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000;ooooo
0ol00003ooooo`Co00000oooool2o`0000?ooooo0_l00003ooooo`;o00000_ooool2o`000003oooo
ool0003o000000;o00002Oooool2o`0000Gooooo0_l00020ooooo`007?ooool00ol0003ooooooooo
o`24ooooo`;o00000_ooool4o`0000;ooooo0_l00003ooooo`Go00002_ooool2o`0000Sooooo0_l0
0007ooooo`;o00002Oooool2o`000004ooooool0003o0000ooooo`Co00006_ooool2o`0006?ooooo
000Looooo`03o`000?oooooooooo08Wooooo0ol00007ooooo`;o00005?ooool2o`0001Sooooo0_l0
00000ooooooo0000o`000002o`000003ooooool0003o000001Oooooo0_l0001Sooooo`0000Kooooo
onk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0
LOooool2o`0000kooooo0_l0000@ooooo`?o00004oooool2o`0000?ooooo0_l00006ooooo`;o0000
0_ooool2o`0000oooooo1?l0001jooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o
8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0KOooool2o`00
00;ooooo0_l0000;ooooo`;o000000Coooooo`000?l0003ooooo0_l0000<ooooo`Co00005oooool8
o`000003ooooool0003o000000;ooooo0_l0000Aooooo`;o0000N_ooool00003ooooool@413ooooo
00;ooooo00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo
06Sooooo0_l00003ooooo`;o00000_ooool3o`0000Sooooo1?l00004ooooo`Co00002_ooool2o`00
00?ooooo0_l0000Dooooo`So00007?ooool2o`0007Kooooo00000ooooooo0000ooooo`02ooooo`03
o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0006Sooooo1_l00003ooooo`?o
00002?ooool2o`0000Sooooo0_l0000?ooooo`;o00006?ooool5o`0000kooooo0_l0000;ooooo`;o
00005?ooool2o`00063ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo
00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`1Zooooo`Co00002oooool2o`000003oooo
ool0003o000000Go00005Oooool2o`0000;ooooo0_l00006ooooo`;o00003?ooool4o`0000kooooo
0_l0000;ooooo`;o00005?ooool2o`00063ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oo
oooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1^ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000006o`0000oooooo0_l0
0003ooooo`;o00000_ooool4o`0000Cooooo0_l0000Hooooo`;o0000ROooool00006oooooomgMgOo
V9RHoooooonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000oooooooo
ool0KOooool3o`000004ooooool0003o0000ooooo`?o00000_ooool2o`0000Oooooo0_l0000?oooo
o`;o00000_ooool2o`0000Gooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00004?ooool2
o`0000Gooooo0_l00007ooooo`;o00003?ooool2o`0007;ooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo06_ooooo
1_l00003ooooo`Oo00007?ooool2o`0000Sooooo0ol000000ooooooo0000o`00000@ooooo`;o0000
3_ooool2o`0000Gooooo0_l00005ooooo`;o0000L_ooool001cooooo00?o0000ooooooooool0Gooo
ool2o`0000[ooooo0_l00002ooooo`;o00001?ooool4o`0000?ooooo0_l00003ooooo`;o0000;Ooo
ool2o`0000Gooooo0_l0000;ooooo`;o00002?ooool2o`0007Wooooo000Looooo`03o`000?oooooo
oooo05oooooo0_l0000?ooooo`;o00000oooool3o`000004ooooool0003o0000ooooo`;o00000ooo
ool2o`000003ooooool0003o000002[ooooo0_l0000:ooooo`;o00001_ooool2o`0000?ooooo0_l0
0005ooooo`;o00002Oooool2o`0006cooooo000Looooo`03o`000?oooooooooo073ooooo0_l00002
ooooo`?o00000_ooool4o`0000?ooooo1_l0000/ooooo`;o00002?ooool4o`0000Wooooo0_l00005
ooooo`;o00000oooool2o`0000Cooooo0_l0001/ooooo`007?ooool00ol0003oooooooooo`1Hoooo
o`;o00001oooool2o`00017ooooo0ol00004ooooo`;o000000?oooooo`000?l000001?l00008oooo
o`;o00009?ooool2o`0000[ooooo0_l0000Eooooo`Co00001?ooool2o`00013ooooo0_l0001Hoooo
o`007?ooool00ol0003oooooooooo`1Hooooo`;o00001oooool2o`0000Cooooo0_l00007ooooo`;o
00000oooool2o`0000Oooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00001?ooool2o`00
01Cooooo0_l00002ooooo`;o00005_ooool2o`0001Oooooo0_l00004ooooo`;o00004?ooool2o`00
05Sooooo000Looooo`03o`000?oooooooooo04Oooooo0_l0000Dooooo`;o00001?ooool2o`000004
ooooool0003o0000o`0000?ooooo0_l000001?oooooo0000o`000?l0000?ooooo`?o00000_ooool3
o`0001Oooooo1?l00002ooooo`;o00005_ooool4o`0001cooooo0_l0001Yooooo`007?ooool00ol0
003oooooooooo`17ooooo`;o00005?ooool2o`0000?ooooo0ol000000ooooooo0000o`000004oooo
o`;o000000?oooooo`000?l000005_ooool2o`0000kooooo0_l00005ooooo`Co00003?ooool2o`00
00_ooooo0_l00003ooooo`?o00001?ooool2o`0001;ooooo0_l000000ooooooo0000o`00001Yoooo
o`007?ooool00ol0003oooooooooo`1Pooooo`Co00003Oooool2o`0002Cooooo0_l00005ooooo`;o
00000oooool2o`0000Wooooo0_l00002ooooo`;o00001oooool2o`0000Cooooo0_l00004ooooo`;o
00004_ooool4o`0006[ooooo000Looooo`03o`000?oooooooooo063ooooo0ol0000>ooooo`;o0000
3oooool2o`0001gooooo1?l00009ooooo`;o00000_ooool2o`0002Wooooo0_l0001Zooooo`007?oo
ool00ol0003oooooooooo`1Qooooo`;o00006?ooool2o`0000?ooooo1?l0000Mooooo`;o00004_oo
ool2o`0002cooooo0_l0001Tooooo`007?ooool00ol0003oooooooooo`1Jooooo`;o00004_ooool4
o`000003ooooool0003o000000Cooooo1?l00002ooooo`Co00004_ooool2o`0000Cooooo0_l0000>
ooooo`;o00002?ooool3o`0001cooooo0ol000000ooooooo0000o`000009ooooo`;o0000I?ooool0
01cooooo0_l0001Kooooo`;o00001?ooool4o`0000[ooooo1?l000000ooooooo0000o`000004oooo
o`;o00001?ooool3o`0000Cooooo0_l0000=ooooo`;o00001?ooool2o`0000kooooo0ol00008oooo
o`;o00005oooool2o`0000?ooooo0ol000000ooooooo0000o`00001_ooooo`007?ooool00ol0003o
ooooooooo`1Dooooo`;o00002_ooool4o`0000?ooooo0_l0000=ooooo`;o000000?oooooo`000?l0
00002oooool2o`0002Cooooo1?l00007ooooo`?o00001_ooool2o`0000gooooo0_l00004ooooo`;o
00002?ooool2o`0000oooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`1Dooooo`?o0000
2_ooool2o`0000Cooooo0_l00003ooooo`;o00000oooool2o`0000?ooooo0_l000000ooooooo0000
o`000002o`0001Cooooo0_l00003ooooo`;o00003?ooool2o`0000Sooooo0_l000000ooooooo0000
o`000004ooooo`?o00001_ooool2o`0000;ooooo0_l0000Iooooo`;o00003oooool2o`0005Oooooo
000Looooo`03o`000?oooooooooo05Gooooo0_l00008ooooo`;o00002Oooool4o`0000?ooooo0_l0
0007ooooo`Co00004oooool2o`0000?ooooo0_l0000<ooooo`;o000000?oooooo`000?l000000_l0
0006ooooo`;o00000_ooool2o`0000gooooo0_l00023ooooo`007?ooool00ol0003oooooooooo`1F
ooooo`;o00000_ooool2o`0000?ooooo0_l00009ooooo`Co000000?oooooo`000?l000001_ooool2
o`0000;ooooo0ol00002ooooo`;o00003_ooool2o`0000Gooooo0_l0000>ooooo`Ko00000oooool2
o`0000?ooooo1?l00003ooooo`Co0000:?ooool2o`0005oooooo000Looooo`03o`000?oooooooooo
053ooooo0_l00004ooooo`;o00000_ooool3o`0001;ooooo0_l000000ooooooo0000o`000003oooo
o`;o00001Oooool4o`0000gooooo0ol00005ooooo`;o00002Oooool2o`0000Cooooo0_l000000ooo
oooo0000o`000003ooooo`;o00001Oooool3o`0000;ooooo1?l00009ooooo`;o00007Oooool2o`00
05oooooo000Looooo`03o`000?oooooooooo053ooooo0_l00009ooooo`;o000000Coooooo`000?l0
003ooooo0ol0000>ooooo`;o00001Oooool2o`0000?ooooo1?l00006ooooo`;o00001Oooool2o`00
017ooooo0_l00002ooooo`;o00000oooool2o`0000Kooooo0_l000000ooooooo0000o`000002o`00
00?ooooo0_l0000:ooooo`;o00001oooool2o`0000;ooooo0_l0001aooooo`007?ooool00ol0003o
ooooooooo`1Jooooo`;o00000_ooool2o`000004ooooool0003o0000o`0001Gooooo0_l00005oooo
o`;o00001_ooool2o`0001cooooo0_l00003ooooo`;o00001_ooool2o`000003ooooool0003o0000
00;ooooo0_l000001?oooooo0000o`000?l0000Booooo`;o00000_ooool2o`0001Kooooo0_l0000=
ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0E_ooool2o`0000;ooooo0_l00005oooo
o`;o000000Coooooo`000?l0003ooooo0_l00009ooooo`;o00000_ooool2o`0000kooooo0_l0000^
ooooo`;o00000_ooool2o`0000;ooooo0_l00007ooooo`;o00005Oooool2o`0000gooooo0ol00007
ooooo`;o00001?ooool2o`0004[ooooo000Looooo`03o`000?oooooooooo05Kooooo0_l00009oooo
o`;o000000Coooooo`000?l0003ooooo0_l00009ooooo`;o00000_ooool2o`0000kooooo0_l0000[
ooooo`;o00000_ooool2o`0000kooooo0_l0000Eooooo`;o00003Oooool2o`0000Gooooo0_l00000
0ooooooo0000o`00001@ooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00009Oooool2o`00
0003ooooool0003o000003Cooooo1_l000000ooooooo0000o`000009ooooo`;o00001_ooool2o`00
0003ooooool0003o000002;ooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o
000000?oooooo`000?l000006Oooool2o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l0
0000<oooool2o`000003ooooool0003o000000?ooooo0ol00008ooooo`;o00001_ooool2o`000003
ooooool0003o000000Wooooo0_l00008ooooo`Co0000H?ooool001cooooo00?o0000ooooooooool0
Boooool2o`0000Wooooo0_l0000Iooooo`;o00000oooool2o`00017ooooo0_l0000Tooooo`Go0000
1_ooool3o`0001kooooo0_l00008ooooo`Co000000?oooooo`000?l00000GOooool001cooooo00?o
0000ooooooooool0Boooool2o`0001Cooooo0_l0000?ooooo`Co00004oooool2o`0000?ooooo0ol0
000<ooooo`;o00003Oooool2o`000003ooooool0003o000000;o00002Oooool2o`0000Kooooo0_l0
000<ooooo`;o00004oooool2o`000003ooooool0003o000005gooooo000Looooo`03o`000?oooooo
oooo04cooooo0ol00005ooooo`Co00000_ooool2o`0000Gooooo0_l00006ooooo`;o00000_ooool2
o`0000?ooooo1Ol0000Aooooo`;o00001?ooool3o`0000cooooo0_l00007ooooo`;o00001?ooool2
o`0000kooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l0000Cooooo`;o0000H?ooool0
01cooooo00?o0000ooooooooool0C?ooool3o`000003ooooool0003o000000;ooooo1?l00002oooo
o`?o00002Oooool2o`000003ooooool0003o000000;ooooo0_l00006ooooo`Ko00001?ooool2o`00
00?ooooo0_l00002ooooo`?o00001_ooool2o`0000[ooooo0_l00007ooooo`;o00001Oooool2o`00
00?ooooo0_l00002ooooo`;o00002oooool4o`0000Cooooo0_l00004ooooo`;o00003oooool2o`00
00[ooooo0_l00005ooooo`;o00002oooool2o`0004Gooooo000Looooo`;o0000C_ooool2o`000003
ooooool0003o000000Wooooo0_l00009ooooo`;o00001?ooool2o`0000Wooooo1?l00004ooooo`;o
00000oooool2o`0000?ooooo0_l00006ooooo`;o000000?oooooo`000?l000001oooool2o`0000?o
oooo0_l00007ooooo`Co00000oooool2o`0000;ooooo0_l0000;ooooo`Go00002Oooool2o`0000oo
oooo0_l0000:ooooo`?o00001?ooool2o`0000_ooooo0_l00015ooooo`007?ooool00ol0003ooooo
ooooo`13ooooo`;o00001?ooool6o`0000?ooooo0_l0000Hooooo`;o00002_ooool3o`0000cooooo
0_l00003ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000
o`000005ooooo`;o00001Oooool4o`0000;ooooo0_l00008ooooo`Go00001_ooool6o`0000?ooooo
0_l00005ooooo`;o00003?ooool3o`0000[ooooo0ol0001Gooooo`007?ooool00ol0003ooooooooo
o`13ooooo`;o00001?ooool5o`0000Cooooo0_l0000:ooooo`;o00000oooool2o`0000Cooooo0_l0
0005ooooo`?o00000oooool4o`0000gooooo0_l00003ooooo`;o00002Oooool3o`000003ooooool0
003o000000;o00000oooool2o`0000Cooooo0ol00004ooooo`?o00001_ooool6o`0000Kooooo0ol0
00000ooooooo0000o`000003ooooo`;o00001Oooool2o`0000?ooooo0_l00008ooooo`;o00002ooo
ool2o`0005Oooooo000Looooo`03o`000?oooooooooo04?ooooo0_l00007ooooo`?o00002oooool2
o`0000;ooooo0_l00003ooooo`;o00000_ooool5o`0000Cooooo1?l00002ooooo`;o00000oooool2
o`0000oooooo0_l000000ooooooo0000o`000006ooooo`;o00000oooool3o`0000Wooooo0_l00006
ooooo`;o00001_ooool2o`000003ooooool0003o000000Cooooo0_l00003ooooo`;o00000oooool2
o`0000Gooooo1?l00003ooooo`;o0000K_ooool001cooooo00?o0000ooooooooool0@oooool2o`00
00Oooooo0ol0000;ooooo`;o00002Oooool4o`000003ooooool0003o000000Kooooo0_l00007oooo
o`?o00003?ooool7o`0000kooooo0_l0000?ooooo`Co00001_ooool3o`0000?ooooo0ol00003oooo
o`;o00000oooool2o`0000Cooooo1Ol00003ooooo`;o0000K_ooool001cooooo00?o0000oooooooo
ool0A_ooool2o`0000gooooo0_l0000>ooooo`;o00002oooool2o`0000Sooooo0_l000000ooooooo
0000o`000007ooooo`Co00000_ooool2o`0000Sooooo1?l000000ooooooo0000o`000002o`0000Co
oooo0ol00008ooooo`Co00000oooool5o`0000;ooooo1_l000000ooooooo0000o`000004ooooo`;o
00001?ooool2o`0000Kooooo0_l0001^ooooo`007?ooool00ol0003oooooooooo`16ooooo`;o0000
1Oooool2o`0000Kooooo0_l00009ooooo`;o00007Oooool2o`0000Oooooo1?l00008ooooo`;o0000
0_ooool4o`000003ooooool0003o000000Kooooo0ol00007ooooo`Go000000?oooooo`000?l00000
4_l00008ooooo`Co0000M?ooool001cooooo00?o0000ooooooooool0B_ooool2o`000003ooooool0
003o000000_ooooo0ol00003ooooo`Co00003Oooool2o`0000;ooooo0_l00004ooooo`;o00001ooo
ool2o`0000Cooooo0_l00005ooooo`;o000000Coooooo`000?l0003o00002oooool2o`000003oooo
ool0003o000000;o00001?oooolHo`0000;ooooo0_l0000:ooooo`;o00008?ooool2o`0005;ooooo
000Looooo`03o`000?oooooooooo047ooooo0_l00007ooooo`Co00000_ooool4o`0000Kooooo0ol0
0005ooooo`;o00002Oooool6o`0000;ooooo0_l00004ooooo`;o00001oooool;o`0000;ooooo0_l0
0002ooooo`;o00002oooool2o`000003ooooool0003o000000;o000000Coooooo`000?l0003ooooo
6?l0000:ooooo`;o00000_ooool2o`0000cooooo0_l0000Booooo`;o00001?ooool2o`0000Wooooo
0_l00011ooooo`007?ooool00ol0003oooooooooo`0looooo`;o00000oooool2o`0000Wooooo0_l0
0002ooooo`Go00001_ooool2o`0000Cooooo0_l0000:ooooo`Co00004_ooool<o`0000;ooooo0_l0
00000ooooooo0000o`00000:ooooo`;o00002?ooool4o`000003ooooool0003o000001Wo00001Ooo
ool2o`000003ooooool0003o000000gooooo0_l0000Hooooo`;o00002Oooool2o`00047ooooo000L
ooooo`03o`000?oooooooooo03cooooo0_l0000:ooooo`;o00001_ooool2o`000003ooooool0003o
000000Kooooo0_l00004ooooo`;o00000oooool3o`0001Gooooo0_l00002oooooa7o000000?ooooo
o`000?l000002_ooool2o`000003ooooool0003o000000Gooooo5_l000000ooooooo0000o`000007
o`000003ooooool0003o000000Gooooo0_l00009ooooo`;o00001_ooool2o`0001;ooooo0_l0001>
ooooo`007?ooool00ol0003oooooooooo`18ooooo`;o00001_ooool2o`000004ooooool0003o0000
ooooo`;o00003_ooool3o`0000kooooo0_l00005oooooaGo00004?ooool2o`0000Gooooo0_l00000
0ooooooo0000o`00000No`0000?ooooo0_l00007ooooo`;o00000_ooool2o`0000Kooooo1?l0000@
ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0D?ooool2o`0000Cooooo0_l00006oooo
o`So00003_ooool7o`0000?ooooo5Ol0000Eooooo`;o000000Coooooo`000?l0003ooooo7Ol00005
ooooo`Co00001Oooool2o`0000cooooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`13oooo
o`;o00000_ooool2o`0000Oooooo0_l00008ooooo`;o00000_ooool8o`0000kooooo0ol00002oooo
o`?o00000_oooolHo`0000?ooooo0_l0000;ooooo`Co000000?oooooo`000?l000000ol000000ooo
oooo0000o`000004o`000003ooooool0003o000000ko00002_ooool2o`0002Cooooo0ol0001>oooo
o`007?ooool00ol0003oooooooooo`0jooooo`;o00001oooool2o`0000;ooooo0_l0000Aooooo`;o
00001oooool2o`0000[ooooo0_l00004ooooo`;o00000oooool3o`0000;ooooo5ol00003ooooo`;o
00000oooool4o`0000Cooooo0ol00002ooooo`go00000oooool?o`0000Gooooo0_l00007ooooo`?o
00007Oooool3o`0004kooooo000Looooo`03o`000?oooooooooo03Oooooo1Ol0000@ooooo`;o0000
4?ooool2o`0000?ooooo0_l00009ooooo`?o00000_ooool6o`000004ooooool0003o0000o`0000;o
oooo5_l00009ooooo`Ko00001ooooolOo`0000Gooooo0_l00007ooooo`?o0000K_ooool001cooooo
0_l0000hooooo`Go00001?ooool3o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000
o`000008ooooo`;o00001_ooool2o`0000_ooooo0_l000000ooooooo0000o`000003ooooo`;o0000
0_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000Bo`000004ooooool0003o0000ooooo`;o
00001oooool2o`000003ooooool0003o000000Gooooo8?l0000booooo`;o0000C?ooool001cooooo
00?o0000ooooooooool0=oooool6o`000003ooooool0003o000000?o000000?oooooo`000?l00000
0oooool2o`0000_ooooo0_l0000Cooooo`;o00003_ooool2o`000003ooooool0003o000000go0000
00?oooooo`000?l000001Ol000000ooooooo0000o`000003o`0000Cooooo0_l000000ooooooo0000
o`000004ooooo`Go000000?oooooo`000?l000006Ol0000booooo`;o0000C?ooool001cooooo00?o
0000ooooooooool0=oooool2o`0000;ooooo1Ol0000Looooo`;o00002?ooool4o`0000kooooo0_l0
0004ooooo`Ko000000?oooooo`000?l000003_l00003ooooo`?o00000oooool2o`0000;ooooo0_l0
0003ooooob3o00002Oooool2o`0001Cooooo0_l0001Qooooo`007?ooool00ol0003oooooooooo`0m
ooooo`;o00004Oooool2o`0000Cooooo0_l00002ooooo`Co00001?ooool2o`0000;ooooo1?l00003
ooooo`;o00002Oooool2o`0000Kooooo5_l00007ooooo`?o00001oooool2o`000003ooooool0003o
000001_o00001Oooool2o`0000;ooooo0_l00007ooooo`;o00002oooool2o`0002Cooooo0_l0000k
ooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00006?ooool3o`0000?ooooo0_l00002oooo
o`;o00001_ooool3o`000004ooooool0003o0000o`0000Cooooo0_l00003ooooo`;o00002Oooool2
o`000003ooooool0003o000001Co00001Oooool4o`0000[ooooo3?l000000ooooooo0000o`00000?
o`0000Gooooo0_l0000;ooooo`;o00003?ooool2o`0001?ooooo0_l0000>ooooo`;o0000>oooool0
01cooooo00?o0000ooooooooool0=_ooool2o`000003ooooool0003o000001Kooooo0_l0000@oooo
o`;o00000_ooool2o`0000Cooooo0_l00003ooooo`Co00001OoooolIo`0000Oooooo0_l00006oooo
o`;o00001?oooolNo`00023ooooo0_l0000Cooooo`;o0000Boooool001cooooo00?o0000oooooooo
ool0>Oooool4o`0001?ooooo1Ol0000Fooooo`Co00001?ooool5o`0000?ooooo6Ol00007ooooo`;o
00001_ooool2o`0000Kooooo7?l0000^ooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0
>oooool2o`0001?ooooo1Ol0000Fooooo`Co00001Oooool4o`0000;ooooo5?l000000ooooooo0000
o`000003o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`0000Sooooo3ol000000ooooooo0000
o`000009o`000003ooooool0003o000001[ooooo0_l0000@ooooo`;o0000D_ooool001cooooo00?o
0000ooooooooool0AOooool2o`0001Sooooo0_l00004ooooo`Co00000oooool3o`000003ooooool0
003o000000Sooooo0_l00003oooooaGo00000_ooool2o`0000?ooooo1?l00002ooooo`;o00000_oo
ool2o`0000Cooooo0_l00002ooooo`Oo000000?oooooo`000?l000002Ol000000ooooooo0000o`00
0002ooooo`;o00006_ooool2o`0006Cooooo000Looooo`03o`000?oooooooooo04Cooooo0ol00007
ooooo`?o00000oooool2o`0000Wooooo0ol00003ooooo`Co00001oooool2o`0000;ooooo0_l0000;
oooooa3o000000?oooooo`000?l000001oooool2o`0000Oooooo1Ol00003ooooo`;o000000?ooooo
o`000?l000004_l00005ooooo`;o00009oooool7o`000003ooooool0003o000004kooooo000Loooo
o`03o`000?oooooooooo03Gooooo0_l0000=ooooo`;o00000oooool2o`0000?ooooo0ol00003oooo
o`;o00002_ooool4o`0000[ooooo0_l00002ooooo`Co00002ooooolAo`00013ooooo1?l000000ooo
oooo0000o`000003ooooo`ko000000?oooooo`000?l000001_l00005ooooo`;o00009?ooool=o`00
04kooooo000Looooo`03o`000?oooooooooo03Cooooo1Ol0000;ooooo`;o00000oooool4o`0001Go
oooo0_l0000:ooooo`?o000000?oooooo`000?l000003_ooool@o`0000Oooooo1?l00005ooooo`Co
00001ooooolDo`0002Sooooo1?l000000ooooooo0000o`000009o`00053ooooo000Looooo`03o`00
0?oooooooooo03Cooooo0_l000000ooooooo0000o`00000@ooooo`Co00001?ooool2o`0000_ooooo
0_l000000ooooooo0000o`00000;ooooo`?o00003?ooool2o`0000?ooooo1Ol000000ooooooo0000
o`000005o`0000Oooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000;o0000
0_ooool2o`000003ooooool0003o000000;ooooo1ol000000ooooooo0000o`000009o`000004oooo
ool0003o0000ooooo`;o000000?oooooo`000?l000003_ooool2o`0000Oooooo0_l00009oooooa3o
00001oooool2o`0000kooooo0_l0000gooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o0000
6?ooool2o`0000Kooooo0_l00002ooooo`;o00001oooool2o`000003ooooool0003o000000Cooooo
0_l00005ooooo`;o00000oooool2o`0000Sooooo0_l00003ooooo`;o000000Coooooo`000?l0003o
oooo0_l0000<ooooo`;o00000oooool2o`000003ooooool0003o000000;o00001Oooool2o`0000;o
oooo0_l00006ooooo`_o00001?ooool2o`000003ooooool0003o000000Oooooo0_l00005ooooo`;o
00001_ooool3o`0000cooooo3Ol00007ooooo`;o00003_ooool2o`0003Oooooo00001_ooooook^k^
oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0
003oooooooooo`0_ooooo`;o00001Oooool2o`000003ooooool0003o000000Wooooo0_l00003oooo
o`;o00001_ooool2o`0000;ooooo0_l0000@ooooo`Co00002?ooool2o`000003ooooool0003o0000
00Sooooo0_l000001?oooooo0000o`000?ooool2o`0000_ooooo0_l00006ooooo`;o000000?ooooo
o`000?l000001?ooool2o`0000kooooo3Ol00009ooooo`;o00000_ooool2o`0000gooooo0_l0000;
ooooo`oo00001oooool2o`0000kooooo0_l0000gooooo`0000KoooooogMgMonHV9SooooooiRHV?mg
MgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Kooooo0_l0
00000ooooooo0000o`000009ooooo`;o00000oooool2o`0000Kooooo0_l00002ooooo`;o00004_oo
ool6o`0000Kooooo0ol00008ooooo`Go000000?oooooo`000?l000000oooool2o`0000Kooooo0_l0
0009ooooo`;o00001?ooool2o`0000cooooo2?l000000ooooooo0000o`000004o`0000Wooooo0_l0
0009ooooo`;o00004OoooolDo`0000?ooooo0ol00017ooooo`0000?ooooooa0@4?ooool00_ooool0
0ol@413oooooooooo`09ooooo`Go00001_ooool00ol0003oooooooooo`1Eooooo`?o00003_ooool2
o`0000?ooooo1?l00006ooooo`;o00000oooool2o`0000Kooooo0_l00007ooooo`;o00002?ooool2
o`0001_ooooo0ol000000ooooooo0000o`000002ooooo`Co00003?ooool2o`0000Wooooo0_l00004
ooooo`;o00002oooool3o`000003ooooool0003o000000ko00000oooool3o`0004Oooooo00000ooo
oooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool3
o`0003Cooooo0_l000000ooooooo0000o`00000Looooo`Co00002oooool4o`0000Gooooo1?l00008
ooooo`Co00004oooool2o`0000?ooooo0ol00002ooooo`;o00002_ooool2o`0000Wooooo1?l00004
ooooo`?o00000oooool2o`0000Wooooo0_l0000;ooooo`;o00000_ooool3o`0000cooooo3ol0001@
ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGooooo
o`0000Oooooo00?o0000ooooooooool0;Oooool2o`0000Gooooo0_l000000ooooooo0000o`000002
ooooo`;o00001?ooool2o`0001;ooooo1?l0000;ooooo`;o000000?oooooo`000?l000000_ooool6
o`0000Sooooo1?l000000ooooooo0000o`000002o`0000Wooooo0_l00003ooooo`?o00000oooool2
o`000005ooooool0003o0000o`000?ooool00_l00007ooooo`;o00000oooool2o`0000Cooooo0ol0
0005ooooo`?o00000oooool2o`0000Sooooo0ol0000;ooooo`;o00000oooool4o`0000Cooooo0_l0
0004ooooo`oo00000_ooool2o`0004cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooo
oooo00[ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0]ooooo`Co00002_ooool2
o`0000;ooooo1?l00005ooooo`;o00002oooool3o`0000Oooooo0_l00006ooooo`;o00000_ooool3
o`0000;ooooo0_l0000<ooooo`Co00001oooool4o`0000;ooooo1?l00006ooooo`;o00000_ooool2
o`0000cooooo0_l00005ooooo`?o00001Oooool4o`0000Gooooo0_l00004ooooo`Co00004Oooool2
o`0000Cooooo0_l00004ooooo`ko00000oooool2o`0004cooooo00001_ooooooMgMgoiRHV?oooooo
V9RHogMgM`cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0_ooooo`;o00000_oo
ool2o`000003ooooool0003o000000?ooooo0_l000001?oooooo0000o`000?l00005ooooo`Co0000
3?ooool2o`0000Oooooo0_l0000;ooooo`Ko00001oooool2o`0000kooooo1?l00002ooooo`?o0000
0_ooool6o`0000?ooooo0_l0000Dooooo`;o00001oooool2o`0000Gooooo0ol00002ooooo`;o0000
00?oooooo`000?l000002?ooool2o`0001?ooooo3?l00008ooooo`;o0000BOooool00006ooooooo^
k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo02oo
oooo0_l00002ooooo`;o000000?oooooo`000?l000001_ooool4o`0000Cooooo0_l00009ooooo`;o
00005Oooool2o`0000?ooooo1?l00008ooooo`;o00003Oooool5o`0000;ooooo1?l000000ooooooo
0000o`000009o`0000kooooo0_l00005ooooo`;o00001?ooool2o`0000Oooooo0ol00002ooooo`;o
000000?oooooo`000?l000002?ooool2o`00017ooooo0_l00002ooooo`Ko00000_ooool2o`0000So
oooo0_l00019ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00000_ooool2o`000003oooo
ool0003o000000Cooooo0_l00002ooooo`;o00003oooool2o`00017ooooo0_l00002ooooo`Co0000
00?oooooo`000?l000000_l00009ooooo`;o00003?ooool4o`0000?ooooo1_l00004ooooo`Go0000
1?ooool2o`0000Wooooo0_l00004ooooo`?o00001?ooool2o`0000Oooooo1?l00005ooooo`;o0000
5oooool2o`000003ooooool0003o000000;ooooo0_l0001Kooooo`007?ooool00ol0003ooooooooo
o`0Yooooo`;o00001oooool5o`000003ooooool0003o000000;ooooo0_l00006ooooo`;o00003Ooo
ool2o`0000_ooooo0_l00002ooooo`;o00001?ooool7o`0000Kooooo0_l000000ooooooo0000o`00
0008ooooo`Co00002Oooool6o`0000?ooooo1?l00004ooooo`Co00000oooool2o`0000Sooooo0_l0
000>ooooo`Co00001Oooool2o`0001Oooooo0_l0001Rooooo`007?ooool00ol0003oooooooooo`0Y
ooooo`;o00001oooool5o`000003ooooool0003o000000[ooooo0_l0000<ooooo`?o00002oooool3
o`0000?ooooo0_l00004ooooo`Go00001_ooool2o`0000[ooooo1Ol00009ooooo`?o000000Cooooo
o`000?l0003o00000_ooool4o`000003ooooool0003o000000?ooooo0_l00003ooooo`;o0000@Ooo
ool2o`0005_ooooo000Looooo`03o`000?oooooooooo03?ooooo0_l00003ooooo`;o00002oooool2
o`0000_ooooo0_l000000ooooooo0000o`00000:ooooo`;o00000oooool2o`0000Oooooo0_l00005
ooooo`?o00002_ooool4o`0000;ooooo0_l00006ooooo`;o00000oooool2o`0000Gooooo1_l00000
0ooooooo0000o`000002ooooo`;o00000_ooool3o`0000gooooo0_l0000Uooooo`;o00001oooool2
o`0005_ooooo000Looooo`03o`000?oooooooooo02Oooooo0_l00008ooooo`;o00001Oooool2o`00
00_ooooo0_l0000>ooooo`;o00002?ooool4o`0000_ooooo0_l00006ooooo`Go00002Oooool3o`00
00;ooooo0_l00006ooooo`;o00001_ooool6o`000003ooooool0003o000000Co00000_ooool2o`00
00;ooooo0ol0000=ooooo`;o00009Oooool2o`0006Cooooo000Looooo`03o`000?oooooooooo02Oo
oooo0_l00008ooooo`;o00004oooool2o`0001?ooooo0_l000001?oooooo0000o`000?l0000=oooo
o`;o000000?oooooo`000?l000001_ooool2o`0000?ooooo0_l0000?ooooo`;o00000_ooool2o`00
00Cooooo1?l00002ooooo`Ko00003Oooool2o`0001kooooo0_l0000@ooooo`;o00004?ooool2o`00
057ooooo000Looooo`03o`000?oooooooooo02Kooooo0_l0000=ooooo`;o00003oooool2o`0001?o
oooo0_l000000ooooooo0000o`000002o`000004ooooool0003o0000o`0000Sooooo0_l000000ooo
oooo0000o`00000;ooooo`;o00003oooool2o`0000;ooooo0_l00005ooooo`?o00000_ooool2o`00
00;ooooo0_l0000=ooooo`;o00000oooool2o`0000cooooo0_l0000;ooooo`;o00002Oooool3o`00
00Cooooo0_l0000@ooooo`;o0000DOooool001cooooo00?o0000ooooooooool09_ooool2o`0000Go
oooo0_l00006ooooo`;o00001?ooool2o`0000Oooooo0_l0000Fooooo`;o00000_ooool2o`000004
ooooool0003o0000o`0000Kooooo1?l0000;ooooo`?o00002_ooool2o`00017ooooo0_l00002oooo
o`?o000000?oooooo`000?l000004_ooool2o`0000cooooo0_l0000Booooo`;o00000_ooool5o`00
06Oooooo000Looooo`03o`000?oooooooooo02cooooo1?l0000;ooooo`;o00001oooool2o`0000Ko
oooo0_l00002ooooo`;o00001Oooool2o`0000?ooooo1?l0000<ooooo`;o00002?ooool8o`0000;o
oooo0_l00006ooooo`;o00004Oooool8o`0003Kooooo0_l00005ooooo`;o00005Oooool2o`0001Wo
oooo0_l0000eooooo`007?ooool00ol0003oooooooooo`0Wooooo`;o00000oooool4o`0000_ooooo
0_l00006ooooo`;o00001oooool2o`0000;ooooo0_l00005ooooo`;o00000oooool4o`0000[ooooo
1?l00008ooooo`Oo00000oooool2o`0000_ooooo0_l0000>ooooo`;o000000Coooooo`000?l0003o
0000<Oooool2o`000003ooooool0003o000001cooooo2?l000000ooooooo0000o`000007ooooo`;o
00002Oooool2o`0000Oooooo0_l0000/ooooo`007?ooool00ol0003oooooooooo`0Wooooo`;o0000
4?ooool5o`0000Gooooo0_l00008ooooo`;o00003Oooool2o`0000?ooooo0_l00007ooooo`Co0000
0_ooool2o`0001[ooooo0ol000000ooooooo0000o`000002o`0000gooooo0_l00003ooooo`Co0000
5_ooool2o`0000cooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000001Ko
oooo0_l00004ooooo`;o00000_ooool4o`000003ooooool0003o000000Gooooo1?l0000Booooo`;o
0000;?ooool001cooooo0_l0000cooooo`;o00001Oooool2o`000003ooooool0003o000000Wooooo
0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l00005ooooo`;o000000?oooooo`000?l0
00000oooool2o`0000Kooooo1Ol00002ooooo`;o00004_ooool2o`0000Gooooo2Ol00002ooooo`;o
00002Oooool2o`0000?ooooo1?l0000Fooooo`;o00003?ooool2o`000003ooooool0003o000000Go
oooo0_l0000:ooooo`;o00002Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000co
oooo0_l0000dooooo`007?ooool00ol0003oooooooooo`0booooo`;o00002?ooool2o`0000Wooooo
0_l000001?oooooo0000o`000?ooool4o`000003ooooool0003o000000;o000000?oooooo`000?l0
00000_l00006ooooo`;o00001?ooool4o`0000Wooooo0_l0000>ooooo`;o00001Oooool2o`000003
ooooool0003o000000?ooooo1Ol00006ooooo`;o00001_ooool4o`0000Cooooo0_l00008ooooo`;o
00005?ooool2o`0000Sooooo0_l0000:ooooo`;o00002oooool2o`0000?ooooo0_l00005ooooo`Co
00004_ooool2o`0003Cooooo000Looooo`03o`000?oooooooooo02[ooooo0_l00004ooooo`;o0000
1?ooool2o`0000?ooooo0ol0000:ooooo`;o00001Oooool2o`0000?ooooo0_l000000ooooooo0000
o`00000>ooooo`Co00000oooool2o`0000Cooooo0_l0000Mooooo`Co00001?ooool2o`000003oooo
ool0003o000000;ooooo2Ol000000ooooooo0000o`000002o`0000;ooooo0_l00004ooooo`;o0000
2?ooool3o`0002Cooooo0_l00002ooooo`;o00000_ooool2o`0000Sooooo0_l00002ooooo`;o0000
0oooool2o`0000Cooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0Zooooo`;o00001?oo
ool2o`0000Cooooo0_l00003ooooo`;o00002oooool2o`0000Gooooo0_l0000Hooooo`;o00000ooo
ool2o`0000Wooooo0_l00006ooooo`;o00001?ooool2o`0000_ooooo0_l00005ooooo`;o00001Ooo
ool4o`000003ooooool0003o000000So000000Coooooo`000?l0003o00001?ooool3o`000003oooo
ool0003o000000?ooooo0ol0000Dooooo`;o00003_ooool3o`000003ooooool0003o000000;ooooo
0_l00003ooooo`;o00000oooool2o`0000Oooooo0_l00004ooooo`;o0000?Oooool001cooooo00?o
0000ooooooooool0;_ooool5o`0002Oooooo0_l00006ooooo`;o00001Oooool2o`0000;ooooo0_l0
000:ooooo`;o00001_ooool2o`0000Cooooo0_l00007ooooo`;o00004Oooool2o`0000;ooooo0_l0
00001?oooooo0000o`000?ooool4o`0000;ooooo0_l00004ooooo`?o000000?oooooo`000?l00000
6_ooool2o`0000?ooooo0_l000000ooooooo0000o`000007ooooo`;o00001Oooool2o`0000;ooooo
0ol0001Aooooo`007?ooool00ol0003oooooooooo`0Qooooo`;o00002oooool5o`0002Cooooo0_l0
00000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l0
000Iooooo`;o00001_ooool2o`0000_ooooo0_l0000Jooooo`;o00000_ooool2o`00013ooooo0_l0
000=ooooo`;o000000?oooooo`000?l000002oooool2o`0000Gooooo0ol0001Aooooo`007?ooool0
0ol0003oooooooooo`0Qooooo`;o00009oooool2o`0000Wooooo1?l00002ooooo`Ko000000?ooooo
o`000?l000000ol000000ooooooo0000o`00000:ooooo`Co00001?ooool4o`000003ooooool0003o
000000Gooooo0_l00006ooooo`Co00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000006
ooooo`;o00004_ooool2o`0000;ooooo0_l0000@ooooo`?o00000_ooool2o`0001Sooooo0_l00000
0ooooooo0000o`000003ooooo`;o0000DOooool001cooooo00?o0000ooooooooool0B_ooool2o`00
00Wooooo0_l00002ooooo`So000000?oooooo`000?l000000_l00002ooooo`;o00002_ooool4o`00
00Cooooo1?l000001?oooooo0000o`000?l0000>ooooo`;o00000_ooool2o`0000;ooooo0_l00004
ooooo`;o00000oooool3o`0000kooooo0_l00002ooooo`Co00001?ooool3o`000004ooooool0003o
0000ooooo`Co00000oooool2o`000003ooooool0003o000000?o00000_ooool2o`0000Cooooo0_l0
000?ooooo`;o00005oooool4o`0003_ooooo000Looooo`03o`000?oooooooooo03_ooooo0_l00005
ooooo`;o00004Oooool2o`0000;ooooo2?l000000ooooooo0000o`00000Booooo`;o00001oooool2
o`000003ooooool0003o000000Sooooo0_l0000Booooo`;o00000oooool3o`0000?ooooo0_l00009
ooooo`So00000oooool?o`0000;ooooo1_l00002ooooo`;o00000_ooool4o`0000;ooooo0_l0000T
ooooo`Co00001oooool2o`0003;ooooo000Looooo`03o`000?oooooooooo03Gooooo0_l00004oooo
o`;o00001Oooool2o`0000Cooooo0_l00002ooooo`?o00001_ooool2o`0000Cooooo1_l00002oooo
o`;o00001?ooool2o`0000Kooooo0_l00003ooooo`;o00001oooool2o`0000[ooooo0ol00005oooo
o`;o00005_ooool2o`0000[ooooo0ol00007oooooa3o000000?oooooo`000?l000000_l00008oooo
o`;o00001?ooool2o`0000kooooo0_l0000Dooooo`;o00002Oooool2o`0003;ooooo000Looooo`03
o`000?oooooooooo03Gooooo0_l00004ooooo`;o00002oooool2o`000003ooooool0003o000000;o
00003_ooool4o`0000;ooooo0_l00004ooooo`Ko00000_ooool2o`0000Wooooo0_l000000ooooooo
0000o`000004o`0000Kooooo0_l00002ooooo`?o000000Coooooo`000?l0003o00003oooool2o`00
00Gooooo0_l0000?ooooo`;o00000_ooool5o`000003ooooool0003o000000ko00007Oooool2o`00
05?ooooo000Looooo`03o`000?oooooooooo02Oooooo0_l0000Rooooo`;o00001_ooool2o`0000Oo
oooo0ol0000;ooooo`Go00001_ooool4o`0000?ooooo0_l000000ooooooo0000o`000005o`0000Ko
oooo1_l00002ooooo`;o00003Oooool4o`0000Gooooo0_l0000?ooooo`;o00000_ooool5o`000003
ooooool0003o000000ko00003?ooool2o`0000Cooooo0_l0000Mooooo`;o0000?oooool001cooooo
00?o0000ooooooooool09oooool2o`0002[ooooo0_l00007ooooo`?o00005_ooool5o`0000Sooooo
1?l00003ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`000003ooooool0003o000000_o
oooo0_l000000ooooooo0000o`00000Ooooooa7o00003_ooool2o`0000Cooooo0_l0000<ooooo`;o
00003Oooool4o`0000;ooooo0_l00007ooooo`;o00001Oooool2o`0002_ooooo000Looooo`03o`00
0?oooooooooo03;ooooo0_l0000?ooooo`;o00000_ooool2o`0000Oooooo0_l00008ooooo`;o0000
3?ooool2o`0000Sooooo0_l00002ooooo`Co00002_ooool2o`0000?ooooo0_l00002ooooo`Go0000
00?oooooo`000?l000001?ooool2o`0000Gooooo0_l00006ooooo`;o00005ooooolCo`000003oooo
ool0003o000000Kooooo0_l0000Hooooo`;o00001?ooool2o`0000Oooooo0_l00004ooooo`;o0000
1oooool2o`0000Gooooo0_l0000[ooooo`007?ooool00ol0003oooooooooo`0booooo`;o00003ooo
ool2o`0000;ooooo0_l00007ooooo`;o000000?oooooo`000?l000001?ooool3o`0000cooooo1?l0
00000ooooooo0000o`00000:o`000003ooooool0003o000000Kooooo1_l000000ooooooo0000o`00
0003ooooo`Co00001oooool2o`000004ooooool0003o0000ooooo`;o00001oooool2o`0000cooooo
0_l00007oooooaSo000000?oooooo`000?l000000oooool2o`0000Kooooo0_l00009ooooo`;o0000
2oooool2o`0000_ooooo0_l00002ooooo`;o0000>Oooool001cooooo00?o0000ooooooooool0=_oo
ool2o`0001_ooooo0_l00002ooooo`Co000000?oooooo`000?l000002oooool@o`000003ooooool0
003o000000Cooooo2?l000000ooooooo0000o`000003ooooo`;o00003?ooool2o`000003ooooool0
003o000001Gooooo0_l00002ooooo`;o00000ooooolLo`0000Wooooo0ol00009ooooo`;o00006?oo
ool2o`0000;ooooo0_l0000iooooo`007?ooool2o`0003Oooooo0_l00009ooooo`;o00004oooool3
o`0000?ooooo0_l0000>ooooo`;o00000_oooolFo`0000Kooooo0_l0000Fooooo`;o00003?ooool2
o`0000Cooooo1_l00002oooooa_o00002Oooool2o`0000gooooo0_l00007ooooo`;o000000?ooooo
o`000?l000002?ooool2o`0003kooooo000Looooo`03o`000?oooooooooo02Wooooo0_l00004oooo
o`;o00004?ooool2o`0001;ooooo0ol0000:ooooo`;o00002?ooool9o`0000Cooooo1ol000001?oo
oooo0000o`000?ooool5o`0000?ooooo0ol00002ooooo`;o00002Oooool2o`0000Cooooo1?l00000
1?oooooo0000o`000?l00005ooooo`;o000000?oooooo`000?l000001?ooool6o`0000;ooooo6Ol0
000Iooooo`?o00001oooool2o`000003ooooool0003o000000Sooooo1Ol0000kooooo`007?ooool0
0ol0003oooooooooo`0Yooooo`;o00001?ooool2o`0001oooooo0ol00002ooooo`?o00002_ooool2
o`0000?ooooo0ol00004ooooo`Ko00000oooool5o`000003ooooool0003o000000?o00000_ooool5
o`0000Cooooo0ol000000ooooooo0000o`000004ooooo`;o00000oooool2o`0000Cooooo0_l00003
ooooo`?o000000?oooooo`000?l000000_ooool2o`0000_ooooo6Ol00002ooooo`Co00003Oooool2
o`0000Cooooo0_l00002ooooo`;o00002?ooool2o`0000cooooo1?l0000kooooo`007?ooool00ol0
003oooooooooo`0/ooooo`;o000000?oooooo`000?l000001?ooool2o`0001Gooooo0_l00002oooo
o`?o00001?ooool3o`000003ooooool0003o000000[ooooo0ol000001?oooooo0000o`000?ooool6
o`0000;ooooo3Ol000000ooooooo0000o`000005o`0000?ooooo0_l00007ooooo`;o000000?ooooo
o`000?l000003Oooool4o`0000cooooo0_l00002oooooaWo000000?oooooo`000?l000000ol0000<
ooooo`;o00001?ooool2o`0000cooooo0_l00005ooooo`;o0000A?ooool001cooooo00?o0000oooo
ooooool0;?ooool2o`000003ooooool0003o000000Cooooo0_l0000:ooooo`Co00001oooool2o`00
00Gooooo0_l00002ooooo`?o000000?oooooo`000?l000003Oooool3o`0000Cooooo6_l0000?oooo
o`;o00002?ooool2o`0000?ooooo0_l0000>ooooo`;o00000ooooolEo`000003ooooool0003o0000
00?o000000?oooooo`000?l000001oooool2o`0000Wooooo0_l0000Cooooo`;o0000A?ooool001co
oooo00?o0000ooooooooool0>?ooool4o`000003ooooool0003o000000;ooooo1?l0000<ooooo`Co
00001oooool2o`0000Kooooo0_l00004oooooaOo000000?oooooo`000?l000003Ol0000:ooooo`;o
00001oooool2o`0000Oooooo0ol000000ooooooo0000o`000006ooooo`Co000000?oooooo`000?l0
00002?l000000ooooooo0000o`00000>o`000003ooooool0003o000000Oooooo0_l00009ooooo`;o
00003Oooool2o`0000gooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o0000
0oooool2o`0000;ooooo1?l000000ooooooo0000o`000002ooooo`;o00002oooool2o`000004oooo
ool0003o0000o`0000Gooooo0_l000000ooooooo0000o`000003ooooo`So00000_oooolVo`0000[o
oooo0_l00008ooooo`;o00001_ooool3o`000003ooooool0003o000000Sooooo7ol0000Gooooo`;o
00002Oooool3o`0000gooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o0000
0oooool2o`0000_ooooo0_l0000;ooooo`Ko00001Oooool2o`0000;ooooo0_l00002oooooaoo0000
00?oooooo`000?l000002?l0000=ooooo`;o00002?ooool2o`000003ooooool0003o000000?ooooo
0_l0000@ooooo`;o000000?oooooo`000?l000005_l000000ooooooo0000o`00000;ooooo`;o0000
1Oooool2o`000003ooooool0003o000000;o00001oooool4o`000003ooooool0003o000001Gooooo
0_l000000ooooooo0000o`00000^ooooo`007?ooool00ol0003oooooooooo`0Zooooo`;o00000_oo
ool2o`0000?ooooo0_l0000<ooooo`;o00003Oooool4o`0000Kooooo0_l000000ooooooo0000o`00
0002ooooo`?o000000Coooooo`000?l0003ooooo1?l000000ooooooo0000o`00000;o`0000;ooooo
4_l0000:ooooo`;o00002?ooool2o`0000Kooooo0_l00009ooooo`;o00001OoooolKo`0000Sooooo
0_l00003ooooo`?o00000oooool4o`000003ooooool0003o000000Wooooo1?l000000ooooooo0000
o`00000;ooooo`Co00001_ooool2o`000003ooooool0003o000002kooooo000Looooo`03o`000?oo
oooooooo02[ooooo0_l00002ooooo`;o00000oooool2o`0000_ooooo0_l00003ooooo`;o00002?oo
ool5o`0000Kooooo1?l00003ooooo`?o000000?oooooo`000?l000000ooooolIo`0000;ooooo1?l0
0002ooooo`?o00006Oooool4o`0000Gooooo0_l00003ooooo`;o00000ooooolLo`0000Wooooo0_l0
0003ooooo`;o00001?ooool8o`0000Wooooo0_l00002ooooo`Co00002Oooool4o`0003Wooooo000L
ooooo`03o`000?oooooooooo02_ooooo0_l0000Cooooo`;o00000_ooool3o`0000Sooooo0_l0000;
ooooo`;o00000_ooool2o`000003ooooool0003o000000Co000000?oooooo`000?l000005ol00000
0ooooooo0000o`000003o`0000Sooooo0_l00003ooooo`;o00003oooool4o`0000Gooooo0_l00008
ooooo`;o00000oooool3o`000003ooooool0003o0000013o00002_ooool2o`0000Kooooo0ol00000
1?oooooo0000o`000?ooool4o`0000gooooo1Ol00005ooooo`;o0000?_ooool001cooooo00?o0000
ooooooooool0:oooool2o`000003ooooool0003o000001Cooooo0_l0000IooooobWo00002Oooool2
o`0000?ooooo0_l0000Jooooo`;o00003?oooolCo`0000cooooo0_l00006ooooo`?o000000?ooooo
o`000?l000004oooool4o`0000Gooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0^oooo
o`;o00001oooool2o`0001Gooooo0_l00005ooooo`;o00002?ooool2o`000003ooooool0003o0000
00;ooooo3?l000000ooooooo0000o`00000Co`0000;ooooo0_l000000ooooooo0000o`00000Noooo
o`;o00000oooool2o`0000Oooooo0ol00003oooooa;o00006Oooool2o`00017ooooo1?l0000Boooo
o`;o000000?oooooo`000?l00000;oooool001cooooo00?o0000ooooooooool0=oooool2o`0000?o
oooo0_l0000@ooooo`;o00001Oooool2o`0000Oooooo0ol000000ooooooo0000o`000002ooooobKo
000000Coooooo`000?l0003o00001Oooool2o`0001Kooooo0_l0000<ooooo`?o00000ooooolBo`00
01?ooooo0_l00004ooooo`;o00001oooool2o`0000Sooooo0_l0000Dooooo`;o000000?oooooo`00
0?l00000;oooool001cooooo00?o0000ooooooooool0??ooool4o`0000Gooooo0_l0000Gooooo`?o
00000_ooool5o`000003ooooool0003o0000023o00000_ooool4o`0000Cooooo0_l0000Kooooo`;o
00003Oooool@o`0001Gooooo0_l00002ooooo`;o00002Oooool2o`0000[ooooo0_l00016ooooo`00
7?ooool00ol0003oooooooooo`0booooo`;o00001_ooool6o`0000Gooooo0_l00003ooooo`;o0000
00Coooooo`000?l0003o00003oooool2o`0000;ooooo1Ol000000ooooooo0000o`00000Oo`0000?o
oooo1?l0000Fooooo`;o00002Oooool2o`0000Wooooo0_l00005ooooo`Go00000_ooool3o`0000?o
oooo1?l0000Eooooo`;o00002Oooool2o`000004ooooool0003o0000ooooo`;o00001?ooool2o`00
04Kooooo000Looooo`;o0000;Oooool2o`0000Cooooo0_l00006ooooo`Co00003?ooool2o`000004
ooooool0003o0000o`0001;ooooo0ol00004ooooo`?o000000?oooooo`000?l000007?l00004oooo
o`;o00000oooool2o`00017ooooo0_l0000Dooooo`Go00001?ooool2o`0000Cooooo0_l00003oooo
o`Co00008?ooool2o`000004ooooool0003o0000ooooo`;o0000C?ooool001cooooo00?o0000oooo
ooooool0;?ooool3o`0000Gooooo0_l0000Kooooo`;o00001Oooool3o`0000Oooooo1?l00002oooo
o`Co000000?oooooo`000?l000000ol000000ooooooo0000o`00000Io`0000;ooooo0_l00002oooo
o`;o00001?ooool2o`0000[ooooo0ol00007ooooo`;o00002Oooool2o`000003ooooool0003o0000
00;o00001?ooool2o`0000Kooooo0_l00009ooooo`;o00002Oooool2o`0000Cooooo0_l00005oooo
o`;o00001?ooool2o`0000cooooo1?l00010ooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o
000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l0000Fooooo`;o00000_ooool2o`000004
ooooool0003o0000o`0000Wooooo0_l00002oooooaoo00000_ooool5o`0000;ooooo0_l00003oooo
o`;o00000oooool2o`0000[ooooo0ol000000ooooooo0000o`000002ooooo`Co00002Oooool2o`00
00?ooooo0_l00004ooooo`;o000000?oooooo`000?l000000_ooool3o`0000Wooooo0_l00008oooo
o`?o00001?ooool2o`0000Gooooo0_l00003ooooo`?o00001?ooool3o`0000Gooooo1Ol0000ooooo
o`007?ooool00ol0003oooooooooo`0`ooooo`;o00001oooool2o`0001[ooooo0_l00003ooooo`;o
00002?ooool3o`000003ooooool0003o000001go00000_ooool4o`0000?ooooo0_l00003ooooo`;o
00004oooool2o`0000;ooooo0ol0000?ooooo`?o00000oooool2o`000003ooooool0003o000000;o
oooo0_l00006ooooo`Ko00002?ooool2o`00017ooooo0_l00005ooooo`?o000000?oooooo`000?l0
00001Oooool2o`0000;ooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o0000
00?oooooo`000?l000003?ooool4o`0001Kooooo0_l00003ooooo`;o00000oooool3o`000003oooo
ool0003o0000023o000000?oooooo`000?l000000_l0000Jooooo`Co00002Oooool2o`0000Wooooo
0_l0000Booooo`Ko00005?ooool2o`00013ooooo0_l00009ooooo`;o00001_ooool2o`0003?ooooo
000Looooo`03o`000?oooooooooo02oooooo0_l000001?oooooo0000o`000?ooool3o`0000Sooooo
1?l0000Eooooo`;o00001?ooool2o`0000Gooooo0_l000000ooooooo0000o`00000Uo`0001Kooooo
0_l000000ooooooo0000o`000002o`0000Kooooo0_l000000ooooooo0000o`00000Booooo`;o0000
2?ooool2o`0000gooooo0_l0000:ooooo`;o00001?ooool2o`00013ooooo0_l0000;ooooo`;o0000
<oooool001cooooo00?o0000ooooooooool0=Oooool3o`0000?ooooo0_l0000Fooooo`;o00000_oo
ool4o`0000_ooooo3Ol000000ooooooo0000o`00000Go`000003ooooool0003o000000Gooooo0ol0
000>ooooo`;o00002oooool6o`00017ooooo0ol00007ooooo`;o00002?ooool2o`0000?ooooo0_l0
000:ooooo`;o00000_ooool6o`0000Cooooo0_l00008ooooo`;o0000@?ooool001cooooo00?o0000
ooooooooool0>Oooool4o`0000Sooooo0_l0000;ooooo`?o00000_ooool2o`0000?ooooo0_l00007
ooooob[o000000?oooooo`000?l000000_l000001?oooooo0000o`000?l0000Booooo`?o00001ooo
ool2o`000003ooooool0003o000000Gooooo0_l00006ooooo`;o00000oooool2o`00013ooooo0ol0
00000ooooooo0000o`00000<ooooo`;o00000_ooool2o`0000;ooooo0_l00004ooooo`;o00002?oo
ool2o`00043ooooo000Looooo`03o`000?oooooooooo03Sooooo0ol0000:ooooo`;o00002Oooool5
o`0000Kooooo1_l00004ooooo`Co000000?oooooo`000?l000008ol000000ooooooo0000o`000002
o`0000;ooooo0_l00002ooooo`;o00003_ooool3o`0000[ooooo1?l00003ooooo`;o00001_ooool4
o`0001?ooooo0_l00002ooooo`;o00002oooool3o`000003ooooool0003o000000?o00001oooool2
o`0000Kooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00003Oooool2o`00
00Oooooo0_l00005ooooo`;o00000_ooool2o`000003ooooool0003o000000;o000000Goooooo`00
0?l0003o0000ooooo`0Ho`000003ooooool0003o000000?o000000?oooooo`000?l000001Ol00003
ooooo`;o00001Oooool2o`000003ooooool0003o000001;ooooo0_l000000ooooooo0000o`000006
ooooo`;o00001Oooool2o`0000Kooooo0_l0000Mooooo`;o00001Oooool3o`000003ooooool0003o
000000?o00001oooool2o`0000Kooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0`oooo
o`;o00005Oooool2o`0000kooooo0_l00003ooooo`;o00000_ooool2o`000004ooooool0003o0000
o`0000?ooooo7?l00002ooooo`Ko00000oooool2o`0000Gooooo1?l0000?ooooo`;o00000_ooool2
o`000003ooooool0003o000000Kooooo0_l00005ooooo`;o00005oooool3o`0000;ooooo0_l00007
ooooo`;o00002_ooool3o`0000kooooo1?l000000ooooooo0000o`00000nooooo`007?ooool00ol0
003oooooooooo`0`ooooo`;o00007oooool2o`0000Cooooo0_l00003ooooo`Co00000oooool3o`00
00;ooooo3ol000000ooooooo0000o`00000>o`0000;ooooo0ol00002ooooo`?o00001oooool2o`00
00oooooo0_l00008ooooo`;o00000oooool2o`000003ooooool0003o000000Gooooo0_l00008oooo
o`Co00002?ooool3o`0000;ooooo0_l00006ooooo`;o00001_ooool2o`0000?ooooo0_l0000?oooo
o`Co000000?oooooo`000?l00000?_ooool001cooooo00?o0000ooooooooool0DOooool3o`0000[o
oooo0_l00004ooooo`?o000000?oooooo`000?l000007_l000000ooooooo0000o`000002o`0000;o
oooo0_l00008ooooo`;o00002oooool2o`0000;ooooo0_l00008ooooo`Co00001?ooool2o`0000Go
oooo0_l00008ooooo`Co00003?ooool2o`0000?ooooo0_l00002ooooo`;o00001_ooool2o`0001Wo
oooo0_l0000nooooo`007?ooool00ol0003oooooooooo`13ooooo`Co00001oooool2o`0000;ooooo
1?l00008ooooo`;o00001Oooool2o`000003ooooool0003o0000027o00003_ooool2o`0000Gooooo
0_l00004ooooo`;o00000_ooool2o`0000[ooooo0_l00004ooooo`;o00003oooool3o`0000Oooooo
0_l00004ooooo`Co000000?oooooo`000?l00000:_ooool2o`0003Wooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0
003oooooooooo`13ooooo`Co00001oooool2o`0000Cooooo0_l0000?ooooo`Wo000000?oooooo`00
0?l000006?l00003ooooo`;o00003_ooool2o`0000;ooooo0_l0000?ooooo`;o00002Oooool4o`00
00?ooooo0_l00008ooooo`;o00002?ooool2o`0000Cooooo1?l00002ooooo`?o00001Oooool4o`00
00?ooooo0_l0000?ooooo`;o00002Oooool2o`0003Wooooo00001_ooooooMgMgoiRHV?ooooooV9RH
ogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooooooo
o`0cooooo`;o00003_ooool2o`000003ooooool0003o000000Cooooo1?l0000Booooo`Co000000?o
ooooo`000?l000001Ol000000ooooooo0000o`00000Go`0000?ooooo0ol0000>ooooo`;o00002ooo
ool2o`0000Kooooo0_l00009ooooo`Co00000oooool4o`0001Kooooo0_l00004ooooo`?o00001?oo
ool7o`000003ooooool0003o000000oooooo0_l00014ooooo`0000?ooooooa0@4?ooool00_ooool0
0ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`0cooooo`?o00004?ooool2o`0000Cooooo1?l00003ooooo`;o00003Oooool9o`0000?ooooo6?l0
0005ooooo`;o00007?ooool8o`0001?ooooo0ol000000ooooooo0000o`00000Gooooo`Co000000?o
ooooo`000?l000001_l000000ooooooo0000o`000002o`0000?ooooo0_l0001Aooooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_oo
ool3o`0003Cooooo0_l00004ooooo`;o00000_ooool2o`00013ooooo0_l000000ooooooo0000o`00
0002ooooo`?o00001oooool2o`000003ooooool0003o000000Go00000ooooolIo`0000;ooooo0_l0
0002ooooo`;o00007?ooool6o`0001?ooooo0ol000000ooooooo0000o`00000Gooooo`;o00000ooo
ool4o`0000;ooooo0_l00003ooooo`;o00000oooool4o`0004oooooo00000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oo
oooooooo03Cooooo0_l00004ooooo`;o00000_ooool2o`0000gooooo0_l000000ooooooo0000o`00
0005ooooo`?o00001oooool2o`000004ooooool0003o0000ooooob3o00000_ooool2o`000004oooo
ool0003o0000o`0000[ooooo0_l0000>ooooo`;o00006?ooool4o`0000Gooooo0_l00007ooooo`;o
00000_ooool2o`0000Wooooo0_l00002ooooo`;o00003_ooool2o`0000cooooo0_l00011ooooo`00
00?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo
00?o0000ooooooooool0=?ooool4o`0000Wooooo0_l0000:ooooo`;o00003_ooool2o`0000;ooooo
1Ol000001?oooooo0000o`000?ooool5o`0000?ooooo4?l000001?oooooo0000o`000?ooool2o`00
00Cooooo0ol00008ooooo`Co00002Oooool2o`0000?ooooo0_l00007ooooo`;o00002_ooool2o`00
00?ooooo0_l00007ooooo`;o00001oooool2o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`00
01Wooooo0ol00004ooooo`;o0000@Oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool0
0ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo03Kooooo0_l00009ooooo`;o000000?ooooo
o`000?l000001_ooool2o`0000gooooo1?l000000ooooooo0000o`000003o`0000?ooooo0_l00004
ooooo`Ko000000?oooooo`000?l000001Ol000000ooooooo0000o`000003o`000004ooooool0003o
0000ooooo`;o00001?ooool2o`0000Wooooo0_l0000;ooooo`;o00002?ooool3o`000003ooooool0
003o000000[ooooo0_l0000Gooooo`;o00000oooool6o`0000gooooo0_l0000=ooooo`Co00001?oo
ool2o`00047ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o
410@1_ooool00ol0003oooooooooo`14ooooo`;o00001_ooool3o`0000cooooo0_l00003ooooo`Co
000000Coooooo`000?l0003ooooo0ol00002ooooo`co000000Coooooo`000?l0003ooooo1_l00000
0ooooooo0000o`000002o`0000;ooooo1?l0000Pooooo`?o00006Oooool2o`0000[ooooo0ol00000
0ooooooo0000o`000004o`0000oooooo0_l00003ooooo`;o00002?ooool2o`0000Kooooo0_l00011
ooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00004Oooool4o`000003ooooool0003o0000
00So000000Coooooo`000?l0003ooooo4?l000000ooooooo0000o`000002o`0000;ooooo0_l00005
ooooo`;o00007?ooool2o`0000Oooooo0_l0000@ooooo`;o00002_ooool3o`000004ooooool0003o
0000ooooo`;o00005Oooool2o`0000Wooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`1B
ooooo`;o00003?ooool2o`0000Gooooo2ol000000ooooooo0000o`000005o`000003ooooool0003o
000000;ooooo2Ol00009ooooo`Co00004?ooool2o`0000Cooooo0_l00002ooooo`;o00001?ooool2
o`000003ooooool0003o0000023ooooo0ol0000;ooooo`?o00000_ooool2o`0000Gooooo0_l00009
ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0<_ooool2o`0000_ooooo0_l00002oooo
o`;o00001Oooool4o`0000Cooooo0_l00003ooooo`;o00001_ooool3o`0000?ooooo0_l00004oooo
o`Oo00000_ooool3o`0000;ooooo0ol00003ooooo`ko00001_ooool2o`00013ooooo1Ol000001?oo
oooo0000o`000?l00006ooooo`Ko00003oooool3o`0000Wooooo0_l00004ooooo`;o00002Oooool5
o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l00000Doooool001cooooo00?o0000oooo
ooooool0<_ooool2o`0000_ooooo0_l00002ooooo`;o00001Oooool4o`0000Gooooo0_l00002oooo
o`;o00000_ooool2o`0000;ooooo0ol00003ooooo`;o00001Oooool5o`0000?ooooo0_l00003oooo
o`?o00000oooool5o`0000;ooooo1ol00003ooooo`;o00003_ooool2o`0000?ooooo1Ol000001?oo
oooo0000o`000?l00004ooooo`So00002?ooool2o`0000Gooooo0ol00009ooooo`Co00001?ooool2
o`0000Kooooo1?l00008ooooo`Co000000?oooooo`000?l000001_ooool2o`0000[ooooo0_l0000m
ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00004Oooool2o`0000?ooooo0_l000000ooo
oooo0000o`000004ooooo`;o00002oooool4o`0000;ooooo0_l00003ooooo`;o00001?ooool2o`00
0003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000005ooooo`;o00003_ooool2o`00
00Cooooo0_l00002ooooo`;o000000?oooooo`000?l000000oooool2o`000003ooooool0003o0000
00?ooooo1?l00003ooooo`Oo00003oooool2o`0000Cooooo0_l00004ooooo`Ko00002_ooool5o`00
0003ooooool0003o000000?ooooo0_l0000:ooooo`;o0000?Oooool001cooooo00?o0000oooooooo
ool0@?ooool2o`0000?ooooo0_l0000:ooooo`;o00001Oooool2o`0000Gooooo1?l00002ooooo`;o
00001?ooool2o`0000;ooooo0ol000000ooooooo0000o`000004ooooo`So00004?ooool2o`0000;o
oooo0_l00006ooooo`Go00001?ooool2o`000003ooooool0003o000000Ko00001Oooool2o`0000;o
oooo1Ol00002ooooo`;o000000?oooooo`000?l000000_l0000@ooooo`;o00001?ooool2o`0000?o
oooo1Ol0000;ooooo`?o00000oooool2o`0004kooooo000Looooo`03o`000?oooooooooo04Gooooo
0_l0000:ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Cooooo0_l000000ooooooo0000
o`000003o`0000;ooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000000Go0000
3oooool2o`0000;ooooo0ol00005ooooo`Co00001oooool;o`0000;ooooo0ol00005ooooo`?o0000
6?ooool3o`0000?ooooo0_l00004ooooo`?o00004?ooool2o`00053ooooo000Looooo`03o`000?oo
oooooooo05Cooooo0_l0000:ooooo`;o00000_ooool2o`000003ooooool0003o000000Go00002_oo
ool4o`0000;ooooo1?l00004ooooo`;o00001Oooool2o`0000Kooooo0ol00005ooooo`;o00002?oo
ool3o`000003ooooool0003o000000Ko000000?oooooo`000?l000001_l000001?oooooo0000o`00
0?l0000Dooooo`;o00000oooool2o`0000Gooooo1?l000000ooooooo0000o`00000@ooooo`?o0000
00?oooooo`000?l000001?ooool2o`0004Kooooo000Looooo`03o`000?oooooooooo047ooooo0_l0
0009ooooo`?o00004Oooool2o`000005ooooool0003o0000o`000?ooool00_l000000ooooooo0000
o`000004o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000002ooooo`Ko0000
0_ooool5o`0000;ooooo0_l00006ooooo`;o00003_oooolKo`000003ooooool0003o000000Cooooo
0_l00006ooooo`;o00000oooool2o`0000[ooooo1?l00004ooooo`;o00001oooool5o`0000;ooooo
0_l000000ooooooo0000o`000003ooooo`?o00000_ooool2o`0004;ooooo000Looooo`03o`000?oo
oooooooo047ooooo0_l00009ooooo`?o00004Oooool2o`000003ooooool0003o000000Wooooo0_l0
00000ooooooo0000o`000003ooooo`Co00001_ooool4o`0000?ooooo1?l00006ooooo`;o00000_oo
ool2o`0000Oooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo3ol000000ooooooo0000
o`000003o`000004ooooool0003o0000ooooo`;o00001?ooool2o`0000Gooooo0ol00002ooooo`Co
00002Oooool2o`0000Kooooo0_l000000ooooooo0000o`000004ooooo`Go00002_ooool2o`0000?o
oooo0_l00012ooooo`007?ooool00ol0003oooooooooo`15ooooo`?o00000_ooool2o`0000Gooooo
0_l0000?ooooo`;o00002_ooool2o`000003ooooool0003o000000?ooooo1?l00002ooooo`;o0000
4oooool2o`0000Wooooo1?l00002ooooo`;o00001?ooool3o`000003ooooool0003o000001;o0000
00Coooooo`000?l0003o00001oooool2o`000003ooooool0003o000000Oo00002Oooool2o`0000Wo
oooo0_l00007ooooo`;o00000oooool3o`0000Gooooo0_l00016ooooo`007?ooool2o`0004Kooooo
0ol00002ooooo`;o00001Oooool2o`0000[ooooo0_l00003ooooo`;o000000?oooooo`000?l00000
1oooool2o`0000cooooo0_l00004ooooo`;o000000Coooooo`000?l0003o00002?ooool2o`0000[o
oooo0_l00002ooooo`;o00000oooool6o`000003ooooool0003o0000017o00000_ooool3o`0000Oo
oooo0_l00002ooooo`Co00006_ooool2o`0000Gooooo0_l000000ooooooo0000o`000003o`0000Go
oooo0_l00016ooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o00001_ooool2o`0001_ooooo
0_l000001?oooooo0000o`000?l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l0000>oooo
o`;o00000ooooolHo`0000Wooooo0_l00005ooooo`;o000000?oooooo`000?l000000_l00005oooo
o`;o00000oooool2o`0000gooooo0_l00008ooooo`;o00002?ooool2o`0000;ooooo0_l00012oooo
o`007?ooool00ol0003oooooooooo`1mooooo`;o00002oooool2o`000003ooooool0003o000000Go
oooo0_l00004ooooo`;o00001?ooool2o`000003ooooool0003o0000017o000000?oooooo`000?l0
00002?l00005ooooo`;o00001Oooool2o`000003ooooool0003o000000;o00001Oooool2o`000003
ooooool0003o000000;o00000_ooool2o`0000;ooooo0_l00002ooooo`;o00005Oooool2o`0000;o
oooo0_l00012ooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o00001Oooool2o`0000[ooooo
0_l00009ooooo`;o00002Oooool2o`0000oooooo0_l00004ooooo`;o00001?ooool2o`0000Cooooo
0_l000000ooooooo0000o`000004ooooo`[o000000?oooooo`000?l000003Ol0000=ooooo`;o0000
0_ooool2o`0000Kooooo0_l00003ooooo`?o00000_ooool2o`0000;ooooo0_l00002ooooo`;o0000
FOooool001cooooo00?o0000ooooooooool0Aoooool2o`0000Oooooo0_l00002ooooo`;o00001Ooo
ool2o`0000Oooooo0_l000000ooooooo0000o`000003o`0000Kooooo0_l00009ooooo`;o00003ooo
ool2o`000003ooooool0003o000000gooooo0_l00005ooooo`co000000?oooooo`000?l000002_l0
00000ooooooo0000o`00000;ooooo`Co00000_ooool2o`0000_ooooo0_l00002ooooo`Co00001Ooo
ool6o`0000Oooooo0_l00002ooooo`;o00002oooool2o`0003_ooooo000Looooo`03o`000?oooooo
oooo04Oooooo0_l00007ooooo`;o00002_ooool2o`0000Kooooo0_l00003ooooo`?o00002Oooool2
o`00013ooooo1?l00006ooooo`;o00005?oooolIo`000004ooooool0003o0000o`0000Wooooo0ol0
000Eooooo`Co00001oooool4o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o00002ooo
ool2o`0003_ooooo000Looooo`03o`000?oooooooooo03Wooooo1?l0000Cooooo`?o00001Oooool2
o`0000;ooooo0_l00007ooooo`;o00000_ooool2o`0000[ooooo1_l00008ooooo`;o00000_ooool4
o`0000Cooooo0_l0000@ooooo`?o000000?oooooo`000?l000007Ol00009ooooo`;o00002Oooool2
o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0ol00004ooooo`Go000000?o
ooooo`000?l000000oooool2o`0004oooooo000Looooo`03o`000?oooooooooo03Wooooo1?l00009
ooooo`;o00002?ooool3o`0000Gooooo0_l00008ooooo`;o000000?oooooo`000?l000001?ooool3
o`0000Wooooo1Ol00007ooooo`Co00002?ooool2o`0000;ooooo0_l00003ooooo`;o00001ooooolT
o`00017ooooo1Ol000001?oooooo0000o`000?ooool<o`0000;ooooo1Ol000000ooooooo0000o`00
001Dooooo`007?ooool00ol0003oooooooooo`16ooooo`;o00001Oooool2o`000003ooooool0003o
000000Cooooo0_l0000:ooooo`;o00001oooool5o`0000Cooooo0_l00004ooooo`;o00002Oooool2
o`0000Kooooo1?l00002ooooo`;o00000oooool2o`0000?ooooo1?l00002ooooo`;o000000?ooooo
o`000?l000006_l000000ooooooo0000o`000004o`000003ooooool0003o000000;o00002?ooool2
o`000003ooooool0003o000000Gooooo1_l000000ooooooo0000o`000002o`0000?ooooo1Ol0001F
ooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00000oooool2o`0000;ooooo0_l00009oooo
o`;o00002_ooool3o`000004ooooool0003o0000ooooo`Ko00003oooool2o`0000;ooooo0_l0000>
ooooo`Co00000_ooool2o`000003ooooool0003o000001So00000_ooool7o`000003ooooool0003o
000000;o00002?ooool2o`0000Wooooo0ol000000ooooooo0000o`000002o`0000Gooooo0_l00000
0ooooooo0000o`00000=ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0D_ooool2o`00
00gooooo0_l00002ooooo`;o00002_ooool4o`000003ooooool0003o000000;o00003oooool2o`00
00Kooooo0_l00009ooooo`;o00001OoooolEo`000003ooooool0003o000000_o00001_ooool4o`00
017ooooo0_l00002ooooo`;o00004_ooool2o`0000Gooooo0_l00017ooooo`007?ooool00ol0003o
ooooooooo`1>ooooo`;o00002?ooool4o`0000Wooooo0_l0000<ooooo`;o00001_ooool2o`0000Ko
oooo0_l0000<ooooo`;o00002Oooool2o`0000?ooooo0_l000000ooooooo0000o`00000Io`000004
ooooool0003o0000o`0000Oooooo0_l00002ooooo`;o00004Oooool2o`0000;ooooo1?l0000@oooo
o`;o0000C_ooool001cooooo00?o0000ooooooooool0C_ooool2o`0000Sooooo1?l0000;ooooo`;o
00002Oooool3o`0000?ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00000_ooool2o`00
00Oooooo0_l0000@ooooo`Go00001?oooolMo`0000Kooooo0_l0000Aooooo`So000000?oooooo`00
0?l000000ol0000=ooooo`;o0000Coooool001cooooo00?o0000ooooooooool0??ooool2o`0001_o
oooo0_l00004ooooo`;o00001_ooool2o`0000Oooooo1?l00004ooooo`;o00000_ooool2o`000003
ooooool0003o000000;o00001_ooool2o`000003ooooool0003o000000Gooooo0_l00009ooooo`Co
00001OoooolMo`0000Cooooo0_l00002ooooo`;o00003oooool4o`0000;ooooo1Ol000000ooooooo
0000o`000004ooooo`;o00001oooool2o`0004oooooo000Looooo`03o`000?oooooooooo03cooooo
0_l0000;ooooo`;o00003_ooool2o`0000Cooooo0_l0000:ooooo`;o00000oooool2o`0000Kooooo
0_l00007ooooo`;o00001_ooool2o`0000Sooooo0_l0000Booooo`;o000000?oooooo`000?l00000
4_l000000ooooooo0000o`000005o`0000;ooooo0_l00002ooooo`;o00001?ooool3o`0000cooooo
1Ol00009ooooo`;o000000?oooooo`000?l00000EOooool001cooooo00?o0000ooooooooool0BOoo
ool2o`00023ooooo0_l0000>ooooo`?o00006_ooool3o`0000cooooo4ol000000ooooooo0000o`00
0009o`0000cooooo0ol00006ooooo`;o00001?ooool3o`0000Cooooo1?l00005ooooo`?o0000EOoo
ool001cooooo0_l0001Hooooo`?o000000?oooooo`000?l000005oooool2o`000003ooooool0003o
000000;ooooo0ol00002ooooo`Co000000?oooooo`000?l000004Oooool3o`0000Kooooo0_l00005
oooooaWo000000Coooooo`000?l0003o00003_ooool2o`0000Kooooo0_l00003ooooo`;o00001_oo
ool4o`0000Gooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`1Fooooo`Co000000?ooooo
o`000?l000005oooool2o`000004ooooool0003o0000ooooo`[o000000Coooooo`000?l0003o0000
4Oooool2o`0000Kooooo0_l00006oooooaSo000000?oooooo`000?l000000_l00009ooooo`;o0000
0_ooool2o`0000;ooooo0_l00007ooooo`;o0000Ioooool001cooooo00?o0000ooooooooool0Booo
ool2o`0000Oooooo1?l0000Rooooo`;o00000_ooool2o`0000Kooooo1?l0000?ooooo`;o00001_oo
ool3o`0000Gooooo0_l00002oooooa?o000000?oooooo`000?l000000ol00009ooooo`;o00001_oo
ool4o`0006kooooo000Looooo`03o`000?oooooooooo04_ooooo0_l00007ooooo`Co00005oooool2
o`0000gooooo0_l00002ooooo`;o00001?ooool4o`000003ooooool0003o000000Cooooo0_l0000=
ooooo`;o00002Oooool2o`000003ooooool0003o000000go00000_ooool2o`0000;ooooo0_l00003
ooooo`;o000000?oooooo`000?l000002?ooool4o`0000;ooooo0_l0000;ooooo`;o0000GOooool0
01cooooo00?o0000ooooooooool0Boooool2o`0000Wooooo1?l0000Eooooo`;o00003Oooool2o`00
00;ooooo0_l00006ooooo`;o000000?oooooo`000?l000001?ooool3o`0000Oooooo0_l00003oooo
o`;o00002OoooolDo`0000Cooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l00003
ooooo`Co000000Coooooo`000?l0003ooooo1_l00007ooooo`;o0000GOooool001cooooo00?o0000
ooooooooool0E_ooool4o`00027ooooo0_l00003ooooo`;o00001oooool2o`0000Wooooo0_l00003
ooooo`;o00000_ooool2o`0000;ooooo0ol00002ooooo`?o000000?oooooo`000?l000003ol00000
0ooooooo0000o`000005o`0000Oooooo0_l00004ooooo`;o00000oooool2o`0000?ooooo0_l00003
ooooo`Co0000I_ooool001cooooo00?o0000ooooooooool0E_ooool3o`0000gooooo0ol0000Boooo
o`;o00000oooool2o`0000Oooooo0_l00009ooooo`Co000000?oooooo`000?l000001_ooool2o`00
00?ooooo0ol000000ooooooo0000o`000002o`0000;ooooo3_l000000ooooooo0000o`000002o`00
00Cooooo0_l0000:ooooo`;o00000_ooool2o`0000?ooooo0_l0000:ooooo`;o00000oooool4o`00
00Kooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`1Cooooo`?o000000?oooooo`000?l0
00000_l00003ooooo`;o00001_ooool3o`0000?ooooo0_l0000Dooooo`;o00002Oooool2o`0000Oo
oooo0ol0000>ooooo`;o00001?ooool2o`0000;ooooo2?l000000ooooooo0000o`000005o`0000Ko
oooo0ol00009ooooo`;o00000_ooool2o`0000?ooooo0_l0000:ooooo`;o00000oooool4o`0000Ko
oooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`1Cooooo`?o00000oooool4o`000003oooo
ool0003o000000cooooo0_l0000Dooooo`;o00002Oooool2o`0000Sooooo0_l0000>ooooo`;o0000
1?ooool7o`0000;ooooo1?l000000ooooooo0000o`000002o`0000Wooooo0_l00004ooooo`;o0000
0oooool2o`0000;ooooo0_l0000Hooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0Dooo
ool2o`0000Kooooo0_l00003ooooo`Co0000;_ooool2o`0001Gooooo0_l00002ooooo`Co00001ooo
ool2o`0000;ooooo1?l0000:ooooo`;o00000_ooool2o`0000?ooooo0ol000000ooooooo0000o`00
000Hooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0Doooool3o`0000Gooooo0_l00003
ooooo`Co00000_ooool2o`0002[ooooo0_l0000Eooooo`;o00000_ooool2o`0000Gooooo0_l00003
ooooo`;o00000_ooool3o`0000[ooooo0_l00008ooooo`;o00002_ooool2o`0006Oooooo000Loooo
o`03o`000?oooooooooo05Cooooo0_l0000@ooooo`;o00001?ooool2o`0000Sooooo0_l0000_oooo
o`;o00000oooool3o`0000Gooooo0_l00003ooooo`;o00000_ooool6o`0000Kooooo0_l0000Eoooo
o`;o0000Ioooool001cooooo00?o0000ooooooooool0H?ooool2o`0000?ooooo1?l00003ooooo`;o
00002?ooool2o`0002oooooo0_l00003ooooo`?o00004?ooool4o`0000Kooooo0_l0000:ooooo`;o
00001oooool2o`0000Oooooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o0000
0oooool4o`0000?ooooo1?l0000booooo`;o00003_ooool2o`0000Sooooo1?l00004ooooo`;o0000
2oooool2o`000004ooooool0003o0000o`0000Cooooo1Ol00007ooooo`;o0000H?ooool001cooooo
00?o0000ooooooooool0IOooool4o`0000Gooooo0_l0000booooo`;o00002?ooool3o`0000?ooooo
0_l00008ooooo`Co00001?ooool6o`0000Oooooo1Ol00005ooooo`?o00001Oooool2o`0006Cooooo
000Looooo`03o`000?oooooooooo05oooooo0_l00006ooooo`;o00004?ooool3o`0002Kooooo0_l0
00000ooooooo0000o`000004ooooo`Co00005oooool4o`0000Sooooo0_l0000?ooooo`;o000000?o
ooooo`000?l000002_ooool2o`0005Gooooo000Looooo`;o0000Foooool2o`0000?ooooo0_l00003
ooooo`?o00004_ooool3o`0002Kooooo0_l000000ooooooo0000o`000004ooooo`;o00001Oooool2
o`0000Sooooo0_l00009ooooo`;o00001?ooool2o`0001Oooooo0_l00008ooooo`Co0000EOooool0
01cooooo00?o0000ooooooooool0F_ooool2o`0000Sooooo1Ol0000gooooo`;o00004?ooool2o`00
00Sooooo0_l00009ooooo`;o00001?ooool2o`0001kooooo0_l000001?oooooo0000o`000?l0001F
ooooo`007?ooool00ol0003oooooooooo`1Hooooo`Co00002oooool2o`0003Oooooo0_l00002oooo
o`;o00002_ooool4o`000003ooooool0003o000000cooooo1?l000000ooooooo0000o`000002o`00
00?ooooo1_l0000Gooooo`?o0000F_ooool001cooooo00?o0000ooooooooool0F?ooool4o`0000Go
oooo0ol00004ooooo`;o00004_ooool2o`0002?ooooo0_l000000ooooooo0000o`00000:ooooo`Co
000000?oooooo`000?l000002_ooool6o`000003ooooool0003o000000;o00000oooool6o`0001Oo
oooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`1Qooooo`Co00000oooool2o`0000Wooooo
0_l00003ooooo`;o00000_ooool2o`0002?ooooo0ol000000ooooooo0000o`00000Jooooo`Co0000
3Oooool2o`0007Gooooo000Looooo`03o`000?oooooooooo06?ooooo0_l00005ooooo`;o00001ooo
ool2o`0000?ooooo0_l00002ooooo`;o00009?ooool2o`000003ooooool0003o000000?o00004_oo
ool2o`0000?ooooo1?l000000ooooooo0000o`000005ooooo`;o00003?ooool2o`0000Cooooo0_l0
001Vooooo`007?ooool00ol0003oooooooooo`1Sooooo`;o00001Oooool2o`00013ooooo0_l0000Y
ooooo`?o00001Oooool4o`0000Wooooo0_l000000ooooooo0000o`000005ooooo`;o00001Oooool2
o`0000cooooo0_l00004ooooo`;o0000I_ooool001cooooo00?o0000ooooooooool0Joooool2o`00
00Gooooo0_l0000kooooo`Co00003?ooool2o`0008Sooooo000Looooo`03o`000?oooooooooo06_o
oooo0_l00004ooooo`Go00009oooool2o`0003?ooooo0_l0001eooooo`007?ooool00ol0003ooooo
ooooo`1aooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00008Oooool2o`0000Sooooo
0_l0000Yooooo`?o0000M?ooool001cooooo00?o0000ooooooooool0M_ooool2o`0000;ooooo0_l0
000Sooooo`;o00001_ooool2o`0000_ooooo0_l0000Mooooo`;o0000M?ooool001cooooo00?o0000
ooooooooool0L?ooool2o`0000Sooooo0_l0000Sooooo`;o00003Oooool2o`0000Cooooo1?l0002A
ooooo`007?ooool00ol0003oooooooooo`1`ooooo`;o00002?ooool2o`00037ooooo0ol00006oooo
o`;o0000TOooool001cooooo00?o0000ooooooooool0K?ooool2o`0000Cooooo0_l00006ooooo`;o
00000_ooool2o`0000gooooo0_l000000ooooooo0000o`000008ooooo`;o00004Oooool2o`0000?o
oooo0_l00005ooooo`;o0000:?ooool2o`0006Cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^
kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1R
ooooo`;o00002?ooool2o`0000Cooooo0_l00006ooooo`;o000000Coooooo`000?l0003o00003Ooo
ool2o`000003ooooool0003o000000Sooooo0_l0000>ooooo`?o00001Oooool2o`0000Gooooo1?l0
000Nooooo`;o00001_ooool2o`0006Cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo
0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1Rooooo`;o
00003oooool3o`0000Cooooo1Ol0000;ooooo`;o00007_ooool5o`0000Oooooo0_l00002ooooo`?o
00007_ooool2o`0006cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo07?ooooo0ol00004ooooo`Go
00002oooool2o`000004ooooool0003o0000o`0000;ooooo1Ol0000Eooooo`?o00000_ooool2o`00
0003ooooool0003o000000;o00000_ooool2o`0001_ooooo0_l0001`ooooo`0000?oooooo`000?oo
ool00_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`00
07[ooooo0_l0000=ooooo`Oo00000_ooool5o`0000?ooooo1?l00007ooooo`Co00000oooool2o`00
00?ooooo0_l000000ooooooo0000o`00000Qooooo`;o0000L?ooool00003ooooool0003ooooo00;o
oooo00?o0000ooooooooool02Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000oooo
ooooool0Noooool2o`0000cooooo1?l00009ooooo`;o000000?oooooo`000?l000001?l00006oooo
o`Co00001Oooool2o`0009Wooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wo
oooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo07_ooooo0_l0000Ioooo
o`;o000000?oooooo`000?l000001?l0000=ooooo`Co00008Oooool2o`0007Kooooo00001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oo
oooooooo09Oooooo1?l0000Aooooo`;o00008oooool2o`0007Kooooo00001_ooooook^k^oc8b<_l0
003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo09Oo
oooo0_l000000ooooooo0000o`00000@ooooo`;o00008?ooool2o`0007Wooooo000Looooo`03o`00
0?oooooooooo07Wooooo0_l0000Oooooo`;o000000?oooooo`000?l000000oooool2o`0000Kooooo
1?l0000Pooooo`;o0000NOooool001cooooo00?o0000ooooooooool0NOooool3o`0001cooooo0_l0
0002ooooo`Co00000_ooool3o`0000Gooooo0_l0002Mooooo`007?ooool00ol0003oooooooooo`1`
ooooo`;o00002?ooool2o`0001?ooooo0_l00007ooooo`;o00000_ooool4o`0000;ooooo0ol00004
ooooo`;o00000_ooool2o`0009[ooooo000Looooo`03o`000?oooooooooo073ooooo0_l0000Hoooo
o`;o00000oooool2o`0000_ooooo0_l0000;ooooo`;o00000_ooool2o`0009[ooooo000Looooo`03
o`000?oooooooooo08Wooooo0ol00009ooooo`;o00005?ooool2o`0009cooooo000Looooo`03o`00
0?oooooooooo08;ooooo0_l00005ooooo`;o00002_ooool2o`0000_ooooo0ol00003ooooo`;o0000
00?oooooo`000?l00000W?ooool001cooooo00?o0000ooooooooool0P_ooool2o`0000gooooo1?l0
000=ooooo`?o00000oooool2o`0001oooooo0_l0001nooooo`007?ooool00ol0003oooooooooo`2:
ooooo`;o000000?oooooo`000?l000000_ooool4o`0003Cooooo0_l0001nooooo`007?ooool00ol0
003oooooooooo`2:ooooo`;o000000?oooooo`000?l00000<_ooool2o`0008Kooooo000Looooo`03
o`000?oooooooooo08Wooooo0_l00006ooooo`;o00003_ooool2o`0000?ooooo0_l00006ooooo`;o
00000_ooool3o`0000cooooo0_l00026ooooo`007?ooool00ol0003oooooooooo`29ooooo`;o0000
1_ooool2o`000003ooooool0003o000000_ooooo0_l00003ooooo`;o00001_ooool2o`0000;ooooo
0ol00007ooooo`;o0000Roooool001cooooo0_l00024ooooo`;o00003_ooool4o`0002;ooooo0_l0
00000ooooooo0000o`00002;ooooo`007?ooool00ol0003oooooooooo`23ooooo`;o00003_ooool4
o`0001Wooooo0_l00007ooooo`;o0000S_ooool001cooooo00?o0000ooooooooool0Y_ooool2o`00
00Sooooo0_l0002Gooooo`007?ooool00ol0003oooooooooo`25ooooo`;o00004?ooool2o`0000go
oooo0_l0002Qooooo`007?ooool00ol0003oooooooooo`25ooooo`;o00004?ooool2o`000;3ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0Toooool2o`0002Oooooo0_l0002;ooooo`007?oo
ool00ol0003oooooooooo`2Booooo`Co00009_ooool2o`0008_ooooo000Looooo`03o`000?oooooo
oooo09;ooooo1?l0002cooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0<;ooooo0_l00025ooooo`007?ooool00ol0003oooooooooo`2kooooo`;o0000
1Oooool2o`0008Gooooo000Looooo`03o`000?oooooooooo0;_ooooo0_l0002<ooooo`007?ooool2
o`000:_ooooo0_l0002Mooooo`007?ooool00ol0003oooooooooo`2Zooooo`;o0000WOooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Booooo`Co000000?o410@
ooooooooool00oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`?o
0000oooooom:ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oo
oooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0
003oooooooooo`3ooooooe;ooooo000Booooo`03oeEEEOmVIVKo00000?ooooooE?ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00:Gooooo00Co410@o`000?l0003ooooo0_l00000
0ol@413oooooooooo`0Eooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01?ooool4o`000008oa0@4?oo
ooooooooonk^k_lb<S;o0000oa0@4?o<c<b@ooooo`00Y_ooool01Ol0003ooooooooooooooooo0000
00Wooooo1_l00009ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`02
ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40T?ooool00:Kooooo00Go0000ooooooooooooooooo`00
000Hooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000T?ooool00:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko
00002Oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000ooooooooool00_ooool01Ol0
003oV9RHoooooonHV9So8B4Q093ooooo002Vooooo`05o`000?n7QhOoooooojVYZOl000006?ooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool00_ooool01Ol0003oEEEEo`00
0?l@413oc<c<093ooooo002Uooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool05_oo
ool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool00_ooool00omEEEGoQhN7
ooooo`2Booooo`00`oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0
0_ooool00ooMgMgo410@oiRHV02Booooo`00`oooool01OnYZJWo410@o`000?l@413oZJVY00Cooooo
00?oEEEEofIVI_l000001Oooool01?o<c<coA4A4o`000?l@412@ooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(822) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.51105 .66148 Mdot
.53242 .66533 Mdot
.62038 .39302 Mdot
.408 .56087 Mdot
.48022 .51615 Mdot
.61935 .35586 Mdot
.6162 .53423 Mdot
.60357 .54857 Mdot
.60235 .34658 Mdot
.28455 .60223 Mdot
.65233 .54015 Mdot
.44019 .56606 Mdot
.62639 .5242 Mdot
.39016 .5311 Mdot
.62427 .18908 Mdot
.39629 .59407 Mdot
.55508 .7189 Mdot
.42698 .35038 Mdot
.40902 .48044 Mdot
.56895 .37934 Mdot
.58991 .68495 Mdot
.38926 .52676 Mdot
.50841 .67012 Mdot
.38897 .53125 Mdot
.38694 .57652 Mdot
.53947 .69218 Mdot
.52976 .72726 Mdot
.35591 .57989 Mdot
.38274 .55597 Mdot
.64568 .55804 Mdot
.43267 .41194 Mdot
.47761 .16451 Mdot
.4144 .58818 Mdot
.30245 .74056 Mdot
.60632 .54695 Mdot
.23589 .36372 Mdot
.57864 .3591 Mdot
.64649 .51134 Mdot
.60646 .55112 Mdot
.60526 .5135 Mdot
.64031 .51144 Mdot
.54436 .68848 Mdot
.60026 .49953 Mdot
.62788 .47341 Mdot
.41949 .54875 Mdot
.68309 .63825 Mdot
.33428 .30059 Mdot
.34742 .56224 Mdot
.54553 .65655 Mdot
.56497 .36646 Mdot
.44238 .82359 Mdot
.59472 .52718 Mdot
.74326 .43099 Mdot
.47181 .08587 Mdot
.62524 .51043 Mdot
.413 .56244 Mdot
.59561 .36569 Mdot
.36716 .51936 Mdot
.37714 .53172 Mdot
.44348 .79804 Mdot
.36437 .57418 Mdot
.44578 .33739 Mdot
.56626 .6445 Mdot
.64268 .34951 Mdot
.61205 .35155 Mdot
.6209 .56181 Mdot
.56257 .70514 Mdot
.62909 .53257 Mdot
.30935 .54414 Mdot
.57713 .34625 Mdot
.34643 .56157 Mdot
.65567 .53412 Mdot
.5462 .64279 Mdot
.35366 .50814 Mdot
.70227 .66036 Mdot
.69368 .24159 Mdot
.42346 .35625 Mdot
.42334 .77792 Mdot
.50646 .75403 Mdot
.72296 .3025 Mdot
.3841 .54454 Mdot
.85886 .55986 Mdot
.64104 .19995 Mdot
.51112 .67036 Mdot
.46393 .51763 Mdot
.55799 .33248 Mdot
.38214 .4988 Mdot
.48152 .45147 Mdot
.31182 .5684 Mdot
.66388 .73527 Mdot
.59683 .34774 Mdot
.55611 .68295 Mdot
.40915 .55626 Mdot
.32685 .55116 Mdot
.3953 .70188 Mdot
.33057 .52103 Mdot
.363 .5869 Mdot
.5632 .7273 Mdot
.63161 .55637 Mdot
.36232 .61373 Mdot
.59076 .49439 Mdot
.76148 .41768 Mdot
.41183 .51774 Mdot
.59686 .3366 Mdot
.57573 .70618 Mdot
.40991 .50815 Mdot
.61088 .51753 Mdot
.36611 .56103 Mdot
.61018 .48672 Mdot
.53496 .66055 Mdot
.32816 .54495 Mdot
.4284 .34454 Mdot
.73998 .67111 Mdot
.55821 .69386 Mdot
.82638 .52934 Mdot
.3562 .56918 Mdot
.38594 .52111 Mdot
.53437 .66766 Mdot
.61404 .38096 Mdot
.47163 .42905 Mdot
.57059 .6821 Mdot
.60255 .52712 Mdot
.50701 .70533 Mdot
.36034 .47888 Mdot
.62063 .34545 Mdot
.76864 .41865 Mdot
.77447 .43718 Mdot
.28138 .44639 Mdot
.39145 .5016 Mdot
.62579 .61023 Mdot
.62279 .365 Mdot
.55057 .67816 Mdot
.63182 .53073 Mdot
.39508 .58837 Mdot
.53329 .71441 Mdot
.6473 .53183 Mdot
.43559 .33241 Mdot
.44198 .25663 Mdot
.55942 .66324 Mdot
.56421 .57563 Mdot
.67 .51071 Mdot
.60732 .51178 Mdot
.34145 .78057 Mdot
.52811 .66664 Mdot
.4725 .34553 Mdot
.64302 .53548 Mdot
.37592 .35521 Mdot
.3801 .59129 Mdot
.25464 .4948 Mdot
.77791 .69048 Mdot
.42902 .82682 Mdot
.7554 .53546 Mdot
.46514 .3632 Mdot
.61732 .50129 Mdot
.39455 .56134 Mdot
.52442 .67375 Mdot
.53366 .67983 Mdot
.33134 .57594 Mdot
.38037 .58225 Mdot
.33617 .54964 Mdot
.32895 .55918 Mdot
.37461 .27701 Mdot
.33297 .55413 Mdot
.5964 .41993 Mdot
.55209 .70595 Mdot
.3796 .57275 Mdot
.60497 .38905 Mdot
.42936 .55957 Mdot
.65124 .52018 Mdot
.37692 .52532 Mdot
.39307 .57995 Mdot
.36614 .49175 Mdot
.63216 .50486 Mdot
.42313 .19527 Mdot
.76718 .69106 Mdot
.27129 .28635 Mdot
.78419 .53792 Mdot
.60385 .37459 Mdot
.39057 .50707 Mdot
.46188 .33571 Mdot
.39254 .63481 Mdot
.37402 .5399 Mdot
.5056 .83261 Mdot
.37799 .58667 Mdot
.26559 .67397 Mdot
.34079 .47081 Mdot
.27126 .27758 Mdot
.53707 .42434 Mdot
.3781 .56072 Mdot
.36994 .67351 Mdot
.22896 .5849 Mdot
.49379 .59367 Mdot
.63433 .51015 Mdot
.61119 .38641 Mdot
.58729 .36144 Mdot
.62527 .49177 Mdot
.33364 .60544 Mdot
.27836 .55989 Mdot
.37989 .61894 Mdot
.76887 .42428 Mdot
.54874 .64209 Mdot
.48026 .32708 Mdot
.54567 .64954 Mdot
.86152 .47708 Mdot
.63771 .7388 Mdot
.67627 .51516 Mdot
.45234 .37327 Mdot
.62268 .38948 Mdot
.77159 .4263 Mdot
.46699 .34033 Mdot
.35077 .54898 Mdot
.55164 .6626 Mdot
.23565 .64026 Mdot
.3578 .4671 Mdot
.19243 .59036 Mdot
.51293 .70377 Mdot
.50933 .43912 Mdot
.64162 .52231 Mdot
.56556 .3833 Mdot
.40194 .52279 Mdot
.34251 .53352 Mdot
.58181 .67354 Mdot
.3499 .56119 Mdot
.47337 .67843 Mdot
.39698 .57918 Mdot
.56703 .32958 Mdot
.41785 .33272 Mdot
.61385 .49585 Mdot
.27866 .4534 Mdot
.51739 .64323 Mdot
.66933 .34651 Mdot
.57031 .37063 Mdot
.32083 .63223 Mdot
.6541 .54022 Mdot
.43007 .34382 Mdot
.5789 .38312 Mdot
.48845 .34874 Mdot
.40075 .49874 Mdot
.57742 .35713 Mdot
.48058 .34338 Mdot
.40531 .23812 Mdot
.41818 .55895 Mdot
.3827 .29761 Mdot
.62035 .53987 Mdot
.50263 .69945 Mdot
.36569 .5747 Mdot
.77866 .43576 Mdot
.41602 .5015 Mdot
.71654 .48583 Mdot
.74671 .43584 Mdot
.74547 .42419 Mdot
.69452 .27022 Mdot
.43964 .35841 Mdot
.74281 .5869 Mdot
.59782 .63107 Mdot
.56344 .70573 Mdot
.41348 .55234 Mdot
.34311 .21325 Mdot
.64306 .53449 Mdot
.3535 .54692 Mdot
.56085 .33185 Mdot
.64046 .53731 Mdot
.36693 .5143 Mdot
.62317 .50389 Mdot
.52892 .67516 Mdot
.63444 .29031 Mdot
.53909 .72334 Mdot
.41356 .56687 Mdot
.61108 .52286 Mdot
.58341 .37866 Mdot
.53584 .69226 Mdot
.36601 .55764 Mdot
.39614 .51833 Mdot
.76226 .42852 Mdot
.38056 .56608 Mdot
.35122 .21482 Mdot
.34948 .57353 Mdot
.64122 .37088 Mdot
.321 .53357 Mdot
.4425 .84452 Mdot
.47088 .26278 Mdot
.56492 .69408 Mdot
.74551 .42906 Mdot
.60058 .35139 Mdot
.61016 .27134 Mdot
.53047 .57727 Mdot
.37596 .55173 Mdot
.75134 .42857 Mdot
.49453 .41414 Mdot
.62827 .56403 Mdot
.341 .50547 Mdot
.66507 .71417 Mdot
.57933 .38788 Mdot
.76896 .42676 Mdot
.43817 .49463 Mdot
.5757 .70719 Mdot
.40623 .56426 Mdot
.57559 .36924 Mdot
.50661 .70569 Mdot
.42974 .53987 Mdot
.28423 .34134 Mdot
.75876 .44143 Mdot
.62126 .53901 Mdot
.28755 .52207 Mdot
.33649 .55618 Mdot
.58716 .36969 Mdot
.50842 .68107 Mdot
.60863 .54592 Mdot
.54669 .69716 Mdot
.22758 .60631 Mdot
.78353 .55436 Mdot
.35198 .27465 Mdot
.44918 .37381 Mdot
.71846 .46384 Mdot
.25091 .30579 Mdot
.75468 .59872 Mdot
.33252 .39259 Mdot
.17156 .42562 Mdot
.59384 .38805 Mdot
.41239 .3054 Mdot
.60067 .35672 Mdot
.40206 .54913 Mdot
.61666 .35262 Mdot
.27118 .27181 Mdot
.37749 .58782 Mdot
.59963 .37346 Mdot
.55209 .3013 Mdot
.37246 .58092 Mdot
.55767 .69981 Mdot
.59348 .18936 Mdot
.67442 .75536 Mdot
.5902 .75802 Mdot
.60714 .37929 Mdot
.50678 .78627 Mdot
.36041 .58053 Mdot
.42581 .57249 Mdot
.52294 .67818 Mdot
.32232 .52774 Mdot
.47126 .32239 Mdot
.49068 .34916 Mdot
.27061 .47665 Mdot
.81785 .58431 Mdot
.33998 .61344 Mdot
.53273 .68955 Mdot
.46892 .69544 Mdot
.69836 .66082 Mdot
.78484 .41937 Mdot
.66157 .55488 Mdot
.43365 .19612 Mdot
.3047 .59079 Mdot
.56418 .58063 Mdot
.67838 .70023 Mdot
.55179 .66858 Mdot
.37799 .22916 Mdot
.62714 .51243 Mdot
.41566 .6606 Mdot
.31335 .71242 Mdot
.34317 .54221 Mdot
.64715 .55159 Mdot
.40648 .6022 Mdot
.63579 .76199 Mdot
.38976 .335 Mdot
.79986 .37074 Mdot
.41864 .55511 Mdot
.73656 .59987 Mdot
.38249 .52335 Mdot
.33506 .43758 Mdot
.34702 .57335 Mdot
.54218 .70081 Mdot
.39317 .62307 Mdot
.50315 .49814 Mdot
.80691 .63204 Mdot
.62742 .74979 Mdot
.4712 .36097 Mdot
.3937 .51959 Mdot
.34316 .53913 Mdot
.44719 .35767 Mdot
.52521 .6967 Mdot
.34377 .57085 Mdot
.26042 .41 Mdot
.33858 .54997 Mdot
.65055 .51636 Mdot
.44366 .41544 Mdot
.54985 .7503 Mdot
.3352 .52518 Mdot
.54367 .72625 Mdot
.62471 .50663 Mdot
.61291 .56049 Mdot
.31262 .52064 Mdot
.62119 .50086 Mdot
.40605 .56685 Mdot
.44648 .39928 Mdot
.51571 .66318 Mdot
.40491 .46047 Mdot
.52232 .69856 Mdot
.5152 .77142 Mdot
.61647 .50735 Mdot
.78067 .42722 Mdot
.53629 .60581 Mdot
.62409 .51734 Mdot
.57036 .77723 Mdot
.33055 .61536 Mdot
.42438 .50246 Mdot
.61435 .77738 Mdot
.59939 .38352 Mdot
.77715 .42544 Mdot
.60853 .52396 Mdot
.33567 .55372 Mdot
.37596 .48425 Mdot
.6603 .52408 Mdot
.42451 .71282 Mdot
.5958 .27088 Mdot
.3567 .58259 Mdot
.53658 .70118 Mdot
.55126 .68142 Mdot
.42993 .53018 Mdot
.36737 .55038 Mdot
.63785 .37396 Mdot
.75508 .43717 Mdot
.76715 .41276 Mdot
.77525 .43559 Mdot
.55718 .37736 Mdot
.70783 .56154 Mdot
.60608 .51241 Mdot
.65897 .61199 Mdot
.69026 .47057 Mdot
.33435 .4821 Mdot
.58729 .37393 Mdot
.3516 .52152 Mdot
.40845 .53547 Mdot
.60935 .54584 Mdot
.76602 .4931 Mdot
.44968 .4933 Mdot
.53266 .65176 Mdot
.6248 .49971 Mdot
.2976 .59439 Mdot
.68858 .51675 Mdot
.47287 .32632 Mdot
.58719 .76444 Mdot
.65145 .54773 Mdot
.55921 .68006 Mdot
.66023 .51659 Mdot
.34069 .54265 Mdot
.34721 .58879 Mdot
.53985 .66547 Mdot
.44205 .36126 Mdot
.36358 .48366 Mdot
.3689 .51322 Mdot
.55623 .85813 Mdot
.70592 .65583 Mdot
.63234 .57841 Mdot
.38876 .55844 Mdot
.39949 .48119 Mdot
.4696 .36515 Mdot
.34088 .55128 Mdot
.40115 .51892 Mdot
.74485 .67269 Mdot
.58142 .53262 Mdot
.42548 .32796 Mdot
.41725 .65785 Mdot
.51533 .70604 Mdot
.38316 .20394 Mdot
.75871 .41738 Mdot
.58812 .51891 Mdot
.63703 .2932 Mdot
.77199 .43203 Mdot
.70316 .46807 Mdot
.3821 .21668 Mdot
.77699 .4322 Mdot
.6555 .31959 Mdot
.45692 .57314 Mdot
.34939 .58432 Mdot
.37642 .52116 Mdot
.46167 .33198 Mdot
.52724 .66854 Mdot
.52306 .42835 Mdot
.44477 .2324 Mdot
.38824 .52479 Mdot
.5512 .62743 Mdot
.43009 .21472 Mdot
.76545 .42994 Mdot
.44063 .33711 Mdot
.47094 .31802 Mdot
.38397 .51958 Mdot
.76307 .63211 Mdot
.53775 .69084 Mdot
.36636 .5572 Mdot
.33427 .53409 Mdot
.60326 .37996 Mdot
.55873 .67239 Mdot
.57024 .36807 Mdot
.74997 .43903 Mdot
.18621 .48562 Mdot
.52736 .85858 Mdot
.61636 .54917 Mdot
.2985 .27194 Mdot
.60873 .56154 Mdot
.75471 .3147 Mdot
.76932 .43813 Mdot
.37745 .54249 Mdot
.52528 .63953 Mdot
.36418 .56209 Mdot
.35169 .54022 Mdot
.34944 .54803 Mdot
.35082 .61786 Mdot
.49872 .83422 Mdot
.45865 .34737 Mdot
.35256 .47606 Mdot
.63477 .35162 Mdot
.32994 .23952 Mdot
.59448 .20278 Mdot
.35407 .51394 Mdot
.38609 .51597 Mdot
.55037 .7122 Mdot
.32535 .57042 Mdot
.6473 .55896 Mdot
.50717 .67709 Mdot
.38318 .48501 Mdot
.36571 .23987 Mdot
.34044 .56861 Mdot
.24772 .3151 Mdot
.66032 .51788 Mdot
.58203 .76426 Mdot
.34365 .48203 Mdot
.77839 .43167 Mdot
.77738 .42606 Mdot
.7792 .41021 Mdot
.65846 .55005 Mdot
.59327 .37256 Mdot
.55166 .21454 Mdot
.36423 .60791 Mdot
.39483 .56488 Mdot
.39593 .48047 Mdot
.57574 .39987 Mdot
.46574 .44638 Mdot
.74796 .55498 Mdot
.30614 .60116 Mdot
.63587 .3665 Mdot
.49857 .69117 Mdot
.83215 .48557 Mdot
.50787 .6778 Mdot
.42453 .32811 Mdot
.65299 .53152 Mdot
.46663 .32301 Mdot
.51143 .80885 Mdot
.53358 .66245 Mdot
.58212 .67817 Mdot
.60182 .37473 Mdot
.53333 .45614 Mdot
.39463 .1326 Mdot
.59262 .33324 Mdot
.28085 .41736 Mdot
.52339 .68306 Mdot
.34496 .51217 Mdot
.48799 .41006 Mdot
.5283 .45864 Mdot
.60636 .36563 Mdot
.38918 .53882 Mdot
.8023 .60852 Mdot
.6366 .37639 Mdot
.34623 .50032 Mdot
.62419 .37195 Mdot
.64575 .51729 Mdot
.62264 .36893 Mdot
.50685 .65648 Mdot
.40668 .50823 Mdot
.44752 .10299 Mdot
.5875 .46344 Mdot
.36498 .57117 Mdot
.62484 .49982 Mdot
.24272 .41864 Mdot
.3549 .53106 Mdot
.46518 .32012 Mdot
.6266 .34943 Mdot
.57093 .26379 Mdot
.35982 .57869 Mdot
.61626 .3653 Mdot
.51092 .65774 Mdot
.59639 .55706 Mdot
.70408 .2696 Mdot
.77471 .41709 Mdot
.52028 .67061 Mdot
.7442 .41332 Mdot
.67142 .5257 Mdot
.35709 .49516 Mdot
.33317 .54117 Mdot
.54676 .70495 Mdot
.70635 .34545 Mdot
.32119 .55994 Mdot
.38414 .54436 Mdot
.6111 .39418 Mdot
.61677 .40099 Mdot
.68346 .31135 Mdot
.5928 .38695 Mdot
.39185 .47793 Mdot
.54684 .70412 Mdot
.40791 .54324 Mdot
.55973 .69909 Mdot
.41275 .55309 Mdot
.48958 .65075 Mdot
.51224 .67154 Mdot
.80069 .56052 Mdot
.40108 .53771 Mdot
.30871 .49036 Mdot
.34924 .5437 Mdot
.34367 .55841 Mdot
.61886 .33988 Mdot
.44933 .35334 Mdot
.31537 .57716 Mdot
.66105 .37129 Mdot
.44007 .3328 Mdot
.24006 .61164 Mdot
.6045 .38118 Mdot
.46109 .3282 Mdot
.38778 .28238 Mdot
.74632 .42581 Mdot
.45637 .34019 Mdot
.58066 .20049 Mdot
.61384 .54816 Mdot
.50489 .69655 Mdot
.37367 .58072 Mdot
.17006 .46348 Mdot
.43089 .40556 Mdot
.75706 .43107 Mdot
.35727 .573 Mdot
.35255 .52372 Mdot
.57125 .70975 Mdot
.8652 .51127 Mdot
.61906 .39554 Mdot
.40294 .55807 Mdot
.54888 .72083 Mdot
.79964 .66771 Mdot
.60939 .33566 Mdot
.45783 .33668 Mdot
.65385 .51463 Mdot
.52538 .7327 Mdot
.77522 .41659 Mdot
.62838 .56477 Mdot
.60548 .29937 Mdot
.53018 .80355 Mdot
.35161 .56941 Mdot
.58225 .3694 Mdot
.43568 .82941 Mdot
.34504 .61054 Mdot
.61059 .58845 Mdot
.26009 .52473 Mdot
.55389 .672 Mdot
.65726 .51984 Mdot
.48598 .34252 Mdot
.5056 .67199 Mdot
.52725 .69685 Mdot
.60054 .54164 Mdot
.54591 .38062 Mdot
.51143 .44223 Mdot
.65638 .52406 Mdot
.67486 .72704 Mdot
.23611 .63125 Mdot
.75102 .4319 Mdot
.43743 .34456 Mdot
.25218 .69235 Mdot
.54471 .68946 Mdot
.43136 .19624 Mdot
.48096 .82973 Mdot
.36275 .58678 Mdot
.47634 .33671 Mdot
.70151 .50414 Mdot
.53069 .20973 Mdot
.637 .54025 Mdot
.48119 .47212 Mdot
.45058 .31634 Mdot
.34588 .57899 Mdot
.58364 .74389 Mdot
.39646 .54321 Mdot
.64922 .52615 Mdot
.52229 .75997 Mdot
.56035 .68311 Mdot
.6698 .52031 Mdot
.57894 .77423 Mdot
.40887 .53283 Mdot
.39535 .53866 Mdot
.36523 .41656 Mdot
.55046 .66081 Mdot
.77133 .41309 Mdot
.37141 .55978 Mdot
.36955 .51982 Mdot
.35385 .49942 Mdot
.28752 .5607 Mdot
.74811 .64444 Mdot
.40375 .55491 Mdot
.55873 .3574 Mdot
.43566 .53558 Mdot
.39833 .53517 Mdot
.55195 .72281 Mdot
.5303 .85061 Mdot
.76998 .44174 Mdot
.37425 .52423 Mdot
.3453 .56909 Mdot
.60306 .54243 Mdot
.50363 .42556 Mdot
.5302 .46473 Mdot
.58522 .3405 Mdot
.34757 .36796 Mdot
.3566 .61795 Mdot
.52598 .71143 Mdot
.43016 .33539 Mdot
.37988 .4943 Mdot
.53735 .71699 Mdot
.41716 .57759 Mdot
.63574 .37379 Mdot
.75337 .43472 Mdot
.61246 .71092 Mdot
.4505 .33819 Mdot
.51585 .38566 Mdot
.64787 .63328 Mdot
.61029 .388 Mdot
.39113 .57026 Mdot
.59087 .53799 Mdot
.57829 .35061 Mdot
.76041 .4278 Mdot
.42884 .48051 Mdot
.53257 .68227 Mdot
.55756 .68864 Mdot
.28687 .46177 Mdot
.65374 .36122 Mdot
.67715 .78688 Mdot
.64651 .51843 Mdot
.4099 .50131 Mdot
.60302 .62037 Mdot
.5581 .69054 Mdot
.28362 .46093 Mdot
.45921 .32797 Mdot
.6349 .54139 Mdot
.78885 .4197 Mdot
.54214 .71614 Mdot
.5569 .66292 Mdot
.42236 .54939 Mdot
.37189 .50419 Mdot
.32281 .39891 Mdot
.27078 .4746 Mdot
.633 .50637 Mdot
.43891 .35253 Mdot
.56999 .35185 Mdot
.39831 .54951 Mdot
.51037 .67011 Mdot
.25845 .6582 Mdot
.33462 .56212 Mdot
.63804 .37492 Mdot
.55018 .66987 Mdot
.44562 .35832 Mdot
.45138 .32251 Mdot
.34368 .55793 Mdot
.43996 .78895 Mdot
.61738 .52148 Mdot
.55883 .69479 Mdot
.59234 .66278 Mdot
.31813 .55217 Mdot
.37818 .5031 Mdot
.44637 .53509 Mdot
.62279 .56327 Mdot
.59677 .73845 Mdot
.42549 .33856 Mdot
.53857 .67839 Mdot
.36452 .56867 Mdot
.44632 .337 Mdot
.59987 .66198 Mdot
.76697 .43604 Mdot
.62504 .36821 Mdot
.47116 .32137 Mdot
.46482 .3572 Mdot
.43645 .33482 Mdot
.44803 .18898 Mdot
.55072 .64441 Mdot
.4657 .66883 Mdot
.34657 .57436 Mdot
.29413 .45719 Mdot
.34171 .59202 Mdot
.66308 .54351 Mdot
.59509 .3846 Mdot
.34902 .53931 Mdot
.42281 .54753 Mdot
.27778 .51807 Mdot
.29148 .54896 Mdot
.58436 .66454 Mdot
.5425 .66 Mdot
.29306 .52721 Mdot
.59785 .38117 Mdot
.87325 .543 Mdot
.32983 .19732 Mdot
.33486 .49128 Mdot
.51939 .4365 Mdot
.50914 .67304 Mdot
.59865 .53608 Mdot
.52666 .47542 Mdot
.64834 .50513 Mdot
.54273 .67738 Mdot
.40024 .54972 Mdot
.66345 .61232 Mdot
.47722 .36305 Mdot
.33498 .54875 Mdot
.64229 .52616 Mdot
.33551 .54937 Mdot
.65772 .54629 Mdot
.48192 .63388 Mdot
.68463 .70313 Mdot
.3761 .58703 Mdot
.32367 .53454 Mdot
.28491 .51331 Mdot
.35705 .5121 Mdot
.74813 .38844 Mdot
.51713 .68947 Mdot
.81081 .59367 Mdot
.42841 .5414 Mdot
.46456 .77339 Mdot
.33824 .57272 Mdot
.70286 .36538 Mdot
.37113 .50127 Mdot
.52557 .50639 Mdot
.35307 .58408 Mdot
.39465 .51217 Mdot
.61277 .51894 Mdot
.60284 .54267 Mdot
.51886 .65344 Mdot
.77495 .41413 Mdot
.28072 .27262 Mdot
.3726 .50844 Mdot
.55555 .36289 Mdot
.58108 .58363 Mdot
.45797 .35798 Mdot
.54438 .68057 Mdot
.80051 .67898 Mdot
.62297 .50514 Mdot
.60965 .32488 Mdot
.71541 .36252 Mdot
.5674 .38258 Mdot
.58512 .50527 Mdot
.31044 .61442 Mdot
.44852 .36237 Mdot
.34132 .5763 Mdot
.30998 .74486 Mdot
.71586 .62879 Mdot
.36659 .48095 Mdot
.65887 .50741 Mdot
.42475 .63014 Mdot
.25774 .69492 Mdot
.4856 .32695 Mdot
.48052 .35172 Mdot
.61606 .51498 Mdot
.59649 .39689 Mdot
.39475 .61355 Mdot
.46008 .32715 Mdot
.62532 .3812 Mdot
.76969 .40946 Mdot
.51747 .57092 Mdot
.53978 .68905 Mdot
.59527 .75231 Mdot
.65619 .66294 Mdot
.63107 .50583 Mdot
.66617 .35058 Mdot
.50732 .71575 Mdot
.57813 .6942 Mdot
.78066 .42022 Mdot
.61981 .34001 Mdot
.52719 .63722 Mdot
.36233 .48667 Mdot
.32986 .47837 Mdot
.38278 .52496 Mdot
.46965 .33532 Mdot
.35548 .51009 Mdot
.63088 .34938 Mdot
.63719 .53642 Mdot
.58947 .34745 Mdot
.61329 .52698 Mdot
.69611 .59202 Mdot
.36204 .55482 Mdot
.39065 .51167 Mdot
.46066 .40285 Mdot
.54275 .65053 Mdot
.47708 .81619 Mdot
.55447 .36221 Mdot
.59683 .36186 Mdot
.41216 .53264 Mdot
.50729 .66126 Mdot
.42504 .31611 Mdot
.4783 .39699 Mdot
.34178 .52126 Mdot
.51624 .68889 Mdot
.39972 .56128 Mdot
.3902 .26337 Mdot
.70033 .68925 Mdot
.54965 .69642 Mdot
.82879 .58478 Mdot
.38963 .55301 Mdot
.45951 .58083 Mdot
.39884 .48025 Mdot
.28406 .38809 Mdot
.31702 .54889 Mdot
.51135 .70194 Mdot
.37762 .52702 Mdot
.5095 .68659 Mdot
.60733 .39277 Mdot
.59951 .52155 Mdot
.51848 .67274 Mdot
.34378 .516 Mdot
.44436 .17071 Mdot
.64479 .52098 Mdot
.39544 .52037 Mdot
.6373 .55253 Mdot
.53167 .71938 Mdot
.54082 .65387 Mdot
.59037 .20978 Mdot
.60481 .57322 Mdot
.6419 .51515 Mdot
.40075 .56729 Mdot
.63612 .68544 Mdot
.40639 .54597 Mdot
.31636 .40736 Mdot
.42225 .53182 Mdot
.31809 .53903 Mdot
.73594 .26636 Mdot
.59861 .55237 Mdot
.69403 .77039 Mdot
.43757 .23595 Mdot
.465 .18046 Mdot
.52617 .738 Mdot
.48544 .32664 Mdot
.38688 .22272 Mdot
.74796 .43696 Mdot
.62809 .35865 Mdot
.34813 .54033 Mdot
.4953 .72115 Mdot
.64963 .51335 Mdot
.45391 .35386 Mdot
.37809 .58685 Mdot
.6401 .36753 Mdot
.64104 .25194 Mdot
.61933 .50057 Mdot
.54449 .68764 Mdot
.53867 .651 Mdot
.78828 .67454 Mdot
.36119 .5703 Mdot
.3913 .51639 Mdot
.65216 .53083 Mdot
.32054 .59588 Mdot
.43288 .351 Mdot
.52014 .30263 Mdot
.64004 .51468 Mdot
.59244 .4725 Mdot
.53203 .65997 Mdot
.35155 .52338 Mdot
.45667 .44043 Mdot
.63958 .43353 Mdot
.3137 .64601 Mdot
.46272 .33373 Mdot
.3387 .4037 Mdot
.51183 .7026 Mdot
.6357 .52997 Mdot
.41796 .28328 Mdot
.4157 .50335 Mdot
.35683 .52148 Mdot
.34224 .40519 Mdot
.50209 .41906 Mdot
.44431 .30639 Mdot
.32612 .57426 Mdot
.49324 .41908 Mdot
.413 .52832 Mdot
.37962 .48487 Mdot
.31543 .52734 Mdot
.38867 .50246 Mdot
.51317 .68488 Mdot
.27342 .52657 Mdot
.621 .36373 Mdot
.39853 .69538 Mdot
.49034 .4735 Mdot
.37339 .572 Mdot
.40221 .54659 Mdot
.32981 .64169 Mdot
.58494 .49786 Mdot
.51986 .68815 Mdot
.53557 .63295 Mdot
.61087 .51265 Mdot
.32025 .48173 Mdot
.58564 .40025 Mdot
.26447 .52096 Mdot
.59266 .34506 Mdot
.51566 .68969 Mdot
.59102 .36481 Mdot
.607 .51781 Mdot
.58165 .36879 Mdot
.55634 .37424 Mdot
.66205 .53072 Mdot
.52681 .65843 Mdot
.34514 .51886 Mdot
.61547 .50688 Mdot
.35974 .41649 Mdot
.46906 .33405 Mdot
.59015 .20935 Mdot
.43604 .54299 Mdot
.43005 .4507 Mdot
.28601 .33976 Mdot
.5883 .35092 Mdot
.71337 .68897 Mdot
.51267 .67124 Mdot
.44364 .36978 Mdot
.51143 .6839 Mdot
.50115 .82545 Mdot
.44475 .35348 Mdot
.57771 .19951 Mdot
.50809 .32727 Mdot
.59603 .24632 Mdot
.33278 .58138 Mdot
.49795 .63285 Mdot
.57368 .35791 Mdot
.64733 .51148 Mdot
.53438 .35878 Mdot
.40049 .51047 Mdot
.75952 .58915 Mdot
.57255 .67832 Mdot
.75699 .41491 Mdot
.62897 .53087 Mdot
.65371 .50174 Mdot
.35719 .56764 Mdot
.6304 .28054 Mdot
.4131 .51336 Mdot
.43618 .2922 Mdot
.34199 .38718 Mdot
.26226 .52476 Mdot
.40839 .5641 Mdot
.58835 .34271 Mdot
.3994 .56275 Mdot
.43472 .62098 Mdot
.33346 .77437 Mdot
.43724 .50664 Mdot
.79232 .55227 Mdot
.50681 .36866 Mdot
.536 .66514 Mdot
.33259 .4896 Mdot
.75844 .42222 Mdot
.38912 .55592 Mdot
.17799 .64482 Mdot
.45385 .34204 Mdot
.63704 .31427 Mdot
.32554 .56222 Mdot
.36746 .56217 Mdot
.35809 .77154 Mdot
.4816 .69688 Mdot
.79001 .42181 Mdot
.36092 .52204 Mdot
.36337 .36667 Mdot
.61988 .55958 Mdot
.42096 .51725 Mdot
.37914 .52113 Mdot
.22584 .58522 Mdot
.63404 .56044 Mdot
.58588 .35514 Mdot
.74582 .43343 Mdot
.56876 .35183 Mdot
.46328 .31236 Mdot
.53891 .48115 Mdot
.25922 .48608 Mdot
.69916 .6868 Mdot
.45598 .3179 Mdot
.32938 .54556 Mdot
.45905 .50373 Mdot
.38142 .55307 Mdot
.48336 .34913 Mdot
.64494 .55777 Mdot
.51526 .68034 Mdot
.61696 .69999 Mdot
.76737 .42521 Mdot
.34776 .49939 Mdot
.48817 .33741 Mdot
.52663 .67693 Mdot
.67251 .37416 Mdot
.53553 .67128 Mdot
.62825 .51601 Mdot
.66736 .53872 Mdot
.44373 .34655 Mdot
.51188 .68609 Mdot
.56652 .34495 Mdot
.44232 .23598 Mdot
.41994 .53725 Mdot
.67204 .55844 Mdot
.51615 .64797 Mdot
.53994 .72962 Mdot
.56455 .66377 Mdot
.35511 .55996 Mdot
.51041 .43099 Mdot
.3911 .48296 Mdot
.61896 .51104 Mdot
.62833 .37196 Mdot
.24935 .50503 Mdot
.36738 .78331 Mdot
.59149 .4687 Mdot
.31376 .5718 Mdot
.40035 .52522 Mdot
.38414 .51971 Mdot
.39696 .58448 Mdot
.4345 .26832 Mdot
.36503 .55174 Mdot
.61241 .52256 Mdot
.60712 .34013 Mdot
.36115 .57442 Mdot
.75693 .42126 Mdot
.50093 .44287 Mdot
.43344 .3299 Mdot
.51507 .48773 Mdot
.39003 .18646 Mdot
.52525 .67725 Mdot
.57824 .37979 Mdot
.62606 .35771 Mdot
.43528 .33271 Mdot
.64029 .50893 Mdot
.53051 .67013 Mdot
.29401 .36831 Mdot
.43495 .34258 Mdot
.37356 .52536 Mdot
.58575 .30316 Mdot
.83354 .54225 Mdot
.33016 .57135 Mdot
.35902 .538 Mdot
.74447 .42852 Mdot
.59179 .39846 Mdot
.15336 .49806 Mdot
.50514 .40486 Mdot
.44684 .35052 Mdot
.47223 .35598 Mdot
.56418 .66166 Mdot
.35274 .48473 Mdot
.61531 .53019 Mdot
.47715 .40867 Mdot
.24099 .44357 Mdot
.54254 .40376 Mdot
.74708 .31023 Mdot
.33922 .56149 Mdot
.35786 .76344 Mdot
.41066 .55107 Mdot
.57381 .70753 Mdot
.56432 .70127 Mdot
.52555 .68911 Mdot
.62129 .51343 Mdot
.50772 .76719 Mdot
.61064 .52818 Mdot
.36917 .18469 Mdot
.50441 .68434 Mdot
.50716 .24581 Mdot
.59507 .36916 Mdot
.33804 .59656 Mdot
.44255 .35846 Mdot
.60841 .47066 Mdot
.30951 .54002 Mdot
.75631 .63045 Mdot
.58689 .37327 Mdot
.53643 .65576 Mdot
.34615 .62482 Mdot
.21627 .33021 Mdot
.54397 .46146 Mdot
.47613 .56584 Mdot
.4626 .81344 Mdot
.44535 .35604 Mdot
.32972 .65025 Mdot
.44014 .36211 Mdot
.64473 .53441 Mdot
.39823 .50784 Mdot
.38751 .50001 Mdot
.41182 .55784 Mdot
.36294 .55211 Mdot
.60723 .54293 Mdot
.41636 .56906 Mdot
.44265 .8445 Mdot
.74857 .4315 Mdot
.39437 .24709 Mdot
.46562 .32516 Mdot
.66299 .51626 Mdot
.60137 .34148 Mdot
.77248 .41162 Mdot
.26758 .46596 Mdot
.35661 .58444 Mdot
.34938 .54175 Mdot
.78423 .42663 Mdot
.31182 .53961 Mdot
.31748 .60837 Mdot
.61998 .36192 Mdot
.57952 .47566 Mdot
.48044 .32501 Mdot
.4678 .32352 Mdot
.65709 .5402 Mdot
.5113 .6848 Mdot
.45954 .33006 Mdot
.6081 .39588 Mdot
.41848 .56941 Mdot
.36038 .49806 Mdot
.5167 .64788 Mdot
.48134 .82991 Mdot
.48853 .3286 Mdot
.35923 .62541 Mdot
.51009 .69533 Mdot
.56573 .65888 Mdot
.35785 .52399 Mdot
.44221 .51887 Mdot
.51756 .7199 Mdot
.45278 .32072 Mdot
.66212 .51426 Mdot
.55711 .23274 Mdot
.64742 .52878 Mdot
.52747 .67171 Mdot
.43186 .54022 Mdot
.52882 .6589 Mdot
.38417 .55981 Mdot
.82356 .32105 Mdot
.37953 .49937 Mdot
.65557 .76464 Mdot
.2906 .3925 Mdot
.62389 .35349 Mdot
.5658 .34737 Mdot
.7521 .42654 Mdot
.50917 .6955 Mdot
.3834 .49447 Mdot
.46406 .36178 Mdot
.49346 .18511 Mdot
.48892 .66005 Mdot
.63369 .36955 Mdot
.58484 .39889 Mdot
.63627 .56218 Mdot
.33334 .56799 Mdot
.35425 .51853 Mdot
.58128 .36644 Mdot
.3111 .31488 Mdot
.53057 .71195 Mdot
.39156 .51759 Mdot
.40039 .52917 Mdot
.62134 .35546 Mdot
.44023 .23884 Mdot
.48552 .63814 Mdot
.39342 .50648 Mdot
.50152 .358 Mdot
.66025 .54699 Mdot
.3993 .58161 Mdot
.41448 .57186 Mdot
.47315 .35003 Mdot
.35559 .25436 Mdot
.2771 .72436 Mdot
.66457 .53237 Mdot
.7705 .41338 Mdot
.3397 .5189 Mdot
.59714 .3693 Mdot
.34817 .50963 Mdot
.24094 .34676 Mdot
.7483 .4247 Mdot
.37281 .54634 Mdot
.33017 .49842 Mdot
.56426 .6816 Mdot
.36904 .55319 Mdot
.24849 .59712 Mdot
.58058 .33962 Mdot
.37061 .54915 Mdot
.45572 .79856 Mdot
.62328 .56197 Mdot
.32961 .49577 Mdot
.48245 .33497 Mdot
.27918 .39047 Mdot
.65157 .64363 Mdot
.57169 .39883 Mdot
.45877 .32332 Mdot
.34457 .51798 Mdot
.59374 .39566 Mdot
.64578 .50841 Mdot
.75211 .60953 Mdot
.35989 .58983 Mdot
.64777 .52443 Mdot
.63568 .53571 Mdot
.44663 .34277 Mdot
.72319 .74448 Mdot
.30765 .57114 Mdot
.35478 .51283 Mdot
.2145 .55307 Mdot
.57113 .68662 Mdot
.348 .5175 Mdot
.33046 .55594 Mdot
.61741 .53995 Mdot
.54103 .60576 Mdot
.4434 .6357 Mdot
.551 .30207 Mdot
.65838 .54596 Mdot
.57959 .40919 Mdot
.59273 .3951 Mdot
.46536 .32577 Mdot
.5424 .6678 Mdot
.4421 .31894 Mdot
.61211 .3759 Mdot
.3447 .56985 Mdot
.62707 .54535 Mdot
.30607 .66763 Mdot
.59457 .53061 Mdot
.6431 .35687 Mdot
.55997 .72412 Mdot
.61067 .62559 Mdot
.25742 .7335 Mdot
.66662 .65175 Mdot
.60056 .49889 Mdot
.45883 .35785 Mdot
.53516 .34077 Mdot
.39988 .5274 Mdot
.37969 .6575 Mdot
.33772 .53564 Mdot
.45553 .80909 Mdot
.603 .38645 Mdot
.78178 .42024 Mdot
.39769 .5069 Mdot
.34704 .3928 Mdot
.63207 .49283 Mdot
.63347 .56331 Mdot
.36065 .54535 Mdot
.62478 .51639 Mdot
.36871 .5068 Mdot
.60868 .3382 Mdot
.68309 .76822 Mdot
.3983 .52283 Mdot
.41653 .48849 Mdot
.58646 .56463 Mdot
.58754 .20703 Mdot
.56447 .34058 Mdot
.35655 .7645 Mdot
.19148 .36663 Mdot
.62361 .51843 Mdot
.38236 .47412 Mdot
.57574 .36226 Mdot
.74432 .42796 Mdot
.58598 .32625 Mdot
.33837 .541 Mdot
.34263 .55349 Mdot
.4123 .53419 Mdot
.39549 .53932 Mdot
.37395 .65517 Mdot
.29464 .57473 Mdot
.36244 .75145 Mdot
.35127 .54146 Mdot
.59206 .72425 Mdot
.60837 .53168 Mdot
.58486 .66818 Mdot
.49677 .34715 Mdot
.34129 .56345 Mdot
.49628 .72627 Mdot
.66421 .52588 Mdot
.36654 .18689 Mdot
.6357 .56141 Mdot
.60156 .35018 Mdot
.59959 .54655 Mdot
.38102 .56448 Mdot
.55197 .6825 Mdot
.59021 .33519 Mdot
.737 .56271 Mdot
.62929 .35917 Mdot
.36435 .57143 Mdot
.44055 .25099 Mdot
.62576 .35987 Mdot
.50368 .45447 Mdot
.5515 .67729 Mdot
.3699 .36785 Mdot
.56121 .70923 Mdot
.37458 .54828 Mdot
.37866 .54617 Mdot
.76217 .40993 Mdot
.61005 .50457 Mdot
.52591 .71744 Mdot
.56514 .8563 Mdot
.44236 .31432 Mdot
.53225 .69393 Mdot
.37881 .60547 Mdot
.51027 .42492 Mdot
.55362 .69898 Mdot
.33211 .35591 Mdot
.64176 .5087 Mdot
.54248 .64006 Mdot
.40656 .59512 Mdot
.55781 .57541 Mdot
.46336 .36998 Mdot
.64057 .35946 Mdot
.55052 .52981 Mdot
.57276 .35697 Mdot
.66706 .5264 Mdot
.6463 .37372 Mdot
.61694 .55716 Mdot
.56336 .7763 Mdot
.47286 .68109 Mdot
.5932 .52183 Mdot
.67059 .52987 Mdot
.60749 .37207 Mdot
.37342 .58907 Mdot
.49466 .50003 Mdot
.31935 .56711 Mdot
.34559 .58976 Mdot
.61636 .55926 Mdot
.52955 .71669 Mdot
.50175 .6881 Mdot
.51944 .62375 Mdot
.54578 .6528 Mdot
.59847 .34029 Mdot
.70009 .70043 Mdot
.50603 .8105 Mdot
.65204 .5433 Mdot
.67287 .54576 Mdot
.40542 .54626 Mdot
.60047 .37088 Mdot
.60616 .39127 Mdot
.62082 .53694 Mdot
.34092 .66882 Mdot
.40635 .48576 Mdot
.56276 .71647 Mdot
.50439 .68142 Mdot
.54817 .70137 Mdot
.5567 .6561 Mdot
.45694 .69566 Mdot
.64663 .51061 Mdot
.50633 .68955 Mdot
.36633 .54492 Mdot
.34041 .55031 Mdot
.77413 .42091 Mdot
.47641 .32729 Mdot
.41371 .58334 Mdot
.43348 .50056 Mdot
.35581 .52475 Mdot
.62559 .36672 Mdot
.42847 .47268 Mdot
.75738 .41699 Mdot
.63265 .38841 Mdot
.57432 .39715 Mdot
.78019 .42701 Mdot
.55951 .62342 Mdot
.20132 .34039 Mdot
.40277 .55807 Mdot
.46555 .49636 Mdot
.60072 .36584 Mdot
.72308 .70621 Mdot
.60379 .7099 Mdot
.40763 .56683 Mdot
.53135 .56769 Mdot
.59813 .33386 Mdot
.57292 .68548 Mdot
.34239 .52617 Mdot
.77155 .43812 Mdot
.43198 .33283 Mdot
.37921 .60633 Mdot
.74461 .43294 Mdot
.51537 .69236 Mdot
.4085 .32331 Mdot
.55297 .64768 Mdot
.60224 .3323 Mdot
.32688 .50089 Mdot
.40049 .1275 Mdot
.57117 .37164 Mdot
.49184 .19373 Mdot
.47427 .65656 Mdot
.39895 .51926 Mdot
.57038 .36683 Mdot
.57327 .69357 Mdot
.66118 .54792 Mdot
.48333 .42124 Mdot
.51484 .6664 Mdot
.77589 .41355 Mdot
.77503 .42628 Mdot
.6214 .3605 Mdot
.54858 .66323 Mdot
.42682 .52629 Mdot
.56309 .69536 Mdot
.60038 .54989 Mdot
.3918 .58017 Mdot
.2676 .27948 Mdot
.31691 .48895 Mdot
.51645 .706 Mdot
.63946 .37484 Mdot
.46646 .3671 Mdot
.36823 .58575 Mdot
.45039 .21358 Mdot
.33089 .56287 Mdot
.63653 .55639 Mdot
.78293 .63856 Mdot
.29086 .65205 Mdot
.34892 .57578 Mdot
.40469 .54518 Mdot
.66183 .52801 Mdot
.36047 .58527 Mdot
.33046 .56948 Mdot
.608 .5851 Mdot
.56278 .68267 Mdot
.38404 .52717 Mdot
.62008 .38631 Mdot
.35928 .78534 Mdot
.33743 .52076 Mdot
.79298 .53094 Mdot
.36398 .37918 Mdot
.76676 .66693 Mdot
.35522 .5063 Mdot
.35228 .42334 Mdot
.38516 .53884 Mdot
.34952 .5637 Mdot
.40476 .56194 Mdot
.33574 .74334 Mdot
.60633 .3746 Mdot
.63578 .3581 Mdot
.46305 .37055 Mdot
.3617 .37703 Mdot
.4765 .33945 Mdot
.6576 .54379 Mdot
.69552 .27532 Mdot
.74833 .42835 Mdot
.51063 .68473 Mdot
.40481 .50378 Mdot
.59794 .33046 Mdot
.34835 .5271 Mdot
.38498 .5625 Mdot
.6051 .33478 Mdot
.57576 .38607 Mdot
.65175 .32926 Mdot
.43808 .3589 Mdot
.5201 .68174 Mdot
.41945 .55652 Mdot
.44013 .33301 Mdot
.4255 .52112 Mdot
.50398 .41152 Mdot
.52009 .68466 Mdot
.56412 .6924 Mdot
.52864 .72135 Mdot
.34377 .56959 Mdot
.3772 .57061 Mdot
.61049 .53036 Mdot
.5114 .65087 Mdot
.65717 .53326 Mdot
.57682 .35118 Mdot
.57709 .33659 Mdot
.33834 .54168 Mdot
.36549 .62808 Mdot
.46804 .35796 Mdot
.5963 .35023 Mdot
.78526 .42721 Mdot
.44985 .36944 Mdot
.35639 .57233 Mdot
.58634 .34444 Mdot
.4689 .32305 Mdot
.36229 .69114 Mdot
.17884 .39678 Mdot
.47405 .36241 Mdot
.36265 .54406 Mdot
.36767 .77941 Mdot
.40426 .2966 Mdot
.43451 .31874 Mdot
.64544 .54648 Mdot
.33201 .56104 Mdot
.22859 .41313 Mdot
.45925 .3161 Mdot
.45964 .81888 Mdot
.62179 .35072 Mdot
.52682 .60111 Mdot
.41875 .58693 Mdot
.39631 .66649 Mdot
.4404 .31817 Mdot
.53435 .67419 Mdot
.49841 .65998 Mdot
.36911 .53407 Mdot
.49605 .35732 Mdot
.62008 .56548 Mdot
.62139 .34675 Mdot
.55683 .35998 Mdot
.55368 .66734 Mdot
.65088 .699 Mdot
.62887 .38269 Mdot
.39176 .62058 Mdot
.62805 .29044 Mdot
.36688 .46133 Mdot
.54778 .77677 Mdot
.72734 .56611 Mdot
.36473 .49355 Mdot
.47386 .36061 Mdot
.65253 .50692 Mdot
.61403 .52208 Mdot
.63302 .51474 Mdot
.56316 .35571 Mdot
.52421 .4778 Mdot
.58628 .37604 Mdot
.74836 .60005 Mdot
.4467 .33647 Mdot
.37162 .34265 Mdot
.38328 .49572 Mdot
.39932 .52443 Mdot
.42746 .51863 Mdot
.41237 .51593 Mdot
.38687 .53608 Mdot
.63696 .50888 Mdot
.5621 .37066 Mdot
.56755 .26648 Mdot
.5368 .70264 Mdot
.68599 .35637 Mdot
.5947 .3691 Mdot
.74526 .42862 Mdot
.45856 .34951 Mdot
.34152 .4349 Mdot
.62152 .40058 Mdot
.59184 .36401 Mdot
.41075 .58115 Mdot
.55014 .71394 Mdot
.29442 .59724 Mdot
.38464 .54381 Mdot
.59345 .35027 Mdot
.53694 .38086 Mdot
.29466 .62559 Mdot
.45118 .53364 Mdot
.41638 .32991 Mdot
.51281 .42908 Mdot
.42524 .34432 Mdot
.44062 .5314 Mdot
.72742 .70213 Mdot
.6125 .37483 Mdot
.60911 .35145 Mdot
.48736 .33866 Mdot
.45614 .58457 Mdot
.54775 .6664 Mdot
.78234 .42028 Mdot
.63106 .55373 Mdot
.3804 .55156 Mdot
.56723 .35061 Mdot
.46874 .58986 Mdot
.60498 .27892 Mdot
.63966 .5163 Mdot
.63082 .38974 Mdot
.33793 .57093 Mdot
.36103 .5429 Mdot
.44847 .35766 Mdot
.47171 .4962 Mdot
.35757 .60418 Mdot
.46384 .18057 Mdot
.68383 .70142 Mdot
.64504 .73562 Mdot
.35684 .52121 Mdot
.55652 .6685 Mdot
.77059 .43692 Mdot
.43707 .34574 Mdot
.42689 .54797 Mdot
.18122 .38446 Mdot
.49829 .6954 Mdot
.64144 .52899 Mdot
.7751 .43466 Mdot
.52268 .47631 Mdot
.3302 .56037 Mdot
.33808 .53487 Mdot
.35887 .5563 Mdot
.15866 .41478 Mdot
.63287 .3737 Mdot
.56278 .66302 Mdot
.46489 .3353 Mdot
.55669 .65865 Mdot
.63351 .35849 Mdot
.62097 .68717 Mdot
.36221 .57726 Mdot
.56325 .7181 Mdot
.53741 .67468 Mdot
.63807 .56183 Mdot
.65036 .55984 Mdot
.65463 .33063 Mdot
.3806 .49992 Mdot
.7679 .44025 Mdot
.56328 .70525 Mdot
.57423 .3894 Mdot
.44455 .354 Mdot
.61457 .50944 Mdot
.35135 .54275 Mdot
.61823 .36952 Mdot
.35483 .48845 Mdot
.55389 .70378 Mdot
.59261 .36445 Mdot
.76084 .4437 Mdot
.47776 .35028 Mdot
.34575 .54912 Mdot
.42525 .3112 Mdot
.7823 .42726 Mdot
.40246 .52987 Mdot
.26085 .50839 Mdot
.49933 .3258 Mdot
.74239 .55753 Mdot
.58164 .37791 Mdot
.76498 .41899 Mdot
.56649 .69345 Mdot
.57904 .61113 Mdot
.60885 .34816 Mdot
.29512 .4668 Mdot
.48784 .51988 Mdot
.41695 .56149 Mdot
.54693 .69261 Mdot
.5266 .34411 Mdot
.41401 .1936 Mdot
.39557 .28722 Mdot
.3901 .52046 Mdot
.5704 .36471 Mdot
.4617 .32116 Mdot
.6511 .54575 Mdot
.79448 .53213 Mdot
.48166 .72026 Mdot
.64494 .37777 Mdot
.4053 .55612 Mdot
.56236 .70604 Mdot
.62231 .53655 Mdot
.6752 .60422 Mdot
.6163 .39405 Mdot
.59795 .38686 Mdot
.35528 .57522 Mdot
.45432 .32989 Mdot
.34977 .28889 Mdot
.6355 .35506 Mdot
.56661 .35579 Mdot
.68621 .34325 Mdot
.48947 .34264 Mdot
.37024 .53915 Mdot
.51834 .62388 Mdot
.38348 .59124 Mdot
.49613 .19049 Mdot
.75774 .41833 Mdot
.53574 .70377 Mdot
.33678 .55113 Mdot
.5863 .29409 Mdot
.6001 .34437 Mdot
.5202 .43853 Mdot
.6466 .35891 Mdot
.63684 .50762 Mdot
.56805 .34847 Mdot
.34543 .52446 Mdot
.63267 .49251 Mdot
.47031 .35599 Mdot
.39197 .50511 Mdot
.3781 .57122 Mdot
.57458 .69675 Mdot
.64504 .53598 Mdot
.25317 .67328 Mdot
.67327 .52858 Mdot
.66071 .51754 Mdot
.51307 .63848 Mdot
.37135 .52983 Mdot
.59941 .35374 Mdot
.63801 .35024 Mdot
.42654 .54385 Mdot
.70584 .71697 Mdot
.55152 .66824 Mdot
.65655 .33076 Mdot
.15622 .4914 Mdot
.40723 .60905 Mdot
.77595 .43973 Mdot
.45662 .48059 Mdot
.64634 .56039 Mdot
.3559 .54387 Mdot
.51717 .70502 Mdot
.56551 .36648 Mdot
.62779 .3832 Mdot
.43104 .5359 Mdot
.63077 .53851 Mdot
.44261 .32215 Mdot
.59576 .38881 Mdot
.62092 .28103 Mdot
.36422 .55739 Mdot
.76265 .58427 Mdot
.58566 .3857 Mdot
.52522 .17126 Mdot
.5793 .27384 Mdot
.54641 .69692 Mdot
.3863 .56395 Mdot
.52721 .65236 Mdot
.46902 .33952 Mdot
.56141 .39446 Mdot
.63531 .53791 Mdot
.4545 .53265 Mdot
.31726 .77322 Mdot
.60215 .37512 Mdot
.51387 .6855 Mdot
.34761 .57534 Mdot
.43118 .59339 Mdot
.35913 .50813 Mdot
.54662 .6088 Mdot
.48343 .30902 Mdot
.61738 .56067 Mdot
.63881 .55469 Mdot
.40793 .53544 Mdot
.43323 .3473 Mdot
.6206 .33789 Mdot
.61884 .34602 Mdot
.88472 .50911 Mdot
.76029 .44398 Mdot
.31213 .40047 Mdot
.34451 .55296 Mdot
.57393 .39085 Mdot
.35912 .77849 Mdot
.65237 .53068 Mdot
.41533 .51741 Mdot
.56479 .38529 Mdot
.63725 .43935 Mdot
.50253 .41402 Mdot
.37985 .53694 Mdot
.35264 .61613 Mdot
.63383 .55389 Mdot
.4825 .39966 Mdot
.5847 .37333 Mdot
.42029 .52599 Mdot
.6727 .52431 Mdot
.67724 .30886 Mdot
.41011 .82747 Mdot
.52044 .68224 Mdot
.64392 .35556 Mdot
.63836 .50897 Mdot
.35383 .60603 Mdot
.46494 .32451 Mdot
.57712 .34519 Mdot
.62868 .36498 Mdot
.39113 .57622 Mdot
.38918 .59461 Mdot
.41025 .60729 Mdot
.52385 .6964 Mdot
.61257 .54392 Mdot
.40217 .50869 Mdot
.65543 .69985 Mdot
.4133 .53258 Mdot
.61273 .5405 Mdot
.55497 .10265 Mdot
.36945 .59251 Mdot
.36098 .5078 Mdot
.36663 .28467 Mdot
.51658 .66209 Mdot
.55389 .65727 Mdot
.68926 .70266 Mdot
.34461 .55258 Mdot
.60837 .25757 Mdot
.5197 .67841 Mdot
.55381 .67259 Mdot
.49628 .25371 Mdot
.39757 .57765 Mdot
.49989 .38822 Mdot
.61545 .53288 Mdot
.62366 .50331 Mdot
.5629 .68937 Mdot
.35266 .60421 Mdot
.65435 .51395 Mdot
.41366 .65079 Mdot
.5937 .37247 Mdot
.72986 .70002 Mdot
.54751 .71085 Mdot
.46722 .46945 Mdot
.64969 .52362 Mdot
.37415 .18064 Mdot
.54251 .55941 Mdot
.41256 .54286 Mdot
.35055 .55129 Mdot
.47592 .34851 Mdot
.30583 .53807 Mdot
.76768 .41263 Mdot
.62548 .51543 Mdot
.32512 .28115 Mdot
.52663 .68974 Mdot
.37572 .50112 Mdot
.32397 .44146 Mdot
.67874 .61375 Mdot
.79175 .55996 Mdot
.53607 .66594 Mdot
.54189 .69134 Mdot
.59586 .38091 Mdot
.61534 .37995 Mdot
.37675 .53279 Mdot
.61653 .51636 Mdot
.51744 .64267 Mdot
.62329 .55277 Mdot
.61358 .37531 Mdot
.5955 .3608 Mdot
.74889 .42308 Mdot
.32963 .51556 Mdot
.60947 .33611 Mdot
.66618 .29147 Mdot
.6462 .70421 Mdot
.57684 .68592 Mdot
.24172 .70365 Mdot
.67649 .60155 Mdot
.2887 .34814 Mdot
.42866 .34992 Mdot
.79446 .41728 Mdot
.60074 .53355 Mdot
.40527 .54213 Mdot
.34711 .53679 Mdot
.76532 .43035 Mdot
.60142 .5121 Mdot
.45979 .3531 Mdot
.60687 .50631 Mdot
.44553 .334 Mdot
.57781 .33219 Mdot
.33831 .51996 Mdot
.33064 .54698 Mdot
.63562 .50961 Mdot
.58459 .35788 Mdot
.61597 .3406 Mdot
.43369 .35801 Mdot
.37973 .423 Mdot
.62159 .36268 Mdot
.54957 .70967 Mdot
.47055 .75276 Mdot
.77378 .42744 Mdot
.34402 .52338 Mdot
.28779 .45987 Mdot
.33582 .6568 Mdot
.41919 .55137 Mdot
.77746 .43328 Mdot
.86782 .55813 Mdot
.3811 .49695 Mdot
.83327 .61473 Mdot
.76801 .41815 Mdot
.51692 .66045 Mdot
.57406 .37282 Mdot
.76728 .41179 Mdot
.39187 .60617 Mdot
.42401 .32724 Mdot
.431 .55885 Mdot
.51735 .66421 Mdot
.54113 .72539 Mdot
.62595 .76703 Mdot
.49732 .19139 Mdot
.44727 .36453 Mdot
.45012 .34936 Mdot
.61151 .34855 Mdot
.71792 .26074 Mdot
.40836 .59279 Mdot
.45042 .35243 Mdot
.31441 .29783 Mdot
.40279 .55059 Mdot
.31414 .41302 Mdot
.53046 .56339 Mdot
.55614 .66897 Mdot
.57387 .63916 Mdot
.60538 .34504 Mdot
.51427 .68489 Mdot
.63004 .7243 Mdot
.42854 .52064 Mdot
.52188 .68693 Mdot
.61529 .54237 Mdot
.708 .47028 Mdot
.53353 .65357 Mdot
.4694 .41577 Mdot
.616 .52914 Mdot
.49361 .31368 Mdot
.34358 .31029 Mdot
.17998 .66877 Mdot
.62403 .51477 Mdot
.57982 .3544 Mdot
.60263 .33278 Mdot
.61799 .3474 Mdot
.51338 .66717 Mdot
.60623 .39359 Mdot
.52645 .70244 Mdot
.46077 .22567 Mdot
.33612 .43258 Mdot
.44287 .34526 Mdot
.6128 .57579 Mdot
.54138 .68273 Mdot
.72509 .65074 Mdot
.26195 .73398 Mdot
.36072 .54666 Mdot
.67296 .52642 Mdot
.48691 .33957 Mdot
.65238 .19771 Mdot
.47448 .34859 Mdot
.57565 .36374 Mdot
.73599 .69409 Mdot
.37288 .50564 Mdot
.24632 .57965 Mdot
.4743 .35565 Mdot
.52942 .66436 Mdot
.4018 .52778 Mdot
.64659 .34302 Mdot
.46484 .32689 Mdot
.43487 .32923 Mdot
.39077 .53108 Mdot
.54166 .65628 Mdot
.59616 .35698 Mdot
.60223 .52836 Mdot
.48474 .31651 Mdot
.33444 .60172 Mdot
.40182 .58193 Mdot
.396 .48757 Mdot
.53244 .45942 Mdot
.25384 .36413 Mdot
.62272 .51971 Mdot
.39143 .34728 Mdot
.62057 .37543 Mdot
.49013 .29896 Mdot
.69442 .66222 Mdot
.59658 .56695 Mdot
.75945 .41764 Mdot
.75283 .42113 Mdot
.38309 .53539 Mdot
.26117 .3545 Mdot
.81078 .5816 Mdot
.57993 .54765 Mdot
.77307 .43086 Mdot
.61914 .34425 Mdot
.49691 .66602 Mdot
.60512 .77012 Mdot
.36594 .59675 Mdot
.63335 .56514 Mdot
.62197 .36679 Mdot
.2374 .3518 Mdot
.45107 .33643 Mdot
.72286 .69129 Mdot
.36373 .57476 Mdot
.39015 .51205 Mdot
.62598 .52779 Mdot
.611 .52881 Mdot
.7812 .54939 Mdot
.65232 .73876 Mdot
.56331 .42216 Mdot
.65781 .58852 Mdot
.21582 .38427 Mdot
.58182 .66088 Mdot
.52115 .7097 Mdot
.74763 .43757 Mdot
.6474 .50018 Mdot
.33862 .53091 Mdot
.50631 .66856 Mdot
.79214 .56248 Mdot
.49534 .70631 Mdot
.32783 .40409 Mdot
.61541 .26667 Mdot
.37526 .56416 Mdot
.55585 .71009 Mdot
.51587 .68453 Mdot
.54451 .64527 Mdot
.77937 .42868 Mdot
.36049 .52071 Mdot
.37027 .58855 Mdot
.40232 .51384 Mdot
.31138 .59328 Mdot
.36719 .5554 Mdot
.68287 .66806 Mdot
.595 .46931 Mdot
.33729 .2682 Mdot
.41752 .55054 Mdot
.62896 .50244 Mdot
.39834 .49601 Mdot
.43258 .34334 Mdot
.40632 .55514 Mdot
.31314 .40658 Mdot
.63688 .52171 Mdot
.45601 .58102 Mdot
.64951 .59309 Mdot
.36516 .57563 Mdot
.45832 .3182 Mdot
.27254 .34805 Mdot
.25097 .68121 Mdot
.68368 .34913 Mdot
.55149 .70837 Mdot
.62032 .39937 Mdot
.60156 .55335 Mdot
.60186 .35432 Mdot
.41669 .53912 Mdot
.76042 .44196 Mdot
.71409 .53308 Mdot
.47172 .47217 Mdot
.33388 .54477 Mdot
.38263 .46742 Mdot
.55851 .6881 Mdot
.58397 .34739 Mdot
.57517 .72731 Mdot
.35237 .56023 Mdot
.46543 .33323 Mdot
.45493 .32726 Mdot
.65818 .72328 Mdot
.26948 .29486 Mdot
.58571 .63001 Mdot
.62462 .52596 Mdot
.63739 .3746 Mdot
.4439 .31696 Mdot
.47212 .68893 Mdot
.62603 .56709 Mdot
.64499 .5609 Mdot
.63886 .54126 Mdot
.37909 .55711 Mdot
.76233 .41459 Mdot
.28955 .30358 Mdot
.77369 .41261 Mdot
.36899 .57558 Mdot
.63054 .37029 Mdot
.763 .4115 Mdot
.47881 .34157 Mdot
.65591 .54327 Mdot
.61016 .37949 Mdot
.37473 .55016 Mdot
.52515 .67963 Mdot
.40299 .42188 Mdot
.26265 .41821 Mdot
.42333 .23169 Mdot
.41731 .23425 Mdot
.51308 .70924 Mdot
.34014 .21763 Mdot
.67078 .55962 Mdot
.34185 .66802 Mdot
.4208 .37006 Mdot
.42755 .53795 Mdot
.6289 .79553 Mdot
.5827 .3723 Mdot
.59609 .33674 Mdot
.37634 .53985 Mdot
.57246 .38441 Mdot
.37017 .50201 Mdot
.60537 .38456 Mdot
.67406 .33719 Mdot
.35185 .59568 Mdot
.59828 .33785 Mdot
.43776 .5592 Mdot
.37152 .58551 Mdot
.56062 .67747 Mdot
.57174 .35127 Mdot
.41475 .53304 Mdot
.71813 .24749 Mdot
.61103 .51803 Mdot
.77902 .42744 Mdot
.57808 .44664 Mdot
.64536 .51145 Mdot
.53535 .69677 Mdot
.33198 .58348 Mdot
.45679 .36078 Mdot
.53269 .6762 Mdot
.6537 .3291 Mdot
.47747 .35418 Mdot
.70045 .6985 Mdot
.55553 .70462 Mdot
.77169 .42659 Mdot
.46836 .35851 Mdot
.37828 .46963 Mdot
.58344 .3357 Mdot
.23664 .45626 Mdot
.77657 .41547 Mdot
.35349 .51863 Mdot
.56022 .34335 Mdot
.62387 .50066 Mdot
.38115 .51996 Mdot
.5698 .36944 Mdot
.78035 .42915 Mdot
.38681 .55349 Mdot
.40009 .53738 Mdot
.58486 .76883 Mdot
.78213 .60434 Mdot
.44845 .35667 Mdot
.56886 .70087 Mdot
.36708 .54511 Mdot
.4353 .35654 Mdot
.73167 .32703 Mdot
.37738 .48741 Mdot
.51806 .65513 Mdot
.27224 .50857 Mdot
.61925 .37895 Mdot
.65744 .53387 Mdot
.6417 .3515 Mdot
.43058 .33499 Mdot
.60465 .84716 Mdot
.75333 .41696 Mdot
.43986 .56099 Mdot
.42111 .51551 Mdot
.5391 .37099 Mdot
.518 .68845 Mdot
.54713 .41454 Mdot
.34615 .54935 Mdot
.31372 .4906 Mdot
.38634 .50582 Mdot
.57783 .26956 Mdot
.55023 .66808 Mdot
.35532 .51289 Mdot
.34787 .62686 Mdot
.32848 .53149 Mdot
.45128 .31834 Mdot
.36604 .3223 Mdot
.38708 .48793 Mdot
.33618 .15704 Mdot
.78361 .42869 Mdot
.60684 .33585 Mdot
.62172 .4168 Mdot
.79903 .35875 Mdot
.55828 .7796 Mdot
.5243 .6994 Mdot
.33524 .46216 Mdot
.59874 .35557 Mdot
.40674 .81775 Mdot
.37399 .1952 Mdot
.37137 .58428 Mdot
.33662 .56709 Mdot
.57563 .36371 Mdot
.57195 .38782 Mdot
.75237 .43806 Mdot
.41529 .54987 Mdot
.42284 .47558 Mdot
.63263 .38667 Mdot
.36816 .56151 Mdot
.26514 .55566 Mdot
.60353 .53529 Mdot
.56293 .67352 Mdot
.65188 .54518 Mdot
.62542 .56353 Mdot
.43539 .70261 Mdot
.68283 .70255 Mdot
.61117 .53832 Mdot
.67396 .5157 Mdot
.30239 .41493 Mdot
.30557 .46586 Mdot
.44038 .32132 Mdot
.35457 .23488 Mdot
.61741 .35126 Mdot
.36201 .5212 Mdot
.51255 .70567 Mdot
.4048 .67471 Mdot
.69864 .42552 Mdot
.7581 .66726 Mdot
.3454 .56063 Mdot
.60683 .34287 Mdot
.78099 .42398 Mdot
.35747 .59737 Mdot
.46358 .28585 Mdot
.39055 .51555 Mdot
.59657 .33086 Mdot
.48736 .75823 Mdot
.25419 .54296 Mdot
.56031 .31909 Mdot
.54689 .63917 Mdot
.39543 .5013 Mdot
.54016 .70986 Mdot
.64755 .51976 Mdot
.43443 .35244 Mdot
.45385 .35744 Mdot
.3997 .53028 Mdot
.47366 .68779 Mdot
.52535 .56736 Mdot
.36712 .58449 Mdot
.3934 .57716 Mdot
.7661 .41839 Mdot
.39319 .57793 Mdot
.42242 .51808 Mdot
.40871 .51479 Mdot
.34526 .50607 Mdot
.65978 .51562 Mdot
.25323 .52991 Mdot
.35991 .48886 Mdot
.44138 .57192 Mdot
.60543 .52537 Mdot
.37631 .45474 Mdot
.62996 .56179 Mdot
.26541 .2834 Mdot
.62912 .55889 Mdot
.44875 .3548 Mdot
.55604 .35082 Mdot
.31518 .48384 Mdot
.51938 .64028 Mdot
.66442 .54342 Mdot
.46101 .34132 Mdot
.62936 .51458 Mdot
.63105 .3775 Mdot
.20862 .61741 Mdot
.49591 .70735 Mdot
.49187 .40473 Mdot
.55063 .58577 Mdot
.76535 .57989 Mdot
.59607 .37753 Mdot
.55621 .6724 Mdot
.24837 .58758 Mdot
.40991 .52112 Mdot
.47529 .35164 Mdot
.38524 .53306 Mdot
.66193 .52222 Mdot
.61193 .34454 Mdot
.42423 .24571 Mdot
.4543 .35906 Mdot
.40891 .83553 Mdot
.62514 .35074 Mdot
.35623 .5895 Mdot
.64017 .56432 Mdot
.24435 .7075 Mdot
.63315 .55903 Mdot
.32268 .4383 Mdot
.56359 .72582 Mdot
.52217 .79289 Mdot
.54638 .68783 Mdot
.80622 .54092 Mdot
.16053 .38047 Mdot
.42366 .20529 Mdot
.52297 .6711 Mdot
.6142 .29412 Mdot
.36179 .5701 Mdot
.39422 .49064 Mdot
.40456 .61368 Mdot
.57407 .68323 Mdot
.36583 .54927 Mdot
.7735 .41623 Mdot
.62864 .69173 Mdot
.50289 .29597 Mdot
.62665 .39668 Mdot
.35144 .51374 Mdot
.60557 .52918 Mdot
.60793 .50414 Mdot
.76696 .41112 Mdot
.60995 .55832 Mdot
.38208 .58663 Mdot
.54351 .68425 Mdot
.48595 .50006 Mdot
.47306 .34138 Mdot
.61421 .20262 Mdot
.49376 .33514 Mdot
.65211 .37078 Mdot
.32976 .49841 Mdot
.59474 .36137 Mdot
.73506 .76817 Mdot
.41112 .53226 Mdot
.51743 .67742 Mdot
.39492 .5429 Mdot
.40309 .50631 Mdot
.39582 .49108 Mdot
.61795 .3923 Mdot
.58059 .41652 Mdot
.3711 .5585 Mdot
.63676 .538 Mdot
.38158 .24511 Mdot
.43581 .54129 Mdot
.63116 .30663 Mdot
.35059 .37595 Mdot
.74526 .6072 Mdot
.57649 .67825 Mdot
.58324 .35022 Mdot
.53191 .6909 Mdot
.52822 .63383 Mdot
.53521 .69685 Mdot
.29502 .29231 Mdot
.38062 .63833 Mdot
.86486 .54565 Mdot
.48466 .79867 Mdot
.38264 .68353 Mdot
.55429 .72227 Mdot
.74658 .36356 Mdot
.51115 .69617 Mdot
.52823 .6986 Mdot
.76867 .24671 Mdot
.50718 .6882 Mdot
.33959 .54046 Mdot
.39857 .58876 Mdot
.66462 .64405 Mdot
.29689 .42843 Mdot
.40873 .55607 Mdot
.37081 .54254 Mdot
.43873 .35765 Mdot
.42129 .62393 Mdot
.74079 .42979 Mdot
.69992 .71257 Mdot
.7013 .5552 Mdot
.38972 .53228 Mdot
.37101 .54577 Mdot
.32273 .58674 Mdot
.13939 .40754 Mdot
.42409 .66807 Mdot
.52413 .72091 Mdot
.38068 .46581 Mdot
.53995 .18455 Mdot
.34891 .58415 Mdot
.32975 .54677 Mdot
.38386 .55992 Mdot
.59901 .35433 Mdot
.49472 .67714 Mdot
.37594 .46673 Mdot
.73393 .60342 Mdot
.3586 .57398 Mdot
.62742 .57673 Mdot
.47918 .3102 Mdot
.34455 .52676 Mdot
.54887 .65007 Mdot
.39996 .55935 Mdot
.55037 .71173 Mdot
.56363 .68455 Mdot
.31322 .57828 Mdot
.27964 .30407 Mdot
.52755 .64911 Mdot
.37391 .57234 Mdot
.58672 .35419 Mdot
.42246 .19589 Mdot
.35068 .52154 Mdot
.43752 .34003 Mdot
.34841 .55109 Mdot
.45695 .31914 Mdot
.38013 .58035 Mdot
.77616 .4141 Mdot
.28167 .64113 Mdot
.61073 .35189 Mdot
.4436 .39114 Mdot
.58505 .39556 Mdot
.58944 .76347 Mdot
.5145 .66001 Mdot
.74211 .43758 Mdot
.73225 .72361 Mdot
.76745 .41945 Mdot
.40578 .42338 Mdot
.69948 .39018 Mdot
.62041 .51006 Mdot
.56265 .66496 Mdot
.402 .37685 Mdot
.62814 .30135 Mdot
.65629 .34504 Mdot
.57829 .39934 Mdot
.62842 .8237 Mdot
.69579 .76077 Mdot
.3773 .55291 Mdot
.20899 .49504 Mdot
.36294 .74488 Mdot
.34691 .50916 Mdot
.32604 .57646 Mdot
.59046 .33042 Mdot
.385 .4966 Mdot
.51348 .46087 Mdot
.60656 .37241 Mdot
.45632 .34502 Mdot
.53501 .70477 Mdot
.45577 .32042 Mdot
.60539 .32077 Mdot
.5839 .47989 Mdot
.61604 .37673 Mdot
.36138 .49302 Mdot
.38957 .54237 Mdot
.56181 .70185 Mdot
.50824 .73789 Mdot
.56297 .67681 Mdot
.48451 .34817 Mdot
.6131 .36572 Mdot
.40795 .66419 Mdot
.35856 .53959 Mdot
.53966 .6747 Mdot
.63093 .47605 Mdot
.36024 .54326 Mdot
.64026 .51272 Mdot
.34747 .57233 Mdot
.52114 .66793 Mdot
.39234 .57844 Mdot
.54301 .68604 Mdot
.58256 .36697 Mdot
.34591 .58068 Mdot
.3754 .53851 Mdot
.28665 .73712 Mdot
.46179 .35273 Mdot
.51486 .66034 Mdot
.53789 .51134 Mdot
.36655 .59076 Mdot
.50832 .32493 Mdot
.35289 .50867 Mdot
.30817 .47202 Mdot
.44046 .54808 Mdot
.77392 .41818 Mdot
.37044 .48039 Mdot
.35153 .51989 Mdot
.24472 .5587 Mdot
.41597 .78831 Mdot
.57202 .73293 Mdot
.66433 .53389 Mdot
.55094 .65225 Mdot
.57583 .338 Mdot
.56316 .36644 Mdot
.59632 .39116 Mdot
.30338 .43542 Mdot
.33811 .59698 Mdot
.37077 .50668 Mdot
.66424 .54773 Mdot
.44867 .34671 Mdot
.53514 .66743 Mdot
.44645 .34256 Mdot
.69439 .71647 Mdot
.484 .34689 Mdot
.76518 .41263 Mdot
.57983 .27489 Mdot
.34717 .65148 Mdot
.44191 .35942 Mdot
.56278 .67517 Mdot
.609 .27124 Mdot
.42612 .53469 Mdot
.67385 .36214 Mdot
.46417 .33231 Mdot
.58004 .85072 Mdot
.34693 .51358 Mdot
.49584 .4283 Mdot
.61072 .55054 Mdot
.47231 .32721 Mdot
.64745 .53321 Mdot
.4084 .543 Mdot
.74641 .55415 Mdot
.5123 .68416 Mdot
.64642 .49731 Mdot
.37459 .48112 Mdot
.46107 .32198 Mdot
.6246 .36354 Mdot
.5692 .58344 Mdot
.62786 .50306 Mdot
.23035 .60529 Mdot
.39633 .28688 Mdot
.61148 .36742 Mdot
.832 .553 Mdot
.64001 .5456 Mdot
.35875 .49787 Mdot
.28872 .52657 Mdot
.40906 .56332 Mdot
.56283 .3528 Mdot
.58679 .34478 Mdot
.63997 .67514 Mdot
.39192 .54432 Mdot
.34899 .51184 Mdot
.50375 .71062 Mdot
.59962 .37275 Mdot
.55396 .68874 Mdot
.54911 .64689 Mdot
.57859 .35782 Mdot
.54811 .69577 Mdot
.47661 .35326 Mdot
.61295 .65419 Mdot
.63851 .54666 Mdot
.63794 .53417 Mdot
.6188 .34458 Mdot
.6354 .35241 Mdot
.59435 .36352 Mdot
.34792 .57247 Mdot
.53985 .66363 Mdot
.38834 .5666 Mdot
.3811 .4858 Mdot
.57999 .7056 Mdot
.50358 .67988 Mdot
.39447 .55832 Mdot
.52787 .34685 Mdot
.46705 .30937 Mdot
.59899 .3389 Mdot
.62078 .55179 Mdot
.40969 .81616 Mdot
.65245 .55941 Mdot
.35357 .51075 Mdot
.64484 .43232 Mdot
.52404 .66339 Mdot
.47593 .34744 Mdot
.50407 .33266 Mdot
.46888 .35535 Mdot
.58721 .51122 Mdot
.52891 .64077 Mdot
.69976 .69732 Mdot
.36302 .50465 Mdot
.53238 .46144 Mdot
.39487 .36235 Mdot
.70248 .65369 Mdot
.61353 .54251 Mdot
.3651 .54376 Mdot
.7689 .42082 Mdot
.30059 .63064 Mdot
.38769 .51383 Mdot
.41708 .52569 Mdot
.5426 .24357 Mdot
.44065 .57411 Mdot
.57623 .69467 Mdot
.63104 .7636 Mdot
.41553 .57361 Mdot
.515 .61773 Mdot
.85746 .41547 Mdot
.36617 .5006 Mdot
.35831 .55955 Mdot
.35318 .52928 Mdot
.40161 .54751 Mdot
.57284 .7154 Mdot
.42944 .41045 Mdot
.64449 .56232 Mdot
.55409 .46636 Mdot
.63054 .54606 Mdot
.58546 .33669 Mdot
.49486 .43269 Mdot
.56311 .6678 Mdot
.47385 .35146 Mdot
.20915 .5558 Mdot
.66975 .74051 Mdot
.59505 .38023 Mdot
.4472 .68049 Mdot
.47087 .33795 Mdot
.42683 .54138 Mdot
.48096 .36216 Mdot
.57154 .3886 Mdot
.62403 .5384 Mdot
.39789 .58853 Mdot
.5278 .71756 Mdot
.53247 .65329 Mdot
.36199 .54747 Mdot
.49407 .18597 Mdot
.64887 .51741 Mdot
.61725 .46427 Mdot
.37783 .55943 Mdot
.41733 .52704 Mdot
.55248 .69923 Mdot
.59507 .3443 Mdot
.70709 .33728 Mdot
.4617 .34818 Mdot
.31441 .55047 Mdot
.40387 .55136 Mdot
.67943 .72284 Mdot
.65777 .54251 Mdot
.76089 .43881 Mdot
.38231 .55421 Mdot
.67882 .70728 Mdot
.38425 .55335 Mdot
.30423 .53881 Mdot
.59069 .35818 Mdot
.4328 .5246 Mdot
.33905 .56502 Mdot
.46371 .49826 Mdot
.64556 .54166 Mdot
.51827 .68327 Mdot
.53241 .73153 Mdot
.7719 .43803 Mdot
.63822 .51255 Mdot
.39681 .55805 Mdot
.66024 .52905 Mdot
.3924 .48878 Mdot
.37041 .55645 Mdot
.61391 .54238 Mdot
.55381 .68936 Mdot
.69006 .49898 Mdot
.29214 .46683 Mdot
.3988 .54625 Mdot
.40306 .58167 Mdot
.30706 .4283 Mdot
.78643 .66634 Mdot
.34022 .55612 Mdot
.52139 .66153 Mdot
.3644 .53978 Mdot
.64572 .52488 Mdot
.48545 .3409 Mdot
.52241 .67516 Mdot
.62834 .34765 Mdot
.58077 .36829 Mdot
.63931 .59675 Mdot
.75981 .41373 Mdot
.39275 .58767 Mdot
.57394 .7384 Mdot
.50559 .69459 Mdot
.76823 .29592 Mdot
.60025 .33342 Mdot
.45717 .31658 Mdot
.40237 .53651 Mdot
.56145 .57113 Mdot
.66043 .5501 Mdot
.33313 .15829 Mdot
.70029 .68786 Mdot
.47176 .37169 Mdot
.75346 .68151 Mdot
.76757 .42559 Mdot
.33223 .55189 Mdot
.43237 .34849 Mdot
.58346 .38003 Mdot
.40575 .50205 Mdot
.37727 .61418 Mdot
.54665 .41731 Mdot
.58929 .40952 Mdot
.65924 .53043 Mdot
.60992 .38647 Mdot
.4391 .36813 Mdot
.76633 .41259 Mdot
.54932 .65717 Mdot
.35678 .51373 Mdot
.2965 .52028 Mdot
.60934 .33877 Mdot
.77761 .4144 Mdot
.37546 .56459 Mdot
.53542 .65156 Mdot
.57694 .38734 Mdot
.393 .52896 Mdot
.3555 .67062 Mdot
.54446 .63467 Mdot
.61888 .36089 Mdot
.41797 .5127 Mdot
.28557 .50297 Mdot
.62466 .34642 Mdot
.61322 .33727 Mdot
.36633 .54896 Mdot
.47272 .35574 Mdot
.33323 .56802 Mdot
.61966 .55919 Mdot
.58189 .4172 Mdot
.64336 .52511 Mdot
.40463 .30892 Mdot
.32995 .50146 Mdot
.77449 .57873 Mdot
.56494 .70268 Mdot
.42351 .35453 Mdot
.29233 .71845 Mdot
.41974 .5343 Mdot
.31779 .24518 Mdot
.466 .46438 Mdot
.63002 .19664 Mdot
.16588 .4306 Mdot
.45792 .33325 Mdot
.63271 .51436 Mdot
.35847 .5588 Mdot
.67143 .54906 Mdot
.43923 .3543 Mdot
.39362 .33525 Mdot
.4193 .51532 Mdot
.55231 .67091 Mdot
.36229 .57272 Mdot
.55062 .70927 Mdot
.35772 .54403 Mdot
.44581 .53327 Mdot
.4137 .35452 Mdot
.31786 .44073 Mdot
.4264 .53782 Mdot
.20573 .61512 Mdot
.55202 .5465 Mdot
.46653 .33711 Mdot
.38168 .56936 Mdot
.75751 .4319 Mdot
.59813 .51792 Mdot
.23824 .39709 Mdot
.59731 .35784 Mdot
.60895 .53814 Mdot
.54422 .70261 Mdot
.63034 .34162 Mdot
.78085 .43135 Mdot
.29231 .53015 Mdot
.44723 .3216 Mdot
.62216 .51031 Mdot
.34846 .52243 Mdot
.34466 .51695 Mdot
.57208 .30661 Mdot
.78311 .48045 Mdot
.49281 .68136 Mdot
.36077 .80663 Mdot
.57718 .70319 Mdot
.45396 .35292 Mdot
.59139 .35995 Mdot
.33706 .54975 Mdot
.38631 .52103 Mdot
.56432 .35645 Mdot
.51338 .66348 Mdot
.60891 .41249 Mdot
.44405 .69838 Mdot
.64315 .37327 Mdot
.37263 .39315 Mdot
.51755 .67284 Mdot
.37415 .39716 Mdot
.43722 .36753 Mdot
.25502 .32191 Mdot
.29322 .37346 Mdot
.60953 .54976 Mdot
.37278 .3886 Mdot
.52828 .66561 Mdot
.38276 .54673 Mdot
.77012 .42833 Mdot
.75045 .42177 Mdot
.54242 .70663 Mdot
.57469 .36298 Mdot
.46713 .32584 Mdot
.36031 .56067 Mdot
.73793 .65373 Mdot
.65473 .61939 Mdot
.63856 .37328 Mdot
.31796 .61139 Mdot
.64389 .53613 Mdot
.34426 .56617 Mdot
.43937 .33488 Mdot
.61847 .51927 Mdot
.7848 .43726 Mdot
.62628 .67762 Mdot
.40409 .53204 Mdot
.64936 .73379 Mdot
.63314 .51023 Mdot
.83728 .5532 Mdot
.37971 .5312 Mdot
.6404 .54542 Mdot
.44787 .506 Mdot
.72844 .57402 Mdot
.51179 .50793 Mdot
.38042 .19919 Mdot
.58485 .40621 Mdot
.57865 .369 Mdot
.72933 .49109 Mdot
.4176 .36369 Mdot
.60872 .51799 Mdot
.76795 .41241 Mdot
.33752 .33138 Mdot
.64692 .53606 Mdot
.32794 .554 Mdot
.35456 .50757 Mdot
.42876 .69563 Mdot
.52075 .48569 Mdot
.77792 .413 Mdot
.5948 .65931 Mdot
.40235 .57534 Mdot
.43072 .50483 Mdot
.37766 .52215 Mdot
.53927 .72519 Mdot
.64481 .50989 Mdot
.22025 .68251 Mdot
.65207 .52191 Mdot
.74179 .6594 Mdot
.61698 .3505 Mdot
.64165 .36964 Mdot
.34464 .52495 Mdot
.79697 .57263 Mdot
.23375 .39161 Mdot
.36598 .58806 Mdot
.48809 .30594 Mdot
.39001 .29495 Mdot
.43518 .50328 Mdot
.55096 .7343 Mdot
.29989 .5198 Mdot
.57869 .66015 Mdot
.61396 .52509 Mdot
.45355 .33196 Mdot
.46665 .31001 Mdot
.61893 .51373 Mdot
.37007 .50811 Mdot
.44729 .29533 Mdot
.38808 .50846 Mdot
.38037 .55248 Mdot
.72014 .6996 Mdot
.45328 .31446 Mdot
.5931 .3665 Mdot
.45446 .35811 Mdot
.52664 .69731 Mdot
.63246 .13249 Mdot
.44386 .33955 Mdot
.56028 .75375 Mdot
.45821 .40121 Mdot
.37523 .39109 Mdot
.53754 .65259 Mdot
.46202 .36622 Mdot
.65723 .52915 Mdot
.62155 .1892 Mdot
.81716 .60894 Mdot
.65498 .55962 Mdot
.38395 .52801 Mdot
.56648 .67585 Mdot
.52146 .71719 Mdot
.67396 .52351 Mdot
.55396 .66507 Mdot
.37331 .47531 Mdot
.39177 .54743 Mdot
.60897 .51771 Mdot
.65557 .64166 Mdot
.63308 .50269 Mdot
.61605 .68059 Mdot
.379 .56728 Mdot
.51988 .67599 Mdot
.32622 .49418 Mdot
.5048 .71562 Mdot
.74684 .4328 Mdot
.40691 .5023 Mdot
.47993 .336 Mdot
.52263 .47375 Mdot
.61806 .35825 Mdot
.635 .43926 Mdot
.56235 .69695 Mdot
.6654 .48159 Mdot
.56081 .67719 Mdot
.57071 .68372 Mdot
.61718 .56391 Mdot
.51734 .69349 Mdot
.35841 .5604 Mdot
.5502 .32581 Mdot
.54043 .71545 Mdot
.63029 .5268 Mdot
.4737 .33183 Mdot
.55052 .69351 Mdot
.61064 .32706 Mdot
.39192 .53697 Mdot
.61248 .38147 Mdot
.45809 .37611 Mdot
.5607 .66247 Mdot
.46643 .36456 Mdot
.60402 .33529 Mdot
.43898 .32676 Mdot
.43592 .23742 Mdot
.64638 .50068 Mdot
.76145 .66002 Mdot
.27618 .49163 Mdot
.52681 .71659 Mdot
.65596 .33998 Mdot
.33889 .55206 Mdot
.3955 .53713 Mdot
.43804 .36559 Mdot
.51846 .71455 Mdot
.43811 .19648 Mdot
.30929 .4761 Mdot
.61703 .65409 Mdot
.65651 .50858 Mdot
.4189 .82971 Mdot
.65289 .69805 Mdot
.64533 .23153 Mdot
.4225 .58109 Mdot
.76767 .42613 Mdot
.38065 .50307 Mdot
.25451 .69151 Mdot
.48392 .33262 Mdot
.73319 .39561 Mdot
.40632 .59376 Mdot
.60222 .36436 Mdot
.36399 .53336 Mdot
.21996 .47676 Mdot
.3014 .51943 Mdot
.44329 .36214 Mdot
.58279 .55044 Mdot
.5187 .64074 Mdot
.47244 .34076 Mdot
.58449 .37199 Mdot
.35275 .34489 Mdot
.42014 .51214 Mdot
.39235 .58426 Mdot
.63568 .38701 Mdot
.55328 .66935 Mdot
.58317 .33688 Mdot
.63813 .5466 Mdot
.44785 .33868 Mdot
.40408 .54215 Mdot
.4258 .5038 Mdot
.53663 .3817 Mdot
.64687 .5105 Mdot
.63961 .35592 Mdot
.65146 .54682 Mdot
.76874 .42633 Mdot
.41805 .56323 Mdot
.62755 .39204 Mdot
.34882 .50976 Mdot
.29276 .72814 Mdot
.72454 .7 Mdot
.41676 .7773 Mdot
.59305 .36914 Mdot
.34687 .39179 Mdot
.63897 .52022 Mdot
.63857 .55617 Mdot
.50407 .80067 Mdot
.26863 .34984 Mdot
.61152 .2605 Mdot
.20899 .57555 Mdot
.6371 .54709 Mdot
.64034 .52685 Mdot
.58257 .382 Mdot
.52245 .7015 Mdot
.53831 .62812 Mdot
.64483 .36176 Mdot
.29904 .45249 Mdot
.53521 .66759 Mdot
.33252 .23195 Mdot
.58888 .32965 Mdot
.41719 .58751 Mdot
.74595 .41482 Mdot
.45297 .32909 Mdot
.29948 .45298 Mdot
.22274 .50656 Mdot
.33515 .54538 Mdot
.60681 .7848 Mdot
.59418 .34783 Mdot
.50851 .39336 Mdot
.25917 .29544 Mdot
.41522 .51353 Mdot
.36412 .52568 Mdot
.3714 .51107 Mdot
.45756 .31296 Mdot
.28 .70458 Mdot
.3345 .54494 Mdot
.35441 .42552 Mdot
.33189 .57851 Mdot
.25324 .4167 Mdot
.45254 .35749 Mdot
.52965 .60897 Mdot
.59682 .40581 Mdot
.72177 .62468 Mdot
.41067 .60985 Mdot
.64798 .54472 Mdot
.6094 .3102 Mdot
.62163 .53979 Mdot
.25389 .35063 Mdot
.29691 .37121 Mdot
.55255 .72469 Mdot
.34533 .56144 Mdot
.57205 .39449 Mdot
.56578 .69058 Mdot
.70185 .37636 Mdot
.74315 .21887 Mdot
.65566 .51709 Mdot
.78077 .70328 Mdot
.63972 .5561 Mdot
.74743 .42943 Mdot
.55033 .70229 Mdot
.44092 .63587 Mdot
.53071 .46156 Mdot
.54934 .69263 Mdot
.71086 .52475 Mdot
.56299 .73118 Mdot
.35919 .38749 Mdot
.53761 .6371 Mdot
.63225 .52345 Mdot
.60162 .50126 Mdot
.40713 .60122 Mdot
.3417 .55133 Mdot
.56644 .46464 Mdot
.42386 .4618 Mdot
.34319 .55536 Mdot
.60642 .37229 Mdot
.80694 .60852 Mdot
.55359 .34602 Mdot
.5224 .70917 Mdot
.66035 .54245 Mdot
.36403 .52766 Mdot
.39507 .54993 Mdot
.36846 .49302 Mdot
.2884 .74162 Mdot
.3384 .22953 Mdot
.37271 .55587 Mdot
.31496 .54257 Mdot
.58531 .36908 Mdot
.42184 .31303 Mdot
.22008 .61328 Mdot
.32756 .34362 Mdot
.40021 .51826 Mdot
.46284 .35451 Mdot
.47411 .31817 Mdot
.43278 .54299 Mdot
.74335 .62433 Mdot
.60714 .29645 Mdot
.34847 .52267 Mdot
.276 .38284 Mdot
.57775 .32732 Mdot
.77033 .41059 Mdot
.61026 .33922 Mdot
.54986 .64958 Mdot
.76096 .41692 Mdot
.59159 .39499 Mdot
.42695 .63854 Mdot
.7709 .4394 Mdot
.72088 .58731 Mdot
.48454 .34817 Mdot
.38113 .5193 Mdot
.55215 .73679 Mdot
.56268 .35767 Mdot
.61876 .51225 Mdot
.53404 .68434 Mdot
.60443 .50599 Mdot
.40904 .33814 Mdot
.41726 .41653 Mdot
.75547 .4158 Mdot
.64201 .54889 Mdot
.62646 .67947 Mdot
.46048 .35586 Mdot
.61604 .5623 Mdot
.7966 .5636 Mdot
.42346 .57368 Mdot
.20517 .41837 Mdot
.36005 .58265 Mdot
.54445 .18128 Mdot
.64163 .55757 Mdot
.76026 .44295 Mdot
.36732 .50663 Mdot
.62511 .35005 Mdot
.43931 .48733 Mdot
.39247 .51641 Mdot
.63708 .36578 Mdot
.37829 .55135 Mdot
.43752 .33613 Mdot
.56649 .64771 Mdot
.47298 .48428 Mdot
.49358 .84357 Mdot
.44108 .32636 Mdot
.73134 .43795 Mdot
.3416 .55788 Mdot
.4178 .2534 Mdot
.55057 .69019 Mdot
.41588 .5183 Mdot
.53246 .79067 Mdot
.53111 .70903 Mdot
.5356 .69137 Mdot
.39162 .57467 Mdot
.60905 .55306 Mdot
.62416 .35402 Mdot
.46183 .3565 Mdot
.68094 .23757 Mdot
.39488 .52413 Mdot
.36992 .53902 Mdot
.47153 .33831 Mdot
.64208 .52588 Mdot
.39719 .55077 Mdot
.68238 .41655 Mdot
.69278 .23016 Mdot
.62793 .56414 Mdot
.43618 .54031 Mdot
.19217 .48292 Mdot
.4883 .6571 Mdot
.78618 .68155 Mdot
.47026 .38936 Mdot
.58298 .35282 Mdot
.44421 .52461 Mdot
.38197 .13852 Mdot
.45556 .32992 Mdot
.70991 .65147 Mdot
.37001 .56253 Mdot
.35423 .53691 Mdot
.53341 .65677 Mdot
.3927 .56356 Mdot
.51036 .67387 Mdot
.52032 .84986 Mdot
.38972 .84051 Mdot
.55985 .68422 Mdot
.5166 .70647 Mdot
.54822 .61919 Mdot
.23682 .6365 Mdot
.53799 .70386 Mdot
.41201 .50242 Mdot
.38631 .23159 Mdot
.31267 .58048 Mdot
.42939 .3596 Mdot
.49895 .35533 Mdot
.49285 .62222 Mdot
.83032 .50202 Mdot
.363 .45861 Mdot
.44277 .58633 Mdot
.52787 .57694 Mdot
.62415 .55732 Mdot
.4044 .51632 Mdot
.75999 .41331 Mdot
.60293 .39177 Mdot
.29881 .54969 Mdot
.38272 .51534 Mdot
.54797 .71234 Mdot
.44944 .31278 Mdot
.598 .54426 Mdot
.37146 .54227 Mdot
.58653 .41228 Mdot
.45835 .34678 Mdot
.53404 .71531 Mdot
.57268 .76018 Mdot
.43042 .3307 Mdot
.38369 .47581 Mdot
.34802 .54806 Mdot
.37645 .56348 Mdot
.43001 .59135 Mdot
.61244 .51814 Mdot
.59508 .32235 Mdot
.39286 .48343 Mdot
.69355 .71261 Mdot
.49846 .41794 Mdot
.42563 .50839 Mdot
.53349 .66205 Mdot
.65118 .5594 Mdot
.75815 .43911 Mdot
.37158 .34141 Mdot
.40305 .52856 Mdot
.33741 .23242 Mdot
.43026 .67599 Mdot
.7584 .41964 Mdot
.56713 .70743 Mdot
.47364 .35078 Mdot
.39431 .58096 Mdot
.34616 .25482 Mdot
.35211 .51047 Mdot
.29685 .47456 Mdot
.5886 .34957 Mdot
.6259 .55536 Mdot
.66903 .20971 Mdot
.60545 .39151 Mdot
.53304 .69112 Mdot
.3883 .18598 Mdot
.49802 .6745 Mdot
.51188 .64921 Mdot
.27717 .31172 Mdot
.61194 .53189 Mdot
.36414 .14795 Mdot
.80534 .63748 Mdot
.32873 .53627 Mdot
.64806 .52426 Mdot
.55447 .70116 Mdot
.34631 .56672 Mdot
.50767 .69716 Mdot
.51103 .65328 Mdot
.40143 .49923 Mdot
.34922 .54283 Mdot
.34574 .43278 Mdot
.29097 .25906 Mdot
.46442 .35902 Mdot
.51743 .66031 Mdot
.39139 .69275 Mdot
.33358 .54919 Mdot
.36211 .50535 Mdot
.5353 .34889 Mdot
.44315 .36179 Mdot
.25868 .58145 Mdot
.38179 .55359 Mdot
.54839 .80082 Mdot
.40172 .58324 Mdot
.54123 .73772 Mdot
.62438 .56454 Mdot
.73762 .63007 Mdot
.56582 .34658 Mdot
.52182 .65297 Mdot
.46203 .32085 Mdot
.52108 .72407 Mdot
.50697 .78403 Mdot
.61405 .53338 Mdot
.52115 .6679 Mdot
.60843 .32948 Mdot
.62228 .53253 Mdot
.62308 .56231 Mdot
.38173 .24432 Mdot
.64142 .35783 Mdot
.48501 .35084 Mdot
.62906 .54162 Mdot
.34266 .66966 Mdot
.62887 .52109 Mdot
.40841 .69423 Mdot
.34685 .57905 Mdot
.36689 .42169 Mdot
.66586 .68766 Mdot
.38652 .61805 Mdot
.62621 .50067 Mdot
.44438 .35712 Mdot
.40122 .56507 Mdot
.55107 .66257 Mdot
.44445 .33744 Mdot
.59886 .58882 Mdot
.62437 .34175 Mdot
.55992 .70969 Mdot
.63422 .56528 Mdot
.51545 .66845 Mdot
.40178 .38809 Mdot
.61715 .43105 Mdot
.53008 .5859 Mdot
.52702 .45078 Mdot
.3546 .50211 Mdot
.4767 .62653 Mdot
.3874 .59081 Mdot
.38524 .51371 Mdot
.61923 .35996 Mdot
.306 .43433 Mdot
.55412 .6903 Mdot
.68095 .21465 Mdot
.63625 .55265 Mdot
.59481 .77411 Mdot
.28827 .50268 Mdot
.4146 .52522 Mdot
.53904 .71438 Mdot
.50019 .66128 Mdot
.41762 .78788 Mdot
.56614 .35389 Mdot
.35669 .61762 Mdot
.3235 .51097 Mdot
.42579 .58349 Mdot
.64434 .55657 Mdot
.68657 .43158 Mdot
.57419 .35325 Mdot
.86952 .5587 Mdot
.59855 .33991 Mdot
.51143 .25541 Mdot
.51677 .69373 Mdot
.48284 .33378 Mdot
.3573 .50898 Mdot
.33835 .44308 Mdot
.56035 .72512 Mdot
.51139 .37086 Mdot
.47929 .34199 Mdot
.70122 .46795 Mdot
.61012 .53501 Mdot
.42999 .53697 Mdot
.40075 .50188 Mdot
.38542 .57004 Mdot
.35882 .57874 Mdot
.66325 .53442 Mdot
.32831 .55175 Mdot
.64589 .49789 Mdot
.35103 .66453 Mdot
.54587 .80371 Mdot
.55721 .3716 Mdot
.24894 .37771 Mdot
.53715 .72015 Mdot
.34834 .68328 Mdot
.26879 .55341 Mdot
.73132 .69325 Mdot
.4203 .24201 Mdot
.38143 .59075 Mdot
.57348 .36981 Mdot
.21331 .48696 Mdot
.56992 .39125 Mdot
.51649 .90176 Mdot
.42854 .29804 Mdot
.36758 .19786 Mdot
.34692 .56508 Mdot
.53711 .36713 Mdot
.27117 .53223 Mdot
.43438 .54169 Mdot
.41814 .30707 Mdot
.58996 .74658 Mdot
.67602 .64238 Mdot
.45028 .31636 Mdot
.393 .53418 Mdot
.51537 .64247 Mdot
.35732 .56214 Mdot
.3717 .50112 Mdot
.34398 .56841 Mdot
.6113 .56445 Mdot
.36862 .59962 Mdot
.33155 .56399 Mdot
.79226 .4776 Mdot
.32003 .40918 Mdot
.61646 .38243 Mdot
.4608 .79682 Mdot
.44887 .3462 Mdot
.55571 .70713 Mdot
.45653 .44016 Mdot
.61137 .54994 Mdot
.40479 .79129 Mdot
.34977 .5733 Mdot
.65704 .68394 Mdot
.63594 .56524 Mdot
.44706 .33419 Mdot
.77303 .43581 Mdot
.3971 .21032 Mdot
.55827 .37252 Mdot
.76811 .44066 Mdot
.61716 .35684 Mdot
.29524 .71022 Mdot
.54595 .71279 Mdot
.37256 .49051 Mdot
.63938 .5403 Mdot
.62664 .35726 Mdot
.28835 .43663 Mdot
.37443 .5201 Mdot
.59447 .37229 Mdot
.35914 .49792 Mdot
.48311 .40804 Mdot
.59696 .2954 Mdot
.58444 .39656 Mdot
.58892 .51433 Mdot
.628 .5344 Mdot
.47818 .35204 Mdot
.55747 .70697 Mdot
.5259 .66233 Mdot
.61867 .52119 Mdot
.75484 .71612 Mdot
.39436 .51586 Mdot
.34251 .56427 Mdot
.69258 .70934 Mdot
.3538 .5563 Mdot
.35567 .36237 Mdot
.74509 .4206 Mdot
.55125 .71547 Mdot
.35105 .56836 Mdot
.39885 .54872 Mdot
.40361 .53432 Mdot
.40334 .39341 Mdot
.60683 .33829 Mdot
.40149 .57595 Mdot
.43126 .3516 Mdot
.78479 .54621 Mdot
.33602 .55851 Mdot
.435 .51615 Mdot
.52484 .66725 Mdot
.43647 .84429 Mdot
.61383 .55512 Mdot
.60277 .377 Mdot
.6134 .33557 Mdot
.48785 .37441 Mdot
.57473 .67119 Mdot
.74039 .42862 Mdot
.77171 .32897 Mdot
.77789 .42258 Mdot
.46895 .34178 Mdot
.54587 .23212 Mdot
.596 .41359 Mdot
.59762 .38293 Mdot
.62887 .49399 Mdot
.35517 .57447 Mdot
.37247 .58973 Mdot
.71261 .6521 Mdot
.41327 .55453 Mdot
.47798 .33592 Mdot
.61006 .51334 Mdot
.52927 .66906 Mdot
.45249 .32774 Mdot
.65196 .5443 Mdot
.5516 .66697 Mdot
.4225 .57388 Mdot
.41396 .58382 Mdot
.53687 .68754 Mdot
.56479 .68241 Mdot
.34306 .53563 Mdot
.76378 .47822 Mdot
.55723 .65242 Mdot
.51943 .67003 Mdot
.78144 .41077 Mdot
.55927 .37639 Mdot
.33061 .48574 Mdot
.64862 .5234 Mdot
.37659 .56223 Mdot
.56468 .38668 Mdot
.44762 .36386 Mdot
.55035 .68182 Mdot
.39659 .5469 Mdot
.38138 .54344 Mdot
.46559 .35382 Mdot
.43565 .32143 Mdot
.46116 .32462 Mdot
.66983 .55525 Mdot
.37137 .57959 Mdot
.53884 .7023 Mdot
.612 .53686 Mdot
.47391 .31811 Mdot
.48898 .35225 Mdot
.81598 .47905 Mdot
.33657 .54022 Mdot
.51437 .51919 Mdot
.59573 .12094 Mdot
.34428 .3444 Mdot
.75215 .43673 Mdot
.64109 .38004 Mdot
.3659 .4108 Mdot
.53969 .32493 Mdot
.64389 .51194 Mdot
.32431 .31067 Mdot
.42386 .35489 Mdot
.38668 .48777 Mdot
.4066 .57843 Mdot
.31458 .56128 Mdot
.45553 .34263 Mdot
.39206 .36873 Mdot
.51197 .70911 Mdot
.34054 .71681 Mdot
.44891 .34593 Mdot
.58376 .39614 Mdot
.61793 .39597 Mdot
.59772 .34024 Mdot
.4197 .56454 Mdot
.4067 .78495 Mdot
.36665 .68337 Mdot
.27504 .66094 Mdot
.60894 .53564 Mdot
.49436 .67517 Mdot
.42702 .24673 Mdot
.53813 .69144 Mdot
.59965 .3932 Mdot
.45967 .34236 Mdot
.52504 .65802 Mdot
.63017 .50653 Mdot
.64114 .52885 Mdot
.62496 .34351 Mdot
.61712 .34453 Mdot
.62141 .37319 Mdot
.53764 .64368 Mdot
.51733 .69378 Mdot
.40775 .53182 Mdot
.54413 .68038 Mdot
.62346 .78032 Mdot
.48536 .36434 Mdot
.60371 .39926 Mdot
.63802 .51436 Mdot
.55425 .70559 Mdot
.38206 .52213 Mdot
.57836 .25373 Mdot
.6847 .56767 Mdot
.43604 .33203 Mdot
.66167 .30305 Mdot
.56867 .88493 Mdot
.39405 .49841 Mdot
.65903 .53567 Mdot
.75398 .60789 Mdot
.36959 .51514 Mdot
.59656 .35393 Mdot
.26464 .70442 Mdot
.77943 .41912 Mdot
.33217 .563 Mdot
.41498 .53843 Mdot
.6108 .55945 Mdot
.44252 .40036 Mdot
.41054 .54149 Mdot
.63223 .72869 Mdot
.59366 .52814 Mdot
.56963 .3675 Mdot
.71129 .23959 Mdot
.65257 .3546 Mdot
.26979 .47241 Mdot
.74951 .42948 Mdot
.40393 .50551 Mdot
.61042 .3716 Mdot
.43329 .33813 Mdot
.61863 .36976 Mdot
.5636 .71445 Mdot
.61853 .37927 Mdot
.36736 .53852 Mdot
.53541 .70182 Mdot
.63488 .51018 Mdot
.63393 .76072 Mdot
.79487 .48867 Mdot
.62513 .3496 Mdot
.78916 .41448 Mdot
.33209 .55613 Mdot
.27897 .59684 Mdot
.43814 .48521 Mdot
.33895 .56028 Mdot
.62037 .5399 Mdot
.53561 .71409 Mdot
.66202 .51744 Mdot
.41054 .48302 Mdot
.50076 .81743 Mdot
.63582 .55835 Mdot
.70761 .61051 Mdot
.47064 .339 Mdot
.316 .44406 Mdot
.38961 .52052 Mdot
.6347 .54298 Mdot
.37168 .57864 Mdot
.50249 .67506 Mdot
.55032 .50596 Mdot
.79169 .55194 Mdot
.63973 .53915 Mdot
.47368 .17684 Mdot
.54187 .51896 Mdot
.30798 .50599 Mdot
.63495 .54575 Mdot
.3471 .76131 Mdot
.75721 .43541 Mdot
.46335 .34765 Mdot
.46534 .31592 Mdot
.44047 .32456 Mdot
.41605 .55232 Mdot
.30084 .59667 Mdot
.48793 .35048 Mdot
.59336 .53817 Mdot
.43884 .3602 Mdot
.36053 .43287 Mdot
.4621 .18171 Mdot
.45382 .32332 Mdot
.38586 .53009 Mdot
.43656 .51724 Mdot
.31565 .41228 Mdot
.57713 .38899 Mdot
.31273 .24944 Mdot
.47148 .6918 Mdot
.33902 .54715 Mdot
.29421 .51685 Mdot
.55306 .72067 Mdot
.78032 .60012 Mdot
.29099 .50855 Mdot
.57462 .30688 Mdot
.50868 .68939 Mdot
.65223 .37631 Mdot
.55383 .71236 Mdot
.37927 .49366 Mdot
.36904 .55779 Mdot
.5678 .64426 Mdot
.64677 .43621 Mdot
.73968 .54727 Mdot
.60197 .20154 Mdot
.51979 .66219 Mdot
.64536 .54159 Mdot
.65873 .52084 Mdot
.61305 .54373 Mdot
.57283 .34014 Mdot
.5568 .65877 Mdot
.37745 .58332 Mdot
.58064 .36357 Mdot
.39762 .51435 Mdot
.62376 .53692 Mdot
.66393 .20622 Mdot
.52613 .66796 Mdot
.35115 .51985 Mdot
.81595 .60999 Mdot
.60746 .3457 Mdot
.45771 .35525 Mdot
.4969 .40133 Mdot
.60979 .32486 Mdot
.62952 .50131 Mdot
.52256 .63196 Mdot
.62688 .57532 Mdot
.45392 .44773 Mdot
.32224 .58866 Mdot
.42732 .51642 Mdot
.71116 .25647 Mdot
.82855 .53152 Mdot
.41908 .5564 Mdot
.58483 .37285 Mdot
.56599 .37888 Mdot
.396 .543 Mdot
.54991 .65658 Mdot
.4833 .32493 Mdot
.42803 .34631 Mdot
.3698 .48142 Mdot
.53394 .4601 Mdot
.35803 .42748 Mdot
.39489 .55664 Mdot
.35824 .62126 Mdot
.62642 .34109 Mdot
.7772 .43436 Mdot
.68508 .69908 Mdot
.47289 .32335 Mdot
.3723 .56155 Mdot
.70927 .57729 Mdot
.50878 .67795 Mdot
.61829 .37788 Mdot
.61709 .51034 Mdot
.40564 .37583 Mdot
.59817 .3293 Mdot
.39516 .54402 Mdot
.39746 .55035 Mdot
.61311 .56107 Mdot
.54129 .7376 Mdot
.458 .341 Mdot
.58185 .3622 Mdot
.48068 .3279 Mdot
.52313 .69537 Mdot
.52875 .67187 Mdot
.30855 .5762 Mdot
.4323 .58706 Mdot
.62036 .34213 Mdot
.34764 .49915 Mdot
.59903 .39564 Mdot
.43891 .39267 Mdot
.65978 .54813 Mdot
.41078 .5057 Mdot
.50116 .64984 Mdot
.61958 .5345 Mdot
.3501 .535 Mdot
.78631 .32188 Mdot
.41228 .51841 Mdot
.60059 .32264 Mdot
.50783 .81759 Mdot
.44382 .35947 Mdot
.54379 .76027 Mdot
.46001 .58859 Mdot
.3554 .55469 Mdot
.61315 .39477 Mdot
.43302 .48253 Mdot
.62748 .56134 Mdot
.5153 .69949 Mdot
.727 .77223 Mdot
.62786 .5248 Mdot
.35938 .56336 Mdot
.44725 .33751 Mdot
.50041 .65759 Mdot
.76906 .41566 Mdot
.69541 .69352 Mdot
.3003 .53955 Mdot
.41072 .58919 Mdot
.35447 .57171 Mdot
.20787 .59864 Mdot
.60738 .37588 Mdot
.55438 .70343 Mdot
.6483 .55415 Mdot
.62207 .51584 Mdot
.59352 .34446 Mdot
.65745 .66214 Mdot
.64342 .42448 Mdot
.49553 .08596 Mdot
.6351 .36673 Mdot
.44285 .365 Mdot
.50895 .44001 Mdot
.6123 .3904 Mdot
.60317 .36913 Mdot
.61546 .33547 Mdot
.68154 .67359 Mdot
.54343 .66292 Mdot
.38132 .54454 Mdot
.5763 .67792 Mdot
.40657 .50702 Mdot
.23923 .50697 Mdot
.61625 .52214 Mdot
.51424 .69646 Mdot
.7505 .28605 Mdot
.42047 .46045 Mdot
.36775 .5225 Mdot
.45801 .22306 Mdot
.39318 .47145 Mdot
.37493 .3742 Mdot
.36619 .4735 Mdot
.61921 .35067 Mdot
.28922 .56415 Mdot
.44242 .54486 Mdot
.62301 .77719 Mdot
.64199 .51605 Mdot
.74608 .42767 Mdot
.36917 .59509 Mdot
.30443 .53921 Mdot
.5044 .65423 Mdot
.52442 .65797 Mdot
.48788 .34929 Mdot
.52423 .42225 Mdot
.63738 .51129 Mdot
.59466 .44005 Mdot
.34324 .55061 Mdot
.57762 .53526 Mdot
.50613 .79609 Mdot
.35002 .53316 Mdot
.37109 .24139 Mdot
.40917 .79064 Mdot
.41159 .53788 Mdot
.3189 .7198 Mdot
.63928 .52431 Mdot
.54461 .7985 Mdot
.32525 .52805 Mdot
.59817 .35414 Mdot
.52014 .70095 Mdot
.55738 .71684 Mdot
.44544 .32633 Mdot
.69995 .74383 Mdot
.63539 .49917 Mdot
.51578 .69473 Mdot
.3745 .51282 Mdot
.61408 .51553 Mdot
.75643 .4165 Mdot
.43908 .5282 Mdot
.31498 .30318 Mdot
.54094 .6774 Mdot
.3163 .53692 Mdot
.5973 .61507 Mdot
.47732 .41559 Mdot
.25762 .27988 Mdot
.61734 .54869 Mdot
.46795 .3234 Mdot
.34735 .47782 Mdot
.7665 .32449 Mdot
.32364 .57345 Mdot
.32395 .43289 Mdot
.48414 .64162 Mdot
.4853 .34017 Mdot
.36315 .51487 Mdot
.40813 .54661 Mdot
.52164 .46044 Mdot
.44129 .31731 Mdot
.41187 .5128 Mdot
.31491 .5892 Mdot
.55222 .66904 Mdot
.7451 .42239 Mdot
.53644 .67215 Mdot
.38323 .52832 Mdot
.29224 .58819 Mdot
.54245 .65681 Mdot
.58799 .22479 Mdot
.42272 .33325 Mdot
.61468 .55445 Mdot
.3339 .61653 Mdot
.34478 .57654 Mdot
.16148 .51828 Mdot
.74693 .43272 Mdot
.24515 .6805 Mdot
.64467 .35655 Mdot
.71071 .53712 Mdot
.55716 .40377 Mdot
.38902 .19425 Mdot
.64425 .74446 Mdot
.31242 .56998 Mdot
.2795 .36406 Mdot
.29944 .69527 Mdot
.64948 .50478 Mdot
.30574 .64363 Mdot
.34151 .55146 Mdot
.37758 .50136 Mdot
.57818 .37975 Mdot
.6467 .67546 Mdot
.74831 .61192 Mdot
.54872 .46476 Mdot
.45966 .33687 Mdot
.51828 .68803 Mdot
.36046 .54433 Mdot
.6832 .36488 Mdot
.62419 .37836 Mdot
.56356 .56946 Mdot
.35809 .51323 Mdot
.74759 .65073 Mdot
.69766 .63694 Mdot
.61198 .51702 Mdot
.63652 .38359 Mdot
.6115 .32592 Mdot
.37223 .49712 Mdot
.62572 .50389 Mdot
.40926 .53265 Mdot
.5547 .5359 Mdot
.33168 .51468 Mdot
.44321 .33343 Mdot
.33453 .53171 Mdot
.50707 .4765 Mdot
.32298 .21371 Mdot
.32855 .47781 Mdot
.56855 .67543 Mdot
.57714 .33751 Mdot
.60255 .33963 Mdot
.52309 .66214 Mdot
.60083 .34113 Mdot
.3546 .72944 Mdot
.47617 .74612 Mdot
.46271 .33388 Mdot
.28335 .58611 Mdot
.44065 .3376 Mdot
.7457 .42913 Mdot
.33719 .5427 Mdot
.78861 .34913 Mdot
.63462 .36059 Mdot
.3387 .77874 Mdot
.62792 .51889 Mdot
.74684 .43067 Mdot
.32842 .57574 Mdot
.53932 .23256 Mdot
.58695 .391 Mdot
.63102 .32779 Mdot
.40428 .53323 Mdot
.53006 .65989 Mdot
.40693 .54837 Mdot
.34614 .48746 Mdot
.76671 .44065 Mdot
.35598 .5741 Mdot
.65213 .5438 Mdot
.55047 .65198 Mdot
.41462 .20062 Mdot
.56249 .35585 Mdot
.34249 .52141 Mdot
.37318 .51273 Mdot
.50097 .68021 Mdot
.32863 .57237 Mdot
.63659 .50576 Mdot
.24921 .21476 Mdot
.47057 .34047 Mdot
.78227 .42897 Mdot
.60673 .32097 Mdot
.38677 .5882 Mdot
.39911 .55562 Mdot
.70119 .247 Mdot
.76881 .52289 Mdot
.64912 .54536 Mdot
.37294 .47764 Mdot
.58621 .36896 Mdot
.44767 .33519 Mdot
.59658 .53365 Mdot
.37941 .56204 Mdot
.36592 .50469 Mdot
.44496 .33203 Mdot
.39697 .23133 Mdot
.60527 .29494 Mdot
.60988 .5398 Mdot
.28645 .55822 Mdot
.58676 .26156 Mdot
.39353 .51607 Mdot
.63736 .2497 Mdot
.52078 .67094 Mdot
.6299 .54788 Mdot
.25122 .64508 Mdot
.37215 .48995 Mdot
.64374 .50873 Mdot
.63808 .5124 Mdot
.33237 .52774 Mdot
.57361 .67036 Mdot
.526 .64537 Mdot
.51455 .67269 Mdot
.51166 .82555 Mdot
.25603 .44313 Mdot
.62258 .37217 Mdot
.64056 .52502 Mdot
.57524 .39473 Mdot
.48009 .32 Mdot
.50043 .41983 Mdot
.57355 .39077 Mdot
.55426 .71936 Mdot
.61657 .39671 Mdot
.4064 .54088 Mdot
.63722 .50982 Mdot
.59842 .38359 Mdot
.40151 .58075 Mdot
.40185 .62073 Mdot
.528 .53238 Mdot
.48531 .32919 Mdot
.49284 .38387 Mdot
.36888 .55131 Mdot
.76144 .44 Mdot
.3437 .5317 Mdot
.60806 .5191 Mdot
.49346 .45927 Mdot
.40074 .5798 Mdot
.62393 .34627 Mdot
.47893 .53391 Mdot
.56852 .37253 Mdot
.33122 .50131 Mdot
.38244 .53035 Mdot
.39171 .51114 Mdot
.41087 .54129 Mdot
.69558 .62612 Mdot
.65747 .5089 Mdot
.37785 .62835 Mdot
.56627 .39592 Mdot
.54497 .6891 Mdot
.51622 .71705 Mdot
.61712 .26655 Mdot
.77874 .43636 Mdot
.64687 .52249 Mdot
.39483 .5184 Mdot
.63306 .32716 Mdot
.65495 .20166 Mdot
.62461 .23289 Mdot
.43557 .25318 Mdot
.58869 .37779 Mdot
.56856 .67782 Mdot
.60931 .38754 Mdot
.38292 .49882 Mdot
.41089 .48872 Mdot
.39628 .19843 Mdot
.66729 .50452 Mdot
.45846 .3427 Mdot
.39472 .50935 Mdot
.26412 .48007 Mdot
.58526 .36899 Mdot
.62916 .34265 Mdot
.40817 .51589 Mdot
.52352 .65061 Mdot
.19514 .329 Mdot
.61458 .51192 Mdot
.28231 .60804 Mdot
.49382 .72321 Mdot
.59699 .74 Mdot
.62061 .51324 Mdot
.52956 .56047 Mdot
.58412 .3425 Mdot
.5126 .75683 Mdot
.54149 .68698 Mdot
.45579 .34583 Mdot
.41539 .49627 Mdot
.55621 .71679 Mdot
.64691 .37154 Mdot
.54 .71834 Mdot
.3814 .49122 Mdot
.65475 .50798 Mdot
.58841 .34456 Mdot
.58711 .51178 Mdot
.56893 .64498 Mdot
.43753 .34749 Mdot
.31455 .44613 Mdot
.3006 .63375 Mdot
.40748 .79081 Mdot
.40096 .57644 Mdot
.63265 .30573 Mdot
.37464 .57942 Mdot
.50805 .6525 Mdot
.38932 .52228 Mdot
.49211 .62078 Mdot
.64119 .36994 Mdot
.31679 .53643 Mdot
.32975 .55897 Mdot
.389 .65483 Mdot
.35987 .52471 Mdot
.32562 .56211 Mdot
.41212 .54552 Mdot
.48626 .71154 Mdot
.30985 .57278 Mdot
.53769 .66061 Mdot
.70371 .6582 Mdot
.60523 .36786 Mdot
.49119 .33778 Mdot
.42963 .33556 Mdot
.33506 .42971 Mdot
.31046 .4463 Mdot
.65986 .66591 Mdot
.54045 .6687 Mdot
.65555 .5312 Mdot
.40926 .53156 Mdot
.24735 .62722 Mdot
.4307 .3733 Mdot
.5858 .34266 Mdot
.56984 .33898 Mdot
.44186 .57233 Mdot
.20362 .59161 Mdot
.31251 .54562 Mdot
.70108 .69443 Mdot
.36288 .48561 Mdot
.4152 .5171 Mdot
.59851 .327 Mdot
.41314 .42058 Mdot
.40145 .57616 Mdot
.50398 .65454 Mdot
.45538 .34995 Mdot
.32679 .47393 Mdot
.47361 .29327 Mdot
.54683 .55666 Mdot
.43571 .64681 Mdot
.36833 .58322 Mdot
.58289 .35648 Mdot
.56055 .7083 Mdot
.68352 .71647 Mdot
.61357 .53902 Mdot
.66494 .69662 Mdot
.37453 .67048 Mdot
.54185 .21312 Mdot
.45802 .34662 Mdot
.38934 .23797 Mdot
.36716 .53912 Mdot
.58028 .33455 Mdot
.39363 .49555 Mdot
.64776 .19889 Mdot
.46273 .36547 Mdot
.56416 .72379 Mdot
.64715 .54032 Mdot
.5034 .67554 Mdot
.42301 .7784 Mdot
.51594 .58954 Mdot
.72411 .43965 Mdot
.56017 .37588 Mdot
.23977 .55418 Mdot
.5396 .70696 Mdot
.38855 .55299 Mdot
.52861 .09414 Mdot
.52037 .67246 Mdot
.51451 .66272 Mdot
.46266 .39619 Mdot
.40281 .31179 Mdot
.43504 .48833 Mdot
.53174 .71729 Mdot
.58596 .40225 Mdot
.45816 .35934 Mdot
.40334 .56714 Mdot
.41015 .5476 Mdot
.53169 .65738 Mdot
.5927 .393 Mdot
.23371 .55564 Mdot
.61824 .3471 Mdot
.55618 .67324 Mdot
.61032 .35135 Mdot
.57888 .32111 Mdot
.59799 .37985 Mdot
.33765 .57486 Mdot
.39464 .52201 Mdot
.47762 .28052 Mdot
.52895 .67198 Mdot
.39781 .56237 Mdot
.37407 .55666 Mdot
.54022 .70409 Mdot
.59577 .41224 Mdot
.23932 .61176 Mdot
.34595 .56095 Mdot
.38884 .53594 Mdot
.48334 .33332 Mdot
.62977 .40787 Mdot
.68779 .32223 Mdot
.4008 .5659 Mdot
.42977 .3533 Mdot
.5396 .64303 Mdot
.34456 .53246 Mdot
.37436 .43003 Mdot
.55911 .34324 Mdot
.33848 .52235 Mdot
.76887 .41472 Mdot
.37949 .58972 Mdot
.20652 .31913 Mdot
.33717 .53208 Mdot
.55395 .70005 Mdot
.52808 .70768 Mdot
.5029 .38377 Mdot
.52959 .68993 Mdot
.74905 .42512 Mdot
.6239 .53535 Mdot
.57073 .18966 Mdot
.75489 .41865 Mdot
.41893 .52434 Mdot
.80512 .63797 Mdot
.34747 .50174 Mdot
.37278 .59423 Mdot
.24092 .64857 Mdot
.75431 .42013 Mdot
.54041 .71269 Mdot
.64718 .43966 Mdot
.37427 .4802 Mdot
.61784 .50875 Mdot
.43559 .52641 Mdot
.33167 .5335 Mdot
.61585 .73272 Mdot
.46592 .81633 Mdot
.60508 .52685 Mdot
.34746 .4749 Mdot
.40014 .5665 Mdot
.81758 .5175 Mdot
.37677 .52001 Mdot
.45074 .32401 Mdot
.51316 .66778 Mdot
.62629 .38207 Mdot
.47232 .34611 Mdot
.34889 .55402 Mdot
.45255 .34354 Mdot
.61851 .37628 Mdot
.62285 .54298 Mdot
.34688 .516 Mdot
.42792 .3574 Mdot
.45845 .33804 Mdot
.38054 .57552 Mdot
.51636 .69793 Mdot
.39037 .4569 Mdot
.34552 .53314 Mdot
.39049 .54929 Mdot
.52601 .66238 Mdot
.86427 .50073 Mdot
.3829 .4962 Mdot
.51712 .52388 Mdot
.56844 .71795 Mdot
.76045 .40925 Mdot
.60126 .38691 Mdot
.34264 .5135 Mdot
.61387 .52227 Mdot
.61612 .52832 Mdot
.63537 .39041 Mdot
.50173 .6716 Mdot
.5788 .38897 Mdot
.35885 .46718 Mdot
.42384 .5951 Mdot
.39005 .48159 Mdot
.71337 .77902 Mdot
.38372 .21177 Mdot
.55764 .66202 Mdot
.57563 .35018 Mdot
.55129 .46333 Mdot
.64529 .52688 Mdot
.61741 .39788 Mdot
.51002 .64121 Mdot
.56654 .68123 Mdot
.53982 .72039 Mdot
.48114 .3331 Mdot
.59271 .33303 Mdot
.54694 .73647 Mdot
.51852 .65349 Mdot
.40516 .53615 Mdot
.39901 .56658 Mdot
.5141 .61947 Mdot
.3327 .39634 Mdot
.43731 .34284 Mdot
.58872 .35221 Mdot
.14214 .52268 Mdot
.60754 .52051 Mdot
.39351 .65413 Mdot
.39245 .58598 Mdot
.73406 .20283 Mdot
.31353 .53566 Mdot
.37583 .51459 Mdot
.5485 .64832 Mdot
.44534 .36915 Mdot
.4441 .34978 Mdot
.53757 .70722 Mdot
.54023 .62793 Mdot
.45899 .32159 Mdot
.41209 .24858 Mdot
.47788 .17246 Mdot
.67314 .71588 Mdot
.5501 .70056 Mdot
.30221 .63121 Mdot
.62896 .50189 Mdot
.57829 .66091 Mdot
.605 .54066 Mdot
.60233 .368 Mdot
.60417 .33195 Mdot
.61126 .55871 Mdot
.40345 .53081 Mdot
.61184 .3806 Mdot
.29693 .55257 Mdot
.43651 .21289 Mdot
.22615 .3759 Mdot
.75248 .50338 Mdot
.39842 .58514 Mdot
.74122 .62573 Mdot
.75717 .57933 Mdot
.36184 .55359 Mdot
.36128 .44676 Mdot
.45658 .34356 Mdot
.58169 .68125 Mdot
.63342 .50516 Mdot
.24711 .29172 Mdot
.39404 .517 Mdot
.55512 .6891 Mdot
.64433 .51797 Mdot
.52901 .38844 Mdot
.62998 .72438 Mdot
.40497 .50824 Mdot
.42429 .11244 Mdot
.58225 .69875 Mdot
.62712 .38149 Mdot
.75566 .69464 Mdot
.57754 .6836 Mdot
.48506 .3861 Mdot
.63128 .34078 Mdot
.62701 .22007 Mdot
.55667 .70544 Mdot
.64324 .38548 Mdot
.52452 .69401 Mdot
.44153 .33205 Mdot
.54294 .63669 Mdot
.58481 .34767 Mdot
.36024 .51909 Mdot
.59718 .34494 Mdot
.43635 .34181 Mdot
.57329 .33839 Mdot
.63063 .50359 Mdot
.75145 .43438 Mdot
.63588 .53255 Mdot
.4931 .41312 Mdot
.48205 .81822 Mdot
.62537 .55529 Mdot
.56595 .41919 Mdot
.41726 .56019 Mdot
.53575 .73662 Mdot
.63524 .37254 Mdot
.57305 .39924 Mdot
.51398 .43003 Mdot
.54512 .69464 Mdot
.58915 .34712 Mdot
.36226 .67149 Mdot
.85286 .58485 Mdot
.3097 .60282 Mdot
.26323 .41523 Mdot
.54303 .70337 Mdot
.64223 .36168 Mdot
.69227 .70787 Mdot
.5343 .72237 Mdot
.63451 .36635 Mdot
.63799 .54416 Mdot
.62165 .51482 Mdot
.40287 .51655 Mdot
.63583 .48897 Mdot
.62603 .38949 Mdot
.7307 .55953 Mdot
.50786 .67298 Mdot
.5286 .39052 Mdot
.44524 .32411 Mdot
.60047 .37263 Mdot
.44055 .5588 Mdot
.529 .62449 Mdot
.55547 .36831 Mdot
.27819 .34041 Mdot
.15168 .55222 Mdot
.59163 .34701 Mdot
.5121 .66874 Mdot
.5519 .68137 Mdot
.41059 .47264 Mdot
.52999 .45764 Mdot
.57695 .38529 Mdot
.79756 .36946 Mdot
.31055 .43767 Mdot
.76925 .42591 Mdot
.83466 .53239 Mdot
.40093 .57752 Mdot
.37056 .57695 Mdot
.64771 .52879 Mdot
.36713 .52974 Mdot
.5231 .64867 Mdot
.35615 .58946 Mdot
.64977 .51298 Mdot
.5826 .34532 Mdot
.34216 .52532 Mdot
.44737 .35888 Mdot
.61705 .50211 Mdot
.60523 .55296 Mdot
.61333 .36199 Mdot
.53425 .71867 Mdot
.67379 .36269 Mdot
.61589 .34368 Mdot
.37014 .58438 Mdot
.75798 .42237 Mdot
.36702 .49367 Mdot
.36473 .27183 Mdot
.50847 .70386 Mdot
.61342 .38724 Mdot
.56692 .70654 Mdot
.6334 .52908 Mdot
.60603 .40439 Mdot
.37699 .52596 Mdot
.63272 .36213 Mdot
.51902 .31899 Mdot
.39262 .2562 Mdot
.50173 .66698 Mdot
.49396 .31315 Mdot
.51313 .66168 Mdot
.77047 .42494 Mdot
.3554 .30369 Mdot
.46527 .34257 Mdot
.59011 .36965 Mdot
.37017 .21611 Mdot
.62887 .34958 Mdot
.35839 .52695 Mdot
.35175 .54092 Mdot
.57997 .38057 Mdot
.4668 .36017 Mdot
.43964 .8429 Mdot
.51983 .55815 Mdot
.54378 .7145 Mdot
.49523 .73627 Mdot
.13563 .4629 Mdot
.5918 .52445 Mdot
.65085 .53332 Mdot
.31428 .52492 Mdot
.41413 .52389 Mdot
.60083 .54934 Mdot
.65924 .54428 Mdot
.48349 .32922 Mdot
.60695 .33437 Mdot
.54637 .74426 Mdot
.5985 .51518 Mdot
.46879 .54786 Mdot
.27459 .47105 Mdot
.41249 .47606 Mdot
.34644 .6091 Mdot
.41523 .57408 Mdot
.47203 .41221 Mdot
.6583 .54104 Mdot
.37124 .55021 Mdot
.30695 .56743 Mdot
.63664 .5483 Mdot
.44129 .33342 Mdot
.59832 .69219 Mdot
.60415 .35219 Mdot
.85867 .41245 Mdot
.33978 .52269 Mdot
.35439 .52371 Mdot
.6089 .535 Mdot
.8322 .50292 Mdot
.56245 .67658 Mdot
.5138 .70708 Mdot
.60829 .37659 Mdot
.51537 .42802 Mdot
.34035 .58075 Mdot
.36473 .55271 Mdot
.59243 .36386 Mdot
.75376 .43622 Mdot
.73251 .49602 Mdot
.38134 .54229 Mdot
.63806 .51603 Mdot
.60137 .31046 Mdot
.65909 .54087 Mdot
.39549 .49835 Mdot
.35775 .52947 Mdot
.33645 .57465 Mdot
.41508 .52493 Mdot
.60103 .5419 Mdot
.36826 .54712 Mdot
.44118 .56378 Mdot
.52005 .70813 Mdot
.35555 .579 Mdot
.35627 .42244 Mdot
.38945 .53176 Mdot
.44299 .35513 Mdot
.6829 .34727 Mdot
.39357 .51094 Mdot
.35482 .57758 Mdot
.52066 .55212 Mdot
.36641 .51119 Mdot
.6069 .52525 Mdot
.5469 .68552 Mdot
.64092 .52561 Mdot
.64478 .5568 Mdot
.57467 .39698 Mdot
.48483 .33127 Mdot
.32743 .58171 Mdot
.43619 .32878 Mdot
.37587 .60901 Mdot
.38349 .49092 Mdot
.6615 .3401 Mdot
.70158 .69189 Mdot
.55009 .31954 Mdot
.37985 .52611 Mdot
.60666 .37297 Mdot
.62354 .38263 Mdot
.27834 .35608 Mdot
.30036 .51838 Mdot
.59814 .54079 Mdot
.63527 .54279 Mdot
.35096 .35803 Mdot
.61827 .73896 Mdot
.43873 .34917 Mdot
.56983 .4667 Mdot
.41526 .57066 Mdot
.38276 .54796 Mdot
.43573 .51921 Mdot
.57327 .39117 Mdot
.77175 .43937 Mdot
.58829 .34009 Mdot
.75421 .40647 Mdot
.66218 .53179 Mdot
.3705 .58961 Mdot
.23854 .35009 Mdot
.53517 .65417 Mdot
.54626 .68488 Mdot
.59566 .54459 Mdot
.57005 .37953 Mdot
.42095 .47451 Mdot
.73037 .77348 Mdot
.58627 .68682 Mdot
.47893 .3638 Mdot
.36242 .55685 Mdot
.61236 .36626 Mdot
.53042 .65258 Mdot
.42523 .33856 Mdot
.34238 .56801 Mdot
.56921 .40084 Mdot
.3905 .52466 Mdot
.29535 .69569 Mdot
.52445 .70971 Mdot
.6525 .19708 Mdot
.49824 .67474 Mdot
.61925 .49999 Mdot
.6361 .554 Mdot
.35163 .53371 Mdot
.73121 .74852 Mdot
.56985 .72094 Mdot
.60024 .49849 Mdot
.45765 .36833 Mdot
.78104 .43008 Mdot
.47902 .35731 Mdot
.61207 .39142 Mdot
.45755 .34876 Mdot
.61393 .33593 Mdot
.3426 .37001 Mdot
.58218 .71471 Mdot
.47151 .34325 Mdot
.81177 .48923 Mdot
.35951 .60027 Mdot
.47273 .318 Mdot
.43877 .57559 Mdot
.5109 .75007 Mdot
.59541 .36177 Mdot
.4639 .36132 Mdot
.39128 .55214 Mdot
.23764 .31399 Mdot
.63865 .55614 Mdot
.59805 .53688 Mdot
.35065 .60078 Mdot
.61803 .33563 Mdot
.54255 .63006 Mdot
.46182 .44818 Mdot
.75161 .41219 Mdot
.36661 .55065 Mdot
.37299 .59006 Mdot
.50891 .71111 Mdot
.49422 .66981 Mdot
.35624 .53222 Mdot
.32834 .65998 Mdot
.36549 .54154 Mdot
.61626 .51657 Mdot
.56525 .68065 Mdot
.54968 .68177 Mdot
.6307 .38776 Mdot
.50555 .66583 Mdot
.34077 .60862 Mdot
.68068 .51721 Mdot
.38469 .47812 Mdot
.6279 .52748 Mdot
.4986 .46907 Mdot
.56601 .34697 Mdot
.28142 .27215 Mdot
.50433 .70384 Mdot
.35491 .57485 Mdot
.50852 .66565 Mdot
.46409 .32619 Mdot
.5318 .67359 Mdot
.57145 .6777 Mdot
.34512 .54655 Mdot
.40395 .50583 Mdot
.75251 .42413 Mdot
.53067 .45391 Mdot
.51102 .68642 Mdot
.362 .54722 Mdot
.33774 .51109 Mdot
.32479 .54816 Mdot
.52935 .49602 Mdot
.56296 .66628 Mdot
.43116 .69951 Mdot
.29739 .30923 Mdot
.51332 .69169 Mdot
.18626 .35728 Mdot
.77501 .41705 Mdot
.78019 .43383 Mdot
.59934 .50737 Mdot
.38309 .54259 Mdot
.571 .36559 Mdot
.37902 .49814 Mdot
.29758 .56076 Mdot
.36813 .50289 Mdot
.44608 .36388 Mdot
.32536 .58201 Mdot
.76808 .4318 Mdot
.61197 .34155 Mdot
.34521 .5653 Mdot
.34486 .52058 Mdot
.77756 .43896 Mdot
.50021 .69589 Mdot
.56508 .6917 Mdot
.63032 .24355 Mdot
.46077 .32977 Mdot
.61795 .53949 Mdot
.40211 .52271 Mdot
.60669 .37452 Mdot
.60008 .34358 Mdot
.50484 .67207 Mdot
.59771 .35201 Mdot
.61205 .51398 Mdot
.37395 .52371 Mdot
.59907 .54126 Mdot
.44249 .36104 Mdot
.51476 .6666 Mdot
.402 .52032 Mdot
.40477 .53623 Mdot
.52836 .70793 Mdot
.41745 .56023 Mdot
.48305 .33275 Mdot
.61755 .34121 Mdot
.56157 .69765 Mdot
.62143 .53388 Mdot
.62241 .39306 Mdot
.40183 .54639 Mdot
.16665 .57911 Mdot
.3661 .53318 Mdot
.39335 .54302 Mdot
.43799 .18523 Mdot
.31954 .51637 Mdot
.63754 .37531 Mdot
.52446 .72194 Mdot
.40827 .58724 Mdot
.25805 .47685 Mdot
.72261 .27816 Mdot
.61282 .39978 Mdot
.35613 .56312 Mdot
.30139 .25396 Mdot
.35036 .5652 Mdot
.59372 .44162 Mdot
.61512 .28285 Mdot
.2224 .49452 Mdot
.35335 .61062 Mdot
.60736 .54927 Mdot
.75109 .42535 Mdot
.63835 .35721 Mdot
.35798 .7635 Mdot
.35107 .54873 Mdot
.33992 .75768 Mdot
.32845 .55104 Mdot
.62251 .51285 Mdot
.43431 .46841 Mdot
.59061 .35162 Mdot
.66769 .76125 Mdot
.37546 .58326 Mdot
.56325 .66792 Mdot
.60256 .39969 Mdot
.78103 .42453 Mdot
.39575 .54747 Mdot
.43096 .33775 Mdot
.60934 .47584 Mdot
.39579 .61363 Mdot
.62502 .52806 Mdot
.37424 .55819 Mdot
.32926 .48431 Mdot
.71691 .74568 Mdot
.52798 .71265 Mdot
.64865 .53664 Mdot
.78329 .58739 Mdot
.4219 .55149 Mdot
.55818 .70375 Mdot
.54222 .68814 Mdot
.43897 .3314 Mdot
.57874 .49347 Mdot
.62202 .60879 Mdot
.20219 .41736 Mdot
.45311 .79613 Mdot
.64062 .37869 Mdot
.74948 .5529 Mdot
.40019 .57039 Mdot
.52898 .5901 Mdot
.6058 .53647 Mdot
.35648 .52101 Mdot
.48482 .80067 Mdot
.51586 .67128 Mdot
.38222 .53779 Mdot
.44104 .33569 Mdot
.59386 .47747 Mdot
.55508 .57059 Mdot
.16696 .49561 Mdot
.59778 .40262 Mdot
.42074 .49918 Mdot
.37106 .61148 Mdot
.76963 .40944 Mdot
.39137 .49142 Mdot
.63881 .36519 Mdot
.44282 .22142 Mdot
.46579 .36178 Mdot
.52282 .65511 Mdot
.77597 .41766 Mdot
.40682 .58371 Mdot
.32662 .52907 Mdot
.49166 .3395 Mdot
.37926 .56597 Mdot
.70553 .73605 Mdot
.7251 .42673 Mdot
.60552 .38226 Mdot
.54567 .71874 Mdot
.42113 .56202 Mdot
.77081 .43938 Mdot
.34752 .54458 Mdot
.44854 .62944 Mdot
.36426 .57405 Mdot
.60127 .62485 Mdot
.51995 .70001 Mdot
.62748 .53109 Mdot
.36998 .60608 Mdot
.37793 .50359 Mdot
.58184 .25785 Mdot
.29773 .56079 Mdot
.33781 .52962 Mdot
.50275 .65507 Mdot
.54669 .65566 Mdot
.53626 .66149 Mdot
.61952 .37937 Mdot
.67952 .7066 Mdot
.63415 .51948 Mdot
.33816 .58408 Mdot
.59842 .51576 Mdot
.45632 .60946 Mdot
.49098 .35021 Mdot
.19217 .37714 Mdot
.34718 .57322 Mdot
.54 .66482 Mdot
.69749 .59219 Mdot
.53728 .64313 Mdot
.56038 .39363 Mdot
.63715 .51092 Mdot
.51836 .67357 Mdot
.37787 .50839 Mdot
.54018 .46696 Mdot
.18064 .50692 Mdot
.64279 .53109 Mdot
.43173 .50821 Mdot
.59636 .40408 Mdot
.56348 .3444 Mdot
.13537 .41489 Mdot
.64759 .54834 Mdot
.7593 .57335 Mdot
.35861 .551 Mdot
.53563 .65503 Mdot
.61754 .5511 Mdot
.61753 .55965 Mdot
.59422 .35887 Mdot
.4023 .5071 Mdot
.38943 .51068 Mdot
.77037 .41517 Mdot
.63094 .54232 Mdot
.37583 .59968 Mdot
.37479 .4842 Mdot
.39886 .19667 Mdot
.59569 .711 Mdot
.86021 .4683 Mdot
.35774 .46748 Mdot
.45207 .80052 Mdot
.49652 .43816 Mdot
.55336 .65595 Mdot
.39789 .50978 Mdot
.42549 .56075 Mdot
.63404 .3834 Mdot
.37079 .52882 Mdot
.5675 .36046 Mdot
.65258 .53057 Mdot
.18024 .39247 Mdot
.68991 .53942 Mdot
.4226 .24398 Mdot
.36571 .52491 Mdot
.60909 .72193 Mdot
.4765 .34 Mdot
.65733 .56494 Mdot
.55896 .67597 Mdot
.42872 .53924 Mdot
.60253 .32359 Mdot
.58897 .36993 Mdot
.5332 .68506 Mdot
.734 .6056 Mdot
.62351 .25089 Mdot
.40773 .50343 Mdot
.59915 .3882 Mdot
.70508 .51426 Mdot
.32408 .66442 Mdot
.66892 .50855 Mdot
.46445 .36338 Mdot
.58368 .3451 Mdot
.61611 .56425 Mdot
.55092 .62093 Mdot
.52263 .68229 Mdot
.54019 .72868 Mdot
.53733 .29129 Mdot
.57244 .37907 Mdot
.46978 .35243 Mdot
.64499 .73196 Mdot
.63273 .75193 Mdot
.45134 .36514 Mdot
.581 .34616 Mdot
.53899 .65266 Mdot
.55768 .68389 Mdot
.54779 .68608 Mdot
.65831 .76553 Mdot
.50684 .69882 Mdot
.44604 .68186 Mdot
.34277 .50714 Mdot
.27688 .589 Mdot
.35176 .56431 Mdot
.60199 .53605 Mdot
.52578 .70998 Mdot
.50929 .43518 Mdot
.42001 .53747 Mdot
.17166 .49096 Mdot
.3671 .55317 Mdot
.67619 .51975 Mdot
.38579 .53993 Mdot
.33779 .6468 Mdot
.57006 .71638 Mdot
.37834 .52827 Mdot
.67022 .52717 Mdot
.45512 .3375 Mdot
.51173 .73081 Mdot
.39282 .51045 Mdot
.63394 .67958 Mdot
.30857 .54824 Mdot
.44415 .21528 Mdot
.42742 .40848 Mdot
.47017 .36902 Mdot
.31182 .5841 Mdot
.64364 .37857 Mdot
.48467 .69423 Mdot
.27422 .56446 Mdot
.6417 .53222 Mdot
.32829 .76556 Mdot
.5925 .37278 Mdot
.43124 .46545 Mdot
.36933 .47881 Mdot
.47745 .32513 Mdot
.49007 .65275 Mdot
.60732 .53464 Mdot
.39381 .58657 Mdot
.32958 .5328 Mdot
.40051 .27158 Mdot
.27937 .57813 Mdot
.32446 .5696 Mdot
.48644 .32734 Mdot
.43924 .70696 Mdot
.39537 .53205 Mdot
.59328 .41126 Mdot
.55195 .72463 Mdot
.33533 .59498 Mdot
.42724 .69379 Mdot
.3603 .5472 Mdot
.52446 .67547 Mdot
.51123 .71526 Mdot
.66094 .63419 Mdot
.45794 .37015 Mdot
.36454 .57386 Mdot
.41663 .38299 Mdot
.37102 .5807 Mdot
.63325 .51594 Mdot
.38172 .49539 Mdot
.5974 .36822 Mdot
.69908 .70394 Mdot
.62804 .3694 Mdot
.38381 .49761 Mdot
.55085 .68994 Mdot
.6103 .54756 Mdot
.49638 .28752 Mdot
.61585 .27659 Mdot
.44595 .68689 Mdot
.76395 .29839 Mdot
.47859 .34924 Mdot
.45498 .31402 Mdot
.64082 .49724 Mdot
.38211 .52826 Mdot
.46648 .39979 Mdot
.33259 .5091 Mdot
.3898 .53654 Mdot
.36541 .50348 Mdot
.62759 .48738 Mdot
.64374 .52315 Mdot
.60519 .34733 Mdot
.35805 .53171 Mdot
.36364 .54636 Mdot
.51497 .68677 Mdot
.45719 .33648 Mdot
.62808 .37415 Mdot
.46728 .33322 Mdot
.6213 .35724 Mdot
.20358 .32312 Mdot
.40692 .48009 Mdot
.45316 .33673 Mdot
.64352 .49728 Mdot
.52603 .66165 Mdot
.74836 .43668 Mdot
.61305 .39243 Mdot
.58861 .35067 Mdot
.36505 .55092 Mdot
.52275 .66539 Mdot
.50728 .67972 Mdot
.47227 .32845 Mdot
.62254 .54779 Mdot
.38477 .49841 Mdot
.40304 .50064 Mdot
.24095 .40098 Mdot
.58655 .39655 Mdot
.3554 .67816 Mdot
.67127 .64152 Mdot
.38239 .52677 Mdot
.52664 .71409 Mdot
.34236 .52848 Mdot
.28765 .28013 Mdot
.55521 .71834 Mdot
.41402 .51612 Mdot
.61131 .7512 Mdot
.56557 .38215 Mdot
.62185 .63405 Mdot
.31619 .54908 Mdot
.69483 .2419 Mdot
.39013 .57598 Mdot
.38703 .1781 Mdot
.78939 .52354 Mdot
.35751 .58897 Mdot
.40718 .55372 Mdot
.19915 .44914 Mdot
.35389 .55552 Mdot
.77264 .42749 Mdot
.33834 .47372 Mdot
.56703 .68275 Mdot
.46279 .42586 Mdot
.56222 .4019 Mdot
.4502 .36796 Mdot
.6082 .37696 Mdot
.50789 .32155 Mdot
.44449 .3307 Mdot
.54919 .70272 Mdot
.41106 .54564 Mdot
.30577 .45251 Mdot
.55239 .37698 Mdot
.34174 .49216 Mdot
.63236 .51454 Mdot
.5771 .41331 Mdot
.57124 .34803 Mdot
.62611 .5352 Mdot
.32837 .55871 Mdot
.22481 .58661 Mdot
.63686 .28457 Mdot
.59516 .18933 Mdot
.60973 .53925 Mdot
.62318 .51006 Mdot
.6869 .72006 Mdot
.4466 .36682 Mdot
.35628 .28582 Mdot
.60634 .67794 Mdot
.61967 .50535 Mdot
.37063 .33643 Mdot
.62264 .33681 Mdot
.62953 .68621 Mdot
.58161 .68077 Mdot
.41748 .48796 Mdot
.37808 .50678 Mdot
.62722 .54945 Mdot
.31007 .4553 Mdot
.74051 .69882 Mdot
.63689 .53315 Mdot
.40174 .60263 Mdot
.5891 .47923 Mdot
.76223 .42026 Mdot
.76782 .41305 Mdot
.47304 .36552 Mdot
.59533 .2308 Mdot
.52642 .6982 Mdot
.471 .32138 Mdot
.57435 .55753 Mdot
.36863 .56991 Mdot
.63769 .53962 Mdot
.75014 .44025 Mdot
.61811 .52313 Mdot
.44229 .34509 Mdot
.48013 .36279 Mdot
.52169 .7094 Mdot
.5624 .67732 Mdot
.4453 .80239 Mdot
.36194 .37628 Mdot
.34817 .5655 Mdot
.25783 .67155 Mdot
.5073 .67149 Mdot
.28346 .56765 Mdot
.43117 .35491 Mdot
.4557 .33385 Mdot
.31322 .70106 Mdot
.40906 .52711 Mdot
.52546 .37654 Mdot
.397 .51987 Mdot
.33992 .31473 Mdot
.41053 .50293 Mdot
.59638 .35614 Mdot
.38367 .5865 Mdot
.66873 .38142 Mdot
.41075 .56213 Mdot
.34038 .52311 Mdot
.59612 .33613 Mdot
.44133 .5202 Mdot
.59552 .36848 Mdot
.39773 .50107 Mdot
.46924 .31168 Mdot
.6071 .3747 Mdot
.2693 .42335 Mdot
.51804 .52495 Mdot
.76802 .43756 Mdot
.43462 .34788 Mdot
.44267 .32459 Mdot
.31805 .43917 Mdot
.5604 .67991 Mdot
.59125 .67804 Mdot
.38203 .52955 Mdot
.62996 .34354 Mdot
.64849 .52776 Mdot
.36378 .5449 Mdot
.4331 .53347 Mdot
.31868 .55977 Mdot
.51254 .67529 Mdot
.57026 .37855 Mdot
.45048 .34094 Mdot
.60538 .38663 Mdot
.58509 .24489 Mdot
.59785 .32915 Mdot
.30486 .56539 Mdot
.4371 .53957 Mdot
.36657 .63567 Mdot
.33021 .75717 Mdot
.58316 .7805 Mdot
.52744 .68585 Mdot
.75554 .43205 Mdot
.48549 .35696 Mdot
.47344 .68716 Mdot
.54929 .6663 Mdot
.58213 .35219 Mdot
.39055 .52435 Mdot
.42651 .58402 Mdot
.57094 .59164 Mdot
.47968 .66349 Mdot
.30983 .43261 Mdot
.58099 .33561 Mdot
.76747 .42361 Mdot
.67948 .71176 Mdot
.48129 .70461 Mdot
.50425 .42644 Mdot
.35493 .51372 Mdot
.43006 .33975 Mdot
.53027 .65262 Mdot
.53453 .30513 Mdot
.6325 .54618 Mdot
.53074 .45672 Mdot
.36684 .52537 Mdot
.72277 .57845 Mdot
.55001 .69042 Mdot
.43889 .34012 Mdot
.62837 .54961 Mdot
.44646 .36836 Mdot
.77056 .41247 Mdot
.60683 .22382 Mdot
.3777 .57402 Mdot
.33502 .53905 Mdot
.63493 .49302 Mdot
.52791 .69692 Mdot
.50581 .37513 Mdot
.39397 .27034 Mdot
.59189 .38614 Mdot
.51942 .35735 Mdot
.54715 .6494 Mdot
.42182 .64347 Mdot
.61046 .38443 Mdot
.5953 .54403 Mdot
.47012 .41571 Mdot
.65483 .51758 Mdot
.39595 .51373 Mdot
.54367 .6716 Mdot
.65086 .54615 Mdot
.56658 .26274 Mdot
.30086 .24164 Mdot
.35248 .64184 Mdot
.36157 .58628 Mdot
.18765 .3862 Mdot
.44239 .20051 Mdot
.35556 .43958 Mdot
.63331 .50329 Mdot
.34546 .53682 Mdot
.39593 .49082 Mdot
.37697 .58477 Mdot
.65644 .53259 Mdot
.51265 .23328 Mdot
.58566 .35749 Mdot
.36474 .55871 Mdot
.45032 .32241 Mdot
.60368 .36269 Mdot
.65497 .33648 Mdot
.6326 .35045 Mdot
.57045 .68809 Mdot
.41503 .52152 Mdot
.673 .68376 Mdot
.35727 .1813 Mdot
.6414 .52675 Mdot
.76832 .43719 Mdot
.33134 .54379 Mdot
.52948 .80343 Mdot
.53727 .662 Mdot
.58868 .38524 Mdot
.35411 .52309 Mdot
.54939 .24121 Mdot
.75235 .40492 Mdot
.61008 .33779 Mdot
.55908 .68377 Mdot
.37303 .43784 Mdot
.37044 .53039 Mdot
.38775 .57496 Mdot
.53376 .70222 Mdot
.62896 .23628 Mdot
.6971 .69762 Mdot
.34384 .52341 Mdot
.62772 .53241 Mdot
.81647 .65168 Mdot
.31844 .55243 Mdot
.52245 .62167 Mdot
.7817 .42974 Mdot
.64279 .66786 Mdot
.35489 .68145 Mdot
.29971 .56779 Mdot
.20595 .37887 Mdot
.40897 .42147 Mdot
.18253 .3778 Mdot
.44394 .38208 Mdot
.70322 .42914 Mdot
.21475 .30523 Mdot
.6706 .52339 Mdot
.28716 .59897 Mdot
.21446 .48418 Mdot
.72249 .63192 Mdot
.44251 .42906 Mdot
.74594 .31576 Mdot
.59727 .26627 Mdot
.80441 .43524 Mdot
.63405 .35893 Mdot
.32406 .31833 Mdot
.37695 .49734 Mdot
.4542 .19273 Mdot
.34059 .65789 Mdot
.73348 .72082 Mdot
.19645 .35814 Mdot
.41239 .3793 Mdot
.18778 .51412 Mdot
.31185 .25074 Mdot
.23682 .5645 Mdot
.57897 .59946 Mdot
.80634 .39678 Mdot
.64501 .7368 Mdot
.40867 .28343 Mdot
.38688 .46782 Mdot
.67969 .37462 Mdot
.49668 .20506 Mdot
.46399 .74003 Mdot
.75929 .70913 Mdot
.62522 .3871 Mdot
.56088 .7214 Mdot
.23321 .40736 Mdot
.49477 .71254 Mdot
.66419 .48133 Mdot
.20437 .38055 Mdot
.37823 .19314 Mdot
.34159 .64836 Mdot
.72124 .25532 Mdot
.35052 .74561 Mdot
.47891 .8424 Mdot
.53241 .52683 Mdot
.53891 .73065 Mdot
.74306 .38355 Mdot
.63133 .75298 Mdot
.68564 .5715 Mdot
.46842 .65665 Mdot
.47078 .37421 Mdot
.29562 .41876 Mdot
.55487 .69041 Mdot
.33996 .67781 Mdot
.78463 .41508 Mdot
.59442 .60419 Mdot
.65975 .33295 Mdot
.26797 .29423 Mdot
.73921 .44771 Mdot
.64007 .69202 Mdot
.73954 .54323 Mdot
.16175 .57129 Mdot
.38548 .36123 Mdot
.33934 .24722 Mdot
.6053 .59348 Mdot
.42447 .42834 Mdot
.73538 .67099 Mdot
.36626 .39137 Mdot
.6216 .76347 Mdot
.20732 .64458 Mdot
.50382 .18295 Mdot
.18068 .57161 Mdot
.4917 .69563 Mdot
.32465 .56784 Mdot
.28577 .30052 Mdot
.45446 .79395 Mdot
.47326 .36849 Mdot
.16926 .52268 Mdot
.42765 .34581 Mdot
.49841 .71222 Mdot
.73129 .61591 Mdot
.42269 .65158 Mdot
.56186 .41326 Mdot
.44233 .31156 Mdot
.30995 .56689 Mdot
.44427 .87834 Mdot
.18253 .41025 Mdot
.6544 .64346 Mdot
.39921 .19521 Mdot
.58364 .55995 Mdot
.51181 .38583 Mdot
.65413 .52991 Mdot
.2661 .26357 Mdot
.55225 .67408 Mdot
.3043 .20771 Mdot
.29844 .23628 Mdot
.80695 .60382 Mdot
.5696 .8993 Mdot
.74695 .48167 Mdot
.27934 .60187 Mdot
.26566 .48257 Mdot
.27016 .45136 Mdot
.74528 .67773 Mdot
.81525 .58065 Mdot
.57823 .52213 Mdot
.5987 .20943 Mdot
.22901 .302 Mdot
.3579 .32735 Mdot
.47489 .22275 Mdot
.73031 .64141 Mdot
.51828 .5045 Mdot
.53769 .62331 Mdot
.50706 .52959 Mdot
.55226 .6012 Mdot
.17812 .54468 Mdot
.50119 .79195 Mdot
.75007 .74488 Mdot
.50772 .35643 Mdot
.82952 .52215 Mdot
.40202 .21151 Mdot
.27381 .40813 Mdot
.46146 .64394 Mdot
.69273 .66135 Mdot
.30617 .56251 Mdot
.68279 .69945 Mdot
.40262 .45345 Mdot
.49019 .30768 Mdot
.67769 .72023 Mdot
.68553 .48123 Mdot
.39246 .28178 Mdot
.22274 .38486 Mdot
.60963 .73638 Mdot
.56668 .6983 Mdot
.37328 .4089 Mdot
.37948 .34511 Mdot
.40076 .19979 Mdot
.78186 .58728 Mdot
.58344 .18537 Mdot
.79461 .58745 Mdot
.33026 .51247 Mdot
.2832 .5772 Mdot
.40472 .46881 Mdot
.37832 .38225 Mdot
.32465 .52535 Mdot
.72298 .56228 Mdot
.42264 .1898 Mdot
.49045 .80079 Mdot
.44262 .28081 Mdot
.2913 .72707 Mdot
.55563 .1832 Mdot
.28714 .30563 Mdot
.78449 .53276 Mdot
.26 .54295 Mdot
.33067 .80894 Mdot
.61017 .35742 Mdot
.36607 .33731 Mdot
.62021 .56778 Mdot
.53478 .2955 Mdot
.20966 .52778 Mdot
.79706 .62025 Mdot
.42852 .18713 Mdot
.69907 .66766 Mdot
.61868 .29282 Mdot
.56297 .44113 Mdot
.58743 .42311 Mdot
.27887 .71344 Mdot
.43515 .56582 Mdot
.46829 .59431 Mdot
.45882 .31655 Mdot
.45301 .78153 Mdot
.31105 .29721 Mdot
.71186 .31221 Mdot
.33197 .61267 Mdot
.71425 .36205 Mdot
.77107 .42175 Mdot
.53675 .46144 Mdot
.14648 .39757 Mdot
.30459 .52047 Mdot
.76529 .49767 Mdot
.51976 .18197 Mdot
.46448 .40741 Mdot
.3721 .23761 Mdot
.70439 .61587 Mdot
.19344 .59862 Mdot
.33562 .20627 Mdot
.65076 .27897 Mdot
.17142 .40304 Mdot
.55523 .15513 Mdot
.21123 .6331 Mdot
.28475 .70343 Mdot
.6698 .54837 Mdot
.33321 .15908 Mdot
.57897 .37022 Mdot
.36049 .79021 Mdot
.46355 .79789 Mdot
.52561 .24742 Mdot
.53485 .63205 Mdot
.45487 .52122 Mdot
.78621 .44473 Mdot
.57989 .71175 Mdot
.3109 .57534 Mdot
.15342 .52957 Mdot
.21969 .67992 Mdot
.15958 .53327 Mdot
.57696 .19991 Mdot
.17436 .3957 Mdot
.22268 .45613 Mdot
.44854 .67898 Mdot
.28245 .34079 Mdot
.38853 .49682 Mdot
.33466 .35151 Mdot
.75278 .48885 Mdot
.61481 .28782 Mdot
.66017 .59509 Mdot
.54915 .64267 Mdot
.19971 .57495 Mdot
.11782 .44611 Mdot
.35145 .7287 Mdot
.40953 .70699 Mdot
.54083 .58335 Mdot
.36953 .36928 Mdot
.46443 .4877 Mdot
.69417 .33445 Mdot
.40313 .20509 Mdot
.21364 .47946 Mdot
.38034 .31458 Mdot
.7366 .32918 Mdot
.61604 .43644 Mdot
.82388 .51321 Mdot
.26824 .28437 Mdot
.24449 .42349 Mdot
.80795 .58258 Mdot
.2535 .55387 Mdot
.76212 .6765 Mdot
.67883 .27304 Mdot
.54118 .34099 Mdot
.3896 .33153 Mdot
.56189 .35337 Mdot
.35195 .33281 Mdot
.56451 .52231 Mdot
.24191 .38141 Mdot
.3971 .42212 Mdot
.35149 .32577 Mdot
.61933 .43498 Mdot
.15739 .48176 Mdot
.60695 .1736 Mdot
.26371 .72589 Mdot
.6742 .23038 Mdot
.39679 .4516 Mdot
.33224 .52376 Mdot
.46797 .17433 Mdot
.14722 .48331 Mdot
.36237 .18461 Mdot
.72813 .5721 Mdot
.55673 .25941 Mdot
.67398 .52486 Mdot
.28324 .73675 Mdot
.69523 .27051 Mdot
.35643 .21239 Mdot
.58736 .77544 Mdot
.59736 .50981 Mdot
.70655 .67254 Mdot
.31113 .75347 Mdot
.2327 .57449 Mdot
.35363 .69586 Mdot
.39651 .47184 Mdot
.30715 .64447 Mdot
.54674 .72615 Mdot
.74236 .56223 Mdot
.37027 .38482 Mdot
.61242 .36192 Mdot
.25014 .4347 Mdot
.4656 .6079 Mdot
.30603 .55889 Mdot
.56839 .31772 Mdot
.56852 .64138 Mdot
.36446 .7816 Mdot
.58397 .50677 Mdot
.19785 .32273 Mdot
.75875 .51412 Mdot
.45815 .49075 Mdot
.39741 .40527 Mdot
.53258 .31656 Mdot
.6861 .6876 Mdot
.64946 .50393 Mdot
.21893 .32884 Mdot
.49404 .51089 Mdot
.3796 .40739 Mdot
.31003 .64849 Mdot
.37766 .27164 Mdot
.43295 .5265 Mdot
.68045 .62285 Mdot
.47712 .73427 Mdot
.53432 .45238 Mdot
.52723 .73714 Mdot
.57475 .64815 Mdot
.79202 .29846 Mdot
.65653 .4223 Mdot
.79697 .55817 Mdot
.22536 .32552 Mdot
.65321 .51928 Mdot
.53172 .63924 Mdot
.33866 .33344 Mdot
.40789 .25757 Mdot
.48453 .75813 Mdot
.63596 .3325 Mdot
.40828 .31481 Mdot
.69975 .29398 Mdot
.18948 .38684 Mdot
.18009 .46907 Mdot
.72216 .74427 Mdot
.50538 .65948 Mdot
.36333 .27008 Mdot
.40747 .2656 Mdot
.51197 .6575 Mdot
.48411 .65025 Mdot
.58346 .6111 Mdot
.1652 .38866 Mdot
.67502 .69751 Mdot
.65432 .22638 Mdot
.46701 .41384 Mdot
.53416 .23498 Mdot
.5185 .30608 Mdot
.40155 .30918 Mdot
.23006 .32301 Mdot
.33064 .67868 Mdot
.21764 .55804 Mdot
.37825 .46518 Mdot
.4608 .81415 Mdot
.28922 .74403 Mdot
.53043 .51197 Mdot
.41014 .64478 Mdot
.68761 .48964 Mdot
.36625 .5835 Mdot
.16064 .56893 Mdot
.44128 .20886 Mdot
.66108 .745 Mdot
.59035 .49661 Mdot
.39755 .5551 Mdot
.35357 .49388 Mdot
.31238 .45596 Mdot
.65332 .65586 Mdot
.24203 .69431 Mdot
.41382 .2774 Mdot
.3638 .44927 Mdot
.32627 .65695 Mdot
.76622 .49992 Mdot
.26687 .30065 Mdot
.42232 .21241 Mdot
.56167 .49937 Mdot
.75301 .49348 Mdot
.52015 .41723 Mdot
.64516 .21557 Mdot
.69744 .37523 Mdot
.22358 .44382 Mdot
.60068 .71892 Mdot
.67433 .65563 Mdot
.54154 .31152 Mdot
.33379 .53346 Mdot
.73343 .60605 Mdot
.30132 .26064 Mdot
.71728 .77522 Mdot
.74533 .66049 Mdot
.14558 .52506 Mdot
.40769 .63381 Mdot
.67418 .6633 Mdot
.20807 .55301 Mdot
.68532 .80974 Mdot
.68834 .35228 Mdot
.18318 .5259 Mdot
.54617 .43122 Mdot
.20878 .34383 Mdot
.64462 .56407 Mdot
.632 .72319 Mdot
.30039 .73353 Mdot
.1689 .38217 Mdot
.31667 .27345 Mdot
.23774 .32388 Mdot
.25212 .53981 Mdot
.1558 .41585 Mdot
.57108 .77269 Mdot
.80788 .43411 Mdot
.61197 .4034 Mdot
.72264 .54444 Mdot
.2562 .63816 Mdot
.50852 .60859 Mdot
.37267 .32924 Mdot
.82365 .47659 Mdot
.48244 .7217 Mdot
.24191 .59449 Mdot
.2939 .37679 Mdot
.69255 .62808 Mdot
.40222 .40743 Mdot
.33564 .22242 Mdot
.81135 .42476 Mdot
.49268 .28834 Mdot
.77758 .55559 Mdot
.60662 .22165 Mdot
.64958 .65398 Mdot
.68057 .42508 Mdot
.33642 .24791 Mdot
.6579 .25413 Mdot
.40398 .37257 Mdot
.80935 .29534 Mdot
.50966 .21026 Mdot
.57903 .60407 Mdot
.19116 .57041 Mdot
.41283 .20685 Mdot
.56256 .77396 Mdot
.72619 .72027 Mdot
.44925 .81483 Mdot
.33984 .37211 Mdot
.36945 .50235 Mdot
.14589 .43254 Mdot
.29802 .40815 Mdot
.17263 .53523 Mdot
.51333 .16887 Mdot
.28878 .637 Mdot
.30517 .5395 Mdot
.64469 .35434 Mdot
.54287 .5606 Mdot
.29219 .37027 Mdot
.19604 .5072 Mdot
.42194 .81281 Mdot
.52185 .35393 Mdot
.71129 .41142 Mdot
.62646 .32799 Mdot
.30565 .48044 Mdot
.74062 .49098 Mdot
.67263 .64498 Mdot
.51153 .34635 Mdot
.64268 .42596 Mdot
.37148 .35713 Mdot
.35185 .67799 Mdot
.23165 .57146 Mdot
.78038 .64042 Mdot
.67365 .48331 Mdot
.63446 .38141 Mdot
.20347 .42566 Mdot
.52434 .20615 Mdot
.71599 .5694 Mdot
.2273 .6438 Mdot
.69758 .65736 Mdot
.31006 .33005 Mdot
.2771 .33084 Mdot
.75625 .66569 Mdot
.80569 .37914 Mdot
.23765 .63632 Mdot
.46333 .81496 Mdot
.52986 .37979 Mdot
.42748 .61764 Mdot
.20339 .32477 Mdot
.39582 .31688 Mdot
.25431 .35917 Mdot
.52265 .53183 Mdot
.45908 .76595 Mdot
.26537 .62651 Mdot
.2588 .44234 Mdot
.51765 .43185 Mdot
.39909 .84995 Mdot
.56099 .64408 Mdot
.1615 .57686 Mdot
.62162 .53958 Mdot
.62666 .79222 Mdot
.65116 .39887 Mdot
.55369 .51728 Mdot
.48979 .42691 Mdot
.67529 .624 Mdot
.60034 .62734 Mdot
.58738 .20371 Mdot
.77952 .65621 Mdot
.60112 .32937 Mdot
.43829 .39881 Mdot
.66098 .23873 Mdot
.20145 .40999 Mdot
.38222 .59616 Mdot
.54283 .21204 Mdot
.52735 .50883 Mdot
.608 .28968 Mdot
.47057 .17633 Mdot
.69833 .51743 Mdot
.37719 .60938 Mdot
.36862 .37293 Mdot
.18724 .53539 Mdot
.31355 .22737 Mdot
.70655 .72409 Mdot
.40111 .45319 Mdot
.6742 .54391 Mdot
.22727 .48979 Mdot
.19301 .4001 Mdot
.53162 .40085 Mdot
.64569 .7008 Mdot
.38388 .35065 Mdot
.17158 .64461 Mdot
.21397 .66521 Mdot
.24631 .69713 Mdot
.4597 .40527 Mdot
.55531 .73758 Mdot
.5199 .80132 Mdot
.25944 .35427 Mdot
.70556 .5631 Mdot
.50681 .19896 Mdot
.36893 .34139 Mdot
.64761 .81723 Mdot
.46224 .66262 Mdot
.58515 .24299 Mdot
.26716 .63392 Mdot
.43356 .78797 Mdot
.66353 .54968 Mdot
.32526 .37748 Mdot
.47399 .48875 Mdot
.62166 .49858 Mdot
.68828 .63179 Mdot
.62885 .67423 Mdot
.2512 .36259 Mdot
.46906 .73227 Mdot
.37015 .45249 Mdot
.21983 .37985 Mdot
.57165 .72848 Mdot
.52942 .30453 Mdot
.50314 .2996 Mdot
.45425 .44254 Mdot
.592 .38267 Mdot
.29374 .55524 Mdot
.55242 .45927 Mdot
.53472 .43055 Mdot
.35644 .80206 Mdot
.42807 .33816 Mdot
.57041 .66578 Mdot
.6283 .77656 Mdot
.51589 .65211 Mdot
.13869 .47962 Mdot
.69393 .33855 Mdot
.32172 .65174 Mdot
.64118 .2729 Mdot
.73911 .36045 Mdot
.49507 .8566 Mdot
.25725 .68604 Mdot
.51691 .55705 Mdot
.4745 .66516 Mdot
.50091 .6868 Mdot
.56043 .40812 Mdot
.78962 .43717 Mdot
.36931 .6976 Mdot
.7657 .48545 Mdot
.29637 .32993 Mdot
.52074 .72441 Mdot
.55679 .23198 Mdot
.45547 .48205 Mdot
.17057 .36424 Mdot
.63672 .36719 Mdot
.28723 .77323 Mdot
.43888 .5187 Mdot
.21919 .53337 Mdot
.45788 .1748 Mdot
.70568 .70244 Mdot
.56519 .314 Mdot
.76924 .32556 Mdot
.36293 .59249 Mdot
.35862 .45606 Mdot
.5563 .6926 Mdot
.33819 .2959 Mdot
.46041 .34587 Mdot
.3325 .41934 Mdot
.6031 .50693 Mdot
.82151 .55849 Mdot
.74399 .50102 Mdot
.57673 .70626 Mdot
.48807 .5239 Mdot
.31361 .28432 Mdot
.62004 .69649 Mdot
.52642 .50616 Mdot
.19995 .44481 Mdot
.47912 .75545 Mdot
.51562 .72019 Mdot
.22978 .65439 Mdot
.40399 .27466 Mdot
.27976 .24514 Mdot
.45835 .56694 Mdot
.53937 .54141 Mdot
.61558 .71493 Mdot
.69063 .618 Mdot
.36238 .68649 Mdot
.39936 .2069 Mdot
.3709 .4017 Mdot
.62931 .74619 Mdot
.34916 .32797 Mdot
.44332 .50394 Mdot
.70632 .41534 Mdot
.72748 .5227 Mdot
.61817 .82733 Mdot
.31195 .71723 Mdot
.721 .68008 Mdot
.48759 .62513 Mdot
.76384 .49639 Mdot
.56892 .65901 Mdot
.49115 .26225 Mdot
.46912 .74992 Mdot
.67223 .32606 Mdot
.23863 .28491 Mdot
.40692 .2011 Mdot
.56248 .59624 Mdot
.62218 .31518 Mdot
.40967 .42513 Mdot
.45689 .49198 Mdot
.51734 .4597 Mdot
.35072 .58811 Mdot
.30047 .47748 Mdot
.69958 .72468 Mdot
.69902 .58952 Mdot
.45404 .51181 Mdot
.19022 .35465 Mdot
.29335 .23336 Mdot
.15745 .43831 Mdot
.526 .36915 Mdot
.56995 .67401 Mdot
.19633 .61095 Mdot
.39391 .6758 Mdot
.33489 .22097 Mdot
.26129 .65537 Mdot
.77262 .2769 Mdot
.20413 .52875 Mdot
.6791 .47808 Mdot
.81096 .59579 Mdot
.6214 .61676 Mdot
.47674 .18031 Mdot
.80921 .43183 Mdot
.43038 .28892 Mdot
.48635 .17817 Mdot
.43991 .87521 Mdot
.2982 .71417 Mdot
.63546 .68609 Mdot
.26182 .58961 Mdot
.43478 .44304 Mdot
.76895 .47582 Mdot
.37493 .4945 Mdot
.55619 .37638 Mdot
.57925 .30424 Mdot
.37324 .34955 Mdot
.38538 .63213 Mdot
.77567 .4791 Mdot
.29181 .36604 Mdot
.33242 .31097 Mdot
.42089 .26389 Mdot
.20088 .50991 Mdot
.37385 .69399 Mdot
.36737 .61026 Mdot
.54299 .74443 Mdot
.46963 .36606 Mdot
.49702 .30822 Mdot
.4102 .51142 Mdot
.58585 .30462 Mdot
.605 .66002 Mdot
.15093 .53361 Mdot
.46596 .26583 Mdot
.4179 .2397 Mdot
.58425 .67467 Mdot
.66271 .64596 Mdot
.26341 .32082 Mdot
.72516 .62617 Mdot
.79117 .48382 Mdot
.49814 .79276 Mdot
.18451 .39357 Mdot
.68704 .6688 Mdot
.37653 .29908 Mdot
.43 .83763 Mdot
.60435 .51787 Mdot
.36842 .78013 Mdot
.21601 .46708 Mdot
.71115 .63412 Mdot
.49452 .69912 Mdot
.67205 .46434 Mdot
.70873 .43112 Mdot
.70405 .6317 Mdot
.52446 .18142 Mdot
.34152 .28215 Mdot
.27921 .64629 Mdot
.18042 .4493 Mdot
.58877 .40149 Mdot
.37796 .31631 Mdot
.6515 .44666 Mdot
.76489 .46521 Mdot
.61549 .73219 Mdot
.19429 .33633 Mdot
.51313 .44995 Mdot
.28761 .41861 Mdot
.38014 .57699 Mdot
.43083 .69671 Mdot
.68768 .60516 Mdot
.61895 .44013 Mdot
.78805 .56993 Mdot
.56082 .71052 Mdot
.74718 .53017 Mdot
.78944 .40477 Mdot
.32806 .3876 Mdot
.47695 .59757 Mdot
.59223 .72514 Mdot
.42312 .36562 Mdot
.75977 .40676 Mdot
.4005 .59312 Mdot
.28829 .43143 Mdot
.58192 .42514 Mdot
.33422 .7544 Mdot
.29441 .71525 Mdot
.20127 .42909 Mdot
.44074 .22069 Mdot
.71297 .5681 Mdot
.25739 .65395 Mdot
.5994 .62037 Mdot
.4481 .65937 Mdot
.74802 .60614 Mdot
.31532 .55017 Mdot
.49427 .2606 Mdot
.54697 .64573 Mdot
.19591 .42031 Mdot
.44247 .63046 Mdot
.27019 .42062 Mdot
.54424 .48511 Mdot
.28 .30019 Mdot
.50667 .49206 Mdot
.46035 .17604 Mdot
.62448 .61507 Mdot
.36932 .38646 Mdot
.5867 .51879 Mdot
.54775 .42936 Mdot
.75281 .65581 Mdot
.26003 .27992 Mdot
.78644 .63633 Mdot
.26784 .48308 Mdot
.71705 .67407 Mdot
.47733 .81384 Mdot
.49897 .17194 Mdot
.35431 .38365 Mdot
.51835 .46158 Mdot
.46293 .48926 Mdot
.5859 .59144 Mdot
.75036 .43765 Mdot
.51453 .26314 Mdot
.38773 .68815 Mdot
.45842 .24236 Mdot
.65716 .31077 Mdot
.36789 .6015 Mdot
.53495 .8036 Mdot
.18316 .42832 Mdot
.49459 .73566 Mdot
.54592 .51691 Mdot
.56703 .2945 Mdot
.32423 .39598 Mdot
.88519 .46676 Mdot
.15905 .56716 Mdot
.38022 .57567 Mdot
.46691 .42023 Mdot
.33076 .41482 Mdot
.56852 .35645 Mdot
.37407 .70448 Mdot
.19995 .42736 Mdot
.62525 .5073 Mdot
.55036 .26676 Mdot
.71402 .51596 Mdot
.674 .61904 Mdot
.25154 .44631 Mdot
.63113 .48813 Mdot
.14103 .50091 Mdot
.54927 .20724 Mdot
.69727 .60103 Mdot
.84866 .38382 Mdot
.7313 .56203 Mdot
.58609 .71404 Mdot
.31217 .27113 Mdot
.15705 .47659 Mdot
.46103 .40708 Mdot
.537 .29176 Mdot
.29956 .72281 Mdot
.36793 .39284 Mdot
.35035 .30471 Mdot
.77666 .55461 Mdot
.7539 .53786 Mdot
.79555 .44895 Mdot
.73953 .35839 Mdot
.38596 .81986 Mdot
.31933 .6652 Mdot
.17609 .47962 Mdot
.69076 .34432 Mdot
.6604 .81049 Mdot
.26554 .26431 Mdot
.32371 .35762 Mdot
.78423 .49177 Mdot
.33444 .25497 Mdot
.31678 .43463 Mdot
.52597 .78558 Mdot
.68583 .32935 Mdot
.48729 .7719 Mdot
.72741 .35571 Mdot
.76189 .60076 Mdot
.35158 .32994 Mdot
.45093 .79843 Mdot
.51197 .44433 Mdot
.20061 .48198 Mdot
.83807 .50203 Mdot
.39768 .39794 Mdot
.56323 .27073 Mdot
.27106 .46438 Mdot
.20812 .38934 Mdot
.32555 .24895 Mdot
.50447 .45391 Mdot
.44166 .87235 Mdot
.17938 .54024 Mdot
.73262 .62803 Mdot
.33971 .51074 Mdot
.23782 .27973 Mdot
.4799 .45382 Mdot
.25947 .66267 Mdot
.49687 .19063 Mdot
.47928 .28912 Mdot
.61034 .71074 Mdot
.32111 .5639 Mdot
.25163 .67516 Mdot
.39557 .64449 Mdot
.43096 .78962 Mdot
.56072 .31315 Mdot
.39355 .40461 Mdot
.83497 .5161 Mdot
.25167 .47125 Mdot
.45702 .49737 Mdot
.54828 .64902 Mdot
.15029 .50761 Mdot
.24161 .54793 Mdot
.29095 .55535 Mdot
.27078 .5805 Mdot
.78378 .64499 Mdot
.80448 .35033 Mdot
.4375 .48184 Mdot
.68158 .68832 Mdot
.37374 .33112 Mdot
.28141 .33464 Mdot
.27379 .69871 Mdot
.58993 .89849 Mdot
.44727 .17603 Mdot
.54084 .62894 Mdot
.37108 .77562 Mdot
.434 .40605 Mdot
.16061 .43831 Mdot
.73326 .32479 Mdot
.52444 .31534 Mdot
.7846 .66932 Mdot
.36299 .4198 Mdot
.42067 .51199 Mdot
.56224 .19239 Mdot
.26646 .269 Mdot
.841 .52189 Mdot
.20634 .32253 Mdot
.31417 .51963 Mdot
.40345 .48047 Mdot
.82112 .6859 Mdot
.20063 .36696 Mdot
.30194 .54578 Mdot
.76528 .6779 Mdot
.51253 .63199 Mdot
.39014 .50081 Mdot
.71742 .45248 Mdot
.39332 .33316 Mdot
.33967 .31066 Mdot
.16851 .3842 Mdot
.55857 .73339 Mdot
.59115 .30221 Mdot
.61667 .56474 Mdot
.49648 .42733 Mdot
.42125 .58807 Mdot
.65204 .5463 Mdot
.31841 .32799 Mdot
.47136 .44605 Mdot
.60532 .47921 Mdot
.40046 .33416 Mdot
.6224 .18816 Mdot
.37612 .63806 Mdot
.55716 .59168 Mdot
.26099 .52532 Mdot
.49297 .73904 Mdot
.293 .36725 Mdot
.27775 .36222 Mdot
.4991 .18097 Mdot
.56806 .13996 Mdot
.63397 .41183 Mdot
.45477 .55118 Mdot
.54063 .75224 Mdot
.37423 .68534 Mdot
.2696 .61376 Mdot
.63097 .45863 Mdot
.75369 .41928 Mdot
.31226 .53037 Mdot
.45983 .50132 Mdot
.60132 .50915 Mdot
.15279 .59778 Mdot
.36432 .49577 Mdot
.31749 .68476 Mdot
.31362 .24293 Mdot
.53286 .30576 Mdot
.35077 .6364 Mdot
.37394 .59382 Mdot
.56793 .77272 Mdot
.47442 .45418 Mdot
.39439 .43435 Mdot
.50923 .30162 Mdot
.16791 .43594 Mdot
.4411 .62981 Mdot
.29627 .65884 Mdot
.36901 .55012 Mdot
.45025 .3112 Mdot
.62866 .68992 Mdot
.25056 .69045 Mdot
.4736 .58262 Mdot
.33112 .21859 Mdot
.47539 .28542 Mdot
.42075 .27726 Mdot
.29033 .61424 Mdot
.1704 .53708 Mdot
.74286 .65734 Mdot
.28737 .62973 Mdot
.676 .73968 Mdot
.67945 .44109 Mdot
.29637 .37493 Mdot
.63416 .33992 Mdot
.45412 .51719 Mdot
.49744 .64204 Mdot
.13849 .42196 Mdot
.2646 .70046 Mdot
.61673 .57647 Mdot
.53126 .3725 Mdot
.42903 .66074 Mdot
.49469 .4311 Mdot
.83365 .34808 Mdot
.74078 .31035 Mdot
.14129 .50553 Mdot
.33104 .29319 Mdot
.54868 .75435 Mdot
.69785 .62509 Mdot
.3 .59313 Mdot
.60131 .33968 Mdot
.16314 .43821 Mdot
.46527 .55726 Mdot
.76009 .58981 Mdot
.39357 .49645 Mdot
.64383 .74959 Mdot
.44404 .45716 Mdot
.60528 .31471 Mdot
.55911 .35161 Mdot
.73081 .7064 Mdot
.29423 .27057 Mdot
.47594 .45766 Mdot
.78431 .30104 Mdot
.1925 .51417 Mdot
.2206 .32659 Mdot
.63194 .32978 Mdot
.65594 .78533 Mdot
.47974 .62697 Mdot
.44628 .46359 Mdot
.58525 .55246 Mdot
.25187 .50484 Mdot
.70995 .62945 Mdot
.2962 .32157 Mdot
.6155 .64369 Mdot
.57902 .59617 Mdot
.70306 .17983 Mdot
.32957 .34645 Mdot
.46887 .63755 Mdot
.73649 .59479 Mdot
.20985 .32891 Mdot
.42152 .31013 Mdot
.59849 .19117 Mdot
.66919 .3935 Mdot
.43995 .56298 Mdot
.47053 .7281 Mdot
.22358 .54003 Mdot
.70913 .5012 Mdot
.45007 .85573 Mdot
.51156 .20366 Mdot
.4208 .28164 Mdot
.62548 .442 Mdot
.51258 .65438 Mdot
.53285 .63215 Mdot
.68989 .29529 Mdot
.68139 .21748 Mdot
.40811 .44431 Mdot
.19328 .39339 Mdot
.53417 .85009 Mdot
.36344 .28267 Mdot
.1595 .41738 Mdot
.64359 .59121 Mdot
.48382 .64434 Mdot
.29299 .36045 Mdot
.51099 .36296 Mdot
.56591 .37705 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo09Kooooo0_l00005ooooo`;o
0000Z_ooool001cooooo00?o0000ooooooooool0U_ooool2o`0000Gooooo0_l0002Zooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0:Sooooo0_l0002O
ooooo`007?ooool00ol0003oooooooooo`2Xooooo`;o0000Woooool001cooooo0_l0003ooooood_o
oooo000Looooo`03o`000?oooooooooo08kooooo0_l0000Qooooo`;o0000U_ooool001cooooo00?o
0000ooooooooool0S_ooool2o`00027ooooo0_l0002Fooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo08Kooooo0_l00031ooooo`007?ooool00ol0003o
ooooooooo`26ooooo`;o0000`Oooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`2nooooo`;o0000ROooool001cooooo00?o0000ooooooooool0__ooool2
o`0008Wooooo000Looooo`03o`000?oooooooooo07kooooo0_l00039ooooo`007?ooool00ol0003o
ooooooooo`1nooooo`;o0000bOooool001cooooo00?o0000ooooooooool0O?ooool2o`0004cooooo
0_l0001mooooo`007?ooool00ol0003oooooooooo`1looooo`;o0000C?ooool2o`0007gooooo000L
ooooo`03o`000?oooooooooo07Sooooo0_l0000kooooo`;o0000T_ooool001cooooo00?o0000oooo
ooooool0N?ooool2o`0003_ooooo0_l0002Booooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo07?ooooo0_l0003Dooooo`007?ooool2o`0007Cooooo0_l0
003Dooooo`007?ooool00ol0003oooooooooo`2aooooo`;o0000U_ooool001cooooo00?o0000oooo
ooooool0J?ooool3o`0004Kooooo0_l0002Fooooo`007?ooool00ol0003oooooooooo`1Xooooo`?o
0000g_ooool001cooooo00?o0000ooooooooool0Uoooool2o`000;3ooooo000Looooo`03o`000?oo
oooooooo09Oooooo0_l0000:ooooo`;o0000Y?ooool001cooooo00?o0000ooooooooool0SOooool2
o`0000oooooo0_l00003ooooo`;o00000_ooool2o`000:3ooooo000Looooo`03o`000?oooooooooo
08gooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l00005ooooo`;o00001oooool2
o`0001Sooooo0_l00026ooooo`007?ooool00ol0003oooooooooo`1jooooo`;o00004_ooool2o`00
0003ooooool0003o000000Ko000000?oooooo`000?l000009Oooool2o`0008Kooooo000Looooo`03
o`000?oooooooooo073ooooo0_l00004ooooo`;o00000_ooool2o`0001;ooooo0_l00002ooooo`Oo
000000?oooooo`000?l000000_ooool2o`0000Oooooo0_l00004ooooo`;o0000<_ooool2o`0006Ko
oooo000Looooo`03o`000?oooooooooo073ooooo1?l00002ooooo`;o00006_ooool3o`0000;ooooo
0_l00005ooooo`Co00000oooool4o`0000?ooooo0ol00002ooooo`;o0000;_ooool2o`0006Kooooo
000Looooo`03o`000?oooooooooo07;ooooo1?l00004ooooo`?o00002_ooool2o`0000;ooooo0_l0
0005ooooo`;o00002Oooool2o`000003ooooool0003o000000?ooooo0_l00005ooooo`;o00000ooo
ool2o`0000Oooooo0_l0002=ooooo`007?ooool00ol0003oooooooooo`1cooooo`?o00001?ooool3
o`0000Wooooo0ol00002ooooo`;o000000?oooooo`000?l000003Oooool3o`0001Kooooo0_l00002
ooooo`;o000000Coooooo`000?l0003o00001_ooool3o`00083ooooo00001_ooooook^k^oc8b<_l0
003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`1gooooo`;o0000
2_ooool2o`000003ooooool0003o000000Kooooo1?l0000:ooooo`Co00004oooool2o`000003oooo
ool0003o000000Gooooo1?l00005ooooo`?o0000P?ooool00006oooooomgMgOoV9RHoooooonHV9So
MgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo
07Kooooo0ol00002ooooo`;o000000?oooooo`000?l000000oooool:o`0000?ooooo0_l0000:oooo
o`Co00004oooool2o`0000[ooooo0_l00008ooooo`;o0000O_ooool00003ooooool@413ooooo00;o
oooo00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo06Oo
oooo0_l0000;ooooo`Ko000000?oooooo`000?l000000ol00005ooooo`So00005?ooool2o`0001Go
oooo0_l0000?ooooo`;o000000Coooooo`000?l0003ooooo0ol0001gooooo`0000?oooooo`000?oo
ool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0001Wooooo`;o
00002oooool2o`0000;ooooo0_l00003ooooo`Go000000?oooooo`000?l000001oooool2o`0001?o
oooo0_l0000Eooooo`?o00000_ooool2o`000003ooooool0003o000000;ooooo0_l00006ooooo`;o
000000?oooooo`000?l000000_l0000Hooooo`;o0000G?ooool00003ooooool0003ooooo00;ooooo
00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo07Wooooo
0_l00004ooooo`?o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o00004?ooool2o`0000;o
oooo0_l00003ooooo`;o00004?ooool6o`000003ooooool0003o000000;ooooo0_l0000;ooooo`;o
00006?ooool2o`0005cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Oooooo`;o00002?ooool2o`0000kooooo
0_l00003ooooo`?o000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l0000@ooooo`;o0000
0_ooool2o`0000?ooooo0_l00006ooooo`;o00002_ooool2o`0001Oooooo0_l0001cooooo`0000Ko
ooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0
003oooooooooo`1Oooooo`;o00002?ooool2o`0000kooooo0_l00002ooooo`Co000000?oooooo`00
0?l000002?ooool2o`0001Cooooo0_l00005ooooo`;o00000_ooool4o`0000[ooooo0ol000000ooo
oooo0000o`00000Cooooo`Co0000LOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0COooool2o`0001Kooooo0_l0
0005ooooo`Ko00001oooool2o`0000;ooooo1?l00004ooooo`;o000000?oooooo`000?l000000_l0
00000ooooooo0000o`000002o`00017ooooo0_l00005ooooo`;o000000?oooooo`000?l000000ol0
000;ooooo`;o000000?oooooo`000?l000005Oooool2o`000003ooooool0003o000006kooooo000L
ooooo`03o`000?oooooooooo04gooooo0_l0000Fooooo`;o00001?ooool7o`0000?ooooo0_l00000
0ooooooo0000o`00000;ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000002
o`0001_ooooo0_l000000ooooooo0000o`00000Mooooo`;o00002Oooool3o`0006gooooo000Loooo
o`03o`000?oooooooooo06Sooooo1Ol00008ooooo`;o000000?oooooo`000?l000004Oooool3o`00
03[ooooo0_l00004ooooo`;o00002_ooool2o`0001;ooooo0_l0001Iooooo`007?ooool00ol0003o
ooooooooo`1Xooooo`?o00003oooool2o`0000oooooo0ol00003ooooo`;o00001?ooool2o`0002So
oooo0_l00005ooooo`;o00009?ooool2o`0005Wooooo000Looooo`03o`000?oooooooooo06;ooooo
0_l00005ooooo`;o00003oooool2o`0001Gooooo0ol00003ooooo`;o00008_ooool2o`0000Cooooo
0_l0000>ooooo`;o0000M_ooool001cooooo00?o0000ooooooooool0H_ooool2o`0000Kooooo0_l0
000;ooooo`;o00006Oooool2o`0002Oooooo0_l000000ooooooo0000o`00000Aooooo`;o00001?oo
ool2o`0000Cooooo0_l0001Zooooo`007?ooool00ol0003oooooooooo`1Looooo`;o00002_ooool4
o`0000_ooooo0_l000001?oooooo0000o`000?ooool2o`0000Oooooo0_l00005ooooo`;o00005?oo
ool2o`0000Kooooo0_l000001?oooooo0000o`000?ooool2o`0000_ooooo0_l00007ooooo`;o0000
1Oooool2o`0000Oooooo0_l00004ooooo`;o0000J_ooool001cooooo00?o0000ooooooooool0G?oo
ool3o`0000Wooooo1?l00003ooooo`;o00002Oooool2o`000003ooooool0003o000000Gooooo1?l0
0002ooooo`Go00005?ooool2o`0000Gooooo0ol000001?oooooo0000o`000?ooool2o`0001Cooooo
1?l00003ooooo`;o0000NOooool001cooooo00?o0000ooooooooool0GOooool2o`0000Sooooo0_l0
0006ooooo`;o00000_ooool4o`0000Cooooo0_l00003ooooo`;o00000_ooool2o`0000Cooooo1?l0
000Looooo`;o00007Oooool2o`0000Sooooo0_l00004ooooo`;o00002?ooool2o`0006Cooooo000L
ooooo`03o`000?oooooooooo05kooooo0_l00002ooooo`;o00000oooool2o`0000[ooooo1?l00004
ooooo`;o00000oooool2o`0000;ooooo0ol00003ooooo`?o00001?ooool2o`0001cooooo0_l00009
ooooo`;o00005oooool2o`0000Cooooo0_l00003ooooo`;o00000oooool2o`0006Cooooo000Loooo
o`03o`000?oooooooooo05Oooooo0_l00005ooooo`;o00000_ooool4o`0000oooooo0_l000000ooo
oooo0000o`00000;ooooo`?o00002Oooool2o`0000kooooo0_l00009ooooo`;o000000?oooooo`00
0?l000002Oooool2o`0000gooooo0_l0000Cooooo`;o0000JOooool001cooooo00?o0000oooooooo
ool0Eoooool2o`0000_ooooo1?l00002ooooo`?o00002oooool2o`0000;ooooo0_l00004ooooo`;o
00000_ooool3o`0001Sooooo0_l00004ooooo`;o00000oooool2o`0000cooooo0_l00002ooooo`;o
00002Oooool2o`0001Gooooo0_l00003ooooo`;o00003oooool2o`00057ooooo000Looooo`;o0000
Hoooool2o`0000;ooooo0_l00002ooooo`?o00003oooool2o`0000Cooooo0_l00003ooooo`;o0000
0_ooool2o`0001[ooooo0_l0000Eooooo`;o00001oooool2o`0000;ooooo0ol0000Booooo`;o0000
0oooool2o`0000oooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o00000_oo
ool2o`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l000004_ooool2o`0000Cooooo0ol0
000@ooooo`;o00000oooool2o`0001Cooooo0_l0000=ooooo`;o00000_ooool3o`0000Cooooo0_l0
000Booooo`;o0000HOooool001cooooo00?o0000ooooooooool0G_ooool2o`0000Wooooo0_l00002
ooooo`;o000000?oooooo`000?l000002_ooool2o`0000?ooooo0_l000000ooooooo0000o`000004
ooooo`Co00003oooool2o`0000?ooooo0_l0000Dooooo`?o00001oooool2o`0000kooooo0_l0000?
ooooo`;o000000?oooooo`000?l00000HOooool001cooooo00?o0000ooooooooool0Foooool2o`00
0003ooooool0003o000001cooooo0_l00003ooooo`;o00002Oooool2o`0000oooooo0_l0000Boooo
o`;o00001_ooool4o`0000Gooooo0ol0000Nooooo`Co0000H_ooool001cooooo00?o0000oooooooo
ool0Doooool2o`0000Kooooo0_l000000ooooooo0000o`00000Kooooo`;o00002?ooool2o`0000ko
oooo0_l00005ooooo`?o00001?ooool2o`0000cooooo0_l000000ooooooo0000o`000002o`0000?o
oooo0_l00006ooooo`;o00008?ooool2o`0006;ooooo000Looooo`03o`000?oooooooooo05?ooooo
0_l0000Vooooo`;o00001?ooool2o`0000;ooooo0_l0000=ooooo`?o00001Oooool2o`0000Gooooo
0_l0000:ooooo`;o00000oooool4o`0000Kooooo0_l00004ooooo`?o00009?ooool2o`0005cooooo
000Looooo`03o`000?oooooooooo05?ooooo0_l00007ooooo`;o00003?ooool2o`0000Kooooo0_l0
0008ooooo`;o00000oooool2o`0000Kooooo0_l00009ooooo`;o00006Oooool2o`0000;ooooo1?l0
00000ooooooo0000o`000004ooooo`;o00001?ooool3o`0001Oooooo0_l000000ooooooo0000o`00
0008ooooo`;o0000G?ooool001cooooo00?o0000ooooooooool0Doooool3o`000004ooooool0003o
0000o`0000;ooooo0ol00003ooooo`?o00001Oooool2o`0000Kooooo0ol00002ooooo`;o00000ooo
ool4o`0000Wooooo0_l0000Xooooo`;o00000oooool2o`0000Cooooo0_l00002ooooo`;o00002?oo
ool2o`0000_ooooo0_l00003ooooo`;o000000?oooooo`000?l00000I_ooool001cooooo00?o0000
ooooooooool0E?ooool2o`000004ooooool0003o0000o`0000?ooooo0_l00003ooooo`?o00002_oo
ool2o`0000;ooooo0_l000001?oooooo0000o`000?l00005ooooo`?o0000=oooool3o`0000Oooooo
1?l00006ooooo`;o00002oooool2o`0000?ooooo0_l0000Gooooo`;o0000D?ooool001cooooo00?o
0000ooooooooool0B_ooool2o`0000Cooooo1_l00004ooooo`;o00004oooool2o`0000Gooooo0_l0
0007ooooo`;o00000_ooool4o`0003;ooooo0_l00006ooooo`;o000000?oooooo`000?l000002_oo
ool2o`0000cooooo0_l00007ooooo`;o00003_ooool2o`00053ooooo000Looooo`03o`000?oooooo
oooo04[ooooo0_l00004ooooo`Ko00001?ooool2o`0000[ooooo0_l00003ooooo`;o00001Oooool2
o`0000Kooooo1?l00005ooooo`Co00001Oooool2o`0000Wooooo0_l0000Xooooo`;o000000?ooooo
o`000?l000000_l000000ooooooo0000o`000005ooooo`;o00005Oooool2o`00063ooooo000Loooo
o`03o`000?oooooooooo04[ooooo0_l00007ooooo`;o00003Oooool2o`0000;ooooo0_l00003oooo
o`;o00000oooool5o`0000Gooooo1?l00003ooooo`;o000000Coooooo`000?l0003o00001Oooool2
o`0000Gooooo0_l00002ooooo`;o0000:oooool4o`000003ooooool0003o000000;o00008oooool2
o`0005Oooooo000Looooo`03o`000?oooooooooo04[ooooo0_l00007ooooo`?o00003?ooool2o`00
00[ooooo1?l000000ooooooo0000o`000008ooooo`;o00000_ooool2o`000003ooooool0003o0000
00;ooooo0_l00009ooooo`;o00000_ooool3o`0000;ooooo0ol0000Uooooo`;o00001Oooool2o`00
02?ooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00001Oooool2o`0000Ko
oooo0_l0000@ooooo`;o00003Oooool2o`0000Wooooo1?l0000<ooooo`;o00000_ooool3o`0000co
oooo0_l0000Eooooo`Co00000_ooool4o`0000Wooooo0_l0001booooo`007?ooool00ol0003ooooo
ooooo`1=ooooo`;o000000Coooooo`000?l0003ooooo0ol00006ooooo`;o00002_ooool2o`00017o
oooo0_l0000=ooooo`;o00000_ooool2o`0000Kooooo0_l0000Booooo`?o00001oooool2o`0000Go
oooo0_l000001?oooooo0000o`000?ooool6o`000003ooooool0003o000000?o00002?ooool2o`00
00Gooooo0_l00002ooooo`;o00008Oooool2o`0004Cooooo000Looooo`03o`000?oooooooooo053o
oooo0_l000001?oooooo0000o`000?l0000;ooooo`?o00001?ooool4o`0000gooooo1?l00003oooo
o`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00002?ooool2o`0000Sooooo0_l00008oooo
o`;o00001Oooool2o`000004ooooool0003o0000ooooo`;o000000Coooooo`000?l0003o00001?oo
ool2o`0000oooooo0_l00002ooooo`;o00004_ooool4o`0000Gooooo0_l00004ooooo`;o0000A?oo
ool001cooooo0_l0001Dooooo`;o00000_ooool4o`0000Kooooo0ol00005ooooo`?o00002oooool4
o`0000Gooooo0_l00005ooooo`;o00004_ooool2o`0000?ooooo1?l0000<ooooo`;o00003oooool2
o`0000Gooooo0_l0000Zooooo`Co00000oooool4o`0004[ooooo000Looooo`03o`000?oooooooooo
04Oooooo0_l0000:ooooo`;o00000_ooool5o`0000Oooooo0_l00004ooooo`;o00000oooool4o`00
00Gooooo0_l0000Rooooo`;o00000oooool4o`000004ooooool0003o0000ooooo`;o00001Oooool3
o`0000Kooooo1_l00003ooooo`;o00001Oooool2o`0000Wooooo0_l0000Booooo`;o00004_ooool2
o`0004cooooo000Looooo`03o`000?oooooooooo04;ooooo0_l00003ooooo`;o00001Oooool2o`00
00Oooooo0_l000000ooooooo0000o`000007ooooo`;o00002Oooool4o`00013ooooo1?l00007oooo
o`;o00003?ooool2o`0000Sooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l00005oooo
o`So00002oooool3o`0000Oooooo0_l0000Booooo`;o0000H?ooool001cooooo00?o0000oooooooo
ool0@_ooool2o`0000[ooooo0_l0000:ooooo`;o000000?oooooo`000?l000001oooool2o`0000?o
oooo0ol0000Aooooo`So00001_ooool2o`0000Gooooo0_l00002ooooo`Go000000?oooooo`000?l0
00001Oooool2o`0000;ooooo0ol0000:ooooo`?o00001oooool4o`0000Gooooo0ol00006ooooo`;o
00001?ooool2o`0001?ooooo1?l0001Hooooo`007?ooool00ol0003oooooooooo`19ooooo`;o0000
2oooool2o`0000Gooooo0_l00007ooooo`Co000000Coooooo`000?l0003o00004Oooool3o`0000?o
oooo0ol00004ooooo`_o000000Coooooo`000?l0003o00000_ooool3o`0000cooooo0_l00004oooo
o`Co00002_ooool4o`0000kooooo0_l00004ooooo`Co00001oooool2o`0000Sooooo1?l0001Hoooo
o`007?ooool00ol0003oooooooooo`19ooooo`;o00000_ooool2o`0000Oooooo0_l00009ooooo`;o
00001Oooool2o`000003ooooool0003o000000[ooooo0ol00003ooooo`Ko00000_ooool3o`0000Co
oooo2ol00003ooooo`;o000000?oooooo`000?l000002?ooool4o`000003ooooool0003o000000Co
oooo1?l0000;ooooo`;o00000oooool2o`0000?ooooo0_l0000=ooooo`;o00001oooool2o`0000Wo
oooo0_l000000ooooooo0000o`00001Fooooo`007?ooool00ol0003oooooooooo`0oooooo`;o0000
3?ooool2o`0001;ooooo0_l00003ooooo`;o00000oooool2o`0000[ooooo0ol00003ooooo`;o0000
0_ooool2o`0000?ooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000_o0000
2Oooool6o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0000[ooooo0_l00003ooooo`;o
00000oooool2o`0000Cooooo0_l0000Kooooo`;o000000?oooooo`000?l00000E_ooool001cooooo
00?o0000ooooooooool0?Oooool4o`0000Kooooo0_l00006ooooo`;o000000?oooooo`000?l00000
2?ooool2o`0000Sooooo0_l0000;ooooo`;o00005?oooolAo`0000Oooooo0_l00002ooooo`;o0000
2?ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000001?ooool5o`0000ko
oooo0_l00009ooooo`;o00007_ooool2o`0000[ooooo0_l0000oooooo`007?ooool00ol0003ooooo
ooooo`0mooooo`Co00001?ooool4o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000
o`000008ooooo`;o00004?ooool2o`0000?ooooo0_l0000<ooooo`;o00001ooooolAo`0000?ooooo
0_l000000ooooooo0000o`000009ooooo`;o000000?oooooo`000?l000001oooool2o`000004oooo
ool0003o0000ooooo`Oo00004_ooool2o`0000?ooooo0_l0000<ooooo`;o00002Oooool3o`0000Co
oooo0_l0000:ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0??ooool6o`000003oooo
ool0003o000000;o00000oooool2o`0001Sooooo0_l00008ooooo`;o000000?oooooo`000?l00000
0_ooool2o`0000[ooooo0_l00003ooooo`;o00000_oooolCo`000004ooooool0003o0000ooooo`;o
00002Oooool2o`000003ooooool0003o000000Oooooo0_l000001?oooooo0000o`000?ooool7o`00
00?ooooo1?l00004ooooo`?o00001?ooool2o`0000;ooooo0_l0000=ooooo`?o00002?ooool4o`00
053ooooo000Looooo`03o`000?oooooooooo03cooooo0_l00002ooooo`;o000000Coooooo`000?l0
003o00004?ooool2o`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l000001?ooool2o`00
00;ooooo0_l000000ooooooo0000o`000002ooooo`?o00000oooool2o`0000Oooooo4Ol000000ooo
oooo0000o`000005o`0000Cooooo0_l0000>ooooo`Go00000_ooool2o`0000;ooooo2Ol00003oooo
o`Go00000oooool3o`0000Sooooo0_l0000=ooooo`?o00002_ooool2o`00053ooooo000Looooo`03
o`000?oooooooooo04?ooooo0_l0000Aooooo`Co00000oooool2o`0000;ooooo0_l00007ooooo`;o
00000_ooool3o`0000Gooooo0_l00003ooooo`Go00001?oooolDo`000005ooooool0003o0000o`00
0?ooool00_l000000ooooooo0000o`00000?ooooo`Go00000_ooool3o`000003ooooool0003o0000
00So00000oooool4o`0000Cooooo1?l00009ooooo`;o0000JOooool001cooooo00?o0000oooooooo
ool0>oooool2o`0001_ooooo0_l0000@ooooo`;o00000oooool2o`0000;ooooo1?l00004ooooo`Go
000000Coooooo`000?l0003ooooo6ol000000ooooooo0000o`00000Doooooa;o00002Oooool4o`00
00;ooooo0_l00005ooooo`;o00000_ooool2o`0006Gooooo000Looooo`03o`000?oooooooooo03_o
oooo0_l000000ooooooo0000o`00000Gooooo`Co00006?ooool4o`0000[ooooo0_l00003oooooaSo
00003?ooool4o`0000Kooooo2Ol000000ooooooo0000o`00000<o`0000Gooooo1?l00002ooooo`;o
00001Oooool2o`0000;ooooo0_l0001Uooooo`007?ooool00ol0003oooooooooo`0nooooo`Co0000
5Oooool4o`0000cooooo0_l00003ooooo`;o00001_ooool3o`0000oooooo6?l00009ooooo`;o0000
00?oooooo`000?l000000_l00004ooooo`Ko000000?oooooo`000?l000004Ol00002ooooo`;o0000
00?oooooo`000?l000000_l00006ooooo`Co0000J_ooool001cooooo00?o0000ooooooooool0@?oo
ool2o`0000Wooooo0_l0000Jooooo`;o00000oooool2o`000003ooooool0003o000000Cooooo0_l0
00001?oooooo0000o`000?ooool2o`0000Wooooo5ol000000ooooooo0000o`000002ooooo`;o0000
0oooool3o`0000Kooooo1_l00002oooooa?o00000oooool2o`000003ooooool0003o000000?ooooo
0_l00002ooooo`Go00000oooool2o`0006Gooooo000Looooo`;o0000Boooool3o`0000;ooooo0_l0
0003ooooo`?o00000oooool2o`0000_ooooo0_l00006ooooo`;o00001Oooool7o`0000[ooooo3_l0
00000ooooooo0000o`000008o`0000;ooooo0_l00004ooooo`Co00001?ooool3o`000003ooooool0
003o000001Wo00000_ooool2o`0000;ooooo0ol00002ooooo`;o00001_ooool2o`0001Sooooo0_l0
0003ooooo`;o00002?ooool2o`0003cooooo000Looooo`03o`000?oooooooooo04Wooooo0ol00003
ooooo`;o00000oooool3o`0000?ooooo0_l0000=ooooo`;o00002oooool2o`000003ooooool0003o
000000cooooo5ol00008ooooo`;o00000_ooool2o`0000Gooooo7_l00006ooooo`;o00000oooool4
o`0001kooooo0_l00003ooooo`;o00002?ooool2o`0003cooooo000Looooo`03o`000?oooooooooo
03[ooooo0_l0000=ooooo`;o00001_ooool2o`0000Cooooo0_l0000?ooooo`?o00002_ooool3o`00
00_ooooo0_l000000ooooooo0000o`00000Eo`000004ooooool0003o0000ooooo`;o00000oooool2
o`0000[ooooo5ol000000ooooooo0000o`000006o`0000Wooooo0ol0000:ooooo`;o0000Goooool0
01cooooo00?o0000ooooooooool0>Oooool5o`00017ooooo1?l00004ooooo`;o00003?ooool2o`00
0003ooooool0003o000000Cooooo0_l00005ooooo`?o00002oooool2o`000003ooooool0003o0000
01Co000000?oooooo`000?l000001?l00002ooooo`;o00000oooool2o`0000Gooooo4ol000000ooo
oooo0000o`00000;o`0000Wooooo0_l0000;ooooo`;o00000_ooool2o`0001;ooooo0_l00017oooo
o`007?ooool00ol0003oooooooooo`0iooooo`;o000000?oooooo`000?l000004?ooool3o`0000Ko
oooo0_l00002ooooo`;o00002?ooool2o`0000Oooooo1?l00007ooooo`;o00000_ooool2o`0000So
oooo4ol00003ooooo`Co000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00001?oooolPo`00
0003ooooool0003o000000Cooooo0_l0000;ooooo`?o00001Oooool2o`0001;ooooo0_l00017oooo
o`007?ooool00ol0003oooooooooo`0dooooo`;o00004oooool2o`0000?ooooo0ol00006ooooo`;o
00000_ooool2o`0001?ooooo0_l00007ooooo`;o00000_ooool2o`0000Gooooo1?l00003oooooa7o
00001_ooool2o`0000cooooo0ol00002oooooa_o000000?oooooo`000?l000001?ooool2o`000003
ooooool0003o000000Gooooo0_l000001?oooooo0000o`000?l00005ooooo`;o000000?oooooo`00
0?l00000F?ooool001cooooo00?o0000ooooooooool0=?ooool2o`0000Gooooo1?l0000:ooooo`;o
00001?ooool2o`0000Kooooo0_l00002ooooo`?o00003oooool2o`0000?ooooo1?l00006ooooo`;o
00001_ooool4o`0000;ooooo4_l00005ooooo`;o00001?ooool2o`0000;ooooo0_l00004oooooago
00003?ooool2o`0000Gooooo0_l0000<ooooo`;o00003_ooool2o`0004Sooooo000Looooo`03o`00
0?oooooooooo03_ooooo1?l0000Looooo`Co00003?ooool4o`0000?ooooo1?l00006ooooo`;o0000
1oooool2o`0000?ooooo1_l000000ooooooo0000o`000005o`0000Wooooo0ol00003ooooo`Ko0000
1?oooolQo`000003ooooool0003o000002[ooooo0ol00017ooooo`007?ooool00ol0003ooooooooo
o`1Kooooo`Co00003?ooool3o`0000Kooooo1?l00007ooooo`;o00001?ooool2o`000003ooooool0
003o000000;ooooo2ol00004ooooo`;o00001?ooool3o`0000Gooooo1?l00004ooooob7o000000?o
ooooo`000?l000000_ooool4o`0000Cooooo0_l0000Oooooo`;o0000Aoooool001cooooo00?o0000
ooooooooool0>?ooool2o`000003ooooool0003o000000Wooooo0_l00005ooooo`;o00003Oooool3
o`0000Oooooo0_l00006ooooo`;o00000_ooool6o`0000Oooooo0ol00006ooooo`;o00001?ooool5
o`0000;ooooo0_l00004ooooo`;o00001?ooool2o`0000Cooooo0_l00007ooooob;o00001Oooool4
o`0000Cooooo0ol0001Wooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00001_ooool2o`00
0003ooooool0003o000000;ooooo0_l00003ooooo`Co00000oooool4o`0000gooooo0_l00008oooo
o`;o00001_ooool2o`0000;ooooo0_l0000;ooooo`Go00003Oooool2o`0001Cooooo0ol000001?oo
oooo0000o`000?ooool?o`000003ooooool0003o000001;o00000oooool2o`0000Wooooo0_l0000P
ooooo`;o0000AOooool001cooooo00?o0000ooooooooool0<?ooool2o`000003ooooool0003o0000
00;ooooo0_l00006ooooo`;o000000?oooooo`000?l000000ol00004ooooo`;o00002Oooool2o`00
01Oooooo0_l000001?oooooo0000o`000?ooool4o`0000Wooooo1?l00006ooooo`;o00003_ooool2
o`0000;ooooo0_l00006ooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`So000000?o
ooooo`000?l000003ol00007ooooo`;o00005oooool2o`0001;ooooo0_l0000<ooooo`;o0000=ooo
ool001cooooo00?o0000ooooooooool0<oooool2o`0000;ooooo1Ol00006ooooo`;o000000?ooooo
o`000?l000003oooool2o`0000oooooo0_l00002ooooo`;o00000_ooool4o`000003ooooool0003o
000000?o00002oooool2o`0000Kooooo0_l0000<ooooo`Co00000_ooool6o`0000kooooo6ol0000O
ooooo`;o00008?ooool2o`0003Oooooo000Looooo`03o`000?oooooooooo03;ooooo0_l00005oooo
o`?o00001?ooool2o`0001Gooooo1?l0000<ooooo`;o00000_ooool2o`0000Cooooo0_l000001?oo
oooo0000o`000?l00008ooooo`;o00005?ooool2o`0000?ooooo0_l00003ooooo`;o000000?ooooo
o`000?l000000_l00002ooooo`;o00002_oooolAo`000003ooooool0003o000000Oo00004?ooool2
o`0000kooooo0_l0001Hooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0<_ooool2o`0000?ooooo0ol0
00000ooooooo0000o`000003ooooo`;o00001_ooool2o`0000gooooo1_l0000;ooooo`;o00000ooo
ool2o`0000Cooooo1Ol00007ooooo`;o00002_ooool3o`0000Oooooo0_l00008ooooo`Co00001Ooo
ool2o`0000Sooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o0000013o00002Ooo
ool2o`0000Oooooo0_l0000>ooooo`;o0000F?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0eooooo`Go0000
00?oooooo`000?l000002oooool4o`0000oooooo0_l00009ooooo`Co00000oooool2o`0000Cooooo
1Ol00007ooooo`;o00002_ooool3o`0000Gooooo0_l00003ooooo`;o00001oooool2o`0000oooooo
1ol000000ooooooo0000o`00000>o`0000cooooo0_l0000Booooo`;o00005_ooool2o`0004Gooooo
00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006ooooo`03o`000?oo
oooooooo02cooooo0_l00007ooooo`?o00000oooool2o`0000gooooo0_l0000Iooooo`Go00003?oo
ool2o`0000Gooooo0_l0000<ooooo`Co00001?ooool3o`0000;ooooo0ol0000HoooooaOo00001_oo
ool2o`0001Sooooo0_l0000Fooooo`;o0000AOooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool02Oooool01?m4A4CogMgMooooool00007ooooo`?o0000;?ooool2o`0000Kooooo0_l0
0005ooooo`;o00003_ooool2o`0001Gooooo0_l000000ooooooo0000o`00000>ooooo`;o00001_oo
ool2o`0000cooooo1?l00002ooooo`Go00000oooool2o`0000?ooooo0_l00009ooooo`;o00002?oo
ool?o`000003ooooool0003o000000?o00002?ooool2o`0007Oooooo00000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003ooooooooo
o`0dooooo`;o00005Oooool2o`0001Gooooo0_l00003ooooo`;o000000Coooooo`000?l0003o0000
2?ooool2o`0000Gooooo0ol00009ooooo`?o000000?oooooo`000?l000000oooool3o`0000Sooooo
1_l00007ooooo`;o000000?oooooo`000?l000000oooool6o`0000?ooooo0ol000001?oooooo0000
o`000?ooool7o`0002Wooooo0_l0000:ooooo`;o0000B_ooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool02_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo02[ooooo
0_l0000Looooo`;o00002oooool2o`0000Kooooo0_l00003ooooo`Co000000Coooooo`000?l0003o
oooo0ol00009ooooo`Co00000_ooool5o`0000Kooooo1?l00007ooooo`?o00000_ooool4o`000003
ooooool0003o000000;ooooo0_l0000:ooooo`;o00000oooool3o`0000Cooooo1?l00002ooooo`;o
000000?oooooo`000?l000000_l00004ooooo`;o00009_ooool4o`000003ooooool0003o000000Go
oooo0_l0001:ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co0000
00Oooooo00?o0000ooooooooool0:_ooool2o`0000cooooo0_l00004ooooo`;o00002?ooool2o`00
00Oooooo0_l00002ooooo`;o00001_ooool2o`0000?ooooo1?l0000=ooooo`;o000000?oooooo`00
0?l000000_l00005ooooo`;o00001_ooool4o`0000Oooooo0ol000000ooooooo0000o`000005o`00
00?ooooo0_l0000@ooooo`;o00001?ooool2o`000003ooooool0003o000000?o00000_ooool2o`00
00Gooooo0ol0000Gooooo`;o00002oooool<o`0001Oooooo0_l0000dooooo`0000Koooooonk^k_lb
<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0:?ooool2
o`0000Kooooo0_l00006ooooo`;o00001?ooool2o`0000Oooooo0_l00008ooooo`?o00002oooool2
o`000004ooooool0003o0000o`0000?ooooo0_l00009ooooo`;o00004oooool3o`000003ooooool0
003o000000Kooooo1Ol00002ooooo`Oo00003?ooool2o`0000?ooooo0_l00003ooooo`;o000000?o
ooooo`000?l000000ol00002ooooo`;o00001_ooool2o`0001Kooooo0ol00009oooooa7o00005?oo
ool2o`0003Cooooo000Looooo`03o`000?oooooooooo02Sooooo0_l00005ooooo`?o00003?ooool3
o`0000Kooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000Cooooo1?l00003
ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Oooooo1?l0000?ooooo`;o00001_ooool2
o`0000Kooooo1Ol00003ooooo`Go00001?ooool2o`0000Oooooo0_l00003ooooo`;o00000oooool3
o`0000?ooooo0_l00006ooooo`;o00004_ooool2o`0000Kooooo0_l0000:ooooo`;o000000?ooooo
o`000?l000003Ol0000Cooooo`;o0000=?ooool001cooooo00?o0000ooooooooool0;oooool3o`00
00[ooooo1Ol0000:ooooo`;o00000_ooool2o`000003ooooool0003o000000;o00000_ooool6o`00
00[ooooo0_l00007ooooo`Co00003?ooool5o`0000kooooo0ol00002ooooo`;o000000?oooooo`00
0?l000000ol00004ooooo`;o00001oooool2o`0000Cooooo0_l00003ooooo`;o00000oooool2o`00
00Kooooo0_l0000Booooo`;o00004_oooolBo`0004Wooooo000Looooo`03o`000?oooooooooo02Wo
oooo0_l0000Aooooo`;o00003_ooool2o`0000Kooooo0_l00006ooooo`;o00002_ooool2o`0000Go
oooo1_l00003ooooo`;o00000oooool7o`00013ooooo0_l00003ooooo`;o000000Coooooo`000?l0
003ooooo0_l000000ooooooo0000o`000003ooooo`;o00000_ooool2o`0000Kooooo0ol00005oooo
o`;o000000?oooooo`000?l000003Oooool2o`0000;ooooo0_l0000Koooooa7o00001Oooool2o`00
04?ooooo000Looooo`03o`000?oooooooooo02Wooooo0_l00009ooooo`;o00001oooool3o`0000co
oooo0_l00006ooooo`;o00006Oooool4o`0000Gooooo0_l00003ooooo`Ko00004?ooool2o`0000Ko
oooo0_l000000ooooooo0000o`000004o`0000?ooooo0_l00002ooooo`;o00001_ooool2o`0000Co
oooo1?l0000@ooooo`;o00000_ooool2o`0000Kooooo0_l00004ooooo`;o00001oooool2o`0000Co
oooo3ol00007ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0<_ooool4o`0000;ooooo
0_l00003ooooo`?o00007Oooool2o`000003ooooool0003o000000Oooooo0_l00004ooooo`Co0000
0oooool2o`0000Wooooo0_l00003ooooo`;o00001?ooool2o`0000Gooooo1?l00004ooooo`go0000
0_ooool2o`0000;ooooo0_l00009ooooo`;o00002_ooool2o`0000Kooooo0_l0000:ooooo`;o0000
1?ooool4o`0000Gooooo0_l00003oooooa3o0000C?ooool001cooooo00?o0000ooooooooool0;?oo
ool2o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`0001[ooooo0_l000001?oooooo0000o`00
0?ooool3o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool2o`0000?ooooo
0_l0000>ooooo`;o00001?ooool2o`0000Oooooo0_l00006ooooo`;o00000oooool6o`0000;ooooo
0_l00002ooooo`;o00005Oooool2o`0000Gooooo1?l0000;ooooo`;o00001?ooool3o`0000Wooooo
4?l00006ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0;?ooool2o`0000Gooooo0_l0
000Iooooo`;o00002_ooool2o`0000?ooooo1_l000001?oooooo0000o`000?ooool6o`0000;ooooo
0_l00009ooooo`;o00007oooool2o`0000?ooooo1Ol00007ooooo`;o00005?ooool3o`0000Gooooo
1?l0000;ooooo`;o00001Oooool2o`0000[ooooo1_l000000ooooooo0000o`000005o`000003oooo
ool0003o000000;ooooo1?l00014ooooo`007?ooool00ol0003oooooooooo`0_ooooo`Ko00006Ooo
ool2o`0000[ooooo0_l00003ooooo`So00000_ooool4o`0000?ooooo0_l00003ooooo`;o00001Ooo
ool2o`0001?ooooo0_l0000;ooooo`;o00000_ooool2o`000003ooooool0003o000001Kooooo0_l0
0005ooooo`?o00000oooool3o`000003ooooool0003o000001Oooooo0_l000001?oooooo0000o`00
0?oooolBo`0000;ooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`0_ooooo`Co00007?oo
ool3o`0000oooooo0_l000000ooooooo0000o`000002o`000004ooooool0003o0000o`0000Cooooo
0_l00003ooooo`;o00004_ooool2o`0000Gooooo0ol0000;ooooo`?o000000Coooooo`000?l0003o
oooo0_l0000<ooooo`;o00002?ooool2o`0000Kooooo1?l000001Ooooooo0000o`000?l0003ooooo
00;o00002Oooool2o`0000cooooo0_l000001?oooooo0000o`000?ooool@o`0004cooooo000Loooo
o`03o`000?oooooooooo02?ooooo0_l0000Hooooo`;o00001_ooool2o`0000Cooooo0_l000000ooo
oooo0000o`000002o`0000Kooooo0_l00007ooooo`Oo00000_ooool2o`0001Gooooo0_l00006oooo
o`;o00001Oooool3o`000004ooooool0003o0000o`0000Sooooo0_l000001?oooooo0000o`000?l0
000>ooooo`;o00002?ooool2o`0000Sooooo0_l0000@ooooo`;o00006?ooool5o`0000Cooooo0_l0
001;ooooo`007?ooool00ol0003oooooooooo`0Sooooo`;o00004_ooool2o`0000Cooooo0_l00006
ooooo`;o00001?ooool2o`000003ooooool0003o000000Sooooo0_l00007ooooo`Co00003Oooool2
o`0000gooooo0_l0000=ooooo`Oo00003?ooool2o`0001?ooooo0_l0000Fooooo`;o00006_ooool2
o`0000Gooooo0_l00007ooooo`;o000000?oooooo`000?l00000B?ooool001cooooo0_l0000hoooo
o`;o00001?ooool2o`0001Gooooo0_l00007ooooo`;o000000?oooooo`000?l000004?ooool2o`00
0003ooooool0003o000000Kooooo0_l00009ooooo`;o00001_ooool4o`0000Gooooo0_l00008oooo
o`;o00000_ooool2o`000003ooooool0003o000000cooooo0_l0000Fooooo`;o00004oooool2o`00
00Gooooo0_l0000Aooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0E?ooool2o`000003
ooooool0003o000000Cooooo1_l0000Booooo`Co00001?ooool4o`0000Oooooo0_l0000<ooooo`Go
00001Oooool2o`000003ooooool0003o000000;ooooo1Ol0000iooooo`;o0000H_ooool001cooooo
00?o0000ooooooooool0AOooool2o`0000;ooooo0_l0000<ooooo`;o00000oooool4o`000004oooo
ool0003o0000o`0000gooooo0ol00003ooooo`;o00000_ooool2o`0000;ooooo0_l0000;ooooo`;o
00002?ooool4o`0000Kooooo0_l00006ooooo`?o00007_ooool2o`0007kooooo000Looooo`03o`00
0?oooooooooo04Gooooo0_l00002ooooo`;o00003Oooool6o`0000Cooooo0_l0000=ooooo`Co0000
1_ooool2o`0000?ooooo0_l00003ooooo`?o00001?ooool2o`0000Wooooo0_l00004ooooo`;o0000
1?ooool<o`000003ooooool0003o000001Oooooo0_l0001nooooo`007?ooool00ol0003ooooooooo
o`0Xooooo`;o00002_ooool2o`0001kooooo0_l00002ooooo`Co00003Oooool2o`0000Sooooo0_l0
000;ooooo`;o00000oooool3o`0000Gooooo0_l00005ooooo`;o00001oooool2o`0000Cooooo3ol0
0002ooooo`;o00001Oooool2o`0000Sooooo0_l0000@ooooo`;o00003Oooool2o`00067ooooo000L
ooooo`03o`000?oooooooooo02Sooooo0_l0000:ooooo`;o00003?ooool2o`0000oooooo0ol00005
ooooo`?o00000_ooool2o`0000Oooooo0_l00005ooooo`?o00000oooool6o`0000cooooo0_l00003
ooooo`;o00001Oooool2o`0001;ooooo0_l00002ooooo`Ko00000_ooool3o`0000Cooooo0_l00008
ooooo`;o00004?ooool2o`0000Oooooo0_l00004ooooo`;o00003Oooool2o`0002Gooooo0_l0000[
ooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00002Oooool2o`0000oooooo1?l00004oooo
o`?o00000_ooool2o`0000Wooooo0_l00003ooooo`?o00000oooool6o`0000Cooooo0_l00006oooo
o`?o00002Oooool2o`0000Sooooo0_l0000<ooooo`;o00000_ooool2o`0000?ooooo0_l00005oooo
o`?o00000oooool2o`0001Sooooo0_l00002ooooo`Co00004Oooool2o`0001gooooo0_l00006oooo
o`;o0000:oooool001cooooo00?o0000ooooooooool0=oooool2o`0001Gooooo0_l00004ooooo`?o
00002Oooool2o`0000Cooooo0_l00002ooooo`?o00001_ooool2o`0000;ooooo0ol00002ooooo`?o
000000?oooooo`000?l000000_l00003ooooo`Co00002Oooool3o`0000;ooooo0_l000000ooooooo
0000o`000002o`0000Kooooo0_l0000Dooooo`?o00000oooool2o`0000Cooooo0_l0000Booooo`;o
00000oooool3o`00033ooooo0_l0000cooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o0000
4oooool2o`0000Sooooo1?l00002ooooo`;o00001oooool2o`000004ooooool0003o0000o`0000?o
oooo0_l00002ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o000000?oooooo`000?l0
00000ol000001?oooooo0000o`000?l00003ooooo`;o000000?oooooo`000?l000000_l0000<oooo
o`;o00000_ooool2o`000003ooooool0003o000000?ooooo0_l00003ooooo`?o00003oooool2o`00
00?ooooo0_l00003ooooo`;o00001?ooool3o`0002_ooooo0_l0000@ooooo`;o00002_ooool2o`00
03?ooooo000Looooo`03o`000?oooooooooo02Wooooo0_l00004ooooo`;o00001Oooool2o`0000[o
oooo1?l0000:ooooo`Ko00001oooool3o`000003ooooool0003o000000Cooooo0_l00004ooooo`Ko
000000?oooooo`000?l000000_l000001?oooooo0000o`000?ooool8o`000004ooooool0003o0000
o`0001Wooooo0_l00003ooooo`?o00003oooool7o`0000;ooooo0ol00005ooooo`;o00003_ooool2
o`0001Wooooo1_l00004ooooo`;o00001Oooool2o`000003ooooool0003o000000[ooooo0_l0000c
ooooo`007?ooool00ol0003oooooooooo`0Yooooo`;o000000Coooooo`000?l0003ooooo0_l00005
ooooo`;o00000oooool4o`0000?ooooo0_l0000>ooooo`?o00002Oooool4o`0000;ooooo0_l00000
0ooooooo0000o`000002o`000004ooooool0003o0000o`0000;ooooo1ol000000ooooooo0000o`00
0009o`0000Cooooo1?l00004ooooo`?o00005?ooool2o`0000;ooooo0_l0000=ooooo`Go00000_oo
ool2o`00017ooooo0_l000000ooooooo0000o`000004o`0001;ooooo0_l00003ooooo`;o00000_oo
ool2o`000004ooooool0003o0000ooooo`;o00001Oooool2o`0004;ooooo000Looooo`03o`000?oo
oooooooo02cooooo0_l000000ooooooo0000o`000008ooooo`Ko00000oooool2o`0000cooooo0_l0
00000ooooooo0000o`00000;ooooo`;o000000Goooooo`000?l0003o0000ooooo`04o`000004oooo
ool0003o0000ooooo`;o000000?oooooo`000?l000004?l00004ooooo`Go00000oooool3o`0000?o
oooo0_l0000=ooooo`;o00001?ooool4o`0002Gooooo0_l000000ooooooo0000o`000002ooooo`;o
00002?ooool2o`0000Sooooo0_l00004ooooo`;o00001?ooool4o`0000_ooooo0_l0000mooooo`00
7?ooool00ol0003oooooooooo`0iooooo`;o00001oooool2o`0000cooooo0_l0000Aooooo`;o0000
0_ooool3o`0000?ooooo1ol00002ooooo`Wo000000?oooooo`000?l000001?l00004ooooo`?o0000
1_ooool2o`000003ooooool0003o000000cooooo0ol00006ooooo`;o00004oooool2o`0000Cooooo
1Ol0000Hooooo`;o00002_ooool2o`0000;ooooo0_l00006ooooo`?o00001?ooool2o`0000Cooooo
0_l0000mooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00000oooool2o`0000cooooo0_l0
0002ooooo`;o00003_ooool2o`0000Wooooo1?l00003ooooo`Oo000000?oooooo`000?l000003Ol0
0003ooooo`Co00001?ooool3o`0000Cooooo1?l000000ooooooo0000o`000009ooooo`;o000000?o
ooooo`000?l000007?ooool2o`0000?ooooo1_l0000?ooooo`;o00002oooool2o`0000;ooooo0_l0
0002ooooo`;o00002?ooool2o`000003ooooool0003o000000Cooooo0_l00013ooooo`007?ooool0
0ol0003oooooooooo`0_ooooo`;o00000_ooool3o`0000[ooooo0_l00003ooooo`?o00001oooool2
o`0000Gooooo0_l00009ooooo`?o00000_ooool7o`0000;ooooo4?l0000<ooooo`;o000000Cooooo
o`000?l0003ooooo0_l0000>ooooo`;o00005Oooool2o`0000;ooooo0_l00009ooooo`Go00004?oo
ool2o`0000_ooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo0_l00004ooooo`;o0000C?oo
ool001cooooo00?o0000ooooooooool0;_ooool2o`0000?ooooo0_l0000;ooooo`;o00000oooool2
o`0000Sooooo0_l0000Eooooo`Co00001OoooolAo`0000?ooooo0_l00006ooooo`;o000000Cooooo
o`000?l0003ooooo1_l00009ooooo`;o00001_ooool2o`0000kooooo1_l000000ooooooo0000o`00
0003ooooo`co00006_ooool2o`0000Gooooo0_l000001?oooooo0000o`000?l0001Booooo`007?oo
ool2o`0002_ooooo0_l00002ooooo`;o0000=_ooool4o`0000?ooooo6_l00002ooooo`;o00001_oo
ool6o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0000Kooooo0_l00009ooooo`;o0000
1Oooool4o`000004ooooool0003o0000o`0000;ooooo3ol00009ooooo`;o00001Oooool2o`0000Go
oooo0_l00002ooooo`;o00001?ooool3o`0001kooooo0_l0000booooo`007?ooool00ol0003ooooo
ooooo`0Zooooo`;o00008_ooool2o`0000Wooooo0ol0000:ooooo`Co00000oooool4o`000003oooo
ool0003o000001[o00000oooool3o`0000Kooooo0_l000000ooooooo0000o`000006ooooo`;o0000
3?ooool2o`0000[ooooo1Ol000000ooooooo0000o`000006o`000003ooooool0003o000000?o0000
0_ooool2o`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l000002Oooool2o`000003oooo
ool0003o000000;ooooo0_l0000Cooooo`Co00001oooool2o`0003;ooooo000Looooo`03o`000?oo
oooooooo02[ooooo0_l000000ooooooo0000o`000008ooooo`;o00000oooool2o`0000Oooooo0_l0
0003ooooo`;o000000Coooooo`000?l0003o00002Oooool3o`0000Cooooo0_l00009ooooo`?o0000
00?oooooo`000?l000005?l000000ooooooo0000o`000008o`000003ooooool0003o000000oooooo
0_l000000ooooooo0000o`000002o`0000Kooooo0_l00009ooooo`;o00000oooool>o`0000;ooooo
1Ol000000ooooooo0000o`000009ooooo`;o00003oooool2o`0001Oooooo1?l0000kooooo`007?oo
ool00ol0003oooooooooo`0Zooooo`;o000000?oooooo`000?l000002?ooool2o`0000?ooooo1?l0
0005ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o00001?oo
ool2o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000003ol000000ooooooo0000o`00
0008o`0000?ooooo1Ol00002ooooo`;o00003Oooool2o`0000?ooooo0_l00003ooooo`?o00001Ooo
ool2o`0000Wooooo0_l00002ooooo`Go000000?oooooo`000?l000003_l000001?oooooo0000o`00
0?l00014ooooo`;o0000:oooool001cooooo00?o0000ooooooooool0>Oooool4o`000003ooooool0
003o0000017ooooo0_l00002ooooo`;o00000_ooool4o`0000Sooooo0_l000000ooooooo0000o`00
000Po`0000Kooooo0_l0000;ooooo`;o00002Oooool5o`0000kooooo0_l000000ooooooo0000o`00
000Do`000004ooooool0003o0000o`0001_ooooo0_l0000Cooooo`;o00002oooool2o`0000Gooooo
0_l0000[ooooo`007?ooool00ol0003oooooooooo`0iooooo`Co00007?ooool2o`000003ooooool0
003o000000Kooooo0_l000001?oooooo0000o`000?l00002ooooo`co000000?oooooo`000?l00000
3_l000000ooooooo0000o`000004ooooo`;o00001_ooool2o`0000oooooo1?l000000ooooooo0000
o`000002o`0000Wooooo0ol000000ooooooo0000o`00000Eo`000003ooooool0003o000000;o0000
00?oooooo`000?l000000oooool2o`000003ooooool0003o000000gooooo0_l0000Cooooo`;o0000
00?oooooo`000?l000002?ooool2o`0003;ooooo000Looooo`03o`000?oooooooooo037ooooo0_l0
000Tooooo`;o00000oooool4o`0000;ooooo1?l000000ooooooo0000o`00000Po`000003ooooool0
003o000000;o00000_ooool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`00
0006ooooo`;o00001oooool6o`0000Wooooo0ol000000ooooooo0000o`00000Jo`000004ooooool0
003o0000ooooo`Co000000?oooooo`000?l000008?ooool2o`0000?ooooo0_l0000looooo`007?oo
ool00ol0003oooooooooo`0Zooooo`;o00001Oooool4o`0001gooooo0_l00003ooooo`;o000000Co
ooooo`000?l0003ooooo1?l000000ooooooo0000o`000004ooooob7o000000?oooooo`000?l00000
0_l00002ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Kooooo0_l00007ooooo`;o0000
1_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000Ho`000003ooooool0003o000000;o0000
1Oooool2o`0000Sooooo0_l0000;ooooo`;o00003_ooool2o`0000;ooooo0_l000000ooooooo0000
o`00000jooooo`007?ooool00ol0003oooooooooo`0Zooooo`Co00001Oooool2o`0000?ooooo0_l0
000Gooooo`?o000000?oooooo`000?l000000oooool2o`0000?ooooo0_l000000ooooooo0000o`00
0002ooooobKo000000Coooooo`000?l0003ooooo0_l00009ooooo`;o00001oooool3o`0000gooooo
0_l00002ooooo`;o00000_oooolMo`0000[ooooo0_l00004ooooo`;o00002oooool2o`0000Gooooo
0_l0000;ooooo`;o000000?oooooo`000?l00000>_ooool001cooooo00?o0000ooooooooool0;?oo
ool4o`0000Sooooo0_l00005ooooo`?o00003oooool2o`0000;ooooo0_l00003ooooo`?o00001Ooo
ool]o`0000cooooo0_l00004ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`00017ooooo
0ol000000ooooooo0000o`000004o`000003ooooool0003o0000013o00002_ooool2o`0001Sooooo
0_l0000:ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0;_ooool2o`0000oooooo0ol0
000=ooooo`;o00000oooool2o`0000Gooooo0_l00005ooooobGo000000Coooooo`000?l0003ooooo
0_l00003ooooo`;o00003oooool2o`0000?ooooo1Ol00004ooooo`;o00002?ooool2o`0000;ooooo
0_l000000ooooooo0000o`00000Go`0001Kooooo0_l0000=ooooo`;o00002Oooool4o`0003cooooo
000Looooo`03o`000?oooooooooo02gooooo0_l000000ooooooo0000o`000002ooooo`;o00000ooo
ool2o`0000Sooooo0_l0000:ooooo`;o00000oooool2o`0000Gooooo0_l00005ooooo`;o000000?o
ooooo`000?l00000:ol00006ooooo`;o00003?ooool4o`0000Gooooo0_l00007ooooo`?o00000_oo
oolKo`0000cooooo0_l00009ooooo`;o000000?oooooo`000?l000001oooool2o`000003ooooool0
003o000000Wooooo1?l0000looooo`007?ooool00ol0003oooooooooo`0]ooooo`;o000000?ooooo
o`000?l000000_ooool2o`0000?ooooo0_l00008ooooo`;o00006_ooool]o`000003ooooool0003o
000000;o00001oooool2o`0001Kooooo0_l00006ooooo`;o00000_oooolKo`0000cooooo0ol0000;
ooooo`?o00001oooool2o`0004cooooo000Looooo`03o`000?oooooooooo03Cooooo0_l000000ooo
oooo0000o`00000<ooooo`;o00001oooool2o`0000kooooo2?l000000ooooooo0000o`00000So`00
01oooooo0_l00003ooooo`;o00002_oooolHo`000003ooooool0003o000000Gooooo0_l00005oooo
o`;o00003?ooool2o`0000Sooooo0_l00005ooooo`;o0000AOooool001cooooo00?o0000oooooooo
ool0=_ooool3o`0000cooooo0_l00007ooooo`Go00002oooool8o`000003ooooool0003o000001Ko
000000?oooooo`000?l000001?l000000ooooooo0000o`000005o`0001gooooo0_l0000AoooooaSo
000000?oooooo`000?l000000oooool2o`0000Wooooo0_l00003ooooo`;o00005?ooool2o`0000Oo
oooo0_l0000;ooooo`;o0000;oooool001cooooo00?o0000ooooooooool0=_ooool2o`0001?ooooo
0_l00002ooooo`Co00002oooool2o`000003ooooool0003o000000;o00000_oooolMo`0000;ooooo
2?l00007ooooo`;o00006Oooool2o`0000Oooooo0_l00003oooooaSo000000?oooooo`000?l00000
3_ooool2o`0000?ooooo0_l0000=ooooo`;o00003_ooool2o`0000Sooooo0_l000000ooooooo0000
o`00000_ooooo`007?ooool2o`0004cooooo0_l0000>ooooo`Go000000?oooooo`000?l000000_l0
00000ooooooo0000o`00000Qo`0000;ooooo0_l00003ooooo`;o00000oooool2o`0001Wooooo0_l0
0007ooooo`?o00000ooooolJo`0001?ooooo0_l0000<ooooo`?o00006?ooool2o`0003;ooooo000L
ooooo`03o`000?oooooooooo02kooooo0_l0000@ooooo`Co00001_ooool2o`0000?ooooo0_l00003
ooooo`;o00001Oooool4o`0000;ooooo3ol000000ooooooo0000o`00000Do`0000Wooooo0_l0000C
ooooo`;o00004oooool2o`0000?ooooo4_l000000ooooooo0000o`000004o`0001Oooooo0ol00008
ooooo`;o000000Coooooo`000?l0003o00002_ooool4o`0003_ooooo000Looooo`03o`000?oooooo
oooo02kooooo0_l0000@ooooo`Co00001?ooool4o`0000?ooooo0_l000000ooooooo0000o`000002
o`0000Gooooo1?l00005ooooo`;o000000?oooooo`000?l000007_l0000<ooooo`;o00003oooool3
o`0000Oooooo0_l0000:ooooo`;o00000_oooolCo`0000;ooooo0_l000000ooooooo0000o`000008
ooooo`;o00003Oooool3o`0000Kooooo2?l0000:ooooo`Co0000>oooool001cooooo00?o0000oooo
ooooool0@?ooool2o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o00001?ooool2o`00
00?ooooo1ol00002ooooo`;o00000_ooool:o`000003ooooool0003o000001Ko000000?oooooo`00
0?l000000ol00006ooooo`;o00003oooool3o`0000Gooooo1?l00007ooooo`;o000000?oooooo`00
0?l000000_ooool2o`0000;ooooo4ol000001?oooooo0000o`000?l00007ooooo`;o00002?ooool2
o`000003ooooool0003o000000;o00001oooool9o`0000Kooooo0_l0000:ooooo`;o000000Cooooo
o`000?l0003o0000<?ooool001cooooo00?o0000ooooooooool0@oooool2o`0000Oooooo0_l00009
ooooo`Go000000Coooooo`000?l0003ooooo;Ol0000Hooooo`;o000000Goooooo`000?l0003o0000
ooooo`03o`0000Sooooo0_l000000ooooooo0000o`000006oooooa7o00000oooool3o`0000Sooooo
0ol00003ooooo`;o000000?oooooo`000?l000000ol0000>ooooo`Go00001Oooool2o`0000[ooooo
0_l000001?oooooo0000o`000?l0000`ooooo`007?ooool00ol0003oooooooooo`19ooooo`;o0000
2_ooool2o`0000?ooooo0_l000000ooooooo0000o`000005o`000003ooooool0003o0000027o0000
0_ooool4o`0000Wooooo0_l0000?ooooo`?o00000_ooool2o`0000cooooo0_l00005ooooo`ko0000
0_ooool2o`0000gooooo0ol00003ooooo`So00003_ooool5o`0004Oooooo000Looooo`03o`000?oo
oooooooo033ooooo0_l0000Gooooo`;o00002_ooool2o`000003ooooool0003o000000;o00000_oo
oolDo`000004ooooool0003o0000oooooa7o00000oooool4o`0000?ooooo0_l00004ooooo`;o0000
3_ooool4o`0000Sooooo0_l00006ooooo`;o000000?oooooo`000?l000000oooool=o`0000;ooooo
0_l00007ooooo`;o00001oooool3o`000003ooooool0003o000001Gooooo0_l00018ooooo`007?oo
ool00ol0003oooooooooo`0`ooooo`?o00001?ooool2o`000003ooooool0003o000000cooooo0_l0
000>ooooo`;o00001?oooolOo`000003ooooool0003o000000Ko000000?oooooo`000?l000000ooo
ool2o`0000?ooooo0_l0000Aooooo`;o000000?oooooo`000?l000000_l00006ooooo`Co00002Ooo
ool2o`0000Kooooo1?l0000Aooooo`;o00001oooool3o`0000;ooooo0_l0000Aooooo`;o000000?o
ooooo`000?l00000B?ooool001cooooo00?o0000ooooooooool0<Oooool2o`0000Cooooo0_l00000
1?oooooo0000o`000?ooool2o`000003ooooool0003o000000Kooooo0_l0000Booooo`;o00000_oo
ool4o`000003ooooool0003o000001Ko000000Coooooo`000?l0003o00000_ooool6o`0000;ooooo
0ol00003ooooo`;o00004Oooool2o`0000_ooooo1Ol0000;ooooo`Co00000oooool2o`00017ooooo
0_l0000<ooooo`;o00002?ooool2o`0000Oooooo0_l000000ooooooo0000o`000018ooooo`007?oo
ool00ol0003oooooooooo`0aooooo`;o00002_ooool2o`000003ooooool0003o000000Kooooo0_l0
000=ooooo`?o00000_ooool2o`0000?ooooo8Ol000000ooooooo0000o`000003o`0000?ooooo0_l0
0004ooooo`;o00005Oooool3o`0000Kooooo0_l000000ooooooo0000o`00000;ooooo`Ko000000?o
ooooo`000?l000000_l0000Gooooo`;o00000_ooool4o`0000Sooooo0_l00003ooooo`;o0000Cooo
ool001cooooo00?o0000ooooooooool0<Oooool3o`0001Sooooo0_l00002ooooo`;o00000_ooool2
o`000004ooooool0003o0000o`0000Oooooo1?l000000ooooooo0000o`000002o`000003ooooool0
003o000000;o000000?oooooo`000?l000000_l000000ooooooo0000o`00000@o`0000Wooooo1?l0
000Dooooo`?o00002?ooool2o`00013ooooo0_l000000ooooooo0000o`000002o`0001Oooooo0_l0
0002ooooo`;o00002Oooool2o`000004ooooool0003o0000ooooo`;o00002_ooool3o`0004;ooooo
000Looooo`03o`000?oooooooooo03;ooooo0_l0000Cooooo`;o00000oooool2o`0000;ooooo0_l0
0002ooooo`;o00003?ooool2o`0000;ooooo5?l00002ooooo`go00001oooool4o`0000;ooooo0_l0
000Dooooo`;o00001Oooool4o`0000;ooooo0_l00007ooooo`;o0000;_ooool5o`0000cooooo1Ol0
00000ooooooo0000o`000006ooooo`;o0000=_ooool001cooooo00?o0000ooooooooool0AOooool4
o`0000Cooooo0_l00009ooooo`;o00002?ooool2o`000004ooooool0003o0000ooooo`Co00000_oo
ool=o`000003ooooool0003o000000go000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l0
000@ooooo`;o00000_ooool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o00001ooo
ool2o`0002;ooooo0_l00005ooooo`;o00001Oooool2o`0000Cooooo0ol000000ooooooo0000o`00
0003ooooo`;o000000Coooooo`000?l0003ooooo0_l00006ooooo`;o0000=_ooool001cooooo00?o
0000ooooooooool0>oooool2o`0000Sooooo0ol00005ooooo`;o00000_ooool2o`0000?ooooo1?l0
00000ooooooo0000o`000002ooooo`;o00000_ooool4o`0000Kooooo4ol000000ooooooo0000o`00
0004o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000003Ooo
ool2o`0000;ooooo0_l00005ooooo`;o00003_ooool2o`0000;ooooo0_l00008ooooo`;o00000ooo
ool2o`0000_ooooo0_l00005ooooo`;o00001Oooool2o`0000Cooooo0_l00005ooooo`?o000000?o
ooooo`000?l00000BOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo
00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo03_ooooo0_l000000ooooooo
0000o`00000Aooooo`;o00000oooool2o`0000?ooooo0_l000000ooooooo0000o`000007o`0000Co
oooo1?l000000ooooooo0000o`00000:o`000003ooooool0003o000000Go00001?ooool2o`0000So
oooo1Ol00006ooooo`;o00001Oooool2o`0000;ooooo0_l00007ooooo`;o00000oooool2o`0000?o
oooo0_l00002ooooo`Ko00002?ooool4o`000003ooooool0003o000000[ooooo0ol0000Booooo`;o
00003oooool2o`0004?ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44oooo
o`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0nooooo`;o00002oooool4
o`0000Sooooo0_l00003ooooo`Co000000Coooooo`000?l0003ooooo0_l00003ooooo`Co00000_oo
ool;o`000003ooooool0003o000000Ko00000oooool4o`0000[ooooo0_l00007ooooo`;o00004_oo
ool4o`000003ooooool0003o000000;o000000?oooooo`000?l000001?ooool2o`0000Wooooo0_l0
00000ooooooo0000o`000002ooooo`;o00002Oooool3o`0000[ooooo0_l0000Gooooo`;o0000@ooo
ool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool0;_ooool2o`0000_ooooo0_l00003ooooo`;o00002Ooo
ool4o`0000Sooooo0_l000000ooooooo0000o`000004o`0000Cooooo0_l00003ooooo`?o00000ooo
ool;o`000003ooooool0003o000000?ooooo0_l00004ooooo`;o00003oooool2o`0001[ooooo0_l0
0003ooooo`;o00004_ooool2o`0000Gooooo0_l0000Fooooo`;o00000_ooool4o`0000Oooooo0_l0
0008ooooo`;o0000@oooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool0
1Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0000^ooooo`;o00002oooool2o`0000?ooooo0_l0
000Eooooo`Go00001?ooool3o`0000Kooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo
1?l00007ooooo`Co00005?ooool2o`0000kooooo0_l00007ooooo`;o00001_ooool2o`0001kooooo
0_l00005ooooo`;o00002_ooool2o`0000;ooooo1?l000000ooooooo0000o`000004ooooo`;o0000
COooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oEEEEo`00
0?l@413oc<c<00Kooooo00?o0000ooooooooool0A_ooool3o`0000kooooo1?l00005ooooo`?o0000
1_ooool2o`0000?ooooo1?l00002ooooo`;o000000?oooooo`000?l000000oooool2o`000003oooo
ool0003o000000;o00009?ooool2o`000003ooooool0003o000000;o00000_ooool2o`0000Kooooo
0_l00003ooooo`;o00006Oooool2o`0000;ooooo0_l000000ooooooo0000o`000009ooooo`?o0000
0_ooool2o`0000?ooooo0_l00004ooooo`;o00001_ooool2o`0004Gooooo00000ooooooo410@oooo
o`02ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003ooooooooo
o`16ooooo`?o00003oooool2o`0000Wooooo0_l00004ooooo`Wo000000?oooooo`000?l000001?l0
0003ooooo`;o00000oooool3o`0000cooooo0_l000000ooooooo0000o`00000<ooooo`;o00001Ooo
ool8o`0000Sooooo0_l00003ooooo`;o00001oooool2o`00013ooooo0_l00002ooooo`;o00003?oo
ool3o`000003ooooool0003o000000?o00001oooool2o`0000Gooooo0ol00002ooooo`;o0000@Ooo
ool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`00
0?oooooooooo03cooooo0_l0000<ooooo`;o00003?ooool2o`0000Wooooo0ol00002ooooo`;o0000
00?oooooo`000?l000001?l00002ooooo`Ko00002?ooool3o`0000cooooo0_l000000ooooooo0000
o`00000<ooooo`;o00001Oooool2o`0000Cooooo0_l00008ooooo`Co00002_ooool3o`0000Wooooo
1?l0000<ooooo`;o00002_ooool5o`0000kooooo0ol000001?oooooo0000o`000?l00011ooooo`00
00Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000
ooooooooool0??ooool2o`000003ooooool0003o000000?ooooo0_l00004ooooo`;o00002?ooool2
o`0000Gooooo0_l00004ooooo`;o000000?oooooo`000?l000000_ooool2o`000005ooooool0003o
0000o`000?ooool00_l000000ooooooo0000o`000005o`0000?ooooo0ol000000ooooooo0000o`00
0002o`0003Cooooo1?l00002ooooo`;o00001oooool2o`0000Wooooo1?l00003ooooo`;o00001_oo
ool3o`0000_ooooo0_l0000Dooooo`;o00001?ooool2o`0003cooooo000Looooo`03o`000?oooooo
oooo03oooooo0ol00002ooooo`;o00003_ooool2o`0000Gooooo0_l00004ooooo`;o00001Oooool5
o`000003ooooool0003o000000Co00000oooool8o`000003ooooool0003o000000Gooooo0_l0000K
ooooo`;o00006?ooool2o`0000Kooooo0ol0000@ooooo`;o00000_ooool2o`0000;ooooo0_l00007
ooooo`;o00007oooool2o`0003cooooo000Looooo`03o`000?oooooooooo043ooooo0_l0000Woooo
o`;o00000oooool5o`0000Gooooo1_l000000ooooooo0000o`000006ooooo`Co00004Oooool2o`00
00Gooooo1Ol00006ooooo`?o00003_ooool3o`0000Cooooo0_l00009ooooo`;o00001?ooool2o`00
00Cooooo0_l0000;ooooo`;o00004oooool2o`0004Sooooo000Looooo`03o`000?oooooooooo06go
oooo0_l00002ooooo`;o00002Oooool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o
00004?ooool3o`0000Gooooo1ol000001?oooooo0000o`000?ooool3o`000003ooooool0003o0000
00_ooooo0ol0000?ooooo`;o00001?ooool4o`0000Cooooo0_l00006ooooo`;o00001Oooool2o`00
00oooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00000oooool2o`0000So
oooo0_l0000?ooooo`;o00000_ooool4o`0000Oooooo0_l00007ooooo`;o00004?ooool3o`000004
ooooool0003o0000o`0000Oooooo0_l000001?oooooo0000o`000?ooool3o`000004ooooool0003o
0000ooooo`;o00002oooool3o`000003ooooool0003o000001?ooooo0ol00002ooooo`Co00001_oo
ool5o`000004ooooool0003o0000o`0005Wooooo000Looooo`03o`000?oooooooooo04Wooooo0_l0
0002ooooo`;o00000oooool2o`0000Kooooo1_l0000=ooooo`;o00000_ooool4o`0000;ooooo0_l0
000=ooooo`;o00001?ooool4o`0000Oooooo0ol0000Aooooo`?o000000?oooooo`000?l000002Ooo
ool2o`0000;ooooo0ol00002ooooo`;o00006?ooool3o`0000?ooooo1?l000000ooooooo0000o`00
0005o`0000?ooooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`11ooooo`;o00001_ooool2
o`0000Sooooo0_l00005ooooo`;o00000_ooool2o`0000Cooooo0_l0000Aooooo`Co00001_ooool2
o`0000?ooooo0_l00004ooooo`Co00002Oooool2o`0000?ooooo0_l00003ooooo`;o000000?ooooo
o`000?l000001_l0000<ooooo`;o00000_ooool2o`0000Kooooo0_l00007ooooo`;o00000_ooool2
o`0000Oooooo0_l00003ooooo`So00000oooool2o`0000Cooooo1?l0000<ooooo`;o0000AOooool0
01cooooo00?o0000ooooooooool0@Oooool2o`0000Kooooo0_l00008ooooo`;o00001Oooool2o`00
00;ooooo0_l00004ooooo`;o00002?ooool2o`0000?ooooo0_l00004ooooo`;o000000?oooooo`00
0?l000000oooool2o`0000Sooooo0ol0000;ooooo`;o00000oooool2o`0000?ooooo0_l000000ooo
oooo0000o`000007o`0001Oooooo0_l00007ooooo`;o00000_ooool2o`0000Oooooo0_l000000ooo
oooo0000o`000004o`0000;ooooo0_l0000;ooooo`;o00001_ooool2o`0000Cooooo0_l00015oooo
o`007?ooool00ol0003oooooooooo`19ooooo`;o00001Oooool2o`0000Sooooo0_l0000Booooo`;o
00000oooool2o`000003ooooool0003o000000;o00000_ooool2o`0000Wooooo0_l00002ooooo`?o
00001oooool2o`0000?ooooo0_l00007ooooo`go00001oooool2o`00027ooooo0_l00003ooooo`;o
00006Oooool4o`0000Cooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`19ooooo`;o0000
1Oooool2o`0000Kooooo0_l00006ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`Co0000
2oooool4o`0000cooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo3ol00004ooooo`Co0000
5oooool3o`0000?ooooo1_l0000=ooooo`;o00003oooool3o`0000Gooooo0_l00015ooooo`007?oo
ool00ol0003oooooooooo`0dooooo`Co00002?ooool2o`0000Cooooo0_l00006ooooo`;o00001ooo
ool3o`0000Kooooo1?l00003ooooo`;o00001_ooool2o`0000cooooo0_l00002ooooo`;o00000_oo
ool2o`0000_ooooo0_l00005ooooo`?o00000_ooool2o`0000;ooooo2?l000000ooooooo0000o`00
0004o`000003ooooool0003o000000?o00003Oooool2o`0000[ooooo2_l0000?ooooo`;o00001?oo
ool2o`0000[ooooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`0dooooo`Co00002?ooool2
o`0000Cooooo0_l00003ooooo`;o000000?oooooo`000?l000001oooool2o`0000Oooooo1?l00006
ooooo`?o00004?ooool2o`0000;ooooo0_l00007ooooo`;o00001_ooool2o`0000Gooooo0_l00008
ooooo`Oo000000?oooooo`000?l000003?l0000;ooooo`;o00003Oooool3o`000003ooooool0003o
000001Kooooo0_l0000:ooooo`;o0000C?ooool001cooooo0_l0001<ooooo`;o00003_ooool2o`00
00Cooooo0_l00002ooooo`Co000000?oooooo`000?l000000ol0000Dooooo`;o000000?oooooo`00
0?l000000_ooool2o`0000gooooo1?l00002oooooaCo000000Coooooo`000?l0003ooooo0_l0000L
ooooo`;o00003?ooool3o`0000;ooooo0_l00005ooooo`;o00005?ooool2o`0004;ooooo000Loooo
o`03o`000?oooooooooo04Oooooo0_l00007ooooo`?o00002?ooool2o`0000Sooooo1?l00004oooo
o`;o00001oooool2o`0000?ooooo0ol00005ooooo`;o000000?oooooo`000?l000004Oooool4o`00
00;ooooo5?l0000@ooooo`Co00002?ooool3o`0000?ooooo1?l00007ooooo`Ko00000_ooool2o`00
00;ooooo0_l000000ooooooo0000o`000002o`0001;ooooo0_l00012ooooo`007?ooool00ol0003o
ooooooooo`17ooooo`;o00001oooool3o`0000[ooooo0_l00007ooooo`;o000000?oooooo`000?l0
00000_l00009ooooo`Co000000Coooooo`000?l0003o00001_ooool2o`0000kooooo1?l00003oooo
o`;o00000_oooolDo`000004ooooool0003o0000o`0000cooooo1?l00008ooooo`?o00001Oooool2
o`0000Kooooo1Ol00008ooooo`?o00000_ooool2o`0000Kooooo0_l0001>ooooo`007?ooool00ol0
003oooooooooo`1@ooooo`;o00001?ooool2o`0000Gooooo0_l00007ooooo`Oo00002oooool2o`00
00Wooooo0ol00002ooooo`;o00001?ooool2o`0000Cooooo1?l00003ooooo`;o000000?oooooo`00
0?l000005ol000001?oooooo0000o`000?l00002ooooo`Ko00006_ooool6o`0000[ooooo0ol00004
ooooo`;o00000oooool2o`0004kooooo000Looooo`03o`000?oooooooooo057ooooo0_l00003oooo
o`;o00003_ooool3o`0000Gooooo0_l0000Aooooo`Co00000oooool2o`0000Cooooo0_l00002oooo
o`;o00000_ooool4o`000004ooooool0003o0000oooooaSo00000_ooool4o`000003ooooool0003o
000000Co00003_ooool3o`0000?ooooo0_l00004ooooo`Go00002oooool3o`0000Cooooo0_l0001C
ooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00003Oooool2o`0000gooooo0_l00002oooo
o`Co00000oooool2o`000003ooooool0003o000000gooooo0_l00002ooooo`;o00000oooool2o`00
00[ooooo0_l00002ooooo`Co00001?oooolJo`0000;ooooo0_l000000ooooooo0000o`00000>oooo
o`;o00000_ooool4o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`?o00004Oooool2o`00
0003ooooool0003o000000Gooooo0_l00002ooooo`;o0000Aoooool001cooooo00?o0000oooooooo
ool0=oooool2o`0000Wooooo0_l0000Looooo`;o00000_ooool2o`0000Gooooo0ol00002ooooo`;o
00001?ooool2o`0000Gooooo0_l00007ooooo`;o00003?ooool2o`0000Oooooo6?l000001Ooooooo
0000o`000?l0003ooooo00;o00004Oooool2o`0000Cooooo0_l00005ooooo`?o00000_ooool2o`00
00[ooooo1?l00003ooooo`;o000000?oooooo`000?l000001?ooool3o`0000;ooooo0_l00017oooo
o`007?ooool00ol0003oooooooooo`0gooooo`;o00005_ooool3o`000003ooooool0003o000001Ko
oooo0ol00002ooooo`So00007?ooool2o`0000Oooooo7_l0000=ooooo`;o00004?ooool3o`0000Go
oooo0_l000000ooooooo0000o`000004ooooo`Go00002oooool2o`0004cooooo000Looooo`03o`00
0?oooooooooo04kooooo1?l000000ooooooo0000o`00000Mooooo`Co00001_ooool2o`0000;ooooo
0_l00006ooooo`;o00004ooooolJo`0000;ooooo0ol0000<ooooo`;o00000_ooool4o`0000[ooooo
0_l00006ooooo`;o000000?oooooo`000?l000001oooool2o`0000Cooooo0_l00006ooooo`;o0000
Boooool001cooooo00?o0000ooooooooool0A?ooool2o`0000Kooooo1?l0000Hooooo`;o000000?o
ooooo`000?l000000_ooool3o`0000[ooooo0_l00002ooooo`;o00001_ooool2o`0000Cooooo0_l0
0006ooooo`;o00001OoooolDo`000003ooooool0003o000000[o00000oooool2o`000003ooooool0
003o000000;ooooo2?l0000Fooooo`;o00001_ooool2o`0000Cooooo0ol00005ooooo`;o00000_oo
ool2o`0004Oooooo000Looooo`03o`000?oooooooooo04Cooooo0_l00006ooooo`Co00006?ooool2
o`000003ooooool0003o000000Go000000?oooooo`000?l000001?ooool2o`0001;ooooo0ol00006
ooooo`;o00001?ooool2o`000003ooooool0003o000001[o000000?oooooo`000?l000000oooool2
o`000003ooooool0003o000000;ooooo1?l0000Jooooo`;o00001_ooool2o`000003ooooool0003o
000000;ooooo0_l00005ooooo`;o00000_ooool2o`0004Oooooo000Looooo`03o`000?oooooooooo
04Cooooo0_l00008ooooo`Co00004Oooool2o`0000Sooooo0_l000000ooooooo0000o`000003o`00
0004ooooool0003o0000ooooo`;o00004_ooool2o`0000Oooooo0_l00004ooooo`;o00000_oooolK
o`000003ooooool0003o000000_ooooo1?l00005ooooo`;o00000oooool2o`0001Sooooo0_l00009
ooooo`;o00002Oooool2o`00043ooooo000Looooo`03o`000?oooooooooo053ooooo0_l0000Aoooo
o`;o00003Oooool2o`0000;ooooo0_l00002ooooo`;o00004Oooool2o`0000Oooooo0_l00007oooo
oaKo000000?oooooo`000?l000000_l000001?oooooo0000o`000?l00008ooooo`;o000000?ooooo
o`000?l000000_l00005ooooo`Co000000Coooooo`000?l0003ooooo0ol00002ooooo`?o00000_oo
ool2o`00027ooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`1>ooooo`?o00008Oooool2
o`0000Kooooo0ol0000@ooooo`;o00001_ooool3o`0000Kooooo6_l00003ooooo`;o00000_ooool2
o`0000Gooooo1?l00002ooooo`;o00001_ooool2o`0000Cooooo0ol00002ooooo`?o00000_ooool2
o`000003ooooool0003o000000cooooo0_l00002ooooo`;o0000C_ooool001cooooo00?o0000oooo
ooooool0Boooool2o`000003ooooool0003o000000;o00002_ooool4o`0000oooooo0_l000000ooo
oooo0000o`000002ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`;o00001?ooool3
o`0000Oooooo0_l00002ooooo`;o00000ooooolPo`0000Gooooo0_l00007ooooo`;o00000_ooool2
o`00013ooooo1?l00005ooooo`;o000000Coooooo`000?l0003o00001Oooool2o`000003ooooool0
003o000000;ooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`1;ooooo`?o00000_ooool2
o`0000?ooooo0_l00005ooooo`Co00003oooool2o`0000?ooooo1?l00006ooooo`;o000000?ooooo
o`000?l000001?ooool3o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo4ol00000
0ooooooo0000o`00000<o`0000_ooooo0_l00008ooooo`;o00000_ooool2o`000003ooooool0003o
000000Gooooo1?l00008ooooo`Go00000oooool2o`0005Gooooo000Looooo`;o0000COooool2o`00
00Cooooo0_l000000ooooooo0000o`00000;ooooo`;o00004?ooool2o`0000Oooooo0_l00009oooo
o`;o00000_ooool2o`0000_ooooo0_l00002ooooo`;o000000?oooooo`000?l000006Ol0000:oooo
o`?o00001_ooool5o`000004ooooool0003o0000ooooo`Ko00000_ooool3o`0000Cooooo1Ol00002
ooooo`;o0000F_ooool001cooooo00?o0000ooooooooool0Boooool2o`0000Gooooo0_l00003oooo
o`Co00001oooool2o`0001;ooooo0_l00005ooooo`;o00002Oooool4o`0000gooooo0_l00002oooo
o`;o000000?oooooo`000?l000001ol000000ooooooo0000o`00000;o`000003ooooool0003o0000
00_ooooo0_l00007ooooo`;o000000?oooooo`000?l000001_ooool5o`000003ooooool0003o0000
00;o00000oooool5o`0000oooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`1;ooooo`?o
00001?ooool2o`0000?ooooo1?l0000Kooooo`;o00002Oooool2o`0000Oooooo0ol0000<ooooo`;o
00000_ooool2o`000003ooooool0003o000001Co000000?oooooo`000?l000000_l0000Cooooo`;o
00002Oooool:o`0000Cooooo0_l000000ooooooo0000o`00000>ooooo`;o0000COooool001cooooo
00?o0000ooooooooool0C?ooool2o`0000kooooo0_l0000Sooooo`;o00002?ooool2o`00013ooooo
0_l000000ooooooo0000o`00000Io`0000?ooooo1ol0000Dooooo`;o00000_ooool2o`0000Sooooo
0_l000000ooooooo0000o`000007ooooo`;o0000E?ooool001cooooo00?o0000ooooooooool0Eooo
ool2o`0000?ooooo0ol00003ooooo`;o00008_ooool2o`0001;ooooo0_l000000ooooooo0000o`00
0006o`000003ooooool0003o000000go000000Coooooo`000?l0003ooooo1?l000000ooooooo0000
o`000005o`0000oooooo0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o0000017ooooo
0_l0001Dooooo`007?ooool00ol0003oooooooooo`1Gooooo`;o00000oooool3o`0000?ooooo0_l0
0007ooooo`;o00006Oooool2o`0001;ooooo0_l000000ooooooo0000o`00000Io`000003ooooool0
003o000000;o00001oooool2o`0000kooooo0_l000000ooooooo0000o`000003o`000003ooooool0
003o000000Co00003_ooool2o`0005Kooooo000Looooo`03o`000?oooooooooo05_ooooo0ol00004
ooooo`Co00001Oooool2o`0002cooooo0_l00005oooooaSo000000?oooooo`000?l000001?ooool2
o`0000?ooooo0_l0000Aooooo`Ko000000Coooooo`000?l0003ooooo0_l00005ooooo`;o00001ooo
ool2o`0005Kooooo000Looooo`03o`000?oooooooooo05_ooooo0_l000000ooooooo0000o`000004
ooooo`;o0000<oooool2o`0000;ooooo0_l00005oooooa?o00002?ooool2o`000003ooooool0003o
000000Kooooo0_l00006ooooo`;o00001?ooool5o`0000_ooooo1?l0001Mooooo`007?ooool00ol0
003oooooooooo`1Booooo`;o00000_ooool2o`0000Kooooo0_l0000iooooo`;o00000_ooool2o`00
00Kooooo4_l00006ooooo`;o00000oooool2o`0000Gooooo0ol00006ooooo`;o00001Oooool2o`00
00Cooooo0_l000000ooooooo0000o`000006ooooo`;o0000GOooool001cooooo00?o0000oooooooo
ool0D_ooool2o`0000;ooooo0_l00003ooooo`;o00004Oooool3o`0002Cooooo0_l00006ooooo`;o
00001_ooool2o`000004ooooool0003o0000ooooo`[o000000Coooooo`000?l0003o00001?ooool2
o`0000[ooooo0ol0000;ooooo`;o00001_ooool2o`000003ooooool0003o000006Gooooo000Loooo
o`03o`000?oooooooooo05_ooooo0_l0000Aooooo`?o00009?ooool2o`0000_ooooo0_l00003oooo
o`Oo00001Oooool2o`000004ooooool0003o0000o`0000_ooooo0_l00004ooooo`;o00000_ooool2
o`0000Oooooo0_l0001`ooooo`007?ooool00ol0003oooooooooo`1@ooooo`?o00002oooool2o`00
03Gooooo1?l00004ooooo`;o00000oooool2o`0000?ooooo1_l00002ooooo`;o000000Goooooo`00
0?l0003o0000ooooo`02o`0000cooooo0_l00008ooooo`?o00000oooool2o`0007?ooooo000Loooo
o`03o`000?oooooooooo053ooooo0ol00005ooooo`?o00000oooool2o`0003Oooooo0_l00003oooo
o`?o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`000008o`0000?ooooo0_l00005oooo
o`;o00000_ooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000002o`00
00;ooooo0_l0000;ooooo`;o0000I_ooool001cooooo00?o0000ooooooooool0F?ooool4o`0000?o
oooo0_l0000booooo`;o00001oooool3o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l0
00001ol00004ooooo`;o00001Oooool2o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`;o
000000?oooooo`000?l000000_l00004ooooo`Co00001oooool2o`0006Kooooo000Looooo`03o`00
0?oooooooooo05[ooooo0_l00003ooooo`Co00001_ooool2o`0000Oooooo0_l0000Oooooo`;o0000
6?ooool3o`0000[ooooo0_l00002ooooo`;o00003Oooool2o`0000Cooooo0_l000000ooooooo0000
o`000002o`0000Kooooo0_l00005ooooo`;o00001oooool2o`0005Oooooo000Looooo`03o`000?oo
oooooooo05[ooooo0_l00005ooooo`;o00001_ooool2o`0000?ooooo0_l00002ooooo`;o00008ooo
ool2o`0001Cooooo0ol0000:ooooo`Co00002oooool2o`0000;ooooo0_l00004ooooo`;o00002ooo
ool2o`0000?ooooo1?l00007ooooo`;o0000Eoooool001cooooo0_l0001_ooooo`;o00009Oooool4
o`0000Wooooo0_l0000;ooooo`;o00002oooool2o`0000Gooooo0_l00003ooooo`?o00000_ooool2
o`0001Kooooo0_l00003ooooo`;o0000GOooool001cooooo00?o0000ooooooooool0HOooool2o`00
00Kooooo0_l00007ooooo`;o00008Oooool2o`0000[ooooo0ol00008ooooo`Go000000?oooooo`00
0?l000002_ooool2o`0000?ooooo0_l00003ooooo`Co000000?oooooo`000?l000006oooool2o`00
05gooooo000Looooo`03o`000?oooooooooo067ooooo0_l00005ooooo`?o00001oooool2o`00027o
oooo0_l000000ooooooo0000o`000007ooooo`Co00001oooool4o`0000;ooooo0_l0000:ooooo`;o
00002Oooool3o`0000_ooooo0_l0001`ooooo`007?ooool00ol0003oooooooooo`1Xooooo`;o0000
00?oooooo`000?l00000:oooool5o`0000Kooooo0_l000000ooooooo0000o`000005ooooo`;o0000
1oooool2o`0000Cooooo0_l0000Iooooo`;o0000L?ooool001cooooo00?o0000ooooooooool0Jooo
ool4o`0000;ooooo0_l0000Wooooo`?o00002Oooool2o`0000Gooooo0_l00007ooooo`;o00001?oo
ool2o`0000Sooooo0_l000000ooooooo0000o`000002o`0000Sooooo0_l00007ooooo`;o0000JOoo
ool001cooooo00?o0000ooooooooool0Ioooool2o`0000Cooooo0_l000001?oooooo0000o`000?l0
000Nooooo`;o00009_ooool5o`0000Sooooo0_l000000ooooooo0000o`000002o`0000Cooooo0ol0
00000ooooooo0000o`000007ooooo`;o0000JOooool001cooooo00?o0000ooooooooool0Ioooool2
o`0000Oooooo0_l0000Oooooo`;o00003_ooool2o`0001Kooooo1?l0000;ooooo`;o00001oooool3
o`0000Kooooo0_l0000?ooooo`;o0000G?ooool001cooooo00?o0000ooooooooool0LOooool2o`00
02Sooooo0_l00004ooooo`;o000000?oooooo`000?l000003oooool3o`0000;ooooo0_l00005oooo
o`;o00001Oooool2o`00013ooooo0_l00002ooooo`;o00002?ooool2o`000003ooooool0003o0000
05cooooo000Looooo`03o`000?oooooooooo05[ooooo0_l00007ooooo`;o00001?ooool2o`0000Ko
oooo0_l00002ooooo`;o00007?ooool2o`0000Kooooo0_l00007ooooo`;o00003Oooool7o`000003
ooooool0003o000000;o00000_ooool2o`0001_ooooo0_l00005ooooo`;o000000Coooooo`000?l0
003o0000G_ooool001cooooo00?o0000ooooooooool0F_ooool2o`0000Oooooo0_l00004ooooo`?o
00001Oooool2o`0000;ooooo0_l0000=ooooo`Co00002oooool2o`0001Wooooo0_l00003ooooo`Co
000000Coooooo`000?l0003ooooo1?l00005ooooo`;o000000Coooooo`000?l0003o00006_ooool3
o`0000;ooooo0_l0001Nooooo`007?ooool00ol0003oooooooooo`1Zooooo`?o00001?ooool5o`00
00kooooo1?l00007ooooo`;o00007Oooool2o`0000;ooooo1Ol00003ooooo`;o00002?ooool2o`00
0004ooooool0003o0000o`0001[ooooo0_l0001Sooooo`007?ooool00ol0003oooooooooo`1[oooo
o`;o00001_ooool3o`0000[ooooo0_l0000=ooooo`;o00004?ooool2o`0000oooooo0_l00006oooo
o`;o00001Oooool2o`0000Cooooo0_l00008ooooo`;o0000M_ooool001cooooo00?o0000oooooooo
ool0LOooool2o`000003ooooool0003o000000[ooooo0_l000001?oooooo0000o`000?l00003oooo
o`;o00005_ooool2o`0000Cooooo0_l0000Hooooo`;o00003_ooool2o`0000Gooooo0_l0001_oooo
o`007?ooool00ol0003oooooooooo`1aooooo`;o00003Oooool6o`0000;ooooo1Ol0000Dooooo`;o
00001?ooool4o`0002gooooo0_l0001_ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5oooo
o`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0LOooool2
o`0000gooooo0ol00005ooooo`;o000000?oooooo`000?l000000oooool2o`0000cooooo0ol00005
ooooo`;o000000?oooooo`000?l000007Oooool2o`0007oooooo00001_ooooooMgMgoiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`2?ooooo`Go00002_ooool5o`0000?ooooo0_l0000Pooooo`?o0000O_ooool00003ooooool@
413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0S?ooool2o`000003ooooool0003o000000Co00001Oooool2o`0000Cooooo
0ol0000:ooooo`;o00006_ooool2o`0007kooooo00000ooooooo0000ooooo`02ooooo`03o`000?oo
oooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000L?ooool2o`0001[ooooo
1_l000000ooooooo0000o`000005ooooo`Co00000_ooool2o`0000?ooooo0_l000000ooooooo0000
o`000002o`000004ooooool0003o0000o`0009Wooooo00000ooooooo0000ooooo`02ooooo`03o`00
0?oooooooooo00Wooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo073o
oooo0ol0000Jooooo`;o00003Oooool2o`0000Oooooo0_l000000ooooooo0000o`000002o`0000;o
oooo0_l0002Iooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05oa0@
4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`1Xooooo`;o00001oooool2o`0001go
oooo0_l0000@ooooo`;o0000=oooool2o`0006cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMg
M`_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo06Sooooo0_l0000K
ooooo`;o00002Oooool2o`0000oooooo0ol0000_ooooo`;o00001_ooool2o`0006cooooo00001_oo
ooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`00
0?oooooooooo08Gooooo0_l00007ooooo`;o00000_ooool3o`0000;ooooo0_l00008ooooo`;o0000
<?ooool2o`0007Cooooo000Looooo`03o`000?oooooooooo083ooooo0ol0000;ooooo`;o00000_oo
ool4o`000003ooooool0003o000000;o00001?ooool4o`0002cooooo0_l0001hooooo`007?ooool0
0ol0003oooooooooo`1jooooo`;o00001?ooool3o`0000oooooo1?l000000ooooooo0000o`000002
o`0000Cooooo1?l0000/ooooo`;o0000N?ooool001cooooo00?o0000ooooooooool0N_ooool2o`00
013ooooo0_l0000jooooo`;o0000Ooooool001cooooo00?o0000ooooooooool0POooool2o`0000Go
oooo0_l00002ooooo`;o00004Oooool2o`000003ooooool0003o0000027ooooo0_l000000ooooooo
0000o`00001oooooo`007?ooool00ol0003oooooooooo`21ooooo`;o000000?oooooo`000?l00000
0_ooool4o`0000cooooo0ol00004ooooo`;o000000?oooooo`000?l000008Oooool2o`0008;ooooo
000Looooo`03o`000?oooooooooo08Cooooo0_l00004ooooo`;o00003?ooool3o`0000?ooooo1?l0
002Wooooo`007?ooool00ol0003oooooooooo`21ooooo`;o00001Oooool2o`0001Cooooo1?l0002W
ooooo`007?ooool00ol0003oooooooooo`1kooooo`;o00001?ooool2o`0000Gooooo0_l0002ooooo
o`007?ooool00ol0003oooooooooo`1kooooo`;o00003_ooool2o`0000_ooooo0_l00003ooooo`;o
0000Z_ooool001cooooo00?o0000ooooooooool0R_ooool4o`0000[ooooo0_l00003ooooo`;o0000
Z_ooool001cooooo00?o0000ooooooooool0O_ooool2o`0000[ooooo1?l0000Gooooo`;o00006_oo
ool2o`0008Kooooo000Looooo`;o0000Ooooool2o`0002Gooooo0_l000000ooooooo0000o`000002
o`0000gooooo0_l00006ooooo`;o0000Q_ooool001cooooo00?o0000ooooooooool0S_ooool2o`00
01Sooooo1?l0000=ooooo`;o0000S_ooool001cooooo00?o0000ooooooooool0S_ooool2o`0000go
oooo0_l00009ooooo`;o00001oooool2o`000003ooooool0003o000009?ooooo000Looooo`03o`00
0?oooooooooo09gooooo0_l00009ooooo`;o00001oooool2o`000003ooooool0003o000009?ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo08co
oooo0_l0002kooooo`007?ooool00ol0003oooooooooo`2;ooooo`?o0000^oooool001cooooo00?o
0000ooooooooool0Roooool4o`000;[ooooo000Looooo`03o`000?oooooooooo08gooooo0_l0002j
ooooo`007?ooool00ol0003oooooooooo`2eooooo`;o0000T_ooool001cooooo00?o0000oooooooo
ool0]Oooool2o`0009;ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2eooooo`;o00001Oooool2
o`0008_ooooo000Looooo`;o0000YOooool2o`0000oooooo0_l00005ooooo`;o0000Roooool001co
oooo00?o0000ooooooooool0Y?ooool2o`000:?ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooo
ooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB_ooool001Cooooo00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o
0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Doooo
o`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`00
4_ooool00omEEEGoIVIVo`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo002Uooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05Oooool01Oo<
c<co8B4Qo`000?lQ8B7oc<c<00?ooooo1Ol00003ooooo`Go0000T?ooool00:Kooooo00Go0000oooo
ooooooooooooo`000009ooooo`Ko00002Oooool01OlQ8B7oV9RHoooooonHV9So8B4Q00?ooooo00Go
V9RHob4Q8Oo^k^koooooodA4A003ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0T?ooool00:Kooooo
00Go0000ooooooooooooooooo`00000Hooooo`05o`000?ooooooooooooooool000001?ooool00onH
V9So8B4Qonk^kP05ooooo`03oiRHV?lQ8B7ok^k^097ooooo002Vooooo`05o`000?oooooooooooooo
ool000002Oooool6o`0000Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P05ooooo`03oiRHV?lQ8B7o
k^k^00Gooooo00?oV9RHob4Q8Oo^k^h0T?ooool00:Kooooo00Go0000ohN7QoooooooZJVYo`00000H
ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00omgMgOoIVIVooooo`05ooooo`03ogMgMomV
IVKooooo08oooooo002Uooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool05_ooool0
1Ol@413o^[Zjoooooonj^[[o410@00Oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`2>ooooo`00`oooool01Ol0003o^[Zjoooooonj^[[o000000?ooooo00Go0000okZj^_ooooooV9RH
oa0@4003ooooo`05o`000?nj^[[ooooooiRHV?l@4100T?ooool00<?ooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@03ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01OnHV9So410@o`000?lQ8B7o
c<c<093ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(828) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.50472 .65227 Mdot
.51842 .67331 Mdot
.61553 .41685 Mdot
.37391 .55928 Mdot
.47784 .52772 Mdot
.63977 .39116 Mdot
.61313 .54161 Mdot
.59348 .54533 Mdot
.63657 .37284 Mdot
.26502 .55659 Mdot
.62858 .57493 Mdot
.412 .57643 Mdot
.62747 .54461 Mdot
.38714 .52758 Mdot
.65215 .20322 Mdot
.35024 .57634 Mdot
.50165 .72432 Mdot
.45601 .32111 Mdot
.43288 .48861 Mdot
.58677 .3738 Mdot
.55632 .71803 Mdot
.39071 .52415 Mdot
.49775 .65466 Mdot
.38645 .52673 Mdot
.348 .55483 Mdot
.50395 .69312 Mdot
.47851 .71319 Mdot
.32662 .5338 Mdot
.36065 .53762 Mdot
.61313 .58261 Mdot
.44775 .39945 Mdot
.50582 .16431 Mdot
.37131 .58248 Mdot
.27577 .71835 Mdot
.59673 .54467 Mdot
.25468 .33679 Mdot
.61194 .36324 Mdot
.64932 .55312 Mdot
.59356 .54903 Mdot
.61868 .52112 Mdot
.64543 .54942 Mdot
.51009 .69575 Mdot
.61644 .50892 Mdot
.64399 .50013 Mdot
.39247 .55899 Mdot
.66081 .66654 Mdot
.36189 .27826 Mdot
.33797 .51429 Mdot
.53314 .67876 Mdot
.59342 .36217 Mdot
.41298 .81216 Mdot
.60019 .52429 Mdot
.75105 .45219 Mdot
.48588 .08429 Mdot
.63719 .53626 Mdot
.37817 .56359 Mdot
.6167 .37963 Mdot
.38596 .50197 Mdot
.3805 .51777 Mdot
.41258 .78445 Mdot
.33563 .53535 Mdot
.48195 .32281 Mdot
.55345 .67475 Mdot
.66418 .39523 Mdot
.63845 .38333 Mdot
.59575 .56808 Mdot
.51378 .72131 Mdot
.62155 .55094 Mdot
.31994 .48675 Mdot
.6187 .35403 Mdot
.33815 .51315 Mdot
.63583 .57394 Mdot
.54037 .66495 Mdot
.38512 .48257 Mdot
.68021 .68857 Mdot
.71991 .2637 Mdot
.44885 .3259 Mdot
.39306 .76136 Mdot
.46185 .74076 Mdot
.74679 .33078 Mdot
.37165 .5315 Mdot
.85102 .58374 Mdot
.66888 .216 Mdot
.49995 .65694 Mdot
.46077 .53356 Mdot
.60146 .33592 Mdot
.40863 .49737 Mdot
.48975 .45245 Mdot
.30438 .50874 Mdot
.63333 .75767 Mdot
.63243 .36941 Mdot
.52243 .70309 Mdot
.37757 .55708 Mdot
.33413 .4958 Mdot
.36065 .68092 Mdot
.3586 .47642 Mdot
.32637 .54545 Mdot
.50952 .73779 Mdot
.60491 .56985 Mdot
.31948 .57864 Mdot
.60335 .50063 Mdot
.77707 .44866 Mdot
.41156 .5334 Mdot
.63993 .36121 Mdot
.5292 .73045 Mdot
.41809 .52431 Mdot
.62258 .52772 Mdot
.34743 .52816 Mdot
.62832 .50421 Mdot
.52336 .6728 Mdot
.34083 .49196 Mdot
.46174 .31673 Mdot
.71888 .69917 Mdot
.51664 .71094 Mdot
.82002 .55783 Mdot
.33564 .52551 Mdot
.39419 .5179 Mdot
.51801 .67625 Mdot
.61606 .40309 Mdot
.48166 .42554 Mdot
.53568 .7122 Mdot
.60835 .52783 Mdot
.47129 .6791 Mdot
.39765 .45977 Mdot
.64913 .38431 Mdot
.78106 .45413 Mdot
.77043 .471 Mdot
.30224 .41036 Mdot
.41239 .50719 Mdot
.60098 .6334 Mdot
.63481 .399 Mdot
.52189 .69592 Mdot
.62447 .55253 Mdot
.35005 .57049 Mdot
.48592 .70254 Mdot
.63149 .5664 Mdot
.47743 .31272 Mdot
.48015 .25117 Mdot
.53894 .69231 Mdot
.55324 .57984 Mdot
.66768 .55964 Mdot
.62156 .52141 Mdot
.31464 .76127 Mdot
.5147 .67024 Mdot
.4923 .34743 Mdot
.62581 .56468 Mdot
.40282 .3296 Mdot
.3362 .56243 Mdot
.26584 .45305 Mdot
.75791 .7164 Mdot
.40089 .81435 Mdot
.74691 .56934 Mdot
.47406 .35356 Mdot
.63546 .52238 Mdot
.36351 .54974 Mdot
.50684 .67032 Mdot
.50845 .6817 Mdot
.31476 .51837 Mdot
.33985 .55418 Mdot
.34339 .49919 Mdot
.32853 .50236 Mdot
.40595 .25828 Mdot
.33636 .50082 Mdot
.5916 .43077 Mdot
.5048 .71267 Mdot
.3454 .54639 Mdot
.60418 .4023 Mdot
.39875 .57 Mdot
.64482 .56256 Mdot
.38615 .51339 Mdot
.35117 .56196 Mdot
.4012 .47746 Mdot
.64497 .53846 Mdot
.45359 .18848 Mdot
.74633 .7175 Mdot
.29461 .26365 Mdot
.77638 .56956 Mdot
.61414 .39118 Mdot
.40774 .51113 Mdot
.49309 .33408 Mdot
.35105 .61431 Mdot
.37121 .52096 Mdot
.47377 .83037 Mdot
.33617 .55626 Mdot
.24243 .64443 Mdot
.37497 .44204 Mdot
.29502 .25536 Mdot
.54348 .42697 Mdot
.35379 .53714 Mdot
.33438 .64992 Mdot
.21896 .54669 Mdot
.48436 .59484 Mdot
.64295 .5444 Mdot
.61067 .40497 Mdot
.61553 .37096 Mdot
.64456 .52005 Mdot
.30083 .5583 Mdot
.27479 .507 Mdot
.33492 .59297 Mdot
.7763 .45831 Mdot
.5423 .66518 Mdot
.51356 .33827 Mdot
.53714 .67243 Mdot
.86156 .50235 Mdot
.60485 .76014 Mdot
.67054 .56453 Mdot
.46079 .35565 Mdot
.61907 .41544 Mdot
.77627 .46146 Mdot
.49215 .34061 Mdot
.35206 .50904 Mdot
.53366 .68722 Mdot
.21768 .60723 Mdot
.39336 .44601 Mdot
.18289 .55843 Mdot
.47673 .68026 Mdot
.51612 .44099 Mdot
.63671 .55732 Mdot
.58089 .37694 Mdot
.40078 .53094 Mdot
.36122 .49292 Mdot
.55255 .70843 Mdot
.34023 .51528 Mdot
.44817 .65403 Mdot
.35484 .56424 Mdot
.61331 .33661 Mdot
.45517 .30574 Mdot
.63316 .51515 Mdot
.29866 .41635 Mdot
.51844 .6446 Mdot
.69123 .3881 Mdot
.59503 .36726 Mdot
.28944 .59428 Mdot
.62992 .57634 Mdot
.46405 .31672 Mdot
.59191 .38076 Mdot
.50569 .35723 Mdot
.41951 .51009 Mdot
.61227 .36117 Mdot
.5011 .35077 Mdot
.43755 .22643 Mdot
.38516 .56454 Mdot
.41546 .27693 Mdot
.61092 .54824 Mdot
.47136 .67216 Mdot
.33594 .53673 Mdot
.77452 .47228 Mdot
.42711 .51898 Mdot
.71525 .52075 Mdot
.75052 .45784 Mdot
.75802 .4465 Mdot
.7214 .29568 Mdot
.46029 .33274 Mdot
.72788 .6195 Mdot
.57897 .65675 Mdot
.51442 .72234 Mdot
.3843 .55751 Mdot
.36966 .19714 Mdot
.62661 .56419 Mdot
.35517 .50997 Mdot
.60531 .33612 Mdot
.62294 .56341 Mdot
.38973 .49823 Mdot
.63937 .52973 Mdot
.50873 .67508 Mdot
.67178 .31836 Mdot
.48652 .71487 Mdot
.37672 .56687 Mdot
.61856 .53118 Mdot
.59818 .37978 Mdot
.50125 .68986 Mdot
.35053 .52605 Mdot
.40158 .52406 Mdot
.76839 .45692 Mdot
.35084 .54249 Mdot
.37817 .19918 Mdot
.32833 .52433 Mdot
.64748 .41244 Mdot
.34108 .48118 Mdot
.41517 .83497 Mdot
.51207 .26272 Mdot
.52232 .71644 Mdot
.75444 .45085 Mdot
.63173 .37466 Mdot
.64898 .2909 Mdot
.52315 .58073 Mdot
.36085 .52996 Mdot
.76002 .45167 Mdot
.50392 .41337 Mdot
.59944 .57588 Mdot
.37529 .47124 Mdot
.63603 .73728 Mdot
.58884 .38556 Mdot
.7742 .46008 Mdot
.4477 .51045 Mdot
.52889 .73108 Mdot
.37068 .56031 Mdot
.60072 .36852 Mdot
.47076 .67933 Mdot
.41021 .55699 Mdot
.3074 .31572 Mdot
.75599 .46661 Mdot
.61214 .54828 Mdot
.30094 .47128 Mdot
.33711 .504 Mdot
.60819 .37601 Mdot
.48951 .66124 Mdot
.59907 .54483 Mdot
.50581 .70232 Mdot
.2141 .57051 Mdot
.77385 .58562 Mdot
.38105 .25502 Mdot
.45854 .35494 Mdot
.71903 .49443 Mdot
.27246 .28168 Mdot
.73921 .63041 Mdot
.35832 .36512 Mdot
.18145 .39906 Mdot
.59773 .3943 Mdot
.45208 .28595 Mdot
.62734 .37808 Mdot
.37818 .54768 Mdot
.64059 .38728 Mdot
.29514 .24985 Mdot
.33537 .55699 Mdot
.61241 .38727 Mdot
.59489 .3096 Mdot
.33546 .54676 Mdot
.51253 .71392 Mdot
.62299 .20048 Mdot
.64454 .77647 Mdot
.54902 .77255 Mdot
.61266 .39679 Mdot
.46821 .78009 Mdot
.32878 .53743 Mdot
.38898 .577 Mdot
.5024 .67112 Mdot
.34596 .47751 Mdot
.51072 .33067 Mdot
.50805 .35804 Mdot
.28704 .43625 Mdot
.80652 .61263 Mdot
.30383 .57065 Mdot
.5009 .68568 Mdot
.43781 .66992 Mdot
.67613 .6888 Mdot
.79262 .46113 Mdot
.63031 .5911 Mdot
.46449 .19083 Mdot
.28484 .53838 Mdot
.55292 .58623 Mdot
.65185 .7245 Mdot
.52963 .69133 Mdot
.40712 .21473 Mdot
.63709 .53933 Mdot
.38028 .6424 Mdot
.2853 .68848 Mdot
.35454 .49912 Mdot
.61759 .57852 Mdot
.36098 .58923 Mdot
.60209 .78076 Mdot
.4204 .30906 Mdot
.81652 .40054 Mdot
.38746 .56246 Mdot
.71997 .63165 Mdot
.3906 .51658 Mdot
.36287 .40991 Mdot
.32713 .52269 Mdot
.50017 .70023 Mdot
.34927 .60284 Mdot
.5042 .50453 Mdot
.79164 .65915 Mdot
.59285 .76921 Mdot
.47969 .35605 Mdot
.39925 .52319 Mdot
.35715 .49715 Mdot
.46563 .3365 Mdot
.49047 .68311 Mdot
.32753 .51877 Mdot
.27981 .37864 Mdot
.34492 .50073 Mdot
.64773 .55947 Mdot
.45695 .40565 Mdot
.49856 .75201 Mdot
.36116 .48202 Mdot
.49016 .72165 Mdot
.63906 .53318 Mdot
.59133 .56205 Mdot
.33605 .47026 Mdot
.63932 .52559 Mdot
.36924 .56193 Mdot
.45739 .38657 Mdot
.50825 .65737 Mdot
.43224 .45823 Mdot
.48713 .68217 Mdot
.47258 .76448 Mdot
.63245 .52589 Mdot
.78223 .46686 Mdot
.53193 .61302 Mdot
.63179 .5392 Mdot
.52864 .78545 Mdot
.29717 .57203 Mdot
.43285 .52087 Mdot
.57874 .79249 Mdot
.60449 .39402 Mdot
.78061 .4643 Mdot
.61563 .53005 Mdot
.33889 .50186 Mdot
.41058 .47669 Mdot
.64801 .57087 Mdot
.38996 .6919 Mdot
.63539 .28716 Mdot
.32529 .53694 Mdot
.49564 .69522 Mdot
.52004 .69823 Mdot
.41724 .54965 Mdot
.35796 .52281 Mdot
.64152 .4138 Mdot
.756 .46111 Mdot
.7846 .44807 Mdot
.77192 .47023 Mdot
.57724 .37057 Mdot
.69178 .59895 Mdot
.61994 .52098 Mdot
.63408 .6396 Mdot
.69461 .5053 Mdot
.36883 .44916 Mdot
.60457 .37885 Mdot
.37561 .49136 Mdot
.39326 .54378 Mdot
.59957 .5452 Mdot
.75942 .52591 Mdot
.45744 .50706 Mdot
.52694 .66421 Mdot
.64273 .52803 Mdot
.27787 .54444 Mdot
.68224 .56387 Mdot
.50854 .33473 Mdot
.5461 .77765 Mdot
.62321 .57916 Mdot
.52682 .70408 Mdot
.6543 .56569 Mdot
.35292 .49753 Mdot
.31588 .53819 Mdot
.52318 .67983 Mdot
.45977 .33678 Mdot
.40035 .4671 Mdot
.39166 .499 Mdot
.53038 .86251 Mdot
.68421 .68442 Mdot
.60028 .59642 Mdot
.3622 .54363 Mdot
.42687 .48686 Mdot
.47711 .35855 Mdot
.34529 .50288 Mdot
.40388 .52775 Mdot
.72384 .70064 Mdot
.58136 .52678 Mdot
.46746 .30471 Mdot
.38193 .64014 Mdot
.47705 .68346 Mdot
.4115 .19132 Mdot
.77531 .44669 Mdot
.59591 .51692 Mdot
.67405 .32225 Mdot
.77182 .46571 Mdot
.70562 .50125 Mdot
.4109 .20331 Mdot
.77538 .46883 Mdot
.68751 .35682 Mdot
.43537 .58152 Mdot
.31981 .53425 Mdot
.38933 .51027 Mdot
.49629 .33171 Mdot
.5127 .67038 Mdot
.53045 .43105 Mdot
.4793 .22835 Mdot
.39205 .5221 Mdot
.54633 .64608 Mdot
.46211 .20842 Mdot
.76921 .46001 Mdot
.47881 .31876 Mdot
.51378 .32652 Mdot
.39442 .51526 Mdot
.74577 .66192 Mdot
.50365 .69088 Mdot
.35109 .52607 Mdot
.35472 .48772 Mdot
.60963 .3943 Mdot
.53207 .69883 Mdot
.59712 .36525 Mdot
.75089 .46199 Mdot
.19172 .45469 Mdot
.50053 .85958 Mdot
.60107 .55271 Mdot
.32357 .25098 Mdot
.58828 .56171 Mdot
.77561 .34205 Mdot
.76587 .46875 Mdot
.37034 .52519 Mdot
.52612 .64676 Mdot
.34558 .52729 Mdot
.36043 .50441 Mdot
.35235 .50745 Mdot
.31126 .57983 Mdot
.46731 .83098 Mdot
.48098 .33824 Mdot
.38945 .45245 Mdot
.65559 .39541 Mdot
.35632 .22127 Mdot
.62504 .21468 Mdot
.38202 .48755 Mdot
.39838 .51444 Mdot
.49993 .71511 Mdot
.31523 .51114 Mdot
.61427 .58461 Mdot
.4915 .65795 Mdot
.41553 .48256 Mdot
.39457 .22378 Mdot
.32759 .51511 Mdot
.26892 .29077 Mdot
.65326 .56676 Mdot
.53994 .7764 Mdot
.3802 .45348 Mdot
.77678 .46929 Mdot
.7802 .4649 Mdot
.79449 .45025 Mdot
.62841 .58591 Mdot
.60935 .38207 Mdot
.58451 .22219 Mdot
.32082 .57188 Mdot
.36121 .55236 Mdot
.42501 .48432 Mdot
.57819 .39734 Mdot
.47681 .44569 Mdot
.73706 .58921 Mdot
.28224 .55255 Mdot
.64458 .40764 Mdot
.47285 .66395 Mdot
.83 .51517 Mdot
.49158 .65884 Mdot
.46611 .30449 Mdot
.6358 .57056 Mdot
.50726 .32888 Mdot
.4759 .80615 Mdot
.52117 .6727 Mdot
.55037 .71242 Mdot
.61274 .38972 Mdot
.53754 .46125 Mdot
.41511 .12467 Mdot
.63838 .35497 Mdot
.30248 .385 Mdot
.49892 .67392 Mdot
.37618 .47917 Mdot
.49744 .40817 Mdot
.53233 .46312 Mdot
.62304 .38765 Mdot
.37952 .53173 Mdot
.78821 .63685 Mdot
.63878 .41501 Mdot
.38185 .47074 Mdot
.63038 .40425 Mdot
.64387 .55698 Mdot
.63151 .40132 Mdot
.50244 .64592 Mdot
.41604 .52238 Mdot
.46428 .09962 Mdot
.59396 .47392 Mdot
.33823 .53368 Mdot
.64271 .52816 Mdot
.25942 .38704 Mdot
.37002 .50067 Mdot
.50875 .32587 Mdot
.65058 .39028 Mdot
.60974 .27498 Mdot
.32972 .53541 Mdot
.62969 .39478 Mdot
.50598 .64986 Mdot
.58225 .55344 Mdot
.72982 .29495 Mdot
.78627 .45601 Mdot
.50649 .66513 Mdot
.76309 .43743 Mdot
.65846 .57468 Mdot
.39298 .4738 Mdot
.3486 .49181 Mdot
.5013 .70722 Mdot
.72794 .3798 Mdot
.32126 .50011 Mdot
.37183 .53142 Mdot
.6069 .4113 Mdot
.61016 .42149 Mdot
.71155 .34418 Mdot
.5979 .39275 Mdot
.42257 .47859 Mdot
.50185 .70677 Mdot
.38686 .54819 Mdot
.51462 .71529 Mdot
.38307 .55752 Mdot
.47945 .63502 Mdot
.50002 .65846 Mdot
.791 .59093 Mdot
.38641 .54015 Mdot
.33431 .44817 Mdot
.35614 .50468 Mdot
.33983 .50922 Mdot
.65212 .37868 Mdot
.47044 .33479 Mdot
.30091 .51871 Mdot
.6715 .4146 Mdot
.48163 .31596 Mdot
.22483 .5748 Mdot
.60957 .39614 Mdot
.49931 .32896 Mdot
.42104 .26408 Mdot
.75765 .4481 Mdot
.48586 .33248 Mdot
.61144 .2105 Mdot
.6004 .5502 Mdot
.47527 .67041 Mdot
.33634 .54756 Mdot
.17687 .43541 Mdot
.44583 .3911 Mdot
.76261 .45562 Mdot
.33285 .52914 Mdot
.37467 .4937 Mdot
.52226 .73027 Mdot
.862 .53551 Mdot
.6135 .41807 Mdot
.37152 .55381 Mdot
.49541 .72046 Mdot
.78239 .69364 Mdot
.64878 .36934 Mdot
.4898 .33165 Mdot
.65137 .5604 Mdot
.47455 .71768 Mdot
.78704 .45573 Mdot
.59918 .57683 Mdot
.64954 .32221 Mdot
.49294 .80414 Mdot
.33314 .52244 Mdot
.60533 .37252 Mdot
.40729 .81784 Mdot
.30759 .56778 Mdot
.58532 .60238 Mdot
.26603 .47834 Mdot
.52873 .69504 Mdot
.64923 .56639 Mdot
.50737 .35214 Mdot
.49359 .65396 Mdot
.49183 .68481 Mdot
.59635 .53726 Mdot
.56308 .37492 Mdot
.51782 .44448 Mdot
.64493 .56835 Mdot
.64507 .75 Mdot
.21899 .59717 Mdot
.75696 .45479 Mdot
.47012 .32096 Mdot
.2297 .66474 Mdot
.50964 .69655 Mdot
.46215 .19062 Mdot
.44964 .8236 Mdot
.32628 .54514 Mdot
.50223 .34452 Mdot
.69887 .54517 Mdot
.56311 .21526 Mdot
.61889 .56199 Mdot
.48781 .47719 Mdot
.49847 .31212 Mdot
.32159 .52688 Mdot
.53922 .75961 Mdot
.37948 .54 Mdot
.63786 .56481 Mdot
.47587 .7525 Mdot
.52556 .70667 Mdot
.66072 .56987 Mdot
.53777 .78463 Mdot
.39577 .54238 Mdot
.38265 .53639 Mdot
.39104 .39454 Mdot
.53404 .68522 Mdot
.78715 .45056 Mdot
.35109 .5315 Mdot
.38685 .50411 Mdot
.38925 .47532 Mdot
.2842 .50524 Mdot
.7293 .67398 Mdot
.37463 .55245 Mdot
.5924 .35374 Mdot
.42014 .55462 Mdot
.38729 .53648 Mdot
.49832 .72519 Mdot
.50209 .85206 Mdot
.76465 .47238 Mdot
.3857 .51063 Mdot
.33006 .51819 Mdot
.59801 .53868 Mdot
.51205 .42615 Mdot
.53358 .46949 Mdot
.62924 .35561 Mdot
.3737 .34147 Mdot
.31542 .58189 Mdot
.48181 .69473 Mdot
.4696 .31137 Mdot
.4093 .49068 Mdot
.48765 .70765 Mdot
.37572 .57626 Mdot
.6393 .41285 Mdot
.75658 .45818 Mdot
.57785 .73659 Mdot
.48421 .32684 Mdot
.52867 .38639 Mdot
.62413 .65951 Mdot
.60905 .40552 Mdot
.35501 .5534 Mdot
.58895 .53264 Mdot
.61702 .35762 Mdot
.76784 .45517 Mdot
.44577 .49115 Mdot
.50592 .6819 Mdot
.51957 .70746 Mdot
.3077 .4238 Mdot
.66767 .40682 Mdot
.64958 .80512 Mdot
.64334 .55825 Mdot
.42314 .51707 Mdot
.58314 .64324 Mdot
.51871 .70899 Mdot
.30394 .42294 Mdot
.49837 .32754 Mdot
.61697 .56086 Mdot
.79598 .4624 Mdot
.49157 .71067 Mdot
.53729 .69064 Mdot
.39495 .56095 Mdot
.39936 .49419 Mdot
.34851 .37055 Mdot
.28748 .43451 Mdot
.64458 .54035 Mdot
.46447 .32738 Mdot
.6082 .35366 Mdot
.37556 .54518 Mdot
.4995 .65617 Mdot
.23684 .62637 Mdot
.32986 .50738 Mdot
.6412 .41456 Mdot
.52755 .69092 Mdot
.4641 .33598 Mdot
.49741 .31823 Mdot
.34034 .50889 Mdot
.409 .77443 Mdot
.62449 .53512 Mdot
.51652 .71201 Mdot
.56829 .69622 Mdot
.3248 .49339 Mdot
.40406 .49856 Mdot
.43355 .55448 Mdot
.59632 .57114 Mdot
.55595 .75759 Mdot
.46227 .31162 Mdot
.51307 .68551 Mdot
.34 .53165 Mdot
.48262 .32301 Mdot
.57576 .69398 Mdot
.7654 .46557 Mdot
.63395 .40248 Mdot
.51148 .32977 Mdot
.47782 .34898 Mdot
.47677 .31465 Mdot
.47841 .18547 Mdot
.54274 .66887 Mdot
.4407 .64769 Mdot
.32596 .52325 Mdot
.3165 .42039 Mdot
.31077 .5405 Mdot
.63649 .58451 Mdot
.601 .39204 Mdot
.35994 .50174 Mdot
.39682 .55988 Mdot
.28908 .46944 Mdot
.29491 .49273 Mdot
.55976 .6992 Mdot
.52874 .67897 Mdot
.30659 .47453 Mdot
.60526 .39114 Mdot
.86757 .56531 Mdot
.35449 .18127 Mdot
.36993 .45671 Mdot
.5262 .43955 Mdot
.49639 .65682 Mdot
.59827 .53234 Mdot
.52898 .48006 Mdot
.65508 .54891 Mdot
.51681 .68876 Mdot
.37654 .54672 Mdot
.63904 .64043 Mdot
.48509 .36186 Mdot
.34332 .49795 Mdot
.63354 .55965 Mdot
.34313 .49866 Mdot
.62948 .58287 Mdot
.4691 .62317 Mdot
.65797 .7277 Mdot
.33459 .55508 Mdot
.34361 .48281 Mdot
.29964 .46488 Mdot
.38518 .4885 Mdot
.77159 .41789 Mdot
.48985 .67264 Mdot
.79831 .62214 Mdot
.40763 .55769 Mdot
.42971 .7589 Mdot
.32238 .51755 Mdot
.7209 .40018 Mdot
.40041 .49083 Mdot
.52532 .51084 Mdot
.3222 .53615 Mdot
.40587 .51815 Mdot
.62319 .53003 Mdot
.59766 .53884 Mdot
.51544 .65362 Mdot
.78887 .45324 Mdot
.30513 .25106 Mdot
.39724 .49841 Mdot
.58571 .35723 Mdot
.5654 .59076 Mdot
.47242 .34434 Mdot
.51572 .69185 Mdot
.7828 .70412 Mdot
.63864 .53049 Mdot
.65341 .35702 Mdot
.73486 .39548 Mdot
.58299 .3764 Mdot
.59461 .50709 Mdot
.28279 .57022 Mdot
.46312 .34142 Mdot
.32108 .52205 Mdot
.28314 .72307 Mdot
.69615 .659 Mdot
.40316 .46626 Mdot
.66054 .5562 Mdot
.38885 .61796 Mdot
.23465 .66762 Mdot
.51845 .33921 Mdot
.49485 .35575 Mdot
.62833 .53041 Mdot
.59396 .40398 Mdot
.34912 .5941 Mdot
.49962 .32764 Mdot
.62555 .41104 Mdot
.78845 .44604 Mdot
.51038 .57423 Mdot
.50638 .69186 Mdot
.55474 .76854 Mdot
.63164 .6892 Mdot
.64374 .53839 Mdot
.68643 .3934 Mdot
.46604 .69043 Mdot
.53681 .72365 Mdot
.78823 .46096 Mdot
.65268 .3793 Mdot
.52796 .64557 Mdot
.39896 .46934 Mdot
.36254 .44444 Mdot
.38935 .51784 Mdot
.49837 .33938 Mdot
.38532 .4856 Mdot
.65405 .39202 Mdot
.62215 .56008 Mdot
.62794 .36355 Mdot
.61685 .53524 Mdot
.67559 .62515 Mdot
.35142 .5213 Mdot
.40415 .51486 Mdot
.47017 .3945 Mdot
.53459 .6717 Mdot
.4446 .80856 Mdot
.58472 .35675 Mdot
.62073 .37825 Mdot
.39849 .54415 Mdot
.50123 .64907 Mdot
.46998 .29695 Mdot
.48651 .39315 Mdot
.36893 .4837 Mdot
.48963 .67163 Mdot
.36698 .55353 Mdot
.42284 .24745 Mdot
.67616 .71611 Mdot
.50851 .70467 Mdot
.81786 .61208 Mdot
.36737 .5409 Mdot
.43817 .58663 Mdot
.42683 .48529 Mdot
.30599 .35864 Mdot
.32629 .49069 Mdot
.47676 .6779 Mdot
.38502 .51504 Mdot
.48618 .66559 Mdot
.60416 .4072 Mdot
.60984 .52221 Mdot
.50354 .66459 Mdot
.37329 .48125 Mdot
.47305 .16652 Mdot
.63992 .55875 Mdot
.39938 .52504 Mdot
.61049 .57103 Mdot
.48235 .70582 Mdot
.53138 .67319 Mdot
.62157 .22146 Mdot
.58184 .57768 Mdot
.6434 .5531 Mdot
.36432 .55845 Mdot
.60848 .71195 Mdot
.38366 .54882 Mdot
.3419 .37805 Mdot
.40774 .54893 Mdot
.3346 .48395 Mdot
.75873 .29061 Mdot
.58687 .54844 Mdot
.66685 .79047 Mdot
.47213 .23041 Mdot
.49448 .17883 Mdot
.47512 .72507 Mdot
.51854 .33889 Mdot
.41628 .20968 Mdot
.75074 .45931 Mdot
.64412 .39827 Mdot
.35862 .50172 Mdot
.45488 .69513 Mdot
.64972 .55674 Mdot
.4729 .33852 Mdot
.33618 .55652 Mdot
.64846 .40971 Mdot
.67377 .27347 Mdot
.63768 .52365 Mdot
.51078 .69546 Mdot
.53148 .66883 Mdot
.76989 .70089 Mdot
.33702 .53006 Mdot
.4007 .51896 Mdot
.63578 .56958 Mdot
.29464 .54388 Mdot
.46095 .3235 Mdot
.56042 .31035 Mdot
.64267 .55166 Mdot
.60211 .48346 Mdot
.52193 .67001 Mdot
.37432 .49267 Mdot
.46944 .43766 Mdot
.64348 .4617 Mdot
.28364 .61124 Mdot
.49537 .33352 Mdot
.36462 .37703 Mdot
.47668 .6787 Mdot
.62696 .55563 Mdot
.45727 .26969 Mdot
.42557 .52117 Mdot
.37886 .49546 Mdot
.36816 .37897 Mdot
.51122 .41925 Mdot
.4953 .2994 Mdot
.31238 .51559 Mdot
.50239 .41802 Mdot
.40289 .54165 Mdot
.41324 .48 Mdot
.33734 .47536 Mdot
.41031 .50602 Mdot
.49038 .66691 Mdot
.28135 .4772 Mdot
.63445 .39706 Mdot
.36361 .67454 Mdot
.49558 .47818 Mdot
.34224 .54096 Mdot
.38027 .54625 Mdot
.29666 .60732 Mdot
.59546 .50189 Mdot
.49275 .67376 Mdot
.535 .64642 Mdot
.62502 .52461 Mdot
.34985 .44407 Mdot
.58512 .40159 Mdot
.27224 .4741 Mdot
.63179 .36437 Mdot
.48862 .67173 Mdot
.61479 .37573 Mdot
.61888 .5251 Mdot
.60548 .3717 Mdot
.57849 .3677 Mdot
.64427 .57581 Mdot
.51966 .66462 Mdot
.37279 .48442 Mdot
.6318 .52468 Mdot
.38587 .39342 Mdot
.49913 .33814 Mdot
.62133 .22098 Mdot
.41606 .56037 Mdot
.4493 .44884 Mdot
.30934 .3143 Mdot
.6247 .36498 Mdot
.6898 .71654 Mdot
.50055 .65869 Mdot
.45624 .34735 Mdot
.48978 .66509 Mdot
.46835 .82219 Mdot
.46747 .33176 Mdot
.60847 .20912 Mdot
.54129 .33793 Mdot
.63189 .26096 Mdot
.31133 .52499 Mdot
.49357 .62564 Mdot
.60832 .35945 Mdot
.64974 .55378 Mdot
.56062 .3577 Mdot
.41052 .5206 Mdot
.74522 .62103 Mdot
.54016 .71013 Mdot
.7755 .44379 Mdot
.62298 .55002 Mdot
.66086 .54856 Mdot
.33746 .52515 Mdot
.66767 .30576 Mdot
.41602 .53072 Mdot
.48239 .28259 Mdot
.36773 .36037 Mdot
.26861 .47792 Mdot
.37275 .56169 Mdot
.63012 .35947 Mdot
.3658 .5543 Mdot
.40149 .61246 Mdot
.30683 .75445 Mdot
.44072 .52668 Mdot
.78319 .5832 Mdot
.52176 .373 Mdot
.52085 .67627 Mdot
.36705 .45437 Mdot
.77132 .45003 Mdot
.36458 .54233 Mdot
.16432 .61908 Mdot
.48279 .33152 Mdot
.67436 .3499 Mdot
.32309 .50303 Mdot
.34704 .52992 Mdot
.3304 .75314 Mdot
.45147 .66879 Mdot
.79569 .46455 Mdot
.38063 .49905 Mdot
.3895 .3411 Mdot
.59603 .56453 Mdot
.41879 .5371 Mdot
.39075 .51238 Mdot
.21595 .54757 Mdot
.60449 .57597 Mdot
.61992 .36596 Mdot
.75149 .45516 Mdot
.60694 .35303 Mdot
.51028 .31625 Mdot
.54074 .48628 Mdot
.27245 .44497 Mdot
.67523 .71367 Mdot
.50276 .31755 Mdot
.34144 .49296 Mdot
.4612 .51867 Mdot
.36247 .53482 Mdot
.49984 .3555 Mdot
.6127 .58183 Mdot
.49542 .66569 Mdot
.58483 .72697 Mdot
.77454 .45797 Mdot
.38359 .47099 Mdot
.51327 .34898 Mdot
.50583 .67384 Mdot
.68461 .41482 Mdot
.51617 .67918 Mdot
.63517 .54241 Mdot
.64456 .58325 Mdot
.47277 .3265 Mdot
.48845 .66683 Mdot
.60853 .34755 Mdot
.47716 .23142 Mdot
.40142 .55155 Mdot
.64387 .59755 Mdot
.51509 .64731 Mdot
.4866 .72263 Mdot
.54263 .69519 Mdot
.34359 .51874 Mdot
.51812 .4327 Mdot
.42116 .48497 Mdot
.63265 .53063 Mdot
.63389 .40699 Mdot
.25796 .46284 Mdot
.33962 .76587 Mdot
.59996 .47973 Mdot
.30358 .51253 Mdot
.39747 .53169 Mdot
.39441 .51549 Mdot
.35278 .56847 Mdot
.47415 .26043 Mdot
.35562 .52185 Mdot
.61986 .53193 Mdot
.64443 .37191 Mdot
.33373 .53303 Mdot
.77096 .44844 Mdot
.50755 .44382 Mdot
.47649 .30988 Mdot
.51673 .49258 Mdot
.41831 .17602 Mdot
.50466 .67274 Mdot
.59395 .37754 Mdot
.64329 .39649 Mdot
.47693 .31268 Mdot
.64739 .54751 Mdot
.51364 .6741 Mdot
.3172 .34102 Mdot
.46972 .31819 Mdot
.38439 .51086 Mdot
.63207 .31936 Mdot
.82623 .56977 Mdot
.31813 .51312 Mdot
.36585 .50863 Mdot
.75389 .45014 Mdot
.59006 .40303 Mdot
.15588 .47095 Mdot
.5153 .40517 Mdot
.47127 .33116 Mdot
.48395 .35354 Mdot
.54371 .69323 Mdot
.39022 .46102 Mdot
.61571 .53858 Mdot
.48632 .40465 Mdot
.25575 .40939 Mdot
.55081 .4016 Mdot
.76876 .3376 Mdot
.33378 .50907 Mdot
.32999 .74472 Mdot
.38294 .55486 Mdot
.52628 .7303 Mdot
.51757 .72025 Mdot
.49598 .67899 Mdot
.6328 .53434 Mdot
.46529 .75774 Mdot
.61391 .53411 Mdot
.39555 .17192 Mdot
.48333 .66109 Mdot
.54438 .24978 Mdot
.61336 .38131 Mdot
.30638 .54604 Mdot
.46209 .33441 Mdot
.62119 .48804 Mdot
.32292 .48348 Mdot
.73866 .66062 Mdot
.60489 .37816 Mdot
.52736 .67084 Mdot
.30805 .58797 Mdot
.23523 .30607 Mdot
.54758 .46752 Mdot
.46309 .57406 Mdot
.43092 .80359 Mdot
.46579 .33408 Mdot
.29688 .61776 Mdot
.45799 .33655 Mdot
.62768 .56558 Mdot
.41127 .5169 Mdot
.41136 .50292 Mdot
.37907 .55986 Mdot
.35436 .52045 Mdot
.6006 .54129 Mdot
.37875 .57003 Mdot
.41531 .83496 Mdot
.75523 .45387 Mdot
.4263 .23313 Mdot
.50478 .32994 Mdot
.65721 .56588 Mdot
.63985 .36854 Mdot
.78892 .44953 Mdot
.28469 .42716 Mdot
.32405 .53873 Mdot
.35796 .50358 Mdot
.78644 .46722 Mdot
.32621 .48332 Mdot
.28896 .56172 Mdot
.63517 .39529 Mdot
.58657 .48301 Mdot
.51535 .33641 Mdot
.50757 .32985 Mdot
.63256 .57853 Mdot
.48898 .6656 Mdot
.49671 .32905 Mdot
.60362 .41062 Mdot
.38102 .57147 Mdot
.39488 .47901 Mdot
.51569 .64768 Mdot
.45002 .82384 Mdot
.51995 .34141 Mdot
.31795 .59261 Mdot
.48034 .67217 Mdot
.54668 .69118 Mdot
.3775 .49803 Mdot
.43814 .53991 Mdot
.47162 .69837 Mdot
.49929 .31782 Mdot
.65806 .56377 Mdot
.59188 .24159 Mdot
.63422 .56495 Mdot
.51042 .67211 Mdot
.41255 .55769 Mdot
.52066 .66665 Mdot
.35814 .54109 Mdot
.83913 .34349 Mdot
.40676 .49591 Mdot
.62411 .78433 Mdot
.31324 .36283 Mdot
.64513 .39226 Mdot
.60622 .34895 Mdot
.76244 .45006 Mdot
.4795 .67177 Mdot
.41138 .49349 Mdot
.474 .35156 Mdot
.52335 .18697 Mdot
.47599 .64036 Mdot
.64019 .40892 Mdot
.58488 .39943 Mdot
.60515 .57954 Mdot
.32341 .51122 Mdot
.37931 .49124 Mdot
.60731 .36989 Mdot
.33629 .29106 Mdot
.48505 .69844 Mdot
.39986 .52004 Mdot
.3938 .53429 Mdot
.64155 .39222 Mdot
.47528 .23381 Mdot
.47448 .62629 Mdot
.40969 .51261 Mdot
.51759 .3653 Mdot
.63156 .58512 Mdot
.3558 .5678 Mdot
.37537 .57078 Mdot
.48934 .35053 Mdot
.38432 .23665 Mdot
.25215 .6997 Mdot
.64568 .57803 Mdot
.7864 .45046 Mdot
.36861 .48041 Mdot
.61444 .38292 Mdot
.38009 .47956 Mdot
.26076 .32073 Mdot
.76045 .4475 Mdot
.36442 .52427 Mdot
.36361 .45999 Mdot
.52995 .70856 Mdot
.35607 .52573 Mdot
.23478 .55694 Mdot
.62609 .35172 Mdot
.36068 .52443 Mdot
.42383 .78646 Mdot
.59716 .56984 Mdot
.36302 .45781 Mdot
.50917 .34573 Mdot
.30065 .36072 Mdot
.62792 .66994 Mdot
.57596 .39556 Mdot
.50219 .32431 Mdot
.37284 .48333 Mdot
.59248 .4011 Mdot
.65112 .55029 Mdot
.73553 .64087 Mdot
.32298 .54656 Mdot
.63856 .5628 Mdot
.62203 .55837 Mdot
.4779 .3264 Mdot
.69793 .76759 Mdot
.29849 .51202 Mdot
.38319 .48725 Mdot
.21082 .51588 Mdot
.53327 .71564 Mdot
.37567 .48555 Mdot
.33267 .50085 Mdot
.60912 .54627 Mdot
.53626 .61437 Mdot
.41381 .62422 Mdot
.5937 .31017 Mdot
.63027 .58313 Mdot
.57862 .41046 Mdot
.59209 .39999 Mdot
.5041 .33018 Mdot
.52336 .68339 Mdot
.49007 .30834 Mdot
.61842 .39824 Mdot
.32902 .51844 Mdot
.61001 .55723 Mdot
.27709 .63648 Mdot
.59758 .52715 Mdot
.65944 .40209 Mdot
.50624 .73293 Mdot
.5894 .6502 Mdot
.23419 .70963 Mdot
.64297 .6785 Mdot
.61692 .50865 Mdot
.47311 .3449 Mdot
.56906 .34276 Mdot
.39515 .53281 Mdot
.34202 .63452 Mdot
.35649 .49094 Mdot
.42415 .79789 Mdot
.60467 .39889 Mdot
.78923 .4612 Mdot
.4117 .51575 Mdot
.37263 .3667 Mdot
.65016 .52599 Mdot
.60299 .57873 Mdot
.35974 .51469 Mdot
.63288 .53934 Mdot
.39579 .49379 Mdot
.6467 .37125 Mdot
.65471 .78833 Mdot
.39855 .52873 Mdot
.43471 .50174 Mdot
.57221 .56296 Mdot
.61863 .21821 Mdot
.60875 .34374 Mdot
.32875 .74571 Mdot
.20783 .34159 Mdot
.63067 .53931 Mdot
.41605 .46798 Mdot
.60707 .36345 Mdot
.75415 .44961 Mdot
.63459 .34371 Mdot
.3529 .49487 Mdot
.34424 .50534 Mdot
.3973 .54529 Mdot
.3821 .53692 Mdot
.33618 .63104 Mdot
.28395 .51939 Mdot
.33383 .73243 Mdot
.35911 .50487 Mdot
.54983 .74652 Mdot
.60954 .53468 Mdot
.55846 .70309 Mdot
.51709 .35723 Mdot
.33319 .51156 Mdot
.45444 .70191 Mdot
.65039 .57363 Mdot
.39287 .17369 Mdot
.60511 .57828 Mdot
.63327 .37463 Mdot
.59183 .54216 Mdot
.35237 .54177 Mdot
.51977 .69939 Mdot
.63573 .355 Mdot
.72438 .59741 Mdot
.64465 .39929 Mdot
.3377 .53334 Mdot
.47754 .24553 Mdot
.64125 .39783 Mdot
.50913 .45657 Mdot
.52318 .69623 Mdot
.39569 .34264 Mdot
.51053 .72275 Mdot
.36343 .5268 Mdot
.36742 .52847 Mdot
.78248 .44265 Mdot
.62684 .51872 Mdot
.47891 .70026 Mdot
.53937 .86168 Mdot
.49139 .3048 Mdot
.49746 .68746 Mdot
.33248 .57686 Mdot
.51868 .42638 Mdot
.50992 .7098 Mdot
.35799 .32938 Mdot
.64844 .54815 Mdot
.53876 .65991 Mdot
.3614 .58348 Mdot
.54791 .57954 Mdot
.47058 .35883 Mdot
.65493 .40369 Mdot
.54824 .53045 Mdot
.60798 .35836 Mdot
.65304 .57478 Mdot
.65212 .41574 Mdot
.59536 .55991 Mdot
.52079 .78278 Mdot
.44672 .65627 Mdot
.60202 .51963 Mdot
.65451 .57799 Mdot
.61844 .39237 Mdot
.33196 .55515 Mdot
.49573 .50766 Mdot
.3128 .5073 Mdot
.31437 .53881 Mdot
.59399 .56215 Mdot
.48202 .70193 Mdot
.47809 .6624 Mdot
.51964 .62666 Mdot
.5355 .67568 Mdot
.63894 .3655 Mdot
.67452 .72675 Mdot
.47102 .80695 Mdot
.62638 .57671 Mdot
.64843 .58944 Mdot
.38272 .54833 Mdot
.61507 .38634 Mdot
.60386 .40499 Mdot
.61365 .54656 Mdot
.30718 .64064 Mdot
.42919 .49541 Mdot
.51011 .72893 Mdot
.48547 .6591 Mdot
.50443 .70624 Mdot
.54145 .68462 Mdot
.42464 .67223 Mdot
.64997 .55261 Mdot
.48131 .6658 Mdot
.36274 .51862 Mdot
.34593 .50198 Mdot
.78256 .45921 Mdot
.51033 .33709 Mdot
.37068 .5785 Mdot
.44107 .51896 Mdot
.37583 .49698 Mdot
.63558 .40192 Mdot
.44726 .47996 Mdot
.77459 .4456 Mdot
.62992 .42074 Mdot
.57888 .394 Mdot
.78188 .4666 Mdot
.55195 .64317 Mdot
.21901 .31604 Mdot
.3714 .55369 Mdot
.46983 .50851 Mdot
.61951 .38354 Mdot
.69848 .73308 Mdot
.56725 .73631 Mdot
.37074 .56301 Mdot
.52447 .57095 Mdot
.64219 .35966 Mdot
.53597 .71546 Mdot
.36631 .4877 Mdot
.76758 .47006 Mdot
.47321 .31082 Mdot
.33283 .57808 Mdot
.75084 .45437 Mdot
.48646 .67334 Mdot
.44523 .29823 Mdot
.54292 .67374 Mdot
.64577 .36115 Mdot
.35902 .46046 Mdot
.42036 .12017 Mdot
.59494 .36838 Mdot
.52217 .19528 Mdot
.45492 .63788 Mdot
.40227 .52663 Mdot
.59832 .36435 Mdot
.53134 .72134 Mdot
.63228 .58629 Mdot
.49264 .4185 Mdot
.50559 .65828 Mdot
.78994 .453 Mdot
.77846 .46367 Mdot
.63743 .39536 Mdot
.53099 .68554 Mdot
.41683 .546 Mdot
.51985 .71577 Mdot
.59002 .54595 Mdot
.35002 .56121 Mdot
.29107 .25697 Mdot
.34553 .44852 Mdot
.4779 .68406 Mdot
.64296 .4149 Mdot
.47388 .35814 Mdot
.33013 .54797 Mdot
.4829 .21079 Mdot
.32644 .50611 Mdot
.60793 .57386 Mdot
.76642 .66688 Mdot
.26449 .61817 Mdot
.32604 .52588 Mdot
.38305 .54716 Mdot
.64616 .574 Mdot
.32574 .54193 Mdot
.32005 .51121 Mdot
.5834 .59661 Mdot
.52792 .70817 Mdot
.38793 .52026 Mdot
.61804 .41136 Mdot
.33185 .7675 Mdot
.36568 .48019 Mdot
.78589 .5622 Mdot
.38926 .35421 Mdot
.74756 .69483 Mdot
.38729 .48227 Mdot
.37924 .39919 Mdot
.37758 .52862 Mdot
.33758 .51676 Mdot
.37046 .5577 Mdot
.30785 .72227 Mdot
.61571 .39308 Mdot
.65129 .40117 Mdot
.47021 .3592 Mdot
.38723 .35176 Mdot
.50026 .34629 Mdot
.63086 .58116 Mdot
.72236 .30152 Mdot
.75754 .45081 Mdot
.4885 .66509 Mdot
.41824 .51706 Mdot
.64343 .35612 Mdot
.36965 .49286 Mdot
.35638 .54343 Mdot
.64658 .36575 Mdot
.58747 .38217 Mdot
.68215 .3701 Mdot
.45886 .3324 Mdot
.49773 .67033 Mdot
.38764 .56382 Mdot
.48155 .31612 Mdot
.41981 .54118 Mdot
.51364 .41185 Mdot
.49551 .67192 Mdot
.52265 .71484 Mdot
.47926 .70574 Mdot
.3287 .51773 Mdot
.34544 .54299 Mdot
.6121 .53533 Mdot
.50908 .64576 Mdot
.63781 .57438 Mdot
.61535 .35704 Mdot
.624 .34711 Mdot
.35228 .49529 Mdot
.32353 .59806 Mdot
.47949 .35181 Mdot
.63018 .37065 Mdot
.78714 .4679 Mdot
.46035 .34992 Mdot
.33296 .52799 Mdot
.62755 .35917 Mdot
.50866 .33002 Mdot
.32806 .66748 Mdot
.19183 .37085 Mdot
.48173 .35928 Mdot
.36186 .51541 Mdot
.33981 .76187 Mdot
.44117 .27795 Mdot
.48181 .30336 Mdot
.61945 .57342 Mdot
.32901 .50527 Mdot
.24391 .3831 Mdot
.50605 .31803 Mdot
.42848 .8091 Mdot
.64581 .3891 Mdot
.52215 .60529 Mdot
.3771 .58376 Mdot
.35983 .64595 Mdot
.48859 .30658 Mdot
.51318 .67959 Mdot
.49044 .64356 Mdot
.37436 .51345 Mdot
.51023 .36475 Mdot
.59376 .57245 Mdot
.64869 .38576 Mdot
.58879 .35526 Mdot
.53189 .69187 Mdot
.62243 .72358 Mdot
.62825 .41436 Mdot
.34727 .59979 Mdot
.66662 .3174 Mdot
.40137 .4442 Mdot
.5045 .7792 Mdot
.71345 .60116 Mdot
.39957 .47814 Mdot
.48196 .35765 Mdot
.65648 .55316 Mdot
.62153 .5328 Mdot
.63887 .54626 Mdot
.5984 .35379 Mdot
.52634 .48236 Mdot
.60214 .37966 Mdot
.73249 .6318 Mdot
.48331 .323 Mdot
.40007 .31724 Mdot
.41072 .49481 Mdot
.39761 .53048 Mdot
.42379 .53898 Mdot
.41343 .53233 Mdot
.38098 .52817 Mdot
.64537 .54531 Mdot
.58714 .36494 Mdot
.6067 .27717 Mdot
.49491 .69637 Mdot
.70491 .3947 Mdot
.61319 .381 Mdot
.75453 .4504 Mdot
.47927 .33944 Mdot
.3695 .40865 Mdot
.61478 .42404 Mdot
.61598 .37584 Mdot
.36747 .57507 Mdot
.49877 .71604 Mdot
.27436 .54873 Mdot
.3726 .53145 Mdot
.62846 .36849 Mdot
.55325 .37727 Mdot
.26943 .58563 Mdot
.44013 .55247 Mdot
.45422 .30355 Mdot
.5207 .43104 Mdot
.45852 .31559 Mdot
.42854 .55163 Mdot
.70345 .72927 Mdot
.61949 .39785 Mdot
.63669 .38113 Mdot
.51153 .34977 Mdot
.4328 .58917 Mdot
.52822 .68696 Mdot
.78971 .46135 Mdot
.60606 .56689 Mdot
.36329 .53313 Mdot
.60594 .35167 Mdot
.45082 .59248 Mdot
.64537 .29813 Mdot
.64104 .55249 Mdot
.62755 .42064 Mdot
.32382 .51589 Mdot
.36221 .51344 Mdot
.46649 .33734 Mdot
.4753 .50732 Mdot
.31673 .56345 Mdot
.49335 .1788 Mdot
.65741 .72601 Mdot
.61311 .75756 Mdot
.37906 .49527 Mdot
.53318 .6946 Mdot
.76758 .46853 Mdot
.46881 .32151 Mdot
.40132 .56174 Mdot
.19565 .35896 Mdot
.46991 .66764 Mdot
.63054 .56022 Mdot
.77237 .46946 Mdot
.52496 .48073 Mdot
.32833 .50386 Mdot
.35729 .49066 Mdot
.34865 .51964 Mdot
.16916 .38962 Mdot
.63669 .41098 Mdot
.54169 .69381 Mdot
.49532 .33599 Mdot
.53991 .68696 Mdot
.64889 .40061 Mdot
.59185 .71492 Mdot
.33213 .53602 Mdot
.51042 .73055 Mdot
.51495 .68262 Mdot
.60639 .58053 Mdot
.61693 .58758 Mdot
.68396 .37158 Mdot
.40719 .49738 Mdot
.76355 .46974 Mdot
.51447 .72192 Mdot
.58396 .38519 Mdot
.46692 .33201 Mdot
.62986 .5256 Mdot
.35798 .50573 Mdot
.62762 .39874 Mdot
.39198 .46589 Mdot
.50742 .71298 Mdot
.61605 .37667 Mdot
.75646 .46973 Mdot
.49321 .35342 Mdot
.34968 .50523 Mdot
.47065 .2937 Mdot
.78395 .46724 Mdot
.39438 .53617 Mdot
.27069 .46393 Mdot
.53249 .33843 Mdot
.73085 .59214 Mdot
.59769 .37819 Mdot
.77843 .45198 Mdot
.52418 .71721 Mdot
.56484 .62855 Mdot
.6392 .37876 Mdot
.31725 .42861 Mdot
.4848 .52984 Mdot
.38275 .5654 Mdot
.50899 .70011 Mdot
.55673 .34795 Mdot
.44403 .18564 Mdot
.43024 .26906 Mdot
.39681 .52087 Mdot
.60019 .36271 Mdot
.50584 .32479 Mdot
.62414 .57757 Mdot
.78735 .56327 Mdot
.44399 .69445 Mdot
.64837 .41831 Mdot
.37476 .5543 Mdot
.51314 .72169 Mdot
.61479 .5474 Mdot
.65157 .63444 Mdot
.61154 .41492 Mdot
.60104 .3956 Mdot
.33001 .52952 Mdot
.49377 .32514 Mdot
.37886 .26801 Mdot
.65353 .39857 Mdot
.60219 .35502 Mdot
.7087 .38083 Mdot
.51115 .35306 Mdot
.37013 .5177 Mdot
.51833 .6263 Mdot
.33903 .56488 Mdot
.52632 .19257 Mdot
.77386 .4468 Mdot
.49341 .69614 Mdot
.34236 .50058 Mdot
.63047 .30971 Mdot
.63693 .36962 Mdot
.52676 .44176 Mdot
.66157 .40459 Mdot
.64611 .54414 Mdot
.60815 .35053 Mdot
.36952 .48874 Mdot
.65066 .526 Mdot
.48253 .3522 Mdot
.40998 .5105 Mdot
.34556 .54413 Mdot
.53116 .72402 Mdot
.62661 .56667 Mdot
.23148 .64358 Mdot
.65856 .57711 Mdot
.65393 .56658 Mdot
.51396 .63744 Mdot
.37936 .51221 Mdot
.62914 .37528 Mdot
.65947 .39511 Mdot
.40375 .55878 Mdot
.67866 .74245 Mdot
.52967 .69091 Mdot
.68552 .37146 Mdot
.15966 .46407 Mdot
.36268 .59565 Mdot
.77038 .47384 Mdot
.46656 .48974 Mdot
.61303 .58519 Mdot
.35903 .51002 Mdot
.47904 .68365 Mdot
.59395 .36235 Mdot
.62697 .41404 Mdot
.41445 .55435 Mdot
.61734 .55558 Mdot
.48962 .31115 Mdot
.59832 .39604 Mdot
.65973 .30442 Mdot
.34995 .52452 Mdot
.74903 .61617 Mdot
.59441 .3874 Mdot
.55364 .17607 Mdot
.61956 .28678 Mdot
.50575 .70192 Mdot
.35607 .54537 Mdot
.52268 .65996 Mdot
.49425 .34157 Mdot
.57078 .38911 Mdot
.62001 .55923 Mdot
.44451 .55088 Mdot
.29148 .75288 Mdot
.61265 .39022 Mdot
.49044 .66778 Mdot
.32566 .5247 Mdot
.39461 .59253 Mdot
.3889 .48693 Mdot
.54115 .61949 Mdot
.52638 .31917 Mdot
.59405 .56457 Mdot
.61015 .57415 Mdot
.3929 .54344 Mdot
.46422 .32067 Mdot
.65466 .37756 Mdot
.64741 .38387 Mdot
.88229 .53011 Mdot
.75594 .46994 Mdot
.33728 .37114 Mdot
.34563 .50644 Mdot
.58273 .38669 Mdot
.33154 .7604 Mdot
.63607 .56964 Mdot
.41413 .53526 Mdot
.57892 .37899 Mdot
.64237 .46668 Mdot
.51201 .41423 Mdot
.37681 .52328 Mdot
.31254 .57804 Mdot
.60765 .56931 Mdot
.49154 .39673 Mdot
.60347 .37678 Mdot
.41047 .5441 Mdot
.66089 .57346 Mdot
.70641 .3417 Mdot
.38327 .81354 Mdot
.49758 .67088 Mdot
.66121 .40116 Mdot
.64619 .54634 Mdot
.31399 .56436 Mdot
.50493 .32907 Mdot
.61936 .35332 Mdot
.63937 .40293 Mdot
.35158 .55776 Mdot
.34329 .57214 Mdot
.3662 .59543 Mdot
.48972 .6819 Mdot
.60303 .54593 Mdot
.41293 .52003 Mdot
.62726 .72414 Mdot
.39944 .54476 Mdot
.6059 .54334 Mdot
.57171 .10758 Mdot
.32797 .55598 Mdot
.39029 .48818 Mdot
.3973 .26477 Mdot
.50961 .65755 Mdot
.53874 .68424 Mdot
.66287 .72774 Mdot
.34602 .50631 Mdot
.64538 .27528 Mdot
.50004 .66837 Mdot
.52826 .69534 Mdot
.53508 .2569 Mdot
.35617 .56354 Mdot
.51033 .389 Mdot
.61368 .54028 Mdot
.64003 .52976 Mdot
.5235 .71216 Mdot
.31358 .56136 Mdot
.65226 .56023 Mdot
.37732 .63345 Mdot
.60968 .38231 Mdot
.7062 .72727 Mdot
.4985 .71169 Mdot
.47666 .47463 Mdot
.6406 .56361 Mdot
.4006 .1687 Mdot
.53583 .56207 Mdot
.39081 .55098 Mdot
.34981 .51019 Mdot
.49289 .35131 Mdot
.31908 .48207 Mdot
.78505 .44825 Mdot
.63398 .53947 Mdot
.35199 .26011 Mdot
.49633 .68029 Mdot
.40351 .49458 Mdot
.3509 .41133 Mdot
.65616 .64334 Mdot
.78171 .59072 Mdot
.52034 .67677 Mdot
.50629 .69491 Mdot
.60422 .38955 Mdot
.61762 .40333 Mdot
.3793 .51821 Mdot
.62782 .53163 Mdot
.51874 .64419 Mdot
.6021 .56 Mdot
.61981 .39895 Mdot
.6209 .37663 Mdot
.76229 .44622 Mdot
.35959 .47206 Mdot
.64855 .36982 Mdot
.69767 .32115 Mdot
.61681 .72863 Mdot
.54003 .71715 Mdot
.2198 .67716 Mdot
.65287 .6322 Mdot
.31204 .32225 Mdot
.45794 .32119 Mdot
.80245 .46095 Mdot
.60231 .53072 Mdot
.3858 .54572 Mdot
.36115 .4986 Mdot
.76879 .46022 Mdot
.61458 .51768 Mdot
.47736 .3426 Mdot
.6227 .51756 Mdot
.48471 .32076 Mdot
.62574 .34394 Mdot
.36689 .48021 Mdot
.3413 .49458 Mdot
.64408 .54497 Mdot
.61695 .36677 Mdot
.64965 .37781 Mdot
.45627 .32992 Mdot
.4052 .40461 Mdot
.63575 .3968 Mdot
.50075 .71277 Mdot
.43298 .73464 Mdot
.77667 .46366 Mdot
.36924 .48691 Mdot
.30891 .42224 Mdot
.30221 .62632 Mdot
.39027 .56047 Mdot
.77499 .46984 Mdot
.86054 .58084 Mdot
.40881 .4945 Mdot
.82045 .64021 Mdot
.78108 .45333 Mdot
.51068 .65684 Mdot
.59644 .37044 Mdot
.78536 .44723 Mdot
.34522 .58511 Mdot
.46573 .30376 Mdot
.40129 .57001 Mdot
.50912 .65945 Mdot
.48796 .71875 Mdot
.59125 .78442 Mdot
.52757 .1936 Mdot
.46108 .34307 Mdot
.47425 .3328 Mdot
.64056 .38094 Mdot
.74221 .285 Mdot
.36366 .58264 Mdot
.47185 .33495 Mdot
.34028 .27533 Mdot
.37748 .54911 Mdot
.33958 .38319 Mdot
.52383 .56654 Mdot
.53256 .69466 Mdot
.56042 .66796 Mdot
.63957 .37405 Mdot
.49119 .66771 Mdot
.59714 .74727 Mdot
.4232 .54102 Mdot
.49502 .67471 Mdot
.60591 .54665 Mdot
.70956 .50337 Mdot
.52665 .66656 Mdot
.47929 .41049 Mdot
.61705 .53844 Mdot
.53317 .32556 Mdot
.37184 .28737 Mdot
.16482 .64484 Mdot
.63361 .53774 Mdot
.61603 .36104 Mdot
.64586 .36195 Mdot
.64575 .38445 Mdot
.50385 .65736 Mdot
.60282 .40706 Mdot
.48742 .68772 Mdot
.49501 .22438 Mdot
.36354 .40524 Mdot
.47336 .3251 Mdot
.58622 .58398 Mdot
.51202 .69021 Mdot
.70449 .67995 Mdot
.23832 .71006 Mdot
.35853 .51554 Mdot
.65968 .5753 Mdot
.5104 .35035 Mdot
.67927 .21439 Mdot
.49159 .35049 Mdot
.60566 .36443 Mdot
.7131 .7215 Mdot
.39916 .49631 Mdot
.23652 .53764 Mdot
.48585 .35471 Mdot
.51723 .67025 Mdot
.39595 .53434 Mdot
.67174 .38806 Mdot
.5028 .33057 Mdot
.47841 .3104 Mdot
.38745 .52804 Mdot
.53053 .67574 Mdot
.62457 .37481 Mdot
.60719 .52839 Mdot
.52471 .32862 Mdot
.3022 .55301 Mdot
.35805 .56982 Mdot
.42218 .49363 Mdot
.53633 .46444 Mdot
.27375 .33661 Mdot
.62916 .53911 Mdot
.41973 .32032 Mdot
.62478 .40406 Mdot
.53402 .30654 Mdot
.67195 .68989 Mdot
.57855 .56693 Mdot
.77568 .44734 Mdot
.7676 .44617 Mdot
.37984 .52476 Mdot
.28205 .32749 Mdot
.7994 .61056 Mdot
.57352 .5419 Mdot
.77343 .46557 Mdot
.64901 .38257 Mdot
.48565 .64652 Mdot
.56762 .78511 Mdot
.32424 .55862 Mdot
.60218 .5807 Mdot
.63272 .39956 Mdot
.25676 .32553 Mdot
.48608 .32632 Mdot
.69957 .71899 Mdot
.33485 .53529 Mdot
.4036 .51477 Mdot
.62419 .54588 Mdot
.61368 .53475 Mdot
.77202 .58091 Mdot
.62082 .76066 Mdot
.56481 .42474 Mdot
.62833 .61748 Mdot
.23213 .35746 Mdot
.55919 .69538 Mdot
.47917 .69002 Mdot
.75008 .4599 Mdot
.65755 .5434 Mdot
.36051 .48831 Mdot
.49662 .65238 Mdot
.78182 .59314 Mdot
.46086 .67794 Mdot
.35369 .37617 Mdot
.65311 .28675 Mdot
.34936 .53717 Mdot
.50525 .71863 Mdot
.49263 .66864 Mdot
.53828 .66716 Mdot
.77973 .46771 Mdot
.38149 .4978 Mdot
.32992 .55224 Mdot
.40895 .52451 Mdot
.28892 .54102 Mdot
.35316 .52564 Mdot
.65957 .69472 Mdot
.60436 .48131 Mdot
.36481 .24851 Mdot
.38929 .55892 Mdot
.64427 .53384 Mdot
.4198 .50562 Mdot
.4669 .31736 Mdot
.37632 .5544 Mdot
.33844 .37699 Mdot
.6348 .55308 Mdot
.43291 .58683 Mdot
.62008 .6196 Mdot
.33497 .53702 Mdot
.50464 .31955 Mdot
.29455 .32163 Mdot
.22916 .65248 Mdot
.70461 .3877 Mdot
.50294 .71365 Mdot
.61368 .42223 Mdot
.58847 .55001 Mdot
.63004 .3775 Mdot
.39713 .55104 Mdot
.75691 .46756 Mdot
.70449 .57307 Mdot
.47995 .47784 Mdot
.34612 .49463 Mdot
.41657 .45935 Mdot
.52068 .70795 Mdot
.62378 .35944 Mdot
.5255 .74436 Mdot
.34218 .51669 Mdot
.49754 .33505 Mdot
.49644 .32402 Mdot
.62797 .74607 Mdot
.29224 .27156 Mdot
.5698 .65532 Mdot
.62507 .54378 Mdot
.64064 .41411 Mdot
.49221 .30796 Mdot
.44334 .66326 Mdot
.59668 .57802 Mdot
.61177 .58472 Mdot
.61904 .56425 Mdot
.3575 .53561 Mdot
.77999 .44679 Mdot
.31347 .28044 Mdot
.78907 .45113 Mdot
.33715 .53999 Mdot
.63693 .40741 Mdot
.78233 .44455 Mdot
.50074 .34878 Mdot
.62964 .57963 Mdot
.61449 .39919 Mdot
.36171 .52808 Mdot
.50273 .67378 Mdot
.42502 .40735 Mdot
.28198 .38587 Mdot
.45648 .22339 Mdot
.45027 .22471 Mdot
.47354 .68543 Mdot
.3667 .20112 Mdot
.64187 .59799 Mdot
.30799 .63988 Mdot
.44021 .34217 Mdot
.40898 .55502 Mdot
.59692 .81029 Mdot
.6031 .37483 Mdot
.63931 .36074 Mdot
.37235 .52263 Mdot
.58602 .37935 Mdot
.3994 .49071 Mdot
.60769 .39928 Mdot
.69891 .37625 Mdot
.31548 .54918 Mdot
.64027 .36338 Mdot
.41063 .5717 Mdot
.33228 .55019 Mdot
.52981 .70353 Mdot
.61034 .3542 Mdot
.40024 .54588 Mdot
.74228 .27042 Mdot
.6224 .52814 Mdot
.78036 .46664 Mdot
.5801 .45517 Mdot
.64852 .55249 Mdot
.49773 .6917 Mdot
.30923 .52743 Mdot
.46951 .34538 Mdot
.5105 .67905 Mdot
.68373 .36969 Mdot
.48984 .3557 Mdot
.67515 .72496 Mdot
.50818 .71498 Mdot
.77609 .46173 Mdot
.47931 .35239 Mdot
.4132 .45988 Mdot
.63018 .35057 Mdot
.24978 .4211 Mdot
.78891 .45516 Mdot
.37877 .49071 Mdot
.60192 .34426 Mdot
.64152 .52794 Mdot
.39271 .51322 Mdot
.59557 .36614 Mdot
.7804 .46831 Mdot
.36524 .53911 Mdot
.38612 .53922 Mdot
.54387 .78102 Mdot
.76737 .63422 Mdot
.46722 .33653 Mdot
.5225 .72328 Mdot
.36291 .51929 Mdot
.45863 .32921 Mdot
.75378 .35698 Mdot
.41093 .48134 Mdot
.51393 .65414 Mdot
.28426 .46249 Mdot
.62128 .40549 Mdot
.63758 .57493 Mdot
.66194 .39715 Mdot
.47029 .31136 Mdot
.57919 .85655 Mdot
.77092 .44341 Mdot
.41305 .57319 Mdot
.42041 .53538 Mdot
.5605 .36747 Mdot
.49122 .67261 Mdot
.55275 .41479 Mdot
.34966 .50567 Mdot
.34113 .44912 Mdot
.40654 .5071 Mdot
.61743 .2821 Mdot
.52885 .68985 Mdot
.38352 .48773 Mdot
.30944 .59114 Mdot
.35069 .48279 Mdot
.49861 .31448 Mdot
.3961 .29854 Mdot
.41657 .48851 Mdot
.35678 .14405 Mdot
.78433 .46867 Mdot
.6471 .36793 Mdot
.61711 .43913 Mdot
.81606 .38702 Mdot
.51604 .78483 Mdot
.48794 .68413 Mdot
.36682 .43246 Mdot
.62722 .3759 Mdot
.37936 .80292 Mdot
.40133 .18218 Mdot
.33284 .54891 Mdot
.3265 .51208 Mdot
.60567 .3644 Mdot
.58323 .3829 Mdot
.75334 .46146 Mdot
.38778 .55712 Mdot
.44299 .48387 Mdot
.63056 .41949 Mdot
.34796 .53006 Mdot
.26214 .50673 Mdot
.60334 .53359 Mdot
.53456 .70242 Mdot
.62509 .57781 Mdot
.59787 .57325 Mdot
.40116 .68122 Mdot
.65618 .72699 Mdot
.6067 .54062 Mdot
.66803 .56515 Mdot
.32676 .38378 Mdot
.33009 .42903 Mdot
.48775 .30895 Mdot
.38243 .21846 Mdot
.64224 .38692 Mdot
.38185 .49932 Mdot
.47525 .68172 Mdot
.36922 .65469 Mdot
.70639 .45447 Mdot
.73832 .69535 Mdot
.33855 .51183 Mdot
.64211 .37364 Mdot
.78539 .46422 Mdot
.31839 .55429 Mdot
.51038 .28575 Mdot
.40099 .51774 Mdot
.64227 .35556 Mdot
.44717 .74299 Mdot
.25447 .49689 Mdot
.60596 .3265 Mdot
.54193 .66061 Mdot
.41471 .50948 Mdot
.49346 .70445 Mdot
.6428 .55983 Mdot
.46111 .32532 Mdot
.47015 .34093 Mdot
.3924 .5345 Mdot
.44551 .66193 Mdot
.51868 .57057 Mdot
.33012 .54586 Mdot
.35294 .56012 Mdot
.77965 .45225 Mdot
.35235 .56054 Mdot
.41946 .53798 Mdot
.41207 .5292 Mdot
.37922 .47464 Mdot
.65473 .56477 Mdot
.25696 .48459 Mdot
.39659 .46979 Mdot
.41194 .5803 Mdot
.61203 .52875 Mdot
.40882 .44062 Mdot
.60139 .57443 Mdot
.28854 .26057 Mdot
.60214 .57052 Mdot
.4689 .33539 Mdot
.59244 .34868 Mdot
.34302 .44442 Mdot
.52155 .64348 Mdot
.63815 .58507 Mdot
.48752 .33668 Mdot
.63686 .54267 Mdot
.63293 .41225 Mdot
.19503 .58496 Mdot
.46086 .67909 Mdot
.50161 .40368 Mdot
.54187 .59169 Mdot
.75233 .61176 Mdot
.60691 .38722 Mdot
.53016 .697 Mdot
.23663 .54608 Mdot
.40735 .53464 Mdot
.48989 .35284 Mdot
.38302 .52496 Mdot
.65114 .5704 Mdot
.64402 .37853 Mdot
.459 .23697 Mdot
.4692 .34237 Mdot
.38283 .82214 Mdot
.64837 .39072 Mdot
.32095 .544 Mdot
.60721 .5847 Mdot
.22209 .68135 Mdot
.60458 .57382 Mdot
.3493 .40815 Mdot
.5101 .73689 Mdot
.48336 .79081 Mdot
.51199 .69725 Mdot
.79861 .57121 Mdot
.17426 .35629 Mdot
.45464 .19841 Mdot
.50794 .66775 Mdot
.65585 .31852 Mdot
.33748 .53037 Mdot
.41977 .49644 Mdot
.36031 .59861 Mdot
.53859 .7143 Mdot
.35831 .52099 Mdot
.78618 .45466 Mdot
.59936 .71832 Mdot
.54505 .30361 Mdot
.62095 .42361 Mdot
.38031 .48532 Mdot
.60925 .53121 Mdot
.62458 .51689 Mdot
.7856 .44642 Mdot
.59047 .55789 Mdot
.33938 .55943 Mdot
.51248 .69289 Mdot
.48744 .50922 Mdot
.49595 .34532 Mdot
.64383 .21681 Mdot
.52089 .34798 Mdot
.66076 .41501 Mdot
.36306 .45983 Mdot
.61996 .3764 Mdot
.71202 .78905 Mdot
.398 .5433 Mdot
.4992 .66595 Mdot
.37884 .53869 Mdot
.41531 .51842 Mdot
.42057 .49798 Mdot
.61363 .4146 Mdot
.57769 .42056 Mdot
.35211 .53048 Mdot
.62063 .56055 Mdot
.41201 .2299 Mdot
.4168 .55907 Mdot
.67017 .33881 Mdot
.37644 .34967 Mdot
.72857 .63866 Mdot
.54427 .71122 Mdot
.6214 .36078 Mdot
.49935 .68561 Mdot
.52893 .64238 Mdot
.49757 .69162 Mdot
.31958 .27011 Mdot
.33955 .61453 Mdot
.85864 .56915 Mdot
.45007 .7904 Mdot
.34727 .66177 Mdot
.5006 .72668 Mdot
.76775 .39401 Mdot
.48059 .67341 Mdot
.49131 .68664 Mdot
.78826 .26724 Mdot
.483 .66534 Mdot
.35416 .49536 Mdot
.35331 .57323 Mdot
.64121 .67093 Mdot
.32056 .39548 Mdot
.37738 .55667 Mdot
.36715 .52034 Mdot
.46026 .33161 Mdot
.38355 .61236 Mdot
.74967 .45048 Mdot
.67269 .73804 Mdot
.68486 .5947 Mdot
.38584 .52798 Mdot
.36412 .52258 Mdot
.3004 .53085 Mdot
.14967 .38465 Mdot
.3901 .64954 Mdot
.47607 .7027 Mdot
.41483 .45634 Mdot
.5697 .19075 Mdot
.31963 .53377 Mdot
.34069 .49401 Mdot
.35785 .54093 Mdot
.62842 .37534 Mdot
.47696 .65234 Mdot
.41097 .45511 Mdot
.71688 .635 Mdot
.33273 .53084 Mdot
.59621 .59156 Mdot
.52287 .31989 Mdot
.36743 .48974 Mdot
.53904 .6745 Mdot
.36846 .55243 Mdot
.50019 .7148 Mdot
.52736 .70987 Mdot
.2983 .52016 Mdot
.30279 .2806 Mdot
.52421 .65734 Mdot
.34229 .5416 Mdot
.62119 .36596 Mdot
.45292 .189 Mdot
.375 .49066 Mdot
.47405 .31822 Mdot
.34907 .50841 Mdot
.50328 .31954 Mdot
.34072 .55244 Mdot
.78972 .45367 Mdot
.25757 .60532 Mdot
.63733 .38259 Mdot
.45399 .37564 Mdot
.58715 .39626 Mdot
.54867 .77719 Mdot
.50861 .65437 Mdot
.74577 .45868 Mdot
.70762 .74884 Mdot
.77962 .45394 Mdot
.42745 .40967 Mdot
.71298 .42299 Mdot
.63421 .53138 Mdot
.5403 .69537 Mdot
.42365 .35229 Mdot
.66762 .33122 Mdot
.67927 .38931 Mdot
.5803 .3971 Mdot
.60066 .83623 Mdot
.6682 .78178 Mdot
.36043 .53167 Mdot
.21462 .46054 Mdot
.33383 .72545 Mdot
.37933 .47825 Mdot
.31037 .51808 Mdot
.63761 .35074 Mdot
.41138 .49713 Mdot
.51769 .4639 Mdot
.61758 .39187 Mdot
.48158 .33506 Mdot
.49229 .69625 Mdot
.50193 .3199 Mdot
.6515 .34957 Mdot
.59265 .48759 Mdot
.6204 .40172 Mdot
.39706 .47498 Mdot
.37645 .53431 Mdot
.51486 .71868 Mdot
.46187 .71938 Mdot
.53221 .70474 Mdot
.50173 .35548 Mdot
.62719 .39275 Mdot
.37194 .64496 Mdot
.36417 .50936 Mdot
.51652 .68467 Mdot
.64789 .50458 Mdot
.3615 .51308 Mdot
.64438 .55036 Mdot
.32827 .52212 Mdot
.50915 .66462 Mdot
.35139 .5603 Mdot
.51085 .69332 Mdot
.60767 .37114 Mdot
.32024 .52848 Mdot
.37319 .52105 Mdot
.26098 .71393 Mdot
.47905 .3439 Mdot
.5088 .65489 Mdot
.53752 .51479 Mdot
.32658 .552 Mdot
.54255 .33543 Mdot
.38424 .4824 Mdot
.33336 .4343 Mdot
.41905 .5645 Mdot
.78481 .45666 Mdot
.40651 .46829 Mdot
.37667 .49012 Mdot
.24034 .51534 Mdot
.3865 .77206 Mdot
.52133 .74703 Mdot
.64429 .57892 Mdot
.53938 .67781 Mdot
.62226 .3475 Mdot
.59164 .36161 Mdot
.59697 .39839 Mdot
.32777 .40235 Mdot
.30626 .54665 Mdot
.39719 .49543 Mdot
.63608 .58778 Mdot
.47568 .33015 Mdot
.51868 .67679 Mdot
.47797 .32615 Mdot
.66631 .74119 Mdot
.50211 .35446 Mdot
.78337 .44687 Mdot
.62026 .28797 Mdot
.31151 .62191 Mdot
.46095 .3349 Mdot
.53323 .70356 Mdot
.64791 .29053 Mdot
.40969 .55227 Mdot
.69004 .4034 Mdot
.49757 .33361 Mdot
.55395 .85779 Mdot
.37707 .48173 Mdot
.5041 .42792 Mdot
.5967 .55037 Mdot
.50741 .33516 Mdot
.63041 .56721 Mdot
.38742 .54836 Mdot
.73555 .58856 Mdot
.49026 .66584 Mdot
.65815 .53933 Mdot
.40983 .47198 Mdot
.50475 .32493 Mdot
.63738 .3993 Mdot
.55673 .59006 Mdot
.64319 .53342 Mdot
.21681 .56902 Mdot
.43114 .26887 Mdot
.62473 .39256 Mdot
.82372 .58052 Mdot
.6165 .56807 Mdot
.39368 .47758 Mdot
.30103 .47459 Mdot
.37376 .56163 Mdot
.59966 .35166 Mdot
.62767 .35974 Mdot
.61407 .70187 Mdot
.37602 .5373 Mdot
.37954 .48194 Mdot
.46578 .68386 Mdot
.61298 .38683 Mdot
.5168 .70438 Mdot
.54064 .67106 Mdot
.61282 .36236 Mdot
.50776 .70287 Mdot
.48978 .35462 Mdot
.5899 .68324 Mdot
.61493 .56751 Mdot
.6244 .5596 Mdot
.64852 .38266 Mdot
.65554 .39631 Mdot
.61786 .3774 Mdot
.32841 .52251 Mdot
.52443 .67878 Mdot
.35546 .5487 Mdot
.41394 .4821 Mdot
.53519 .73184 Mdot
.48579 .65766 Mdot
.3659 .54777 Mdot
.55721 .34983 Mdot
.51394 .31446 Mdot
.64015 .3648 Mdot
.60152 .55757 Mdot
.38199 .80138 Mdot
.61923 .58867 Mdot
.38356 .48462 Mdot
.64906 .46164 Mdot
.51457 .66505 Mdot
.49373 .35067 Mdot
.53415 .3446 Mdot
.48199 .35079 Mdot
.59627 .51152 Mdot
.52837 .65058 Mdot
.67459 .72378 Mdot
.39337 .48717 Mdot
.53607 .46645 Mdot
.41985 .33549 Mdot
.68075 .68222 Mdot
.60474 .54551 Mdot
.3633 .51698 Mdot
.77934 .45591 Mdot
.27375 .59182 Mdot
.40092 .51423 Mdot
.40818 .5422 Mdot
.57865 .25098 Mdot
.41029 .58163 Mdot
.53424 .72325 Mdot
.59685 .78181 Mdot
.37572 .57259 Mdot
.51332 .61904 Mdot
.86441 .44096 Mdot
.3975 .4861 Mdot
.34534 .52109 Mdot
.37067 .4981 Mdot
.37917 .54638 Mdot
.52304 .73486 Mdot
.4451 .39706 Mdot
.6111 .58574 Mdot
.55764 .47271 Mdot
.61116 .56041 Mdot
.63143 .35283 Mdot
.50273 .43237 Mdot
.53876 .69793 Mdot
.48878 .35185 Mdot
.20486 .51967 Mdot
.63934 .76275 Mdot
.60421 .38846 Mdot
.4161 .65959 Mdot
.49689 .34189 Mdot
.40578 .55721 Mdot
.48972 .36302 Mdot
.58237 .38371 Mdot
.61413 .54994 Mdot
.35268 .57255 Mdot
.48029 .70158 Mdot
.52608 .6654 Mdot
.35832 .51699 Mdot
.52401 .18789 Mdot
.64573 .55911 Mdot
.62894 .48521 Mdot
.35475 .53612 Mdot
.40723 .54326 Mdot
.50891 .70891 Mdot
.63388 .36569 Mdot
.72986 .37104 Mdot
.48242 .3411 Mdot
.32186 .4918 Mdot
.37761 .55035 Mdot
.65 .7461 Mdot
.63179 .58047 Mdot
.75905 .46413 Mdot
.36193 .53619 Mdot
.65125 .73118 Mdot
.36382 .53711 Mdot
.31658 .48262 Mdot
.62041 .37146 Mdot
.42443 .54504 Mdot
.33017 .51161 Mdot
.46757 .5111 Mdot
.62268 .57034 Mdot
.49529 .6697 Mdot
.48027 .72013 Mdot
.76791 .47019 Mdot
.64334 .54894 Mdot
.36759 .54931 Mdot
.6438 .57377 Mdot
.41946 .49296 Mdot
.35368 .5287 Mdot
.60507 .54567 Mdot
.51626 .70458 Mdot
.69024 .54154 Mdot
.31365 .4284 Mdot
.37845 .54356 Mdot
.35934 .57046 Mdot
.33193 .39647 Mdot
.76842 .69329 Mdot
.33998 .50571 Mdot
.51423 .66176 Mdot
.36677 .51384 Mdot
.6368 .56165 Mdot
.50794 .35087 Mdot
.5044 .6692 Mdot
.65336 .38954 Mdot
.60536 .37076 Mdot
.61053 .62072 Mdot
.77854 .4445 Mdot
.34815 .56823 Mdot
.52487 .75223 Mdot
.4772 .66908 Mdot
.7886 .32076 Mdot
.64391 .36082 Mdot
.50414 .31706 Mdot
.38821 .54036 Mdot
.55158 .5743 Mdot
.63054 .58723 Mdot
.35365 .14506 Mdot
.67628 .71478 Mdot
.4784 .36591 Mdot
.73223 .70894 Mdot
.77433 .45836 Mdot
.33791 .49889 Mdot
.4625 .32125 Mdot
.59713 .38086 Mdot
.42007 .51596 Mdot
.33182 .58625 Mdot
.55185 .41833 Mdot
.58577 .41529 Mdot
.64185 .57397 Mdot
.60962 .40405 Mdot
.45398 .343 Mdot
.78417 .44746 Mdot
.53551 .68166 Mdot
.38398 .48956 Mdot
.31366 .46927 Mdot
.64673 .3722 Mdot
.7905 .45446 Mdot
.34912 .5376 Mdot
.52897 .66649 Mdot
.58749 .38392 Mdot
.39044 .52845 Mdot
.32061 .64474 Mdot
.54127 .65361 Mdot
.63524 .39392 Mdot
.42003 .53216 Mdot
.30253 .45693 Mdot
.65142 .38697 Mdot
.65016 .37329 Mdot
.35883 .52117 Mdot
.48452 .35372 Mdot
.32331 .51119 Mdot
.59608 .56391 Mdot
.5787 .42178 Mdot
.63512 .56 Mdot
.44166 .28754 Mdot
.36303 .46214 Mdot
.76181 .61001 Mdot
.51743 .7216 Mdot
.44998 .32423 Mdot
.26629 .69402 Mdot
.40344 .54948 Mdot
.34369 .22592 Mdot
.47618 .46819 Mdot
.65825 .21168 Mdot
.17509 .40431 Mdot
.49292 .32974 Mdot
.63898 .54575 Mdot
.34612 .52077 Mdot
.64528 .5912 Mdot
.46327 .32903 Mdot
.42457 .30889 Mdot
.41894 .53503 Mdot
.52836 .69315 Mdot
.33562 .53264 Mdot
.50178 .71345 Mdot
.35969 .51156 Mdot
.4338 .55301 Mdot
.44054 .32391 Mdot
.34401 .40945 Mdot
.40775 .5546 Mdot
.19257 .58285 Mdot
.54672 .54699 Mdot
.49473 .33828 Mdot
.34909 .54559 Mdot
.76222 .4565 Mdot
.60929 .51917 Mdot
.2556 .36795 Mdot
.62449 .3762 Mdot
.6053 .53901 Mdot
.50072 .70335 Mdot
.65939 .3847 Mdot
.77923 .47015 Mdot
.3044 .47684 Mdot
.49405 .31428 Mdot
.63524 .53324 Mdot
.37292 .48958 Mdot
.37346 .48262 Mdot
.61825 .31835 Mdot
.77611 .51379 Mdot
.47222 .65502 Mdot
.33451 .78995 Mdot
.53202 .72929 Mdot
.47364 .33793 Mdot
.61928 .37306 Mdot
.34398 .49976 Mdot
.39444 .51815 Mdot
.5993 .35468 Mdot
.50596 .65544 Mdot
.6024 .42829 Mdot
.41049 .67649 Mdot
.64842 .41463 Mdot
.39689 .37017 Mdot
.50279 .66383 Mdot
.39825 .37472 Mdot
.45302 .3415 Mdot
.27644 .29717 Mdot
.31623 .34568 Mdot
.59658 .54901 Mdot
.39711 .36523 Mdot
.51558 .66989 Mdot
.36894 .53188 Mdot
.77359 .46191 Mdot
.76487 .44566 Mdot
.49703 .7043 Mdot
.60553 .36337 Mdot
.50516 .33132 Mdot
.34517 .52336 Mdot
.71789 .68274 Mdot
.63039 .64623 Mdot
.64275 .41352 Mdot
.28879 .56586 Mdot
.6258 .56577 Mdot
.33228 .51526 Mdot
.47949 .31664 Mdot
.62706 .53495 Mdot
.78014 .47567 Mdot
.59944 .70537 Mdot
.39334 .53871 Mdot
.6179 .75598 Mdot
.6422 .54351 Mdot
.82914 .58005 Mdot
.3822 .51939 Mdot
.61686 .5683 Mdot
.45047 .52377 Mdot
.71356 .60828 Mdot
.51119 .51359 Mdot
.40839 .18656 Mdot
.5832 .40879 Mdot
.60326 .36999 Mdot
.72601 .52525 Mdot
.44005 .33371 Mdot
.6204 .52645 Mdot
.78537 .44818 Mdot
.36439 .30634 Mdot
.62775 .56828 Mdot
.33241 .49829 Mdot
.3861 .4828 Mdot
.39468 .67474 Mdot
.52233 .49028 Mdot
.79176 .45308 Mdot
.57184 .69194 Mdot
.36158 .56528 Mdot
.43641 .52433 Mdot
.38917 .51189 Mdot
.48632 .71706 Mdot
.64938 .5509 Mdot
.20118 .65507 Mdot
.6438 .56418 Mdot
.72163 .68806 Mdot
.64257 .38613 Mdot
.64886 .41161 Mdot
.36866 .4885 Mdot
.78575 .60276 Mdot
.25099 .36321 Mdot
.32755 .54873 Mdot
.53081 .31541 Mdot
.42385 .27506 Mdot
.4409 .52252 Mdot
.49625 .73543 Mdot
.31854 .4689 Mdot
.55684 .69454 Mdot
.61891 .53458 Mdot
.49149 .32574 Mdot
.51347 .31505 Mdot
.63112 .53227 Mdot
.39586 .49603 Mdot
.49638 .29006 Mdot
.40537 .51044 Mdot
.36244 .53368 Mdot
.69591 .72697 Mdot
.50142 .31221 Mdot
.61454 .37827 Mdot
.47005 .34184 Mdot
.49107 .68459 Mdot
.65191 .14331 Mdot
.47895 .32253 Mdot
.51116 .7602 Mdot
.46756 .39193 Mdot
.3993 .36821 Mdot
.52987 .66923 Mdot
.47035 .35405 Mdot
.64124 .57189 Mdot
.64959 .20315 Mdot
.80377 .63627 Mdot
.62186 .59051 Mdot
.38711 .52072 Mdot
.53599 .70589 Mdot
.47565 .6974 Mdot
.6628 .57277 Mdot
.53367 .69049 Mdot
.40899 .46399 Mdot
.37335 .53909 Mdot
.62078 .52644 Mdot
.63203 .66811 Mdot
.64678 .53721 Mdot
.58786 .70965 Mdot
.34901 .54211 Mdot
.50204 .66736 Mdot
.35851 .45531 Mdot
.46421 .68973 Mdot
.7528 .45475 Mdot
.42059 .51687 Mdot
.50591 .34575 Mdot
.52517 .47806 Mdot
.63686 .39175 Mdot
.63982 .46584 Mdot
.51824 .71613 Mdot
.67448 .52038 Mdot
.53017 .70349 Mdot
.5347 .71342 Mdot
.59266 .56889 Mdot
.4871 .67535 Mdot
.34459 .52167 Mdot
.59213 .32994 Mdot
.49068 .70881 Mdot
.62715 .54934 Mdot
.50434 .33965 Mdot
.51103 .70388 Mdot
.65344 .3603 Mdot
.38256 .53267 Mdot
.61463 .40229 Mdot
.46497 .36202 Mdot
.54043 .69239 Mdot
.47452 .35572 Mdot
.64559 .36547 Mdot
.48412 .31163 Mdot
.47055 .23151 Mdot
.65658 .54333 Mdot
.74248 .68848 Mdot
.29195 .44853 Mdot
.47998 .70004 Mdot
.68144 .38327 Mdot
.3431 .50225 Mdot
.38413 .53553 Mdot
.45457 .33945 Mdot
.47462 .69309 Mdot
.46904 .19185 Mdot
.33491 .43759 Mdot
.59379 .68258 Mdot
.65791 .55714 Mdot
.39166 .81657 Mdot
.62472 .72261 Mdot
.67551 .25066 Mdot
.38251 .58133 Mdot
.77393 .4588 Mdot
.40562 .5006 Mdot
.23185 .66386 Mdot
.51244 .34421 Mdot
.7534 .42292 Mdot
.36123 .58225 Mdot
.62165 .38379 Mdot
.37251 .50915 Mdot
.22914 .44194 Mdot
.32077 .46865 Mdot
.46001 .33839 Mdot
.57492 .54482 Mdot
.52085 .64348 Mdot
.49591 .34458 Mdot
.60451 .37573 Mdot
.3801 .31921 Mdot
.4223 .53186 Mdot
.34882 .56498 Mdot
.63359 .42151 Mdot
.53017 .69293 Mdot
.62949 .35136 Mdot
.61477 .56713 Mdot
.48218 .32508 Mdot
.38495 .54492 Mdot
.43311 .52268 Mdot
.55255 .37815 Mdot
.6502 .55267 Mdot
.65668 .4005 Mdot
.62378 .57856 Mdot
.77444 .45963 Mdot
.38323 .56718 Mdot
.62328 .42044 Mdot
.38053 .48016 Mdot
.26661 .70456 Mdot
.70056 .72733 Mdot
.38688 .76043 Mdot
.61219 .37983 Mdot
.37247 .36563 Mdot
.63713 .55433 Mdot
.60926 .57533 Mdot
.46796 .79584 Mdot
.29027 .32321 Mdot
.64872 .27909 Mdot
.20133 .5401 Mdot
.61388 .5666 Mdot
.63186 .55833 Mdot
.59513 .38208 Mdot
.48517 .68421 Mdot
.53722 .64203 Mdot
.65773 .40651 Mdot
.32246 .41682 Mdot
.51861 .67693 Mdot
.35896 .21424 Mdot
.63655 .34894 Mdot
.375 .58341 Mdot
.76436 .439 Mdot
.49368 .32369 Mdot
.32295 .41729 Mdot
.22769 .46915 Mdot
.34661 .49576 Mdot
.57101 .7983 Mdot
.63075 .36743 Mdot
.51966 .39409 Mdot
.28137 .27175 Mdot
.41724 .53215 Mdot
.37928 .504 Mdot
.39468 .49942 Mdot
.50553 .31356 Mdot
.25514 .67851 Mdot
.34648 .4951 Mdot
.3816 .4019 Mdot
.31294 .52137 Mdot
.27143 .3848 Mdot
.46928 .34002 Mdot
.52644 .61464 Mdot
.59221 .41451 Mdot
.70261 .65517 Mdot
.36715 .59778 Mdot
.62237 .57437 Mdot
.65446 .33753 Mdot
.6117 .5491 Mdot
.27447 .32396 Mdot
.32033 .34377 Mdot
.49872 .72747 Mdot
.33767 .51238 Mdot
.5789 .39061 Mdot
.52531 .715 Mdot
.71784 .41054 Mdot
.76366 .2381 Mdot
.6505 .56339 Mdot
.76063 .72805 Mdot
.60998 .57618 Mdot
.75587 .45163 Mdot
.50555 .70881 Mdot
.41049 .62422 Mdot
.5344 .46637 Mdot
.51074 .70233 Mdot
.7029 .56572 Mdot
.50897 .74076 Mdot
.38442 .36251 Mdot
.53603 .6532 Mdot
.63104 .54963 Mdot
.61774 .51092 Mdot
.3617 .58872 Mdot
.34577 .50342 Mdot
.57067 .47188 Mdot
.44527 .4636 Mdot
.3427 .50686 Mdot
.61759 .3917 Mdot
.79307 .63656 Mdot
.59172 .34498 Mdot
.48037 .69032 Mdot
.63414 .5823 Mdot
.37755 .50528 Mdot
.37327 .54304 Mdot
.40252 .48054 Mdot
.26267 .71885 Mdot
.36512 .21235 Mdot
.35533 .53009 Mdot
.32821 .48583 Mdot
.60756 .37437 Mdot
.46557 .29372 Mdot
.20623 .57909 Mdot
.35335 .31771 Mdot
.40389 .5267 Mdot
.47846 .34579 Mdot
.51587 .32787 Mdot
.41193 .55985 Mdot
.72527 .65504 Mdot
.65033 .3192 Mdot
.37277 .48977 Mdot
.29717 .3537 Mdot
.62605 .33976 Mdot
.78819 .44751 Mdot
.64702 .37322 Mdot
.53994 .67444 Mdot
.7773 .44775 Mdot
.59149 .39928 Mdot
.39237 .625 Mdot
.76641 .47076 Mdot
.70381 .62052 Mdot
.50177 .35549 Mdot
.39322 .51275 Mdot
.4972 .73867 Mdot
.59678 .35501 Mdot
.63185 .53121 Mdot
.50553 .68427 Mdot
.61985 .51576 Mdot
.44191 .30933 Mdot
.43604 .40291 Mdot
.77364 .44366 Mdot
.61552 .57213 Mdot
.59928 .70712 Mdot
.47575 .34486 Mdot
.59261 .56617 Mdot
.78637 .59406 Mdot
.38531 .5768 Mdot
.21793 .38989 Mdot
.32719 .53915 Mdot
.57381 .1878 Mdot
.61055 .57908 Mdot
.75635 .4687 Mdot
.39499 .49248 Mdot
.64891 .39017 Mdot
.45127 .50035 Mdot
.40129 .51988 Mdot
.64635 .40755 Mdot
.36239 .53144 Mdot
.47687 .31608 Mdot
.55251 .67887 Mdot
.47901 .4927 Mdot
.46373 .83997 Mdot
.48642 .31292 Mdot
.73578 .4597 Mdot
.33907 .50769 Mdot
.45289 .24281 Mdot
.5133 .70219 Mdot
.41374 .53624 Mdot
.49263 .79065 Mdot
.48694 .69637 Mdot
.50171 .68921 Mdot
.35282 .55697 Mdot
.59376 .55209 Mdot
.6449 .39281 Mdot
.47625 .34629 Mdot
.70805 .25902 Mdot
.39572 .52694 Mdot
.37011 .51738 Mdot
.4971 .34254 Mdot
.63367 .55935 Mdot
.37387 .54511 Mdot
.68991 .44857 Mdot
.71861 .25122 Mdot
.59918 .57577 Mdot
.41785 .55836 Mdot
.19836 .45128 Mdot
.47581 .63854 Mdot
.76726 .70758 Mdot
.47692 .38272 Mdot
.61956 .36227 Mdot
.43676 .54535 Mdot
.40286 .12938 Mdot
.49448 .32605 Mdot
.6886 .6804 Mdot
.34795 .53211 Mdot
.36456 .50418 Mdot
.52481 .66899 Mdot
.36063 .54986 Mdot
.49685 .65816 Mdot
.49172 .85004 Mdot
.36542 .82656 Mdot
.5244 .70689 Mdot
.47773 .68456 Mdot
.54364 .6337 Mdot
.21912 .60295 Mdot
.49512 .69831 Mdot
.42371 .51907 Mdot
.4162 .21795 Mdot
.29642 .52312 Mdot
.45174 .33025 Mdot
.51512 .36337 Mdot
.48547 .61696 Mdot
.82662 .53097 Mdot
.39684 .43935 Mdot
.4124 .58978 Mdot
.52068 .58026 Mdot
.5998 .56494 Mdot
.40812 .52774 Mdot
.77892 .44426 Mdot
.60092 .4029 Mdot
.30341 .49162 Mdot
.39716 .51129 Mdot
.498 .71307 Mdot
.49844 .30809 Mdot
.5921 .53946 Mdot
.36772 .52064 Mdot
.58308 .41744 Mdot
.48128 .33766 Mdot
.48604 .70386 Mdot
.52794 .77029 Mdot
.47244 .30872 Mdot
.41691 .47097 Mdot
.35168 .50636 Mdot
.35057 .53765 Mdot
.39296 .59091 Mdot
.6235 .52929 Mdot
.6433 .34547 Mdot
.42202 .48659 Mdot
.6659 .73751 Mdot
.50768 .41768 Mdot
.42988 .52809 Mdot
.52139 .67239 Mdot
.61789 .58778 Mdot
.75684 .4638 Mdot
.40019 .31606 Mdot
.39598 .53569 Mdot
.36411 .21504 Mdot
.39712 .65653 Mdot
.77339 .44817 Mdot
.51786 .72612 Mdot
.48915 .3513 Mdot
.35171 .56368 Mdot
.37404 .23659 Mdot
.38266 .48324 Mdot
.31905 .435 Mdot
.62588 .36431 Mdot
.60197 .5643 Mdot
.69555 .22825 Mdot
.60314 .40465 Mdot
.50001 .68675 Mdot
.41641 .17536 Mdot
.4827 .65191 Mdot
.51022 .64499 Mdot
.30004 .28768 Mdot
.61199 .53727 Mdot
.38551 .13713 Mdot
.78974 .66448 Mdot
.34797 .48622 Mdot
.63891 .56289 Mdot
.5093 .71189 Mdot
.33287 .51695 Mdot
.47718 .67215 Mdot
.50778 .64707 Mdot
.41957 .51095 Mdot
.35691 .50413 Mdot
.37365 .40748 Mdot
.31584 .23828 Mdot
.47618 .34986 Mdot
.51122 .65723 Mdot
.35636 .67166 Mdot
.34172 .49759 Mdot
.39241 .48704 Mdot
.56583 .34925 Mdot
.46014 .33795 Mdot
.24773 .53678 Mdot
.36219 .53543 Mdot
.51041 .80481 Mdot
.3576 .57081 Mdot
.48717 .73272 Mdot
.59676 .57378 Mdot
.71893 .66047 Mdot
.60673 .3484 Mdot
.5184 .65589 Mdot
.5063 .32478 Mdot
.47273 .70466 Mdot
.46803 .77757 Mdot
.61233 .53961 Mdot
.50918 .66461 Mdot
.65106 .36193 Mdot
.61826 .54492 Mdot
.59689 .57013 Mdot
.41212 .22919 Mdot
.65702 .40254 Mdot
.50035 .35734 Mdot
.614 .55617 Mdot
.30878 .6418 Mdot
.63143 .54548 Mdot
.37359 .67357 Mdot
.32212 .52747 Mdot
.39316 .40048 Mdot
.63985 .71269 Mdot
.34134 .59499 Mdot
.64329 .53004 Mdot
.46429 .33427 Mdot
.36586 .55725 Mdot
.53326 .68683 Mdot
.48107 .32182 Mdot
.57753 .60034 Mdot
.65477 .3827 Mdot
.50904 .72195 Mdot
.60269 .58146 Mdot
.50463 .65982 Mdot
.4225 .36639 Mdot
.61654 .45115 Mdot
.52343 .58976 Mdot
.53192 .45495 Mdot
.38893 .47819 Mdot
.46165 .61801 Mdot
.34253 .56732 Mdot
.39977 .51216 Mdot
.63628 .3936 Mdot
.33071 .40173 Mdot
.51585 .70536 Mdot
.70688 .23409 Mdot
.60981 .57025 Mdot
.556 .78737 Mdot
.30614 .45657 Mdot
.40684 .54038 Mdot
.49022 .70691 Mdot
.49254 .64498 Mdot
.38804 .77168 Mdot
.60276 .35357 Mdot
.31547 .58147 Mdot
.35292 .46633 Mdot
.3871 .58432 Mdot
.61285 .58032 Mdot
.69313 .46225 Mdot
.61163 .35677 Mdot
.86226 .58114 Mdot
.63924 .36528 Mdot
.54972 .26037 Mdot
.48651 .67515 Mdot
.51049 .34487 Mdot
.38718 .48615 Mdot
.36712 .41593 Mdot
.50657 .73404 Mdot
.52699 .37422 Mdot
.50087 .34929 Mdot
.70398 .50132 Mdot
.60835 .5379 Mdot
.41249 .55493 Mdot
.41724 .5131 Mdot
.35105 .54892 Mdot
.32913 .53476 Mdot
.64273 .57874 Mdot
.33481 .4969 Mdot
.65755 .53976 Mdot
.31611 .63742 Mdot
.50845 .80728 Mdot
.58135 .3652 Mdot
.26796 .3496 Mdot
.48597 .71012 Mdot
.31459 .65739 Mdot
.26691 .50333 Mdot
.70828 .72079 Mdot
.45433 .23263 Mdot
.33746 .56288 Mdot
.59852 .36791 Mdot
.22044 .45233 Mdot
.57932 .38657 Mdot
.49785 .90185 Mdot
.47384 .28483 Mdot
.39456 .18408 Mdot
.33484 .51606 Mdot
.56007 .3644 Mdot
.27697 .48265 Mdot
.41474 .55923 Mdot
.46026 .28847 Mdot
.54772 .76298 Mdot
.65317 .67003 Mdot
.49819 .31192 Mdot
.38565 .53173 Mdot
.51665 .64257 Mdot
.34252 .52182 Mdot
.40086 .49116 Mdot
.32993 .51687 Mdot
.58882 .567 Mdot
.32525 .56369 Mdot
.32587 .50728 Mdot
.78614 .51109 Mdot
.34579 .3802 Mdot
.61701 .4059 Mdot
.42837 .7852 Mdot
.47624 .33001 Mdot
.50686 .71668 Mdot
.46931 .43731 Mdot
.59755 .55015 Mdot
.37606 .77471 Mdot
.32869 .52432 Mdot
.63076 .70949 Mdot
.60391 .58264 Mdot
.48557 .32203 Mdot
.77011 .46911 Mdot
.42666 .19919 Mdot
.58181 .3661 Mdot
.76355 .47027 Mdot
.63741 .39027 Mdot
.26901 .68522 Mdot
.49624 .71158 Mdot
.40644 .48114 Mdot
.62003 .56411 Mdot
.64414 .39647 Mdot
.31064 .40211 Mdot
.38917 .50801 Mdot
.61028 .38276 Mdot
.39397 .47792 Mdot
.49244 .40521 Mdot
.64111 .31456 Mdot
.58611 .39688 Mdot
.59796 .51392 Mdot
.61945 .55086 Mdot
.49224 .35473 Mdot
.50834 .71813 Mdot
.51653 .66618 Mdot
.6256 .53609 Mdot
.73236 .74141 Mdot
.40273 .52089 Mdot
.33313 .51284 Mdot
.66534 .73436 Mdot
.34652 .51559 Mdot
.38216 .33634 Mdot
.76024 .4433 Mdot
.49879 .71801 Mdot
.33383 .52127 Mdot
.37651 .5451 Mdot
.3909 .53987 Mdot
.42366 .37296 Mdot
.64551 .37016 Mdot
.36048 .56511 Mdot
.45906 .32347 Mdot
.7761 .57761 Mdot
.33443 .50542 Mdot
.43277 .53722 Mdot
.51214 .6676 Mdot
.40946 .83404 Mdot
.59504 .55634 Mdot
.61156 .3919 Mdot
.65137 .37168 Mdot
.49625 .37498 Mdot
.54686 .70491 Mdot
.75007 .44932 Mdot
.79104 .35646 Mdot
.78382 .46221 Mdot
.49247 .34282 Mdot
.58063 .23965 Mdot
.59034 .4233 Mdot
.60381 .39232 Mdot
.64749 .52523 Mdot
.33058 .52884 Mdot
.33107 .55514 Mdot
.69137 .68108 Mdot
.38238 .55877 Mdot
.50425 .34484 Mdot
.62393 .52442 Mdot
.51363 .67246 Mdot
.49457 .32255 Mdot
.62569 .57729 Mdot
.53063 .69017 Mdot
.38399 .57648 Mdot
.37098 .579 Mdot
.50533 .68845 Mdot
.52988 .70938 Mdot
.36004 .49476 Mdot
.75707 .51001 Mdot
.54371 .68108 Mdot
.50632 .66411 Mdot
.79578 .45136 Mdot
.58003 .36974 Mdot
.36427 .45057 Mdot
.6401 .56276 Mdot
.35167 .53695 Mdot
.57794 .38058 Mdot
.46168 .34252 Mdot
.5191 .69767 Mdot
.37665 .54233 Mdot
.37132 .52872 Mdot
.48088 .34745 Mdot
.48246 .30592 Mdot
.50251 .32671 Mdot
.64132 .59479 Mdot
.33564 .54481 Mdot
.49669 .69805 Mdot
.60832 .5403 Mdot
.51576 .32773 Mdot
.50374 .35987 Mdot
.81286 .51106 Mdot
.35224 .49321 Mdot
.51215 .52452 Mdot
.6147 .12912 Mdot
.37112 .31856 Mdot
.75412 .45999 Mdot
.6422 .41907 Mdot
.39119 .38839 Mdot
.5787 .32927 Mdot
.64723 .55196 Mdot
.35072 .28724 Mdot
.45007 .32461 Mdot
.4164 .48805 Mdot
.36394 .57038 Mdot
.31292 .50157 Mdot
.48322 .33315 Mdot
.41616 .3432 Mdot
.47282 .6849 Mdot
.31027 .69416 Mdot
.4765 .32988 Mdot
.58597 .39611 Mdot
.61238 .41769 Mdot
.63844 .36486 Mdot
.38452 .56899 Mdot
.37765 .76812 Mdot
.33183 .65982 Mdot
.25087 .6292 Mdot
.60706 .53749 Mdot
.47753 .65097 Mdot
.46214 .23854 Mdot
.5035 .69153 Mdot
.59772 .40201 Mdot
.48581 .33623 Mdot
.5187 .6628 Mdot
.64279 .53823 Mdot
.63051 .5599 Mdot
.65389 .3845 Mdot
.6474 .38169 Mdot
.62718 .40318 Mdot
.5339 .66061 Mdot
.48689 .67553 Mdot
.39588 .54101 Mdot
.51568 .69153 Mdot
.58924 .79608 Mdot
.49484 .36661 Mdot
.59874 .41074 Mdot
.64177 .5501 Mdot
.50664 .71442 Mdot
.3914 .51543 Mdot
.6158 .26589 Mdot
.66151 .60544 Mdot
.47813 .3128 Mdot
.69388 .33545 Mdot
.54811 .88993 Mdot
.41593 .50572 Mdot
.6376 .57706 Mdot
.73763 .63926 Mdot
.39052 .50088 Mdot
.62736 .37322 Mdot
.24077 .67801 Mdot
.78808 .45963 Mdot
.32724 .50684 Mdot
.39615 .54965 Mdot
.59037 .5596 Mdot
.45438 .38691 Mdot
.39021 .54885 Mdot
.59932 .75108 Mdot
.59823 .52494 Mdot
.59705 .36457 Mdot
.73592 .26173 Mdot
.67039 .40031 Mdot
.28656 .43265 Mdot
.75766 .45214 Mdot
.41642 .51817 Mdot
.62066 .39427 Mdot
.47139 .31461 Mdot
.62773 .39916 Mdot
.51153 .72816 Mdot
.62047 .4052 Mdot
.36936 .51516 Mdot
.49435 .69454 Mdot
.64327 .54484 Mdot
.6 .77946 Mdot
.78906 .52145 Mdot
.64929 .38982 Mdot
.79955 .45717 Mdot
.33378 .50178 Mdot
.26172 .55071 Mdot
.45104 .4975 Mdot
.33479 .50805 Mdot
.61091 .54827 Mdot
.48783 .70404 Mdot
.65527 .56679 Mdot
.43286 .49269 Mdot
.46691 .81358 Mdot
.60655 .57521 Mdot
.68817 .64181 Mdot
.49585 .34239 Mdot
.34201 .41211 Mdot
.39652 .52051 Mdot
.61562 .56173 Mdot
.33653 .54436 Mdot
.48795 .65419 Mdot
.55173 .5085 Mdot
.78258 .58291 Mdot
.6211 .56377 Mdot
.50281 .17628 Mdot
.54084 .52153 Mdot
.33242 .45946 Mdot
.61367 .56381 Mdot
.31952 .74165 Mdot
.75896 .45972 Mdot
.48399 .34206 Mdot
.51086 .32145 Mdot
.48665 .31128 Mdot
.38657 .55915 Mdot
.27962 .54702 Mdot
.50381 .35832 Mdot
.59142 .53321 Mdot
.4584 .33395 Mdot
.38865 .41106 Mdot
.49172 .17974 Mdot
.49909 .32079 Mdot
.38607 .52355 Mdot
.4335 .53846 Mdot
.3412 .38266 Mdot
.58648 .38565 Mdot
.33845 .22975 Mdot
.44172 .66601 Mdot
.34793 .49919 Mdot
.3114 .46685 Mdot
.4995 .7241 Mdot
.76576 .63034 Mdot
.30878 .46087 Mdot
.62113 .31939 Mdot
.4834 .66707 Mdot
.65845 .41902 Mdot
.50242 .71824 Mdot
.40922 .48953 Mdot
.35177 .52847 Mdot
.55464 .67463 Mdot
.65195 .46571 Mdot
.72946 .58253 Mdot
.63211 .2143 Mdot
.51253 .66063 Mdot
.6226 .57013 Mdot
.64945 .56799 Mdot
.60346 .54612 Mdot
.61841 .34737 Mdot
.53992 .68712 Mdot
.33721 .55278 Mdot
.60947 .36754 Mdot
.40576 .52199 Mdot
.61523 .54875 Mdot
.69059 .22421 Mdot
.51242 .6691 Mdot
.37645 .48979 Mdot
.80242 .63735 Mdot
.64032 .37607 Mdot
.47432 .34235 Mdot
.50709 .40104 Mdot
.65352 .35707 Mdot
.6453 .53333 Mdot
.52364 .63676 Mdot
.59577 .58933 Mdot
.46724 .44673 Mdot
.29906 .53353 Mdot
.42541 .5368 Mdot
.73607 .28028 Mdot
.82206 .55977 Mdot
.38729 .56353 Mdot
.60397 .37652 Mdot
.58449 .37275 Mdot
.37938 .53954 Mdot
.53631 .68154 Mdot
.5179 .33686 Mdot
.46 .31804 Mdot
.40591 .46905 Mdot
.53775 .4653 Mdot
.38543 .40477 Mdot
.36758 .54703 Mdot
.3168 .5869 Mdot
.65679 .38284 Mdot
.77412 .47046 Mdot
.65907 .72394 Mdot
.51102 .33228 Mdot
.34994 .53326 Mdot
.69151 .61215 Mdot
.49224 .65954 Mdot
.62122 .40411 Mdot
.63164 .52846 Mdot
.42682 .35071 Mdot
.644 .35508 Mdot
.37809 .53953 Mdot
.37437 .54506 Mdot
.59125 .56298 Mdot
.48723 .73262 Mdot
.48607 .33418 Mdot
.61147 .3675 Mdot
.51325 .33913 Mdot
.48991 .68072 Mdot
.51115 .67335 Mdot
.29578 .51815 Mdot
.39656 .58854 Mdot
.65153 .38143 Mdot
.38351 .47071 Mdot
.59621 .40409 Mdot
.45056 .37621 Mdot
.63062 .58555 Mdot
.42048 .5224 Mdot
.49821 .6385 Mdot
.61502 .54414 Mdot
.36421 .49967 Mdot
.8047 .34789 Mdot
.41128 .53416 Mdot
.64764 .34921 Mdot
.47365 .81499 Mdot
.46211 .33598 Mdot
.4953 .76038 Mdot
.43823 .5918 Mdot
.34871 .51595 Mdot
.6085 .41331 Mdot
.44808 .49401 Mdot
.60004 .5721 Mdot
.48137 .67824 Mdot
.70328 .79266 Mdot
.6277 .54623 Mdot
.34229 .5242 Mdot
.48278 .32399 Mdot
.49421 .6429 Mdot
.78377 .45187 Mdot
.67057 .71975 Mdot
.31097 .4832 Mdot
.36674 .58118 Mdot
.33256 .52618 Mdot
.19668 .56481 Mdot
.61538 .39468 Mdot
.50797 .71321 Mdot
.61702 .58137 Mdot
.63169 .53649 Mdot
.6328 .36462 Mdot
.63298 .68841 Mdot
.64579 .45417 Mdot
.5097 .08625 Mdot
.64363 .40752 Mdot
.45804 .34128 Mdot
.51565 .44185 Mdot
.60951 .40896 Mdot
.61819 .38733 Mdot
.65279 .3726 Mdot
.65794 .69988 Mdot
.52744 .68143 Mdot
.37025 .5294 Mdot
.54427 .71091 Mdot
.41689 .52117 Mdot
.24604 .46636 Mdot
.62314 .53454 Mdot
.48273 .67547 Mdot
.77236 .31107 Mdot
.44307 .46126 Mdot
.38375 .50457 Mdot
.49182 .22141 Mdot
.42391 .47015 Mdot
.3999 .34967 Mdot
.40281 .45752 Mdot
.64396 .38763 Mdot
.28422 .50846 Mdot
.42332 .56221 Mdot
.58848 .79323 Mdot
.64266 .55376 Mdot
.75599 .44972 Mdot
.32695 .55873 Mdot
.31664 .48291 Mdot
.50077 .64284 Mdot
.51829 .6622 Mdot
.50462 .35746 Mdot
.53208 .42444 Mdot
.64388 .54745 Mdot
.59531 .45242 Mdot
.34719 .50415 Mdot
.57603 .5298 Mdot
.46914 .79105 Mdot
.36574 .49835 Mdot
.40041 .22555 Mdot
.38017 .7742 Mdot
.39377 .54727 Mdot
.29062 .69683 Mdot
.63361 .55631 Mdot
.50615 .80173 Mdot
.34917 .47893 Mdot
.6281 .37459 Mdot
.4839 .68217 Mdot
.50425 .72469 Mdot
.49038 .31624 Mdot
.67193 .76646 Mdot
.65021 .5354 Mdot
.48508 .67523 Mdot
.39495 .50304 Mdot
.62646 .52905 Mdot
.7741 .44469 Mdot
.42874 .54881 Mdot
.34077 .28026 Mdot
.5155 .68718 Mdot
.33349 .48213 Mdot
.57848 .63585 Mdot
.48667 .41171 Mdot
.28045 .25697 Mdot
.60202 .55296 Mdot
.50777 .32983 Mdot
.38395 .45151 Mdot
.78627 .35198 Mdot
.31109 .51441 Mdot
.35044 .40331 Mdot
.47216 .62841 Mdot
.50829 .35033 Mdot
.38713 .49564 Mdot
.38445 .5504 Mdot
.52556 .4641 Mdot
.48962 .30649 Mdot
.41568 .52952 Mdot
.29333 .53484 Mdot
.52962 .69195 Mdot
.75896 .44487 Mdot
.51615 .68045 Mdot
.38649 .52035 Mdot
.27574 .53715 Mdot
.53075 .67677 Mdot
.62098 .23694 Mdot
.46144 .30725 Mdot
.59602 .55615 Mdot
.29944 .57411 Mdot
.32298 .5241 Mdot
.16161 .48985 Mdot
.75293 .45469 Mdot
.22396 .65166 Mdot
.66126 .40217 Mdot
.6999 .57749 Mdot
.5633 .39981 Mdot
.41751 .1831 Mdot
.61178 .76555 Mdot
.30375 .51042 Mdot
.30138 .3366 Mdot
.27255 .66866 Mdot
.65605 .54929 Mdot
.27717 .60799 Mdot
.34552 .50339 Mdot
.40457 .49635 Mdot
.59394 .37748 Mdot
.62093 .70186 Mdot
.73135 .64319 Mdot
.55218 .47094 Mdot
.49069 .33313 Mdot
.49172 .67255 Mdot
.3606 .51392 Mdot
.69949 .40372 Mdot
.62605 .40836 Mdot
.55358 .57212 Mdot
.38513 .49024 Mdot
.72838 .67989 Mdot
.67652 .6661 Mdot
.62383 .52826 Mdot
.63564 .41967 Mdot
.65441 .35933 Mdot
.40311 .48765 Mdot
.64132 .53218 Mdot
.39622 .54249 Mdot
.5514 .53549 Mdot
.36228 .4724 Mdot
.48369 .31865 Mdot
.35649 .48625 Mdot
.51031 .48089 Mdot
.34836 .19623 Mdot
.36072 .44356 Mdot
.5382 .70644 Mdot
.62378 .34788 Mdot
.64194 .36807 Mdot
.51492 .6636 Mdot
.63979 .36788 Mdot
.32456 .70846 Mdot
.43737 .72688 Mdot
.49524 .3336 Mdot
.26889 .53634 Mdot
.47842 .31905 Mdot
.75457 .45095 Mdot
.35057 .49521 Mdot
.80671 .37708 Mdot
.64818 .4027 Mdot
.31196 .75922 Mdot
.63274 .54356 Mdot
.75439 .45268 Mdot
.31282 .51757 Mdot
.57416 .23934 Mdot
.59145 .39304 Mdot
.66728 .3685 Mdot
.39234 .53962 Mdot
.52078 .66832 Mdot
.38218 .55066 Mdot
.38317 .45965 Mdot
.76242 .46941 Mdot
.3313 .52908 Mdot
.62615 .57711 Mdot
.53918 .67728 Mdot
.44494 .19251 Mdot
.59756 .35369 Mdot
.36938 .48434 Mdot
.39433 .50196 Mdot
.48277 .65654 Mdot
.31604 .51387 Mdot
.64713 .54237 Mdot
.26864 .19726 Mdot
.49466 .3432 Mdot
.78266 .46858 Mdot
.6524 .35052 Mdot
.3427 .56441 Mdot
.37102 .54951 Mdot
.72692 .26975 Mdot
.76122 .55579 Mdot
.62285 .57572 Mdot
.40863 .46661 Mdot
.60824 .37489 Mdot
.48507 .32303 Mdot
.59774 .53 Mdot
.35341 .53896 Mdot
.39522 .48963 Mdot
.4861 .31923 Mdot
.42772 .21902 Mdot
.64847 .31678 Mdot
.60474 .5407 Mdot
.28429 .50296 Mdot
.62514 .27549 Mdot
.40212 .52043 Mdot
.67031 .27053 Mdot
.50657 .66573 Mdot
.60938 .56119 Mdot
.23133 .61168 Mdot
.40641 .48025 Mdot
.64962 .54932 Mdot
.64338 .54874 Mdot
.35692 .48221 Mdot
.54632 .70385 Mdot
.5245 .65271 Mdot
.50078 .66109 Mdot
.4786 .82405 Mdot
.27301 .40798 Mdot
.62893 .40331 Mdot
.63361 .55772 Mdot
.58113 .39133 Mdot
.51889 .33158 Mdot
.50952 .41981 Mdot
.5825 .38651 Mdot
.5008 .72399 Mdot
.61097 .41743 Mdot
.38754 .54574 Mdot
.6449 .54626 Mdot
.60381 .39338 Mdot
.35813 .56867 Mdot
.35845 .60392 Mdot
.52447 .53587 Mdot
.51648 .34134 Mdot
.50173 .38418 Mdot
.35777 .52449 Mdot
.7587 .46564 Mdot
.3633 .49255 Mdot
.61914 .5267 Mdot
.49948 .46147 Mdot
.35775 .56739 Mdot
.65098 .38655 Mdot
.47206 .54596 Mdot
.59181 .36817 Mdot
.36473 .46258 Mdot
.38425 .52101 Mdot
.40512 .51522 Mdot
.39061 .54895 Mdot
.6746 .65588 Mdot
.65837 .55778 Mdot
.33479 .6027 Mdot
.57368 .39146 Mdot
.51008 .6966 Mdot
.47182 .69472 Mdot
.65462 .28694 Mdot
.77429 .47276 Mdot
.63983 .56104 Mdot
.40084 .52318 Mdot
.66892 .368 Mdot
.68195 .21879 Mdot
.65689 .25022 Mdot
.47248 .24651 Mdot
.60215 .3824 Mdot
.53654 .70829 Mdot
.60852 .40442 Mdot
.40911 .498 Mdot
.43093 .50092 Mdot
.42543 .18791 Mdot
.66926 .55234 Mdot
.48482 .33547 Mdot
.40814 .51589 Mdot
.279 .43946 Mdot
.60761 .37427 Mdot
.65774 .38529 Mdot
.41081 .52974 Mdot
.52064 .65537 Mdot
.21315 .30529 Mdot
.62877 .52722 Mdot
.26195 .56429 Mdot
.4532 .69781 Mdot
.55626 .75882 Mdot
.63251 .53358 Mdot
.5231 .56358 Mdot
.62711 .35622 Mdot
.46726 .74577 Mdot
.50909 .6924 Mdot
.48057 .3351 Mdot
.43016 .51225 Mdot
.5031 .7236 Mdot
.65401 .41431 Mdot
.48888 .71071 Mdot
.41165 .48839 Mdot
.65716 .55553 Mdot
.62899 .3608 Mdot
.59602 .51189 Mdot
.55525 .67568 Mdot
.46768 .32294 Mdot
.34041 .41371 Mdot
.27355 .59573 Mdot
.37858 .77431 Mdot
.35974 .5651 Mdot
.67125 .33788 Mdot
.3378 .54732 Mdot
.50508 .64436 Mdot
.39484 .52139 Mdot
.48432 .61576 Mdot
.6481 .41173 Mdot
.33437 .4819 Mdot
.32933 .50261 Mdot
.35091 .63336 Mdot
.37795 .5001 Mdot
.32327 .50296 Mdot
.38844 .55236 Mdot
.45056 .68372 Mdot
.29932 .51375 Mdot
.52507 .67518 Mdot
.68181 .68658 Mdot
.62049 .38813 Mdot
.51631 .3498 Mdot
.4689 .31119 Mdot
.36216 .40225 Mdot
.33573 .41313 Mdot
.63517 .6921 Mdot
.52135 .68217 Mdot
.6381 .57206 Mdot
.39721 .54173 Mdot
.22958 .59159 Mdot
.44629 .34753 Mdot
.62829 .35754 Mdot
.6155 .345 Mdot
.41256 .58063 Mdot
.19363 .55794 Mdot
.32298 .48789 Mdot
.67634 .72113 Mdot
.39957 .46865 Mdot
.4143 .53495 Mdot
.64496 .35281 Mdot
.43311 .40737 Mdot
.36033 .56524 Mdot
.50024 .64274 Mdot
.47689 .33719 Mdot
.35786 .43989 Mdot
.52066 .29701 Mdot
.54019 .55871 Mdot
.40389 .63228 Mdot
.3316 .54563 Mdot
.61693 .3646 Mdot
.51022 .72161 Mdot
.65483 .74025 Mdot
.6076 .54282 Mdot
.63789 .72087 Mdot
.33855 .64736 Mdot
.57465 .21975 Mdot
.48122 .33731 Mdot
.41998 .22418 Mdot
.3687 .51543 Mdot
.62776 .34744 Mdot
.41725 .50209 Mdot
.67505 .21534 Mdot
.47122 .35386 Mdot
.51096 .73567 Mdot
.62468 .57085 Mdot
.48868 .65491 Mdot
.39278 .76186 Mdot
.50952 .59211 Mdot
.72835 .4632 Mdot
.5813 .36933 Mdot
.23648 .51177 Mdot
.49464 .70194 Mdot
.36673 .54009 Mdot
.54413 .09695 Mdot
.50511 .6661 Mdot
.50739 .65602 Mdot
.47084 .38756 Mdot
.43912 .28958 Mdot
.44772 .50212 Mdot
.48337 .70398 Mdot
.58494 .40434 Mdot
.4715 .34537 Mdot
.36665 .56022 Mdot
.38524 .55237 Mdot
.52335 .66798 Mdot
.59353 .39807 Mdot
.22992 .51457 Mdot
.64616 .38437 Mdot
.52953 .69753 Mdot
.63752 .38195 Mdot
.6277 .33493 Mdot
.60632 .39024 Mdot
.32003 .51908 Mdot
.39752 .52545 Mdot
.52207 .28305 Mdot
.51119 .67358 Mdot
.36496 .55285 Mdot
.35529 .53159 Mdot
.49676 .70056 Mdot
.59015 .42162 Mdot
.22414 .57504 Mdot
.33852 .5124 Mdot
.38204 .52962 Mdot
.51134 .34462 Mdot
.62532 .43476 Mdot
.71421 .35661 Mdot
.36508 .55753 Mdot
.45648 .32449 Mdot
.53565 .66163 Mdot
.36327 .49371 Mdot
.4014 .41139 Mdot
.60053 .34395 Mdot
.36572 .48206 Mdot
.78437 .45092 Mdot
.33623 .56041 Mdot
.22568 .29567 Mdot
.35856 .48815 Mdot
.50952 .71073 Mdot
.48542 .69295 Mdot
.51387 .3849 Mdot
.49834 .68304 Mdot
.76083 .44804 Mdot
.61664 .54789 Mdot
.6007 .19831 Mdot
.7713 .44542 Mdot
.41067 .54233 Mdot
.7895 .66497 Mdot
.38269 .47273 Mdot
.3298 .56024 Mdot
.22178 .61615 Mdot
.76971 .44618 Mdot
.49211 .70669 Mdot
.65304 .46917 Mdot
.40965 .47067 Mdot
.63299 .52809 Mdot
.42612 .54692 Mdot
.35268 .48584 Mdot
.57985 .75417 Mdot
.43417 .80718 Mdot
.61061 .52943 Mdot
.38354 .44879 Mdot
.36419 .55745 Mdot
.81196 .54698 Mdot
.39044 .50977 Mdot
.49617 .31888 Mdot
.50329 .65746 Mdot
.62605 .41229 Mdot
.49172 .34765 Mdot
.34657 .51042 Mdot
.48073 .33132 Mdot
.6225 .40322 Mdot
.60977 .55235 Mdot
.37568 .48355 Mdot
.452 .32783 Mdot
.48895 .33288 Mdot
.34413 .54913 Mdot
.48326 .6778 Mdot
.42094 .44889 Mdot
.36337 .49489 Mdot
.37104 .53926 Mdot
.51656 .6663 Mdot
.86201 .52526 Mdot
.41027 .49505 Mdot
.51434 .52876 Mdot
.51685 .73403 Mdot
.78129 .44103 Mdot
.60314 .39793 Mdot
.37366 .4785 Mdot
.62124 .5328 Mdot
.61782 .53803 Mdot
.63223 .42375 Mdot
.48924 .65175 Mdot
.5877 .38636 Mdot
.39447 .44661 Mdot
.38389 .59155 Mdot
.42103 .48264 Mdot
.68866 .7986 Mdot
.41241 .19881 Mdot
.53845 .69033 Mdot
.61488 .35565 Mdot
.55485 .46973 Mdot
.63464 .56235 Mdot
.61143 .41904 Mdot
.51052 .63795 Mdot
.53229 .70974 Mdot
.48785 .71234 Mdot
.50938 .34386 Mdot
.63854 .35484 Mdot
.49221 .73485 Mdot
.51509 .65336 Mdot
.39036 .54205 Mdot
.36323 .55668 Mdot
.51263 .62043 Mdot
.35851 .36892 Mdot
.47146 .31981 Mdot
.62404 .36615 Mdot
.14123 .49672 Mdot
.61765 .52721 Mdot
.35547 .63343 Mdot
.34834 .56653 Mdot
.75441 .22081 Mdot
.33055 .4808 Mdot
.39423 .5053 Mdot
.5396 .67241 Mdot
.45759 .34742 Mdot
.47021 .32876 Mdot
.49291 .70027 Mdot
.53885 .64298 Mdot
.50382 .32333 Mdot
.44609 .23721 Mdot
.50669 .17238 Mdot
.64419 .73914 Mdot
.50635 .70752 Mdot
.275 .59254 Mdot
.64459 .53339 Mdot
.5561 .69535 Mdot
.60083 .53794 Mdot
.61862 .38603 Mdot
.64725 .36215 Mdot
.59101 .55884 Mdot
.3941 .53746 Mdot
.61481 .40121 Mdot
.29929 .49482 Mdot
.46865 .20779 Mdot
.24373 .34894 Mdot
.74618 .53692 Mdot
.35396 .57006 Mdot
.72297 .65635 Mdot
.74384 .61173 Mdot
.35249 .52044 Mdot
.39219 .42598 Mdot
.483 .33447 Mdot
.5482 .71489 Mdot
.64559 .53965 Mdot
.26895 .26814 Mdot
.40162 .52153 Mdot
.51742 .70558 Mdot
.64238 .55652 Mdot
.54218 .38713 Mdot
.59706 .74733 Mdot
.41499 .5213 Mdot
.44228 .10719 Mdot
.54039 .72779 Mdot
.62712 .41242 Mdot
.73378 .72141 Mdot
.54218 .71564 Mdot
.49264 .38419 Mdot
.6607 .38418 Mdot
.65759 .23654 Mdot
.5086 .71649 Mdot
.6432 .42341 Mdot
.49185 .68098 Mdot
.48341 .31662 Mdot
.5399 .65572 Mdot
.62426 .36024 Mdot
.38254 .49645 Mdot
.63471 .36776 Mdot
.47154 .31858 Mdot
.61948 .34633 Mdot
.64468 .53611 Mdot
.75534 .4574 Mdot
.62481 .557 Mdot
.50252 .41214 Mdot
.44943 .81145 Mdot
.60167 .5638 Mdot
.56671 .42151 Mdot
.38361 .56475 Mdot
.48273 .72824 Mdot
.63954 .41175 Mdot
.57668 .39623 Mdot
.52174 .43219 Mdot
.50629 .69946 Mdot
.62791 .36309 Mdot
.32698 .64669 Mdot
.84289 .60888 Mdot
.28446 .55451 Mdot
.28275 .38322 Mdot
.49937 .70272 Mdot
.65501 .40582 Mdot
.66522 .73295 Mdot
.48312 .71047 Mdot
.64329 .40702 Mdot
.61642 .56531 Mdot
.63215 .53552 Mdot
.407 .52697 Mdot
.65325 .5233 Mdot
.62256 .41756 Mdot
.71808 .59489 Mdot
.49524 .65592 Mdot
.54118 .38934 Mdot
.4913 .31458 Mdot
.61361 .3874 Mdot
.41476 .57189 Mdot
.52847 .63208 Mdot
.5818 .36216 Mdot
.30092 .31465 Mdot
.14737 .52535 Mdot
.62971 .36491 Mdot
.5018 .65701 Mdot
.52053 .69875 Mdot
.43533 .47762 Mdot
.5341 .46233 Mdot
.58894 .38189 Mdot
.81456 .39923 Mdot
.33578 .40541 Mdot
.77513 .45967 Mdot
.8283 .56002 Mdot
.35914 .56586 Mdot
.3371 .54225 Mdot
.6344 .56518 Mdot
.3773 .50902 Mdot
.5211 .65338 Mdot
.32092 .5439 Mdot
.6501 .55654 Mdot
.62404 .35707 Mdot
.36668 .48692 Mdot
.46483 .33759 Mdot
.63493 .52273 Mdot
.59135 .55056 Mdot
.63048 .3907 Mdot
.48455 .70684 Mdot
.68978 .40395 Mdot
.64727 .38031 Mdot
.33203 .54807 Mdot
.77087 .44985 Mdot
.40122 .48006 Mdot
.39491 .25306 Mdot
.47331 .67827 Mdot
.61201 .40726 Mdot
.51798 .72541 Mdot
.62666 .55317 Mdot
.59986 .41794 Mdot
.38562 .51386 Mdot
.64514 .4031 Mdot
.5562 .32717 Mdot
.42505 .2412 Mdot
.49197 .64901 Mdot
.53367 .3249 Mdot
.50659 .65418 Mdot
.77674 .45981 Mdot
.38496 .28173 Mdot
.48922 .3406 Mdot
.61001 .37804 Mdot
.39816 .20164 Mdot
.65227 .3914 Mdot
.37533 .50051 Mdot
.35982 .5049 Mdot
.59451 .37909 Mdot
.47699 .35233 Mdot
.41229 .83289 Mdot
.51341 .56169 Mdot
.49367 .71087 Mdot
.45239 .71526 Mdot
.14107 .43899 Mdot
.59851 .52158 Mdot
.63266 .56993 Mdot
.33681 .47348 Mdot
.4077 .53915 Mdot
.59078 .54545 Mdot
.63203 .58266 Mdot
.51474 .34104 Mdot
.648 .3665 Mdot
.49304 .74333 Mdot
.61037 .5177 Mdot
.45711 .56088 Mdot
.29238 .43143 Mdot
.43619 .4831 Mdot
.30872 .56608 Mdot
.37516 .57273 Mdot
.48151 .40724 Mdot
.63313 .57993 Mdot
.35996 .52555 Mdot
.30042 .50783 Mdot
.61277 .56706 Mdot
.48223 .31719 Mdot
.56416 .72294 Mdot
.63313 .37788 Mdot
.86596 .4375 Mdot
.36662 .48324 Mdot
.37578 .49513 Mdot
.60749 .53707 Mdot
.82853 .53165 Mdot
.53195 .70424 Mdot
.47531 .68359 Mdot
.61543 .39584 Mdot
.52331 .43024 Mdot
.31685 .52598 Mdot
.35458 .52218 Mdot
.61646 .37618 Mdot
.75571 .45981 Mdot
.72838 .53046 Mdot
.37239 .52794 Mdot
.64038 .55124 Mdot
.64822 .33452 Mdot
.63392 .58041 Mdot
.41678 .50659 Mdot
.37284 .50175 Mdot
.31943 .51843 Mdot
.40743 .54046 Mdot
.59661 .53762 Mdot
.36151 .52143 Mdot
.41417 .57511 Mdot
.47924 .68792 Mdot
.3271 .5328 Mdot
.3831 .39907 Mdot
.3862 .52744 Mdot
.46501 .33184 Mdot
.70436 .38587 Mdot
.40626 .51641 Mdot
.32778 .53112 Mdot
.51484 .55579 Mdot
.39159 .49548 Mdot
.6133 .52971 Mdot
.51401 .69656 Mdot
.63327 .55828 Mdot
.61304 .58085 Mdot
.57925 .39385 Mdot
.5144 .34319 Mdot
.30726 .52462 Mdot
.48008 .31099 Mdot
.3301 .57941 Mdot
.41307 .48956 Mdot
.68637 .38232 Mdot
.67716 .71874 Mdot
.59292 .3253 Mdot
.38692 .51621 Mdot
.6172 .3923 Mdot
.62315 .4109 Mdot
.30046 .32924 Mdot
.31958 .46789 Mdot
.59457 .53616 Mdot
.61604 .56208 Mdot
.37755 .33186 Mdot
.58249 .7594 Mdot
.46716 .32479 Mdot
.57449 .47396 Mdot
.37681 .57042 Mdot
.36782 .53265 Mdot
.43133 .54032 Mdot
.58201 .38693 Mdot
.76711 .47122 Mdot
.63175 .35759 Mdot
.77654 .4356 Mdot
.64354 .57655 Mdot
.32972 .55355 Mdot
.25805 .3239 Mdot
.52744 .66849 Mdot
.514 .69567 Mdot
.58971 .53941 Mdot
.58759 .37421 Mdot
.44193 .48217 Mdot
.70708 .79383 Mdot
.55095 .71963 Mdot
.48699 .36338 Mdot
.34966 .52279 Mdot
.62626 .39253 Mdot
.525 .663 Mdot
.46195 .31155 Mdot
.32934 .51568 Mdot
.57311 .39755 Mdot
.39321 .52381 Mdot
.26894 .66907 Mdot
.48158 .69216 Mdot
.67933 .21372 Mdot
.48285 .65214 Mdot
.63782 .52315 Mdot
.60896 .57131 Mdot
.36608 .49997 Mdot
.70698 .77129 Mdot
.51837 .737 Mdot
.61654 .50817 Mdot
.46605 .35299 Mdot
.78045 .46918 Mdot
.48888 .35849 Mdot
.60884 .40962 Mdot
.47918 .33819 Mdot
.65148 .37231 Mdot
.36861 .34323 Mdot
.53637 .73839 Mdot
.49328 .34544 Mdot
.80755 .52082 Mdot
.31886 .55913 Mdot
.51501 .32722 Mdot
.40714 .5823 Mdot
.46462 .73656 Mdot
.62 .37714 Mdot
.47417 .35108 Mdot
.36912 .54159 Mdot
.25847 .28997 Mdot
.60932 .57536 Mdot
.59708 .53293 Mdot
.31302 .55567 Mdot
.65441 .37406 Mdot
.54044 .64668 Mdot
.47358 .44773 Mdot
.77166 .4391 Mdot
.35736 .5224 Mdot
.33132 .55588 Mdot
.46948 .68575 Mdot
.48002 .64764 Mdot
.36969 .50251 Mdot
.29592 .62899 Mdot
.36562 .51582 Mdot
.62748 .53152 Mdot
.53151 .7086 Mdot
.51865 .69708 Mdot
.6281 .4191 Mdot
.49738 .65034 Mdot
.30498 .56392 Mdot
.67362 .56657 Mdot
.41751 .47465 Mdot
.62541 .54748 Mdot
.50314 .47261 Mdot
.60673 .34873 Mdot
.30587 .25064 Mdot
.47002 .67679 Mdot
.33013 .52898 Mdot
.50046 .65243 Mdot
.50294 .32963 Mdot
.51188 .67696 Mdot
.53947 .70926 Mdot
.35169 .50323 Mdot
.4162 .51847 Mdot
.76489 .44828 Mdot
.53516 .4586 Mdot
.48753 .66647 Mdot
.35856 .51686 Mdot
.37012 .47329 Mdot
.335 .49271 Mdot
.53037 .50065 Mdot
.53966 .6966 Mdot
.39699 .6784 Mdot
.32175 .28581 Mdot
.48541 .6716 Mdot
.20288 .33279 Mdot
.78651 .45609 Mdot
.77672 .47173 Mdot
.61327 .51337 Mdot
.37297 .52946 Mdot
.59998 .36363 Mdot
.40699 .49418 Mdot
.29507 .50269 Mdot
.3976 .48983 Mdot
.4607 .34174 Mdot
.30554 .52478 Mdot
.7694 .46306 Mdot
.64633 .37622 Mdot
.33368 .51518 Mdot
.37164 .48549 Mdot
.77208 .47408 Mdot
.47151 .66838 Mdot
.52394 .71518 Mdot
.66337 .26273 Mdot
.49771 .32975 Mdot
.60982 .54631 Mdot
.40095 .53098 Mdot
.616 .3933 Mdot
.63749 .36905 Mdot
.49268 .6536 Mdot
.62958 .37288 Mdot
.62554 .5264 Mdot
.38599 .51006 Mdot
.59519 .53669 Mdot
.4602 .3368 Mdot
.50539 .6583 Mdot
.40311 .52925 Mdot
.39002 .54184 Mdot
.48549 .69336 Mdot
.3838 .5649 Mdot
.5115 .34408 Mdot
.65026 .37917 Mdot
.5171 .71594 Mdot
.61663 .54508 Mdot
.61747 .41815 Mdot
.38019 .54585 Mdot
.15897 .55079 Mdot
.3737 .5106 Mdot
.37788 .53758 Mdot
.46823 .18027 Mdot
.34663 .46864 Mdot
.6404 .41466 Mdot
.47593 .70399 Mdot
.36393 .57826 Mdot
.27227 .43702 Mdot
.74655 .30408 Mdot
.6068 .41772 Mdot
.3411 .52144 Mdot
.32663 .23366 Mdot
.33651 .51843 Mdot
.59483 .4538 Mdot
.65498 .3052 Mdot
.22925 .458 Mdot
.31314 .57068 Mdot
.59559 .54749 Mdot
.76254 .44875 Mdot
.65448 .40121 Mdot
.33011 .7448 Mdot
.35242 .50913 Mdot
.3125 .73738 Mdot
.3356 .49646 Mdot
.63392 .53516 Mdot
.45185 .47399 Mdot
.62569 .36719 Mdot
.63739 .78165 Mdot
.33593 .55112 Mdot
.53879 .69809 Mdot
.59768 .41047 Mdot
.78494 .4647 Mdot
.37569 .54205 Mdot
.46917 .31315 Mdot
.62429 .49359 Mdot
.35024 .59468 Mdot
.62347 .54512 Mdot
.35396 .53265 Mdot
.36231 .44896 Mdot
.69096 .76855 Mdot
.48271 .69716 Mdot
.62846 .57002 Mdot
.76995 .61782 Mdot
.3931 .56208 Mdot
.51074 .71679 Mdot
.5088 .69364 Mdot
.48148 .3144 Mdot
.58656 .49704 Mdot
.59752 .63113 Mdot
.21477 .38916 Mdot
.42134 .78351 Mdot
.64224 .41799 Mdot
.73892 .58705 Mdot
.36223 .56023 Mdot
.52276 .59404 Mdot
.60422 .53587 Mdot
.379 .49485 Mdot
.45044 .7927 Mdot
.50276 .66158 Mdot
.37714 .52566 Mdot
.48029 .31826 Mdot
.60507 .48826 Mdot
.54611 .57385 Mdot
.17027 .46687 Mdot
.59359 .41123 Mdot
.43217 .51662 Mdot
.32626 .5799 Mdot
.78841 .44599 Mdot
.41767 .49553 Mdot
.64864 .40764 Mdot
.47595 .21717 Mdot
.47526 .35283 Mdot
.51828 .65847 Mdot
.78667 .45705 Mdot
.36271 .57459 Mdot
.35015 .48024 Mdot
.51571 .35116 Mdot
.35016 .54143 Mdot
.6779 .75959 Mdot
.73453 .44902 Mdot
.60946 .3977 Mdot
.49286 .71549 Mdot
.38721 .56817 Mdot
.76634 .47068 Mdot
.35455 .5039 Mdot
.42089 .61975 Mdot
.33567 .53516 Mdot
.5818 .64886 Mdot
.48441 .68135 Mdot
.62206 .54877 Mdot
.32521 .57258 Mdot
.40362 .49882 Mdot
.61978 .27075 Mdot
.29521 .50268 Mdot
.36071 .48688 Mdot
.49848 .6424 Mdot
.5345 .67877 Mdot
.52353 .67443 Mdot
.62123 .40595 Mdot
.65209 .73057 Mdot
.63545 .54963 Mdot
.31294 .52924 Mdot
.61013 .51801 Mdot
.43185 .60589 Mdot
.50766 .35887 Mdot
.20775 .35165 Mdot
.32733 .52268 Mdot
.52372 .6796 Mdot
.67718 .6253 Mdot
.53382 .65971 Mdot
.57043 .38801 Mdot
.64404 .54703 Mdot
.50282 .66488 Mdot
.40025 .50257 Mdot
.54327 .47261 Mdot
.18302 .47614 Mdot
.62942 .56234 Mdot
.43513 .52837 Mdot
.59224 .41223 Mdot
.60526 .34606 Mdot
.14474 .3922 Mdot
.61976 .57647 Mdot
.74677 .60587 Mdot
.35356 .51639 Mdot
.52725 .66958 Mdot
.60023 .55498 Mdot
.59456 .5633 Mdot
.62184 .37452 Mdot
.41423 .51868 Mdot
.40431 .51318 Mdot
.785 .45213 Mdot
.61436 .55818 Mdot
.3306 .56835 Mdot
.40969 .47578 Mdot
.42812 .18661 Mdot
.55628 .73738 Mdot
.86114 .4939 Mdot
.39338 .44637 Mdot
.42058 .78812 Mdot
.50375 .43824 Mdot
.53911 .68273 Mdot
.40956 .51835 Mdot
.3931 .56947 Mdot
.63317 .41805 Mdot
.37997 .51111 Mdot
.60051 .35847 Mdot
.63633 .56972 Mdot
.19377 .36666 Mdot
.67419 .58465 Mdot
.45703 .23497 Mdot
.38074 .50468 Mdot
.57239 .74547 Mdot
.49984 .34661 Mdot
.62427 .59637 Mdot
.52964 .70135 Mdot
.40945 .55626 Mdot
.64886 .35145 Mdot
.60908 .37742 Mdot
.50441 .68386 Mdot
.71679 .63707 Mdot
.65822 .27016 Mdot
.42026 .51846 Mdot
.60077 .3974 Mdot
.69967 .55603 Mdot
.29233 .63366 Mdot
.66811 .55716 Mdot
.47345 .3532 Mdot
.62504 .35769 Mdot
.59187 .5689 Mdot
.54571 .6369 Mdot
.49899 .67284 Mdot
.48689 .72175 Mdot
.57849 .29903 Mdot
.58998 .3746 Mdot
.48487 .34968 Mdot
.61328 .75422 Mdot
.59874 .7715 Mdot
.46324 .34582 Mdot
.62222 .3565 Mdot
.53083 .6706 Mdot
.52295 .70491 Mdot
.51424 .69763 Mdot
.62719 .78523 Mdot
.47536 .67303 Mdot
.4146 .66092 Mdot
.3765 .47374 Mdot
.26218 .54147 Mdot
.33805 .5188 Mdot
.60166 .53306 Mdot
.48243 .69331 Mdot
.51653 .43689 Mdot
.40132 .55174 Mdot
.17575 .46177 Mdot
.3552 .52427 Mdot
.6676 .5693 Mdot
.37685 .52981 Mdot
.30331 .61479 Mdot
.5192 .7339 Mdot
.38425 .51641 Mdot
.65599 .57593 Mdot
.4875 .33002 Mdot
.46479 .71048 Mdot
.40625 .51547 Mdot
.60715 .70661 Mdot
.31634 .49002 Mdot
.47671 .21141 Mdot
.44338 .39425 Mdot
.4772 .36249 Mdot
.29356 .52808 Mdot
.64626 .41858 Mdot
.45599 .66591 Mdot
.26853 .51321 Mdot
.62786 .56195 Mdot
.30161 .74504 Mdot
.6087 .38166 Mdot
.45 .46957 Mdot
.40563 .46567 Mdot
.51293 .3355 Mdot
.47975 .63636 Mdot
.60661 .53578 Mdot
.3494 .56803 Mdot
.35103 .48425 Mdot
.43512 .25623 Mdot
.26822 .52752 Mdot
.31525 .51006 Mdot
.51894 .33974 Mdot
.40483 .68532 Mdot
.38873 .53224 Mdot
.58838 .41932 Mdot
.49815 .72691 Mdot
.30522 .54348 Mdot
.39317 .67301 Mdot
.35785 .51552 Mdot
.50553 .67118 Mdot
.46913 .69115 Mdot
.63754 .66108 Mdot
.46569 .35514 Mdot
.33596 .53524 Mdot
.43443 .35995 Mdot
.33472 .54546 Mdot
.63801 .54711 Mdot
.40991 .49325 Mdot
.61552 .38247 Mdot
.67297 .72994 Mdot
.63541 .40523 Mdot
.41018 .49733 Mdot
.51367 .70231 Mdot
.59878 .54734 Mdot
.53912 .29386 Mdot
.65478 .29811 Mdot
.41389 .66546 Mdot
.78464 .3237 Mdot
.49482 .35323 Mdot
.50303 .31295 Mdot
.65457 .53635 Mdot
.38604 .51942 Mdot
.47521 .39273 Mdot
.365 .46888 Mdot
.38193 .53075 Mdot
.39552 .48812 Mdot
.64654 .51643 Mdot
.6372 .55931 Mdot
.63768 .37548 Mdot
.37104 .50354 Mdot
.36009 .51759 Mdot
.49028 .66939 Mdot
.48961 .33104 Mdot
.63218 .40819 Mdot
.49873 .33634 Mdot
.64005 .39329 Mdot
.22235 .2995 Mdot
.43173 .48756 Mdot
.48705 .32809 Mdot
.65626 .53772 Mdot
.51711 .66595 Mdot
.75124 .45909 Mdot
.60926 .41119 Mdot
.62508 .36505 Mdot
.3564 .52138 Mdot
.51221 .66484 Mdot
.48952 .65968 Mdot
.50631 .33615 Mdot
.60567 .55571 Mdot
.41043 .499 Mdot
.4195 .51314 Mdot
.25841 .37134 Mdot
.5874 .39803 Mdot
.32093 .65281 Mdot
.64822 .6689 Mdot
.38753 .5187 Mdot
.481 .69758 Mdot
.36483 .48932 Mdot
.31215 .25852 Mdot
.50186 .72397 Mdot
.41435 .53347 Mdot
.57402 .76929 Mdot
.58168 .37577 Mdot
.59914 .66014 Mdot
.32514 .49073 Mdot
.72098 .26406 Mdot
.3509 .55683 Mdot
.41424 .16778 Mdot
.78256 .55519 Mdot
.32199 .54417 Mdot
.3781 .55413 Mdot
.20887 .41885 Mdot
.34729 .51522 Mdot
.7759 .46296 Mdot
.37254 .44362 Mdot
.53172 .71096 Mdot
.47397 .42072 Mdot
.56766 .39782 Mdot
.46117 .34836 Mdot
.6151 .39601 Mdot
.54351 .33202 Mdot
.4868 .31814 Mdot
.50444 .70803 Mdot
.3875 .55175 Mdot
.33034 .41779 Mdot
.57233 .3705 Mdot
.37804 .46109 Mdot
.63864 .54552 Mdot
.57587 .4156 Mdot
.61179 .35183 Mdot
.61785 .54962 Mdot
.32853 .50174 Mdot
.21471 .54926 Mdot
.67335 .31164 Mdot
.62462 .20065 Mdot
.60507 .54021 Mdot
.63608 .53406 Mdot
.65797 .74394 Mdot
.45945 .34528 Mdot
.38593 .26542 Mdot
.57784 .70902 Mdot
.63601 .52745 Mdot
.39976 .31143 Mdot
.65682 .37712 Mdot
.60131 .71315 Mdot
.54837 .7145 Mdot
.43553 .5011 Mdot
.40164 .50161 Mdot
.60678 .56028 Mdot
.33543 .42089 Mdot
.71752 .72591 Mdot
.62478 .55818 Mdot
.35548 .58712 Mdot
.59929 .48834 Mdot
.77558 .45111 Mdot
.78485 .44874 Mdot
.48035 .36125 Mdot
.62885 .24428 Mdot
.4903 .68495 Mdot
.51137 .32969 Mdot
.56459 .55529 Mdot
.34117 .53578 Mdot
.61974 .56223 Mdot
.75022 .46335 Mdot
.62361 .53657 Mdot
.47313 .32457 Mdot
.48858 .36316 Mdot
.47973 .69009 Mdot
.53138 .70466 Mdot
.41443 .78929 Mdot
.3875 .351 Mdot
.3351 .51717 Mdot
.23569 .64163 Mdot
.49573 .6547 Mdot
.27673 .5139 Mdot
.45653 .32633 Mdot
.49108 .32844 Mdot
.28477 .67572 Mdot
.40131 .5384 Mdot
.54194 .37627 Mdot
.40064 .52578 Mdot
.36766 .29127 Mdot
.42237 .51917 Mdot
.62542 .37446 Mdot
.34072 .56053 Mdot
.67795 .42153 Mdot
.376 .56196 Mdot
.36683 .48398 Mdot
.63964 .36023 Mdot
.43634 .54144 Mdot
.61421 .38123 Mdot
.41614 .51062 Mdot
.51497 .31828 Mdot
.61613 .39372 Mdot
.2893 .3903 Mdot
.51515 .52968 Mdot
.76524 .46748 Mdot
.46497 .32169 Mdot
.48874 .31294 Mdot
.34417 .40806 Mdot
.52789 .70488 Mdot
.56085 .71191 Mdot
.3848 .52018 Mdot
.65772 .38642 Mdot
.63585 .56522 Mdot
.36157 .51677 Mdot
.41852 .55268 Mdot
.31872 .49998 Mdot
.49737 .6607 Mdot
.58854 .37349 Mdot
.48182 .32831 Mdot
.60614 .40078 Mdot
.62109 .25774 Mdot
.64381 .35469 Mdot
.29975 .50596 Mdot
.41945 .55787 Mdot
.32583 .60748 Mdot
.30317 .73639 Mdot
.54351 .79127 Mdot
.49967 .67902 Mdot
.76052 .45596 Mdot
.49665 .36138 Mdot
.44546 .66141 Mdot
.52941 .68804 Mdot
.6193 .36125 Mdot
.39351 .52366 Mdot
.38814 .58492 Mdot
.55783 .60102 Mdot
.46117 .64221 Mdot
.33497 .40073 Mdot
.62808 .3488 Mdot
.776 .45693 Mdot
.65129 .73547 Mdot
.44821 .67656 Mdot
.51257 .42714 Mdot
.38275 .48807 Mdot
.46694 .31386 Mdot
.52487 .66289 Mdot
.57519 .31221 Mdot
.61205 .56207 Mdot
.53494 .46149 Mdot
.38092 .50584 Mdot
.70672 .61253 Mdot
.51274 .7018 Mdot
.47504 .31923 Mdot
.60725 .56128 Mdot
.45866 .34702 Mdot
.78706 .44957 Mdot
.63899 .23842 Mdot
.34335 .54581 Mdot
.35185 .4915 Mdot
.65216 .52797 Mdot
.49224 .68541 Mdot
.51871 .37773 Mdot
.42753 .25416 Mdot
.59793 .39152 Mdot
.54202 .36136 Mdot
.53821 .673 Mdot
.38641 .62831 Mdot
.61134 .40296 Mdot
.58976 .53875 Mdot
.47994 .41056 Mdot
.64951 .56318 Mdot
.40532 .52033 Mdot
.52159 .68656 Mdot
.62371 .57764 Mdot
.60523 .27323 Mdot
.32596 .22179 Mdot
.31485 .61142 Mdot
.32582 .54378 Mdot
.20219 .36047 Mdot
.47358 .19665 Mdot
.38479 .4168 Mdot
.64658 .53792 Mdot
.36029 .49736 Mdot
.42075 .49771 Mdot
.33622 .5537 Mdot
.63769 .57349 Mdot
.54801 .23729 Mdot
.61794 .36731 Mdot
.34894 .52571 Mdot
.49654 .31733 Mdot
.62394 .38391 Mdot
.68207 .37903 Mdot
.65466 .39358 Mdot
.5316 .71634 Mdot
.4104 .53802 Mdot
.64799 .70914 Mdot
.38235 .16774 Mdot
.6325 .55919 Mdot
.7657 .46737 Mdot
.34485 .49257 Mdot
.49225 .80387 Mdot
.52384 .67559 Mdot
.59662 .38881 Mdot
.37607 .49447 Mdot
.58516 .24933 Mdot
.77506 .43354 Mdot
.64783 .37177 Mdot
.5241 .706 Mdot
.40172 .41984 Mdot
.37839 .51192 Mdot
.34953 .55428 Mdot
.49287 .69339 Mdot
.66128 .25444 Mdot
.67179 .72381 Mdot
.36909 .48678 Mdot
.62103 .54963 Mdot
.80098 .67697 Mdot
.32494 .49363 Mdot
.5222 .62585 Mdot
.78144 .46905 Mdot
.61776 .69445 Mdot
.32062 .65626 Mdot
.29298 .50968 Mdot
.22204 .35283 Mdot
.42984 .40782 Mdot
.19766 .35255 Mdot
.4539 .36366 Mdot
.71051 .45691 Mdot
.23489 .28228 Mdot
.65926 .57268 Mdot
.26796 .55201 Mdot
.22208 .4496 Mdot
.70292 .66207 Mdot
.45726 .42214 Mdot
.7675 .34368 Mdot
.6361 .28255 Mdot
.8052 .47579 Mdot
.64903 .40118 Mdot
.3502 .29424 Mdot
.40604 .49166 Mdot
.48474 .19021 Mdot
.30635 .62828 Mdot
.70899 .7463 Mdot
.21339 .33328 Mdot
.4316 .35491 Mdot
.18944 .48215 Mdot
.33753 .23097 Mdot
.23094 .52321 Mdot
.56405 .61259 Mdot
.82015 .43134 Mdot
.61301 .75864 Mdot
.4458 .26786 Mdot
.41964 .46194 Mdot
.69285 .41354 Mdot
.52805 .20715 Mdot
.42723 .71917 Mdot
.73726 .73476 Mdot
.62279 .41526 Mdot
.50743 .73132 Mdot
.2494 .37752 Mdot
.45756 .6848 Mdot
.67365 .51998 Mdot
.22026 .35448 Mdot
.40582 .18072 Mdot
.30654 .61727 Mdot
.74519 .27899 Mdot
.32208 .72545 Mdot
.44929 .8368 Mdot
.52979 .53006 Mdot
.48565 .7231 Mdot
.76526 .41294 Mdot
.59716 .77232 Mdot
.66265 .60829 Mdot
.44665 .63841 Mdot
.47717 .36764 Mdot
.31918 .38677 Mdot
.51634 .70607 Mdot
.30668 .65044 Mdot
.7955 .45674 Mdot
.57562 .62109 Mdot
.68749 .37377 Mdot
.29067 .27091 Mdot
.73871 .47093 Mdot
.61169 .71779 Mdot
.72991 .57866 Mdot
.15513 .54343 Mdot
.41115 .33527 Mdot
.3664 .22916 Mdot
.58229 .60833 Mdot
.44279 .41892 Mdot
.71412 .69911 Mdot
.391 .36748 Mdot
.58625 .78085 Mdot
.19139 .61478 Mdot
.53363 .18599 Mdot
.17379 .54093 Mdot
.46297 .66725 Mdot
.31699 .50832 Mdot
.30947 .2775 Mdot
.42247 .78131 Mdot
.4802 .36397 Mdot
.16902 .49317 Mdot
.46 .31752 Mdot
.46073 .68471 Mdot
.71318 .64686 Mdot
.38798 .63526 Mdot
.56482 .41291 Mdot
.49209 .30256 Mdot
.3037 .50723 Mdot
.42201 .87113 Mdot
.19435 .38361 Mdot
.63079 .66985 Mdot
.42846 .18529 Mdot
.5714 .55652 Mdot
.52412 .38694 Mdot
.63812 .57034 Mdot
.28987 .24189 Mdot
.52604 .69501 Mdot
.32787 .19009 Mdot
.32327 .21664 Mdot
.79342 .63209 Mdot
.5516 .90408 Mdot
.74226 .5134 Mdot
.26079 .55694 Mdot
.28048 .44151 Mdot
.28894 .41461 Mdot
.72391 .70545 Mdot
.80414 .60931 Mdot
.5819 .5181 Mdot
.62958 .2222 Mdot
.24986 .27862 Mdot
.38681 .30306 Mdot
.50883 .22309 Mdot
.71054 .67115 Mdot
.51811 .50949 Mdot
.5361 .63538 Mdot
.50307 .53572 Mdot
.54426 .61085 Mdot
.17484 .51386 Mdot
.46405 .78544 Mdot
.72767 .76773 Mdot
.52683 .36357 Mdot
.82395 .55048 Mdot
.432 .20103 Mdot
.29474 .37674 Mdot
.43846 .62986 Mdot
.67021 .68895 Mdot
.30312 .50288 Mdot
.65662 .72406 Mdot
.4296 .448 Mdot
.53206 .31785 Mdot
.64838 .74352 Mdot
.68978 .51908 Mdot
.4264 .26401 Mdot
.23952 .35761 Mdot
.5721 .75692 Mdot
.5215 .72025 Mdot
.39788 .38753 Mdot
.40783 .31937 Mdot
.43023 .18978 Mdot
.76848 .61782 Mdot
.6128 .19521 Mdot
.7818 .61715 Mdot
.36119 .47018 Mdot
.27222 .52531 Mdot
.43179 .47038 Mdot
.40244 .35873 Mdot
.34981 .47677 Mdot
.70916 .59803 Mdot
.45283 .183 Mdot
.45556 .79368 Mdot
.48703 .27427 Mdot
.26527 .70332 Mdot
.58507 .19056 Mdot
.31085 .28228 Mdot
.77711 .5645 Mdot
.26063 .49551 Mdot
.30669 .79154 Mdot
.63233 .38565 Mdot
.39482 .31225 Mdot
.59289 .57557 Mdot
.57603 .30315 Mdot
.21027 .49188 Mdot
.78203 .6484 Mdot
.45874 .18105 Mdot
.67658 .69536 Mdot
.65933 .31817 Mdot
.56542 .44751 Mdot
.58431 .43112 Mdot
.25394 .68797 Mdot
.40474 .57535 Mdot
.44983 .59559 Mdot
.50555 .3182 Mdot
.42045 .7674 Mdot
.33665 .27475 Mdot
.73638 .34248 Mdot
.29849 .5684 Mdot
.73368 .3952 Mdot
.77988 .45803 Mdot
.54038 .46695 Mdot
.15803 .3742 Mdot
.32495 .4694 Mdot
.75857 .53063 Mdot
.5494 .18663 Mdot
.47429 .40053 Mdot
.40129 .2221 Mdot
.68448 .6467 Mdot
.18279 .56696 Mdot
.36144 .19 Mdot
.68443 .30598 Mdot
.18343 .37724 Mdot
.5808 .16168 Mdot
.19591 .6017 Mdot
.25952 .67741 Mdot
.64329 .59026 Mdot
.35383 .14581 Mdot
.60243 .37106 Mdot
.33319 .77266 Mdot
.43093 .78673 Mdot
.56242 .25327 Mdot
.53444 .64477 Mdot
.45001 .53955 Mdot
.77904 .48182 Mdot
.5336 .73583 Mdot
.29842 .51677 Mdot
.15185 .50212 Mdot
.20078 .65228 Mdot
.15764 .50498 Mdot
.60777 .20945 Mdot
.18727 .36998 Mdot
.23434 .42263 Mdot
.41785 .65813 Mdot
.3055 .31515 Mdot
.41348 .49999 Mdot
.36074 .3252 Mdot
.74722 .52135 Mdot
.65541 .31103 Mdot
.63268 .62406 Mdot
.54234 .66606 Mdot
.19228 .54109 Mdot
.12384 .42542 Mdot
.32155 .70749 Mdot
.37501 .6862 Mdot
.53338 .58807 Mdot
.39522 .34413 Mdot
.47118 .49798 Mdot
.71815 .36982 Mdot
.43291 .1951 Mdot
.22185 .44529 Mdot
.41237 .29157 Mdot
.75829 .35891 Mdot
.61724 .45609 Mdot
.81888 .54229 Mdot
.29149 .26163 Mdot
.26112 .39125 Mdot
.79635 .61169 Mdot
.25061 .50803 Mdot
.74184 .70397 Mdot
.70786 .29905 Mdot
.57709 .34182 Mdot
.42081 .30599 Mdot
.59825 .35179 Mdot
.37997 .30792 Mdot
.56536 .52085 Mdot
.2603 .3534 Mdot
.42016 .40667 Mdot
.37988 .30151 Mdot
.62038 .45586 Mdot
.162 .45449 Mdot
.63412 .18521 Mdot
.23978 .70117 Mdot
.70153 .25094 Mdot
.42497 .44394 Mdot
.35898 .47928 Mdot
.49695 .17304 Mdot
.15127 .45722 Mdot
.38817 .1712 Mdot
.71347 .60656 Mdot
.59478 .26849 Mdot
.66191 .57394 Mdot
.25783 .71338 Mdot
.72202 .29602 Mdot
.38348 .19718 Mdot
.54755 .7874 Mdot
.61018 .51375 Mdot
.68408 .70041 Mdot
.28464 .73203 Mdot
.22463 .5347 Mdot
.32029 .67173 Mdot
.42616 .47213 Mdot
.2783 .60907 Mdot
.49296 .72399 Mdot
.73018 .5966 Mdot
.39491 .36086 Mdot
.62994 .39 Mdot
.26679 .40086 Mdot
.44543 .60493 Mdot
.30561 .49938 Mdot
.61577 .32774 Mdot
.55608 .67087 Mdot
.33675 .76396 Mdot
.5927 .5079 Mdot
.21631 .29927 Mdot
.75151 .5477 Mdot
.46509 .50272 Mdot
.41904 .38667 Mdot
.57183 .32296 Mdot
.6616 .71332 Mdot
.65664 .54848 Mdot
.23812 .30472 Mdot
.49296 .51923 Mdot
.40355 .38686 Mdot
.28054 .61403 Mdot
.40916 .25368 Mdot
.42322 .54675 Mdot
.65817 .65185 Mdot
.43843 .71209 Mdot
.53888 .45748 Mdot
.47596 .72446 Mdot
.55857 .68003 Mdot
.8104 .32198 Mdot
.66092 .45477 Mdot
.78736 .58878 Mdot
.2451 .30144 Mdot
.64694 .56327 Mdot
.53099 .65114 Mdot
.36554 .30825 Mdot
.4423 .24479 Mdot
.44484 .74252 Mdot
.66882 .37531 Mdot
.44603 .29216 Mdot
.72607 .3228 Mdot
.20404 .36103 Mdot
.18693 .43964 Mdot
.69678 .76738 Mdot
.50004 .6466 Mdot
.39333 .2514 Mdot
.44259 .25209 Mdot
.50707 .65056 Mdot
.47086 .63391 Mdot
.56803 .62904 Mdot
.17844 .36376 Mdot
.64862 .72186 Mdot
.68316 .24559 Mdot
.47703 .40802 Mdot
.56933 .24123 Mdot
.55822 .31404 Mdot
.43765 .28748 Mdot
.25018 .29893 Mdot
.2985 .65053 Mdot
.21309 .52034 Mdot
.41271 .45437 Mdot
.42929 .80411 Mdot
.26351 .72147 Mdot
.52969 .5159 Mdot
.37253 .6276 Mdot
.69025 .52984 Mdot
.33017 .54431 Mdot
.15433 .54116 Mdot
.47319 .20469 Mdot
.63007 .76672 Mdot
.60302 .50222 Mdot
.37051 .54804 Mdot
.39005 .47011 Mdot
.3382 .42187 Mdot
.62921 .68218 Mdot
.22044 .66686 Mdot
.45131 .26369 Mdot
.39532 .42953 Mdot
.29411 .62519 Mdot
.75943 .53294 Mdot
.28923 .27691 Mdot
.45374 .20493 Mdot
.56554 .50183 Mdot
.74725 .52637 Mdot
.52891 .41898 Mdot
.67392 .23309 Mdot
.71302 .41033 Mdot
.23629 .41137 Mdot
.56189 .74314 Mdot
.6509 .68254 Mdot
.58267 .31802 Mdot
.35473 .487 Mdot
.71615 .63749 Mdot
.32655 .24014 Mdot
.69271 .79523 Mdot
.72529 .68908 Mdot
.14444 .49865 Mdot
.36794 .61748 Mdot
.65043 .68984 Mdot
.20423 .51706 Mdot
.66089 .8263 Mdot
.70845 .39005 Mdot
.18289 .49447 Mdot
.55083 .43509 Mdot
.2266 .31917 Mdot
.61103 .58758 Mdot
.59943 .7463 Mdot
.27371 .71079 Mdot
.18298 .35726 Mdot
.34278 .25277 Mdot
.25824 .29952 Mdot
.25315 .49429 Mdot
.16608 .39091 Mdot
.5286 .78132 Mdot
.80963 .47393 Mdot
.60545 .42081 Mdot
.7118 .58182 Mdot
.23633 .60343 Mdot
.50398 .60874 Mdot
.40274 .3048 Mdot
.82159 .50794 Mdot
.44436 .69618 Mdot
.22926 .5551 Mdot
.31691 .34873 Mdot
.67125 .65754 Mdot
.42319 .38974 Mdot
.36209 .20537 Mdot
.81678 .46396 Mdot
.53595 .29447 Mdot
.76759 .58721 Mdot
.6385 .23609 Mdot
.62557 .68028 Mdot
.68739 .45674 Mdot
.36329 .22964 Mdot
.68861 .27705 Mdot
.42599 .3467 Mdot
.82637 .31713 Mdot
.54187 .21378 Mdot
.5644 .61888 Mdot
.18439 .5379 Mdot
.44332 .1982 Mdot
.51938 .78031 Mdot
.70101 .74587 Mdot
.4187 .80335 Mdot
.36579 .34514 Mdot
.39875 .49043 Mdot
.15404 .40809 Mdot
.32181 .37725 Mdot
.17064 .5052 Mdot
.54169 .17258 Mdot
.26373 .60002 Mdot
.31747 .48313 Mdot
.66282 .40009 Mdot
.53608 .56333 Mdot
.31515 .34273 Mdot
.19908 .47419 Mdot
.39324 .7985 Mdot
.54663 .35774 Mdot
.72322 .43857 Mdot
.66405 .36792 Mdot
.33028 .44038 Mdot
.73611 .52389 Mdot
.64951 .67231 Mdot
.5367 .35446 Mdot
.64524 .45538 Mdot
.39823 .33153 Mdot
.31759 .65213 Mdot
.22426 .53166 Mdot
.76366 .66882 Mdot
.68012 .52291 Mdot
.63429 .41695 Mdot
.2155 .39676 Mdot
.55628 .21112 Mdot
.70012 .60491 Mdot
.20976 .6118 Mdot
.67545 .68546 Mdot
.33488 .30525 Mdot
.29987 .30563 Mdot
.73647 .69391 Mdot
.82119 .40978 Mdot
.21989 .60268 Mdot
.43168 .80534 Mdot
.54574 .3781 Mdot
.39109 .60893 Mdot
.22205 .30107 Mdot
.42999 .29335 Mdot
.27449 .33194 Mdot
.51904 .53585 Mdot
.42433 .74969 Mdot
.24532 .58896 Mdot
.27627 .40717 Mdot
.52506 .43447 Mdot
.37512 .83718 Mdot
.54984 .67306 Mdot
.15421 .54925 Mdot
.61187 .54895 Mdot
.594 .80709 Mdot
.6522 .43475 Mdot
.55398 .51818 Mdot
.4985 .42563 Mdot
.65259 .6525 Mdot
.58105 .652 Mdot
.61822 .21472 Mdot
.76181 .68409 Mdot
.64616 .35724 Mdot
.45081 .3839 Mdot
.69011 .25969 Mdot
.21458 .38235 Mdot
.33668 .56891 Mdot
.57551 .21875 Mdot
.52687 .51309 Mdot
.64982 .31132 Mdot
.49968 .17537 Mdot
.69196 .56147 Mdot
.33128 .58055 Mdot
.39409 .34796 Mdot
.18559 .50322 Mdot
.33894 .20867 Mdot
.67911 .7489 Mdot
.42846 .44728 Mdot
.65089 .58855 Mdot
.23543 .45285 Mdot
.20643 .37356 Mdot
.5415 .39964 Mdot
.6166 .72552 Mdot
.41138 .32449 Mdot
.15837 .61977 Mdot
.19623 .63679 Mdot
.22417 .66993 Mdot
.4696 .397 Mdot
.50071 .74153 Mdot
.48277 .79968 Mdot
.28021 .32728 Mdot
.68885 .6005 Mdot
.53764 .2022 Mdot
.39741 .31605 Mdot
.62064 .83159 Mdot
.43728 .64335 Mdot
.62087 .25575 Mdot
.24612 .5976 Mdot
.40298 .77286 Mdot
.63433 .58876 Mdot
.35088 .34998 Mdot
.47895 .49804 Mdot
.64043 .52411 Mdot
.66654 .66075 Mdot
.60272 .70182 Mdot
.27102 .33522 Mdot
.43182 .70987 Mdot
.40247 .43548 Mdot
.23674 .35306 Mdot
.52051 .74347 Mdot
.56977 .31177 Mdot
.54486 .30774 Mdot
.46755 .44008 Mdot
.60054 .38856 Mdot
.29401 .49819 Mdot
.5561 .466 Mdot
.54107 .43411 Mdot
.33005 .78495 Mdot
.46561 .31214 Mdot
.54631 .69882 Mdot
.59435 .79319 Mdot
.51308 .65013 Mdot
.14279 .45466 Mdot
.71715 .37439 Mdot
.29025 .61862 Mdot
.67599 .29805 Mdot
.75997 .39126 Mdot
.4675 .85358 Mdot
.23458 .65793 Mdot
.51039 .56088 Mdot
.45338 .64374 Mdot
.47815 .66105 Mdot
.56489 .40579 Mdot
.78622 .47659 Mdot
.33509 .67498 Mdot
.75909 .51784 Mdot
.32039 .30519 Mdot
.47239 .70492 Mdot
.59148 .24077 Mdot
.46526 .49174 Mdot
.18609 .34021 Mdot
.64499 .40845 Mdot
.26347 .75298 Mdot
.43475 .54011 Mdot
.21941 .4955 Mdot
.48698 .17224 Mdot
.68015 .72903 Mdot
.61158 .32339 Mdot
.7888 .35295 Mdot
.32356 .55154 Mdot
.39169 .43476 Mdot
.51597 .70855 Mdot
.36623 .27407 Mdot
.48329 .33877 Mdot
.35887 .39172 Mdot
.61797 .5155 Mdot
.81252 .58721 Mdot
.7384 .53473 Mdot
.53052 .73101 Mdot
.48419 .53379 Mdot
.33958 .26284 Mdot
.58898 .72349 Mdot
.52624 .51057 Mdot
.21005 .41477 Mdot
.44018 .73862 Mdot
.47013 .69807 Mdot
.21127 .62333 Mdot
.43939 .2595 Mdot
.30388 .22469 Mdot
.43884 .57707 Mdot
.53491 .54365 Mdot
.58105 .73971 Mdot
.66934 .6481 Mdot
.32792 .66257 Mdot
.42895 .19627 Mdot
.39535 .37926 Mdot
.59511 .76618 Mdot
.37721 .30345 Mdot
.4475 .52202 Mdot
.71675 .44303 Mdot
.72034 .5601 Mdot
.59018 .83877 Mdot
.28418 .69373 Mdot
.69862 .70804 Mdot
.478 .61803 Mdot
.75719 .52931 Mdot
.54919 .69209 Mdot
.5315 .26532 Mdot
.43168 .73113 Mdot
.70003 .36321 Mdot
.26016 .26187 Mdot
.4368 .19187 Mdot
.5516 .60608 Mdot
.66388 .3488 Mdot
.43078 .4125 Mdot
.46367 .50444 Mdot
.52142 .46283 Mdot
.31838 .53925 Mdot
.32357 .43754 Mdot
.67137 .74912 Mdot
.679 .623 Mdot
.4534 .52947 Mdot
.20707 .33013 Mdot
.31775 .21381 Mdot
.16552 .41245 Mdot
.54555 .36967 Mdot
.54049 .70584 Mdot
.18413 .57968 Mdot
.35808 .65495 Mdot
.36126 .20393 Mdot
.23946 .62304 Mdot
.79265 .29982 Mdot
.20423 .49386 Mdot
.68487 .51561 Mdot
.79828 .62416 Mdot
.59799 .64051 Mdot
.50613 .18017 Mdot
.81194 .4715 Mdot
.47423 .27783 Mdot
.51571 .17921 Mdot
.41726 .86736 Mdot
.27169 .68969 Mdot
.60767 .71261 Mdot
.24854 .54549 Mdot
.45248 .43886 Mdot
.76188 .50794 Mdot
.40607 .48709 Mdot
.57685 .3697 Mdot
.62561 .31818 Mdot
.40086 .32395 Mdot
.34307 .60942 Mdot
.76868 .51194 Mdot
.31483 .33887 Mdot
.35957 .28767 Mdot
.45763 .25324 Mdot
.20375 .47609 Mdot
.33926 .67162 Mdot
.3232 .57652 Mdot
.48979 .74168 Mdot
.47703 .3594 Mdot
.53762 .31852 Mdot
.41573 .52734 Mdot
.63253 .32099 Mdot
.58125 .69093 Mdot
.14881 .50653 Mdot
.50787 .26503 Mdot
.4515 .22997 Mdot
.55456 .70961 Mdot
.63916 .67268 Mdot
.28529 .29607 Mdot
.70607 .65663 Mdot
.78503 .51697 Mdot
.46143 .78581 Mdot
.19813 .36761 Mdot
.66397 .69566 Mdot
.40845 .27797 Mdot
.40273 .82613 Mdot
.61626 .52327 Mdot
.34055 .76264 Mdot
.22599 .43348 Mdot
.69092 .66393 Mdot
.46387 .67065 Mdot
.67952 .49849 Mdot
.71577 .45753 Mdot
.68353 .66144 Mdot
.55401 .18644 Mdot
.36982 .2615 Mdot
.25514 .61164 Mdot
.18884 .42086 Mdot
.58717 .40499 Mdot
.40963 .29311 Mdot
.65884 .47726 Mdot
.75669 .49589 Mdot
.57943 .75372 Mdot
.21193 .31232 Mdot
.51857 .45257 Mdot
.31012 .38627 Mdot
.34291 .54991 Mdot
.39681 .67569 Mdot
.666 .63636 Mdot
.62185 .46086 Mdot
.77666 .60056 Mdot
.50961 .72323 Mdot
.7392 .56492 Mdot
.80454 .44499 Mdot
.3538 .35987 Mdot
.46197 .59787 Mdot
.55003 .74718 Mdot
.44359 .33629 Mdot
.78175 .4384 Mdot
.35473 .57821 Mdot
.31071 .39758 Mdot
.57975 .43151 Mdot
.30692 .7337 Mdot
.26822 .69066 Mdot
.21279 .40012 Mdot
.47373 .21608 Mdot
.69686 .60401 Mdot
.23616 .62153 Mdot
.58032 .64297 Mdot
.41928 .64209 Mdot
.73157 .63765 Mdot
.32324 .49152 Mdot
.5342 .26394 Mdot
.53972 .66879 Mdot
.20769 .39234 Mdot
.41252 .62028 Mdot
.29039 .38788 Mdot
.54641 .48993 Mdot
.30326 .27699 Mdot
.50834 .49774 Mdot
.48954 .1738 Mdot
.60048 .63887 Mdot
.39397 .36254 Mdot
.59401 .51664 Mdot
.5522 .43288 Mdot
.7336 .68465 Mdot
.28301 .25707 Mdot
.7702 .66451 Mdot
.28296 .44181 Mdot
.6949 .70218 Mdot
.44467 .80605 Mdot
.52787 .17432 Mdot
.3798 .35792 Mdot
.52221 .46491 Mdot
.46954 .50015 Mdot
.5687 .60235 Mdot
.75211 .46058 Mdot
.55363 .26885 Mdot
.35251 .66685 Mdot
.49506 .24062 Mdot
.68996 .3453 Mdot
.32428 .56557 Mdot
.49762 .80512 Mdot
.19341 .40076 Mdot
.45196 .7144 Mdot
.54553 .519 Mdot
.6105 .3055 Mdot
.34994 .36783 Mdot
.88668 .48781 Mdot
.15298 .53957 Mdot
.34382 .549 Mdot
.47732 .41484 Mdot
.35693 .38705 Mdot
.60391 .35613 Mdot
.34015 .68259 Mdot
.21149 .39862 Mdot
.63905 .53416 Mdot
.58933 .27524 Mdot
.70811 .55581 Mdot
.65111 .64773 Mdot
.26761 .41098 Mdot
.64954 .51953 Mdot
.14285 .47526 Mdot
.58138 .21445 Mdot
.67687 .6331 Mdot
.85946 .40852 Mdot
.71835 .59716 Mdot
.54221 .73874 Mdot
.33797 .25049 Mdot
.16216 .44951 Mdot
.47105 .39936 Mdot
.57817 .29949 Mdot
.27292 .6992 Mdot
.39254 .36927 Mdot
.37941 .28251 Mdot
.76676 .58632 Mdot
.74519 .57186 Mdot
.79036 .48647 Mdot
.7604 .3892 Mdot
.35997 .8044 Mdot
.28829 .63419 Mdot
.18167 .45026 Mdot
.71284 .38117 Mdot
.63376 .82606 Mdot
.28927 .24257 Mdot
.34913 .33107 Mdot
.77759 .52485 Mdot
.36135 .23614 Mdot
.34266 .40366 Mdot
.48551 .78354 Mdot
.71142 .36523 Mdot
.44882 .75972 Mdot
.74804 .38748 Mdot
.74649 .63216 Mdot
.37973 .3053 Mdot
.41945 .78572 Mdot
.5181 .4467 Mdot
.20748 .44928 Mdot
.83482 .53019 Mdot
.41902 .37804 Mdot
.60288 .28084 Mdot
.28892 .42574 Mdot
.2235 .36264 Mdot
.35183 .22998 Mdot
.50993 .45603 Mdot
.41848 .86452 Mdot
.17675 .50927 Mdot
.71378 .65848 Mdot
.37228 .47431 Mdot
.25933 .25703 Mdot
.48824 .45518 Mdot
.2375 .63148 Mdot
.52708 .1928 Mdot
.52475 .29345 Mdot
.57532 .73658 Mdot
.31741 .50408 Mdot
.23003 .64569 Mdot
.35613 .62443 Mdot
.4006 .77442 Mdot
.60607 .32148 Mdot
.41572 .38549 Mdot
.8302 .54412 Mdot
.26553 .43264 Mdot
.46192 .51117 Mdot
.53914 .6731 Mdot
.15153 .48073 Mdot
.23997 .50496 Mdot
.29076 .49901 Mdot
.25933 .53269 Mdot
.76696 .67301 Mdot
.82112 .37729 Mdot
.45159 .49285 Mdot
.65675 .71365 Mdot
.40368 .3065 Mdot
.30446 .30932 Mdot
.24942 .67204 Mdot
.57258 .90508 Mdot
.47655 .17216 Mdot
.53929 .64458 Mdot
.34301 .75811 Mdot
.44828 .39225 Mdot
.16883 .41217 Mdot
.75537 .35439 Mdot
.56297 .32277 Mdot
.76629 .69621 Mdot
.38925 .39762 Mdot
.4229 .53172 Mdot
.5926 .20032 Mdot
.2902 .24701 Mdot
.8359 .54922 Mdot
.22529 .2989 Mdot
.33851 .46978 Mdot
.4295 .48712 Mdot
.80495 .70849 Mdot
.21729 .34162 Mdot
.30954 .48813 Mdot
.74512 .70519 Mdot
.51244 .63117 Mdot
.4123 .50563 Mdot
.71957 .48056 Mdot
.42463 .30708 Mdot
.36753 .28759 Mdot
.18236 .35923 Mdot
.50383 .73978 Mdot
.6372 .32032 Mdot
.59202 .56981 Mdot
.50482 .42701 Mdot
.38052 .58567 Mdot
.62454 .57867 Mdot
.34382 .30318 Mdot
.48139 .44557 Mdot
.62023 .49482 Mdot
.43266 .30714 Mdot
.6503 .20211 Mdot
.33514 .61295 Mdot
.54725 .59953 Mdot
.26695 .47869 Mdot
.45061 .7189 Mdot
.31612 .34001 Mdot
.29955 .33487 Mdot
.52882 .18353 Mdot
.59083 .14692 Mdot
.63125 .44009 Mdot
.43772 .56616 Mdot
.48979 .74977 Mdot
.3392 .66273 Mdot
.25044 .57313 Mdot
.6415 .48462 Mdot
.7698 .44525 Mdot
.33164 .47698 Mdot
.46288 .51555 Mdot
.61523 .51577 Mdot
.14373 .57269 Mdot
.39847 .47997 Mdot
.28749 .65683 Mdot
.33932 .22355 Mdot
.5733 .31281 Mdot
.31272 .60423 Mdot
.33076 .5606 Mdot
.52505 .78054 Mdot
.48362 .45552 Mdot
.41978 .4211 Mdot
.55004 .30985 Mdot
.17671 .40927 Mdot
.41065 .6197 Mdot
.2688 .62614 Mdot
.35897 .52386 Mdot
.49963 .30714 Mdot
.5997 .71665 Mdot
.22833 .66265 Mdot
.45804 .58715 Mdot
.35721 .20139 Mdot
.52088 .28828 Mdot
.45969 .26509 Mdot
.26733 .57133 Mdot
.16811 .50733 Mdot
.7229 .68612 Mdot
.26318 .59113 Mdot
.64591 .76209 Mdot
.6857 .47271 Mdot
.31968 .34713 Mdot
.6635 .38419 Mdot
.45109 .53546 Mdot
.49344 .63211 Mdot
.14733 .39863 Mdot
.24081 .67375 Mdot
.58875 .58641 Mdot
.55046 .37117 Mdot
.39577 .64341 Mdot
.50273 .43069 Mdot
.84764 .37172 Mdot
.76295 .33809 Mdot
.14254 .4798 Mdot
.35844 .27136 Mdot
.49853 .75586 Mdot
.67709 .65503 Mdot
.28023 .54232 Mdot
.64116 .36718 Mdot
.1715 .41185 Mdot
.45046 .56916 Mdot
.74574 .62164 Mdot
.41676 .50313 Mdot
.6111 .77017 Mdot
.4598 .45851 Mdot
.65175 .34172 Mdot
.59589 .34982 Mdot
.70676 .73316 Mdot
.31914 .24956 Mdot
.48474 .45971 Mdot
.80328 .32535 Mdot
.19433 .4815 Mdot
.24002 .30255 Mdot
.66708 .37126 Mdot
.62601 .80296 Mdot
.46618 .61849 Mdot
.46105 .4673 Mdot
.57608 .54708 Mdot
.26089 .46224 Mdot
.68989 .6595 Mdot
.32027 .29728 Mdot
.59317 .67118 Mdot
.56389 .6081 Mdot
.72404 .1961 Mdot
.35544 .32038 Mdot
.44944 .62519 Mdot
.72031 .6269 Mdot
.22857 .30491 Mdot
.4652 .2916 Mdot
.62799 .20296 Mdot
.6762 .43088 Mdot
.41261 .57444 Mdot
.43337 .70486 Mdot
.22282 .50105 Mdot
.70651 .5401 Mdot
.42391 .8478 Mdot
.54303 .20742 Mdot
.46056 .26895 Mdot
.62996 .46514 Mdot
.50889 .64902 Mdot
.53277 .6435 Mdot
.71756 .32479 Mdot
.70745 .23717 Mdot
.43233 .43669 Mdot
.20738 .36718 Mdot
.50598 .85204 Mdot
.39375 .26283 Mdot
.16977 .39208 Mdot
.61322 .61594 Mdot
.47138 .63014 Mdot
.31629 .3338 Mdot
.52893 .36811 Mdot
.58582 .3712 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo09[ooooo0_l0002]ooooo`00
7?ooool00ol0003oooooooooo`2Jooooo`;o00001_ooool2o`000:Gooooo000Looooo`03o`000?oo
oooooooo0:;ooooo0_l0002Uooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0:gooooo0_l0002Jooooo`007?ooool2o`0009Cooooo0_l0000Hooooo`;o
0000V_ooool001cooooo00?o0000ooooooooool0Toooool2o`000;Cooooo000Looooo`03o`000?oo
oooooooo08cooooo0_l0000Xooooo`;o0000TOooool001cooooo00?o0000ooooooooool0S?ooool2
o`0002Sooooo0_l0002Aooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`25ooooo`;o0000`_ooool001cooooo00?o0000ooooooooool0Poooool4
o`000<;ooooo000Looooo`03o`000?oooooooooo08?ooooo0_l0000oooooo`;o0000Poooool001co
oooo00?o0000ooooooooool0Ooooool2o`0004?ooooo0_l00023ooooo`007?ooool00ol0003ooooo
ooooo`1oooooo`;o0000b?ooool001cooooo00?o0000ooooooooool0NOooool2o`000<kooooo000L
ooooo`03o`000?oooooooooo07Wooooo0_l0003>ooooo`007?ooool00ol0003oooooooooo`1`oooo
o`;o0000G_ooool2o`0007Oooooo000Looooo`03o`000?oooooooooo06oooooo0ol0001:ooooo`;o
00004_ooool2o`0007Oooooo000Looooo`03o`000?oooooooooo06oooooo0_l0001;ooooo`;o0000
Roooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2iooooo`;o
0000S_ooool001cooooo00?o0000ooooooooool0XOooool2o`0001Kooooo0_l0002>ooooo`007?oo
ool00ol0003oooooooooo`1hooooo`;o00001?ooool2o`0000?ooooo0_l0000Aooooo`;o00002Ooo
ool2o`000:Kooooo000Looooo`03o`000?oooooooooo07Sooooo1?l000001?oooooo0000o`000?l0
0003ooooo`;o00004Oooool3o`000003ooooool0003o00000:gooooo000Looooo`03o`000?oooooo
oooo07[ooooo1Ol00005ooooo`;o00004Oooool2o`000005ooooool0003o0000o`000?ooool01Ol0
0005ooooo`;o00000_ooool2o`0009_ooooo000Looooo`03o`000?oooooooooo07cooooo0_l00006
ooooo`;o00005Oooool2o`000003ooooool0003o000000?o00001Oooool2o`0000;ooooo0_l00002
ooooo`;o0000Uoooool001cooooo00?o0000ooooooooool0Koooool2o`0000oooooo0_l00002oooo
o`;o00002oooool2o`000003ooooool0003o000000Kooooo0ol000001Ooooooo0000o`000?l0003o
oooo00;o00002_ooool2o`0009Oooooo000Looooo`03o`000?oooooooooo06oooooo0_l0000;oooo
o`;o000000Coooooo`000?l0003o00000_ooool2o`0000Wooooo1?l000000ooooooo0000o`000006
ooooo`?o00000_ooool2o`000003ooooool0003o000000;ooooo0_l0002Oooooo`007?ooool00ol0
003oooooooooo`1looooo`;o000000?oooooo`000?l000000_l000001?oooooo0000o`000?ooool2
o`0000?ooooo0_l000000ooooooo0000o`000007ooooo`;o00003?ooool6o`0000?ooooo0ol0000H
ooooo`;o0000OOooool001cooooo00?o0000ooooooooool0Ioooool2o`0000Wooooo0_l0000=oooo
o`;o00000oooool4o`0000;ooooo0_l000000ooooooo0000o`000003o`0000Cooooo1?l0000:oooo
o`;o00000_ooool2o`0000?ooooo0ol00003ooooo`Co000000?oooooo`000?l000003_ooool2o`00
07gooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool0
0ol0003oooooooooo`1Wooooo`;o00002Oooool2o`0000kooooo0_l00002ooooo`Ko000000?ooooo
o`000?l000002?l00003ooooo`;o00002_ooool4o`0000_ooooo1?l000000ooooooo0000o`00002=
ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^
k_ooooooA4A400Kooooo00?o0000ooooooooool0KOooool2o`0001?ooooo0_l00004ooooo`Co0000
00?oooooo`000?l000001?ooool5o`0000kooooo1?l0000Iooooo`;o00008_ooool2o`00063ooooo
00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00ol0003oooooooooo`1Dooooo`;o00005oooool2o`0000Gooooo0_l000000ooooooo0000o`00
0002o`0000Oooooo0_l00003ooooo`Co000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l0
000>ooooo`;o00005oooool2o`0000;ooooo0_l0000Rooooo`;o0000H?ooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06ooooo`?o0000E?ooool2
o`0001[ooooo0_l000001Ooooooo0000o`000?l0003ooooo00Co00000oooool2o`0000;ooooo0_l0
0003ooooo`Co000000?oooooo`000?l000000_ooool2o`0001Wooooo0_l0000@ooooo`Co00001_oo
ool3o`0000Gooooo0_l0001hooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<
ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0L?ooool5o`0000Wooooo0_l00002
ooooo`;o00001Oooool2o`0000Gooooo0_l00004ooooo`;o00004oooool2o`00013ooooo0_l00008
ooooo`?o00001Oooool3o`0007Oooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo
00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Zooooo`;o00001_ooool2o`00
00kooooo0_l0000<ooooo`So00004?ooool2o`0000?ooooo0_l0000Cooooo`;o00002oooool3o`00
07Oooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@
4006ooooo`03o`000?oooooooooo06[ooooo0_l00007ooooo`;o00003_ooool2o`0000gooooo1?l0
00000ooooooo0000o`000002o`0000gooooo0_l00003ooooo`;o00000_ooool2o`0000oooooo0ol0
000=ooooo`;o0000MOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@
o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0Hoooool2o`0000cooooo1?l0000<ooooo`Co
00004_ooool4o`00017ooooo0_l00003ooooo`Co00001?ooool2o`0000Oooooo1ol000000ooooooo
0000o`000006ooooo`;o00000oooool4o`0006kooooo000Looooo`03o`000?oooooooooo06?ooooo
1?l0000:ooooo`Co00000oooool2o`0000Oooooo1?l0000Aooooo`?o00004oooool2o`0000Gooooo
0_l00004ooooo`;o00002_ooool4o`000004ooooool0003o0000ooooo`;o00001_ooool6o`0006ko
oooo000Looooo`03o`000?oooooooooo06Gooooo0_l00009ooooo`;o00001_ooool2o`0000Wooooo
0_l00002ooooo`;o00003Oooool3o`0000?ooooo0_l0000Iooooo`;o00003?ooool3o`0000Gooooo
0_l00006ooooo`;o00000oooool2o`0001Gooooo0_l0001Fooooo`007?ooool00ol0003ooooooooo
o`1Oooooo`;o00001Oooool2o`0000;ooooo0_l00004ooooo`;o00002_ooool2o`000003ooooool0
003o000000Cooooo1?l00008ooooo`;o00002Oooool3o`0000?ooooo0_l0000Cooooo`;o000000?o
ooooo`000?l000002_ooool2o`000003ooooool0003o000000oooooo0_l000000ooooooo0000o`00
000Booooo`;o0000E_ooool001cooooo00?o0000ooooooooool0Goooool2o`0000Gooooo0_l00002
ooooo`Co00003_ooool5o`0000Cooooo0_l00003ooooo`;o00000oooool4o`0000[ooooo0_l00003
ooooo`;o00005_ooool2o`0000gooooo0_l0000Booooo`;o0000J_ooool001cooooo00?o0000oooo
ooooool0J_ooool4o`000004ooooool0003o0000ooooo`?o00002Oooool2o`0000;ooooo0_l00006
ooooo`;o00000oooool2o`0000Gooooo1?l00014ooooo`;o0000JOooool001cooooo00?o0000oooo
ooooool0I_ooool2o`0000;ooooo0_l00003ooooo`;o000000Coooooo`000?l0003o00003Oooool2
o`0000?ooooo0_l00006ooooo`?o00000oooool5o`0003gooooo0_l00005ooooo`;o0000JOooool0
01cooooo00?o0000ooooooooool0I_ooool2o`0000;ooooo0_l00006ooooo`;o00000_ooool2o`00
0003ooooool0003o000000cooooo0_l00007ooooo`?o00000_ooool4o`0002gooooo0_l00004oooo
o`;o00001?ooool2o`0000?ooooo0_l00009ooooo`;o0000IOooool001cooooo00?o0000oooooooo
ool0Hoooool2o`0000gooooo0_l00002ooooo`;o000000?oooooo`000?l000004_ooool2o`0000;o
oooo0ol0000Jooooo`;o00001oooool4o`0000_ooooo0_l00004ooooo`;o00001?ooool2o`0000ko
oooo0_l0000@ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0F_ooool2o`0000Oooooo
0_l000000ooooooo0000o`00000Nooooo`;o00001Oooool4o`000003ooooool0003o000000Wooooo
0_l0000?ooooo`;o00001Oooool6o`000003ooooool0003o000000kooooo0_l0000Dooooo`;o0000
4?ooool2o`0005?ooooo000Looooo`03o`000?oooooooooo05[ooooo0_l0000:ooooo`;o00007_oo
ool2o`0000Cooooo0_l000000ooooooo0000o`000006ooooo`;o00001?ooool2o`0001Kooooo0_l0
0005ooooo`;o00002_ooool2o`00013ooooo0_l0001]ooooo`007?ooool00ol0003oooooooooo`1K
ooooo`;o00005_ooool2o`00017ooooo0_l00004ooooo`;o00002?ooool3o`00027ooooo0_l0000<
ooooo`;o00004?ooool2o`0006gooooo000Looooo`;o0000G?ooool3o`000004ooooool0003o0000
o`0000;ooooo0ol00003ooooo`;o00001oooool2o`0000Oooooo0_l00008ooooo`;o00001?ooool2
o`0000Sooooo1?l0000Cooooo`;o00002Oooool4o`0001Kooooo0_l00004ooooo`;o00001_ooool2
o`0000Cooooo0_l0001Qooooo`007?ooool00ol0003oooooooooo`1Looooo`;o000000Coooooo`00
0?l0003o00000_ooool3o`0000?ooooo1?l0000:ooooo`;o00000_ooool3o`0000;ooooo0_l00004
ooooo`;o00000oooool2o`0000?ooooo0_l00005ooooo`;o00004oooool2o`0000Cooooo0_l00003
ooooo`;o00006?ooool3o`0000?ooooo0_l00006ooooo`;o00001?ooool2o`00067ooooo000Loooo
o`03o`000?oooooooooo057ooooo0_l00004ooooo`?o000000Coooooo`000?l0003o00001?ooool2
o`0000Sooooo0_l0000:ooooo`;o00000oooool2o`000004ooooool0003o0000o`0000Cooooo0_l0
00000ooooooo0000o`000005ooooo`;o00005oooool2o`0000Oooooo0_l0000Aooooo`;o00002ooo
ool2o`0007Cooooo000Looooo`03o`000?oooooooooo057ooooo0_l00004ooooo`Ko00001Oooool2
o`0000_ooooo0_l00003ooooo`;o00002_ooool2o`0000Sooooo0ol00009ooooo`;o00004_ooool2
o`0000?ooooo0_l0000Eooooo`;o000000?oooooo`000?l000004Oooool2o`0000Cooooo0_l0001U
ooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o00001oooool4o`0000gooooo0_l00002oooo
o`;o00000oooool2o`0000Kooooo0_l00007ooooo`Co00000_ooool2o`0000;ooooo0_l00005oooo
o`;o00002oooool2o`0000Gooooo0_l00003ooooo`;o00006?ooool2o`0000Wooooo0_l00006oooo
o`;o00001?ooool2o`0000;ooooo0_l00003ooooo`;o0000G?ooool001cooooo00?o0000oooooooo
ool0DOooool2o`0000Wooooo0_l0000=ooooo`;o00003Oooool5o`0000Kooooo1?l00006ooooo`;o
000000?oooooo`000?l000003Oooool4o`0000Cooooo0ol0000Hooooo`;o00003_ooool2o`00013o
oooo0_l00003ooooo`;o00003oooool2o`0004_ooooo000Looooo`03o`000?oooooooooo05Cooooo
0_l0000>ooooo`;o00004Oooool2o`000004ooooool0003o0000ooooo`;o00002Oooool2o`0000?o
oooo0_l00002ooooo`?o00003Oooool2o`0000Kooooo0_l00005ooooo`;o00002oooool2o`0000Go
oooo1?l0000:ooooo`;o00000_ooool2o`00013ooooo0_l00003ooooo`;o00003Oooool2o`0004_o
oooo000Looooo`03o`000?oooooooooo05Cooooo0_l00002ooooo`;o000000?oooooo`000?l00000
1oooool2o`0000_ooooo0_l00004ooooo`;o00003oooool2o`0000?ooooo0_l00002ooooo`?o0000
7?ooool2o`0000_ooooo0_l00002ooooo`;o00000oooool2o`0000[ooooo0_l00002ooooo`?o0000
3oooool2o`0000?ooooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`1Hooooo`Go00000_oo
ool2o`0000Wooooo0ol00004ooooo`Co00003_ooool2o`000003ooooool0003o000001;ooooo0_l0
000Pooooo`;o00000oooool3o`0000?ooooo0_l00005ooooo`;o00001oooool2o`0000?ooooo0_l0
001[ooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00002oooool2o`0000?ooooo1?l00007
ooooo`?o00001Oooool3o`0000cooooo1?l000000ooooooo0000o`000004ooooo`;o00002?ooool2
o`0000;ooooo0_l0000Pooooo`;o00000oooool3o`0000?ooooo0_l00005ooooo`?o00002oooool2
o`00013ooooo0_l0001Iooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00000_ooool2o`00
00Kooooo0_l00008ooooo`Go00001oooool2o`0000Gooooo0_l00004ooooo`?o00001_ooool2o`00
00Wooooo0_l00008ooooo`;o000000?oooooo`000?l000002oooool2o`0001Sooooo0ol00002oooo
o`;o00001?ooool2o`0000;ooooo0_l0000Jooooo`;o000000?oooooo`000?l00000FOooool001co
oooo00?o0000ooooooooool0BOooool2o`0000[ooooo0_l00008ooooo`Go000000?oooooo`000?l0
00001?ooool2o`0000_ooooo0ol0000Dooooo`;o00001Oooool2o`000003ooooool0003o000000Oo
oooo0_l00002ooooo`;o00006?ooool2o`0000?ooooo0_l00004ooooo`;o00007_ooool4o`0005[o
oooo000Looooo`03o`000?oooooooooo05kooooo0_l00005ooooo`;o00001oooool2o`000004oooo
ool0003o0000ooooo`?o00004oooool4o`000004ooooool0003o0000ooooo`;o00000_ooool2o`00
00[ooooo0_l000000ooooooo0000o`00000Nooooo`?o00000oooool2o`0000?ooooo0ol0000Joooo
o`;o0000F_ooool001cooooo00?o0000ooooooooool0D?ooool2o`0000;ooooo0_l00008ooooo`;o
00002_ooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool3o`0000_ooooo0_l00006oooo
o`Go00000oooool3o`0000Sooooo0_l00006ooooo`;o00007_ooool3o`0000?ooooo0_l00002oooo
o`Co00008?ooool2o`0005Cooooo000Looooo`03o`000?oooooooooo053ooooo0_l00002ooooo`;o
00005?ooool2o`0000;ooooo0_l00004ooooo`;o00002oooool3o`0000Cooooo0_l000000ooooooo
0000o`000002o`0000Cooooo1?l00006ooooo`;o00002?ooool2o`000004ooooool0003o0000o`00
02;ooooo0_l0000Hooooo`;o00002?ooool2o`0005Cooooo000Looooo`03o`000?oooooooooo04Ko
oooo0_l0000>ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Sooooo0_l0000=ooooo`;o
00000_ooool2o`0000Gooooo0_l00003ooooo`;o00001?ooool4o`0000kooooo1?l000001?oooooo
0000o`000?l0000Qooooo`;o000000?oooooo`000?l000001Oooool2o`0000gooooo1?l0001Noooo
o`007?ooool2o`0004Cooooo1Ol00004ooooo`Ko00001?ooool2o`000003ooooool0003o000000Wo
oooo0_l0000Booooo`;o00000oooool2o`0000kooooo0_l00006ooooo`;o00001_ooool2o`0000Ko
oooo0_l0000Aooooo`;o00005?ooool2o`000003ooooool0003o000000Gooooo0_l00008ooooo`;o
00000oooool2o`0001Gooooo0_l00019ooooo`007?ooool00ol0003oooooooooo`13ooooo`Co0000
0oooool8o`0001[ooooo0_l00009ooooo`Go00005?ooool2o`0000;ooooo0_l00003ooooo`;o0000
00Coooooo`000?l0003o00003_ooool2o`0000Sooooo0ol0000Iooooo`;o00003Oooool2o`0000?o
oooo0_l00006ooooo`;o00003Oooool2o`0004Wooooo000Looooo`03o`000?oooooooooo04;ooooo
0_l00003ooooo`Go00004_ooool2o`0000Cooooo0_l00003ooooo`;o000000?oooooo`000?l00000
1Oooool2o`0000;ooooo1Ol00003ooooo`;o00001?ooool3o`000003ooooool0003o000000Gooooo
1_l00003ooooo`Go000000?oooooo`000?l000002Oooool2o`000003ooooool0003o000000Sooooo
0_l0000:ooooo`;o00003?ooool6o`0000Cooooo0_l0000Booooo`;o0000F?ooool001cooooo00?o
0000ooooooooool0@_ooool2o`0000?ooooo1?l0000Cooooo`?o00000oooool2o`0000?ooooo0_l0
0008ooooo`;o00000oooool2o`0000Gooooo0_l00004ooooo`?o000000Coooooo`000?l0003ooooo
0_l00002ooooo`Co00000_ooool;o`0000Wooooo0_l000000ooooooo0000o`000002o`000003oooo
ool0003o000000Wooooo0_l00004ooooo`;o00001?ooool2o`0000Kooooo0_l00002ooooo`;o0000
1?ooool2o`0006cooooo000Looooo`03o`000?oooooooooo047ooooo0_l0000Looooo`;o00004_oo
ool2o`0000?ooooo0_l00003ooooo`?o00001Oooool3o`0000Cooooo0_l00004oooooa3o00003Ooo
ool2o`000004ooooool0003o0000ooooo`Co00001?ooool2o`0000[ooooo0_l00004ooooo`Co0000
1?ooool2o`0001kooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`11ooooo`Co00006Ooo
ool5o`0001[ooooo0ol0000AoooooaCo00001?ooool2o`0000Oooooo0_l000000ooooooo0000o`00
0002o`0001?ooooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l0000Nooooo`;o0000D?oo
ool001cooooo00?o0000ooooooooool0@oooool2o`000003ooooool0003o000001Kooooo1Ol0000<
ooooo`;o00001?ooool2o`000003ooooool0003o000000?ooooo0ol000000ooooooo0000o`00000>
oooooaco00001Oooool2o`0000Gooooo0_l0000:ooooo`Co000000?oooooo`000?l000000_l00000
0ooooooo0000o`000003o`000004ooooool0003o0000o`00037ooooo0_l0000nooooo`007?ooool0
0ol0003oooooooooo`16ooooo`;o00002Oooool2o`0000Sooooo0ol00004ooooo`;o00002oooool3
o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000000_ooool2
o`0000Wooooo3?l000000ooooooo0000o`00000>o`0000Kooooo0_l000001?oooooo0000o`000?oo
ool2o`0000Kooooo0_l00002ooooo`Co000000Coooooo`000?l0003o00000_ooool5o`000003oooo
ool0003o000000;o00001_ooool2o`0000Oooooo0_l0000Booooo`;o00001Oooool2o`0000Cooooo
0_l0000nooooo`007?ooool00ol0003oooooooooo`1@ooooo`?o00000_ooool2o`0000Cooooo0ol0
0004ooooo`;o00003?ooool3o`0000_ooooo0_l00002ooooo`;o000000?oooooo`000?l000001?oo
ool2o`000003ooooool0003o000001Co00001Oooool3o`0000Oooooo0_l000000ooooooo0000o`00
0005ooooo`;o00000_ooool4o`0000Gooooo0ol00002ooooo`;o00001_ooool2o`0000Kooooo0_l0
0004ooooo`;o000000?oooooo`000?l000004Oooool3o`0000?ooooo1?l00014ooooo`007?ooool0
0ol0003oooooooooo`1@ooooo`;o00000oooool5o`0000Cooooo0_l0000Aooooo`;o00002oooool2
o`0000;ooooo0_l00007ooooo`;o000000?oooooo`000?l000005_l000000ooooooo0000o`000003
o`0000Gooooo0_l00005ooooo`;o00000oooool2o`0000;ooooo1Ol0000Oooooo`;o00005?ooool2
o`0000Cooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00004oooool5o`00
00Cooooo0_l0000>ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Gooooo0ol0000>oooo
oa[o00001?ooool2o`0000;ooooo0_l00005ooooo`;o00000oooool2o`0000;ooooo0_l000000ooo
oooo0000o`00000?ooooo`;o00006?ooool2o`0005Sooooo000Looooo`03o`000?oooooooooo03ko
oooo1_l0000@ooooo`?o00001oooool2o`0000?ooooo0_l00009ooooo`;o00001oooool2o`0000Go
oooo0ol000001?oooooo0000o`000?ooool2o`0000Cooooo0_l00002oooooaSo00001Oooool3o`00
00kooooo0_l00009ooooo`;o00001Oooool2o`0000Cooooo0_l00007ooooo`;o00003oooool2o`00
05Sooooo000Looooo`03o`000?oooooooooo03kooooo0_l00002ooooo`;o00002oooool2o`0000?o
oooo0ol00007ooooo`;o00000oooool2o`0001?ooooo0_l00008ooooo`;o000000?oooooo`000?l0
00001?ooool3o`0000?ooooo3ol000000ooooooo0000o`000003o`0000?ooooo0_l000000ooooooo
0000o`00000Booooo`Go00000oooool2o`0000Gooooo1?l00003ooooo`;o00001_ooool2o`0001Co
oooo1?l0001Aooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00001Oooool2o`000003oooo
ool0003o000000[ooooo0_l00004ooooo`;o00001oooool2o`0000?ooooo0_l0000Aooooo`Co0000
00?oooooo`000?l000003oooool2o`000003ooooool0003o000001Ko00000_ooool2o`000003oooo
ool0003o000001;ooooo1Ol00003ooooo`;o00001_ooool3o`0000?ooooo0_l0000:ooooo`;o0000
4?ooool4o`00057ooooo000Looooo`03o`000?oooooooooo03Wooooo0_l00005ooooo`;o000000?o
ooooo`000?l000007_ooool3o`0000kooooo1?l00003ooooo`Co00001?ooool2o`0000Kooooo0_l0
0002oooooaSo00000oooool2o`0000Wooooo0_l000000ooooooo0000o`000005ooooo`Go00000ooo
ool5o`0000Cooooo0_l00004ooooo`;o00002_ooool3o`0000Kooooo0_l00008ooooo`;o000000?o
ooooo`000?l000004oooool2o`0003[ooooo000Looooo`03o`000?oooooooooo06?ooooo0ol0000=
ooooo`?o00001oooool2o`0000Cooooo0_l00002ooooo`;o00000_ooool4o`000003ooooool0003o
000000Wo000000?oooooo`000?l000001ol00005ooooo`;o00002Oooool2o`000003ooooool0003o
000000;ooooo0_l000000ooooooo0000o`00000;o`000003ooooool0003o000000gooooo0_l00005
ooooo`;o00001_ooool2o`0000Sooooo0_l000000ooooooo0000o`000008ooooo`;o00002Oooool2
o`0003[ooooo000Looooo`;o0000C?ooool2o`0000Kooooo0_l0000>ooooo`?o00002?ooool2o`00
00?ooooo0_l00002ooooo`;o00000oooool4o`0000Oooooo0_l00004ooooo`;o000000?oooooo`00
0?l000005Ol0000:ooooo`;o000000?oooooo`000?l000001_ooool4o`000003ooooool0003o0000
00oo00000_ooool2o`000003ooooool0003o000000?ooooo0_l0000Tooooo`;o0000AOooool001co
oooo00?o0000ooooooooool0?Oooool2o`000003ooooool0003o000000;ooooo0_l00003ooooo`Co
00001?ooool4o`0000Sooooo0_l00004ooooo`;o00002Oooool2o`0000Oooooo0_l000000ooooooo
0000o`000004o`0000Kooooo0ol00009oooooaGo00002_ooool2o`000003ooooool0003o000000Oo
oooo2_l000000ooooooo0000o`000003o`000003ooooool0003o000000;o00000_ooool2o`000003
ooooool0003o000002?ooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`0eooooo`;o0000
1_ooool2o`000003ooooool0003o000000;ooooo0_l00003ooooo`;o00001_ooool2o`0000[ooooo
0_l0000Kooooo`?o00002Oooool4o`0000Oooooo5Ol00005ooooo`;o00003OoooolHo`0000[ooooo
0_l00006ooooo`;o00002oooool3o`0000Sooooo0ol0001:ooooo`007?ooool00ol0003ooooooooo
o`0eooooo`;o000000?oooooo`000?l000000_ooool2o`0000Kooooo0_l00002ooooo`Co00005?oo
ool2o`0000gooooo0_l00007ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Oooooo0ol0
0006oooooa;o000000?oooooo`000?l000001Oooool2o`000003ooooool0003o000000;ooooo0_l0
0006ooooo`?o000000?oooooo`000?l000004ol00009ooooo`;o00001_ooool2o`0000_ooooo1?l0
0008ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0>?ooool2o`0000;ooooo1Ol00004
ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00003_ooool6o`0000_ooooo0_l00003
ooooo`;o00000_ooool3o`000003ooooool0003o000000?o00002?ooool2o`0000Sooooo2_l00000
0ooooooo0000o`000003o`000003ooooool0003o000000Kooooo1?l00002ooooo`;o00001Oooool8
o`000003ooooool0003o000000Oo000000?oooooo`000?l000001Ol0000=ooooo`;o00004Oooool2
o`0005Cooooo000Looooo`03o`000?oooooooooo03Kooooo0_l00006ooooo`?o00001?ooool2o`00
00Oooooo0_l0000>ooooo`;o00000_ooool2o`0000gooooo0_l000001?oooooo0000o`000?l00002
ooooo`;o000000Coooooo`000?l0003o00001_ooool2o`0000Wooooo0_l000000ooooooo0000o`00
0002ooooo`Ko000000?oooooo`000?l000000_ooool4o`000003ooooool0003o000000?ooooo0_l0
0004ooooo`;o00001OoooolIo`0000kooooo0_l000000ooooooo0000o`00001Tooooo`007?ooool0
0ol0003oooooooooo`0fooooo`;o00000oooool4o`000003ooooool0003o000000gooooo0_l0000M
ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Cooooo1Ol00005ooooo`;o00002Oooool2
o`0000Gooooo1Ol000000ooooooo0000o`000003ooooo`Co000000Coooooo`000?l0003o00002?oo
ool2o`0000Cooooo6Ol00003ooooo`?o00003?ooool2o`0006Cooooo000Looooo`03o`000?oooooo
oooo03Wooooo1_l000000ooooooo0000o`00000=ooooo`?o00006?ooool2o`000005ooooool0003o
0000o`000?ooool00_l00002ooooo`;o00001?ooool5o`0001Oooooo0_l00004ooooo`;o00002Ooo
ool2o`0000?ooooo1?l000000ooooooo0000o`000002oooooaco00000_ooool3o`0000?ooooo0ol0
0008ooooo`;o00000_ooool2o`0002Gooooo0_l0000gooooo`007?ooool00ol0003oooooooooo`0`
ooooo`;o00001oooool4o`0000;ooooo0_l0000?ooooo`;o00006?ooool2o`000003ooooool0003o
000000kooooo0ol00006ooooo`;o00005Oooool2o`0000Oooooo0ol00004ooooo`Co00000_ooool2
o`000003ooooool0003o000001_o00000_ooool2o`0000?ooooo1?l00007ooooo`;o00000_ooool2
o`0002Gooooo0_l0000gooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00001_ooool2o`00
00Gooooo0_l0000<ooooo`;o00002?ooool2o`0000?ooooo0_l00007ooooo`;o00000oooool3o`00
00;ooooo0_l00002ooooo`;o00002Oooool2o`0000Cooooo1?l00007ooooo`?o00002oooool2o`00
00Kooooo1?l00003ooooo`Ko000000?oooooo`000?l000001?oooolKo`000003ooooool0003o0000
00Gooooo0_l000000ooooooo0000o`000004ooooo`;o00006oooool2o`0000?ooooo0_l00010oooo
o`007?ooool00ol0003oooooooooo`0hooooo`;o00004oooool2o`0000Sooooo0_l00003ooooo`;o
00001oooool2o`0000?ooooo1ol00002ooooo`?o00001oooool2o`0000Gooooo0_l00009ooooo`?o
00004oooool2o`0000Gooooo1_l00006oooooaco00001_ooool2o`0000?ooooo0_l000000ooooooo
0000o`000002o`0000?ooooo0_l0000Gooooo`;o00000oooool2o`00043ooooo000Looooo`03o`00
0?oooooooooo02gooooo0_l0000<ooooo`;o00001Oooool2o`0000Sooooo0_l00006ooooo`;o0000
0_ooool2o`0000cooooo0_l00003ooooo`Co00001Oooool2o`0000Oooooo0_l0000@ooooo`;o0000
1_ooool2o`0000?ooooo0_l000000ooooooo0000o`00000Goooooa7o00000_ooool;o`0000Cooooo
0ol00005ooooo`Co00000oooool2o`0005kooooo000Looooo`03o`000?oooooooooo02gooooo0_l0
000<ooooo`;o00001Oooool2o`0000Sooooo0_l00003ooooo`;o000000?oooooo`000?l000000_oo
ool2o`000003ooooool0003o000000;ooooo1?l000000ooooooo0000o`000002o`0000?ooooo0_l0
0003ooooo`;o00003?ooool3o`0000;ooooo0ol00009ooooo`Co00000_ooool4o`0000?ooooo0_l0
00000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00002_oo
oolAo`000003ooooool0003o000000[o00001?ooool3o`0000Cooooo0_l0000<ooooo`;o00005?oo
ool2o`0004;ooooo000Looooo`03o`000?oooooooooo03;ooooo0ol0000=ooooo`?o00003?ooool2
o`0000Gooooo1Ol00002ooooo`Co000000?oooooo`000?l000002_ooool2o`0000Wooooo0_l00000
1?oooooo0000o`000?l00002ooooo`Go00002?ooool3o`0000;ooooo0_l0000;ooooo`?o000000?o
ooooo`000?l000000_l00002ooooo`;o00002?oooolNo`0000;ooooo0_l000000ooooooo0000o`00
0002ooooo`;o00000_ooool3o`0000_ooooo0_l00002ooooo`;o00004?ooool2o`0004;ooooo0000
1_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0
1?ooool00ol0003oooooooooo`0[ooooo`;o00001Oooool3o`0000_ooooo1Ol0000<ooooo`;o0000
1oooool2o`0001Gooooo0_l00007ooooo`?o00002Oooool2o`0000Gooooo0ol00004ooooo`;o0000
00Coooooo`000?l0003ooooo0_l00006ooooo`;o000000?oooooo`000?l000001Oooool2o`0000So
oooo1Ol000000ooooooo0000o`00000Eo`0000?ooooo0_l000000ooooooo0000o`000004o`0000?o
oooo0_l0000?ooooo`;o000000?oooooo`000?l00000DOooool00006oooooomgMgOoV9RHoooooonH
V9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0[oooo
o`;o00001_ooool2o`0000_ooooo1?l0000=ooooo`;o00004Oooool2o`0000;ooooo0_l00007oooo
o`;o00001oooool3o`0000oooooo1?l00004ooooo`Go000000?oooooo`000?l000000_l00007oooo
o`;o00004?oooolOo`0000Gooooo0_l00004ooooo`;o00002?ooool2o`0000Kooooo0_l000000ooo
oooo0000o`00001Aooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`Go
00001_ooool00ol0003oooooooooo`0/ooooo`;o00002Oooool2o`0000Sooooo0ol0000Mooooo`;o
000000?oooooo`000?l000000_ooool2o`0000gooooo1_l0000?ooooo`Co00001Oooool2o`0000Go
oooo0_l0000>ooooo`;o00001OoooolSo`0000_ooooo0_l00003ooooo`;o00000oooool2o`0001So
oooo0_l00012ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04odA4
A?oMgMgoooooo`0000Oooooo0ol0000/ooooo`;o00002Oooool2o`0000;ooooo0_l00004ooooo`;o
00004?ooool2o`0000cooooo0_l00004ooooo`Co00000oooool2o`0000;ooooo0_l00003ooooo`Oo
00003?ooool2o`0000;ooooo0_l00005ooooo`?o00002Oooool2o`0000Wooooo0_l000000ooooooo
0000o`000002ooooobGo00003_ooool2o`0001gooooo0_l00012ooooo`0000?oooooo`000?ooool0
0_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000oooooooo
ool0=Oooool2o`0000Cooooo0_l0000Fooooo`;o00003?ooool2o`0000Cooooo1?l000000ooooooo
0000o`000002o`0000;ooooo0_l00004ooooo`?o000000?oooooo`000?l000000_ooool2o`0000So
oooo0_l00005ooooo`;o00000oooool2o`0000;ooooo1?l000000ooooooo0000o`000002o`000003
ooooool0003o000000Wooooo0_l00003ooooo`;o00001?oooolKo`000003ooooool0003o000000Co
oooo0_l000000ooooooo0000o`00000Tooooo`;o0000@_ooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool02_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo02kooooo
0_l00005ooooo`?o00005oooool2o`0000Cooooo0ol0000Aooooo`;o000000?oooooo`000?l00000
0_l00002ooooo`Ko000000?oooooo`000?l000001Oooool2o`0000?ooooo1_l00006ooooo`;o0000
1?ooool:o`0000?ooooo0_l0000>ooooo`;o00001?oooolMo`0000Gooooo0_l000000ooooooo0000
o`00000booooo`;o0000=?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg3?ooool00oo^k^ko
A4A4o`000007ooooo`03o`000?oooooooooo02kooooo0_l00002ooooo`Ko00004Oooool2o`0000Co
oooo0_l00002ooooo`Go00001_ooool2o`0000_ooooo1Ol00002ooooo`Ko00000oooool2o`0000;o
oooo0_l00004ooooo`Ko00003?ooool5o`0000;ooooo0ol00002ooooo`;o00004oooool4o`000003
ooooool0003o000001;o000000Coooooo`000?l0003ooooo0_l0000=ooooo`?o00008?ooool2o`00
00[ooooo0_l0000dooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003o
oooo00Kooooo00?o0000ooooooooool0<_ooool4o`0000_ooooo0_l00006ooooo`;o00002?ooool2
o`0000Gooooo0_l00002ooooo`;o00002Oooool4o`000003ooooool0003o000000;ooooo0_l00007
ooooo`;o00000_ooool2o`0000Kooooo0ol0000=ooooo`Go00000oooool3o`000003ooooool0003o
000000_ooooo0_l00002ooooo`;o000000?oooooo`000?l000000ol000000ooooooo0000o`00000F
o`000003ooooool0003o000000?ooooo1?l00005ooooo`?o00003_ooool2o`00013ooooo0_l00010
ooooo`007?ooool00ol0003oooooooooo`11ooooo`;o00005oooool2o`000003ooooool0003o0000
00Kooooo0_l000000ooooooo0000o`000003o`0000Oooooo0_l00003ooooo`;o00007?ooool2o`00
00?ooooo0_l000000ooooooo0000o`000004o`0000[ooooo0ol00002ooooo`;o000000Coooooo`00
0?l0003ooooo0_l000000ooooooo0000o`00000Fo`000003ooooool0003o000000?ooooo1?l0000F
ooooo`Co0000D?ooool001cooooo00?o0000ooooooooool0>_ooool2o`0000Cooooo0_l0000;oooo
o`;o00003_ooool2o`0000Cooooo1?l000001?oooooo0000o`000?l00009ooooo`;o00000oooool2
o`0000Cooooo0_l00004ooooo`;o00001Oooool2o`0000Sooooo0_l00004ooooo`;o000000?ooooo
o`000?l000000ol00004ooooo`;o00001Oooool2o`0000?ooooo0_l00002ooooo`Ko000000?ooooo
o`000?l000004ol00004ooooo`;o00007Oooool2o`00053ooooo000Looooo`03o`000?oooooooooo
03[ooooo0_l00004ooooo`;o00001_ooool2o`0000?ooooo0_l0000@ooooo`Ko00001?ooool3o`00
01?ooooo0_l00004ooooo`;o00001Oooool2o`0000?ooooo0_l00003ooooo`;o00002_ooool2o`00
00Cooooo0ol00009ooooo`;o00000_ooool2o`000004ooooool0003o0000o`0000?ooooo3_l00003
ooooo`;o00001?ooool2o`0000[ooooo0_l0000;ooooo`;o0000E_ooool001cooooo00?o0000oooo
ooooool09Oooool2o`00027ooooo0_l0000?ooooo`?o00000oooool4o`0000Oooooo0_l0000@oooo
o`;o00004oooool2o`0000Kooooo0_l00003ooooo`Co000000?oooooo`000?l000000_l00002oooo
o`;o00000_ooool2o`0000Gooooo0_l00006ooooo`;o00001_ooool4o`0000;ooooo0_l000000ooo
oooo0000o`00000Eooooo`;o00002oooool2o`0005Kooooo000Looooo`03o`000?oooooooooo02Go
oooo0_l0000booooo`?o00001_ooool3o`0000;ooooo0_l0000Cooooo`?o00006_ooool2o`0000?o
oooo1?l000000ooooooo0000o`000003o`000003ooooool0003o000000;ooooo0_l0000=ooooo`;o
00000_ooool2o`0001Kooooo0_l0001_ooooo`007?ooool00ol0003oooooooooo`16ooooo`;o0000
2oooool2o`0000Cooooo1?l00005ooooo`?o00000_ooool2o`0000[ooooo0_l00008ooooo`;o0000
8Oooool2o`0000?ooooo0ol000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00007ooooo`Go
00000_ooool2o`0001Kooooo0_l0000Nooooo`;o00003Oooool2o`00043ooooo000Looooo`03o`00
0?oooooooooo03Kooooo0_l0000>ooooo`;o00002oooool4o`0000;ooooo1?l00007ooooo`;o0000
0oooool2o`0000Sooooo0_l00006ooooo`;o00000_ooool2o`0000Sooooo0_l0000Eooooo`;o0000
0_ooool5o`0000?ooooo0_l000001?oooooo0000o`000?l00007ooooo`?o00002oooool2o`0000Oo
oooo0_l0000Vooooo`;o00003Oooool2o`00043ooooo000Looooo`03o`000?oooooooooo02[ooooo
0_l0000:ooooo`;o000000?oooooo`000?l000006_ooool4o`000003ooooool0003o000000Sooooo
0ol00002ooooo`;o00001_ooool2o`0000Sooooo1_l00008ooooo`;o00001?ooool2o`0000?ooooo
0ol00009ooooo`;o00000_ooool2o`000003ooooool0003o000000Kooooo0_l0000Dooooo`Ko0000
1Oooool2o`0001Gooooo0_l0000;ooooo`;o000000?oooooo`000?l000000ol0000Iooooo`;o0000
<_ooool001cooooo00?o0000ooooooooool0:_ooool2o`0000gooooo0_l0000<ooooo`;o00003_oo
ool3o`0000_ooooo0_l000001?oooooo0000o`000?l00006ooooo`;o00000oooool2o`0000Gooooo
0_l00002ooooo`;o00003?ooool2o`0000?ooooo0ol00009ooooo`;o00000_ooool2o`000003oooo
ool0003o000001cooooo0_l00002ooooo`;o00006_ooool4o`0000[ooooo0ol000001?oooooo0000
o`000?ooool2o`0001Wooooo0_l0000booooo`007?ooool00ol0003oooooooooo`14ooooo`;o0000
00?oooooo`000?l000003?ooool5o`0000kooooo0_l00002ooooo`Co000000Goooooo`000?l0003o
0000ooooo`03o`0000Cooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l0000?ooooo`Co
00001_ooool2o`000004ooooool0003o0000ooooo`;o0000??ooool2o`0000cooooo2ol00004oooo
o`;o00004Oooool2o`0003;ooooo000Looooo`03o`000?oooooooooo037ooooo0_l0000=ooooo`;o
00000_ooool2o`0000oooooo0_l00004ooooo`;o00003?ooool7o`000003ooooool0003o000000Co
00000_ooool2o`000004ooooool0003o0000ooooo`;o00001?ooool5o`0000Cooooo0_l00004oooo
o`Oo00001_ooool2o`000004ooooool0003o0000o`0000gooooo0_l0000Vooooo`;o00003Oooool2
o`0000?ooooo3_l00004ooooo`;o0000AOooool001cooooo0_l0000booooo`;o00001?ooool2o`00
00Cooooo0_l000000ooooooo0000o`000002ooooo`;o00005Oooool2o`0000cooooo1_l00003oooo
o`Co00000oooool5o`0000Oooooo1Ol00004ooooo`;o00001?ooool4o`0000?ooooo0_l00008oooo
o`;o00003Oooool2o`0000Sooooo0_l00004ooooo`;o00005_ooool2o`0000gooooo0_l00003oooo
oa7o0000B?ooool001cooooo00?o0000ooooooooool0:oooool2o`0000Cooooo0_l00004ooooo`;o
00000_ooool4o`0000Gooooo0_l00003ooooo`;o00002?ooool2o`0001cooooo1?l00003ooooo`Go
00001Oooool2o`0001Gooooo1?l00008ooooo`;o00000_ooool2o`0000kooooo0_l00002ooooo`?o
00001?ooool2o`0000Sooooo0_l00003ooooo`;o00003Oooool2o`0000cooooo4Ol00018ooooo`00
7?ooool00ol0003oooooooooo`0[ooooo`Co00000_ooool2o`0000Sooooo0_l0000:ooooo`Co0000
2?ooool2o`0000[ooooo0ol0000?ooooo`Go00000_ooool2o`0000Gooooo0_l000001?oooooo0000
o`000?l00004ooooo`;o00001oooool2o`0000Gooooo1?l00005ooooo`;o00001Oooool4o`0000co
oooo0_l00002ooooo`;o00001_ooool3o`0000Kooooo0_l00003ooooo`;o00001_ooool2o`0000Go
oooo1Ol00007oooooaCo0000Aoooool001cooooo00?o0000ooooooooool0;Oooool2o`0000Kooooo
0_l0000;ooooo`;o00000oooool2o`0001Kooooo1?l00005ooooo`;o00001oooool5o`000003oooo
ool0003o000000So000000?oooooo`000?l000000_l00003ooooo`;o000000?oooooo`000?l00000
1?ooool2o`0000Kooooo0_l00002ooooo`;o00000_ooool2o`0000Kooooo0ol0000Hooooo`?o0000
1Oooool4o`0000[ooooo0_l00006ooooo`Co00001?ooool2o`000003ooooool0003o000001?o0000
A_ooool001cooooo00?o0000ooooooooool0<?ooool2o`0000?ooooo0_l0000;ooooo`;o00003?oo
ool3o`000003ooooool0003o000000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000001Ooo
ool2o`0000Oooooo1?l00002ooooo`So00000_ooool6o`0000Gooooo0ol0000;ooooo`;o00000_oo
ool2o`0000Cooooo2Ol0000Iooooo`;o00001Oooool4o`0000cooooo0_l0000:ooooo`Co00000ooo
ool5o`000003ooooool0003o000000_o00000_ooool2o`0004;ooooo000Looooo`03o`000?oooooo
oooo033ooooo0_l00002ooooo`;o00005_ooool2o`0000;ooooo0ol000000ooooooo0000o`000003
ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`;o00002Oooool2o`000004ooooool0
003o0000o`0000Oooooo2ol00006ooooo`;o00000oooool2o`00013ooooo3?l000000ooooooo0000
o`00000Fooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000_ooooo0_l0000:ooooo`;o
00001Oooool>o`000003ooooool0003o000000Cooooo0_l00012ooooo`007?ooool00ol0003ooooo
ooooo`0_ooooo`;o00000oooool2o`00013ooooo0_l00004ooooo`;o00003?ooool2o`0000Gooooo
1ol000001Ooooooo0000o`000?l0003ooooo00Co000000Coooooo`000?l0003o00000oooool@o`00
0003ooooool0003o000000?ooooo0_l00002ooooo`;o00000oooool2o`00017ooooo2Ol0000Foooo
o`;o000000Goooooo`000?l0003o0000ooooo`02o`0001[ooooo0_l00004ooooo`co0000Boooool0
01cooooo00?o0000ooooooooool0;oooool2o`0000cooooo0_l00007ooooo`;o00003Oooool2o`00
00?ooooo0_l00002ooooo`;o00000_ooool6o`000005ooooool0003o0000o`000?ooool00_l00002
oooooa;o000000?oooooo`000?l000001Ol00003ooooo`?o00001_ooool2o`0000Oooooo0_l00008
ooooo`;o000000Coooooo`000?l0003ooooo0ol00003ooooo`?o00001?ooool2o`00017ooooo0_l0
0009ooooo`;o00003oooool2o`0000Cooooo2ol00006ooooo`?o0000@oooool001cooooo00?o0000
ooooooooool0:oooool2o`0000_ooooo0_l00003ooooo`?o00005Oooool2o`000003ooooool0003o
000000Cooooo1?l00006ooooo`Co00000_ooool2o`000003ooooool0003o000000co00000_ooool5
o`000003ooooool0003o000000Kooooo0_l00006ooooo`;o00000_ooool2o`0000?ooooo0_l0000;
ooooo`;o00000_ooool2o`0000?ooooo0ol00004ooooo`;o00004oooool2o`0000Oooooo0_l0000H
ooooo`Wo00001?ooool4o`0004?ooooo000Looooo`03o`000?oooooooooo02_ooooo0_l0000;oooo
o`;o00001?ooool2o`0001?ooooo0ol00002ooooo`;o00001?ooool4o`0000Kooooo1?l000001Ooo
oooo0000o`000?l0003ooooo00Wo000000?oooooo`000?l000002ol00002ooooo`;o00000_ooool2
o`0000Oooooo0ol000000ooooooo0000o`000002o`0000Sooooo0ol0000Eooooo`;o00004Oooool2
o`0002Kooooo1?l00004ooooo`;o0000AOooool001cooooo00?o0000ooooooooool0:oooool2o`00
0003ooooool0003o000000[ooooo0ol0000Fooooo`Go00002OoooolWo`0000;ooooo1_l00008oooo
o`;o00000oooool2o`0000?ooooo0_l00003ooooo`?o00004Oooool2o`0000;ooooo1?l0000Soooo
o`;o00004Oooool2o`0004kooooo000Looooo`03o`000?oooooooooo02kooooo0_l0000:ooooo`?o
00004oooool2o`0000Cooooo0_l00009oooooa_o000000?oooooo`000?l000002_l000000ooooooo
0000o`000002o`0001Cooooo0_l00003ooooo`;o00000oooool2o`0000gooooo0_l00003ooooo`?o
00001_ooool2o`0000;ooooo0_l0000Gooooo`;o00004Oooool2o`0000;ooooo0_l0001:ooooo`00
7?ooool00ol0003oooooooooo`1@ooooo`;o00003oooool2o`000003ooooool0003o000000Go0000
0_oooolNo`000003ooooool0003o000001kooooo0_l0000?ooooo`Ko00000oooool2o`000003oooo
ool0003o000000;ooooo0_l0000^ooooo`;o00007Oooool2o`0002_ooooo000Looooo`03o`000?oo
oooooooo037ooooo0_l0000>ooooo`;o00007?ooool9o`0000?ooooo8?l00002ooooo`;o00001?oo
ool3o`0000kooooo1?l00006ooooo`;o00003Oooool6o`0000?ooooo0_l0001Dooooo`;o0000:ooo
ool001cooooo00?o0000ooooooooool0<Oooool4o`0000?ooooo0_l00005ooooo`Co000000?ooooo
o`000?l000002Oooool4o`0000Wooooo1Ol00002ooooo`Go000000?oooooo`000?l000007?l00000
1?oooooo0000o`000?l00002ooooo`Co00000_ooool3o`0000;ooooo0_l0000:ooooo`Co00001_oo
ool2o`0001Kooooo0ol0000Mooooo`;o0000;?ooool2o`0003?ooooo000Looooo`03o`000?oooooo
oooo02[ooooo0ol00006ooooo`;o00000oooool2o`0000Gooooo0_l00003ooooo`;o00002Oooool4
o`0000Wooooo0ol00007ooooob7o000000?oooooo`000?l000001?ooool3o`0000Cooooo0_l00000
0ooooooo0000o`000007ooooo`;o00006?ooool2o`0000Wooooo0ol0000@ooooo`;o00002oooool2
o`0000[ooooo0_l0000Pooooo`;o0000<oooool001cooooo0_l0000[ooooo`?o00006?ooool2o`00
00Sooooo0_l0000:ooooo`?o00000_oooolWo`000003ooooool0003o000000;o00000oooool2o`00
00Cooooo0_l000000ooooooo0000o`000007ooooo`;o00001_ooool2o`0000Wooooo0_l00005oooo
o`;o000000?oooooo`000?l000000_l0000;ooooo`;o00002_ooool2o`0000Kooooo0_l0000?oooo
o`;o0000EOooool001cooooo00?o0000ooooooooool0;_ooool4o`0000Oooooo0_l0000:ooooo`;o
00000oooool2o`0000Oooooo0_l00004ooooo`Go000000?oooooo`000?l000009Ol00002ooooo`Co
00000_ooool3o`0000;ooooo1?l00009ooooo`;o00001oooool2o`0000Wooooo0_l00008ooooo`Co
00001_ooool2o`0000?ooooo1?l0000@ooooo`Co0000;oooool2o`0003?ooooo000Looooo`03o`00
0?oooooooooo02gooooo1Ol000001?oooooo0000o`000?l00003ooooo`;o00003oooool2o`0000;o
oooo0_l000000ooooooo0000o`000002o`000004ooooool0003o0000ooooo`;o000000?oooooo`00
0?l000000ol000000ooooooo0000o`00000So`0000Oooooo0_l000000ooooooo0000o`000002o`00
00;ooooo0_l00004ooooo`;o000000?oooooo`000?l000006oooool2o`000003ooooool0003o0000
00Kooooo0_l00005ooooo`;o00003Oooool2o`0000?ooooo0_l0000?ooooo`;o00004Oooool2o`00
00_ooooo0_l0000cooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o00001?ooool5o`0001Ko
oooo0_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000000_l000001Ooooooo
0000o`000?l0003ooooo00?o000000?oooooo`000?l000005_l00002ooooo`Oo00001oooool2o`00
0003ooooool0003o000000Ko00000_ooool4o`0000Kooooo1?l00006ooooo`;o00003?ooool2o`00
00Gooooo0ol0000Gooooo`;o00004_ooool4o`0000Kooooo0_l00006ooooo`;o000000?oooooo`00
0?l00000@?ooool001cooooo00?o0000ooooooooool0=Oooool3o`00017ooooo0_l00009ooooo`Co
000000?oooooo`000?l000001_l00002ooooobCo000000?oooooo`000?l000001?ooool2o`0000;o
oooo1Ol00004ooooo`;o00001Oooool2o`000003ooooool0003o000000;o00001_ooool2o`0000go
oooo0_l00002ooooo`Go00009_ooool2o`0000?ooooo0_l00002ooooo`Co00000_ooool2o`0000Ko
oooo0_l00013ooooo`007?ooool00ol0003oooooooooo`0eooooo`;o00002?ooool4o`0000Cooooo
1Ol00008ooooo`Co00001Oooool^o`0000Sooooo0_l0000=ooooo`;o00000oooool3o`000003oooo
ool0003o0000013ooooo0ol00002ooooo`Oo000000?oooooo`000?l000000_ooool2o`0000_ooooo
0_l0000@ooooo`;o00001oooool4o`000003ooooool0003o000000gooooo0_l0000mooooo`007?oo
ool00ol0003oooooooooo`0oooooo`Go00000oooool2o`000003ooooool0003o000000gooooo0_l0
00000ooooooo0000o`000002o`000003ooooool0003o000001?o000000?oooooo`000?l000004_l0
00000ooooooo0000o`000004ooooo`?o00001oooool2o`0000[ooooo0_l000000ooooooo0000o`00
0002o`000003ooooool0003o000000Oooooo0_l00002ooooo`oo00000_ooool3o`0000Kooooo0_l0
0002ooooo`?o00005Oooool2o`0000Kooooo0_l0000=ooooo`;o0000?Oooool001cooooo00?o0000
ooooooooool0?oooool2o`000003ooooool0003o000000?ooooo0_l0000@ooooo`;o000000?ooooo
o`000?l000000_l000000ooooooo0000o`00000]o`0000;ooooo0_l00008ooooo`;o00003_ooool3
o`000003ooooool0003o000000;ooooo0_l00003ooooo`;o00001?ooool>o`000003ooooool0003o
000000;o00001Oooool4o`000003ooooool0003o000000Oooooo0_l00008ooooo`;o00000_ooool2
o`0000Oooooo0_l00004ooooo`;o0000AOooool001cooooo00?o0000ooooooooool0;?ooool2o`00
01Wooooo0_l0000<ooooo`;o00001_ooool2o`000003ooooool0003o000002Ko000000?oooooo`00
0?l000000_l000001?oooooo0000o`000?l0000Booooo`;o00001oooool2o`0000Kooooo0_l00009
ooooo`;o000000?oooooo`000?l000002_l000001?oooooo0000o`000?l00007ooooo`;o00002_oo
ool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000;ooooo0_l00004ooooo`;o0000
00?oooooo`000?l000001?ooool2o`00013ooooo0_l0000cooooo`007?ooool00ol0003ooooooooo
o`0/ooooo`;o00009Oooool4o`0000Gooooo0_l00002ooooobKo00000_ooool5o`0000;ooooo0ol0
0005ooooo`;o00002_ooool2o`0001Cooooo0_l00003oooooaCo00005_ooool2o`000003ooooool0
003o000000;ooooo0_l000001?oooooo0000o`000?l00004ooooo`;o00006Oooool2o`0003?ooooo
000Looooo`03o`000?oooooooooo04Gooooo0_l0000:ooooo`Co00001oooool4o`000003ooooool0
003o000002[o00000oooool2o`0000Gooooo0_l000000ooooooo0000o`000007ooooo`?o00000_oo
ool2o`0000Cooooo0_l00007ooooo`Co000000?oooooo`000?l000004Ol000000ooooooo0000o`00
000:ooooo`;o00002oooool2o`0000Oooooo0ol0000Dooooo`Co00003_ooool2o`0002cooooo000L
ooooo`03o`000?oooooooooo04Gooooo0_l0000:ooooo`;o00002Oooool4o`0000Cooooo9?l00007
ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Cooooo0_l00002ooooo`;o00000_ooool2
o`0000Cooooo0ol00006ooooo`;o00000ooooolEo`0000_ooooo0_l0000;ooooo`;o000000?ooooo
o`000?l000001Oooool2o`0001Cooooo1?l00007ooooo`;o00001Oooool2o`0002cooooo000Loooo
o`03o`000?oooooooooo03Sooooo0_l0000;ooooo`;o00000_ooool2o`0000;ooooo0_l00005oooo
o`Co000000Coooooo`000?l0003ooooo0ol00003ooooo`_o000000?oooooo`000?l000001?l00002
oooooa;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000Kooooo0_l00004
ooooo`;o00000oooool4o`0000Kooooo0_l0000;oooooaOo00006Oooool2o`000003ooooool0003o
000000;ooooo0_l0000Oooooo`;o0000<oooool001cooooo00?o0000ooooooooool0;_ooool2o`00
00Gooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000Wooooo0_l00002
ooooo`;o00000_ooool2o`000003ooooool0003o000000;o000000Coooooo`000?l0003o00001Ooo
ool<o`000003ooooool0003o000001go000000?oooooo`000?l000005Oooool4o`0000kooooo0_l0
0003oooooaCo000000Coooooo`000?l0003o00002?ooool2o`0000Cooooo0_l0000;ooooo`;o0000
F?ooool001cooooo00?o0000ooooooooool0;_ooool3o`0000Cooooo0_l00004ooooo`;o000000?o
ooooo`000?l000004Oooool2o`0000Cooooo0_l000000ooooooo0000o`000002o`000003ooooool0
003o000000;o000000?oooooo`000?l000007_l000000ooooooo0000o`000006o`000003ooooool0
003o000001[ooooo0_l0000;ooooo`;o00000ooooolDo`000004ooooool0003o0000o`0000Sooooo
0_l00004ooooo`;o00008_ooool2o`0000;ooooo0_l0000mooooo`007?ooool00ol0003ooooooooo
o`0_ooooo`;o00004Oooool3o`0000Cooooo0_l00002ooooo`;o00002?ooool2o`0000?ooooo0_l0
00001?oooooo0000o`000?l00003oooooa_o000000?oooooo`000?l000001_l000000ooooooo0000
o`00000:ooooo`;o00004_ooool2o`0000;ooooo0_l00007ooooo`;o00000ooooolHo`0000_ooooo
0_l0000?ooooo`;o00004_ooool4o`0000;ooooo0_l0000mooooo`007?ooool2o`0002oooooo1?l0
000@ooooo`?o00001?ooool2o`0000;ooooo0_l00002ooooo`;o00000_ooool4o`0000Oooooo0_l0
00000ooooooo0000o`00000No`000003ooooool0003o000000Ko000000?oooooo`000?l000001ooo
ool2o`0001Kooooo0_l00007ooooo`;o00000_oooolJo`0000[ooooo0_l0000?ooooo`;o00004_oo
ool2o`0000;ooooo0_l00002ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0;_ooool4
o`00013ooooo0_l0000=ooooo`Ko000000?oooooo`000?l000001?ooool2o`0000?ooooo8?l00000
1?oooooo0000o`000?ooool8o`0002[ooooo7?l000000ooooooo0000o`00000`ooooo`;o00000_oo
ool2o`0003_ooooo000Looooo`03o`000?oooooooooo04Oooooo1?l00006ooooo`Co00000oooool3
o`0000?ooooo0_l00002oooooa[o00000oooool>o`0001Kooooo0_l0000?ooooo`Co000000?ooooo
o`000?l000000_oooolKo`0000Oooooo0_l000000ooooooo0000o`00000?ooooo`;o00001Oooool2
o`0004gooooo000Looooo`03o`000?oooooooooo03Sooooo0_l000000ooooooo0000o`00000:oooo
o`Co00001_ooool3o`0000Gooooo0_l00003ooooo`;o00000_ooool?o`000003ooooool0003o0000
01?o00000_ooool2o`0001Sooooo0_l00007ooooo`;o00001_ooool4o`0000Cooooo6ol00008oooo
o`;o000000?oooooo`000?l000000_ooool2o`0000_ooooo0_l00005ooooo`;o00002oooool4o`00
03kooooo000Looooo`03o`000?oooooooooo03Sooooo0_l000000ooooooo0000o`00000Mooooo`;o
00000_ooool2o`0000;ooooo2ol000001Ooooooo0000o`000?l0003ooooo01Ko00002Oooool2o`00
00oooooo0ol00005ooooo`Co00002?ooool2o`0000?ooooo6Ol000000ooooooo0000o`000006oooo
o`;o00001oooool2o`0001?ooooo0ol00009ooooo`Co0000?_ooool001cooooo00?o0000oooooooo
ool0??ooool2o`0001?ooooo0_l00007ooooo`;o00000oooool6o`000003ooooool0003o000001Wo
00000oooool4o`0000;ooooo0_l00005ooooo`;o00003oooool3o`000003ooooool0003o000000;o
oooo0_l0000:ooooo`;o00000ooooolIo`000003ooooool0003o000000;o000000Coooooo`000?l0
003ooooo0_l00002ooooo`;o00002Oooool2o`0000_ooooo1Ol0000Hooooo`;o0000<Oooool001co
oooo00?o0000ooooooooool0>?ooool2o`0000;ooooo0_l00005ooooo`;o00003?ooool2o`0000Oo
oooo0_l000000ooooooo0000o`000005o`0000;ooooo3_l00003ooooo`Oo00001_ooool2o`0000Co
oooo0_l00003ooooo`;o00005Oooool2o`00013ooooo0_l000000ooooooo0000o`00000Go`000003
ooooool0003o000000;o000000?oooooo`000?l000001Oooool2o`0000Wooooo0_l000000ooooooo
0000o`000007ooooo`?o00006?ooool2o`000003ooooool0003o0000037ooooo000Looooo`03o`00
0?oooooooooo02_ooooo0_l0000;ooooo`;o00002?ooool3o`0000kooooo0_l00003ooooo`;o0000
0ooooolGo`0000;ooooo2ol000001?oooooo0000o`000?l0000:ooooo`;o00005?ooool4o`0000Oo
oooo0_l00006ooooo`;o000000?oooooo`000?l000006_l0000Gooooo`?o00001oooool2o`0000Ko
oooo0_l00007ooooo`;o00002?ooool2o`0003Cooooo000Looooo`03o`000?oooooooooo02_ooooo
0_l0000Eooooo`;o000000?oooooo`000?l000001oooool2o`0000?ooooo0_l00003ooooo`;o0000
0oooool4o`000003ooooool0003o000000Co00001?ooool>o`0000Cooooo1ol0000>ooooo`;o0000
3Oooool2o`000003ooooool0003o000000;o00001Oooool4o`0000_ooooo6Ol0000;ooooo`;o0000
2oooool2o`00013ooooo0_l00007ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0AOoo
ool2o`0000Oooooo0_l0000>ooooo`;o00000_ooool5o`000003ooooool0003o000000Cooooo0ol0
00000ooooooo0000o`000004o`000003ooooool0003o000000;o00000oooool5o`0000Kooooo0_l0
0006ooooo`;o00003Oooool2o`0000[ooooo0ol00008ooooo`;o00000_ooool7o`000003ooooool0
003o000000ko00002oooool3o`0000Kooooo0_l0000=ooooo`;o0000Coooool001cooooo00?o0000
ooooooooool0>?ooool2o`0000Gooooo0_l0000Pooooo`Wo00001?ooool3o`000003ooooool0003o
000000Co000000?oooooo`000?l000000_l00005ooooo`;o00001_ooool3o`0001Sooooo0ol00006
ooooo`Co00001oooool2o`0000?ooooo4_l000001?oooooo0000o`000?l0000<ooooo`;o000000?o
ooooo`000?l000001?ooool2o`0000cooooo0ol0000>ooooo`Co00002?ooool2o`0003?ooooo000L
ooooo`03o`000?oooooooooo03Sooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00008?oo
ool4o`000003ooooool0003o000000;o00002?ooool:o`0000Gooooo0ol00006ooooo`;o00006Ooo
ool3o`0000Kooooo1?l00009ooooo`;o00000oooool@o`0000Oooooo0_l0000:ooooo`;o00001?oo
ool2o`0000cooooo0_l000001?oooooo0000o`000?l0000;ooooo`Co00001Oooool2o`000003oooo
ool0003o000003?ooooo000Looooo`03o`000?oooooooooo03_ooooo0ol0000Fooooo`;o00002_oo
ool2o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o00000_ooool4o`000003ooooool0
003o000000Go00001Oooool2o`0000Kooooo1?l00004ooooo`;o00005_ooool2o`0000Gooooo0_l0
0009ooooo`;o00000oooool7o`000003ooooool0003o000000Ko00001oooool2o`00013ooooo0_l0
00000ooooooo0000o`000007ooooo`So00001oooool2o`0000_ooooo0_l0000fooooo`007?ooool0
0ol0003oooooooooo`1<ooooo`;o00001?ooool4o`0000[ooooo1Ol00003ooooo`;o00000_ooool2
o`0000;ooooo1?l00004ooooo`;o00000_ooool3o`0000?ooooo0_l00005ooooo`Co00001?ooool2
o`0001?ooooo0_l000000ooooooo0000o`000005ooooo`?o000000?oooooo`000?l000001Oooool2
o`000003ooooool0003o000000?ooooo3ol0000Iooooo`?o00001oooool:o`0000Gooooo0_l00013
ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`00
0?l@413oc<c<00Kooooo00?o0000ooooooooool0Aoooool2o`0000?ooooo0_l00004ooooo`;o0000
00Coooooo`000?l0003o00000_ooool2o`0000Gooooo0_l000000ooooooo0000o`000003ooooo`;o
00000oooool2o`0000;ooooo0_l00005ooooo`;o000000Coooooo`000?l0003o00000oooool2o`00
00Gooooo1?l00002ooooo`;o00004Oooool2o`0000;ooooo0_l00004ooooo`;o00000oooool2o`00
0003ooooool0003o000000Sooooo0_l00005ooooo`?o000000Goooooo`000?l0003o0000ooooo`05
o`0001Sooooo1?l0000<ooooo`Go0000B_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Ooo
ool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo04?ooooo
0_l00002ooooo`;o00003?ooool3o`0000;ooooo0_l00008ooooo`;o00000oooool4o`000003oooo
ool0003o000000;ooooo0ol00004ooooo`;o000000?oooooo`000?l000003Oooool2o`000004oooo
ool0003o0000o`0000Wooooo0_l00006ooooo`;o00000_ooool2o`0000Cooooo0_l0000<ooooo`;o
00000_ooool3o`0000Kooooo0_l00004ooooo`;o00003?ooool2o`0000Sooooo1ol0000>ooooo`Co
0000Boooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool0@oooool2o`0000Oooooo0_l00004ooooo`;o
000000?oooooo`000?l000003_ooool2o`0000Cooooo1Ol000000ooooooo0000o`000003o`0001So
oooo0_l00002ooooo`;o00001_ooool2o`0001;ooooo0_l00008ooooo`Co00000oooool2o`0000Ko
oooo0_l00004ooooo`;o00003?ooool4o`0000Cooooo2?l0001Nooooo`0000?oooooo`000?ooool0
0_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0003co
oooo0_l00005ooooo`?o00000oooool2o`000003ooooool0003o000000Cooooo0_l0000Aooooo`;o
00000_ooool2o`0000;ooooo0ol000001?oooooo0000o`000?ooool2o`0001cooooo0_l0000Joooo
o`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000;o00004Oooool2o`00
00gooooo0ol00004ooooo`?o00004_ooool2o`000003ooooool0003o000004cooooo00000ooooooo
0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006oooo
o`03o`000?oooooooooo03cooooo0_l00005ooooo`?o00000oooool2o`0000Gooooo0_l0000@oooo
o`;o00001Oooool2o`0000?ooooo0_l000000ooooooo0000o`00000Fooooo`;o00000_ooool2o`00
01Oooooo0_l00007ooooo`Co00000_ooool2o`0000?ooooo0_l0000Gooooo`;o00002_ooool3o`00
00;ooooo0_l00009ooooo`;o00001oooool2o`000003ooooool0003o000004cooooo00000ooooooo
410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003o
ooooooooo`13ooooo`;o00002oooool2o`0000Cooooo0ol00004ooooo`;o00000oooool2o`0000;o
oooo0_l00004ooooo`;o00000oooool2o`0000Sooooo0_l0000<ooooo`;o00000_ooool2o`00017o
oooo0_l00004ooooo`;o00001oooool2o`0000;ooooo0_l00004ooooo`;o00006?ooool2o`0000[o
oooo0ol00002ooooo`;o00002Oooool2o`00013ooooo0_l0000;ooooo`;o0000>Oooool00006oooo
oomgMgOoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo
043ooooo0_l000000ooooooo0000o`000002ooooo`;o00001_ooool2o`0000Gooooo1?l00003oooo
o`;o00001?ooool2o`000003ooooool0003o000000Cooooo0_l0000;ooooo`Co00000_ooool2o`00
01oooooo0_l0000;ooooo`;o00001?ooool2o`0000Cooooo0_l0000Hooooo`;o00002?ooool2o`00
00?ooooo1?l00008ooooo`;o000000Coooooo`000?l0003ooooo0_l00009ooooo`Go00000_ooool2
o`0000Kooooo0_l0000iooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0>_ooool2o`0000Cooooo0_l00005ooooo`;o0000
1_ooool2o`0000Kooooo0ol00005ooooo`;o00000_ooool2o`0000Cooooo1?l000000ooooooo0000
o`000009ooooo`;o00001?ooool2o`0001Wooooo0_l0000;ooooo`Go000000?oooooo`000?l00000
1?ooool2o`0002Sooooo0_l00003ooooo`;o00002_ooool2o`000004ooooool0003o0000ooooo`;o
00002Oooool5o`0000;ooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0jooooo`;o0000
2?ooool2o`0000cooooo0_l00003ooooo`;o00000_ooool7o`0000Oooooo1?l000000ooooooo0000
o`000004ooooo`;o00001Oooool2o`0001Gooooo1?l00002ooooo`Co00002oooool5o`0000Sooooo
0_l0000=ooooo`;o00000oooool2o`0002Gooooo0_l00005ooooo`;o00000_ooool2o`0004gooooo
000Looooo`03o`000?oooooooooo033ooooo1?l0000@ooooo`;o00000oooool2o`0000Oooooo0_l0
0007ooooo`Co000000Coooooo`000?l0003o00004Oooool2o`0000Gooooo0_l00005ooooo`;o0000
00?oooooo`000?l000002oooool4o`0000;ooooo1?l00007ooooo`;o00001oooool2o`0000Kooooo
0_l000000ooooooo0000o`00000:ooooo`;o000000?oooooo`000?l000000_l0000Gooooo`;o0000
1_ooool2o`0000?ooooo0ol00005ooooo`;o00000_ooool2o`0004gooooo000Looooo`03o`000?oo
oooooooo033ooooo1?l0000=ooooo`;o00001_ooool3o`0001Gooooo0_l0000=ooooo`;o00002_oo
ool2o`0000Cooooo1Ol0000>ooooo`;o00003?ooool2o`0000Oooooo0_l00009ooooo`;o00002_oo
ool2o`000003ooooool0003o000000;ooooo0_l0000=ooooo`;o00001_ooool2o`0000Kooooo0_l0
0003ooooo`;o00003oooool2o`0004Sooooo000Looooo`03o`000?oooooooooo047ooooo0_l00006
ooooo`?o00002?ooool2o`0000Kooooo1?l0000@ooooo`;o00000oooool2o`0000Gooooo0_l00004
ooooo`?o00002Oooool2o`0000Gooooo0ol00005ooooo`;o00001_ooool3o`0002;ooooo0_l0000<
ooooo`?o00002oooool2o`0001Oooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`19oooo
o`;o00000oooool2o`0000Cooooo0_l00006ooooo`Ko00001oooool2o`0000[ooooo0_l00003oooo
o`;o00003oooool2o`000003ooooool0003o000000Gooooo0ol00005ooooo`;o00001?ooool5o`00
00cooooo0ol00007ooooo`;o00006?ooool2o`0000cooooo0_l00004ooooo`;o00001oooool2o`00
05;ooooo000Looooo`03o`000?oooooooooo04Wooooo0_l00003ooooo`;o00002_ooool4o`0000;o
oooo0_l00007ooooo`;o00000oooool4o`0000Gooooo0_l000000ooooooo0000o`000003ooooo`;o
00002_ooool2o`0000Sooooo0ol00005ooooo`;o00001?ooool2o`0000?ooooo0_l00003ooooo`;o
00001Oooool3o`0000Oooooo0ol0000?ooooo`;o00001_ooool2o`0000cooooo0_l00002ooooo`Co
000000?oooooo`000?l000001?ooool2o`0000Oooooo0_l00019ooooo`007?ooool00ol0003ooooo
ooooo`0looooo`;o00002oooool2o`0000_ooooo0_l00002ooooo`?o00001_ooool2o`0000Kooooo
0_l000000ooooooo0000o`000002o`0000Gooooo0_l000000ooooooo0000o`000003ooooo`;o0000
5?ooool2o`000003ooooool0003o000000?ooooo0_l00004ooooo`;o000000?oooooo`000?l00000
1?l000000ooooooo0000o`000009ooooo`;o00001Oooool2o`0000oooooo0_l00003ooooo`;o0000
00?oooooo`000?l000002oooool3o`0000;ooooo0_l00003ooooo`;o00001?ooool2o`0000Gooooo
1?l000000ooooooo0000o`000016ooooo`007?ooool00ol0003oooooooooo`0looooo`;o00006?oo
ool2o`0000Sooooo0_l000000ooooooo0000o`000006ooooo`;o00002oooool4o`00017ooooo0_l0
00000ooooooo0000o`000005ooooo`?o00001?ooool2o`0000;ooooo0ol000000ooooooo0000o`00
0002ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Cooooo0ol00009ooooo`Co00000_oo
ool2o`0000?ooooo0_l0000>ooooo`;o00000_ooool5o`0000kooooo1?l000000ooooooo0000o`00
0004ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0Aoooool4o`0001Gooooo0ol0000E
ooooo`;o00000oooool2o`0000Gooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo1?l0
0003ooooo`;o00000oooool5o`000003ooooool0003o000000Wo00000oooool2o`0000Oooooo0ol0
0002ooooo`?o00002Oooool4o`0000?ooooo0_l00009ooooo`;o00001oooool2o`0000;ooooo1Ol0
000Iooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0<_ooool2o`0001?ooooo1_l0000C
ooooo`?o000000?oooooo`000?l000000_l00009ooooo`;o00000_ooool2o`000003ooooool0003o
000000?ooooo0_l00005ooooo`;o00001?ooool2o`0000Cooooo1?l00006oooooaSo00001oooool3
o`0000gooooo0_l00006ooooo`;o00002?ooool3o`0000cooooo0ol0001Looooo`007?ooool00ol0
003oooooooooo`0booooo`;o00004oooool2o`0000;ooooo0_l0000Gooooo`Co00000_ooool2o`00
00Gooooo0_l00002ooooo`;o00001?ooool2o`0000kooooo0_l00003ooooo`;o00001_ooool6o`00
0003ooooool0003o000000oo00002Oooool2o`0000kooooo0_l00005ooooo`;o00001?ooool2o`00
00?ooooo0_l00007ooooo`;o00005?ooool2o`0004gooooo000Looooo`;o0000?oooool2o`0000Go
oooo1?l0000Dooooo`;o000000Coooooo`000?l0003ooooo1?l00002ooooo`?o00003oooool2o`00
00kooooo0_l0000:ooooo`oo000000?oooooo`000?l000000_l0000>ooooo`;o000000?oooooo`00
0?l000004_ooool4o`0000;ooooo0_l0000<ooooo`;o00005?ooool2o`0004gooooo000Looooo`03
o`000?oooooooooo03kooooo0_l00005ooooo`Co00005?ooool2o`000004ooooool0003o0000oooo
o`Co00000_ooool2o`0000Kooooo0_l000000ooooooo0000o`00000Hooooo`;o00001_oooolHo`00
00Oooooo0_l00002ooooo`;o000000?oooooo`000?l000004_ooool4o`0000?ooooo0ol00006oooo
o`;o00001_ooool2o`0005oooooo000Looooo`03o`000?oooooooooo03kooooo0_l00008ooooo`;o
00004?ooool2o`0000Kooooo1?l0000;ooooo`;o000000?oooooo`000?l000001oooool2o`0000Go
oooo0_l00007ooooo`?o00001_ooool2o`000003ooooool0003o000000ko000000?oooooo`000?l0
00000_l00007ooooo`;o000000?oooooo`000?l000007?ooool4o`0000Cooooo2?l000001?oooooo
0000o`000?l0001Oooooo`007?ooool00ol0003oooooooooo`18ooooo`;o00004?ooool2o`0000Ko
oooo1?l00002ooooo`;o00000oooool2o`0000kooooo0_l00004ooooo`?o00001oooool2o`0000Wo
oooo4Ol000000ooooooo0000o`000002o`0000[ooooo0_l00005ooooo`;o00001_ooool2o`0000;o
oooo0_l00008ooooo`?o00000_ooool6o`000003ooooool0003o000000Ko00000oooool4o`0000go
oooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`16ooooo`Co00007Oooool5o`000003oooo
ool0003o000001Cooooo0_l00007ooooo`?o00001ooooolCo`000003ooooool0003o000000;o0000
4Oooool2o`0000Kooooo0_l00002ooooo`;o00002?ooool2o`0000?ooooo1Ol00002ooooo`;o0000
0oooool2o`0000Cooooo1?l00006ooooo`;o00001Oooool2o`0004[ooooo000Looooo`03o`000?oo
oooooooo04Cooooo1ol0000Looooo`;o000000?oooooo`000?l000000oooool2o`0001;ooooo0_l0
0007ooooo`;o00000_ooool2o`000003ooooool0003o000001Go000000Coooooo`000?l0003o0000
1?ooool2o`0001Kooooo0_l00007ooooo`;o00000oooool2o`0000?ooooo0_l0000Fooooo`?o0000
1Oooool2o`0004[ooooo000Looooo`03o`000?oooooooooo04Cooooo0ol00002ooooo`;o00002Ooo
ool3o`00013ooooo0_l00006ooooo`;o00004_ooool2o`0000Gooooo1?l000001Ooooooo0000o`00
0?l0003ooooo01co00000_ooool3o`0000Wooooo0_l00009ooooo`Ko000000Goooooo`000?l0003o
0000ooooo`02o`0000?ooooo0_l00009ooooo`;o00003oooool3o`0005;ooooo000Looooo`03o`00
0?oooooooooo04Gooooo0_l00004ooooo`Co00001Oooool3o`0000gooooo0_l00004ooooo`;o0000
1?ooool2o`0000Cooooo0_l00004ooooo`;o00002?ooool2o`0000;ooooo0_l00003ooooo`;o0000
0_oooolPo`0000[ooooo0_l00009ooooo`?o000000Coooooo`000?l0003ooooo0ol0000Aooooo`;o
00001?ooool2o`0000Wooooo0ol0001Booooo`007?ooool00ol0003oooooooooo`14ooooo`;o0000
1Oooool4o`0000;ooooo0_l00006ooooo`;o00002Oooool2o`0000?ooooo0ol00004ooooo`Co0000
0_ooool2o`0000Cooooo0ol00003ooooo`;o00000_ooool2o`0000Kooooo0_l00005oooooako0000
6Oooool2o`000003ooooool0003o000001Sooooo0_l0000:ooooo`;o00002Oooool2o`0004Oooooo
000Looooo`03o`000?oooooooooo04Cooooo0_l00005ooooo`;o00000_ooool4o`0000Kooooo0_l0
000>ooooo`;o00001oooool2o`0000Sooooo0ol00003ooooo`;o00002_ooool2o`0000;ooooo0_l0
00000ooooooo0000o`000005o`000003ooooool0003o000000oo00000_ooool4o`0001?ooooo0_l0
0004ooooo`;o00003Oooool2o`0000?ooooo0_l00006ooooo`;o00005Oooool2o`0004Oooooo000L
ooooo`03o`000?oooooooooo04Cooooo0_l00005ooooo`;o00000_ooool2o`0001[ooooo0_l00004
ooooo`;o00002_ooool4o`00017ooooo0_l000000ooooooo0000o`00000Ho`000003ooooool0003o
000000;o00002?ooool3o`0000Sooooo1?l00002ooooo`;o000000?oooooo`000?l000001oooool2
o`000004ooooool0003o0000o`0000;ooooo0_l00002ooooo`;o00000_ooool2o`0005kooooo000L
ooooo`03o`000?oooooooooo04Cooooo0_l0000>ooooo`;o00005Oooool2o`0000Cooooo0_l00003
ooooo`;o00001oooool3o`0000gooooo8?l0000=ooooo`?o00002_ooool2o`0000Gooooo0_l00006
ooooo`Co000000?oooooo`000?l000001_ooool4o`000003ooooool0003o000000Sooooo0_l0001C
ooooo`007?ooool00ol0003oooooooooo`1?ooooo`;o00000oooool3o`0000;ooooo0_l0000Koooo
o`;o00002?ooool2o`0000gooooo4ol000000ooooooo0000o`000009o`0001_ooooo0ol0000:oooo
o`Ko00002oooool5o`000003ooooool0003o000000Gooooo0_l0001Cooooo`007?ooool00ol0003o
ooooooooo`1?ooooo`;o00000_ooool4o`0000;ooooo0_l0000Pooooo`;o00005_ooool4o`000003
ooooool0003o000000?o000000?oooooo`000?l000001_l00002ooooo`Wo00001Oooool2o`000003
ooooool0003o000000kooooo1?l00002ooooo`;o00001Oooool5o`0000cooooo0ol00003ooooo`;o
0000F_ooool001cooooo00?o0000ooooooooool0Doooool2o`0000Cooooo0_l00006ooooo`;o0000
6?ooool2o`0000oooooo0_l00002ooooo`;o00000_oooolPo`0000;ooooo1Ol0000:ooooo`;o0000
1?ooool2o`0000;ooooo0_l000000ooooooo0000o`000006o`00017ooooo0ol000000ooooooo0000
o`000005ooooo`;o00000_ooool2o`0004gooooo000Looooo`03o`000?oooooooooo05?ooooo0_l0
0004ooooo`Co00001?ooool2o`0002Wooooo1_l00003oooooa_o000000Goooooo`000?l0003o0000
ooooo`04o`0000cooooo0_l0000;ooooo`Co00000_ooool2o`00017ooooo0ol000000ooooooo0000
o`000004ooooo`?o00000_ooool2o`0004gooooo000Looooo`;o0000Boooool2o`0000;ooooo0_l0
0005ooooo`;o00001?ooool2o`00033ooooo1Ol00003oooooa_o00000_ooool2o`000003ooooool0
003o000000Wooooo0_l00002ooooo`Co00002_ooool2o`0000Kooooo0_l00008ooooo`Go00003?oo
ool3o`00057ooooo000Looooo`03o`000?oooooooooo04[ooooo0_l00002ooooo`;o00000_ooool5
o`0003;ooooo0_l00005ooooo`;o00001?oooolFo`0000;ooooo0_l00002ooooo`;o00003?ooool2
o`0000;ooooo1?l0000:ooooo`;o00001_ooool2o`0000;ooooo0_l00004ooooo`Go00001?ooool3
o`0000Kooooo0_l00002ooooo`;o0000COooool001cooooo00?o0000ooooooooool0D_ooool3o`00
013ooooo0_l0000Rooooo`;o00002ooooolJo`0000;ooooo0_l0000;ooooo`Co00006oooool3o`00
00Kooooo0_l00004ooooo`?o00001Oooool2o`0000?ooooo0_l0001=ooooo`007?ooool00ol0003o
ooooooooo`18ooooo`Co00002Oooool2o`0000kooooo0ol0000Qooooo`;o00002?ooool2o`0000?o
oooo5ol000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l000000_ooool4o`0000Ko
oooo0_l00004ooooo`;o00003_ooool2o`0000Kooooo0_l000000ooooooo0000o`000009ooooo`;o
00002oooool2o`0004Gooooo000Looooo`03o`000?oooooooooo04Sooooo1?l00004ooooo`?o0000
0_ooool2o`0000oooooo0_l0000Qooooo`Co00000_ooool2o`0000;ooooo0_l00003oooooaco0000
1?ooool2o`000003ooooool0003o000000?ooooo1?l00005ooooo`;o000000Coooooo`000?l0003o
oooo0_l000001?oooooo0000o`000?l00003ooooo`;o00004?ooool2o`0001Kooooo0_l00015oooo
o`007?ooool00ol0003oooooooooo`1@ooooo`?o0000>?ooool2o`0000;ooooo0_l00007oooooaWo
000000?oooooo`000?l000002?ooool2o`000003ooooool0003o000000?o00002?ooool2o`0000Co
oooo0ol00003ooooo`;o00000_ooool2o`00017ooooo0_l000000ooooooo0000o`00001Eooooo`00
7?ooool00ol0003oooooooooo`1Booooo`;o00000_ooool2o`0002oooooo0_l00006ooooo`;o0000
00?oooooo`000?l000000_oooolMo`0000Wooooo0_l000000ooooooo0000o`000002ooooo`;o0000
4Oooool4o`0000;ooooo0_l000000ooooooo0000o`00000>ooooo`;o000000?oooooo`000?l00000
EOooool001cooooo00?o0000ooooooooool0D_ooool2o`0000;ooooo1?l00006ooooo`;o00009Ooo
ool2o`0000Kooooo0_l000000ooooooo0000o`000002oooooa;o000000?oooooo`000?l000000_l0
0002ooooo`Ko00001oooool2o`000003ooooool0003o000000;ooooo0_l000001?oooooo0000o`00
0?l00002ooooo`;o00000_ooool2o`0000Gooooo1?l00005ooooo`;o000000?oooooo`000?l00000
0_l00005ooooo`;o0000G?ooool001cooooo00?o0000ooooooooool0D_ooool2o`0000Cooooo0_l0
0006ooooo`;o00000oooool2o`0000;ooooo0_l0000/ooooo`;o000000?oooooo`000?l000003?l0
00000ooooooo0000o`000002o`0000Kooooo0_l00007ooooo`;o00001oooool5o`000003ooooool0
003o000000;ooooo1Ol00002ooooo`Co00002?ooool5o`0000Cooooo0_l0001Looooo`007?ooool0
0ol0003oooooooooo`1Uooooo`;o00000_ooool2o`0001oooooo0_l0000;ooooo`Co000000?ooooo
o`000?l000002?l00003ooooo`;o000000?oooooo`000?l000003?ooool2o`0000Wooooo0_l00000
0ooooooo0000o`000006ooooo`_o00000oooool6o`000003ooooool0003o000000cooooo0_l0001D
ooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o00003_ooool2o`0001gooooo1?l0000=oooo
o`Co000000Coooooo`000?l0003ooooo0ol00002ooooo`So00003?ooool2o`0000Wooooo0_l00009
ooooo`Ko000000?oooooo`000?l000000_l00003ooooo`Ko00003oooool2o`0005Cooooo000Loooo
o`03o`000?oooooooooo05Wooooo0_l00005ooooo`;o00001oooool2o`0001gooooo0ol0000?oooo
o`Go00000_ooool;o`0002Cooooo0_l00002ooooo`;o000000?oooooo`000?l000001_ooool2o`00
0003ooooool0003o000000Sooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`1Oooooo`Go
00009Oooool4o`0000Kooooo0_l00007ooooo`Co000000?oooooo`000?l000001Ol00002ooooo`Co
00000oooool2o`000004ooooool0003o0000ooooo`?o00004Oooool2o`0000?ooooo0_l00002oooo
o`Go00001_ooool2o`000003ooooool0003o000000Sooooo0_l0001Kooooo`007?ooool00ol0003o
ooooooooo`1Oooooo`;o000000?oooooo`000?l000000_l0000Uooooo`;o00001Oooool3o`0000Ko
oooo0_l000000ooooooo0000o`000004o`000003ooooool0003o000000?ooooo1?l00003ooooo`;o
000000Coooooo`000?l0003ooooo1?l0000@ooooo`Co00000_ooool2o`0000;ooooo1?l0000Aoooo
o`;o0000GOooool001cooooo00?o0000ooooooooool0G_ooool2o`0000Cooooo0_l000001?oooooo
0000o`000?l0000Sooooo`?o00000_ooool2o`0000Oooooo0ol000000ooooooo0000o`000003o`00
0003ooooool0003o000000;o00002_ooool2o`0000Cooooo0_l0000Booooo`Oo000000?oooooo`00
0?l000000_ooool2o`0000oooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o
00001oooool3o`0002?ooooo0ol00004ooooo`;o00001_ooool2o`0000Oooooo1?l00006ooooo`;o
00000_ooool2o`000003ooooool0003o000000Kooooo0ol00007ooooo`;o00001Oooool2o`000003
ooooool0003o000000Gooooo0_l00005ooooo`;o000000?oooooo`000?l00000I?ooool001cooooo
0_l0001Xooooo`;o00007Oooool2o`0000cooooo0_l00005ooooo`;o00002Oooool2o`0000Oooooo
0_l00005ooooo`;o00001_ooool3o`0000Oooooo0_l00004ooooo`?o00001Oooool2o`000003oooo
ool0003o000000Gooooo1Ol0001Tooooo`007?ooool00ol0003oooooooooo`1Booooo`;o00001ooo
ool2o`0000?ooooo0_l00006ooooo`;o00007?ooool2o`0000oooooo0_l00002ooooo`;o000000?o
ooooo`000?l000001oooool2o`0000oooooo0ol00004ooooo`;o00000_ooool2o`0000Wooooo0_l0
0006ooooo`;o000000?oooooo`000?l000001oooool2o`0006Gooooo000Looooo`03o`000?oooooo
oooo05;ooooo0_l00007ooooo`;o00000oooool2o`0000Kooooo0_l0000]ooooo`;o00001Oooool2
o`0000Oooooo0_l00008ooooo`;o00000oooool5o`0000Sooooo1?l00022ooooo`007?ooool00ol0
003oooooooooo`1Rooooo`;o00001?ooool2o`0000;ooooo0_l0000<ooooo`;o00003?ooool2o`00
00Cooooo0_l00003ooooo`;o00002?ooool3o`0000;ooooo0_l00007ooooo`;o00001?ooool2o`00
00?ooooo0_l000000ooooooo0000o`000006ooooo`Oo00000_ooool2o`0000cooooo0_l0001_oooo
o`007?ooool00ol0003oooooooooo`1Rooooo`;o00001?ooool2o`000004ooooool0003o0000o`00
00cooooo1?l0000:ooooo`;o00001?ooool2o`0000?ooooo0_l00008ooooo`;o00000oooool2o`00
00Oooooo0_l000001?oooooo0000o`000?ooool2o`0000Kooooo0_l00006ooooo`Co000000?ooooo
o`000?l000000_ooool6o`0000Sooooo0_l0001_ooooo`007?ooool00ol0003oooooooooo`1Roooo
o`;o00001_ooool3o`0000oooooo0_l0000Hooooo`;o00005_ooool2o`0000kooooo0_l00003oooo
o`;o00001?ooool2o`000003ooooool0003o000000;o00001_ooool2o`00077ooooo000Looooo`03
o`000?oooooooooo06Sooooo1Ol0000:ooooo`;o00003?ooool2o`0000oooooo0_l0000Hooooo`;o
00001Oooool2o`0000Cooooo0ol00003ooooo`;o00001?ooool2o`0000_ooooo0_l00005ooooo`Co
00002?ooool2o`0005kooooo000Looooo`03o`000?oooooooooo06Sooooo0ol0000<ooooo`;o0000
00?oooooo`000?l000000oooool2o`0000Cooooo0_l0000Qooooo`;o00001Oooool3o`0000Gooooo
0_l00004ooooo`Co00000_ooool2o`0001Sooooo1?l000000ooooooo0000o`000005ooooo`;o0000
G_ooool001cooooo00?o0000ooooooooool0JOooool2o`0000_ooooo1_l00002ooooo`Go00009Ooo
ool2o`0000Gooooo0_l0000=ooooo`?o00000_ooool2o`0001gooooo0_l0001Uooooo`007?ooool0
0ol0003oooooooooo`1fooooo`Co00001?ooool2o`000003ooooool0003o0000017ooooo0_l0000F
ooooo`Co00007_ooool2o`0007Wooooo000Looooo`03o`000?oooooooooo08Gooooo0_l0000=oooo
o`;o00002_ooool2o`0000?ooooo1Ol00002ooooo`Co00002oooool2o`000003ooooool0003o0000
00;o00002Oooool2o`000003ooooool0003o000000Gooooo0_l0001booooo`007?ooool00ol0003o
ooooooooo`1Wooooo`;o00006Oooool2o`000003ooooool0003o000000;o00002oooool2o`0000Co
oooo0_l00004ooooo`;o00000_ooool6o`000003ooooool0003o000000;o00001_ooool2o`0000Co
oooo1ol00005ooooo`?o000000?oooooo`000?l000002?ooool2o`0007;ooooo000Looooo`03o`00
0?oooooooooo06Oooooo0_l0000Iooooo`;o000000?oooooo`000?l000000ol00008ooooo`?o0000
1Oooool2o`0000Sooooo0ol000001?oooooo0000o`000?ooool2o`000004ooooool0003o0000oooo
o`;o00000_ooool2o`0000Gooooo0_l00009ooooo`?o00001oooool2o`0007Kooooo000Looooo`03
o`000?oooooooooo06Wooooo0_l0000Hooooo`Oo00001?ooool2o`0000;ooooo1Ol00002ooooo`;o
000000?oooooo`000?l000002_ooool2o`0000?ooooo0ol000000ooooooo0000o`00000Nooooo`;o
00000_ooool2o`0000cooooo0_l0001Tooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5oooo
o`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0H?ooool2
o`0000Oooooo0_l0000Hooooo`;o00002Oooool4o`0000?ooooo0_l00002ooooo`;o000000?ooooo
o`000?l000003oooool2o`0000Wooooo0_l000000ooooooo0000o`000002o`0001Kooooo0_l0000:
ooooo`Co0000I?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go
8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo063ooooo0_l0000]ooooo`?o0000
0_ooool2o`0002;ooooo0_l000000ooooooo0000o`000002o`0001kooooo0_l00002ooooo`?o0000
IOooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool0O?ooool2o`0000Sooooo0_l0000<ooooo`;o0000
0oooool2o`0001_ooooo0_l00004ooooo`;o00007_ooool3o`0006[ooooo00000ooooooo0000oooo
o`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000
Moooool3o`0000;ooooo0_l00006ooooo`Ko00003oooool2o`0000Kooooo0_l0000Cooooo`;o0000
4?ooool2o`0001;ooooo0_l0001[ooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooooooo
o`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`1aooooo`;o0000
1?ooool3o`0000[ooooo0_l00002ooooo`;o00000oooool2o`0000Sooooo0_l00003ooooo`Co0000
00Coooooo`000?l0003o00009?ooool2o`0000Gooooo0_l0001hooooo`0000?ooooooa0@4?ooool0
0_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003o
ooooooooo`1aooooo`;o00005?ooool4o`0000;ooooo0_l00006ooooo`Co00000oooool4o`000004
ooooool0003o0000o`0001Wooooo0_l0000@ooooo`;o0000N?ooool00006oooooomgMgOoV9RHoooo
oonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0P_oo
ool2o`0000?ooooo1?l00002ooooo`?o00001Oooool2o`0000[ooooo0_l0000Jooooo`?o0000ROoo
ool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Ko
oooo00?o0000ooooooooool0NOooool2o`0000?ooooo0_l00002ooooo`;o00002_ooool2o`0000Co
oooo1?l0000Vooooo`;o0000ROooool001cooooo00?o0000ooooooooool0NOooool4o`000004oooo
ool0003o0000ooooo`;o00004Oooool4o`000;7ooooo000Looooo`03o`000?oooooooooo07Wooooo
1?l00004ooooo`;o00004Oooool2o`000;?ooooo000Looooo`03o`000?oooooooooo07Wooooo0_l0
000Cooooo`;o00001?ooool2o`0000;ooooo0_l0002_ooooo`007?ooool00ol0003oooooooooo`1c
ooooo`;o00002_ooool2o`0000gooooo0_l00008ooooo`;o0000<?ooool2o`0000Oooooo0_l0001d
ooooo`007?ooool00ol0003oooooooooo`1cooooo`;o00002_ooool2o`0001?ooooo1?l0000boooo
o`;o00001oooool2o`0007Cooooo000Looooo`03o`000?oooooooooo087ooooo0ol0000@ooooo`Co
0000;_ooool2o`00087ooooo000Looooo`03o`000?oooooooooo07Kooooo0_l00009ooooo`Co0000
2Oooool2o`0002oooooo0_l00005ooooo`;o0000POooool001cooooo00?o0000ooooooooool0M_oo
ool2o`0000_ooooo0_l00009ooooo`;o00000oooool2o`0002Oooooo0_l000000ooooooo0000o`00
0028ooooo`007?ooool00ol0003oooooooooo`2Cooooo`;o00009oooool2o`0008_ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0Q_ooool2o`000<7o
oooo000Looooo`;o0000Qoooool2o`0001Cooooo0_l000000ooooooo0000o`000002o`000:Kooooo
000Looooo`03o`000?oooooooooo09Cooooo0_l00006ooooo`;o000000?oooooo`000?l000000_l0
002Vooooo`007?ooool00ol0003oooooooooo`2Dooooo`;o00006_ooool2o`0000Kooooo0_l0002?
ooooo`007?ooool00ol0003oooooooooo`2Oooooo`;o00002_ooool2o`0000?ooooo0_l00006oooo
o`;o0000Soooool001cooooo00?o0000ooooooooool0Q?ooool2o`0001Wooooo0_l00008ooooo`Co
0000W?ooool001cooooo00?o0000ooooooooool0Q?ooool2o`0002?ooooo0_l0002Nooooo`007?oo
ool00ol0003oooooooooo`24ooooo`?o0000`_ooool001cooooo00?o0000ooooooooool0QOooool2
o`000<;ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0[_ooool2o`0009Wooooo000Loooo
o`03o`000?oooooooooo0:kooooo0_l0002Iooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0002Oooooo`;o0000ZOoo
ool001cooooo00?o0000ooooooooool0W_ooool2o`0000oooooo0_l00005ooooo`;o0000TOooool0
01cooooo00?o0000ooooooooool0[oooool2o`0000Gooooo0_l0002Aooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Booooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooood[ooooo000D
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0
003oooooooooo`05ooooo`?o0000oooooom:ooooo`005?ooool00ol0003oooooooooo`3ooooooe;o
oooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooo
oomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Booooo`03oeEEEOmVIVKo0000
0?ooooooE?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Gooooo00Co410@
o`000?l0003ooooo0_l000000ol@413oooooooooo`0Eooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0
0oooool5o`0000?ooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c02@ooooo`00Y_ooool01Ol0003ooooo
oooooooooooo000000Wooooo1_l00009ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B400oooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@2@ooooo`00Y_ooool0
1Ol0003ooooooooooooooooo000001Sooooo00Go0000ooooooooooooooooo`000004ooooo`03oiRH
V?lQ8B7ok^k^00Cooooo00Go0000ooooooooooooooooo`00002@ooooo`00Y_ooool01Ol0003ooooo
oooooooooooo000000Wooooo1_l00009ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801Oooool00onH
V9So8B4Qonk^kP03ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80T?ooool00:Kooooo00Go0000ohN7
QoooooooZJVYo`00000Hooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00omgMgOoIVIVoooo
o`02ooooo`05olc<c?l0003o0000o`000?o<c<`0T?ooool00:Gooooo00?o410@o`000?mgMgL00_l0
00000onHV9Soooooooooo`0Fooooo`05oa0@4?nj^[[ooooookZj^_l@41001oooool02Ol0003ooooo
oooooooooooo410@okZj^_oooooo^[Zjoa0@402@ooooo`00`oooool01Ol0003o^[Zjoooooonj^[[o
000000?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05o`000?nj^[[ooooookZj^_l00000
T?ooool00<?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`00oooool01OnYZJWo410@o`000?l@413oZJVY093ooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(834) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.5005 .6592 Mdot
.49544 .68593 Mdot
.60989 .42449 Mdot
.3394 .52789 Mdot
.47035 .53802 Mdot
.64393 .4228 Mdot
.61688 .55769 Mdot
.59821 .54525 Mdot
.65666 .40954 Mdot
.25695 .50858 Mdot
.59911 .59051 Mdot
.37204 .5674 Mdot
.62309 .57196 Mdot
.37315 .51789 Mdot
.6794 .22 Mdot
.31538 .53207 Mdot
.45297 .70479 Mdot
.49822 .30302 Mdot
.4389 .50791 Mdot
.61885 .37645 Mdot
.51144 .73824 Mdot
.37839 .51874 Mdot
.49394 .65505 Mdot
.37353 .51693 Mdot
.32633 .50731 Mdot
.47313 .68328 Mdot
.44176 .6819 Mdot
.33081 .47851 Mdot
.3483 .50284 Mdot
.58563 .58717 Mdot
.46516 .38891 Mdot
.53426 .16746 Mdot
.32907 .55054 Mdot
.25171 .69422 Mdot
.60214 .54612 Mdot
.27655 .31139 Mdot
.64871 .38493 Mdot
.62879 .59464 Mdot
.59568 .54812 Mdot
.63185 .54754 Mdot
.62863 .59004 Mdot
.47518 .69065 Mdot
.6311 .53291 Mdot
.65232 .53486 Mdot
.35294 .54144 Mdot
.6344 .69142 Mdot
.39119 .25984 Mdot
.35753 .4738 Mdot
.50215 .7011 Mdot
.63319 .37174 Mdot
.38317 .79663 Mdot
.61324 .53496 Mdot
.76034 .47547 Mdot
.49989 .08388 Mdot
.63479 .57632 Mdot
.33966 .53488 Mdot
.63887 .39859 Mdot
.39552 .50187 Mdot
.37828 .50789 Mdot
.38193 .76593 Mdot
.33536 .48453 Mdot
.5222 .32333 Mdot
.52369 .70519 Mdot
.66532 .43866 Mdot
.64918 .41721 Mdot
.58445 .56446 Mdot
.4623 .71184 Mdot
.61502 .56988 Mdot
.35576 .44606 Mdot
.65921 .38282 Mdot
.35868 .47338 Mdot
.60425 .59596 Mdot
.51689 .69353 Mdot
.4114 .48576 Mdot
.65472 .71381 Mdot
.74448 .28784 Mdot
.48694 .30323 Mdot
.36391 .73981 Mdot
.42152 .71523 Mdot
.76758 .36091 Mdot
.3603 .50785 Mdot
.84049 .60801 Mdot
.69584 .23455 Mdot
.49491 .65904 Mdot
.44823 .54643 Mdot
.64771 .35474 Mdot
.41341 .51182 Mdot
.49786 .45513 Mdot
.32587 .45452 Mdot
.60113 .77541 Mdot
.65693 .40439 Mdot
.47842 .70711 Mdot
.34313 .52888 Mdot
.36856 .46065 Mdot
.32938 .65514 Mdot
.39753 .46122 Mdot
.32025 .48767 Mdot
.45598 .72647 Mdot
.58961 .56974 Mdot
.2941 .52809 Mdot
.61551 .51583 Mdot
.78582 .48593 Mdot
.38495 .53848 Mdot
.66842 .40305 Mdot
.47495 .73349 Mdot
.39864 .53668 Mdot
.63175 .55651 Mdot
.34943 .48782 Mdot
.64082 .53471 Mdot
.49911 .68987 Mdot
.37641 .46262 Mdot
.50673 .30355 Mdot
.6949 .725 Mdot
.46987 .7067 Mdot
.80979 .58629 Mdot
.34494 .47795 Mdot
.386 .51787 Mdot
.49316 .68728 Mdot
.61885 .41282 Mdot
.4929 .42337 Mdot
.48501 .72434 Mdot
.6207 .54446 Mdot
.45509 .65116 Mdot
.4294 .46243 Mdot
.65649 .42504 Mdot
.78425 .49203 Mdot
.76309 .49858 Mdot
.33003 .37905 Mdot
.40748 .52201 Mdot
.57418 .65318 Mdot
.63462 .42387 Mdot
.48225 .7023 Mdot
.6151 .57329 Mdot
.31774 .52476 Mdot
.45398 .67509 Mdot
.60696 .58727 Mdot
.52383 .31257 Mdot
.51972 .25232 Mdot
.49838 .71392 Mdot
.54246 .5797 Mdot
.64527 .60591 Mdot
.63388 .55015 Mdot
.28938 .73933 Mdot
.49524 .68065 Mdot
.50828 .34335 Mdot
.60536 .58128 Mdot
.43326 .30883 Mdot
.31315 .5096 Mdot
.2861 .41354 Mdot
.73593 .74096 Mdot
.37242 .798 Mdot
.73375 .60214 Mdot
.49122 .33541 Mdot
.64315 .56221 Mdot
.33974 .51268 Mdot
.4905 .67346 Mdot
.48344 .68095 Mdot
.33303 .4631 Mdot
.32169 .50231 Mdot
.3739 .46957 Mdot
.35904 .46096 Mdot
.43827 .24435 Mdot
.3675 .46544 Mdot
.58931 .43391 Mdot
.46124 .69715 Mdot
.3315 .49848 Mdot
.61133 .40504 Mdot
.35589 .55496 Mdot
.61794 .59655 Mdot
.38544 .50929 Mdot
.32327 .51585 Mdot
.42405 .48888 Mdot
.63797 .58257 Mdot
.48427 .18497 Mdot
.72334 .7423 Mdot
.31942 .24311 Mdot
.76426 .60048 Mdot
.62706 .40335 Mdot
.40082 .52249 Mdot
.51902 .33672 Mdot
.31506 .58216 Mdot
.3698 .50247 Mdot
.44147 .82437 Mdot
.31766 .50266 Mdot
.22345 .61374 Mdot
.41105 .42994 Mdot
.3201 .23525 Mdot
.55031 .42967 Mdot
.34466 .49754 Mdot
.30383 .62067 Mdot
.21462 .50834 Mdot
.47657 .59405 Mdot
.63115 .58564 Mdot
.61388 .41127 Mdot
.64542 .39256 Mdot
.65001 .56248 Mdot
.28967 .50158 Mdot
.28658 .45564 Mdot
.30167 .55059 Mdot
.77704 .49272 Mdot
.51833 .6943 Mdot
.53462 .3517 Mdot
.50967 .6987 Mdot
.85882 .52828 Mdot
.57048 .77592 Mdot
.64694 .60944 Mdot
.48065 .33247 Mdot
.61306 .42486 Mdot
.77443 .49481 Mdot
.51245 .33885 Mdot
.37064 .48204 Mdot
.49681 .707 Mdot
.20416 .57377 Mdot
.42633 .44191 Mdot
.17702 .52674 Mdot
.46051 .65447 Mdot
.52287 .44347 Mdot
.61684 .58684 Mdot
.61032 .37663 Mdot
.37856 .52973 Mdot
.38997 .47797 Mdot
.50798 .73077 Mdot
.35808 .476 Mdot
.42985 .63138 Mdot
.32429 .52024 Mdot
.65905 .36144 Mdot
.50174 .29279 Mdot
.64449 .55214 Mdot
.3261 .384 Mdot
.51258 .66142 Mdot
.70258 .43082 Mdot
.6317 .37593 Mdot
.26853 .55096 Mdot
.59904 .59277 Mdot
.50917 .30508 Mdot
.62012 .38303 Mdot
.5145 .35907 Mdot
.41047 .52797 Mdot
.65031 .38378 Mdot
.51396 .35202 Mdot
.4702 .21892 Mdot
.34449 .54087 Mdot
.44984 .26196 Mdot
.61054 .55941 Mdot
.45872 .64672 Mdot
.33426 .48569 Mdot
.76532 .50198 Mdot
.41216 .53664 Mdot
.7081 .55588 Mdot
.7559 .47994 Mdot
.77141 .4738 Mdot
.74576 .32358 Mdot
.49624 .31231 Mdot
.70858 .65058 Mdot
.55386 .68213 Mdot
.46237 .7134 Mdot
.34726 .53432 Mdot
.39624 .18386 Mdot
.60617 .58168 Mdot
.37136 .48494 Mdot
.65152 .35681 Mdot
.60503 .57809 Mdot
.40103 .50166 Mdot
.64111 .57203 Mdot
.48822 .67771 Mdot
.70336 .35257 Mdot
.44722 .68653 Mdot
.33727 .53699 Mdot
.62726 .5557 Mdot
.62647 .38567 Mdot
.47354 .6788 Mdot
.35318 .48917 Mdot
.3852 .52656 Mdot
.77263 .48679 Mdot
.33809 .49876 Mdot
.40519 .18655 Mdot
.34082 .47307 Mdot
.63923 .44239 Mdot
.38143 .45447 Mdot
.38721 .82208 Mdot
.55341 .27063 Mdot
.47043 .71556 Mdot
.76509 .47525 Mdot
.65203 .40722 Mdot
.68407 .31637 Mdot
.5153 .58241 Mdot
.35535 .49895 Mdot
.77005 .47826 Mdot
.51373 .41295 Mdot
.58126 .57291 Mdot
.41108 .46643 Mdot
.60476 .7559 Mdot
.6128 .38524 Mdot
.7741 .49259 Mdot
.44139 .52868 Mdot
.47452 .73381 Mdot
.33669 .52634 Mdot
.63624 .38029 Mdot
.45433 .65112 Mdot
.37149 .55204 Mdot
.33333 .29296 Mdot
.75492 .48869 Mdot
.61135 .56046 Mdot
.33088 .4289 Mdot
.36573 .46785 Mdot
.6366 .3902 Mdot
.48399 .65205 Mdot
.60432 .54762 Mdot
.46832 .69062 Mdot
.20566 .53458 Mdot
.7602 .61611 Mdot
.41118 .23943 Mdot
.47937 .33109 Mdot
.71456 .52545 Mdot
.29588 .25932 Mdot
.71974 .6608 Mdot
.38762 .34237 Mdot
.19452 .37238 Mdot
.61308 .39522 Mdot
.49556 .27629 Mdot
.64648 .40589 Mdot
.35014 .52231 Mdot
.64759 .42102 Mdot
.32032 .23 Mdot
.31659 .50317 Mdot
.62945 .39984 Mdot
.63667 .32695 Mdot
.32504 .49337 Mdot
.46553 .70499 Mdot
.65188 .21477 Mdot
.61354 .7936 Mdot
.50685 .77969 Mdot
.62125 .40591 Mdot
.42989 .76716 Mdot
.329 .4822 Mdot
.34511 .55523 Mdot
.48725 .6697 Mdot
.38667 .45433 Mdot
.53715 .34567 Mdot
.51667 .36106 Mdot
.3126 .40009 Mdot
.7921 .64074 Mdot
.28603 .5174 Mdot
.47609 .67596 Mdot
.4133 .64294 Mdot
.65045 .71368 Mdot
.78922 .50174 Mdot
.59315 .60744 Mdot
.49556 .18888 Mdot
.28446 .48282 Mdot
.54122 .58795 Mdot
.62273 .74488 Mdot
.49079 .7066 Mdot
.43649 .2038 Mdot
.63221 .57811 Mdot
.3468 .61777 Mdot
.2608 .66226 Mdot
.38115 .47774 Mdot
.59038 .58508 Mdot
.32057 .55373 Mdot
.56765 .79441 Mdot
.45493 .28999 Mdot
.82885 .43034 Mdot
.34712 .54065 Mdot
.69915 .66167 Mdot
.38514 .51441 Mdot
.39396 .39025 Mdot
.34137 .47142 Mdot
.46602 .68426 Mdot
.31233 .56743 Mdot
.50378 .51125 Mdot
.77366 .68561 Mdot
.55713 .78278 Mdot
.49401 .34128 Mdot
.38445 .52443 Mdot
.38426 .47823 Mdot
.49823 .3177 Mdot
.47073 .66561 Mdot
.34521 .46928 Mdot
.30411 .3498 Mdot
.37382 .47171 Mdot
.62247 .59705 Mdot
.47233 .39757 Mdot
.44849 .739 Mdot
.39679 .4684 Mdot
.44639 .69515 Mdot
.6384 .57545 Mdot
.58533 .55717 Mdot
.37654 .44171 Mdot
.64382 .56758 Mdot
.33482 .52681 Mdot
.47265 .37365 Mdot
.50031 .6668 Mdot
.45218 .46652 Mdot
.46885 .66244 Mdot
.43107 .74843 Mdot
.63934 .56381 Mdot
.77487 .5019 Mdot
.52402 .62128 Mdot
.62969 .57309 Mdot
.48673 .78703 Mdot
.28007 .52027 Mdot
.41793 .53876 Mdot
.54279 .8022 Mdot
.61815 .39899 Mdot
.77539 .4993 Mdot
.62575 .55237 Mdot
.36873 .46791 Mdot
.43028 .49076 Mdot
.61513 .60391 Mdot
.35861 .66613 Mdot
.67167 .30988 Mdot
.32708 .47994 Mdot
.46616 .67733 Mdot
.47958 .70188 Mdot
.3832 .55145 Mdot
.3604 .49338 Mdot
.63282 .43955 Mdot
.75926 .4832 Mdot
.79198 .48811 Mdot
.76471 .49878 Mdot
.60912 .37163 Mdot
.66891 .63336 Mdot
.63287 .54844 Mdot
.60502 .66279 Mdot
.69176 .54122 Mdot
.40694 .43589 Mdot
.6318 .38938 Mdot
.39896 .48678 Mdot
.36264 .53152 Mdot
.60451 .54819 Mdot
.74859 .55782 Mdot
.45398 .523 Mdot
.50737 .68644 Mdot
.64441 .57126 Mdot
.27435 .4914 Mdot
.66298 .6077 Mdot
.53171 .34721 Mdot
.50433 .78372 Mdot
.59331 .58982 Mdot
.48108 .71177 Mdot
.62474 .60498 Mdot
.38146 .4754 Mdot
.31733 .47887 Mdot
.49407 .69428 Mdot
.49282 .31453 Mdot
.42846 .4741 Mdot
.40154 .50357 Mdot
.50472 .86441 Mdot
.65898 .71013 Mdot
.57168 .60151 Mdot
.34394 .50754 Mdot
.43515 .50532 Mdot
.49083 .34209 Mdot
.37239 .47332 Mdot
.38361 .53018 Mdot
.70004 .72647 Mdot
.58928 .52765 Mdot
.5178 .2996 Mdot
.34829 .61579 Mdot
.45886 .65659 Mdot
.43994 .18202 Mdot
.78591 .48335 Mdot
.60976 .52643 Mdot
.70491 .35755 Mdot
.76804 .49517 Mdot
.70187 .53503 Mdot
.43981 .19334 Mdot
.76825 .49963 Mdot
.71026 .39935 Mdot
.40627 .57891 Mdot
.32507 .47563 Mdot
.39009 .50961 Mdot
.52343 .33812 Mdot
.49394 .67889 Mdot
.53789 .43433 Mdot
.51463 .22923 Mdot
.381 .51863 Mdot
.53031 .67187 Mdot
.49449 .20591 Mdot
.77067 .48937 Mdot
.52223 .31816 Mdot
.54351 .34411 Mdot
.38854 .51643 Mdot
.72509 .69033 Mdot
.47441 .68163 Mdot
.35347 .48962 Mdot
.38931 .46897 Mdot
.62135 .40231 Mdot
.4883 .71302 Mdot
.63493 .37591 Mdot
.75343 .48361 Mdot
.20114 .42353 Mdot
.47359 .85801 Mdot
.60041 .55393 Mdot
.3498 .23267 Mdot
.58282 .55569 Mdot
.7936 .37067 Mdot
.76135 .49391 Mdot
.36536 .50384 Mdot
.51679 .66843 Mdot
.34924 .48592 Mdot
.3794 .48562 Mdot
.37231 .48137 Mdot
.28786 .52977 Mdot
.43536 .824 Mdot
.50748 .32911 Mdot
.42356 .44923 Mdot
.65503 .43603 Mdot
.38313 .206 Mdot
.6546 .22997 Mdot
.40571 .48805 Mdot
.39157 .51891 Mdot
.45656 .69495 Mdot
.33864 .45895 Mdot
.58527 .59033 Mdot
.48699 .65163 Mdot
.42946 .49896 Mdot
.42378 .21116 Mdot
.34836 .46737 Mdot
.29221 .26813 Mdot
.62296 .60499 Mdot
.49725 .78101 Mdot
.41674 .44661 Mdot
.76896 .50077 Mdot
.77463 .49951 Mdot
.79838 .49368 Mdot
.59299 .60052 Mdot
.63213 .39463 Mdot
.61655 .2342 Mdot
.29797 .51859 Mdot
.3364 .51312 Mdot
.43535 .50216 Mdot
.59299 .39269 Mdot
.48758 .44744 Mdot
.72151 .62221 Mdot
.27506 .49944 Mdot
.63836 .43697 Mdot
.4641 .64269 Mdot
.82363 .54535 Mdot
.48675 .65233 Mdot
.51623 .29848 Mdot
.60644 .59363 Mdot
.53525 .34288 Mdot
.44001 .79848 Mdot
.49768 .68797 Mdot
.50389 .73272 Mdot
.62747 .40151 Mdot
.54133 .46689 Mdot
.43505 .11839 Mdot
.67181 .39601 Mdot
.3294 .35645 Mdot
.48301 .66789 Mdot
.40805 .4762 Mdot
.50745 .40652 Mdot
.536 .46827 Mdot
.63571 .40802 Mdot
.36478 .51414 Mdot
.771 .66454 Mdot
.62997 .43855 Mdot
.41543 .46972 Mdot
.62798 .42393 Mdot
.62138 .59278 Mdot
.63063 .42281 Mdot
.50144 .65135 Mdot
.39827 .53442 Mdot
.48079 .09763 Mdot
.59786 .48519 Mdot
.33864 .48479 Mdot
.6443 .57141 Mdot
.28092 .35714 Mdot
.38774 .49001 Mdot
.53919 .34155 Mdot
.65356 .4296 Mdot
.64627 .2926 Mdot
.33145 .48131 Mdot
.63418 .4173 Mdot
.50226 .65775 Mdot
.58147 .54701 Mdot
.75322 .32246 Mdot
.78712 .49544 Mdot
.49404 .67039 Mdot
.78114 .46936 Mdot
.62589 .61278 Mdot
.42108 .48017 Mdot
.38244 .46797 Mdot
.46229 .68999 Mdot
.74499 .41597 Mdot
.35284 .45525 Mdot
.36048 .50796 Mdot
.60691 .41468 Mdot
.60478 .42714 Mdot
.73451 .38022 Mdot
.61456 .39426 Mdot
.43722 .495 Mdot
.46293 .69015 Mdot
.3551 .52946 Mdot
.46604 .70788 Mdot
.3464 .53339 Mdot
.47721 .6262 Mdot
.49429 .66031 Mdot
.77753 .62075 Mdot
.36123 .524 Mdot
.37091 .42029 Mdot
.37692 .4826 Mdot
.36344 .47273 Mdot
.66334 .42299 Mdot
.50346 .31977 Mdot
.315 .46121 Mdot
.66876 .45364 Mdot
.52601 .31847 Mdot
.21526 .53757 Mdot
.61971 .40353 Mdot
.5282 .33873 Mdot
.45544 .25118 Mdot
.77015 .47471 Mdot
.5158 .33042 Mdot
.64138 .22413 Mdot
.60167 .55182 Mdot
.46427 .64784 Mdot
.32491 .49453 Mdot
.18689 .40699 Mdot
.46388 .37821 Mdot
.76929 .48234 Mdot
.33947 .47872 Mdot
.39638 .48791 Mdot
.46791 .72811 Mdot
.85599 .56026 Mdot
.60796 .42475 Mdot
.34167 .52171 Mdot
.4506 .69675 Mdot
.76299 .71868 Mdot
.66827 .41389 Mdot
.51908 .33317 Mdot
.62517 .6001 Mdot
.43648 .6858 Mdot
.78801 .49552 Mdot
.58038 .57372 Mdot
.68629 .35515 Mdot
.45551 .79947 Mdot
.34621 .47464 Mdot
.63731 .38604 Mdot
.37843 .80242 Mdot
.29027 .51306 Mdot
.56209 .60933 Mdot
.28314 .434 Mdot
.48779 .70798 Mdot
.61912 .60204 Mdot
.51921 .35694 Mdot
.49046 .65062 Mdot
.47051 .66774 Mdot
.60585 .54093 Mdot
.58752 .37485 Mdot
.52405 .4473 Mdot
.61402 .60002 Mdot
.61349 .76857 Mdot
.20663 .56266 Mdot
.76504 .47874 Mdot
.51328 .31231 Mdot
.21064 .63642 Mdot
.47439 .69068 Mdot
.49316 .18832 Mdot
.41766 .81344 Mdot
.32046 .48733 Mdot
.51891 .349 Mdot
.6877 .58601 Mdot
.59515 .22518 Mdot
.60417 .5739 Mdot
.49277 .48433 Mdot
.54124 .32631 Mdot
.33331 .4711 Mdot
.49278 .76494 Mdot
.35718 .51844 Mdot
.61171 .59193 Mdot
.43193 .73282 Mdot
.47863 .71223 Mdot
.63072 .61091 Mdot
.49629 .78847 Mdot
.36538 .53254 Mdot
.3624 .51904 Mdot
.41846 .37804 Mdot
.49843 .70597 Mdot
.7921 .49124 Mdot
.34829 .4924 Mdot
.39415 .5039 Mdot
.41803 .47998 Mdot
.29958 .45249 Mdot
.70715 .70167 Mdot
.34453 .52304 Mdot
.63559 .36519 Mdot
.38457 .55611 Mdot
.36511 .5227 Mdot
.45046 .7036 Mdot
.47376 .85065 Mdot
.75785 .49656 Mdot
.38765 .50729 Mdot
.34782 .47046 Mdot
.60723 .54303 Mdot
.5208 .42748 Mdot
.53647 .47487 Mdot
.66568 .39164 Mdot
.40305 .31948 Mdot
.29017 .53269 Mdot
.45572 .66705 Mdot
.51714 .30565 Mdot
.41913 .50609 Mdot
.45217 .68034 Mdot
.33363 .54613 Mdot
.63125 .43721 Mdot
.76213 .48088 Mdot
.53935 .75385 Mdot
.51993 .32677 Mdot
.53985 .38902 Mdot
.59635 .68201 Mdot
.61239 .41081 Mdot
.33181 .51007 Mdot
.59789 .53435 Mdot
.65612 .38469 Mdot
.7737 .48529 Mdot
.44965 .50887 Mdot
.48173 .67858 Mdot
.47383 .70716 Mdot
.33674 .39168 Mdot
.66514 .44758 Mdot
.6217 .82031 Mdot
.62 .59302 Mdot
.40899 .53424 Mdot
.55932 .66543 Mdot
.47235 .70732 Mdot
.33237 .39042 Mdot
.5288 .33735 Mdot
.6041 .57165 Mdot
.79188 .50386 Mdot
.45329 .68541 Mdot
.49783 .71174 Mdot
.35413 .5447 Mdot
.41014 .50406 Mdot
.37808 .34704 Mdot
.31314 .39866 Mdot
.63602 .584 Mdot
.50402 .31177 Mdot
.65094 .37506 Mdot
.35055 .51854 Mdot
.49484 .65797 Mdot
.21967 .5935 Mdot
.35669 .46465 Mdot
.63223 .43992 Mdot
.48945 .70459 Mdot
.49731 .31655 Mdot
.53633 .33109 Mdot
.36408 .47295 Mdot
.37854 .75473 Mdot
.62873 .56377 Mdot
.46916 .70732 Mdot
.53257 .72305 Mdot
.35977 .45315 Mdot
.4095 .51036 Mdot
.40415 .56114 Mdot
.58254 .56753 Mdot
.51296 .76782 Mdot
.5096 .30069 Mdot
.48375 .68772 Mdot
.34176 .48433 Mdot
.52244 .32393 Mdot
.54234 .72011 Mdot
.76348 .49107 Mdot
.63181 .42549 Mdot
.53864 .34539 Mdot
.49678 .33369 Mdot
.52231 .31345 Mdot
.50913 .18552 Mdot
.51655 .69806 Mdot
.41974 .62664 Mdot
.33992 .47114 Mdot
.34657 .38997 Mdot
.31038 .48063 Mdot
.59968 .60523 Mdot
.61746 .39558 Mdot
.38161 .48351 Mdot
.3563 .54521 Mdot
.31452 .42633 Mdot
.31893 .44296 Mdot
.52048 .72563 Mdot
.49865 .69814 Mdot
.33881 .43254 Mdot
.62122 .39756 Mdot
.85943 .58818 Mdot
.37904 .16756 Mdot
.40868 .44569 Mdot
.53281 .44305 Mdot
.49179 .65539 Mdot
.60919 .53902 Mdot
.53092 .48532 Mdot
.63752 .59487 Mdot
.48384 .69328 Mdot
.34991 .52035 Mdot
.61022 .66417 Mdot
.49504 .35034 Mdot
.37469 .46866 Mdot
.61333 .58521 Mdot
.3741 .46902 Mdot
.59519 .59826 Mdot
.46069 .61385 Mdot
.62881 .74849 Mdot
.31759 .50084 Mdot
.38326 .45746 Mdot
.32914 .42403 Mdot
.40662 .49078 Mdot
.79083 .45152 Mdot
.4779 .65881 Mdot
.78265 .65018 Mdot
.36828 .55093 Mdot
.3961 .73766 Mdot
.34167 .46591 Mdot
.73382 .43605 Mdot
.41345 .50162 Mdot
.52473 .51548 Mdot
.32552 .47784 Mdot
.39335 .52618 Mdot
.6309 .55887 Mdot
.6068 .54289 Mdot
.50664 .6692 Mdot
.79148 .49425 Mdot
.33073 .2318 Mdot
.4054 .50653 Mdot
.62678 .36481 Mdot
.55036 .59269 Mdot
.49665 .32681 Mdot
.48111 .69397 Mdot
.76318 .72838 Mdot
.64012 .57253 Mdot
.68062 .40351 Mdot
.7504 .42994 Mdot
.61304 .37692 Mdot
.60661 .51699 Mdot
.26864 .52065 Mdot
.49204 .31958 Mdot
.33681 .46793 Mdot
.2588 .69923 Mdot
.67243 .6867 Mdot
.43053 .47378 Mdot
.63805 .60217 Mdot
.35233 .59574 Mdot
.21501 .63946 Mdot
.53987 .35403 Mdot
.5053 .35104 Mdot
.63409 .56387 Mdot
.60228 .40157 Mdot
.31183 .55567 Mdot
.52966 .33816 Mdot
.62005 .42493 Mdot
.79643 .48758 Mdot
.50278 .57583 Mdot
.47548 .68478 Mdot
.51291 .77733 Mdot
.60326 .71129 Mdot
.63714 .58204 Mdot
.69465 .43667 Mdot
.44228 .65831 Mdot
.48435 .73344 Mdot
.785 .49999 Mdot
.66333 .42372 Mdot
.51843 .66733 Mdot
.42671 .47684 Mdot
.40016 .42774 Mdot
.38328 .51425 Mdot
.51849 .34323 Mdot
.40907 .48846 Mdot
.65545 .43295 Mdot
.6075 .57542 Mdot
.65889 .39709 Mdot
.62383 .55709 Mdot
.64941 .65479 Mdot
.35829 .48761 Mdot
.39497 .52311 Mdot
.48263 .38579 Mdot
.50814 .69674 Mdot
.41166 .79636 Mdot
.62565 .36414 Mdot
.64245 .40087 Mdot
.36622 .53577 Mdot
.49945 .65359 Mdot
.52007 .29419 Mdot
.4963 .38792 Mdot
.40103 .47569 Mdot
.47843 .65805 Mdot
.33911 .51814 Mdot
.45615 .23627 Mdot
.6491 .73971 Mdot
.46849 .69472 Mdot
.80398 .63923 Mdot
.34934 .50962 Mdot
.41119 .58304 Mdot
.43613 .50354 Mdot
.33206 .3325 Mdot
.36249 .45229 Mdot
.46194 .65309 Mdot
.38332 .50948 Mdot
.47913 .65166 Mdot
.60785 .4094 Mdot
.62375 .54134 Mdot
.49268 .66741 Mdot
.40521 .47644 Mdot
.50199 .16552 Mdot
.61738 .59041 Mdot
.38291 .52552 Mdot
.59196 .57383 Mdot
.449 .67614 Mdot
.50467 .69593 Mdot
.65171 .23677 Mdot
.56729 .57251 Mdot
.62407 .59043 Mdot
.33404 .52034 Mdot
.57691 .7329 Mdot
.35262 .5274 Mdot
.37173 .3538 Mdot
.37268 .54534 Mdot
.37411 .45258 Mdot
.77961 .31622 Mdot
.58911 .545 Mdot
.63891 .80759 Mdot
.50751 .22974 Mdot
.52429 .18093 Mdot
.43415 .69446 Mdot
.54017 .35386 Mdot
.44588 .20008 Mdot
.75511 .4812 Mdot
.6428 .4302 Mdot
.38095 .48252 Mdot
.42725 .66212 Mdot
.62632 .59694 Mdot
.5019 .32349 Mdot
.31747 .50294 Mdot
.64139 .441 Mdot
.70398 .29869 Mdot
.64384 .56471 Mdot
.47579 .69115 Mdot
.50767 .69267 Mdot
.74934 .7261 Mdot
.34136 .48166 Mdot
.38901 .52322 Mdot
.60711 .59299 Mdot
.29184 .48604 Mdot
.50281 .30716 Mdot
.59956 .32496 Mdot
.62479 .58913 Mdot
.60899 .49749 Mdot
.50002 .68686 Mdot
.39711 .48689 Mdot
.48229 .43759 Mdot
.64289 .48841 Mdot
.2616 .57256 Mdot
.52109 .33823 Mdot
.39376 .35553 Mdot
.46138 .65352 Mdot
.61361 .57716 Mdot
.49853 .26369 Mdot
.40884 .53778 Mdot
.39713 .4921 Mdot
.39715 .35798 Mdot
.52078 .42013 Mdot
.54372 .31067 Mdot
.33195 .46071 Mdot
.51213 .41751 Mdot
.37132 .53744 Mdot
.42977 .49543 Mdot
.378 .44703 Mdot
.40709 .51987 Mdot
.48195 .65621 Mdot
.30325 .43201 Mdot
.63572 .42239 Mdot
.33203 .64871 Mdot
.49955 .48437 Mdot
.3343 .49227 Mdot
.35247 .52297 Mdot
.27266 .56747 Mdot
.6066 .51277 Mdot
.47907 .66208 Mdot
.52258 .6703 Mdot
.63489 .55593 Mdot
.38725 .42226 Mdot
.59639 .39743 Mdot
.29165 .43012 Mdot
.66067 .40045 Mdot
.47759 .65724 Mdot
.64106 .39488 Mdot
.6304 .55116 Mdot
.63799 .38564 Mdot
.61234 .36989 Mdot
.60917 .60426 Mdot
.50216 .68135 Mdot
.40313 .47929 Mdot
.63956 .5621 Mdot
.41385 .37603 Mdot
.52001 .34317 Mdot
.65144 .23623 Mdot
.37762 .55766 Mdot
.46569 .45269 Mdot
.33539 .29174 Mdot
.65576 .39565 Mdot
.66342 .74116 Mdot
.49464 .66105 Mdot
.48195 .32228 Mdot
.48245 .65463 Mdot
.43504 .81478 Mdot
.50362 .31618 Mdot
.63846 .22241 Mdot
.57056 .35243 Mdot
.66552 .28049 Mdot
.32359 .46685 Mdot
.49291 .62471 Mdot
.64825 .37971 Mdot
.62866 .59528 Mdot
.59131 .36298 Mdot
.39495 .53038 Mdot
.7269 .65172 Mdot
.4908 .72633 Mdot
.78811 .48075 Mdot
.6165 .57065 Mdot
.6437 .59658 Mdot
.34654 .47887 Mdot
.70033 .3366 Mdot
.39142 .5396 Mdot
.53064 .28562 Mdot
.39669 .3382 Mdot
.28645 .4334 Mdot
.33716 .52912 Mdot
.66356 .39567 Mdot
.33784 .51786 Mdot
.36556 .59407 Mdot
.28191 .73199 Mdot
.42478 .54354 Mdot
.77014 .61353 Mdot
.53232 .37729 Mdot
.495 .69 Mdot
.40602 .44133 Mdot
.78043 .48398 Mdot
.34647 .50844 Mdot
.15312 .59382 Mdot
.51474 .32761 Mdot
.70061 .39367 Mdot
.35294 .45802 Mdot
.34752 .48844 Mdot
.30444 .73149 Mdot
.43187 .64139 Mdot
.79028 .50528 Mdot
.39496 .49607 Mdot
.41886 .32003 Mdot
.58747 .56129 Mdot
.39044 .54484 Mdot
.38901 .51196 Mdot
.21146 .50981 Mdot
.58446 .57493 Mdot
.65206 .39271 Mdot
.75883 .47783 Mdot
.65014 .37367 Mdot
.54802 .33428 Mdot
.54232 .49194 Mdot
.29462 .40669 Mdot
.64834 .73728 Mdot
.54095 .33303 Mdot
.37636 .46377 Mdot
.45362 .53329 Mdot
.35188 .50264 Mdot
.50978 .35427 Mdot
.58575 .58591 Mdot
.4866 .66034 Mdot
.54841 .7462 Mdot
.77611 .49139 Mdot
.41638 .47101 Mdot
.52747 .35817 Mdot
.48737 .67432 Mdot
.68642 .45396 Mdot
.48995 .68718 Mdot
.62868 .57796 Mdot
.60723 .61016 Mdot
.5123 .31745 Mdot
.48041 .65438 Mdot
.65321 .36984 Mdot
.51286 .23186 Mdot
.36499 .54275 Mdot
.60574 .62271 Mdot
.50935 .66206 Mdot
.44345 .69467 Mdot
.50063 .71794 Mdot
.35656 .48025 Mdot
.52583 .43502 Mdot
.4319 .50263 Mdot
.63663 .56806 Mdot
.62924 .42859 Mdot
.27552 .42225 Mdot
.31324 .74508 Mdot
.60569 .49281 Mdot
.32237 .45705 Mdot
.37576 .52774 Mdot
.38833 .51657 Mdot
.32058 .52376 Mdot
.51539 .25999 Mdot
.36003 .49114 Mdot
.62771 .55737 Mdot
.66292 .41393 Mdot
.33633 .48188 Mdot
.78134 .48257 Mdot
.51461 .44579 Mdot
.52431 .30973 Mdot
.51785 .49804 Mdot
.4463 .16852 Mdot
.48745 .67265 Mdot
.62441 .38186 Mdot
.64316 .42849 Mdot
.52339 .31215 Mdot
.6318 .5902 Mdot
.49185 .68186 Mdot
.34395 .31715 Mdot
.51414 .31024 Mdot
.38669 .50651 Mdot
.67298 .34718 Mdot
.81529 .59731 Mdot
.34063 .46128 Mdot
.37827 .49212 Mdot
.76492 .47461 Mdot
.59966 .39978 Mdot
.16137 .44343 Mdot
.52519 .40625 Mdot
.50729 .31844 Mdot
.4985 .34197 Mdot
.50291 .71721 Mdot
.42434 .46123 Mdot
.62093 .55823 Mdot
.49727 .40079 Mdot
.27613 .37688 Mdot
.56197 .40018 Mdot
.78755 .36636 Mdot
.3589 .46821 Mdot
.30408 .72273 Mdot
.34804 .53125 Mdot
.47182 .73121 Mdot
.46524 .71423 Mdot
.47751 .66786 Mdot
.63402 .57096 Mdot
.42454 .73837 Mdot
.62241 .55383 Mdot
.42157 .16189 Mdot
.47844 .6467 Mdot
.58124 .25996 Mdot
.63535 .39707 Mdot
.3024 .48589 Mdot
.49675 .3144 Mdot
.63023 .51083 Mdot
.36026 .44542 Mdot
.7175 .68926 Mdot
.6326 .38918 Mdot
.50329 .69154 Mdot
.28357 .5413 Mdot
.2564 .28295 Mdot
.55054 .47386 Mdot
.44718 .57673 Mdot
.3989 .78906 Mdot
.5003 .31641 Mdot
.27196 .58044 Mdot
.49122 .31363 Mdot
.60555 .58341 Mdot
.39859 .52843 Mdot
.41047 .51792 Mdot
.34222 .53223 Mdot
.36071 .4895 Mdot
.60807 .54678 Mdot
.33764 .54163 Mdot
.38734 .82209 Mdot
.76391 .47751 Mdot
.45862 .22353 Mdot
.532 .34236 Mdot
.62808 .60678 Mdot
.66248 .40897 Mdot
.7943 .49096 Mdot
.30988 .39223 Mdot
.32467 .48054 Mdot
.37889 .48325 Mdot
.77861 .50395 Mdot
.36441 .44713 Mdot
.27718 .50865 Mdot
.63751 .42186 Mdot
.59186 .49248 Mdot
.53792 .35128 Mdot
.53472 .34365 Mdot
.59945 .59678 Mdot
.48151 .65418 Mdot
.52621 .33706 Mdot
.60513 .41222 Mdot
.339 .54467 Mdot
.41933 .48777 Mdot
.50964 .66299 Mdot
.41804 .81375 Mdot
.54046 .35581 Mdot
.28982 .54793 Mdot
.46935 .65168 Mdot
.50743 .71712 Mdot
.39408 .49314 Mdot
.41575 .55284 Mdot
.44362 .66628 Mdot
.53802 .33181 Mdot
.63017 .60599 Mdot
.62539 .25545 Mdot
.60958 .58882 Mdot
.49135 .67774 Mdot
.37384 .55386 Mdot
.50143 .68358 Mdot
.34372 .50304 Mdot
.85263 .36567 Mdot
.41341 .50952 Mdot
.59198 .79966 Mdot
.3401 .33687 Mdot
.64756 .42713 Mdot
.6508 .36959 Mdot
.77309 .47863 Mdot
.46864 .65095 Mdot
.41828 .50982 Mdot
.49242 .3335 Mdot
.55342 .19263 Mdot
.47276 .62887 Mdot
.63363 .43486 Mdot
.5977 .39547 Mdot
.58219 .57854 Mdot
.3475 .46286 Mdot
.4011 .48919 Mdot
.64061 .38582 Mdot
.36352 .27069 Mdot
.45597 .67151 Mdot
.38753 .5232 Mdot
.37108 .52645 Mdot
.64454 .42465 Mdot
.51126 .23385 Mdot
.46885 .61784 Mdot
.40095 .52462 Mdot
.52767 .371 Mdot
.59557 .60199 Mdot
.32294 .52461 Mdot
.33491 .54001 Mdot
.50411 .34326 Mdot
.41368 .22255 Mdot
.23005 .67372 Mdot
.6096 .6069 Mdot
.79158 .49087 Mdot
.40254 .47218 Mdot
.6346 .39879 Mdot
.41038 .47936 Mdot
.2833 .29629 Mdot
.7731 .47574 Mdot
.3627 .49892 Mdot
.40354 .44632 Mdot
.48108 .71726 Mdot
.35656 .49331 Mdot
.2279 .51611 Mdot
.66577 .38579 Mdot
.36035 .49619 Mdot
.39215 .76918 Mdot
.58416 .56659 Mdot
.40277 .44335 Mdot
.52498 .35419 Mdot
.32636 .33406 Mdot
.60013 .69242 Mdot
.59185 .39104 Mdot
.53476 .33751 Mdot
.40381 .47827 Mdot
.60304 .39819 Mdot
.63265 .59402 Mdot
.71511 .67072 Mdot
.31664 .48804 Mdot
.61355 .59141 Mdot
.60891 .57433 Mdot
.51627 .32158 Mdot
.67142 .78813 Mdot
.3157 .45635 Mdot
.40658 .48853 Mdot
.21243 .47868 Mdot
.48139 .72471 Mdot
.40407 .4824 Mdot
.36413 .46285 Mdot
.61068 .55682 Mdot
.52723 .62383 Mdot
.38286 .60669 Mdot
.63551 .32731 Mdot
.59557 .5991 Mdot
.58587 .40649 Mdot
.60355 .39714 Mdot
.53116 .34212 Mdot
.49169 .6965 Mdot
.53625 .31765 Mdot
.62394 .41066 Mdot
.34673 .46998 Mdot
.60336 .56366 Mdot
.25393 .60255 Mdot
.6097 .53498 Mdot
.65568 .44265 Mdot
.45386 .71826 Mdot
.56391 .67335 Mdot
.21336 .68488 Mdot
.6154 .70147 Mdot
.6315 .53292 Mdot
.49667 .32761 Mdot
.60659 .35179 Mdot
.37328 .52664 Mdot
.30969 .60424 Mdot
.38847 .47294 Mdot
.39264 .78188 Mdot
.61413 .40242 Mdot
.78582 .50054 Mdot
.39987 .52787 Mdot
.40128 .34532 Mdot
.65051 .57147 Mdot
.58142 .57687 Mdot
.36918 .49082 Mdot
.63012 .57418 Mdot
.40831 .50171 Mdot
.66513 .41457 Mdot
.62552 .80505 Mdot
.37912 .52691 Mdot
.43219 .52164 Mdot
.56589 .55685 Mdot
.64869 .23301 Mdot
.6542 .36631 Mdot
.30288 .72372 Mdot
.22683 .31696 Mdot
.62905 .57212 Mdot
.4381 .47975 Mdot
.64471 .3815 Mdot
.76554 .47433 Mdot
.67429 .38062 Mdot
.38338 .47341 Mdot
.36965 .474 Mdot
.36462 .53561 Mdot
.36159 .51889 Mdot
.30439 .59954 Mdot
.293 .46422 Mdot
.30751 .70992 Mdot
.37828 .48492 Mdot
.50359 .75717 Mdot
.61876 .5504 Mdot
.51762 .72831 Mdot
.52809 .36497 Mdot
.35624 .46908 Mdot
.42423 .6687 Mdot
.61626 .60728 Mdot
.41884 .16329 Mdot
.58307 .57729 Mdot
.65303 .40832 Mdot
.5987 .54213 Mdot
.33962 .49928 Mdot
.47871 .70231 Mdot
.67016 .3948 Mdot
.70688 .63059 Mdot
.64267 .43122 Mdot
.33862 .48427 Mdot
.5157 .24606 Mdot
.64049 .42792 Mdot
.51462 .45976 Mdot
.48296 .7037 Mdot
.42482 .32188 Mdot
.45957 .71042 Mdot
.35976 .49935 Mdot
.36058 .50315 Mdot
.7941 .48197 Mdot
.63887 .55189 Mdot
.44943 .66997 Mdot
.51384 .86456 Mdot
.53871 .31479 Mdot
.47263 .67402 Mdot
.30345 .52746 Mdot
.52715 .42845 Mdot
.46628 .69962 Mdot
.38695 .30711 Mdot
.63212 .5912 Mdot
.51862 .68794 Mdot
.32144 .54647 Mdot
.53791 .58029 Mdot
.48598 .3393 Mdot
.65048 .44091 Mdot
.54752 .53159 Mdot
.64861 .37868 Mdot
.61894 .60972 Mdot
.64358 .4477 Mdot
.59025 .55708 Mdot
.47815 .78222 Mdot
.42751 .63287 Mdot
.61632 .53301 Mdot
.61979 .61272 Mdot
.62876 .40715 Mdot
.31584 .49996 Mdot
.49452 .51563 Mdot
.33808 .45578 Mdot
.31528 .47932 Mdot
.5876 .55832 Mdot
.45112 .67265 Mdot
.4715 .64451 Mdot
.51613 .63749 Mdot
.50618 .70031 Mdot
.66435 .40605 Mdot
.64633 .74957 Mdot
.43563 .79851 Mdot
.59661 .59002 Mdot
.61083 .61789 Mdot
.35238 .52631 Mdot
.63196 .40121 Mdot
.60919 .40724 Mdot
.61363 .5608 Mdot
.2796 .60781 Mdot
.43142 .51484 Mdot
.45749 .71667 Mdot
.4812 .64716 Mdot
.46492 .69208 Mdot
.50553 .7102 Mdot
.39687 .64603 Mdot
.62975 .59478 Mdot
.47398 .64836 Mdot
.36706 .495 Mdot
.37354 .47324 Mdot
.78114 .49652 Mdot
.53183 .34955 Mdot
.32934 .54551 Mdot
.4292 .53739 Mdot
.39408 .49118 Mdot
.63339 .42637 Mdot
.45645 .49489 Mdot
.78611 .48202 Mdot
.62065 .43729 Mdot
.59597 .38989 Mdot
.77477 .50155 Mdot
.53521 .66775 Mdot
.23899 .29239 Mdot
.34168 .52153 Mdot
.46689 .52176 Mdot
.63715 .40296 Mdot
.67169 .75697 Mdot
.52583 .7528 Mdot
.33512 .52885 Mdot
.5172 .57251 Mdot
.6711 .40261 Mdot
.48442 .72677 Mdot
.39684 .4774 Mdot
.76162 .49607 Mdot
.52085 .30791 Mdot
.30319 .52923 Mdot
.75862 .47716 Mdot
.4747 .65646 Mdot
.48733 .28352 Mdot
.51373 .70272 Mdot
.67246 .40537 Mdot
.39941 .44427 Mdot
.4397 .11444 Mdot
.63093 .37659 Mdot
.55273 .2008 Mdot
.44057 .62113 Mdot
.38343 .52845 Mdot
.63663 .37608 Mdot
.47836 .72746 Mdot
.59576 .60369 Mdot
.5028 .41655 Mdot
.49829 .66546 Mdot
.79257 .49445 Mdot
.77429 .49764 Mdot
.63901 .42365 Mdot
.4957 .70408 Mdot
.38434 .54899 Mdot
.4691 .71292 Mdot
.59407 .54434 Mdot
.32296 .51444 Mdot
.31589 .23652 Mdot
.38358 .42504 Mdot
.4593 .65749 Mdot
.63376 .4414 Mdot
.4887 .33998 Mdot
.32064 .49152 Mdot
.51592 .21214 Mdot
.35433 .46179 Mdot
.58818 .57474 Mdot
.74701 .69412 Mdot
.24452 .58192 Mdot
.33766 .47283 Mdot
.35343 .52576 Mdot
.61169 .6045 Mdot
.32298 .48404 Mdot
.34415 .46105 Mdot
.56129 .6004 Mdot
.4796 .71528 Mdot
.38029 .51462 Mdot
.61424 .42055 Mdot
.3058 .7465 Mdot
.4007 .46986 Mdot
.77455 .59289 Mdot
.41764 .33355 Mdot
.72575 .72117 Mdot
.41279 .48673 Mdot
.40827 .38152 Mdot
.36652 .51106 Mdot
.35498 .47468 Mdot
.33835 .52405 Mdot
.28254 .69846 Mdot
.62639 .40557 Mdot
.64792 .4369 Mdot
.48555 .33959 Mdot
.41587 .33084 Mdot
.5159 .34869 Mdot
.59692 .5977 Mdot
.74649 .33022 Mdot
.76831 .47643 Mdot
.48137 .65345 Mdot
.40423 .53214 Mdot
.67429 .39927 Mdot
.39446 .48383 Mdot
.34062 .50327 Mdot
.66951 .40989 Mdot
.61445 .38223 Mdot
.6999 .4157 Mdot
.49501 .31133 Mdot
.48479 .66494 Mdot
.34672 .54197 Mdot
.52586 .31852 Mdot
.38984 .54781 Mdot
.52335 .4129 Mdot
.48219 .6637 Mdot
.47159 .71478 Mdot
.44643 .67476 Mdot
.3471 .46942 Mdot
.33443 .49576 Mdot
.62039 .55309 Mdot
.50584 .65569 Mdot
.60518 .59796 Mdot
.65517 .38299 Mdot
.66589 .37941 Mdot
.38268 .47328 Mdot
.29324 .55592 Mdot
.49608 .3372 Mdot
.65449 .40354 Mdot
.77887 .50472 Mdot
.48365 .32594 Mdot
.34065 .478 Mdot
.66215 .39363 Mdot
.53561 .34431 Mdot
.2983 .63922 Mdot
.20773 .34494 Mdot
.49385 .3457 Mdot
.36965 .49275 Mdot
.31344 .74093 Mdot
.48013 .26654 Mdot
.53177 .30797 Mdot
.59481 .58159 Mdot
.35747 .46292 Mdot
.2635 .35422 Mdot
.54326 .33476 Mdot
.39694 .79489 Mdot
.6503 .42568 Mdot
.51579 .61014 Mdot
.33363 .55531 Mdot
.32699 .6189 Mdot
.53578 .31501 Mdot
.4878 .68445 Mdot
.49161 .64011 Mdot
.3786 .50104 Mdot
.51864 .36774 Mdot
.57969 .56781 Mdot
.65503 .42562 Mdot
.63099 .36466 Mdot
.49223 .70878 Mdot
.59107 .7432 Mdot
.621 .42992 Mdot
.31061 .56279 Mdot
.69936 .35099 Mdot
.43218 .44177 Mdot
.46143 .77408 Mdot
.69428 .63438 Mdot
.42264 .48909 Mdot
.49488 .34434 Mdot
.63573 .59852 Mdot
.62831 .55951 Mdot
.62714 .58323 Mdot
.64205 .36861 Mdot
.52818 .48751 Mdot
.62946 .3882 Mdot
.71255 .66209 Mdot
.52288 .32447 Mdot
.43174 .29729 Mdot
.41682 .51067 Mdot
.37695 .52719 Mdot
.39578 .54844 Mdot
.3876 .53902 Mdot
.36898 .51349 Mdot
.63211 .58772 Mdot
.62452 .37068 Mdot
.64361 .2945 Mdot
.46486 .6775 Mdot
.71641 .43396 Mdot
.63552 .39677 Mdot
.76547 .47497 Mdot
.5053 .32834 Mdot
.40011 .39022 Mdot
.60799 .43257 Mdot
.64169 .39584 Mdot
.32792 .53959 Mdot
.45524 .69483 Mdot
.26894 .49721 Mdot
.36091 .50857 Mdot
.65522 .40082 Mdot
.57322 .37827 Mdot
.25364 .54249 Mdot
.41492 .56122 Mdot
.50046 .29075 Mdot
.52852 .43351 Mdot
.50355 .30091 Mdot
.39743 .55793 Mdot
.67728 .7536 Mdot
.62495 .4112 Mdot
.64975 .41468 Mdot
.52493 .35788 Mdot
.40338 .58374 Mdot
.49256 .7029 Mdot
.78619 .50082 Mdot
.59282 .56777 Mdot
.3539 .50237 Mdot
.64974 .37179 Mdot
.43072 .58896 Mdot
.68161 .32415 Mdot
.62308 .58821 Mdot
.61857 .43541 Mdot
.34434 .46567 Mdot
.37173 .49201 Mdot
.49817 .31874 Mdot
.47317 .51937 Mdot
.29951 .50705 Mdot
.52319 .18073 Mdot
.62842 .74685 Mdot
.57952 .77419 Mdot
.39741 .49209 Mdot
.49169 .7114 Mdot
.76278 .4948 Mdot
.51175 .3116 Mdot
.36002 .54979 Mdot
.21289 .33361 Mdot
.45886 .64334 Mdot
.61138 .58284 Mdot
.76558 .4984 Mdot
.52695 .48579 Mdot
.35785 .46168 Mdot
.38918 .47329 Mdot
.35843 .48465 Mdot
.18245 .36422 Mdot
.62973 .43377 Mdot
.50039 .71651 Mdot
.51877 .33927 Mdot
.50258 .71093 Mdot
.64587 .43494 Mdot
.55784 .73597 Mdot
.33248 .48306 Mdot
.45756 .71878 Mdot
.48685 .68793 Mdot
.58246 .58054 Mdot
.58529 .59541 Mdot
.70122 .41676 Mdot
.41248 .51105 Mdot
.75889 .49338 Mdot
.46255 .71304 Mdot
.60813 .3834 Mdot
.50294 .31596 Mdot
.63775 .56115 Mdot
.37688 .48461 Mdot
.62979 .41812 Mdot
.42376 .46879 Mdot
.46279 .69971 Mdot
.64103 .39638 Mdot
.75308 .49211 Mdot
.5054 .34822 Mdot
.37301 .47805 Mdot
.52025 .2914 Mdot
.77612 .50296 Mdot
.36972 .5279 Mdot
.29096 .42216 Mdot
.55864 .35418 Mdot
.71454 .62541 Mdot
.62733 .38437 Mdot
.78405 .48926 Mdot
.47149 .71782 Mdot
.54673 .64653 Mdot
.65345 .415 Mdot
.34808 .39759 Mdot
.47796 .53861 Mdot
.3423 .53994 Mdot
.47168 .69221 Mdot
.58837 .35655 Mdot
.47419 .18096 Mdot
.46628 .25689 Mdot
.38494 .52144 Mdot
.63942 .37618 Mdot
.53751 .33943 Mdot
.59476 .58897 Mdot
.77599 .59387 Mdot
.41542 .66291 Mdot
.63876 .44753 Mdot
.34331 .52457 Mdot
.46173 .71166 Mdot
.61381 .56222 Mdot
.62283 .66017 Mdot
.60758 .42037 Mdot
.6144 .39796 Mdot
.33715 .47741 Mdot
.52768 .33311 Mdot
.40939 .25138 Mdot
.65137 .43667 Mdot
.64524 .37204 Mdot
.7245 .42028 Mdot
.52239 .35973 Mdot
.3722 .50005 Mdot
.51508 .63636 Mdot
.31346 .51344 Mdot
.55668 .19857 Mdot
.78473 .48276 Mdot
.46392 .67616 Mdot
.37219 .46972 Mdot
.67031 .33489 Mdot
.65964 .40771 Mdot
.53308 .44543 Mdot
.65729 .44508 Mdot
.6337 .58745 Mdot
.652 .3723 Mdot
.39805 .48063 Mdot
.65083 .57165 Mdot
.49817 .33979 Mdot
.40296 .52323 Mdot
.33353 .49674 Mdot
.47794 .72953 Mdot
.60409 .58313 Mdot
.21373 .61312 Mdot
.62532 .61437 Mdot
.62383 .60529 Mdot
.51178 .64912 Mdot
.38258 .50389 Mdot
.64995 .40564 Mdot
.6592 .43788 Mdot
.3636 .54919 Mdot
.64947 .76443 Mdot
.49108 .70639 Mdot
.70294 .41621 Mdot
.16615 .43629 Mdot
.32233 .56271 Mdot
.76119 .5011 Mdot
.47028 .50272 Mdot
.58422 .59039 Mdot
.37332 .48785 Mdot
.46069 .65791 Mdot
.63365 .37213 Mdot
.61997 .42859 Mdot
.37772 .55279 Mdot
.60881 .56887 Mdot
.53474 .32019 Mdot
.61206 .39668 Mdot
.69387 .33412 Mdot
.35434 .48799 Mdot
.73138 .64694 Mdot
.61637 .38887 Mdot
.58219 .18443 Mdot
.65697 .30679 Mdot
.46854 .6903 Mdot
.33875 .50433 Mdot
.50723 .68052 Mdot
.51353 .3412 Mdot
.59009 .38548 Mdot
.60714 .57313 Mdot
.42197 .56046 Mdot
.26742 .73037 Mdot
.62696 .40174 Mdot
.48147 .65674 Mdot
.33844 .47186 Mdot
.35289 .57322 Mdot
.40993 .49171 Mdot
.53077 .63204 Mdot
.56146 .33796 Mdot
.58585 .56052 Mdot
.58921 .57622 Mdot
.36264 .53102 Mdot
.5077 .30764 Mdot
.66658 .423 Mdot
.65552 .4236 Mdot
.87766 .55178 Mdot
.75249 .49231 Mdot
.36677 .34649 Mdot
.3696 .47569 Mdot
.60557 .38425 Mdot
.30549 .73908 Mdot
.60723 .59327 Mdot
.38625 .5411 Mdot
.60685 .37752 Mdot
.64321 .49359 Mdot
.52167 .41511 Mdot
.37102 .50789 Mdot
.28945 .52724 Mdot
.59175 .57073 Mdot
.50128 .39314 Mdot
.63275 .38737 Mdot
.37792 .54406 Mdot
.62952 .6132 Mdot
.73024 .37811 Mdot
.35623 .79603 Mdot
.48429 .66509 Mdot
.65825 .44262 Mdot
.63185 .5888 Mdot
.29697 .50817 Mdot
.53291 .34187 Mdot
.66004 .38263 Mdot
.6359 .42999 Mdot
.32639 .51195 Mdot
.31247 .52398 Mdot
.32522 .56389 Mdot
.47104 .66427 Mdot
.60659 .55148 Mdot
.3974 .53135 Mdot
.59629 .74368 Mdot
.36662 .53688 Mdot
.61048 .55246 Mdot
.58896 .11405 Mdot
.3125 .49971 Mdot
.4097 .49361 Mdot
.42918 .24963 Mdot
.50097 .66802 Mdot
.50321 .70835 Mdot
.63396 .74911 Mdot
.36995 .47591 Mdot
.67938 .29803 Mdot
.48774 .66607 Mdot
.48724 .70775 Mdot
.57353 .26684 Mdot
.32559 .52024 Mdot
.51906 .38936 Mdot
.61828 .55745 Mdot
.64149 .57232 Mdot
.47382 .71383 Mdot
.29845 .50424 Mdot
.6262 .60056 Mdot
.34275 .60845 Mdot
.63212 .39501 Mdot
.68032 .75178 Mdot
.4576 .69111 Mdot
.48332 .48291 Mdot
.61415 .59365 Mdot
.42673 .15945 Mdot
.52939 .56274 Mdot
.35605 .53449 Mdot
.36835 .48093 Mdot
.50641 .34648 Mdot
.35553 .44243 Mdot
.79219 .48843 Mdot
.63056 .57528 Mdot
.38007 .24249 Mdot
.47681 .66888 Mdot
.41242 .50657 Mdot
.38236 .38912 Mdot
.62879 .66911 Mdot
.76784 .62082 Mdot
.49431 .68985 Mdot
.47344 .68653 Mdot
.62193 .39587 Mdot
.6197 .41388 Mdot
.37717 .50723 Mdot
.63301 .56432 Mdot
.51293 .66114 Mdot
.59607 .5598 Mdot
.62433 .41215 Mdot
.64394 .40006 Mdot
.7755 .4759 Mdot
.39967 .45745 Mdot
.6677 .41421 Mdot
.72451 .35497 Mdot
.58456 .74776 Mdot
.48893 .73087 Mdot
.20079 .65019 Mdot
.62393 .65828 Mdot
.33838 .29942 Mdot
.50051 .30407 Mdot
.79987 .50399 Mdot
.61379 .54127 Mdot
.35622 .52695 Mdot
.38506 .48218 Mdot
.77019 .48925 Mdot
.62926 .54111 Mdot
.50137 .32881 Mdot
.6361 .54727 Mdot
.52582 .32463 Mdot
.66797 .37666 Mdot
.40149 .47074 Mdot
.37529 .46482 Mdot
.63143 .58672 Mdot
.64954 .391 Mdot
.66198 .42117 Mdot
.49379 .30848 Mdot
.43107 .39164 Mdot
.63681 .42324 Mdot
.45849 .69376 Mdot
.39869 .70827 Mdot
.77302 .49657 Mdot
.39923 .47889 Mdot
.33804 .39046 Mdot
.27586 .59095 Mdot
.35035 .54101 Mdot
.76727 .50021 Mdot
.85073 .60404 Mdot
.41584 .50935 Mdot
.80512 .66564 Mdot
.78496 .49139 Mdot
.502 .66827 Mdot
.63114 .37878 Mdot
.7932 .48763 Mdot
.30976 .54207 Mdot
.51582 .29764 Mdot
.3588 .55657 Mdot
.49952 .66914 Mdot
.44627 .69101 Mdot
.55598 .79643 Mdot
.55798 .19975 Mdot
.48907 .31984 Mdot
.50796 .32148 Mdot
.65262 .41724 Mdot
.76456 .31094 Mdot
.32325 .54658 Mdot
.50433 .32084 Mdot
.36777 .25617 Mdot
.34865 .52276 Mdot
.36959 .3586 Mdot
.51694 .56813 Mdot
.49111 .71095 Mdot
.53369 .69813 Mdot
.65763 .41238 Mdot
.48211 .6574 Mdot
.56201 .7639 Mdot
.39414 .54945 Mdot
.4799 .66471 Mdot
.60815 .55431 Mdot
.70516 .53696 Mdot
.50563 .68798 Mdot
.49096 .40601 Mdot
.62193 .55929 Mdot
.56563 .34356 Mdot
.40207 .26882 Mdot
.15177 .62139 Mdot
.63179 .5739 Mdot
.65317 .38649 Mdot
.67192 .40616 Mdot
.65381 .42281 Mdot
.49773 .6632 Mdot
.60702 .40848 Mdot
.46511 .66617 Mdot
.5299 .22802 Mdot
.39412 .38539 Mdot
.51383 .31723 Mdot
.56751 .58071 Mdot
.47999 .68937 Mdot
.6804 .70674 Mdot
.21712 .68516 Mdot
.36772 .49035 Mdot
.6273 .61384 Mdot
.52331 .35768 Mdot
.7054 .23333 Mdot
.50588 .34492 Mdot
.64291 .38115 Mdot
.68785 .74643 Mdot
.40831 .50581 Mdot
.23426 .49512 Mdot
.49925 .34428 Mdot
.49679 .68291 Mdot
.37238 .52806 Mdot
.67885 .43447 Mdot
.52965 .34164 Mdot
.52579 .31158 Mdot
.37292 .51836 Mdot
.50227 .69719 Mdot
.64762 .40183 Mdot
.61941 .54385 Mdot
.55416 .34691 Mdot
.29411 .49469 Mdot
.3234 .5281 Mdot
.42654 .5124 Mdot
.53977 .47 Mdot
.29693 .31112 Mdot
.62843 .57059 Mdot
.45264 .29954 Mdot
.62403 .41946 Mdot
.57329 .32344 Mdot
.64608 .71435 Mdot
.5704 .56031 Mdot
.78574 .48411 Mdot
.78014 .47883 Mdot
.3715 .51095 Mdot
.30598 .3027 Mdot
.78472 .63914 Mdot
.57639 .53759 Mdot
.76932 .49604 Mdot
.65775 .42391 Mdot
.48566 .63883 Mdot
.52966 .79416 Mdot
.30795 .50195 Mdot
.57965 .57874 Mdot
.63268 .42259 Mdot
.27892 .30079 Mdot
.52159 .32801 Mdot
.67374 .74392 Mdot
.33493 .48406 Mdot
.39466 .52271 Mdot
.62047 .56962 Mdot
.6219 .55407 Mdot
.75877 .61162 Mdot
.58781 .77757 Mdot
.56908 .42514 Mdot
.5949 .63826 Mdot
.25172 .33146 Mdot
.52105 .7227 Mdot
.45651 .66225 Mdot
.75402 .48166 Mdot
.64418 .59151 Mdot
.39283 .47366 Mdot
.4939 .65217 Mdot
.7677 .62315 Mdot
.44197 .64809 Mdot
.3833 .35339 Mdot
.68729 .31219 Mdot
.34196 .49421 Mdot
.45817 .70226 Mdot
.48261 .65924 Mdot
.51394 .69481 Mdot
.77222 .50121 Mdot
.39655 .49568 Mdot
.31692 .49612 Mdot
.39039 .5317 Mdot
.28741 .48452 Mdot
.35503 .49102 Mdot
.63297 .71782 Mdot
.61069 .49613 Mdot
.39331 .23237 Mdot
.35038 .53911 Mdot
.64131 .5779 Mdot
.41427 .52451 Mdot
.51174 .30758 Mdot
.34417 .52583 Mdot
.3682 .35232 Mdot
.61942 .58298 Mdot
.40321 .58211 Mdot
.58813 .63881 Mdot
.33337 .48535 Mdot
.5409 .33534 Mdot
.31947 .29772 Mdot
.21104 .62304 Mdot
.71806 .42766 Mdot
.45944 .69626 Mdot
.60742 .42984 Mdot
.58981 .54684 Mdot
.64861 .40763 Mdot
.36134 .5393 Mdot
.75503 .48976 Mdot
.68792 .61083 Mdot
.48559 .4862 Mdot
.37879 .46831 Mdot
.44146 .46691 Mdot
.47431 .70852 Mdot
.65951 .39108 Mdot
.47196 .7443 Mdot
.35779 .47819 Mdot
.52125 .34052 Mdot
.53059 .33417 Mdot
.59574 .76407 Mdot
.31668 .25042 Mdot
.54616 .68193 Mdot
.6226 .56933 Mdot
.63191 .43917 Mdot
.53814 .31856 Mdot
.42177 .63771 Mdot
.57781 .57411 Mdot
.5837 .58906 Mdot
.60229 .57539 Mdot
.34828 .49945 Mdot
.78937 .48537 Mdot
.33927 .26003 Mdot
.79324 .49246 Mdot
.33203 .48875 Mdot
.63162 .43128 Mdot
.7927 .48388 Mdot
.51483 .35055 Mdot
.59694 .59532 Mdot
.6206 .40879 Mdot
.35756 .49868 Mdot
.48553 .67137 Mdot
.44729 .39708 Mdot
.30661 .35632 Mdot
.49017 .21933 Mdot
.48373 .21941 Mdot
.45385 .65648 Mdot
.39338 .18746 Mdot
.60372 .62212 Mdot
.28033 .607 Mdot
.46937 .31623 Mdot
.37108 .55001 Mdot
.565 .82104 Mdot
.63397 .3859 Mdot
.66839 .40233 Mdot
.36894 .50415 Mdot
.61487 .37979 Mdot
.41293 .50098 Mdot
.61593 .40467 Mdot
.71538 .41777 Mdot
.30816 .49004 Mdot
.66692 .40509 Mdot
.37036 .56315 Mdot
.32017 .49479 Mdot
.48381 .71403 Mdot
.65253 .37702 Mdot
.36675 .5382 Mdot
.76485 .29488 Mdot
.63141 .5567 Mdot
.77349 .5008 Mdot
.58109 .46244 Mdot
.62858 .59379 Mdot
.46996 .67686 Mdot
.31918 .46866 Mdot
.49374 .32589 Mdot
.48648 .68148 Mdot
.70179 .41483 Mdot
.50156 .34767 Mdot
.64718 .74796 Mdot
.46214 .7019 Mdot
.77409 .49488 Mdot
.49563 .3376 Mdot
.43917 .467 Mdot
.66906 .38691 Mdot
.26888 .3874 Mdot
.79009 .49577 Mdot
.40126 .48843 Mdot
.64764 .36268 Mdot
.6437 .57083 Mdot
.38939 .5139 Mdot
.63293 .37552 Mdot
.77227 .50201 Mdot
.34967 .507 Mdot
.36191 .52328 Mdot
.50238 .78639 Mdot
.7492 .66319 Mdot
.49944 .31874 Mdot
.469 .72171 Mdot
.36652 .49545 Mdot
.49684 .30927 Mdot
.77237 .38873 Mdot
.42726 .49644 Mdot
.50544 .66846 Mdot
.30844 .42092 Mdot
.62053 .4177 Mdot
.60471 .59816 Mdot
.66125 .43976 Mdot
.51781 .30614 Mdot
.55418 .86356 Mdot
.78486 .47836 Mdot
.37346 .56547 Mdot
.39323 .54476 Mdot
.58709 .36987 Mdot
.47886 .66003 Mdot
.56066 .41461 Mdot
.3726 .4783 Mdot
.37884 .42379 Mdot
.40362 .51861 Mdot
.65436 .30138 Mdot
.49113 .70509 Mdot
.40636 .48913 Mdot
.28402 .5457 Mdot
.38897 .46203 Mdot
.5399 .32864 Mdot
.42859 .28025 Mdot
.42582 .50611 Mdot
.37673 .13266 Mdot
.77545 .50418 Mdot
.66814 .41198 Mdot
.60987 .452 Mdot
.82926 .41542 Mdot
.47382 .7832 Mdot
.46808 .66428 Mdot
.40163 .4158 Mdot
.64827 .40454 Mdot
.35203 .78434 Mdot
.42853 .17212 Mdot
.32158 .49385 Mdot
.34983 .46509 Mdot
.64293 .38114 Mdot
.60934 .38139 Mdot
.75628 .48332 Mdot
.35016 .53664 Mdot
.45075 .50069 Mdot
.62149 .43651 Mdot
.34791 .48923 Mdot
.27128 .45847 Mdot
.61396 .54418 Mdot
.48854 .71724 Mdot
.59517 .58993 Mdot
.5821 .56998 Mdot
.3702 .65546 Mdot
.62702 .74763 Mdot
.61301 .55163 Mdot
.64313 .60965 Mdot
.35609 .35747 Mdot
.36257 .40117 Mdot
.53413 .3168 Mdot
.41061 .20531 Mdot
.64917 .4219 Mdot
.39543 .49711 Mdot
.45806 .65457 Mdot
.33667 .62888 Mdot
.70772 .48392 Mdot
.71579 .72172 Mdot
.36015 .47304 Mdot
.65979 .41377 Mdot
.77985 .50133 Mdot
.3068 .49613 Mdot
.55537 .29739 Mdot
.39024 .52276 Mdot
.67389 .39828 Mdot
.41001 .71815 Mdot
.26488 .45143 Mdot
.65122 .34685 Mdot
.52062 .68961 Mdot
.40726 .52499 Mdot
.45853 .68172 Mdot
.61836 .59341 Mdot
.50194 .30832 Mdot
.49785 .32318 Mdot
.37002 .52552 Mdot
.42503 .63674 Mdot
.5114 .57224 Mdot
.32244 .48964 Mdot
.32559 .51493 Mdot
.78474 .48998 Mdot
.32494 .51502 Mdot
.39081 .54573 Mdot
.38906 .53635 Mdot
.41201 .47288 Mdot
.62578 .6047 Mdot
.27069 .44039 Mdot
.42504 .47643 Mdot
.37194 .5703 Mdot
.62357 .54837 Mdot
.43743 .43854 Mdot
.58366 .5723 Mdot
.31312 .23977 Mdot
.58724 .56905 Mdot
.50173 .31914 Mdot
.63644 .36131 Mdot
.37984 .41994 Mdot
.51507 .66216 Mdot
.60095 .60702 Mdot
.51301 .33349 Mdot
.62927 .57964 Mdot
.62595 .43187 Mdot
.18533 .55264 Mdot
.44149 .64886 Mdot
.51164 .40258 Mdot
.53153 .59528 Mdot
.73528 .64258 Mdot
.62588 .39608 Mdot
.48776 .71033 Mdot
.23223 .50396 Mdot
.38016 .53643 Mdot
.50319 .34542 Mdot
.37321 .51347 Mdot
.61875 .60577 Mdot
.6572 .41802 Mdot
.49455 .2331 Mdot
.49594 .32355 Mdot
.35634 .80542 Mdot
.65137 .42838 Mdot
.31715 .48509 Mdot
.5809 .58669 Mdot
.20268 .65466 Mdot
.5862 .57306 Mdot
.38043 .38548 Mdot
.45657 .72584 Mdot
.44462 .78261 Mdot
.47533 .69337 Mdot
.78696 .60102 Mdot
.19035 .33193 Mdot
.48589 .19485 Mdot
.493 .67311 Mdot
.691 .35132 Mdot
.34134 .48213 Mdot
.42219 .51532 Mdot
.32064 .56553 Mdot
.48779 .7279 Mdot
.36232 .49281 Mdot
.78811 .49436 Mdot
.56603 .73868 Mdot
.58437 .31902 Mdot
.61277 .43491 Mdot
.40667 .48517 Mdot
.62019 .54775 Mdot
.63772 .54803 Mdot
.79395 .48692 Mdot
.58701 .55363 Mdot
.31729 .50727 Mdot
.47849 .69135 Mdot
.48549 .51882 Mdot
.51263 .34489 Mdot
.67248 .23399 Mdot
.53793 .36002 Mdot
.65385 .45192 Mdot
.40303 .4458 Mdot
.6436 .3992 Mdot
.68834 .80806 Mdot
.36638 .53485 Mdot
.48894 .66404 Mdot
.35799 .51721 Mdot
.4007 .53152 Mdot
.42164 .51701 Mdot
.60928 .42117 Mdot
.58031 .4187 Mdot
.34984 .49265 Mdot
.60632 .57443 Mdot
.44276 .21871 Mdot
.37874 .55716 Mdot
.70008 .37914 Mdot
.40548 .32788 Mdot
.7079 .66846 Mdot
.49579 .72929 Mdot
.65699 .39033 Mdot
.47512 .67455 Mdot
.52016 .66309 Mdot
.4699 .67667 Mdot
.34572 .25067 Mdot
.30568 .58014 Mdot
.84971 .5931 Mdot
.41546 .77672 Mdot
.31599 .63464 Mdot
.45139 .70675 Mdot
.78507 .42656 Mdot
.46886 .65259 Mdot
.46884 .66847 Mdot
.80668 .28837 Mdot
.47612 .64912 Mdot
.38384 .47471 Mdot
.31869 .52963 Mdot
.61372 .69407 Mdot
.34988 .36759 Mdot
.34328 .52841 Mdot
.36798 .49911 Mdot
.49702 .31159 Mdot
.34536 .58881 Mdot
.75975 .47408 Mdot
.64324 .75986 Mdot
.66046 .63025 Mdot
.37201 .51711 Mdot
.36411 .49791 Mdot
.30642 .47098 Mdot
.16222 .36128 Mdot
.3578 .62568 Mdot
.44531 .67122 Mdot
.44097 .46222 Mdot
.59931 .20065 Mdot
.32533 .47521 Mdot
.37519 .464 Mdot
.34368 .50273 Mdot
.64946 .40513 Mdot
.47324 .63759 Mdot
.43849 .45957 Mdot
.6956 .66467 Mdot
.33775 .47984 Mdot
.571 .59353 Mdot
.55743 .33896 Mdot
.39605 .47993 Mdot
.50985 .70146 Mdot
.34081 .51838 Mdot
.45692 .69491 Mdot
.47813 .71586 Mdot
.31069 .46221 Mdot
.32783 .25957 Mdot
.50992 .6793 Mdot
.33377 .49282 Mdot
.65284 .39368 Mdot
.4836 .1854 Mdot
.39926 .48583 Mdot
.51818 .3137 Mdot
.36966 .47939 Mdot
.53979 .33476 Mdot
.32365 .50118 Mdot
.7919 .49491 Mdot
.24023 .56751 Mdot
.64898 .416 Mdot
.47054 .35823 Mdot
.60214 .39309 Mdot
.50715 .78387 Mdot
.50214 .66436 Mdot
.75022 .48028 Mdot
.68139 .77152 Mdot
.78325 .49136 Mdot
.44928 .40024 Mdot
.72046 .45624 Mdot
.63695 .57008 Mdot
.49795 .71679 Mdot
.45001 .33046 Mdot
.69926 .36894 Mdot
.68743 .4348 Mdot
.5952 .39274 Mdot
.57328 .84588 Mdot
.63961 .79966 Mdot
.35355 .49951 Mdot
.22531 .42608 Mdot
.30721 .70248 Mdot
.41046 .47727 Mdot
.32773 .46176 Mdot
.67368 .39078 Mdot
.41538 .51311 Mdot
.5216 .46768 Mdot
.62864 .40623 Mdot
.51073 .32814 Mdot
.46304 .67532 Mdot
.53839 .33448 Mdot
.68322 .39381 Mdot
.59983 .49834 Mdot
.6227 .41445 Mdot
.42312 .48401 Mdot
.36054 .513 Mdot
.46422 .71052 Mdot
.42542 .68736 Mdot
.48521 .71677 Mdot
.51169 .35545 Mdot
.63411 .41416 Mdot
.33864 .61924 Mdot
.37667 .49128 Mdot
.48644 .69065 Mdot
.65521 .54198 Mdot
.3717 .4913 Mdot
.62708 .58977 Mdot
.34281 .47166 Mdot
.49596 .67244 Mdot
.32445 .51423 Mdot
.47724 .68999 Mdot
.64 .38686 Mdot
.33088 .47143 Mdot
.3709 .50401 Mdot
.23789 .68924 Mdot
.50138 .3308 Mdot
.502 .66502 Mdot
.53734 .51868 Mdot
.3148 .49487 Mdot
.57316 .3502 Mdot
.41109 .48511 Mdot
.36705 .407 Mdot
.38175 .56216 Mdot
.78531 .4954 Mdot
.43185 .47782 Mdot
.40064 .48656 Mdot
.24423 .47197 Mdot
.35783 .75122 Mdot
.4682 .74476 Mdot
.60794 .60648 Mdot
.50792 .70428 Mdot
.66444 .37869 Mdot
.63159 .37048 Mdot
.609 .39762 Mdot
.35792 .37523 Mdot
.30191 .4865 Mdot
.40782 .50394 Mdot
.59865 .60806 Mdot
.51136 .32139 Mdot
.49322 .68824 Mdot
.51654 .32153 Mdot
.6361 .76213 Mdot
.5127 .35502 Mdot
.79191 .48657 Mdot
.6578 .3082 Mdot
.28366 .58624 Mdot
.49533 .31403 Mdot
.48676 .71687 Mdot
.68311 .31578 Mdot
.37316 .54869 Mdot
.69592 .44417 Mdot
.5226 .33991 Mdot
.52825 .86228 Mdot
.40739 .47967 Mdot
.51301 .4283 Mdot
.5979 .55041 Mdot
.53021 .34691 Mdot
.60573 .58681 Mdot
.35535 .53001 Mdot
.71999 .62171 Mdot
.48243 .6555 Mdot
.64762 .58836 Mdot
.43247 .48425 Mdot
.53643 .33904 Mdot
.63638 .42605 Mdot
.54368 .59251 Mdot
.64092 .57712 Mdot
.20848 .53256 Mdot
.4673 .25687 Mdot
.63265 .41214 Mdot
.81189 .60798 Mdot
.59766 .5757 Mdot
.41959 .48546 Mdot
.33094 .43128 Mdot
.33783 .52981 Mdot
.64395 .36766 Mdot
.66179 .39417 Mdot
.58406 .7236 Mdot
.35752 .51418 Mdot
.40886 .48169 Mdot
.44563 .65308 Mdot
.63021 .4 Mdot
.47387 .70251 Mdot
.51341 .69942 Mdot
.64997 .38501 Mdot
.46917 .6928 Mdot
.50209 .34674 Mdot
.56033 .70816 Mdot
.59731 .57416 Mdot
.60901 .57707 Mdot
.6573 .42363 Mdot
.6545 .43656 Mdot
.64149 .39818 Mdot
.34258 .47197 Mdot
.49569 .69465 Mdot
.33572 .50649 Mdot
.4287 .49806 Mdot
.48152 .73865 Mdot
.48195 .64648 Mdot
.34274 .51301 Mdot
.58854 .35784 Mdot
.5522 .33317 Mdot
.66571 .40621 Mdot
.59729 .55775 Mdot
.35438 .78274 Mdot
.58607 .59797 Mdot
.40894 .48657 Mdot
.6485 .48988 Mdot
.4988 .67725 Mdot
.50746 .34666 Mdot
.55816 .35833 Mdot
.49853 .33816 Mdot
.60955 .52185 Mdot
.51648 .674 Mdot
.64672 .74679 Mdot
.41223 .4945 Mdot
.53927 .47199 Mdot
.44987 .31333 Mdot
.6554 .70781 Mdot
.60812 .55269 Mdot
.36894 .49461 Mdot
.7813 .49277 Mdot
.2562 .54953 Mdot
.39332 .52065 Mdot
.37634 .54142 Mdot
.61358 .26421 Mdot
.36997 .57063 Mdot
.48141 .73128 Mdot
.56198 .79474 Mdot
.33461 .54217 Mdot
.51029 .62464 Mdot
.86926 .46611 Mdot
.41544 .49577 Mdot
.35521 .48274 Mdot
.39035 .48852 Mdot
.35171 .52217 Mdot
.4681 .73305 Mdot
.46317 .38567 Mdot
.58277 .59002 Mdot
.56045 .47973 Mdot
.60133 .56652 Mdot
.66865 .39006 Mdot
.51129 .43293 Mdot
.49497 .71748 Mdot
.50292 .34385 Mdot
.20544 .48351 Mdot
.60748 .78052 Mdot
.62291 .39514 Mdot
.38762 .63566 Mdot
.51559 .34353 Mdot
.36647 .54946 Mdot
.498 .35425 Mdot
.6077 .38179 Mdot
.6115 .56303 Mdot
.31856 .52851 Mdot
.44985 .67159 Mdot
.50599 .68675 Mdot
.36619 .49092 Mdot
.55413 .19362 Mdot
.62109 .59537 Mdot
.63634 .51066 Mdot
.34617 .49769 Mdot
.37485 .54145 Mdot
.46616 .69805 Mdot
.66091 .40288 Mdot
.7482 .40683 Mdot
.50581 .33154 Mdot
.35676 .45045 Mdot
.34782 .52376 Mdot
.61875 .76516 Mdot
.59786 .5978 Mdot
.75978 .4864 Mdot
.35035 .503 Mdot
.62136 .75104 Mdot
.35064 .50488 Mdot
.35211 .44163 Mdot
.64798 .39659 Mdot
.39422 .5524 Mdot
.35358 .46711 Mdot
.46351 .5248 Mdot
.59899 .58203 Mdot
.48363 .66232 Mdot
.43987 .68963 Mdot
.76177 .49637 Mdot
.62752 .58828 Mdot
.34259 .51537 Mdot
.60972 .60248 Mdot
.4247 .51149 Mdot
.35241 .49295 Mdot
.60823 .55306 Mdot
.4734 .70211 Mdot
.67972 .58462 Mdot
.34394 .3967 Mdot
.35355 .51976 Mdot
.32393 .52949 Mdot
.36211 .37035 Mdot
.74807 .71906 Mdot
.36659 .47097 Mdot
.50083 .67478 Mdot
.37387 .49561 Mdot
.61348 .5892 Mdot
.52051 .35655 Mdot
.48985 .6706 Mdot
.65644 .43099 Mdot
.63855 .38497 Mdot
.58066 .63843 Mdot
.78988 .48259 Mdot
.31757 .52113 Mdot
.47374 .75209 Mdot
.46729 .6481 Mdot
.80663 .34639 Mdot
.67141 .40441 Mdot
.54242 .33318 Mdot
.36212 .52551 Mdot
.54224 .5738 Mdot
.59407 .60333 Mdot
.37353 .13343 Mdot
.64934 .73845 Mdot
.48875 .35104 Mdot
.70851 .73444 Mdot
.77563 .49152 Mdot
.37 .46535 Mdot
.50558 .30684 Mdot
.62466 .38575 Mdot
.40662 .53235 Mdot
.30044 .54057 Mdot
.559 .41868 Mdot
.58898 .41318 Mdot
.60813 .60102 Mdot
.61382 .40989 Mdot
.48274 .31756 Mdot
.79212 .48742 Mdot
.50208 .70458 Mdot
.40508 .49092 Mdot
.34859 .43079 Mdot
.66437 .41536 Mdot
.79201 .49581 Mdot
.34142 .49427 Mdot
.50735 .68939 Mdot
.6129 .38355 Mdot
.37434 .52082 Mdot
.29148 .61357 Mdot
.52368 .68133 Mdot
.6386 .42109 Mdot
.39461 .5427 Mdot
.33274 .41859 Mdot
.65646 .42817 Mdot
.66617 .41782 Mdot
.36243 .49329 Mdot
.49882 .34253 Mdot
.34743 .46278 Mdot
.58801 .56074 Mdot
.58089 .42021 Mdot
.61384 .5868 Mdot
.4818 .27465 Mdot
.40313 .44851 Mdot
.74532 .64034 Mdot
.46477 .71541 Mdot
.4892 .30251 Mdot
.24338 .6679 Mdot
.36799 .54281 Mdot
.37019 .20947 Mdot
.48402 .47508 Mdot
.68566 .22939 Mdot
.18737 .37782 Mdot
.52292 .33473 Mdot
.62763 .58308 Mdot
.35595 .4832 Mdot
.60721 .61756 Mdot
.50174 .31189 Mdot
.45987 .28974 Mdot
.39171 .54373 Mdot
.48866 .70657 Mdot
.33794 .48266 Mdot
.45877 .69514 Mdot
.37219 .48916 Mdot
.40492 .56026 Mdot
.47699 .30095 Mdot
.3752 .3856 Mdot
.36994 .54897 Mdot
.18321 .55076 Mdot
.54308 .54669 Mdot
.51624 .33979 Mdot
.33441 .50003 Mdot
.76832 .48266 Mdot
.62402 .53839 Mdot
.27705 .34032 Mdot
.64639 .4026 Mdot
.6131 .54949 Mdot
.46436 .68677 Mdot
.66601 .42993 Mdot
.77021 .50277 Mdot
.33567 .43366 Mdot
.53664 .32592 Mdot
.63616 .57248 Mdot
.3991 .48359 Mdot
.40462 .47801 Mdot
.66128 .34187 Mdot
.7645 .54563 Mdot
.46581 .63699 Mdot
.30909 .77038 Mdot
.47827 .73447 Mdot
.50294 .32368 Mdot
.646 .3967 Mdot
.3739 .47039 Mdot
.38592 .5182 Mdot
.64268 .36987 Mdot
.50001 .66324 Mdot
.59776 .43234 Mdot
.38047 .65072 Mdot
.6395 .44463 Mdot
.4237 .35133 Mdot
.49278 .66633 Mdot
.42475 .35645 Mdot
.48282 .31598 Mdot
.30012 .27427 Mdot
.34293 .32135 Mdot
.59876 .54933 Mdot
.42419 .34595 Mdot
.49602 .68125 Mdot
.35834 .50594 Mdot
.77221 .49348 Mdot
.77813 .47692 Mdot
.46117 .68443 Mdot
.64347 .38037 Mdot
.53117 .34337 Mdot
.35288 .4837 Mdot
.69457 .70959 Mdot
.60195 .66907 Mdot
.63408 .44017 Mdot
.27532 .51383 Mdot
.60442 .5819 Mdot
.35223 .47034 Mdot
.52381 .31716 Mdot
.63044 .56601 Mdot
.76801 .50774 Mdot
.56774 .7273 Mdot
.36674 .5285 Mdot
.58472 .77303 Mdot
.63145 .58459 Mdot
.81756 .60696 Mdot
.37781 .51001 Mdot
.59766 .57612 Mdot
.43876 .54011 Mdot
.69371 .64068 Mdot
.5096 .51935 Mdot
.43639 .17711 Mdot
.59051 .40519 Mdot
.63748 .38298 Mdot
.71748 .55914 Mdot
.47271 .30863 Mdot
.63084 .55355 Mdot
.7925 .48848 Mdot
.39377 .28567 Mdot
.60342 .58511 Mdot
.36549 .46109 Mdot
.41173 .48652 Mdot
.36351 .64937 Mdot
.5236 .49547 Mdot
.79408 .4952 Mdot
.53817 .719 Mdot
.32805 .52514 Mdot
.42037 .54158 Mdot
.38854 .51052 Mdot
.44593 .68863 Mdot
.63058 .59343 Mdot
.18506 .6275 Mdot
.61599 .59666 Mdot
.69831 .71462 Mdot
.65005 .42164 Mdot
.64102 .44264 Mdot
.39774 .47983 Mdot
.77089 .63223 Mdot
.27209 .33615 Mdot
.31821 .49141 Mdot
.56758 .33362 Mdot
.45929 .26123 Mdot
.42714 .54026 Mdot
.44621 .71534 Mdot
.35507 .43236 Mdot
.51836 .72188 Mdot
.62559 .55842 Mdot
.52563 .33186 Mdot
.55143 .33376 Mdot
.63459 .56786 Mdot
.40653 .50368 Mdot
.54463 .29961 Mdot
.39981 .52063 Mdot
.3529 .50203 Mdot
.66927 .75124 Mdot
.54343 .32767 Mdot
.63873 .39619 Mdot
.497 .32372 Mdot
.47011 .667 Mdot
.67174 .15558 Mdot
.5204 .32077 Mdot
.46209 .75468 Mdot
.48047 .38225 Mdot
.426 .34934 Mdot
.50621 .69204 Mdot
.48831 .33404 Mdot
.60902 .59918 Mdot
.67702 .21978 Mdot
.78745 .66328 Mdot
.58685 .60159 Mdot
.37942 .51428 Mdot
.488 .72056 Mdot
.44821 .66663 Mdot
.63239 .61355 Mdot
.4947 .70911 Mdot
.43503 .47212 Mdot
.35439 .51307 Mdot
.63111 .55387 Mdot
.60435 .69079 Mdot
.64034 .58206 Mdot
.55392 .73173 Mdot
.33732 .49728 Mdot
.48974 .66744 Mdot
.39836 .43803 Mdot
.44054 .65739 Mdot
.76059 .47761 Mdot
.40646 .53317 Mdot
.52167 .35225 Mdot
.52736 .48307 Mdot
.64137 .42107 Mdot
.64046 .49199 Mdot
.46784 .71172 Mdot
.67188 .56367 Mdot
.48415 .71431 Mdot
.48354 .72436 Mdot
.58146 .56401 Mdot
.47385 .65817 Mdot
.35423 .48243 Mdot
.63666 .34554 Mdot
.45376 .68324 Mdot
.61903 .57412 Mdot
.52392 .34765 Mdot
.47053 .69661 Mdot
.67859 .40716 Mdot
.36573 .51701 Mdot
.61847 .41136 Mdot
.48076 .34153 Mdot
.49985 .71487 Mdot
.49035 .33779 Mdot
.669 .40927 Mdot
.53005 .31681 Mdot
.50601 .23046 Mdot
.64336 .5911 Mdot
.72064 .71528 Mdot
.31865 .41061 Mdot
.45055 .67016 Mdot
.69284 .42894 Mdot
.3714 .4713 Mdot
.36407 .51975 Mdot
.48569 .31445 Mdot
.44997 .66285 Mdot
.50023 .19063 Mdot
.36936 .41055 Mdot
.56459 .70697 Mdot
.63434 .60186 Mdot
.36411 .79983 Mdot
.59363 .74232 Mdot
.70405 .27275 Mdot
.33857 .55576 Mdot
.77498 .49156 Mdot
.40874 .51287 Mdot
.21267 .63545 Mdot
.52959 .35485 Mdot
.77208 .45357 Mdot
.32152 .54481 Mdot
.63821 .40475 Mdot
.38144 .49739 Mdot
.24383 .40765 Mdot
.35797 .43309 Mdot
.49183 .31571 Mdot
.57711 .5399 Mdot
.5146 .66176 Mdot
.51307 .34439 Mdot
.63431 .38744 Mdot
.41034 .29833 Mdot
.39754 .54351 Mdot
.31985 .51782 Mdot
.62374 .44073 Mdot
.49021 .70797 Mdot
.66825 .38738 Mdot
.59754 .57378 Mdot
.52025 .32445 Mdot
.35633 .52576 Mdot
.41714 .54018 Mdot
.57196 .37906 Mdot
.62992 .59495 Mdot
.65351 .43992 Mdot
.59399 .58966 Mdot
.77464 .49244 Mdot
.34206 .54198 Mdot
.61505 .43248 Mdot
.41039 .48037 Mdot
.24332 .67932 Mdot
.67428 .75174 Mdot
.35821 .73873 Mdot
.63593 .39535 Mdot
.40114 .34416 Mdot
.6195 .58568 Mdot
.58777 .57671 Mdot
.43159 .78548 Mdot
.31485 .29899 Mdot
.68275 .30279 Mdot
.19823 .50471 Mdot
.59752 .57274 Mdot
.61358 .58302 Mdot
.62181 .38555 Mdot
.46579 .66231 Mdot
.52558 .66474 Mdot
.65224 .4445 Mdot
.35293 .38786 Mdot
.49307 .68826 Mdot
.38574 .19944 Mdot
.67396 .38819 Mdot
.33181 .55372 Mdot
.78178 .47136 Mdot
.52893 .33228 Mdot
.35351 .38841 Mdot
.23883 .43196 Mdot
.37845 .46949 Mdot
.53502 .80658 Mdot
.65751 .4018 Mdot
.52961 .39563 Mdot
.30526 .24998 Mdot
.39162 .54112 Mdot
.38979 .49873 Mdot
.403 .50584 Mdot
.54586 .33059 Mdot
.23368 .651 Mdot
.37876 .46891 Mdot
.41055 .38497 Mdot
.32848 .46453 Mdot
.29467 .35517 Mdot
.49797 .32206 Mdot
.52013 .62249 Mdot
.59423 .41324 Mdot
.67942 .68335 Mdot
.32628 .56716 Mdot
.59577 .58467 Mdot
.68888 .37718 Mdot
.61046 .56054 Mdot
.29793 .29929 Mdot
.34739 .31989 Mdot
.44989 .70652 Mdot
.35902 .47266 Mdot
.59845 .38696 Mdot
.47347 .71729 Mdot
.72847 .44535 Mdot
.78341 .25817 Mdot
.62235 .60121 Mdot
.73882 .75156 Mdot
.5875 .57783 Mdot
.76611 .47626 Mdot
.46405 .69493 Mdot
.37866 .60616 Mdot
.53765 .47177 Mdot
.47131 .6953 Mdot
.68747 .60464 Mdot
.45524 .72963 Mdot
.41252 .34196 Mdot
.52026 .67934 Mdot
.62059 .57781 Mdot
.63236 .53608 Mdot
.32112 .5534 Mdot
.37223 .474 Mdot
.57359 .47955 Mdot
.4602 .47329 Mdot
.36737 .47369 Mdot
.6288 .40614 Mdot
.77613 .66406 Mdot
.63597 .3581 Mdot
.45744 .66304 Mdot
.59854 .60133 Mdot
.38766 .49842 Mdot
.35092 .51535 Mdot
.42266 .49284 Mdot
.23941 .69454 Mdot
.39215 .19816 Mdot
.35205 .4949 Mdot
.36639 .45009 Mdot
.63749 .38876 Mdot
.51424 .28853 Mdot
.19693 .54488 Mdot
.38194 .29591 Mdot
.38454 .52962 Mdot
.49952 .33171 Mdot
.54467 .34567 Mdot
.37237 .55498 Mdot
.70344 .68391 Mdot
.68683 .35126 Mdot
.39885 .48363 Mdot
.32236 .32737 Mdot
.66921 .37178 Mdot
.7952 .48886 Mdot
.66375 .41632 Mdot
.51064 .70192 Mdot
.78667 .48522 Mdot
.60361 .39642 Mdot
.35753 .60321 Mdot
.76023 .49595 Mdot
.68176 .65153 Mdot
.51172 .35548 Mdot
.39011 .51399 Mdot
.4466 .72018 Mdot
.63997 .36862 Mdot
.63576 .56775 Mdot
.47992 .67956 Mdot
.63409 .54309 Mdot
.48224 .29086 Mdot
.45597 .39236 Mdot
.78679 .47983 Mdot
.59378 .57791 Mdot
.56732 .72886 Mdot
.49847 .32924 Mdot
.58347 .56142 Mdot
.77237 .62391 Mdot
.34164 .55284 Mdot
.23444 .36193 Mdot
.3264 .48258 Mdot
.603 .19789 Mdot
.58582 .58105 Mdot
.75369 .49093 Mdot
.4089 .50009 Mdot
.6522 .42841 Mdot
.45058 .51756 Mdot
.3886 .52413 Mdot
.64017 .43807 Mdot
.3549 .50085 Mdot
.52172 .31455 Mdot
.52063 .70882 Mdot
.48118 .5034 Mdot
.43332 .83305 Mdot
.53135 .31956 Mdot
.73872 .48125 Mdot
.36432 .47138 Mdot
.48876 .23735 Mdot
.47296 .69768 Mdot
.38525 .54142 Mdot
.45291 .7843 Mdot
.45888 .67138 Mdot
.47427 .67882 Mdot
.32776 .51196 Mdot
.5938 .55054 Mdot
.64698 .4273 Mdot
.49771 .3306 Mdot
.73359 .28273 Mdot
.37895 .52389 Mdot
.37249 .49987 Mdot
.51538 .34409 Mdot
.61364 .58518 Mdot
.34961 .51718 Mdot
.69022 .48083 Mdot
.74309 .27418 Mdot
.58116 .57273 Mdot
.38023 .55726 Mdot
.2087 .41952 Mdot
.47224 .62741 Mdot
.74628 .73243 Mdot
.48708 .37277 Mdot
.65465 .38998 Mdot
.41205 .55606 Mdot
.42317 .12185 Mdot
.52736 .33404 Mdot
.66367 .70656 Mdot
.34593 .49031 Mdot
.38175 .4885 Mdot
.50271 .68844 Mdot
.33792 .51074 Mdot
.49163 .65687 Mdot
.4629 .84725 Mdot
.34076 .8097 Mdot
.47763 .7113 Mdot
.4588 .6577 Mdot
.53153 .6535 Mdot
.20601 .56894 Mdot
.46373 .67891 Mdot
.40818 .53579 Mdot
.44636 .20795 Mdot
.30635 .46486 Mdot
.48825 .30705 Mdot
.52457 .36883 Mdot
.48202 .61362 Mdot
.81885 .56031 Mdot
.42834 .43404 Mdot
.37412 .5782 Mdot
.5129 .58185 Mdot
.59016 .56305 Mdot
.38693 .53304 Mdot
.79033 .4825 Mdot
.6086 .40351 Mdot
.33152 .44331 Mdot
.39374 .51599 Mdot
.45644 .69182 Mdot
.5431 .32198 Mdot
.60026 .54027 Mdot
.36804 .49968 Mdot
.58586 .4153 Mdot
.5082 .32907 Mdot
.45323 .67621 Mdot
.48248 .77152 Mdot
.52113 .30587 Mdot
.4375 .48431 Mdot
.37301 .48024 Mdot
.34225 .4954 Mdot
.35068 .57091 Mdot
.63151 .55856 Mdot
.67953 .38611 Mdot
.43146 .50457 Mdot
.636 .75865 Mdot
.51733 .41798 Mdot
.40959 .54358 Mdot
.49804 .68796 Mdot
.58575 .59619 Mdot
.75793 .48591 Mdot
.43198 .29621 Mdot
.37116 .52882 Mdot
.39115 .20065 Mdot
.36593 .63258 Mdot
.78342 .4837 Mdot
.46433 .72032 Mdot
.50352 .3437 Mdot
.32258 .51795 Mdot
.40261 .22181 Mdot
.40959 .48487 Mdot
.35091 .4037 Mdot
.65701 .39607 Mdot
.59231 .56344 Mdot
.72108 .24892 Mdot
.60893 .40649 Mdot
.4748 .6758 Mdot
.44421 .16766 Mdot
.48105 .64034 Mdot
.50688 .65565 Mdot
.32495 .26606 Mdot
.61914 .55422 Mdot
.40624 .12799 Mdot
.77154 .69076 Mdot
.38526 .46314 Mdot
.61367 .59176 Mdot
.46465 .70059 Mdot
.35123 .47157 Mdot
.46567 .64992 Mdot
.5045 .65617 Mdot
.40989 .52862 Mdot
.37784 .48283 Mdot
.40385 .38975 Mdot
.34165 .21992 Mdot
.49508 .33335 Mdot
.50208 .66904 Mdot
.32493 .64549 Mdot
.37375 .46724 Mdot
.4118 .49385 Mdot
.60091 .35658 Mdot
.49228 .31547 Mdot
.24603 .49146 Mdot
.35118 .50277 Mdot
.47231 .80351 Mdot
.32262 .52898 Mdot
.44072 .70778 Mdot
.58091 .57012 Mdot
.6965 .68885 Mdot
.65139 .36943 Mdot
.50709 .67377 Mdot
.53792 .33963 Mdot
.4411 .6721 Mdot
.42935 .76404 Mdot
.6178 .55591 Mdot
.49598 .67246 Mdot
.67569 .40808 Mdot
.61799 .56383 Mdot
.58374 .56677 Mdot
.44282 .21806 Mdot
.65304 .44146 Mdot
.50914 .35584 Mdot
.60647 .5664 Mdot
.28099 .60925 Mdot
.62428 .57604 Mdot
.34186 .64797 Mdot
.33325 .47173 Mdot
.4206 .38521 Mdot
.61081 .7334 Mdot
.30614 .55469 Mdot
.64342 .57362 Mdot
.49885 .3156 Mdot
.33582 .52034 Mdot
.49673 .70648 Mdot
.52252 .32221 Mdot
.55711 .60616 Mdot
.66248 .42719 Mdot
.45889 .70831 Mdot
.57963 .58006 Mdot
.49677 .66581 Mdot
.44671 .34732 Mdot
.61272 .46652 Mdot
.51577 .59233 Mdot
.53656 .45983 Mdot
.41643 .48347 Mdot
.44913 .60846 Mdot
.31436 .51766 Mdot
.39448 .51849 Mdot
.63955 .42171 Mdot
.36103 .37518 Mdot
.47268 .70222 Mdot
.73175 .25544 Mdot
.59222 .57279 Mdot
.51684 .79458 Mdot
.33752 .41903 Mdot
.37576 .5394 Mdot
.45456 .68131 Mdot
.49319 .64283 Mdot
.35926 .75086 Mdot
.64632 .37126 Mdot
.29032 .5321 Mdot
.39392 .44732 Mdot
.34328 .56141 Mdot
.58658 .58406 Mdot
.69299 .49355 Mdot
.65239 .38006 Mdot
.85253 .60411 Mdot
.66472 .40606 Mdot
.58733 .27199 Mdot
.47351 .65759 Mdot
.52694 .35436 Mdot
.40962 .49003 Mdot
.39879 .39764 Mdot
.454 .71985 Mdot
.53899 .37881 Mdot
.51465 .35095 Mdot
.70039 .53532 Mdot
.61605 .55145 Mdot
.37511 .55205 Mdot
.40639 .52893 Mdot
.33285 .50394 Mdot
.33165 .48054 Mdot
.6066 .60514 Mdot
.36853 .46184 Mdot
.64681 .58852 Mdot
.28746 .60486 Mdot
.4709 .80574 Mdot
.61736 .36895 Mdot
.29065 .32331 Mdot
.44941 .68168 Mdot
.28604 .6272 Mdot
.27809 .45431 Mdot
.68284 .74573 Mdot
.48903 .22782 Mdot
.31364 .51052 Mdot
.63462 .37847 Mdot
.23283 .41788 Mdot
.60206 .38349 Mdot
.47911 .90056 Mdot
.52222 .28429 Mdot
.42143 .1732 Mdot
.35358 .47244 Mdot
.58778 .36775 Mdot
.29637 .43634 Mdot
.37606 .55611 Mdot
.50685 .28139 Mdot
.50378 .77065 Mdot
.62628 .69412 Mdot
.54113 .32598 Mdot
.36845 .51892 Mdot
.51202 .65747 Mdot
.35295 .48087 Mdot
.41347 .50215 Mdot
.34887 .46969 Mdot
.57984 .56067 Mdot
.30526 .50837 Mdot
.35291 .4621 Mdot
.77418 .54349 Mdot
.37566 .35649 Mdot
.61743 .41559 Mdot
.39617 .76826 Mdot
.51187 .32177 Mdot
.46031 .70208 Mdot
.48219 .43716 Mdot
.5989 .55059 Mdot
.34808 .75395 Mdot
.34111 .47326 Mdot
.60117 .73044 Mdot
.57984 .58224 Mdot
.5252 .32582 Mdot
.76419 .4968 Mdot
.45637 .19153 Mdot
.61741 .3697 Mdot
.7585 .49391 Mdot
.6429 .4206 Mdot
.2462 .65841 Mdot
.45611 .68928 Mdot
.42457 .49484 Mdot
.60294 .5761 Mdot
.64391 .42905 Mdot
.3392 .37247 Mdot
.39202 .50806 Mdot
.63211 .3957 Mdot
.41953 .48603 Mdot
.50278 .40251 Mdot
.67955 .34334 Mdot
.6007 .39347 Mdot
.61194 .52504 Mdot
.61393 .56805 Mdot
.50387 .3485 Mdot
.46045 .70448 Mdot
.49918 .67966 Mdot
.62881 .56545 Mdot
.70825 .76478 Mdot
.38874 .52566 Mdot
.35506 .46968 Mdot
.63574 .75563 Mdot
.36127 .48107 Mdot
.41181 .3149 Mdot
.77538 .47265 Mdot
.45419 .69656 Mdot
.34789 .47439 Mdot
.35117 .51923 Mdot
.3642 .5273 Mdot
.44707 .35511 Mdot
.66516 .41308 Mdot
.32741 .52426 Mdot
.50071 .30603 Mdot
.76332 .60832 Mdot
.36233 .4667 Mdot
.40899 .55016 Mdot
.49559 .6768 Mdot
.38182 .8205 Mdot
.59223 .55427 Mdot
.62476 .40201 Mdot
.66845 .41696 Mdot
.50318 .37062 Mdot
.50127 .72643 Mdot
.76096 .47324 Mdot
.80716 .38496 Mdot
.77985 .49925 Mdot
.51128 .34049 Mdot
.61437 .25236 Mdot
.58942 .42374 Mdot
.61917 .39747 Mdot
.64922 .5697 Mdot
.33819 .47725 Mdot
.31526 .49967 Mdot
.66656 .70735 Mdot
.34515 .53385 Mdot
.52066 .35059 Mdot
.63421 .55482 Mdot
.49301 .68092 Mdot
.53057 .33223 Mdot
.59584 .58993 Mdot
.49228 .70677 Mdot
.3405 .5517 Mdot
.32941 .54626 Mdot
.47706 .68178 Mdot
.48055 .71772 Mdot
.38781 .47852 Mdot
.74678 .5407 Mdot
.51 .70876 Mdot
.49467 .66968 Mdot
.79874 .49519 Mdot
.6132 .37162 Mdot
.403 .43544 Mdot
.61441 .59274 Mdot
.34356 .49584 Mdot
.60483 .3784 Mdot
.48999 .31969 Mdot
.47931 .70064 Mdot
.3535 .51754 Mdot
.36268 .50627 Mdot
.49989 .33462 Mdot
.53119 .31065 Mdot
.5329 .33916 Mdot
.60302 .61856 Mdot
.32683 .4918 Mdot
.46503 .68 Mdot
.61442 .55285 Mdot
.54466 .34554 Mdot
.5114 .3598 Mdot
.80443 .5432 Mdot
.38407 .47165 Mdot
.50906 .52957 Mdot
.63411 .13894 Mdot
.4008 .29732 Mdot
.75817 .48205 Mdot
.632 .44438 Mdot
.41839 .37104 Mdot
.62009 .34213 Mdot
.62789 .59266 Mdot
.37908 .26755 Mdot
.48913 .30279 Mdot
.42604 .50555 Mdot
.32699 .53209 Mdot
.3415 .4523 Mdot
.51352 .32862 Mdot
.44458 .32168 Mdot
.45342 .65577 Mdot
.28351 .66843 Mdot
.51216 .32193 Mdot
.60118 .39278 Mdot
.60719 .42372 Mdot
.66454 .40525 Mdot
.34254 .54462 Mdot
.34958 .74695 Mdot
.30164 .6312 Mdot
.23177 .59585 Mdot
.61532 .55006 Mdot
.4744 .63698 Mdot
.49809 .2354 Mdot
.47389 .68189 Mdot
.60679 .40088 Mdot
.51235 .33196 Mdot
.5028 .67924 Mdot
.63661 .58143 Mdot
.61163 .58263 Mdot
.66024 .42819 Mdot
.6572 .42228 Mdot
.62631 .42072 Mdot
.5147 .687 Mdot
.47355 .65811 Mdot
.36643 .53175 Mdot
.4813 .69374 Mdot
.55467 .80692 Mdot
.50177 .36095 Mdot
.60154 .40999 Mdot
.6255 .58764 Mdot
.46146 .70014 Mdot
.38664 .51431 Mdot
.65103 .28374 Mdot
.6294 .63635 Mdot
.52441 .31318 Mdot
.72006 .37242 Mdot
.52799 .89331 Mdot
.41119 .52277 Mdot
.60351 .59978 Mdot
.71742 .66921 Mdot
.39922 .50425 Mdot
.65062 .40302 Mdot
.22017 .65052 Mdot
.78582 .49895 Mdot
.35458 .4627 Mdot
.36126 .53763 Mdot
.58593 .55487 Mdot
.47041 .37368 Mdot
.357 .53254 Mdot
.56444 .76739 Mdot
.61096 .53391 Mdot
.63528 .37543 Mdot
.75908 .28551 Mdot
.67118 .44334 Mdot
.31205 .39702 Mdot
.76759 .47733 Mdot
.40184 .53193 Mdot
.62859 .40995 Mdot
.51735 .30915 Mdot
.62955 .41847 Mdot
.45877 .71703 Mdot
.62019 .4169 Mdot
.37412 .49821 Mdot
.46567 .67588 Mdot
.63095 .58612 Mdot
.56531 .79296 Mdot
.77792 .55349 Mdot
.65276 .42845 Mdot
.79861 .50118 Mdot
.36453 .46417 Mdot
.25578 .50281 Mdot
.45178 .51463 Mdot
.36061 .46841 Mdot
.61051 .55943 Mdot
.45453 .67742 Mdot
.62534 .60619 Mdot
.4364 .51229 Mdot
.43264 .8051 Mdot
.58629 .57525 Mdot
.66413 .67043 Mdot
.51438 .343 Mdot
.3734 .3878 Mdot
.38507 .52104 Mdot
.60262 .57108 Mdot
.32777 .49191 Mdot
.48518 .64593 Mdot
.55364 .51239 Mdot
.76953 .61326 Mdot
.60379 .57678 Mdot
.5323 .17941 Mdot
.54028 .52459 Mdot
.37122 .43016 Mdot
.59978 .57076 Mdot
.294 .71907 Mdot
.76327 .48281 Mdot
.50597 .33324 Mdot
.54474 .33914 Mdot
.53225 .31823 Mdot
.34806 .53728 Mdot
.27498 .4938 Mdot
.512 .35863 Mdot
.60091 .53565 Mdot
.49347 .31207 Mdot
.41754 .39668 Mdot
.52168 .18148 Mdot
.53537 .33372 Mdot
.37626 .51502 Mdot
.40957 .55111 Mdot
.37119 .35831 Mdot
.61036 .38449 Mdot
.36486 .21279 Mdot
.41909 .63975 Mdot
.377 .47291 Mdot
.34545 .42826 Mdot
.45166 .70308 Mdot
.74775 .6596 Mdot
.34145 .42301 Mdot
.66398 .34395 Mdot
.47566 .65046 Mdot
.65074 .45366 Mdot
.45653 .69967 Mdot
.41997 .50494 Mdot
.35156 .49136 Mdot
.52501 .70509 Mdot
.65226 .49506 Mdot
.71428 .61652 Mdot
.6613 .23033 Mdot
.50062 .67265 Mdot
.59912 .58183 Mdot
.61835 .60316 Mdot
.60677 .55196 Mdot
.66148 .37608 Mdot
.50249 .71105 Mdot
.32117 .49973 Mdot
.64387 .38589 Mdot
.39002 .52826 Mdot
.61311 .56332 Mdot
.71632 .24438 Mdot
.49469 .67791 Mdot
.4008 .48616 Mdot
.78596 .66438 Mdot
.65647 .41412 Mdot
.49957 .32665 Mdot
.51712 .40079 Mdot
.68066 .40361 Mdot
.6424 .57778 Mdot
.51831 .65345 Mdot
.57165 .59002 Mdot
.47978 .44907 Mdot
.303 .47381 Mdot
.39894 .54771 Mdot
.75911 .30588 Mdot
.81176 .58801 Mdot
.34654 .54146 Mdot
.63331 .38756 Mdot
.61682 .37499 Mdot
.35754 .51811 Mdot
.50285 .70498 Mdot
.54065 .3524 Mdot
.50432 .30325 Mdot
.43118 .47877 Mdot
.54105 .47099 Mdot
.41413 .38888 Mdot
.34434 .51374 Mdot
.28998 .53987 Mdot
.66446 .42792 Mdot
.76621 .50023 Mdot
.63043 .74509 Mdot
.53617 .34686 Mdot
.34596 .49246 Mdot
.66791 .64424 Mdot
.48708 .65344 Mdot
.62152 .41673 Mdot
.63738 .56533 Mdot
.45334 .32808 Mdot
.67534 .3983 Mdot
.35676 .51706 Mdot
.34995 .51755 Mdot
.58468 .55793 Mdot
.44079 .70767 Mdot
.51437 .3313 Mdot
.64533 .38735 Mdot
.5337 .35211 Mdot
.47205 .66369 Mdot
.49089 .67909 Mdot
.30852 .46089 Mdot
.35434 .57032 Mdot
.66056 .42483 Mdot
.41646 .4706 Mdot
.60409 .40233 Mdot
.46806 .35882 Mdot
.59469 .6017 Mdot
.40236 .53668 Mdot
.50058 .6412 Mdot
.61634 .56066 Mdot
.38566 .48517 Mdot
.82033 .37445 Mdot
.38401 .53875 Mdot
.68083 .39231 Mdot
.43908 .8078 Mdot
.49555 .31539 Mdot
.44801 .74888 Mdot
.41186 .58664 Mdot
.36212 .48296 Mdot
.60662 .41736 Mdot
.4505 .51155 Mdot
.58456 .56961 Mdot
.4666 .65599 Mdot
.67893 .81108 Mdot
.62188 .57301 Mdot
.35047 .48185 Mdot
.52164 .32447 Mdot
.49571 .64245 Mdot
.78835 .49113 Mdot
.64295 .74253 Mdot
.34426 .43981 Mdot
.32576 .5464 Mdot
.34215 .47658 Mdot
.18965 .53119 Mdot
.62481 .40631 Mdot
.46302 .70037 Mdot
.58853 .58798 Mdot
.63179 .57133 Mdot
.6611 .40135 Mdot
.60468 .71055 Mdot
.64298 .48107 Mdot
.52405 .08779 Mdot
.6375 .43625 Mdot
.48779 .31704 Mdot
.52231 .44433 Mdot
.61029 .41404 Mdot
.63302 .40409 Mdot
.66892 .41825 Mdot
.63114 .72254 Mdot
.49593 .69876 Mdot
.36141 .50576 Mdot
.49589 .72909 Mdot
.39996 .5341 Mdot
.26071 .42667 Mdot
.62824 .56213 Mdot
.46979 .65517 Mdot
.79193 .33721 Mdot
.45917 .47025 Mdot
.39191 .5021 Mdot
.52628 .2245 Mdot
.44254 .48382 Mdot
.42816 .32925 Mdot
.43294 .46088 Mdot
.64994 .4235 Mdot
.29827 .45503 Mdot
.38782 .56261 Mdot
.55355 .80418 Mdot
.62304 .59018 Mdot
.76745 .47506 Mdot
.30974 .50266 Mdot
.35215 .44187 Mdot
.50155 .64728 Mdot
.50294 .67847 Mdot
.51332 .35857 Mdot
.54016 .42724 Mdot
.62915 .5879 Mdot
.59414 .46175 Mdot
.3725 .4755 Mdot
.58179 .52851 Mdot
.43211 .78024 Mdot
.38759 .48527 Mdot
.43009 .21335 Mdot
.35194 .7534 Mdot
.36071 .53423 Mdot
.26565 .67144 Mdot
.61611 .58357 Mdot
.46758 .79947 Mdot
.38935 .45765 Mdot
.64991 .40443 Mdot
.46617 .66012 Mdot
.45457 .70722 Mdot
.53275 .32537 Mdot
.64245 .78577 Mdot
.64428 .58158 Mdot
.47217 .65661 Mdot
.39992 .50879 Mdot
.6336 .561 Mdot
.78639 .48097 Mdot
.39886 .55623 Mdot
.36832 .26077 Mdot
.48411 .69108 Mdot
.37323 .45047 Mdot
.55629 .65611 Mdot
.49754 .4085 Mdot
.30464 .23589 Mdot
.60101 .55464 Mdot
.53492 .34374 Mdot
.41944 .44563 Mdot
.80292 .38055 Mdot
.33113 .45962 Mdot
.38118 .38077 Mdot
.46571 .61864 Mdot
.52117 .35645 Mdot
.40172 .49786 Mdot
.35199 .52914 Mdot
.52925 .46861 Mdot
.53663 .31552 Mdot
.39211 .53868 Mdot
.29567 .47673 Mdot
.49039 .70694 Mdot
.77322 .47314 Mdot
.48908 .68788 Mdot
.3794 .51363 Mdot
.27534 .48415 Mdot
.50172 .69806 Mdot
.65245 .25322 Mdot
.51011 .29733 Mdot
.59327 .55452 Mdot
.2811 .52266 Mdot
.33673 .47014 Mdot
.16484 .46117 Mdot
.76079 .47757 Mdot
.20635 .62227 Mdot
.65789 .44333 Mdot
.68173 .61533 Mdot
.57583 .39619 Mdot
.446 .17505 Mdot
.57797 .78144 Mdot
.32396 .45559 Mdot
.32668 .31186 Mdot
.24968 .64001 Mdot
.63821 .59549 Mdot
.2566 .56898 Mdot
.37211 .47379 Mdot
.41166 .50872 Mdot
.62445 .38182 Mdot
.59131 .72345 Mdot
.71055 .67283 Mdot
.55495 .47759 Mdot
.5183 .33448 Mdot
.47925 .66047 Mdot
.3704 .49107 Mdot
.70761 .44265 Mdot
.62197 .42335 Mdot
.54459 .57095 Mdot
.40515 .49219 Mdot
.70594 .70716 Mdot
.6513 .69227 Mdot
.63229 .55802 Mdot
.62589 .44038 Mdot
.67994 .4064 Mdot
.41761 .50001 Mdot
.64061 .57523 Mdot
.36561 .53296 Mdot
.55041 .53544 Mdot
.40178 .45955 Mdot
.52646 .32236 Mdot
.39138 .46897 Mdot
.51291 .4862 Mdot
.37381 .1813 Mdot
.39824 .42603 Mdot
.48999 .72258 Mdot
.66545 .38009 Mdot
.66431 .40972 Mdot
.49999 .67659 Mdot
.66298 .40844 Mdot
.29755 .68405 Mdot
.40304 .69876 Mdot
.52092 .33817 Mdot
.26841 .48526 Mdot
.52176 .31804 Mdot
.76516 .47535 Mdot
.38163 .47197 Mdot
.82109 .4055 Mdot
.64422 .43589 Mdot
.28681 .7371 Mdot
.62653 .57628 Mdot
.76385 .47645 Mdot
.33118 .46205 Mdot
.60815 .25142 Mdot
.60878 .39169 Mdot
.68534 .41682 Mdot
.3653 .52825 Mdot
.50038 .68479 Mdot
.35038 .52754 Mdot
.4193 .45614 Mdot
.75829 .49256 Mdot
.33846 .47782 Mdot
.59623 .59017 Mdot
.50809 .70377 Mdot
.47543 .1877 Mdot
.64119 .36804 Mdot
.40094 .47663 Mdot
.40052 .50758 Mdot
.47945 .6434 Mdot
.33767 .46087 Mdot
.63608 .5868 Mdot
.28826 .18085 Mdot
.51287 .34254 Mdot
.77399 .50335 Mdot
.6834 .3953 Mdot
.31612 .51427 Mdot
.34453 .5181 Mdot
.75091 .29441 Mdot
.74922 .58779 Mdot
.59516 .58626 Mdot
.43383 .47593 Mdot
.63753 .38957 Mdot
.52396 .32586 Mdot
.60917 .53704 Mdot
.34275 .49829 Mdot
.41133 .49773 Mdot
.52782 .32466 Mdot
.45884 .21053 Mdot
.68532 .34776 Mdot
.61152 .55 Mdot
.30058 .45072 Mdot
.66081 .29544 Mdot
.3887 .525 Mdot
.70081 .29505 Mdot
.49365 .67079 Mdot
.59968 .56555 Mdot
.21624 .57744 Mdot
.42522 .49385 Mdot
.63214 .59258 Mdot
.62771 .5882 Mdot
.39377 .46564 Mdot
.50092 .72552 Mdot
.51282 .67483 Mdot
.49353 .66303 Mdot
.44501 .81851 Mdot
.29627 .37545 Mdot
.62744 .42215 Mdot
.61494 .58429 Mdot
.6002 .38791 Mdot
.54535 .34908 Mdot
.51909 .42045 Mdot
.60547 .38405 Mdot
.45254 .7038 Mdot
.60616 .42268 Mdot
.35735 .52834 Mdot
.63092 .58795 Mdot
.61824 .39816 Mdot
.32404 .52685 Mdot
.31973 .57159 Mdot
.52079 .53887 Mdot
.53617 .35467 Mdot
.50934 .38216 Mdot
.35869 .49402 Mdot
.75818 .48788 Mdot
.39143 .47916 Mdot
.62985 .55269 Mdot
.50531 .46513 Mdot
.32444 .52521 Mdot
.65636 .42763 Mdot
.46022 .55456 Mdot
.62782 .3748 Mdot
.40467 .45004 Mdot
.37753 .51237 Mdot
.39535 .52392 Mdot
.35724 .53292 Mdot
.64931 .68254 Mdot
.63442 .60248 Mdot
.30139 .56395 Mdot
.592 .38746 Mdot
.47462 .69113 Mdot
.44606 .66335 Mdot
.6886 .31261 Mdot
.76484 .50226 Mdot
.61555 .59155 Mdot
.38547 .52556 Mdot
.68723 .41617 Mdot
.70809 .23818 Mdot
.68737 .27107 Mdot
.51054 .2458 Mdot
.62697 .38993 Mdot
.48742 .72247 Mdot
.61281 .40955 Mdot
.4132 .51263 Mdot
.42909 .52062 Mdot
.45467 .18066 Mdot
.65152 .60036 Mdot
.51242 .33087 Mdot
.397 .52611 Mdot
.30277 .40225 Mdot
.6376 .38874 Mdot
.66372 .43003 Mdot
.38749 .53588 Mdot
.50878 .67518 Mdot
.23319 .28219 Mdot
.63613 .56156 Mdot
.2518 .51825 Mdot
.42439 .66485 Mdot
.5135 .76896 Mdot
.63441 .57013 Mdot
.51646 .56522 Mdot
.66389 .39079 Mdot
.42543 .72239 Mdot
.47677 .68774 Mdot
.51006 .32737 Mdot
.4203 .53144 Mdot
.45424 .70516 Mdot
.646 .44772 Mdot
.4513 .6838 Mdot
.42244 .50467 Mdot
.63466 .60048 Mdot
.6618 .39589 Mdot
.60931 .52203 Mdot
.52516 .70606 Mdot
.50993 .31155 Mdot
.37189 .38901 Mdot
.25537 .55437 Mdot
.35045 .75351 Mdot
.32693 .52378 Mdot
.70106 .37782 Mdot
.32603 .49508 Mdot
.50373 .65147 Mdot
.38329 .52029 Mdot
.48047 .61222 Mdot
.64017 .44225 Mdot
.37428 .45083 Mdot
.35966 .46163 Mdot
.31747 .60409 Mdot
.3925 .49504 Mdot
.35317 .45808 Mdot
.35341 .53363 Mdot
.42627 .65246 Mdot
.31582 .4576 Mdot
.49868 .69279 Mdot
.65642 .71203 Mdot
.63373 .40631 Mdot
.53071 .35984 Mdot
.51655 .30503 Mdot
.39254 .38192 Mdot
.36699 .38731 Mdot
.60682 .71414 Mdot
.49123 .69392 Mdot
.60687 .59664 Mdot
.36682 .53323 Mdot
.21725 .55525 Mdot
.47276 .32184 Mdot
.66377 .39277 Mdot
.65976 .37173 Mdot
.37275 .57083 Mdot
.1877 .52451 Mdot
.35942 .44853 Mdot
.64882 .74449 Mdot
.42736 .4761 Mdot
.38663 .54102 Mdot
.67733 .39603 Mdot
.45365 .39776 Mdot
.32725 .52431 Mdot
.50125 .64687 Mdot
.50579 .32552 Mdot
.39458 .42092 Mdot
.56353 .31238 Mdot
.53431 .55895 Mdot
.37173 .61198 Mdot
.32358 .49025 Mdot
.65116 .38956 Mdot
.45984 .70903 Mdot
.62416 .76 Mdot
.61208 .55362 Mdot
.60808 .74077 Mdot
.3075 .61828 Mdot
.60686 .23084 Mdot
.50847 .32886 Mdot
.45089 .21436 Mdot
.37349 .49786 Mdot
.6684 .38186 Mdot
.41513 .52053 Mdot
.70155 .23415 Mdot
.48904 .33426 Mdot
.45743 .72507 Mdot
.59969 .58407 Mdot
.48558 .64704 Mdot
.36365 .74036 Mdot
.50283 .59375 Mdot
.72922 .48719 Mdot
.61495 .37172 Mdot
.24089 .46941 Mdot
.46099 .6809 Mdot
.34967 .50865 Mdot
.56006 .10119 Mdot
.49252 .66966 Mdot
.50057 .66492 Mdot
.48276 .37751 Mdot
.47857 .27573 Mdot
.44579 .52023 Mdot
.45097 .67494 Mdot
.59452 .40034 Mdot
.49516 .32702 Mdot
.33427 .52343 Mdot
.35119 .53117 Mdot
.50236 .68664 Mdot
.60638 .39608 Mdot
.23314 .47351 Mdot
.65418 .42305 Mdot
.48695 .71012 Mdot
.64965 .41575 Mdot
.67094 .36624 Mdot
.62277 .3976 Mdot
.33834 .46561 Mdot
.38139 .52439 Mdot
.56473 .29552 Mdot
.49075 .67925 Mdot
.33836 .51613 Mdot
.35064 .49564 Mdot
.46342 .68166 Mdot
.58952 .42146 Mdot
.21457 .53794 Mdot
.35962 .4733 Mdot
.36825 .51505 Mdot
.52807 .3546 Mdot
.61614 .45009 Mdot
.73527 .3938 Mdot
.33515 .52005 Mdot
.49716 .3053 Mdot
.51535 .68868 Mdot
.39042 .48002 Mdot
.42846 .39929 Mdot
.64618 .3616 Mdot
.39976 .47172 Mdot
.7896 .49053 Mdot
.31459 .50726 Mdot
.24675 .27306 Mdot
.39164 .4721 Mdot
.46547 .69993 Mdot
.45995 .66806 Mdot
.52238 .38616 Mdot
.47622 .67217 Mdot
.77307 .47632 Mdot
.61464 .56405 Mdot
.63024 .21051 Mdot
.7837 .48026 Mdot
.37896 .5431 Mdot
.77127 .69124 Mdot
.41506 .47269 Mdot
.31057 .50514 Mdot
.20699 .58319 Mdot
.78191 .48005 Mdot
.4561 .68242 Mdot
.65401 .4991 Mdot
.43296 .48231 Mdot
.63849 .56631 Mdot
.39583 .55417 Mdot
.38895 .46598 Mdot
.54179 .76841 Mdot
.40204 .79347 Mdot
.62211 .54765 Mdot
.41901 .44185 Mdot
.33465 .5194 Mdot
.80205 .57638 Mdot
.39118 .51009 Mdot
.53492 .33087 Mdot
.49729 .66278 Mdot
.6199 .42635 Mdot
.50769 .34304 Mdot
.36637 .47854 Mdot
.51361 .32588 Mdot
.62306 .41713 Mdot
.60684 .56071 Mdot
.4055 .48057 Mdot
.48991 .30554 Mdot
.5174 .33301 Mdot
.32846 .50009 Mdot
.46875 .65692 Mdot
.44557 .45242 Mdot
.38941 .48098 Mdot
.35291 .51141 Mdot
.49912 .67976 Mdot
.85691 .55036 Mdot
.41634 .51064 Mdot
.51082 .53328 Mdot
.46249 .72762 Mdot
.79431 .47997 Mdot
.61385 .40074 Mdot
.40673 .47368 Mdot
.62812 .55924 Mdot
.62271 .55969 Mdot
.62219 .44206 Mdot
.48731 .64528 Mdot
.61097 .38544 Mdot
.42716 .4431 Mdot
.34104 .56745 Mdot
.4334 .49981 Mdot
.66343 .81593 Mdot
.44121 .18924 Mdot
.49911 .71229 Mdot
.65547 .38146 Mdot
.55771 .47654 Mdot
.61177 .58768 Mdot
.60613 .42479 Mdot
.50937 .64765 Mdot
.48244 .71998 Mdot
.4496 .68462 Mdot
.52641 .35317 Mdot
.67199 .39595 Mdot
.44366 .71276 Mdot
.50656 .66864 Mdot
.36202 .52817 Mdot
.33459 .51808 Mdot
.50988 .62619 Mdot
.38784 .34635 Mdot
.51514 .31267 Mdot
.65443 .39596 Mdot
.14293 .47061 Mdot
.62855 .55186 Mdot
.32165 .60483 Mdot
.31862 .51927 Mdot
.77423 .23968 Mdot
.37013 .44772 Mdot
.39746 .50989 Mdot
.51168 .70003 Mdot
.48305 .32263 Mdot
.50836 .31651 Mdot
.46082 .67839 Mdot
.52628 .66651 Mdot
.53701 .33756 Mdot
.48071 .23057 Mdot
.5358 .17589 Mdot
.61323 .75799 Mdot
.46536 .69471 Mdot
.25712 .55026 Mdot
.64189 .57758 Mdot
.51707 .7224 Mdot
.61009 .54491 Mdot
.63442 .40369 Mdot
.67276 .40689 Mdot
.58696 .55455 Mdot
.36836 .52839 Mdot
.61935 .41057 Mdot
.32472 .44464 Mdot
.50118 .20655 Mdot
.2646 .3231 Mdot
.73533 .56973 Mdot
.32059 .52621 Mdot
.70094 .68509 Mdot
.72636 .64296 Mdot
.35971 .48804 Mdot
.42268 .41536 Mdot
.51217 .32901 Mdot
.50032 .73351 Mdot
.63738 .5839 Mdot
.29238 .24623 Mdot
.38741 .52523 Mdot
.47355 .70388 Mdot
.62066 .59135 Mdot
.55595 .38862 Mdot
.56192 .76395 Mdot
.39816 .5332 Mdot
.45986 .10337 Mdot
.48832 .73873 Mdot
.62078 .42733 Mdot
.70972 .74622 Mdot
.4919 .73115 Mdot
.50044 .37947 Mdot
.6679 .42976 Mdot
.68675 .25611 Mdot
.46154 .70343 Mdot
.63288 .449 Mdot
.47327 .66543 Mdot
.52723 .32052 Mdot
.52169 .68362 Mdot
.65925 .39206 Mdot
.39835 .49536 Mdot
.65974 .40494 Mdot
.51573 .31191 Mdot
.66262 .37564 Mdot
.63974 .58023 Mdot
.76143 .48 Mdot
.61145 .57598 Mdot
.51237 .41146 Mdot
.41632 .80017 Mdot
.59251 .56287 Mdot
.57109 .42086 Mdot
.34319 .53995 Mdot
.43879 .7003 Mdot
.63189 .43653 Mdot
.59216 .39165 Mdot
.52937 .4348 Mdot
.47047 .68927 Mdot
.65925 .39676 Mdot
.29717 .61637 Mdot
.8304 .63313 Mdot
.27629 .50113 Mdot
.30744 .35398 Mdot
.46386 .68518 Mdot
.64968 .44238 Mdot
.63578 .7543 Mdot
.44694 .68081 Mdot
.63743 .43566 Mdot
.59998 .57394 Mdot
.63278 .57115 Mdot
.3867 .53186 Mdot
.65403 .56928 Mdot
.61513 .42895 Mdot
.70019 .62859 Mdot
.49115 .65361 Mdot
.55428 .39075 Mdot
.53442 .32456 Mdot
.63009 .40077 Mdot
.3758 .56532 Mdot
.52209 .64773 Mdot
.61969 .36698 Mdot
.32634 .29153 Mdot
.1457 .49859 Mdot
.65893 .39933 Mdot
.49642 .66097 Mdot
.47961 .70265 Mdot
.44734 .49397 Mdot
.53783 .46764 Mdot
.61619 .38257 Mdot
.82718 .42908 Mdot
.36653 .37974 Mdot
.77508 .49289 Mdot
.81828 .58775 Mdot
.32614 .52426 Mdot
.32998 .49049 Mdot
.60951 .58911 Mdot
.38422 .50059 Mdot
.51024 .6736 Mdot
.31722 .48498 Mdot
.62684 .59707 Mdot
.66131 .38932 Mdot
.3976 .477 Mdot
.49662 .31793 Mdot
.64263 .56229 Mdot
.5924 .54841 Mdot
.63792 .41551 Mdot
.4502 .67803 Mdot
.69543 .44466 Mdot
.65817 .42135 Mdot
.32176 .49262 Mdot
.78022 .48356 Mdot
.42224 .49187 Mdot
.42596 .23863 Mdot
.45794 .65141 Mdot
.61315 .41396 Mdot
.46453 .71971 Mdot
.61557 .57561 Mdot
.59771 .4182 Mdot
.38472 .50921 Mdot
.64108 .43413 Mdot
.59251 .34055 Mdot
.45805 .23082 Mdot
.49098 .64549 Mdot
.5665 .34282 Mdot
.50101 .66257 Mdot
.77608 .49398 Mdot
.41635 .26445 Mdot
.5105 .3365 Mdot
.63609 .39273 Mdot
.42623 .19039 Mdot
.65426 .4314 Mdot
.39069 .49355 Mdot
.37862 .48547 Mdot
.62387 .38316 Mdot
.49402 .336 Mdot
.38429 .81953 Mdot
.50641 .56381 Mdot
.4547 .68681 Mdot
.41829 .68351 Mdot
.14904 .41457 Mdot
.61211 .53176 Mdot
.605 .59052 Mdot
.37744 .44504 Mdot
.37725 .53926 Mdot
.59523 .54425 Mdot
.59694 .60002 Mdot
.53426 .35385 Mdot
.66995 .41111 Mdot
.4435 .72493 Mdot
.62533 .53789 Mdot
.43898 .56736 Mdot
.31902 .39648 Mdot
.44498 .50102 Mdot
.29199 .51063 Mdot
.33415 .54193 Mdot
.49295 .40276 Mdot
.59901 .5984 Mdot
.3589 .49617 Mdot
.32081 .45354 Mdot
.59653 .57226 Mdot
.52593 .31993 Mdot
.52206 .7426 Mdot
.65016 .41017 Mdot
.8712 .46214 Mdot
.39975 .47353 Mdot
.39571 .48975 Mdot
.61587 .55017 Mdot
.82084 .56076 Mdot
.48526 .71624 Mdot
.45698 .65585 Mdot
.62387 .40705 Mdot
.53112 .43287 Mdot
.32925 .46875 Mdot
.35914 .49048 Mdot
.64169 .3964 Mdot
.75996 .48202 Mdot
.71907 .56455 Mdot
.36405 .50672 Mdot
.62373 .58703 Mdot
.6851 .37186 Mdot
.5993 .59946 Mdot
.41112 .52391 Mdot
.38825 .49275 Mdot
.33823 .46495 Mdot
.37633 .53985 Mdot
.60606 .54134 Mdot
.36367 .49543 Mdot
.37496 .56741 Mdot
.45801 .66077 Mdot
.33205 .47809 Mdot
.41169 .38201 Mdot
.37272 .5171 Mdot
.50134 .31466 Mdot
.71831 .42601 Mdot
.39515 .52534 Mdot
.33408 .47731 Mdot
.50836 .5582 Mdot
.40445 .5006 Mdot
.62415 .55015 Mdot
.47698 .69496 Mdot
.61431 .58427 Mdot
.58643 .58486 Mdot
.59645 .3898 Mdot
.53255 .35502 Mdot
.31891 .46627 Mdot
.52701 .31334 Mdot
.30087 .53054 Mdot
.4225 .50639 Mdot
.69915 .42677 Mdot
.6499 .74231 Mdot
.63697 .34149 Mdot
.38336 .51152 Mdot
.62803 .40618 Mdot
.61818 .42303 Mdot
.32577 .30507 Mdot
.35639 .432 Mdot
.60405 .53912 Mdot
.60255 .57165 Mdot
.40726 .3103 Mdot
.54503 .77313 Mdot
.50834 .31214 Mdot
.57762 .48188 Mdot
.33609 .54067 Mdot
.35699 .50548 Mdot
.40573 .55175 Mdot
.60462 .38425 Mdot
.76045 .49681 Mdot
.66593 .39506 Mdot
.79353 .47252 Mdot
.60821 .60421 Mdot
.31567 .4975 Mdot
.28034 .29926 Mdot
.50492 .68991 Mdot
.47756 .69445 Mdot
.5973 .53933 Mdot
.61953 .37702 Mdot
.45063 .49876 Mdot
.68322 .81227 Mdot
.50348 .73771 Mdot
.49589 .35308 Mdot
.35588 .48694 Mdot
.63367 .4133 Mdot
.5068 .68427 Mdot
.5093 .30044 Mdot
.3494 .4687 Mdot
.58753 .39284 Mdot
.38019 .52039 Mdot
.2465 .64054 Mdot
.45726 .66503 Mdot
.70542 .23261 Mdot
.48111 .64059 Mdot
.6442 .56418 Mdot
.59085 .57317 Mdot
.38635 .48674 Mdot
.68166 .7918 Mdot
.46343 .73182 Mdot
.6311 .5321 Mdot
.48588 .33118 Mdot
.77174 .50269 Mdot
.4994 .34946 Mdot
.60937 .41425 Mdot
.50638 .32771 Mdot
.66804 .41755 Mdot
.39787 .32094 Mdot
.48361 .74481 Mdot
.51031 .34283 Mdot
.79818 .55232 Mdot
.30374 .50182 Mdot
.54424 .345 Mdot
.36605 .56977 Mdot
.42403 .70956 Mdot
.64298 .39967 Mdot
.49286 .33318 Mdot
.34976 .51134 Mdot
.28132 .26742 Mdot
.58779 .57677 Mdot
.60773 .53854 Mdot
.30161 .49725 Mdot
.66919 .41999 Mdot
.52603 .67208 Mdot
.48471 .45006 Mdot
.78804 .47461 Mdot
.36046 .49273 Mdot
.31482 .50056 Mdot
.44907 .65534 Mdot
.47876 .63592 Mdot
.38592 .49109 Mdot
.27038 .59384 Mdot
.37136 .49575 Mdot
.63287 .56393 Mdot
.48238 .71862 Mdot
.47938 .69985 Mdot
.61941 .43427 Mdot
.4955 .65124 Mdot
.29018 .50816 Mdot
.65056 .61085 Mdot
.43603 .48945 Mdot
.61975 .57157 Mdot
.50723 .47754 Mdot
.65129 .36973 Mdot
.3315 .23144 Mdot
.45471 .6492 Mdot
.33775 .4771 Mdot
.49739 .65588 Mdot
.53065 .34115 Mdot
.48877 .6817 Mdot
.49026 .72527 Mdot
.37593 .47832 Mdot
.40142 .53201 Mdot
.77635 .47881 Mdot
.53931 .46398 Mdot
.47984 .65335 Mdot
.36644 .49103 Mdot
.40676 .46553 Mdot
.37099 .45915 Mdot
.53096 .50577 Mdot
.49659 .71724 Mdot
.36589 .65284 Mdot
.34811 .26539 Mdot
.47491 .65462 Mdot
.22193 .30866 Mdot
.78726 .4956 Mdot
.76732 .5027 Mdot
.62835 .53566 Mdot
.36298 .50789 Mdot
.63864 .37665 Mdot
.41494 .50809 Mdot
.31564 .44976 Mdot
.41256 .49921 Mdot
.48981 .31857 Mdot
.31667 .46628 Mdot
.76836 .49171 Mdot
.66077 .41813 Mdot
.35345 .47121 Mdot
.40171 .47942 Mdot
.76231 .50224 Mdot
.4606 .64459 Mdot
.47234 .71617 Mdot
.69423 .28557 Mdot
.52629 .33808 Mdot
.61115 .55744 Mdot
.37864 .52989 Mdot
.62639 .40591 Mdot
.6605 .40772 Mdot
.48978 .64953 Mdot
.65225 .40449 Mdot
.63443 .558 Mdot
.38833 .50713 Mdot
.60465 .53983 Mdot
.49321 .31477 Mdot
.49815 .66531 Mdot
.38171 .53047 Mdot
.36197 .52778 Mdot
.45973 .66837 Mdot
.34329 .54023 Mdot
.5286 .35434 Mdot
.66136 .42252 Mdot
.46722 .71056 Mdot
.61676 .56253 Mdot
.61104 .42691 Mdot
.35273 .52263 Mdot
.15418 .52271 Mdot
.38081 .49907 Mdot
.35839 .51584 Mdot
.49863 .17877 Mdot
.38775 .44611 Mdot
.63148 .43944 Mdot
.44443 .67232 Mdot
.3245 .54135 Mdot
.29477 .40003 Mdot
.76813 .33175 Mdot
.6028 .4207 Mdot
.35253 .47958 Mdot
.35269 .21592 Mdot
.35259 .47474 Mdot
.59401 .46331 Mdot
.69003 .33439 Mdot
.24207 .42184 Mdot
.2931 .51684 Mdot
.59886 .54776 Mdot
.77404 .4778 Mdot
.65104 .43899 Mdot
.30419 .72282 Mdot
.37074 .48237 Mdot
.28725 .71434 Mdot
.36951 .46209 Mdot
.63401 .57259 Mdot
.46255 .48648 Mdot
.65459 .39788 Mdot
.60621 .79797 Mdot
.32172 .49756 Mdot
.49491 .71761 Mdot
.6009 .4095 Mdot
.77904 .50152 Mdot
.35317 .51662 Mdot
.51589 .30652 Mdot
.63489 .51894 Mdot
.31268 .55681 Mdot
.62073 .56857 Mdot
.34888 .4952 Mdot
.40086 .4327 Mdot
.66374 .78864 Mdot
.45486 .66932 Mdot
.60248 .58686 Mdot
.75307 .64739 Mdot
.35203 .54431 Mdot
.46274 .70555 Mdot
.47579 .68817 Mdot
.52662 .31714 Mdot
.5947 .50563 Mdot
.57137 .65024 Mdot
.231 .36141 Mdot
.38986 .76568 Mdot
.63221 .44349 Mdot
.72372 .62001 Mdot
.33154 .52055 Mdot
.51528 .59699 Mdot
.61383 .5465 Mdot
.39775 .49173 Mdot
.41593 .77937 Mdot
.49441 .66514 Mdot
.36902 .50929 Mdot
.52375 .31906 Mdot
.61367 .50384 Mdot
.53738 .57432 Mdot
.17691 .43778 Mdot
.59727 .40971 Mdot
.41977 .53528 Mdot
.29815 .53055 Mdot
.79644 .48752 Mdot
.42117 .51406 Mdot
.64242 .43961 Mdot
.5097 .21732 Mdot
.49251 .33538 Mdot
.50541 .67584 Mdot
.78663 .4964 Mdot
.32472 .53626 Mdot
.38977 .45947 Mdot
.52906 .36048 Mdot
.33859 .49752 Mdot
.64868 .77985 Mdot
.7416 .47241 Mdot
.61836 .40458 Mdot
.45147 .69056 Mdot
.34501 .54568 Mdot
.76024 .49584 Mdot
.37682 .4809 Mdot
.3913 .60424 Mdot
.33557 .48443 Mdot
.55753 .67237 Mdot
.4672 .65995 Mdot
.61707 .56919 Mdot
.30054 .52015 Mdot
.40901 .51034 Mdot
.65528 .28952 Mdot
.31585 .44976 Mdot
.39382 .47254 Mdot
.50011 .64543 Mdot
.50324 .70196 Mdot
.49811 .69109 Mdot
.62014 .41797 Mdot
.6223 .75055 Mdot
.62267 .58183 Mdot
.32214 .47036 Mdot
.62506 .53801 Mdot
.40433 .59544 Mdot
.51603 .36144 Mdot
.22617 .32655 Mdot
.34154 .47151 Mdot
.4946 .69461 Mdot
.6513 .65506 Mdot
.51519 .68615 Mdot
.59036 .38453 Mdot
.62961 .5878 Mdot
.49203 .66689 Mdot
.40358 .51154 Mdot
.54576 .47871 Mdot
.18918 .44506 Mdot
.60908 .58305 Mdot
.41645 .54463 Mdot
.59562 .41063 Mdot
.65059 .36632 Mdot
.15634 .36907 Mdot
.59288 .58449 Mdot
.73004 .6373 Mdot
.36427 .48697 Mdot
.50406 .69057 Mdot
.59801 .55525 Mdot
.58727 .55955 Mdot
.64628 .39954 Mdot
.39958 .53114 Mdot
.39659 .5221 Mdot
.78913 .49183 Mdot
.60498 .56784 Mdot
.30612 .51555 Mdot
.43028 .48936 Mdot
.4575 .17979 Mdot
.51098 .7518 Mdot
.85936 .52017 Mdot
.42634 .44242 Mdot
.38924 .77069 Mdot
.5117 .43937 Mdot
.50451 .70758 Mdot
.39603 .52849 Mdot
.35013 .55078 Mdot
.62419 .43712 Mdot
.3839 .50365 Mdot
.64224 .37354 Mdot
.60732 .59355 Mdot
.21019 .34094 Mdot
.64666 .62304 Mdot
.4922 .23069 Mdot
.39004 .50015 Mdot
.53257 .76055 Mdot
.5153 .34859 Mdot
.58797 .61031 Mdot
.48487 .71253 Mdot
.37099 .55111 Mdot
.6806 .39553 Mdot
.63601 .39169 Mdot
.47949 .67822 Mdot
.69539 .6666 Mdot
.69032 .29365 Mdot
.405 .53407 Mdot
.61268 .39897 Mdot
.68594 .59649 Mdot
.26708 .59914 Mdot
.64727 .60413 Mdot
.49101 .33473 Mdot
.66153 .39057 Mdot
.58086 .56371 Mdot
.53233 .65848 Mdot
.48383 .66741 Mdot
.44404 .69379 Mdot
.61852 .31435 Mdot
.62198 .37818 Mdot
.50126 .33932 Mdot
.57976 .77112 Mdot
.5637 .78553 Mdot
.4887 .32323 Mdot
.66052 .38756 Mdot
.50601 .69364 Mdot
.47773 .70873 Mdot
.47641 .6958 Mdot
.5954 .80067 Mdot
.46306 .64944 Mdot
.38583 .6368 Mdot
.4107 .4701 Mdot
.25951 .49256 Mdot
.35327 .47601 Mdot
.61253 .54233 Mdot
.45722 .66633 Mdot
.52377 .43923 Mdot
.3648 .5428 Mdot
.18326 .43226 Mdot
.35748 .49194 Mdot
.64077 .61233 Mdot
.36497 .51107 Mdot
.27737 .57691 Mdot
.46457 .72928 Mdot
.38165 .50975 Mdot
.62231 .61219 Mdot
.51911 .33068 Mdot
.4311 .67698 Mdot
.39596 .52475 Mdot
.57609 .7281 Mdot
.35019 .44645 Mdot
.5098 .21169 Mdot
.4619 .382 Mdot
.48901 .34632 Mdot
.29998 .46986 Mdot
.63634 .4465 Mdot
.43921 .63964 Mdot
.27679 .46266 Mdot
.60866 .58146 Mdot
.27689 .72203 Mdot
.63206 .39393 Mdot
.46231 .48093 Mdot
.43229 .47365 Mdot
.53582 .34972 Mdot
.47785 .62736 Mdot
.61586 .54855 Mdot
.31851 .52153 Mdot
.38852 .46351 Mdot
.47072 .24616 Mdot
.27116 .47641 Mdot
.33944 .4583 Mdot
.54015 .3545 Mdot
.37392 .65922 Mdot
.36984 .52154 Mdot
.58874 .41824 Mdot
.44972 .70552 Mdot
.30299 .48317 Mdot
.36192 .64771 Mdot
.36737 .48983 Mdot
.48911 .67267 Mdot
.44535 .65963 Mdot
.61001 .68424 Mdot
.48437 .33332 Mdot
.33568 .48464 Mdot
.458 .33788 Mdot
.32569 .49184 Mdot
.62601 .58288 Mdot
.41753 .50882 Mdot
.63567 .39934 Mdot
.64434 .75238 Mdot
.63148 .42855 Mdot
.41444 .51264 Mdot
.47311 .69811 Mdot
.60222 .54905 Mdot
.57974 .30869 Mdot
.68955 .32571 Mdot
.38484 .64073 Mdot
.80286 .34992 Mdot
.50679 .34924 Mdot
.54426 .32903 Mdot
.64686 .58416 Mdot
.37998 .51277 Mdot
.48651 .38465 Mdot
.40471 .45749 Mdot
.36713 .51553 Mdot
.4127 .49656 Mdot
.65251 .55819 Mdot
.61546 .58829 Mdot
.65515 .41196 Mdot
.3857 .49277 Mdot
.36656 .49254 Mdot
.48038 .65745 Mdot
.51952 .33276 Mdot
.62718 .42812 Mdot
.52107 .34199 Mdot
.64249 .42429 Mdot
.24311 .27665 Mdot
.4386 .50663 Mdot
.52059 .32951 Mdot
.6472 .58612 Mdot
.49969 .68 Mdot
.75579 .48106 Mdot
.60857 .41586 Mdot
.65594 .39599 Mdot
.36091 .49152 Mdot
.49757 .67517 Mdot
.48463 .65105 Mdot
.52835 .34686 Mdot
.6017 .55918 Mdot
.41321 .51421 Mdot
.40819 .53014 Mdot
.2801 .34328 Mdot
.60099 .39465 Mdot
.29174 .62256 Mdot
.62106 .69265 Mdot
.38148 .51343 Mdot
.45311 .66872 Mdot
.3948 .4777 Mdot
.33797 .23938 Mdot
.45325 .70457 Mdot
.38763 .54022 Mdot
.53553 .78083 Mdot
.61188 .37607 Mdot
.57196 .6836 Mdot
.36112 .45164 Mdot
.74546 .28823 Mdot
.32663 .51071 Mdot
.44128 .16029 Mdot
.77139 .58622 Mdot
.31789 .48541 Mdot
.34543 .52697 Mdot
.22269 .38875 Mdot
.36207 .48149 Mdot
.77299 .49562 Mdot
.40922 .43089 Mdot
.48131 .72027 Mdot
.48643 .41699 Mdot
.58147 .39365 Mdot
.48528 .32458 Mdot
.6235 .40695 Mdot
.5756 .34718 Mdot
.52901 .32432 Mdot
.46381 .69337 Mdot
.35316 .53247 Mdot
.36159 .39057 Mdot
.6025 .37119 Mdot
.41554 .4555 Mdot
.62767 .58265 Mdot
.58097 .41279 Mdot
.65465 .37593 Mdot
.61402 .56603 Mdot
.35944 .4606 Mdot
.20991 .51181 Mdot
.70486 .34433 Mdot
.65343 .2151 Mdot
.61212 .55 Mdot
.63603 .57391 Mdot
.62713 .76383 Mdot
.48607 .321 Mdot
.41691 .24945 Mdot
.54187 .73207 Mdot
.64074 .5681 Mdot
.43191 .29199 Mdot
.66902 .42327 Mdot
.56882 .7341 Mdot
.50065 .73332 Mdot
.43343 .52105 Mdot
.40531 .51152 Mdot
.59899 .56286 Mdot
.36734 .39486 Mdot
.69235 .7506 Mdot
.61041 .5766 Mdot
.31673 .54856 Mdot
.60743 .50136 Mdot
.78274 .48724 Mdot
.79167 .48878 Mdot
.49183 .34674 Mdot
.66076 .26196 Mdot
.46929 .66661 Mdot
.53859 .3453 Mdot
.56038 .55079 Mdot
.33846 .48786 Mdot
.60441 .57472 Mdot
.75181 .48493 Mdot
.62726 .56393 Mdot
.51401 .31678 Mdot
.49713 .35376 Mdot
.45701 .66255 Mdot
.48453 .71604 Mdot
.38369 .7714 Mdot
.41619 .33007 Mdot
.35277 .47315 Mdot
.21763 .6108 Mdot
.4921 .65314 Mdot
.28636 .46115 Mdot
.49618 .30644 Mdot
.52289 .33277 Mdot
.26033 .64789 Mdot
.37208 .53425 Mdot
.55842 .37957 Mdot
.38306 .52683 Mdot
.39749 .27211 Mdot
.40663 .53541 Mdot
.64841 .40227 Mdot
.31731 .509 Mdot
.67699 .45946 Mdot
.33903 .53176 Mdot
.39949 .4744 Mdot
.66899 .40202 Mdot
.41267 .55352 Mdot
.63594 .39766 Mdot
.40744 .52659 Mdot
.55076 .33714 Mdot
.62611 .40625 Mdot
.31487 .36051 Mdot
.51156 .53406 Mdot
.76183 .49245 Mdot
.50793 .30879 Mdot
.53325 .32127 Mdot
.37526 .38423 Mdot
.48147 .71321 Mdot
.51887 .73471 Mdot
.3786 .51232 Mdot
.66289 .43088 Mdot
.61028 .5904 Mdot
.36818 .49322 Mdot
.38341 .55404 Mdot
.34995 .4538 Mdot
.49105 .65929 Mdot
.62102 .37691 Mdot
.51706 .3255 Mdot
.61378 .40496 Mdot
.6551 .27563 Mdot
.67546 .39781 Mdot
.32085 .45221 Mdot
.38247 .5578 Mdot
.29471 .56895 Mdot
.27832 .71304 Mdot
.5036 .79607 Mdot
.47987 .6712 Mdot
.7674 .48129 Mdot
.50376 .35661 Mdot
.42505 .63638 Mdot
.49272 .70452 Mdot
.65525 .38908 Mdot
.3805 .52053 Mdot
.34442 .56257 Mdot
.54312 .6072 Mdot
.45015 .62505 Mdot
.36547 .37502 Mdot
.66818 .38362 Mdot
.778 .49163 Mdot
.62094 .75509 Mdot
.42534 .64715 Mdot
.52117 .42859 Mdot
.40566 .48893 Mdot
.51333 .30536 Mdot
.50678 .68412 Mdot
.61559 .32697 Mdot
.60039 .56834 Mdot
.53875 .46688 Mdot
.38911 .50102 Mdot
.68555 .64451 Mdot
.47285 .69688 Mdot
.51864 .31523 Mdot
.5984 .56398 Mdot
.48419 .32248 Mdot
.79278 .49032 Mdot
.6696 .25667 Mdot
.33075 .49683 Mdot
.38497 .47006 Mdot
.65064 .5744 Mdot
.4704 .66844 Mdot
.52779 .38039 Mdot
.46198 .24305 Mdot
.61566 .39345 Mdot
.56308 .36907 Mdot
.51016 .69974 Mdot
.35149 .6051 Mdot
.61578 .40998 Mdot
.59751 .5389 Mdot
.49153 .40618 Mdot
.62157 .6004 Mdot
.3911 .52706 Mdot
.48832 .69671 Mdot
.59447 .58871 Mdot
.64175 .29011 Mdot
.35165 .20439 Mdot
.28639 .57326 Mdot
.32135 .48581 Mdot
.21967 .335 Mdot
.50515 .19629 Mdot
.415 .40261 Mdot
.63961 .58267 Mdot
.38571 .48065 Mdot
.42203 .51674 Mdot
.31977 .50009 Mdot
.60569 .59725 Mdot
.58311 .24681 Mdot
.64975 .39209 Mdot
.35263 .48777 Mdot
.5364 .32992 Mdot
.63948 .40658 Mdot
.6956 .42477 Mdot
.65513 .4343 Mdot
.47941 .72379 Mdot
.38066 .54035 Mdot
.6199 .73049 Mdot
.4071 .15669 Mdot
.61318 .58404 Mdot
.76227 .49265 Mdot
.37914 .46591 Mdot
.45481 .79904 Mdot
.49752 .69209 Mdot
.61698 .39095 Mdot
.39646 .48944 Mdot
.61971 .26304 Mdot
.79303 .46972 Mdot
.66556 .41555 Mdot
.47793 .71048 Mdot
.42966 .40975 Mdot
.38228 .50307 Mdot
.32774 .50766 Mdot
.46537 .67396 Mdot
.69169 .27607 Mdot
.64377 .7465 Mdot
.39922 .47867 Mdot
.61583 .56873 Mdot
.78327 .70175 Mdot
.35986 .45338 Mdot
.51793 .63728 Mdot
.77262 .5031 Mdot
.5886 .71644 Mdot
.29144 .62634 Mdot
.30942 .45478 Mdot
.24115 .32743 Mdot
.4511 .39808 Mdot
.21553 .3275 Mdot
.47246 .34165 Mdot
.71176 .48539 Mdot
.25675 .26034 Mdot
.62751 .61197 Mdot
.26139 .50265 Mdot
.23502 .41523 Mdot
.67948 .68986 Mdot
.47284 .4178 Mdot
.78599 .37306 Mdot
.67176 .30485 Mdot
.79747 .51507 Mdot
.64571 .43541 Mdot
.37851 .27399 Mdot
.41631 .50527 Mdot
.51565 .19132 Mdot
.27923 .59353 Mdot
.68287 .76924 Mdot
.23282 .30898 Mdot
.45676 .33209 Mdot
.19517 .4499 Mdot
.36394 .21392 Mdot
.23214 .48177 Mdot
.5469 .62382 Mdot
.82892 .46587 Mdot
.5794 .77517 Mdot
.48442 .25902 Mdot
.44254 .47131 Mdot
.69709 .45181 Mdot
.55971 .21367 Mdot
.3947 .69092 Mdot
.71345 .75854 Mdot
.61601 .42674 Mdot
.45498 .71722 Mdot
.26985 .34899 Mdot
.43468 .65283 Mdot
.67133 .5633 Mdot
.23916 .32904 Mdot
.43326 .17131 Mdot
.2798 .58018 Mdot
.76741 .30419 Mdot
.29614 .70216 Mdot
.41917 .82773 Mdot
.52724 .53306 Mdot
.44258 .69484 Mdot
.78421 .44571 Mdot
.56196 .78609 Mdot
.63141 .63891 Mdot
.42839 .62051 Mdot
.48748 .35266 Mdot
.34798 .35936 Mdot
.47256 .70315 Mdot
.27901 .61888 Mdot
.79495 .49947 Mdot
.55483 .63618 Mdot
.7041 .41805 Mdot
.31504 .2497 Mdot
.73684 .493 Mdot
.57981 .73809 Mdot
.71525 .61283 Mdot
.15131 .51575 Mdot
.44095 .31404 Mdot
.39401 .21432 Mdot
.55979 .61817 Mdot
.46142 .41307 Mdot
.68994 .72489 Mdot
.41843 .34791 Mdot
.55022 .79251 Mdot
.17882 .58511 Mdot
.56352 .19277 Mdot
.17034 .51028 Mdot
.44914 .64133 Mdot
.34274 .45796 Mdot
.33498 .25708 Mdot
.39081 .76333 Mdot
.49064 .34968 Mdot
.17208 .46345 Mdot
.50453 .30293 Mdot
.43879 .65287 Mdot
.69102 .67576 Mdot
.35411 .61204 Mdot
.57226 .41083 Mdot
.54012 .31276 Mdot
.32575 .45342 Mdot
.39894 .86182 Mdot
.20922 .35694 Mdot
.60306 .69244 Mdot
.4578 .17859 Mdot
.56759 .55098 Mdot
.53449 .38921 Mdot
.60799 .59553 Mdot
.31469 .22215 Mdot
.48569 .70567 Mdot
.35145 .17453 Mdot
.3486 .19935 Mdot
.77677 .65981 Mdot
.53411 .90761 Mdot
.73373 .54455 Mdot
.25281 .51003 Mdot
.3045 .404 Mdot
.31485 .38175 Mdot
.69986 .73107 Mdot
.78985 .63772 Mdot
.59132 .52171 Mdot
.65938 .23843 Mdot
.27243 .25655 Mdot
.41823 .28384 Mdot
.54318 .22834 Mdot
.68717 .69862 Mdot
.51732 .5146 Mdot
.52642 .65448 Mdot
.49759 .54099 Mdot
.53294 .62024 Mdot
.1751 .48296 Mdot
.42705 .7729 Mdot
.70425 .78881 Mdot
.54071 .37149 Mdot
.81448 .57896 Mdot
.4621 .19403 Mdot
.32053 .34853 Mdot
.41635 .61375 Mdot
.64427 .7133 Mdot
.32712 .45052 Mdot
.62782 .74496 Mdot
.4516 .45174 Mdot
.56788 .336 Mdot
.61725 .76253 Mdot
.68533 .55879 Mdot
.46152 .25186 Mdot
.25974 .33133 Mdot
.53254 .76992 Mdot
.46835 .71791 Mdot
.42427 .37087 Mdot
.43977 .29922 Mdot
.45984 .18309 Mdot
.75154 .64747 Mdot
.64176 .20831 Mdot
.76549 .64615 Mdot
.40132 .45647 Mdot
.27655 .47302 Mdot
.44799 .48432 Mdot
.4296 .33903 Mdot
.39032 .45601 Mdot
.68971 .6318 Mdot
.4832 .17953 Mdot
.42046 .78117 Mdot
.53299 .27807 Mdot
.24211 .67794 Mdot
.61429 .20144 Mdot
.33648 .2616 Mdot
.76533 .59553 Mdot
.2726 .44898 Mdot
.28348 .77197 Mdot
.64322 .41406 Mdot
.42652 .29257 Mdot
.57689 .57074 Mdot
.61617 .31824 Mdot
.21613 .45586 Mdot
.76399 .67581 Mdot
.48912 .17834 Mdot
.6508 .71997 Mdot
.69367 .35133 Mdot
.56781 .45306 Mdot
.5838 .43329 Mdot
.23217 .66113 Mdot
.36296 .56292 Mdot
.42953 .59099 Mdot
.54272 .33469 Mdot
.38863 .74743 Mdot
.36387 .25551 Mdot
.75723 .37492 Mdot
.28257 .5152 Mdot
.7491 .42983 Mdot
.77984 .4946 Mdot
.54345 .47284 Mdot
.17192 .35044 Mdot
.36341 .43557 Mdot
.74759 .5628 Mdot
.57902 .19494 Mdot
.48641 .39375 Mdot
.43079 .21018 Mdot
.66008 .67477 Mdot
.17572 .53554 Mdot
.38726 .17632 Mdot
.71404 .33742 Mdot
.19836 .35137 Mdot
.60641 .17108 Mdot
.18429 .57031 Mdot
.23779 .64982 Mdot
.6052 .61546 Mdot
.37381 .13414 Mdot
.63612 .38307 Mdot
.30713 .75198 Mdot
.39847 .77026 Mdot
.59844 .2653 Mdot
.52285 .66789 Mdot
.43276 .55264 Mdot
.7655 .51304 Mdot
.47961 .74088 Mdot
.31281 .45974 Mdot
.15307 .47454 Mdot
.18487 .62454 Mdot
.15859 .47659 Mdot
.6378 .22269 Mdot
.20302 .34424 Mdot
.25122 .39005 Mdot
.38969 .63446 Mdot
.33128 .2923 Mdot
.41438 .51672 Mdot
.3898 .3032 Mdot
.73762 .55309 Mdot
.69054 .34169 Mdot
.60078 .64665 Mdot
.51785 .69518 Mdot
.18895 .50733 Mdot
.1319 .40416 Mdot
.2947 .68296 Mdot
.34365 .6606 Mdot
.52446 .59078 Mdot
.42423 .32339 Mdot
.47203 .51073 Mdot
.73672 .40743 Mdot
.46286 .18852 Mdot
.23524 .41139 Mdot
.44669 .2747 Mdot
.77647 .39037 Mdot
.61502 .47245 Mdot
.80971 .57148 Mdot
.31619 .24097 Mdot
.28278 .36082 Mdot
.78138 .64035 Mdot
.25758 .46245 Mdot
.7191 .72976 Mdot
.73395 .32808 Mdot
.61752 .35171 Mdot
.4557 .28739 Mdot
.64246 .36691 Mdot
.41058 .28788 Mdot
.56954 .52237 Mdot
.28239 .32694 Mdot
.44343 .39582 Mdot
.41065 .28206 Mdot
.61787 .47322 Mdot
.16966 .4268 Mdot
.66092 .19943 Mdot
.21853 .67539 Mdot
.72745 .27381 Mdot
.44872 .44559 Mdot
.39662 .46426 Mdot
.52625 .17532 Mdot
.15813 .4307 Mdot
.41363 .16049 Mdot
.69378 .63916 Mdot
.63115 .28384 Mdot
.63082 .61391 Mdot
.23499 .68861 Mdot
.7463 .32394 Mdot
.4106 .18498 Mdot
.50742 .79319 Mdot
.62537 .53382 Mdot
.65841 .72538 Mdot
.26042 .7085 Mdot
.22289 .49473 Mdot
.29135 .64348 Mdot
.44322 .48674 Mdot
.2574 .57019 Mdot
.44736 .6993 Mdot
.71329 .62959 Mdot
.42247 .34106 Mdot
.63814 .4147 Mdot
.28912 .36923 Mdot
.42393 .59687 Mdot
.33227 .44878 Mdot
.66056 .35209 Mdot
.52824 .70135 Mdot
.31048 .74299 Mdot
.60441 .51685 Mdot
.2367 .27647 Mdot
.73982 .5804 Mdot
.46409 .51686 Mdot
.44259 .37148 Mdot
.61173 .33624 Mdot
.63422 .73546 Mdot
.6394 .59509 Mdot
.25951 .2817 Mdot
.4892 .52746 Mdot
.42922 .37064 Mdot
.25869 .576 Mdot
.44148 .24043 Mdot
.39191 .55287 Mdot
.63136 .6773 Mdot
.40608 .68183 Mdot
.54306 .4632 Mdot
.43495 .69381 Mdot
.52677 .71012 Mdot
.82669 .3458 Mdot
.65908 .48591 Mdot
.77393 .6188 Mdot
.26703 .27859 Mdot
.61916 .5986 Mdot
.51792 .67541 Mdot
.39498 .28748 Mdot
.47747 .23698 Mdot
.40815 .71756 Mdot
.68279 .42357 Mdot
.48803 .27925 Mdot
.74904 .35415 Mdot
.22158 .33552 Mdot
.19743 .40992 Mdot
.67013 .78788 Mdot
.49965 .65047 Mdot
.42417 .23697 Mdot
.47866 .24383 Mdot
.50273 .6593 Mdot
.46433 .62211 Mdot
.54899 .64719 Mdot
.19429 .33869 Mdot
.61957 .74217 Mdot
.7106 .26744 Mdot
.48897 .40287 Mdot
.60374 .25298 Mdot
.59688 .3286 Mdot
.47658 .2738 Mdot
.27248 .27617 Mdot
.27187 .61864 Mdot
.21398 .48261 Mdot
.43969 .4589 Mdot
.39744 .78943 Mdot
.24019 .69736 Mdot
.52889 .52007 Mdot
.3371 .60156 Mdot
.68312 .57162 Mdot
.3238 .4884 Mdot
.15079 .51356 Mdot
.50549 .20434 Mdot
.59772 .78378 Mdot
.61548 .51716 Mdot
.34532 .51662 Mdot
.42079 .47351 Mdot
.37039 .39654 Mdot
.60106 .70442 Mdot
.20201 .63893 Mdot
.49022 .25667 Mdot
.42582 .42072 Mdot
.26909 .58931 Mdot
.74831 .56518 Mdot
.31341 .25531 Mdot
.48541 .20103 Mdot
.5698 .50663 Mdot
.73723 .55849 Mdot
.53774 .42112 Mdot
.70145 .25327 Mdot
.72261 .44592 Mdot
.25396 .37996 Mdot
.51913 .75732 Mdot
.62374 .70581 Mdot
.62433 .333 Mdot
.38974 .46838 Mdot
.69468 .66698 Mdot
.35272 .22227 Mdot
.66754 .81299 Mdot
.70218 .71564 Mdot
.14596 .47209 Mdot
.33072 .58985 Mdot
.62314 .71263 Mdot
.20524 .48108 Mdot
.63655 .8406 Mdot
.72176 .42906 Mdot
.18639 .46278 Mdot
.55583 .43874 Mdot
.24681 .29535 Mdot
.5818 .59239 Mdot
.56463 .7632 Mdot
.24981 .68618 Mdot
.19959 .33235 Mdot
.36998 .2352 Mdot
.28099 .27664 Mdot
.26395 .44942 Mdot
.17909 .36571 Mdot
.48592 .78277 Mdot
.80361 .51305 Mdot
.60114 .42376 Mdot
.69492 .61747 Mdot
.22176 .56767 Mdot
.50039 .61053 Mdot
.4356 .28609 Mdot
.81478 .53982 Mdot
.41538 .66449 Mdot
.22297 .51527 Mdot
.34372 .32421 Mdot
.64567 .68382 Mdot
.44597 .37531 Mdot
.38876 .19116 Mdot
.81591 .50349 Mdot
.57687 .3094 Mdot
.75355 .61787 Mdot
.66891 .25412 Mdot
.59743 .7025 Mdot
.68722 .48859 Mdot
.39072 .21455 Mdot
.71697 .30316 Mdot
.45351 .32373 Mdot
.84166 .33888 Mdot
.57403 .22181 Mdot
.54689 .6328 Mdot
.18147 .50548 Mdot
.47397 .19295 Mdot
.47624 .77919 Mdot
.67412 .76867 Mdot
.38786 .78735 Mdot
.39501 .32267 Mdot
.41277 .50037 Mdot
.16481 .38311 Mdot
.35034 .35078 Mdot
.17199 .47503 Mdot
.57027 .17977 Mdot
.24633 .5606 Mdot
.35325 .44239 Mdot
.66091 .44208 Mdot
.52945 .56405 Mdot
.34172 .31857 Mdot
.20658 .441 Mdot
.3646 .78002 Mdot
.57091 .36555 Mdot
.73064 .46673 Mdot
.68259 .41632 Mdot
.36465 .41173 Mdot
.72708 .55664 Mdot
.6224 .69602 Mdot
.55764 .36495 Mdot
.64278 .48215 Mdot
.42839 .31076 Mdot
.28875 .62154 Mdot
.2232 .4917 Mdot
.74403 .69609 Mdot
.67571 .56584 Mdot
.62549 .43694 Mdot
.23133 .36831 Mdot
.58803 .22039 Mdot
.67852 .63806 Mdot
.19629 .57953 Mdot
.64979 .71046 Mdot
.36212 .284 Mdot
.32512 .28295 Mdot
.7139 .72034 Mdot
.83239 .44016 Mdot
.20677 .56857 Mdot
.39967 .79111 Mdot
.5629 .38035 Mdot
.35278 .58767 Mdot
.24273 .27813 Mdot
.46712 .27741 Mdot
.29781 .30675 Mdot
.51493 .53939 Mdot
.39127 .72646 Mdot
.23198 .55007 Mdot
.30008 .37483 Mdot
.53231 .43753 Mdot
.35061 .82166 Mdot
.52087 .70327 Mdot
.14968 .52188 Mdot
.61069 .5606 Mdot
.56136 .81773 Mdot
.64448 .46388 Mdot
.55583 .52073 Mdot
.50785 .42506 Mdot
.62544 .67732 Mdot
.55644 .67621 Mdot
.6481 .22927 Mdot
.74147 .71065 Mdot
.6754 .40144 Mdot
.46787 .36932 Mdot
.71752 .28334 Mdot
.23124 .35519 Mdot
.30977 .51778 Mdot
.6076 .22986 Mdot
.52614 .51755 Mdot
.68612 .34109 Mdot
.52913 .17807 Mdot
.67575 .6034 Mdot
.30131 .53237 Mdot
.42279 .32729 Mdot
.18788 .47089 Mdot
.3647 .19246 Mdot
.6498 .77029 Mdot
.45086 .45066 Mdot
.6137 .61856 Mdot
.24982 .41655 Mdot
.22308 .34728 Mdot
.55252 .39984 Mdot
.58455 .74496 Mdot
.44283 .3038 Mdot
.14742 .59546 Mdot
.18167 .60838 Mdot
.20521 .64214 Mdot
.48232 .38872 Mdot
.44887 .72581 Mdot
.4454 .79252 Mdot
.30401 .30246 Mdot
.66516 .63468 Mdot
.56869 .20965 Mdot
.42901 .29614 Mdot
.59397 .84321 Mdot
.41512 .62335 Mdot
.65466 .27346 Mdot
.23138 .55986 Mdot
.37304 .75269 Mdot
.59698 .60775 Mdot
.38002 .3268 Mdot
.4797 .50915 Mdot
.64533 .56624 Mdot
.64057 .68643 Mdot
.57186 .72395 Mdot
.29404 .30981 Mdot
.40005 .68032 Mdot
.43214 .43027 Mdot
.25691 .32719 Mdot
.46621 .74037 Mdot
.60968 .32631 Mdot
.58367 .32347 Mdot
.48073 .44061 Mdot
.62024 .39297 Mdot
.31599 .44665 Mdot
.55908 .47286 Mdot
.5474 .43802 Mdot
.3046 .76499 Mdot
.51282 .30329 Mdot
.50293 .7223 Mdot
.55996 .8049 Mdot
.50693 .66363 Mdot
.14946 .42932 Mdot
.73483 .41232 Mdot
.26638 .58139 Mdot
.70709 .32778 Mdot
.77728 .42402 Mdot
.43945 .84782 Mdot
.21558 .62894 Mdot
.50324 .56319 Mdot
.43835 .62486 Mdot
.47211 .64371 Mdot
.57499 .40239 Mdot
.77352 .51107 Mdot
.305 .64783 Mdot
.74857 .54926 Mdot
.34694 .28363 Mdot
.44063 .67228 Mdot
.62492 .25455 Mdot
.46837 .50526 Mdot
.204 .31622 Mdot
.63834 .43781 Mdot
.24136 .73128 Mdot
.41075 .55242 Mdot
.22552 .45761 Mdot
.51641 .17316 Mdot
.65208 .75226 Mdot
.6561 .34545 Mdot
.80523 .38139 Mdot
.31297 .49364 Mdot
.42363 .42653 Mdot
.47086 .70446 Mdot
.39587 .25623 Mdot
.50846 .3311 Mdot
.38877 .37027 Mdot
.63247 .54139 Mdot
.80008 .61569 Mdot
.7281 .56808 Mdot
.47637 .73486 Mdot
.47641 .54228 Mdot
.36685 .24451 Mdot
.55363 .74327 Mdot
.52572 .51519 Mdot
.22422 .38496 Mdot
.40451 .71275 Mdot
.44229 .66568 Mdot
.19658 .59198 Mdot
.47592 .25003 Mdot
.32873 .20634 Mdot
.41148 .57669 Mdot
.53095 .54515 Mdot
.54325 .75657 Mdot
.64342 .67493 Mdot
.29808 .63385 Mdot
.45869 .18908 Mdot
.42205 .36125 Mdot
.55963 .78035 Mdot
.40769 .28366 Mdot
.43583 .53919 Mdot
.72151 .47188 Mdot
.70743 .59642 Mdot
.56259 .84728 Mdot
.25975 .66803 Mdot
.67334 .73334 Mdot
.47253 .61238 Mdot
.74635 .56145 Mdot
.50995 .71866 Mdot
.57129 .27591 Mdot
.39777 .7042 Mdot
.72037 .40375 Mdot
.28308 .24031 Mdot
.46686 .18597 Mdot
.53832 .61418 Mdot
.69254 .39345 Mdot
.45197 .40412 Mdot
.46191 .51892 Mdot
.52533 .46686 Mdot
.31893 .47999 Mdot
.35646 .40719 Mdot
.64125 .7699 Mdot
.65331 .65318 Mdot
.44017 .54439 Mdot
.22633 .30604 Mdot
.34263 .19644 Mdot
.17656 .38628 Mdot
.56534 .37435 Mdot
.49281 .72376 Mdot
.17542 .54863 Mdot
.32591 .62827 Mdot
.38784 .18969 Mdot
.22231 .58957 Mdot
.81089 .32338 Mdot
.20922 .45876 Mdot
.68172 .55544 Mdot
.78247 .6521 Mdot
.57179 .66172 Mdot
.53589 .18382 Mdot
.80738 .51074 Mdot
.52089 .2774 Mdot
.54537 .18404 Mdot
.39382 .85734 Mdot
.24849 .66335 Mdot
.57595 .7335 Mdot
.24427 .5005 Mdot
.46902 .43916 Mdot
.75081 .53846 Mdot
.41987 .50098 Mdot
.60908 .37097 Mdot
.66757 .34385 Mdot
.43188 .30349 Mdot
.30799 .57442 Mdot
.75721 .54319 Mdot
.34135 .31499 Mdot
.3887 .26835 Mdot
.49563 .24844 Mdot
.2114 .4421 Mdot
.30875 .64447 Mdot
.29747 .52537 Mdot
.44128 .72133 Mdot
.49031 .34288 Mdot
.5735 .33573 Mdot
.39396 .53741 Mdot
.67354 .34942 Mdot
.54944 .71655 Mdot
.14941 .47936 Mdot
.55002 .27259 Mdot
.48568 .22467 Mdot
.51049 .73214 Mdot
.61157 .69563 Mdot
.3094 .27338 Mdot
.68304 .68483 Mdot
.77347 .54918 Mdot
.42485 .77294 Mdot
.21473 .34178 Mdot
.63766 .71907 Mdot
.44207 .26237 Mdot
.37487 .81121 Mdot
.62911 .54743 Mdot
.31414 .74176 Mdot
.24099 .40043 Mdot
.6667 .69109 Mdot
.4492 .64368 Mdot
.67942 .53471 Mdot
.71728 .48492 Mdot
.65892 .68835 Mdot
.58351 .19514 Mdot
.39937 .24474 Mdot
.23728 .57513 Mdot
.20081 .3923 Mdot
.596 .40149 Mdot
.44362 .27593 Mdot
.66064 .50945 Mdot
.74607 .52463 Mdot
.54128 .76799 Mdot
.23172 .2889 Mdot
.52375 .45583 Mdot
.33793 .35811 Mdot
.32707 .50012 Mdot
.36574 .65028 Mdot
.63922 .66386 Mdot
.62114 .47954 Mdot
.76161 .63043 Mdot
.45875 .71009 Mdot
.72626 .59864 Mdot
.81108 .48692 Mdot
.38316 .33664 Mdot
.44734 .59405 Mdot
.50397 .75775 Mdot
.47558 .31093 Mdot
.79601 .47711 Mdot
.31792 .53652 Mdot
.3391 .36839 Mdot
.5803 .43321 Mdot
.28187 .71034 Mdot
.24529 .66431 Mdot
.22811 .37151 Mdot
.5073 .21579 Mdot
.67471 .63738 Mdot
.21951 .58809 Mdot
.55704 .66525 Mdot
.39129 .62157 Mdot
.71114 .66759 Mdot
.35853 .45106 Mdot
.57356 .27464 Mdot
.51406 .69702 Mdot
.22301 .36462 Mdot
.3806 .60323 Mdot
.31605 .3584 Mdot
.54832 .49559 Mdot
.32833 .25624 Mdot
.50899 .50417 Mdot
.51905 .1751 Mdot
.57386 .65976 Mdot
.42147 .3428 Mdot
.60746 .52511 Mdot
.55731 .43602 Mdot
.71132 .71166 Mdot
.30735 .23612 Mdot
.75106 .69168 Mdot
.30754 .40443 Mdot
.6697 .72757 Mdot
.41155 .7936 Mdot
.55699 .1803 Mdot
.40835 .33666 Mdot
.52587 .46912 Mdot
.46963 .51331 Mdot
.55092 .60912 Mdot
.75566 .48242 Mdot
.59178 .28154 Mdot
.32112 .64031 Mdot
.53262 .24469 Mdot
.71518 .38501 Mdot
.30344 .5106 Mdot
.46008 .80144 Mdot
.20699 .37319 Mdot
.41811 .68258 Mdot
.54603 .522 Mdot
.65156 .32565 Mdot
.37944 .34442 Mdot
.88628 .50923 Mdot
.14964 .51215 Mdot
.32837 .49981 Mdot
.48925 .41063 Mdot
.38673 .36513 Mdot
.64635 .37411 Mdot
.30999 .65625 Mdot
.22677 .37021 Mdot
.63758 .57633 Mdot
.62665 .29036 Mdot
.6952 .59439 Mdot
.62362 .67264 Mdot
.28991 .37798 Mdot
.65337 .56327 Mdot
.1473 .44929 Mdot
.61288 .22581 Mdot
.65135 .66197 Mdot
.86795 .43246 Mdot
.70022 .63062 Mdot
.49145 .74812 Mdot
.36483 .23281 Mdot
.17032 .422 Mdot
.48364 .3918 Mdot
.61823 .31478 Mdot
.24932 .67373 Mdot
.41977 .34999 Mdot
.41031 .26484 Mdot
.75278 .61705 Mdot
.73179 .60476 Mdot
.77688 .52087 Mdot
.7777 .42192 Mdot
.33418 .78562 Mdot
.2636 .59968 Mdot
.19081 .42053 Mdot
.72882 .41984 Mdot
.60729 .83891 Mdot
.31407 .22277 Mdot
.3777 .3086 Mdot
.76629 .55681 Mdot
.38895 .22056 Mdot
.37342 .37949 Mdot
.44534 .77474 Mdot
.73099 .4037 Mdot
.41173 .73951 Mdot
.7652 .42103 Mdot
.72726 .66234 Mdot
.41039 .28548 Mdot
.38819 .76794 Mdot
.52404 .44965 Mdot
.21884 .41658 Mdot
.82767 .55878 Mdot
.44289 .36126 Mdot
.64039 .29788 Mdot
.31489 .39133 Mdot
.24215 .33662 Mdot
.37871 .21401 Mdot
.5154 .45917 Mdot
.39451 .8544 Mdot
.17773 .47819 Mdot
.69112 .68682 Mdot
.4077 .46805 Mdot
.28211 .23579 Mdot
.4963 .45843 Mdot
.21988 .59924 Mdot
.55745 .19889 Mdot
.56721 .30816 Mdot
.53618 .7537 Mdot
.34592 .45556 Mdot
.21229 .61552 Mdot
.32103 .59498 Mdot
.37086 .75425 Mdot
.65046 .34159 Mdot
.43978 .36992 Mdot
.82162 .57238 Mdot
.28689 .39639 Mdot
.45726 .52604 Mdot
.51085 .70035 Mdot
.15563 .45354 Mdot
.24639 .46211 Mdot
.31105 .44723 Mdot
.2596 .48423 Mdot
.74739 .69992 Mdot
.83443 .40424 Mdot
.4546 .50948 Mdot
.62903 .73531 Mdot
.43653 .28763 Mdot
.33009 .28671 Mdot
.22858 .64409 Mdot
.55593 .91043 Mdot
.5061 .17167 Mdot
.52604 .66889 Mdot
.31653 .7371 Mdot
.46572 .37987 Mdot
.18008 .38574 Mdot
.77401 .38577 Mdot
.60127 .33615 Mdot
.74567 .7219 Mdot
.41704 .38132 Mdot
.39838 .54366 Mdot
.62254 .21198 Mdot
.31511 .227 Mdot
.82725 .57677 Mdot
.24623 .27609 Mdot
.37925 .44259 Mdot
.43708 .50589 Mdot
.78723 .73065 Mdot
.23667 .31689 Mdot
.34124 .44267 Mdot
.72257 .73086 Mdot
.51096 .63998 Mdot
.40876 .52068 Mdot
.71661 .5092 Mdot
.46014 .28827 Mdot
.39737 .26875 Mdot
.19878 .33423 Mdot
.4513 .72521 Mdot
.67707 .34979 Mdot
.5803 .56464 Mdot
.51379 .42742 Mdot
.33688 .55935 Mdot
.59437 .59035 Mdot
.37163 .28216 Mdot
.49145 .44721 Mdot
.63167 .51855 Mdot
.46997 .28839 Mdot
.6776 .2187 Mdot
.30209 .57747 Mdot
.53526 .60509 Mdot
.28422 .43418 Mdot
.41581 .68795 Mdot
.34275 .31615 Mdot
.32471 .31015 Mdot
.55863 .18978 Mdot
.61383 .1562 Mdot
.62324 .45967 Mdot
.40998 .56952 Mdot
.44158 .73278 Mdot
.30848 .635 Mdot
.23929 .53108 Mdot
.64728 .51428 Mdot
.78262 .47935 Mdot
.37158 .44519 Mdot
.45669 .53004 Mdot
.63003 .53963 Mdot
.13698 .54815 Mdot
.42071 .49055 Mdot
.2625 .62594 Mdot
.36561 .20683 Mdot
.61353 .32739 Mdot
.28506 .56368 Mdot
.31095 .50584 Mdot
.48209 .781 Mdot
.49232 .4591 Mdot
.44389 .41413 Mdot
.58865 .32511 Mdot
.18867 .3824 Mdot
.37812 .60242 Mdot
.24743 .59096 Mdot
.35994 .49464 Mdot
.54439 .32146 Mdot
.5666 .73721 Mdot
.20953 .63417 Mdot
.44074 .58593 Mdot
.38348 .1869 Mdot
.56407 .30174 Mdot
.50028 .26025 Mdot
.25487 .5254 Mdot
.16907 .47748 Mdot
.69977 .71284 Mdot
.24731 .55004 Mdot
.61435 .78024 Mdot
.68533 .50493 Mdot
.34673 .32294 Mdot
.67122 .43015 Mdot
.43532 .54953 Mdot
.4938 .63111 Mdot
.15854 .37486 Mdot
.22042 .64598 Mdot
.56831 .58467 Mdot
.57159 .37444 Mdot
.3636 .62068 Mdot
.51144 .43111 Mdot
.85934 .3948 Mdot
.78216 .36737 Mdot
.14646 .45377 Mdot
.38736 .25326 Mdot
.44945 .74406 Mdot
.65202 .68196 Mdot
.27774 .48843 Mdot
.66449 .40864 Mdot
.18293 .38523 Mdot
.42931 .57294 Mdot
.7274 .65229 Mdot
.41393 .52112 Mdot
.57721 .78562 Mdot
.47252 .46485 Mdot
.6862 .38289 Mdot
.64029 .364 Mdot
.68065 .75723 Mdot
.3452 .23111 Mdot
.49277 .46403 Mdot
.81998 .35013 Mdot
.20046 .4486 Mdot
.26161 .27965 Mdot
.68349 .41965 Mdot
.59587 .81689 Mdot
.45585 .60965 Mdot
.47172 .47617 Mdot
.57745 .54179 Mdot
.27916 .42148 Mdot
.66575 .68688 Mdot
.34665 .27611 Mdot
.56525 .69574 Mdot
.54708 .61738 Mdot
.74483 .21352 Mdot
.38418 .29847 Mdot
.43189 .61163 Mdot
.69982 .65734 Mdot
.24943 .28182 Mdot
.51345 .28643 Mdot
.65674 .21787 Mdot
.67422 .46626 Mdot
.37284 .5662 Mdot
.40227 .67479 Mdot
.22829 .46207 Mdot
.69662 .5788 Mdot
.39712 .83692 Mdot
.57456 .21548 Mdot
.50231 .26401 Mdot
.63066 .48754 Mdot
.50452 .65907 Mdot
.52224 .66569 Mdot
.74141 .35726 Mdot
.73241 .25881 Mdot
.45406 .43605 Mdot
.22463 .34129 Mdot
.47771 .85112 Mdot
.42522 .24758 Mdot
.18287 .36653 Mdot
.58201 .63285 Mdot
.46475 .61961 Mdot
.34295 .31042 Mdot
.54275 .37484 Mdot
.61925 .37441 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo09oooooo0_l0002Xooooo`00
7?ooool00ol0003oooooooooo`2Oooooo`;o00001Oooool2o`000:7ooooo000Looooo`03o`000?oo
oooooooo0:Kooooo0_l0002Qooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo09Sooooo0_l0002_ooooo`007?ooool2o`0009Wooooo0_l0000Hooooo`;o
0000UOooool001cooooo00?o0000ooooooooool0T_ooool2o`0001kooooo0_l0002Eooooo`007?oo
ool00ol0003oooooooooo`2Booooo`;o0000]Oooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo08_o
oooo0_l0000_ooooo`;o0000Roooool001cooooo00?o0000ooooooooool0R_ooool3o`0002oooooo
0_l0002;ooooo`007?ooool00ol0003oooooooooo`26ooooo`;o00000_ooool2o`000;gooooo000L
ooooo`03o`000?oooooooooo08Kooooo0_l00031ooooo`007?ooool00ol0003oooooooooo`20oooo
o`;o0000aoooool001cooooo00?o0000ooooooooool0P?ooool2o`000<Oooooo000Looooo`03o`00
0?oooooooooo07Kooooo0ol0003@ooooo`007?ooool00ol0003oooooooooo`1fooooo`?o0000d?oo
ool001cooooo00?o0000ooooooooool0b_ooool2o`0007gooooo000Looooo`03o`000?oooooooooo
0<[ooooo0_l0001mooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooo
oooo083ooooo0_l00012ooooo`;o00004?ooool2o`00077ooooo000Looooo`03o`000?oooooooooo
083ooooo0_l00005ooooo`;o0000>oooool2o`00013ooooo0_l0001aooooo`007?ooool00ol0003o
ooooooooo`23ooooo`Ko00000oooool2o`000;_ooooo000Looooo`03o`000?oooooooooo08?ooooo
1?l00005ooooo`;o00004Oooool2o`000:Sooooo000Looooo`03o`000?oooooooooo07Oooooo0_l0
000;ooooo`;o00001oooool2o`00013ooooo0_l00009ooooo`;o0000WOooool001cooooo00?o0000
ooooooooool0Moooool2o`0000kooooo1?l00002ooooo`;o00004_ooool2o`0000Oooooo0_l0000E
ooooo`;o0000Q_ooool001cooooo00?o0000ooooooooool0K_ooool2o`0001Gooooo1_l00002oooo
o`;o00004_ooool2o`000003ooooool0003o000000?o00006?ooool2o`0008Kooooo000Looooo`03
o`000?oooooooooo06kooooo0_l0000:ooooo`;o00002Oooool2o`0000?ooooo0_l000000ooooooo
0000o`00000<ooooo`;o00001oooool8o`0009gooooo000Looooo`03o`000?oooooooooo05[ooooo
0_l0000Jooooo`;o00000_ooool2o`0000kooooo0_l00004ooooo`?o00000oooool2o`000003oooo
ool0003o000000;o000000?oooooo`000?l000001_ooool6o`0000Gooooo0_l00002ooooo`;o0000
T_ooool001cooooo00?o0000ooooooooool0F_ooool2o`0001[ooooo0_l00005ooooo`;o00003?oo
ool2o`0000?ooooo1?l00002ooooo`;o000000?oooooo`000?l000000oooool2o`0000Kooooo1_l0
00000ooooooo0000o`000002ooooo`;o00000_ooool2o`0000;ooooo0_l0002>ooooo`007?ooool0
0ol0003oooooooooo`1iooooo`;o000000Goooooo`000?l0003o0000ooooo`04o`0000Oooooo0_l0
0005ooooo`Co000000?oooooo`000?l000000ol00006ooooo`;o00001_ooool2o`000003ooooool0
003o000000[ooooo0_l0002>ooooo`007?ooool00ol0003oooooooooo`1iooooo`Go00000_ooool4
o`0000?ooooo0_l00003ooooo`;o00000oooool5o`000003ooooool0003o000000So000000?ooooo
o`000?l000003_ooool2o`0009Gooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ
8B44ooooo`Go00001_ooool00ol0003oooooooooo`1cooooo`;o00001Oooool3o`0000[ooooo0_l0
0002ooooo`?o00000_ooool5o`000003ooooool0003o000000Cooooo1Ol00003ooooo`;o00002_oo
ool5o`0009Cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1/ooooo`;o00001Oooool2o`0000Ko
oooo0_l0000>ooooo`;o00000oooool4o`0000;ooooo0_l00002ooooo`;o00001?ooool2o`0000;o
oooo0_l0000:ooooo`;o000000?oooooo`000?l000000oooool4o`0008gooooo00000ooooooo410@
ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003ooooo
ooooo`1/ooooo`Co00002_ooool4o`0001Cooooo0_l00006ooooo`;o00001?ooool2o`0000oooooo
0_l00005ooooo`Co00001?ooool2o`00017ooooo0_l0001dooooo`0000?oooooo`000?ooool00_oo
ool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0001^ooooo`;o00002_oo
ool4o`0000oooooo0_l0000;ooooo`;o00005?ooool3o`0000cooooo0ol00002ooooo`;o00003Ooo
ool2o`0007Cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oMgMg
ofIVI_ooool01Oooool00ol0003oooooooooo`1^ooooo`;o00002Oooool4o`0000Gooooo0_l00006
ooooo`;o000000?oooooo`000?l000002oooool2o`000004ooooool0003o0000ooooo`;o00003_oo
ool2o`0000gooooo0_l00003ooooo`;o0000Poooool00003ooooool@413ooooo00;ooooo00?o410@
ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06Oooooo0_l00005
ooooo`;o00000oooool2o`0000Cooooo0_l00007ooooo`;o00001_ooool2o`000003ooooool0003o
000000kooooo1Ol0000[ooooo`;o0000N_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2ooo
ool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0Ioooool2o`0000[ooooo
1?l0000?ooooo`Co00000oooool2o`0000;ooooo0_l0000<ooooo`;o000000?oooooo`000?l00000
0_l0000?ooooo`;o00003oooool2o`000003ooooool0003o000000;ooooo0_l0001jooooo`0000Ko
ooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0
003oooooooooo`1booooo`Oo00000_ooool3o`0000Sooooo1?l00005ooooo`Co00003oooool4o`00
00cooooo0_l000000ooooooo0000o`00000?ooooo`;o000000?oooooo`000?l000001Oooool2o`00
01cooooo0_l0001Iooooo`007?ooool00ol0003oooooooooo`1_ooooo`;o000000Coooooo`000?l0
003o00000_ooool2o`0000;ooooo0ol0000:ooooo`;o00000_ooool2o`000003ooooool0003o0000
013ooooo0ol0000>ooooo`;o00000oooool2o`0001Oooooo1?l0000Jooooo`;o0000FOooool001co
oooo00?o0000ooooooooool0Joooool2o`0000;ooooo0_l0000:ooooo`;o00003oooool2o`0000Oo
oooo0_l00002ooooo`Co00001?ooool3o`0001?ooooo0_l00002ooooo`;o00005Oooool2o`0000Co
oooo0ol0001^ooooo`007?ooool00ol0003oooooooooo`1Rooooo`;o00001oooool2o`0000;ooooo
0_l0000:ooooo`;o00000_ooool2o`0000;ooooo0_l00007ooooo`;o00000oooool2o`0000;ooooo
0_l00002ooooo`Co00002_ooool2o`0000kooooo0_l00002ooooo`;o00003_ooool4o`0000Wooooo
0ol0001^ooooo`007?ooool00ol0003oooooooooo`1Rooooo`?o00002_ooool2o`0000kooooo0_l0
0002ooooo`;o00003?ooool2o`0000Oooooo0_l0000;ooooo`;o00003_ooool2o`0000Gooooo0_l0
0003ooooo`;o00001_ooool4o`0007[ooooo000Looooo`03o`000?oooooooooo06?ooooo0ol0000[
ooooo`;o00001Oooool2o`000004ooooool0003o0000o`0000?ooooo1?l00003ooooo`;o00000ooo
ool2o`0000oooooo0_l000000ooooooo0000o`000002o`0000[ooooo1_l00006ooooo`;o0000K?oo
ool001cooooo00?o0000ooooooooool0I?ooool2o`0000;ooooo0_l00002ooooo`Co00000oooool2
o`0000Oooooo0_l0000Cooooo`;o00001Oooool2o`000003ooooool0003o000000;o00000_ooool4
o`0000?ooooo0_l00003ooooo`;o00004_ooool3o`0000_ooooo1_l00006ooooo`;o00001?ooool2
o`0006Kooooo000Looooo`03o`000?oooooooooo05Sooooo0_l00005ooooo`?o000000Coooooo`00
0?l0003o00000_ooool2o`0000;ooooo1?l00003ooooo`?o00001_ooool2o`0000Sooooo0_l00008
ooooo`;o00001Oooool2o`0000Cooooo0ol00002ooooo`?o00007oooool2o`0000Wooooo0ol00005
ooooo`;o00001Oooool5o`0006Kooooo000Looooo`03o`000?oooooooooo05Sooooo0_l00005oooo
o`Oo00001?ooool2o`0000Sooooo0_l0000<ooooo`;o00000_ooool3o`0000Oooooo0_l00005oooo
o`;o00000_ooool2o`000003ooooool0003o000002Cooooo0_l0000:ooooo`Co00000oooool2o`00
00Gooooo1_l0000Dooooo`;o0000Coooool001cooooo00?o0000ooooooooool0F?ooool2o`0000So
oooo1?l00004ooooo`;o00003?ooool2o`0000Sooooo0_l00003ooooo`;o00000oooool2o`0000Co
oooo0_l00007ooooo`;o0000=Oooool2o`0000kooooo0_l0000Dooooo`;o0000Coooool001cooooo
00?o0000ooooooooool0F?ooool2o`000003ooooool0003o000000Kooooo0ol0000=ooooo`;o0000
0oooool2o`0000Cooooo0_l0000;ooooo`?o00001?ooool2o`000004ooooool0003o0000ooooo`;o
00002?ooool4o`0000?ooooo0_l0000jooooo`;o0000H_ooool001cooooo00?o0000ooooooooool0
Foooool2o`0001Kooooo0_l00009ooooo`;o00001_ooool2o`0000?ooooo0_l00008ooooo`;o0000
00?oooooo`000?l000000oooool2o`0000?ooooo1?l00003ooooo`;o00003oooool2o`0002Wooooo
0ol0001Qooooo`007?ooool2o`00063ooooo0_l00002ooooo`;o00002?ooool2o`0001;ooooo0_l0
00000ooooooo0000o`000004o`0000Kooooo1?l00003ooooo`;o00001?ooool2o`0000Kooooo0_l0
000Cooooo`;o00001_ooool4o`00023ooooo0_l0001Qooooo`007?ooool00ol0003oooooooooo`1O
ooooo`;o000000Coooooo`000?l0003o00002?ooool2o`0000_ooooo0_l00005ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0000Kooooo1?l00003ooooo`;o00003?ooool2o`0001Wooooo1_l0
00000ooooooo0000o`000007ooooo`;o00000oooool2o`0000Wooooo0_l00008ooooo`;o0000GOoo
ool001cooooo00?o0000ooooooooool0EOooool2o`0000_ooooo0_l00003ooooo`Co00001oooool4
o`0000Cooooo0_l000000ooooooo0000o`00000Eooooo`;o00001Oooool2o`0002?ooooo0_l00005
ooooo`;o00001oooool2o`0000?ooooo0ol00003ooooo`;o00000oooool2o`0000Sooooo0_l0000?
ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0D?ooool2o`0000?ooooo0_l00005oooo
o`;o00002Oooool5o`0000Kooooo1?l00005ooooo`Co00004_ooool2o`000003ooooool0003o0000
00Cooooo0ol00002ooooo`;o00000oooool2o`0001?ooooo0_l0000Kooooo`;o00000oooool2o`00
00gooooo0_l0000?ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0D?ooool2o`0000[o
oooo0_l00009ooooo`;o000000?oooooo`000?l000002?ooool2o`0000Gooooo0_l00007ooooo`;o
00001_ooool4o`000003ooooool0003o000000Oooooo0_l00002ooooo`?o00000oooool2o`0001?o
oooo0_l00009ooooo`Co00002oooool2o`0001Gooooo0_l0001Mooooo`007?ooool00ol0003ooooo
ooooo`1Hooooo`;o00003?ooool2o`0000Gooooo0_l00008ooooo`;o00002Oooool4o`0000Kooooo
1?l00008ooooo`;o00001?ooool3o`0001Kooooo0_l00006ooooo`;o00000oooool4o`0000_ooooo
0_l0000>ooooo`;o0000I?ooool001cooooo00?o0000ooooooooool0F?ooool2o`000003ooooool0
003o000000Wooooo0_l00005ooooo`;o00000oooool2o`0000?ooooo0_l00002ooooo`Ko000000?o
ooooo`000?l000005?ooool2o`0001Kooooo0_l00005ooooo`;o00001_ooool2o`0002;ooooo0_l0
001Tooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00003Oooool2o`0000Cooooo0_l0000?
ooooo`;o00001oooool6o`0001Kooooo0_l0000Fooooo`?o00002Oooool2o`0001Cooooo0_l00008
ooooo`;o00001?ooool2o`0000Gooooo0_l0001Oooooo`007?ooool00ol0003oooooooooo`19oooo
o`Go00001oooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`00000:oooo
o`;o00002?ooool2o`0000Cooooo0_l0000=ooooo`?o00002?ooool4o`0000;ooooo0_l0000@oooo
o`;o00001Oooool3o`0000;ooooo0_l0000Dooooo`;o00002?ooool4o`0000;ooooo0_l00005oooo
o`;o00001?ooool2o`0005Wooooo000Looooo`03o`000?oooooooooo04Wooooo1Ol00003ooooo`Ko
000000?oooooo`000?l000001?ooool2o`0000gooooo0_l00008ooooo`;o00004oooool3o`0000Go
oooo0_l00002ooooo`Oo00001_ooool2o`0000;ooooo0_l0000;ooooo`?o00006?ooool2o`0000[o
oooo0_l0000?ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0B?ooool2o`000003oooo
ool0003o000000;o000000?oooooo`000?l000000ol0000Aooooo`;o00003Oooool2o`0000_ooooo
0_l00003ooooo`;o00002oooool2o`0000Gooooo0_l00004ooooo`;o00000_ooool2o`0000;ooooo
0_l0000Aooooo`;o00005_ooool2o`0001Cooooo0_l0001Mooooo`007?ooool00ol0003ooooooooo
o`18ooooo`;o00000oooool2o`000004ooooool0003o0000o`0001?ooooo0_l00005ooooo`;o0000
0oooool2o`000003ooooool0003o000000Gooooo0_l00003ooooo`Go000000Coooooo`000?l0003o
oooo0_l0000?ooooo`;o00001?ooool2o`0000?ooooo0_l000000ooooooo0000o`00000Aooooo`;o
00002oooool2o`0000Gooooo0_l00002ooooo`;o00002?ooool2o`0000Gooooo0_l00003ooooo`;o
00001oooool2o`0005Cooooo000Looooo`03o`000?oooooooooo04Sooooo0_l0000Mooooo`;o0000
1?ooool2o`0000?ooooo0_l00008ooooo`?o00000_ooool5o`0000Cooooo0_l00004ooooo`Co0000
00?oooooo`000?l000001?ooool2o`0000Kooooo0_l000001?oooooo0000o`000?ooool2o`0001ko
oooo0_l00005ooooo`;o00003?ooool2o`0000Gooooo0_l00007ooooo`;o00000oooool2o`0000go
oooo0_l00015ooooo`007?ooool00ol0003oooooooooo`18ooooo`Co00006_ooool5o`0001;ooooo
0_l00003ooooo`;o00001Oooool3o`0000Cooooo1?l000000ooooooo0000o`000002ooooo`;o0000
1?ooool2o`0000;ooooo1?l0000Qooooo`;o00000oooool2o`0000;ooooo0_l0000Kooooo`;o0000
4_ooool2o`0004Gooooo000Looooo`03o`000?oooooooooo04[ooooo1?l0000Hooooo`Go00007?oo
ool4o`0000Gooooo1?l00005ooooo`;o00001?ooool2o`0000Cooooo0_l0000=ooooo`;o00004_oo
ool2o`0000?ooooo0ol000000ooooooo0000o`000002o`0000Oooooo0_l00002ooooo`;o00003_oo
ool2o`0000?ooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00002_ooool2
o`0000[ooooo0_l00003ooooo`;o00003Oooool3o`0000?ooooo0_l00002ooooo`;o00000oooool4
o`0001Cooooo0_l000000ooooooo0000o`000003o`0000[ooooo0_l000000ooooooo0000o`00000F
ooooo`Co00000oooool2o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o00003_ooool2
o`0000?ooooo0_l0001Booooo`007?ooool2o`0005Sooooo0ol00003ooooo`;o00001?ooool3o`00
00Cooooo0_l0000<ooooo`?o00000oooool2o`0000;ooooo0_l00004ooooo`Go00000_ooool2o`00
00Kooooo0_l00007ooooo`Ko00001oooool2o`0000;ooooo0_l0000Iooooo`;o00000oooool2o`00
00Kooooo0_l00006ooooo`;o0000I_ooool001cooooo00?o0000ooooooooool0Eoooool2o`0000Co
oooo1Ol000000ooooooo0000o`000005ooooo`;o00003oooool2o`0000cooooo1Ol000000ooooooo
0000o`000006ooooo`;o000000Goooooo`000?l0003o0000ooooo`08o`0000Oooooo0_l00004oooo
o`;o00007?ooool2o`0000Oooooo0_l00005ooooo`;o00000_ooool2o`0000kooooo0_l0001Boooo
o`007?ooool00ol0003oooooooooo`16ooooo`;o00005Oooool5o`0000Cooooo0_l0000Booooo`?o
00003?ooool2o`000003ooooool0003o000000cooooo3_l0000;ooooo`;o00007Oooool2o`0000;o
oooo0_l00002ooooo`;o00002Oooool2o`0000cooooo1?l0001Booooo`007?ooool00ol0003ooooo
ooooo`14ooooo`Ko00004_ooool3o`0000Oooooo0_l00004ooooo`;o00002Oooool2o`000003oooo
ool0003o000000Gooooo0_l00004ooooo`Co00002oooool3o`0000;ooooo4?l00002ooooo`;o0000
1Oooool2o`0000;ooooo0ol0000Gooooo`;o00000_ooool2o`0001_ooooo1?l0001Booooo`007?oo
ool00ol0003oooooooooo`14ooooo`;o00000_ooool2o`0000cooooo0_l00004ooooo`?o00001ooo
ool2o`0000Cooooo0_l00009ooooo`;o00002?ooool2o`0000Cooooo1?l00003ooooo`;o00001_oo
ool3o`0000?ooooo3ol000001?oooooo0000o`000?l00004ooooo`?o00000_ooool3o`0001Oooooo
0_l00002ooooo`;o00000oooool3o`0001Oooooo0_l0001Booooo`007?ooool00ol0003ooooooooo
o`0oooooo`;o00001Oooool2o`000003ooooool0003o000000_ooooo0_l00005ooooo`;o00001ooo
ool2o`0000?ooooo0ol0000Dooooo`;o00001oooool2o`000003ooooool0003o000000Gooooo0_l0
0002oooooaGo00001Oooool2o`00013ooooo0_l0000Cooooo`Co00006oooool2o`0004kooooo000L
ooooo`03o`000?oooooooooo03oooooo0_l00005ooooo`;o000000?oooooo`000?l000008?ooool4
o`00013ooooo0_l000000ooooooo0000o`000002o`0000Gooooo0_l00008ooooo`;o00000_oooolD
o`0000gooooo0_l00008ooooo`?o00004oooool2o`0001gooooo0_l0001>ooooo`007?ooool00ol0
003oooooooooo`1Booooo`;o00005oooool4o`0000kooooo1?l00003ooooo`Co00001Oooool2o`00
00Oooooo0_l000000ooooooo0000o`00000Do`0000_ooooo0_l00008ooooo`;o0000:oooool2o`00
05Kooooo000Looooo`03o`000?oooooooooo05;ooooo0_l00007ooooo`;o00003oooool3o`0000ko
oooo0ol00006ooooo`;o00001Oooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo
0000o`00000Do`0000Oooooo0_l00002ooooo`?o00000_ooool2o`000003ooooool0003o000000co
oooo0_l00008ooooo`Co00004?ooool5o`00017ooooo0_l00013ooooo`007?ooool00ol0003ooooo
ooooo`12ooooo`;o00000_ooool2o`0000;ooooo0ol00003ooooo`;o00001_ooool2o`000003oooo
ool0003o000000Sooooo0_l00005ooooo`;o00002_ooool2o`0000Kooooo0_l00004ooooo`?o0000
1oooool2o`0000Oooooo0ol000000ooooooo0000o`00000@o`0000Oooooo0_l00002ooooo`?o0000
00Goooooo`000?l0003o0000ooooo`04o`0000Gooooo0_l00003ooooo`;o00002?ooool4o`0000Co
oooo0_l00007ooooo`;o000000Coooooo`000?l0003o00004oooool2o`0004?ooooo000Looooo`03
o`000?oooooooooo03[ooooo0_l000000ooooooo0000o`000003ooooo`;o00000_ooool2o`0000;o
oooo0ol000000ooooooo0000o`000003o`0000Gooooo0_l0000;ooooo`;o000000?oooooo`000?l0
00003_ooool2o`0000Kooooo0_l000001?oooooo0000o`000?ooool3o`0000Gooooo1Ol00005oooo
o`Co000000?oooooo`000?l000004Ol0000>ooooo`;o00001?ooool2o`0000Gooooo0_l0000Eoooo
o`;o00001oooool2o`0000;ooooo0_l00005ooooo`;o0000DOooool001cooooo00?o0000oooooooo
ool0>_ooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000008ooooo`;o
000000?oooooo`000?l000004oooool4o`0001Wooooo0ol00008ooooo`;o000000?oooooo`000?l0
00001OoooolJo`0000?ooooo0_l0000@ooooo`;o00003Oooool2o`0000Cooooo1?l0000?ooooo`;o
00001Oooool2o`00057ooooo000Looooo`03o`000?oooooooooo03gooooo0_l00002ooooo`;o0000
00?oooooo`000?l000001Oooool2o`0000Sooooo0_l0000?ooooo`;o00000oooool2o`0000cooooo
0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000_ooooo0_l00007oooooaSo0000
00?oooooo`000?l000001?l00007ooooo`;o000000?oooooo`000?l000000_ooool2o`0000gooooo
0_l00004ooooo`Ko00000_ooool2o`0001Oooooo0_l0001:ooooo`007?ooool00ol0003ooooooooo
o`0kooooo`;o00001?ooool2o`0000;ooooo0_l00004ooooo`;o00002?ooool3o`0001?ooooo0_l0
000<ooooo`;o00000_ooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000001ooo
ool2o`0000?ooooo2ol000000ooooooo0000o`00000Eo`0000Cooooo0_l000001?oooooo0000o`00
0?ooool2o`0000Kooooo0_l00002ooooo`;o00002_ooool4o`000003ooooool0003o000000;ooooo
0_l0000Gooooo`;o00003oooool2o`0003Wooooo000Looooo`03o`000?oooooooooo03_ooooo0_l0
00001?oooooo0000o`000?ooool3o`000003ooooool0003o000000oooooo0ol0000Oooooo`Co0000
0oooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000003?oooolIo`0000;o
oooo0_l000000ooooooo0000o`000007ooooo`;o00001oooool2o`0000?ooooo0_l00002ooooo`;o
00000_ooool4o`0000;ooooo1_l00002ooooo`;o0000:oooool2o`0003Wooooo000Looooo`03o`00
0?oooooooooo03kooooo1_l000000ooooooo0000o`00000@ooooo`;o00006_ooool2o`0000;ooooo
1Ol00003ooooo`;o000000?oooooo`000?l000001?l00005ooooo`;o00003?oooolDo`000003oooo
ool0003o000000;ooooo0_l000000ooooooo0000o`00000=ooooo`;o00000oooool2o`0000?ooooo
3Ol00004ooooo`;o00007oooool2o`0000Gooooo0_l0000nooooo`007?ooool2o`0003Gooooo0_l0
000:ooooo`;o00000oooool2o`0000gooooo0_l00009ooooo`;o00000oooool2o`0000Sooooo0_l0
0003ooooo`;o00000_ooool2o`000003ooooool0003o000000?ooooo0_l00003ooooo`Go00001?oo
ool2o`0000cooooo5?l000000ooooooo0000o`000004ooooo`?o00004_ooool2o`0000?ooooo0ol0
0004ooooo`?o000000?oooooo`000?l000000_ooool2o`00023ooooo0ol00003ooooo`Co0000?_oo
ool001cooooo00?o0000ooooooooool0=?ooool2o`0000Oooooo0_l0000Eooooo`;o00002Oooool3
o`0000;ooooo0_l00008ooooo`;o00001?ooool3o`0000;ooooo0_l0000:ooooo`Co00004_oooolD
o`0000Oooooo0_l00009ooooo`;o00000_ooool2o`0000cooooo0_l00002ooooo`?o000000?ooooo
o`000?l000001_l0000Nooooo`;o00001?ooool2o`00043ooooo000Looooo`03o`000?oooooooooo
03gooooo0_l000000ooooooo0000o`000005ooooo`;o00002Oooool2o`0000Cooooo0_l00002oooo
o`;o00000_ooool2o`0000Gooooo0_l0000;ooooo`Co000000Coooooo`000?l0003ooooo0_l00008
ooooo`;o00001Oooool2o`0000cooooo4ol00004ooooo`;o00000_ooool2o`0000?ooooo0_l00002
ooooo`Co00000_ooool2o`0000Sooooo0ol000000ooooooo0000o`000006ooooo`Go000000?ooooo
o`000?l000001Oooool2o`0000Kooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`10oooo
o`;o00001Oooool2o`0000Wooooo0_l00004ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooo
oooo0000o`000002ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000002
ooooo`Co00001?ooool3o`0000Oooooo0_l00005ooooo`;o00001Oooool3o`0000Oooooo4?l00004
ooooo`;o00001oooool2o`0000;ooooo0_l0000:ooooo`;o00000_ooool3o`0000Wooooo0_l00004
ooooo`;o00001Oooool2o`0000?ooooo0_l000000ooooooo0000o`00001Gooooo`007?ooool00ol0
003oooooooooo`0aooooo`;o00005?ooool3o`0000kooooo0_l00009ooooo`;o00001Oooool2o`00
0004ooooool0003o0000ooooo`;o00000_ooool3o`0000Kooooo0_l00006ooooo`;o00001Oooool2
o`0000Kooooo0ol00008ooooo`;o000000?oooooo`000?l000002Ol00005ooooo`;o00001oooool3
o`0000gooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00003Oooool2o`0000[ooooo0_l0
0007ooooo`;o0000DOooool001cooooo00?o0000ooooooooool0<Oooool2o`0000?ooooo1?l0000;
ooooo`Go00003_ooool2o`0000Wooooo0_l0000Eooooo`;o00002Oooool2o`0000Gooooo0_l0000A
ooooo`;o00000oooool2o`0000;ooooo0_l00007ooooo`;o00000oooool2o`0000Cooooo0_l00009
ooooo`go00000_ooool2o`0001kooooo0_l00004ooooo`;o00004oooool2o`0003Kooooo000Loooo
o`03o`000?oooooooooo02oooooo0_l00005ooooo`Co00002oooool4o`00017ooooo0_l0000>oooo
o`;o00000_ooool2o`0000[ooooo0_l0000Hooooo`;o00003oooool5o`0000Oooooo1?l000000ooo
oooo0000o`000003ooooo`;o00002?ooool:o`000004ooooool0003o0000o`0000?ooooo0_l00007
ooooo`;o00006Oooool4o`0001?ooooo0_l0000fooooo`007?ooool00ol0003oooooooooo`0_oooo
o`;o00001oooool2o`000003ooooool0003o000000Wooooo0ol0000Aooooo`;o00003_ooool2o`00
00;ooooo0_l00002ooooo`;o00001oooool2o`0000Oooooo1_l000001?oooooo0000o`000?l00006
ooooo`;o00002_ooool2o`0000?ooooo1Ol00002ooooo`;o00001Oooool2o`0000Kooooo0_l00003
oooooa;o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00000_ooool2o`0000Gooooo0_l0
000Booooo`;o00000_ooool2o`0004Wooooo000Looooo`03o`000?oooooooooo033ooooo0_l00009
ooooo`;o00000oooool2o`0000Cooooo0_l0000Eooooo`?o00002_ooool2o`0000Gooooo1?l00006
ooooo`;o00001oooool6o`000003ooooool0003o000000;o00001_ooool3o`0000;ooooo0_l00004
ooooo`;o00001_ooool2o`0000;ooooo0ol00005ooooo`Co00000oooool2o`0000?ooooo4_l00000
1?oooooo0000o`000?ooool2o`0000?ooooo0_l00009ooooo`;o00002_ooool2o`0000Oooooo0_l0
00000ooooooo0000o`000007ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0<?ooool2
o`0000Oooooo0_l00005ooooo`;o00005?ooool2o`0000;ooooo0_l000001?oooooo0000o`000?l0
000Aooooo`Co00003_ooool3o`0000Oooooo0_l00004ooooo`Go000000Coooooo`000?l0003o0000
3Oooool2o`0000;ooooo0_l00005ooooo`Co00000oooool2o`0000Cooooo5_l00005ooooo`;o0000
0_ooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000[ooooo0_l00010ooooo`007?oo
ool00ol0003oooooooooo`0iooooo`;o00005?ooool2o`0000Gooooo0_l00002ooooo`;o00001ooo
ool2o`0000;ooooo0_l0000:ooooo`;o000000?oooooo`000?l000000_l00007ooooo`Go00003Ooo
ool3o`0000?ooooo0_l00004ooooo`;o00001oooool5o`0000Gooooo0ol000000ooooooo0000o`00
0009ooooo`Oo000000?oooooo`000?l000003_l00003ooooo`;o00000_ooool2o`0000Oooooo1?l0
000Dooooo`?o0000AOooool001cooooo00?o0000ooooooooool0<_ooool2o`0000Kooooo0_l0000C
ooooo`;o00004_ooool2o`000004ooooool0003o0000o`0000[ooooo0_l000000ooooooo0000o`00
0002o`0000;ooooo0_l00003ooooo`Go00003?ooool4o`0000;ooooo1?l00003ooooo`;o000000?o
ooooo`000?l000001?ooool2o`000003ooooool0003o000000Gooooo0ol000000ooooooo0000o`00
0004ooooo`;o00000_oooolIo`0000;ooooo0_l00003ooooo`;o00002Oooool2o`0001Cooooo0ol0
0015ooooo`007?ooool00ol0003oooooooooo`0booooo`;o00000_ooool6o`0000Wooooo0_l0000=
ooooo`;o00004?ooool2o`0000Oooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l00002
ooooo`;o00001?ooool2o`000003ooooool0003o000000_ooooo0ol00003ooooo`Co000000?ooooo
o`000?l000000oooool2o`0000;ooooo0_l0000Doooooaco000000?oooooo`000?l000000_l00008
ooooo`;o00004Oooool2o`0000Sooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`0foooo
o`Co00002oooool2o`0000Oooooo0_l00004ooooo`;o00004_ooool4o`000003ooooool0003o0000
00;o000000?oooooo`000?l000001_l00002ooooo`Go000000?oooooo`000?l000000ol0000<oooo
o`;o00001?ooool2o`0000;ooooo0_l00006ooooo`?o00000_ooool4o`0000;ooooo0ol00009oooo
o`Go00000_oooolHo`0000[ooooo0_l0000@ooooo`?o00002?ooool2o`0004Gooooo00001_oooooo
k^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool0
0ol0003oooooooooo`0nooooo`;o00001Oooool2o`0000Oooooo0_l0000Aooooo`Co00000oooool4
o`000003ooooool0003o000000;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00
0002ooooo`Go00000_ooool2o`0000?ooooo0_l00006ooooo`;o000000?oooooo`000?l000001?oo
ool3o`0000?ooooo0_l00004ooooo`;o00000oooool4o`0000;ooooo0ol00006oooooaCo000000?o
ooooo`000?l000003?l000001?oooooo0000o`000?ooool2o`0000Wooooo0_l0000:ooooo`?o0000
Coooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0nooooo`;o00006Oooool2o`0000Kooooo1Ol00004ooooo`Co
00001_ooool3o`0000gooooo0_l00002ooooo`;o00000_ooool6o`0000Oooooo0ol00003ooooo`;o
00001oooool2o`0000gooooo9Ol000001?oooooo0000o`000?ooool2o`0000Wooooo0_l0000Voooo
o`;o0000=?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool5o`0000Ko
oooo00?o0000ooooooooool0FOooool2o`000003ooooool0003o000000Cooooo1?l00006ooooo`?o
00001Oooool3o`0000Oooooo0_l00004ooooo`;o000000?oooooo`000?l000000oooool6o`0000Co
oooo0_l0000@ooooo`;o00001_ooool2o`000003ooooool0003o000000;ooooo0_l00005oooooako
00001oooool2o`0002kooooo0_l0000dooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooo
ooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0001;ooooo`;o00003oooool2o`000004
ooooool0003o0000ooooo`;o00002Oooool2o`0000?ooooo0_l0000:ooooo`;o00000oooool2o`00
00;ooooo0_l00005ooooo`Co00001?ooool2o`0000?ooooo2ol0000:ooooo`;o000000?oooooo`00
0?l000000_ooool2o`0000Cooooo7Ol00009ooooo`;o0000I?ooool00003ooooool0003ooooo00;o
oooo00?o0000ooooooooool02Oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo
02Oooooo0_l0000Rooooo`;o00004_ooool3o`0000cooooo0_l00002ooooo`;o00003oooool2o`00
00[ooooo0_l0000:ooooo`_o000000?oooooo`000?l000003_ooool2o`0000?ooooo7ol0000;oooo
o`;o00000_ooool2o`0001_ooooo0_l00002ooooo`;o0000??ooool00003ooooool@413ooooo00;o
oooo00?o410@ooooooooool02_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo02Oo
oooo0_l0000@ooooo`;o00004?ooool2o`0000oooooo0_l000001?oooooo0000o`000?l0000<oooo
o`Co000000?oooooo`000?l000006_ooool2o`0000_ooooo1?l000000ooooooo0000o`000004oooo
o`;o00004_ooool3o`000003ooooool0003o000001[o00002oooool2o`0000;ooooo1?l000000ooo
oooo0000o`00000Fooooo`;o00000_ooool2o`0003cooooo00001_ooooooMgMgoiRHV?ooooooV9RH
ogMgM`cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0iooooo`;o000000?ooooo
o`000?l000002oooool4o`0000oooooo0_l00006ooooo`;o00002_ooool2o`000004ooooool0003o
0000o`0001;ooooo0_l0000Aooooo`;o000000Coooooo`000?l0003ooooo1?l0000Aooooo`;o0000
0oooool2o`000003ooooool0003o000000ko000000?oooooo`000?l000002_l0000@ooooo`?o0000
00?oooooo`000?l00000F?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo
0000ooooo`06ooooo`03o`000?oooooooooo02gooooo0_l0000=ooooo`;o00002oooool2o`0000ko
oooo0_l00009ooooo`;o00003Oooool3o`00013ooooo1?l00002ooooo`;o00001?ooool2o`0000Oo
oooo0_l00006ooooo`;o000000?oooooo`000?l000002_ooool2o`0000;ooooo0_l000000ooooooo
0000o`00000Mo`0000Sooooo0_l00009ooooo`;o00007Oooool2o`0003gooooo000Looooo`03o`00
0?oooooooooo02gooooo0_l0000Dooooo`;o00000oooool3o`0000;ooooo0_l0000:ooooo`;o0000
3Oooool2o`0001Gooooo0_l00005ooooo`;o00001?ooool2o`0000Cooooo0_l00002ooooo`;o0000
0_ooool2o`0000Cooooo0_l000000ooooooo0000o`000003o`0000[ooooo0_l00005ooooo`Oo0000
00?oooooo`000?l000005?l00003ooooo`?o00000oooool3o`0000;ooooo0_l00007ooooo`;o0000
6_ooool2o`0003gooooo000Looooo`03o`000?oooooooooo03[ooooo0_l00004ooooo`;o000000?o
ooooo`000?l000000oooool2o`000003ooooool0003o000000;o00002?ooool2o`0000Oooooo0_l0
0006ooooo`Co00002Oooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`00
0006ooooo`;o00003Oooool2o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l000000_l0
0004ooooo`;o00001Oooool2o`0000;ooooo0_l000000ooooooo0000o`00000Mo`0000;ooooo0ol0
0003ooooo`?o00000_ooool2o`000004ooooool0003o0000o`0000?ooooo0_l00005ooooo`;o0000
D_ooool001cooooo00?o0000ooooooooool0=?ooool2o`0000Cooooo0_l00002ooooo`Co00002Ooo
ool2o`0000Wooooo0ol00002ooooo`;o00000oooool2o`0000Gooooo0_l000001?oooooo0000o`00
0?l00008ooooo`Wo00002Oooool2o`0001?ooooo0_l00007ooooo`;o00001?ooool2o`0000Wooooo
0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000001Oo00000_ooool2o`0000;o
oooo0_l00008ooooo`?o00002_ooool2o`0000;ooooo0_l0001>ooooo`007?ooool00ol0003ooooo
ooooo`0cooooo`?o00002?ooool2o`0000Gooooo0_l0000:ooooo`;o00000oooool2o`0000?ooooo
0_l00005ooooo`;o00000oooool2o`0000;ooooo0_l0000:ooooo`Go00000_ooool2o`0000Kooooo
0_l0000Dooooo`;o00000oooool6o`0000Gooooo0_l00007ooooo`;o00001Oooool2o`000003oooo
ool0003o000001Oo00000_ooool2o`0000;ooooo0ol00004ooooo`?o00004Oooool4o`0004cooooo
000Looooo`03o`000?oooooooooo02gooooo0_l000001?oooooo0000o`000?ooool2o`00013ooooo
0_l0000:ooooo`;o00002?ooool2o`0000Gooooo0_l00004ooooo`;o00000_ooool4o`0000Gooooo
0_l00002ooooo`;o00000oooool2o`000004ooooool0003o0000o`0000;ooooo0_l000000ooooooo
0000o`00000Fooooo`So00000oooool2o`000003ooooool0003o000000Cooooo0_l0000:oooooaOo
00001Oooool5o`0000?ooooo1?l00007ooooo`;o00002Oooool2o`0000cooooo0_l0000nooooo`00
7?ooool00ol0003oooooooooo`0]ooooo`;o000000?oooooo`000?l000001_ooool2o`00013ooooo
0_l0000<ooooo`Go00000_ooool2o`0000Oooooo2ol00002ooooo`;o00001oooool2o`000004oooo
ool0003o0000o`0000?ooooo1?l0000Gooooo`?o000000?oooooo`000?l000000ol00004ooooo`;o
00002?ooool7o`0000;ooooo3Ol000000ooooooo0000o`000006o`0000Gooooo0_l000000ooooooo
0000o`000003ooooo`Co00001oooool2o`0001Oooooo0_l0000;ooooo`;o0000<Oooool001cooooo
00?o0000ooooooooool0<_ooool2o`0000Cooooo0_l0000@ooooo`;o00003?ooool3o`0000;ooooo
1?l00007ooooo`Co00001?ooool4o`0000[ooooo1?l00005ooooo`;o00001oooool2o`0000Oooooo
0_l00007ooooo`;o00000oooool6o`0000Cooooo0_l00006ooooo`Oo00000_oooolAo`0000Kooooo
0_l000000ooooooo0000o`000002o`0000Gooooo0_l00004ooooo`;o0000:Oooool2o`00037ooooo
000Looooo`03o`000?oooooooooo03;ooooo0_l00002ooooo`;o00008Oooool2o`0000;ooooo0_l0
000=ooooo`;o00001?ooool2o`0000[ooooo1?l00008ooooo`;o00001?ooool2o`0000?ooooo0_l0
0002ooooo`;o00001oooool2o`0000;ooooo1ol000001?oooooo0000o`000?ooool2o`00013ooooo
4ol00003ooooo`;o000000?oooooo`000?l000000_l0000;ooooo`;o00007_ooool2o`0003cooooo
000Looooo`03o`000?oooooooooo03Kooooo0_l00007ooooo`Co00004Oooool2o`0000kooooo0_l0
0002ooooo`;o000000Goooooo`000?l0003o0000ooooo`03o`0000Gooooo0_l00005ooooo`Co0000
0_ooool2o`000003ooooool0003o000000?o00002Oooool2o`000004ooooool0003o0000o`0000Oo
oooo0_l00002ooooo`;o000000?oooooo`000?l000000oooool2o`000003ooooool0003o000001?o
oooo4_l0000:ooooo`;o00009oooool2o`0003cooooo000Looooo`03o`000?oooooooooo037ooooo
0_l00007ooooo`;o00000oooool4o`00017ooooo0_l0000>ooooo`Ko000000Coooooo`000?l0003o
oooo1Ol00002ooooo`Co000000?oooooo`000?l000000_ooool5o`000003ooooool0003o000000Go
00000oooool2o`0000Sooooo0_l00009ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Koooo
o`oo000000?oooooo`000?l000001_ooool2o`0000;ooooo0_l00003ooooo`Co00004?ooool2o`00
04cooooo000Looooo`03o`000?oooooooooo02cooooo0_l00003ooooo`;o00001oooool2o`000003
ooooool0003o000001?ooooo0_l000000ooooooo0000o`00000:ooooo`Co000000?oooooo`000?l0
00000_l00004ooooo`_o000000?oooooo`000?l000001ol000000ooooooo0000o`000002o`0000Ko
oooo0_l00008ooooo`;o000000Coooooo`000?l0003o00001Oooool2o`000004ooooool0003o0000
ooooo`;o00007oooool<o`0000Sooooo0_l00007ooooo`Co00004?ooool2o`0004cooooo000Loooo
o`;o0000;Oooool2o`0000kooooo0ol0000Cooooo`;o000000?oooooo`000?l000001oooool2o`00
0003ooooool0003o000000?o000000Goooooo`000?l0003o0000ooooo`02o`0000?ooooo2Ol00003
ooooo`;o000000Coooooo`000?l0003o00000_ooool4o`0000Gooooo1?l00007ooooo`Ko00002?oo
ool2o`0001[ooooo1?l00004ooooo`Ko000000Coooooo`000?l0003ooooo0_l00009ooooo`;o0000
7?ooool2o`0004[ooooo000Looooo`03o`000?oooooooooo02cooooo0_l000000ooooooo0000o`00
000;ooooo`;o00005?ooool2o`0000?ooooo1?l00002ooooo`?o000000?oooooo`000?l000001_l0
0002ooooo`[o000000?oooooo`000?l000001?l00004ooooo`;o000000?oooooo`000?l000002?oo
ool4o`0000?ooooo0_l00004ooooo`;o00000_ooool2o`0000Kooooo0_l0000=ooooo`;o00002ooo
ool4o`0000[ooooo0ol00002ooooo`;o00001?ooool2o`0000;ooooo0_l0000Fooooo`;o00001?oo
ool2o`0004[ooooo000Looooo`03o`000?oooooooooo02cooooo0_l000000ooooooo0000o`00000?
ooooo`;o000000Coooooo`000?l0003ooooo0_l0000<ooooo`;o000000?oooooo`000?l000000_l0
0002ooooo`;o00000_ooool7o`0000;ooooo2Ol00005ooooo`Go000000?oooooo`000?l000000_l0
00001?oooooo0000o`000?l0000>ooooo`;o00001oooool3o`0000Kooooo0_l0000=ooooo`;o0000
6Oooool2o`0000?ooooo0_l00004ooooo`;o00002Oooool2o`0000oooooo0_l0001@ooooo`007?oo
ool00ol0003oooooooooo`0booooo`;o00003?ooool2o`000004ooooool0003o0000ooooo`;o0000
3?ooool2o`0000?ooooo0_l00005ooooo`ko000000?oooooo`000?l000001_l00002ooooo`Wo0000
0_ooool4o`000003ooooool0003o000000;o00003oooool3o`0000Cooooo1Ol00003ooooo`;o0000
4?ooool2o`0000Sooooo0_l0000?ooooo`;o00003?ooool2o`00067ooooo000Looooo`03o`000?oo
oooooooo03;ooooo1?l00003ooooo`;o00002oooool2o`0000Cooooo0_l00002ooooo`;o00001?oo
ool2o`000003ooooool0003o000000;o00000oooool5o`0000;ooooo6_l00005ooooo`Oo00002Ooo
ool2o`0000Cooooo0_l00005ooooo`?o00001Oooool4o`0000[ooooo0_l00002ooooo`;o00002?oo
ool2o`0000Gooooo0_l00008ooooo`;o0000?Oooool2o`00033ooooo000Looooo`03o`000?oooooo
oooo03Cooooo0_l00003ooooo`;o00002oooool2o`0000Cooooo0_l00002ooooo`;o00001?ooool2
o`0000?ooooo0_l00003oooooaoo000000?oooooo`000?l000000_l00004ooooo`;o000000Gooooo
o`000?l0003o0000ooooo`02o`0000Gooooo0_l00004ooooo`;o00000_ooool2o`0000Cooooo0ol0
0002ooooo`Co00002_ooool2o`0000;ooooo0_l00004ooooo`;o00002Oooool2o`0000Oooooo0_l0
000Aooooo`;o00007Oooool2o`0000cooooo0_l0000`ooooo`007?ooool00ol0003oooooooooo`0[
ooooo`;o00003?ooool2o`00013ooooo0_l0000Aooooo`Co000000?oooooo`000?l000008ol00003
ooooo`?o000000?oooooo`000?l000000_l0000=ooooo`;o00001?ooool8o`0001Gooooo0_l0000B
ooooo`;o00004Oooool2o`0000kooooo0_l00002ooooo`;o00002Oooool2o`0000cooooo0_l0000`
ooooo`007?ooool00ol0003oooooooooo`0[ooooo`?o00002oooool2o`0000gooooo0_l000001?oo
oooo0000o`000?l00008ooooo`;o00001_ooool4o`0000;ooooo:_l00003ooooo`?o00004oooool:
o`000003ooooool0003o0000013ooooo0ol0000Pooooo`;o00001?ooool2o`0000Cooooo0_l00002
ooooo`Go00000_ooool2o`0004Wooooo000Looooo`03o`000?oooooooooo02cooooo1_l00002oooo
o`;o00004_ooool2o`0000;ooooo0_l00006ooooo`Co00001?ooool2o`000003ooooool0003o0000
00Gooooo:?l00004ooooo`;o000000?oooooo`000?l000000_ooool2o`0000oooooo2_l0000@oooo
o`?o00008?ooool2o`0000Cooooo0_l00004ooooo`ko0000B?ooool001cooooo00?o0000oooooooo
ool0;Oooool5o`000003ooooool0003o000000?o00002Oooool2o`00017ooooo0_l00006ooooo`;o
00001OoooolZo`0000Sooooo0_l00002ooooo`;o00001_ooool2o`0000Oooooo0_l00002ooooo`Ko
00000oooool2o`0000gooooo0_l0000Xoooooa7o0000B?ooool001cooooo00?o0000ooooooooool0
;Oooool2o`0000Cooooo1Ol00007ooooo`Go00001?ooool2o`0000oooooo0_l00004ooooobSo0000
00?oooooo`000?l000000ol00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o0000
1?ooool6o`0000?ooooo0ol0000<ooooo`;o00001Oooool2o`0000gooooo0_l0000>ooooo`;o0000
0_ooool@o`0004Wooooo000Looooo`03o`000?oooooooooo03Gooooo0_l00008ooooo`;o000000?o
ooooo`000?l000001?ooool2o`0000Oooooo1?l000001?oooooo0000o`000?ooool4o`000003oooo
ool0003o000000go000000?oooooo`000?l000006?l000000ooooooo0000o`000005o`0000;ooooo
0_l00005ooooo`Go000000?oooooo`000?l000000_ooool2o`0000;ooooo1?l0000=ooooo`;o0000
1?ooool2o`0000gooooo0_l00003ooooo`;o00002?ooool2o`0000Cooooo1Ol00005ooooo`;o0000
0_ooool@o`0004Wooooo000Looooo`03o`000?oooooooooo03oooooo0_l0000@ooooo`Co000000Go
ooooo`000?l0003o0000ooooo`03o`000004ooooool0003o0000o`0000;ooooo1?l000000ooooooo
0000o`00000Vo`0000;ooooo0_l00006ooooo`Co000000?oooooo`000?l000000_ooool2o`0000;o
oooo1?l0000Cooooo`;o00002Oooool2o`0000;ooooo0_l00003ooooo`;o00001oooool2o`0000Go
oooo1Ol00002ooooo`;o00001Oooool5o`000003ooooool0003o000000Wo00000oooool2o`0004?o
oooo000Looooo`03o`000?oooooooooo04Gooooo0_l00005ooooo`;o00000oooool2o`0000;ooooo
1?l00007ooooo`;o000000?oooooo`000?l000001ol000000ooooooo0000o`00000Oo`0001[ooooo
0_l00002ooooo`;o00003_ooool2o`0000_ooooo0_l000000ooooooo0000o`000003o`0000[ooooo
0_l0000<ooooo`;o00001_ooool@o`0000?ooooo0_l00013ooooo`007?ooool00ol0003ooooooooo
o`15ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l00002ooooo`?o00001?oo
ool2o`0000;ooooo6Ol000000ooooooo0000o`00000@o`0000;ooooo0_l000000ooooooo0000o`00
000Cooooo`;o00001?ooool4o`0000cooooo0_l00003ooooo`;o00002Oooool6o`0000_ooooo0_l0
000=ooooo`;o00000ooooolAo`0004Oooooo000Looooo`03o`000?oooooooooo02cooooo0_l0000G
ooooo`;o000000?oooooo`000?l000002_ooool4o`0000Cooooo:Ol000000ooooooo0000o`000004
o`0000;ooooo1Ol0000Aooooo`Co00001_ooool2o`0000oooooo1_l00008ooooo`;o000000?ooooo
o`000?l000002oooool2o`0000gooooo0_l00004oooooa3o0000Aoooool001cooooo0_l0000]oooo
o`;o00007_ooool2o`0000Kooooo1?l00002ooooo`;o00000_ooool]o`0000;ooooo1?l0000Coooo
o`;o00006Oooool2o`000004ooooool0003o0000o`0000cooooo0_l0000Ooooooa3o0000Aoooool0
01cooooo00?o0000ooooooooool0?Oooool2o`0000Wooooo0_l00002ooooo`;o000000?oooooo`00
0?l000000_l00003ooooo`;o00000_ooool2o`000003ooooool0003o000002So000000?oooooo`00
0?l000000_l000000ooooooo0000o`000002o`0000Cooooo0_l00002ooooo`;o00001oooool2o`00
01kooooo1?l0000;ooooo`;o00002?ooool2o`0001Kooooo3ol00003ooooo`;o0000@_ooool001co
oooo00?o0000ooooooooool0=oooool2o`000004ooooool0003o0000ooooo`;o00002Oooool2o`00
00Gooooo1?l0000:oooooc3o00001oooool3o`0000;ooooo0_l00007ooooo`;o00001Oooool2o`00
00[ooooo0_l00006ooooo`;o00001Oooool2o`0001Gooooo0_l0000Gooooo`Oo00000_ooool2o`00
0003ooooool0003o000000?ooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`0dooooo`;o
000000Coooooo`000?l0003ooooo0_l00005ooooo`?o00002_ooool4o`0000Cooooo0_l00003oooo
o`[o000000?oooooo`000?l000008Ol000001Ooooooo0000o`000?l0003ooooo00Co00000_ooool6
o`0000oooooo0_l0000:ooooo`;o00001_ooool2o`0000[ooooo1?l00006ooooo`;o00004?ooool2
o`0000oooooo0ol00004ooooo`;o00000oooool2o`0001Sooooo0_l0000[ooooo`007?ooool00ol0
003oooooooooo`0]ooooo`;o00001Oooool2o`0000[ooooo1?l0000:ooooo`Co00001?ooool2o`00
00?ooooo1_l000001Ooooooo0000o`000?l0003ooooo02?o000000?oooooo`000?l000000_ooool4
o`0000?ooooo1Ol00006ooooo`;o00003_ooool2o`0000oooooo0_l00006ooooo`Co00001_ooool2
o`00013ooooo0_l0000>ooooo`Co00002?ooool3o`0001Sooooo0_l0000[ooooo`007?ooool00ol0
003oooooooooo`0]ooooo`;o00004Oooool2o`0000?ooooo0ol0000>ooooo`Co000000?oooooo`00
0?l000000oooool9o`000003ooooool0003o000001;o000000?oooooo`000?l000002ol00003oooo
o`;o00000_ooool4o`0000Kooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`00
0?l000001oooool2o`0000oooooo0_l000000ooooooo0000o`000008ooooo`;o00009Oooool2o`00
00Sooooo1?l00016ooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o00005_ooool3o`0000Ko
oooo0_l00007oooooa7o000000?oooooo`000?l000004ol000000ooooooo0000o`000006o`000003
ooooool0003o000000?ooooo1?l000001Ooooooo0000o`000?l0003ooooo00;o00000_ooool2o`00
0003ooooool0003o000000?ooooo1?l000001Ooooooo0000o`000?l0003ooooo00;o00005?ooool2
o`000003ooooool0003o000000?ooooo0ol00002ooooo`;o0000;oooool2o`0001;ooooo0_l0000d
ooooo`007?ooool00ol0003oooooooooo`0]ooooo`?o00007_ooool2o`0000Cooooo0_l000000ooo
oooo0000o`000002o`0000;ooooo0ol000000ooooooo0000o`00000Ro`0000?ooooo0ol00002oooo
o`_o00000_ooool2o`0000Kooooo0_l00003ooooo`?o000000Coooooo`000?l0003ooooo0_l00000
0ooooooo0000o`000002ooooo`;o00001Oooool2o`0000Cooooo0_l00005ooooo`?o0000;Oooool2
o`0001Sooooo0_l0000dooooo`007?ooool00ol0003oooooooooo`0]ooooo`?o00002Oooool2o`00
01Cooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00003ooooob?o00000oooool3o`00
00Gooooo1_l0000Fooooo`Co000000?oooooo`000?l000000_ooool2o`0000Gooooo0_l00004oooo
o`?o00007oooool2o`0000Wooooo0_l00008ooooo`;o0000C_ooool001cooooo00?o0000oooooooo
ool0=_ooool2o`000003ooooool0003o000001Cooooo0_l00009ooooo`Oo000000?oooooo`000?l0
00008Ol00007ooooo`;o00000oooool4o`0000Kooooo0_l00005ooooo`;o00002?ooool2o`0000_o
oooo0_l000000ooooooo0000o`000004ooooo`?o00007oooool2o`0000Wooooo0_l0000Rooooo`;o
0000=?ooool001cooooo00?o0000ooooooooool0=_ooool2o`0000;ooooo0_l00004ooooo`;o0000
2?ooool2o`0000kooooo1ol00002ooooo`Go000000?oooooo`000?l000006Ol000000ooooooo0000
o`000005ooooo`;o00000oooool2o`0000Sooooo0_l00005ooooo`;o00002_ooool2o`0000Wooooo
0_l000000ooooooo0000o`000005ooooo`;o00001?ooool2o`0004Sooooo0_l0000dooooo`007?oo
ool00ol0003oooooooooo`0eooooo`;o00000oooool2o`0000?ooooo0ol00008ooooo`;o00003_oo
ool6o`0000?ooooo0_l000000ooooooo0000o`000002oooooaWo00000_ooool2o`0000Wooooo0ol0
000?ooooo`;o00000oooool2o`0000Gooooo0ol0000=ooooo`?o000000?oooooo`000?l000000_l0
00000ooooooo0000o`000002o`000003ooooool0003o000000;ooooo0_l00007ooooo`;o00001Ooo
ool2o`0006Oooooo000Looooo`03o`000?oooooooooo03Gooooo0_l00008ooooo`;o000000?ooooo
o`000?l000008?ooool4o`0000;ooooo3Ol000000ooooooo0000o`00000=o`000003ooooool0003o
000000Kooooo0_l00003ooooo`;o000000?oooooo`000?l000002?ooool2o`000003ooooool0003o
000000;o00001_ooool2o`0000Kooooo0_l00005ooooo`?o000000?oooooo`000?l000000_l00000
0ooooooo0000o`000005o`0000;ooooo0_l00007ooooo`;o00001Oooool3o`0000gooooo0_l0001G
ooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00005?ooool4o`0000;ooooo0_l00004oooo
o`go000000?oooooo`000?l000006Ol00008ooooo`;o000000?oooooo`000?l000001?ooool2o`00
00Cooooo0ol0000@ooooo`?o00001?ooool8o`000003ooooool0003o000000?o00004Oooool2o`00
00;ooooo0_l0000<ooooo`?o00004oooool2o`0004;ooooo000Looooo`03o`000?oooooooooo03co
oooo0_l0000Aooooo`;o00001oooool4o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`co
000000?oooooo`000?l000003?l000001?oooooo0000o`000?ooool5o`000004ooooool0003o0000
o`0000[ooooo0_l00005ooooo`;o00001?ooool2o`0001;ooooo0_l00002oooooa3o00001Oooool2
o`0000[ooooo0_l0000<ooooo`;o00000_ooool2o`000003ooooool0003o000000Cooooo0_l00007
ooooo`;o00000_ooool2o`0004;ooooo000Looooo`03o`000?oooooooooo03cooooo0_l0000Aoooo
o`;o00002?ooool3o`0000Gooooo0_l00002ooooo`Wo000000Goooooo`000?l0003o0000ooooo`06
o`0000;ooooo1Ol000001?oooooo0000o`000?ooool4o`0000?ooooo0_l000000ooooooo0000o`00
0007ooooo`;o00004?ooool2o`0000;ooooo0_l0000:ooooo`;o000000?oooooo`000?l000002_l0
00000ooooooo0000o`000002o`0000Cooooo0_l0000Hooooo`;o00001Oooool2o`000004ooooool0
003o0000ooooo`;o00001oooool2o`0000Gooooo0_l0000oooooo`007?ooool2o`0002[ooooo0_l0
000:ooooo`;o000000?oooooo`000?l000003_ooool2o`0000?ooooo0_l000000ooooooo0000o`00
0002ooooo`;o00000oooool3o`0000;ooooo0_l00003ooooo`So000000?oooooo`000?l000002Ol0
0002ooooo`Oo000000?oooooo`000?l000001oooool2o`0000;ooooo0_l0000Iooooo`;o00000_oo
ool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000003ol0
000Rooooo`;o00001?ooool4o`0000oooooo0_l00009ooooo`;o0000=?ooool001cooooo00?o0000
ooooooooool0:Oooool2o`0000[ooooo0_l000001?oooooo0000o`000?l0000=ooooo`;o00000ooo
ool2o`000003ooooool0003o000000;ooooo0_l00008ooooo`;o00000oooool7o`000004ooooool0
003o0000ooooo`;o000000?oooooo`000?l000002?l000001Ooooooo0000o`000?l0003ooooo00Go
00001?ooool3o`0002Kooooo0_l000000ooooooo0000o`000004oooooaGo00007?ooool2o`000003
ooooool0003o000000Kooooo1?l00004ooooo`;o00004_ooool2o`0000Cooooo0_l0000^ooooo`00
7?ooool00ol0003oooooooooo`0iooooo`;o00002?ooool2o`0000[ooooo0_l0000;ooooo`;o0000
0_ooool7o`000003ooooool0003o000000Co00000_ooool3o`0000;ooooo1_l000000ooooooo0000
o`000007o`0000Cooooo0_l00007ooooo`;o00008?ooool2o`0000Cooooo5_l0000:ooooo`;o0000
1_ooool2o`0000Cooooo0_l00002ooooo`;o00001oooool2o`0000;ooooo0_l00004ooooo`;o0000
6?ooool2o`0002kooooo000Looooo`03o`000?oooooooooo04?ooooo0_l00002ooooo`;o00001_oo
ool2o`0000_ooooo0_l00002ooooo`Co00001Oooool5o`0000;ooooo0ol00002ooooo`Ko00000_oo
ool7o`0000kooooo0_l0000=ooooo`;o00001oooool2o`0000Sooooo1?l00002oooooa;o00001?oo
ool2o`0000Sooooo0ol00005ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o0000
00?oooooo`000?l000001?ooool2o`0000oooooo0_l000000ooooooo0000o`000007ooooo`;o0000
=Oooool001cooooo00?o0000ooooooooool0?oooool2o`0000Kooooo0_l00003ooooo`;o00004ooo
ool2o`0000;ooooo0_l00003ooooo`Co00001?ooool2o`000003ooooool0003o000000Go000000Co
ooooo`000?l0003ooooo0_l000000ooooooo0000o`000002o`0001Wooooo0ol00005ooooo`Co0000
2_ooool2o`000003ooooool0003o000001Oo00001?ooool2o`0000?ooooo0_l00008ooooo`;o0000
1Oooool2o`000003ooooool0003o000001Gooooo1Ol00007ooooo`;o0000=Oooool001cooooo00?o
0000ooooooooool0?oooool2o`0000_ooooo0_l0000;ooooo`;o00000oooool2o`000004ooooool0
003o0000ooooo`Co00001?ooool2o`0000Cooooo0_l000000ooooooo0000o`000005o`0000Cooooo
0_l000000ooooooo0000o`000002o`0001Wooooo0ol000000ooooooo0000o`000002ooooo`;o0000
3oooool>o`000003ooooool0003o000000So00001?ooool4o`0000cooooo0_l00007ooooo`;o0000
5_ooool2o`00043ooooo000Looooo`03o`000?oooooooooo03oooooo0_l00003ooooo`;o00001?oo
ool2o`0000Cooooo0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o000000;o00000_oo
ool6o`0000?ooooo0_l00008ooooo`?o00002Oooool2o`0000Sooooo0_l0000Dooooo`;o000000?o
ooooo`000?l000000_ooool2o`0000oooooo6_l00003ooooo`Co00003?ooool2o`000003ooooool0
003o000000Cooooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00001Oooool2
o`0000?ooooo0_l00004ooooo`;o00001?ooool3o`0000;ooooo0_l00005ooooo`;o00001?ooool6
o`0000?ooooo0_l000001?oooooo0000o`000?l00002ooooo`Go00002Oooool2o`0000Sooooo0_l0
000Eooooo`Co00001oooool2o`0000Kooooo0_l000000ooooooo0000o`00000Io`0000Oooooo0_l0
000=ooooo`Co00005_ooool2o`0000;ooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0h
ooooo`;o00001Oooool2o`0000Sooooo0_l00005ooooo`?o00001_ooool2o`0000Gooooo0_l00002
ooooo`;o00002?ooool3o`0000;ooooo1?l0000Aooooo`;o00005_ooool6o`0000Gooooo1?l00006
ooooo`;o000000?oooooo`000?l000006?l00008ooooo`;o00003oooool2o`0001Kooooo0_l00002
ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0?oooool2o`0000;ooooo0_l00004oooo
o`;o00001Oooool2o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`Co00003Oooool2o`00
00Gooooo0_l00008ooooo`Co00001?ooool2o`0000Cooooo0_l0000@ooooo`;o00002Oooool3o`00
00[ooooo5ol000000ooooooo0000o`00000<ooooo`;o00008Oooool2o`0000Kooooo0_l0000noooo
o`007?ooool00ol0003oooooooooo`0looooo`;o00001Oooool2o`0000Oooooo0_l00002ooooo`;o
000000?oooooo`000?l000001?l00005ooooo`Co00005?ooool2o`0000Sooooo1?l0000:ooooo`;o
00004oooool2o`0000Kooooo0ol00007ooooo`;o00000_oooolFo`0000oooooo0_l0000=ooooo`;o
00004_ooool2o`0000;ooooo0_l00002ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0
??ooool2o`0000;ooooo0_l0000:ooooo`;o00001Oooool6o`0000Oooooo0_l000000ooooooo0000
o`00000Jooooo`;o000000?oooooo`000?l000007oooool3o`0000Gooooo0ol00007ooooo`;o0000
0_oooolGo`0000Wooooo0_l0000Booooo`;o00005_ooool2o`0004;ooooo000Looooo`03o`000?oo
oooooooo03Kooooo0_l00008ooooo`;o00000_ooool2o`0001;ooooo0_l00009ooooo`;o00002_oo
ool2o`0000kooooo0_l000000ooooooo0000o`000007ooooo`;o00005oooool2o`0000Kooooo0_l0
0007ooooo`;o00000_oooolGo`0000Wooooo0_l000000ooooooo0000o`00000Booooo`;o00001Ooo
ool2o`0000[ooooo1Ol0000;ooooo`;o0000=?ooool001cooooo00?o0000ooooooooool0=_ooool2
o`0000cooooo0ol00006ooooo`;o00001Oooool6o`0000kooooo0_l00002ooooo`;o000000?ooooo
o`000?l000004Oooool2o`0000Cooooo0_l000000ooooooo0000o`00000Jooooo`;o00000oooool2
o`0000Sooooo0_l000000ooooooo0000o`00000Fo`0000_ooooo0_l0000Booooo`;o00001Oooool2
o`0000[ooooo1Ol0000;ooooo`;o0000=?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Ooo
ool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo02kooooo
0_l0000<ooooo`;o00001_ooool3o`0000Kooooo0_l00005ooooo`Go00003oooool2o`0000;ooooo
0_l00005ooooo`;o00004oooool2o`0000Cooooo0_l00007ooooo`;o00001oooool2o`0000;ooooo
0_l000000ooooooo0000o`000004ooooo`Co00001Oooool2o`000005ooooool0003o0000o`000?oo
ool03ol000000ooooooo0000o`000002o`0002Oooooo0_l0000Fooooo`;o0000=oooool00006oooo
oomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06
ooooo`03o`000?oooooooooo02cooooo1?l0000<ooooo`;o00001_ooool2o`0000;ooooo0_l0000:
ooooo`;o000000?oooooo`000?l000003?ooool2o`0000Sooooo0_l00002ooooo`;o00002oooool2
o`0000Cooooo0_l00006ooooo`;o00001oooool2o`0000Oooooo0_l00002ooooo`;o00000oooool2
o`0000;ooooo1?l00005ooooo`;o000000Coooooo`000?l0003o00000_oooolAo`0000cooooo0_l0
00000ooooooo0000o`000002ooooo`;o00004Oooool2o`000003ooooool0003o000000_ooooo0_l0
0009ooooo`;o0000=oooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0;?ooool2o`0001Kooooo0_l0
0002ooooo`;o00002?ooool3o`0000[ooooo0_l00004ooooo`;o00002?ooool2o`0000oooooo0_l0
0004ooooo`;o00007?ooool2o`0000?ooooo0_l00008ooooo`;o00001Oooool3o`000003ooooool0
003o000000oo000000?oooooo`000?l000002Oooool2o`000003ooooool0003o000000;ooooo0_l0
0004ooooo`;o00002_ooool3o`0000kooooo0_l00012ooooo`0000?oooooo`000?ooool00_ooool0
0ol0003oooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0004Cooooo0_l0
0009ooooo`;o000000Coooooo`000?l0003o00002_ooool2o`0000Wooooo0_l00004ooooo`;o0000
1Oooool3o`0003Wooooo0_l000000ooooooo0000o`000003oooooa;o00000oooool2o`0000Kooooo
0_l0000>ooooo`;o000000?oooooo`000?l000001oooool2o`0000Kooooo0_l0001;ooooo`0000?o
ooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
1_ooool00ol0003oooooooooo`1?ooooo`;o00002Oooool2o`0000Gooooo1_l00003ooooo`;o0000
0_ooool4o`0000Gooooo0ol000000ooooooo0000o`00000]ooooo`;o00001Oooool2o`0000?ooooo
0_l00003oooooa;o000000?oooooo`000?l000002?ooool2o`0000;ooooo0_l0000<ooooo`?o0000
3oooool2o`0001?ooooo0_l0000fooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0=oooool2o`0001kooooo1Ol0
0005ooooo`Ko00001Oooool4o`0000Oooooo1_l0000Aooooo`Co00006?ooool2o`000003ooooool0
003o000000Ko00002?ooool>o`0000;ooooo0ol00004ooooo`;o00001_ooool2o`0000cooooo0_l0
0008ooooo`;o00003_ooool4o`0000Gooooo0_l00002ooooo`;o0000=_ooool00006oooooomgMgOo
V9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo03Oooooo
0_l0000:ooooo`;o00004_ooool3o`0001;ooooo0_l000000ooooooo0000o`000004ooooo`;o0000
0_ooool2o`0000kooooo0_l00003ooooo`Co00001?ooool4o`0000Gooooo0_l00003ooooo`;o0000
1oooool4o`0000;ooooo0_l00006oooooa3o000000?oooooo`000?l000001?l00002ooooo`;o0000
1_ooool2o`0001Gooooo0ol0000>ooooo`Co00001Oooool2o`0003[ooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`11oooo
o`Ko00005?ooool2o`00013ooooo1?l00004ooooo`;o00003Oooool2o`0000?ooooo0_l00007oooo
o`;o00000_ooool5o`0000Cooooo0_l00003ooooo`;o00001Oooool2o`0000kooooo0_l00004oooo
o`;o00000oooool8o`0000;ooooo0_l00008ooooo`Co00001oooool2o`0000cooooo0_l000000ooo
oooo0000o`000008ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0@Oooool3o`000003
ooooool0003o000000kooooo1?l00002ooooo`Co000000?oooooo`000?l000001?ooool2o`0000Go
oooo0_l0000Eooooo`;o00003?ooool5o`0000;ooooo0_l0000@ooooo`;o000000?oooooo`000?l0
00000_ooool2o`0000cooooo1_l000000ooooooo0000o`000003o`0000kooooo0_l00002ooooo`;o
00001?ooool3o`0000[ooooo1?l000000ooooooo0000o`000002o`0000Kooooo0_l00017ooooo`00
7?ooool00ol0003oooooooooo`0^ooooo`;o00009Oooool4o`000004ooooool0003o0000ooooo`Go
00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o00001oooool2o`0000[o
oooo0_l00002ooooo`;o00001_ooool4o`0000oooooo0_l000000ooooooo0000o`000003ooooo`;o
00000_ooool2o`0000cooooo1_l0000Hooooo`;o00001?ooool5o`0000Sooooo1?l000000ooooooo
0000o`000003o`0004kooooo000Looooo`03o`000?oooooooooo02kooooo0_l00008ooooo`;o0000
1Oooool4o`0001Oooooo0ol00002ooooo`;o00002Oooool2o`0000Kooooo0_l00007ooooo`;o0000
1_ooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000000oooool2o`0000Oooooo
0_l00004ooooo`;o000000?oooooo`000?l000001?l00003ooooo`;o00004?ooool3o`0000_ooooo
0_l0000Fooooo`?o00003Oooool5o`0004kooooo000Looooo`03o`000?oooooooooo03Sooooo0_l0
0005ooooo`Co00003oooool2o`0000Gooooo1?l0000Cooooo`;o00004Oooool4o`0000Cooooo0_l0
00000ooooooo0000o`000003ooooo`;o000000Coooooo`000?l0003o00000oooool2o`0000Cooooo
0_l000000ooooooo0000o`000002o`0000Gooooo0_l0000@ooooo`?o00002oooool2o`0001Cooooo
0_l000000ooooooo0000o`00000=ooooo`?o0000D?ooool001cooooo00?o0000ooooooooool0>?oo
ool2o`0000Sooooo0_l0000>ooooo`;o00001Oooool4o`000003ooooool0003o000000Kooooo0_l0
0002ooooo`;o00001?ooool2o`0001?ooooo0_l0000?ooooo`?o00001?ooool2o`0000?ooooo0_l0
000_ooooo`;o00002oooool6o`0000kooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`10
ooooo`Co00006Oooool3o`0000Kooooo0_l00002ooooo`;o00001oooool2o`0001;ooooo0ol0000<
ooooo`;o00001Oooool2o`0000[ooooo0_l00003ooooo`;o00002Oooool2o`0001Sooooo1?l00005
ooooo`[o00003_ooool2o`000003ooooool0003o0000017ooooo0_l0000mooooo`007?ooool00ol0
003oooooooooo`10ooooo`?o00006_ooool2o`000004ooooool0003o0000ooooo`;o00003_ooool2
o`0000Gooooo0ol00009ooooo`Co00002_ooool6o`0000[ooooo0_l00003ooooo`;o00000oooool4
o`0000Oooooo0_l0000>ooooo`;o00002Oooool5o`0000?ooooo1?l00009ooooo`;o00003?ooool2
o`00017ooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0nooooo`;o000000Coooooo`00
0?l0003o00002?ooool3o`0000kooooo0_l000001?oooooo0000o`000?ooool4o`0001?ooooo0ol0
0007ooooo`Co00000oooool2o`0000Oooooo2_l00004ooooo`Co00002_ooool2o`0000Oooooo1_l0
000:ooooo`;o00002Oooool2o`000003ooooool0003o000000;o00000oooool2o`0000Wooooo0_l0
0003ooooo`;o00002_ooool5o`0000;ooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`0n
ooooo`?o000000?oooooo`000?l000002?ooool3o`0000cooooo1?l00006ooooo`;o00004_ooool2
o`0000Sooooo1?l00002ooooo`Co000000Coooooo`000?l0003ooooo1?l000000ooooooo0000o`00
0009o`000003ooooool0003o000000;o00004oooool6o`0000[ooooo0_l0000>ooooo`;o00000ooo
ool2o`0000Sooooo0_l000001?oooooo0000o`000?ooool2o`0000[ooooo1Ol00002ooooo`;o0000
A_ooool001cooooo00?o0000ooooooooool0?oooool2o`0000?ooooo0_l000000ooooooo0000o`00
000Booooo`;o00001?ooool2o`0000?ooooo0_l0000Aooooo`;o00000_ooool2o`0000Cooooo0_l0
0004ooooo`;o00000oooool2o`000003ooooool0003o000000ko00003Oooool2o`0000oooooo0_l0
000Dooooo`;o00001?ooool2o`000003ooooool0003o000000Sooooo0_l000000ooooooo0000o`00
0008ooooo`;o00001_ooool2o`0004[ooooo000Looooo`03o`000?oooooooooo04Cooooo0_l00000
0ooooooo0000o`000008ooooo`;o00003?ooool4o`0000?ooooo1?l000000ooooooo0000o`000005
ooooo`;o00002Oooool2o`0000Oooooo0_l00004oooooa;o000000Coooooo`000?l0003ooooo0_l0
0002ooooo`;o00001_ooool3o`0000kooooo0_l0000Dooooo`;o00001?ooool2o`0000gooooo0_l0
0004ooooo`?o00000_ooool2o`0005;ooooo000Looooo`;o0000?oooool2o`0000Cooooo0_l00002
ooooo`Co00001Oooool2o`0000cooooo0_l00007ooooo`;o000000?oooooo`000?l000001Oooool3
o`0000?ooooo0_l0000<ooooo`So00000_oooolDo`0000;ooooo0_l00007ooooo`;o00001Oooool2
o`0002;ooooo0_l00006ooooo`;o00001?ooool4o`0000Cooooo0ol00007ooooo`;o0000COooool0
01cooooo00?o0000ooooooooool0?_ooool2o`0000Cooooo0_l00002ooooo`Co00006oooool2o`00
00[ooooo1?l000000ooooooo0000o`00000=oooooaco00000_ooool6o`0000_ooooo0ol0000Foooo
o`?o00002?ooool2o`0000Kooooo0_l00004ooooo`;o00004?ooool2o`0004gooooo000Looooo`03
o`000?oooooooooo03kooooo0_l0000<ooooo`;o00004oooool2o`0000Cooooo0_l0000<ooooo`;o
00005?oooolPo`0000Kooooo0_l00004ooooo`;o00003_ooool2o`0000Kooooo0ol0000>ooooo`;o
0000Ioooool001cooooo00?o0000ooooooooool0B?ooool2o`0000;ooooo0_l0000Cooooo`;o0000
2Oooool2o`0000Sooooo0_l0000Cooooo`Co000000?oooooo`000?l000004ol00004ooooo`;o0000
1_ooool2o`0000?ooooo0ol0000>ooooo`;o00001oooool2o`0000gooooo0ol00002ooooo`Co0000
1oooool2o`0000Sooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`18ooooo`;o00000_oo
ool3o`0000;ooooo0_l0000Iooooo`;o00002?ooool2o`0000_ooooo0_l000001?oooooo0000o`00
0?l00004ooooo`?o000000Coooooo`000?l0003ooooo5Ol0000=ooooo`?o00002?ooool3o`0000?o
oooo0_l00003ooooo`;o00000_ooool2o`0000cooooo0ol00003ooooo`Ko00001Oooool3o`0000Go
oooo1ol0001;ooooo`007?ooool00ol0003oooooooooo`1;ooooo`Co00000_ooool2o`0001kooooo
0_l0000@ooooo`;o000000Coooooo`000?l0003o00000ooooolMo`000003ooooool0003o000000Go
oooo0ol0000=ooooo`?o00002?ooool2o`00013ooooo0_l00003ooooo`;o00000oooool2o`0000Ko
oooo0_l00005ooooo`?o000000Coooooo`000?l0003o00001?ooool2o`0004Gooooo000Looooo`03
o`000?oooooooooo04_ooooo0_l00004ooooo`;o00001Oooool2o`0001Oooooo0_l0000Cooooo`;o
00001?oooolGo`000003ooooool0003o000000?o000000?oooooo`000?l000001Oooool3o`0000co
oooo0_l00006ooooo`;o00002_ooool2o`0000Sooooo0_l00002ooooo`Go00006oooool2o`0004Go
oooo000Looooo`03o`000?oooooooooo04Oooooo0_l00004ooooo`;o00001?ooool2o`0000?ooooo
0_l0000/ooooo`;o00000ooooolOo`0000Oooooo1?l0000;ooooo`;o00001Oooool3o`0000[ooooo
0_l0000<ooooo`Go0000H_ooool001cooooo00?o0000ooooooooool0@oooool2o`0000;ooooo0_l0
0004ooooo`;o00001?ooool2o`0002[ooooo0_l00007ooooo`;o000000?oooooo`000?l000003?l0
00000ooooooo0000o`00000:o`000004ooooool0003o0000o`0000Oooooo1?l0000Booooo`Co0000
0_ooool2o`0000Cooooo0_l00008ooooo`;o00001?ooool2o`0000oooooo0_l0001Cooooo`007?oo
ool00ol0003oooooooooo`13ooooo`;o00001_ooool2o`00037ooooo0ol00007ooooo`;o00000ooo
oolJo`0000[ooooo0_l0000Dooooo`Co00000_ooool2o`0000Cooooo0_l00008ooooo`;o00005Ooo
ool2o`0005?ooooo000Looooo`03o`000?oooooooooo04_ooooo0_l0000?ooooo`;o00008?ooool4
o`0000;ooooo0_l00006ooooo`Wo000000?oooooo`000?l000003?l000001?oooooo0000o`000?l0
0006ooooo`Co00001?ooool2o`0000Kooooo0_l0000?ooooo`?o00001oooool2o`0006kooooo000L
ooooo`03o`000?oooooooooo04;ooooo0ol00008ooooo`;o00003Oooool3o`00027ooooo0_l00002
ooooo`;o00001?oooolIo`000003ooooool0003o000000;o00001_ooool4o`0000Cooooo0_l00006
ooooo`;o00000_ooool2o`0000Sooooo1_l00005ooooo`Go00001?ooool3o`0001Cooooo0_l0001@
ooooo`007?ooool00ol0003oooooooooo`12ooooo`?o00001?ooool3o`000003ooooool0003o0000
00kooooo0_l0000Tooooo`;o000000?oooooo`000?l000000_oooolMo`0001_ooooo0_l00008oooo
o`Co00000_ooool4o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000001?l00002
ooooo`;o00004?ooool2o`00053ooooo000Looooo`03o`000?oooooooooo04Wooooo0ol0000`oooo
o`;o00001Oooool2o`000003ooooool0003o000000?ooooo7?l0000Hooooo`Co00000oooool2o`00
00;ooooo0_l00004ooooo`Oo00000_ooool2o`0000;ooooo0ol00005ooooo`;o000000?oooooo`00
0?l000001_ooool2o`0000Gooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o
00000_ooool2o`0002cooooo0_l0000;oooooako00003Oooool2o`0000Wooooo3Ol00004ooooo`;o
00000oooool2o`0000;ooooo0_l0000=ooooo`;o00001Oooool3o`0000Gooooo0_l0001@ooooo`00
7?ooool00ol0003oooooooooo`1:ooooo`;o00000_ooool2o`0000Sooooo0_l0000Uooooo`;o0000
2?oooolNo`0000?ooooo0_l00008ooooo`;o00003Oooool7o`00017ooooo0_l0000Aooooo`?o0000
F?ooool001cooooo0_l0001;ooooo`;o00001?ooool2o`0000Kooooo0_l0000Uooooo`;o00002_oo
ool2o`000003ooooool0003o000000[o000000?oooooo`000?l000002Ol00002ooooo`Co00006?oo
ool4o`0001?ooooo0_l00005ooooo`;o00002_ooool3o`0000[ooooo0_l0001<ooooo`007?ooool0
0ol0003oooooooooo`1@ooooo`;o00002_ooool2o`0000;ooooo0_l0000Kooooo`;o00003?ooool2
o`000003ooooool0003o000001[o00005?ooool3o`0000?ooooo0_l0000Looooo`;o00002oooool2
o`0000[ooooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`1Looooo`;o00000_ooool2o`00
01_ooooo0ol0000;ooooo`;o000000?oooooo`000?l000006Ol00009ooooo`Co00002?ooool3o`00
00Kooooo0_l00008ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0000Oooooo0_l0001U
ooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o00001Oooool2o`0000Kooooo0_l0000Loooo
o`;o00001_ooool2o`0000?ooooo0_l000000ooooooo0000o`00000Do`000003ooooool0003o0000
00;o00002Oooool4o`0000[ooooo0ol00004ooooo`;o00001_ooool8o`0000;ooooo0_l00003oooo
o`;o00000_ooool2o`0000Wooooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o
00001?ooool5o`0000Cooooo0_l0000Nooooo`;o00001?ooool2o`0000Cooooo0_l00003oooooa?o
000000?oooooo`000?l000000_l0000Gooooo`?o00001?ooool2o`0000Cooooo1ol0000:ooooo`Co
000000?oooooo`000?l000002?ooool2o`0005[ooooo000Looooo`03o`000?oooooooooo05Oooooo
0_l000000ooooooo0000o`00000Tooooo`?o00000_ooool2o`0000Gooooo0ol000000ooooooo0000
o`00000Ao`0000cooooo0_l0000:ooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`Ko0000
3?ooool3o`000004ooooool0003o0000ooooo`;o0000HOooool001cooooo00?o0000ooooooooool0
G?ooool2o`0002?ooooo0_l00002ooooo`;o00001_ooool2o`000003ooooool0003o000001;o0000
1oooool3o`000003ooooool0003o000000[ooooo0_l0000=ooooo`?o00000oooool2o`0000gooooo
0ol00002ooooo`Co00001oooool2o`0000?ooooo0_l0001Cooooo`007?ooool00ol0003ooooooooo
o`1Fooooo`;o00001?ooool2o`000003ooooool0003o0000023ooooo0_l00003ooooo`;o00001?oo
ool3o`000003ooooool0003o000000Go000000?oooooo`000?l000003Ol00002ooooo`Go00003?oo
ool4o`0000_ooooo1?l00003ooooo`;o00004_ooool3o`000003ooooool0003o000000Cooooo0ol0
0003ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0E_ooool2o`0000Oooooo0_l0000J
ooooo`;o00002Oooool2o`0000Cooooo1ol00002ooooo`;o000000?oooooo`000?l000001?l00000
1?oooooo0000o`000?l00002ooooo`?o00000_ooool2o`0000_ooooo0_l00002ooooo`Co00002ooo
ool2o`0000Oooooo0_l00008ooooo`Ko00000oooool2o`000003ooooool0003o000000Cooooo1?l0
001Gooooo`007?ooool00ol0003oooooooooo`1kooooo`;o00003oooool:o`000003ooooool0003o
000000So00000oooool3o`0000kooooo1?l0000Iooooo`;o00000_ooool2o`0000Cooooo1_l00004
ooooo`;o00002?ooool2o`0000;ooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`1;oooo
o`;o00001_ooool2o`0000?ooooo0_l00005ooooo`;o0000:?ooool2o`000003ooooool0003o0000
00;ooooo3ol000000ooooooo0000o`000004o`0000Kooooo0_l00002ooooo`;o00000oooool5o`00
00Gooooo0_l00005ooooo`;o00003_ooool2o`0000Sooooo0_l00004ooooo`?o00001_ooool2o`00
00?ooooo0_l00006ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0Boooool2o`0000Ko
oooo0_l00003ooooo`;o00001Oooool2o`0002Sooooo0_l000000ooooooo0000o`000005ooooo`_o
000000?oooooo`000?l000000ol000000ooooooo0000o`000005ooooo`;o00000_ooool3o`0000;o
oooo1Ol00005ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`?o00002oooool2o`00
00Oooooo1?l00003ooooo`;o00001_ooool2o`0000_ooooo0_l0001;ooooo`007?ooool00ol0003o
ooooooooo`1Iooooo`;o00001Oooool2o`000003ooooool0003o000000cooooo0_l0000:ooooo`;o
00001oooool2o`0000Kooooo0_l00004ooooo`Wo00000_ooool5o`000003ooooool0003o000000[o
oooo0_l000000ooooooo0000o`000005o`0000Sooooo0_l00004ooooo`?o00000oooool2o`0000Ko
oooo0_l00009ooooo`;o0000IOooool001cooooo00?o0000ooooooooool0FOooool3o`0000Cooooo
1Ol0000<ooooo`?o00002Oooool2o`0000?ooooo0_l00002ooooo`;o00001_ooool2o`0000Cooooo
0_l00002ooooo`Go00000oooool4o`00013ooooo0_l00003ooooo`;o00001oooool2o`000003oooo
ool0003o000000Sooooo0_l00003ooooo`;o00005Oooool2o`0005cooooo000Looooo`03o`000?oo
oooooooo05[ooooo0_l00005ooooo`?o00003_ooool2o`0000kooooo0_l0000:ooooo`;o00001?oo
ool7o`0000_ooooo0_l00008ooooo`;o00002?ooool6o`0000;ooooo0_l000000ooooooo0000o`00
0004o`0000;ooooo1?l00003ooooo`;o000000?oooooo`000?l000003_ooool2o`0000;ooooo0_l0
001Looooo`007?ooool00ol0003oooooooooo`1Pooooo`Co00002_ooool2o`0000_ooooo0_l0000A
ooooo`;o00001?ooool4o`000004ooooool0003o0000ooooo`;o00002?ooool2o`0000Kooooo1?l0
0008ooooo`Ko00001_ooool5o`0000;ooooo1?l00006ooooo`;o000000?oooooo`000?l000000_l0
0005ooooo`;o00000_ooool2o`00063ooooo000Looooo`;o0000HOooool2o`0000cooooo0_l00000
0ooooooo0000o`000008ooooo`;o00002oooool2o`0000Cooooo0_l0000<ooooo`;o00004?ooool2
o`0000[ooooo0_l0000:ooooo`Ko000000Coooooo`000?l0003o00001_ooool2o`0000;ooooo1Ol0
0004ooooo`;o0000I?ooool001cooooo00?o0000ooooooooool0H?ooool2o`0000_ooooo1_l00002
ooooo`;o00004Oooool2o`0000Cooooo0_l00006ooooo`;o00002_ooool2o`0000?ooooo0_l00000
1?oooooo0000o`000?l0000Iooooo`Oo000000?oooooo`000?l000000_l00004ooooo`Go00000_oo
ool2o`0000gooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o00002oooool4
o`0000Cooooo1?l0000Iooooo`;o00000_ooool2o`0000Sooooo1?l000000ooooooo0000o`000002
o`000003ooooool0003o000000?o00004_ooool2o`0000?ooooo0_l00003ooooo`;o000000?ooooo
o`000?l000000_l00004ooooo`Go00004Oooool2o`0005_ooooo000Looooo`03o`000?oooooooooo
07Oooooo0_l0000Iooooo`;o00003?ooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`00
01;ooooo1?l000001?oooooo0000o`000?l00002ooooo`Co00001oooool2o`000003ooooool0003o
000000Wooooo0_l0001Sooooo`007?ooool00ol0003oooooooooo`1kooooo`;o00008oooool2o`00
00Oooooo0_l00009ooooo`;o00003Oooool6o`0000;ooooo1?l0000Eooooo`;o0000Hoooool001co
oooo00?o0000ooooooooool0Goooool2o`0001Oooooo0_l000000ooooooo0000o`00000;ooooo`;o
00004_ooool2o`0001Gooooo0ol00008ooooo`;o00001Oooool2o`000004ooooool0003o0000oooo
o`;o00000_ooool2o`00017ooooo0_l0001Uooooo`007?ooool00ol0003oooooooooo`1Oooooo`;o
00005oooool7o`0000Wooooo0_l0000Booooo`;o00001Oooool2o`0000Cooooo0_l000000ooooooo
0000o`000005ooooo`?o00002?ooool2o`0000?ooooo1?l000000ooooooo0000o`000003ooooo`Co
00001_ooool2o`000003ooooool0003o000000Kooooo0_l0001Uooooo`007?ooool00ol0003ooooo
ooooo`1Hooooo`;o00001oooool2o`0001Kooooo1ol00006ooooo`Co00003oooool2o`0000Gooooo
0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000001_ooool2o`0000?ooooo
0_l00008ooooo`;o00002?ooool4o`0000Kooooo0_l000000ooooooo0000o`00001]ooooo`007?oo
ool00ol0003oooooooooo`1Hooooo`;o00001oooool2o`0001Kooooo1?l000000ooooooo0000o`00
0006ooooo`?o00001?ooool2o`0000?ooooo0_l00005ooooo`;o00001Oooool2o`0000_ooooo0_l0
0007ooooo`Ko00000oooool2o`0000kooooo0_l00009ooooo`;o0000KOooool001cooooo00?o0000
ooooooooool0Poooool2o`0000Sooooo0_l00003ooooo`;o00003oooool2o`0000Sooooo0_l00007
ooooo`Oo00000_ooool2o`0008Sooooo000Looooo`03o`000?oooooooooo07?ooooo0_l00007oooo
o`;o00001Oooool4o`0000;ooooo0_l0000<ooooo`Co00000oooool2o`000003ooooool0003o0000
00;o00001Oooool2o`0000Kooooo0_l00004ooooo`;o000000?oooooo`000?l000001Oooool4o`00
00Wooooo0_l0001hooooo`007?ooool00ol0003oooooooooo`1_ooooo`;o00000_ooool2o`0000Oo
oooo0_l00005ooooo`Co00000_ooool2o`0000;ooooo1?l00005ooooo`Ko00000_ooool5o`0000Oo
oooo0_l00005ooooo`?o00001?ooool2o`0000Cooooo0_l00002ooooo`Co00002Oooool2o`0007So
oooo000Looooo`03o`000?oooooooooo06Wooooo0_l00004ooooo`;o00002Oooool2o`0000cooooo
0_l00003ooooo`Co00001Oooool2o`0000;ooooo0_l00003ooooo`Co00003_ooool4o`0000?ooooo
0_l00004ooooo`;o00003Oooool2o`0000Oooooo0_l0001aooooo`007?ooool00ol0003ooooooooo
o`1Yooooo`;o00003oooool2o`000004ooooool0003o0000o`0000Sooooo0_l0000@ooooo`;o0000
00?oooooo`000?l000000_l0000Booooo`;o00000oooool2o`0001?ooooo0_l00005ooooo`Co0000
2Oooool2o`0006Kooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1mooooo`Co000000?oooooo`00
0?l000002Oooool2o`0000kooooo0_l00002ooooo`;o00001Oooool2o`0000Gooooo0_l00003oooo
o`?o00003Oooool2o`0000kooooo0_l00004ooooo`;o00001Oooool2o`0006Kooooo00001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_oo
ool00ol0003oooooooooo`1`ooooo`;o00001oooool2o`0000;ooooo1?l000000ooooooo0000o`00
0009ooooo`;o00004Oooool3o`000003ooooool0003o000000;ooooo0_l00005ooooo`So00003Ooo
ool2o`0001Cooooo0_l0001]ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`1`ooooo`;o000000?o
ooooo`000?l000000_l00002ooooo`;o00000_ooool2o`0000?ooooo0ol00005ooooo`?o00000ooo
ool2o`0000;ooooo0_l0000:ooooo`;o00000_ooool2o`0000_ooooo1?l00008ooooo`?o000000?o
ooooo`000?l000002Oooool2o`0007_ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000Loooool6o`0000[ooooo0_l0
0005ooooo`?o00000oooool8o`0001Gooooo0_l0000>ooooo`?o000000?oooooo`000?l000002Ooo
ool2o`0007_ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Goc<c<
o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo073ooooo0_l00005ooooo`;o00004?oo
ool2o`0000Oooooo0_l000001?oooooo0000o`000?l0000Booooo`;o000000Coooooo`000?l0003o
oooo1?l0000Cooooo`;o0000P?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool0
2Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0Joooool2o`0000?o
oooo0_l0000Gooooo`Co00002?ooool2o`0001?ooooo0_l00004ooooo`Co00004oooool2o`0000?o
oooo0_l0000>ooooo`;o0000Joooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0
003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0Joooool2o`0000Wooooo0_l0000C
ooooo`;o00008oooool2o`0001[ooooo0_l00007ooooo`;o00000_ooool5o`0006_ooooo00001_oo
ooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`00
0?oooooooooo07Kooooo0_l0000<ooooo`;o00001?ooool2o`0004Sooooo0ol00002ooooo`?o0000
KOooool001cooooo00?o0000ooooooooool0Q?ooool2o`0000Cooooo0_l000000ooooooo0000o`00
000Tooooo`;o00002Oooool2o`0001Cooooo0_l0001cooooo`007?ooool00ol0003oooooooooo`1^
ooooo`;o00002?ooool4o`00017ooooo0_l0000Tooooo`?o00002?ooool2o`0000Kooooo0_l00021
ooooo`007?ooool00ol0003oooooooooo`1^ooooo`;o00002?ooool4o`0000kooooo1?l0000Voooo
o`;o00004?ooool2o`00087ooooo000Looooo`03o`000?oooooooooo08Cooooo0_l00004ooooo`Co
0000^oooool001cooooo00?o0000ooooooooool0Q?ooool2o`000<?ooooo000Looooo`03o`000?oo
oooooooo08Wooooo0_l0002nooooo`007?ooool00ol0003oooooooooo`1mooooo`;o00002_ooool2
o`000;kooooo000Looooo`03o`000?oooooooooo07gooooo0_l00012ooooo`;o00002?ooool2o`00
07cooooo000Looooo`03o`000?oooooooooo0;gooooo0_l00002ooooo`;o00002?ooool2o`0007co
oooo000Looooo`03o`000?oooooooooo0;Kooooo0_l00005ooooo`;o0000R_ooool001cooooo00?o
0000ooooooooool0Roooool2o`0000Kooooo0_l0000Nooooo`;o000000?oooooo`000?l00000TOoo
ool001cooooo0_l0002<ooooo`;o00001_ooool2o`000004ooooool0003o0000o`0001[ooooo0_l0
002Dooooo`007?ooool00ol0003oooooooooo`1looooo`;o00006?ooool3o`000;3ooooo000Loooo
o`03o`000?oooooooooo07cooooo0_l0000Hooooo`;o0000/Oooool001cooooo00?o0000oooooooo
ool0O?ooool4o`0001Kooooo0_l0000@ooooo`;o0000Woooool001cooooo00?o0000ooooooooool0
O_ooool2o`00023ooooo0_l000000ooooooo0000o`000003ooooo`;o00001_ooool2o`0009Oooooo
000Looooo`03o`000?oooooooooo0:3ooooo0_l000000ooooooo0000o`00000;ooooo`;o0000Uooo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0:Sooooo0_l0002Oooooo`007?oo
ool00ol0003oooooooooo`2Xooooo`;o0000Woooool001cooooo0_l0002Iooooo`;o0000[oooool0
01cooooo00?o0000ooooooooool0V?ooool2o`000:oooooo000Looooo`03o`000?oooooooooo0:[o
oooo0_l0002Mooooo`007?ooool00ol0003oooooooooo`2Zooooo`;o00001Oooool2o`0009Kooooo
000Looooo`03o`000?oooooooooo0;7ooooo0_l0002Fooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001;ooooo1?l00000
0ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Go
oooo0ol0003ooooood[ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o
0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Doooo
o`03o`000?oooooooooo0?ooooooD_ooool001;ooooo00?oEEEEofIVI_l00000oooooomDooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00YOooool01?l@413o0000o`000?ooool2
o`000003oa0@4?oooooooooo01Gooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c003ooooo`05oiRHV?l@
413o0000oc8b<_o<c<`01Oooool2o`000003oa0@4?oooooooooo08kooooo002Vooooo`05o`000?oo
ooooooooooooool000002Oooool6o`0000Wooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@03ooooo`05
oa0@4?nj^[[oooooogMgMolb<S801_ooool00ol0003oooooooooo`2?ooooo`00Y_ooool01Ol0003o
oooooooooooooooo000001Sooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oooooo
ooooooooo`Go0000T?ooool00:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00002Ooo
ool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?oZJVYoa0@4?ooool00_ooool01?m4A4CogMgM
ooooool0002Aooooo`00Y_ooool01Ol0003oQhN7oooooonYZJWo000001Sooooo00Goc<c<o`000?l0
003o0000olc<c005ooooo`03oa0@4?l0003o^[Zj00?ooooo00CogMgMoeEEEOoooooo0000TOooool0
0:Gooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Fooooo`05oa0@4?nj^[[ooooo
okZj^_l@41001_ooool00onj^[[o8B4Qooooo`03ooooo`03ogMgMoo<c<co0000097ooooo0033oooo
o`05o`000?nj^[[ooooookZj^_l000000oooool01Ol@413oV9RHoooooonj^[[o000000Cooooo00?o
k^k^odA4A?l00000TOooool00<?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05ojVYZOl@
413o0000oa0@4?nYZJT01Oooool00omgMgOo0000ooooo`2@ooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(840) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.48303 .6772 Mdot
.46064 .6922 Mdot
.61526 .42377 Mdot
.32899 .47652 Mdot
.45823 .54516 Mdot
.64155 .44228 Mdot
.61476 .58754 Mdot
.60855 .5599 Mdot
.65941 .44466 Mdot
.26023 .46039 Mdot
.57925 .59155 Mdot
.33307 .535 Mdot
.60663 .60159 Mdot
.35837 .4931 Mdot
.70573 .23929 Mdot
.3073 .47413 Mdot
.42177 .67011 Mdot
.54808 .30324 Mdot
.42502 .52387 Mdot
.65805 .39601 Mdot
.46081 .74244 Mdot
.36098 .49776 Mdot
.4823 .66856 Mdot
.35944 .49291 Mdot
.33775 .45476 Mdot
.45054 .66984 Mdot
.42414 .64757 Mdot
.36439 .43915 Mdot
.35726 .46549 Mdot
.57315 .58146 Mdot
.48451 .3808 Mdot
.56295 .17392 Mdot
.30589 .49869 Mdot
.23059 .6687 Mdot
.61163 .56413 Mdot
.30117 .28792 Mdot
.6749 .42324 Mdot
.59299 .61939 Mdot
.60557 .56034 Mdot
.63007 .58822 Mdot
.59597 .61641 Mdot
.44645 .67641 Mdot
.63525 .56968 Mdot
.64953 .57594 Mdot
.32671 .49557 Mdot
.60464 .71221 Mdot
.42158 .24563 Mdot
.38814 .45835 Mdot
.45591 .70814 Mdot
.6724 .40128 Mdot
.35345 .77693 Mdot
.62314 .56234 Mdot
.77058 .50465 Mdot
.51397 .08463 Mdot
.61025 .61344 Mdot
.3231 .48268 Mdot
.65796 .42468 Mdot
.38655 .5011 Mdot
.37026 .49202 Mdot
.35223 .74237 Mdot
.36408 .44573 Mdot
.55561 .33591 Mdot
.47873 .72357 Mdot
.65133 .47083 Mdot
.64887 .44303 Mdot
.58824 .5645 Mdot
.42387 .68167 Mdot
.60457 .59306 Mdot
.40015 .43343 Mdot
.68347 .42797 Mdot
.38921 .45906 Mdot
.57754 .59864 Mdot
.47407 .71289 Mdot
.4132 .50051 Mdot
.6265 .73547 Mdot
.76691 .31354 Mdot
.534 .29554 Mdot
.33676 .71336 Mdot
.3896 .67906 Mdot
.7848 .39244 Mdot
.35963 .47736 Mdot
.82714 .63265 Mdot
.72153 .25534 Mdot
.48008 .67295 Mdot
.42856 .55127 Mdot
.68719 .38853 Mdot
.39209 .51886 Mdot
.50535 .45952 Mdot
.36838 .42063 Mdot
.568 .78826 Mdot
.66415 .44169 Mdot
.43661 .69048 Mdot
.3306 .47921 Mdot
.40466 .45785 Mdot
.30255 .62535 Mdot
.42369 .47306 Mdot
.34776 .43832 Mdot
.4122 .69479 Mdot
.58882 .57151 Mdot
.29039 .47125 Mdot
.62355 .5388 Mdot
.78436 .52525 Mdot
.35085 .5144 Mdot
.67418 .44776 Mdot
.42337 .71405 Mdot
.36361 .52441 Mdot
.62414 .59689 Mdot
.37138 .45838 Mdot
.64129 .57589 Mdot
.45989 .69815 Mdot
.40902 .465 Mdot
.55516 .31008 Mdot
.66861 .7482 Mdot
.4319 .68274 Mdot
.79559 .61451 Mdot
.37647 .44996 Mdot
.36668 .50335 Mdot
.45844 .691 Mdot
.63185 .41829 Mdot
.50481 .4227 Mdot
.43242 .71092 Mdot
.62471 .57817 Mdot
.45206 .63478 Mdot
.44542 .47886 Mdot
.64881 .45425 Mdot
.77777 .52915 Mdot
.75589 .52114 Mdot
.36328 .35393 Mdot
.38014 .52176 Mdot
.54509 .67001 Mdot
.63473 .43644 Mdot
.44196 .69064 Mdot
.60188 .595 Mdot
.31496 .46651 Mdot
.44129 .64923 Mdot
.58635 .59549 Mdot
.56484 .33049 Mdot
.55997 .26041 Mdot
.44677 .71398 Mdot
.53414 .57676 Mdot
.60703 .63899 Mdot
.62973 .59212 Mdot
.26605 .71495 Mdot
.46424 .68853 Mdot
.52948 .33361 Mdot
.59071 .59069 Mdot
.46618 .29406 Mdot
.32356 .45196 Mdot
.31482 .37828 Mdot
.71238 .76383 Mdot
.34394 .77779 Mdot
.71624 .6334 Mdot
.52264 .31827 Mdot
.62786 .6081 Mdot
.34326 .46534 Mdot
.46682 .67967 Mdot
.45777 .67779 Mdot
.3748 .43153 Mdot
.33805 .449 Mdot
.40173 .46814 Mdot
.39757 .45068 Mdot
.47101 .23534 Mdot
.40122 .46129 Mdot
.5924 .43241 Mdot
.43322 .66891 Mdot
.34963 .45131 Mdot
.63185 .40938 Mdot
.32224 .51233 Mdot
.58499 .61108 Mdot
.3736 .49831 Mdot
.3277 .45943 Mdot
.4217 .50714 Mdot
.60812 .61954 Mdot
.51493 .18492 Mdot
.6987 .76512 Mdot
.34528 .22501 Mdot
.74828 .63029 Mdot
.64602 .41833 Mdot
.37359 .51743 Mdot
.54215 .33894 Mdot
.28959 .54156 Mdot
.36997 .48225 Mdot
.40883 .81463 Mdot
.33396 .44762 Mdot
.20883 .58259 Mdot
.44119 .43205 Mdot
.34611 .21755 Mdot
.55743 .43291 Mdot
.35977 .45974 Mdot
.27962 .58727 Mdot
.21585 .47028 Mdot
.46991 .59235 Mdot
.6009 .61596 Mdot
.62888 .4146 Mdot
.66701 .42632 Mdot
.63431 .60964 Mdot
.30161 .44535 Mdot
.31347 .41067 Mdot
.28611 .49842 Mdot
.77118 .52543 Mdot
.47542 .71413 Mdot
.54577 .35969 Mdot
.46397 .71218 Mdot
.85324 .55512 Mdot
.53546 .78592 Mdot
.60905 .64213 Mdot
.51389 .31267 Mdot
.61775 .42502 Mdot
.76747 .52504 Mdot
.53592 .33436 Mdot
.38878 .47263 Mdot
.44898 .70764 Mdot
.19508 .54043 Mdot
.45032 .45019 Mdot
.1748 .49541 Mdot
.45753 .64076 Mdot
.52976 .44688 Mdot
.59152 .6038 Mdot
.64896 .39133 Mdot
.35235 .5038 Mdot
.40525 .48415 Mdot
.45579 .73472 Mdot
.38664 .45989 Mdot
.41586 .61043 Mdot
.32464 .46313 Mdot
.69383 .40161 Mdot
.55156 .29619 Mdot
.63615 .59857 Mdot
.35948 .35798 Mdot
.48969 .68486 Mdot
.70303 .47183 Mdot
.66955 .40422 Mdot
.25863 .50501 Mdot
.5773 .59297 Mdot
.55648 .31314 Mdot
.65575 .40142 Mdot
.52513 .35103 Mdot
.38033 .52732 Mdot
.6768 .42342 Mdot
.52849 .3446 Mdot
.50303 .21558 Mdot
.32142 .49077 Mdot
.48501 .25292 Mdot
.61016 .58263 Mdot
.45769 .63407 Mdot
.36225 .44559 Mdot
.75523 .52518 Mdot
.37784 .53387 Mdot
.69497 .59033 Mdot
.76337 .50553 Mdot
.78199 .50934 Mdot
.76708 .35333 Mdot
.54141 .30762 Mdot
.68541 .67949 Mdot
.52144 .70388 Mdot
.42294 .68317 Mdot
.32853 .48593 Mdot
.42274 .17358 Mdot
.59078 .5916 Mdot
.38656 .47464 Mdot
.68966 .3927 Mdot
.59331 .58857 Mdot
.39046 .50481 Mdot
.61846 .61465 Mdot
.46251 .68023 Mdot
.72804 .39136 Mdot
.42802 .65304 Mdot
.31973 .48364 Mdot
.62205 .59346 Mdot
.65938 .40764 Mdot
.45389 .66741 Mdot
.3724 .46204 Mdot
.35917 .50735 Mdot
.77287 .51912 Mdot
.35449 .45559 Mdot
.43207 .17703 Mdot
.37675 .44384 Mdot
.62812 .45615 Mdot
.41619 .45822 Mdot
.35875 .80584 Mdot
.5936 .28679 Mdot
.4267 .6908 Mdot
.77531 .50702 Mdot
.65865 .43972 Mdot
.71448 .34644 Mdot
.50711 .58243 Mdot
.36487 .46859 Mdot
.77786 .5121 Mdot
.52423 .4134 Mdot
.5797 .568 Mdot
.42947 .48262 Mdot
.57204 .76947 Mdot
.64716 .39824 Mdot
.76908 .52349 Mdot
.42058 .53833 Mdot
.42303 .7142 Mdot
.32845 .474 Mdot
.67031 .41107 Mdot
.45109 .63424 Mdot
.33478 .51676 Mdot
.36147 .27357 Mdot
.7556 .51167 Mdot
.60991 .58408 Mdot
.37258 .40134 Mdot
.39814 .46139 Mdot
.66329 .41813 Mdot
.47793 .6586 Mdot
.61266 .56745 Mdot
.44247 .67028 Mdot
.20228 .49897 Mdot
.74279 .64538 Mdot
.44189 .2281 Mdot
.51323 .31124 Mdot
.70488 .55627 Mdot
.32082 .23906 Mdot
.69676 .68925 Mdot
.41939 .32482 Mdot
.21063 .34573 Mdot
.64143 .4044 Mdot
.54151 .27699 Mdot
.65648 .43458 Mdot
.3409 .47824 Mdot
.64514 .44411 Mdot
.34635 .21253 Mdot
.33243 .44766 Mdot
.65066 .41815 Mdot
.67468 .35275 Mdot
.34811 .44454 Mdot
.43047 .67788 Mdot
.67994 .23201 Mdot
.58191 .80653 Mdot
.46477 .77963 Mdot
.63955 .41584 Mdot
.3927 .74726 Mdot
.36008 .4401 Mdot
.31454 .50869 Mdot
.46795 .6744 Mdot
.41991 .46043 Mdot
.55249 .35794 Mdot
.52573 .35405 Mdot
.34588 .37035 Mdot
.77466 .66823 Mdot
.28815 .46148 Mdot
.45732 .668 Mdot
.39318 .61602 Mdot
.62208 .73488 Mdot
.77581 .53797 Mdot
.56415 .6069 Mdot
.52676 .19038 Mdot
.30366 .43089 Mdot
.53079 .58611 Mdot
.59172 .76072 Mdot
.44491 .70179 Mdot
.46572 .19647 Mdot
.60708 .61252 Mdot
.31772 .58667 Mdot
.2402 .63452 Mdot
.39944 .47803 Mdot
.57844 .58178 Mdot
.2988 .50212 Mdot
.53296 .8029 Mdot
.49164 .27838 Mdot
.83712 .45983 Mdot
.32333 .4918 Mdot
.67454 .68925 Mdot
.36906 .50085 Mdot
.42575 .37847 Mdot
.37822 .44333 Mdot
.44551 .66427 Mdot
.28911 .52156 Mdot
.50206 .51777 Mdot
.75336 .71106 Mdot
.52113 .79052 Mdot
.52053 .3239 Mdot
.36029 .50559 Mdot
.40114 .48058 Mdot
.54072 .31244 Mdot
.46118 .65668 Mdot
.38258 .44533 Mdot
.33263 .32439 Mdot
.39984 .4693 Mdot
.58739 .61555 Mdot
.48942 .39166 Mdot
.40474 .71084 Mdot
.41796 .47991 Mdot
.42205 .65927 Mdot
.61363 .61543 Mdot
.5926 .56017 Mdot
.41669 .43937 Mdot
.62434 .61253 Mdot
.32671 .47347 Mdot
.49223 .36145 Mdot
.47719 .68319 Mdot
.46232 .4812 Mdot
.46141 .65297 Mdot
.39242 .72253 Mdot
.62346 .60761 Mdot
.76289 .5305 Mdot
.51183 .63002 Mdot
.60938 .6077 Mdot
.44533 .78201 Mdot
.28028 .46593 Mdot
.38435 .53851 Mdot
.50703 .80655 Mdot
.64314 .40974 Mdot
.76489 .52871 Mdot
.62342 .58939 Mdot
.3999 .46358 Mdot
.42669 .50959 Mdot
.5792 .61521 Mdot
.33114 .63632 Mdot
.70356 .33774 Mdot
.35983 .43756 Mdot
.45039 .65995 Mdot
.44076 .68784 Mdot
.34435 .52433 Mdot
.37275 .46988 Mdot
.62426 .44858 Mdot
.76469 .50898 Mdot
.78829 .52918 Mdot
.75699 .52191 Mdot
.64892 .38709 Mdot
.64017 .66341 Mdot
.63015 .58974 Mdot
.57272 .68095 Mdot
.68189 .57724 Mdot
.43798 .43968 Mdot
.66065 .41396 Mdot
.4029 .49473 Mdot
.34039 .49297 Mdot
.61258 .56814 Mdot
.73373 .58864 Mdot
.43992 .53466 Mdot
.46817 .70245 Mdot
.62219 .61555 Mdot
.28717 .43991 Mdot
.63284 .64413 Mdot
.5459 .35513 Mdot
.46274 .78298 Mdot
.57626 .58742 Mdot
.43546 .69647 Mdot
.58494 .62388 Mdot
.4017 .47686 Mdot
.34992 .43137 Mdot
.45399 .69645 Mdot
.53678 .3064 Mdot
.43778 .49361 Mdot
.38924 .50635 Mdot
.47927 .86381 Mdot
.63095 .7324 Mdot
.55207 .59592 Mdot
.35052 .465 Mdot
.42176 .52157 Mdot
.51729 .32352 Mdot
.39753 .46919 Mdot
.35543 .50811 Mdot
.67397 .74978 Mdot
.59992 .53778 Mdot
.56579 .31444 Mdot
.31895 .58471 Mdot
.4548 .64104 Mdot
.46821 .17591 Mdot
.7866 .52318 Mdot
.62035 .54889 Mdot
.72855 .39728 Mdot
.76236 .52123 Mdot
.69207 .56868 Mdot
.46866 .18678 Mdot
.75903 .5244 Mdot
.72311 .44383 Mdot
.37247 .56328 Mdot
.36028 .43378 Mdot
.37639 .50189 Mdot
.54449 .34332 Mdot
.46474 .68621 Mdot
.54528 .4384 Mdot
.55047 .2351 Mdot
.36276 .4998 Mdot
.49956 .69758 Mdot
.52707 .20716 Mdot
.76917 .51941 Mdot
.55984 .33333 Mdot
.56104 .36064 Mdot
.36957 .50453 Mdot
.70165 .71679 Mdot
.45242 .66996 Mdot
.37217 .46249 Mdot
.41232 .47671 Mdot
.64274 .41381 Mdot
.43985 .70421 Mdot
.67209 .40646 Mdot
.75753 .50773 Mdot
.21457 .39238 Mdot
.44659 .85387 Mdot
.6074 .56918 Mdot
.37676 .21735 Mdot
.59024 .55744 Mdot
.80826 .40012 Mdot
.75819 .51665 Mdot
.36615 .4793 Mdot
.48843 .69272 Mdot
.37296 .45733 Mdot
.3911 .48107 Mdot
.39042 .47356 Mdot
.28341 .47469 Mdot
.40307 .81331 Mdot
.54058 .3262 Mdot
.44648 .46053 Mdot
.64227 .46145 Mdot
.4101 .19387 Mdot
.68293 .24841 Mdot
.40668 .49901 Mdot
.36947 .5082 Mdot
.43119 .66437 Mdot
.38208 .43288 Mdot
.5702 .58452 Mdot
.48005 .66021 Mdot
.41946 .51604 Mdot
.45303 .20227 Mdot
.38627 .44683 Mdot
.31719 .24755 Mdot
.58357 .62247 Mdot
.45485 .77846 Mdot
.44239 .45645 Mdot
.75882 .5258 Mdot
.76415 .52839 Mdot
.79089 .53561 Mdot
.56762 .59725 Mdot
.65675 .41729 Mdot
.64762 .25032 Mdot
.30044 .45996 Mdot
.34032 .46397 Mdot
.42422 .51921 Mdot
.61844 .39493 Mdot
.49761 .45151 Mdot
.7017 .65334 Mdot
.28471 .44677 Mdot
.62934 .44973 Mdot
.46427 .63463 Mdot
.81274 .57619 Mdot
.47959 .66077 Mdot
.56488 .31229 Mdot
.58065 .59887 Mdot
.55227 .35521 Mdot
.4042 .78559 Mdot
.46043 .6956 Mdot
.45076 .73391 Mdot
.64787 .41762 Mdot
.54463 .47284 Mdot
.45449 .11377 Mdot
.68255 .44455 Mdot
.36061 .3327 Mdot
.46705 .66946 Mdot
.41964 .49216 Mdot
.51876 .40559 Mdot
.53927 .47393 Mdot
.64806 .42721 Mdot
.35653 .48438 Mdot
.75104 .69123 Mdot
.6224 .44538 Mdot
.43034 .48736 Mdot
.63005 .43201 Mdot
.58949 .61156 Mdot
.63275 .43299 Mdot
.48886 .67 Mdot
.3646 .52269 Mdot
.49718 .09701 Mdot
.59887 .49577 Mdot
.36654 .44828 Mdot
.62198 .61561 Mdot
.30681 .32977 Mdot
.39244 .48927 Mdot
.55741 .35696 Mdot
.64414 .45515 Mdot
.67956 .31568 Mdot
.36305 .4412 Mdot
.63934 .43146 Mdot
.48514 .677 Mdot
.59062 .55041 Mdot
.77378 .35154 Mdot
.77779 .53271 Mdot
.47099 .68073 Mdot
.79199 .50815 Mdot
.58429 .63204 Mdot
.42649 .49909 Mdot
.40855 .47224 Mdot
.43896 .66485 Mdot
.75735 .45324 Mdot
.39571 .44072 Mdot
.35963 .47756 Mdot
.61947 .41439 Mdot
.60931 .42502 Mdot
.75183 .41848 Mdot
.64352 .4047 Mdot
.43125 .51398 Mdot
.43929 .66547 Mdot
.33749 .48645 Mdot
.4288 .68067 Mdot
.32878 .48469 Mdot
.47711 .62631 Mdot
.47881 .67355 Mdot
.76058 .64971 Mdot
.34581 .48718 Mdot
.41018 .40902 Mdot
.39227 .47767 Mdot
.39255 .46233 Mdot
.65536 .45801 Mdot
.54462 .31836 Mdot
.35309 .41935 Mdot
.65535 .48482 Mdot
.5625 .33616 Mdot
.21119 .50045 Mdot
.64045 .41343 Mdot
.54817 .34774 Mdot
.49023 .2437 Mdot
.78034 .50944 Mdot
.54515 .33372 Mdot
.67031 .24114 Mdot
.60915 .56863 Mdot
.46364 .6389 Mdot
.34714 .4452 Mdot
.20022 .3784 Mdot
.48476 .36743 Mdot
.77394 .51434 Mdot
.37184 .44578 Mdot
.39998 .49403 Mdot
.41963 .70277 Mdot
.84705 .58581 Mdot
.61343 .42348 Mdot
.33619 .47283 Mdot
.42495 .66243 Mdot
.74176 .7425 Mdot
.66612 .45447 Mdot
.54514 .33756 Mdot
.58729 .62014 Mdot
.41596 .64901 Mdot
.77866 .53312 Mdot
.57815 .56849 Mdot
.71402 .39542 Mdot
.41826 .78939 Mdot
.37971 .44926 Mdot
.66689 .41594 Mdot
.34948 .78316 Mdot
.29545 .45616 Mdot
.54205 .60934 Mdot
.31092 .39453 Mdot
.44209 .7 Mdot
.58249 .6167 Mdot
.52984 .35226 Mdot
.4827 .66151 Mdot
.45974 .65779 Mdot
.61597 .56261 Mdot
.61807 .38304 Mdot
.5304 .45111 Mdot
.58065 .61051 Mdot
.58071 .78249 Mdot
.19902 .52827 Mdot
.77302 .50947 Mdot
.55673 .32223 Mdot
.19519 .60787 Mdot
.44597 .67572 Mdot
.52428 .18946 Mdot
.38549 .79918 Mdot
.3482 .43822 Mdot
.53414 .3462 Mdot
.6684 .62429 Mdot
.62669 .23945 Mdot
.59637 .58538 Mdot
.49529 .49264 Mdot
.57019 .34895 Mdot
.37136 .43673 Mdot
.4464 .76032 Mdot
.34837 .48108 Mdot
.58478 .60218 Mdot
.39409 .70077 Mdot
.4336 .69455 Mdot
.58924 .63368 Mdot
.45514 .78585 Mdot
.34147 .49565 Mdot
.35083 .4852 Mdot
.44662 .36697 Mdot
.45069 .70837 Mdot
.78604 .53155 Mdot
.36661 .45971 Mdot
.38393 .50137 Mdot
.42395 .49852 Mdot
.33203 .40919 Mdot
.68227 .72701 Mdot
.33683 .47535 Mdot
.67612 .39576 Mdot
.34457 .52996 Mdot
.34926 .48931 Mdot
.42051 .66791 Mdot
.44541 .8464 Mdot
.75267 .51849 Mdot
.37674 .49879 Mdot
.38385 .44829 Mdot
.61646 .56587 Mdot
.52975 .42965 Mdot
.53885 .48065 Mdot
.68124 .43836 Mdot
.4348 .30269 Mdot
.28414 .47768 Mdot
.44701 .64553 Mdot
.56288 .3197 Mdot
.40236 .5178 Mdot
.43681 .65126 Mdot
.31106 .49353 Mdot
.62387 .44487 Mdot
.76894 .50921 Mdot
.49902 .76274 Mdot
.55108 .33566 Mdot
.54851 .39258 Mdot
.56507 .69998 Mdot
.6279 .41359 Mdot
.33957 .45947 Mdot
.61005 .5494 Mdot
.67999 .42785 Mdot
.775 .51889 Mdot
.43902 .52454 Mdot
.45857 .67477 Mdot
.4339 .68635 Mdot
.37187 .3672 Mdot
.65084 .47815 Mdot
.59376 .83233 Mdot
.58851 .61045 Mdot
.37546 .53041 Mdot
.53039 .68585 Mdot
.43294 .68529 Mdot
.36704 .36514 Mdot
.54966 .34756 Mdot
.59809 .58396 Mdot
.77776 .54051 Mdot
.43484 .65543 Mdot
.44742 .71192 Mdot
.32552 .49961 Mdot
.39582 .51188 Mdot
.41041 .32882 Mdot
.34638 .36916 Mdot
.60568 .61886 Mdot
.54903 .3137 Mdot
.68311 .41588 Mdot
.34452 .4763 Mdot
.48082 .67197 Mdot
.20713 .56034 Mdot
.39392 .45182 Mdot
.62368 .44856 Mdot
.44499 .69911 Mdot
.54037 .31102 Mdot
.56153 .34983 Mdot
.39273 .46292 Mdot
.34947 .72983 Mdot
.6165 .60105 Mdot
.43107 .68265 Mdot
.48922 .73777 Mdot
.40159 .44365 Mdot
.38988 .51567 Mdot
.36582 .54713 Mdot
.58457 .56508 Mdot
.46928 .76974 Mdot
.55874 .3099 Mdot
.45314 .68251 Mdot
.36922 .45055 Mdot
.5553 .33638 Mdot
.50245 .73626 Mdot
.76221 .51593 Mdot
.6316 .43574 Mdot
.55437 .35867 Mdot
.52885 .32002 Mdot
.56314 .33014 Mdot
.54004 .18909 Mdot
.47179 .716 Mdot
.40105 .60487 Mdot
.37723 .44196 Mdot
.38183 .36758 Mdot
.34017 .43009 Mdot
.5693 .60618 Mdot
.64525 .40729 Mdot
.39455 .48158 Mdot
.32665 .50117 Mdot
.35178 .39328 Mdot
.35965 .40822 Mdot
.47235 .7369 Mdot
.45455 .70315 Mdot
.38241 .4086 Mdot
.64668 .41099 Mdot
.84873 .61175 Mdot
.40329 .1563 Mdot
.4372 .45403 Mdot
.53942 .44737 Mdot
.48092 .66737 Mdot
.61923 .56369 Mdot
.5325 .49102 Mdot
.60043 .62665 Mdot
.44923 .68622 Mdot
.34252 .47688 Mdot
.57797 .68292 Mdot
.51548 .33274 Mdot
.40302 .46816 Mdot
.59119 .59977 Mdot
.40234 .46796 Mdot
.57058 .59571 Mdot
.45661 .60682 Mdot
.59784 .76489 Mdot
.33539 .44626 Mdot
.4164 .46297 Mdot
.36953 .39611 Mdot
.40471 .50123 Mdot
.80284 .48815 Mdot
.47013 .65876 Mdot
.76402 .67743 Mdot
.3326 .51363 Mdot
.36506 .70945 Mdot
.38196 .44025 Mdot
.74182 .47206 Mdot
.40086 .51194 Mdot
.52388 .52036 Mdot
.3596 .43534 Mdot
.36535 .5137 Mdot
.62185 .59845 Mdot
.61621 .56535 Mdot
.47973 .68907 Mdot
.78317 .53351 Mdot
.35717 .21519 Mdot
.38971 .51071 Mdot
.66874 .39051 Mdot
.53779 .58969 Mdot
.53406 .31618 Mdot
.44728 .68409 Mdot
.74196 .75146 Mdot
.61721 .6145 Mdot
.68602 .45223 Mdot
.76237 .4655 Mdot
.65193 .39296 Mdot
.61549 .53546 Mdot
.26815 .46953 Mdot
.53355 .3089 Mdot
.3766 .43757 Mdot
.23734 .67377 Mdot
.64534 .71123 Mdot
.43975 .49345 Mdot
.59853 .63198 Mdot
.32038 .56297 Mdot
.19901 .61098 Mdot
.55084 .36425 Mdot
.52248 .33827 Mdot
.61983 .60444 Mdot
.62546 .4029 Mdot
.29188 .50484 Mdot
.54986 .34863 Mdot
.62356 .42732 Mdot
.79294 .53038 Mdot
.49507 .57616 Mdot
.4508 .67293 Mdot
.47095 .77877 Mdot
.57176 .72828 Mdot
.60784 .61858 Mdot
.69062 .47649 Mdot
.4337 .6319 Mdot
.43089 .72051 Mdot
.77254 .53478 Mdot
.65495 .45852 Mdot
.49052 .6922 Mdot
.43429 .49634 Mdot
.43358 .42709 Mdot
.36797 .49933 Mdot
.5372 .34194 Mdot
.40884 .50105 Mdot
.64395 .45929 Mdot
.59676 .5892 Mdot
.67182 .43838 Mdot
.619 .59258 Mdot
.61847 .67988 Mdot
.37672 .46548 Mdot
.36863 .51319 Mdot
.49865 .378 Mdot
.46327 .70982 Mdot
.37872 .77942 Mdot
.66782 .38923 Mdot
.65827 .42873 Mdot
.33963 .49848 Mdot
.48628 .67108 Mdot
.56869 .30954 Mdot
.50918 .38214 Mdot
.41496 .48836 Mdot
.4709 .65868 Mdot
.33767 .46891 Mdot
.48963 .22991 Mdot
.61984 .75966 Mdot
.43963 .67308 Mdot
.78724 .66603 Mdot
.35182 .47024 Mdot
.38022 .56856 Mdot
.42425 .52032 Mdot
.36149 .31044 Mdot
.40387 .44459 Mdot
.4596 .64086 Mdot
.37205 .49683 Mdot
.47446 .65421 Mdot
.6247 .41068 Mdot
.62798 .5764 Mdot
.47255 .67757 Mdot
.41734 .49095 Mdot
.53108 .16772 Mdot
.58898 .60637 Mdot
.35842 .50494 Mdot
.58784 .57577 Mdot
.43565 .64662 Mdot
.46052 .70666 Mdot
.68042 .25547 Mdot
.56374 .56571 Mdot
.5927 .61256 Mdot
.3319 .46804 Mdot
.54269 .74755 Mdot
.33777 .48334 Mdot
.40449 .33515 Mdot
.33812 .51074 Mdot
.41176 .45201 Mdot
.79823 .34271 Mdot
.59954 .55332 Mdot
.61053 .82157 Mdot
.54334 .23401 Mdot
.5545 .18659 Mdot
.4095 .6562 Mdot
.55132 .36431 Mdot
.47536 .19414 Mdot
.76149 .50615 Mdot
.63598 .44677 Mdot
.39505 .4806 Mdot
.4107 .63071 Mdot
.58994 .61887 Mdot
.54111 .31892 Mdot
.33353 .44776 Mdot
.63008 .456 Mdot
.73099 .32676 Mdot
.6266 .61031 Mdot
.44643 .67729 Mdot
.46483 .7068 Mdot
.727 .74982 Mdot
.37106 .44886 Mdot
.36431 .50856 Mdot
.58153 .599 Mdot
.31237 .43245 Mdot
.55019 .30955 Mdot
.63714 .3459 Mdot
.59409 .61243 Mdot
.61188 .51331 Mdot
.46258 .69694 Mdot
.40148 .49381 Mdot
.49469 .44021 Mdot
.6386 .51382 Mdot
.24793 .53193 Mdot
.54246 .34132 Mdot
.42508 .33952 Mdot
.45886 .64074 Mdot
.59806 .59568 Mdot
.54093 .26571 Mdot
.37339 .53258 Mdot
.39642 .49681 Mdot
.42818 .34252 Mdot
.53061 .42187 Mdot
.58212 .3355 Mdot
.37441 .42916 Mdot
.52261 .41804 Mdot
.34202 .50338 Mdot
.42251 .51332 Mdot
.4164 .44694 Mdot
.38075 .5202 Mdot
.47453 .66059 Mdot
.33739 .39518 Mdot
.63657 .4361 Mdot
.30497 .61865 Mdot
.50188 .49146 Mdot
.35704 .44937 Mdot
.34164 .48032 Mdot
.25845 .52461 Mdot
.61427 .53039 Mdot
.4692 .66227 Mdot
.49252 .69606 Mdot
.62653 .59829 Mdot
.42374 .41651 Mdot
.62071 .39848 Mdot
.32196 .39205 Mdot
.67026 .4416 Mdot
.4706 .65723 Mdot
.66243 .42438 Mdot
.62697 .59102 Mdot
.66762 .41617 Mdot
.65299 .38724 Mdot
.57541 .61079 Mdot
.46787 .69502 Mdot
.41317 .49203 Mdot
.62495 .60644 Mdot
.44275 .36428 Mdot
.53848 .34325 Mdot
.68015 .25487 Mdot
.33838 .52692 Mdot
.47813 .46098 Mdot
.36364 .2726 Mdot
.67089 .43551 Mdot
.63485 .76246 Mdot
.47844 .67438 Mdot
.52061 .30551 Mdot
.47565 .65971 Mdot
.40156 .80305 Mdot
.54652 .31624 Mdot
.66749 .23909 Mdot
.59724 .36877 Mdot
.6963 .30413 Mdot
.36248 .42761 Mdot
.48974 .6304 Mdot
.67841 .41874 Mdot
.59254 .61972 Mdot
.62588 .37567 Mdot
.36401 .51751 Mdot
.70496 .68067 Mdot
.43709 .71812 Mdot
.79051 .52178 Mdot
.60463 .59485 Mdot
.60674 .63195 Mdot
.37692 .45175 Mdot
.7275 .37179 Mdot
.35549 .5204 Mdot
.57671 .30229 Mdot
.42807 .32119 Mdot
.31521 .39423 Mdot
.32634 .47654 Mdot
.67643 .44005 Mdot
.33698 .4681 Mdot
.33179 .56416 Mdot
.25911 .70729 Mdot
.39413 .54487 Mdot
.75339 .64284 Mdot
.5391 .37961 Mdot
.45754 .69447 Mdot
.43658 .44719 Mdot
.78147 .52178 Mdot
.35122 .46741 Mdot
.14438 .56921 Mdot
.54676 .33171 Mdot
.71452 .44085 Mdot
.39458 .44331 Mdot
.36966 .45714 Mdot
.28069 .70699 Mdot
.41941 .61786 Mdot
.77527 .54097 Mdot
.39133 .49742 Mdot
.45074 .30428 Mdot
.593 .56461 Mdot
.35236 .52371 Mdot
.37369 .50242 Mdot
.21234 .47235 Mdot
.58126 .57092 Mdot
.67096 .43114 Mdot
.76784 .50545 Mdot
.68333 .41388 Mdot
.57283 .35611 Mdot
.54338 .49812 Mdot
.32496 .37323 Mdot
.61921 .75725 Mdot
.56501 .35332 Mdot
.40807 .46583 Mdot
.43665 .54206 Mdot
.35953 .46804 Mdot
.52415 .344 Mdot
.57435 .58026 Mdot
.47476 .66784 Mdot
.50967 .75736 Mdot
.7716 .52405 Mdot
.4301 .489 Mdot
.53587 .35899 Mdot
.46456 .67738 Mdot
.67797 .48919 Mdot
.45677 .68799 Mdot
.60487 .60961 Mdot
.57108 .61629 Mdot
.55311 .32511 Mdot
.47421 .65764 Mdot
.68716 .41088 Mdot
.54908 .23741 Mdot
.334 .50335 Mdot
.56792 .63258 Mdot
.48683 .68424 Mdot
.41942 .65773 Mdot
.44711 .71894 Mdot
.3822 .46074 Mdot
.53366 .43814 Mdot
.41964 .51915 Mdot
.61813 .60912 Mdot
.62761 .43631 Mdot
.30175 .38507 Mdot
.28865 .72114 Mdot
.60754 .50676 Mdot
.36355 .42037 Mdot
.35201 .50047 Mdot
.36931 .50444 Mdot
.31836 .46568 Mdot
.55761 .2674 Mdot
.37455 .46853 Mdot
.62106 .59518 Mdot
.66098 .45142 Mdot
.367 .44498 Mdot
.78346 .52096 Mdot
.52163 .44881 Mdot
.56682 .32835 Mdot
.51838 .50389 Mdot
.47409 .16417 Mdot
.46584 .67642 Mdot
.6602 .40364 Mdot
.63727 .44568 Mdot
.56474 .32984 Mdot
.59821 .61919 Mdot
.46154 .68625 Mdot
.3735 .29728 Mdot
.55839 .32128 Mdot
.37676 .49766 Mdot
.7053 .38391 Mdot
.8008 .62472 Mdot
.38335 .43624 Mdot
.38432 .48367 Mdot
.77548 .50644 Mdot
.62376 .40069 Mdot
.16982 .41553 Mdot
.53504 .40782 Mdot
.54863 .32114 Mdot
.52354 .32639 Mdot
.4497 .72026 Mdot
.44225 .47723 Mdot
.61647 .59157 Mdot
.50993 .3976 Mdot
.3018 .34697 Mdot
.57451 .40192 Mdot
.80299 .39608 Mdot
.39325 .45621 Mdot
.28066 .6979 Mdot
.33163 .48372 Mdot
.42156 .70922 Mdot
.42427 .68592 Mdot
.46394 .66435 Mdot
.61393 .60956 Mdot
.38784 .70862 Mdot
.62051 .58877 Mdot
.44724 .15469 Mdot
.47623 .64942 Mdot
.61703 .27629 Mdot
.65692 .4211 Mdot
.32695 .43217 Mdot
.54088 .30928 Mdot
.63371 .5382 Mdot
.40406 .43567 Mdot
.6935 .71579 Mdot
.66137 .41445 Mdot
.46171 .70273 Mdot
.27439 .48962 Mdot
.2795 .26123 Mdot
.55291 .48062 Mdot
.43009 .57346 Mdot
.36714 .76975 Mdot
.54338 .31338 Mdot
.25555 .54043 Mdot
.53546 .30479 Mdot
.58895 .5921 Mdot
.36832 .51927 Mdot
.38511 .52108 Mdot
.32707 .48157 Mdot
.37639 .46831 Mdot
.61562 .57018 Mdot
.31644 .48882 Mdot
.35887 .80586 Mdot
.77276 .50798 Mdot
.49105 .21824 Mdot
.54934 .35266 Mdot
.58738 .62808 Mdot
.66457 .4479 Mdot
.78844 .53215 Mdot
.34203 .3629 Mdot
.35699 .43645 Mdot
.39298 .47947 Mdot
.76476 .53437 Mdot
.40725 .44028 Mdot
.28288 .45491 Mdot
.63817 .43691 Mdot
.5944 .5029 Mdot
.54973 .3615 Mdot
.55121 .35527 Mdot
.57429 .59629 Mdot
.47516 .6585 Mdot
.54761 .34524 Mdot
.61967 .41197 Mdot
.31539 .49296 Mdot
.41785 .50561 Mdot
.48638 .68518 Mdot
.38587 .79957 Mdot
.55095 .3657 Mdot
.27741 .49684 Mdot
.4664 .64569 Mdot
.45502 .72357 Mdot
.39353 .49528 Mdot
.38147 .54715 Mdot
.43335 .63753 Mdot
.56273 .35124 Mdot
.5896 .62904 Mdot
.65714 .27404 Mdot
.58632 .59855 Mdot
.46414 .68311 Mdot
.33615 .52026 Mdot
.46581 .69595 Mdot
.35434 .46219 Mdot
.8641 .38745 Mdot
.39406 .51732 Mdot
.55953 .8105 Mdot
.3704 .3154 Mdot
.64119 .44829 Mdot
.68575 .40945 Mdot
.78015 .5142 Mdot
.46612 .64457 Mdot
.3984 .51995 Mdot
.52518 .31739 Mdot
.58373 .20193 Mdot
.47263 .62662 Mdot
.62672 .44428 Mdot
.62345 .39754 Mdot
.57665 .57273 Mdot
.3882 .44296 Mdot
.40209 .49733 Mdot
.66919 .41823 Mdot
.3923 .25414 Mdot
.44508 .6485 Mdot
.36332 .50739 Mdot
.34993 .49607 Mdot
.64072 .44403 Mdot
.54775 .23909 Mdot
.46692 .61348 Mdot
.37256 .51881 Mdot
.53512 .37168 Mdot
.56844 .60012 Mdot
.3197 .46678 Mdot
.31584 .48617 Mdot
.52661 .33074 Mdot
.44334 .21232 Mdot
.21108 .64696 Mdot
.57417 .61396 Mdot
.78582 .53108 Mdot
.41912 .48613 Mdot
.655 .42146 Mdot
.41844 .4957 Mdot
.30821 .27394 Mdot
.78224 .51189 Mdot
.36906 .47454 Mdot
.43363 .45407 Mdot
.4326 .70089 Mdot
.37065 .46672 Mdot
.2278 .47551 Mdot
.68592 .43306 Mdot
.37021 .47122 Mdot
.36123 .74659 Mdot
.58654 .56564 Mdot
.43391 .44958 Mdot
.53614 .35454 Mdot
.35554 .31135 Mdot
.56889 .71008 Mdot
.61762 .39374 Mdot
.55523 .35206 Mdot
.41463 .49164 Mdot
.62867 .40107 Mdot
.59631 .62223 Mdot
.69134 .69846 Mdot
.34363 .43698 Mdot
.58618 .60348 Mdot
.59828 .58987 Mdot
.55278 .33049 Mdot
.64412 .80583 Mdot
.3549 .41645 Mdot
.40688 .49977 Mdot
.21935 .44172 Mdot
.42968 .70833 Mdot
.4109 .4945 Mdot
.40027 .45639 Mdot
.61193 .58099 Mdot
.51376 .63377 Mdot
.35209 .58157 Mdot
.67368 .35295 Mdot
.57016 .59661 Mdot
.60173 .40457 Mdot
.62986 .40066 Mdot
.5487 .35191 Mdot
.4511 .6957 Mdot
.5716 .34077 Mdot
.63748 .42039 Mdot
.38331 .44705 Mdot
.60322 .57852 Mdot
.23685 .56717 Mdot
.62028 .55953 Mdot
.64129 .46778 Mdot
.41446 .68399 Mdot
.53339 .69356 Mdot
.19515 .65968 Mdot
.58467 .71984 Mdot
.6355 .56991 Mdot
.53352 .31659 Mdot
.64693 .37063 Mdot
.35121 .49788 Mdot
.28507 .56856 Mdot
.40853 .47946 Mdot
.36155 .761 Mdot
.63672 .40931 Mdot
.773 .53557 Mdot
.36977 .51995 Mdot
.43216 .3291 Mdot
.62869 .61733 Mdot
.57702 .57124 Mdot
.37995 .47579 Mdot
.60877 .60866 Mdot
.39627 .50928 Mdot
.66264 .45314 Mdot
.59592 .81823 Mdot
.35484 .50265 Mdot
.40971 .53233 Mdot
.5683 .55333 Mdot
.67746 .25118 Mdot
.68921 .40678 Mdot
.27948 .69891 Mdot
.24824 .29308 Mdot
.60977 .60663 Mdot
.44257 .49989 Mdot
.67489 .41785 Mdot
.77622 .50656 Mdot
.69623 .42948 Mdot
.40469 .47679 Mdot
.3952 .46759 Mdot
.33865 .49724 Mdot
.3505 .48451 Mdot
.28074 .56284 Mdot
.32087 .41674 Mdot
.28407 .68441 Mdot
.39101 .47989 Mdot
.45616 .75646 Mdot
.62051 .58324 Mdot
.46846 .73765 Mdot
.53582 .36593 Mdot
.3908 .45458 Mdot
.4054 .63534 Mdot
.57794 .6193 Mdot
.44451 .15569 Mdot
.57837 .572 Mdot
.65831 .44109 Mdot
.60969 .55757 Mdot
.3551 .45696 Mdot
.43997 .68733 Mdot
.68217 .44291 Mdot
.68499 .66145 Mdot
.63532 .44753 Mdot
.36693 .448 Mdot
.55461 .25279 Mdot
.63575 .44329 Mdot
.51979 .46408 Mdot
.44145 .69228 Mdot
.45649 .30631 Mdot
.42299 .67862 Mdot
.36701 .47232 Mdot
.36403 .47497 Mdot
.79471 .52499 Mdot
.63183 .59696 Mdot
.43912 .64281 Mdot
.48858 .86492 Mdot
.57557 .33894 Mdot
.45669 .66362 Mdot
.30008 .46856 Mdot
.5357 .43133 Mdot
.43476 .6744 Mdot
.41813 .28973 Mdot
.59779 .62006 Mdot
.47859 .70958 Mdot
.3026 .49198 Mdot
.52948 .57798 Mdot
.51492 .31974 Mdot
.63679 .46223 Mdot
.54824 .53409 Mdot
.67931 .41798 Mdot
.57879 .62372 Mdot
.62993 .46468 Mdot
.59764 .56356 Mdot
.43623 .77464 Mdot
.41251 .61092 Mdot
.62559 .56192 Mdot
.57884 .62753 Mdot
.64401 .4216 Mdot
.33425 .44505 Mdot
.49115 .52329 Mdot
.38211 .42987 Mdot
.3472 .43069 Mdot
.59463 .5626 Mdot
.43965 .64564 Mdot
.47136 .64188 Mdot
.50421 .65379 Mdot
.45985 .71076 Mdot
.66845 .44718 Mdot
.61619 .76861 Mdot
.40029 .78496 Mdot
.57813 .58954 Mdot
.57149 .62815 Mdot
.33859 .48239 Mdot
.65123 .42076 Mdot
.62787 .40975 Mdot
.61085 .58646 Mdot
.25897 .57207 Mdot
.41129 .52773 Mdot
.41783 .68386 Mdot
.47823 .65211 Mdot
.43929 .66832 Mdot
.45487 .71717 Mdot
.37255 .61781 Mdot
.59359 .62031 Mdot
.47173 .64697 Mdot
.37505 .47614 Mdot
.39832 .46997 Mdot
.77145 .53033 Mdot
.5445 .35655 Mdot
.30851 .49176 Mdot
.4006 .542 Mdot
.39537 .49427 Mdot
.63204 .43744 Mdot
.45428 .51168 Mdot
.78786 .52215 Mdot
.61587 .43877 Mdot
.62404 .39366 Mdot
.76301 .53013 Mdot
.50647 .69277 Mdot
.26105 .26979 Mdot
.33637 .4727 Mdot
.45739 .53271 Mdot
.65322 .42565 Mdot
.64333 .77754 Mdot
.48229 .75947 Mdot
.32513 .47534 Mdot
.50985 .57264 Mdot
.67677 .44903 Mdot
.43141 .71303 Mdot
.41044 .48759 Mdot
.75665 .5185 Mdot
.56504 .32449 Mdot
.29866 .47059 Mdot
.768 .50491 Mdot
.46865 .65394 Mdot
.53308 .2803 Mdot
.46682 .71751 Mdot
.67596 .45146 Mdot
.43146 .45026 Mdot
.45858 .11027 Mdot
.66865 .40428 Mdot
.58361 .21031 Mdot
.43045 .60604 Mdot
.35656 .50697 Mdot
.67315 .40774 Mdot
.42684 .70904 Mdot
.56767 .6025 Mdot
.51411 .41585 Mdot
.47707 .68054 Mdot
.7842 .53405 Mdot
.76526 .52687 Mdot
.63786 .4392 Mdot
.4496 .70458 Mdot
.3459 .52275 Mdot
.42744 .68737 Mdot
.60491 .55599 Mdot
.3287 .45828 Mdot
.34167 .2184 Mdot
.42128 .41908 Mdot
.45497 .64194 Mdot
.62443 .4514 Mdot
.5169 .32103 Mdot
.34535 .44105 Mdot
.54935 .21768 Mdot
.39376 .44762 Mdot
.58431 .57352 Mdot
.72516 .71984 Mdot
.23105 .54462 Mdot
.37426 .4411 Mdot
.33969 .4827 Mdot
.57681 .61298 Mdot
.3529 .43756 Mdot
.38662 .43898 Mdot
.54438 .59627 Mdot
.4326 .69791 Mdot
.36571 .49718 Mdot
.62164 .42122 Mdot
.28151 .72264 Mdot
.41968 .48318 Mdot
.75919 .62267 Mdot
.4485 .31792 Mdot
.70181 .74558 Mdot
.41333 .5019 Mdot
.43783 .37014 Mdot
.36032 .48412 Mdot
.38581 .45672 Mdot
.3317 .47297 Mdot
.26029 .67244 Mdot
.64364 .41907 Mdot
.63641 .45657 Mdot
.51431 .31989 Mdot
.44702 .31502 Mdot
.5319 .3435 Mdot
.57206 .59593 Mdot
.7674 .36082 Mdot
.77751 .50969 Mdot
.4754 .65776 Mdot
.37157 .52585 Mdot
.68212 .44809 Mdot
.40267 .49048 Mdot
.35227 .46002 Mdot
.67007 .45257 Mdot
.65066 .39731 Mdot
.70459 .46083 Mdot
.54063 .3061 Mdot
.47025 .66926 Mdot
.32217 .49301 Mdot
.56235 .33609 Mdot
.35094 .52585 Mdot
.53324 .41455 Mdot
.46978 .66614 Mdot
.42786 .69101 Mdot
.43327 .64444 Mdot
.38397 .44702 Mdot
.35428 .45144 Mdot
.61987 .58687 Mdot
.48888 .67668 Mdot
.5766 .60087 Mdot
.6806 .42587 Mdot
.69059 .4265 Mdot
.40433 .47625 Mdot
.2777 .50685 Mdot
.52543 .32172 Mdot
.66329 .4395 Mdot
.76462 .53518 Mdot
.5208 .3087 Mdot
.37325 .44638 Mdot
.67705 .43792 Mdot
.55171 .35622 Mdot
.27388 .60761 Mdot
.22646 .31932 Mdot
.51734 .32766 Mdot
.37851 .47713 Mdot
.28897 .71681 Mdot
.5201 .26257 Mdot
.57339 .32994 Mdot
.5842 .58273 Mdot
.39542 .45106 Mdot
.28709 .32713 Mdot
.56655 .3552 Mdot
.36556 .7762 Mdot
.64402 .44957 Mdot
.50652 .61459 Mdot
.30688 .50621 Mdot
.29999 .58631 Mdot
.57289 .33823 Mdot
.45756 .68418 Mdot
.48774 .65028 Mdot
.37648 .48865 Mdot
.52654 .36302 Mdot
.5817 .56364 Mdot
.64745 .45347 Mdot
.67247 .39268 Mdot
.44484 .70469 Mdot
.55779 .75736 Mdot
.62086 .43188 Mdot
.28883 .515 Mdot
.72494 .38971 Mdot
.45457 .45009 Mdot
.41929 .76129 Mdot
.67042 .66484 Mdot
.42007 .50712 Mdot
.51906 .32683 Mdot
.59712 .62762 Mdot
.61978 .5974 Mdot
.59992 .61119 Mdot
.68005 .40334 Mdot
.52963 .49315 Mdot
.65986 .41145 Mdot
.68901 .69026 Mdot
.5552 .33695 Mdot
.46542 .2834 Mdot
.39625 .51985 Mdot
.35321 .50108 Mdot
.35645 .53104 Mdot
.35267 .51692 Mdot
.35963 .48742 Mdot
.60012 .61796 Mdot
.66536 .39477 Mdot
.67728 .31748 Mdot
.44938 .65898 Mdot
.72033 .47257 Mdot
.65728 .42106 Mdot
.77581 .50702 Mdot
.5397 .32405 Mdot
.43102 .37936 Mdot
.60901 .43144 Mdot
.66206 .42543 Mdot
.31143 .48399 Mdot
.43019 .66351 Mdot
.27834 .44627 Mdot
.35932 .47823 Mdot
.66612 .43839 Mdot
.59493 .38505 Mdot
.24712 .49814 Mdot
.38048 .55268 Mdot
.54992 .29334 Mdot
.53642 .43681 Mdot
.55375 .30569 Mdot
.35761 .54039 Mdot
.64947 .77472 Mdot
.63778 .42136 Mdot
.65118 .442 Mdot
.534 .35708 Mdot
.37002 .56629 Mdot
.448 .70083 Mdot
.77321 .53595 Mdot
.59274 .57266 Mdot
.36095 .46939 Mdot
.684 .4115 Mdot
.40941 .57905 Mdot
.71262 .35552 Mdot
.59377 .61033 Mdot
.6155 .43657 Mdot
.3842 .44233 Mdot
.38035 .47845 Mdot
.54018 .31303 Mdot
.46557 .52994 Mdot
.31041 .44878 Mdot
.55342 .18624 Mdot
.59758 .76331 Mdot
.54508 .78535 Mdot
.39659 .497 Mdot
.44312 .70609 Mdot
.75866 .51785 Mdot
.55574 .32036 Mdot
.32699 .50799 Mdot
.23279 .30873 Mdot
.45828 .63155 Mdot
.59229 .59675 Mdot
.75794 .52198 Mdot
.52857 .49135 Mdot
.39634 .45033 Mdot
.40873 .48015 Mdot
.37942 .46426 Mdot
.19845 .33873 Mdot
.62436 .44051 Mdot
.44717 .71759 Mdot
.53989 .33975 Mdot
.45173 .7154 Mdot
.63575 .45321 Mdot
.52084 .74926 Mdot
.36274 .44288 Mdot
.41666 .68608 Mdot
.45463 .68558 Mdot
.57553 .57439 Mdot
.56622 .58968 Mdot
.70584 .46141 Mdot
.39191 .51783 Mdot
.7562 .51585 Mdot
.42327 .68294 Mdot
.64296 .39465 Mdot
.54601 .31548 Mdot
.62448 .60457 Mdot
.39038 .47868 Mdot
.63558 .429 Mdot
.43749 .48707 Mdot
.43244 .67184 Mdot
.66118 .4252 Mdot
.75103 .51418 Mdot
.5241 .33552 Mdot
.39377 .47228 Mdot
.56896 .30617 Mdot
.7633 .53214 Mdot
.3479 .49587 Mdot
.32103 .3857 Mdot
.57857 .3703 Mdot
.69387 .65659 Mdot
.66095 .40741 Mdot
.77995 .52713 Mdot
.4261 .69371 Mdot
.52374 .66486 Mdot
.65318 .44518 Mdot
.38439 .37571 Mdot
.46768 .54499 Mdot
.32069 .4888 Mdot
.44334 .67426 Mdot
.62248 .37122 Mdot
.5043 .1797 Mdot
.50284 .25074 Mdot
.36297 .50438 Mdot
.67496 .40971 Mdot
.55686 .35483 Mdot
.57787 .58762 Mdot
.76063 .62358 Mdot
.39481 .63104 Mdot
.62619 .46159 Mdot
.33463 .47586 Mdot
.42362 .6811 Mdot
.60986 .58748 Mdot
.59007 .68062 Mdot
.61577 .41905 Mdot
.64072 .40679 Mdot
.3708 .44323 Mdot
.55192 .34464 Mdot
.44072 .23924 Mdot
.63914 .45909 Mdot
.68093 .40914 Mdot
.73342 .46009 Mdot
.53092 .35668 Mdot
.37354 .48295 Mdot
.50384 .65198 Mdot
.32044 .45549 Mdot
.58728 .20844 Mdot
.7861 .52228 Mdot
.44963 .65734 Mdot
.40052 .46702 Mdot
.70375 .36741 Mdot
.66316 .44547 Mdot
.53938 .44993 Mdot
.6427 .47119 Mdot
.60149 .6191 Mdot
.68522 .41329 Mdot
.40822 .49041 Mdot
.62894 .61753 Mdot
.52497 .32456 Mdot
.37515 .51947 Mdot
.35274 .45146 Mdot
.42607 .71116 Mdot
.58843 .59076 Mdot
.20005 .58248 Mdot
.58361 .63325 Mdot
.58412 .62343 Mdot
.49686 .6705 Mdot
.37644 .49321 Mdot
.65876 .43721 Mdot
.64527 .46615 Mdot
.32979 .50915 Mdot
.61877 .78259 Mdot
.44522 .70191 Mdot
.70824 .46064 Mdot
.17567 .40817 Mdot
.29707 .51519 Mdot
.75247 .52309 Mdot
.46712 .51585 Mdot
.56934 .58426 Mdot
.38508 .47762 Mdot
.45632 .6432 Mdot
.67264 .40197 Mdot
.62097 .43035 Mdot
.33952 .52179 Mdot
.60248 .58671 Mdot
.56844 .34228 Mdot
.63944 .40465 Mdot
.72244 .36857 Mdot
.37413 .46244 Mdot
.71009 .67607 Mdot
.64873 .40262 Mdot
.61081 .1962 Mdot
.69034 .33259 Mdot
.44284 .67027 Mdot
.35008 .45939 Mdot
.4721 .69825 Mdot
.53475 .3363 Mdot
.61776 .39002 Mdot
.59844 .58759 Mdot
.39065 .55522 Mdot
.24546 .706 Mdot
.64732 .41738 Mdot
.47392 .66058 Mdot
.3755 .44116 Mdot
.31817 .53487 Mdot
.40647 .50359 Mdot
.51507 .64576 Mdot
.589 .35973 Mdot
.59215 .56296 Mdot
.58412 .57517 Mdot
.34077 .49262 Mdot
.55409 .31393 Mdot
.65863 .45993 Mdot
.64888 .45242 Mdot
.87082 .57424 Mdot
.75028 .51427 Mdot
.39925 .3271 Mdot
.39369 .46846 Mdot
.63938 .39397 Mdot
.28141 .71486 Mdot
.58136 .59927 Mdot
.35042 .51729 Mdot
.64457 .39029 Mdot
.64021 .52019 Mdot
.53163 .41668 Mdot
.36585 .48611 Mdot
.28626 .47134 Mdot
.58981 .57371 Mdot
.51324 .38924 Mdot
.66284 .41341 Mdot
.34255 .51334 Mdot
.58781 .63496 Mdot
.74809 .41695 Mdot
.32934 .77495 Mdot
.46987 .66891 Mdot
.64375 .46957 Mdot
.59918 .61838 Mdot
.30659 .44997 Mdot
.55052 .35306 Mdot
.68418 .42819 Mdot
.63116 .44176 Mdot
.33362 .45817 Mdot
.31078 .46539 Mdot
.29882 .51713 Mdot
.46217 .65612 Mdot
.6125 .57293 Mdot
.36562 .52009 Mdot
.56338 .75794 Mdot
.33912 .4996 Mdot
.61436 .57741 Mdot
.6069 .12205 Mdot
.33078 .44397 Mdot
.40455 .50467 Mdot
.46167 .23939 Mdot
.4767 .6846 Mdot
.45353 .71408 Mdot
.60319 .76631 Mdot
.3937 .46883 Mdot
.70973 .32492 Mdot
.47097 .67254 Mdot
.44182 .69931 Mdot
.61071 .28369 Mdot
.32564 .46376 Mdot
.52797 .38855 Mdot
.61563 .58872 Mdot
.61858 .61506 Mdot
.42977 .69194 Mdot
.31095 .44644 Mdot
.58773 .62138 Mdot
.3134 .57591 Mdot
.65643 .41749 Mdot
.65279 .77317 Mdot
.43467 .66221 Mdot
.4864 .49295 Mdot
.58482 .6055 Mdot
.45242 .153 Mdot
.52392 .56238 Mdot
.33388 .49094 Mdot
.38837 .47032 Mdot
.52595 .33469 Mdot
.40002 .42912 Mdot
.78826 .52949 Mdot
.60816 .60962 Mdot
.40891 .22852 Mdot
.46279 .66432 Mdot
.39569 .51482 Mdot
.41551 .37503 Mdot
.59745 .69022 Mdot
.75036 .64983 Mdot
.45727 .69374 Mdot
.44842 .67219 Mdot
.64854 .41053 Mdot
.63163 .41944 Mdot
.37015 .49077 Mdot
.61874 .60412 Mdot
.49013 .68473 Mdot
.60122 .56989 Mdot
.63652 .4215 Mdot
.65986 .42949 Mdot
.78409 .51312 Mdot
.42736 .46917 Mdot
.66536 .45436 Mdot
.74606 .39184 Mdot
.55058 .76119 Mdot
.43515 .72126 Mdot
.18487 .62313 Mdot
.59087 .67893 Mdot
.36708 .28017 Mdot
.54968 .30564 Mdot
.78726 .54315 Mdot
.62186 .57012 Mdot
.34029 .48546 Mdot
.39809 .48337 Mdot
.7689 .51904 Mdot
.63152 .57932 Mdot
.53652 .32093 Mdot
.63282 .59046 Mdot
.55738 .33915 Mdot
.69369 .42369 Mdot
.41954 .48434 Mdot
.40656 .46595 Mdot
.60035 .61681 Mdot
.67079 .42824 Mdot
.65508 .45582 Mdot
.54078 .30345 Mdot
.4567 .38378 Mdot
.63669 .43745 Mdot
.43357 .66465 Mdot
.36977 .67487 Mdot
.76505 .52531 Mdot
.41073 .48988 Mdot
.37309 .36627 Mdot
.25737 .55274 Mdot
.32523 .49377 Mdot
.75786 .52432 Mdot
.83838 .62778 Mdot
.39646 .51846 Mdot
.78747 .69072 Mdot
.77899 .529 Mdot
.47717 .68552 Mdot
.66769 .40623 Mdot
.7898 .52926 Mdot
.29637 .48603 Mdot
.56477 .31113 Mdot
.32396 .51545 Mdot
.47496 .68442 Mdot
.42442 .65598 Mdot
.52057 .80303 Mdot
.58863 .20982 Mdot
.53016 .3072 Mdot
.54728 .32351 Mdot
.65104 .44586 Mdot
.78456 .33805 Mdot
.3038 .49232 Mdot
.54484 .31983 Mdot
.39639 .24067 Mdot
.33962 .47756 Mdot
.40258 .33988 Mdot
.51002 .5685 Mdot
.44293 .70524 Mdot
.49392 .72 Mdot
.6578 .44705 Mdot
.47408 .66173 Mdot
.52582 .77409 Mdot
.35457 .53062 Mdot
.46771 .66464 Mdot
.61195 .5767 Mdot
.6949 .57032 Mdot
.46569 .70229 Mdot
.50425 .40281 Mdot
.61622 .59309 Mdot
.59278 .36318 Mdot
.43354 .25497 Mdot
.1409 .59861 Mdot
.61004 .60979 Mdot
.67665 .42745 Mdot
.67494 .45163 Mdot
.64818 .45047 Mdot
.47848 .67833 Mdot
.62463 .40969 Mdot
.45661 .65207 Mdot
.56523 .23662 Mdot
.42569 .37287 Mdot
.55438 .32624 Mdot
.55994 .57242 Mdot
.45 .68003 Mdot
.65354 .73052 Mdot
.1986 .65976 Mdot
.37955 .47438 Mdot
.58551 .63405 Mdot
.53282 .3558 Mdot
.73032 .25424 Mdot
.52664 .33311 Mdot
.67401 .41636 Mdot
.66085 .76844 Mdot
.39275 .512 Mdot
.23952 .45302 Mdot
.52242 .32865 Mdot
.46353 .69142 Mdot
.34954 .49802 Mdot
.66913 .47347 Mdot
.54761 .35048 Mdot
.56692 .33079 Mdot
.35781 .49315 Mdot
.45784 .70558 Mdot
.66059 .43335 Mdot
.62419 .57674 Mdot
.57453 .36532 Mdot
.31105 .43895 Mdot
.31715 .47025 Mdot
.40617 .52484 Mdot
.54271 .47591 Mdot
.32294 .28822 Mdot
.61061 .60527 Mdot
.48848 .28613 Mdot
.63036 .42592 Mdot
.60804 .34576 Mdot
.61754 .73502 Mdot
.57379 .5564 Mdot
.78582 .52374 Mdot
.7855 .51743 Mdot
.3634 .48814 Mdot
.33246 .28068 Mdot
.76693 .66697 Mdot
.58595 .54108 Mdot
.76263 .5226 Mdot
.65032 .45446 Mdot
.48436 .64572 Mdot
.49174 .7973 Mdot
.32378 .44497 Mdot
.5739 .57244 Mdot
.63434 .43421 Mdot
.30355 .27801 Mdot
.5513 .33751 Mdot
.64591 .76555 Mdot
.36409 .44516 Mdot
.36868 .51272 Mdot
.60725 .59795 Mdot
.62005 .58868 Mdot
.74168 .6411 Mdot
.55397 .78935 Mdot
.57621 .42527 Mdot
.56124 .65189 Mdot
.27433 .30671 Mdot
.47311 .73501 Mdot
.44999 .64306 Mdot
.75972 .50634 Mdot
.60917 .62904 Mdot
.41098 .48253 Mdot
.48401 .66559 Mdot
.75002 .65204 Mdot
.43472 .6253 Mdot
.41541 .33609 Mdot
.71707 .3418 Mdot
.36106 .45584 Mdot
.42742 .67074 Mdot
.47332 .66366 Mdot
.47018 .71227 Mdot
.76111 .52823 Mdot
.39268 .49829 Mdot
.33822 .44268 Mdot
.35936 .51457 Mdot
.30698 .43179 Mdot
.37182 .4644 Mdot
.6037 .7368 Mdot
.61304 .51229 Mdot
.42234 .21995 Mdot
.32661 .49189 Mdot
.61415 .61899 Mdot
.38612 .5273 Mdot
.55754 .31717 Mdot
.33403 .47729 Mdot
.40095 .33317 Mdot
.5959 .60406 Mdot
.36936 .5648 Mdot
.55625 .65183 Mdot
.36176 .44478 Mdot
.56334 .35467 Mdot
.34673 .2768 Mdot
.19684 .5935 Mdot
.72395 .46727 Mdot
.43254 .66705 Mdot
.61004 .4285 Mdot
.59986 .55522 Mdot
.65629 .4372 Mdot
.33374 .49804 Mdot
.75489 .51253 Mdot
.66492 .64505 Mdot
.48787 .496 Mdot
.40592 .47045 Mdot
.45301 .48368 Mdot
.43329 .68783 Mdot
.67722 .43468 Mdot
.42125 .72671 Mdot
.38464 .46075 Mdot
.54111 .3427 Mdot
.55367 .34741 Mdot
.56233 .77694 Mdot
.34233 .23173 Mdot
.51312 .70502 Mdot
.60851 .59971 Mdot
.62369 .4475 Mdot
.57268 .34216 Mdot
.40456 .61326 Mdot
.57493 .56852 Mdot
.57001 .58277 Mdot
.59412 .58469 Mdot
.36028 .46351 Mdot
.78796 .52613 Mdot
.3665 .24274 Mdot
.78624 .53288 Mdot
.35795 .44585 Mdot
.62733 .43988 Mdot
.79209 .52613 Mdot
.53 .34408 Mdot
.57397 .59388 Mdot
.6366 .41709 Mdot
.36638 .4702 Mdot
.46579 .67389 Mdot
.46948 .3908 Mdot
.33582 .33048 Mdot
.52408 .21958 Mdot
.51738 .21841 Mdot
.44912 .63745 Mdot
.42 .1768 Mdot
.56652 .63105 Mdot
.25967 .57115 Mdot
.50659 .29901 Mdot
.33503 .51428 Mdot
.53323 .82777 Mdot
.66481 .41337 Mdot
.67469 .4473 Mdot
.36796 .48242 Mdot
.65254 .396 Mdot
.40094 .51124 Mdot
.63635 .41173 Mdot
.72334 .45944 Mdot
.33209 .43603 Mdot
.67137 .44812 Mdot
.33176 .52898 Mdot
.34251 .44307 Mdot
.43618 .70081 Mdot
.68291 .41879 Mdot
.33825 .50065 Mdot
.7854 .32042 Mdot
.62379 .59685 Mdot
.76239 .52869 Mdot
.5819 .46797 Mdot
.5934 .61866 Mdot
.45313 .66297 Mdot
.35644 .42616 Mdot
.53183 .31363 Mdot
.45896 .681 Mdot
.70732 .45976 Mdot
.52179 .33295 Mdot
.61722 .76721 Mdot
.43045 .67303 Mdot
.76716 .52486 Mdot
.52473 .32181 Mdot
.45099 .48421 Mdot
.68759 .43512 Mdot
.29364 .35613 Mdot
.78069 .53407 Mdot
.40297 .49693 Mdot
.68574 .3991 Mdot
.62181 .61493 Mdot
.37228 .50379 Mdot
.67071 .40471 Mdot
.7607 .52898 Mdot
.35435 .46893 Mdot
.34684 .48726 Mdot
.46111 .78518 Mdot
.72806 .69073 Mdot
.54144 .31405 Mdot
.42255 .69582 Mdot
.37434 .47593 Mdot
.54358 .3062 Mdot
.78692 .42188 Mdot
.41888 .51378 Mdot
.47941 .68777 Mdot
.34322 .38741 Mdot
.62909 .42226 Mdot
.57618 .60069 Mdot
.64682 .46915 Mdot
.56323 .32064 Mdot
.52969 .86809 Mdot
.78958 .51845 Mdot
.33413 .53337 Mdot
.35485 .52584 Mdot
.61837 .37983 Mdot
.47035 .66066 Mdot
.57001 .41574 Mdot
.39329 .47212 Mdot
.41738 .41603 Mdot
.37823 .51712 Mdot
.68754 .32624 Mdot
.44591 .70103 Mdot
.40613 .50004 Mdot
.27327 .49509 Mdot
.41744 .47045 Mdot
.56703 .35018 Mdot
.4625 .26769 Mdot
.40954 .52043 Mdot
.39595 .1229 Mdot
.76207 .5328 Mdot
.66727 .45314 Mdot
.60476 .45598 Mdot
.83875 .44366 Mdot
.43239 .7747 Mdot
.4599 .65346 Mdot
.43414 .41126 Mdot
.65868 .43529 Mdot
.3252 .76202 Mdot
.45544 .16529 Mdot
.34453 .44308 Mdot
.38871 .44649 Mdot
.67403 .41637 Mdot
.64556 .39398 Mdot
.76135 .50789 Mdot
.32844 .48951 Mdot
.44455 .51773 Mdot
.61695 .43822 Mdot
.3692 .45783 Mdot
.29278 .41373 Mdot
.62071 .57325 Mdot
.43784 .70763 Mdot
.57732 .58863 Mdot
.58258 .56627 Mdot
.34289 .62592 Mdot
.59603 .76381 Mdot
.61635 .57916 Mdot
.6039 .64054 Mdot
.38907 .33677 Mdot
.39895 .38376 Mdot
.57033 .33936 Mdot
.43879 .1956 Mdot
.64558 .44599 Mdot
.39065 .49829 Mdot
.45469 .63912 Mdot
.30893 .59786 Mdot
.70235 .51375 Mdot
.69104 .74593 Mdot
.39038 .46004 Mdot
.65827 .44946 Mdot
.76723 .53297 Mdot
.32644 .44027 Mdot
.59552 .31975 Mdot
.36551 .50928 Mdot
.68258 .44711 Mdot
.37866 .68439 Mdot
.28574 .40881 Mdot
.6897 .37928 Mdot
.48014 .71156 Mdot
.37844 .52347 Mdot
.44172 .65664 Mdot
.58733 .60921 Mdot
.5489 .30965 Mdot
.53752 .31528 Mdot
.34998 .49471 Mdot
.40912 .61314 Mdot
.50398 .57258 Mdot
.34847 .44078 Mdot
.33033 .45992 Mdot
.77998 .5279 Mdot
.32974 .45966 Mdot
.35238 .52477 Mdot
.3554 .51635 Mdot
.42535 .49019 Mdot
.58587 .62447 Mdot
.29454 .39961 Mdot
.43315 .49574 Mdot
.33328 .53848 Mdot
.62449 .58403 Mdot
.45918 .44555 Mdot
.58234 .56877 Mdot
.33872 .22128 Mdot
.58739 .56937 Mdot
.54336 .31635 Mdot
.67773 .39187 Mdot
.41753 .41146 Mdot
.49112 .68628 Mdot
.56911 .60913 Mdot
.54071 .33261 Mdot
.60396 .61103 Mdot
.62305 .43657 Mdot
.17954 .5206 Mdot
.43392 .62565 Mdot
.52264 .40201 Mdot
.52055 .59561 Mdot
.71458 .67182 Mdot
.65122 .41348 Mdot
.44085 .7017 Mdot
.23514 .46216 Mdot
.34878 .50929 Mdot
.52438 .33176 Mdot
.36223 .49085 Mdot
.58025 .61977 Mdot
.65349 .45007 Mdot
.53044 .23425 Mdot
.53545 .31394 Mdot
.32979 .78541 Mdot
.64323 .45245 Mdot
.3461 .43516 Mdot
.56955 .57975 Mdot
.18633 .62782 Mdot
.58387 .57106 Mdot
.41358 .37058 Mdot
.41278 .6941 Mdot
.4065 .7682 Mdot
.44455 .67833 Mdot
.77152 .6302 Mdot
.20871 .30764 Mdot
.51717 .1948 Mdot
.4684 .68163 Mdot
.71826 .39034 Mdot
.37068 .44909 Mdot
.39916 .52526 Mdot
.29536 .51907 Mdot
.43411 .71714 Mdot
.37434 .47118 Mdot
.77959 .53233 Mdot
.53025 .75207 Mdot
.62092 .34052 Mdot
.61143 .43488 Mdot
.41019 .49765 Mdot
.62276 .58137 Mdot
.63339 .59225 Mdot
.79101 .52901 Mdot
.5952 .55868 Mdot
.32986 .45092 Mdot
.44775 .67994 Mdot
.48035 .5276 Mdot
.53154 .33798 Mdot
.69977 .25394 Mdot
.54653 .36738 Mdot
.63931 .47572 Mdot
.43343 .45323 Mdot
.66038 .42876 Mdot
.66438 .82506 Mdot
.34041 .49795 Mdot
.47316 .67222 Mdot
.34992 .48098 Mdot
.36848 .52283 Mdot
.39764 .52614 Mdot
.6168 .42031 Mdot
.58954 .41643 Mdot
.36733 .46106 Mdot
.59702 .5876 Mdot
.47358 .21156 Mdot
.33937 .5271 Mdot
.7193 .42463 Mdot
.43701 .31123 Mdot
.68374 .69604 Mdot
.44194 .72519 Mdot
.67611 .43261 Mdot
.45777 .66624 Mdot
.49456 .68867 Mdot
.45323 .6628 Mdot
.37301 .23434 Mdot
.28254 .53879 Mdot
.83803 .61763 Mdot
.38133 .75729 Mdot
.2901 .60321 Mdot
.41931 .67114 Mdot
.79746 .46059 Mdot
.4656 .64596 Mdot
.45811 .65672 Mdot
.82371 .30975 Mdot
.47316 .64942 Mdot
.4039 .47796 Mdot
.31196 .47147 Mdot
.58291 .71262 Mdot
.38334 .34593 Mdot
.33112 .47889 Mdot
.3719 .479 Mdot
.54258 .30777 Mdot
.31363 .55322 Mdot
.77048 .50335 Mdot
.61219 .77773 Mdot
.62934 .66039 Mdot
.35833 .49178 Mdot
.37077 .4752 Mdot
.33837 .42291 Mdot
.177 .33757 Mdot
.3289 .59622 Mdot
.43353 .64153 Mdot
.4547 .47742 Mdot
.62862 .21423 Mdot
.36077 .4337 Mdot
.40716 .46531 Mdot
.35459 .46198 Mdot
.65889 .43655 Mdot
.47374 .63641 Mdot
.45391 .47417 Mdot
.67056 .69185 Mdot
.36966 .44502 Mdot
.55594 .58632 Mdot
.58302 .3606 Mdot
.40751 .48894 Mdot
.46301 .7142 Mdot
.33868 .46994 Mdot
.43151 .66456 Mdot
.43136 .69719 Mdot
.3469 .41828 Mdot
.35431 .24138 Mdot
.47516 .69893 Mdot
.35616 .44933 Mdot
.67066 .43231 Mdot
.51427 .18525 Mdot
.40404 .4943 Mdot
.5598 .32736 Mdot
.39053 .47052 Mdot
.56247 .35384 Mdot
.34068 .44912 Mdot
.78319 .53412 Mdot
.22962 .52888 Mdot
.64969 .44216 Mdot
.49342 .34117 Mdot
.63034 .39767 Mdot
.46575 .78379 Mdot
.48015 .68251 Mdot
.75568 .50484 Mdot
.65405 .7913 Mdot
.77741 .52825 Mdot
.4708 .39472 Mdot
.72153 .48924 Mdot
.61673 .61081 Mdot
.44499 .7157 Mdot
.48083 .31339 Mdot
.72134 .41223 Mdot
.68073 .47517 Mdot
.62147 .39533 Mdot
.54639 .85266 Mdot
.61035 .81421 Mdot
.36332 .46751 Mdot
.2412 .39214 Mdot
.28371 .67651 Mdot
.42042 .4941 Mdot
.36923 .42694 Mdot
.68851 .44002 Mdot
.39299 .52074 Mdot
.52538 .47243 Mdot
.64471 .42102 Mdot
.54361 .32854 Mdot
.44949 .65611 Mdot
.56119 .35284 Mdot
.6959 .44364 Mdot
.60369 .51113 Mdot
.63338 .42176 Mdot
.42499 .50277 Mdot
.35513 .48048 Mdot
.42593 .68177 Mdot
.40208 .65019 Mdot
.43573 .70423 Mdot
.52495 .34617 Mdot
.64184 .4294 Mdot
.31036 .58748 Mdot
.38406 .48201 Mdot
.45246 .68697 Mdot
.6497 .5854 Mdot
.38094 .47807 Mdot
.59509 .61485 Mdot
.37922 .4447 Mdot
.47051 .68373 Mdot
.33005 .45886 Mdot
.44805 .67788 Mdot
.66803 .41851 Mdot
.3687 .43513 Mdot
.36924 .48396 Mdot
.2177 .66357 Mdot
.53485 .32189 Mdot
.47957 .68295 Mdot
.53729 .52322 Mdot
.33673 .44114 Mdot
.6016 .36705 Mdot
.41358 .49991 Mdot
.40401 .39178 Mdot
.3413 .53439 Mdot
.77601 .53186 Mdot
.43812 .49791 Mdot
.40434 .49546 Mdot
.25664 .4295 Mdot
.33065 .7259 Mdot
.41843 .72549 Mdot
.57346 .61243 Mdot
.45992 .71477 Mdot
.68999 .42538 Mdot
.67148 .39899 Mdot
.63569 .40354 Mdot
.39196 .355 Mdot
.32597 .43253 Mdot
.39394 .51047 Mdot
.56721 .60953 Mdot
.54961 .32636 Mdot
.45779 .69169 Mdot
.55301 .33068 Mdot
.60448 .77886 Mdot
.52592 .34636 Mdot
.78935 .52802 Mdot
.69119 .33428 Mdot
.26452 .54691 Mdot
.53962 .30797 Mdot
.43677 .70572 Mdot
.71366 .34566 Mdot
.3371 .51432 Mdot
.69118 .48195 Mdot
.5426 .34351 Mdot
.50289 .86418 Mdot
.41594 .49441 Mdot
.52235 .42974 Mdot
.60699 .56405 Mdot
.54473 .35384 Mdot
.5861 .59424 Mdot
.33717 .48701 Mdot
.70011 .65295 Mdot
.47522 .66043 Mdot
.615 .62869 Mdot
.4339 .50422 Mdot
.55594 .35396 Mdot
.6343 .43918 Mdot
.53185 .5909 Mdot
.61441 .61821 Mdot
.20536 .49638 Mdot
.50399 .25089 Mdot
.64251 .42716 Mdot
.79673 .63526 Mdot
.59083 .58127 Mdot
.42023 .50367 Mdot
.37315 .4036 Mdot
.32621 .47744 Mdot
.6817 .40332 Mdot
.67635 .43809 Mdot
.55109 .73936 Mdot
.35237 .47895 Mdot
.41512 .49648 Mdot
.43951 .63 Mdot
.65106 .41879 Mdot
.43711 .68301 Mdot
.46767 .71508 Mdot
.67565 .42415 Mdot
.44142 .67242 Mdot
.52274 .33237 Mdot
.52547 .72606 Mdot
.59165 .58005 Mdot
.59608 .59146 Mdot
.65014 .45389 Mdot
.64164 .46148 Mdot
.65995 .42653 Mdot
.37883 .44468 Mdot
.4546 .69818 Mdot
.34588 .45895 Mdot
.41927 .51524 Mdot
.42844 .7247 Mdot
.47903 .65194 Mdot
.345 .46738 Mdot
.62258 .3721 Mdot
.57885 .35605 Mdot
.66949 .44808 Mdot
.6034 .56939 Mdot
.3273 .76026 Mdot
.56488 .59249 Mdot
.41056 .49974 Mdot
.64399 .517 Mdot
.46864 .68946 Mdot
.52658 .33551 Mdot
.57657 .37282 Mdot
.52659 .32379 Mdot
.61947 .543 Mdot
.4846 .69747 Mdot
.61682 .76607 Mdot
.40586 .50661 Mdot
.54195 .4779 Mdot
.48374 .29787 Mdot
.62722 .72982 Mdot
.61279 .57535 Mdot
.37646 .47748 Mdot
.7745 .5281 Mdot
.24788 .50573 Mdot
.36921 .5105 Mdot
.34287 .51 Mdot
.64674 .28287 Mdot
.33164 .53799 Mdot
.42841 .71586 Mdot
.52691 .80238 Mdot
.31411 .48867 Mdot
.50215 .63418 Mdot
.87188 .49078 Mdot
.40752 .50913 Mdot
.37926 .46077 Mdot
.39551 .49032 Mdot
.34192 .4793 Mdot
.41865 .7093 Mdot
.48326 .37675 Mdot
.56846 .58355 Mdot
.56253 .48722 Mdot
.60016 .57839 Mdot
.68478 .43809 Mdot
.52026 .43463 Mdot
.44238 .71357 Mdot
.52531 .33039 Mdot
.21094 .44756 Mdot
.57478 .79362 Mdot
.64982 .41081 Mdot
.36123 .60858 Mdot
.53466 .33954 Mdot
.33168 .51093 Mdot
.51568 .33815 Mdot
.64339 .39344 Mdot
.60809 .58577 Mdot
.3127 .47025 Mdot
.43881 .64412 Mdot
.46679 .70171 Mdot
.37819 .47341 Mdot
.58449 .20303 Mdot
.58756 .61306 Mdot
.63827 .54039 Mdot
.36057 .46096 Mdot
.34181 .50895 Mdot
.43583 .67321 Mdot
.66837 .44323 Mdot
.76184 .44391 Mdot
.53739 .32585 Mdot
.40044 .43889 Mdot
.33821 .47777 Mdot
.58623 .7796 Mdot
.57255 .5964 Mdot
.7628 .51108 Mdot
.35832 .4671 Mdot
.58978 .76625 Mdot
.35681 .46841 Mdot
.39696 .42606 Mdot
.66523 .43067 Mdot
.35422 .53331 Mdot
.3902 .45101 Mdot
.45227 .53535 Mdot
.58645 .58616 Mdot
.47163 .6666 Mdot
.41829 .65253 Mdot
.75653 .51881 Mdot
.59648 .61438 Mdot
.34273 .46877 Mdot
.57675 .60936 Mdot
.40439 .52367 Mdot
.36858 .46324 Mdot
.61267 .57576 Mdot
.43713 .68231 Mdot
.65926 .62478 Mdot
.38003 .37378 Mdot
.34512 .47919 Mdot
.31642 .47184 Mdot
.3958 .35081 Mdot
.72576 .74331 Mdot
.39597 .4637 Mdot
.47166 .68945 Mdot
.37846 .48202 Mdot
.58791 .6021 Mdot
.53114 .35292 Mdot
.46864 .67727 Mdot
.64566 .45857 Mdot
.66847 .41612 Mdot
.55075 .65097 Mdot
.79059 .52398 Mdot
.3178 .46292 Mdot
.42406 .73781 Mdot
.46621 .64139 Mdot
.82208 .37244 Mdot
.67571 .4503 Mdot
.56662 .35396 Mdot
.34506 .48874 Mdot
.5353 .57123 Mdot
.56678 .60144 Mdot
.39267 .12342 Mdot
.62016 .75848 Mdot
.51033 .33202 Mdot
.68278 .75761 Mdot
.77113 .52383 Mdot
.40289 .46299 Mdot
.55269 .31158 Mdot
.65791 .40638 Mdot
.37393 .52765 Mdot
.2894 .48524 Mdot
.5676 .41988 Mdot
.60152 .41036 Mdot
.57658 .60649 Mdot
.63001 .41371 Mdot
.5236 .30273 Mdot
.78892 .52872 Mdot
.4543 .71051 Mdot
.4034 .50049 Mdot
.39226 .41182 Mdot
.66136 .45325 Mdot
.7827 .5348 Mdot
.36066 .45547 Mdot
.46636 .70441 Mdot
.64823 .39725 Mdot
.3566 .49556 Mdot
.26908 .57879 Mdot
.4875 .706 Mdot
.63947 .43709 Mdot
.35688 .52528 Mdot
.37246 .39226 Mdot
.64707 .45646 Mdot
.66139 .45597 Mdot
.37397 .4715 Mdot
.52336 .32697 Mdot
.38819 .44285 Mdot
.59384 .56463 Mdot
.5895 .41777 Mdot
.59008 .6011 Mdot
.52384 .27029 Mdot
.43278 .45721 Mdot
.72533 .66924 Mdot
.42328 .68673 Mdot
.53713 .29639 Mdot
.22391 .64068 Mdot
.33605 .50522 Mdot
.39693 .19603 Mdot
.48886 .48438 Mdot
.71189 .24954 Mdot
.20264 .35127 Mdot
.54669 .34141 Mdot
.60032 .61155 Mdot
.37928 .46158 Mdot
.56884 .62581 Mdot
.54697 .31183 Mdot
.49753 .27857 Mdot
.3538 .52375 Mdot
.44342 .69978 Mdot
.36766 .44664 Mdot
.43281 .66583 Mdot
.38318 .47739 Mdot
.36672 .54685 Mdot
.51994 .28949 Mdot
.40888 .36966 Mdot
.33444 .51244 Mdot
.17769 .51896 Mdot
.54137 .54695 Mdot
.53772 .33785 Mdot
.35066 .45398 Mdot
.77287 .51395 Mdot
.62935 .57306 Mdot
.30216 .31479 Mdot
.6592 .43278 Mdot
.61756 .57741 Mdot
.44265 .66448 Mdot
.65441 .46471 Mdot
.75856 .52836 Mdot
.37907 .40811 Mdot
.5658 .34698 Mdot
.61419 .61203 Mdot
.4061 .49282 Mdot
.41546 .49184 Mdot
.69704 .37498 Mdot
.74869 .57586 Mdot
.46582 .63047 Mdot
.28479 .74808 Mdot
.42579 .71745 Mdot
.54187 .31998 Mdot
.66394 .42924 Mdot
.40104 .46861 Mdot
.36634 .50346 Mdot
.68012 .40518 Mdot
.47971 .68013 Mdot
.60062 .42944 Mdot
.35377 .62172 Mdot
.62761 .4588 Mdot
.45261 .33695 Mdot
.47344 .67689 Mdot
.45322 .34261 Mdot
.52434 .30174 Mdot
.3256 .25366 Mdot
.37258 .30111 Mdot
.60805 .56387 Mdot
.45351 .33117 Mdot
.46427 .68962 Mdot
.36025 .4748 Mdot
.76691 .52283 Mdot
.78536 .51502 Mdot
.44199 .66042 Mdot
.67492 .41612 Mdot
.54788 .3526 Mdot
.37708 .45929 Mdot
.66859 .73376 Mdot
.57028 .68722 Mdot
.625 .45016 Mdot
.27827 .46061 Mdot
.58968 .5903 Mdot
.38713 .45195 Mdot
.56177 .33379 Mdot
.61563 .6038 Mdot
.75407 .53253 Mdot
.53272 .74225 Mdot
.34546 .494 Mdot
.55061 .78476 Mdot
.60183 .61561 Mdot
.80275 .63379 Mdot
.36811 .49276 Mdot
.59052 .58153 Mdot
.41475 .54584 Mdot
.6694 .67034 Mdot
.50717 .52488 Mdot
.46411 .17089 Mdot
.60837 .40333 Mdot
.66921 .41391 Mdot
.7037 .59234 Mdot
.51306 .29389 Mdot
.62572 .59368 Mdot
.78851 .52964 Mdot
.42482 .2698 Mdot
.58636 .59138 Mdot
.40215 .45586 Mdot
.41273 .50119 Mdot
.33586 .61988 Mdot
.52438 .50122 Mdot
.78533 .53512 Mdot
.49698 .73535 Mdot
.32328 .46876 Mdot
.38777 .54169 Mdot
.3746 .50127 Mdot
.42548 .65402 Mdot
.59508 .62017 Mdot
.17201 .60016 Mdot
.58381 .60939 Mdot
.67247 .73859 Mdot
.64632 .44654 Mdot
.62931 .45757 Mdot
.40879 .48974 Mdot
.75263 .66064 Mdot
.29663 .31093 Mdot
.34297 .43991 Mdot
.59858 .35557 Mdot
.49542 .25355 Mdot
.39747 .54336 Mdot
.41056 .67845 Mdot
.39882 .41686 Mdot
.46935 .73336 Mdot
.61901 .5948 Mdot
.55122 .34243 Mdot
.57753 .35637 Mdot
.61683 .6078 Mdot
.39308 .50956 Mdot
.58638 .32273 Mdot
.37387 .51555 Mdot
.36068 .46845 Mdot
.64083 .77217 Mdot
.57166 .35047 Mdot
.65986 .42326 Mdot
.53638 .31487 Mdot
.45991 .65698 Mdot
.69183 .16929 Mdot
.55635 .33341 Mdot
.4154 .73684 Mdot
.49727 .37323 Mdot
.4549 .33485 Mdot
.4638 .70537 Mdot
.52082 .31623 Mdot
.57818 .6054 Mdot
.70351 .23896 Mdot
.7685 .68961 Mdot
.56295 .59666 Mdot
.36543 .49631 Mdot
.43583 .70979 Mdot
.43913 .63993 Mdot
.5907 .63717 Mdot
.4464 .70722 Mdot
.44461 .49131 Mdot
.3516 .476 Mdot
.62568 .59417 Mdot
.57323 .70869 Mdot
.61046 .62092 Mdot
.51632 .74552 Mdot
.35526 .45418 Mdot
.47098 .67513 Mdot
.43201 .44108 Mdot
.43123 .63075 Mdot
.76966 .50623 Mdot
.37332 .52806 Mdot
.53456 .35069 Mdot
.52921 .48858 Mdot
.64127 .43911 Mdot
.63745 .5175 Mdot
.42742 .68532 Mdot
.65686 .60772 Mdot
.43627 .70133 Mdot
.43131 .70969 Mdot
.58601 .56214 Mdot
.46722 .65445 Mdot
.37896 .45982 Mdot
.67762 .37345 Mdot
.43659 .65422 Mdot
.60296 .59905 Mdot
.53908 .3494 Mdot
.43948 .67608 Mdot
.68085 .45503 Mdot
.35457 .48668 Mdot
.63278 .4172 Mdot
.50874 .32069 Mdot
.44746 .71594 Mdot
.52 .31984 Mdot
.67008 .45189 Mdot
.56695 .33737 Mdot
.54191 .23439 Mdot
.60842 .62831 Mdot
.69649 .74007 Mdot
.35436 .38088 Mdot
.44022 .64371 Mdot
.69001 .47094 Mdot
.39865 .46735 Mdot
.35118 .48684 Mdot
.52862 .302 Mdot
.44254 .63879 Mdot
.53158 .19287 Mdot
.40676 .39667 Mdot
.53048 .72474 Mdot
.5947 .62892 Mdot
.33655 .7794 Mdot
.56057 .75664 Mdot
.73041 .29723 Mdot
.30996 .50775 Mdot
.77061 .52343 Mdot
.38706 .51685 Mdot
.1972 .60676 Mdot
.53943 .35819 Mdot
.78718 .48881 Mdot
.30354 .48974 Mdot
.65239 .42742 Mdot
.38154 .48879 Mdot
.26398 .37463 Mdot
.40158 .41922 Mdot
.53511 .30643 Mdot
.58702 .54319 Mdot
.49102 .68577 Mdot
.53218 .33798 Mdot
.66389 .41465 Mdot
.44262 .28286 Mdot
.35936 .52833 Mdot
.32291 .45992 Mdot
.61697 .44398 Mdot
.4438 .70224 Mdot
.68657 .43538 Mdot
.5921 .58 Mdot
.55324 .33491 Mdot
.34137 .48476 Mdot
.38322 .53905 Mdot
.59281 .38564 Mdot
.59361 .62057 Mdot
.63965 .4636 Mdot
.57682 .5877 Mdot
.76961 .52374 Mdot
.31904 .49087 Mdot
.61462 .43296 Mdot
.4175 .49641 Mdot
.2232 .65298 Mdot
.64626 .77287 Mdot
.33155 .71239 Mdot
.6587 .4206 Mdot
.43207 .32786 Mdot
.59377 .6056 Mdot
.58269 .57439 Mdot
.39556 .76957 Mdot
.34182 .27767 Mdot
.71285 .3306 Mdot
.19973 .46961 Mdot
.59282 .57934 Mdot
.59317 .59879 Mdot
.65577 .40422 Mdot
.45907 .6502 Mdot
.49849 .69053 Mdot
.63787 .46709 Mdot
.38801 .36684 Mdot
.4577 .69157 Mdot
.41255 .18772 Mdot
.6907 .43745 Mdot
.30632 .50364 Mdot
.79148 .51047 Mdot
.55367 .34523 Mdot
.38864 .36754 Mdot
.25614 .39585 Mdot
.40473 .47104 Mdot
.49936 .80979 Mdot
.66681 .44051 Mdot
.53871 .39743 Mdot
.33045 .23047 Mdot
.35482 .52162 Mdot
.38563 .49533 Mdot
.38841 .50874 Mdot
.57252 .35307 Mdot
.21589 .62275 Mdot
.40541 .47084 Mdot
.43973 .37441 Mdot
.36915 .42923 Mdot
.32239 .32863 Mdot
.53829 .31478 Mdot
.50902 .63173 Mdot
.60744 .41032 Mdot
.65284 .70848 Mdot
.29897 .52186 Mdot
.58215 .58546 Mdot
.71004 .42455 Mdot
.60936 .58328 Mdot
.32385 .27713 Mdot
.37731 .30018 Mdot
.41826 .67024 Mdot
.39002 .45897 Mdot
.62894 .39262 Mdot
.42759 .69474 Mdot
.73379 .47997 Mdot
.8021 .27879 Mdot
.58493 .61871 Mdot
.71572 .7735 Mdot
.58175 .57486 Mdot
.7756 .50832 Mdot
.43669 .66946 Mdot
.3475 .58013 Mdot
.5404 .47757 Mdot
.44089 .67592 Mdot
.66513 .64003 Mdot
.41085 .69898 Mdot
.44288 .32643 Mdot
.48479 .70358 Mdot
.60065 .60243 Mdot
.63527 .57471 Mdot
.29931 .50169 Mdot
.39682 .46946 Mdot
.5753 .4873 Mdot
.46702 .48785 Mdot
.39406 .46574 Mdot
.6449 .42108 Mdot
.75646 .69066 Mdot
.6778 .38791 Mdot
.45066 .64425 Mdot
.57068 .60058 Mdot
.38457 .49369 Mdot
.34761 .47476 Mdot
.41682 .51019 Mdot
.21896 .66919 Mdot
.41915 .18712 Mdot
.36662 .46392 Mdot
.40748 .4447 Mdot
.66498 .41789 Mdot
.56343 .29942 Mdot
.1921 .51099 Mdot
.41253 .27876 Mdot
.35648 .50853 Mdot
.53272 .32082 Mdot
.56152 .3621 Mdot
.33473 .52055 Mdot
.67851 .71031 Mdot
.71508 .39024 Mdot
.4059 .49271 Mdot
.35084 .30467 Mdot
.69698 .4178 Mdot
.79085 .5309 Mdot
.66008 .45356 Mdot
.46369 .71502 Mdot
.78571 .52499 Mdot
.63031 .40026 Mdot
.32613 .57252 Mdot
.75547 .51815 Mdot
.6554 .67948 Mdot
.52496 .34621 Mdot
.37269 .50438 Mdot
.40842 .68441 Mdot
.67856 .40216 Mdot
.61775 .6084 Mdot
.45694 .67368 Mdot
.63367 .58451 Mdot
.52684 .2838 Mdot
.47684 .38497 Mdot
.79012 .52052 Mdot
.58643 .57961 Mdot
.53215 .74358 Mdot
.5339 .3188 Mdot
.5895 .56189 Mdot
.75488 .65275 Mdot
.31312 .5045 Mdot
.25456 .33491 Mdot
.3573 .4387 Mdot
.63193 .21155 Mdot
.57824 .57595 Mdot
.75254 .5133 Mdot
.39817 .5085 Mdot
.64382 .45316 Mdot
.43686 .53102 Mdot
.36334 .50874 Mdot
.63024 .4521 Mdot
.3629 .46928 Mdot
.56196 .33054 Mdot
.47365 .72523 Mdot
.47919 .51411 Mdot
.40259 .82281 Mdot
.566 .34015 Mdot
.7397 .50438 Mdot
.39424 .46228 Mdot
.52491 .2371 Mdot
.4401 .67897 Mdot
.34945 .51673 Mdot
.41392 .7716 Mdot
.44808 .65052 Mdot
.45429 .66808 Mdot
.33469 .45885 Mdot
.60317 .56092 Mdot
.64068 .44793 Mdot
.53219 .31892 Mdot
.75703 .30822 Mdot
.35707 .50087 Mdot
.37386 .48309 Mdot
.53416 .33974 Mdot
.59137 .60003 Mdot
.34522 .47484 Mdot
.68343 .51226 Mdot
.76574 .29862 Mdot
.57972 .56783 Mdot
.3406 .52816 Mdot
.22325 .3879 Mdot
.47198 .62477 Mdot
.72363 .75576 Mdot
.50306 .36077 Mdot
.67484 .43093 Mdot
.37628 .54757 Mdot
.44284 .11604 Mdot
.55089 .34482 Mdot
.63588 .72941 Mdot
.367 .4568 Mdot
.38995 .48425 Mdot
.46322 .70026 Mdot
.34367 .46304 Mdot
.47987 .66865 Mdot
.43395 .84156 Mdot
.31601 .78995 Mdot
.43353 .6929 Mdot
.45432 .64173 Mdot
.50933 .67666 Mdot
.19753 .53504 Mdot
.44764 .65894 Mdot
.37375 .53087 Mdot
.47644 .20177 Mdot
.34007 .4189 Mdot
.53503 .29893 Mdot
.53225 .36782 Mdot
.47987 .61399 Mdot
.80663 .58985 Mdot
.45318 .43931 Mdot
.33638 .54891 Mdot
.50482 .58188 Mdot
.59397 .56768 Mdot
.35584 .51252 Mdot
.79105 .52406 Mdot
.63048 .40704 Mdot
.37579 .41496 Mdot
.37341 .50822 Mdot
.43321 .66203 Mdot
.5752 .34615 Mdot
.61149 .55719 Mdot
.37143 .47934 Mdot
.59693 .41267 Mdot
.5411 .32679 Mdot
.44 .64936 Mdot
.43766 .76397 Mdot
.56611 .32273 Mdot
.43883 .50486 Mdot
.39187 .47349 Mdot
.36017 .45673 Mdot
.31635 .53116 Mdot
.62246 .59855 Mdot
.69718 .43585 Mdot
.41765 .52057 Mdot
.60457 .77558 Mdot
.52746 .41921 Mdot
.37303 .53721 Mdot
.46064 .69591 Mdot
.56597 .59059 Mdot
.76127 .51004 Mdot
.46574 .28244 Mdot
.34815 .49755 Mdot
.41821 .18945 Mdot
.33759 .6038 Mdot
.78421 .52258 Mdot
.42022 .69131 Mdot
.52585 .33067 Mdot
.32528 .46068 Mdot
.43151 .21071 Mdot
.41267 .49897 Mdot
.38827 .38299 Mdot
.67138 .43656 Mdot
.59545 .5695 Mdot
.74518 .27133 Mdot
.62826 .40914 Mdot
.4567 .66672 Mdot
.47182 .16309 Mdot
.48101 .64527 Mdot
.4896 .677 Mdot
.35145 .24726 Mdot
.61839 .58709 Mdot
.42623 .12055 Mdot
.75107 .716 Mdot
.41418 .46974 Mdot
.58596 .60381 Mdot
.43302 .67387 Mdot
.38555 .45185 Mdot
.46407 .64148 Mdot
.48767 .67658 Mdot
.37937 .52738 Mdot
.39267 .47847 Mdot
.43414 .37926 Mdot
.36804 .20432 Mdot
.52769 .3187 Mdot
.47665 .68617 Mdot
.29825 .61519 Mdot
.40365 .46668 Mdot
.40608 .50596 Mdot
.63977 .37308 Mdot
.53573 .30659 Mdot
.25364 .44673 Mdot
.35901 .46759 Mdot
.43434 .79698 Mdot
.31577 .4711 Mdot
.40982 .66911 Mdot
.58138 .56571 Mdot
.67101 .71458 Mdot
.68619 .40953 Mdot
.47682 .69296 Mdot
.55717 .35519 Mdot
.42755 .64057 Mdot
.39203 .74323 Mdot
.61651 .58722 Mdot
.47051 .68376 Mdot
.67702 .45486 Mdot
.61064 .59236 Mdot
.58607 .56545 Mdot
.47359 .21095 Mdot
.63896 .4647 Mdot
.52289 .34516 Mdot
.6031 .58306 Mdot
.26008 .5737 Mdot
.6039 .60484 Mdot
.31432 .61798 Mdot
.37092 .43705 Mdot
.44816 .37556 Mdot
.57948 .74929 Mdot
.28805 .50367 Mdot
.61948 .61687 Mdot
.5424 .31166 Mdot
.33322 .46892 Mdot
.44918 .7072 Mdot
.55678 .3356 Mdot
.53916 .6056 Mdot
.65228 .46043 Mdot
.42387 .67629 Mdot
.57301 .57347 Mdot
.47596 .67969 Mdot
.4744 .33162 Mdot
.60755 .47623 Mdot
.50701 .59322 Mdot
.54094 .4654 Mdot
.41928 .5013 Mdot
.43961 .59867 Mdot
.31767 .45941 Mdot
.37177 .5102 Mdot
.63966 .43816 Mdot
.39499 .35557 Mdot
.43663 .68174 Mdot
.75514 .27836 Mdot
.58875 .57533 Mdot
.47785 .79587 Mdot
.37782 .39442 Mdot
.34373 .50802 Mdot
.43849 .65347 Mdot
.48764 .6544 Mdot
.33199 .72548 Mdot
.68202 .40895 Mdot
.28458 .47694 Mdot
.42698 .45332 Mdot
.31163 .51653 Mdot
.5766 .57886 Mdot
.68631 .52455 Mdot
.68089 .42169 Mdot
.84029 .62763 Mdot
.66876 .44741 Mdot
.62331 .2902 Mdot
.4672 .6537 Mdot
.53761 .35606 Mdot
.40779 .50235 Mdot
.4303 .38798 Mdot
.41368 .68588 Mdot
.54639 .38295 Mdot
.52963 .34426 Mdot
.69067 .56922 Mdot
.61831 .582 Mdot
.33763 .51921 Mdot
.37551 .52535 Mdot
.34596 .45563 Mdot
.3638 .44088 Mdot
.57343 .60999 Mdot
.40406 .459 Mdot
.61386 .62852 Mdot
.26612 .56878 Mdot
.43342 .79914 Mdot
.65868 .38903 Mdot
.31651 .29949 Mdot
.43315 .65064 Mdot
.26338 .59401 Mdot
.30224 .40996 Mdot
.65561 .76761 Mdot
.52397 .22774 Mdot
.32325 .45284 Mdot
.67035 .40843 Mdot
.25043 .38421 Mdot
.6355 .39193 Mdot
.46025 .89786 Mdot
.56982 .29794 Mdot
.44797 .16552 Mdot
.38658 .45434 Mdot
.61979 .37851 Mdot
.32822 .39723 Mdot
.33746 .52423 Mdot
.55525 .28736 Mdot
.45955 .76988 Mdot
.59605 .71392 Mdot
.5703 .34869 Mdot
.35452 .48984 Mdot
.49199 .68062 Mdot
.37958 .45806 Mdot
.40044 .5123 Mdot
.38517 .44872 Mdot
.58603 .55894 Mdot
.31597 .45026 Mdot
.39259 .44675 Mdot
.75771 .57406 Mdot
.40834 .3385 Mdot
.62836 .4191 Mdot
.36476 .74579 Mdot
.54963 .32695 Mdot
.42909 .67192 Mdot
.49465 .43969 Mdot
.6077 .56506 Mdot
.32152 .7291 Mdot
.37684 .44418 Mdot
.56907 .74614 Mdot
.57179 .57533 Mdot
.55591 .33928 Mdot
.75815 .52004 Mdot
.48608 .18739 Mdot
.65855 .38968 Mdot
.75537 .51627 Mdot
.64254 .44004 Mdot
.22708 .63048 Mdot
.43469 .65997 Mdot
.41719 .51213 Mdot
.5939 .58566 Mdot
.63744 .4467 Mdot
.37251 .34904 Mdot
.37899 .50236 Mdot
.65587 .41787 Mdot
.41966 .50416 Mdot
.51476 .40048 Mdot
.71045 .37945 Mdot
.62837 .39731 Mdot
.62213 .54863 Mdot
.6055 .59101 Mdot
.52287 .33496 Mdot
.42753 .67387 Mdot
.46716 .69142 Mdot
.61512 .60224 Mdot
.68297 .78593 Mdot
.36232 .5097 Mdot
.38957 .45394 Mdot
.60451 .77271 Mdot
.38415 .46489 Mdot
.44386 .29881 Mdot
.78589 .50995 Mdot
.42812 .66424 Mdot
.38112 .45055 Mdot
.34425 .47715 Mdot
.34483 .49136 Mdot
.4736 .34042 Mdot
.66369 .45215 Mdot
.32356 .46778 Mdot
.54893 .30713 Mdot
.7467 .63786 Mdot
.39668 .45802 Mdot
.37217 .54162 Mdot
.46715 .68629 Mdot
.35371 .80365 Mdot
.6006 .56279 Mdot
.64549 .41597 Mdot
.66425 .45663 Mdot
.51459 .36087 Mdot
.4478 .72679 Mdot
.77202 .50335 Mdot
.81987 .41401 Mdot
.7685 .53142 Mdot
.53376 .33416 Mdot
.6467 .26997 Mdot
.59652 .4205 Mdot
.64522 .40952 Mdot
.62844 .61565 Mdot
.37178 .44397 Mdot
.33387 .44466 Mdot
.63891 .73036 Mdot
.3276 .48443 Mdot
.53466 .34873 Mdot
.6269 .59688 Mdot
.46281 .6867 Mdot
.55514 .34648 Mdot
.57772 .58902 Mdot
.44588 .7033 Mdot
.31284 .50266 Mdot
.30817 .49279 Mdot
.4538 .67246 Mdot
.43202 .70083 Mdot
.4033 .48318 Mdot
.73311 .57017 Mdot
.4602 .71931 Mdot
.47187 .68077 Mdot
.79041 .53676 Mdot
.65364 .389 Mdot
.43529 .43837 Mdot
.58564 .60512 Mdot
.3606 .45796 Mdot
.64167 .38999 Mdot
.53124 .30768 Mdot
.44148 .68676 Mdot
.34709 .47789 Mdot
.3624 .47837 Mdot
.53057 .32265 Mdot
.57163 .33247 Mdot
.55225 .35161 Mdot
.56599 .62561 Mdot
.35094 .44452 Mdot
.44779 .66072 Mdot
.61651 .58155 Mdot
.56158 .36202 Mdot
.52253 .3502 Mdot
.79021 .57501 Mdot
.40661 .47591 Mdot
.50531 .53409 Mdot
.65403 .15043 Mdot
.43247 .28125 Mdot
.76441 .50775 Mdot
.62229 .45378 Mdot
.44683 .35874 Mdot
.66094 .36511 Mdot
.59369 .61736 Mdot
.40878 .25193 Mdot
.53701 .29655 Mdot
.41026 .5201 Mdot
.31666 .47529 Mdot
.38617 .42946 Mdot
.54509 .3311 Mdot
.47662 .30567 Mdot
.44877 .6367 Mdot
.2608 .6405 Mdot
.5497 .32725 Mdot
.62932 .39709 Mdot
.61337 .42222 Mdot
.66924 .44681 Mdot
.31774 .49416 Mdot
.32317 .72157 Mdot
.27721 .59887 Mdot
.21783 .56184 Mdot
.61862 .58006 Mdot
.47493 .63664 Mdot
.53445 .23744 Mdot
.45194 .66965 Mdot
.63091 .40444 Mdot
.54153 .33144 Mdot
.46979 .69408 Mdot
.60783 .61782 Mdot
.59259 .59685 Mdot
.64988 .45951 Mdot
.65083 .45287 Mdot
.63114 .42845 Mdot
.47486 .70708 Mdot
.467 .65414 Mdot
.34278 .49589 Mdot
.44754 .68413 Mdot
.52032 .81283 Mdot
.51553 .34774 Mdot
.61777 .40918 Mdot
.59565 .6122 Mdot
.43124 .6712 Mdot
.37013 .50194 Mdot
.68331 .30645 Mdot
.59135 .65822 Mdot
.56492 .33136 Mdot
.73945 .41251 Mdot
.50827 .89503 Mdot
.38359 .52449 Mdot
.57451 .60164 Mdot
.69387 .69711 Mdot
.38703 .50516 Mdot
.66137 .43633 Mdot
.20305 .62255 Mdot
.77405 .53447 Mdot
.39346 .44855 Mdot
.33485 .49658 Mdot
.59375 .55888 Mdot
.49051 .36153 Mdot
.33604 .48991 Mdot
.52865 .77747 Mdot
.62146 .5593 Mdot
.67256 .40623 Mdot
.78032 .31046 Mdot
.6581 .47728 Mdot
.34496 .36751 Mdot
.77625 .50994 Mdot
.36935 .52394 Mdot
.64149 .42307 Mdot
.56161 .32303 Mdot
.63514 .42908 Mdot
.41848 .68483 Mdot
.62949 .42153 Mdot
.37631 .48356 Mdot
.45107 .65861 Mdot
.60043 .61607 Mdot
.53038 .80121 Mdot
.76212 .58428 Mdot
.6442 .45365 Mdot
.78695 .54083 Mdot
.39981 .45783 Mdot
.26097 .45499 Mdot
.43948 .52874 Mdot
.39431 .45776 Mdot
.61013 .58261 Mdot
.44061 .65106 Mdot
.58509 .62543 Mdot
.41933 .52674 Mdot
.39824 .7919 Mdot
.5825 .57244 Mdot
.63613 .69565 Mdot
.53406 .33811 Mdot
.40738 .37169 Mdot
.36338 .50427 Mdot
.5977 .58231 Mdot
.35172 .44513 Mdot
.48129 .65318 Mdot
.55574 .51774 Mdot
.75279 .64258 Mdot
.59379 .58678 Mdot
.56217 .18613 Mdot
.54009 .52829 Mdot
.41213 .42162 Mdot
.59598 .57981 Mdot
.27105 .69394 Mdot
.76848 .51105 Mdot
.53609 .32672 Mdot
.56554 .35835 Mdot
.56772 .33963 Mdot
.32657 .48903 Mdot
.28698 .44184 Mdot
.52355 .34937 Mdot
.61268 .55305 Mdot
.53867 .3054 Mdot
.44556 .38902 Mdot
.55201 .18679 Mdot
.55857 .35057 Mdot
.3628 .49413 Mdot
.37292 .54266 Mdot
.40413 .33981 Mdot
.6449 .39643 Mdot
.39159 .19884 Mdot
.40094 .61432 Mdot
.40088 .47224 Mdot
.38854 .40753 Mdot
.42182 .66802 Mdot
.72665 .68743 Mdot
.38302 .40007 Mdot
.69903 .37815 Mdot
.47217 .6501 Mdot
.63634 .4757 Mdot
.42793 .66779 Mdot
.40409 .51744 Mdot
.3695 .46178 Mdot
.48057 .72384 Mdot
.64841 .52394 Mdot
.69443 .64845 Mdot
.68923 .24931 Mdot
.47306 .68781 Mdot
.58671 .58613 Mdot
.58144 .61707 Mdot
.61236 .57348 Mdot
.68942 .42148 Mdot
.45159 .71541 Mdot
.3397 .44694 Mdot
.67115 .4206 Mdot
.36142 .51222 Mdot
.60868 .58747 Mdot
.74069 .26637 Mdot
.46585 .68622 Mdot
.40485 .49529 Mdot
.76687 .69069 Mdot
.65576 .44711 Mdot
.53685 .31842 Mdot
.52762 .40102 Mdot
.686 .45231 Mdot
.61532 .61944 Mdot
.49897 .67696 Mdot
.55862 .58223 Mdot
.49061 .45436 Mdot
.33266 .42409 Mdot
.35988 .5329 Mdot
.77979 .33277 Mdot
.79757 .61606 Mdot
.32239 .49237 Mdot
.66309 .41395 Mdot
.65651 .39365 Mdot
.34888 .48115 Mdot
.45478 .71142 Mdot
.55267 .36369 Mdot
.55331 .30798 Mdot
.43682 .4988 Mdot
.54384 .477 Mdot
.44272 .37939 Mdot
.34528 .46898 Mdot
.28054 .48649 Mdot
.65383 .46228 Mdot
.75703 .52378 Mdot
.59985 .76198 Mdot
.55063 .35798 Mdot
.36512 .45792 Mdot
.63924 .67248 Mdot
.47933 .66213 Mdot
.63062 .42234 Mdot
.62085 .60759 Mdot
.48484 .31059 Mdot
.68399 .44743 Mdot
.34936 .48001 Mdot
.34508 .47529 Mdot
.59174 .56027 Mdot
.40994 .669 Mdot
.54344 .33287 Mdot
.67097 .42271 Mdot
.54458 .35931 Mdot
.46324 .65668 Mdot
.46295 .68355 Mdot
.34409 .41684 Mdot
.31912 .53152 Mdot
.6519 .45737 Mdot
.43046 .48854 Mdot
.62678 .4042 Mdot
.49123 .34227 Mdot
.56803 .5994 Mdot
.36716 .52728 Mdot
.49307 .65681 Mdot
.61231 .58897 Mdot
.39564 .48531 Mdot
.83305 .40127 Mdot
.34996 .51382 Mdot
.69434 .44223 Mdot
.40439 .79591 Mdot
.53916 .30895 Mdot
.40447 .72507 Mdot
.38212 .57175 Mdot
.38297 .46644 Mdot
.61713 .4164 Mdot
.43899 .52652 Mdot
.58484 .56778 Mdot
.46231 .64656 Mdot
.65431 .82733 Mdot
.60517 .60107 Mdot
.3772 .45646 Mdot
.55426 .336 Mdot
.48942 .65545 Mdot
.78245 .53007 Mdot
.6132 .76156 Mdot
.38956 .41925 Mdot
.30562 .49238 Mdot
.37535 .44687 Mdot
.18686 .49798 Mdot
.64184 .41844 Mdot
.43212 .67248 Mdot
.57463 .5834 Mdot
.61213 .60822 Mdot
.66983 .4424 Mdot
.57326 .72764 Mdot
.63659 .50493 Mdot
.53874 .09052 Mdot
.62902 .44842 Mdot
.52993 .30476 Mdot
.5291 .44776 Mdot
.62321 .41486 Mdot
.64956 .42308 Mdot
.66386 .45777 Mdot
.60177 .74103 Mdot
.45232 .70113 Mdot
.36214 .47704 Mdot
.44203 .72507 Mdot
.36631 .52384 Mdot
.28316 .38929 Mdot
.6176 .59949 Mdot
.46525 .64863 Mdot
.80888 .36407 Mdot
.46715 .48444 Mdot
.38395 .49871 Mdot
.5612 .23229 Mdot
.44453 .50346 Mdot
.45907 .31376 Mdot
.44893 .47653 Mdot
.6451 .44775 Mdot
.32994 .41076 Mdot
.34716 .53857 Mdot
.51881 .81004 Mdot
.59229 .61146 Mdot
.77762 .50819 Mdot
.32528 .44575 Mdot
.397 .42635 Mdot
.49117 .66524 Mdot
.47043 .69366 Mdot
.52452 .34994 Mdot
.54823 .43079 Mdot
.59784 .6156 Mdot
.59262 .46733 Mdot
.39567 .47048 Mdot
.59109 .53543 Mdot
.39558 .76349 Mdot
.39682 .48673 Mdot
.4598 .20496 Mdot
.32511 .72839 Mdot
.33706 .49355 Mdot
.24437 .64438 Mdot
.59388 .60137 Mdot
.42927 .79165 Mdot
.42045 .46594 Mdot
.65975 .43653 Mdot
.46034 .64909 Mdot
.42146 .67306 Mdot
.5626 .34455 Mdot
.61198 .80149 Mdot
.6147 .62293 Mdot
.46655 .65177 Mdot
.38368 .50844 Mdot
.62188 .6019 Mdot
.78892 .52138 Mdot
.35928 .5399 Mdot
.39711 .24501 Mdot
.45094 .68504 Mdot
.41196 .44899 Mdot
.52962 .6755 Mdot
.50978 .40627 Mdot
.32983 .21695 Mdot
.60745 .57031 Mdot
.55137 .35545 Mdot
.4445 .45527 Mdot
.8162 .40978 Mdot
.37381 .42782 Mdot
.41405 .36552 Mdot
.4637 .61304 Mdot
.53175 .35334 Mdot
.39423 .50288 Mdot
.33589 .48428 Mdot
.53268 .47386 Mdot
.57332 .33897 Mdot
.35663 .52037 Mdot
.32131 .42546 Mdot
.44445 .70167 Mdot
.78388 .50957 Mdot
.45582 .68764 Mdot
.36597 .49595 Mdot
.29123 .43359 Mdot
.45696 .70572 Mdot
.68208 .27332 Mdot
.56005 .30694 Mdot
.60151 .56375 Mdot
.2802 .46825 Mdot
.37513 .43879 Mdot
.1712 .43226 Mdot
.76987 .50632 Mdot
.19256 .59289 Mdot
.64336 .46996 Mdot
.65694 .64912 Mdot
.59325 .39723 Mdot
.47421 .17023 Mdot
.54359 .792 Mdot
.36581 .42028 Mdot
.35478 .29061 Mdot
.2312 .61019 Mdot
.60085 .62756 Mdot
.24414 .52837 Mdot
.39693 .46925 Mdot
.39318 .51582 Mdot
.66026 .40363 Mdot
.55883 .73939 Mdot
.68639 .70026 Mdot
.55708 .48478 Mdot
.5435 .33743 Mdot
.47041 .66137 Mdot
.38042 .4769 Mdot
.70698 .48018 Mdot
.62609 .42743 Mdot
.53849 .56808 Mdot
.40222 .50132 Mdot
.68085 .73203 Mdot
.6228 .71474 Mdot
.62336 .59855 Mdot
.61868 .44461 Mdot
.68309 .4545 Mdot
.40591 .51301 Mdot
.61559 .61669 Mdot
.34132 .4961 Mdot
.55154 .53718 Mdot
.42755 .47225 Mdot
.55972 .33849 Mdot
.41373 .47777 Mdot
.51477 .49208 Mdot
.39915 .16896 Mdot
.43223 .42429 Mdot
.43684 .7136 Mdot
.68984 .42721 Mdot
.66557 .44947 Mdot
.46983 .69003 Mdot
.66543 .44786 Mdot
.27419 .65697 Mdot
.37533 .66429 Mdot
.54237 .34114 Mdot
.28216 .43589 Mdot
.55957 .33293 Mdot
.77531 .50714 Mdot
.40473 .4747 Mdot
.83171 .43409 Mdot
.63409 .45282 Mdot
.26366 .71262 Mdot
.60495 .6069 Mdot
.77339 .50721 Mdot
.37306 .4295 Mdot
.64089 .26852 Mdot
.63892 .39997 Mdot
.68397 .46237 Mdot
.34471 .49276 Mdot
.46429 .69587 Mdot
.33631 .48209 Mdot
.44114 .47018 Mdot
.75624 .5151 Mdot
.37162 .44449 Mdot
.57777 .58943 Mdot
.46031 .71453 Mdot
.50592 .18636 Mdot
.67961 .4022 Mdot
.41405 .48906 Mdot
.38512 .50813 Mdot
.47867 .64744 Mdot
.38051 .43358 Mdot
.60382 .62055 Mdot
.30786 .16568 Mdot
.53329 .33657 Mdot
.76134 .53122 Mdot
.6951 .44508 Mdot
.3224 .45647 Mdot
.34147 .47175 Mdot
.77268 .32051 Mdot
.73298 .61851 Mdot
.58042 .58604 Mdot
.44116 .49596 Mdot
.6644 .41844 Mdot
.5549 .33839 Mdot
.6196 .5615 Mdot
.35793 .45873 Mdot
.40229 .50823 Mdot
.55895 .34069 Mdot
.48994 .20594 Mdot
.71443 .38558 Mdot
.61632 .57634 Mdot
.33364 .40816 Mdot
.69295 .32032 Mdot
.36277 .5093 Mdot
.72818 .32253 Mdot
.47048 .68068 Mdot
.59975 .57641 Mdot
.20593 .54305 Mdot
.41872 .51143 Mdot
.59688 .62093 Mdot
.59666 .61451 Mdot
.41794 .47594 Mdot
.44741 .72575 Mdot
.48078 .69672 Mdot
.47636 .67513 Mdot
.41129 .80874 Mdot
.32522 .34662 Mdot
.63096 .43032 Mdot
.59274 .60069 Mdot
.63075 .39379 Mdot
.5606 .36427 Mdot
.52897 .42202 Mdot
.63937 .3938 Mdot
.42207 .66906 Mdot
.61307 .42086 Mdot
.33977 .48715 Mdot
.59908 .61711 Mdot
.6439 .40931 Mdot
.31871 .46914 Mdot
.29378 .52747 Mdot
.51709 .54167 Mdot
.54579 .36248 Mdot
.51914 .37789 Mdot
.37122 .46879 Mdot
.75996 .51145 Mdot
.40514 .48585 Mdot
.62567 .5922 Mdot
.5105 .47027 Mdot
.32042 .46763 Mdot
.64731 .456 Mdot
.44473 .55789 Mdot
.66685 .4006 Mdot
.43339 .4597 Mdot
.36588 .49377 Mdot
.36838 .51396 Mdot
.33587 .49035 Mdot
.6204 .70546 Mdot
.59463 .62945 Mdot
.28184 .51692 Mdot
.61961 .39149 Mdot
.44577 .67622 Mdot
.43777 .63663 Mdot
.71821 .34239 Mdot
.75468 .5253 Mdot
.58714 .60538 Mdot
.36011 .50702 Mdot
.68699 .46188 Mdot
.73295 .25953 Mdot
.71541 .2949 Mdot
.54933 .2512 Mdot
.65672 .41069 Mdot
.43477 .71113 Mdot
.62937 .41298 Mdot
.39119 .51929 Mdot
.40578 .53093 Mdot
.48381 .1767 Mdot
.61647 .63761 Mdot
.54248 .33106 Mdot
.36826 .51657 Mdot
.33443 .37058 Mdot
.66507 .41796 Mdot
.65209 .46335 Mdot
.35437 .51473 Mdot
.47715 .69502 Mdot
.25503 .26 Mdot
.62307 .6039 Mdot
.25165 .47173 Mdot
.40633 .6325 Mdot
.47009 .77097 Mdot
.61486 .60931 Mdot
.5098 .56575 Mdot
.68059 .43681 Mdot
.3911 .68727 Mdot
.44941 .676 Mdot
.54379 .32766 Mdot
.39002 .53492 Mdot
.42251 .67109 Mdot
.63197 .46623 Mdot
.43387 .65312 Mdot
.40686 .51831 Mdot
.59538 .62814 Mdot
.67494 .43924 Mdot
.61928 .54308 Mdot
.48056 .72455 Mdot
.55421 .31876 Mdot
.40609 .37268 Mdot
.24606 .51153 Mdot
.32373 .72855 Mdot
.32361 .46717 Mdot
.72061 .42278 Mdot
.3477 .44616 Mdot
.49021 .67121 Mdot
.36283 .50248 Mdot
.47815 .61203 Mdot
.62882 .45659 Mdot
.41253 .44994 Mdot
.39769 .45178 Mdot
.29157 .56866 Mdot
.39075 .4952 Mdot
.39472 .44353 Mdot
.33296 .4887 Mdot
.41038 .62407 Mdot
.35486 .41734 Mdot
.45754 .69971 Mdot
.62828 .73395 Mdot
.64818 .4248 Mdot
.53861 .36266 Mdot
.56264 .31873 Mdot
.42421 .36868 Mdot
.40141 .36964 Mdot
.57547 .73117 Mdot
.45269 .6936 Mdot
.5785 .60122 Mdot
.34193 .49717 Mdot
.21027 .51885 Mdot
.50922 .30329 Mdot
.67894 .4382 Mdot
.69059 .41575 Mdot
.33403 .53949 Mdot
.1859 .49147 Mdot
.40304 .43868 Mdot
.6192 .76415 Mdot
.43541 .49563 Mdot
.35077 .51754 Mdot
.68788 .44562 Mdot
.47448 .39168 Mdot
.3234 .46774 Mdot
.49119 .66458 Mdot
.54241 .32329 Mdot
.42928 .41657 Mdot
.60024 .3363 Mdot
.52993 .55832 Mdot
.34131 .58447 Mdot
.34909 .44179 Mdot
.67295 .42839 Mdot
.42407 .67743 Mdot
.59205 .77515 Mdot
.61466 .57989 Mdot
.57621 .75579 Mdot
.28292 .5847 Mdot
.63828 .24613 Mdot
.54147 .32693 Mdot
.48183 .20849 Mdot
.37625 .48286 Mdot
.69083 .42978 Mdot
.38875 .52527 Mdot
.7268 .25505 Mdot
.52139 .31664 Mdot
.41358 .69336 Mdot
.58512 .58792 Mdot
.48108 .65457 Mdot
.3365 .71397 Mdot
.49543 .59472 Mdot
.72599 .51208 Mdot
.65549 .39001 Mdot
.25327 .42792 Mdot
.44423 .65802 Mdot
.35287 .46991 Mdot
.57663 .10683 Mdot
.47075 .67896 Mdot
.47877 .68187 Mdot
.49946 .36702 Mdot
.51994 .27029 Mdot
.42936 .53292 Mdot
.43843 .64699 Mdot
.61681 .39994 Mdot
.53251 .3152 Mdot
.32932 .4705 Mdot
.33365 .48543 Mdot
.46427 .69877 Mdot
.63373 .40134 Mdot
.24344 .43312 Mdot
.64829 .45094 Mdot
.4404 .70078 Mdot
.65028 .44255 Mdot
.70028 .41062 Mdot
.64776 .41211 Mdot
.37924 .43733 Mdot
.35826 .5031 Mdot
.60377 .31701 Mdot
.46276 .68353 Mdot
.33897 .46711 Mdot
.36511 .46321 Mdot
.44552 .66046 Mdot
.5976 .41799 Mdot
.21045 .50096 Mdot
.38985 .45976 Mdot
.3578 .48766 Mdot
.53837 .357 Mdot
.60949 .45463 Mdot
.75048 .43278 Mdot
.33298 .46837 Mdot
.54589 .30393 Mdot
.47465 .70862 Mdot
.40366 .48582 Mdot
.45433 .39288 Mdot
.685 .39705 Mdot
.41747 .48443 Mdot
.78415 .53009 Mdot
.32703 .45028 Mdot
.26949 .25163 Mdot
.41141 .48059 Mdot
.43402 .67401 Mdot
.45095 .64922 Mdot
.53065 .38583 Mdot
.46007 .66579 Mdot
.78183 .51236 Mdot
.6089 .58936 Mdot
.65912 .22602 Mdot
.78729 .51987 Mdot
.34374 .51322 Mdot
.75078 .71646 Mdot
.4278 .49062 Mdot
.3243 .44789 Mdot
.19651 .55026 Mdot
.78601 .51908 Mdot
.43921 .65528 Mdot
.65054 .52915 Mdot
.43583 .50247 Mdot
.62088 .60893 Mdot
.35582 .53606 Mdot
.41442 .47398 Mdot
.50289 .77565 Mdot
.37004 .7751 Mdot
.62396 .58238 Mdot
.44518 .44979 Mdot
.33321 .46764 Mdot
.78781 .60536 Mdot
.3767 .50296 Mdot
.56028 .34885 Mdot
.47856 .67768 Mdot
.62245 .4284 Mdot
.52928 .33296 Mdot
.38927 .46756 Mdot
.54742 .33007 Mdot
.63144 .42366 Mdot
.60719 .57996 Mdot
.41369 .49405 Mdot
.53763 .29899 Mdot
.5441 .33609 Mdot
.34574 .45066 Mdot
.46366 .64903 Mdot
.46199 .4637 Mdot
.40209 .48575 Mdot
.35226 .47393 Mdot
.46705 .69143 Mdot
.84887 .5763 Mdot
.39581 .51961 Mdot
.50677 .5373 Mdot
.41614 .6991 Mdot
.79629 .52327 Mdot
.63794 .40813 Mdot
.42088 .48937 Mdot
.61987 .59705 Mdot
.61635 .59394 Mdot
.61554 .44517 Mdot
.4829 .65372 Mdot
.64503 .39734 Mdot
.45061 .45191 Mdot
.30928 .52431 Mdot
.42347 .51722 Mdot
.63796 .83085 Mdot
.46994 .18301 Mdot
.44815 .71344 Mdot
.68193 .42476 Mdot
.55991 .48394 Mdot
.58835 .59976 Mdot
.61181 .42299 Mdot
.49603 .66814 Mdot
.43215 .70437 Mdot
.43163 .65281 Mdot
.53788 .35489 Mdot
.68277 .44454 Mdot
.40983 .67499 Mdot
.48008 .68857 Mdot
.34275 .49034 Mdot
.33436 .46665 Mdot
.50182 .63643 Mdot
.41959 .32903 Mdot
.55805 .32406 Mdot
.66977 .43483 Mdot
.1472 .44437 Mdot
.62542 .59058 Mdot
.29508 .56974 Mdot
.32041 .46117 Mdot
.79324 .25915 Mdot
.41092 .44401 Mdot
.38109 .50734 Mdot
.46554 .71439 Mdot
.52176 .3062 Mdot
.55049 .32083 Mdot
.44574 .6563 Mdot
.49821 .6924 Mdot
.55756 .35356 Mdot
.51554 .22868 Mdot
.56532 .18299 Mdot
.58083 .77211 Mdot
.43771 .67037 Mdot
.24856 .50641 Mdot
.61496 .61904 Mdot
.46761 .73313 Mdot
.61782 .57036 Mdot
.65084 .42393 Mdot
.67517 .45253 Mdot
.59493 .55934 Mdot
.34662 .49514 Mdot
.63413 .4173 Mdot
.36749 .41239 Mdot
.53394 .20911 Mdot
.28843 .29889 Mdot
.72 .6015 Mdot
.31633 .46809 Mdot
.67582 .71129 Mdot
.70506 .67249 Mdot
.37713 .46683 Mdot
.45002 .41339 Mdot
.54386 .33011 Mdot
.44671 .73233 Mdot
.60679 .61986 Mdot
.31704 .22629 Mdot
.3617 .5084 Mdot
.43597 .68369 Mdot
.59005 .60996 Mdot
.56831 .39345 Mdot
.52572 .77413 Mdot
.36521 .52185 Mdot
.47713 .10098 Mdot
.43442 .72918 Mdot
.62246 .42963 Mdot
.68399 .76871 Mdot
.4381 .72395 Mdot
.51242 .37224 Mdot
.65663 .46562 Mdot
.71397 .2784 Mdot
.42898 .6738 Mdot
.62157 .45981 Mdot
.46312 .6589 Mdot
.56185 .33813 Mdot
.48415 .70732 Mdot
.67625 .43524 Mdot
.3941 .49933 Mdot
.66568 .44381 Mdot
.55892 .32396 Mdot
.69045 .42127 Mdot
.61114 .61939 Mdot
.76894 .50828 Mdot
.59807 .59307 Mdot
.52302 .41161 Mdot
.3831 .78423 Mdot
.59603 .56928 Mdot
.57929 .41995 Mdot
.32126 .48922 Mdot
.41171 .66151 Mdot
.62465 .44465 Mdot
.61778 .39416 Mdot
.5371 .43826 Mdot
.44474 .67129 Mdot
.67235 .43838 Mdot
.27395 .58215 Mdot
.81537 .65748 Mdot
.28541 .44802 Mdot
.33658 .32841 Mdot
.44341 .66306 Mdot
.63585 .46312 Mdot
.60465 .77146 Mdot
.43086 .64882 Mdot
.62922 .4478 Mdot
.59381 .58193 Mdot
.61294 .6088 Mdot
.35647 .51162 Mdot
.63409 .61594 Mdot
.61686 .42954 Mdot
.67767 .65976 Mdot
.48162 .66514 Mdot
.56596 .39514 Mdot
.56475 .3451 Mdot
.65033 .41913 Mdot
.33616 .53452 Mdot
.50446 .66967 Mdot
.66151 .38856 Mdot
.35393 .27155 Mdot
.14671 .47192 Mdot
.66994 .43985 Mdot
.47945 .67562 Mdot
.44024 .68839 Mdot
.44395 .51248 Mdot
.54113 .4734 Mdot
.65221 .39859 Mdot
.83568 .4587 Mdot
.40049 .36148 Mdot
.76955 .52429 Mdot
.8045 .61546 Mdot
.32261 .46719 Mdot
.35479 .4456 Mdot
.58604 .59866 Mdot
.3804 .49252 Mdot
.47947 .69445 Mdot
.34624 .43511 Mdot
.59022 .6194 Mdot
.67988 .43434 Mdot
.41135 .48767 Mdot
.539 .3113 Mdot
.62732 .608 Mdot
.60227 .55818 Mdot
.64335 .43302 Mdot
.43597 .64857 Mdot
.69046 .4823 Mdot
.65204 .45302 Mdot
.34561 .44233 Mdot
.78167 .52139 Mdot
.41721 .50936 Mdot
.45746 .22869 Mdot
.45563 .63691 Mdot
.62595 .41598 Mdot
.42066 .6908 Mdot
.6002 .59666 Mdot
.60794 .41475 Mdot
.3732 .49773 Mdot
.63263 .44893 Mdot
.62899 .35932 Mdot
.49116 .22504 Mdot
.48515 .65615 Mdot
.59424 .36257 Mdot
.48081 .68027 Mdot
.76942 .52558 Mdot
.44879 .25222 Mdot
.53652 .33181 Mdot
.66094 .41925 Mdot
.45416 .18248 Mdot
.6438 .45713 Mdot
.391 .49317 Mdot
.39072 .48042 Mdot
.65898 .40412 Mdot
.52463 .31995 Mdot
.35586 .80277 Mdot
.49934 .56481 Mdot
.43513 .65735 Mdot
.39467 .64749 Mdot
.1595 .38959 Mdot
.62249 .55746 Mdot
.58255 .59585 Mdot
.41671 .44414 Mdot
.34487 .509 Mdot
.60605 .55675 Mdot
.57037 .59816 Mdot
.54403 .3607 Mdot
.6696 .45361 Mdot
.40429 .69019 Mdot
.63033 .57316 Mdot
.41705 .56497 Mdot
.35292 .36828 Mdot
.4371 .51886 Mdot
.29902 .45331 Mdot
.31398 .48826 Mdot
.50613 .39931 Mdot
.57275 .59738 Mdot
.3694 .47002 Mdot
.36203 .41699 Mdot
.59242 .57828 Mdot
.5613 .33695 Mdot
.47594 .75028 Mdot
.65509 .43982 Mdot
.87425 .48624 Mdot
.41594 .48599 Mdot
.39775 .49464 Mdot
.6189 .58071 Mdot
.80881 .59019 Mdot
.43604 .70386 Mdot
.45294 .63922 Mdot
.64051 .41825 Mdot
.539 .4364 Mdot
.36837 .43241 Mdot
.37463 .46749 Mdot
.66158 .42574 Mdot
.76619 .50866 Mdot
.70458 .59774 Mdot
.36279 .47975 Mdot
.59501 .61024 Mdot
.70885 .41816 Mdot
.57217 .59856 Mdot
.38298 .52515 Mdot
.39019 .49106 Mdot
.37942 .4368 Mdot
.34382 .50876 Mdot
.61603 .56319 Mdot
.37276 .47358 Mdot
.33558 .53652 Mdot
.45227 .6432 Mdot
.36584 .43976 Mdot
.44074 .37105 Mdot
.35878 .49235 Mdot
.54521 .31322 Mdot
.72467 .46587 Mdot
.3673 .51464 Mdot
.36821 .44082 Mdot
.50177 .55951 Mdot
.39401 .5063 Mdot
.6239 .58626 Mdot
.44432 .68087 Mdot
.59246 .60012 Mdot
.57581 .57953 Mdot
.62475 .3937 Mdot
.54172 .36025 Mdot
.35684 .42453 Mdot
.56681 .33292 Mdot
.29563 .47263 Mdot
.40552 .5195 Mdot
.69974 .46926 Mdot
.62049 .76222 Mdot
.67734 .36892 Mdot
.37034 .49796 Mdot
.6443 .42056 Mdot
.62333 .4249 Mdot
.35365 .28423 Mdot
.39997 .41711 Mdot
.61489 .55927 Mdot
.59723 .5826 Mdot
.43927 .29403 Mdot
.50695 .78016 Mdot
.55255 .31775 Mdot
.57943 .48972 Mdot
.31614 .48726 Mdot
.3599 .47351 Mdot
.36788 .54083 Mdot
.63824 .39353 Mdot
.755 .51894 Mdot
.67868 .441 Mdot
.80009 .51507 Mdot
.57487 .61001 Mdot
.3359 .44325 Mdot
.30505 .27661 Mdot
.46393 .70301 Mdot
.44501 .68108 Mdot
.60912 .55399 Mdot
.65849 .39686 Mdot
.4454 .51612 Mdot
.65913 .82867 Mdot
.4503 .73785 Mdot
.51468 .33605 Mdot
.37594 .46322 Mdot
.64226 .42859 Mdot
.46917 .70055 Mdot
.5586 .30947 Mdot
.38619 .44856 Mdot
.61064 .39449 Mdot
.36074 .50004 Mdot
.22833 .61095 Mdot
.44958 .64539 Mdot
.73032 .25346 Mdot
.48094 .64556 Mdot
.62735 .61001 Mdot
.58744 .57454 Mdot
.39461 .4866 Mdot
.65565 .80984 Mdot
.41574 .70517 Mdot
.63542 .56856 Mdot
.52021 .31327 Mdot
.75987 .52926 Mdot
.51918 .33357 Mdot
.62217 .41476 Mdot
.54098 .3247 Mdot
.66344 .45681 Mdot
.42956 .30374 Mdot
.43075 .73345 Mdot
.53128 .33474 Mdot
.78355 .58317 Mdot
.31893 .44459 Mdot
.5614 .3615 Mdot
.32825 .53515 Mdot
.39346 .67202 Mdot
.65961 .42852 Mdot
.52583 .31736 Mdot
.35053 .47156 Mdot
.30584 .24671 Mdot
.58266 .57444 Mdot
.6181 .56186 Mdot
.31935 .44076 Mdot
.66305 .45911 Mdot
.49499 .69804 Mdot
.49471 .45497 Mdot
.79459 .5157 Mdot
.37337 .46962 Mdot
.33267 .44519 Mdot
.44351 .63355 Mdot
.47952 .63886 Mdot
.39025 .48856 Mdot
.25228 .55625 Mdot
.37686 .48005 Mdot
.61898 .60373 Mdot
.43281 .70319 Mdot
.44209 .6863 Mdot
.61684 .43561 Mdot
.48545 .66573 Mdot
.29845 .45129 Mdot
.61407 .64435 Mdot
.43375 .50928 Mdot
.60536 .59836 Mdot
.51035 .48357 Mdot
.68599 .40985 Mdot
.35796 .21491 Mdot
.45199 .63318 Mdot
.37152 .44353 Mdot
.48364 .67187 Mdot
.54882 .35098 Mdot
.45999 .6833 Mdot
.43661 .71657 Mdot
.39542 .47458 Mdot
.36889 .52367 Mdot
.78259 .51601 Mdot
.54305 .46977 Mdot
.47424 .65626 Mdot
.37823 .47367 Mdot
.427 .4805 Mdot
.40703 .45789 Mdot
.5311 .51119 Mdot
.44371 .71483 Mdot
.33837 .62333 Mdot
.37596 .24834 Mdot
.46965 .65271 Mdot
.24322 .28517 Mdot
.77783 .53288 Mdot
.75632 .52675 Mdot
.63287 .57193 Mdot
.3611 .47948 Mdot
.67416 .4096 Mdot
.39671 .51713 Mdot
.35523 .41183 Mdot
.4021 .50986 Mdot
.53153 .3069 Mdot
.35396 .42337 Mdot
.76546 .51934 Mdot
.65601 .45294 Mdot
.38736 .4535 Mdot
.41201 .49144 Mdot
.75269 .52454 Mdot
.46046 .63368 Mdot
.42754 .69287 Mdot
.72219 .31147 Mdot
.54694 .34581 Mdot
.6118 .58187 Mdot
.35229 .50396 Mdot
.64335 .41925 Mdot
.66385 .44598 Mdot
.48271 .65986 Mdot
.66108 .43841 Mdot
.62473 .59986 Mdot
.37732 .49919 Mdot
.61525 .56051 Mdot
.53708 .30682 Mdot
.47711 .68032 Mdot
.35395 .50677 Mdot
.34305 .49005 Mdot
.45055 .64926 Mdot
.32111 .48955 Mdot
.53894 .35719 Mdot
.6538 .45633 Mdot
.42777 .68384 Mdot
.61109 .59047 Mdot
.61476 .42649 Mdot
.34209 .48031 Mdot
.15228 .49492 Mdot
.3796 .48928 Mdot
.35138 .48051 Mdot
.52915 .18069 Mdot
.42318 .44958 Mdot
.62327 .44749 Mdot
.43187 .64193 Mdot
.30784 .48564 Mdot
.32479 .36759 Mdot
.78692 .36064 Mdot
.61118 .41797 Mdot
.38039 .45711 Mdot
.3792 .20105 Mdot
.38417 .45474 Mdot
.59262 .46927 Mdot
.71933 .36869 Mdot
.26088 .38687 Mdot
.29623 .4593 Mdot
.60852 .56261 Mdot
.78155 .51407 Mdot
.63792 .46086 Mdot
.28077 .69799 Mdot
.38855 .47288 Mdot
.26465 .68893 Mdot
.40469 .46004 Mdot
.61261 .61058 Mdot
.46441 .50194 Mdot
.66824 .43615 Mdot
.57455 .81005 Mdot
.34189 .44569 Mdot
.44227 .71361 Mdot
.6175 .40859 Mdot
.76648 .53266 Mdot
.34773 .47713 Mdot
.56148 .31956 Mdot
.63834 .55142 Mdot
.2921 .50646 Mdot
.60821 .59761 Mdot
.36445 .46163 Mdot
.43392 .43415 Mdot
.63573 .80577 Mdot
.44506 .64631 Mdot
.58432 .59173 Mdot
.73294 .6756 Mdot
.32435 .49815 Mdot
.42831 .67639 Mdot
.44856 .67538 Mdot
.56398 .3357 Mdot
.6006 .51745 Mdot
.54302 .6666 Mdot
.25075 .33448 Mdot
.35927 .74249 Mdot
.62271 .45285 Mdot
.70427 .65115 Mdot
.32985 .46695 Mdot
.50633 .59828 Mdot
.61956 .57541 Mdot
.39716 .49703 Mdot
.38181 .76045 Mdot
.47522 .67737 Mdot
.3634 .48523 Mdot
.56029 .3349 Mdot
.61826 .52269 Mdot
.53016 .57238 Mdot
.18688 .40839 Mdot
.61337 .40782 Mdot
.38764 .53718 Mdot
.29296 .47328 Mdot
.79299 .53034 Mdot
.39864 .52403 Mdot
.63128 .45521 Mdot
.54381 .22184 Mdot
.5238 .31882 Mdot
.47404 .69358 Mdot
.77663 .53314 Mdot
.31161 .47949 Mdot
.41976 .46828 Mdot
.53696 .36215 Mdot
.35593 .45521 Mdot
.61832 .79655 Mdot
.74675 .49847 Mdot
.63846 .41317 Mdot
.42974 .6582 Mdot
.31878 .49648 Mdot
.75557 .51806 Mdot
.39375 .47668 Mdot
.36102 .58122 Mdot
.36434 .44582 Mdot
.52729 .69362 Mdot
.46123 .64985 Mdot
.60605 .59456 Mdot
.30219 .46096 Mdot
.38947 .51536 Mdot
.68757 .31323 Mdot
.35551 .41192 Mdot
.4126 .48214 Mdot
.49111 .66213 Mdot
.45651 .7096 Mdot
.45844 .69806 Mdot
.62858 .42217 Mdot
.59081 .76591 Mdot
.59843 .60642 Mdot
.35936 .42892 Mdot
.63012 .57316 Mdot
.37434 .57684 Mdot
.52512 .3541 Mdot
.24724 .30218 Mdot
.3783 .44354 Mdot
.45404 .69715 Mdot
.62068 .68036 Mdot
.47584 .70666 Mdot
.61863 .38944 Mdot
.59825 .61593 Mdot
.4726 .67668 Mdot
.38402 .51269 Mdot
.54772 .48519 Mdot
.19913 .41377 Mdot
.59103 .59486 Mdot
.38239 .54179 Mdot
.61081 .4083 Mdot
.68674 .40516 Mdot
.17012 .34545 Mdot
.58051 .58314 Mdot
.70946 .66707 Mdot
.38063 .46999 Mdot
.46287 .70274 Mdot
.60518 .56809 Mdot
.59387 .56328 Mdot
.66173 .43108 Mdot
.36766 .52172 Mdot
.37052 .51388 Mdot
.78265 .53087 Mdot
.6013 .58252 Mdot
.31122 .45682 Mdot
.42778 .5084 Mdot
.48673 .17627 Mdot
.46362 .75431 Mdot
.8548 .5473 Mdot
.45021 .45091 Mdot
.35866 .7481 Mdot
.51989 .44167 Mdot
.45511 .71454 Mdot
.36607 .51722 Mdot
.31974 .50487 Mdot
.61841 .43975 Mdot
.37748 .49403 Mdot
.67822 .40888 Mdot
.58117 .59951 Mdot
.22939 .31559 Mdot
.60952 .65218 Mdot
.52767 .2313 Mdot
.38448 .49628 Mdot
.49134 .76744 Mdot
.53147 .34294 Mdot
.55959 .60966 Mdot
.4377 .70063 Mdot
.33466 .51544 Mdot
.69177 .44534 Mdot
.66172 .41857 Mdot
.45764 .67249 Mdot
.67029 .69363 Mdot
.71907 .32055 Mdot
.37129 .5276 Mdot
.63838 .40636 Mdot
.66441 .63352 Mdot
.24876 .56246 Mdot
.60998 .63866 Mdot
.52297 .31766 Mdot
.67906 .43541 Mdot
.5857 .56154 Mdot
.50785 .68287 Mdot
.46786 .66991 Mdot
.42053 .65725 Mdot
.65591 .33678 Mdot
.66022 .39937 Mdot
.52769 .32629 Mdot
.5453 .78249 Mdot
.52842 .79402 Mdot
.52806 .30894 Mdot
.6807 .43259 Mdot
.46277 .70624 Mdot
.43517 .69104 Mdot
.44339 .68091 Mdot
.5633 .81173 Mdot
.46202 .63916 Mdot
.35927 .60946 Mdot
.42658 .48682 Mdot
.26884 .44443 Mdot
.38368 .45598 Mdot
.62058 .57016 Mdot
.44892 .64618 Mdot
.53118 .4424 Mdot
.33383 .50329 Mdot
.19427 .40245 Mdot
.37239 .46682 Mdot
.60065 .64131 Mdot
.35939 .48285 Mdot
.26063 .53578 Mdot
.41709 .70237 Mdot
.37075 .4957 Mdot
.5811 .62882 Mdot
.54724 .3366 Mdot
.41231 .64175 Mdot
.36831 .51493 Mdot
.54206 .74323 Mdot
.39512 .4301 Mdot
.54322 .21607 Mdot
.4827 .37217 Mdot
.51306 .32697 Mdot
.3295 .421 Mdot
.62478 .45899 Mdot
.43068 .61888 Mdot
.29907 .41643 Mdot
.59219 .59359 Mdot
.25453 .69692 Mdot
.65726 .41685 Mdot
.46628 .49593 Mdot
.44131 .49334 Mdot
.54836 .35934 Mdot
.47786 .62803 Mdot
.61978 .57922 Mdot
.31835 .46336 Mdot
.41603 .47161 Mdot
.50658 .24159 Mdot
.28839 .42801 Mdot
.38307 .43299 Mdot
.55103 .3647 Mdot
.34682 .62948 Mdot
.35314 .49233 Mdot
.59847 .41505 Mdot
.41873 .66924 Mdot
.32898 .43037 Mdot
.3342 .61821 Mdot
.37981 .47384 Mdot
.46669 .67792 Mdot
.43789 .63395 Mdot
.57898 .70276 Mdot
.51731 .31441 Mdot
.36426 .44601 Mdot
.48736 .31953 Mdot
.34986 .44393 Mdot
.59952 .61 Mdot
.39854 .5189 Mdot
.65526 .42257 Mdot
.61386 .77097 Mdot
.62918 .43777 Mdot
.39237 .51995 Mdot
.43987 .6794 Mdot
.61063 .56677 Mdot
.61689 .3306 Mdot
.71916 .35805 Mdot
.35839 .61289 Mdot
.81839 .37665 Mdot
.5245 .33733 Mdot
.57167 .35166 Mdot
.61602 .62571 Mdot
.36707 .49597 Mdot
.50178 .37694 Mdot
.43063 .47017 Mdot
.3567 .48701 Mdot
.40448 .50819 Mdot
.63955 .60518 Mdot
.58965 .60338 Mdot
.65653 .44481 Mdot
.38854 .48929 Mdot
.37696 .4745 Mdot
.47274 .6601 Mdot
.54579 .33777 Mdot
.6265 .43458 Mdot
.54008 .34345 Mdot
.63961 .44209 Mdot
.26559 .25493 Mdot
.42537 .52291 Mdot
.54928 .33735 Mdot
.61547 .62711 Mdot
.4672 .69211 Mdot
.76243 .50623 Mdot
.62012 .41579 Mdot
.67072 .43585 Mdot
.3747 .46942 Mdot
.46943 .68696 Mdot
.47879 .65808 Mdot
.54315 .35239 Mdot
.60531 .57425 Mdot
.39004 .52031 Mdot
.37676 .52729 Mdot
.30561 .3175 Mdot
.62809 .39813 Mdot
.26876 .58894 Mdot
.59054 .71198 Mdot
.36749 .4975 Mdot
.44353 .64466 Mdot
.40877 .48672 Mdot
.36475 .22312 Mdot
.42212 .67008 Mdot
.352 .51777 Mdot
.49673 .78585 Mdot
.6509 .39172 Mdot
.54019 .70277 Mdot
.40321 .44302 Mdot
.7678 .31393 Mdot
.33492 .45739 Mdot
.46804 .15574 Mdot
.75605 .61629 Mdot
.34672 .43568 Mdot
.33378 .47885 Mdot
.24051 .35921 Mdot
.38422 .46571 Mdot
.76574 .52464 Mdot
.43985 .43309 Mdot
.43126 .70371 Mdot
.49982 .41526 Mdot
.60181 .39499 Mdot
.52339 .30843 Mdot
.64033 .41795 Mdot
.60578 .36475 Mdot
.56021 .34136 Mdot
.43764 .66825 Mdot
.33376 .48757 Mdot
.39664 .3718 Mdot
.64057 .38404 Mdot
.43882 .469 Mdot
.60067 .61135 Mdot
.59277 .4109 Mdot
.68495 .41871 Mdot
.60709 .58993 Mdot
.39806 .45071 Mdot
.2104 .47467 Mdot
.73042 .38114 Mdot
.68141 .23248 Mdot
.61669 .57691 Mdot
.613 .61282 Mdot
.59495 .77923 Mdot
.52615 .30633 Mdot
.44861 .2381 Mdot
.50141 .74522 Mdot
.62118 .61152 Mdot
.46594 .27861 Mdot
.66113 .46137 Mdot
.53358 .74821 Mdot
.44708 .73237 Mdot
.41162 .53221 Mdot
.3854 .51382 Mdot
.60119 .57415 Mdot
.40248 .378 Mdot
.66555 .7725 Mdot
.5971 .59247 Mdot
.29829 .49466 Mdot
.61159 .51727 Mdot
.78053 .52513 Mdot
.78749 .52956 Mdot
.51509 .32811 Mdot
.69051 .28336 Mdot
.45955 .656 Mdot
.55438 .3586 Mdot
.56185 .54831 Mdot
.364 .44978 Mdot
.59583 .58609 Mdot
.7546 .5085 Mdot
.61548 .60012 Mdot
.55478 .32608 Mdot
.51524 .33724 Mdot
.45041 .64362 Mdot
.43564 .70304 Mdot
.35371 .74854 Mdot
.44739 .31424 Mdot
.38551 .45407 Mdot
.20374 .57967 Mdot
.48243 .66533 Mdot
.31226 .41466 Mdot
.54432 .30392 Mdot
.54829 .34058 Mdot
.2403 .61851 Mdot
.34476 .50173 Mdot
.57273 .38646 Mdot
.35751 .50577 Mdot
.42866 .2576 Mdot
.37229 .52958 Mdot
.66069 .43421 Mdot
.32842 .45226 Mdot
.66656 .49209 Mdot
.32535 .47967 Mdot
.415 .48658 Mdot
.67542 .44747 Mdot
.37716 .54607 Mdot
.65683 .42188 Mdot
.37781 .52458 Mdot
.57468 .35862 Mdot
.64285 .41926 Mdot
.34526 .335 Mdot
.50749 .53794 Mdot
.75983 .51571 Mdot
.55376 .31496 Mdot
.56626 .34235 Mdot
.40886 .36818 Mdot
.43498 .69798 Mdot
.47039 .74288 Mdot
.3666 .4946 Mdot
.65089 .46343 Mdot
.58532 .60004 Mdot
.37726 .47616 Mdot
.34392 .52705 Mdot
.39382 .43725 Mdot
.47788 .6704 Mdot
.65992 .39774 Mdot
.5501 .3328 Mdot
.63419 .41066 Mdot
.68646 .29792 Mdot
.68452 .447 Mdot
.3622 .41605 Mdot
.34248 .53025 Mdot
.27578 .52425 Mdot
.25609 .68758 Mdot
.46395 .79501 Mdot
.46287 .66857 Mdot
.77323 .51254 Mdot
.51882 .34362 Mdot
.40913 .61289 Mdot
.44731 .70212 Mdot
.67594 .43068 Mdot
.36082 .50037 Mdot
.31229 .51837 Mdot
.52797 .60953 Mdot
.44498 .61242 Mdot
.39924 .3563 Mdot
.6894 .43157 Mdot
.77282 .5254 Mdot
.58903 .77004 Mdot
.40948 .62035 Mdot
.52997 .43085 Mdot
.40579 .49954 Mdot
.55983 .31657 Mdot
.46926 .70043 Mdot
.65421 .34936 Mdot
.5982 .57875 Mdot
.54213 .47269 Mdot
.38312 .49614 Mdot
.65987 .67348 Mdot
.44062 .67835 Mdot
.55922 .32886 Mdot
.59992 .57441 Mdot
.5232 .30656 Mdot
.78742 .53111 Mdot
.69824 .27818 Mdot
.35038 .44986 Mdot
.40852 .47523 Mdot
.62691 .61964 Mdot
.45922 .6581 Mdot
.53497 .38118 Mdot
.49667 .23717 Mdot
.64517 .40487 Mdot
.58173 .37958 Mdot
.46403 .71322 Mdot
.32092 .57351 Mdot
.63167 .41482 Mdot
.60939 .55374 Mdot
.50473 .40305 Mdot
.58486 .61736 Mdot
.36305 .51239 Mdot
.44916 .69267 Mdot
.57792 .58724 Mdot
.67526 .31248 Mdot
.37765 .18966 Mdot
.26854 .53049 Mdot
.35009 .43777 Mdot
.23992 .31012 Mdot
.53685 .19945 Mdot
.44354 .39591 Mdot
.6094 .62079 Mdot
.39999 .48307 Mdot
.39825 .52611 Mdot
.33815 .44655 Mdot
.57739 .60067 Mdot
.61751 .26181 Mdot
.67003 .42911 Mdot
.37333 .46095 Mdot
.56249 .34928 Mdot
.65165 .42939 Mdot
.6953 .46796 Mdot
.64306 .46009 Mdot
.4286 .70574 Mdot
.34653 .51235 Mdot
.58954 .74726 Mdot
.43139 .14822 Mdot
.59212 .599 Mdot
.76 .5161 Mdot
.40809 .46892 Mdot
.41757 .78878 Mdot
.45741 .69819 Mdot
.64801 .40426 Mdot
.39852 .49497 Mdot
.65239 .28194 Mdot
.80093 .51148 Mdot
.66237 .45406 Mdot
.43421 .69254 Mdot
.45523 .40639 Mdot
.37698 .49254 Mdot
.33855 .45571 Mdot
.45214 .65713 Mdot
.71955 .30063 Mdot
.61374 .76541 Mdot
.41093 .48972 Mdot
.60584 .59316 Mdot
.76361 .72574 Mdot
.40155 .44394 Mdot
.50539 .65364 Mdot
.76036 .53018 Mdot
.55629 .73279 Mdot
.26827 .59316 Mdot
.34625 .41298 Mdot
.26303 .30308 Mdot
.47243 .39206 Mdot
.23598 .30298 Mdot
.50066 .32088 Mdot
.70663 .51442 Mdot
.28006 .23974 Mdot
.58589 .63237 Mdot
.26738 .45334 Mdot
.25316 .38173 Mdot
.65281 .71462 Mdot
.48859 .41637 Mdot
.80096 .40347 Mdot
.70336 .33201 Mdot
.78075 .55048 Mdot
.63541 .4535 Mdot
.40831 .25792 Mdot
.40041 .51586 Mdot
.54683 .19607 Mdot
.25997 .55567 Mdot
.65558 .78931 Mdot
.25455 .28557 Mdot
.48759 .31387 Mdot
.20493 .41754 Mdot
.39068 .19987 Mdot
.24045 .44088 Mdot
.52781 .63259 Mdot
.833 .49984 Mdot
.54497 .78626 Mdot
.52372 .25687 Mdot
.45181 .48908 Mdot
.69191 .48767 Mdot
.59131 .22455 Mdot
.3679 .65758 Mdot
.68832 .78018 Mdot
.61899 .42763 Mdot
.41582 .68323 Mdot
.29418 .32243 Mdot
.42295 .62614 Mdot
.65641 .6075 Mdot
.26087 .3046 Mdot
.46041 .16509 Mdot
.26213 .53965 Mdot
.78743 .33048 Mdot
.27327 .67625 Mdot
.3886 .81521 Mdot
.52492 .53612 Mdot
.41844 .65754 Mdot
.79723 .48118 Mdot
.52655 .79429 Mdot
.5943 .66136 Mdot
.41255 .60223 Mdot
.50858 .33367 Mdot
.38073 .33759 Mdot
.43591 .6823 Mdot
.25763 .58455 Mdot
.78353 .53842 Mdot
.53181 .64944 Mdot
.70903 .4619 Mdot
.34062 .23092 Mdot
.7328 .51515 Mdot
.54568 .75232 Mdot
.69586 .645 Mdot
.15029 .48833 Mdot
.4738 .29891 Mdot
.42189 .20287 Mdot
.53794 .62297 Mdot
.47966 .41088 Mdot
.66343 .74793 Mdot
.44798 .33311 Mdot
.51408 .79849 Mdot
.16965 .55579 Mdot
.59357 .20324 Mdot
.17028 .47982 Mdot
.44516 .62422 Mdot
.38639 .43537 Mdot
.36189 .23965 Mdot
.36014 .73988 Mdot
.51247 .33083 Mdot
.17849 .43359 Mdot
.55363 .3079 Mdot
.42925 .62739 Mdot
.66536 .70197 Mdot
.32406 .58149 Mdot
.5836 .41033 Mdot
.57796 .33732 Mdot
.36837 .41974 Mdot
.37512 .85043 Mdot
.22715 .33054 Mdot
.57189 .71022 Mdot
.48696 .17517 Mdot
.57183 .54936 Mdot
.54253 .39192 Mdot
.57997 .60135 Mdot
.34028 .20461 Mdot
.4419 .69631 Mdot
.3748 .16116 Mdot
.37416 .18461 Mdot
.75728 .68664 Mdot
.51708 .90983 Mdot
.72091 .57512 Mdot
.2553 .46299 Mdot
.33663 .37238 Mdot
.34687 .35423 Mdot
.67365 .75416 Mdot
.77247 .66548 Mdot
.6011 .53293 Mdot
.68769 .25784 Mdot
.2964 .23613 Mdot
.45122 .27011 Mdot
.57778 .23866 Mdot
.66086 .72324 Mdot
.51603 .51981 Mdot
.50464 .67855 Mdot
.49099 .54518 Mdot
.51828 .62824 Mdot
.17884 .45211 Mdot
.39081 .75401 Mdot
.68021 .80788 Mdot
.54912 .37752 Mdot
.80095 .60732 Mdot
.49221 .1906 Mdot
.35044 .32443 Mdot
.39452 .59447 Mdot
.61563 .73383 Mdot
.3703 .41831 Mdot
.59711 .76146 Mdot
.46688 .46205 Mdot
.59824 .35742 Mdot
.5848 .7769 Mdot
.67225 .59835 Mdot
.49701 .24525 Mdot
.28308 .30649 Mdot
.49224 .77573 Mdot
.42411 .69152 Mdot
.45192 .3588 Mdot
.474 .28553 Mdot
.4894 .17974 Mdot
.73134 .67574 Mdot
.66998 .22444 Mdot
.746 .67395 Mdot
.42893 .4682 Mdot
.29624 .42449 Mdot
.45006 .50287 Mdot
.45934 .32394 Mdot
.42186 .46425 Mdot
.66529 .66259 Mdot
.51349 .17947 Mdot
.38575 .76307 Mdot
.57768 .29305 Mdot
.22214 .65149 Mdot
.6431 .21578 Mdot
.36362 .24402 Mdot
.74966 .62548 Mdot
.29592 .40622 Mdot
.26132 .75038 Mdot
.64779 .43642 Mdot
.46009 .27874 Mdot
.57615 .56563 Mdot
.65397 .34063 Mdot
.22728 .42008 Mdot
.74333 .70205 Mdot
.51945 .17902 Mdot
.62244 .74092 Mdot
.72035 .39032 Mdot
.57059 .45782 Mdot
.58774 .43243 Mdot
.2138 .63347 Mdot
.32597 .52515 Mdot
.40819 .58029 Mdot
.56595 .35498 Mdot
.35856 .72149 Mdot
.39223 .23987 Mdot
.77384 .40901 Mdot
.28558 .46009 Mdot
.76085 .46551 Mdot
.77185 .52833 Mdot
.54599 .47905 Mdot
.1881 .32646 Mdot
.40627 .42515 Mdot
.73247 .59382 Mdot
.60867 .20708 Mdot
.50116 .38797 Mdot
.46026 .20199 Mdot
.63186 .69931 Mdot
.17225 .50453 Mdot
.41281 .16538 Mdot
.73885 .37224 Mdot
.21605 .3256 Mdot
.63219 .1833 Mdot
.17638 .53915 Mdot
.21981 .62139 Mdot
.56768 .62199 Mdot
.39307 .12412 Mdot
.66824 .41298 Mdot
.28269 .72843 Mdot
.36677 .74824 Mdot
.63291 .28324 Mdot
.49417 .69383 Mdot
.40629 .55318 Mdot
.74985 .53812 Mdot
.42684 .72622 Mdot
.35039 .41751 Mdot
.15711 .44683 Mdot
.17209 .59702 Mdot
.1625 .44808 Mdot
.66688 .23934 Mdot
.22149 .31872 Mdot
.27318 .35908 Mdot
.36352 .60768 Mdot
.35925 .27274 Mdot
.38977 .52251 Mdot
.42099 .28613 Mdot
.72375 .58406 Mdot
.71912 .37794 Mdot
.56683 .66295 Mdot
.47448 .71454 Mdot
.18975 .47382 Mdot
.14193 .38216 Mdot
.27151 .65586 Mdot
.31634 .63088 Mdot
.51495 .59132 Mdot
.45579 .30779 Mdot
.46654 .52276 Mdot
.74966 .44617 Mdot
.49278 .1854 Mdot
.25372 .37837 Mdot
.48216 .26417 Mdot
.79065 .42315 Mdot
.61038 .4847 Mdot
.79615 .6005 Mdot
.34192 .22268 Mdot
.30902 .33308 Mdot
.76328 .66817 Mdot
.27472 .41882 Mdot
.69434 .75347 Mdot
.75649 .35944 Mdot
.65947 .3737 Mdot
.49261 .27626 Mdot
.68086 .40159 Mdot
.44291 .27315 Mdot
.57527 .52752 Mdot
.30773 .30266 Mdot
.4665 .3892 Mdot
.44296 .26784 Mdot
.61285 .48639 Mdot
.18037 .39876 Mdot
.68724 .2161 Mdot
.20022 .64911 Mdot
.75144 .29852 Mdot
.46605 .45419 Mdot
.42092 .47586 Mdot
.55598 .18109 Mdot
.1678 .40371 Mdot
.43872 .15246 Mdot
.66956 .66901 Mdot
.66492 .30478 Mdot
.58906 .63649 Mdot
.21501 .66292 Mdot
.76755 .3537 Mdot
.43752 .17596 Mdot
.4675 .79291 Mdot
.63146 .56787 Mdot
.63017 .74693 Mdot
.23885 .68331 Mdot
.22739 .45505 Mdot
.26757 .61232 Mdot
.44346 .50633 Mdot
.24463 .52967 Mdot
.42047 .66292 Mdot
.69212 .66045 Mdot
.45236 .32596 Mdot
.64414 .43272 Mdot
.31663 .34076 Mdot
.40159 .58333 Mdot
.37653 .42004 Mdot
.69641 .38864 Mdot
.48584 .7219 Mdot
.28607 .71897 Mdot
.61332 .53412 Mdot
.25878 .25467 Mdot
.72368 .61188 Mdot
.45514 .52919 Mdot
.46774 .35976 Mdot
.65119 .35779 Mdot
.60463 .75358 Mdot
.60225 .62818 Mdot
.28281 .26012 Mdot
.48308 .53447 Mdot
.45623 .35871 Mdot
.24471 .53628 Mdot
.47413 .232 Mdot
.35184 .53204 Mdot
.60082 .6984 Mdot
.38122 .64756 Mdot
.54675 .46913 Mdot
.4107 .65562 Mdot
.48206 .72778 Mdot
.84078 .36962 Mdot
.65259 .51504 Mdot
.75694 .6479 Mdot
.29084 .2573 Mdot
.58445 .61381 Mdot
.48497 .69931 Mdot
.42615 .27158 Mdot
.51284 .23423 Mdot
.3771 .68399 Mdot
.67712 .46721 Mdot
.53304 .27676 Mdot
.76812 .38744 Mdot
.24193 .31063 Mdot
.21151 .3802 Mdot
.64269 .80552 Mdot
.48829 .66784 Mdot
.45545 .22694 Mdot
.51495 .24106 Mdot
.48432 .67865 Mdot
.46304 .61575 Mdot
.52541 .66537 Mdot
.21259 .31373 Mdot
.58855 .7579 Mdot
.73609 .29146 Mdot
.50275 .39906 Mdot
.63692 .26992 Mdot
.63423 .34915 Mdot
.51708 .26807 Mdot
.29663 .25506 Mdot
.25137 .58439 Mdot
.22029 .44515 Mdot
.45514 .47312 Mdot
.36586 .77003 Mdot
.21962 .67216 Mdot
.52799 .52452 Mdot
.30802 .56733 Mdot
.6666 .61223 Mdot
.35068 .44073 Mdot
.15004 .4862 Mdot
.53801 .2077 Mdot
.56469 .796 Mdot
.62386 .54051 Mdot
.34329 .47137 Mdot
.43173 .49231 Mdot
.40552 .38076 Mdot
.56961 .72161 Mdot
.18689 .61096 Mdot
.52985 .25624 Mdot
.45246 .42074 Mdot
.25174 .55106 Mdot
.73302 .59623 Mdot
.33892 .23614 Mdot
.51707 .20078 Mdot
.57369 .51348 Mdot
.72287 .5898 Mdot
.54664 .42432 Mdot
.72729 .27572 Mdot
.72606 .4811 Mdot
.27641 .35021 Mdot
.47469 .76163 Mdot
.59355 .72469 Mdot
.66384 .35697 Mdot
.41308 .47644 Mdot
.6695 .69395 Mdot
.37944 .20733 Mdot
.6421 .82838 Mdot
.67657 .73972 Mdot
.15013 .44541 Mdot
.30187 .55242 Mdot
.59303 .73098 Mdot
.21114 .44528 Mdot
.61245 .85256 Mdot
.72816 .4679 Mdot
.19374 .43095 Mdot
.56122 .44275 Mdot
.2692 .27275 Mdot
.56582 .58584 Mdot
.52871 .77373 Mdot
.22901 .66029 Mdot
.21864 .30765 Mdot
.39783 .22096 Mdot
.30562 .2556 Mdot
.28486 .40729 Mdot
.19477 .34034 Mdot
.4438 .77724 Mdot
.78922 .55026 Mdot
.60791 .42044 Mdot
.67255 .65022 Mdot
.21259 .53169 Mdot
.49462 .61414 Mdot
.47017 .27356 Mdot
.80243 .57179 Mdot
.39458 .63226 Mdot
.22296 .47574 Mdot
.37357 .30387 Mdot
.61649 .70627 Mdot
.47028 .36426 Mdot
.41538 .17993 Mdot
.80816 .54263 Mdot
.61399 .33155 Mdot
.73571 .6472 Mdot
.69742 .27537 Mdot
.56591 .71969 Mdot
.6804 .51999 Mdot
.41844 .20281 Mdot
.74223 .3318 Mdot
.48591 .30657 Mdot
.85515 .36035 Mdot
.60606 .23447 Mdot
.52643 .64556 Mdot
.18232 .47324 Mdot
.50465 .19121 Mdot
.4337 .77077 Mdot
.64601 .7883 Mdot
.35735 .76679 Mdot
.42668 .30525 Mdot
.40131 .51075 Mdot
.17814 .35785 Mdot
.38252 .32955 Mdot
.17673 .44482 Mdot
.59911 .19038 Mdot
.23655 .52018 Mdot
.398 .42763 Mdot
.64633 .47094 Mdot
.52376 .56362 Mdot
.37116 .29838 Mdot
.21865 .40787 Mdot
.33652 .75731 Mdot
.59451 .37713 Mdot
.73314 .49545 Mdot
.68035 .46202 Mdot
.4028 .39649 Mdot
.71337 .5885 Mdot
.59199 .71533 Mdot
.57432 .37689 Mdot
.63674 .50618 Mdot
.46099 .29568 Mdot
.26614 .5877 Mdot
.22841 .45205 Mdot
.72197 .72179 Mdot
.66022 .60874 Mdot
.61946 .44029 Mdot
.25087 .34066 Mdot
.6194 .23398 Mdot
.65177 .6677 Mdot
.18681 .5475 Mdot
.62137 .73175 Mdot
.39125 .26676 Mdot
.35232 .26329 Mdot
.68904 .74459 Mdot
.83946 .47004 Mdot
.1983 .53455 Mdot
.36787 .77216 Mdot
.5791 .38695 Mdot
.31959 .5535 Mdot
.26518 .2563 Mdot
.50585 .26912 Mdot
.32381 .28413 Mdot
.51058 .54251 Mdot
.36145 .69637 Mdot
.22516 .51084 Mdot
.32958 .34642 Mdot
.53961 .44144 Mdot
.32568 .8034 Mdot
.47538 .7215 Mdot
.14789 .49481 Mdot
.60944 .58354 Mdot
.52875 .82411 Mdot
.63234 .48464 Mdot
.55843 .52507 Mdot
.51804 .42578 Mdot
.59455 .69767 Mdot
.5254 .69771 Mdot
.67679 .24713 Mdot
.71893 .73558 Mdot
.68157 .45009 Mdot
.48908 .35599 Mdot
.74259 .30921 Mdot
.25129 .32885 Mdot
.31308 .45915 Mdot
.63891 .24514 Mdot
.52523 .52228 Mdot
.71571 .37692 Mdot
.55899 .18434 Mdot
.65068 .64034 Mdot
.29491 .47481 Mdot
.45405 .31167 Mdot
.19412 .43848 Mdot
.39047 .17899 Mdot
.61912 .78794 Mdot
.46655 .46071 Mdot
.57359 .63048 Mdot
.2705 .38179 Mdot
.24281 .32161 Mdot
.56328 .40257 Mdot
.55066 .75869 Mdot
.47705 .28965 Mdot
.13878 .57187 Mdot
.17038 .5803 Mdot
.18959 .61421 Mdot
.4982 .38154 Mdot
.40773 .69213 Mdot
.40837 .77972 Mdot
.33036 .28036 Mdot
.63554 .66424 Mdot
.5997 .22128 Mdot
.46258 .28218 Mdot
.56772 .85198 Mdot
.39435 .60155 Mdot
.68589 .2955 Mdot
.22282 .52169 Mdot
.34455 .7275 Mdot
.56636 .60849 Mdot
.41181 .30851 Mdot
.47598 .51983 Mdot
.62687 .61196 Mdot
.61108 .70816 Mdot
.5376 .73943 Mdot
.31983 .28688 Mdot
.37473 .6469 Mdot
.45626 .43424 Mdot
.28005 .30271 Mdot
.41672 .71836 Mdot
.64804 .348 Mdot
.61967 .34474 Mdot
.49294 .444 Mdot
.64944 .40766 Mdot
.35583 .40977 Mdot
.56147 .48015 Mdot
.55359 .44216 Mdot
.28041 .74236 Mdot
.56029 .31443 Mdot
.44964 .72448 Mdot
.52574 .8117 Mdot
.48394 .68452 Mdot
.15872 .4035 Mdot
.74678 .45113 Mdot
.25058 .54191 Mdot
.73361 .36089 Mdot
.7902 .45841 Mdot
.411 .83931 Mdot
.20051 .59969 Mdot
.49598 .56433 Mdot
.42785 .6082 Mdot
.47224 .64171 Mdot
.5901 .40206 Mdot
.75699 .5384 Mdot
.27984 .61721 Mdot
.73423 .5795 Mdot
.37543 .26569 Mdot
.42685 .64054 Mdot
.65663 .27303 Mdot
.46409 .51856 Mdot
.22407 .29254 Mdot
.62902 .45059 Mdot
.22117 .70842 Mdot
.3745 .54428 Mdot
.23767 .42018 Mdot
.54616 .17746 Mdot
.62216 .77173 Mdot
.69331 .37863 Mdot
.81831 .41043 Mdot
.33549 .43973 Mdot
.45041 .42866 Mdot
.43401 .6818 Mdot
.42647 .24262 Mdot
.53959 .32785 Mdot
.42067 .3551 Mdot
.63345 .58157 Mdot
.78425 .64374 Mdot
.71308 .60032 Mdot
.42431 .71671 Mdot
.46559 .54806 Mdot
.39499 .22963 Mdot
.51583 .75529 Mdot
.52497 .52008 Mdot
.24234 .35577 Mdot
.37456 .67905 Mdot
.43174 .63662 Mdot
.1858 .5609 Mdot
.51279 .24627 Mdot
.35405 .19028 Mdot
.37905 .56353 Mdot
.52779 .54659 Mdot
.50382 .76556 Mdot
.6136 .69772 Mdot
.27389 .60167 Mdot
.48843 .18536 Mdot
.45047 .3478 Mdot
.52379 .7886 Mdot
.43977 .26905 Mdot
.41039 .5447 Mdot
.72022 .50109 Mdot
.68903 .63069 Mdot
.53541 .85292 Mdot
.23903 .64081 Mdot
.64579 .75547 Mdot
.46958 .60938 Mdot
.73136 .59246 Mdot
.45813 .72636 Mdot
.60932 .29402 Mdot
.3694 .67065 Mdot
.73287 .44566 Mdot
.30709 .22059 Mdot
.49688 .18351 Mdot
.52307 .61941 Mdot
.70598 .44268 Mdot
.47265 .39962 Mdot
.45171 .53102 Mdot
.5291 .47182 Mdot
.35127 .43284 Mdot
.39432 .38857 Mdot
.60973 .78674 Mdot
.62277 .67891 Mdot
.417 .54899 Mdot
.24782 .28271 Mdot
.36768 .18152 Mdot
.19044 .35985 Mdot
.58394 .38285 Mdot
.43909 .71734 Mdot
.17024 .51799 Mdot
.29914 .59669 Mdot
.41437 .1784 Mdot
.20997 .55576 Mdot
.82709 .3472 Mdot
.21916 .42374 Mdot
.66953 .59564 Mdot
.76371 .67924 Mdot
.54227 .6801 Mdot
.56595 .19104 Mdot
.79486 .54897 Mdot
.56767 .28883 Mdot
.5753 .19236 Mdot
.36964 .84512 Mdot
.2289 .63579 Mdot
.54159 .74803 Mdot
.249 .4558 Mdot
.48351 .4434 Mdot
.73671 .56768 Mdot
.40719 .51478 Mdot
.64897 .38657 Mdot
.7016 .37863 Mdot
.46518 .28905 Mdot
.28485 .53114 Mdot
.74217 .57304 Mdot
.37065 .29501 Mdot
.41914 .25339 Mdot
.53419 .24973 Mdot
.22385 .40828 Mdot
.28328 .61363 Mdot
.29543 .46748 Mdot
.40403 .68523 Mdot
.51631 .32404 Mdot
.60555 .35639 Mdot
.35904 .52106 Mdot
.70552 .38701 Mdot
.51172 .73351 Mdot
.15274 .45211 Mdot
.59093 .28881 Mdot
.52005 .22394 Mdot
.45905 .73708 Mdot
.58068 .71392 Mdot
.33526 .25318 Mdot
.65668 .71008 Mdot
.75741 .57986 Mdot
.389 .7538 Mdot
.23419 .31643 Mdot
.60871 .73852 Mdot
.47656 .25247 Mdot
.34673 .79282 Mdot
.62842 .58642 Mdot
.28962 .71766 Mdot
.26104 .36853 Mdot
.63922 .71498 Mdot
.44526 .62594 Mdot
.67174 .57194 Mdot
.71282 .51304 Mdot
.63092 .7118 Mdot
.613 .2076 Mdot
.42967 .23208 Mdot
.22562 .53788 Mdot
.21625 .36383 Mdot
.61808 .40099 Mdot
.47882 .26501 Mdot
.65693 .54289 Mdot
.73328 .55145 Mdot
.50227 .77523 Mdot
.25346 .26637 Mdot
.529 .46029 Mdot
.36992 .33518 Mdot
.34453 .44997 Mdot
.33818 .62085 Mdot
.60815 .6868 Mdot
.61739 .49524 Mdot
.74301 .65907 Mdot
.42263 .67789 Mdot
.70876 .63072 Mdot
.8091 .52916 Mdot
.41512 .31853 Mdot
.43387 .58687 Mdot
.45678 .75714 Mdot
.51652 .2961 Mdot
.79949 .52091 Mdot
.30617 .47925 Mdot
.37207 .34512 Mdot
.58467 .43282 Mdot
.25956 .68476 Mdot
.22589 .63682 Mdot
.24715 .34359 Mdot
.54119 .21974 Mdot
.64722 .66697 Mdot
.20756 .55439 Mdot
.52831 .68608 Mdot
.36411 .59667 Mdot
.68726 .69537 Mdot
.40167 .44076 Mdot
.61123 .29265 Mdot
.46937 .71383 Mdot
.24174 .33746 Mdot
.34896 .57769 Mdot
.34638 .33317 Mdot
.54956 .50201 Mdot
.35477 .23829 Mdot
.50853 .51056 Mdot
.54894 .17984 Mdot
.54429 .67772 Mdot
.45124 .32777 Mdot
.61804 .54561 Mdot
.56296 .43958 Mdot
.68653 .73643 Mdot
.33269 .21735 Mdot
.72948 .71743 Mdot
.34029 .37327 Mdot
.64204 .7498 Mdot
.37848 .77631 Mdot
.58648 .18979 Mdot
.43931 .32054 Mdot
.52934 .47418 Mdot
.46293 .52543 Mdot
.53359 .61109 Mdot
.76126 .50713 Mdot
.62788 .30099 Mdot
.29471 .60956 Mdot
.57075 .25489 Mdot
.73219 .42766 Mdot
.31232 .45208 Mdot
.42267 .79247 Mdot
.22387 .34581 Mdot
.39466 .64672 Mdot
.54698 .52607 Mdot
.6877 .35361 Mdot
.41165 .32623 Mdot
.88409 .53109 Mdot
.14906 .48496 Mdot
.3459 .45044 Mdot
.50253 .40797 Mdot
.41874 .34921 Mdot
.6806 .41207 Mdot
.28452 .6265 Mdot
.2457 .34245 Mdot
.61235 .61538 Mdot
.66128 .31151 Mdot
.67559 .63045 Mdot
.59235 .69293 Mdot
.31792 .34842 Mdot
.63721 .61045 Mdot
.15433 .42298 Mdot
.64362 .24115 Mdot
.62144 .68667 Mdot
.87412 .4557 Mdot
.67754 .66155 Mdot
.43967 .74171 Mdot
.39232 .21837 Mdot
.18152 .39413 Mdot
.49904 .38539 Mdot
.65567 .33721 Mdot
.22911 .64699 Mdot
.44908 .3354 Mdot
.4423 .25205 Mdot
.73498 .64644 Mdot
.71402 .63607 Mdot
.75789 .55022 Mdot
.79058 .45623 Mdot
.30889 .76366 Mdot
.24565 .56323 Mdot
.20354 .39066 Mdot
.73857 .45898 Mdot
.58111 .84892 Mdot
.33964 .20516 Mdot
.4086 .29076 Mdot
.75068 .58757 Mdot
.41692 .20839 Mdot
.40695 .36267 Mdot
.40599 .75893 Mdot
.74429 .44347 Mdot
.37773 .7108 Mdot
.77826 .45619 Mdot
.70467 .6907 Mdot
.4427 .27093 Mdot
.35777 .74495 Mdot
.53009 .45365 Mdot
.23473 .38427 Mdot
.81648 .58796 Mdot
.46906 .34784 Mdot
.67463 .32084 Mdot
.34772 .36287 Mdot
.26384 .31166 Mdot
.40588 .20121 Mdot
.52057 .46344 Mdot
.36984 .84199 Mdot
.18228 .44712 Mdot
.66528 .71239 Mdot
.42597 .48375 Mdot
.30586 .21635 Mdot
.50344 .46342 Mdot
.20674 .56668 Mdot
.58805 .20886 Mdot
.60465 .3312 Mdot
.49513 .76214 Mdot
.38986 .43578 Mdot
.19857 .5852 Mdot
.29428 .55785 Mdot
.3425 .72918 Mdot
.68873 .37242 Mdot
.46546 .35799 Mdot
.80899 .60091 Mdot
.31521 .36395 Mdot
.44352 .53667 Mdot
.46453 .71408 Mdot
.16254 .42598 Mdot
.26119 .42047 Mdot
.34894 .40833 Mdot
.27172 .43695 Mdot
.72549 .7253 Mdot
.84447 .43104 Mdot
.44528 .5244 Mdot
.59916 .75271 Mdot
.47115 .27502 Mdot
.35778 .26731 Mdot
.21152 .61555 Mdot
.53994 .91454 Mdot
.53582 .1745 Mdot
.49673 .69483 Mdot
.29207 .71281 Mdot
.48601 .36953 Mdot
.19425 .35912 Mdot
.78871 .41848 Mdot
.63942 .35626 Mdot
.72314 .74602 Mdot
.44529 .37073 Mdot
.36013 .52913 Mdot
.65187 .22712 Mdot
.34084 .20925 Mdot
.81479 .60467 Mdot
.2689 .25447 Mdot
.41862 .4417 Mdot
.42385 .52221 Mdot
.76819 .75212 Mdot
.2585 .29313 Mdot
.38656 .42024 Mdot
.69807 .75453 Mdot
.50016 .65708 Mdot
.38205 .52172 Mdot
.70841 .53791 Mdot
.49789 .2774 Mdot
.42847 .25448 Mdot
.21766 .30942 Mdot
.40955 .69199 Mdot
.70801 .38788 Mdot
.5846 .56174 Mdot
.52316 .42887 Mdot
.30762 .51241 Mdot
.57648 .58847 Mdot
.4012 .2653 Mdot
.50097 .4508 Mdot
.63603 .54942 Mdot
.51026 .27881 Mdot
.704 .23782 Mdot
.28008 .53528 Mdot
.52213 .60743 Mdot
.31231 .39471 Mdot
.39087 .65176 Mdot
.37218 .29622 Mdot
.35262 .28885 Mdot
.58864 .19962 Mdot
.63716 .16775 Mdot
.61426 .46939 Mdot
.37512 .55705 Mdot
.40102 .70089 Mdot
.28326 .6033 Mdot
.23601 .48884 Mdot
.64712 .54736 Mdot
.78709 .51866 Mdot
.41283 .44175 Mdot
.44166 .53961 Mdot
.6326 .57797 Mdot
.13255 .52421 Mdot
.41674 .50804 Mdot
.24285 .59317 Mdot
.39213 .19306 Mdot
.65215 .34949 Mdot
.26932 .51821 Mdot
.32418 .44852 Mdot
.4397 .7743 Mdot
.49978 .46466 Mdot
.46599 .41257 Mdot
.62514 .34594 Mdot
.2037 .35548 Mdot
.34619 .5763 Mdot
.23236 .55459 Mdot
.37137 .47013 Mdot
.57692 .34593 Mdot
.53093 .75082 Mdot
.19438 .60551 Mdot
.42291 .57912 Mdot
.4097 .17523 Mdot
.60263 .3244 Mdot
.54177 .2629 Mdot
.25268 .47861 Mdot
.17333 .44758 Mdot
.67407 .73701 Mdot
.23964 .50807 Mdot
.58185 .79388 Mdot
.67865 .53722 Mdot
.37675 .30298 Mdot
.66057 .46738 Mdot
.40996 .55163 Mdot
.49064 .63944 Mdot
.17205 .35066 Mdot
.20361 .61775 Mdot
.55875 .5762 Mdot
.59341 .38266 Mdot
.33419 .59185 Mdot
.52061 .43266 Mdot
.86869 .41734 Mdot
.79789 .39774 Mdot
.15292 .42744 Mdot
.41723 .23917 Mdot
.40521 .71841 Mdot
.62333 .70518 Mdot
.29268 .43667 Mdot
.66657 .44889 Mdot
.19734 .35847 Mdot
.40403 .56677 Mdot
.70544 .6812 Mdot
.38722 .52498 Mdot
.54289 .79586 Mdot
.48086 .4746 Mdot
.70518 .43192 Mdot
.68008 .39698 Mdot
.65307 .77821 Mdot
.37201 .21557 Mdot
.49923 .47019 Mdot
.83428 .37504 Mdot
.2109 .41563 Mdot
.28508 .25823 Mdot
.67986 .46445 Mdot
.56571 .827 Mdot
.44891 .6016 Mdot
.47702 .48825 Mdot
.58708 .54467 Mdot
.30629 .38446 Mdot
.63822 .71097 Mdot
.37482 .25844 Mdot
.53206 .71476 Mdot
.52893 .62324 Mdot
.7651 .2319 Mdot
.41497 .28132 Mdot
.41601 .59649 Mdot
.67546 .6853 Mdot
.27217 .25997 Mdot
.56238 .29646 Mdot
.68462 .23568 Mdot
.66435 .49768 Mdot
.33366 .53393 Mdot
.37775 .64181 Mdot
.24009 .4237 Mdot
.67967 .61605 Mdot
.36971 .82309 Mdot
.60588 .22789 Mdot
.54525 .26735 Mdot
.62797 .50861 Mdot
.48564 .67939 Mdot
.49486 .69152 Mdot
.76093 .39195 Mdot
.75582 .28203 Mdot
.47212 .44105 Mdot
.24485 .3161 Mdot
.44944 .84736 Mdot
.45732 .23711 Mdot
.19872 .34089 Mdot
.5518 .64334 Mdot
.46291 .61359 Mdot
.37222 .29089 Mdot
.55147 .3806 Mdot
.6592 .39463 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0:?ooooo0_l0002Tooooo`00
7?ooool00ol0003oooooooooo`2Sooooo`;o0000Y?ooool001cooooo00?o0000ooooooooool0Zooo
ool2o`0009cooooo000Looooo`03o`000?oooooooooo0:_ooooo0_l0002Looooo`007?ooool00ol0
003oooooooooo`2Nooooo`;o0000ZOooool001cooooo0_l0002Hooooo`;o00001Oooool2o`000:Wo
oooo000Looooo`03o`000?oooooooooo09Oooooo0_l0002`ooooo`007?ooool00ol0003ooooooooo
o`2hooooo`;o0000Soooool001cooooo00?o0000ooooooooool0TOooool2o`0002Gooooo0_l0002?
ooooo`007?ooool00ol0003oooooooooo`2@ooooo`?o0000]_ooool001cooooo00?o0000oooooooo
ool0S?ooool2o`0000;ooooo0_l0002gooooo`007?ooool00ol0003oooooooooo`2<ooooo`;o0000
^oooool001cooooo00?o0000ooooooooool0OOooool2o`0000Sooooo0_l0000hooooo`;o0000Q_oo
ool001cooooo00?o0000ooooooooool0O?ooool3o`0000Sooooo0_l0000hooooo`;o0000Q_ooool0
01cooooo00?o0000ooooooooool0O?ooool2o`000<_ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo08Sooooo0_l00017ooooo`;o0000M_ooool001cooooo0_l00029ooooo`;o000000?o
ooooo`000?l000000_ooool2o`00043ooooo0_l0001fooooo`007?ooool00ol0003oooooooooo`1o
ooooo`;o00002_ooool6o`0000?ooooo0_l0002cooooo`007?ooool00ol0003oooooooooo`1ooooo
o`;o00003?ooool3o`0000Cooooo0_l0002cooooo`007?ooool00ol0003oooooooooo`1fooooo`;o
0000dOooool001cooooo00?o0000ooooooooool0H?ooool2o`0001Cooooo0_l0000:ooooo`;o0000
2_ooool6o`0000;ooooo0_l0002aooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o00007?oo
ool2o`0000;ooooo0_l0000:ooooo`Ko00000_ooool2o`00017ooooo0_l0000Pooooo`;o0000O?oo
ool001cooooo00?o0000ooooooooool0O_ooool2o`0001?ooooo0_l000000ooooooo0000o`00000A
ooooo`;o00008?ooool2o`00013ooooo0_l0001Zooooo`007?ooool00ol0003oooooooooo`21oooo
o`;o00000oooool2o`0000_ooooo0_l000000ooooooo0000o`000002ooooo`;o00003_ooool2o`00
00Oooooo0_l0000Xooooo`;o0000J_ooool001cooooo00?o0000ooooooooool0POooool7o`000004
ooooool0003o0000o`0000Sooooo0_l00003ooooo`?o00003_ooool2o`0000;ooooo0_l00003oooo
o`;o0000U?ooool001cooooo00?o0000ooooooooool0M?ooool2o`0000Gooooo0_l00006ooooo`Co
00000_ooool3o`0000Sooooo0_l00003ooooo`Co00000oooool2o`000003ooooool0003o000000;o
000000?oooooo`000?l000001?ooool5o`0009Kooooo000Looooo`03o`000?oooooooooo07Cooooo
1?l00003ooooo`;o00001_ooool2o`0000_ooooo0_l00003ooooo`;o00001?ooool2o`000003oooo
ool0003o000000;o000000?oooooo`000?l000000_l000000ooooooo0000o`000005ooooo`Oo0000
5?ooool2o`0007gooooo000Looooo`03o`000?oooooooooo07Kooooo0_l0000:ooooo`Co00002_oo
ool2o`0000;ooooo0ol00003ooooo`Ko000000?oooooo`000?l000000ol0000:ooooo`Ko00005?oo
ool2o`0007gooooo000Looooo`03o`000?oooooooooo06oooooo0_l00006ooooo`;o00002Oooool4
o`0000kooooo0_l00004ooooo`Co00000oooool5o`000003ooooool0003o000000?ooooo0_l00002
ooooo`;o000000?oooooo`000?l000001_ooool2o`0000;ooooo0_l00028ooooo`0000Koooooonk^
k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0Kooo
ool2o`0000Kooooo0_l00003ooooo`;o00000oooool2o`000003ooooool0003o000001Kooooo0_l0
0002ooooo`;o00001Oooool4o`000003ooooool0003o000000Kooooo0_l000000ooooooo0000o`00
0002ooooo`;o00000_ooool2o`0008Sooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1looooo`?o
00000_ooool2o`0000Sooooo0_l00007ooooo`;o000000?oooooo`000?l000001oooool2o`0000;o
oooo0_l00003ooooo`;o00000oooool2o`0000Cooooo0_l000000ooooooo0000o`00000:ooooo`;o
0000Q?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00onHV9So8B4Q
onk^kP07ooooo`03o`000?oooooooooo07_ooooo1?l0000<ooooo`;o00001oooool2o`000003oooo
ool0003o000000_ooooo0_l00005ooooo`;o000000?oooooo`000?l000002oooool2o`0000Kooooo
0_l00024ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ
8B7ok^k^00Kooooo0ol0001gooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`?o00002?oo
ool2o`000003ooooool0003o000000?ooooo0_l0000;ooooo`;o00001Oooool2o`0000gooooo0ol0
002<ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKo
oooo00Gooooo00?o0000ooooooooool0Joooool2o`0000Oooooo0_l000000ooooooo0000o`000007
ooooo`;o00000_ooool3o`0000Sooooo0_l000000ooooooo0000o`000003ooooo`;o00000_ooool2
o`0000Oooooo0_l0000Dooooo`;o000000?oooooo`000?l00000R_ooool00003ooooool@413ooooo
00;ooooo00?o410@ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
06_ooooo0_l00007ooooo`;o00000_ooool2o`0000[ooooo0_l0000<ooooo`;o00001Oooool4o`00
00[ooooo0_l000001?oooooo0000o`000?l0000>ooooo`Co00000oooool3o`0008Cooooo00001_oo
ooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`00
0?oooooooooo06_ooooo0_l0000;ooooo`;o00002_ooool2o`0000;ooooo0_l00002ooooo`;o0000
2?ooool2o`000003ooooool0003o000000cooooo0_l000001?oooooo0000o`000?l0000=ooooo`?o
00001Oooool3o`0000Cooooo0_l0001nooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1]ooooo`;o000000Cooooo
o`000?l0003o00005Oooool2o`0000;ooooo0_l00008ooooo`;o00008_ooool3o`0000_ooooo0ol0
001nooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o00001Oooool3o`000003ooooool0003o
000000;o000000Coooooo`000?l0003o00000_ooool4o`0000?ooooo0_l0000Nooooo`;o00000_oo
ool2o`0000;ooooo0_l00007ooooo`Co00005oooool2o`0000?ooooo0_l0000<ooooo`;o0000K?oo
ool001cooooo00?o0000ooooooooool0H?ooool2o`0000Gooooo2?l00006ooooo`Co00000oooool3
o`0000Kooooo0_l0000Eooooo`;o00000_ooool2o`0000;ooooo1?l00004ooooo`Go00003_ooool2
o`0000cooooo0_l0000<ooooo`;o0000K?ooool001cooooo00?o0000ooooooooool0H?ooool2o`00
00Sooooo0ol00006ooooo`;o00002?ooool2o`0000Kooooo0_l0000Nooooo`?o00001?ooool3o`00
00gooooo0_l000000ooooooo0000o`00000Eooooo`;o0000LOooool001cooooo00?o0000oooooooo
ool0Hoooool2o`0000Kooooo0ol00005ooooo`;o00006oooool2o`0000[ooooo0_l00007ooooo`?o
00001Oooool2o`0000gooooo0_l0000Booooo`Co00000_ooool2o`00077ooooo000Looooo`03o`00
0?oooooooooo06?ooooo0_l00003ooooo`;o00000_ooool2o`0000oooooo0_l00002ooooo`;o0000
2Oooool2o`0000;ooooo0ol00008ooooo`?o00001_ooool4o`0001Wooooo0_l0000=ooooo`Co0000
MOooool001cooooo00?o0000ooooooooool0J?ooool2o`000003ooooool0003o0000013ooooo0_l0
0002ooooo`;o00001Oooool2o`0000;ooooo0_l00003ooooo`;o00000oooool2o`0000?ooooo0_l0
0007ooooo`;o00000_ooool2o`0000Wooooo0_l0000<ooooo`;o00005_ooool3o`0001Wooooo0_l0
001Booooo`007?ooool00ol0003oooooooooo`1Mooooo`;o00002oooool3o`0000Sooooo0_l0000A
ooooo`;o00002oooool3o`0000_ooooo0_l00003ooooo`?o000000?oooooo`000?l000000ol00002
ooooo`?o00002oooool2o`0000;ooooo0_l0000Booooo`Co00006?ooool2o`0005;ooooo000Loooo
o`03o`000?oooooooooo05Oooooo0_l00004ooooo`;o00001Oooool2o`0000Cooooo0_l00004oooo
o`Co000000?oooooo`000?l000001Oooool2o`0000Kooooo0_l00005ooooo`;o000000Coooooo`00
0?l0003ooooo0ol000000ooooooo0000o`000007ooooo`;o00000oooool2o`0000;ooooo2_l00003
ooooo`;o00000_ooool2o`0000Oooooo0_l00002ooooo`;o000000?oooooo`000?l000002oooool2
o`0000Cooooo0_l00004ooooo`;o0000I_ooool001cooooo00?o0000ooooooooool0Eoooool2o`00
00_ooooo0_l00009ooooo`Ko00001oooool3o`0000Gooooo0_l000000ooooooo0000o`000002oooo
o`;o000000Coooooo`000?l0003ooooo0ol0000:ooooo`;o000000Coooooo`000?l0003ooooo0_l0
00001?oooooo0000o`000?ooool2o`0000;ooooo0ol00007ooooo`;o00003_ooool2o`0000?ooooo
0_l00006ooooo`?o00002Oooool2o`0006Kooooo000Looooo`03o`000?oooooooooo06oooooo0_l0
00001?oooooo0000o`000?l00008ooooo`;o00001_ooool4o`0001;ooooo0_l000001?oooooo0000
o`000?ooool2o`000003ooooool0003o000002Kooooo0ol00007ooooo`;o0000LOooool001cooooo
00?o0000ooooooooool0H?ooool2o`000003ooooool0003o000000Wooooo0_l00002ooooo`;o0000
0_ooool2o`0000Gooooo0_l00006ooooo`;o00005?ooool2o`000003ooooool0003o000000?ooooo
0_l0000Wooooo`;o00002_ooool6o`0006_ooooo000Looooo`;o0000EOooool2o`0000[ooooo0_l0
00000ooooooo0000o`000009ooooo`;o00001_ooool2o`0000Wooooo0_l00009ooooo`Co00004?oo
ool2o`000003ooooool0003o000000Gooooo0_l00003ooooo`;o00007_ooool2o`0000Oooooo1_l0
0005ooooo`;o0000I?ooool001cooooo00?o0000ooooooooool0D?ooool2o`000004ooooool0003o
0000o`0000Oooooo0_l00007ooooo`;o000000?oooooo`000?l000004Oooool2o`0000?ooooo0_l0
00001?oooooo0000o`000?ooool4o`000003ooooool0003o000000;o00001oooool2o`000004oooo
ool0003o0000ooooo`;o000000?oooooo`000?l000002?ooool2o`0000?ooooo0ol00004ooooo`;o
00005oooool2o`0000Oooooo0ol00005ooooo`;o000000?oooooo`000?l000000_ooool4o`0005ko
oooo000Looooo`03o`000?oooooooooo053ooooo1_l00003ooooo`Ko000000?oooooo`000?l00000
1?ooool2o`000003ooooool0003o000000_ooooo0_l00004ooooo`;o00000oooool2o`000004oooo
ool0003o0000ooooo`Co00003?ooool2o`000004ooooool0003o0000ooooo`;o00001oooool4o`00
00Kooooo0_l00004ooooo`;o00008Oooool2o`000003ooooool0003o000000;ooooo0_l00005oooo
o`Co0000G_ooool001cooooo00?o0000ooooooooool0Coooool2o`000004ooooool0003o0000oooo
o`So00000oooool2o`0001Cooooo0_l00009ooooo`;o00001?ooool2o`0001gooooo1?l00008oooo
o`;o0000:?ooool2o`0000cooooo0_l0000Booooo`;o0000BOooool001cooooo00?o0000oooooooo
ool0Coooool2o`0000Cooooo1Ol0000Eooooo`;o0000:?ooool2o`0000[ooooo0_l00005ooooo`;o
00001?ooool2o`00017ooooo0_l0000Sooooo`;o00004_ooool2o`0004Wooooo000Looooo`03o`00
0?oooooooooo04oooooo0_l0000Nooooo`?o00001?ooool2o`0000?ooooo0_l00002ooooo`;o0000
4Oooool2o`0000Cooooo0ol0000:ooooo`;o00001Oooool3o`0000;ooooo0_l0000Booooo`;o0000
9_ooool2o`0005[ooooo000Looooo`03o`000?oooooooooo04oooooo1?l0000Mooooo`;o00001?oo
ool2o`0000?ooooo0_l00002ooooo`;o00001Oooool2o`0000?ooooo0ol000001?oooooo0000o`00
0?ooool2o`0000Cooooo0_l00007ooooo`;o000000?oooooo`000?l000000_l00004ooooo`?o0000
0_ooool2o`0001Sooooo1Ol0000Mooooo`;o0000F_ooool001cooooo00?o0000ooooooooool0DOoo
ool2o`000003ooooool0003o000000[ooooo0_l0000=ooooo`Go00004_ooool3o`0000;ooooo0ol0
00000ooooooo0000o`000004ooooo`;o00002_ooool2o`000003ooooool0003o000000;o00008ooo
ool5o`0000;ooooo0_l00006ooooo`;o00004_ooool2o`0005Wooooo000Looooo`03o`000?oooooo
oooo05Cooooo0_l00009ooooo`?o00002oooool7o`0001?ooooo0_l00003ooooo`;o00001oooool2
o`0000Gooooo0_l0000;ooooo`;o000000?oooooo`000?l000005oooool2o`0000_ooooo0_l00006
ooooo`;o00000oooool2o`0000Oooooo0_l00004ooooo`;o0000FOooool001cooooo00?o0000oooo
ooooool0Goooool2o`0000Cooooo0_l00004ooooo`Co00004oooool2o`0000kooooo1Ol00005oooo
o`Co00000_ooool2o`0000Gooooo0_l000000ooooooo0000o`00000Gooooo`;o00002oooool2o`00
00_ooooo0_l00003ooooo`;o00000_ooool2o`0000Oooooo0_l0000>ooooo`;o0000A_ooool001co
oooo00?o0000ooooooooool0COooool2o`00013ooooo0_l00004ooooo`;o000000Coooooo`000?l0
003ooooo0_l00007ooooo`;o00003?ooool3o`0000Cooooo0_l000000ooooooo0000o`000004oooo
o`Co00001_ooool4o`0000;ooooo0_l00005ooooo`;o00008oooool4o`0000gooooo0_l00003oooo
o`;o00002oooool3o`0000gooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`1;ooooo`Ko
00005?ooool2o`000003ooooool0003o000000Gooooo0_l00003ooooo`;o00003Oooool4o`0000;o
oooo0_l000000ooooooo0000o`000005ooooo`Go00000oooool2o`0000[ooooo1?l0000Hooooo`;o
00001Oooool2o`0000;ooooo1?l0000;ooooo`;o00004oooool2o`0005Gooooo000Looooo`03o`00
0?oooooooooo04_ooooo0_l00002ooooo`;o00003Oooool2o`0000Cooooo0ol00008ooooo`;o0000
5?ooool2o`0000cooooo0_l000000ooooooo0000o`000003ooooo`;o00002_ooool2o`0000Sooooo
0_l00002ooooo`;o00001Oooool3o`0000Cooooo0_l00005ooooo`;o00004Oooool2o`0006[ooooo
000Looooo`03o`000?oooooooooo05kooooo0_l00004ooooo`?o00002?ooool3o`0000?ooooo0_l0
000:ooooo`;o000000?oooooo`000?l000003Oooool2o`0000;ooooo0_l0000<ooooo`;o00002_oo
ool2o`0000;ooooo0_l00005ooooo`?o00002?ooool2o`0002;ooooo0_l0001Looooo`007?ooool0
0ol0003oooooooooo`15ooooo`;o00001_ooool2o`000003ooooool0003o000001kooooo0_l00003
ooooo`;o00002_ooool2o`000003ooooool0003o000000Gooooo0_l00007ooooo`;o000000?ooooo
o`000?l000002_ooool4o`0000?ooooo0_l00003ooooo`;o00001oooool2o`0000Sooooo0ol00002
ooooo`;o00004_ooool2o`0000Sooooo0_l00004ooooo`;o0000G?ooool001cooooo00?o0000oooo
ooooool0AOooool2o`0000Kooooo0_l000000ooooooo0000o`00000Sooooo`?o00004oooool2o`00
00Gooooo1?l00003ooooo`;o00002?ooool3o`0000Cooooo0ol00002ooooo`;o00000_ooool4o`00
0003ooooool0003o000000Sooooo0ol0000Fooooo`;o00002?ooool2o`0000;ooooo0_l00005oooo
o`;o00000oooool2o`0005;ooooo000Looooo`;o0000Foooool2o`0000Oooooo0_l0000@ooooo`Co
00004oooool2o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l000001_ooool2o`000003
ooooool0003o000000Cooooo0ol00002ooooo`;o00000_ooool4o`00017ooooo0_l0000Aooooo`;o
00002Oooool2o`000003ooooool0003o000000Gooooo0_l00003ooooo`;o0000D_ooool001cooooo
00?o0000ooooooooool0BOooool2o`0000;ooooo0_l00002ooooo`?o00000oooool2o`000003oooo
ool0003o000000Cooooo0_l000000ooooooo0000o`000009ooooo`;o00001Oooool4o`0000oooooo
0ol000001?oooooo0000o`000?ooool2o`0000Gooooo0_l00009ooooo`?o00000_ooool:o`0000?o
oooo0_l00003ooooo`;o00003_ooool2o`0000[ooooo0_l00008ooooo`;o00001_ooool2o`00067o
oooo000Looooo`03o`000?oooooooooo043ooooo0_l000000ooooooo0000o`000004ooooo`;o0000
0_ooool2o`0000;ooooo0ol000000ooooooo0000o`000003o`0000Kooooo0_l0000<ooooo`;o0000
1_ooool3o`0000kooooo1?l00004ooooo`Co00001?ooool2o`000003ooooool0003o000000Kooooo
0_l000000ooooooo0000o`00000=o`000004ooooool0003o0000ooooo`;o00006_ooool2o`0000Co
oooo0_l00002ooooo`;o0000JOooool001cooooo00?o0000ooooooooool0@?ooool2o`000003oooo
ool0003o000000?ooooo1Ol00008ooooo`;o000000?oooooo`000?l000000oooool2o`0001?ooooo
0_l0000>ooooo`;o00000oooool2o`0000Oooooo0ol00004ooooo`;o000000?oooooo`000?l00000
2Oooool?o`000003ooooool0003o000002?ooooo0_l0000Aooooo`;o00000oooool2o`0000Kooooo
0_l0000<ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0@Oooool4o`0000?ooooo1Ol0
0005ooooo`;o00002Oooool2o`00017ooooo1?l0000>ooooo`;o00001_ooool2o`0000Cooooo0ol0
0005ooooo`Go00001_oooolDo`0001cooooo0_l00003ooooo`;o00000_ooool2o`0000Wooooo0_l0
0004ooooo`;o00000oooool2o`000004ooooool0003o0000o`0000;ooooo0_l0000<ooooo`;o0000
?oooool001cooooo00?o0000ooooooooool0@Oooool2o`0000Cooooo0ol00002ooooo`;o00001?oo
ool2o`0000[ooooo0_l0000@ooooo`;o00000oooool2o`0001?ooooo0_l000000ooooooo0000o`00
0004o`0000Gooooo0_l000000ooooooo0000o`000006ooooo`Go000000?oooooo`000?l000002ol0
000:ooooo`;o00004Oooool2o`0000?ooooo0ol000000ooooooo0000o`000009ooooo`;o00003?oo
ool3o`00057ooooo000Looooo`03o`000?oooooooooo04Cooooo1_l00002ooooo`;o00004?ooool4
o`0001?ooooo0_l0000<ooooo`;o00002?ooool3o`0000_ooooo0_l00006oooooa?o00002?ooool4
o`0001Kooooo0ol0001^ooooo`007?ooool00ol0003oooooooooo`14ooooo`Co00000oooool2o`00
00oooooo0_l00002ooooo`;o00008Oooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`00
0?l000002oooool2o`0000;ooooo5ol00005ooooo`;o000000?oooooo`000?l000005oooool3o`00
00?ooooo0_l00007ooooo`;o000000?oooooo`000?l000003?ooool2o`0000;ooooo0_l0001<oooo
o`007?ooool00ol0003oooooooooo`12ooooo`;o00001oooool2o`0000oooooo0_l0000:ooooo`;o
00001?ooool2o`0001;ooooo1?l000000ooooooo0000o`000002ooooo`;o00000_ooool4o`0000co
oooo1?l000000ooooooo0000o`00000@o`0000Gooooo0_l00003ooooo`;o00005Oooool2o`0000?o
oooo0ol00004ooooo`;o000000Coooooo`000?l0003ooooo0_l0000<ooooo`;o00000_ooool2o`00
04cooooo000Looooo`03o`000?oooooooooo03Wooooo0_l00007ooooo`;o00002_ooool2o`0000[o
oooo0_l00009ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00003_ooool2o`0000;o
oooo1Ol00002ooooo`;o000000Coooooo`000?l0003ooooo1?l0000@oooooa?o00002_ooool2o`00
01[ooooo0_l00005ooooo`;o00001Oooool2o`0005gooooo000Looooo`03o`000?oooooooooo03Wo
oooo0_l0000;ooooo`;o00001_ooool2o`0000[ooooo0_l00004ooooo`;o00000oooool2o`0000;o
oooo0ol0000=ooooo`;o00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o
000000Coooooo`000?l0003ooooo0ol00004ooooo`;o00002_ooool7o`000003ooooool0003o0000
00co00002Oooool2o`000004ooooool0003o0000o`0001[ooooo0_l000000ooooooo0000o`000004
ooooo`;o000000?oooooo`000?l000003Oooool2o`0004_ooooo000Looooo`03o`000?oooooooooo
04Kooooo0_l00006ooooo`?o00003oooool3o`0000Kooooo0_l000001?oooooo0000o`000?l00002
ooooo`;o000000?oooooo`000?l000000oooool2o`0000Cooooo0ol0000<ooooo`Co00001?ooool2
o`0000Wooooo5ol000000ooooooo0000o`000006ooooo`;o000000Coooooo`000?l0003o00005Ooo
ool3o`0000;ooooo0_l000000ooooooo0000o`000007ooooo`;o00002_ooool2o`000003ooooool0
003o000004_ooooo000Looooo`03o`000?oooooooooo03Kooooo0_l0000Cooooo`;o000000Cooooo
o`000?l0003o00004?ooool2o`0000Wooooo0ol00002ooooo`;o000000?oooooo`000?l000000_oo
ool2o`000003ooooool0003o000000;ooooo1_l00009ooooo`Co00003ooooolJo`0000Cooooo0_l0
000@ooooo`;o00002Oooool3o`0000;ooooo0_l0000Fooooo`Co0000C?ooool001cooooo00?o0000
ooooooooool0=_ooool2o`0000Cooooo0ol0000<ooooo`;o000000?oooooo`000?l000004oooool2
o`0001?ooooo0_l000000ooooooo0000o`000002ooooo`Ko000000?oooooo`000?l000001oooool2
o`0000Gooooo0_l00005ooooo`;o00001?oooolGo`0000Gooooo0_l00005ooooo`;o00002Oooool2
o`0000kooooo0_l0000Hooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0??ooool3o`00
00gooooo1?l0000Cooooo`;o00006_ooool3o`0000Cooooo0ol00006ooooo`;o00001Oooool2o`00
00Cooooo0ol00006oooooaCo00003Oooool2o`0000Wooooo0_l0000Booooo`;o00006?ooool2o`00
04Sooooo000Looooo`03o`000?oooooooooo03Cooooo0_l0000;ooooo`;o00000_ooool2o`0000Go
oooo0ol0000?ooooo`;o00001_ooool3o`0000cooooo0_l00002ooooo`;o00003?ooool2o`0000Ko
oooo0_l00004ooooo`;o00001Oooool2o`0000Kooooo5_l00008ooooo`;o00000_ooool3o`0000;o
oooo0_l0000Gooooo`?o00006?ooool2o`0000Sooooo0_l0000nooooo`007?ooool2o`0003Gooooo
0_l0000;ooooo`;o00000_ooool2o`0000oooooo0_l00006ooooo`;o00001?ooool5o`0000cooooo
0_l00002ooooo`;o00000_ooool2o`0000Gooooo0_l00009ooooo`;o00001?ooool2o`0000gooooo
1Ol000001Ooooooo0000o`000?l0003ooooo00co00002?ooool2o`0000?ooooo0_l000001?oooooo
0000o`000?l00002ooooo`Co00004Oooool2o`0002?ooooo0_l0000nooooo`007?ooool00ol0003o
ooooooooo`0dooooo`;o00002?ooool2o`0001Kooooo0_l0000<ooooo`;o00003?ooool2o`000003
ooooool0003o000000Kooooo0_l00005ooooo`;o00008?oooolBo`0001;ooooo0_l00003ooooo`Co
00001?ooool2o`0000?ooooo0_l0000Gooooo`Go0000Coooool001cooooo00?o0000ooooooooool0
?_ooool2o`0000_ooooo0_l0000?ooooo`;o00003oooool2o`0000?ooooo0_l00008ooooo`Co0000
1Oooool2o`0001Cooooo0_l0000:oooooa?o00001Oooool4o`0000Wooooo0_l00006ooooo`;o0000
00?oooooo`000?l000000oooool2o`0000Kooooo0_l0000?ooooo`Go0000Coooool001cooooo00?o
0000ooooooooool0=_ooool2o`0000;ooooo1_l0000:ooooo`?o00002?ooool2o`0000Gooooo0_l0
000?ooooo`;o00000_ooool2o`0000Wooooo1?l00005ooooo`;o00001_ooool5o`000004ooooool0
003o0000o`0000Gooooo0_l0000:oooooa?o00000_ooool2o`000003ooooool0003o000000;o0000
1_ooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o00003_ooool4o`0000[ooooo
0_l0001Eooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00000_ooool4o`0000cooooo0_l0
0009ooooo`;o00005?ooool4o`0000;ooooo0_l0000;ooooo`Co00002oooool5o`000004ooooool0
003o0000o`0000Kooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`000003oooo
ool0003o000000[o000000Coooooo`000?l0003ooooo1ol00008ooooo`;o00001Oooool2o`0001Co
oooo0_l00002ooooo`;o00001_ooool2o`000003ooooool0003o000000Gooooo0_l0000Dooooo`;o
0000=Oooool001cooooo00?o0000ooooooooool0@oooool2o`0001kooooo0_l00006ooooo`Co0000
1?ooool4o`0000Oooooo1?l000000ooooooo0000o`000007ooooo`;o00001oooool2o`0000Gooooo
0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000Wo0000
0_ooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`00013ooooo0_l0000Eooooo`;o
00002Oooool2o`0000Gooooo0_l00005ooooo`;o00003Oooool2o`0003Gooooo000Looooo`03o`00
0?oooooooooo04?ooooo0_l0000<ooooo`;o00004?ooool2o`000003ooooool0003o000000Cooooo
1Ol00002ooooo`Co000000?oooooo`000?l000000ol00004ooooo`Co000000?oooooo`000?l00000
1?ooool3o`0000Kooooo0_l00003ooooo`;o00000_ooool2o`0000Wooooo0ol00002ooooo`Ko0000
0oooool2o`0000Gooooo1Ol0000@ooooo`;o00000oooool2o`0000Oooooo0_l00003ooooo`?o0000
6_ooool2o`0004Cooooo000Looooo`03o`000?oooooooooo057ooooo0_l0000Cooooo`;o000000?o
ooooo`000?l000001_l00004ooooo`;o000000?oooooo`000?l000002ol000000ooooooo0000o`00
0002ooooo`Go00002_ooool3o`0000;ooooo0_l00003ooooo`;o00001?ooool3o`0000;ooooo0_l0
0008ooooo`;o00001?ooool4o`0000Cooooo0_l00006ooooo`;o00002?ooool2o`0000;ooooo0_l0
0003ooooo`;o00000oooool5o`000003ooooool0003o000001Wooooo0_l00004ooooo`;o0000>_oo
ool001cooooo00?o0000ooooooooool0D_ooool2o`0001;ooooo0_l000000ooooooo0000o`000004
o`0000Wooooo0_l00003ooooo`So00000_ooool2o`000003ooooool0003o000000Co00002Oooool3
o`0000;ooooo0_l00003ooooo`;o00001Oooool2o`0000cooooo0_l0000<ooooo`;o00001?ooool4
o`0000;ooooo0_l00004ooooo`;o00000_ooool2o`000003ooooool0003o000000Sooooo0_l00000
0ooooooo0000o`00000Iooooo`;o00000_ooool4o`0003[ooooo000Looooo`03o`000?oooooooooo
03gooooo0_l0000@ooooo`;o000000?oooooo`000?l000003oooool2o`000003ooooool0003o0000
00?ooooo0_l0000;ooooo`?o00001?ooool3o`000003ooooool0003o000000;ooooo0_l00002oooo
o`;o000000?oooooo`000?l000002Oooool2o`0000?ooooo0ol00004ooooo`;o00002?ooool2o`00
00Kooooo0ol00003ooooo`;o00001oooool4o`0000;ooooo0_l00004ooooo`;o00001?ooool2o`00
00?ooooo1Ol00003ooooo`?o00007_ooool2o`0000?ooooo0_l0000looooo`007?ooool00ol0003o
ooooooooo`0mooooo`;o00000_ooool2o`0000cooooo0_l00003ooooo`;o00003Oooool2o`0000[o
oooo0_l00008ooooo`;o00001?ooool3o`0000Gooooo1?l000000ooooooo0000o`00000;ooooo`?o
00000_ooool3o`0000Cooooo0_l00003ooooo`?o00000_ooool2o`0000Kooooo1?l00002ooooo`;o
00001_ooool5o`0001;ooooo1_l000000ooooooo0000o`000003o`000003ooooool0003o000001_o
oooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0Zooooo`;o00005Oooool2o`0000Kooooo
0_l00003ooooo`?o00000oooool2o`0000[ooooo0_l0000=ooooo`;o00002Oooool2o`0000;ooooo
1?l00006ooooo`?o000000?oooooo`000?l000000oooool2o`0000Oooooo0_l00002ooooo`;o0000
0_ooool2o`0000Kooooo0ol000001?oooooo0000o`000?l00008ooooo`?o000000?oooooo`000?l0
00001_ooool2o`0000Gooooo0_l0000>ooooo`;o00000oooool4o`0000Cooooo0_l0001Nooooo`00
7?ooool00ol0003oooooooooo`0Zooooo`;o00006Oooool2o`0000;ooooo0_l00003ooooo`;o0000
00?oooooo`000?l000002oooool4o`0000?ooooo0_l00005ooooo`;o00003?ooool2o`0000;ooooo
0_l0000Aooooo`;o00001?ooool2o`0000Gooooo0_l00002ooooo`;o00001Oooool2o`0000?ooooo
0_l00006ooooo`Ko000000?oooooo`000?l000001_ooool2o`0000Gooooo0_l000001?oooooo0000
o`000?l00006ooooo`;o00001oooool5o`00013ooooo0_l0000Mooooo`;o0000<_ooool001cooooo
00?o0000ooooooooool0<?ooool2o`0000cooooo0_l00005ooooo`;o00002_ooool2o`0000Gooooo
0_l00004ooooo`;o00001Oooool2o`0000Gooooo0_l0000>ooooo`;o00002_ooool2o`0000?ooooo
0_l00005ooooo`Go00001Oooool3o`0000;ooooo0_l00003ooooo`?o00002oooool4o`0000?ooooo
0_l00006ooooo`;o00001_ooool:o`000004ooooool0003o0000ooooo`;o000000Coooooo`000?l0
003ooooo2Ol0000<ooooo`;o00007Oooool2o`0003;ooooo00001_ooooook^k^oc8b<_l0003o<S8b
onk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0`
ooooo`;o00003?ooool2o`0000;ooooo0_l00007ooooo`;o00002oooool2o`0000_ooooo0_l00008
ooooo`;o00001?ooool2o`0000Gooooo0_l000000ooooooo0000o`000007ooooo`;o00000oooool2
o`000003ooooool0003o000000;ooooo1?l00003ooooo`;o00000_ooool2o`0000;ooooo0_l00003
ooooo`;o00000_ooool4o`0000Gooooo0_l0000>oooooaGo000000?oooooo`000?l000000ol00004
ooooo`Oo00001?ooool2o`0000;ooooo0_l00006ooooo`;o0000C?ooool00006oooooomgMgOoV9RH
oooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0gooooo`;o00002Oooool2o`0000Oooooo0_l00002ooooo`;o00004?ooool6o`0000?ooooo0_l0
0003ooooo`;o00000oooool5o`0000Kooooo0ol0000:ooooo`;o00000_ooool2o`0000?ooooo0ol0
0003ooooo`;o00003oooool4o`0000Cooooo0ol00009ooooo`;o000000?oooooo`000?l000004Ol0
00000ooooooo0000o`000005o`0000Kooooo0_l00003ooooo`;o00001?ooool2o`0000;ooooo0_l0
0006ooooo`;o00001?ooool2o`0004Kooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooo
oooo00Wooooo1Ol00006ooooo`03o`000?oooooooooo03Oooooo0_l0000Fooooo`;o00002oooool2
o`0000?ooooo1?l00002ooooo`;o000000?oooooo`000?l000002?ooool2o`000003ooooool0003o
000000;o00001?ooool3o`0000[ooooo0_l00007ooooo`?o00002?ooool4o`0000Oooooo0_l00007
ooooo`;o00001oooool2o`000004ooooool0003o0000ooooo`So000000?oooooo`000?l000003ol0
0007ooooo`;o00000oooool2o`0001Cooooo1_l00014ooooo`0000?oooooo`000?ooool00_ooool0
0ol0003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0000gooooo`;o00000_oo
ool2o`0001oooooo0_l00009ooooo`;o00003?ooool2o`0000;ooooo0_l0000Kooooo`;o00002?oo
ool5o`000003ooooool0003o000000;o000000?oooooo`000?l000001_ooool2o`0000;ooooo0_l0
0003ooooo`?o00000oooool2o`000003ooooool0003o000001Ko000000?oooooo`000?l000002Ooo
ool2o`0001Cooooo0_l00002ooooo`;o00001_ooool2o`0003cooooo00000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003ooooooooo
o`0`ooooo`;o000000?oooooo`000?l000001_ooool2o`0001oooooo0_l0000Gooooo`;o00006Ooo
ool2o`0000kooooo2_l00009ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`Co000000?o
ooooo`000?l000005_l000000ooooooo0000o`00000Pooooo`;o00002Oooool2o`0003cooooo0000
0ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oMgMgolc<c?l000001oooool0
0ol0003oooooooooo`0`ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00002?ooool4
o`0001;ooooo0_l000000ooooooo0000o`00000:ooooo`?o00000oooool2o`000003ooooool0003o
000000;ooooo1ol00005ooooo`;o00003Oooool2o`0000gooooo0_l000001?oooooo0000o`000?oo
ool2o`0000?ooooo0_l0000Dooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`00
000Do`0001[ooooo0_l00006ooooo`;o0000Aoooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo03Gooooo0_l00002ooooo`;o0000
2?ooool4o`0001;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo1?l00003ooooo`Go0000
00Coooooo`000?l0003ooooo1ol00003ooooo`;o000000?oooooo`000?l000000oooool2o`0000Wo
oooo0_l00002ooooo`;o00001Oooool2o`0000Gooooo0_l00002ooooo`;o00003_ooool2o`000004
ooooool0003o0000oooooa7o000000Goooooo`000?l0003o0000ooooo`08o`0000;ooooo0_l00005
ooooo`;o00000oooool2o`0000[ooooo0_l0000;ooooo`?o0000@Oooool00006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo03?ooooo0_l0
0008ooooo`;o00000_ooool2o`0001Sooooo0_l000000ooooooo0000o`000002ooooo`;o00000ooo
ool2o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`Co00001?ooool2o`0000Kooooo0_l0
0003ooooo`;o00000oooool2o`0000Cooooo0_l00002ooooo`;o00001Oooool2o`0000Gooooo1Ol0
000?ooooo`;o000000?oooooo`000?l000001Ol000000ooooooo0000o`00000Fo`0000?ooooo0_l0
0005ooooo`;o00000oooool2o`0001Oooooo0ol00011ooooo`007?ooool00ol0003oooooooooo`0c
ooooo`;o00002?ooool6o`0001Sooooo1?l00003ooooo`;o000000?oooooo`000?l000001Oooool8
o`000004ooooool0003o0000o`0000Kooooo0_l00004ooooo`Ko00001?ooool2o`0000_ooooo0_l0
0002ooooo`;o00000_ooool2o`000003ooooool0003o000000?o00002_ooool2o`0000Gooooo1Ol0
00000ooooooo0000o`00000Mo`000003ooooool0003o000000_ooooo0ol0000:ooooo`;o00002?oo
ool2o`0000kooooo0_l0000aooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00001Oooool2
o`000003ooooool0003o000000Kooooo0_l00003ooooo`;o00001Oooool2o`0000Kooooo1?l00002
ooooo`ko000000Goooooo`000?l0003o0000ooooo`03o`000003ooooool0003o000000Ko00001Ooo
ool2o`0000[ooooo0_l00006ooooo`;o000000?oooooo`000?l000000ol0000:ooooo`;o000000?o
ooooo`000?l000000_ooool4o`0000;ooooo7ol000000ooooooo0000o`00000;ooooo`?o00002_oo
ool2o`0001Sooooo0_l0000aooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00004oooool2
o`000004ooooool0003o0000ooooo`?o00001Oooool2o`0000?ooooo0_l00005ooooo`;o00002?oo
ool6o`0000;ooooo1ol000001?oooooo0000o`000?ooool3o`0000;ooooo0_l000001?oooooo0000
o`000?ooool2o`0000;ooooo0_l00004ooooo`;o00003oooool2o`0000Kooooo0ol00003ooooo`;o
00001Oooool2o`000003ooooool0003o000000Cooooo0_l00002oooooa?o000000?oooooo`000?l0
00002?l00003ooooo`;o000000?oooooo`000?l000005?ooool3o`0004[ooooo000Looooo`03o`00
0?oooooooooo02kooooo0_l000000ooooooo0000o`00000@ooooo`;o00001Oooool2o`0000?ooooo
0_l0000<ooooo`;o00001_ooool2o`000003ooooool0003o000000;o00000oooool9o`0000Gooooo
1Ol00007ooooo`;o00005Oooool2o`0000?ooooo0_l000001?oooooo0000o`000?l00003ooooo`;o
00001oooool2o`0000Wooooo2Ol00002oooooa?o00000oooool2o`000003ooooool0003o000000;o
oooo0_l0000@ooooo`?o0000B_ooool001cooooo00?o0000ooooooooool0;_ooool2o`000003oooo
ool0003o000000Sooooo0_l0000Booooo`?o00002?ooool2o`0000?ooooo0_l00004ooooo`Co0000
0_ooool4o`000003ooooool0003o000000[o000000?oooooo`000?l000000ol00007ooooo`;o0000
1?ooool2o`0001Cooooo1Ol00004ooooo`;o00001oooool2o`0000Kooooo0_l000000ooooooo0000
o`00000Lo`0000[ooooo0_l0000Rooooo`;o0000>Oooool001cooooo00?o0000ooooooooool0=?oo
ool4o`0000?ooooo0_l0000>ooooo`;o00000oooool2o`0000Sooooo0ol00002ooooo`Go00000_oo
ool3o`0000;ooooo1Ol000001?oooooo0000o`000?ooool8o`000004ooooool0003o0000o`0000Wo
oooo1Ol000000ooooooo0000o`00000Dooooo`Oo00000_ooool2o`000003ooooool0003o000000Oo
oooo1ol000000ooooooo0000o`000004o`000003ooooool0003o000000Co000000?oooooo`000?l0
00003_l000000ooooooo0000o`00000=ooooo`;o00006?ooool2o`0000;ooooo0_l0000iooooo`00
7?ooool00ol0003oooooooooo`0dooooo`Co00004oooool2o`0000Sooooo0_l000001?oooooo0000
o`000?ooool2o`0000?ooooo1?l00002ooooo`Co00000_ooool7o`000003ooooool0003o000000Oo
000000?oooooo`000?l000000_l00007ooooo`Go00000_ooool2o`0001?ooooo0_l00003ooooo`?o
00001?ooool2o`0000Oooooo1Ol00003oooooaco000000?oooooo`000?l000000_l0000=ooooo`;o
00006?ooool2o`0003gooooo000Looooo`03o`000?oooooooooo03_ooooo0_l0000Hooooo`;o0000
00?oooooo`000?l000000ol00004ooooo`;o00000oooool5o`000003ooooool0003o000001Go0000
00?oooooo`000?l000001?ooool3o`0000;ooooo0ol0000;ooooo`;o00001_ooool2o`0000?ooooo
1Ol00004ooooo`;o00003_oooolNo`0006Sooooo000Looooo`03o`000?oooooooooo03_ooooo0_l0
0007ooooo`;o00001?ooool2o`0000kooooo0_l00005ooooo`;o000000?oooooo`000?l000000_l0
00000ooooooo0000o`00000Ko`0000?ooooo1?l00002ooooo`;o00001Oooool2o`000003ooooool0
003o000000;ooooo0_l00006ooooo`;o00000_ooool6o`000004ooooool0003o0000ooooo`;o0000
3ooooolLo`0000;ooooo1?l0001Sooooo`007?ooool00ol0003oooooooooo`0/ooooo`?o00001ooo
ool2o`0000Wooooo0_l000000ooooooo0000o`000004ooooo`;o00002?ooool2o`000004ooooool0
003o0000ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooob;o00000oooool2o`0000Ko
oooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l00007ooooo`;o00000_ooool2o`00
0003ooooool0003o000000;ooooo0_l000000ooooooo0000o`00000?oooooaCo000000?oooooo`00
0?l000001Ol00002ooooo`Co000000Coooooo`000?l0003ooooo0_l00002ooooo`Co00000_ooool2
o`0001Oooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`0/ooooo`Oo00000_ooool5o`00
00Oooooo0_l000000ooooooo0000o`000009ooooo`;o00000oooool2o`000003ooooool0003o0000
00;o00000oooool2o`000004ooooool0003o0000oooooa[o000000?oooooo`000?l000001Ol00004
ooooo`;o00001Oooool2o`0000Wooooo0_l00008ooooo`Co000000?oooooo`000?l000005ooooolL
o`0000Oooooo0_l000000ooooooo0000o`000002ooooo`Co00000_ooool2o`0001Oooooo0_l0000j
ooooo`007?ooool2o`0002oooooo1Ol00002ooooo`Go00001oooool2o`0000?ooooo0_l00007oooo
o`;o00002?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000@o`000003ooooool0003o0000
00_o00000_ooool:o`000003ooooool0003o000000?o00003?ooool3o`0000Gooooo1ol0000Joooo
oaKo00004_ooool2o`0005Sooooo000Looooo`03o`000?oooooooooo02kooooo0_l00006ooooo`;o
00003_ooool2o`0000;ooooo0_l00005ooooo`Co00000oooool2o`0000?ooooo0_l000000ooooooo
0000o`000007o`000003ooooool0003o000000[o000000?oooooo`000?l000001ol00002ooooo`;o
00000_ooool6o`000003ooooool0003o000000?o00000_ooool2o`0000Kooooo1Ol00007ooooo`Go
00005Oooool2o`0000;ooooo5ol0000Booooo`;o000000?oooooo`000?l000009?ooool2o`0002oo
oooo000Looooo`03o`000?oooooooooo04Kooooo0_l00002ooooo`;o000000?oooooo`000?l00000
0_ooool4o`0000?ooooo0_l00002ooooo`?o00000_ooool2o`000003ooooool0003o000000Ko0000
00?oooooo`000?l000004ol000000ooooooo0000o`000002ooooo`So00001Oooool2o`0000Kooooo
0ol00009ooooo`;o00003?ooool2o`0000Wooooo0ol00002oooooaKo00005_ooool2o`0000Gooooo
0_l00002ooooo`;o00003Oooool2o`0000[ooooo0_l0000_ooooo`007?ooool00ol0003ooooooooo
o`1=ooooo`;o00000_ooool2o`0000Cooooo2Ol000000ooooooo0000o`00000Oo`000003ooooool0
003o000000;o00000_ooool2o`000004ooooool0003o0000o`0000Gooooo0_l00002ooooo`;o0000
1_ooool2o`0000Kooooo0_l0000<ooooo`;o00002Oooool2o`0000?ooooo4?l00005ooooo`;o0000
1?ooool3o`0000?ooooo0_l000000ooooooo0000o`000002o`0000_ooooo0_l00002ooooo`Co0000
2oooool2o`0003_ooooo000Looooo`03o`000?oooooooooo04Wooooo0_l00004ooooo`Co00001?oo
ool5o`000004ooooool0003o0000o`0000;ooooo8?l00002ooooo`?o00000_ooool2o`0000;ooooo
0_l00003ooooo`Co00000_ooool2o`0000Gooooo0ol00003ooooo`;o000000?oooooo`000?l00000
7?ooool@o`0000?ooooo1?l00004ooooo`Co00000_ooool2o`000003ooooool0003o000000;o0000
4Oooool2o`0000_ooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00001?oo
ool2o`0000Kooooo0_l00003ooooo`;o00000ooooolRo`000004ooooool0003o0000o`0000_ooooo
1?l00009ooooo`?o00000oooool2o`0000Gooooo0_l0000;ooooo`;o00000_ooool2o`0000[ooooo
3?l00003ooooo`Co00000_ooool2o`0000?ooooo0_l00002ooooo`Co00002?ooool3o`0005?ooooo
000Looooo`03o`000?oooooooooo03gooooo0_l00003ooooo`;o00003oooool2o`0000;ooooo0_l0
0003ooooo`Co000000?oooooo`000?l000009ol000001?oooooo0000o`000?l0000@ooooo`;o0000
0_ooool2o`0000Sooooo1?l00009ooooo`;o00000_ooool2o`0000Gooooo0_l00003ooooo`co0000
0oooool2o`0000;ooooo1Ol00006ooooo`Co00002?ooool3o`0001Oooooo0_l0000jooooo`007?oo
ool00ol0003oooooooooo`0/ooooo`;o00002_ooool4o`000003ooooool0003o000000;ooooo0ol0
000:ooooo`;o00000oooool2o`0000;ooooo<ol000001?oooooo0000o`000?l00002ooooo`;o0000
3?ooool2o`0000;ooooo0_l00003ooooo`Wo00003Oooool2o`0000Gooooo0_l00007ooooo`Go0000
1?ooool2o`0000Cooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l00005ooooo`;o0000
7_ooool2o`0003[ooooo000Looooo`03o`000?oooooooooo02cooooo0_l0000:ooooo`Co00001Ooo
ool2o`0000;ooooo0ol00006ooooo`;o00002?ooool6o`0000;ooooo1Ol000000ooooooo0000o`00
000Qo`0000?ooooo1_l00006ooooo`;o00003Oooool8o`0001?ooooo0_l00007ooooo`Co00000ooo
ool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool2o`0000?ooooo0_l0
0005ooooo`;o0000F_ooool001cooooo00?o0000ooooooooool0=?ooool2o`0000_ooooo0_l00002
ooooo`?o00001_ooool2o`0000Sooooo0ol000000ooooooo0000o`000002ooooo`Go000000?ooooo
o`000?l000007ol00005ooooo`Ko00001_ooool2o`0001;ooooo1?l00003ooooo`;o00003Oooool2
o`0000Oooooo0ol00002ooooo`Co00001Oooool2o`0000;ooooo0_l00003ooooo`;o00001oooool2
o`0005cooooo000Looooo`03o`000?oooooooooo03Cooooo0_l0000Hooooo`;o00002Oooool2o`00
00Gooooo0ol00002ooooobGo00000oooool2o`000003ooooool0003o000000;o00005oooool7o`00
0003ooooool0003o000001_ooooo0_l0000:ooooo`?o00000oooool2o`0000Cooooo0_l000000ooo
oooo0000o`00000Booooo`;o0000B?ooool001cooooo00?o0000ooooooooool0;Oooool2o`0002So
oooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000002So00001Oooool2o`00
0003ooooool0003o000000;o00001Oooool2o`0000Gooooo0_l00007ooooo`;o000000?oooooo`00
0?l000001?l0000>ooooo`?o00001Oooool2o`0000Gooooo0_l00009ooooo`?o00002Oooool2o`00
01Gooooo0_l0000Gooooo`;o0000;oooool001cooooo00?o0000ooooooooool0;Oooool2o`0001[o
oooo0_l0000<ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00000Do`00
0003ooooool0003o000001?o00000oooool2o`0000?ooooo0_l000000ooooooo0000o`000002oooo
o`;o00001Oooool2o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l000000_l00002oooo
o`;o00002Oooool3o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000?ooooo0_l00008oooo
o`;o00004oooool2o`0000?ooooo0_l0000Eooooo`;o0000;oooool001cooooo00?o0000oooooooo
ool0;Oooool2o`0000[ooooo0_l0000>ooooo`;o00002_ooool2o`0000Sooooo5Ol000000ooooooo
0000o`00000Eo`000003ooooool0003o000000;o00000oooool2o`000003ooooool0003o000000Co
oooo1?l00002ooooo`;o00000oooool3o`0000Sooooo0_l00002ooooo`?o00006oooool2o`000003
ooooool0003o000000?ooooo0_l00008ooooo`;o00004oooool2o`0000?ooooo0_l0000Dooooo`;o
0000<?ooool001cooooo00?o0000ooooooooool0;?ooool4o`0000Gooooo0_l00002ooooo`;o0000
6_ooool2o`0000Kooooo2ol000000ooooooo0000o`00000To`0000_ooooo0_l000000ooooooo0000
o`000002o`0000;ooooo0_l00003ooooo`?o00003Oooool2o`0000Gooooo0_l00004ooooo`;o0000
3_ooool2o`0001?ooooo0_l0000[ooooo`;o0000<?ooool001cooooo00?o0000ooooooooool0;?oo
ool4o`0000Gooooo0_l00002ooooo`;o00001?ooool2o`0000cooooo0_l00006ooooo`?o000000?o
ooooo`000?l000000_ooool2o`000003ooooool0003o000000Ko000000?oooooo`000?l000007Ol0
00000ooooooo0000o`000003o`0000Kooooo0_l00004ooooo`?o00002oooool2o`0000?ooooo0_l0
000@ooooo`;o00001?ooool2o`0000gooooo0_l0000Dooooo`;o00000oooool2o`0005Sooooo000L
ooooo`;o0000>_ooool2o`0000?ooooo1Ol0000:ooooo`;o00001oooool2o`000003ooooool0003o
000000?ooooo1?l00002ooooo`Co000000?oooooo`000?l000008ol00006ooooo`;o00001Oooool2
o`0000[ooooo0_l00004ooooo`;o00009Oooool2o`00013ooooo0_l00007ooooo`;o00006_ooool2
o`0003cooooo000Looooo`03o`000?oooooooooo03Cooooo0_l00008ooooo`;o000000?oooooo`00
0?l000003Oooool2o`0000Sooooo3_l000000ooooooo0000o`000003o`000003ooooool0003o0000
00go000000?oooooo`000?l000003ol00003ooooo`;o00004?ooool4o`0000Kooooo0_l0000<oooo
o`;o00003?ooool2o`0001Wooooo0_l00004ooooo`;o00001?ooool2o`0000;ooooo0ol0000Boooo
o`;o0000??ooool001cooooo00?o0000ooooooooool0=?ooool2o`0001Cooooo0_l000001?oooooo
0000o`000?ooool2o`0000Cooooo0_l00002ooooo`Go000000?oooooo`000?l000001_l000000ooo
oooo0000o`000003o`000003ooooool0003o000000go00000_ooool3o`000003ooooool0003o0000
00;o000000?oooooo`000?l000001Ol00003ooooo`;o00004?ooool2o`0000Sooooo0_l0000<oooo
o`;o00000oooool2o`0000Oooooo0_l0000Oooooo`;o00001?ooool8o`0004oooooo000Looooo`03
o`000?oooooooooo03_ooooo0_l00008ooooo`;o00000oooool2o`000003ooooool0003o000000Oo
oooo0_l00003ooooo`;o00000oooool4o`0000;ooooo7Ol000000ooooooo0000o`000005o`000003
ooooool0003o000001?ooooo0_l0000Mooooo`Co00001?ooool2o`000003ooooool0003o000002Co
oooo3_l0001:ooooo`007?ooool00ol0003oooooooooo`0kooooo`;o00002?ooool2o`0000Gooooo
0_l0000Booooo`Co000000?oooooo`000?l000004Ol000000ooooooo0000o`000008o`000003oooo
ool0003o000000Go000000?oooooo`000?l000000_ooool2o`0000Kooooo0_l00007ooooo`;o0000
1_ooool2o`0000cooooo0_l00007ooooo`;o000000?oooooo`000?l000000oooool2o`0000;ooooo
0_l0000<ooooo`;o00001?ooool2o`0000;ooooo0_l00002ooooo`;o00001_ooool?o`000003oooo
ool0003o000004Oooooo000Looooo`03o`000?oooooooooo04cooooo0_l0000:ooooo`Co000000Co
ooooo`000?l0003ooooo1?l000000ooooooo0000o`00000Lo`000003ooooool0003o000000Co0000
0_ooool3o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o00003oooool2o`0000cooooo
0_l0000:ooooo`;o00001oooool3o`000003ooooool0003o000000Sooooo0_l00004ooooo`Ko0000
0_ooool4o`0000Cooooo1_l000000ooooooo0000o`000004o`000003ooooool0003o000000;o0000
Aoooool001cooooo00?o0000ooooooooool0=?ooool4o`0000Wooooo0_l00006ooooo`;o00002Ooo
ool2o`0000;ooooo1ol00003ooooo`;o00000_ooool2o`000004ooooool0003o0000o`0000;ooooo
6_l00002ooooo`;o000000?oooooo`000?l000001?ooool3o`000003ooooool0003o000000Kooooo
0_l00003ooooo`Go00002?ooool2o`0000cooooo0_l00002ooooo`;o00001_ooool4o`000003oooo
ool0003o000000Oooooo0_l00007ooooo`;o00001_ooool2o`0000Cooooo4_l00017ooooo`007?oo
ool00ol0003oooooooooo`0dooooo`Go00002?ooool2o`0000;ooooo0_l00002ooooo`;o00002Ooo
ool2o`0000Cooooo1Ol00003ooooo`;o00001OoooolOo`0000;ooooo0_l000000ooooooo0000o`00
0004ooooo`?o000000?oooooo`000?l000000oooool2o`000003ooooool0003o000000?ooooo1Ol0
0002ooooo`;o00001?ooool2o`0000cooooo0_l00004ooooo`;o00001?ooool3o`0000_ooooo0_l0
000Foooooa7o0000Aoooool001cooooo00?o0000ooooooooool09oooool2o`0000kooooo0_l0000<
ooooo`;o00002Oooool2o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2
o`0000?ooooo0_l000000ooooooo0000o`00000Ho`000003ooooool0003o000000;o00000oooool4
o`0000Cooooo0ol00006ooooo`;o00000oooool2o`0000Cooooo0ol000001?oooooo0000o`000?oo
ool2o`0000;ooooo0_l0000Aooooo`;o00002?ooool2o`0000[ooooo0_l0000Dooooo`So000000?o
ooooo`000?l000001_l00017ooooo`007?ooool00ol0003oooooooooo`0Wooooo`;o00005?ooool2
o`0000Sooooo0_l00003ooooo`;o00000_ooool2o`0000Cooooo0_l00004ooooo`;o00000oooool2
o`0000?ooooo8_l00003ooooo`Co000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00001ooo
ool2o`0000Gooooo0_l00002ooooo`Co00000_ooool2o`0000?ooooo0_l0000Fooooo`?o00002Ooo
ool2o`0001Cooooo3ol00003ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0?Oooool2
o`0000;ooooo0_l00004ooooo`;o00000oooool3o`0000Gooooo0_l00003ooooo`;o000000?ooooo
o`000?l000001Oooool3o`0000;ooooo1_l000000ooooooo0000o`000002o`000003ooooool0003o
000000Ko00001?ooool6o`0000Cooooo0ol00002ooooo`Ko00000oooool2o`0001;ooooo0_l00009
ooooo`;o00002oooool2o`0000[ooooo0_l0000Oooooo`oo00000oooool2o`0001Kooooo0_l0000/
ooooo`007?ooool00ol0003oooooooooo`0looooo`?o00000_ooool2o`0000Wooooo0ol00002oooo
o`;o000000Coooooo`000?l0003ooooo1?l00008ooooo`?o000000?oooooo`000?l000001Ol00000
0ooooooo0000o`000002o`0000?ooooo0ol00002ooooo`;o00000oooool4o`0000Cooooo1Ol00002
ooooo`Ko00001?ooool2o`0000Gooooo0_l0000<ooooo`;o00003?ooool2o`000003ooooool0003o
000000;ooooo0ol0000[ooooo`oo00006oooool2o`0002cooooo000Looooo`03o`000?oooooooooo
03cooooo0ol00007ooooo`;o00001?ooool2o`0000?ooooo0_l00004ooooo`?o00002_ooool2o`00
0003ooooool0003o000000[o00000_ooool8o`0000Sooooo0_l000001?oooooo0000o`000?ooool3
o`000003ooooool0003o000000Sooooo0_l00005ooooo`?o00001?ooool2o`0000Gooooo0ol0000;
ooooo`;o000000?oooooo`000?l000000_ooool3o`000004ooooool0003o0000ooooo`;o00003Ooo
ool2o`0000Oooooo0_l0000<ooooo`oo0000B_ooool001cooooo00?o0000ooooooooool0=_ooool2
o`0000Cooooo0_l00008ooooo`;o00001?ooool7o`0000Gooooo1?l0000<ooooo`?o00000_ooool2
o`000005ooooool0003o0000o`000?ooool00ol000000ooooooo0000o`000002o`0000Wooooo0_l0
0005ooooo`;o00004oooool2o`000004ooooool0003o0000ooooo`;o00001_ooool2o`0000[ooooo
0_l00002ooooo`;o00001_ooool2o`000003ooooool0003o000000;o00002oooool2o`0000Oooooo
0_l0000<ooooo`Co00000oooool8o`0004[ooooo000Looooo`03o`000?oooooooooo03Kooooo0_l0
0004ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Gooooo1Ol00007ooooo`;o00003Ooo
ool2o`0000Gooooo0ol000000ooooooo0000o`00000:o`0000;ooooo0_l00006ooooo`Co00001_oo
ool2o`0000cooooo1?l0000Eooooo`;o00002?ooool4o`0000?ooooo0_l00004ooooo`;o00009?oo
ool3o`000003ooooool0003o000000Gooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0i
ooooo`;o00001?ooool2o`0000Kooooo0_l00009ooooo`;o00007oooool7o`0000;ooooo1?l00002
ooooo`?o00001Oooool2o`0000Gooooo1Ol00006ooooo`;o00001?ooool2o`0000Cooooo0_l00002
ooooo`;o00003Oooool2o`0000Sooooo0_l00007ooooo`;o00000_ooool2o`0002Sooooo0_l00005
ooooo`;o00003Oooool2o`0003Gooooo000Looooo`;o0000>_ooool2o`000003ooooool0003o0000
013ooooo0_l00002ooooo`;o00005_ooool2o`0000Oooooo0_l000000ooooooo0000o`000002o`00
00Wooooo0ol0000;ooooo`Co00001oooool2o`0000[ooooo0_l00002ooooo`;o00001Oooool2o`00
0003ooooool0003o000000Cooooo0_l00004ooooo`;o000000Coooooo`000?l0003o00000oooool2
o`000003ooooool0003o000002;ooooo0_l00006ooooo`;o000000Coooooo`000?l0003o00004_oo
ool2o`0003Gooooo000Looooo`03o`000?oooooooooo03cooooo0_l0000@ooooo`Co00003?ooool2
o`0000;ooooo1?l00004ooooo`;o00003?ooool2o`0000Kooooo0ol000001?oooooo0000o`000?oo
ool2o`0002[ooooo1Ol00004ooooo`;o000000Coooooo`000?l0003ooooo0ol000000ooooooo0000
o`000003ooooo`?o00007?ooool2o`0000Kooooo0_l00006ooooo`;o000000Coooooo`000?l0003o
0000BOooool001cooooo00?o0000ooooooooool0<oooool2o`0000_ooooo0ol00005ooooo`;o0000
1?ooool5o`0000_ooooo0_l00002ooooo`Co00004?ooool4o`000003ooooool0003o000000?ooooo
0ol00004ooooo`;o0000;?ooool4o`0000Kooooo1_l00007ooooo`;o00004oooool2o`0000Oooooo
0_l0000Uooooo`;o0000=_ooool001cooooo00?o0000ooooooooool0<oooool2o`0000_ooooo0ol0
0005ooooo`;o00001?ooool2o`000003ooooool0003o000000Wooooo0_l0000Hooooo`;o00000ooo
ool2o`00013ooooo0_l0000@ooooo`;o00001oooool2o`0000gooooo0_l00002ooooo`go00006Ooo
ool2o`0002kooooo0_l0000fooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00001Oooool2
o`000003ooooool0003o000000Oooooo0ol00008ooooo`;o00000oooool2o`0000Kooooo0_l0000?
ooooo`Co00005?ooool2o`00013ooooo0_l00005ooooo`Co00004?ooool?o`00083ooooo000Loooo
o`03o`000?oooooooooo03Wooooo0_l00008ooooo`;o00001oooool3o`0000Sooooo0_l0000;oooo
o`;o00000_ooool2o`0000[ooooo1Ol0000;ooooo`;o00005oooool3o`0000;ooooo0_l00002oooo
o`;o00002oooool2o`0000;ooooo4_l00020ooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o
00004_ooool2o`0000Sooooo0_l00008ooooo`;o00001?ooool4o`0000?ooooo0_l00006ooooo`;o
00002_ooool2o`0000;ooooo0_l00006ooooo`;o00000_ooool2o`0001Oooooo0ol00002ooooo`;o
00000_ooool2o`0000?ooooo0_l00006ooooo`;o00000_ooool@o`0000;ooooo1?l0000@ooooo`;o
00003?ooool2o`0005cooooo000Looooo`03o`000?oooooooooo02Wooooo1?l0000Booooo`;o0000
2?ooool2o`0000Gooooo1Ol00004ooooo`Go00000_ooool2o`0000Cooooo0_l0000@ooooo`;o0000
1_ooool2o`0001kooooo1?l00004ooooo`Go00001Oooool2o`0000?ooooo4Ol000000ooooooo0000
o`000002o`0000Wooooo0_l00005ooooo`?o00002_ooool3o`0001Cooooo0_l00016ooooo`007?oo
ool00ol0003oooooooooo`0Yooooo`;o00009Oooool3o`0000Wooooo0_l00007ooooo`?o00004?oo
ool2o`0000kooooo0_l0000Fooooo`Co00001?ooool4o`0000Kooooo0_l00002oooooa;o000000?o
ooooo`000?l000000_l00009ooooo`;o00001_ooool2o`0000Kooooo0_l00002ooooo`;o000000?o
ooooo`000?l000000_l000000ooooooo0000o`000009ooooo`;o00000_ooool2o`0001Cooooo0_l0
000`ooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o000000?oooooo`000?l000003?ooool2
o`000003ooooool0003o000000Kooooo0ol00006ooooo`;o00004?ooool2o`0001?ooooo0_l00009
ooooo`Co00001_ooool2o`0000;ooooo6ol00009ooooo`;o00002_ooool2o`0000Gooooo1?l00000
0ooooooo0000o`000009ooooo`;o00001Oooool2o`0000[ooooo0_l00005ooooo`;o0000<?ooool0
01cooooo00?o0000ooooooooool0=?ooool2o`0000Sooooo0_l0000Dooooo`;o00003?ooool2o`00
00;ooooo0_l00005ooooo`Co000000?oooooo`000?l000000_ooool2o`0000Wooooo0_l00003oooo
o`;o00005Oooool2o`000003ooooool0003o000000Kooooo1?l00006ooooo`;o000000?oooooo`00
0?l000000ol000000ooooooo0000o`00000?o`000003ooooool0003o000000;o00002Oooool2o`00
00oooooo0_l00005ooooo`;o00004?ooool2o`0000[ooooo0_l0000gooooo`007?ooool00ol0003o
ooooooooo`0dooooo`;o00001oooool5o`0000cooooo1?l00003ooooo`;o000000?oooooo`000?l0
00002_ooool4o`0000?ooooo1_l000000ooooooo0000o`00000;ooooo`Co00000oooool2o`0001So
oooo0ol0000?ooooo`;o000000?oooooo`000?l000005Ol0000Kooooo`;o00000_ooool2o`0000Go
oooo1?l00005ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0?Oooool2o`000003oooo
ool0003o000000cooooo1?l000000ooooooo0000o`000005o`0000Cooooo0_l000000ooooooo0000
o`000003o`0000Gooooo0_l0000Booooo`;o00002?ooool2o`0001Kooooo0_l00006ooooo`;o0000
1_oooolKo`0000?ooooo0_l0000Fooooo`;o00001oooool2o`0000;ooooo0_l00005ooooo`;o0000
2?ooool2o`0000Sooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00005?oo
ool3o`000003ooooool0003o000000Gooooo0_l000000ooooooo0000o`000002o`0002Cooooo0_l0
000Nooooo`Co00001?ooool2o`000004ooooool0003o0000oooooaGo00000oooool2o`0000gooooo
0_l00004ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l0000@ooooo`Go0000
2?ooool2o`0003Sooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05
onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0kooooo`?o00003Oooool2o`00
00Gooooo1?l0000Cooooo`;o0000:_ooool2o`0000[ooooo0_l000000ooooooo0000o`000003oooo
o`Co00001oooool2o`000003ooooool0003o000001?o00004_ooool2o`000004ooooool0003o0000
ooooo`;o000000Coooooo`000?l0003ooooo0ol0000Eooooo`?o0000A?ooool00006oooooomgMgOo
V9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03
o`000?oooooooooo03Cooooo0_l00005ooooo`?o00003Oooool2o`0000Gooooo0ol00008ooooo`;o
00002?ooool4o`0000Sooooo0_l00007ooooo`;o00001Oooool2o`00013ooooo0_l00006ooooo`;o
00000_ooool2o`000004ooooool0003o0000o`0000Kooooo0_l000001?oooooo0000o`000?oooolI
o`0000[ooooo0_l00009ooooo`;o00001oooool2o`0005gooooo00000ooooooo410@ooooo`02oooo
o`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo02[ooooo0_l00008ooooo`;o00001oooool2o`0001Oooooo0_l00005ooooo`;o00000_ooool2
o`0000Cooooo0_l0000:ooooo`;o00001oooool2o`0000Gooooo0_l00006ooooo`;o00004?ooool2
o`0000;ooooo0_l00002ooooo`;o00001_ooool2o`000004ooooool0003o0000oooooa[o00002Ooo
ool3o`0000Sooooo0_l000000ooooooo0000o`000004ooooo`;o00004oooool2o`0004Sooooo0000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oiRHV?ooooooV9RHob4Q
8@06ooooo`?o0000:_ooool2o`0000Sooooo0_l00007ooooo`;o00005_ooool5o`000003ooooool0
003o000000Cooooo0_l0000Iooooo`;o00001?ooool2o`0000Oooooo0_l000000ooooooo0000o`00
000Aooooo`;o00004OoooolFo`000003ooooool0003o000000[ooooo0_l00008ooooo`;o000000?o
ooooo`000?l000000_l0000Gooooo`;o00000_ooool2o`0004Cooooo00000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oo
oooooooo03_ooooo0_l0000Hooooo`;o000000Coooooo`000?l0003ooooo0_l0000=ooooo`;o0000
4?ooool2o`000004ooooool0003o0000ooooo`;o00001?ooool2o`0000Cooooo0_l0000Kooooo`;o
00001ooooolEo`0000?ooooo0_l0000Hooooo`;o00005?ooool2o`0000Gooooo1?l00012ooooo`00
00?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo
00?o0000ooooooooool0>oooool3o`0001Oooooo0_l00005ooooo`;o00003?ooool2o`0000Gooooo
0ol0000;ooooo`;o00001_ooool3o`0000Oooooo0_l00002ooooo`;o00003oooool4o`000004oooo
ool0003o0000o`0000Cooooo1Ol000000ooooooo0000o`00000Do`0000?ooooo1?l0000Wooooo`;o
00000_ooool2o`0000?ooooo0_l00012ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;oooo
o`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0>Oooool2o`000004ooooool0003o0000
o`0000Oooooo0ol0000:ooooo`Co00001Oooool2o`0001?ooooo0ol0000>ooooo`?o00000_ooool2
o`0000Cooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000cooooo2?l00004
oooooa_o00001?ooool6o`00013ooooo0_l0000Gooooo`;o00003_ooool2o`0003Oooooo00001_oo
ooook^k^oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003ooooo
ooooo`0iooooo`?o000000?oooooo`000?l000000_ooool2o`0000?ooooo0ol0000:ooooo`;o0000
0oooool2o`0000?ooooo0_l0000Booooo`;o00002oooool7o`0000Sooooo0_l00004ooooo`?o0000
0_ooool2o`0000?ooooo0_l00002ooooo`;o00001oooool2o`0000[ooooo5?l000000ooooooo0000
o`000008ooooo`;o00004?ooool2o`0001Kooooo0_l000000ooooooo0000o`00000<ooooo`;o0000
=oooool001cooooo00?o0000ooooooooool0>_ooool2o`0000;ooooo0_l000000ooooooo0000o`00
0007ooooo`;o00002oooool3o`0000?ooooo1?l000000ooooooo0000o`000005ooooo`;o00001_oo
ool2o`0000;ooooo0_l00005ooooo`Oo000000?oooooo`000?l000000_ooool2o`0000Wooooo0ol0
0002ooooo`;o00000oooool2o`0000;ooooo0_l0000CoooooaKo00003Oooool2o`0000oooooo0_l0
0006ooooo`;o00002oooool2o`000003ooooool0003o000000Sooooo0_l0000kooooo`007?ooool0
0ol0003oooooooooo`0nooooo`;o00001?ooool2o`0000Cooooo0_l0000;ooooo`;o00001_ooool2
o`000003ooooool0003o000000Gooooo0ol00003ooooo`;o00001?ooool2o`0000Gooooo0_l00003
ooooo`;o000000?oooooo`000?l000000_ooool2o`0001cooooo0_l0000=oooooa;o000000?ooooo
o`000?l000000_l0000=ooooo`;o00003oooool2o`0000Kooooo0_l0000;ooooo`;o00002oooool2
o`0003_ooooo000Looooo`03o`000?oooooooooo03Sooooo0_l00004ooooo`;o00000_ooool4o`00
02?ooooo0ol00003ooooo`;o00004?ooool3o`0000Wooooo0_l00007ooooo`;o00003_ooool4o`00
0003ooooool0003o000000Sooooo0_l000000ooooooo0000o`00000<o`0000;ooooo0_l00008oooo
o`;o000000?oooooo`000?l000007?ooool2o`0000_ooooo0_l00017ooooo`007?ooool00ol0003o
ooooooooo`0hooooo`?o00000oooool2o`0000;ooooo0_l0000Eooooo`;o00001?ooool2o`0000Wo
oooo1?l0000Dooooo`;o00000_ooool5o`0000;ooooo0_l00007ooooo`?o00003oooool2o`000003
ooooool0003o000000Oooooo2Ol000000ooooooo0000o`000002o`0000;ooooo0_l0000<ooooo`;o
000000?oooooo`000?l000006Oooool2o`000003ooooool0003o000000_ooooo0_l0000;ooooo`;o
0000>_ooool001cooooo00?o0000ooooooooool0>Oooool2o`0000_ooooo0_l0000Aooooo`;o0000
1?ooool2o`0000;ooooo0_l00007ooooo`?o00003_ooool2o`0000?ooooo0_l00002ooooo`Wo0000
1Oooool5o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l000003OoooolBo`0001;ooooo
0_l00002ooooo`;o00001?ooool2o`0000_ooooo0ol00005ooooo`;o00005?ooool2o`0003[ooooo
000Looooo`03o`000?oooooooooo04;ooooo0_l00002ooooo`;o00006oooool2o`0000Sooooo0_l0
000=ooooo`?o000000?oooooo`000?l000000_l00004ooooo`Ko000000?oooooo`000?l000001Ol0
0005ooooo`;o00000_ooool2o`000003ooooool0003o000000?o000000?oooooo`000?l000002_oo
oolBo`0000kooooo0_l00002ooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`00
0008ooooo`;o00001_ooool2o`0000Sooooo0_l00006ooooo`;o0000?_ooool001cooooo00?o0000
ooooooooool0@_ooool2o`0000;ooooo0ol000000ooooooo0000o`00000Looooo`;o00004_ooool2
o`0000;ooooo0_l00006ooooo`go000000Coooooo`000?l0003o00001_ooool2o`000004ooooool0
003o0000o`0000?ooooo0_l0000;ooooo`;o00000oooool4o`000003ooooool0003o000000;o0000
4Oooool2o`0000kooooo0ol0000Hooooo`Co00001_ooool2o`0003kooooo000Looooo`03o`000?oo
oooooooo04Kooooo0ol000000ooooooo0000o`000005ooooo`;o00005Oooool2o`0001Kooooo0_l0
0005ooooo`ko000000?oooooo`000?l000000_l00002ooooo`;o000000?oooooo`000?l000006_oo
ool3o`0000;ooooo1_l0000:ooooo`;o00000_ooool2o`0000kooooo0_l00009ooooo`;o00003_oo
ool2o`0004Sooooo000Looooo`03o`000?oooooooooo04Gooooo0_l00003ooooo`;o00001Oooool2
o`0002Cooooo0_l00009ooooo`;o00000ooooolCo`0000;ooooo0_l0000Aooooo`;o00003_ooool7
o`0000[ooooo0_l00002ooooo`;o00005oooool6o`0005Kooooo000Looooo`03o`000?oooooooooo
04Gooooo0_l00003ooooo`Co0000:Oooool2o`0000Wooooo0_l00003oooooaGo00002?ooool2o`00
0003ooooool0003o000000Kooooo0_l0000>ooooo`;o000000?oooooo`000?l000000_l00004oooo
o`;o00002?ooool2o`0000Sooooo0_l0000;ooooo`Co00000_ooool2o`0000Sooooo0_l0001<oooo
o`007?ooool00ol0003oooooooooo`0mooooo`;o00000_ooool2o`0000Cooooo0_l00003ooooo`;o
0000:?ooool4o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l000002Ol000000ooooooo
0000o`000008o`0000Sooooo0_l000000ooooooo0000o`000002o`0001Wooooo0_l00004ooooo`;o
00001_ooool4o`0000Sooooo0_l0000;ooooo`Co00000oooool3o`0000Kooooo0_l0001<ooooo`00
7?ooool2o`0003kooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l0000]ooooo`Co
000000Goooooo`000?l0003o0000ooooo`02o`0000;ooooo5ol000000ooooooo0000o`000003oooo
o`;o00001oooool2o`0000Cooooo1_l0000=ooooo`;o00003_ooool2o`0000?ooooo0_l00005oooo
o`;o000000?oooooo`000?l000002?ooool2o`0000?ooooo1Ol0001Dooooo`007?ooool00ol0003o
ooooooooo`14ooooo`?o00003Oooool2o`0002Gooooo0_l00002ooooo`;o000000?oooooo`000?l0
00002Ol000001?oooooo0000o`000?ooool<o`0000?ooooo0_l0000=ooooo`Ko00003Oooool2o`00
01?ooooo0_l00007ooooo`?o00003Oooool3o`0005Kooooo000Looooo`03o`000?oooooooooo04Go
oooo0_l0000=ooooo`?o00007Oooool2o`0000_ooooo7Ol000001?oooooo0000o`000?l0000Joooo
o`;o00008?ooool4o`0002?ooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`0looooo`?o
00002?ooool2o`0000cooooo0_l0000Mooooo`;o00002ooooolMo`000003ooooool0003o000001_o
oooo0ol0000:ooooo`;o00003Oooool2o`000003ooooool0003o000000?o00003_ooool2o`000003
ooooool0003o000001;ooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`0looooo`?o0000
0oooool3o`0000;ooooo0_l0000]ooooo`;o00002_ooool2o`000003ooooool0003o000001Co0000
00?oooooo`000?l000002?ooool2o`0000cooooo0_l00007ooooo`;o00002_ooool5o`0000Kooooo
1_l000000ooooooo0000o`000002o`0000oooooo0_l000000ooooooo0000o`00001Fooooo`007?oo
ool00ol0003oooooooooo`12ooooo`?o0000<Oooool2o`0000gooooo6_l00007ooooo`?o00001?oo
ool2o`0000Gooooo0_l0000Eooooo`Oo00000_ooool4o`0000_ooooo0_l0000?ooooo`Ko00000_oo
ool2o`0004_ooooo000Looooo`03o`000?oooooooooo04?ooooo0_l00002ooooo`;o0000:oooool2
o`0000_ooooo0_l000000ooooooo0000o`00000Lo`0000Gooooo0_l00004ooooo`;o00007oooool4
o`0000Cooooo0_l0000;ooooo`;o00000oooool2o`0000[ooooo1_l00002ooooo`;o0000Boooool0
01cooooo00?o0000ooooooooool0@oooool3o`000003ooooool0003o000000;o00001_ooool2o`00
027ooooo0_l00006ooooo`;o00000oooool2o`000003ooooool0003o000001Oo000000?oooooo`00
0?l000000_l0000;ooooo`;o00007Oooool2o`0000Gooooo0_l000000ooooooo0000o`000009oooo
o`;o000000?oooooo`000?l000000_ooool2o`0000Gooooo0_l0001Hooooo`007?ooool00ol0003o
ooooooooo`14ooooo`;o00000oooool2o`0000Kooooo0_l00002ooooo`;o000000?oooooo`000?l0
00006_ooool2o`0000Kooooo0_l00003ooooo`;o00000_oooolHo`000003ooooool0003o000000;o
oooo0_l00004ooooo`;o00008_ooool2o`0000Gooooo0_l0000<ooooo`Go00001?ooool2o`0000?o
oooo0_l00003ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0EOooool2o`000003oooo
ool0003o000001[ooooo1?l00003ooooo`;o00001?ooool3o`0000;ooooo1?l000000ooooooo0000
o`000003o`000003ooooool0003o000000[o000000?oooooo`000?l000001?l00004ooooo`;o0000
0_ooool3o`0000gooooo0_l00007ooooo`Co00002?ooool2o`0000Sooooo0_l00006ooooo`;o0000
1Oooool2o`0000Sooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o0000:_oo
ool2o`0000?ooooo0_l00005ooooo`?o000000?oooooo`000?l000005_l00002ooooo`?o00002Ooo
ool3o`0000Oooooo1?l00002ooooo`;o00001oooool4o`0000Sooooo0_l00008ooooo`;o00001?oo
ool2o`00017ooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o00001Oooool2
o`0000Kooooo0_l0000Looooo`;o00001ooooolNo`0000?ooooo0_l00005ooooo`?o00002oooool4
o`0000;ooooo0_l00008ooooo`;o00004?ooool2o`0000Oooooo0_l0000?ooooo`;o0000EOooool0
01cooooo00?o0000ooooooooool0Coooool5o`0000Gooooo0_l0000Looooo`;o00000_ooool2o`00
00?ooooo7ol00009ooooo`?o00002_ooool2o`0000_ooooo0_l00002ooooo`;o00003oooool3o`00
00Gooooo0_l00007ooooo`;o00002?ooool2o`0000;ooooo0_l0001Aooooo`007?ooool00ol0003o
ooooooooo`1?ooooo`;o000000?oooooo`000?l000009oooool2o`0000?ooooo0ol00002oooooaGo
000000?oooooo`000?l000000ol000000ooooooo0000o`00000Booooo`;o00001oooool2o`0000;o
oooo0_l0000Booooo`?o00000oooool2o`000003ooooool0003o000000;o00001Oooool3o`0000Go
oooo1?l000001?oooooo0000o`000?l00004ooooo`;o0000Boooool001cooooo00?o0000oooooooo
ool0E?ooool2o`0002[ooooo6_l000000ooooooo0000o`000003o`000003ooooool0003o000000Go
oooo0ol0000Booooo`?o00002oooool2o`0000Wooooo0_l00003ooooo`?o00000oooool2o`0000Ko
oooo0_l00005ooooo`Co000000?oooooo`000?l000001Oooool2o`0004_ooooo000Looooo`03o`00
0?oooooooooo04oooooo0_l00003ooooo`;o000000?oooooo`000?l000006Oooool2o`0000kooooo
0ol000000ooooooo0000o`000006o`000003ooooool0003o0000013o00001_ooool4o`0001;ooooo
1?l00003ooooo`;o00001Oooool2o`0000Wooooo0_l00002ooooo`Ko0000JOooool001cooooo0_l0
001@ooooo`;o00001_ooool2o`0001Wooooo0_l00008ooooo`;o000000Coooooo`000?l0003ooooo
0ol00003oooooaWo00001_ooool2o`0000_ooooo0_l00007ooooo`Co00000oooool2o`0000?ooooo
0_l00009ooooo`;o00001?ooool6o`0000kooooo0_l0001Iooooo`007?ooool00ol0003ooooooooo
o`1looooo`;o000000?oooooo`000?l000000_ooool4o`000003ooooool0003o000000go00000ooo
ool2o`0000Oooooo0_l000000ooooooo0000o`000004ooooo`;o00001_ooool2o`0000;ooooo0_l0
000=ooooo`Co00002Oooool2o`0000Gooooo0_l0000Aooooo`;o0000FOooool001cooooo00?o0000
ooooooooool0C?ooool2o`0000;ooooo0_l00005ooooo`;o0000:_oooolFo`000004ooooool0003o
0000o`0000Kooooo0_l000000ooooooo0000o`000004ooooo`;o00002_ooool2o`0000Wooooo1_l0
0020ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00001_ooool2o`0000;ooooo0_l00005
ooooo`;o00006_ooool2o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`;o00000_oooolA
o`000003ooooool0003o000000Go00006?ooool3o`0000_ooooo1Ol00004ooooo`So00001?ooool3
o`0001Kooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00003?ooool2o`00
00Oooooo0_l0000;ooooo`Co00001oooool2o`0000;ooooo0_l000000ooooooo0000o`000004oooo
o`;o00000_oooolFo`0001_ooooo0ol000000ooooooo0000o`000005o`000003ooooool0003o0000
00Kooooo0_l000000ooooooo0000o`000008o`0000;ooooo0ol0000Fooooo`;o0000E_ooool001co
oooo00?o0000ooooooooool0D_ooool3o`0000?ooooo1Ol0000;ooooo`Co00006_oooolDo`0000oo
oooo0_l0000>ooooo`Oo000000?oooooo`000?l000001?ooool4o`000003ooooool0003o000000;o
oooo0_l00002ooooo`Co00001Oooool2o`000003ooooool0003o000000Oooooo0_l00005ooooo`;o
0000Eoooool001cooooo00?o0000ooooooooool0Doooool2o`0000?ooooo1?l0000Tooooo`;o0000
0_oooolDo`0000Gooooo0_l0000:ooooo`;o00002Oooool2o`0000Cooooo0_l000000ooooooo0000
o`000008ooooo`;o00000oooool2o`0000;ooooo0_l00004ooooo`;o00001Oooool2o`000003oooo
ool0003o000000Kooooo0ol00005ooooo`;o0000Eoooool001cooooo00?o0000ooooooooool0F?oo
ool4o`0000Wooooo0_l0000:ooooo`;o00002Oooool2o`0000;ooooo0_l00002ooooo`;o00000_oo
ool4o`000003ooooool0003o000000Go00000oooool5o`000003ooooool0003o000001Gooooo0ol0
0003ooooo`;o00005oooool2o`0001;ooooo0ol0001Oooooo`007?ooool00ol0003oooooooooo`1H
ooooo`Co00002Oooool2o`000003ooooool0003o000000Oooooo0_l00009ooooo`;o00000_ooool2
o`0000;ooooo1Ol000000ooooooo0000o`000007o`0000?ooooo1_l0000;ooooo`Co00002_ooool2
o`0000Kooooo0_l0000Dooooo`;o00004_ooool3o`0000[ooooo0_l0001Cooooo`007?ooool00ol0
003oooooooooo`1Hooooo`;o00002oooool5o`0000;ooooo1?l0000@ooooo`;o00000_ooool<o`00
0003ooooool0003o000000?ooooo1Ol0000<ooooo`Co00002oooool2o`0000Gooooo0_l00009oooo
o`;o000000?oooooo`000?l000003Oooool2o`0000cooooo0_l0000:ooooo`;o0000Doooool001co
oooo00?o0000ooooooooool0F?ooool2o`0000_ooooo0ol00004ooooo`Co00006Oooool2o`0000;o
oooo0_l0000:ooooo`;o00005_ooool2o`0000?ooooo0ol00004ooooo`;o00001oooool8o`0000;o
oooo0_l00007ooooo`?o0000KOooool001cooooo00?o0000ooooooooool0R?ooool2o`0000?ooooo
1Ol00002ooooo`Co00001_ooool2o`0000;ooooo0_l0000=ooooo`;o00001?ooool2o`0000Cooooo
0_l00005ooooo`Oo000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l00002ooooo`;o0000
2oooool2o`00067ooooo000Looooo`03o`000?oooooooooo08?ooooo0_l000000ooooooo0000o`00
0002o`0000Gooooo1?l000000ooooooo0000o`000002o`0000?ooooo0_l000001Ooooooo0000o`00
0?l0003ooooo00;o00007?ooool:o`0000_ooooo1?l00002ooooo`;o00002Oooool2o`00067ooooo
000Looooo`03o`000?oooooooooo077ooooo0_l0000@ooooo`;o000000?oooooo`000?l000000ooo
ool2o`0000;ooooo1?l000000ooooooo0000o`000002o`0000?ooooo0_l00002ooooo`;o00002_oo
ool2o`0000;ooooo0_l000000ooooooo0000o`00000<ooooo`Co00000_ooool2o`0000oooooo0ol0
00001?oooooo0000o`000?ooool2o`0006Wooooo000Looooo`03o`000?oooooooooo05Oooooo0_l0
000Fooooo`Co00002Oooool2o`0000gooooo0_l00005ooooo`;o000000?oooooo`000?l000002?oo
ool2o`0000Sooooo1Ol000001?oooooo0000o`000?ooool2o`0000cooooo0_l00004ooooo`;o0000
4?ooool2o`0000;ooooo1?l00008ooooo`;o00000oooool2o`0005[ooooo000Looooo`03o`000?oo
oooooooo05Oooooo1?l0000Dooooo`Ko00001oooool2o`0001Cooooo0_l000000ooooooo0000o`00
0008ooooo`;o00000oooool2o`0000?ooooo1_l00006ooooo`;o00001Oooool2o`0000_ooooo0_l0
0009ooooo`?o00001Oooool3o`000003ooooool0003o000000Gooooo0ol00003ooooo`;o0000F_oo
ool001cooooo0_l0001Booooo`;o00001_ooool2o`0001Cooooo1_l00007ooooo`;o00006Oooool2
o`0000_ooooo0ol00002ooooo`Ko00001_ooool2o`000003ooooool0003o000000;ooooo0_l0000;
ooooo`;o00000_ooool2o`0000Gooooo1Ol00004ooooo`;o000000?oooooo`000?l000001Oooool3
o`0005oooooo000Looooo`03o`000?oooooooooo057ooooo0_l0000Looooo`;o00002_ooool2o`00
01Kooooo0_l00002ooooo`;o00003?ooool2o`000004ooooool0003o0000o`0000;ooooo0_l00009
ooooo`;o00001Oooool4o`0000[ooooo0_l00008ooooo`;o00001Oooool2o`0000Sooooo0_l00003
ooooo`;o00001oooool2o`00057ooooo000Looooo`03o`000?oooooooooo06[ooooo0_l0000<oooo
o`;o000000?oooooo`000?l000004oooool5o`0000gooooo1?l00002ooooo`;o00000oooool2o`00
00;ooooo0ol00003ooooo`;o00001_ooool4o`0000;ooooo0_l00007ooooo`;o00001oooool2o`00
00Gooooo0ol00006ooooo`;o00001?ooool2o`0000Oooooo0_l0001Aooooo`007?ooool00ol0003o
ooooooooo`1Wooooo`;o000000?oooooo`000?l000003?ooool2o`0000Kooooo0_l0000;ooooo`;o
000000Coooooo`000?l0003o00001_ooool2o`0000Oooooo1?l00009ooooo`Ko00000_ooool2o`00
00;ooooo0_l00008ooooo`?o00001_ooool2o`0000[ooooo0_l00003ooooo`;o00001_ooool2o`00
063ooooo000Looooo`03o`000?oooooooooo067ooooo0_l00003ooooo`?o00002Oooool2o`0000Co
oooo1?l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00007ooooo`;o00001oooool2o`00
0003ooooool0003o000000;ooooo0ol0000?ooooo`;o00000_ooool2o`0000Kooooo1_l00002oooo
o`;o000000?oooooo`000?l000000_ooool2o`0000kooooo0_l0001]ooooo`007?ooool00ol0003o
ooooooooo`1Qooooo`;o00000oooool2o`0000Sooooo1?l00006ooooo`;o000000?oooooo`000?l0
00001Oooool2o`0000Cooooo0_l0000:ooooo`;o00001Oooool5o`0000gooooo0_l0000;ooooo`Ko
000000?oooooo`000?l000000ol00002ooooo`;o00000_ooool2o`0000oooooo0_l00003ooooo`;o
0000Hoooool001cooooo00?o0000ooooooooool0L?ooool2o`0000;ooooo0_l00007ooooo`;o0000
00?oooooo`000?l000002?ooool2o`0000Kooooo0_l000000ooooooo0000o`000005ooooo`;o0000
0_ooool2o`0001Cooooo0_l00004ooooo`Ko00000_ooool3o`0000Oooooo0_l000000ooooooo0000
o`000002o`0000Gooooo0_l00003ooooo`;o00000oooool2o`0006?ooooo000Looooo`03o`000?oo
oooooooo07?ooooo0ol00007ooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o0000
1oooool2o`000003ooooool0003o000000Gooooo0_l0000Hooooo`;o000000Coooooo`000?l0003o
oooo0_l00003ooooo`;o000000?oooooo`000?l000000_l00004ooooo`Co000000?oooooo`000?l0
00000ol00004ooooo`;o0000KOooool001cooooo00?o0000ooooooooool0Ioooool2o`0000[ooooo
0ol0000=ooooo`;o00001?ooool4o`0000Sooooo0_l00005ooooo`;o000000Coooooo`000?l0003o
00001Oooool3o`0000oooooo0_l000001?oooooo0000o`000?l00002ooooo`;o000000?oooooo`00
0?l000000_l00004ooooo`Ko00000_ooool2o`0000oooooo0_l0001Rooooo`007?ooool00ol0003o
ooooooooo`1Wooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo0ol000000ooooooo
0000o`00000@ooooo`Go00000_ooool2o`0000?ooooo0_l00005ooooo`;o000000Coooooo`000?l0
003o00001Oooool3o`0000Wooooo0_l00005ooooo`;o000000?oooooo`000?l000000_ooool4o`00
00Sooooo1Ol0000Cooooo`;o0000H_ooool001cooooo00?o0000ooooooooool0J_ooool4o`000003
ooooool0003o000000;ooooo0_l00002ooooo`;o00002?ooool2o`0000Wooooo0ol000001?oooooo
0000o`000?ooool4o`0000[ooooo0_l00005ooooo`;o00002Oooool2o`0000Gooooo1Ol00002oooo
o`Co00002?ooool2o`000003ooooool0003o000000[ooooo0_l0001[ooooo`007?ooool00ol0003o
ooooooooo`1Zooooo`;o00000_ooool2o`0000Oooooo1?l00003ooooo`;o000000?oooooo`000?l0
00002_ooool2o`0000?ooooo1?l0000;ooooo`;o00002_ooool4o`0000Sooooo1_l00006ooooo`;o
00005Oooool2o`0006_ooooo000Looooo`03o`000?oooooooooo06Oooooo0_l00005ooooo`;o0000
2Oooool2o`0000?ooooo1?l0000>ooooo`Ko00002?ooool2o`0000[ooooo0_l000000ooooooo0000
o`000002o`0000Cooooo0_l00002ooooo`;o00001oooool2o`000003ooooool0003o000000Oooooo
0_l0000:ooooo`;o0000KOooool001cooooo00?o0000ooooooooool0Hoooool2o`0000;ooooo0_l0
000Gooooo`;o00000_ooool2o`0000[ooooo0_l0000<ooooo`;o00001_ooool2o`0000;ooooo0_l0
00001?oooooo0000o`000?ooool2o`0000?ooooo0_l0000;ooooo`;o000000?oooooo`000?l00000
1oooool2o`000003ooooool0003o000000Oooooo0_l0001]ooooo`0000Koooooonk^k_lb<S;o0000
oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000oooo
ooooool0Hoooool2o`0000Sooooo0_l0000?ooooo`;o00001?ooool6o`0000[ooooo0_l0000@oooo
o`Co00000oooool2o`000003ooooool0003o000000Gooooo1?l0000Fooooo`;o0000M_ooool00006
oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q
8@06ooooo`03o`000?oooooooooo06gooooo0_l0000?ooooo`Co00001?ooool5o`0000Sooooo0ol0
00000ooooooo0000o`000003ooooo`;o00002Oooool3o`0000?ooooo0_l00005ooooo`;o000000?o
ooooo`000?l000000_l0000:ooooo`;o0000P_ooool00003ooooool@413ooooo00;ooooo00?o410@
ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0NOoo
ool3o`0000Cooooo0_l00007ooooo`;o00002?ooool2o`0000;ooooo0_l00003ooooo`;o00001Ooo
ool2o`0000Sooooo0_l00005ooooo`;o00003oooool2o`0008;ooooo00000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000I_oo
ool2o`0000Oooooo0ol00007ooooo`?o00000oooool2o`0000Sooooo0_l0000Hooooo`So00006?oo
ool2o`0008Cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Goc<c<
o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo06Kooooo0_l00007ooooo`Co00003?oo
ool2o`00023ooooo0_l00002ooooo`Ko00003_ooool2o`0000Sooooo0_l00006ooooo`Co0000N_oo
ool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol@413o^[Zjoooooonj
^[[o410@00Kooooo00?o0000ooooooooool0LOooool2o`0000oooooo0_l0000Jooooo`;o000000?o
ooooo`000?l000005_ooool2o`00013ooooo1?l00002ooooo`;o00001_ooool2o`0006kooooo0000
1_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03
o`000?oooooooooo08;ooooo0_l0000Jooooo`;o00001Oooool4o`0000Wooooo0ol00002ooooo`;o
00006?ooool2o`0000Kooooo0_l0001^ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;oooo
o`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`1jooooo`;o00000oooool4
o`0002;ooooo1?l00009ooooo`?o00000_ooool2o`0000Wooooo0_l00025ooooo`007?ooool00ol0
003oooooooooo`1jooooo`;o00000oooool4o`0003_ooooo0_l00002ooooo`;o0000QOooool001co
oooo00?o0000ooooooooool0__ooool2o`0000?ooooo0_l00024ooooo`007?ooool00ol0003ooooo
ooooo`1dooooo`;o00002Oooool2o`0002Oooooo0_l0000Iooooo`;o00003oooool2o`0007?ooooo
000Looooo`03o`000?oooooooooo07Cooooo0_l00009ooooo`;o00009oooool3o`0000Wooooo0_l0
000Gooooo`;o00000_ooool2o`000003ooooool0003o000007?ooooo000Looooo`03o`000?oooooo
oooo0:Wooooo0_l00009ooooo`;o00005Oooool4o`0000;ooooo0ol0001eooooo`007?ooool00ol0
003oooooooooo`2mooooo`;o00003?ooool2o`0000Gooooo0_l0001eooooo`007?ooool00ol0003o
ooooooooo`2mooooo`;o0000R_ooool001cooooo00?o0000ooooooooool0P_ooool2o`000<Gooooo
000Looooo`03o`000?oooooooooo07Cooooo0_l0000<ooooo`;o00001Oooool2o`000;kooooo000L
ooooo`03o`000?oooooooooo07Cooooo0_l0000Cooooo`;o00000_ooool2o`000;[ooooo000Loooo
o`03o`000?oooooooooo07Cooooo0_l0000Gooooo`?o0000:Oooool2o`0008kooooo000Looooo`;o
0000Moooool2o`0001Kooooo0_l0000Jooooo`;o00000_ooool2o`0000Gooooo0_l00002ooooo`;o
00002?ooool2o`0008Cooooo000Looooo`03o`000?oooooooooo07Kooooo0_l0000Eooooo`;o0000
6oooool2o`0000;ooooo0_l00005ooooo`;o00003?ooool2o`0008Cooooo000Looooo`03o`000?oo
oooooooo08gooooo0_l0002jooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo09Sooooo0_l000000ooooooo0000o`000003ooooo`;o0000Yoooool001co
oooo00?o0000ooooooooool0V?ooool2o`000003ooooool0003o000000?ooooo0_l00006ooooo`;o
0000Woooool001cooooo00?o0000ooooooooool0Z?ooool2o`0009oooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0XOooool2o`00
0:Kooooo000Looooo`03o`000?oooooooooo09;ooooo0_l0000=ooooo`;o0000Y_ooool001cooooo
0_l0002Cooooo`;o0000]Oooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0:Cooooo0_l0002Soooo
o`007?ooool00ol0003oooooooooo`2Tooooo`;o00001_ooool2o`0009_ooooo000Looooo`03o`00
0?oooooooooo0:cooooo0_l0002Kooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooo
oom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Booooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooood[ooooo
000Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool0
0ol0003oooooooooo`05ooooo`?o0000oooooom:ooooo`005?ooool00ol0003oooooooooo`3ooooo
oe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0
oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Booooo`03oeEEEOmVIVKo
00000?ooooooE?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Gooooo00Co
410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0Eooooo`05olc<c?lQ8B7o0000ob4Q8Oo<
c<`01Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^093ooooo002V
ooooo`05o`000?ooooooooooooooool000002Oooool6o`0000Wooooo00Go8B4QoiRHV?ooooooV9RH
ob4Q8@06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`2@ooooo`00
Y_ooool01Ol0003ooooooooooooooooo000001Sooooo00Go0000ooooooooooooooooo`000003oooo
o`Go00000oooool01Ol@413ooooooooooooooooo410@093ooooo002Vooooo`05o`000?oooooooooo
ooooool000002Oooool6o`0000Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P03ooooo`04odA4A?oM
gMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`00002@ooooo`00Y_ooool01Ol0003oQhN7
oooooonYZJWo000001Sooooo00Goc<c<o`000?l0003o0000olc<c003ooooo`04omgMgOmEEEGooooo
o`0000Cooooo00Go0000ooooooooooooooooo`00002@ooooo`00YOooool00ol@413o0000ogMgM`02
o`000003oiRHV?oooooooooo01Kooooo00Go410@okZj^_oooooo^[Zjoa0@4004ooooo`03ogMgMoo<
c<co000000Cooooo00Go410@oooooooooooooooooa0@402@ooooo`00`oooool01Ol0003o^[Zjoooo
oonj^[[o000000Cooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg093o
oooo0033ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01Oooool00omgMgOo0000ooooo`03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h0T?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(846) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.44592 .69084 Mdot
.42115 .68292 Mdot
.63433 .42602 Mdot
.35145 .42813 Mdot
.44373 .54771 Mdot
.6441 .45282 Mdot
.59528 .62113 Mdot
.61072 .59051 Mdot
.65277 .46837 Mdot
.27449 .4142 Mdot
.57417 .59292 Mdot
.31128 .48374 Mdot
.57952 .62302 Mdot
.35819 .45736 Mdot
.73078 .26077 Mdot
.32863 .41904 Mdot
.41088 .63655 Mdot
.59399 .32291 Mdot
.39642 .52385 Mdot
.68989 .43473 Mdot
.41027 .73135 Mdot
.35556 .46193 Mdot
.45164 .68431 Mdot
.35902 .4581 Mdot
.37563 .42104 Mdot
.43247 .65978 Mdot
.42136 .6225 Mdot
.40561 .43087 Mdot
.38222 .44168 Mdot
.57672 .58197 Mdot
.50542 .37556 Mdot
.59206 .18359 Mdot
.30944 .44042 Mdot
.21264 .64225 Mdot
.61021 .59743 Mdot
.32808 .26693 Mdot
.68064 .46752 Mdot
.55935 .62275 Mdot
.6088 .58895 Mdot
.60595 .63022 Mdot
.56282 .62261 Mdot
.42529 .66011 Mdot
.62274 .61293 Mdot
.63288 .61956 Mdot
.33255 .43958 Mdot
.57232 .72808 Mdot
.45258 .2359 Mdot
.40601 .46383 Mdot
.40822 .69086 Mdot
.69656 .44678 Mdot
.32437 .75318 Mdot
.61805 .60206 Mdot
.776 .54125 Mdot
.52826 .08651 Mdot
.57302 .63331 Mdot
.34042 .42895 Mdot
.66871 .45574 Mdot
.36885 .48294 Mdot
.36602 .46583 Mdot
.32439 .71376 Mdot
.40193 .43577 Mdot
.57928 .35227 Mdot
.42644 .72304 Mdot
.63374 .48582 Mdot
.64786 .45905 Mdot
.59555 .5799 Mdot
.40581 .64573 Mdot
.58568 .61633 Mdot
.4315 .44657 Mdot
.68449 .47422 Mdot
.40608 .4651 Mdot
.56759 .59662 Mdot
.4217 .71054 Mdot
.39151 .50295 Mdot
.59622 .75311 Mdot
.78676 .34029 Mdot
.58374 .30511 Mdot
.31276 .68238 Mdot
.36864 .63819 Mdot
.79804 .42494 Mdot
.37317 .45001 Mdot
.81098 .65757 Mdot
.74552 .27807 Mdot
.44664 .68605 Mdot
.40417 .54538 Mdot
.71309 .43311 Mdot
.36117 .49831 Mdot
.51168 .46588 Mdot
.41444 .41457 Mdot
.53445 .79601 Mdot
.65811 .47019 Mdot
.40909 .6608 Mdot
.35068 .43052 Mdot
.41812 .47379 Mdot
.28104 .59252 Mdot
.42377 .49225 Mdot
.3929 .41696 Mdot
.38695 .6522 Mdot
.5934 .5867 Mdot
.30818 .41732 Mdot
.62411 .56788 Mdot
.77262 .56369 Mdot
.33548 .4655 Mdot
.66188 .4815 Mdot
.38529 .67572 Mdot
.33633 .48252 Mdot
.59424 .63411 Mdot
.39634 .44925 Mdot
.62444 .62059 Mdot
.41636 .68634 Mdot
.41596 .48117 Mdot
.59632 .33451 Mdot
.64061 .76832 Mdot
.41153 .65194 Mdot
.77741 .64223 Mdot
.40625 .44881 Mdot
.35405 .4695 Mdot
.42085 .68007 Mdot
.65519 .43211 Mdot
.5171 .42444 Mdot
.39274 .67576 Mdot
.60881 .6197 Mdot
.45136 .63241 Mdot
.44426 .49766 Mdot
.63942 .4665 Mdot
.76378 .5617 Mdot
.75108 .54483 Mdot
.39999 .33608 Mdot
.34956 .49186 Mdot
.51301 .68321 Mdot
.64393 .44424 Mdot
.41222 .66506 Mdot
.58291 .61499 Mdot
.34397 .4156 Mdot
.43883 .63728 Mdot
.57588 .60079 Mdot
.59137 .3558 Mdot
.6 .27571 Mdot
.39986 .68872 Mdot
.52944 .57338 Mdot
.56231 .65427 Mdot
.6029 .63317 Mdot
.24509 .68848 Mdot
.42584 .68368 Mdot
.56234 .32777 Mdot
.58154 .60188 Mdot
.50067 .28575 Mdot
.36253 .41048 Mdot
.35072 .3497 Mdot
.68773 .78465 Mdot
.31608 .75374 Mdot
.69473 .66246 Mdot
.56532 .31365 Mdot
.59086 .64353 Mdot
.37266 .4314 Mdot
.43368 .68005 Mdot
.43042 .67101 Mdot
.41599 .43104 Mdot
.3793 .41745 Mdot
.40748 .47856 Mdot
.41837 .46427 Mdot
.50377 .23117 Mdot
.41266 .47416 Mdot
.60126 .43113 Mdot
.42161 .64405 Mdot
.38753 .42749 Mdot
.66099 .427 Mdot
.31566 .45439 Mdot
.56188 .61028 Mdot
.36255 .47185 Mdot
.36316 .41758 Mdot
.39772 .51209 Mdot
.56812 .63599 Mdot
.5455 .18827 Mdot
.67291 .78563 Mdot
.37192 .20968 Mdot
.7286 .65854 Mdot
.66622 .44292 Mdot
.34771 .48389 Mdot
.5677 .34079 Mdot
.27647 .49626 Mdot
.37448 .46034 Mdot
.3763 .80111 Mdot
.37604 .41371 Mdot
.19855 .55142 Mdot
.46222 .4444 Mdot
.3727 .20256 Mdot
.56466 .43748 Mdot
.3887 .44044 Mdot
.26237 .55125 Mdot
.22249 .43296 Mdot
.46398 .59082 Mdot
.56582 .62666 Mdot
.65491 .42796 Mdot
.6729 .46351 Mdot
.59829 .64713 Mdot
.33483 .39907 Mdot
.35312 .37681 Mdot
.2892 .4439 Mdot
.76152 .55511 Mdot
.42271 .71256 Mdot
.55642 .35806 Mdot
.41267 .70174 Mdot
.84492 .58287 Mdot
.50019 .79036 Mdot
.56449 .65894 Mdot
.55671 .3051 Mdot
.63631 .42788 Mdot
.7589 .5523 Mdot
.56674 .33303 Mdot
.39443 .4711 Mdot
.40447 .68423 Mdot
.19029 .50749 Mdot
.46294 .46595 Mdot
.17622 .46447 Mdot
.45491 .6438 Mdot
.53665 .45156 Mdot
.5712 .61052 Mdot
.68485 .42499 Mdot
.34502 .45868 Mdot
.39695 .48941 Mdot
.40383 .71972 Mdot
.40384 .46361 Mdot
.40505 .59076 Mdot
.35743 .4181 Mdot
.71206 .451 Mdot
.5983 .31695 Mdot
.60597 .63999 Mdot
.39664 .3395 Mdot
.44733 .69973 Mdot
.69239 .50882 Mdot
.69257 .44854 Mdot
.25929 .45867 Mdot
.57146 .59273 Mdot
.59568 .33826 Mdot
.68511 .43861 Mdot
.5471 .33853 Mdot
.34739 .4969 Mdot
.68197 .46857 Mdot
.55371 .33422 Mdot
.53567 .21645 Mdot
.33195 .43374 Mdot
.52024 .24966 Mdot
.59688 .61405 Mdot
.45643 .63617 Mdot
.40068 .43405 Mdot
.74736 .54767 Mdot
.34353 .50163 Mdot
.67616 .62314 Mdot
.76866 .53783 Mdot
.78308 .55076 Mdot
.78491 .38428 Mdot
.58745 .32226 Mdot
.65902 .70547 Mdot
.4829 .71761 Mdot
.40401 .64626 Mdot
.34276 .4335 Mdot
.449 .16637 Mdot
.5809 .60249 Mdot
.39123 .47006 Mdot
.71325 .43903 Mdot
.58434 .60305 Mdot
.3689 .48791 Mdot
.57817 .64118 Mdot
.43102 .67665 Mdot
.74515 .43329 Mdot
.42438 .62919 Mdot
.33626 .42814 Mdot
.59503 .6305 Mdot
.68339 .44602 Mdot
.43618 .66126 Mdot
.39379 .45203 Mdot
.3462 .4662 Mdot
.76809 .5528 Mdot
.38837 .43391 Mdot
.45873 .17073 Mdot
.41127 .44497 Mdot
.62431 .45649 Mdot
.42738 .47788 Mdot
.33023 .78634 Mdot
.6309 .31127 Mdot
.40211 .65405 Mdot
.77925 .54637 Mdot
.65613 .46466 Mdot
.73946 .37988 Mdot
.49927 .58122 Mdot
.38383 .44926 Mdot
.77776 .55197 Mdot
.53544 .41513 Mdot
.58768 .57592 Mdot
.42326 .50061 Mdot
.53842 .77805 Mdot
.68054 .43032 Mdot
.76147 .55257 Mdot
.39 .53162 Mdot
.38499 .6758 Mdot
.35303 .42646 Mdot
.68788 .45524 Mdot
.45058 .63108 Mdot
.32256 .46118 Mdot
.39122 .25792 Mdot
.75709 .53839 Mdot
.59557 .61494 Mdot
.41648 .39175 Mdot
.41025 .47242 Mdot
.67757 .45594 Mdot
.45675 .6734 Mdot
.60889 .60176 Mdot
.42722 .65288 Mdot
.20374 .46384 Mdot
.72199 .67293 Mdot
.4728 .22109 Mdot
.55636 .30388 Mdot
.6901 .58622 Mdot
.34688 .22122 Mdot
.67087 .71508 Mdot
.45285 .31276 Mdot
.22964 .31945 Mdot
.67246 .43088 Mdot
.58758 .28893 Mdot
.65923 .46006 Mdot
.36007 .43666 Mdot
.64479 .45679 Mdot
.3729 .19771 Mdot
.37441 .41278 Mdot
.66953 .44643 Mdot
.70635 .38566 Mdot
.39028 .42181 Mdot
.41382 .6476 Mdot
.70686 .25199 Mdot
.54999 .81513 Mdot
.42342 .77279 Mdot
.6634 .43649 Mdot
.35797 .72018 Mdot
.40202 .42805 Mdot
.31102 .45075 Mdot
.43827 .67763 Mdot
.42913 .48042 Mdot
.56199 .3613 Mdot
.54589 .34198 Mdot
.38433 .34904 Mdot
.75448 .69473 Mdot
.30994 .40997 Mdot
.43758 .6646 Mdot
.37574 .58826 Mdot
.59163 .75194 Mdot
.75605 .56633 Mdot
.55071 .59725 Mdot
.55786 .19531 Mdot
.34028 .38964 Mdot
.52342 .58225 Mdot
.55951 .77196 Mdot
.4058 .67559 Mdot
.49491 .19285 Mdot
.57162 .62984 Mdot
.29559 .55037 Mdot
.22376 .60583 Mdot
.3972 .48242 Mdot
.58141 .58547 Mdot
.30009 .44499 Mdot
.49851 .80621 Mdot
.52928 .27413 Mdot
.84144 .48906 Mdot
.33281 .43536 Mdot
.64688 .71367 Mdot
.35758 .46985 Mdot
.45645 .3737 Mdot
.41245 .44568 Mdot
.43317 .65175 Mdot
.28177 .47067 Mdot
.49909 .52357 Mdot
.73102 .73513 Mdot
.48518 .79254 Mdot
.56074 .31571 Mdot
.34832 .46592 Mdot
.39646 .4848 Mdot
.58494 .32567 Mdot
.44797 .66019 Mdot
.41327 .45022 Mdot
.3646 .30326 Mdot
.40498 .47808 Mdot
.5593 .61523 Mdot
.50778 .38844 Mdot
.37262 .6695 Mdot
.4123 .49593 Mdot
.41619 .6293 Mdot
.57414 .63759 Mdot
.6005 .5795 Mdot
.43991 .45625 Mdot
.58468 .6442 Mdot
.35177 .42517 Mdot
.51608 .35095 Mdot
.43755 .69078 Mdot
.46227 .49674 Mdot
.45033 .65736 Mdot
.35959 .68657 Mdot
.58663 .64044 Mdot
.75064 .55392 Mdot
.49531 .63832 Mdot
.57635 .62893 Mdot
.40492 .77067 Mdot
.2976 .41467 Mdot
.34845 .51061 Mdot
.47171 .80573 Mdot
.67033 .43563 Mdot
.75375 .55334 Mdot
.59926 .62822 Mdot
.40977 .47481 Mdot
.40304 .51602 Mdot
.55521 .61012 Mdot
.30845 .60317 Mdot
.73019 .36939 Mdot
.40297 .42569 Mdot
.43905 .65314 Mdot
.41361 .66221 Mdot
.32425 .47243 Mdot
.38704 .45616 Mdot
.62635 .44811 Mdot
.76817 .541 Mdot
.77374 .56791 Mdot
.75171 .54572 Mdot
.68567 .42042 Mdot
.60653 .68789 Mdot
.60494 .63148 Mdot
.53815 .6937 Mdot
.66513 .61232 Mdot
.45677 .45481 Mdot
.67935 .4514 Mdot
.38608 .49226 Mdot
.34661 .4438 Mdot
.60844 .60245 Mdot
.71491 .61798 Mdot
.41795 .53662 Mdot
.41903 .69714 Mdot
.58125 .64461 Mdot
.31574 .39451 Mdot
.59373 .67082 Mdot
.5593 .35468 Mdot
.42194 .77578 Mdot
.57482 .58819 Mdot
.40402 .66438 Mdot
.55228 .62235 Mdot
.40011 .48337 Mdot
.39675 .41265 Mdot
.41448 .67961 Mdot
.58372 .31712 Mdot
.42679 .5099 Mdot
.36685 .48796 Mdot
.45398 .86064 Mdot
.60081 .75068 Mdot
.5439 .58758 Mdot
.37827 .43642 Mdot
.39168 .52047 Mdot
.5571 .3137 Mdot
.40331 .47652 Mdot
.3433 .46382 Mdot
.64627 .77016 Mdot
.60673 .55647 Mdot
.60226 .3438 Mdot
.29668 .54815 Mdot
.45283 .64169 Mdot
.49627 .17329 Mdot
.77651 .56345 Mdot
.62128 .5825 Mdot
.74422 .44 Mdot
.75789 .54692 Mdot
.67644 .60132 Mdot
.49741 .18376 Mdot
.75193 .54809 Mdot
.72616 .48727 Mdot
.34032 .53263 Mdot
.40502 .42281 Mdot
.36128 .47595 Mdot
.56621 .34555 Mdot
.42781 .68258 Mdot
.55243 .44311 Mdot
.58638 .24592 Mdot
.3548 .46445 Mdot
.45478 .71215 Mdot
.55962 .2122 Mdot
.76493 .55037 Mdot
.58456 .35454 Mdot
.57006 .37033 Mdot
.35478 .4724 Mdot
.67594 .74081 Mdot
.43343 .66152 Mdot
.39327 .45207 Mdot
.40958 .49041 Mdot
.66724 .4378 Mdot
.4013 .67358 Mdot
.69263 .45184 Mdot
.76179 .53638 Mdot
.23183 .3616 Mdot
.41961 .84717 Mdot
.60505 .59979 Mdot
.40418 .20511 Mdot
.59931 .57466 Mdot
.81943 .43009 Mdot
.75706 .54239 Mdot
.375 .45593 Mdot
.4418 .70462 Mdot
.3981 .45005 Mdot
.3886 .47679 Mdot
.39471 .47291 Mdot
.29763 .42144 Mdot
.37083 .79888 Mdot
.57595 .33358 Mdot
.45461 .47851 Mdot
.63137 .46956 Mdot
.43712 .18495 Mdot
.70966 .26972 Mdot
.38575 .49715 Mdot
.35176 .47458 Mdot
.42277 .63938 Mdot
.42021 .43734 Mdot
.57151 .58244 Mdot
.45681 .67616 Mdot
.38975 .5155 Mdot
.48219 .19707 Mdot
.4142 .45382 Mdot
.34345 .22938 Mdot
.55227 .61972 Mdot
.41333 .7691 Mdot
.45273 .47467 Mdot
.75057 .5491 Mdot
.7534 .55275 Mdot
.77281 .57308 Mdot
.56055 .58955 Mdot
.67415 .45059 Mdot
.67723 .27031 Mdot
.32779 .40848 Mdot
.37145 .42849 Mdot
.39524 .52028 Mdot
.6519 .40981 Mdot
.50606 .45776 Mdot
.67816 .68193 Mdot
.31048 .39947 Mdot
.6295 .45172 Mdot
.46137 .6405 Mdot
.79688 .60737 Mdot
.45606 .67637 Mdot
.60259 .3413 Mdot
.56977 .59869 Mdot
.56322 .35919 Mdot
.36906 .76756 Mdot
.41852 .68507 Mdot
.39924 .71574 Mdot
.66805 .44396 Mdot
.54732 .4792 Mdot
.47353 .11081 Mdot
.67152 .48513 Mdot
.39488 .31465 Mdot
.44165 .67372 Mdot
.40423 .50319 Mdot
.53113 .40587 Mdot
.54191 .48004 Mdot
.66041 .44934 Mdot
.36506 .45136 Mdot
.72863 .71643 Mdot
.62699 .44438 Mdot
.42093 .50433 Mdot
.64331 .4387 Mdot
.56365 .61394 Mdot
.64498 .44091 Mdot
.4562 .68841 Mdot
.33806 .48158 Mdot
.51359 .09777 Mdot
.59693 .50507 Mdot
.40202 .43962 Mdot
.58101 .6445 Mdot
.33646 .30587 Mdot
.38278 .48155 Mdot
.5669 .36465 Mdot
.6359 .46385 Mdot
.7088 .34321 Mdot
.40364 .43143 Mdot
.65131 .44471 Mdot
.44786 .69195 Mdot
.60035 .56687 Mdot
.79106 .38165 Mdot
.76105 .56383 Mdot
.43532 .68424 Mdot
.79194 .55129 Mdot
.54747 .63317 Mdot
.40848 .51038 Mdot
.40982 .48536 Mdot
.42827 .64636 Mdot
.76511 .49112 Mdot
.42443 .45397 Mdot
.373 .45013 Mdot
.64503 .42192 Mdot
.62603 .42517 Mdot
.76315 .45815 Mdot
.67386 .4326 Mdot
.40728 .52046 Mdot
.42813 .64704 Mdot
.35012 .43857 Mdot
.41065 .64827 Mdot
.34413 .43277 Mdot
.47143 .63376 Mdot
.44536 .6855 Mdot
.74043 .67733 Mdot
.35546 .44476 Mdot
.444 .41282 Mdot
.39239 .47629 Mdot
.40557 .46934 Mdot
.64152 .47515 Mdot
.58429 .33356 Mdot
.40123 .40286 Mdot
.63811 .5055 Mdot
.58506 .35793 Mdot
.21252 .46378 Mdot
.66581 .43581 Mdot
.56561 .35143 Mdot
.52498 .24153 Mdot
.7817 .5506 Mdot
.57351 .34136 Mdot
.69794 .26127 Mdot
.6063 .60048 Mdot
.45979 .64561 Mdot
.38915 .42153 Mdot
.21675 .34989 Mdot
.50829 .35914 Mdot
.77282 .55073 Mdot
.40711 .4425 Mdot
.38442 .48966 Mdot
.3887 .66157 Mdot
.83524 .61224 Mdot
.63229 .42519 Mdot
.361 .43059 Mdot
.41835 .63318 Mdot
.71909 .76478 Mdot
.65085 .48034 Mdot
.57069 .34306 Mdot
.55568 .6189 Mdot
.40981 .61951 Mdot
.76146 .56464 Mdot
.58617 .57515 Mdot
.73154 .44045 Mdot
.38169 .77402 Mdot
.40858 .45094 Mdot
.68167 .45715 Mdot
.32098 .76013 Mdot
.32226 .40575 Mdot
.52712 .60336 Mdot
.34803 .36302 Mdot
.40547 .67184 Mdot
.55584 .61303 Mdot
.55001 .34182 Mdot
.4576 .6786 Mdot
.44637 .65978 Mdot
.61348 .59889 Mdot
.6528 .40146 Mdot
.53669 .45616 Mdot
.55998 .60699 Mdot
.54737 .79139 Mdot
.19597 .49429 Mdot
.77566 .54674 Mdot
.58999 .34564 Mdot
.18347 .5795 Mdot
.42552 .65927 Mdot
.55529 .19403 Mdot
.35352 .78085 Mdot
.39333 .41722 Mdot
.55704 .33893 Mdot
.64215 .65812 Mdot
.65732 .25783 Mdot
.58817 .60394 Mdot
.49519 .50123 Mdot
.5859 .3698 Mdot
.41144 .43409 Mdot
.40178 .74637 Mdot
.36273 .44351 Mdot
.56948 .60394 Mdot
.36666 .65912 Mdot
.4042 .66165 Mdot
.54939 .63754 Mdot
.41488 .77707 Mdot
.34498 .44592 Mdot
.36063 .44745 Mdot
.4751 .36083 Mdot
.40504 .68638 Mdot
.76973 .56822 Mdot
.39257 .44597 Mdot
.36677 .48119 Mdot
.40545 .50885 Mdot
.37666 .38166 Mdot
.65518 .74952 Mdot
.35945 .43235 Mdot
.70233 .44165 Mdot
.3213 .47938 Mdot
.35586 .4484 Mdot
.41067 .63434 Mdot
.41714 .83933 Mdot
.74913 .54207 Mdot
.36408 .47448 Mdot
.41166 .45331 Mdot
.61187 .60281 Mdot
.53889 .43311 Mdot
.54061 .48684 Mdot
.67404 .48064 Mdot
.4682 .29146 Mdot
.29713 .42385 Mdot
.44492 .63901 Mdot
.59679 .34725 Mdot
.37073 .50483 Mdot
.4337 .63499 Mdot
.31861 .43513 Mdot
.62856 .44475 Mdot
.77206 .54383 Mdot
.45821 .76367 Mdot
.5761 .34797 Mdot
.55659 .39565 Mdot
.53109 .71235 Mdot
.65457 .4267 Mdot
.37414 .42531 Mdot
.6144 .57752 Mdot
.68097 .47309 Mdot
.76995 .55416 Mdot
.41752 .52985 Mdot
.43311 .66988 Mdot
.41036 .65589 Mdot
.4099 .35142 Mdot
.6333 .49479 Mdot
.56589 .84116 Mdot
.56413 .61245 Mdot
.34245 .49651 Mdot
.49582 .70141 Mdot
.41048 .65443 Mdot
.40498 .34831 Mdot
.56675 .35263 Mdot
.59004 .60467 Mdot
.75663 .56962 Mdot
.43011 .63634 Mdot
.40129 .68713 Mdot
.32809 .44213 Mdot
.3684 .49623 Mdot
.44441 .31623 Mdot
.38468 .34799 Mdot
.56693 .63331 Mdot
.59008 .33367 Mdot
.69369 .4646 Mdot
.36435 .43822 Mdot
.44792 .68584 Mdot
.19918 .52736 Mdot
.415 .46306 Mdot
.62591 .44779 Mdot
.40773 .67355 Mdot
.58532 .32421 Mdot
.57516 .36401 Mdot
.4052 .46979 Mdot
.32293 .69987 Mdot
.58568 .63107 Mdot
.41099 .65127 Mdot
.44234 .73951 Mdot
.42622 .45915 Mdot
.36101 .49446 Mdot
.33184 .50997 Mdot
.59243 .57738 Mdot
.42627 .76379 Mdot
.599 .33637 Mdot
.42447 .66972 Mdot
.40176 .44317 Mdot
.5787 .35221 Mdot
.45918 .74146 Mdot
.76181 .54375 Mdot
.64191 .4419 Mdot
.56337 .36339 Mdot
.57128 .31981 Mdot
.58996 .35463 Mdot
.57104 .19607 Mdot
.41873 .71135 Mdot
.38385 .58118 Mdot
.41293 .44394 Mdot
.41921 .35378 Mdot
.38735 .40437 Mdot
.55588 .59753 Mdot
.67352 .43562 Mdot
.39065 .47993 Mdot
.32779 .44391 Mdot
.39537 .37398 Mdot
.40658 .39414 Mdot
.42154 .73167 Mdot
.41016 .68521 Mdot
.42472 .40549 Mdot
.67206 .43909 Mdot
.83546 .63605 Mdot
.42707 .14756 Mdot
.4491 .47281 Mdot
.54574 .45247 Mdot
.45155 .68259 Mdot
.61469 .60244 Mdot
.5332 .49722 Mdot
.55961 .63635 Mdot
.41958 .6685 Mdot
.36243 .4371 Mdot
.54323 .69602 Mdot
.55 .31913 Mdot
.40851 .47935 Mdot
.5745 .60775 Mdot
.40812 .47882 Mdot
.56401 .59035 Mdot
.45409 .60344 Mdot
.56566 .7768 Mdot
.37802 .41373 Mdot
.42392 .48251 Mdot
.4129 .3839 Mdot
.38257 .49675 Mdot
.80719 .52614 Mdot
.45191 .66872 Mdot
.74273 .70346 Mdot
.32318 .45743 Mdot
.33863 .67468 Mdot
.41674 .44578 Mdot
.74556 .50782 Mdot
.37275 .49999 Mdot
.52264 .52533 Mdot
.40377 .42361 Mdot
.34495 .47519 Mdot
.59126 .63359 Mdot
.61203 .60205 Mdot
.43516 .69682 Mdot
.76546 .56777 Mdot
.38412 .20141 Mdot
.36415 .49105 Mdot
.69965 .43264 Mdot
.5301 .58416 Mdot
.57774 .32203 Mdot
.4201 .66548 Mdot
.71949 .77305 Mdot
.57731 .64001 Mdot
.67218 .49148 Mdot
.77039 .5022 Mdot
.68672 .42831 Mdot
.61819 .56036 Mdot
.28105 .42038 Mdot
.57983 .31622 Mdot
.41461 .43892 Mdot
.21903 .64716 Mdot
.61562 .73197 Mdot
.4295 .51013 Mdot
.55569 .64068 Mdot
.29823 .52195 Mdot
.18678 .58257 Mdot
.55936 .36638 Mdot
.55301 .32648 Mdot
.58558 .63581 Mdot
.65737 .41884 Mdot
.29176 .44975 Mdot
.56614 .3534 Mdot
.64061 .43232 Mdot
.77832 .57033 Mdot
.48751 .57544 Mdot
.4303 .66187 Mdot
.42963 .77333 Mdot
.5381 .73969 Mdot
.56848 .63499 Mdot
.67477 .51003 Mdot
.43367 .61694 Mdot
.38717 .68681 Mdot
.75519 .56189 Mdot
.64097 .47528 Mdot
.44451 .70524 Mdot
.4206 .51113 Mdot
.45765 .43853 Mdot
.35823 .46816 Mdot
.56216 .33811 Mdot
.38664 .49993 Mdot
.63347 .46803 Mdot
.5854 .60672 Mdot
.66634 .47399 Mdot
.59364 .6278 Mdot
.58394 .69927 Mdot
.39319 .45749 Mdot
.34743 .47727 Mdot
.51776 .3715 Mdot
.41279 .69903 Mdot
.3464 .7578 Mdot
.69951 .43072 Mdot
.66539 .45822 Mdot
.34094 .4469 Mdot
.45305 .68835 Mdot
.60685 .33936 Mdot
.52539 .377 Mdot
.40241 .49819 Mdot
.45243 .66914 Mdot
.36555 .42945 Mdot
.52297 .22828 Mdot
.58892 .77551 Mdot
.42345 .65215 Mdot
.76784 .69209 Mdot
.37464 .44028 Mdot
.34924 .54136 Mdot
.39522 .52104 Mdot
.39347 .29308 Mdot
.42718 .46075 Mdot
.45626 .64565 Mdot
.36287 .46986 Mdot
.45783 .6672 Mdot
.65279 .42294 Mdot
.61264 .61914 Mdot
.4385 .68336 Mdot
.40262 .5011 Mdot
.56015 .17304 Mdot
.56785 .61006 Mdot
.34775 .46409 Mdot
.5906 .58935 Mdot
.43408 .63055 Mdot
.4118 .69373 Mdot
.70732 .27724 Mdot
.5698 .56588 Mdot
.56425 .61717 Mdot
.36109 .42522 Mdot
.50708 .75558 Mdot
.35317 .43711 Mdot
.43893 .32242 Mdot
.32958 .45654 Mdot
.4281 .47072 Mdot
.81424 .36965 Mdot
.60697 .57624 Mdot
.58202 .83233 Mdot
.57916 .24317 Mdot
.58489 .19568 Mdot
.39946 .62152 Mdot
.55972 .36674 Mdot
.50479 .19185 Mdot
.76657 .53728 Mdot
.6366 .45273 Mdot
.39182 .47993 Mdot
.40145 .60442 Mdot
.55793 .61968 Mdot
.58157 .33062 Mdot
.37551 .41353 Mdot
.62579 .45731 Mdot
.75414 .35703 Mdot
.58827 .6442 Mdot
.42463 .66062 Mdot
.41496 .69781 Mdot
.70329 .77171 Mdot
.40421 .44376 Mdot
.34829 .47093 Mdot
.57028 .59938 Mdot
.35261 .39274 Mdot
.59304 .33085 Mdot
.67198 .37326 Mdot
.56496 .61821 Mdot
.61053 .52946 Mdot
.41874 .68795 Mdot
.38573 .49075 Mdot
.50579 .44525 Mdot
.63154 .53748 Mdot
.24225 .4909 Mdot
.56623 .34242 Mdot
.45774 .3291 Mdot
.45583 .64491 Mdot
.58073 .6118 Mdot
.58362 .27604 Mdot
.34013 .49732 Mdot
.37953 .48812 Mdot
.46044 .33257 Mdot
.5407 .42497 Mdot
.60875 .36504 Mdot
.41675 .42819 Mdot
.53367 .42005 Mdot
.33854 .45158 Mdot
.39515 .51587 Mdot
.43521 .46553 Mdot
.35093 .49107 Mdot
.45307 .67302 Mdot
.37994 .37081 Mdot
.64564 .44526 Mdot
.28345 .58537 Mdot
.50237 .49905 Mdot
.39452 .43215 Mdot
.35875 .43825 Mdot
.25375 .48085 Mdot
.61635 .55268 Mdot
.44856 .67057 Mdot
.44578 .70876 Mdot
.59548 .63631 Mdot
.453 .42415 Mdot
.6538 .41331 Mdot
.36113 .36339 Mdot
.66272 .47476 Mdot
.45335 .66773 Mdot
.67171 .45894 Mdot
.60104 .63119 Mdot
.68194 .45781 Mdot
.68902 .42252 Mdot
.55641 .60455 Mdot
.42317 .69131 Mdot
.39745 .49883 Mdot
.58872 .6407 Mdot
.47209 .35769 Mdot
.56216 .34007 Mdot
.70706 .27658 Mdot
.31875 .47349 Mdot
.48542 .47199 Mdot
.39345 .25723 Mdot
.66784 .47165 Mdot
.6048 .77983 Mdot
.44452 .68576 Mdot
.56772 .30389 Mdot
.45447 .67308 Mdot
.36825 .78714 Mdot
.58692 .33379 Mdot
.6953 .25894 Mdot
.62267 .38758 Mdot
.72355 .33117 Mdot
.40899 .41867 Mdot
.47938 .64128 Mdot
.68736 .46554 Mdot
.5589 .62267 Mdot
.66292 .3988 Mdot
.34123 .47692 Mdot
.67995 .70718 Mdot
.39197 .68664 Mdot
.78154 .56349 Mdot
.58422 .61742 Mdot
.56233 .64645 Mdot
.40503 .4503 Mdot
.74853 .40993 Mdot
.33382 .47366 Mdot
.61559 .33153 Mdot
.4611 .30968 Mdot
.35324 .36364 Mdot
.34887 .4267 Mdot
.66868 .47836 Mdot
.36563 .42853 Mdot
.30699 .52424 Mdot
.23881 .68068 Mdot
.35843 .52298 Mdot
.73327 .67067 Mdot
.54724 .37829 Mdot
.41781 .68159 Mdot
.45206 .46467 Mdot
.77277 .5602 Mdot
.37669 .43827 Mdot
.1382 .54527 Mdot
.57606 .34201 Mdot
.71599 .48638 Mdot
.42189 .45603 Mdot
.39642 .44713 Mdot
.25964 .67996 Mdot
.41186 .59811 Mdot
.75425 .56876 Mdot
.3753 .4845 Mdot
.48433 .29436 Mdot
.59929 .58421 Mdot
.32979 .47545 Mdot
.35906 .47426 Mdot
.21845 .43558 Mdot
.58812 .57954 Mdot
.67143 .46923 Mdot
.77293 .54025 Mdot
.69541 .46287 Mdot
.58658 .37514 Mdot
.54342 .50474 Mdot
.36174 .34707 Mdot
.58838 .77313 Mdot
.57745 .36862 Mdot
.41453 .48111 Mdot
.41345 .54083 Mdot
.38133 .44484 Mdot
.55057 .33153 Mdot
.5787 .58178 Mdot
.44731 .67855 Mdot
.47002 .76046 Mdot
.76299 .55463 Mdot
.41952 .50547 Mdot
.55039 .35105 Mdot
.43422 .6767 Mdot
.66152 .51804 Mdot
.42219 .67647 Mdot
.57233 .62595 Mdot
.54887 .60885 Mdot
.58524 .34476 Mdot
.45521 .67041 Mdot
.70073 .46126 Mdot
.58538 .24807 Mdot
.33214 .4486 Mdot
.5373 .63052 Mdot
.44473 .69791 Mdot
.41314 .62697 Mdot
.39789 .69436 Mdot
.4005 .46021 Mdot
.54145 .44236 Mdot
.38873 .5175 Mdot
.58128 .63731 Mdot
.63794 .44018 Mdot
.33588 .35372 Mdot
.26633 .69436 Mdot
.60565 .52011 Mdot
.41055 .41114 Mdot
.34766 .4564 Mdot
.3547 .47215 Mdot
.34875 .41634 Mdot
.59955 .2832 Mdot
.38925 .45701 Mdot
.593 .63099 Mdot
.64902 .47421 Mdot
.4045 .43786 Mdot
.77525 .56078 Mdot
.52871 .45328 Mdot
.59482 .35521 Mdot
.51806 .50979 Mdot
.50169 .163 Mdot
.43562 .67716 Mdot
.68671 .44321 Mdot
.6384 .45253 Mdot
.59172 .35531 Mdot
.56237 .62704 Mdot
.42603 .67971 Mdot
.40521 .28207 Mdot
.59198 .34606 Mdot
.36507 .47386 Mdot
.72788 .42642 Mdot
.78272 .65179 Mdot
.41965 .4422 Mdot
.38168 .47216 Mdot
.77972 .54597 Mdot
.65648 .41645 Mdot
.18114 .38745 Mdot
.54531 .4103 Mdot
.58499 .33868 Mdot
.56256 .31932 Mdot
.39935 .69788 Mdot
.44154 .49669 Mdot
.59292 .62522 Mdot
.52431 .3959 Mdot
.33211 .32083 Mdot
.58565 .40735 Mdot
.81487 .42642 Mdot
.41104 .46601 Mdot
.26019 .67057 Mdot
.34758 .43367 Mdot
.38646 .66927 Mdot
.40342 .64898 Mdot
.44397 .66788 Mdot
.57805 .63401 Mdot
.35873 .66956 Mdot
.59758 .62607 Mdot
.47239 .15039 Mdot
.46194 .66305 Mdot
.65083 .29859 Mdot
.6711 .45296 Mdot
.37196 .39833 Mdot
.58643 .32322 Mdot
.63076 .56943 Mdot
.43293 .4502 Mdot
.66716 .73965 Mdot
.67942 .45224 Mdot
.41445 .69147 Mdot
.28063 .43778 Mdot
.3042 .24128 Mdot
.55462 .48768 Mdot
.41274 .56439 Mdot
.3363 .74567 Mdot
.58643 .3289 Mdot
.24739 .49953 Mdot
.58306 .31468 Mdot
.57967 .60106 Mdot
.34283 .48142 Mdot
.35388 .49488 Mdot
.34529 .42995 Mdot
.3905 .45849 Mdot
.60884 .6068 Mdot
.3284 .43099 Mdot
.33034 .78636 Mdot
.77633 .54542 Mdot
.52329 .21731 Mdot
.56303 .35539 Mdot
.55135 .62921 Mdot
.65388 .47453 Mdot
.77195 .56977 Mdot
.37915 .34092 Mdot
.40129 .42252 Mdot
.3913 .47769 Mdot
.74936 .55791 Mdot
.43243 .4564 Mdot
.3053 .40559 Mdot
.64617 .44687 Mdot
.59399 .51299 Mdot
.55902 .36282 Mdot
.56248 .35845 Mdot
.56665 .59304 Mdot
.45513 .67176 Mdot
.56697 .34949 Mdot
.64635 .42065 Mdot
.32372 .43444 Mdot
.39389 .50885 Mdot
.44364 .69836 Mdot
.3539 .78133 Mdot
.55916 .36794 Mdot
.28094 .44445 Mdot
.45785 .65408 Mdot
.40258 .70584 Mdot
.37865 .48516 Mdot
.34576 .51824 Mdot
.43292 .62139 Mdot
.57578 .36569 Mdot
.55207 .63174 Mdot
.68661 .29693 Mdot
.57344 .60275 Mdot
.42974 .67997 Mdot
.3212 .46523 Mdot
.42129 .69015 Mdot
.38322 .43764 Mdot
.87355 .40876 Mdot
.36376 .49864 Mdot
.52716 .81675 Mdot
.40321 .29909 Mdot
.63911 .45658 Mdot
.70058 .4594 Mdot
.778 .55488 Mdot
.4583 .65277 Mdot
.36599 .50352 Mdot
.5684 .31495 Mdot
.61426 .21495 Mdot
.46828 .63271 Mdot
.63131 .44581 Mdot
.65745 .41425 Mdot
.58352 .57741 Mdot
.41827 .45196 Mdot
.38331 .49277 Mdot
.6812 .46036 Mdot
.42207 .24174 Mdot
.44211 .63983 Mdot
.34866 .46942 Mdot
.35024 .45237 Mdot
.6422 .45325 Mdot
.58435 .24954 Mdot
.46451 .61419 Mdot
.34601 .48413 Mdot
.54578 .36622 Mdot
.55946 .59194 Mdot
.34956 .41763 Mdot
.32984 .42894 Mdot
.56204 .32414 Mdot
.473 .20596 Mdot
.19544 .61978 Mdot
.55291 .60724 Mdot
.7698 .56782 Mdot
.4084 .49986 Mdot
.66961 .45168 Mdot
.40044 .50414 Mdot
.33503 .25414 Mdot
.78153 .5533 Mdot
.38084 .45561 Mdot
.44584 .47336 Mdot
.39908 .66588 Mdot
.38869 .45289 Mdot
.23428 .43577 Mdot
.68328 .47877 Mdot
.38443 .45478 Mdot
.33215 .71862 Mdot
.59385 .5795 Mdot
.44852 .46798 Mdot
.55323 .34726 Mdot
.38733 .29317 Mdot
.53505 .72207 Mdot
.65106 .40864 Mdot
.56756 .35984 Mdot
.39924 .49964 Mdot
.66195 .41975 Mdot
.55967 .62862 Mdot
.66485 .72346 Mdot
.38941 .41269 Mdot
.56903 .60591 Mdot
.58554 .60858 Mdot
.58111 .34716 Mdot
.6164 .82053 Mdot
.40288 .40075 Mdot
.38543 .4977 Mdot
.23142 .40539 Mdot
.39246 .67144 Mdot
.39313 .49836 Mdot
.41586 .47043 Mdot
.59911 .61398 Mdot
.4958 .64327 Mdot
.32552 .54819 Mdot
.70553 .3858 Mdot
.56307 .59068 Mdot
.62411 .41046 Mdot
.6635 .42027 Mdot
.56311 .35441 Mdot
.41347 .67644 Mdot
.59229 .36578 Mdot
.65836 .43739 Mdot
.41234 .45201 Mdot
.59668 .60561 Mdot
.22583 .53134 Mdot
.61763 .59781 Mdot
.62788 .47677 Mdot
.3952 .643 Mdot
.49783 .70815 Mdot
.17971 .63436 Mdot
.55155 .7329 Mdot
.62282 .61323 Mdot
.57709 .3218 Mdot
.68455 .40126 Mdot
.34944 .45435 Mdot
.26902 .52959 Mdot
.40389 .48932 Mdot
.33166 .7352 Mdot
.66553 .43053 Mdot
.75503 .56277 Mdot
.34331 .48296 Mdot
.46462 .31833 Mdot
.58818 .64984 Mdot
.58433 .5765 Mdot
.38596 .46479 Mdot
.5753 .62894 Mdot
.37036 .49488 Mdot
.64909 .47677 Mdot
.56612 .82779 Mdot
.34754 .45995 Mdot
.37578 .52106 Mdot
.57653 .55784 Mdot
.70456 .27245 Mdot
.70515 .4571 Mdot
.259 .67165 Mdot
.27181 .27041 Mdot
.57734 .62866 Mdot
.43029 .51484 Mdot
.6854 .4633 Mdot
.78036 .54658 Mdot
.69721 .47935 Mdot
.40274 .48533 Mdot
.40299 .47404 Mdot
.34125 .44565 Mdot
.36103 .44685 Mdot
.26593 .52314 Mdot
.3637 .38379 Mdot
.26406 .65641 Mdot
.38957 .47619 Mdot
.40978 .74532 Mdot
.60201 .62175 Mdot
.41729 .73033 Mdot
.54731 .35869 Mdot
.41077 .46317 Mdot
.3941 .606 Mdot
.55112 .61365 Mdot
.46966 .15106 Mdot
.58541 .57805 Mdot
.65484 .46523 Mdot
.61234 .58842 Mdot
.38783 .4352 Mdot
.41352 .66123 Mdot
.67213 .48392 Mdot
.65929 .68921 Mdot
.63553 .45299 Mdot
.40249 .43979 Mdot
.5934 .26584 Mdot
.63917 .44986 Mdot
.52462 .46942 Mdot
.41072 .66576 Mdot
.49 .29674 Mdot
.40697 .6431 Mdot
.3817 .45288 Mdot
.37771 .45204 Mdot
.78366 .567 Mdot
.60193 .63753 Mdot
.43871 .6303 Mdot
.46352 .86274 Mdot
.59851 .3662 Mdot
.44059 .66126 Mdot
.3228 .41455 Mdot
.54424 .43535 Mdot
.41921 .64882 Mdot
.45081 .27753 Mdot
.56163 .62753 Mdot
.42699 .71121 Mdot
.31065 .43389 Mdot
.52383 .57509 Mdot
.55569 .31009 Mdot
.62741 .46779 Mdot
.54978 .53854 Mdot
.68873 .46524 Mdot
.54868 .61935 Mdot
.6217 .46745 Mdot
.60277 .58699 Mdot
.39558 .76033 Mdot
.40052 .58987 Mdot
.61996 .60191 Mdot
.54667 .62481 Mdot
.66224 .44313 Mdot
.37736 .41211 Mdot
.48594 .5295 Mdot
.42145 .43372 Mdot
.39428 .41001 Mdot
.60121 .58366 Mdot
.43856 .63307 Mdot
.46297 .65211 Mdot
.48033 .67311 Mdot
.40975 .69686 Mdot
.65737 .47699 Mdot
.58466 .78338 Mdot
.36558 .76634 Mdot
.57477 .59087 Mdot
.54172 .62423 Mdot
.35468 .43716 Mdot
.66779 .44836 Mdot
.65671 .42445 Mdot
.59411 .61735 Mdot
.24549 .53487 Mdot
.37775 .51842 Mdot
.39875 .64402 Mdot
.46153 .66702 Mdot
.42635 .64889 Mdot
.40405 .69873 Mdot
.3513 .58706 Mdot
.55917 .62424 Mdot
.46044 .65798 Mdot
.38273 .46097 Mdot
.40326 .47746 Mdot
.75766 .55808 Mdot
.55755 .35477 Mdot
.31724 .43349 Mdot
.36519 .52395 Mdot
.38084 .48615 Mdot
.64093 .44332 Mdot
.44186 .52316 Mdot
.77858 .56313 Mdot
.625 .43654 Mdot
.65921 .41191 Mdot
.75102 .55367 Mdot
.4653 .70953 Mdot
.28489 .24861 Mdot
.36127 .43063 Mdot
.44264 .53825 Mdot
.66496 .45258 Mdot
.614 .79449 Mdot
.4385 .7571 Mdot
.34866 .42539 Mdot
.50312 .57189 Mdot
.66344 .48411 Mdot
.39102 .67778 Mdot
.39873 .4947 Mdot
.75387 .54319 Mdot
.59558 .35163 Mdot
.31964 .4161 Mdot
.77338 .53993 Mdot
.45444 .66351 Mdot
.57973 .28858 Mdot
.41355 .70884 Mdot
.66135 .48513 Mdot
.44602 .4691 Mdot
.4771 .10769 Mdot
.69193 .44816 Mdot
.61467 .22371 Mdot
.42367 .59282 Mdot
.34493 .46394 Mdot
.69238 .45351 Mdot
.39023 .67079 Mdot
.55718 .5936 Mdot
.52606 .41682 Mdot
.43926 .68889 Mdot
.76617 .56871 Mdot
.75558 .55216 Mdot
.64408 .44806 Mdot
.4066 .68195 Mdot
.32625 .47127 Mdot
.40498 .65205 Mdot
.60993 .58316 Mdot
.36493 .41742 Mdot
.36808 .2029 Mdot
.45073 .4278 Mdot
.45251 .64265 Mdot
.62464 .4506 Mdot
.55764 .31193 Mdot
.38971 .41722 Mdot
.58292 .22728 Mdot
.41815 .45938 Mdot
.58958 .58429 Mdot
.7013 .74361 Mdot
.22387 .5073 Mdot
.41156 .44083 Mdot
.35524 .43807 Mdot
.55552 .60714 Mdot
.39763 .42026 Mdot
.42016 .44743 Mdot
.53492 .58878 Mdot
.40117 .66348 Mdot
.35885 .46524 Mdot
.64324 .42734 Mdot
.2594 .69618 Mdot
.41136 .49868 Mdot
.74001 .65111 Mdot
.48106 .30786 Mdot
.67624 .76763 Mdot
.39089 .50377 Mdot
.46727 .36454 Mdot
.36752 .45413 Mdot
.40597 .46085 Mdot
.35694 .42782 Mdot
.24151 .64472 Mdot
.66396 .44148 Mdot
.62978 .46091 Mdot
.55491 .30987 Mdot
.47984 .30482 Mdot
.55713 .33542 Mdot
.56508 .59141 Mdot
.78462 .39266 Mdot
.77928 .54994 Mdot
.45585 .67122 Mdot
.34113 .48934 Mdot
.66937 .48701 Mdot
.38942 .49025 Mdot
.38352 .43486 Mdot
.65522 .48182 Mdot
.68379 .43183 Mdot
.69631 .50154 Mdot
.58728 .32022 Mdot
.44358 .67612 Mdot
.33071 .43574 Mdot
.58496 .35778 Mdot
.3276 .47709 Mdot
.54363 .41741 Mdot
.44579 .67368 Mdot
.40281 .65499 Mdot
.43202 .62697 Mdot
.41273 .45243 Mdot
.39106 .4312 Mdot
.59869 .62418 Mdot
.45161 .69363 Mdot
.56533 .5975 Mdot
.68329 .4718 Mdot
.69294 .47543 Mdot
.40288 .4848 Mdot
.2772 .45561 Mdot
.56711 .31792 Mdot
.65922 .46817 Mdot
.74868 .55859 Mdot
.56674 .30613 Mdot
.4074 .444 Mdot
.67068 .47758 Mdot
.56217 .35941 Mdot
.25534 .57385 Mdot
.24776 .29439 Mdot
.55512 .31637 Mdot
.38384 .46417 Mdot
.26692 .68986 Mdot
.56015 .26577 Mdot
.60087 .35918 Mdot
.58408 .59094 Mdot
.41659 .46337 Mdot
.31421 .30257 Mdot
.57854 .37085 Mdot
.3349 .75303 Mdot
.63982 .45931 Mdot
.4947 .61778 Mdot
.30547 .44853 Mdot
.28032 .54981 Mdot
.59539 .36475 Mdot
.4255 .67472 Mdot
.46923 .66841 Mdot
.37252 .46863 Mdot
.54194 .3524 Mdot
.59052 .5739 Mdot
.63906 .46476 Mdot
.70139 .43666 Mdot
.40388 .67805 Mdot
.52331 .76581 Mdot
.6347 .4339 Mdot
.28419 .46261 Mdot
.74276 .43179 Mdot
.46681 .46502 Mdot
.37935 .74095 Mdot
.64255 .69163 Mdot
.39563 .51112 Mdot
.55753 .31674 Mdot
.55714 .635 Mdot
.59045 .63145 Mdot
.56857 .62238 Mdot
.70049 .45171 Mdot
.53015 .49934 Mdot
.68082 .44913 Mdot
.66257 .71565 Mdot
.57822 .35238 Mdot
.5004 .27582 Mdot
.3642 .50195 Mdot
.34788 .4577 Mdot
.32839 .48581 Mdot
.33466 .46881 Mdot
.36417 .45533 Mdot
.56415 .6276 Mdot
.69551 .43656 Mdot
.70682 .34508 Mdot
.43894 .65152 Mdot
.71654 .50925 Mdot
.67135 .45322 Mdot
.77973 .54673 Mdot
.57693 .33178 Mdot
.46069 .3751 Mdot
.62166 .43006 Mdot
.67057 .45924 Mdot
.32646 .4267 Mdot
.42247 .63796 Mdot
.30196 .39959 Mdot
.37222 .45025 Mdot
.66213 .4697 Mdot
.61724 .3975 Mdot
.24956 .45411 Mdot
.34572 .524 Mdot
.59732 .31247 Mdot
.54422 .44114 Mdot
.59729 .32917 Mdot
.32614 .49785 Mdot
.6206 .79235 Mdot
.65783 .43815 Mdot
.65001 .46021 Mdot
.55021 .34836 Mdot
.3387 .5352 Mdot
.40817 .67738 Mdot
.75495 .56319 Mdot
.59516 .59135 Mdot
.38095 .44667 Mdot
.69773 .46088 Mdot
.38747 .5619 Mdot
.73766 .39058 Mdot
.56659 .61657 Mdot
.62599 .4349 Mdot
.41647 .44893 Mdot
.3838 .46632 Mdot
.58425 .32563 Mdot
.45396 .53669 Mdot
.34663 .40296 Mdot
.58382 .19516 Mdot
.5655 .77527 Mdot
.51032 .7911 Mdot
.37951 .48834 Mdot
.40202 .6779 Mdot
.75673 .54332 Mdot
.59058 .34379 Mdot
.3228 .44993 Mdot
.25513 .28469 Mdot
.45731 .63361 Mdot
.57749 .60697 Mdot
.75269 .54604 Mdot
.52934 .49747 Mdot
.41779 .46328 Mdot
.40349 .4898 Mdot
.39582 .45936 Mdot
.21702 .31339 Mdot
.63207 .44136 Mdot
.39852 .69294 Mdot
.56559 .33904 Mdot
.40239 .69429 Mdot
.63164 .45777 Mdot
.48246 .75492 Mdot
.40255 .43249 Mdot
.39633 .64531 Mdot
.42292 .67294 Mdot
.58186 .57795 Mdot
.56415 .58369 Mdot
.69799 .50195 Mdot
.36158 .49746 Mdot
.75518 .5413 Mdot
.40445 .64629 Mdot
.67863 .42439 Mdot
.58704 .33279 Mdot
.58945 .63923 Mdot
.39021 .47512 Mdot
.6503 .4406 Mdot
.43012 .50512 Mdot
.41922 .64523 Mdot
.67023 .45846 Mdot
.74965 .53879 Mdot
.55638 .32558 Mdot
.39804 .47524 Mdot
.60832 .33549 Mdot
.74973 .55541 Mdot
.34909 .45073 Mdot
.35902 .35755 Mdot
.59243 .38548 Mdot
.66938 .68499 Mdot
.6846 .44682 Mdot
.76713 .56206 Mdot
.39967 .65592 Mdot
.49421 .6815 Mdot
.64864 .46377 Mdot
.42233 .36361 Mdot
.45588 .54839 Mdot
.33296 .43198 Mdot
.42503 .65607 Mdot
.65842 .3939 Mdot
.53426 .1818 Mdot
.5392 .25039 Mdot
.35095 .46728 Mdot
.69214 .45619 Mdot
.5673 .36278 Mdot
.57607 .58935 Mdot
.74146 .65198 Mdot
.37954 .60058 Mdot
.62015 .46126 Mdot
.35714 .43119 Mdot
.40596 .64519 Mdot
.59277 .6173 Mdot
.5546 .69499 Mdot
.63812 .42312 Mdot
.6704 .43194 Mdot
.40811 .43978 Mdot
.57039 .35311 Mdot
.47243 .23173 Mdot
.63036 .46508 Mdot
.69698 .45777 Mdot
.73595 .49883 Mdot
.54825 .34663 Mdot
.37583 .46335 Mdot
.48089 .67087 Mdot
.35723 .41113 Mdot
.61803 .22212 Mdot
.77673 .56268 Mdot
.44001 .65048 Mdot
.40744 .47719 Mdot
.72971 .40505 Mdot
.65459 .47184 Mdot
.54538 .45519 Mdot
.62738 .48161 Mdot
.5643 .62985 Mdot
.69743 .46291 Mdot
.39423 .49448 Mdot
.58846 .6501 Mdot
.56514 .31929 Mdot
.34733 .48646 Mdot
.38985 .43001 Mdot
.3885 .67294 Mdot
.58039 .59977 Mdot
.19043 .55203 Mdot
.54645 .63463 Mdot
.55205 .6213 Mdot
.46387 .69067 Mdot
.36861 .47113 Mdot
.65827 .46332 Mdot
.63112 .47683 Mdot
.32421 .45207 Mdot
.58718 .79663 Mdot
.40589 .67596 Mdot
.70155 .5013 Mdot
.18815 .37983 Mdot
.29145 .46098 Mdot
.74586 .54535 Mdot
.45795 .52589 Mdot
.57087 .58175 Mdot
.38761 .47008 Mdot
.45268 .64485 Mdot
.69627 .44761 Mdot
.63588 .43296 Mdot
.32263 .46786 Mdot
.5899 .61055 Mdot
.58741 .3651 Mdot
.6707 .42961 Mdot
.74474 .4063 Mdot
.39441 .45374 Mdot
.68569 .70286 Mdot
.67914 .43482 Mdot
.63948 .21128 Mdot
.71866 .36289 Mdot
.42748 .65319 Mdot
.38236 .43285 Mdot
.42362 .69715 Mdot
.56446 .33307 Mdot
.65184 .4062 Mdot
.5874 .60733 Mdot
.35682 .53186 Mdot
.22588 .68009 Mdot
.66785 .44339 Mdot
.45271 .67261 Mdot
.41235 .44188 Mdot
.30065 .48333 Mdot
.38284 .49944 Mdot
.49284 .65992 Mdot
.61114 .38125 Mdot
.59916 .58183 Mdot
.58875 .58547 Mdot
.34722 .44384 Mdot
.59349 .33753 Mdot
.64263 .47932 Mdot
.64067 .46514 Mdot
.86186 .59769 Mdot
.74862 .53864 Mdot
.43374 .31337 Mdot
.40122 .4734 Mdot
.67562 .4215 Mdot
.25978 .68808 Mdot
.56997 .59943 Mdot
.33299 .46792 Mdot
.68119 .42126 Mdot
.63384 .54625 Mdot
.54211 .41955 Mdot
.36877 .45933 Mdot
.30279 .41805 Mdot
.59287 .58949 Mdot
.52783 .38594 Mdot
.68119 .45259 Mdot
.33085 .46052 Mdot
.54792 .63852 Mdot
.75958 .45728 Mdot
.30314 .75043 Mdot
.44364 .67559 Mdot
.62861 .48012 Mdot
.56337 .62712 Mdot
.34058 .40294 Mdot
.56353 .35656 Mdot
.68504 .47461 Mdot
.63679 .44617 Mdot
.36977 .42042 Mdot
.33921 .41376 Mdot
.29206 .46298 Mdot
.44896 .66059 Mdot
.60536 .60724 Mdot
.34043 .48006 Mdot
.52928 .76673 Mdot
.33953 .44752 Mdot
.60312 .61266 Mdot
.62563 .13156 Mdot
.37393 .40917 Mdot
.38038 .49853 Mdot
.49434 .23409 Mdot
.43625 .69137 Mdot
.4041 .69443 Mdot
.57116 .77903 Mdot
.40091 .47361 Mdot
.73567 .35495 Mdot
.44137 .67885 Mdot
.40582 .67111 Mdot
.64548 .30721 Mdot
.35806 .41903 Mdot
.53919 .38699 Mdot
.59479 .62264 Mdot
.57805 .64156 Mdot
.4035 .65699 Mdot
.34813 .40161 Mdot
.55526 .62081 Mdot
.29223 .53766 Mdot
.67379 .45048 Mdot
.62412 .79115 Mdot
.42659 .64091 Mdot
.48555 .50309 Mdot
.56659 .60625 Mdot
.47759 .14936 Mdot
.51979 .56229 Mdot
.34297 .43932 Mdot
.39617 .46976 Mdot
.55859 .32612 Mdot
.43319 .44045 Mdot
.7735 .56808 Mdot
.57423 .62896 Mdot
.43809 .21849 Mdot
.44336 .66692 Mdot
.3666 .49809 Mdot
.44821 .36869 Mdot
.56323 .70579 Mdot
.72964 .67727 Mdot
.41821 .68084 Mdot
.42953 .6593 Mdot
.67371 .44016 Mdot
.65414 .4326 Mdot
.36706 .46507 Mdot
.58503 .63474 Mdot
.44789 .69984 Mdot
.60142 .59613 Mdot
.65673 .43727 Mdot
.6657 .45987 Mdot
.78221 .55484 Mdot
.43034 .48908 Mdot
.65033 .4797 Mdot
.76173 .43087 Mdot
.51563 .76882 Mdot
.38949 .68974 Mdot
.17212 .59625 Mdot
.55515 .69338 Mdot
.3975 .26491 Mdot
.59437 .32656 Mdot
.76569 .57688 Mdot
.61242 .61068 Mdot
.35323 .43987 Mdot
.39177 .48359 Mdot
.765 .54997 Mdot
.61358 .62298 Mdot
.577 .3274 Mdot
.60713 .6329 Mdot
.57844 .35534 Mdot
.69797 .47433 Mdot
.41027 .49921 Mdot
.41319 .48022 Mdot
.56496 .62682 Mdot
.6737 .46748 Mdot
.64251 .47297 Mdot
.58824 .31792 Mdot
.48151 .38053 Mdot
.64464 .44615 Mdot
.4244 .6416 Mdot
.34769 .63727 Mdot
.75672 .55103 Mdot
.39699 .49606 Mdot
.41094 .35066 Mdot
.24677 .51335 Mdot
.3328 .43763 Mdot
.75076 .54774 Mdot
.82338 .65201 Mdot
.36518 .50113 Mdot
.7677 .71509 Mdot
.76489 .56244 Mdot
.43592 .69236 Mdot
.68984 .44951 Mdot
.77539 .56856 Mdot
.30732 .42889 Mdot
.60304 .34007 Mdot
.315 .45797 Mdot
.43525 .68987 Mdot
.41999 .62844 Mdot
.48551 .80435 Mdot
.61938 .22372 Mdot
.57714 .31214 Mdot
.58237 .33865 Mdot
.64683 .46249 Mdot
.8018 .36584 Mdot
.31171 .43419 Mdot
.58341 .33458 Mdot
.42567 .22909 Mdot
.35978 .4354 Mdot
.43726 .32728 Mdot
.50372 .56811 Mdot
.40244 .67696 Mdot
.4456 .72682 Mdot
.65 .46864 Mdot
.45185 .67359 Mdot
.48935 .77793 Mdot
.3274 .48448 Mdot
.44583 .67106 Mdot
.60239 .61032 Mdot
.67899 .60262 Mdot
.41727 .69477 Mdot
.51885 .40182 Mdot
.59158 .62602 Mdot
.61646 .38367 Mdot
.46567 .24594 Mdot
.13225 .57655 Mdot
.57529 .63078 Mdot
.67836 .47135 Mdot
.66022 .48456 Mdot
.6416 .46317 Mdot
.44174 .68843 Mdot
.65318 .42233 Mdot
.44767 .65238 Mdot
.60056 .25021 Mdot
.4568 .36709 Mdot
.58534 .34642 Mdot
.56355 .56891 Mdot
.42462 .66543 Mdot
.62452 .75083 Mdot
.18293 .63417 Mdot
.38698 .46383 Mdot
.5471 .63639 Mdot
.55012 .34657 Mdot
.75365 .27686 Mdot
.56032 .3256 Mdot
.68604 .46164 Mdot
.63261 .78723 Mdot
.36573 .49408 Mdot
.252 .41217 Mdot
.55991 .31992 Mdot
.42333 .685 Mdot
.34826 .45311 Mdot
.64948 .49913 Mdot
.56336 .35263 Mdot
.59331 .35699 Mdot
.3578 .45695 Mdot
.41065 .69032 Mdot
.66276 .46257 Mdot
.60947 .61815 Mdot
.58686 .38126 Mdot
.35013 .39678 Mdot
.34399 .4187 Mdot
.37191 .5127 Mdot
.54501 .48226 Mdot
.35122 .26842 Mdot
.57891 .62861 Mdot
.52582 .28052 Mdot
.64811 .43537 Mdot
.63949 .37151 Mdot
.58692 .75141 Mdot
.58418 .56261 Mdot
.77527 .56351 Mdot
.78008 .55882 Mdot
.36562 .45858 Mdot
.3609 .26184 Mdot
.74631 .69364 Mdot
.59439 .55384 Mdot
.75697 .54798 Mdot
.64026 .46796 Mdot
.46936 .66221 Mdot
.45432 .7948 Mdot
.36549 .40595 Mdot
.58056 .57555 Mdot
.64538 .44263 Mdot
.33021 .25773 Mdot
.57493 .34901 Mdot
.61675 .78361 Mdot
.40227 .43537 Mdot
.34781 .47699 Mdot
.58281 .62155 Mdot
.59732 .62573 Mdot
.72111 .66886 Mdot
.51981 .79586 Mdot
.58486 .4273 Mdot
.52833 .65939 Mdot
.29965 .28385 Mdot
.42203 .73029 Mdot
.44824 .6394 Mdot
.76485 .53647 Mdot
.565 .64528 Mdot
.40355 .4925 Mdot
.45527 .68286 Mdot
.72914 .67936 Mdot
.43443 .61199 Mdot
.44903 .3246 Mdot
.74178 .37451 Mdot
.39265 .43931 Mdot
.41606 .64055 Mdot
.44983 .67454 Mdot
.41819 .70698 Mdot
.75086 .55151 Mdot
.37558 .48595 Mdot
.38227 .41313 Mdot
.34051 .47131 Mdot
.34499 .39091 Mdot
.39139 .45273 Mdot
.57249 .75108 Mdot
.61125 .52849 Mdot
.45157 .21145 Mdot
.33568 .43686 Mdot
.57255 .6406 Mdot
.35236 .50097 Mdot
.59406 .34244 Mdot
.35541 .43156 Mdot
.43558 .3199 Mdot
.5728 .61455 Mdot
.33774 .53322 Mdot
.52458 .65979 Mdot
.4008 .43306 Mdot
.57483 .36806 Mdot
.37577 .25936 Mdot
.18646 .56413 Mdot
.72235 .50516 Mdot
.42221 .64228 Mdot
.62473 .4279 Mdot
.60684 .57886 Mdot
.65689 .46137 Mdot
.33641 .44429 Mdot
.75561 .53876 Mdot
.63643 .67478 Mdot
.48652 .50572 Mdot
.40902 .48259 Mdot
.45065 .50082 Mdot
.40886 .65649 Mdot
.6732 .47586 Mdot
.37919 .69242 Mdot
.40195 .46241 Mdot
.56435 .34194 Mdot
.5697 .35609 Mdot
.52821 .78443 Mdot
.36888 .21581 Mdot
.47225 .71867 Mdot
.58198 .62366 Mdot
.62662 .44688 Mdot
.59294 .36702 Mdot
.39009 .58899 Mdot
.5829 .57308 Mdot
.57265 .58107 Mdot
.58758 .60136 Mdot
.38573 .44291 Mdot
.77551 .56588 Mdot
.39478 .22877 Mdot
.76905 .56912 Mdot
.39733 .43056 Mdot
.63507 .4425 Mdot
.77998 .56714 Mdot
.55525 .33468 Mdot
.56806 .59123 Mdot
.66013 .43493 Mdot
.38324 .45127 Mdot
.43754 .67551 Mdot
.49127 .38839 Mdot
.36865 .30934 Mdot
.55791 .22413 Mdot
.55092 .22161 Mdot
.4484 .63296 Mdot
.44641 .16927 Mdot
.53708 .62805 Mdot
.24625 .53381 Mdot
.54914 .29305 Mdot
.32454 .45889 Mdot
.50191 .83047 Mdot
.68247 .45389 Mdot
.66262 .48157 Mdot
.37322 .45894 Mdot
.68588 .43175 Mdot
.37323 .4996 Mdot
.66367 .43171 Mdot
.72295 .49938 Mdot
.37743 .40409 Mdot
.65917 .47973 Mdot
.31309 .47526 Mdot
.38625 .41655 Mdot
.40139 .66818 Mdot
.69122 .46704 Mdot
.3379 .44801 Mdot
.80356 .34666 Mdot
.59395 .6339 Mdot
.75163 .55229 Mdot
.58313 .47198 Mdot
.56001 .62239 Mdot
.43896 .65774 Mdot
.40387 .41258 Mdot
.57651 .31815 Mdot
.42863 .674 Mdot
.7004 .50076 Mdot
.55614 .32243 Mdot
.58581 .78222 Mdot
.417 .64438 Mdot
.7588 .55199 Mdot
.56631 .31745 Mdot
.44804 .50165 Mdot
.68372 .48078 Mdot
.32353 .32843 Mdot
.76269 .56658 Mdot
.38432 .49327 Mdot
.70734 .44752 Mdot
.58108 .64393 Mdot
.35704 .474 Mdot
.693 .44956 Mdot
.74988 .552 Mdot
.37741 .44142 Mdot
.35609 .44556 Mdot
.42066 .7777 Mdot
.70437 .71631 Mdot
.58467 .3276 Mdot
.3955 .65582 Mdot
.38252 .46031 Mdot
.58964 .32265 Mdot
.79687 .45608 Mdot
.39038 .51389 Mdot
.43585 .69566 Mdot
.38474 .36522 Mdot
.64971 .43247 Mdot
.56514 .59713 Mdot
.63075 .4812 Mdot
.59649 .34811 Mdot
.50563 .87015 Mdot
.78307 .56063 Mdot
.31271 .48155 Mdot
.33004 .47904 Mdot
.65339 .39931 Mdot
.45052 .67026 Mdot
.57952 .41895 Mdot
.39786 .47476 Mdot
.44855 .42341 Mdot
.35109 .487 Mdot
.71611 .35553 Mdot
.40688 .6758 Mdot
.38458 .49724 Mdot
.2773 .4438 Mdot
.41922 .48943 Mdot
.58123 .36852 Mdot
.49713 .26101 Mdot
.37642 .51157 Mdot
.41444 .11481 Mdot
.74822 .55559 Mdot
.65257 .48021 Mdot
.60556 .45381 Mdot
.84467 .47172 Mdot
.39225 .75958 Mdot
.44903 .65645 Mdot
.46111 .41666 Mdot
.65987 .46218 Mdot
.29946 .73612 Mdot
.48209 .16162 Mdot
.38812 .41809 Mdot
.41589 .45524 Mdot
.68604 .46166 Mdot
.68111 .42546 Mdot
.76557 .53836 Mdot
.33944 .43593 Mdot
.42655 .52664 Mdot
.62651 .43641 Mdot
.39558 .44711 Mdot
.32593 .37558 Mdot
.60958 .61331 Mdot
.39795 .67548 Mdot
.57479 .58972 Mdot
.59048 .5768 Mdot
.32005 .59292 Mdot
.56384 .7755 Mdot
.60286 .61556 Mdot
.55959 .65422 Mdot
.42423 .32229 Mdot
.43487 .37645 Mdot
.59148 .36436 Mdot
.46693 .18943 Mdot
.64355 .45829 Mdot
.3741 .48443 Mdot
.45309 .63948 Mdot
.28764 .56289 Mdot
.6903 .5428 Mdot
.6646 .76757 Mdot
.40603 .46655 Mdot
.64861 .47067 Mdot
.75235 .55774 Mdot
.37013 .40407 Mdot
.62899 .34953 Mdot
.34842 .4723 Mdot
.67032 .48668 Mdot
.35547 .64499 Mdot
.31675 .3714 Mdot
.71737 .42023 Mdot
.42819 .71382 Mdot
.34735 .49205 Mdot
.43506 .64304 Mdot
.56462 .61071 Mdot
.59208 .32994 Mdot
.58106 .32479 Mdot
.35147 .45171 Mdot
.3963 .59038 Mdot
.49689 .57205 Mdot
.39254 .4194 Mdot
.36554 .41942 Mdot
.76652 .5625 Mdot
.36511 .41891 Mdot
.32916 .47663 Mdot
.33675 .46997 Mdot
.41264 .50505 Mdot
.55248 .62362 Mdot
.32795 .36476 Mdot
.41938 .51054 Mdot
.31011 .48872 Mdot
.60418 .62463 Mdot
.47262 .45846 Mdot
.58957 .57868 Mdot
.36503 .20537 Mdot
.59339 .58352 Mdot
.58472 .33107 Mdot
.70533 .43693 Mdot
.44901 .41693 Mdot
.44797 .7014 Mdot
.55322 .60059 Mdot
.57137 .33657 Mdot
.57083 .62599 Mdot
.63358 .43803 Mdot
.1776 .48906 Mdot
.43343 .61182 Mdot
.53473 .40242 Mdot
.51045 .59346 Mdot
.69075 .69884 Mdot
.67348 .44407 Mdot
.40359 .6722 Mdot
.24502 .42149 Mdot
.33824 .4599 Mdot
.55936 .32326 Mdot
.36254 .45915 Mdot
.55218 .61477 Mdot
.64518 .46725 Mdot
.56618 .24036 Mdot
.57984 .32176 Mdot
.30362 .76221 Mdot
.63716 .46093 Mdot
.39224 .41306 Mdot
.57343 .57869 Mdot
.17315 .60112 Mdot
.59014 .58186 Mdot
.44677 .36319 Mdot
.38788 .65166 Mdot
.36975 .74759 Mdot
.42281 .6596 Mdot
.75243 .65828 Mdot
.22915 .28375 Mdot
.54835 .19823 Mdot
.43318 .6827 Mdot
.73673 .4335 Mdot
.4038 .44357 Mdot
.36481 .5083 Mdot
.28813 .46621 Mdot
.39067 .68405 Mdot
.38676 .45807 Mdot
.76281 .56478 Mdot
.49328 .75839 Mdot
.65454 .36705 Mdot
.62245 .43293 Mdot
.39004 .49926 Mdot
.60497 .62158 Mdot
.60661 .63447 Mdot
.77693 .56887 Mdot
.60289 .57989 Mdot
.37012 .41333 Mdot
.42345 .66339 Mdot
.47268 .53404 Mdot
.5608 .33168 Mdot
.72533 .27639 Mdot
.55537 .3671 Mdot
.6246 .48628 Mdot
.44613 .47239 Mdot
.66666 .45985 Mdot
.64048 .83992 Mdot
.34205 .44684 Mdot
.44282 .68039 Mdot
.36386 .4446 Mdot
.34056 .48443 Mdot
.36317 .50798 Mdot
.63864 .42433 Mdot
.60288 .41799 Mdot
.39181 .44727 Mdot
.58676 .60597 Mdot
.50419 .20856 Mdot
.31934 .47399 Mdot
.72719 .47144 Mdot
.4702 .30018 Mdot
.65678 .72071 Mdot
.39277 .69855 Mdot
.67386 .47389 Mdot
.43917 .66386 Mdot
.45089 .70441 Mdot
.43913 .6577 Mdot
.40112 .22131 Mdot
.2712 .49384 Mdot
.8235 .64268 Mdot
.34872 .73209 Mdot
.27047 .5689 Mdot
.40754 .63595 Mdot
.80437 .4957 Mdot
.45719 .65395 Mdot
.44593 .65745 Mdot
.83915 .33109 Mdot
.45999 .66142 Mdot
.40106 .48542 Mdot
.33655 .41802 Mdot
.54955 .7258 Mdot
.41916 .331 Mdot
.35142 .43066 Mdot
.37843 .46007 Mdot
.58835 .32335 Mdot
.29365 .50911 Mdot
.77664 .54013 Mdot
.58009 .79125 Mdot
.59272 .68342 Mdot
.35936 .45662 Mdot
.38119 .45724 Mdot
.38623 .39696 Mdot
.19386 .31362 Mdot
.30565 .56161 Mdot
.43277 .62485 Mdot
.45531 .49463 Mdot
.65756 .23125 Mdot
.40541 .42311 Mdot
.4142 .48019 Mdot
.38356 .43771 Mdot
.6589 .46306 Mdot
.46705 .64652 Mdot
.45582 .49158 Mdot
.6425 .71573 Mdot
.40632 .4402 Mdot
.55431 .57905 Mdot
.60144 .38089 Mdot
.39485 .49328 Mdot
.41126 .70273 Mdot
.3655 .43069 Mdot
.42291 .63978 Mdot
.40085 .6621 Mdot
.39523 .39777 Mdot
.3819 .2263 Mdot
.42597 .70025 Mdot
.39388 .4314 Mdot
.67026 .46967 Mdot
.54484 .1885 Mdot
.38735 .49297 Mdot
.58882 .35098 Mdot
.39739 .4717 Mdot
.57418 .3669 Mdot
.38153 .41938 Mdot
.7651 .56817 Mdot
.22547 .49032 Mdot
.64903 .45914 Mdot
.52271 .32703 Mdot
.6654 .4186 Mdot
.42511 .77728 Mdot
.44008 .69249 Mdot
.76085 .53386 Mdot
.62603 .80797 Mdot
.76419 .56094 Mdot
.4918 .39307 Mdot
.71577 .52126 Mdot
.57922 .63722 Mdot
.39794 .68913 Mdot
.51482 .30336 Mdot
.73321 .45838 Mdot
.66232 .50584 Mdot
.65567 .41165 Mdot
.52 .85652 Mdot
.58079 .82531 Mdot
.38393 .44748 Mdot
.2621 .35938 Mdot
.26387 .64808 Mdot
.40379 .50463 Mdot
.41427 .42259 Mdot
.68155 .48454 Mdot
.36092 .50031 Mdot
.5287 .47802 Mdot
.6632 .44336 Mdot
.57627 .33753 Mdot
.44063 .64941 Mdot
.57311 .3653 Mdot
.68935 .48905 Mdot
.60337 .52455 Mdot
.65391 .43513 Mdot
.40451 .51158 Mdot
.36773 .44826 Mdot
.40754 .64711 Mdot
.38961 .6159 Mdot
.39881 .67081 Mdot
.54984 .33373 Mdot
.65459 .44558 Mdot
.28921 .55115 Mdot
.38299 .47116 Mdot
.42074 .67187 Mdot
.62889 .62916 Mdot
.38453 .46668 Mdot
.56341 .62062 Mdot
.41191 .44739 Mdot
.43291 .68589 Mdot
.36595 .41859 Mdot
.42512 .66241 Mdot
.68023 .45974 Mdot
.4103 .43041 Mdot
.37255 .46071 Mdot
.2006 .6373 Mdot
.57515 .32629 Mdot
.43935 .69239 Mdot
.53708 .52826 Mdot
.38127 .41097 Mdot
.62937 .38692 Mdot
.39226 .50292 Mdot
.43936 .38807 Mdot
.31707 .48411 Mdot
.76024 .56215 Mdot
.42505 .51283 Mdot
.38663 .4937 Mdot
.27737 .38916 Mdot
.30595 .69643 Mdot
.37767 .69015 Mdot
.55369 .60543 Mdot
.40859 .70068 Mdot
.69311 .4744 Mdot
.69739 .4439 Mdot
.66802 .42614 Mdot
.42782 .34206 Mdot
.37073 .39813 Mdot
.36771 .49396 Mdot
.55134 .60056 Mdot
.58189 .34223 Mdot
.41999 .67993 Mdot
.58113 .34746 Mdot
.57188 .79113 Mdot
.5505 .33439 Mdot
.7757 .56761 Mdot
.71944 .36486 Mdot
.25424 .506 Mdot
.58576 .32094 Mdot
.39847 .67289 Mdot
.73878 .37896 Mdot
.32609 .45956 Mdot
.67587 .5146 Mdot
.5648 .34389 Mdot
.47778 .86348 Mdot
.39847 .50186 Mdot
.53199 .4326 Mdot
.6077 .59404 Mdot
.55939 .35289 Mdot
.57667 .59978 Mdot
.34933 .43869 Mdot
.67647 .68162 Mdot
.45362 .67336 Mdot
.57061 .64929 Mdot
.41612 .51593 Mdot
.56688 .36147 Mdot
.64135 .44583 Mdot
.52316 .58663 Mdot
.57318 .64025 Mdot
.20728 .46069 Mdot
.54047 .25077 Mdot
.6568 .44491 Mdot
.7782 .66203 Mdot
.58844 .59606 Mdot
.39786 .50938 Mdot
.41732 .39489 Mdot
.348 .42713 Mdot
.70173 .45211 Mdot
.67001 .47717 Mdot
.51628 .74879 Mdot
.36734 .44537 Mdot
.39608 .50234 Mdot
.44089 .61915 Mdot
.66927 .44711 Mdot
.41489 .65615 Mdot
.41504 .70739 Mdot
.68042 .46857 Mdot
.42508 .65329 Mdot
.55744 .32262 Mdot
.48717 .7356 Mdot
.58976 .59603 Mdot
.58333 .60745 Mdot
.6405 .46733 Mdot
.63095 .46927 Mdot
.66831 .45828 Mdot
.41172 .44709 Mdot
.41355 .68141 Mdot
.37944 .42953 Mdot
.38999 .51494 Mdot
.38424 .69162 Mdot
.46215 .66728 Mdot
.37232 .43378 Mdot
.6586 .39466 Mdot
.59595 .37723 Mdot
.65756 .47834 Mdot
.60284 .59717 Mdot
.30136 .7341 Mdot
.56111 .5848 Mdot
.38915 .50057 Mdot
.63625 .54289 Mdot
.4277 .68815 Mdot
.55853 .32703 Mdot
.58882 .38652 Mdot
.56727 .31999 Mdot
.62131 .57326 Mdot
.43586 .70587 Mdot
.58545 .78108 Mdot
.38053 .50064 Mdot
.544 .48424 Mdot
.51982 .28998 Mdot
.59688 .74774 Mdot
.60382 .60972 Mdot
.38233 .4627 Mdot
.76196 .55889 Mdot
.24846 .46201 Mdot
.34982 .47589 Mdot
.3337 .45759 Mdot
.67745 .30651 Mdot
.30918 .48787 Mdot
.38775 .67974 Mdot
.4921 .80474 Mdot
.3259 .43059 Mdot
.48699 .64597 Mdot
.87217 .51504 Mdot
.38068 .50334 Mdot
.39876 .45749 Mdot
.38418 .4845 Mdot
.35985 .43793 Mdot
.38427 .66865 Mdot
.50517 .37068 Mdot
.57054 .58074 Mdot
.56365 .49459 Mdot
.59524 .60291 Mdot
.67828 .48204 Mdot
.52942 .43769 Mdot
.39742 .68492 Mdot
.56119 .32305 Mdot
.22119 .41212 Mdot
.54152 .80194 Mdot
.67444 .44131 Mdot
.33787 .57741 Mdot
.56203 .3348 Mdot
.32443 .45452 Mdot
.54668 .32342 Mdot
.67936 .42356 Mdot
.59329 .61474 Mdot
.33843 .41741 Mdot
.43807 .63114 Mdot
.41829 .69529 Mdot
.38701 .46225 Mdot
.61505 .21618 Mdot
.56146 .61359 Mdot
.63363 .57366 Mdot
.38811 .44174 Mdot
.33376 .45621 Mdot
.42072 .64901 Mdot
.66009 .47437 Mdot
.77039 .48193 Mdot
.57402 .33045 Mdot
.42865 .45357 Mdot
.35852 .43452 Mdot
.55297 .7891 Mdot
.56516 .59202 Mdot
.76529 .54126 Mdot
.38144 .44339 Mdot
.55714 .77683 Mdot
.3794 .44297 Mdot
.43231 .43509 Mdot
.66803 .46463 Mdot
.32598 .48757 Mdot
.41327 .45991 Mdot
.43533 .53961 Mdot
.58273 .59511 Mdot
.44648 .67537 Mdot
.4126 .62295 Mdot
.75352 .54336 Mdot
.56446 .62143 Mdot
.3695 .43293 Mdot
.55851 .60386 Mdot
.3703 .51055 Mdot
.39062 .44943 Mdot
.60345 .61 Mdot
.41541 .65572 Mdot
.63055 .65912 Mdot
.4183 .36036 Mdot
.3622 .44016 Mdot
.34186 .41947 Mdot
.43125 .33814 Mdot
.70193 .76566 Mdot
.40678 .47242 Mdot
.42953 .69069 Mdot
.37941 .46647 Mdot
.57107 .60639 Mdot
.55059 .34306 Mdot
.43641 .68002 Mdot
.63494 .46835 Mdot
.68253 .45833 Mdot
.52054 .65925 Mdot
.77998 .56517 Mdot
.34993 .41442 Mdot
.38007 .70979 Mdot
.46009 .64939 Mdot
.83483 .39857 Mdot
.66172 .48421 Mdot
.57907 .37019 Mdot
.35357 .44499 Mdot
.53173 .56873 Mdot
.55707 .59246 Mdot
.41109 .11505 Mdot
.58931 .77444 Mdot
.54468 .31726 Mdot
.65561 .77807 Mdot
.76281 .55417 Mdot
.41263 .47613 Mdot
.59378 .3345 Mdot
.68326 .44404 Mdot
.34201 .49267 Mdot
.29956 .42957 Mdot
.57669 .42288 Mdot
.62172 .41418 Mdot
.5608 .60156 Mdot
.65655 .42823 Mdot
.572 .30403 Mdot
.77476 .56787 Mdot
.40614 .69162 Mdot
.38191 .49529 Mdot
.43167 .41344 Mdot
.64814 .47587 Mdot
.76423 .56833 Mdot
.39271 .43877 Mdot
.41694 .69716 Mdot
.68191 .43019 Mdot
.35488 .45731 Mdot
.25387 .54194 Mdot
.43781 .71373 Mdot
.64694 .44795 Mdot
.33162 .47949 Mdot
.41469 .38013 Mdot
.63699 .46716 Mdot
.64657 .47803 Mdot
.38627 .45792 Mdot
.562 .31954 Mdot
.41835 .45187 Mdot
.59989 .585 Mdot
.60254 .41894 Mdot
.5729 .60759 Mdot
.56654 .27444 Mdot
.44326 .47708 Mdot
.70231 .69612 Mdot
.40203 .649 Mdot
.58678 .3083 Mdot
.20809 .61286 Mdot
.33227 .4509 Mdot
.42377 .1857 Mdot
.49009 .49424 Mdot
.73657 .27183 Mdot
.22079 .32492 Mdot
.56902 .34653 Mdot
.56851 .62297 Mdot
.39808 .45793 Mdot
.54109 .62032 Mdot
.58968 .33045 Mdot
.53621 .27516 Mdot
.33067 .47626 Mdot
.40637 .67277 Mdot
.40393 .43957 Mdot
.42313 .64172 Mdot
.38659 .46833 Mdot
.33257 .51004 Mdot
.56607 .29044 Mdot
.44284 .36138 Mdot
.32546 .45696 Mdot
.17595 .48768 Mdot
.5414 .54885 Mdot
.56547 .33624 Mdot
.38655 .42996 Mdot
.77222 .54972 Mdot
.61604 .6161 Mdot
.33038 .29209 Mdot
.66241 .46119 Mdot
.60482 .61489 Mdot
.43113 .64932 Mdot
.63765 .48089 Mdot
.74832 .551 Mdot
.42232 .40344 Mdot
.58147 .36599 Mdot
.57667 .63581 Mdot
.39031 .49393 Mdot
.39991 .5003 Mdot
.72349 .41467 Mdot
.72953 .60428 Mdot
.46301 .63561 Mdot
.26196 .72327 Mdot
.38532 .68089 Mdot
.58134 .33191 Mdot
.66845 .46283 Mdot
.40652 .47842 Mdot
.35375 .46931 Mdot
.69925 .45364 Mdot
.44135 .69054 Mdot
.61246 .42807 Mdot
.3311 .58937 Mdot
.62228 .45851 Mdot
.48326 .32757 Mdot
.43952 .68361 Mdot
.48327 .33345 Mdot
.57317 .30385 Mdot
.35241 .23572 Mdot
.40445 .28562 Mdot
.60837 .59458 Mdot
.4847 .32162 Mdot
.42506 .68444 Mdot
.37579 .4491 Mdot
.7603 .5507 Mdot
.78185 .55673 Mdot
.43314 .64598 Mdot
.68691 .46185 Mdot
.56213 .35425 Mdot
.39878 .45472 Mdot
.64054 .75478 Mdot
.53611 .69998 Mdot
.62589 .44984 Mdot
.29712 .41068 Mdot
.58132 .60066 Mdot
.41065 .45841 Mdot
.58602 .3561 Mdot
.58313 .632 Mdot
.74125 .55356 Mdot
.49589 .74997 Mdot
.34916 .44795 Mdot
.51611 .79112 Mdot
.56657 .62725 Mdot
.78455 .66031 Mdot
.36414 .46462 Mdot
.58809 .59594 Mdot
.38349 .53488 Mdot
.64131 .69638 Mdot
.50406 .52969 Mdot
.49161 .16803 Mdot
.63462 .41121 Mdot
.68485 .45707 Mdot
.68479 .62387 Mdot
.55752 .29114 Mdot
.59798 .63261 Mdot
.77369 .56829 Mdot
.45698 .25903 Mdot
.57892 .5982 Mdot
.41772 .47099 Mdot
.39063 .50296 Mdot
.31294 .58663 Mdot
.52434 .50723 Mdot
.76674 .57006 Mdot
.45201 .73971 Mdot
.35196 .42066 Mdot
.35145 .51596 Mdot
.36062 .47428 Mdot
.42152 .62791 Mdot
.56007 .62537 Mdot
.16211 .5734 Mdot
.56268 .60828 Mdot
.6447 .75955 Mdot
.64354 .45922 Mdot
.62424 .45827 Mdot
.39531 .49459 Mdot
.73138 .68755 Mdot
.32414 .28827 Mdot
.38798 .41456 Mdot
.62617 .379 Mdot
.53146 .25176 Mdot
.36185 .52343 Mdot
.39378 .63749 Mdot
.43607 .42228 Mdot
.4174 .72655 Mdot
.59192 .62923 Mdot
.57144 .35134 Mdot
.59377 .37703 Mdot
.58123 .63542 Mdot
.36762 .49274 Mdot
.61861 .35353 Mdot
.34919 .48275 Mdot
.38163 .44595 Mdot
.61124 .78938 Mdot
.58726 .37138 Mdot
.67108 .4564 Mdot
.5803 .32336 Mdot
.44696 .65929 Mdot
.71204 .18442 Mdot
.58165 .35174 Mdot
.37438 .70668 Mdot
.51764 .36533 Mdot
.48564 .32544 Mdot
.41466 .69564 Mdot
.56399 .31106 Mdot
.56278 .60169 Mdot
.72872 .26039 Mdot
.7472 .71482 Mdot
.55632 .58776 Mdot
.35947 .46454 Mdot
.39547 .6763 Mdot
.43925 .62783 Mdot
.54931 .64294 Mdot
.40324 .68168 Mdot
.43701 .50872 Mdot
.36945 .44323 Mdot
.5976 .63293 Mdot
.53951 .72109 Mdot
.56901 .63912 Mdot
.47696 .75118 Mdot
.38993 .43368 Mdot
.43935 .68054 Mdot
.45118 .45745 Mdot
.43046 .61443 Mdot
.77427 .54196 Mdot
.34136 .49262 Mdot
.55448 .34295 Mdot
.5303 .49464 Mdot
.64644 .45058 Mdot
.63135 .54197 Mdot
.40636 .65057 Mdot
.6302 .64657 Mdot
.40109 .66868 Mdot
.3927 .67376 Mdot
.59448 .57592 Mdot
.45321 .66303 Mdot
.3994 .45672 Mdot
.70935 .41156 Mdot
.43223 .63695 Mdot
.57997 .61827 Mdot
.55851 .34516 Mdot
.42129 .65386 Mdot
.66499 .49061 Mdot
.36169 .45103 Mdot
.6568 .43216 Mdot
.54753 .30853 Mdot
.39942 .69137 Mdot
.56185 .3128 Mdot
.65566 .48136 Mdot
.58885 .36136 Mdot
.57779 .24324 Mdot
.56455 .64405 Mdot
.67053 .76236 Mdot
.39512 .36183 Mdot
.43969 .63196 Mdot
.67398 .50563 Mdot
.40571 .47621 Mdot
.35935 .44857 Mdot
.57744 .30716 Mdot
.44253 .6293 Mdot
.56289 .19855 Mdot
.4417 .3951 Mdot
.49308 .73473 Mdot
.555 .63467 Mdot
.30955 .75544 Mdot
.52629 .76535 Mdot
.754 .32368 Mdot
.30737 .45001 Mdot
.76272 .5536 Mdot
.35797 .49323 Mdot
.18549 .57823 Mdot
.55326 .35244 Mdot
.7944 .52748 Mdot
.31327 .43166 Mdot
.66296 .45289 Mdot
.37541 .47248 Mdot
.28942 .34384 Mdot
.4375 .42619 Mdot
.58216 .31569 Mdot
.59582 .55662 Mdot
.44817 .701 Mdot
.5613 .33215 Mdot
.68087 .45418 Mdot
.47618 .27304 Mdot
.33152 .48416 Mdot
.35776 .41522 Mdot
.62289 .4411 Mdot
.40487 .67505 Mdot
.68233 .48065 Mdot
.59003 .59641 Mdot
.57822 .34963 Mdot
.35459 .44031 Mdot
.34733 .51046 Mdot
.61381 .39764 Mdot
.55904 .62454 Mdot
.62871 .47085 Mdot
.57509 .58874 Mdot
.76167 .55307 Mdot
.32949 .43307 Mdot
.62732 .43213 Mdot
.39888 .50387 Mdot
.2065 .62595 Mdot
.61713 .79042 Mdot
.30798 .68175 Mdot
.67263 .45403 Mdot
.4646 .317 Mdot
.5706 .61361 Mdot
.58814 .58355 Mdot
.36065 .74801 Mdot
.37062 .25971 Mdot
.73834 .36151 Mdot
.20569 .43502 Mdot
.59086 .59662 Mdot
.57613 .60898 Mdot
.68327 .44095 Mdot
.4504 .65304 Mdot
.45523 .70685 Mdot
.62603 .47439 Mdot
.42473 .35421 Mdot
.42004 .67976 Mdot
.43937 .17919 Mdot
.68592 .48339 Mdot
.30658 .44573 Mdot
.7902 .55366 Mdot
.57125 .35499 Mdot
.42534 .35511 Mdot
.27955 .3617 Mdot
.40753 .48216 Mdot
.46419 .80796 Mdot
.66097 .47148 Mdot
.54837 .39942 Mdot
.35655 .21349 Mdot
.33262 .47451 Mdot
.37286 .47914 Mdot
.36451 .48885 Mdot
.5873 .37326 Mdot
.20187 .59421 Mdot
.40827 .48248 Mdot
.4684 .36961 Mdot
.41322 .42489 Mdot
.35379 .30618 Mdot
.58193 .32518 Mdot
.49276 .64132 Mdot
.63044 .41521 Mdot
.62355 .72993 Mdot
.29008 .46889 Mdot
.5811 .59079 Mdot
.71662 .47335 Mdot
.59594 .61393 Mdot
.35169 .25795 Mdot
.40937 .28527 Mdot
.4068 .63482 Mdot
.40668 .46563 Mdot
.6653 .41395 Mdot
.40001 .65774 Mdot
.73398 .51389 Mdot
.81944 .29966 Mdot
.55548 .61604 Mdot
.6917 .79356 Mdot
.58733 .58308 Mdot
.77871 .54764 Mdot
.42374 .6474 Mdot
.32126 .54573 Mdot
.54251 .48381 Mdot
.42232 .65497 Mdot
.63684 .67071 Mdot
.3833 .6562 Mdot
.47493 .31622 Mdot
.43498 .71051 Mdot
.57615 .61797 Mdot
.61987 .61864 Mdot
.30086 .44437 Mdot
.40257 .47618 Mdot
.57588 .49442 Mdot
.46521 .50211 Mdot
.40376 .47226 Mdot
.66329 .44354 Mdot
.73436 .71588 Mdot
.70687 .43153 Mdot
.44827 .641 Mdot
.56097 .59356 Mdot
.37343 .47747 Mdot
.36785 .43963 Mdot
.39007 .51057 Mdot
.20152 .64317 Mdot
.44613 .17934 Mdot
.38893 .44819 Mdot
.42974 .46164 Mdot
.67883 .45704 Mdot
.60643 .32625 Mdot
.1916 .47754 Mdot
.44446 .26657 Mdot
.34359 .46492 Mdot
.57441 .32384 Mdot
.57044 .37184 Mdot
.31999 .46513 Mdot
.65106 .73368 Mdot
.73401 .4338 Mdot
.39022 .49373 Mdot
.38183 .28616 Mdot
.70511 .46918 Mdot
.77552 .57001 Mdot
.64709 .47511 Mdot
.41157 .70404 Mdot
.77415 .5642 Mdot
.66422 .42032 Mdot
.30271 .53419 Mdot
.75272 .54263 Mdot
.62544 .7034 Mdot
.54982 .33378 Mdot
.35684 .47466 Mdot
.38847 .64212 Mdot
.70026 .44997 Mdot
.58145 .63654 Mdot
.43306 .66777 Mdot
.61194 .62828 Mdot
.57343 .2889 Mdot
.49828 .38092 Mdot
.78206 .56245 Mdot
.58744 .59095 Mdot
.49526 .7511 Mdot
.57643 .3237 Mdot
.59738 .57852 Mdot
.73423 .68012 Mdot
.31256 .44628 Mdot
.27811 .30935 Mdot
.40053 .42463 Mdot
.66049 .22856 Mdot
.5842 .58098 Mdot
.75209 .53863 Mdot
.37238 .49581 Mdot
.63701 .46188 Mdot
.41373 .53337 Mdot
.34757 .47031 Mdot
.62852 .45414 Mdot
.38213 .44811 Mdot
.58854 .35423 Mdot
.4207 .7213 Mdot
.47307 .52303 Mdot
.37176 .80937 Mdot
.5859 .36244 Mdot
.73812 .53017 Mdot
.40675 .47047 Mdot
.56083 .24191 Mdot
.41969 .65613 Mdot
.33281 .46687 Mdot
.37622 .75266 Mdot
.44293 .64387 Mdot
.43588 .66203 Mdot
.37032 .42156 Mdot
.60715 .58795 Mdot
.63905 .45602 Mdot
.57492 .32214 Mdot
.77786 .335 Mdot
.35044 .46063 Mdot
.37589 .46367 Mdot
.56151 .33454 Mdot
.57435 .60806 Mdot
.36614 .43795 Mdot
.67038 .54174 Mdot
.78619 .32413 Mdot
.58774 .57581 Mdot
.3196 .47571 Mdot
.2419 .35691 Mdot
.46811 .62994 Mdot
.69972 .77723 Mdot
.52534 .34871 Mdot
.67426 .47201 Mdot
.34095 .51588 Mdot
.46201 .11193 Mdot
.56952 .35226 Mdot
.60592 .74836 Mdot
.39521 .44472 Mdot
.3851 .47726 Mdot
.41672 .69086 Mdot
.37469 .43037 Mdot
.44979 .68287 Mdot
.40504 .83295 Mdot
.29149 .76748 Mdot
.40533 .66039 Mdot
.45218 .64193 Mdot
.47471 .69663 Mdot
.19348 .50156 Mdot
.43782 .64997 Mdot
.3409 .4958 Mdot
.50629 .19946 Mdot
.38802 .39429 Mdot
.58456 .30939 Mdot
.54444 .35997 Mdot
.47459 .61759 Mdot
.78974 .61948 Mdot
.46962 .45187 Mdot
.31029 .50401 Mdot
.497 .58077 Mdot
.59854 .58803 Mdot
.33997 .46719 Mdot
.7804 .56535 Mdot
.66097 .42461 Mdot
.42002 .41121 Mdot
.35426 .47751 Mdot
.42558 .63953 Mdot
.59442 .37031 Mdot
.61354 .58918 Mdot
.37786 .45989 Mdot
.61418 .41535 Mdot
.57588 .33434 Mdot
.43759 .63627 Mdot
.39497 .74818 Mdot
.59772 .35083 Mdot
.42283 .5173 Mdot
.39573 .47413 Mdot
.39143 .43908 Mdot
.30063 .47844 Mdot
.59167 .63408 Mdot
.69478 .48421 Mdot
.38601 .51717 Mdot
.57205 .78803 Mdot
.5381 .42184 Mdot
.3388 .50206 Mdot
.41841 .68548 Mdot
.56331 .58416 Mdot
.76443 .5397 Mdot
.50075 .27497 Mdot
.34778 .45179 Mdot
.44527 .18151 Mdot
.31412 .57023 Mdot
.77464 .56208 Mdot
.39655 .65085 Mdot
.56144 .32359 Mdot
.35982 .41696 Mdot
.46048 .20337 Mdot
.39184 .50178 Mdot
.42626 .37314 Mdot
.66741 .47262 Mdot
.59849 .5911 Mdot
.7674 .29514 Mdot
.65746 .42435 Mdot
.43823 .66325 Mdot
.49923 .16169 Mdot
.46729 .66067 Mdot
.45211 .69421 Mdot
.37913 .23159 Mdot
.59768 .62329 Mdot
.44563 .11492 Mdot
.72864 .73981 Mdot
.41671 .48754 Mdot
.56864 .60596 Mdot
.41835 .64701 Mdot
.4098 .45718 Mdot
.45875 .64862 Mdot
.45053 .69295 Mdot
.34656 .49627 Mdot
.39196 .47699 Mdot
.46326 .37516 Mdot
.39476 .19156 Mdot
.57055 .31792 Mdot
.43512 .69242 Mdot
.27732 .58181 Mdot
.41024 .47883 Mdot
.38111 .50045 Mdot
.678 .40142 Mdot
.58269 .31636 Mdot
.27014 .40387 Mdot
.38142 .44419 Mdot
.39707 .78524 Mdot
.34164 .41879 Mdot
.39677 .63035 Mdot
.58966 .57539 Mdot
.64302 .73708 Mdot
.70088 .45963 Mdot
.43033 .69732 Mdot
.56745 .36328 Mdot
.42607 .61979 Mdot
.35751 .7149 Mdot
.59651 .6221 Mdot
.43288 .68591 Mdot
.66092 .4881 Mdot
.58914 .62113 Mdot
.59352 .57893 Mdot
.50414 .20796 Mdot
.62777 .47189 Mdot
.54878 .33203 Mdot
.59307 .60873 Mdot
.2463 .53662 Mdot
.57554 .6223 Mdot
.29224 .58448 Mdot
.411 .43406 Mdot
.47536 .37093 Mdot
.54661 .75997 Mdot
.28861 .44932 Mdot
.57794 .64354 Mdot
.5866 .32662 Mdot
.36163 .42654 Mdot
.40484 .68399 Mdot
.58044 .35315 Mdot
.52593 .59961 Mdot
.6382 .475 Mdot
.40925 .64202 Mdot
.57919 .57588 Mdot
.43914 .68743 Mdot
.5053 .32112 Mdot
.60284 .48032 Mdot
.49788 .5925 Mdot
.54478 .47139 Mdot
.39803 .50752 Mdot
.43318 .58964 Mdot
.35193 .41225 Mdot
.35169 .47758 Mdot
.64619 .44872 Mdot
.43061 .34319 Mdot
.41548 .65497 Mdot
.7766 .30249 Mdot
.59136 .58984 Mdot
.43955 .79153 Mdot
.41951 .38475 Mdot
.33589 .45616 Mdot
.43428 .63802 Mdot
.46661 .67311 Mdot
.30723 .69591 Mdot
.69798 .45788 Mdot
.29803 .4231 Mdot
.44039 .47303 Mdot
.30357 .46018 Mdot
.58165 .58204 Mdot
.67367 .55441 Mdot
.68702 .46877 Mdot
.82547 .65169 Mdot
.65745 .47737 Mdot
.65656 .31465 Mdot
.45368 .66235 Mdot
.55333 .34946 Mdot
.38487 .4998 Mdot
.45964 .38577 Mdot
.39337 .64436 Mdot
.55353 .38464 Mdot
.55484 .33458 Mdot
.675 .60213 Mdot
.60172 .61926 Mdot
.32298 .46455 Mdot
.34426 .49164 Mdot
.38173 .42752 Mdot
.40435 .43183 Mdot
.55573 .60295 Mdot
.41675 .47427 Mdot
.56952 .64831 Mdot
.25243 .53083 Mdot
.39654 .78752 Mdot
.69319 .42715 Mdot
.345 .27875 Mdot
.4303 .63154 Mdot
.247 .55905 Mdot
.3383 .37398 Mdot
.62707 .78613 Mdot
.55875 .23228 Mdot
.36176 .41089 Mdot
.68995 .45287 Mdot
.27318 .35214 Mdot
.67237 .41731 Mdot
.44122 .89368 Mdot
.61139 .32538 Mdot
.47429 .16099 Mdot
.40838 .45981 Mdot
.65531 .39883 Mdot
.36965 .36976 Mdot
.31962 .46996 Mdot
.60139 .30727 Mdot
.41638 .76121 Mdot
.56333 .72863 Mdot
.5862 .36972 Mdot
.35876 .45263 Mdot
.45233 .69779 Mdot
.40124 .45629 Mdot
.37215 .4999 Mdot
.41207 .45454 Mdot
.59547 .57298 Mdot
.35373 .4058 Mdot
.41807 .45789 Mdot
.73761 .60247 Mdot
.44254 .32648 Mdot
.65142 .43017 Mdot
.33529 .71776 Mdot
.58149 .34255 Mdot
.41666 .6426 Mdot
.50586 .44465 Mdot
.60756 .59564 Mdot
.29719 .70043 Mdot
.41104 .44528 Mdot
.53536 .75624 Mdot
.57721 .57665 Mdot
.57712 .35411 Mdot
.75452 .54465 Mdot
.51568 .18677 Mdot
.69288 .42785 Mdot
.75388 .54134 Mdot
.64648 .45214 Mdot
.2119 .602 Mdot
.42786 .6394 Mdot
.38937 .51187 Mdot
.58677 .60177 Mdot
.63772 .45342 Mdot
.40872 .33258 Mdot
.3626 .47813 Mdot
.67312 .45028 Mdot
.39687 .50928 Mdot
.52814 .39978 Mdot
.73305 .42034 Mdot
.6633 .41707 Mdot
.62245 .58244 Mdot
.58779 .61593 Mdot
.55569 .32447 Mdot
.41408 .64279 Mdot
.42537 .68823 Mdot
.58393 .63067 Mdot
.65694 .80457 Mdot
.34617 .47016 Mdot
.41052 .46177 Mdot
.57211 .78529 Mdot
.39815 .46377 Mdot
.47745 .28848 Mdot
.78585 .55206 Mdot
.4205 .63671 Mdot
.40832 .45288 Mdot
.36341 .43847 Mdot
.3511 .44615 Mdot
.50314 .33005 Mdot
.65045 .47684 Mdot
.35299 .42023 Mdot
.59322 .32752 Mdot
.72658 .6658 Mdot
.41194 .46946 Mdot
.33728 .50651 Mdot
.42912 .68473 Mdot
.32557 .7836 Mdot
.60481 .58823 Mdot
.66762 .44118 Mdot
.64828 .48068 Mdot
.53439 .34808 Mdot
.39679 .70456 Mdot
.77813 .54103 Mdot
.82902 .44338 Mdot
.75452 .55714 Mdot
.56529 .33117 Mdot
.67701 .29212 Mdot
.61123 .42059 Mdot
.672 .43705 Mdot
.58833 .64861 Mdot
.40837 .44122 Mdot
.37708 .41158 Mdot
.6091 .7496 Mdot
.34326 .43207 Mdot
.55579 .34138 Mdot
.59683 .63547 Mdot
.42639 .68117 Mdot
.57151 .35692 Mdot
.57482 .59025 Mdot
.40535 .67767 Mdot
.31358 .4443 Mdot
.31608 .43451 Mdot
.4323 .66426 Mdot
.39874 .66547 Mdot
.39608 .48753 Mdot
.71569 .59832 Mdot
.40743 .70525 Mdot
.43584 .68496 Mdot
.77173 .57364 Mdot
.68924 .42488 Mdot
.45514 .45351 Mdot
.56733 .60661 Mdot
.39065 .44011 Mdot
.67867 .41925 Mdot
.57804 .31336 Mdot
.41482 .66212 Mdot
.36471 .4409 Mdot
.37379 .45264 Mdot
.57137 .32283 Mdot
.59738 .36031 Mdot
.5657 .3571 Mdot
.53923 .61969 Mdot
.39259 .42398 Mdot
.43689 .6514 Mdot
.60109 .61765 Mdot
.57053 .37182 Mdot
.54551 .33668 Mdot
.76987 .6056 Mdot
.40514 .48615 Mdot
.50122 .53788 Mdot
.67445 .16356 Mdot
.46541 .2706 Mdot
.76853 .53998 Mdot
.6215 .45156 Mdot
.47606 .35137 Mdot
.69606 .39834 Mdot
.56097 .62143 Mdot
.43929 .24075 Mdot
.58666 .30838 Mdot
.37728 .51183 Mdot
.3395 .42171 Mdot
.42421 .43553 Mdot
.57539 .34011 Mdot
.51107 .29674 Mdot
.4482 .63191 Mdot
.24254 .61113 Mdot
.58131 .34276 Mdot
.66445 .41751 Mdot
.63309 .4243 Mdot
.6583 .47733 Mdot
.32524 .4357 Mdot
.29931 .69227 Mdot
.25908 .56416 Mdot
.20894 .52775 Mdot
.60341 .61794 Mdot
.46772 .6473 Mdot
.57072 .24457 Mdot
.4334 .66091 Mdot
.66277 .42333 Mdot
.57277 .33683 Mdot
.42503 .69229 Mdot
.5689 .63438 Mdot
.57752 .6073 Mdot
.63712 .4723 Mdot
.6416 .46711 Mdot
.64692 .43731 Mdot
.42387 .70644 Mdot
.45328 .6626 Mdot
.3457 .44687 Mdot
.42022 .66573 Mdot
.48624 .81394 Mdot
.54105 .33246 Mdot
.64525 .41806 Mdot
.56583 .6193 Mdot
.41877 .64381 Mdot
.3573 .47129 Mdot
.71196 .33318 Mdot
.55154 .67071 Mdot
.59084 .35641 Mdot
.75156 .45439 Mdot
.48881 .89505 Mdot
.35114 .49665 Mdot
.56323 .5967 Mdot
.66758 .72233 Mdot
.36607 .48565 Mdot
.66065 .46485 Mdot
.18952 .59449 Mdot
.75658 .56249 Mdot
.41725 .45999 Mdot
.33866 .44368 Mdot
.60178 .57904 Mdot
.51456 .3513 Mdot
.34574 .43973 Mdot
.49258 .78142 Mdot
.61851 .59773 Mdot
.69312 .45182 Mdot
.79927 .33616 Mdot
.63937 .49752 Mdot
.38291 .34604 Mdot
.77804 .54927 Mdot
.34053 .48602 Mdot
.65929 .44193 Mdot
.59342 .34911 Mdot
.64988 .44033 Mdot
.39884 .64502 Mdot
.65063 .43232 Mdot
.37685 .46571 Mdot
.44024 .65269 Mdot
.56548 .62631 Mdot
.49564 .80416 Mdot
.7421 .61326 Mdot
.63692 .46254 Mdot
.76598 .57491 Mdot
.41437 .4712 Mdot
.27698 .4094 Mdot
.41784 .53269 Mdot
.4105 .4678 Mdot
.59688 .61401 Mdot
.43739 .63806 Mdot
.5515 .62447 Mdot
.3883 .5227 Mdot
.36428 .77402 Mdot
.58867 .5818 Mdot
.60502 .7165 Mdot
.56262 .33358 Mdot
.44155 .36352 Mdot
.35129 .46753 Mdot
.59109 .60322 Mdot
.39289 .42501 Mdot
.4628 .66979 Mdot
.55733 .52437 Mdot
.73265 .67041 Mdot
.5859 .60237 Mdot
.59226 .19619 Mdot
.54013 .53284 Mdot
.44364 .43112 Mdot
.59211 .59992 Mdot
.25108 .66663 Mdot
.7705 .5448 Mdot
.57249 .32964 Mdot
.57624 .37202 Mdot
.58816 .3632 Mdot
.33818 .43476 Mdot
.315 .39588 Mdot
.5468 .33623 Mdot
.61557 .58445 Mdot
.58576 .31789 Mdot
.47177 .38722 Mdot
.58249 .19552 Mdot
.57156 .36193 Mdot
.35992 .46135 Mdot
.33786 .50816 Mdot
.43867 .32738 Mdot
.67967 .42728 Mdot
.41846 .18802 Mdot
.38547 .58881 Mdot
.40333 .48037 Mdot
.42903 .40613 Mdot
.41216 .63512 Mdot
.70296 .71325 Mdot
.42444 .39404 Mdot
.72439 .4189 Mdot
.45899 .66164 Mdot
.62259 .48508 Mdot
.41829 .63892 Mdot
.37253 .50581 Mdot
.39239 .44945 Mdot
.42875 .72435 Mdot
.64059 .55252 Mdot
.67053 .67761 Mdot
.71552 .27101 Mdot
.43157 .69074 Mdot
.58287 .59533 Mdot
.55498 .61284 Mdot
.60491 .60767 Mdot
.69526 .47127 Mdot
.4023 .69419 Mdot
.38199 .41722 Mdot
.68041 .46337 Mdot
.34359 .47116 Mdot
.5922 .61635 Mdot
.76325 .28987 Mdot
.42841 .68357 Mdot
.38719 .49403 Mdot
.74543 .71585 Mdot
.64872 .46706 Mdot
.57888 .32631 Mdot
.53903 .40197 Mdot
.67214 .49152 Mdot
.57318 .64192 Mdot
.46238 .69658 Mdot
.55974 .57561 Mdot
.49895 .4622 Mdot
.37948 .39484 Mdot
.32979 .48963 Mdot
.79773 .36045 Mdot
.7795 .64366 Mdot
.33146 .43537 Mdot
.68092 .45315 Mdot
.68982 .43143 Mdot
.363 .44391 Mdot
.40604 .69294 Mdot
.5609 .36694 Mdot
.59597 .3313 Mdot
.42281 .51316 Mdot
.54598 .48344 Mdot
.47034 .37547 Mdot
.37121 .43485 Mdot
.28882 .43289 Mdot
.63837 .47804 Mdot
.7503 .54713 Mdot
.56797 .77439 Mdot
.56055 .36 Mdot
.39322 .44378 Mdot
.60641 .69569 Mdot
.45476 .67741 Mdot
.65105 .43351 Mdot
.58434 .6385 Mdot
.51988 .30066 Mdot
.67186 .48761 Mdot
.36438 .44368 Mdot
.36564 .43809 Mdot
.59976 .57886 Mdot
.39696 .6303 Mdot
.573 .33932 Mdot
.67849 .46449 Mdot
.55591 .35698 Mdot
.4493 .66195 Mdot
.42877 .67919 Mdot
.39211 .39461 Mdot
.30263 .47865 Mdot
.63957 .4718 Mdot
.42029 .5052 Mdot
.65825 .42045 Mdot
.52022 .32864 Mdot
.55957 .59123 Mdot
.33724 .4877 Mdot
.46937 .67668 Mdot
.59281 .62025 Mdot
.38839 .48242 Mdot
.84283 .42814 Mdot
.33539 .4645 Mdot
.68788 .48771 Mdot
.3701 .77939 Mdot
.58501 .32135 Mdot
.36821 .6888 Mdot
.35215 .54539 Mdot
.3961 .4634 Mdot
.64115 .42206 Mdot
.41729 .53113 Mdot
.59185 .57993 Mdot
.45471 .65259 Mdot
.62976 .84132 Mdot
.57926 .62141 Mdot
.40124 .45327 Mdot
.5782 .35108 Mdot
.4673 .67459 Mdot
.76703 .5653 Mdot
.58193 .77624 Mdot
.42977 .42306 Mdot
.31364 .43419 Mdot
.40812 .44597 Mdot
.18819 .46522 Mdot
.66316 .43972 Mdot
.4186 .64537 Mdot
.57655 .58428 Mdot
.57777 .63167 Mdot
.66182 .47494 Mdot
.53967 .73921 Mdot
.62809 .52537 Mdot
.55387 .09444 Mdot
.63017 .45046 Mdot
.57777 .31017 Mdot
.53591 .45247 Mdot
.64895 .42444 Mdot
.66479 .4483 Mdot
.64738 .48131 Mdot
.57054 .75484 Mdot
.41028 .68154 Mdot
.37483 .45172 Mdot
.39286 .69846 Mdot
.33843 .48377 Mdot
.31315 .35599 Mdot
.58749 .63105 Mdot
.45541 .65635 Mdot
.82298 .39127 Mdot
.46653 .49879 Mdot
.36895 .47973 Mdot
.59621 .24489 Mdot
.43157 .5173 Mdot
.49191 .30419 Mdot
.44934 .49482 Mdot
.64188 .45901 Mdot
.37438 .38222 Mdot
.31929 .49156 Mdot
.4844 .81097 Mdot
.56499 .61612 Mdot
.78048 .54872 Mdot
.36705 .40727 Mdot
.43224 .43552 Mdot
.46176 .68483 Mdot
.42574 .69254 Mdot
.54724 .33718 Mdot
.55613 .43523 Mdot
.56434 .62355 Mdot
.59253 .46946 Mdot
.40087 .47591 Mdot
.59831 .5498 Mdot
.36046 .74076 Mdot
.38808 .48398 Mdot
.48938 .2004 Mdot
.30059 .69943 Mdot
.3433 .44246 Mdot
.22709 .61626 Mdot
.57425 .61113 Mdot
.39171 .7784 Mdot
.42557 .48572 Mdot
.65942 .46372 Mdot
.45191 .65323 Mdot
.4088 .63843 Mdot
.57954 .3623 Mdot
.58094 .81343 Mdot
.57148 .64417 Mdot
.45442 .66014 Mdot
.36113 .48523 Mdot
.58888 .63577 Mdot
.78024 .5628 Mdot
.32741 .49791 Mdot
.42665 .23329 Mdot
.42139 .66929 Mdot
.43032 .4674 Mdot
.49721 .69162 Mdot
.52325 .40589 Mdot
.35566 .20046 Mdot
.6044 .601 Mdot
.56246 .35868 Mdot
.45533 .47294 Mdot
.82592 .43938 Mdot
.41691 .42634 Mdot
.44734 .35729 Mdot
.4619 .613 Mdot
.5508 .34374 Mdot
.37314 .48952 Mdot
.35076 .43643 Mdot
.53554 .47972 Mdot
.59554 .36537 Mdot
.33453 .47429 Mdot
.3651 .39077 Mdot
.40563 .67511 Mdot
.78446 .55131 Mdot
.42197 .67536 Mdot
.36009 .46475 Mdot
.32239 .39008 Mdot
.41006 .68964 Mdot
.70932 .2968 Mdot
.60129 .33384 Mdot
.60488 .58991 Mdot
.2965 .41661 Mdot
.41313 .43913 Mdot
.18059 .40329 Mdot
.77442 .54216 Mdot
.18251 .56375 Mdot
.62819 .48041 Mdot
.62642 .67774 Mdot
.61314 .40494 Mdot
.50222 .16872 Mdot
.50898 .79731 Mdot
.41237 .41247 Mdot
.38498 .27326 Mdot
.21721 .57981 Mdot
.55937 .63759 Mdot
.23953 .48751 Mdot
.40282 .47614 Mdot
.36383 .49697 Mdot
.68675 .44323 Mdot
.52452 .74931 Mdot
.65954 .72484 Mdot
.55848 .4921 Mdot
.5697 .34139 Mdot
.44998 .6708 Mdot
.38525 .4657 Mdot
.69705 .51511 Mdot
.64301 .43369 Mdot
.53602 .56591 Mdot
.38037 .4948 Mdot
.65367 .75408 Mdot
.59182 .73284 Mdot
.59237 .63471 Mdot
.62419 .44202 Mdot
.66779 .49152 Mdot
.37686 .50438 Mdot
.57492 .64017 Mdot
.34444 .4461 Mdot
.55389 .54151 Mdot
.42846 .49187 Mdot
.58086 .35706 Mdot
.41003 .49194 Mdot
.51556 .49844 Mdot
.42427 .15939 Mdot
.45736 .43473 Mdot
.39401 .68108 Mdot
.69167 .47571 Mdot
.65354 .47634 Mdot
.42801 .68954 Mdot
.65455 .47516 Mdot
.25496 .62787 Mdot
.355 .62695 Mdot
.56629 .34222 Mdot
.30967 .39168 Mdot
.58462 .35412 Mdot
.77919 .54648 Mdot
.40452 .48423 Mdot
.83874 .46271 Mdot
.63076 .45664 Mdot
.24291 .6861 Mdot
.57442 .62441 Mdot
.77732 .5452 Mdot
.41572 .42771 Mdot
.67172 .29032 Mdot
.67299 .42606 Mdot
.66699 .49729 Mdot
.34978 .44677 Mdot
.42049 .68873 Mdot
.35311 .43553 Mdot
.44406 .48996 Mdot
.7557 .54082 Mdot
.40794 .44147 Mdot
.57455 .59057 Mdot
.40897 .70078 Mdot
.53627 .18848 Mdot
.70097 .45035 Mdot
.40092 .49792 Mdot
.36244 .48608 Mdot
.4646 .66208 Mdot
.41891 .43721 Mdot
.5649 .6332 Mdot
.32725 .15187 Mdot
.56316 .33216 Mdot
.74875 .55404 Mdot
.6877 .48973 Mdot
.3591 .41278 Mdot
.36611 .43363 Mdot
.7918 .34757 Mdot
.71282 .64746 Mdot
.57959 .58977 Mdot
.43016 .51205 Mdot
.678 .45695 Mdot
.57697 .35277 Mdot
.61618 .60012 Mdot
.38841 .43844 Mdot
.3762 .49878 Mdot
.57871 .35743 Mdot
.52084 .20531 Mdot
.73477 .42799 Mdot
.60495 .61309 Mdot
.37839 .38138 Mdot
.72083 .34915 Mdot
.34676 .47024 Mdot
.75179 .35225 Mdot
.43505 .6838 Mdot
.59645 .60104 Mdot
.20043 .50896 Mdot
.39156 .51251 Mdot
.56067 .62768 Mdot
.56447 .62169 Mdot
.41544 .49366 Mdot
.3966 .70293 Mdot
.43189 .70296 Mdot
.44263 .68469 Mdot
.37769 .79493 Mdot
.35871 .32295 Mdot
.64537 .43826 Mdot
.57435 .60969 Mdot
.66701 .41593 Mdot
.5688 .37293 Mdot
.53915 .42497 Mdot
.67566 .42135 Mdot
.41183 .63597 Mdot
.63367 .42326 Mdot
.35133 .44036 Mdot
.56406 .6259 Mdot
.67118 .43592 Mdot
.34672 .41855 Mdot
.28365 .47726 Mdot
.51375 .5444 Mdot
.55574 .36112 Mdot
.53352 .37184 Mdot
.38717 .45439 Mdot
.7625 .53982 Mdot
.3954 .4901 Mdot
.59897 .63151 Mdot
.5146 .47646 Mdot
.34974 .41851 Mdot
.63741 .46689 Mdot
.42747 .55534 Mdot
.69323 .44365 Mdot
.44233 .47983 Mdot
.36198 .46349 Mdot
.34669 .47762 Mdot
.3452 .43991 Mdot
.58873 .72381 Mdot
.55466 .63521 Mdot
.27721 .46654 Mdot
.65407 .40805 Mdot
.42504 .6594 Mdot
.43803 .62384 Mdot
.74273 .3752 Mdot
.74669 .54761 Mdot
.56785 .60794 Mdot
.34704 .4667 Mdot
.67091 .49822 Mdot
.7561 .28255 Mdot
.74052 .32119 Mdot
.58803 .26277 Mdot
.67935 .44633 Mdot
.39409 .67714 Mdot
.65638 .42737 Mdot
.36014 .49797 Mdot
.37099 .51746 Mdot
.51272 .17612 Mdot
.57163 .65844 Mdot
.57368 .33758 Mdot
.34473 .4794 Mdot
.372 .34661 Mdot
.67882 .45715 Mdot
.63675 .47791 Mdot
.33738 .46796 Mdot
.42913 .69902 Mdot
.27842 .23908 Mdot
.58863 .63784 Mdot
.26112 .42667 Mdot
.39518 .60417 Mdot
.42735 .76525 Mdot
.57886 .63465 Mdot
.50376 .56562 Mdot
.67444 .47937 Mdot
.36806 .64553 Mdot
.42725 .66249 Mdot
.57703 .3373 Mdot
.35424 .51072 Mdot
.41109 .63764 Mdot
.6225 .47051 Mdot
.43015 .63391 Mdot
.3747 .50829 Mdot
.55584 .63429 Mdot
.66805 .4768 Mdot
.62118 .57333 Mdot
.42887 .72497 Mdot
.59053 .34162 Mdot
.44048 .36447 Mdot
.24527 .46868 Mdot
.29929 .69969 Mdot
.35349 .41991 Mdot
.72922 .46938 Mdot
.38909 .42262 Mdot
.45668 .68978 Mdot
.3525 .46605 Mdot
.47318 .61476 Mdot
.62452 .4572 Mdot
.43014 .46854 Mdot
.4176 .46527 Mdot
.27453 .52938 Mdot
.37667 .48295 Mdot
.42181 .4563 Mdot
.34421 .43735 Mdot
.40014 .59938 Mdot
.40286 .40175 Mdot
.41399 .68523 Mdot
.59805 .75186 Mdot
.66249 .44813 Mdot
.55031 .35613 Mdot
.59719 .34635 Mdot
.45586 .36204 Mdot
.43653 .36006 Mdot
.54204 .74278 Mdot
.41585 .67643 Mdot
.56651 .59887 Mdot
.34393 .44708 Mdot
.20849 .48279 Mdot
.55297 .29711 Mdot
.67198 .47911 Mdot
.70022 .4669 Mdot
.31025 .49023 Mdot
.18814 .45888 Mdot
.43051 .45388 Mdot
.58804 .77964 Mdot
.42252 .51086 Mdot
.33301 .46834 Mdot
.67764 .48812 Mdot
.4953 .38915 Mdot
.35286 .42011 Mdot
.46225 .68423 Mdot
.57929 .33396 Mdot
.45701 .42413 Mdot
.63121 .36426 Mdot
.52738 .55852 Mdot
.31623 .54974 Mdot
.39252 .42059 Mdot
.67504 .46918 Mdot
.40873 .64291 Mdot
.55902 .78556 Mdot
.6014 .61501 Mdot
.54309 .76569 Mdot
.26556 .5483 Mdot
.66847 .26546 Mdot
.57602 .33476 Mdot
.51255 .20668 Mdot
.37743 .4653 Mdot
.69103 .47789 Mdot
.35529 .50098 Mdot
.7504 .27775 Mdot
.56448 .31171 Mdot
.38908 .65109 Mdot
.5808 .59497 Mdot
.46174 .67115 Mdot
.31247 .68307 Mdot
.48735 .59456 Mdot
.71775 .53788 Mdot
.69051 .42693 Mdot
.27346 .38832 Mdot
.43605 .64626 Mdot
.37561 .44087 Mdot
.59392 .11381 Mdot
.43642 .68285 Mdot
.43952 .69106 Mdot
.52074 .35703 Mdot
.56192 .27308 Mdot
.40259 .53184 Mdot
.43687 .63312 Mdot
.64821 .41222 Mdot
.57662 .31986 Mdot
.35667 .42503 Mdot
.34781 .43577 Mdot
.41835 .69073 Mdot
.66729 .42333 Mdot
.26072 .39405 Mdot
.64134 .46359 Mdot
.40398 .67109 Mdot
.64906 .45985 Mdot
.71278 .46108 Mdot
.67206 .44061 Mdot
.41649 .4407 Mdot
.34923 .46288 Mdot
.63771 .34565 Mdot
.42869 .67901 Mdot
.36801 .42935 Mdot
.3887 .4466 Mdot
.43554 .64917 Mdot
.61351 .41892 Mdot
.21169 .46442 Mdot
.40592 .466 Mdot
.36283 .454 Mdot
.55327 .35073 Mdot
.61012 .45227 Mdot
.75972 .4727 Mdot
.36185 .42608 Mdot
.5921 .32207 Mdot
.4233 .70752 Mdot
.39415 .48899 Mdot
.47852 .39173 Mdot
.70788 .44475 Mdot
.40816 .49786 Mdot
.7687 .56633 Mdot
.36731 .41125 Mdot
.29362 .23173 Mdot
.40558 .49184 Mdot
.41896 .64794 Mdot
.44559 .64524 Mdot
.54116 .38406 Mdot
.44075 .66556 Mdot
.78086 .55368 Mdot
.59076 .61777 Mdot
.68711 .24464 Mdot
.77979 .56128 Mdot
.33179 .46087 Mdot
.72834 .74025 Mdot
.41546 .50613 Mdot
.36516 .40822 Mdot
.19035 .51772 Mdot
.7792 .56034 Mdot
.4339 .63991 Mdot
.64268 .55939 Mdot
.41969 .51524 Mdot
.58358 .63937 Mdot
.32596 .49164 Mdot
.41366 .49028 Mdot
.46393 .77607 Mdot
.33878 .75211 Mdot
.60506 .62301 Mdot
.4585 .46638 Mdot
.36262 .4258 Mdot
.76919 .63363 Mdot
.3606 .47679 Mdot
.57439 .36251 Mdot
.44225 .68805 Mdot
.63873 .43246 Mdot
.56266 .32725 Mdot
.3991 .46935 Mdot
.5777 .3419 Mdot
.65078 .4348 Mdot
.59753 .6098 Mdot
.39625 .5002 Mdot
.5869 .31139 Mdot
.57108 .34138 Mdot
.38474 .42417 Mdot
.45415 .65569 Mdot
.46855 .47875 Mdot
.39289 .48777 Mdot
.37171 .44261 Mdot
.4253 .68815 Mdot
.83796 .60318 Mdot
.36397 .50147 Mdot
.50257 .54069 Mdot
.38795 .65707 Mdot
.78653 .5661 Mdot
.66729 .43071 Mdot
.40772 .50258 Mdot
.59077 .63131 Mdot
.59098 .62667 Mdot
.6207 .4422 Mdot
.46357 .671 Mdot
.6793 .42813 Mdot
.46248 .46793 Mdot
.2977 .47005 Mdot
.3944 .5186 Mdot
.61252 .84328 Mdot
.49854 .18023 Mdot
.40095 .68925 Mdot
.68555 .47137 Mdot
.56135 .49135 Mdot
.57332 .60524 Mdot
.6306 .42432 Mdot
.4645 .68841 Mdot
.39647 .66868 Mdot
.42809 .63188 Mdot
.55422 .34864 Mdot
.67177 .48524 Mdot
.39454 .63464 Mdot
.43576 .69672 Mdot
.3506 .4441 Mdot
.36441 .42597 Mdot
.48599 .64923 Mdot
.45297 .31727 Mdot
.58972 .34769 Mdot
.66757 .47042 Mdot
.15394 .41797 Mdot
.59999 .63015 Mdot
.27738 .53051 Mdot
.35423 .41459 Mdot
.81115 .279 Mdot
.43275 .46143 Mdot
.36013 .48265 Mdot
.41335 .70504 Mdot
.56877 .3051 Mdot
.58648 .34005 Mdot
.43804 .64635 Mdot
.45424 .70813 Mdot
.5687 .36265 Mdot
.55016 .23142 Mdot
.59508 .19331 Mdot
.54754 .78123 Mdot
.42388 .64884 Mdot
.24895 .46258 Mdot
.57313 .64133 Mdot
.4154 .72527 Mdot
.60989 .60851 Mdot
.66491 .44977 Mdot
.66001 .48531 Mdot
.60251 .58043 Mdot
.34891 .44939 Mdot
.65789 .43321 Mdot
.41352 .40339 Mdot
.56679 .21549 Mdot
.31479 .27688 Mdot
.70032 .63157 Mdot
.34463 .41704 Mdot
.64817 .73438 Mdot
.68052 .69954 Mdot
.39224 .45847 Mdot
.47291 .4185 Mdot
.57529 .33848 Mdot
.3958 .71113 Mdot
.56705 .63508 Mdot
.34257 .2086 Mdot
.34686 .46883 Mdot
.41367 .65569 Mdot
.56527 .6133 Mdot
.57808 .39993 Mdot
.48925 .77795 Mdot
.33901 .48128 Mdot
.4942 .10004 Mdot
.38732 .70051 Mdot
.63786 .43326 Mdot
.6571 .78857 Mdot
.3904 .69469 Mdot
.52969 .36338 Mdot
.63904 .48341 Mdot
.73881 .30301 Mdot
.41535 .64378 Mdot
.61741 .45754 Mdot
.44774 .66358 Mdot
.58305 .35856 Mdot
.43353 .713 Mdot
.67205 .47547 Mdot
.37577 .48752 Mdot
.65758 .4727 Mdot
.59049 .34818 Mdot
.69639 .47144 Mdot
.57023 .63844 Mdot
.77254 .54311 Mdot
.58288 .6103 Mdot
.53446 .41302 Mdot
.35041 .76367 Mdot
.59896 .59145 Mdot
.58958 .42171 Mdot
.33313 .43253 Mdot
.40156 .62598 Mdot
.62936 .44499 Mdot
.65119 .40899 Mdot
.54468 .4427 Mdot
.42799 .6555 Mdot
.66674 .47439 Mdot
.25785 .5456 Mdot
.7978 .68171 Mdot
.31109 .40034 Mdot
.36925 .30748 Mdot
.43253 .64906 Mdot
.62639 .46844 Mdot
.57233 .78415 Mdot
.42846 .62841 Mdot
.63076 .45006 Mdot
.58944 .59927 Mdot
.57791 .63272 Mdot
.34108 .46704 Mdot
.59586 .65123 Mdot
.63215 .43052 Mdot
.65104 .68749 Mdot
.45384 .68133 Mdot
.57547 .401 Mdot
.58143 .36426 Mdot
.66853 .44674 Mdot
.31359 .4834 Mdot
.47237 .69069 Mdot
.6954 .42772 Mdot
.38313 .25511 Mdot
.15039 .44534 Mdot
.66379 .47345 Mdot
.44431 .68735 Mdot
.41289 .66213 Mdot
.42705 .52311 Mdot
.54381 .4796 Mdot
.68434 .43403 Mdot
.84019 .48809 Mdot
.43561 .35061 Mdot
.76117 .55334 Mdot
.7869 .64297 Mdot
.35243 .41939 Mdot
.39505 .42778 Mdot
.57321 .60258 Mdot
.37161 .47369 Mdot
.43141 .70044 Mdot
.39238 .41313 Mdot
.55777 .62048 Mdot
.67559 .4775 Mdot
.39951 .49536 Mdot
.58407 .32315 Mdot
.59034 .64314 Mdot
.60768 .58413 Mdot
.65266 .44875 Mdot
.43382 .6323 Mdot
.67498 .51476 Mdot
.64227 .46822 Mdot
.3894 .41836 Mdot
.77326 .5601 Mdot
.39101 .51039 Mdot
.48897 .22328 Mdot
.45421 .63775 Mdot
.65115 .42681 Mdot
.39724 .65061 Mdot
.58081 .61438 Mdot
.62943 .41802 Mdot
.3628 .47122 Mdot
.63251 .45275 Mdot
.6648 .38497 Mdot
.52411 .22384 Mdot
.46353 .67431 Mdot
.61879 .3834 Mdot
.4421 .6914 Mdot
.75999 .55395 Mdot
.48167 .24498 Mdot
.56904 .33239 Mdot
.67516 .45492 Mdot
.48193 .17795 Mdot
.63452 .46558 Mdot
.37851 .48218 Mdot
.38891 .47618 Mdot
.68552 .44285 Mdot
.56697 .31619 Mdot
.32741 .78272 Mdot
.49245 .56495 Mdot
.42955 .63793 Mdot
.37979 .6131 Mdot
.17239 .36415 Mdot
.62003 .59536 Mdot
.57332 .59802 Mdot
.43716 .46218 Mdot
.33589 .4576 Mdot
.61049 .58492 Mdot
.56226 .59182 Mdot
.55484 .35786 Mdot
.65417 .48221 Mdot
.38127 .64705 Mdot
.61676 .61636 Mdot
.39261 .55244 Mdot
.39136 .34858 Mdot
.41504 .52566 Mdot
.32839 .40396 Mdot
.32607 .43026 Mdot
.52087 .3978 Mdot
.56467 .59279 Mdot
.38506 .45355 Mdot
.4092 .40596 Mdot
.59141 .5955 Mdot
.58335 .35754 Mdot
.42901 .74649 Mdot
.65402 .46193 Mdot
.87502 .50991 Mdot
.40538 .49763 Mdot
.38229 .48819 Mdot
.60307 .61866 Mdot
.79221 .61977 Mdot
.39924 .6707 Mdot
.45155 .63805 Mdot
.66233 .43856 Mdot
.54671 .44084 Mdot
.41129 .42751 Mdot
.39022 .4566 Mdot
.67001 .45906 Mdot
.76974 .54168 Mdot
.68505 .62917 Mdot
.37276 .45366 Mdot
.56721 .61753 Mdot
.71805 .46757 Mdot
.56344 .5932 Mdot
.35036 .49678 Mdot
.37965 .48055 Mdot
.41684 .44023 Mdot
.33537 .45687 Mdot
.61321 .59959 Mdot
.38373 .45794 Mdot
.31239 .48617 Mdot
.44996 .64145 Mdot
.4064 .43266 Mdot
.46963 .36567 Mdot
.35912 .45728 Mdot
.58778 .33033 Mdot
.72356 .50406 Mdot
.34549 .4773 Mdot
.40752 .43551 Mdot
.49547 .56004 Mdot
.37055 .49138 Mdot
.60195 .62614 Mdot
.42082 .66094 Mdot
.57472 .60909 Mdot
.58055 .58208 Mdot
.66005 .41235 Mdot
.55355 .35579 Mdot
.40446 .41117 Mdot
.59176 .35839 Mdot
.31435 .41784 Mdot
.3727 .50813 Mdot
.68801 .5065 Mdot
.58948 .77802 Mdot
.70928 .40565 Mdot
.36085 .46919 Mdot
.66328 .4428 Mdot
.64218 .43063 Mdot
.38346 .26715 Mdot
.43679 .42292 Mdot
.61461 .59421 Mdot
.59065 .60296 Mdot
.47274 .28346 Mdot
.46886 .78075 Mdot
.59002 .3397 Mdot
.5798 .497 Mdot
.32929 .42979 Mdot
.37673 .44814 Mdot
.33382 .50319 Mdot
.67467 .42039 Mdot
.75162 .54302 Mdot
.66996 .48053 Mdot
.79527 .55999 Mdot
.55671 .60359 Mdot
.37967 .41194 Mdot
.33177 .25649 Mdot
.41574 .69375 Mdot
.42106 .66167 Mdot
.61306 .58333 Mdot
.68971 .43582 Mdot
.42815 .52572 Mdot
.63515 .84293 Mdot
.3996 .72036 Mdot
.54698 .32149 Mdot
.39474 .45572 Mdot
.65551 .44547 Mdot
.42048 .69644 Mdot
.5991 .33586 Mdot
.4128 .45512 Mdot
.64089 .40643 Mdot
.35338 .46302 Mdot
.21455 .58089 Mdot
.44689 .64103 Mdot
.75365 .27602 Mdot
.46709 .661 Mdot
.58926 .64445 Mdot
.59104 .58799 Mdot
.38657 .48214 Mdot
.62936 .82521 Mdot
.38412 .66352 Mdot
.62348 .61162 Mdot
.56437 .30874 Mdot
.7489 .552 Mdot
.55325 .32132 Mdot
.64787 .42374 Mdot
.57732 .33328 Mdot
.64759 .48024 Mdot
.46291 .29205 Mdot
.38464 .70534 Mdot
.56296 .32967 Mdot
.76348 .61276 Mdot
.35953 .40336 Mdot
.57038 .37128 Mdot
.30788 .48356 Mdot
.37492 .63175 Mdot
.66639 .45914 Mdot
.5691 .31546 Mdot
.37264 .44005 Mdot
.33164 .22818 Mdot
.58811 .58356 Mdot
.6151 .59958 Mdot
.36113 .40096 Mdot
.64607 .48183 Mdot
.44853 .71113 Mdot
.50262 .46212 Mdot
.7897 .55933 Mdot
.38762 .45655 Mdot
.37561 .4112 Mdot
.44401 .62496 Mdot
.46963 .65212 Mdot
.38176 .47945 Mdot
.24158 .51774 Mdot
.38026 .46426 Mdot
.58544 .6347 Mdot
.39767 .66802 Mdot
.41551 .66234 Mdot
.62807 .4346 Mdot
.45637 .68352 Mdot
.32826 .40257 Mdot
.56995 .66387 Mdot
.4133 .51876 Mdot
.58162 .62008 Mdot
.51225 .49017 Mdot
.7005 .45987 Mdot
.38493 .20122 Mdot
.45152 .63061 Mdot
.40843 .44064 Mdot
.45023 .68749 Mdot
.56382 .35393 Mdot
.42741 .67637 Mdot
.39245 .68452 Mdot
.39721 .47764 Mdot
.34036 .48547 Mdot
.77863 .557 Mdot
.54621 .47596 Mdot
.45626 .66914 Mdot
.38681 .4624 Mdot
.42195 .49869 Mdot
.41995 .47518 Mdot
.53071 .51694 Mdot
.39758 .68726 Mdot
.31547 .59018 Mdot
.40491 .23498 Mdot
.45585 .66298 Mdot
.26652 .26275 Mdot
.76095 .56395 Mdot
.7473 .54919 Mdot
.61958 .61526 Mdot
.37209 .45227 Mdot
.69166 .45573 Mdot
.36615 .5004 Mdot
.40287 .39578 Mdot
.37507 .49961 Mdot
.5786 .31303 Mdot
.40184 .4078 Mdot
.76199 .54777 Mdot
.64488 .47142 Mdot
.40953 .45976 Mdot
.39684 .49773 Mdot
.74512 .5465 Mdot
.45885 .63782 Mdot
.40127 .65622 Mdot
.7467 .33976 Mdot
.56613 .34923 Mdot
.59834 .61459 Mdot
.34485 .45874 Mdot
.66361 .44135 Mdot
.65472 .47271 Mdot
.45895 .6771 Mdot
.65869 .46583 Mdot
.59262 .63644 Mdot
.36412 .47513 Mdot
.61419 .59595 Mdot
.58385 .31772 Mdot
.43943 .68877 Mdot
.3435 .46178 Mdot
.35106 .44418 Mdot
.4453 .64494 Mdot
.33272 .43269 Mdot
.55354 .35128 Mdot
.6414 .4724 Mdot
.40766 .64976 Mdot
.59093 .6203 Mdot
.63182 .4277 Mdot
.35908 .43857 Mdot
.15327 .46742 Mdot
.37382 .47129 Mdot
.36527 .44545 Mdot
.55965 .18599 Mdot
.4393 .46878 Mdot
.62629 .44665 Mdot
.43084 .62392 Mdot
.32101 .42797 Mdot
.36076 .34189 Mdot
.80251 .39031 Mdot
.63266 .42082 Mdot
.40252 .4565 Mdot
.40593 .18917 Mdot
.40665 .45814 Mdot
.59223 .47195 Mdot
.74215 .40658 Mdot
.28557 .35413 Mdot
.32211 .4079 Mdot
.60931 .59354 Mdot
.77932 .55517 Mdot
.62874 .46662 Mdot
.26029 .67066 Mdot
.39407 .47101 Mdot
.24514 .66156 Mdot
.41642 .47531 Mdot
.57645 .63352 Mdot
.45804 .515 Mdot
.66544 .47002 Mdot
.54275 .8178 Mdot
.38452 .41795 Mdot
.39733 .68488 Mdot
.64516 .41759 Mdot
.75198 .55715 Mdot
.36583 .44097 Mdot
.59567 .34656 Mdot
.63224 .58971 Mdot
.29115 .45156 Mdot
.58356 .6222 Mdot
.3897 .44523 Mdot
.45575 .44815 Mdot
.60726 .81971 Mdot
.44305 .63805 Mdot
.57758 .59664 Mdot
.70997 .70191 Mdot
.32829 .4405 Mdot
.41312 .64504 Mdot
.42724 .66136 Mdot
.58687 .35857 Mdot
.60226 .5314 Mdot
.51169 .67957 Mdot
.27383 .30888 Mdot
.33069 .7139 Mdot
.6224 .45097 Mdot
.68107 .67982 Mdot
.35995 .42334 Mdot
.4967 .59788 Mdot
.60737 .61453 Mdot
.3799 .4888 Mdot
.34904 .73593 Mdot
.44028 .68531 Mdot
.36821 .45702 Mdot
.58385 .35573 Mdot
.61788 .54364 Mdot
.52554 .57027 Mdot
.2001 .37888 Mdot
.6399 .41552 Mdot
.3517 .5114 Mdot
.31046 .41861 Mdot
.7784 .57031 Mdot
.36464 .5069 Mdot
.62715 .45724 Mdot
.57802 .23058 Mdot
.56643 .31484 Mdot
.42805 .6955 Mdot
.75975 .56333 Mdot
.33026 .42329 Mdot
.42317 .48781 Mdot
.54942 .35465 Mdot
.38968 .43482 Mdot
.58725 .80944 Mdot
.75042 .52757 Mdot
.66443 .43414 Mdot
.42446 .63408 Mdot
.32437 .43779 Mdot
.75288 .54259 Mdot
.39426 .47713 Mdot
.33357 .54955 Mdot
.40206 .43606 Mdot
.491 .70882 Mdot
.45205 .65461 Mdot
.58509 .61854 Mdot
.32976 .40938 Mdot
.36088 .49396 Mdot
.71592 .34094 Mdot
.40316 .39604 Mdot
.40539 .4934 Mdot
.46395 .68191 Mdot
.40793 .69275 Mdot
.41566 .68493 Mdot
.64931 .43208 Mdot
.55823 .77667 Mdot
.57186 .6182 Mdot
.40606 .41766 Mdot
.6166 .61633 Mdot
.34552 .54825 Mdot
.54541 .34182 Mdot
.27071 .27899 Mdot
.41233 .44589 Mdot
.41399 .68016 Mdot
.58644 .70013 Mdot
.42489 .70688 Mdot
.65307 .40619 Mdot
.56436 .62419 Mdot
.43917 .68282 Mdot
.35833 .48819 Mdot
.549 .49197 Mdot
.21278 .38255 Mdot
.57851 .60467 Mdot
.34625 .51282 Mdot
.6361 .41495 Mdot
.70429 .45496 Mdot
.18597 .32153 Mdot
.58195 .58791 Mdot
.68558 .69448 Mdot
.39155 .46287 Mdot
.41519 .69256 Mdot
.60454 .59709 Mdot
.60041 .58368 Mdot
.66548 .46216 Mdot
.34073 .48292 Mdot
.34813 .47913 Mdot
.76669 .56589 Mdot
.59263 .60677 Mdot
.34454 .40835 Mdot
.40523 .51589 Mdot
.51574 .17611 Mdot
.41665 .74583 Mdot
.84762 .57523 Mdot
.46253 .46683 Mdot
.32979 .72031 Mdot
.52812 .44534 Mdot
.40503 .69627 Mdot
.3428 .47823 Mdot
.31868 .44619 Mdot
.62706 .4379 Mdot
.36856 .47236 Mdot
.69513 .45664 Mdot
.56967 .59946 Mdot
.25112 .29098 Mdot
.56707 .66981 Mdot
.56297 .23671 Mdot
.37128 .47879 Mdot
.45 .76665 Mdot
.55719 .33474 Mdot
.54416 .60028 Mdot
.40245 .66908 Mdot
.32342 .45985 Mdot
.68305 .489 Mdot
.67621 .45507 Mdot
.43434 .66767 Mdot
.6422 .71735 Mdot
.7439 .35011 Mdot
.34005 .49081 Mdot
.66879 .42994 Mdot
.63632 .66556 Mdot
.23742 .52491 Mdot
.56508 .65562 Mdot
.56589 .31349 Mdot
.67407 .47761 Mdot
.59441 .57513 Mdot
.47035 .70187 Mdot
.44174 .67466 Mdot
.41478 .62715 Mdot
.68896 .36549 Mdot
.68949 .43924 Mdot
.56637 .32223 Mdot
.51044 .78838 Mdot
.49311 .79697 Mdot
.5744 .3117 Mdot
.67781 .47675 Mdot
.41357 .69544 Mdot
.40775 .66015 Mdot
.42025 .66015 Mdot
.53122 .8183 Mdot
.45869 .64529 Mdot
.3359 .57804 Mdot
.41663 .50341 Mdot
.2899 .39933 Mdot
.40534 .45859 Mdot
.61155 .61015 Mdot
.44599 .64112 Mdot
.53858 .44679 Mdot
.33205 .44849 Mdot
.20865 .37261 Mdot
.38957 .4544 Mdot
.55683 .65333 Mdot
.36814 .45277 Mdot
.25304 .49348 Mdot
.38684 .66066 Mdot
.36309 .46824 Mdot
.54734 .62741 Mdot
.57279 .34467 Mdot
.40482 .61299 Mdot
.34593 .47824 Mdot
.50639 .75163 Mdot
.42968 .44037 Mdot
.57672 .22447 Mdot
.50558 .36514 Mdot
.55044 .31415 Mdot
.37544 .39077 Mdot
.6202 .45732 Mdot
.4276 .60408 Mdot
.33427 .37837 Mdot
.57999 .60503 Mdot
.23491 .67008 Mdot
.67484 .45071 Mdot
.46188 .50965 Mdot
.43167 .51025 Mdot
.55836 .35957 Mdot
.47168 .63648 Mdot
.60468 .61803 Mdot
.35028 .41494 Mdot
.41696 .48988 Mdot
.54217 .24232 Mdot
.31927 .38597 Mdot
.4208 .43809 Mdot
.55942 .36697 Mdot
.32414 .59648 Mdot
.35563 .45287 Mdot
.61566 .41701 Mdot
.40786 .63437 Mdot
.37463 .398 Mdot
.31129 .58489 Mdot
.38762 .46383 Mdot
.4349 .67881 Mdot
.4385 .62156 Mdot
.54528 .71584 Mdot
.56041 .30791 Mdot
.40189 .43613 Mdot
.52137 .30776 Mdot
.39202 .42271 Mdot
.56932 .62128 Mdot
.36671 .50289 Mdot
.66882 .4525 Mdot
.58209 .78521 Mdot
.63826 .44197 Mdot
.36079 .49928 Mdot
.41925 .65619 Mdot
.60819 .59958 Mdot
.6503 .35783 Mdot
.74295 .39361 Mdot
.33529 .58124 Mdot
.83106 .40354 Mdot
.55544 .32701 Mdot
.58669 .37206 Mdot
.57211 .64749 Mdot
.36071 .4656 Mdot
.52051 .37003 Mdot
.43307 .49026 Mdot
.36274 .45282 Mdot
.37828 .50047 Mdot
.60699 .64564 Mdot
.57074 .60867 Mdot
.65092 .4662 Mdot
.3799 .47839 Mdot
.3853 .46171 Mdot
.45239 .67148 Mdot
.57097 .34379 Mdot
.63817 .43851 Mdot
.56314 .34155 Mdot
.64302 .4512 Mdot
.28953 .23467 Mdot
.39697 .52337 Mdot
.57364 .347 Mdot
.57131 .64826 Mdot
.4249 .68874 Mdot
.76742 .53783 Mdot
.64508 .42308 Mdot
.66747 .47172 Mdot
.38854 .45755 Mdot
.42998 .68713 Mdot
.4577 .6734 Mdot
.5593 .35063 Mdot
.60075 .60334 Mdot
.35855 .49788 Mdot
.34443 .49431 Mdot
.33432 .29477 Mdot
.66268 .41747 Mdot
.25239 .55327 Mdot
.55747 .7261 Mdot
.35958 .46676 Mdot
.4423 .63539 Mdot
.39792 .49312 Mdot
.39213 .20986 Mdot
.41128 .63672 Mdot
.3336 .46921 Mdot
.45826 .78466 Mdot
.68636 .42648 Mdot
.50464 .71566 Mdot
.42777 .45884 Mdot
.78757 .34068 Mdot
.37147 .42078 Mdot
.49434 .154 Mdot
.73688 .64493 Mdot
.39267 .41398 Mdot
.35385 .43222 Mdot
.26211 .33072 Mdot
.39749 .46418 Mdot
.75786 .55098 Mdot
.46082 .44598 Mdot
.39633 .66752 Mdot
.51362 .41599 Mdot
.62706 .40455 Mdot
.56972 .30772 Mdot
.66243 .43826 Mdot
.63553 .38578 Mdot
.57936 .35882 Mdot
.42519 .64743 Mdot
.34592 .4371 Mdot
.43254 .3617 Mdot
.67862 .41287 Mdot
.44224 .48917 Mdot
.56884 .62316 Mdot
.6087 .41406 Mdot
.6931 .46763 Mdot
.58941 .61664 Mdot
.41868 .46457 Mdot
.21604 .43819 Mdot
.74943 .42096 Mdot
.70823 .25257 Mdot
.60473 .61384 Mdot
.5753 .63531 Mdot
.56195 .78997 Mdot
.57339 .30838 Mdot
.48057 .23147 Mdot
.45896 .74888 Mdot
.5823 .64125 Mdot
.50094 .27145 Mdot
.64371 .48247 Mdot
.49694 .75532 Mdot
.39611 .71143 Mdot
.37822 .52214 Mdot
.35864 .48996 Mdot
.59873 .60029 Mdot
.43753 .37018 Mdot
.63763 .79134 Mdot
.58295 .60902 Mdot
.3041 .43704 Mdot
.6112 .5344 Mdot
.76925 .56138 Mdot
.77261 .56776 Mdot
.5523 .31562 Mdot
.71756 .30799 Mdot
.4473 .65817 Mdot
.5634 .36334 Mdot
.56743 .55172 Mdot
.39922 .43831 Mdot
.58738 .60388 Mdot
.75749 .53603 Mdot
.58569 .62972 Mdot
.58576 .34662 Mdot
.54682 .32259 Mdot
.4484 .64025 Mdot
.39954 .66972 Mdot
.32536 .72073 Mdot
.48027 .30406 Mdot
.40798 .45875 Mdot
.1941 .54869 Mdot
.45426 .68192 Mdot
.35195 .37962 Mdot
.5909 .32097 Mdot
.57068 .34762 Mdot
.22486 .5883 Mdot
.34195 .4516 Mdot
.58306 .39529 Mdot
.3465 .46389 Mdot
.46059 .2479 Mdot
.34003 .49343 Mdot
.66206 .46312 Mdot
.36796 .41332 Mdot
.65032 .51797 Mdot
.34529 .42794 Mdot
.40396 .49729 Mdot
.66317 .48219 Mdot
.3416 .51461 Mdot
.67038 .45333 Mdot
.34632 .49255 Mdot
.58864 .37736 Mdot
.66325 .44096 Mdot
.37917 .31483 Mdot
.50331 .54125 Mdot
.75974 .54223 Mdot
.59263 .33823 Mdot
.58478 .36385 Mdot
.44285 .35962 Mdot
.40264 .66518 Mdot
.42073 .73662 Mdot
.36165 .46449 Mdot
.63596 .47719 Mdot
.57166 .6029 Mdot
.38398 .46271 Mdot
.32239 .47552 Mdot
.42551 .44935 Mdot
.44712 .68269 Mdot
.69021 .43743 Mdot
.57751 .34575 Mdot
.66242 .42946 Mdot
.71454 .32386 Mdot
.67272 .4876 Mdot
.40931 .40489 Mdot
.31978 .47903 Mdot
.26929 .47694 Mdot
.23689 .66041 Mdot
.4251 .78836 Mdot
.44011 .66971 Mdot
.77356 .54901 Mdot
.54623 .32896 Mdot
.39626 .59018 Mdot
.40693 .67786 Mdot
.67523 .47269 Mdot
.35314 .46327 Mdot
.3031 .46234 Mdot
.51381 .60773 Mdot
.44346 .60479 Mdot
.43446 .3447 Mdot
.68823 .47878 Mdot
.76286 .55623 Mdot
.55614 .78025 Mdot
.39824 .5962 Mdot
.53895 .4344 Mdot
.38459 .4967 Mdot
.59619 .34338 Mdot
.42059 .69642 Mdot
.68849 .37921 Mdot
.59399 .60129 Mdot
.54489 .47892 Mdot
.37045 .47771 Mdot
.63036 .69849 Mdot
.42045 .6562 Mdot
.58725 .35153 Mdot
.59791 .59955 Mdot
.57019 .30635 Mdot
.7715 .56865 Mdot
.72442 .30253 Mdot
.38901 .42714 Mdot
.40738 .48706 Mdot
.58527 .65043 Mdot
.44584 .65956 Mdot
.54413 .37918 Mdot
.53119 .23626 Mdot
.67499 .43389 Mdot
.59666 .39215 Mdot
.41241 .70272 Mdot
.29847 .53504 Mdot
.65743 .43003 Mdot
.61328 .58316 Mdot
.51923 .4021 Mdot
.55654 .61482 Mdot
.34447 .47253 Mdot
.41467 .67258 Mdot
.57641 .58911 Mdot
.70487 .33942 Mdot
.40377 .17776 Mdot
.2613 .48599 Mdot
.39518 .41831 Mdot
.26272 .28622 Mdot
.56868 .20611 Mdot
.46959 .39581 Mdot
.56835 .63813 Mdot
.3934 .48501 Mdot
.36375 .50839 Mdot
.38063 .41585 Mdot
.56607 .59784 Mdot
.65051 .28208 Mdot
.67248 .4674 Mdot
.39525 .45229 Mdot
.57656 .36449 Mdot
.66083 .45338 Mdot
.68174 .50469 Mdot
.63249 .46839 Mdot
.39332 .66808 Mdot
.33433 .46137 Mdot
.55748 .75913 Mdot
.4552 .14237 Mdot
.57553 .60813 Mdot
.75968 .54253 Mdot
.41207 .48308 Mdot
.38103 .77321 Mdot
.41503 .68405 Mdot
.67752 .43548 Mdot
.38259 .48894 Mdot
.68256 .30557 Mdot
.79802 .55626 Mdot
.64833 .47726 Mdot
.40603 .66059 Mdot
.47773 .4088 Mdot
.36951 .47116 Mdot
.37571 .4222 Mdot
.44177 .65248 Mdot
.74433 .32758 Mdot
.58226 .77997 Mdot
.39732 .49611 Mdot
.58617 .61753 Mdot
.74227 .74858 Mdot
.42599 .45946 Mdot
.48144 .67273 Mdot
.74865 .5529 Mdot
.52185 .74301 Mdot
.25151 .55797 Mdot
.39384 .39199 Mdot
.28741 .28031 Mdot
.49353 .38974 Mdot
.25876 .27938 Mdot
.53719 .30789 Mdot
.69495 .54302 Mdot
.30452 .22081 Mdot
.5482 .63419 Mdot
.28547 .40672 Mdot
.27646 .34996 Mdot
.6236 .73574 Mdot
.50386 .41792 Mdot
.81217 .43455 Mdot
.73003 .3628 Mdot
.75715 .58057 Mdot
.6312 .45784 Mdot
.43905 .2464 Mdot
.37007 .50217 Mdot
.57812 .20427 Mdot
.24869 .51644 Mdot
.62759 .80625 Mdot
.27832 .26349 Mdot
.52254 .30314 Mdot
.21876 .38533 Mdot
.41758 .18895 Mdot
.25569 .40122 Mdot
.50699 .63851 Mdot
.83267 .53311 Mdot
.51023 .79197 Mdot
.56284 .26129 Mdot
.44683 .50591 Mdot
.67736 .51954 Mdot
.62301 .23981 Mdot
.3472 .62161 Mdot
.66232 .79937 Mdot
.6358 .43018 Mdot
.39705 .6428 Mdot
.32191 .29858 Mdot
.41888 .60606 Mdot
.62965 .64647 Mdot
.28509 .28168 Mdot
.48732 .16206 Mdot
.25356 .49782 Mdot
.8049 .3574 Mdot
.25393 .64821 Mdot
.35801 .79927 Mdot
.52294 .53952 Mdot
.41183 .62642 Mdot
.80297 .51861 Mdot
.49115 .79693 Mdot
.55482 .67502 Mdot
.39851 .58278 Mdot
.54182 .31864 Mdot
.41594 .32206 Mdot
.41461 .65474 Mdot
.24276 .54877 Mdot
.76324 .57135 Mdot
.50561 .66081 Mdot
.70245 .50211 Mdot
.36707 .21485 Mdot
.72568 .53891 Mdot
.51031 .76019 Mdot
.67234 .67444 Mdot
.15209 .46113 Mdot
.50848 .29063 Mdot
.44973 .19495 Mdot
.5181 .62201 Mdot
.49698 .41221 Mdot
.63516 .76774 Mdot
.47926 .32345 Mdot
.47817 .79886 Mdot
.16389 .52708 Mdot
.6237 .21732 Mdot
.17361 .44966 Mdot
.44626 .61689 Mdot
.42199 .44315 Mdot
.38982 .22541 Mdot
.33165 .71092 Mdot
.54777 .31673 Mdot
.18813 .40372 Mdot
.59623 .33139 Mdot
.42751 .61051 Mdot
.63689 .7247 Mdot
.30107 .54468 Mdot
.59648 .41388 Mdot
.60251 .3659 Mdot
.41443 .41343 Mdot
.35071 .83706 Mdot
.24794 .30482 Mdot
.53815 .72244 Mdot
.5159 .17509 Mdot
.58065 .55557 Mdot
.55121 .39372 Mdot
.56748 .59984 Mdot
.3663 .18951 Mdot
.40804 .669 Mdot
.39785 .15006 Mdot
.39979 .17257 Mdot
.7353 .7121 Mdot
.50037 .9107 Mdot
.70386 .60445 Mdot
.26777 .41769 Mdot
.37467 .34883 Mdot
.38318 .33349 Mdot
.64592 .77429 Mdot
.75226 .69219 Mdot
.60658 .55075 Mdot
.7141 .28013 Mdot
.32145 .21766 Mdot
.48505 .26205 Mdot
.61226 .2541 Mdot
.63223 .74445 Mdot
.51415 .5249 Mdot
.46827 .69845 Mdot
.48389 .54808 Mdot
.50076 .63448 Mdot
.18598 .42144 Mdot
.35648 .72868 Mdot
.65588 .82475 Mdot
.55547 .37961 Mdot
.78327 .63544 Mdot
.52222 .19075 Mdot
.38339 .30532 Mdot
.37306 .57049 Mdot
.58491 .74997 Mdot
.4159 .41268 Mdot
.56513 .77346 Mdot
.47408 .47577 Mdot
.62544 .38027 Mdot
.55152 .78626 Mdot
.65092 .63555 Mdot
.53235 .24407 Mdot
.30918 .28378 Mdot
.45209 .77456 Mdot
.39965 .653 Mdot
.48051 .3514 Mdot
.50956 .27865 Mdot
.5188 .17981 Mdot
.70829 .7021 Mdot
.69729 .24343 Mdot
.72372 .70011 Mdot
.43259 .48829 Mdot
.33025 .38395 Mdot
.43928 .51694 Mdot
.49118 .31425 Mdot
.42819 .48417 Mdot
.63656 .6894 Mdot
.54372 .18277 Mdot
.35232 .73936 Mdot
.61789 .31945 Mdot
.20561 .62438 Mdot
.67138 .23337 Mdot
.39183 .22971 Mdot
.73018 .65389 Mdot
.32996 .37014 Mdot
.24049 .72697 Mdot
.65259 .45419 Mdot
.4947 .27096 Mdot
.58503 .57157 Mdot
.68752 .36958 Mdot
.24367 .38496 Mdot
.72041 .72668 Mdot
.54976 .18309 Mdot
.59205 .75784 Mdot
.73855 .43319 Mdot
.57396 .46183 Mdot
.59606 .43206 Mdot
.19901 .60549 Mdot
.31072 .46978 Mdot
.3863 .56255 Mdot
.57788 .37027 Mdot
.33181 .68974 Mdot
.42131 .22803 Mdot
.78571 .44436 Mdot
.30705 .40918 Mdot
.76881 .5022 Mdot
.75964 .5572 Mdot
.54787 .48567 Mdot
.20642 .3025 Mdot
.43864 .43557 Mdot
.71329 .62337 Mdot
.6382 .22267 Mdot
.51812 .38396 Mdot
.48962 .19755 Mdot
.60066 .71945 Mdot
.17235 .47396 Mdot
.43822 .15726 Mdot
.75822 .40943 Mdot
.2363 .30029 Mdot
.65803 .19823 Mdot
.17214 .50857 Mdot
.20576 .59264 Mdot
.54235 .61481 Mdot
.4116 .11576 Mdot
.68499 .45574 Mdot
.26027 .70228 Mdot
.33685 .72066 Mdot
.66497 .30673 Mdot
.44847 .70786 Mdot
.37467 .53745 Mdot
.73474 .55885 Mdot
.38282 .69327 Mdot
.39865 .39909 Mdot
.1639 .41894 Mdot
.16249 .57011 Mdot
.16937 .41953 Mdot
.69474 .25917 Mdot
.24246 .29378 Mdot
.3 .33065 Mdot
.34019 .57682 Mdot
.38882 .25686 Mdot
.35727 .49941 Mdot
.45361 .27426 Mdot
.70569 .61361 Mdot
.7404 .41804 Mdot
.5322 .67337 Mdot
.42169 .7122 Mdot
.19459 .44076 Mdot
.15391 .35953 Mdot
.25243 .62684 Mdot
.29411 .59791 Mdot
.50583 .58971 Mdot
.48918 .29816 Mdot
.45619 .53124 Mdot
.7571 .48537 Mdot
.52259 .18578 Mdot
.27719 .34709 Mdot
.51809 .25997 Mdot
.80033 .45689 Mdot
.605 .49207 Mdot
.77813 .62905 Mdot
.36838 .20706 Mdot
.3392 .309 Mdot
.74235 .69476 Mdot
.30187 .37905 Mdot
.66812 .7747 Mdot
.77499 .39234 Mdot
.69555 .4084 Mdot
.53024 .27234 Mdot
.70229 .45003 Mdot
.47625 .26402 Mdot
.58049 .53609 Mdot
.33578 .28122 Mdot
.48901 .38663 Mdot
.47616 .25907 Mdot
.60687 .49467 Mdot
.19406 .37051 Mdot
.71281 .23505 Mdot
.18502 .62264 Mdot
.77301 .32461 Mdot
.47604 .46721 Mdot
.41867 .49438 Mdot
.58596 .19021 Mdot
.18019 .37644 Mdot
.46327 .14727 Mdot
.6415 .69523 Mdot
.69517 .33055 Mdot
.54823 .64121 Mdot
.1981 .63669 Mdot
.7853 .38465 Mdot
.46421 .1702 Mdot
.42836 .78687 Mdot
.62085 .61028 Mdot
.60005 .7646 Mdot
.2202 .65683 Mdot
.23795 .4163 Mdot
.24939 .57932 Mdot
.42882 .51907 Mdot
.2397 .48887 Mdot
.41287 .63097 Mdot
.66724 .68846 Mdot
.48411 .31621 Mdot
.65341 .44922 Mdot
.34848 .31658 Mdot
.37881 .56289 Mdot
.42076 .41856 Mdot
.71963 .43338 Mdot
.43513 .72531 Mdot
.26399 .6922 Mdot
.61632 .55747 Mdot
.28232 .23417 Mdot
.70339 .6415 Mdot
.44005 .53562 Mdot
.49457 .35174 Mdot
.68667 .38801 Mdot
.57352 .76724 Mdot
.55991 .63928 Mdot
.30771 .24035 Mdot
.47518 .5395 Mdot
.4843 .35122 Mdot
.23836 .49619 Mdot
.50671 .22832 Mdot
.32499 .48494 Mdot
.56742 .71428 Mdot
.36298 .61259 Mdot
.54991 .47544 Mdot
.40124 .62167 Mdot
.43132 .72856 Mdot
.85262 .39321 Mdot
.64297 .54184 Mdot
.73669 .67555 Mdot
.31618 .23795 Mdot
.55928 .61192 Mdot
.43587 .70741 Mdot
.45844 .26085 Mdot
.54795 .23636 Mdot
.35393 .64486 Mdot
.65846 .49757 Mdot
.57877 .28484 Mdot
.78281 .42211 Mdot
.26485 .28677 Mdot
.22912 .35081 Mdot
.61481 .82012 Mdot
.45724 .68638 Mdot
.48674 .22137 Mdot
.55098 .24352 Mdot
.44603 .69262 Mdot
.4618 .61607 Mdot
.49566 .68169 Mdot
.23314 .28925 Mdot
.5563 .76889 Mdot
.75909 .31724 Mdot
.51801 .39739 Mdot
.6682 .29178 Mdot
.66934 .37612 Mdot
.55798 .2701 Mdot
.32224 .23599 Mdot
.23708 .54889 Mdot
.2319 .40837 Mdot
.4576 .49028 Mdot
.33519 .74591 Mdot
.20202 .64625 Mdot
.52691 .52918 Mdot
.28824 .52726 Mdot
.64161 .64863 Mdot
.39437 .42104 Mdot
.1521 .45904 Mdot
.57069 .21483 Mdot
.5313 .80334 Mdot
.62431 .57049 Mdot
.36776 .43473 Mdot
.41951 .50802 Mdot
.43998 .37396 Mdot
.53583 .73314 Mdot
.17526 .5832 Mdot
.56933 .26244 Mdot
.47366 .42795 Mdot
.24193 .51197 Mdot
.71367 .62582 Mdot
.36541 .21969 Mdot
.54869 .20408 Mdot
.57591 .52185 Mdot
.70424 .61962 Mdot
.55538 .42842 Mdot
.75095 .30008 Mdot
.72315 .51514 Mdot
.30333 .32296 Mdot
.43051 .75711 Mdot
.56113 .73849 Mdot
.6976 .38924 Mdot
.41049 .49078 Mdot
.64134 .71758 Mdot
.40645 .19543 Mdot
.61665 .84129 Mdot
.64907 .7609 Mdot
.15685 .41856 Mdot
.28461 .50864 Mdot
.56082 .74434 Mdot
.22177 .40997 Mdot
.58871 .86219 Mdot
.72786 .50532 Mdot
.20478 .39921 Mdot
.56711 .44729 Mdot
.29345 .25177 Mdot
.56635 .58082 Mdot
.49247 .77798 Mdot
.21152 .63357 Mdot
.23992 .2835 Mdot
.42607 .21027 Mdot
.3317 .23678 Mdot
.31563 .3702 Mdot
.21298 .31507 Mdot
.40274 .765 Mdot
.76645 .58341 Mdot
.62715 .4215 Mdot
.64541 .67918 Mdot
.20859 .49592 Mdot
.48566 .61794 Mdot
.50541 .26723 Mdot
.78431 .60362 Mdot
.37929 .60147 Mdot
.22906 .43696 Mdot
.40566 .2884 Mdot
.5846 .72404 Mdot
.49617 .35666 Mdot
.44187 .17185 Mdot
.79343 .58141 Mdot
.64718 .35885 Mdot
.71446 .67471 Mdot
.72357 .29944 Mdot
.53196 .73105 Mdot
.66798 .54966 Mdot
.44612 .19456 Mdot
.76384 .36226 Mdot
.52174 .29727 Mdot
.86681 .38138 Mdot
.63764 .25156 Mdot
.50223 .65681 Mdot
.18688 .44136 Mdot
.53519 .19301 Mdot
.39282 .75529 Mdot
.61715 .80454 Mdot
.32785 .74169 Mdot
.46005 .29331 Mdot
.37384 .49956 Mdot
.19391 .33238 Mdot
.41709 .31415 Mdot
.18475 .41472 Mdot
.6281 .20421 Mdot
.23402 .47983 Mdot
.43242 .43767 Mdot
.62997 .48315 Mdot
.51941 .56337 Mdot
.4028 .28282 Mdot
.23516 .37517 Mdot
.3097 .73059 Mdot
.61742 .39252 Mdot
.73118 .52482 Mdot
.66265 .49521 Mdot
.43878 .39423 Mdot
.695 .61895 Mdot
.55912 .72949 Mdot
.58495 .38859 Mdot
.62849 .52704 Mdot
.49515 .28688 Mdot
.25015 .55196 Mdot
.23967 .41334 Mdot
.69791 .74545 Mdot
.63441 .64681 Mdot
.62778 .43864 Mdot
.27393 .3144 Mdot
.65012 .25171 Mdot
.62071 .69281 Mdot
.18131 .51584 Mdot
.59083 .74882 Mdot
.42164 .25387 Mdot
.38099 .24701 Mdot
.66245 .76622 Mdot
.84258 .49951 Mdot
.19432 .50095 Mdot
.33691 .74853 Mdot
.59244 .39677 Mdot
.29807 .50938 Mdot
.28911 .23595 Mdot
.54495 .26819 Mdot
.35196 .26459 Mdot
.50644 .5452 Mdot
.33685 .66054 Mdot
.22472 .47194 Mdot
.36355 .32336 Mdot
.54666 .44619 Mdot
.30069 .78252 Mdot
.42195 .71894 Mdot
.14884 .46801 Mdot
.59578 .61418 Mdot
.49654 .82628 Mdot
.62062 .49645 Mdot
.56097 .53116 Mdot
.52849 .42796 Mdot
.56094 .71271 Mdot
.48828 .71245 Mdot
.70396 .26804 Mdot
.69464 .75843 Mdot
.66781 .48789 Mdot
.51468 .34484 Mdot
.76475 .33672 Mdot
.27451 .30384 Mdot
.34604 .41033 Mdot
.66901 .2644 Mdot
.524 .52709 Mdot
.7378 .41695 Mdot
.58907 .19395 Mdot
.61817 .67055 Mdot
.31215 .41961 Mdot
.4871 .30192 Mdot
.20418 .40626 Mdot
.41613 .16837 Mdot
.5876 .80156 Mdot
.47424 .47438 Mdot
.54189 .62817 Mdot
.29732 .34984 Mdot
.26538 .29702 Mdot
.57258 .40731 Mdot
.51569 .7665 Mdot
.51266 .28257 Mdot
.1325 .54897 Mdot
.16242 .55283 Mdot
.17747 .58644 Mdot
.51666 .37608 Mdot
.38393 .64914 Mdot
.37222 .76136 Mdot
.35868 .2614 Mdot
.601 .6879 Mdot
.6306 .23701 Mdot
.49737 .2744 Mdot
.54189 .85793 Mdot
.37459 .57656 Mdot
.71392 .32116 Mdot
.22031 .48372 Mdot
.31866 .69751 Mdot
.55146 .59927 Mdot
.44535 .29553 Mdot
.46823 .52813 Mdot
.58782 .64539 Mdot
.57893 .7251 Mdot
.50139 .74786 Mdot
.34788 .26695 Mdot
.35534 .61201 Mdot
.47378 .44498 Mdot
.30579 .28024 Mdot
.37881 .67992 Mdot
.68267 .37687 Mdot
.65323 .37075 Mdot
.5034 .44984 Mdot
.67635 .43892 Mdot
.40316 .39383 Mdot
.56305 .48747 Mdot
.55987 .44725 Mdot
.25783 .71734 Mdot
.5978 .3416 Mdot
.39841 .70293 Mdot
.49175 .81367 Mdot
.4419 .69638 Mdot
.17051 .37722 Mdot
.75328 .49012 Mdot
.24258 .50178 Mdot
.75494 .39636 Mdot
.7977 .49402 Mdot
.38244 .82814 Mdot
.18933 .57056 Mdot
.48879 .56455 Mdot
.42091 .59365 Mdot
.4636 .6523 Mdot
.60722 .40795 Mdot
.74056 .56009 Mdot
.26028 .5843 Mdot
.71607 .60836 Mdot
.40539 .25179 Mdot
.42526 .61929 Mdot
.68611 .2958 Mdot
.45361 .52815 Mdot
.24613 .26952 Mdot
.62865 .45227 Mdot
.20308 .68464 Mdot
.33915 .51099 Mdot
.25574 .38382 Mdot
.5762 .1851 Mdot
.59088 .78713 Mdot
.72009 .41946 Mdot
.82789 .4398 Mdot
.38044 .4091 Mdot
.47037 .4386 Mdot
.41366 .65295 Mdot
.45761 .23352 Mdot
.57408 .33339 Mdot
.45336 .34618 Mdot
.61374 .62559 Mdot
.76518 .67094 Mdot
.69344 .63088 Mdot
.38467 .67943 Mdot
.45339 .5507 Mdot
.42362 .21843 Mdot
.47698 .7595 Mdot
.52383 .52511 Mdot
.26421 .32765 Mdot
.35214 .6405 Mdot
.43112 .61952 Mdot
.1789 .53014 Mdot
.5494 .24811 Mdot
.37953 .1767 Mdot
.3467 .53552 Mdot
.52559 .54859 Mdot
.46402 .76701 Mdot
.58085 .71552 Mdot
.25581 .56729 Mdot
.51805 .18512 Mdot
.48026 .33906 Mdot
.48793 .79116 Mdot
.47279 .25986 Mdot
.3775 .53171 Mdot
.71241 .53019 Mdot
.66572 .66197 Mdot
.50873 .85561 Mdot
.22228 .61264 Mdot
.61666 .77407 Mdot
.46612 .60981 Mdot
.71231 .622 Mdot
.40489 .71144 Mdot
.6442 .31941 Mdot
.34782 .63334 Mdot
.73778 .48704 Mdot
.33185 .20293 Mdot
.52677 .1845 Mdot
.507 .62099 Mdot
.70359 .48899 Mdot
.4926 .39888 Mdot
.43512 .53659 Mdot
.53239 .47753 Mdot
.39769 .41501 Mdot
.43165 .38177 Mdot
.57749 .79932 Mdot
.58852 .69913 Mdot
.38743 .53867 Mdot
.27129 .26053 Mdot
.39279 .16913 Mdot
.20704 .33342 Mdot
.60003 .39474 Mdot
.39354 .68678 Mdot
.16855 .48784 Mdot
.279 .56161 Mdot
.44073 .17023 Mdot
.20242 .52209 Mdot
.84113 .37099 Mdot
.23394 .38918 Mdot
.64847 .63366 Mdot
.74233 .70516 Mdot
.50899 .69422 Mdot
.59626 .2017 Mdot
.77363 .58403 Mdot
.61062 .31264 Mdot
.60547 .20414 Mdot
.34488 .83082 Mdot
.21318 .60759 Mdot
.50585 .75592 Mdot
.26233 .41267 Mdot
.49504 .45086 Mdot
.71907 .59542 Mdot
.3771 .50638 Mdot
.68581 .41988 Mdot
.72626 .4195 Mdot
.49991 .28102 Mdot
.27512 .48374 Mdot
.72371 .60118 Mdot
.40207 .27953 Mdot
.45033 .24298 Mdot
.57266 .25706 Mdot
.24103 .37501 Mdot
.26361 .58031 Mdot
.31705 .41388 Mdot
.38319 .64251 Mdot
.5557 .31351 Mdot
.63558 .37979 Mdot
.33558 .47641 Mdot
.72715 .43056 Mdot
.47062 .74052 Mdot
.15876 .42477 Mdot
.62868 .31383 Mdot
.55428 .22764 Mdot
.40737 .72439 Mdot
.54726 .7268 Mdot
.36237 .23582 Mdot
.62767 .73172 Mdot
.73755 .60868 Mdot
.35505 .72831 Mdot
.25626 .29192 Mdot
.57781 .75344 Mdot
.5112 .24815 Mdot
.3188 .77101 Mdot
.60567 .62825 Mdot
.26748 .69071 Mdot
.28593 .33867 Mdot
.60922 .73494 Mdot
.44646 .61862 Mdot
.65618 .60904 Mdot
.70205 .54088 Mdot
.60035 .73103 Mdot
.64232 .22353 Mdot
.46027 .22373 Mdot
.21996 .50068 Mdot
.23506 .33584 Mdot
.64937 .41347 Mdot
.51454 .26032 Mdot
.6476 .57721 Mdot
.71725 .57715 Mdot
.4632 .77559 Mdot
.27689 .24507 Mdot
.53405 .46586 Mdot
.40471 .31828 Mdot
.38417 .42281 Mdot
.31524 .58768 Mdot
.57384 .70413 Mdot
.61123 .50756 Mdot
.72133 .68595 Mdot
.40705 .6424 Mdot
.68704 .66047 Mdot
.79901 .57125 Mdot
.44879 .30593 Mdot
.42195 .5771 Mdot
.41058 .74632 Mdot
.56255 .29439 Mdot
.79137 .56508 Mdot
.32372 .42262 Mdot
.40792 .32852 Mdot
.59257 .43305 Mdot
.2404 .65742 Mdot
.21027 .60875 Mdot
.2697 .31692 Mdot
.57517 .2279 Mdot
.61529 .69179 Mdot
.20036 .5209 Mdot
.49351 .70193 Mdot
.33924 .56617 Mdot
.66056 .72032 Mdot
.42822 .45597 Mdot
.6459 .31771 Mdot
.41698 .70767 Mdot
.2637 .31133 Mdot
.32221 .54312 Mdot
.38014 .31323 Mdot
.54998 .50882 Mdot
.38227 .22341 Mdot
.50693 .51665 Mdot
.57908 .18795 Mdot
.51125 .69158 Mdot
.48286 .31803 Mdot
.6202 .57679 Mdot
.56921 .44369 Mdot
.65979 .75851 Mdot
.35868 .20107 Mdot
.70586 .74131 Mdot
.37881 .35056 Mdot
.61263 .76843 Mdot
.34613 .7542 Mdot
.61606 .20253 Mdot
.47189 .3099 Mdot
.53226 .47992 Mdot
.45114 .53328 Mdot
.51841 .6081 Mdot
.76587 .53781 Mdot
.6608 .32666 Mdot
.27431 .57581 Mdot
.60843 .2714 Mdot
.74086 .47102 Mdot
.34806 .40562 Mdot
.38593 .77825 Mdot
.24384 .31903 Mdot
.37981 .61251 Mdot
.54799 .53131 Mdot
.71709 .38753 Mdot
.44557 .3136 Mdot
.88016 .55329 Mdot
.15126 .45794 Mdot
.38502 .42413 Mdot
.5168 .40767 Mdot
.45183 .33936 Mdot
.69454 .46048 Mdot
.26427 .59432 Mdot
.26806 .31588 Mdot
.5732 .63646 Mdot
.6922 .33773 Mdot
.65022 .66267 Mdot
.55835 .70774 Mdot
.35072 .3236 Mdot
.60199 .6485 Mdot
.16395 .39628 Mdot
.67319 .26024 Mdot
.58814 .70625 Mdot
.87794 .4784 Mdot
.65085 .68905 Mdot
.39144 .72019 Mdot
.42023 .2073 Mdot
.19563 .36607 Mdot
.51672 .38082 Mdot
.68878 .36595 Mdot
.21253 .61948 Mdot
.48009 .32589 Mdot
.47482 .24412 Mdot
.71374 .67399 Mdot
.69229 .66513 Mdot
.73784 .57445 Mdot
.79813 .4917 Mdot
.2846 .73863 Mdot
.23445 .52602 Mdot
.2197 .36089 Mdot
.7427 .49741 Mdot
.55529 .85613 Mdot
.36566 .18998 Mdot
.44104 .27799 Mdot
.73124 .61662 Mdot
.44492 .19982 Mdot
.44124 .35298 Mdot
.36862 .73617 Mdot
.75141 .48354 Mdot
.34947 .67411 Mdot
.78653 .49264 Mdot
.67928 .71664 Mdot
.47596 .26193 Mdot
.32918 .7167 Mdot
.53605 .45889 Mdot
.25505 .3529 Mdot
.80094 .61749 Mdot
.49764 .33827 Mdot
.70457 .3487 Mdot
.3852 .34208 Mdot
.2883 .28831 Mdot
.43314 .19173 Mdot
.52547 .4688 Mdot
.34463 .82739 Mdot
.19035 .41615 Mdot
.63688 .73457 Mdot
.41823 .50104 Mdot
.33028 .19893 Mdot
.50908 .47012 Mdot
.19808 .53424 Mdot
.61878 .22265 Mdot
.63697 .35927 Mdot
.45364 .76244 Mdot
.42394 .44568 Mdot
.18882 .55509 Mdot
.27787 .51615 Mdot
.31664 .69943 Mdot
.71763 .411 Mdot
.49275 .34992 Mdot
.7922 .62945 Mdot
.34938 .33707 Mdot
.42295 .5388 Mdot
.41257 .70391 Mdot
.17227 .39822 Mdot
.28424 .38134 Mdot
.3959 .38867 Mdot
.29549 .3932 Mdot
.70167 .74875 Mdot
.85133 .45764 Mdot
.42683 .53115 Mdot
.5678 .76555 Mdot
.50647 .26868 Mdot
.38698 .25146 Mdot
.1983 .58679 Mdot
.5245 .91738 Mdot
.56574 .18061 Mdot
.45152 .70952 Mdot
.2702 .68559 Mdot
.50894 .36161 Mdot
.21121 .33255 Mdot
.79889 .45221 Mdot
.6753 .38399 Mdot
.69912 .76819 Mdot
.47351 .36527 Mdot
.33164 .48546 Mdot
.68033 .24555 Mdot
.36709 .19401 Mdot
.79849 .63268 Mdot
.29302 .23439 Mdot
.44006 .45924 Mdot
.39467 .52213 Mdot
.74808 .77263 Mdot
.28254 .27081 Mdot
.42773 .4234 Mdot
.67214 .77581 Mdot
.4751 .67762 Mdot
.35101 .49317 Mdot
.69487 .56608 Mdot
.53651 .27416 Mdot
.46028 .24495 Mdot
.23879 .28516 Mdot
.38585 .64916 Mdot
.72886 .43151 Mdot
.59345 .57446 Mdot
.53286 .43173 Mdot
.30244 .45564 Mdot
.57418 .58907 Mdot
.43188 .25299 Mdot
.5093 .45663 Mdot
.63124 .58647 Mdot
.55201 .27812 Mdot
.72916 .25916 Mdot
.26996 .48983 Mdot
.50919 .60647 Mdot
.34975 .36345 Mdot
.37459 .61605 Mdot
.40376 .28089 Mdot
.3826 .27138 Mdot
.61881 .21303 Mdot
.6608 .18154 Mdot
.60907 .47102 Mdot
.34152 .52649 Mdot
.37326 .65805 Mdot
.26422 .56901 Mdot
.24026 .44728 Mdot
.63934 .58408 Mdot
.78056 .56023 Mdot
.43559 .4589 Mdot
.42026 .54039 Mdot
.61542 .62193 Mdot
.13046 .50079 Mdot
.39122 .50937 Mdot
.2287 .55945 Mdot
.41874 .18233 Mdot
.68663 .37906 Mdot
.2654 .47107 Mdot
.36478 .40858 Mdot
.39857 .7607 Mdot
.50531 .4718 Mdot
.48552 .41577 Mdot
.65935 .3722 Mdot
.22171 .32877 Mdot
.31964 .541 Mdot
.22346 .51807 Mdot
.38605 .45517 Mdot
.59702 .37076 Mdot
.49402 .75736 Mdot
.18295 .57706 Mdot
.40523 .56684 Mdot
.43569 .16659 Mdot
.63563 .35305 Mdot
.58359 .27326 Mdot
.26038 .43295 Mdot
.18078 .41779 Mdot
.6464 .75819 Mdot
.23982 .46634 Mdot
.54871 .80286 Mdot
.66653 .56865 Mdot
.40895 .2879 Mdot
.64185 .48799 Mdot
.37893 .53777 Mdot
.4769 .65433 Mdot
.18777 .32618 Mdot
.1905 .58945 Mdot
.56127 .57128 Mdot
.61507 .39585 Mdot
.31032 .55723 Mdot
.52999 .43559 Mdot
.87583 .43938 Mdot
.80989 .42881 Mdot
.16194 .40074 Mdot
.44756 .22935 Mdot
.37046 .67945 Mdot
.59187 .72393 Mdot
.32399 .39233 Mdot
.65469 .4767 Mdot
.21461 .3318 Mdot
.37637 .54891 Mdot
.68045 .70767 Mdot
.35404 .49965 Mdot
.50839 .80092 Mdot
.4842 .48605 Mdot
.70718 .48061 Mdot
.70443 .44419 Mdot
.6245 .79583 Mdot
.39926 .203 Mdot
.50357 .4777 Mdot
.84608 .39987 Mdot
.22559 .38291 Mdot
.31009 .23864 Mdot
.66185 .49684 Mdot
.53577 .83331 Mdot
.44474 .59533 Mdot
.47645 .50032 Mdot
.59615 .55826 Mdot
.3413 .3538 Mdot
.60807 .73104 Mdot
.40432 .24467 Mdot
.49489 .72629 Mdot
.51063 .62498 Mdot
.78456 .25104 Mdot
.44712 .26917 Mdot
.40155 .57922 Mdot
.64794 .71014 Mdot
.29649 .23975 Mdot
.6062 .32201 Mdot
.71124 .25616 Mdot
.64966 .52367 Mdot
.31214 .48228 Mdot
.35889 .60776 Mdot
.25817 .38652 Mdot
.65643 .65011 Mdot
.34198 .8064 Mdot
.63692 .24449 Mdot
.58832 .27938 Mdot
.62229 .5278 Mdot
.44672 .69389 Mdot
.45016 .70651 Mdot
.77561 .4283 Mdot
.77722 .30647 Mdot
.48545 .45026 Mdot
.26779 .29198 Mdot
.42128 .8408 Mdot
.48957 .23142 Mdot
.21719 .31541 Mdot
.52278 .6483 Mdot
.46135 .6135 Mdot
.4035 .27579 Mdot
.55756 .38366 Mdot
.69138 .43381 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0Z?ooool2o`0009oooooo000Looooo`03o`000?oooooooooo0:Sooooo0_l0
002Oooooo`007?ooool00ol0003oooooooooo`2`ooooo`;o0000Uoooool001cooooo00?o0000oooo
ooooool0Xoooool2o`0000_ooooo0_l0002Gooooo`007?ooool2o`0009kooooo0_l00004ooooo`;o
0000Y?ooool001cooooo00?o0000ooooooooool0WOooool2o`000:[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0Uoooool2o`000;3ooooo000Loooo
o`03o`000?oooooooooo09;ooooo0_l00002ooooo`?o0000/?ooool001cooooo00?o0000oooooooo
ool0P_ooool3o`0000Sooooo0_l00003ooooo`;o00000_ooool2o`0002Gooooo0_l0002:ooooo`00
7?ooool00ol0003oooooooooo`22ooooo`?o00002?ooool2o`0002kooooo0_l0002:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`37ooooo`;o
0000P?ooool001cooooo00?o0000ooooooooool0aoooool2o`00083ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`2@ooooo`;o0000]oooool001cooooo00?o0000ooooooooool0Qoooool2o`0000Oo
oooo0_l000000ooooooo0000o`00002dooooo`007?ooool00ol0003oooooooooo`1mooooo`;o0000
2?ooool2o`0000[ooooo0_l000001?oooooo0000o`000?l0002`ooooo`007?ooool2o`0006Sooooo
0_l0000Dooooo`;o00005_ooool4o`000;3ooooo000Looooo`03o`000?oooooooooo06Oooooo0_l0
000/ooooo`;o00001_ooool2o`000:[ooooo000Looooo`03o`000?oooooooooo08Kooooo0_l00003
ooooo`;o00004?ooool2o`000:[ooooo000Looooo`03o`000?oooooooooo08Kooooo0_l00003oooo
o`;o00002Oooool2o`000003ooooool0003o000000;o000000Coooooo`000?l0003o0000Z?ooool0
01cooooo00?o0000ooooooooool0U_ooool2o`000003ooooool0003o000000;o000000Coooooo`00
0?l0003o0000=_ooool2o`00073ooooo000Looooo`03o`000?oooooooooo07cooooo0_l00005oooo
o`;o00001Oooool2o`0000;ooooo0_l0000<ooooo`;o000000?oooooo`000?l00000=_ooool2o`00
073ooooo000Looooo`03o`000?oooooooooo07cooooo0_l00005ooooo`;o00001Oooool6o`000003
ooooool0003o000000;o00001oooool2o`000003ooooool0003o00000:Sooooo000Looooo`03o`00
0?oooooooooo07kooooo0_l0000;ooooo`Co00000_ooool4o`0000Sooooo0_l00005ooooo`;o0000
3?ooool2o`0009Gooooo000Looooo`03o`000?oooooooooo07Sooooo0_l00004ooooo`?o00006?oo
ool2o`0000;ooooo0_l00004ooooo`?o00003?ooool2o`0009Gooooo000Looooo`03o`000?oooooo
oooo07Sooooo0_l00005ooooo`;o00002_ooool4o`0000[ooooo0_l00003ooooo`;o00000oooool4
o`0000gooooo0_l0000Mooooo`;o0000M?ooool001cooooo00?o0000ooooooooool0Q?ooool2o`00
00Gooooo1?l0000?ooooo`;o00001Oooool4o`000004ooooool0003o0000ooooo`Co00000oooool2
o`0000Oooooo0_l0000Dooooo`;o00003_ooool2o`0006Cooooo000Looooo`03o`000?oooooooooo
08Cooooo1?l00002ooooo`;o00004_ooool2o`0000Cooooo1Ol000001?oooooo0000o`000?ooool4
o`000003ooooool0003o000000?ooooo0_l00004ooooo`;o00009?ooool2o`0006Cooooo000Loooo
o`03o`000?oooooooooo07?ooooo0_l0000;ooooo`;o00000_ooool4o`0000;ooooo0_l00008oooo
o`;o00003_ooool4o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o00000oooool3o`00
0003ooooool0003o000008cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44
ooooo`Go00001_ooool00ol0003oooooooooo`1cooooo`;o00001oooool2o`0000;ooooo0_l00002
ooooo`;o00000oooool2o`0000Wooooo0_l00007ooooo`;o000000?oooooo`000?l000001?ooool2
o`0000;ooooo0_l000000ooooooo0000o`000009ooooo`;o000000Coooooo`000?l0003ooooo0_l0
0029ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Q
onk^k_ooooooA4A400Kooooo00?o0000ooooooooool0M?ooool2o`0000Kooooo0_l00002ooooo`;o
00001oooool2o`0000;ooooo0ol0000=ooooo`;o000000?oooooo`000?l000002?ooool2o`0000Go
oooo0_l00003ooooo`;o000000?oooooo`000?l000001Ol00029ooooo`0000?ooooooa0@4?ooool0
0_ooool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0
J?ooool2o`0000[ooooo0ol00009ooooo`;o00002oooool3o`0000Wooooo1?l00004ooooo`;o0000
2oooool2o`000003ooooool0003o000000;o000000Coooooo`000?l0003ooooo1_l0000Cooooo`;o
0000MOooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Q
onk^kP06ooooo`?o0000J?ooool2o`0000Kooooo0ol000001?oooooo0000o`000?l00002ooooo`;o
00000oooool2o`0000gooooo0_l0000:ooooo`Co00001?ooool2o`0000_ooooo0_l00003ooooo`;o
00002Oooool2o`0000Cooooo0_l0000<ooooo`;o0000MOooool00003ooooool0003ooooo00;ooooo
00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo06Sooooo
0_l00006ooooo`Oo00000_ooool2o`0000?ooooo1?l0000@ooooo`;o00000_ooool2o`0000?ooooo
0_l00008ooooo`;o00001oooool2o`0000Gooooo0_l000000ooooooo0000o`000004ooooo`;o0000
00Coooooo`000?l0003ooooo0_l00002ooooo`;o0000Ooooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06cooooo
0_l00005ooooo`?o00002_ooool2o`0000?ooooo0_l0000;ooooo`;o00000_ooool2o`0000Sooooo
0_l000000ooooooo0000o`000002o`0000Oooooo0_l00005ooooo`;o000000?oooooo`000?l00000
1oooool2o`0000Gooooo0_l0001oooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05
o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`1/ooooo`;o00001_ooool3o`00
00Gooooo0_l00007ooooo`Co00001_ooool2o`0000oooooo0_l000000ooooooo0000o`00000=oooo
o`;o00006?ooool2o`0007_ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo073ooooo0_l00002ooooo`?o00001Ooo
ool2o`0000Wooooo0_l00006ooooo`;o00008Oooool2o`0000;ooooo0_l0000<ooooo`?o00001Ooo
ool2o`0007_ooooo000Looooo`03o`000?oooooooooo06Gooooo0_l00009ooooo`;o00000_ooool2
o`00013ooooo0_l00003ooooo`;o00006Oooool2o`0000;ooooo0_l00008ooooo`Co00003?ooool5
o`00083ooooo000Looooo`03o`000?oooooooooo05oooooo0_l00004ooooo`;o00001_ooool2o`00
00Cooooo0ol00009ooooo`;o00001Oooool2o`0000?ooooo0_l00009ooooo`;o00000_ooool2o`00
00[ooooo0_l00002ooooo`;o00000oooool2o`0000?ooooo0_l0000>ooooo`;o000000?oooooo`00
0?l00000P?ooool001cooooo00?o0000ooooooooool0Goooool2o`0000cooooo0_l00004ooooo`;o
00000oooool2o`0000Gooooo0_l0000Aooooo`;o00000_ooool2o`0000;ooooo0ol00009ooooo`;o
00001oooool4o`0000Gooooo0_l0000:ooooo`?o00001Oooool3o`0007[ooooo000Looooo`03o`00
0?oooooooooo07Sooooo0_l000000ooooooo0000o`00000Eooooo`;o00001oooool2o`0000Wooooo
0_l00008ooooo`?o00001Oooool4o`0000Sooooo0ol00005ooooo`?o0000N_ooool001cooooo00?o
0000ooooooooool0J?ooool2o`0000;ooooo0_l0000:ooooo`;o000000Coooooo`000?l0003o0000
1oooool4o`0000Gooooo0_l0000Aooooo`;o00000oooool2o`0000Sooooo0_l00005ooooo`Go0000
5oooool2o`0007Cooooo000Looooo`03o`000?oooooooooo05cooooo0_l0000:ooooo`;o00000_oo
ool2o`0000Wooooo0_l00003ooooo`;o00001oooool4o`0000Gooooo0_l000000ooooooo0000o`00
0003ooooo`Co000000?oooooo`000?l000000oooool3o`0000?ooooo0_l00007ooooo`;o000000?o
ooooo`000?l000000oooool3o`0001Sooooo0ol000000ooooooo0000o`00001aooooo`007?ooool0
0ol0003oooooooooo`1Hooooo`Ko00001oooool2o`000003ooooool0003o000000Gooooo0_l00000
0ooooooo0000o`000003ooooo`;o00001oooool2o`0000Gooooo0_l00006ooooo`Co00000oooool4
o`000003ooooool0003o000000;o000000?oooooo`000?l000001oooool2o`0000?ooooo0ol00000
1?oooooo0000o`000?l0000Dooooo`;o00001oooool2o`0000;ooooo0_l0000<ooooo`;o0000Hooo
ool001cooooo00?o0000ooooooooool0Eoooool8o`0000;ooooo1_l000000ooooooo0000o`000005
ooooo`;o000000?oooooo`000?l000003?ooool2o`0000gooooo0_l0000<ooooo`;o00002_ooool2
o`0000?ooooo0_l00003ooooo`;o00004_ooool4o`0001Wooooo0_l0001Sooooo`007?ooool00ol0
003oooooooooo`1Gooooo`;o00001?ooool8o`00023ooooo0_l00004ooooo`;o00000_ooool2o`00
01Kooooo0_l00003ooooo`;o00001?ooool4o`0000;ooooo0_l0000=ooooo`;o0000P?ooool001co
oooo00?o0000ooooooooool0E_ooool2o`0000Oooooo0ol0000Nooooo`;o00000oooool2o`0000Co
oooo0_l00002ooooo`;o000000?oooooo`000?l000001?l000000ooooooo0000o`00000<ooooo`Co
000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000006o`000004ooooool0003o0000
ooooo`;o00002oooool2o`0000cooooo1?l00002ooooo`;o0000J?ooool001cooooo00?o0000oooo
ooooool0E_ooool2o`000003ooooool0003o000001gooooo0_l00006ooooo`;o00002Oooool2o`00
00Gooooo1_l000000ooooooo0000o`000007ooooo`;o00001Oooool2o`0000Cooooo0_l00005oooo
o`Oo000000?oooooo`000?l000002oooool2o`0000cooooo1?l00002ooooo`;o0000J?ooool001co
oooo0_l0001Jooooo`;o000000?oooooo`000?l000006_ooool4o`0000Cooooo0_l00009ooooo`;o
00001Oooool2o`0000kooooo0_l000000ooooooo0000o`000002ooooo`Go000000?oooooo`000?l0
00002Oooool2o`0000?ooooo0_l0000:ooooo`;o00000_ooool2o`00017ooooo0_l0000Gooooo`;o
0000C?ooool001cooooo00?o0000ooooooooool0G?ooool2o`0000_ooooo0_l0000>ooooo`?o0000
1?ooool2o`0000?ooooo0_l00002ooooo`;o00006_ooool2o`0000;ooooo1Ol0000<ooooo`;o0000
0oooool2o`0000;ooooo0_l00006ooooo`;o00000_ooool2o`00017ooooo0_l0000Gooooo`;o0000
C?ooool001cooooo00?o0000ooooooooool0J?ooool3o`0000Cooooo0_l00008ooooo`Go00001ooo
ool2o`0000;ooooo0_l0000[ooooo`;o00002oooool2o`0000gooooo0_l0000>ooooo`?o0000I?oo
ool001cooooo00?o0000ooooooooool0E?ooool2o`0001;ooooo0_l00005ooooo`Co00000_ooool3
o`0000?ooooo0ol0000Cooooo`;o00000oooool3o`0000Gooooo0_l00003ooooo`Co00003?ooool2
o`000003ooooool0003o000001[ooooo0_l00003ooooo`;o00001Oooool3o`0000;ooooo0_l00004
ooooo`?o0000GOooool001cooooo00?o0000ooooooooool0Doooool3o`000003ooooool0003o0000
01Kooooo1?l00002ooooo`?o00006Oooool2o`0000?ooooo0ol000000ooooooo0000o`000002oooo
o`;o00000oooool4o`0000cooooo1?l00004ooooo`;o00006Oooool3o`0000Gooooo0ol00008oooo
o`?o0000GOooool001cooooo00?o0000ooooooooool0Doooool2o`0000;ooooo0_l0000>ooooo`;o
00001?ooool6o`0000Kooooo0_l00002ooooo`;o00003_ooool2o`0000Sooooo0_l000000ooooooo
0000o`000004ooooo`;o00004?ooool2o`000003ooooool0003o000000Cooooo1?l0000Fooooo`?o
0000LOooool001cooooo00?o0000ooooooooool0C?ooool2o`0000Oooooo0_l000000ooooooo0000
o`00000=ooooo`;o00001?ooool3o`0000Wooooo0_l00002ooooo`;o00003_ooool2o`0000Cooooo
0_l0000;ooooo`?o00002_ooool2o`0000;ooooo0ol00009ooooo`;o00005_ooool2o`000003oooo
ool0003o000000Oooooo1?l0001Tooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00001ooo
ool2o`000003ooooool0003o000001Cooooo0_l00009ooooo`;o00004_ooool2o`0000Cooooo0_l0
0002ooooo`;o00001?ooool6o`0000Gooooo0_l00003ooooo`;o00000_ooool4o`0000Gooooo0_l0
0006ooooo`;o00005?ooool2o`0000Oooooo1_l00004ooooo`;o0000G?ooool001cooooo00?o0000
ooooooooool0Hoooool2o`0001Cooooo0_l00004ooooo`;o00003oooool2o`0000Gooooo0_l00004
ooooo`Co00001oooool5o`0000Kooooo0ol00004ooooo`;o00000oooool2o`000003ooooool0003o
000001gooooo0ol000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000Cooooo0_l0
001Fooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00000_ooool2o`0000gooooo0_l00007
ooooo`;o00004Oooool2o`0000_ooooo0_l000001?oooooo0000o`000?l0000<ooooo`?o000000?o
ooooo`000?l000001?ooool5o`0000?ooooo0_l00002ooooo`;o00001?ooool3o`0000;ooooo0_l0
000Qooooo`Co00000_ooool2o`0000Cooooo1Ol0000Aooooo`;o0000@oooool001cooooo00?o0000
ooooooooool0D?ooool2o`0000;ooooo0_l00003ooooo`?o00001?ooool2o`0000Oooooo0_l00000
0ooooooo0000o`00000Aooooo`?o00002_ooool2o`000003ooooool0003o000000kooooo0_l00000
1?oooooo0000o`000?l00002ooooo`;o00001oooool2o`0000Wooooo0_l00002ooooo`;o00003ooo
ool2o`00013ooooo1?l00008ooooo`Ko00004?ooool2o`0004?ooooo000Looooo`03o`000?oooooo
oooo04Oooooo0_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000001Oooool3
o`0000;ooooo1Ol00006ooooo`;o00003Oooool2o`0000Gooooo1?l0000Cooooo`;o00001oooool2
o`0000;ooooo0_l00002ooooo`;o00003oooool2o`0000Gooooo0_l0000?ooooo`;o00008?ooool2
o`0005Gooooo000Looooo`03o`000?oooooooooo04Oooooo1Ol00003ooooo`;o000000?oooooo`00
0?l000001_ooool2o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o00004?ooool2o`00
00Kooooo0ol0000Cooooo`?o00001?ooool4o`0001Gooooo1ol0002<ooooo`007?ooool00ol0003o
ooooooooo`18ooooo`;o00001?ooool7o`0000Gooooo0_l0000:ooooo`Co00005_ooool3o`00013o
oooo0ol000000ooooooo0000o`000004ooooo`;o00000_ooool2o`0000;ooooo0_l0000:ooooo`;o
000000?oooooo`000?l000000_l000000ooooooo0000o`000002o`0001Sooooo1Ol0000Jooooo`;o
0000Doooool001cooooo00?o0000ooooooooool0Boooool7o`000003ooooool0003o000001?ooooo
0ol0000?ooooo`Co00003oooool2o`0000?ooooo1?l00004ooooo`;o00001Oooool2o`0000;ooooo
0_l00008ooooo`Oo00007oooool5o`0001[ooooo0ol0001Booooo`007?ooool00ol0003ooooooooo
o`1;ooooo`Co00000oooool2o`00017ooooo0_l00002ooooo`;o00003oooool4o`0000oooooo0_l0
0003ooooo`;o00001_ooool3o`0000Gooooo0_l00002ooooo`;o00001oooool3o`000003ooooool0
003o000001_ooooo0_l00009ooooo`;o00001_ooool2o`00013ooooo0_l0001Booooo`007?ooool2
o`0004[ooooo0_l00007ooooo`;o00004Oooool2o`0001Sooooo0_l0000Dooooo`;o00001?ooool2
o`0000Gooooo0_l000001?oooooo0000o`000?l00008ooooo`;o00007_ooool2o`0000Wooooo0_l0
0006ooooo`;o00000_ooool2o`0000Oooooo0_l0000Dooooo`;o0000@Oooool001cooooo00?o0000
ooooooooool0?oooool2o`0000Sooooo0_l0000:ooooo`;o00002oooool2o`0000oooooo0_l0000:
ooooo`;o00005?ooool2o`000003ooooool0003o000000Co00001Oooool5o`0000Wooooo0_l00002
ooooo`?o0000;oooool3o`0000;ooooo0_l00002ooooo`;o00001_ooool2o`0000cooooo0_l00011
ooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00003?ooool2o`0000Kooooo0_l0000;oooo
o`;o00001_ooool2o`0000?ooooo0_l00002ooooo`?o00000oooool2o`0001?ooooo0_l00008oooo
o`Ko00001Oooool2o`000003ooooool0003o000000Wooooo0_l000000ooooooo0000o`000006o`00
00Cooooo0_l0000<ooooo`;o00001?ooool2o`0000;ooooo1?l0000<ooooo`;o00000_ooool2o`00
00[ooooo0ol0001>ooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00001_ooool4o`00017o
oooo0_l00003ooooo`;o00000oooool2o`0000?ooooo0_l0000Cooooo`;o00000_ooool2o`0000;o
oooo1Ol0000;ooooo`;o00000oooool2o`000003ooooool0003o000000go00000oooool2o`0000co
oooo0_l00004ooooo`;o00000_ooool4o`0000Wooooo0_l0000Booooo`;o0000C_ooool001cooooo
00?o0000ooooooooool0>oooool2o`0000Kooooo0_l0000=ooooo`;o000000?oooooo`000?l00000
0_l0000Aooooo`;o00002?ooool2o`0000;ooooo0_l0000?ooooo`;o00000_ooool4o`000003oooo
ool0003o000000;ooooo0_l0000Cooooo`;o000000?oooooo`000?l000003Ol000000ooooooo0000
o`000003ooooo`;o00000oooool3o`0001[ooooo0_l0001Rooooo`007?ooool00ol0003ooooooooo
o`0kooooo`;o00001?ooool4o`0000gooooo1Ol0000Fooooo`;o00002?ooool3o`0000?ooooo0_l0
0005ooooo`;o00000oooool2o`0000;ooooo1?l00002ooooo`;o00000_ooool4o`000003ooooool0
003o0000013ooooo3ol000001?oooooo0000o`000?l00002ooooo`;o00000oooool3o`0000Kooooo
0_l0001fooooo`007?ooool00ol0003oooooooooo`11ooooo`Co00000_ooool2o`0000;ooooo0_l0
0006ooooo`Co00005_ooool2o`0000Sooooo0_l00004ooooo`;o000000?oooooo`000?l000000_oo
ool2o`0000Cooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00002ooooo`Co000000?o
ooooo`000?l000003_oooolAo`0000;ooooo0_l00004ooooo`;o00001_ooool3o`000003ooooool0
003o0000023ooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00003?ooool2
o`0000;ooooo0_l0000Booooo`;o00001oooool2o`0000Oooooo0_l0000=ooooo`;o000000Cooooo
o`000?l0003ooooo0_l00002ooooo`?o00000_ooool2o`0000;ooooo0_l00004ooooo`?o00001?oo
ool2o`0000[ooooo4ol00002ooooo`;o00000_ooool2o`0000Kooooo0ol0000Dooooo`;o00001ooo
ool2o`0000Cooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00002Oooool2
o`0001Wooooo0_l00007ooooo`;o00001?ooool2o`000004ooooool0003o0000o`0000oooooo0_l0
00000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000002?ooool4o`0000Cooooo0_l0
000<oooooa7o00000_ooool4o`0001oooooo0_l00007ooooo`;o00000_ooool2o`0000Cooooo0_l0
0003ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0>Oooool2o`0000Wooooo0_l0000<
ooooo`;o00004Oooool2o`0000Oooooo0_l00002ooooo`;o00003Oooool2o`0000Oooooo1_l00000
0ooooooo0000o`000005ooooo`Co00002Oooool3o`0000Kooooo1ol00002ooooo`Wo000000?ooooo
o`000?l000000_l0000>ooooo`;o00003oooool2o`0000Sooooo0_l000000ooooooo0000o`000004
ooooo`;o00000oooool2o`0004_ooooo000Looooo`03o`000?oooooooooo03_ooooo0_l00005oooo
o`Co00002oooool3o`0000[ooooo0_l00005ooooo`;o00006_ooool2o`000003ooooool0003o0000
00Cooooo1?l00003ooooo`;o00001_ooool2o`0000Gooooo0_l00003ooooo`?o00001?oooolDo`00
00Cooooo0_l0000=ooooo`;o00002Oooool2o`0000Oooooo0_l00005ooooo`;o00007Oooool2o`00
03[ooooo000Looooo`03o`000?oooooooooo03_ooooo0_l00003ooooo`Co00003Oooool2o`0000_o
oooo0_l0000Iooooo`;o00001_ooool2o`000003ooooool0003o000000cooooo0_l00005ooooo`;o
00001Oooool2o`0000[ooooo6_l0000Hooooo`;o00000oooool2o`0000;ooooo0_l0000@ooooo`;o
00004_ooool2o`0003[ooooo000Looooo`03o`000?oooooooooo043ooooo0ol00006ooooo`;o0000
8oooool2o`0000Wooooo0_l00003ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Sooooo
0_l00005ooooo`;o00000oooool2o`0000gooooo5ol0000Iooooo`;o00001?ooool2o`00013ooooo
0_l00002ooooo`;o00001Oooool2o`0004Oooooo000Looooo`03o`000?oooooooooo04Wooooo0_l0
000>ooooo`;o00004oooool2o`0000Oooooo0_l00004ooooo`?o00002?ooool2o`0000Gooooo0_l0
0007ooooo`;o00001?ooool2o`0000gooooo0ol000000ooooooo0000o`00000@o`0001[ooooo0_l0
0002ooooo`;o00000_ooool2o`0000Sooooo0_l00004ooooo`;o00001Oooool2o`0000;ooooo0_l0
0017ooooo`007?ooool00ol0003oooooooooo`1Iooooo`?o00005Oooool2o`0000Cooooo1?l00002
ooooo`;o00002?ooool4o`0000Cooooo0_l00007ooooo`;o00004ooooolFo`0001kooooo0ol00000
0ooooooo0000o`000008ooooo`;o00002oooool2o`0004_ooooo000Looooo`03o`000?oooooooooo
05Kooooo0_l00002ooooo`;o00005Oooool3o`000003ooooool0003o000000;ooooo0_l0000<oooo
o`Co00001Oooool2o`00017ooooo0_l00008oooooaGo00002Oooool2o`0001Gooooo0_l0000Ioooo
o`;o00000_ooool2o`0004Kooooo000Looooo`;o0000A?ooool2o`0000;ooooo0_l0000=ooooo`;o
00001Oooool2o`0000oooooo0_l00002ooooo`;o000000?oooooo`000?l000001_l00003ooooo`Co
00001_ooool2o`0000Cooooo0_l0000:ooooo`;o00001Oooool3o`000004ooooool0003o0000oooo
o`;o00000_oooolBo`0000Wooooo1?l0000Dooooo`?o00000_ooool2o`0000Kooooo0_l0000=oooo
o`;o00000_ooool2o`0004Kooooo000Looooo`03o`000?oooooooooo04?ooooo0_l00002ooooo`;o
00001_ooool2o`0000Cooooo0ol00005ooooo`;o00002_ooool4o`000003ooooool0003o000000Ko
oooo1ol00003ooooo`Ko00001?ooool4o`0000Wooooo2?l00004ooooo`?o000000Coooooo`000?l0
003ooooo1?l000000ooooooo0000o`00000?o`0000Gooooo0_l00002ooooo`Co00005?ooool2o`00
00?ooooo0_l00006ooooo`Co0000Eoooool001cooooo00?o0000ooooooooool0Boooool2o`0000;o
oooo0_l00004ooooo`;o00000_ooool2o`0000Oooooo0_l00005ooooo`Co00005?ooool2o`000003
ooooool0003o000000;o00001?ooool2o`0000Wooooo1Ol000000ooooooo0000o`000004ooooo`Co
00001Oooool2o`000003ooooool0003o000000oo00001Oooool2o`0000Cooooo0_l0000Hooooo`;o
00001?ooool2o`0000?ooooo0ol0001Fooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o0000
6oooool2o`0000Cooooo0_l00006ooooo`;o00001oooool2o`0000gooooo0_l0000Cooooo`;o0000
0_ooool6o`0000Kooooo0_l00005ooooo`;o00000_ooool2o`0000;ooooo0_l00006oooooaCo0000
2_ooool2o`000004ooooool0003o0000o`0001Cooooo0_l00004ooooo`;o00001?ooool2o`0000oo
oooo0_l00015ooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00005?ooool2o`0000;ooooo
0_l00007ooooo`;o00001?ooool2o`0001Cooooo0_l00002ooooo`;o00002_ooool2o`0000Gooooo
0_l00003ooooo`Wo00001?ooool3o`0000Sooooo0ol00009oooooaCo00002_ooool2o`000004oooo
ool0003o0000o`0001Gooooo0_l000001?oooooo0000o`000?ooool2o`0000Kooooo0_l00009oooo
o`;o000000?oooooo`000?l00000AOooool001cooooo00?o0000ooooooooool0=?ooool2o`0000Ko
oooo0_l00006ooooo`;o00000_ooool2o`0000gooooo0_l0000>ooooo`;o00001?ooool4o`000003
ooooool0003o000000Gooooo0_l00002ooooo`;o00001Oooool3o`0000;ooooo1_l000000ooooooo
0000o`000002ooooo`Go00001oooool6o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l0
00004Ol00005ooooo`;o00004Oooool2o`0000Sooooo0_l000001?oooooo0000o`000?ooool2o`00
00Kooooo0_l00009ooooo`Co0000A_ooool001cooooo00?o0000ooooooooool0=?ooool2o`0000Ko
oooo0_l0000Yooooo`;o00001Oooool3o`000003ooooool0003o000000Gooooo0_l0000:ooooo`;o
00001?ooool5o`000004ooooool0003o0000ooooo`Co00002?ooool2o`0000;ooooo0_l00002oooo
o`;o00001?ooool2o`000003ooooool0003o0000017o00001Oooool2o`0000Kooooo0_l00009oooo
o`;o00002?ooool2o`000003ooooool0003o000001Kooooo0_l00016ooooo`007?ooool00ol0003o
ooooooooo`0kooooo`;o00009_ooool2o`0000;ooooo0_l0000;ooooo`;o00000_ooool2o`00013o
oooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000007oooo
o`;o00000_ooool3o`0000?ooooo0_l00005ooooo`?o000000?oooooo`000?l000002Ol0000<oooo
o`;o00000_ooool4o`0000Sooooo0_l0000;ooooo`;o00006_ooool2o`0000Kooooo0_l0000joooo
o`007?ooool00ol0003oooooooooo`0kooooo`;o00000oooool2o`0000Oooooo1?l0000Fooooo`;o
000000Goooooo`000?l0003o0000ooooo`02o`0000Sooooo0_l00002ooooo`;o00000oooool2o`00
00Sooooo0_l000001?oooooo0000o`000?l00004ooooo`So00001oooool2o`0000;ooooo0ol00003
ooooo`;o00002Oooool5o`000003ooooool0003o000000?o00003?ooool2o`0000;ooooo1?l00002
ooooo`;o00001?ooool2o`0000oooooo0_l0000Fooooo`;o00001_ooool2o`0003[ooooo000Loooo
o`03o`000?oooooooooo03Cooooo0_l000000ooooooo0000o`000007ooooo`;o00001oooool4o`00
01Wooooo0_l000001?oooooo0000o`000?l00003ooooo`;o00003?ooool2o`0000Sooooo0_l00000
1?oooooo0000o`000?l00004ooooo`Ko00002Oooool2o`0000;ooooo0_l000000ooooooo0000o`00
0005ooooo`;o00001Oooool2o`0000Cooooo1Ol0000Fooooo`;o00000_ooool2o`00017ooooo0_l0
001Jooooo`007?ooool00ol0003oooooooooo`0dooooo`;o000000?oooooo`000?l000000_l00002
ooooo`;o00006_ooool2o`0000?ooooo0_l00009ooooo`;o00001?ooool2o`0000Kooooo0_l0000:
ooooo`;o00000oooool4o`0000gooooo0_l00003ooooo`;o00001?ooool2o`000003ooooool0003o
000000Cooooo0ol000000ooooooo0000o`000008ooooo`Oo000000?oooooo`000?l000000_ooool3
o`000003ooooool0003o000000Wooooo0_l00002ooooo`Co00003_ooool2o`0000oooooo0_l0000G
ooooo`;o0000<Oooool001cooooo00?o0000ooooooooool0>Oooool2o`0000;ooooo0_l00002oooo
o`;o00000oooool2o`0000Oooooo0_l00008ooooo`;o00000oooool2o`0000Sooooo0_l00005oooo
o`;o000000?oooooo`000?l000000_ooool3o`0000Wooooo1Ol000000ooooooo0000o`00000?oooo
o`;o00000oooool2o`0000Cooooo0ol00005ooooo`?o000000Coooooo`000?l0003o00002?ooool2
o`0000?ooooo0_l000000ooooooo0000o`000005o`000003ooooool0003o000000_ooooo0_l00000
1?oooooo0000o`000?l0000>ooooo`;o00003Oooool4o`0001Oooooo0_l0000aooooo`007?ooool0
0ol0003oooooooooo`0gooooo`;o00002?ooool4o`000003ooooool0003o000000?ooooo0_l00002
ooooo`?o00004_ooool2o`0000;ooooo0_l00008ooooo`;o00000_ooool2o`0000[ooooo0_l00000
0ooooooo0000o`00000;ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Sooooo0_l00000
1?oooooo0000o`000?ooool3o`0000;ooooo0ol00008ooooo`Co00001Oooool4o`000003ooooool0
003o000000;o00001oooool2o`0000;ooooo0_l00007ooooo`?o000000?oooooo`000?l000005?oo
ool2o`0004cooooo000Looooo`03o`000?oooooooooo03Oooooo0_l0000:ooooo`;o00000oooool2
o`000003ooooool0003o000000?ooooo0_l00003ooooo`?o00003?ooool3o`0000Cooooo0ol00005
ooooo`;o000000?oooooo`000?l000001Oooool2o`0000cooooo0_l00005ooooo`;o000000?ooooo
o`000?l000001?ooool4o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l000003Oooool5
o`0000Oooooo0_l000000ooooooo0000o`000002o`0000Oooooo0_l00005ooooo`;o00000_ooool5
o`000003ooooool0003o000000Gooooo0_l0000Cooooo`;o0000A_ooool00006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oo
oooooooo04Sooooo0_l00007ooooo`;o00000_ooool3o`0000Cooooo0_l00003ooooo`;o00000_oo
ool3o`0000?ooooo0ol000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000001?oo
ool5o`0000?ooooo1?l00003ooooo`;o00002oooool2o`0000;ooooo0ol00002ooooo`;o00003?oo
ool2o`0000Wooooo0_l00002ooooo`;o00001Oooool2o`0000_ooooo0_l00007ooooo`;o00000_oo
ool2o`0000_ooooo1?l00008ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Gooooo0_l0
0007ooooo`;o0000=_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0booooo`;o00007Oooool2o`0000Wooooo
0_l00003ooooo`Co000000?oooooo`000?l000001_ooool3o`0000Oooooo1_l000001?oooooo0000
o`000?l00002ooooo`Co00000oooool3o`0000Oooooo0_l000000ooooooo0000o`000002ooooo`;o
00002Oooool2o`0000Kooooo1?l00007ooooo`;o000000?oooooo`000?l000000_l00003ooooo`?o
00002oooool2o`0001[ooooo0_l000000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l0
00002oooool2o`0000Oooooo0_l0000fooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooo
ooooo`09ooooo`Go00001_ooool00ol0003oooooooooo`0booooo`Co00002Oooool2o`0001Wooooo
0_l00002ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o00000oooool2o`0000Gooooo
3Ol00002ooooo`;o00001Oooool3o`0000Oooooo0_l00005ooooo`;o00001oooool5o`0000Cooooo
0_l000000ooooooo0000o`000005ooooo`Co000000?oooooo`000?l000000_l00003ooooo`?o0000
2Oooool6o`0000Sooooo0_l0000Aooooo`;o00006?ooool2o`0000;ooooo0_l0000hooooo`0000?o
ooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oooooo
0ol0000aooooo`;o000000Coooooo`000?l0003ooooo0_l00006ooooo`;o00003_ooool2o`0000Wo
oooo0_l00002ooooo`;o000000?oooooo`000?l000001?ooool8o`0000?ooooo0_l000001?oooooo
0000o`000?l00005ooooo`Co00006oooool2o`0000Oooooo0_l000000ooooooo0000o`000003o`00
0003ooooool0003o000000Oooooo0ol0000:ooooo`?o00002Oooool3o`000003ooooool0003o0000
00;ooooo0_l000001?oooooo0000o`000?ooool2o`0002_ooooo0_l00002ooooo`;o0000>?ooool0
0003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo037ooooo0_l00004ooooo`Co00001?ooool2o`0000Kooooo0_l00006
ooooo`;o00000oooool2o`0000Wooooo1?l00002ooooo`Co00000_ooool;o`000004ooooool0003o
0000ooooo`;o00000oooool;o`0001_ooooo0ol000000ooooooo0000o`000002o`0000[ooooo0_l0
000:ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`;o00001_ooool2o`000003ooooool0
003o000000Kooooo0_l00004ooooo`;o00000oooool2o`0001[ooooo0_l0000mooooo`0000?ooooo
oa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000
ooooooooool0>Oooool2o`0000Cooooo0_l00006ooooo`?o00002_ooool4o`000003ooooool0003o
000000Cooooo0ol00003ooooo`Co00000oooool@o`0000?ooooo2ol0000=ooooo`;o00002oooool4
o`000003ooooool0003o000000_ooooo0_l00002ooooo`;o00001Oooool4o`0000?ooooo0_l00002
ooooo`;o00000_ooool3o`0000_ooooo0_l00003ooooo`;o00001?ooool2o`0000;ooooo0ol00002
ooooo`;o00005_ooool2o`0000cooooo0_l0000_ooooo`0000KoooooogMgMonHV9SooooooiRHV?mg
MgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0A?ooool2o`0000;ooooo0_l0
0004ooooo`;o00001_ooool2o`000003ooooool0003o000000;ooooo0_l000001?oooooo0000o`00
0?l00002ooooo`Co00000oooool>o`0000;ooooo0_l000000ooooooo0000o`000003o`000003oooo
ool0003o0000013ooooo0_l00005ooooo`;o00001?ooool2o`0000Oooooo0_l00007ooooo`;o0000
0_ooool2o`0000Gooooo0_l00004ooooo`;o000000?oooooo`000?l000000oooool6o`0000Wooooo
0_l00003ooooo`Co00001_ooool4o`000003ooooool0003o000002Cooooo0_l0000_ooooo`0000Ko
ooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000oooooooo
ool0>?ooool2o`0000[ooooo0_l00004ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo
0000o`000006ooooo`;o00000_ooool6o`0000?ooooo7Ol000000ooooooo0000o`000002ooooo`;o
00004?ooool2o`0000[ooooo0_l000000ooooooo0000o`00000?ooooo`;o00000_ooool<o`000003
ooooool0003o000000Go00000oooool2o`0000Sooooo1_l00006ooooo`;o0000F?ooool001cooooo
00?o0000ooooooooool0;_ooool3o`0000Kooooo1Ol0000>ooooo`;o00001_ooool5o`0000Kooooo
2_l00003oooooaGo000000?oooooo`000?l000001Ol000000ooooooo0000o`000002ooooo`Co0000
0_ooool2o`0000;ooooo0_l00002ooooo`;o00001?ooool2o`000003ooooool0003o000000;ooooo
0_l000001?oooooo0000o`000?ooool2o`0000oooooo2_l000000ooooooo0000o`00000@o`0000co
oooo0_l00003ooooo`?o0000F_ooool001cooooo00?o0000ooooooooool0;_ooool3o`000004oooo
ool0003o0000o`0000;ooooo1Ol0000>ooooo`Co00001Oooool2o`0000?ooooo0_l00003ooooo`Wo
000000Coooooo`000?l0003ooooo5Ol000001?oooooo0000o`000?l00002ooooo`;o00001oooool2
o`0000;ooooo0_l00002ooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`000002
ooooo`;o000000?oooooo`000?l000000ol00009ooooo`;o00000_ooool2o`0000;ooooo0_l00000
1?oooooo0000o`000?l00002ooooo`Co00000_ooool2o`000003ooooool0003o000000[o00002?oo
ool:o`000003ooooool0003o000005Oooooo000Looooo`03o`000?oooooooooo033ooooo1Ol00004
ooooo`;o00004Oooool2o`0000[ooooo0_l00003ooooo`;o00000oooool2o`000003ooooool0003o
000000?o000000?oooooo`000?l000000_oooolFo`0000;ooooo1Ol00002ooooo`Go00004Oooool2
o`0000Cooooo1?l0000:ooooo`;o00000_ooool2o`0000;ooooo0_l000001?oooooo0000o`000?l0
0002oooooaKo00001oooool7o`0000Cooooo0_l00008ooooo`;o0000COooool001cooooo00?o0000
ooooooooool0<?ooool2o`0001oooooo0_l0000:ooooo`;o00001_ooool5o`0000;ooooo2Ol00000
0ooooooo0000o`00000>o`000003ooooool0003o000000?o00000_ooool5o`0000?ooooo0_l0000<
ooooo`;o00000_ooool2o`000004ooooool0003o0000o`0000[ooooo1?l0000;oooooaWo00002Ooo
ool4o`0000gooooo0_l00003ooooo`;o00001?ooool2o`0004;ooooo000Looooo`03o`000?oooooo
oooo057ooooo0_l0000;ooooo`Co00000oooool4o`000003ooooool0003o000001[o00001?ooool2
o`0000?ooooo0_l00005ooooo`;o00004?ooool2o`000004ooooool0003o0000o`0000?ooooo0_l0
0007ooooo`;o00001oooool2o`000003ooooool0003o000000Oo000000?oooooo`000?l000003ol0
0007ooooo`Go00001oooool2o`0000;ooooo0_l00005ooooo`;o00000_ooool5o`0000Kooooo0_l0
000iooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00002_ooool2o`0000Oooooo0_l00002
ooooo`Oo000000?oooooo`000?l000007ol00005ooooo`;o00006oooool4o`0000Cooooo0_l0000:
ooooo`Go000000Coooooo`000?l0003ooooo6ol000000ooooooo0000o`00000<o`0000Cooooo0_l0
0002ooooo`;o00002Oooool2o`000003ooooool0003o000000Kooooo0_l0000iooooo`007?ooool0
0ol0003oooooooooo`0oooooo`;o00000_ooool7o`0000Oooooo0_l00007ooooo`;o00000ooooolY
o`000003ooooool0003o000000?o00000oooool2o`0001Gooooo1ol00002ooooo`;o00002_ooool5
o`0000Cooooo8_l000000ooooooo0000o`000005o`0001Cooooo0_l00013ooooo`007?ooool00ol0
003oooooooooo`0oooooo`;o000000Coooooo`000?l0003o00000_ooool3o`0000gooooo0_l00006
ooooo`;o000000?oooooo`000?l000009?l000000ooooooo0000o`000002o`0000Cooooo0_l00002
ooooo`;o00004Oooool2o`000003ooooool0003o000000;o00000_ooool2o`000003ooooool0003o
0000017ooooo7?l000000ooooooo0000o`000008ooooo`;o00005?ooool2o`0000;ooooo0ol0000>
ooooo`;o0000;_ooool001cooooo00?o0000ooooooooool0>Oooool2o`000003ooooool0003o0000
00Cooooo0_l0000Cooooo`;o00002?ooool2o`0000?ooooo1?l00002oooooa_o000000Coooooo`00
0?l0003o00001_ooool2o`0000;ooooo0_l0000Aooooo`;o00000_ooool6o`0000;ooooo0_l0000@
ooooo`_o000000?oooooo`000?l000002_l00002ooooo`;o00000_ooool2o`0000Cooooo0_l00002
ooooo`;o00006?ooool3o`0000kooooo0_l0000^ooooo`007?ooool00ol0003oooooooooo`0]oooo
o`;o00002_ooool2o`000003ooooool0003o000001Sooooo1_l00002ooooo`So000000Coooooo`00
0?l0003ooooo8Ol00007ooooo`;o00000_ooool2o`0000Wooooo0_l00005ooooo`;o00000_ooool6
o`0000?ooooo0_l0000?oooooako00001_ooool2o`0000oooooo0_l0000<ooooo`;o0000?_ooool0
01cooooo00?o0000ooooooooool0;Oooool2o`0001_ooooo0_l0000:ooooo`Ko00000_ooool8o`00
0003ooooool0003o0000027o00001_ooool4o`0000;ooooo0_l00009ooooo`;o00001Oooool2o`00
0004ooooool0003o0000ooooo`;o00000_ooool5o`00017ooooo7?l0000Gooooo`;o0000C?ooool0
01cooooo0_l0000fooooo`;o00004oooool2o`0000kooooo0ol00003ooooo`?o00000_oooolVo`00
00Gooooo0_l00003ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`;o00002?ooool3
o`000003ooooool0003o000000;ooooo1?l0000<ooooo`;o00000_ooool5o`000003ooooool0003o
000000Co000000?oooooo`000?l000004?l0000Kooooo`;o0000Aoooool001cooooo00?o0000oooo
ooooool0=Oooool2o`0001Kooooo0_l00007ooooo`;o00000oooool2o`0000;ooooo;?l00005oooo
o`?o00000_ooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0000Kooooo2?l0000A
ooooo`?o00000_ooool<o`000003ooooool0003o0000013o00002oooool2o`0000kooooo0_l00017
ooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o00007_ooool2o`0000;ooooo0_l00003oooo
o`;o00001oooool2o`0000;ooooo2?l000000ooooooo0000o`00000Oo`0000;ooooo1?l00003oooo
o`;o00002Oooool3o`0000Cooooo0_l000000ooooooo0000o`000002o`0001;ooooo0_l00002oooo
o`go000000?oooooo`000?l000003_l00007ooooo`;o00001?ooool2o`000004ooooool0003o0000
o`0000Wooooo0ol0000?ooooo`;o0000=_ooool001cooooo00?o0000ooooooooool0;Oooool3o`00
00Wooooo0_l00005ooooo`;o00003oooool2o`0000Sooooo0_l00002ooooo`;o00000_oooolZo`00
00;ooooo0_l00005ooooo`;o00002Oooool3o`0000Kooooo0ol0000:ooooo`;o00003?ooool<o`00
0003ooooool0003o000000oo000000?oooooo`000?l000001?ooool2o`0000Oooooo0ol00009oooo
o`?o00003oooool2o`0003Kooooo000Looooo`03o`000?oooooooooo02kooooo0_l00006ooooo`;o
000000?oooooo`000?l000000oooool5o`0000[ooooo0_l0000:ooooo`Co00000_ooool2o`0000Co
oooo8Ol000000ooooooo0000o`000004o`0000;ooooo0_l0000=ooooo`Co00002?ooool2o`0000_o
oooo0_l0000=ooooo`;o000000?oooooo`000?l000004_l000000ooooooo0000o`000002o`0000;o
oooo0_l0000Wooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0;Oooool3o`0000Kooooo
0_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000001oooool2o`000003oooo
ool0003o000000Oooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00003ooooo`?o0000
00?oooooo`000?l000002ol000000ooooooo0000o`00000>o`0000;ooooo1?l00002ooooo`So0000
00?oooooo`000?l000001Oooool6o`0000Kooooo0_l0000Joooooaco00000oooool2o`0002Kooooo
0_l0000jooooo`007?ooool00ol0003oooooooooo`0]ooooo`?o00002Oooool2o`0000oooooo1?l0
0004ooooo`;o00000_ooool9o`0000;ooooo0_l000001Ooooooo0000o`000?l0003ooooo01ko0000
00?oooooo`000?l000001ol000000ooooooo0000o`000003o`000003ooooool0003o000000Wooooo
0_l00003ooooo`;o000000?oooooo`000?l000004Oooool2o`0000?ooooo0_l00002oooooaWo0000
00Coooooo`000?l0003o00000_ooool2o`0000;ooooo0_l00002ooooo`;o0000F_ooool001cooooo
00?o0000ooooooooool0=?ooool2o`0000oooooo0_l00005ooooo`;o00001?ooool2o`0000Cooooo
0_l000000ooooooo0000o`000002o`0000;ooooo0_l000000ooooooo0000o`00000Po`000005oooo
ool0003o0000o`000?ooool01ol00008ooooo`;o00001?ooool4o`0000?ooooo0_l00004ooooo`;o
00002oooool2o`000003ooooool0003o000000?ooooo0_l00002oooooaOo000000Coooooo`000?l0
003ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0000Cooooo0_l0000J
ooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0=?ooool2o`0000oooooo0_l0000=oooo
o`;o00000_ooool2o`0000Sooooo9Ol00004ooooo`Oo00001?ooool2o`0000;ooooo0_l00004oooo
o`;o000000?oooooo`000?l000002?ooool4o`0000Wooooo0_l000000ooooooo0000o`000009oooo
oaWo00001?ooool2o`000003ooooool0003o000000Wooooo0_l0000Jooooo`;o0000>?ooool001co
oooo00?o0000ooooooooool0>oooool2o`0000_ooooo0_l0000:ooooo`;o00000_ooool2o`0000Co
oooo0ol000000ooooooo0000o`00000Uo`0000?ooooo0_l000001?oooooo0000o`000?l00002oooo
o`Co00002?ooool2o`000003ooooool0003o000000?ooooo2Ol0000?ooooo`;o00001_oooolIo`00
03Sooooo0_l0000^ooooo`007?ooool00ol0003oooooooooo`0kooooo`;o00000oooool2o`0000Ko
oooo0_l00005ooooo`;o00003Oooool3o`000003ooooool0003o0000027o000000?oooooo`000?l0
00000_l00002ooooo`;o00000_ooool2o`0000;ooooo0_l0000:ooooo`;o00001_ooool8o`00013o
oooo0_l00006oooooaWo000000?oooooo`000?l000004_ooool2o`00027ooooo0_l0000^ooooo`00
7?ooool00ol0003oooooooooo`10ooooo`;o00000_ooool2o`0000Wooooo1?l00003ooooo`;o0000
1_ooool7o`000003ooooool0003o000000So000000?oooooo`000?l000004_l000000ooooooo0000
o`000002o`00013ooooo0_l0000@ooooo`Co00005_oooolGo`000003ooooool0003o000000;ooooo
0_l000000ooooooo0000o`000009ooooo`Co00000_ooool2o`00057ooooo000Looooo`03o`000?oo
oooooooo03?ooooo1Ol0000<ooooo`;o00001?ooool2o`0000Gooooo0_l00003ooooo`;o00002?oo
ool5o`000003ooooool0003o000000So000000?oooooo`000?l000004?l000000ooooooo0000o`00
0005o`000003ooooool0003o000000cooooo0_l0000@ooooo`Ko000000?oooooo`000?l000004Ooo
ool3o`000004ooooool0003o0000ooooo`;o00001?ooool=o`000003ooooool0003o000000;ooooo
0_l000000ooooooo0000o`000002ooooo`;o00000_ooool4o`0001Wooooo0_l0000jooooo`007?oo
ool00ol0003oooooooooo`0cooooo`Go00003_ooool2o`0000;ooooo0ol00007ooooo`;o00002ooo
ool2o`000003ooooool0003o000000?o000000?oooooo`000?l000001?l000000ooooooo0000o`00
000Ho`000003ooooool0003o000000;ooooo0ol0000@ooooo`;o00001oooool2o`000003ooooool0
003o000000Co00003?ooool2o`0000[ooooo0_l00004ooooo`_o00000oooool2o`0000Gooooo0_l0
0002ooooo`;o00000oooool2o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l000003?oo
ool2o`0003[ooooo000Looooo`03o`000?oooooooooo03cooooo0_l00008ooooo`;o00000oooool2
o`000003ooooool0003o000000Cooooo0_l0000;ooooo`;o000000?oooooo`000?l000000ol00002
ooooo`co000000?oooooo`000?l000004Ol000000ooooooo0000o`000005o`0000Sooooo0_l00006
ooooo`;o00000oooool2o`0000Gooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00002?oo
ool2o`0000Oooooo0_l00007ooooo`Ko00000oooool2o`0001?ooooo0_l00002ooooo`;o00001Ooo
ool2o`000003ooooool0003o000000;o0000A_ooool001cooooo00?o0000ooooooooool0??ooool2
o`0000;ooooo0_l00008ooooo`;o00000_ooool3o`0000?ooooo1?l0000>ooooo`?o00000_oooolL
o`0000Gooooo2_l00005ooooo`;o00001oooool2o`0000;ooooo0ol00008ooooo`;o00000_ooool4
o`0000Kooooo0_l00003ooooo`;o00000_ooool4o`0000Cooooo1_l0000Cooooo`Co00004?ooool4
o`0004Kooooo000Looooo`;o0000:?ooool2o`0001;ooooo0_l00003ooooo`;o00000_ooool2o`00
00Cooooo1ol00005ooooo`;o00003_ooool3o`0000;ooooo7Ol00004ooooo`Go000000?oooooo`00
0?l000000_l000000ooooooo0000o`000004ooooo`Co00000oooool2o`0000;ooooo0ol0000>oooo
o`;o00002oooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool6o`0000Kooooo1?l00005
ooooo`;o00000_ooool4o`0001oooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`0Woooo
o`;o00004_ooool2o`0000Oooooo0_l00005ooooo`Co00004_ooool2o`0000Kooooo1Ol000000ooo
oooo0000o`00000Go`0000Kooooo0ol00002ooooo`;o00000_ooool2o`000004ooooool0003o0000
ooooo`Co00001oooool2o`0000?ooooo0_l0000Pooooo`;o00002Oooool2o`0000;ooooo1?l00005
ooooo`;o00003Oooool2o`0001Kooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`0joooo
o`;o00002Oooool2o`0000Sooooo0_l0000@ooooo`;o00001_ooool3o`0000Kooooo2?l000000ooo
oooo0000o`00000:o`000003ooooool0003o000000?ooooo0_l00004ooooo`;o00001Oooool2o`00
00_ooooo0_l00004ooooo`;o00003oooool2o`0000?ooooo0_l00006ooooo`;o00001_ooool2o`00
00;ooooo0_l000000ooooooo0000o`000002o`000004ooooool0003o0000o`0000Gooooo1?l00003
ooooo`;o00001_ooool2o`00057ooooo000Looooo`03o`000?oooooooooo03Cooooo0_l00004oooo
o`;o000000?oooooo`000?l000001_ooool2o`0000Sooooo0_l00008ooooo`;o000000Coooooo`00
0?l0003o00002Oooool4o`000003ooooool0003o000000;o000000?oooooo`000?l000001Ol00002
oooooa7o000000?oooooo`000?l000000oooool2o`0000Kooooo0_l00009ooooo`Co00001_ooool2
o`0000gooooo0_l00003ooooo`;o00001_ooool2o`0000Kooooo0_l00002ooooo`;o00000oooool3
o`0000Kooooo1_l00003ooooo`;o0000:?ooool2o`0002oooooo000Looooo`03o`000?oooooooooo
03Cooooo0_l00007ooooo`;o00003?ooool3o`0000_ooooo0_l000001?oooooo0000o`000?l00009
ooooo`Co000000?oooooo`000?l000000_l000000ooooooo0000o`000005o`0000;ooooo1?l00000
1Ooooooo0000o`000?l0003ooooo00So00001_ooool2o`00017ooooo0_l00008ooooo`;o00003?oo
ool2o`0001Sooooo0_l00004ooooo`;o00001_ooool2o`0000Cooooo0_l0000[ooooo`;o0000;ooo
ool001cooooo00?o0000ooooooooool0=oooool2o`0001;ooooo1?l00008ooooo`;o00004_ooool6
o`0000Cooooo1?l000000ooooooo0000o`000006o`000003ooooool0003o000000Go000000?ooooo
o`000?l000001?ooool2o`0000kooooo0_l00006ooooo`;o00004_ooool2o`0001Sooooo0ol00005
ooooo`;o00001_ooool2o`0000;ooooo0_l0000Zooooo`;o0000<?ooool001cooooo00?o0000oooo
ooooool0=oooool2o`000003ooooool0003o000000Wooooo0_l00004ooooo`Co00002?ooool2o`00
01;ooooo1Ol00005ooooo`Co000000?oooooo`000?l000001_l000000ooooooo0000o`000005o`00
0003ooooool0003o000000Cooooo0_l0000>ooooo`;o00001_ooool2o`0001Kooooo0_l0000<oooo
o`;o00000_ooool2o`0000;ooooo0ol00005ooooo`;o00001_ooool2o`0001Sooooo0_l0000Doooo
o`;o0000<?ooool001cooooo00?o0000ooooooooool0>_ooool2o`000004ooooool0003o0000o`00
00Gooooo0_l00004ooooo`;o00001_ooool2o`0000Sooooo0_l0000>ooooo`;o00000_ooool3o`00
0003ooooool0003o000000;o000000?oooooo`000?l000000ol00002ooooo`Co00000_ooool3o`00
00;ooooo0_l00008ooooo`;o00007oooool2o`0000Sooooo0_l0000<ooooo`;o00000_ooool2o`00
00?ooooo0_l0000;ooooo`;o00006_ooool2o`0004Kooooo000Looooo`03o`000?oooooooooo03go
oooo0ol00008ooooo`?o00002?ooool2o`0000Sooooo0_l000000ooooooo0000o`000009ooooo`Co
00000_ooool4o`000005ooooool0003o0000o`000?ooool01Ol00002ooooo`Co00000_ooool2o`00
00?ooooo0_l00003ooooo`;o00000oooool2o`0000Kooooo0_l00003ooooo`;o000000?oooooo`00
0?l000002Oooool2o`0000Cooooo0_l00007ooooo`;o00001_ooool2o`0000Gooooo0_l0000Doooo
o`;o00000oooool2o`0001Kooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`0booooo`;o
00002Oooool2o`000003ooooool0003o000000Kooooo0ol00009ooooo`?o00000oooool2o`0000Co
oooo0_l00009ooooo`Co00001?ooool2o`0000Sooooo0_l00004ooooo`;o00000_ooool2o`0000Oo
oooo0ol000000ooooooo0000o`000004ooooo`;o00000_ooool2o`0000?ooooo0_l000001?oooooo
0000o`000?l00002ooooo`;o00001?ooool2o`0000gooooo0_l000001?oooooo0000o`000?ooool4
o`0000Gooooo0_l0000Iooooo`;o00001?ooool2o`0000cooooo0_l00002ooooo`;o0000AOooool0
01cooooo00?o0000ooooooooool0<_ooool2o`0000;ooooo0_l00005ooooo`;o000000?oooooo`00
0?l000001?ooool2o`0000Kooooo0_l00004ooooo`Co00000_ooool2o`0000oooooo0_l00003oooo
o`;o00001Oooool2o`0000;ooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o0000
00Oooooo0_l00002ooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`?o00000_ooool2o`00
0003ooooool0003o000000;ooooo0_l0000<ooooo`;o000000Coooooo`000?l0003ooooo1?l0000J
ooooo`;o00001_ooool2o`0000;ooooo0_l0000<ooooo`;o0000BOooool001cooooo00?o0000oooo
ooooool0=_ooool2o`0000Gooooo0_l00007ooooo`;o00001?ooool4o`0000Kooooo0_l00005oooo
o`Co00002Oooool5o`000003ooooool0003o000000Gooooo1_l00002ooooo`;o00000_ooool3o`00
0003ooooool0003o000000;ooooo0_l00002ooooo`?o00001?ooool2o`0000Sooooo0_l0000:oooo
o`Co00000_ooool2o`0000cooooo0_l000000ooooooo0000o`00000Oooooo`;o00001_ooool2o`00
00Gooooo0_l0000Fooooo`;o0000??ooool001cooooo00?o0000ooooooooool0?Oooool2o`0000go
oooo0_l0000=ooooo`Ko00002Oooool2o`000003ooooool0003o000000Oooooo1_l00007ooooo`Go
00000_ooool4o`000004ooooool0003o0000o`0000Cooooo0_l00007ooooo`;o00002oooool2o`00
0003ooooool0003o000000Sooooo0_l00008ooooo`;o00001?ooool2o`0001[ooooo0_l00008oooo
o`Wo00004oooool2o`0003cooooo000Looooo`03o`000?oooooooooo04cooooo0_l000000ooooooo
0000o`00000:ooooo`;o00001oooool2o`0000Sooooo0_l00006ooooo`?o000000?oooooo`000?l0
00001oooool5o`0000;ooooo1?l00002ooooo`;o00001Oooool2o`0000Kooooo0ol00004ooooo`;o
00001oooool3o`0000Oooooo0_l0000>ooooo`;o00000_ooool2o`0000Oooooo0_l00008ooooo`;o
00000oooool2o`000003ooooool0003o000000Gooooo3?l0001>ooooo`007?ooool00ol0003ooooo
ooooo`1?ooooo`;o00003Oooool2o`0000Cooooo0ol00007ooooo`;o00004oooool4o`0000?ooooo
0_l0000;ooooo`;o00001_ooool3o`000004ooooool0003o0000ooooo`;o00002?ooool2o`0001?o
oooo0_l00002ooooo`Ko00001oooool2o`0000Cooooo1_l00006ooooo`;o00001_ooool;o`0004ko
oooo000Looooo`03o`000?oooooooooo02Wooooo0_l0000Uooooo`;o00003?ooool2o`0000Gooooo
0_l00008ooooo`;o00003oooool2o`0000[ooooo0_l0000;ooooo`;o00001_ooool4o`00023ooooo
0_l00003ooooo`?o00003oooool4o`0000kooooo3_l0001=ooooo`007?ooool2o`0002Sooooo1?l0
000@ooooo`;o00003?ooool4o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o000000?o
ooooo`000?l000000ol00004ooooo`Go000000?oooooo`000?l000000_ooool4o`0000Kooooo0_l0
0007ooooo`;o00002_ooool2o`0000;ooooo0_l00007ooooo`;o00001_ooool2o`0000Cooooo0_l0
0003ooooo`;o00004Oooool4o`0000Oooooo0_l00009ooooo`;o00005oooool?o`0004cooooo000L
ooooo`03o`000?oooooooooo02Oooooo0_l00008ooooo`;o00001oooool5o`0000[ooooo1?l00000
0ooooooo0000o`000002ooooo`?o00000_ooool2o`000003ooooool0003o000000?o00001?ooool2
o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000Sooooo0_l00003ooooo`;o00004_oo
ool2o`0001Gooooo0_l00003ooooo`;o00001oooool2o`0000Kooooo1_l000000ooooooo0000o`00
0006ooooo`;o00001oooool2o`0001Kooooo4_l0000Kooooo`;o0000;Oooool001cooooo00?o0000
ooooooooool0<Oooool2o`0000Oooooo0_l000000ooooooo0000o`00000?ooooo`;o00000_ooool2
o`0000gooooo0_l0000Iooooo`;o00002Oooool2o`0002cooooo0_l00002ooooo`;o00000_ooool3
o`000004ooooool0003o0000ooooo`;o00001_ooool2o`0000Wooooo0_l0000Dooooo`_o000000?o
ooooo`000?l000001_l0000Iooooo`;o0000;Oooool001cooooo00?o0000ooooooooool0>_ooool2
o`0000_ooooo0_l00004ooooo`?o00004Oooool2o`0002Cooooo0_l0000Dooooo`;o00002Oooool2
o`0000gooooo1?l00003ooooo`;o000000Coooooo`000?l0003ooooo0ol00006ooooo`;o00002?oo
ool2o`0001;ooooo2ol000000ooooooo0000o`000003o`000003ooooool0003o000000;o0000B?oo
ool001cooooo00?o0000ooooooooool0Aoooool2o`0000Cooooo0ol00007ooooo`;o000000?ooooo
o`000?l000001?ooool2o`0001Gooooo0_l000000ooooooo0000o`00000Qooooo`;o00001_ooool2
o`000003ooooool0003o000000gooooo0_l000000ooooooo0000o`000002ooooo`;o00001?ooool3
o`0000Kooooo0_l0000LoooooaKo0000B?ooool001cooooo00?o0000ooooooooool0>?ooool3o`00
01Gooooo0_l00005ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Sooooo0_l0000;oooo
o`;o000000?oooooo`000?l000001_ooool2o`0001Oooooo0ol00002ooooo`;o00000oooool2o`00
00?ooooo0_l00009ooooo`;o00000oooool2o`0002;ooooo0_l0000Aooooo`ko0000B_ooool001co
oooo00?o0000ooooooooool0>?ooool3o`0001Cooooo1ol0000Dooooo`;o00005?ooool4o`0001Oo
oooo0ol00002ooooo`;o00001oooool3o`0000Oooooo1?l00008ooooo`;o00001_ooool4o`0000[o
oooo0_l00007ooooo`;o00004Oooool>o`0004[ooooo000Looooo`03o`000?oooooooooo037ooooo
0_l00007ooooo`;o00004oooool2o`000003ooooool0003o000000;o00003?ooool2o`00017ooooo
0_l00009ooooo`;o00007?ooool4o`0000Gooooo1?l00008ooooo`;o00001Oooool2o`0000?ooooo
0_l00006ooooo`Co00002_ooool2o`0001[ooooo3?l00003ooooo`;o0000Aoooool001cooooo00?o
0000ooooooooool0<Oooool2o`0000Oooooo0_l0000Cooooo`;o00001?ooool2o`0000_ooooo0_l0
000Aooooo`;o00009?ooool2o`000003ooooool0003o000000;o00001?ooool4o`0000Sooooo0ol0
0004ooooo`So00001Oooool3o`000003ooooool0003o0000023ooooo0_l00006ooooo`Oo00001Ooo
ool2o`0000kooooo0_l0000gooooo`007?ooool00ol0003oooooooooo`0Wooooo`;o00002?ooool2
o`0000Gooooo0ol0000Dooooo`;o00001?ooool2o`0001;ooooo1?l00009ooooo`;o00003Oooool2
o`0001Cooooo0_l00009ooooo`Co00002?ooool2o`0000;ooooo3Ol000000ooooooo0000o`000002
o`0000;ooooo0_l00003ooooo`;o00005?ooool2o`0000Gooooo0_l00007ooooo`Co00005oooool2
o`0003Oooooo000Looooo`03o`000?oooooooooo02Oooooo0_l0000?ooooo`?o00001oooool3o`00
00Sooooo0_l00003ooooo`;o00000_ooool2o`00017ooooo1?l00009ooooo`;o000000?oooooo`00
0?l000001?ooool2o`0000Cooooo0_l0000Gooooo`;o00004?ooool2o`0000;ooooo3ol000000ooo
oooo0000o`000002o`0000Oooooo0_l0000Dooooo`;o00002oooool2o`000003ooooool0003o0000
00Oooooo0_l00019ooooo`007?ooool00ol0003oooooooooo`0eooooo`;o000000Coooooo`000?l0
003o00001oooool3o`0000Sooooo0_l00002ooooo`?o00000_ooool2o`0000?ooooo0_l00004oooo
o`;o00001_ooool2o`0000kooooo0_l00003ooooo`?o00007Oooool2o`0000Kooooo1?l00006oooo
oaSo00001?ooool2o`0002Cooooo0_l000000ooooooo0000o`000002o`0000Gooooo0_l0000?oooo
o`;o0000>?ooool001cooooo00?o0000ooooooooool0=Oooool3o`000003ooooool0003o000000;o
oooo0_l0000Booooo`;o00001Oooool2o`000003ooooool0003o000000Cooooo1?l00009ooooo`;o
00003_ooool2o`0002Kooooo1?l00003ooooo`;o00000_ooool4o`000003ooooool0003o0000013o
000000Coooooo`000?l0003ooooo0_l0000>ooooo`;o00005oooool4o`0001Kooooo0_l0000hoooo
o`007?ooool00ol0003oooooooooo`0fooooo`;o00000_ooool2o`000003ooooool0003o000000Ko
oooo0_l0000Aooooo`;o00002?ooool3o`0000?ooooo0_l00004ooooo`;o00001_ooool2o`000003
ooooool0003o000000Oo00001oooool2o`0000Sooooo0_l0000<ooooo`;o00000oooool2o`0000;o
oooo0_l000000ooooooo0000o`000002oooooaGo00000oooool3o`00013ooooo0_l0001[ooooo`00
00Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413o
c<c<00Kooooo00?o0000ooooooooool0>_ooool2o`0000;ooooo0ol00004ooooo`;o00002oooool2
o`0000Cooooo0_l00009ooooo`?o00000_ooool2o`0000cooooo0_l000000ooooooo0000o`000007
o`0000?ooooo0ol000000ooooooo0000o`000008ooooo`;o00002Oooool2o`000004ooooool0003o
0000o`0000Kooooo0_l00005oooooaGo00001?ooool2o`0007gooooo00001_ooooooMgMgoiRHV?oo
ooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003o
ooooooooo`0dooooo`;o00001?ooool2o`0000;ooooo0ol0000Aooooo`;o00001?ooool2o`0000[o
oooo1?l0000Fooooo`;o00001Oooool3o`0000Gooooo0_l0000<ooooo`;o000000?oooooo`000?l0
00000_ooool2o`0000_ooooo6Ol0000Nooooo`;o0000HOooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool0=?ooool2o`0000Cooooo0_l0000Pooooo`;o00002?ooool2o`0001Kooooo0_l00002ooooo`;o
00002Oooool2o`0000cooooo0_l000000ooooooo0000o`000007ooooo`;o00001?oooolKo`0001go
oooo0ol0000/ooooo`;o0000<oooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
2Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0000eooooo`;o00002_ooool2o`0001Wo
oooo0_l00002ooooo`;o00005Oooool3o`0000Cooooo0_l00002ooooo`;o00003?ooool2o`0000co
oooo0_l00007ooooo`;o00001?oooolKo`0000oooooo1?l0000:ooooo`Co00000oooool2o`0001ko
oooo0_l00006ooooo`;o0000<oooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
2Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0=Oooool2o`0000Ko
oooo0_l00002ooooo`;o00000_ooool2o`0001Wooooo0_l0000Eooooo`?o00000_ooool5o`0000?o
oooo0_l000000ooooooo0000o`000003ooooo`;o00000_ooool2o`00013ooooo0_l00003ooooo`;o
00001_oooolIo`0000oooooo1?l00006ooooo`;o00001?ooool4o`000003ooooool0003o000000So
oooo0_l00003ooooo`;o00003oooool2o`0003_ooooo00000ooooooo410@ooooo`02ooooo`03oa0@
4?oooooooooo00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`0mooooo`;o0000
0_ooool3o`000003ooooool0003o000002[ooooo0_l00009ooooo`Go00000oooool2o`000003oooo
ool0003o000000?ooooo0_l0000Dooooo`Go00002?oooolEo`0000gooooo0_l0000>ooooo`;o0000
0_ooool2o`0000;ooooo0_l000000ooooooo0000o`000008ooooo`;o00000oooool2o`0000;ooooo
0_l00018ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00So
oooo00?o0000ooooooooool0@Oooool5o`0000Gooooo0_l0000Sooooo`Co00001?ooool2o`0000go
oooo1?l00009ooooo`;o00003Oooool4o`0000Sooooo5_l000001?oooooo0000o`000?l00008oooo
o`;o000000?oooooo`000?l000003oooool2o`0000Gooooo0_l00006ooooo`;o00002Oooool2o`00
00[ooooo0_l0000looooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co
0000oa0@40Kooooo00?o0000ooooooooool0@?ooool2o`0000;ooooo0_l00005ooooo`;o00008ooo
ool4o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`;o00001Oooool4o`0000Oooooo1_l0
000Dooooo`;o000000?oooooo`000?l000006?l0000;ooooo`;o00002oooool2o`0000[ooooo0_l0
0005ooooo`;o00005Oooool2o`0003cooooo000Looooo`03o`000?oooooooooo043ooooo0_l00004
ooooo`;o0000;_ooool4o`000003ooooool0003o000000?ooooo0_l00006ooooo`?o00000_ooool2
o`0000?ooooo0ol000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000003Oooool2
o`000003ooooool0003o000001So00005Oooool2o`000004ooooool0003o0000ooooo`;o00001?oo
ool2o`000003ooooool0003o0000017ooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`0l
ooooo`;o00000oooool2o`0000?ooooo0_l0000Uooooo`;o00001oooool2o`0000Kooooo1Ol00003
ooooo`Wo00000oooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2
o`0000;ooooo0_l00004oooooako000000?oooooo`000?l000004_ooool2o`000004ooooool0003o
0000ooooo`;o00001?ooool2o`00017ooooo1Ol00017ooooo`007?ooool00ol0003oooooooooo`0h
ooooo`;o00000_ooool2o`000003ooooool0003o000000;o0000:_ooool2o`0000oooooo1_l00000
0ooooooo0000o`000007o`0001?ooooo0ol000000ooooooo0000o`000004oooooa_o000000Cooooo
o`000?l0003ooooo0_l0000<ooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0
003o000001Oooooo0ol00019ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00001Oooool2
o`0000gooooo0ol0000Oooooo`;o00003Oooool2o`000003ooooool0003o000000?o000000?ooooo
o`000?l000001?l0000Dooooo`;o00001ooooolHo`000003ooooool0003o000001;ooooo0_l00000
0ooooooo0000o`000007ooooo`;o0000Hoooool001cooooo00?o0000ooooooooool0?oooool2o`00
00gooooo0ol0000Oooooo`;o00002oooool4o`000003ooooool0003o000000[o000000?oooooo`00
0?l000000oooool2o`0001Gooooo1_l000000ooooooo0000o`00000Bo`0000;ooooo0_l0000Aoooo
o`Co00001Oooool2o`0001?ooooo0_l00003ooooo`;o0000BOooool001cooooo00?o0000oooooooo
ool0=oooool3o`0000Oooooo0_l0000Zooooo`;o00001oooool2o`0000Gooooo0_l00002oooooa;o
000000Coooooo`000?l0003o00005?ooool2o`000003ooooool0003o000001Go00000oooool2o`00
00Gooooo0_l0000:ooooo`Co000000?oooooo`000?l000005?ooool2o`000003ooooool0003o0000
00?ooooo1?l00017ooooo`007?ooool00ol0003oooooooooo`0gooooo`?o00000oooool2o`0000;o
oooo0_l0000Zooooo`;o00001oooool2o`0000Cooooo0_l00002oooooaOo00002?ooool2o`0000go
oooo5Ol0000<ooooo`?o00003_ooool2o`0001Cooooo0_l00003ooooo`;o00000oooool2o`0000[o
oooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0mooooo`;o0000;_ooool4o`0000?ooooo
0_l00006ooooo`;o00000_oooolGo`0000Kooooo1_l0000;oooooaGo00003Oooool2o`0002Wooooo
0_l0000?ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0?_ooool2o`000003ooooool0
003o000002cooooo0_l00003ooooo`;o00000oooool6o`000003ooooool0003o000001;o00001?oo
ool2o`0000;ooooo0ol00002ooooo`;o00002oooool6o`000003ooooool0003o000000Oo00000_oo
ool3o`0001kooooo0_l0000Fooooo`;o000000?oooooo`000?l000002_ooool2o`0003oooooo000L
ooooo`03o`000?oooooooooo03kooooo0_l000000ooooooo0000o`000008ooooo`;o00008_ooool3
o`0000;ooooo0_l00003oooooago00000_ooool7o`0000oooooo4?l00003ooooo`;o00001_ooool2
o`0001Kooooo0_l00009ooooo`;o00002oooool2o`000003ooooool0003o000000[ooooo0_l0000o
ooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00000oooool2o`0000Kooooo0_l00002oooo
o`;o000000?oooooo`000?l000006oooool3o`0000;ooooo0_l00002oooooako00001?ooool2o`00
00[ooooo0_l0000;ooooo`Go000000?oooooo`000?l000000ol000000ooooooo0000o`000002o`00
00Kooooo0ol000000ooooooo0000o`00000Eooooo`;o00001_ooool2o`0000_ooooo0_l0001>oooo
o`007?ooool2o`0004Cooooo0_l0000:ooooo`;o000000?oooooo`000?l000009?oooolOo`0000?o
oooo0_l0000:ooooo`;o00003Oooool3o`0000;ooooo0ol000000ooooooo0000o`000002o`0000So
oooo0_l000000ooooooo0000o`000002ooooo`;o00004Oooool2o`0000Oooooo0_l0000;ooooo`;o
00003?ooool2o`0003oooooo000Looooo`03o`000?oooooooooo07[ooooo7ol0000Hooooo`Go0000
1?ooool3o`000003ooooool0003o0000017ooooo0_l0000Fooooo`;o00000_ooool2o`0000_ooooo
0_l0000<ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0A?ooool2o`0000Cooooo0_l0
0006ooooo`;o00008_ooool2o`000005ooooool0003o0000o`000?ooool03?l00002ooooo`Wo0000
0oooool2o`0000Kooooo0_l0000@ooooo`Oo00005Oooool2o`0001[ooooo0_l00006ooooo`;o0000
4Oooool2o`0004?ooooo000Looooo`03o`000?oooooooooo04Cooooo0_l00003ooooo`Go00001?oo
ool2o`0001Kooooo0_l00007ooooo`;o000000Coooooo`000?l0003ooooo1?l000000ooooooo0000
o`00000Fo`0000Kooooo0_l000001?oooooo0000o`000?l00003ooooo`Go00002_ooool4o`00017o
oooo0_l00002ooooo`;o00001Oooool2o`0000Gooooo0_l0000<ooooo`;o00001_ooool2o`0000Ko
oooo1?l00007ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0BOooool2o`000003oooo
ool0003o000001cooooo0_l00007ooooo`;o00001?ooool4o`000003ooooool0003o000001Oo0000
1Oooool2o`0000;ooooo0_l00003ooooo`Go00002oooool2o`0001;ooooo0_l00004ooooo`;o0000
0oooool2o`0000Gooooo1Ol0000Iooooo`Co0000C?ooool001cooooo00?o0000ooooooooool0C_oo
ool2o`0002Wooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o0000013o000000?o
ooooo`000?l000007_ooool2o`0001Cooooo0_l00002ooooo`;o00003?ooool3o`0000Sooooo0_l0
001Oooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00000oooool2o`000003ooooool0003o
000001kooooo0_l00002ooooo`;o00000_ooool;o`000003ooooool0003o0000013o000000?ooooo
o`000?l000005Oooool2o`0000?ooooo0_l00007ooooo`;o00001_ooool2o`0000Cooooo0_l0000I
ooooo`Ko00002Oooool2o`0005;ooooo000Looooo`03o`000?oooooooooo04Wooooo0_l00005oooo
o`?o00006oooool2o`000003ooooool0003o000000;ooooo0_l00002oooooako000000Coooooo`00
0?l0003o00003_ooool2o`0000Cooooo0_l00003ooooo`;o00001oooool2o`0000Kooooo0_l00004
ooooo`;o00005oooool5o`000003ooooool0003o000000Wooooo0_l0001Booooo`007?ooool00ol0
003oooooooooo`1@ooooo`;o00006?ooool2o`0000;ooooo0_l00009oooooako000000Coooooo`00
0?l0003o00003_ooool2o`0000Gooooo0_l0000Iooooo`;o00002_ooool2o`0000_ooooo0_l00000
0ooooooo0000o`000006o`0005[ooooo000Looooo`03o`000?oooooooooo04Kooooo0_l00009oooo
o`;o00005oooool2o`0000Wooooo7_l000000ooooooo0000o`000003o`0000Wooooo0_l0000<oooo
o`;o00005_ooool2o`000004ooooool0003o0000ooooo`;o00001_ooool5o`0000Wooooo0_l00003
ooooo`Ko0000F_ooool001cooooo00?o0000ooooooooool0A_ooool2o`0000;ooooo0_l00005oooo
o`;o00003Oooool4o`00017ooooo2Ol000000ooooooo0000o`00000Do`0000;ooooo0_l00004oooo
o`;o00000oooool3o`0001Sooooo0_l00009ooooo`;o00001?ooool2o`0000Kooooo1Ol0000>oooo
o`Co00004_ooool2o`0004Sooooo000Looooo`03o`000?oooooooooo03kooooo0_l0000:ooooo`?o
00001oooool2o`0000[ooooo1?l0000=ooooo`;o00001_oooolLo`0000Sooooo0_l00004ooooo`;o
00006?ooool2o`0001Oooooo1?l0000=ooooo`;o00005_ooool2o`0004Sooooo000Looooo`03o`00
0?oooooooooo03kooooo0_l0000;ooooo`?o00000oooool2o`000003ooooool0003o000001;ooooo
0_l00007ooooo`;o000000?oooooo`000?l000001?oooolKo`0002[ooooo1?l00008ooooo`;o0000
0oooool4o`000004ooooool0003o0000o`0000oooooo0_l000000ooooooo0000o`00001Mooooo`00
7?ooool00ol0003oooooooooo`1<ooooo`;o00000oooool4o`0000Wooooo0_l00008ooooo`;o0000
2_ooool2o`000003ooooool0003o000001co000000?oooooo`000?l000001_ooool2o`0000;ooooo
0_l0000Kooooo`Co000000?oooooo`000?l000000_l00003ooooo`Co000000?oooooo`000?l00000
0_l000000ooooooo0000o`00000Cooooo`;o00001Oooool2o`0000?ooooo0_l0001Aooooo`007?oo
ool00ol0003oooooooooo`1Booooo`?o00002Oooool4o`0001Gooooo1_l000000ooooooo0000o`00
000Ao`0000;ooooo0_l000000ooooooo0000o`000006ooooo`;o00000_ooool2o`0000Oooooo0_l0
0003ooooo`?o00003_ooool2o`000003ooooool0003o000000;o00001Oooool2o`0000cooooo0_l0
000@ooooo`Ko00000oooool2o`00057ooooo000Looooo`03o`000?oooooooooo057ooooo1?l0000;
ooooo`;o00000_ooool2o`0001?ooooo6?l000000ooooooo0000o`000004o`0000[ooooo0_l00007
ooooo`Co000000Coooooo`000?l0003o00003_ooool2o`0000Kooooo0_l00002ooooo`;o00003?oo
ool4o`000003ooooool0003o000000_ooooo1_l0001Fooooo`007?ooool2o`0005;ooooo0_l0000:
ooooo`Go000000?oooooo`000?l000000_l0000CoooooaOo000000?oooooo`000?l000001?l00005
ooooo`;o00002oooool2o`000003ooooool0003o000000_ooooo0ol0000<ooooo`;o00000_ooool2
o`0000[ooooo0_l00002ooooo`;o000000?oooooo`000?l000000ol00002ooooo`;o0000H?ooool0
01cooooo00?o0000ooooooooool0DOooool2o`0000[ooooo0ol00003ooooo`Co00004oooool2o`00
0005ooooool0003o0000o`000?ooool01?l00002ooooo`Co000000?oooooo`000?l000000ol00004
ooooo`;o00001_ooool2o`0000_ooooo0_l0000;ooooo`;o000000Coooooo`000?l0003o00002_oo
ool2o`00013ooooo1?l00005ooooo`?o00000_ooool2o`0000Cooooo0_l0001Jooooo`007?ooool0
0ol0003oooooooooo`1Aooooo`;o00008oooool2o`000003ooooool0003o000000;ooooo2ol00000
0ooooooo0000o`000007o`0000cooooo0_l0000Booooo`?o00000_ooool2o`0000;ooooo0_l0000:
ooooo`;o00002Oooool2o`0000Gooooo1?l0000@ooooo`;o0000F_ooool001cooooo00?o0000oooo
ooooool0J?ooool2o`0000cooooo1Ol00002ooooo`co000000Coooooo`000?l0003ooooo1Ol00000
0ooooooo0000o`000007ooooo`Co00004_ooool3o`0000Kooooo0_l0000Booooo`;o000000?ooooo
o`000?l000001Oooool2o`0006kooooo000Looooo`03o`000?oooooooooo06Kooooo1?l0000>oooo
o`;o00000oooool2o`000004ooooool0003o0000ooooo`Wo000000?oooooo`000?l000000ol00000
0ooooooo0000o`000006ooooo`?o00002oooool2o`0000Oooooo0_l000000ooooooo0000o`00000G
ooooo`?o00004?ooool2o`0000Sooooo0_l0001Looooo`007?ooool00ol0003oooooooooo`1@oooo
o`;o00005?ooool4o`0000Kooooo0_l0000;ooooo`Go00000oooool7o`0000Cooooo0_l00009oooo
o`;o00000oooool2o`0000Oooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o0000
00;ooooo0_l00006ooooo`;o00002_ooool3o`0000?ooooo0_l000001?oooooo0000o`000?ooool2
o`0000Kooooo0_l00006ooooo`Co000000Coooooo`000?l0003o00001Oooool2o`00057ooooo000L
ooooo`03o`000?oooooooooo053ooooo0_l0000Eooooo`Co00001Oooool3o`0000Sooooo0_l00000
1?oooooo0000o`000?l00004ooooo`;o00003oooool2o`000003ooooool0003o000000Gooooo0_l0
000;ooooo`;o00002_ooool2o`0000Cooooo1?l0000:ooooo`;o00001?ooool2o`000004ooooool0
003o0000ooooo`;o00001_ooool2o`0000Kooooo1?l000001?oooooo0000o`000?l00005ooooo`;o
0000DOooool001cooooo00?o0000ooooooooool0DOooool2o`0001?ooooo1_l00005ooooo`;o0000
2?ooool2o`000004ooooool0003o0000o`0000Cooooo1?l0000=ooooo`;o000000?oooooo`000?l0
00003oooool3o`0001;ooooo0_l0000<ooooo`;o00000oooool5o`0007;ooooo000Looooo`03o`00
0?oooooooooo057ooooo0_l0000Cooooo`;o00000_ooool2o`0001Gooooo2ol0000Aooooo`;o0000
2oooool3o`000003ooooool0003o000000?o00001Oooool6o`0000gooooo0_l00005ooooo`Go0000
3oooool2o`00067ooooo000Looooo`03o`000?oooooooooo04[ooooo0_l0000Tooooo`;o00003ooo
ool5o`0000;ooooo1?l000000ooooooo0000o`00000>ooooo`;o00003oooool7o`000003ooooool0
003o000000Ko00003Oooool2o`0000Gooooo0_l0000Booooo`;o0000HOooool001cooooo00?o0000
ooooooooool0B_ooool2o`0001Gooooo0_l0000;ooooo`Co00004?ooool5o`000003ooooool0003o
000000?ooooo0_l0000Jooooo`;o00001?ooool2o`000005ooooool0003o0000o`000?ooool00_l0
0004ooooo`;o000000Coooooo`000?l0003ooooo1?l000001?oooooo0000o`000?l0001oooooo`00
7?ooool00ol0003oooooooooo`1Nooooo`;o000000?oooooo`000?l000001Oooool2o`0000Cooooo
0_l0000Booooo`Go00004oooool4o`0000_ooooo0ol00003ooooo`;o00002oooool2o`000004oooo
ool0003o0000ooooo`Co000000Goooooo`000?l0003o0000ooooo`02o`0000;ooooo0ol0000Hoooo
o`;o0000GOooool001cooooo00?o0000ooooooooool0FOooool2o`0000?ooooo0_l00008ooooo`;o
00001?ooool2o`0000Cooooo0_l0000?ooooo`;o00004oooool4o`0000cooooo0_l00007ooooo`;o
00003Oooool2o`0000?ooooo0_l00002ooooo`Oo00006?ooool2o`0005gooooo000Looooo`03o`00
0?oooooooooo05Wooooo0_l00003ooooo`;o00001oooool2o`0000Kooooo1?l000001?oooooo0000
o`000?ooool2o`0000cooooo0_l00005ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o
00005?ooool3o`0000Gooooo0_l0000Hooooo`;o00001_ooool2o`000003ooooool0003o000000Oo
oooo0_l00006ooooo`;o0000G_ooool001cooooo00?o0000ooooooooool0Ioooool2o`0000Kooooo
1?l00004ooooo`;o00004oooool2o`000003ooooool0003o000000;o00000_ooool2o`0000oooooo
0_l00003ooooo`?o00001?ooool2o`0001Kooooo0_l00009ooooo`;o000000?oooooo`000?l00000
1_ooool3o`0000Kooooo0_l0001Nooooo`007?ooool00ol0003oooooooooo`1Yooooo`?o00001Ooo
ool2o`000003ooooool0003o000000Oooooo2Ol00002ooooo`;o00005Oooool2o`0000Gooooo0_l0
0004ooooo`;o00001?ooool2o`0000[ooooo0_l000000ooooooo0000o`000007ooooo`;o00004ooo
ool3o`0006Oooooo000Looooo`;o0000H?ooool2o`0000Sooooo0ol00005ooooo`;o000000?ooooo
o`000?l000001oooool9o`0000;ooooo0_l00007ooooo`;o00001?ooool2o`0000Cooooo1?l00003
ooooo`;o000000?oooooo`000?l000003Oooool2o`0000;ooooo2_l00003ooooo`;o00002?ooool2
o`0000cooooo0ol0000;ooooo`;o0000F_ooool001cooooo00?o0000ooooooooool0Goooool2o`00
00;ooooo0_l000001?oooooo0000o`000?ooool3o`000003ooooool0003o000000Oooooo0_l0000I
ooooo`;o00001?ooool2o`0000Cooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l0
000=ooooo`_o000000?oooooo`000?l000000oooool2o`0000Sooooo0_l0000=ooooo`;o00002ooo
ool2o`0005[ooooo000Looooo`03o`000?oooooooooo067ooooo1?l000001?oooooo0000o`000?oo
ool3o`000003ooooool0003o000000Oooooo0_l00004ooooo`;o00002_ooool2o`000003ooooool0
003o000000cooooo0_l00002ooooo`?o000000?oooooo`000?l000001oooool2o`0000[ooooo1?l0
0002ooooo`Co00003?ooool2o`0000?ooooo0_l0001fooooo`007?ooool00ol0003oooooooooo`1Q
ooooo`;o00000_ooool2o`0000Kooooo0_l0000=ooooo`?o00002Oooool2o`000003ooooool0003o
000000Sooooo1_l000000ooooooo0000o`000002o`000004ooooool0003o0000o`0000Kooooo0_l0
0002ooooo`;o000000?oooooo`000?l000000oooool2o`0000Gooooo0_l0000=ooooo`Co00000ooo
ool2o`0000Wooooo0_l0001Yooooo`007?ooool00ol0003oooooooooo`1Oooooo`;o00001?ooool2
o`0000Kooooo0ol00005ooooo`;o00001Oooool4o`0000Cooooo0_l0000:ooooo`?o00000_ooool4
o`0000?ooooo0_l00004ooooo`;o00002_ooool2o`000003ooooool0003o000000[ooooo0_l0000?
ooooo`?o00000_ooool2o`000003ooooool0003o000000Kooooo0_l0001Yooooo`007?ooool00ol0
003oooooooooo`1Oooooo`;o00003Oooool2o`0000?ooooo1?l00007ooooo`?o00000oooool2o`00
0003ooooool0003o000000Gooooo1Ol0000Aooooo`Ko00000oooool2o`0000Kooooo0_l00008oooo
o`;o00003_ooool2o`0000;ooooo0_l000000ooooooo0000o`000008ooooo`;o00001?ooool2o`00
067ooooo000Looooo`03o`000?oooooooooo05_ooooo0_l0000Fooooo`?o00002Oooool2o`0000;o
oooo0_l00002ooooo`;o00001Oooool2o`0000?ooooo0_l0000?ooooo`Ko00000oooool2o`0000;o
oooo0_l00002ooooo`Co00001_ooool2o`0000;ooooo0_l00006ooooo`?o00001Oooool3o`0000;o
oooo0_l00005ooooo`?o00001?ooool2o`00067ooooo000Looooo`03o`000?oooooooooo05_ooooo
0_l00007ooooo`;o00003_ooool2o`0000[ooooo0_l000001?oooooo0000o`000?ooool2o`0000_o
oooo0_l0000?ooooo`;o00002oooool3o`0000?ooooo0_l0000:ooooo`;o00001_ooool5o`0000Co
oooo0_l00002ooooo`;o00001Oooool4o`0000cooooo0_l0001Hooooo`007?ooool00ol0003ooooo
ooooo`1Tooooo`;o00003Oooool2o`0000?ooooo0_l00006ooooo`;o00000oooool5o`0000Gooooo
0_l00002ooooo`;o00007Oooool5o`0000Cooooo0ol00007ooooo`;o00001oooool2o`0000Gooooo
1?l00008ooooo`;o00000oooool2o`0000Oooooo0_l0001Hooooo`007?ooool00ol0003ooooooooo
o`1cooooo`;o00000oooool6o`0000Gooooo1ol00005ooooo`;o00000_ooool2o`0000Kooooo0ol0
000=ooooo`;o00001?ooool7o`000003ooooool0003o000000?o00001oooool2o`0000Oooooo0_l0
00000ooooooo0000o`000002ooooo`Co00001_ooool2o`0000Gooooo0_l0001Qooooo`007?ooool0
0ol0003oooooooooo`1_ooooo`;o00000oooool2o`0000Cooooo1?l00005ooooo`Go00003Oooool2
o`0000Cooooo0ol0000=ooooo`;o000000Coooooo`000?l0003ooooo1ol000000ooooooo0000o`00
0003o`0000?ooooo0_l0000>ooooo`;o00003?ooool2o`0006Sooooo000Looooo`03o`000?oooooo
oooo05kooooo0_l00006ooooo`?o00001_ooool2o`0000?ooooo0_l00007ooooo`;o00004_ooool2
o`0000;ooooo0_l00005ooooo`;o00002_ooool2o`0000Cooooo0_l000000ooooooo0000o`000003
ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o00000_ooool2o`0001Gooooo0_l0001[
ooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o00001_ooool4o`0000[ooooo0_l00007oooo
o`;o00001oooool3o`0000Sooooo0_l0000?ooooo`;o00001?ooool2o`0000Gooooo0_l000000ooo
oooo0000o`000002ooooo`;o000000?oooooo`000?l000000ol00007ooooo`;o000000?oooooo`00
0?l000000_l0000;ooooo`;o00000oooool2o`0006_ooooo000Looooo`03o`000?oooooooooo06So
oooo0_l0000:ooooo`;o00001oooool2o`0000Oooooo0ol0000Booooo`;o00000_ooool2o`000003
ooooool0003o000000;o00002?ooool7o`000004ooooool0003o0000ooooo`;o000000?oooooo`00
0?l000001Oooool:o`0000Gooooo0_l00003ooooo`;o0000L?ooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oo
oooooooo08_ooooo0_l0000=ooooo`?o00000_ooool2o`000003ooooool0003o000000;o00002?oo
ool4o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000002?ooool6o`0000;ooooo
0_l00005ooooo`;o00002Oooool2o`0006[ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Go
oooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1goooo
o`;o00004_ooool2o`0000?ooooo0_l00008ooooo`Co00001?ooool2o`000003ooooool0003o0000
00?ooooo0_l0000?ooooo`;o00001oooool5o`0001Cooooo0_l0001Zooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`1aooooo`;o00000_ooool4o`0001Oooooo0_l00006ooooo`;o00000_ooool2o`00
00Cooooo0_l000000ooooooo0000o`000003ooooo`;o00003?ooool2o`000003ooooool0003o0000
00[ooooo0_l0000:ooooo`;o0000M?ooool00003ooooool0003ooooo00;ooooo00?o0000oooooooo
ool02Oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0001aooooo`;o00000_ooool3o`00
023ooooo0_l00007ooooo`;o00001_ooool2o`000003ooooool0003o000000;o00002?ooool2o`00
0003ooooool0003o000001Kooooo0_l0001dooooo`0000?oooooo`000?ooool00_ooool00ol0003o
ooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`1[oooo
o`;o00002Oooool2o`0001gooooo0_l00003ooooo`Ko000000?oooooo`000?l000001_ooool2o`00
0003ooooool0003o000000;o00002oooool2o`0000Sooooo0_l000000ooooooo0000o`000008oooo
o`;o0000MOooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol@413o
^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0Joooool2o`0000Sooooo0_l0000Loooo
o`Co00000oooool6o`0001_ooooo0_l00008ooooo`;o000000?oooooo`000?l000002?ooool2o`00
07Gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zjo`00
0006ooooo`03o`000?oooooooooo07Gooooo0_l0000Looooo`;o00001Oooool2o`0001oooooo0_l0
000;ooooo`;o0000Ooooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@
o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0V_ooool4o`00017ooooo0_l00008ooooo`;o
0000S_ooool001cooooo00?o0000ooooooooool0V_ooool4o`0000Wooooo1?l00002ooooo`Co0000
2?ooool2o`0008kooooo000Looooo`03o`000?oooooooooo0:Oooooo1?l00002ooooo`;o00004_oo
ool2o`000003ooooool0003o000008?ooooo000Looooo`03o`000?oooooooooo0;Wooooo0_l00006
ooooo`;o000000?oooooo`000?l000000oooool2o`0000Kooooo0_l0001fooooo`007?ooool00ol0
003oooooooooo`1/ooooo`;o00002_ooool2o`0002Cooooo0_l0000Dooooo`;o00000oooool2o`00
00kooooo0_l00006ooooo`;o0000M_ooool001cooooo00?o0000ooooooooool0K?ooool2o`0000[o
oooo0_l0000Tooooo`?o00004oooool2o`0009?ooooo000Looooo`03o`000?oooooooooo06cooooo
0_l0000Booooo`;o00007Oooool2o`0000Wooooo0_l0000=ooooo`;o0000S_ooool001cooooo00?o
0000ooooooooool0K_ooool2o`00013ooooo0_l0000Xooooo`;o00003Oooool2o`0008kooooo000L
ooooo`03o`000?oooooooooo06kooooo0_l0000Dooooo`;o0000A_ooool2o`0007_ooooo000Loooo
o`03o`000?oooooooooo08Cooooo0ol0000]ooooo`;o00003Oooool4o`0000;ooooo1Ol0001koooo
o`007?ooool00ol0003oooooooooo`25ooooo`;o0000;Oooool2o`0000gooooo1?l00002ooooo`Co
0000O?ooool001cooooo00?o0000ooooooooool0QOooool2o`000<;ooooo000Looooo`;o0000Q_oo
ool2o`000<;ooooo000Looooo`03o`000?oooooooooo0:7ooooo0_l0000>ooooo`;o0000U_ooool0
01cooooo00?o0000ooooooooool0XOooool2o`0000;ooooo0_l00005ooooo`;o00000oooool2o`00
09Kooooo000Looooo`03o`000?oooooooooo093ooooo0_l0000Cooooo`;o00001Oooool2o`0000go
oooo0_l0002<ooooo`007?ooool00ol0003oooooooooo`2@ooooo`;o000000?oooooo`000?l00000
0_ooool2o`0002;ooooo0_l0002<ooooo`007?ooool00ol0003oooooooooo`2Cooooo`;o00000_oo
ool2o`000;3ooooo000Looooo`03o`000?oooooooooo0:3ooooo0_l0002Wooooo`007?ooool00ol0
003oooooooooo`2Pooooo`;o0000Yoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
S?ooool2o`0000gooooo0_l0002/ooooo`007?ooool00ol0003oooooooooo`2<ooooo`;o00003Ooo
ool2o`000:cooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
Woooool2o`000:Sooooo000Looooo`03o`000?oooooooooo09oooooo0_l0002Xooooo`007?ooool0
0ol0003oooooooooo`2Wooooo`;o0000X?ooool001cooooo00?o0000ooooooooool0Yoooool2o`00
0:3ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Booooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3o
oooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom:oooo
o`005?ooool00ol0003oooooooooo`05ooooo`?o0000oooooom:ooooo`005?ooool00ol0003ooooo
ooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000
ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Booooo`03
oeEEEOmVIVKo00000?ooooooE?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0:Gooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0Eooooo`05olc<c?lQ8B7o
0000ob4Q8Oo<c<`01Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?l@413oc<c<
093ooooo002Vooooo`05o`000?ooooooooooooooool000002Oooool6o`0000Wooooo00Go8B4QoiRH
V?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo00;ooooo00GoEEEEogMgMoooooooV9RHob4Q
8@2@ooooo`00Y_ooool01Ol0003ooooooooooooooooo000001Sooooo00Go0000oooooooooooooooo
o`000003ooooo`Go00000oooool01Ol0003ooooooooooooooooo0000093ooooo002Vooooo`05o`00
0?ooooooooooooooool000002Oooool6o`0000Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P03oooo
o`04odA4A?oMgMgoooooo`0000Cooooo00Go0000oiRHV?ooooooV9RHob4Q8@2@ooooo`00Y_ooool0
1Ol0003oQhN7oooooonYZJWo000001Sooooo00Goc<c<o`000?l0003o0000olc<c003ooooo`04omgM
gOmEEEGoooooo`0000Cooooo00Go0000oeEEEOl0003o410@olc<c02@ooooo`00YOooool00ol@413o
0000ogMgM`02o`000003oiRHV?oooooooooo01Kooooo00Go410@okZj^_oooooo^[Zjoa0@4004oooo
o`03ogMgMoo<c<co000000Cooooo00?oEEEEohN7Qoooool0T_ooool00<?ooooo00Go0000okZj^_oo
oooo^[Zjo`000004ooooo`03onk^k_m4A4Co000000Cooooo00?ogMgMoa0@4?nHV9P0T_ooool00<?o
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@05ooooo`03ogMgMol0003ooooo00Cooooo00Coc<c<odA4
A?l0003o410@T?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(852) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.3983 .68472 Mdot
.38796 .65748 Mdot
.66212 .44219 Mdot
.39459 .40419 Mdot
.42897 .54533 Mdot
.65537 .46554 Mdot
.56011 .64372 Mdot
.59451 .62928 Mdot
.648 .48104 Mdot
.29892 .37208 Mdot
.57402 .60602 Mdot
.31431 .42591 Mdot
.55135 .63171 Mdot
.37669 .42519 Mdot
.75423 .28416 Mdot
.3735 .38252 Mdot
.41121 .61716 Mdot
.62746 .35654 Mdot
.364 .49948 Mdot
.70186 .48436 Mdot
.36466 .70639 Mdot
.37103 .42544 Mdot
.40649 .68481 Mdot
.37658 .42621 Mdot
.41664 .41811 Mdot
.41162 .65317 Mdot
.42397 .61269 Mdot
.42888 .44611 Mdot
.40621 .43724 Mdot
.58159 .59836 Mdot
.52773 .37346 Mdot
.6212 .19617 Mdot
.33889 .38968 Mdot
.19804 .61512 Mdot
.58895 .63571 Mdot
.35683 .24891 Mdot
.66762 .50179 Mdot
.5421 .61651 Mdot
.59426 .62705 Mdot
.56357 .65771 Mdot
.5444 .61851 Mdot
.40735 .647 Mdot
.59104 .65248 Mdot
.60191 .65762 Mdot
.37004 .39691 Mdot
.53823 .73843 Mdot
.48385 .23065 Mdot
.40214 .46795 Mdot
.37475 .65335 Mdot
.69811 .49717 Mdot
.29682 .72559 Mdot
.59243 .64249 Mdot
.77178 .58319 Mdot
.54284 .08957 Mdot
.53964 .63381 Mdot
.38454 .396 Mdot
.66896 .48606 Mdot
.36204 .44653 Mdot
.37452 .43568 Mdot
.29981 .68054 Mdot
.42282 .44848 Mdot
.59624 .36481 Mdot
.37612 .70293 Mdot
.62372 .48732 Mdot
.65283 .47197 Mdot
.59308 .61018 Mdot
.40346 .61978 Mdot
.55946 .63264 Mdot
.43792 .46906 Mdot
.66687 .50864 Mdot
.40117 .46875 Mdot
.56818 .6032 Mdot
.3729 .68366 Mdot
.36474 .47687 Mdot
.5646 .76632 Mdot
.80371 .36774 Mdot
.62768 .33212 Mdot
.29325 .64744 Mdot
.35769 .59877 Mdot
.80704 .45797 Mdot
.39295 .43395 Mdot
.79197 .68252 Mdot
.76747 .30245 Mdot
.40135 .68208 Mdot
.37832 .5265 Mdot
.72354 .48301 Mdot
.34487 .45175 Mdot
.51636 .47321 Mdot
.44506 .43117 Mdot
.5007 .79879 Mdot
.65009 .48625 Mdot
.39751 .63281 Mdot
.39247 .40505 Mdot
.40355 .48289 Mdot
.26555 .55766 Mdot
.40162 .49742 Mdot
.43047 .42548 Mdot
.38039 .61211 Mdot
.58738 .61563 Mdot
.34489 .37432 Mdot
.6154 .60262 Mdot
.75269 .59652 Mdot
.35378 .414 Mdot
.64492 .49734 Mdot
.36756 .62987 Mdot
.33885 .42708 Mdot
.55136 .65192 Mdot
.40837 .45244 Mdot
.59003 .65828 Mdot
.38278 .65595 Mdot
.39764 .48562 Mdot
.62213 .36757 Mdot
.6114 .78498 Mdot
.40446 .62909 Mdot
.75538 .669 Mdot
.41437 .45973 Mdot
.36339 .42846 Mdot
.38997 .65542 Mdot
.67835 .46149 Mdot
.52901 .42834 Mdot
.37474 .63232 Mdot
.57173 .65225 Mdot
.44168 .6408 Mdot
.42892 .50794 Mdot
.64063 .47028 Mdot
.74644 .58953 Mdot
.74614 .57218 Mdot
.43821 .32613 Mdot
.3412 .43998 Mdot
.47776 .69119 Mdot
.66144 .46051 Mdot
.39648 .63841 Mdot
.55949 .62942 Mdot
.393 .3896 Mdot
.43076 .64067 Mdot
.56879 .61363 Mdot
.60474 .3776 Mdot
.63847 .29845 Mdot
.37104 .64674 Mdot
.52847 .57237 Mdot
.52183 .65367 Mdot
.55922 .65778 Mdot
.22681 .66022 Mdot
.38989 .66197 Mdot
.60238 .33501 Mdot
.57014 .61942 Mdot
.53578 .2839 Mdot
.41196 .39887 Mdot
.39164 .32992 Mdot
.66238 .80314 Mdot
.28959 .72621 Mdot
.6697 .6887 Mdot
.61152 .32753 Mdot
.54502 .65733 Mdot
.40775 .42348 Mdot
.39675 .66662 Mdot
.40202 .65841 Mdot
.43585 .45071 Mdot
.42094 .41718 Mdot
.391 .47751 Mdot
.41036 .47759 Mdot
.5363 .23183 Mdot
.39833 .47928 Mdot
.61379 .43477 Mdot
.4161 .63279 Mdot
.42018 .43175 Mdot
.68584 .46198 Mdot
.33979 .40011 Mdot
.55431 .6087 Mdot
.36698 .43596 Mdot
.4093 .40568 Mdot
.3665 .48972 Mdot
.53503 .63255 Mdot
.57578 .19493 Mdot
.64642 .80354 Mdot
.39907 .19728 Mdot
.70569 .6847 Mdot
.67807 .47681 Mdot
.34643 .43308 Mdot
.59792 .34778 Mdot
.27546 .44974 Mdot
.38508 .43975 Mdot
.34429 .78408 Mdot
.42029 .41108 Mdot
.19254 .52052 Mdot
.47181 .46175 Mdot
.3997 .19044 Mdot
.5721 .4429 Mdot
.41133 .44175 Mdot
.25227 .51397 Mdot
.23442 .39672 Mdot
.45799 .59023 Mdot
.5423 .62364 Mdot
.68057 .45835 Mdot
.6653 .49361 Mdot
.5509 .66575 Mdot
.38336 .37116 Mdot
.40019 .35818 Mdot
.31 .3933 Mdot
.74958 .58416 Mdot
.3733 .687 Mdot
.5777 .35154 Mdot
.37036 .66714 Mdot
.83402 .61121 Mdot
.46515 .78935 Mdot
.52179 .661 Mdot
.6038 .31305 Mdot
.66387 .44468 Mdot
.74926 .58109 Mdot
.60263 .34234 Mdot
.38911 .46184 Mdot
.37737 .64538 Mdot
.18969 .47507 Mdot
.46364 .48285 Mdot
.18121 .434 Mdot
.43705 .65484 Mdot
.54313 .45738 Mdot
.55878 .61617 Mdot
.70463 .47269 Mdot
.36707 .4159 Mdot
.37688 .47342 Mdot
.35959 .68737 Mdot
.40092 .46611 Mdot
.39694 .57194 Mdot
.40484 .4018 Mdot
.71283 .50114 Mdot
.63412 .3518 Mdot
.56026 .66465 Mdot
.43535 .32932 Mdot
.39483 .69226 Mdot
.67174 .53906 Mdot
.69318 .49638 Mdot
.26969 .41369 Mdot
.57256 .60345 Mdot
.61924 .36974 Mdot
.69511 .48542 Mdot
.58238 .3317 Mdot
.33586 .44358 Mdot
.66795 .50339 Mdot
.59136 .33202 Mdot
.56786 .22143 Mdot
.3724 .39322 Mdot
.55512 .25192 Mdot
.56661 .64028 Mdot
.44313 .64691 Mdot
.42343 .44629 Mdot
.74026 .57167 Mdot
.32998 .4474 Mdot
.65215 .65328 Mdot
.76769 .57645 Mdot
.77151 .59401 Mdot
.79883 .41594 Mdot
.62307 .35239 Mdot
.63012 .7279 Mdot
.44038 .72087 Mdot
.40179 .61859 Mdot
.38402 .40052 Mdot
.47506 .16225 Mdot
.56936 .61928 Mdot
.38808 .45842 Mdot
.72067 .48976 Mdot
.57026 .62267 Mdot
.35811 .44938 Mdot
.53708 .645 Mdot
.39798 .66227 Mdot
.75443 .47687 Mdot
.42505 .62141 Mdot
.38023 .39267 Mdot
.55387 .64986 Mdot
.6875 .48987 Mdot
.41264 .65739 Mdot
.40461 .45186 Mdot
.36116 .42113 Mdot
.75701 .58712 Mdot
.41597 .43703 Mdot
.48517 .16769 Mdot
.42058 .46117 Mdot
.63456 .45636 Mdot
.41218 .49043 Mdot
.30225 .7638 Mdot
.66336 .34342 Mdot
.39614 .6226 Mdot
.77102 .58906 Mdot
.65345 .48152 Mdot
.75847 .41559 Mdot
.49241 .57915 Mdot
.40087 .44235 Mdot
.76569 .59212 Mdot
.54732 .41861 Mdot
.59069 .59946 Mdot
.39874 .50239 Mdot
.50441 .7812 Mdot
.6979 .47635 Mdot
.75154 .58277 Mdot
.35873 .50385 Mdot
.36721 .62987 Mdot
.3969 .40441 Mdot
.68361 .49848 Mdot
.44175 .63884 Mdot
.34374 .40626 Mdot
.42217 .24645 Mdot
.75733 .57166 Mdot
.5652 .63984 Mdot
.45348 .39841 Mdot
.39799 .47637 Mdot
.67437 .49285 Mdot
.41667 .68112 Mdot
.58453 .63887 Mdot
.41359 .64387 Mdot
.2098 .42931 Mdot
.69819 .6982 Mdot
.50375 .21837 Mdot
.60349 .3118 Mdot
.67065 .6145 Mdot
.37367 .20612 Mdot
.64271 .73769 Mdot
.48719 .30651 Mdot
.25127 .29394 Mdot
.69165 .47251 Mdot
.6307 .31225 Mdot
.65948 .48128 Mdot
.39524 .41643 Mdot
.65269 .46833 Mdot
.39972 .18571 Mdot
.41954 .40903 Mdot
.67724 .4814 Mdot
.73014 .42364 Mdot
.42596 .42899 Mdot
.40855 .62819 Mdot
.73229 .27441 Mdot
.5179 .81942 Mdot
.38365 .75972 Mdot
.68133 .47066 Mdot
.32763 .68585 Mdot
.42868 .44153 Mdot
.33578 .3971 Mdot
.40108 .66934 Mdot
.41341 .49268 Mdot
.57906 .35742 Mdot
.57941 .33386 Mdot
.42497 .33736 Mdot
.73183 .71978 Mdot
.34867 .36975 Mdot
.41085 .66075 Mdot
.3605 .55836 Mdot
.55991 .76444 Mdot
.73657 .58865 Mdot
.55198 .59342 Mdot
.58875 .20349 Mdot
.38873 .36542 Mdot
.51991 .57936 Mdot
.52644 .77815 Mdot
.38472 .6403 Mdot
.52396 .19286 Mdot
.54211 .6302 Mdot
.28203 .51076 Mdot
.21159 .57674 Mdot
.38171 .46997 Mdot
.58262 .60533 Mdot
.3239 .39284 Mdot
.46443 .80458 Mdot
.56674 .27684 Mdot
.84211 .51805 Mdot
.37272 .39463 Mdot
.61681 .73421 Mdot
.36539 .43117 Mdot
.48503 .37519 Mdot
.42073 .46238 Mdot
.41776 .64804 Mdot
.28988 .41961 Mdot
.49507 .52835 Mdot
.70699 .7574 Mdot
.44965 .78904 Mdot
.6071 .32527 Mdot
.36283 .4224 Mdot
.37962 .47051 Mdot
.61912 .3533 Mdot
.42049 .66568 Mdot
.41739 .46592 Mdot
.399 .28725 Mdot
.3896 .47503 Mdot
.54803 .61103 Mdot
.527 .3883 Mdot
.35618 .62328 Mdot
.38622 .49118 Mdot
.41834 .61559 Mdot
.53637 .63777 Mdot
.59586 .61323 Mdot
.44081 .47778 Mdot
.54023 .65338 Mdot
.39664 .40253 Mdot
.54429 .34368 Mdot
.39192 .67733 Mdot
.45319 .50819 Mdot
.42418 .665 Mdot
.3364 .64261 Mdot
.54297 .6511 Mdot
.73983 .57709 Mdot
.4742 .64512 Mdot
.54492 .63317 Mdot
.36624 .75354 Mdot
.33027 .3712 Mdot
.32921 .45944 Mdot
.43694 .79989 Mdot
.68669 .47496 Mdot
.74337 .57859 Mdot
.55837 .65169 Mdot
.39564 .47741 Mdot
.3711 .49742 Mdot
.54887 .60504 Mdot
.29143 .56743 Mdot
.75107 .40383 Mdot
.4309 .43968 Mdot
.42011 .6538 Mdot
.39929 .63777 Mdot
.33659 .41532 Mdot
.39698 .44825 Mdot
.64187 .45148 Mdot
.76554 .57896 Mdot
.75107 .60002 Mdot
.74632 .57306 Mdot
.70787 .46765 Mdot
.56921 .70562 Mdot
.56203 .65793 Mdot
.50195 .70029 Mdot
.64182 .64496 Mdot
.46149 .47381 Mdot
.67943 .49143 Mdot
.36772 .46543 Mdot
.38022 .40925 Mdot
.58365 .63919 Mdot
.69225 .64528 Mdot
.39277 .52567 Mdot
.37687 .66676 Mdot
.53768 .65118 Mdot
.35752 .36023 Mdot
.54991 .68607 Mdot
.58211 .35018 Mdot
.38263 .76261 Mdot
.57713 .60253 Mdot
.39157 .63119 Mdot
.53723 .61266 Mdot
.38278 .47324 Mdot
.43488 .42214 Mdot
.38681 .64985 Mdot
.62357 .34558 Mdot
.40289 .51033 Mdot
.35659 .44802 Mdot
.42878 .8549 Mdot
.56922 .76465 Mdot
.54623 .58428 Mdot
.40759 .43087 Mdot
.35941 .49257 Mdot
.60355 .32048 Mdot
.38984 .47273 Mdot
.36134 .41774 Mdot
.61739 .78723 Mdot
.60615 .58106 Mdot
.62345 .37657 Mdot
.28322 .5081 Mdot
.43709 .65198 Mdot
.52411 .174 Mdot
.75648 .59877 Mdot
.60738 .62247 Mdot
.7517 .48417 Mdot
.75226 .57745 Mdot
.65546 .63208 Mdot
.52598 .18421 Mdot
.74506 .57455 Mdot
.7204 .52755 Mdot
.31916 .48843 Mdot
.43413 .43756 Mdot
.36256 .43711 Mdot
.59338 .34917 Mdot
.39175 .66298 Mdot
.55938 .44905 Mdot
.62183 .26141 Mdot
.36832 .4262 Mdot
.40339 .70856 Mdot
.59179 .22093 Mdot
.75632 .58377 Mdot
.59921 .37101 Mdot
.58021 .37184 Mdot
.36131 .43069 Mdot
.64852 .76189 Mdot
.4109 .65518 Mdot
.40428 .45146 Mdot
.38652 .48574 Mdot
.6829 .47438 Mdot
.38316 .63564 Mdot
.69066 .49866 Mdot
.76288 .57228 Mdot
.25278 .33174 Mdot
.39276 .83793 Mdot
.5832 .6354 Mdot
.4319 .19628 Mdot
.59804 .60649 Mdot
.82696 .46029 Mdot
.75461 .57425 Mdot
.38917 .43819 Mdot
.38905 .69263 Mdot
.4087 .45423 Mdot
.38119 .45932 Mdot
.3878 .46299 Mdot
.32875 .37588 Mdot
.33912 .78092 Mdot
.60795 .35144 Mdot
.44842 .49428 Mdot
.63182 .46966 Mdot
.46404 .17946 Mdot
.73443 .2936 Mdot
.36405 .46807 Mdot
.35737 .42996 Mdot
.41928 .62994 Mdot
.43437 .4582 Mdot
.57738 .59477 Mdot
.41506 .68305 Mdot
.35879 .48627 Mdot
.51129 .19562 Mdot
.41518 .46862 Mdot
.3706 .21395 Mdot
.53917 .61051 Mdot
.37364 .75354 Mdot
.44744 .49139 Mdot
.74292 .57432 Mdot
.74343 .57804 Mdot
.74728 .60329 Mdot
.56572 .59245 Mdot
.67663 .48731 Mdot
.7049 .2938 Mdot
.37404 .37503 Mdot
.40917 .42078 Mdot
.36278 .49506 Mdot
.68493 .44093 Mdot
.51248 .46592 Mdot
.6515 .70725 Mdot
.35044 .36257 Mdot
.64306 .45525 Mdot
.44386 .65325 Mdot
.77576 .63831 Mdot
.41426 .68273 Mdot
.62508 .37493 Mdot
.56798 .60675 Mdot
.58122 .35633 Mdot
.33531 .74459 Mdot
.38493 .65673 Mdot
.35724 .67998 Mdot
.67839 .47883 Mdot
.54919 .48606 Mdot
.49231 .10952 Mdot
.65067 .50722 Mdot
.43103 .30305 Mdot
.40603 .66996 Mdot
.37476 .48841 Mdot
.54458 .40802 Mdot
.54368 .48672 Mdot
.6691 .47611 Mdot
.38631 .42792 Mdot
.70416 .73966 Mdot
.64506 .44929 Mdot
.39505 .50335 Mdot
.66485 .45679 Mdot
.55217 .61267 Mdot
.66464 .45936 Mdot
.40869 .69079 Mdot
.34118 .42669 Mdot
.53012 .09992 Mdot
.59313 .51207 Mdot
.41971 .45128 Mdot
.53756 .65089 Mdot
.36913 .28629 Mdot
.37366 .45669 Mdot
.58066 .36413 Mdot
.64011 .4668 Mdot
.73328 .37416 Mdot
.42723 .44562 Mdot
.66671 .46643 Mdot
.39933 .68707 Mdot
.60117 .59514 Mdot
.80472 .41231 Mdot
.74262 .58941 Mdot
.39458 .67073 Mdot
.78076 .59523 Mdot
.52411 .62297 Mdot
.37792 .49762 Mdot
.38948 .48317 Mdot
.41884 .64014 Mdot
.76764 .52971 Mdot
.42482 .47294 Mdot
.39274 .43386 Mdot
.67496 .44676 Mdot
.65149 .43696 Mdot
.76812 .49867 Mdot
.69145 .47477 Mdot
.37568 .50421 Mdot
.41828 .64055 Mdot
.38677 .40925 Mdot
.40587 .6258 Mdot
.38563 .40117 Mdot
.45567 .64526 Mdot
.40063 .68062 Mdot
.7174 .70319 Mdot
.3858 .41686 Mdot
.46777 .42799 Mdot
.38376 .46251 Mdot
.3973 .47084 Mdot
.635 .47789 Mdot
.61326 .35854 Mdot
.44146 .411 Mdot
.62273 .51591 Mdot
.59792 .37354 Mdot
.21896 .42787 Mdot
.68349 .47197 Mdot
.58847 .35227 Mdot
.55931 .24453 Mdot
.77023 .59335 Mdot
.60083 .35355 Mdot
.72387 .28419 Mdot
.58356 .63658 Mdot
.43923 .65837 Mdot
.42549 .42807 Mdot
.2362 .32192 Mdot
.53444 .35394 Mdot
.76246 .58849 Mdot
.4202 .45672 Mdot
.36845 .46253 Mdot
.37892 .6195 Mdot
.82055 .63939 Mdot
.65983 .44041 Mdot
.40026 .41365 Mdot
.41899 .62081 Mdot
.69533 .78519 Mdot
.63786 .48814 Mdot
.59791 .3518 Mdot
.54233 .61184 Mdot
.4113 .60143 Mdot
.74242 .59025 Mdot
.59007 .59743 Mdot
.73855 .48725 Mdot
.34645 .75365 Mdot
.41395 .46274 Mdot
.67639 .49638 Mdot
.29368 .73357 Mdot
.36661 .37073 Mdot
.51975 .59558 Mdot
.39149 .34249 Mdot
.38733 .63746 Mdot
.54699 .60762 Mdot
.58373 .33513 Mdot
.41453 .68517 Mdot
.41976 .66433 Mdot
.59053 .63827 Mdot
.68641 .4329 Mdot
.54247 .46229 Mdot
.55593 .60497 Mdot
.51372 .79541 Mdot
.19731 .46092 Mdot
.76774 .58735 Mdot
.6093 .37051 Mdot
.17543 .55141 Mdot
.40807 .64665 Mdot
.58609 .20184 Mdot
.3224 .75868 Mdot
.43059 .426 Mdot
.59183 .33732 Mdot
.61017 .68598 Mdot
.68655 .28006 Mdot
.57106 .62647 Mdot
.49238 .50903 Mdot
.59388 .38253 Mdot
.43026 .45197 Mdot
.36044 .72386 Mdot
.3915 .4222 Mdot
.56353 .61017 Mdot
.35226 .61496 Mdot
.39348 .62945 Mdot
.52208 .62828 Mdot
.37612 .76261 Mdot
.37739 .40913 Mdot
.38684 .4224 Mdot
.50357 .35957 Mdot
.37612 .64746 Mdot
.74722 .5978 Mdot
.40898 .44775 Mdot
.36198 .444 Mdot
.37452 .49379 Mdot
.42408 .3731 Mdot
.6265 .76873 Mdot
.39792 .41342 Mdot
.70809 .49264 Mdot
.32808 .42018 Mdot
.38298 .41897 Mdot
.41157 .61521 Mdot
.38909 .82946 Mdot
.74559 .56948 Mdot
.36582 .4385 Mdot
.41395 .46642 Mdot
.58626 .64097 Mdot
.548 .43791 Mdot
.54136 .49349 Mdot
.6544 .50534 Mdot
.50241 .28613 Mdot
.32738 .37753 Mdot
.43368 .64631 Mdot
.61532 .376 Mdot
.3481 .46287 Mdot
.42845 .63403 Mdot
.35405 .38809 Mdot
.64662 .45035 Mdot
.76678 .58312 Mdot
.41795 .75733 Mdot
.5973 .35953 Mdot
.56603 .3977 Mdot
.49523 .71827 Mdot
.68102 .45719 Mdot
.41322 .42064 Mdot
.60552 .61451 Mdot
.66415 .50542 Mdot
.75746 .58908 Mdot
.39064 .51955 Mdot
.40433 .66009 Mdot
.40133 .63068 Mdot
.4481 .34458 Mdot
.61976 .49929 Mdot
.53817 .84679 Mdot
.55377 .61187 Mdot
.3325 .44172 Mdot
.45665 .70883 Mdot
.40228 .62982 Mdot
.44359 .34035 Mdot
.58822 .35394 Mdot
.57124 .62848 Mdot
.73512 .59191 Mdot
.42543 .63258 Mdot
.37317 .64593 Mdot
.36314 .39613 Mdot
.35173 .45462 Mdot
.47923 .30955 Mdot
.42516 .33628 Mdot
.53685 .62955 Mdot
.61738 .36296 Mdot
.68247 .50761 Mdot
.39686 .42077 Mdot
.40252 .68298 Mdot
.1956 .49477 Mdot
.40883 .4744 Mdot
.64155 .45108 Mdot
.38746 .6404 Mdot
.62032 .35246 Mdot
.58676 .36915 Mdot
.39669 .47078 Mdot
.30036 .66532 Mdot
.54723 .64229 Mdot
.40446 .62816 Mdot
.3955 .72967 Mdot
.42274 .47732 Mdot
.34753 .44881 Mdot
.31761 .45612 Mdot
.59292 .60482 Mdot
.38505 .75073 Mdot
.62365 .3702 Mdot
.39981 .65232 Mdot
.41656 .45314 Mdot
.59586 .36424 Mdot
.41516 .73659 Mdot
.75863 .57794 Mdot
.66147 .45762 Mdot
.57887 .36055 Mdot
.61343 .3381 Mdot
.60394 .37579 Mdot
.60191 .20631 Mdot
.37072 .68284 Mdot
.36797 .55416 Mdot
.4227 .46122 Mdot
.45621 .34846 Mdot
.43209 .4072 Mdot
.55795 .59575 Mdot
.68887 .47696 Mdot
.37988 .46265 Mdot
.36168 .39709 Mdot
.4382 .36921 Mdot
.44678 .40007 Mdot
.37347 .71161 Mdot
.38007 .65028 Mdot
.45569 .41926 Mdot
.68507 .47861 Mdot
.81964 .66096 Mdot
.45057 .14137 Mdot
.44353 .49015 Mdot
.55167 .45852 Mdot
.40724 .68362 Mdot
.58902 .64178 Mdot
.53264 .5037 Mdot
.53018 .62895 Mdot
.39808 .6472 Mdot
.39649 .41862 Mdot
.50691 .70289 Mdot
.59469 .31957 Mdot
.39141 .47881 Mdot
.56239 .61723 Mdot
.39135 .4782 Mdot
.56813 .59557 Mdot
.45053 .60351 Mdot
.53271 .78381 Mdot
.42171 .41243 Mdot
.40595 .49161 Mdot
.45171 .38621 Mdot
.36202 .46522 Mdot
.80455 .56425 Mdot
.41663 .6745 Mdot
.71912 .72778 Mdot
.34722 .40381 Mdot
.31883 .63486 Mdot
.42404 .46438 Mdot
.74596 .54351 Mdot
.35246 .46012 Mdot
.52096 .53035 Mdot
.43282 .43787 Mdot
.35228 .42575 Mdot
.54947 .64904 Mdot
.58696 .64041 Mdot
.38715 .67996 Mdot
.74375 .59489 Mdot
.41141 .19064 Mdot
.35229 .44829 Mdot
.71163 .48327 Mdot
.52849 .58081 Mdot
.61663 .3452 Mdot
.40059 .64575 Mdot
.69611 .79287 Mdot
.537 .64296 Mdot
.64949 .51347 Mdot
.77323 .5403 Mdot
.7039 .47675 Mdot
.61312 .58999 Mdot
.30631 .37602 Mdot
.62124 .34206 Mdot
.42854 .45774 Mdot
.20409 .61971 Mdot
.584 .74823 Mdot
.40672 .51182 Mdot
.52399 .63283 Mdot
.28847 .4763 Mdot
.17826 .55439 Mdot
.57476 .36135 Mdot
.59499 .32654 Mdot
.54437 .64596 Mdot
.68735 .45288 Mdot
.31086 .3977 Mdot
.58726 .354 Mdot
.66625 .45066 Mdot
.75412 .6044 Mdot
.48032 .5741 Mdot
.40889 .65265 Mdot
.38976 .76155 Mdot
.50312 .74504 Mdot
.53608 .63192 Mdot
.65214 .53428 Mdot
.43428 .61399 Mdot
.36238 .64066 Mdot
.73873 .5847 Mdot
.63452 .4778 Mdot
.39135 .69536 Mdot
.39395 .50753 Mdot
.4697 .45653 Mdot
.36727 .43072 Mdot
.5964 .34107 Mdot
.36279 .47054 Mdot
.63467 .4692 Mdot
.56755 .62612 Mdot
.65287 .495 Mdot
.55448 .64681 Mdot
.54689 .71205 Mdot
.39965 .45406 Mdot
.35206 .42868 Mdot
.53984 .36699 Mdot
.37202 .66427 Mdot
.31562 .73168 Mdot
.7127 .48107 Mdot
.66484 .48494 Mdot
.37347 .40661 Mdot
.4058 .6885 Mdot
.63109 .37433 Mdot
.54486 .37303 Mdot
.37563 .48347 Mdot
.41667 .67515 Mdot
.40433 .41671 Mdot
.55589 .23131 Mdot
.55692 .78712 Mdot
.41199 .64005 Mdot
.74598 .71698 Mdot
.40218 .43028 Mdot
.32591 .50143 Mdot
.36275 .4958 Mdot
.42721 .28107 Mdot
.42264 .47874 Mdot
.43669 .65721 Mdot
.36891 .43521 Mdot
.42227 .67697 Mdot
.68149 .45308 Mdot
.57617 .65362 Mdot
.39701 .67308 Mdot
.37421 .48547 Mdot
.58931 .18145 Mdot
.55777 .61295 Mdot
.36411 .42091 Mdot
.58416 .61608 Mdot
.43083 .62967 Mdot
.37489 .65842 Mdot
.73203 .30172 Mdot
.57791 .57681 Mdot
.54974 .61547 Mdot
.40379 .41015 Mdot
.47092 .75716 Mdot
.39002 .41095 Mdot
.47415 .31567 Mdot
.3551 .40567 Mdot
.41669 .48616 Mdot
.82741 .3967 Mdot
.60167 .61085 Mdot
.55346 .83987 Mdot
.61458 .25704 Mdot
.61528 .20802 Mdot
.39924 .59653 Mdot
.57485 .36198 Mdot
.53407 .1932 Mdot
.76629 .57503 Mdot
.64948 .45993 Mdot
.38055 .46372 Mdot
.3971 .58281 Mdot
.54344 .61353 Mdot
.6135 .35442 Mdot
.41999 .41054 Mdot
.63566 .45753 Mdot
.77297 .38886 Mdot
.54281 .65609 Mdot
.40662 .64674 Mdot
.37405 .66435 Mdot
.67859 .79143 Mdot
.41747 .45527 Mdot
.35834 .42541 Mdot
.56767 .60772 Mdot
.40335 .37442 Mdot
.62164 .36288 Mdot
.70157 .40691 Mdot
.54927 .61673 Mdot
.60542 .54451 Mdot
.38293 .65897 Mdot
.36856 .46425 Mdot
.51487 .45256 Mdot
.62172 .55922 Mdot
.24412 .45054 Mdot
.59582 .34733 Mdot
.49099 .32437 Mdot
.43691 .65629 Mdot
.56141 .62548 Mdot
.62493 .29473 Mdot
.33019 .44196 Mdot
.36603 .45768 Mdot
.49328 .32828 Mdot
.55082 .42949 Mdot
.62629 .39226 Mdot
.43839 .44796 Mdot
.54508 .42392 Mdot
.36791 .40749 Mdot
.36346 .49097 Mdot
.4292 .48404 Mdot
.3428 .44025 Mdot
.41405 .67848 Mdot
.4246 .36105 Mdot
.66209 .46239 Mdot
.26821 .54995 Mdot
.50073 .50637 Mdot
.42114 .44043 Mdot
.39312 .41622 Mdot
.2578 .43781 Mdot
.61213 .57797 Mdot
.41281 .67359 Mdot
.39278 .69983 Mdot
.55127 .65465 Mdot
.47118 .44071 Mdot
.68621 .44551 Mdot
.40523 .34683 Mdot
.6498 .4928 Mdot
.41846 .67467 Mdot
.66819 .49011 Mdot
.55836 .6551 Mdot
.67606 .49695 Mdot
.70921 .47068 Mdot
.55487 .6012 Mdot
.38304 .66519 Mdot
.37147 .47934 Mdot
.54437 .65301 Mdot
.50131 .35616 Mdot
.59522 .34226 Mdot
.73182 .30099 Mdot
.33002 .41502 Mdot
.48712 .48401 Mdot
.42446 .24607 Mdot
.65561 .49461 Mdot
.57369 .79316 Mdot
.39983 .68007 Mdot
.61497 .31995 Mdot
.41508 .67942 Mdot
.33572 .7672 Mdot
.61497 .36066 Mdot
.72148 .28161 Mdot
.64778 .41024 Mdot
.74678 .36083 Mdot
.43931 .43458 Mdot
.45847 .65351 Mdot
.67497 .50504 Mdot
.54185 .61622 Mdot
.69555 .43408 Mdot
.3482 .42431 Mdot
.65249 .73066 Mdot
.36649 .64186 Mdot
.76154 .60163 Mdot
.55792 .6321 Mdot
.52507 .64235 Mdot
.41243 .45962 Mdot
.76291 .44984 Mdot
.34474 .41894 Mdot
.6441 .36829 Mdot
.49517 .3039 Mdot
.39718 .34467 Mdot
.39338 .40121 Mdot
.65156 .49975 Mdot
.40501 .41618 Mdot
.29533 .47794 Mdot
.22133 .65248 Mdot
.33277 .47845 Mdot
.71013 .69651 Mdot
.56122 .37415 Mdot
.38715 .65384 Mdot
.45105 .48329 Mdot
.75519 .5944 Mdot
.40514 .43076 Mdot
.13455 .52188 Mdot
.60182 .35633 Mdot
.70564 .52682 Mdot
.42028 .47387 Mdot
.41019 .45136 Mdot
.24169 .65075 Mdot
.40792 .58212 Mdot
.73358 .59012 Mdot
.36564 .45238 Mdot
.51873 .29059 Mdot
.59189 .61759 Mdot
.33931 .41925 Mdot
.36254 .43466 Mdot
.22963 .39981 Mdot
.58946 .60411 Mdot
.65988 .49584 Mdot
.76992 .58077 Mdot
.68543 .50733 Mdot
.59348 .38705 Mdot
.54264 .51153 Mdot
.40261 .32989 Mdot
.55642 .78477 Mdot
.58636 .37477 Mdot
.39621 .48459 Mdot
.38807 .52693 Mdot
.40306 .43819 Mdot
.58967 .32833 Mdot
.58296 .59959 Mdot
.40575 .67777 Mdot
.43048 .75627 Mdot
.75127 .58484 Mdot
.39299 .50309 Mdot
.57793 .34308 Mdot
.39965 .66514 Mdot
.64168 .53932 Mdot
.39346 .65443 Mdot
.54587 .62793 Mdot
.54423 .60083 Mdot
.6059 .36617 Mdot
.41775 .67787 Mdot
.69236 .5087 Mdot
.62118 .26352 Mdot
.36367 .40203 Mdot
.51676 .61995 Mdot
.39357 .68884 Mdot
.41537 .61094 Mdot
.36577 .65161 Mdot
.40161 .46153 Mdot
.54906 .44777 Mdot
.35745 .48741 Mdot
.54076 .64347 Mdot
.65937 .45365 Mdot
.37619 .3304 Mdot
.24678 .66519 Mdot
.60071 .53163 Mdot
.44414 .42558 Mdot
.37084 .41659 Mdot
.36148 .43049 Mdot
.39777 .39372 Mdot
.63914 .30785 Mdot
.39764 .45051 Mdot
.55209 .64856 Mdot
.64055 .48157 Mdot
.42264 .45172 Mdot
.75701 .59631 Mdot
.53533 .45931 Mdot
.60884 .37971 Mdot
.51669 .51565 Mdot
.52904 .16492 Mdot
.40003 .66667 Mdot
.6926 .48966 Mdot
.65122 .46104 Mdot
.60535 .37758 Mdot
.54015 .62169 Mdot
.39298 .65966 Mdot
.43832 .27183 Mdot
.61085 .37223 Mdot
.36705 .43896 Mdot
.74015 .47212 Mdot
.76107 .67812 Mdot
.42979 .46235 Mdot
.38065 .45106 Mdot
.77172 .58905 Mdot
.68755 .45012 Mdot
.19521 .35937 Mdot
.55633 .41379 Mdot
.61004 .3624 Mdot
.6074 .32986 Mdot
.36451 .65592 Mdot
.4253 .50674 Mdot
.55576 .64448 Mdot
.54006 .39639 Mdot
.36622 .29956 Mdot
.5944 .41483 Mdot
.82302 .45704 Mdot
.40378 .47312 Mdot
.24316 .64112 Mdot
.38803 .40442 Mdot
.37244 .62478 Mdot
.40003 .61995 Mdot
.41198 .66821 Mdot
.54115 .63808 Mdot
.34042 .62535 Mdot
.55834 .64887 Mdot
.49723 .14898 Mdot
.42882 .67571 Mdot
.68155 .32644 Mdot
.67275 .48632 Mdot
.42124 .39146 Mdot
.62172 .35248 Mdot
.61994 .60458 Mdot
.43688 .47231 Mdot
.63906 .76045 Mdot
.67872 .49203 Mdot
.37801 .6584 Mdot
.3011 .3898 Mdot
.33022 .22344 Mdot
.5553 .49483 Mdot
.39613 .54963 Mdot
.30737 .71712 Mdot
.61801 .35678 Mdot
.24712 .45899 Mdot
.62418 .34268 Mdot
.57008 .61719 Mdot
.34524 .42826 Mdot
.34198 .44489 Mdot
.38839 .40038 Mdot
.39715 .45225 Mdot
.58056 .64282 Mdot
.36917 .38965 Mdot
.30235 .76383 Mdot
.76924 .58675 Mdot
.5551 .22068 Mdot
.58388 .35313 Mdot
.53071 .61916 Mdot
.64378 .48573 Mdot
.74827 .60026 Mdot
.41899 .32752 Mdot
.43202 .4357 Mdot
.38202 .46219 Mdot
.7359 .57904 Mdot
.43199 .47686 Mdot
.34269 .36588 Mdot
.66136 .46373 Mdot
.59062 .52174 Mdot
.5763 .35708 Mdot
.58132 .35527 Mdot
.56907 .59967 Mdot
.41662 .67884 Mdot
.59077 .3522 Mdot
.67679 .44677 Mdot
.36138 .38964 Mdot
.3642 .48367 Mdot
.39246 .68829 Mdot
.32276 .75926 Mdot
.57392 .36312 Mdot
.29931 .39532 Mdot
.43192 .66611 Mdot
.36224 .667 Mdot
.36768 .45536 Mdot
.32478 .46905 Mdot
.43383 .61894 Mdot
.58643 .37105 Mdot
.52896 .62216 Mdot
.71315 .32368 Mdot
.56614 .61285 Mdot
.39473 .66307 Mdot
.33915 .40894 Mdot
.3828 .6627 Mdot
.4099 .43553 Mdot
.88106 .42959 Mdot
.3466 .45352 Mdot
.49483 .81846 Mdot
.43767 .2885 Mdot
.64892 .46385 Mdot
.69321 .50749 Mdot
.76381 .59416 Mdot
.43315 .66513 Mdot
.34534 .45899 Mdot
.61352 .33149 Mdot
.64465 .23135 Mdot
.45363 .64422 Mdot
.6489 .45257 Mdot
.6891 .44859 Mdot
.58771 .59829 Mdot
.41993 .46978 Mdot
.36538 .46342 Mdot
.67336 .49798 Mdot
.4525 .23361 Mdot
.4313 .6456 Mdot
.35992 .42475 Mdot
.37598 .41649 Mdot
.65368 .46433 Mdot
.62043 .2649 Mdot
.4575 .61914 Mdot
.34506 .43211 Mdot
.56493 .35738 Mdot
.56397 .59342 Mdot
.39823 .39536 Mdot
.37194 .38925 Mdot
.60425 .33251 Mdot
.50265 .20347 Mdot
.18323 .59252 Mdot
.54924 .6016 Mdot
.74754 .59756 Mdot
.38001 .48998 Mdot
.6729 .48447 Mdot
.37117 .48566 Mdot
.36336 .23724 Mdot
.76817 .59516 Mdot
.39344 .44286 Mdot
.43906 .49079 Mdot
.38655 .62885 Mdot
.40083 .44809 Mdot
.24687 .39748 Mdot
.66366 .51086 Mdot
.39648 .44544 Mdot
.30618 .68561 Mdot
.59247 .60839 Mdot
.445 .48635 Mdot
.58318 .34089 Mdot
.42099 .28023 Mdot
.49951 .72783 Mdot
.68419 .43925 Mdot
.58329 .35951 Mdot
.3723 .48144 Mdot
.69049 .45649 Mdot
.53721 .62137 Mdot
.63632 .7452 Mdot
.43005 .41831 Mdot
.56171 .61113 Mdot
.56602 .62748 Mdot
.60115 .36382 Mdot
.58852 .83209 Mdot
.44324 .40862 Mdot
.36345 .46815 Mdot
.24838 .37029 Mdot
.37722 .62876 Mdot
.36855 .47516 Mdot
.40379 .47938 Mdot
.56779 .64206 Mdot
.47259 .65117 Mdot
.30742 .5077 Mdot
.72946 .42382 Mdot
.56728 .59512 Mdot
.65106 .42669 Mdot
.6914 .45788 Mdot
.58466 .35245 Mdot
.38866 .64701 Mdot
.60189 .38456 Mdot
.67717 .4674 Mdot
.41538 .46621 Mdot
.57354 .63426 Mdot
.22067 .49559 Mdot
.59494 .63854 Mdot
.62413 .47466 Mdot
.39293 .61058 Mdot
.45882 .71438 Mdot
.16714 .60906 Mdot
.51686 .74016 Mdot
.59101 .65271 Mdot
.61635 .34448 Mdot
.71229 .44267 Mdot
.37377 .41688 Mdot
.26162 .48931 Mdot
.38203 .47999 Mdot
.3041 .70481 Mdot
.68706 .46784 Mdot
.73799 .58527 Mdot
.34421 .42961 Mdot
.49801 .31323 Mdot
.54067 .6616 Mdot
.58851 .59778 Mdot
.38912 .45133 Mdot
.54446 .63238 Mdot
.35413 .45496 Mdot
.63874 .48349 Mdot
.53629 .83368 Mdot
.36765 .41841 Mdot
.34618 .48313 Mdot
.58374 .57114 Mdot
.72964 .29645 Mdot
.7006 .50631 Mdot
.24188 .64228 Mdot
.29726 .24937 Mdot
.54556 .63376 Mdot
.40734 .51527 Mdot
.6748 .50247 Mdot
.77183 .58979 Mdot
.67989 .51867 Mdot
.38333 .47679 Mdot
.39169 .47118 Mdot
.3746 .40616 Mdot
.38761 .42244 Mdot
.25993 .48248 Mdot
.41277 .37022 Mdot
.24796 .62632 Mdot
.38222 .45991 Mdot
.36668 .72474 Mdot
.5644 .6493 Mdot
.36981 .70788 Mdot
.57024 .34939 Mdot
.40582 .47126 Mdot
.38772 .58081 Mdot
.54261 .60556 Mdot
.49451 .14933 Mdot
.58855 .60038 Mdot
.65209 .48085 Mdot
.59718 .62752 Mdot
.41468 .43751 Mdot
.39993 .63704 Mdot
.65159 .50662 Mdot
.63054 .71321 Mdot
.64831 .45939 Mdot
.41984 .45172 Mdot
.63141 .28526 Mdot
.65369 .4601 Mdot
.52853 .47584 Mdot
.3951 .63756 Mdot
.52438 .29344 Mdot
.4055 .61887 Mdot
.39633 .44231 Mdot
.39438 .43864 Mdot
.76191 .60486 Mdot
.55647 .66039 Mdot
.43405 .63295 Mdot
.43854 .85799 Mdot
.61032 .3886 Mdot
.41511 .66115 Mdot
.36635 .37695 Mdot
.55271 .44058 Mdot
.4116 .63399 Mdot
.48425 .2708 Mdot
.53931 .62161 Mdot
.37661 .68837 Mdot
.34324 .38547 Mdot
.52111 .57356 Mdot
.6022 .31648 Mdot
.6299 .46658 Mdot
.55099 .54503 Mdot
.67656 .50566 Mdot
.53639 .60892 Mdot
.62525 .4639 Mdot
.59175 .62251 Mdot
.35713 .73975 Mdot
.39093 .56906 Mdot
.59429 .64301 Mdot
.53038 .61359 Mdot
.67531 .47388 Mdot
.42198 .41031 Mdot
.47941 .5338 Mdot
.43817 .455 Mdot
.43433 .41755 Mdot
.59333 .61823 Mdot
.43262 .63588 Mdot
.4373 .66612 Mdot
.44332 .68712 Mdot
.37164 .66014 Mdot
.64456 .49033 Mdot
.5523 .79375 Mdot
.33227 .74284 Mdot
.5756 .6048 Mdot
.52587 .6127 Mdot
.39108 .41223 Mdot
.67455 .48118 Mdot
.68396 .45707 Mdot
.56245 .64031 Mdot
.23892 .49728 Mdot
.3483 .48112 Mdot
.3971 .61334 Mdot
.42549 .67889 Mdot
.41595 .64041 Mdot
.36696 .65902 Mdot
.3339 .55286 Mdot
.54078 .61753 Mdot
.43117 .67083 Mdot
.39017 .44687 Mdot
.38902 .47316 Mdot
.74368 .5836 Mdot
.58086 .34928 Mdot
.35278 .38667 Mdot
.33759 .48194 Mdot
.36856 .45763 Mdot
.65969 .4577 Mdot
.42381 .52554 Mdot
.75872 .59976 Mdot
.64707 .44327 Mdot
.69124 .44719 Mdot
.74038 .57717 Mdot
.4166 .71111 Mdot
.3102 .22922 Mdot
.40042 .4139 Mdot
.42579 .53702 Mdot
.66928 .48142 Mdot
.58404 .80751 Mdot
.3958 .74668 Mdot
.39395 .40019 Mdot
.4972 .57072 Mdot
.64455 .50065 Mdot
.37183 .63334 Mdot
.37486 .47807 Mdot
.7504 .57284 Mdot
.61159 .378 Mdot
.36156 .37672 Mdot
.77048 .58072 Mdot
.42249 .67213 Mdot
.62453 .30887 Mdot
.36795 .67647 Mdot
.64252 .50012 Mdot
.44128 .48745 Mdot
.49538 .10671 Mdot
.6929 .49579 Mdot
.64552 .2408 Mdot
.42008 .58249 Mdot
.36235 .4189 Mdot
.68915 .49965 Mdot
.37549 .62726 Mdot
.56097 .59337 Mdot
.5385 .4202 Mdot
.39415 .67753 Mdot
.74377 .59602 Mdot
.74605 .57901 Mdot
.65888 .46281 Mdot
.38042 .64526 Mdot
.33959 .4149 Mdot
.39971 .62338 Mdot
.59922 .6206 Mdot
.41062 .40683 Mdot
.39492 .19022 Mdot
.46767 .44579 Mdot
.4362 .65289 Mdot
.63832 .45249 Mdot
.60431 .31944 Mdot
.42829 .42384 Mdot
.61614 .24086 Mdot
.41373 .47467 Mdot
.58729 .61026 Mdot
.6759 .76497 Mdot
.2227 .47042 Mdot
.42458 .45801 Mdot
.39082 .4132 Mdot
.5517 .60285 Mdot
.43136 .4316 Mdot
.42574 .4668 Mdot
.53394 .58411 Mdot
.38984 .62856 Mdot
.3702 .42966 Mdot
.67097 .4493 Mdot
.23994 .66753 Mdot
.38369 .49193 Mdot
.71744 .6777 Mdot
.51482 .30369 Mdot
.64956 .78695 Mdot
.36387 .47695 Mdot
.496 .36415 Mdot
.38551 .43125 Mdot
.40447 .46622 Mdot
.39903 .40848 Mdot
.22658 .61573 Mdot
.67778 .47421 Mdot
.63734 .46178 Mdot
.6013 .31576 Mdot
.51388 .30055 Mdot
.59382 .33522 Mdot
.56854 .59719 Mdot
.7978 .42521 Mdot
.76849 .59159 Mdot
.41758 .67891 Mdot
.33701 .43446 Mdot
.64813 .50734 Mdot
.37145 .46712 Mdot
.41219 .43396 Mdot
.64016 .49288 Mdot
.69928 .47911 Mdot
.67615 .5342 Mdot
.62425 .35064 Mdot
.40529 .67309 Mdot
.36999 .39362 Mdot
.5979 .37336 Mdot
.33583 .42001 Mdot
.55441 .42167 Mdot
.40855 .67342 Mdot
.39624 .62376 Mdot
.43114 .62439 Mdot
.4153 .46674 Mdot
.41967 .43708 Mdot
.56034 .64846 Mdot
.40183 .69105 Mdot
.5664 .60193 Mdot
.66707 .50629 Mdot
.67591 .51433 Mdot
.38375 .47665 Mdot
.29072 .40613 Mdot
.61136 .33287 Mdot
.65251 .4859 Mdot
.73479 .57931 Mdot
.61393 .32146 Mdot
.41909 .45783 Mdot
.65347 .50065 Mdot
.58045 .35587 Mdot
.24295 .53901 Mdot
.27133 .27058 Mdot
.60102 .32111 Mdot
.38829 .44926 Mdot
.2478 .66049 Mdot
.59967 .27574 Mdot
.61528 .38554 Mdot
.58017 .61268 Mdot
.40974 .47577 Mdot
.34438 .28126 Mdot
.58621 .37745 Mdot
.30587 .72568 Mdot
.64723 .46594 Mdot
.48131 .61848 Mdot
.3295 .39533 Mdot
.26867 .5111 Mdot
.60614 .38594 Mdot
.39656 .65629 Mdot
.43238 .68271 Mdot
.37682 .44218 Mdot
.56949 .34219 Mdot
.59311 .59896 Mdot
.64188 .46885 Mdot
.71057 .48763 Mdot
.38163 .64056 Mdot
.48836 .76858 Mdot
.65965 .44747 Mdot
.29608 .41084 Mdot
.75249 .47565 Mdot
.46848 .48118 Mdot
.3428 .71326 Mdot
.61145 .71399 Mdot
.36498 .4871 Mdot
.60369 .32334 Mdot
.52973 .62689 Mdot
.55009 .64675 Mdot
.54749 .6224 Mdot
.69852 .50188 Mdot
.5295 .50574 Mdot
.68266 .49067 Mdot
.63387 .73768 Mdot
.59539 .36387 Mdot
.53558 .27451 Mdot
.3449 .45654 Mdot
.36984 .41744 Mdot
.32933 .42794 Mdot
.35005 .41581 Mdot
.38228 .42909 Mdot
.5406 .62325 Mdot
.70517 .4874 Mdot
.73147 .37622 Mdot
.42119 .65246 Mdot
.70457 .54269 Mdot
.6727 .48665 Mdot
.77117 .58957 Mdot
.60979 .35125 Mdot
.48834 .37675 Mdot
.64408 .43779 Mdot
.66721 .48942 Mdot
.36827 .38615 Mdot
.41971 .6284 Mdot
.33857 .36112 Mdot
.39209 .43328 Mdot
.65323 .48907 Mdot
.64016 .41558 Mdot
.26021 .41158 Mdot
.3237 .47712 Mdot
.63527 .34637 Mdot
.55187 .44662 Mdot
.62633 .36362 Mdot
.31894 .44019 Mdot
.59111 .80617 Mdot
.67624 .46747 Mdot
.65327 .47428 Mdot
.57974 .34061 Mdot
.31786 .4918 Mdot
.38484 .64335 Mdot
.73764 .58554 Mdot
.58464 .62146 Mdot
.40123 .43877 Mdot
.68915 .50719 Mdot
.3658 .53627 Mdot
.75608 .42813 Mdot
.55156 .6167 Mdot
.64894 .44275 Mdot
.42097 .46677 Mdot
.38655 .4502 Mdot
.61867 .35279 Mdot
.44008 .53813 Mdot
.39762 .38095 Mdot
.61423 .20733 Mdot
.5326 .78232 Mdot
.47567 .79152 Mdot
.36584 .45779 Mdot
.38048 .63914 Mdot
.75357 .57462 Mdot
.61103 .36983 Mdot
.35175 .39885 Mdot
.27957 .26192 Mdot
.44512 .64407 Mdot
.56423 .61937 Mdot
.74722 .57382 Mdot
.52882 .50386 Mdot
.41068 .47659 Mdot
.38142 .47987 Mdot
.39962 .4572 Mdot
.23788 .28855 Mdot
.65276 .45035 Mdot
.36715 .65029 Mdot
.59802 .34481 Mdot
.36883 .65346 Mdot
.64139 .46028 Mdot
.44375 .7532 Mdot
.42576 .44601 Mdot
.39374 .61285 Mdot
.39655 .65293 Mdot
.58653 .59775 Mdot
.57087 .59047 Mdot
.67849 .53493 Mdot
.34575 .45134 Mdot
.75323 .57246 Mdot
.40212 .61899 Mdot
.70042 .46994 Mdot
.61575 .36006 Mdot
.54547 .65221 Mdot
.38344 .45996 Mdot
.66902 .46323 Mdot
.40811 .50884 Mdot
.41375 .63147 Mdot
.66764 .48873 Mdot
.74794 .56773 Mdot
.59862 .32859 Mdot
.38782 .46721 Mdot
.63444 .3714 Mdot
.73791 .57745 Mdot
.37658 .41476 Mdot
.40187 .34001 Mdot
.60046 .39894 Mdot
.6418 .70985 Mdot
.68781 .49105 Mdot
.74904 .59192 Mdot
.39277 .62232 Mdot
.4577 .69245 Mdot
.64927 .47529 Mdot
.45878 .36017 Mdot
.44375 .54814 Mdot
.37445 .3928 Mdot
.41007 .64407 Mdot
.69151 .42693 Mdot
.56398 .18731 Mdot
.57489 .25565 Mdot
.36334 .425 Mdot
.68681 .50132 Mdot
.58178 .3624 Mdot
.5773 .60464 Mdot
.71892 .67856 Mdot
.36767 .57057 Mdot
.62772 .45789 Mdot
.397 .41079 Mdot
.40382 .61952 Mdot
.56184 .63917 Mdot
.51758 .70285 Mdot
.66747 .44276 Mdot
.68946 .47212 Mdot
.42321 .45535 Mdot
.58998 .3572 Mdot
.50419 .22883 Mdot
.63445 .46549 Mdot
.69047 .5048 Mdot
.73294 .53593 Mdot
.57917 .3384 Mdot
.38356 .44224 Mdot
.4449 .68517 Mdot
.40722 .39567 Mdot
.64855 .23942 Mdot
.75718 .5984 Mdot
.42254 .65253 Mdot
.39199 .47674 Mdot
.74757 .44597 Mdot
.64634 .48451 Mdot
.55093 .46136 Mdot
.62101 .47942 Mdot
.53864 .62512 Mdot
.68765 .5083 Mdot
.37176 .47381 Mdot
.54089 .66205 Mdot
.60934 .33216 Mdot
.34398 .43458 Mdot
.41978 .4353 Mdot
.37245 .62845 Mdot
.57149 .61691 Mdot
.18491 .52194 Mdot
.52209 .62457 Mdot
.53783 .61169 Mdot
.41601 .69655 Mdot
.3719 .44036 Mdot
.65602 .48239 Mdot
.62645 .47582 Mdot
.35202 .40072 Mdot
.55487 .8064 Mdot
.3845 .64062 Mdot
.68338 .5353 Mdot
.20343 .35157 Mdot
.30531 .40744 Mdot
.73983 .56956 Mdot
.445 .53028 Mdot
.5772 .59368 Mdot
.38592 .45522 Mdot
.43477 .6551 Mdot
.69721 .49762 Mdot
.66134 .44768 Mdot
.33877 .41123 Mdot
.56617 .63239 Mdot
.59714 .38041 Mdot
.69129 .4704 Mdot
.76024 .44599 Mdot
.40353 .45324 Mdot
.65876 .72673 Mdot
.69351 .47946 Mdot
.66791 .22949 Mdot
.74132 .39648 Mdot
.41351 .64431 Mdot
.41295 .43174 Mdot
.37958 .67039 Mdot
.60093 .34021 Mdot
.68524 .43728 Mdot
.56786 .62818 Mdot
.33113 .49023 Mdot
.20893 .6529 Mdot
.67874 .47836 Mdot
.41411 .67794 Mdot
.42417 .45925 Mdot
.30376 .42739 Mdot
.36032 .46706 Mdot
.46289 .6719 Mdot
.6295 .40311 Mdot
.59352 .615 Mdot
.5861 .61083 Mdot
.38066 .40975 Mdot
.61767 .36789 Mdot
.63283 .4821 Mdot
.64279 .46997 Mdot
.85091 .622 Mdot
.74672 .56709 Mdot
.4692 .30572 Mdot
.39113 .46925 Mdot
.69986 .46566 Mdot
.24104 .65909 Mdot
.5675 .60748 Mdot
.34931 .41444 Mdot
.70414 .46769 Mdot
.62399 .57147 Mdot
.55282 .42388 Mdot
.38191 .4347 Mdot
.33698 .37404 Mdot
.58505 .61794 Mdot
.54482 .38411 Mdot
.6799 .49319 Mdot
.35335 .40871 Mdot
.52022 .62928 Mdot
.76458 .49841 Mdot
.2783 .72268 Mdot
.40574 .67282 Mdot
.62257 .47797 Mdot
.54062 .62238 Mdot
.39087 .37735 Mdot
.58331 .35438 Mdot
.66724 .50926 Mdot
.65411 .4563 Mdot
.4127 .41317 Mdot
.38803 .38496 Mdot
.30506 .40913 Mdot
.42084 .66659 Mdot
.57743 .64136 Mdot
.34459 .42614 Mdot
.49461 .76996 Mdot
.37181 .40594 Mdot
.5714 .64406 Mdot
.64509 .14249 Mdot
.42086 .40509 Mdot
.35912 .46451 Mdot
.52686 .23365 Mdot
.39072 .6766 Mdot
.36982 .65446 Mdot
.53834 .78706 Mdot
.39077 .46908 Mdot
.75678 .38729 Mdot
.40186 .67281 Mdot
.38808 .63723 Mdot
.67646 .33698 Mdot
.40489 .40304 Mdot
.55364 .38527 Mdot
.55875 .6443 Mdot
.53685 .64534 Mdot
.39575 .62566 Mdot
.39927 .38063 Mdot
.54061 .61295 Mdot
.2808 .49607 Mdot
.67649 .48698 Mdot
.59484 .80538 Mdot
.421 .63426 Mdot
.48101 .51165 Mdot
.56042 .60921 Mdot
.50247 .14855 Mdot
.51712 .56295 Mdot
.38049 .40401 Mdot
.39121 .46276 Mdot
.60031 .3307 Mdot
.44383 .46351 Mdot
.75074 .59999 Mdot
.544 .63159 Mdot
.46748 .21241 Mdot
.41236 .66709 Mdot
.3491 .45483 Mdot
.47909 .36899 Mdot
.52695 .71497 Mdot
.70604 .70264 Mdot
.38795 .65368 Mdot
.4103 .65025 Mdot
.68532 .48047 Mdot
.67723 .46102 Mdot
.37588 .43613 Mdot
.54458 .64457 Mdot
.3953 .69279 Mdot
.5838 .63028 Mdot
.67613 .46607 Mdot
.66367 .48609 Mdot
.76783 .59646 Mdot
.41171 .49858 Mdot
.63784 .48712 Mdot
.77115 .47122 Mdot
.4804 .77062 Mdot
.36247 .64427 Mdot
.16263 .56978 Mdot
.5179 .70119 Mdot
.42928 .25414 Mdot
.62548 .36004 Mdot
.73914 .60286 Mdot
.58105 .64745 Mdot
.38808 .41252 Mdot
.37772 .4655 Mdot
.75669 .58359 Mdot
.57541 .65664 Mdot
.61278 .34837 Mdot
.56367 .66028 Mdot
.59361 .36574 Mdot
.68277 .5157 Mdot
.38226 .49126 Mdot
.39531 .48307 Mdot
.54175 .62314 Mdot
.6628 .49653 Mdot
.63739 .47661 Mdot
.62623 .34895 Mdot
.5053 .38165 Mdot
.66065 .46214 Mdot
.41925 .63317 Mdot
.33262 .59801 Mdot
.74806 .57907 Mdot
.37279 .47725 Mdot
.44898 .34386 Mdot
.24373 .47401 Mdot
.37148 .39594 Mdot
.74402 .57366 Mdot
.80576 .67658 Mdot
.34611 .45638 Mdot
.74602 .73838 Mdot
.74687 .59074 Mdot
.38996 .67708 Mdot
.69 .49563 Mdot
.75222 .60145 Mdot
.34028 .38179 Mdot
.62621 .37419 Mdot
.33678 .4026 Mdot
.39094 .67459 Mdot
.42222 .6178 Mdot
.45089 .80056 Mdot
.64989 .24127 Mdot
.62097 .33596 Mdot
.60825 .3602 Mdot
.64918 .47318 Mdot
.81597 .39396 Mdot
.34465 .38579 Mdot
.61192 .35852 Mdot
.45542 .22162 Mdot
.39596 .41547 Mdot
.47256 .32083 Mdot
.49816 .56738 Mdot
.38145 .6388 Mdot
.39513 .71795 Mdot
.64595 .47909 Mdot
.41267 .67813 Mdot
.45308 .77571 Mdot
.32954 .42646 Mdot
.41065 .67176 Mdot
.57282 .6419 Mdot
.65788 .63294 Mdot
.37739 .66335 Mdot
.5342 .4033 Mdot
.55431 .64392 Mdot
.63817 .40603 Mdot
.4981 .24187 Mdot
.12585 .55515 Mdot
.54283 .63369 Mdot
.66326 .50238 Mdot
.64208 .49886 Mdot
.64511 .46955 Mdot
.39626 .67946 Mdot
.68216 .45292 Mdot
.42596 .65932 Mdot
.63539 .26861 Mdot
.48649 .36733 Mdot
.60485 .36719 Mdot
.57159 .57661 Mdot
.40311 .6498 Mdot
.59397 .76719 Mdot
.17019 .6085 Mdot
.39053 .45175 Mdot
.52123 .6267 Mdot
.58098 .33899 Mdot
.77506 .30092 Mdot
.60209 .33184 Mdot
.67667 .50181 Mdot
.60359 .80247 Mdot
.35121 .45141 Mdot
.27125 .37355 Mdot
.60501 .32791 Mdot
.38758 .66072 Mdot
.37404 .41534 Mdot
.63019 .5098 Mdot
.58618 .35142 Mdot
.60629 .37976 Mdot
.3768 .42469 Mdot
.37657 .65459 Mdot
.6596 .48538 Mdot
.57329 .65158 Mdot
.59371 .39248 Mdot
.40125 .37713 Mdot
.39233 .39197 Mdot
.34536 .47144 Mdot
.54645 .48905 Mdot
.38124 .25221 Mdot
.54624 .635 Mdot
.5634 .28228 Mdot
.67078 .45829 Mdot
.66835 .40095 Mdot
.55511 .76314 Mdot
.59035 .5803 Mdot
.75527 .59807 Mdot
.76288 .5979 Mdot
.38043 .43181 Mdot
.39082 .24672 Mdot
.72316 .71866 Mdot
.59734 .57336 Mdot
.7505 .57749 Mdot
.64002 .47173 Mdot
.43669 .6769 Mdot
.41777 .78704 Mdot
.41538 .39634 Mdot
.58662 .59407 Mdot
.66374 .46067 Mdot
.3585 .24033 Mdot
.5958 .35899 Mdot
.58675 .79765 Mdot
.42334 .44836 Mdot
.35258 .42876 Mdot
.55388 .63356 Mdot
.55839 .64843 Mdot
.69744 .69431 Mdot
.48568 .79727 Mdot
.59383 .43197 Mdot
.49593 .66201 Mdot
.32729 .26343 Mdot
.37362 .71003 Mdot
.43563 .64808 Mdot
.76532 .5736 Mdot
.52722 .64177 Mdot
.37991 .48139 Mdot
.41043 .68649 Mdot
.70542 .7046 Mdot
.43473 .60837 Mdot
.48327 .31884 Mdot
.76088 .40931 Mdot
.41456 .44412 Mdot
.41382 .62498 Mdot
.41055 .67719 Mdot
.37144 .67679 Mdot
.74167 .57584 Mdot
.36468 .45339 Mdot
.42504 .41458 Mdot
.35277 .42043 Mdot
.39448 .36881 Mdot
.40263 .45026 Mdot
.54016 .76041 Mdot
.60583 .54336 Mdot
.4809 .20682 Mdot
.37518 .39728 Mdot
.53383 .63992 Mdot
.33663 .44944 Mdot
.61518 .37137 Mdot
.39547 .40958 Mdot
.47104 .3127 Mdot
.55609 .62037 Mdot
.31729 .48903 Mdot
.49277 .66326 Mdot
.42426 .44552 Mdot
.58459 .37237 Mdot
.40611 .24587 Mdot
.18014 .53515 Mdot
.71321 .54009 Mdot
.41747 .63195 Mdot
.64901 .43794 Mdot
.60008 .61435 Mdot
.6568 .48023 Mdot
.37119 .40201 Mdot
.75533 .57106 Mdot
.60343 .69891 Mdot
.48185 .51378 Mdot
.39019 .48097 Mdot
.43716 .51098 Mdot
.39998 .62973 Mdot
.65637 .50133 Mdot
.35235 .64583 Mdot
.40071 .46391 Mdot
.59507 .34539 Mdot
.58728 .35844 Mdot
.49395 .78672 Mdot
.39609 .20285 Mdot
.42652 .71981 Mdot
.55178 .63423 Mdot
.64299 .45074 Mdot
.60234 .38581 Mdot
.37765 .5637 Mdot
.58868 .59267 Mdot
.57896 .5944 Mdot
.57303 .62419 Mdot
.40753 .44077 Mdot
.75406 .59975 Mdot
.4237 .21841 Mdot
.74604 .59804 Mdot
.42403 .4411 Mdot
.65503 .45299 Mdot
.75763 .60318 Mdot
.59257 .33335 Mdot
.57084 .59941 Mdot
.68024 .46715 Mdot
.39873 .44282 Mdot
.40234 .66742 Mdot
.51238 .38984 Mdot
.40399 .2938 Mdot
.5912 .23282 Mdot
.58391 .22896 Mdot
.43943 .64064 Mdot
.47262 .16486 Mdot
.51825 .61699 Mdot
.2398 .49608 Mdot
.59371 .29847 Mdot
.34774 .40523 Mdot
.47095 .82922 Mdot
.67989 .49473 Mdot
.64539 .49792 Mdot
.38536 .4381 Mdot
.70094 .48001 Mdot
.35308 .46017 Mdot
.68496 .46747 Mdot
.71452 .53608 Mdot
.42552 .4018 Mdot
.64406 .49388 Mdot
.32217 .41689 Mdot
.42632 .42096 Mdot
.38696 .63196 Mdot
.6783 .50802 Mdot
.36996 .4051 Mdot
.81899 .3732 Mdot
.55124 .65152 Mdot
.74196 .57673 Mdot
.58516 .475 Mdot
.54285 .61659 Mdot
.41678 .65724 Mdot
.43935 .42512 Mdot
.61796 .34116 Mdot
.39877 .65861 Mdot
.68178 .53463 Mdot
.60021 .32642 Mdot
.55353 .79287 Mdot
.41261 .62878 Mdot
.7494 .58086 Mdot
.611 .33177 Mdot
.43357 .51132 Mdot
.66335 .51258 Mdot
.35775 .30559 Mdot
.74211 .59233 Mdot
.36575 .46456 Mdot
.70948 .49803 Mdot
.53785 .65032 Mdot
.36141 .43317 Mdot
.69278 .49729 Mdot
.74034 .57554 Mdot
.40317 .43316 Mdot
.38556 .41777 Mdot
.38164 .7644 Mdot
.67861 .7394 Mdot
.61768 .35458 Mdot
.38848 .6197 Mdot
.39058 .4464 Mdot
.62438 .3541 Mdot
.80197 .49101 Mdot
.35977 .48525 Mdot
.38821 .67962 Mdot
.42769 .35573 Mdot
.67378 .45757 Mdot
.56643 .60149 Mdot
.62362 .48013 Mdot
.61451 .37638 Mdot
.48182 .86974 Mdot
.76487 .60057 Mdot
.31727 .42328 Mdot
.33639 .42228 Mdot
.68704 .43093 Mdot
.41437 .67478 Mdot
.58822 .42442 Mdot
.3881 .4668 Mdot
.46755 .44076 Mdot
.34615 .43741 Mdot
.73936 .38803 Mdot
.38523 .64128 Mdot
.36313 .46713 Mdot
.29498 .39554 Mdot
.39728 .49282 Mdot
.58983 .37782 Mdot
.53196 .26012 Mdot
.34924 .47284 Mdot
.43234 .10835 Mdot
.73627 .57692 Mdot
.63913 .4893 Mdot
.61374 .45221 Mdot
.84715 .49963 Mdot
.35432 .73822 Mdot
.42396 .66347 Mdot
.48079 .42946 Mdot
.65807 .48298 Mdot
.27555 .70689 Mdot
.50848 .16112 Mdot
.42683 .42386 Mdot
.41523 .47068 Mdot
.67667 .50182 Mdot
.70158 .4721 Mdot
.76492 .57553 Mdot
.3795 .39942 Mdot
.40266 .52206 Mdot
.64909 .44397 Mdot
.40973 .4507 Mdot
.36868 .34772 Mdot
.57646 .64815 Mdot
.37929 .63475 Mdot
.57632 .60383 Mdot
.59203 .60263 Mdot
.30281 .55687 Mdot
.53087 .78223 Mdot
.56914 .6458 Mdot
.52015 .65287 Mdot
.46039 .31411 Mdot
.46764 .37813 Mdot
.60141 .38308 Mdot
.49497 .1868 Mdot
.6506 .46823 Mdot
.36478 .4514 Mdot
.43881 .64971 Mdot
.2738 .52545 Mdot
.67231 .5697 Mdot
.63699 .78635 Mdot
.39994 .46956 Mdot
.64327 .47919 Mdot
.7389 .58033 Mdot
.41949 .39724 Mdot
.65596 .38239 Mdot
.3572 .42634 Mdot
.64906 .5077 Mdot
.34107 .60423 Mdot
.35661 .34196 Mdot
.73308 .46642 Mdot
.37723 .6925 Mdot
.33951 .4391 Mdot
.42498 .64286 Mdot
.55562 .61088 Mdot
.6215 .36154 Mdot
.61708 .34993 Mdot
.37734 .41712 Mdot
.38579 .56768 Mdot
.49045 .5709 Mdot
.4289 .42805 Mdot
.41014 .40908 Mdot
.74821 .59182 Mdot
.41007 .40831 Mdot
.33768 .42005 Mdot
.35086 .41757 Mdot
.3837 .49737 Mdot
.53639 .61389 Mdot
.3692 .3387 Mdot
.39233 .5063 Mdot
.31003 .43166 Mdot
.56464 .65273 Mdot
.4775 .47361 Mdot
.59068 .6042 Mdot
.39183 .19227 Mdot
.58957 .61234 Mdot
.61533 .35711 Mdot
.71418 .48776 Mdot
.4705 .43237 Mdot
.39511 .69431 Mdot
.55386 .59681 Mdot
.60317 .34887 Mdot
.5452 .62679 Mdot
.65653 .44929 Mdot
.17937 .45809 Mdot
.43385 .60758 Mdot
.54808 .40428 Mdot
.50257 .58968 Mdot
.66432 .72301 Mdot
.68176 .48294 Mdot
.3858 .6363 Mdot
.2615 .38267 Mdot
.36105 .41207 Mdot
.60265 .32956 Mdot
.37793 .42959 Mdot
.54265 .60694 Mdot
.64397 .47463 Mdot
.60134 .25127 Mdot
.61819 .34678 Mdot
.27843 .73604 Mdot
.64373 .46524 Mdot
.4318 .42039 Mdot
.58074 .59271 Mdot
.16316 .57479 Mdot
.58911 .60814 Mdot
.47871 .36218 Mdot
.38165 .61228 Mdot
.3354 .72094 Mdot
.40632 .64442 Mdot
.73006 .68476 Mdot
.25142 .2606 Mdot
.57929 .20507 Mdot
.3945 .66779 Mdot
.74604 .47857 Mdot
.4174 .45486 Mdot
.34193 .46293 Mdot
.29897 .41322 Mdot
.3672 .63894 Mdot
.39517 .44891 Mdot
.74349 .59112 Mdot
.45603 .75788 Mdot
.68461 .39869 Mdot
.64454 .43985 Mdot
.36569 .473 Mdot
.56698 .65123 Mdot
.56243 .66109 Mdot
.75357 .60257 Mdot
.59702 .61461 Mdot
.4162 .4067 Mdot
.40396 .64745 Mdot
.46321 .53757 Mdot
.59898 .33598 Mdot
.74875 .30092 Mdot
.57162 .36044 Mdot
.61722 .48541 Mdot
.43988 .49002 Mdot
.66428 .4868 Mdot
.61686 .85255 Mdot
.3744 .40742 Mdot
.40161 .67504 Mdot
.39134 .42367 Mdot
.34073 .4298 Mdot
.34084 .46176 Mdot
.66767 .44393 Mdot
.61779 .42562 Mdot
.40746 .44783 Mdot
.56875 .62673 Mdot
.53458 .2096 Mdot
.33029 .41547 Mdot
.72452 .516 Mdot
.50447 .29499 Mdot
.62764 .74185 Mdot
.35955 .65482 Mdot
.65817 .50054 Mdot
.4123 .66164 Mdot
.39823 .69924 Mdot
.4169 .65736 Mdot
.42973 .21183 Mdot
.27117 .44821 Mdot
.80619 .66811 Mdot
.31892 .70117 Mdot
.25752 .53292 Mdot
.40812 .61392 Mdot
.80561 .53117 Mdot
.43152 .66567 Mdot
.42119 .66228 Mdot
.85286 .35216 Mdot
.42829 .67356 Mdot
.3821 .47523 Mdot
.38398 .38635 Mdot
.51452 .73294 Mdot
.45585 .32301 Mdot
.39298 .40574 Mdot
.38809 .44287 Mdot
.623 .35381 Mdot
.28737 .46106 Mdot
.77304 .58259 Mdot
.54725 .80029 Mdot
.5525 .6982 Mdot
.37808 .42577 Mdot
.39229 .44389 Mdot
.4325 .39698 Mdot
.21259 .28978 Mdot
.29 .52326 Mdot
.43263 .62267 Mdot
.44436 .50648 Mdot
.68577 .25154 Mdot
.43418 .43804 Mdot
.3963 .48382 Mdot
.41007 .43585 Mdot
.65667 .48273 Mdot
.44452 .66065 Mdot
.44578 .50416 Mdot
.61206 .73564 Mdot
.42173 .45461 Mdot
.56243 .58117 Mdot
.61367 .3995 Mdot
.37297 .47367 Mdot
.36902 .66744 Mdot
.40342 .41744 Mdot
.4192 .63041 Mdot
.3904 .6274 Mdot
.43902 .40185 Mdot
.41009 .2145 Mdot
.3792 .6751 Mdot
.42129 .43937 Mdot
.65874 .4952 Mdot
.57512 .19507 Mdot
.36811 .46691 Mdot
.60491 .37273 Mdot
.39033 .46486 Mdot
.58466 .37089 Mdot
.42173 .42082 Mdot
.74319 .59499 Mdot
.22746 .4524 Mdot
.65353 .47292 Mdot
.55766 .32007 Mdot
.69359 .45733 Mdot
.38588 .76481 Mdot
.3928 .68089 Mdot
.7631 .56973 Mdot
.59771 .82133 Mdot
.74732 .58927 Mdot
.5119 .39522 Mdot
.70285 .55129 Mdot
.53953 .64167 Mdot
.36937 .64636 Mdot
.55071 .30101 Mdot
.73501 .50423 Mdot
.64024 .52441 Mdot
.6882 .44494 Mdot
.49392 .85743 Mdot
.55111 .83293 Mdot
.4025 .44158 Mdot
.28775 .32866 Mdot
.24817 .6177 Mdot
.37395 .48909 Mdot
.44028 .44097 Mdot
.66014 .51395 Mdot
.34337 .45318 Mdot
.53099 .48446 Mdot
.67574 .47475 Mdot
.6053 .35408 Mdot
.42366 .65216 Mdot
.58463 .3687 Mdot
.66782 .522 Mdot
.59951 .53695 Mdot
.67543 .46252 Mdot
.37303 .4951 Mdot
.39077 .42863 Mdot
.40411 .62223 Mdot
.38417 .58712 Mdot
.38312 .63206 Mdot
.58778 .32932 Mdot
.66832 .46948 Mdot
.27637 .51201 Mdot
.38224 .45172 Mdot
.39619 .65033 Mdot
.59387 .6645 Mdot
.38673 .45098 Mdot
.54639 .61741 Mdot
.41883 .46331 Mdot
.39213 .66966 Mdot
.4108 .40863 Mdot
.4056 .64834 Mdot
.67307 .49695 Mdot
.43228 .44787 Mdot
.38339 .43837 Mdot
.18675 .61064 Mdot
.6123 .34599 Mdot
.39233 .68016 Mdot
.53645 .53402 Mdot
.42529 .41159 Mdot
.65708 .41146 Mdot
.36534 .47751 Mdot
.46961 .39427 Mdot
.32 .42529 Mdot
.74307 .58769 Mdot
.4001 .51127 Mdot
.36708 .46674 Mdot
.30581 .35261 Mdot
.28484 .66323 Mdot
.35209 .64334 Mdot
.55151 .60055 Mdot
.36857 .66342 Mdot
.67655 .51374 Mdot
.70124 .49481 Mdot
.69155 .46577 Mdot
.46383 .33628 Mdot
.4202 .39051 Mdot
.35276 .45257 Mdot
.55171 .59598 Mdot
.60529 .36186 Mdot
.38962 .6546 Mdot
.60096 .36399 Mdot
.53863 .79871 Mdot
.5881 .33015 Mdot
.75312 .601 Mdot
.74191 .39875 Mdot
.25225 .46506 Mdot
.62273 .35028 Mdot
.38153 .63327 Mdot
.75794 .41456 Mdot
.34898 .40621 Mdot
.65408 .53953 Mdot
.59383 .34696 Mdot
.45278 .86018 Mdot
.37057 .48223 Mdot
.54163 .4371 Mdot
.58962 .63167 Mdot
.58351 .34875 Mdot
.56996 .61364 Mdot
.3861 .40868 Mdot
.64968 .70693 Mdot
.4142 .67909 Mdot
.52899 .65007 Mdot
.38742 .5075 Mdot
.58211 .36075 Mdot
.65825 .45947 Mdot
.51859 .58278 Mdot
.53435 .63988 Mdot
.21397 .42567 Mdot
.57625 .25626 Mdot
.67031 .47078 Mdot
.75641 .6879 Mdot
.5779 .62067 Mdot
.36735 .48756 Mdot
.45372 .40319 Mdot
.39239 .40079 Mdot
.69974 .50216 Mdot
.65326 .49988 Mdot
.48057 .75176 Mdot
.39298 .42691 Mdot
.36856 .48045 Mdot
.4403 .62097 Mdot
.67651 .48159 Mdot
.40409 .63493 Mdot
.36931 .67542 Mdot
.66672 .50225 Mdot
.41209 .64226 Mdot
.60131 .32758 Mdot
.44737 .73666 Mdot
.57848 .62165 Mdot
.56612 .62484 Mdot
.64073 .47134 Mdot
.6317 .46925 Mdot
.6666 .48718 Mdot
.41897 .463 Mdot
.38491 .6503 Mdot
.41355 .42734 Mdot
.35915 .48592 Mdot
.35707 .64502 Mdot
.42584 .6794 Mdot
.40571 .42465 Mdot
.69172 .42784 Mdot
.60496 .39447 Mdot
.64384 .49157 Mdot
.58384 .63198 Mdot
.27735 .70453 Mdot
.56793 .58927 Mdot
.36419 .47306 Mdot
.62557 .56719 Mdot
.38769 .66662 Mdot
.59973 .33122 Mdot
.5963 .39811 Mdot
.61044 .33458 Mdot
.61181 .61039 Mdot
.38411 .68912 Mdot
.55318 .79176 Mdot
.35779 .46596 Mdot
.54515 .49101 Mdot
.55671 .2897 Mdot
.56512 .76117 Mdot
.57426 .64242 Mdot
.3885 .44732 Mdot
.74698 .58661 Mdot
.25719 .41948 Mdot
.35491 .42945 Mdot
.35861 .40824 Mdot
.70478 .33459 Mdot
.30962 .43083 Mdot
.36749 .63402 Mdot
.45769 .80205 Mdot
.36599 .38828 Mdot
.46307 .65746 Mdot
.87012 .53907 Mdot
.35629 .4681 Mdot
.40284 .45867 Mdot
.37226 .45944 Mdot
.39413 .41695 Mdot
.37034 .62374 Mdot
.52869 .36774 Mdot
.57742 .59252 Mdot
.56332 .5018 Mdot
.57511 .63125 Mdot
.65767 .50961 Mdot
.53846 .44251 Mdot
.37197 .64224 Mdot
.60423 .33105 Mdot
.23599 .37766 Mdot
.50823 .80536 Mdot
.68482 .48171 Mdot
.31951 .54178 Mdot
.59816 .33896 Mdot
.35063 .40237 Mdot
.58983 .32055 Mdot
.70148 .4695 Mdot
.56421 .63792 Mdot
.38643 .38711 Mdot
.43322 .63337 Mdot
.37764 .66459 Mdot
.39184 .45105 Mdot
.64546 .23273 Mdot
.55102 .61102 Mdot
.621 .61018 Mdot
.40993 .44203 Mdot
.35974 .40743 Mdot
.41249 .6355 Mdot
.64826 .49051 Mdot
.7734 .52072 Mdot
.60893 .34771 Mdot
.42977 .47376 Mdot
.39569 .41392 Mdot
.51936 .79383 Mdot
.56837 .59772 Mdot
.76304 .57777 Mdot
.40432 .43752 Mdot
.52387 .78236 Mdot
.40329 .43564 Mdot
.44659 .4576 Mdot
.66126 .49056 Mdot
.32592 .42892 Mdot
.40996 .47132 Mdot
.41625 .53579 Mdot
.57633 .61536 Mdot
.40766 .67506 Mdot
.4148 .60675 Mdot
.74988 .57273 Mdot
.54635 .6187 Mdot
.40449 .42195 Mdot
.55752 .60169 Mdot
.34503 .46825 Mdot
.40495 .44798 Mdot
.57375 .64242 Mdot
.40469 .63512 Mdot
.59493 .68568 Mdot
.4555 .35579 Mdot
.39391 .42007 Mdot
.38989 .39097 Mdot
.46694 .33231 Mdot
.67699 .78575 Mdot
.39554 .47358 Mdot
.38705 .6701 Mdot
.3836 .44658 Mdot
.56214 .61325 Mdot
.58362 .3363 Mdot
.39822 .66907 Mdot
.63558 .47004 Mdot
.67612 .49763 Mdot
.48941 .66354 Mdot
.75885 .60189 Mdot
.39941 .39304 Mdot
.34591 .66894 Mdot
.4368 .66253 Mdot
.84472 .42463 Mdot
.64331 .49957 Mdot
.587 .37734 Mdot
.38433 .41544 Mdot
.53151 .5688 Mdot
.56127 .59246 Mdot
.42889 .10831 Mdot
.55735 .78617 Mdot
.58806 .31517 Mdot
.62752 .79551 Mdot
.75147 .58448 Mdot
.39698 .48037 Mdot
.61982 .36608 Mdot
.68909 .48845 Mdot
.33512 .4379 Mdot
.32899 .38163 Mdot
.58495 .42803 Mdot
.64734 .42814 Mdot
.56174 .60101 Mdot
.68172 .45977 Mdot
.61887 .32328 Mdot
.75203 .60061 Mdot
.37298 .65273 Mdot
.36255 .4638 Mdot
.45787 .43032 Mdot
.63868 .48205 Mdot
.74233 .5946 Mdot
.41502 .4438 Mdot
.37564 .6652 Mdot
.69902 .47682 Mdot
.37465 .42257 Mdot
.24567 .50431 Mdot
.38529 .69938 Mdot
.66111 .46494 Mdot
.33741 .42311 Mdot
.45319 .38095 Mdot
.63816 .46987 Mdot
.63622 .48289 Mdot
.39499 .44842 Mdot
.60686 .32952 Mdot
.42009 .46973 Mdot
.59159 .61882 Mdot
.61722 .42623 Mdot
.56188 .6157 Mdot
.60848 .28687 Mdot
.43407 .49348 Mdot
.67673 .72042 Mdot
.39876 .61893 Mdot
.62898 .33734 Mdot
.19605 .58479 Mdot
.36211 .40351 Mdot
.4506 .17863 Mdot
.4874 .50348 Mdot
.75931 .29596 Mdot
.24154 .29914 Mdot
.59427 .35221 Mdot
.54692 .62279 Mdot
.40209 .45836 Mdot
.52786 .60903 Mdot
.61931 .3603 Mdot
.57463 .27899 Mdot
.33942 .42015 Mdot
.38719 .63881 Mdot
.42086 .45263 Mdot
.41837 .63227 Mdot
.3867 .4535 Mdot
.31812 .45623 Mdot
.61256 .3041 Mdot
.47566 .35968 Mdot
.35018 .4043 Mdot
.17785 .45695 Mdot
.54254 .55317 Mdot
.59979 .34306 Mdot
.41773 .43284 Mdot
.76274 .58749 Mdot
.58168 .65275 Mdot
.36114 .27296 Mdot
.66053 .48434 Mdot
.57113 .64666 Mdot
.41835 .64459 Mdot
.62865 .4822 Mdot
.7393 .57408 Mdot
.45467 .41624 Mdot
.5912 .3761 Mdot
.53899 .63835 Mdot
.36946 .47003 Mdot
.37241 .48246 Mdot
.74012 .45844 Mdot
.70697 .63046 Mdot
.44805 .64785 Mdot
.24106 .69626 Mdot
.36448 .63444 Mdot
.61245 .35509 Mdot
.66298 .48986 Mdot
.39036 .47659 Mdot
.36336 .42815 Mdot
.69563 .50314 Mdot
.39483 .68061 Mdot
.63048 .43372 Mdot
.31358 .55366 Mdot
.63134 .45689 Mdot
.51514 .32353 Mdot
.39744 .67418 Mdot
.51453 .32946 Mdot
.61988 .32391 Mdot
.38019 .22074 Mdot
.43779 .27523 Mdot
.58969 .63245 Mdot
.51718 .31757 Mdot
.38891 .66179 Mdot
.39556 .43569 Mdot
.75192 .58104 Mdot
.76614 .59752 Mdot
.42183 .64362 Mdot
.67735 .50244 Mdot
.5842 .35164 Mdot
.40516 .45724 Mdot
.61099 .77221 Mdot
.50008 .70659 Mdot
.64022 .45248 Mdot
.33032 .36839 Mdot
.57109 .61837 Mdot
.40936 .46849 Mdot
.59964 .37328 Mdot
.54513 .64078 Mdot
.72971 .5739 Mdot
.45839 .75059 Mdot
.37891 .41342 Mdot
.48167 .79219 Mdot
.54212 .62463 Mdot
.76311 .68614 Mdot
.37427 .43358 Mdot
.57785 .62029 Mdot
.35325 .50408 Mdot
.61019 .71805 Mdot
.50042 .53371 Mdot
.51889 .16844 Mdot
.66576 .43206 Mdot
.67928 .49813 Mdot
.66122 .6529 Mdot
.60356 .3004 Mdot
.55505 .6538 Mdot
.75077 .60025 Mdot
.4896 .25333 Mdot
.5722 .61448 Mdot
.40488 .48105 Mdot
.36404 .47609 Mdot
.29605 .5503 Mdot
.52334 .51326 Mdot
.7434 .59736 Mdot
.40637 .73297 Mdot
.39929 .39952 Mdot
.32941 .46719 Mdot
.36356 .43573 Mdot
.42354 .61829 Mdot
.54042 .61888 Mdot
.15536 .54695 Mdot
.5567 .60762 Mdot
.61551 .77707 Mdot
.64981 .46875 Mdot
.63352 .45753 Mdot
.37243 .47484 Mdot
.70744 .71244 Mdot
.3541 .26887 Mdot
.42831 .41967 Mdot
.65193 .40478 Mdot
.56697 .25568 Mdot
.33519 .48009 Mdot
.39183 .60584 Mdot
.45722 .4416 Mdot
.36934 .70276 Mdot
.55239 .6464 Mdot
.59197 .35709 Mdot
.60186 .39311 Mdot
.54176 .64174 Mdot
.35354 .45166 Mdot
.64235 .38589 Mdot
.34843 .43331 Mdot
.40232 .43897 Mdot
.58088 .80252 Mdot
.59494 .38469 Mdot
.66988 .48822 Mdot
.61747 .34831 Mdot
.4205 .66438 Mdot
.73223 .20087 Mdot
.59844 .36674 Mdot
.34254 .66517 Mdot
.54146 .35932 Mdot
.51773 .32139 Mdot
.3753 .66211 Mdot
.61095 .32396 Mdot
.56261 .6028 Mdot
.75234 .28376 Mdot
.72384 .7385 Mdot
.56219 .58866 Mdot
.37121 .42978 Mdot
.37671 .63402 Mdot
.43559 .63062 Mdot
.51818 .6348 Mdot
.37848 .64267 Mdot
.41747 .51385 Mdot
.39621 .42756 Mdot
.55458 .65374 Mdot
.50409 .72723 Mdot
.53274 .63592 Mdot
.43713 .74897 Mdot
.41714 .43806 Mdot
.3994 .67206 Mdot
.45367 .47718 Mdot
.43137 .60901 Mdot
.76987 .58284 Mdot
.33466 .43768 Mdot
.58734 .33813 Mdot
.53006 .50106 Mdot
.65878 .46607 Mdot
.62195 .56531 Mdot
.40153 .62358 Mdot
.59413 .67656 Mdot
.38639 .6321 Mdot
.37599 .63071 Mdot
.59473 .60458 Mdot
.42194 .67106 Mdot
.40384 .45878 Mdot
.72913 .45621 Mdot
.42653 .63486 Mdot
.55556 .62898 Mdot
.58889 .34247 Mdot
.40954 .63923 Mdot
.64333 .50782 Mdot
.38443 .425 Mdot
.67956 .46273 Mdot
.59237 .31038 Mdot
.36886 .64911 Mdot
.60871 .3237 Mdot
.64072 .49276 Mdot
.5999 .37905 Mdot
.61326 .25682 Mdot
.52747 .63984 Mdot
.64331 .78181 Mdot
.43621 .35403 Mdot
.43392 .63557 Mdot
.65071 .52926 Mdot
.39164 .47472 Mdot
.38506 .42189 Mdot
.62265 .33073 Mdot
.43713 .63413 Mdot
.59401 .20753 Mdot
.47044 .40395 Mdot
.45419 .73664 Mdot
.52854 .62603 Mdot
.28381 .72821 Mdot
.49145 .76841 Mdot
.77437 .35161 Mdot
.33128 .39644 Mdot
.75185 .58412 Mdot
.34622 .44611 Mdot
.17754 .54996 Mdot
.57932 .34534 Mdot
.79293 .56805 Mdot
.34781 .38446 Mdot
.66778 .48008 Mdot
.37577 .44632 Mdot
.31978 .31644 Mdot
.45645 .4464 Mdot
.62312 .34312 Mdot
.59884 .57797 Mdot
.39535 .69408 Mdot
.5991 .3367 Mdot
.67823 .49408 Mdot
.51022 .26902 Mdot
.33334 .42727 Mdot
.40643 .39967 Mdot
.64217 .44523 Mdot
.38453 .63921 Mdot
.66198 .51154 Mdot
.57828 .62218 Mdot
.59736 .36242 Mdot
.38873 .41388 Mdot
.32848 .45898 Mdot
.63467 .41467 Mdot
.54044 .6177 Mdot
.62876 .46974 Mdot
.57706 .60324 Mdot
.75133 .58317 Mdot
.36966 .39142 Mdot
.65145 .44182 Mdot
.37002 .48407 Mdot
.19335 .59855 Mdot
.58731 .80404 Mdot
.28874 .64738 Mdot
.67282 .48807 Mdot
.49807 .31184 Mdot
.55595 .6178 Mdot
.58706 .6084 Mdot
.3279 .72091 Mdot
.40077 .24564 Mdot
.75874 .39465 Mdot
.21596 .40119 Mdot
.57846 .62299 Mdot
.56201 .61953 Mdot
.69174 .48626 Mdot
.42731 .66146 Mdot
.40349 .70427 Mdot
.62426 .47187 Mdot
.46088 .34963 Mdot
.38977 .65453 Mdot
.46602 .17398 Mdot
.66507 .51594 Mdot
.3324 .3933 Mdot
.77748 .59749 Mdot
.58903 .35902 Mdot
.46137 .35073 Mdot
.30868 .33076 Mdot
.38907 .47947 Mdot
.42964 .80125 Mdot
.65103 .48927 Mdot
.55938 .40173 Mdot
.38329 .19925 Mdot
.34283 .41925 Mdot
.36825 .44767 Mdot
.35421 .44706 Mdot
.5946 .38612 Mdot
.19183 .56571 Mdot
.38956 .48028 Mdot
.49601 .36998 Mdot
.43811 .44319 Mdot
.38802 .28867 Mdot
.6174 .35083 Mdot
.47062 .64974 Mdot
.65985 .43283 Mdot
.59225 .7471 Mdot
.29987 .41532 Mdot
.57899 .61028 Mdot
.70956 .51808 Mdot
.56623 .63946 Mdot
.38101 .24216 Mdot
.44282 .27556 Mdot
.40752 .61242 Mdot
.40113 .46952 Mdot
.69535 .45247 Mdot
.39219 .62379 Mdot
.72985 .54692 Mdot
.83523 .32058 Mdot
.54433 .60966 Mdot
.66715 .81147 Mdot
.58695 .6073 Mdot
.76965 .58964 Mdot
.41544 .63713 Mdot
.30408 .50454 Mdot
.54373 .49052 Mdot
.40933 .64089 Mdot
.60375 .69562 Mdot
.37465 .61383 Mdot
.50802 .31175 Mdot
.38281 .69362 Mdot
.55439 .62554 Mdot
.58483 .65592 Mdot
.32522 .3923 Mdot
.38966 .47188 Mdot
.57506 .50091 Mdot
.4562 .51231 Mdot
.39367 .47092 Mdot
.67565 .47492 Mdot
.71018 .73928 Mdot
.71879 .48164 Mdot
.43451 .64961 Mdot
.56463 .59565 Mdot
.37011 .44728 Mdot
.39807 .42438 Mdot
.36045 .48191 Mdot
.1872 .61669 Mdot
.47291 .17492 Mdot
.40499 .44599 Mdot
.42504 .48 Mdot
.6743 .49441 Mdot
.63671 .36258 Mdot
.19527 .44469 Mdot
.47705 .25948 Mdot
.36057 .4186 Mdot
.61332 .34365 Mdot
.5798 .3736 Mdot
.33788 .40859 Mdot
.6217 .75347 Mdot
.7433 .47939 Mdot
.36954 .46982 Mdot
.41465 .27244 Mdot
.69433 .51476 Mdot
.75154 .60256 Mdot
.63851 .48071 Mdot
.36854 .66919 Mdot
.7538 .59782 Mdot
.69192 .45836 Mdot
.29021 .49087 Mdot
.74945 .57183 Mdot
.59258 .72249 Mdot
.58773 .32933 Mdot
.3607 .43341 Mdot
.38433 .60621 Mdot
.69958 .50035 Mdot
.54129 .64294 Mdot
.40593 .65878 Mdot
.57108 .65963 Mdot
.61914 .30618 Mdot
.52013 .38044 Mdot
.76272 .60124 Mdot
.58158 .61522 Mdot
.45776 .75154 Mdot
.61475 .34527 Mdot
.59483 .60995 Mdot
.71076 .70557 Mdot
.34037 .39405 Mdot
.30472 .28583 Mdot
.43012 .43741 Mdot
.68836 .24871 Mdot
.5865 .60277 Mdot
.75105 .56895 Mdot
.35501 .45696 Mdot
.64277 .46581 Mdot
.38647 .52036 Mdot
.35841 .42455 Mdot
.64044 .45651 Mdot
.40076 .44042 Mdot
.60283 .37438 Mdot
.3713 .69727 Mdot
.464 .52866 Mdot
.34129 .79287 Mdot
.5968 .37733 Mdot
.73451 .55813 Mdot
.39716 .47245 Mdot
.59616 .25162 Mdot
.407 .63927 Mdot
.35006 .41366 Mdot
.34076 .72765 Mdot
.42897 .64942 Mdot
.4119 .65764 Mdot
.41252 .41458 Mdot
.59386 .62542 Mdot
.64931 .46349 Mdot
.61464 .34285 Mdot
.79573 .36262 Mdot
.36894 .4209 Mdot
.38335 .44242 Mdot
.5979 .33834 Mdot
.56207 .61731 Mdot
.39826 .42206 Mdot
.65294 .56826 Mdot
.80406 .35031 Mdot
.59077 .59936 Mdot
.3292 .41693 Mdot
.26439 .32716 Mdot
.45473 .64047 Mdot
.67493 .79651 Mdot
.55455 .33931 Mdot
.65983 .49969 Mdot
.32214 .46505 Mdot
.48082 .10951 Mdot
.59014 .35598 Mdot
.57442 .76307 Mdot
.41153 .44912 Mdot
.37876 .45642 Mdot
.37973 .65969 Mdot
.40987 .42439 Mdot
.40559 .68248 Mdot
.37636 .82153 Mdot
.26771 .74248 Mdot
.39516 .62942 Mdot
.43648 .65204 Mdot
.42909 .70408 Mdot
.19374 .46862 Mdot
.42166 .65036 Mdot
.33185 .44063 Mdot
.53598 .20086 Mdot
.43385 .39411 Mdot
.62714 .33774 Mdot
.56711 .35021 Mdot
.46474 .62238 Mdot
.76811 .64849 Mdot
.47664 .46772 Mdot
.30277 .45075 Mdot
.4901 .57879 Mdot
.58872 .62082 Mdot
.35608 .41756 Mdot
.7592 .60223 Mdot
.68719 .46009 Mdot
.45035 .42742 Mdot
.35645 .4334 Mdot
.42102 .63221 Mdot
.60353 .38892 Mdot
.59755 .6286 Mdot
.38785 .44232 Mdot
.63529 .4263 Mdot
.60737 .35184 Mdot
.43042 .63853 Mdot
.35537 .72468 Mdot
.61455 .37875 Mdot
.39648 .51293 Mdot
.3874 .46453 Mdot
.41402 .44301 Mdot
.30646 .42208 Mdot
.5495 .64977 Mdot
.67552 .52105 Mdot
.35522 .48501 Mdot
.53892 .7958 Mdot
.54888 .42604 Mdot
.32626 .44696 Mdot
.38456 .65694 Mdot
.57 .59027 Mdot
.76329 .57615 Mdot
.53594 .27374 Mdot
.37478 .41431 Mdot
.47216 .177 Mdot
.29736 .53281 Mdot
.75556 .59675 Mdot
.39193 .61686 Mdot
.60412 .33162 Mdot
.40721 .40269 Mdot
.48948 .19978 Mdot
.36557 .47629 Mdot
.46152 .3731 Mdot
.65461 .49491 Mdot
.58635 .62373 Mdot
.78736 .32007 Mdot
.6846 .45749 Mdot
.41225 .66044 Mdot
.5264 .16336 Mdot
.43559 .67521 Mdot
.402 .69182 Mdot
.40755 .21929 Mdot
.56019 .64708 Mdot
.46457 .11102 Mdot
.70461 .76179 Mdot
.39537 .48992 Mdot
.5615 .61082 Mdot
.41211 .63194 Mdot
.40976 .46715 Mdot
.43637 .66121 Mdot
.4012 .68978 Mdot
.33569 .44267 Mdot
.38296 .46246 Mdot
.49052 .37669 Mdot
.4217 .1818 Mdot
.61389 .33597 Mdot
.38939 .6764 Mdot
.26268 .54648 Mdot
.39324 .47997 Mdot
.35835 .4663 Mdot
.70743 .44198 Mdot
.62321 .34415 Mdot
.29503 .36447 Mdot
.40365 .43792 Mdot
.36089 .76872 Mdot
.38982 .39032 Mdot
.39605 .60213 Mdot
.59206 .60024 Mdot
.61319 .75585 Mdot
.69345 .50772 Mdot
.38365 .67618 Mdot
.58165 .363 Mdot
.42794 .61264 Mdot
.32802 .67889 Mdot
.56015 .64536 Mdot
.3921 .66965 Mdot
.64072 .50252 Mdot
.55693 .63866 Mdot
.59263 .60749 Mdot
.53449 .209 Mdot
.62728 .4703 Mdot
.58759 .32755 Mdot
.56917 .63368 Mdot
.23941 .49909 Mdot
.55041 .62796 Mdot
.27655 .54857 Mdot
.42998 .45176 Mdot
.50181 .37112 Mdot
.5128 .76528 Mdot
.30704 .3979 Mdot
.53597 .64752 Mdot
.61965 .35522 Mdot
.40336 .4115 Mdot
.37778 .64546 Mdot
.59656 .36639 Mdot
.51926 .59268 Mdot
.63282 .47666 Mdot
.40779 .62005 Mdot
.58569 .59353 Mdot
.39485 .67639 Mdot
.53871 .31665 Mdot
.60161 .47949 Mdot
.48947 .59023 Mdot
.54788 .47803 Mdot
.36805 .48618 Mdot
.42894 .58249 Mdot
.40188 .39269 Mdot
.35466 .43173 Mdot
.65999 .46481 Mdot
.46631 .33787 Mdot
.40523 .63468 Mdot
.79576 .32753 Mdot
.58412 .61712 Mdot
.40232 .78191 Mdot
.45613 .38842 Mdot
.36188 .40854 Mdot
.42737 .63762 Mdot
.42678 .68557 Mdot
.28613 .66254 Mdot
.69142 .50537 Mdot
.32885 .37706 Mdot
.43198 .49034 Mdot
.32076 .40462 Mdot
.58451 .602 Mdot
.65648 .58226 Mdot
.67265 .50685 Mdot
.80807 .67612 Mdot
.64438 .4907 Mdot
.68583 .34474 Mdot
.42279 .67081 Mdot
.58158 .34281 Mdot
.36158 .46896 Mdot
.48568 .38997 Mdot
.39031 .61048 Mdot
.56432 .38303 Mdot
.59225 .33299 Mdot
.65387 .63314 Mdot
.56566 .64747 Mdot
.34163 .40887 Mdot
.3376 .4376 Mdot
.41651 .42762 Mdot
.42737 .44638 Mdot
.55552 .5996 Mdot
.40197 .4822 Mdot
.52874 .64816 Mdot
.24607 .49233 Mdot
.36069 .77122 Mdot
.70964 .47664 Mdot
.37557 .26165 Mdot
.42785 .62789 Mdot
.23684 .52328 Mdot
.38305 .35006 Mdot
.5978 .80091 Mdot
.59288 .24135 Mdot
.41121 .39871 Mdot
.68742 .49797 Mdot
.30068 .32259 Mdot
.6994 .45963 Mdot
.42195 .88797 Mdot
.64197 .36205 Mdot
.50033 .15961 Mdot
.40682 .46752 Mdot
.68886 .43121 Mdot
.41491 .35651 Mdot
.33393 .41214 Mdot
.63974 .34039 Mdot
.37525 .74544 Mdot
.5289 .73765 Mdot
.59422 .3827 Mdot
.38118 .42337 Mdot
.40039 .69448 Mdot
.40524 .45997 Mdot
.35207 .45968 Mdot
.41325 .46742 Mdot
.5964 .60138 Mdot
.40478 .38817 Mdot
.41478 .47376 Mdot
.71431 .6284 Mdot
.47736 .32041 Mdot
.67648 .4573 Mdot
.30906 .68446 Mdot
.60478 .36167 Mdot
.41328 .62712 Mdot
.51507 .45191 Mdot
.58828 .63305 Mdot
.27597 .66837 Mdot
.42015 .46127 Mdot
.50076 .76071 Mdot
.58418 .59309 Mdot
.59341 .36377 Mdot
.75015 .57409 Mdot
.54509 .18976 Mdot
.70896 .47744 Mdot
.75169 .57173 Mdot
.65758 .46699 Mdot
.20069 .5733 Mdot
.42254 .63386 Mdot
.3595 .48254 Mdot
.57234 .62381 Mdot
.65003 .46107 Mdot
.44613 .32351 Mdot
.36156 .43924 Mdot
.67624 .48636 Mdot
.36656 .48662 Mdot
.54274 .4011 Mdot
.74683 .46407 Mdot
.69271 .4547 Mdot
.60831 .62251 Mdot
.56068 .63417 Mdot
.59862 .32734 Mdot
.41122 .62492 Mdot
.38637 .66472 Mdot
.54656 .64053 Mdot
.63055 .82049 Mdot
.35761 .42351 Mdot
.40673 .47027 Mdot
.5391 .79321 Mdot
.39729 .46152 Mdot
.51183 .28409 Mdot
.7736 .59572 Mdot
.41896 .62575 Mdot
.41222 .46361 Mdot
.39605 .42015 Mdot
.38172 .41403 Mdot
.53513 .32516 Mdot
.63968 .48464 Mdot
.40035 .40002 Mdot
.62395 .36038 Mdot
.70332 .69158 Mdot
.40166 .47586 Mdot
.32283 .45206 Mdot
.39087 .66554 Mdot
.29799 .76055 Mdot
.5921 .62478 Mdot
.68042 .47686 Mdot
.63594 .48678 Mdot
.56437 .33722 Mdot
.35915 .66345 Mdot
.77369 .58418 Mdot
.8347 .47288 Mdot
.7414 .58122 Mdot
.60262 .33985 Mdot
.70462 .31837 Mdot
.63004 .42877 Mdot
.68668 .47707 Mdot
.54109 .66049 Mdot
.42209 .45659 Mdot
.42202 .40958 Mdot
.57776 .76463 Mdot
.3853 .40006 Mdot
.58942 .33796 Mdot
.55269 .65505 Mdot
.39206 .66086 Mdot
.5877 .3604 Mdot
.57601 .60432 Mdot
.38289 .64135 Mdot
.34284 .39276 Mdot
.35073 .38695 Mdot
.40822 .65593 Mdot
.3865 .62835 Mdot
.37753 .4716 Mdot
.69453 .6246 Mdot
.36549 .66844 Mdot
.3944 .67168 Mdot
.74599 .60312 Mdot
.70801 .47347 Mdot
.46027 .47291 Mdot
.56043 .61011 Mdot
.41277 .4431 Mdot
.7033 .46465 Mdot
.62118 .33788 Mdot
.40003 .63882 Mdot
.39494 .4225 Mdot
.39113 .4357 Mdot
.61176 .34023 Mdot
.61 .38441 Mdot
.58417 .3562 Mdot
.52613 .60857 Mdot
.42583 .43231 Mdot
.42011 .65072 Mdot
.56633 .64598 Mdot
.57987 .37362 Mdot
.58158 .3298 Mdot
.74406 .63383 Mdot
.38485 .47946 Mdot
.49684 .54085 Mdot
.69526 .17824 Mdot
.49891 .26548 Mdot
.76646 .57831 Mdot
.63416 .45187 Mdot
.50565 .34889 Mdot
.72115 .43954 Mdot
.54421 .61647 Mdot
.47023 .23402 Mdot
.62888 .33739 Mdot
.34983 .47366 Mdot
.38654 .39079 Mdot
.43922 .45738 Mdot
.60286 .35468 Mdot
.54667 .29497 Mdot
.43977 .63922 Mdot
.22902 .58084 Mdot
.6045 .36164 Mdot
.69337 .45576 Mdot
.66109 .44033 Mdot
.64498 .49131 Mdot
.36287 .39101 Mdot
.27905 .65955 Mdot
.24749 .52826 Mdot
.20494 .49396 Mdot
.56789 .64776 Mdot
.44459 .66158 Mdot
.6065 .25664 Mdot
.41133 .65475 Mdot
.68924 .46013 Mdot
.60378 .35037 Mdot
.38346 .66754 Mdot
.53682 .63174 Mdot
.56396 .61962 Mdot
.63412 .47408 Mdot
.64171 .47182 Mdot
.66864 .45863 Mdot
.37543 .68023 Mdot
.42231 .67078 Mdot
.37727 .41018 Mdot
.40048 .64602 Mdot
.4526 .81037 Mdot
.57851 .32507 Mdot
.67659 .44399 Mdot
.54884 .61813 Mdot
.41422 .63001 Mdot
.36394 .43178 Mdot
.73632 .36307 Mdot
.51303 .67455 Mdot
.60391 .37756 Mdot
.75642 .49704 Mdot
.46942 .89334 Mdot
.33872 .44484 Mdot
.56521 .59963 Mdot
.6392 .74432 Mdot
.35779 .44603 Mdot
.65627 .48508 Mdot
.17962 .56654 Mdot
.73958 .58597 Mdot
.41265 .47435 Mdot
.37378 .40319 Mdot
.59691 .61317 Mdot
.54266 .34435 Mdot
.38255 .40641 Mdot
.45672 .77951 Mdot
.59577 .63863 Mdot
.69112 .4989 Mdot
.81566 .3623 Mdot
.62324 .50446 Mdot
.42324 .33377 Mdot
.76791 .59041 Mdot
.3393 .43119 Mdot
.67434 .47091 Mdot
.61055 .37506 Mdot
.66889 .46275 Mdot
.39692 .6141 Mdot
.67461 .45817 Mdot
.38238 .44415 Mdot
.4211 .65441 Mdot
.54245 .62313 Mdot
.46129 .80207 Mdot
.71849 .63999 Mdot
.64209 .46623 Mdot
.74021 .60113 Mdot
.40205 .47874 Mdot
.303 .36808 Mdot
.39172 .52221 Mdot
.40197 .47376 Mdot
.56664 .64026 Mdot
.42942 .64027 Mdot
.53491 .61435 Mdot
.35613 .49246 Mdot
.33145 .75163 Mdot
.58842 .60697 Mdot
.57164 .73233 Mdot
.59929 .33877 Mdot
.47432 .36223 Mdot
.36334 .42539 Mdot
.57293 .6283 Mdot
.42528 .43342 Mdot
.42467 .68168 Mdot
.55767 .53194 Mdot
.7095 .69624 Mdot
.57146 .62353 Mdot
.62236 .20954 Mdot
.53996 .53854 Mdot
.45962 .45129 Mdot
.57619 .6267 Mdot
.23457 .63752 Mdot
.76483 .58302 Mdot
.60849 .34575 Mdot
.58378 .37678 Mdot
.5986 .37973 Mdot
.37894 .39784 Mdot
.35656 .36105 Mdot
.58321 .3299 Mdot
.60217 .62352 Mdot
.62453 .34763 Mdot
.49561 .3906 Mdot
.61298 .20751 Mdot
.58512 .36453 Mdot
.37431 .42853 Mdot
.32259 .45426 Mdot
.47384 .32108 Mdot
.69929 .47316 Mdot
.44538 .18036 Mdot
.37196 .56179 Mdot
.38683 .4747 Mdot
.4585 .42023 Mdot
.41279 .61708 Mdot
.67712 .73655 Mdot
.45855 .40255 Mdot
.73966 .46359 Mdot
.42732 .67324 Mdot
.61617 .4835 Mdot
.41628 .62566 Mdot
.34894 .4649 Mdot
.40597 .44942 Mdot
.37827 .70599 Mdot
.62901 .58055 Mdot
.64327 .70321 Mdot
.73982 .29509 Mdot
.38822 .67196 Mdot
.5762 .61566 Mdot
.54644 .607 Mdot
.57674 .64144 Mdot
.68063 .51258 Mdot
.36884 .65331 Mdot
.42298 .4188 Mdot
.6705 .49919 Mdot
.35499 .4224 Mdot
.56235 .63808 Mdot
.78363 .31457 Mdot
.39134 .66415 Mdot
.36724 .4674 Mdot
.72194 .73944 Mdot
.64647 .47722 Mdot
.61467 .34924 Mdot
.5517 .40401 Mdot
.64944 .51348 Mdot
.53369 .64201 Mdot
.41183 .70007 Mdot
.56841 .58069 Mdot
.50426 .47148 Mdot
.42737 .39108 Mdot
.32758 .43192 Mdot
.81254 .38854 Mdot
.7576 .6704 Mdot
.37107 .39384 Mdot
.67918 .49343 Mdot
.70418 .48092 Mdot
.39135 .42262 Mdot
.37204 .65397 Mdot
.57558 .36298 Mdot
.6238 .36493 Mdot
.39687 .51023 Mdot
.54725 .49027 Mdot
.49654 .37667 Mdot
.40412 .4244 Mdot
.31329 .38472 Mdot
.63069 .47921 Mdot
.74388 .57305 Mdot
.53522 .78197 Mdot
.57907 .35529 Mdot
.41118 .44708 Mdot
.57043 .71286 Mdot
.41253 .68262 Mdot
.67424 .45929 Mdot
.54225 .64733 Mdot
.55682 .29897 Mdot
.65018 .50965 Mdot
.39243 .42363 Mdot
.39781 .42174 Mdot
.59586 .61214 Mdot
.3963 .60219 Mdot
.60208 .35196 Mdot
.66834 .4984 Mdot
.57809 .35039 Mdot
.42003 .66781 Mdot
.39483 .66177 Mdot
.43688 .39621 Mdot
.30848 .42195 Mdot
.63632 .4745 Mdot
.39409 .50347 Mdot
.6873 .45486 Mdot
.55428 .32179 Mdot
.56432 .59298 Mdot
.33519 .43195 Mdot
.42834 .6889 Mdot
.55942 .64114 Mdot
.37662 .46188 Mdot
.84971 .45486 Mdot
.35456 .41332 Mdot
.66634 .52023 Mdot
.33679 .75846 Mdot
.62196 .35008 Mdot
.34388 .64326 Mdot
.32857 .50713 Mdot
.39639 .45945 Mdot
.67112 .44411 Mdot
.39062 .52052 Mdot
.59121 .60738 Mdot
.43065 .6633 Mdot
.60546 .85296 Mdot
.55262 .63043 Mdot
.40777 .45836 Mdot
.59629 .36315 Mdot
.42682 .68685 Mdot
.74672 .59404 Mdot
.54967 .78662 Mdot
.45162 .44314 Mdot
.34741 .38611 Mdot
.41784 .45955 Mdot
.19348 .433 Mdot
.67869 .47254 Mdot
.41321 .63099 Mdot
.58034 .60049 Mdot
.5431 .6362 Mdot
.64905 .49224 Mdot
.50474 .74475 Mdot
.61792 .54215 Mdot
.56948 .09957 Mdot
.64459 .45481 Mdot
.62211 .33434 Mdot
.5423 .45835 Mdot
.67742 .45141 Mdot
.67272 .47884 Mdot
.63503 .48695 Mdot
.53832 .76368 Mdot
.38295 .64778 Mdot
.39264 .43613 Mdot
.35967 .65473 Mdot
.33955 .42869 Mdot
.34992 .32852 Mdot
.54836 .64386 Mdot
.42851 .66697 Mdot
.83405 .41853 Mdot
.45828 .50969 Mdot
.36482 .44493 Mdot
.63082 .26205 Mdot
.40888 .51746 Mdot
.52597 .30083 Mdot
.43635 .50649 Mdot
.64887 .46735 Mdot
.42219 .37287 Mdot
.3171 .43329 Mdot
.45044 .80709 Mdot
.55106 .61522 Mdot
.77041 .59138 Mdot
.41645 .39879 Mdot
.44625 .45809 Mdot
.41608 .69163 Mdot
.38369 .66832 Mdot
.58321 .33076 Mdot
.56397 .44109 Mdot
.54442 .62021 Mdot
.59495 .46994 Mdot
.38886 .47019 Mdot
.59976 .56921 Mdot
.32792 .71207 Mdot
.37522 .46246 Mdot
.51885 .19967 Mdot
.27934 .66694 Mdot
.37857 .40601 Mdot
.21397 .5875 Mdot
.55949 .61931 Mdot
.35545 .76014 Mdot
.40675 .49439 Mdot
.65644 .4835 Mdot
.42822 .66244 Mdot
.4088 .6169 Mdot
.59108 .3716 Mdot
.5496 .82147 Mdot
.5317 .64387 Mdot
.42504 .6695 Mdot
.35464 .44257 Mdot
.54663 .64873 Mdot
.76056 .60051 Mdot
.31993 .44025 Mdot
.45669 .22577 Mdot
.39848 .64932 Mdot
.42169 .4843 Mdot
.45922 .70056 Mdot
.53752 .40791 Mdot
.38193 .18654 Mdot
.58178 .636 Mdot
.58114 .35545 Mdot
.45149 .48984 Mdot
.83214 .46917 Mdot
.43974 .44599 Mdot
.47981 .35536 Mdot
.45568 .61761 Mdot
.58341 .33691 Mdot
.36 .45346 Mdot
.38868 .40858 Mdot
.53744 .48626 Mdot
.6062 .38643 Mdot
.34481 .41967 Mdot
.41538 .37873 Mdot
.38496 .63984 Mdot
.77259 .59484 Mdot
.39419 .65357 Mdot
.37144 .43038 Mdot
.36613 .35879 Mdot
.37671 .6536 Mdot
.73372 .32324 Mdot
.62747 .36893 Mdot
.59085 .62652 Mdot
.32834 .37248 Mdot
.42726 .4573 Mdot
.19292 .37441 Mdot
.76986 .58308 Mdot
.17641 .53507 Mdot
.62214 .47817 Mdot
.59131 .7001 Mdot
.63367 .41925 Mdot
.52999 .17044 Mdot
.47456 .79743 Mdot
.44471 .42789 Mdot
.4168 .26046 Mdot
.20767 .54927 Mdot
.52895 .63017 Mdot
.24223 .44741 Mdot
.38984 .47209 Mdot
.34778 .45231 Mdot
.69261 .48969 Mdot
.48926 .75303 Mdot
.63066 .74604 Mdot
.55859 .49943 Mdot
.59862 .34996 Mdot
.41358 .6748 Mdot
.38796 .45114 Mdot
.67819 .54518 Mdot
.66759 .45337 Mdot
.53692 .56685 Mdot
.36175 .46226 Mdot
.62499 .77284 Mdot
.55915 .74594 Mdot
.54969 .65084 Mdot
.64323 .44639 Mdot
.6455 .51057 Mdot
.35288 .46633 Mdot
.53545 .64115 Mdot
.37683 .40882 Mdot
.55607 .54829 Mdot
.40805 .49956 Mdot
.59463 .36909 Mdot
.38611 .48698 Mdot
.51482 .50493 Mdot
.44921 .15263 Mdot
.47102 .45236 Mdot
.37207 .6374 Mdot
.67427 .51387 Mdot
.64226 .48679 Mdot
.38694 .66792 Mdot
.64381 .48672 Mdot
.24026 .59736 Mdot
.34136 .58918 Mdot
.59601 .34728 Mdot
.3493 .3566 Mdot
.59948 .37082 Mdot
.77089 .5891 Mdot
.38539 .47787 Mdot
.84219 .49131 Mdot
.64121 .45914 Mdot
.22489 .65786 Mdot
.54811 .62848 Mdot
.77023 .58715 Mdot
.43796 .44713 Mdot
.69994 .3164 Mdot
.69526 .46863 Mdot
.64403 .51634 Mdot
.3803 .4133 Mdot
.38335 .66096 Mdot
.39107 .41 Mdot
.43042 .50246 Mdot
.75418 .57248 Mdot
.4216 .45652 Mdot
.57566 .60435 Mdot
.36873 .66376 Mdot
.56637 .19402 Mdot
.70014 .50066 Mdot
.3746 .48196 Mdot
.35486 .44392 Mdot
.43196 .67592 Mdot
.43341 .45768 Mdot
.53594 .62823 Mdot
.34632 .13947 Mdot
.60049 .33843 Mdot
.73782 .57611 Mdot
.66577 .52167 Mdot
.40844 .39858 Mdot
.40166 .41965 Mdot
.80791 .3752 Mdot
.68911 .67406 Mdot
.57905 .60817 Mdot
.40745 .51339 Mdot
.67384 .49374 Mdot
.59422 .3629 Mdot
.59204 .64024 Mdot
.41264 .44017 Mdot
.35583 .4616 Mdot
.59262 .3673 Mdot
.55149 .20854 Mdot
.74596 .47272 Mdot
.57248 .64556 Mdot
.42552 .37342 Mdot
.7438 .38087 Mdot
.35794 .42396 Mdot
.77117 .38361 Mdot
.39474 .6702 Mdot
.57728 .63071 Mdot
.19956 .47542 Mdot
.36116 .48496 Mdot
.53865 .62113 Mdot
.54614 .6189 Mdot
.39085 .49247 Mdot
.35984 .66131 Mdot
.38213 .68277 Mdot
.39892 .67769 Mdot
.34477 .77723 Mdot
.39556 .30553 Mdot
.66679 .45806 Mdot
.56072 .61843 Mdot
.69596 .45548 Mdot
.57823 .37401 Mdot
.5494 .42939 Mdot
.69998 .46553 Mdot
.41225 .6175 Mdot
.66214 .44001 Mdot
.38636 .41122 Mdot
.54211 .62185 Mdot
.68702 .47572 Mdot
.39516 .39392 Mdot
.28909 .42592 Mdot
.51073 .54714 Mdot
.57512 .35391 Mdot
.55327 .36525 Mdot
.39857 .44752 Mdot
.76168 .5754 Mdot
.37542 .47238 Mdot
.5564 .65378 Mdot
.51716 .48336 Mdot
.39818 .39619 Mdot
.63872 .46982 Mdot
.41071 .54695 Mdot
.69764 .49336 Mdot
.43171 .49529 Mdot
.3738 .43127 Mdot
.35125 .4284 Mdot
.38199 .40608 Mdot
.55505 .73686 Mdot
.52782 .62657 Mdot
.28656 .4167 Mdot
.68717 .44034 Mdot
.40771 .64631 Mdot
.43665 .62522 Mdot
.76167 .41005 Mdot
.73954 .57127 Mdot
.55954 .61146 Mdot
.36127 .422 Mdot
.64742 .5196 Mdot
.77718 .30697 Mdot
.76222 .34941 Mdot
.62615 .28051 Mdot
.68395 .48804 Mdot
.37494 .63409 Mdot
.68209 .45901 Mdot
.34432 .45087 Mdot
.34322 .47636 Mdot
.54147 .17898 Mdot
.52685 .66265 Mdot
.60376 .35167 Mdot
.34833 .42818 Mdot
.41283 .3319 Mdot
.67421 .49447 Mdot
.62966 .47861 Mdot
.35326 .41656 Mdot
.38199 .67665 Mdot
.30309 .21973 Mdot
.54549 .65031 Mdot
.27953 .38435 Mdot
.38865 .57972 Mdot
.38633 .75255 Mdot
.54093 .63914 Mdot
.4984 .56518 Mdot
.65532 .50469 Mdot
.35635 .60425 Mdot
.40673 .65032 Mdot
.60592 .35466 Mdot
.3332 .46121 Mdot
.41109 .61822 Mdot
.62393 .46702 Mdot
.42662 .63018 Mdot
.34934 .46856 Mdot
.52946 .62581 Mdot
.65212 .49819 Mdot
.6117 .61048 Mdot
.37849 .70686 Mdot
.61234 .36852 Mdot
.47332 .36333 Mdot
.25228 .42685 Mdot
.27807 .66735 Mdot
.40091 .40017 Mdot
.72756 .5141 Mdot
.4247 .42899 Mdot
.4085 .69202 Mdot
.36543 .4254 Mdot
.46417 .61892 Mdot
.6344 .45693 Mdot
.42075 .48506 Mdot
.40906 .47761 Mdot
.26658 .48837 Mdot
.36795 .45263 Mdot
.41996 .47407 Mdot
.38279 .40387 Mdot
.39366 .57767 Mdot
.44286 .40999 Mdot
.38226 .65327 Mdot
.56643 .76538 Mdot
.6714 .47699 Mdot
.57435 .34765 Mdot
.61627 .37567 Mdot
.48657 .36133 Mdot
.47048 .35759 Mdot
.50732 .74844 Mdot
.39002 .64899 Mdot
.56633 .60401 Mdot
.37572 .40896 Mdot
.21168 .44736 Mdot
.59949 .30401 Mdot
.65344 .50266 Mdot
.6889 .51196 Mdot
.30932 .43347 Mdot
.19427 .42678 Mdot
.43162 .47448 Mdot
.55592 .79084 Mdot
.39668 .50856 Mdot
.34895 .41475 Mdot
.65536 .51409 Mdot
.5158 .39029 Mdot
.40031 .39983 Mdot
.41691 .69143 Mdot
.60969 .35472 Mdot
.47474 .43975 Mdot
.65806 .39414 Mdot
.5264 .56039 Mdot
.29974 .5094 Mdot
.42813 .42925 Mdot
.66244 .49856 Mdot
.40699 .62026 Mdot
.52557 .79118 Mdot
.56843 .64445 Mdot
.50911 .77019 Mdot
.25563 .51053 Mdot
.69692 .28845 Mdot
.60716 .35222 Mdot
.54301 .20884 Mdot
.38314 .44443 Mdot
.67261 .515 Mdot
.33867 .4507 Mdot
.77202 .30198 Mdot
.61125 .32499 Mdot
.38323 .61259 Mdot
.57566 .61363 Mdot
.42273 .6822 Mdot
.29289 .64822 Mdot
.47894 .59342 Mdot
.70402 .56339 Mdot
.70768 .47602 Mdot
.30089 .35212 Mdot
.42327 .64611 Mdot
.40237 .43139 Mdot
.61189 .12209 Mdot
.39617 .67085 Mdot
.39317 .67934 Mdot
.54691 .34938 Mdot
.60327 .28385 Mdot
.37201 .51184 Mdot
.43146 .63457 Mdot
.68089 .44094 Mdot
.61714 .34266 Mdot
.40055 .4064 Mdot
.38682 .4058 Mdot
.38075 .66084 Mdot
.6926 .46285 Mdot
.28444 .35748 Mdot
.64457 .46959 Mdot
.38689 .63579 Mdot
.65295 .47335 Mdot
.70852 .50942 Mdot
.68382 .47969 Mdot
.42845 .46001 Mdot
.36615 .42127 Mdot
.66619 .37841 Mdot
.39493 .66159 Mdot
.40619 .41868 Mdot
.4062 .44501 Mdot
.42093 .64794 Mdot
.63391 .42832 Mdot
.21799 .42862 Mdot
.40032 .46915 Mdot
.38256 .42736 Mdot
.58059 .34387 Mdot
.61982 .45044 Mdot
.76298 .51302 Mdot
.40381 .41137 Mdot
.62654 .35488 Mdot
.37476 .68111 Mdot
.37534 .47062 Mdot
.50055 .39527 Mdot
.71184 .4955 Mdot
.38091 .48862 Mdot
.74753 .59584 Mdot
.41518 .40288 Mdot
.31886 .21368 Mdot
.38205 .48292 Mdot
.41196 .63315 Mdot
.42971 .65212 Mdot
.55544 .3816 Mdot
.41188 .66406 Mdot
.76727 .59505 Mdot
.56049 .63783 Mdot
.71391 .2661 Mdot
.761 .59929 Mdot
.35404 .40935 Mdot
.70431 .7622 Mdot
.38739 .50038 Mdot
.4147 .39849 Mdot
.18832 .48564 Mdot
.76098 .59834 Mdot
.42624 .63927 Mdot
.63031 .58981 Mdot
.39231 .5096 Mdot
.54135 .64751 Mdot
.32303 .43305 Mdot
.39071 .48911 Mdot
.42551 .77012 Mdot
.30923 .72472 Mdot
.56623 .65225 Mdot
.45831 .48407 Mdot
.40454 .41181 Mdot
.74644 .66057 Mdot
.36136 .43712 Mdot
.58689 .36726 Mdot
.39684 .67965 Mdot
.66444 .44937 Mdot
.60292 .335 Mdot
.39323 .46525 Mdot
.60288 .35783 Mdot
.67322 .45993 Mdot
.57046 .63788 Mdot
.36978 .47911 Mdot
.62812 .34113 Mdot
.59942 .35125 Mdot
.42086 .42728 Mdot
.42807 .66573 Mdot
.46576 .4931 Mdot
.37541 .4688 Mdot
.39826 .42911 Mdot
.38639 .6646 Mdot
.82418 .63084 Mdot
.345 .45598 Mdot
.49826 .54334 Mdot
.37998 .61593 Mdot
.76586 .60541 Mdot
.68815 .46916 Mdot
.37847 .49124 Mdot
.55039 .64691 Mdot
.55348 .64385 Mdot
.63864 .44508 Mdot
.42465 .68293 Mdot
.69845 .47375 Mdot
.46234 .48473 Mdot
.308 .41446 Mdot
.36226 .4929 Mdot
.58732 .85324 Mdot
.52695 .18089 Mdot
.3714 .64778 Mdot
.66955 .50754 Mdot
.56151 .49861 Mdot
.56401 .61445 Mdot
.6579 .43888 Mdot
.41779 .69524 Mdot
.38244 .62917 Mdot
.42623 .62663 Mdot
.58293 .34252 Mdot
.65085 .5075 Mdot
.39287 .60415 Mdot
.38761 .68041 Mdot
.38299 .41258 Mdot
.40575 .41341 Mdot
.4605 .66182 Mdot
.48714 .3113 Mdot
.6077 .37155 Mdot
.65635 .49363 Mdot
.16316 .39148 Mdot
.55788 .6536 Mdot
.26895 .48931 Mdot
.40349 .39641 Mdot
.82776 .29902 Mdot
.42884 .48057 Mdot
.35606 .44032 Mdot
.36913 .67145 Mdot
.61587 .32201 Mdot
.6101 .36451 Mdot
.42434 .64774 Mdot
.4024 .70477 Mdot
.58277 .36312 Mdot
.58412 .23872 Mdot
.62486 .2069 Mdot
.51391 .78528 Mdot
.41457 .63824 Mdot
.25758 .41995 Mdot
.53389 .64122 Mdot
.3677 .7001 Mdot
.58014 .64469 Mdot
.67159 .47978 Mdot
.64148 .49937 Mdot
.59641 .61512 Mdot
.37755 .41394 Mdot
.67971 .46427 Mdot
.4489 .41514 Mdot
.59914 .22563 Mdot
.34328 .25756 Mdot
.67666 .65923 Mdot
.39344 .3912 Mdot
.61862 .75383 Mdot
.65332 .72351 Mdot
.39823 .45372 Mdot
.49039 .42916 Mdot
.60402 .35371 Mdot
.35594 .67229 Mdot
.53533 .6311 Mdot
.3687 .19342 Mdot
.35926 .42317 Mdot
.40361 .63352 Mdot
.55368 .61331 Mdot
.58497 .4063 Mdot
.45297 .77572 Mdot
.34227 .42665 Mdot
.51122 .10056 Mdot
.35463 .65601 Mdot
.66319 .44926 Mdot
.62949 .80551 Mdot
.36011 .64979 Mdot
.55292 .35474 Mdot
.62841 .4858 Mdot
.76081 .32954 Mdot
.41172 .62683 Mdot
.62638 .45457 Mdot
.41773 .668 Mdot
.59585 .37212 Mdot
.38149 .69544 Mdot
.65581 .50022 Mdot
.36359 .45442 Mdot
.64777 .48743 Mdot
.60816 .37241 Mdot
.68196 .51318 Mdot
.53388 .63599 Mdot
.76766 .58282 Mdot
.5635 .62636 Mdot
.54667 .4162 Mdot
.31907 .73869 Mdot
.58629 .62442 Mdot
.59956 .42719 Mdot
.37442 .39321 Mdot
.40226 .60139 Mdot
.64736 .45092 Mdot
.6843 .43968 Mdot
.55207 .44828 Mdot
.41214 .64632 Mdot
.65285 .49556 Mdot
.24886 .50804 Mdot
.77777 .70553 Mdot
.35126 .36336 Mdot
.40436 .29205 Mdot
.41932 .6455 Mdot
.62858 .46673 Mdot
.53937 .79216 Mdot
.4281 .6234 Mdot
.64548 .45487 Mdot
.5756 .62411 Mdot
.54223 .63705 Mdot
.35697 .4182 Mdot
.54822 .66783 Mdot
.65812 .44364 Mdot
.62116 .7111 Mdot
.40981 .68448 Mdot
.58243 .40674 Mdot
.59195 .37476 Mdot
.67636 .48081 Mdot
.31691 .42514 Mdot
.42709 .69929 Mdot
.71106 .47749 Mdot
.4135 .24264 Mdot
.15667 .41882 Mdot
.6515 .49272 Mdot
.39884 .68096 Mdot
.39894 .63707 Mdot
.40281 .51952 Mdot
.54564 .48635 Mdot
.69808 .48125 Mdot
.84097 .51725 Mdot
.4703 .3468 Mdot
.75065 .583 Mdot
.76551 .66986 Mdot
.40033 .39894 Mdot
.42463 .43718 Mdot
.56619 .61253 Mdot
.37194 .44397 Mdot
.38284 .67985 Mdot
.43187 .42055 Mdot
.54271 .61402 Mdot
.65726 .50424 Mdot
.37504 .47918 Mdot
.62015 .35079 Mdot
.54474 .65657 Mdot
.59703 .62123 Mdot
.66454 .46984 Mdot
.42982 .63132 Mdot
.65322 .53942 Mdot
.6412 .47297 Mdot
.42752 .42496 Mdot
.75569 .59465 Mdot
.3613 .48255 Mdot
.52033 .22236 Mdot
.44069 .64811 Mdot
.6781 .45472 Mdot
.3928 .61712 Mdot
.55922 .62722 Mdot
.65805 .43424 Mdot
.36769 .43585 Mdot
.64552 .45747 Mdot
.6962 .41872 Mdot
.55661 .22714 Mdot
.42274 .68527 Mdot
.64175 .40639 Mdot
.39496 .68188 Mdot
.74906 .5826 Mdot
.51468 .24288 Mdot
.60456 .34415 Mdot
.67366 .49047 Mdot
.50948 .17686 Mdot
.6375 .46762 Mdot
.36999 .45364 Mdot
.38185 .4593 Mdot
.69193 .4888 Mdot
.61197 .33129 Mdot
.29957 .75959 Mdot
.48595 .56445 Mdot
.4243 .63372 Mdot
.37041 .58127 Mdot
.18758 .33851 Mdot
.59866 .63657 Mdot
.57002 .60937 Mdot
.43375 .48213 Mdot
.36077 .40938 Mdot
.59835 .62286 Mdot
.56624 .59536 Mdot
.5767 .3507 Mdot
.6392 .49246 Mdot
.37409 .60689 Mdot
.58236 .65319 Mdot
.36791 .52835 Mdot
.43139 .33831 Mdot
.38634 .51424 Mdot
.37507 .37202 Mdot
.36635 .38816 Mdot
.53668 .39868 Mdot
.56771 .59792 Mdot
.39795 .44538 Mdot
.44525 .41781 Mdot
.57963 .62242 Mdot
.59659 .37172 Mdot
.38399 .73255 Mdot
.65443 .47835 Mdot
.87352 .53337 Mdot
.3785 .48593 Mdot
.36804 .45994 Mdot
.56712 .64801 Mdot
.77095 .64886 Mdot
.38356 .63225 Mdot
.43872 .64769 Mdot
.67903 .47118 Mdot
.55427 .44644 Mdot
.43503 .44526 Mdot
.39859 .45113 Mdot
.66701 .48889 Mdot
.76639 .58028 Mdot
.66097 .65795 Mdot
.38952 .43532 Mdot
.55107 .61786 Mdot
.71343 .51407 Mdot
.56663 .59726 Mdot
.33807 .44461 Mdot
.37221 .45367 Mdot
.42916 .45973 Mdot
.36083 .40866 Mdot
.58975 .63884 Mdot
.39335 .44632 Mdot
.31385 .42837 Mdot
.43532 .65073 Mdot
.42802 .44819 Mdot
.49783 .36537 Mdot
.37735 .4259 Mdot
.61798 .35886 Mdot
.71503 .53937 Mdot
.35074 .42739 Mdot
.42648 .4514 Mdot
.48952 .56004 Mdot
.35668 .45271 Mdot
.56189 .65218 Mdot
.40426 .64348 Mdot
.56136 .61835 Mdot
.58388 .60124 Mdot
.69178 .44808 Mdot
.57716 .34837 Mdot
.44034 .42352 Mdot
.60396 .37948 Mdot
.35363 .37609 Mdot
.34794 .46725 Mdot
.6662 .53579 Mdot
.55745 .78955 Mdot
.73046 .44855 Mdot
.36811 .43326 Mdot
.67625 .47447 Mdot
.66844 .45073 Mdot
.41473 .25439 Mdot
.45751 .44234 Mdot
.59486 .63425 Mdot
.57296 .62777 Mdot
.50699 .27864 Mdot
.43128 .77529 Mdot
.6132 .36697 Mdot
.57859 .50356 Mdot
.37088 .38945 Mdot
.39705 .43601 Mdot
.32193 .44751 Mdot
.69977 .46412 Mdot
.74791 .57143 Mdot
.65112 .50225 Mdot
.78 .60249 Mdot
.55606 .60055 Mdot
.42371 .41162 Mdot
.36007 .23926 Mdot
.37716 .66127 Mdot
.40387 .64418 Mdot
.60119 .62156 Mdot
.7009 .4854 Mdot
.40479 .52215 Mdot
.6115 .85495 Mdot
.35674 .68695 Mdot
.59068 .31942 Mdot
.40206 .45451 Mdot
.66901 .47012 Mdot
.37816 .66726 Mdot
.62405 .36985 Mdot
.41327 .46829 Mdot
.67343 .43148 Mdot
.36869 .42438 Mdot
.20511 .55072 Mdot
.43356 .64909 Mdot
.77507 .30002 Mdot
.43518 .67549 Mdot
.54348 .65705 Mdot
.58538 .6151 Mdot
.37571 .46017 Mdot
.60304 .8378 Mdot
.37268 .6196 Mdot
.5926 .65164 Mdot
.61155 .32209 Mdot
.73931 .57497 Mdot
.59809 .32342 Mdot
.67677 .45011 Mdot
.60897 .35252 Mdot
.63569 .48584 Mdot
.49709 .28621 Mdot
.35062 .6625 Mdot
.60176 .33675 Mdot
.73871 .64021 Mdot
.41049 .38962 Mdot
.58001 .37299 Mdot
.31096 .42632 Mdot
.36621 .59501 Mdot
.6647 .4862 Mdot
.61386 .33258 Mdot
.40099 .42852 Mdot
.35838 .21214 Mdot
.58704 .60838 Mdot
.59144 .63943 Mdot
.41203 .38807 Mdot
.6339 .48683 Mdot
.39602 .70397 Mdot
.508 .47083 Mdot
.77345 .60185 Mdot
.39701 .44891 Mdot
.42114 .40824 Mdot
.44012 .62915 Mdot
.44332 .66691 Mdot
.37468 .45476 Mdot
.23802 .47934 Mdot
.38591 .4463 Mdot
.54487 .6449 Mdot
.38392 .62945 Mdot
.40026 .6396 Mdot
.65167 .44374 Mdot
.41113 .68769 Mdot
.37488 .37092 Mdot
.52625 .66904 Mdot
.38347 .50745 Mdot
.55465 .63156 Mdot
.51247 .49714 Mdot
.69283 .50777 Mdot
.41223 .19053 Mdot
.4426 .63849 Mdot
.42265 .45619 Mdot
.40366 .68587 Mdot
.58546 .35265 Mdot
.39629 .65893 Mdot
.36832 .64004 Mdot
.38541 .4676 Mdot
.33966 .43064 Mdot
.76287 .59586 Mdot
.54857 .48274 Mdot
.41951 .6776 Mdot
.39159 .45095 Mdot
.39708 .50034 Mdot
.4046 .48492 Mdot
.52944 .52302 Mdot
.37043 .64442 Mdot
.29841 .55402 Mdot
.43455 .22551 Mdot
.42396 .67248 Mdot
.29153 .24178 Mdot
.74245 .58944 Mdot
.73931 .57248 Mdot
.58611 .65343 Mdot
.39025 .43412 Mdot
.68673 .50077 Mdot
.34727 .45633 Mdot
.44427 .40152 Mdot
.35444 .46141 Mdot
.6217 .33794 Mdot
.43998 .41793 Mdot
.75576 .58045 Mdot
.64017 .47679 Mdot
.4076 .46839 Mdot
.37168 .47812 Mdot
.73833 .56985 Mdot
.44379 .64954 Mdot
.39416 .62357 Mdot
.76728 .36981 Mdot
.59048 .35134 Mdot
.56689 .64185 Mdot
.36691 .4158 Mdot
.67766 .47387 Mdot
.64575 .48518 Mdot
.41652 .685 Mdot
.65414 .48413 Mdot
.54905 .65243 Mdot
.36528 .43885 Mdot
.59329 .63574 Mdot
.62334 .34621 Mdot
.39433 .6776 Mdot
.36329 .41664 Mdot
.38325 .41298 Mdot
.42974 .6517 Mdot
.37383 .39307 Mdot
.58039 .34446 Mdot
.63712 .47566 Mdot
.4029 .62417 Mdot
.55845 .63962 Mdot
.65853 .44169 Mdot
.3931 .41666 Mdot
.15707 .44013 Mdot
.37558 .4445 Mdot
.39155 .42524 Mdot
.58993 .19445 Mdot
.43269 .4872 Mdot
.64275 .45045 Mdot
.43178 .62038 Mdot
.36019 .38465 Mdot
.40072 .32445 Mdot
.81468 .42027 Mdot
.6616 .43785 Mdot
.40582 .46106 Mdot
.43282 .18036 Mdot
.40702 .46524 Mdot
.59401 .47271 Mdot
.75795 .44661 Mdot
.31574 .32477 Mdot
.36623 .37219 Mdot
.59118 .63187 Mdot
.76479 .59512 Mdot
.63189 .46612 Mdot
.24325 .64121 Mdot
.38897 .46146 Mdot
.22912 .63261 Mdot
.40105 .48256 Mdot
.5409 .63654 Mdot
.44528 .52187 Mdot
.65524 .49178 Mdot
.5108 .82125 Mdot
.4245 .4214 Mdot
.37193 .64217 Mdot
.67664 .44356 Mdot
.73896 .57976 Mdot
.39562 .42344 Mdot
.61443 .37494 Mdot
.61346 .63039 Mdot
.30927 .39934 Mdot
.55364 .63462 Mdot
.40794 .4451 Mdot
.46342 .46737 Mdot
.57866 .83036 Mdot
.43306 .64445 Mdot
.57293 .61208 Mdot
.68461 .72581 Mdot
.36442 .39523 Mdot
.40938 .62572 Mdot
.40755 .64957 Mdot
.59924 .37556 Mdot
.59951 .5455 Mdot
.47688 .68789 Mdot
.2999 .28515 Mdot
.30548 .6803 Mdot
.63552 .45183 Mdot
.65475 .70532 Mdot
.40403 .40785 Mdot
.48764 .59568 Mdot
.57355 .64795 Mdot
.3658 .45836 Mdot
.31885 .70583 Mdot
.39688 .67601 Mdot
.38348 .43317 Mdot
.59797 .37106 Mdot
.61248 .56535 Mdot
.52361 .56972 Mdot
.21641 .34959 Mdot
.67153 .43843 Mdot
.33115 .46131 Mdot
.34786 .37556 Mdot
.75421 .60443 Mdot
.34248 .46141 Mdot
.63713 .45804 Mdot
.61182 .24357 Mdot
.61205 .32961 Mdot
.38321 .67268 Mdot
.74183 .58828 Mdot
.37448 .38606 Mdot
.4028 .49437 Mdot
.57462 .34602 Mdot
.41613 .43869 Mdot
.55596 .81846 Mdot
.75197 .56013 Mdot
.68376 .46979 Mdot
.4228 .62618 Mdot
.3608 .39189 Mdot
.74966 .57191 Mdot
.38416 .46463 Mdot
.31393 .5099 Mdot
.42267 .44879 Mdot
.4506 .71475 Mdot
.42735 .66369 Mdot
.55734 .63355 Mdot
.37661 .37658 Mdot
.34779 .44835 Mdot
.73971 .37171 Mdot
.44444 .40198 Mdot
.38099 .4836 Mdot
.41983 .69058 Mdot
.3733 .65496 Mdot
.38342 .65437 Mdot
.67367 .45701 Mdot
.52501 .78237 Mdot
.55257 .62208 Mdot
.43807 .43233 Mdot
.5822 .65311 Mdot
.32345 .5096 Mdot
.57899 .33356 Mdot
.29625 .25746 Mdot
.42045 .46248 Mdot
.38612 .64982 Mdot
.54962 .7134 Mdot
.37603 .68153 Mdot
.68642 .43789 Mdot
.54384 .62071 Mdot
.39775 .67335 Mdot
.3503 .44279 Mdot
.54904 .49893 Mdot
.22998 .35179 Mdot
.56656 .61868 Mdot
.32683 .46179 Mdot
.66722 .43572 Mdot
.70089 .50457 Mdot
.20369 .29761 Mdot
.58137 .60816 Mdot
.65895 .7189 Mdot
.39413 .4552 Mdot
.37768 .65987 Mdot
.58501 .63285 Mdot
.59284 .61783 Mdot
.66163 .48722 Mdot
.34223 .42853 Mdot
.35087 .43029 Mdot
.74604 .59424 Mdot
.57061 .632 Mdot
.39486 .38422 Mdot
.37354 .49907 Mdot
.54462 .1794 Mdot
.37249 .72755 Mdot
.83789 .60361 Mdot
.46283 .48373 Mdot
.30388 .68763 Mdot
.53604 .45075 Mdot
.36918 .65684 Mdot
.34808 .42615 Mdot
.34878 .39503 Mdot
.64918 .44521 Mdot
.37083 .44094 Mdot
.68941 .50314 Mdot
.56735 .60724 Mdot
.27507 .26756 Mdot
.52468 .67591 Mdot
.59763 .24681 Mdot
.36737 .44627 Mdot
.40957 .75876 Mdot
.59424 .33486 Mdot
.54343 .59285 Mdot
.38718 .63331 Mdot
.34577 .40547 Mdot
.66065 .51846 Mdot
.67419 .49135 Mdot
.40671 .65983 Mdot
.61177 .73711 Mdot
.76431 .38159 Mdot
.33504 .43557 Mdot
.68973 .46949 Mdot
.60287 .69141 Mdot
.23279 .48748 Mdot
.52298 .65652 Mdot
.61201 .32789 Mdot
.65594 .50316 Mdot
.59498 .60347 Mdot
.42299 .70689 Mdot
.40536 .6706 Mdot
.41714 .61245 Mdot
.71598 .39927 Mdot
.69805 .48822 Mdot
.60856 .33526 Mdot
.47569 .78887 Mdot
.45815 .79458 Mdot
.61914 .33334 Mdot
.65955 .50542 Mdot
.37477 .66115 Mdot
.39706 .63123 Mdot
.4045 .64245 Mdot
.49911 .82043 Mdot
.43867 .65761 Mdot
.31769 .54227 Mdot
.3892 .49949 Mdot
.32186 .36004 Mdot
.40585 .46446 Mdot
.58056 .64668 Mdot
.43291 .64874 Mdot
.54568 .45234 Mdot
.36365 .40192 Mdot
.22621 .34309 Mdot
.40008 .44953 Mdot
.51876 .65116 Mdot
.38711 .43111 Mdot
.25391 .45158 Mdot
.37722 .6181 Mdot
.37045 .43458 Mdot
.52894 .61636 Mdot
.59789 .35464 Mdot
.40396 .59222 Mdot
.35018 .42827 Mdot
.47004 .75341 Mdot
.44057 .46335 Mdot
.60983 .23688 Mdot
.53044 .36113 Mdot
.59563 .31611 Mdot
.42408 .38383 Mdot
.6297 .45524 Mdot
.42772 .59572 Mdot
.37921 .35282 Mdot
.56687 .62024 Mdot
.21837 .64183 Mdot
.67696 .4879 Mdot
.45096 .51805 Mdot
.40977 .51287 Mdot
.57798 .35371 Mdot
.45453 .64869 Mdot
.56886 .64867 Mdot
.39964 .39374 Mdot
.3945 .49146 Mdot
.57713 .24814 Mdot
.3617 .35459 Mdot
.4343 .45902 Mdot
.57454 .36208 Mdot
.30684 .56052 Mdot
.37899 .42098 Mdot
.63754 .42778 Mdot
.40868 .61291 Mdot
.42345 .39257 Mdot
.2945 .54847 Mdot
.39094 .4523 Mdot
.39837 .66699 Mdot
.43803 .62296 Mdot
.50983 .7227 Mdot
.60769 .31813 Mdot
.42252 .44874 Mdot
.55813 .30471 Mdot
.42637 .43084 Mdot
.54879 .6222 Mdot
.34624 .45886 Mdot
.67173 .48433 Mdot
.54955 .79501 Mdot
.65836 .45493 Mdot
.34393 .45227 Mdot
.4067 .63891 Mdot
.58567 .63677 Mdot
.67949 .38963 Mdot
.76036 .43123 Mdot
.31731 .54558 Mdot
.84069 .43043 Mdot
.59696 .32874 Mdot
.59415 .38478 Mdot
.53067 .64854 Mdot
.37111 .43131 Mdot
.54269 .36475 Mdot
.41498 .50028 Mdot
.38353 .42672 Mdot
.35624 .46421 Mdot
.56137 .66945 Mdot
.56012 .61451 Mdot
.64867 .47841 Mdot
.37422 .45276 Mdot
.3912 .44936 Mdot
.41478 .67688 Mdot
.59751 .35246 Mdot
.66068 .4528 Mdot
.59466 .34406 Mdot
.65579 .46379 Mdot
.31465 .21621 Mdot
.36451 .49937 Mdot
.5966 .3567 Mdot
.52986 .6491 Mdot
.38576 .66469 Mdot
.76669 .57589 Mdot
.67449 .44764 Mdot
.65531 .49437 Mdot
.39674 .45016 Mdot
.38966 .66792 Mdot
.41748 .68172 Mdot
.58518 .34687 Mdot
.57755 .63555 Mdot
.34323 .44992 Mdot
.33562 .44015 Mdot
.36565 .27583 Mdot
.69207 .45474 Mdot
.24265 .51671 Mdot
.52268 .73433 Mdot
.36936 .431 Mdot
.43406 .64117 Mdot
.37521 .4764 Mdot
.41996 .19979 Mdot
.41154 .61764 Mdot
.34871 .4156 Mdot
.42048 .77759 Mdot
.7048 .47465 Mdot
.46646 .72089 Mdot
.4248 .47748 Mdot
.80444 .36809 Mdot
.41375 .41478 Mdot
.5204 .15516 Mdot
.71415 .67163 Mdot
.43171 .42176 Mdot
.39387 .40869 Mdot
.28714 .30388 Mdot
.39656 .46114 Mdot
.74924 .57973 Mdot
.46969 .46382 Mdot
.38306 .62828 Mdot
.52715 .41929 Mdot
.65533 .42375 Mdot
.61644 .3255 Mdot
.67933 .47106 Mdot
.66514 .41216 Mdot
.59245 .36886 Mdot
.41631 .63842 Mdot
.38438 .40507 Mdot
.46709 .35905 Mdot
.70574 .4569 Mdot
.42817 .50163 Mdot
.54691 .62317 Mdot
.62667 .42403 Mdot
.68014 .50926 Mdot
.5608 .63598 Mdot
.41037 .47799 Mdot
.22665 .40264 Mdot
.7615 .46251 Mdot
.73356 .27506 Mdot
.57176 .64591 Mdot
.53885 .63697 Mdot
.52841 .79593 Mdot
.61929 .32907 Mdot
.51251 .22951 Mdot
.4163 .74351 Mdot
.53972 .64834 Mdot
.5361 .27045 Mdot
.63202 .48641 Mdot
.45986 .7556 Mdot
.35608 .67281 Mdot
.34789 .48568 Mdot
.34916 .4442 Mdot
.57903 .63176 Mdot
.47029 .37031 Mdot
.609 .80684 Mdot
.56463 .62558 Mdot
.33274 .38701 Mdot
.60656 .5512 Mdot
.75131 .59285 Mdot
.75013 .59924 Mdot
.59776 .31843 Mdot
.74141 .33533 Mdot
.42156 .66374 Mdot
.57892 .3605 Mdot
.57282 .56115 Mdot
.41919 .44843 Mdot
.57078 .62579 Mdot
.75902 .57015 Mdot
.5482 .64136 Mdot
.60505 .36768 Mdot
.59024 .32008 Mdot
.43513 .64896 Mdot
.38445 .63177 Mdot
.29986 .68828 Mdot
.51438 .29982 Mdot
.40738 .46661 Mdot
.18861 .51801 Mdot
.40993 .68517 Mdot
.39968 .36066 Mdot
.62636 .35327 Mdot
.5944 .35432 Mdot
.21409 .55778 Mdot
.37063 .40992 Mdot
.59017 .40351 Mdot
.36345 .41994 Mdot
.49289 .24313 Mdot
.33302 .43811 Mdot
.6587 .48517 Mdot
.41465 .40525 Mdot
.63289 .53629 Mdot
.38961 .39916 Mdot
.37743 .48442 Mdot
.64542 .49883 Mdot
.32299 .4634 Mdot
.672 .48598 Mdot
.33839 .43915 Mdot
.59572 .39022 Mdot
.67774 .47336 Mdot
.41545 .3009 Mdot
.49907 .54386 Mdot
.75779 .57579 Mdot
.61646 .36779 Mdot
.59521 .37737 Mdot
.47581 .35767 Mdot
.38997 .63075 Mdot
.37385 .7176 Mdot
.37271 .4315 Mdot
.62962 .47775 Mdot
.56529 .61138 Mdot
.38955 .44871 Mdot
.33218 .41734 Mdot
.42966 .46965 Mdot
.40345 .68027 Mdot
.70005 .4871 Mdot
.59986 .35969 Mdot
.68549 .46491 Mdot
.73872 .35277 Mdot
.65096 .51024 Mdot
.4457 .41629 Mdot
.32677 .41977 Mdot
.27452 .42973 Mdot
.22104 .63188 Mdot
.38742 .77647 Mdot
.40826 .66617 Mdot
.76436 .58776 Mdot
.58635 .32427 Mdot
.38568 .56748 Mdot
.38372 .64269 Mdot
.66003 .50084 Mdot
.36831 .42434 Mdot
.3189 .40656 Mdot
.5027 .60247 Mdot
.44218 .60309 Mdot
.46966 .34 Mdot
.66899 .51404 Mdot
.74988 .58564 Mdot
.52276 .78552 Mdot
.39012 .57391 Mdot
.54786 .43927 Mdot
.36351 .46681 Mdot
.61679 .37326 Mdot
.37823 .66733 Mdot
.71572 .41531 Mdot
.57587 .62915 Mdot
.54681 .4857 Mdot
.36768 .44509 Mdot
.59775 .71866 Mdot
.40738 .64001 Mdot
.60319 .37171 Mdot
.57923 .63059 Mdot
.61708 .32442 Mdot
.74851 .59917 Mdot
.74762 .32926 Mdot
.42136 .43251 Mdot
.38632 .48196 Mdot
.53806 .6603 Mdot
.41959 .66379 Mdot
.55867 .37528 Mdot
.56523 .24021 Mdot
.69127 .47649 Mdot
.60682 .40563 Mdot
.36971 .66813 Mdot
.28649 .49233 Mdot
.68135 .46172 Mdot
.60145 .62141 Mdot
.5345 .40362 Mdot
.54613 .60934 Mdot
.35436 .42381 Mdot
.39227 .64554 Mdot
.57766 .60472 Mdot
.72984 .3699 Mdot
.42983 .1688 Mdot
.26385 .44185 Mdot
.43111 .42821 Mdot
.28772 .26376 Mdot
.60028 .21627 Mdot
.49227 .40139 Mdot
.53329 .63463 Mdot
.37766 .46775 Mdot
.34109 .46248 Mdot
.42262 .41641 Mdot
.56667 .60282 Mdot
.68122 .30736 Mdot
.66203 .49556 Mdot
.40522 .45317 Mdot
.5876 .3707 Mdot
.66605 .47874 Mdot
.65867 .53173 Mdot
.6336 .46911 Mdot
.38007 .62674 Mdot
.35618 .41085 Mdot
.52451 .76585 Mdot
.47882 .13911 Mdot
.56248 .61842 Mdot
.75749 .57594 Mdot
.39282 .48378 Mdot
.34583 .75262 Mdot
.38373 .65325 Mdot
.69181 .47913 Mdot
.36769 .46061 Mdot
.70943 .33339 Mdot
.78511 .59915 Mdot
.6379 .48335 Mdot
.39555 .63012 Mdot
.49659 .41622 Mdot
.37253 .44108 Mdot
.41612 .41924 Mdot
.42216 .65542 Mdot
.76554 .35635 Mdot
.54988 .79017 Mdot
.373 .4776 Mdot
.55865 .63382 Mdot
.71956 .76994 Mdot
.42223 .47749 Mdot
.44482 .68674 Mdot
.73847 .57534 Mdot
.48633 .74673 Mdot
.24119 .52187 Mdot
.43815 .39312 Mdot
.31398 .25962 Mdot
.51411 .39116 Mdot
.28357 .25713 Mdot
.57853 .30626 Mdot
.67721 .56977 Mdot
.32983 .20382 Mdot
.52385 .62424 Mdot
.31486 .36553 Mdot
.30451 .32084 Mdot
.59252 .75268 Mdot
.51796 .42262 Mdot
.8194 .46602 Mdot
.75132 .39628 Mdot
.73104 .6038 Mdot
.6409 .46013 Mdot
.47032 .23946 Mdot
.34916 .46022 Mdot
.60935 .21594 Mdot
.24498 .47712 Mdot
.59928 .81988 Mdot
.30386 .24314 Mdot
.55996 .30115 Mdot
.23641 .35375 Mdot
.44454 .18122 Mdot
.2774 .36386 Mdot
.48458 .64114 Mdot
.82824 .56577 Mdot
.47562 .79235 Mdot
.60142 .27191 Mdot
.43147 .51421 Mdot
.65647 .54517 Mdot
.6542 .25918 Mdot
.33231 .58425 Mdot
.63585 .81589 Mdot
.66241 .44583 Mdot
.39532 .6115 Mdot
.35247 .27819 Mdot
.41941 .5939 Mdot
.59335 .67645 Mdot
.31155 .2608 Mdot
.51399 .1622 Mdot
.25339 .45623 Mdot
.8195 .38458 Mdot
.23855 .61849 Mdot
.3278 .78009 Mdot
.52114 .54338 Mdot
.41391 .60937 Mdot
.8018 .55637 Mdot
.45613 .79421 Mdot
.51556 .68059 Mdot
.38606 .56151 Mdot
.58407 .31506 Mdot
.45244 .31302 Mdot
.40482 .63374 Mdot
.23424 .51244 Mdot
.73966 .5965 Mdot
.47537 .66917 Mdot
.68465 .5361 Mdot
.39418 .2017 Mdot
.71414 .56329 Mdot
.47453 .76187 Mdot
.64537 .70036 Mdot
.15663 .43409 Mdot
.54398 .28921 Mdot
.47763 .1906 Mdot
.50197 .61574 Mdot
.5128 .41697 Mdot
.60572 .784 Mdot
.51161 .31931 Mdot
.44283 .794 Mdot
.16151 .49887 Mdot
.65361 .23479 Mdot
.18025 .41981 Mdot
.44418 .61931 Mdot
.43116 .46375 Mdot
.41832 .21458 Mdot
.30672 .67682 Mdot
.59205 .31649 Mdot
.20092 .37403 Mdot
.62396 .36513 Mdot
.42852 .60282 Mdot
.60626 .74346 Mdot
.28742 .5037 Mdot
.60836 .42172 Mdot
.61645 .39032 Mdot
.44561 .42965 Mdot
.32603 .82182 Mdot
.27122 .28022 Mdot
.50272 .72841 Mdot
.54469 .17843 Mdot
.58677 .57005 Mdot
.56202 .39462 Mdot
.56612 .6056 Mdot
.39256 .17703 Mdot
.39108 .63751 Mdot
.42051 .14127 Mdot
.42532 .16335 Mdot
.71116 .73574 Mdot
.48383 .91018 Mdot
.68264 .63185 Mdot
.2896 .37577 Mdot
.41579 .33488 Mdot
.42197 .32052 Mdot
.6171 .79114 Mdot
.72952 .71738 Mdot
.60553 .57268 Mdot
.73823 .30493 Mdot
.34727 .20143 Mdot
.51921 .25962 Mdot
.64603 .27444 Mdot
.60191 .76179 Mdot
.51171 .5297 Mdot
.41992 .70374 Mdot
.4766 .54952 Mdot
.48053 .63822 Mdot
.19648 .39106 Mdot
.32552 .69686 Mdot
.63158 .83929 Mdot
.56638 .37674 Mdot
.76151 .66277 Mdot
.55201 .19449 Mdot
.41839 .29197 Mdot
.35307 .54024 Mdot
.55299 .7614 Mdot
.44692 .42888 Mdot
.53229 .78054 Mdot
.47321 .48964 Mdot
.65102 .40557 Mdot
.51794 .79081 Mdot
.62227 .66799 Mdot
.56717 .24815 Mdot
.33763 .26376 Mdot
.41277 .76688 Mdot
.39428 .62026 Mdot
.5097 .34866 Mdot
.54537 .27835 Mdot
.54803 .18342 Mdot
.68286 .72601 Mdot
.7234 .26497 Mdot
.69897 .72412 Mdot
.41509 .49886 Mdot
.37536 .35641 Mdot
.41985 .52016 Mdot
.52436 .31052 Mdot
.41077 .49463 Mdot
.60436 .71138 Mdot
.57366 .18935 Mdot
.32128 .7101 Mdot
.65016 .35524 Mdot
.19263 .59694 Mdot
.6988 .25394 Mdot
.4207 .21898 Mdot
.70738 .68026 Mdot
.37253 .34403 Mdot
.2213 .70201 Mdot
.66011 .47288 Mdot
.52954 .26921 Mdot
.59039 .59218 Mdot
.71482 .40393 Mdot
.26494 .3513 Mdot
.69563 .74922 Mdot
.57981 .19037 Mdot
.56043 .77032 Mdot
.74793 .4779 Mdot
.57791 .46607 Mdot
.60657 .43544 Mdot
.18789 .57747 Mdot
.32347 .412 Mdot
.36475 .53649 Mdot
.58593 .37647 Mdot
.31008 .65274 Mdot
.45086 .22023 Mdot
.79252 .48068 Mdot
.3447 .36866 Mdot
.77169 .54026 Mdot
.74621 .5842 Mdot
.54881 .49257 Mdot
.22665 .27887 Mdot
.45231 .45743 Mdot
.69034 .65075 Mdot
.66735 .2417 Mdot
.53693 .38223 Mdot
.51889 .19689 Mdot
.56729 .73452 Mdot
.17594 .44388 Mdot
.4633 .152 Mdot
.77168 .44797 Mdot
.25881 .27588 Mdot
.68379 .21571 Mdot
.17149 .47856 Mdot
.19577 .56389 Mdot
.53306 .6041 Mdot
.42953 .10904 Mdot
.68055 .4973 Mdot
.24029 .67388 Mdot
.31008 .68776 Mdot
.69364 .33525 Mdot
.3957 .70084 Mdot
.34603 .50337 Mdot
.71941 .57833 Mdot
.35498 .64683 Mdot
.4411 .40497 Mdot
.17346 .39123 Mdot
.1561 .5435 Mdot
.1791 .39118 Mdot
.72095 .28185 Mdot
.26562 .26986 Mdot
.33118 .30573 Mdot
.32165 .54135 Mdot
.41959 .2451 Mdot
.34118 .45039 Mdot
.48691 .26782 Mdot
.68356 .64115 Mdot
.75402 .46037 Mdot
.49703 .67843 Mdot
.37262 .68582 Mdot
.20335 .40826 Mdot
.1677 .33639 Mdot
.23789 .59649 Mdot
.27776 .56258 Mdot
.49803 .58677 Mdot
.52352 .29475 Mdot
.4428 .53422 Mdot
.75934 .52479 Mdot
.55218 .18971 Mdot
.30528 .31845 Mdot
.55376 .26181 Mdot
.80522 .49131 Mdot
.60073 .49492 Mdot
.75567 .6566 Mdot
.39534 .1943 Mdot
.3725 .28949 Mdot
.71889 .71962 Mdot
.33826 .34576 Mdot
.64091 .79316 Mdot
.789 .42616 Mdot
.71923 .45283 Mdot
.56763 .2753 Mdot
.70196 .50031 Mdot
.50997 .26042 Mdot
.58215 .54719 Mdot
.36604 .2632 Mdot
.51074 .38803 Mdot
.50966 .25569 Mdot
.60152 .4983 Mdot
.2105 .34239 Mdot
.73732 .25602 Mdot
.173 .59611 Mdot
.79174 .35168 Mdot
.47825 .48134 Mdot
.39419 .49539 Mdot
.61594 .20245 Mdot
.19516 .34914 Mdot
.48758 .14488 Mdot
.61036 .71705 Mdot
.72109 .36019 Mdot
.5185 .63251 Mdot
.18442 .61014 Mdot
.79916 .4163 Mdot
.49071 .16768 Mdot
.3904 .77543 Mdot
.59022 .65002 Mdot
.56855 .77816 Mdot
.20471 .62939 Mdot
.25422 .37915 Mdot
.23696 .54536 Mdot
.40485 .51731 Mdot
.2421 .44882 Mdot
.41453 .61423 Mdot
.63936 .71293 Mdot
.51709 .31218 Mdot
.66467 .47069 Mdot
.38369 .2978 Mdot
.35686 .53411 Mdot
.44727 .43733 Mdot
.72954 .48211 Mdot
.38415 .71087 Mdot
.24473 .66311 Mdot
.61225 .58508 Mdot
.30702 .21531 Mdot
.67931 .66864 Mdot
.42221 .5343 Mdot
.52287 .34784 Mdot
.71435 .42583 Mdot
.5412 .77623 Mdot
.52786 .63207 Mdot
.33389 .22275 Mdot
.46615 .54206 Mdot
.51326 .34817 Mdot
.23916 .45674 Mdot
.53904 .22938 Mdot
.32708 .42625 Mdot
.53206 .7242 Mdot
.34977 .57749 Mdot
.55231 .48232 Mdot
.40157 .59763 Mdot
.38141 .71269 Mdot
.86214 .41648 Mdot
.63042 .56661 Mdot
.71353 .70133 Mdot
.3427 .22089 Mdot
.55083 .60852 Mdot
.38384 .69083 Mdot
.4912 .25523 Mdot
.58239 .24328 Mdot
.33925 .6042 Mdot
.63691 .51178 Mdot
.62296 .30368 Mdot
.79279 .45767 Mdot
.29 .26441 Mdot
.25002 .32227 Mdot
.58677 .83154 Mdot
.41064 .69015 Mdot
.5179 .22022 Mdot
.58631 .25108 Mdot
.39746 .68606 Mdot
.45528 .62164 Mdot
.45932 .69237 Mdot
.25569 .26561 Mdot
.52312 .7748 Mdot
.77919 .34435 Mdot
.53424 .39821 Mdot
.69682 .3181 Mdot
.69941 .40973 Mdot
.59832 .27954 Mdot
.34897 .2193 Mdot
.22891 .51313 Mdot
.24852 .37289 Mdot
.44848 .50317 Mdot
.3064 .71736 Mdot
.18749 .61986 Mdot
.52551 .53419 Mdot
.27909 .48418 Mdot
.6097 .67865 Mdot
.42892 .4307 Mdot
.1569 .43202 Mdot
.60291 .22566 Mdot
.49798 .80574 Mdot
.6149 .60658 Mdot
.40189 .42157 Mdot
.39274 .50474 Mdot
.47179 .37523 Mdot
.5006 .7385 Mdot
.16702 .55588 Mdot
.60835 .27497 Mdot
.48855 .44037 Mdot
.23941 .47312 Mdot
.69059 .65317 Mdot
.39259 .20623 Mdot
.58012 .21097 Mdot
.57562 .53074 Mdot
.68157 .6473 Mdot
.56394 .43393 Mdot
.77199 .326 Mdot
.71359 .54708 Mdot
.33424 .29915 Mdot
.38783 .7446 Mdot
.52726 .74685 Mdot
.72293 .42804 Mdot
.3872 .48674 Mdot
.61085 .73723 Mdot
.43368 .18673 Mdot
.5914 .85171 Mdot
.6202 .77876 Mdot
.16614 .39167 Mdot
.27976 .46252 Mdot
.52733 .75233 Mdot
.23692 .37562 Mdot
.56536 .86951 Mdot
.72116 .54042 Mdot
.21943 .36788 Mdot
.57321 .45239 Mdot
.31923 .23282 Mdot
.57392 .58962 Mdot
.4564 .77623 Mdot
.19758 .60626 Mdot
.26314 .26029 Mdot
.45444 .20328 Mdot
.35889 .22051 Mdot
.35506 .34074 Mdot
.23344 .29023 Mdot
.36369 .74662 Mdot
.73871 .61 Mdot
.65405 .43527 Mdot
.61447 .70348 Mdot
.20964 .46075 Mdot
.47345 .62107 Mdot
.54074 .26702 Mdot
.75989 .63402 Mdot
.36757 .57129 Mdot
.24095 .39943 Mdot
.43926 .27815 Mdot
.55071 .73643 Mdot
.52347 .353 Mdot
.46817 .16693 Mdot
.77071 .61753 Mdot
.6762 .39045 Mdot
.6902 .69979 Mdot
.74682 .32591 Mdot
.49656 .73614 Mdot
.6512 .57715 Mdot
.47388 .18985 Mdot
.78132 .39392 Mdot
.55903 .29616 Mdot
.87666 .40183 Mdot
.66829 .27294 Mdot
.47331 .66569 Mdot
.19511 .4099 Mdot
.56549 .19828 Mdot
.35438 .73312 Mdot
.58798 .8172 Mdot
.30033 .71233 Mdot
.49425 .28719 Mdot
.35356 .46055 Mdot
.21194 .30701 Mdot
.453 .30508 Mdot
.19598 .38483 Mdot
.65695 .22107 Mdot
.23832 .44033 Mdot
.445 .46049 Mdot
.62224 .48247 Mdot
.51661 .56383 Mdot
.4359 .27224 Mdot
.25581 .34346 Mdot
.28503 .70011 Mdot
.64019 .41227 Mdot
.7246 .5541 Mdot
.64051 .51136 Mdot
.46841 .40298 Mdot
.6723 .64721 Mdot
.52458 .73789 Mdot
.59189 .39811 Mdot
.61841 .54453 Mdot
.52997 .28439 Mdot
.24072 .5154 Mdot
.25666 .37628 Mdot
.67232 .76666 Mdot
.59998 .67698 Mdot
.64969 .44608 Mdot
.30017 .29007 Mdot
.67972 .27334 Mdot
.58621 .71237 Mdot
.17972 .4847 Mdot
.55899 .76125 Mdot
.45294 .24553 Mdot
.41066 .23446 Mdot
.63465 .78497 Mdot
.84208 .52866 Mdot
.19467 .4679 Mdot
.30776 .72048 Mdot
.60133 .40771 Mdot
.29109 .46039 Mdot
.31425 .2174 Mdot
.58349 .27418 Mdot
.38173 .24857 Mdot
.50245 .54746 Mdot
.31904 .62077 Mdot
.23028 .4339 Mdot
.40068 .30677 Mdot
.55346 .45199 Mdot
.27611 .75921 Mdot
.37216 .69484 Mdot
.15248 .44141 Mdot
.56594 .6395 Mdot
.46471 .8243 Mdot
.61088 .50024 Mdot
.56216 .53911 Mdot
.53908 .43216 Mdot
.52538 .72165 Mdot
.44717 .71744 Mdot
.72922 .29165 Mdot
.6691 .77882 Mdot
.64648 .50706 Mdot
.54467 .3374 Mdot
.78362 .36532 Mdot
.30053 .28068 Mdot
.39621 .38689 Mdot
.69739 .28728 Mdot
.52239 .53207 Mdot
.75196 .45941 Mdot
.61916 .20679 Mdot
.58002 .6927 Mdot
.35006 .37663 Mdot
.52132 .29825 Mdot
.21798 .37449 Mdot
.44172 .16063 Mdot
.55568 .81109 Mdot
.47383 .48837 Mdot
.52317 .61681 Mdot
.32977 .32196 Mdot
.29045 .27391 Mdot
.5803 .41263 Mdot
.48039 .76844 Mdot
.54875 .28237 Mdot
.12857 .52665 Mdot
.15779 .52577 Mdot
.1688 .55906 Mdot
.5376 .37279 Mdot
.37725 .6089 Mdot
.33776 .73767 Mdot
.38849 .24609 Mdot
.56297 .70449 Mdot
.66098 .25663 Mdot
.53239 .27279 Mdot
.51636 .86106 Mdot
.35631 .54677 Mdot
.73818 .34979 Mdot
.2235 .44641 Mdot
.29673 .66318 Mdot
.55226 .59514 Mdot
.47981 .28828 Mdot
.45792 .53282 Mdot
.542 .65693 Mdot
.54486 .73656 Mdot
.4644 .74935 Mdot
.37765 .2505 Mdot
.34104 .57625 Mdot
.48339 .45933 Mdot
.33376 .26032 Mdot
.3585 .63246 Mdot
.71089 .4121 Mdot
.68353 .4021 Mdot
.51159 .45796 Mdot
.6882 .48116 Mdot
.44454 .39875 Mdot
.56363 .49448 Mdot
.56601 .45314 Mdot
.23735 .6902 Mdot
.61953 .37306 Mdot
.36104 .6618 Mdot
.45817 .81094 Mdot
.39214 .68536 Mdot
.18468 .35082 Mdot
.75473 .52908 Mdot
.24207 .46211 Mdot
.77054 .43328 Mdot
.79939 .53037 Mdot
.35404 .81444 Mdot
.18215 .54172 Mdot
.48194 .56404 Mdot
.41733 .58219 Mdot
.43773 .66643 Mdot
.62427 .41965 Mdot
.72544 .57922 Mdot
.2466 .55007 Mdot
.6941 .63522 Mdot
.43631 .24207 Mdot
.42719 .61156 Mdot
.71271 .32242 Mdot
.43948 .53157 Mdot
.26989 .24754 Mdot
.64178 .45528 Mdot
.18723 .66015 Mdot
.32252 .45818 Mdot
.27938 .34946 Mdot
.60617 .19581 Mdot
.55881 .79813 Mdot
.7357 .465 Mdot
.83402 .46933 Mdot
.42553 .40905 Mdot
.48221 .45333 Mdot
.40531 .63169 Mdot
.48894 .22888 Mdot
.60698 .3496 Mdot
.48605 .34311 Mdot
.57448 .65848 Mdot
.74311 .69688 Mdot
.66959 .65895 Mdot
.36477 .63293 Mdot
.44111 .54978 Mdot
.45256 .21106 Mdot
.43809 .7565 Mdot
.52222 .53023 Mdot
.28946 .30126 Mdot
.33752 .60056 Mdot
.43225 .6155 Mdot
.17585 .49999 Mdot
.58523 .25536 Mdot
.40504 .16573 Mdot
.32371 .49325 Mdot
.52418 .55154 Mdot
.42464 .7615 Mdot
.54594 .72762 Mdot
.24406 .53182 Mdot
.54747 .18848 Mdot
.51106 .33526 Mdot
.45243 .78815 Mdot
.50615 .25604 Mdot
.34749 .49732 Mdot
.69782 .55805 Mdot
.63829 .68938 Mdot
.48238 .85533 Mdot
.20964 .58398 Mdot
.58645 .78871 Mdot
.45924 .61326 Mdot
.68943 .64941 Mdot
.36175 .67575 Mdot
.67443 .35118 Mdot
.33294 .59459 Mdot
.73613 .52684 Mdot
.35713 .18753 Mdot
.55642 .189 Mdot
.49147 .61856 Mdot
.68684 .52715 Mdot
.51143 .40191 Mdot
.41567 .53344 Mdot
.53469 .48403 Mdot
.4344 .42558 Mdot
.46478 .38509 Mdot
.54467 .80749 Mdot
.55163 .7128 Mdot
.35783 .51059 Mdot
.29644 .2399 Mdot
.41781 .15939 Mdot
.22617 .30731 Mdot
.61233 .40862 Mdot
.36763 .64258 Mdot
.17024 .45816 Mdot
.26612 .52449 Mdot
.46692 .16518 Mdot
.19945 .48887 Mdot
.85291 .39453 Mdot
.25323 .35577 Mdot
.61952 .66675 Mdot
.71867 .72937 Mdot
.47213 .70197 Mdot
.62654 .21573 Mdot
.74577 .61351 Mdot
.64572 .34779 Mdot
.63557 .21917 Mdot
.31988 .81458 Mdot
.20139 .57908 Mdot
.46962 .75732 Mdot
.28372 .37249 Mdot
.50312 .46058 Mdot
.69791 .62122 Mdot
.35205 .46828 Mdot
.70823 .46702 Mdot
.74111 .46403 Mdot
.53512 .27936 Mdot
.27808 .43564 Mdot
.70179 .62727 Mdot
.43493 .26893 Mdot
.48194 .23727 Mdot
.61046 .27016 Mdot
.26259 .34295 Mdot
.25 .54555 Mdot
.35823 .37441 Mdot
.37721 .60407 Mdot
.60193 .31927 Mdot
.66438 .40727 Mdot
.3438 .4216 Mdot
.73794 .47714 Mdot
.42844 .73817 Mdot
.16746 .39746 Mdot
.66108 .34687 Mdot
.58792 .23569 Mdot
.36181 .69547 Mdot
.5122 .73362 Mdot
.39042 .22163 Mdot
.59667 .74922 Mdot
.71424 .63511 Mdot
.3244 .69643 Mdot
.28061 .26867 Mdot
.54583 .76356 Mdot
.54563 .24926 Mdot
.29172 .74606 Mdot
.56414 .65617 Mdot
.24826 .66133 Mdot
.31531 .31181 Mdot
.57743 .75039 Mdot
.44424 .62159 Mdot
.63273 .64391 Mdot
.68503 .56745 Mdot
.56797 .74548 Mdot
.67121 .24282 Mdot
.49105 .21964 Mdot
.22005 .46397 Mdot
.25694 .30875 Mdot
.68184 .44281 Mdot
.55011 .26165 Mdot
.63158 .6124 Mdot
.69773 .60114 Mdot
.42468 .76956 Mdot
.30172 .22535 Mdot
.53832 .47225 Mdot
.44115 .30795 Mdot
.4215 .42586 Mdot
.29822 .55142 Mdot
.53733 .71505 Mdot
.6041 .51564 Mdot
.69693 .71056 Mdot
.40587 .61842 Mdot
.66166 .68717 Mdot
.78068 .61066 Mdot
.48355 .29897 Mdot
.41214 .56595 Mdot
.36752 .72625 Mdot
.60989 .30651 Mdot
.7726 .60606 Mdot
.3658 .38248 Mdot
.44517 .31895 Mdot
.60215 .43638 Mdot
.22472 .62865 Mdot
.19852 .58041 Mdot
.29544 .29207 Mdot
.60872 .24021 Mdot
.57988 .71066 Mdot
.19763 .48787 Mdot
.4539 .7093 Mdot
.31982 .52977 Mdot
.63171 .74189 Mdot
.42749 .47546 Mdot
.67609 .34911 Mdot
.37045 .67689 Mdot
.28856 .28675 Mdot
.30499 .50128 Mdot
.41619 .29945 Mdot
.5493 .51595 Mdot
.41032 .21176 Mdot
.50416 .52217 Mdot
.60918 .19916 Mdot
.4749 .69933 Mdot
.51567 .31395 Mdot
.60953 .61503 Mdot
.5758 .44863 Mdot
.63166 .77757 Mdot
.3851 .1874 Mdot
.68066 .76287 Mdot
.42003 .33776 Mdot
.58195 .78307 Mdot
.31547 .72746 Mdot
.64563 .21846 Mdot
.50558 .30505 Mdot
.53419 .48641 Mdot
.43646 .53515 Mdot
.50763 .60172 Mdot
.76545 .57519 Mdot
.68936 .35758 Mdot
.26039 .54019 Mdot
.64476 .29437 Mdot
.74178 .51363 Mdot
.39896 .38424 Mdot
.35042 .75913 Mdot
.26662 .29333 Mdot
.37033 .5808 Mdot
.54834 .53789 Mdot
.73891 .42563 Mdot
.48035 .30686 Mdot
.87446 .57575 Mdot
.15616 .43107 Mdot
.42106 .42744 Mdot
.53142 .40986 Mdot
.48519 .33537 Mdot
.68606 .50537 Mdot
.24973 .56068 Mdot
.29355 .29105 Mdot
.53695 .63627 Mdot
.71842 .36806 Mdot
.62012 .68999 Mdot
.52232 .71625 Mdot
.38715 .30482 Mdot
.55514 .6691 Mdot
.176 .36951 Mdot
.70115 .28271 Mdot
.55233 .71978 Mdot
.8795 .5008 Mdot
.62095 .71247 Mdot
.35147 .68525 Mdot
.44826 .19985 Mdot
.2125 .33814 Mdot
.53638 .37858 Mdot
.71582 .39979 Mdot
.19972 .59154 Mdot
.51218 .32181 Mdot
.50754 .24126 Mdot
.68947 .69911 Mdot
.66708 .69131 Mdot
.71705 .59473 Mdot
.8 .5279 Mdot
.26188 .71081 Mdot
.22976 .489 Mdot
.23912 .3317 Mdot
.742 .535 Mdot
.52974 .86059 Mdot
.39192 .17743 Mdot
.47437 .2706 Mdot
.70818 .6436 Mdot
.47297 .19485 Mdot
.47496 .35002 Mdot
.33462 .70647 Mdot
.75276 .52343 Mdot
.32964 .63184 Mdot
.78887 .52998 Mdot
.65162 .73957 Mdot
.50959 .2584 Mdot
.30377 .68356 Mdot
.54143 .46514 Mdot
.27948 .32321 Mdot
.78098 .64701 Mdot
.52822 .33351 Mdot
.72941 .38023 Mdot
.42491 .33001 Mdot
.31521 .26713 Mdot
.46041 .18568 Mdot
.52948 .47522 Mdot
.31923 .81075 Mdot
.2018 .38554 Mdot
.60657 .75284 Mdot
.39158 .49919 Mdot
.35513 .1837 Mdot
.51276 .47785 Mdot
.19375 .5022 Mdot
.64928 .24006 Mdot
.66498 .39037 Mdot
.41282 .75532 Mdot
.43101 .46627 Mdot
.18317 .52535 Mdot
.272 .47261 Mdot
.29453 .66547 Mdot
.7361 .4546 Mdot
.52145 .34604 Mdot
.77117 .65757 Mdot
.38789 .3174 Mdot
.39978 .53004 Mdot
.36919 .66962 Mdot
.18463 .37043 Mdot
.31504 .34652 Mdot
.43971 .38911 Mdot
.32988 .35578 Mdot
.67641 .76982 Mdot
.85512 .48412 Mdot
.40376 .52579 Mdot
.53529 .77349 Mdot
.54189 .26852 Mdot
.41725 .23956 Mdot
.18909 .5582 Mdot
.50945 .91897 Mdot
.59559 .18985 Mdot
.39938 .7043 Mdot
.25144 .65584 Mdot
.53444 .35652 Mdot
.23076 .30636 Mdot
.80436 .48664 Mdot
.70509 .41969 Mdot
.67404 .78807 Mdot
.50132 .36472 Mdot
.33237 .42847 Mdot
.70761 .26697 Mdot
.39357 .18147 Mdot
.77823 .66055 Mdot
.31832 .21617 Mdot
.43918 .48024 Mdot
.3622 .49647 Mdot
.72716 .79191 Mdot
.30849 .25039 Mdot
.44981 .44361 Mdot
.64529 .79438 Mdot
.43508 .69054 Mdot
.34121 .44185 Mdot
.67654 .59277 Mdot
.57485 .2781 Mdot
.49244 .24026 Mdot
.26188 .26181 Mdot
.37979 .60952 Mdot
.73919 .47788 Mdot
.59465 .60184 Mdot
.54258 .4362 Mdot
.32178 .40104 Mdot
.57625 .60275 Mdot
.4633 .24533 Mdot
.51596 .46423 Mdot
.61393 .62694 Mdot
.5936 .28568 Mdot
.75275 .28242 Mdot
.27113 .44394 Mdot
.49805 .60231 Mdot
.39343 .34344 Mdot
.36438 .58254 Mdot
.43676 .27049 Mdot
.41416 .25834 Mdot
.64884 .22975 Mdot
.68463 .19743 Mdot
.61067 .46841 Mdot
.32049 .48006 Mdot
.36087 .61406 Mdot
.25171 .5333 Mdot
.25145 .40706 Mdot
.62229 .62244 Mdot
.7624 .59906 Mdot
.43398 .47945 Mdot
.39655 .53006 Mdot
.57805 .65663 Mdot
.1307 .4778 Mdot
.36184 .48185 Mdot
.22 .52547 Mdot
.44534 .17469 Mdot
.71419 .415 Mdot
.27246 .4246 Mdot
.4143 .39859 Mdot
.35965 .74074 Mdot
.50848 .48009 Mdot
.50197 .42321 Mdot
.68985 .40428 Mdot
.2424 .30265 Mdot
.3031 .49862 Mdot
.22044 .48185 Mdot
.39719 .44696 Mdot
.60723 .3907 Mdot
.45677 .75705 Mdot
.17522 .54891 Mdot
.3882 .54886 Mdot
.46161 .16096 Mdot
.66353 .38506 Mdot
.62427 .29139 Mdot
.27729 .38989 Mdot
.19136 .38822 Mdot
.6173 .77596 Mdot
.24717 .42562 Mdot
.51551 .80702 Mdot
.6495 .59896 Mdot
.4426 .27811 Mdot
.6281 .49246 Mdot
.34975 .5055 Mdot
.44911 .66918 Mdot
.20549 .30175 Mdot
.18113 .5613 Mdot
.56947 .57764 Mdot
.63662 .41384 Mdot
.29434 .51819 Mdot
.53932 .44028 Mdot
.88081 .46103 Mdot
.81794 .4603 Mdot
.17345 .37396 Mdot
.47816 .22383 Mdot
.34993 .63269 Mdot
.55838 .73745 Mdot
.36846 .36112 Mdot
.64284 .48798 Mdot
.23451 .30559 Mdot
.35015 .5178 Mdot
.65301 .73114 Mdot
.33868 .44886 Mdot
.47417 .80089 Mdot
.48241 .49703 Mdot
.6934 .52247 Mdot
.7085 .49502 Mdot
.5954 .80982 Mdot
.42685 .19374 Mdot
.5054 .48615 Mdot
.85533 .42444 Mdot
.24432 .35098 Mdot
.33633 .22124 Mdot
.63969 .51281 Mdot
.50602 .83584 Mdot
.44182 .59235 Mdot
.47035 .51013 Mdot
.59924 .58052 Mdot
.38225 .33168 Mdot
.57604 .7465 Mdot
.43465 .23492 Mdot
.4557 .72956 Mdot
.49331 .62227 Mdot
.80299 .27074 Mdot
.47996 .26228 Mdot
.38849 .55941 Mdot
.61793 .73109 Mdot
.32208 .22151 Mdot
.63853 .35827 Mdot
.7363 .27902 Mdot
.63335 .5438 Mdot
.31618 .42417 Mdot
.34465 .57282 Mdot
.2821 .35153 Mdot
.62787 .67955 Mdot
.31437 .78702 Mdot
.66722 .26515 Mdot
.62961 .30022 Mdot
.61397 .54446 Mdot
.39736 .68751 Mdot
.39755 .70068 Mdot
.78499 .46567 Mdot
.79625 .33179 Mdot
.49356 .46218 Mdot
.29313 .26944 Mdot
.39335 .83143 Mdot
.5217 .23048 Mdot
.23799 .29042 Mdot
.49505 .64832 Mdot
.45523 .61823 Mdot
.43617 .26548 Mdot
.5672 .38241 Mdot
.70373 .48381 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2]ooooo`;o0000V_oo
ool001cooooo00?o0000ooooooooool0[Oooool2o`0009[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo0_l0002Sooooo`;o00001?ooool2o`0000_ooooo0_l0002Booooo`00
7?ooool00ol0003oooooooooo`2Rooooo`;o00001?ooool2o`0000_ooooo0_l0002Booooo`007?oo
ool00ol0003oooooooooo`2Mooooo`;o0000Z_ooool001cooooo00?o0000ooooooooool0R?ooool3
o`0000gooooo0_l00002ooooo`?o0000Z_ooool001cooooo00?o0000ooooooooool0R?ooool3o`00
00Sooooo0_l00003ooooo`;o00000_ooool2o`000:_ooooo000Looooo`03o`000?oooooooooo09?o
oooo0_l0002dooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0<?ooooo0_l00024ooooo`007?ooool00ol0003oooooooooo`33ooooo`;o0000Q?ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`1]ooooo`;o00005_ooool2o`0000Sooooo0_l00007
ooooo`;o0000[oooool001cooooo00?o0000ooooooooool0KOooool2o`0001Kooooo0_l00008oooo
o`;o00001oooool2o`0003Cooooo0_l0001iooooo`007?ooool00ol0003oooooooooo`2Kooooo`;o
0000<Oooool2o`0007Wooooo000Looooo`03o`000?oooooooooo09_ooooo1_l0002Xooooo`007?oo
ool2o`0008oooooo0_l00003ooooo`;o00002?ooool4o`000:Sooooo000Looooo`03o`000?oooooo
oooo08kooooo0_l00003ooooo`;o00004?ooool2o`000:;ooooo000Looooo`03o`000?oooooooooo
08Cooooo0_l0000Iooooo`;o00001?ooool2o`000:;ooooo000Looooo`03o`000?oooooooooo08Co
oooo0_l00006ooooo`;o00001?ooool2o`0000?ooooo0_l00006ooooo`Ko0000Y?ooool001cooooo
00?o0000ooooooooool0P?ooool2o`0000Cooooo0_l00004ooooo`;o00001?ooool7o`0000Sooooo
1?l00002ooooo`?o0000Woooool001cooooo00?o0000ooooooooool0P?ooool2o`0000Cooooo1?l0
000:ooooo`Co00000_ooool4o`0000Oooooo1Ol0002Oooooo`007?ooool00ol0003oooooooooo`28
ooooo`;o00002_ooool2o`0000Cooooo1?l00007ooooo`;o000000?oooooo`000?l00000Woooool0
01cooooo00?o0000ooooooooool0SOooool2o`0000Gooooo1?l0000>ooooo`Co0000Woooool001co
oooo00?o0000ooooooooool0O?ooool2o`0000oooooo0_l00005ooooo`Co00002_ooool2o`0000;o
oooo0_l00005ooooo`;o0000;oooool2o`0006Wooooo000Looooo`03o`000?oooooooooo07cooooo
0_l0000;ooooo`;o00000_ooool4o`0000;ooooo0_l000000ooooooo0000o`00000:ooooo`;o0000
0oooool2o`0000?ooooo0ol0000=ooooo`;o00008?ooool2o`0006Wooooo000Looooo`03o`000?oo
oooooooo073ooooo0_l0000:ooooo`;o00001oooool2o`0000;ooooo0_l00002ooooo`Co00000_oo
ool2o`0001;ooooo0_l00003ooooo`Co00003?ooool2o`0008_ooooo000Looooo`03o`000?oooooo
oooo073ooooo0_l00006ooooo`?o00000oooool2o`0000Gooooo0_l00002ooooo`;o00001oooool2
o`0000Wooooo0_l00008ooooo`;o00001Oooool2o`0000?ooooo0_l0002Dooooo`007?ooool00ol0
003oooooooooo`1`ooooo`;o00001_ooool3o`0000;ooooo0ol00002ooooo`;o00001Oooool2o`00
00Oooooo0_l00002ooooo`?o00001?ooool2o`0000kooooo2?l00002ooooo`Co00000oooool2o`00
08Wooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool0
0ol0003oooooooooo`1dooooo`;o00001_ooool4o`0000;ooooo0_l00003ooooo`;o00003Oooool3
o`0000gooooo0_l00002ooooo`;o000000?oooooo`000?l000001?l00004ooooo`Co00000oooool2
o`0008Wooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1dooooo`;o00001_ooool3o`0000Sooooo
1?l0000;ooooo`;o00002_ooool2o`000004ooooool0003o0000o`0000;ooooo0_l00004ooooo`;o
00000_ooool2o`000003ooooool0003o000000?ooooo0_l00003ooooo`;o00000oooool2o`00087o
oooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h0
1oooool00ol0003oooooooooo`1iooooo`;o00000_ooool3o`0000Gooooo0_l00002ooooo`;o0000
0oooool2o`0000Kooooo0_l00003ooooo`;o00001Oooool2o`000003ooooool0003o000000Wooooo
0_l00002ooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo0ol00002ooooo`;o0000
4oooool2o`0006cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o
V9RHob4Q8Oo^k^h01_ooool3o`0006gooooo0_l0000:ooooo`;o000000?oooooo`000?l000000_l0
0005ooooo`;o00001oooool2o`0000_ooooo0_l00008ooooo`;o00000oooool2o`0000Sooooo0_l0
0005ooooo`;o00001Oooool4o`0001Gooooo0_l0000=ooooo`;o0000GOooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooo
oooo06Oooooo0_l00004ooooo`;o00001oooool2o`0000Cooooo0ol0000Aooooo`;o00003_ooool2
o`0000Sooooo0_l0000<ooooo`;o000000?oooooo`000?l000001oooool2o`0002Cooooo0_l0001M
ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0Ioooool2o`0000gooooo0_l00004ooooo`;o00004_ooool2o`00
00Kooooo0_l00006ooooo`;o00002?ooool2o`000003ooooool0003o000000;o00001oooool2o`00
0003ooooool0003o000000;o000000Coooooo`000?l0003ooooo1_l00020ooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003ooooo
ooooo`1aooooo`;o00002Oooool2o`0000Cooooo0_l00004ooooo`;o00001Oooool2o`0000Oooooo
0_l0000@ooooo`;o000000?oooooo`000?l000000_l00008ooooo`;o00000_ooool2o`000004oooo
ool0003o0000ooooo`Ko0000P?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnH
V9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0H?ooool2o`0000;ooooo0_l0000;
ooooo`;o00000_ooool2o`0000[ooooo1Ol00002ooooo`;o00001Oooool2o`0000?ooooo0_l0000D
ooooo`;o00003Oooool2o`0000_ooooo0_l00021ooooo`007?ooool00ol0003oooooooooo`1Poooo
o`Ko00003oooool2o`0000[ooooo0_l000000ooooooo0000o`000002o`0000cooooo0_l0000:oooo
o`;o00007Oooool2o`000003ooooool0003o000000Cooooo0_l00004ooooo`;o00002_ooool2o`00
06gooooo000Looooo`03o`000?oooooooooo05oooooo0_l000000ooooooo0000o`000003o`0000?o
oooo1_l000000ooooooo0000o`000005ooooo`;o00001oooool2o`0000;ooooo0ol00007ooooo`;o
00002oooool2o`0000;ooooo0_l00002ooooo`;o00002oooool2o`0000;ooooo0_l00005ooooo`;o
000000Coooooo`000?l0003ooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l00002
ooooo`;o00001_ooool2o`0006gooooo000Looooo`03o`000?oooooooooo05oooooo0_l00004oooo
o`;o000000?oooooo`000?l000001_l000000ooooooo0000o`000005ooooo`;o000000?oooooo`00
0?l000001?ooool2o`0000;ooooo0_l00008ooooo`?o00001_ooool2o`0000;ooooo0_l00006oooo
o`?o00002_ooool2o`0000;ooooo0_l00005ooooo`;o00003Oooool2o`0000Gooooo0_l0001eoooo
o`007?ooool00ol0003oooooooooo`1Nooooo`;o00002?ooool3o`00013ooooo0_l0000<ooooo`;o
00001Oooool3o`0000Gooooo0_l0000;ooooo`;o00002_ooool2o`0000cooooo0ol00027ooooo`00
7?ooool00ol0003oooooooooo`1Nooooo`;o000000?oooooo`000?l000009_ooool2o`0000Kooooo
0_l00006ooooo`Co00000oooool2o`000004ooooool0003o0000ooooo`;o00000oooool2o`0000Co
oooo0_l00007ooooo`;o00000oooool3o`0000gooooo0_l00004ooooo`;o0000L_ooool001cooooo
00?o0000ooooooooool0HOooool2o`000003ooooool0003o000002Wooooo0_l00008ooooo`Co0000
0oooool2o`000004ooooool0003o0000ooooo`?o000000Coooooo`000?l0003o00001?ooool2o`00
00Oooooo1?l0000@ooooo`?o00001?ooool2o`0007;ooooo000Looooo`03o`000?oooooooooo06Co
oooo0_l0000Looooo`;o00001Oooool2o`0000Cooooo0_l00004ooooo`;o00004?ooool2o`000003
ooooool0003o000000Gooooo0_l00008ooooo`?o00001?ooool2o`0000[ooooo0_l000000ooooooo
0000o`00001fooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o00004_ooool3o`0000kooooo
1?l00003ooooo`;o00002_ooool2o`0000;ooooo0_l0000Oooooo`?o00001Oooool2o`0000_ooooo
1?l0001fooooo`007?ooool00ol0003oooooooooo`1Kooooo`Ko00004?ooool3o`0000Cooooo0_l0
0009ooooo`?o00001?ooool2o`0000Wooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l0
00000ooooooo0000o`000002o`0000oooooo0_l00004ooooo`;o000000?oooooo`000?l000000ooo
ool4o`0000Sooooo0ol00004ooooo`?o0000LOooool001cooooo00?o0000ooooooooool0Foooool2
o`0000;ooooo0_l0000@ooooo`;o00001Oooool4o`0000;ooooo1?l000000ooooooo0000o`000003
o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000Oooooo1?l000000ooooooo0000o`000002
o`0000gooooo1?l00003ooooo`;o00000_ooool2o`0000?ooooo1?l00008ooooo`?o00001?ooool3
o`00077ooooo000Looooo`03o`000?oooooooooo05Cooooo0_l0000Jooooo`;o00001_ooool5o`00
0003ooooool0003o000000;o00000oooool3o`0000Oooooo0_l00002ooooo`;o00006?ooool2o`00
00?ooooo1?l00002ooooo`?o00000oooool2o`0000?ooooo0_l0000Gooooo`;o0000Joooool001co
oooo0_l0001Eooooo`;o00001oooool2o`000003ooooool0003o000000kooooo0_l00005ooooo`?o
000000?oooooo`000?l000002?ooool2o`0002Kooooo0_l00002ooooo`;o000000?oooooo`000?l0
00000_ooool2o`000004ooooool0003o0000ooooo`Co00006Oooool3o`0006_ooooo000Looooo`03
o`000?oooooooooo05gooooo0_l000000ooooooo0000o`00000Eooooo`?o00002Oooool2o`0000?o
oooo0_l0000Aooooo`?o00004oooool2o`0000Oooooo0ol000000ooooooo0000o`000002o`0001Wo
oooo0_l00002ooooo`;o0000J?ooool001cooooo00?o0000ooooooooool0F?ooool2o`0000?ooooo
0_l0000=ooooo`;o00005Oooool2o`0000?ooooo0_l0000Aooooo`?o00000oooool3o`00013ooooo
0_l000001?oooooo0000o`000?ooool2o`0000Gooooo1Ol0000=ooooo`;o00002_ooool2o`0000_o
oooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o00000_ooool2o`0000Cooooo
0_l00003ooooo`;o00000_ooool3o`0000Gooooo0_l000000ooooooo0000o`000008ooooo`;o0000
2oooool3o`00017ooooo0_l00008ooooo`?o000000?oooooo`000?l000000_ooool2o`0000Cooooo
0_l00003ooooo`;o000000?oooooo`000?l000002?ooool7o`0000Wooooo1?l0000Gooooo`;o0000
Foooool001cooooo00?o0000ooooooooool0C_ooool2o`000004ooooool0003o0000o`0000?ooooo
0_l000000ooooooo0000o`000005ooooo`?o00000oooool5o`0000Oooooo0_l000000ooooooo0000
o`00000<ooooo`;o00004Oooool3o`0000Sooooo0_l000000ooooooo0000o`000002ooooo`;o0000
1?ooool3o`0001Cooooo0_l000000ooooooo0000o`000006ooooo`;o0000M_ooool001cooooo00?o
0000ooooooooool0Coooool4o`0000?ooooo0ol000000ooooooo0000o`000007ooooo`;o00000_oo
ool2o`000003ooooool0003o000000Oooooo0_l0000Eooooo`;o00003?ooool2o`0000Cooooo0_l0
000<ooooo`;o00000_ooool2o`0001Cooooo0_l000000ooooooo0000o`00000:ooooo`;o00002ooo
ool4o`000003ooooool0003o0000063ooooo000Looooo`03o`000?oooooooooo04oooooo0_l00002
ooooo`Ko00000_ooool2o`0000Kooooo0_l0000:ooooo`;o00006Oooool2o`0000[ooooo0_l00002
ooooo`;o00000_ooool2o`0000;ooooo0_l00004ooooo`Ko00005Oooool2o`000003ooooool0003o
000000?ooooo0_l00008ooooo`;o00002oooool4o`000003ooooool0003o000001Sooooo0_l00016
ooooo`007?ooool00ol0003oooooooooo`1Cooooo`?o000000?oooooo`000?l000000_ooool2o`00
01;ooooo0_l000000ooooooo0000o`00000?ooooo`;o00001Oooool3o`0000Wooooo0_l00002oooo
o`;o00001_ooool2o`0000Cooooo1_l0000Booooo`;o000000?oooooo`000?l000001_ooool2o`00
00Sooooo0_l00002ooooo`;o00009_ooool2o`0004Kooooo000Looooo`03o`000?oooooooooo053o
oooo0_l00009ooooo`;o00005Oooool3o`0000kooooo0_l00005ooooo`Co00006oooool3o`0000So
oooo0ol00003ooooo`;o00000oooool5o`0000[ooooo0_l00005ooooo`;o00000_ooool2o`0000oo
oooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`16ooooo`;o00002?ooool2o`0001gooooo
0_l00002ooooo`;o00005Oooool4o`0001?ooooo0_l00007ooooo`;o000000?oooooo`000?l00000
1Oooool5o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`00000:ooooo`;o0000
2oooool2o`0000gooooo0ol0001Looooo`007?ooool00ol0003oooooooooo`16ooooo`;o00003?oo
ool2o`0000Sooooo0_l0000<ooooo`;o000000?oooooo`000?l000005?ooool4o`0000;ooooo0ol0
000Cooooo`;o00001oooool2o`000004ooooool0003o0000o`0000?ooooo0_l00002ooooo`;o0000
1_ooool2o`0000Oooooo0_l0000Aooooo`;o00000oooool2o`0000Cooooo0ol00002ooooo`;o0000
1?ooool2o`0005Kooooo000Looooo`03o`000?oooooooooo05Cooooo0_l00008ooooo`?o00002ooo
ool2o`0000Kooooo0_l0000?ooooo`Co00005Oooool3o`000003ooooool0003o000000Cooooo1?l0
0002ooooo`;o00000oooool2o`0000Sooooo0_l000000ooooooo0000o`000006ooooo`?o00005Ooo
ool2o`0000Cooooo0ol00008ooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0B_ooool2
o`0000kooooo0_l00002ooooo`?o00004oooool2o`0000Cooooo0_l00002ooooo`;o00002_ooool2
o`0000cooooo0_l00003ooooo`Co000000?oooooo`000?l000001?ooool4o`000003ooooool0003o
000000kooooo0_l000000ooooooo0000o`000002o`0000Gooooo0_l0000Dooooo`;o00001_ooool2
o`0000Sooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`11ooooo`;o00001Oooool4o`00
00kooooo1_l0000Eooooo`;o00000oooool2o`0000;ooooo1?l00002ooooo`;o00001?ooool2o`00
00cooooo0_l00003ooooo`;o00001_ooool2o`0000Kooooo0_l00002ooooo`;o00003oooool2o`00
00?ooooo0_l0000Fooooo`;o00002?ooool2o`0005kooooo000Looooo`03o`000?oooooooooo047o
oooo0_l00005ooooo`Co00000_ooool2o`0000?ooooo0_l00007ooooo`Co00005Oooool2o`0000So
oooo0ol00002ooooo`;o00006_ooool2o`0000?ooooo1?l00005ooooo`;o000000?oooooo`000?l0
00005?ooool2o`0000Gooooo0_l0000Aooooo`;o00001_ooool6o`0005[ooooo000Looooo`03o`00
0?oooooooooo03kooooo0_l0000>ooooo`;o00000oooool2o`0002Cooooo0_l00004ooooo`;o0000
7oooool2o`0000Cooooo0ol00005ooooo`;o00000_ooool2o`0000Wooooo0_l00008ooooo`;o0000
0oooool4o`00017ooooo0_l00006ooooo`Ko00001?ooool2o`0005Cooooo000Looooo`;o0000?ooo
ool2o`0000_ooooo0_l0000=ooooo`;o00003Oooool2o`0000Sooooo0_l00004ooooo`;o00002?oo
ool2o`0001Cooooo0_l00008ooooo`;o000000Coooooo`000?l0003o00001_ooool5o`0000Wooooo
0_l000000ooooooo0000o`000007ooooo`;o000000?oooooo`000?l000006oooool3o`0000?ooooo
0_l00002ooooo`;o00000oooool2o`0000oooooo0_l0000nooooo`007?ooool00ol0003ooooooooo
o`0oooooo`;o00002_ooool2o`0000gooooo0_l0000=ooooo`;o00002?ooool2o`0000kooooo0_l0
0003ooooo`;o00003oooool2o`0000;ooooo0_l00004ooooo`;o00000_ooool2o`0000Kooooo1Ol0
000;ooooo`?o000000?oooooo`000?l000000_ooool4o`0001oooooo0_l00003ooooo`;o00001?oo
ool5o`0000oooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0oooooo`Co00000oooool4
o`000003ooooool0003o000000gooooo0_l0000<ooooo`;o00001_ooool2o`0000Sooooo0_l00000
1?oooooo0000o`000?l00008ooooo`;o00001Oooool2o`0000Cooooo0_l000000ooooooo0000o`00
0002o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000003Oooool2o`0000Cooooo
0_l00005ooooo`;o000000?oooooo`000?l000001Ol00003ooooo`;o00002oooool2o`0000oooooo
1?l00007ooooo`Ko0000C_ooool001cooooo00?o0000ooooooooool0@Oooool2o`0000?ooooo1?l0
0006ooooo`;o00005_ooool2o`0000Kooooo0_l00008ooooo`;o000000Coooooo`000?l0003o0000
3?ooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000002o`0000Cooooo
0_l00005ooooo`;o00003oooool2o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l00000
0_l00003ooooo`;o00002oooool2o`00017ooooo0_l0000;ooooo`;o0000C_ooool001cooooo00?o
0000ooooooooool0D?ooool2o`00017ooooo0_l0000Wooooo`;o000000?oooooo`000?l000001?oo
ool2o`000003ooooool0003o000000;o00000_ooool2o`000004ooooool0003o0000ooooo`;o0000
00?oooooo`000?l000005?ooool2o`000003ooooool0003o000000Gooooo1?l0001nooooo`007?oo
ool00ol0003oooooooooo`1Sooooo`?o0000:Oooool2o`000004ooooool0003o0000ooooo`?o0000
0_ooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000Gooooo0_l0000=ooooo`So
00001oooool2o`0001Gooooo0_l0000Iooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0
Goooool2o`0000?ooooo0_l0000Dooooo`;o00004Oooool2o`0000?ooooo0_l00002ooooo`;o0000
00?oooooo`000?l000001oooool4o`0000Gooooo0_l00004ooooo`;o00001oooool<o`0001Wooooo
1?l0000Hooooo`?o0000Boooool001cooooo00?o0000ooooooooool0BOooool2o`0000?ooooo0_l0
0007ooooo`;o00001Oooool3o`0000Kooooo0_l0000Aooooo`;o00002Oooool2o`0000Kooooo0_l0
00000ooooooo0000o`000004ooooo`Go00001oooool4o`0000[ooooo0ol00009ooooo`[o00006Ooo
ool4o`000003ooooool0003o000000Gooooo0_l0000?ooooo`;o00003Oooool2o`0003cooooo000L
ooooo`03o`000?oooooooooo04Wooooo0_l00003ooooo`;o00001oooool2o`0000Gooooo0ol00002
ooooo`;o00000_ooool2o`0001Gooooo0_l00005ooooo`;o00001?ooool4o`000003ooooool0003o
000000Cooooo0ol00003ooooo`;o00001Oooool3o`0000Cooooo0_l00004ooooo`;o00001_ooool2
o`000003ooooool0003o000000_o00007?ooool2o`0000Gooooo0_l00002ooooo`;o00001_ooool2
o`0001;ooooo0_l0000looooo`007?ooool00ol0003oooooooooo`1Booooo`;o00001_ooool2o`00
00Oooooo0_l00009ooooo`;o00003_ooool2o`0000Cooooo0_l00004ooooo`Go00003Oooool2o`00
00Kooooo0_l00004ooooo`;o00003?ooool2o`000003ooooool0003o000000_o00004_ooool2o`00
00Sooooo0_l00009ooooo`;o00001_ooool2o`0000Kooooo0_l00018ooooo`007?ooool00ol0003o
ooooooooo`1:ooooo`;o00000_ooool2o`0000;ooooo0_l00006ooooo`;o00001Oooool2o`0000_o
oooo0_l00006ooooo`Co000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000Co
00000_ooool2o`0000Sooooo0_l00006ooooo`;o00001Oooool2o`0001Cooooo4Ol0000@ooooo`;o
00004oooool2o`0000;ooooo0_l0000:ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0
B_ooool2o`0000;ooooo0_l0000Aooooo`;o00004oooool4o`000003ooooool0003o000000;ooooo
0_l000001Ooooooo0000o`000?l0003ooooo00;o00003?ooool2o`0000Cooooo0_l00006ooooo`?o
00000oooool2o`0000kooooo4_l0000Dooooo`;o000000?oooooo`000?l000000_l00008ooooo`;o
00001?ooool2o`0000[ooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o0000
1?ooool2o`0000Kooooo0_l00010ooooo`Oo00002Oooool3o`0000Cooooo0_l00006ooooo`;o0000
1?ooool2o`0000?ooooo0_l00005ooooo`;o00000_oooolCo`0000gooooo0_l00004ooooo`;o0000
00?oooooo`000?l000000_l00008ooooo`;o0000F_ooool001cooooo00?o0000ooooooooool0<ooo
ool2o`0000Cooooo0_l00006ooooo`;o0000;Oooool2o`0000;ooooo0_l00009ooooo`;o00001?oo
ool5o`0000;ooooo0_l00005ooooo`Co00005_ooool2o`000003ooooool0003o000000;ooooo0_l0
0002ooooo`[o000000?oooooo`000?l000001_l000000ooooooo0000o`00000:ooooo`;o0000Kooo
ool001cooooo00?o0000ooooooooool0@Oooool2o`0000?ooooo0_l00007ooooo`;o000000?ooooo
o`000?l000007?ooool2o`0000;ooooo0ol00004ooooo`Ko00002oooool4o`0000Gooooo0_l00003
ooooo`;o00004Oooool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`00000@
o`0000;ooooo0_l00006ooooo`;o00001Oooool2o`0001cooooo0_l0001>ooooo`007?ooool00ol0
003oooooooooo`11ooooo`;o00000oooool2o`0000Oooooo0_l000000ooooooo0000o`00000?oooo
o`;o00001Oooool2o`0000Cooooo0_l00002ooooo`?o00001?ooool4o`000003ooooool0003o0000
00cooooo0_l00005ooooo`;o00000oooool2o`0000[ooooo0_l00005ooooo`;o00001_oooolDo`00
00;ooooo0_l000000ooooooo0000o`000003ooooo`?o00001Oooool2o`0001cooooo0_l0001>oooo
o`007?ooool2o`0003Wooooo0_l00002ooooo`;o00001Oooool2o`0000Oooooo0_l00009ooooo`;o
00002_ooool2o`0000Gooooo0_l00008ooooo`;o00000oooool2o`0000Gooooo0_l0000>ooooo`Co
000000?oooooo`000?l000000_l00007ooooo`Go000000?oooooo`000?l000001_ooool2o`0000Co
oooo2?l000000ooooooo0000o`00000;o`000004ooooool0003o0000ooooo`;o00000oooool2o`00
00?ooooo0_l0000Booooo`;o00001_ooool2o`0000_ooooo0_l00016ooooo`007?ooool00ol0003o
ooooooooo`0hooooo`;o00000_ooool4o`0000?ooooo0_l00002ooooo`Co000000?oooooo`000?l0
00001?ooool2o`0000?ooooo0ol00004ooooo`Co00005Oooool4o`0000oooooo0_l00004ooooo`Co
00000oooool2o`0000Oooooo1Ol000000ooooooo0000o`000002ooooo`;o00000_ooool2o`0000Co
oooo6?l0000;ooooo`?o00004_ooool2o`0000Kooooo0_l00002ooooo`;o00000oooool2o`0000;o
oooo0_l0000>ooooo`;o0000=_ooool001cooooo00?o0000ooooooooool0?_ooool2o`0000Oooooo
1?l00004ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Cooooo1?l00005ooooo`;o0000
1Oooool2o`0000;ooooo0_l00002ooooo`?o00002_ooool2o`0000;ooooo0_l000000ooooooo0000
o`000004ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00000_ooool2o`0000Cooooo
0_l00005oooooaGo00000oooool2o`0000Kooooo0_l0000Cooooo`;o00001oooool2o`000003oooo
ool0003o000000?ooooo0_l0000Booooo`;o0000=_ooool001cooooo00?o0000ooooooooool0??oo
ool2o`00017ooooo0_l00008ooooo`;o00002_ooool4o`0000Gooooo1ol000000ooooooo0000o`00
0006ooooo`;o00000oooool2o`0000;ooooo0_l00007ooooo`?o000000?oooooo`000?l000001?l0
0005ooooo`?o00002?ooool4o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000004Ol0
0002ooooo`;o000000?oooooo`000?l000002oooool2o`0000Sooooo0_l0000=ooooo`;o0000D_oo
ool001cooooo00?o0000ooooooooool0??ooool2o`0001_ooooo0_l0000:ooooo`;o00000oooool2
o`0000;ooooo1?l000001?oooooo0000o`000?l00008ooooo`;o00001_ooool2o`0000Wooooo0_l0
00000ooooooo0000o`000006o`0000Cooooo0_l00007ooooo`;o000000?oooooo`000?l000001_oo
oolEo`0000;ooooo1?l0000=ooooo`;o00002?ooool2o`0000?ooooo0_l00002ooooo`;o00003_oo
ool2o`0000Cooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`1Fooooo`;o00001?ooool2
o`0000Gooooo0_l00005ooooo`So00000_ooool2o`0000Gooooo0_l000000ooooooo0000o`000006
ooooo`;o00003_ooool6o`000003ooooool0003o000000;o00002?ooool2o`0000;ooooo0_l00000
0ooooooo0000o`000004oooooaCo000000?oooooo`000?l000000_l0000Looooo`;o00000_ooool2
o`0000[ooooo0_l00002ooooo`;o00001?ooool2o`0004;ooooo000Looooo`03o`000?oooooooooo
04Cooooo0_l0000@ooooo`;o00001?ooool2o`000003ooooool0003o000000;ooooo0_l00003oooo
o`;o00000_ooool4o`0000_ooooo0ol0000=ooooo`;o00002Oooool6o`000003ooooool0003o0000
00;o00001oooool2o`0000;ooooo0ol000000ooooooo0000o`000007oooooa7o00000oooool2o`00
01Oooooo0_l0000Cooooo`;o00001?ooool2o`0004Kooooo000Looooo`03o`000?oooooooooo03Go
oooo0_l000000ooooooo0000o`00000:ooooo`;o00001oooool2o`0000Wooooo0_l00003ooooo`Co
00001_ooool3o`0000;ooooo1?l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooo
oooo0000o`000004ooooo`;o00001oooool2o`0000Sooooo0_l000000ooooooo0000o`000002o`00
0003ooooool0003o000000;o00001oooool2o`0000;ooooo0_l0000;oooooa?o000000?oooooo`00
0?l000005oooool2o`000004ooooool0003o0000ooooo`;o00001oooool2o`0000[ooooo0_l00016
ooooo`007?ooool00ol0003oooooooooo`0eooooo`;o000000Coooooo`000?l0003ooooo0_l00000
0ooooooo0000o`000003ooooo`;o00001?ooool2o`0000;ooooo0_l00005ooooo`;o00000_ooool2
o`0000?ooooo0_l00008ooooo`Wo000000?oooooo`000?l000000_l000001?oooooo0000o`000?oo
ool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool3o`0000[ooooo0_l000000ooooooo0000
o`000003ooooo`;o000000?oooooo`000?l000000_l00007ooooo`;o000000?oooooo`000?l00000
0_l00003ooooo`?o00000ooooolDo`0001gooooo1Ol00007ooooo`;o00003?ooool2o`000003oooo
ool0003o0000047ooooo000Looooo`03o`000?oooooooooo03Gooooo0_l00004ooooo`;o000000?o
ooooo`000?l000000oooool2o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l000000_oo
ool2o`0000Cooooo0_l00004ooooo`;o00001Oooool2o`000003ooooool0003o000000Wo000000Co
ooooo`000?l0003o00000_ooool2o`0000;ooooo0_l00004ooooo`?o00002_ooool5o`0000?ooooo
1_l00008ooooo`Oo00000oooool4o`0000;ooooo4ol0000:ooooo`;o00004oooool2o`0001Oooooo
0_l000000ooooooo0000o`000011ooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00001?oo
ool3o`0000Sooooo0_l00004ooooo`;o00001Oooool2o`0000;ooooo0_l000001Ooooooo0000o`00
0?l0003ooooo00?o00000_ooool2o`0000;ooooo1_l00002ooooo`;o00002_ooool2o`0000?ooooo
0_l00005ooooo`Oo00000oooool2o`0000?ooooo0_l00005ooooo`;o000000?oooooo`000?l00000
1?ooool<o`000003ooooool0003o000000cooooo0_l0000Booooo`?o00000_ooool2o`0000Cooooo
0_l0001Cooooo`007?ooool00ol0003oooooooooo`0looooo`;o00004Oooool4o`0000Cooooo0_l0
0009ooooo`;o00000oooool2o`0000;ooooo1?l00002ooooo`Co000000?oooooo`000?l000001Ooo
ool3o`0000?ooooo0_l000000ooooooo0000o`000007ooooo`;o00003oooool2o`0000?ooooo0_l0
0004ooooo`Co00000_ooool2o`000003ooooool0003o000000Oooooo2Ol0000;ooooo`;o00005_oo
ool2o`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l000003Oooool2o`00047ooooo000L
ooooo`03o`000?oooooooooo03cooooo1?l0000Aooooo`;o00001?ooool2o`0000Wooooo0_l00004
ooooo`;o00000_ooool<o`000005ooooool0003o0000o`000?ooool00ol00006ooooo`;o00001ooo
ool2o`0000;ooooo0_l0000Fooooo`Co000000?oooooo`000?l000000_ooool2o`0000Oooooo0_l0
00000ooooooo0000o`000004o`0000Oooooo0_l00002ooooo`;o000000?oooooo`000?l000007?oo
ool2o`0000?ooooo0_l0000=ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0>_ooool2
o`0000;ooooo0_l0000Fooooo`;o00001_ooool2o`0000Sooooo2Ol000000ooooooo0000o`000004
o`000003ooooool0003o000000Co000000?oooooo`000?l000000_l000000ooooooo0000o`000004
ooooo`;o00000_ooool3o`000003ooooool0003o000000Gooooo0_l000000ooooooo0000o`000003
ooooo`Co000000?oooooo`000?l000001oooool2o`0000_ooooo2Ol00007ooooo`;o00001Oooool2
o`0000;ooooo0ol0000Aooooo`;o00001?ooool2o`0000?ooooo0_l0000;ooooo`;o0000@oooool0
0006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413ooooooooo
o`04ooooo`03o`000?oooooooooo037ooooo0ol000001?oooooo0000o`000?l00002ooooo`Co0000
6?ooool2o`0000Kooooo0_l000000ooooooo0000o`000002ooooo`Wo000000?oooooo`000?l00000
4ol000000ooooooo0000o`000006o`0000?ooooo0_l00008ooooo`;o000000?oooooo`000?l00000
0oooool4o`000003ooooool0003o000001Cooooo2Ol00002ooooo`;o00002_ooool2o`0000;ooooo
0ol0000Aooooo`;o00002Oooool2o`000003ooooool0003o000000Sooooo0ol00012ooooo`0000Ko
ooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo037ooooo0ol000001?oooooo0000o`000?l00004ooooo`;o00002_ooool2o`00
01;ooooo1?l000000ooooooo0000o`000002ooooo`_o000000?oooooo`000?l000002?l000000ooo
oooo0000o`00000?o`0000Sooooo0_l00008ooooo`;o00000_ooool2o`0000Oooooo0_l00005oooo
o`;o00002?ooool2o`000004ooooool0003o0000o`0000Gooooo0_l00008ooooo`;o00006Oooool2
o`000004ooooool0003o0000ooooo`;o00001Oooool2o`0000Wooooo0_l00002ooooo`;o00001_oo
ool2o`0003Kooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006
ooooo`03o`000?oooooooooo03?ooooo0_l0000Booooo`?o000000Coooooo`000?l0003o00003_oo
ool7o`0000Cooooo1_l000001Ooooooo0000o`000?l0003ooooo01Go00000_ooool3o`000004oooo
ool0003o0000ooooo`;o00000oooool2o`0000Sooooo0_l00002ooooo`;o00001Oooool4o`0000Go
oooo0ol00006ooooo`Oo000000?oooooo`000?l000003?ooool2o`0000Oooooo0_l00008ooooo`;o
00001_ooool2o`000004ooooool0003o0000ooooo`;o00005?ooool2o`0000Kooooo0_l0000foooo
o`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`00
00Oooooo0ol0000cooooo`;o00003Oooool2o`0000;ooooo0ol00002ooooo`?o00004_ooool3o`00
00;ooooo0_l00003ooooo`?o000000Goooooo`000?l0003o0000ooooo`02o`000003ooooool0003o
0000017o00000oooool4o`000005ooooool0003o0000o`000?ooool00_l00006ooooo`;o00001?oo
ool2o`0000Kooooo1Ol00003ooooo`Co00001_ooool5o`0000?ooooo0_l00003ooooo`;o00002_oo
ool2o`0000?ooooo0ol00008ooooo`;o00001_ooool2o`0002[ooooo0_l0000^ooooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o
0000ooooooooool0@_ooool2o`0000;ooooo0_l0000Cooooo`;o00001oooool3o`0000?ooooo7_l0
0003ooooo`Co000000Goooooo`000?l0003o0000ooooo`03o`0000Gooooo0_l00004ooooo`;o0000
1_ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000001_ooool4o`0000?ooooo
0_l00006ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000?ooooo0_l00003ooooo`Co
00001_ooool2o`0000[ooooo0_l0000Wooooo`;o0000;_ooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool02_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo03kooooo
0_l0000>ooooo`;o00002oooool2o`0000;ooooo0_l00003ooooo`;o00001?oooolNo`000004oooo
ool0003o0000ooooo`;o00001oooool2o`0001?ooooo1ol00008ooooo`Go00000_ooool5o`0000Oo
oooo0ol000000ooooooo0000o`000002ooooo`;o00001_ooool2o`0000;ooooo0_l00002ooooo`;o
00002_ooool2o`000003ooooool0003o000005Cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMg
M`cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0looooo`Co00003_ooool2o`00
0003ooooool0003o000000Wooooo0_l000000ooooooo0000o`000003ooooo`?o00000_ooool4o`00
00;ooooo6Ol000001?oooooo0000o`000?ooool2o`0001_ooooo1_l0000:ooooo`;o00001Oooool2
o`000003ooooool0003o000000Oooooo0_l000001?oooooo0000o`000?ooool4o`0000Wooooo0ol0
00000ooooooo0000o`00000>ooooo`?o00003?ooool2o`0004Gooooo00001_ooooook^k^oc8b<_l0
003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`0looooo`;o0000
4oooool2o`000003ooooool0003o000000Kooooo1_l00003ooooo`So000000?oooooo`000?l00000
1?l000000ooooooo0000o`00000Ao`0000Cooooo1?l0000Iooooo`;o00001_ooool2o`0000Kooooo
0_l00002ooooo`;o00002oooool4o`000004ooooool0003o0000ooooo`Co00002Oooool2o`0000;o
oooo1?l0000;ooooo`Co00003?ooool2o`0004Gooooo000Looooo`03o`000?oooooooooo05Cooooo
0_l00003ooooo`;o00000_ooool5o`0000?ooooo2?l000000ooooooo0000o`00000Ro`0000cooooo
0_l00003ooooo`;o00002Oooool2o`000003ooooool0003o000000Kooooo0_l00002ooooo`;o0000
2oooool4o`00013ooooo0_l00004ooooo`?o00002oooool3o`0000_ooooo0_l00009ooooo`;o0000
1oooool2o`0003?ooooo000Looooo`03o`000?oooooooooo02oooooo0_l00006ooooo`;o00005ooo
ool2o`0000Oooooo0ol00009ooooob[o000000Coooooo`000?l0003o00002oooool2o`0000?ooooo
0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000;o00004?ooool2o`0000?ooooo
0_l000000ooooooo0000o`00000Booooo`;o000000?oooooo`000?l000007Oooool2o`0000?ooooo
0_l00004ooooo`;o00001oooool2o`0003?ooooo000Looooo`03o`000?oooooooooo02oooooo0_l0
0006ooooo`;o00005oooool2o`0000?ooooo0_l00003ooooo`;o00001?ooool2o`000004ooooool0
003o0000ooooobOo00000oooool3o`0000cooooo0_l00003ooooo`;o000000?oooooo`000?l00000
0_ooool4o`000003ooooool0003o000000Wooooo0_l00005ooooo`;o00000oooool5o`0000Gooooo
0_l0000>ooooo`;o00001_ooool2o`0001[ooooo0_l00008ooooo`;o000000?oooooo`000?l00000
=Oooool001cooooo00?o0000ooooooooool0>oooool2o`0000Gooooo0ol00008ooooo`?o00001Ooo
ool2o`0000?ooooo0_l00003ooooo`Oo000000?oooooo`000?l00000:?l00003ooooo`;o00002Ooo
ool2o`0000?ooooo0_l00007ooooo`Go00002Oooool2o`0000;ooooo0_l00004ooooo`;o000000Co
ooooo`000?l0003ooooo0_l00003ooooo`?o00002_ooool2o`0000Gooooo0_l00003ooooo`;o0000
00?oooooo`000?l000003_ooool2o`000003ooooool0003o000000kooooo0_l000000ooooooo0000
o`00000eooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00002_ooool2o`0000?ooooo1Ol0
0008ooooo`?o00001Oooool2o`0000?ooooo0_l00003ooooocCo000000?oooooo`000?l000000_oo
ool2o`0000;ooooo0_l0000:ooooo`;o00001Oooool2o`0000Wooooo0_l00003ooooo`;o00001?oo
ool2o`0000;ooooo1?l000000ooooooo0000o`000002o`0000Wooooo1?l00005ooooo`;o000000?o
ooooo`000?l000000oooool2o`0000Cooooo0_l00008ooooo`;o000000?oooooo`000?l000003?oo
ool2o`0000_ooooo0_l0000]ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00001_ooool2
o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`0000cooooo0_l0000:
ooooobWo000000?oooooo`000?l000000_l00002ooooo`;o00000_ooool2o`000003ooooool0003o
000000;ooooo0_l0000:ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00005
ooooo`;o000000?oooooo`000?l000002_ooool3o`0000;ooooo0_l00003ooooo`?o000000?ooooo
o`000?l000000_ooool5o`0000Oooooo0_l00009ooooo`?o000000?oooooo`000?l000005Oooool2
o`0000_ooooo0_l0000]ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00001_ooool2o`00
00;ooooo0_l0000:ooooo`;o00003_ooool2o`0000Sooooo;_l00006ooooo`;o00005?ooool3o`00
00Gooooo0_l00008ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000?ooooo0_l00005
ooooo`Wo00000_ooool5o`0001?ooooo0_l000000ooooooo0000o`00001Aooooo`007?ooool00ol0
003oooooooooo`0_ooooo`;o00007oooool2o`0000Gooooo0_l0000;ooooo`;o00000_ooool7o`00
0003ooooool0003o000001_o000000?oooooo`000?l000001_ooool2o`0001?ooooo1Ol0000@oooo
o`?o000000?oooooo`000?l000001oooool;o`0000;ooooo0ol00009ooooo`;o0000HOooool001co
oooo00?o0000ooooooooool0;_ooool3o`0001Wooooo0_l00004ooooo`Co00004?ooool2o`0000;o
oooo9Ol000000ooooooo0000o`000003o`000003ooooool0003o000000;o00000oooool2o`0000ko
oooo0_l000000ooooooo0000o`000002o`000004ooooool0003o0000ooooo`;o00005Oooool;o`00
0003ooooool0003o000000;o00001Oooool6o`00067ooooo000Looooo`03o`000?oooooooooo02ko
oooo0_l00005ooooo`;o00001Oooool2o`0000Oooooo0_l00003ooooo`;o00001_ooool4o`0001;o
oooo9Ol000000ooooooo0000o`000003o`000004ooooool0003o0000o`0000Cooooo0_l0000>oooo
o`;o00000oooool2o`000004ooooool0003o0000ooooo`;o00005?oooolBo`0000Cooooo1?l00009
ooooo`;o00000_ooool2o`0005Cooooo000Looooo`03o`000?oooooooooo03Gooooo0_l00005oooo
o`;o00000oooool2o`0000;ooooo0_l00004ooooo`;o00001oooool2o`0000oooooo:?l000001?oo
oooo0000o`000?ooool2o`000003ooooool0003o000001Wooooo1Ol00003ooooo`;o00004oooool>
o`000003ooooool0003o000000;o00002_ooool2o`0000Cooooo0_l000001?oooooo0000o`000?l0
0002ooooo`;o0000D?ooool001cooooo0_l00012ooooo`;o00000oooool2o`0000?ooooo0ol00000
0ooooooo0000o`000003ooooo`Co00001oooool2o`0000Cooooo1?l000000ooooooo0000o`00000:
o`0000;ooooo5Ol00005ooooo`;o000000?oooooo`000?l000003?ooool3o`0000Cooooo0_l00000
0ooooooo0000o`000005o`0000;ooooo0ol0000;ooooo`Co00000_ooool@o`0000;ooooo1?l00009
ooooo`;o00001oooool4o`000003ooooool0003o0000053ooooo000Looooo`03o`000?oooooooooo
04Kooooo0_l00004ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Oooooo0_l00004oooo
o`;o00000ooooolSo`0000Gooooo0_l000000ooooooo0000o`000002ooooo`;o00002?ooool3o`00
00Cooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo1?l0000<oooooa?o000000?ooooo
o`000?l000001_l00006ooooo`;o00000oooool2o`0000Oooooo0_l0000Jooooo`;o0000=oooool0
01cooooo00?o0000ooooooooool0=?ooool5o`00017ooooo0_l00003ooooo`;o00004_ooool4o`00
00Gooooo3Ol000000ooooooo0000o`000007o`000003ooooool0003o000000_o00001?ooool2o`00
00;ooooo0_l00007ooooo`;o00002?ooool5o`0000?ooooo0_l0000Booooo`So000000?oooooo`00
0?l000003Ol000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000001?l0000?oooo
o`;o00000_ooool2o`0000Cooooo0_l00006ooooo`;o0000=oooool001cooooo00?o0000oooooooo
ool0=?ooool5o`0000?ooooo0_l00002ooooo`;o00002?ooool2o`000003ooooool0003o000000;o
00002Oooool3o`0000Kooooo3ol000000ooooooo0000o`00000Lo`0000Cooooo0ol000000ooooooo
0000o`000005ooooo`Co00001_ooool7o`0001Oooooo6ol00006ooooo`;o00000_ooool2o`000004
ooooool0003o0000o`0000_ooooo0_l00002ooooo`;o00000_ooool5o`0000oooooo0_l0000]oooo
o`007?ooool00ol0003oooooooooo`0looooo`;o00000_ooool2o`0000;ooooo0_l00005ooooo`Co
00002?ooool2o`000004ooooool0003o0000o`0000Sooooo:_l00006ooooo`?o000000?oooooo`00
0?l000000_ooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`Co000000?oooooo`00
0?l000005_ooool2o`0000;ooooo6?l00009ooooo`Oo000000?oooooo`000?l000004?ooool2o`00
0003ooooool0003o000000oooooo0_l0000]ooooo`007?ooool00ol0003oooooooooo`0looooo`;o
00001_ooool2o`0000Gooooo0_l000000ooooooo0000o`000007ooooo`;o00003?ooool4o`0000;o
oooo7ol000001?oooooo0000o`000?l00005ooooo`Ko00001?ooool2o`0000Cooooo0ol00006oooo
o`;o00002_ooool2o`0000gooooo6?l000000ooooooo0000o`000002o`0000Kooooo1ol00003oooo
o`;o00001Oooool2o`0000Wooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0kooooo`?o
00001oooool2o`0000Oooooo0_l0000Eooooo`Co00000ooooolNo`000003ooooool0003o000000Ko
oooo0_l00002ooooo`;o00002?ooool4o`0000Oooooo0_l0000:ooooo`;o00000oooool2o`0000Co
oooo0_l00002oooooako00001Oooool3o`0000kooooo0_l00009ooooo`;o00000_ooool3o`0003co
oooo000Looooo`03o`000?oooooooooo03_ooooo0_l00008ooooo`;o00000oooool3o`0000Sooooo
0_l0000?ooooo`;o00001?oooolQo`0000Gooooo0_l00003ooooo`;o00001oooool3o`000003oooo
ool0003o000000Gooooo0_l0000@ooooo`;o00001?ooool2o`0000;ooooo2ol000000ooooooo0000
o`00000@o`0000Sooooo1?l00006ooooo`;o00004Oooool3o`0003cooooo000Looooo`03o`000?oo
oooooooo03[ooooo0_l000000ooooooo0000o`00000;ooooo`Co00001oooool2o`0000?ooooo0_l0
0009ooooo`;o00001Oooool4o`0000;ooooo6_l00004ooooo`Co00000oooool2o`0000Oooooo0_l0
0002ooooo`;o00000_ooool2o`000003ooooool0003o000000gooooo0_l000000ooooooo0000o`00
0008ooooo`_o000000Coooooo`000?l0003ooooo3ol00007ooooo`Oo00001?ooool2o`0001;ooooo
0_l0000looooo`007?ooool00ol0003oooooooooo`0Wooooo`;o00002oooool2o`0000Cooooo0_l0
00000ooooooo0000o`00000;ooooo`Co00003?ooool4o`0000Kooooo0ol000001Ooooooo0000o`00
0?l0003ooooo00;o00001?oooolKo`0000?ooooo0_l0000?ooooo`Co00000oooool2o`0000Cooooo
0_l0000:ooooo`;o00001?ooool2o`0000Cooooo3_l000000ooooooo0000o`00000>o`0000Oooooo
1ol0001Fooooo`007?ooool00ol0003oooooooooo`0Wooooo`;o00002oooool2o`0000kooooo0_l0
0004ooooo`;o00001Oooool2o`0000Wooooo0_l00006ooooo`;o00000_ooool4o`000003ooooool0
003o000000;ooooo4ol000000ooooooo0000o`000006o`0000;ooooo0_l00002ooooo`?o00000_oo
ool2o`0000Oooooo1Ol00008ooooo`Co00003_ooool2o`0000Cooooo3_l000000ooooooo0000o`00
000Do`000003ooooool0003o000000?o00003Oooool2o`0004Wooooo000Looooo`03o`000?oooooo
oooo03Oooooo1?l00009ooooo`;o00002oooool2o`0000Cooooo0_l0000Aooooo`;o000000Cooooo
o`000?l0003ooooo4_l00002ooooo`?o000000Coooooo`000?l0003o00000_ooool9o`0000;ooooo
1?l00004ooooo`;o00000_ooool2o`0000?ooooo2Ol0000BooooobOo00001Oooool2o`0000cooooo
0_l0000Booooo`;o0000=Oooool001cooooo00?o0000ooooooooool0=oooool4o`000004ooooool0
003o0000o`0000Sooooo0ol00007ooooo`Go000000?oooooo`000?l000002_ooool3o`0000Oooooo
0_l000000ooooooo0000o`00000=o`000003ooooool0003o000000;ooooo0ol000001Ooooooo0000
o`000?l0003ooooo00?o00000_ooool4o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o
00001oooool8o`0001?ooooo8_l00006ooooo`;o00000_ooool2o`0000oooooo0_l0000?ooooo`;o
0000=Oooool001cooooo00?o0000ooooooooool0??ooool3o`0000Sooooo0ol00002ooooo`;o0000
0oooool5o`0000?ooooo1?l00006ooooo`?o00000_ooool2o`0000Kooooo3ol000000ooooooo0000
o`000003o`0000Cooooo2?l00005ooooo`;o00005Oooool4o`0001Kooooo8Ol00004ooooo`;o0000
4oooool3o`0000[ooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`0looooo`;o000000?o
ooooo`000?l000000oooool2o`0000Kooooo0_l0000;ooooo`Co00001oooool3o`000003ooooool0
003o000000Kooooo5Ol00003ooooo`Wo00000oooool4o`0001Cooooo2Ol0000:ooooo`;o00001ooo
ool2o`0000;ooooo6Ol000000ooooooo0000o`00000Iooooo`?o00002_ooool2o`0003Wooooo000L
ooooo`03o`000?oooooooooo03cooooo0_l000000ooooooo0000o`000003ooooo`;o00001?ooool2
o`0000_ooooo0_l00006ooooo`;o00001?ooool2o`0000Kooooo0_l00003ooooo`;o000000?ooooo
o`000?l000001?l000000ooooooo0000o`000006o`0000Cooooo0ol00003ooooo`;o00001?ooool2
o`0000?ooooo0_l00008ooooo`;o00001oooool2o`0000?ooooo1?l0000:ooooo`?o00002_oooolI
o`0000gooooo0_l000001?oooooo0000o`000?l0001Aooooo`007?ooool2o`0003;ooooo0_l00002
ooooo`;o00004oooool2o`0000_ooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00003
oooooa?o00000_ooool2o`00013ooooo0_l00008ooooo`;o00000oooool2o`0000Gooooo0_l00000
1?oooooo0000o`000?l00002ooooo`;o00001oooool2o`000004ooooool0003o0000ooooo`;o0000
1OoooolEo`000004ooooool0003o0000o`0000cooooo0_l000001?oooooo0000o`000?l0000Goooo
o`;o00002Oooool2o`0002gooooo000Looooo`03o`000?oooooooooo037ooooo0_l00002ooooo`;o
00001?ooool2o`0000gooooo1?l0000<ooooo`;o00000oooool2o`0000Gooooo0_l00005ooooo`So
000000?oooooo`000?l000000_ooool6o`000003ooooool0003o000000;o00000_ooool3o`0000?o
oooo0ol0000;ooooo`;o00001_ooool2o`0000?ooooo0ol00004ooooo`;o000000Coooooo`000?l0
003o00000_ooool3o`0000Wooooo0_l000001?oooooo0000o`000?l00003ooooo`ko000000?ooooo
o`000?l000001Ol00002ooooo`;o00001Oooool2o`0002;ooooo0_l00009ooooo`;o0000;Oooool0
01cooooo00?o0000ooooooooool0>oooool2o`0000oooooo0ol0000;ooooo`;o00000oooool3o`00
00Gooooo0_l00004ooooo`Ko00000oooool2o`000003ooooool0003o000000Go00001_ooool6o`00
0004ooooool0003o0000o`0000_ooooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo0ol0000=
ooooo`;o00003Oooool2o`0000?ooooo5_l00009ooooo`;o0000G?ooool001cooooo00?o0000oooo
ooooool0COooool4o`0000?ooooo0_l00002ooooo`;o00001?ooool6o`000003ooooool0003o0000
00;o00001Oooool2o`000003ooooool0003o000000Kooooo2_l00003ooooo`Ko000000?oooooo`00
0?l000001?l00002ooooo`;o00001Oooool2o`000003ooooool0003o000000Oooooo0_l0000Ooooo
o`;o00000_oooolBo`000003ooooool0003o000000;o0000IOooool001cooooo00?o0000oooooooo
ool0Aoooool3o`0000Cooooo0ol00003ooooo`Ko00001?ooool2o`0000;ooooo0_l000000ooooooo
0000o`00000:ooooo`;o00000_ooool2o`0000?ooooo2Ol000000ooooooo0000o`000002ooooo`Co
00000oooool4o`0000;ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00002?ooool2o`00
00Cooooo0_l0000?ooooo`;o00002_oooolFo`0000?ooooo1?l00003ooooo`;o00000_ooool2o`00
00Gooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`17ooooo`Ko000000?oooooo`000?l0
00001_ooool2o`0001gooooo0_l00003ooooo`;o000000?oooooo`000?l000001?l000000ooooooo
0000o`000002ooooo`?o00001Oooool2o`0000Kooooo0ol00009ooooo`Co00001?ooool2o`000003
ooooool0003o000000cooooo0_l000000ooooooo0000o`000004ooooo`;o00000ooooolEo`0000Co
oooo0_l00002ooooo`?o00000_ooool2o`0000Gooooo0_l0000Gooooo`;o0000>_ooool001cooooo
00?o0000ooooooooool0>_ooool2o`0000kooooo0ol0000?ooooo`;o00004?ooool2o`0000[ooooo
0ol00002ooooo`Co00000_ooool2o`0000Sooooo0_l0000Cooooo`;o00002Oooool2o`0000oooooo
0_l00004ooooo`;o00001Oooool4o`0000;ooooo2Ol00002ooooo`;o00000oooool2o`0000?ooooo
0_l0000Sooooo`?o0000>Oooool001cooooo00?o0000ooooooooool0:?ooool2o`0000kooooo1Ol0
000<ooooo`Co00003Oooool4o`00013ooooo0_l0000:ooooo`Co000000?oooooo`000?l000000_l0
0002ooooo`;o00001_ooool4o`0000oooooo0_l00006ooooo`;o00004_ooool2o`00017ooooo0_l0
0002ooooo`Co000000Coooooo`000?l0003o00000_ooool2o`0000Cooooo0_l0000<ooooo`;o0000
1?ooool2o`0001Gooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`0Xooooo`;o00001_oo
ool2o`0000Kooooo0_l000000ooooooo0000o`000007ooooo`;o00000oooool4o`0000Kooooo1?l0
0003ooooo`;o00006oooool2o`0000;ooooo0ol000001?oooooo0000o`000?l00004ooooo`;o0000
1Oooool2o`00017ooooo0_l00006ooooo`;o00004_ooool2o`0000kooooo0_l00006ooooo`?o0000
00?oooooo`000?l000000oooool2o`0001;ooooo1?l00002ooooo`;o0000D?ooool001cooooo00?o
0000ooooooooool09_ooool2o`0000Sooooo0_l00006ooooo`;o00002_ooool2o`0000Oooooo0_l0
0004ooooo`Co00007Oooool2o`000004ooooool0003o0000ooooo`Co000000?oooooo`000?l00000
1Oooool2o`0000_ooooo0_l00008ooooo`;o0000;Oooool2o`0000;ooooo0_l00009ooooo`;o0000
1?ooool2o`0000?ooooo0_l00003ooooo`;o00001?ooool4o`0000_ooooo0_l0000<ooooo`;o0000
>Oooool001cooooo00?o0000ooooooooool09_ooool2o`0002Cooooo0ol0000Eooooo`;o00003_oo
ool2o`0000Cooooo0_l000001?oooooo0000o`000?l0000;ooooo`Co00001?ooool2o`0000Sooooo
0_l00003ooooo`;o000000Coooooo`000?l0003o00002Oooool2o`0000Cooooo0_l00006ooooo`;o
00003oooool4o`0000Oooooo0_l00004ooooo`;o00000oooool2o`0000?ooooo0_l00004ooooo`;o
00000oooool2o`0000Cooooo0_l00002ooooo`Co00002_ooool2o`0003Wooooo000Looooo`03o`00
0?oooooooooo03Kooooo0ol0000Cooooo`Ko00002oooool2o`0000Gooooo0_l0000:ooooo`;o0000
2oooool3o`0000?ooooo1?l00003ooooo`Go00000_ooool2o`0000Gooooo0_l00005ooooo`;o0000
00Coooooo`000?l0003ooooo1?l000000ooooooo0000o`000005ooooo`;o00001?ooool2o`0000Ko
oooo0_l0000?ooooo`Co000000Coooooo`000?l0003ooooo1?l0000Aooooo`;o00001oooool2o`00
00Cooooo0_l00002ooooo`Co00005?ooool2o`0002oooooo000Looooo`03o`000?oooooooooo03Ko
oooo0ol0000Eooooo`Co00002oooool2o`00017ooooo0_l000000ooooooo0000o`00000>ooooo`Ko
000000?oooooo`000?l000000_l00003ooooo`Co00000oooool2o`0000Gooooo0_l00006ooooo`;o
000000?oooooo`000?l000001?l0000?ooooo`;o00002Oooool2o`0000Cooooo0_l00003ooooo`;o
000000?oooooo`000?l000000ol00007ooooo`;o00001?ooool2o`000003ooooool0003o000002Wo
oooo0_l0000_ooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00004_ooool2o`0000Cooooo
0_l0000Aooooo`?o00002?ooool2o`0000;ooooo0_l0000Booooo`;o00000_ooool2o`0000Kooooo
0_l00009ooooo`;o00003?ooool4o`0000?ooooo0_l0000:ooooo`;o00002Oooool2o`000004oooo
ool0003o0000ooooo`?o00000oooool2o`0000?ooooo0_l00007ooooo`Co00000_ooool2o`0000_o
oooo0_l0000Nooooo`;o0000<?ooool001cooooo00?o0000ooooooooool0;oooool2o`0000Kooooo
0_l0000Booooo`;o00001?ooool2o`00013ooooo1?l00008ooooo`;o00008oooool2o`0000Sooooo
0_l00006ooooo`;o00001oooool2o`0000;ooooo0_l0000<ooooo`;o000000Coooooo`000?l0003o
00000oooool2o`000004ooooool0003o0000ooooo`?o00000oooool2o`0000Wooooo0_l000000ooo
oooo0000o`000002o`0000Oooooo0_l00006ooooo`;o00007_ooool2o`00033ooooo000Looooo`03
o`000?oooooooooo02oooooo0_l0000Hooooo`;o00000_ooool2o`0000?ooooo0_l0000?ooooo`;o
00002oooool2o`00013ooooo0_l00004ooooo`;o00002_ooool2o`0000Sooooo0ol000000ooooooo
0000o`000002ooooo`;o00001oooool2o`0000Sooooo0_l00004ooooo`Co000000Coooooo`000?l0
003o00000oooool2o`0000Gooooo0_l00006ooooo`;o00001_ooool2o`000003ooooool0003o0000
00?ooooo0_l00004ooooo`;o0000F?ooool001cooooo0_l0000`ooooo`;o00001?ooool3o`0000Oo
oooo0ol00007ooooo`;o000000Coooooo`000?l0003o00000oooool3o`000003ooooool0003o0000
00Cooooo0_l00005ooooo`;o00002oooool2o`0000Sooooo0_l000000ooooooo0000o`000003oooo
o`;o00001?ooool2o`0000;ooooo0_l00009ooooo`;o00001_ooool2o`000003ooooool0003o0000
00gooooo0_l00006ooooo`;o00001?ooool4o`0000kooooo0_l00006ooooo`;o00002Oooool2o`00
00?ooooo0_l0001Nooooo`007?ooool00ol0003oooooooooo`0eooooo`?o00001oooool3o`0000[o
oooo0_l00005ooooo`;o000000?oooooo`000?l000001?ooool3o`0000?ooooo0_l00005ooooo`;o
00002Oooool2o`0000Cooooo0_l000000ooooooo0000o`00000=ooooo`;o00002Oooool2o`0000ko
oooo0_l00003ooooo`;o00000oooool2o`0000kooooo0_l0000Nooooo`;o00001Oooool2o`0005oo
oooo000Looooo`03o`000?oooooooooo02Gooooo0_l0000<ooooo`Go00009Oooool4o`000003oooo
ool0003o000000Gooooo0_l00009ooooo`;o0000<Oooool2o`0000?ooooo0_l0000cooooo`;o0000
1Oooool2o`0001Oooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`0Uooooo`;o00003?oo
ool2o`000003ooooool0003o000000;ooooo0_l00006ooooo`;o00003oooool2o`0000[ooooo0_l0
000@ooooo`;o00001oooool2o`0001oooooo0_l0000:ooooo`;o00007Oooool2o`0001Oooooo0_l0
000:ooooo`;o00000oooool2o`0000oooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`0c
ooooo`;o00000_ooool2o`000003ooooool0003o000000Kooooo0_l00009ooooo`;o00001?ooool2
o`0000;ooooo0_l00007ooooo`;o00003oooool2o`0000;ooooo0_l00003ooooo`;o00007oooool2
o`0000Oooooo0_l000000ooooooo0000o`00000=ooooo`;o00003_ooool2o`0001Oooooo1?l00000
0ooooooo0000o`000005ooooo`;o00000oooool2o`0005Oooooo000Looooo`03o`000?oooooooooo
03Oooooo0_l00002ooooo`?o00003oooool2o`0000Sooooo0_l00007ooooo`;o00004oooool4o`00
0003ooooool0003o000000Kooooo0_l0000Eooooo`?o00000_ooool2o`0000Cooooo0_l0000@oooo
o`;o00002oooool2o`000004ooooool0003o0000ooooo`;o00005_ooool2o`000003ooooool0003o
000001cooooo0_l00005ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0=oooool2o`00
00;ooooo0ol0000Mooooo`;o00006_ooool2o`000004ooooool0003o0000o`0000Gooooo0_l0000E
ooooo`?o00000_ooool2o`0000Cooooo0_l00003ooooo`Co00004_ooool2o`0000;ooooo0_l00000
0ooooooo0000o`000003o`0000Gooooo0_l00005ooooo`;o00000_ooool2o`00013ooooo1Ol0000<
ooooo`;o00000_ooool2o`0000Gooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0aoooo
o`;o0000:?ooool2o`0001Oooooo0_l00004ooooo`Go00007Oooool4o`0000Kooooo1ol0000=oooo
o`?o00000_ooool4o`0000Cooooo0_l00007ooooo`;o00001Oooool3o`000003ooooool0003o0000
00oooooo2_l00008ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0<Oooool2o`0000[o
oooo0_l0000]ooooo`;o00001_ooool2o`0000Gooooo1?l0000Iooooo`;o00000_ooool4o`0000Ko
oooo1?l0000@ooooo`?o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o00003oooool2o`00
00oooooo0_l000000ooooooo0000o`000009o`00027ooooo0_l0000_ooooo`007?ooool00ol0003o
ooooooooo`0aooooo`;o00001_ooool2o`0000;ooooo0_l00002ooooo`;o0000:?ooool5o`0000_o
oooo0ol0000Jooooo`;o000000?oooooo`000?l000002Oooool2o`0000gooooo1Ol00004ooooo`?o
00000_ooool2o`0000_ooooo0_l0000Dooooo`;o000000?oooooo`000?l000003Ol0000Pooooo`;o
0000;oooool001cooooo00?o0000ooooooooool0>Oooool2o`0000;ooooo0ol000000ooooooo0000
o`000004ooooo`;o00008_ooool2o`000003ooooool0003o000000Gooooo0_l00003ooooo`Co0000
7Oooool3o`0000Oooooo0_l000000ooooooo0000o`000009ooooo`Oo00000_ooool2o`000003oooo
ool0003o000000Co00001?ooool2o`0000Gooooo0_l0000Dooooo`Co000000?oooooo`000?l00000
2ol0001Aooooo`007?ooool00ol0003oooooooooo`0looooo`Ko00001Oooool2o`0001oooooo0_l0
0009ooooo`Co00000oooool5o`0000;ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o0000
4_ooool2o`0000Oooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00003ooooo`Co0000
1Oooool2o`000003ooooool0003o000000Co00001?ooool2o`0000Kooooo0_l0000Eooooo`;o0000
00?oooooo`000?l000001ol000000ooooooo0000o`000003o`0004oooooo000Looooo`03o`000?oo
oooooooo03cooooo0_l00002ooooo`Co00009?ooool2o`0000Wooooo0_l00004ooooo`;o00000_oo
ool2o`0000;ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00005?ooool2o`0000Gooooo
0_l00003ooooo`;o00000_ooool2o`0001?ooooo0_l0000<ooooo`;o00006Oooool>o`0004oooooo
000Looooo`03o`000?oooooooooo04;ooooo0_l0000Wooooo`;o00003?ooool2o`0001Kooooo0_l0
0008ooooo`;o000000Coooooo`000?l0003o00004_ooool6o`0000[ooooo0_l00004ooooo`;o0000
7oooool?o`00053ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05
onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0hooooo`;o00000oooool2o`00
02cooooo0_l0000Booooo`;o00000oooool2o`0000Kooooo0_l00003ooooo`;o00001Oooool2o`00
0003ooooool0003o000000;ooooo0_l00004ooooo`;o00001_ooool2o`000003ooooool0003o0000
00co00001Oooool2o`0000Cooooo0_l0000=ooooo`;o00004?ooool?o`00053ooooo00001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_oo
ool00ol0003oooooooooo`0eooooo`;o000000Coooooo`000?l0003ooooo1?l0000;ooooo`;o0000
7?ooool2o`0000Wooooo0_l00009ooooo`?o00000oooool2o`000003ooooool0003o000000?ooooo
0_l0000:ooooo`;o000000?oooooo`000?l000002?ooool2o`0000Kooooo2_l000000ooooooo0000
o`000004o`000003ooooool0003o000001Oooooo0_l0000;ooooo`;o00001?ooool>o`000003oooo
ool0003o000004gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo03Gooooo0_l00004ooooo`;o0000
3Oooool2o`0001cooooo0_l00006ooooo`;o000000?oooooo`000?l000002Oooool3o`0000Kooooo
0_l0000Booooo`;o00002?ooool2o`0000Sooooo1?l000000ooooooo0000o`00000;o`0000kooooo
0_l0000Dooooo`;o00001OoooolAo`0004cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000>oooool2o`0002_ooooo
1?l00004ooooo`;o00002oooool4o`000003ooooool0003o000000?ooooo0_l00003ooooo`;o0000
00?oooooo`000?l000003Oooool5o`0000[ooooo4ol00004ooooo`;o00002Oooool2o`0000kooooo
0_l0000;oooooa7o0000C?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0??ooool2o`0002cooooo
0ol00003ooooo`;o00001Oooool4o`000003ooooool0003o000000?o000000?oooooo`000?l00000
0oooool2o`0000?ooooo0_l000000ooooooo0000o`00000=ooooo`Go00001_ooool2o`000003oooo
ool0003o000001;o00001?ooool4o`0001Oooooo0_l00009ooooo`oo000000?oooooo`000?l00000
4?ooool2o`0003_ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00?o
EEEEohN7Qoooool02?ooool00ol0003oooooooooo`0cooooo`?o00001_ooool2o`0002cooooo0ol0
0003ooooo`;o00001?ooool5o`000003ooooool0003o000000Gooooo0_l00003ooooo`?o00007?oo
oolIo`0000Cooooo1?l0000Rooooo`;o00001Oooool2o`000003ooooool0003o000000?o00004ooo
ool2o`0003_ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P0
2?ooool00ol0003oooooooooo`0cooooo`?o00000_ooool3o`0003_ooooo2Ol00002ooooo`[o0000
7?oooolKo`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000008Oooool2o`0000co
oooo0_l0000?ooooo`;o0000??ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<
c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo03Sooooo0ol00002ooooo`;o00001oooool2
o`0002Oooooo1?l00003ooooo`Wo00000_ooool:o`0000Kooooo0_l0000<ooooo`;o00001_oooolN
o`000004ooooool0003o0000ooooo`;o00002oooool2o`0001Cooooo1?l0000:ooooo`;o00003ooo
ool2o`0003cooooo000Looooo`03o`000?oooooooooo03Wooooo0_l00002ooooo`;o00001oooool2
o`0000;ooooo0_l000000ooooooo0000o`00000Pooooo`Co00000oooool4o`0000;ooooo3?l00000
0ooooooo0000o`000005ooooo`Go00001?ooool2o`000004ooooool0003o0000ooooo`;o00001?oo
oolOo`0001;ooooo0_l0000Fooooo`;o00001oooool2o`00053ooooo000Looooo`03o`000?oooooo
oooo03Wooooo0_l00004ooooo`;o00002Oooool2o`000003ooooool0003o000001Gooooo0_l0000?
oooooa?o000000?oooooo`000?l000001?l000000ooooooo0000o`000003o`000004ooooool0003o
0000ooooo`;o000000?oooooo`000?l000001_oooolNo`0001gooooo0_l0000Fooooo`;o00006?oo
ool2o`0003Kooooo000Looooo`03o`000?oooooooooo03Wooooo0_l00004ooooo`;o00008oooool2
o`0000[ooooo0_l00003ooooo`Co000000?oooooo`000?l000004ol000000ooooooo0000o`000003
o`000003ooooool0003o000000Cooooo0_l00006ooooob3o00000_ooool2o`0001Kooooo0ol0000`
ooooo`;o0000=_ooool001cooooo00?o0000ooooooooool0COooool2o`0001cooooo0_l00003oooo
o`;o00000oooool5o`000003ooooool0003o0000013o00001_ooool2o`0000Oooooo0_l00008oooo
o`Co000000?oooooo`000?l000006ol0000Fooooo`Co0000Ioooool001cooooo00?o0000oooooooo
ool0?oooool2o`0000Cooooo0_l00006ooooo`;o00007?ooool2o`0000Oooooo6Ol0000Hoooooa_o
00000oooool3o`0001[ooooo1_l0000Rooooo`;o0000?oooool001cooooo00?o0000ooooooooool0
?oooool2o`0000?ooooo1Ol0000Nooooo`;o00001Oooool2o`000003ooooool0003o000001[o0000
6?oooolKo`0000?ooooo0_l0000<ooooo`?o00001_ooool2o`0000Kooooo1?l00008ooooo`;o0000
0oooool2o`0001?ooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`14ooooo`;o000000?o
ooooo`000?l000006oooool2o`000003ooooool0003o000000Gooooo0_l000000ooooooo0000o`00
0009o`000003ooooool0003o000000go00006OoooolLo`00013ooooo0ol00006ooooo`;o00000_oo
ool2o`0000Cooooo0_l00008ooooo`;o00000oooool2o`0005Cooooo000Looooo`03o`000?oooooo
oooo04Sooooo0_l0000Jooooo`;o00003OoooolCo`000003ooooool0003o000000Go00000_ooool2
o`0000Kooooo0_l0000;ooooo`;o000000?oooooo`000?l000005ol0000Mooooo`;o00001?ooool4
o`0000Cooooo0_l0000:ooooo`;o00003Oooool2o`00043ooooo000Looooo`03o`000?oooooooooo
04?ooooo0_l00003ooooo`;o000000?oooooo`000?l000007Oooool4o`000004ooooool0003o0000
oooooaco00000_ooool2o`0000Kooooo1?l0000;ooooo`Wo000000?oooooo`000?l000003Ol0000J
ooooo`;o00001_ooool2o`0000;ooooo0_l00004ooooo`;o00002_ooool2o`0000gooooo0_l00010
ooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00001_ooool2o`0001gooooo1?l000000ooo
oooo0000o`00000:o`000003ooooool0003o0000017o000000?oooooo`000?l000001?ooool2o`00
00;ooooo0_l0000;oooooaSo00002oooool2o`000003ooooool0003o000000_ooooo0_l000000ooo
oooo0000o`000003ooooo`;o0000IOooool001cooooo00?o0000ooooooooool0F_ooool4o`00017o
oooo8ol00003ooooo`?o00001Oooool2o`0000Wooooo4ol0000?ooooo`;o000000?oooooo`000?l0
00002?ooool2o`000003ooooool0003o000000?o00005oooool3o`000003ooooool0003o000004go
oooo000Looooo`;o0000AOooool2o`0000Gooooo0_l0000=ooooo`Co00000oooool2o`0000gooooo
8_l00003ooooo`?o00001Oooool2o`0000Kooooo0_l000000ooooooo0000o`00000Ao`000004oooo
ool0003o0000o`0001Sooooo0_l000000ooooooo0000o`000002o`0001Sooooo0ol000000ooooooo
0000o`00001=ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00000_ooool2o`0000Gooooo
0_l000000ooooooo0000o`00000Aooooo`;o00003_oooolCo`000003ooooool0003o000000Oo0000
0oooool2o`0000?ooooo0_l0000=ooooo`Go000000?oooooo`000?l000004_l0000Aooooo`;o0000
00?oooooo`000?l000001oooool3o`0006[ooooo000Looooo`03o`000?oooooooooo043ooooo0_l0
0003ooooo`;o00001oooool2o`0001oooooo6?l00002ooooo`Go00000oooool4o`00017ooooo0_l0
0004ooooo`Wo00000_ooool7o`0000;ooooo0_l0000>ooooo`;o000000Coooooo`000?l0003ooooo
0_l00005ooooo`;o00004oooool2o`0000?ooooo0_l0001@ooooo`007?ooool00ol0003ooooooooo
o`0iooooo`;o00002_ooool3o`0000?ooooo1?l00008ooooo`;o00005_oooolGo`000004ooooool0
003o0000ooooo`Go00000oooool3o`0000Sooooo0_l00007ooooo`;o00000oooool4o`0000;ooooo
1?l000000ooooooo0000o`000002o`0000;ooooo0_l00002ooooo`;o00004Oooool2o`000003oooo
ool0003o000000;o00005Oooool2o`000003ooooool0003o000000?ooooo1?l0000;ooooo`;o0000
@Oooool001cooooo00?o0000ooooooooool0>Oooool2o`0000_ooooo0_l00003ooooo`Co00002?oo
ool4o`0000;ooooo0_l0000=ooooo`Co000000?oooooo`000?l000006Ol000000ooooooo0000o`00
0003ooooo`;o00001oooool4o`0000Oooooo0ol00002ooooo`?o00000oooool4o`000003ooooool0
003o000000Gooooo0_l0000Iooooo`;o00005Oooool2o`0000?ooooo0_l00003ooooo`;o00002ooo
ool2o`00047ooooo000Looooo`03o`000?oooooooooo04[ooooo1?l00009ooooo`Co000000?ooooo
o`000?l000000_l0000<ooooo`Co000000?oooooo`000?l000006ol00008ooooo`;o00000oooool3
o`0000Wooooo0_l00005ooooo`?o000000?oooooo`000?l000002Oooool2o`0000Kooooo0ol0000/
ooooo`;o00003?ooool2o`0004Gooooo000Looooo`03o`000?oooooooooo04[ooooo0_l0000:oooo
o`?o00000oooool4o`0000gooooo0_l00003oooooako00001_ooool3o`0000kooooo0_l00005oooo
o`Oo00004?ooool3o`00017ooooo0_l0000Gooooo`;o000000?oooooo`000?l000002oooool2o`00
04Gooooo000Looooo`03o`000?oooooooooo04[ooooo0_l0000:ooooo`;o00005Oooool2o`000004
ooooool0003o0000ooooo`?o00000_ooool<o`000003ooooool0003o000000?o00001?ooool2o`00
00?ooooo0_l00002ooooo`;o00003_ooool2o`0000Sooooo1?l0000Tooooo`;o000000?oooooo`00
0?l000001_ooool2o`0000cooooo0_l000000ooooooo0000o`00001Booooo`007?ooool00ol0003o
ooooooooo`1:ooooo`;o00005?ooool2o`0000kooooo7?l00007ooooo`;o00003_ooool2o`0000;o
oooo0_l0000Dooooo`Co00006oooool2o`0000Kooooo0_l0000Looooo`?o0000A?ooool001cooooo
00?o0000ooooooooool0G_ooool4o`0000Gooooo0_l00007oooooaco00004_ooool2o`0000?ooooo
0ol000000ooooooo0000o`00000Dooooo`Co000000?oooooo`000?l000001?ooool2o`0001Sooooo
0_l000001?oooooo0000o`000?l0000;ooooo`;o00003Oooool3o`0004Cooooo000Looooo`03o`00
0?oooooooooo05kooooo1?l00005ooooo`;o00001oooool2o`0000?ooooo5_l0000Cooooo`;o0000
1?ooool2o`0001cooooo0_l00004ooooo`;o00006?ooool2o`000004ooooool0003o0000o`0000_o
oooo0_l00008ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0Goooool4o`0000Cooooo
0_l00005ooooo`;o00001Oooool5o`0000;ooooo3ol00002ooooo`;o00008?ooool2o`0000cooooo
0_l00003ooooo`;o00007Oooool2o`0000Kooooo0_l00009ooooo`;o00001oooool2o`0004[ooooo
000Looooo`03o`000?oooooooooo05kooooo1Ol00004ooooo`;o00001Oooool5o`0000;ooooo1_l0
00000ooooooo0000o`00000;o`0000?ooooo0ol00008ooooo`;o00005_ooool2o`0000cooooo0_l0
0003ooooo`;o00002?ooool2o`0000Gooooo0_l000000ooooooo0000o`000009ooooo`;o00001_oo
ool2o`0000Oooooo1?l0001Cooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00004oooool5
o`0000gooooo0ol00003oooooa?o000000?oooooo`000?l000000_l00003ooooo`;o00001?ooool2
o`00023ooooo0_l00005ooooo`;o00001?ooool2o`0000Cooooo0_l00005ooooo`Go00002Oooool2
o`0000oooooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00009oooool2o`00
0003ooooool0003o0000013o00000oooool2o`0000Gooooo0_l00004ooooo`;o00008?ooool2o`00
00Gooooo0_l00004ooooo`;o00003Oooool2o`0000Sooooo1?l0001Vooooo`007?ooool00ol0003o
ooooooooo`1;ooooo`;o00006Oooool2o`0000[ooooo0_l000001?oooooo0000o`000?ooool8o`00
00?ooooo0ol0000Zooooo`;o00003_ooool2o`0001gooooo0_l00002ooooo`;o00002Oooool2o`00
05Wooooo000Looooo`;o0000AOooool2o`0000Gooooo0_l0000<ooooo`;o00002Oooool4o`0000co
oooo0ol00002ooooo`;o000000?oooooo`000?l000000_l00002ooooo`?o00000_ooool2o`0000So
oooo0_l00003ooooo`?o00001_ooool2o`0000?ooooo0_l0000:ooooo`;o00002_ooool2o`0000;o
oooo0_l0000<ooooo`;o00003?ooool2o`000003ooooool0003o000000;ooooo0ol00008ooooo`;o
0000FOooool001cooooo00?o0000ooooooooool0A?ooool2o`00013ooooo0_l000000ooooooo0000
o`000004ooooo`;o00000oooool2o`0000kooooo1?l000001?oooooo0000o`000?ooool5o`000004
ooooool0003o0000ooooo`Go00001oooool2o`0000?ooooo0ol00006ooooo`Co000000?oooooo`00
0?l000003Oooool2o`0000Oooooo0_l00006ooooo`;o00001oooool3o`0000cooooo0_l00003oooo
o`Ko0000H_ooool001cooooo00?o0000ooooooooool0E_ooool2o`0000Oooooo0_l00003ooooo`;o
00000oooool2o`0000Sooooo1_l00004ooooo`Co00001?ooool5o`0001Gooooo1?l000000ooooooo
0000o`00000=ooooo`Co00003Oooool2o`0000Oooooo1_l0000>ooooo`Ko00004_ooool2o`0004ko
oooo000Looooo`03o`000?oooooooooo057ooooo0_l00003ooooo`;o00003?ooool3o`0000;ooooo
0_l00008ooooo`So00001?ooool2o`0000?ooooo1?l00008ooooo`?o00003?ooool2o`0001Cooooo
0_l00002ooooo`;o00001_ooool2o`0000?ooooo0_l00005ooooo`Ko00003?ooool2o`0000;ooooo
0_l0000Dooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0DOooool2o`0000_ooooo0_l0
0005ooooo`Co00000oooool2o`0000Sooooo1Ol00004ooooo`;o00000oooool2o`0000[ooooo0ol0
000Kooooo`?o00001Oooool2o`000003ooooool0003o000000;o00001?ooool4o`000004ooooool0
003o0000ooooo`;o000000Coooooo`000?l0003o00004?ooool2o`000003ooooool0003o000006Go
oooo000Looooo`03o`000?oooooooooo05kooooo1?l00005ooooo`;o00000oooool2o`0000Sooooo
1?l0000Dooooo`Go00004oooool3o`0000;ooooo0_l000001?oooooo0000o`000?l00005ooooo`;o
00000oooool2o`0000Gooooo0ol000001?oooooo0000o`000?ooool2o`000003ooooool0003o0000
01Cooooo0_l00005ooooo`;o00001?ooool2o`0005Sooooo000Looooo`03o`000?oooooooooo063o
oooo0_l0000Dooooo`;o00001Oooool2o`0000Sooooo0_l00005ooooo`?o00003?ooool2o`0000Oo
oooo0ol00002ooooo`;o00000oooool2o`0000cooooo0_l00002ooooo`;o00003_ooool2o`0000Co
oooo0_l0000<ooooo`Ko00000oooool2o`0005Sooooo000Looooo`03o`000?oooooooooo05Oooooo
0_l00007ooooo`;o00001Oooool4o`0000_ooooo0_l00005ooooo`;o00002?ooool2o`0000;ooooo
0_l00007ooooo`;o00001oooool2o`0000?ooooo0_l00003ooooo`;o00001oooool2o`0000_ooooo
0ol00002ooooo`;o00003?ooool6o`0000;ooooo0_l0000<ooooo`?o000000?oooooo`000?l00000
GOooool001cooooo00?o0000ooooooooool0Eoooool2o`000004ooooool0003o0000ooooo`;o0000
00Coooooo`000?l0003o00001?ooool4o`0000Gooooo1_l0000Eooooo`;o00001oooool2o`0000co
oooo0_l00003ooooo`Co00004_ooool2o`00017ooooo1_l00004ooooo`?o00000_ooool2o`0006So
oooo000Looooo`03o`000?oooooooooo05Sooooo1?l000001?oooooo0000o`000?ooool5o`0000Ko
oooo0_l00003ooooo`Oo00001_ooool2o`00017ooooo0_l0000<ooooo`Co00001oooool2o`0000?o
oooo0_l0000Iooooo`;o00001oooool2o`0000Kooooo0ol00002ooooo`;o00001Oooool2o`00067o
oooo000Looooo`03o`000?oooooooooo05Sooooo0_l00009ooooo`;o00001_ooool2o`0000Sooooo
0_l00002ooooo`;o00000_ooool2o`00017ooooo0_l0000<ooooo`Co000000?oooooo`000?l00000
2Oooool2o`0000Kooooo0_l0000=ooooo`;o00000_ooool2o`0000Gooooo0_l0000Dooooo`;o0000
HOooool001cooooo00?o0000ooooooooool0Eoooool2o`0000?ooooo0_l00005ooooo`;o00002_oo
ool2o`0000Sooooo0_l00005ooooo`;o00008Oooool2o`000003ooooool0003o000000gooooo0ol0
000;ooooo`Co00002Oooool2o`00017ooooo0_l0001Tooooo`007?ooool00ol0003oooooooooo`1G
ooooo`;o00000oooool2o`0000Kooooo0_l00004ooooo`;o00000oooool2o`0000oooooo0_l00000
0ooooooo0000o`000002ooooo`;o00001Oooool4o`0000cooooo0ol00002ooooo`;o000000?ooooo
o`000?l000000_l000000ooooooo0000o`000007o`000003ooooool0003o000000cooooo1?l00003
ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Wooooo0_l00002ooooo`;o00001_ooool2
o`0005Sooooo000Looooo`03o`000?oooooooooo06Cooooo0_l00004ooooo`;o00000oooool4o`00
013ooooo0_l00002ooooo`;o00001Oooool4o`0000cooooo0ol00003ooooo`;o000000Goooooo`00
0?l0003o0000ooooo`09o`0000oooooo0_l00003ooooo`Co000000Coooooo`000?l0003ooooo0_l0
0006ooooo`?o00001_ooool4o`0000;ooooo0_l00006ooooo`;o0000F?ooool001cooooo00?o0000
ooooooooool0Doooool2o`0001?ooooo0ol00005ooooo`?o00001oooool2o`0000Oooooo0_l0000K
ooooo`;o00000_ooool2o`0001_ooooo0_l00005ooooo`Ko00000_ooool2o`0000Oooooo0_l00006
ooooo`Co00000_ooool2o`00063ooooo000Looooo`03o`000?oooooooooo05?ooooo0_l00006oooo
o`;o00002oooool3o`0000Oooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o0000
00Cooooo0_l0000Eooooo`;o00001?ooool2o`0000Kooooo0_l00008ooooo`;o000000?oooooo`00
0?l000000_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00006ooooo`Go0000Noooool0
01cooooo0_l0001Looooo`;o00005Oooool2o`0000;ooooo0_l000000ooooooo0000o`000002oooo
o`;o00002oooool2o`0000Gooooo1?l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00008oooo
o`;o000000?oooooo`000?l000001Ol000001?oooooo0000o`000?l00009ooooo`;o00004oooool2
o`0006Wooooo000Looooo`03o`000?oooooooooo06Sooooo0_l00003ooooo`;o00001?ooool2o`00
0004ooooool0003o0000ooooo`?o00003_ooool4o`0000?ooooo1_l000001?oooooo0000o`000?oo
ool2o`0000Cooooo0_l00005ooooo`;o00003_ooool2o`0000?ooooo0ol000000ooooooo0000o`00
0002ooooo`?o00005_ooool2o`0006Wooooo000Looooo`03o`000?oooooooooo06Sooooo0_l00003
ooooo`;o00001?ooool2o`000003ooooool0003o000000;ooooo0_l00006ooooo`Co00000_ooool2
o`000004ooooool0003o0000o`0000?ooooo0ol000001?oooooo0000o`000?ooool2o`000003oooo
ool0003o000000_ooooo0_l0000Cooooo`;o00000_ooool7o`0001[ooooo0_l0001Uooooo`007?oo
ool00ol0003oooooooooo`1Fooooo`;o00001Oooool3o`0000Gooooo0_l00003ooooo`;o00000_oo
ool4o`0000Oooooo0_l00006ooooo`Go00000_ooool2o`000003ooooool0003o000000?ooooo1?l0
00000ooooooo0000o`00000Eooooo`;o00005Oooool2o`0000Oooooo0_l0000Dooooo`;o0000IOoo
ool001cooooo00?o0000ooooooooool0E_ooool2o`0000Gooooo0ol00005ooooo`;o00000oooool2
o`0000;ooooo1?l00004ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o00000oooool2
o`0000Sooooo0_l00004ooooo`;o00001oooool2o`0000[ooooo2ol000000ooooooo0000o`000007
ooooo`;o00002_ooool2o`000003ooooool0003o000000Sooooo0_l00006ooooo`;o0000I_ooool0
01cooooo00?o0000ooooooooool0G_ooool2o`0001Kooooo1ol00009ooooo`;o00003_ooool2o`00
00Oooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000:o`00
00Kooooo0_l0000=ooooo`;o00001_ooool4o`0000Kooooo0_l0001Vooooo`007?ooool00ol0003o
ooooooooo`1Nooooo`;o00002Oooool2o`0000Kooooo0_l00005ooooo`Co00001_ooool2o`0000;o
oooo0_l0000@ooooo`;o000000Coooooo`000?l0003o00001Oooool2o`0000;ooooo0_l00009oooo
o`Go000000?oooooo`000?l000000oooool2o`0000Wooooo0_l0000=ooooo`?o0000Koooool001co
oooo00?o0000ooooooooool0JOooool2o`0000Kooooo0_l0000?ooooo`;o00000_ooool2o`00013o
oooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l0000>ooooo`;o00002Oooool2o`0000Co
oooo0_l00002ooooo`?o00003_ooool2o`0000cooooo0_l0001Qooooo`007?ooool00ol0003ooooo
ooooo`1aooooo`;o00002?ooool2o`0000Wooooo1?l00005ooooo`;o00001oooool2o`0000?ooooo
0_l00003ooooo`;o00000_ooool2o`0000;ooooo0_l00006ooooo`;o00003oooool6o`0001gooooo
0_l0001Qooooo`007?ooool00ol0003oooooooooo`1/ooooo`;o00003?ooool3o`0000Sooooo0_l0
00000ooooooo0000o`000005ooooo`Co00004oooool3o`000003ooooool0003o000000;o00001ooo
ool2o`0000gooooo1?l000000ooooooo0000o`00000;ooooo`;o0000LOooool001cooooo00?o0000
ooooooooool0Ioooool2o`000003ooooool0003o000000;o00003?ooool2o`0000?ooooo0_l00004
ooooo`;o00002_ooool2o`0000gooooo0_l00005ooooo`Oo00001oooool2o`0000gooooo1?l00000
0ooooooo0000o`000002ooooo`;o00001oooool2o`00077ooooo000Looooo`03o`000?oooooooooo
06Oooooo0_l000000ooooooo0000o`000002o`00017ooooo0_l0000@ooooo`;o00003Oooool2o`00
0004ooooool0003o0000ooooo`Ko00001Oooool2o`0000Kooooo0_l00006ooooo`Co00001Oooool2
o`000003ooooool0003o000000oooooo0_l0001Yooooo`007?ooool00ol0003oooooooooo`1Roooo
o`;o00002?ooool2o`0001Kooooo0_l00009ooooo`;o00003?ooool2o`0000Cooooo0_l000000ooo
oooo0000o`000005o`0000;ooooo1?l00006ooooo`;o00001_ooool6o`0000?ooooo0ol00002oooo
o`;o00001_ooool3o`0000Cooooo0_l0001Yooooo`007?ooool00ol0003oooooooooo`1Rooooo`;o
00008?ooool2o`0000Sooooo0ol00002ooooo`;o00000_ooool2o`0000Cooooo0_l00005ooooo`Go
00000_ooool2o`0000;ooooo1?l00008ooooo`;o00002?ooool2o`0000Cooooo0_l00002ooooo`;o
00001_ooool4o`0006kooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44oooo
o`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1[ooooo`;o00007oooool6
o`000003ooooool0003o000000;ooooo1?l00009ooooo`Go00000_ooool2o`0000;ooooo1?l00004
ooooo`;o00000_ooool2o`0000Sooooo0_l00005ooooo`Co00002Oooool2o`0000?ooooo0_l00008
ooooo`;o0000Goooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go
8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo06_ooooo0_l0000Oooooo`;o0000
0_ooool3o`0000?ooooo1_l00007ooooo`Co000000Coooooo`000?l0003ooooo0_l00002ooooo`?o
00001Oooool2o`0000;ooooo0_l0000;ooooo`;o00000_ooool4o`0000Oooooo0_l00005ooooo`;o
00002?ooool2o`0005oooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo08[ooooo0_l00003ooooo`Co
00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l000001?oooooo
0000o`000?ooool3o`000003ooooool0003o000000Oooooo0_l0000;ooooo`;o00003Oooool2o`00
073ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P06ooooo`?o0000R?ooool4o`0000?ooooo1Ol00002ooooo`;o00001oooool2o`00
00[ooooo0_l000000ooooooo0000o`000002ooooo`;o00001Oooool2o`0000?ooooo1?l0000<oooo
o`;o00000oooool2o`0007Cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wo
oooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo08Sooooo0_l00007oooo
o`Co000000?oooooo`000?l000001_ooool2o`000003ooooool0003o000000gooooo0_l00007oooo
o`_o00001Oooool2o`0000?ooooo0_l00003ooooo`;o0000M?ooool00003ooooool@413ooooo00;o
oooo00?o410@ooooooooool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000oooo
ooooool0Soooool2o`0000;ooooo0_l00009ooooo`;o000000Coooooo`000?l0003ooooo0_l00007
ooooo`;o000000?oooooo`000?l000002?ooool6o`0000;ooooo0_l00005ooooo`;o0000O_ooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo
00?o0000ooooooooool0I?ooool2o`0002Wooooo1?l0000Aooooo`;o00001oooool2o`0000;ooooo
0_l00007ooooo`;o00000_ooool2o`0001Gooooo0_l0001booooo`0000Koooooonk^k_lb<S;o0000
oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`1Toooo
o`;o00002Oooool2o`0001kooooo1?l0000Nooooo`;o00006?ooool2o`0000Sooooo0_l0001boooo
o`007?ooool00ol0003oooooooooo`1Tooooo`;o00002Oooool2o`0002cooooo0_l0000Booooo`;o
00002?ooool2o`0000kooooo0_l0001looooo`007?ooool00ol0003oooooooooo`1Vooooo`;o0000
3oooool2o`0002Cooooo0ol00002ooooo`Co00002Oooool4o`0000Sooooo0_l000001?oooooo0000
o`000?l00008ooooo`;o0000O_ooool001cooooo00?o0000ooooooooool0I_ooool2o`0000oooooo
0_l0000Jooooo`;o00002Oooool2o`0000;ooooo1?l00009ooooo`;o00003Oooool3o`0000Sooooo
0_l0001nooooo`007?ooool00ol0003oooooooooo`2Cooooo`;o0000]?ooool001cooooo00?o0000
ooooooooool0Noooool3o`0001Oooooo0_l0000Qooooo`;o0000Soooool001cooooo00?o0000oooo
ooooool0Noooool3o`0001Oooooo0_l0000Cooooo`;o00000oooool2o`0000Oooooo0_l000000ooo
oooo0000o`00002<ooooo`007?ooool00ol0003oooooooooo`2Qooooo`;o00001oooool2o`0000?o
oooo0_l0000:ooooo`;o0000S?ooool001cooooo00?o0000ooooooooool0O?ooool2o`0002?ooooo
0_l0000=ooooo`;o00003_ooool2o`0000Oooooo0_l0001nooooo`007?ooool00ol0003ooooooooo
o`1looooo`;o0000<_ooool2o`0000kooooo0_l00007ooooo`;o0000O_ooool001cooooo00?o0000
ooooooooool0Zoooool2o`0009cooooo000Looooo`03o`000?oooooooooo0:_ooooo0_l0002Loooo
o`007?ooool2o`000;gooooo0_l00003ooooo`;o00000_ooool2o`0008;ooooo000Looooo`03o`00
0?oooooooooo08Sooooo0_l0000?ooooo`;o00008?ooool3o`0000?ooooo1_l00022ooooo`007?oo
ool00ol0003oooooooooo`28ooooo`;o000000?oooooo`000?l000003?ooool2o`0000;ooooo0_l0
000Looooo`;o00001_ooool2o`0008Cooooo000Looooo`03o`000?oooooooooo08_ooooo0_l00002
ooooo`;o00003?ooool2o`0000Gooooo0_l00002ooooo`;o0000Woooool001cooooo00?o0000oooo
ooooool0Soooool2o`0001?ooooo0_l00002ooooo`;o0000Woooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Iooooo`;o00006Oooool2o`0009?ooooo
000Looooo`03o`000?oooooooooo09Wooooo0_l0000Iooooo`;o0000Toooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`25ooooo`;o0000`_ooool001cooooo00?o0000ooooooooool0QOooool2
o`000<;ooooo000Looooo`03o`000?oooooooooo09Gooooo0_l0002booooo`007?ooool00ol0003o
ooooooooo`2Eooooo`;o0000/_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`2Iooooo`;o0000[_ooool001cooooo00?o0000ooooooooool0VOooool2o`000:ko
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0X_oo
ool2o`000:Gooooo000Looooo`03o`000?oooooooooo0:;ooooo0_l0002Uooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001;ooooo1?l000000ol@413oooooooooo`03ooooo`03o`00
0?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo0ol0003ooooood[ooooo000Doooo
o`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`00
5?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_oo
ool001;ooooo00?oEEEEofIVI_l00000oooooomDooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00YOooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo01Gooooo
00Goc<c<ob4Q8Ol0003o8B4Qolc<c004ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool5o`00
093ooooo002Vooooo`05o`000?ooooooooooooooool000002Oooool6o`0000Wooooo00Go8B4QoiRH
V?ooooooV9RHob4Q8@07ooooo`09ogMgMolb<S;ooooooooooonHV9So8B4Qonk^k_ooooooA4A4093o
oooo002Vooooo`05o`000?ooooooooooooooool000006?ooool01Ol0003ooooooooooooooooo0000
00Sooooo00Oo0000oooooooooooooooooiRHV?lQ8B7ok^k^097ooooo002Vooooo`05o`000?oooooo
ooooooooool000002Oooool6o`0000Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P07ooooo`03ogMg
Molb<S;ooooo00?ooooo00?oV9RHob4Q8Oo^k^h0T?ooool00:Kooooo00Go0000ohN7QoooooooZJVY
o`00000Hooooo`05olc<c?l0003o0000o`000?o<c<`01?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?oMgMgofIVI_ooool0Soooool00:Gooooo00?o410@o`000?mgMgL00_l000000onHV9So
ooooooooo`0Fooooo`05oa0@4?nj^[[ooooookZj^_l@41001?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo08kooooo0033ooooo`05o`000?nj^[[ooooookZj^_l000001?ooool00ol0
003oooooooooo`04ooooo`05o`000?nj^[[ooooooiRHV?l@4100T?ooool00<?ooooo00GoZJVYoa0@
4?l0003o410@ojVYZ@04ooooo`Co00000oooool01OnHV9So410@o`000?lQ8B7oc<c<093ooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(858) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.35509 .65411 Mdot
.36874 .62504 Mdot
.68749 .47657 Mdot
.43333 .40985 Mdot
.41558 .53792 Mdot
.66892 .48875 Mdot
.52309 .64755 Mdot
.55803 .66075 Mdot
.65159 .49134 Mdot
.33241 .33616 Mdot
.56392 .63122 Mdot
.34159 .37396 Mdot
.52971 .63235 Mdot
.40636 .40875 Mdot
.77571 .30911 Mdot
.42643 .37412 Mdot
.40948 .61373 Mdot
.64486 .39265 Mdot
.34454 .45187 Mdot
.691 .53094 Mdot
.32755 .66911 Mdot
.40239 .40414 Mdot
.36027 .66137 Mdot
.40551 .40917 Mdot
.43672 .43489 Mdot
.38421 .64283 Mdot
.42017 .61579 Mdot
.42435 .4617 Mdot
.41471 .44081 Mdot
.57405 .62911 Mdot
.55111 .37478 Mdot
.65019 .21162 Mdot
.38752 .35787 Mdot
.18699 .58743 Mdot
.54837 .66269 Mdot
.38699 .23421 Mdot
.64922 .51885 Mdot
.53895 .61555 Mdot
.55928 .65898 Mdot
.516 .66192 Mdot
.53934 .61849 Mdot
.38658 .63503 Mdot
.5454 .67554 Mdot
.55951 .6834 Mdot
.41975 .38491 Mdot
.50297 .74288 Mdot
.51516 .22996 Mdot
.38706 .45289 Mdot
.36315 .61216 Mdot
.67944 .53697 Mdot
.27158 .69454 Mdot
.54929 .66924 Mdot
.75553 .62611 Mdot
.55782 .09385 Mdot
.52162 .62586 Mdot
.43128 .39502 Mdot
.66188 .51018 Mdot
.37938 .40772 Mdot
.39672 .41214 Mdot
.2799 .64322 Mdot
.41692 .46015 Mdot
.61575 .37286 Mdot
.33545 .66604 Mdot
.62574 .48344 Mdot
.66224 .49043 Mdot
.57114 .64539 Mdot
.40323 .61115 Mdot
.53187 .63916 Mdot
.42167 .48027 Mdot
.64466 .52385 Mdot
.38593 .45248 Mdot
.56367 .62464 Mdot
.34081 .63835 Mdot
.35798 .4273 Mdot
.53192 .77488 Mdot
.8175 .39554 Mdot
.65892 .37159 Mdot
.27954 .60938 Mdot
.35386 .56306 Mdot
.81166 .49127 Mdot
.40945 .42751 Mdot
.77023 .70716 Mdot
.78707 .3282 Mdot
.35838 .65427 Mdot
.3562 .49314 Mdot
.71932 .53199 Mdot
.36067 .39931 Mdot
.51886 .48116 Mdot
.45178 .45439 Mdot
.46714 .7965 Mdot
.64879 .49569 Mdot
.39209 .61705 Mdot
.43148 .40911 Mdot
.37933 .46373 Mdot
.25634 .52175 Mdot
.37427 .47503 Mdot
.44142 .44716 Mdot
.38462 .58549 Mdot
.56224 .64729 Mdot
.39476 .34882 Mdot
.59586 .63956 Mdot
.72779 .62287 Mdot
.39694 .38423 Mdot
.63636 .49856 Mdot
.36775 .59134 Mdot
.37358 .38133 Mdot
.51217 .64843 Mdot
.40337 .45038 Mdot
.54344 .67933 Mdot
.36684 .61979 Mdot
.37376 .4607 Mdot
.63401 .39623 Mdot
.58146 .79799 Mdot
.39886 .62031 Mdot
.72968 .69419 Mdot
.40139 .45923 Mdot
.3946 .39947 Mdot
.37142 .62544 Mdot
.68869 .50276 Mdot
.54019 .4347 Mdot
.37481 .59782 Mdot
.52479 .66291 Mdot
.41556 .65055 Mdot
.40664 .50361 Mdot
.65383 .47971 Mdot
.72792 .6143 Mdot
.73973 .60387 Mdot
.47629 .32403 Mdot
.36654 .38971 Mdot
.43988 .69216 Mdot
.6772 .49037 Mdot
.38747 .61993 Mdot
.53514 .63715 Mdot
.4398 .39395 Mdot
.40629 .64666 Mdot
.55467 .63383 Mdot
.61339 .3894 Mdot
.6736 .32869 Mdot
.36426 .6052 Mdot
.53026 .57529 Mdot
.49139 .64167 Mdot
.51232 .65883 Mdot
.21153 .63044 Mdot
.36633 .62964 Mdot
.64024 .35911 Mdot
.54951 .6388 Mdot
.57068 .28833 Mdot
.44774 .41473 Mdot
.43487 .32038 Mdot
.63671 .8191 Mdot
.26525 .69546 Mdot
.64176 .71149 Mdot
.64971 .35921 Mdot
.50457 .65084 Mdot
.42634 .4334 Mdot
.36648 .63885 Mdot
.37529 .63815 Mdot
.42828 .46809 Mdot
.44059 .43637 Mdot
.37381 .44884 Mdot
.38747 .46593 Mdot
.56841 .23713 Mdot
.37729 .45637 Mdot
.62733 .4438 Mdot
.40248 .63138 Mdot
.42841 .44717 Mdot
.69385 .50738 Mdot
.3874 .36591 Mdot
.55176 .61901 Mdot
.39119 .40611 Mdot
.44125 .42012 Mdot
.35059 .44087 Mdot
.51958 .62244 Mdot
.60568 .20494 Mdot
.61962 .81864 Mdot
.42645 .18792 Mdot
.67992 .70818 Mdot
.67577 .51234 Mdot
.3769 .38923 Mdot
.62922 .36389 Mdot
.28556 .40493 Mdot
.40032 .42346 Mdot
.31336 .76385 Mdot
.44484 .43057 Mdot
.19077 .48993 Mdot
.47004 .47803 Mdot
.42689 .18127 Mdot
.57938 .44947 Mdot
.41423 .44756 Mdot
.24901 .47644 Mdot
.25108 .36204 Mdot
.4511 .58973 Mdot
.53413 .62046 Mdot
.69268 .50168 Mdot
.65336 .51152 Mdot
.50535 .66402 Mdot
.43454 .36651 Mdot
.44682 .35644 Mdot
.34616 .35184 Mdot
.73476 .61343 Mdot
.33931 .64256 Mdot
.61178 .35066 Mdot
.34976 .62032 Mdot
.82056 .63974 Mdot
.43071 .7831 Mdot
.4869 .65181 Mdot
.64851 .33691 Mdot
.68798 .47992 Mdot
.73694 .61156 Mdot
.63568 .36482 Mdot
.3849 .43825 Mdot
.37049 .60885 Mdot
.19307 .4433 Mdot
.45439 .49497 Mdot
.18958 .40403 Mdot
.4008 .66062 Mdot
.54875 .46438 Mdot
.54818 .62811 Mdot
.70247 .52277 Mdot
.4069 .39585 Mdot
.3684 .43443 Mdot
.32965 .64109 Mdot
.38767 .45076 Mdot
.3914 .55406 Mdot
.44122 .41419 Mdot
.69761 .54475 Mdot
.65491 .39143 Mdot
.51257 .66761 Mdot
.47376 .32739 Mdot
.34983 .6602 Mdot
.646 .56018 Mdot
.67429 .53374 Mdot
.28863 .37184 Mdot
.56546 .62792 Mdot
.62959 .39568 Mdot
.68324 .52807 Mdot
.62621 .3393 Mdot
.35786 .38973 Mdot
.64845 .52033 Mdot
.63444 .34672 Mdot
.59936 .23036 Mdot
.4232 .38353 Mdot
.58929 .25938 Mdot
.5291 .64989 Mdot
.41262 .65617 Mdot
.41934 .45899 Mdot
.73366 .60007 Mdot
.34816 .39092 Mdot
.62357 .67967 Mdot
.75594 .61962 Mdot
.74822 .63311 Mdot
.8086 .4479 Mdot
.64255 .38755 Mdot
.59933 .74621 Mdot
.39697 .71371 Mdot
.40248 .60878 Mdot
.42916 .39908 Mdot
.50106 .16125 Mdot
.54932 .63814 Mdot
.38716 .43567 Mdot
.71303 .53743 Mdot
.54634 .64101 Mdot
.37433 .40618 Mdot
.50928 .63396 Mdot
.37033 .63706 Mdot
.75576 .52093 Mdot
.41676 .62673 Mdot
.42957 .3887 Mdot
.51509 .64802 Mdot
.67263 .52625 Mdot
.38159 .6466 Mdot
.40156 .44685 Mdot
.39865 .39397 Mdot
.73828 .62037 Mdot
.42108 .44862 Mdot
.5115 .16786 Mdot
.40597 .46523 Mdot
.65603 .46704 Mdot
.38562 .47756 Mdot
.27545 .73852 Mdot
.68898 .38123 Mdot
.39684 .60803 Mdot
.75078 .62981 Mdot
.65501 .49586 Mdot
.77127 .45271 Mdot
.48688 .57692 Mdot
.40749 .43896 Mdot
.74267 .62904 Mdot
.55921 .42412 Mdot
.57868 .63353 Mdot
.37126 .47759 Mdot
.47039 .77926 Mdot
.6924 .52404 Mdot
.73741 .61409 Mdot
.34007 .45624 Mdot
.36735 .59111 Mdot
.4345 .41156 Mdot
.66346 .5286 Mdot
.417 .64876 Mdot
.39039 .37248 Mdot
.45389 .2394 Mdot
.74965 .61074 Mdot
.52861 .64847 Mdot
.47846 .41675 Mdot
.37879 .45419 Mdot
.66016 .51815 Mdot
.36893 .66713 Mdot
.54235 .66219 Mdot
.39233 .63799 Mdot
.22018 .39572 Mdot
.67183 .72072 Mdot
.53457 .21991 Mdot
.64829 .33513 Mdot
.64721 .64033 Mdot
.40102 .19386 Mdot
.6129 .75663 Mdot
.52176 .30611 Mdot
.27516 .26966 Mdot
.69006 .51794 Mdot
.66727 .34705 Mdot
.6594 .50043 Mdot
.42419 .4193 Mdot
.66485 .4883 Mdot
.42677 .17662 Mdot
.44583 .42828 Mdot
.67137 .51414 Mdot
.74543 .46495 Mdot
.43512 .44786 Mdot
.40179 .62239 Mdot
.75593 .29889 Mdot
.48567 .81938 Mdot
.34617 .74116 Mdot
.68341 .51067 Mdot
.30412 .645 Mdot
.42779 .45838 Mdot
.38251 .36167 Mdot
.36678 .64459 Mdot
.38686 .48049 Mdot
.60917 .35543 Mdot
.62259 .339 Mdot
.46497 .33543 Mdot
.70705 .74293 Mdot
.39885 .34678 Mdot
.37808 .64746 Mdot
.34807 .52469 Mdot
.52711 .7722 Mdot
.71916 .60846 Mdot
.55863 .60376 Mdot
.61917 .21504 Mdot
.43851 .36168 Mdot
.52028 .57928 Mdot
.4932 .77941 Mdot
.37943 .61095 Mdot
.55288 .19653 Mdot
.52684 .6249 Mdot
.2774 .46963 Mdot
.20379 .54736 Mdot
.37419 .43637 Mdot
.56857 .63637 Mdot
.36654 .35406 Mdot
.4308 .79822 Mdot
.60313 .28611 Mdot
.83926 .54687 Mdot
.42284 .38497 Mdot
.58502 .75046 Mdot
.39389 .40242 Mdot
.51081 .38177 Mdot
.40545 .46598 Mdot
.39155 .64417 Mdot
.31131 .37249 Mdot
.49002 .53211 Mdot
.68162 .77749 Mdot
.41494 .78034 Mdot
.64789 .35354 Mdot
.39894 .39594 Mdot
.37247 .43494 Mdot
.63826 .38549 Mdot
.38051 .6589 Mdot
.40041 .46511 Mdot
.43512 .27696 Mdot
.37479 .44606 Mdot
.54615 .61602 Mdot
.54668 .39148 Mdot
.35412 .58195 Mdot
.36304 .45608 Mdot
.41511 .61714 Mdot
.51548 .62713 Mdot
.57089 .64899 Mdot
.42327 .48712 Mdot
.50472 .64429 Mdot
.43577 .40989 Mdot
.5765 .34167 Mdot
.35626 .64246 Mdot
.43867 .51252 Mdot
.38376 .66112 Mdot
.32545 .59612 Mdot
.5081 .64299 Mdot
.73043 .60315 Mdot
.44811 .64889 Mdot
.52532 .62873 Mdot
.3301 .73124 Mdot
.37547 .34032 Mdot
.33889 .40137 Mdot
.40301 .78942 Mdot
.68404 .51662 Mdot
.7335 .6061 Mdot
.51611 .65281 Mdot
.37668 .45274 Mdot
.35 .45242 Mdot
.5506 .61214 Mdot
.28085 .52999 Mdot
.7659 .44007 Mdot
.43113 .45823 Mdot
.38849 .65012 Mdot
.38941 .62195 Mdot
.37782 .37355 Mdot
.40034 .43858 Mdot
.66531 .46906 Mdot
.75218 .62104 Mdot
.72432 .62442 Mdot
.73953 .60458 Mdot
.70956 .51841 Mdot
.52959 .71558 Mdot
.51464 .66104 Mdot
.46484 .70015 Mdot
.61271 .67359 Mdot
.45325 .48819 Mdot
.66481 .52126 Mdot
.36894 .42228 Mdot
.42104 .40261 Mdot
.54142 .66181 Mdot
.66624 .66976 Mdot
.36945 .4999 Mdot
.35482 .62321 Mdot
.50472 .64095 Mdot
.4076 .34197 Mdot
.50556 .68931 Mdot
.61658 .35252 Mdot
.34551 .74416 Mdot
.56836 .63033 Mdot
.38918 .6106 Mdot
.53651 .61025 Mdot
.37218 .43921 Mdot
.44796 .44509 Mdot
.37396 .61908 Mdot
.64746 .38266 Mdot
.37627 .48942 Mdot
.37414 .40431 Mdot
.40359 .84663 Mdot
.53658 .7739 Mdot
.55254 .59173 Mdot
.42046 .43827 Mdot
.34454 .44134 Mdot
.64741 .34578 Mdot
.37665 .44482 Mdot
.40117 .39226 Mdot
.58779 .80078 Mdot
.59676 .60973 Mdot
.6325 .40313 Mdot
.27898 .46647 Mdot
.40301 .65831 Mdot
.55182 .17806 Mdot
.72956 .62701 Mdot
.57622 .65937 Mdot
.75106 .52837 Mdot
.74192 .61143 Mdot
.62963 .65995 Mdot
.55444 .18828 Mdot
.73768 .60477 Mdot
.70658 .56342 Mdot
.31545 .43635 Mdot
.43548 .45834 Mdot
.3871 .40316 Mdot
.62552 .36059 Mdot
.36655 .63195 Mdot
.56575 .45594 Mdot
.65597 .28138 Mdot
.3999 .40232 Mdot
.35368 .68661 Mdot
.62329 .23318 Mdot
.74041 .61805 Mdot
.61291 .37942 Mdot
.59996 .36873 Mdot
.39134 .39891 Mdot
.61994 .77976 Mdot
.38231 .64362 Mdot
.40172 .44638 Mdot
.36558 .45125 Mdot
.6815 .51401 Mdot
.38094 .60638 Mdot
.67036 .53359 Mdot
.75417 .61467 Mdot
.27687 .30344 Mdot
.36617 .82614 Mdot
.54355 .65882 Mdot
.45979 .19074 Mdot
.57804 .64323 Mdot
.83088 .49056 Mdot
.74591 .6109 Mdot
.40401 .42636 Mdot
.34629 .65693 Mdot
.40201 .45154 Mdot
.38266 .4301 Mdot
.38329 .43769 Mdot
.37368 .34339 Mdot
.30851 .75978 Mdot
.63194 .37517 Mdot
.43213 .50076 Mdot
.64536 .47342 Mdot
.49093 .17731 Mdot
.75681 .3196 Mdot
.36446 .42072 Mdot
.38893 .39541 Mdot
.40651 .63134 Mdot
.42255 .47204 Mdot
.57424 .62227 Mdot
.36693 .66735 Mdot
.34743 .43369 Mdot
.54024 .19785 Mdot
.39681 .46476 Mdot
.39846 .20142 Mdot
.54004 .60967 Mdot
.33658 .73252 Mdot
.43112 .49854 Mdot
.73557 .60326 Mdot
.73394 .60582 Mdot
.71971 .62521 Mdot
.56872 .61129 Mdot
.66611 .51682 Mdot
.73 .32042 Mdot
.42652 .36607 Mdot
.42941 .43243 Mdot
.34557 .44571 Mdot
.70612 .48651 Mdot
.51623 .47478 Mdot
.6224 .72869 Mdot
.39992 .34105 Mdot
.66501 .47268 Mdot
.4088 .66167 Mdot
.74932 .66785 Mdot
.3665 .66635 Mdot
.635 .40304 Mdot
.56066 .6277 Mdot
.61175 .35592 Mdot
.30376 .71722 Mdot
.36756 .62203 Mdot
.33115 .63144 Mdot
.67429 .51366 Mdot
.55004 .49325 Mdot
.51102 .10994 Mdot
.63437 .51219 Mdot
.4681 .29824 Mdot
.36898 .64949 Mdot
.35644 .44428 Mdot
.5585 .41234 Mdot
.54443 .49381 Mdot
.67028 .50506 Mdot
.41024 .41845 Mdot
.67799 .76048 Mdot
.66913 .46991 Mdot
.36781 .4757 Mdot
.6824 .49054 Mdot
.54773 .62035 Mdot
.68047 .49211 Mdot
.35953 .66933 Mdot
.37631 .38253 Mdot
.54693 .10353 Mdot
.5887 .51652 Mdot
.41175 .45966 Mdot
.50487 .64058 Mdot
.40407 .27181 Mdot
.37977 .42248 Mdot
.60598 .36134 Mdot
.65558 .47736 Mdot
.75238 .40757 Mdot
.42327 .46049 Mdot
.67648 .49787 Mdot
.35459 .65738 Mdot
.58817 .63081 Mdot
.81452 .4432 Mdot
.72466 .61196 Mdot
.36235 .63982 Mdot
.75935 .6364 Mdot
.51712 .61091 Mdot
.35467 .45655 Mdot
.36897 .45157 Mdot
.39826 .63929 Mdot
.76428 .56893 Mdot
.40351 .47481 Mdot
.4094 .42727 Mdot
.69599 .48849 Mdot
.67902 .46475 Mdot
.76654 .53952 Mdot
.68809 .51929 Mdot
.35173 .46343 Mdot
.39761 .63917 Mdot
.42496 .40786 Mdot
.40202 .61862 Mdot
.42999 .40093 Mdot
.42763 .65432 Mdot
.35887 .65239 Mdot
.69188 .72671 Mdot
.41836 .41181 Mdot
.47845 .44859 Mdot
.38154 .43394 Mdot
.3822 .45024 Mdot
.64378 .48012 Mdot
.63003 .384 Mdot
.46184 .43425 Mdot
.61174 .51728 Mdot
.6103 .38002 Mdot
.23018 .39314 Mdot
.68398 .5128 Mdot
.62 .35853 Mdot
.59291 .25249 Mdot
.74698 .63217 Mdot
.62653 .36994 Mdot
.74768 .3095 Mdot
.54307 .6599 Mdot
.40103 .66424 Mdot
.43545 .44693 Mdot
.25825 .29497 Mdot
.56288 .35298 Mdot
.74189 .62502 Mdot
.40826 .46268 Mdot
.37169 .42133 Mdot
.38311 .59079 Mdot
.80313 .66693 Mdot
.68625 .47352 Mdot
.42935 .42102 Mdot
.41322 .62356 Mdot
.6708 .80344 Mdot
.63813 .48888 Mdot
.62629 .36627 Mdot
.54187 .61251 Mdot
.41385 .5956 Mdot
.72385 .61239 Mdot
.57981 .63084 Mdot
.73571 .53297 Mdot
.31333 .7288 Mdot
.39926 .46048 Mdot
.65896 .52178 Mdot
.26837 .70387 Mdot
.41895 .35725 Mdot
.52009 .5913 Mdot
.43688 .33461 Mdot
.38272 .61126 Mdot
.54762 .61277 Mdot
.62695 .34299 Mdot
.36571 .66879 Mdot
.38073 .65737 Mdot
.5487 .66534 Mdot
.70954 .47678 Mdot
.54734 .46939 Mdot
.55548 .61726 Mdot
.48004 .79445 Mdot
.20289 .42832 Mdot
.7482 .62739 Mdot
.62007 .388 Mdot
.17111 .52365 Mdot
.38722 .6354 Mdot
.61641 .21307 Mdot
.29283 .73305 Mdot
.44111 .44766 Mdot
.63239 .35153 Mdot
.5738 .70701 Mdot
.71379 .30577 Mdot
.54303 .64403 Mdot
.48733 .51544 Mdot
.60325 .38578 Mdot
.42163 .46619 Mdot
.32364 .69378 Mdot
.41757 .41986 Mdot
.55572 .6274 Mdot
.34882 .57499 Mdot
.39149 .61104 Mdot
.51111 .61496 Mdot
.33958 .74314 Mdot
.41931 .40026 Mdot
.41471 .41601 Mdot
.53156 .36278 Mdot
.36812 .60934 Mdot
.72262 .6204 Mdot
.40777 .44857 Mdot
.38128 .40632 Mdot
.35367 .45005 Mdot
.46474 .38177 Mdot
.59674 .7843 Mdot
.42812 .41918 Mdot
.69427 .5382 Mdot
.36429 .37267 Mdot
.41505 .41074 Mdot
.41044 .61179 Mdot
.36144 .81687 Mdot
.74031 .60163 Mdot
.38834 .40647 Mdot
.39704 .4625 Mdot
.54297 .66477 Mdot
.55672 .44443 Mdot
.54092 .5003 Mdot
.63792 .51245 Mdot
.53684 .28662 Mdot
.37189 .3442 Mdot
.40442 .65233 Mdot
.62288 .39707 Mdot
.35508 .40868 Mdot
.40953 .64008 Mdot
.40592 .3659 Mdot
.67024 .47188 Mdot
.75031 .62435 Mdot
.37906 .74451 Mdot
.62022 .37034 Mdot
.57824 .39939 Mdot
.45851 .71726 Mdot
.69383 .50097 Mdot
.43227 .43488 Mdot
.57895 .65243 Mdot
.64456 .51927 Mdot
.73707 .62177 Mdot
.36581 .49141 Mdot
.37518 .64137 Mdot
.39589 .61899 Mdot
.48444 .34597 Mdot
.61522 .49538 Mdot
.51052 .84931 Mdot
.54926 .621 Mdot
.35536 .38744 Mdot
.41514 .70649 Mdot
.39709 .61921 Mdot
.48084 .3407 Mdot
.6187 .35939 Mdot
.54128 .64546 Mdot
.71566 .61018 Mdot
.40847 .63732 Mdot
.36655 .60618 Mdot
.41431 .37912 Mdot
.36484 .40483 Mdot
.51414 .30886 Mdot
.46509 .33421 Mdot
.52386 .62138 Mdot
.63097 .38996 Mdot
.65836 .53428 Mdot
.42175 .42349 Mdot
.35862 .6561 Mdot
.19631 .46271 Mdot
.38809 .46269 Mdot
.66514 .46852 Mdot
.38105 .61339 Mdot
.63986 .38585 Mdot
.60647 .36936 Mdot
.3819 .44966 Mdot
.28344 .62694 Mdot
.51756 .63664 Mdot
.39958 .61957 Mdot
.35179 .70965 Mdot
.39875 .47574 Mdot
.36557 .39871 Mdot
.32874 .39886 Mdot
.57569 .64015 Mdot
.34647 .73147 Mdot
.63476 .39894 Mdot
.37877 .63211 Mdot
.40803 .45784 Mdot
.61596 .37218 Mdot
.37238 .72279 Mdot
.74669 .61624 Mdot
.67923 .48852 Mdot
.60699 .35744 Mdot
.64496 .37101 Mdot
.61347 .38716 Mdot
.6323 .2197 Mdot
.33978 .63669 Mdot
.35438 .52226 Mdot
.40801 .46693 Mdot
.49101 .35085 Mdot
.45664 .429 Mdot
.56278 .61005 Mdot
.68416 .51918 Mdot
.37912 .43079 Mdot
.41268 .3788 Mdot
.47495 .37686 Mdot
.4724 .41995 Mdot
.33284 .67854 Mdot
.36935 .61395 Mdot
.46996 .44225 Mdot
.67963 .518 Mdot
.80137 .68621 Mdot
.47395 .13769 Mdot
.42581 .49644 Mdot
.5567 .46558 Mdot
.36135 .66094 Mdot
.54564 .66693 Mdot
.53113 .51022 Mdot
.51932 .61713 Mdot
.38178 .62717 Mdot
.42319 .42177 Mdot
.46983 .70286 Mdot
.64034 .33792 Mdot
.37313 .45004 Mdot
.54857 .63162 Mdot
.37354 .44959 Mdot
.56865 .61659 Mdot
.4432 .60603 Mdot
.49953 .78608 Mdot
.44489 .43232 Mdot
.37916 .47335 Mdot
.48138 .40004 Mdot
.36529 .41756 Mdot
.79578 .60147 Mdot
.3727 .66212 Mdot
.69357 .74998 Mdot
.39529 .37323 Mdot
.30721 .59232 Mdot
.40763 .46958 Mdot
.74329 .57986 Mdot
.36115 .40889 Mdot
.51872 .53549 Mdot
.43412 .45791 Mdot
.38778 .38948 Mdot
.51337 .64444 Mdot
.54392 .66482 Mdot
.35185 .64107 Mdot
.72169 .61621 Mdot
.43885 .18295 Mdot
.37029 .40144 Mdot
.704 .53189 Mdot
.53138 .58271 Mdot
.64208 .37842 Mdot
.38412 .62841 Mdot
.67213 .81062 Mdot
.511 .63191 Mdot
.63021 .51868 Mdot
.7695 .57949 Mdot
.69861 .52617 Mdot
.59923 .62308 Mdot
.34236 .33942 Mdot
.64783 .37886 Mdot
.41621 .46888 Mdot
.19264 .59158 Mdot
.55091 .75976 Mdot
.38072 .49382 Mdot
.50948 .61915 Mdot
.29139 .42954 Mdot
.17353 .52651 Mdot
.60266 .35661 Mdot
.63907 .34484 Mdot
.51297 .63826 Mdot
.70148 .50054 Mdot
.34673 .3549 Mdot
.61796 .35869 Mdot
.68725 .48677 Mdot
.72505 .63015 Mdot
.47353 .57224 Mdot
.38313 .6402 Mdot
.35203 .74417 Mdot
.46756 .74414 Mdot
.52094 .6226 Mdot
.62944 .54833 Mdot
.42709 .61949 Mdot
.35873 .59583 Mdot
.72412 .60709 Mdot
.64334 .47982 Mdot
.34675 .66199 Mdot
.36707 .47958 Mdot
.46903 .47414 Mdot
.39559 .40371 Mdot
.63287 .35822 Mdot
.36162 .42142 Mdot
.64877 .47481 Mdot
.5417 .64123 Mdot
.64365 .50252 Mdot
.51779 .64587 Mdot
.50859 .71749 Mdot
.3968 .44362 Mdot
.38545 .39082 Mdot
.56472 .3655 Mdot
.35315 .61854 Mdot
.28735 .70148 Mdot
.70662 .53027 Mdot
.66001 .50638 Mdot
.41793 .39523 Mdot
.35823 .66444 Mdot
.64331 .40612 Mdot
.56755 .3713 Mdot
.35997 .44029 Mdot
.37235 .66263 Mdot
.42948 .42616 Mdot
.58827 .23882 Mdot
.52432 .79395 Mdot
.39445 .63404 Mdot
.72193 .7403 Mdot
.41767 .43334 Mdot
.31692 .45235 Mdot
.34523 .44665 Mdot
.46207 .27484 Mdot
.39818 .47662 Mdot
.39903 .66232 Mdot
.39317 .40728 Mdot
.37548 .66852 Mdot
.69704 .49777 Mdot
.52851 .66734 Mdot
.36198 .64361 Mdot
.35776 .44092 Mdot
.6181 .19275 Mdot
.55063 .625 Mdot
.40103 .39621 Mdot
.55963 .6459 Mdot
.41472 .63681 Mdot
.35965 .61558 Mdot
.75411 .32849 Mdot
.57991 .59719 Mdot
.54444 .62047 Mdot
.43429 .42061 Mdot
.43501 .75241 Mdot
.4255 .41149 Mdot
.50918 .31511 Mdot
.40291 .38008 Mdot
.39077 .47761 Mdot
.83764 .42364 Mdot
.57769 .64852 Mdot
.52504 .84411 Mdot
.64876 .27531 Mdot
.64525 .22343 Mdot
.40254 .58304 Mdot
.60237 .35717 Mdot
.56317 .19815 Mdot
.75554 .61806 Mdot
.66806 .48078 Mdot
.37866 .43191 Mdot
.39592 .56612 Mdot
.54161 .61446 Mdot
.63318 .38173 Mdot
.44502 .42994 Mdot
.65684 .4686 Mdot
.78717 .4217 Mdot
.50422 .6485 Mdot
.3864 .63424 Mdot
.35459 .61972 Mdot
.65328 .80875 Mdot
.40692 .45968 Mdot
.39319 .39391 Mdot
.55969 .62834 Mdot
.45045 .37931 Mdot
.63547 .39296 Mdot
.72347 .4457 Mdot
.54338 .62098 Mdot
.59712 .55726 Mdot
.36461 .62189 Mdot
.37042 .42233 Mdot
.52174 .46133 Mdot
.60906 .57884 Mdot
.25282 .41153 Mdot
.62829 .36167 Mdot
.52412 .32524 Mdot
.39977 .6617 Mdot
.53989 .63613 Mdot
.66327 .32145 Mdot
.35238 .38705 Mdot
.3738 .4168 Mdot
.52593 .32949 Mdot
.56076 .43567 Mdot
.63695 .41606 Mdot
.43254 .46755 Mdot
.55626 .4297 Mdot
.41296 .39131 Mdot
.34799 .4409 Mdot
.4063 .48522 Mdot
.3679 .39081 Mdot
.36865 .66278 Mdot
.46536 .36475 Mdot
.67626 .49199 Mdot
.25956 .51348 Mdot
.49734 .51287 Mdot
.42226 .45383 Mdot
.42313 .41747 Mdot
.2698 .39674 Mdot
.60149 .605 Mdot
.3707 .65812 Mdot
.34626 .6689 Mdot
.51007 .65109 Mdot
.47692 .4601 Mdot
.70487 .49219 Mdot
.44933 .34334 Mdot
.64326 .49891 Mdot
.37389 .66378 Mdot
.65803 .51177 Mdot
.51348 .65572 Mdot
.65831 .52188 Mdot
.709 .52125 Mdot
.55752 .61332 Mdot
.35997 .62619 Mdot
.36027 .43354 Mdot
.50745 .64574 Mdot
.53005 .35931 Mdot
.63136 .35792 Mdot
.75395 .32769 Mdot
.36932 .37022 Mdot
.48376 .49467 Mdot
.45621 .23936 Mdot
.64591 .50452 Mdot
.54202 .80213 Mdot
.35877 .65123 Mdot
.65505 .35239 Mdot
.36876 .66439 Mdot
.30463 .7437 Mdot
.63006 .38664 Mdot
.74562 .30671 Mdot
.67214 .43859 Mdot
.76549 .39243 Mdot
.44288 .45722 Mdot
.42605 .66196 Mdot
.6529 .52673 Mdot
.53894 .61519 Mdot
.71588 .47981 Mdot
.38496 .38586 Mdot
.62322 .75056 Mdot
.3626 .59881 Mdot
.73293 .63249 Mdot
.53184 .63762 Mdot
.50217 .62829 Mdot
.39985 .45747 Mdot
.77039 .4906 Mdot
.38503 .38065 Mdot
.66303 .40522 Mdot
.52954 .30394 Mdot
.44223 .33866 Mdot
.43489 .40671 Mdot
.63938 .50499 Mdot
.43034 .4262 Mdot
.29757 .42962 Mdot
.207 .62297 Mdot
.33117 .42155 Mdot
.68438 .71983 Mdot
.58237 .36954 Mdot
.37109 .62199 Mdot
.43709 .49393 Mdot
.73119 .62318 Mdot
.41906 .4361 Mdot
.13347 .49887 Mdot
.62498 .37243 Mdot
.6845 .56018 Mdot
.39829 .47187 Mdot
.40544 .45142 Mdot
.22735 .61973 Mdot
.40666 .57044 Mdot
.71518 .60823 Mdot
.37757 .4137 Mdot
.5533 .29289 Mdot
.56409 .65091 Mdot
.37908 .37735 Mdot
.38905 .4019 Mdot
.2454 .36544 Mdot
.57396 .63824 Mdot
.64801 .50871 Mdot
.75528 .62378 Mdot
.66142 .53611 Mdot
.60158 .39088 Mdot
.54058 .51854 Mdot
.44491 .32284 Mdot
.52385 .79161 Mdot
.60206 .37425 Mdot
.3731 .45855 Mdot
.36522 .49873 Mdot
.41208 .43859 Mdot
.63402 .34208 Mdot
.57388 .6311 Mdot
.36367 .65483 Mdot
.39188 .74549 Mdot
.73557 .61501 Mdot
.36586 .47382 Mdot
.61778 .34503 Mdot
.36906 .64048 Mdot
.62241 .55322 Mdot
.37399 .62785 Mdot
.53129 .62584 Mdot
.55 .60573 Mdot
.6202 .38212 Mdot
.3715 .66555 Mdot
.66838 .54145 Mdot
.65563 .28361 Mdot
.41234 .38406 Mdot
.50891 .60864 Mdot
.35039 .65508 Mdot
.41464 .60946 Mdot
.35661 .60538 Mdot
.39155 .44888 Mdot
.55602 .45456 Mdot
.34583 .43455 Mdot
.51304 .63384 Mdot
.67998 .48413 Mdot
.42016 .31707 Mdot
.23044 .63399 Mdot
.5935 .54016 Mdot
.45458 .44919 Mdot
.40913 .39929 Mdot
.39162 .39894 Mdot
.44148 .40167 Mdot
.67378 .34158 Mdot
.39877 .44021 Mdot
.51515 .64565 Mdot
.64589 .48571 Mdot
.41412 .46193 Mdot
.73146 .6257 Mdot
.54094 .46644 Mdot
.61617 .39479 Mdot
.51416 .52138 Mdot
.55616 .16985 Mdot
.36814 .64184 Mdot
.67781 .52926 Mdot
.66878 .48282 Mdot
.6139 .38993 Mdot
.53404 .61792 Mdot
.36974 .63084 Mdot
.47235 .26709 Mdot
.62046 .39055 Mdot
.38886 .40769 Mdot
.7422 .51837 Mdot
.73604 .70316 Mdot
.41509 .4722 Mdot
.38874 .42538 Mdot
.75158 .63008 Mdot
.70329 .49773 Mdot
.21185 .33171 Mdot
.56813 .41875 Mdot
.62529 .38347 Mdot
.64603 .3587 Mdot
.35252 .60835 Mdot
.40175 .5007 Mdot
.52024 .64489 Mdot
.55669 .39941 Mdot
.40321 .28419 Mdot
.60106 .42253 Mdot
.82743 .48775 Mdot
.3849 .45746 Mdot
.23005 .60992 Mdot
.42942 .4054 Mdot
.37464 .59075 Mdot
.40084 .609 Mdot
.37348 .6536 Mdot
.51833 .62966 Mdot
.33301 .58159 Mdot
.51825 .65042 Mdot
.52196 .15045 Mdot
.38201 .67213 Mdot
.70776 .35926 Mdot
.66426 .51328 Mdot
.45793 .40798 Mdot
.64117 .38679 Mdot
.59907 .641 Mdot
.41893 .48178 Mdot
.60978 .7778 Mdot
.66385 .52104 Mdot
.36183 .61781 Mdot
.33393 .34908 Mdot
.35725 .20802 Mdot
.55472 .50206 Mdot
.38163 .52901 Mdot
.28147 .68443 Mdot
.63514 .38671 Mdot
.25411 .41961 Mdot
.64995 .38059 Mdot
.55171 .63727 Mdot
.37933 .38595 Mdot
.3634 .39322 Mdot
.43227 .40236 Mdot
.39704 .4406 Mdot
.53672 .6623 Mdot
.42156 .37807 Mdot
.27553 .73856 Mdot
.75027 .62768 Mdot
.58637 .22814 Mdot
.61597 .35572 Mdot
.52607 .61132 Mdot
.64481 .49049 Mdot
.72191 .62291 Mdot
.45931 .32318 Mdot
.43505 .45592 Mdot
.38083 .4323 Mdot
.72431 .60224 Mdot
.41074 .48198 Mdot
.39113 .34062 Mdot
.67469 .49222 Mdot
.58559 .52828 Mdot
.60683 .35379 Mdot
.61252 .35531 Mdot
.56668 .62179 Mdot
.37015 .66531 Mdot
.62171 .36028 Mdot
.69734 .48946 Mdot
.41376 .37235 Mdot
.35272 .43311 Mdot
.34999 .65367 Mdot
.29316 .73374 Mdot
.60078 .35795 Mdot
.33056 .353 Mdot
.39001 .6668 Mdot
.343 .61748 Mdot
.37671 .41692 Mdot
.32905 .41158 Mdot
.42454 .6256 Mdot
.60483 .37081 Mdot
.5228 .61227 Mdot
.73611 .35373 Mdot
.55433 .63133 Mdot
.36806 .63464 Mdot
.3838 .37126 Mdot
.36168 .6243 Mdot
.41828 .443 Mdot
.88666 .44998 Mdot
.36091 .40139 Mdot
.46273 .81572 Mdot
.47308 .28402 Mdot
.66501 .48269 Mdot
.66974 .54109 Mdot
.73925 .62907 Mdot
.39167 .66676 Mdot
.3554 .40444 Mdot
.64905 .36491 Mdot
.6744 .25091 Mdot
.42596 .6536 Mdot
.67143 .47527 Mdot
.7053 .49657 Mdot
.57776 .6313 Mdot
.40039 .46931 Mdot
.36895 .41929 Mdot
.65568 .52045 Mdot
.4834 .23002 Mdot
.40297 .65073 Mdot
.39495 .39482 Mdot
.41261 .40344 Mdot
.66848 .48671 Mdot
.65513 .28501 Mdot
.44386 .62456 Mdot
.37633 .38784 Mdot
.59464 .35203 Mdot
.56728 .6113 Mdot
.4411 .40386 Mdot
.42433 .37973 Mdot
.64275 .35858 Mdot
.53217 .20485 Mdot
.17452 .56515 Mdot
.55319 .60967 Mdot
.72303 .6204 Mdot
.3589 .44967 Mdot
.66588 .5124 Mdot
.35582 .43904 Mdot
.39283 .22359 Mdot
.74358 .63222 Mdot
.40282 .43266 Mdot
.41939 .49508 Mdot
.38676 .6044 Mdot
.4026 .44177 Mdot
.26501 .3612 Mdot
.64114 .52366 Mdot
.40243 .43673 Mdot
.28491 .64804 Mdot
.57227 .64351 Mdot
.42831 .49442 Mdot
.62394 .34706 Mdot
.45586 .27297 Mdot
.46329 .72682 Mdot
.70622 .48429 Mdot
.6113 .35943 Mdot
.35929 .43589 Mdot
.7014 .50545 Mdot
.53139 .61616 Mdot
.60631 .76315 Mdot
.44686 .44036 Mdot
.55407 .62675 Mdot
.53969 .64094 Mdot
.61924 .37646 Mdot
.56073 .84047 Mdot
.46481 .43135 Mdot
.364 .42028 Mdot
.26981 .33712 Mdot
.37892 .59686 Mdot
.36175 .4285 Mdot
.38121 .4614 Mdot
.52862 .65214 Mdot
.44361 .65594 Mdot
.30053 .463 Mdot
.74483 .46523 Mdot
.56843 .61549 Mdot
.67855 .45504 Mdot
.7011 .50716 Mdot
.61705 .35581 Mdot
.37711 .61879 Mdot
.60902 .39369 Mdot
.68308 .50608 Mdot
.39844 .4636 Mdot
.53778 .65097 Mdot
.22108 .46028 Mdot
.55345 .66767 Mdot
.63334 .47386 Mdot
.39768 .59403 Mdot
.41816 .71152 Mdot
.15745 .58374 Mdot
.48132 .74123 Mdot
.54532 .67569 Mdot
.64239 .37774 Mdot
.72611 .49097 Mdot
.41087 .40185 Mdot
.26234 .44907 Mdot
.36645 .44291 Mdot
.28006 .67014 Mdot
.6901 .51212 Mdot
.72292 .60706 Mdot
.37731 .386 Mdot
.53158 .31388 Mdot
.49925 .65428 Mdot
.57861 .63086 Mdot
.39348 .43306 Mdot
.5259 .62789 Mdot
.36672 .40653 Mdot
.64282 .48569 Mdot
.50647 .83593 Mdot
.40553 .39772 Mdot
.33996 .42604 Mdot
.58345 .59032 Mdot
.75222 .32275 Mdot
.67906 .54419 Mdot
.22864 .61118 Mdot
.32427 .23033 Mdot
.52502 .62957 Mdot
.38219 .49782 Mdot
.65398 .52463 Mdot
.75124 .6306 Mdot
.65259 .54207 Mdot
.36975 .44192 Mdot
.37884 .44547 Mdot
.41906 .39586 Mdot
.41512 .41668 Mdot
.26204 .4421 Mdot
.45693 .3759 Mdot
.23629 .59457 Mdot
.38277 .4313 Mdot
.32821 .69595 Mdot
.52139 .6552 Mdot
.33067 .67217 Mdot
.60525 .34615 Mdot
.38753 .45815 Mdot
.38458 .5589 Mdot
.54582 .60825 Mdot
.51925 .1505 Mdot
.57661 .63406 Mdot
.65462 .49446 Mdot
.56184 .66056 Mdot
.41979 .4481 Mdot
.39028 .62202 Mdot
.63531 .51203 Mdot
.59949 .73281 Mdot
.6674 .47952 Mdot
.41148 .45999 Mdot
.66726 .31085 Mdot
.67148 .48418 Mdot
.53099 .48328 Mdot
.38735 .61813 Mdot
.55894 .29635 Mdot
.40493 .6116 Mdot
.40491 .43495 Mdot
.40666 .43127 Mdot
.7322 .63523 Mdot
.50989 .66017 Mdot
.41469 .64121 Mdot
.41354 .8507 Mdot
.61566 .40393 Mdot
.38012 .65125 Mdot
.41908 .36351 Mdot
.56073 .44731 Mdot
.399 .62914 Mdot
.51793 .26959 Mdot
.53329 .61742 Mdot
.34075 .64542 Mdot
.39333 .3571 Mdot
.52132 .57457 Mdot
.64706 .34013 Mdot
.64503 .47052 Mdot
.55066 .55312 Mdot
.65393 .52838 Mdot
.53794 .60717 Mdot
.64077 .46682 Mdot
.56014 .65451 Mdot
.32168 .71361 Mdot
.38367 .548 Mdot
.55135 .67048 Mdot
.52847 .60759 Mdot
.67638 .50863 Mdot
.44668 .43026 Mdot
.47183 .53622 Mdot
.42853 .4719 Mdot
.45108 .44049 Mdot
.56482 .65199 Mdot
.41135 .64348 Mdot
.39547 .66939 Mdot
.39724 .68725 Mdot
.35596 .61483 Mdot
.64163 .49356 Mdot
.51941 .79944 Mdot
.30119 .71497 Mdot
.56568 .63125 Mdot
.5238 .60499 Mdot
.4251 .41319 Mdot
.66973 .51194 Mdot
.69609 .50242 Mdot
.5268 .64669 Mdot
.23894 .46006 Mdot
.34275 .42432 Mdot
.40102 .60023 Mdot
.37713 .6723 Mdot
.39639 .63735 Mdot
.35282 .61171 Mdot
.32179 .51488 Mdot
.53718 .61549 Mdot
.38691 .66986 Mdot
.39769 .43174 Mdot
.37586 .44439 Mdot
.73008 .6092 Mdot
.61617 .35105 Mdot
.40457 .36388 Mdot
.33353 .42514 Mdot
.37557 .41882 Mdot
.67782 .48722 Mdot
.40428 .51692 Mdot
.73094 .6292 Mdot
.67292 .46682 Mdot
.70763 .49551 Mdot
.73108 .60349 Mdot
.36662 .6965 Mdot
.33668 .21192 Mdot
.42926 .42132 Mdot
.40976 .52871 Mdot
.66595 .50799 Mdot
.55389 .81658 Mdot
.35576 .72918 Mdot
.43587 .40617 Mdot
.49248 .56961 Mdot
.63393 .50157 Mdot
.37144 .59657 Mdot
.36341 .43562 Mdot
.74318 .60701 Mdot
.61899 .39561 Mdot
.41421 .36036 Mdot
.75589 .62389 Mdot
.37847 .66508 Mdot
.66329 .34089 Mdot
.34159 .62865 Mdot
.63274 .50005 Mdot
.42292 .49377 Mdot
.51362 .10738 Mdot
.67431 .53321 Mdot
.67564 .26127 Mdot
.41826 .57619 Mdot
.40116 .39372 Mdot
.66824 .53323 Mdot
.37759 .59457 Mdot
.56549 .60933 Mdot
.5507 .42573 Mdot
.35736 .64443 Mdot
.72092 .61703 Mdot
.73573 .60813 Mdot
.67354 .4898 Mdot
.37309 .61094 Mdot
.38173 .37504 Mdot
.39919 .61204 Mdot
.56833 .65622 Mdot
.44127 .42193 Mdot
.42201 .18046 Mdot
.47054 .46538 Mdot
.40149 .65867 Mdot
.66137 .46709 Mdot
.64819 .34513 Mdot
.44089 .44498 Mdot
.6485 .25819 Mdot
.392 .467 Mdot
.56695 .643 Mdot
.64935 .78358 Mdot
.22718 .43444 Mdot
.4118 .46658 Mdot
.42419 .41364 Mdot
.55409 .61241 Mdot
.43751 .45254 Mdot
.40807 .47209 Mdot
.53862 .58683 Mdot
.38935 .60711 Mdot
.39848 .40558 Mdot
.69162 .48856 Mdot
.22351 .63703 Mdot
.36083 .45472 Mdot
.69189 .70184 Mdot
.54893 .30555 Mdot
.62219 .80331 Mdot
.35733 .42691 Mdot
.52344 .36858 Mdot
.40723 .41947 Mdot
.38973 .45399 Mdot
.43264 .4162 Mdot
.21577 .58568 Mdot
.67778 .51072 Mdot
.65622 .47241 Mdot
.6464 .33859 Mdot
.54826 .30236 Mdot
.6348 .35157 Mdot
.56798 .61873 Mdot
.80658 .45805 Mdot
.74616 .63024 Mdot
.37077 .66618 Mdot
.36627 .38441 Mdot
.63264 .51104 Mdot
.37005 .42626 Mdot
.42094 .44393 Mdot
.63631 .49329 Mdot
.69162 .52659 Mdot
.64953 .55631 Mdot
.64478 .38694 Mdot
.36646 .651 Mdot
.42103 .3821 Mdot
.61042 .37988 Mdot
.3746 .37579 Mdot
.5653 .42744 Mdot
.36811 .65418 Mdot
.39643 .60913 Mdot
.41889 .63124 Mdot
.39806 .46382 Mdot
.4238 .45078 Mdot
.51965 .65152 Mdot
.35458 .6639 Mdot
.56364 .62212 Mdot
.64604 .52198 Mdot
.65017 .53543 Mdot
.37012 .44218 Mdot
.31629 .36163 Mdot
.64694 .36472 Mdot
.65076 .49738 Mdot
.72275 .60182 Mdot
.65379 .35368 Mdot
.40659 .4623 Mdot
.64021 .50738 Mdot
.61143 .35511 Mdot
.23652 .50366 Mdot
.29676 .24831 Mdot
.64532 .34445 Mdot
.39467 .43126 Mdot
.23206 .62908 Mdot
.63736 .29203 Mdot
.62091 .40465 Mdot
.56053 .64087 Mdot
.38802 .46429 Mdot
.37702 .26398 Mdot
.6001 .37684 Mdot
.27937 .69451 Mdot
.66224 .48258 Mdot
.46716 .61634 Mdot
.37421 .35766 Mdot
.26496 .47174 Mdot
.61233 .39848 Mdot
.37415 .63182 Mdot
.38357 .67957 Mdot
.3932 .41738 Mdot
.6089 .34047 Mdot
.58057 .63355 Mdot
.65579 .47992 Mdot
.70021 .53503 Mdot
.37707 .60864 Mdot
.45344 .76567 Mdot
.68327 .47956 Mdot
.32204 .36451 Mdot
.75404 .52 Mdot
.4609 .49366 Mdot
.31123 .67839 Mdot
.57791 .73127 Mdot
.35109 .43716 Mdot
.64646 .34897 Mdot
.52052 .61556 Mdot
.51549 .64263 Mdot
.53786 .62336 Mdot
.67792 .54022 Mdot
.52786 .51213 Mdot
.66779 .5233 Mdot
.60352 .75576 Mdot
.61596 .37155 Mdot
.57046 .27917 Mdot
.35689 .40253 Mdot
.40782 .39896 Mdot
.36127 .37779 Mdot
.39223 .38253 Mdot
.40693 .41553 Mdot
.53322 .61919 Mdot
.69322 .53397 Mdot
.75061 .4099 Mdot
.39023 .64993 Mdot
.68409 .57167 Mdot
.66395 .51342 Mdot
.75061 .63019 Mdot
.63316 .37667 Mdot
.51338 .38331 Mdot
.67067 .46047 Mdot
.65793 .51062 Mdot
.42105 .37413 Mdot
.40794 .63039 Mdot
.38532 .335 Mdot
.40947 .42639 Mdot
.64866 .49957 Mdot
.66338 .43987 Mdot
.27809 .37173 Mdot
.32399 .42109 Mdot
.65867 .38732 Mdot
.55888 .45344 Mdot
.64043 .3966 Mdot
.33973 .38441 Mdot
.56133 .81614 Mdot
.68236 .50553 Mdot
.66076 .49201 Mdot
.62134 .34435 Mdot
.31323 .44102 Mdot
.37751 .6131 Mdot
.72236 .60705 Mdot
.55531 .65008 Mdot
.41055 .43733 Mdot
.66535 .53843 Mdot
.34779 .50086 Mdot
.7676 .46722 Mdot
.54462 .62277 Mdot
.67495 .46776 Mdot
.40316 .46851 Mdot
.39292 .43018 Mdot
.63824 .38484 Mdot
.42625 .53439 Mdot
.44621 .38613 Mdot
.64421 .22256 Mdot
.49948 .78463 Mdot
.44147 .78675 Mdot
.37358 .41671 Mdot
.37698 .60679 Mdot
.74481 .61044 Mdot
.62171 .38903 Mdot
.40188 .37288 Mdot
.30573 .24079 Mdot
.41674 .65382 Mdot
.54715 .63442 Mdot
.74003 .60568 Mdot
.5273 .51024 Mdot
.3883 .46559 Mdot
.36616 .44232 Mdot
.39414 .44507 Mdot
.26073 .26464 Mdot
.67586 .47657 Mdot
.3588 .60496 Mdot
.63132 .36213 Mdot
.35829 .60821 Mdot
.66091 .47465 Mdot
.4056 .74468 Mdot
.42163 .46001 Mdot
.39821 .59693 Mdot
.37668 .62962 Mdot
.57745 .63029 Mdot
.57257 .61222 Mdot
.65184 .55795 Mdot
.36186 .3995 Mdot
.74574 .60859 Mdot
.40258 .60942 Mdot
.69983 .52018 Mdot
.63108 .38692 Mdot
.50871 .64535 Mdot
.3834 .43239 Mdot
.6807 .4978 Mdot
.38169 .49172 Mdot
.40217 .62865 Mdot
.65878 .51058 Mdot
.74304 .60162 Mdot
.64102 .35 Mdot
.37988 .43989 Mdot
.64877 .4054 Mdot
.72772 .60238 Mdot
.41434 .40293 Mdot
.44558 .33432 Mdot
.60515 .40759 Mdot
.61187 .73062 Mdot
.67209 .52712 Mdot
.72822 .61746 Mdot
.39436 .60472 Mdot
.41599 .69326 Mdot
.6571 .48935 Mdot
.49189 .36451 Mdot
.43237 .54494 Mdot
.42504 .38468 Mdot
.39026 .63529 Mdot
.71432 .46984 Mdot
.59332 .19601 Mdot
.60947 .26614 Mdot
.39732 .39769 Mdot
.6651 .53276 Mdot
.60813 .36059 Mdot
.56658 .63228 Mdot
.6934 .70274 Mdot
.35862 .53948 Mdot
.64718 .46386 Mdot
.42966 .41655 Mdot
.40356 .61113 Mdot
.52731 .64537 Mdot
.47995 .7035 Mdot
.69177 .48033 Mdot
.68858 .51641 Mdot
.41208 .46426 Mdot
.61769 .36277 Mdot
.53579 .23041 Mdot
.65085 .47254 Mdot
.66763 .53759 Mdot
.72517 .57122 Mdot
.62149 .34232 Mdot
.39743 .42337 Mdot
.39939 .68618 Mdot
.44667 .40899 Mdot
.67835 .26001 Mdot
.73036 .6272 Mdot
.39104 .65094 Mdot
.37494 .44917 Mdot
.75703 .48868 Mdot
.6476 .49186 Mdot
.55559 .46846 Mdot
.62743 .476 Mdot
.52983 .61931 Mdot
.66333 .53828 Mdot
.36487 .43037 Mdot
.49919 .65493 Mdot
.64608 .36252 Mdot
.37343 .38842 Mdot
.42532 .44956 Mdot
.37376 .59345 Mdot
.55257 .63808 Mdot
.18341 .49221 Mdot
.51366 .61194 Mdot
.53779 .60986 Mdot
.36478 .68089 Mdot
.39119 .41233 Mdot
.65608 .49831 Mdot
.63545 .47547 Mdot
.40175 .37445 Mdot
.52253 .81188 Mdot
.37909 .61098 Mdot
.65691 .56008 Mdot
.22126 .32382 Mdot
.3361 .36142 Mdot
.73388 .59848 Mdot
.43061 .52884 Mdot
.57475 .62077 Mdot
.38855 .43217 Mdot
.39847 .65983 Mdot
.67815 .53679 Mdot
.68458 .48088 Mdot
.38225 .3724 Mdot
.53507 .64418 Mdot
.60629 .38537 Mdot
.69141 .51633 Mdot
.76862 .48675 Mdot
.39971 .4466 Mdot
.62991 .74715 Mdot
.68616 .52349 Mdot
.69568 .25046 Mdot
.75792 .43225 Mdot
.39194 .63823 Mdot
.42319 .44292 Mdot
.35402 .62777 Mdot
.63617 .36185 Mdot
.70753 .48206 Mdot
.53983 .64277 Mdot
.32461 .43664 Mdot
.19486 .62468 Mdot
.67493 .51368 Mdot
.369 .66244 Mdot
.41064 .46696 Mdot
.32626 .37611 Mdot
.3625 .41764 Mdot
.42508 .67695 Mdot
.6442 .42559 Mdot
.56751 .64957 Mdot
.56566 .64286 Mdot
.4209 .40327 Mdot
.62876 .39333 Mdot
.63843 .48229 Mdot
.65588 .48126 Mdot
.83808 .64685 Mdot
.7421 .60045 Mdot
.50487 .30415 Mdot
.38001 .4439 Mdot
.70255 .51635 Mdot
.22558 .62823 Mdot
.55983 .62802 Mdot
.39234 .38123 Mdot
.70557 .51826 Mdot
.6103 .59596 Mdot
.56351 .42977 Mdot
.40236 .418 Mdot
.38465 .34493 Mdot
.55858 .64776 Mdot
.56405 .38424 Mdot
.66375 .52261 Mdot
.39958 .38071 Mdot
.50809 .61578 Mdot
.76285 .53974 Mdot
.25554 .69203 Mdot
.36689 .65122 Mdot
.62989 .47557 Mdot
.53393 .61864 Mdot
.44116 .37807 Mdot
.61468 .35613 Mdot
.64466 .52466 Mdot
.67408 .48196 Mdot
.43785 .42864 Mdot
.43815 .38583 Mdot
.33519 .36261 Mdot
.38028 .65982 Mdot
.53526 .65891 Mdot
.38013 .38442 Mdot
.45987 .76762 Mdot
.41698 .39338 Mdot
.52954 .65638 Mdot
.66511 .15481 Mdot
.4496 .42451 Mdot
.36355 .41534 Mdot
.55903 .23791 Mdot
.35609 .64089 Mdot
.35851 .60947 Mdot
.50521 .79031 Mdot
.37996 .44349 Mdot
.77268 .42117 Mdot
.36478 .64771 Mdot
.38334 .61176 Mdot
.70214 .37197 Mdot
.44034 .41529 Mdot
.57153 .38426 Mdot
.52194 .64697 Mdot
.50884 .63422 Mdot
.39512 .61022 Mdot
.44741 .38645 Mdot
.53997 .61214 Mdot
.27927 .45326 Mdot
.66629 .51653 Mdot
.56523 .81583 Mdot
.40418 .63612 Mdot
.47363 .51774 Mdot
.55512 .62426 Mdot
.52722 .1506 Mdot
.51578 .56492 Mdot
.42485 .39921 Mdot
.38524 .44052 Mdot
.64124 .35347 Mdot
.43197 .47924 Mdot
.72406 .62418 Mdot
.52649 .62704 Mdot
.49695 .21037 Mdot
.37444 .65314 Mdot
.36223 .40357 Mdot
.50703 .37494 Mdot
.48992 .7172 Mdot
.67996 .72541 Mdot
.37165 .62256 Mdot
.38568 .63973 Mdot
.67825 .51933 Mdot
.68826 .50178 Mdot
.3973 .41352 Mdot
.51424 .63703 Mdot
.3499 .66117 Mdot
.54769 .65568 Mdot
.68339 .50452 Mdot
.65826 .50607 Mdot
.74248 .63284 Mdot
.38475 .48429 Mdot
.63894 .48807 Mdot
.77407 .5121 Mdot
.4454 .76675 Mdot
.35716 .59859 Mdot
.1564 .54345 Mdot
.48013 .70182 Mdot
.46181 .24804 Mdot
.64094 .39385 Mdot
.7133 .62136 Mdot
.53523 .66599 Mdot
.42313 .411 Mdot
.37537 .43055 Mdot
.74086 .61821 Mdot
.52714 .66938 Mdot
.63718 .37742 Mdot
.51577 .66477 Mdot
.61351 .37136 Mdot
.656 .54109 Mdot
.35996 .45284 Mdot
.37314 .45652 Mdot
.53423 .61979 Mdot
.6495 .51142 Mdot
.64696 .48075 Mdot
.64776 .38656 Mdot
.5278 .38697 Mdot
.67539 .49076 Mdot
.40399 .63397 Mdot
.3242 .55855 Mdot
.73743 .60956 Mdot
.36276 .43335 Mdot
.48523 .34518 Mdot
.24774 .4354 Mdot
.42132 .38516 Mdot
.73704 .60353 Mdot
.78561 .70118 Mdot
.35816 .40305 Mdot
.72269 .76022 Mdot
.72734 .61529 Mdot
.35534 .64065 Mdot
.67132 .53129 Mdot
.7246 .62638 Mdot
.38957 .35259 Mdot
.63667 .40326 Mdot
.38273 .36591 Mdot
.35763 .63954 Mdot
.41708 .62199 Mdot
.41692 .792 Mdot
.67964 .26215 Mdot
.65158 .37333 Mdot
.62569 .38054 Mdot
.65866 .48817 Mdot
.82684 .42216 Mdot
.39505 .35816 Mdot
.62915 .38283 Mdot
.48548 .21832 Mdot
.42537 .41917 Mdot
.50756 .32054 Mdot
.49361 .56673 Mdot
.37798 .60726 Mdot
.34862 .69503 Mdot
.65173 .48869 Mdot
.36796 .66127 Mdot
.41752 .76779 Mdot
.36249 .37695 Mdot
.37043 .65489 Mdot
.53183 .65583 Mdot
.63213 .66037 Mdot
.35773 .62082 Mdot
.54993 .40754 Mdot
.51992 .64333 Mdot
.65815 .43128 Mdot
.5305 .24264 Mdot
.12166 .53425 Mdot
.52364 .62774 Mdot
.64591 .51618 Mdot
.63324 .4987 Mdot
.65813 .48289 Mdot
.35717 .64768 Mdot
.69763 .49795 Mdot
.38818 .65823 Mdot
.66877 .29163 Mdot
.51402 .37266 Mdot
.61889 .38185 Mdot
.575 .59412 Mdot
.3823 .6333 Mdot
.56237 .77923 Mdot
.16043 .58286 Mdot
.39392 .43453 Mdot
.51117 .61363 Mdot
.62314 .344 Mdot
.79425 .32617 Mdot
.64177 .35605 Mdot
.65578 .52554 Mdot
.57425 .81404 Mdot
.36691 .4026 Mdot
.29657 .33809 Mdot
.64549 .35485 Mdot
.366 .62686 Mdot
.41224 .40119 Mdot
.61927 .50923 Mdot
.6189 .35626 Mdot
.614 .3927 Mdot
.40681 .4086 Mdot
.36365 .61427 Mdot
.65608 .50257 Mdot
.52645 .66353 Mdot
.60014 .39749 Mdot
.4491 .38237 Mdot
.4384 .3962 Mdot
.34659 .41418 Mdot
.54679 .49613 Mdot
.41255 .23999 Mdot
.52409 .63086 Mdot
.60012 .29071 Mdot
.68569 .49572 Mdot
.6932 .43579 Mdot
.5222 .77003 Mdot
.58738 .60553 Mdot
.72895 .62571 Mdot
.73605 .63077 Mdot
.40369 .41526 Mdot
.42179 .23557 Mdot
.69787 .74158 Mdot
.59216 .59658 Mdot
.74046 .61025 Mdot
.65241 .48 Mdot
.38946 .67747 Mdot
.38237 .77436 Mdot
.45152 .41289 Mdot
.58006 .62548 Mdot
.67882 .49224 Mdot
.38801 .22611 Mdot
.6198 .3687 Mdot
.55632 .80766 Mdot
.41748 .4604 Mdot
.38584 .39123 Mdot
.52884 .63545 Mdot
.51861 .65009 Mdot
.67112 .71698 Mdot
.45184 .79366 Mdot
.60189 .43867 Mdot
.46388 .65984 Mdot
.35687 .24595 Mdot
.33298 .67622 Mdot
.40475 .65453 Mdot
.75558 .61661 Mdot
.50451 .6281 Mdot
.36413 .44218 Mdot
.36227 .66644 Mdot
.67926 .72723 Mdot
.42927 .61214 Mdot
.51741 .31897 Mdot
.77416 .4454 Mdot
.41433 .45155 Mdot
.40717 .62344 Mdot
.3671 .6587 Mdot
.34395 .63012 Mdot
.73343 .60344 Mdot
.37613 .41348 Mdot
.44578 .43537 Mdot
.39199 .38711 Mdot
.4434 .36844 Mdot
.40178 .44437 Mdot
.50688 .76457 Mdot
.59741 .55575 Mdot
.51022 .20617 Mdot
.42376 .38917 Mdot
.51153 .62803 Mdot
.35414 .39397 Mdot
.62454 .39367 Mdot
.4297 .41458 Mdot
.50641 .31174 Mdot
.54305 .6288 Mdot
.31364 .43759 Mdot
.46048 .66223 Mdot
.42072 .45889 Mdot
.6026 .37118 Mdot
.43735 .2366 Mdot
.17759 .50652 Mdot
.69614 .57111 Mdot
.40392 .63168 Mdot
.67619 .4639 Mdot
.57357 .65148 Mdot
.65841 .49782 Mdot
.41852 .38994 Mdot
.74828 .60888 Mdot
.56697 .71672 Mdot
.47453 .51949 Mdot
.37086 .45052 Mdot
.41788 .5098 Mdot
.39574 .61717 Mdot
.64185 .51028 Mdot
.34371 .59797 Mdot
.3892 .44935 Mdot
.62915 .35976 Mdot
.61501 .36145 Mdot
.45984 .78385 Mdot
.42355 .19302 Mdot
.3803 .70899 Mdot
.52731 .63431 Mdot
.66663 .4694 Mdot
.60905 .39534 Mdot
.36731 .53641 Mdot
.58199 .624 Mdot
.57534 .62299 Mdot
.54617 .64398 Mdot
.4127 .4438 Mdot
.72696 .62611 Mdot
.45325 .21173 Mdot
.72151 .61991 Mdot
.42415 .4557 Mdot
.67664 .48031 Mdot
.72863 .63125 Mdot
.63479 .34889 Mdot
.5678 .62279 Mdot
.68548 .50777 Mdot
.40587 .43734 Mdot
.3688 .64443 Mdot
.53244 .39505 Mdot
.44095 .28447 Mdot
.62364 .2455 Mdot
.61616 .24027 Mdot
.41359 .64991 Mdot
.49876 .1636 Mdot
.51213 .60656 Mdot
.24003 .45871 Mdot
.63723 .31449 Mdot
.39535 .37452 Mdot
.44027 .82407 Mdot
.6626 .52349 Mdot
.63624 .49921 Mdot
.4018 .42285 Mdot
.69275 .52788 Mdot
.36166 .40924 Mdot
.6888 .51065 Mdot
.6979 .56847 Mdot
.45517 .42167 Mdot
.63845 .49555 Mdot
.35732 .36908 Mdot
.44165 .44173 Mdot
.3855 .60705 Mdot
.65439 .53157 Mdot
.41598 .39131 Mdot
.83156 .39984 Mdot
.51241 .64797 Mdot
.73322 .60414 Mdot
.58838 .47798 Mdot
.53945 .6161 Mdot
.38398 .64987 Mdot
.44994 .44852 Mdot
.64594 .37634 Mdot
.37349 .63535 Mdot
.65509 .55884 Mdot
.64299 .34924 Mdot
.52072 .79883 Mdot
.40359 .62568 Mdot
.73724 .61153 Mdot
.64732 .36336 Mdot
.41323 .50863 Mdot
.64023 .5252 Mdot
.3953 .28872 Mdot
.72204 .61357 Mdot
.36831 .42021 Mdot
.69383 .54209 Mdot
.50551 .63998 Mdot
.38943 .40024 Mdot
.67336 .53406 Mdot
.73192 .60251 Mdot
.41603 .43582 Mdot
.41751 .41217 Mdot
.34477 .74597 Mdot
.65122 .75952 Mdot
.63619 .38518 Mdot
.39201 .59876 Mdot
.39831 .43187 Mdot
.64285 .38939 Mdot
.80206 .52636 Mdot
.34873 .43288 Mdot
.35267 .64154 Mdot
.46766 .35818 Mdot
.68834 .4971 Mdot
.56397 .62171 Mdot
.63003 .47739 Mdot
.62198 .39668 Mdot
.45811 .86684 Mdot
.7369 .63378 Mdot
.34719 .37216 Mdot
.37384 .37735 Mdot
.71037 .47437 Mdot
.37101 .66037 Mdot
.59601 .43128 Mdot
.38036 .43992 Mdot
.47255 .46094 Mdot
.37336 .39129 Mdot
.75686 .42278 Mdot
.37914 .61204 Mdot
.36459 .41945 Mdot
.3245 .35329 Mdot
.37128 .46694 Mdot
.60213 .37855 Mdot
.5664 .26467 Mdot
.34893 .4172 Mdot
.44977 .10348 Mdot
.72586 .6012 Mdot
.6383 .49017 Mdot
.62694 .45569 Mdot
.84636 .52748 Mdot
.31937 .71136 Mdot
.38439 .65987 Mdot
.4917 .44654 Mdot
.65701 .50018 Mdot
.25431 .6748 Mdot
.53472 .16381 Mdot
.43971 .44437 Mdot
.39563 .46596 Mdot
.65577 .52555 Mdot
.69946 .52209 Mdot
.75392 .61806 Mdot
.42632 .39449 Mdot
.37867 .50184 Mdot
.67475 .46884 Mdot
.40572 .45069 Mdot
.41656 .33333 Mdot
.53066 .66321 Mdot
.37814 .60275 Mdot
.56684 .63089 Mdot
.57697 .63754 Mdot
.29223 .51857 Mdot
.49769 .7842 Mdot
.52685 .65599 Mdot
.49051 .64076 Mdot
.49651 .31257 Mdot
.49561 .3869 Mdot
.60905 .39176 Mdot
.5229 .18772 Mdot
.66334 .48658 Mdot
.37769 .41249 Mdot
.40628 .65721 Mdot
.26761 .48696 Mdot
.65022 .59325 Mdot
.60867 .80191 Mdot
.38463 .45186 Mdot
.64975 .48661 Mdot
.72736 .60456 Mdot
.45373 .4152 Mdot
.67796 .41699 Mdot
.39157 .3935 Mdot
.63305 .51188 Mdot
.33404 .56446 Mdot
.40257 .32345 Mdot
.73695 .51391 Mdot
.33927 .65107 Mdot
.36549 .38832 Mdot
.40023 .64533 Mdot
.55108 .62172 Mdot
.63594 .39205 Mdot
.63903 .38182 Mdot
.41298 .40492 Mdot
.37753 .54408 Mdot
.48483 .56951 Mdot
.43817 .44861 Mdot
.43927 .42365 Mdot
.72763 .61684 Mdot
.43981 .42292 Mdot
.37676 .37684 Mdot
.39196 .38412 Mdot
.35917 .46042 Mdot
.53486 .61069 Mdot
.41504 .32396 Mdot
.36543 .47697 Mdot
.33263 .3786 Mdot
.51898 .65811 Mdot
.47394 .48705 Mdot
.5747 .63877 Mdot
.4189 .18209 Mdot
.56667 .64577 Mdot
.63261 .38485 Mdot
.70504 .53543 Mdot
.47961 .45235 Mdot
.3493 .66301 Mdot
.55937 .6085 Mdot
.63124 .36935 Mdot
.5322 .6246 Mdot
.67968 .47863 Mdot
.18476 .42766 Mdot
.4289 .61093 Mdot
.56232 .40802 Mdot
.49756 .58569 Mdot
.63587 .74385 Mdot
.6733 .51839 Mdot
.38239 .60912 Mdot
.28387 .34657 Mdot
.4046 .38872 Mdot
.64324 .35442 Mdot
.40378 .41201 Mdot
.54501 .60929 Mdot
.65372 .48476 Mdot
.63529 .26663 Mdot
.64211 .38062 Mdot
.2549 .7073 Mdot
.65969 .47936 Mdot
.44663 .44284 Mdot
.57732 .62169 Mdot
.15644 .54858 Mdot
.57013 .64194 Mdot
.50833 .36697 Mdot
.38594 .58659 Mdot
.30462 .68859 Mdot
.38803 .63243 Mdot
.70473 .7091 Mdot
.27516 .2386 Mdot
.60975 .21541 Mdot
.36443 .63767 Mdot
.74635 .52389 Mdot
.40716 .45943 Mdot
.34932 .40561 Mdot
.32517 .3659 Mdot
.36453 .59734 Mdot
.39882 .43729 Mdot
.72416 .61351 Mdot
.41924 .751 Mdot
.70849 .4356 Mdot
.67096 .46242 Mdot
.36165 .42489 Mdot
.52153 .65861 Mdot
.51467 .66486 Mdot
.72524 .62816 Mdot
.57077 .65055 Mdot
.44518 .42459 Mdot
.38451 .63245 Mdot
.45286 .53836 Mdot
.63765 .35689 Mdot
.76964 .32724 Mdot
.60009 .35519 Mdot
.62009 .48072 Mdot
.42065 .49492 Mdot
.65809 .50692 Mdot
.59365 .86297 Mdot
.41817 .39659 Mdot
.36312 .64906 Mdot
.41636 .42053 Mdot
.37372 .38389 Mdot
.34911 .40422 Mdot
.69143 .48155 Mdot
.63157 .43805 Mdot
.40677 .4473 Mdot
.54164 .64251 Mdot
.56469 .21462 Mdot
.3695 .37059 Mdot
.7129 .55598 Mdot
.53894 .29577 Mdot
.59699 .75903 Mdot
.34789 .60624 Mdot
.64359 .51092 Mdot
.37821 .64927 Mdot
.34982 .67136 Mdot
.38396 .65006 Mdot
.45878 .20597 Mdot
.28142 .40437 Mdot
.78617 .69361 Mdot
.2935 .6649 Mdot
.2513 .49632 Mdot
.4085 .608 Mdot
.80141 .56665 Mdot
.38986 .66625 Mdot
.38298 .65697 Mdot
.86476 .37285 Mdot
.38268 .67019 Mdot
.37019 .43988 Mdot
.43482 .38495 Mdot
.47864 .73368 Mdot
.49229 .32188 Mdot
.43123 .40998 Mdot
.39967 .42779 Mdot
.64162 .38844 Mdot
.29473 .41318 Mdot
.75728 .62586 Mdot
.51418 .80475 Mdot
.51127 .70387 Mdot
.4068 .41024 Mdot
.40134 .43215 Mdot
.46313 .41664 Mdot
.23293 .26641 Mdot
.28277 .48296 Mdot
.42119 .62959 Mdot
.42703 .50885 Mdot
.71283 .27471 Mdot
.43517 .45872 Mdot
.37352 .45799 Mdot
.41814 .44333 Mdot
.65625 .49898 Mdot
.40594 .66761 Mdot
.42875 .50749 Mdot
.5799 .75115 Mdot
.41112 .46282 Mdot
.56789 .5959 Mdot
.62003 .41535 Mdot
.36574 .43129 Mdot
.34848 .62003 Mdot
.42833 .42607 Mdot
.4061 .63167 Mdot
.39031 .60671 Mdot
.46531 .42312 Mdot
.43892 .20624 Mdot
.35042 .63178 Mdot
.42326 .45317 Mdot
.64768 .50739 Mdot
.60502 .20501 Mdot
.36804 .42339 Mdot
.61566 .38568 Mdot
.38308 .44084 Mdot
.60373 .36975 Mdot
.43826 .4396 Mdot
.72114 .616 Mdot
.2352 .41569 Mdot
.662 .49149 Mdot
.59616 .32256 Mdot
.7032 .50731 Mdot
.34872 .74707 Mdot
.35431 .64608 Mdot
.75573 .61233 Mdot
.56941 .83136 Mdot
.72886 .61473 Mdot
.53062 .40106 Mdot
.68246 .57807 Mdot
.51392 .63161 Mdot
.36298 .60377 Mdot
.58704 .30604 Mdot
.72785 .54734 Mdot
.62195 .53129 Mdot
.7066 .49216 Mdot
.46797 .85544 Mdot
.52152 .83701 Mdot
.40906 .43994 Mdot
.31743 .30096 Mdot
.2371 .58577 Mdot
.35558 .44448 Mdot
.43915 .46296 Mdot
.63724 .52453 Mdot
.35808 .3995 Mdot
.53199 .49152 Mdot
.67594 .50944 Mdot
.62851 .37432 Mdot
.39205 .65148 Mdot
.60534 .36778 Mdot
.64178 .53872 Mdot
.59243 .54699 Mdot
.68579 .50171 Mdot
.35215 .45065 Mdot
.41226 .42274 Mdot
.40269 .61407 Mdot
.38291 .56353 Mdot
.3827 .60379 Mdot
.63203 .34143 Mdot
.67519 .50084 Mdot
.27193 .47177 Mdot
.38918 .42713 Mdot
.37847 .62759 Mdot
.54876 .68573 Mdot
.39239 .43074 Mdot
.54121 .61925 Mdot
.40323 .4649 Mdot
.3618 .63688 Mdot
.44006 .42365 Mdot
.38466 .63446 Mdot
.6562 .51958 Mdot
.42638 .46454 Mdot
.40037 .42123 Mdot
.17624 .58366 Mdot
.63861 .37553 Mdot
.35454 .64506 Mdot
.53486 .54054 Mdot
.44825 .43245 Mdot
.68336 .44332 Mdot
.35789 .42813 Mdot
.49297 .40806 Mdot
.35002 .37388 Mdot
.72636 .61117 Mdot
.37354 .48841 Mdot
.3675 .42245 Mdot
.34114 .32178 Mdot
.2685 .62693 Mdot
.3444 .59601 Mdot
.55559 .61037 Mdot
.35104 .61616 Mdot
.6509 .53529 Mdot
.68433 .53712 Mdot
.69525 .51333 Mdot
.49879 .33735 Mdot
.45764 .40653 Mdot
.36739 .40426 Mdot
.55786 .60619 Mdot
.62287 .37885 Mdot
.37186 .62459 Mdot
.619 .3764 Mdot
.50509 .80154 Mdot
.63218 .34239 Mdot
.72555 .62651 Mdot
.75825 .43483 Mdot
.258 .42508 Mdot
.64349 .38593 Mdot
.38093 .60329 Mdot
.7709 .45161 Mdot
.39638 .37602 Mdot
.63137 .55584 Mdot
.62731 .35962 Mdot
.42779 .85427 Mdot
.3577 .43539 Mdot
.55082 .44338 Mdot
.55167 .66022 Mdot
.6187 .35253 Mdot
.55516 .63466 Mdot
.42503 .40697 Mdot
.62044 .72833 Mdot
.36838 .66336 Mdot
.4994 .63737 Mdot
.36102 .47481 Mdot
.60955 .35949 Mdot
.6755 .48728 Mdot
.51869 .58179 Mdot
.51194 .62819 Mdot
.22513 .39173 Mdot
.61088 .267 Mdot
.67552 .50308 Mdot
.73161 .71239 Mdot
.55189 .64512 Mdot
.35234 .43887 Mdot
.47647 .42312 Mdot
.43457 .40568 Mdot
.67931 .54105 Mdot
.64054 .5065 Mdot
.44483 .74837 Mdot
.41485 .4237 Mdot
.35769 .43241 Mdot
.42782 .62909 Mdot
.67071 .51368 Mdot
.39409 .62415 Mdot
.34328 .628 Mdot
.64832 .51856 Mdot
.39276 .63569 Mdot
.64323 .35131 Mdot
.40754 .72969 Mdot
.5513 .64618 Mdot
.54241 .63931 Mdot
.65326 .48037 Mdot
.64548 .47311 Mdot
.65935 .50893 Mdot
.40353 .46484 Mdot
.37253 .61779 Mdot
.42711 .4401 Mdot
.34789 .43343 Mdot
.35002 .59819 Mdot
.37716 .67294 Mdot
.42413 .43271 Mdot
.71433 .47108 Mdot
.60984 .40585 Mdot
.64013 .49374 Mdot
.54649 .65689 Mdot
.25616 .672 Mdot
.57112 .60878 Mdot
.36061 .42404 Mdot
.61168 .59008 Mdot
.36159 .63096 Mdot
.64063 .35345 Mdot
.60122 .40476 Mdot
.64541 .36574 Mdot
.58818 .64848 Mdot
.34487 .64961 Mdot
.52038 .7977 Mdot
.36125 .41572 Mdot
.54516 .498 Mdot
.59333 .29657 Mdot
.53228 .76979 Mdot
.53243 .65729 Mdot
.39635 .43045 Mdot
.73067 .61298 Mdot
.27314 .37937 Mdot
.3873 .39329 Mdot
.40477 .3844 Mdot
.7279 .36645 Mdot
.33251 .37801 Mdot
.36671 .59416 Mdot
.42384 .79459 Mdot
.4186 .3745 Mdot
.42989 .66486 Mdot
.86573 .56305 Mdot
.35832 .4166 Mdot
.3946 .44857 Mdot
.37668 .42279 Mdot
.42314 .41878 Mdot
.37222 .58864 Mdot
.55355 .36833 Mdot
.57553 .61947 Mdot
.56195 .50893 Mdot
.54113 .65011 Mdot
.63748 .51857 Mdot
.54687 .4489 Mdot
.36753 .60287 Mdot
.64348 .35719 Mdot
.255 .34469 Mdot
.47506 .80385 Mdot
.6768 .51977 Mdot
.3082 .50221 Mdot
.63533 .3584 Mdot
.39965 .37461 Mdot
.63567 .3353 Mdot
.70135 .51979 Mdot
.5295 .64632 Mdot
.43621 .38721 Mdot
.41371 .64134 Mdot
.35697 .62193 Mdot
.39522 .43535 Mdot
.67521 .25248 Mdot
.54809 .61825 Mdot
.5977 .64712 Mdot
.41313 .4465 Mdot
.40625 .38476 Mdot
.39831 .63096 Mdot
.64405 .49651 Mdot
.7703 .55992 Mdot
.63528 .37378 Mdot
.40875 .47866 Mdot
.42643 .41788 Mdot
.48566 .79357 Mdot
.56757 .6192 Mdot
.75064 .61897 Mdot
.41335 .43932 Mdot
.49047 .78304 Mdot
.41419 .43734 Mdot
.4381 .47592 Mdot
.653 .50658 Mdot
.35605 .3775 Mdot
.3908 .46184 Mdot
.39854 .52348 Mdot
.55622 .64032 Mdot
.36651 .65455 Mdot
.41571 .6041 Mdot
.74281 .6066 Mdot
.54043 .62008 Mdot
.42547 .43001 Mdot
.559 .6157 Mdot
.34845 .41123 Mdot
.40512 .44523 Mdot
.5321 .65691 Mdot
.39427 .62478 Mdot
.55424 .70334 Mdot
.48972 .35927 Mdot
.42057 .42061 Mdot
.43708 .3935 Mdot
.5018 .33306 Mdot
.65132 .80334 Mdot
.37926 .45028 Mdot
.35867 .63288 Mdot
.39403 .42567 Mdot
.55232 .62866 Mdot
.62647 .34385 Mdot
.36548 .64184 Mdot
.64919 .47588 Mdot
.65787 .52234 Mdot
.45711 .66352 Mdot
.7302 .63096 Mdot
.44288 .40187 Mdot
.32639 .61988 Mdot
.39664 .6664 Mdot
.85175 .4505 Mdot
.63363 .49976 Mdot
.60068 .37703 Mdot
.4186 .40972 Mdot
.53344 .57279 Mdot
.56596 .60849 Mdot
.44622 .10314 Mdot
.52477 .79311 Mdot
.63435 .3289 Mdot
.59887 .80966 Mdot
.73601 .61496 Mdot
.3757 .45591 Mdot
.63196 .39372 Mdot
.67516 .52645 Mdot
.36144 .38579 Mdot
.37425 .34776 Mdot
.59297 .43466 Mdot
.67439 .45423 Mdot
.56185 .61799 Mdot
.6925 .50342 Mdot
.65631 .35844 Mdot
.72484 .62553 Mdot
.36216 .61048 Mdot
.36675 .41721 Mdot
.46626 .4533 Mdot
.64399 .48475 Mdot
.72066 .61529 Mdot
.41489 .45178 Mdot
.35511 .62128 Mdot
.69307 .52498 Mdot
.40706 .40567 Mdot
.24428 .46673 Mdot
.34186 .66434 Mdot
.67359 .49275 Mdot
.37451 .37835 Mdot
.48385 .39233 Mdot
.65185 .47757 Mdot
.64102 .48416 Mdot
.39912 .43689 Mdot
.64588 .35796 Mdot
.40057 .46941 Mdot
.56286 .65173 Mdot
.63083 .43832 Mdot
.54988 .6302 Mdot
.64836 .30693 Mdot
.41216 .49461 Mdot
.64907 .74156 Mdot
.4003 .60707 Mdot
.65738 .37734 Mdot
.18776 .55653 Mdot
.41032 .38392 Mdot
.47742 .17489 Mdot
.48175 .51096 Mdot
.77978 .32163 Mdot
.26455 .27441 Mdot
.62395 .36326 Mdot
.53723 .62318 Mdot
.39446 .44776 Mdot
.5279 .60349 Mdot
.63422 .38977 Mdot
.61178 .28951 Mdot
.37869 .37791 Mdot
.38187 .61208 Mdot
.41172 .46119 Mdot
.40419 .63258 Mdot
.39036 .43199 Mdot
.32925 .39888 Mdot
.65497 .32989 Mdot
.50623 .36405 Mdot
.39844 .37559 Mdot
.18333 .42674 Mdot
.54314 .56019 Mdot
.63355 .36264 Mdot
.42572 .44666 Mdot
.74293 .62464 Mdot
.53436 .67041 Mdot
.39385 .25801 Mdot
.65758 .50275 Mdot
.52754 .65813 Mdot
.39452 .64219 Mdot
.63421 .48079 Mdot
.73122 .60107 Mdot
.47066 .43899 Mdot
.60425 .37763 Mdot
.51675 .62871 Mdot
.36643 .42626 Mdot
.35868 .43689 Mdot
.74686 .50389 Mdot
.68126 .65384 Mdot
.41731 .65741 Mdot
.22255 .66739 Mdot
.36324 .59251 Mdot
.63196 .38127 Mdot
.65473 .50754 Mdot
.37406 .44768 Mdot
.39483 .39929 Mdot
.67401 .53952 Mdot
.35562 .64737 Mdot
.65272 .44923 Mdot
.30259 .51512 Mdot
.65207 .46528 Mdot
.54748 .3251 Mdot
.36146 .64479 Mdot
.54622 .33083 Mdot
.65675 .35974 Mdot
.40875 .20901 Mdot
.47208 .27048 Mdot
.5512 .66081 Mdot
.55017 .31939 Mdot
.36593 .62869 Mdot
.40962 .43072 Mdot
.73905 .61339 Mdot
.73995 .63254 Mdot
.39746 .64395 Mdot
.65602 .52652 Mdot
.61724 .35495 Mdot
.39717 .44994 Mdot
.58046 .78573 Mdot
.46318 .70622 Mdot
.66338 .4685 Mdot
.37532 .33818 Mdot
.55096 .63878 Mdot
.39197 .45967 Mdot
.61155 .38129 Mdot
.51786 .63399 Mdot
.71817 .59613 Mdot
.42119 .74445 Mdot
.41688 .40405 Mdot
.44756 .78816 Mdot
.5329 .62104 Mdot
.73856 .71079 Mdot
.3982 .41089 Mdot
.55221 .64484 Mdot
.33635 .45543 Mdot
.57676 .73475 Mdot
.49619 .53699 Mdot
.54601 .17205 Mdot
.6932 .46824 Mdot
.65998 .52511 Mdot
.63359 .6785 Mdot
.64723 .32109 Mdot
.5127 .6524 Mdot
.72397 .62443 Mdot
.52233 .25283 Mdot
.55528 .63683 Mdot
.38118 .4635 Mdot
.35812 .4263 Mdot
.28615 .51194 Mdot
.52128 .51928 Mdot
.71976 .61793 Mdot
.36273 .7166 Mdot
.43946 .40898 Mdot
.33444 .40923 Mdot
.38893 .40326 Mdot
.41778 .62297 Mdot
.53603 .61621 Mdot
.1518 .521 Mdot
.55406 .62003 Mdot
.58543 .79088 Mdot
.66237 .48625 Mdot
.65449 .46711 Mdot
.36446 .43155 Mdot
.68122 .7348 Mdot
.38598 .25326 Mdot
.44431 .44124 Mdot
.67609 .43523 Mdot
.60154 .26492 Mdot
.3324 .42322 Mdot
.39641 .58828 Mdot
.45964 .46379 Mdot
.33127 .66432 Mdot
.517 .64397 Mdot
.61902 .36427 Mdot
.60668 .40245 Mdot
.51515 .63283 Mdot
.3688 .40422 Mdot
.66056 .41741 Mdot
.37863 .39065 Mdot
.41104 .43839 Mdot
.55025 .81161 Mdot
.60337 .3888 Mdot
.66073 .51206 Mdot
.64049 .38109 Mdot
.38124 .65798 Mdot
.75219 .2185 Mdot
.61559 .37598 Mdot
.32467 .61637 Mdot
.5688 .35685 Mdot
.55037 .32311 Mdot
.3572 .61857 Mdot
.65084 .35478 Mdot
.56106 .62029 Mdot
.77399 .30875 Mdot
.69876 .76026 Mdot
.56747 .60458 Mdot
.39909 .40646 Mdot
.376 .60041 Mdot
.41767 .63906 Mdot
.50103 .62103 Mdot
.37307 .60781 Mdot
.39366 .50276 Mdot
.41622 .42681 Mdot
.5125 .65208 Mdot
.46794 .72667 Mdot
.51456 .62416 Mdot
.39805 .7395 Mdot
.42108 .45006 Mdot
.36398 .64496 Mdot
.44158 .48997 Mdot
.42667 .61234 Mdot
.75374 .62532 Mdot
.36106 .38549 Mdot
.62879 .34832 Mdot
.52871 .50749 Mdot
.67104 .49164 Mdot
.60915 .58732 Mdot
.40033 .61352 Mdot
.55109 .69538 Mdot
.38502 .60665 Mdot
.37678 .59748 Mdot
.57719 .64034 Mdot
.37863 .66389 Mdot
.39507 .4495 Mdot
.73694 .5037 Mdot
.40746 .63991 Mdot
.53412 .63381 Mdot
.6271 .35254 Mdot
.39373 .63154 Mdot
.6292 .50965 Mdot
.41132 .41534 Mdot
.68856 .50434 Mdot
.63834 .32645 Mdot
.36104 .60519 Mdot
.64952 .35291 Mdot
.63684 .49338 Mdot
.60889 .38624 Mdot
.64749 .27483 Mdot
.50641 .62629 Mdot
.61529 .79817 Mdot
.47431 .35668 Mdot
.41264 .64364 Mdot
.62832 .54099 Mdot
.37617 .44757 Mdot
.41406 .4142 Mdot
.65575 .36857 Mdot
.41631 .64322 Mdot
.62464 .21977 Mdot
.49054 .42022 Mdot
.41517 .73079 Mdot
.52006 .6144 Mdot
.26005 .698 Mdot
.45659 .76583 Mdot
.79122 .38061 Mdot
.37652 .35911 Mdot
.73659 .61504 Mdot
.36652 .39628 Mdot
.17336 .52203 Mdot
.61755 .3474 Mdot
.78358 .60873 Mdot
.39888 .35898 Mdot
.66606 .50613 Mdot
.38926 .41866 Mdot
.35442 .29351 Mdot
.45637 .46768 Mdot
.64873 .3805 Mdot
.59279 .60402 Mdot
.34952 .66286 Mdot
.6373 .35757 Mdot
.66192 .52182 Mdot
.54427 .27063 Mdot
.36696 .37868 Mdot
.44374 .4131 Mdot
.66735 .46471 Mdot
.37993 .61005 Mdot
.63955 .5232 Mdot
.55071 .64639 Mdot
.61816 .37225 Mdot
.42244 .41239 Mdot
.33845 .40096 Mdot
.65513 .43663 Mdot
.53677 .61541 Mdot
.6417 .47209 Mdot
.56769 .63088 Mdot
.73693 .61415 Mdot
.42164 .38 Mdot
.67777 .46884 Mdot
.35616 .43679 Mdot
.18385 .57086 Mdot
.55721 .8137 Mdot
.27505 .61002 Mdot
.66288 .51428 Mdot
.53174 .31243 Mdot
.54553 .62702 Mdot
.56851 .64128 Mdot
.29846 .68864 Mdot
.43185 .23567 Mdot
.77377 .42922 Mdot
.23031 .36847 Mdot
.55009 .64706 Mdot
.54612 .63285 Mdot
.6793 .52669 Mdot
.3882 .66063 Mdot
.35339 .68115 Mdot
.63498 .47199 Mdot
.4949 .35235 Mdot
.372 .62468 Mdot
.49262 .17202 Mdot
.6406 .52997 Mdot
.37845 .35742 Mdot
.75408 .63737 Mdot
.61573 .36316 Mdot
.4952 .35361 Mdot
.3428 .30435 Mdot
.37118 .44849 Mdot
.39593 .78999 Mdot
.64697 .49798 Mdot
.57229 .40459 Mdot
.41042 .18798 Mdot
.38289 .37954 Mdot
.38297 .41328 Mdot
.37292 .40206 Mdot
.60268 .39029 Mdot
.18561 .53729 Mdot
.37092 .44947 Mdot
.52202 .37506 Mdot
.43515 .46424 Mdot
.42423 .27682 Mdot
.63865 .38263 Mdot
.44208 .65511 Mdot
.68786 .46609 Mdot
.55944 .75965 Mdot
.3257 .36735 Mdot
.56225 .63817 Mdot
.69011 .5551 Mdot
.52947 .649 Mdot
.4114 .23007 Mdot
.47711 .27142 Mdot
.40863 .60596 Mdot
.38538 .45291 Mdot
.70781 .5024 Mdot
.39332 .60545 Mdot
.72167 .57874 Mdot
.84934 .3414 Mdot
.54453 .61239 Mdot
.64239 .82707 Mdot
.56944 .64022 Mdot
.7488 .62962 Mdot
.3987 .63438 Mdot
.29838 .45957 Mdot
.54381 .49749 Mdot
.39234 .63253 Mdot
.56695 .71394 Mdot
.37778 .58332 Mdot
.54149 .31305 Mdot
.34224 .65489 Mdot
.53719 .6307 Mdot
.53735 .67479 Mdot
.36851 .35404 Mdot
.37719 .44415 Mdot
.57352 .50681 Mdot
.44265 .51623 Mdot
.38013 .44707 Mdot
.67573 .50946 Mdot
.6843 .76041 Mdot
.71404 .53118 Mdot
.40256 .65533 Mdot
.56668 .61431 Mdot
.38458 .41455 Mdot
.41974 .42655 Mdot
.35136 .42973 Mdot
.17613 .58982 Mdot
.4996 .17379 Mdot
.40684 .44427 Mdot
.40097 .47937 Mdot
.6589 .51898 Mdot
.65418 .39998 Mdot
.20294 .41258 Mdot
.50988 .25764 Mdot
.39995 .39212 Mdot
.64096 .37485 Mdot
.59844 .37035 Mdot
.38234 .37034 Mdot
.59105 .76932 Mdot
.74315 .5251 Mdot
.36664 .42621 Mdot
.44868 .26406 Mdot
.66923 .54693 Mdot
.72353 .62694 Mdot
.64497 .48384 Mdot
.34688 .62155 Mdot
.72785 .62453 Mdot
.70115 .50783 Mdot
.28917 .44569 Mdot
.74288 .60567 Mdot
.55753 .7362 Mdot
.63198 .34141 Mdot
.38873 .39979 Mdot
.38839 .58294 Mdot
.67973 .53978 Mdot
.51381 .63365 Mdot
.37699 .64187 Mdot
.52261 .66916 Mdot
.65973 .33548 Mdot
.54215 .38362 Mdot
.73426 .63294 Mdot
.55882 .64373 Mdot
.42058 .74525 Mdot
.6407 .37707 Mdot
.57267 .64581 Mdot
.68487 .72851 Mdot
.38901 .36188 Mdot
.33391 .26494 Mdot
.43218 .45621 Mdot
.71514 .27165 Mdot
.57322 .63579 Mdot
.74554 .60446 Mdot
.36591 .40825 Mdot
.65849 .47893 Mdot
.36208 .48979 Mdot
.3939 .39353 Mdot
.66209 .47147 Mdot
.409 .43784 Mdot
.61325 .38503 Mdot
.33396 .65634 Mdot
.45321 .53095 Mdot
.31169 .7736 Mdot
.60715 .382 Mdot
.72913 .58835 Mdot
.381 .45106 Mdot
.63021 .26598 Mdot
.39233 .62952 Mdot
.39352 .38132 Mdot
.30861 .69702 Mdot
.39811 .65255 Mdot
.381 .64616 Mdot
.43662 .42969 Mdot
.56005 .6576 Mdot
.66557 .48279 Mdot
.64238 .37539 Mdot
.81035 .39079 Mdot
.40453 .4001 Mdot
.39714 .42328 Mdot
.63558 .35773 Mdot
.54836 .63144 Mdot
.4216 .42536 Mdot
.63295 .59161 Mdot
.8191 .3769 Mdot
.57881 .63343 Mdot
.36742 .37102 Mdot
.29023 .29936 Mdot
.42935 .64986 Mdot
.64966 .81338 Mdot
.58968 .33683 Mdot
.64529 .51145 Mdot
.32866 .40747 Mdot
.49945 .1088 Mdot
.61866 .36213 Mdot
.54187 .77306 Mdot
.4082 .45145 Mdot
.38339 .42654 Mdot
.36205 .61987 Mdot
.42701 .4355 Mdot
.36084 .65842 Mdot
.3482 .80742 Mdot
.24522 .71537 Mdot
.39268 .61255 Mdot
.40242 .65809 Mdot
.37921 .69513 Mdot
.19813 .4364 Mdot
.39214 .64876 Mdot
.35542 .38652 Mdot
.56551 .20598 Mdot
.46552 .41283 Mdot
.65558 .3771 Mdot
.60102 .34637 Mdot
.44895 .62652 Mdot
.74166 .67605 Mdot
.47437 .48227 Mdot
.31481 .39767 Mdot
.48424 .57657 Mdot
.55894 .65183 Mdot
.39683 .38802 Mdot
.73039 .63145 Mdot
.69633 .50675 Mdot
.45982 .45137 Mdot
.38551 .39644 Mdot
.40579 .63444 Mdot
.60921 .39941 Mdot
.56153 .66154 Mdot
.39996 .42728 Mdot
.65859 .44601 Mdot
.63131 .3749 Mdot
.40764 .64483 Mdot
.3199 .69434 Mdot
.62134 .39857 Mdot
.37026 .48766 Mdot
.38183 .43814 Mdot
.41489 .45052 Mdot
.33232 .37168 Mdot
.51283 .64517 Mdot
.64837 .5419 Mdot
.34559 .43105 Mdot
.50545 .79878 Mdot
.55948 .43199 Mdot
.34414 .39013 Mdot
.36719 .62186 Mdot
.57209 .61138 Mdot
.75199 .61789 Mdot
.57081 .27847 Mdot
.41354 .40121 Mdot
.49896 .1758 Mdot
.28859 .49295 Mdot
.72996 .62498 Mdot
.39563 .59912 Mdot
.64312 .35762 Mdot
.44207 .41626 Mdot
.51843 .19998 Mdot
.35898 .42728 Mdot
.49186 .38097 Mdot
.64497 .50388 Mdot
.55471 .65267 Mdot
.8048 .34584 Mdot
.69627 .50314 Mdot
.37907 .6484 Mdot
.55332 .16802 Mdot
.38914 .67562 Mdot
.35444 .66493 Mdot
.43667 .21058 Mdot
.5206 .65028 Mdot
.48324 .10883 Mdot
.67933 .78159 Mdot
.37053 .46256 Mdot
.55427 .62635 Mdot
.40087 .62786 Mdot
.39308 .45927 Mdot
.3968 .6652 Mdot
.35466 .66196 Mdot
.35837 .38907 Mdot
.38115 .43323 Mdot
.51536 .38305 Mdot
.44873 .17523 Mdot
.64665 .36946 Mdot
.35549 .63964 Mdot
.25461 .51027 Mdot
.3734 .45236 Mdot
.36146 .41622 Mdot
.7224 .49043 Mdot
.64811 .38137 Mdot
.32749 .33028 Mdot
.41264 .43896 Mdot
.32653 .74789 Mdot
.43729 .39275 Mdot
.4005 .58756 Mdot
.57894 .63481 Mdot
.58205 .7705 Mdot
.66994 .54139 Mdot
.35241 .6354 Mdot
.60756 .36103 Mdot
.42302 .61648 Mdot
.3063 .63643 Mdot
.52188 .64887 Mdot
.36179 .63685 Mdot
.63015 .50239 Mdot
.52519 .64111 Mdot
.57319 .64268 Mdot
.56455 .21401 Mdot
.63955 .47196 Mdot
.63217 .3398 Mdot
.53559 .64729 Mdot
.23911 .46189 Mdot
.53321 .62919 Mdot
.2677 .51136 Mdot
.42147 .46592 Mdot
.52712 .37575 Mdot
.47849 .76517 Mdot
.34114 .3549 Mdot
.50642 .63626 Mdot
.63756 .387 Mdot
.43297 .42144 Mdot
.3708 .60919 Mdot
.61478 .37416 Mdot
.51945 .58914 Mdot
.64221 .4783 Mdot
.40612 .61451 Mdot
.57979 .62442 Mdot
.35854 .6442 Mdot
.57337 .31916 Mdot
.60525 .47819 Mdot
.48234 .58685 Mdot
.55008 .48534 Mdot
.35359 .43772 Mdot
.42599 .57821 Mdot
.44472 .40288 Mdot
.38533 .39425 Mdot
.67287 .49183 Mdot
.50091 .33927 Mdot
.39491 .6249 Mdot
.81239 .3532 Mdot
.55868 .64663 Mdot
.36655 .76737 Mdot
.48405 .40264 Mdot
.40744 .38717 Mdot
.40597 .64265 Mdot
.37689 .67858 Mdot
.2699 .62605 Mdot
.66847 .53856 Mdot
.37389 .34431 Mdot
.40959 .49132 Mdot
.35965 .36105 Mdot
.57268 .63418 Mdot
.63595 .6077 Mdot
.65014 .52648 Mdot
.7882 .70063 Mdot
.64121 .49362 Mdot
.70994 .37937 Mdot
.37948 .66433 Mdot
.62133 .34715 Mdot
.36197 .41964 Mdot
.5077 .39942 Mdot
.39496 .59174 Mdot
.58097 .37992 Mdot
.63471 .34831 Mdot
.62777 .66121 Mdot
.52348 .65469 Mdot
.38684 .37272 Mdot
.36455 .38656 Mdot
.42893 .44212 Mdot
.42277 .4611 Mdot
.55917 .61239 Mdot
.37839 .46178 Mdot
.50062 .6351 Mdot
.24674 .4541 Mdot
.32656 .75072 Mdot
.70554 .52647 Mdot
.40764 .24874 Mdot
.41385 .63405 Mdot
.2328 .48751 Mdot
.43081 .34097 Mdot
.56812 .81191 Mdot
.626 .25467 Mdot
.44736 .41422 Mdot
.66741 .531 Mdot
.3323 .29663 Mdot
.70662 .51056 Mdot
.40236 .88064 Mdot
.66139 .40055 Mdot
.52623 .16142 Mdot
.3905 .45685 Mdot
.71166 .47506 Mdot
.458 .35752 Mdot
.37571 .37031 Mdot
.66612 .38219 Mdot
.3372 .7235 Mdot
.49342 .74061 Mdot
.60345 .38614 Mdot
.41058 .41167 Mdot
.35248 .66681 Mdot
.39485 .45129 Mdot
.36113 .40839 Mdot
.39585 .46246 Mdot
.58092 .63725 Mdot
.44831 .39842 Mdot
.39344 .46734 Mdot
.68809 .65129 Mdot
.51193 .32035 Mdot
.69046 .49853 Mdot
.28781 .64643 Mdot
.62272 .37828 Mdot
.40524 .6248 Mdot
.52207 .46063 Mdot
.54952 .6604 Mdot
.2589 .6335 Mdot
.40552 .46493 Mdot
.46577 .75944 Mdot
.57914 .62333 Mdot
.61487 .36985 Mdot
.7423 .60776 Mdot
.57425 .1962 Mdot
.70418 .52709 Mdot
.74485 .60702 Mdot
.66946 .49127 Mdot
.19354 .54461 Mdot
.40549 .63678 Mdot
.35025 .42998 Mdot
.54618 .64325 Mdot
.66776 .4819 Mdot
.48344 .32172 Mdot
.38469 .40346 Mdot
.66663 .51601 Mdot
.35238 .43743 Mdot
.55807 .40466 Mdot
.75164 .50893 Mdot
.7043 .50429 Mdot
.57731 .65946 Mdot
.53083 .64107 Mdot
.64152 .34879 Mdot
.40577 .62159 Mdot
.36227 .62854 Mdot
.5188 .63477 Mdot
.60412 .83359 Mdot
.39403 .39239 Mdot
.38883 .45837 Mdot
.50574 .79634 Mdot
.38937 .44514 Mdot
.54639 .28557 Mdot
.74996 .63501 Mdot
.40951 .62765 Mdot
.39723 .45947 Mdot
.42175 .42243 Mdot
.41815 .40673 Mdot
.56866 .32662 Mdot
.64268 .48688 Mdot
.43979 .4101 Mdot
.63915 .39298 Mdot
.67736 .71468 Mdot
.38171 .45725 Mdot
.33692 .39465 Mdot
.36416 .63289 Mdot
.27165 .7348 Mdot
.55888 .65631 Mdot
.67741 .51407 Mdot
.63752 .48717 Mdot
.60294 .33588 Mdot
.34234 .61346 Mdot
.75692 .62729 Mdot
.8369 .50239 Mdot
.72956 .60645 Mdot
.6374 .36313 Mdot
.72875 .34826 Mdot
.6513 .4453 Mdot
.68226 .51797 Mdot
.50009 .65299 Mdot
.41016 .46409 Mdot
.44725 .42953 Mdot
.54538 .77506 Mdot
.43026 .39964 Mdot
.63035 .34995 Mdot
.51053 .65231 Mdot
.36833 .63082 Mdot
.61382 .36311 Mdot
.56628 .63111 Mdot
.37752 .61016 Mdot
.39219 .36243 Mdot
.40216 .36279 Mdot
.38032 .64188 Mdot
.38695 .60398 Mdot
.37027 .43385 Mdot
.66993 .64822 Mdot
.34491 .61974 Mdot
.36158 .64034 Mdot
.71872 .62435 Mdot
.70576 .52366 Mdot
.45181 .48747 Mdot
.55436 .62496 Mdot
.41403 .44948 Mdot
.70689 .51545 Mdot
.65055 .37517 Mdot
.38902 .62331 Mdot
.41933 .42291 Mdot
.40707 .42682 Mdot
.64248 .37134 Mdot
.61611 .39998 Mdot
.61414 .35791 Mdot
.52606 .60248 Mdot
.4325 .45029 Mdot
.39088 .64791 Mdot
.52496 .65403 Mdot
.59847 .3704 Mdot
.62567 .33726 Mdot
.71433 .65834 Mdot
.36857 .4449 Mdot
.49205 .54314 Mdot
.71626 .1943 Mdot
.53247 .26586 Mdot
.75351 .62085 Mdot
.65664 .46373 Mdot
.53519 .35106 Mdot
.73475 .48567 Mdot
.54041 .617 Mdot
.50139 .23194 Mdot
.65726 .37736 Mdot
.34885 .41814 Mdot
.43483 .39116 Mdot
.42858 .47385 Mdot
.62675 .37244 Mdot
.58238 .30019 Mdot
.41489 .64883 Mdot
.22035 .55009 Mdot
.6226 .37801 Mdot
.70412 .50561 Mdot
.68736 .47424 Mdot
.64114 .49442 Mdot
.4151 .37463 Mdot
.26337 .62398 Mdot
.24228 .49197 Mdot
.20564 .46073 Mdot
.52463 .65656 Mdot
.40567 .66834 Mdot
.64095 .2733 Mdot
.38286 .64369 Mdot
.69785 .50798 Mdot
.63046 .3708 Mdot
.35846 .62819 Mdot
.52165 .62288 Mdot
.54679 .63439 Mdot
.64518 .47733 Mdot
.6538 .48141 Mdot
.68392 .49453 Mdot
.34446 .63525 Mdot
.37909 .66395 Mdot
.41841 .4008 Mdot
.38386 .62849 Mdot
.41957 .80234 Mdot
.62298 .33177 Mdot
.69854 .48655 Mdot
.54223 .62161 Mdot
.40356 .6278 Mdot
.39237 .40156 Mdot
.75583 .39533 Mdot
.47645 .67121 Mdot
.61272 .38861 Mdot
.75411 .53946 Mdot
.44993 .88986 Mdot
.36009 .39159 Mdot
.56466 .61901 Mdot
.60934 .76261 Mdot
.37662 .40413 Mdot
.65403 .49986 Mdot
.17344 .53881 Mdot
.72417 .60826 Mdot
.39127 .46591 Mdot
.42004 .39294 Mdot
.57182 .6493 Mdot
.57444 .34254 Mdot
.42473 .40268 Mdot
.42156 .77205 Mdot
.55441 .66809 Mdot
.67071 .53403 Mdot
.82929 .38861 Mdot
.61608 .50137 Mdot
.46336 .33104 Mdot
.74632 .62925 Mdot
.37116 .38383 Mdot
.6782 .50627 Mdot
.6191 .39241 Mdot
.68098 .49741 Mdot
.40061 .60084 Mdot
.6885 .49806 Mdot
.39519 .42331 Mdot
.38865 .65127 Mdot
.53476 .62021 Mdot
.42745 .79519 Mdot
.6917 .6639 Mdot
.65764 .47863 Mdot
.71499 .61982 Mdot
.38029 .45943 Mdot
.33803 .33341 Mdot
.36743 .49522 Mdot
.38318 .45622 Mdot
.52913 .64991 Mdot
.40553 .64576 Mdot
.53301 .61028 Mdot
.34239 .44027 Mdot
.30053 .72526 Mdot
.57071 .64056 Mdot
.53673 .74257 Mdot
.63615 .35931 Mdot
.50448 .36707 Mdot
.39701 .39788 Mdot
.54237 .64658 Mdot
.43122 .45084 Mdot
.37532 .67397 Mdot
.55592 .5401 Mdot
.68372 .71953 Mdot
.54601 .64244 Mdot
.65205 .22588 Mdot
.53888 .54539 Mdot
.4583 .47148 Mdot
.54563 .64788 Mdot
.22184 .60688 Mdot
.74845 .6233 Mdot
.63647 .37217 Mdot
.59898 .37524 Mdot
.60762 .38577 Mdot
.4265 .39259 Mdot
.40668 .34234 Mdot
.62744 .33842 Mdot
.56961 .65933 Mdot
.64696 .38475 Mdot
.51649 .39849 Mdot
.64302 .22257 Mdot
.60888 .3645 Mdot
.40218 .40842 Mdot
.33527 .3967 Mdot
.5087 .32089 Mdot
.69607 .52263 Mdot
.4723 .17607 Mdot
.36069 .53204 Mdot
.37343 .44352 Mdot
.47228 .44273 Mdot
.41062 .61478 Mdot
.64958 .75682 Mdot
.48079 .42133 Mdot
.74472 .50955 Mdot
.38195 .66933 Mdot
.61999 .4789 Mdot
.40805 .6257 Mdot
.35437 .4106 Mdot
.4045 .44681 Mdot
.33623 .67139 Mdot
.6132 .60815 Mdot
.61346 .72465 Mdot
.76169 .32115 Mdot
.35799 .63526 Mdot
.55587 .64047 Mdot
.54763 .61192 Mdot
.53474 .65845 Mdot
.65483 .53702 Mdot
.3584 .6081 Mdot
.44084 .4386 Mdot
.65287 .51909 Mdot
.3926 .38979 Mdot
.52839 .64498 Mdot
.80156 .3402 Mdot
.36545 .63237 Mdot
.36709 .42295 Mdot
.69675 .76109 Mdot
.65359 .48814 Mdot
.63778 .37953 Mdot
.56553 .40757 Mdot
.63018 .51867 Mdot
.50946 .62995 Mdot
.36065 .68154 Mdot
.57255 .5981 Mdot
.50595 .48122 Mdot
.4623 .40819 Mdot
.35622 .37983 Mdot
.82405 .41681 Mdot
.73206 .69565 Mdot
.42183 .38308 Mdot
.66308 .52218 Mdot
.69601 .52939 Mdot
.41715 .41996 Mdot
.36064 .61058 Mdot
.60244 .35821 Mdot
.63705 .39567 Mdot
.3702 .48485 Mdot
.54738 .49733 Mdot
.52086 .38247 Mdot
.42334 .43136 Mdot
.35176 .34626 Mdot
.63834 .47929 Mdot
.73719 .60305 Mdot
.50219 .78482 Mdot
.61057 .35396 Mdot
.40972 .45013 Mdot
.53248 .72312 Mdot
.36538 .6647 Mdot
.68743 .49869 Mdot
.51065 .63851 Mdot
.59405 .30505 Mdot
.63269 .51461 Mdot
.41702 .42143 Mdot
.42158 .42482 Mdot
.57177 .64805 Mdot
.40079 .58783 Mdot
.62837 .37018 Mdot
.65195 .51693 Mdot
.61294 .35005 Mdot
.37897 .66011 Mdot
.36909 .63387 Mdot
.46672 .41564 Mdot
.33521 .3714 Mdot
.6472 .47888 Mdot
.36691 .47509 Mdot
.70011 .50237 Mdot
.59157 .32361 Mdot
.56767 .61101 Mdot
.36591 .38222 Mdot
.37846 .68219 Mdot
.52461 .64497 Mdot
.37764 .42767 Mdot
.85373 .48136 Mdot
.39807 .38442 Mdot
.6408 .53574 Mdot
.30522 .73362 Mdot
.64292 .38537 Mdot
.33414 .59551 Mdot
.31783 .45974 Mdot
.39062 .44336 Mdot
.69414 .48373 Mdot
.36598 .49253 Mdot
.57226 .64206 Mdot
.39022 .664 Mdot
.58153 .86227 Mdot
.53152 .63248 Mdot
.39776 .45276 Mdot
.61701 .37182 Mdot
.37685 .67964 Mdot
.72477 .61736 Mdot
.5169 .79214 Mdot
.45193 .46496 Mdot
.39835 .36009 Mdot
.40449 .4621 Mdot
.2025 .4014 Mdot
.67984 .51035 Mdot
.40224 .62788 Mdot
.57164 .63071 Mdot
.52126 .6296 Mdot
.64321 .49804 Mdot
.46919 .74405 Mdot
.60607 .55486 Mdot
.5856 .10596 Mdot
.66659 .47355 Mdot
.65342 .37224 Mdot
.5478 .46537 Mdot
.6951 .49411 Mdot
.67044 .50929 Mdot
.63656 .487 Mdot
.50509 .7675 Mdot
.3732 .61452 Mdot
.4076 .42839 Mdot
.34808 .60618 Mdot
.37326 .3826 Mdot
.39181 .30901 Mdot
.51685 .63882 Mdot
.38642 .66541 Mdot
.84201 .44568 Mdot
.44527 .51455 Mdot
.3826 .40907 Mdot
.66409 .28352 Mdot
.38449 .50104 Mdot
.56035 .30376 Mdot
.41613 .5058 Mdot
.66264 .48471 Mdot
.46346 .38124 Mdot
.34135 .37926 Mdot
.41704 .7986 Mdot
.5454 .62132 Mdot
.74852 .63102 Mdot
.45075 .41614 Mdot
.43742 .47625 Mdot
.36527 .67623 Mdot
.35803 .62894 Mdot
.62727 .33911 Mdot
.57161 .44784 Mdot
.53835 .61964 Mdot
.59994 .4713 Mdot
.37807 .44247 Mdot
.59381 .5909 Mdot
.29942 .67763 Mdot
.37625 .42683 Mdot
.54815 .20265 Mdot
.26243 .63153 Mdot
.42225 .39911 Mdot
.20514 .55825 Mdot
.54538 .63077 Mdot
.32124 .73739 Mdot
.37966 .47656 Mdot
.65545 .49919 Mdot
.38849 .6619 Mdot
.40787 .61175 Mdot
.6075 .37388 Mdot
.51817 .82556 Mdot
.50634 .6312 Mdot
.38204 .66498 Mdot
.37678 .39992 Mdot
.51208 .64234 Mdot
.73239 .63102 Mdot
.34096 .38446 Mdot
.48706 .22257 Mdot
.38038 .62893 Mdot
.39662 .48015 Mdot
.41769 .69971 Mdot
.5521 .41241 Mdot
.4085 .17533 Mdot
.54204 .65825 Mdot
.61226 .3553 Mdot
.43685 .49849 Mdot
.83484 .49896 Mdot
.4352 .46671 Mdot
.51063 .3592 Mdot
.44294 .62313 Mdot
.62608 .34419 Mdot
.37276 .40978 Mdot
.42658 .40884 Mdot
.53825 .49328 Mdot
.61225 .39899 Mdot
.38467 .3811 Mdot
.45825 .38851 Mdot
.37986 .61085 Mdot
.74913 .63406 Mdot
.37502 .62793 Mdot
.39877 .40695 Mdot
.41639 .34432 Mdot
.36449 .61372 Mdot
.7548 .35217 Mdot
.63985 .40065 Mdot
.55649 .65701 Mdot
.37291 .3407 Mdot
.41506 .46788 Mdot
.20802 .34601 Mdot
.75356 .62549 Mdot
.17393 .50676 Mdot
.6293 .47556 Mdot
.55269 .71525 Mdot
.65477 .43976 Mdot
.55761 .17534 Mdot
.44061 .7925 Mdot
.45361 .45138 Mdot
.44956 .25236 Mdot
.20266 .51888 Mdot
.5171 .61766 Mdot
.25152 .40869 Mdot
.37713 .44443 Mdot
.36301 .4012 Mdot
.67779 .52929 Mdot
.4538 .75056 Mdot
.60033 .76334 Mdot
.55748 .50677 Mdot
.62802 .36585 Mdot
.37049 .65967 Mdot
.39296 .43192 Mdot
.65308 .5685 Mdot
.68664 .48985 Mdot
.53959 .57222 Mdot
.36739 .41574 Mdot
.59529 .788 Mdot
.52517 .75376 Mdot
.5121 .64635 Mdot
.66814 .46637 Mdot
.6292 .51375 Mdot
.35677 .41362 Mdot
.51155 .62969 Mdot
.41911 .39959 Mdot
.55617 .55723 Mdot
.38078 .48232 Mdot
.61162 .37445 Mdot
.3646 .45197 Mdot
.51275 .51118 Mdot
.47393 .1487 Mdot
.47214 .47043 Mdot
.36993 .59961 Mdot
.64889 .53391 Mdot
.64288 .48987 Mdot
.36021 .63125 Mdot
.64403 .49105 Mdot
.23042 .56583 Mdot
.33323 .55122 Mdot
.62844 .36181 Mdot
.39749 .33498 Mdot
.61321 .37952 Mdot
.7506 .62979 Mdot
.37015 .44433 Mdot
.84225 .51989 Mdot
.66147 .47383 Mdot
.20992 .62817 Mdot
.53172 .62783 Mdot
.75112 .62831 Mdot
.43259 .4668 Mdot
.7247 .34629 Mdot
.69598 .51742 Mdot
.6255 .52036 Mdot
.41785 .40513 Mdot
.36334 .62356 Mdot
.42684 .41162 Mdot
.40752 .49962 Mdot
.74653 .60924 Mdot
.40972 .46369 Mdot
.5661 .63089 Mdot
.35093 .61653 Mdot
.59611 .20292 Mdot
.68031 .54028 Mdot
.36038 .43823 Mdot
.3759 .40081 Mdot
.385 .67416 Mdot
.42171 .47126 Mdot
.52451 .61993 Mdot
.36502 .1285 Mdot
.63707 .36017 Mdot
.72833 .60154 Mdot
.64017 .53719 Mdot
.44572 .41284 Mdot
.42548 .42646 Mdot
.82084 .4031 Mdot
.66233 .69765 Mdot
.56422 .63648 Mdot
.38185 .49597 Mdot
.6591 .51824 Mdot
.616 .36993 Mdot
.54946 .6675 Mdot
.41633 .44789 Mdot
.36303 .41164 Mdot
.61172 .37172 Mdot
.58178 .2156 Mdot
.74805 .51809 Mdot
.52921 .6583 Mdot
.46571 .38238 Mdot
.76144 .41465 Mdot
.39396 .39287 Mdot
.78599 .41605 Mdot
.36282 .63957 Mdot
.54287 .65136 Mdot
.20301 .44257 Mdot
.34987 .43315 Mdot
.53295 .61677 Mdot
.54019 .62005 Mdot
.3662 .46121 Mdot
.34441 .6116 Mdot
.34719 .64107 Mdot
.35986 .64865 Mdot
.31313 .75603 Mdot
.43441 .29516 Mdot
.68299 .49283 Mdot
.54674 .63115 Mdot
.70641 .50584 Mdot
.597 .37024 Mdot
.55944 .43554 Mdot
.70277 .51625 Mdot
.41008 .61487 Mdot
.68837 .47457 Mdot
.42315 .40878 Mdot
.53556 .61918 Mdot
.68367 .5173 Mdot
.43959 .40023 Mdot
.30823 .37817 Mdot
.50779 .55 Mdot
.60769 .35106 Mdot
.57895 .36033 Mdot
.40181 .43959 Mdot
.75106 .61655 Mdot
.3683 .43254 Mdot
.51341 .65322 Mdot
.5179 .49066 Mdot
.44065 .40476 Mdot
.65241 .47796 Mdot
.39626 .53263 Mdot
.68091 .53432 Mdot
.40887 .49467 Mdot
.39969 .40935 Mdot
.38496 .3901 Mdot
.42465 .40203 Mdot
.52009 .74421 Mdot
.51898 .61445 Mdot
.30804 .37078 Mdot
.70799 .48644 Mdot
.3873 .63486 Mdot
.42234 .6332 Mdot
.77479 .44615 Mdot
.73286 .59945 Mdot
.55276 .6253 Mdot
.39807 .3945 Mdot
.62714 .52604 Mdot
.79591 .33248 Mdot
.78015 .37905 Mdot
.66234 .30401 Mdot
.67089 .52276 Mdot
.37423 .59923 Mdot
.69333 .50302 Mdot
.36084 .39843 Mdot
.3415 .41809 Mdot
.57012 .18523 Mdot
.48983 .65368 Mdot
.62948 .37153 Mdot
.38238 .38797 Mdot
.45421 .3272 Mdot
.65879 .51895 Mdot
.63755 .47851 Mdot
.39488 .38532 Mdot
.35108 .63481 Mdot
.32874 .20224 Mdot
.5102 .64333 Mdot
.30569 .34602 Mdot
.38521 .55824 Mdot
.34786 .73375 Mdot
.51719 .63026 Mdot
.49391 .56483 Mdot
.63899 .51253 Mdot
.35312 .56736 Mdot
.38374 .63677 Mdot
.62842 .37521 Mdot
.34178 .40298 Mdot
.40901 .61485 Mdot
.63722 .46853 Mdot
.41119 .63571 Mdot
.35204 .41362 Mdot
.52106 .61475 Mdot
.64082 .50414 Mdot
.58802 .64857 Mdot
.33624 .67277 Mdot
.62341 .38932 Mdot
.50338 .3684 Mdot
.26625 .38709 Mdot
.26112 .63215 Mdot
.44001 .41054 Mdot
.71727 .55483 Mdot
.43412 .44723 Mdot
.35899 .67047 Mdot
.39851 .39957 Mdot
.45004 .62265 Mdot
.65568 .46731 Mdot
.39542 .48003 Mdot
.3864 .46484 Mdot
.26731 .44722 Mdot
.37898 .41569 Mdot
.39785 .47173 Mdot
.42665 .40107 Mdot
.39002 .55862 Mdot
.46368 .433 Mdot
.36858 .61762 Mdot
.53375 .77423 Mdot
.67111 .50729 Mdot
.611 .3463 Mdot
.62394 .39758 Mdot
.51557 .36582 Mdot
.50216 .36159 Mdot
.47199 .74804 Mdot
.37635 .62127 Mdot
.56216 .62409 Mdot
.41819 .39875 Mdot
.21955 .41288 Mdot
.64426 .32329 Mdot
.63895 .50926 Mdot
.6635 .54182 Mdot
.33075 .38013 Mdot
.20405 .39526 Mdot
.41088 .48026 Mdot
.52323 .79732 Mdot
.3698 .48281 Mdot
.3918 .38115 Mdot
.63377 .52206 Mdot
.53558 .39509 Mdot
.43988 .4099 Mdot
.36606 .67669 Mdot
.63053 .37864 Mdot
.48152 .4584 Mdot
.68143 .42729 Mdot
.52628 .56422 Mdot
.29358 .46593 Mdot
.43666 .44915 Mdot
.64785 .51259 Mdot
.40548 .61414 Mdot
.49195 .79188 Mdot
.52737 .65443 Mdot
.47482 .76933 Mdot
.25277 .47248 Mdot
.723 .31475 Mdot
.6309 .37495 Mdot
.57318 .21488 Mdot
.39544 .42413 Mdot
.64711 .53389 Mdot
.35537 .39556 Mdot
.79135 .32746 Mdot
.65063 .35619 Mdot
.38759 .58807 Mdot
.5576 .63854 Mdot
.37335 .67296 Mdot
.27906 .61024 Mdot
.47072 .59092 Mdot
.68431 .58762 Mdot
.70362 .52581 Mdot
.33479 .321 Mdot
.39648 .64676 Mdot
.41692 .43413 Mdot
.63045 .1317 Mdot
.36312 .64128 Mdot
.35555 .64501 Mdot
.57764 .34646 Mdot
.64279 .30187 Mdot
.34871 .47164 Mdot
.41141 .64187 Mdot
.70319 .4853 Mdot
.64428 .37699 Mdot
.43514 .41557 Mdot
.42767 .40551 Mdot
.36182 .62143 Mdot
.69834 .51189 Mdot
.31407 .32467 Mdot
.65764 .48248 Mdot
.38339 .60972 Mdot
.66126 .49126 Mdot
.68957 .54914 Mdot
.67766 .51794 Mdot
.4148 .47011 Mdot
.40226 .39804 Mdot
.6892 .4143 Mdot
.36928 .63384 Mdot
.42912 .4289 Mdot
.40838 .44481 Mdot
.39353 .64652 Mdot
.65694 .44688 Mdot
.22903 .39399 Mdot
.38513 .45196 Mdot
.40842 .41492 Mdot
.61976 .34718 Mdot
.63608 .45598 Mdot
.75997 .55342 Mdot
.43336 .42162 Mdot
.64468 .39107 Mdot
.34348 .63599 Mdot
.36968 .43145 Mdot
.51989 .40297 Mdot
.69822 .54079 Mdot
.36026 .44916 Mdot
.72415 .61907 Mdot
.44714 .42022 Mdot
.34499 .19771 Mdot
.36439 .44513 Mdot
.39985 .62873 Mdot
.39656 .65505 Mdot
.57409 .37925 Mdot
.37624 .65061 Mdot
.74255 .63168 Mdot
.52761 .64333 Mdot
.73908 .29001 Mdot
.73339 .63044 Mdot
.39987 .38161 Mdot
.67904 .78197 Mdot
.36137 .46651 Mdot
.44978 .41527 Mdot
.19027 .45413 Mdot
.73385 .62979 Mdot
.40388 .64337 Mdot
.61268 .62024 Mdot
.36577 .48081 Mdot
.50996 .63826 Mdot
.34943 .3796 Mdot
.36723 .45789 Mdot
.38829 .75838 Mdot
.28232 .69336 Mdot
.52032 .65888 Mdot
.44698 .49534 Mdot
.43349 .42245 Mdot
.71992 .68544 Mdot
.38623 .40222 Mdot
.608 .36783 Mdot
.35737 .64834 Mdot
.68638 .48445 Mdot
.64057 .35957 Mdot
.38426 .44356 Mdot
.62444 .37426 Mdot
.68624 .49852 Mdot
.53311 .65114 Mdot
.35942 .43211 Mdot
.65449 .38066 Mdot
.6275 .36733 Mdot
.43244 .44414 Mdot
.38667 .66423 Mdot
.45548 .5027 Mdot
.37121 .43048 Mdot
.41624 .42939 Mdot
.36237 .62847 Mdot
.80778 .65892 Mdot
.35743 .40221 Mdot
.4937 .54544 Mdot
.38434 .58853 Mdot
.73642 .63784 Mdot
.68989 .51366 Mdot
.35727 .44978 Mdot
.51553 .64299 Mdot
.51955 .64263 Mdot
.66327 .4621 Mdot
.37499 .675 Mdot
.69481 .52269 Mdot
.45235 .49627 Mdot
.33753 .36619 Mdot
.34626 .44281 Mdot
.56235 .8606 Mdot
.55526 .18515 Mdot
.36399 .60613 Mdot
.64731 .52481 Mdot
.56047 .50589 Mdot
.55193 .63092 Mdot
.68491 .47085 Mdot
.36659 .6809 Mdot
.38352 .60109 Mdot
.41364 .63225 Mdot
.62258 .34798 Mdot
.63433 .51259 Mdot
.39738 .58732 Mdot
.35182 .64182 Mdot
.42006 .40688 Mdot
.43301 .4245 Mdot
.42534 .6689 Mdot
.52142 .31117 Mdot
.61835 .38733 Mdot
.64718 .50449 Mdot
.17476 .36514 Mdot
.51437 .65409 Mdot
.2694 .44783 Mdot
.44391 .40811 Mdot
.84294 .31905 Mdot
.40596 .48248 Mdot
.37968 .39976 Mdot
.34582 .62397 Mdot
.65483 .35533 Mdot
.62402 .38479 Mdot
.39597 .64864 Mdot
.3525 .68113 Mdot
.60827 .36189 Mdot
.61719 .25037 Mdot
.65428 .22337 Mdot
.48023 .78446 Mdot
.39732 .63463 Mdot
.27349 .37973 Mdot
.51035 .62924 Mdot
.33084 .65995 Mdot
.53547 .66334 Mdot
.66888 .50891 Mdot
.63245 .49894 Mdot
.56983 .65077 Mdot
.4156 .40325 Mdot
.68743 .50551 Mdot
.46589 .43856 Mdot
.63083 .23934 Mdot
.37346 .24147 Mdot
.64948 .6838 Mdot
.43947 .39604 Mdot
.58777 .76927 Mdot
.62414 .74388 Mdot
.39636 .44223 Mdot
.50172 .44343 Mdot
.6281 .37294 Mdot
.33415 .62236 Mdot
.5212 .6216 Mdot
.39521 .18096 Mdot
.39562 .3935 Mdot
.39493 .62281 Mdot
.54824 .622 Mdot
.59257 .41145 Mdot
.41741 .76778 Mdot
.37743 .38322 Mdot
.52836 .10257 Mdot
.34164 .6064 Mdot
.6854 .4835 Mdot
.60161 .81933 Mdot
.35139 .60235 Mdot
.58249 .35024 Mdot
.63128 .48377 Mdot
.77965 .35759 Mdot
.40459 .62348 Mdot
.64581 .46105 Mdot
.37725 .65833 Mdot
.61012 .37745 Mdot
.34085 .65686 Mdot
.64214 .50883 Mdot
.37459 .41314 Mdot
.64621 .49451 Mdot
.6183 .38835 Mdot
.65591 .5384 Mdot
.51536 .62466 Mdot
.75145 .62451 Mdot
.53981 .6383 Mdot
.55901 .42148 Mdot
.29002 .70965 Mdot
.55415 .65313 Mdot
.60785 .43503 Mdot
.42483 .38502 Mdot
.40612 .59046 Mdot
.67074 .47287 Mdot
.70615 .48484 Mdot
.55879 .45514 Mdot
.38965 .63852 Mdot
.64322 .50287 Mdot
.2467 .47039 Mdot
.75539 .72863 Mdot
.401 .34215 Mdot
.44107 .2827 Mdot
.3944 .64359 Mdot
.64335 .46996 Mdot
.50606 .7954 Mdot
.41743 .62958 Mdot
.66737 .47429 Mdot
.54757 .64576 Mdot
.51994 .62964 Mdot
.39721 .38909 Mdot
.50316 .6656 Mdot
.68343 .47522 Mdot
.58886 .72998 Mdot
.36267 .664 Mdot
.5905 .41145 Mdot
.60571 .37688 Mdot
.67126 .51314 Mdot
.34569 .37338 Mdot
.3763 .68994 Mdot
.70669 .52728 Mdot
.44468 .2344 Mdot
.16563 .39238 Mdot
.64449 .50016 Mdot
.35765 .65114 Mdot
.38974 .62117 Mdot
.37816 .49923 Mdot
.54645 .49348 Mdot
.68898 .52724 Mdot
.8382 .54625 Mdot
.50341 .34947 Mdot
.73652 .61358 Mdot
.74044 .69558 Mdot
.44044 .409 Mdot
.42778 .45326 Mdot
.55466 .63114 Mdot
.38842 .41426 Mdot
.3494 .63833 Mdot
.44655 .44301 Mdot
.54086 .61427 Mdot
.64063 .51352 Mdot
.36267 .4365 Mdot
.64084 .38469 Mdot
.50497 .64987 Mdot
.56588 .65579 Mdot
.67224 .49816 Mdot
.41268 .63811 Mdot
.6307 .5555 Mdot
.65265 .48162 Mdot
.43942 .44555 Mdot
.73139 .62368 Mdot
.3515 .43071 Mdot
.55144 .2258 Mdot
.40928 .65654 Mdot
.69345 .49737 Mdot
.39624 .6001 Mdot
.53728 .63554 Mdot
.68603 .46648 Mdot
.39179 .40662 Mdot
.66613 .47611 Mdot
.7186 .45969 Mdot
.58857 .23475 Mdot
.37261 .67558 Mdot
.66337 .43298 Mdot
.35488 .64862 Mdot
.73558 .61223 Mdot
.54744 .24571 Mdot
.63544 .3677 Mdot
.66151 .51625 Mdot
.53693 .17922 Mdot
.65262 .47584 Mdot
.37961 .41788 Mdot
.38304 .43066 Mdot
.67773 .52835 Mdot
.64818 .36359 Mdot
.27302 .73369 Mdot
.47992 .56348 Mdot
.40677 .63772 Mdot
.36472 .55145 Mdot
.20485 .31301 Mdot
.55863 .66783 Mdot
.55921 .63134 Mdot
.41261 .4866 Mdot
.40601 .38682 Mdot
.56605 .65757 Mdot
.56772 .61506 Mdot
.61136 .34957 Mdot
.63585 .49271 Mdot
.37654 .57711 Mdot
.53501 .67119 Mdot
.34781 .49154 Mdot
.47044 .33728 Mdot
.36091 .48228 Mdot
.42731 .36329 Mdot
.41898 .37465 Mdot
.55312 .40228 Mdot
.56709 .61895 Mdot
.40329 .43799 Mdot
.46088 .44175 Mdot
.55123 .64751 Mdot
.61085 .37776 Mdot
.34265 .71 Mdot
.65831 .49501 Mdot
.86975 .5568 Mdot
.36019 .44471 Mdot
.37345 .41961 Mdot
.52396 .65619 Mdot
.74492 .67669 Mdot
.38292 .60431 Mdot
.40772 .65554 Mdot
.68124 .50967 Mdot
.5612 .4533 Mdot
.43082 .46415 Mdot
.39874 .44133 Mdot
.65822 .51017 Mdot
.75206 .62231 Mdot
.63293 .68318 Mdot
.40643 .42519 Mdot
.5435 .62319 Mdot
.69618 .55331 Mdot
.56689 .61747 Mdot
.35955 .3912 Mdot
.38112 .41969 Mdot
.41575 .47036 Mdot
.40648 .38641 Mdot
.5476 .6653 Mdot
.39996 .43435 Mdot
.33966 .37572 Mdot
.40241 .65655 Mdot
.42199 .46265 Mdot
.52483 .36979 Mdot
.40624 .40968 Mdot
.63381 .38792 Mdot
.69883 .57088 Mdot
.38522 .38922 Mdot
.41814 .46398 Mdot
.48403 .55973 Mdot
.37067 .40695 Mdot
.51773 .65568 Mdot
.38769 .63006 Mdot
.54707 .63159 Mdot
.57298 .63316 Mdot
.70756 .49669 Mdot
.61341 .34817 Mdot
.45209 .44709 Mdot
.61214 .3904 Mdot
.40543 .35512 Mdot
.35177 .41188 Mdot
.64062 .55454 Mdot
.52483 .79636 Mdot
.74067 .49454 Mdot
.39415 .40566 Mdot
.67652 .50968 Mdot
.68889 .48824 Mdot
.44694 .24612 Mdot
.45963 .46438 Mdot
.55527 .6646 Mdot
.54286 .64626 Mdot
.54142 .27961 Mdot
.39476 .76426 Mdot
.62497 .38908 Mdot
.57668 .50926 Mdot
.42328 .37913 Mdot
.41024 .4322 Mdot
.33878 .39055 Mdot
.70366 .51492 Mdot
.74165 .60441 Mdot
.63759 .5072 Mdot
.75559 .64137 Mdot
.55884 .61362 Mdot
.44703 .43207 Mdot
.38956 .22522 Mdot
.35913 .61912 Mdot
.38696 .63019 Mdot
.56974 .65757 Mdot
.68926 .53117 Mdot
.38105 .50327 Mdot
.58826 .86475 Mdot
.32763 .64079 Mdot
.6367 .33484 Mdot
.39773 .44594 Mdot
.67517 .50173 Mdot
.35535 .62433 Mdot
.63537 .39898 Mdot
.39535 .46296 Mdot
.69981 .47104 Mdot
.4016 .40169 Mdot
.20013 .52076 Mdot
.40214 .65452 Mdot
.79431 .3252 Mdot
.38855 .67562 Mdot
.5039 .64987 Mdot
.56128 .64587 Mdot
.37841 .42601 Mdot
.57692 .84762 Mdot
.37553 .5869 Mdot
.54748 .67569 Mdot
.65201 .3531 Mdot
.73082 .60162 Mdot
.64243 .34444 Mdot
.6954 .49257 Mdot
.63173 .37672 Mdot
.63806 .48632 Mdot
.53149 .28616 Mdot
.33417 .61204 Mdot
.63886 .36 Mdot
.71029 .66467 Mdot
.45156 .40263 Mdot
.59901 .3698 Mdot
.33665 .37442 Mdot
.36353 .56258 Mdot
.65887 .50694 Mdot
.6487 .36624 Mdot
.4183 .43133 Mdot
.38584 .19879 Mdot
.56851 .64125 Mdot
.54911 .66662 Mdot
.45312 .401 Mdot
.63563 .48653 Mdot
.34777 .67648 Mdot
.51021 .4801 Mdot
.74702 .63886 Mdot
.39979 .43892 Mdot
.44758 .42792 Mdot
.42226 .63839 Mdot
.40197 .67204 Mdot
.38197 .42228 Mdot
.24113 .44161 Mdot
.39564 .42759 Mdot
.51413 .63751 Mdot
.38452 .60257 Mdot
.38857 .62404 Mdot
.67739 .47057 Mdot
.36237 .66822 Mdot
.42708 .36194 Mdot
.48774 .66261 Mdot
.35754 .47198 Mdot
.53115 .63476 Mdot
.5107 .50394 Mdot
.66921 .54106 Mdot
.43967 .18294 Mdot
.41803 .64855 Mdot
.41097 .46429 Mdot
.35791 .65988 Mdot
.61753 .35649 Mdot
.37199 .63333 Mdot
.36519 .59885 Mdot
.37827 .43808 Mdot
.37196 .38373 Mdot
.7372 .62948 Mdot
.54998 .48998 Mdot
.37291 .66683 Mdot
.39516 .43507 Mdot
.36971 .47412 Mdot
.37946 .4663 Mdot
.52729 .52917 Mdot
.36495 .60324 Mdot
.28818 .51575 Mdot
.46484 .22007 Mdot
.3795 .6664 Mdot
.31791 .22259 Mdot
.72448 .61189 Mdot
.73198 .6001 Mdot
.53927 .67364 Mdot
.40777 .42521 Mdot
.66527 .53233 Mdot
.3593 .40362 Mdot
.46964 .42223 Mdot
.36193 .41081 Mdot
.65093 .37544 Mdot
.45581 .44161 Mdot
.74255 .61579 Mdot
.6493 .48286 Mdot
.3906 .45805 Mdot
.36137 .43295 Mdot
.73163 .59792 Mdot
.41137 .65856 Mdot
.39493 .60705 Mdot
.78357 .4011 Mdot
.6221 .35951 Mdot
.52821 .65129 Mdot
.40684 .39567 Mdot
.67798 .51045 Mdot
.64664 .49174 Mdot
.36728 .67038 Mdot
.65334 .49773 Mdot
.51054 .64755 Mdot
.38767 .40622 Mdot
.55284 .66502 Mdot
.64681 .38308 Mdot
.35741 .64464 Mdot
.40343 .39322 Mdot
.4199 .40734 Mdot
.39692 .65473 Mdot
.42442 .38445 Mdot
.61916 .34746 Mdot
.64727 .48005 Mdot
.40096 .61504 Mdot
.52522 .64303 Mdot
.68458 .47381 Mdot
.42277 .41775 Mdot
.16359 .41305 Mdot
.39055 .41754 Mdot
.41529 .42157 Mdot
.61983 .20616 Mdot
.41077 .48951 Mdot
.6665 .469 Mdot
.42217 .62689 Mdot
.41288 .36706 Mdot
.4424 .31627 Mdot
.82314 .45035 Mdot
.6885 .47213 Mdot
.3943 .45236 Mdot
.45974 .17479 Mdot
.3921 .45573 Mdot
.59836 .47392 Mdot
.76638 .48781 Mdot
.35069 .30016 Mdot
.41873 .35854 Mdot
.55297 .66122 Mdot
.73973 .63024 Mdot
.64763 .47132 Mdot
.23013 .61 Mdot
.38514 .43794 Mdot
.21689 .60234 Mdot
.37753 .46122 Mdot
.51969 .62847 Mdot
.42961 .52152 Mdot
.64784 .50254 Mdot
.4789 .82038 Mdot
.43988 .44134 Mdot
.36754 .60279 Mdot
.69877 .48613 Mdot
.72782 .60425 Mdot
.41901 .424 Mdot
.62243 .39556 Mdot
.58001 .66571 Mdot
.34408 .35593 Mdot
.52766 .63595 Mdot
.40936 .44635 Mdot
.45758 .48336 Mdot
.55015 .83765 Mdot
.40532 .65059 Mdot
.5579 .63552 Mdot
.65735 .74676 Mdot
.41573 .37935 Mdot
.40414 .62099 Mdot
.38473 .63695 Mdot
.60988 .38258 Mdot
.59269 .55813 Mdot
.43914 .68928 Mdot
.32846 .26387 Mdot
.2853 .64227 Mdot
.6583 .46463 Mdot
.62591 .72701 Mdot
.4362 .41886 Mdot
.47953 .59197 Mdot
.52831 .6609 Mdot
.37312 .41697 Mdot
.29269 .67052 Mdot
.3599 .64566 Mdot
.40452 .41862 Mdot
.61215 .3784 Mdot
.60254 .58663 Mdot
.52402 .57182 Mdot
.23549 .32104 Mdot
.69667 .47809 Mdot
.33967 .40316 Mdot
.39852 .35146 Mdot
.72512 .63023 Mdot
.35092 .40473 Mdot
.6582 .47 Mdot
.64467 .26044 Mdot
.64906 .36187 Mdot
.35459 .63206 Mdot
.72474 .61084 Mdot
.42724 .3785 Mdot
.37574 .47313 Mdot
.61241 .34523 Mdot
.41982 .44987 Mdot
.52445 .82345 Mdot
.7492 .59729 Mdot
.68599 .51151 Mdot
.41159 .63036 Mdot
.41284 .37384 Mdot
.74305 .60586 Mdot
.38004 .43538 Mdot
.30549 .46491 Mdot
.41651 .46025 Mdot
.40835 .71057 Mdot
.38709 .66229 Mdot
.53015 .6381 Mdot
.42901 .36935 Mdot
.36617 .3986 Mdot
.75839 .40469 Mdot
.46953 .42282 Mdot
.36326 .44477 Mdot
.36898 .67811 Mdot
.36097 .61212 Mdot
.36848 .61926 Mdot
.68867 .49661 Mdot
.49165 .78325 Mdot
.54004 .62711 Mdot
.44325 .45506 Mdot
.53485 .67102 Mdot
.31336 .46343 Mdot
.62214 .33854 Mdot
.3235 .23797 Mdot
.40513 .46581 Mdot
.3736 .61847 Mdot
.51154 .71946 Mdot
.34408 .63695 Mdot
.70823 .48316 Mdot
.53764 .61957 Mdot
.3622 .64445 Mdot
.3729 .39699 Mdot
.54792 .50594 Mdot
.25033 .32208 Mdot
.54877 .6357 Mdot
.33507 .40384 Mdot
.69385 .47296 Mdot
.67996 .54317 Mdot
.22304 .27407 Mdot
.56533 .63802 Mdot
.6302 .73981 Mdot
.39299 .43937 Mdot
.36051 .61853 Mdot
.54679 .65828 Mdot
.56471 .65148 Mdot
.65595 .50507 Mdot
.37611 .38418 Mdot
.38314 .39081 Mdot
.72406 .6171 Mdot
.53784 .64728 Mdot
.44315 .38879 Mdot
.35115 .45573 Mdot
.57334 .18604 Mdot
.3328 .70086 Mdot
.82564 .63205 Mdot
.45316 .49556 Mdot
.28242 .65055 Mdot
.54311 .45752 Mdot
.35631 .61094 Mdot
.38355 .38674 Mdot
.39904 .36793 Mdot
.67449 .46988 Mdot
.38999 .41177 Mdot
.66708 .53576 Mdot
.55997 .6277 Mdot
.30084 .24573 Mdot
.48534 .67234 Mdot
.63118 .26126 Mdot
.3834 .41181 Mdot
.3708 .74457 Mdot
.63525 .35165 Mdot
.55 .59812 Mdot
.38494 .60822 Mdot
.39302 .37333 Mdot
.63657 .53023 Mdot
.6612 .51716 Mdot
.3766 .64326 Mdot
.57965 .7525 Mdot
.77996 .41435 Mdot
.3631 .38434 Mdot
.69087 .51481 Mdot
.56532 .71015 Mdot
.23447 .45061 Mdot
.49053 .64548 Mdot
.64985 .35997 Mdot
.6404 .51162 Mdot
.57829 .63922 Mdot
.37249 .69515 Mdot
.36818 .64932 Mdot
.41537 .61248 Mdot
.73588 .43668 Mdot
.68446 .53137 Mdot
.64384 .36479 Mdot
.44136 .78411 Mdot
.42389 .78721 Mdot
.65178 .36991 Mdot
.64143 .51611 Mdot
.35755 .6175 Mdot
.39285 .61557 Mdot
.3886 .62958 Mdot
.46717 .81818 Mdot
.40083 .66343 Mdot
.30656 .50278 Mdot
.36306 .46695 Mdot
.36308 .3297 Mdot
.39182 .45423 Mdot
.53506 .66508 Mdot
.40187 .65393 Mdot
.55201 .4592 Mdot
.41237 .38397 Mdot
.24665 .31448 Mdot
.40092 .44185 Mdot
.49031 .63874 Mdot
.40826 .42082 Mdot
.26262 .41114 Mdot
.38118 .58848 Mdot
.39476 .40821 Mdot
.52551 .60869 Mdot
.62416 .36789 Mdot
.40589 .58032 Mdot
.38406 .38928 Mdot
.43388 .74871 Mdot
.42769 .47802 Mdot
.64205 .253 Mdot
.55713 .36073 Mdot
.64159 .33492 Mdot
.46251 .39737 Mdot
.65033 .46321 Mdot
.42637 .5945 Mdot
.4279 .34291 Mdot
.54733 .63695 Mdot
.20515 .61239 Mdot
.66586 .51739 Mdot
.43617 .51974 Mdot
.38438 .497 Mdot
.61059 .35232 Mdot
.42424 .65779 Mdot
.5246 .65797 Mdot
.44277 .40286 Mdot
.36942 .46328 Mdot
.61106 .25883 Mdot
.41093 .33792 Mdot
.42204 .4725 Mdot
.602 .35718 Mdot
.29599 .52229 Mdot
.41105 .4085 Mdot
.66205 .44838 Mdot
.40925 .60725 Mdot
.45893 .40977 Mdot
.28481 .51006 Mdot
.39369 .43516 Mdot
.36704 .64055 Mdot
.42489 .63091 Mdot
.47359 .72284 Mdot
.65078 .34573 Mdot
.41642 .46012 Mdot
.59591 .30999 Mdot
.43404 .44947 Mdot
.53855 .62423 Mdot
.35635 .40481 Mdot
.6652 .51142 Mdot
.51652 .80013 Mdot
.67844 .48428 Mdot
.35935 .39918 Mdot
.39244 .62902 Mdot
.54465 .6615 Mdot
.70323 .42581 Mdot
.77108 .47015 Mdot
.30617 .50646 Mdot
.84731 .45717 Mdot
.63981 .34867 Mdot
.60276 .38852 Mdot
.50181 .63593 Mdot
.39781 .40714 Mdot
.56832 .36232 Mdot
.38828 .48816 Mdot
.40949 .41543 Mdot
.36131 .41371 Mdot
.51315 .67389 Mdot
.55031 .62799 Mdot
.6542 .49049 Mdot
.3832 .42083 Mdot
.39626 .43393 Mdot
.37006 .66227 Mdot
.62559 .36628 Mdot
.68156 .48452 Mdot
.6298 .35856 Mdot
.67048 .48802 Mdot
.34069 .1998 Mdot
.34491 .4519 Mdot
.62194 .36798 Mdot
.50077 .6364 Mdot
.36194 .628 Mdot
.75536 .6189 Mdot
.69518 .48907 Mdot
.64588 .50411 Mdot
.39859 .43926 Mdot
.36172 .63352 Mdot
.36923 .66831 Mdot
.62124 .3526 Mdot
.5393 .65488 Mdot
.36053 .39722 Mdot
.36027 .38739 Mdot
.39897 .26132 Mdot
.70377 .50416 Mdot
.23936 .48007 Mdot
.48692 .73629 Mdot
.39682 .40555 Mdot
.4086 .64843 Mdot
.36497 .43488 Mdot
.44801 .19306 Mdot
.40954 .61452 Mdot
.39105 .38146 Mdot
.38397 .76516 Mdot
.7012 .52448 Mdot
.42734 .71805 Mdot
.4011 .47742 Mdot
.81816 .39585 Mdot
.43731 .4306 Mdot
.54636 .15925 Mdot
.68838 .69578 Mdot
.44544 .4441 Mdot
.42946 .41279 Mdot
.31512 .27945 Mdot
.38932 .44433 Mdot
.73798 .61079 Mdot
.4667 .47993 Mdot
.38438 .60096 Mdot
.53998 .42544 Mdot
.68304 .45459 Mdot
.6538 .35979 Mdot
.68156 .50977 Mdot
.69167 .44644 Mdot
.61044 .3727 Mdot
.39817 .63604 Mdot
.42688 .40323 Mdot
.49904 .36322 Mdot
.71426 .50785 Mdot
.4044 .49773 Mdot
.53682 .62341 Mdot
.64512 .44023 Mdot
.65545 .53388 Mdot
.52928 .64232 Mdot
.38724 .46619 Mdot
.2418 .36841 Mdot
.76637 .50477 Mdot
.75708 .29959 Mdot
.52849 .65803 Mdot
.518 .62758 Mdot
.49466 .79694 Mdot
.65416 .3655 Mdot
.54423 .23209 Mdot
.37523 .73021 Mdot
.50829 .63842 Mdot
.57089 .27527 Mdot
.63423 .48554 Mdot
.42317 .7494 Mdot
.33399 .62295 Mdot
.33987 .42925 Mdot
.37079 .39699 Mdot
.54315 .65337 Mdot
.49937 .37694 Mdot
.58012 .81879 Mdot
.54106 .63866 Mdot
.3794 .3531 Mdot
.59811 .56634 Mdot
.72934 .61957 Mdot
.724 .62322 Mdot
.64318 .33904 Mdot
.76159 .3649 Mdot
.38239 .6583 Mdot
.60706 .35744 Mdot
.57355 .57454 Mdot
.4138 .45776 Mdot
.54353 .6434 Mdot
.75191 .61063 Mdot
.51882 .63659 Mdot
.61871 .38235 Mdot
.63618 .33517 Mdot
.40362 .65505 Mdot
.38381 .60473 Mdot
.27859 .65167 Mdot
.54881 .30169 Mdot
.39147 .45683 Mdot
.18724 .48771 Mdot
.36247 .66476 Mdot
.44677 .35943 Mdot
.64541 .38982 Mdot
.62248 .36466 Mdot
.20795 .52721 Mdot
.41365 .39515 Mdot
.59669 .40933 Mdot
.40127 .39518 Mdot
.52522 .24322 Mdot
.35874 .38524 Mdot
.65562 .50177 Mdot
.44514 .42248 Mdot
.61642 .54782 Mdot
.43364 .40207 Mdot
.36044 .44251 Mdot
.63561 .49997 Mdot
.33037 .40568 Mdot
.66402 .51251 Mdot
.36422 .38785 Mdot
.60225 .39552 Mdot
.67846 .51023 Mdot
.453 .29377 Mdot
.49463 .54595 Mdot
.74751 .61419 Mdot
.62757 .39232 Mdot
.60598 .38092 Mdot
.50675 .36175 Mdot
.38829 .60883 Mdot
.33308 .68744 Mdot
.39876 .40855 Mdot
.638 .47791 Mdot
.55537 .62963 Mdot
.39584 .43211 Mdot
.37127 .37254 Mdot
.41094 .47627 Mdot
.36071 .6546 Mdot
.68726 .53178 Mdot
.62148 .37269 Mdot
.69128 .50924 Mdot
.75853 .38396 Mdot
.63286 .51565 Mdot
.46228 .44009 Mdot
.36264 .37203 Mdot
.29021 .38548 Mdot
.20882 .60222 Mdot
.3515 .75984 Mdot
.3728 .6489 Mdot
.74431 .6258 Mdot
.63159 .33607 Mdot
.37734 .54382 Mdot
.37723 .61174 Mdot
.64469 .51255 Mdot
.40136 .40137 Mdot
.35629 .36188 Mdot
.49613 .59608 Mdot
.43636 .60632 Mdot
.50374 .34181 Mdot
.64435 .53053 Mdot
.73383 .61444 Mdot
.48925 .78594 Mdot
.38462 .55279 Mdot
.55636 .44582 Mdot
.36508 .41959 Mdot
.62543 .39629 Mdot
.35535 .62444 Mdot
.73441 .45585 Mdot
.54334 .64928 Mdot
.54773 .49286 Mdot
.38453 .41142 Mdot
.56279 .73341 Mdot
.39198 .63035 Mdot
.61498 .38341 Mdot
.54417 .65271 Mdot
.65468 .35886 Mdot
.72277 .62218 Mdot
.76746 .35799 Mdot
.42876 .44828 Mdot
.36776 .44799 Mdot
.49836 .65198 Mdot
.38095 .65685 Mdot
.57959 .37121 Mdot
.59852 .24894 Mdot
.68655 .52029 Mdot
.6133 .41771 Mdot
.34856 .62094 Mdot
.28538 .44807 Mdot
.69069 .50463 Mdot
.5701 .65753 Mdot
.55014 .40787 Mdot
.54594 .61343 Mdot
.39101 .39004 Mdot
.38008 .62099 Mdot
.56667 .6326 Mdot
.74953 .40302 Mdot
.45594 .16289 Mdot
.27529 .39952 Mdot
.43983 .44978 Mdot
.31453 .24317 Mdot
.63128 .22969 Mdot
.51077 .41164 Mdot
.51627 .62323 Mdot
.37348 .43175 Mdot
.34883 .40489 Mdot
.44247 .43636 Mdot
.56316 .62318 Mdot
.7086 .33729 Mdot
.6497 .5102 Mdot
.40079 .44803 Mdot
.60588 .37114 Mdot
.666 .50411 Mdot
.63411 .54682 Mdot
.64768 .47411 Mdot
.38274 .5973 Mdot
.401 .38416 Mdot
.49082 .76731 Mdot
.50236 .13844 Mdot
.54743 .63248 Mdot
.74716 .61408 Mdot
.37099 .45495 Mdot
.31278 .72753 Mdot
.36954 .61877 Mdot
.68492 .52229 Mdot
.37269 .41968 Mdot
.73223 .36476 Mdot
.76359 .63939 Mdot
.64218 .48518 Mdot
.39256 .61342 Mdot
.51117 .42763 Mdot
.39109 .41321 Mdot
.43544 .43549 Mdot
.38855 .65277 Mdot
.78285 .3864 Mdot
.51702 .79557 Mdot
.36262 .43374 Mdot
.53037 .63928 Mdot
.69577 .78953 Mdot
.39814 .47546 Mdot
.39926 .6873 Mdot
.72954 .60142 Mdot
.45058 .74402 Mdot
.23716 .48564 Mdot
.46908 .41135 Mdot
.34233 .24149 Mdot
.53376 .39628 Mdot
.30999 .23662 Mdot
.62174 .3158 Mdot
.65493 .59332 Mdot
.35581 .18901 Mdot
.51604 .61184 Mdot
.35399 .33264 Mdot
.33674 .29554 Mdot
.56009 .76509 Mdot
.53046 .42996 Mdot
.82262 .49759 Mdot
.7669 .4315 Mdot
.70614 .6212 Mdot
.66059 .47419 Mdot
.50185 .23728 Mdot
.35804 .40728 Mdot
.63997 .2308 Mdot
.24841 .43844 Mdot
.57092 .83017 Mdot
.33083 .22489 Mdot
.59787 .30729 Mdot
.25742 .32342 Mdot
.47151 .17684 Mdot
.30496 .32987 Mdot
.46085 .64014 Mdot
.81996 .59769 Mdot
.44145 .78757 Mdot
.63829 .28837 Mdot
.41106 .51016 Mdot
.63385 .56368 Mdot
.68427 .28236 Mdot
.32302 .54589 Mdot
.60924 .82958 Mdot
.68628 .48002 Mdot
.39995 .59696 Mdot
.38531 .26193 Mdot
.41962 .59052 Mdot
.55004 .69501 Mdot
.33983 .24241 Mdot
.54048 .16547 Mdot
.26106 .41592 Mdot
.83105 .41183 Mdot
.22752 .58745 Mdot
.29855 .75798 Mdot
.51928 .54771 Mdot
.41417 .60663 Mdot
.79439 .59359 Mdot
.42182 .78652 Mdot
.47737 .67875 Mdot
.37554 .5376 Mdot
.63011 .32635 Mdot
.48904 .31087 Mdot
.39541 .62393 Mdot
.23188 .47631 Mdot
.71709 .6154 Mdot
.44066 .67261 Mdot
.65844 .56129 Mdot
.42156 .19166 Mdot
.69764 .58764 Mdot
.43901 .75744 Mdot
.61576 .72215 Mdot
.16387 .40722 Mdot
.57935 .29444 Mdot
.5055 .18988 Mdot
.49103 .60706 Mdot
.52653 .42481 Mdot
.5755 .79644 Mdot
.54438 .32086 Mdot
.40838 .78429 Mdot
.16242 .47115 Mdot
.68281 .25537 Mdot
.19004 .39036 Mdot
.43196 .62726 Mdot
.41595 .47379 Mdot
.44745 .20736 Mdot
.28721 .63832 Mdot
.63832 .33283 Mdot
.21668 .34495 Mdot
.63717 .39591 Mdot
.4267 .60366 Mdot
.57402 .75782 Mdot
.28365 .46091 Mdot
.61803 .43233 Mdot
.62227 .40923 Mdot
.45339 .45305 Mdot
.30147 .8049 Mdot
.29658 .25721 Mdot
.46659 .7277 Mdot
.57337 .1851 Mdot
.58536 .5894 Mdot
.57589 .39554 Mdot
.56077 .62539 Mdot
.41882 .16725 Mdot
.38505 .61458 Mdot
.44297 .13477 Mdot
.45093 .15699 Mdot
.68525 .75709 Mdot
.46727 .90827 Mdot
.65778 .65654 Mdot
.31975 .33886 Mdot
.45703 .33116 Mdot
.46141 .31574 Mdot
.58765 .80449 Mdot
.7046 .74061 Mdot
.59744 .59682 Mdot
.75965 .33187 Mdot
.37366 .18765 Mdot
.55314 .26262 Mdot
.67831 .29933 Mdot
.57039 .77482 Mdot
.50864 .53418 Mdot
.36852 .69043 Mdot
.46914 .54975 Mdot
.45785 .63865 Mdot
.21015 .3613 Mdot
.2999 .65893 Mdot
.60754 .85146 Mdot
.58552 .37216 Mdot
.73576 .68865 Mdot
.58151 .20166 Mdot
.45472 .28482 Mdot
.33767 .5028 Mdot
.51998 .76788 Mdot
.45529 .45245 Mdot
.49922 .78285 Mdot
.46554 .50003 Mdot
.67514 .43563 Mdot
.48428 .79043 Mdot
.58781 .69381 Mdot
.60113 .25728 Mdot
.368 .24694 Mdot
.37502 .75335 Mdot
.39637 .6043 Mdot
.53903 .35049 Mdot
.58071 .28431 Mdot
.57699 .19038 Mdot
.65552 .74693 Mdot
.74788 .2887 Mdot
.67225 .74547 Mdot
.38844 .48701 Mdot
.42503 .34559 Mdot
.39805 .50997 Mdot
.55814 .3129 Mdot
.38392 .48009 Mdot
.5695 .72787 Mdot
.6032 .19912 Mdot
.29415 .67556 Mdot
.67289 .39499 Mdot
.18329 .56923 Mdot
.72495 .27716 Mdot
.45025 .21194 Mdot
.68169 .70397 Mdot
.41958 .33066 Mdot
.20402 .67577 Mdot
.66672 .49652 Mdot
.56414 .27321 Mdot
.58325 .62376 Mdot
.73464 .44221 Mdot
.29053 .31999 Mdot
.66938 .76926 Mdot
.60944 .20084 Mdot
.52784 .77821 Mdot
.74857 .52295 Mdot
.58211 .47117 Mdot
.61777 .44315 Mdot
.18046 .54941 Mdot
.36117 .36639 Mdot
.34693 .50084 Mdot
.6006 .37577 Mdot
.29536 .61191 Mdot
.48077 .2165 Mdot
.79399 .51758 Mdot
.39393 .34389 Mdot
.76809 .57946 Mdot
.7319 .61115 Mdot
.54856 .49962 Mdot
.2485 .25595 Mdot
.44597 .47598 Mdot
.66402 .67529 Mdot
.69561 .26373 Mdot
.5574 .38316 Mdot
.548 .19989 Mdot
.5325 .74403 Mdot
.18293 .41433 Mdot
.48819 .14959 Mdot
.77895 .48708 Mdot
.28321 .25283 Mdot
.70918 .23548 Mdot
.17426 .44904 Mdot
.18972 .53524 Mdot
.53703 .60223 Mdot
.447 .10392 Mdot
.66152 .52557 Mdot
.22324 .64367 Mdot
.28809 .65003 Mdot
.71779 .36811 Mdot
.34786 .67199 Mdot
.33142 .45368 Mdot
.70269 .59787 Mdot
.34656 .59922 Mdot
.46517 .427 Mdot
.18561 .36366 Mdot
.15294 .51739 Mdot
.19159 .36304 Mdot
.74512 .30697 Mdot
.29059 .2474 Mdot
.36605 .28533 Mdot
.31013 .50174 Mdot
.45113 .2377 Mdot
.35817 .39649 Mdot
.52041 .26687 Mdot
.6579 .66588 Mdot
.75965 .50379 Mdot
.4611 .6779 Mdot
.33946 .64091 Mdot
.2158 .37659 Mdot
.18317 .31306 Mdot
.22813 .56519 Mdot
.26782 .5259 Mdot
.4926 .58345 Mdot
.55805 .29756 Mdot
.42868 .53171 Mdot
.7559 .56439 Mdot
.58148 .19702 Mdot
.33743 .29357 Mdot
.58862 .26913 Mdot
.80524 .52611 Mdot
.59932 .49501 Mdot
.72912 .6823 Mdot
.42254 .18452 Mdot
.40813 .27536 Mdot
.69333 .74227 Mdot
.38203 .32178 Mdot
.61315 .80859 Mdot
.79819 .46041 Mdot
.72854 .50221 Mdot
.6039 .28474 Mdot
.68273 .54092 Mdot
.54361 .26227 Mdot
.57939 .55884 Mdot
.39791 .24915 Mdot
.53134 .39328 Mdot
.54303 .25761 Mdot
.59902 .49856 Mdot
.22948 .31483 Mdot
.76049 .27869 Mdot
.16422 .56973 Mdot
.80736 .37941 Mdot
.47338 .49329 Mdot
.36813 .46682 Mdot
.64559 .21769 Mdot
.21252 .32219 Mdot
.51182 .14525 Mdot
.57689 .73387 Mdot
.74196 .39287 Mdot
.50329 .61884 Mdot
.17402 .58331 Mdot
.80887 .44824 Mdot
.51707 .16843 Mdot
.35419 .75909 Mdot
.54478 .67336 Mdot
.53627 .78719 Mdot
.19252 .60115 Mdot
.27571 .3443 Mdot
.23025 .51106 Mdot
.37989 .49828 Mdot
.2511 .41011 Mdot
.41288 .61275 Mdot
.60921 .73326 Mdot
.55052 .31408 Mdot
.67166 .49874 Mdot
.42121 .28525 Mdot
.33982 .49606 Mdot
.45021 .45996 Mdot
.72669 .53013 Mdot
.33984 .68082 Mdot
.22868 .63205 Mdot
.59999 .61576 Mdot
.3326 .19835 Mdot
.652 .69259 Mdot
.40495 .52468 Mdot
.5522 .34841 Mdot
.73186 .46909 Mdot
.50852 .78048 Mdot
.5142 .61909 Mdot
.36104 .20763 Mdot
.45661 .54259 Mdot
.54251 .34967 Mdot
.24651 .41846 Mdot
.57095 .235 Mdot
.35932 .37609 Mdot
.49566 .72748 Mdot
.34094 .54165 Mdot
.55376 .48959 Mdot
.40482 .58559 Mdot
.33804 .68247 Mdot
.86939 .43935 Mdot
.61526 .58941 Mdot
.68785 .72469 Mdot
.37013 .20643 Mdot
.54961 .61623 Mdot
.34388 .6516 Mdot
.52405 .25488 Mdot
.61586 .25475 Mdot
.33196 .56434 Mdot
.62301 .51318 Mdot
.66236 .33312 Mdot
.79779 .4935 Mdot
.31699 .24397 Mdot
.27381 .29515 Mdot
.55882 .83973 Mdot
.3612 .67028 Mdot
.54884 .22335 Mdot
.62038 .26352 Mdot
.35391 .65476 Mdot
.44052 .62811 Mdot
.41809 .69331 Mdot
.27986 .24321 Mdot
.48964 .77564 Mdot
.79607 .37244 Mdot
.55099 .40193 Mdot
.72184 .34842 Mdot
.72159 .44894 Mdot
.63689 .29573 Mdot
.37657 .20526 Mdot
.22661 .47753 Mdot
.26972 .33938 Mdot
.43229 .50753 Mdot
.28062 .68474 Mdot
.17613 .59305 Mdot
.52348 .53959 Mdot
.28039 .44049 Mdot
.57232 .70095 Mdot
.43621 .45064 Mdot
.16439 .40517 Mdot
.63446 .24 Mdot
.46485 .80324 Mdot
.59336 .64417 Mdot
.42415 .42788 Mdot
.36572 .47551 Mdot
.49955 .38286 Mdot
.46476 .73736 Mdot
.1623 .52878 Mdot
.64558 .29348 Mdot
.49653 .45536 Mdot
.24364 .43505 Mdot
.66417 .67769 Mdot
.42014 .19592 Mdot
.61089 .22136 Mdot
.57246 .53922 Mdot
.6554 .67208 Mdot
.57255 .44056 Mdot
.79013 .35314 Mdot
.69702 .57618 Mdot
.36847 .27963 Mdot
.34814 .72513 Mdot
.4925 .74934 Mdot
.73864 .47106 Mdot
.36549 .45269 Mdot
.57865 .75248 Mdot
.461 .1813 Mdot
.56642 .85958 Mdot
.59043 .79302 Mdot
.17787 .36495 Mdot
.28651 .417 Mdot
.49304 .75468 Mdot
.25625 .34279 Mdot
.54238 .87453 Mdot
.70809 .57253 Mdot
.2374 .33749 Mdot
.57927 .45862 Mdot
.34622 .21621 Mdot
.57477 .61314 Mdot
.421 .7688 Mdot
.1873 .57852 Mdot
.28793 .23846 Mdot
.48294 .19999 Mdot
.38694 .20708 Mdot
.40055 .3218 Mdot
.25586 .26624 Mdot
.32745 .72279 Mdot
.71031 .62946 Mdot
.68187 .46493 Mdot
.58059 .72242 Mdot
.21545 .42646 Mdot
.45829 .62196 Mdot
.57556 .27253 Mdot
.73003 .66136 Mdot
.3587 .54017 Mdot
.25806 .36367 Mdot
.47376 .27363 Mdot
.51555 .74303 Mdot
.5518 .35354 Mdot
.49441 .16514 Mdot
.74016 .64917 Mdot
.70005 .42635 Mdot
.66341 .72192 Mdot
.76681 .35439 Mdot
.46057 .73463 Mdot
.63154 .6022 Mdot
.50161 .18874 Mdot
.79442 .42635 Mdot
.5964 .30289 Mdot
.88467 .42175 Mdot
.69738 .2982 Mdot
.43929 .66989 Mdot
.20672 .37912 Mdot
.59544 .20703 Mdot
.31929 .70502 Mdot
.55865 .82617 Mdot
.27593 .67907 Mdot
.52867 .28688 Mdot
.3618 .40976 Mdot
.23192 .28217 Mdot
.48938 .30243 Mdot
.21027 .35552 Mdot
.68533 .24071 Mdot
.24886 .40232 Mdot
.43472 .47764 Mdot
.62733 .47862 Mdot
.51522 .56561 Mdot
.46996 .26719 Mdot
.28013 .31358 Mdot
.26356 .66631 Mdot
.66262 .43717 Mdot
.71382 .5825 Mdot
.62558 .51326 Mdot
.4891 .41951 Mdot
.64583 .67244 Mdot
.48903 .74017 Mdot
.5978 .40366 Mdot
.60646 .55818 Mdot
.56473 .28807 Mdot
.23771 .47884 Mdot
.27883 .34161 Mdot
.64563 .78508 Mdot
.55914 .69749 Mdot
.67468 .47094 Mdot
.32906 .2683 Mdot
.70759 .29853 Mdot
.54915 .7256 Mdot
.18185 .45409 Mdot
.52607 .76882 Mdot
.48471 .24199 Mdot
.44113 .22592 Mdot
.6061 .80039 Mdot
.83805 .55756 Mdot
.19919 .43557 Mdot
.28145 .68839 Mdot
.60734 .41728 Mdot
.2988 .41133 Mdot
.34032 .2009 Mdot
.62037 .28653 Mdot
.4127 .23644 Mdot
.49848 .54939 Mdot
.30884 .57932 Mdot
.24142 .3973 Mdot
.4396 .2974 Mdot
.55946 .45895 Mdot
.25251 .73383 Mdot
.33531 .65289 Mdot
.15871 .41498 Mdot
.52928 .6488 Mdot
.43313 .81827 Mdot
.60672 .49854 Mdot
.56081 .54805 Mdot
.54923 .43818 Mdot
.48894 .72386 Mdot
.40457 .71223 Mdot
.75214 .31754 Mdot
.64271 .7965 Mdot
.63171 .50995 Mdot
.57812 .33624 Mdot
.79885 .39474 Mdot
.32893 .2599 Mdot
.44305 .39265 Mdot
.72345 .31343 Mdot
.52023 .53725 Mdot
.75793 .50306 Mdot
.64887 .22263 Mdot
.53813 .70552 Mdot
.40126 .3536 Mdot
.55579 .30082 Mdot
.23521 .3437 Mdot
.4673 .15585 Mdot
.52363 .81642 Mdot
.46654 .49903 Mdot
.51883 .60657 Mdot
.36701 .29968 Mdot
.31761 .2528 Mdot
.58865 .41801 Mdot
.44532 .76463 Mdot
.58436 .2886 Mdot
.12703 .5047 Mdot
.15647 .49913 Mdot
.16365 .53191 Mdot
.56073 .37241 Mdot
.38081 .5806 Mdot
.30589 .70911 Mdot
.41935 .2347 Mdot
.52289 .71298 Mdot
.69024 .27982 Mdot
.56715 .27706 Mdot
.49101 .86142 Mdot
.34166 .51115 Mdot
.75815 .38075 Mdot
.23209 .41031 Mdot
.28027 .62523 Mdot
.55857 .60571 Mdot
.51453 .28685 Mdot
.44628 .53355 Mdot
.50313 .64911 Mdot
.50955 .74214 Mdot
.42761 .74411 Mdot
.40872 .23791 Mdot
.33147 .53899 Mdot
.48498 .47413 Mdot
.36356 .24343 Mdot
.35602 .58908 Mdot
.73078 .45199 Mdot
.70773 .43918 Mdot
.51705 .46732 Mdot
.68015 .52146 Mdot
.47129 .41847 Mdot
.56311 .50144 Mdot
.57182 .45971 Mdot
.21934 .66129 Mdot
.62862 .39815 Mdot
.34528 .61233 Mdot
.42515 .80375 Mdot
.35133 .65016 Mdot
.20106 .32464 Mdot
.75101 .56803 Mdot
.24838 .42348 Mdot
.78012 .47102 Mdot
.79534 .5668 Mdot
.32625 .79836 Mdot
.17885 .51319 Mdot
.47547 .56294 Mdot
.41559 .57461 Mdot
.39578 .66981 Mdot
.64044 .43601 Mdot
.7105 .59862 Mdot
.23881 .51518 Mdot
.66871 .6594 Mdot
.46796 .23696 Mdot
.42285 .61491 Mdot
.73578 .35234 Mdot
.42433 .52835 Mdot
.29502 .22695 Mdot
.66385 .47169 Mdot
.17372 .63512 Mdot
.33284 .40038 Mdot
.30795 .3182 Mdot
.63586 .20955 Mdot
.52626 .80474 Mdot
.74024 .51178 Mdot
.83668 .49885 Mdot
.45029 .42981 Mdot
.48536 .46908 Mdot
.39729 .62286 Mdot
.52028 .22874 Mdot
.63277 .37322 Mdot
.51798 .34554 Mdot
.52602 .6704 Mdot
.71832 .72108 Mdot
.64207 .68372 Mdot
.36386 .59168 Mdot
.4299 .54592 Mdot
.48171 .20754 Mdot
.39994 .74694 Mdot
.52004 .53548 Mdot
.31759 .2773 Mdot
.32985 .56112 Mdot
.42513 .62109 Mdot
.17649 .47039 Mdot
.61973 .26772 Mdot
.43066 .15738 Mdot
.31766 .44169 Mdot
.52307 .55568 Mdot
.38646 .74971 Mdot
.5097 .73332 Mdot
.23849 .49595 Mdot
.57663 .19525 Mdot
.54221 .33658 Mdot
.41772 .77989 Mdot
.53944 .25752 Mdot
.33436 .44509 Mdot
.67661 .58305 Mdot
.60762 .71211 Mdot
.4562 .8521 Mdot
.20118 .55497 Mdot
.55559 .79917 Mdot
.44755 .61701 Mdot
.66318 .67397 Mdot
.33718 .62629 Mdot
.6986 .38765 Mdot
.32436 .55549 Mdot
.72889 .56464 Mdot
.38275 .17457 Mdot
.58576 .19683 Mdot
.47787 .61276 Mdot
.66006 .55374 Mdot
.52861 .40849 Mdot
.3971 .52085 Mdot
.53585 .49112 Mdot
.44484 .44823 Mdot
.49161 .39663 Mdot
.51188 .81126 Mdot
.5134 .71922 Mdot
.33862 .46539 Mdot
.32296 .22113 Mdot
.44278 .15235 Mdot
.24749 .28194 Mdot
.62026 .4227 Mdot
.36337 .60007 Mdot
.17525 .42893 Mdot
.26062 .4867 Mdot
.49306 .16322 Mdot
.20087 .45623 Mdot
.86239 .4177 Mdot
.27653 .32426 Mdot
.58423 .6927 Mdot
.69311 .75146 Mdot
.433 .70176 Mdot
.65639 .23281 Mdot
.71512 .63548 Mdot
.6698 .38874 Mdot
.66523 .2373 Mdot
.29508 .79659 Mdot
.1936 .55046 Mdot
.43365 .75239 Mdot
.31236 .33652 Mdot
.50723 .47135 Mdot
.67342 .64437 Mdot
.35458 .41472 Mdot
.71036 .51787 Mdot
.746 .5098 Mdot
.57005 .28383 Mdot
.2925 .39023 Mdot
.67665 .65062 Mdot
.46874 .26368 Mdot
.51364 .23624 Mdot
.6467 .2887 Mdot
.28806 .31299 Mdot
.24251 .51012 Mdot
.41048 .35618 Mdot
.38013 .57627 Mdot
.64644 .34318 Mdot
.69017 .44128 Mdot
.38241 .38148 Mdot
.73806 .52379 Mdot
.38691 .72741 Mdot
.17873 .37036 Mdot
.68614 .38528 Mdot
.62066 .24791 Mdot
.32822 .65251 Mdot
.47633 .73402 Mdot
.41918 .21087 Mdot
.56422 .76221 Mdot
.6878 .6587 Mdot
.29905 .65855 Mdot
.30685 .24713 Mdot
.51279 .76873 Mdot
.5795 .25555 Mdot
.26619 .71833 Mdot
.51685 .66078 Mdot
.2324 .6299 Mdot
.34864 .28893 Mdot
.54431 .76097 Mdot
.43062 .62994 Mdot
.60195 .6741 Mdot
.66276 .5911 Mdot
.5342 .7548 Mdot
.69918 .26511 Mdot
.52181 .21984 Mdot
.22555 .42826 Mdot
.28151 .28317 Mdot
.70311 .48773 Mdot
.5849 .26847 Mdot
.60794 .64666 Mdot
.67488 .62272 Mdot
.38738 .75771 Mdot
.32765 .20749 Mdot
.54166 .47956 Mdot
.47812 .30455 Mdot
.43404 .44337 Mdot
.28814 .51302 Mdot
.4999 .71895 Mdot
.59751 .51931 Mdot
.67024 .73244 Mdot
.40533 .61138 Mdot
.63322 .71018 Mdot
.75449 .6469 Mdot
.51857 .29797 Mdot
.40503 .55401 Mdot
.32895 .69812 Mdot
.65304 .33183 Mdot
.74464 .64136 Mdot
.41871 .36882 Mdot
.48248 .31664 Mdot
.61218 .4434 Mdot
.21284 .59871 Mdot
.19062 .55195 Mdot
.32382 .26963 Mdot
.64132 .25635 Mdot
.54202 .7228 Mdot
.1992 .4554 Mdot
.41182 .70651 Mdot
.30868 .48845 Mdot
.60132 .75951 Mdot
.40513 .47811 Mdot
.7004 .38526 Mdot
.34317 .62991 Mdot
.31583 .26426 Mdot
.29988 .45547 Mdot
.45353 .29235 Mdot
.54696 .52319 Mdot
.43894 .2036 Mdot
.50048 .52692 Mdot
.63896 .2134 Mdot
.43603 .69944 Mdot
.54894 .31575 Mdot
.58302 .653 Mdot
.58237 .45486 Mdot
.60261 .79317 Mdot
.41182 .17653 Mdot
.65429 .78173 Mdot
.46084 .3352 Mdot
.55054 .79339 Mdot
.28746 .69655 Mdot
.67467 .23724 Mdot
.53965 .30606 Mdot
.53492 .4934 Mdot
.4215 .53061 Mdot
.50297 .59536 Mdot
.75465 .61796 Mdot
.71237 .3927 Mdot
.25313 .50382 Mdot
.67841 .32365 Mdot
.73607 .55447 Mdot
.44591 .39086 Mdot
.31689 .73564 Mdot
.29178 .2692 Mdot
.36449 .55096 Mdot
.54714 .54552 Mdot
.75277 .46636 Mdot
.51531 .30606 Mdot
.86696 .59838 Mdot
.16374 .40434 Mdot
.43246 .44436 Mdot
.546 .41487 Mdot
.518 .33703 Mdot
.66279 .53511 Mdot
.241 .5263 Mdot
.32163 .26856 Mdot
.51735 .62617 Mdot
.73919 .40149 Mdot
.58636 .71162 Mdot
.48556 .7179 Mdot
.42591 .2929 Mdot
.50821 .6704 Mdot
.19036 .34283 Mdot
.72697 .30823 Mdot
.51522 .72658 Mdot
.87889 .5231 Mdot
.58869 .73117 Mdot
.32418 .63922 Mdot
.47645 .19596 Mdot
.23185 .31079 Mdot
.55787 .37904 Mdot
.73573 .4373 Mdot
.19073 .56332 Mdot
.5447 .32334 Mdot
.54009 .24325 Mdot
.66265 .72125 Mdot
.63901 .71398 Mdot
.69535 .61216 Mdot
.7962 .56419 Mdot
.24137 .68058 Mdot
.23118 .45253 Mdot
.26134 .30366 Mdot
.73779 .57195 Mdot
.50436 .86232 Mdot
.41819 .16756 Mdot
.508 .26861 Mdot
.68189 .66778 Mdot
.50107 .19357 Mdot
.50707 .35319 Mdot
.3056 .67002 Mdot
.74864 .56287 Mdot
.3194 .58784 Mdot
.78505 .56772 Mdot
.62238 .75894 Mdot
.54311 .26025 Mdot
.28306 .64606 Mdot
.54587 .47229 Mdot
.30751 .29601 Mdot
.7564 .6759 Mdot
.56018 .33425 Mdot
.74851 .4144 Mdot
.46463 .32693 Mdot
.34414 .24864 Mdot
.48769 .18309 Mdot
.53207 .48267 Mdot
.29408 .79231 Mdot
.2165 .3556 Mdot
.57485 .76681 Mdot
.36516 .46854 Mdot
.38028 .17082 Mdot
.51399 .48603 Mdot
.19363 .47059 Mdot
.67903 .26077 Mdot
.6886 .42504 Mdot
.37357 .74162 Mdot
.41442 .47515 Mdot
.18146 .49597 Mdot
.27614 .42938 Mdot
.27767 .62795 Mdot
.7442 .50029 Mdot
.55107 .34673 Mdot
.74599 .68459 Mdot
.42898 .3061 Mdot
.37806 .50894 Mdot
.34711 .6222 Mdot
.19952 .34296 Mdot
.35247 .31801 Mdot
.47177 .40556 Mdot
.37317 .32808 Mdot
.65011 .78821 Mdot
.856 .51055 Mdot
.38101 .50657 Mdot
.50228 .7766 Mdot
.57678 .27417 Mdot
.4483 .23187 Mdot
.18374 .52975 Mdot
.4946 .91931 Mdot
.62508 .20215 Mdot
.35016 .67877 Mdot
.23632 .624 Mdot
.56227 .35549 Mdot
.25255 .28102 Mdot
.80499 .52148 Mdot
.72537 .46129 Mdot
.64829 .80541 Mdot
.52822 .36873 Mdot
.36492 .37905 Mdot
.73323 .29103 Mdot
.42023 .1717 Mdot
.75406 .6877 Mdot
.34452 .20006 Mdot
.42054 .488 Mdot
.34458 .44732 Mdot
.70566 .80975 Mdot
.33601 .23228 Mdot
.44939 .46529 Mdot
.61791 .81001 Mdot
.38652 .68687 Mdot
.36505 .39089 Mdot
.65429 .61701 Mdot
.61188 .28869 Mdot
.52463 .24037 Mdot
.28656 .23982 Mdot
.38385 .58275 Mdot
.73919 .52425 Mdot
.57937 .63733 Mdot
.55187 .44248 Mdot
.3621 .35897 Mdot
.56777 .6299 Mdot
.49508 .24256 Mdot
.52041 .47258 Mdot
.58209 .66295 Mdot
.63369 .30085 Mdot
.77444 .30728 Mdot
.28252 .40011 Mdot
.49067 .59658 Mdot
.43875 .33622 Mdot
.35809 .55019 Mdot
.47069 .26552 Mdot
.4467 .2499 Mdot
.67821 .24953 Mdot
.70837 .2152 Mdot
.61923 .46746 Mdot
.31982 .42536 Mdot
.36025 .57603 Mdot
.24565 .49706 Mdot
.26884 .3691 Mdot
.59429 .65844 Mdot
.73491 .63121 Mdot
.41311 .48488 Mdot
.37468 .50715 Mdot
.52979 .67116 Mdot
.13325 .45508 Mdot
.35235 .43025 Mdot
.2165 .49147 Mdot
.47192 .17035 Mdot
.73319 .45549 Mdot
.28923 .38114 Mdot
.44945 .41527 Mdot
.32376 .71518 Mdot
.50891 .48862 Mdot
.51475 .43394 Mdot
.71349 .44209 Mdot
.26544 .27761 Mdot
.2989 .45249 Mdot
.22299 .44634 Mdot
.40154 .43814 Mdot
.61236 .40376 Mdot
.41997 .75032 Mdot
.17121 .52111 Mdot
.37296 .52448 Mdot
.48747 .15833 Mdot
.68672 .42009 Mdot
.66235 .31701 Mdot
.30212 .35066 Mdot
.20494 .35913 Mdot
.58726 .79003 Mdot
.26093 .38676 Mdot
.48235 .80638 Mdot
.62821 .62758 Mdot
.47708 .27399 Mdot
.62642 .48949 Mdot
.33366 .45699 Mdot
.40825 .67488 Mdot
.22495 .27773 Mdot
.17552 .53338 Mdot
.57339 .59459 Mdot
.65781 .43684 Mdot
.28731 .47681 Mdot
.54807 .44659 Mdot
.88374 .48239 Mdot
.822 .49187 Mdot
.18725 .34726 Mdot
.50885 .2227 Mdot
.34435 .58776 Mdot
.52361 .74538 Mdot
.4192 .34792 Mdot
.64232 .49096 Mdot
.25669 .28028 Mdot
.33291 .47404 Mdot
.62377 .75105 Mdot
.35682 .39427 Mdot
.44037 .7959 Mdot
.4762 .50585 Mdot
.66764 .55254 Mdot
.69374 .53988 Mdot
.56604 .8201 Mdot
.45459 .18769 Mdot
.5046 .49446 Mdot
.86202 .44873 Mdot
.26657 .32055 Mdot
.36352 .20635 Mdot
.62437 .51491 Mdot
.47636 .83464 Mdot
.43716 .59286 Mdot
.46048 .51621 Mdot
.59255 .60813 Mdot
.42635 .32002 Mdot
.54257 .757 Mdot
.46571 .22956 Mdot
.41604 .72455 Mdot
.47875 .61572 Mdot
.82024 .2908 Mdot
.51299 .26066 Mdot
.37737 .53641 Mdot
.58612 .7477 Mdot
.34868 .2055 Mdot
.65787 .39728 Mdot
.75946 .30387 Mdot
.61696 .55846 Mdot
.34516 .37271 Mdot
.33479 .5361 Mdot
.31124 .31988 Mdot
.59509 .70343 Mdot
.28735 .7653 Mdot
.6962 .28947 Mdot
.66706 .32987 Mdot
.60328 .55777 Mdot
.35317 .65624 Mdot
.34904 .67283 Mdot
.78885 .50354 Mdot
.81267 .35772 Mdot
.4961 .47459 Mdot
.32046 .24892 Mdot
.36578 .81931 Mdot
.55354 .23414 Mdot
.26082 .26637 Mdot
.46867 .6439 Mdot
.44227 .62399 Mdot
.46971 .26034 Mdot
.5835 .37876 Mdot
.69359 .53122 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0;7ooooo0_l0002Fooooo`007?ooool00ol0003oooooooooo`2aoooo
o`;o0000U_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo08gooooo
0ol0000Hooooo`;o00001?ooool2o`0009Wooooo000Looooo`03o`000?oooooooooo08gooooo0ol0
000Cooooo`;o00000oooool2o`0000Cooooo0_l0000:ooooo`;o0000SOooool001cooooo00?o0000
ooooooooool0VOooool2o`0000?ooooo0_l00002ooooo`?o00005Oooool2o`0008gooooo000Loooo
o`03o`000?oooooooooo09Wooooo0_l00003ooooo`;o00000_ooool2o`000:Gooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0Loooool2o`000=Cooooo000Looooo`03o`000?oooooooooo07?o
oooo0_l0001Dooooo`;o0000O_ooool001cooooo00?o0000ooooooooool0S?ooool2o`0003_ooooo
0_l0001nooooo`007?ooool00ol0003oooooooooo`2<ooooo`;o00002?ooool2o`0000Oooooo0_l0
002Xooooo`007?ooool00ol0003oooooooooo`2Fooooo`;o00001oooool2o`000:Sooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0X_ooool2o`000:Go
oooo000Looooo`03o`000?oooooooooo09Kooooo0_l00003ooooo`;o00001Oooool2o`000003oooo
ool0003o000000;o0000X?ooool001cooooo0_l0002=ooooo`;o00002?ooool2o`0000?ooooo0_l0
0008ooooo`Co0000X?ooool001cooooo00?o0000ooooooooool0S?ooool2o`0000Kooooo0_l0000n
ooooo`;o0000Loooool001cooooo00?o0000ooooooooool0R?ooool2o`0000Gooooo0_l00003oooo
o`;o00001Oooool2o`00017ooooo0_l0000Tooooo`;o0000Loooool001cooooo00?o0000oooooooo
ool0R?ooool2o`0000Gooooo0ol00009ooooo`;o00000_ooool2o`0000Kooooo0_l00005ooooo`;o
0000VOooool001cooooo00?o0000ooooooooool0T?ooool2o`0000[ooooo1Ol00006ooooo`;o0000
00?oooooo`000?l000000_l0002Kooooo`007?ooool00ol0003oooooooooo`24ooooo`;o00005_oo
ool4o`0000;ooooo1?l00004ooooo`Co00000_ooool2o`0009Oooooo000Looooo`03o`000?oooooo
oooo07Sooooo0_l0000:ooooo`?o00003oooool2o`0000Cooooo0_l00004ooooo`Co00002?ooool5
o`0009Kooooo000Looooo`03o`000?oooooooooo07Sooooo0ol00006ooooo`;o00000_ooool2o`00
00Oooooo0_l00002ooooo`;o00000_ooool3o`0000?ooooo0_l000000ooooooo0000o`00000=oooo
o`;o000000?oooooo`000?l00000U_ooool001cooooo00?o0000ooooooooool0NOooool2o`0000Ko
oooo0ol00003ooooo`;o00001Oooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000?o
oooo1Ol0000>ooooo`Co0000U_ooool001cooooo00?o0000ooooooooool0OOooool2o`0000?ooooo
0_l000000ooooooo0000o`000002o`0000Wooooo0_l000001?oooooo0000o`000?l00004ooooo`Co
00002oooool2o`0000;ooooo0_l0002Hooooo`007?ooool00ol0003oooooooooo`1mooooo`;o0000
1Oooool5o`0000;ooooo0_l00005ooooo`;o00001oooool2o`0000kooooo0_l0002Looooo`007?oo
ool00ol0003oooooooooo`1fooooo`;o00003?ooool4o`0000?ooooo0_l00003ooooo`;o00002Ooo
ool2o`0000Wooooo0_l00009ooooo`;o00000_ooool3o`00097ooooo000Looooo`03o`000?oooooo
oooo073ooooo0_l00004ooooo`;o00002_ooool2o`0000?ooooo0_l00007ooooo`Co00002oooool3
o`0000Cooooo0_l00008ooooo`?o00000_ooool5o`0008oooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`1`ooooo`;o00003Ooo
ool2o`000004ooooool0003o0000ooooo`Co00001Oooool2o`0000;ooooo0_l0000;ooooo`?o0000
3_ooool2o`0000Kooooo0_l0000;ooooo`;o0000P_ooool00006oooooomgMgOoV9RHoooooonHV9So
MgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo
07oooooo0_l00004ooooo`?o00001_ooool2o`0000Oooooo0_l00006ooooo`;o00003oooool2o`00
00Gooooo1Ol000000ooooooo0000o`000006ooooo`;o00007_ooool2o`0006;ooooo00000ooooooo
410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003o
ooooooooo`1Xooooo`;o000000Coooooo`000?l0003o00003?ooool2o`0000Wooooo0_l0000@oooo
o`Co00002_ooool2o`0000Gooooo1_l000000ooooooo0000o`000002ooooo`Go000000Coooooo`00
0?l0003ooooo0_l0000Sooooo`;o0000H_ooool00003ooooool0003ooooo00;ooooo00?o0000oooo
ooooool02oooool00onHV9So8B4Qonk^kP06ooooo`?o0000Ioooool3o`000004ooooool0003o0000
o`0000cooooo0_l00002ooooo`;o00006Oooool2o`0000[ooooo0_l00005ooooo`Co00000oooool2
o`0000Cooooo0_l00003ooooo`Ko00000oooool2o`00083ooooo00000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`1Woooo
o`;o00000_ooool5o`0000Oooooo0_l00005ooooo`;o00002oooool2o`0000Cooooo0_l0000?oooo
o`;o00001Oooool2o`0000?ooooo0_l00004ooooo`;o00000oooool2o`0000?ooooo0_l000001?oo
oooo0000o`000?l00002ooooo`?o0000P?ooool00003ooooool@413ooooo00;ooooo00?o410@oooo
ooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06Oooooo0_l00005oooo
o`So000000Coooooo`000?l0003ooooo0_l00005ooooo`;o00002?ooool2o`000004ooooool0003o
0000ooooo`;o00001_ooool2o`0000Oooooo0_l00005ooooo`;o00002Oooool2o`0000Sooooo0_l0
00000ooooooo0000o`000003ooooo`;o0000POooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
2oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0Ioooool2o`000003
ooooool0003o000000Cooooo1_l00004ooooo`;o00001Oooool2o`000003ooooool0003o000000Co
oooo0ol000001?oooooo0000o`000?l00008ooooo`;o00000oooool2o`0001kooooo0_l0000;oooo
o`;o00000_ooool2o`0007Sooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo06[ooooo0_l0000Hooooo`;o00001?oo
ool2o`0000?ooooo0_l0000=ooooo`;o00005?ooool4o`0000[ooooo1Ol00004ooooo`?o000000?o
ooooo`000?l000004Oooool2o`0006Gooooo000Looooo`03o`000?oooooooooo06gooooo0_l0000Y
ooooo`Co00006?ooool4o`000003ooooool0003o000000Oooooo1Ol00005ooooo`Co00004_ooool2
o`0000gooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o00001_ooool2o`00
02Cooooo0_l00003ooooo`Co00002_ooool2o`0000;ooooo0_l0000=ooooo`;o00002?ooool2o`00
00;ooooo0_l000000ooooooo0000o`000002ooooo`;o00008Oooool2o`0005Kooooo000Looooo`03
o`000?oooooooooo06Cooooo0ol0000Eooooo`;o00005Oooool2o`0000Gooooo0_l00006ooooo`;o
00000_ooool2o`0000;ooooo0_l00003ooooo`;o00004_ooool2o`0000;ooooo0_l000001?oooooo
0000o`000?ooool6o`0007Kooooo000Looooo`03o`000?oooooooooo05cooooo0_l00006ooooo`;o
00000_ooool2o`00013ooooo1?l0000>ooooo`;o00003?ooool2o`0000Kooooo0_l0000;ooooo`;o
00007?ooool6o`0007Kooooo000Looooo`03o`000?oooooooooo05cooooo0_l00008ooooo`Co0000
4?ooool3o`0000Gooooo0_l00008ooooo`;o00001_ooool2o`0000?ooooo0_l00009ooooo`?o0000
0oooool2o`0000?ooooo0_l0000:ooooo`;o00000_ooool2o`0000Sooooo0_l000000ooooooo0000
o`000002ooooo`;o0000Moooool001cooooo00?o0000ooooooooool0I_ooool2o`000003ooooool0
003o000001Oooooo0_l0000:ooooo`;o00001?ooool2o`0000?ooooo0_l00004ooooo`;o00000ooo
ool3o`0000?ooooo0_l000000ooooooo0000o`00000<ooooo`;o00000_ooool2o`0000Kooooo1?l0
00000ooooooo0000o`000003ooooo`;o0000M_ooool001cooooo00?o0000ooooooooool0HOooool2
o`0000Kooooo0_l0000?ooooo`;o00001_ooool5o`0000;ooooo0ol000001?oooooo0000o`000?l0
0004ooooo`;o00002Oooool2o`0000;ooooo0_l00008ooooo`;o000000?oooooo`000?l000001?oo
ool2o`0000?ooooo0_l0000:ooooo`;o00002?ooool2o`00013ooooo0_l0001Tooooo`007?ooool0
0ol0003oooooooooo`1Fooooo`;o000000Coooooo`000?l0003o00001Oooool2o`0000;ooooo0_l0
000Cooooo`;o00001Oooool6o`0000;ooooo0ol000000ooooooo0000o`000003o`0000;ooooo0_l0
0009ooooo`;o00000_ooool2o`0000_ooooo1?l000001?oooooo0000o`000?l00003ooooo`;o0000
3?ooool3o`0000Sooooo0_l000000ooooooo0000o`00000:ooooo`;o0000I?ooool001cooooo00?o
0000ooooooooool0E_ooool2o`000004ooooool0003o0000o`0000Cooooo1?l000000ooooooo0000
o`000004ooooo`;o00002Oooool2o`0000Wooooo0ol0000;ooooo`?o00002?ooool2o`000003oooo
ool0003o000000;o00001_ooool4o`0000Oooooo0_l000000ooooooo0000o`000004ooooo`;o0000
1oooool2o`0000?ooooo0ol00008ooooo`;o000000?oooooo`000?l000000_ooool2o`0006cooooo
000Looooo`03o`000?oooooooooo05Oooooo0_l00005ooooo`Oo00001_ooool2o`0000?ooooo1?l0
0002ooooo`;o00005Oooool2o`0000_ooooo0_l000000ooooooo0000o`000008ooooo`Co000000?o
ooooo`000?l000000_l0000Dooooo`;o000000?oooooo`000?l000004_ooool2o`0006cooooo000L
ooooo`03o`000?oooooooooo05Oooooo0_l00002ooooo`Oo000000Coooooo`000?l0003o00001_oo
ool2o`0000;ooooo1_l00008ooooo`;o000000?oooooo`000?l000002_ooool2o`0000?ooooo0_l0
000Cooooo`;o00000oooool4o`0000oooooo0_l00005ooooo`?o0000P?ooool001cooooo0_l0001L
ooooo`Co000000?oooooo`000?l000000_ooool2o`0000Kooooo0_l00006ooooo`;o00002?ooool2
o`000003ooooool0003o000000[ooooo0ol00002ooooo`;o0000:oooool2o`0000Cooooo0ol0000?
ooooo`Co00000oooool2o`0006Wooooo000Looooo`03o`000?oooooooooo05Sooooo0_l00009oooo
o`;o00005Oooool2o`00017ooooo0ol0000Fooooo`;o00005Oooool2o`0000Gooooo0ol000000ooo
oooo0000o`000003ooooo`;o00002?ooool5o`0000;ooooo0_l0001Yooooo`007?ooool00ol0003o
ooooooooo`1=ooooo`;o00002Oooool2o`0000?ooooo0_l00004ooooo`;o00005Oooool4o`0002Co
oooo0_l00002ooooo`;o00000oooool4o`0000Wooooo0_l00003ooooo`Co00000oooool2o`0000;o
oooo0_l00003ooooo`Co00001oooool4o`0006gooooo000Looooo`03o`000?oooooooooo04gooooo
0_l0000>ooooo`;o00002?ooool2o`0001?ooooo1?l0000Eooooo`;o00002oooool3o`0000Kooooo
1?l00009ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o0000
0_ooool4o`0000Oooooo0ol0001^ooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o00004?oo
ool2o`0000;ooooo0_l0000>ooooo`Co00000oooool2o`0000kooooo0_l00005ooooo`;o00003?oo
ool2o`0000Sooooo0_l000000ooooooo0000o`000002ooooo`;o00001_ooool2o`0000Gooooo0_l0
00001?oooooo0000o`000?ooool2o`0000?ooooo0_l00008ooooo`?o00000oooool2o`0006Wooooo
000Looooo`03o`000?oooooooooo04Sooooo0_l00005ooooo`Co00004?ooool2o`0000;ooooo1?l0
000<ooooo`Co00004oooool2o`0000Gooooo0ol0000=ooooo`;o00000_ooool2o`0000;ooooo0_l0
00000ooooooo0000o`000002ooooo`;o00002_ooool5o`000004ooooool0003o0000ooooo`Co0000
3?ooool2o`0000?ooooo0ol0001Xooooo`007?ooool00ol0003oooooooooo`18ooooo`;o00001Ooo
ool4o`0000?ooooo0_l00003ooooo`;o00002?ooool6o`0002[ooooo0ol00009ooooo`;o000000Co
ooooo`000?l0003o00000_ooool2o`0000;ooooo0_l0000;ooooo`?o00000oooool5o`000004oooo
ool0003o0000ooooo`Co00004_ooool2o`0006Sooooo000Looooo`03o`000?oooooooooo05Kooooo
0_l00003ooooo`;o00002?ooool4o`0001Oooooo0_l0000>ooooo`;o00001?ooool3o`0000Sooooo
0_l000000ooooooo0000o`000007ooooo`;o00001?ooool2o`0000;ooooo0_l000001?oooooo0000
o`000?l0000?ooooo`;o00005_ooool2o`0006?ooooo000Looooo`03o`000?oooooooooo04Gooooo
0_l0000;ooooo`;o0000;?ooool3o`0000?ooooo0_l00002ooooo`;o00001?ooool4o`0000;ooooo
0ol0000Jooooo`Oo00004_ooool2o`000003ooooool0003o000001?ooooo0_l0001Sooooo`007?oo
ool00ol0003oooooooooo`15ooooo`;o00002oooool3o`0000kooooo0_l0000?ooooo`;o00002ooo
ool2o`0000?ooooo0_l00002ooooo`;o00001_ooool2o`0000?ooooo0_l0000Cooooo`;o00001_oo
ool6o`0001Gooooo0_l0000;ooooo`;o00001_ooool2o`0000;ooooo0_l00009ooooo`;o0000E?oo
ool001cooooo00?o0000ooooooooool0AOooool2o`000003ooooool0003o000000?ooooo1Ol00000
0ooooooo0000o`000003ooooo`;o00002Oooool2o`0000oooooo0_l0000Fooooo`;o00007_ooool2
o`0000Sooooo0_l0000Iooooo`;o00001oooool4o`0000[ooooo0_l00009ooooo`;o0000E?ooool0
01cooooo00?o0000ooooooooool0B?ooool2o`0000?ooooo1Ol00006ooooo`;o00006Oooool2o`00
00[ooooo0_l00004ooooo`;o00001?ooool3o`0000;ooooo0_l00004ooooo`;o00004Oooool2o`00
00?ooooo0_l00005ooooo`;o00000_ooool2o`0000Gooooo0_l0000?ooooo`;o000000?oooooo`00
0?l000001?ooool2o`0006gooooo000Looooo`03o`000?oooooooooo06kooooo0_l00003ooooo`;o
00002?ooool4o`0000Cooooo0_l00004ooooo`;o00000oooool2o`0000Cooooo0_l0000;ooooo`;o
00000oooool5o`000003ooooool0003o000000Cooooo1?l000001?oooooo0000o`000?l00004oooo
o`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`Co000000Coooooo`000?l0003ooooo0_l0
000Iooooo`;o0000F?ooool001cooooo00?o0000ooooooooool0K_ooool2o`0000gooooo0_l0000A
ooooo`;o00004Oooool2o`0000?ooooo0_l000000ooooooo0000o`000007ooooo`Co00000_ooool2
o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000000oooool5o`0000Gooooo0_l00007
ooooo`;o00002_ooool4o`000003ooooool0003o000001Kooooo0_l00010ooooo`007?ooool00ol0
003oooooooooo`1@ooooo`;o00000oooool2o`0001?ooooo0_l00003ooooo`;o00005_ooool4o`00
00Cooooo0ol0000Nooooo`;o00001_ooool2o`0000Gooooo0_l00002ooooo`;o00001_ooool2o`00
0003ooooool0003o000000Gooooo0_l00007ooooo`;o00002_ooool4o`0001Wooooo0_l00010oooo
o`007?ooool00ol0003oooooooooo`1@ooooo`;o00000oooool2o`0000Wooooo0_l00006ooooo`Co
00000oooool2o`0001Kooooo1_l00002ooooo`;o00000oooool2o`0000oooooo0_l00004ooooo`;o
00000oooool4o`0000Cooooo0_l00003ooooo`;o00003?ooool2o`000003ooooool0003o000000oo
oooo0_l000000ooooooo0000o`00001Uooooo`007?ooool2o`0005cooooo0_l00003ooooo`;o0000
00?oooooo`000?l000000oooool2o`0000Cooooo0_l00003ooooo`;o00005_ooool2o`0000Oooooo
0_l0000?ooooo`;o00001?ooool2o`0000;ooooo1Ol00005ooooo`;o00000_ooool2o`0000_ooooo
0ol0000<ooooo`;o00001?ooool2o`000003ooooool0003o000000kooooo0_l0001Eooooo`007?oo
ool00ol0003oooooooooo`1Aooooo`;o00000oooool2o`0000?ooooo0_l00006ooooo`;o00001ooo
ool4o`0000?ooooo0_l0000Sooooo`;o000000?oooooo`000?l000000oooool2o`0000Kooooo0_l0
0004ooooo`Ko00001Oooool2o`0000?ooooo0_l0000:ooooo`;o000000?oooooo`000?l000001?oo
ool2o`0000Cooooo0_l0000Gooooo`?o0000E?ooool001cooooo00?o0000ooooooooool0DOooool2
o`0000?ooooo0_l0000Dooooo`;o00006_ooool2o`0000kooooo0_l000000ooooooo0000o`000003
ooooo`;o00000_ooool6o`0000;ooooo1Ol000000ooooooo0000o`000007ooooo`Go00003Oooool4
o`0000;ooooo0_l0000?ooooo`;o00002?ooool2o`0000?ooooo0_l00003ooooo`;o0000Coooool0
01cooooo00?o0000ooooooooool0B?ooool2o`0003;ooooo0_l0000:ooooo`;o00004Oooool2o`00
00Kooooo1Ol00004ooooo`;o000000?oooooo`000?l000002_ooool5o`0000oooooo0_l00004oooo
o`;o00003Oooool2o`0000;ooooo0_l00004ooooo`?o00001oooool2o`0004oooooo000Looooo`03
o`000?oooooooooo03Sooooo0_l00005ooooo`;o00001oooool2o`0000gooooo0_l000000ooooooo
0000o`00000Pooooo`;o00007Oooool2o`000004ooooool0003o0000ooooo`Co000000Coooooo`00
0?l0003ooooo0_l000000ooooooo0000o`000004ooooo`;o00002_ooool2o`0001Gooooo0_l0000@
ooooo`?o00001Oooool2o`0000Oooooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`0hoooo
o`;o00001Oooool2o`0000Kooooo0_l00003ooooo`;o00002Oooool2o`000003ooooool0003o0000
02Wooooo0_l00005ooooo`;o00001?ooool2o`0000Gooooo0_l00003ooooo`;o000000Coooooo`00
0?l0003o00000_ooool2o`000004ooooool0003o0000ooooo`;o000000Coooooo`000?l0003ooooo
0_l0000Booooo`;o00000oooool2o`0000Kooooo0_l0000Booooo`;o0000H?ooool001cooooo00?o
0000ooooooooool0Aoooool2o`0000?ooooo0_l0000=ooooo`;o00000oooool3o`0000cooooo0_l0
000Dooooo`Co00000oooool2o`0000Cooooo0_l00005ooooo`;o00001oooool4o`0000Wooooo0_l0
0005ooooo`;o00003_ooool2o`0000?ooooo0_l00006ooooo`;o00004_ooool2o`0000Sooooo0ol0
000Jooooo`;o0000>Oooool001cooooo00?o0000ooooooooool0@Oooool2o`0000Kooooo0_l00003
ooooo`;o00000oooool2o`0000Kooooo0_l00003ooooo`?o00001_ooool4o`0000;ooooo0_l00007
ooooo`;o00001?ooool2o`0000Oooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l0
0006ooooo`;o000000?oooooo`000?l000000oooool5o`0000Oooooo1?l00005ooooo`;o00001_oo
ool2o`0000kooooo0_l00004ooooo`;o00004oooool2o`0000Kooooo1Ol00003ooooo`;o00004ooo
ool2o`0003Wooooo000Looooo`03o`000?oooooooooo03kooooo0_l000001?oooooo0000o`000?oo
ool2o`0000?ooooo0_l00003ooooo`Co000000Coooooo`000?l0003ooooo0_l0000:ooooo`;o0000
1Oooool4o`0000_ooooo0_l00004ooooo`?o00000_ooool2o`0000Gooooo0_l000000ooooooo0000
o`000002ooooo`;o00001?ooool4o`000003ooooool0003o000000?ooooo1?l000000ooooooo0000
o`000005ooooo`Co00002oooool4o`0000gooooo0ol00004ooooo`;o00000oooool2o`0000kooooo
0_l00006ooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo0_l00019ooooo`007?oo
ool00ol0003oooooooooo`0nooooo`;o00001?ooool2o`0000[ooooo0_l00004ooooo`;o00002_oo
ool2o`00017ooooo0_l00008ooooo`;o00000_ooool2o`0000_ooooo0_l000001?oooooo0000o`00
0?ooool3o`0000gooooo0_l00005ooooo`?o00001Oooool2o`0000Gooooo0_l0000;ooooo`Ko0000
2?ooool4o`0001Kooooo0_l00003ooooo`;o00001?ooool4o`0004Wooooo000Looooo`03o`000?oo
oooooooo047ooooo0_l0000Looooo`;o00001_ooool2o`0000Wooooo0_l000000ooooooo0000o`00
000>ooooo`;o00002Oooool5o`000003ooooool0003o000000oooooo0_l00005ooooo`;o00001Ooo
ool2o`00013ooooo1ol00002ooooo`?o00000_ooool4o`0001Sooooo1?l000000ooooooo0000o`00
0004ooooo`Go0000B?ooool001cooooo00?o0000ooooooooool0@Oooool2o`0001cooooo0_l00006
ooooo`;o000000?oooooo`000?l000000oooool2o`000003ooooool0003o000000Gooooo0_l00002
ooooo`;o00001Oooool3o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`Co00002_ooool2
o`0000Kooooo0_l00005ooooo`;o00000_ooool2o`0001?ooooo0_l00002ooooo`co00007?ooool2
o`0000[ooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00002Oooool2o`00
00Oooooo0_l00003ooooo`;o00001?ooool4o`0000?ooooo0_l00005ooooo`;o000000?oooooo`00
0?l000000_ooool2o`0000?ooooo1?l00004ooooo`Go00000oooool5o`0000Oooooo0ol00003oooo
o`;o00001_ooool2o`0000Cooooo0_l00004ooooo`;o00000_ooool2o`0000;ooooo0_l00004oooo
o`_o00000_ooool2o`0000gooooo0_l0001Uooooo`007?ooool00ol0003oooooooooo`19ooooo`;o
00002Oooool2o`000003ooooool0003o000000Cooooo0_l00003ooooo`Co00000_ooool2o`000003
ooooool0003o000000Sooooo0ol00003ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Co
oooo0_l000001?oooooo0000o`000?l00007ooooo`;o000000?oooooo`000?l000001?ooool3o`00
00?ooooo0_l00006ooooo`;o00002Oooool3o`0000;ooooo0_l00002ooooo`Co00000_ooool;o`00
00?ooooo0_l000000ooooooo0000o`000009ooooo`;o00007Oooool2o`0000gooooo0_l0000goooo
o`007?ooool00ol0003oooooooooo`0jooooo`;o000000?oooooo`000?l000002_ooool2o`0000Co
oooo0ol00002ooooo`Go00002oooool2o`0000Gooooo0_l00008ooooo`?o00000oooool8o`000004
ooooool0003o0000ooooo`?o00001?ooool2o`0000Sooooo0_l00005ooooo`?o00005Oooool2o`00
00Wooooo0_l00002ooooo`Ko000000Coooooo`000?l0003o00001?ooool2o`000003ooooool0003o
000002Sooooo0_l0000=ooooo`;o0000=oooool001cooooo00?o0000ooooooooool0>Oooool3o`00
0004ooooool0003o0000ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Cooooo0ol00004
ooooo`Co00001_ooool2o`0000gooooo0_l00004ooooo`?o000000Coooooo`000?l0003ooooo1ol0
00000ooooooo0000o`000003o`0000Gooooo0_l0000:ooooo`;o00001?ooool2o`0000;ooooo0_l0
0009ooooo`;o00001_ooool3o`0000Gooooo4ol00003ooooo`;o00004Oooool2o`0001Sooooo0_l0
0015ooooo`007?ooool2o`0003[ooooo0_l00005ooooo`;o000000?oooooo`000?l000004oooool2
o`0000Cooooo1?l00007ooooo`;o00001?ooool2o`0000Gooooo0_l000001?oooooo0000o`000?oo
ool4o`0000Cooooo1?l0000Booooo`Co00000_ooool2o`0000;ooooo0_l00005ooooo`?o000000Co
ooooo`000?l0003o00001_ooool3o`0000Cooooo4ol00003ooooo`;o00004?ooool4o`0001Oooooo
0_l00015ooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o00001_ooool5o`0000;ooooo0_l0
0004ooooo`?o00000_ooool2o`000003ooooool0003o000000Co00000oooool2o`0001Kooooo0ol0
00001?oooooo0000o`000?l00007ooooo`Co000000Goooooo`000?l0003o0000ooooo`02o`0000Co
oooo0_l00002ooooo`;o00000_oooolBo`0001Cooooo1_l00004ooooo`;o00002_ooool2o`0000Go
oooo0_l00013ooooo`007?ooool00ol0003oooooooooo`11ooooo`Co00008Oooool4o`000003oooo
ool0003o000000;o00001?ooool3o`0000;ooooo0_l000000ooooooo0000o`000007o`0000Wooooo
0_l00007ooooo`;o00001Oooool2o`0000;ooooo0_l00007ooooo`;o00000oooool2o`0000;ooooo
1?l00006oooooaKo00006?ooool2o`0000Cooooo0_l00002ooooo`;o00001_ooool2o`0000Gooooo
0_l00013ooooo`007?ooool00ol0003oooooooooo`0oooooo`Ko00009_ooool4o`0000?ooooo0_l0
0002ooooo`?o000000?oooooo`000?l000002_l00007ooooo`;o00000_ooool2o`000003ooooool0
003o000000;o00000oooool2o`0000Gooooo0_l00004ooooo`;o00002Oooool4o`0000Sooooo5Ol0
000>ooooo`;o00004Oooool2o`0000;ooooo0_l00009ooooo`;o0000@oooool001cooooo00?o0000
ooooooooool0>oooool2o`0000;ooooo1?l0000;ooooo`;o00000_ooool2o`0000oooooo0_l00004
ooooo`;o00001Oooool4o`0000;ooooo2ol00002ooooo`?o000000?oooooo`000?l000000_ooool4
o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l000001?l00004
ooooo`?o00001_ooool2o`0000;ooooo0_l000000ooooooo0000o`000005oooooaGo00003_ooool2
o`00017ooooo0_l00002ooooo`;o00002Oooool2o`0004?ooooo000Looooo`03o`000?oooooooooo
03Gooooo0ol000000ooooooo0000o`000002o`0000Cooooo0_l00009ooooo`So00003oooool5o`00
0004ooooool0003o0000o`0000Cooooo1?l00005ooooo`Go000000Goooooo`000?l0003o0000oooo
o`03o`000003ooooool0003o000000;ooooo0_l00006ooooo`;o00001oooool7o`000003ooooool0
003o000000?ooooo0_l00006ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000Oooooo
4_l0000Gooooo`;o00002?ooool2o`0005?ooooo000Looooo`03o`000?oooooooooo03Gooooo0ol0
00000ooooooo0000o`00000<ooooo`;o00000_ooool3o`0000;ooooo0_l00002ooooo`;o00003ooo
ool3o`0000;ooooo0_l00004ooooo`Co00001Oooool3o`0000;ooooo2?l000000ooooooo0000o`00
0002o`000003ooooool0003o000000Gooooo0_l00007ooooo`;o00000_ooool3o`000003ooooool0
003o000000Co00001_ooool2o`0000;ooooo0_l00009ooooo`Go000000?oooooo`000?l000003?l0
000Booooo`;o00000_ooool3o`0000Sooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`0f
ooooo`;o00003oooool2o`0000;ooooo0_l00007ooooo`;o000000Coooooo`000?l0003ooooo0_l0
0004ooooo`?o00000oooool5o`0000;ooooo0_l000000ooooooo0000o`00000;o`000003ooooool0
003o000000;ooooo1?l00002ooooo`?o000000?oooooo`000?l000004_ooool3o`0000?ooooo1?l0
0006ooooo`Co000000Coooooo`000?l0003ooooo1?l00002oooooaKo00003?ooool2o`0000?ooooo
0_l00002ooooo`;o00005?ooool2o`0004Sooooo000Looooo`03o`000?oooooooooo03Kooooo0_l0
000Oooooo`;o000000?oooooo`000?l000001?ooool3o`0000Gooooo2?l00002ooooo`oo000000?o
ooooo`000?l000001Ol0000Hooooo`Co000000Coooooo`000?l0003o00001_ooool2o`000004oooo
ool0003o0000ooooo`;o000000?oooooo`000?l000000_l00002oooooaKo00003?ooool2o`0001go
oooo0_l0000Dooooo`;o0000<_ooool001cooooo00?o0000ooooooooool0@_ooool2o`0001cooooo
0_l00004ooooo`oo000000?oooooo`000?l000002Ol000000ooooooo0000o`000005o`0000?ooooo
0_l00003ooooo`;o00001?ooool2o`0000Gooooo0_l000000ooooooo0000o`000002o`000004oooo
ool0003o0000o`0000Kooooo0_l0000>oooooaGo0000<_ooool2o`0000gooooo0_l0000booooo`00
7?ooool00ol0003oooooooooo`0oooooo`;o000000?oooooo`000?l000004Oooool2o`0000?ooooo
0_l00004ooooo`;o00001?ooool4o`000004ooooool0003o0000ooooo`Oo000000?oooooo`000?l0
00002Ol000000ooooooo0000o`000005o`0000?ooooo0_l000000ooooooo0000o`000004o`0000;o
oooo0_l00003ooooo`Co00000_ooool2o`0000?ooooo0_l00008ooooo`;o00001?ooool5o`0000?o
oooo5Ol00008ooooo`;o00001Oooool2o`0000gooooo0_l00006ooooo`;o000000?oooooo`000?l0
00000oooool2o`0000;ooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0oooooo`;o0000
5?ooool2o`0000?ooooo0_l0000<ooooo`;o000000Coooooo`000?l0003ooooo6_l00006ooooo`?o
00000_ooool3o`0000Kooooo0_l000001?oooooo0000o`000?ooool5o`0000Gooooo0_l00003oooo
o`Co000000?oooooo`000?l000001?l00005oooooa;o00000_ooool2o`0000Gooooo0_l00005oooo
o`;o00003Oooool3o`0000Gooooo0_l000000ooooooo0000o`000003ooooo`;o0000AOooool001co
oooo00?o0000ooooooooool0DOooool4o`0000Kooooo0_l0000>ooooo`;o00000_ooool<o`000003
ooooool0003o000000Ko000000Goooooo`000?l0003o0000ooooo`07o`0000Cooooo0_l00007oooo
o`Co00000_ooool4o`000003ooooool0003o000000;ooooo0_l00003ooooo`Co000000?oooooo`00
0?l000002?oooolAo`000004ooooool0003o0000ooooo`;o00001?ooool2o`0000;ooooo0ol0000A
ooooo`;o00001Oooool2o`0004gooooo000Looooo`03o`000?oooooooooo03[ooooo0_l0000Eoooo
o`Co00001_ooool2o`0000gooooo5Ol000001Ooooooo0000o`000?l0003ooooo00co000000?ooooo
o`000?l000002_ooool2o`0000Wooooo0_l0000Foooooa7o000000?oooooo`000?l000000_ooool2
o`0000?ooooo0_l00002ooooo`?o00006?ooool2o`0000Oooooo0_l00005ooooo`;o0000?Oooool0
0006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413ooooooooo
o`04ooooo`03o`000?oooooooooo03;ooooo0_l00006ooooo`;o00002Oooool4o`0001;ooooo0_l0
000=ooooobGo00000_ooool2o`0000Kooooo0_l0000>ooooo`;o00000oooool2o`00013ooooo4?l0
00000ooooooo0000o`000003ooooo`;o00003?ooool2o`0000Oooooo0_l00006ooooo`;o00003?oo
ool2o`0000Gooooo0_l0000mooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q
1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03;ooooo0_l0000;ooooo`;o0000
0oooool5o`0000_ooooo0_l0000Cooooo`?o00000oooool9o`000003ooooool0003o000001?o0000
2oooool2o`000003ooooool0003o000000_ooooo0ol00002ooooo`;o00001oooool2o`0000Oooooo
4?l000000ooooooo0000o`000004ooooo`;o00002oooool2o`0000Oooooo0_l00003ooooo`;o0000
00?oooooo`000?l000002Oooool2o`0000Cooooo0_l00011ooooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`09ooooo`Go00001_ooool00ol0003oooooooooo`0oooooo`;o00000ooo
ool2o`0000Gooooo0_l00007ooooo`Ko00002Oooool2o`0000;ooooo1Ol00004oooooa[o000000Co
ooooo`000?l0003ooooo0_l00002ooooo`;o00001Oooool2o`000003ooooool0003o000000?ooooo
0_l000000ooooooo0000o`000003ooooo`?o00001Oooool2o`0000Cooooo0ol00005ooooo`oo0000
0oooool3o`0000?ooooo0_l0000Iooooo`;o00003?ooool2o`0000Cooooo0_l00002ooooo`;o0000
?Oooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?m4A4CogMgMoooo
ool00007ooooo`?o0000?_ooool2o`0000_ooooo1?l00007ooooo`Co00002Oooool2o`0000;ooooo
1_l00003ooooob7o000000?oooooo`000?l000001Oooool2o`0000Kooooo0_l000001?oooooo0000
o`000?l00002ooooo`;o00001?ooool4o`0000Gooooo0_l00005ooooo`oo00000oooool4o`0001Oo
oooo0_l00002ooooo`;o00002Oooool2o`0000[ooooo0_l000000ooooooo0000o`00000mooooo`00
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oo
oooo00?o0000ooooooooool0<Oooool3o`0000Kooooo0_l00002ooooo`;o00003Oooool2o`0000Wo
oooo0ol0000=ooooo`Go000000?oooooo`000?l000008Ol00004ooooo`;o00000_ooool2o`0000[o
oooo0_l00002ooooo`;o00001?ooool5o`0000;ooooo0_l00006ooooo`[o00000_ooool7o`0000;o
oooo0ol0000Fooooo`;o00000_ooool2o`000003ooooool0003o000000Kooooo0_l0000:ooooo`;o
0000@?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00omgMgOoc<c<
o`000007ooooo`03o`000?oooooooooo037ooooo0ol00006ooooo`;o00004_ooool2o`0000Sooooo
0ol0000<ooooo`Co00000ooooolQo`0000;ooooo0ol000000ooooooo0000o`000005ooooo`;o0000
2_ooool2o`0000Gooooo0_l000000ooooooo0000o`000004o`0000Kooooo2_l00005ooooo`Co0000
0oooool2o`0001_ooooo1?l0001Dooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<ooooo`03
onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0<_ooool2o`0000[ooooo0_l00008ooooo`;o
00001?ooool2o`0000;ooooo0_l00009ooooo`;o00002?ooool4o`0000;ooooo8_l00002ooooo`?o
000000?oooooo`000?l000001Oooool2o`0000Cooooo0_l00004ooooo`;o00001Oooool7o`0000Ko
oooo1?l000000ooooooo0000o`000003ooooo`;o0000:?ooool3o`0001Oooooo0_l0000mooooo`00
00Koooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000oooo
ooooool0<?ooool3o`0000Gooooo0_l00004ooooo`;o00001?ooool2o`0000;ooooo0_l00004oooo
o`;o00000_ooool2o`0000Sooooo0ol00008ooooo`;o00001?ooool7o`000003ooooool0003o0000
023o00002oooool2o`0000[ooooo1_l00008ooooo`?o00001oooool2o`0001Cooooo0_l0000Aoooo
o`?o00000_ooool2o`0000Cooooo0_l0000>ooooo`;o0000?Oooool001cooooo00?o0000oooooooo
ool0<?ooool3o`0000Gooooo0_l0000:ooooo`;o00000oooool2o`000003ooooool0003o000000?o
oooo0_l00006ooooo`;o000000?oooooo`000?l000003OoooolJo`000003ooooool0003o000000[o
000000?oooooo`000?l000000_l000000ooooooo0000o`00000Dooooo`;o00001Oooool2o`0000Co
oooo0_l00005ooooo`?o000000?oooooo`000?l000000oooool2o`0000Kooooo0_l00003ooooo`;o
00000_ooool2o`00017ooooo0_l00003ooooo`;o00001?ooool3o`0000_ooooo0_l0000:ooooo`;o
0000<oooool001cooooo00?o0000ooooooooool0BOooool2o`000004ooooool0003o0000ooooo`Co
00001_ooool2o`0000_ooooo1?l000001?oooooo0000o`000?ooool2o`000003ooooool0003o0000
01oo000000?oooooo`000?l000001Ol000001?oooooo0000o`000?l0000Dooooo`;o000000?ooooo
o`000?l000001?ooool2o`0000Gooooo0ol00006ooooo`;o00001_ooool2o`0000?ooooo0_l00000
0ooooooo0000o`00000Jooooo`;o00000_ooool3o`0000[ooooo0_l0000:ooooo`;o00001_ooool2
o`0002_ooooo000Looooo`03o`000?oooooooooo04gooooo1?l0000Eooooo`Co00000_ooool2o`00
00?ooooo2_l00002oooooaGo000000?oooooo`000?l000001Ol000001?oooooo0000o`000?l00009
ooooo`;o00002Oooool2o`0000_ooooo0_l00005ooooo`;o00004oooool2o`0001Gooooo0_l00003
ooooo`;o00000oooool2o`0000_ooooo0_l000000ooooooo0000o`00000>ooooo`;o0000:oooool0
01cooooo00?o0000ooooooooool0>?ooool2o`0000Sooooo0_l00009ooooo`;o000000?oooooo`00
0?l000004_ooool2o`0000;ooooo1_l00002ooooob3o00000oooool6o`0000Wooooo0_l00003oooo
o`;o00000oooool2o`000004ooooool0003o0000ooooo`Co00002Oooool2o`0000Gooooo0_l00005
ooooo`;o00002oooool4o`0000;ooooo0ol0000?ooooo`;o00002_ooool2o`0000Wooooo0_l00000
0ooooooo0000o`00000kooooo`007?ooool00ol0003oooooooooo`0eooooo`;o000000?oooooo`00
0?l000001?ooool2o`0000;ooooo0_l00002ooooo`;o00002?ooool2o`0000Cooooo0_l00003oooo
o`Co00001Oooool2o`0000?ooooo8ol000000ooooooo0000o`000006o`0000gooooo0_l00005oooo
o`;o000000Coooooo`000?l0003ooooo1ol0000Gooooo`;o00002oooool4o`0000;ooooo0ol0000E
ooooo`;o00001?ooool2o`0004Wooooo000Looooo`03o`000?oooooooooo03Gooooo0_l00007oooo
o`;o00001_ooool2o`0000kooooo0_l00003ooooo`Co00003?oooolQo`000003ooooool0003o0000
00Ko00003_ooool2o`0000Cooooo0_l00006ooooo`Co00002Oooool2o`0000Gooooo0_l0000;oooo
o`Co00007?ooool2o`000004ooooool0003o0000ooooo`;o0000Coooool001cooooo00?o0000oooo
ooooool0?Oooool2o`0000Oooooo0_l00003ooooo`Co00005?ooool2o`000003ooooool0003o0000
00Gooooo8ol00002ooooo`?o00003_ooool2o`0000Oooooo0_l00004ooooo`;o00002Oooool3o`00
00;ooooo0_l000000ooooooo0000o`000005ooooo`;o00000oooool5o`0000;ooooo0_l00003oooo
o`;o00000oooool2o`0000Oooooo0_l00005ooooo`;o000000?oooooo`000?l00000D_ooool001co
oooo00?o0000ooooooooool0?Oooool2o`0000Oooooo0_l00003ooooo`Co00004oooool3o`000003
ooooool0003o000000?ooooo9?l00003ooooo`Go00005Oooool2o`000004ooooool0003o0000oooo
o`;o00002Oooool2o`000003ooooool0003o000000;o00001Oooool2o`000003ooooool0003o0000
00;o000000?oooooo`000?l000000ol000001?oooooo0000o`000?l00003ooooo`;o00000oooool2
o`0000Oooooo0_l00005ooooo`;o000000?oooooo`000?l000008?ooool2o`00033ooooo000Loooo
o`03o`000?oooooooooo03_ooooo0_l000000ooooooo0000o`00000;ooooo`Co00000_ooool2o`00
00Cooooo0_l00009ooooo`?o00001_ooool]o`0001Oooooo0_l00005ooooo`;o00002?ooool2o`00
0003ooooool0003o000000;o00000_ooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool2
o`000004ooooool0003o0000ooooo`Co00001?ooool4o`0000Gooooo0_l00008ooooo`;o00003_oo
ool2o`00013ooooo0_l0000`ooooo`007?ooool00ol0003oooooooooo`0kooooo`;o000000?ooooo
o`000?l000001Oooool2o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`000003ooooool0003o
000000Kooooo0ol00004ooooo`;o000000?oooooo`000?l000009_l000001?oooooo0000o`000?l0
0007ooooo`;o00003_ooool4o`0000?ooooo0_l0000;ooooo`Co000000?oooooo`000?l000001_oo
ool4o`0000Kooooo1Ol00005ooooo`;o000000?oooooo`000?l000000_ooool2o`0000_ooooo0_l0
000;ooooo`;o00001oooool2o`0003Wooooo000Looooo`03o`000?oooooooooo03Gooooo0_l0000>
ooooo`;o00002oooool4o`0000?ooooo0ol0000=ooooo`;o000000Goooooo`000?l0003o0000oooo
o`0Ro`0000Kooooo0_l00002ooooo`;o000000?oooooo`000?l000003Oooool2o`000004ooooool0
003o0000o`0000;ooooo1?l0000>ooooo`;o00001_ooool5o`0000Sooooo0_l00008ooooo`;o0000
3oooool2o`0000Wooooo0_l00009ooooo`;o00001?ooool2o`0003?ooooo000Looooo`;o0000=_oo
ool2o`00013ooooo0ol00008ooooo`Co00000oooool2o`0000;ooooo0_l00004ooooo`;o00001ooo
oolXo`0000Cooooo0_l00002ooooo`;o00004?ooool2o`0000;ooooo0_l00002ooooo`Co00005_oo
ool5o`0001;ooooo0_l000000ooooooo0000o`00000;ooooo`;o00002_ooool2o`0000?ooooo0_l0
0007ooooo`;o000000?oooooo`000?l000001_ooool2o`0002_ooooo000Looooo`03o`000?oooooo
oooo02Sooooo0_l0000=ooooo`;o000000Coooooo`000?l0003ooooo0_l00008ooooo`?o00000_oo
ool2o`0000Wooooo0_l00004ooooo`?o00000oooool2o`0000?ooooo9_l000000ooooooo0000o`00
0005o`0000;ooooo0_l00004ooooo`;o00004Oooool4o`0000Cooooo0_l0000=ooooo`;o00003Ooo
ool5o`0000kooooo0_l0000;ooooo`;o00003oooool2o`0000Oooooo0_l00009ooooo`;o0000:ooo
ool001cooooo00?o0000ooooooooool0:?ooool2o`0000gooooo0_l000001?oooooo0000o`000?oo
ool3o`0000[ooooo1?l00009ooooo`;o00001Oooool2o`0000Sooooo1Ol000000ooooooo0000o`00
000@o`000003ooooool0003o000000_o000000Coooooo`000?l0003o00000_ooool2o`0000?ooooo
0_l00003ooooo`;o00003Oooool2o`0000;ooooo1Ol00002ooooo`?o00003Oooool2o`000003oooo
ool0003o000000[ooooo1Ol0000>ooooo`?o00002_ooool2o`0000Wooooo0_l0000;ooooo`;o0000
>?ooool001cooooo00?o0000ooooooooool0?_ooool3o`0000?ooooo0_l00004ooooo`;o00003?oo
ool2o`0000?ooooo0_l00005ooooo`;o00000oooool4o`000003ooooool0003o0000023o00001_oo
ool5o`0000_ooooo0_l00005ooooo`;o000000?oooooo`000?l000002?l0000Aooooo`;o000000?o
ooooo`000?l000001_ooool2o`0000kooooo1?l000000ooooooo0000o`00000Booooo`;o000000?o
ooooo`000?l000002oooool2o`0003Sooooo000Looooo`03o`000?oooooooooo03cooooo0_l00000
0ooooooo0000o`000003ooooo`;o00001?ooool2o`0000cooooo0_l00003ooooo`Wo00002OoooolN
o`000005ooooool0003o0000o`000?ooool00_l00002ooooo`?o00003Oooool2o`0000Kooooo1_l0
0002ooooo`;o00005_ooool3o`000003ooooool0003o000000So00002_ooool4o`0000Cooooo0_l0
000?ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0??ooool2o`0000cooooo1?l00009
ooooo`;o00000oooool8o`0000Kooooo0_l00003ooooo`;o000000?oooooo`000?l000006Ol00000
0ooooooo0000o`000004o`000003ooooool0003o000000gooooo0_l00006ooooo`Co000000?ooooo
o`000?l000004_ooool2o`0000Gooooo4_l0000@ooooo`;o000000?oooooo`000?l000000oooool2
o`00057ooooo000Looooo`03o`000?oooooooooo03Kooooo0_l00003ooooo`;o00003oooool2o`00
00Sooooo0ol00003ooooo`;o00003?ooool2o`0000Kooooo1Ol000000ooooooo0000o`00000Bo`00
00;ooooo1?l00003ooooo`?o00000_ooool2o`0000Sooooo0_l00006ooooo`Co000000?oooooo`00
0?l000004_ooool2o`0000Cooooo3ol000000ooooooo0000o`000002o`000003ooooool0003o0000
00;ooooo0_l00004ooooo`Ko000000?oooooo`000?l000000oooool3o`000003ooooool0003o0000
04gooooo000Looooo`03o`000?oooooooooo037ooooo0_l00003ooooo`;o00000oooool2o`0000oo
oooo1?l00002ooooo`;o000000Coooooo`000?l0003o00004?ooool2o`0000Cooooo1?l000000ooo
oooo0000o`000004o`0000Cooooo3?l00008ooooo`;o00000_ooool3o`0000;ooooo0_l00005oooo
o`;o00000_ooool2o`0000Oooooo0_l000000ooooooo0000o`000006ooooo`;o00001?ooool2o`00
00Wooooo4?l000000ooooooo0000o`000005o`0000;ooooo0_l00004ooooo`Co00002Oooool2o`00
0003ooooool0003o000004gooooo000Looooo`03o`000?oooooooooo037ooooo0_l0000Eooooo`;o
00000oooool3o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o00003?ooool2o`0000Co
oooo3?l00003ooooo`co000000?oooooo`000?l000000ol00002ooooo`;o00000_ooool2o`0000?o
oooo0_l000000ooooooo0000o`000002ooooo`;o000000Coooooo`000?l0003o00001oooool2o`00
00Wooooo0_l00004ooooo`;o00001ooooolHo`0000?ooooo0_l0001Tooooo`007?ooool00ol0003o
ooooooooo`16ooooo`Ko000000?oooooo`000?l000002oooool2o`0001Kooooo7Ol00005ooooo`?o
00001_ooool2o`0000?ooooo1?l00006ooooo`;o00003Oooool2o`0000Cooooo0_l00003oooooa_o
00000_ooool4o`0006;ooooo000Looooo`03o`000?oooooooooo04Kooooo0_l00002ooooo`;o0000
3?ooool2o`0001Sooooo1Ol000000ooooooo0000o`00000Ao`0000Kooooo0_l000000ooooooo0000
o`000002o`0000Wooooo0ol000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l00000
3Oooool2o`0000Cooooo0_l00003oooooa_o000000Coooooo`000?l0003ooooo0_l0000Zooooo`;o
00002?ooool2o`0002cooooo000Looooo`03o`000?oooooooooo04Wooooo0_l0000=ooooo`;o0000
6?ooool5o`000003ooooool0003o000000;o00001?ooool6o`0000_ooooo0_l00003ooooo`;o0000
2Oooool6o`0000;ooooo0_l00004ooooo`;o00005OoooolNo`0000Oooooo0_l0000Tooooo`;o0000
2?ooool2o`0002cooooo000Looooo`03o`000?oooooooooo03Wooooo0_l0000=ooooo`?o00001_oo
ool4o`0000cooooo0_l0000Booooo`?o000000Coooooo`000?l0003o00001?ooool4o`000004oooo
ool0003o0000o`0000Oooooo0_l00005ooooo`;o00002_ooool3o`0000[ooooo0ol0000Foooooaco
00001oooool2o`0000Gooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00003_ooool2o`00
03kooooo000Looooo`03o`000?oooooooooo03Sooooo1?l00007ooooo`;o00000oooool2o`000003
ooooool0003o000000Cooooo1?l0000<ooooo`;o00002_ooool2o`0000?ooooo2_l00005ooooo`?o
000000Coooooo`000?l0003o00001?ooool2o`000003ooooool0003o000000Gooooo0_l0000:oooo
o`Co00000oooool3o`0000?ooooo0ol0000Fooooo`;o000000?oooooo`000?l000005ol00003oooo
o`?o00002?ooool2o`000005ooooool0003o0000o`000?ooool00_l00009ooooo`;o000000?ooooo
o`000?l000000ol0000mooooo`007?ooool00ol0003oooooooooo`0hooooo`Co00001oooool2o`00
00Kooooo0_l0000=ooooo`;o00004Oooool2o`000003ooooool0003o000000Co00000_ooool2o`00
00Oooooo2?l000000ooooooo0000o`000008o`0000;ooooo0_l000000ooooooo0000o`000005oooo
o`;o00000_ooool2o`0000?ooooo2?l0000>ooooo`;o00000oooool2o`0000Gooooo2_l000000ooo
oooo0000o`000005o`000004ooooool0003o0000ooooo`?o00000oooool3o`0000?ooooo0_l00007
ooooo`;o00001oooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0003gooooo000L
ooooo`03o`000?oooooooooo03Oooooo0_l0000Aooooo`Ko00002_ooool2o`0000oooooo0_l00003
ooooo`;o000000Coooooo`000?l0003o00000_ooool3o`0000Gooooo3?l000000ooooooo0000o`00
0005o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`;o00002?ooool7o`0000kooooo1?l0
00000ooooooo0000o`000004ooooo`[o000000?oooooo`000?l000003Ol00009ooooo`;o00004?oo
ool2o`0000Kooooo0_l00003ooooo`;o0000>oooool001cooooo0_l0000Yooooo`;o00001Oooool2
o`0000Kooooo0_l0000Aooooo`Ko00004Oooool2o`0000Sooooo1?l00004ooooo`?o000000?ooooo
o`000?l000000_l00004ooooo`Co00001?ooool5o`0000?ooooo0_l00002ooooo`?o00005_ooool4
o`0000?ooooo0_l0000:ooooo`Co000000?oooooo`000?l000001?ooool:o`000003ooooool0003o
000000go00002_ooool2o`0001Oooooo0_l00002ooooo`?o0000>oooool001cooooo00?o0000oooo
ooooool09_ooool4o`0000Gooooo0_l0000Hooooo`;o00001?ooool2o`0000oooooo0ol00007oooo
o`;o000000?oooooo`000?l000001Oooool2o`000003ooooool0003o000000;o000000Coooooo`00
0?l0003ooooo1?l00006ooooo`;o00001Oooool2o`000004ooooool0003o0000o`0000cooooo0_l0
0008ooooo`Ko000000?oooooo`000?l000003oooool2o`0000?ooooo2ol000001?oooooo0000o`00
0?ooool<o`0000Gooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000?o0000
1Oooool2o`0000gooooo0ol0000kooooo`007?ooool00ol0003oooooooooo`0Vooooo`;o00003Ooo
ool3o`00017ooooo0_l00004ooooo`;o00003oooool2o`0000Sooooo0_l0000:ooooo`Co00000_oo
ool2o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`?o00001Oooool2o`0000Gooooo0_l0
0009ooooo`;o00001?ooool2o`0000Cooooo1_l00003ooooo`;o00004?oooolMo`0000?ooooo0_l0
00001?oooooo0000o`000?ooool2o`000003ooooool0003o000000?o00001Oooool2o`0000kooooo
0_l0000kooooo`007?ooool00ol0003oooooooooo`0eooooo`?o00003oooool2o`0000;ooooo0_l0
0002ooooo`;o00002?ooool2o`0000Gooooo0_l00009ooooo`;o00002Oooool4o`0000Cooooo0_l0
0002ooooo`Co000000?oooooo`000?l000000_l0000<ooooo`Co00003Oooool3o`0000?ooooo0_l0
00000ooooooo0000o`000002o`0000;ooooo0ol0000;ooooo`;o00000_oooolMo`0000Sooooo1?l0
000Pooooo`;o0000=Oooool001cooooo00?o0000ooooooooool0=_ooool2o`0000oooooo0_l00002
ooooo`;o00000_ooool6o`0000Cooooo0ol0000?ooooo`;o00002_ooool2o`0000Gooooo0_l00002
ooooo`Co000000?oooooo`000?l000000_ooool2o`0000cooooo0_l00003ooooo`;o00000oooool2
o`0000?ooooo0ol00008ooooo`;o00000oooool2o`0000_ooooo7?l000000ooooooo0000o`000008
ooooo`Ko00001_ooool2o`0001Sooooo0_l0000eooooo`007?ooool00ol0003oooooooooo`0foooo
o`;o00004_ooool2o`0000Gooooo1?l00004ooooo`?o00000oooool2o`0000Cooooo0_l0000Ioooo
o`;o00002Oooool4o`0000?ooooo0_l00007ooooo`;o000000?oooooo`000?l000000oooool2o`00
00?ooooo0_l0000Aooooo`;o00001_ooool2o`0000;ooooo7Ol00008ooooo`?o00002Oooool2o`00
04oooooo000Looooo`03o`000?oooooooooo02kooooo0_l0000>ooooo`;o00002_ooool2o`0000ko
oooo0ol00002ooooo`;o00001?ooool2o`0001Wooooo0_l00008ooooo`Go00000oooool2o`0000;o
oooo0_l00003ooooo`;o00002Oooool2o`0000Cooooo0_l0000=ooooo`;o000000?oooooo`000?l0
00000oooool2o`0000;ooooo7_l00008ooooo`Ko00002oooool2o`0000kooooo0_l0000iooooo`00
7?ooool00ol0003oooooooooo`0^ooooo`;o00001?ooool3o`0000Kooooo0ol0000@ooooo`;o0000
2Oooool3o`00017ooooo0_l0000<ooooo`?o00002?ooool4o`0000[ooooo0_l0000;ooooo`;o0000
00?oooooo`000?l000001?ooool4o`0000kooooo0_l00007oooooako00002?ooool7o`0000[ooooo
0_l00002ooooo`;o00002_ooool2o`0000[ooooo0_l0000]ooooo`007?ooool00ol0003ooooooooo
o`0^ooooo`;o00001?ooool3o`0000Kooooo0_l0000<ooooo`;o00000oooool2o`000003ooooool0
003o000000Oooooo0_l0000?ooooo`Co00001?ooool2o`0000Kooooo1Ol00006ooooo`;o00006Ooo
ool2o`0000Wooooo0_l0000Hoooooago00001oooool5o`000003ooooool0003o000000gooooo0ol0
000Fooooo`;o0000;Oooool001cooooo00?o0000ooooooooool0<Oooool2o`000004ooooool0003o
0000o`0000Wooooo0_l00009ooooo`;o00001_ooool2o`0001Sooooo0_l00006ooooo`;o000000?o
ooooo`000?l000001_ooool3o`0000?ooooo1?l0000Eooooo`;o00001oooool2o`00013ooooo0_l0
000<ooooo`;o000000?oooooo`000?l000002Ol000000ooooooo0000o`00000;o`0000Sooooo1_l0
000?ooooo`?o00002oooool2o`0003Sooooo000Looooo`03o`000?oooooooooo037ooooo0_l00005
ooooo`;o00001_ooool2o`0001Kooooo0_l0000Gooooo`;o00001Oooool2o`0000?ooooo0_l00002
ooooo`;o00000_ooool5o`0000Gooooo0_l0000:ooooo`;o00000_ooool2o`0000Oooooo0_l0000@
ooooo`;o00002_ooool2o`0000?ooooo2?l000000ooooooo0000o`00000:o`000003ooooool0003o
000000Oo00001_ooool2o`0001gooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0Toooo
o`;o00002oooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0001cooooo0_l0000Goooo
o`;o00002_ooool2o`0000Kooooo1Ol00003ooooo`Co00002_ooool2o`0000Cooooo0_l00002oooo
o`;o00007oooool2o`0000?ooooo7ol000000ooooooo0000o`00001Looooo`007?ooool00ol0003o
ooooooooo`0Tooooo`;o00003oooool2o`0000;ooooo0ol0000]ooooo`;o00002Oooool5o`0000[o
oooo0_l00002ooooo`;o00001?ooool4o`0000Gooooo0_l00005ooooo`;o00000_ooool2o`0000;o
oooo0_l0000Uoooooa3o000000?oooooo`000?l000001?l000000ooooooo0000o`000005ooooo`;o
0000G?ooool001cooooo00?o0000ooooooooool0=Oooool2o`0000;ooooo0_l0000]ooooo`Go0000
1?ooool2o`000003ooooool0003o000000?o00002_ooool2o`0000[ooooo0_l00005ooooo`;o0000
1Oooool2o`0000Kooooo0ol00002ooooo`;o00001Oooool2o`0000?ooooo0_l00005ooooo`;o0000
2Oooool2o`0000;ooooo4?l00002ooooo`?o00000oooool2o`0000_ooooo0_l000001?oooooo0000
o`000?l0001Booooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00002_ooool2o`0002_ooooo
0_l000000ooooooo0000o`000004ooooo`;o00001?ooool2o`00013ooooo0_l00006ooooo`;o0000
2Oooool2o`0000Sooooo0_l00002ooooo`;o00001Oooool2o`0000?ooooo0_l00005ooooo`;o0000
2Oooool2o`0000Gooooo1?l000000ooooooo0000o`000006o`0000;ooooo0ol0000@ooooo`;o0000
00Coooooo`000?l0003o0000D_ooool001cooooo00?o0000ooooooooool0;oooool2o`0000[ooooo
0_l000000ooooooo0000o`00000Uooooo`;o00004?ooool4o`0000gooooo0ol00006ooooo`;o0000
2Oooool3o`0000Kooooo0_l00004ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Wooooo
0_l00005ooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l00000
0oooool3o`0000Sooooo0_l0000Qooooo`?o0000>_ooool001cooooo0_l0000`ooooo`;o00001_oo
ool2o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`;o00007oooool2o`0000[ooooo1?l0
0004ooooo`;o00003Oooool2o`0000_ooooo0_l00006ooooo`?o000000?oooooo`000?l000000_oo
ool2o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o00002Oooool2o`0000Gooooo0_l0
0003ooooo`?o00002_ooool2o`0000Cooooo0_l0000;ooooo`;o00008Oooool3o`0003[ooooo000L
ooooo`03o`000?oooooooooo02oooooo0_l00006ooooo`;o000000Coooooo`000?l0003o00001ooo
ool2o`0002?ooooo0_l00006ooooo`Co00001?ooool4o`0000?ooooo0_l0000Cooooo`;o00001ooo
ool2o`000003ooooool0003o000000cooooo0_l0000Eooooo`;o000000?oooooo`000?l000002?oo
ool4o`0000Gooooo1?l0000Cooooo`;o0000E?ooool001cooooo00?o0000ooooooooool0>Oooool3
o`0000;ooooo0_l0000Vooooo`;o000000?oooooo`000?l000002?ooool2o`0000Cooooo1?l00003
ooooo`;o00009?ooool2o`0000Oooooo1?l0000;ooooo`;o000000?oooooo`000?l000000oooool2
o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000000_ooool4o`0000Gooooo1?l0
0004ooooo`?o00001?ooool2o`0000Kooooo0_l0000Rooooo`;o0000<?ooool001cooooo00?o0000
ooooooooool0>Oooool2o`0000?ooooo0ol0000Uooooo`;o00004Oooool4o`0001cooooo0_l0000;
ooooo`;o00001Oooool2o`0000;ooooo0_l00005ooooo`;o00000oooool6o`0000;ooooo0_l00002
ooooo`;o000000?oooooo`000?l000001_l00007ooooo`?o00001_ooool3o`0000Cooooo0_l00009
ooooo`;o00005?ooool2o`0000Wooooo0_l0000`ooooo`007?ooool00ol0003oooooooooo`0joooo
o`;o00000oooool2o`0002Gooooo0ol00006ooooo`;o000000?oooooo`000?l000001Oooool4o`00
01[ooooo1?l0000Booooo`;o00002Oooool2o`0000?ooooo0_l000001?oooooo0000o`000?l00002
ooooo`;o00001oooool6o`0000Oooooo0_l00005ooooo`;o00002oooool2o`0000Gooooo0_l0000D
ooooo`;o00001oooool2o`0003;ooooo000Looooo`03o`000?oooooooooo03Gooooo0_l00003oooo
o`;o00002_ooool3o`0001kooooo1?l00004ooooo`;o000000?oooooo`000?l000001Oooool2o`00
00;ooooo0_l0000Hooooo`?o00000oooool2o`0000Gooooo0_l000000ooooooo0000o`00000Foooo
o`;o00002Oooool2o`0000Kooooo0_l0000>ooooo`;o00001Oooool2o`0000Cooooo0_l000000ooo
oooo0000o`00000;ooooo`;o00005?ooool2o`0003;ooooo000Looooo`03o`000?oooooooooo03Go
oooo0_l000000ooooooo0000o`00000<ooooo`?o00007oooool3o`0000Cooooo0_l0000<ooooo`;o
00006oooool5o`0000Gooooo0_l000000ooooooo0000o`00000Fooooo`;o00002Oooool2o`0000Co
oooo0_l0000=ooooo`;o00002?ooool2o`0000Gooooo1_l00005ooooo`;o00000_ooool4o`0004Ko
oooo000Looooo`03o`000?oooooooooo03;ooooo0_l00004ooooo`;o0000=Oooool2o`0000oooooo
0_l0000Dooooo`;o00000_ooool5o`0000Oooooo0_l00004ooooo`;o00008_ooool2o`0000Sooooo
0_l00002ooooo`?o000000?oooooo`000?l000001?ooool2o`0000;ooooo0_l00002ooooo`;o0000
0_ooool2o`0000Gooooo0_l00002ooooo`Co0000A_ooool001cooooo00?o0000ooooooooool0<_oo
ool2o`0000Cooooo0_l0000dooooo`;o00004?ooool2o`000003ooooool0003o0000017ooooo0_l0
000>ooooo`So00002Oooool2o`00027ooooo0_l00002ooooo`?o000000?oooooo`000?l000001?oo
ool2o`0000;ooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`0iooooo`;o0000<oooool2
o`000003ooooool0003o000000Cooooo0ol00009ooooo`?o000000?oooooo`000?l000004Oooool2
o`0000[ooooo1_l0000;ooooo`;o00002Oooool2o`0001Kooooo0_l00003ooooo`;o00001_ooool2
o`00063ooooo000Looooo`03o`000?oooooooooo03Wooooo0_l0000Vooooo`;o00001Oooool2o`00
00Gooooo1?l00004ooooo`?o00001_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000Aoooo
o`;o00002Oooool2o`0001_ooooo0_l0000Fooooo`;o00000oooool2o`0000Kooooo0_l00005oooo
o`;o00001_ooool2o`00057ooooo000Looooo`03o`000?oooooooooo02oooooo0ol00003ooooo`?o
0000:Oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool5o`0000?ooooo0ol0000Jooooo`;o
00001oooool2o`0000;ooooo0_l0000]ooooo`;o00002_ooool2o`0000Sooooo0_l00006ooooo`;o
0000DOooool001cooooo00?o0000ooooooooool0;oooool3o`0000?ooooo0ol000000ooooooo0000
o`000007ooooo`;o00000_ooool2o`000003ooooool0003o000001Wooooo0_l00006ooooo`;o0000
2?ooool6o`000003ooooool0003o000000?o00005oooool2o`000003ooooool0003o000000;o0000
2Oooool4o`0001?ooooo1?l0000Dooooo`Co00000oooool2o`0000?ooooo0_l0001Sooooo`007?oo
ool00ol0003oooooooooo`0fooooo`;o000000?oooooo`000?l000001oooool2o`0000;ooooo0_l0
00000ooooooo0000o`00000Iooooo`;o00001_ooool2o`0000;ooooo0_l00002ooooo`So000000?o
ooooo`000?l000000ol00003ooooo`;o00002?ooool2o`0000Cooooo0_l00002ooooo`;o00000ooo
ool2o`0000Gooooo0_l00004ooooo`;o00003Oooool2o`000004ooooool0003o0000ooooo`Ko0000
3Oooool2o`0000Gooooo0_l00003ooooo`;o00002?ooool2o`0005kooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0
003oooooooooo`0fooooo`;o00000oooool2o`0002?ooooo0_l0000>ooooo`_o00000_ooool2o`00
0003ooooool0003o000000?ooooo0_l00003ooooo`;o00000oooool2o`0000Cooooo0_l000000ooo
oooo0000o`00000;ooooo`;o00002Oooool2o`0000Gooooo0_l000001?oooooo0000o`000?ooool2
o`0000Cooooo0ol00004ooooo`;o00000oooool6o`0001Cooooo0_l0000Cooooo`;o0000BOooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RH
ob4Q8@06ooooo`03o`000?oooooooooo03Kooooo0_l00003ooooo`;o00003?ooool2o`0001Gooooo
0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`[o00000_ooool3o`0000?o
oooo0_l00002ooooo`;o000000?oooooo`000?l000003?ooool2o`0000;ooooo0ol000000ooooooo
0000o`000003ooooo`;o00002Oooool2o`0000?ooooo1_l00002ooooo`?o00000_ooool2o`0000Ko
oooo0_l00003ooooo`Co00004_ooool2o`0000Wooooo0_l0000<ooooo`;o0000BOooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool0@Oooool2o`0000Kooooo0_l0000Kooooo`;o000000Coooooo`000?l0
003ooooo3ol000000ooooooo0000o`000003o`0000;ooooo0_l00002ooooo`;o00004oooool3o`00
0003ooooool0003o000000gooooo0_l00004ooooo`?o000000?oooooo`000?l000000_ooool3o`00
00;ooooo0_l0000Looooo`;o000000?oooooo`000?l000000_l00003ooooo`Go000000?oooooo`00
0?l000005Oooool2o`0000gooooo0_l0000aooooo`0000?oooooo`000?ooool00_ooool00ol0003o
ooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0003_ooooo0_l00003oooo
o`Go00009oooool?o`000003ooooool0003o000000?o00009_ooool3o`000003ooooool0003o0000
00;ooooo0_l00005ooooo`;o00004Oooool2o`0001Gooooo0_l000000ooooooo0000o`000002oooo
o`Wo00003oooool2o`0000Kooooo0_l0000=ooooo`;o0000<Oooool00003ooooool0003ooooo00;o
oooo00?o0000ooooooooool02Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000oooo
ooooool0>oooool2o`0000?ooooo0_l000000ooooooo0000o`00000Vooooo`_o000000?oooooo`00
0?l000001ol000000ooooooo0000o`000002o`0000;ooooo0_l000000ooooooo0000o`000002o`00
01Gooooo1ol000000ooooooo0000o`000002ooooo`Go000000?oooooo`000?l000001?ooool4o`00
0003ooooool0003o000000Oooooo0_l0000Looooo`Wo00003oooool2o`0004Sooooo00000ooooooo
410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003o
ooooooooo`14ooooo`;o00004Oooool2o`0001;ooooo6_l00002ooooo`;o000000?oooooo`000?l0
00000_l0000>ooooo`;o00001?ooool8o`000003ooooool0003o000000_o00000oooool7o`000003
ooooool0003o000000Kooooo0_l0000Hooooo`co00002_ooool2o`0004cooooo00001_ooooooMgMg
oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0ooooo
o`;o00000oooool2o`000003ooooool0003o000000gooooo0ol00003ooooo`;o00002oooool2o`00
0004ooooool0003o0000oooooaKo00000_ooool3o`0000gooooo0_l00003ooooo`;o00001?oooolF
o`0000Gooooo0ol00003ooooo`;o00001_ooool2o`00017ooooo0_l00005ooooo`oo00001oooool2
o`0004cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@
1_ooool00ol0003oooooooooo`0oooooo`;o00001_ooool2o`0000gooooo0ol00003ooooo`;o0000
2oooool5o`000003ooooool0003o000001Wo00003Oooool3o`0000Oooooo6?l00006ooooo`;o0000
7Oooool2o`0000Gooooo3ol0001Eooooo`007?ooool00ol0003oooooooooo`1Vooooo`;o00000ooo
oolMo`0000Kooooo0_l00004ooooo`;o00000_ooool2o`0000Kooooo1ol00002oooooa3o00001_oo
ool2o`00013ooooo0_l0000Booooo`oo0000EOooool001cooooo00?o0000ooooooooool0A_ooool2
o`0001kooooo0_l00004oooooaKo000000?oooooo`000?l000001?l00005ooooo`;o000000Cooooo
o`000?l0003ooooo0_l00009oooooa_o00002Oooool2o`0000cooooo0_l0000?ooooo`Wo000000?o
ooooo`000?l000001_l0001Eooooo`007?ooool00ol0003oooooooooo`0looooo`;o00000_ooool2
o`0000Cooooo0_l000000ooooooo0000o`000007ooooo`;o00004_ooool2o`000004ooooool0003o
0000oooooago00000oooool4o`000003ooooool0003o000000cooooo0_l000000ooooooo0000o`00
000Ho`0000?ooooo0_l00002ooooo`;o00004_ooool2o`0000Wooooo4_l0001Eooooo`007?ooool0
0ol0003oooooooooo`0looooo`;o00000_ooool2o`0000Oooooo0_l00007ooooo`So00003ooooolO
o`000003ooooool0003o000000Go00004?oooolLo`0000?ooooo0_l00007ooooo`;o00003Oooool2
o`0000gooooo1_l000000ooooooo0000o`000005o`0005Gooooo000Looooo`03o`000?oooooooooo
043ooooo0ol00003ooooo`Co00002_ooool6o`00013ooooo1?l000000ooooooo0000o`00000Lo`00
0003ooooool0003o000000oooooo7_l0000;ooooo`;o00006Oooool2o`000003ooooool0003o0000
00co0000EOooool001cooooo00?o0000ooooooooool0@Oooool2o`0000?ooooo1?l00006ooooo`Co
00005?ooool2o`000003ooooool0003o000001go00005OoooolNo`0002Kooooo0_l00003ooooo`[o
00005_ooool2o`0003oooooo000Looooo`03o`000?oooooooooo03Gooooo0_l0000>ooooo`Co0000
1oooool4o`0000cooooo0_l00006ooooo`;o000000?oooooo`000?l000006_l0000Gooooo`Wo0000
00?oooooo`000?l000004Ol0000Yooooo`;o00000oooool<o`0001?ooooo0_l0000oooooo`007?oo
ool00ol0003oooooooooo`0eooooo`;o00003_ooool2o`0001?ooooo0_l00004ooooo`;o00001?oo
ool2o`0000?ooooo3Ol000000ooooooo0000o`00000<o`0000[ooooo0ol00008ooooo`_o000000?o
ooooo`000?l000004Ol00003ooooo`;o00003_ooool2o`0001Cooooo0_l00004ooooo`?o00000_oo
ool7o`00017ooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`1Gooooo`Go00002_ooool3
o`000003ooooool0003o000001_o00002_ooool3o`0000Sooooo0_l00002ooooo`_o000000?ooooo
o`000?l000003?l00004ooooo`?o00003Oooool2o`0001_ooooo0_l000001Ooooooo0000o`000?l0
003ooooo00Co00004Oooool2o`00043ooooo000Looooo`03o`000?oooooooooo04Gooooo0_l0000@
ooooo`Go00000oooool2o`0000Kooooo0_l000000ooooooo0000o`00000Io`0000oooooo0_l00006
ooooo`;o00000_oooolJo`0000?ooooo1?l000000ooooooo0000o`00000Cooooo`;o00005Oooool2
o`0000;ooooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00004Oooool4o`00
00?ooooo0_l0000:ooooo`?o000000?oooooo`000?l000005Ol00008ooooo`;o00001?ooool2o`00
00Kooooo0_l00002oooooa[o000000?oooooo`000?l000000ol00002ooooo`;o00004_ooool3o`00
01Cooooo0_l00002ooooo`;o00006Oooool2o`0003_ooooo000Looooo`;o0000F?ooool5o`0000_o
oooo0_l000000ooooooo0000o`00000Jo`0000;ooooo0_l00004ooooo`;o00002_ooool2o`0000;o
oooo7?l000001?oooooo0000o`000?ooool2o`0001Kooooo1?l00002ooooo`;o00003oooool2o`00
00;ooooo0_l0000Iooooo`;o0000>oooool001cooooo00?o0000ooooooooool0Eoooool5o`0000_o
oooo7ol000001?oooooo0000o`000?l00002ooooo`;o00003?ooool3o`000003ooooool0003o0000
01co00007?ooool3o`000003ooooool0003o000006_ooooo000Looooo`03o`000?oooooooooo05go
oooo0ol00009oooooa?o000000?oooooo`000?l000002_l00003ooooo`;o00003Oooool2o`000004
ooooool0003o0000o`0000;ooooo5?l00003ooooo`;o000000?oooooo`000?l000004oooool2o`00
00Gooooo0_l000000ooooooo0000o`000006ooooo`;o00007Oooool2o`0004Cooooo000Looooo`03
o`000?oooooooooo04Cooooo0_l0000Gooooo`?o00002?oooolDo`0000;ooooo2ol0000:ooooo`;o
00003OoooolHo`0000?ooooo0_l00009ooooo`Co00001_ooool2o`000003ooooool0003o000000Go
oooo0_l00006ooooo`;o00000oooool2o`0001Sooooo0_l00014ooooo`007?ooool00ol0003ooooo
ooooo`14ooooo`;o00005_ooool2o`0000[ooooo0_l000000ooooooo0000o`00000@o`000003oooo
ool0003o000000?o00001?ooool3o`0000Oooooo1?l00006ooooo`;o00000oooool6o`000003oooo
ool0003o000001;o00003Oooool4o`0000Wooooo0_l00006ooooo`;o00001?ooool2o`0000Cooooo
0_l0001Nooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00002oooool2o`0000Sooooo0_l0
000:ooooo`Go000000?oooooo`000?l000004_l00006ooooo`;o00001oooool3o`0000Oooooo0_l0
0003ooooo`;o000000Goooooo`000?l0003o0000ooooo`0=o`0000Gooooo0_l0000Gooooo`;o0000
1_ooool2o`000003ooooool0003o000000Cooooo0_l0000;ooooo`;o00003oooool2o`0004Kooooo
000Looooo`03o`000?oooooooooo04Gooooo0_l0000;ooooo`;o00000oooool2o`0000;ooooo0_l0
0003ooooo`;o00001Oooool4o`0000;ooooo4_l000000ooooooo0000o`000004ooooo`;o00000ooo
ool2o`0000[ooooo0_l00007ooooo`Go000000?oooooo`000?l000001?l000000ooooooo0000o`00
0005o`0000Gooooo0_l0000Gooooo`;o000000?oooooo`000?l000000oooool2o`0001Cooooo0_l0
000?ooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0Coooool2o`0000Kooooo0_l00002
ooooo`;o00000oooool2o`0000Gooooo1?l00002ooooo`?o000000?oooooo`000?l000002Ol00000
0ooooooo0000o`000003o`0000Cooooo0_l00003ooooo`;o00002_ooool2o`000003ooooool0003o
000000Gooooo1?l000000ooooooo0000o`000009o`0000oooooo0_l000000ooooooo0000o`000009
ooooo`;o000000Coooooo`000?l0003ooooo0ol0001booooo`007?ooool00ol0003oooooooooo`0o
ooooo`;o00003_ooool2o`0000_ooooo0_l0000:ooooo`?o00000_ooool3o`0000?ooooo2_l00002
ooooo`Co00000oooool2o`0000?ooooo0_l0000=ooooo`;o00001oooool2o`0000Kooooo1Ol0000@
ooooo`;o000000?oooooo`000?l000002Oooool2o`000004ooooool0003o0000ooooo`;o00005ooo
ool3o`0000;ooooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00002_ooool2
o`0000;ooooo0_l00005ooooo`;o00001?ooool4o`000003ooooool0003o000000Gooooo0_l00003
ooooo`?o00000oooool:o`0000Cooooo0_l00003ooooo`;o00002_ooool2o`0000?ooooo0_l0000B
ooooo`Go00005oooool2o`000003ooooool0003o000000Sooooo0_l0000Gooooo`?o00000_ooool2
o`0005Gooooo000Looooo`03o`000?oooooooooo04_ooooo0_l00009ooooo`;o00001_ooool2o`00
0003ooooool0003o000000Gooooo1Ol000000ooooooo0000o`000006o`000003ooooool0003o0000
00;o00005oooool2o`0000?ooooo0_l0000Dooooo`;o00000oooool2o`0001?ooooo0_l000000ooo
oooo0000o`000008ooooo`;o00004oooool2o`0005kooooo000Looooo`03o`000?oooooooooo05Oo
oooo0ol0000@ooooo`?o00000_ooool6o`0000;ooooo0_l00005ooooo`;o0000;_ooool2o`0000;o
oooo0_l0000Fooooo`;o000000?oooooo`000?l000000_l0000Eooooo`;o000000?oooooo`000?l0
00001?ooool2o`0000oooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`1Gooooo`?o0000
0oooool4o`0000Oooooo0_l00005ooooo`;o00002Oooool2o`000004ooooool0003o0000o`0000_o
oooo0_l0000Cooooo`;o00003?ooool2o`0001gooooo1?l0000Eooooo`;o00000oooool2o`0000;o
oooo1?l0000=ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0Coooool2o`0000Oooooo
0_l00003ooooo`Co00001oooool2o`0000[ooooo1?l00002ooooo`;o000000Coooooo`000?l0003o
00002oooool2o`0001?ooooo0_l0000Hooooo`;o00005?ooool2o`0001Wooooo0_l00004ooooo`;o
0000E_ooool001cooooo00?o0000ooooooooool0Coooool2o`000004ooooool0003o0000ooooo`Go
00002_ooool5o`0000Gooooo0_l00004ooooo`Go00002_ooool3o`0000Gooooo0_l0000Rooooo`;o
00002Oooool3o`0001?ooooo0_l0000:ooooo`;o00002oooool3o`000003ooooool0003o000000go
oooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`1Aooooo`?o000000?oooooo`000?l00000
1Ol00005ooooo`;o000000?oooooo`000?l000000ol00005ooooo`;o00000oooool6o`0000[ooooo
0ol0000Yooooo`;o000000?oooooo`000?l000001oooool2o`0001Kooooo0_l00007ooooo`;o0000
2oooool3o`000003ooooool0003o000000gooooo0_l0001;ooooo`007?ooool2o`0005;ooooo0_l0
0007ooooo`;o00001Oooool2o`0000Cooooo0ol00009ooooo`;o00003oooool2o`0000?ooooo0ol0
0007ooooo`;o00000oooool2o`0001Sooooo0_l00002ooooo`;o00006oooool2o`0000Sooooo0_l0
000Looooo`?o0000Boooool001cooooo00?o0000ooooooooool0Doooool2o`0000Gooooo0_l00008
ooooo`;o00000_ooool2o`0001[ooooo0_l00003ooooo`?o00001oooool4o`000003ooooool0003o
000000Sooooo0_l0000<ooooo`;o00001?ooool2o`0000Kooooo0_l0000Jooooo`;o000000?ooooo
o`000?l000003?ooool2o`0000kooooo0ol0001;ooooo`007?ooool00ol0003oooooooooo`1?oooo
o`;o00000_ooool2o`0000oooooo0_l0000Looooo`?o00003_ooool4o`000003ooooool0003o0000
00Sooooo0_l00007ooooo`;o00000oooool2o`0000Gooooo0_l00005ooooo`;o00006Oooool3o`00
0003ooooool0003o000000cooooo0_l00009ooooo`;o0000DOooool001cooooo00?o0000oooooooo
ool0Coooool2o`0000Wooooo0_l00004ooooo`;o00000_ooool2o`0000Kooooo0_l000000ooooooo
0000o`000007ooooo`;o00001oooool4o`0000kooooo0_l0000Fooooo`;o00001oooool2o`000003
ooooool0003o0000017ooooo0_l0000=ooooo`;o00001_ooool2o`0000Wooooo0_l00008ooooo`;o
0000DOooool001cooooo00?o0000ooooooooool0F_ooool2o`0000Cooooo0_l00002ooooo`?o0000
1Oooool2o`000003ooooool0003o000000Oooooo0_l00003ooooo`;o000000Goooooo`000?l0003o
0000ooooo`02o`00023ooooo0_l0000<ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`Go
00004_ooool2o`0000Oooooo1?l0001Kooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o0000
4?ooool3o`0000Cooooo0_l0000;ooooo`;o00002Oooool2o`000003ooooool0003o000000;ooooo
0_l0000;ooooo`;o00002?ooool2o`0000Cooooo0_l00003ooooo`Co00001_ooool2o`0000;ooooo
0_l00005ooooo`;o00001Oooool2o`0000Sooooo0ol00007ooooo`Co00004?ooool2o`0005gooooo
000Looooo`03o`000?oooooooooo04cooooo0_l00005ooooo`;o00002Oooool3o`0000Cooooo0_l0
000;ooooo`;o00004oooool2o`0000Sooooo0_l00007ooooo`?o00000_ooool6o`0000?ooooo0_l0
0006ooooo`;o00000_ooool2o`00023ooooo1ol0001/ooooo`007?ooool00ol0003oooooooooo`1C
ooooo`;o00004_ooool2o`000003ooooool0003o000000Wooooo0_l0000@ooooo`;o00003Oooool2
o`0000;ooooo0_l00003ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`000003ooooool0
003o000000_ooooo0_l00009ooooo`;o00003Oooool5o`0000;ooooo0ol00009ooooo`;o0000HOoo
ool001cooooo00?o0000ooooooooool0G_ooool2o`0000Oooooo0_l000001?oooooo0000o`000?oo
ool2o`0000Kooooo0_l0000<ooooo`;o00003oooool4o`0000?ooooo0_l00007ooooo`;o00000ooo
ool2o`000004ooooool0003o0000ooooo`;o00002?ooool2o`0000Sooooo0ol0000=ooooo`Go0000
00Coooooo`000?l0003ooooo0ol00007ooooo`;o0000HOooool001cooooo00?o0000ooooooooool0
G_ooool2o`0000;ooooo0_l00009ooooo`;o000000?oooooo`000?l000002?ooool2o`0000Gooooo
1?l0000>ooooo`?o00001Oooool4o`0000Gooooo0_l00009ooooo`;o00001?ooool2o`0000cooooo
0_l000000ooooooo0000o`000002o`0000oooooo1_l0000Cooooo`;o0000EOooool001cooooo00?o
0000ooooooooool0H_ooool2o`0000Cooooo1?l000001?oooooo0000o`000?ooool2o`0000Cooooo
0_l00002ooooo`;o00001Oooool4o`0000kooooo0ol00007ooooo`;o00005_ooool2o`000004oooo
ool0003o0000ooooo`?o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000;o
00003?ooool2o`000003ooooool0003o000000;o00005Oooool2o`0005Gooooo000Looooo`03o`00
0?oooooooooo04kooooo0_l00005ooooo`;o00001?ooool3o`000003ooooool0003o000000;ooooo
0_l00003ooooo`Co000000?oooooo`000?l000001oooool2o`0000_ooooo0_l0000=ooooo`;o0000
0oooool3o`0000Sooooo0_l0000?ooooo`;o00000oooool2o`000005ooooool0003o0000o`000?oo
ool00_l000001?oooooo0000o`000?l0000Aooooo`;o000000?oooooo`000?l00000K_ooool001co
oooo00?o0000ooooooooool0C_ooool2o`0000Gooooo0ol00003ooooo`?o000000?oooooo`000?l0
00000_ooool4o`0000Kooooo0_l0000Sooooo`?o00000_ooool5o`0000Kooooo0_l0000=ooooo`Co
00000oooool2o`0000Sooooo0_l0000Eooooo`;o0000K_ooool001cooooo00?o0000ooooooooool0
E_ooool2o`0000gooooo0_l00006ooooo`;o00001oooool2o`0000Kooooo0_l0000Cooooo`;o0000
1?ooool6o`0000?ooooo0_l0000=ooooo`;o00005_ooool2o`0000Cooooo0_l0000>ooooo`Co0000
1?ooool2o`00063ooooo000Looooo`03o`000?oooooooooo05oooooo0_l0000:ooooo`Ko00001?oo
ool4o`0000Gooooo1?l00003ooooo`Co00001_ooool2o`0000?ooooo0ol00002ooooo`Ko000000?o
ooooo`000?l000001Ol00002ooooo`Co00006_ooool6o`0000;ooooo0_l0000<ooooo`Oo00000ooo
ool2o`00063ooooo000Looooo`03o`000?oooooooooo05oooooo0_l00005ooooo`;o00000oooool6
o`0000Cooooo1?l00003ooooo`Ko00000oooool4o`0000Kooooo0_l00003ooooo`Co00002?ooool2
o`0000;ooooo1?l000000ooooooo0000o`000002o`0000kooooo0_l00002ooooo`;o00001_ooool6
o`0000Cooooo0ol00003ooooo`;o00001?ooool2o`0000?ooooo0_l0001Uooooo`007?ooool2o`00
06Oooooo0_l00004ooooo`Co00002_ooool6o`0000Cooooo1?l000000ooooooo0000o`000002oooo
o`;o000000?oooooo`000?l000001?ooool2o`0000Cooooo0_l00008ooooo`;o00004Oooool4o`00
00;ooooo0_l00006ooooo`Co00001_ooool3o`0000?ooooo0_l00004ooooo`;o0000J_ooool001co
oooo00?o0000ooooooooool0I_ooool2o`0000kooooo0_l00002ooooo`;o00002?ooool4o`000005
ooooool0003o0000o`000?ooool00_l000000ooooooo0000o`00000:ooooo`;o00002Oooool2o`00
00oooooo1?l0000;ooooo`;o00005?ooool2o`0006[ooooo000Looooo`03o`000?oooooooooo06;o
oooo0_l0000Booooo`;o00004Oooool4o`0000oooooo0_l00009ooooo`;o000000?oooooo`000?l0
00000_l0000:ooooo`?o00001Oooool2o`000003ooooool0003o000000[ooooo0_l0000:ooooo`Co
0000J_ooool001cooooo00?o0000ooooooooool0GOooool2o`000003ooooool0003o000000;o0000
2_ooool3o`0000Wooooo0_l0000?ooooo`;o00001oooool2o`0000Kooooo0_l0000<ooooo`Co0000
00Coooooo`000?l0003ooooo0_l00003ooooo`;o00001Oooool4o`000004ooooool0003o0000oooo
o`;o00001oooool3o`0000Kooooo1Ol00002ooooo`;o00001_ooool2o`00063ooooo000Looooo`03
o`000?oooooooooo05gooooo0_l000000ooooooo0000o`00000<ooooo`?o00002Oooool2o`0001So
oooo0_l0000Gooooo`Co000000?oooooo`000?l000000_l000000ooooooo0000o`000005ooooo`Ko
00000_ooool2o`0000Sooooo0_l00006ooooo`Co00000oooool2o`0000Kooooo0_l0001Pooooo`00
7?ooool00ol0003oooooooooo`1Jooooo`;o00001_ooool2o`0001Gooooo0_l000000ooooooo0000
o`00000?ooooo`;o000000Coooooo`000?l0003o00001Oooool2o`0000Oooooo0_l0000:ooooo`;o
00000oooool4o`000003ooooool0003o000000Kooooo1Ol0000Kooooo`;o0000J?ooool001cooooo
00?o0000ooooooooool0F_ooool2o`0000Kooooo0_l0000?ooooo`;o00001?ooool2o`000003oooo
ool0003o000000Kooooo0ol00006ooooo`;o000000?oooooo`000?l000000_l00002ooooo`Co0000
0_ooool2o`0000;ooooo2ol00007ooooo`;o00000oooool2o`0000;ooooo0ol0000Hooooo`;o0000
LOooool001cooooo00?o0000ooooooooool0Loooool2o`0000oooooo0ol0000;ooooo`;o00000_oo
ool2o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l000001_l0000>ooooo`Go00006?oo
ool2o`00077ooooo000Looooo`03o`000?oooooooooo06;ooooo0_l0000Dooooo`;o00002oooool2
o`0001Cooooo0_l00009ooooo`Wo00001oooool2o`000003ooooool0003o000008kooooo000Loooo
o`03o`000?oooooooooo06;ooooo0_l0000Dooooo`;o00008Oooool2o`0000;ooooo0_l00007oooo
o`Oo00001oooool2o`0000[ooooo0_l0000Fooooo`;o0000KOooool001cooooo00?o0000oooooooo
ool0Poooool3o`0000oooooo0_l00005ooooo`;o000000?oooooo`000?l000000_l00005ooooo`;o
00002Oooool2o`0000gooooo0_l00002ooooo`;o00002Oooool2o`0000Kooooo0ol0001]ooooo`00
7?ooool00ol0003oooooooooo`21ooooo`Go00000_ooool2o`0000;ooooo0_l00004ooooo`;o0000
00Coooooo`000?l0003ooooo0_l00002ooooo`Oo00004?ooool2o`0000Wooooo0_l00006ooooo`;o
00001_ooool5o`0000Kooooo0_l0001^ooooo`007?ooool00ol0003oooooooooo`21ooooo`;o0000
0_ooool5o`0000;ooooo1?l00002ooooo`;o00001?ooool2o`000003ooooool0003o000000Co0000
2Oooool2o`0000gooooo0_l00003ooooo`;o00003_ooool3o`0007Sooooo000Looooo`03o`000?oo
oooooooo07gooooo1?l00004ooooo`?o00001?ooool4o`0000[ooooo0ol00002ooooo`?o00002?oo
ool2o`0000gooooo1?l000000ooooooo0000o`00000?ooooo`;o00003Oooool2o`0006Wooooo0000
1_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<
c<`01_ooool00ol0003oooooooooo`1Looooo`;o00007oooool4o`0000?ooooo0_l00005ooooo`;o
00000_ooool2o`0000Oooooo1_l00002ooooo`;o00000_ooool5o`0000Kooooo0_l00009ooooo`Co
00000_ooool2o`0001cooooo0_l0001Yooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5oooo
o`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0G?ooool2
o`0002Kooooo1Ol00002ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`Oo00000_ooool2
o`000003ooooool0003o000000?o00001_ooool2o`0000Kooooo0_l00003ooooo`;o00000_ooool2
o`0000_ooooo0_l0001jooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`1Looooo`;o00002?ooool2
o`0001cooooo1_l000000ooooooo0000o`000007ooooo`;o00001oooool2o`000005ooooool0003o
0000o`000?ooool01Ol00008ooooo`;o00001?ooool4o`0000Kooooo0_l000000ooooooo0000o`00
0007ooooo`;o0000N_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool0
1Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0001Vooooo`;o00007?ooool6o`0000Wooooo0_l0
000;ooooo`;o00000_ooool3o`0000Gooooo0_l00003ooooo`;o00001_ooool4o`0000Cooooo1ol0
0008ooooo`;o00001?ooool2o`00077ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo00Wooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo05kooooo0_l0
000Uooooo`?o00002oooool2o`0000;ooooo1?l00005ooooo`;o000000?oooooo`000?l000000_oo
ool2o`0000?ooooo0_l0000=ooooo`;o00001Oooool2o`0000;ooooo0_l00007ooooo`?o00001?oo
ool2o`00077ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go410@
okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo05kooooo0_l0000=ooooo`;o0000:?oo
ool4o`0000Sooooo0_l00002ooooo`;o00002?ooool2o`0000Sooooo0_l00002ooooo`;o00000_oo
ool2o`0000[ooooo0ol0000?ooooo`;o0000I_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0KOooool2o`0003Co
oooo0_l000000ooooooo0000o`000007ooooo`Co00000_ooool2o`0000Sooooo0_l00002ooooo`Co
00002Oooool2o`0000Gooooo0_l00008ooooo`;o0000I_ooool00006ooooooo^k^ko<S8bo`000?lb
<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0Toooool2
o`0000kooooo0_l000000ooooooo0000o`000007ooooo`Co000000?oooooo`000?l000000ol0000<
ooooo`;o00002?ooool2o`0000Kooooo0_l0001`ooooo`007?ooool00ol0003oooooooooo`1boooo
o`;o00005Oooool2o`0000Sooooo0ol0000@ooooo`;o00002?ooool6o`000003ooooool0003o0000
00;o00002_ooool2o`0000Cooooo0_l00002ooooo`;o0000N?ooool001cooooo00?o0000oooooooo
ool0L_ooool3o`0001Cooooo0_l00009ooooo`;o00000_ooool4o`0000[ooooo0_l00008ooooo`;o
000000Coooooo`000?l0003o00000oooool2o`0000Gooooo0_l00003ooooo`;o00001?ooool2o`00
07cooooo000Looooo`03o`000?oooooooooo07?ooooo0_l0000Fooooo`;o00002oooool4o`0000_o
oooo0_l0000;ooooo`;o00002_ooool2o`0008Oooooo000Looooo`03o`000?oooooooooo07?ooooo
0_l0000Fooooo`;o00006?ooool4o`0000Wooooo0_l0000Iooooo`;o0000N_ooool001cooooo00?o
0000ooooooooool0Loooool2o`00033ooooo0_l0000;ooooo`;o000000Coooooo`000?l0003o0000
2_ooool2o`0000Wooooo0_l0001jooooo`007?ooool00ol0003oooooooooo`2eooooo`?o00002?oo
ool4o`0008Gooooo000Looooo`03o`000?oooooooooo09Oooooo0_l00008ooooo`;o00000oooool2
o`0000Oooooo0_l0000?ooooo`;o0000Qoooool001cooooo00?o0000ooooooooool0Uoooool2o`00
00Sooooo0_l00003ooooo`;o00001oooool2o`000003ooooool0003o000009Gooooo000Looooo`03
o`000?oooooooooo0;;ooooo0_l0002Eooooo`007?ooool00ol0003oooooooooo`1oooooo`;o0000
9_ooool2o`000:3ooooo000Looooo`03o`000?oooooooooo07oooooo0_l0000Qooooo`;o00000ooo
ool2o`0000oooooo0_l0002?ooooo`007?ooool2o`0008Cooooo0_l0000;ooooo`;o00004?ooool2
o`0001Cooooo0_l00008ooooo`;o0000QOooool001cooooo00?o0000ooooooooool0Poooool2o`00
00;ooooo0_l00007ooooo`;o00000_ooool2o`0002cooooo0_l00025ooooo`007?ooool00ol0003o
ooooooooo`27ooooo`;o00002oooool2o`000;?ooooo000Looooo`03o`000?oooooooooo09cooooo
0_l00002ooooo`;o00004Oooool3o`0000?ooooo0_l0002>ooooo`007?ooool00ol0003ooooooooo
o`2Looooo`;o00000_ooool2o`00017ooooo0ol00003ooooo`Ko0000R_ooool001cooooo00?o0000
ooooooooool0TOooool2o`0002Sooooo1?l0002:ooooo`007?ooool00ol0003oooooooooo`2Aoooo
o`;o0000]_ooool001cooooo00?o0000ooooooooool0[?ooool2o`0009_ooooo000Looooo`03o`00
0?oooooooooo0:cooooo0_l0002Kooooo`007?ooool00ol0003oooooooooo`1oooooo`;o0000b?oo
ool001cooooo00?o0000ooooooooool0Ooooool2o`000<Sooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0S_ooool2o`000;Wooooo000Looooo`03o`00
0?oooooooooo08kooooo0_l0002iooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0U?ooool2o`000;?ooooo
000Looooo`03o`000?oooooooooo09Cooooo0_l0002cooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0WOooool2o`000:[ooooo000Looooo`03o`000?oooooooooo09gooooo0_l0002Zooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001;ooooo1?l000000ol@413oooooooooo`03oooo
o`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo0ol0003ooooood[ooooo
000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomB
ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?oo
ooooD_ooool001;ooooo00?oEEEEofIVI_l00000oooooomDooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00YOooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo
01Gooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c004ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<093ooooo002Vooooo`05o`000?ooooooooooooooool00000
2Oooool6o`0000Wooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@07ooooo`09ogMgMolb<S;ooooooooo
oolQ8B7oV9RHoooooonHV9So8B4Q093ooooo002Vooooo`05o`000?ooooooooooooooool000006?oo
ool01Ol0003ooooooooooooooooo000000Sooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`2>ooooo`00Y_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l00009ooooo`05
oc8b<_nHV9SooooooiRHV?lb<S801oooool02OmgMgOo<S8boooooooooooo<S8boiRHV?ooooooV9RH
oc8b<P2@ooooo`00Y_ooool01Ol0003oQhN7oooooonYZJWo000001Sooooo00Goc<c<o`000?l0003o
0000olc<c004ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Oo<c<co0000o`000?l0003o
c<c<093ooooo002Uooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool05_ooool01Ol@
413o^[Zjoooooonj^[[o410@00Cooooo00?o0000ooooooooool01?ooool01Ol@413o^[Zjoooooonj
^[[o410@093ooooo0033ooooo`05o`000?nj^[[ooooookZj^_l000001?ooool00ol0003ooooooooo
o`04ooooo`05o`000?nj^[[ooooookZj^_l00000T?ooool00<?ooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@04ooooo`Co00000oooool01OnYZJWo410@o`000?l@413oZJVY093ooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(864) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.33211 .60853 Mdot
.36148 .59601 Mdot
.69772 .52388 Mdot
.44748 .42939 Mdot
.40508 .52686 Mdot
.67484 .52178 Mdot
.4969 .63813 Mdot
.51064 .67161 Mdot
.66061 .50874 Mdot
.37325 .30837 Mdot
.53625 .65698 Mdot
.38732 .33799 Mdot
.5155 .6333 Mdot
.43072 .40905 Mdot
.79496 .3353 Mdot
.46725 .39175 Mdot
.39447 .61782 Mdot
.65075 .421 Mdot
.35312 .39436 Mdot
.66463 .56246 Mdot
.30262 .62189 Mdot
.43226 .40328 Mdot
.32949 .61853 Mdot
.42987 .40858 Mdot
.43026 .44723 Mdot
.3551 .62167 Mdot
.40211 .6224 Mdot
.40394 .45526 Mdot
.40942 .43432 Mdot
.54626 .66066 Mdot
.5751 .37974 Mdot
.67848 .22966 Mdot
.44179 .35194 Mdot
.17942 .5592 Mdot
.50198 .66657 Mdot
.41817 .22325 Mdot
.63834 .52229 Mdot
.5366 .63021 Mdot
.5123 .67102 Mdot
.47901 .64757 Mdot
.53448 .63263 Mdot
.36249 .61814 Mdot
.49527 .67712 Mdot
.51106 .69337 Mdot
.45715 .40154 Mdot
.46723 .74107 Mdot
.54637 .23374 Mdot
.38402 .41545 Mdot
.36631 .58235 Mdot
.65062 .55914 Mdot
.24961 .66058 Mdot
.50063 .6734 Mdot
.728 .66384 Mdot
.57331 .09945 Mdot
.51692 .62392 Mdot
.45831 .41685 Mdot
.65332 .5273 Mdot
.41458 .38552 Mdot
.42239 .40291 Mdot
.26623 .60269 Mdot
.39835 .44722 Mdot
.64169 .38267 Mdot
.31036 .61693 Mdot
.6392 .48614 Mdot
.66876 .51725 Mdot
.53057 .66967 Mdot
.39157 .61306 Mdot
.51015 .63868 Mdot
.39714 .46795 Mdot
.63194 .52468 Mdot
.38363 .41413 Mdot
.5424 .65258 Mdot
.33245 .58763 Mdot
.38467 .37913 Mdot
.49887 .77868 Mdot
.82797 .42355 Mdot
.67385 .4142 Mdot
.27286 .56932 Mdot
.35428 .53049 Mdot
.81181 .52449 Mdot
.41712 .4221 Mdot
.74594 .73108 Mdot
.8041 .35499 Mdot
.33391 .61042 Mdot
.34564 .447 Mdot
.70279 .57464 Mdot
.40475 .36492 Mdot
.51917 .48934 Mdot
.43746 .46786 Mdot
.43387 .78927 Mdot
.65553 .5087 Mdot
.37999 .61021 Mdot
.44671 .42787 Mdot
.37163 .41785 Mdot
.25348 .48551 Mdot
.36261 .42738 Mdot
.4276 .45807 Mdot
.39066 .57388 Mdot
.52106 .66493 Mdot
.44774 .34521 Mdot
.56356 .67237 Mdot
.70325 .64391 Mdot
.44256 .38607 Mdot
.64387 .50024 Mdot
.37589 .56824 Mdot
.42495 .36405 Mdot
.48819 .63377 Mdot
.3957 .42959 Mdot
.4933 .68009 Mdot
.36414 .59093 Mdot
.36985 .4117 Mdot
.63865 .41528 Mdot
.55113 .80712 Mdot
.38166 .61749 Mdot
.70068 .71702 Mdot
.38813 .43243 Mdot
.43063 .3939 Mdot
.36249 .59869 Mdot
.67987 .54395 Mdot
.54999 .4431 Mdot
.3809 .58103 Mdot
.48415 .65186 Mdot
.37477 .6484 Mdot
.38563 .48276 Mdot
.67001 .50391 Mdot
.70916 .63879 Mdot
.72588 .64072 Mdot
.51286 .32959 Mdot
.41481 .36381 Mdot
.40051 .68514 Mdot
.67977 .52928 Mdot
.37501 .60897 Mdot
.51393 .63982 Mdot
.46545 .41895 Mdot
.36714 .64096 Mdot
.528 .65203 Mdot
.62775 .39366 Mdot
.70321 .36629 Mdot
.37048 .57809 Mdot
.53164 .58273 Mdot
.47245 .62519 Mdot
.47898 .64342 Mdot
.19957 .5995 Mdot
.35676 .59697 Mdot
.66548 .39518 Mdot
.52029 .65093 Mdot
.60466 .29861 Mdot
.45628 .43912 Mdot
.4778 .32145 Mdot
.61092 .83237 Mdot
.24391 .66209 Mdot
.61157 .73033 Mdot
.67203 .40052 Mdot
.47961 .6335 Mdot
.42294 .43913 Mdot
.34975 .60375 Mdot
.35434 .61069 Mdot
.40664 .46347 Mdot
.43278 .45066 Mdot
.37885 .40309 Mdot
.37524 .42509 Mdot
.5998 .24685 Mdot
.37529 .41051 Mdot
.63975 .45731 Mdot
.37502 .62772 Mdot
.41571 .44928 Mdot
.68128 .54978 Mdot
.44163 .36109 Mdot
.5408 .64113 Mdot
.42365 .39483 Mdot
.44557 .44026 Mdot
.36687 .38469 Mdot
.51846 .62051 Mdot
.63498 .21813 Mdot
.59277 .83081 Mdot
.45415 .18174 Mdot
.65185 .72845 Mdot
.66176 .53971 Mdot
.42429 .37249 Mdot
.65585 .38921 Mdot
.3052 .3635 Mdot
.41548 .41222 Mdot
.28418 .74091 Mdot
.44134 .44881 Mdot
.19303 .4597 Mdot
.45904 .48849 Mdot
.45427 .1752 Mdot
.58649 .45745 Mdot
.40453 .43769 Mdot
.25224 .43948 Mdot
.27196 .32953 Mdot
.4429 .58873 Mdot
.52954 .6299 Mdot
.68433 .5456 Mdot
.64656 .52115 Mdot
.46986 .64808 Mdot
.47515 .38292 Mdot
.48564 .36942 Mdot
.39377 .32421 Mdot
.71562 .64345 Mdot
.32834 .59126 Mdot
.65329 .36466 Mdot
.35073 .57818 Mdot
.80465 .66793 Mdot
.39705 .77185 Mdot
.46075 .63649 Mdot
.6836 .37492 Mdot
.69613 .52713 Mdot
.7187 .64395 Mdot
.65855 .39548 Mdot
.39456 .40653 Mdot
.37289 .58661 Mdot
.20029 .41225 Mdot
.4388 .49826 Mdot
.2012 .37465 Mdot
.35481 .64794 Mdot
.55317 .4723 Mdot
.53008 .64439 Mdot
.68143 .56397 Mdot
.44147 .40206 Mdot
.387 .39094 Mdot
.31905 .58888 Mdot
.38603 .41491 Mdot
.38846 .53703 Mdot
.45051 .43613 Mdot
.67032 .57634 Mdot
.66308 .42715 Mdot
.47313 .65343 Mdot
.51036 .33343 Mdot
.3243 .61234 Mdot
.62105 .57204 Mdot
.64747 .55275 Mdot
.31477 .3348 Mdot
.54055 .65575 Mdot
.63531 .41135 Mdot
.658 .55505 Mdot
.66877 .36546 Mdot
.40635 .35697 Mdot
.63683 .5231 Mdot
.67031 .37951 Mdot
.63011 .24306 Mdot
.46033 .40168 Mdot
.62232 .27159 Mdot
.49835 .64358 Mdot
.36869 .65119 Mdot
.40086 .44879 Mdot
.72262 .63362 Mdot
.39341 .35152 Mdot
.59135 .70138 Mdot
.73195 .65997 Mdot
.71551 .66443 Mdot
.81408 .48001 Mdot
.65 .41551 Mdot
.56731 .76007 Mdot
.35526 .69701 Mdot
.39279 .61074 Mdot
.45354 .41932 Mdot
.52708 .16339 Mdot
.5208 .65043 Mdot
.39807 .40737 Mdot
.69266 .57723 Mdot
.51646 .64989 Mdot
.41202 .3802 Mdot
.49912 .62169 Mdot
.3529 .60565 Mdot
.74928 .56414 Mdot
.39098 .63107 Mdot
.4616 .40989 Mdot
.49084 .63459 Mdot
.64991 .54563 Mdot
.35093 .62228 Mdot
.39733 .42622 Mdot
.43714 .39388 Mdot
.71361 .65004 Mdot
.40875 .44436 Mdot
.53782 .17131 Mdot
.38778 .44081 Mdot
.67714 .49586 Mdot
.3689 .4367 Mdot
.25047 .71107 Mdot
.70652 .42212 Mdot
.38971 .60661 Mdot
.72028 .66379 Mdot
.65962 .51418 Mdot
.7778 .49049 Mdot
.48258 .57489 Mdot
.40686 .4271 Mdot
.712 .65833 Mdot
.57095 .43149 Mdot
.54671 .66584 Mdot
.35961 .42891 Mdot
.43655 .77236 Mdot
.66936 .55889 Mdot
.71739 .64588 Mdot
.3463 .39886 Mdot
.37551 .56767 Mdot
.44694 .4312 Mdot
.64152 .54055 Mdot
.37726 .64769 Mdot
.44193 .3697 Mdot
.48619 .23698 Mdot
.73075 .65134 Mdot
.49941 .64233 Mdot
.48891 .44009 Mdot
.37795 .40987 Mdot
.64641 .53058 Mdot
.33009 .63031 Mdot
.49714 .66174 Mdot
.36343 .62475 Mdot
.23455 .36333 Mdot
.64341 .73995 Mdot
.56513 .22559 Mdot
.6841 .37241 Mdot
.62047 .66284 Mdot
.42885 .18458 Mdot
.582 .77146 Mdot
.55576 .31157 Mdot
.30079 .24712 Mdot
.67027 .55364 Mdot
.69311 .3908 Mdot
.65904 .52026 Mdot
.43312 .42891 Mdot
.67221 .51818 Mdot
.45388 .17054 Mdot
.44405 .44764 Mdot
.65707 .53709 Mdot
.75202 .50793 Mdot
.42129 .45435 Mdot
.3819 .62095 Mdot
.77745 .325 Mdot
.45356 .81496 Mdot
.31175 .71799 Mdot
.66899 .54492 Mdot
.29029 .59943 Mdot
.40828 .45578 Mdot
.43747 .35304 Mdot
.34551 .60836 Mdot
.36883 .44109 Mdot
.64902 .36641 Mdot
.66607 .36253 Mdot
.50226 .34261 Mdot
.6805 .76377 Mdot
.45105 .34463 Mdot
.34857 .61999 Mdot
.34039 .48638 Mdot
.49396 .77512 Mdot
.70322 .62992 Mdot
.55543 .62899 Mdot
.64884 .22971 Mdot
.47885 .37651 Mdot
.52237 .58375 Mdot
.45989 .77568 Mdot
.37726 .59652 Mdot
.58159 .20369 Mdot
.52103 .62703 Mdot
.28134 .42886 Mdot
.20037 .51794 Mdot
.38938 .39645 Mdot
.53485 .66288 Mdot
.42053 .33519 Mdot
.39783 .78729 Mdot
.63784 .30115 Mdot
.83305 .57555 Mdot
.45926 .40304 Mdot
.55204 .76207 Mdot
.42808 .39502 Mdot
.5331 .39267 Mdot
.38705 .44096 Mdot
.35819 .62854 Mdot
.34348 .33288 Mdot
.48417 .53474 Mdot
.65521 .79512 Mdot
.38124 .76673 Mdot
.67443 .39427 Mdot
.43598 .39538 Mdot
.38943 .39439 Mdot
.64657 .41061 Mdot
.34154 .63125 Mdot
.38392 .4356 Mdot
.47208 .27293 Mdot
.38174 .40197 Mdot
.54031 .63517 Mdot
.56626 .39808 Mdot
.36066 .54961 Mdot
.36588 .40105 Mdot
.39672 .6227 Mdot
.5105 .62111 Mdot
.52824 .67171 Mdot
.39931 .47608 Mdot
.48542 .62801 Mdot
.44936 .4307 Mdot
.61107 .34722 Mdot
.34157 .59884 Mdot
.42265 .50865 Mdot
.34209 .63578 Mdot
.32573 .55245 Mdot
.48979 .6279 Mdot
.71816 .63371 Mdot
.4169 .64801 Mdot
.51645 .62812 Mdot
.29739 .70467 Mdot
.42792 .32618 Mdot
.37647 .354 Mdot
.37014 .77453 Mdot
.66534 .54857 Mdot
.71916 .63782 Mdot
.48713 .639 Mdot
.37768 .40757 Mdot
.35761 .39546 Mdot
.5456 .63416 Mdot
.27705 .49175 Mdot
.7745 .47723 Mdot
.41166 .45831 Mdot
.35214 .63065 Mdot
.37456 .61181 Mdot
.43141 .36118 Mdot
.40331 .42089 Mdot
.68423 .5051 Mdot
.72686 .65925 Mdot
.69918 .64276 Mdot
.72525 .64108 Mdot
.69274 .56396 Mdot
.48914 .71716 Mdot
.47876 .64623 Mdot
.42801 .69292 Mdot
.57868 .69683 Mdot
.4368 .49261 Mdot
.64745 .53627 Mdot
.39679 .38487 Mdot
.44504 .41713 Mdot
.49647 .66068 Mdot
.63746 .69069 Mdot
.35464 .45928 Mdot
.35347 .58378 Mdot
.48833 .6254 Mdot
.45779 .34197 Mdot
.46431 .68145 Mdot
.65634 .36999 Mdot
.31131 .72125 Mdot
.54043 .65888 Mdot
.38323 .60334 Mdot
.53797 .6237 Mdot
.38568 .39628 Mdot
.43625 .46016 Mdot
.36855 .59687 Mdot
.65679 .41611 Mdot
.36005 .44751 Mdot
.41312 .37895 Mdot
.3784 .83581 Mdot
.50343 .77844 Mdot
.55388 .60912 Mdot
.41476 .43782 Mdot
.36046 .38409 Mdot
.67866 .38561 Mdot
.38399 .40254 Mdot
.44001 .39483 Mdot
.55785 .81066 Mdot
.57846 .64008 Mdot
.6361 .42079 Mdot
.28354 .42522 Mdot
.35802 .64752 Mdot
.57951 .18543 Mdot
.70199 .64792 Mdot
.52982 .68164 Mdot
.74276 .57112 Mdot
.72303 .64753 Mdot
.59973 .68379 Mdot
.58273 .19576 Mdot
.7235 .63985 Mdot
.68486 .59374 Mdot
.33055 .38437 Mdot
.41641 .46156 Mdot
.42302 .38965 Mdot
.65647 .38383 Mdot
.35509 .5988 Mdot
.57151 .46387 Mdot
.68785 .30532 Mdot
.43219 .40014 Mdot
.31381 .64961 Mdot
.65376 .2489 Mdot
.71702 .65034 Mdot
.63476 .38502 Mdot
.6316 .37041 Mdot
.42882 .39081 Mdot
.59062 .7941 Mdot
.35354 .62067 Mdot
.39779 .42613 Mdot
.3714 .39928 Mdot
.66492 .5452 Mdot
.38109 .59422 Mdot
.64426 .54977 Mdot
.73296 .65591 Mdot
.30361 .27746 Mdot
.33997 .81188 Mdot
.49921 .65934 Mdot
.48793 .18864 Mdot
.5394 .67184 Mdot
.83117 .52071 Mdot
.72703 .64967 Mdot
.41509 .4169 Mdot
.32429 .60754 Mdot
.39401 .42892 Mdot
.39992 .40075 Mdot
.39405 .40482 Mdot
.42667 .32847 Mdot
.27965 .73596 Mdot
.64862 .39843 Mdot
.41243 .49442 Mdot
.66552 .49232 Mdot
.51788 .17852 Mdot
.77647 .34739 Mdot
.39462 .38033 Mdot
.42955 .38671 Mdot
.37815 .63005 Mdot
.39971 .46182 Mdot
.55254 .65523 Mdot
.32889 .62919 Mdot
.36909 .37847 Mdot
.56901 .20369 Mdot
.38168 .43199 Mdot
.42678 .192 Mdot
.54087 .6256 Mdot
.303 .70694 Mdot
.4108 .49187 Mdot
.72263 .63729 Mdot
.71969 .63793 Mdot
.6944 .64116 Mdot
.55733 .64199 Mdot
.65141 .53442 Mdot
.75201 .34968 Mdot
.46971 .3808 Mdot
.42597 .44071 Mdot
.35833 .38828 Mdot
.70779 .5374 Mdot
.5172 .48393 Mdot
.59159 .74588 Mdot
.45146 .33799 Mdot
.68246 .50814 Mdot
.3622 .65347 Mdot
.71755 .69474 Mdot
.32928 .62777 Mdot
.63819 .42237 Mdot
.5375 .65278 Mdot
.651 .36873 Mdot
.27542 .68614 Mdot
.363 .59303 Mdot
.32514 .58071 Mdot
.65963 .53921 Mdot
.54969 .50068 Mdot
.52985 .1121 Mdot
.63169 .51063 Mdot
.50512 .30042 Mdot
.34279 .614 Mdot
.36974 .38918 Mdot
.57263 .41896 Mdot
.54393 .50106 Mdot
.66328 .5315 Mdot
.42485 .41745 Mdot
.6505 .77854 Mdot
.68687 .50854 Mdot
.35809 .4251 Mdot
.68389 .53222 Mdot
.53744 .63958 Mdot
.68108 .53231 Mdot
.32377 .62731 Mdot
.42687 .36728 Mdot
.56416 .10865 Mdot
.58507 .51899 Mdot
.39494 .44223 Mdot
.48881 .62515 Mdot
.44061 .26307 Mdot
.40419 .39433 Mdot
.64257 .3686 Mdot
.67269 .5038 Mdot
.76567 .44267 Mdot
.40331 .45339 Mdot
.67352 .53286 Mdot
.3293 .61153 Mdot
.55885 .66547 Mdot
.82034 .47416 Mdot
.70757 .6352 Mdot
.34696 .60121 Mdot
.72906 .67215 Mdot
.5195 .61076 Mdot
.35862 .40014 Mdot
.37347 .40176 Mdot
.36587 .63015 Mdot
.75421 .60838 Mdot
.38215 .44727 Mdot
.41727 .42191 Mdot
.69701 .53811 Mdot
.69663 .50845 Mdot
.75846 .58014 Mdot
.66747 .55305 Mdot
.35191 .4077 Mdot
.36558 .62958 Mdot
.44319 .42301 Mdot
.38504 .61838 Mdot
.45258 .42118 Mdot
.38816 .65441 Mdot
.33562 .60894 Mdot
.6643 .74736 Mdot
.43546 .42035 Mdot
.47605 .46736 Mdot
.39607 .40156 Mdot
.38314 .40954 Mdot
.66121 .49563 Mdot
.64127 .40242 Mdot
.45946 .45699 Mdot
.60744 .5143 Mdot
.63253 .38383 Mdot
.24577 .35988 Mdot
.66794 .54646 Mdot
.65501 .37748 Mdot
.62542 .2649 Mdot
.71465 .66311 Mdot
.64982 .39037 Mdot
.76897 .33675 Mdot
.49839 .65996 Mdot
.35377 .65115 Mdot
.42214 .45396 Mdot
.28244 .26962 Mdot
.59302 .35718 Mdot
.71377 .65539 Mdot
.39072 .44101 Mdot
.39947 .38667 Mdot
.38897 .57927 Mdot
.7833 .69435 Mdot
.69838 .52044 Mdot
.43522 .43383 Mdot
.39018 .62741 Mdot
.64581 .81935 Mdot
.65098 .49592 Mdot
.65256 .38798 Mdot
.54041 .62944 Mdot
.40908 .59913 Mdot
.70647 .63493 Mdot
.54994 .66424 Mdot
.72421 .57578 Mdot
.28315 .70035 Mdot
.38593 .4312 Mdot
.64312 .53227 Mdot
.24575 .67154 Mdot
.46625 .36668 Mdot
.5245 .5953 Mdot
.47986 .33958 Mdot
.379 .59947 Mdot
.54349 .63301 Mdot
.66771 .36994 Mdot
.32739 .63016 Mdot
.34274 .63016 Mdot
.50141 .6693 Mdot
.7161 .52734 Mdot
.55104 .47734 Mdot
.54437 .64215 Mdot
.44659 .78853 Mdot
.21241 .39654 Mdot
.71868 .66086 Mdot
.63294 .39703 Mdot
.1705 .49606 Mdot
.36255 .61892 Mdot
.64602 .2274 Mdot
.26561 .70457 Mdot
.427 .45821 Mdot
.66634 .38281 Mdot
.53416 .72022 Mdot
.73839 .33447 Mdot
.51182 .64935 Mdot
.48039 .51996 Mdot
.62298 .38597 Mdot
.39997 .45626 Mdot
.29289 .65701 Mdot
.42817 .42411 Mdot
.53497 .6493 Mdot
.35205 .54051 Mdot
.38426 .60525 Mdot
.51144 .61059 Mdot
.306 .7194 Mdot
.44591 .41452 Mdot
.42958 .41972 Mdot
.55837 .37025 Mdot
.37106 .58479 Mdot
.70013 .63912 Mdot
.39967 .43255 Mdot
.41686 .38639 Mdot
.36265 .39334 Mdot
.49239 .40222 Mdot
.56637 .79604 Mdot
.43589 .43185 Mdot
.66642 .56959 Mdot
.41786 .34998 Mdot
.4343 .41719 Mdot
.3967 .61628 Mdot
.33441 .80165 Mdot
.72778 .63949 Mdot
.42151 .39259 Mdot
.38323 .43051 Mdot
.4968 .66476 Mdot
.56465 .45234 Mdot
.5393 .50724 Mdot
.63458 .51194 Mdot
.57081 .29283 Mdot
.42484 .32843 Mdot
.36254 .64388 Mdot
.62953 .40705 Mdot
.39404 .36632 Mdot
.37345 .63821 Mdot
.45533 .37236 Mdot
.6867 .51102 Mdot
.72289 .66023 Mdot
.34259 .72592 Mdot
.64631 .3848 Mdot
.59379 .40131 Mdot
.42207 .7092 Mdot
.68592 .54583 Mdot
.42654 .44418 Mdot
.53576 .67819 Mdot
.63474 .51981 Mdot
.71168 .64994 Mdot
.35258 .44628 Mdot
.35183 .61293 Mdot
.38081 .61436 Mdot
.51756 .35469 Mdot
.6207 .49245 Mdot
.48295 .84873 Mdot
.53764 .64098 Mdot
.4042 .35386 Mdot
.37359 .6943 Mdot
.38139 .61537 Mdot
.5152 .34879 Mdot
.6536 .3769 Mdot
.50951 .64899 Mdot
.69811 .62913 Mdot
.3747 .63557 Mdot
.37159 .58092 Mdot
.45682 .39285 Mdot
.40533 .37148 Mdot
.54837 .31407 Mdot
.50245 .34117 Mdot
.52264 .62283 Mdot
.6386 .40765 Mdot
.63469 .54215 Mdot
.42798 .42956 Mdot
.33262 .61229 Mdot
.20104 .43127 Mdot
.37758 .42264 Mdot
.68427 .50445 Mdot
.3764 .59951 Mdot
.6479 .41219 Mdot
.63707 .37434 Mdot
.38343 .409 Mdot
.27379 .58587 Mdot
.50321 .62813 Mdot
.38267 .61745 Mdot
.31364 .68155 Mdot
.37837 .44411 Mdot
.40947 .36851 Mdot
.36252 .35108 Mdot
.53877 .66882 Mdot
.3115 .70705 Mdot
.63864 .41829 Mdot
.36078 .60955 Mdot
.39351 .43782 Mdot
.64237 .38238 Mdot
.33324 .70145 Mdot
.72417 .65347 Mdot
.68276 .52918 Mdot
.64614 .36638 Mdot
.66037 .40683 Mdot
.62943 .39177 Mdot
.6619 .23616 Mdot
.33236 .586 Mdot
.34532 .48484 Mdot
.38848 .44408 Mdot
.52266 .35991 Mdot
.45586 .45244 Mdot
.5543 .6389 Mdot
.6638 .55012 Mdot
.39717 .39799 Mdot
.45592 .39163 Mdot
.50257 .39335 Mdot
.48048 .44463 Mdot
.30261 .63487 Mdot
.36922 .58924 Mdot
.46663 .46279 Mdot
.66063 .5459 Mdot
.78091 .71142 Mdot
.49726 .1365 Mdot
.40421 .48691 Mdot
.56071 .47342 Mdot
.33035 .61873 Mdot
.49831 .66875 Mdot
.52823 .5166 Mdot
.52002 .61656 Mdot
.3662 .60888 Mdot
.4304 .42961 Mdot
.43308 .69574 Mdot
.67822 .37277 Mdot
.37744 .40344 Mdot
.52676 .6465 Mdot
.37807 .4034 Mdot
.55328 .64823 Mdot
.43079 .60813 Mdot
.46624 .78338 Mdot
.44017 .45004 Mdot
.36643 .42794 Mdot
.4997 .42075 Mdot
.39746 .37918 Mdot
.78187 .63729 Mdot
.33519 .62777 Mdot
.66645 .76963 Mdot
.44554 .37411 Mdot
.30419 .54962 Mdot
.38713 .44603 Mdot
.73517 .61843 Mdot
.39979 .37088 Mdot
.51541 .54063 Mdot
.41501 .46029 Mdot
.43283 .38219 Mdot
.49287 .63105 Mdot
.49757 .66547 Mdot
.33999 .59449 Mdot
.70185 .63594 Mdot
.46651 .1785 Mdot
.41192 .37402 Mdot
.6804 .5704 Mdot
.53437 .59115 Mdot
.65357 .40911 Mdot
.36643 .61167 Mdot
.6478 .82618 Mdot
.50234 .62141 Mdot
.62393 .51498 Mdot
.75846 .61905 Mdot
.67521 .56406 Mdot
.57492 .65628 Mdot
.38697 .31333 Mdot
.65872 .41396 Mdot
.39426 .45331 Mdot
.18484 .56275 Mdot
.51701 .76626 Mdot
.3628 .45565 Mdot
.50856 .61261 Mdot
.30582 .38479 Mdot
.17257 .49879 Mdot
.64195 .36313 Mdot
.67403 .38039 Mdot
.49823 .62645 Mdot
.69365 .54962 Mdot
.39491 .32678 Mdot
.65364 .37581 Mdot
.69073 .53205 Mdot
.69621 .64754 Mdot
.46735 .56996 Mdot
.35657 .61888 Mdot
.3172 .72206 Mdot
.43215 .7371 Mdot
.51968 .62144 Mdot
.61121 .55322 Mdot
.40676 .62609 Mdot
.36728 .56534 Mdot
.70976 .63194 Mdot
.66099 .49509 Mdot
.32108 .61321 Mdot
.35605 .43005 Mdot
.45801 .48549 Mdot
.42828 .39723 Mdot
.66202 .38876 Mdot
.39196 .37844 Mdot
.66814 .49619 Mdot
.51367 .64675 Mdot
.64687 .50801 Mdot
.49489 .63409 Mdot
.47022 .71514 Mdot
.39718 .42019 Mdot
.43031 .38108 Mdot
.59195 .36829 Mdot
.35469 .57926 Mdot
.26245 .66781 Mdot
.68455 .57046 Mdot
.6549 .52382 Mdot
.44907 .40988 Mdot
.3262 .62088 Mdot
.64824 .43082 Mdot
.59315 .37327 Mdot
.37605 .38814 Mdot
.33466 .628 Mdot
.43112 .43694 Mdot
.61978 .25054 Mdot
.49126 .79619 Mdot
.36782 .62368 Mdot
.69595 .76165 Mdot
.41706 .43252 Mdot
.32515 .40104 Mdot
.35735 .38912 Mdot
.49741 .27473 Mdot
.37767 .44456 Mdot
.3526 .6482 Mdot
.42408 .39719 Mdot
.33304 .63647 Mdot
.69123 .54555 Mdot
.48456 .65861 Mdot
.34389 .60387 Mdot
.37364 .38739 Mdot
.64649 .20693 Mdot
.53455 .64438 Mdot
.43721 .39731 Mdot
.51997 .66225 Mdot
.38081 .63819 Mdot
.3621 .58172 Mdot
.77319 .35721 Mdot
.57099 .62254 Mdot
.5355 .63745 Mdot
.43894 .43724 Mdot
.40005 .74168 Mdot
.44047 .42554 Mdot
.5434 .32051 Mdot
.44897 .38711 Mdot
.37233 .44014 Mdot
.84472 .45043 Mdot
.53608 .67503 Mdot
.49671 .84517 Mdot
.68083 .29749 Mdot
.67434 .24167 Mdot
.40438 .58031 Mdot
.64145 .36335 Mdot
.59206 .20657 Mdot
.73243 .65874 Mdot
.6799 .51646 Mdot
.39597 .39812 Mdot
.39661 .55455 Mdot
.53902 .63113 Mdot
.64467 .40364 Mdot
.44197 .44845 Mdot
.67736 .49788 Mdot
.79661 .45507 Mdot
.48128 .63138 Mdot
.363 .61744 Mdot
.35538 .58113 Mdot
.62765 .8235 Mdot
.39155 .43782 Mdot
.43348 .38935 Mdot
.5363 .65255 Mdot
.48207 .40101 Mdot
.64085 .41365 Mdot
.73613 .488 Mdot
.53439 .63701 Mdot
.58617 .56671 Mdot
.36147 .59029 Mdot
.39781 .38615 Mdot
.52582 .47116 Mdot
.5937 .59594 Mdot
.26774 .37459 Mdot
.65708 .38701 Mdot
.55645 .33169 Mdot
.35345 .64817 Mdot
.51752 .64262 Mdot
.69646 .35585 Mdot
.40052 .35169 Mdot
.40425 .3859 Mdot
.55777 .33613 Mdot
.57032 .44359 Mdot
.64179 .43581 Mdot
.41143 .46621 Mdot
.5671 .43741 Mdot
.44862 .40338 Mdot
.36425 .3841 Mdot
.38255 .46079 Mdot
.41553 .36564 Mdot
.33268 .62544 Mdot
.49805 .37929 Mdot
.67784 .52955 Mdot
.25752 .47672 Mdot
.49205 .5181 Mdot
.40639 .44842 Mdot
.4339 .42706 Mdot
.28878 .35859 Mdot
.58379 .63276 Mdot
.33708 .62257 Mdot
.31639 .62148 Mdot
.48408 .63528 Mdot
.47106 .47586 Mdot
.703 .54286 Mdot
.48893 .35201 Mdot
.64938 .50565 Mdot
.33469 .63029 Mdot
.64954 .52508 Mdot
.48254 .64079 Mdot
.64263 .53187 Mdot
.6907 .56561 Mdot
.5487 .63977 Mdot
.35562 .58954 Mdot
.38168 .38446 Mdot
.48667 .62994 Mdot
.5577 .36679 Mdot
.66146 .38722 Mdot
.77311 .35634 Mdot
.42362 .35174 Mdot
.47606 .50256 Mdot
.48852 .23727 Mdot
.64687 .51107 Mdot
.51 .8068 Mdot
.33646 .60783 Mdot
.6804 .39606 Mdot
.33167 .62719 Mdot
.27574 .71717 Mdot
.63971 .40438 Mdot
.76731 .33378 Mdot
.69268 .47476 Mdot
.77932 .42546 Mdot
.42518 .46551 Mdot
.38376 .65982 Mdot
.63571 .532 Mdot
.53687 .62992 Mdot
.72023 .53082 Mdot
.43271 .37733 Mdot
.59266 .76658 Mdot
.37075 .57125 Mdot
.70164 .65435 Mdot
.51162 .63779 Mdot
.49626 .61526 Mdot
.38843 .43005 Mdot
.77084 .53143 Mdot
.43497 .37322 Mdot
.67525 .44017 Mdot
.56338 .30983 Mdot
.48391 .34533 Mdot
.45135 .42797 Mdot
.64178 .50622 Mdot
.43169 .4376 Mdot
.31272 .38326 Mdot
.19597 .59227 Mdot
.35683 .3675 Mdot
.65649 .74013 Mdot
.61057 .3693 Mdot
.36495 .59617 Mdot
.41715 .49078 Mdot
.7059 .64648 Mdot
.41563 .43536 Mdot
.13497 .47598 Mdot
.64709 .39039 Mdot
.65486 .58345 Mdot
.37939 .43974 Mdot
.39619 .43199 Mdot
.21694 .58722 Mdot
.40604 .56429 Mdot
.69829 .62771 Mdot
.4091 .38739 Mdot
.58736 .30101 Mdot
.52041 .66851 Mdot
.43117 .36539 Mdot
.42522 .39061 Mdot
.26531 .33305 Mdot
.53839 .66678 Mdot
.64509 .51518 Mdot
.72896 .66231 Mdot
.63611 .54591 Mdot
.61827 .391 Mdot
.53683 .5254 Mdot
.48616 .32596 Mdot
.49082 .79381 Mdot
.62983 .37548 Mdot
.37094 .40954 Mdot
.35154 .45635 Mdot
.40969 .4308 Mdot
.67249 .37406 Mdot
.54434 .66203 Mdot
.33621 .61436 Mdot
.35525 .72869 Mdot
.71523 .64502 Mdot
.35756 .42204 Mdot
.66046 .36457 Mdot
.34972 .60709 Mdot
.60526 .56033 Mdot
.36185 .60253 Mdot
.52269 .63081 Mdot
.54897 .62661 Mdot
.63728 .39266 Mdot
.33238 .63042 Mdot
.63992 .55633 Mdot
.68775 .30781 Mdot
.45267 .39654 Mdot
.51059 .60515 Mdot
.32844 .60721 Mdot
.40179 .61463 Mdot
.36393 .57184 Mdot
.38986 .4177 Mdot
.56186 .46241 Mdot
.36671 .37863 Mdot
.50223 .62379 Mdot
.68655 .52645 Mdot
.46487 .31488 Mdot
.21785 .60122 Mdot
.58528 .5453 Mdot
.44314 .46528 Mdot
.44039 .40622 Mdot
.42899 .39107 Mdot
.46091 .42697 Mdot
.70041 .38334 Mdot
.40113 .42041 Mdot
.4931 .63277 Mdot
.65973 .50059 Mdot
.39532 .44585 Mdot
.70445 .64834 Mdot
.54528 .47446 Mdot
.62571 .39975 Mdot
.51043 .5266 Mdot
.58319 .17776 Mdot
.34826 .60734 Mdot
.65253 .55177 Mdot
.67901 .51826 Mdot
.62771 .39439 Mdot
.53166 .62818 Mdot
.35745 .60075 Mdot
.50674 .268 Mdot
.63134 .39933 Mdot
.42097 .39373 Mdot
.73483 .56306 Mdot
.70795 .72632 Mdot
.39228 .45514 Mdot
.40746 .40365 Mdot
.7211 .66438 Mdot
.69754 .54793 Mdot
.23083 .30489 Mdot
.58015 .42538 Mdot
.63908 .39807 Mdot
.66967 .39817 Mdot
.35848 .57135 Mdot
.38033 .47635 Mdot
.49758 .63463 Mdot
.57394 .4051 Mdot
.44198 .27542 Mdot
.60845 .42933 Mdot
.82806 .51834 Mdot
.37927 .4162 Mdot
.22124 .5772 Mdot
.44837 .42412 Mdot
.38243 .57345 Mdot
.39148 .61008 Mdot
.34181 .62103 Mdot
.51045 .62434 Mdot
.33443 .54167 Mdot
.49092 .63784 Mdot
.54672 .15481 Mdot
.33605 .64527 Mdot
.72814 .39634 Mdot
.65268 .53088 Mdot
.4716 .43458 Mdot
.64886 .41389 Mdot
.56704 .67325 Mdot
.3943 .4672 Mdot
.57976 .79139 Mdot
.64695 .5354 Mdot
.3624 .58511 Mdot
.37648 .3185 Mdot
.38503 .19526 Mdot
.55306 .50932 Mdot
.37067 .502 Mdot
.25968 .64811 Mdot
.64329 .40871 Mdot
.26759 .38213 Mdot
.66003 .4167 Mdot
.52299 .65169 Mdot
.42801 .37244 Mdot
.41028 .36342 Mdot
.45303 .42343 Mdot
.39981 .41896 Mdot
.49248 .6578 Mdot
.46222 .39506 Mdot
.25054 .71111 Mdot
.72084 .66218 Mdot
.61699 .2395 Mdot
.65423 .37197 Mdot
.52805 .61672 Mdot
.65603 .50233 Mdot
.69788 .64046 Mdot
.49824 .32777 Mdot
.41662 .45959 Mdot
.39698 .40018 Mdot
.71252 .62906 Mdot
.38662 .4607 Mdot
.44356 .3337 Mdot
.67651 .5284 Mdot
.58015 .53282 Mdot
.64749 .36351 Mdot
.65194 .36886 Mdot
.54724 .65211 Mdot
.33182 .62919 Mdot
.65468 .38015 Mdot
.69752 .53959 Mdot
.45925 .38454 Mdot
.37508 .37999 Mdot
.32925 .60563 Mdot
.26588 .70538 Mdot
.6394 .36305 Mdot
.37187 .32058 Mdot
.34391 .64578 Mdot
.34527 .57169 Mdot
.40623 .38851 Mdot
.35835 .36018 Mdot
.39978 .63156 Mdot
.63459 .37447 Mdot
.52476 .61521 Mdot
.75484 .38657 Mdot
.53026 .65048 Mdot
.35372 .60199 Mdot
.43717 .36371 Mdot
.35811 .58947 Mdot
.41024 .43867 Mdot
.8904 .46999 Mdot
.40389 .36634 Mdot
.431 .8086 Mdot
.50862 .28589 Mdot
.67632 .51506 Mdot
.6411 .55676 Mdot
.70889 .65601 Mdot
.3452 .64692 Mdot
.39668 .36404 Mdot
.66765 .40499 Mdot
.70289 .2733 Mdot
.38623 .65371 Mdot
.68583 .51478 Mdot
.7005 .54696 Mdot
.54763 .66384 Mdot
.38194 .43922 Mdot
.39897 .3832 Mdot
.64176 .52874 Mdot
.51462 .23095 Mdot
.36213 .64179 Mdot
.43405 .39135 Mdot
.43905 .41133 Mdot
.67599 .52024 Mdot
.68743 .30933 Mdot
.42287 .62721 Mdot
.42446 .37104 Mdot
.63286 .3565 Mdot
.55639 .64172 Mdot
.45881 .42852 Mdot
.46326 .3981 Mdot
.66751 .39622 Mdot
.56153 .21007 Mdot
.16935 .53767 Mdot
.54877 .6331 Mdot
.70053 .63934 Mdot
.36763 .39416 Mdot
.65444 .5317 Mdot
.37342 .3852 Mdot
.42307 .21342 Mdot
.71118 .66103 Mdot
.40942 .41958 Mdot
.39658 .48143 Mdot
.38607 .59671 Mdot
.40193 .42457 Mdot
.28793 .32777 Mdot
.6295 .52311 Mdot
.40593 .42158 Mdot
.27008 .60684 Mdot
.53295 .66919 Mdot
.40671 .48649 Mdot
.66396 .37155 Mdot
.49132 .2718 Mdot
.42735 .719 Mdot
.70924 .5352 Mdot
.64854 .37089 Mdot
.37903 .38514 Mdot
.6902 .55282 Mdot
.53098 .62477 Mdot
.57538 .77703 Mdot
.43751 .45644 Mdot
.5347 .64778 Mdot
.51282 .64516 Mdot
.64093 .38776 Mdot
.53297 .84567 Mdot
.46485 .45457 Mdot
.39459 .37971 Mdot
.29505 .3067 Mdot
.38397 .5832 Mdot
.38682 .38255 Mdot
.37428 .41684 Mdot
.49592 .64476 Mdot
.40873 .65489 Mdot
.30537 .41751 Mdot
.75141 .50835 Mdot
.55405 .64704 Mdot
.69863 .49668 Mdot
.68872 .55374 Mdot
.65489 .37297 Mdot
.37034 .59948 Mdot
.62171 .396 Mdot
.67227 .54224 Mdot
.38339 .43257 Mdot
.50239 .65004 Mdot
.22665 .42582 Mdot
.5047 .67465 Mdot
.65218 .48336 Mdot
.3977 .59308 Mdot
.37785 .69975 Mdot
.15066 .55838 Mdot
.44566 .73604 Mdot
.49516 .67723 Mdot
.65425 .40894 Mdot
.72573 .54073 Mdot
.43934 .40908 Mdot
.27044 .40981 Mdot
.37867 .39435 Mdot
.26082 .63173 Mdot
.67414 .55036 Mdot
.70842 .63118 Mdot
.42622 .37067 Mdot
.56465 .32025 Mdot
.47187 .63659 Mdot
.5488 .66381 Mdot
.40407 .41187 Mdot
.51761 .62805 Mdot
.40587 .37397 Mdot
.65706 .498 Mdot
.47668 .83455 Mdot
.43924 .40213 Mdot
.36589 .37086 Mdot
.57456 .6122 Mdot
.77195 .35102 Mdot
.64865 .56555 Mdot
.2196 .57862 Mdot
.35237 .21364 Mdot
.51544 .62842 Mdot
.36399 .4618 Mdot
.63779 .53082 Mdot
.72041 .66452 Mdot
.62827 .54895 Mdot
.38178 .39605 Mdot
.38489 .40447 Mdot
.44931 .41112 Mdot
.42925 .42041 Mdot
.27151 .40287 Mdot
.48832 .39576 Mdot
.2294 .56134 Mdot
.399 .40141 Mdot
.29601 .66014 Mdot
.48859 .64329 Mdot
.30367 .62575 Mdot
.64751 .35692 Mdot
.38032 .41875 Mdot
.3841 .53998 Mdot
.54513 .62723 Mdot
.54402 .15458 Mdot
.54428 .66527 Mdot
.66042 .51309 Mdot
.51414 .67407 Mdot
.40812 .44292 Mdot
.37502 .61251 Mdot
.63262 .51079 Mdot
.5669 .7476 Mdot
.68027 .51514 Mdot
.39454 .44216 Mdot
.69957 .34189 Mdot
.68001 .52125 Mdot
.53193 .49106 Mdot
.37632 .60762 Mdot
.59291 .30517 Mdot
.3925 .6142 Mdot
.4087 .42264 Mdot
.41261 .42197 Mdot
.6997 .65624 Mdot
.47602 .64408 Mdot
.37826 .64131 Mdot
.38851 .84088 Mdot
.62226 .41003 Mdot
.34674 .62469 Mdot
.46517 .37523 Mdot
.56805 .45525 Mdot
.37453 .62376 Mdot
.55129 .27381 Mdot
.53153 .62724 Mdot
.32788 .59426 Mdot
.44685 .35469 Mdot
.52258 .57936 Mdot
.68136 .37858 Mdot
.66598 .48983 Mdot
.54759 .56184 Mdot
.63534 .53414 Mdot
.54033 .62179 Mdot
.66202 .48354 Mdot
.51491 .6682 Mdot
.29028 .68271 Mdot
.37923 .52628 Mdot
.502 .67588 Mdot
.53141 .61524 Mdot
.66505 .53828 Mdot
.44363 .44935 Mdot
.46358 .53685 Mdot
.40614 .46658 Mdot
.44268 .45813 Mdot
.5205 .66974 Mdot
.37358 .64154 Mdot
.34758 .65208 Mdot
.34894 .67024 Mdot
.35922 .5785 Mdot
.65157 .5013 Mdot
.48613 .80052 Mdot
.27335 .68343 Mdot
.53752 .65802 Mdot
.52787 .61002 Mdot
.43879 .42618 Mdot
.65752 .53459 Mdot
.68696 .54807 Mdot
.50002 .63996 Mdot
.24498 .42372 Mdot
.37028 .3704 Mdot
.39799 .60267 Mdot
.33254 .64191 Mdot
.36633 .6274 Mdot
.35761 .57402 Mdot
.31704 .47351 Mdot
.53549 .62878 Mdot
.34048 .64652 Mdot
.40744 .41481 Mdot
.38382 .40174 Mdot
.71439 .63736 Mdot
.65675 .36845 Mdot
.45491 .36921 Mdot
.3581 .37014 Mdot
.40406 .38861 Mdot
.68261 .52751 Mdot
.38737 .49734 Mdot
.70176 .65044 Mdot
.69109 .50776 Mdot
.70366 .54611 Mdot
.71854 .63438 Mdot
.32291 .66793 Mdot
.36404 .19694 Mdot
.43491 .43393 Mdot
.39651 .5138 Mdot
.65778 .52946 Mdot
.52358 .82156 Mdot
.31938 .70584 Mdot
.4526 .42804 Mdot
.48889 .56905 Mdot
.63933 .50148 Mdot
.37874 .57676 Mdot
.38241 .38789 Mdot
.72708 .64546 Mdot
.62711 .40221 Mdot
.4625 .36916 Mdot
.72962 .66265 Mdot
.33659 .63527 Mdot
.69225 .38315 Mdot
.33892 .57935 Mdot
.63917 .49987 Mdot
.40032 .48248 Mdot
.53203 .10973 Mdot
.64771 .5523 Mdot
.70425 .28472 Mdot
.41538 .57473 Mdot
.43901 .39579 Mdot
.64266 .54788 Mdot
.38397 .57982 Mdot
.55652 .63867 Mdot
.56239 .4335 Mdot
.34076 .60117 Mdot
.70057 .63601 Mdot
.71986 .64081 Mdot
.67748 .52615 Mdot
.37336 .59057 Mdot
.43414 .36548 Mdot
.38817 .61135 Mdot
.52206 .67498 Mdot
.44406 .4415 Mdot
.44926 .1737 Mdot
.46137 .47934 Mdot
.35646 .64685 Mdot
.68168 .50021 Mdot
.67952 .38521 Mdot
.42829 .45633 Mdot
.67926 .27891 Mdot
.37738 .42958 Mdot
.52814 .66563 Mdot
.62204 .79922 Mdot
.23687 .3996 Mdot
.39149 .44729 Mdot
.43779 .42574 Mdot
.54741 .63662 Mdot
.42072 .45899 Mdot
.38653 .4487 Mdot
.54255 .59868 Mdot
.38596 .60081 Mdot
.42874 .40076 Mdot
.69317 .53576 Mdot
.21053 .60511 Mdot
.36525 .39901 Mdot
.66383 .72288 Mdot
.5825 .31324 Mdot
.59452 .81652 Mdot
.38438 .37849 Mdot
.54904 .37725 Mdot
.42233 .41558 Mdot
.38483 .41859 Mdot
.44149 .43334 Mdot
.20931 .55478 Mdot
.66451 .54049 Mdot
.67547 .50059 Mdot
.68161 .37629 Mdot
.58202 .30997 Mdot
.66764 .38471 Mdot
.55096 .6501 Mdot
.81095 .49103 Mdot
.71482 .66137 Mdot
.33162 .63058 Mdot
.41698 .36014 Mdot
.63096 .50911 Mdot
.39461 .38799 Mdot
.41156 .44152 Mdot
.64668 .49712 Mdot
.66727 .55998 Mdot
.62358 .56754 Mdot
.65257 .41688 Mdot
.34047 .61319 Mdot
.45965 .39923 Mdot
.63272 .38378 Mdot
.42788 .36056 Mdot
.57608 .43486 Mdot
.33882 .61718 Mdot
.38865 .60718 Mdot
.38946 .63544 Mdot
.38302 .43239 Mdot
.40955 .44792 Mdot
.49088 .63936 Mdot
.32453 .61868 Mdot
.54479 .6509 Mdot
.63409 .52337 Mdot
.62868 .53932 Mdot
.38181 .39646 Mdot
.35143 .32487 Mdot
.66613 .40361 Mdot
.65561 .51132 Mdot
.71086 .62784 Mdot
.6787 .3969 Mdot
.38974 .43918 Mdot
.64056 .50838 Mdot
.6511 .36787 Mdot
.23598 .4685 Mdot
.32357 .22799 Mdot
.67806 .38304 Mdot
.4062 .41197 Mdot
.22023 .59601 Mdot
.67233 .31387 Mdot
.62618 .41396 Mdot
.5249 .66006 Mdot
.37651 .42394 Mdot
.41154 .2512 Mdot
.62643 .3765 Mdot
.25641 .66004 Mdot
.67439 .51271 Mdot
.45374 .61068 Mdot
.42926 .3432 Mdot
.26871 .43291 Mdot
.62114 .40214 Mdot
.35877 .6053 Mdot
.33523 .65445 Mdot
.41628 .40293 Mdot
.65278 .35474 Mdot
.54862 .66653 Mdot
.67146 .50574 Mdot
.67448 .57072 Mdot
.37726 .59266 Mdot
.41903 .75722 Mdot
.69243 .5245 Mdot
.35934 .32734 Mdot
.74757 .56345 Mdot
.44708 .49893 Mdot
.28623 .63715 Mdot
.54273 .74302 Mdot
.37033 .38203 Mdot
.6763 .38877 Mdot
.52172 .61613 Mdot
.49618 .63069 Mdot
.52889 .63428 Mdot
.64821 .56103 Mdot
.52481 .51831 Mdot
.64815 .53993 Mdot
.57212 .76963 Mdot
.64285 .38198 Mdot
.60447 .28941 Mdot
.39921 .36402 Mdot
.43981 .40492 Mdot
.41377 .35166 Mdot
.44015 .38103 Mdot
.42538 .41318 Mdot
.53017 .62845 Mdot
.66604 .56592 Mdot
.76379 .44528 Mdot
.35329 .63189 Mdot
.65654 .59393 Mdot
.65237 .53071 Mdot
.71988 .66394 Mdot
.64819 .40046 Mdot
.53513 .39401 Mdot
.69128 .49956 Mdot
.65032 .52437 Mdot
.46362 .39009 Mdot
.38009 .63013 Mdot
.43681 .32482 Mdot
.41801 .42144 Mdot
.65254 .5107 Mdot
.68423 .47237 Mdot
.30214 .33579 Mdot
.34764 .36816 Mdot
.66871 .42562 Mdot
.56494 .46133 Mdot
.6446 .4206 Mdot
.38271 .34378 Mdot
.53143 .82212 Mdot
.67209 .54143 Mdot
.66652 .51692 Mdot
.6634 .36678 Mdot
.32607 .38977 Mdot
.37468 .59617 Mdot
.70779 .63083 Mdot
.51361 .66153 Mdot
.40986 .42877 Mdot
.63836 .55103 Mdot
.33895 .45617 Mdot
.77227 .50694 Mdot
.53334 .63889 Mdot
.69223 .50974 Mdot
.38427 .44102 Mdot
.40608 .40985 Mdot
.64689 .41016 Mdot
.41427 .52665 Mdot
.47549 .40997 Mdot
.67333 .24064 Mdot
.46624 .78196 Mdot
.40783 .7771 Mdot
.40416 .38566 Mdot
.37828 .59118 Mdot
.72631 .64876 Mdot
.63314 .39923 Mdot
.45059 .37829 Mdot
.33314 .22174 Mdot
.37452 .65128 Mdot
.52319 .64691 Mdot
.72501 .64225 Mdot
.52442 .51643 Mdot
.37593 .42536 Mdot
.37895 .39378 Mdot
.39444 .41834 Mdot
.28513 .24211 Mdot
.68832 .51838 Mdot
.36619 .57319 Mdot
.65828 .39001 Mdot
.3647 .57525 Mdot
.67834 .50633 Mdot
.36896 .72989 Mdot
.40208 .45154 Mdot
.39715 .59714 Mdot
.36176 .60606 Mdot
.54824 .66293 Mdot
.55923 .64382 Mdot
.62527 .57027 Mdot
.40574 .36597 Mdot
.72841 .64803 Mdot
.39239 .61131 Mdot
.67944 .56098 Mdot
.64023 .40541 Mdot
.48818 .62997 Mdot
.39849 .40247 Mdot
.67683 .53607 Mdot
.36348 .45326 Mdot
.37708 .62555 Mdot
.65093 .52503 Mdot
.73019 .64117 Mdot
.67223 .38725 Mdot
.39019 .40275 Mdot
.65555 .43382 Mdot
.71608 .6314 Mdot
.44054 .41245 Mdot
.4866 .3402 Mdot
.61369 .41187 Mdot
.5803 .74683 Mdot
.64896 .54584 Mdot
.70728 .64085 Mdot
.39066 .60236 Mdot
.37212 .68249 Mdot
.66592 .5124 Mdot
.5204 .37539 Mdot
.42279 .53958 Mdot
.46096 .40376 Mdot
.36436 .62128 Mdot
.72284 .5189 Mdot
.62231 .20803 Mdot
.6424 .28147 Mdot
.43367 .3951 Mdot
.64042 .54519 Mdot
.64515 .36937 Mdot
.53721 .65917 Mdot
.66537 .72386 Mdot
.3527 .5062 Mdot
.66942 .4861 Mdot
.43908 .43152 Mdot
.39182 .61321 Mdot
.50159 .63944 Mdot
.44291 .69683 Mdot
.69906 .52939 Mdot
.66979 .55176 Mdot
.39271 .44571 Mdot
.65047 .37811 Mdot
.56708 .2364 Mdot
.67079 .49617 Mdot
.64047 .5517 Mdot
.71429 .60504 Mdot
.6643 .36497 Mdot
.41399 .40981 Mdot
.35104 .67016 Mdot
.45973 .43448 Mdot
.70667 .2835 Mdot
.70253 .64861 Mdot
.35314 .63332 Mdot
.37933 .40404 Mdot
.75816 .53183 Mdot
.65736 .50552 Mdot
.55918 .47632 Mdot
.64398 .4816 Mdot
.52796 .62596 Mdot
.63682 .54954 Mdot
.38769 .38604 Mdot
.4713 .63738 Mdot
.66704 .40136 Mdot
.42165 .36884 Mdot
.41157 .44842 Mdot
.38132 .57565 Mdot
.52272 .65276 Mdot
.18574 .46284 Mdot
.51521 .60975 Mdot
.5392 .62434 Mdot
.32183 .64542 Mdot
.41904 .39837 Mdot
.65847 .51637 Mdot
.6546 .48593 Mdot
.45006 .38001 Mdot
.48996 .81303 Mdot
.37704 .59622 Mdot
.62914 .5742 Mdot
.24144 .29706 Mdot
.37996 .32793 Mdot
.72349 .63244 Mdot
.41735 .52211 Mdot
.55423 .65405 Mdot
.40184 .40697 Mdot
.3533 .64574 Mdot
.64957 .5581 Mdot
.69265 .5262 Mdot
.43552 .36357 Mdot
.50724 .64394 Mdot
.6256 .38667 Mdot
.67266 .55363 Mdot
.76985 .52769 Mdot
.39646 .42437 Mdot
.59969 .76377 Mdot
.66323 .55423 Mdot
.72226 .2739 Mdot
.76806 .46931 Mdot
.36302 .62462 Mdot
.41395 .44275 Mdot
.35009 .58643 Mdot
.6611 .39401 Mdot
.7117 .53297 Mdot
.5112 .64636 Mdot
.34091 .38183 Mdot
.18377 .59555 Mdot
.6601 .53973 Mdot
.3331 .62535 Mdot
.39043 .44652 Mdot
.36419 .3357 Mdot
.39529 .37698 Mdot
.38181 .67084 Mdot
.65528 .44891 Mdot
.52441 .66997 Mdot
.52708 .66473 Mdot
.4444 .41745 Mdot
.63549 .40859 Mdot
.65504 .49249 Mdot
.67061 .50661 Mdot
.82344 .67178 Mdot
.73005 .63967 Mdot
.53992 .30869 Mdot
.38697 .40464 Mdot
.68474 .56006 Mdot
.21381 .59592 Mdot
.53669 .65245 Mdot
.44071 .37993 Mdot
.68755 .56253 Mdot
.59283 .61922 Mdot
.57399 .43737 Mdot
.42087 .41082 Mdot
.43825 .3354 Mdot
.51773 .66256 Mdot
.58538 .38716 Mdot
.64583 .53644 Mdot
.44646 .3854 Mdot
.50779 .60963 Mdot
.75446 .58067 Mdot
.23559 .6591 Mdot
.3405 .61371 Mdot
.64745 .48251 Mdot
.53105 .62862 Mdot
.47578 .39946 Mdot
.65314 .37119 Mdot
.63144 .52554 Mdot
.68351 .52159 Mdot
.4353 .44432 Mdot
.46955 .40908 Mdot
.37859 .32848 Mdot
.34076 .63183 Mdot
.49352 .65363 Mdot
.42941 .37203 Mdot
.42546 .75988 Mdot
.44981 .40775 Mdot
.49253 .64847 Mdot
.68546 .16845 Mdot
.45082 .44659 Mdot
.39768 .3765 Mdot
.59055 .24668 Mdot
.34262 .59749 Mdot
.36435 .57636 Mdot
.47186 .78859 Mdot
.38728 .40441 Mdot
.78315 .45601 Mdot
.34219 .60923 Mdot
.37897 .60026 Mdot
.721 .41088 Mdot
.44875 .43657 Mdot
.59292 .38547 Mdot
.4967 .63705 Mdot
.4985 .62166 Mdot
.38705 .60712 Mdot
.47624 .4104 Mdot
.53954 .62803 Mdot
.2869 .41123 Mdot
.65174 .53439 Mdot
.53548 .82235 Mdot
.37233 .63214 Mdot
.46411 .52072 Mdot
.53771 .64695 Mdot
.552 .1555 Mdot
.51492 .56867 Mdot
.45046 .41707 Mdot
.39288 .40786 Mdot
.67009 .39079 Mdot
.40851 .47468 Mdot
.69909 .64244 Mdot
.51878 .62799 Mdot
.52645 .2124 Mdot
.3426 .62145 Mdot
.40381 .36865 Mdot
.53149 .38557 Mdot
.45299 .71216 Mdot
.65187 .74511 Mdot
.3648 .59704 Mdot
.35831 .62066 Mdot
.65861 .54554 Mdot
.68026 .54308 Mdot
.42163 .40416 Mdot
.5003 .62642 Mdot
.32365 .61349 Mdot
.50408 .65982 Mdot
.67377 .54164 Mdot
.65397 .52223 Mdot
.70982 .66074 Mdot
.3665 .44478 Mdot
.65223 .49611 Mdot
.77034 .55286 Mdot
.41112 .75737 Mdot
.36565 .56668 Mdot
.15338 .51733 Mdot
.44304 .69508 Mdot
.49488 .24685 Mdot
.64595 .41882 Mdot
.68996 .63647 Mdot
.49016 .6609 Mdot
.4393 .42351 Mdot
.39494 .39465 Mdot
.71731 .65075 Mdot
.48294 .66041 Mdot
.65014 .40453 Mdot
.47691 .65064 Mdot
.64123 .38012 Mdot
.63083 .54912 Mdot
.36604 .39712 Mdot
.37247 .40802 Mdot
.53024 .62959 Mdot
.64403 .51794 Mdot
.66362 .49864 Mdot
.65586 .41894 Mdot
.54839 .39597 Mdot
.67812 .52817 Mdot
.37394 .63055 Mdot
.32169 .51902 Mdot
.72043 .64303 Mdot
.38375 .38612 Mdot
.5184 .35377 Mdot
.25798 .39816 Mdot
.45809 .40253 Mdot
.72372 .63851 Mdot
.76314 .72542 Mdot
.40023 .36525 Mdot
.69799 .78029 Mdot
.70799 .63895 Mdot
.34234 .59677 Mdot
.6461 .5485 Mdot
.69815 .64434 Mdot
.44338 .3469 Mdot
.63973 .42365 Mdot
.43754 .35778 Mdot
.3445 .59755 Mdot
.3949 .62741 Mdot
.38388 .77894 Mdot
.70788 .28595 Mdot
.6649 .41278 Mdot
.64132 .39621 Mdot
.66788 .51303 Mdot
.83435 .45033 Mdot
.44834 .35705 Mdot
.64159 .40083 Mdot
.51572 .21928 Mdot
.43403 .42974 Mdot
.54149 .32631 Mdot
.49003 .56663 Mdot
.37867 .59251 Mdot
.31011 .66093 Mdot
.66256 .50736 Mdot
.33342 .62342 Mdot
.38309 .7545 Mdot
.41528 .35194 Mdot
.33938 .61962 Mdot
.49437 .64935 Mdot
.60245 .68386 Mdot
.35739 .58416 Mdot
.56551 .41462 Mdot
.49882 .63346 Mdot
.67607 .46115 Mdot
.56253 .24816 Mdot
.11966 .51359 Mdot
.51639 .62639 Mdot
.63799 .51808 Mdot
.64042 .4991 Mdot
.67116 .50948 Mdot
.33828 .60366 Mdot
.69164 .54603 Mdot
.34674 .63686 Mdot
.69962 .31859 Mdot
.53882 .38248 Mdot
.63672 .39137 Mdot
.56854 .61713 Mdot
.36159 .61339 Mdot
.53008 .78686 Mdot
.15365 .55702 Mdot
.40311 .41302 Mdot
.51188 .6097 Mdot
.6648 .36794 Mdot
.81106 .35229 Mdot
.66864 .39348 Mdot
.63841 .53286 Mdot
.54463 .82187 Mdot
.40841 .37186 Mdot
.3268 .30691 Mdot
.67193 .39435 Mdot
.35871 .59476 Mdot
.44074 .40984 Mdot
.61934 .50422 Mdot
.65581 .37489 Mdot
.62579 .39687 Mdot
.43113 .40935 Mdot
.36545 .58428 Mdot
.65519 .5186 Mdot
.48486 .65328 Mdot
.61326 .39776 Mdot
.47964 .40517 Mdot
.46274 .42096 Mdot
.381 .365 Mdot
.54591 .50335 Mdot
.44475 .23208 Mdot
.51359 .62857 Mdot
.63524 .30529 Mdot
.68275 .5376 Mdot
.71096 .47656 Mdot
.48895 .77197 Mdot
.57288 .63532 Mdot
.70233 .64659 Mdot
.70517 .65499 Mdot
.42378 .4104 Mdot
.45356 .22878 Mdot
.67081 .76199 Mdot
.5794 .62142 Mdot
.72257 .64577 Mdot
.66867 .50287 Mdot
.34086 .65597 Mdot
.34855 .75724 Mdot
.46134 .43902 Mdot
.5546 .65979 Mdot
.67963 .5315 Mdot
.41837 .2154 Mdot
.64735 .38346 Mdot
.52562 .81344 Mdot
.39865 .4479 Mdot
.43029 .38164 Mdot
.51199 .63447 Mdot
.49149 .63773 Mdot
.64267 .73632 Mdot
.41847 .78514 Mdot
.60963 .44691 Mdot
.43167 .65352 Mdot
.388 .23183 Mdot
.30354 .6314 Mdot
.36167 .64572 Mdot
.73334 .65772 Mdot
.49932 .61564 Mdot
.37765 .39226 Mdot
.32699 .62534 Mdot
.65113 .7468 Mdot
.41353 .61841 Mdot
.55073 .3249 Mdot
.78145 .48216 Mdot
.40204 .44002 Mdot
.38515 .62469 Mdot
.33489 .6203 Mdot
.34059 .58122 Mdot
.72062 .63593 Mdot
.40826 .386 Mdot
.43922 .45252 Mdot
.43731 .38413 Mdot
.48081 .38628 Mdot
.39942 .42522 Mdot
.47326 .76345 Mdot
.58651 .56471 Mdot
.53953 .20946 Mdot
.45726 .40771 Mdot
.50632 .61935 Mdot
.40019 .35697 Mdot
.63216 .40532 Mdot
.44075 .4304 Mdot
.54101 .31683 Mdot
.52656 .64105 Mdot
.32797 .38616 Mdot
.42702 .65669 Mdot
.40197 .45 Mdot
.63235 .37356 Mdot
.46927 .23179 Mdot
.17885 .47816 Mdot
.67147 .59666 Mdot
.37582 .62883 Mdot
.69465 .50623 Mdot
.52981 .67487 Mdot
.66039 .51809 Mdot
.45319 .40569 Mdot
.7306 .64942 Mdot
.52818 .72743 Mdot
.46531 .52233 Mdot
.37556 .40227 Mdot
.39883 .49622 Mdot
.38214 .61286 Mdot
.63957 .51139 Mdot
.3493 .55815 Mdot
.38806 .41567 Mdot
.65897 .3866 Mdot
.64974 .37506 Mdot
.42604 .77597 Mdot
.45145 .1864 Mdot
.33735 .68755 Mdot
.51219 .63278 Mdot
.68519 .50641 Mdot
.62063 .39775 Mdot
.35998 .50542 Mdot
.55753 .65859 Mdot
.55278 .6562 Mdot
.51364 .65152 Mdot
.40608 .43425 Mdot
.70036 .64562 Mdot
.48307 .20896 Mdot
.69934 .63817 Mdot
.40675 .45114 Mdot
.6866 .5219 Mdot
.69863 .65061 Mdot
.66926 .38202 Mdot
.54711 .65336 Mdot
.67303 .54486 Mdot
.40729 .42481 Mdot
.34658 .60986 Mdot
.55083 .40371 Mdot
.47859 .28183 Mdot
.65476 .26198 Mdot
.64728 .25533 Mdot
.37283 .64715 Mdot
.52493 .1655 Mdot
.51499 .60515 Mdot
.24629 .42226 Mdot
.6769 .34005 Mdot
.44519 .37551 Mdot
.40995 .81508 Mdot
.64447 .53624 Mdot
.64339 .50059 Mdot
.41675 .41307 Mdot
.66791 .56155 Mdot
.4 .37148 Mdot
.67397 .54868 Mdot
.67333 .59504 Mdot
.45875 .44688 Mdot
.64761 .49979 Mdot
.41011 .34259 Mdot
.43085 .45469 Mdot
.38367 .59811 Mdot
.63364 .53739 Mdot
.4506 .40533 Mdot
.84118 .42654 Mdot
.48881 .63348 Mdot
.72007 .63629 Mdot
.59288 .48222 Mdot
.53652 .63102 Mdot
.34976 .6268 Mdot
.43709 .46327 Mdot
.65812 .41089 Mdot
.35568 .60716 Mdot
.62772 .57218 Mdot
.67392 .3875 Mdot
.48747 .80021 Mdot
.38055 .62433 Mdot
.71897 .64415 Mdot
.66737 .40277 Mdot
.39358 .49233 Mdot
.62794 .52451 Mdot
.43499 .27872 Mdot
.70386 .63456 Mdot
.39786 .38319 Mdot
.66549 .5723 Mdot
.49 .62485 Mdot
.42664 .38999 Mdot
.64654 .55235 Mdot
.7198 .63424 Mdot
.41414 .43258 Mdot
.43462 .41988 Mdot
.31074 .72317 Mdot
.62266 .77636 Mdot
.64497 .40861 Mdot
.3921 .59464 Mdot
.40767 .4154 Mdot
.64955 .41704 Mdot
.79714 .56175 Mdot
.37112 .37826 Mdot
.34015 .59547 Mdot
.50126 .37031 Mdot
.68397 .54005 Mdot
.54541 .65079 Mdot
.64745 .48384 Mdot
.62896 .40588 Mdot
.43429 .86144 Mdot
.70439 .65788 Mdot
.39579 .33934 Mdot
.42666 .3612 Mdot
.71784 .52455 Mdot
.33555 .62478 Mdot
.60388 .43844 Mdot
.39045 .40319 Mdot
.4649 .47634 Mdot
.42014 .37062 Mdot
.76818 .45889 Mdot
.37635 .59697 Mdot
.39562 .37971 Mdot
.3633 .31973 Mdot
.36447 .41632 Mdot
.62712 .37868 Mdot
.59991 .27433 Mdot
.38218 .36796 Mdot
.46692 .10015 Mdot
.71479 .6294 Mdot
.65043 .49676 Mdot
.64278 .4671 Mdot
.84238 .55527 Mdot
.28846 .6798 Mdot
.34321 .6352 Mdot
.49356 .46355 Mdot
.65765 .51813 Mdot
.23646 .64028 Mdot
.5609 .16952 Mdot
.4275 .45517 Mdot
.38023 .43187 Mdot
.63839 .53286 Mdot
.67812 .56196 Mdot
.73063 .65814 Mdot
.45521 .41395 Mdot
.36159 .46566 Mdot
.69158 .51069 Mdot
.39689 .43186 Mdot
.46397 .334 Mdot
.48782 .65511 Mdot
.3811 .58875 Mdot
.53871 .65846 Mdot
.54199 .66772 Mdot
.28894 .47921 Mdot
.46444 .7812 Mdot
.49131 .64662 Mdot
.472 .62454 Mdot
.5318 .31738 Mdot
.51741 .40119 Mdot
.62306 .39395 Mdot
.55081 .19217 Mdot
.67238 .51597 Mdot
.41005 .38679 Mdot
.36164 .64865 Mdot
.26887 .44855 Mdot
.62597 .61286 Mdot
.58003 .81414 Mdot
.38329 .41253 Mdot
.66245 .50442 Mdot
.71448 .63254 Mdot
.46186 .44132 Mdot
.69509 .45411 Mdot
.43267 .38777 Mdot
.63075 .50996 Mdot
.33297 .52629 Mdot
.45074 .31784 Mdot
.72986 .55989 Mdot
.32273 .59972 Mdot
.41453 .36205 Mdot
.36281 .63601 Mdot
.53796 .64264 Mdot
.64156 .41331 Mdot
.64905 .40882 Mdot
.438 .41242 Mdot
.37194 .51887 Mdot
.48002 .56802 Mdot
.42366 .45687 Mdot
.44058 .44184 Mdot
.70719 .64007 Mdot
.44173 .44159 Mdot
.4294 .36315 Mdot
.43922 .3821 Mdot
.3597 .4046 Mdot
.53634 .6228 Mdot
.46168 .32181 Mdot
.35595 .42612 Mdot
.37319 .33826 Mdot
.48435 .64479 Mdot
.4639 .49581 Mdot
.53871 .66747 Mdot
.44618 .17489 Mdot
.52599 .66708 Mdot
.64243 .40521 Mdot
.68121 .57317 Mdot
.47658 .47019 Mdot
.32199 .6154 Mdot
.55319 .63555 Mdot
.6527 .39435 Mdot
.5244 .63079 Mdot
.69007 .52208 Mdot
.19355 .39788 Mdot
.41385 .6171 Mdot
.57716 .41385 Mdot
.49614 .58358 Mdot
.60599 .76093 Mdot
.65541 .54103 Mdot
.38034 .59759 Mdot
.31112 .31426 Mdot
.4447 .39514 Mdot
.67072 .39282 Mdot
.42649 .40869 Mdot
.54413 .62792 Mdot
.66666 .50682 Mdot
.66736 .28618 Mdot
.65247 .41051 Mdot
.23364 .67647 Mdot
.67468 .50864 Mdot
.43589 .45803 Mdot
.55548 .65556 Mdot
.15293 .52255 Mdot
.53182 .66705 Mdot
.53489 .37676 Mdot
.39166 .57608 Mdot
.27872 .65118 Mdot
.36533 .61755 Mdot
.67689 .73076 Mdot
.29997 .21812 Mdot
.63949 .229 Mdot
.34965 .60123 Mdot
.73825 .56752 Mdot
.39189 .43791 Mdot
.38897 .36086 Mdot
.36381 .32868 Mdot
.37259 .57149 Mdot
.40355 .41887 Mdot
.70611 .6358 Mdot
.38372 .73813 Mdot
.72407 .47699 Mdot
.69097 .50188 Mdot
.38944 .38045 Mdot
.48558 .64628 Mdot
.4761 .65042 Mdot
.69758 .64608 Mdot
.5272 .67261 Mdot
.44603 .44484 Mdot
.36341 .61467 Mdot
.44264 .53667 Mdot
.66558 .39151 Mdot
.78774 .35502 Mdot
.63927 .36075 Mdot
.63273 .48243 Mdot
.39797 .48212 Mdot
.65321 .52254 Mdot
.57092 .87113 Mdot
.44818 .41113 Mdot
.34034 .60906 Mdot
.42682 .42355 Mdot
.424 .36601 Mdot
.38935 .35991 Mdot
.69795 .53021 Mdot
.64338 .45396 Mdot
.40001 .43101 Mdot
.51245 .64747 Mdot
.59439 .22343 Mdot
.42376 .35219 Mdot
.69306 .59005 Mdot
.57304 .30231 Mdot
.56533 .77189 Mdot
.35365 .56684 Mdot
.64038 .51279 Mdot
.34729 .62152 Mdot
.31711 .62604 Mdot
.34962 .62692 Mdot
.48806 .20387 Mdot
.30052 .36375 Mdot
.76364 .71875 Mdot
.2741 .62376 Mdot
.25151 .45979 Mdot
.39794 .61199 Mdot
.79206 .6017 Mdot
.344 .64516 Mdot
.3443 .63168 Mdot
.87487 .39313 Mdot
.33718 .6437 Mdot
.38379 .39515 Mdot
.46764 .40739 Mdot
.44276 .72787 Mdot
.52745 .32746 Mdot
.44578 .42832 Mdot
.41166 .41419 Mdot
.64864 .41538 Mdot
.31406 .36892 Mdot
.73026 .66447 Mdot
.48098 .80457 Mdot
.47071 .70015 Mdot
.42973 .41022 Mdot
.40904 .41806 Mdot
.47153 .44235 Mdot
.25455 .24393 Mdot
.28416 .44235 Mdot
.39313 .63477 Mdot
.40859 .50002 Mdot
.73823 .30031 Mdot
.41597 .4616 Mdot
.37163 .40938 Mdot
.40994 .43874 Mdot
.65807 .51687 Mdot
.35818 .65685 Mdot
.41017 .49946 Mdot
.54656 .76195 Mdot
.39268 .44373 Mdot
.56379 .61895 Mdot
.62392 .42589 Mdot
.38761 .38722 Mdot
.3497 .5771 Mdot
.4304 .43605 Mdot
.37755 .63006 Mdot
.38682 .60116 Mdot
.47009 .44779 Mdot
.46799 .20159 Mdot
.3449 .58672 Mdot
.40761 .44888 Mdot
.64586 .51417 Mdot
.63433 .21813 Mdot
.3953 .38475 Mdot
.63195 .3919 Mdot
.39133 .40604 Mdot
.63434 .37317 Mdot
.4288 .45116 Mdot
.70141 .63551 Mdot
.24814 .38042 Mdot
.6678 .51765 Mdot
.63543 .33435 Mdot
.691 .5547 Mdot
.31436 .72485 Mdot
.33779 .6005 Mdot
.73595 .65469 Mdot
.54109 .83799 Mdot
.70971 .63971 Mdot
.54745 .41016 Mdot
.65579 .59942 Mdot
.50497 .62295 Mdot
.37003 .5758 Mdot
.62277 .31787 Mdot
.71403 .58664 Mdot
.61106 .52941 Mdot
.70476 .54292 Mdot
.44201 .85053 Mdot
.49197 .83761 Mdot
.40691 .429 Mdot
.35036 .27716 Mdot
.23102 .55257 Mdot
.36879 .38899 Mdot
.4198 .46722 Mdot
.62609 .52305 Mdot
.40198 .3631 Mdot
.53147 .4986 Mdot
.6641 .53834 Mdot
.64744 .39476 Mdot
.35343 .63453 Mdot
.63723 .37261 Mdot
.62174 .54056 Mdot
.58355 .55396 Mdot
.67812 .54159 Mdot
.36084 .39381 Mdot
.42246 .42156 Mdot
.38898 .61519 Mdot
.38431 .54494 Mdot
.38363 .59312 Mdot
.67164 .37205 Mdot
.67025 .53335 Mdot
.27555 .43195 Mdot
.40633 .40496 Mdot
.36424 .60629 Mdot
.50013 .69031 Mdot
.40533 .40969 Mdot
.53488 .63448 Mdot
.38599 .43802 Mdot
.34886 .59862 Mdot
.44134 .44219 Mdot
.36189 .61616 Mdot
.6427 .52849 Mdot
.4053 .45921 Mdot
.41728 .411 Mdot
.1691 .55635 Mdot
.65242 .40459 Mdot
.33869 .59973 Mdot
.53188 .54737 Mdot
.44397 .45149 Mdot
.70287 .48372 Mdot
.38393 .37959 Mdot
.50782 .42649 Mdot
.39973 .3419 Mdot
.70974 .63586 Mdot
.35835 .4448 Mdot
.39561 .38378 Mdot
.38219 .29857 Mdot
.25817 .58812 Mdot
.35013 .55698 Mdot
.54969 .63534 Mdot
.35392 .57608 Mdot
.62921 .53947 Mdot
.65511 .56252 Mdot
.67853 .55422 Mdot
.53186 .34485 Mdot
.47229 .43317 Mdot
.40783 .3732 Mdot
.55364 .6317 Mdot
.64105 .39257 Mdot
.36336 .59854 Mdot
.64085 .38752 Mdot
.47139 .79946 Mdot
.67123 .3732 Mdot
.69888 .64503 Mdot
.76805 .47217 Mdot
.27066 .38687 Mdot
.65163 .41516 Mdot
.38271 .59135 Mdot
.77761 .48933 Mdot
.44552 .37787 Mdot
.6111 .56443 Mdot
.65813 .38484 Mdot
.40274 .84577 Mdot
.37806 .3839 Mdot
.55899 .45137 Mdot
.50542 .66657 Mdot
.65786 .37182 Mdot
.52748 .65282 Mdot
.44399 .42248 Mdot
.58948 .74542 Mdot
.33216 .62584 Mdot
.48532 .62181 Mdot
.35369 .42245 Mdot
.64716 .3696 Mdot
.68078 .52615 Mdot
.52119 .58565 Mdot
.5065 .61968 Mdot
.2404 .35911 Mdot
.64382 .28257 Mdot
.66873 .53476 Mdot
.70406 .73495 Mdot
.5159 .65622 Mdot
.37023 .38368 Mdot
.48361 .44668 Mdot
.45198 .42707 Mdot
.64923 .56268 Mdot
.64157 .50784 Mdot
.40984 .73885 Mdot
.42323 .42428 Mdot
.38036 .38212 Mdot
.40109 .63462 Mdot
.65694 .53631 Mdot
.37556 .61678 Mdot
.34112 .57921 Mdot
.63791 .5214 Mdot
.36548 .62352 Mdot
.67275 .38974 Mdot
.36918 .7154 Mdot
.51457 .6564 Mdot
.51582 .64612 Mdot
.66914 .50382 Mdot
.66575 .49219 Mdot
.65253 .52461 Mdot
.38623 .43825 Mdot
.36864 .59473 Mdot
.41893 .44389 Mdot
.36978 .37841 Mdot
.35718 .56183 Mdot
.33234 .64267 Mdot
.42195 .43709 Mdot
.72241 .52045 Mdot
.61754 .41085 Mdot
.65017 .50013 Mdot
.50248 .65991 Mdot
.23854 .63699 Mdot
.56042 .6388 Mdot
.38928 .37912 Mdot
.59472 .61117 Mdot
.35324 .59411 Mdot
.66972 .39043 Mdot
.61153 .40716 Mdot
.66425 .40346 Mdot
.5497 .67848 Mdot
.3285 .59953 Mdot
.48714 .79905 Mdot
.39569 .37483 Mdot
.54394 .50511 Mdot
.62875 .3099 Mdot
.49895 .77353 Mdot
.49339 .65082 Mdot
.40776 .41295 Mdot
.71246 .64004 Mdot
.29538 .34278 Mdot
.42988 .38409 Mdot
.44756 .39191 Mdot
.74596 .40133 Mdot
.3731 .33786 Mdot
.37481 .57023 Mdot
.3908 .78259 Mdot
.4618 .38952 Mdot
.38875 .66244 Mdot
.85904 .5871 Mdot
.39257 .37311 Mdot
.39193 .42047 Mdot
.40189 .3918 Mdot
.43283 .4278 Mdot
.38025 .5691 Mdot
.57923 .37287 Mdot
.5559 .65298 Mdot
.55938 .5159 Mdot
.50509 .65177 Mdot
.62987 .51694 Mdot
.55397 .45691 Mdot
.37373 .57907 Mdot
.66897 .39542 Mdot
.2777 .31389 Mdot
.44192 .7975 Mdot
.65713 .54462 Mdot
.30552 .46019 Mdot
.6632 .391 Mdot
.44847 .37877 Mdot
.67622 .3667 Mdot
.68145 .56155 Mdot
.502 .64151 Mdot
.46729 .41041 Mdot
.37715 .64099 Mdot
.35603 .58442 Mdot
.40317 .41461 Mdot
.70368 .27506 Mdot
.5395 .63822 Mdot
.56317 .67788 Mdot
.40448 .43613 Mdot
.44828 .39317 Mdot
.37263 .62448 Mdot
.65163 .50502 Mdot
.76082 .59899 Mdot
.65158 .40063 Mdot
.38532 .45563 Mdot
.43581 .42982 Mdot
.45214 .78837 Mdot
.55026 .65039 Mdot
.72643 .65726 Mdot
.40981 .4323 Mdot
.45713 .77872 Mdot
.41188 .43188 Mdot
.41621 .47597 Mdot
.65007 .51817 Mdot
.40762 .34785 Mdot
.37971 .42417 Mdot
.38423 .50253 Mdot
.52277 .65662 Mdot
.33779 .6162 Mdot
.40617 .60915 Mdot
.72698 .64489 Mdot
.53364 .63442 Mdot
.42515 .43636 Mdot
.5477 .64315 Mdot
.38489 .364 Mdot
.40062 .42851 Mdot
.49354 .65034 Mdot
.37515 .61732 Mdot
.51047 .71097 Mdot
.5198 .36948 Mdot
.42955 .42692 Mdot
.46374 .41773 Mdot
.53505 .34007 Mdot
.62527 .81824 Mdot
.38127 .40755 Mdot
.35 .59336 Mdot
.4103 .40831 Mdot
.53182 .64763 Mdot
.66708 .3705 Mdot
.34699 .60521 Mdot
.66803 .49731 Mdot
.64202 .5319 Mdot
.42282 .65868 Mdot
.70011 .65129 Mdot
.46194 .42749 Mdot
.32363 .57075 Mdot
.34935 .65016 Mdot
.85592 .47617 Mdot
.64029 .49995 Mdot
.62682 .3769 Mdot
.43741 .4194 Mdot
.53437 .58098 Mdot
.55735 .63766 Mdot
.46323 .09947 Mdot
.49173 .79546 Mdot
.67591 .35746 Mdot
.57001 .8205 Mdot
.71563 .64534 Mdot
.37461 .40919 Mdot
.63783 .41153 Mdot
.65183 .5477 Mdot
.41181 .35718 Mdot
.42821 .33313 Mdot
.60094 .44214 Mdot
.69545 .494 Mdot
.54744 .64684 Mdot
.68282 .54661 Mdot
.67803 .40241 Mdot
.69891 .64388 Mdot
.3665 .58024 Mdot
.39881 .38017 Mdot
.45793 .47088 Mdot
.65863 .49844 Mdot
.70132 .63481 Mdot
.40229 .44064 Mdot
.35493 .58262 Mdot
.66961 .55991 Mdot
.43376 .40799 Mdot
.24916 .42995 Mdot
.31622 .61475 Mdot
.6753 .5278 Mdot
.42691 .36256 Mdot
.50507 .41073 Mdot
.66952 .50078 Mdot
.65636 .49564 Mdot
.40404 .41891 Mdot
.67008 .3974 Mdot
.38203 .43948 Mdot
.51879 .66818 Mdot
.64252 .45389 Mdot
.52892 .6467 Mdot
.68445 .33385 Mdot
.38889 .476 Mdot
.61987 .75917 Mdot
.39253 .60823 Mdot
.66974 .4181 Mdot
.18341 .52806 Mdot
.45143 .3952 Mdot
.50436 .17443 Mdot
.47373 .51591 Mdot
.79777 .34852 Mdot
.28934 .2512 Mdot
.65368 .38402 Mdot
.5287 .63371 Mdot
.39248 .41993 Mdot
.53216 .61127 Mdot
.64112 .41014 Mdot
.64694 .30607 Mdot
.43066 .36557 Mdot
.37787 .59937 Mdot
.39399 .44314 Mdot
.37527 .62965 Mdot
.40311 .40852 Mdot
.36325 .35109 Mdot
.68981 .36698 Mdot
.53368 .37372 Mdot
.44728 .37902 Mdot
.19215 .39715 Mdot
.54163 .56909 Mdot
.65906 .39228 Mdot
.41372 .44696 Mdot
.71494 .6559 Mdot
.48814 .66536 Mdot
.42809 .24769 Mdot
.65605 .51995 Mdot
.48976 .64868 Mdot
.36142 .62937 Mdot
.65141 .48857 Mdot
.71995 .63277 Mdot
.4689 .46032 Mdot
.62952 .3789 Mdot
.51003 .62284 Mdot
.39199 .38502 Mdot
.3777 .38537 Mdot
.74402 .54916 Mdot
.65297 .67371 Mdot
.37341 .65416 Mdot
.20677 .63696 Mdot
.37156 .56575 Mdot
.64422 .40223 Mdot
.6505 .52011 Mdot
.37994 .40249 Mdot
.4309 .39399 Mdot
.6451 .55786 Mdot
.33761 .60245 Mdot
.67481 .47617 Mdot
.29914 .47484 Mdot
.67402 .49113 Mdot
.57966 .3322 Mdot
.34273 .60439 Mdot
.57788 .3376 Mdot
.6777 .40375 Mdot
.4377 .20066 Mdot
.50671 .27153 Mdot
.50487 .66677 Mdot
.58288 .32699 Mdot
.3573 .59595 Mdot
.41466 .42414 Mdot
.71923 .64668 Mdot
.70763 .6589 Mdot
.36188 .63292 Mdot
.63791 .53382 Mdot
.6555 .37248 Mdot
.39238 .42359 Mdot
.54937 .79519 Mdot
.42642 .69877 Mdot
.68285 .50312 Mdot
.42724 .32393 Mdot
.52114 .65197 Mdot
.38196 .42385 Mdot
.63247 .38568 Mdot
.50592 .62671 Mdot
.70634 .62166 Mdot
.38522 .732 Mdot
.44119 .41501 Mdot
.41393 .77923 Mdot
.52826 .62931 Mdot
.71115 .73375 Mdot
.42424 .40345 Mdot
.51635 .65629 Mdot
.34304 .39876 Mdot
.54183 .74602 Mdot
.49126 .53959 Mdot
.57307 .17881 Mdot
.70635 .51681 Mdot
.64157 .53551 Mdot
.60266 .69994 Mdot
.68515 .35205 Mdot
.48493 .6374 Mdot
.69885 .64256 Mdot
.55476 .25739 Mdot
.52546 .65405 Mdot
.37293 .41875 Mdot
.38556 .3786 Mdot
.28372 .47265 Mdot
.51797 .52498 Mdot
.69879 .63595 Mdot
.32356 .69234 Mdot
.45323 .4317 Mdot
.36692 .35831 Mdot
.42418 .39128 Mdot
.39481 .6284 Mdot
.5342 .62844 Mdot
.15136 .49524 Mdot
.54117 .64345 Mdot
.55484 .80077 Mdot
.67191 .51497 Mdot
.67573 .49465 Mdot
.38648 .38636 Mdot
.65317 .75419 Mdot
.41936 .2419 Mdot
.43403 .45583 Mdot
.69591 .47236 Mdot
.63462 .27904 Mdot
.35761 .36872 Mdot
.39863 .58497 Mdot
.44664 .47653 Mdot
.30796 .61501 Mdot
.49608 .63236 Mdot
.6502 .38016 Mdot
.61607 .40564 Mdot
.50483 .62442 Mdot
.40901 .37434 Mdot
.67467 .44936 Mdot
.42498 .37494 Mdot
.40927 .42979 Mdot
.5194 .81647 Mdot
.62098 .38925 Mdot
.65115 .52739 Mdot
.65071 .40953 Mdot
.34261 .63107 Mdot
.77172 .23706 Mdot
.63916 .38454 Mdot
.32222 .56789 Mdot
.59911 .35987 Mdot
.5828 .33046 Mdot
.35827 .58215 Mdot
.67579 .3968 Mdot
.54483 .64825 Mdot
.79338 .335 Mdot
.67232 .77975 Mdot
.56044 .6322 Mdot
.42838 .40176 Mdot
.38072 .58469 Mdot
.38246 .64102 Mdot
.49826 .60999 Mdot
.37514 .58823 Mdot
.37366 .47418 Mdot
.42149 .42733 Mdot
.48508 .63702 Mdot
.43199 .71934 Mdot
.51212 .61871 Mdot
.36071 .72355 Mdot
.40785 .4452 Mdot
.3439 .60643 Mdot
.42218 .48957 Mdot
.41071 .61896 Mdot
.72629 .66256 Mdot
.41151 .3567 Mdot
.66623 .37683 Mdot
.52608 .5138 Mdot
.67424 .52512 Mdot
.59314 .60756 Mdot
.38777 .61331 Mdot
.50483 .70169 Mdot
.38361 .59743 Mdot
.38234 .58229 Mdot
.54025 .66963 Mdot
.33727 .63422 Mdot
.39148 .42138 Mdot
.73323 .55068 Mdot
.37179 .63686 Mdot
.51658 .63726 Mdot
.66277 .37926 Mdot
.36938 .62144 Mdot
.62879 .50683 Mdot
.42811 .41664 Mdot
.6785 .54487 Mdot
.67888 .35612 Mdot
.36805 .57526 Mdot
.67595 .39442 Mdot
.64718 .49751 Mdot
.6269 .38862 Mdot
.67961 .29677 Mdot
.50242 .61547 Mdot
.58689 .81117 Mdot
.50695 .36776 Mdot
.3749 .64219 Mdot
.61209 .54225 Mdot
.38142 .40381 Mdot
.43073 .41824 Mdot
.67182 .41083 Mdot
.37908 .64344 Mdot
.65444 .23522 Mdot
.50082 .4401 Mdot
.37738 .7178 Mdot
.52164 .61495 Mdot
.23902 .6654 Mdot
.42214 .75774 Mdot
.80429 .41034 Mdot
.43162 .34619 Mdot
.71605 .64584 Mdot
.41155 .36783 Mdot
.17294 .49428 Mdot
.65933 .36648 Mdot
.76741 .64773 Mdot
.45146 .3602 Mdot
.6593 .52861 Mdot
.41301 .40035 Mdot
.39251 .27617 Mdot
.44139 .47815 Mdot
.65887 .4157 Mdot
.5775 .63249 Mdot
.32222 .61531 Mdot
.6649 .39182 Mdot
.64512 .53451 Mdot
.57781 .27765 Mdot
.41967 .3567 Mdot
.45379 .43631 Mdot
.68728 .50213 Mdot
.37817 .59638 Mdot
.62861 .52209 Mdot
.51403 .65611 Mdot
.64364 .38419 Mdot
.43765 .42375 Mdot
.376 .35361 Mdot
.67423 .4648 Mdot
.53525 .62839 Mdot
.66226 .48833 Mdot
.53938 .65891 Mdot
.71696 .64558 Mdot
.46126 .39727 Mdot
.69388 .51216 Mdot
.37554 .38395 Mdot
.17801 .54281 Mdot
.52693 .81926 Mdot
.26806 .57061 Mdot
.65101 .53035 Mdot
.56491 .31877 Mdot
.52971 .6419 Mdot
.5308 .66566 Mdot
.27359 .65176 Mdot
.46365 .23013 Mdot
.78319 .46464 Mdot
.24833 .33728 Mdot
.51306 .65606 Mdot
.52419 .64538 Mdot
.65514 .5511 Mdot
.34535 .63886 Mdot
.31494 .64123 Mdot
.65447 .48312 Mdot
.52592 .3614 Mdot
.36336 .59872 Mdot
.51928 .17333 Mdot
.62548 .53002 Mdot
.43342 .34559 Mdot
.72165 .67048 Mdot
.64893 .37671 Mdot
.52596 .36278 Mdot
.38106 .28381 Mdot
.37738 .40112 Mdot
.36337 .77453 Mdot
.6526 .50838 Mdot
.58715 .40865 Mdot
.43792 .17967 Mdot
.43362 .37046 Mdot
.41309 .39185 Mdot
.41363 .37663 Mdot
.61947 .39067 Mdot
.18334 .5089 Mdot
.37643 .40161 Mdot
.54599 .38426 Mdot
.41499 .46558 Mdot
.46152 .27118 Mdot
.64833 .40903 Mdot
.40705 .65445 Mdot
.70302 .51316 Mdot
.52568 .76728 Mdot
.36446 .32973 Mdot
.52851 .6598 Mdot
.66112 .58119 Mdot
.49942 .64324 Mdot
.44259 .22202 Mdot
.51162 .27309 Mdot
.3995 .60989 Mdot
.38296 .41382 Mdot
.69954 .5521 Mdot
.38951 .60222 Mdot
.71093 .61006 Mdot
.86177 .36203 Mdot
.54202 .63085 Mdot
.61767 .84024 Mdot
.5324 .66566 Mdot
.71807 .66258 Mdot
.37008 .62711 Mdot
.30424 .41421 Mdot
.54266 .50457 Mdot
.36775 .62104 Mdot
.52765 .72485 Mdot
.38503 .56697 Mdot
.57452 .32013 Mdot
.32267 .60424 Mdot
.52134 .6378 Mdot
.48909 .67184 Mdot
.42278 .33625 Mdot
.3849 .40259 Mdot
.57163 .51227 Mdot
.42783 .51356 Mdot
.38443 .40625 Mdot
.66393 .53818 Mdot
.65708 .77889 Mdot
.69507 .57333 Mdot
.35928 .64496 Mdot
.5538 .64527 Mdot
.41321 .39399 Mdot
.424 .42993 Mdot
.37635 .37715 Mdot
.16835 .56258 Mdot
.52632 .17597 Mdot
.40232 .42946 Mdot
.37889 .4498 Mdot
.64497 .53018 Mdot
.66198 .4329 Mdot
.21434 .38131 Mdot
.54254 .26104 Mdot
.43929 .39376 Mdot
.65471 .40607 Mdot
.62888 .3711 Mdot
.43633 .3618 Mdot
.55956 .78091 Mdot
.73436 .5688 Mdot
.39218 .38516 Mdot
.48345 .26122 Mdot
.63931 .56291 Mdot
.69683 .64416 Mdot
.66002 .49874 Mdot
.34747 .57708 Mdot
.70219 .64509 Mdot
.68833 .55417 Mdot
.29896 .40139 Mdot
.72759 .64421 Mdot
.52114 .74395 Mdot
.67162 .37199 Mdot
.42647 .38913 Mdot
.3935 .57299 Mdot
.64989 .56176 Mdot
.50301 .62412 Mdot
.35227 .61484 Mdot
.4796 .65811 Mdot
.69149 .37566 Mdot
.56383 .3905 Mdot
.70257 .65558 Mdot
.52129 .66044 Mdot
.38465 .7327 Mdot
.65317 .40721 Mdot
.53194 .67081 Mdot
.65699 .74851 Mdot
.44326 .3577 Mdot
.36516 .24728 Mdot
.41351 .45772 Mdot
.74034 .29693 Mdot
.5396 .66491 Mdot
.73076 .64477 Mdot
.40413 .37431 Mdot
.67406 .50735 Mdot
.35022 .44315 Mdot
.43422 .38969 Mdot
.6807 .50473 Mdot
.4086 .42774 Mdot
.63085 .38986 Mdot
.31473 .60497 Mdot
.44195 .52983 Mdot
.28356 .75194 Mdot
.62876 .38385 Mdot
.72077 .62103 Mdot
.38175 .40915 Mdot
.6624 .28466 Mdot
.37014 .61901 Mdot
.44164 .38101 Mdot
.28083 .66164 Mdot
.35716 .63985 Mdot
.35096 .62146 Mdot
.4336 .44408 Mdot
.51349 .67048 Mdot
.67666 .51558 Mdot
.65561 .4075 Mdot
.82156 .41927 Mdot
.43687 .40283 Mdot
.41391 .40952 Mdot
.66383 .3907 Mdot
.52684 .64626 Mdot
.42631 .43059 Mdot
.61136 .61174 Mdot
.83123 .40375 Mdot
.5469 .66583 Mdot
.42146 .35099 Mdot
.31878 .27422 Mdot
.39228 .65134 Mdot
.62414 .82768 Mdot
.62867 .34475 Mdot
.64115 .51447 Mdot
.35946 .35719 Mdot
.51813 .10982 Mdot
.65155 .37856 Mdot
.50865 .77841 Mdot
.39789 .43448 Mdot
.40327 .3996 Mdot
.36131 .5867 Mdot
.42186 .44092 Mdot
.332 .61583 Mdot
.32088 .79078 Mdot
.22462 .68657 Mdot
.38382 .60722 Mdot
.3576 .647 Mdot
.33281 .67091 Mdot
.20644 .40496 Mdot
.35526 .63248 Mdot
.40457 .35333 Mdot
.5948 .21479 Mdot
.47675 .43859 Mdot
.6677 .41729 Mdot
.64227 .35497 Mdot
.42796 .62726 Mdot
.71076 .70101 Mdot
.46465 .49212 Mdot
.34339 .35134 Mdot
.47942 .57426 Mdot
.51531 .66541 Mdot
.43996 .38855 Mdot
.69999 .65181 Mdot
.68416 .55083 Mdot
.44961 .46843 Mdot
.42653 .38445 Mdot
.37497 .63193 Mdot
.61863 .40243 Mdot
.5136 .67469 Mdot
.41222 .41414 Mdot
.68054 .47641 Mdot
.64849 .39769 Mdot
.36935 .64044 Mdot
.29005 .6578 Mdot
.62784 .40726 Mdot
.35623 .44243 Mdot
.39281 .40372 Mdot
.40311 .43994 Mdot
.37364 .33377 Mdot
.49177 .63137 Mdot
.62542 .54706 Mdot
.36905 .37601 Mdot
.47176 .79682 Mdot
.56977 .43976 Mdot
.38792 .349 Mdot
.36292 .59259 Mdot
.55946 .6426 Mdot
.72862 .65718 Mdot
.60482 .28876 Mdot
.44151 .41089 Mdot
.52579 .17794 Mdot
.28831 .45222 Mdot
.70366 .64681 Mdot
.39457 .59787 Mdot
.66843 .3956 Mdot
.44961 .43791 Mdot
.54734 .20398 Mdot
.38554 .37978 Mdot
.51588 .39484 Mdot
.64672 .50991 Mdot
.51141 .66282 Mdot
.81961 .37225 Mdot
.68662 .54862 Mdot
.34835 .62157 Mdot
.58014 .17562 Mdot
.34082 .65389 Mdot
.32374 .61981 Mdot
.46611 .20562 Mdot
.4927 .6388 Mdot
.50184 .10839 Mdot
.65311 .79891 Mdot
.36649 .41141 Mdot
.5352 .64769 Mdot
.37682 .62416 Mdot
.38295 .42468 Mdot
.34981 .64918 Mdot
.32592 .61648 Mdot
.40722 .35693 Mdot
.39642 .40089 Mdot
.53713 .39348 Mdot
.4759 .1718 Mdot
.66268 .40705 Mdot
.34315 .5961 Mdot
.25297 .47382 Mdot
.37583 .40522 Mdot
.3955 .37529 Mdot
.72191 .54103 Mdot
.65792 .41577 Mdot
.3661 .30284 Mdot
.4097 .43149 Mdot
.29473 .7234 Mdot
.46442 .41696 Mdot
.40168 .58588 Mdot
.54602 .66681 Mdot
.5501 .78079 Mdot
.64119 .55721 Mdot
.34409 .59068 Mdot
.64427 .36933 Mdot
.4044 .62335 Mdot
.29528 .59003 Mdot
.49485 .63843 Mdot
.34888 .59859 Mdot
.63487 .50087 Mdot
.50435 .63539 Mdot
.53449 .66913 Mdot
.59423 .2228 Mdot
.65997 .48649 Mdot
.67244 .37028 Mdot
.5046 .64624 Mdot
.24485 .42554 Mdot
.52054 .63407 Mdot
.26577 .47378 Mdot
.39989 .45589 Mdot
.55087 .3844 Mdot
.44426 .75964 Mdot
.38699 .32474 Mdot
.49427 .6223 Mdot
.64519 .41104 Mdot
.43736 .43675 Mdot
.37292 .58716 Mdot
.64004 .38278 Mdot
.52341 .59293 Mdot
.66074 .49319 Mdot
.39122 .61721 Mdot
.55524 .65872 Mdot
.3416 .60181 Mdot
.60807 .32831 Mdot
.61325 .48022 Mdot
.47693 .58298 Mdot
.55111 .49303 Mdot
.37235 .3834 Mdot
.42171 .5779 Mdot
.46272 .42879 Mdot
.42789 .38302 Mdot
.67546 .52672 Mdot
.53351 .34692 Mdot
.37544 .61788 Mdot
.82637 .37936 Mdot
.51868 .66198 Mdot
.33273 .74849 Mdot
.50117 .42299 Mdot
.44754 .39594 Mdot
.36888 .63793 Mdot
.33039 .64912 Mdot
.25982 .58703 Mdot
.64083 .55327 Mdot
.42711 .32949 Mdot
.3859 .47043 Mdot
.41325 .33765 Mdot
.54042 .66363 Mdot
.61268 .63042 Mdot
.63406 .53016 Mdot
.76606 .72484 Mdot
.65117 .50097 Mdot
.72764 .41741 Mdot
.3376 .63534 Mdot
.66226 .36941 Mdot
.39352 .37769 Mdot
.52502 .41274 Mdot
.39653 .58827 Mdot
.6045 .37856 Mdot
.66955 .38136 Mdot
.5975 .68512 Mdot
.4904 .64385 Mdot
.43903 .36727 Mdot
.41451 .36016 Mdot
.41926 .44643 Mdot
.40265 .4534 Mdot
.55038 .6399 Mdot
.37222 .41548 Mdot
.48874 .62022 Mdot
.25376 .4169 Mdot
.29488 .72666 Mdot
.68414 .56765 Mdot
.44083 .24027 Mdot
.38229 .63569 Mdot
.2345 .45218 Mdot
.47527 .34691 Mdot
.53823 .81896 Mdot
.65754 .27207 Mdot
.45632 .43859 Mdot
.64311 .54535 Mdot
.36738 .27525 Mdot
.69313 .55793 Mdot
.38242 .87163 Mdot
.67221 .43605 Mdot
.55212 .16635 Mdot
.38317 .42089 Mdot
.71865 .5254 Mdot
.49379 .37046 Mdot
.43026 .35674 Mdot
.67965 .42377 Mdot
.30317 .6965 Mdot
.45758 .73725 Mdot
.62287 .38642 Mdot
.43078 .41408 Mdot
.32138 .62118 Mdot
.38997 .42207 Mdot
.40009 .37058 Mdot
.38251 .42939 Mdot
.54634 .66924 Mdot
.46932 .42476 Mdot
.37806 .43109 Mdot
.65947 .6705 Mdot
.5455 .32622 Mdot
.68475 .54224 Mdot
.27338 .60467 Mdot
.6414 .39204 Mdot
.38251 .62467 Mdot
.5263 .47047 Mdot
.50357 .6652 Mdot
.24693 .59625 Mdot
.38759 .44015 Mdot
.43101 .75239 Mdot
.55558 .65754 Mdot
.64333 .38013 Mdot
.72582 .64543 Mdot
.60318 .20606 Mdot
.68212 .56745 Mdot
.72862 .64651 Mdot
.67337 .52364 Mdot
.19043 .51581 Mdot
.37276 .63344 Mdot
.37496 .37688 Mdot
.51431 .65108 Mdot
.6789 .51688 Mdot
.51945 .3271 Mdot
.42117 .38773 Mdot
.65234 .53434 Mdot
.37141 .38272 Mdot
.57401 .41065 Mdot
.74767 .55331 Mdot
.69427 .55305 Mdot
.53109 .68224 Mdot
.50776 .63911 Mdot
.67328 .38628 Mdot
.38551 .62267 Mdot
.35541 .59291 Mdot
.50594 .62771 Mdot
.57783 .84381 Mdot
.4351 .38908 Mdot
.38096 .4201 Mdot
.47215 .79453 Mdot
.39153 .41381 Mdot
.5804 .2928 Mdot
.71695 .66675 Mdot
.38369 .62889 Mdot
.38539 .42871 Mdot
.42885 .42892 Mdot
.43969 .41743 Mdot
.60262 .33443 Mdot
.65624 .49855 Mdot
.45258 .43266 Mdot
.64427 .41674 Mdot
.64921 .73457 Mdot
.3775 .41387 Mdot
.37571 .34928 Mdot
.35317 .59752 Mdot
.24721 .70692 Mdot
.51295 .6686 Mdot
.66168 .54194 Mdot
.65133 .49453 Mdot
.64631 .34789 Mdot
.34553 .56855 Mdot
.72909 .66521 Mdot
.8357 .53181 Mdot
.71558 .63528 Mdot
.66084 .39584 Mdot
.74864 .38126 Mdot
.6722 .4713 Mdot
.66285 .54796 Mdot
.47371 .63512 Mdot
.39136 .4438 Mdot
.44478 .44907 Mdot
.51231 .78093 Mdot
.45388 .42032 Mdot
.66615 .37964 Mdot
.48335 .63651 Mdot
.3568 .59951 Mdot
.64766 .37513 Mdot
.53809 .65827 Mdot
.37663 .59419 Mdot
.44608 .36054 Mdot
.45352 .36669 Mdot
.35386 .61772 Mdot
.38642 .59645 Mdot
.38879 .39211 Mdot
.64254 .66841 Mdot
.34645 .57447 Mdot
.34615 .60102 Mdot
.69392 .64024 Mdot
.6853 .56598 Mdot
.43486 .49156 Mdot
.53662 .64691 Mdot
.40316 .43859 Mdot
.6907 .56122 Mdot
.66302 .41352 Mdot
.37323 .61239 Mdot
.42678 .42736 Mdot
.41636 .4197 Mdot
.65819 .40512 Mdot
.62344 .4053 Mdot
.65172 .37204 Mdot
.53074 .60925 Mdot
.41741 .45416 Mdot
.35509 .63084 Mdot
.49195 .64409 Mdot
.62888 .37115 Mdot
.66877 .36277 Mdot
.68227 .67831 Mdot
.3785 .39706 Mdot
.48696 .54486 Mdot
.73718 .21156 Mdot
.56562 .27161 Mdot
.72849 .65974 Mdot
.67856 .49333 Mdot
.56406 .35781 Mdot
.73679 .53316 Mdot
.53641 .63242 Mdot
.53259 .23445 Mdot
.66958 .41808 Mdot
.38154 .36852 Mdot
.46371 .41455 Mdot
.40581 .46814 Mdot
.64798 .39203 Mdot
.61719 .31172 Mdot
.37486 .64686 Mdot
.2167 .51901 Mdot
.64153 .39173 Mdot
.69319 .55388 Mdot
.6989 .52163 Mdot
.65067 .50133 Mdot
.45936 .38806 Mdot
.2534 .58603 Mdot
.2432 .45597 Mdot
.21077 .42814 Mdot
.4894 .64596 Mdot
.35785 .65731 Mdot
.67335 .29412 Mdot
.35378 .62118 Mdot
.68481 .55243 Mdot
.65117 .39448 Mdot
.35309 .58991 Mdot
.51996 .6221 Mdot
.52302 .64663 Mdot
.66389 .49498 Mdot
.66895 .50491 Mdot
.68216 .53581 Mdot
.33806 .58574 Mdot
.33754 .63466 Mdot
.44489 .41422 Mdot
.36623 .6115 Mdot
.3871 .79006 Mdot
.66707 .35465 Mdot
.70066 .53713 Mdot
.53312 .63654 Mdot
.37879 .62582 Mdot
.42767 .39323 Mdot
.77008 .42931 Mdot
.4419 .66196 Mdot
.62787 .39263 Mdot
.74478 .58073 Mdot
.43016 .88459 Mdot
.40788 .35979 Mdot
.54839 .64904 Mdot
.57853 .77683 Mdot
.41505 .38103 Mdot
.65592 .51545 Mdot
.17096 .51115 Mdot
.70922 .63269 Mdot
.37754 .42798 Mdot
.4521 .40931 Mdot
.52902 .67246 Mdot
.60837 .34787 Mdot
.44743 .41944 Mdot
.38742 .75933 Mdot
.50538 .67567 Mdot
.64435 .55043 Mdot
.84002 .41499 Mdot
.61972 .49708 Mdot
.50121 .33736 Mdot
.71554 .66084 Mdot
.42172 .36378 Mdot
.66826 .53853 Mdot
.62922 .39968 Mdot
.67738 .53602 Mdot
.39728 .60314 Mdot
.68337 .54079 Mdot
.41281 .40794 Mdot
.35145 .63169 Mdot
.53015 .63023 Mdot
.39438 .78372 Mdot
.66228 .68421 Mdot
.67362 .50644 Mdot
.69255 .63555 Mdot
.37502 .41459 Mdot
.38023 .30741 Mdot
.35325 .45211 Mdot
.37916 .41412 Mdot
.49836 .64362 Mdot
.36688 .63987 Mdot
.53476 .62095 Mdot
.35906 .38283 Mdot
.27237 .69554 Mdot
.53332 .66659 Mdot
.50078 .74673 Mdot
.66298 .39233 Mdot
.53124 .37714 Mdot
.43333 .39496 Mdot
.50909 .65043 Mdot
.41591 .45362 Mdot
.33081 .64264 Mdot
.5519 .54794 Mdot
.6558 .73978 Mdot
.51496 .65049 Mdot
.68083 .24502 Mdot
.53627 .55286 Mdot
.44348 .48126 Mdot
.50973 .65347 Mdot
.21331 .57504 Mdot
.72144 .6586 Mdot
.65349 .40072 Mdot
.62633 .37492 Mdot
.62631 .38763 Mdot
.45674 .41232 Mdot
.45709 .34213 Mdot
.66982 .3653 Mdot
.52234 .67802 Mdot
.65562 .41712 Mdot
.53384 .40991 Mdot
.67221 .24051 Mdot
.64274 .37252 Mdot
.42856 .40542 Mdot
.37268 .35019 Mdot
.5425 .32673 Mdot
.67402 .56034 Mdot
.49935 .17507 Mdot
.35278 .49806 Mdot
.38294 .39954 Mdot
.46958 .46309 Mdot
.39462 .61918 Mdot
.62083 .77375 Mdot
.48936 .44394 Mdot
.74013 .55478 Mdot
.33703 .64228 Mdot
.63283 .48116 Mdot
.38405 .62675 Mdot
.39216 .36696 Mdot
.39905 .4288 Mdot
.30814 .62422 Mdot
.5926 .63472 Mdot
.58179 .74145 Mdot
.78085 .34886 Mdot
.34784 .59461 Mdot
.52244 .65645 Mdot
.54408 .63218 Mdot
.49364 .65298 Mdot
.63117 .54338 Mdot
.36484 .57526 Mdot
.43174 .4522 Mdot
.64072 .52542 Mdot
.43591 .38631 Mdot
.50261 .63991 Mdot
.8169 .36656 Mdot
.35423 .59817 Mdot
.39493 .38372 Mdot
.67023 .7804 Mdot
.66429 .50868 Mdot
.64927 .40631 Mdot
.58024 .41299 Mdot
.62391 .51496 Mdot
.50283 .61932 Mdot
.31912 .64442 Mdot
.56623 .62298 Mdot
.50423 .49045 Mdot
.47614 .4344 Mdot
.40747 .34956 Mdot
.83215 .44509 Mdot
.70324 .7187 Mdot
.45964 .4006 Mdot
.64566 .53563 Mdot
.67089 .56457 Mdot
.42781 .42385 Mdot
.36544 .57897 Mdot
.64117 .36416 Mdot
.6413 .4171 Mdot
.35679 .43847 Mdot
.54631 .50454 Mdot
.54272 .39217 Mdot
.42253 .43565 Mdot
.40056 .32179 Mdot
.65666 .49068 Mdot
.72415 .63828 Mdot
.46901 .78268 Mdot
.6509 .36636 Mdot
.39977 .43511 Mdot
.49336 .72587 Mdot
.32972 .62521 Mdot
.68194 .5406 Mdot
.49611 .62553 Mdot
.63045 .31805 Mdot
.62858 .51218 Mdot
.4265 .42463 Mdot
.42675 .43024 Mdot
.52969 .67166 Mdot
.4018 .58629 Mdot
.65057 .3922 Mdot
.64158 .52313 Mdot
.65459 .36503 Mdot
.33986 .63101 Mdot
.35479 .60232 Mdot
.47636 .44116 Mdot
.37798 .33432 Mdot
.6649 .49771 Mdot
.35771 .42401 Mdot
.69089 .55033 Mdot
.62987 .33424 Mdot
.55685 .64145 Mdot
.41757 .35837 Mdot
.33076 .65444 Mdot
.50034 .6374 Mdot
.39875 .39518 Mdot
.85488 .50764 Mdot
.44319 .38706 Mdot
.62249 .5367 Mdot
.27624 .70549 Mdot
.65124 .41431 Mdot
.33707 .55316 Mdot
.32302 .40931 Mdot
.39374 .41416 Mdot
.6988 .53341 Mdot
.35254 .44791 Mdot
.53391 .66829 Mdot
.34515 .64334 Mdot
.55806 .86926 Mdot
.51641 .63466 Mdot
.39061 .42558 Mdot
.64329 .38299 Mdot
.33008 .65036 Mdot
.7042 .63849 Mdot
.48374 .79287 Mdot
.43563 .47495 Mdot
.45109 .36133 Mdot
.38837 .43709 Mdot
.21507 .37063 Mdot
.66635 .54197 Mdot
.37776 .62506 Mdot
.54275 .66079 Mdot
.51288 .62601 Mdot
.64997 .50512 Mdot
.43376 .73721 Mdot
.59327 .56315 Mdot
.6023 .1137 Mdot
.68317 .51002 Mdot
.66735 .41284 Mdot
.5521 .47331 Mdot
.69219 .54184 Mdot
.66009 .53379 Mdot
.65044 .49373 Mdot
.47159 .76606 Mdot
.37118 .59315 Mdot
.41541 .42108 Mdot
.35388 .56692 Mdot
.42413 .36469 Mdot
.43659 .29907 Mdot
.50067 .62901 Mdot
.34178 .64181 Mdot
.84681 .47267 Mdot
.4305 .51283 Mdot
.41585 .38911 Mdot
.69508 .30875 Mdot
.36595 .46722 Mdot
.59413 .31263 Mdot
.39577 .49079 Mdot
.67317 .51428 Mdot
.49153 .40179 Mdot
.38625 .3412 Mdot
.38443 .78584 Mdot
.53519 .6386 Mdot
.71701 .66329 Mdot
.45811 .44138 Mdot
.41536 .4758 Mdot
.32374 .63934 Mdot
.35225 .59014 Mdot
.66953 .36598 Mdot
.57883 .45591 Mdot
.53282 .6326 Mdot
.60706 .47523 Mdot
.38688 .40243 Mdot
.58165 .61299 Mdot
.27646 .63803 Mdot
.39847 .39356 Mdot
.57726 .20938 Mdot
.25095 .59366 Mdot
.44879 .41553 Mdot
.20065 .52872 Mdot
.52588 .64378 Mdot
.2899 .71085 Mdot
.36541 .43205 Mdot
.65737 .5163 Mdot
.34487 .64018 Mdot
.39467 .61544 Mdot
.63476 .37795 Mdot
.48678 .82572 Mdot
.49899 .61844 Mdot
.33896 .63799 Mdot
.41801 .37879 Mdot
.4938 .6289 Mdot
.70194 .6528 Mdot
.38456 .34423 Mdot
.51764 .22373 Mdot
.3641 .60883 Mdot
.37552 .44722 Mdot
.3753 .68862 Mdot
.5665 .41955 Mdot
.43517 .16699 Mdot
.4983 .6577 Mdot
.65173 .36866 Mdot
.41764 .49462 Mdot
.83406 .52867 Mdot
.41458 .46741 Mdot
.53911 .36822 Mdot
.42252 .62617 Mdot
.6667 .37057 Mdot
.40837 .38092 Mdot
.44346 .42468 Mdot
.53772 .50038 Mdot
.62092 .40275 Mdot
.4345 .37329 Mdot
.48396 .41249 Mdot
.37759 .59685 Mdot
.71622 .6656 Mdot
.36229 .6035 Mdot
.42779 .40175 Mdot
.46455 .34819 Mdot
.36627 .58464 Mdot
.77213 .38316 Mdot
.64315 .42355 Mdot
.51064 .6674 Mdot
.42518 .32543 Mdot
.39358 .45137 Mdot
.2257 .31841 Mdot
.72597 .66258 Mdot
.17519 .47872 Mdot
.64666 .48217 Mdot
.51208 .72245 Mdot
.67475 .46774 Mdot
.58521 .18343 Mdot
.40724 .7828 Mdot
.441 .46643 Mdot
.4831 .24943 Mdot
.20212 .48874 Mdot
.5174 .6157 Mdot
.26684 .37205 Mdot
.38463 .40269 Mdot
.40584 .3679 Mdot
.6525 .55178 Mdot
.41883 .74204 Mdot
.56909 .77648 Mdot
.55517 .51389 Mdot
.65375 .38931 Mdot
.33581 .62374 Mdot
.4047 .41082 Mdot
.6267 .58403 Mdot
.68799 .53401 Mdot
.54034 .58212 Mdot
.4003 .37984 Mdot
.56504 .79939 Mdot
.49065 .75593 Mdot
.49007 .63203 Mdot
.68739 .50436 Mdot
.62612 .51039 Mdot
.39288 .37031 Mdot
.5048 .62038 Mdot
.44635 .41395 Mdot
.55275 .56692 Mdot
.36437 .44004 Mdot
.6376 .38078 Mdot
.37018 .39915 Mdot
.50915 .5169 Mdot
.49866 .14755 Mdot
.46268 .48297 Mdot
.3768 .57839 Mdot
.62875 .53719 Mdot
.65471 .50036 Mdot
.35216 .59329 Mdot
.65504 .50196 Mdot
.2257 .5336 Mdot
.33017 .51308 Mdot
.65705 .38723 Mdot
.44831 .32981 Mdot
.63489 .3853 Mdot
.72008 .66367 Mdot
.38005 .39779 Mdot
.83894 .5484 Mdot
.67917 .50614 Mdot
.19825 .59729 Mdot
.52102 .63223 Mdot
.72149 .66303 Mdot
.41163 .46569 Mdot
.74515 .37951 Mdot
.67673 .55711 Mdot
.61913 .51527 Mdot
.44088 .41634 Mdot
.35964 .59025 Mdot
.44127 .42659 Mdot
.38547 .47864 Mdot
.72872 .64887 Mdot
.39122 .44307 Mdot
.53816 .65803 Mdot
.35363 .57627 Mdot
.62537 .21517 Mdot
.65029 .56259 Mdot
.37803 .38722 Mdot
.41676 .37852 Mdot
.33767 .64954 Mdot
.399 .46045 Mdot
.52395 .62235 Mdot
.3833 .11891 Mdot
.66287 .39368 Mdot
.71712 .63125 Mdot
.62133 .53823 Mdot
.45585 .43692 Mdot
.4281 .43418 Mdot
.83043 .4311 Mdot
.63308 .71759 Mdot
.53142 .66024 Mdot
.36365 .45914 Mdot
.64562 .52982 Mdot
.64408 .38101 Mdot
.50135 .67186 Mdot
.40581 .43973 Mdot
.39962 .37394 Mdot
.63967 .37908 Mdot
.61145 .22629 Mdot
.74143 .56224 Mdot
.49059 .64977 Mdot
.49296 .4028 Mdot
.77338 .4497 Mdot
.43472 .38933 Mdot
.79611 .44911 Mdot
.34738 .60139 Mdot
.50494 .65373 Mdot
.21063 .41044 Mdot
.37211 .37887 Mdot
.53173 .62647 Mdot
.53354 .63422 Mdot
.36449 .40747 Mdot
.34831 .56856 Mdot
.33668 .5919 Mdot
.33903 .60627 Mdot
.28348 .73187 Mdot
.474 .29252 Mdot
.68268 .53415 Mdot
.52625 .64495 Mdot
.69575 .55459 Mdot
.62742 .37051 Mdot
.56907 .44345 Mdot
.68507 .5601 Mdot
.39411 .61909 Mdot
.69955 .52241 Mdot
.44119 .42232 Mdot
.5316 .63022 Mdot
.66455 .54867 Mdot
.4605 .42518 Mdot
.33861 .33746 Mdot
.50463 .55314 Mdot
.64913 .36206 Mdot
.61056 .36155 Mdot
.40327 .42269 Mdot
.72848 .6559 Mdot
.38844 .38989 Mdot
.48472 .63845 Mdot
.51656 .49777 Mdot
.4577 .42905 Mdot
.66978 .50151 Mdot
.38528 .51279 Mdot
.6529 .55793 Mdot
.38573 .47383 Mdot
.42636 .40384 Mdot
.43045 .38023 Mdot
.44793 .41896 Mdot
.48438 .7454 Mdot
.52049 .61438 Mdot
.33937 .33188 Mdot
.7096 .53741 Mdot
.36301 .61861 Mdot
.3916 .63799 Mdot
.78195 .48289 Mdot
.72218 .6326 Mdot
.53542 .64603 Mdot
.43638 .39373 Mdot
.61761 .52231 Mdot
.81213 .35886 Mdot
.79401 .40972 Mdot
.69528 .3328 Mdot
.65068 .54189 Mdot
.37996 .58191 Mdot
.68389 .54685 Mdot
.40533 .36454 Mdot
.37241 .36575 Mdot
.59846 .19469 Mdot
.4627 .63782 Mdot
.65009 .39401 Mdot
.42956 .37654 Mdot
.49377 .33222 Mdot
.64492 .53007 Mdot
.65619 .48956 Mdot
.44046 .38522 Mdot
.34353 .58932 Mdot
.35507 .18681 Mdot
.49129 .62892 Mdot
.33815 .3132 Mdot
.38441 .53944 Mdot
.31284 .70985 Mdot
.5089 .62406 Mdot
.49026 .56497 Mdot
.63543 .51228 Mdot
.35477 .53466 Mdot
.35958 .61699 Mdot
.64671 .3952 Mdot
.37992 .35601 Mdot
.39324 .6187 Mdot
.65746 .48217 Mdot
.37849 .63571 Mdot
.388 .36719 Mdot
.52245 .6159 Mdot
.64369 .50647 Mdot
.54943 .67851 Mdot
.30747 .62619 Mdot
.63389 .40087 Mdot
.52985 .37869 Mdot
.28636 .35028 Mdot
.24947 .5945 Mdot
.4524 .43307 Mdot
.69949 .59028 Mdot
.42075 .45326 Mdot
.3228 .62852 Mdot
.43319 .39729 Mdot
.43116 .62324 Mdot
.67676 .49581 Mdot
.37471 .44618 Mdot
.37523 .42327 Mdot
.27596 .40713 Mdot
.40868 .38979 Mdot
.37915 .43922 Mdot
.45012 .41939 Mdot
.38888 .54212 Mdot
.46252 .45593 Mdot
.3665 .59105 Mdot
.50065 .77831 Mdot
.66215 .53331 Mdot
.65369 .36066 Mdot
.63019 .40846 Mdot
.54209 .37503 Mdot
.53052 .37125 Mdot
.43673 .74163 Mdot
.3681 .60039 Mdot
.5419 .65138 Mdot
.44648 .41276 Mdot
.23181 .3796 Mdot
.68302 .3541 Mdot
.63792 .50957 Mdot
.63595 .55376 Mdot
.37015 .33887 Mdot
.21727 .36463 Mdot
.38694 .45901 Mdot
.49007 .79927 Mdot
.357 .43544 Mdot
.4403 .37939 Mdot
.62481 .51923 Mdot
.55404 .40332 Mdot
.45283 .43255 Mdot
.32406 .64039 Mdot
.64529 .39923 Mdot
.47766 .47464 Mdot
.69988 .46519 Mdot
.52584 .57014 Mdot
.29787 .42213 Mdot
.42194 .45621 Mdot
.64203 .51724 Mdot
.391 .61662 Mdot
.45842 .78768 Mdot
.49305 .64573 Mdot
.44066 .76323 Mdot
.2566 .43508 Mdot
.74612 .34384 Mdot
.64823 .39734 Mdot
.60281 .22466 Mdot
.41229 .40861 Mdot
.62763 .53647 Mdot
.40091 .3588 Mdot
.80822 .3539 Mdot
.67473 .39808 Mdot
.39277 .57897 Mdot
.52524 .65666 Mdot
.32996 .64016 Mdot
.27224 .57023 Mdot
.46339 .58711 Mdot
.6591 .60828 Mdot
.68171 .5664 Mdot
.37414 .29665 Mdot
.35939 .63429 Mdot
.416 .43235 Mdot
.64947 .14268 Mdot
.34624 .60293 Mdot
.33931 .60038 Mdot
.6116 .3509 Mdot
.67891 .32632 Mdot
.34588 .41759 Mdot
.37444 .64039 Mdot
.70582 .53607 Mdot
.65632 .40997 Mdot
.444 .43432 Mdot
.44704 .42318 Mdot
.36014 .58756 Mdot
.6827 .5551 Mdot
.34846 .29676 Mdot
.67109 .50883 Mdot
.38055 .59876 Mdot
.66744 .51691 Mdot
.66018 .57583 Mdot
.65909 .54427 Mdot
.39267 .45305 Mdot
.43678 .39953 Mdot
.70626 .45309 Mdot
.3549 .60246 Mdot
.42863 .43834 Mdot
.4028 .43108 Mdot
.35771 .63183 Mdot
.67896 .47634 Mdot
.24441 .36079 Mdot
.38353 .41307 Mdot
.42675 .41407 Mdot
.66115 .36811 Mdot
.65559 .4719 Mdot
.75046 .59328 Mdot
.43748 .43714 Mdot
.65102 .41971 Mdot
.33664 .5861 Mdot
.39029 .3904 Mdot
.5361 .41403 Mdot
.67111 .57366 Mdot
.3692 .39422 Mdot
.70248 .63914 Mdot
.45138 .44272 Mdot
.37169 .18403 Mdot
.37541 .39428 Mdot
.3754 .62411 Mdot
.35459 .64064 Mdot
.59747 .37935 Mdot
.34534 .62091 Mdot
.71049 .66 Mdot
.50372 .63834 Mdot
.76225 .31589 Mdot
.70313 .65303 Mdot
.44621 .38642 Mdot
.65282 .79926 Mdot
.35772 .41184 Mdot
.45783 .44035 Mdot
.19605 .42328 Mdot
.7039 .65284 Mdot
.36674 .63712 Mdot
.58902 .64951 Mdot
.35477 .43137 Mdot
.49575 .62506 Mdot
.39824 .34532 Mdot
.36748 .40528 Mdot
.35285 .74138 Mdot
.25912 .65851 Mdot
.48456 .64596 Mdot
.4296 .49624 Mdot
.43691 .4377 Mdot
.69009 .70737 Mdot
.42308 .38836 Mdot
.63947 .37424 Mdot
.33791 .60437 Mdot
.69169 .52988 Mdot
.66536 .39576 Mdot
.3898 .40832 Mdot
.64537 .39098 Mdot
.68103 .5398 Mdot
.49955 .64704 Mdot
.3821 .38302 Mdot
.66503 .41944 Mdot
.65235 .38972 Mdot
.4211 .45014 Mdot
.34249 .6409 Mdot
.44094 .50503 Mdot
.39212 .39115 Mdot
.4194 .42896 Mdot
.35551 .59294 Mdot
.78892 .68683 Mdot
.39994 .36422 Mdot
.48892 .54715 Mdot
.39029 .57743 Mdot
.70224 .66105 Mdot
.67283 .5511 Mdot
.3661 .3938 Mdot
.49588 .63096 Mdot
.4992 .63282 Mdot
.68473 .49674 Mdot
.33027 .64366 Mdot
.67261 .55959 Mdot
.43632 .49874 Mdot
.38191 .33159 Mdot
.36109 .38566 Mdot
.53762 .86547 Mdot
.58339 .19278 Mdot
.36988 .57859 Mdot
.6332 .52696 Mdot
.55832 .51309 Mdot
.52932 .64854 Mdot
.69864 .5172 Mdot
.32294 .64632 Mdot
.3854 .59099 Mdot
.38361 .6342 Mdot
.66264 .37122 Mdot
.63137 .51096 Mdot
.39959 .58441 Mdot
.33944 .59509 Mdot
.44077 .41899 Mdot
.43492 .43853 Mdot
.38248 .66487 Mdot
.5551 .31685 Mdot
.63242 .39514 Mdot
.64775 .51213 Mdot
.18859 .33907 Mdot
.48464 .63958 Mdot
.278 .40741 Mdot
.45791 .43276 Mdot
.85668 .33896 Mdot
.38236 .45734 Mdot
.42022 .38124 Mdot
.34537 .57803 Mdot
.67856 .39892 Mdot
.63744 .39798 Mdot
.35786 .63532 Mdot
.31442 .64097 Mdot
.64425 .37035 Mdot
.64887 .26611 Mdot
.68283 .2426 Mdot
.44672 .77854 Mdot
.36905 .62626 Mdot
.29574 .34305 Mdot
.50421 .6194 Mdot
.30996 .6095 Mdot
.49116 .65812 Mdot
.65922 .53233 Mdot
.63942 .49902 Mdot
.52611 .67218 Mdot
.44106 .41359 Mdot
.67655 .5449 Mdot
.46272 .46016 Mdot
.66129 .25654 Mdot
.40497 .22898 Mdot
.61961 .70446 Mdot
.46368 .4211 Mdot
.55609 .7804 Mdot
.59355 .76031 Mdot
.39806 .4191 Mdot
.50654 .45874 Mdot
.64828 .39356 Mdot
.3327 .57346 Mdot
.52051 .62096 Mdot
.42201 .17118 Mdot
.43541 .39107 Mdot
.37719 .61647 Mdot
.5361 .64093 Mdot
.60308 .41501 Mdot
.38298 .75447 Mdot
.42757 .36878 Mdot
.5458 .10614 Mdot
.34609 .56323 Mdot
.69153 .52865 Mdot
.57367 .82997 Mdot
.3585 .566 Mdot
.6171 .3538 Mdot
.64623 .48857 Mdot
.79504 .38689 Mdot
.38308 .62337 Mdot
.66817 .48274 Mdot
.34018 .62808 Mdot
.63434 .38179 Mdot
.32027 .60592 Mdot
.64096 .51038 Mdot
.40739 .38446 Mdot
.65455 .50579 Mdot
.63165 .39589 Mdot
.63148 .54562 Mdot
.51261 .61949 Mdot
.72408 .66095 Mdot
.51534 .64372 Mdot
.57124 .42871 Mdot
.26406 .67729 Mdot
.51069 .66272 Mdot
.6153 .44419 Mdot
.46063 .40402 Mdot
.40481 .59086 Mdot
.68657 .51223 Mdot
.70884 .53575 Mdot
.56451 .46301 Mdot
.36146 .62302 Mdot
.64631 .50784 Mdot
.25095 .43346 Mdot
.73088 .75064 Mdot
.45252 .33974 Mdot
.47848 .27991 Mdot
.36032 .6303 Mdot
.66445 .48806 Mdot
.47253 .79368 Mdot
.38937 .63358 Mdot
.68336 .51122 Mdot
.51281 .65355 Mdot
.51184 .62524 Mdot
.4395 .38955 Mdot
.46722 .65015 Mdot
.69512 .52072 Mdot
.55489 .74364 Mdot
.32885 .62284 Mdot
.60134 .41513 Mdot
.63123 .37908 Mdot
.65774 .53647 Mdot
.3935 .33941 Mdot
.32953 .66316 Mdot
.68554 .5686 Mdot
.47646 .2306 Mdot
.17699 .36621 Mdot
.64927 .50741 Mdot
.33591 .60709 Mdot
.37537 .61153 Mdot
.36107 .4619 Mdot
.54603 .5008 Mdot
.66419 .55862 Mdot
.83203 .57512 Mdot
.53421 .35797 Mdot
.71701 .64492 Mdot
.71188 .71945 Mdot
.45406 .43212 Mdot
.41136 .45258 Mdot
.53064 .65061 Mdot
.41587 .39712 Mdot
.34022 .59063 Mdot
.43571 .4581 Mdot
.53875 .63054 Mdot
.63606 .51358 Mdot
.38114 .38786 Mdot
.64938 .41218 Mdot
.48082 .63273 Mdot
.51972 .6731 Mdot
.67014 .52958 Mdot
.37782 .63824 Mdot
.61068 .56389 Mdot
.66787 .50404 Mdot
.42656 .45573 Mdot
.70573 .64695 Mdot
.37572 .37788 Mdot
.58216 .23343 Mdot
.36496 .6498 Mdot
.68829 .54318 Mdot
.39471 .59958 Mdot
.51668 .64046 Mdot
.70143 .51303 Mdot
.42367 .39564 Mdot
.68145 .51174 Mdot
.7295 .50552 Mdot
.61973 .24644 Mdot
.32857 .64285 Mdot
.68255 .46516 Mdot
.33623 .60317 Mdot
.71712 .64336 Mdot
.57959 .25327 Mdot
.65625 .39707 Mdot
.64867 .53043 Mdot
.56436 .18491 Mdot
.67096 .50018 Mdot
.40752 .39162 Mdot
.39969 .40135 Mdot
.65294 .55106 Mdot
.66787 .40345 Mdot
.24842 .70559 Mdot
.4744 .56221 Mdot
.37299 .63489 Mdot
.36197 .52187 Mdot
.22397 .28809 Mdot
.50916 .67819 Mdot
.53307 .65397 Mdot
.38829 .46728 Mdot
.44684 .39468 Mdot
.51927 .67453 Mdot
.55392 .64639 Mdot
.6533 .36349 Mdot
.6465 .49651 Mdot
.38293 .55838 Mdot
.48841 .6666 Mdot
.34001 .44364 Mdot
.50664 .34489 Mdot
.351 .43248 Mdot
.47084 .37705 Mdot
.462 .38987 Mdot
.56985 .40868 Mdot
.55014 .64997 Mdot
.40537 .42301 Mdot
.45455 .46236 Mdot
.5133 .65711 Mdot
.63463 .38247 Mdot
.3066 .68049 Mdot
.6625 .51652 Mdot
.86376 .58032 Mdot
.37273 .39109 Mdot
.402 .38722 Mdot
.48931 .64534 Mdot
.71437 .70217 Mdot
.38351 .59376 Mdot
.36391 .64823 Mdot
.66797 .54273 Mdot
.56733 .46122 Mdot
.41019 .46243 Mdot
.40018 .42093 Mdot
.65084 .52436 Mdot
.72601 .65997 Mdot
.60176 .70416 Mdot
.41731 .4182 Mdot
.5323 .63832 Mdot
.6687 .58228 Mdot
.5513 .64851 Mdot
.40749 .35913 Mdot
.40718 .39397 Mdot
.3934 .45414 Mdot
.4474 .39467 Mdot
.50049 .66851 Mdot
.40653 .41818 Mdot
.38416 .33836 Mdot
.35845 .6458 Mdot
.40141 .45384 Mdot
.55011 .37838 Mdot
.42987 .40945 Mdot
.64164 .40841 Mdot
.67503 .59721 Mdot
.43116 .37988 Mdot
.39756 .45116 Mdot
.47895 .55918 Mdot
.40875 .37749 Mdot
.48566 .64216 Mdot
.36703 .61569 Mdot
.52598 .6454 Mdot
.54163 .66311 Mdot
.70283 .54719 Mdot
.65568 .36384 Mdot
.44063 .46303 Mdot
.62618 .39393 Mdot
.45641 .35844 Mdot
.38861 .36603 Mdot
.61748 .56335 Mdot
.49174 .79866 Mdot
.74031 .54099 Mdot
.42592 .39711 Mdot
.66435 .53893 Mdot
.69106 .53403 Mdot
.47984 .24275 Mdot
.44654 .47692 Mdot
.50723 .67312 Mdot
.50966 .65057 Mdot
.5753 .28621 Mdot
.35979 .74811 Mdot
.63497 .40197 Mdot
.57446 .51424 Mdot
.46285 .39698 Mdot
.41382 .42552 Mdot
.37971 .3473 Mdot
.68692 .55969 Mdot
.72725 .64248 Mdot
.63832 .50744 Mdot
.72301 .67406 Mdot
.54923 .64095 Mdot
.44281 .45073 Mdot
.41988 .21468 Mdot
.35964 .58393 Mdot
.36652 .61519 Mdot
.52308 .67682 Mdot
.66267 .56146 Mdot
.36355 .46862 Mdot
.56552 .87234 Mdot
.31706 .58876 Mdot
.677 .36668 Mdot
.39584 .42218 Mdot
.66953 .53378 Mdot
.35321 .58496 Mdot
.63913 .41877 Mdot
.38187 .42927 Mdot
.71048 .52065 Mdot
.43379 .40126 Mdot
.19952 .49104 Mdot
.35935 .64408 Mdot
.81119 .35126 Mdot
.34031 .6535 Mdot
.47979 .63252 Mdot
.52126 .66341 Mdot
.40057 .39502 Mdot
.55106 .85462 Mdot
.38329 .56973 Mdot
.49698 .67853 Mdot
.67769 .3956 Mdot
.71931 .6329 Mdot
.67627 .38172 Mdot
.69359 .5409 Mdot
.64735 .39916 Mdot
.65236 .49445 Mdot
.56547 .29183 Mdot
.33554 .56557 Mdot
.66402 .39491 Mdot
.67916 .68514 Mdot
.46912 .42931 Mdot
.62985 .37089 Mdot
.37982 .33668 Mdot
.36447 .5339 Mdot
.65371 .52318 Mdot
.6664 .40589 Mdot
.41903 .43187 Mdot
.4138 .18836 Mdot
.53082 .66564 Mdot
.50133 .6708 Mdot
.4718 .42763 Mdot
.64971 .49284 Mdot
.31326 .63263 Mdot
.50931 .48913 Mdot
.71233 .66794 Mdot
.40274 .42063 Mdot
.44625 .4481 Mdot
.38802 .64205 Mdot
.3536 .65849 Mdot
.40576 .39612 Mdot
.25022 .40501 Mdot
.40967 .41075 Mdot
.49979 .62664 Mdot
.38544 .59326 Mdot
.37239 .6125 Mdot
.69277 .51369 Mdot
.32596 .62753 Mdot
.47096 .37512 Mdot
.45543 .64901 Mdot
.35236 .41859 Mdot
.51399 .63568 Mdot
.50724 .51016 Mdot
.64068 .55641 Mdot
.46734 .1786 Mdot
.37853 .64797 Mdot
.39187 .44471 Mdot
.3293 .61566 Mdot
.6548 .37389 Mdot
.35656 .60444 Mdot
.37307 .57351 Mdot
.39065 .40057 Mdot
.4225 .36438 Mdot
.70692 .6549 Mdot
.55021 .49752 Mdot
.33234 .6328 Mdot
.40337 .41442 Mdot
.36003 .42376 Mdot
.37014 .42036 Mdot
.52399 .5352 Mdot
.37177 .57708 Mdot
.28529 .47652 Mdot
.49544 .21876 Mdot
.33659 .6374 Mdot
.3453 .20548 Mdot
.70742 .63504 Mdot
.72112 .63255 Mdot
.49091 .6716 Mdot
.41801 .41933 Mdot
.64077 .54493 Mdot
.40105 .36642 Mdot
.47593 .44677 Mdot
.39923 .3726 Mdot
.66328 .41392 Mdot
.44808 .46063 Mdot
.72054 .65058 Mdot
.66434 .50186 Mdot
.38232 .42165 Mdot
.38301 .38489 Mdot
.72166 .63057 Mdot
.36614 .65234 Mdot
.38928 .60455 Mdot
.79535 .43317 Mdot
.65545 .38 Mdot
.49649 .64393 Mdot
.44156 .40188 Mdot
.66488 .54051 Mdot
.6567 .50462 Mdot
.3273 .63295 Mdot
.65708 .51373 Mdot
.48769 .63242 Mdot
.42124 .39188 Mdot
.50504 .67181 Mdot
.656 .41588 Mdot
.34063 .60137 Mdot
.44089 .39732 Mdot
.44027 .41911 Mdot
.35505 .64066 Mdot
.46066 .40322 Mdot
.6606 .36787 Mdot
.66433 .49851 Mdot
.38704 .61491 Mdot
.50256 .63657 Mdot
.69686 .51995 Mdot
.43343 .42694 Mdot
.17287 .38631 Mdot
.41463 .40079 Mdot
.42527 .42332 Mdot
.64906 .22082 Mdot
.38683 .46921 Mdot
.68522 .50592 Mdot
.39622 .6326 Mdot
.45997 .3773 Mdot
.48371 .31782 Mdot
.82792 .48037 Mdot
.70092 .52005 Mdot
.38882 .42209 Mdot
.48684 .17248 Mdot
.38499 .42181 Mdot
.60489 .47748 Mdot
.76747 .52921 Mdot
.38951 .28156 Mdot
.46594 .36836 Mdot
.50625 .66842 Mdot
.70861 .65712 Mdot
.6683 .49257 Mdot
.22131 .57728 Mdot
.39496 .4066 Mdot
.20878 .571 Mdot
.372 .41446 Mdot
.51279 .62438 Mdot
.41453 .51405 Mdot
.6497 .51163 Mdot
.4471 .81522 Mdot
.4293 .45334 Mdot
.37377 .57901 Mdot
.70117 .53674 Mdot
.71511 .63265 Mdot
.42565 .42778 Mdot
.62973 .40518 Mdot
.53437 .68781 Mdot
.39128 .32656 Mdot
.51081 .63398 Mdot
.40224 .43275 Mdot
.44231 .48999 Mdot
.52162 .84158 Mdot
.36424 .64319 Mdot
.52824 .65527 Mdot
.62858 .76435 Mdot
.45766 .39386 Mdot
.38473 .62138 Mdot
.35997 .61793 Mdot
.63031 .38585 Mdot
.58268 .56802 Mdot
.39952 .68255 Mdot
.35898 .24558 Mdot
.27194 .60086 Mdot
.67978 .49546 Mdot
.59529 .74453 Mdot
.44201 .43712 Mdot
.47338 .58739 Mdot
.48782 .65144 Mdot
.40365 .38541 Mdot
.27207 .63041 Mdot
.34129 .6039 Mdot
.42154 .41293 Mdot
.63503 .38375 Mdot
.58839 .60685 Mdot
.52483 .57734 Mdot
.25706 .29376 Mdot
.70447 .5284 Mdot
.37686 .35538 Mdot
.45092 .35041 Mdot
.69621 .64764 Mdot
.39134 .36132 Mdot
.67801 .5002 Mdot
.6758 .28087 Mdot
.66976 .40247 Mdot
.34771 .5899 Mdot
.70831 .63459 Mdot
.46589 .39754 Mdot
.36436 .42589 Mdot
.65539 .36076 Mdot
.40704 .44398 Mdot
.49296 .82451 Mdot
.73749 .639 Mdot
.6707 .54724 Mdot
.38328 .63189 Mdot
.4581 .38592 Mdot
.72762 .64447 Mdot
.39398 .4009 Mdot
.30955 .41844 Mdot
.39799 .44691 Mdot
.36681 .69665 Mdot
.34369 .63945 Mdot
.51019 .6369 Mdot
.4706 .3859 Mdot
.41007 .36893 Mdot
.77156 .43918 Mdot
.47546 .44728 Mdot
.3749 .39326 Mdot
.32537 .64384 Mdot
.36491 .58039 Mdot
.36542 .59206 Mdot
.68464 .5399 Mdot
.45832 .77914 Mdot
.52649 .63794 Mdot
.42621 .46429 Mdot
.48833 .66632 Mdot
.31746 .41477 Mdot
.6658 .36171 Mdot
.35199 .22087 Mdot
.3869 .44051 Mdot
.36877 .59615 Mdot
.47322 .71789 Mdot
.33662 .58711 Mdot
.71173 .53414 Mdot
.53247 .63201 Mdot
.34337 .60469 Mdot
.41665 .37367 Mdot
.5456 .51296 Mdot
.27349 .29407 Mdot
.52284 .64873 Mdot
.36995 .3548 Mdot
.7048 .52234 Mdot
.64958 .56509 Mdot
.24372 .2513 Mdot
.53081 .66182 Mdot
.59994 .75683 Mdot
.39847 .41452 Mdot
.36114 .58448 Mdot
.50208 .66131 Mdot
.52064 .66932 Mdot
.6532 .51981 Mdot
.426 .36833 Mdot
.4286 .37908 Mdot
.70371 .63786 Mdot
.50587 .64776 Mdot
.47155 .41323 Mdot
.35623 .39903 Mdot
.60176 .19587 Mdot
.29897 .6673 Mdot
.81094 .66009 Mdot
.43728 .49842 Mdot
.26701 .60987 Mdot
.54873 .46547 Mdot
.36159 .5758 Mdot
.43114 .37673 Mdot
.4499 .37085 Mdot
.69087 .51156 Mdot
.41872 .39703 Mdot
.64069 .54946 Mdot
.53708 .65235 Mdot
.32795 .2259 Mdot
.45004 .66132 Mdot
.66297 .27986 Mdot
.41443 .39139 Mdot
.33466 .7249 Mdot
.66784 .38511 Mdot
.55143 .61686 Mdot
.38255 .59866 Mdot
.44374 .37255 Mdot
.62248 .52947 Mdot
.64781 .53075 Mdot
.35104 .61554 Mdot
.54639 .76319 Mdot
.79068 .44796 Mdot
.41401 .35753 Mdot
.67308 .5524 Mdot
.52496 .72091 Mdot
.24199 .41473 Mdot
.46891 .62892 Mdot
.67164 .40128 Mdot
.63734 .51193 Mdot
.54218 .6694 Mdot
.32731 .66829 Mdot
.34255 .61322 Mdot
.40027 .61796 Mdot
.74804 .47645 Mdot
.65762 .55827 Mdot
.66381 .40173 Mdot
.40762 .77441 Mdot
.39046 .77498 Mdot
.66706 .41026 Mdot
.63475 .51599 Mdot
.35916 .5816 Mdot
.38161 .60963 Mdot
.36792 .61611 Mdot
.43556 .81161 Mdot
.35379 .65034 Mdot
.30398 .46099 Mdot
.35875 .41263 Mdot
.41099 .31126 Mdot
.38591 .42071 Mdot
.49031 .6598 Mdot
.35943 .64347 Mdot
.55713 .46708 Mdot
.45275 .39648 Mdot
.26954 .28735 Mdot
.40097 .4232 Mdot
.47305 .62286 Mdot
.42179 .41716 Mdot
.27836 .37294 Mdot
.3879 .57535 Mdot
.42437 .39907 Mdot
.52833 .61416 Mdot
.65022 .38699 Mdot
.40671 .57736 Mdot
.43021 .37892 Mdot
.3987 .73786 Mdot
.40398 .47076 Mdot
.67276 .27264 Mdot
.58503 .36487 Mdot
.68002 .36931 Mdot
.48308 .42276 Mdot
.6727 .48795 Mdot
.41929 .59846 Mdot
.47306 .34902 Mdot
.52082 .64835 Mdot
.19545 .58187 Mdot
.65084 .53457 Mdot
.42129 .51461 Mdot
.3656 .46176 Mdot
.65156 .3651 Mdot
.38213 .65637 Mdot
.48808 .64715 Mdot
.46106 .42834 Mdot
.3653 .4114 Mdot
.64348 .27403 Mdot
.45999 .33806 Mdot
.39909 .46175 Mdot
.64104 .36314 Mdot
.2923 .48284 Mdot
.43377 .41278 Mdot
.68445 .48104 Mdot
.39906 .61135 Mdot
.47141 .43629 Mdot
.28265 .47078 Mdot
.40246 .41313 Mdot
.34872 .60548 Mdot
.39629 .63632 Mdot
.43746 .7161 Mdot
.68093 .38703 Mdot
.39799 .44674 Mdot
.63315 .32309 Mdot
.41933 .45467 Mdot
.52843 .63527 Mdot
.39745 .36495 Mdot
.65469 .53063 Mdot
.48316 .80056 Mdot
.6852 .52574 Mdot
.40348 .36385 Mdot
.3706 .61876 Mdot
.49923 .66272 Mdot
.71977 .46593 Mdot
.77508 .50955 Mdot
.30323 .46514 Mdot
.85088 .48377 Mdot
.6723 .38515 Mdot
.62071 .38878 Mdot
.48945 .62103 Mdot
.42707 .40104 Mdot
.59706 .36474 Mdot
.36834 .45196 Mdot
.42694 .41521 Mdot
.39694 .37374 Mdot
.47156 .66188 Mdot
.53137 .64584 Mdot
.66305 .51055 Mdot
.40766 .39639 Mdot
.40491 .41479 Mdot
.33373 .62595 Mdot
.65219 .38735 Mdot
.6876 .52749 Mdot
.66019 .38633 Mdot
.67652 .52264 Mdot
.36739 .18561 Mdot
.35344 .39443 Mdot
.64904 .38497 Mdot
.4878 .62124 Mdot
.3556 .59228 Mdot
.73171 .65927 Mdot
.6959 .53811 Mdot
.64715 .51082 Mdot
.40182 .41975 Mdot
.35138 .59608 Mdot
.32953 .63184 Mdot
.65942 .37407 Mdot
.49961 .65357 Mdot
.40563 .36356 Mdot
.41004 .35729 Mdot
.43374 .25177 Mdot
.69375 .5528 Mdot
.24212 .44397 Mdot
.451 .73175 Mdot
.42773 .39933 Mdot
.36848 .64353 Mdot
.38417 .38858 Mdot
.47631 .18963 Mdot
.39392 .61857 Mdot
.43958 .37903 Mdot
.34919 .74787 Mdot
.67907 .56439 Mdot
.38888 .70749 Mdot
.37956 .44788 Mdot
.82858 .4238 Mdot
.43351 .44508 Mdot
.5723 .16619 Mdot
.66009 .7167 Mdot
.43378 .45831 Mdot
.4421 .4291 Mdot
.34534 .25798 Mdot
.39217 .41338 Mdot
.72008 .64423 Mdot
.45453 .48953 Mdot
.38603 .59147 Mdot
.55157 .43384 Mdot
.7022 .49764 Mdot
.67503 .40279 Mdot
.66815 .54303 Mdot
.70968 .48906 Mdot
.63794 .37893 Mdot
.36842 .62786 Mdot
.44844 .42108 Mdot
.52718 .37327 Mdot
.70416 .55674 Mdot
.3821 .47446 Mdot
.52823 .63354 Mdot
.66282 .46289 Mdot
.63289 .54013 Mdot
.50568 .63882 Mdot
.37497 .42518 Mdot
.26106 .33607 Mdot
.76394 .54691 Mdot
.77847 .32573 Mdot
.49041 .64915 Mdot
.51219 .62287 Mdot
.461 .79311 Mdot
.67182 .40783 Mdot
.57555 .23908 Mdot
.33715 .71019 Mdot
.49409 .62454 Mdot
.60486 .28554 Mdot
.64871 .49135 Mdot
.38769 .73712 Mdot
.33225 .57392 Mdot
.3638 .37337 Mdot
.41487 .37185 Mdot
.50325 .65518 Mdot
.52376 .38871 Mdot
.55103 .82726 Mdot
.51569 .64479 Mdot
.43415 .34144 Mdot
.58635 .57889 Mdot
.7068 .64287 Mdot
.69966 .64178 Mdot
.67946 .37546 Mdot
.77766 .39626 Mdot
.34305 .63229 Mdot
.64621 .36641 Mdot
.56801 .58934 Mdot
.39761 .44301 Mdot
.51269 .64932 Mdot
.73306 .65215 Mdot
.50424 .62882 Mdot
.63625 .3916 Mdot
.67657 .36681 Mdot
.36038 .64541 Mdot
.3839 .59482 Mdot
.263 .61162 Mdot
.58261 .30936 Mdot
.38379 .42182 Mdot
.18979 .45777 Mdot
.32821 .62355 Mdot
.48509 .37355 Mdot
.65219 .41937 Mdot
.65185 .38351 Mdot
.20645 .49679 Mdot
.44639 .40693 Mdot
.60695 .41228 Mdot
.43809 .39684 Mdot
.55725 .24811 Mdot
.40905 .35479 Mdot
.65551 .5178 Mdot
.44759 .4434 Mdot
.60205 .55293 Mdot
.4543 .42393 Mdot
.37465 .38986 Mdot
.64231 .50076 Mdot
.36253 .35584 Mdot
.65308 .53027 Mdot
.41358 .36072 Mdot
.61586 .39621 Mdot
.66541 .54078 Mdot
.4908 .29385 Mdot
.48998 .54771 Mdot
.72636 .6527 Mdot
.63504 .40674 Mdot
.62866 .38229 Mdot
.53479 .37118 Mdot
.38405 .6014 Mdot
.3004 .64817 Mdot
.42647 .40263 Mdot
.65684 .4895 Mdot
.53255 .65029 Mdot
.40616 .41344 Mdot
.42538 .35519 Mdot
.38771 .4552 Mdot
.33492 .6121 Mdot
.66029 .56053 Mdot
.64511 .38733 Mdot
.6774 .54943 Mdot
.77351 .4169 Mdot
.62804 .51314 Mdot
.45716 .46138 Mdot
.41612 .34831 Mdot
.3147 .34595 Mdot
.20047 .57156 Mdot
.31784 .73909 Mdot
.34501 .61667 Mdot
.71558 .65751 Mdot
.67333 .36531 Mdot
.37167 .51848 Mdot
.37542 .595 Mdot
.6399 .51467 Mdot
.43386 .40086 Mdot
.40906 .33653 Mdot
.49505 .59179 Mdot
.42386 .61013 Mdot
.53569 .34963 Mdot
.62774 .53179 Mdot
.71416 .64331 Mdot
.45583 .78136 Mdot
.38184 .53249 Mdot
.564 .45373 Mdot
.39589 .38019 Mdot
.63181 .40848 Mdot
.35314 .58503 Mdot
.74382 .49891 Mdot
.50713 .65275 Mdot
.54744 .50024 Mdot
.41546 .39215 Mdot
.52631 .74221 Mdot
.36927 .61929 Mdot
.63319 .38962 Mdot
.50444 .65546 Mdot
.67633 .40228 Mdot
.69915 .64042 Mdot
.78359 .38833 Mdot
.41532 .45023 Mdot
.37544 .39846 Mdot
.47274 .6342 Mdot
.34322 .62991 Mdot
.6066 .37101 Mdot
.63066 .26195 Mdot
.66535 .55253 Mdot
.61837 .42646 Mdot
.34931 .57779 Mdot
.2944 .40465 Mdot
.68022 .54631 Mdot
.52348 .67701 Mdot
.56564 .41495 Mdot
.5421 .63266 Mdot
.43466 .38518 Mdot
.37016 .60348 Mdot
.53696 .65942 Mdot
.76345 .43799 Mdot
.48227 .15997 Mdot
.29448 .36035 Mdot
.42453 .45874 Mdot
.34269 .22482 Mdot
.66129 .24639 Mdot
.52464 .42538 Mdot
.51447 .6191 Mdot
.39269 .39365 Mdot
.38871 .36015 Mdot
.43479 .45168 Mdot
.54346 .65134 Mdot
.73163 .37157 Mdot
.6451 .51742 Mdot
.39596 .42606 Mdot
.63529 .37523 Mdot
.66085 .52754 Mdot
.61474 .55128 Mdot
.66741 .49474 Mdot
.38629 .58627 Mdot
.4453 .3891 Mdot
.45704 .76344 Mdot
.52596 .14035 Mdot
.52527 .64612 Mdot
.72609 .65244 Mdot
.37221 .40546 Mdot
.28269 .69882 Mdot
.36635 .59269 Mdot
.66266 .55255 Mdot
.40141 .38659 Mdot
.75017 .39901 Mdot
.73443 .6754 Mdot
.65679 .49719 Mdot
.38308 .60779 Mdot
.52097 .44151 Mdot
.4183 .39878 Mdot
.4288 .44672 Mdot
.35041 .63278 Mdot
.79596 .41735 Mdot
.48375 .79624 Mdot
.38333 .38625 Mdot
.50919 .63773 Mdot
.67122 .80711 Mdot
.37802 .44328 Mdot
.3511 .67121 Mdot
.71829 .63195 Mdot
.41539 .7351 Mdot
.23908 .44987 Mdot
.48159 .4368 Mdot
.37211 .22626 Mdot
.55185 .40479 Mdot
.33759 .21821 Mdot
.66325 .33609 Mdot
.63018 .61283 Mdot
.38231 .17655 Mdot
.51798 .61089 Mdot
.40053 .31103 Mdot
.37246 .27496 Mdot
.52672 .77274 Mdot
.54083 .43955 Mdot
.82188 .52907 Mdot
.77651 .46771 Mdot
.68224 .63532 Mdot
.67829 .50569 Mdot
.5334 .23983 Mdot
.39781 .3676 Mdot
.66961 .24879 Mdot
.25813 .40107 Mdot
.54257 .83704 Mdot
.35881 .20908 Mdot
.635 .32093 Mdot
.28141 .29504 Mdot
.49862 .17577 Mdot
.33728 .30042 Mdot
.43596 .63537 Mdot
.80811 .62881 Mdot
.40784 .77793 Mdot
.67263 .31001 Mdot
.39185 .4929 Mdot
.6124 .57546 Mdot
.71248 .30878 Mdot
.31948 .5063 Mdot
.58279 .8404 Mdot
.69465 .52637 Mdot
.39842 .59827 Mdot
.41983 .25036 Mdot
.41454 .59359 Mdot
.50362 .7009 Mdot
.36954 .22691 Mdot
.56688 .17173 Mdot
.27576 .37768 Mdot
.83945 .43904 Mdot
.22121 .5553 Mdot
.27091 .73346 Mdot
.51684 .55259 Mdot
.40332 .61156 Mdot
.78156 .6297 Mdot
.38838 .77397 Mdot
.44131 .67022 Mdot
.3679 .51019 Mdot
.67263 .352 Mdot
.52491 .31531 Mdot
.37655 .61758 Mdot
.23522 .44083 Mdot
.69724 .63307 Mdot
.402 .66867 Mdot
.63038 .57605 Mdot
.44936 .18478 Mdot
.67563 .60979 Mdot
.40436 .74721 Mdot
.58419 .73932 Mdot
.17378 .38066 Mdot
.61366 .3058 Mdot
.53338 .19274 Mdot
.48731 .59974 Mdot
.53778 .43522 Mdot
.54493 .80486 Mdot
.57684 .32804 Mdot
.37499 .76984 Mdot
.16656 .44384 Mdot
.71066 .27869 Mdot
.20283 .36148 Mdot
.4073 .63254 Mdot
.3928 .45733 Mdot
.47677 .20383 Mdot
.27491 .59653 Mdot
.67842 .36489 Mdot
.23517 .31686 Mdot
.64136 .4174 Mdot
.41577 .60923 Mdot
.54077 .76746 Mdot
.28937 .41844 Mdot
.62504 .44351 Mdot
.62631 .4203 Mdot
.44012 .46748 Mdot
.27751 .7865 Mdot
.32352 .23622 Mdot
.43067 .72024 Mdot
.60173 .19495 Mdot
.57599 .61085 Mdot
.59303 .39732 Mdot
.53981 .65137 Mdot
.44531 .16024 Mdot
.37775 .60346 Mdot
.4652 .13054 Mdot
.47655 .15355 Mdot
.65793 .77579 Mdot
.45053 .90494 Mdot
.62992 .67775 Mdot
.35656 .30846 Mdot
.49594 .3372 Mdot
.50012 .31926 Mdot
.5579 .81425 Mdot
.67787 .76147 Mdot
.58312 .62149 Mdot
.77804 .36057 Mdot
.40053 .17644 Mdot
.58638 .2708 Mdot
.70794 .32829 Mdot
.53811 .78349 Mdot
.50472 .53825 Mdot
.32361 .66038 Mdot
.46157 .54891 Mdot
.43296 .6352 Mdot
.22675 .33246 Mdot
.28172 .61562 Mdot
.58383 .86126 Mdot
.61304 .37138 Mdot
.70637 .71229 Mdot
.61067 .21236 Mdot
.49142 .28433 Mdot
.33085 .45863 Mdot
.4866 .76934 Mdot
.44297 .46769 Mdot
.46605 .78019 Mdot
.45314 .50507 Mdot
.69507 .47249 Mdot
.45079 .78505 Mdot
.54873 .71172 Mdot
.63374 .27095 Mdot
.39986 .23378 Mdot
.33951 .73462 Mdot
.39216 .60339 Mdot
.56798 .35692 Mdot
.61483 .29596 Mdot
.60567 .20061 Mdot
.62669 .76446 Mdot
.77043 .31417 Mdot
.64397 .76377 Mdot
.36861 .45054 Mdot
.47092 .35215 Mdot
.37949 .48564 Mdot
.59153 .32139 Mdot
.36699 .43881 Mdot
.53281 .73833 Mdot
.63228 .21211 Mdot
.2723 .63621 Mdot
.68735 .43451 Mdot
.17763 .54119 Mdot
.74939 .30256 Mdot
.48006 .20878 Mdot
.65362 .72446 Mdot
.46611 .33143 Mdot
.18889 .64851 Mdot
.66736 .52425 Mdot
.59807 .28257 Mdot
.55886 .65846 Mdot
.74628 .48297 Mdot
.3197 .29193 Mdot
.64201 .78645 Mdot
.63854 .21442 Mdot
.49498 .78139 Mdot
.7409 .56654 Mdot
.58662 .47718 Mdot
.62712 .45337 Mdot
.17684 .52133 Mdot
.41494 .34291 Mdot
.33831 .45606 Mdot
.62754 .37594 Mdot
.2892 .56901 Mdot
.51088 .21696 Mdot
.79002 .55455 Mdot
.4467 .3388 Mdot
.75709 .61918 Mdot
.71475 .6399 Mdot
.54715 .50679 Mdot
.27157 .23412 Mdot
.42613 .48008 Mdot
.63499 .69622 Mdot
.72242 .28846 Mdot
.57912 .38735 Mdot
.57691 .20655 Mdot
.49674 .74745 Mdot
.19312 .38528 Mdot
.51309 .15003 Mdot
.77979 .52623 Mdot
.30905 .23156 Mdot
.73374 .25718 Mdot
.18036 .41994 Mdot
.18767 .50659 Mdot
.54105 .61601 Mdot
.46415 .10032 Mdot
.6423 .53696 Mdot
.20944 .61198 Mdot
.27273 .6084 Mdot
.73632 .40443 Mdot
.31561 .6262 Mdot
.33909 .39816 Mdot
.68284 .61772 Mdot
.35288 .5607 Mdot
.46769 .45102 Mdot
.20022 .3366 Mdot
.15294 .49148 Mdot
.20663 .33549 Mdot
.76683 .33409 Mdot
.3169 .2268 Mdot
.40368 .27044 Mdot
.30731 .45946 Mdot
.48326 .23485 Mdot
.40354 .36136 Mdot
.5536 .27129 Mdot
.62931 .68703 Mdot
.75734 .54713 Mdot
.42493 .67154 Mdot
.32948 .58975 Mdot
.23161 .34607 Mdot
.20019 .28992 Mdot
.22344 .53324 Mdot
.26445 .48873 Mdot
.48977 .58121 Mdot
.592 .30628 Mdot
.41605 .52454 Mdot
.74619 .60365 Mdot
.61048 .20773 Mdot
.37295 .27333 Mdot
.62221 .28169 Mdot
.80043 .56094 Mdot
.60158 .49516 Mdot
.69887 .70518 Mdot
.45 .1778 Mdot
.44533 .26728 Mdot
.66602 .76229 Mdot
.43019 .30969 Mdot
.58518 .8208 Mdot
.80247 .49486 Mdot
.72391 .55112 Mdot
.63848 .29988 Mdot
.65265 .5647 Mdot
.57669 .26938 Mdot
.5722 .56926 Mdot
.43106 .23937 Mdot
.55018 .40203 Mdot
.57585 .26473 Mdot
.6004 .49831 Mdot
.25065 .28838 Mdot
.78203 .30268 Mdot
.15869 .54309 Mdot
.81977 .40757 Mdot
.46294 .50061 Mdot
.36242 .41426 Mdot
.67447 .23568 Mdot
.23206 .29604 Mdot
.5361 .14838 Mdot
.54188 .74523 Mdot
.75717 .42782 Mdot
.50166 .60927 Mdot
.16695 .55618 Mdot
.8143 .48033 Mdot
.54342 .17246 Mdot
.3203 .73852 Mdot
.49546 .67456 Mdot
.50345 .7916 Mdot
.18374 .57215 Mdot
.30156 .31267 Mdot
.22917 .47687 Mdot
.36229 .46135 Mdot
.26615 .37344 Mdot
.39801 .61775 Mdot
.57752 .74905 Mdot
.5836 .32192 Mdot
.66926 .52941 Mdot
.45998 .27951 Mdot
.33318 .44971 Mdot
.434 .47094 Mdot
.71349 .57384 Mdot
.30661 .63819 Mdot
.21636 .59945 Mdot
.57872 .64754 Mdot
.35881 .18348 Mdot
.62211 .71273 Mdot
.39055 .50688 Mdot
.58197 .3539 Mdot
.73866 .51499 Mdot
.47563 .7798 Mdot
.51382 .61511 Mdot
.38892 .19521 Mdot
.44725 .54112 Mdot
.57166 .35582 Mdot
.25972 .38188 Mdot
.60214 .24494 Mdot
.41179 .34903 Mdot
.459 .72386 Mdot
.33647 .50409 Mdot
.55405 .49722 Mdot
.40524 .58415 Mdot
.30495 .64069 Mdot
.87439 .46188 Mdot
.59755 .61005 Mdot
.66009 .74509 Mdot
.39823 .19476 Mdot
.542 .63747 Mdot
.32629 .60128 Mdot
.55658 .25964 Mdot
.64785 .2705 Mdot
.33067 .52584 Mdot
.62094 .508 Mdot
.69407 .37247 Mdot
.79767 .52929 Mdot
.34536 .22582 Mdot
.29994 .2701 Mdot
.53087 .8447 Mdot
.32411 .62934 Mdot
.57942 .23063 Mdot
.65275 .28042 Mdot
.33089 .6086 Mdot
.41699 .6316 Mdot
.37468 .68305 Mdot
.30524 .22246 Mdot
.45611 .77136 Mdot
.80953 .40124 Mdot
.56787 .40857 Mdot
.74235 .38224 Mdot
.73401 .49203 Mdot
.67255 .3179 Mdot
.40478 .19411 Mdot
.22976 .44255 Mdot
.29485 .30864 Mdot
.41421 .50118 Mdot
.25889 .64854 Mdot
.16804 .56583 Mdot
.5205 .54518 Mdot
.29118 .39804 Mdot
.53095 .71437 Mdot
.42063 .45688 Mdot
.17454 .37863 Mdot
.66478 .2578 Mdot
.43191 .79588 Mdot
.55849 .67588 Mdot
.426 .43406 Mdot
.35673 .42422 Mdot
.52218 .39558 Mdot
.42917 .72985 Mdot
.16103 .50175 Mdot
.67994 .31721 Mdot
.49754 .47008 Mdot
.25385 .39827 Mdot
.63505 .69858 Mdot
.44813 .18884 Mdot
.64096 .23516 Mdot
.56696 .54638 Mdot
.62631 .69321 Mdot
.58091 .44865 Mdot
.80516 .38126 Mdot
.67355 .60094 Mdot
.40522 .2653 Mdot
.31248 .69995 Mdot
.45744 .74587 Mdot
.74437 .51609 Mdot
.37024 .40025 Mdot
.54531 .76302 Mdot
.4885 .17922 Mdot
.5417 .86492 Mdot
.5602 .80352 Mdot
.1919 .33857 Mdot
.30354 .37419 Mdot
.45848 .7513 Mdot
.27922 .31214 Mdot
.51966 .87731 Mdot
.68893 .60104 Mdot
.25834 .30858 Mdot
.58517 .4663 Mdot
.37417 .20216 Mdot
.56009 .64542 Mdot
.38668 .75598 Mdot
.18068 .5503 Mdot
.31384 .21839 Mdot
.51157 .2005 Mdot
.41556 .1967 Mdot
.44851 .31541 Mdot
.27981 .24353 Mdot
.29499 .69447 Mdot
.68341 .64333 Mdot
.69878 .50975 Mdot
.54466 .7355 Mdot
.22569 .39324 Mdot
.44132 .61943 Mdot
.60943 .2834 Mdot
.69624 .68388 Mdot
.35294 .50701 Mdot
.27972 .33043 Mdot
.50853 .27505 Mdot
.47973 .7434 Mdot
.58077 .35872 Mdot
.52069 .16654 Mdot
.70454 .67406 Mdot
.71694 .46646 Mdot
.6346 .74053 Mdot
.78319 .38452 Mdot
.42491 .72664 Mdot
.60938 .62466 Mdot
.52935 .19121 Mdot
.8029 .45922 Mdot
.63278 .31644 Mdot
.89091 .44114 Mdot
.72406 .32681 Mdot
.40059 .66654 Mdot
.22154 .34922 Mdot
.62485 .21916 Mdot
.28862 .67188 Mdot
.52942 .83149 Mdot
.25566 .64243 Mdot
.56271 .29231 Mdot
.39979 .37189 Mdot
.2535 .25831 Mdot
.52532 .30624 Mdot
.22736 .32709 Mdot
.71264 .26276 Mdot
.265 .36637 Mdot
.41194 .47521 Mdot
.64354 .48334 Mdot
.51441 .56922 Mdot
.50444 .26778 Mdot
.30747 .28632 Mdot
.24623 .62969 Mdot
.6828 .46916 Mdot
.69935 .61003 Mdot
.62321 .50886 Mdot
.4995 .4398 Mdot
.61634 .69382 Mdot
.45324 .73611 Mdot
.60927 .40494 Mdot
.59322 .56766 Mdot
.59873 .29757 Mdot
.24067 .44286 Mdot
.30535 .31027 Mdot
.61824 .80047 Mdot
.51434 .70687 Mdot
.69051 .51268 Mdot
.36006 .24969 Mdot
.73313 .3267 Mdot
.51044 .73194 Mdot
.18756 .42409 Mdot
.49273 .77146 Mdot
.51684 .24324 Mdot
.47211 .22157 Mdot
.5772 .81248 Mdot
.83073 .58625 Mdot
.20765 .40403 Mdot
.25905 .65274 Mdot
.61349 .42471 Mdot
.31942 .36631 Mdot
.36709 .18663 Mdot
.65505 .30453 Mdot
.44455 .22855 Mdot
.49445 .55133 Mdot
.30627 .53797 Mdot
.25759 .36252 Mdot
.47903 .29583 Mdot
.56451 .46678 Mdot
.23047 .70688 Mdot
.318 .60112 Mdot
.16752 .38877 Mdot
.49949 .64299 Mdot
.40219 .80834 Mdot
.60949 .49665 Mdot
.55657 .55687 Mdot
.55845 .44626 Mdot
.45243 .7191 Mdot
.36304 .69738 Mdot
.77234 .34534 Mdot
.61585 .81124 Mdot
.63088 .50789 Mdot
.61372 .34307 Mdot
.81025 .42461 Mdot
.35918 .242 Mdot
.46898 .41783 Mdot
.74661 .34233 Mdot
.51705 .54253 Mdot
.75573 .54666 Mdot
.67772 .24124 Mdot
.49457 .70811 Mdot
.45318 .35451 Mdot
.58963 .30925 Mdot
.25555 .31437 Mdot
.49285 .15403 Mdot
.49132 .81752 Mdot
.45432 .50441 Mdot
.52272 .60835 Mdot
.40782 .28433 Mdot
.34637 .23409 Mdot
.59826 .4236 Mdot
.41097 .75522 Mdot
.61873 .30075 Mdot
.12787 .48285 Mdot
.15847 .47276 Mdot
.16199 .50482 Mdot
.58554 .37566 Mdot
.38716 .5654 Mdot
.27759 .67652 Mdot
.45103 .22761 Mdot
.48238 .71271 Mdot
.71773 .30603 Mdot
.60117 .28683 Mdot
.46565 .85904 Mdot
.33395 .46903 Mdot
.77338 .41349 Mdot
.24561 .37563 Mdot
.27084 .58469 Mdot
.55435 .63152 Mdot
.54889 .29117 Mdot
.43473 .53112 Mdot
.47971 .6317 Mdot
.47367 .74144 Mdot
.39191 .73256 Mdot
.44069 .22952 Mdot
.32704 .50017 Mdot
.47924 .48626 Mdot
.39479 .23 Mdot
.36419 .55733 Mdot
.7414 .49476 Mdot
.72321 .4811 Mdot
.51956 .47715 Mdot
.65884 .54836 Mdot
.48 .4434 Mdot
.56171 .50852 Mdot
.57719 .46748 Mdot
.20418 .63094 Mdot
.63383 .41291 Mdot
.34909 .56961 Mdot
.39262 .79224 Mdot
.3328 .60275 Mdot
.2195 .29901 Mdot
.74159 .60696 Mdot
.26078 .3865 Mdot
.78354 .50902 Mdot
.78583 .60279 Mdot
.29944 .78013 Mdot
.17941 .48489 Mdot
.46945 .56144 Mdot
.41325 .57205 Mdot
.34777 .65269 Mdot
.65455 .45647 Mdot
.6944 .61981 Mdot
.23692 .48029 Mdot
.64054 .68007 Mdot
.50004 .2364 Mdot
.40523 .6218 Mdot
.75466 .38508 Mdot
.41083 .51935 Mdot
.32109 .20809 Mdot
.68205 .5064 Mdot
.1626 .60969 Mdot
.36798 .35219 Mdot
.34056 .29105 Mdot
.66491 .2261 Mdot
.4935 .80691 Mdot
.73447 .55743 Mdot
.83594 .52829 Mdot
.44806 .45048 Mdot
.48053 .4823 Mdot
.3786 .61815 Mdot
.55145 .23304 Mdot
.65057 .39804 Mdot
.5483 .35325 Mdot
.48183 .66117 Mdot
.69112 .74302 Mdot
.61174 .70444 Mdot
.37217 .56543 Mdot
.42058 .54015 Mdot
.51101 .20801 Mdot
.36344 .73131 Mdot
.51681 .54078 Mdot
.34793 .25633 Mdot
.32796 .5224 Mdot
.40353 .6276 Mdot
.18072 .4412 Mdot
.65241 .28471 Mdot
.45621 .15182 Mdot
.33067 .38904 Mdot
.52138 .56095 Mdot
.3503 .73226 Mdot
.47289 .73227 Mdot
.2389 .46036 Mdot
.60554 .20541 Mdot
.57317 .34312 Mdot
.38397 .76666 Mdot
.57222 .2642 Mdot
.34717 .38775 Mdot
.65023 .60324 Mdot
.57456 .72966 Mdot
.43 .84593 Mdot
.19697 .52576 Mdot
.52433 .80536 Mdot
.43087 .6186 Mdot
.63419 .69493 Mdot
.33479 .57697 Mdot
.71573 .42703 Mdot
.32158 .51604 Mdot
.71759 .60051 Mdot
.40853 .16422 Mdot
.61477 .20802 Mdot
.46814 .60472 Mdot
.63128 .56703 Mdot
.54356 .41816 Mdot
.38203 .49862 Mdot
.53561 .49832 Mdot
.43078 .46074 Mdot
.51066 .41369 Mdot
.47897 .81054 Mdot
.4749 .71796 Mdot
.34008 .41025 Mdot
.35046 .20456 Mdot
.46771 .14808 Mdot
.27057 .25783 Mdot
.62541 .43413 Mdot
.37134 .57308 Mdot
.18342 .40013 Mdot
.26211 .44918 Mdot
.51926 .16442 Mdot
.20651 .42424 Mdot
.86955 .44059 Mdot
.30326 .29553 Mdot
.54401 .7101 Mdot
.66601 .771 Mdot
.39315 .69308 Mdot
.68522 .25277 Mdot
.68541 .65052 Mdot
.68368 .42935 Mdot
.69381 .25812 Mdot
.27095 .77716 Mdot
.18986 .52166 Mdot
.39866 .74148 Mdot
.34675 .30597 Mdot
.50728 .48189 Mdot
.6462 .66408 Mdot
.39002 .36947 Mdot
.69408 .56377 Mdot
.74143 .55485 Mdot
.60405 .29402 Mdot
.3166 .34961 Mdot
.64882 .67049 Mdot
.50301 .26391 Mdot
.54524 .23987 Mdot
.68029 .31201 Mdot
.31669 .28593 Mdot
.241 .47463 Mdot
.46023 .36203 Mdot
.38584 .55942 Mdot
.67946 .38205 Mdot
.70848 .48258 Mdot
.43248 .37167 Mdot
.72854 .56815 Mdot
.34794 .70921 Mdot
.19241 .34363 Mdot
.70305 .42613 Mdot
.65205 .26406 Mdot
.31168 .60119 Mdot
.44049 .72791 Mdot
.44835 .20368 Mdot
.53079 .77041 Mdot
.6588 .6787 Mdot
.28102 .61538 Mdot
.33449 .22775 Mdot
.47941 .7688 Mdot
.6125 .26653 Mdot
.24292 .6883 Mdot
.4805 .64665 Mdot
.22045 .59679 Mdot
.38517 .27097 Mdot
.51042 .76653 Mdot
.4039 .63513 Mdot
.56506 .69742 Mdot
.63724 .61043 Mdot
.49983 .75859 Mdot
.72568 .29004 Mdot
.5524 .22427 Mdot
.23607 .39374 Mdot
.3082 .25966 Mdot
.70416 .53844 Mdot
.6185 .2805 Mdot
.57646 .67627 Mdot
.64916 .64121 Mdot
.3519 .74059 Mdot
.35436 .19173 Mdot
.54387 .48748 Mdot
.51472 .30802 Mdot
.42297 .45072 Mdot
.28551 .47365 Mdot
.46239 .7154 Mdot
.59295 .51962 Mdot
.64174 .75108 Mdot
.39297 .61417 Mdot
.6025 .72895 Mdot
.72139 .67793 Mdot
.5532 .30284 Mdot
.40056 .54275 Mdot
.29636 .6632 Mdot
.68805 .36927 Mdot
.70932 .66874 Mdot
.4637 .38223 Mdot
.51888 .32136 Mdot
.62081 .45237 Mdot
.20501 .5678 Mdot
.18673 .52331 Mdot
.35428 .2502 Mdot
.67231 .27613 Mdot
.50265 .72758 Mdot
.20491 .42362 Mdot
.36985 .69353 Mdot
.30763 .44455 Mdot
.56996 .77294 Mdot
.38247 .45203 Mdot
.71775 .4245 Mdot
.33991 .5808 Mdot
.34496 .24434 Mdot
.30693 .40933 Mdot
.49114 .29238 Mdot
.5432 .53023 Mdot
.46776 .19896 Mdot
.49583 .53082 Mdot
.66805 .23045 Mdot
.39642 .69129 Mdot
.58187 .32342 Mdot
.54086 .68006 Mdot
.58901 .4626 Mdot
.57308 .80528 Mdot
.43866 .16853 Mdot
.62709 .79768 Mdot
.49885 .34225 Mdot
.51859 .79943 Mdot
.26312 .66198 Mdot
.70274 .25859 Mdot
.57316 .31286 Mdot
.5342 .5004 Mdot
.40864 .52079 Mdot
.50403 .59257 Mdot
.73149 .65838 Mdot
.72887 .43076 Mdot
.2523 .46734 Mdot
.7075 .35917 Mdot
.72439 .59308 Mdot
.47246 .41579 Mdot
.28617 .70852 Mdot
.31876 .24713 Mdot
.36159 .52121 Mdot
.54402 .55352 Mdot
.75854 .50835 Mdot
.54965 .31116 Mdot
.85754 .62111 Mdot
.17394 .37791 Mdot
.42099 .45029 Mdot
.55982 .42266 Mdot
.54944 .34419 Mdot
.63756 .5458 Mdot
.23803 .49171 Mdot
.35173 .24894 Mdot
.51303 .62161 Mdot
.75386 .43716 Mdot
.54992 .72687 Mdot
.44891 .71238 Mdot
.46579 .28863 Mdot
.46887 .65647 Mdot
.2069 .31661 Mdot
.75012 .33633 Mdot
.47744 .72614 Mdot
.87616 .54542 Mdot
.55481 .7447 Mdot
.31402 .58783 Mdot
.50483 .19573 Mdot
.25332 .28456 Mdot
.58078 .3828 Mdot
.74784 .47717 Mdot
.18569 .53473 Mdot
.57695 .33042 Mdot
.57215 .24992 Mdot
.63381 .73987 Mdot
.60875 .73264 Mdot
.67177 .6281 Mdot
.78699 .60007 Mdot
.22362 .64832 Mdot
.23826 .41702 Mdot
.28595 .27741 Mdot
.72881 .60887 Mdot
.47902 .86135 Mdot
.44469 .16048 Mdot
.54144 .27215 Mdot
.65293 .68848 Mdot
.52918 .19597 Mdot
.53703 .36189 Mdot
.28371 .62747 Mdot
.73892 .60191 Mdot
.31817 .54518 Mdot
.7752 .60525 Mdot
.59202 .77452 Mdot
.57608 .26734 Mdot
.26873 .60509 Mdot
.54919 .48028 Mdot
.33835 .27207 Mdot
.72742 .70309 Mdot
.59269 .34091 Mdot
.7614 .4503 Mdot
.50254 .33253 Mdot
.3747 .23321 Mdot
.51504 .18398 Mdot
.53321 .49049 Mdot
.26966 .77237 Mdot
.23415 .32671 Mdot
.54225 .77629 Mdot
.35949 .41509 Mdot
.40556 .16043 Mdot
.5128 .49398 Mdot
.19753 .43953 Mdot
.70731 .28438 Mdot
.7064 .46413 Mdot
.33702 .72215 Mdot
.39111 .45722 Mdot
.18356 .46692 Mdot
.28924 .38808 Mdot
.26753 .58775 Mdot
.74228 .5461 Mdot
.58103 .35241 Mdot
.7167 .70971 Mdot
.4707 .30384 Mdot
.36209 .4749 Mdot
.34737 .57768 Mdot
.21676 .31608 Mdot
.39526 .2979 Mdot
.48755 .42998 Mdot
.42227 .3131 Mdot
.62314 .8037 Mdot
.85407 .53694 Mdot
.36396 .47299 Mdot
.46911 .77463 Mdot
.61069 .28523 Mdot
.4799 .22855 Mdot
.18237 .50143 Mdot
.47976 .91842 Mdot
.65394 .21726 Mdot
.31377 .63676 Mdot
.22539 .59035 Mdot
.5919 .35944 Mdot
.27613 .25701 Mdot
.80077 .5564 Mdot
.73494 .50657 Mdot
.6222 .82004 Mdot
.55369 .37688 Mdot
.41753 .35536 Mdot
.75681 .31722 Mdot
.44698 .16481 Mdot
.72611 .7134 Mdot
.37138 .18624 Mdot
.39638 .47493 Mdot
.35627 .38968 Mdot
.68381 .826 Mdot
.36469 .21684 Mdot
.43217 .47418 Mdot
.59034 .82251 Mdot
.33815 .66452 Mdot
.4129 .36332 Mdot
.62913 .63807 Mdot
.64692 .30525 Mdot
.55653 .24518 Mdot
.31239 .21959 Mdot
.38987 .56994 Mdot
.72983 .56842 Mdot
.54461 .66866 Mdot
.56023 .45045 Mdot
.41605 .33723 Mdot
.54036 .65831 Mdot
.52699 .24463 Mdot
.5224 .48159 Mdot
.53731 .6865 Mdot
.67066 .3229 Mdot
.79391 .33339 Mdot
.3027 .35975 Mdot
.48762 .59164 Mdot
.48134 .34184 Mdot
.35497 .51805 Mdot
.50503 .26612 Mdot
.48 .24654 Mdot
.70638 .27205 Mdot
.73166 .2346 Mdot
.63195 .47301 Mdot
.34058 .3728 Mdot
.36581 .54678 Mdot
.24581 .46095 Mdot
.29161 .33432 Mdot
.55524 .6859 Mdot
.70398 .65458 Mdot
.38872 .46576 Mdot
.35914 .47112 Mdot
.48444 .66384 Mdot
.13811 .4325 Mdot
.37695 .37794 Mdot
.218 .45789 Mdot
.49863 .1692 Mdot
.74282 .49863 Mdot
.31423 .34244 Mdot
.45752 .44022 Mdot
.29193 .68482 Mdot
.50664 .49656 Mdot
.52338 .44674 Mdot
.72792 .48442 Mdot
.29033 .25416 Mdot
.30691 .40635 Mdot
.23071 .41182 Mdot
.40431 .42164 Mdot
.61988 .40883 Mdot
.38442 .73757 Mdot
.1709 .49349 Mdot
.36163 .493 Mdot
.51332 .15876 Mdot
.7042 .45869 Mdot
.696 .34959 Mdot
.33335 .31683 Mdot
.22129 .33083 Mdot
.55672 .80022 Mdot
.28047 .35058 Mdot
.4492 .80093 Mdot
.60271 .65347 Mdot
.51176 .27578 Mdot
.63705 .49057 Mdot
.33947 .4014 Mdot
.36068 .66397 Mdot
.24585 .25454 Mdot
.17372 .50558 Mdot
.56745 .61765 Mdot
.67742 .46639 Mdot
.2895 .43506 Mdot
.55561 .45461 Mdot
.88466 .50352 Mdot
.82205 .52334 Mdot
.20324 .321 Mdot
.53951 .22591 Mdot
.3494 .55023 Mdot
.48804 .74721 Mdot
.46665 .35399 Mdot
.65362 .50049 Mdot
.28069 .25639 Mdot
.33191 .42264 Mdot
.59324 .76709 Mdot
.4031 .35905 Mdot
.40717 .78621 Mdot
.46675 .51114 Mdot
.63757 .56854 Mdot
.66549 .57052 Mdot
.53663 .82662 Mdot
.48256 .185 Mdot
.50103 .50182 Mdot
.86622 .47273 Mdot
.29188 .29237 Mdot
.39139 .19416 Mdot
.62118 .50995 Mdot
.44678 .82978 Mdot
.4292 .59466 Mdot
.44838 .51772 Mdot
.57572 .63849 Mdot
.47061 .31953 Mdot
.50843 .76224 Mdot
.49714 .22855 Mdot
.37749 .71187 Mdot
.46844 .60686 Mdot
.83621 .311 Mdot
.54581 .26432 Mdot
.36921 .50948 Mdot
.55307 .75965 Mdot
.37602 .19195 Mdot
.66709 .43254 Mdot
.78034 .3303 Mdot
.60076 .56789 Mdot
.39275 .33873 Mdot
.32986 .49743 Mdot
.34468 .29264 Mdot
.5591 .72093 Mdot
.26156 .74165 Mdot
.72309 .31693 Mdot
.69822 .36793 Mdot
.59087 .56719 Mdot
.32929 .60975 Mdot
.31584 .6277 Mdot
.78698 .54138 Mdot
.82635 .38413 Mdot
.49327 .48569 Mdot
.34929 .23083 Mdot
.33876 .80451 Mdot
.58485 .24224 Mdot
.28523 .24371 Mdot
.44374 .63553 Mdot
.42129 .62719 Mdot
.50372 .26053 Mdot
.60771 .37727 Mdot
.66735 .56429 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`0009Cooooo0ol0000Pooooo`;o0000TOooool001cooooo00?o0000ooooooooool0
Toooool3o`00023ooooo0_l0002Aooooo`007?ooool00ol0003oooooooooo`2^ooooo`;o0000VOoo
ool001cooooo00?o0000ooooooooool0Woooool2o`0000Cooooo0_l00002ooooo`;o00000oooool2
o`0000?ooooo0_l0002Dooooo`007?ooool00ol0003oooooooooo`2Oooooo`;o00001?ooool2o`00
0004ooooool0003o0000o`0000Sooooo0_l0000;ooooo`;o0000Qoooool001cooooo00?o0000oooo
ooooool0Z?ooool2o`0001Kooooo0_l00027ooooo`007?ooool00ol0003oooooooooo`1iooooo`;o
0000c_ooool001cooooo00?o0000ooooooooool0NOooool2o`000<kooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`2Cooooo`;o0000]?ooool001cooooo00?o0000ooooooooool0Toooool2o`000;Co
oooo000Looooo`03o`000?oooooooooo09kooooo0_l0002Yooooo`007?ooool00ol0003ooooooooo
o`2Nooooo`;o00001oooool2o`000:3ooooo000Looooo`03o`000?oooooooooo0:Oooooo0_l0000V
ooooo`;o0000N?ooool001cooooo00?o0000ooooooooool0W_ooool2o`0002oooooo0_l0001hoooo
o`007?ooool00ol0003oooooooooo`2Dooooo`;o00002?ooool2o`0000?ooooo0_l00005ooooo`;o
0000WOooool001cooooo0_l0002Aooooo`;o00000_ooool2o`000003ooooool0003o000000[ooooo
0_l00005ooooo`;o0000WOooool001cooooo00?o0000ooooooooool0T?ooool2o`0000Gooooo0_l0
0003ooooo`;o00003oooool5o`0009Oooooo000Looooo`03o`000?oooooooooo09Wooooo0_l00000
0ooooooo0000o`000005ooooo`;o00002?ooool5o`0009Oooooo000Looooo`03o`000?oooooooooo
083ooooo0_l0000;ooooo`;o00002_ooool2o`0000Sooooo0_l0002Tooooo`007?ooool00ol0003o
ooooooooo`20ooooo`?o00002_ooool2o`0001Kooooo1?l0002Pooooo`007?ooool00ol0003ooooo
ooooo`21ooooo`;o00001oooool5o`0000oooooo0_l00005ooooo`Co00001oooool2o`0000Cooooo
0_l0000Sooooo`;o0000K?ooool001cooooo00?o0000ooooooooool0QOooool2o`0000?ooooo0ol0
0003ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00001?ooool2o`0000?ooooo2?l0
000Sooooo`;o0000K?ooool001cooooo00?o0000ooooooooool0QOooool2o`0000Kooooo1Ol00005
ooooo`;o000000?oooooo`000?l000000_ooool4o`0000?ooooo0_l00004ooooo`Co00000oooool4
o`0009?ooooo000Looooo`03o`000?oooooooooo07Sooooo0_l00004ooooo`;o00003Oooool5o`00
00Sooooo0_l00002ooooo`Co00000oooool4o`0000Cooooo0_l0000:ooooo`?o0000SOooool001co
oooo00?o0000ooooooooool0N?ooool2o`0000Cooooo0_l0000;ooooo`;o000000?oooooo`000?l0
00001?ooool2o`0000Gooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l0
00003Oooool2o`000004ooooool0003o0000o`0008gooooo000Looooo`03o`000?oooooooooo077o
oooo0_l00002ooooo`;o00004Oooool2o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o
00001Oooool2o`0000Oooooo0_l0000@ooooo`;o00000_ooool2o`0008gooooo000Looooo`03o`00
0?oooooooooo073ooooo0ol000001?oooooo0000o`000?l0000Aooooo`;o00001?ooool4o`0000Oo
oooo0_l00009ooooo`;o00003_ooool2o`0000;ooooo1?l0002=ooooo`007?ooool00ol0003ooooo
ooooo`1`ooooo`;o00000_ooool3o`0000cooooo0_l00009ooooo`?o00001_ooool6o`0001Oooooo
0_l00002ooooo`;o0000Soooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Co
oooo1Ol00006ooooo`03o`000?oooooooooo06oooooo0_l00005ooooo`;o00002oooool2o`0000;o
oooo0_l00005ooooo`;o00001oooool2o`0000;ooooo0_l0000;ooooo`?o00001?ooool2o`0000Wo
oooo0_l0002=ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnH
V9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0Koooool2o`0000;ooooo0_l00000
1?oooooo0000o`000?ooool4o`000003ooooool0003o000000;o000000?oooooo`000?l000000_oo
ool2o`0001Oooooo0_l00006ooooo`?o00001?ooool2o`0000Wooooo0_l00003ooooo`?o0000Qooo
ool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07
ooooo`03o`000?oooooooooo07?ooooo0_l00004ooooo`Co000000?oooooo`000?l000000_l00000
0ooooooo0000o`00000?ooooo`;o00002_ooool2o`0000Kooooo0_l0000@ooooo`;o00000oooool3
o`0008Oooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q
8Oo^k^h01_ooool3o`0007Kooooo0_l0000Booooo`;o00002?ooool2o`0000cooooo0_l0000Moooo
o`;o0000Q_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00omgMgOo
IVIVooooo`05ooooo`03o`000?oooooooooo06cooooo1?l00006ooooo`;o00004_ooool2o`0000;o
oooo0_l00004ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Gooooo0_l0000:ooooo`;o
00001Oooool2o`0000;ooooo0_l00005ooooo`?o0000Q_ooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06Gooooo
0_l00005ooooo`Co000000?oooooo`000?l000006oooool2o`0000Cooooo0_l000000ooooooo0000
o`000004o`0000Gooooo0_l0000:ooooo`;o00001Oooool2o`000004ooooool0003o0000o`0000;o
oooo0_l000000ooooooo0000o`000006o`0000Kooooo0_l0001iooooo`0000KoooooogMgMonHV9So
oooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`1U
ooooo`;o00002_ooool2o`0002Gooooo0ol00007ooooo`;o00001oooool2o`0000Kooooo0_l00003
ooooo`;o00000oooool2o`0000Cooooo1Ol00002ooooo`;o00000_ooool2o`0001cooooo0_l0001K
ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
1_ooool00ol0003oooooooooo`1_ooooo`;o00004oooool4o`0001oooooo0_l00002ooooo`;o0000
1_ooool2o`0000?ooooo0_l00003ooooo`;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000
o`000002o`0001kooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o00000_oo
ool2o`0000Kooooo0_l00003ooooo`;o00000_ooool2o`0000oooooo1?l0000Jooooo`;o00000ooo
ool2o`0001Cooooo0_l00008ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o0000M_oo
ool001cooooo00?o0000ooooooooool0G_ooool2o`0000;ooooo0_l00006ooooo`;o00000oooool2
o`0000;ooooo0_l0000Qooooo`;o00001Oooool2o`0000?ooooo1?l0000Qooooo`;o000000?ooooo
o`000?l000000oooool4o`0007Kooooo000Looooo`03o`000?oooooooooo05oooooo0_l000000ooo
oooo0000o`000004ooooo`;o00001Oooool2o`0001?ooooo0_l00006ooooo`;o00002?ooool2o`00
00Gooooo0_l00005ooooo`;o00002_ooool2o`0000_ooooo0_l000000ooooooo0000o`000005oooo
o`;o00001_ooool2o`0007Sooooo000Looooo`03o`000?oooooooooo05oooooo0_l00002ooooo`;o
00000_ooool4o`000003ooooool0003o000000Kooooo0ol0000=ooooo`;o00001_ooool2o`000003
ooooool0003o000001?ooooo0_l00005ooooo`;o00000oooool2o`0000;ooooo0_l00007ooooo`;o
000000Coooooo`000?l0003ooooo0_l00009ooooo`;o00001?ooool2o`0007?ooooo000Looooo`03
o`000?oooooooooo06?ooooo2?l000000ooooooo0000o`000002o`0000Cooooo0ol00006ooooo`;o
000000?oooooo`000?l000002Oooool7o`000003ooooool0003o000000;ooooo0ol00004ooooo`;o
00002oooool2o`0000Oooooo0_l00002ooooo`;o00002Oooool2o`0000Oooooo1Ol00003ooooo`?o
00000_ooool2o`0006kooooo000Looooo`03o`000?oooooooooo067ooooo0_l00002ooooo`;o0000
1oooool2o`0000Kooooo0_l00002ooooo`;o000000?oooooo`000?l000000ol00009ooooo`Co0000
00Coooooo`000?l0003ooooo1ol00004ooooo`;o00000oooool2o`0000Wooooo0ol00007ooooo`?o
00004Oooool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o0000K_ooool001cooooo
00?o0000ooooooooool0EOooool2o`0000[ooooo0_l00002ooooo`;o00001_ooool2o`0000Oooooo
0_l00002ooooo`;o00000_ooool2o`0000gooooo0_l00006ooooo`;o00000_ooool3o`0000?ooooo
0_l00002ooooo`;o00001?ooool2o`0000?ooooo0ol00003ooooo`;o00000oooool2o`00017ooooo
0_l00003ooooo`Co00000_ooool2o`00017ooooo0_l0001Mooooo`007?ooool00ol0003ooooooooo
o`1Eooooo`;o00003_ooool2o`0000Kooooo0_l0000Iooooo`;o00003oooool4o`0000;ooooo0_l0
0008ooooo`;o00000_ooool2o`0000Gooooo0_l000000ooooooo0000o`00000<ooooo`;o00001Ooo
ool2o`0000?ooooo1?l00002ooooo`;o00004Oooool2o`0000_ooooo0_l0001@ooooo`007?ooool0
0ol0003oooooooooo`1Iooooo`;o00005_ooool2o`00017ooooo0_l00002ooooo`;o000000?ooooo
o`000?l000002oooool2o`000003ooooool0003o000000cooooo0_l00002ooooo`;o00002?ooool2
o`000003ooooool0003o000000Wooooo0_l00002ooooo`;o00003?ooool5o`0001_ooooo0_l0001@
ooooo`007?ooool00ol0003oooooooooo`1?ooooo`;o00001_ooool4o`00017ooooo0_l00003oooo
o`;o00004Oooool2o`0000Gooooo0_l0000;ooooo`;o00002_ooool2o`000003ooooool0003o0000
00Sooooo0_l00007ooooo`;o00001?ooool2o`0000Oooooo0_l0000<ooooo`Go0000KOooool001co
oooo00?o0000ooooooooool0Coooool2o`0000Kooooo1?l00003ooooo`;o00001?ooool2o`0000Ko
oooo0_l000000ooooooo0000o`000004o`0001;ooooo0_l0000?ooooo`;o00000oooool2o`0000Go
oooo0_l000000ooooooo0000o`000008ooooo`Co00001oooool2o`000004ooooool0003o0000o`00
00Cooooo0_l00009ooooo`Co000000Coooooo`000?l0003ooooo0_l0001^ooooo`007?ooool2o`00
04cooooo0_l0000=ooooo`;o00000_ooool2o`0000Cooooo0_l00009ooooo`Ko00003Oooool2o`00
0003ooooool0003o000000Co00003Oooool3o`0000;ooooo0_l0000Booooo`Co000000?oooooo`00
0?l000001?ooool2o`000003ooooool0003o000000Gooooo0_l00009ooooo`Co000000?oooooo`00
0?l00000LOooool001cooooo00?o0000ooooooooool0Boooool3o`0000cooooo0ol0000Booooo`Co
00003oooool2o`000003ooooool0003o000000;ooooo0_l0000>ooooo`;o00006oooool4o`0000co
oooo0_l00006ooooo`;o00002oooool2o`0006cooooo000Looooo`03o`000?oooooooooo04cooooo
0_l000000ooooooo0000o`000003ooooo`Go00000_ooool2o`0000oooooo0ol00011ooooo`;o0000
1_ooool2o`0001Cooooo0_l00003ooooo`?o00001Oooool2o`000003ooooool0003o000000_ooooo
0_l0001Looooo`007?ooool00ol0003oooooooooo`1?ooooo`;o00000oooool5o`0000Oooooo0_l0
000:ooooo`?o0000:_ooool2o`0000Gooooo0_l0000:ooooo`;o00000_ooool3o`00023ooooo0ol0
0008ooooo`Co00002Oooool2o`0005cooooo000Looooo`03o`000?oooooooooo063ooooo0_l0000Y
ooooo`;o00003?ooool2o`0000Gooooo0_l0000:ooooo`Co000000?oooooo`000?l000000oooool3
o`00013ooooo0_l00005ooooo`?o00003Oooool2o`0000;ooooo0_l0001Sooooo`007?ooool00ol0
003oooooooooo`20ooooo`;o00002Oooool4o`00017ooooo0_l0000<ooooo`;o00001_ooool3o`00
00[ooooo0_l00002ooooo`Co00001?ooool4o`00017ooooo0_l0001Sooooo`007?ooool00ol0003o
ooooooooo`1Hooooo`;o00001?ooool2o`0001oooooo0ol0000;ooooo`;o00004Oooool3o`0001Co
oooo0ol000000ooooooo0000o`000006ooooo`;o00000_ooool2o`0000Kooooo0_l0001hooooo`00
7?ooool00ol0003oooooooooo`1Hooooo`;o00001?ooool2o`0000[ooooo0_l00009ooooo`;o0000
0_ooool2o`0000Cooooo0_l0000Aooooo`;o00000_ooool2o`0000Cooooo0_l00003ooooo`?o0000
2?ooool2o`000004ooooool0003o0000o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l0
00002Oooool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000000oooool2o`0000So
oooo0ol00003ooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0I?ooool2o`0000Cooooo
0_l00008ooooo`?o00000_ooool2o`000003ooooool0003o000000kooooo0_l00004ooooo`;o0000
0_ooool2o`0000Cooooo1?l000001?oooooo0000o`000?l00008ooooo`;o000000Coooooo`000?l0
003o00000_ooool2o`0000Wooooo0_l00005ooooo`;o00000_ooool2o`000003ooooool0003o0000
00?ooooo0_l00003ooooo`;o00002?ooool3o`0000?ooooo0_l0001Pooooo`007?ooool00ol0003o
ooooooooo`1Iooooo`;o00001?ooool2o`0000?ooooo0_l00008ooooo`;o00001?ooool3o`0000Go
oooo0_l0000<ooooo`Co00001?ooool2o`0000Cooooo0_l00004ooooo`;o000000Coooooo`000?l0
003o00005?ooool2o`0000Gooooo0_l00009ooooo`;o000000?oooooo`000?l000001Oooool2o`00
0003ooooool0003o000000;o00001_ooool4o`0006Cooooo000Looooo`03o`000?oooooooooo05Wo
oooo0_l00004ooooo`;o00003Oooool2o`0000_ooooo0_l0000=ooooo`;o00001_ooool2o`0000Co
oooo0_l0000Nooooo`;o00001?ooool2o`0000Gooooo0ol00002ooooo`;o000000Coooooo`000?l0
003ooooo0_l00002ooooo`;o00000_ooool3o`0000Sooooo0_l0001Tooooo`007?ooool00ol0003o
ooooooooo`1?ooooo`;o00004_ooool2o`0001?ooooo0_l000000ooooooo0000o`000004ooooo`;o
00005Oooool2o`0000;ooooo0_l00003ooooo`;o00005?ooool2o`0000Gooooo0_l000000ooooooo
0000o`000005o`0000Gooooo0_l000001?oooooo0000o`000?ooool4o`000003ooooool0003o0000
00Oooooo0ol0001Uooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00001oooool3o`0000?o
oooo0_l0000:ooooo`;o000000?oooooo`000?l000004oooool2o`0000Oooooo0_l0000Aooooo`;o
00001_ooool2o`0000?ooooo0_l0000Dooooo`;o00001_ooool6o`0000_ooooo0_l000000ooooooo
0000o`000002o`0000[ooooo0ol00003ooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0
?Oooool2o`0000Kooooo0_l00007ooooo`;o00001?ooool2o`0000Gooooo0_l00003ooooo`;o0000
0_ooool2o`0000Gooooo0_l0000Wooooo`;o00001_ooool2o`00017ooooo0_l00002ooooo`?o0000
2Oooool4o`0002Cooooo0ol0001Oooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00004Ooo
ool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00003ooooo`;o0000
1Oooool3o`0002Sooooo0_l00004ooooo`;o00004Oooool2o`0000;ooooo1Ol000000ooooooo0000
o`000005ooooo`?o00005?ooool2o`0000oooooo0_l0001Oooooo`007?ooool00ol0003ooooooooo
o`18ooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo0_l000000ooooooo0000o`00
0005ooooo`;o00002oooool3o`0000Oooooo1?l00003ooooo`;o00005oooool4o`0000;ooooo0_l0
000Hooooo`;o000000?oooooo`000?l000001?ooool4o`000003ooooool0003o0000017ooooo1?l0
000Booooo`;o0000F_ooool001cooooo0_l00015ooooo`;o00000_ooool2o`000003ooooool0003o
000001gooooo0_l000000ooooooo0000o`000007ooooo`Co00000oooool2o`0000_ooooo0_l0000<
ooooo`;o00001_ooool2o`0001Wooooo0_l00002ooooo`Co000000Coooooo`000?l0003o00001?oo
ool3o`0000_ooooo0_l0000Aooooo`?o0000F_ooool001cooooo00?o0000ooooooooool0A?ooool2
o`0002Cooooo0_l00007ooooo`;o00005Oooool2o`0000Wooooo0_l00009ooooo`;o00003_ooool2
o`0000Cooooo0_l00003ooooo`;o00002?ooool2o`0000Cooooo0ol00003ooooo`;o00006Oooool2
o`0000;ooooo0_l00008ooooo`;o0000COooool001cooooo00?o0000ooooooooool0Aoooool2o`00
01?ooooo0_l00008ooooo`;o00001Oooool2o`0000Cooooo0_l00003ooooo`;o00006oooool2o`00
013ooooo0_l00007ooooo`;o00001?ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`00
0004ooooool0003o0000ooooo`;o00002Oooool2o`0000Oooooo0_l00009ooooo`;o00002?ooool2
o`0004gooooo000Looooo`03o`000?oooooooooo04Oooooo0_l00007ooooo`;o00002_ooool2o`00
0003ooooool0003o000000Gooooo0_l00005ooooo`;o000000?oooooo`000?l000001?ooool4o`00
00kooooo0_l0000Iooooo`;o00000_ooool2o`0000?ooooo0_l00005ooooo`;o00001?ooool2o`00
0004ooooool0003o0000o`0000Gooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l0
0007ooooo`;o00000oooool4o`0000Cooooo0ol0001Rooooo`007?ooool00ol0003oooooooooo`1@
ooooo`;o00001?ooool3o`0000?ooooo1Ol00009ooooo`;o00001?ooool2o`0000Cooooo0_l00002
ooooo`;o00000_ooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0001Wooooo0_l0
0007ooooo`;o000000?oooooo`000?l000001?l000001?oooooo0000o`000?ooool2o`000004oooo
ool0003o0000o`0000Kooooo0_l000000ooooooo0000o`00000=ooooo`Co000000?oooooo`000?l0
00000_l00004ooooo`;o00009_ooool2o`0003_ooooo000Looooo`03o`000?oooooooooo043ooooo
0_l000000ooooooo0000o`000004ooooo`;o00001?ooool2o`0000Gooooo0ol00005ooooo`;o0000
00?oooooo`000?l000001_ooool3o`0000kooooo0_l00002ooooo`;o00000_ooool2o`000003oooo
ool0003o000000Oooooo0_l00003ooooo`;o00004_ooool2o`0000?ooooo1ol00003ooooo`;o0000
00?oooooo`000?l000000_ooool2o`0000Kooooo0_l00003ooooo`;o00002oooool4o`0000cooooo
0_l0000;ooooo`Co00005?ooool2o`0003_ooooo000Looooo`03o`000?oooooooooo043ooooo0_l0
00001?oooooo0000o`000?ooool2o`000003ooooool0003o000000Cooooo0_l0000@ooooo`;o0000
1_ooool2o`0000Oooooo0_l00003ooooo`;o00005Oooool3o`0000;ooooo1?l00002ooooo`;o0000
1?ooool2o`0000Kooooo1?l000000ooooooo0000o`000002o`000004ooooool0003o0000ooooo`;o
000000?oooooo`000?l000003_ooool5o`0000_ooooo1?l00004ooooo`;o00001_ooool2o`0000Wo
oooo1_l0001Aooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00001_ooool2o`0002[ooooo
0_l000000ooooooo0000o`000002o`0000Gooooo0_l0000?ooooo`;o000000Coooooo`000?l0003o
oooo1_l00004ooooo`;o00001?ooool2o`0000;ooooo0_l00002ooooo`;o00001Oooool2o`000004
ooooool0003o0000ooooo`Co00002Oooool5o`0000[ooooo1Ol00004ooooo`;o00004Oooool2o`00
05Gooooo000Looooo`03o`000?oooooooooo03kooooo0_l0000^ooooo`;o00001Oooool2o`0000?o
oooo1_l00006ooooo`?o000000?oooooo`000?l000001_ooool2o`0000?ooooo0_l000000ooooooo
0000o`000009ooooo`;o00001Oooool5o`0000?ooooo0_l00003ooooo`Go00003?ooool2o`0000[o
oooo0_l000000ooooooo0000o`00000Nooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0
A_ooool4o`00013ooooo0_l0000Booooo`;o000000Coooooo`000?l0003o00000oooool8o`0000Oo
oooo0ol000000ooooooo0000o`00000>ooooo`;o00000_ooool2o`0000Gooooo0_l000000ooooooo
0000o`000002ooooo`Go00001oooool4o`0000Kooooo0_l0000Eooooo`;o00001oooool2o`0000?o
oooo0_l000000ooooooo0000o`00000=ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0
A?ooool6o`0000_ooooo1?l000000ooooooo0000o`00000?ooooo`;o00001?ooool4o`0000;ooooo
0ol000000ooooooo0000o`000002o`0000Oooooo0ol00005ooooo`;o00001?ooool2o`0000Oooooo
0ol00003ooooo`Co000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l00005ooooo`Co0000
1_ooool2o`0001kooooo0_l00003ooooo`;o000000?oooooo`000?l000003_ooool2o`0004gooooo
000Looooo`03o`000?oooooooooo03oooooo0_l00003ooooo`Co00002_ooool2o`000003ooooool0
003o000000;o00000_ooool2o`0000Kooooo0_l00006ooooo`?o00001Oooool2o`000003ooooool0
003o000000;o00002oooool4o`0000;ooooo1Ol00003ooooo`?o00001oooool4o`000004ooooool0
003o0000o`0000cooooo0_l00005ooooo`Co00001?ooool2o`0000Oooooo1?l0000>ooooo`;o0000
00?oooooo`000?l000003?ooool2o`0000Oooooo0_l00003ooooo`;o00000_ooool2o`0004Wooooo
000Looooo`03o`000?oooooooooo03_ooooo1_l0000<ooooo`;o00000_ooool3o`0000Oooooo0_l0
00000ooooooo0000o`000003ooooo`;o00001Oooool4o`0000Gooooo2Ol00005ooooo`So00000_oo
ool3o`000004ooooool0003o0000ooooo`?o00002?ooool4o`000003ooooool0003o000000gooooo
0_l00005ooooo`;o00001_ooool2o`0000Oooooo1?l00007ooooo`;o00001Oooool2o`000003oooo
ool0003o000000cooooo0_l00002ooooo`;o00000oooool3o`0000Kooooo0_l00019ooooo`007?oo
ool00ol0003oooooooooo`0jooooo`Go00003_ooool2o`0000;ooooo0_l0000;ooooo`;o00002_oo
ool2o`0000Oooooo1?l000000ooooooo0000o`000005o`0000;ooooo1?l000001?oooooo0000o`00
0?ooool2o`0000;ooooo1?l000000ooooooo0000o`000004ooooo`Co000000?oooooo`000?l00000
0_l00009ooooo`;o00001Oooool2o`0000Gooooo0_l00003ooooo`;o00005Oooool2o`0000;ooooo
0_l0000Fooooo`;o00001?ooool2o`0001[ooooo0_l0000eooooo`007?ooool00ol0003ooooooooo
o`0jooooo`?o00007oooool2o`0000Cooooo0_l0000Aooooo`;o00000_ooool7o`000003ooooool0
003o000000;o00000oooool3o`0000;ooooo1_l00005ooooo`Co00000_ooool3o`0000Wooooo0_l0
0003ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00000_ooool2o`0000kooooo0_l0
0005ooooo`;o00003_ooool2o`00027ooooo0_l0000eooooo`007?ooool00ol0003oooooooooo`0k
ooooo`;o00002oooool2o`0001;ooooo0_l00004ooooo`?o00004oooool3o`0000?ooooo0_l00000
0ooooooo0000o`000002o`0000?ooooo0ol000000ooooooo0000o`000005o`0000Cooooo1?l00003
ooooo`Go00001_ooool3o`0000?ooooo0_l00005ooooo`;o00002_ooool4o`0000;ooooo0_l00004
ooooo`;o00003oooool2o`0000kooooo0_l00006ooooo`?o0000Coooool001cooooo0_l00015oooo
o`;o00000_ooool2o`0000gooooo1?l00008ooooo`;o00004?ooool7o`0000;ooooo0_l000000ooo
oooo0000o`000004o`000005ooooool0003o0000o`000?ooool01Ol00002ooooo`;o000000?ooooo
o`000?l000000ol00006ooooo`;o000000?oooooo`000?l000000oooool3o`0001Kooooo0ol00009
ooooo`;o00003_ooool2o`00013ooooo0_l00005ooooo`Go00000oooool2o`0004Sooooo000Loooo
o`03o`000?oooooooooo04Cooooo0_l0000Aooooo`Co00002?ooool2o`0000Oooooo0_l00004oooo
o`Oo000000?oooooo`000?l000003?l00002ooooo`Co000000?oooooo`000?l000000_ooool5o`00
00?ooooo0_l00007ooooo`?o00000oooool2o`0000;ooooo0_l00009ooooo`;o00002?ooool4o`00
013ooooo0_l00002ooooo`;o000000?oooooo`000?l000004?ooool2o`0000Gooooo0_l000000ooo
oooo0000o`000003ooooo`;o00000_ooool3o`0004?ooooo000Looooo`03o`000?oooooooooo06co
oooo0_l00004ooooo`So00000_oooolEo`0000?ooooo0ol00004ooooo`;o00001oooool3o`0000Oo
oooo0_l00005ooooo`?o000000?oooooo`000?l000002_ooool2o`0000?ooooo0_l000000ooooooo
0000o`000003o`0000?ooooo2?l000000ooooooo0000o`00000Gooooo`;o00000oooool2o`0000?o
oooo1Ol00013ooooo`007?ooool00ol0003oooooooooo`1:ooooo`Co00003?ooool2o`0000?ooooo
0_l0000@ooooo`Go000000Goooooo`000?l0003o0000ooooo`02o`000003ooooool0003o000001?o
00004Oooool4o`0000;ooooo0_l00007ooooo`Go000000Coooooo`000?l0003ooooo1Ol00009oooo
o`;o000000?oooooo`000?l000000ol00003ooooo`;o000000?oooooo`000?l000000_l00002oooo
o`;o00000_ooool2o`0001?ooooo0_l00003ooooo`;o00000oooool2o`000003ooooool0003o0000
04?ooooo000Looooo`03o`000?oooooooooo03kooooo0_l0000:ooooo`Co00000_ooool2o`0000So
oooo1?l000000ooooooo0000o`00000@ooooo`Co00001_ooool2o`000003ooooool0003o000000Ko
000000?oooooo`000?l000002ol0000Booooo`?o000000Coooooo`000?l0003o00001_ooool2o`00
00Cooooo0_l000000ooooooo0000o`000003o`0000;ooooo0_l00007ooooo`Oo000000Goooooo`00
0?l0003o0000ooooo`02o`0000Sooooo0_l0000Cooooo`Co00002Oooool2o`0000kooooo0_l0000c
ooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00001_ooool2o`0000?ooooo0_l00003oooo
o`;o00000_ooool2o`0000;ooooo1?l00008ooooo`Go00000oooool2o`0000oooooo0_l000000ooo
oooo0000o`00000Go`000003ooooool0003o000001?ooooo0_l00002ooooo`;o00003Oooool2o`00
00;ooooo0_l00003ooooo`;o00001oooool?o`0000Kooooo0_l0000Fooooo`;o00006Oooool2o`00
03?ooooo000Looooo`03o`000?oooooooooo03Kooooo0_l0000;ooooo`;o00000oooool2o`0000So
oooo0_l0000:ooooo`?o000000?oooooo`000?l000000_l00007ooooo`;o000000?oooooo`000?l0
00000oooool2o`000003ooooool0003o000001?o00000oooool6o`0000Cooooo0_l00005ooooo`;o
00002?ooool2o`0000Cooooo0_l00007ooooo`;o000000Coooooo`000?l0003o00000oooool2o`00
00Oooooo3ol000001?oooooo0000o`000?ooool4o`0002?ooooo0_l00011ooooo`007?ooool00ol0
003oooooooooo`12ooooo`;o00003oooool2o`0000gooooo0_l00009ooooo`;o000000?oooooo`00
0?l000001Ol000000ooooooo0000o`00000Lo`0000Cooooo0_l000000ooooooo0000o`000004o`00
00;ooooo0_l00002ooooo`Co00001?ooool3o`0000Wooooo0_l00002ooooo`Co00000oooool3o`00
00;ooooo5?l00009ooooo`;o00006_ooool2o`00047ooooo000Looooo`03o`000?oooooooooo03ko
oooo0_l00002ooooo`;o00002?ooool2o`0000Gooooo0_l00002ooooo`;o00001_ooool2o`0000[o
oooo0_l00004ooooo`Ko00001OoooolFo`000003ooooool0003o000000;o00000oooool2o`000003
ooooool0003o000000;o00001?ooool9o`0000Cooooo0_l00004ooooo`;o00000oooool2o`0000;o
oooo1?l00003oooooaCo00000_ooool2o`0000[ooooo0_l0000Jooooo`;o0000@Oooool001cooooo
00?o0000ooooooooool0=Oooool2o`0000Oooooo0_l0000<ooooo`;o00001Oooool2o`000004oooo
ool0003o0000o`0000Kooooo0_l0000:ooooo`;o00001OoooolJo`000003ooooool0003o000000;o
000000?oooooo`000?l000000ol000000ooooooo0000o`000002o`0000Wooooo2Ol000001?oooooo
0000o`000?l00006ooooo`Co000000?oooooo`000?l000000_ooool3o`0000Cooooo1_l000000ooo
oooo0000o`000003o`000003ooooool0003o000000Go000000?oooooo`000?l00000J_ooool001co
oooo00?o0000ooooooooool0=Oooool2o`0000_ooooo0_l00004ooooo`;o00000oooool2o`0000Oo
oooo0_l0000Kooooo`go000000?oooooo`000?l000003_l000001?oooooo0000o`000?ooool2o`00
0003ooooool0003o000000Cooooo0_l00008ooooo`Co00000oooool3o`0000Gooooo0_l000000ooo
oooo0000o`000002ooooo`;o000000Coooooo`000?l0003o00001?oooolDo`000003ooooool0003o
000000oooooo0ol0000Aooooo`;o00001Oooool2o`0003kooooo000Looooo`03o`000?oooooooooo
03Gooooo0_l0000;ooooo`;o00001?ooool2o`0000?ooooo0_l00002ooooo`Co00002oooool4o`00
00Cooooo0_l000000ooooooo0000o`000004ooooo`oo000000?oooooo`000?l000003Ol000000ooo
oooo0000o`000006o`0000Gooooo0_l0000;ooooo`;o000000Coooooo`000?l0003o00001_ooool4
o`0000?ooooo0_l00008oooooa?o00000_ooool2o`000003ooooool0003o000000_ooooo1?l00006
ooooo`;o00000_ooool2o`0000Gooooo0_l00005ooooo`;o0000?_ooool001cooooo00?o0000oooo
ooooool0=?ooool2o`0000Gooooo0_l0000Dooooo`Go00002_ooool4o`0000?ooooo0ol000000ooo
oooo0000o`000002o`0000;ooooo7ol000000ooooooo0000o`000007o`0000oooooo1?l000001?oo
oooo0000o`000?l00007ooooo`Co000000?oooooo`000?l000002?oooolDo`0000;ooooo0_l00000
0ooooooo0000o`00000;ooooo`;o00000_ooool2o`0000Cooooo0_l00002ooooo`;o000000?ooooo
o`000?l000002Oooool2o`0003kooooo000Looooo`03o`000?oooooooooo03?ooooo0ol00005oooo
o`;o00005?ooool2o`000003ooooool0003o000000Cooooo0_l0000:ooooo`Co00000oooool2o`00
0003ooooool0003o000001ko000000?oooooo`000?l000001?l000000ooooooo0000o`00000<oooo
o`;o000000?oooooo`000?l000002?ooool2o`0000?ooooo1?l000000ooooooo0000o`000006oooo
oaKo00000_ooool2o`0001;ooooo0_l00008ooooo`;o000000?oooooo`000?l00000BOooool00006
ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04
ooooo`03o`000?oooooooooo03?ooooo0_l0000Aooooo`;o000000?oooooo`000?l000003oooool2
o`0000[ooooo1?l00006ooooobKo00002Oooool2o`0000Gooooo0_l000000ooooooo0000o`000004
o`0000Cooooo0_l0000@oooooaGo00000oooool2o`0001cooooo0_l0000Kooooo`;o0000;oooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0kooooo`;o00001?ooool2o`0000?ooooo0_l000000ooooooo0000o`00
000TooooobOo00001Oooool2o`0000;ooooo0_l00003ooooo`Co000000?oooooo`000?l000001Ol0
000DoooooaOo00003_ooool2o`0000kooooo0_l0000Mooooo`;o0000;oooool00003ooooool@413o
oooo00;ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo00?o0000ooooooooool0>?ooool2
o`000003ooooool0003o000000Cooooo0_l00006ooooo`;o00001?ooool3o`0000Wooooo0_l0000=
ooooobOo000000?oooooo`000?l000000_l000000ooooooo0000o`000002ooooo`;o00001oooool4
o`0000Kooooo0_l00004ooooo`;o00001oooool2o`0000Cooooo6?l0000>ooooo`;o00001Oooool2
o`0000Oooooo0_l0001>ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09oooo
o`04odA4A?oMgMgoooooo`0000Oooooo0ol0000hooooo`;o000000?oooooo`000?l000003?ooool2
o`0000Cooooo0ol00002ooooo`;o00001Oooool4o`0000Oooooo0_l00002ooooo`Go000000?ooooo
o`000?l000003ol000000ooooooo0000o`00000:o`0000?ooooo1Ol000000ooooooo0000o`000002
o`000003ooooool0003o000000Kooooo0_l00009ooooo`?o00000_ooool2o`0000Oooooo0_l00004
ooooo`oo00000_ooool7o`0001Cooooo0ol0000Aooooo`;o0000A?ooool00003ooooool0003ooooo
00;ooooo00?o0000ooooooooool02Oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooo
oooo03oooooo0ol0000<ooooo`Co00000_ooool2o`0000Kooooo0ol000000ooooooo0000o`000004
ooooo`;o00000oooool2o`0000Cooooo8ol00004ooooo`?o000000?oooooo`000?l000001_ooool2
o`0000Wooooo0ol00005ooooo`;o00001?ooool2o`0000?ooooo6?l0000Aooooo`;o00000_ooool2
o`0001;ooooo0_l00005ooooo`;o0000?Oooool00003ooooool@413ooooo00;ooooo00?o410@oooo
ooooool02_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo03oooooo0ol0000<oooo
o`;o00001_ooool3o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000Sooooo5Ol000000ooo
oooo0000o`00000@o`000003ooooool0003o000001Gooooo0_l00004ooooo`Co00000_ooool2o`00
00Gooooo6?l0000Aooooo`;o00006Oooool2o`0000;ooooo0_l0000mooooo`0000KoooooogMgMonH
V9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0?Oooool2
o`0000;ooooo0_l00004ooooo`;o00002oooool7o`0000Gooooo0_l00003ooooo`;o00001?ooool2
o`0000;ooooo0ol000000ooooooo0000o`00000Vo`0000Gooooo0_l00008ooooo`;o00000_ooool2
o`0000Gooooo1?l00002ooooo`;o00001?oooolGo`0000kooooo0_l0000Fooooo`;o000000?ooooo
o`000?l000000oooool2o`00047ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPgooooo00?o
MgMgo`000?ooool01_ooool00ol0003oooooooooo`0mooooo`;o00000_ooool2o`0000Cooooo0_l0
0002ooooo`;o00001oooool2o`0000?ooooo0_l00004ooooo`;o00000_ooool2o`0000Kooooo0_l0
0003ooooob_o00001Oooool4o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o00001?oo
ool2o`000003ooooool0003o000000;o00001Oooool3o`000003ooooool0003o000001?o00003Ooo
ool2o`0000oooooo0_l00005ooooo`;o000000?oooooo`000?l000002_ooool2o`0003[ooooo000L
ooooo`03o`000?oooooooooo04[ooooo0ol00002ooooo`;o00002Oooool2o`0000?ooooo1_l00008
ooooob_o00002_ooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0000Gooooo0_l0
0002ooooo`?o00001Oooool2o`0000Kooooo4Ol0000@ooooo`;o00003?ooool2o`0000Kooooo0_l0
000<ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0=oooool2o`00017ooooo0_l00003
ooooo`;o00002Oooool2o`0000?ooooo1?l0000:ooooo`Co00000_oooolUo`0000Oooooo0_l0000<
ooooo`;o00001Oooool4o`00013ooooo0_l000000ooooooo0000o`00000;o`00017ooooo0_l0000<
ooooo`;o00001_ooool2o`0000Kooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0goooo
o`Co000000Coooooo`000?l0003ooooo0_l0000;ooooo`;o00003oooool2o`0000Wooooo0_l00005
ooooo`Co000000?oooooo`000?l000007?l000000ooooooo0000o`000002o`0000;ooooo0_l00004
ooooo`;o00004Oooool6o`0000Oooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o
000000Ko000000?oooooo`000?l000000oooool2o`0000Oooooo0_l000000ooooooo0000o`00000L
ooooo`;o00000_ooool4o`0003kooooo000Looooo`03o`000?oooooooooo03Wooooo0_l000001?oo
oooo0000o`000?ooool2o`0000Gooooo0_l00004ooooo`;o00002_ooool2o`0000?ooooo0_l00009
ooooo`;o00001Oooool6o`000003ooooool0003o000001co000000Goooooo`000?l0003o0000oooo
o`02o`0000Cooooo1?l00004ooooo`;o00002Oooool2o`0000Gooooo0_l00004ooooo`;o00000_oo
ool6o`0000?ooooo0ol00005ooooo`?o00000_ooool2o`0000Kooooo0ol000000ooooooo0000o`00
000;ooooo`;o00001Oooool2o`0000Sooooo0_l00004ooooo`;o00000_ooool2o`0003[ooooo000L
ooooo`03o`000?oooooooooo047ooooo0_l00003ooooo`;o00001?ooool3o`0000Wooooo0_l0000F
ooooo`Go000000?oooooo`000?l000008?l00003ooooo`;o00001?ooool2o`0000Cooooo0_l0000=
ooooo`;o000000?oooooo`000?l000001oooool2o`000003ooooool0003o000000;o00001_ooool2
o`0000?ooooo0ol00003ooooo`;o00001Oooool2o`0000;ooooo0_l00002ooooo`;o00001oooool2
o`0000;ooooo0_l000000ooooooo0000o`00000Booooo`;o0000>_ooool001cooooo00?o0000oooo
ooooool0:Oooool2o`0001?ooooo0_l000000ooooooo0000o`00000:ooooo`?o00001?ooool6o`00
01Cooooo1ol00002ooooob7o00000oooool2o`0001;ooooo0_l00002ooooo`;o000000?oooooo`00
0?l000002_ooool2o`0000?ooooo0_l00006ooooo`So00000oooool2o`0000gooooo0_l0000;oooo
o`;o00001oooool2o`0000Wooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0Yooooo`;o
00004oooool2o`0000kooooo1?l00002ooooo`Co00000_ooool2o`0001;ooooo1?l000001Ooooooo
0000o`000?l0003ooooo00Go000000?oooooo`000?l000005Ol000000ooooooo0000o`000004o`00
013ooooo0_l00002ooooo`;o00000_ooool2o`000004ooooool0003o0000o`0000kooooo0_l00004
ooooo`;o00000_ooool8o`0000;ooooo0_l0000Dooooo`;o00003?ooool2o`0000Wooooo0_l0000m
ooooo`007?ooool00ol0003oooooooooo`0looooo`;o00004?ooool4o`0000Sooooo0_l0000Doooo
o`;o000000?oooooo`000?l000007ol000000ooooooo0000o`000006o`000004ooooool0003o0000
o`0000[ooooo0ol00006ooooo`Go00001oooool2o`0000_ooooo0_l00008ooooo`?o000000?ooooo
o`000?l000005?ooool2o`000004ooooool0003o0000ooooo`;o00005?ooool2o`0003[ooooo000L
ooooo`03o`000?oooooooooo03Oooooo0_l00003ooooo`;o00002Oooool5o`0000;ooooo0_l00009
ooooo`;o00004oooool4o`000003ooooool0003o000001oo000000?oooooo`000?l000000ol00000
1?oooooo0000o`000?ooool3o`0000Cooooo0_l00005ooooo`;o000000?oooooo`000?l000000ooo
ool5o`0000Kooooo0ol0000Fooooo`;o00006_ooool5o`0001Cooooo0_l00008ooooo`;o00001Ooo
ool2o`0002Wooooo000Looooo`03o`000?oooooooooo03;ooooo0_l00003ooooo`;o00003_ooool6
o`0000cooooo0_l00005ooooo`;o00002Oooool2o`000003ooooool0003o000002Co000000?ooooo
o`000?l000000ol000000ooooooo0000o`000008ooooo`;o00002?ooool2o`000004ooooool0003o
0000ooooo`;o00002?ooool2o`0000?ooooo0_l000000ooooooo0000o`00000[ooooo`?o00004ooo
ool2o`0000_ooooo0_l00005ooooo`;o0000:Oooool001cooooo00?o0000ooooooooool0<_ooool2
o`0001Oooooo0_l00004ooooo`;o000000?oooooo`000?l000002_ooool2o`0000Wooooo2_l00000
0ooooooo0000o`00000>o`000003ooooool0003o000000[o00000_ooool8o`0000Wooooo0_l0000:
ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Oooooo1?l000000ooooooo0000o`000008
ooooo`;o00001?ooool2o`0001_ooooo0_l00007ooooo`Co00002Oooool2o`0003gooooo000Loooo
o`;o0000BOooool4o`0000Gooooo0_l000000ooooooo0000o`000004ooooo`;o00003Oooool2o`00
00;ooooo1_l000000ooooooo0000o`00000Mo`000003ooooool0003o000000Go00002oooool2o`00
00[ooooo1?l00003ooooo`;o00001oooool2o`0000;ooooo0_l00009ooooo`;o00001?ooool2o`00
01_ooooo0_l000000ooooooo0000o`000004ooooo`Co00002_ooool2o`0000;ooooo0_l0000hoooo
o`007?ooool00ol0003oooooooooo`18ooooo`Co00003_ooool2o`0000gooooo0_l00004ooooo`;o
000000?oooooo`000?l000000_l000000ooooooo0000o`00000Io`000004ooooool0003o0000o`00
01_ooooo1_l0000?ooooo`Co00000oooool2o`0000oooooo0_l00002ooooo`;o00004?ooool2o`00
0003ooooool0003o000000Kooooo0_l0000:ooooo`;o00000_ooool2o`0003Sooooo000Looooo`03
o`000?oooooooooo03[ooooo0_l00007ooooo`;o00001_ooool2o`0001_ooooo1?l00002ooooo`;o
00000_ooool2o`0000Cooooo5_l00003ooooo`Co00003?ooool2o`0000gooooo1ol000001?oooooo
0000o`000?ooool2o`0000_ooooo0_l00002ooooo`?o00000_ooool2o`0000_ooooo0_l000001?oo
oooo0000o`000?l0000Gooooo`;o00000_ooool2o`0004Sooooo000Looooo`03o`000?oooooooooo
03[ooooo0ol00006ooooo`;o00001Oooool6o`0000oooooo0ol00006ooooo`Co00000_ooool3o`00
0004ooooool0003o0000o`0000?ooooo6?l000000ooooooo0000o`000004o`0000[ooooo0_l0000=
ooooo`;o00000_ooool3o`000004ooooool0003o0000ooooo`;o00003oooool2o`0000?ooooo0_l0
0005ooooo`;o00001oooool2o`0001?ooooo0_l00003ooooo`;o00001?ooool2o`0001Gooooo0_l0
000_ooooo`007?ooool00ol0003oooooooooo`0iooooo`Co00003Oooool6o`0000oooooo0ol0000=
ooooo`;o000000Coooooo`000?l0003o00001?ooool3o`0000;ooooo3ol000000ooooooo0000o`00
0007o`0000Kooooo0_l0000Dooooo`Go00001?ooool2o`0001Kooooo0_l000001?oooooo0000o`00
0?l00008ooooo`;o00004_ooool2o`0000?ooooo0_l00004ooooo`;o00005Oooool2o`0002oooooo
000Looooo`03o`000?oooooooooo03Sooooo0ol0000Cooooo`;o00003oooool2o`00017ooooo0ol0
0005ooooo`Go000000?oooooo`000?l000001ol000000ooooooo0000o`000002o`0000;ooooo0_l0
0002ooooo`Go00001?ooool2o`0000oooooo0_l000000ooooooo0000o`00000;o`0000oooooo0_l0
0005ooooo`;o000000?oooooo`000?l000000ol00004ooooo`Co000000Coooooo`000?l0003o0000
4?ooool2o`000003ooooool0003o000004cooooo000Looooo`03o`000?oooooooooo03Sooooo0_l0
000?ooooo`;o00000oooool2o`0000Sooooo0_l00005ooooo`;o00002?ooool2o`0000Kooooo1?l0
0005ooooo`ko000000?oooooo`000?l000001Ol000000ooooooo0000o`000004ooooo`;o00001Ooo
ool2o`0000Oooooo0_l00005ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`Co0000
4Oooool2o`0000Sooooo1Ol00004ooooo`;o00000oooool3o`0000kooooo1?l0000Sooooo`;o0000
:_ooool001cooooo00?o0000ooooooooool0<?ooool2o`0001Oooooo0_l00003ooooo`;o00000ooo
ool2o`0000?ooooo0ol00008ooooo`;o00001?ooool2o`0000Kooooo0ol00002ooooo`;o00000_oo
ool2o`0000?ooooo0ol00007ooooo`;o00000oooool2o`000003ooooool0003o000000Cooooo0_l0
0005ooooo`;o00001oooool2o`0000Oooooo1?l0000Eooooo`;o00001_ooool2o`0000Cooooo0_l0
00000ooooooo0000o`000002ooooo`;o00005_ooool2o`0000oooooo0_l00006ooooo`;o00001Ooo
ool2o`0000Gooooo0_l0000Zooooo`007?ooool00ol0003oooooooooo`0Xooooo`;o00001_ooool2
o`0001Gooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000003
ooooo`?o00000_ooool2o`0000Cooooo0_l0000=ooooo`;o00000_ooool:o`000003ooooool0003o
000000;o00001?ooool3o`000003ooooool0003o000000Cooooo1_l0000<ooooo`Co00001?ooool2
o`000003ooooool0003o000000;o00001oooool2o`0000Cooooo0_l00006ooooo`;o00001_ooool2
o`0000Cooooo1Ol000001?oooooo0000o`000?l00003ooooo`;o00000_ooool2o`0000Kooooo0_l0
0005ooooo`Co00003Oooool2o`0000Kooooo0_l000000ooooooo0000o`000002ooooo`;o0000<Ooo
ool001cooooo00?o0000ooooooooool0:?ooool2o`0000_ooooo0ol0000?ooooo`Ko00000oooool2
o`0000Oooooo0ol000000ooooooo0000o`00000Cooooo`;o00001?ooool8o`000003ooooool0003o
000000;o00000_ooool2o`000003ooooool0003o000000?o00000oooool7o`0000cooooo0_l00006
ooooo`Co000000?oooooo`000?l000001oooool2o`0000Cooooo1?l0000Booooo`Co00000_ooool2
o`0000Cooooo0_l00002ooooo`;o00001_ooool2o`0000Oooooo0_l0000;ooooo`;o00002oooool2
o`0003Gooooo000Looooo`03o`000?oooooooooo02Kooooo0_l0000=ooooo`?o00004Oooool2o`00
00oooooo0ol0000Looooo`?o000000Coooooo`000?l0003o00001oooool2o`0000?ooooo0_l00004
ooooo`?o00000oooool2o`0000Oooooo0_l00003ooooo`;o00001oooool2o`0000cooooo0_l00002
ooooo`Co00001Oooool2o`000003ooooool0003o000000Go000000?oooooo`000?l000001?ooool2
o`0000Gooooo0_l00003ooooo`;o00001_ooool2o`0000Wooooo0_l00009ooooo`;o00000_ooool2
o`0003kooooo000Looooo`03o`000?oooooooooo02Kooooo0_l0000?ooooo`;o00005_ooool2o`00
00[ooooo0_l0000>ooooo`?o00002_ooool4o`000003ooooool0003o000000?o00002_ooool2o`00
00?ooooo1?l00003ooooo`;o00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`00
01Gooooo0_l0000;ooooo`ko00000oooool2o`0000Cooooo0ol00003ooooo`Co00001?ooool2o`00
00Wooooo0_l0000=ooooo`;o00001_ooool2o`0003Kooooo000Looooo`03o`000?oooooooooo03Oo
oooo0_l00005ooooo`;o00003oooool2o`000003ooooool0003o000001Oooooo0ol0000:ooooo`;o
00001_ooool2o`0000?ooooo0_l00009ooooo`?o00001Oooool2o`0000;ooooo0_l00004ooooo`Go
00001_ooool2o`0001gooooo3Ol00008ooooo`Co00001?ooool4o`0000cooooo0_l0000Fooooo`;o
0000=_ooool001cooooo00?o0000ooooooooool0;_ooool2o`0000gooooo0ol0000:ooooo`;o0000
1_ooool2o`0000;ooooo0_l0000Tooooo`?o000000?oooooo`000?l000001Ol00003ooooo`Co0000
0_ooool5o`0000_ooooo1?l000000ooooooo0000o`000002ooooo`;o00000_ooool2o`0001Oooooo
0_l00003ooooo`;o000000?oooooo`000?l000002Ol0000:ooooo`;o00001_ooool2o`0000cooooo
0_l00009ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0;Oooool3o`0000Cooooo0_l0
0007ooooo`;o00002oooool2o`0000[ooooo0_l0000Jooooo`;o00002?ooool3o`0000?ooooo1?l0
0004ooooo`Co00001Oooool2o`0000_ooooo0_l000000ooooooo0000o`000004ooooo`;o00001?oo
ool2o`0000oooooo0_l00004ooooo`;o00000oooool2o`0000;ooooo3?l00003ooooo`;o00002ooo
ool4o`0000[ooooo0_l00006ooooo`;o000000?oooooo`000?l00000@oooool001cooooo00?o0000
ooooooooool0;Oooool2o`0000Gooooo0_l00009ooooo`;o00009_ooool2o`0000Kooooo0_l00000
0ooooooo0000o`000004ooooo`So00000_ooool4o`0000;ooooo1Ol00006ooooo`;o00003?ooool5
o`0000?ooooo0ol00003ooooo`?o00003Oooool5o`0000;ooooo0_l00006ooooo`oo000000?ooooo
o`000?l000000_l0000;ooooo`;o00004_ooool2o`0004Kooooo000Looooo`;o0000<_ooool2o`00
0003ooooool0003o000000;ooooo0_l00005ooooo`;o00009_ooool2o`0000Kooooo0_l00007oooo
o`Co00000_ooool2o`000003ooooool0003o000000;o00000oooool7o`0000Cooooo0_l0000:oooo
o`Co000000?oooooo`000?l000000oooool9o`0000gooooo0_l000000ooooooo0000o`000002oooo
o`;o00000_oooolHo`0000_ooooo0ol0001Iooooo`007?ooool00ol0003oooooooooo`0aooooo`;o
00001Oooool2o`0002gooooo0_l000000ooooooo0000o`000009ooooo`;o00000_ooool2o`0000Ko
oooo1?l00008ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00001_ooool2o`00
00Wooooo1ol0000Dooooo`;o00000ooooolEo`0000oooooo0_l0000/ooooo`;o0000:oooool001co
oooo00?o0000ooooooooool0<Oooool2o`0000;ooooo0_l00002ooooo`;o0000:Oooool2o`0000Co
oooo0_l00003ooooo`Co00000_ooool2o`0000;ooooo1?l0000>ooooo`;o00000_ooool3o`0000Go
oooo0_l0000Booooo`Go00005Oooool6o`000003ooooool0003o000001;o00002Oooool4o`0000?o
oooo0_l00005ooooo`;o00006Oooool2o`0000Sooooo0_l0000[ooooo`007?ooool00ol0003ooooo
ooooo`0dooooo`?o000000Coooooo`000?l0003o0000:Oooool2o`0000Wooooo1?l000000ooooooo
0000o`000005ooooo`;o00002Oooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000_o
oooo0_l00008ooooo`Oo000000?oooooo`000?l000004OoooolKo`0000Sooooo1?l00003ooooo`;o
000000?oooooo`000?l000000_ooool3o`000003ooooool0003o000001Gooooo0_l0000eooooo`00
7?ooool00ol0003oooooooooo`0Sooooo`;o00003oooool2o`0000;ooooo0_l0000^ooooo`;o0000
2_ooool2o`0000?ooooo0_l00002ooooo`;o00001?ooool2o`000003ooooool0003o000000;o0000
2_ooool2o`0000_ooooo0_l00004ooooo`;o00001?ooool2o`000003ooooool0003o000000?o0000
00Coooooo`000?l0003o00003OoooolCo`000003ooooool0003o000000Oo00003Oooool2o`000003
ooooool0003o000000?ooooo0_l000000ooooooo0000o`00001<ooooo`007?ooool00ol0003ooooo
ooooo`0Sooooo`;o00002Oooool2o`0000[ooooo0_l0000Yooooo`;o000000?oooooo`000?l00000
3oooool2o`0000;ooooo0_l00004ooooo`Oo00003?ooool2o`0000[ooooo0_l00003ooooo`?o0000
0oooool2o`0000;ooooo0ol00002ooooo`?o00002Oooool2o`000003ooooool0003o000001go0000
2?ooool4o`0005Wooooo000Looooo`03o`000?oooooooooo02kooooo0_l0000:ooooo`;o000000?o
ooooo`000?l000001?ooool2o`00023ooooo0_l00009ooooo`;o00000oooool2o`0000_ooooo0_l0
00000ooooooo0000o`000007ooooo`;o00001_ooool4o`0000;ooooo0_l00004ooooo`;o00000ooo
ool3o`0000Sooooo0_l00006ooooo`;o000000?oooooo`000?l000000oooool2o`000003ooooool0
003o000001Oo000000?oooooo`000?l000000ol00003ooooo`;o00000oooool4o`0001Wooooo0_l0
000nooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00001_ooool2o`000005ooooool0003o
0000o`000?ooool00_l00004ooooo`;o00008?ooool4o`0000Oooooo1?l000000ooooooo0000o`00
000:ooooo`Go00002?ooool2o`0000?ooooo0_l00003ooooo`;o00000_ooool2o`0000Wooooo0_l0
000Aooooo`;o000000?oooooo`000?l000001_oooolPo`0000;ooooo0_l0000Nooooo`Go0000?Ooo
ool001cooooo00?o0000ooooooooool0;_ooool2o`0000Kooooo0_l000000ooooooo0000o`000003
o`0002Wooooo0ol00008ooooo`;o00000oooool2o`0000Sooooo1Ol0000=ooooo`;o00003oooool2
o`0000Gooooo0_l0000Hooooo`;o000000?oooooo`000?l000002Ol00002oooooaCo00004?ooool2
o`0000Wooooo0_l000001?oooooo0000o`000?ooool2o`0003gooooo000Looooo`03o`000?oooooo
oooo03Sooooo0_l00002ooooo`?o0000:Oooool2o`0000gooooo0_l00007ooooo`;o000000?ooooo
o`000?l000007Oooool4o`0000Gooooo0_l0000Fooooo`;o000000?oooooo`000?l000006ol00002
ooooo`?o00003Oooool3o`000003ooooool0003o000000Cooooo0_l00003ooooo`;o000000?ooooo
o`000?l000000_ooool3o`0003_ooooo000Looooo`03o`000?oooooooooo03Sooooo0_l00003oooo
o`;o0000<?ooool2o`0000Oooooo0_l00006ooooo`;o000000?oooooo`000?l000001?ooool2o`00
0003ooooool0003o000000oooooo0_l00003ooooo`;o00002Oooool2o`0001Cooooo0_l000000ooo
oooo0000o`00000Ko`0000;ooooo0ol0000:ooooo`;o000000?oooooo`000?l000000_l00006oooo
o`;o00001_ooool2o`0000;ooooo0ol0000kooooo`007?ooool00ol0003oooooooooo`0iooooo`;o
00002_ooool3o`0002Oooooo0ol000000ooooooo0000o`000003ooooo`;o00003oooool2o`000003
ooooool0003o000000cooooo0_l000000ooooooo0000o`000007ooooo`;o00001Oooool2o`0000[o
oooo0_l0000<oooooa[o000000Goooooo`000?l0003o0000ooooo`02o`0000Cooooo0_l00004oooo
o`;o00000oooool2o`0001?ooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0cooooo`;o
00001?ooool2o`0000[ooooo0ol0000Hooooo`;o00003_ooool2o`000003ooooool0003o000000Go
oooo0_l0000@ooooo`;o00001Oooool2o`0000Gooooo0_l00004ooooo`;o00001?ooool2o`00017o
oooo0_l0000;oooooaoo00001oooool2o`0002Cooooo0_l0000eooooo`007?ooool00ol0003ooooo
ooooo`0cooooo`;o000000?oooooo`000?l00000:?ooool2o`0000Oooooo0_l00004ooooo`;o0000
2?ooool3o`0000Wooooo0ol00004ooooo`Co00000oooool2o`0000Oooooo0_l00002ooooo`;o0000
0_ooool2o`00023ooooo1_l000000ooooooo0000o`00000Fo`0000;ooooo0ol00003ooooo`;o0000
3Oooool2o`0001Cooooo0_l0000eooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00001?oo
ool2o`00037ooooo0_l00004ooooo`;o00002?ooool4o`000003ooooool0003o000000Gooooo0ol0
0006ooooo`;o00002_ooool4o`0000Kooooo0_l0000Mooooo`;o000000?oooooo`000?l000006ol0
0004ooooo`?o00000oooool2o`0000gooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`0`
ooooo`;o00001?ooool2o`0002cooooo0_l0000=ooooo`;o00001?ooool4o`000003ooooool0003o
000001[ooooo0ol00007ooooo`?o00000_ooool2o`0000Gooooo0_l00002ooooo`;o00001?ooool2
o`0000Oooooo0_l00002oooooaco00002_ooool2o`0000?ooooo1?l0000Sooooo`;o0000;_ooool0
01cooooo0_l0000hooooo`;o00009_ooool2o`0000?ooooo0_l00008ooooo`;o000000?oooooo`00
0?l000000_l0000Mooooo`;o00001oooool2o`0000Sooooo0_l00002ooooo`;o00001Oooool2o`00
00;ooooo0_l00004ooooo`;o00002ooooolLo`0000Cooooo0_l000001?oooooo0000o`000?ooool3
o`0000;ooooo1?l0000Gooooo`;o00002_ooool2o`0002kooooo000Looooo`03o`000?oooooooooo
03Oooooo0_l0000>ooooo`;o00005_ooool2o`0000Gooooo0_l00002ooooo`;o00000_ooool2o`00
0003ooooool0003o000001oooooo0_l00009ooooo`;o000000?oooooo`000?l000000_ooool2o`00
00Cooooo0_l000000ooooooo0000o`00000;ooooo`;o00001?ooool2o`000004ooooool0003o0000
o`0000;ooooo6Ol00006ooooo`;o000000?oooooo`000?l000000_ooool3o`0000Gooooo0_l0000E
ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0;_ooool2o`0000?ooooo0_l0000;oooo
o`;o00000_ooool2o`000003ooooool0003o000001gooooo0_l00002ooooo`;o00000_ooool2o`00
00?ooooo0_l00008ooooo`;o00007_ooool2o`000003ooooool0003o000000;ooooo0_l00004oooo
o`;o000000?oooooo`000?l000000_ooool2o`0000Oooooo0_l00004ooooo`;o000000Coooooo`00
0?l0003o00001OoooolHo`0000[ooooo1?l00005ooooo`;o00001Oooool2o`000003ooooool0003o
000000cooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`0]ooooo`?o00000oooool2o`00
00;ooooo0_l00007ooooo`;o00000_ooool2o`0002Sooooo0_l00003ooooo`;o00001?ooool3o`00
0003ooooool0003o000001Wooooo0_l0000Gooooo`;o00003_ooool2o`0000Wooooo5?l000000ooo
oooo0000o`000006ooooo`Ko00003_ooool2o`000003ooooool0003o000000cooooo0_l0000ioooo
o`007?ooool00ol0003oooooooooo`0]ooooo`;o00001?ooool2o`0000;ooooo0ol0000=ooooo`;o
00009?ooool5o`0000Oooooo0ol0000Iooooo`Go00003?ooool2o`0000Kooooo0_l0000=ooooo`;o
00000_ooool2o`0000;ooooo0_l00005oooooa?o00002_ooool8o`0000kooooo0ol00017ooooo`00
7?ooool00ol0003oooooooooo`0cooooo`;o00000oooool2o`0000gooooo0_l0000Pooooo`;o0000
0_ooool6o`000004ooooool0003o0000o`0000?ooooo0_l00004ooooo`;o00004oooool3o`0000?o
oooo0_l00009ooooo`;o00001_ooool2o`0000_ooooo1?l00004ooooo`Co00001Oooool2o`000003
ooooool0003o000000oo00002oooool7o`0000gooooo0ol00017ooooo`007?ooool00ol0003ooooo
ooooo`0cooooo`;o00002_ooool2o`0001Cooooo0_l00003ooooo`;o00002Oooool2o`0000;ooooo
0_l00002ooooo`oo00001?ooool2o`0001Kooooo0_l000000ooooooo0000o`000006ooooo`;o0000
1oooool2o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l000001_l00002ooooo`;o0000
0_ooool6o`0000;ooooo0ol00003ooooo`_o00002Oooool6o`000003ooooool0003o000005Oooooo
000Looooo`03o`000?oooooooooo03Sooooo0_l00003ooooo`Go00004Oooool4o`0000?ooooo0_l0
0009ooooo`;o00001OoooolAo`0000Gooooo0_l0000@ooooo`;o00000_ooool2o`000003ooooool0
003o000000Kooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00004ooooo`;o000000?o
ooooo`000?l000001_l00005ooooo`Oo00001oooool9o`0000cooooo1_l0001Jooooo`007?ooool0
0ol0003oooooooooo`0hooooo`;o00000oooool2o`000003ooooool0003o000000;o00003oooool4
o`0000kooooo0_l000000ooooooo0000o`000002ooooo`?o000000?oooooo`000?l000003?l00004
ooooo`?o00003oooool2o`0000;ooooo0ol0000<ooooo`;o00006_ooool2o`000003ooooool0003o
000000?o00002?ooool:o`000003ooooool0003o000000;o00000_ooool2o`000003ooooool0003o
000000Cooooo0_l0000Kooooo`?o0000??ooool001cooooo00?o0000ooooooooool0@_ooool4o`00
02;ooooo0ol000000ooooooo0000o`00000@o`0000;ooooo0_l000000ooooooo0000o`000002o`00
017ooooo0ol0000<ooooo`;o00004_ooool2o`0000Kooooo0_l00004ooooo`;o00002?ooool2o`00
0004ooooool0003o0000ooooo`;o00000_ooool5o`0000;ooooo0_l000000ooooooo0000o`00000Q
ooooo`?o0000??ooool001cooooo00?o0000ooooooooool0??ooool2o`0000Kooooo0_l0000Poooo
o`;o000000?oooooo`000?l000004ol00002ooooo`;o00000oooool2o`0001Cooooo0_l00009oooo
o`?o000000?oooooo`000?l000003oooool2o`0000cooooo0_l00008ooooo`;o000000?oooooo`00
0?l000001Oooool2o`0000oooooo0_l000000ooooooo0000o`000002o`00023ooooo0_l0000boooo
o`007?ooool00ol0003oooooooooo`0looooo`;o00005_ooool2o`00013ooooo0_l00002ooooo`?o
00000_oooolCo`0001Gooooo0_l00002ooooo`Co00001oooool2o`000003ooooool0003o000000?o
00006_ooool2o`0000Oooooo1_l0000Gooooo`;o000000?oooooo`000?l000000_l0000Pooooo`;o
0000<_ooool001cooooo00?o0000ooooooooool0@oooool2o`0000[ooooo2?l0000;ooooo`;o0000
1?ooool?o`000003ooooool0003o000000;o00000_ooool4o`00017ooooo0_l000001?oooooo0000
o`000?l00004ooooo`;o00001oooool2o`000004ooooool0003o0000ooooo`;o00006_ooool2o`00
00Oooooo0_l00002ooooo`;o00003Oooool2o`0002Cooooo0_l00007ooooo`;o0000=?ooool001co
oooo00?o0000ooooooooool0@oooool2o`000003ooooool0003o000000Oooooo2?l00005ooooo`;o
00001?ooool4o`000003ooooool0003o000001?o000000?oooooo`000?l000000ol0000:ooooo`;o
00001Oooool2o`000003ooooool0003o000000kooooo0_l00002ooooo`;o00002Oooool2o`0002Ko
oooo1?l00003ooooo`;o00009?ooool2o`0000Oooooo0_l0000dooooo`0000Koooooonk^k_lb<S;o
0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000
ooooooooool0??ooool2o`0000Sooooo0_l00006ooooo`;o00003?ooool2o`0000Gooooo0ol00000
1?oooooo0000o`000?oooolBo`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l00000
1oooool2o`0000gooooo1?l000000ooooooo0000o`000004ooooo`;o00000_ooool2o`0000Wooooo
0_l0000Jooooo`;o00002?ooool6o`0000Kooooo0_l00007ooooo`;o0000Eoooool00006oooooomg
MgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06oooo
o`03o`000?oooooooooo03Sooooo0_l00002ooooo`?o00000oooool4o`0000Oooooo0ol00006oooo
o`;o00003oooool2o`000003ooooool0003o000001?o00001?ooool2o`0000?ooooo0_l0000Aoooo
o`Co000000?oooooo`000?l000001?ooool3o`0001Cooooo0_l0000Booooo`;o00000oooool3o`00
00;ooooo0_l0000:ooooo`;o00001oooool2o`0005Oooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
03Sooooo0_l00003ooooo`;o00000oooool4o`0000Oooooo0_l00007ooooo`;o00000oooool2o`00
00Sooooo1?l000000ooooooo0000o`00000Do`000004ooooool0003o0000ooooo`;o00000_ooool2
o`00017ooooo0_l0000:ooooo`;o00000oooool2o`0000oooooo0_l0000Booooo`;o00000oooool3
o`0001[ooooo0_l00007ooooo`;o0000Boooool00003ooooool0003ooooo00;ooooo00?o0000oooo
ooooool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0000mooooo`;o00001?ooool2
o`0000kooooo1?l00004ooooo`;o00001OoooolNo`000004ooooool0003o0000ooooo`;o00005Ooo
ool2o`0000oooooo0_l0000Qooooo`Co00001?ooool2o`0000?ooooo0_l00007ooooo`;o00001Ooo
ool2o`0000Gooooo0_l00006ooooo`Co0000B_ooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool02Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0@Ooo
ool4o`0000kooooo1?l0000;oooooako00005?ooool2o`0000cooooo1?l0000Yooooo`;o00001_oo
ool2o`0000?ooooo0_l00006ooooo`?o00001Oooool2o`000003ooooool0003o000000Oooooo0_l0
00000ooooooo0000o`000002o`0004[ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooo
oooo00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`0aooooo`;o00003_ooool2
o`00017ooooo0ol0000:oooooaCo000000?oooooo`000?l000001_l00002ooooo`;o000000?ooooo
o`000?l000000oooool2o`0000[ooooo0_l00009ooooo`Wo000000?oooooo`000?l000001Oooool2
o`0000Wooooo1?l0000Cooooo`;o00004?ooool2o`0000?ooooo0_l00002ooooo`Ko00001Oooool2
o`0004oooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`0aooooo`;o00003Oooool2o`00013ooooo1Ol0000:ooooo`;o00000ooo
oolLo`000004ooooool0003o0000ooooo`Co00001_ooool2o`0000;ooooo0_l00008ooooo`go0000
1Oooool2o`0000Gooooo0_l00002ooooo`Go00000oooool2o`0000Kooooo0_l00005ooooo`;o0000
1?ooool2o`0000Gooooo0_l00002ooooo`;o00001?ooool2o`0000;ooooo0_l00002ooooo`;o0000
E_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106oooo
o`03o`000?oooooooooo043ooooo0_l0000@ooooo`?o00000oooool2o`0000Kooooo0_l000000ooo
oooo0000o`00000<o`000003ooooool0003o000000go00001Oooool2o`0000Sooooo0_l0000;oooo
o`ko00003?ooool4o`0000;ooooo0ol00003ooooo`;o00000oooool5o`0000_ooooo0_l00005oooo
o`;o00000_ooool2o`0006Cooooo000Looooo`03o`000?oooooooooo05Sooooo0_l00006ooooob7o
000000Coooooo`000?l0003o00000oooool2o`0001?ooooo1?l00002ooooo`So000000Coooooo`00
0?l0003ooooo0_l00002ooooo`Co00000_ooool2o`0000gooooo0ol0000?ooooo`;o00003oooool2
o`0005cooooo000Looooo`03o`000?oooooooooo05oooooo9_l00003ooooo`;o00000_ooool2o`00
00cooooo0ol000000ooooooo0000o`00000>o`000003ooooool0003o000000;ooooo1?l000000ooo
oooo0000o`000002o`000003ooooool0003o000001_ooooo0_l00002ooooo`;o00000_ooool2o`00
00;ooooo0_l00003ooooo`;o00001Oooool3o`0001kooooo0_l0000dooooo`007?ooool00ol0003o
ooooooooo`1Eooooo`;o00002?ooool3o`000003ooooool0003o000001Ko000000?oooooo`000?l0
00001?l00006ooooo`;o00000_ooool2o`0000Sooooo0_l00002ooooo`ko000000?oooooo`000?l0
00000ol00006ooooo`So000000?oooooo`000?l000000oooool2o`0001[ooooo0_l00002ooooo`;o
00000_ooool2o`0000[ooooo0ol0000Nooooo`;o0000=?ooool001cooooo00?o0000ooooooooool0
EOooool2o`000003ooooool0003o000000Gooooo0ol000000ooooooo0000o`00000;o`0000;ooooo
4?l00003ooooo`Go00003?ooool2o`0000;ooooo5ol00003ooooo`Co00002_ooool2o`0001;ooooo
0_l00007ooooo`;o00000_ooool2o`0006Cooooo000Looooo`03o`000?oooooooooo03oooooo0_l0
000;ooooo`;o00001oooool2o`000003ooooool0003o000000Gooooo0ol000000ooooooo0000o`00
000Mo`0000?ooooo1?l0000<ooooo`?o00000_oooolIo`00013ooooo0_l0000Aooooo`;o00001ooo
ool:o`00017ooooo0_l00007ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0?oooool2
o`0000_ooooo0_l00003ooooo`;o00000_ooool2o`0000Sooooo0_l000001?oooooo0000o`000?oo
oolKo`000004ooooool0003o0000ooooo`;o00003ooooolOo`0000Cooooo1?l00007ooooo`;o0000
6_ooool:o`00017ooooo0_l00007ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0?ooo
ool2o`0000Wooooo0_l00005ooooo`;o00000_ooool2o`0000;ooooo0_l00004ooooo`;o000000?o
ooooo`000?l000000ooooolLo`000003ooooool0003o000000?ooooo1Ol00004ooooo`;o000000?o
ooooo`000?l000004?l000000ooooooo0000o`00000:o`0000;ooooo1_l000000ooooooo0000o`00
000Kooooo`oo00004Oooool2o`0004gooooo000Looooo`03o`000?oooooooooo03oooooo0_l00008
ooooo`?o00002Oooool3o`000003ooooool0003o000000Cooooo1Ol000000ooooooo0000o`00000C
o`000003ooooool0003o000000Co00002?ooool5o`0000Cooooo1_l000000ooooooo0000o`00000I
o`0000;ooooo1?l00003ooooo`;o00002_ooool2o`0000oooooo4Ol000000ooooooo0000o`00000<
ooooo`;o0000COooool001cooooo00?o0000ooooooooool0BOooool2o`0000Cooooo0_l00005oooo
o`;o00001oooool?o`000003ooooool0003o000000co00005_ooool2o`0000?ooooo7?l00003oooo
o`?o00003oooool2o`0000Cooooo0_l00009ooooo`;o00000_ooool=o`000003ooooool0003o0000
05_ooooo000Looooo`03o`000?oooooooooo04oooooo0_l0000>ooooo`;o000000?oooooo`000?l0
00002_l000000ooooooo0000o`00000;o`0001_ooooo7Ol0000Kooooo`;o00002Oooool2o`0000;o
oooo3_l0001Mooooo`007?ooool00ol0003oooooooooo`0jooooo`;o00002Oooool2o`0000Wooooo
0ol0000;ooooo`;o00000_oooolBo`000003ooooool0003o000000;o00002oooool2o`0000[ooooo
0_l00003oooooaoo00001?ooool2o`0000;ooooo0_l0000Pooooo`Go00000_ooool7o`0000Wooooo
0_l0001Booooo`007?ooool2o`0003_ooooo0_l00009ooooo`;o00002Oooool3o`0000;ooooo1?l0
0005ooooo`;o00000_ooool2o`0000?ooooo4_l00003ooooo`;o00001_ooool2o`0000[ooooo0_l0
0002oooooako00001_ooool2o`0000;ooooo0_l0000Mooooo`;o000000?oooooo`000?l000003?l0
0009ooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0D?ooool2o`0000?ooooo1?l0000>
ooooo`[o000000?oooooo`000?l000001?l00002ooooo`Co00000_ooool3o`0000Gooooo0_l0000:
ooooo`Go000000?oooooo`000?l000005ol0000=ooooo`;o00006Oooool2o`0000;ooooo3_l0001L
ooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00002?ooool3o`0000_ooooo1Ol00002oooo
o`Go00000_ooool6o`0000Cooooo0ol00003ooooo`Co00002ooooolOo`0000?ooooo0_l00007oooo
o`;o00007Oooool>o`0005cooooo000Looooo`03o`000?oooooooooo04Wooooo0_l000001Ooooooo
0000o`000?l0003ooooo00Co00001?ooool6o`0000?ooooo0_l00002ooooo`;o00001?ooool2o`00
00;ooooo1?l00005ooooo`?o00002oooool3o`0000?ooooo1?l00005ooooo`;o000000?oooooo`00
0?l000002?l000000ooooooo0000o`00000?o`0000?ooooo0_l0000Vooooo`go00006?ooool2o`00
04?ooooo000Looooo`03o`000?oooooooooo04Wooooo0_l000001Ooooooo0000o`000?l0003ooooo
00Co00001?ooool2o`0000;ooooo0ol00002ooooo`;o00000_ooool4o`000003ooooool0003o0000
00Gooooo0_l00006ooooo`Co00003oooool4o`0000Gooooo0_l00002oooooaWo00005?ooool2o`00
00Kooooo0_l0000@ooooo`;o000000?oooooo`000?l000001ol0000Hooooo`;o0000@oooool001co
oooo00?o0000ooooooooool0B_ooool2o`0000Kooooo0_l00009ooooo`;o00001_ooool4o`000003
ooooool0003o000000Gooooo0_l00006ooooo`Co000000?oooooo`000?l000006_ooool3o`000003
ooooool0003o0000017o000000?oooooo`000?l000004_ooool2o`0000Kooooo0_l0000Dooooo`Oo
00005oooool2o`0004Gooooo000Looooo`03o`000?oooooooooo04[ooooo0_l00006ooooo`;o0000
2Oooool2o`0000Kooooo1Ol00004ooooo`;o00002?ooool2o`0000Cooooo0ol0000;ooooo`;o0000
3Oooool2o`000003ooooool0003o0000013o00000_ooool2o`0001Wooooo1?l000000ooooooo0000
o`00000?ooooo`So00005oooool2o`0004Gooooo000Looooo`03o`000?oooooooooo04cooooo0_l0
000<ooooo`;o00002oooool3o`0000Cooooo0_l00008ooooo`;o00001Oooool2o`0000Gooooo0_l0
0004ooooo`;o00003OoooolEo`0000?ooooo0ol0000Gooooo`Oo00003Oooool4o`0000;ooooo1?l0
000Mooooo`;o0000?oooool001cooooo00?o0000ooooooooool0B?ooool2o`0000;ooooo0_l00004
ooooo`;o00000_ooool2o`0000;ooooo0_l0000Zooooo`;o00004ooooolBo`0000Gooooo1?l00000
0ooooooo0000o`00000Gooooo`;o00003oooool2o`0000Cooooo1_l0000Kooooo`;o0000?oooool0
01cooooo00?o0000ooooooooool0B?ooool2o`0000Sooooo0_l00002ooooo`;o00000_ooool2o`00
00Cooooo0_l0000joooooa;o000000Coooooo`000?l0003ooooo0ol00002ooooo`;o00004?ooool2
o`000003ooooool0003o000000Cooooo0_l00006ooooo`;o00002oooool2o`0000;ooooo0_l0001L
ooooo`007?ooool00ol0003oooooooooo`1Eooooo`;o00000oooool3o`0000?ooooo1?l0000Aoooo
o`?o00001_ooool2o`0001?ooooo0_l00007ooooo`Co00000_ooool2o`0000;ooooo2?l000000ooo
oooo0000o`000002ooooo`;o00005?ooool2o`000003ooooool0003o000000Cooooo0_l00006oooo
o`;o00002oooool2o`00063ooooo000Looooo`03o`000?oooooooooo04Gooooo0_l0000>ooooo`?o
00000oooool2o`0000Gooooo0_l0000Aooooo`?o00001_ooool2o`0001?ooooo0_l0000Cooooo`Go
00001?ooool2o`0000_ooooo1?l0000Aooooo`;o00001?ooool2o`0000?ooooo0_l0001Yooooo`00
7?ooool00ol0003oooooooooo`15ooooo`;o00001?ooool2o`0000Wooooo0_l00003ooooo`;o0000
3Oooool2o`0000[ooooo0_l00006ooooo`;o0000:_ooool3o`0000Cooooo0_l0000;ooooo`Co0000
1oooool2o`0000Gooooo0_l000000ooooooo0000o`000004ooooo`;o00000oooool2o`0001cooooo
0_l0001;ooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o00006?ooool2o`0000?ooooo0_l0
000:ooooo`;o00001Oooool2o`00023ooooo0_l00009ooooo`;o00007Oooool4o`0000?ooooo0_l0
000Zooooo`;o0000Boooool001cooooo00?o0000ooooooooool0EOooool2o`0000Gooooo0_l00007
ooooo`;o00003Oooool4o`0000Cooooo0ol00008ooooo`Co000000?oooooo`000?l000004Oooool2
o`000003ooooool0003o0000023ooooo0_l00002ooooo`Go00006?ooool2o`0001Cooooo0_l0001<
ooooo`007?ooool00ol0003oooooooooo`1Eooooo`;o000000?oooooo`000?l000000_ooool2o`00
0003ooooool0003o000000oooooo2?l00004ooooo`;o00002Oooool4o`000003ooooool0003o0000
01Cooooo0_l0000@ooooo`;o00000_ooool2o`0000[ooooo0_l00002ooooo`Co00006Oooool2o`00
01Cooooo0_l0001<ooooo`007?ooool2o`0005Wooooo0_l00005ooooo`;o000000?oooooo`000?l0
00001Oooool2o`0000Gooooo1Ol00002ooooo`;o00003_ooool2o`0000?ooooo0_l00007ooooo`;o
00002Oooool2o`0001;ooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo0_l00008ooooo`;o
00005oooool2o`0006Cooooo000Looooo`03o`000?oooooooooo05?ooooo0_l00003ooooo`;o0000
0oooool2o`0000?ooooo0_l00005ooooo`;o00003?ooool2o`0001cooooo0_l00009ooooo`;o0000
6_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0001Sooooo0_l00002ooooo`?o0000
0_ooool2o`0005oooooo000Looooo`03o`000?oooooooooo04Oooooo0_l00004ooooo`;o00001?oo
ool2o`000003ooooool0003o000000Gooooo1_l000000ooooooo0000o`00000Eooooo`;o00008?oo
ool2o`0000Cooooo0_l0000Kooooo`;o000000?oooooo`000?l000000_l0000Eooooo`;o000000?o
ooooo`000?l000000oooool2o`0000;ooooo0_l0001Oooooo`007?ooool00ol0003oooooooooo`17
ooooo`;o00001?ooool3o`0000?ooooo0_l000001?oooooo0000o`000?ooool3o`0000?ooooo1ol0
0004ooooo`;o000000?oooooo`000?l000003?ooool2o`0000Sooooo0_l0000Fooooo`;o00000ooo
ool3o`0000Sooooo0_l0000]ooooo`;o00001oooool2o`0006;ooooo000Looooo`03o`000?oooooo
oooo04kooooo0_l00009ooooo`?o00001_ooool2o`0000Kooooo0_l000000ooooooo0000o`000008
ooooo`;o00003?ooool2o`0000Oooooo0ol00008ooooo`;o00001oooool2o`0000Gooooo0_l00002
ooooo`?o00005_ooool2o`0001[ooooo0_l000001?oooooo0000o`000?ooool2o`00013ooooo0_l0
001=ooooo`007?ooool00ol0003oooooooooo`1Fooooo`;o00007?ooool2o`000003ooooool0003o
0000017ooooo0_l00002ooooo`?o000000Coooooo`000?l0003ooooo0_l00002ooooo`Co00003?oo
ool2o`0000?ooooo0_l0000Fooooo`;o00002oooool2o`0000_ooooo1?l00004ooooo`;o00004?oo
ool2o`0004gooooo000Looooo`03o`000?oooooooooo05Kooooo0_l00008ooooo`Co00004?ooool2
o`000003ooooool0003o000000kooooo1Ol00003ooooo`;o000000Coooooo`000?l0003ooooo1?l0
0002ooooo`;o00003Oooool2o`0001kooooo0_l00007ooooo`;o00002oooool5o`0000oooooo0_l0
001Cooooo`007?ooool00ol0003oooooooooo`1Looooo`;o00000_ooool5o`0000Gooooo0_l00005
ooooo`;o00001?ooool2o`0000kooooo1?l00004ooooo`;o00001Oooool3o`0000[ooooo0_l00002
ooooo`;o000000?oooooo`000?l000001_ooool2o`0001Kooooo0_l00008ooooo`;o00002oooool4
o`0000oooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`1Looooo`;o00000oooool4o`00
00Cooooo1Ol00003ooooo`;o00004oooool2o`0000Wooooo0_l00004ooooo`;o00001?ooool2o`00
00Cooooo0_l00002ooooo`?o00002?ooool2o`0001gooooo0_l000000ooooooo0000o`00000<oooo
o`;o00004?ooool3o`0005;ooooo000Looooo`03o`000?oooooooooo05cooooo0_l00004ooooo`;o
00001Oooool2o`000003ooooool0003o000000;ooooo0_l0000Dooooo`Co000000Coooooo`000?l0
003o00000oooool2o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l000001_ooool2o`00
00Gooooo0_l00006ooooo`;o00001oooool2o`0000kooooo0ol000000ooooooo0000o`00000<oooo
o`;o00004?ooool3o`0005;ooooo000Looooo`03o`000?oooooooooo05Sooooo0_l0000Dooooo`So
00000oooool2o`000003ooooool0003o000000[ooooo0_l000001Ooooooo0000o`000?l0003ooooo
00;o00001Oooool2o`0000Sooooo1?l00004ooooo`;o00001Oooool2o`0000Kooooo0_l00007oooo
o`Go00002oooool2o`0000Kooooo0_l0000Dooooo`;o0000FOooool001cooooo00?o0000oooooooo
ool0E?ooool2o`000004ooooool0003o0000o`00017ooooo0_l000000ooooooo0000o`000002oooo
o`Co00000oooool2o`000003ooooool0003o000000Gooooo0_l00008ooooo`Co00001Oooool2o`00
00[ooooo0_l00009ooooo`;o00004oooool3o`0000[ooooo0_l00007ooooo`;o00001oooool4o`00
00Wooooo0_l0001Iooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o000000?oooooo`000?l0
00002oooool2o`0000Gooooo0_l0000<ooooo`?o00000_ooool2o`000003ooooool0003o000000;o
00001?ooool2o`0000;ooooo1_l0000Fooooo`;o00000_ooool2o`0001kooooo1?l0000@ooooo`Co
0000I?ooool001cooooo00?o0000ooooooooool0DOooool2o`0000Kooooo0_l00009ooooo`;o0000
2Oooool2o`0000Sooooo0ol00002ooooo`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`?o
00000oooool4o`000003ooooool0003o000000;o00004Oooool2o`0000kooooo0ol0000>ooooo`;o
000000?oooooo`000?l000000_ooool2o`0007Kooooo000Looooo`03o`000?oooooooooo057ooooo
0_l00006ooooo`;o00005?ooool2o`0000gooooo0_l00004ooooo`;o00001?ooool2o`0000Sooooo
1_l0000<ooooo`?o00000oooool3o`000003ooooool0003o000000Oooooo0ol00002ooooo`;o0000
2_ooool2o`000004ooooool0003o0000ooooo`Go00002?ooool2o`0006[ooooo000Looooo`03o`00
0?oooooooooo06kooooo0_l000000ooooooo0000o`00000=ooooo`;o00003oooool2o`0000Gooooo
1Ol000001?oooooo0000o`000?l00005ooooo`?o00000oooool3o`000003ooooool0003o000000;o
oooo0_l00003ooooo`;o000000?oooooo`000?l000000_l0000@ooooo`;o000000Coooooo`000?l0
003o00001oooool2o`0006[ooooo000Looooo`;o0000JOooool2o`0000Cooooo0_l000000ooooooo
0000o`00000=ooooo`;o00003oooool2o`0000Oooooo0ol000001?oooooo0000o`000?l0000;oooo
o`;o00001_ooool2o`0000;ooooo0ol000000ooooooo0000o`00000?ooooo`;o000000?oooooo`00
0?l000001?l0000Dooooo`;o0000GOooool001cooooo00?o0000ooooooooool0F?ooool2o`0000ko
oooo0_l0000?ooooo`;o00003Oooool2o`0000Oooooo0_l0000Uooooo`;o00004oooool2o`000003
ooooool0003o000000;o00005_ooool2o`0005gooooo000Looooo`03o`000?oooooooooo05Sooooo
0_l0000Cooooo`;o00002_ooool3o`0000Kooooo1?l00002ooooo`;o00004_ooool2o`00027ooooo
0_l0000?ooooo`;o0000Moooool001cooooo00?o0000ooooooooool0KOooool2o`0000_ooooo0_l0
0006ooooo`Ko00001Oooool2o`0000gooooo0_l000000ooooooo0000o`00000?ooooo`;o00000ooo
ool2o`0000Kooooo1?l00005ooooo`;o0000POooool001cooooo00?o0000ooooooooool0N_ooool2
o`0000Wooooo0ol00003ooooo`Co00000_ooool2o`0000?ooooo0_l00007ooooo`Co00002_ooool5
o`0000?ooooo0_l00006ooooo`;o00000_ooool2o`0000?ooooo0_l0000=ooooo`Go00001?ooool2
o`0006Wooooo000Looooo`03o`000?oooooooooo07Sooooo0ol0000@ooooo`;o00001?ooool2o`00
00;ooooo0ol00009ooooo`Go00001oooool5o`0000_ooooo1_l00005ooooo`;o00000oooool2o`00
00Kooooo1_l00003ooooo`;o0000JOooool001cooooo00?o0000ooooooooool0M_ooool5o`0001[o
oooo0_l000000ooooooo0000o`000002o`0000Kooooo1?l000000ooooooo0000o`000003ooooo`;o
00002?ooool2o`0000Gooooo1?l00007ooooo`;o00000oooool2o`0000Kooooo0_l00002ooooo`;o
0000K_ooool001cooooo00?o0000ooooooooool0E?ooool2o`00023ooooo0_l00005ooooo`;o0000
2oooool2o`0000Cooooo0_l00006ooooo`Ko00002Oooool4o`000003ooooool0003o000000Kooooo
1?l000000ooooooo0000o`000002ooooo`;o00005_ooool2o`0007;ooooo000Looooo`03o`000?oo
oooooooo05Cooooo0_l0000Looooo`Co00001?ooool5o`0000;ooooo0_l00004ooooo`;o000000?o
ooooo`000?l000001?ooool4o`000003ooooool0003o000000Cooooo1Ol00007ooooo`Co00002Ooo
ool3o`0000;ooooo0_l00002ooooo`;o00001oooool2o`0000[ooooo0_l000000ooooooo0000o`00
001booooo`007?ooool00ol0003oooooooooo`1Dooooo`;o00007?ooool4o`0000?ooooo1?l00004
ooooo`;o00001?ooool2o`0000Cooooo0_l00002ooooo`?o000000?oooooo`000?l000001_ooool6
o`0000Wooooo0_l00007ooooo`Go00000oooool2o`0000Oooooo0_l00008ooooo`Co0000MOooool0
01cooooo00?o0000ooooooooool0E?ooool2o`0000Sooooo0_l0000Iooooo`;o00001_ooool4o`00
00Sooooo0_l000000ooooooo0000o`000004o`000003ooooool0003o000000Cooooo2?l00007oooo
o`;o000000?oooooo`000?l000000ol000000ooooooo0000o`000003o`0000cooooo0_l00008oooo
o`Co00000_ooool3o`0000Kooooo0_l0001Xooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o
00006oooool3o`0000?ooooo1Ol00009ooooo`?o000000?oooooo`000?l000001?l00004ooooo`;o
00001?ooool2o`0000Kooooo0_l00002ooooo`Go00008_ooool3o`0000Kooooo0_l0001Xooooo`00
7?ooool00ol0003oooooooooo`1Fooooo`;o00008Oooool6o`0000;ooooo0_l000000ooooooo0000
o`000009ooooo`Co000000Coooooo`000?l0003o00004Oooool2o`000003ooooool0003o0000023o
oooo0_l0001jooooo`007?ooool00ol0003oooooooooo`1Fooooo`;o00003Oooool2o`0001;ooooo
0ol000000ooooooo0000o`000002ooooo`;o00001_ooool2o`0000;ooooo1_l00003ooooo`;o0000
4?ooool2o`0000oooooo0_l0000Booooo`;o0000N_ooool00006ooooooo^k^ko<S8bo`000?lb<S;o
k^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo
06Gooooo0_l0000Cooooo`Co00002oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`00
0004ooooool0003o0000ooooo`;o00000_ooool2o`0001Oooooo0_l000000ooooooo0000o`00002;
ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooo
oonHV9So8B4Q00Kooooo00?o0000ooooooooool0O?ooool2o`0000_ooooo0_l000000ooooooo0000
o`000004ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`000003ooooool0003o000000;o
oooo0_l0000=ooooo`;o00000oooool2o`0000Kooooo0_l0000Cooooo`;o0000M_ooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool0ROooool2o`000003ooooool0003o000000Oooooo0_l00002ooooo`Go
00001oooool2o`0000Sooooo1?l000000ooooooo0000o`00000?ooooo`Go00001_ooool3o`0007Ko
oooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?oooooo
V9RHoc8b<P06ooooo`?o0000JOooool2o`0002?ooooo0_l00005ooooo`;o00000_ooool5o`0000Oo
oooo0_l00009ooooo`Ko00003oooool5o`0000Kooooo0_l0001gooooo`0000?oooooo`000?ooool0
0_ooool00ol0003oooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003o
ooooooooo`1Yooooo`?o00008_ooool2o`0000Sooooo0_l00008ooooo`;o00000oooool2o`0000Co
oooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l0000?ooooo`;o0000P?ooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00Ko
oooo00?o0000ooooooooool0J_ooool2o`0001?ooooo0_l00007ooooo`;o00003_ooool2o`0000?o
oooo0_l00003ooooo`;o00000oooool2o`0000Cooooo1?l00005ooooo`;o00007_ooool2o`00077o
oooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zjo`000006
ooooo`03o`000?oooooooooo06_ooooo0_l0000Booooo`;o00001oooool4o`0000cooooo0_l00000
0ooooooo0000o`000002o`00013ooooo1?l00005ooooo`;o000000?oooooo`000?l000001oooool2
o`00013ooooo0_l0001aooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@
413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`1[ooooo`;o00005?ooool2o`0000Oooooo
0_l000001?oooooo0000o`000?ooool2o`0000Kooooo0_l000000ooooooo0000o`00000:ooooo`;o
00002?ooool2o`0000Gooooo1Ol00007ooooo`;o0000Poooool001cooooo00?o0000ooooooooool0
POooool2o`0000[ooooo0_l000000ooooooo0000o`00000:ooooo`;o00001oooool4o`0000;ooooo
0_l00004ooooo`;o00001_ooool2o`0000;ooooo0_l00008ooooo`;o0000P?ooool001cooooo00?o
0000ooooooooool0W?ooool2o`0000Oooooo2_l00006ooooo`;o00000oooool2o`000003ooooool0
003o000000Oooooo0ol00005ooooo`;o0000NOooool001cooooo00?o0000ooooooooool0W?ooool2
o`0000Sooooo1_l000000ooooooo0000o`000006ooooo`;o00000oooool4o`0000Sooooo1?l00004
ooooo`;o0000NOooool001cooooo00?o0000ooooooooool0V_ooool4o`0000cooooo0ol00002oooo
o`;o00002oooool2o`0000Wooooo0ol00005ooooo`;o00002Oooool2o`0006gooooo000Looooo`03
o`000?oooooooooo08gooooo0_l0000;ooooo`;o00003?ooool2o`000003ooooool0003o000000;o
oooo0_l00006ooooo`;o00001?ooool2o`0000Sooooo0_l00006ooooo`;o00002Oooool2o`0006go
oooo000Looooo`03o`000?oooooooooo08gooooo0_l00008ooooo`;o00003oooool2o`0000gooooo
0_l00004ooooo`;o00001?ooool2o`0008Cooooo000Looooo`03o`000?oooooooooo07Oooooo0_l0
000Nooooo`;o00000oooool2o`0000kooooo0_l0000Eooooo`;o0000Q?ooool001cooooo00?o0000
ooooooooool0Moooool2o`0002?ooooo0_l0000>ooooo`;o00003?ooool2o`0000Wooooo0_l00022
ooooo`007?ooool00ol0003oooooooooo`1jooooo`;o0000:_ooool2o`0000Cooooo0_l0000:oooo
o`Co00002Oooool2o`0008;ooooo000Looooo`03o`000?oooooooooo07[ooooo0_l00003ooooo`;o
00001oooool2o`0001Cooooo0_l00006ooooo`;o000000?oooooo`000?l000003Oooool2o`0008oo
oooo000Looooo`03o`000?oooooooooo07oooooo0_l00007ooooo`;o00003oooool2o`0000?ooooo
0_l00009ooooo`;o0000W_ooool001cooooo0_l0002=ooooo`;o00002oooool2o`000:kooooo000L
ooooo`03o`000?oooooooooo08cooooo0_l0000Qooooo`;o0000V?ooool001cooooo00?o0000oooo
ooooool0U?ooool2o`0001Wooooo0_l0002Hooooo`007?ooool00ol0003oooooooooo`29ooooo`;o
00002Oooool2o`0000;ooooo0_l0000Pooooo`;o0000SOooool001cooooo00?o0000ooooooooool0
ROooool2o`0000gooooo0_l0000Booooo`;o00003?ooool2o`0008gooooo000Looooo`03o`000?oo
oooooooo0:_ooooo0ol0002Kooooo`007?ooool00ol0003oooooooooo`2[ooooo`;o00001Oooool2
o`0000;ooooo0_l0002Aooooo`007?ooool00ol0003oooooooooo`1hooooo`;o0000>?ooool6o`00
097ooooo000Looooo`03o`000?oooooooooo07Sooooo0_l0000[ooooo`;o00003Oooool2o`0009?o
oooo000Looooo`03o`000?oooooooooo0:Gooooo0_l0002Rooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo08Sooooo0_l0002oooooo`007?ooool00ol0
003oooooooooo`28ooooo`;o0000_oooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo08oooooo0_l0002hoooo
o`007?ooool00ol0003oooooooooo`2?ooooo`;o0000^?ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0V?ooool2o`000:oooooo000Looooo`03
o`000?oooooooooo09Sooooo0_l0002_ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooo
od_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001;ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB_ooool0
01Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03
o`000?oooooooooo00Gooooo0ol0003ooooood[ooooo000Dooooo`03o`000?oooooooooo0?oooooo
D_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3o
oooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001;ooooo00?oEEEEofIVI_l0
0000oooooomDooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00YOooool01?l@
413o0000o`000?ooool2o`000003oa0@4?oooooooooo01Gooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<
c003ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01Oooool2o`000003oa0@4?oooooooooo08kooooo
002Vooooo`05o`000?ooooooooooooooool000002Oooool6o`0000Wooooo00Go8B4QoiRHV?oooooo
V9RHob4Q8@03ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2?oooo
o`00Y_ooool01Ol0003ooooooooooooooooo000001Sooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000oooool5o`00093ooooo002Vooooo`05o`000?oooooo
ooooooooool000002Oooool6o`0000Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P03ooooo`05o`00
0?nHV9SooooooiRHV?lQ8B400oooool01?m4A4CogMgMooooool0002Aooooo`00Y_ooool01Ol0003o
QhN7oooooonYZJWo000001Sooooo00Goc<c<o`000?l0003o0000olc<c003ooooo`05o`000?mEEEGo
0000oa0@4?o<c<`00oooool01?oMgMgoEEEEooooool0002Aooooo`00YOooool00ol@413o0000ogMg
M`02o`000003oiRHV?oooooooooo01Kooooo00Go410@okZj^_oooooo^[Zjoa0@4003ooooo`03oeEE
EOn7QhOooooo00Kooooo00?oMgMgolc<c?l00000TOooool00<?ooooo00Go0000okZj^_oooooo^[Zj
o`000003ooooo`03omgMgOl@413oV9RH00Kooooo00?ok^k^odA4A?l00000TOooool00<?ooooo00Go
ZJVYoa0@4?l0003o410@ojVYZ@04ooooo`04olc<c?m4A4Co0000oa0@40Gooooo00?oMgMgo`000?oo
ool0T?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(870) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.33171 .5637 Mdot
.35776 .57704 Mdot
.68644 .57172 Mdot
.43776 .4384 Mdot
.39824 .51336 Mdot
.66712 .55647 Mdot
.48423 .62934 Mdot
.46727 .65949 Mdot
.66628 .53674 Mdot
.41916 .29062 Mdot
.49538 .66766 Mdot
.44275 .32418 Mdot
.50255 .64072 Mdot
.44108 .41387 Mdot
.81189 .36236 Mdot
.48326 .42102 Mdot
.36248 .61475 Mdot
.65263 .43933 Mdot
.39057 .3458 Mdot
.63467 .57512 Mdot
.29418 .56929 Mdot
.44666 .41197 Mdot
.32263 .56995 Mdot
.44096 .41289 Mdot
.41408 .4352 Mdot
.33383 .58955 Mdot
.3686 .62092 Mdot
.3916 .42073 Mdot
.408 .40857 Mdot
.50169 .67769 Mdot
.59907 .38874 Mdot
.70574 .25007 Mdot
.48577 .37087 Mdot
.17548 .53032 Mdot
.46367 .64996 Mdot
.45015 .21621 Mdot
.64252 .52563 Mdot
.51924 .65367 Mdot
.46882 .6599 Mdot
.45899 .6268 Mdot
.51578 .65444 Mdot
.34043 .59273 Mdot
.45347 .65934 Mdot
.46359 .68585 Mdot
.4663 .42748 Mdot
.43174 .73278 Mdot
.57725 .24196 Mdot
.40788 .37558 Mdot
.36971 .56975 Mdot
.6251 .56376 Mdot
.23157 .62445 Mdot
.45886 .65656 Mdot
.69194 .69387 Mdot
.58946 .1064 Mdot
.51067 .63637 Mdot
.45626 .4394 Mdot
.64822 .54117 Mdot
.44852 .38665 Mdot
.44101 .40345 Mdot
.26027 .5599 Mdot
.39241 .40918 Mdot
.67182 .40244 Mdot
.3054 .56439 Mdot
.6569 .50138 Mdot
.66586 .54879 Mdot
.48353 .67145 Mdot
.36351 .61006 Mdot
.49432 .63921 Mdot
.38273 .43096 Mdot
.63448 .52449 Mdot
.40867 .37455 Mdot
.50355 .67045 Mdot
.34324 .54698 Mdot
.4343 .35618 Mdot
.46548 .77763 Mdot
.83514 .45168 Mdot
.67602 .45063 Mdot
.27427 .52842 Mdot
.3575 .49931 Mdot
.80748 .55741 Mdot
.422 .40865 Mdot
.71948 .75383 Mdot
.81842 .38257 Mdot
.33164 .56625 Mdot
.35387 .394 Mdot
.67702 .60878 Mdot
.45624 .36311 Mdot
.51708 .49697 Mdot
.41556 .45953 Mdot
.40111 .77726 Mdot
.66296 .53234 Mdot
.35648 .60115 Mdot
.43821 .43695 Mdot
.3968 .36833 Mdot
.25679 .44968 Mdot
.38177 .37262 Mdot
.40795 .44229 Mdot
.3892 .57391 Mdot
.47886 .6605 Mdot
.49185 .3625 Mdot
.5202 .69372 Mdot
.68005 .66275 Mdot
.4664 .40807 Mdot
.65914 .51663 Mdot
.382 .56143 Mdot
.46918 .37731 Mdot
.48036 .6213 Mdot
.40352 .39358 Mdot
.45102 .66286 Mdot
.36299 .57544 Mdot
.39969 .36344 Mdot
.64548 .42349 Mdot
.52062 .81241 Mdot
.35185 .60695 Mdot
.66874 .73671 Mdot
.39712 .38969 Mdot
.45294 .40512 Mdot
.35618 .5797 Mdot
.65658 .57333 Mdot
.55792 .45319 Mdot
.37942 .58022 Mdot
.46094 .63136 Mdot
.32968 .62629 Mdot
.37374 .44592 Mdot
.67605 .54185 Mdot
.68907 .66465 Mdot
.70215 .67793 Mdot
.54686 .34219 Mdot
.46292 .37013 Mdot
.36146 .66977 Mdot
.66565 .56477 Mdot
.35447 .59659 Mdot
.49598 .64272 Mdot
.46337 .44281 Mdot
.32631 .61395 Mdot
.49347 .65848 Mdot
.65302 .40013 Mdot
.72453 .41035 Mdot
.37424 .56873 Mdot
.52937 .59367 Mdot
.46559 .61091 Mdot
.46224 .62394 Mdot
.19116 .56759 Mdot
.35471 .57368 Mdot
.67568 .43043 Mdot
.48967 .6521 Mdot
.63714 .3142 Mdot
.44202 .45059 Mdot
.51753 .33289 Mdot
.58519 .84286 Mdot
.22619 .62677 Mdot
.57986 .74479 Mdot
.67808 .43936 Mdot
.47086 .61772 Mdot
.41338 .42323 Mdot
.34621 .57247 Mdot
.34272 .58115 Mdot
.39013 .43124 Mdot
.4149 .44019 Mdot
.4138 .3646 Mdot
.39442 .37529 Mdot
.63024 .26067 Mdot
.40547 .36589 Mdot
.64935 .47395 Mdot
.34015 .60908 Mdot
.40238 .42447 Mdot
.65466 .57808 Mdot
.48164 .38229 Mdot
.51209 .66384 Mdot
.44789 .3999 Mdot
.42998 .44328 Mdot
.41341 .34561 Mdot
.51427 .63543 Mdot
.66348 .23435 Mdot
.56607 .83995 Mdot
.48202 .17879 Mdot
.62196 .74489 Mdot
.64492 .55563 Mdot
.46382 .38473 Mdot
.67402 .41874 Mdot
.33258 .32713 Mdot
.429 .40223 Mdot
.25728 .71583 Mdot
.423 .44603 Mdot
.19923 .42992 Mdot
.44318 .4905 Mdot
.4818 .17227 Mdot
.59329 .46661 Mdot
.40241 .40618 Mdot
.26143 .40387 Mdot
.29641 .29975 Mdot
.43371 .58577 Mdot
.5149 .64942 Mdot
.6598 .57785 Mdot
.64871 .53179 Mdot
.44783 .62726 Mdot
.4963 .41087 Mdot
.51241 .39247 Mdot
.4473 .31429 Mdot
.69156 .67257 Mdot
.33754 .54799 Mdot
.68984 .39696 Mdot
.36205 .5527 Mdot
.78644 .69528 Mdot
.36461 .75599 Mdot
.44284 .61954 Mdot
.70357 .42212 Mdot
.68269 .57324 Mdot
.69376 .67529 Mdot
.67057 .42495 Mdot
.42089 .38079 Mdot
.37092 .57924 Mdot
.21109 .38199 Mdot
.42233 .49184 Mdot
.21579 .34608 Mdot
.31467 .61228 Mdot
.55617 .48093 Mdot
.50194 .65718 Mdot
.64965 .5885 Mdot
.45352 .41838 Mdot
.42806 .36563 Mdot
.32781 .54224 Mdot
.4095 .37706 Mdot
.38791 .52138 Mdot
.43673 .4446 Mdot
.6372 .59276 Mdot
.66428 .45434 Mdot
.44798 .63188 Mdot
.54408 .34665 Mdot
.3234 .56223 Mdot
.60006 .57592 Mdot
.62644 .55576 Mdot
.34666 .30359 Mdot
.49961 .6706 Mdot
.64576 .41828 Mdot
.63229 .5637 Mdot
.69888 .4067 Mdot
.46003 .35646 Mdot
.64043 .52545 Mdot
.6902 .42213 Mdot
.65966 .25925 Mdot
.46939 .42845 Mdot
.65378 .28818 Mdot
.48085 .63294 Mdot
.32403 .62517 Mdot
.39287 .41233 Mdot
.70344 .67092 Mdot
.45095 .34106 Mdot
.55661 .71762 Mdot
.69799 .69333 Mdot
.679 .68579 Mdot
.81523 .51209 Mdot
.65366 .43315 Mdot
.53472 .76925 Mdot
.31765 .67235 Mdot
.36654 .60906 Mdot
.45029 .43732 Mdot
.55322 .16867 Mdot
.49046 .65228 Mdot
.42225 .38442 Mdot
.66291 .60627 Mdot
.48812 .64881 Mdot
.45058 .3811 Mdot
.50014 .6223 Mdot
.34625 .57648 Mdot
.73556 .60566 Mdot
.35175 .6222 Mdot
.46495 .4351 Mdot
.48199 .62347 Mdot
.63286 .55074 Mdot
.33125 .58689 Mdot
.40711 .393 Mdot
.45702 .41018 Mdot
.68529 .67434 Mdot
.40032 .41447 Mdot
.56424 .17801 Mdot
.39067 .39574 Mdot
.686 .54028 Mdot
.38054 .38305 Mdot
.22792 .68205 Mdot
.71549 .46388 Mdot
.36691 .60483 Mdot
.68366 .68862 Mdot
.6617 .53912 Mdot
.77797 .52837 Mdot
.47973 .57364 Mdot
.41201 .40214 Mdot
.67871 .67825 Mdot
.58182 .44107 Mdot
.49938 .68112 Mdot
.37796 .37342 Mdot
.4033 .76052 Mdot
.63994 .57527 Mdot
.69132 .67525 Mdot
.37895 .34871 Mdot
.38203 .56049 Mdot
.43595 .43896 Mdot
.63067 .54132 Mdot
.332 .62721 Mdot
.47718 .39202 Mdot
.51871 .23933 Mdot
.70055 .68717 Mdot
.48282 .63305 Mdot
.4854 .46015 Mdot
.40808 .36743 Mdot
.64151 .53709 Mdot
.31294 .58114 Mdot
.46365 .64372 Mdot
.33563 .59809 Mdot
.25251 .33249 Mdot
.61346 .75536 Mdot
.59524 .2353 Mdot
.70547 .41938 Mdot
.59111 .68119 Mdot
.45688 .17838 Mdot
.55054 .78209 Mdot
.58857 .32255 Mdot
.32766 .22677 Mdot
.64309 .57184 Mdot
.70492 .43838 Mdot
.65687 .5421 Mdot
.42746 .42618 Mdot
.66772 .55225 Mdot
.48117 .16756 Mdot
.42594 .44738 Mdot
.64352 .55011 Mdot
.74991 .55103 Mdot
.40409 .43367 Mdot
.34926 .60937 Mdot
.79653 .35225 Mdot
.42165 .80622 Mdot
.28105 .69111 Mdot
.64693 .56492 Mdot
.28893 .55216 Mdot
.3942 .42434 Mdot
.48253 .37086 Mdot
.34056 .57212 Mdot
.37742 .38756 Mdot
.68627 .39567 Mdot
.69878 .40178 Mdot
.53498 .35765 Mdot
.6525 .78195 Mdot
.49425 .36221 Mdot
.33205 .58338 Mdot
.34052 .44347 Mdot
.46051 .77305 Mdot
.6866 .6542 Mdot
.53468 .65882 Mdot
.67743 .24733 Mdot
.50316 .40279 Mdot
.52215 .59298 Mdot
.42666 .76695 Mdot
.3658 .58982 Mdot
.61005 .2144 Mdot
.51137 .64162 Mdot
.29308 .38985 Mdot
.20145 .48834 Mdot
.42551 .37088 Mdot
.49076 .67012 Mdot
.47461 .33949 Mdot
.36579 .77205 Mdot
.67017 .3213 Mdot
.8236 .60409 Mdot
.4673 .42924 Mdot
.51848 .76887 Mdot
.45056 .40374 Mdot
.55116 .40694 Mdot
.39015 .39531 Mdot
.32987 .59704 Mdot
.38356 .3029 Mdot
.4779 .53629 Mdot
.62811 .81009 Mdot
.34903 .74864 Mdot
.68336 .43649 Mdot
.45515 .41026 Mdot
.42704 .36981 Mdot
.65345 .42591 Mdot
.31894 .58765 Mdot
.39231 .3887 Mdot
.50916 .27546 Mdot
.41662 .36663 Mdot
.51736 .65974 Mdot
.58514 .40805 Mdot
.36937 .52596 Mdot
.40325 .3545 Mdot
.36191 .61911 Mdot
.50828 .62978 Mdot
.48058 .67127 Mdot
.3835 .44319 Mdot
.48196 .61657 Mdot
.43853 .44055 Mdot
.64655 .36077 Mdot
.34542 .56184 Mdot
.40913 .49696 Mdot
.31551 .59205 Mdot
.33392 .51395 Mdot
.48648 .61937 Mdot
.69967 .66809 Mdot
.38046 .63996 Mdot
.5072 .63855 Mdot
.26883 .67484 Mdot
.47936 .33075 Mdot
.43143 .33103 Mdot
.33874 .75565 Mdot
.64172 .56427 Mdot
.69818 .67188 Mdot
.475 .62377 Mdot
.40957 .36598 Mdot
.39625 .34753 Mdot
.52228 .66147 Mdot
.28014 .45378 Mdot
.77679 .5147 Mdot
.39543 .42934 Mdot
.32503 .59432 Mdot
.35195 .59803 Mdot
.47489 .37804 Mdot
.41478 .3957 Mdot
.6862 .55134 Mdot
.69208 .68993 Mdot
.67625 .65936 Mdot
.70135 .67781 Mdot
.6631 .5961 Mdot
.44925 .70989 Mdot
.45975 .62581 Mdot
.39226 .67883 Mdot
.54106 .71341 Mdot
.41886 .48492 Mdot
.63783 .5415 Mdot
.43813 .37093 Mdot
.44461 .42967 Mdot
.46402 .64263 Mdot
.60655 .70736 Mdot
.35624 .40817 Mdot
.3616 .56026 Mdot
.48653 .61704 Mdot
.4996 .3591 Mdot
.42797 .66471 Mdot
.68892 .40465 Mdot
.28065 .69475 Mdot
.49744 .67222 Mdot
.36417 .59906 Mdot
.52526 .64866 Mdot
.42334 .3673 Mdot
.41454 .45095 Mdot
.36071 .58328 Mdot
.65843 .43898 Mdot
.36675 .39265 Mdot
.45212 .38107 Mdot
.35324 .82244 Mdot
.46992 .77816 Mdot
.54396 .6324 Mdot
.40882 .41541 Mdot
.40529 .34168 Mdot
.69251 .43101 Mdot
.41764 .36899 Mdot
.45814 .41297 Mdot
.52773 .81682 Mdot
.5504 .66849 Mdot
.64169 .42859 Mdot
.29608 .38588 Mdot
.31704 .61406 Mdot
.60694 .19591 Mdot
.6763 .66411 Mdot
.47874 .68145 Mdot
.72735 .61176 Mdot
.695 .68042 Mdot
.56662 .70235 Mdot
.61078 .20654 Mdot
.70057 .67603 Mdot
.6562 .61682 Mdot
.36183 .34004 Mdot
.39776 .43633 Mdot
.45113 .39614 Mdot
.67872 .41585 Mdot
.35255 .57354 Mdot
.57648 .47281 Mdot
.71655 .33264 Mdot
.44913 .41017 Mdot
.28795 .6019 Mdot
.68285 .26772 Mdot
.68791 .6773 Mdot
.66525 .39846 Mdot
.67057 .38617 Mdot
.45404 .40165 Mdot
.56097 .80474 Mdot
.33389 .58763 Mdot
.40744 .39336 Mdot
.41024 .35666 Mdot
.64352 .56175 Mdot
.36982 .59107 Mdot
.62627 .55138 Mdot
.70092 .69116 Mdot
.33233 .25443 Mdot
.31435 .79522 Mdot
.46734 .64273 Mdot
.51627 .18999 Mdot
.48906 .67953 Mdot
.82782 .55065 Mdot
.69746 .68412 Mdot
.42496 .40426 Mdot
.32638 .55854 Mdot
.40311 .39179 Mdot
.42836 .3828 Mdot
.42191 .3795 Mdot
.4786 .33328 Mdot
.2532 .71002 Mdot
.66303 .41822 Mdot
.3963 .47489 Mdot
.67964 .52903 Mdot
.54499 .1831 Mdot
.79315 .37651 Mdot
.44 .36593 Mdot
.45743 .39947 Mdot
.34064 .6132 Mdot
.38613 .42488 Mdot
.51155 .67863 Mdot
.31312 .57952 Mdot
.4186 .34339 Mdot
.59757 .21318 Mdot
.39373 .38436 Mdot
.45547 .1857 Mdot
.5258 .65193 Mdot
.27359 .67782 Mdot
.39426 .47075 Mdot
.70135 .67371 Mdot
.69853 .67233 Mdot
.67151 .65615 Mdot
.52653 .67125 Mdot
.64172 .54365 Mdot
.77044 .38104 Mdot
.49243 .40918 Mdot
.41436 .42669 Mdot
.40053 .34346 Mdot
.69053 .5845 Mdot
.51541 .49244 Mdot
.55959 .75845 Mdot
.49611 .35273 Mdot
.68269 .55299 Mdot
.31836 .62351 Mdot
.68153 .71734 Mdot
.31463 .57822 Mdot
.64292 .43142 Mdot
.49943 .66665 Mdot
.68637 .3994 Mdot
.25112 .65239 Mdot
.36083 .57613 Mdot
.33615 .53827 Mdot
.64379 .55355 Mdot
.54814 .50811 Mdot
.54901 .11603 Mdot
.64223 .51419 Mdot
.54098 .30958 Mdot
.33443 .57456 Mdot
.4147 .35007 Mdot
.58634 .42812 Mdot
.54214 .50834 Mdot
.65163 .55208 Mdot
.43056 .41303 Mdot
.62206 .79354 Mdot
.68622 .55521 Mdot
.37885 .36978 Mdot
.66723 .56961 Mdot
.51126 .66062 Mdot
.66473 .56753 Mdot
.31102 .57592 Mdot
.46862 .38158 Mdot
.58193 .11533 Mdot
.58333 .52115 Mdot
.39374 .40237 Mdot
.48717 .61721 Mdot
.47797 .26055 Mdot
.43564 .38301 Mdot
.68077 .3926 Mdot
.67803 .54411 Mdot
.77284 .47886 Mdot
.39206 .41844 Mdot
.65835 .56157 Mdot
.32759 .56444 Mdot
.51492 .68785 Mdot
.82216 .5051 Mdot
.68932 .66111 Mdot
.34668 .56825 Mdot
.69149 .7007 Mdot
.52009 .62666 Mdot
.39518 .35076 Mdot
.41035 .35958 Mdot
.33287 .60402 Mdot
.73752 .64686 Mdot
.38292 .39773 Mdot
.42225 .40869 Mdot
.67701 .58122 Mdot
.69497 .5594 Mdot
.74387 .61954 Mdot
.64097 .56913 Mdot
.38215 .35514 Mdot
.33313 .60337 Mdot
.43882 .43153 Mdot
.35352 .60989 Mdot
.44819 .43763 Mdot
.34308 .63899 Mdot
.33395 .56608 Mdot
.63508 .76475 Mdot
.43508 .42375 Mdot
.46351 .47837 Mdot
.42553 .37979 Mdot
.41184 .37175 Mdot
.67505 .52831 Mdot
.65613 .41534 Mdot
.44088 .46469 Mdot
.6106 .51253 Mdot
.66416 .39626 Mdot
.26528 .32855 Mdot
.64512 .56501 Mdot
.68303 .41031 Mdot
.65645 .28151 Mdot
.6787 .68404 Mdot
.67006 .41422 Mdot
.7875 .36546 Mdot
.46614 .64278 Mdot
.31288 .61549 Mdot
.4049 .43404 Mdot
.30828 .24646 Mdot
.62395 .36743 Mdot
.6819 .6776 Mdot
.39221 .39817 Mdot
.4384 .37452 Mdot
.38595 .58045 Mdot
.76137 .72094 Mdot
.6893 .56962 Mdot
.42542 .43059 Mdot
.3525 .61928 Mdot
.62055 .83285 Mdot
.66702 .51957 Mdot
.67336 .41515 Mdot
.52243 .65516 Mdot
.39201 .60368 Mdot
.68832 .66006 Mdot
.50379 .68232 Mdot
.70583 .61428 Mdot
.25679 .6691 Mdot
.3968 .38711 Mdot
.6381 .53567 Mdot
.2266 .6373 Mdot
.49686 .39229 Mdot
.52526 .60787 Mdot
.51673 .35571 Mdot
.3645 .59335 Mdot
.52164 .65961 Mdot
.69551 .4112 Mdot
.31123 .57998 Mdot
.32049 .58751 Mdot
.46156 .6524 Mdot
.70588 .57687 Mdot
.55327 .48584 Mdot
.51399 .66661 Mdot
.41356 .7777 Mdot
.22561 .36583 Mdot
.6831 .68511 Mdot
.65496 .40528 Mdot
.17359 .46851 Mdot
.33982 .59331 Mdot
.67458 .24471 Mdot
.24144 .674 Mdot
.4074 .44192 Mdot
.6851 .42256 Mdot
.49255 .72489 Mdot
.75973 .36537 Mdot
.48549 .64515 Mdot
.47232 .52241 Mdot
.65329 .3927 Mdot
.38865 .41907 Mdot
.26951 .6149 Mdot
.42753 .41936 Mdot
.50051 .66303 Mdot
.35851 .51055 Mdot
.36346 .60088 Mdot
.51334 .62063 Mdot
.27596 .69224 Mdot
.44723 .42886 Mdot
.43164 .4183 Mdot
.58363 .38195 Mdot
.37109 .57619 Mdot
.67935 .65787 Mdot
.40348 .39873 Mdot
.4494 .38906 Mdot
.40392 .34828 Mdot
.50471 .42734 Mdot
.53565 .80385 Mdot
.42726 .4301 Mdot
.63399 .58331 Mdot
.47039 .35695 Mdot
.43664 .42115 Mdot
.36607 .61463 Mdot
.3082 .78392 Mdot
.70466 .67795 Mdot
.44807 .39672 Mdot
.39575 .38451 Mdot
.46104 .64624 Mdot
.57145 .46167 Mdot
.53625 .51403 Mdot
.64487 .5166 Mdot
.60382 .30436 Mdot
.4772 .3326 Mdot
.32166 .6134 Mdot
.64465 .41202 Mdot
.44763 .35491 Mdot
.33251 .61618 Mdot
.4852 .39924 Mdot
.68447 .55711 Mdot
.68735 .68774 Mdot
.30927 .70251 Mdot
.67279 .40776 Mdot
.61289 .4056 Mdot
.38694 .69439 Mdot
.66123 .57918 Mdot
.41276 .42965 Mdot
.48426 .68203 Mdot
.64121 .52185 Mdot
.68372 .67272 Mdot
.3606 .39199 Mdot
.33967 .58064 Mdot
.35374 .60437 Mdot
.54659 .36945 Mdot
.63294 .49734 Mdot
.45535 .8451 Mdot
.51003 .66148 Mdot
.4593 .35148 Mdot
.33452 .67339 Mdot
.35334 .60542 Mdot
.54563 .36336 Mdot
.68274 .40869 Mdot
.48424 .64329 Mdot
.68049 .65034 Mdot
.33486 .61494 Mdot
.37357 .57287 Mdot
.47258 .42008 Mdot
.45229 .3687 Mdot
.58135 .32487 Mdot
.53547 .35597 Mdot
.51559 .63998 Mdot
.65067 .41726 Mdot
.62444 .53983 Mdot
.42351 .42208 Mdot
.32932 .56699 Mdot
.20968 .40048 Mdot
.39808 .37495 Mdot
.68665 .55082 Mdot
.36296 .59136 Mdot
.65355 .42837 Mdot
.67395 .39298 Mdot
.41245 .37171 Mdot
.27282 .54326 Mdot
.49799 .6286 Mdot
.35256 .60765 Mdot
.2821 .64756 Mdot
.38246 .39306 Mdot
.45671 .36976 Mdot
.41221 .32086 Mdot
.4903 .67707 Mdot
.28085 .67865 Mdot
.64425 .4267 Mdot
.34666 .58556 Mdot
.3961 .39778 Mdot
.67244 .40283 Mdot
.29907 .67425 Mdot
.69209 .68455 Mdot
.66823 .56704 Mdot
.6843 .39346 Mdot
.66528 .43426 Mdot
.65581 .39972 Mdot
.6903 .25534 Mdot
.34352 .54561 Mdot
.34438 .44174 Mdot
.38882 .39918 Mdot
.55029 .37446 Mdot
.43677 .45925 Mdot
.5259 .66808 Mdot
.63954 .56406 Mdot
.42884 .37891 Mdot
.47267 .41875 Mdot
.51954 .41494 Mdot
.47266 .46339 Mdot
.28663 .58377 Mdot
.36701 .57829 Mdot
.45067 .47251 Mdot
.63991 .55875 Mdot
.75864 .73603 Mdot
.52068 .13781 Mdot
.38782 .46074 Mdot
.56365 .48192 Mdot
.32303 .57062 Mdot
.45959 .65069 Mdot
.52376 .52228 Mdot
.51796 .63339 Mdot
.34985 .58949 Mdot
.42512 .42421 Mdot
.3976 .68171 Mdot
.70065 .41873 Mdot
.41246 .36361 Mdot
.49789 .65538 Mdot
.41297 .36411 Mdot
.51755 .67434 Mdot
.41399 .60638 Mdot
.43301 .77584 Mdot
.4215 .446 Mdot
.38482 .374 Mdot
.50571 .44275 Mdot
.44244 .36767 Mdot
.76338 .67118 Mdot
.31829 .58101 Mdot
.63812 .78638 Mdot
.47696 .39814 Mdot
.30932 .50863 Mdot
.38672 .39993 Mdot
.71891 .65808 Mdot
.44947 .36359 Mdot
.51083 .54543 Mdot
.39699 .43386 Mdot
.46278 .39885 Mdot
.48664 .62304 Mdot
.46115 .6472 Mdot
.34715 .55718 Mdot
.68281 .6572 Mdot
.49433 .17721 Mdot
.45462 .37616 Mdot
.6477 .59328 Mdot
.53224 .60502 Mdot
.65899 .43033 Mdot
.34769 .5915 Mdot
.62336 .83944 Mdot
.50265 .62426 Mdot
.63102 .51414 Mdot
.74066 .65746 Mdot
.64342 .58403 Mdot
.53975 .68333 Mdot
.4367 .30029 Mdot
.66059 .43852 Mdot
.38651 .41229 Mdot
.18067 .53323 Mdot
.48255 .76771 Mdot
.36451 .40306 Mdot
.51045 .62072 Mdot
.32983 .34461 Mdot
.17537 .47109 Mdot
.68236 .38724 Mdot
.69216 .42471 Mdot
.49526 .62428 Mdot
.66775 .5868 Mdot
.44921 .31748 Mdot
.6836 .40791 Mdot
.6739 .57395 Mdot
.67049 .66115 Mdot
.46195 .56718 Mdot
.33688 .58863 Mdot
.28592 .69612 Mdot
.39766 .72399 Mdot
.51445 .63698 Mdot
.59887 .55154 Mdot
.37325 .62436 Mdot
.37657 .55119 Mdot
.69293 .6606 Mdot
.67516 .52765 Mdot
.31986 .56187 Mdot
.37355 .37433 Mdot
.44142 .48738 Mdot
.44906 .40526 Mdot
.67783 .42353 Mdot
.43964 .36221 Mdot
.6796 .5348 Mdot
.48922 .64539 Mdot
.65758 .5242 Mdot
.48587 .62595 Mdot
.43281 .70477 Mdot
.4118 .38972 Mdot
.46195 .39612 Mdot
.62062 .37654 Mdot
.36468 .55707 Mdot
.24184 .63155 Mdot
.65235 .59608 Mdot
.65176 .54054 Mdot
.45313 .42861 Mdot
.31855 .57026 Mdot
.64983 .44844 Mdot
.62107 .38056 Mdot
.42188 .35424 Mdot
.3178 .58095 Mdot
.42044 .42879 Mdot
.65014 .2661 Mdot
.458 .79364 Mdot
.33888 .60069 Mdot
.66836 .78062 Mdot
.41412 .41427 Mdot
.3495 .35429 Mdot
.39882 .34362 Mdot
.53266 .28077 Mdot
.38164 .39342 Mdot
.31323 .61127 Mdot
.44649 .4017 Mdot
.3096 .58863 Mdot
.66681 .58269 Mdot
.45576 .63689 Mdot
.34319 .56751 Mdot
.42 .35191 Mdot
.67412 .22374 Mdot
.50476 .66065 Mdot
.45446 .41239 Mdot
.47957 .6575 Mdot
.3385 .62131 Mdot
.36765 .56556 Mdot
.78892 .38739 Mdot
.55162 .64937 Mdot
.51199 .65809 Mdot
.42557 .43554 Mdot
.36665 .72536 Mdot
.43478 .43069 Mdot
.57606 .33157 Mdot
.47032 .41206 Mdot
.38076 .38735 Mdot
.8487 .4771 Mdot
.48486 .6794 Mdot
.46855 .843 Mdot
.71001 .32313 Mdot
.70212 .26256 Mdot
.39718 .58476 Mdot
.68189 .38709 Mdot
.62061 .21847 Mdot
.69912 .69275 Mdot
.67468 .55769 Mdot
.42806 .37792 Mdot
.39656 .54924 Mdot
.52007 .6558 Mdot
.65706 .41897 Mdot
.4237 .44629 Mdot
.68507 .54236 Mdot
.80105 .48887 Mdot
.4747 .61681 Mdot
.34125 .59267 Mdot
.36419 .55945 Mdot
.60192 .83555 Mdot
.39499 .39628 Mdot
.45803 .40439 Mdot
.49873 .66553 Mdot
.49354 .42854 Mdot
.64791 .42377 Mdot
.73898 .53212 Mdot
.51169 .6571 Mdot
.57398 .5729 Mdot
.36199 .57273 Mdot
.43782 .37267 Mdot
.52706 .48105 Mdot
.57609 .61029 Mdot
.28797 .34032 Mdot
.67646 .41839 Mdot
.58726 .34331 Mdot
.31373 .61171 Mdot
.49569 .64663 Mdot
.7221 .39743 Mdot
.45708 .34648 Mdot
.44178 .37825 Mdot
.58808 .34783 Mdot
.5788 .45319 Mdot
.64444 .45015 Mdot
.39305 .43789 Mdot
.57672 .44711 Mdot
.45752 .42448 Mdot
.41035 .34368 Mdot
.37546 .41433 Mdot
.46225 .37221 Mdot
.31886 .57755 Mdot
.52036 .40069 Mdot
.66399 .56331 Mdot
.26177 .44054 Mdot
.48528 .52168 Mdot
.39648 .41598 Mdot
.42929 .42588 Mdot
.31358 .32421 Mdot
.55879 .65908 Mdot
.3238 .57784 Mdot
.30873 .56913 Mdot
.47493 .62021 Mdot
.45673 .48365 Mdot
.68178 .587 Mdot
.52103 .37044 Mdot
.66078 .52498 Mdot
.31586 .58313 Mdot
.64756 .53663 Mdot
.46855 .62319 Mdot
.63806 .53508 Mdot
.66039 .59611 Mdot
.51995 .66694 Mdot
.3593 .56705 Mdot
.429 .35686 Mdot
.482 .61837 Mdot
.58362 .37856 Mdot
.67872 .42209 Mdot
.78894 .38645 Mdot
.4739 .36275 Mdot
.46552 .50657 Mdot
.52103 .23996 Mdot
.65578 .5261 Mdot
.47781 .80699 Mdot
.33537 .56568 Mdot
.68858 .44017 Mdot
.31671 .57869 Mdot
.24975 .68837 Mdot
.65377 .41557 Mdot
.78629 .36233 Mdot
.70386 .51944 Mdot
.78798 .45949 Mdot
.4042 .44781 Mdot
.33826 .64173 Mdot
.6323 .532 Mdot
.51966 .65358 Mdot
.70944 .57971 Mdot
.46617 .39484 Mdot
.56144 .77842 Mdot
.37764 .56119 Mdot
.6721 .66841 Mdot
.49615 .63993 Mdot
.49834 .61482 Mdot
.39911 .38824 Mdot
.76433 .57168 Mdot
.47038 .39229 Mdot
.68227 .4746 Mdot
.59606 .32125 Mdot
.51864 .3628 Mdot
.44234 .44051 Mdot
.65434 .51862 Mdot
.42037 .42963 Mdot
.33857 .3422 Mdot
.18852 .56077 Mdot
.40399 .33005 Mdot
.62691 .75685 Mdot
.64429 .37741 Mdot
.35938 .57996 Mdot
.39959 .47275 Mdot
.68097 .6662 Mdot
.41114 .41469 Mdot
.13903 .45292 Mdot
.66869 .41188 Mdot
.62393 .59485 Mdot
.38638 .38899 Mdot
.40196 .39558 Mdot
.21087 .55334 Mdot
.40319 .56416 Mdot
.68102 .64947 Mdot
.4437 .38326 Mdot
.62008 .3145 Mdot
.47633 .66294 Mdot
.47249 .38232 Mdot
.45187 .39856 Mdot
.28879 .30318 Mdot
.49119 .67546 Mdot
.65206 .527 Mdot
.69349 .6934 Mdot
.62304 .54427 Mdot
.64514 .39446 Mdot
.53192 .53161 Mdot
.524 .33855 Mdot
.45759 .79121 Mdot
.66703 .38879 Mdot
.40229 .36266 Mdot
.35491 .40471 Mdot
.41084 .40676 Mdot
.69573 .41785 Mdot
.49918 .67707 Mdot
.33009 .57078 Mdot
.32135 .7068 Mdot
.69014 .67304 Mdot
.38019 .36703 Mdot
.69427 .4014 Mdot
.34361 .57479 Mdot
.59136 .56146 Mdot
.35284 .58175 Mdot
.50958 .64518 Mdot
.53119 .65533 Mdot
.66146 .40523 Mdot
.31434 .58218 Mdot
.61908 .55624 Mdot
.71656 .33546 Mdot
.46609 .42182 Mdot
.51332 .61394 Mdot
.32983 .56057 Mdot
.37294 .6154 Mdot
.37316 .55651 Mdot
.40957 .38187 Mdot
.56681 .47126 Mdot
.41554 .34196 Mdot
.50078 .62556 Mdot
.6735 .568 Mdot
.50737 .32377 Mdot
.20936 .56709 Mdot
.5777 .54774 Mdot
.42143 .46123 Mdot
.44947 .42 Mdot
.45396 .40196 Mdot
.45295 .44662 Mdot
.71551 .43023 Mdot
.4139 .39347 Mdot
.48542 .62406 Mdot
.6712 .53082 Mdot
.39151 .40577 Mdot
.67842 .6661 Mdot
.54793 .4831 Mdot
.64697 .40372 Mdot
.5054 .53107 Mdot
.61016 .18867 Mdot
.3427 .57373 Mdot
.63041 .55759 Mdot
.67273 .558 Mdot
.65251 .4006 Mdot
.5177 .64936 Mdot
.35224 .57692 Mdot
.54099 .27462 Mdot
.65194 .40605 Mdot
.44692 .39697 Mdot
.71911 .60467 Mdot
.67706 .74691 Mdot
.38441 .41289 Mdot
.43079 .39086 Mdot
.68433 .68969 Mdot
.67308 .58794 Mdot
.25187 .27933 Mdot
.59231 .43402 Mdot
.65819 .41026 Mdot
.67728 .43586 Mdot
.36947 .55172 Mdot
.37019 .43498 Mdot
.48773 .62805 Mdot
.59126 .41386 Mdot
.48161 .27397 Mdot
.6179 .43535 Mdot
.82493 .54872 Mdot
.40424 .37205 Mdot
.21705 .54323 Mdot
.44244 .43609 Mdot
.38382 .5708 Mdot
.3658 .60801 Mdot
.32774 .57952 Mdot
.50584 .6317 Mdot
.3413 .50538 Mdot
.47943 .62514 Mdot
.5718 .16205 Mdot
.30508 .59975 Mdot
.7414 .43661 Mdot
.64515 .54268 Mdot
.46344 .45479 Mdot
.65346 .4307 Mdot
.52516 .6951 Mdot
.38106 .42833 Mdot
.5494 .80116 Mdot
.63818 .54052 Mdot
.36589 .56904 Mdot
.42558 .30078 Mdot
.41336 .18529 Mdot
.55017 .51617 Mdot
.36502 .46823 Mdot
.24298 .60899 Mdot
.65252 .42173 Mdot
.2867 .3472 Mdot
.6608 .44201 Mdot
.49066 .65447 Mdot
.46632 .38722 Mdot
.46041 .36628 Mdot
.44707 .43921 Mdot
.41427 .39156 Mdot
.46335 .63891 Mdot
.47608 .42336 Mdot
.22799 .6821 Mdot
.68467 .68773 Mdot
.6466 .2545 Mdot
.68649 .40499 Mdot
.52312 .63688 Mdot
.66749 .52872 Mdot
.67602 .65729 Mdot
.53409 .34056 Mdot
.39849 .43451 Mdot
.4271 .3799 Mdot
.69663 .66037 Mdot
.37817 .41576 Mdot
.49125 .34541 Mdot
.66374 .56155 Mdot
.57517 .53569 Mdot
.6865 .39173 Mdot
.68688 .40024 Mdot
.50835 .67362 Mdot
.31506 .58071 Mdot
.68079 .412 Mdot
.67678 .58247 Mdot
.48056 .41316 Mdot
.42507 .34872 Mdot
.33147 .55976 Mdot
.24163 .67493 Mdot
.6803 .38538 Mdot
.4202 .30075 Mdot
.30935 .6036 Mdot
.35817 .54186 Mdot
.44112 .38149 Mdot
.4067 .32562 Mdot
.36181 .62625 Mdot
.67192 .39122 Mdot
.52176 .63387 Mdot
.76873 .4217 Mdot
.4963 .6597 Mdot
.34948 .57462 Mdot
.47735 .38352 Mdot
.36071 .56922 Mdot
.40527 .41193 Mdot
.89229 .48977 Mdot
.45485 .36352 Mdot
.39944 .79719 Mdot
.54358 .29408 Mdot
.67297 .55395 Mdot
.61961 .55711 Mdot
.67737 .67422 Mdot
.30949 .60562 Mdot
.45061 .35525 Mdot
.67249 .43898 Mdot
.72944 .29812 Mdot
.3408 .63753 Mdot
.68113 .5596 Mdot
.6771 .58878 Mdot
.50138 .68056 Mdot
.38846 .38992 Mdot
.44056 .37181 Mdot
.63998 .5322 Mdot
.54584 .23647 Mdot
.32265 .6111 Mdot
.45693 .40618 Mdot
.44443 .4219 Mdot
.66908 .5566 Mdot
.71635 .33716 Mdot
.39534 .62434 Mdot
.46486 .38362 Mdot
.67436 .37574 Mdot
.52578 .67078 Mdot
.4497 .44618 Mdot
.475 .4261 Mdot
.6766 .43279 Mdot
.59068 .21903 Mdot
.16775 .5098 Mdot
.5258 .66167 Mdot
.67969 .65828 Mdot
.40948 .35134 Mdot
.64566 .54466 Mdot
.42082 .35048 Mdot
.45394 .20694 Mdot
.67659 .67975 Mdot
.41942 .40058 Mdot
.38156 .44922 Mdot
.37152 .59595 Mdot
.41109 .39631 Mdot
.31483 .29786 Mdot
.63332 .52211 Mdot
.41579 .39843 Mdot
.26337 .56306 Mdot
.48563 .6729 Mdot
.38972 .46145 Mdot
.6922 .41094 Mdot
.5268 .2768 Mdot
.39261 .70467 Mdot
.69347 .58315 Mdot
.68367 .39948 Mdot
.4264 .35497 Mdot
.66244 .58664 Mdot
.51988 .64607 Mdot
.54397 .78664 Mdot
.41686 .44882 Mdot
.50168 .6622 Mdot
.49014 .64407 Mdot
.66758 .40496 Mdot
.5054 .8477 Mdot
.44839 .4657 Mdot
.4404 .36547 Mdot
.32336 .27973 Mdot
.38006 .5832 Mdot
.4337 .36033 Mdot
.39983 .36916 Mdot
.47782 .63192 Mdot
.36906 .64495 Mdot
.32125 .37427 Mdot
.74921 .55158 Mdot
.51928 .67384 Mdot
.70283 .54792 Mdot
.66038 .58623 Mdot
.68626 .40641 Mdot
.3596 .5866 Mdot
.64581 .39924 Mdot
.65123 .56599 Mdot
.3943 .38612 Mdot
.47814 .63879 Mdot
.23702 .39252 Mdot
.46146 .6598 Mdot
.67093 .50883 Mdot
.38395 .59669 Mdot
.33982 .68005 Mdot
.14669 .5328 Mdot
.41072 .72448 Mdot
.45335 .65945 Mdot
.65954 .43073 Mdot
.7128 .58742 Mdot
.44644 .42085 Mdot
.28508 .37271 Mdot
.41999 .35985 Mdot
.24752 .59041 Mdot
.64809 .57266 Mdot
.69193 .65903 Mdot
.46624 .38442 Mdot
.59656 .33199 Mdot
.45807 .61799 Mdot
.50262 .68134 Mdot
.42229 .39198 Mdot
.5081 .63944 Mdot
.45095 .37107 Mdot
.67087 .5266 Mdot
.44684 .82967 Mdot
.45195 .41676 Mdot
.4165 .33657 Mdot
.55839 .63447 Mdot
.78849 .38075 Mdot
.62161 .5707 Mdot
.21511 .54476 Mdot
.38114 .19952 Mdot
.50625 .63792 Mdot
.36254 .41116 Mdot
.63498 .532 Mdot
.68359 .68932 Mdot
.61529 .545 Mdot
.42098 .36355 Mdot
.41678 .37079 Mdot
.45245 .4295 Mdot
.43091 .41838 Mdot
.28746 .36599 Mdot
.50328 .42191 Mdot
.22793 .52694 Mdot
.42733 .38233 Mdot
.2712 .61875 Mdot
.47273 .6271 Mdot
.29313 .57304 Mdot
.68857 .38479 Mdot
.40301 .37439 Mdot
.38543 .52393 Mdot
.52772 .65504 Mdot
.56913 .16153 Mdot
.49732 .679 Mdot
.66304 .53918 Mdot
.46875 .66401 Mdot
.40083 .41284 Mdot
.35167 .59882 Mdot
.64323 .51477 Mdot
.53332 .75742 Mdot
.67593 .55712 Mdot
.39356 .40202 Mdot
.72657 .37796 Mdot
.67141 .56051 Mdot
.53102 .49866 Mdot
.3563 .59676 Mdot
.62544 .31944 Mdot
.36347 .61131 Mdot
.41659 .40146 Mdot
.41942 .40461 Mdot
.66933 .66908 Mdot
.45808 .62374 Mdot
.33478 .62212 Mdot
.36347 .82849 Mdot
.63687 .4131 Mdot
.32713 .58575 Mdot
.4916 .40299 Mdot
.57436 .46457 Mdot
.34267 .60584 Mdot
.58386 .28335 Mdot
.51838 .6485 Mdot
.33604 .5501 Mdot
.48805 .37554 Mdot
.52155 .58773 Mdot
.69935 .42551 Mdot
.68106 .52706 Mdot
.5417 .57029 Mdot
.6304 .53352 Mdot
.52826 .64805 Mdot
.67932 .51677 Mdot
.47218 .65872 Mdot
.26377 .64824 Mdot
.37747 .50337 Mdot
.45894 .66005 Mdot
.52609 .63663 Mdot
.64825 .55753 Mdot
.42494 .44832 Mdot
.45504 .53595 Mdot
.38911 .4347 Mdot
.42087 .45428 Mdot
.47572 .66404 Mdot
.33095 .61909 Mdot
.30842 .61317 Mdot
.30706 .63826 Mdot
.36771 .55997 Mdot
.66493 .52412 Mdot
.45278 .79685 Mdot
.24957 .64923 Mdot
.49569 .66931 Mdot
.52584 .62881 Mdot
.43318 .4296 Mdot
.64558 .54898 Mdot
.6611 .58134 Mdot
.48536 .63232 Mdot
.25641 .38885 Mdot
.42226 .33902 Mdot
.37769 .60523 Mdot
.30512 .59442 Mdot
.33518 .60226 Mdot
.36823 .55396 Mdot
.32103 .43058 Mdot
.51971 .6519 Mdot
.30692 .60289 Mdot
.42197 .39648 Mdot
.41813 .36843 Mdot
.69453 .66804 Mdot
.68999 .40331 Mdot
.48664 .39539 Mdot
.40546 .33213 Mdot
.43973 .37973 Mdot
.66919 .56598 Mdot
.37683 .4673 Mdot
.67455 .66562 Mdot
.69041 .5564 Mdot
.68153 .58937 Mdot
.69964 .6689 Mdot
.28898 .6292 Mdot
.39192 .18455 Mdot
.42514 .43038 Mdot
.38797 .49321 Mdot
.64943 .54623 Mdot
.49329 .82258 Mdot
.28755 .67793 Mdot
.44352 .44147 Mdot
.48604 .56945 Mdot
.65459 .51354 Mdot
.37989 .57393 Mdot
.42723 .35958 Mdot
.70024 .68153 Mdot
.6463 .40658 Mdot
.49257 .39571 Mdot
.69419 .69401 Mdot
.31276 .58885 Mdot
.70709 .43117 Mdot
.35165 .54421 Mdot
.65525 .51238 Mdot
.38423 .45261 Mdot
.55078 .11379 Mdot
.62689 .55546 Mdot
.73069 .31069 Mdot
.40877 .57668 Mdot
.45677 .41281 Mdot
.62644 .54884 Mdot
.38216 .57962 Mdot
.52821 .66849 Mdot
.57273 .44335 Mdot
.34349 .56285 Mdot
.68129 .65633 Mdot
.69685 .67439 Mdot
.66606 .5611 Mdot
.36821 .58246 Mdot
.47441 .38393 Mdot
.36184 .6071 Mdot
.47411 .66961 Mdot
.42812 .44292 Mdot
.47668 .17008 Mdot
.44465 .48328 Mdot
.31627 .61224 Mdot
.68712 .54624 Mdot
.69354 .43096 Mdot
.40912 .44131 Mdot
.7078 .30275 Mdot
.39262 .37982 Mdot
.484 .66666 Mdot
.5943 .8116 Mdot
.25126 .36625 Mdot
.3884 .40435 Mdot
.43282 .42852 Mdot
.52156 .66415 Mdot
.40202 .43747 Mdot
.38466 .4021 Mdot
.53782 .61747 Mdot
.36822 .59912 Mdot
.44659 .4077 Mdot
.67419 .57771 Mdot
.20136 .57191 Mdot
.40386 .35293 Mdot
.63378 .74019 Mdot
.61486 .32649 Mdot
.5668 .82645 Mdot
.43435 .35549 Mdot
.57238 .38992 Mdot
.43053 .4099 Mdot
.40592 .37794 Mdot
.43004 .43562 Mdot
.20737 .52303 Mdot
.64637 .55842 Mdot
.68211 .54385 Mdot
.70102 .4233 Mdot
.61452 .32312 Mdot
.68441 .42494 Mdot
.51355 .6747 Mdot
.81077 .52392 Mdot
.67945 .68267 Mdot
.31372 .58201 Mdot
.46641 .36849 Mdot
.64208 .51285 Mdot
.43467 .37095 Mdot
.40408 .41493 Mdot
.66297 .51679 Mdot
.63771 .57463 Mdot
.60329 .56943 Mdot
.65509 .43651 Mdot
.33378 .57239 Mdot
.4705 .42632 Mdot
.66437 .39635 Mdot
.47296 .37553 Mdot
.58621 .44427 Mdot
.32942 .57456 Mdot
.36555 .60464 Mdot
.34823 .62442 Mdot
.39421 .3857 Mdot
.3988 .41803 Mdot
.47817 .62591 Mdot
.31901 .56764 Mdot
.50689 .67139 Mdot
.6376 .52441 Mdot
.62146 .5347 Mdot
.42071 .3638 Mdot
.39361 .29804 Mdot
.67174 .43673 Mdot
.6612 .534 Mdot
.69541 .65816 Mdot
.68628 .44035 Mdot
.39296 .39593 Mdot
.65229 .51889 Mdot
.68689 .39864 Mdot
.24099 .4339 Mdot
.35127 .21008 Mdot
.69355 .42863 Mdot
.42348 .39396 Mdot
.21267 .56165 Mdot
.70355 .34042 Mdot
.63735 .41811 Mdot
.48469 .6599 Mdot
.39627 .3752 Mdot
.44744 .24347 Mdot
.66294 .38771 Mdot
.23776 .62312 Mdot
.6732 .55097 Mdot
.44296 .60206 Mdot
.47989 .35394 Mdot
.27931 .39563 Mdot
.64122 .40454 Mdot
.34919 .58108 Mdot
.29984 .61154 Mdot
.43709 .39814 Mdot
.69301 .38527 Mdot
.50127 .68284 Mdot
.67584 .54424 Mdot
.64165 .58966 Mdot
.36877 .587 Mdot
.38557 .74346 Mdot
.68063 .56971 Mdot
.40473 .30175 Mdot
.73376 .60511 Mdot
.43119 .49583 Mdot
.27006 .59073 Mdot
.50635 .74911 Mdot
.41881 .3464 Mdot
.68834 .43285 Mdot
.51932 .63368 Mdot
.48984 .62509 Mdot
.51065 .65171 Mdot
.62273 .56491 Mdot
.52027 .52377 Mdot
.63564 .54476 Mdot
.54023 .77906 Mdot
.67302 .40299 Mdot
.63694 .30473 Mdot
.45263 .35742 Mdot
.45011 .41881 Mdot
.46703 .35629 Mdot
.46843 .40251 Mdot
.43439 .41133 Mdot
.51654 .6488 Mdot
.63463 .57939 Mdot
.77071 .48176 Mdot
.32471 .59617 Mdot
.62615 .60773 Mdot
.64509 .54231 Mdot
.68321 .68846 Mdot
.66126 .4193 Mdot
.55288 .40801 Mdot
.69535 .54937 Mdot
.64857 .5369 Mdot
.48087 .41919 Mdot
.342 .61469 Mdot
.48611 .3318 Mdot
.42307 .4091 Mdot
.65971 .53093 Mdot
.69764 .51407 Mdot
.33128 .30451 Mdot
.38995 .32826 Mdot
.67073 .45681 Mdot
.57015 .47029 Mdot
.64811 .43411 Mdot
.4382 .32656 Mdot
.5015 .82425 Mdot
.65159 .56535 Mdot
.66449 .54669 Mdot
.69488 .40551 Mdot
.35421 .34496 Mdot
.36461 .58755 Mdot
.69139 .65828 Mdot
.47551 .65226 Mdot
.41251 .40577 Mdot
.62135 .55028 Mdot
.34442 .406 Mdot
.77007 .54657 Mdot
.50922 .65733 Mdot
.69022 .55853 Mdot
.38851 .39321 Mdot
.42509 .39279 Mdot
.65391 .4258 Mdot
.40593 .51593 Mdot
.48085 .43788 Mdot
.70116 .26135 Mdot
.43303 .77443 Mdot
.37521 .76275 Mdot
.4419 .37802 Mdot
.37046 .58671 Mdot
.69732 .68315 Mdot
.65335 .40705 Mdot
.47789 .40442 Mdot
.36129 .20509 Mdot
.32898 .62893 Mdot
.49529 .65271 Mdot
.70038 .6784 Mdot
.51998 .5219 Mdot
.39475 .37588 Mdot
.4206 .35978 Mdot
.41168 .38633 Mdot
.31059 .22141 Mdot
.6809 .56342 Mdot
.3741 .55979 Mdot
.67469 .42128 Mdot
.37224 .56085 Mdot
.68049 .54992 Mdot
.33464 .7097 Mdot
.39221 .4158 Mdot
.38071 .60055 Mdot
.34996 .58402 Mdot
.50248 .68043 Mdot
.52713 .67321 Mdot
.60366 .57331 Mdot
.45616 .36476 Mdot
.6999 .68392 Mdot
.36569 .60927 Mdot
.64815 .58455 Mdot
.65329 .41677 Mdot
.4834 .61938 Mdot
.42623 .38241 Mdot
.65883 .56616 Mdot
.36624 .40029 Mdot
.3429 .60905 Mdot
.64844 .53781 Mdot
.70597 .68023 Mdot
.68586 .42972 Mdot
.42128 .37487 Mdot
.65731 .45628 Mdot
.69897 .66474 Mdot
.44462 .42366 Mdot
.52207 .35603 Mdot
.62844 .41385 Mdot
.5477 .75827 Mdot
.63209 .55035 Mdot
.68601 .66425 Mdot
.37101 .60246 Mdot
.33047 .66037 Mdot
.66733 .54354 Mdot
.54368 .39093 Mdot
.41522 .53381 Mdot
.46857 .43019 Mdot
.33885 .59635 Mdot
.71718 .56881 Mdot
.65064 .22301 Mdot
.67328 .30107 Mdot
.45393 .40829 Mdot
.62668 .54522 Mdot
.68225 .39537 Mdot
.49469 .6697 Mdot
.63534 .74128 Mdot
.35132 .46935 Mdot
.68459 .52538 Mdot
.42963 .43262 Mdot
.36363 .6103 Mdot
.48705 .63316 Mdot
.40749 .68302 Mdot
.68439 .57613 Mdot
.64362 .57007 Mdot
.3901 .40374 Mdot
.68019 .40692 Mdot
.59779 .24667 Mdot
.68141 .5369 Mdot
.62241 .5517 Mdot
.69939 .63821 Mdot
.69637 .40382 Mdot
.43002 .39971 Mdot
.30872 .63889 Mdot
.44788 .45014 Mdot
.73287 .30944 Mdot
.67642 .66488 Mdot
.32355 .59725 Mdot
.41344 .3655 Mdot
.75115 .57428 Mdot
.66631 .53194 Mdot
.56157 .48477 Mdot
.66225 .50098 Mdot
.51706 .64558 Mdot
.62121 .54824 Mdot
.43192 .36336 Mdot
.4568 .61851 Mdot
.67348 .43587 Mdot
.46426 .37957 Mdot
.39993 .42017 Mdot
.38212 .57333 Mdot
.4895 .65469 Mdot
.19185 .43379 Mdot
.51687 .62248 Mdot
.52559 .64989 Mdot
.2959 .59595 Mdot
.44235 .39804 Mdot
.65934 .53941 Mdot
.67275 .51333 Mdot
.47632 .40594 Mdot
.45744 .80988 Mdot
.3659 .58943 Mdot
.60519 .57895 Mdot
.26355 .27175 Mdot
.43195 .31075 Mdot
.70473 .67031 Mdot
.40754 .51128 Mdot
.51437 .67858 Mdot
.42478 .38762 Mdot
.31495 .6089 Mdot
.62469 .56201 Mdot
.67972 .57099 Mdot
.47633 .38257 Mdot
.48744 .63937 Mdot
.65554 .39438 Mdot
.64515 .57374 Mdot
.76401 .5681 Mdot
.40808 .39122 Mdot
.56868 .77627 Mdot
.63679 .56664 Mdot
.74706 .29927 Mdot
.77179 .50694 Mdot
.33551 .59768 Mdot
.40491 .4179 Mdot
.35799 .55955 Mdot
.67331 .42612 Mdot
.69776 .58161 Mdot
.4879 .64337 Mdot
.37732 .33714 Mdot
.17577 .56571 Mdot
.64375 .55426 Mdot
.31918 .5777 Mdot
.38829 .40284 Mdot
.41267 .30988 Mdot
.44262 .36413 Mdot
.3379 .65156 Mdot
.66287 .47295 Mdot
.47863 .6671 Mdot
.48371 .66516 Mdot
.44387 .42936 Mdot
.64793 .41607 Mdot
.67156 .52012 Mdot
.67466 .54406 Mdot
.80703 .69641 Mdot
.7067 .67913 Mdot
.57362 .31899 Mdot
.41795 .37278 Mdot
.65383 .58777 Mdot
.20614 .56228 Mdot
.4991 .66581 Mdot
.46963 .40183 Mdot
.65672 .59167 Mdot
.57133 .64058 Mdot
.58364 .44694 Mdot
.43352 .4062 Mdot
.48738 .34647 Mdot
.47768 .65603 Mdot
.60819 .39391 Mdot
.63667 .54047 Mdot
.46971 .40935 Mdot
.51019 .617 Mdot
.73945 .62022 Mdot
.21902 .62446 Mdot
.33337 .57283 Mdot
.66634 .50437 Mdot
.51696 .6494 Mdot
.48727 .42819 Mdot
.68634 .40343 Mdot
.63333 .52495 Mdot
.67415 .56312 Mdot
.41937 .43733 Mdot
.47456 .4362 Mdot
.43037 .31055 Mdot
.31804 .58764 Mdot
.46787 .63627 Mdot
.46748 .38775 Mdot
.39188 .74685 Mdot
.45526 .42793 Mdot
.47169 .63228 Mdot
.70592 .18339 Mdot
.43318 .45185 Mdot
.44437 .36591 Mdot
.62117 .25965 Mdot
.34683 .56172 Mdot
.37152 .56177 Mdot
.43858 .78214 Mdot
.4183 .37295 Mdot
.78802 .49119 Mdot
.33809 .5703 Mdot
.36386 .59392 Mdot
.73191 .45212 Mdot
.43468 .44348 Mdot
.61722 .39099 Mdot
.48496 .62867 Mdot
.49951 .62183 Mdot
.36424 .60371 Mdot
.4815 .43819 Mdot
.523 .65346 Mdot
.30259 .37175 Mdot
.64195 .54391 Mdot
.50571 .82509 Mdot
.33538 .61043 Mdot
.45363 .52089 Mdot
.50452 .6642 Mdot
.57707 .16327 Mdot
.51292 .57423 Mdot
.44917 .43375 Mdot
.41892 .37986 Mdot
.68183 .43124 Mdot
.39024 .44673 Mdot
.67633 .65912 Mdot
.509 .64036 Mdot
.55603 .21855 Mdot
.3278 .58037 Mdot
.45329 .36525 Mdot
.5517 .39999 Mdot
.41719 .69986 Mdot
.62222 .76123 Mdot
.35861 .58047 Mdot
.33626 .59123 Mdot
.63874 .55692 Mdot
.6574 .57311 Mdot
.43949 .40344 Mdot
.49717 .62565 Mdot
.32221 .56274 Mdot
.47045 .64544 Mdot
.65282 .56687 Mdot
.65236 .53884 Mdot
.67558 .67856 Mdot
.37326 .39097 Mdot
.66796 .52081 Mdot
.76004 .59285 Mdot
.37795 .74278 Mdot
.3753 .55167 Mdot
.15363 .49112 Mdot
.40759 .6812 Mdot
.52813 .25082 Mdot
.64959 .43324 Mdot
.66787 .65113 Mdot
.45873 .64053 Mdot
.43539 .42866 Mdot
.43002 .3751 Mdot
.68788 .67776 Mdot
.45284 .63843 Mdot
.65945 .42395 Mdot
.45424 .62906 Mdot
.67339 .40045 Mdot
.61712 .54571 Mdot
.40594 .35221 Mdot
.40486 .36254 Mdot
.51563 .64965 Mdot
.64957 .52771 Mdot
.67504 .53277 Mdot
.65693 .44098 Mdot
.56646 .40828 Mdot
.66514 .56277 Mdot
.33754 .6104 Mdot
.32483 .47952 Mdot
.69583 .6761 Mdot
.42936 .35977 Mdot
.54762 .3684 Mdot
.27376 .36293 Mdot
.46649 .42852 Mdot
.70157 .67518 Mdot
.73875 .74886 Mdot
.45295 .35943 Mdot
.67218 .79829 Mdot
.68782 .66376 Mdot
.34711 .56094 Mdot
.62837 .55111 Mdot
.67424 .65987 Mdot
.4885 .36422 Mdot
.64375 .43388 Mdot
.48057 .37688 Mdot
.34785 .56339 Mdot
.35781 .62144 Mdot
.35201 .7616 Mdot
.73396 .31218 Mdot
.66685 .44267 Mdot
.66095 .41075 Mdot
.66826 .54562 Mdot
.8384 .47847 Mdot
.48806 .37889 Mdot
.65748 .41434 Mdot
.54604 .22456 Mdot
.42748 .4274 Mdot
.57361 .33778 Mdot
.48698 .56736 Mdot
.36968 .58798 Mdot
.28141 .61868 Mdot
.66857 .53758 Mdot
.32101 .57629 Mdot
.35034 .7363 Mdot
.46805 .35772 Mdot
.32763 .57684 Mdot
.47243 .63381 Mdot
.56976 .70223 Mdot
.36367 .56397 Mdot
.58004 .42443 Mdot
.48982 .62828 Mdot
.68978 .49752 Mdot
.59384 .2582 Mdot
.11984 .49288 Mdot
.50846 .63746 Mdot
.64541 .52263 Mdot
.65673 .51288 Mdot
.67311 .54634 Mdot
.33979 .5633 Mdot
.667 .58325 Mdot
.31726 .59583 Mdot
.72697 .34895 Mdot
.56023 .39605 Mdot
.6621 .40396 Mdot
.55199 .64246 Mdot
.34388 .5888 Mdot
.49742 .7899 Mdot
.14981 .53099 Mdot
.42083 .39167 Mdot
.51385 .61994 Mdot
.69512 .40757 Mdot
.82538 .37908 Mdot
.679 .43193 Mdot
.63393 .53386 Mdot
.51506 .826 Mdot
.45388 .37158 Mdot
.36078 .28106 Mdot
.6811 .4351 Mdot
.35729 .57378 Mdot
.44683 .42233 Mdot
.62944 .50524 Mdot
.6854 .40882 Mdot
.64918 .40138 Mdot
.44109 .41438 Mdot
.36812 .57087 Mdot
.65576 .53784 Mdot
.46045 .63263 Mdot
.63588 .39927 Mdot
.48842 .43294 Mdot
.45872 .44363 Mdot
.43592 .34286 Mdot
.54377 .51053 Mdot
.47764 .22878 Mdot
.50482 .63654 Mdot
.66802 .3252 Mdot
.66286 .57186 Mdot
.71847 .52194 Mdot
.45546 .76886 Mdot
.54683 .66478 Mdot
.67745 .66359 Mdot
.67478 .67076 Mdot
.43569 .40851 Mdot
.48587 .22652 Mdot
.64234 .77943 Mdot
.55923 .64612 Mdot
.69581 .67907 Mdot
.67583 .54006 Mdot
.3029 .61548 Mdot
.31683 .73617 Mdot
.44802 .45385 Mdot
.51116 .68245 Mdot
.66406 .5659 Mdot
.44944 .20837 Mdot
.67437 .40781 Mdot
.4948 .815 Mdot
.39216 .41002 Mdot
.46154 .3965 Mdot
.49911 .63853 Mdot
.48 .62546 Mdot
.61265 .75178 Mdot
.38579 .77193 Mdot
.61741 .45551 Mdot
.39886 .64289 Mdot
.42026 .22133 Mdot
.28958 .5795 Mdot
.32032 .61467 Mdot
.7007 .69252 Mdot
.50167 .61715 Mdot
.4206 .3578 Mdot
.31525 .57489 Mdot
.62148 .76279 Mdot
.38596 .61904 Mdot
.58248 .33625 Mdot
.78274 .51904 Mdot
.3992 .40573 Mdot
.34915 .61426 Mdot
.32446 .57466 Mdot
.35276 .54713 Mdot
.70049 .67148 Mdot
.44416 .38176 Mdot
.41978 .44713 Mdot
.46429 .40339 Mdot
.50011 .41357 Mdot
.40911 .39434 Mdot
.43972 .75705 Mdot
.57466 .57033 Mdot
.56879 .21674 Mdot
.46179 .43235 Mdot
.50659 .62558 Mdot
.45542 .3515 Mdot
.64797 .41161 Mdot
.43156 .43344 Mdot
.5742 .32761 Mdot
.50289 .65311 Mdot
.3578 .34182 Mdot
.39254 .64623 Mdot
.39289 .41423 Mdot
.67021 .38902 Mdot
.50159 .23168 Mdot
.18393 .44996 Mdot
.6411 .61465 Mdot
.3399 .61053 Mdot
.69451 .55671 Mdot
.48003 .67482 Mdot
.65929 .54205 Mdot
.45941 .42915 Mdot
.70142 .68587 Mdot
.48783 .73045 Mdot
.45516 .52259 Mdot
.41182 .36145 Mdot
.38547 .47083 Mdot
.35584 .60435 Mdot
.65004 .51985 Mdot
.36125 .53006 Mdot
.41011 .37923 Mdot
.6778 .41968 Mdot
.6819 .40398 Mdot
.39294 .76325 Mdot
.47963 .1831 Mdot
.30063 .65794 Mdot
.50058 .63779 Mdot
.68616 .55277 Mdot
.64375 .40018 Mdot
.3573 .4697 Mdot
.5155 .68296 Mdot
.51124 .67933 Mdot
.48469 .64744 Mdot
.40601 .40552 Mdot
.67601 .66168 Mdot
.51312 .21016 Mdot
.67889 .65682 Mdot
.39534 .41876 Mdot
.67674 .56515 Mdot
.67143 .66412 Mdot
.68757 .42373 Mdot
.50731 .67421 Mdot
.65031 .56824 Mdot
.41406 .40132 Mdot
.33988 .5741 Mdot
.56711 .41542 Mdot
.51606 .28614 Mdot
.6842 .28189 Mdot
.6769 .27382 Mdot
.32843 .6238 Mdot
.55123 .17057 Mdot
.51724 .61679 Mdot
.25797 .38732 Mdot
.71006 .37371 Mdot
.4758 .39945 Mdot
.38007 .80242 Mdot
.63592 .53944 Mdot
.65853 .51644 Mdot
.42909 .40377 Mdot
.63773 .57657 Mdot
.44919 .36423 Mdot
.64889 .57143 Mdot
.6428 .61369 Mdot
.4423 .45725 Mdot
.66256 .51959 Mdot
.46689 .34322 Mdot
.41183 .44198 Mdot
.3686 .5957 Mdot
.62673 .53533 Mdot
.4576 .42711 Mdot
.8478 .45314 Mdot
.48113 .62156 Mdot
.69983 .67141 Mdot
.59814 .48817 Mdot
.5185 .65429 Mdot
.32692 .58953 Mdot
.41501 .45466 Mdot
.66137 .43547 Mdot
.34627 .57982 Mdot
.60481 .57604 Mdot
.68707 .43077 Mdot
.45413 .79683 Mdot
.34596 .61076 Mdot
.69384 .6756 Mdot
.67316 .43715 Mdot
.38068 .46307 Mdot
.63072 .52254 Mdot
.47568 .27638 Mdot
.68567 .65779 Mdot
.43993 .3708 Mdot
.63281 .5857 Mdot
.48862 .61784 Mdot
.45323 .39931 Mdot
.62608 .55495 Mdot
.70075 .66967 Mdot
.41223 .41174 Mdot
.43486 .42278 Mdot
.28015 .69686 Mdot
.59337 .78957 Mdot
.65362 .42299 Mdot
.37805 .59661 Mdot
.42164 .39697 Mdot
.65281 .43429 Mdot
.78728 .59673 Mdot
.4211 .34467 Mdot
.34665 .55806 Mdot
.52653 .38948 Mdot
.66249 .57422 Mdot
.50755 .67175 Mdot
.6663 .50562 Mdot
.64506 .41071 Mdot
.4102 .85355 Mdot
.67251 .67277 Mdot
.45269 .33081 Mdot
.47184 .37549 Mdot
.70921 .57444 Mdot
.32103 .57872 Mdot
.61224 .44649 Mdot
.4211 .37533 Mdot
.44881 .48213 Mdot
.46216 .37997 Mdot
.77328 .49571 Mdot
.36493 .58943 Mdot
.441 .36639 Mdot
.40886 .29699 Mdot
.39116 .36413 Mdot
.66259 .38962 Mdot
.63222 .28873 Mdot
.4363 .34604 Mdot
.48395 .09828 Mdot
.69859 .66215 Mdot
.66624 .51977 Mdot
.65684 .48582 Mdot
.83528 .58301 Mdot
.26253 .64463 Mdot
.31659 .59214 Mdot
.48758 .47712 Mdot
.65758 .5397 Mdot
.22262 .6039 Mdot
.58706 .17824 Mdot
.40887 .43964 Mdot
.39294 .38316 Mdot
.63392 .53385 Mdot
.64666 .58439 Mdot
.69705 .69148 Mdot
.45539 .43554 Mdot
.35954 .41617 Mdot
.68904 .55901 Mdot
.40244 .39602 Mdot
.50572 .34843 Mdot
.46163 .63507 Mdot
.37396 .58695 Mdot
.49634 .67057 Mdot
.49369 .67879 Mdot
.29307 .43995 Mdot
.43122 .77331 Mdot
.47227 .63049 Mdot
.46519 .61041 Mdot
.56555 .3281 Mdot
.53235 .41883 Mdot
.64833 .39833 Mdot
.57861 .20009 Mdot
.66942 .55115 Mdot
.44473 .38371 Mdot
.31924 .61778 Mdot
.27706 .41119 Mdot
.60074 .62838 Mdot
.55131 .82294 Mdot
.40967 .37344 Mdot
.67046 .53562 Mdot
.69716 .66466 Mdot
.44789 .45557 Mdot
.70594 .49488 Mdot
.45867 .40267 Mdot
.64141 .51336 Mdot
.33653 .48884 Mdot
.49654 .32555 Mdot
.71358 .60205 Mdot
.32904 .55176 Mdot
.46382 .36842 Mdot
.32695 .60651 Mdot
.50863 .66253 Mdot
.64857 .42407 Mdot
.65611 .42646 Mdot
.44282 .42172 Mdot
.36941 .4909 Mdot
.47615 .5669 Mdot
.4051 .43797 Mdot
.42483 .44017 Mdot
.68642 .66375 Mdot
.42593 .44098 Mdot
.47254 .37899 Mdot
.46702 .40289 Mdot
.39391 .35408 Mdot
.52482 .64695 Mdot
.50487 .3323 Mdot
.37591 .3706 Mdot
.42526 .31614 Mdot
.46718 .62641 Mdot
.45006 .49849 Mdot
.49104 .67615 Mdot
.47364 .17084 Mdot
.48149 .66607 Mdot
.65466 .41839 Mdot
.64846 .59629 Mdot
.46413 .48052 Mdot
.31927 .56398 Mdot
.52758 .66505 Mdot
.6683 .41916 Mdot
.51076 .64647 Mdot
.67993 .56693 Mdot
.20562 .36885 Mdot
.38723 .61794 Mdot
.59212 .42226 Mdot
.4966 .58505 Mdot
.57518 .77395 Mdot
.63967 .55129 Mdot
.36675 .59302 Mdot
.34224 .28658 Mdot
.46106 .41646 Mdot
.68094 .43317 Mdot
.43878 .40999 Mdot
.5264 .65539 Mdot
.67174 .54078 Mdot
.69695 .3093 Mdot
.65755 .43064 Mdot
.21527 .64421 Mdot
.67621 .54882 Mdot
.41492 .44884 Mdot
.51483 .68008 Mdot
.15263 .49642 Mdot
.48602 .67054 Mdot
.55791 .3907 Mdot
.38909 .57711 Mdot
.25917 .6097 Mdot
.34236 .59457 Mdot
.64692 .74903 Mdot
.32544 .19951 Mdot
.66819 .24569 Mdot
.34807 .5706 Mdot
.72258 .60848 Mdot
.39512 .39661 Mdot
.44471 .34599 Mdot
.41105 .30425 Mdot
.3786 .56292 Mdot
.41651 .39492 Mdot
.68757 .66033 Mdot
.35011 .71984 Mdot
.73 .52131 Mdot
.69381 .55137 Mdot
.43677 .36136 Mdot
.46715 .62787 Mdot
.45348 .62891 Mdot
.67271 .66069 Mdot
.47929 .67122 Mdot
.42887 .44695 Mdot
.34372 .59111 Mdot
.43313 .53341 Mdot
.67816 .42816 Mdot
.8028 .38389 Mdot
.68068 .38328 Mdot
.64853 .49434 Mdot
.38256 .4509 Mdot
.65168 .53835 Mdot
.54866 .8771 Mdot
.45154 .42865 Mdot
.33711 .56896 Mdot
.42702 .41788 Mdot
.46748 .37864 Mdot
.44533 .3455 Mdot
.6827 .57619 Mdot
.65199 .47225 Mdot
.40488 .39807 Mdot
.4877 .64479 Mdot
.62356 .23595 Mdot
.47388 .36342 Mdot
.66664 .61712 Mdot
.60587 .3143 Mdot
.53326 .7803 Mdot
.36613 .543 Mdot
.65007 .52139 Mdot
.33012 .58364 Mdot
.30608 .57355 Mdot
.32674 .58953 Mdot
.51756 .2056 Mdot
.3268 .32771 Mdot
.73905 .743 Mdot
.26259 .57891 Mdot
.25778 .42411 Mdot
.37071 .61212 Mdot
.77802 .63586 Mdot
.30981 .60294 Mdot
.32006 .58977 Mdot
.88322 .41303 Mdot
.30678 .59825 Mdot
.42295 .36492 Mdot
.47347 .43444 Mdot
.40774 .71556 Mdot
.56045 .33931 Mdot
.43707 .43648 Mdot
.42502 .39991 Mdot
.65272 .43194 Mdot
.34286 .33065 Mdot
.69455 .69565 Mdot
.4477 .79979 Mdot
.43258 .6872 Mdot
.43952 .41361 Mdot
.42038 .39949 Mdot
.46062 .45985 Mdot
.27709 .22274 Mdot
.29364 .40288 Mdot
.35245 .62584 Mdot
.3944 .48018 Mdot
.76139 .32774 Mdot
.3974 .43603 Mdot
.40305 .36294 Mdot
.40503 .4117 Mdot
.65874 .53935 Mdot
.31458 .62503 Mdot
.39563 .48018 Mdot
.5126 .76789 Mdot
.39144 .402 Mdot
.54744 .64582 Mdot
.63141 .43195 Mdot
.43104 .36399 Mdot
.36143 .55077 Mdot
.42057 .42768 Mdot
.34023 .61276 Mdot
.36863 .59983 Mdot
.45695 .4631 Mdot
.49739 .2006 Mdot
.35448 .55529 Mdot
.39703 .41733 Mdot
.6532 .52708 Mdot
.66284 .23429 Mdot
.43735 .36952 Mdot
.65797 .40119 Mdot
.41943 .37754 Mdot
.67228 .39006 Mdot
.41136 .43724 Mdot
.68247 .65661 Mdot
.26565 .34711 Mdot
.66487 .5482 Mdot
.67318 .35512 Mdot
.66272 .58842 Mdot
.28343 .699 Mdot
.34175 .56035 Mdot
.70519 .69166 Mdot
.51275 .8413 Mdot
.689 .66565 Mdot
.56179 .42201 Mdot
.62616 .61368 Mdot
.50321 .62696 Mdot
.37504 .56575 Mdot
.65663 .33585 Mdot
.69482 .62152 Mdot
.60919 .52531 Mdot
.68406 .58761 Mdot
.4159 .84276 Mdot
.46258 .83475 Mdot
.41057 .40324 Mdot
.38551 .25809 Mdot
.23047 .51836 Mdot
.41372 .34931 Mdot
.39952 .44549 Mdot
.62993 .52053 Mdot
.45509 .35903 Mdot
.52935 .5055 Mdot
.64752 .55676 Mdot
.66532 .41484 Mdot
.32278 .59847 Mdot
.67492 .39178 Mdot
.61467 .53468 Mdot
.57428 .55777 Mdot
.65646 .57045 Mdot
.40135 .34777 Mdot
.42574 .41304 Mdot
.35943 .61011 Mdot
.38693 .531 Mdot
.37243 .59178 Mdot
.69656 .4154 Mdot
.6555 .55909 Mdot
.2865 .39382 Mdot
.42907 .39056 Mdot
.35097 .5862 Mdot
.45457 .67786 Mdot
.42476 .39205 Mdot
.51436 .65591 Mdot
.39168 .39212 Mdot
.34949 .568 Mdot
.42538 .4411 Mdot
.34174 .59093 Mdot
.64084 .53265 Mdot
.39074 .42564 Mdot
.43112 .40317 Mdot
.16537 .52845 Mdot
.66077 .42579 Mdot
.34297 .5603 Mdot
.52719 .55382 Mdot
.42449 .45019 Mdot
.7105 .53121 Mdot
.43349 .35585 Mdot
.51358 .44576 Mdot
.45734 .33599 Mdot
.69121 .66334 Mdot
.36676 .38963 Mdot
.43821 .36916 Mdot
.42734 .28443 Mdot
.25502 .54767 Mdot
.36178 .52918 Mdot
.52463 .66396 Mdot
.36501 .55319 Mdot
.62181 .53505 Mdot
.62737 .56995 Mdot
.64994 .57882 Mdot
.5622 .35799 Mdot
.46499 .45402 Mdot
.45264 .37213 Mdot
.53109 .66146 Mdot
.66381 .40807 Mdot
.35672 .58033 Mdot
.66772 .40474 Mdot
.43784 .7927 Mdot
.69551 .41641 Mdot
.6747 .66063 Mdot
.77139 .51002 Mdot
.28932 .35126 Mdot
.65498 .43412 Mdot
.37311 .58988 Mdot
.77796 .52717 Mdot
.47446 .40199 Mdot
.59483 .56622 Mdot
.67877 .41786 Mdot
.37763 .83467 Mdot
.42621 .35343 Mdot
.56592 .46059 Mdot
.46619 .65166 Mdot
.68862 .40751 Mdot
.49241 .65839 Mdot
.43988 .43185 Mdot
.55736 .75783 Mdot
.3182 .57763 Mdot
.48457 .61289 Mdot
.37554 .36735 Mdot
.68346 .39722 Mdot
.66859 .56383 Mdot
.52155 .59503 Mdot
.50657 .626 Mdot
.25935 .32822 Mdot
.67465 .30243 Mdot
.65337 .55859 Mdot
.67399 .75502 Mdot
.48182 .65118 Mdot
.41793 .34727 Mdot
.4765 .46513 Mdot
.44356 .44047 Mdot
.62296 .56739 Mdot
.65338 .51944 Mdot
.37615 .72354 Mdot
.42414 .41511 Mdot
.42928 .35432 Mdot
.3622 .62871 Mdot
.64398 .54953 Mdot
.34867 .60194 Mdot
.35366 .54582 Mdot
.64288 .52476 Mdot
.3377 .59878 Mdot
.68462 .432 Mdot
.33343 .69479 Mdot
.48076 .65031 Mdot
.49125 .64675 Mdot
.6755 .54105 Mdot
.67986 .5291 Mdot
.64973 .53895 Mdot
.39165 .39249 Mdot
.36247 .5818 Mdot
.4076 .42302 Mdot
.41945 .34383 Mdot
.36909 .53954 Mdot
.30449 .59525 Mdot
.41412 .42118 Mdot
.71614 .57037 Mdot
.63252 .41293 Mdot
.66447 .5221 Mdot
.46922 .6447 Mdot
.22515 .60004 Mdot
.5319 .66942 Mdot
.43753 .3603 Mdot
.57471 .63002 Mdot
.35487 .56846 Mdot
.6818 .43072 Mdot
.62881 .40885 Mdot
.67019 .43504 Mdot
.50044 .69191 Mdot
.3345 .5545 Mdot
.45381 .79562 Mdot
.44428 .36293 Mdot
.54143 .51216 Mdot
.66198 .32889 Mdot
.46527 .77231 Mdot
.4703 .63425 Mdot
.42363 .39584 Mdot
.69123 .66816 Mdot
.32282 .31044 Mdot
.45952 .39792 Mdot
.46562 .41554 Mdot
.75815 .43865 Mdot
.42506 .31575 Mdot
.38048 .56321 Mdot
.3588 .76624 Mdot
.47953 .41833 Mdot
.34427 .64606 Mdot
.85 .61119 Mdot
.44337 .35892 Mdot
.40859 .38514 Mdot
.43612 .37967 Mdot
.42804 .42534 Mdot
.38425 .5645 Mdot
.60511 .38172 Mdot
.51705 .67854 Mdot
.5557 .52224 Mdot
.47851 .64146 Mdot
.63716 .51781 Mdot
.55964 .46597 Mdot
.37575 .57267 Mdot
.67819 .43347 Mdot
.30342 .28585 Mdot
.40923 .78651 Mdot
.63836 .55514 Mdot
.31201 .41767 Mdot
.67686 .42591 Mdot
.47597 .40411 Mdot
.70296 .4113 Mdot
.65005 .58651 Mdot
.4856 .63445 Mdot
.47113 .43673 Mdot
.33401 .6211 Mdot
.36275 .56306 Mdot
.41962 .39249 Mdot
.73016 .30007 Mdot
.51393 .66137 Mdot
.51918 .69735 Mdot
.40359 .4052 Mdot
.4652 .41696 Mdot
.34102 .60492 Mdot
.66274 .52659 Mdot
.74506 .63706 Mdot
.66288 .4222 Mdot
.37984 .40893 Mdot
.42863 .42896 Mdot
.41899 .77836 Mdot
.51257 .67459 Mdot
.69252 .6884 Mdot
.40977 .40774 Mdot
.42392 .76951 Mdot
.41136 .40934 Mdot
.39632 .4534 Mdot
.65301 .53314 Mdot
.46354 .34749 Mdot
.39842 .37742 Mdot
.37539 .4733 Mdot
.48593 .65635 Mdot
.32964 .57316 Mdot
.38226 .6117 Mdot
.70051 .68112 Mdot
.51361 .65504 Mdot
.41678 .42341 Mdot
.51608 .66879 Mdot
.44002 .34521 Mdot
.40721 .39721 Mdot
.47086 .634 Mdot
.34801 .60199 Mdot
.46645 .70754 Mdot
.54482 .3848 Mdot
.42645 .42204 Mdot
.46208 .4415 Mdot
.5659 .35275 Mdot
.599 .83031 Mdot
.41217 .36904 Mdot
.35356 .56501 Mdot
.42891 .39573 Mdot
.49997 .65983 Mdot
.69476 .41145 Mdot
.34376 .57114 Mdot
.67886 .53556 Mdot
.6376 .53476 Mdot
.38699 .64813 Mdot
.6725 .66529 Mdot
.45394 .4474 Mdot
.33417 .52957 Mdot
.31028 .61173 Mdot
.85722 .50172 Mdot
.65624 .51336 Mdot
.66319 .38819 Mdot
.43704 .42496 Mdot
.53134 .59203 Mdot
.52979 .66777 Mdot
.48008 .09724 Mdot
.45849 .79302 Mdot
.70717 .39874 Mdot
.54118 .82787 Mdot
.69025 .67354 Mdot
.40587 .36462 Mdot
.64732 .41979 Mdot
.6327 .55374 Mdot
.46399 .36121 Mdot
.48018 .33989 Mdot
.60936 .4505 Mdot
.70122 .54462 Mdot
.51267 .67094 Mdot
.65782 .57731 Mdot
.68325 .44444 Mdot
.67534 .65993 Mdot
.37094 .56777 Mdot
.44258 .36958 Mdot
.43959 .47484 Mdot
.6717 .52828 Mdot
.68266 .65612 Mdot
.3989 .4064 Mdot
.36311 .56046 Mdot
.63973 .5763 Mdot
.44376 .41582 Mdot
.25975 .39464 Mdot
.31329 .56297 Mdot
.66323 .5602 Mdot
.47126 .37698 Mdot
.51563 .43195 Mdot
.67779 .53942 Mdot
.67144 .52407 Mdot
.41677 .39539 Mdot
.67801 .43568 Mdot
.38832 .39019 Mdot
.47523 .66146 Mdot
.651 .47172 Mdot
.49903 .65718 Mdot
.71533 .36635 Mdot
.37618 .43758 Mdot
.58968 .77285 Mdot
.36826 .60723 Mdot
.6712 .45077 Mdot
.18296 .49924 Mdot
.46611 .42017 Mdot
.53146 .17726 Mdot
.46415 .51794 Mdot
.81309 .37626 Mdot
.3154 .23 Mdot
.67713 .41361 Mdot
.51103 .65126 Mdot
.40932 .38534 Mdot
.52829 .63206 Mdot
.65029 .42112 Mdot
.67932 .32787 Mdot
.47206 .3822 Mdot
.36392 .5924 Mdot
.39258 .40245 Mdot
.339 .61072 Mdot
.42433 .3895 Mdot
.41324 .32121 Mdot
.71293 .41284 Mdot
.55757 .38774 Mdot
.47492 .40389 Mdot
.20421 .36828 Mdot
.53669 .57878 Mdot
.67333 .42337 Mdot
.40225 .42087 Mdot
.68257 .67885 Mdot
.45381 .64425 Mdot
.46327 .24248 Mdot
.65529 .53935 Mdot
.46904 .63116 Mdot
.33098 .60008 Mdot
.6695 .51332 Mdot
.70161 .66854 Mdot
.45365 .47148 Mdot
.66497 .39105 Mdot
.50667 .63049 Mdot
.43523 .3667 Mdot
.42503 .354 Mdot
.73253 .59265 Mdot
.62275 .68925 Mdot
.32763 .6311 Mdot
.19406 .60535 Mdot
.37972 .55508 Mdot
.65786 .41753 Mdot
.65184 .53462 Mdot
.41505 .36523 Mdot
.45305 .40539 Mdot
.6216 .55969 Mdot
.34019 .56188 Mdot
.69037 .5158 Mdot
.30365 .4343 Mdot
.68607 .53386 Mdot
.61084 .34468 Mdot
.34221 .56689 Mdot
.60856 .34963 Mdot
.68238 .44534 Mdot
.46705 .19575 Mdot
.54114 .27841 Mdot
.46566 .65158 Mdot
.61455 .33994 Mdot
.35571 .57341 Mdot
.41894 .40754 Mdot
.69228 .67714 Mdot
.67467 .67548 Mdot
.32859 .60325 Mdot
.63279 .5344 Mdot
.68691 .4064 Mdot
.40638 .38723 Mdot
.518 .80044 Mdot
.39088 .68446 Mdot
.6863 .54914 Mdot
.47862 .32762 Mdot
.48923 .65317 Mdot
.40007 .37897 Mdot
.66276 .39746 Mdot
.50097 .62977 Mdot
.69235 .65011 Mdot
.35123 .71389 Mdot
.44314 .42557 Mdot
.38119 .76552 Mdot
.51455 .64821 Mdot
.68123 .75446 Mdot
.44172 .40534 Mdot
.48205 .65152 Mdot
.37443 .34894 Mdot
.50577 .75181 Mdot
.48583 .54155 Mdot
.60008 .1887 Mdot
.7001 .56804 Mdot
.63441 .5373 Mdot
.56946 .71637 Mdot
.71498 .39196 Mdot
.47406 .62188 Mdot
.67599 .65908 Mdot
.58653 .26678 Mdot
.49001 .65732 Mdot
.39727 .36963 Mdot
.43524 .35661 Mdot
.28871 .43373 Mdot
.51322 .53005 Mdot
.67919 .65514 Mdot
.29022 .66209 Mdot
.44199 .44397 Mdot
.41901 .32854 Mdot
.45073 .39813 Mdot
.35728 .62207 Mdot
.51913 .65091 Mdot
.15407 .46942 Mdot
.51025 .66519 Mdot
.52401 .80673 Mdot
.66979 .55018 Mdot
.68563 .53841 Mdot
.43095 .36244 Mdot
.62372 .77019 Mdot
.45372 .23512 Mdot
.41411 .44553 Mdot
.70669 .51678 Mdot
.66584 .29751 Mdot
.40497 .33107 Mdot
.38974 .58887 Mdot
.42636 .47372 Mdot
.30383 .56256 Mdot
.48834 .62588 Mdot
.67848 .40815 Mdot
.63423 .40725 Mdot
.502 .62771 Mdot
.4526 .374 Mdot
.68502 .48382 Mdot
.46271 .38734 Mdot
.41136 .40581 Mdot
.48849 .81714 Mdot
.64914 .39412 Mdot
.64682 .53935 Mdot
.65681 .42838 Mdot
.31966 .58819 Mdot
.79056 .25631 Mdot
.66884 .40152 Mdot
.33223 .52673 Mdot
.63099 .36977 Mdot
.61428 .34326 Mdot
.36529 .5628 Mdot
.68329 .43916 Mdot
.50911 .67006 Mdot
.81044 .36215 Mdot
.64488 .79661 Mdot
.53658 .66285 Mdot
.44557 .40794 Mdot
.3767 .58354 Mdot
.33865 .62459 Mdot
.5016 .6114 Mdot
.37093 .58215 Mdot
.36587 .43031 Mdot
.42073 .4152 Mdot
.47454 .62169 Mdot
.39717 .70547 Mdot
.51104 .62931 Mdot
.32612 .70209 Mdot
.39921 .41435 Mdot
.34132 .56937 Mdot
.4038 .47402 Mdot
.38172 .61957 Mdot
.69035 .69186 Mdot
.46391 .36041 Mdot
.68969 .41734 Mdot
.52188 .5195 Mdot
.66432 .55783 Mdot
.5741 .62558 Mdot
.35988 .60819 Mdot
.45955 .69479 Mdot
.3691 .59513 Mdot
.37957 .5819 Mdot
.49099 .6787 Mdot
.31405 .5881 Mdot
.40762 .38523 Mdot
.71948 .59471 Mdot
.33207 .61385 Mdot
.50003 .64365 Mdot
.68579 .41741 Mdot
.34148 .60032 Mdot
.64046 .51044 Mdot
.43323 .41546 Mdot
.6549 .57276 Mdot
.70959 .39742 Mdot
.37416 .56354 Mdot
.68473 .43732 Mdot
.66324 .51753 Mdot
.65554 .39631 Mdot
.70888 .32221 Mdot
.50449 .61914 Mdot
.55836 .82076 Mdot
.53279 .3853 Mdot
.33166 .62059 Mdot
.60448 .53785 Mdot
.41503 .36726 Mdot
.43352 .41856 Mdot
.6744 .44661 Mdot
.3347 .62452 Mdot
.68309 .25353 Mdot
.50138 .45888 Mdot
.3419 .69855 Mdot
.51983 .63236 Mdot
.2213 .63106 Mdot
.38859 .74431 Mdot
.8135 .44069 Mdot
.48075 .35918 Mdot
.69025 .67414 Mdot
.4584 .37089 Mdot
.17629 .46659 Mdot
.69259 .40285 Mdot
.74578 .68374 Mdot
.48877 .38363 Mdot
.65102 .54703 Mdot
.43688 .39391 Mdot
.43305 .26533 Mdot
.4207 .47221 Mdot
.66008 .44015 Mdot
.55285 .66035 Mdot
.31958 .56392 Mdot
.67748 .4278 Mdot
.63769 .5386 Mdot
.61031 .28976 Mdot
.46957 .36651 Mdot
.44031 .44709 Mdot
.69057 .55008 Mdot
.36643 .59042 Mdot
.6332 .52088 Mdot
.48067 .6498 Mdot
.67183 .40507 Mdot
.43413 .42738 Mdot
.43081 .3304 Mdot
.6889 .5012 Mdot
.51986 .65143 Mdot
.67846 .52215 Mdot
.49656 .67137 Mdot
.69118 .67474 Mdot
.47353 .42505 Mdot
.69024 .56125 Mdot
.42362 .35143 Mdot
.17593 .5143 Mdot
.49659 .82077 Mdot
.26889 .53015 Mdot
.64452 .54093 Mdot
.59695 .33051 Mdot
.50406 .65589 Mdot
.48605 .66876 Mdot
.25456 .61125 Mdot
.49591 .22923 Mdot
.7869 .50029 Mdot
.26967 .30805 Mdot
.48006 .64908 Mdot
.49735 .65292 Mdot
.6326 .55863 Mdot
.31491 .59686 Mdot
.29329 .59023 Mdot
.67307 .51038 Mdot
.55311 .37574 Mdot
.35658 .58045 Mdot
.54609 .17794 Mdot
.62453 .52589 Mdot
.48211 .35909 Mdot
.68342 .6951 Mdot
.68036 .4046 Mdot
.55279 .37717 Mdot
.42234 .27009 Mdot
.41414 .36232 Mdot
.33232 .75515 Mdot
.66128 .52958 Mdot
.60354 .41512 Mdot
.46559 .17448 Mdot
.47121 .38881 Mdot
.44308 .38917 Mdot
.45399 .37964 Mdot
.64667 .3946 Mdot
.18511 .48046 Mdot
.41302 .36179 Mdot
.56722 .3971 Mdot
.39587 .43976 Mdot
.49918 .27222 Mdot
.65551 .42604 Mdot
.36689 .64445 Mdot
.69863 .56477 Mdot
.49131 .76998 Mdot
.4121 .30532 Mdot
.48765 .66276 Mdot
.62896 .594 Mdot
.48203 .63349 Mdot
.47439 .21812 Mdot
.54582 .28059 Mdot
.37391 .61123 Mdot
.40849 .37381 Mdot
.674 .59176 Mdot
.37012 .60183 Mdot
.69698 .64182 Mdot
.87259 .38243 Mdot
.52242 .65719 Mdot
.59308 .85089 Mdot
.48729 .67004 Mdot
.6819 .68602 Mdot
.33757 .60491 Mdot
.32088 .37138 Mdot
.5402 .51163 Mdot
.34089 .5988 Mdot
.4867 .72769 Mdot
.38809 .56314 Mdot
.60642 .33256 Mdot
.32686 .55516 Mdot
.50263 .64765 Mdot
.45091 .65171 Mdot
.47643 .34181 Mdot
.41819 .36985 Mdot
.56963 .51746 Mdot
.4149 .50464 Mdot
.41515 .37125 Mdot
.6475 .55652 Mdot
.62888 .79447 Mdot
.6658 .60439 Mdot
.31902 .61221 Mdot
.52033 .67256 Mdot
.44163 .39049 Mdot
.42052 .4188 Mdot
.42744 .34783 Mdot
.16386 .53473 Mdot
.55317 .18149 Mdot
.40746 .39931 Mdot
.37907 .39979 Mdot
.64094 .53561 Mdot
.66406 .45936 Mdot
.22918 .35112 Mdot
.5747 .26961 Mdot
.45848 .41173 Mdot
.66138 .42878 Mdot
.66755 .38501 Mdot
.47777 .38102 Mdot
.52771 .78814 Mdot
.71797 .6094 Mdot
.43524 .36697 Mdot
.51847 .26428 Mdot
.61581 .5642 Mdot
.67284 .65916 Mdot
.67249 .52972 Mdot
.35953 .54889 Mdot
.67825 .66264 Mdot
.65978 .58625 Mdot
.31822 .36054 Mdot
.70155 .68104 Mdot
.48385 .74563 Mdot
.69659 .41532 Mdot
.45372 .39861 Mdot
.39147 .57362 Mdot
.62373 .56654 Mdot
.50103 .62628 Mdot
.33824 .58237 Mdot
.45149 .63591 Mdot
.71001 .42322 Mdot
.58453 .40101 Mdot
.67222 .66988 Mdot
.48172 .65718 Mdot
.35071 .71452 Mdot
.65972 .42845 Mdot
.48393 .67328 Mdot
.62756 .7651 Mdot
.48436 .37878 Mdot
.39782 .23322 Mdot
.39696 .43021 Mdot
.7634 .32399 Mdot
.49329 .67523 Mdot
.70439 .6829 Mdot
.44968 .36987 Mdot
.67665 .54753 Mdot
.35999 .38878 Mdot
.45825 .40521 Mdot
.68348 .54966 Mdot
.41255 .40407 Mdot
.65839 .39925 Mdot
.31744 .55431 Mdot
.43146 .52615 Mdot
.25738 .72836 Mdot
.66062 .39408 Mdot
.70639 .65755 Mdot
.41125 .37033 Mdot
.69218 .30706 Mdot
.34382 .59927 Mdot
.46948 .40325 Mdot
.25871 .62246 Mdot
.32087 .60572 Mdot
.33197 .58627 Mdot
.41809 .43562 Mdot
.46998 .66007 Mdot
.67286 .55453 Mdot
.66119 .43063 Mdot
.82931 .44799 Mdot
.44986 .41536 Mdot
.4302 .3995 Mdot
.67751 .42622 Mdot
.49816 .65535 Mdot
.42163 .42118 Mdot
.58844 .62857 Mdot
.84036 .43077 Mdot
.4996 .68126 Mdot
.47262 .36055 Mdot
.34922 .2524 Mdot
.34788 .6381 Mdot
.59858 .8393 Mdot
.66797 .36314 Mdot
.64983 .52306 Mdot
.40822 .3239 Mdot
.53706 .11256 Mdot
.68041 .40816 Mdot
.47508 .77894 Mdot
.40103 .39865 Mdot
.43122 .38511 Mdot
.3643 .56955 Mdot
.41142 .42344 Mdot
.32628 .56938 Mdot
.29469 .77178 Mdot
.20635 .65666 Mdot
.36159 .60184 Mdot
.31696 .6132 Mdot
.29556 .63504 Mdot
.21841 .37441 Mdot
.32532 .59808 Mdot
.45972 .35119 Mdot
.62359 .22705 Mdot
.46914 .45861 Mdot
.66893 .44856 Mdot
.68399 .37946 Mdot
.40225 .62307 Mdot
.67617 .72203 Mdot
.45048 .49554 Mdot
.38431 .3164 Mdot
.47605 .57258 Mdot
.47399 .65645 Mdot
.46277 .4086 Mdot
.67208 .6656 Mdot
.65688 .58101 Mdot
.42909 .46831 Mdot
.45709 .39555 Mdot
.33734 .61225 Mdot
.63874 .40421 Mdot
.46807 .66433 Mdot
.42541 .40037 Mdot
.69463 .51825 Mdot
.66353 .41762 Mdot
.32822 .61508 Mdot
.26704 .61637 Mdot
.64316 .41158 Mdot
.36614 .38711 Mdot
.42206 .3778 Mdot
.39985 .40647 Mdot
.42503 .3126 Mdot
.48541 .62246 Mdot
.61416 .54234 Mdot
.41928 .34183 Mdot
.43828 .79019 Mdot
.57896 .44941 Mdot
.44496 .33485 Mdot
.36113 .57574 Mdot
.52825 .67234 Mdot
.69501 .68973 Mdot
.63727 .3041 Mdot
.44657 .4235 Mdot
.55276 .18344 Mdot
.29628 .41217 Mdot
.67863 .66466 Mdot
.37784 .60051 Mdot
.67767 .43314 Mdot
.435 .445 Mdot
.5761 .21176 Mdot
.4346 .3574 Mdot
.53282 .41265 Mdot
.65635 .52525 Mdot
.47301 .65182 Mdot
.8316 .39914 Mdot
.66049 .58144 Mdot
.3306 .58444 Mdot
.60695 .18621 Mdot
.3035 .61255 Mdot
.31738 .5685 Mdot
.49589 .20445 Mdot
.48017 .6268 Mdot
.52059 .10965 Mdot
.62626 .81361 Mdot
.39659 .36165 Mdot
.5021 .66256 Mdot
.34373 .60785 Mdot
.40003 .3803 Mdot
.31106 .61084 Mdot
.32183 .56629 Mdot
.46067 .35712 Mdot
.42624 .37976 Mdot
.55514 .40721 Mdot
.5033 .17155 Mdot
.66722 .43637 Mdot
.34798 .56112 Mdot
.2575 .43799 Mdot
.40986 .36325 Mdot
.44386 .3631 Mdot
.70774 .58785 Mdot
.65935 .4395 Mdot
.40912 .28366 Mdot
.41032 .40717 Mdot
.2661 .69607 Mdot
.46344 .44109 Mdot
.39172 .59048 Mdot
.4982 .68121 Mdot
.51773 .78658 Mdot
.61938 .55761 Mdot
.35177 .55775 Mdot
.68167 .39462 Mdot
.3712 .62213 Mdot
.29722 .54327 Mdot
.48226 .62809 Mdot
.34952 .56799 Mdot
.65044 .50979 Mdot
.4927 .63313 Mdot
.48682 .67404 Mdot
.62336 .23527 Mdot
.67717 .51835 Mdot
.69824 .41381 Mdot
.48335 .63849 Mdot
.256 .39065 Mdot
.5054 .64522 Mdot
.27049 .43679 Mdot
.38876 .41863 Mdot
.57234 .39673 Mdot
.41052 .74863 Mdot
.43963 .3114 Mdot
.49457 .61919 Mdot
.65228 .42514 Mdot
.42483 .43395 Mdot
.37053 .57966 Mdot
.67073 .40112 Mdot
.52435 .60446 Mdot
.67579 .52572 Mdot
.35985 .61268 Mdot
.5126 .68206 Mdot
.34347 .56404 Mdot
.64175 .34369 Mdot
.62329 .48669 Mdot
.47398 .58018 Mdot
.55088 .50095 Mdot
.42047 .34865 Mdot
.41386 .57969 Mdot
.45424 .44853 Mdot
.459 .39564 Mdot
.66412 .55973 Mdot
.56347 .3601 Mdot
.34774 .60256 Mdot
.83755 .40582 Mdot
.47879 .65631 Mdot
.30139 .7259 Mdot
.5067 .44433 Mdot
.46249 .41878 Mdot
.32946 .61261 Mdot
.29936 .60283 Mdot
.25709 .54637 Mdot
.62164 .55343 Mdot
.47904 .33477 Mdot
.37476 .42849 Mdot
.46904 .33905 Mdot
.49473 .67508 Mdot
.58694 .64999 Mdot
.63224 .52981 Mdot
.74206 .7483 Mdot
.6648 .52354 Mdot
.73792 .45759 Mdot
.31331 .58936 Mdot
.69271 .40783 Mdot
.44108 .36307 Mdot
.53698 .42862 Mdot
.38607 .59158 Mdot
.63424 .38401 Mdot
.68828 .42332 Mdot
.56393 .70362 Mdot
.47392 .62829 Mdot
.47664 .38824 Mdot
.46481 .36665 Mdot
.40639 .42525 Mdot
.39165 .41801 Mdot
.52136 .66767 Mdot
.39907 .36714 Mdot
.48888 .61395 Mdot
.26649 .38143 Mdot
.26625 .69982 Mdot
.65216 .59347 Mdot
.47474 .2367 Mdot
.3411 .62035 Mdot
.24162 .41766 Mdot
.51127 .36571 Mdot
.50827 .82218 Mdot
.68709 .29305 Mdot
.44228 .45029 Mdot
.62847 .54662 Mdot
.40492 .25923 Mdot
.66447 .59201 Mdot
.36205 .86085 Mdot
.67721 .46883 Mdot
.57805 .17429 Mdot
.40311 .378 Mdot
.70979 .57515 Mdot
.51948 .39161 Mdot
.47633 .37243 Mdot
.68355 .46158 Mdot
.27388 .66552 Mdot
.42226 .72733 Mdot
.65289 .39296 Mdot
.43697 .4165 Mdot
.31407 .56934 Mdot
.40621 .38432 Mdot
.44985 .36362 Mdot
.39617 .38316 Mdot
.4976 .68297 Mdot
.46501 .44766 Mdot
.39199 .38136 Mdot
.62922 .68529 Mdot
.5774 .33765 Mdot
.66202 .57612 Mdot
.26763 .56039 Mdot
.66443 .40801 Mdot
.34714 .61241 Mdot
.5277 .48042 Mdot
.46578 .64949 Mdot
.24096 .55726 Mdot
.39103 .39504 Mdot
.397 .73974 Mdot
.51374 .68143 Mdot
.67468 .40223 Mdot
.69905 .6808 Mdot
.63163 .21918 Mdot
.64994 .59192 Mdot
.70109 .68302 Mdot
.6647 .55627 Mdot
.19152 .48682 Mdot
.33486 .61179 Mdot
.42598 .34659 Mdot
.48556 .64774 Mdot
.67362 .55713 Mdot
.55312 .33914 Mdot
.45127 .39342 Mdot
.64237 .5444 Mdot
.41972 .34757 Mdot
.58983 .41945 Mdot
.73571 .59609 Mdot
.66716 .58938 Mdot
.4801 .68304 Mdot
.49213 .63754 Mdot
.68733 .42949 Mdot
.3507 .61307 Mdot
.35687 .56948 Mdot
.50022 .63034 Mdot
.55185 .85117 Mdot
.45925 .40545 Mdot
.40236 .37574 Mdot
.43873 .78802 Mdot
.41355 .38147 Mdot
.61333 .30528 Mdot
.6796 .68877 Mdot
.34558 .61629 Mdot
.39839 .38493 Mdot
.42456 .4225 Mdot
.44012 .42579 Mdot
.63598 .3487 Mdot
.66999 .5263 Mdot
.44078 .44404 Mdot
.64899 .42964 Mdot
.61938 .75066 Mdot
.40469 .36939 Mdot
.4301 .32671 Mdot
.35248 .57095 Mdot
.22524 .67749 Mdot
.47048 .65791 Mdot
.64337 .55701 Mdot
.66784 .51871 Mdot
.68728 .37374 Mdot
.35856 .53887 Mdot
.69294 .69554 Mdot
.83104 .56103 Mdot
.69679 .6676 Mdot
.67191 .42707 Mdot
.76363 .41693 Mdot
.68827 .50829 Mdot
.64012 .56186 Mdot
.46157 .61739 Mdot
.39065 .40108 Mdot
.42612 .44902 Mdot
.47886 .78198 Mdot
.44991 .43813 Mdot
.68748 .41983 Mdot
.47304 .62074 Mdot
.35286 .57552 Mdot
.68059 .40229 Mdot
.49597 .66994 Mdot
.36724 .58763 Mdot
.48492 .38303 Mdot
.48694 .3921 Mdot
.33655 .5857 Mdot
.37199 .59592 Mdot
.42831 .36794 Mdot
.61309 .68447 Mdot
.35894 .54551 Mdot
.3464 .56741 Mdot
.6714 .6553 Mdot
.65368 .59289 Mdot
.41657 .48285 Mdot
.5038 .66332 Mdot
.40088 .40554 Mdot
.66076 .59277 Mdot
.66477 .44172 Mdot
.35073 .59737 Mdot
.42426 .41985 Mdot
.42346 .40677 Mdot
.66436 .43112 Mdot
.64097 .40846 Mdot
.68499 .40313 Mdot
.528 .6289 Mdot
.4013 .43017 Mdot
.32647 .5966 Mdot
.47507 .62925 Mdot
.66754 .38505 Mdot
.70032 .40338 Mdot
.64917 .69239 Mdot
.41791 .36115 Mdot
.48169 .54607 Mdot
.75768 .22984 Mdot
.5979 .28243 Mdot
.69374 .69134 Mdot
.68835 .53833 Mdot
.59185 .36906 Mdot
.72809 .57931 Mdot
.51723 .65536 Mdot
.56362 .24152 Mdot
.67101 .45064 Mdot
.4355 .34593 Mdot
.4642 .4391 Mdot
.38865 .43645 Mdot
.6678 .41363 Mdot
.65022 .32892 Mdot
.33014 .62489 Mdot
.21815 .4877 Mdot
.66474 .40794 Mdot
.6656 .58928 Mdot
.68908 .57069 Mdot
.66419 .52334 Mdot
.47827 .41647 Mdot
.2502 .5465 Mdot
.2499 .42083 Mdot
.22004 .3964 Mdot
.47113 .62919 Mdot
.31422 .62539 Mdot
.70301 .31862 Mdot
.33357 .58819 Mdot
.65672 .58253 Mdot
.66742 .4179 Mdot
.35761 .56507 Mdot
.51418 .63764 Mdot
.49544 .65248 Mdot
.67722 .53004 Mdot
.67462 .54155 Mdot
.66341 .57037 Mdot
.34937 .54891 Mdot
.31384 .58865 Mdot
.44665 .42792 Mdot
.34772 .59123 Mdot
.35561 .77368 Mdot
.7025 .39182 Mdot
.68173 .5822 Mdot
.51129 .65597 Mdot
.3438 .61053 Mdot
.45158 .40226 Mdot
.77866 .46452 Mdot
.40917 .64833 Mdot
.6538 .39948 Mdot
.72886 .62034 Mdot
.40997 .8775 Mdot
.46043 .36079 Mdot
.51183 .6727 Mdot
.54722 .78687 Mdot
.45199 .38423 Mdot
.65847 .53667 Mdot
.17222 .48337 Mdot
.69207 .66071 Mdot
.39395 .37869 Mdot
.45597 .43055 Mdot
.48076 .67241 Mdot
.64322 .36095 Mdot
.44494 .43278 Mdot
.3548 .74179 Mdot
.46156 .66127 Mdot
.6259 .55206 Mdot
.84789 .44138 Mdot
.6316 .5004 Mdot
.53518 .35165 Mdot
.68029 .68276 Mdot
.46729 .37509 Mdot
.65045 .56039 Mdot
.64996 .40527 Mdot
.65931 .56658 Mdot
.37665 .60542 Mdot
.66151 .57421 Mdot
.4308 .39773 Mdot
.32386 .59467 Mdot
.51503 .65004 Mdot
.36231 .76788 Mdot
.63102 .70004 Mdot
.67693 .54657 Mdot
.67153 .65155 Mdot
.40217 .36819 Mdot
.42742 .29214 Mdot
.35834 .39914 Mdot
.40574 .37075 Mdot
.48083 .63296 Mdot
.32681 .61278 Mdot
.52515 .64445 Mdot
.40374 .34039 Mdot
.24782 .66344 Mdot
.48744 .6714 Mdot
.46444 .74469 Mdot
.67581 .42657 Mdot
.55408 .39143 Mdot
.45382 .40793 Mdot
.48259 .64365 Mdot
.40041 .42837 Mdot
.30354 .59466 Mdot
.54585 .55475 Mdot
.6262 .75643 Mdot
.48656 .64795 Mdot
.70824 .26673 Mdot
.53146 .55986 Mdot
.4234 .47644 Mdot
.48019 .64553 Mdot
.20909 .54199 Mdot
.68671 .68561 Mdot
.66386 .42391 Mdot
.66342 .38652 Mdot
.65562 .39535 Mdot
.45787 .43562 Mdot
.49907 .35927 Mdot
.69963 .407 Mdot
.47274 .67244 Mdot
.65728 .43906 Mdot
.54717 .4239 Mdot
.70011 .26109 Mdot
.679 .39605 Mdot
.44274 .41009 Mdot
.42618 .32559 Mdot
.57451 .33822 Mdot
.64341 .57996 Mdot
.52658 .17733 Mdot
.35057 .45916 Mdot
.41921 .36649 Mdot
.45466 .47374 Mdot
.36151 .61578 Mdot
.59132 .78699 Mdot
.48505 .46288 Mdot
.72683 .59777 Mdot
.30763 .5965 Mdot
.64855 .4934 Mdot
.34707 .61498 Mdot
.4458 .35377 Mdot
.40606 .39595 Mdot
.29872 .57076 Mdot
.56679 .65902 Mdot
.54894 .75335 Mdot
.79707 .3778 Mdot
.35155 .56407 Mdot
.48587 .65602 Mdot
.52283 .65919 Mdot
.46855 .63587 Mdot
.62096 .53947 Mdot
.37232 .56096 Mdot
.41346 .4406 Mdot
.64195 .52919 Mdot
.46179 .40412 Mdot
.48747 .63411 Mdot
.82953 .39348 Mdot
.35257 .57236 Mdot
.43785 .36851 Mdot
.64272 .79707 Mdot
.66883 .53988 Mdot
.65775 .42462 Mdot
.59539 .42089 Mdot
.63099 .51412 Mdot
.50405 .62304 Mdot
.29459 .59432 Mdot
.54732 .65086 Mdot
.49943 .49809 Mdot
.46979 .45571 Mdot
.46294 .34927 Mdot
.83679 .47337 Mdot
.67145 .73875 Mdot
.46949 .42743 Mdot
.63718 .53976 Mdot
.63928 .58144 Mdot
.42747 .4189 Mdot
.37093 .5655 Mdot
.6814 .38761 Mdot
.64665 .42748 Mdot
.36902 .38275 Mdot
.54398 .51165 Mdot
.56144 .40524 Mdot
.41551 .4208 Mdot
.45395 .31482 Mdot
.67339 .51979 Mdot
.70208 .67524 Mdot
.43581 .77571 Mdot
.68752 .39698 Mdot
.40158 .4005 Mdot
.45426 .72071 Mdot
.31725 .57587 Mdot
.66033 .57298 Mdot
.49414 .62235 Mdot
.66471 .33744 Mdot
.63776 .51405 Mdot
.42602 .41816 Mdot
.42218 .42138 Mdot
.48172 .67229 Mdot
.3916 .59091 Mdot
.66894 .41598 Mdot
.64425 .52857 Mdot
.6905 .39826 Mdot
.31824 .58638 Mdot
.34976 .57576 Mdot
.46777 .46019 Mdot
.43071 .31531 Mdot
.67646 .53316 Mdot
.37912 .36879 Mdot
.66424 .58551 Mdot
.66705 .35348 Mdot
.52645 .67071 Mdot
.46754 .36699 Mdot
.2971 .61028 Mdot
.48777 .63128 Mdot
.43181 .37882 Mdot
.85313 .53376 Mdot
.4661 .40921 Mdot
.61761 .53087 Mdot
.25058 .67499 Mdot
.65503 .43302 Mdot
.34699 .51799 Mdot
.34403 .36212 Mdot
.41452 .38367 Mdot
.68173 .57879 Mdot
.35972 .394 Mdot
.48688 .67303 Mdot
.31168 .60149 Mdot
.53502 .87395 Mdot
.50211 .64219 Mdot
.40381 .38688 Mdot
.67256 .404 Mdot
.29855 .60443 Mdot
.68416 .66045 Mdot
.45051 .78884 Mdot
.41435 .46544 Mdot
.48797 .38499 Mdot
.39374 .39328 Mdot
.23083 .34093 Mdot
.64674 .56087 Mdot
.34367 .6092 Mdot
.49837 .67511 Mdot
.50626 .63451 Mdot
.66153 .52518 Mdot
.39922 .7243 Mdot
.58063 .56728 Mdot
.61963 .12285 Mdot
.68204 .55477 Mdot
.66919 .44467 Mdot
.55493 .48192 Mdot
.66974 .58098 Mdot
.64785 .55067 Mdot
.66737 .51726 Mdot
.43818 .7594 Mdot
.36505 .58264 Mdot
.42178 .40662 Mdot
.36631 .54325 Mdot
.46831 .37745 Mdot
.48173 .29967 Mdot
.49524 .62726 Mdot
.31077 .59808 Mdot
.84846 .49955 Mdot
.41726 .50471 Mdot
.44683 .38987 Mdot
.72291 .33727 Mdot
.36217 .41891 Mdot
.62651 .32714 Mdot
.38208 .46196 Mdot
.67121 .55086 Mdot
.50395 .42717 Mdot
.44206 .32655 Mdot
.35282 .7689 Mdot
.51069 .65851 Mdot
.6807 .68584 Mdot
.44338 .45325 Mdot
.39563 .45262 Mdot
.30118 .58875 Mdot
.35698 .5645 Mdot
.69909 .40771 Mdot
.5853 .46541 Mdot
.51472 .65335 Mdot
.61564 .48245 Mdot
.41956 .3716 Mdot
.56374 .63442 Mdot
.26064 .5942 Mdot
.43285 .37769 Mdot
.60608 .21969 Mdot
.24588 .55409 Mdot
.44886 .43161 Mdot
.20062 .49883 Mdot
.49989 .65364 Mdot
.26218 .68149 Mdot
.38096 .37775 Mdot
.65874 .53842 Mdot
.31367 .59793 Mdot
.36466 .61315 Mdot
.67022 .39388 Mdot
.45542 .82198 Mdot
.50085 .61947 Mdot
.31195 .59262 Mdot
.45545 .38497 Mdot
.48924 .62256 Mdot
.67329 .6674 Mdot
.4405 .32822 Mdot
.54824 .22932 Mdot
.34885 .58776 Mdot
.3783 .39597 Mdot
.33508 .6678 Mdot
.57991 .42927 Mdot
.46208 .16156 Mdot
.46811 .64122 Mdot
.68686 .39988 Mdot
.40101 .47781 Mdot
.82976 .55815 Mdot
.39535 .44166 Mdot
.56452 .38174 Mdot
.39527 .62364 Mdot
.69449 .41131 Mdot
.44779 .37849 Mdot
.43781 .43267 Mdot
.53576 .50748 Mdot
.64061 .4051 Mdot
.47002 .39211 Mdot
.48988 .43872 Mdot
.36572 .59031 Mdot
.67929 .68729 Mdot
.35228 .58276 Mdot
.44522 .40744 Mdot
.5028 .36795 Mdot
.36838 .57191 Mdot
.78536 .41585 Mdot
.64639 .43647 Mdot
.46942 .65534 Mdot
.47716 .32887 Mdot
.38716 .40984 Mdot
.24567 .29201 Mdot
.68998 .69168 Mdot
.18022 .45083 Mdot
.66541 .50346 Mdot
.47084 .72106 Mdot
.68997 .50497 Mdot
.61253 .19453 Mdot
.37476 .76853 Mdot
.41919 .46076 Mdot
.51692 .25185 Mdot
.20597 .45877 Mdot
.5165 .63066 Mdot
.28733 .33809 Mdot
.41794 .36965 Mdot
.45496 .36636 Mdot
.63039 .55758 Mdot
.38495 .72775 Mdot
.53742 .78524 Mdot
.55161 .52041 Mdot
.67288 .41699 Mdot
.32207 .57803 Mdot
.42349 .39205 Mdot
.60234 .59222 Mdot
.66996 .57347 Mdot
.53616 .59473 Mdot
.44368 .37066 Mdot
.53446 .80689 Mdot
.45589 .75248 Mdot
.48339 .62167 Mdot
.68933 .55204 Mdot
.63554 .51189 Mdot
.44501 .35707 Mdot
.50502 .62532 Mdot
.44801 .42888 Mdot
.54597 .57612 Mdot
.37462 .3854 Mdot
.67044 .39794 Mdot
.40918 .35569 Mdot
.50392 .52158 Mdot
.52354 .1492 Mdot
.44684 .487 Mdot
.37792 .57454 Mdot
.62283 .53305 Mdot
.66786 .52628 Mdot
.35482 .56688 Mdot
.66704 .52762 Mdot
.22635 .50086 Mdot
.33229 .47405 Mdot
.67627 .4185 Mdot
.49476 .34104 Mdot
.66515 .39872 Mdot
.68348 .68839 Mdot
.41855 .3629 Mdot
.83243 .57683 Mdot
.68128 .55014 Mdot
.19013 .56554 Mdot
.50727 .64464 Mdot
.6851 .68888 Mdot
.39329 .43742 Mdot
.76061 .41563 Mdot
.64711 .57952 Mdot
.6251 .51257 Mdot
.44188 .42607 Mdot
.36102 .57116 Mdot
.43465 .43189 Mdot
.37365 .43993 Mdot
.6997 .68461 Mdot
.39107 .40034 Mdot
.49618 .66987 Mdot
.36475 .55315 Mdot
.65391 .2305 Mdot
.62378 .56774 Mdot
.42429 .35535 Mdot
.4548 .38374 Mdot
.3036 .60571 Mdot
.38623 .42289 Mdot
.51686 .64039 Mdot
.40115 .11065 Mdot
.6748 .42732 Mdot
.69993 .6653 Mdot
.61558 .53243 Mdot
.44238 .44892 Mdot
.42031 .42468 Mdot
.83667 .45918 Mdot
.60203 .73339 Mdot
.48961 .66551 Mdot
.36345 .40768 Mdot
.64161 .53597 Mdot
.67448 .40343 Mdot
.46012 .65512 Mdot
.40163 .40858 Mdot
.44729 .36576 Mdot
.67311 .39846 Mdot
.64045 .2405 Mdot
.72698 .60409 Mdot
.4688 .63228 Mdot
.50509 .42776 Mdot
.77944 .4855 Mdot
.45883 .40534 Mdot
.80131 .48268 Mdot
.34678 .56875 Mdot
.47656 .64233 Mdot
.22212 .37929 Mdot
.42209 .34576 Mdot
.51911 .64795 Mdot
.51372 .65485 Mdot
.3973 .35808 Mdot
.36124 .54092 Mdot
.34569 .5528 Mdot
.3384 .5659 Mdot
.25643 .70536 Mdot
.513 .29781 Mdot
.66491 .56981 Mdot
.49902 .65438 Mdot
.66856 .5913 Mdot
.66608 .38379 Mdot
.57757 .45305 Mdot
.65419 .58803 Mdot
.36109 .61546 Mdot
.68924 .57154 Mdot
.43769 .42959 Mdot
.51601 .65096 Mdot
.64102 .56369 Mdot
.45343 .4454 Mdot
.37723 .30596 Mdot
.50087 .55663 Mdot
.68821 .39135 Mdot
.64558 .37189 Mdot
.41335 .39657 Mdot
.69549 .68883 Mdot
.42968 .36634 Mdot
.47294 .62245 Mdot
.51308 .50422 Mdot
.44823 .44568 Mdot
.6775 .54014 Mdot
.37866 .48761 Mdot
.62723 .56361 Mdot
.3741 .43314 Mdot
.44269 .40736 Mdot
.46266 .39562 Mdot
.4457 .43289 Mdot
.44857 .74027 Mdot
.51935 .63128 Mdot
.37795 .30177 Mdot
.69288 .58482 Mdot
.3403 .59347 Mdot
.34937 .62733 Mdot
.78311 .51974 Mdot
.70356 .66976 Mdot
.50377 .66202 Mdot
.45664 .40951 Mdot
.6207 .51747 Mdot
.82572 .38591 Mdot
.80367 .44123 Mdot
.7236 .36601 Mdot
.63595 .5482 Mdot
.37823 .58089 Mdot
.6587 .57828 Mdot
.45682 .36326 Mdot
.42608 .33723 Mdot
.62657 .20732 Mdot
.44483 .62008 Mdot
.66725 .41668 Mdot
.46466 .39201 Mdot
.52966 .34596 Mdot
.64099 .5355 Mdot
.67332 .5183 Mdot
.46556 .40625 Mdot
.35222 .55619 Mdot
.38182 .17358 Mdot
.48701 .6209 Mdot
.37513 .28705 Mdot
.38552 .5233 Mdot
.28201 .68197 Mdot
.50499 .6304 Mdot
.48702 .56583 Mdot
.64562 .51735 Mdot
.35927 .50451 Mdot
.33991 .58967 Mdot
.66458 .41451 Mdot
.43581 .33498 Mdot
.36057 .61475 Mdot
.67586 .51176 Mdot
.33778 .61779 Mdot
.44194 .35035 Mdot
.51991 .63372 Mdot
.6558 .52043 Mdot
.50009 .69178 Mdot
.29679 .57288 Mdot
.65264 .40884 Mdot
.5522 .39316 Mdot
.31162 .31717 Mdot
.24409 .55515 Mdot
.44036 .44416 Mdot
.67613 .61995 Mdot
.40416 .43226 Mdot
.30915 .57697 Mdot
.45198 .40926 Mdot
.40815 .61901 Mdot
.68574 .54004 Mdot
.3784 .39457 Mdot
.39579 .374 Mdot
.29152 .36944 Mdot
.44171 .38426 Mdot
.38659 .38844 Mdot
.44726 .43479 Mdot
.38954 .52859 Mdot
.44509 .46558 Mdot
.3642 .57745 Mdot
.46719 .77756 Mdot
.64958 .55214 Mdot
.69198 .39289 Mdot
.64412 .41357 Mdot
.56579 .38835 Mdot
.55507 .38551 Mdot
.40218 .72927 Mdot
.35766 .5855 Mdot
.50406 .66949 Mdot
.44899 .4283 Mdot
.24802 .34779 Mdot
.71305 .39489 Mdot
.64938 .51744 Mdot
.61794 .55237 Mdot
.42131 .31513 Mdot
.23365 .33509 Mdot
.37911 .41376 Mdot
.45678 .79645 Mdot
.37111 .37969 Mdot
.46973 .40113 Mdot
.63038 .51731 Mdot
.57068 .41468 Mdot
.4411 .44417 Mdot
.30065 .59 Mdot
.66066 .41609 Mdot
.46553 .48405 Mdot
.71048 .50824 Mdot
.52319 .57775 Mdot
.31194 .38036 Mdot
.40392 .43591 Mdot
.64882 .52552 Mdot
.36012 .61216 Mdot
.42515 .77868 Mdot
.47457 .63084 Mdot
.40711 .75184 Mdot
.26655 .39913 Mdot
.76576 .37512 Mdot
.66367 .41716 Mdot
.63186 .23804 Mdot
.42993 .39763 Mdot
.62233 .53199 Mdot
.45555 .35393 Mdot
.82249 .38106 Mdot
.68157 .43963 Mdot
.3888 .5812 Mdot
.48744 .6582 Mdot
.30473 .59143 Mdot
.27349 .52932 Mdot
.45794 .58213 Mdot
.63023 .62355 Mdot
.64961 .59074 Mdot
.41741 .28029 Mdot
.3262 .60254 Mdot
.41357 .41325 Mdot
.66886 .15509 Mdot
.34508 .56886 Mdot
.34302 .56122 Mdot
.64742 .36397 Mdot
.71039 .35624 Mdot
.3689 .36382 Mdot
.33211 .6187 Mdot
.68864 .58314 Mdot
.66047 .43321 Mdot
.43126 .43823 Mdot
.44196 .43456 Mdot
.36312 .56932 Mdot
.65337 .5827 Mdot
.38621 .2749 Mdot
.67351 .54588 Mdot
.36597 .59404 Mdot
.66515 .54747 Mdot
.62802 .58731 Mdot
.63997 .55645 Mdot
.38569 .41093 Mdot
.45245 .4134 Mdot
.71605 .49463 Mdot
.34971 .57595 Mdot
.41776 .42745 Mdot
.40648 .40067 Mdot
.32713 .59931 Mdot
.69347 .51764 Mdot
.26368 .32945 Mdot
.40942 .37392 Mdot
.43451 .41297 Mdot
.69282 .40578 Mdot
.67317 .49898 Mdot
.73447 .63203 Mdot
.42465 .43427 Mdot
.65312 .43815 Mdot
.34792 .54821 Mdot
.43042 .36836 Mdot
.54857 .4275 Mdot
.63804 .59041 Mdot
.41123 .35237 Mdot
.68196 .65954 Mdot
.43517 .44959 Mdot
.39881 .17281 Mdot
.41743 .35698 Mdot
.34292 .60673 Mdot
.31887 .60464 Mdot
.62479 .385 Mdot
.32967 .5818 Mdot
.6765 .67839 Mdot
.48968 .63414 Mdot
.78311 .3432 Mdot
.67421 .66821 Mdot
.46876 .41014 Mdot
.626 .81393 Mdot
.38694 .35865 Mdot
.44337 .4524 Mdot
.2054 .39309 Mdot
.67501 .66849 Mdot
.32857 .61033 Mdot
.55891 .67481 Mdot
.37135 .3757 Mdot
.49422 .62186 Mdot
.45614 .3385 Mdot
.40201 .35803 Mdot
.31985 .71982 Mdot
.24044 .62106 Mdot
.4664 .62727 Mdot
.41252 .48553 Mdot
.42387 .43409 Mdot
.65761 .72548 Mdot
.45208 .39538 Mdot
.67585 .39477 Mdot
.33897 .56368 Mdot
.67624 .5731 Mdot
.67522 .43071 Mdot
.41681 .3772 Mdot
.66734 .41075 Mdot
.66 .57178 Mdot
.47874 .63539 Mdot
.43013 .35637 Mdot
.66573 .44836 Mdot
.67184 .41603 Mdot
.40581 .42983 Mdot
.3118 .59741 Mdot
.42602 .49983 Mdot
.43095 .37049 Mdot
.41819 .41428 Mdot
.35691 .5696 Mdot
.76795 .7139 Mdot
.45312 .35825 Mdot
.48394 .54853 Mdot
.38761 .57845 Mdot
.66927 .67473 Mdot
.64656 .57209 Mdot
.40787 .35029 Mdot
.48935 .62502 Mdot
.4907 .62822 Mdot
.69141 .54398 Mdot
.30253 .59578 Mdot
.64246 .5783 Mdot
.4199 .49127 Mdot
.43506 .31506 Mdot
.40549 .34293 Mdot
.51318 .86791 Mdot
.61129 .20366 Mdot
.37367 .5688 Mdot
.63389 .52688 Mdot
.55503 .51966 Mdot
.49755 .6582 Mdot
.69156 .56736 Mdot
.29612 .59732 Mdot
.37538 .59086 Mdot
.34303 .62008 Mdot
.69168 .40986 Mdot
.64168 .51429 Mdot
.3908 .58858 Mdot
.3464 .55721 Mdot
.4398 .42746 Mdot
.42193 .43287 Mdot
.33742 .64591 Mdot
.58752 .32799 Mdot
.65602 .40364 Mdot
.6557 .52752 Mdot
.20452 .31357 Mdot
.47192 .62313 Mdot
.29368 .36943 Mdot
.44658 .4479 Mdot
.86903 .35858 Mdot
.37699 .40989 Mdot
.45522 .38852 Mdot
.35755 .5481 Mdot
.6852 .44191 Mdot
.65729 .40895 Mdot
.32462 .60229 Mdot
.29305 .58992 Mdot
.68113 .39548 Mdot
.67878 .28555 Mdot
.71006 .26426 Mdot
.41357 .7677 Mdot
.3376 .60349 Mdot
.32323 .31066 Mdot
.50506 .62411 Mdot
.3091 .55806 Mdot
.46197 .63862 Mdot
.64831 .54909 Mdot
.65583 .51198 Mdot
.4787 .67011 Mdot
.44413 .42469 Mdot
.65322 .57115 Mdot
.44527 .46882 Mdot
.69016 .27685 Mdot
.43743 .22038 Mdot
.58777 .72064 Mdot
.45982 .44393 Mdot
.52403 .78711 Mdot
.56218 .77244 Mdot
.41316 .39002 Mdot
.50516 .47269 Mdot
.6667 .41482 Mdot
.34549 .53525 Mdot
.51541 .6373 Mdot
.44897 .16438 Mdot
.45799 .40703 Mdot
.34985 .60299 Mdot
.50906 .66036 Mdot
.6169 .41882 Mdot
.35023 .73626 Mdot
.46824 .38346 Mdot
.56369 .11129 Mdot
.35889 .53369 Mdot
.67692 .57217 Mdot
.5459 .83737 Mdot
.37006 .54553 Mdot
.65463 .36751 Mdot
.66472 .50906 Mdot
.80682 .41715 Mdot
.34839 .61189 Mdot
.68444 .52056 Mdot
.32085 .58414 Mdot
.66721 .39613 Mdot
.3238 .55538 Mdot
.65167 .52046 Mdot
.4447 .38011 Mdot
.66427 .52968 Mdot
.65485 .4037 Mdot
.61978 .54196 Mdot
.51089 .63028 Mdot
.6884 .68915 Mdot
.49322 .6454 Mdot
.58273 .43823 Mdot
.24211 .64246 Mdot
.47259 .6513 Mdot
.6227 .45257 Mdot
.46802 .43033 Mdot
.39194 .59576 Mdot
.68355 .55801 Mdot
.69268 .5835 Mdot
.56943 .47189 Mdot
.33593 .59534 Mdot
.65727 .52359 Mdot
.26103 .39798 Mdot
.70452 .77123 Mdot
.49648 .35536 Mdot
.51578 .28393 Mdot
.32968 .6 Mdot
.68026 .52375 Mdot
.43913 .78727 Mdot
.34897 .62305 Mdot
.6814 .5558 Mdot
.48223 .64775 Mdot
.50612 .63327 Mdot
.46172 .40906 Mdot
.44335 .62955 Mdot
.68585 .56832 Mdot
.51972 .7519 Mdot
.31878 .5732 Mdot
.61522 .41927 Mdot
.66645 .39223 Mdot
.64441 .5503 Mdot
.45024 .32951 Mdot
.294 .62302 Mdot
.65365 .59517 Mdot
.50857 .23142 Mdot
.19079 .34039 Mdot
.65963 .52598 Mdot
.33551 .56475 Mdot
.35265 .59848 Mdot
.36036 .41101 Mdot
.54434 .50814 Mdot
.63564 .5711 Mdot
.82256 .60384 Mdot
.56215 .3716 Mdot
.69169 .67444 Mdot
.68031 .74069 Mdot
.44267 .44481 Mdot
.39768 .42363 Mdot
.49641 .66005 Mdot
.44112 .39456 Mdot
.34926 .55442 Mdot
.41473 .44876 Mdot
.52039 .65513 Mdot
.64566 .51856 Mdot
.42641 .3584 Mdot
.65459 .42958 Mdot
.47306 .61754 Mdot
.47332 .66637 Mdot
.65804 .55687 Mdot
.33596 .61931 Mdot
.59466 .56553 Mdot
.67447 .54008 Mdot
.40789 .43936 Mdot
.68052 .66633 Mdot
.42649 .34783 Mdot
.61224 .24513 Mdot
.32143 .62128 Mdot
.66501 .57924 Mdot
.37676 .60203 Mdot
.49718 .64511 Mdot
.69703 .56466 Mdot
.44733 .40041 Mdot
.67937 .55536 Mdot
.72826 .55299 Mdot
.6498 .26188 Mdot
.30196 .59423 Mdot
.69605 .5045 Mdot
.3386 .5617 Mdot
.69286 .6737 Mdot
.61085 .26536 Mdot
.66802 .42398 Mdot
.64301 .53896 Mdot
.59167 .19394 Mdot
.6792 .54029 Mdot
.43967 .38431 Mdot
.42777 .38291 Mdot
.63117 .55725 Mdot
.67331 .43805 Mdot
.22636 .67589 Mdot
.46937 .56089 Mdot
.33409 .61312 Mdot
.36203 .49119 Mdot
.24469 .26417 Mdot
.46329 .66578 Mdot
.49522 .66345 Mdot
.37707 .42516 Mdot
.46294 .41739 Mdot
.47224 .66738 Mdot
.51963 .67335 Mdot
.69036 .39571 Mdot
.66305 .51616 Mdot
.38761 .55029 Mdot
.45324 .64563 Mdot
.35011 .39107 Mdot
.53848 .35985 Mdot
.36663 .37718 Mdot
.49559 .40468 Mdot
.47948 .41869 Mdot
.58611 .41807 Mdot
.51279 .67427 Mdot
.41434 .39864 Mdot
.43464 .46612 Mdot
.47925 .64974 Mdot
.66697 .39676 Mdot
.27684 .64575 Mdot
.66192 .54299 Mdot
.85553 .60395 Mdot
.41681 .35322 Mdot
.43949 .37711 Mdot
.4716 .62875 Mdot
.68001 .72406 Mdot
.37185 .59222 Mdot
.32108 .61889 Mdot
.64746 .5627 Mdot
.57262 .47024 Mdot
.39287 .43253 Mdot
.41294 .39287 Mdot
.64889 .53735 Mdot
.69081 .68982 Mdot
.56849 .72015 Mdot
.42526 .40685 Mdot
.50909 .65628 Mdot
.63595 .59845 Mdot
.51522 .67377 Mdot
.46031 .35975 Mdot
.43776 .38534 Mdot
.38558 .41259 Mdot
.46337 .4177 Mdot
.46136 .65123 Mdot
.4188 .3973 Mdot
.43908 .32258 Mdot
.31807 .61251 Mdot
.39068 .4176 Mdot
.57319 .39092 Mdot
.44023 .41334 Mdot
.65184 .4202 Mdot
.64519 .61635 Mdot
.46337 .39592 Mdot
.38961 .41235 Mdot
.47418 .55862 Mdot
.45034 .37621 Mdot
.47079 .62516 Mdot
.34475 .59466 Mdot
.49843 .65434 Mdot
.49608 .6757 Mdot
.68007 .58982 Mdot
.6917 .39761 Mdot
.41847 .45721 Mdot
.65137 .39959 Mdot
.49309 .38179 Mdot
.4429 .34994 Mdot
.60003 .56399 Mdot
.45846 .79618 Mdot
.73017 .58583 Mdot
.4477 .40321 Mdot
.6473 .55733 Mdot
.67303 .57539 Mdot
.51303 .24441 Mdot
.42628 .47401 Mdot
.46402 .65928 Mdot
.48286 .64412 Mdot
.60809 .29811 Mdot
.32695 .72739 Mdot
.65258 .41039 Mdot
.57241 .51886 Mdot
.47535 .42511 Mdot
.41738 .40753 Mdot
.4349 .32761 Mdot
.65646 .58907 Mdot
.70233 .67976 Mdot
.65076 .51644 Mdot
.68443 .69908 Mdot
.51939 .66796 Mdot
.42365 .4487 Mdot
.45088 .20782 Mdot
.36508 .56564 Mdot
.34489 .59392 Mdot
.47392 .67186 Mdot
.63344 .57294 Mdot
.36017 .42034 Mdot
.54324 .87774 Mdot
.32542 .54168 Mdot
.7035 .41152 Mdot
.40946 .38951 Mdot
.65464 .55872 Mdot
.36077 .56108 Mdot
.64447 .42754 Mdot
.39587 .38257 Mdot
.70264 .57131 Mdot
.4492 .41205 Mdot
.20323 .46145 Mdot
.31954 .61135 Mdot
.82561 .37797 Mdot
.30329 .6118 Mdot
.47184 .61714 Mdot
.4799 .65944 Mdot
.43298 .3803 Mdot
.52544 .85882 Mdot
.38591 .56621 Mdot
.45425 .66156 Mdot
.68586 .43898 Mdot
.70102 .6682 Mdot
.6929 .42686 Mdot
.67172 .58123 Mdot
.6618 .41768 Mdot
.6687 .51954 Mdot
.59855 .30287 Mdot
.34806 .52956 Mdot
.67481 .42904 Mdot
.64634 .70048 Mdot
.46243 .45072 Mdot
.66862 .38545 Mdot
.43345 .3184 Mdot
.36754 .50739 Mdot
.65151 .53916 Mdot
.67103 .43861 Mdot
.41583 .4156 Mdot
.44212 .18083 Mdot
.48607 .66877 Mdot
.46067 .65396 Mdot
.4668 .45018 Mdot
.66699 .51582 Mdot
.29776 .57994 Mdot
.50549 .49695 Mdot
.675 .68674 Mdot
.41466 .39505 Mdot
.42792 .44947 Mdot
.34384 .6286 Mdot
.3109 .62465 Mdot
.43529 .38532 Mdot
.2646 .37019 Mdot
.42656 .39642 Mdot
.49653 .62542 Mdot
.37369 .59281 Mdot
.35017 .59678 Mdot
.68823 .56194 Mdot
.31249 .57681 Mdot
.49672 .40231 Mdot
.42947 .63181 Mdot
.3763 .36398 Mdot
.49958 .64077 Mdot
.50206 .51537 Mdot
.61955 .5566 Mdot
.49517 .17741 Mdot
.3331 .62826 Mdot
.39031 .40225 Mdot
.32464 .56764 Mdot
.68558 .40719 Mdot
.34888 .5787 Mdot
.37794 .56564 Mdot
.4232 .37424 Mdot
.46744 .37615 Mdot
.67636 .67198 Mdot
.5492 .50518 Mdot
.31228 .58456 Mdot
.41988 .39258 Mdot
.38172 .36885 Mdot
.39362 .36938 Mdot
.51922 .54082 Mdot
.37546 .56866 Mdot
.28979 .43754 Mdot
.52629 .22176 Mdot
.31101 .591 Mdot
.37322 .19076 Mdot
.68924 .66088 Mdot
.7027 .66906 Mdot
.45241 .65176 Mdot
.42478 .40804 Mdot
.62711 .54513 Mdot
.45305 .36118 Mdot
.46559 .46378 Mdot
.44798 .36443 Mdot
.66487 .44226 Mdot
.4266 .46047 Mdot
.69072 .68025 Mdot
.67347 .53561 Mdot
.402 .37782 Mdot
.42968 .35832 Mdot
.70407 .66764 Mdot
.32173 .62477 Mdot
.36814 .60325 Mdot
.80246 .46589 Mdot
.68131 .41253 Mdot
.47902 .63187 Mdot
.45372 .41833 Mdot
.64662 .55874 Mdot
.66648 .5308 Mdot
.3088 .58284 Mdot
.66041 .53669 Mdot
.48101 .6203 Mdot
.4484 .39606 Mdot
.4629 .65677 Mdot
.65791 .43817 Mdot
.34327 .5629 Mdot
.45683 .41516 Mdot
.43931 .42716 Mdot
.31912 .60497 Mdot
.46863 .42971 Mdot
.69261 .40518 Mdot
.67561 .53329 Mdot
.35799 .6088 Mdot
.49028 .63242 Mdot
.68808 .56858 Mdot
.42906 .42541 Mdot
.18469 .35986 Mdot
.43763 .39556 Mdot
.42618 .4164 Mdot
.67735 .23833 Mdot
.37566 .4272 Mdot
.6865 .5524 Mdot
.35708 .62559 Mdot
.4859 .40571 Mdot
.52263 .32862 Mdot
.82892 .51034 Mdot
.69221 .57033 Mdot
.40552 .38335 Mdot
.51414 .17337 Mdot
.40349 .38004 Mdot
.61303 .48424 Mdot
.76128 .57003 Mdot
.43106 .26996 Mdot
.49582 .39443 Mdot
.46562 .65384 Mdot
.6765 .67483 Mdot
.68149 .53163 Mdot
.21711 .54329 Mdot
.42106 .38119 Mdot
.20495 .5386 Mdot
.39965 .36637 Mdot
.50742 .63347 Mdot
.40323 .50037 Mdot
.65728 .52896 Mdot
.41554 .80579 Mdot
.411 .43954 Mdot
.37579 .57264 Mdot
.68253 .58214 Mdot
.69766 .66518 Mdot
.42319 .41909 Mdot
.6462 .41036 Mdot
.48392 .69126 Mdot
.44506 .31538 Mdot
.49867 .63735 Mdot
.40484 .40112 Mdot
.42409 .48485 Mdot
.49316 .84209 Mdot
.32317 .61395 Mdot
.49066 .66 Mdot
.59887 .77824 Mdot
.47259 .42121 Mdot
.35094 .61166 Mdot
.33932 .59062 Mdot
.6607 .39627 Mdot
.57085 .57498 Mdot
.35998 .66722 Mdot
.39083 .23068 Mdot
.26713 .55714 Mdot
.68816 .54096 Mdot
.56342 .75747 Mdot
.42791 .43813 Mdot
.47022 .58346 Mdot
.4648 .63234 Mdot
.44177 .37742 Mdot
.25861 .58663 Mdot
.34178 .56533 Mdot
.43221 .40786 Mdot
.66638 .39785 Mdot
.57044 .62528 Mdot
.5231 .58573 Mdot
.28064 .26827 Mdot
.69121 .57729 Mdot
.43203 .3324 Mdot
.49239 .37037 Mdot
.67045 .66122 Mdot
.44685 .34833 Mdot
.68424 .54479 Mdot
.70467 .30456 Mdot
.67536 .4389 Mdot
.35443 .56028 Mdot
.69036 .66131 Mdot
.47807 .42617 Mdot
.38444 .37164 Mdot
.693 .39396 Mdot
.39943 .41269 Mdot
.46161 .82162 Mdot
.7144 .68068 Mdot
.64694 .5678 Mdot
.34381 .61817 Mdot
.47865 .41415 Mdot
.70141 .68122 Mdot
.42486 .37753 Mdot
.32561 .37422 Mdot
.39239 .40865 Mdot
.32834 .67438 Mdot
.31352 .59651 Mdot
.49583 .63835 Mdot
.49019 .41475 Mdot
.45679 .37058 Mdot
.77896 .47469 Mdot
.46479 .46401 Mdot
.41769 .35599 Mdot
.29924 .59451 Mdot
.36995 .56659 Mdot
.36286 .57734 Mdot
.6632 .57463 Mdot
.4251 .77013 Mdot
.50577 .65176 Mdot
.40525 .4473 Mdot
.45335 .64531 Mdot
.3357 .36871 Mdot
.69903 .40064 Mdot
.38128 .20648 Mdot
.39038 .39481 Mdot
.3614 .58293 Mdot
.43561 .70832 Mdot
.34766 .54902 Mdot
.69722 .58255 Mdot
.515 .65273 Mdot
.34233 .56766 Mdot
.45791 .37975 Mdot
.54177 .51956 Mdot
.29884 .26832 Mdot
.49334 .65317 Mdot
.42287 .32762 Mdot
.6952 .57279 Mdot
.62243 .57048 Mdot
.26541 .22969 Mdot
.48828 .6661 Mdot
.56873 .76961 Mdot
.41695 .38819 Mdot
.36558 .56741 Mdot
.46773 .64551 Mdot
.47607 .66379 Mdot
.65367 .5368 Mdot
.46746 .38206 Mdot
.46228 .39338 Mdot
.68397 .6597 Mdot
.48283 .64012 Mdot
.47435 .43986 Mdot
.39265 .34938 Mdot
.62989 .20886 Mdot
.27219 .62816 Mdot
.79388 .68737 Mdot
.42081 .49134 Mdot
.25914 .56661 Mdot
.55273 .47444 Mdot
.37025 .55901 Mdot
.46556 .39325 Mdot
.48206 .39612 Mdot
.68786 .55941 Mdot
.44311 .39699 Mdot
.62402 .54954 Mdot
.49947 .66609 Mdot
.3559 .20852 Mdot
.41842 .64572 Mdot
.69248 .30201 Mdot
.44429 .39005 Mdot
.30189 .7007 Mdot
.68421 .4254 Mdot
.53934 .64355 Mdot
.36737 .59538 Mdot
.47669 .39576 Mdot
.62203 .52414 Mdot
.64225 .5384 Mdot
.33706 .58191 Mdot
.51251 .76905 Mdot
.79624 .48201 Mdot
.46549 .36338 Mdot
.64613 .57321 Mdot
.48312 .72293 Mdot
.25462 .38036 Mdot
.45857 .6125 Mdot
.67745 .43958 Mdot
.64772 .51843 Mdot
.49287 .67998 Mdot
.29191 .63027 Mdot
.33499 .57376 Mdot
.36853 .6174 Mdot
.75213 .51741 Mdot
.63065 .56663 Mdot
.67068 .43343 Mdot
.37496 .75997 Mdot
.35826 .75832 Mdot
.66984 .44243 Mdot
.64316 .51927 Mdot
.36609 .56301 Mdot
.35807 .6019 Mdot
.34487 .59564 Mdot
.40415 .80081 Mdot
.31313 .61449 Mdot
.31038 .4188 Mdot
.38761 .35951 Mdot
.46138 .30714 Mdot
.40491 .38006 Mdot
.45976 .63964 Mdot
.31995 .6108 Mdot
.5611 .47577 Mdot
.46622 .42179 Mdot
.2944 .2623 Mdot
.4116 .39473 Mdot
.4674 .60956 Mdot
.42891 .41022 Mdot
.3 .33788 Mdot
.38674 .57499 Mdot
.44531 .40308 Mdot
.52457 .6341 Mdot
.673 .41251 Mdot
.40051 .58111 Mdot
.46346 .39447 Mdot
.36513 .72133 Mdot
.38709 .43871 Mdot
.70142 .29545 Mdot
.61322 .37408 Mdot
.70405 .41534 Mdot
.48384 .44758 Mdot
.68647 .5296 Mdot
.40415 .60122 Mdot
.50894 .36869 Mdot
.49242 .65146 Mdot
.18943 .55051 Mdot
.64125 .54324 Mdot
.40925 .50359 Mdot
.36366 .41149 Mdot
.6885 .39616 Mdot
.33627 .63793 Mdot
.46885 .62941 Mdot
.45238 .44746 Mdot
.39539 .3611 Mdot
.67399 .29329 Mdot
.5021 .35374 Mdot
.38577 .42444 Mdot
.68164 .38661 Mdot
.29605 .44334 Mdot
.43987 .41846 Mdot
.69688 .52544 Mdot
.37237 .6121 Mdot
.46249 .45587 Mdot
.2879 .43193 Mdot
.42036 .39113 Mdot
.34439 .57282 Mdot
.35552 .62821 Mdot
.40246 .70266 Mdot
.69388 .43285 Mdot
.3925 .40849 Mdot
.66828 .34305 Mdot
.4025 .43229 Mdot
.50946 .65192 Mdot
.45088 .35671 Mdot
.6466 .54426 Mdot
.44976 .79625 Mdot
.67271 .56671 Mdot
.45589 .36104 Mdot
.34427 .59946 Mdot
.46447 .64531 Mdot
.72761 .50917 Mdot
.7724 .54879 Mdot
.30898 .42339 Mdot
.85139 .51024 Mdot
.68732 .42806 Mdot
.64915 .39368 Mdot
.48949 .61499 Mdot
.44536 .40646 Mdot
.62749 .3735 Mdot
.3704 .3999 Mdot
.43368 .41372 Mdot
.44579 .36325 Mdot
.44088 .64069 Mdot
.50138 .65877 Mdot
.66667 .53996 Mdot
.43629 .38709 Mdot
.4205 .39416 Mdot
.31903 .57858 Mdot
.67369 .41445 Mdot
.6738 .56925 Mdot
.67869 .42052 Mdot
.66779 .55836 Mdot
.39451 .17384 Mdot
.39098 .34591 Mdot
.67404 .41023 Mdot
.48755 .61406 Mdot
.3574 .56917 Mdot
.69797 .69275 Mdot
.67574 .58073 Mdot
.65613 .5262 Mdot
.41482 .39377 Mdot
.35255 .56831 Mdot
.31127 .58247 Mdot
.68786 .41073 Mdot
.47283 .63908 Mdot
.45749 .36263 Mdot
.46265 .35986 Mdot
.46949 .24764 Mdot
.66663 .58891 Mdot
.2505 .40897 Mdot
.41573 .72067 Mdot
.44712 .40606 Mdot
.32617 .61731 Mdot
.4279 .36161 Mdot
.5049 .18965 Mdot
.36134 .61501 Mdot
.46949 .40041 Mdot
.31675 .72633 Mdot
.64715 .58716 Mdot
.35231 .68983 Mdot
.38076 .39763 Mdot
.8357 .45188 Mdot
.41756 .4363 Mdot
.59819 .17588 Mdot
.6298 .73369 Mdot
.41302 .44742 Mdot
.43349 .4339 Mdot
.37718 .24009 Mdot
.41424 .38185 Mdot
.6947 .67653 Mdot
.43786 .48972 Mdot
.3755 .59154 Mdot
.56139 .44425 Mdot
.70561 .5486 Mdot
.67992 .4433 Mdot
.64742 .56304 Mdot
.71474 .53727 Mdot
.67198 .39699 Mdot
.33605 .6042 Mdot
.44464 .43445 Mdot
.55113 .3879 Mdot
.67931 .59666 Mdot
.37154 .4328 Mdot
.51088 .65082 Mdot
.67739 .4929 Mdot
.62433 .53716 Mdot
.49079 .63581 Mdot
.39415 .37521 Mdot
.2839 .30612 Mdot
.75428 .58814 Mdot
.79741 .35298 Mdot
.4692 .63177 Mdot
.50813 .63211 Mdot
.42762 .78455 Mdot
.67519 .44438 Mdot
.60617 .25031 Mdot
.30322 .68471 Mdot
.49316 .62048 Mdot
.63727 .30079 Mdot
.66653 .51366 Mdot
.35406 .71929 Mdot
.34499 .53545 Mdot
.41311 .33694 Mdot
.45792 .37682 Mdot
.47403 .64217 Mdot
.54282 .40443 Mdot
.52208 .83214 Mdot
.49243 .6461 Mdot
.4836 .35353 Mdot
.57213 .58846 Mdot
.68418 .66495 Mdot
.67736 .65909 Mdot
.6998 .42188 Mdot
.78937 .42908 Mdot
.31888 .58949 Mdot
.68434 .39355 Mdot
.55708 .60401 Mdot
.39468 .40495 Mdot
.48611 .64578 Mdot
.70283 .6888 Mdot
.49818 .62971 Mdot
.6616 .40377 Mdot
.70313 .41155 Mdot
.31951 .61344 Mdot
.37132 .59328 Mdot
.25443 .56913 Mdot
.61513 .32256 Mdot
.40276 .37909 Mdot
.19618 .42828 Mdot
.31773 .5736 Mdot
.51028 .39761 Mdot
.65409 .43869 Mdot
.67663 .41173 Mdot
.20962 .4665 Mdot
.45324 .42488 Mdot
.62176 .41504 Mdot
.45538 .41276 Mdot
.58864 .25758 Mdot
.46262 .35626 Mdot
.65653 .53766 Mdot
.43094 .44717 Mdot
.59111 .55282 Mdot
.44789 .44043 Mdot
.41951 .35402 Mdot
.65751 .51563 Mdot
.41257 .32435 Mdot
.64586 .54267 Mdot
.46395 .3665 Mdot
.63956 .39823 Mdot
.64683 .55935 Mdot
.52777 .30124 Mdot
.48512 .54921 Mdot
.69483 .68559 Mdot
.64899 .41431 Mdot
.66165 .39295 Mdot
.5594 .38508 Mdot
.36627 .59838 Mdot
.27835 .60146 Mdot
.44374 .40681 Mdot
.67386 .51879 Mdot
.49796 .66147 Mdot
.42229 .39464 Mdot
.47384 .36807 Mdot
.38155 .40977 Mdot
.331 .56821 Mdot
.63186 .57046 Mdot
.67015 .4083 Mdot
.6514 .5747 Mdot
.7833 .45112 Mdot
.63668 .51449 Mdot
.43792 .46681 Mdot
.46964 .35378 Mdot
.34619 .31259 Mdot
.19614 .54 Mdot
.28703 .71489 Mdot
.33319 .57824 Mdot
.68216 .68043 Mdot
.70188 .4086 Mdot
.36909 .4903 Mdot
.36594 .58727 Mdot
.64881 .52207 Mdot
.44957 .41189 Mdot
.46513 .33538 Mdot
.49744 .59271 Mdot
.40425 .61016 Mdot
.56516 .36285 Mdot
.62544 .52831 Mdot
.69043 .67129 Mdot
.42264 .77192 Mdot
.3815 .51276 Mdot
.57054 .46299 Mdot
.44084 .36697 Mdot
.64535 .4142 Mdot
.36069 .56108 Mdot
.74385 .54282 Mdot
.47904 .64337 Mdot
.54589 .50765 Mdot
.44443 .39135 Mdot
.48881 .7449 Mdot
.34311 .59878 Mdot
.6606 .40048 Mdot
.47463 .64302 Mdot
.68144 .44364 Mdot
.67754 .658 Mdot
.79577 .42 Mdot
.40163 .42494 Mdot
.4145 .35929 Mdot
.46087 .61658 Mdot
.32095 .58762 Mdot
.63869 .37844 Mdot
.66132 .27895 Mdot
.63947 .56704 Mdot
.62709 .43134 Mdot
.36095 .55112 Mdot
.31233 .36437 Mdot
.65558 .57506 Mdot
.47412 .67229 Mdot
.5801 .42474 Mdot
.5209 .65872 Mdot
.4618 .40239 Mdot
.35627 .58922 Mdot
.49434 .66963 Mdot
.77123 .4742 Mdot
.50878 .16018 Mdot
.32003 .32532 Mdot
.4052 .4404 Mdot
.37164 .20907 Mdot
.68993 .26598 Mdot
.53334 .4407 Mdot
.51246 .63139 Mdot
.42947 .37244 Mdot
.44464 .34519 Mdot
.41624 .44272 Mdot
.50538 .67065 Mdot
.74925 .40949 Mdot
.65058 .52834 Mdot
.40647 .39171 Mdot
.67213 .3923 Mdot
.65278 .54774 Mdot
.60267 .54868 Mdot
.67985 .53293 Mdot
.37953 .5868 Mdot
.46608 .41203 Mdot
.42365 .75427 Mdot
.54969 .14487 Mdot
.49732 .65406 Mdot
.69468 .68527 Mdot
.40657 .36077 Mdot
.25649 .66729 Mdot
.36288 .57855 Mdot
.63722 .56491 Mdot
.43959 .3762 Mdot
.76256 .43557 Mdot
.69824 .7054 Mdot
.67112 .52575 Mdot
.36057 .60173 Mdot
.52576 .456 Mdot
.44155 .39762 Mdot
.41319 .43355 Mdot
.32246 .59486 Mdot
.80474 .44903 Mdot
.45045 .79214 Mdot
.42901 .35946 Mdot
.49438 .63798 Mdot
.64615 .82249 Mdot
.3828 .39207 Mdot
.30894 .64028 Mdot
.70064 .66671 Mdot
.38143 .72019 Mdot
.24658 .41501 Mdot
.47645 .45831 Mdot
.40292 .21424 Mdot
.56794 .41633 Mdot
.36589 .20218 Mdot
.6995 .36521 Mdot
.6044 .62803 Mdot
.40897 .16658 Mdot
.51892 .62594 Mdot
.45086 .30325 Mdot
.41071 .25993 Mdot
.49284 .77562 Mdot
.54851 .45079 Mdot
.81712 .56028 Mdot
.78004 .50429 Mdot
.65792 .64824 Mdot
.68089 .5494 Mdot
.56473 .24709 Mdot
.4501 .35931 Mdot
.69778 .26957 Mdot
.27347 .36568 Mdot
.51419 .84059 Mdot
.38746 .19586 Mdot
.66981 .34125 Mdot
.30773 .26922 Mdot
.5259 .17796 Mdot
.37303 .27656 Mdot
.4099 .62706 Mdot
.79294 .65899 Mdot
.37524 .7636 Mdot
.70346 .33611 Mdot
.37946 .46304 Mdot
.59266 .58133 Mdot
.73795 .33783 Mdot
.32216 .46586 Mdot
.55658 .84832 Mdot
.68166 .57203 Mdot
.38115 .60189 Mdot
.45554 .24391 Mdot
.40099 .59728 Mdot
.45845 .69339 Mdot
.40029 .21454 Mdot
.59327 .181 Mdot
.29644 .34241 Mdot
.84465 .46618 Mdot
.2199 .52222 Mdot
.24553 .70708 Mdot
.51303 .55771 Mdot
.37705 .61337 Mdot
.76386 .66412 Mdot
.35621 .757 Mdot
.40712 .65618 Mdot
.36433 .47821 Mdot
.70665 .38999 Mdot
.5593 .32586 Mdot
.34862 .60322 Mdot
.24393 .40635 Mdot
.67831 .65239 Mdot
.36117 .65509 Mdot
.60559 .58162 Mdot
.4774 .18117 Mdot
.64856 .62789 Mdot
.37109 .73153 Mdot
.5514 .75157 Mdot
.18619 .35441 Mdot
.64626 .32258 Mdot
.56125 .19921 Mdot
.48985 .59745 Mdot
.54591 .44718 Mdot
.51412 .80929 Mdot
.60819 .34047 Mdot
.34312 .7512 Mdot
.17385 .41689 Mdot
.73652 .30431 Mdot
.2184 .33342 Mdot
.37137 .62869 Mdot
.38365 .41556 Mdot
.5064 .2041 Mdot
.27163 .5527 Mdot
.7055 .40958 Mdot
.25606 .29021 Mdot
.64658 .42784 Mdot
.39444 .61125 Mdot
.5069 .77233 Mdot
.30367 .3783 Mdot
.63118 .45378 Mdot
.63451 .42539 Mdot
.41832 .46113 Mdot
.25455 .76684 Mdot
.35153 .21779 Mdot
.3959 .70626 Mdot
.62982 .20792 Mdot
.55987 .63239 Mdot
.61349 .40164 Mdot
.50233 .66787 Mdot
.47185 .15612 Mdot
.36058 .59512 Mdot
.48743 .12852 Mdot
.50228 .15305 Mdot
.62956 .79153 Mdot
.43342 .90016 Mdot
.59977 .69471 Mdot
.39806 .2861 Mdot
.53059 .35177 Mdot
.53661 .33054 Mdot
.52801 .82033 Mdot
.64964 .77953 Mdot
.56235 .64543 Mdot
.79307 .39064 Mdot
.42753 .168 Mdot
.61857 .28379 Mdot
.73382 .36049 Mdot
.50543 .78757 Mdot
.49988 .54184 Mdot
.29064 .61796 Mdot
.45405 .54711 Mdot
.40595 .6278 Mdot
.24602 .30489 Mdot
.27329 .56891 Mdot
.56057 .8687 Mdot
.64728 .3792 Mdot
.67373 .73269 Mdot
.63924 .22625 Mdot
.52775 .29063 Mdot
.33618 .41078 Mdot
.45302 .76569 Mdot
.42146 .46336 Mdot
.43283 .77261 Mdot
.43903 .50386 Mdot
.706 .51686 Mdot
.41765 .77478 Mdot
.50664 .72093 Mdot
.66468 .28879 Mdot
.43287 .2245 Mdot
.30685 .7115 Mdot
.37158 .60382 Mdot
.59606 .3679 Mdot
.64716 .3128 Mdot
.63394 .21399 Mdot
.59694 .77826 Mdot
.79075 .34088 Mdot
.61453 .7786 Mdot
.37139 .39825 Mdot
.50632 .37299 Mdot
.36951 .44806 Mdot
.62375 .33538 Mdot
.37752 .38474 Mdot
.495 .74242 Mdot
.66063 .22802 Mdot
.25726 .59307 Mdot
.69487 .47296 Mdot
.17572 .51272 Mdot
.77164 .32958 Mdot
.51013 .20959 Mdot
.62362 .74108 Mdot
.50767 .34512 Mdot
.17607 .62054 Mdot
.65976 .55152 Mdot
.6306 .29693 Mdot
.5173 .68342 Mdot
.74947 .52494 Mdot
.35147 .26796 Mdot
.61389 .80059 Mdot
.66686 .23091 Mdot
.46178 .77969 Mdot
.72575 .60773 Mdot
.59134 .48446 Mdot
.63475 .46539 Mdot
.17699 .493 Mdot
.4703 .34639 Mdot
.34388 .406 Mdot
.66442 .38784 Mdot
.2926 .52639 Mdot
.54114 .22166 Mdot
.78067 .59104 Mdot
.49268 .35306 Mdot
.73926 .65778 Mdot
.69329 .66997 Mdot
.54446 .51377 Mdot
.29547 .21378 Mdot
.40557 .46489 Mdot
.60387 .71286 Mdot
.74709 .31522 Mdot
.60137 .3953 Mdot
.60556 .21679 Mdot
.46066 .7447 Mdot
.2064 .357 Mdot
.53817 .15333 Mdot
.7744 .56494 Mdot
.33584 .21247 Mdot
.75703 .28044 Mdot
.18962 .39136 Mdot
.18979 .47794 Mdot
.53232 .64178 Mdot
.48116 .09817 Mdot
.63385 .53876 Mdot
.19936 .57907 Mdot
.26581 .564 Mdot
.74828 .44332 Mdot
.30451 .57354 Mdot
.36917 .34894 Mdot
.65908 .63586 Mdot
.36535 .53536 Mdot
.45286 .46442 Mdot
.21711 .3103 Mdot
.15615 .46552 Mdot
.22405 .30881 Mdot
.7858 .36269 Mdot
.34407 .20844 Mdot
.44326 .26188 Mdot
.31388 .41656 Mdot
.51564 .23671 Mdot
.45679 .35871 Mdot
.58599 .28092 Mdot
.5985 .70388 Mdot
.74726 .58926 Mdot
.38871 .65895 Mdot
.33933 .5473 Mdot
.25054 .31703 Mdot
.21856 .26728 Mdot
.22406 .50079 Mdot
.26761 .45193 Mdot
.48863 .58118 Mdot
.62452 .32046 Mdot
.40697 .51386 Mdot
.72981 .64234 Mdot
.63892 .2216 Mdot
.41094 .25851 Mdot
.65402 .29883 Mdot
.79085 .5954 Mdot
.60744 .49797 Mdot
.66553 .72422 Mdot
.47764 .17428 Mdot
.4833 .26575 Mdot
.63736 .77929 Mdot
.47845 .31096 Mdot
.55728 .82977 Mdot
.80179 .52922 Mdot
.70769 .59531 Mdot
.67068 .32007 Mdot
.62484 .57137 Mdot
.60881 .28136 Mdot
.56196 .57771 Mdot
.46504 .23435 Mdot
.56683 .41389 Mdot
.60775 .27659 Mdot
.60556 .50049 Mdot
.27365 .26351 Mdot
.80164 .32753 Mdot
.15646 .51621 Mdot
.82878 .43606 Mdot
.44958 .50247 Mdot
.39045 .36196 Mdot
.70215 .2562 Mdot
.25342 .27113 Mdot
.5606 .15425 Mdot
.50572 .75106 Mdot
.76625 .46431 Mdot
.50483 .61272 Mdot
.16322 .52847 Mdot
.81541 .51239 Mdot
.56985 .17971 Mdot
.28924 .71437 Mdot
.45449 .65617 Mdot
.47023 .79134 Mdot
.1784 .54244 Mdot
.33095 .28503 Mdot
.23342 .44316 Mdot
.36153 .41028 Mdot
.28637 .33941 Mdot
.36624 .61629 Mdot
.54487 .76003 Mdot
.61555 .33511 Mdot
.65749 .55604 Mdot
.49896 .281 Mdot
.34114 .39977 Mdot
.41233 .46021 Mdot
.69194 .61103 Mdot
.28833 .58709 Mdot
.20815 .5655 Mdot
.54778 .67533 Mdot
.3854 .17078 Mdot
.59036 .72848 Mdot
.38142 .48172 Mdot
.61156 .36458 Mdot
.73482 .56101 Mdot
.44251 .77422 Mdot
.51408 .6273 Mdot
.41735 .18561 Mdot
.43834 .53846 Mdot
.60007 .36663 Mdot
.2781 .34758 Mdot
.6324 .2589 Mdot
.46636 .35183 Mdot
.42303 .71329 Mdot
.33744 .46447 Mdot
.5532 .50499 Mdot
.39602 .58875 Mdot
.2855 .59048 Mdot
.87712 .48418 Mdot
.57723 .6282 Mdot
.63069 .7621 Mdot
.42683 .18597 Mdot
.51644 .66232 Mdot
.33157 .55475 Mdot
.58842 .26926 Mdot
.67797 .2901 Mdot
.3342 .488 Mdot
.63005 .50835 Mdot
.71393 .4193 Mdot
.79237 .56471 Mdot
.37455 .21035 Mdot
.32784 .24768 Mdot
.50311 .84645 Mdot
.30954 .57811 Mdot
.60943 .24193 Mdot
.6829 .3013 Mdot
.33076 .56305 Mdot
.38542 .62812 Mdot
.33315 .66172 Mdot
.33137 .20375 Mdot
.42287 .76202 Mdot
.81947 .43062 Mdot
.58408 .41821 Mdot
.75755 .41908 Mdot
.7361 .53696 Mdot
.70415 .34507 Mdot
.43346 .18586 Mdot
.23803 .40854 Mdot
.32314 .28141 Mdot
.39969 .48423 Mdot
.24217 .6096 Mdot
.16317 .53801 Mdot
.51624 .55067 Mdot
.31017 .35884 Mdot
.48748 .71795 Mdot
.40263 .43541 Mdot
.18719 .35241 Mdot
.69345 .27864 Mdot
.39948 .78396 Mdot
.51239 .69457 Mdot
.41895 .4228 Mdot
.37793 .3689 Mdot
.53906 .41195 Mdot
.39464 .71606 Mdot
.16325 .47467 Mdot
.7104 .34537 Mdot
.49232 .48191 Mdot
.26936 .36342 Mdot
.6039 .71517 Mdot
.47648 .1851 Mdot
.66985 .25209 Mdot
.55998 .55194 Mdot
.59511 .70995 Mdot
.58867 .45809 Mdot
.81693 .41012 Mdot
.6443 .6194 Mdot
.44367 .2569 Mdot
.28161 .67041 Mdot
.42262 .73634 Mdot
.74037 .56097 Mdot
.40846 .35635 Mdot
.51135 .76872 Mdot
.5162 .18041 Mdot
.51729 .86784 Mdot
.52969 .8102 Mdot
.2081 .3128 Mdot
.32896 .33608 Mdot
.4241 .74207 Mdot
.30519 .28429 Mdot
.49706 .87785 Mdot
.6641 .62469 Mdot
.2818 .28165 Mdot
.59088 .47475 Mdot
.40271 .19095 Mdot
.52697 .67463 Mdot
.35395 .73826 Mdot
.17778 .52149 Mdot
.34043 .20042 Mdot
.54031 .20482 Mdot
.44466 .18934 Mdot
.49458 .32206 Mdot
.30486 .22255 Mdot
.26709 .66264 Mdot
.65741 .65454 Mdot
.69621 .56142 Mdot
.50737 .74234 Mdot
.24005 .36132 Mdot
.42337 .61238 Mdot
.64169 .29911 Mdot
.66069 .70005 Mdot
.35163 .47041 Mdot
.30521 .30027 Mdot
.54302 .28239 Mdot
.44388 .73734 Mdot
.60952 .36886 Mdot
.54712 .17114 Mdot
.66729 .68982 Mdot
.72497 .51001 Mdot
.60434 .75536 Mdot
.79572 .41599 Mdot
.39044 .71228 Mdot
.58479 .64414 Mdot
.55715 .19726 Mdot
.8067 .49232 Mdot
.66687 .33624 Mdot
.89542 .46014 Mdot
.74753 .35798 Mdot
.35921 .65302 Mdot
.23929 .32056 Mdot
.6535 .23446 Mdot
.26343 .6347 Mdot
.50017 .83318 Mdot
.24048 .60316 Mdot
.59584 .30311 Mdot
.44879 .36436 Mdot
.27632 .23586 Mdot
.55989 .31622 Mdot
.24699 .29994 Mdot
.73828 .28687 Mdot
.28603 .33307 Mdot
.39287 .4496 Mdot
.66188 .50221 Mdot
.51249 .57471 Mdot
.53881 .27413 Mdot
.33713 .26245 Mdot
.23392 .59092 Mdot
.69655 .50952 Mdot
.68217 .63643 Mdot
.63257 .50975 Mdot
.49981 .45889 Mdot
.58454 .71067 Mdot
.41803 .72554 Mdot
.62765 .40661 Mdot
.57956 .57312 Mdot
.6313 .31239 Mdot
.24919 .40796 Mdot
.33536 .28307 Mdot
.59042 .81258 Mdot
.46882 .70398 Mdot
.68681 .56013 Mdot
.3925 .23466 Mdot
.75559 .35715 Mdot
.47116 .73084 Mdot
.19663 .39471 Mdot
.45911 .76904 Mdot
.54892 .2494 Mdot
.50342 .2216 Mdot
.54818 .82103 Mdot
.82019 .61474 Mdot
.21978 .37342 Mdot
.24147 .61439 Mdot
.62346 .42901 Mdot
.35025 .32811 Mdot
.39429 .1748 Mdot
.68678 .32746 Mdot
.47705 .2251 Mdot
.49013 .55335 Mdot
.31074 .49778 Mdot
.27821 .33013 Mdot
.51765 .3022 Mdot
.56878 .4755 Mdot
.21045 .67881 Mdot
.32343 .55118 Mdot
.17881 .36286 Mdot
.48232 .63342 Mdot
.37169 .79461 Mdot
.6178 .49887 Mdot
.54971 .56415 Mdot
.56633 .45571 Mdot
.4168 .70736 Mdot
.3249 .67437 Mdot
.78957 .37457 Mdot
.58871 .82288 Mdot
.64257 .51197 Mdot
.64946 .35766 Mdot
.81768 .45488 Mdot
.3907 .22737 Mdot
.46842 .44277 Mdot
.76636 .37336 Mdot
.51261 .54755 Mdot
.74565 .58903 Mdot
.70528 .26243 Mdot
.45237 .70009 Mdot
.49242 .37628 Mdot
.62209 .32323 Mdot
.27852 .287 Mdot
.51854 .15518 Mdot
.45914 .81446 Mdot
.44027 .50356 Mdot
.52288 .62481 Mdot
.45066 .27711 Mdot
.37613 .2182 Mdot
.61007 .42965 Mdot
.37774 .74055 Mdot
.65122 .31817 Mdot
.1311 .46081 Mdot
.16373 .44642 Mdot
.16385 .47764 Mdot
.61166 .38341 Mdot
.38999 .56174 Mdot
.25387 .64087 Mdot
.48328 .22498 Mdot
.44296 .70346 Mdot
.7426 .33469 Mdot
.63369 .30167 Mdot
.44018 .85394 Mdot
.33668 .42278 Mdot
.78353 .44757 Mdot
.26345 .3429 Mdot
.26977 .5426 Mdot
.53185 .66138 Mdot
.58238 .30104 Mdot
.4248 .5262 Mdot
.47231 .61661 Mdot
.4379 .73423 Mdot
.35804 .71521 Mdot
.47339 .2256 Mdot
.32881 .45959 Mdot
.46824 .49359 Mdot
.4271 .22026 Mdot
.37406 .53819 Mdot
.74246 .5387 Mdot
.72846 .52617 Mdot
.51913 .48659 Mdot
.63691 .559 Mdot
.47229 .46249 Mdot
.55933 .5154 Mdot
.58182 .4762 Mdot
.19213 .59945 Mdot
.64358 .41902 Mdot
.36193 .54263 Mdot
.36105 .77664 Mdot
.3362 .5594 Mdot
.23972 .27436 Mdot
.72542 .64565 Mdot
.27857 .35177 Mdot
.78087 .54682 Mdot
.77128 .63782 Mdot
.27402 .75998 Mdot
.18388 .45672 Mdot
.46381 .55959 Mdot
.40744 .57359 Mdot
.30837 .61407 Mdot
.66589 .48101 Mdot
.67671 .64179 Mdot
.24065 .44581 Mdot
.61026 .69651 Mdot
.53221 .2406 Mdot
.37293 .62129 Mdot
.76875 .42013 Mdot
.4013 .50565 Mdot
.34768 .19128 Mdot
.6835 .55147 Mdot
.15387 .58392 Mdot
.41997 .32451 Mdot
.37599 .26899 Mdot
.69288 .24518 Mdot
.46066 .80455 Mdot
.71957 .60011 Mdot
.83175 .55751 Mdot
.42889 .45257 Mdot
.46968 .49065 Mdot
.34935 .60514 Mdot
.58226 .24169 Mdot
.66433 .41961 Mdot
.57677 .36574 Mdot
.45128 .63911 Mdot
.66185 .76224 Mdot
.57937 .72051 Mdot
.3802 .55516 Mdot
.4135 .53409 Mdot
.54045 .21247 Mdot
.32936 .71046 Mdot
.51225 .54575 Mdot
.37985 .23892 Mdot
.33114 .48391 Mdot
.36831 .6247 Mdot
.18835 .4125 Mdot
.68278 .30582 Mdot
.48176 .149 Mdot
.36065 .34352 Mdot
.51825 .5671 Mdot
.31688 .71001 Mdot
.43638 .72424 Mdot
.24495 .42549 Mdot
.63395 .21877 Mdot
.60306 .35465 Mdot
.35169 .7489 Mdot
.60412 .27566 Mdot
.38464 .34098 Mdot
.62154 .61717 Mdot
.53994 .74166 Mdot
.40368 .83687 Mdot
.19713 .49618 Mdot
.49285 .80716 Mdot
.40969 .6153 Mdot
.60309 .71159 Mdot
.34762 .53939 Mdot
.72516 .46811 Mdot
.32453 .47635 Mdot
.70187 .63483 Mdot
.43453 .15643 Mdot
.64318 .22232 Mdot
.46426 .59692 Mdot
.60894 .56893 Mdot
.55576 .43032 Mdot
.37298 .4671 Mdot
.53384 .50544 Mdot
.40974 .44724 Mdot
.52099 .43319 Mdot
.44611 .80542 Mdot
.43707 .70863 Mdot
.36522 .35851 Mdot
.3785 .19041 Mdot
.49276 .14652 Mdot
.29499 .23544 Mdot
.63076 .44286 Mdot
.37712 .56374 Mdot
.1946 .37192 Mdot
.27006 .41261 Mdot
.5456 .16879 Mdot
.2161 .39302 Mdot
.87441 .46321 Mdot
.33262 .2703 Mdot
.50055 .71797 Mdot
.63772 .78766 Mdot
.3546 .67627 Mdot
.71252 .27524 Mdot
.65764 .66052 Mdot
.6895 .46729 Mdot
.72078 .28139 Mdot
.24796 .75652 Mdot
.19027 .49257 Mdot
.36526 .72499 Mdot
.38529 .28229 Mdot
.50368 .49104 Mdot
.617 .67971 Mdot
.44295 .35388 Mdot
.66485 .59674 Mdot
.72835 .59778 Mdot
.63653 .30943 Mdot
.34834 .31543 Mdot
.61903 .68614 Mdot
.53725 .26981 Mdot
.57644 .2481 Mdot
.71034 .33942 Mdot
.34765 .26259 Mdot
.24531 .4397 Mdot
.49424 .38675 Mdot
.38964 .5528 Mdot
.69539 .42824 Mdot
.71535 .52937 Mdot
.46972 .38943 Mdot
.71116 .60849 Mdot
.3128 .68488 Mdot
.20835 .31751 Mdot
.71172 .46747 Mdot
.68171 .28377 Mdot
.31529 .55114 Mdot
.40555 .71532 Mdot
.47791 .20011 Mdot
.4968 .77383 Mdot
.62799 .69427 Mdot
.27261 .56884 Mdot
.36299 .21087 Mdot
.44593 .76371 Mdot
.6441 .28193 Mdot
.22258 .65667 Mdot
.46143 .62651 Mdot
.21276 .56239 Mdot
.42403 .25869 Mdot
.47608 .767 Mdot
.36568 .6298 Mdot
.52349 .71233 Mdot
.61054 .62493 Mdot
.46518 .75699 Mdot
.75006 .31691 Mdot
.58267 .23282 Mdot
.25108 .36074 Mdot
.33638 .23872 Mdot
.68534 .58437 Mdot
.65042 .29714 Mdot
.538 .69777 Mdot
.62134 .65604 Mdot
.31889 .7189 Mdot
.38152 .17827 Mdot
.54443 .49552 Mdot
.54996 .31806 Mdot
.40694 .43193 Mdot
.29035 .43456 Mdot
.42587 .70425 Mdot
.59206 .51962 Mdot
.61186 .76605 Mdot
.36396 .61151 Mdot
.57025 .74312 Mdot
.68252 .70184 Mdot
.58646 .31332 Mdot
.39812 .53343 Mdot
.27088 .62284 Mdot
.71038 .41573 Mdot
.67214 .68588 Mdot
.48607 .41109 Mdot
.55321 .33265 Mdot
.62829 .46267 Mdot
.20142 .53594 Mdot
.18688 .49436 Mdot
.38616 .23421 Mdot
.70115 .29912 Mdot
.46298 .72445 Mdot
.21452 .39257 Mdot
.33069 .67169 Mdot
.31713 .40066 Mdot
.53814 .78195 Mdot
.38011 .40341 Mdot
.72734 .46551 Mdot
.35229 .54622 Mdot
.37531 .22747 Mdot
.32521 .36623 Mdot
.52798 .29963 Mdot
.53798 .53677 Mdot
.49696 .19791 Mdot
.49017 .53383 Mdot
.696 .25004 Mdot
.35786 .67501 Mdot
.61369 .3364 Mdot
.48971 .68753 Mdot
.59553 .4712 Mdot
.5433 .81364 Mdot
.46572 .16351 Mdot
.5994 .81046 Mdot
.532 .35753 Mdot
.48635 .80097 Mdot
.24337 .62469 Mdot
.72913 .28217 Mdot
.60556 .32517 Mdot
.532 .50732 Mdot
.39976 .50669 Mdot
.50711 .59675 Mdot
.69806 .69206 Mdot
.73801 .47063 Mdot
.2576 .43156 Mdot
.73018 .40021 Mdot
.7078 .62949 Mdot
.4739 .44202 Mdot
.25904 .67866 Mdot
.34698 .22767 Mdot
.36157 .49023 Mdot
.53861 .561 Mdot
.75631 .55032 Mdot
.58274 .32187 Mdot
.84616 .6439 Mdot
.18661 .35179 Mdot
.40565 .42987 Mdot
.57233 .43281 Mdot
.57904 .35634 Mdot
.62418 .54472 Mdot
.24085 .45742 Mdot
.3832 .23267 Mdot
.50963 .63195 Mdot
.76201 .47428 Mdot
.5115 .73537 Mdot
.41341 .69977 Mdot
.50541 .29228 Mdot
.44135 .63542 Mdot
.22536 .29119 Mdot
.77018 .36632 Mdot
.43998 .71831 Mdot
.87132 .56783 Mdot
.51975 .75288 Mdot
.32172 .54064 Mdot
.53332 .1992 Mdot
.27656 .25994 Mdot
.60436 .39068 Mdot
.75184 .51824 Mdot
.18463 .5057 Mdot
.60813 .3428 Mdot
.60338 .2611 Mdot
.60349 .75468 Mdot
.57701 .7469 Mdot
.64543 .6423 Mdot
.77278 .63505 Mdot
.20915 .61454 Mdot
.25044 .3829 Mdot
.31243 .2536 Mdot
.71405 .64635 Mdot
.45359 .85775 Mdot
.47124 .15628 Mdot
.5742 .28113 Mdot
.62187 .70488 Mdot
.55731 .20205 Mdot
.56397 .37542 Mdot
.27114 .58045 Mdot
.72286 .64017 Mdot
.32426 .50537 Mdot
.75972 .64162 Mdot
.5611 .78603 Mdot
.6081 .27924 Mdot
.26237 .56168 Mdot
.55096 .48868 Mdot
.37113 .25207 Mdot
.69408 .72773 Mdot
.62461 .35346 Mdot
.76782 .48723 Mdot
.53724 .34597 Mdot
.40645 .22122 Mdot
.54254 .18832 Mdot
.53253 .49817 Mdot
.24648 .75121 Mdot
.25446 .29928 Mdot
.50914 .78111 Mdot
.38685 .36149 Mdot
.43098 .15251 Mdot
.50912 .50093 Mdot
.20528 .40907 Mdot
.73345 .31044 Mdot
.71608 .5072 Mdot
.30391 .69794 Mdot
.38264 .41431 Mdot
.18942 .43814 Mdot
.30993 .35015 Mdot
.26549 .54587 Mdot
.73125 .5901 Mdot
.61065 .36324 Mdot
.6838 .73199 Mdot
.51121 .31082 Mdot
.35778 .42889 Mdot
.35932 .5494 Mdot
.23607 .29022 Mdot
.44154 .28787 Mdot
.48684 .45264 Mdot
.4724 .31288 Mdot
.59575 .81604 Mdot
.84937 .56328 Mdot
.3595 .42641 Mdot
.43585 .76761 Mdot
.64294 .30117 Mdot
.51179 .22979 Mdot
.18502 .47314 Mdot
.46479 .91628 Mdot
.68195 .23511 Mdot
.29531 .5847 Mdot
.21908 .55536 Mdot
.62228 .36928 Mdot
.30106 .23481 Mdot
.79178 .59097 Mdot
.73329 .55289 Mdot
.59593 .83182 Mdot
.57731 .38907 Mdot
.46867 .36346 Mdot
.77797 .34497 Mdot
.47394 .1609 Mdot
.69453 .73701 Mdot
.39868 .17494 Mdot
.38149 .44 Mdot
.39705 .34358 Mdot
.66183 .84056 Mdot
.39423 .20418 Mdot
.41081 .46236 Mdot
.56286 .83184 Mdot
.29935 .62703 Mdot
.46205 .36825 Mdot
.60187 .65542 Mdot
.67921 .32699 Mdot
.58782 .25453 Mdot
.33893 .20145 Mdot
.39009 .56851 Mdot
.71268 .60881 Mdot
.49582 .68133 Mdot
.56734 .45974 Mdot
.47125 .33988 Mdot
.49775 .67185 Mdot
.55878 .2516 Mdot
.52179 .49031 Mdot
.48675 .6917 Mdot
.70321 .35069 Mdot
.81107 .36036 Mdot
.32997 .32423 Mdot
.48842 .59011 Mdot
.51737 .35855 Mdot
.35515 .48441 Mdot
.53928 .27241 Mdot
.51361 .24839 Mdot
.73263 .29688 Mdot
.7541 .25536 Mdot
.64586 .48599 Mdot
.3787 .33106 Mdot
.37278 .52491 Mdot
.25186 .42563 Mdot
.31884 .30339 Mdot
.50837 .70051 Mdot
.67401 .66981 Mdot
.37773 .4233 Mdot
.35627 .4237 Mdot
.45174 .64211 Mdot
.14532 .40992 Mdot
.42782 .34884 Mdot
.22424 .42497 Mdot
.52551 .17125 Mdot
.74295 .54268 Mdot
.34579 .30979 Mdot
.44305 .45211 Mdot
.26498 .65086 Mdot
.50181 .50312 Mdot
.52761 .4601 Mdot
.73214 .52934 Mdot
.31657 .23277 Mdot
.32599 .36347 Mdot
.24318 .37861 Mdot
.41479 .39699 Mdot
.63574 .41119 Mdot
.35079 .71936 Mdot
.17431 .46593 Mdot
.35714 .45366 Mdot
.53942 .16227 Mdot
.71426 .50078 Mdot
.72308 .38867 Mdot
.36935 .28954 Mdot
.24016 .30366 Mdot
.52591 .80646 Mdot
.30481 .31774 Mdot
.41625 .79086 Mdot
.57325 .67539 Mdot
.54608 .28348 Mdot
.65464 .50349 Mdot
.36839 .35137 Mdot
.31578 .635 Mdot
.26784 .23259 Mdot
.17571 .47774 Mdot
.55092 .6434 Mdot
.692 .50439 Mdot
.30042 .39472 Mdot
.56182 .46368 Mdot
.88355 .52455 Mdot
.8181 .55455 Mdot
.22123 .29549 Mdot
.56995 .23344 Mdot
.35898 .52083 Mdot
.45229 .74284 Mdot
.50244 .37573 Mdot
.66701 .5254 Mdot
.30606 .23438 Mdot
.34986 .37178 Mdot
.56207 .77896 Mdot
.45714 .35602 Mdot
.3748 .77202 Mdot
.45539 .51275 Mdot
.61282 .57164 Mdot
.63301 .58378 Mdot
.50722 .82946 Mdot
.51077 .18568 Mdot
.49524 .50769 Mdot
.86788 .49657 Mdot
.31954 .2671 Mdot
.41979 .1848 Mdot
.6296 .50974 Mdot
.41719 .82126 Mdot
.41694 .59473 Mdot
.43604 .515 Mdot
.54825 .66744 Mdot
.51191 .33007 Mdot
.47386 .76227 Mdot
.52875 .2321 Mdot
.3413 .69249 Mdot
.46436 .59845 Mdot
.85086 .33109 Mdot
.57806 .27324 Mdot
.36521 .47769 Mdot
.51942 .76671 Mdot
.40388 .18112 Mdot
.67007 .46231 Mdot
.79874 .35784 Mdot
.58564 .57232 Mdot
.44929 .32837 Mdot
.33128 .45659 Mdot
.3811 .27088 Mdot
.52089 .73173 Mdot
.23758 .71654 Mdot
.74714 .34681 Mdot
.71953 .4133 Mdot
.57775 .57286 Mdot
.32878 .56305 Mdot
.30358 .5751 Mdot
.77942 .57874 Mdot
.83717 .41081 Mdot
.48603 .49413 Mdot
.37908 .21556 Mdot
.3125 .78718 Mdot
.61535 .25451 Mdot
.31074 .2229 Mdot
.42019 .62462 Mdot
.39316 .62457 Mdot
.53773 .26626 Mdot
.63893 .38304 Mdot
.63635 .57875 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0V?ooool3o`00
0:kooooo000Looooo`;o0000VOooool3o`000:kooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0_?ooool2o`0008_ooooo000Looooo`03o`000?oooooo
oooo07oooooo0_l0000Tooooo`;o00005Oooool2o`0008_ooooo000Looooo`03o`000?oooooooooo
07oooooo0_l0000Tooooo`;o00001?ooool2o`0000;ooooo0_l00002ooooo`;o0000U?ooool001co
oooo00?o0000ooooooooool0Zoooool2o`0000;ooooo0_l00002ooooo`;o00001?ooool2o`0008ko
oooo000Looooo`03o`000?oooooooooo0:oooooo0_l00008ooooo`;o0000S_ooool001cooooo00?o
0000ooooooooool0aOooool2o`0008;ooooo000Looooo`03o`000?oooooooooo0<Gooooo0_l00022
ooooo`007?ooool00ol0003oooooooooo`2Kooooo`;o0000[?ooool001cooooo00?o0000oooooooo
ool0Voooool2o`000:cooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0YOooool2o`000:;ooooo000Looooo`03o`000?oooooooooo0:Gooooo0_l0002R
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo09co
oooo0_l0000Aooooo`;o0000V?ooool001cooooo00?o0000ooooooooool0VOooool2o`000003oooo
ool0003o000000Sooooo0_l00007ooooo`;o0000V?ooool001cooooo0_l00029ooooo`;o00003ooo
ool2o`0000Cooooo0_l00005ooooo`;o00000oooool2o`0009cooooo000Looooo`03o`000?oooooo
oooo08Sooooo0ol0000:ooooo`?o00001oooool2o`0000Cooooo0_l00004ooooo`;o00001Oooool2
o`00027ooooo0_l0001booooo`007?ooool00ol0003oooooooooo`29ooooo`;o00002_ooool3o`00
00gooooo0_l0000;ooooo`;o00008Oooool2o`0007;ooooo000Looooo`03o`000?oooooooooo09;o
oooo0_l00002ooooo`;o00002_ooool2o`0000Oooooo0_l00008ooooo`?o0000TOooool001cooooo
00?o0000ooooooooool0S_ooool2o`0000;ooooo1_l0000:ooooo`;o00001oooool2o`0000Sooooo
1Ol0002?ooooo`007?ooool00ol0003oooooooooo`21ooooo`;o00001?ooool2o`0000Gooooo0_l0
0004ooooo`;o00000oooool2o`0001;ooooo0_l000000ooooooo0000o`000006ooooo`;o0000Sooo
ool001cooooo00?o0000ooooooooool0NOooool2o`0000Kooooo0_l00004ooooo`;o00003Oooool5
o`0000Gooooo0_l00005ooooo`;o00001?ooool5o`0009Oooooo000Looooo`03o`000?oooooooooo
07Sooooo0ol000000ooooooo0000o`000002o`0001?ooooo0_l000000ooooooo0000o`000003o`00
00Gooooo0_l000000ooooooo0000o`000002ooooo`;o00001Oooool3o`0000Oooooo0_l0002?oooo
o`007?ooool00ol0003oooooooooo`1hooooo`;o00000_ooool4o`00017ooooo1?l00002ooooo`;o
00001?ooool2o`0000Cooooo0_l00002ooooo`Co00000oooool2o`0000Cooooo0_l00002ooooo`;o
000000?oooooo`000?l000000_ooool2o`0008Sooooo000Looooo`03o`000?oooooooooo07Sooooo
0_l00005ooooo`;o00002oooool2o`0000?ooooo0_l00004ooooo`Co00000_ooool2o`0000Gooooo
0_l000000ooooooo0000o`000002o`0000?ooooo1?l00002ooooo`?o00001?ooool6o`0008Sooooo
000Looooo`03o`000?oooooooooo07cooooo0_l000000ooooooo0000o`00000;ooooo`;o00002Ooo
ool4o`0000Wooooo0_l00007ooooo`;o000000?oooooo`000?l000000oooool2o`0000Kooooo0_l0
000Sooooo`;o0000IOooool001cooooo00?o0000ooooooooool0O?ooool2o`0000Gooooo2?l00005
ooooo`;o00001Oooool3o`0000Sooooo0_l00009ooooo`;o000000?oooooo`000?l000003oooool2
o`0001oooooo0_l0001Uooooo`007?ooool00ol0003oooooooooo`1eooooo`Co00002_ooool8o`00
00;ooooo0_l000000ooooooo0000o`000005ooooo`;o00001oooool6o`0000Kooooo0_l0000Aoooo
o`Go0000QOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006
ooooo`03o`000?oooooooooo06gooooo0_l00006ooooo`Co00001_ooool2o`0000cooooo0_l0000A
ooooo`;o00000_ooool2o`0000Kooooo0_l0000Aooooo`;o000000?oooooo`000?l00000QOooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A006ooooo`03o`000?oooooooooo06gooooo0_l0000;ooooo`;o00000oooool2o`0001?ooooo
0_l0000Vooooo`;o00000oooool4o`0008Cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oo
oooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`1Vooooo`;o00004?oo
ool4o`0001Sooooo0_l00008ooooo`;o00002Oooool2o`0000Kooooo1?l00007ooooo`;o00000ooo
ool4o`0008Cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RH
ob4Q8Oo^k^h01_ooool3o`0006Kooooo0_l00002ooooo`?o00001_ooool2o`0000?ooooo0_l0000M
ooooo`;o00001Oooool2o`0000Wooooo0_l00006ooooo`Co00000oooool2o`0008oooooo00000ooo
oooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0
003oooooooooo`1Xooooo`Go00001Oooool3o`0000Oooooo0_l0000Iooooo`;o00001?ooool3o`00
0004ooooool0003o0000ooooo`;o00001_ooool2o`0000?ooooo0_l00005ooooo`;o00002Oooool2
o`0008Cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`1Xooooo`;o00000_ooool2o`0000;ooooo1?l000001?oo
oooo0000o`000?ooool2o`0000;ooooo0_l0000@ooooo`Co00002oooool2o`0000;ooooo0_l00000
0ooooooo0000o`000006ooooo`;o00005Oooool2o`0000?ooooo0ol0001nooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003ooooo
ooooo`1/ooooo`So000000?oooooo`000?l000000ol0000Dooooo`Co00004?ooool3o`0001;ooooo
0_l0000:ooooo`;o00000oooool3o`0007kooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo05cooooo0_l0000;oooo
o`;o00000oooool2o`0000;ooooo0_l00002ooooo`;o00001_ooool3o`00027ooooo0ol00007oooo
o`;o00002Oooool2o`0000Gooooo0_l00002ooooo`;o00001_ooool2o`0007gooooo000Looooo`03
o`000?oooooooooo05cooooo0_l0000;ooooo`;o00000oooool2o`0000Kooooo0ol00005ooooo`?o
00003Oooool2o`0000Kooooo0_l0000Dooooo`;o00001oooool2o`0000Oooooo0_l000001?oooooo
0000o`000?l00002ooooo`;o00000_ooool2o`0007gooooo000Looooo`03o`000?oooooooooo067o
oooo0_l0000;ooooo`;o00001_ooool3o`0000Oooooo0_l00003ooooo`Co000000?oooooo`000?l0
00000_ooool2o`0000Kooooo0_l00008ooooo`;o00003oooool2o`0000;ooooo0_l00005ooooo`;o
00000oooool2o`0000?ooooo0_l000000ooooooo0000o`000003o`0007_ooooo000Looooo`03o`00
0?oooooooooo05Kooooo0_l00007ooooo`Co00007Oooool2o`0000?ooooo1ol0000Dooooo`;o0000
1Oooool2o`0000?ooooo1?l000000ooooooo0000o`000009ooooo`;o00000oooool2o`0000Kooooo
1_l000000ooooooo0000o`000005ooooo`;o0000L?ooool001cooooo00?o0000ooooooooool0E_oo
ool2o`0000Oooooo1?l00004ooooo`;o00001?ooool2o`0000Oooooo0_l00003ooooo`;o00003?oo
ool2o`0000_ooooo1_l0000;ooooo`;o00000oooool4o`0001Oooooo0_l00003ooooo`?o000000?o
ooooo`000?l000001Oooool2o`00073ooooo000Looooo`03o`000?oooooooooo05?ooooo0_l0000>
ooooo`;o00000_ooool2o`0000Cooooo0_l00007ooooo`;o00000oooool2o`0001Wooooo1_l00000
0ooooooo0000o`000003ooooo`;o00002_ooool2o`0001Oooooo0_l00003ooooo`;o00000oooool4
o`0001gooooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00003_ooool2o`00
01Cooooo1_l0000Hooooo`;o00001?ooool7o`0000Cooooo0_l00004ooooo`;o00001Oooool2o`00
00;ooooo0_l0000Fooooo`Ko00006oooool2o`0005Gooooo000Looooo`03o`000?oooooooooo05?o
oooo0_l000000ooooooo0000o`000004ooooo`Ko000000?oooooo`000?l000005?ooool6o`00017o
oooo0_l000001?oooooo0000o`000?ooool2o`0000Oooooo1?l000000ooooooo0000o`000002oooo
o`;o00001?ooool2o`0000Gooooo0_l00002ooooo`;o00000oooool2o`0000Oooooo0_l00007oooo
o`;o00000_ooool3o`0000?ooooo0_l0001]ooooo`007?ooool00ol0003oooooooooo`1Fooooo`;o
00001?ooool6o`0000Sooooo0_l0000;ooooo`Oo00004_ooool2o`000004ooooool0003o0000oooo
o`;o00003?ooool3o`0000Oooooo0_l0000>ooooo`;o00001oooool4o`0000Gooooo0_l00002oooo
o`;o00000_ooool4o`0006gooooo000Looooo`03o`000?oooooooooo06[ooooo0_l0000;ooooo`?o
00006Oooool2o`00013ooooo0_l00002ooooo`;o00002?ooool2o`0000?ooooo0ol00007ooooo`;o
00001Oooool2o`000003ooooool0003o000000[ooooo0_l0001_ooooo`007?ooool00ol0003ooooo
ooooo`2>ooooo`Co000000?oooooo`000?l000003_ooool2o`0000Cooooo0_l00008ooooo`;o0000
0oooool3o`0000Oooooo0ol00007ooooo`;o00001oooool4o`0000Cooooo0_l0001Zooooo`007?oo
ool00ol0003oooooooooo`1Pooooo`;o00001Oooool2o`0002Gooooo1?l00003ooooo`;o00003?oo
ool2o`0000oooooo0_l000000ooooooo0000o`000005ooooo`;o00000oooool2o`00013ooooo1Ol0
0003ooooo`;o0000J_ooool001cooooo0_l0001Qooooo`;o00001Oooool2o`0000Gooooo0_l00005
ooooo`;o00007_ooool2o`0000cooooo0ol00002ooooo`;o00001Oooool2o`000003ooooool0003o
000000;o000000?oooooo`000?l000001Oooool2o`000003ooooool0003o000001?ooooo1?l00004
ooooo`;o000000?oooooo`000?l00000I_ooool001cooooo00?o0000ooooooooool0H_ooool2o`00
00Cooooo0_l00004ooooo`;o00001Oooool2o`0002gooooo0_l00002ooooo`;o00001Oooool2o`00
0003ooooool0003o000000Oooooo0_l00004ooooo`;o000000?oooooo`000?l000002?ooool2o`00
00Kooooo0_l00002ooooo`Ko000000?oooooo`000?l000003_ooool2o`0005Kooooo000Looooo`03
o`000?oooooooooo06;ooooo0_l00004ooooo`;o00003oooool2o`0000Oooooo0_l00008ooooo`;o
0000;Oooool4o`0000Gooooo0_l00008ooooo`;o00002_ooool4o`0000;ooooo0_l0000?ooooo`;o
00002_ooool2o`0004[ooooo000Looooo`03o`000?oooooooooo05Kooooo0_l0000Qooooo`;o0000
1Oooool4o`0000;ooooo0_l00004ooooo`;o00002_ooool2o`00027ooooo1?l000000ooooooo0000
o`000004ooooo`;o000000Coooooo`000?l0003o00001_ooool2o`0000cooooo0_l0000Kooooo`;o
0000B_ooool001cooooo00?o0000ooooooooool0C?ooool2o`0000Oooooo0ol00004ooooo`;o0000
3?ooool2o`000003ooooool0003o0000017ooooo1?l00002ooooo`;o00001?ooool2o`0000[ooooo
0_l0000;ooooo`;o00006Oooool2o`0000Cooooo0_l000001?oooooo0000o`000?l00003ooooo`;o
000000?oooooo`000?l000003?ooool5o`0006Cooooo000Looooo`03o`000?oooooooooo04?ooooo
0_l00007ooooo`;o00001oooool2o`0000Gooooo0_l00006ooooo`;o00001?ooool2o`000003oooo
ool0003o000001[ooooo0_l000000ooooooo0000o`00000;ooooo`;o00002_ooool2o`0000Cooooo
0_l0000>ooooo`;o00001_ooool2o`0000[ooooo0_l00009ooooo`Co00000_ooool5o`0006Cooooo
000Looooo`03o`000?oooooooooo04?ooooo0_l0000Booooo`;o00001?ooool2o`000003ooooool0
003o000000;ooooo0_l00002ooooo`;o00001?ooool2o`0000Kooooo1?l0000;ooooo`;o000000Co
ooooo`000?l0003o00003_ooool2o`00013ooooo0_l0000:ooooo`;o00000_ooool2o`0000Kooooo
0_l0000:ooooo`;o00002Oooool4o`000004ooooool0003o0000ooooo`;o0000IOooool001cooooo
00?o0000ooooooooool0Coooool2o`000003ooooool0003o000000?ooooo0_l00004ooooo`;o0000
00?oooooo`000?l000001_ooool2o`0000Cooooo0_l00006ooooo`Co00002oooool2o`000003oooo
ool0003o000000oooooo0_l00003ooooo`;o00002oooool2o`0000[ooooo0ol000000ooooooo0000
o`00000Kooooo`;o00001Oooool2o`0006Sooooo000Looooo`03o`000?oooooooooo04[ooooo0_l0
0003ooooo`;o000000?oooooo`000?l000008Oooool2o`0000?ooooo0_l0000Kooooo`Co00000ooo
ool2o`0000;ooooo0_l00003ooooo`;o00000_ooool3o`0000[ooooo0_l00006ooooo`Co00005?oo
ool2o`0000;ooooo0_l00006ooooo`;o0000Hoooool001cooooo00?o0000ooooooooool0B_ooool2
o`0000;ooooo0_l0000Eooooo`;o00003_ooool2o`0000?ooooo0_l0000Cooooo`;o00001_ooool2
o`0000Wooooo0_l00003ooooo`;o00000_ooool3o`0001;ooooo1?l0000?ooooo`;o00001oooool3
o`0000Gooooo0_l0001Sooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o00002?ooool2o`00
00_ooooo0_l00002ooooo`;o00001_ooool2o`0000Kooooo0_l00009ooooo`;o00002Oooool2o`00
00gooooo0_l00009ooooo`;o000000?oooooo`000?l000000_l00007ooooo`;o00000_ooool2o`00
0003ooooool0003o000000;ooooo0_l00009ooooo`;o00000_ooool4o`0000Gooooo0_l000000ooo
oooo0000o`000007ooooo`;o000000?oooooo`000?l000001oooool2o`0005Gooooo000Looooo`03
o`000?oooooooooo05Sooooo0_l00005ooooo`;o00001?ooool2o`000004ooooool0003o0000o`00
00Kooooo0_l00006ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`;o000000?ooooo
o`000?l000005Oooool2o`0000Cooooo0_l00003ooooo`;o00000_ooool3o`0000Oooooo0_l00000
1Ooooooo0000o`000?l0003ooooo00;o00000_ooool2o`000003ooooool0003o000000Kooooo0_l0
0002ooooo`;o00001_ooool3o`0000[ooooo0_l000000ooooooo0000o`000007ooooo`;o0000EOoo
ool001cooooo00?o0000ooooooooool0Eoooool2o`0000Kooooo0_l00007ooooo`;o000000?ooooo
o`000?l000002Oooool2o`0000Kooooo0_l000000ooooooo0000o`000004ooooo`;o00000oooool2
o`0001Kooooo0_l00008ooooo`;o00002_ooool2o`0000Wooooo0_l00003ooooo`;o00001Oooool2
o`000003ooooool0003o000000?ooooo0ol0000@ooooo`;o0000Foooool001cooooo00?o0000oooo
ooooool0AOooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000Kooooo0_l0000B
ooooo`;o00001oooool4o`0000cooooo0_l000000ooooooo0000o`000003ooooo`;o00004_ooool2
o`0000Kooooo0_l0000Hooooo`;o00001_ooool2o`0000Gooooo0_l000000ooooooo0000o`000002
ooooo`;o00004_ooool2o`0005_ooooo000Looooo`03o`000?oooooooooo04Cooooo0ol00002oooo
o`;o000000Coooooo`000?l0003ooooo0_l0000Sooooo`;o00003_ooool2o`000003ooooool0003o
000001Oooooo0_l00006ooooo`;o00000oooool2o`0001?ooooo0_l0000Cooooo`?o000000?ooooo
o`000?l000000oooool2o`0006Oooooo000Looooo`03o`000?oooooooooo04Cooooo0_l0000Moooo
o`;o00005oooool2o`0000?ooooo0_l0000Pooooo`;o00002?ooool2o`0001?ooooo0_l00005oooo
o`;o00001?ooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool2o`00
00Oooooo0ol0001Mooooo`007?ooool2o`0004kooooo1?l0000<ooooo`Co00000_ooool2o`0001Oo
oooo0_l00003ooooo`;o00000_ooool3o`0000;ooooo0_l0000=ooooo`;o00002?ooool2o`0000?o
oooo0_l0000?ooooo`;o00001oooool2o`0000Gooooo2_l000001?oooooo0000o`000?ooool2o`00
0003ooooool0003o000000Cooooo0_l00007ooooo`?o00000oooool2o`0005Sooooo000Looooo`03
o`000?oooooooooo04[ooooo0_l000000ooooooo0000o`000002o`0000Wooooo0_l000000ooooooo
0000o`000002o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000Sooooo1?l00005ooooo`Co
000000Coooooo`000?l0003o00000_ooool2o`0000?ooooo0_l00008ooooo`;o00002Oooool2o`00
00;ooooo0_l0000?ooooo`;o00000oooool4o`0000Sooooo1Ol00002ooooo`;o00001?ooool2o`00
0004ooooool0003o0000ooooo`;o000000?oooooo`000?l000000_l00005ooooo`Co00000_ooool2
o`0005Sooooo000Looooo`03o`000?oooooooooo04[ooooo1?l0000;ooooo`?o00002?ooool2o`00
00;ooooo0_l00003ooooo`;o00002?ooool4o`0000Gooooo1?l0000;ooooo`;o000000?oooooo`00
0?l000004?ooool2o`0001Sooooo1?l000000ooooooo0000o`000006ooooo`;o00002_ooool2o`00
0004ooooool0003o0000ooooo`;o00000_ooool3o`0000Oooooo0_l0001Looooo`007?ooool00ol0
003oooooooooo`13ooooo`Co00001Oooool2o`0000Kooooo0_l00003ooooo`;o00002_ooool2o`00
00Kooooo0_l00008ooooo`;o00002Oooool2o`0000Cooooo0ol00007ooooo`;o00003_ooool2o`00
00Sooooo0_l0000Eooooo`;o00001_ooool2o`0000gooooo0_l000000ooooooo0000o`000002o`00
00Wooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`0oooooo`?o000000?oooooo`000?l0
00000_l0000=ooooo`;o00003oooool2o`0000Kooooo0_l0000Cooooo`;o00000_ooool7o`0000Wo
oooo1?l00008ooooo`;o00002?ooool2o`0000gooooo0_l0000<ooooo`Co000000?oooooo`000?l0
00003oooool2o`0000Wooooo0ol0001Looooo`007?ooool00ol0003oooooooooo`0oooooo`?o0000
3?ooool2o`0001gooooo0_l0000:ooooo`;o00002_ooool=o`0000Cooooo1?l0000Hooooo`;o0000
1oooool2o`0000Cooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000
o`00000Kooooo`;o00000_ooool3o`0005Oooooo000Looooo`03o`000?oooooooooo043ooooo0_l0
000<ooooo`;o00003oooool2o`000003ooooool0003o000000Wooooo0_l0000:ooooo`;o00002_oo
ool7o`000003ooooool0003o000000?o00007Oooool2o`000003ooooool0003o000000?ooooo0_l0
0008ooooo`;o00000oooool3o`0000;ooooo0_l00003ooooo`;o00001?ooool2o`0000Wooooo0_l0
000<ooooo`?o0000Eoooool001cooooo00?o0000ooooooooool0@?ooool2o`0000Sooooo0_l0000C
ooooo`;o000000?oooooo`000?l000007_ooool2o`0000Gooooo1?l000000ooooooo0000o`00000=
ooooo`;o00004?ooool2o`0000Kooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00001?oo
ool5o`0000Gooooo1?l00004ooooo`;o00002Oooool4o`0006Cooooo000Looooo`03o`000?oooooo
oooo04[ooooo0_l0000Fooooo`Co000000?oooooo`000?l000005oooool4o`000003ooooool0003o
000000;o00000_ooool3o`0000oooooo0ol000000ooooooo0000o`00000?ooooo`;o00001Oooool4
o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000000ol00005ooooo`;o00001Ooo
ool3o`0000[ooooo0ol0000?ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0DOooool3
o`0000kooooo2?l00004ooooo`;o00002oooool2o`0000?ooooo4?l00007ooooo`?o00001?ooool2
o`000003ooooool0003o000000?ooooo0_l0000:ooooo`Co000000?oooooo`000?l000001?l00004
ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Gooooo0_l00002ooooo`Co00000_ooool4
o`0001Oooooo0_l0000;ooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0C_ooool2o`00
0004ooooool0003o0000o`0000?ooooo0_l0000=ooooo`Co00000_ooool4o`0000Oooooo0_l00002
ooooo`;o00000_ooool3o`0000;ooooo3Ol00006ooooo`Go00001?ooool2o`000004ooooool0003o
0000ooooo`;o00000oooool2o`0000Oooooo0_l000000ooooooo0000o`000002ooooo`;o000000?o
ooooo`000?l000001?ooool2o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`0000Cooooo1?l0
000Gooooo`;o000000?oooooo`000?l000002?ooool2o`0000kooooo0_l0000fooooo`007?ooool0
0ol0003oooooooooo`13ooooo`;o00000oooool2o`0000Cooooo0_l00002ooooo`;o00000oooool4
o`00017ooooo0_l00009ooooo`;o00001_ooool3o`0000Kooooo1?l000000ooooooo0000o`000002
o`0000;ooooo0_l00002ooooo`Go00001?ooool2o`000004ooooool0003o0000o`0000Gooooo0_l0
0003ooooo`;o00001Oooool2o`0000Gooooo0_l000001?oooooo0000o`000?ooool2o`000003oooo
ool0003o000001cooooo0_l00006ooooo`;o00002?ooool2o`0001Sooooo0_l0000fooooo`007?oo
ool00ol0003oooooooooo`13ooooo`;o00000oooool2o`0000oooooo0ol00002ooooo`;o00001ooo
ool2o`0000kooooo0_l00009ooooo`Co000000Coooooo`000?l0003ooooo0_l000001?oooooo0000
o`000?ooool5o`0000;ooooo0ol0000:ooooo`Co00002?ooool2o`0000Gooooo1?l00006ooooo`;o
000000Coooooo`000?l0003ooooo0_l00009ooooo`Go00002_ooool2o`0000;ooooo1?l00003oooo
o`?o0000F_ooool001cooooo00?o0000ooooooooool0>_ooool2o`0000_ooooo0_l0000@ooooo`?o
00000_ooool2o`0000Oooooo0_l00009ooooo`;o00000oooool4o`0000Cooooo2_l00006ooooo`Co
00000_ooool5o`0000?ooooo0_l00007ooooo`;o00000_ooool2o`0000Cooooo1?l00003ooooo`Co
00001oooool4o`0000cooooo1_l00009ooooo`So00000oooool2o`0000oooooo0_l0001:ooooo`00
7?ooool00ol0003oooooooooo`0jooooo`;o00002oooool2o`0000Wooooo0_l00005ooooo`?o0000
00?oooooo`000?l000002?ooool2o`000003ooooool0003o000000Cooooo1?l00005ooooo`;o0000
0_ooool:o`0000?ooooo0_l00003ooooo`;o00000oooool6o`0000?ooooo0_l0000;ooooo`;o0000
0_ooool6o`0000Oooooo0_l00005ooooo`Co00001oooool2o`0000Kooooo0ol00009ooooo`Co0000
5_ooool4o`0004[ooooo000Looooo`03o`000?oooooooooo04;ooooo0_l00009ooooo`;o00000ooo
ool3o`0000;ooooo1?l00002ooooo`;o00002?ooool2o`000003ooooool0003o000000?ooooo1?l0
0008ooooo`ko000000?oooooo`000?l000000ol00002ooooo`So00000_ooool3o`0000?ooooo0_l0
0005ooooo`;o000000?oooooo`000?l000000ol0000;ooooo`;o00001Oooool4o`0000Oooooo0_l0
0006ooooo`;o00002_ooool4o`0000[ooooo0_l00008ooooo`Co0000C?ooool001cooooo0_l00013
ooooo`;o00002Oooool2o`0000Cooooo0_l00002ooooo`Co00001_ooool2o`0000cooooo0_l00003
ooooo`Go00000_ooool>o`000003ooooool0003o000000?o00000_ooool6o`0000Cooooo0ol00003
ooooo`;o00001Oooool2o`000003ooooool0003o000000;o00003?ooool2o`0000Gooooo0_l00007
ooooo`;o00005?ooool4o`0000?ooooo0_l00005ooooo`;o00002?ooool2o`0004kooooo000Loooo
o`03o`000?oooooooooo03Wooooo0_l0000<ooooo`;o00003_ooool2o`000003ooooool0003o0000
00Gooooo0_l0000Aooooo`Go00000oooool=o`0000?ooooo0ol000000ooooooo0000o`000005o`00
0005ooooool0003o0000o`000?ooool01ol00006ooooo`?o00002?ooool2o`0000cooooo0_l00003
ooooo`;o00000_ooool2o`0000Sooooo0_l0000:ooooo`;o00001Oooool2o`0001Gooooo0_l00018
ooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00001?ooool2o`0000Kooooo0_l0000>oooo
o`;o000000?oooooo`000?l000004_ooool2o`0000Cooooo0_l00002ooooo`;o00000_ooool2o`00
0003ooooool0003o000001Ko000000Goooooo`000?l0003o0000ooooo`05o`0000?ooooo1?l00000
1?oooooo0000o`000?l00008ooooo`;o00000_ooool2o`0000Kooooo0_l00005ooooo`;o00003?oo
ool4o`0000[ooooo0_l0000=ooooo`;o00002oooool2o`0004Sooooo000Looooo`03o`000?oooooo
oooo03Sooooo0ol00004ooooo`;o00008?ooool2o`0000_ooooo0_l00003ooooo`;o00000ooooolO
o`000004ooooool0003o0000o`0000?ooooo0ol00003ooooo`Co000000?oooooo`000?l000000_l0
0006ooooo`;o00000oooool2o`0000Kooooo0_l0000=ooooo`;o00001_ooool2o`0000[ooooo0_l0
000:ooooo`;o000000?oooooo`000?l000003?ooool2o`0001Cooooo0_l0000aooooo`007?ooool0
0ol0003oooooooooo`0fooooo`Co00004?ooool2o`0000;ooooo0_l00005ooooo`;o00002_ooool2
o`000003ooooool0003o000000Kooooo0_l00005ooooo`;o00001OoooolQo`000003ooooool0003o
000000?o00000oooool3o`0000;ooooo1?l00006ooooo`?o00003Oooool2o`0000Sooooo1?l00004
ooooo`;o00005?ooool2o`0000;ooooo0_l0000:ooooo`?o00000_ooool2o`000004ooooool0003o
0000o`00013ooooo0_l0000aooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00003_ooool2
o`0000;ooooo0_l00002ooooo`;o00001?ooool3o`0000?ooooo0_l00006ooooo`Ko00001?ooool2
o`0000Kooooo1?l00002oooooako00000oooool4o`0000?ooooo0_l000000ooooooo0000o`000006
ooooo`;o00001Oooool2o`0000;ooooo0_l00009ooooo`;o00002?ooool4o`0000Cooooo0_l00008
ooooo`;o00001?ooool4o`0000;ooooo0_l00006ooooo`;o000000?oooooo`000?l000000oooool3
o`0000Gooooo0ol00013ooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00001Oooool2o`00
00Kooooo0_l00004ooooo`?o00000oooool4o`0000Cooooo0_l00002ooooo`;o000000?oooooo`00
0?l000002Oooool6o`000003ooooool0003o000001_o00000oooool2o`0000?ooooo1?l00009oooo
o`?o00002?ooool2o`0000;ooooo1Ol000001Ooooooo0000o`000?l0003ooooo00?o00001_ooool4
o`0000cooooo0_l00004ooooo`Co00002_ooool2o`000003ooooool0003o000000Cooooo0_l0001;
ooooo`007?ooool00ol0003oooooooooo`0looooo`;o000000?oooooo`000?l000004Oooool2o`00
00Oooooo0ol000000ooooooo0000o`000004ooooo`;o00000_ooool2o`0000?ooooo0_l00006oooo
o`Go000000?oooooo`000?l000008?l00002ooooo`Co000000?oooooo`000?l000001oooool2o`00
00?ooooo0_l00007ooooo`Go000000?oooooo`000?l000000_ooool5o`0000?ooooo0_l000000ooo
oooo0000o`00001fooooo`007?ooool00ol0003oooooooooo`0looooo`;o00001Oooool3o`0000co
oooo0_l00005ooooo`;o00001?ooool2o`0000Cooooo0ol00006ooooo`;o00001_ooool5o`000003
ooooool0003o0000023o00000oooool2o`0000;ooooo0_l00008ooooo`;o00000_ooool2o`0000ko
oooo0_l00003ooooo`?o00000oooool2o`0000_ooooo0_l00006ooooo`;o00004?ooool2o`0000Ko
oooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`13ooooo`?o00001Oooool2o`0000cooooo
0_l00004ooooo`;o00001?ooool3o`0000_ooooo2?l000000ooooooo0000o`000005o`000003oooo
ool0003o000000go000000?oooooo`000?l000001?l000001Ooooooo0000o`000?l0003ooooo00Co
00003?ooool3o`000003ooooool0003o000000Gooooo0_l00007ooooo`;o000000?oooooo`000?l0
00000_l00002ooooo`?o00002?ooool2o`0000;ooooo0_l00006ooooo`;o00000oooool2o`0000_o
oooo0_l00006ooooo`Co00000oooool2o`0000;ooooo0_l0000oooooo`007?ooool00ol0003ooooo
ooooo`14ooooo`;o00001Oooool2o`0000;ooooo0_l00002ooooo`;o00002_ooool2o`000003oooo
ool0003o000000oooooo1?l000000ooooooo0000o`000002ooooob;o000000?oooooo`000?l00000
3oooool2o`0000;ooooo0_l00004ooooo`;o00001Oooool2o`0000?ooooo0_l00004ooooo`Co0000
1oooool2o`000003ooooool0003o000000cooooo0_l0000<ooooo`;o00001?ooool5o`0000?ooooo
0_l000001?oooooo0000o`000?l0000oooooo`007?ooool00ol0003oooooooooo`11ooooo`;o0000
00?oooooo`000?l000002?ooool3o`0000;ooooo0_l0000=ooooo`;o00004?ooool6o`0000;ooooo
8_l0000?ooooo`;o00001Oooool2o`0000Cooooo0_l00005ooooo`Co000000?oooooo`000?l00000
0_ooool6o`0000Gooooo0_l00002ooooo`Go00006?ooool2o`0000Cooooo0_l00003ooooo`;o0000
0oooool4o`0000kooooo0_l0000_ooooo`007?ooool00ol0003oooooooooo`11ooooo`;o00002ooo
ool4o`0000[ooooo0_l0000Eooooo`Oo00000_oooolFo`000003ooooool0003o000000[o00002_oo
ool2o`0000;ooooo1ol00006ooooo`;o00001oooool2o`0000;ooooo0_l000000ooooooo0000o`00
0002o`0000Kooooo1?l000000ooooooo0000o`000004o`0001gooooo0_l00003ooooo`;o00000ooo
ool4o`0000kooooo0_l0000_ooooo`007?ooool00ol0003oooooooooo`1?ooooo`?o00002Oooool3
o`0001?ooooo1?l000000ooooooo0000o`00000Jo`000003ooooool0003o000000Co00000_ooool4
o`0000Sooooo1?l00002ooooo`go00001Oooool4o`0000;ooooo1?l0000:ooooo`Wo000000?ooooo
o`000?l000000oooool2o`0000?ooooo0_l0000Cooooo`Co00002?ooool2o`0003oooooo00001_oo
ooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?oo
ool00ol0003oooooooooo`0jooooo`;o00000oooool2o`000003ooooool0003o000000Gooooo0_l0
0004ooooo`?o00001oooool4o`00017ooooo1ol000000ooooooo0000o`00000Qo`000003ooooool0
003o000000;ooooo0_l00003ooooo`Ko00001?ooool2o`000005ooooool0003o0000o`000?ooool0
1_l00005ooooo`Go000000?oooooo`000?l000002?ooool3o`000003ooooool0003o000000[o0000
00?oooooo`000?l000001?l000000ooooooo0000o`00000Eooooo`;o00002_ooool2o`0003gooooo
00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0>_ooool4o`000004ooooool0003o0000ooooo`Co00000oooool2o`00
00Kooooo0_l00004ooooo`Co00000oooool2o`0000kooooo1ol00002ooooobWo00000oooool4o`00
00Wooooo2?l00008ooooo`Co00002_oooolAo`000003ooooool0003o000000;ooooo0_l0000Toooo
o`;o0000?Oooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool5o`0000Ko
oooo00?o0000ooooooooool0??ooool2o`0000Kooooo0_l0000;ooooo`Co00000_ooool2o`0000Go
oooo0_l0000;ooooo`;o00001?ooool2o`0000;ooooo8Ol000000ooooooo0000o`000006o`0000?o
oooo0_l0000;ooooo`;o000000?oooooo`000?l000001?l00008ooooo`;o00002OoooolDo`0000?o
oooo1?l000000ooooooo0000o`000002o`0001oooooo0_l0000mooooo`0000?oooooo`000?ooool0
0_ooool00ol0003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol00010ooooo`;o
00003oooool4o`0000Oooooo0_l00005ooooo`;o00001_ooool2o`0000Cooooo:?l000000ooooooo
0000o`000008o`000003ooooool0003o000000Sooooo0_l00009ooooo`;o00001oooool2o`0000Ko
oooo5_l000001?oooooo0000o`000?l00002ooooo`Co00007oooool2o`0003gooooo00000ooooooo
0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0
003oooooooooo`10ooooo`;o00002_ooool2o`0000?ooooo0_l00009ooooo`;o00001Oooool2o`00
00Oooooo0_l00002ooooo`;o000000?oooooo`000?l000000ooooolQo`000003ooooool0003o0000
00Ko00000oooool2o`0000Kooooo0_l00004ooooo`;o00001Oooool2o`0000Oooooo0_l00007oooo
oaKo0000:_ooool2o`0003_ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[o
oooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0oooooo`;o00002Oooool6o`000003
ooooool0003o000001Wooooo0_l00002ooooo`Co00001?oooolQo`000003ooooool0003o000000?o
00003_ooool9o`0000Cooooo0_l00007ooooo`;o00000ooooolJo`0000kooooo0_l0000Jooooo`;o
0000>oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007oooo
o`03o`000?oooooooooo02cooooo0_l0000;ooooo`;o00001?ooool2o`0000Wooooo0_l000001?oo
oooo0000o`000?l00006ooooo`;o00001Oooool2o`0000[ooooo0_l00005ooooo`Co00000ooooolP
o`0000?ooooo1Ol0000<ooooo`;o00000_ooool4o`000003ooooool0003o000000Cooooo0_l0000<
oooooa_o00001Oooool2o`0000Kooooo0_l0000Dooooo`;o00001?ooool2o`0003_ooooo00001_oo
ooook^k^oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooooooo
o`0/ooooo`;o00002oooool2o`00017ooooo0_l00006ooooo`Co00001Oooool2o`0000[ooooo0_l0
0006ooooo`?o00000_oooolQo`000003ooooool0003o000000Oo00001?ooool2o`0000;ooooo1?l0
0007ooooo`Co00001?ooool2o`0000;ooooo0_l00004oooooago000000?oooooo`000?l000001?l0
0009ooooo`;o00004Oooool2o`0000Cooooo0_l0000=ooooo`;o0000;?ooool001cooooo00?o0000
ooooooooool0=Oooool2o`0001Cooooo0ol00006ooooo`;o00003?ooool2o`0000gooooo0_l00003
oooooaoo000000?oooooo`000?l000000_l000000ooooooo0000o`000002ooooo`;o00001?ooool2
o`0000;ooooo0_l00009ooooo`Co00000_ooool4o`0000;ooooo0_l00004ooooob;o00002oooool3
o`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l000005oooool2o`0002cooooo000Loooo
o`03o`000?oooooooooo03Gooooo0_l0000Dooooo`Co00004_ooool3o`0000gooooo0ol00003oooo
o`;o00000_ooool7o`000003ooooool0003o000001Ko00003_ooool2o`0000[ooooo0_l00003oooo
o`Ko00001?ooool3o`0000Cooooo6ol0000<ooooo`Ko00000oooool2o`0000;ooooo0_l000000ooo
oooo0000o`000015ooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o000000?oooooo`000?l0
00003oooool2o`0000Oooooo0_l00004ooooo`Co00000oooool2o`000003ooooool0003o000000go
000000?oooooo`000?l000003ol00005ooooo`;o00001oooool2o`0000?ooooo0_l00003ooooo`;o
00001?ooool2o`000003ooooool0003o000000;o00001?ooool3o`0000Kooooo4_l000000ooooooo
0000o`000004o`0000cooooo0_l00002ooooo`;o00001oooool2o`0004Sooooo000Looooo`03o`00
0?oooooooooo04Gooooo0_l00005ooooo`Ko00003oooool2o`0000Oooooo0_l00004ooooo`?o0000
0oooool3o`000003ooooool0003o000001Oo000000?oooooo`000?l000001?l00006ooooo`;o0000
3?ooool2o`0000?ooooo0_l00004ooooo`;o00000_ooool2o`0000_ooooo0_l000000ooooooo0000
o`00000Fo`0006Cooooo000Looooo`03o`000?oooooooooo03cooooo0ol00006ooooo`;o00001Ooo
ool4o`0001Gooooo0_l00009ooooo`Go000000?oooooo`000?l000006ol000000ooooooo0000o`00
0004o`000003ooooool0003o000000;o000000?oooooo`000?l000002Oooool2o`000004ooooool0
003o0000ooooo`;o00001_ooool4o`0000Gooooo0_l00003ooooo`;o000000Coooooo`000?l0003o
oooo2?l000000ooooooo0000o`000009o`0000Cooooo0_l0000Fooooo`;o00001oooool2o`0000Go
oooo0_l0000jooooo`007?ooool00ol0003oooooooooo`0kooooo`Co00003?ooool2o`0000?ooooo
0_l00008ooooo`;o00002Oooool2o`0000Wooooo0_l000000ooooooo0000o`00000?o`000003oooo
ool0003o0000013o00001?ooool4o`0000Gooooo0ol00004ooooo`;o00001?ooool2o`0000?ooooo
0_l000000ooooooo0000o`000004o`0000?ooooo0_l00003ooooo`Co00000_oooolCo`0000;ooooo
0_l000000ooooooo0000o`00000Fooooo`;o00001oooool2o`0000Gooooo0_l0000jooooo`007?oo
ool00ol0003oooooooooo`0kooooo`;o00003_ooool2o`0000?ooooo0_l00002ooooo`;o00001?oo
ool3o`0000;ooooo0_l0000Dooooo`?o00000ooooolMo`0000?ooooo0_l00007ooooo`?o00003ooo
ool2o`0000Gooooo0_l00006ooooo`;o000000Coooooo`000?l0003o00000_oooolCo`0000;ooooo
0_l00009ooooo`;o00001Oooool2o`0001?ooooo0_l0000nooooo`007?ooool00ol0003ooooooooo
o`0jooooo`;o00004?ooool2o`0000;ooooo0_l00002ooooo`;o00001?ooool3o`0000;ooooo0_l0
000DooooobSo00007Oooool2o`0000Wooooo0_l00007oooooa3o00000oooool2o`0000[ooooo0_l0
0003ooooo`Co00004oooool2o`0003kooooo000Looooo`03o`000?oooooooooo03[ooooo0_l0000<
ooooo`;o00000_ooool2o`0000;ooooo0ol00007ooooo`Co00003_ooool2o`0000Sooooo9ol00004
ooooo`;o00001_ooool2o`0000_ooooo0_l000001?oooooo0000o`000?l0000=ooooo`;o00001Ooo
ool>o`0000?ooooo0_l0000<ooooo`;o000000?oooooo`000?l000003Oooool2o`000003ooooool0
003o000000[ooooo0_l0000gooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00005Oooool4
o`0000Gooooo0_l00009ooooo`;o00003Oooool3o`0000Sooooo0_l000000ooooooo0000o`000002
oooooa_o00002Oooool4o`0000Cooooo0_l00008ooooo`;o000000Coooooo`000?l0003ooooo1?l0
000<ooooo`;o00001oooool;o`0001;ooooo0_l0000@ooooo`;o000000?oooooo`000?l000002_oo
ool2o`0003Oooooo000Looooo`03o`000?oooooooooo037ooooo0_l0000Gooooo`;o00007oooool2
o`0000Oooooo1_l000001?oooooo0000o`000?oooolGo`0000Cooooo0_l00006ooooo`Co00002Ooo
ool2o`0000?ooooo0_l00003ooooo`Go00001_ooool2o`0000[ooooo0_l00003ooooo`So00007ooo
ool2o`0000Gooooo0_l00006ooooo`;o0000?Oooool001cooooo0_l0000hooooo`?o00005_ooool2
o`000003ooooool0003o000001oooooo0_l00002ooooo`Oo000000?oooooo`000?l000005?l00003
ooooo`?o00004_ooool2o`0000Sooooo1?l00006ooooo`?o000000?oooooo`000?l000001_ooool3
o`0000?ooooo1_l0000@ooooo`;o00003oooool2o`0000Gooooo0_l00006ooooo`Co0000>oooool0
01cooooo00?o0000ooooooooool0:Oooool2o`0000cooooo0ol0000Fooooo`;o000000?oooooo`00
0?l000000_ooool2o`0001Oooooo0_l00007ooooo`;o000000Coooooo`000?l0003o00001?ooool=
o`0000;ooooo1Ol00003ooooo`;o00004_ooool2o`000004ooooool0003o0000ooooo`;o00000_oo
ool2o`0000Sooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00000oooool2o`0000Cooooo
1_l0000@ooooo`;o00003oooool2o`0000Wooooo0_l00003ooooo`?o00000_ooool2o`0003Oooooo
000Looooo`03o`000?oooooooooo02Wooooo0_l0000=ooooo`;o00001Oooool2o`0000[ooooo0_l0
000:ooooo`;o00003oooool2o`0000Kooooo0_l0000;ooooo`;o00001?ooool4o`0000Gooooo1?l0
0002ooooo`Oo00003_ooool2o`0000Sooooo0_l000000ooooooo0000o`000002ooooo`;o000000?o
ooooo`000?l000002?ooool2o`0000;ooooo0_l00007ooooo`Ko00005?ooool2o`0001Sooooo0_l0
0008ooooo`;o0000=oooool001cooooo00?o0000ooooooooool09oooool2o`0000oooooo0_l00004
ooooo`?o00002_ooool2o`0001[ooooo0ol00004ooooo`;o00002_ooool3o`0000Gooooo1ol00000
0ooooooo0000o`000002o`0000Cooooo1ol000000ooooooo0000o`000003ooooo`;o00001_ooool3
o`0000[ooooo1?l00003ooooo`;o00005Oooool6o`0000;ooooo0_l0000@ooooo`;o00003_ooool2
o`0000kooooo0_l0000Aooooo`;o0000:?ooool001cooooo00?o0000ooooooooool09oooool2o`00
01Gooooo0_l0000Wooooo`;o000000?oooooo`000?l000000_ooool2o`0000Sooooo1Ol00003oooo
o`Wo000000Coooooo`000?l0003o00000_ooool9o`0000;ooooo0_l00003ooooo`;o00001oooool2
o`0000Wooooo1_l0000?ooooo`;o00002_ooool4o`0000;ooooo0_l00009ooooo`;o00003_ooool2
o`0000;ooooo0_l000000ooooooo0000o`00000>ooooo`;o00002_ooool2o`0000Gooooo0_l0000X
ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00001?ooool3o`0000Sooooo0_l0000Soooo
o`;o00000oooool2o`0000Wooooo1Ol00006ooooo`Oo00000_ooool<o`000005ooooool0003o0000
o`000?ooool00_l0000Fooooo`?o000000Goooooo`000?l0003o0000ooooo`02o`000003ooooool0
003o000000Wooooo1?l0000:ooooo`;o00001?ooool2o`0000Gooooo1?l000000ooooooo0000o`00
000;ooooo`;o00000_ooool2o`0000Kooooo0_l0000<ooooo`;o00001oooool2o`0002oooooo000L
ooooo`03o`000?oooooooooo02kooooo0ol00004ooooo`?o00002?ooool2o`0002?ooooo0_l00007
ooooo`Co000000?oooooo`000?l000001_l000000ooooooo0000o`000005ooooo`;o00000oooool8
o`0000Oooooo0_l0000Iooooo`;o000000Coooooo`000?l0003o00000_ooool2o`000003ooooool0
003o000000_ooooo0_l0000<ooooo`;o00000_ooool2o`0000Gooooo0_l00003ooooo`;o00000_oo
ool2o`0001?ooooo0_l0000<ooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0;_ooool2
o`0000Gooooo0_l000000ooooooo0000o`00000^ooooo`;o00001?ooool4o`000004ooooool0003o
0000ooooo`;o000000Coooooo`000?l0003ooooo1Ol00004ooooo`Go00000oooool5o`0000kooooo
0_l0000Booooo`Go00001Oooool2o`0000oooooo0ol00002ooooo`;o00000_ooool2o`0000Cooooo
0_l00008ooooo`;o00000_ooool2o`0000Wooooo0_l0000Cooooo`;o0000>oooool001cooooo00?o
0000ooooooooool0<Oooool2o`0000Gooooo0_l0000/ooooo`Co00003?ooool2o`0000Gooooo1?l0
0004ooooo`Co00000_ooool2o`0000;ooooo0ol00009ooooo`;o00000oooool2o`0000kooooo2ol0
00000ooooooo0000o`000002o`0000oooooo0ol00002ooooo`;o00001?ooool2o`0000;ooooo0_l0
000Dooooo`;o000000?oooooo`000?l000000_l0000Aooooo`;o00000_ooool2o`0003Oooooo000L
ooooo`03o`000?oooooooooo037ooooo0ol000000ooooooo0000o`000003ooooo`;o0000:_ooool2
o`0000_ooooo0_l00007ooooo`Go00001Oooool2o`0000?ooooo0_l00006ooooo`;o00001_ooool2
o`0001?ooooo1?l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000007?ooool2
o`0001Sooooo0_l000000ooooooo0000o`000002o`0001;ooooo0_l000000ooooooo0000o`00000g
ooooo`007?ooool00ol0003oooooooooo`0booooo`Go000000?oooooo`000?l000000_l0000Zoooo
o`;o00002oooool2o`0000?ooooo0_l00002ooooo`Go00000oooool2o`0000Oooooo0ol00003oooo
o`;o00001oooool2o`0000Wooooo0ol00004ooooo`Oo00003oooool2o`0000oooooo0_l0000Poooo
o`;o00001_ooool3o`0000_ooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`0dooooo`;o
00000_ooool2o`0002kooooo0_l00006ooooo`;o00001_ooool2o`0000Cooooo0_l00002ooooo`Ko
00001Oooool3o`000003ooooool0003o000000;o00001oooool2o`0000Wooooo0ol00004ooooo`Oo
00001oooool2o`0000Gooooo0ol00008ooooo`;o00000_ooool2o`000003ooooool0003o000000Co
oooo0_l0000Jooooo`Co00001?ooool3o`0001Oooooo0_l0000^ooooo`007?ooool00ol0003ooooo
ooooo`0kooooo`;o000000?oooooo`000?l000000oooool2o`0002?ooooo1?l00004ooooo`;o0000
1Oooool2o`0000Gooooo0_l00002ooooo`Ko00001?ooool3o`0000;ooooo1?l0000@ooooo`;o0000
2?ooool3o`000003ooooool0003o000000Oooooo0_l000000ooooooo0000o`000002ooooo`;o0000
0_ooool2o`0000Gooooo0_l00002ooooo`;o00001oooool2o`0001Wooooo0_l000000ooooooo0000
o`000005ooooo`;o00005oooool2o`0002kooooo000Looooo`03o`000?oooooooooo02kooooo0_l0
000:ooooo`?o000000?oooooo`000?l000000oooool2o`0002Cooooo0ol00006ooooo`Co000000?o
ooooo`000?l000003?ooool2o`0000?ooooo1Ol00006ooooo`;o00002Oooool2o`0000;ooooo1?l0
0007ooooo`;o00003_ooool2o`0000Kooooo0_l0000]ooooo`;o00001?ooool2o`0000;ooooo1?l0
000Jooooo`;o0000:Oooool001cooooo00?o0000ooooooooool08oooool2o`0000Wooooo0_l00006
ooooo`;o000000Coooooo`000?l0003o0000=_ooool4o`0000Cooooo0_l00009ooooo`;o00000ooo
ool4o`000003ooooool0003o000000?ooooo0ol00003ooooo`;o00001?ooool2o`0000;ooooo1?l0
0005ooooo`;o00008?ooool2o`0000Oooooo0_l00008ooooo`;o000000?oooooo`000?l000004?oo
ool2o`0000?ooooo0_l00004ooooo`;o00006_ooool2o`0002Wooooo000Looooo`03o`000?oooooo
oooo02?ooooo0_l00009ooooo`;o00001_ooool2o`000004ooooool0003o0000ooooo`?o00008_oo
ool2o`0001Oooooo0_l00005ooooo`;o00001Oooool2o`0000Cooooo0ol00003ooooo`;o00001?oo
ool2o`0000;ooooo1?l00002ooooo`;o00000oooool2o`0000;ooooo0_l0000Cooooo`;o00001_oo
ool2o`0000?ooooo0_l00007ooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`00
000@ooooo`;o00007Oooool2o`00037ooooo000Looooo`;o0000;oooool2o`0000Sooooo0_l00002
ooooo`?o00001_ooool3o`0001Wooooo0_l0000=ooooo`;o00003Oooool4o`0000Cooooo0ol00004
ooooo`;o00003_ooool8o`0000?ooooo0_l00004ooooo`;o00004?ooool3o`000003ooooool0003o
000000;ooooo0ol00006ooooo`?o00000_ooool2o`0000?ooooo0_l00006ooooo`;o00005_ooool2
o`0001;ooooo0_l000001?oooooo0000o`000?ooool2o`00037ooooo000Looooo`03o`000?oooooo
oooo03Sooooo0_l0000;ooooo`?o0000:?ooool3o`0000Cooooo0_l00006ooooo`Oo000000?ooooo
o`000?l000000_ooool2o`000003ooooool0003o000000oooooo0_l000001?oooooo0000o`000?l0
000:ooooo`?o00003oooool2o`0000;ooooo0_l00002ooooo`;o00001_ooool8o`0000?ooooo1?l0
0004ooooo`;o00005?ooool4o`0001;ooooo0_l000000ooooooo0000o`00000dooooo`007?ooool0
0ol0003oooooooooo`0hooooo`;o0000;?ooool2o`0000?ooooo0_l00004ooooo`;o000000Cooooo
o`000?l0003ooooo0_l00005ooooo`So00001Oooool2o`000003ooooool0003o000000?ooooo0_l0
0008ooooo`Co00000_ooool2o`0000?ooooo1?l00002ooooo`Co00005oooool2o`0000Kooooo1_l0
0005ooooo`Co00001Oooool2o`00013ooooo0_l000000ooooooo0000o`00000;ooooo`;o0000@?oo
ool001cooooo00?o0000ooooooooool0<oooool2o`0000?ooooo0_l0000Wooooo`;o00000oooool2
o`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l000002?ooool3o`0001;ooooo0_l00008
ooooo`;o00002Oooool9o`0001Sooooo1Ol000000ooooooo0000o`000003ooooo`Go00000oooool4
o`0000?ooooo1?l000001?oooooo0000o`000?l0000<ooooo`;o00003_ooool4o`0000Kooooo0_l0
000fooooo`007?ooool00ol0003oooooooooo`0cooooo`Co0000:_ooool2o`0000Kooooo0_l00006
ooooo`;o00001Oooool2o`0000Cooooo1Ol0000=ooooo`;o00006?ooool6o`0001?ooooo0_l00002
oooooa?o00000_ooool5o`0000;ooooo0_l00003ooooo`?o00003?ooool2o`0000cooooo0_l00002
ooooo`;o00001_ooool2o`0003Kooooo000Looooo`03o`000?oooooooooo02oooooo0_l00004oooo
o`;o0000<_ooool2o`0000gooooo0_l00004ooooo`Go00001oooool2o`0000Cooooo0_l0000=oooo
o`;o00002Oooool7o`000003ooooool0003o000000oooooo0_l00002oooooaCo000000Coooooo`00
0?l0003ooooo0_l000000ooooooo0000o`00000Eooooo`;o00002_ooool2o`0004;ooooo000Loooo
o`03o`000?oooooooooo02oooooo0_l00004ooooo`;o00004?ooool2o`0002Cooooo0_l0000Aoooo
o`;o00002?ooool2o`0000Oooooo0_l0000:ooooo`;o00001Oooool2o`0000Cooooo0_l000000ooo
oooo0000o`000003o`000004ooooool0003o0000o`0000Gooooo0_l00007ooooo`;o000000?ooooo
o`000?l000004?l000000ooooooo0000o`000002o`000004ooooool0003o0000o`0000cooooo0ol0
0006ooooo`Co0000C?ooool001cooooo00?o0000ooooooooool0=_ooool2o`0000Sooooo0_l00002
ooooo`;o000000?oooooo`000?l000009?ooool2o`0000;ooooo0_l00006ooooo`?o00005?ooool2
o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000Cooooo0_l00003ooooo`?o00001?oo
ool2o`000003ooooool0003o000000;o00000_ooool3o`0000;ooooo0_l000000ooooooo0000o`00
0007ooooo`;o000000?oooooo`000?l000005Ol000000ooooooo0000o`000003ooooo`;o000000?o
ooooo`000?l000001Oooool3o`0000Oooooo0ol0001<ooooo`007?ooool00ol0003oooooooooo`0f
ooooo`;o00002?ooool2o`0000;ooooo0_l0000Eooooo`;o00005?ooool2o`000004ooooool0003o
0000o`0000;ooooo0ol0000:ooooo`Co00001_ooool2o`0000Cooooo0_l00002ooooo`;o00001?oo
ool2o`0000?ooooo0ol00009ooooo`;o00001oooool2o`0000Kooooo0_l00002oooooaOo00000_oo
ool2o`0000Gooooo0_l000000ooooooo0000o`000005ooooo`;o00004_ooool2o`0001Gooooo0_l0
000/ooooo`007?ooool00ol0003oooooooooo`0aooooo`?o00004_ooool2o`0000gooooo0_l00004
ooooo`;o00002oooool3o`0000;ooooo0_l00003ooooo`Go00000_ooool4o`0000Wooooo1?l0000K
ooooo`;o00006oooool2o`0000;ooooo0ol000000ooooooo0000o`00000Ao`0000;ooooo0_l00004
ooooo`;o00000_ooool3o`0000Cooooo0_l00007ooooo`;o00001_ooool2o`000003ooooool0003o
000001Gooooo0_l0000/ooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o00000_ooool3o`00
0003ooooool0003o000000oooooo0_l0000<ooooo`?o00004Oooool3o`0000;ooooo0_l00003oooo
o`;o00001_ooool3o`0002?ooooo0_l000000ooooooo0000o`000004ooooo`;o00006Oooool5o`00
0003ooooool0003o0000017o00001_ooool4o`0000?ooooo1?l0000;ooooo`;o00001_ooool2o`00
04Kooooo000Looooo`03o`000?oooooooooo02cooooo0ol00003ooooo`;o000000?oooooo`000?l0
00000_l0000Kooooo`;o00005_ooool2o`0000?ooooo1?l00005ooooo`;o00000_ooool2o`0000?o
oooo0_l00004ooooo`;o00004?ooool2o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`;o
00003?ooool2o`0000_ooooo2_l000001Ooooooo0000o`000?l0003ooooo00[o00001_ooool2o`00
00Oooooo0_l0000Sooooo`;o0000=_ooool001cooooo00?o0000ooooooooool0;?ooool2o`0000?o
oooo0ol00003ooooo`;o00001Oooool3o`0002Sooooo0_l000000ooooooo0000o`000003ooooo`Co
000000?oooooo`000?l000001_ooool2o`0000?ooooo0_l00004ooooo`Co00000oooool2o`0000Go
oooo0_l00002ooooo`;o00003_ooool2o`0000[ooooo0_l00008ooooo`;o000000?oooooo`000?l0
00006?l00006ooooo`;o00001Oooool4o`0002;ooooo0_l0000fooooo`007?ooool00ol0003ooooo
ooooo`0aooooo`;o00002Oooool5o`0002Cooooo0ol000000ooooooo0000o`000002ooooo`;o0000
0_ooool7o`0001?ooooo0_l00003ooooo`;o00001Oooool2o`000003ooooool0003o000000?ooooo
0_l00004ooooo`;o00001?ooool2o`0001Cooooo0_l00003oooooaSo00001_ooool2o`0000Gooooo
1?l0001Jooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00001?ooool2o`0000;ooooo1Ol0
000?ooooo`?o00001_ooool2o`0000Kooooo1?l00004ooooo`?o000000?oooooo`000?l000000ol0
000Tooooo`;o00000oooool2o`0000Cooooo0_l0000Moooooa_o000000?oooooo`000?l000003?oo
ool2o`0005Wooooo000Looooo`03o`000?oooooooooo03Kooooo0_l00008ooooo`Go00002Oooool4
o`000003ooooool0003o000000;o00001_ooool2o`0000Sooooo0_l000000ooooooo0000o`00000:
o`0001[ooooo0_l00007ooooo`;o00001oooool3o`0001?ooooo0_l0000:ooooo`Ko000000?ooooo
o`000?l000004_l000001?oooooo0000o`000?l0000;ooooo`;o00001_ooool2o`0000;ooooo0_l0
001=ooooo`007?ooool2o`0003_ooooo0_l0000Booooo`Co000000?oooooo`000?l000003_ooool4
o`0000;ooooo3Ol000001?oooooo0000o`000?ooool2o`000003ooooool0003o0000017ooooo0_l0
0007ooooo`?o00001_ooool4o`0001;ooooo0_l00006ooooo`;o00000oooool=o`0000;ooooo3?l0
00000ooooooo0000o`00000=ooooo`Co00000_ooool3o`000003ooooool0003o000000cooooo0ol0
000nooooo`007?ooool00ol0003oooooooooo`0jooooo`;o00001Oooool2o`0000Wooooo0_l00007
ooooo`;o00000oooool2o`0000Oooooo2?l00002ooooo`?o000000?oooooo`000?l000001_l00000
0ooooooo0000o`000003o`0001[ooooo1?l00007ooooo`;o000000?oooooo`000?l000002Oooool2
o`0000Sooooo0_l000001?oooooo0000o`000?l00003ooooo`go000000?oooooo`000?l000002ol0
00000ooooooo0000o`000006ooooo`?o00001?ooool4o`0000?ooooo0_l0000?ooooo`?o0000?_oo
ool001cooooo00?o0000ooooooooool0@Oooool4o`0000Kooooo0ol00005ooooo`Co00000oooool2
o`0000Oooooo2?l00002ooooo`Co000000?oooooo`000?l000001_l000000ooooooo0000o`00000N
ooooo`;o00000_ooool2o`0000Kooooo0_l00005ooooo`;o00000_ooool2o`0000Sooooo0_l00000
0ooooooo0000o`000004oooooa_o00002Oooool3o`0000Cooooo0_l0000Dooooo`;o0000@Oooool0
01cooooo00?o0000ooooooooool0@oooool2o`0000Kooooo0ol00003ooooo`Co00003?oooolIo`00
01Wooooo0_l000000ooooooo0000o`000007ooooo`;o00000_ooool2o`0000Cooooo0_l00003oooo
o`;o00001oooool2o`0000cooooo6ol0000Rooooo`;o00000_ooool2o`0000;ooooo0_l0000moooo
o`007?ooool00ol0003oooooooooo`0jooooo`;o00000oooool4o`0000kooooo1?l0000:oooooako
00005_ooool5o`0000_ooooo0_l00004ooooo`Co00002_ooool2o`0000?ooooo0_l00007oooooa_o
00002oooool4o`0001?ooooo0_l00002ooooo`;o00000_ooool2o`0000Cooooo0_l0000gooooo`00
7?ooool00ol0003oooooooooo`0eooooo`;o00000oooool2o`0000?ooooo1?l0000=ooooo`Go0000
2_ooool2o`000003ooooool0003o000001Wo00000_ooool2o`0001Cooooo0_l00003ooooo`;o0000
3oooool2o`0000;ooooo0_l0000;ooooo`Go00000ooooolGo`000003ooooool0003o000000?o0000
2_ooool4o`0000Wooooo0_l00004ooooo`;o00002_ooool2o`0000Cooooo0_l0000gooooo`007?oo
ool00ol0003oooooooooo`0eooooo`;o00000oooool2o`0000Cooooo0_l0000=ooooo`?o000000?o
ooooo`000?l000000_l00005ooooo`;o000000?oooooo`000?l000007?l00002ooooo`;o00004Ooo
ool2o`0000?ooooo0_l000000ooooooo0000o`000009ooooo`;o00002?ooool2o`0000Sooooo0_l0
0002ooooobGo00000oooool2o`0000gooooo0_l00002ooooo`;o00001?ooool2o`0001Oooooo0_l0
000`ooooo`007?ooool00ol0003oooooooooo`0jooooo`;o00000_ooool4o`0000gooooo0_l00004
ooooo`;o00001Oooool3o`0000;ooooo5ol000000ooooooo0000o`000002o`0001Gooooo0_l00003
ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Gooooo0_l00009ooooo`Go00001?ooool5
o`000003ooooool0003o000001Oo000000?oooooo`000?l000000oooool2o`0000cooooo0ol0000Q
ooooo`;o0000<?ooool001cooooo00?o0000ooooooooool0?_ooool2o`0001_ooooo1ol000000ooo
oooo0000o`00000Ho`0000Cooooo0_l0000Dooooo`?o00002Oooool2o`0000Oooooo0_l00008oooo
o`Ko00001?ooool2o`000004ooooool0003o0000oooooaco000000?oooooo`000?l000000_l00009
ooooo`;o000000Coooooo`000?l0003o0000Doooool001cooooo00?o0000ooooooooool0D_ooool2
o`0000Oooooo8_l00004ooooo`;o00005Oooool2o`0000Wooooo0_l000000ooooooo0000o`000003
ooooo`;o000000?oooooo`000?l000000oooool2o`000003ooooool0003o000000;o00001Oooool4
o`0000Oooooo5_l000000ooooooo0000o`000002o`0000_ooooo0_l00007ooooo`;o00004?ooool2
o`0003cooooo000Looooo`03o`000?oooooooooo03gooooo0_l0000Cooooo`Co00001?ooool2o`00
0003ooooool0003o000000;ooooo7?l000001?oooooo0000o`000?ooool4o`00017ooooo0_l00003
ooooo`;o00002Oooool2o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`;o00002?ooool6
o`0000Oooooo6ol00004ooooo`;o00003_ooool2o`00013ooooo0_l0000looooo`007?ooool00ol0
003oooooooooo`0^ooooo`;o00003Oooool2o`0001Gooooo0_l00003ooooo`Ko00000_ooool5o`00
0003ooooool0003o000001Oo00000oooool2o`0000cooooo0_l00002ooooo`?o00000oooool2o`00
0003ooooool0003o000001gooooo0_l00002ooooo`;o00001ooooolGo`0000;ooooo0_l00004oooo
o`;o00008?ooool2o`0003cooooo000Looooo`03o`000?oooooooooo02kooooo0_l0000Pooooo`;o
00001oooool5o`0000?ooooo2ol000000ooooooo0000o`00000;o`0000?ooooo0_l0000:ooooo`;o
00001_ooool2o`0000;ooooo0_l00007ooooo`;o00001_ooool2o`00023ooooo1?l000000ooooooo
0000o`00000Bo`000003ooooool0003o000000;o00000oooool2o`0000Kooooo0_l0000Hooooo`;o
0000??ooool001cooooo00?o0000ooooooooool0B?ooool2o`0000?ooooo0_l000000ooooooo0000
o`000002ooooo`;o00000oooool7o`000003ooooool0003o000001Oo000000?oooooo`000?l00000
0_l0000:ooooo`;o00004?ooool2o`0000Wooooo0_l0000>ooooo`;o00004?oooolDo`0000Kooooo
1?l00003ooooo`?o00000_ooool5o`0000Oooooo0_l000000ooooooo0000o`00001:ooooo`0000Ko
ooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
00Kooooo00?o0000ooooooooool0B?ooool2o`0000?ooooo0_l000001Ooooooo0000o`000?l0003o
oooo00;o00000oooool?o`000003ooooool0003o000000go00000_ooool5o`0001cooooo0_l00000
0ooooooo0000o`000006ooooo`Go00002oooool2o`0000Sooooo0_l00007oooooa?o00003_ooool2
o`0000;ooooo0ol00002ooooo`;o00001Oooool2o`000003ooooool0003o000004[ooooo00001_oo
ooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40
1_ooool00ol0003oooooooooo`1@ooooo`?o00002OoooolRo`000003ooooool0003o000000?ooooo
0_l0000=ooooo`;o00002Oooool2o`000003ooooool0003o000000?ooooo1_l0000Dooooo`;o0000
1Oooool6o`0000;ooooo3?l00007ooooo`;o00000_ooool2o`0000;ooooo0ol00006ooooo`;o0000
1oooool3o`0004[ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo03_ooooo0_l00008ooooo`;o0000
5OoooolOo`000004ooooool0003o0000ooooo`;o00000oooool2o`0000gooooo0_l00006ooooo`;o
00001?ooool2o`0000?ooooo0_l00002ooooo`;o00006oooool2o`0000;ooooo0_l00002ooooo`Oo
00000oooool2o`0000Oooooo0_l00002ooooo`Oo00003oooool3o`0004[ooooo00000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o
0000>oooool2o`0000Sooooo0_l00003ooooo`;o00002oooool2o`000003ooooool0003o000000;o
oooo1_l000000ooooooo0000o`00000Co`0000Kooooo0_l0000:ooooo`;o00001Oooool2o`0000Ko
oooo0_l0000^ooooo`;o00005oooool7o`0005kooooo00000ooooooo0000ooooo`02ooooo`03o`00
0?oooooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo03_o
oooo0_l00008ooooo`;o00000oooool2o`0000_ooooo0_l000001?oooooo0000o`000?oooolMo`00
00;ooooo0_l00002ooooo`;o000000?oooooo`000?l000001oooool2o`0001Wooooo1?l00006oooo
o`;o00008Oooool2o`0000kooooo1_l000000ooooooo0000o`00000Jooooo`?o00002?ooool2o`00
03Gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qooo
ool02?ooool00ol0003oooooooooo`0kooooo`;o00002?ooool2o`0000Cooooo0_l00003ooooo`;o
00002ooooolLo`0000?ooooo0_l00005ooooo`;o00003oooool2o`00017ooooo1?l00006ooooo`;o
00005Oooool2o`0000[ooooo0_l00002ooooo`;o00002Oooool7o`000003ooooool0003o000001[o
oooo0ol00008ooooo`;o0000=Oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool00ooM
gMgo410@oiRHV008ooooo`03o`000?oooooooooo04_ooooo0_l00002ooooo`?o00002ooooolMo`00
00;ooooo0_l00002ooooo`;o00001?ooool2o`0000Wooooo1Ol00009ooooo`?o00001Oooool2o`00
00kooooo0_l0000?ooooo`;o00003_ooool2o`0000?ooooo0_l00004ooooo`Oo00009_ooool2o`00
03Oooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_oo
ool00ol0003oooooooooo`10ooooo`;o00002Oooool2o`0000;ooooo0_l00003ooooo`;o00001ooo
oolMo`0000;ooooo0_l00002ooooo`?o00000oooool2o`0000Wooooo1?l00005ooooo`?o000000?o
ooooo`000?l000000_l000000ooooooo0000o`00000Booooo`;o00003oooool2o`0000;ooooo0ol0
000>ooooo`;o00000_ooool2o`0000Gooooo0_l0000Mooooo`;o00001oooool2o`0003Oooooo000L
ooooo`03o`000?oooooooooo043ooooo0_l00009ooooo`;o00001_ooool3o`0000;ooooo0_l00000
0ooooooo0000o`000002oooooa7o000000?oooooo`000?l000001_l000000ooooooo0000o`000005
ooooo`;o00003_ooool3o`000005ooooool0003o0000o`000?ooool01?l000001Ooooooo0000o`00
0?l0003ooooo00Co00001Oooool2o`0001Wooooo1?l00002ooooo`Co000000?oooooo`000?l00000
0_ooool2o`0000[ooooo0_l0000Tooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0=Ooo
ool2o`0001?ooooo0_l00007ooooo`?o00000_ooool2o`000003ooooool0003o000000Oooooo4ol0
00000ooooooo0000o`000002o`0000Gooooo0_l00009ooooo`?o00000_ooool3o`000003ooooool0
003o000000oo00001Oooool2o`0001Wooooo0_l00006ooooo`;o000000?oooooo`000?l000000_oo
ool2o`000003ooooool0003o000000Cooooo0_l00009ooooo`;o000000?oooooo`000?l000000_l0
001Iooooo`007?ooool00ol0003oooooooooo`0eooooo`;o00003?ooool2o`0000?ooooo1Ol00003
ooooo`;o00000_ooool2o`0000Kooooo0_l00003ooooob;o00000_ooool2o`0000Gooooo0ol00002
oooooaOo00006oooool2o`0000Cooooo0_l00003ooooo`;o00001?ooool2o`0000;ooooo0_l00004
ooooo`;o00002Oooool2o`000003ooooool0003o000000;o0000FOooool001cooooo00?o0000oooo
ooooool0@oooool2o`000003ooooool0003o000000Go00000oooool2o`0000;ooooo0ol00005oooo
o`Co000000?oooooo`000?l000002Ol000000ooooooo0000o`000009o`000004ooooool0003o0000
ooooo`Oo00000_ooool2o`0000Oooooo0_l000000ooooooo0000o`00000Eo`0000kooooo1?l00007
ooooo`Co00001?ooool2o`0000Cooooo0_l00003ooooo`;o0000Loooool001cooooo00?o0000oooo
ooooool0A?ooool4o`0000gooooo0_l00003ooooo`?o000000?oooooo`000?l000000_ooool2o`00
00;ooooo1?l00002ooooo`_o00000_ooool2o`0000Gooooo0ol00009oooooako00003?ooool4o`00
0003ooooool0003o000000;ooooo1?l0000<ooooo`;o00004Oooool2o`0006Gooooo000Looooo`03
o`000?oooooooooo04Cooooo0_l00005ooooo`;o00003Oooool3o`0000[ooooo0ol00002ooooo`;o
00001?ooool5o`00017ooooo0_l00002oooooako00000oooool2o`0000?ooooo0_l00003ooooo`;o
00000_ooool2o`0000;ooooo0_l0000Qooooo`;o00001oooool2o`0005cooooo000Looooo`03o`00
0?oooooooooo04Kooooo0_l00003ooooo`;o00001Oooool2o`0000Sooooo0_l00005ooooo`;o0000
8oooool2o`0000;ooooo7_l00003ooooo`;o00000oooool3o`0001gooooo0_l00006ooooo`;o0000
1?ooool2o`0000Wooooo0_l000000ooooooo0000o`000007ooooo`Co0000C_ooool001cooooo00?o
0000ooooooooool0A_ooool2o`0000[ooooo0_l00008ooooo`;o00000_ooool5o`0000Gooooo1Ol0
0009ooooo`;o00004_ooool2o`000003ooooool0003o000001So00002Oooool3o`0001gooooo0_l0
0006ooooo`;o00000oooool3o`0000Gooooo0_l00005ooooo`;o00001oooool4o`0004kooooo000L
ooooo`03o`000?oooooooooo04_ooooo0_l00002ooooo`;o00003oooool3o`0000Oooooo1Ol00009
ooooo`;o00001?ooool2o`0000_ooooo0_l00002oooooaOo00000oooool4o`0000;ooooo0ol00004
ooooo`;o00005_ooool2o`0000Sooooo0_l00005ooooo`;o00001_ooool4o`0000Sooooo0_l00002
ooooo`;o0000D?ooool001cooooo00?o0000ooooooooool0@_ooool2o`0000Oooooo0_l00002oooo
o`;o000000?oooooo`000?l000000_ooool2o`0001;ooooo1?l00005ooooo`?o00001_ooool4o`00
00Cooooo0_l00005ooooo`;o00000_oooolNo`000003ooooool0003o000000Go000000?oooooo`00
0?l000000_ooool2o`0001;ooooo0_l00008ooooo`;o00001Oooool2o`0000?ooooo0_l00002oooo
o`?o00002?ooool2o`0001[ooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`12ooooo`;o
00002Oooool2o`0000?ooooo0_l00002ooooo`Co00004?ooool4o`0000Gooooo0ol00004ooooo`Co
00000oooool2o`000003ooooool0003o000000Wooooo2?l000000ooooooo0000o`00000@o`0000Co
oooo0ol000001?oooooo0000o`000?l00005ooooo`;o00005_ooool2o`0000Gooooo0_l00009oooo
o`;o00000_ooool2o`0000;ooooo0_l0000Qooooo`;o0000>?ooool001cooooo0_l0001>ooooo`?o
00000_ooool2o`0000Cooooo0_l0000@ooooo`;o00003_ooool2o`0000Gooooo0_l0000<ooooo`;o
000000?oooooo`000?l000002ol000000ooooooo0000o`000008o`0000Cooooo0ol0000:ooooo`;o
00005Oooool2o`000005ooooool0003o0000o`000?ooool00_l00002ooooo`;o00003Oooool2o`00
05_ooooo000Looooo`03o`000?oooooooooo04kooooo0_l00002ooooo`;o00005_ooool2o`0000Go
oooo0ol0000Kooooo`;o000000?oooooo`000?l000005ol00003ooooo`;o00002oooool2o`0000?o
oooo0_l0000@ooooo`;o000000Goooooo`000?l0003o0000ooooo`06o`0006[ooooo000Looooo`03
o`000?oooooooooo03oooooo0_l00004ooooo`;o00005oooool2o`00017ooooo0ol00007ooooo`;o
00001?ooool2o`0000gooooo7?l00008ooooo`;o00002_ooool2o`0000Cooooo0_l0000:ooooo`;o
00000_ooool:o`0000;ooooo0_l00002ooooo`;o00001?ooool3o`0000oooooo0_l00019ooooo`00
7?ooool00ol0003oooooooooo`0oooooo`;o00001?ooool2o`0001Cooooo0_l000000ooooooo0000
o`000008ooooo`;o00004Oooool2o`0000Cooooo0_l0000=oooooaco00001?ooool6o`00013ooooo
0_l0000:ooooo`;o00000_ooool:o`0000;ooooo0_l00002ooooo`;o00001?ooool3o`0000oooooo
0_l00019ooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00001?ooool2o`0000Kooooo0_l0
000;ooooo`;o00007Oooool2o`0000Kooooo7_l000000ooooooo0000o`000004o`0001kooooo0_l0
0002ooooo`_o00004oooool2o`0005?ooooo000Looooo`03o`000?oooooooooo04gooooo0_l00000
1?oooooo0000o`000?ooool4o`0001;ooooo0_l00006ooooo`;o00005?ooool2o`0000Kooooo0_l0
0002oooooaOo000000Coooooo`000?l0003ooooo0_l0000Vooooo`go00004Oooool2o`0005?ooooo
000Looooo`03o`000?oooooooooo053ooooo0_l00003ooooo`;o000000?oooooo`000?l000003ooo
ool2o`0000Kooooo0ol0000Oooooo`;o000000?oooooo`000?l000004ol00003ooooo`?o00009Ooo
ool5o`000003ooooool0003o000000Go00004Oooool2o`0005?ooooo000Looooo`03o`000?oooooo
oooo04_ooooo0_l00003ooooo`;o00001_ooool2o`0000?ooooo0_l00004ooooo`;o000000?ooooo
o`000?l000000ol00007ooooo`;o00008_oooolEo`0000Cooooo0_l0000Uooooo`go00004Oooool2
o`0005?ooooo000Looooo`03o`000?oooooooooo04Gooooo0ol00003ooooo`;o000000?oooooo`00
0?l000001?ooool2o`0000Oooooo0_l00004ooooo`;o000000?oooooo`000?l000000ol00004oooo
o`Co00008oooool:o`000003ooooool0003o000000Oo00001?ooool2o`0000;ooooo0_l00002oooo
o`;o00007_ooool<o`0006Oooooo000Looooo`03o`000?oooooooooo047ooooo0_l00002ooooo`?o
00000oooool2o`000003ooooool0003o000000;o00000_ooool3o`000003ooooool0003o000000;o
00003oooool2o`0000;ooooo1?l00009ooooo`;o00004_ooool2o`0000Kooooo2Ol000000ooooooo
0000o`000002o`000003ooooool0003o000000Gooooo0_l00002ooooo`;o00000_ooool2o`0000go
oooo0_l0000?ooooo`ko0000IOooool001cooooo00?o0000ooooooooool0@Oooool2o`0000?ooooo
0_l00008ooooo`?o00000_ooool2o`000003ooooool0003o000000;o00003oooool2o`0000oooooo
0ol00002ooooo`;o00003Oooool2o`0000Kooooo3_l00006ooooo`;o00003_ooool2o`0000Oooooo
0_l0000Aooooo`ko0000Hoooool001cooooo00?o0000ooooooooool0A_ooool2o`0000Wooooo0_l0
0005ooooo`;o00001Oooool2o`000003ooooool0003o000001Oooooo1?l00002ooooo`;o00004?oo
ool2o`0000?ooooo1?l000000ooooooo0000o`000007o`0000Kooooo0_l0000>ooooo`;o00001Ooo
ool4o`0000;ooooo0_l0000<ooooo`co000000?oooooo`000?l000002?ooool2o`0005Wooooo000L
ooooo`03o`000?oooooooooo04gooooo0_l0000@ooooo`;o000000?oooooo`000?l000002oooool2
o`0000[ooooo0_l0000<ooooo`;o00002?ooool2o`0000Kooooo0_l00006ooooo`;o00007_ooool8
o`0000[ooooo3_l0000;ooooo`;o00003_ooool2o`0004Wooooo000Looooo`03o`000?oooooooooo
04gooooo0_l00007ooooo`Co00004Oooool2o`0000;ooooo0_l0000Hooooo`;o00003_ooool4o`00
00;ooooo0_l00002ooooo`;o00008_ooool2o`0000Kooooo0_l00004ooooo`;o00000_ooool:o`00
01_ooooo0_l00019ooooo`007?ooool00ol0003oooooooooo`1Fooooo`Co00003oooool4o`0000go
oooo0_l0000Eooooo`?o00001Oooool3o`0000?ooooo0_l00002ooooo`Ko00005_ooool2o`0000Oo
oooo0_l00005ooooo`;o00002Oooool9o`0001Wooooo0_l0001;ooooo`007?ooool00ol0003ooooo
ooooo`1Cooooo`;o00000_ooool4o`0000Cooooo0_l00008ooooo`Co00003Oooool2o`0001Gooooo
0ol0000?ooooo`Ko00000_ooool2o`0001;ooooo0_l000000ooooooo0000o`000004ooooo`;o0000
4?ooool2o`000003ooooool0003o000000;o00006oooool2o`0000Cooooo0_l00015ooooo`007?oo
ool2o`0005Cooooo0_l00002ooooo`Co00000oooool3o`0000Gooooo0_l00003ooooo`;o00005_oo
ool3o`0000Wooooo0_l0000@ooooo`;o00000_ooool2o`0000Cooooo0_l0000Eooooo`;o00001Ooo
ool2o`0000?ooooo0_l00003ooooo`;o00001Oooool5o`0002?ooooo0_l00015ooooo`007?ooool0
0ol0003oooooooooo`1Cooooo`;o00002Oooool2o`000003ooooool0003o000000?ooooo0_l0000D
ooooo`;o000000?oooooo`000?l000000_ooool3o`000003ooooool0003o000000;o000000Cooooo
o`000?l0003ooooo0_l00004ooooo`;o00002_ooool2o`00013ooooo1?l00008ooooo`;o00001Ooo
ool2o`000003ooooool0003o000000?ooooo0_l00003ooooo`;o00001Oooool5o`0006[ooooo000L
ooooo`03o`000?oooooooooo04cooooo0_l00002ooooo`;o00003oooool2o`0000;ooooo0_l0000E
ooooo`Go00000oooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000001_ooool3
o`0001cooooo1?l00008ooooo`Co00000oooool2o`0001Oooooo0_l0001Xooooo`007?ooool00ol0
003oooooooooo`1<ooooo`;o000000Coooooo`000?l0003o00004Oooool8o`0001;ooooo0_l00005
ooooo`;o00001?ooool2o`0000;ooooo0_l00004ooooo`;o00009?ooool2o`0000;ooooo0_l00000
0ooooooo0000o`00000Looooo`;o0000J?ooool001cooooo00?o0000ooooooooool0Coooool2o`00
00Wooooo0_l00004ooooo`;o000000?oooooo`000?l000000_ooool4o`0000?ooooo0_l0000;oooo
o`;o00002Oooool2o`0000;ooooo0_l00002ooooo`;o00005_ooool2o`0000Cooooo0_l0000<oooo
o`;o00000_ooool4o`0003Cooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`19ooooo`;o
00001Oooool2o`0000Sooooo0_l00004ooooo`;o00003?ooool2o`000003ooooool0003o000000So
oooo0ol00002ooooo`?o00000oooool2o`0001kooooo0_l00004ooooo`;o00001oooool2o`0000Wo
oooo0_l0000Hooooo`;o00006_ooool2o`00057ooooo000Looooo`03o`000?oooooooooo04Wooooo
0_l00005ooooo`;o00002?ooool2o`0000Sooooo0_l00008ooooo`Go00001Oooool2o`0000;ooooo
0_l00002ooooo`?o00002?ooool2o`0000kooooo0_l00002ooooo`;o00004?ooool2o`0000;ooooo
0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l0000Hooooo`;o0000KOooool001cooooo
00?o0000ooooooooool0I?ooool2o`0000Sooooo0ol00002ooooo`;o000000?oooooo`000?l00000
0_l00009ooooo`;o00001_ooool2o`0000?ooooo0_l00003ooooo`;o00000_ooool4o`0000;ooooo
1?l0000>ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o00006oooool2o`0001[o
oooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o00000oooool2o`0000kooooo
0_l000000ooooooo0000o`000005ooooo`?o00000_ooool4o`0000Cooooo0_l00004ooooo`;o0000
00?oooooo`000?l000000_l00002ooooo`;o000000?oooooo`000?l000000oooool2o`0002oooooo
1?l00002ooooo`?o00006Oooool2o`0005?ooooo000Looooo`03o`000?oooooooooo053ooooo0_l0
000<ooooo`;o00000oooool2o`000003ooooool0003o000000_ooooo0_l00004ooooo`;o00000_oo
ool4o`000003ooooool0003o000000?o00000oooool2o`0000Oooooo0_l00005ooooo`Co00007_oo
ool2o`0001Cooooo1?l00003ooooo`;o00000oooool2o`0006Wooooo000Looooo`03o`000?oooooo
oooo053ooooo0_l0000Dooooo`;o00003Oooool2o`0000;ooooo0_l00004ooooo`;o00001?ooool2
o`000003ooooool0003o000000_ooooo0_l00003ooooo`?o00002?ooool2o`0001Gooooo0_l0000I
ooooo`;o000000?oooooo`000?l000000_ooool2o`0006Wooooo000Looooo`03o`000?oooooooooo
07Gooooo0_l0000Aooooo`Co00002Oooool2o`0000Cooooo0_l00005ooooo`;o000000?oooooo`00
0?l000006Oooool2o`0000Oooooo0_l0000<ooooo`;o000000?oooooo`000?l000005oooool2o`00
05Cooooo000Looooo`03o`000?oooooooooo06?ooooo0_l00009ooooo`?o00005Oooool2o`0000;o
oooo1?l0000Dooooo`;o00007?ooool2o`0000Oooooo0_l0000:ooooo`?o00001_ooool2o`0001?o
oooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`1Sooooo`;o00002Oooool4o`0000Gooooo
0_l00004ooooo`;o00001oooool2o`0000Cooooo1?l0000Looooo`;o00006Oooool2o`000004oooo
ool0003o0000o`0000Sooooo0ol000000ooooooo0000o`000003ooooo`;o0000JOooool001cooooo
00?o0000ooooooooool0L?ooool2o`0000Gooooo0_l000001?oooooo0000o`000?ooool2o`0000Oo
oooo0_l00006ooooo`?o000000Coooooo`000?l0003o00001_ooool4o`0000;ooooo0_l00009oooo
o`;o00001oooool2o`0000;ooooo0_l0000;ooooo`?o000000Coooooo`000?l0003o00003?ooool2
o`00017ooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`1gooooo`;o000000?oooooo`00
0?l000000_l0000Aooooo`;o000000Coooooo`000?l0003o00001?ooool6o`0000;ooooo0_l0000B
ooooo`;o000000Coooooo`000?l0003o00002oooool2o`00013ooooo0_l0000Booooo`?o0000F_oo
ool001cooooo0_l0001=ooooo`;o00007_ooool5o`0000_ooooo0_l00004ooooo`;o00005Oooool2
o`0000Kooooo0_l0000Eooooo`;o00002oooool2o`0000Oooooo0_l00008ooooo`;o00004_ooool3
o`0005[ooooo000Looooo`03o`000?oooooooooo04cooooo0_l0000Nooooo`Go00004?ooool3o`00
00;ooooo0_l00008ooooo`;o00003oooool2o`0000;ooooo0_l00008ooooo`;o00004_ooool4o`00
00Oooooo0_l00009ooooo`;o00002oooool2o`0000Cooooo0_l0001Kooooo`007?ooool00ol0003o
ooooooooo`1=ooooo`;o00006Oooool4o`0000Cooooo0_l000000ooooooo0000o`00000<ooooo`;o
00000oooool2o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000003?ooool2o`0000;o
oooo0_l00002ooooo`;o00001?ooool2o`0000;ooooo0_l0000;ooooo`Go00000oooool2o`0000go
oooo1?l0000;ooooo`;o0000HOooool001cooooo00?o0000ooooooooool0COooool2o`0000Kooooo
0_l0000Aooooo`Co00001?ooool5o`000003ooooool0003o000000Oooooo0_l0000:ooooo`;o0000
1_ooool2o`0001Cooooo0_l00002ooooo`?o000000?oooooo`000?l000000_l0000;ooooo`Go0000
0oooool2o`0000gooooo0_l0001`ooooo`007?ooool00ol0003oooooooooo`1Eooooo`;o00006?oo
ool4o`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l000001Oooool2o`0000?ooooo1?l0
0007ooooo`;o00005Oooool3o`000004ooooool0003o0000o`0001;ooooo0_l000000ooooooo0000
o`000008ooooo`;o0000M?ooool001cooooo00?o0000ooooooooool0Coooool2o`0001kooooo1?l0
0003ooooo`Co00000_ooool2o`0000Sooooo0_l00005ooooo`Co00001Oooool2o`0000gooooo0_l0
000Looooo`;o000000?oooooo`000?l000001Ol00006ooooo`;o0000M?ooool001cooooo00?o0000
ooooooooool0Coooool2o`0001kooooo1Ol00002ooooo`Co00002Oooool2o`000005ooooool0003o
0000o`000?ooool00_l00003ooooo`Co00001?ooool4o`0000Oooooo1Ol00003ooooo`;o00002Ooo
ool2o`0000cooooo0_l00003ooooo`;o000000?oooooo`000?l00000O?ooool001cooooo00?o0000
ooooooooool0G?ooool2o`00017ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00000_oo
ool2o`0000Oooooo0_l000000ooooooo0000o`000004o`0000Cooooo1Ol00002ooooo`Co000000?o
ooooo`000?l000000oooool6o`0000?ooooo0_l00007ooooo`Co00001Oooool2o`0000Wooooo0_l0
000Hooooo`;o0000I_ooool001cooooo00?o0000ooooooooool0G?ooool2o`0001;ooooo0_l00000
1?oooooo0000o`000?ooool2o`0000;ooooo0_l00008ooooo`[o00001?ooool3o`0000Oooooo1?l0
00000ooooooo0000o`00000@ooooo`;o00000_ooool2o`0000?ooooo0_l00009ooooo`;o00006?oo
ool2o`0006Kooooo000Looooo`03o`000?oooooooooo073ooooo1?l0000;ooooo`;o00000_ooool;
o`0000Cooooo1ol00003ooooo`Co00003?ooool2o`0000Gooooo1_l00005ooooo`?o00000oooool2
o`0008?ooooo000Looooo`03o`000?oooooooooo07;ooooo0_l0000;ooooo`;o00000_ooool5o`00
00?ooooo0_l00005ooooo`So00002?ooool2o`0000Gooooo1Ol000000ooooooo0000o`000002oooo
o`Co00001oooool3o`0000?ooooo0_l00005ooooo`Oo00000oooool2o`0007;ooooo000Looooo`03
o`000?oooooooooo063ooooo0_l0000Looooo`;o00001oooool2o`0000;ooooo0_l00005ooooo`;o
00001?ooool2o`0000Sooooo0_l00005ooooo`Co00000_ooool2o`0001[ooooo1ol00003ooooo`;o
0000L_ooool001cooooo00?o0000ooooooooool0H?ooool4o`0001[ooooo0_l000000ooooooo0000
o`000004ooooo`;o00000_ooool2o`0001?ooooo0_l00002ooooo`Ko000000?oooooo`000?l00000
0ol00002ooooo`;o00002?ooool2o`0000gooooo0_l0001looooo`007?ooool00ol0003ooooooooo
o`1Rooooo`;o00007Oooool4o`0000Kooooo0_l00002ooooo`Co00000_ooool2o`0000Oooooo1?l0
0002ooooo`Ko00000oooool3o`0000;ooooo0_l00008ooooo`?o00003?ooool2o`0007cooooo0000
1_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<
c<`01_ooool00ol0003oooooooooo`23ooooo`;o00001Oooool3o`0000;ooooo1?l00002ooooo`;o
00001oooool2o`0001gooooo0_l00007ooooo`Go0000O_ooool00006oooooomgMgOoV9RHoooooonH
V9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooo
oooo06;ooooo0_l0000Aooooo`;o00001oooool2o`0000[ooooo0_l00002ooooo`Go0000<oooool5
o`0000;ooooo0ol0001iooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`1Rooooo`;o00004Oooool2
o`0000Oooooo0_l0000>ooooo`Go00004Oooool2o`0001kooooo0_l00007ooooo`?o00001oooool2
o`00073ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRH
V?ooooooV9RHoc8b<P06ooooo`?o0000N?ooool2o`0000Kooooo0_l0000<ooooo`;o00002_ooool2
o`0000Sooooo0_l00009ooooo`;o00004oooool2o`00017ooooo0_l0001`ooooo`0000?oooooo`00
0?ooool00_ooool00ol0003oooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool0
0ol0003oooooooooo`1hooooo`;o00001_ooool2o`000003ooooool0003o000000;o00001_ooool2
o`0000?ooooo0_l00006ooooo`;o00002_ooool3o`000003ooooool0003o000000?ooooo0_l00000
0ooooooo0000o`00002Eooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09oooo
o`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`23ooooo`Co00001_ooool2
o`0000;ooooo0ol00003ooooo`;o00000oooool2o`0000Gooooo0_l000001Ooooooo0000o`000?l0
003ooooo00;o00001_ooool2o`0009Gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo
00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo097ooooo0_l00004ooooo`;o
00000oooool2o`0000Gooooo1?l000000ooooooo0000o`00000Booooo`Go00001oooool2o`0007oo
oooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06
ooooo`03o`000?oooooooooo097ooooo0_l0000:ooooo`;o00001_ooool2o`000003ooooool0003o
000000?ooooo0_l0000=ooooo`Go00001oooool2o`0007oooooo000Looooo`03o`000?oooooooooo
097ooooo0_l00008ooooo`Co00002Oooool2o`0000?ooooo0_l0000?ooooo`;o00002?ooool2o`00
07oooooo000Looooo`03o`000?oooooooooo08Cooooo0_l0000:ooooo`Co00001oooool2o`000004
ooooool0003o0000ooooo`;o00001Oooool2o`0000Cooooo0_l00002ooooo`;o0000UOooool001co
oooo00?o0000ooooooooool0Koooool2o`0001?ooooo0_l0000:ooooo`Co00002?ooool7o`0000Go
oooo0_l00004ooooo`?o000000?oooooo`000?l000001oooool2o`00017ooooo0_l0001iooooo`00
7?ooool00ol0003oooooooooo`1_ooooo`;o0000:oooool2o`000003ooooool0003o000000;o0000
00?oooooo`000?l000001_ooool2o`000003ooooool0003o000000?ooooo0_l00005ooooo`;o0000
4Oooool2o`0007Wooooo000Looooo`03o`000?oooooooooo07;ooooo0_l0000Iooooo`;o00004_oo
ool2o`000003ooooool0003o000000Kooooo0_l00003ooooo`;o000000?oooooo`000?l000002Ooo
ool2o`0008Sooooo000Looooo`03o`000?oooooooooo07;ooooo0_l0000Iooooo`;o00004?ooool4
o`0000?ooooo0_l00009ooooo`Co00002Oooool3o`0000Gooooo0_l00021ooooo`007?ooool00ol0
003oooooooooo`1gooooo`;o00001_ooool2o`0001;ooooo0_l0000:ooooo`;o00001Oooool2o`00
00Kooooo0_l00003ooooo`;o00002Oooool4o`0000Cooooo0_l00021ooooo`007?ooool00ol0003o
ooooooooo`1gooooo`;o00001_ooool2o`0001;ooooo0_l0000>ooooo`;o00002Oooool2o`0000Co
oooo0_l00009ooooo`?o00001Oooool2o`0000[ooooo0_l0001dooooo`007?ooool00ol0003ooooo
ooooo`23ooooo`;o00003oooool2o`0000Kooooo0_l00005ooooo`;o00003oooool2o`0000Cooooo
0_l00003ooooo`;o00001_ooool2o`0000[ooooo0_l0001dooooo`007?ooool00ol0003ooooooooo
o`23ooooo`;o00002oooool2o`0000;ooooo0_l00006ooooo`;o00000_ooool2o`000003ooooool0
003o000001Gooooo0_l0002=ooooo`007?ooool00ol0003oooooooooo`2@ooooo`;o00003_ooool2
o`0000oooooo0_l0002Fooooo`007?ooool2o`000:7ooooo0_l0000=ooooo`Co00002_ooool2o`00
08[ooooo000Looooo`03o`000?oooooooooo08;ooooo0_l00007ooooo`;o00008_ooool2o`0000co
oooo0_l0002:ooooo`007?ooool00ol0003oooooooooo`22ooooo`;o00001oooool2o`0000?ooooo
0_l0000Eooooo`;o0000X?ooool001cooooo00?o0000ooooooooool0L_ooool2o`0001cooooo0_l0
000Eooooo`;o0000X?ooool001cooooo00?o0000ooooooooool0L_ooool2o`000=Gooooo000Loooo
o`03o`000?oooooooooo0:?ooooo0ol0002Sooooo`007?ooool00ol0003oooooooooo`2Sooooo`?o
00003?ooool2o`0009Gooooo000Looooo`03o`000?oooooooooo0:[ooooo0_l00006ooooo`;o0000
UOooool001cooooo00?o0000ooooooooool0POooool2o`0002Oooooo0_l000001?oooooo0000o`00
0?l0002Iooooo`007?ooool00ol0003oooooooooo`21ooooo`;o00006oooool2o`0000gooooo0ol0
002Iooooo`007?ooool00ol0003oooooooooo`2Nooooo`;o0000ZOooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000R_ooool2o`000;kooooo000Looooo`03
o`000?oooooooooo08Wooooo0_l0002nooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`2Cooooo`;o0000]?ooool001cooooo00?o0000oooooooo
ool0Toooool2o`000;Cooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Booooo`Co000000?o410@ooooooooool00oooool00ol0
003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`?o0000oooooom:ooooo`005?oo
ool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool0
01Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;o
oooo000Booooo`03oeEEEOmVIVKo00000?ooooooE?ooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00:Gooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0Eoooo
o`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01Oooool00ol0003ok^k^ooooo`03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h0T?ooool00:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00002Ooo
ool01OlQ8B7oV9RHoooooonHV9So8B4Q00Gooooo00?oEEEEojVYZOooool00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg093ooooo002Vooooo`05o`000?ooooooooooooooool000006?ooool01Ol0003o
oooooooooooooooo000000Gooooo00?oZJVYoeEEEOooool00oooool01Ol@413ooooooooooooooooo
410@093ooooo002Vooooo`05o`000?ooooooooooooooool000002Oooool6o`0000Wooooo00Go<S8b
oiRHV?ooooooV9RHoc8b<P06ooooo`03ob4Q8Ooooooooooo00;ooooo00Go0000oooooooooooooooo
o`00002@ooooo`00Y_ooool01Ol0003oQhN7oooooonYZJWo000001Sooooo00Goc<c<o`000?l0003o
0000olc<c006ooooo`03oeEEEOo<c<cooooo00;ooooo00Go0000ooooooooooooooooo`00002@oooo
o`00YOooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo01Kooooo00Go410@okZj^_oo
oooo^[Zjoa0@4006ooooo`03ojVYZOmgMgOooooo00;ooooo00Go410@oooooooooooooooooa0@402@
ooooo`00`oooool01Ol0003o^[Zjoooooonj^[[o000000?ooooo00Go410@oooooooooooooooooc8b
<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0T?ooool00<?ooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@03ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^093ooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(876) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.34516 .53312 Mdot
.3485 .56325 Mdot
.65717 .60845 Mdot
.42461 .42176 Mdot
.3952 .4986 Mdot
.64778 .58361 Mdot
.47807 .63052 Mdot
.43997 .63458 Mdot
.66085 .57097 Mdot
.46753 .28414 Mdot
.45535 .65806 Mdot
.49621 .33488 Mdot
.48153 .65225 Mdot
.44248 .40873 Mdot
.8263 .38985 Mdot
.47467 .44363 Mdot
.32386 .59316 Mdot
.65808 .44849 Mdot
.44665 .32163 Mdot
.61362 .57366 Mdot
.30443 .5202 Mdot
.4471 .41263 Mdot
.33475 .53178 Mdot
.4431 .40804 Mdot
.41189 .39967 Mdot
.326 .5537 Mdot
.3275 .60171 Mdot
.40643 .37303 Mdot
.42654 .37523 Mdot
.45318 .67026 Mdot
.62248 .40178 Mdot
.73151 .27248 Mdot
.507 .40254 Mdot
.17526 .50069 Mdot
.44385 .62684 Mdot
.48267 .21324 Mdot
.65292 .54275 Mdot
.48287 .67131 Mdot
.44109 .63555 Mdot
.45426 .61099 Mdot
.47938 .66919 Mdot
.32663 .56071 Mdot
.42611 .63223 Mdot
.42358 .66238 Mdot
.45206 .43917 Mdot
.39708 .71806 Mdot
.60747 .25446 Mdot
.45251 .35595 Mdot
.36154 .5656 Mdot
.61365 .55887 Mdot
.2181 .58689 Mdot
.43377 .62997 Mdot
.65166 .71347 Mdot
.60634 .11481 Mdot
.49069 .6556 Mdot
.43765 .43932 Mdot
.64667 .55769 Mdot
.46642 .3984 Mdot
.44984 .40245 Mdot
.2634 .51618 Mdot
.41606 .36436 Mdot
.69707 .43511 Mdot
.32017 .51913 Mdot
.67091 .53141 Mdot
.65202 .57791 Mdot
.44468 .65206 Mdot
.327 .59045 Mdot
.47771 .64438 Mdot
.39277 .38041 Mdot
.64645 .53519 Mdot
.45369 .35605 Mdot
.45924 .66724 Mdot
.35946 .52465 Mdot
.48116 .36688 Mdot
.43185 .77169 Mdot
.83892 .48002 Mdot
.67246 .47748 Mdot
.28449 .48814 Mdot
.36334 .46773 Mdot
.79867 .58978 Mdot
.43465 .38782 Mdot
.6914 .7749 Mdot
.82992 .41067 Mdot
.34368 .53519 Mdot
.38293 .34574 Mdot
.64524 .63251 Mdot
.48953 .38669 Mdot
.51269 .50345 Mdot
.40244 .42826 Mdot
.36915 .76069 Mdot
.66181 .56538 Mdot
.32804 .57889 Mdot
.42574 .42112 Mdot
.4488 .34175 Mdot
.26595 .41493 Mdot
.43017 .33478 Mdot
.4038 .40192 Mdot
.37457 .57679 Mdot
.44932 .64118 Mdot
.51814 .39289 Mdot
.46973 .69912 Mdot
.65716 .6824 Mdot
.46355 .42623 Mdot
.66937 .55009 Mdot
.37624 .56469 Mdot
.48723 .4048 Mdot
.4811 .62317 Mdot
.43594 .3627 Mdot
.42163 .63558 Mdot
.35246 .56609 Mdot
.45379 .34092 Mdot
.66294 .4307 Mdot
.49016 .8138 Mdot
.32101 .57936 Mdot
.63446 .75247 Mdot
.43534 .35505 Mdot
.45573 .41421 Mdot
.34549 .5639 Mdot
.63023 .58585 Mdot
.5637 .4642 Mdot
.35974 .57925 Mdot
.45443 .6144 Mdot
.29511 .5838 Mdot
.37847 .39746 Mdot
.66426 .5821 Mdot
.66442 .69106 Mdot
.66825 .70968 Mdot
.57731 .36052 Mdot
.48839 .39592 Mdot
.32507 .64651 Mdot
.64176 .58757 Mdot
.33054 .57428 Mdot
.47577 .64741 Mdot
.44471 .44805 Mdot
.30077 .56813 Mdot
.46102 .65138 Mdot
.68561 .41875 Mdot
.73483 .45804 Mdot
.36537 .56713 Mdot
.52155 .60626 Mdot
.46675 .60393 Mdot
.46006 .61038 Mdot
.18642 .53492 Mdot
.34994 .55856 Mdot
.67773 .45731 Mdot
.46395 .64549 Mdot
.66726 .33449 Mdot
.42288 .43698 Mdot
.55217 .35289 Mdot
.55971 .85054 Mdot
.21268 .5902 Mdot
.54728 .75453 Mdot
.67509 .46702 Mdot
.47141 .61242 Mdot
.4192 .38951 Mdot
.34692 .55097 Mdot
.33799 .55427 Mdot
.39809 .38298 Mdot
.40941 .40463 Mdot
.46334 .35471 Mdot
.44274 .34443 Mdot
.6593 .27821 Mdot
.45698 .34771 Mdot
.65535 .49227 Mdot
.31248 .57228 Mdot
.41139 .38206 Mdot
.62644 .58831 Mdot
.49508 .41278 Mdot
.46997 .67113 Mdot
.45652 .40644 Mdot
.41707 .4186 Mdot
.47196 .33968 Mdot
.49404 .65683 Mdot
.69084 .25331 Mdot
.53964 .84605 Mdot
.51012 .17914 Mdot
.59073 .75697 Mdot
.63393 .5638 Mdot
.47761 .40783 Mdot
.685 .44743 Mdot
.36569 .29708 Mdot
.44339 .39069 Mdot
.23317 .68914 Mdot
.41147 .416 Mdot
.20931 .40064 Mdot
.42765 .48347 Mdot
.50956 .17254 Mdot
.59979 .4769 Mdot
.42518 .36909 Mdot
.276 .37007 Mdot
.32363 .27322 Mdot
.42512 .58047 Mdot
.48259 .66596 Mdot
.63035 .59212 Mdot
.65356 .5525 Mdot
.43796 .60789 Mdot
.49636 .43769 Mdot
.52461 .41929 Mdot
.49927 .32354 Mdot
.66183 .69793 Mdot
.355 .52157 Mdot
.71158 .44209 Mdot
.36899 .54423 Mdot
.76612 .72141 Mdot
.33378 .73579 Mdot
.43297 .60302 Mdot
.70552 .46876 Mdot
.65226 .60705 Mdot
.66195 .70138 Mdot
.67855 .44884 Mdot
.45482 .37077 Mdot
.35404 .57394 Mdot
.22522 .35277 Mdot
.40991 .47655 Mdot
.23312 .31859 Mdot
.29468 .56163 Mdot
.55751 .48982 Mdot
.46719 .65856 Mdot
.61838 .59521 Mdot
.44694 .42268 Mdot
.4707 .36843 Mdot
.3469 .50953 Mdot
.45238 .35829 Mdot
.38914 .5077 Mdot
.42084 .4261 Mdot
.60786 .59475 Mdot
.66289 .47321 Mdot
.436 .6109 Mdot
.57382 .36568 Mdot
.33929 .52617 Mdot
.58434 .57385 Mdot
.62027 .55201 Mdot
.38281 .27895 Mdot
.45637 .66382 Mdot
.66723 .42647 Mdot
.61936 .56176 Mdot
.71077 .45464 Mdot
.49714 .38231 Mdot
.65134 .54072 Mdot
.69294 .46228 Mdot
.68769 .27855 Mdot
.45489 .44183 Mdot
.68313 .30856 Mdot
.47276 .62955 Mdot
.29215 .58011 Mdot
.41394 .36694 Mdot
.67327 .70591 Mdot
.49987 .36037 Mdot
.52019 .72762 Mdot
.65779 .71738 Mdot
.64407 .69778 Mdot
.81198 .54413 Mdot
.66221 .44203 Mdot
.50176 .7736 Mdot
.28584 .64176 Mdot
.33002 .59187 Mdot
.43347 .43239 Mdot
.57953 .17709 Mdot
.4643 .64626 Mdot
.45253 .37408 Mdot
.62786 .62254 Mdot
.4657 .6428 Mdot
.47176 .39622 Mdot
.49356 .63825 Mdot
.34361 .55378 Mdot
.71528 .64466 Mdot
.31188 .59178 Mdot
.44767 .44342 Mdot
.48067 .62555 Mdot
.62884 .55245 Mdot
.32694 .55002 Mdot
.4383 .36544 Mdot
.45445 .421 Mdot
.65556 .69359 Mdot
.41751 .37307 Mdot
.59083 .18791 Mdot
.42554 .35417 Mdot
.6737 .58769 Mdot
.42359 .3409 Mdot
.20831 .65209 Mdot
.71621 .50547 Mdot
.33261 .58918 Mdot
.6463 .70289 Mdot
.65605 .56867 Mdot
.77195 .56586 Mdot
.47764 .57401 Mdot
.43363 .3749 Mdot
.6477 .69132 Mdot
.59139 .45264 Mdot
.44986 .67144 Mdot
.42473 .3337 Mdot
.37098 .74385 Mdot
.61732 .57581 Mdot
.65995 .6993 Mdot
.43042 .31808 Mdot
.37691 .56385 Mdot
.42316 .42049 Mdot
.63422 .54427 Mdot
.29631 .5861 Mdot
.48352 .42045 Mdot
.5512 .24665 Mdot
.6626 .71463 Mdot
.47427 .63123 Mdot
.47189 .47158 Mdot
.45787 .35113 Mdot
.64573 .54917 Mdot
.31921 .53455 Mdot
.44876 .6229 Mdot
.31933 .56089 Mdot
.27353 .30369 Mdot
.5824 .76659 Mdot
.62465 .24888 Mdot
.70911 .46687 Mdot
.55975 .69481 Mdot
.48517 .17531 Mdot
.51884 .78823 Mdot
.61949 .33855 Mdot
.35528 .20899 Mdot
.62176 .57493 Mdot
.70276 .482 Mdot
.65105 .56605 Mdot
.42593 .40338 Mdot
.65098 .58159 Mdot
.50868 .16772 Mdot
.41277 .41967 Mdot
.63723 .55894 Mdot
.73938 .593 Mdot
.40633 .39104 Mdot
.31774 .57918 Mdot
.81301 .3801 Mdot
.38986 .79328 Mdot
.2546 .66146 Mdot
.62896 .57214 Mdot
.30105 .50765 Mdot
.40575 .3774 Mdot
.50391 .40255 Mdot
.34444 .54622 Mdot
.41713 .3426 Mdot
.71031 .43904 Mdot
.71446 .45017 Mdot
.56208 .37856 Mdot
.62335 .79709 Mdot
.5205 .3923 Mdot
.33038 .54815 Mdot
.35114 .3985 Mdot
.42692 .76603 Mdot
.66675 .68152 Mdot
.49652 .68145 Mdot
.70462 .26759 Mdot
.5087 .43031 Mdot
.51623 .60524 Mdot
.39402 .75327 Mdot
.34243 .57817 Mdot
.63806 .22843 Mdot
.48663 .65929 Mdot
.31158 .35376 Mdot
.20716 .45844 Mdot
.4651 .36933 Mdot
.45055 .65601 Mdot
.51665 .36365 Mdot
.33498 .75277 Mdot
.69925 .34569 Mdot
.81097 .63232 Mdot
.45221 .44102 Mdot
.4846 .77081 Mdot
.45533 .4112 Mdot
.56472 .42351 Mdot
.4254 .35362 Mdot
.31726 .55609 Mdot
.42872 .28388 Mdot
.47134 .53659 Mdot
.60053 .8222 Mdot
.31879 .72649 Mdot
.68031 .46845 Mdot
.45329 .41935 Mdot
.46675 .37004 Mdot
.66763 .43629 Mdot
.31881 .54252 Mdot
.43221 .35104 Mdot
.54554 .28472 Mdot
.46387 .35877 Mdot
.47691 .67318 Mdot
.60253 .42138 Mdot
.37733 .5088 Mdot
.46039 .33768 Mdot
.32145 .5961 Mdot
.49424 .64914 Mdot
.44268 .65011 Mdot
.38695 .3944 Mdot
.48353 .61987 Mdot
.42384 .42413 Mdot
.68089 .38237 Mdot
.35451 .54205 Mdot
.40081 .47874 Mdot
.31229 .54437 Mdot
.3464 .47986 Mdot
.48613 .62577 Mdot
.67136 .70148 Mdot
.34112 .62217 Mdot
.48645 .65472 Mdot
.24488 .64257 Mdot
.52233 .35198 Mdot
.48742 .33755 Mdot
.3092 .73312 Mdot
.62581 .56807 Mdot
.66781 .70292 Mdot
.47448 .62029 Mdot
.45972 .35159 Mdot
.45365 .3266 Mdot
.48039 .6776 Mdot
.28997 .417 Mdot
.77275 .55198 Mdot
.40317 .38263 Mdot
.317 .55096 Mdot
.32798 .57326 Mdot
.49157 .40751 Mdot
.44002 .37376 Mdot
.66718 .59518 Mdot
.65296 .71011 Mdot
.65427 .67742 Mdot
.66748 .70907 Mdot
.62767 .61168 Mdot
.41145 .69386 Mdot
.45582 .6106 Mdot
.35865 .65835 Mdot
.50122 .72246 Mdot
.40608 .46587 Mdot
.63992 .54898 Mdot
.47195 .37985 Mdot
.4342 .42195 Mdot
.45 .62241 Mdot
.57433 .71913 Mdot
.37936 .3575 Mdot
.36403 .55268 Mdot
.48712 .62358 Mdot
.52719 .38772 Mdot
.39699 .64226 Mdot
.70476 .44886 Mdot
.25408 .66553 Mdot
.4538 .66296 Mdot
.33446 .5833 Mdot
.49247 .67174 Mdot
.46693 .36541 Mdot
.40416 .41628 Mdot
.34459 .56992 Mdot
.66236 .45017 Mdot
.40043 .34411 Mdot
.47273 .39733 Mdot
.32823 .80662 Mdot
.43618 .773 Mdot
.52202 .6567 Mdot
.42197 .38045 Mdot
.46405 .32866 Mdot
.6907 .47051 Mdot
.46282 .36119 Mdot
.45332 .4236 Mdot
.49769 .81925 Mdot
.51372 .68937 Mdot
.65604 .43426 Mdot
.31549 .34969 Mdot
.29487 .5642 Mdot
.63419 .2095 Mdot
.65241 .68047 Mdot
.43574 .65956 Mdot
.70566 .6496 Mdot
.66006 .70561 Mdot
.53126 .71497 Mdot
.63847 .22057 Mdot
.66766 .70742 Mdot
.62318 .63075 Mdot
.4051 .30821 Mdot
.40037 .39063 Mdot
.46119 .40699 Mdot
.68978 .44936 Mdot
.34904 .55675 Mdot
.58011 .48273 Mdot
.7414 .36264 Mdot
.44984 .41379 Mdot
.27889 .54843 Mdot
.71011 .2893 Mdot
.65588 .69761 Mdot
.6962 .42698 Mdot
.70558 .41975 Mdot
.45891 .41309 Mdot
.53123 .81157 Mdot
.3277 .55242 Mdot
.43818 .36594 Mdot
.46496 .34568 Mdot
.62874 .5673 Mdot
.34456 .58161 Mdot
.62317 .54877 Mdot
.66157 .71772 Mdot
.36246 .23481 Mdot
.28951 .77634 Mdot
.45346 .62414 Mdot
.54478 .19488 Mdot
.4439 .663 Mdot
.8208 .58034 Mdot
.66064 .7102 Mdot
.43953 .38807 Mdot
.34327 .52488 Mdot
.43718 .36131 Mdot
.45684 .3786 Mdot
.45635 .37095 Mdot
.52124 .35536 Mdot
.22958 .68257 Mdot
.67976 .43796 Mdot
.38891 .44307 Mdot
.67554 .57602 Mdot
.57229 .19102 Mdot
.8066 .40648 Mdot
.47716 .37817 Mdot
.46266 .41432 Mdot
.30985 .57616 Mdot
.39918 .37518 Mdot
.46066 .67937 Mdot
.32068 .53333 Mdot
.47684 .34222 Mdot
.62574 .2261 Mdot
.43653 .34942 Mdot
.4844 .1826 Mdot
.49062 .67407 Mdot
.24882 .64613 Mdot
.3875 .43637 Mdot
.6697 .70645 Mdot
.66784 .7035 Mdot
.6495 .67183 Mdot
.47996 .68593 Mdot
.64106 .55324 Mdot
.78486 .41386 Mdot
.49207 .43604 Mdot
.41747 .39289 Mdot
.45891 .32635 Mdot
.65975 .61942 Mdot
.51095 .49953 Mdot
.52722 .76632 Mdot
.52725 .38048 Mdot
.66267 .59401 Mdot
.2894 .57615 Mdot
.64267 .73405 Mdot
.32306 .53295 Mdot
.65522 .43723 Mdot
.45887 .6612 Mdot
.70755 .44286 Mdot
.23151 .61679 Mdot
.35072 .56502 Mdot
.35413 .50934 Mdot
.63478 .5615 Mdot
.54535 .51509 Mdot
.56864 .12172 Mdot
.65707 .53375 Mdot
.5747 .32514 Mdot
.33902 .54348 Mdot
.47131 .34461 Mdot
.59883 .43995 Mdot
.53893 .51513 Mdot
.64071 .56715 Mdot
.43677 .39845 Mdot
.59292 .80512 Mdot
.66499 .59767 Mdot
.42723 .33169 Mdot
.64026 .5922 Mdot
.47141 .66874 Mdot
.63946 .58859 Mdot
.32092 .52972 Mdot
.48341 .40821 Mdot
.60036 .1237 Mdot
.58344 .5242 Mdot
.42259 .3604 Mdot
.48753 .62421 Mdot
.51559 .26472 Mdot
.46096 .38522 Mdot
.70919 .43306 Mdot
.66422 .58508 Mdot
.7737 .51563 Mdot
.40852 .37127 Mdot
.6386 .57906 Mdot
.3417 .53085 Mdot
.46411 .69076 Mdot
.81989 .53607 Mdot
.66665 .68905 Mdot
.35051 .54829 Mdot
.65011 .71993 Mdot
.50448 .65062 Mdot
.45215 .32832 Mdot
.4637 .34795 Mdot
.31267 .56339 Mdot
.71459 .68339 Mdot
.41662 .35158 Mdot
.43477 .38807 Mdot
.644 .60854 Mdot
.67293 .60482 Mdot
.72333 .65707 Mdot
.62206 .57145 Mdot
.43453 .3238 Mdot
.31338 .56307 Mdot
.42934 .41778 Mdot
.3201 .58282 Mdot
.4318 .43075 Mdot
.30252 .60624 Mdot
.34538 .53672 Mdot
.60456 .77831 Mdot
.43211 .40904 Mdot
.44629 .47929 Mdot
.45788 .37435 Mdot
.45756 .35733 Mdot
.67273 .57198 Mdot
.67804 .43068 Mdot
.42071 .45144 Mdot
.61964 .51571 Mdot
.69675 .42441 Mdot
.28801 .29965 Mdot
.62766 .57094 Mdot
.69671 .44891 Mdot
.6855 .30167 Mdot
.64471 .69614 Mdot
.68668 .44121 Mdot
.80294 .39501 Mdot
.45218 .62352 Mdot
.29092 .56482 Mdot
.40662 .39198 Mdot
.33528 .22586 Mdot
.65447 .38377 Mdot
.65079 .69301 Mdot
.42482 .35668 Mdot
.46914 .38229 Mdot
.36647 .58165 Mdot
.73771 .74609 Mdot
.66153 .60871 Mdot
.42181 .40437 Mdot
.3138 .58953 Mdot
.59512 .84383 Mdot
.67288 .55862 Mdot
.68751 .44456 Mdot
.48478 .67423 Mdot
.3623 .59922 Mdot
.6663 .68752 Mdot
.45288 .67616 Mdot
.68207 .64828 Mdot
.23483 .63596 Mdot
.43706 .35335 Mdot
.64435 .54527 Mdot
.21142 .60188 Mdot
.50577 .42245 Mdot
.51644 .62684 Mdot
.54485 .37978 Mdot
.339 .57965 Mdot
.48093 .67617 Mdot
.70425 .45756 Mdot
.31857 .53287 Mdot
.32016 .54314 Mdot
.4397 .62758 Mdot
.68224 .61957 Mdot
.55386 .49452 Mdot
.46959 .67419 Mdot
.38116 .76237 Mdot
.24219 .33645 Mdot
.64766 .69966 Mdot
.68433 .42337 Mdot
.18048 .4408 Mdot
.32581 .56067 Mdot
.70179 .26469 Mdot
.22096 .64206 Mdot
.40364 .40116 Mdot
.68908 .45879 Mdot
.45036 .72075 Mdot
.7772 .39781 Mdot
.46701 .63903 Mdot
.46369 .52268 Mdot
.68895 .41354 Mdot
.40537 .37035 Mdot
.2552 .56896 Mdot
.43059 .39926 Mdot
.46207 .66011 Mdot
.36644 .48297 Mdot
.33259 .58401 Mdot
.50345 .64168 Mdot
.25006 .66256 Mdot
.43644 .42378 Mdot
.43379 .40252 Mdot
.60692 .39739 Mdot
.35684 .57166 Mdot
.65828 .67868 Mdot
.43175 .36556 Mdot
.46521 .40074 Mdot
.46224 .33337 Mdot
.50236 .44934 Mdot
.50496 .80762 Mdot
.42324 .40579 Mdot
.60891 .5824 Mdot
.50408 .38622 Mdot
.43479 .40889 Mdot
.32701 .59556 Mdot
.28306 .7639 Mdot
.67095 .71127 Mdot
.45894 .40463 Mdot
.43812 .35101 Mdot
.44381 .62343 Mdot
.57673 .47224 Mdot
.53172 .51991 Mdot
.65874 .53821 Mdot
.63505 .32076 Mdot
.52039 .35434 Mdot
.29837 .56522 Mdot
.67023 .42158 Mdot
.49034 .37467 Mdot
.30287 .57387 Mdot
.48806 .42768 Mdot
.66206 .59779 Mdot
.64972 .70472 Mdot
.27983 .67539 Mdot
.6933 .43939 Mdot
.63428 .41446 Mdot
.35415 .67337 Mdot
.63082 .5944 Mdot
.41449 .39405 Mdot
.43937 .66282 Mdot
.65359 .53898 Mdot
.65524 .69135 Mdot
.39266 .34355 Mdot
.33688 .55167 Mdot
.32404 .57899 Mdot
.57078 .3889 Mdot
.64704 .5114 Mdot
.42772 .83845 Mdot
.46995 .6681 Mdot
.5001 .37646 Mdot
.30038 .64543 Mdot
.32303 .57942 Mdot
.57141 .38299 Mdot
.6978 .44765 Mdot
.4676 .6372 Mdot
.66103 .67351 Mdot
.30518 .57411 Mdot
.36152 .57017 Mdot
.46263 .43789 Mdot
.48253 .38886 Mdot
.6123 .34075 Mdot
.56306 .3767 Mdot
.49115 .66094 Mdot
.67237 .42832 Mdot
.62947 .53939 Mdot
.42629 .39707 Mdot
.34156 .53413 Mdot
.22192 .3706 Mdot
.44618 .34699 Mdot
.66794 .59511 Mdot
.33941 .57724 Mdot
.66577 .43817 Mdot
.70504 .42923 Mdot
.45794 .35786 Mdot
.28169 .50101 Mdot
.48794 .64107 Mdot
.32098 .58043 Mdot
.25779 .60936 Mdot
.4194 .34834 Mdot
.48447 .39242 Mdot
.46898 .31239 Mdot
.4461 .66152 Mdot
.25508 .64728 Mdot
.6595 .43328 Mdot
.33603 .56046 Mdot
.42808 .359 Mdot
.69708 .43586 Mdot
.27055 .6427 Mdot
.65533 .70601 Mdot
.64245 .59132 Mdot
.71075 .43581 Mdot
.66925 .45143 Mdot
.68837 .42046 Mdot
.7171 .27699 Mdot
.35996 .52319 Mdot
.3549 .39581 Mdot
.42113 .35541 Mdot
.57336 .39331 Mdot
.41743 .44183 Mdot
.4805 .68363 Mdot
.6244 .56651 Mdot
.46023 .37679 Mdot
.46343 .43705 Mdot
.52545 .43714 Mdot
.45521 .46994 Mdot
.28789 .53181 Mdot
.35235 .5708 Mdot
.43136 .46687 Mdot
.62823 .56256 Mdot
.73495 .75947 Mdot
.54437 .14165 Mdot
.38438 .41982 Mdot
.56533 .49083 Mdot
.33463 .53255 Mdot
.43883 .62573 Mdot
.51806 .52697 Mdot
.49832 .65658 Mdot
.33416 .56572 Mdot
.42584 .39992 Mdot
.36443 .66136 Mdot
.70388 .46549 Mdot
.46304 .35275 Mdot
.46628 .65416 Mdot
.4631 .35359 Mdot
.46803 .6815 Mdot
.39366 .59944 Mdot
.40005 .76346 Mdot
.41053 .41493 Mdot
.43329 .33739 Mdot
.50088 .4606 Mdot
.47724 .38106 Mdot
.74105 .70268 Mdot
.32403 .537 Mdot
.60893 .79996 Mdot
.47903 .4257 Mdot
.3213 .47029 Mdot
.41865 .35483 Mdot
.69387 .69713 Mdot
.48491 .38316 Mdot
.50504 .54964 Mdot
.40137 .38779 Mdot
.46705 .41742 Mdot
.48393 .62843 Mdot
.44321 .62407 Mdot
.35846 .53918 Mdot
.66217 .68096 Mdot
.5224 .17924 Mdot
.47804 .39575 Mdot
.61502 .59912 Mdot
.52217 .62218 Mdot
.66802 .44286 Mdot
.33136 .56541 Mdot
.59888 .85036 Mdot
.49411 .64145 Mdot
.64612 .52516 Mdot
.71681 .69334 Mdot
.61561 .5867 Mdot
.49658 .69908 Mdot
.48785 .30202 Mdot
.66406 .45117 Mdot
.40881 .36393 Mdot
.18026 .50293 Mdot
.44784 .76416 Mdot
.392 .3521 Mdot
.50148 .64086 Mdot
.36128 .31095 Mdot
.18202 .4432 Mdot
.71323 .42775 Mdot
.69287 .46558 Mdot
.48887 .63573 Mdot
.63348 .60609 Mdot
.50101 .32843 Mdot
.69892 .44775 Mdot
.64354 .60078 Mdot
.64668 .67469 Mdot
.45777 .56402 Mdot
.3284 .55528 Mdot
.25873 .66725 Mdot
.36488 .70509 Mdot
.49288 .65813 Mdot
.5939 .54708 Mdot
.33193 .60688 Mdot
.37802 .55023 Mdot
.66995 .69143 Mdot
.67324 .57157 Mdot
.33653 .52359 Mdot
.41816 .33284 Mdot
.4254 .47912 Mdot
.45334 .41076 Mdot
.68353 .45394 Mdot
.47998 .37545 Mdot
.6717 .58032 Mdot
.46929 .64239 Mdot
.66393 .55528 Mdot
.48149 .62973 Mdot
.3977 .68666 Mdot
.44329 .36769 Mdot
.46836 .41491 Mdot
.64989 .39087 Mdot
.36775 .55074 Mdot
.22618 .59359 Mdot
.61822 .60503 Mdot
.64918 .56053 Mdot
.44075 .42896 Mdot
.33146 .52931 Mdot
.65287 .45899 Mdot
.64999 .39406 Mdot
.47393 .3544 Mdot
.32366 .53669 Mdot
.41995 .39891 Mdot
.67887 .28508 Mdot
.42482 .78641 Mdot
.31877 .56504 Mdot
.63944 .79701 Mdot
.42599 .384 Mdot
.38652 .31738 Mdot
.45687 .32523 Mdot
.56686 .29303 Mdot
.4183 .34818 Mdot
.29449 .56014 Mdot
.45437 .40627 Mdot
.31035 .53891 Mdot
.6337 .6018 Mdot
.44391 .61596 Mdot
.34931 .54489 Mdot
.4739 .35078 Mdot
.70078 .24295 Mdot
.46664 .66287 Mdot
.45135 .41999 Mdot
.45243 .63994 Mdot
.30332 .58264 Mdot
.36371 .56115 Mdot
.80113 .41865 Mdot
.52207 .67295 Mdot
.47367 .66811 Mdot
.41878 .40817 Mdot
.33549 .7039 Mdot
.42738 .41334 Mdot
.60652 .34766 Mdot
.46471 .43125 Mdot
.42126 .34382 Mdot
.84953 .50381 Mdot
.44107 .66038 Mdot
.44041 .83766 Mdot
.73565 .35156 Mdot
.72815 .28568 Mdot
.3783 .58574 Mdot
.71299 .42733 Mdot
.64861 .23361 Mdot
.6591 .71771 Mdot
.65288 .59077 Mdot
.46066 .37553 Mdot
.39325 .54949 Mdot
.48203 .67306 Mdot
.67574 .43373 Mdot
.4118 .4168 Mdot
.67152 .58869 Mdot
.80049 .52286 Mdot
.47602 .61463 Mdot
.32711 .56129 Mdot
.36603 .55326 Mdot
.57612 .84481 Mdot
.42851 .35732 Mdot
.45934 .41828 Mdot
.45913 .65988 Mdot
.4866 .45009 Mdot
.66484 .4319 Mdot
.73218 .57622 Mdot
.47414 .66736 Mdot
.56154 .57588 Mdot
.35423 .5635 Mdot
.47032 .38068 Mdot
.52535 .49015 Mdot
.55664 .62177 Mdot
.31262 .30941 Mdot
.68654 .44923 Mdot
.61611 .35966 Mdot
.29449 .56076 Mdot
.47228 .64873 Mdot
.73771 .44457 Mdot
.50162 .36959 Mdot
.46831 .38739 Mdot
.61641 .36418 Mdot
.58605 .4644 Mdot
.64869 .45949 Mdot
.39619 .39094 Mdot
.58493 .45864 Mdot
.44631 .43014 Mdot
.46937 .33514 Mdot
.3971 .36249 Mdot
.48621 .39737 Mdot
.3272 .53477 Mdot
.531 .42453 Mdot
.64137 .58515 Mdot
.27191 .40559 Mdot
.4778 .5235 Mdot
.41373 .37161 Mdot
.42724 .40492 Mdot
.34284 .29444 Mdot
.52672 .68031 Mdot
.33014 .53835 Mdot
.32212 .52374 Mdot
.47572 .61771 Mdot
.4399 .48164 Mdot
.6485 .61643 Mdot
.54336 .3949 Mdot
.66545 .55833 Mdot
.32018 .53746 Mdot
.64957 .55442 Mdot
.46748 .61458 Mdot
.64468 .54487 Mdot
.62516 .60998 Mdot
.47438 .67911 Mdot
.35764 .5577 Mdot
.47734 .36298 Mdot
.4833 .62171 Mdot
.60757 .39419 Mdot
.68509 .45363 Mdot
.80127 .41763 Mdot
.50245 .39311 Mdot
.45383 .50678 Mdot
.55347 .24762 Mdot
.66163 .55526 Mdot
.44566 .80285 Mdot
.34652 .53743 Mdot
.68461 .47543 Mdot
.32456 .53438 Mdot
.22724 .65805 Mdot
.67617 .42916 Mdot
.80224 .39172 Mdot
.70087 .56963 Mdot
.79129 .49431 Mdot
.39872 .40612 Mdot
.29873 .60777 Mdot
.64077 .53879 Mdot
.48331 .67156 Mdot
.68665 .62204 Mdot
.47239 .41673 Mdot
.52981 .78591 Mdot
.37317 .56286 Mdot
.64594 .68048 Mdot
.47823 .64634 Mdot
.49657 .62995 Mdot
.43782 .35582 Mdot
.75114 .6106 Mdot
.47725 .41764 Mdot
.68511 .50939 Mdot
.6269 .33756 Mdot
.54394 .38734 Mdot
.42625 .42762 Mdot
.66525 .54827 Mdot
.41937 .39951 Mdot
.37264 .3088 Mdot
.18469 .52849 Mdot
.4617 .31636 Mdot
.59602 .76954 Mdot
.68041 .39686 Mdot
.34677 .56659 Mdot
.39105 .44079 Mdot
.65646 .68525 Mdot
.42391 .38177 Mdot
.14574 .42946 Mdot
.68792 .43859 Mdot
.59756 .59528 Mdot
.42633 .3476 Mdot
.43349 .36247 Mdot
.20952 .51849 Mdot
.39448 .56699 Mdot
.66169 .67313 Mdot
.46587 .39223 Mdot
.65088 .33277 Mdot
.44528 .64139 Mdot
.48616 .41044 Mdot
.45988 .40922 Mdot
.31507 .27634 Mdot
.44763 .66075 Mdot
.65874 .55252 Mdot
.65318 .71411 Mdot
.62558 .5416 Mdot
.67944 .41025 Mdot
.52571 .53678 Mdot
.55683 .3588 Mdot
.42438 .78389 Mdot
.70194 .41993 Mdot
.45629 .34265 Mdot
.37947 .35457 Mdot
.42953 .37657 Mdot
.69941 .46329 Mdot
.45189 .66785 Mdot
.33938 .53759 Mdot
.29102 .68078 Mdot
.66036 .69701 Mdot
.42995 .33049 Mdot
.71116 .44842 Mdot
.34375 .55052 Mdot
.58211 .55873 Mdot
.34218 .56271 Mdot
.48227 .65991 Mdot
.49434 .6783 Mdot
.68914 .42843 Mdot
.31962 .536 Mdot
.61302 .55092 Mdot
.74137 .36584 Mdot
.45492 .43527 Mdot
.50659 .63339 Mdot
.34527 .52906 Mdot
.33407 .60024 Mdot
.37312 .55499 Mdot
.44863 .36114 Mdot
.57015 .48095 Mdot
.47418 .33792 Mdot
.49194 .64126 Mdot
.64623 .5964 Mdot
.54488 .34258 Mdot
.20541 .53197 Mdot
.57163 .54843 Mdot
.40591 .43394 Mdot
.44328 .42001 Mdot
.45864 .41321 Mdot
.43342 .44265 Mdot
.71766 .47699 Mdot
.44133 .3717 Mdot
.48246 .62824 Mdot
.66838 .57079 Mdot
.41806 .36145 Mdot
.65396 .68324 Mdot
.54858 .49187 Mdot
.67717 .41747 Mdot
.49927 .53461 Mdot
.6369 .20242 Mdot
.3442 .54907 Mdot
.62206 .5558 Mdot
.6511 .58935 Mdot
.68479 .41873 Mdot
.48488 .66785 Mdot
.34602 .55883 Mdot
.5744 .28696 Mdot
.68099 .42187 Mdot
.45806 .40374 Mdot
.69675 .64243 Mdot
.64383 .7644 Mdot
.40655 .36352 Mdot
.45251 .38562 Mdot
.64639 .70426 Mdot
.63877 .61109 Mdot
.2746 .25541 Mdot
.60377 .44511 Mdot
.68335 .42898 Mdot
.6757 .46317 Mdot
.37363 .54698 Mdot
.37992 .38404 Mdot
.48128 .63238 Mdot
.60775 .42589 Mdot
.52101 .28027 Mdot
.62985 .44179 Mdot
.81803 .57885 Mdot
.45248 .3505 Mdot
.21791 .50816 Mdot
.42888 .42445 Mdot
.37119 .57312 Mdot
.32995 .59063 Mdot
.33119 .54236 Mdot
.49113 .64931 Mdot
.35092 .47159 Mdot
.47753 .62458 Mdot
.59709 .17211 Mdot
.29774 .54611 Mdot
.74649 .47883 Mdot
.64378 .55579 Mdot
.44329 .45758 Mdot
.66389 .43992 Mdot
.4762 .70263 Mdot
.39302 .37709 Mdot
.51893 .80688 Mdot
.64101 .5485 Mdot
.35973 .56302 Mdot
.47722 .29769 Mdot
.44198 .17825 Mdot
.54621 .52248 Mdot
.36762 .42773 Mdot
.23226 .56795 Mdot
.67029 .43267 Mdot
.31048 .31556 Mdot
.66274 .45524 Mdot
.46261 .64731 Mdot
.47766 .41124 Mdot
.48973 .39152 Mdot
.4301 .4309 Mdot
.44301 .37095 Mdot
.45212 .61988 Mdot
.46497 .44198 Mdot
.20836 .65213 Mdot
.6475 .70273 Mdot
.67482 .27281 Mdot
.70294 .44773 Mdot
.4997 .66173 Mdot
.66732 .56637 Mdot
.65468 .6758 Mdot
.56565 .35993 Mdot
.40201 .3889 Mdot
.45856 .37581 Mdot
.67312 .69375 Mdot
.39882 .36419 Mdot
.52655 .3716 Mdot
.64224 .5838 Mdot
.57137 .53768 Mdot
.71316 .43481 Mdot
.70718 .44392 Mdot
.46059 .6733 Mdot
.32148 .53514 Mdot
.69403 .44841 Mdot
.64354 .60935 Mdot
.47473 .43753 Mdot
.47877 .35233 Mdot
.34689 .52948 Mdot
.22105 .64311 Mdot
.71253 .4244 Mdot
.4717 .29521 Mdot
.29808 .55087 Mdot
.37057 .52789 Mdot
.46549 .38896 Mdot
.46386 .31384 Mdot
.31956 .60226 Mdot
.70474 .42605 Mdot
.50084 .65851 Mdot
.77729 .45877 Mdot
.46175 .65437 Mdot
.34669 .55506 Mdot
.48983 .41295 Mdot
.35654 .56018 Mdot
.4224 .37521 Mdot
.89233 .50949 Mdot
.48831 .38634 Mdot
.36845 .78164 Mdot
.57694 .30837 Mdot
.65378 .58709 Mdot
.61298 .55172 Mdot
.64872 .68767 Mdot
.29645 .55295 Mdot
.49197 .37667 Mdot
.67134 .46204 Mdot
.75351 .32486 Mdot
.30075 .60341 Mdot
.6573 .59704 Mdot
.64299 .61468 Mdot
.45142 .67233 Mdot
.42783 .34927 Mdot
.47267 .38232 Mdot
.64773 .54471 Mdot
.57687 .24659 Mdot
.3008 .56354 Mdot
.4573 .41851 Mdot
.43888 .41657 Mdot
.64915 .58539 Mdot
.74117 .36779 Mdot
.36191 .61296 Mdot
.47911 .40768 Mdot
.71066 .40936 Mdot
.47917 .68517 Mdot
.43037 .43948 Mdot
.46258 .44325 Mdot
.67692 .46002 Mdot
.61937 .23162 Mdot
.16975 .48141 Mdot
.48392 .67997 Mdot
.65852 .67924 Mdot
.467 .341 Mdot
.6426 .5574 Mdot
.47515 .35033 Mdot
.48517 .20419 Mdot
.64504 .69124 Mdot
.43889 .38076 Mdot
.38335 .40178 Mdot
.34255 .58598 Mdot
.43767 .37081 Mdot
.34472 .27199 Mdot
.64638 .53277 Mdot
.43846 .3762 Mdot
.2663 .51845 Mdot
.44524 .65466 Mdot
.38549 .42136 Mdot
.70182 .45583 Mdot
.56151 .288 Mdot
.36009 .68422 Mdot
.66379 .61984 Mdot
.70589 .44142 Mdot
.47654 .35902 Mdot
.62872 .60198 Mdot
.48933 .66737 Mdot
.51237 .79187 Mdot
.40639 .41512 Mdot
.46346 .66079 Mdot
.471 .64268 Mdot
.6928 .4333 Mdot
.47791 .84661 Mdot
.42777 .45787 Mdot
.47778 .37815 Mdot
.35401 .2567 Mdot
.35855 .58167 Mdot
.47805 .36973 Mdot
.45096 .34477 Mdot
.47089 .62662 Mdot
.32805 .62326 Mdot
.3464 .33597 Mdot
.73852 .59364 Mdot
.47005 .68261 Mdot
.6878 .59794 Mdot
.62724 .60015 Mdot
.70165 .44866 Mdot
.34128 .57139 Mdot
.67839 .41391 Mdot
.6311 .57617 Mdot
.43585 .35088 Mdot
.46606 .63013 Mdot
.25173 .36073 Mdot
.43408 .63298 Mdot
.6803 .54997 Mdot
.35444 .59298 Mdot
.30604 .65383 Mdot
.14551 .5068 Mdot
.37717 .70683 Mdot
.42592 .63233 Mdot
.66806 .44358 Mdot
.69018 .6279 Mdot
.4408 .41776 Mdot
.30526 .33867 Mdot
.46997 .35727 Mdot
.24135 .54724 Mdot
.62463 .57887 Mdot
.66986 .68949 Mdot
.47952 .40915 Mdot
.62656 .34853 Mdot
.45583 .60519 Mdot
.45211 .67411 Mdot
.44679 .37849 Mdot
.48628 .65587 Mdot
.47978 .38954 Mdot
.671 .56742 Mdot
.41698 .8213 Mdot
.44687 .42029 Mdot
.47491 .33265 Mdot
.53515 .65515 Mdot
.80162 .4115 Mdot
.60615 .56591 Mdot
.21558 .50983 Mdot
.41024 .18822 Mdot
.48636 .65369 Mdot
.38498 .35948 Mdot
.64348 .54052 Mdot
.64594 .70345 Mdot
.61657 .5403 Mdot
.46852 .36098 Mdot
.46096 .36139 Mdot
.43972 .42893 Mdot
.4333 .40189 Mdot
.30883 .33232 Mdot
.50183 .44547 Mdot
.23223 .49158 Mdot
.4567 .37741 Mdot
.25538 .57329 Mdot
.46999 .62016 Mdot
.30156 .52294 Mdot
.71809 .4271 Mdot
.45019 .35084 Mdot
.38778 .51095 Mdot
.49053 .67688 Mdot
.59447 .17133 Mdot
.44955 .668 Mdot
.65688 .56987 Mdot
.43793 .63862 Mdot
.41907 .37236 Mdot
.32715 .57357 Mdot
.65784 .53515 Mdot
.49947 .762 Mdot
.65425 .59144 Mdot
.42273 .36006 Mdot
.74704 .41794 Mdot
.64861 .58978 Mdot
.52837 .50571 Mdot
.33139 .57585 Mdot
.6559 .33855 Mdot
.32631 .59132 Mdot
.43664 .37866 Mdot
.43598 .38307 Mdot
.64252 .67933 Mdot
.45426 .60884 Mdot
.30055 .58146 Mdot
.33846 .81361 Mdot
.66089 .41958 Mdot
.32567 .54629 Mdot
.49393 .43129 Mdot
.5793 .47502 Mdot
.31646 .57154 Mdot
.61501 .29788 Mdot
.48612 .66786 Mdot
.35336 .52289 Mdot
.50607 .4073 Mdot
.51589 .59841 Mdot
.69899 .47084 Mdot
.678 .57477 Mdot
.53307 .57739 Mdot
.63811 .53871 Mdot
.4961 .67219 Mdot
.68271 .56352 Mdot
.44513 .63644 Mdot
.24285 .6112 Mdot
.37892 .47846 Mdot
.43137 .63287 Mdot
.50255 .66213 Mdot
.63474 .56771 Mdot
.41178 .42001 Mdot
.44687 .5338 Mdot
.39525 .38632 Mdot
.4072 .42448 Mdot
.44394 .64191 Mdot
.29988 .57591 Mdot
.28953 .56122 Mdot
.277 .59583 Mdot
.36779 .55595 Mdot
.66867 .56078 Mdot
.41966 .78856 Mdot
.2305 .61322 Mdot
.45448 .65943 Mdot
.50767 .65406 Mdot
.42711 .41105 Mdot
.63935 .55986 Mdot
.6298 .5962 Mdot
.47669 .63298 Mdot
.2727 .35599 Mdot
.48009 .34043 Mdot
.34294 .59593 Mdot
.30222 .54127 Mdot
.31544 .56359 Mdot
.37166 .54903 Mdot
.33441 .38849 Mdot
.48459 .67068 Mdot
.2967 .5496 Mdot
.44338 .38079 Mdot
.4635 .36133 Mdot
.66702 .69755 Mdot
.70657 .44829 Mdot
.492 .42476 Mdot
.46371 .31935 Mdot
.46586 .38668 Mdot
.64381 .59144 Mdot
.37606 .42754 Mdot
.64979 .68024 Mdot
.66895 .60074 Mdot
.64799 .61812 Mdot
.67087 .70204 Mdot
.26653 .58352 Mdot
.4201 .17481 Mdot
.42178 .40397 Mdot
.38484 .46705 Mdot
.64367 .56173 Mdot
.46308 .81976 Mdot
.26083 .64667 Mdot
.42662 .42954 Mdot
.4832 .57103 Mdot
.66743 .54359 Mdot
.36525 .57428 Mdot
.47471 .36377 Mdot
.66458 .71063 Mdot
.67488 .41893 Mdot
.49878 .4258 Mdot
.65374 .71518 Mdot
.31277 .54056 Mdot
.70681 .47654 Mdot
.36604 .52726 Mdot
.66825 .54289 Mdot
.38404 .40715 Mdot
.57002 .11956 Mdot
.62083 .55208 Mdot
.75433 .33856 Mdot
.39622 .57793 Mdot
.45252 .42231 Mdot
.62512 .54704 Mdot
.36276 .57998 Mdot
.48325 .68519 Mdot
.58132 .45516 Mdot
.35282 .54138 Mdot
.66083 .6791 Mdot
.66513 .70341 Mdot
.64418 .58554 Mdot
.34951 .57466 Mdot
.4867 .41248 Mdot
.32737 .58711 Mdot
.4387 .64565 Mdot
.41607 .41664 Mdot
.50434 .16962 Mdot
.42755 .47581 Mdot
.2958 .56199 Mdot
.67117 .5923 Mdot
.69166 .47118 Mdot
.40509 .40174 Mdot
.73351 .32913 Mdot
.4385 .34593 Mdot
.44836 .64853 Mdot
.56634 .82063 Mdot
.26976 .3349 Mdot
.41663 .3588 Mdot
.4276 .41 Mdot
.47793 .67864 Mdot
.4026 .39318 Mdot
.41505 .35537 Mdot
.52305 .63887 Mdot
.33748 .5861 Mdot
.45012 .41 Mdot
.6422 .60374 Mdot
.19623 .53789 Mdot
.46134 .33705 Mdot
.60212 .75307 Mdot
.64531 .34456 Mdot
.53922 .83304 Mdot
.48162 .36632 Mdot
.59304 .40611 Mdot
.43893 .3966 Mdot
.44971 .35561 Mdot
.42141 .41231 Mdot
.21023 .49045 Mdot
.63289 .56688 Mdot
.66778 .58799 Mdot
.70188 .46932 Mdot
.64514 .34107 Mdot
.68712 .46001 Mdot
.46384 .67823 Mdot
.80607 .55663 Mdot
.64605 .6954 Mdot
.3192 .5356 Mdot
.49231 .39587 Mdot
.65721 .5324 Mdot
.46993 .37711 Mdot
.41945 .37638 Mdot
.67177 .55299 Mdot
.61613 .57433 Mdot
.59039 .56527 Mdot
.66118 .44602 Mdot
.34041 .54141 Mdot
.4571 .44106 Mdot
.69686 .42465 Mdot
.4918 .40465 Mdot
.59544 .45555 Mdot
.33605 .53993 Mdot
.33162 .5881 Mdot
.30837 .59177 Mdot
.43606 .35056 Mdot
.41381 .37452 Mdot
.47579 .62395 Mdot
.33332 .52763 Mdot
.46099 .67075 Mdot
.64941 .53757 Mdot
.62822 .53436 Mdot
.46819 .3609 Mdot
.44002 .2824 Mdot
.67194 .45931 Mdot
.65947 .56513 Mdot
.67316 .69115 Mdot
.68226 .47403 Mdot
.42729 .35568 Mdot
.66377 .54683 Mdot
.70844 .44241 Mdot
.25131 .40039 Mdot
.37941 .19483 Mdot
.69255 .46945 Mdot
.44606 .38073 Mdot
.20989 .52622 Mdot
.73024 .37065 Mdot
.65889 .4234 Mdot
.45415 .64473 Mdot
.44444 .34577 Mdot
.48417 .24099 Mdot
.69907 .4159 Mdot
.22409 .58455 Mdot
.65584 .58551 Mdot
.43671 .59161 Mdot
.51308 .3836 Mdot
.29591 .36077 Mdot
.67034 .41507 Mdot
.34106 .55935 Mdot
.28389 .55868 Mdot
.45123 .39574 Mdot
.72074 .42927 Mdot
.45072 .6747 Mdot
.66247 .58341 Mdot
.61216 .59238 Mdot
.3465 .57822 Mdot
.35362 .72471 Mdot
.65162 .60325 Mdot
.45454 .28961 Mdot
.71333 .6441 Mdot
.41794 .48508 Mdot
.26491 .54178 Mdot
.46938 .74939 Mdot
.47584 .34515 Mdot
.68616 .469 Mdot
.49909 .65743 Mdot
.48466 .63209 Mdot
.47749 .66394 Mdot
.61084 .55964 Mdot
.51444 .52828 Mdot
.63557 .54993 Mdot
.50807 .78386 Mdot
.69727 .43644 Mdot
.66722 .3245 Mdot
.49165 .37984 Mdot
.44442 .41985 Mdot
.50214 .38449 Mdot
.46894 .42372 Mdot
.44026 .40105 Mdot
.48441 .66672 Mdot
.61092 .57791 Mdot
.77119 .51878 Mdot
.31512 .55218 Mdot
.59742 .61245 Mdot
.64401 .55551 Mdot
.64602 .70248 Mdot
.67794 .43723 Mdot
.56634 .42427 Mdot
.6784 .59755 Mdot
.64996 .5555 Mdot
.47228 .44164 Mdot
.30967 .57839 Mdot
.52707 .35352 Mdot
.43498 .38908 Mdot
.66073 .56188 Mdot
.69729 .56369 Mdot
.36419 .27859 Mdot
.44337 .30725 Mdot
.66848 .48116 Mdot
.57385 .48017 Mdot
.65745 .44124 Mdot
.49272 .33573 Mdot
.47166 .82254 Mdot
.63176 .576 Mdot
.65254 .57547 Mdot
.70833 .45234 Mdot
.39394 .31097 Mdot
.34331 .57579 Mdot
.66972 .68849 Mdot
.45342 .63456 Mdot
.4312 .37745 Mdot
.6197 .54546 Mdot
.36621 .35806 Mdot
.76129 .5855 Mdot
.47215 .66535 Mdot
.66762 .60206 Mdot
.42539 .35142 Mdot
.44781 .38154 Mdot
.66808 .43645 Mdot
.40095 .50419 Mdot
.46702 .45409 Mdot
.72728 .28431 Mdot
.40011 .76204 Mdot
.34386 .74396 Mdot
.46856 .38734 Mdot
.34799 .57906 Mdot
.66094 .70942 Mdot
.68176 .42343 Mdot
.47626 .43062 Mdot
.38977 .1911 Mdot
.29372 .58705 Mdot
.46693 .65076 Mdot
.66619 .70873 Mdot
.5142 .52635 Mdot
.44269 .34504 Mdot
.47038 .35778 Mdot
.44601 .36562 Mdot
.3367 .20286 Mdot
.65504 .59937 Mdot
.37185 .55965 Mdot
.68341 .44971 Mdot
.37005 .55972 Mdot
.66252 .59054 Mdot
.30365 .68499 Mdot
.41066 .36923 Mdot
.34824 .59437 Mdot
.3389 .562 Mdot
.45223 .67302 Mdot
.48007 .68751 Mdot
.58884 .56992 Mdot
.48816 .38806 Mdot
.66319 .71195 Mdot
.32916 .59143 Mdot
.61891 .59016 Mdot
.67485 .42964 Mdot
.48401 .62364 Mdot
.45609 .37648 Mdot
.63598 .58249 Mdot
.39567 .34987 Mdot
.31408 .57421 Mdot
.64924 .55592 Mdot
.6714 .71348 Mdot
.68531 .46473 Mdot
.45981 .36776 Mdot
.65747 .47181 Mdot
.67267 .69856 Mdot
.43788 .41789 Mdot
.54988 .3791 Mdot
.65016 .41943 Mdot
.51478 .76473 Mdot
.62853 .55168 Mdot
.66203 .68828 Mdot
.33751 .59023 Mdot
.29506 .6292 Mdot
.65669 .5761 Mdot
.56113 .40979 Mdot
.40941 .52913 Mdot
.45327 .44251 Mdot
.3226 .56205 Mdot
.69908 .61409 Mdot
.6781 .24084 Mdot
.70148 .32431 Mdot
.45401 .41703 Mdot
.62795 .54458 Mdot
.70819 .4367 Mdot
.45353 .65878 Mdot
.60367 .75432 Mdot
.35697 .42858 Mdot
.68193 .57378 Mdot
.42305 .40976 Mdot
.32696 .5907 Mdot
.47726 .63482 Mdot
.37463 .66288 Mdot
.65326 .61017 Mdot
.62329 .57385 Mdot
.41858 .35923 Mdot
.69778 .44466 Mdot
.62757 .26093 Mdot
.67178 .58291 Mdot
.61969 .54697 Mdot
.67953 .67148 Mdot
.71087 .4514 Mdot
.4458 .39017 Mdot
.278 .59693 Mdot
.42815 .44161 Mdot
.75634 .33724 Mdot
.65223 .68104 Mdot
.31343 .55233 Mdot
.46257 .35495 Mdot
.73649 .61487 Mdot
.6643 .56773 Mdot
.56274 .49355 Mdot
.67495 .53422 Mdot
.48741 .66529 Mdot
.62111 .54353 Mdot
.4746 .37025 Mdot
.45388 .60516 Mdot
.67341 .46 Mdot
.48165 .40437 Mdot
.41294 .37684 Mdot
.36764 .57473 Mdot
.46168 .6464 Mdot
.20168 .40517 Mdot
.50478 .64492 Mdot
.49189 .67268 Mdot
.2912 .54233 Mdot
.45452 .40032 Mdot
.65441 .56673 Mdot
.67989 .55667 Mdot
.47391 .43074 Mdot
.42507 .80258 Mdot
.34277 .57799 Mdot
.58752 .57649 Mdot
.28722 .24829 Mdot
.48577 .31246 Mdot
.67488 .70614 Mdot
.4017 .4981 Mdot
.46362 .68188 Mdot
.45133 .37821 Mdot
.29759 .55811 Mdot
.61444 .55702 Mdot
.65012 .60341 Mdot
.48953 .41187 Mdot
.47299 .63827 Mdot
.69057 .41637 Mdot
.62194 .57773 Mdot
.75137 .60725 Mdot
.44023 .36528 Mdot
.53718 .78448 Mdot
.6207 .56701 Mdot
.76958 .32613 Mdot
.76894 .54455 Mdot
.31964 .56052 Mdot
.41773 .3791 Mdot
.36252 .54979 Mdot
.6792 .452 Mdot
.66988 .62058 Mdot
.47014 .64041 Mdot
.42735 .30939 Mdot
.17101 .53525 Mdot
.6342 .56197 Mdot
.32733 .53507 Mdot
.41774 .35766 Mdot
.46623 .30114 Mdot
.48023 .37886 Mdot
.29969 .62015 Mdot
.66688 .49749 Mdot
.44404 .64567 Mdot
.44928 .64725 Mdot
.4339 .42104 Mdot
.67088 .42598 Mdot
.67561 .56271 Mdot
.6617 .58235 Mdot
.78897 .7204 Mdot
.67274 .71314 Mdot
.6054 .33454 Mdot
.45992 .36357 Mdot
.62177 .59717 Mdot
.20285 .52776 Mdot
.4592 .66039 Mdot
.47038 .42401 Mdot
.62254 .60291 Mdot
.54559 .65886 Mdot
.59226 .45825 Mdot
.44335 .39724 Mdot
.52301 .3733 Mdot
.45212 .63798 Mdot
.63195 .40522 Mdot
.63982 .54749 Mdot
.46576 .42909 Mdot
.50324 .63644 Mdot
.71842 .65779 Mdot
.2063 .58873 Mdot
.33981 .54145 Mdot
.67771 .5411 Mdot
.48426 .66735 Mdot
.47788 .4493 Mdot
.70417 .44636 Mdot
.64509 .53469 Mdot
.64936 .59374 Mdot
.41396 .40515 Mdot
.45901 .45003 Mdot
.48427 .31137 Mdot
.31807 .54211 Mdot
.45895 .6208 Mdot
.47813 .4124 Mdot
.35966 .72883 Mdot
.44269 .4304 Mdot
.46523 .62185 Mdot
.72625 .19956 Mdot
.41595 .43051 Mdot
.47987 .3813 Mdot
.6505 .27651 Mdot
.35531 .54308 Mdot
.36897 .56016 Mdot
.40542 .77087 Mdot
.45994 .36399 Mdot
.7872 .52656 Mdot
.3446 .54298 Mdot
.33813 .57959 Mdot
.73404 .49414 Mdot
.41995 .42307 Mdot
.64346 .40211 Mdot
.47904 .63071 Mdot
.49341 .63738 Mdot
.33119 .58652 Mdot
.46783 .45457 Mdot
.48659 .6736 Mdot
.32506 .33613 Mdot
.641 .55361 Mdot
.47602 .82402 Mdot
.30877 .5703 Mdot
.44356 .51861 Mdot
.46411 .66457 Mdot
.60228 .17385 Mdot
.50836 .58067 Mdot
.43482 .42888 Mdot
.45464 .36845 Mdot
.6813 .46291 Mdot
.39007 .40081 Mdot
.65444 .67731 Mdot
.48609 .65703 Mdot
.58548 .22874 Mdot
.33053 .54301 Mdot
.48594 .38685 Mdot
.56733 .41706 Mdot
.38378 .68058 Mdot
.59141 .77336 Mdot
.34598 .56634 Mdot
.32577 .55664 Mdot
.62873 .5605 Mdot
.63094 .58634 Mdot
.44894 .4011 Mdot
.4893 .63828 Mdot
.33808 .52582 Mdot
.45437 .62751 Mdot
.63157 .57807 Mdot
.65076 .56009 Mdot
.64475 .68974 Mdot
.40984 .34367 Mdot
.67278 .56047 Mdot
.7435 .63113 Mdot
.34641 .72328 Mdot
.37702 .55014 Mdot
.15716 .46449 Mdot
.37473 .66105 Mdot
.56113 .26 Mdot
.65914 .44086 Mdot
.64525 .6659 Mdot
.44531 .61908 Mdot
.42904 .41252 Mdot
.46399 .37566 Mdot
.65556 .69787 Mdot
.43914 .61582 Mdot
.67325 .43895 Mdot
.44631 .61083 Mdot
.69952 .43502 Mdot
.61825 .54102 Mdot
.46348 .3384 Mdot
.4583 .34489 Mdot
.48298 .66658 Mdot
.65671 .55067 Mdot
.66974 .57529 Mdot
.66048 .45192 Mdot
.58156 .42334 Mdot
.64253 .58582 Mdot
.30999 .57166 Mdot
.33376 .44004 Mdot
.6632 .70363 Mdot
.47589 .36576 Mdot
.57217 .38775 Mdot
.29418 .33042 Mdot
.45167 .43999 Mdot
.66913 .70753 Mdot
.71297 .77094 Mdot
.49033 .38186 Mdot
.64555 .81407 Mdot
.66387 .6895 Mdot
.356 .54263 Mdot
.62504 .54989 Mdot
.65174 .6763 Mdot
.51398 .39517 Mdot
.65432 .43974 Mdot
.49775 .40791 Mdot
.35468 .54536 Mdot
.31694 .59522 Mdot
.32181 .74039 Mdot
.75723 .34025 Mdot
.66633 .46116 Mdot
.68473 .43146 Mdot
.65591 .57812 Mdot
.83887 .50665 Mdot
.5039 .41059 Mdot
.67974 .43103 Mdot
.57626 .23413 Mdot
.42515 .40421 Mdot
.60338 .35419 Mdot
.48382 .56906 Mdot
.34653 .57945 Mdot
.26428 .57053 Mdot
.66182 .57334 Mdot
.32963 .53528 Mdot
.31984 .71372 Mdot
.50185 .38631 Mdot
.3332 .54033 Mdot
.46476 .62318 Mdot
.53492 .71486 Mdot
.36263 .55765 Mdot
.59294 .43702 Mdot
.4825 .63413 Mdot
.6955 .54074 Mdot
.62411 .27256 Mdot
.12217 .47184 Mdot
.48824 .65494 Mdot
.65662 .54333 Mdot
.6692 .54451 Mdot
.65896 .58253 Mdot
.35064 .5388 Mdot
.63371 .60243 Mdot
.3103 .54812 Mdot
.74986 .3817 Mdot
.57797 .41269 Mdot
.69041 .42813 Mdot
.52549 .66587 Mdot
.33185 .56057 Mdot
.46454 .7884 Mdot
.14888 .50451 Mdot
.44623 .37696 Mdot
.50417 .64106 Mdot
.70681 .45423 Mdot
.83712 .40622 Mdot
.67881 .46131 Mdot
.64158 .54105 Mdot
.48556 .8264 Mdot
.4812 .39201 Mdot
.39734 .26119 Mdot
.67875 .46556 Mdot
.35106 .56066 Mdot
.44015 .41907 Mdot
.64379 .5166 Mdot
.69926 .44966 Mdot
.68088 .41718 Mdot
.44212 .40904 Mdot
.35956 .56569 Mdot
.65345 .56259 Mdot
.45301 .61498 Mdot
.66638 .40957 Mdot
.47831 .45276 Mdot
.43967 .44497 Mdot
.48881 .35489 Mdot
.54028 .51718 Mdot
.51099 .23027 Mdot
.48656 .65185 Mdot
.69751 .34959 Mdot
.63561 .58994 Mdot
.71394 .56963 Mdot
.42197 .76076 Mdot
.51013 .68674 Mdot
.65392 .68098 Mdot
.64795 .68371 Mdot
.44304 .40063 Mdot
.51858 .22899 Mdot
.61282 .79364 Mdot
.53168 .66774 Mdot
.66151 .70545 Mdot
.6653 .58081 Mdot
.28365 .56344 Mdot
.28769 .71172 Mdot
.42776 .44524 Mdot
.46026 .68271 Mdot
.63991 .58692 Mdot
.4809 .2051 Mdot
.69405 .44071 Mdot
.46398 .81256 Mdot
.41521 .36484 Mdot
.46778 .41493 Mdot
.48124 .64825 Mdot
.4778 .6252 Mdot
.58148 .76297 Mdot
.35414 .75435 Mdot
.6254 .46458 Mdot
.36501 .62678 Mdot
.45324 .21475 Mdot
.29392 .52812 Mdot
.29652 .5659 Mdot
.66091 .71859 Mdot
.49772 .63428 Mdot
.47134 .35616 Mdot
.32576 .53083 Mdot
.5907 .77483 Mdot
.34955 .60812 Mdot
.6122 .3525 Mdot
.77801 .55564 Mdot
.42364 .36632 Mdot
.31444 .58295 Mdot
.33298 .53652 Mdot
.36624 .53198 Mdot
.67012 .70441 Mdot
.46725 .3916 Mdot
.40894 .41502 Mdot
.46495 .42168 Mdot
.50034 .43961 Mdot
.43822 .36796 Mdot
.40634 .74531 Mdot
.56285 .57282 Mdot
.59786 .22783 Mdot
.44513 .439 Mdot
.49603 .64462 Mdot
.49757 .37493 Mdot
.67389 .42301 Mdot
.42369 .41219 Mdot
.60517 .34354 Mdot
.47118 .65788 Mdot
.39922 .30904 Mdot
.35688 .62912 Mdot
.41243 .36839 Mdot
.70432 .42251 Mdot
.53411 .23644 Mdot
.19277 .42188 Mdot
.60882 .62366 Mdot
.31122 .5733 Mdot
.67367 .60278 Mdot
.44006 .6531 Mdot
.6525 .56819 Mdot
.44506 .43484 Mdot
.66408 .71435 Mdot
.44715 .7255 Mdot
.44537 .52055 Mdot
.46376 .35065 Mdot
.38171 .43408 Mdot
.32531 .5806 Mdot
.66178 .54571 Mdot
.3725 .51158 Mdot
.451 .36011 Mdot
.68628 .4512 Mdot
.70118 .4439 Mdot
.36093 .74591 Mdot
.50803 .18317 Mdot
.27152 .62259 Mdot
.48278 .64914 Mdot
.66631 .59607 Mdot
.67558 .41346 Mdot
.36188 .42911 Mdot
.46483 .6868 Mdot
.46027 .67972 Mdot
.46453 .6393 Mdot
.42774 .37168 Mdot
.65305 .67875 Mdot
.54341 .21545 Mdot
.65811 .67759 Mdot
.41076 .3731 Mdot
.65049 .59717 Mdot
.6467 .67724 Mdot
.69011 .46149 Mdot
.45943 .67276 Mdot
.62902 .57714 Mdot
.43534 .37627 Mdot
.34252 .54709 Mdot
.58053 .42975 Mdot
.5522 .29756 Mdot
.71149 .30478 Mdot
.70463 .29527 Mdot
.29561 .58009 Mdot
.5777 .17884 Mdot
.50794 .6382 Mdot
.27454 .35443 Mdot
.73527 .41368 Mdot
.47705 .42622 Mdot
.35075 .78611 Mdot
.64004 .54625 Mdot
.66908 .54946 Mdot
.44236 .39167 Mdot
.61491 .57613 Mdot
.48423 .38348 Mdot
.62598 .57848 Mdot
.61017 .62292 Mdot
.42224 .44408 Mdot
.66999 .55531 Mdot
.50975 .36782 Mdot
.40646 .40429 Mdot
.34031 .584 Mdot
.63354 .53777 Mdot
.44487 .43192 Mdot
.85142 .47981 Mdot
.48141 .62382 Mdot
.66955 .70391 Mdot
.60395 .49582 Mdot
.48178 .67111 Mdot
.32232 .54874 Mdot
.40332 .42138 Mdot
.66611 .44895 Mdot
.34079 .55612 Mdot
.58856 .57303 Mdot
.68588 .46645 Mdot
.42101 .78881 Mdot
.31473 .57778 Mdot
.66182 .70164 Mdot
.6726 .4609 Mdot
.37932 .42172 Mdot
.64347 .53132 Mdot
.51619 .28227 Mdot
.66486 .68372 Mdot
.47312 .3812 Mdot
.60717 .58507 Mdot
.48833 .62587 Mdot
.46014 .41091 Mdot
.62054 .55121 Mdot
.67143 .70331 Mdot
.4267 .38082 Mdot
.43263 .40821 Mdot
.25354 .66787 Mdot
.56355 .79891 Mdot
.67009 .43426 Mdot
.34806 .5902 Mdot
.44283 .38076 Mdot
.66082 .4429 Mdot
.77265 .63086 Mdot
.4782 .34562 Mdot
.35764 .53962 Mdot
.54232 .41227 Mdot
.63413 .59142 Mdot
.46123 .67153 Mdot
.67751 .54264 Mdot
.67134 .42096 Mdot
.38578 .8432 Mdot
.64468 .68368 Mdot
.50348 .34754 Mdot
.49088 .40423 Mdot
.68742 .61832 Mdot
.32782 .53704 Mdot
.62189 .45518 Mdot
.45934 .36786 Mdot
.43132 .47647 Mdot
.47989 .40345 Mdot
.77194 .53272 Mdot
.3421 .57732 Mdot
.4774 .37919 Mdot
.45791 .28663 Mdot
.44474 .33497 Mdot
.69819 .41742 Mdot
.66268 .30731 Mdot
.48772 .35857 Mdot
.50099 .09785 Mdot
.67381 .69642 Mdot
.67226 .55822 Mdot
.6669 .51125 Mdot
.82507 .6106 Mdot
.24223 .60692 Mdot
.31305 .54496 Mdot
.47597 .485 Mdot
.65317 .56531 Mdot
.21339 .56621 Mdot
.61329 .19003 Mdot
.40585 .3999 Mdot
.43662 .34815 Mdot
.64157 .54104 Mdot
.61788 .58901 Mdot
.65736 .71521 Mdot
.43828 .43562 Mdot
.37896 .36465 Mdot
.66599 .60177 Mdot
.43338 .36315 Mdot
.53761 .37329 Mdot
.45289 .61689 Mdot
.35067 .58126 Mdot
.45411 .66086 Mdot
.44736 .66537 Mdot
.30444 .4021 Mdot
.39836 .76056 Mdot
.46706 .62146 Mdot
.46639 .60335 Mdot
.59687 .3442 Mdot
.54006 .43756 Mdot
.68169 .41464 Mdot
.60632 .21146 Mdot
.65293 .58241 Mdot
.46619 .39336 Mdot
.2935 .56904 Mdot
.29147 .37589 Mdot
.57498 .63966 Mdot
.52273 .82821 Mdot
.45507 .35631 Mdot
.66453 .57357 Mdot
.67119 .69723 Mdot
.42741 .44679 Mdot
.70858 .539 Mdot
.46111 .41748 Mdot
.65654 .53228 Mdot
.34469 .4511 Mdot
.53611 .34524 Mdot
.69023 .63932 Mdot
.34727 .52005 Mdot
.49043 .39483 Mdot
.30719 .56177 Mdot
.46823 .66741 Mdot
.66517 .43244 Mdot
.66912 .43826 Mdot
.43804 .41499 Mdot
.37102 .45922 Mdot
.47282 .56645 Mdot
.40436 .39564 Mdot
.41553 .41145 Mdot
.66267 .68832 Mdot
.41571 .41303 Mdot
.48877 .40754 Mdot
.46751 .42309 Mdot
.45026 .32981 Mdot
.49328 .67045 Mdot
.54164 .35334 Mdot
.42272 .33124 Mdot
.48081 .31503 Mdot
.46456 .61538 Mdot
.43599 .49474 Mdot
.44713 .66122 Mdot
.50134 .16995 Mdot
.44698 .64651 Mdot
.67456 .43163 Mdot
.61496 .60305 Mdot
.44741 .4816 Mdot
.3351 .52492 Mdot
.48412 .68283 Mdot
.68177 .44284 Mdot
.48194 .66147 Mdot
.65231 .60089 Mdot
.22067 .34078 Mdot
.35163 .60773 Mdot
.6065 .43376 Mdot
.49573 .59065 Mdot
.54382 .78268 Mdot
.63364 .55711 Mdot
.34085 .58095 Mdot
.3762 .26418 Mdot
.4533 .42813 Mdot
.67943 .46379 Mdot
.44386 .40438 Mdot
.4888 .67649 Mdot
.6618 .57796 Mdot
.7235 .33554 Mdot
.66685 .44205 Mdot
.2002 .61111 Mdot
.65967 .58654 Mdot
.40511 .41387 Mdot
.46399 .68356 Mdot
.15561 .46987 Mdot
.44705 .65287 Mdot
.57695 .40792 Mdot
.3721 .57969 Mdot
.24734 .56534 Mdot
.32599 .56343 Mdot
.61523 .76343 Mdot
.35118 .18305 Mdot
.69557 .2652 Mdot
.34934 .55112 Mdot
.70052 .64614 Mdot
.42833 .35761 Mdot
.49359 .36355 Mdot
.46265 .2947 Mdot
.3726 .56471 Mdot
.44151 .37487 Mdot
.6655 .68711 Mdot
.3192 .69674 Mdot
.72566 .56676 Mdot
.67558 .59875 Mdot
.47899 .37278 Mdot
.46378 .61613 Mdot
.44529 .61049 Mdot
.64957 .6758 Mdot
.44173 .64945 Mdot
.4148 .42148 Mdot
.32973 .56206 Mdot
.42492 .5295 Mdot
.68059 .45765 Mdot
.81473 .41352 Mdot
.71355 .42194 Mdot
.66225 .51741 Mdot
.38347 .40433 Mdot
.65071 .55918 Mdot
.52678 .88091 Mdot
.43957 .42755 Mdot
.34505 .54123 Mdot
.43129 .39794 Mdot
.4848 .40521 Mdot
.49423 .36331 Mdot
.65133 .60905 Mdot
.65706 .4912 Mdot
.43303 .36639 Mdot
.46881 .64081 Mdot
.65186 .25184 Mdot
.50192 .39375 Mdot
.63488 .63533 Mdot
.63697 .33117 Mdot
.50097 .78409 Mdot
.3753 .53375 Mdot
.66085 .54681 Mdot
.3291 .54695 Mdot
.31695 .52612 Mdot
.32224 .54861 Mdot
.54728 .21125 Mdot
.35856 .29745 Mdot
.71294 .76581 Mdot
.26043 .53242 Mdot
.26962 .38989 Mdot
.33267 .59675 Mdot
.7597 .66863 Mdot
.29898 .55037 Mdot
.31783 .54471 Mdot
.88992 .43259 Mdot
.30053 .54502 Mdot
.46867 .36369 Mdot
.45801 .44826 Mdot
.37449 .69693 Mdot
.59061 .35637 Mdot
.42531 .4197 Mdot
.44267 .38562 Mdot
.6624 .4406 Mdot
.37877 .30015 Mdot
.65364 .71687 Mdot
.41464 .79048 Mdot
.39844 .66608 Mdot
.44174 .40718 Mdot
.44024 .38103 Mdot
.44005 .4601 Mdot
.30019 .20316 Mdot
.31026 .36592 Mdot
.31133 .59592 Mdot
.38786 .4503 Mdot
.78179 .35642 Mdot
.40031 .39021 Mdot
.45676 .34351 Mdot
.42243 .37486 Mdot
.65411 .56616 Mdot
.28618 .57756 Mdot
.38871 .45066 Mdot
.4783 .76892 Mdot
.42104 .35882 Mdot
.51897 .67045 Mdot
.64447 .43602 Mdot
.47361 .36993 Mdot
.36983 .54167 Mdot
.42075 .39815 Mdot
.3099 .57549 Mdot
.33726 .58687 Mdot
.43639 .46084 Mdot
.5271 .20342 Mdot
.36345 .54281 Mdot
.41309 .37292 Mdot
.65941 .55363 Mdot
.69022 .2532 Mdot
.47266 .37836 Mdot
.68933 .42305 Mdot
.45676 .36759 Mdot
.70549 .42511 Mdot
.40889 .39951 Mdot
.66201 .68026 Mdot
.28705 .31628 Mdot
.65176 .57669 Mdot
.70636 .38359 Mdot
.62845 .60383 Mdot
.25638 .67037 Mdot
.35365 .53788 Mdot
.66639 .72073 Mdot
.48451 .84127 Mdot
.66381 .69163 Mdot
.57313 .43613 Mdot
.59695 .62036 Mdot
.49276 .64403 Mdot
.36821 .56514 Mdot
.68762 .35912 Mdot
.67152 .65206 Mdot
.6159 .52517 Mdot
.65116 .61829 Mdot
.38957 .83217 Mdot
.43329 .82856 Mdot
.43201 .37426 Mdot
.42207 .24444 Mdot
.23584 .48341 Mdot
.47104 .34316 Mdot
.39674 .40167 Mdot
.64354 .52945 Mdot
.492 .38254 Mdot
.52558 .51176 Mdot
.63481 .5666 Mdot
.68377 .43763 Mdot
.31183 .55286 Mdot
.70632 .42864 Mdot
.62011 .53222 Mdot
.56585 .55882 Mdot
.63176 .58355 Mdot
.45961 .33068 Mdot
.43384 .39391 Mdot
.32387 .58748 Mdot
.38908 .52212 Mdot
.34622 .58367 Mdot
.70194 .46156 Mdot
.63836 .57491 Mdot
.30386 .35827 Mdot
.4517 .38387 Mdot
.33751 .56433 Mdot
.41876 .65215 Mdot
.44815 .3808 Mdot
.47716 .66883 Mdot
.42914 .35258 Mdot
.35208 .55037 Mdot
.41533 .41271 Mdot
.3289 .56044 Mdot
.64806 .5458 Mdot
.40222 .37741 Mdot
.44403 .39322 Mdot
.16506 .4999 Mdot
.67252 .44123 Mdot
.3543 .53879 Mdot
.52073 .55936 Mdot
.4108 .42186 Mdot
.70287 .5812 Mdot
.48084 .36592 Mdot
.51098 .4623 Mdot
.50591 .35587 Mdot
.66699 .69198 Mdot
.40199 .34193 Mdot
.47346 .37881 Mdot
.47409 .28051 Mdot
.26009 .50631 Mdot
.37272 .5105 Mdot
.48129 .6805 Mdot
.37031 .54636 Mdot
.62846 .53478 Mdot
.61142 .56603 Mdot
.6226 .58545 Mdot
.58933 .37595 Mdot
.44513 .45795 Mdot
.47999 .39151 Mdot
.49039 .68233 Mdot
.68836 .43217 Mdot
.34521 .56477 Mdot
.69304 .43327 Mdot
.40475 .78146 Mdot
.70022 .462 Mdot
.65198 .67712 Mdot
.76813 .54781 Mdot
.31292 .31905 Mdot
.66252 .44351 Mdot
.34807 .58276 Mdot
.77212 .56463 Mdot
.47441 .42709 Mdot
.58359 .56347 Mdot
.68822 .45073 Mdot
.35245 .82096 Mdot
.47719 .35749 Mdot
.57105 .47109 Mdot
.44513 .62903 Mdot
.70221 .45101 Mdot
.46045 .65041 Mdot
.42981 .41903 Mdot
.52486 .76547 Mdot
.32662 .53443 Mdot
.48626 .61782 Mdot
.42315 .32905 Mdot
.7075 .43913 Mdot
.64453 .58951 Mdot
.51566 .60797 Mdot
.49573 .64499 Mdot
.28138 .29957 Mdot
.70278 .3259 Mdot
.63731 .57271 Mdot
.64192 .77216 Mdot
.45936 .63851 Mdot
.47482 .34511 Mdot
.46048 .47276 Mdot
.42708 .42871 Mdot
.60943 .56238 Mdot
.6642 .54821 Mdot
.34457 .70282 Mdot
.43144 .39361 Mdot
.47883 .36093 Mdot
.31968 .60483 Mdot
.63797 .5589 Mdot
.32292 .57335 Mdot
.36708 .53079 Mdot
.65361 .54248 Mdot
.31983 .56287 Mdot
.68317 .46562 Mdot
.30162 .66908 Mdot
.45929 .63727 Mdot
.46944 .64475 Mdot
.66439 .58116 Mdot
.67567 .57618 Mdot
.64916 .55777 Mdot
.42885 .35276 Mdot
.34673 .57022 Mdot
.4157 .38496 Mdot
.4774 .34345 Mdot
.37743 .52996 Mdot
.30104 .5417 Mdot
.42108 .38857 Mdot
.69746 .61542 Mdot
.6556 .4189 Mdot
.66969 .55884 Mdot
.45377 .62636 Mdot
.21661 .56177 Mdot
.48785 .68745 Mdot
.4803 .37263 Mdot
.55151 .6461 Mdot
.35436 .5551 Mdot
.6816 .46247 Mdot
.65268 .41564 Mdot
.67184 .45643 Mdot
.44978 .68468 Mdot
.35094 .52644 Mdot
.42068 .78753 Mdot
.48222 .37924 Mdot
.53748 .51857 Mdot
.69211 .35265 Mdot
.43148 .76614 Mdot
.46257 .6217 Mdot
.4448 .38196 Mdot
.66423 .69502 Mdot
.35411 .28306 Mdot
.46527 .41464 Mdot
.45803 .43082 Mdot
.76373 .47773 Mdot
.48054 .31448 Mdot
.37371 .56581 Mdot
.32828 .74594 Mdot
.47108 .44051 Mdot
.30405 .61545 Mdot
.83864 .63539 Mdot
.48489 .37583 Mdot
.44548 .36219 Mdot
.46363 .38359 Mdot
.42684 .40339 Mdot
.37615 .56773 Mdot
.63064 .39507 Mdot
.46657 .6842 Mdot
.5514 .52805 Mdot
.46441 .63165 Mdot
.65181 .53258 Mdot
.56348 .47584 Mdot
.36323 .57112 Mdot
.67746 .46188 Mdot
.33149 .26109 Mdot
.37709 .77098 Mdot
.62976 .55903 Mdot
.32743 .37724 Mdot
.68137 .45489 Mdot
.47461 .42935 Mdot
.71151 .45948 Mdot
.6195 .5934 Mdot
.47529 .63426 Mdot
.45452 .44863 Mdot
.30063 .57986 Mdot
.36277 .55626 Mdot
.44498 .37633 Mdot
.75413 .32699 Mdot
.47302 .67135 Mdot
.46899 .70173 Mdot
.42663 .36945 Mdot
.45677 .43148 Mdot
.31631 .56963 Mdot
.66562 .56101 Mdot
.7235 .67324 Mdot
.6765 .44054 Mdot
.40541 .35859 Mdot
.42481 .40632 Mdot
.38637 .7637 Mdot
.46317 .67733 Mdot
.65394 .70921 Mdot
.4282 .37622 Mdot
.39131 .75543 Mdot
.42793 .37857 Mdot
.39158 .41134 Mdot
.6552 .5573 Mdot
.50532 .37299 Mdot
.44498 .34881 Mdot
.37465 .43588 Mdot
.45796 .64405 Mdot
.33729 .53906 Mdot
.3466 .60221 Mdot
.66504 .71055 Mdot
.4772 .66782 Mdot
.42122 .39221 Mdot
.46981 .67708 Mdot
.49063 .36005 Mdot
.43495 .36791 Mdot
.46324 .62202 Mdot
.32253 .57287 Mdot
.4248 .69302 Mdot
.56428 .40379 Mdot
.4281 .39983 Mdot
.44344 .44605 Mdot
.5938 .37029 Mdot
.57265 .83942 Mdot
.45957 .35598 Mdot
.35639 .55142 Mdot
.44797 .38679 Mdot
.46389 .65782 Mdot
.70341 .45749 Mdot
.34678 .54805 Mdot
.67064 .58024 Mdot
.64448 .54428 Mdot
.35007 .63018 Mdot
.64752 .67865 Mdot
.43429 .44418 Mdot
.35054 .49808 Mdot
.29202 .55995 Mdot
.85558 .52726 Mdot
.66871 .54465 Mdot
.69913 .41653 Mdot
.43246 .41166 Mdot
.52319 .60409 Mdot
.48569 .68549 Mdot
.49689 .09641 Mdot
.4253 .78588 Mdot
.7237 .44853 Mdot
.51253 .83181 Mdot
.66014 .69739 Mdot
.45795 .34724 Mdot
.66748 .42836 Mdot
.62653 .55449 Mdot
.49629 .38839 Mdot
.52045 .3646 Mdot
.61822 .45985 Mdot
.6873 .5951 Mdot
.46569 .67539 Mdot
.62913 .59012 Mdot
.67886 .47601 Mdot
.65303 .67713 Mdot
.36397 .56464 Mdot
.47576 .3824 Mdot
.4212 .46308 Mdot
.67044 .56933 Mdot
.66235 .68004 Mdot
.42291 .36654 Mdot
.36477 .55376 Mdot
.61651 .57664 Mdot
.44267 .4123 Mdot
.27544 .36132 Mdot
.32975 .52092 Mdot
.6427 .58249 Mdot
.48921 .40534 Mdot
.51606 .45156 Mdot
.66722 .58196 Mdot
.67303 .56583 Mdot
.44129 .37537 Mdot
.67622 .46362 Mdot
.42748 .34937 Mdot
.44553 .63984 Mdot
.656 .49011 Mdot
.46547 .65588 Mdot
.73968 .40351 Mdot
.38386 .3867 Mdot
.55874 .78242 Mdot
.33248 .59176 Mdot
.6685 .47404 Mdot
.18654 .46997 Mdot
.45581 .43419 Mdot
.55878 .1834 Mdot
.45413 .51739 Mdot
.82559 .40459 Mdot
.3423 .21117 Mdot
.69069 .44667 Mdot
.47815 .66401 Mdot
.44568 .36295 Mdot
.50775 .65775 Mdot
.66896 .43097 Mdot
.70812 .35396 Mdot
.48585 .41019 Mdot
.33929 .57861 Mdot
.4216 .35978 Mdot
.31055 .57287 Mdot
.44972 .3789 Mdot
.47018 .31339 Mdot
.72111 .46271 Mdot
.57744 .40519 Mdot
.47378 .42858 Mdot
.21921 .34034 Mdot
.52822 .58728 Mdot
.68119 .45002 Mdot
.41387 .37917 Mdot
.65063 .6944 Mdot
.4365 .61995 Mdot
.49907 .24266 Mdot
.65209 .56304 Mdot
.46368 .61923 Mdot
.31509 .55907 Mdot
.67769 .5542 Mdot
.67287 .70305 Mdot
.43427 .46749 Mdot
.69954 .42052 Mdot
.49261 .64887 Mdot
.47375 .37493 Mdot
.47612 .357 Mdot
.71341 .63314 Mdot
.59144 .69993 Mdot
.29209 .58945 Mdot
.18473 .57287 Mdot
.37806 .55697 Mdot
.67743 .43337 Mdot
.65347 .55712 Mdot
.46375 .35634 Mdot
.45559 .41447 Mdot
.61319 .55428 Mdot
.35182 .53794 Mdot
.69125 .56441 Mdot
.31601 .39512 Mdot
.67796 .58233 Mdot
.64027 .36202 Mdot
.34927 .54363 Mdot
.63759 .36653 Mdot
.67799 .47635 Mdot
.49674 .19439 Mdot
.57459 .29111 Mdot
.44466 .62873 Mdot
.64436 .35783 Mdot
.35063 .55916 Mdot
.4336 .38431 Mdot
.65958 .70125 Mdot
.6455 .68688 Mdot
.31098 .56007 Mdot
.64016 .54073 Mdot
.70205 .44908 Mdot
.44263 .36149 Mdot
.48665 .80151 Mdot
.35757 .66374 Mdot
.66855 .59383 Mdot
.52234 .34771 Mdot
.46277 .64554 Mdot
.44527 .3511 Mdot
.69514 .42422 Mdot
.48921 .64449 Mdot
.67285 .68158 Mdot
.32003 .69079 Mdot
.43575 .41779 Mdot
.34959 .74741 Mdot
.4833 .66508 Mdot
.64912 .77244 Mdot
.44891 .40421 Mdot
.45924 .63885 Mdot
.42377 .31683 Mdot
.4692 .75194 Mdot
.48015 .54268 Mdot
.62692 .20158 Mdot
.67642 .61241 Mdot
.64021 .54375 Mdot
.53473 .72719 Mdot
.73367 .43919 Mdot
.47425 .61823 Mdot
.65405 .67703 Mdot
.61717 .28088 Mdot
.45982 .64791 Mdot
.44851 .34296 Mdot
.48147 .36798 Mdot
.30073 .39642 Mdot
.50714 .53415 Mdot
.65881 .67651 Mdot
.26339 .62773 Mdot
.4246 .43041 Mdot
.47703 .32537 Mdot
.45951 .40792 Mdot
.31628 .59541 Mdot
.48487 .66972 Mdot
.16 .4432 Mdot
.46767 .67023 Mdot
.49323 .80868 Mdot
.65385 .58215 Mdot
.67459 .58606 Mdot
.47482 .36889 Mdot
.59317 .78241 Mdot
.48891 .23328 Mdot
.40609 .40957 Mdot
.70449 .56596 Mdot
.69453 .31976 Mdot
.463 .31799 Mdot
.36654 .58839 Mdot
.40984 .45404 Mdot
.31881 .51733 Mdot
.48315 .63149 Mdot
.69588 .44417 Mdot
.66033 .41498 Mdot
.49139 .6438 Mdot
.47848 .39278 Mdot
.69045 .52177 Mdot
.47502 .40901 Mdot
.43052 .37646 Mdot
.45763 .81386 Mdot
.6842 .41207 Mdot
.64719 .55535 Mdot
.6681 .44002 Mdot
.31891 .54328 Mdot
.80848 .27596 Mdot
.69619 .4321 Mdot
.34807 .49409 Mdot
.66326 .38678 Mdot
.64395 .36096 Mdot
.36446 .5575 Mdot
.67951 .47082 Mdot
.46353 .67189 Mdot
.82496 .38976 Mdot
.61666 .81068 Mdot
.497 .68462 Mdot
.44934 .40923 Mdot
.35519 .5804 Mdot
.30171 .58637 Mdot
.50006 .62713 Mdot
.35154 .57617 Mdot
.37823 .37908 Mdot
.42931 .39042 Mdot
.47487 .61853 Mdot
.36453 .68537 Mdot
.49649 .65003 Mdot
.29528 .67618 Mdot
.4169 .37217 Mdot
.34698 .54482 Mdot
.39394 .44401 Mdot
.34364 .60707 Mdot
.6508 .71052 Mdot
.49686 .38763 Mdot
.69562 .45854 Mdot
.51624 .52402 Mdot
.64498 .58197 Mdot
.55197 .64091 Mdot
.32528 .58642 Mdot
.4195 .67452 Mdot
.34113 .58392 Mdot
.35888 .58051 Mdot
.44565 .66347 Mdot
.31445 .54058 Mdot
.44491 .36139 Mdot
.69788 .63422 Mdot
.30425 .57134 Mdot
.47747 .65141 Mdot
.69303 .45568 Mdot
.32047 .56671 Mdot
.65601 .52873 Mdot
.43669 .40236 Mdot
.62932 .58405 Mdot
.72648 .44691 Mdot
.36929 .56293 Mdot
.68138 .4702 Mdot
.67157 .55391 Mdot
.6898 .41783 Mdot
.73463 .35047 Mdot
.49848 .63737 Mdot
.52995 .82684 Mdot
.55078 .40662 Mdot
.29941 .57797 Mdot
.60602 .53432 Mdot
.46249 .35763 Mdot
.43473 .40444 Mdot
.67131 .47173 Mdot
.29919 .58414 Mdot
.71018 .27443 Mdot
.4938 .47254 Mdot
.3099 .67409 Mdot
.50046 .65638 Mdot
.20743 .59563 Mdot
.35649 .72586 Mdot
.81872 .47148 Mdot
.51047 .38995 Mdot
.65977 .69775 Mdot
.48465 .39431 Mdot
.18351 .43876 Mdot
.70874 .4491 Mdot
.71995 .71605 Mdot
.50166 .41502 Mdot
.64402 .56363 Mdot
.45407 .39298 Mdot
.47487 .26169 Mdot
.40554 .44903 Mdot
.66299 .45242 Mdot
.51913 .68261 Mdot
.3354 .52507 Mdot
.68044 .45681 Mdot
.6421 .54685 Mdot
.64115 .30643 Mdot
.49626 .39525 Mdot
.42235 .43187 Mdot
.67261 .59652 Mdot
.34245 .579 Mdot
.64683 .53184 Mdot
.45965 .63698 Mdot
.695 .43687 Mdot
.42913 .41048 Mdot
.48691 .33632 Mdot
.69459 .54545 Mdot
.48508 .67053 Mdot
.67913 .56932 Mdot
.45374 .6616 Mdot
.66015 .69888 Mdot
.46127 .44178 Mdot
.66625 .60386 Mdot
.47649 .35355 Mdot
.17763 .48513 Mdot
.46633 .81839 Mdot
.27832 .48997 Mdot
.6447 .55419 Mdot
.62708 .34707 Mdot
.46954 .66003 Mdot
.44831 .65145 Mdot
.24256 .56813 Mdot
.52842 .23316 Mdot
.78483 .53594 Mdot
.29369 .28123 Mdot
.45976 .63618 Mdot
.46801 .65272 Mdot
.62296 .55791 Mdot
.30769 .5478 Mdot
.29219 .53715 Mdot
.68119 .55323 Mdot
.57604 .39424 Mdot
.34504 .56474 Mdot
.5731 .18586 Mdot
.635 .53019 Mdot
.51167 .38982 Mdot
.64403 .70913 Mdot
.69981 .44322 Mdot
.57529 .39563 Mdot
.46529 .26393 Mdot
.46483 .35347 Mdot
.30321 .73236 Mdot
.66267 .56212 Mdot
.62085 .42475 Mdot
.49353 .17249 Mdot
.48021 .41551 Mdot
.46126 .39551 Mdot
.47497 .39773 Mdot
.6812 .41112 Mdot
.19095 .4518 Mdot
.46438 .35203 Mdot
.58548 .41315 Mdot
.39711 .39383 Mdot
.53635 .28019 Mdot
.66903 .43759 Mdot
.32554 .6221 Mdot
.67549 .60979 Mdot
.45667 .76777 Mdot
.46419 .29624 Mdot
.45386 .64849 Mdot
.60153 .59471 Mdot
.47331 .63079 Mdot
.50665 .21853 Mdot
.57892 .29378 Mdot
.33659 .59789 Mdot
.45409 .35545 Mdot
.63932 .61503 Mdot
.33708 .58924 Mdot
.67741 .67472 Mdot
.88187 .40247 Mdot
.48337 .67533 Mdot
.56874 .85901 Mdot
.44829 .65325 Mdot
.64625 .69967 Mdot
.31444 .56722 Mdot
.34651 .3336 Mdot
.53628 .51802 Mdot
.32151 .56523 Mdot
.44552 .72216 Mdot
.38063 .56653 Mdot
.63646 .34989 Mdot
.34455 .52201 Mdot
.47566 .65545 Mdot
.42801 .62569 Mdot
.51694 .36707 Mdot
.46239 .36217 Mdot
.56781 .52288 Mdot
.40644 .49112 Mdot
.4598 .36014 Mdot
.63497 .56642 Mdot
.59997 .80681 Mdot
.63064 .62214 Mdot
.29765 .56287 Mdot
.47167 .68264 Mdot
.45942 .39507 Mdot
.4267 .39229 Mdot
.48075 .35344 Mdot
.16266 .50623 Mdot
.5802 .19031 Mdot
.43341 .36931 Mdot
.41126 .35132 Mdot
.64636 .54773 Mdot
.66332 .47986 Mdot
.2471 .32234 Mdot
.60579 .28311 Mdot
.45433 .42319 Mdot
.67055 .44378 Mdot
.70353 .41647 Mdot
.49208 .41088 Mdot
.49577 .79095 Mdot
.69528 .64632 Mdot
.47354 .37511 Mdot
.55304 .27339 Mdot
.60486 .55849 Mdot
.65029 .67485 Mdot
.67001 .57102 Mdot
.36987 .53851 Mdot
.6552 .68097 Mdot
.62678 .59975 Mdot
.34511 .32484 Mdot
.66616 .71125 Mdot
.44636 .74111 Mdot
.70203 .4615 Mdot
.46094 .41085 Mdot
.37734 .57664 Mdot
.61064 .56157 Mdot
.49165 .642 Mdot
.3346 .55188 Mdot
.43878 .61395 Mdot
.71289 .47073 Mdot
.60365 .41501 Mdot
.64555 .68153 Mdot
.4543 .64126 Mdot
.31954 .69138 Mdot
.66986 .44214 Mdot
.4438 .65394 Mdot
.59693 .77781 Mdot
.50023 .41024 Mdot
.43143 .22317 Mdot
.4037 .38403 Mdot
.78382 .35224 Mdot
.44918 .66211 Mdot
.66849 .71432 Mdot
.47996 .38779 Mdot
.66085 .5861 Mdot
.39331 .34114 Mdot
.45886 .41903 Mdot
.66542 .59247 Mdot
.43247 .37649 Mdot
.69083 .42207 Mdot
.3362 .51578 Mdot
.42281 .52122 Mdot
.23359 .70334 Mdot
.69505 .41984 Mdot
.68252 .69532 Mdot
.45815 .3559 Mdot
.71905 .33267 Mdot
.32261 .56774 Mdot
.46934 .42487 Mdot
.24329 .58048 Mdot
.3042 .55782 Mdot
.32785 .55011 Mdot
.41419 .40283 Mdot
.44203 .63622 Mdot
.65333 .58734 Mdot
.66909 .44493 Mdot
.83356 .47696 Mdot
.44655 .41755 Mdot
.44607 .39021 Mdot
.68154 .45567 Mdot
.46647 .6544 Mdot
.42575 .39475 Mdot
.56409 .64185 Mdot
.84651 .45796 Mdot
.44996 .67174 Mdot
.5031 .39065 Mdot
.38094 .2344 Mdot
.30647 .6073 Mdot
.57307 .84818 Mdot
.70338 .39149 Mdot
.65967 .54774 Mdot
.4652 .31308 Mdot
.55641 .11701 Mdot
.69689 .44565 Mdot
.44126 .77463 Mdot
.43045 .36344 Mdot
.45681 .38255 Mdot
.35832 .56258 Mdot
.41782 .38818 Mdot
.33779 .53385 Mdot
.26989 .7507 Mdot
.19092 .62614 Mdot
.33063 .58327 Mdot
.29551 .56323 Mdot
.26964 .59122 Mdot
.23375 .34509 Mdot
.31374 .554 Mdot
.50056 .37629 Mdot
.6517 .24264 Mdot
.45016 .46415 Mdot
.66672 .46961 Mdot
.71676 .4181 Mdot
.37211 .61232 Mdot
.63888 .73789 Mdot
.4358 .49173 Mdot
.43289 .2954 Mdot
.47356 .57209 Mdot
.44863 .63608 Mdot
.45998 .42435 Mdot
.64693 .67861 Mdot
.62681 .59273 Mdot
.4114 .44825 Mdot
.46533 .41124 Mdot
.30849 .57313 Mdot
.66753 .41388 Mdot
.43709 .63859 Mdot
.44257 .38625 Mdot
.69342 .56811 Mdot
.68053 .43797 Mdot
.30103 .57031 Mdot
.25248 .57135 Mdot
.66884 .42064 Mdot
.40238 .3401 Mdot
.45779 .37011 Mdot
.42346 .36728 Mdot
.47974 .31082 Mdot
.48352 .62722 Mdot
.61676 .53793 Mdot
.47757 .34119 Mdot
.40512 .77897 Mdot
.58689 .46078 Mdot
.4974 .34989 Mdot
.35121 .56497 Mdot
.48184 .68756 Mdot
.65595 .71228 Mdot
.66755 .32387 Mdot
.43926 .4196 Mdot
.57989 .19226 Mdot
.31173 .37437 Mdot
.65482 .68251 Mdot
.34524 .59282 Mdot
.67735 .46119 Mdot
.41952 .42485 Mdot
.6047 .2232 Mdot
.48056 .36815 Mdot
.54231 .43196 Mdot
.66252 .5551 Mdot
.45157 .63274 Mdot
.84084 .42636 Mdot
.6293 .59582 Mdot
.32869 .54785 Mdot
.63353 .19962 Mdot
.28621 .55997 Mdot
.33143 .5273 Mdot
.52601 .20724 Mdot
.4769 .626 Mdot
.53967 .11259 Mdot
.59897 .8255 Mdot
.45168 .33719 Mdot
.46352 .66139 Mdot
.31546 .57386 Mdot
.44434 .35188 Mdot
.29329 .55911 Mdot
.33621 .52844 Mdot
.4971 .38323 Mdot
.45825 .37496 Mdot
.56908 .4233 Mdot
.5309 .17453 Mdot
.6693 .45501 Mdot
.35632 .54349 Mdot
.26773 .40341 Mdot
.46144 .35004 Mdot
.48183 .37906 Mdot
.68334 .62745 Mdot
.66278 .45124 Mdot
.45439 .2738 Mdot
.42894 .37635 Mdot
.24119 .66663 Mdot
.44496 .44676 Mdot
.36829 .58977 Mdot
.44904 .67067 Mdot
.48527 .78792 Mdot
.61242 .55218 Mdot
.36051 .54338 Mdot
.70842 .43568 Mdot
.33004 .60407 Mdot
.31194 .50109 Mdot
.47759 .62833 Mdot
.3521 .55039 Mdot
.66497 .53637 Mdot
.48114 .63946 Mdot
.44536 .6564 Mdot
.65166 .25111 Mdot
.6804 .56475 Mdot
.70476 .46073 Mdot
.47056 .63428 Mdot
.27205 .35772 Mdot
.47948 .65665 Mdot
.28143 .40126 Mdot
.40577 .37004 Mdot
.59126 .41241 Mdot
.3777 .73239 Mdot
.4926 .31692 Mdot
.49168 .63145 Mdot
.66734 .43509 Mdot
.41933 .40633 Mdot
.3534 .57405 Mdot
.69754 .43335 Mdot
.51647 .62187 Mdot
.67495 .57064 Mdot
.32269 .58969 Mdot
.46173 .68355 Mdot
.35199 .54236 Mdot
.67328 .36479 Mdot
.63345 .49739 Mdot
.47248 .57919 Mdot
.5494 .50865 Mdot
.47584 .34849 Mdot
.40149 .57957 Mdot
.43443 .44541 Mdot
.46656 .41263 Mdot
.6436 .58298 Mdot
.59021 .37798 Mdot
.32191 .57306 Mdot
.84601 .43254 Mdot
.45279 .6388 Mdot
.27296 .70026 Mdot
.50199 .46168 Mdot
.4532 .43071 Mdot
.30367 .56865 Mdot
.28974 .54899 Mdot
.26276 .50491 Mdot
.61765 .54844 Mdot
.52119 .35742 Mdot
.38739 .37641 Mdot
.51294 .36237 Mdot
.45023 .66302 Mdot
.55884 .66568 Mdot
.64172 .53723 Mdot
.7167 .77048 Mdot
.66897 .56024 Mdot
.74016 .49889 Mdot
.31279 .54122 Mdot
.70473 .45345 Mdot
.48015 .37706 Mdot
.54332 .44517 Mdot
.36034 .58966 Mdot
.66699 .39845 Mdot
.69086 .46172 Mdot
.5281 .71603 Mdot
.47017 .62169 Mdot
.48569 .41696 Mdot
.49259 .39362 Mdot
.41336 .38573 Mdot
.40854 .37074 Mdot
.47529 .68051 Mdot
.45143 .34285 Mdot
.48977 .62196 Mdot
.2842 .3483 Mdot
.24117 .67086 Mdot
.61842 .60194 Mdot
.50911 .23828 Mdot
.30551 .58316 Mdot
.25371 .38449 Mdot
.53532 .39242 Mdot
.4784 .82151 Mdot
.71419 .31712 Mdot
.42314 .43691 Mdot
.62839 .54671 Mdot
.44395 .2492 Mdot
.62936 .60851 Mdot
.34128 .84831 Mdot
.67796 .50017 Mdot
.60412 .18534 Mdot
.44793 .35313 Mdot
.68807 .61887 Mdot
.5333 .41643 Mdot
.49715 .40285 Mdot
.68139 .49458 Mdot
.24983 .63179 Mdot
.38803 .71109 Mdot
.68846 .41349 Mdot
.43821 .40648 Mdot
.32776 .52615 Mdot
.44493 .35962 Mdot
.48512 .38342 Mdot
.43935 .35055 Mdot
.44803 .67213 Mdot
.44595 .453 Mdot
.43695 .34641 Mdot
.59812 .69518 Mdot
.60705 .35397 Mdot
.63282 .5925 Mdot
.27227 .51566 Mdot
.68874 .43265 Mdot
.31434 .57999 Mdot
.52614 .48958 Mdot
.44643 .62748 Mdot
.24176 .51694 Mdot
.42642 .35393 Mdot
.36438 .72177 Mdot
.46287 .6839 Mdot
.69876 .43727 Mdot
.66369 .70921 Mdot
.65945 .23541 Mdot
.61719 .59895 Mdot
.66484 .7122 Mdot
.64625 .58134 Mdot
.1969 .45762 Mdot
.30739 .57115 Mdot
.48039 .35113 Mdot
.46487 .64017 Mdot
.65233 .58955 Mdot
.58371 .35666 Mdot
.46324 .40524 Mdot
.64088 .55428 Mdot
.47588 .34692 Mdot
.60474 .43139 Mdot
.71652 .63617 Mdot
.63239 .60797 Mdot
.43609 .66203 Mdot
.47763 .64156 Mdot
.68664 .46564 Mdot
.31619 .58312 Mdot
.35448 .55742 Mdot
.48829 .64424 Mdot
.52627 .85566 Mdot
.4594 .4199 Mdot
.44894 .35108 Mdot
.40554 .77684 Mdot
.45083 .36451 Mdot
.64445 .32249 Mdot
.64307 .70064 Mdot
.31092 .58221 Mdot
.43979 .35333 Mdot
.42664 .39832 Mdot
.43374 .41512 Mdot
.6676 .36875 Mdot
.67059 .56647 Mdot
.42372 .42935 Mdot
.66126 .4374 Mdot
.5883 .76252 Mdot
.45444 .34924 Mdot
.4863 .33108 Mdot
.35117 .55492 Mdot
.20627 .64716 Mdot
.44427 .63506 Mdot
.63189 .56365 Mdot
.67389 .55842 Mdot
.71976 .41107 Mdot
.37104 .52363 Mdot
.65214 .71568 Mdot
.82293 .59003 Mdot
.66916 .69897 Mdot
.67775 .45151 Mdot
.7731 .45479 Mdot
.69245 .55466 Mdot
.62629 .56512 Mdot
.46088 .60593 Mdot
.42114 .35774 Mdot
.41226 .42167 Mdot
.44516 .77832 Mdot
.43272 .43263 Mdot
.69238 .4586 Mdot
.47339 .61653 Mdot
.34751 .55835 Mdot
.70187 .44183 Mdot
.45427 .66011 Mdot
.34496 .57766 Mdot
.49802 .41394 Mdot
.49441 .42202 Mdot
.33078 .55301 Mdot
.34297 .58625 Mdot
.46895 .37 Mdot
.58229 .69586 Mdot
.37051 .5336 Mdot
.351 .54741 Mdot
.64956 .67114 Mdot
.6198 .60229 Mdot
.40404 .46209 Mdot
.4642 .66342 Mdot
.42481 .36748 Mdot
.62584 .60674 Mdot
.66539 .45836 Mdot
.32788 .57185 Mdot
.42826 .39646 Mdot
.43686 .38811 Mdot
.67062 .44805 Mdot
.66801 .4176 Mdot
.70364 .44527 Mdot
.50946 .65428 Mdot
.40679 .38594 Mdot
.31578 .55357 Mdot
.47047 .62309 Mdot
.70352 .4165 Mdot
.71459 .45204 Mdot
.61614 .7002 Mdot
.46791 .3563 Mdot
.47634 .54664 Mdot
.77748 .24891 Mdot
.62867 .29792 Mdot
.65407 .71254 Mdot
.67722 .58693 Mdot
.61788 .38446 Mdot
.71036 .62192 Mdot
.47989 .67078 Mdot
.59422 .25311 Mdot
.66836 .47374 Mdot
.4872 .35789 Mdot
.44605 .44581 Mdot
.39392 .38808 Mdot
.68604 .43894 Mdot
.68061 .35111 Mdot
.2961 .58224 Mdot
.22482 .45625 Mdot
.68897 .43286 Mdot
.63088 .60674 Mdot
.66082 .60929 Mdot
.66872 .55963 Mdot
.47056 .43863 Mdot
.2547 .50597 Mdot
.26188 .38714 Mdot
.23318 .36581 Mdot
.46699 .61992 Mdot
.28578 .578 Mdot
.72923 .34612 Mdot
.32704 .55258 Mdot
.62608 .59406 Mdot
.68235 .4413 Mdot
.35838 .55487 Mdot
.49213 .65846 Mdot
.46721 .6508 Mdot
.67311 .57503 Mdot
.66339 .58076 Mdot
.63687 .58939 Mdot
.36347 .53181 Mdot
.31381 .54091 Mdot
.43662 .42261 Mdot
.33161 .56526 Mdot
.32546 .75364 Mdot
.72393 .43975 Mdot
.6489 .6127 Mdot
.47467 .66649 Mdot
.31359 .57606 Mdot
.457 .41123 Mdot
.78146 .50053 Mdot
.37764 .63069 Mdot
.6867 .41885 Mdot
.70691 .65759 Mdot
.38928 .86854 Mdot
.49411 .38672 Mdot
.46385 .67566 Mdot
.51572 .79254 Mdot
.4703 .39943 Mdot
.65587 .56438 Mdot
.17721 .45527 Mdot
.66919 .69089 Mdot
.4404 .34618 Mdot
.44169 .43276 Mdot
.44206 .65122 Mdot
.67713 .38167 Mdot
.43253 .4244 Mdot
.32426 .71987 Mdot
.43316 .63423 Mdot
.6224 .54902 Mdot
.85285 .46781 Mdot
.64596 .51355 Mdot
.56398 .37209 Mdot
.64669 .69596 Mdot
.48758 .40206 Mdot
.63424 .57151 Mdot
.67946 .42016 Mdot
.63605 .58318 Mdot
.34171 .59551 Mdot
.6334 .59059 Mdot
.44768 .38972 Mdot
.31595 .55055 Mdot
.48218 .66638 Mdot
.33162 .74803 Mdot
.5986 .71069 Mdot
.6617 .58573 Mdot
.65023 .66839 Mdot
.45327 .34621 Mdot
.47648 .28894 Mdot
.38643 .34917 Mdot
.45433 .35106 Mdot
.47273 .62954 Mdot
.30199 .56732 Mdot
.49557 .66858 Mdot
.46241 .32616 Mdot
.22751 .6297 Mdot
.44748 .65449 Mdot
.42831 .73634 Mdot
.68032 .45446 Mdot
.5725 .40892 Mdot
.45421 .41672 Mdot
.46605 .63595 Mdot
.4074 .38381 Mdot
.30059 .54103 Mdot
.5382 .56004 Mdot
.59531 .76905 Mdot
.46537 .64111 Mdot
.7338 .29055 Mdot
.52459 .56579 Mdot
.40798 .45625 Mdot
.46269 .63477 Mdot
.20961 .50796 Mdot
.6502 .70254 Mdot
.67568 .44249 Mdot
.69975 .41508 Mdot
.69027 .41717 Mdot
.44023 .43784 Mdot
.52662 .38802 Mdot
.71122 .45511 Mdot
.43583 .64772 Mdot
.66151 .44973 Mdot
.55616 .43948 Mdot
.7263 .28396 Mdot
.70588 .4355 Mdot
.44614 .40797 Mdot
.48306 .32689 Mdot
.60417 .35461 Mdot
.6172 .58215 Mdot
.55404 .1829 Mdot
.35733 .41591 Mdot
.46555 .36122 Mdot
.43575 .47043 Mdot
.32253 .59325 Mdot
.56128 .79628 Mdot
.47167 .4736 Mdot
.70626 .63734 Mdot
.30259 .544 Mdot
.66199 .51627 Mdot
.31266 .5821 Mdot
.48998 .37253 Mdot
.43536 .36621 Mdot
.3097 .52181 Mdot
.5359 .67858 Mdot
.51571 .76017 Mdot
.8101 .40753 Mdot
.35607 .54898 Mdot
.45819 .64387 Mdot
.48242 .6767 Mdot
.45987 .62109 Mdot
.62605 .53714 Mdot
.37002 .55989 Mdot
.40827 .40405 Mdot
.65073 .54459 Mdot
.46242 .42058 Mdot
.47686 .63567 Mdot
.83945 .42074 Mdot
.35005 .55596 Mdot
.47379 .37813 Mdot
.61445 .81092 Mdot
.66036 .57505 Mdot
.67168 .43812 Mdot
.61038 .43192 Mdot
.64609 .52512 Mdot
.49585 .64107 Mdot
.29086 .54087 Mdot
.51646 .67534 Mdot
.4921 .50326 Mdot
.4508 .46207 Mdot
.50391 .37504 Mdot
.83786 .50173 Mdot
.63726 .75508 Mdot
.45545 .44121 Mdot
.64081 .5473 Mdot
.61358 .5818 Mdot
.43087 .39895 Mdot
.36577 .56282 Mdot
.71248 .42774 Mdot
.66096 .43472 Mdot
.40839 .33724 Mdot
.5403 .5182 Mdot
.57673 .42097 Mdot
.42222 .38936 Mdot
.50448 .32658 Mdot
.67704 .56384 Mdot
.66962 .7079 Mdot
.40281 .76386 Mdot
.7101 .441 Mdot
.42925 .365 Mdot
.41627 .70737 Mdot
.32705 .5326 Mdot
.63314 .58865 Mdot
.48936 .63348 Mdot
.69552 .36214 Mdot
.65311 .52986 Mdot
.43049 .39715 Mdot
.42595 .3954 Mdot
.44283 .65165 Mdot
.3679 .59007 Mdot
.68468 .44136 Mdot
.65267 .5463 Mdot
.71103 .44378 Mdot
.31934 .5412 Mdot
.34585 .55606 Mdot
.44867 .4648 Mdot
.48564 .31727 Mdot
.67051 .5767 Mdot
.42795 .33117 Mdot
.63063 .60233 Mdot
.70036 .38021 Mdot
.48005 .68555 Mdot
.49433 .39497 Mdot
.28228 .55734 Mdot
.47909 .63435 Mdot
.46187 .37933 Mdot
.84846 .55986 Mdot
.46251 .42683 Mdot
.62516 .53003 Mdot
.22892 .64283 Mdot
.6633 .44252 Mdot
.35885 .48893 Mdot
.37797 .32338 Mdot
.4495 .36665 Mdot
.64957 .61019 Mdot
.39063 .34509 Mdot
.44603 .65553 Mdot
.30152 .54988 Mdot
.5123 .87632 Mdot
.47999 .65253 Mdot
.44161 .35904 Mdot
.69621 .43675 Mdot
.28777 .55067 Mdot
.66238 .68439 Mdot
.41732 .78004 Mdot
.40095 .43603 Mdot
.49995 .41617 Mdot
.42999 .35465 Mdot
.24948 .31269 Mdot
.63149 .56896 Mdot
.31443 .57488 Mdot
.45258 .66577 Mdot
.4892 .6516 Mdot
.66579 .55902 Mdot
.36634 .70555 Mdot
.56938 .56811 Mdot
.63762 .13353 Mdot
.661 .59468 Mdot
.66746 .46534 Mdot
.55608 .49077 Mdot
.63689 .60271 Mdot
.63945 .5629 Mdot
.67436 .55667 Mdot
.405 .74753 Mdot
.34745 .57265 Mdot
.43595 .38645 Mdot
.37538 .53422 Mdot
.48641 .40454 Mdot
.52449 .31129 Mdot
.48689 .6378 Mdot
.30364 .54674 Mdot
.84688 .52642 Mdot
.40827 .49193 Mdot
.46308 .39916 Mdot
.7468 .36817 Mdot
.38024 .3671 Mdot
.65679 .34659 Mdot
.38047 .42022 Mdot
.65443 .58376 Mdot
.50138 .4493 Mdot
.4957 .33773 Mdot
.32271 .74826 Mdot
.4724 .66721 Mdot
.6454 .69878 Mdot
.42368 .44086 Mdot
.39139 .41008 Mdot
.30294 .53539 Mdot
.3585 .55389 Mdot
.71017 .45559 Mdot
.59109 .47584 Mdot
.47935 .66783 Mdot
.62439 .49181 Mdot
.46164 .36438 Mdot
.54021 .65371 Mdot
.25362 .54796 Mdot
.46335 .37959 Mdot
.63438 .2335 Mdot
.24813 .51332 Mdot
.43589 .42713 Mdot
.20522 .46846 Mdot
.46894 .65535 Mdot
.23859 .65009 Mdot
.42693 .33765 Mdot
.65477 .56562 Mdot
.30588 .54802 Mdot
.32644 .59351 Mdot
.70222 .42721 Mdot
.4243 .81447 Mdot
.49586 .63632 Mdot
.30904 .54311 Mdot
.47186 .4025 Mdot
.48595 .62996 Mdot
.64767 .68051 Mdot
.49453 .33921 Mdot
.57869 .23931 Mdot
.33517 .56373 Mdot
.41295 .34847 Mdot
.30009 .63907 Mdot
.59171 .44153 Mdot
.48921 .15901 Mdot
.45542 .6237 Mdot
.70746 .44359 Mdot
.39224 .44871 Mdot
.82193 .58741 Mdot
.39578 .39592 Mdot
.58663 .399 Mdot
.36191 .61249 Mdot
.7033 .45725 Mdot
.47197 .39229 Mdot
.42802 .41762 Mdot
.53224 .51395 Mdot
.66934 .4152 Mdot
.4771 .41728 Mdot
.47931 .45695 Mdot
.34203 .57845 Mdot
.64355 .69921 Mdot
.34106 .56297 Mdot
.44949 .40862 Mdot
.52564 .39712 Mdot
.35881 .56668 Mdot
.7943 .44986 Mdot
.65479 .4431 Mdot
.44537 .63293 Mdot
.52108 .3493 Mdot
.41125 .36225 Mdot
.26757 .26718 Mdot
.65054 .71009 Mdot
.18899 .42299 Mdot
.67714 .53934 Mdot
.43034 .71063 Mdot
.69461 .55069 Mdot
.63966 .20862 Mdot
.34348 .74994 Mdot
.40455 .43201 Mdot
.55055 .25977 Mdot
.21431 .42896 Mdot
.49929 .65336 Mdot
.31208 .30745 Mdot
.46243 .36183 Mdot
.48611 .3887 Mdot
.62204 .55577 Mdot
.35293 .70801 Mdot
.50557 .78956 Mdot
.54719 .52638 Mdot
.68581 .44533 Mdot
.32896 .53728 Mdot
.44743 .37962 Mdot
.5812 .59405 Mdot
.64047 .59723 Mdot
.52655 .60762 Mdot
.47556 .38392 Mdot
.50395 .81043 Mdot
.42124 .74333 Mdot
.48276 .62535 Mdot
.67014 .5973 Mdot
.65111 .52626 Mdot
.48724 .37522 Mdot
.49513 .64367 Mdot
.43696 .4245 Mdot
.53619 .58372 Mdot
.41478 .34027 Mdot
.69969 .43076 Mdot
.46463 .34398 Mdot
.49746 .52505 Mdot
.5487 .15368 Mdot
.43041 .48103 Mdot
.36327 .57377 Mdot
.6303 .53404 Mdot
.66917 .56475 Mdot
.35559 .55391 Mdot
.66775 .56516 Mdot
.23266 .46774 Mdot
.34061 .43392 Mdot
.68634 .44915 Mdot
.53115 .36553 Mdot
.69596 .42709 Mdot
.64627 .70258 Mdot
.46737 .35819 Mdot
.8226 .60506 Mdot
.66307 .59126 Mdot
.18566 .53301 Mdot
.48119 .6579 Mdot
.64732 .70399 Mdot
.39663 .3905 Mdot
.7704 .45402 Mdot
.62017 .58416 Mdot
.63875 .52061 Mdot
.43462 .41696 Mdot
.35505 .56174 Mdot
.42653 .41405 Mdot
.38062 .38968 Mdot
.66268 .71226 Mdot
.42209 .35748 Mdot
.45446 .66026 Mdot
.37019 .54617 Mdot
.68145 .24869 Mdot
.60989 .56289 Mdot
.47494 .35748 Mdot
.47239 .40116 Mdot
.29153 .55209 Mdot
.40064 .37323 Mdot
.49174 .66193 Mdot
.41852 .10364 Mdot
.67925 .45417 Mdot
.67317 .69964 Mdot
.62207 .53062 Mdot
.42345 .43561 Mdot
.42258 .39579 Mdot
.83949 .48743 Mdot
.56975 .74443 Mdot
.45304 .65177 Mdot
.38803 .3562 Mdot
.64652 .54856 Mdot
.69769 .43792 Mdot
.43617 .62904 Mdot
.42284 .3701 Mdot
.4818 .38325 Mdot
.7009 .43332 Mdot
.66835 .25791 Mdot
.70582 .64279 Mdot
.46265 .61958 Mdot
.50277 .4496 Mdot
.77945 .52165 Mdot
.45917 .41953 Mdot
.80155 .51653 Mdot
.35016 .54873 Mdot
.46211 .63051 Mdot
.2372 .34939 Mdot
.4783 .34734 Mdot
.48715 .66806 Mdot
.47742 .66781 Mdot
.45342 .33532 Mdot
.37254 .5281 Mdot
.35961 .53344 Mdot
.34808 .53985 Mdot
.23244 .67717 Mdot
.54996 .31093 Mdot
.63834 .59032 Mdot
.4678 .65482 Mdot
.63346 .61071 Mdot
.7026 .41417 Mdot
.58477 .46428 Mdot
.62192 .59767 Mdot
.32234 .59271 Mdot
.6607 .60993 Mdot
.42983 .41534 Mdot
.48224 .66753 Mdot
.62569 .56716 Mdot
.43407 .442 Mdot
.42131 .28499 Mdot
.49602 .56024 Mdot
.71445 .43517 Mdot
.68152 .39252 Mdot
.43861 .37295 Mdot
.65676 .71198 Mdot
.47097 .37022 Mdot
.47275 .61767 Mdot
.50768 .50965 Mdot
.42909 .43773 Mdot
.66651 .5822 Mdot
.3774 .45667 Mdot
.61553 .55934 Mdot
.3843 .38161 Mdot
.44804 .40629 Mdot
.46924 .415 Mdot
.43297 .42517 Mdot
.41327 .72865 Mdot
.50088 .6551 Mdot
.42135 .28163 Mdot
.66287 .62073 Mdot
.32592 .56113 Mdot
.3085 .59564 Mdot
.77829 .55631 Mdot
.67402 .70517 Mdot
.46505 .66269 Mdot
.4547 .42027 Mdot
.63311 .52227 Mdot
.83662 .41332 Mdot
.80894 .47339 Mdot
.7461 .40266 Mdot
.63316 .55259 Mdot
.35825 .57916 Mdot
.62934 .59165 Mdot
.48978 .38711 Mdot
.48312 .34125 Mdot
.65414 .22288 Mdot
.43591 .60325 Mdot
.68326 .44038 Mdot
.47322 .41365 Mdot
.56024 .36657 Mdot
.64646 .54771 Mdot
.67778 .56229 Mdot
.46401 .42448 Mdot
.36173 .54215 Mdot
.40863 .1628 Mdot
.48558 .62728 Mdot
.41517 .26854 Mdot
.38777 .51 Mdot
.25591 .65116 Mdot
.49152 .64781 Mdot
.48365 .56747 Mdot
.65914 .53954 Mdot
.36561 .47507 Mdot
.32908 .55821 Mdot
.68367 .43681 Mdot
.49077 .34536 Mdot
.32225 .5918 Mdot
.6826 .55634 Mdot
.30499 .57857 Mdot
.48956 .36683 Mdot
.49949 .65772 Mdot
.66523 .551 Mdot
.44947 .6843 Mdot
.30646 .52296 Mdot
.67999 .42409 Mdot
.5699 .41071 Mdot
.34079 .28843 Mdot
.24581 .51454 Mdot
.42339 .42906 Mdot
.64823 .64263 Mdot
.40727 .38985 Mdot
.3184 .52977 Mdot
.45216 .41584 Mdot
.38165 .60903 Mdot
.67361 .58742 Mdot
.41398 .34756 Mdot
.44473 .34464 Mdot
.31288 .33511 Mdot
.46388 .39124 Mdot
.42693 .34736 Mdot
.43287 .4279 Mdot
.39081 .51894 Mdot
.42459 .45547 Mdot
.3514 .56834 Mdot
.43351 .77192 Mdot
.63941 .56534 Mdot
.71588 .43847 Mdot
.66884 .42236 Mdot
.58626 .40516 Mdot
.57535 .4033 Mdot
.36912 .71112 Mdot
.34128 .56909 Mdot
.46025 .66713 Mdot
.43798 .42499 Mdot
.26771 .31793 Mdot
.73072 .44333 Mdot
.66224 .54306 Mdot
.61442 .54731 Mdot
.47683 .31159 Mdot
.25281 .3071 Mdot
.40115 .36264 Mdot
.42364 .78897 Mdot
.41273 .33568 Mdot
.4709 .4236 Mdot
.64504 .52733 Mdot
.58474 .4288 Mdot
.42391 .42977 Mdot
.30132 .53647 Mdot
.68026 .43464 Mdot
.44971 .48551 Mdot
.7104 .55517 Mdot
.51718 .58593 Mdot
.33428 .34259 Mdot
.40482 .39291 Mdot
.65755 .54851 Mdot
.32319 .58951 Mdot
.3923 .76493 Mdot
.46884 .62346 Mdot
.37448 .73535 Mdot
.28196 .3652 Mdot
.78142 .4079 Mdot
.68098 .43778 Mdot
.65993 .2547 Mdot
.44723 .38885 Mdot
.63016 .53307 Mdot
.49603 .37765 Mdot
.83407 .40863 Mdot
.67779 .47001 Mdot
.36944 .58274 Mdot
.45743 .64609 Mdot
.30412 .53885 Mdot
.28357 .48897 Mdot
.45509 .57754 Mdot
.6004 .6324 Mdot
.61744 .59753 Mdot
.46268 .27297 Mdot
.31022 .55807 Mdot
.4264 .3829 Mdot
.68851 .16893 Mdot
.34924 .54745 Mdot
.3537 .53961 Mdot
.68243 .38565 Mdot
.73613 .39022 Mdot
.414 .32509 Mdot
.30087 .57615 Mdot
.65734 .61753 Mdot
.66691 .44624 Mdot
.42058 .41541 Mdot
.4295 .42291 Mdot
.35782 .56173 Mdot
.62356 .59185 Mdot
.42607 .25993 Mdot
.65958 .58256 Mdot
.33955 .58111 Mdot
.65245 .57652 Mdot
.60301 .58611 Mdot
.62996 .56092 Mdot
.40914 .36251 Mdot
.44945 .41875 Mdot
.71728 .53864 Mdot
.34567 .55614 Mdot
.41914 .39597 Mdot
.43182 .36923 Mdot
.31367 .55602 Mdot
.6928 .56717 Mdot
.28617 .30051 Mdot
.45457 .35637 Mdot
.43919 .40212 Mdot
.70651 .45177 Mdot
.68324 .53809 Mdot
.71244 .66887 Mdot
.41903 .40643 Mdot
.65893 .44724 Mdot
.36267 .52984 Mdot
.46972 .37204 Mdot
.557 .44249 Mdot
.6093 .59212 Mdot
.46781 .34336 Mdot
.6605 .68195 Mdot
.41797 .42971 Mdot
.42611 .16416 Mdot
.46967 .35258 Mdot
.31588 .57241 Mdot
.30382 .55593 Mdot
.65423 .39779 Mdot
.33039 .54534 Mdot
.64566 .6901 Mdot
.47837 .63754 Mdot
.80122 .37138 Mdot
.64842 .68166 Mdot
.46439 .42905 Mdot
.59873 .82579 Mdot
.44075 .32875 Mdot
.42379 .43999 Mdot
.21818 .3638 Mdot
.64922 .68239 Mdot
.30498 .56608 Mdot
.52324 .69324 Mdot
.41457 .33318 Mdot
.48973 .63318 Mdot
.50439 .35886 Mdot
.45824 .33918 Mdot
.2899 .69444 Mdot
.22703 .58184 Mdot
.46329 .61524 Mdot
.4015 .46415 Mdot
.41868 .40567 Mdot
.6231 .73869 Mdot
.46231 .40726 Mdot
.70503 .43225 Mdot
.34994 .53848 Mdot
.64602 .60206 Mdot
.6773 .45715 Mdot
.4558 .36502 Mdot
.68813 .43677 Mdot
.63355 .58749 Mdot
.4691 .62902 Mdot
.47836 .36354 Mdot
.66417 .46674 Mdot
.68606 .44385 Mdot
.40992 .38904 Mdot
.30496 .54671 Mdot
.41431 .4883 Mdot
.46827 .37374 Mdot
.42842 .38754 Mdot
.35439 .55754 Mdot
.74514 .73954 Mdot
.49135 .38086 Mdot
.47885 .54942 Mdot
.36951 .58055 Mdot
.64045 .6833 Mdot
.62398 .57739 Mdot
.46583 .33868 Mdot
.48439 .63168 Mdot
.48314 .63477 Mdot
.67698 .59236 Mdot
.29869 .54197 Mdot
.61722 .57988 Mdot
.40795 .47488 Mdot
.4894 .31931 Mdot
.46424 .33001 Mdot
.48894 .86788 Mdot
.63886 .21771 Mdot
.36493 .56689 Mdot
.64476 .53637 Mdot
.55101 .52572 Mdot
.46374 .6549 Mdot
.66524 .60846 Mdot
.29044 .54363 Mdot
.3494 .58472 Mdot
.30689 .58408 Mdot
.70229 .45467 Mdot
.65659 .53337 Mdot
.36809 .5883 Mdot
.35805 .53862 Mdot
.43246 .41593 Mdot
.41826 .40321 Mdot
.2984 .6129 Mdot
.61802 .34413 Mdot
.68624 .42311 Mdot
.66067 .55623 Mdot
.22235 .28887 Mdot
.47133 .61726 Mdot
.31532 .33492 Mdot
.42725 .43836 Mdot
.88005 .37773 Mdot
.40183 .3588 Mdot
.46917 .40482 Mdot
.36899 .53636 Mdot
.68097 .47478 Mdot
.68371 .42745 Mdot
.30952 .55693 Mdot
.29211 .53687 Mdot
.70747 .43625 Mdot
.70651 .30818 Mdot
.73552 .28802 Mdot
.3812 .75217 Mdot
.31566 .56618 Mdot
.35459 .28326 Mdot
.4959 .64254 Mdot
.32646 .51539 Mdot
.45071 .61914 Mdot
.64089 .56239 Mdot
.66878 .54289 Mdot
.44201 .64819 Mdot
.43693 .41812 Mdot
.62907 .58149 Mdot
.4253 .4594 Mdot
.71696 .29993 Mdot
.47056 .21586 Mdot
.55467 .73178 Mdot
.44076 .44617 Mdot
.49187 .78938 Mdot
.53032 .78016 Mdot
.44371 .36907 Mdot
.49876 .48315 Mdot
.68451 .43877 Mdot
.36152 .51091 Mdot
.49332 .65888 Mdot
.47618 .16042 Mdot
.45729 .42001 Mdot
.32274 .57499 Mdot
.46996 .66665 Mdot
.63471 .42523 Mdot
.31973 .71367 Mdot
.48169 .40956 Mdot
.58219 .11809 Mdot
.37135 .51596 Mdot
.64707 .60198 Mdot
.5183 .84147 Mdot
.37718 .53957 Mdot
.69115 .39147 Mdot
.67589 .54584 Mdot
.81493 .4482 Mdot
.31546 .58046 Mdot
.68459 .56878 Mdot
.32342 .54075 Mdot
.69897 .42677 Mdot
.34182 .52034 Mdot
.6625 .54759 Mdot
.4688 .39095 Mdot
.66454 .56453 Mdot
.68518 .42229 Mdot
.62384 .53815 Mdot
.49569 .65087 Mdot
.65004 .7067 Mdot
.4718 .64599 Mdot
.59286 .44985 Mdot
.22472 .60603 Mdot
.45161 .63219 Mdot
.63043 .46102 Mdot
.45259 .44224 Mdot
.36572 .59367 Mdot
.6606 .59775 Mdot
.66271 .61972 Mdot
.57281 .48162 Mdot
.32196 .55923 Mdot
.66413 .55457 Mdot
.27635 .36444 Mdot
.67677 .79006 Mdot
.52628 .38375 Mdot
.55187 .29499 Mdot
.31446 .55815 Mdot
.67949 .57138 Mdot
.40593 .77615 Mdot
.30949 .59084 Mdot
.65981 .59485 Mdot
.46248 .63739 Mdot
.4901 .65062 Mdot
.45874 .42401 Mdot
.43019 .60949 Mdot
.65784 .6059 Mdot
.48406 .75465 Mdot
.32991 .53159 Mdot
.63264 .42605 Mdot
.70022 .42277 Mdot
.63765 .55975 Mdot
.50181 .34494 Mdot
.27262 .574 Mdot
.61941 .60479 Mdot
.54082 .23705 Mdot
.20682 .31513 Mdot
.66406 .55822 Mdot
.34724 .53677 Mdot
.32797 .57411 Mdot
.38264 .35958 Mdot
.54132 .51501 Mdot
.61693 .57023 Mdot
.80989 .63223 Mdot
.58661 .38947 Mdot
.66076 .69913 Mdot
.64606 .75862 Mdot
.4248 .43184 Mdot
.40882 .37837 Mdot
.46153 .65461 Mdot
.45622 .39713 Mdot
.36128 .53814 Mdot
.40502 .41365 Mdot
.48282 .6729 Mdot
.65872 .54057 Mdot
.47482 .36205 Mdot
.66559 .43961 Mdot
.47398 .61395 Mdot
.44022 .64252 Mdot
.64147 .57579 Mdot
.30289 .57906 Mdot
.58372 .56269 Mdot
.66428 .57973 Mdot
.40537 .39894 Mdot
.65597 .68495 Mdot
.48013 .35268 Mdot
.64136 .26056 Mdot
.29255 .57401 Mdot
.63368 .59747 Mdot
.34332 .59327 Mdot
.47448 .64949 Mdot
.67338 .60912 Mdot
.45581 .40624 Mdot
.65823 .59306 Mdot
.71559 .5986 Mdot
.6783 .28067 Mdot
.29931 .5405 Mdot
.69903 .55131 Mdot
.35099 .53652 Mdot
.66219 .69969 Mdot
.64078 .28159 Mdot
.67788 .446 Mdot
.64528 .55166 Mdot
.61888 .20617 Mdot
.6677 .58366 Mdot
.46256 .38957 Mdot
.45646 .37815 Mdot
.62287 .55603 Mdot
.67227 .46186 Mdot
.20741 .64525 Mdot
.4648 .55929 Mdot
.30595 .5719 Mdot
.36565 .45801 Mdot
.26671 .2416 Mdot
.43187 .63869 Mdot
.45819 .65533 Mdot
.39152 .37303 Mdot
.45441 .43017 Mdot
.43862 .64293 Mdot
.4706 .68259 Mdot
.71283 .44101 Mdot
.67212 .55243 Mdot
.3863 .55054 Mdot
.43483 .62092 Mdot
.37908 .34411 Mdot
.56499 .38033 Mdot
.40728 .33328 Mdot
.49811 .433 Mdot
.47086 .44072 Mdot
.60103 .4305 Mdot
.46355 .67734 Mdot
.43753 .375 Mdot
.41561 .44887 Mdot
.45859 .63584 Mdot
.6984 .42707 Mdot
.25382 .60736 Mdot
.65345 .57108 Mdot
.84499 .62769 Mdot
.47112 .34898 Mdot
.46772 .38481 Mdot
.46775 .62007 Mdot
.64261 .7411 Mdot
.34541 .58365 Mdot
.29382 .5709 Mdot
.63078 .57089 Mdot
.57646 .48021 Mdot
.39928 .38517 Mdot
.44131 .3705 Mdot
.64983 .55606 Mdot
.65189 .70909 Mdot
.53384 .73061 Mdot
.43788 .38985 Mdot
.47281 .66477 Mdot
.60533 .60154 Mdot
.46577 .67912 Mdot
.49486 .38573 Mdot
.46064 .38852 Mdot
.40778 .36377 Mdot
.45462 .43068 Mdot
.44038 .62675 Mdot
.44095 .37831 Mdot
.49339 .33097 Mdot
.29679 .56287 Mdot
.40808 .36999 Mdot
.59368 .40698 Mdot
.44235 .40767 Mdot
.67096 .43111 Mdot
.61251 .62659 Mdot
.46957 .41567 Mdot
.41135 .36531 Mdot
.4696 .55789 Mdot
.47533 .39266 Mdot
.46915 .61756 Mdot
.32714 .5653 Mdot
.46747 .65426 Mdot
.45073 .66447 Mdot
.64625 .61756 Mdot
.71233 .44361 Mdot
.40488 .42684 Mdot
.68423 .41733 Mdot
.50744 .41311 Mdot
.49041 .36695 Mdot
.58988 .55938 Mdot
.42532 .78904 Mdot
.71173 .6273 Mdot
.45401 .40829 Mdot
.63426 .56682 Mdot
.64214 .60112 Mdot
.54622 .25135 Mdot
.40982 .45439 Mdot
.43698 .63312 Mdot
.46589 .63638 Mdot
.63918 .3147 Mdot
.29687 .7028 Mdot
.67891 .42504 Mdot
.57086 .52374 Mdot
.46342 .44277 Mdot
.43269 .38287 Mdot
.49014 .33524 Mdot
.62313 .60013 Mdot
.66754 .71098 Mdot
.66367 .54336 Mdot
.64422 .71411 Mdot
.47319 .67925 Mdot
.41082 .41951 Mdot
.48226 .20472 Mdot
.36212 .55984 Mdot
.32785 .5649 Mdot
.43712 .64759 Mdot
.61413 .57106 Mdot
.37746 .36878 Mdot
.52132 .88096 Mdot
.34445 .50779 Mdot
.71193 .45976 Mdot
.4423 .36551 Mdot
.63804 .57392 Mdot
.36302 .55308 Mdot
.6591 .43412 Mdot
.43951 .34998 Mdot
.67897 .6152 Mdot
.44853 .41498 Mdot
.21135 .43194 Mdot
.29866 .56219 Mdot
.83749 .40503 Mdot
.28658 .55909 Mdot
.47265 .61269 Mdot
.45104 .64118 Mdot
.46129 .3812 Mdot
.50005 .86027 Mdot
.37656 .56946 Mdot
.42561 .63424 Mdot
.68212 .47249 Mdot
.67251 .70244 Mdot
.6926 .46768 Mdot
.63871 .60448 Mdot
.67955 .43661 Mdot
.67401 .55989 Mdot
.62982 .31883 Mdot
.36263 .50468 Mdot
.6781 .45549 Mdot
.61284 .70986 Mdot
.44269 .45364 Mdot
.70429 .41767 Mdot
.48868 .32258 Mdot
.37239 .48127 Mdot
.65004 .5595 Mdot
.67061 .46047 Mdot
.42609 .38629 Mdot
.47062 .17642 Mdot
.44832 .65147 Mdot
.43759 .62829 Mdot
.44769 .45609 Mdot
.67488 .55499 Mdot
.30453 .52808 Mdot
.4992 .50275 Mdot
.64037 .69681 Mdot
.44047 .37328 Mdot
.41323 .42356 Mdot
.30391 .59396 Mdot
.28395 .57634 Mdot
.45912 .38633 Mdot
.28355 .33776 Mdot
.44609 .38502 Mdot
.489 .63758 Mdot
.34661 .5851 Mdot
.32808 .57101 Mdot
.66358 .60318 Mdot
.32189 .53097 Mdot
.50062 .43108 Mdot
.40859 .61364 Mdot
.42496 .32713 Mdot
.47963 .64972 Mdot
.49536 .51901 Mdot
.61327 .55125 Mdot
.52325 .17955 Mdot
.29666 .58798 Mdot
.41993 .35834 Mdot
.33769 .5314 Mdot
.70064 .44872 Mdot
.34295 .55742 Mdot
.37022 .56653 Mdot
.46126 .36912 Mdot
.48681 .40305 Mdot
.64895 .68554 Mdot
.54697 .51245 Mdot
.3159 .53696 Mdot
.44505 .37662 Mdot
.4314 .33243 Mdot
.44516 .34005 Mdot
.51305 .54558 Mdot
.36625 .56769 Mdot
.30137 .40007 Mdot
.55717 .22913 Mdot
.30959 .54142 Mdot
.40139 .17853 Mdot
.66669 .68883 Mdot
.67359 .70411 Mdot
.42974 .62573 Mdot
.43675 .39008 Mdot
.62837 .54478 Mdot
.48902 .38344 Mdot
.44659 .46691 Mdot
.48331 .3828 Mdot
.66524 .45904 Mdot
.40959 .4361 Mdot
.65635 .70184 Mdot
.66667 .57596 Mdot
.44732 .35206 Mdot
.47693 .36482 Mdot
.67565 .70372 Mdot
.29091 .5788 Mdot
.33455 .58894 Mdot
.80477 .49904 Mdot
.69392 .44912 Mdot
.47199 .62755 Mdot
.44709 .42283 Mdot
.63284 .5673 Mdot
.66522 .56707 Mdot
.3141 .53407 Mdot
.65699 .56614 Mdot
.48201 .62283 Mdot
.45962 .4045 Mdot
.43781 .63102 Mdot
.66237 .44901 Mdot
.35267 .54124 Mdot
.45108 .42372 Mdot
.43236 .41525 Mdot
.30371 .55632 Mdot
.45352 .44222 Mdot
.70685 .45117 Mdot
.6698 .57612 Mdot
.32366 .58543 Mdot
.47998 .63702 Mdot
.66042 .60738 Mdot
.42741 .4044 Mdot
.19897 .33394 Mdot
.45338 .39465 Mdot
.43179 .39629 Mdot
.70439 .25838 Mdot
.38897 .37507 Mdot
.66688 .59604 Mdot
.31531 .59863 Mdot
.48541 .43275 Mdot
.55729 .34743 Mdot
.82608 .54031 Mdot
.66495 .61069 Mdot
.44537 .35845 Mdot
.54166 .17749 Mdot
.44678 .35472 Mdot
.62163 .49315 Mdot
.74812 .60945 Mdot
.47408 .26614 Mdot
.50333 .42454 Mdot
.44284 .63017 Mdot
.64758 .68752 Mdot
.67539 .57893 Mdot
.21797 .50821 Mdot
.45457 .37115 Mdot
.20567 .50528 Mdot
.45234 .34283 Mdot
.49082 .65156 Mdot
.39694 .48152 Mdot
.66062 .55855 Mdot
.38412 .79225 Mdot
.4073 .40133 Mdot
.36329 .57111 Mdot
.64984 .61318 Mdot
.6713 .69793 Mdot
.42812 .39501 Mdot
.67273 .42131 Mdot
.43686 .67464 Mdot
.49764 .32416 Mdot
.48193 .64722 Mdot
.43057 .36809 Mdot
.41002 .46795 Mdot
.46476 .83934 Mdot
.29885 .5665 Mdot
.45802 .64953 Mdot
.56839 .78814 Mdot
.46209 .43866 Mdot
.31725 .58219 Mdot
.32792 .55844 Mdot
.69416 .42165 Mdot
.55819 .57887 Mdot
.32314 .64362 Mdot
.42352 .21957 Mdot
.27247 .51308 Mdot
.67542 .58902 Mdot
.53115 .76577 Mdot
.4186 .41223 Mdot
.46915 .58138 Mdot
.45865 .61671 Mdot
.46895 .38683 Mdot
.2538 .54076 Mdot
.35023 .54207 Mdot
.44138 .39699 Mdot
.6973 .42742 Mdot
.54881 .64132 Mdot
.51707 .59599 Mdot
.30579 .245 Mdot
.66168 .61475 Mdot
.4879 .33973 Mdot
.51377 .40158 Mdot
.6466 .67471 Mdot
.49386 .36732 Mdot
.66919 .58985 Mdot
.73061 .33091 Mdot
.67328 .46436 Mdot
.36023 .54804 Mdot
.66743 .69001 Mdot
.46633 .44485 Mdot
.43384 .33567 Mdot
.71583 .44007 Mdot
.41833 .37121 Mdot
.43047 .81497 Mdot
.68159 .71652 Mdot
.62705 .57434 Mdot
.30859 .58275 Mdot
.47208 .43734 Mdot
.66595 .71126 Mdot
.4594 .37245 Mdot
.35178 .33525 Mdot
.41646 .36397 Mdot
.29507 .64551 Mdot
.30697 .54684 Mdot
.47934 .64526 Mdot
.48663 .43997 Mdot
.48386 .39312 Mdot
.78044 .51078 Mdot
.44567 .46668 Mdot
.4703 .35201 Mdot
.29608 .5408 Mdot
.36429 .56317 Mdot
.35075 .56734 Mdot
.63446 .59232 Mdot
.39246 .75625 Mdot
.47409 .65998 Mdot
.3996 .40591 Mdot
.43519 .62069 Mdot
.36557 .32936 Mdot
.7155 .44918 Mdot
.41092 .19507 Mdot
.42598 .35343 Mdot
.34524 .57021 Mdot
.40001 .69095 Mdot
.36227 .53064 Mdot
.66904 .62099 Mdot
.48005 .66774 Mdot
.34876 .54432 Mdot
.47734 .40053 Mdot
.53667 .52545 Mdot
.32586 .24532 Mdot
.46535 .64918 Mdot
.48036 .32707 Mdot
.66815 .61365 Mdot
.60699 .56574 Mdot
.28777 .20956 Mdot
.45173 .65113 Mdot
.53699 .77801 Mdot
.447 .37144 Mdot
.36094 .56153 Mdot
.45163 .62599 Mdot
.44441 .64189 Mdot
.65299 .56009 Mdot
.48214 .40802 Mdot
.47053 .41313 Mdot
.66252 .68373 Mdot
.46896 .6346 Mdot
.4581 .45256 Mdot
.44918 .32549 Mdot
.65748 .22476 Mdot
.25341 .58508 Mdot
.77465 .71357 Mdot
.40866 .47532 Mdot
.26018 .52216 Mdot
.5547 .48369 Mdot
.36989 .55631 Mdot
.47303 .41516 Mdot
.48617 .4248 Mdot
.66445 .60133 Mdot
.45572 .40035 Mdot
.62265 .54603 Mdot
.45927 .6609 Mdot
.38424 .19377 Mdot
.38965 .62717 Mdot
.71925 .32727 Mdot
.4614 .3971 Mdot
.27308 .673 Mdot
.6867 .46021 Mdot
.51123 .66938 Mdot
.3396 .58297 Mdot
.48032 .42365 Mdot
.63284 .52767 Mdot
.64524 .55063 Mdot
.33437 .5507 Mdot
.47831 .77004 Mdot
.79659 .51646 Mdot
.49566 .39091 Mdot
.62295 .57798 Mdot
.44131 .71588 Mdot
.27185 .34802 Mdot
.4578 .60179 Mdot
.67458 .46672 Mdot
.66047 .54236 Mdot
.44615 .66582 Mdot
.26837 .58468 Mdot
.34 .54329 Mdot
.32864 .59908 Mdot
.74829 .55854 Mdot
.61618 .56371 Mdot
.67304 .45549 Mdot
.34362 .74104 Mdot
.32772 .73756 Mdot
.6684 .46339 Mdot
.65635 .53888 Mdot
.36478 .55817 Mdot
.3284 .58063 Mdot
.32635 .56607 Mdot
.37312 .78589 Mdot
.29187 .5637 Mdot
.32549 .37864 Mdot
.44148 .32973 Mdot
.50935 .31837 Mdot
.4476 .35598 Mdot
.44728 .61888 Mdot
.29938 .56187 Mdot
.56342 .48494 Mdot
.45506 .43534 Mdot
.32073 .23976 Mdot
.43918 .37037 Mdot
.46908 .60396 Mdot
.43772 .39526 Mdot
.32641 .30678 Mdot
.37105 .57741 Mdot
.45268 .40606 Mdot
.50305 .6594 Mdot
.68952 .4426 Mdot
.3841 .58282 Mdot
.47064 .41467 Mdot
.33395 .69959 Mdot
.39157 .39011 Mdot
.72748 .32095 Mdot
.64116 .38847 Mdot
.70995 .46318 Mdot
.46992 .4619 Mdot
.68093 .57833 Mdot
.38081 .5974 Mdot
.53155 .39632 Mdot
.46621 .64768 Mdot
.18725 .51841 Mdot
.64109 .55257 Mdot
.40195 .48794 Mdot
.38603 .35971 Mdot
.71133 .4406 Mdot
.29728 .60205 Mdot
.46465 .61823 Mdot
.43276 .44293 Mdot
.45065 .33588 Mdot
.70209 .31602 Mdot
.53212 .38059 Mdot
.3992 .37462 Mdot
.71298 .42659 Mdot
.30712 .40512 Mdot
.43856 .41034 Mdot
.69195 .57627 Mdot
.3345 .59767 Mdot
.4421 .45782 Mdot
.30011 .39473 Mdot
.44638 .37622 Mdot
.34576 .54976 Mdot
.3135 .60027 Mdot
.36967 .6828 Mdot
.69135 .47286 Mdot
.41667 .36392 Mdot
.69965 .36887 Mdot
.40618 .38864 Mdot
.47643 .66312 Mdot
.49108 .37824 Mdot
.64345 .55802 Mdot
.41666 .78734 Mdot
.64627 .5949 Mdot
.49096 .38474 Mdot
.32268 .56821 Mdot
.44838 .62426 Mdot
.72595 .55393 Mdot
.76333 .58731 Mdot
.32321 .38344 Mdot
.84879 .53672 Mdot
.68737 .46453 Mdot
.68436 .41175 Mdot
.48999 .62354 Mdot
.45029 .40815 Mdot
.65887 .38932 Mdot
.40104 .34971 Mdot
.43818 .40178 Mdot
.4829 .3805 Mdot
.42125 .61763 Mdot
.46558 .65868 Mdot
.65879 .57336 Mdot
.4585 .38829 Mdot
.4442 .37809 Mdot
.32654 .53563 Mdot
.68826 .44439 Mdot
.64583 .59748 Mdot
.6862 .45248 Mdot
.64711 .58534 Mdot
.42178 .16463 Mdot
.4472 .32192 Mdot
.69192 .442 Mdot
.48862 .62113 Mdot
.35499 .55764 Mdot
.65794 .7169 Mdot
.64277 .60718 Mdot
.66178 .55563 Mdot
.44155 .3727 Mdot
.35335 .5531 Mdot
.31663 .53486 Mdot
.69922 .45276 Mdot
.46131 .62599 Mdot
.49072 .38691 Mdot
.49639 .38667 Mdot
.50573 .24937 Mdot
.63195 .60715 Mdot
.26398 .37562 Mdot
.3819 .7032 Mdot
.45161 .4095 Mdot
.29809 .57135 Mdot
.47382 .3659 Mdot
.53368 .19318 Mdot
.32276 .59254 Mdot
.47115 .42298 Mdot
.28721 .70122 Mdot
.6171 .59226 Mdot
.31909 .66605 Mdot
.41455 .35048 Mdot
.83947 .48016 Mdot
.41345 .40307 Mdot
.62413 .18844 Mdot
.59801 .74608 Mdot
.40451 .41097 Mdot
.42457 .41435 Mdot
.40995 .22616 Mdot
.45085 .36535 Mdot
.66198 .70294 Mdot
.42268 .48034 Mdot
.34907 .58525 Mdot
.5688 .4562 Mdot
.69087 .59857 Mdot
.67591 .47248 Mdot
.63053 .57111 Mdot
.70512 .58646 Mdot
.70126 .43122 Mdot
.31421 .56565 Mdot
.43131 .42531 Mdot
.5703 .40591 Mdot
.64524 .62278 Mdot
.38219 .38137 Mdot
.47839 .66369 Mdot
.68609 .53142 Mdot
.63034 .53759 Mdot
.47795 .63942 Mdot
.44255 .34417 Mdot
.30959 .27907 Mdot
.73784 .62749 Mdot
.81376 .38083 Mdot
.46338 .61965 Mdot
.49238 .65098 Mdot
.39457 .7713 Mdot
.67215 .46992 Mdot
.63576 .26548 Mdot
.27423 .65525 Mdot
.4899 .63138 Mdot
.6676 .32037 Mdot
.67554 .55236 Mdot
.32306 .69653 Mdot
.36114 .51088 Mdot
.47182 .33029 Mdot
.47961 .39846 Mdot
.4601 .62838 Mdot
.55608 .42255 Mdot
.49318 .83355 Mdot
.47072 .64556 Mdot
.51635 .38285 Mdot
.55662 .59515 Mdot
.66005 .68717 Mdot
.65565 .67803 Mdot
.70103 .468 Mdot
.79643 .46301 Mdot
.31714 .54395 Mdot
.7107 .43593 Mdot
.54174 .61746 Mdot
.42119 .36273 Mdot
.46691 .63983 Mdot
.66454 .71727 Mdot
.48732 .642 Mdot
.69023 .4276 Mdot
.71153 .45972 Mdot
.297 .56433 Mdot
.34425 .58403 Mdot
.2542 .52527 Mdot
.64576 .34056 Mdot
.44696 .3535 Mdot
.20635 .39929 Mdot
.32878 .53125 Mdot
.51988 .4245 Mdot
.6594 .4482 Mdot
.69195 .44507 Mdot
.21749 .43634 Mdot
.44302 .42659 Mdot
.6417 .4209 Mdot
.45167 .42103 Mdot
.61905 .27148 Mdot
.49906 .38301 Mdot
.65403 .56319 Mdot
.41603 .42345 Mdot
.58478 .55028 Mdot
.43015 .43264 Mdot
.47251 .35207 Mdot
.66882 .54796 Mdot
.47026 .3163 Mdot
.6442 .55642 Mdot
.49209 .39316 Mdot
.67151 .41014 Mdot
.63256 .5679 Mdot
.56272 .3157 Mdot
.48007 .55028 Mdot
.65751 .70907 Mdot
.67311 .42536 Mdot
.69632 .41969 Mdot
.5802 .40254 Mdot
.33654 .58429 Mdot
.26931 .55033 Mdot
.44906 .4069 Mdot
.67791 .56323 Mdot
.46142 .65678 Mdot
.44489 .38002 Mdot
.49839 .39814 Mdot
.40636 .35988 Mdot
.34193 .53628 Mdot
.61456 .568 Mdot
.69154 .43756 Mdot
.62571 .58289 Mdot
.78766 .48637 Mdot
.65201 .52941 Mdot
.41837 .45199 Mdot
.50565 .38218 Mdot
.38276 .28626 Mdot
.19603 .50762 Mdot
.25955 .68804 Mdot
.33534 .54531 Mdot
.64941 .69524 Mdot
.71228 .45692 Mdot
.37071 .45832 Mdot
.34434 .57654 Mdot
.65954 .5461 Mdot
.44887 .41522 Mdot
.51138 .35668 Mdot
.49799 .60008 Mdot
.37841 .60348 Mdot
.59138 .38058 Mdot
.63501 .53233 Mdot
.66169 .69623 Mdot
.39003 .75767 Mdot
.3836 .49316 Mdot
.57553 .47343 Mdot
.47683 .37945 Mdot
.66971 .42335 Mdot
.36297 .55304 Mdot
.73473 .58599 Mdot
.46341 .63292 Mdot
.54304 .51461 Mdot
.46055 .39803 Mdot
.45101 .74137 Mdot
.32267 .56688 Mdot
.69189 .42464 Mdot
.45997 .62925 Mdot
.67716 .47393 Mdot
.65623 .6774 Mdot
.80381 .45265 Mdot
.41058 .38185 Mdot
.46666 .35165 Mdot
.46015 .60507 Mdot
.32041 .54346 Mdot
.67328 .39565 Mdot
.69004 .29936 Mdot
.62237 .56886 Mdot
.6404 .436 Mdot
.36937 .54185 Mdot
.33754 .32869 Mdot
.62859 .58645 Mdot
.43703 .64807 Mdot
.59293 .43731 Mdot
.48081 .67519 Mdot
.46371 .41934 Mdot
.33752 .57062 Mdot
.45333 .65845 Mdot
.77267 .51112 Mdot
.53551 .16351 Mdot
.35042 .29539 Mdot
.40301 .398 Mdot
.40094 .19619 Mdot
.71675 .28819 Mdot
.53666 .45601 Mdot
.49594 .65257 Mdot
.46587 .37366 Mdot
.49387 .36257 Mdot
.40887 .40803 Mdot
.46041 .66899 Mdot
.76046 .45023 Mdot
.65695 .55202 Mdot
.43902 .36414 Mdot
.70438 .42725 Mdot
.64455 .56564 Mdot
.5995 .54344 Mdot
.67314 .5792 Mdot
.35582 .58404 Mdot
.46068 .42871 Mdot
.39079 .73975 Mdot
.57369 .15196 Mdot
.46704 .65313 Mdot
.65751 .70872 Mdot
.46041 .34528 Mdot
.23472 .63388 Mdot
.34972 .56821 Mdot
.62215 .56584 Mdot
.4685 .38431 Mdot
.76872 .47396 Mdot
.6571 .72828 Mdot
.67172 .56693 Mdot
.33002 .58243 Mdot
.5254 .46942 Mdot
.45432 .39937 Mdot
.41233 .39764 Mdot
.31487 .54991 Mdot
.80902 .48125 Mdot
.41729 .78335 Mdot
.47587 .3652 Mdot
.47875 .64378 Mdot
.62077 .8356 Mdot
.42046 .34786 Mdot
.27796 .59899 Mdot
.673 .70109 Mdot
.34957 .69973 Mdot
.25916 .38168 Mdot
.45964 .46719 Mdot
.43431 .20564 Mdot
.58127 .43052 Mdot
.39445 .18886 Mdot
.72817 .40147 Mdot
.5782 .63877 Mdot
.43592 .15916 Mdot
.50411 .6494 Mdot
.50039 .31057 Mdot
.45045 .25105 Mdot
.45868 .7737 Mdot
.55318 .4628 Mdot
.80843 .59119 Mdot
.77742 .54082 Mdot
.63155 .65971 Mdot
.66319 .59052 Mdot
.59555 .25895 Mdot
.48866 .38014 Mdot
.72405 .29284 Mdot
.29353 .33298 Mdot
.48589 .84078 Mdot
.41648 .18548 Mdot
.7008 .36717 Mdot
.33581 .24645 Mdot
.55341 .18348 Mdot
.41099 .25897 Mdot
.38218 .6144 Mdot
.77473 .68798 Mdot
.3439 .74485 Mdot
.73003 .36567 Mdot
.37846 .42159 Mdot
.57576 .58212 Mdot
.7599 .36884 Mdot
.33159 .42525 Mdot
.5308 .85335 Mdot
.65164 .60552 Mdot
.34816 .59547 Mdot
.492 .2429 Mdot
.37781 .59489 Mdot
.41879 .67256 Mdot
.43161 .20559 Mdot
.61964 .19327 Mdot
.32198 .31094 Mdot
.84668 .49341 Mdot
.22393 .48827 Mdot
.22286 .6794 Mdot
.50753 .56256 Mdot
.33959 .60097 Mdot
.74206 .69629 Mdot
.32576 .73596 Mdot
.37463 .63758 Mdot
.36669 .44109 Mdot
.72798 .43732 Mdot
.59113 .34198 Mdot
.32184 .5742 Mdot
.25744 .37346 Mdot
.65835 .67368 Mdot
.32186 .63126 Mdot
.58682 .57973 Mdot
.50563 .18089 Mdot
.61775 .6398 Mdot
.33981 .71075 Mdot
.51812 .75877 Mdot
.20098 .32869 Mdot
.67628 .34419 Mdot
.58911 .20924 Mdot
.49225 .60293 Mdot
.55067 .45994 Mdot
.48333 .80968 Mdot
.63775 .35778 Mdot
.3132 .72868 Mdot
.18434 .39015 Mdot
.75982 .3317 Mdot
.23648 .3065 Mdot
.32946 .60954 Mdot
.40384 .36559 Mdot
.53625 .20829 Mdot
.27878 .50896 Mdot
.7153 .45847 Mdot
.27896 .26538 Mdot
.66064 .43502 Mdot
.36378 .60432 Mdot
.47272 .77238 Mdot
.32522 .34185 Mdot
.63763 .46223 Mdot
.65118 .42973 Mdot
.40394 .43205 Mdot
.2329 .74612 Mdot
.38012 .20216 Mdot
.36331 .6861 Mdot
.65737 .22379 Mdot
.53725 .65234 Mdot
.63622 .41101 Mdot
.4601 .6646 Mdot
.49846 .15486 Mdot
.33513 .57804 Mdot
.50985 .12868 Mdot
.52827 .15553 Mdot
.60045 .80399 Mdot
.41582 .8939 Mdot
.5681 .70676 Mdot
.44232 .27291 Mdot
.5595 .37291 Mdot
.56959 .34848 Mdot
.49824 .82275 Mdot
.62026 .79447 Mdot
.53517 .66623 Mdot
.80459 .42169 Mdot
.45482 .16231 Mdot
.64907 .30111 Mdot
.75492 .39507 Mdot
.47255 .78711 Mdot
.4942 .54485 Mdot
.27237 .56758 Mdot
.447 .54459 Mdot
.37646 .61541 Mdot
.26754 .27898 Mdot
.27674 .52173 Mdot
.53776 .87381 Mdot
.68416 .39952 Mdot
.63852 .7491 Mdot
.66696 .24323 Mdot
.56256 .30366 Mdot
.35519 .36476 Mdot
.41957 .75704 Mdot
.40581 .43691 Mdot
.39996 .76016 Mdot
.42655 .49738 Mdot
.70382 .56618 Mdot
.38514 .75988 Mdot
.46324 .72091 Mdot
.69336 .31025 Mdot
.46659 .21945 Mdot
.2777 .6849 Mdot
.33729 .59151 Mdot
.62254 .38312 Mdot
.67697 .33414 Mdot
.66162 .23037 Mdot
.56643 .78807 Mdot
.80856 .36829 Mdot
.58423 .78972 Mdot
.40326 .34852 Mdot
.52668 .40171 Mdot
.3745 .40052 Mdot
.65397 .35446 Mdot
.41889 .34083 Mdot
.45673 .74015 Mdot
.68797 .24666 Mdot
.25053 .54761 Mdot
.69668 .51182 Mdot
.17758 .48361 Mdot
.79126 .35764 Mdot
.54043 .21449 Mdot
.59228 .75325 Mdot
.54051 .36892 Mdot
.16569 .59218 Mdot
.64617 .57409 Mdot
.66123 .31565 Mdot
.4668 .68861 Mdot
.74436 .56699 Mdot
.38514 .24867 Mdot
.58525 .81134 Mdot
.69407 .25003 Mdot
.42832 .77313 Mdot
.70413 .64583 Mdot
.59608 .49283 Mdot
.64136 .47648 Mdot
.18101 .46429 Mdot
.51043 .3727 Mdot
.36556 .35819 Mdot
.70021 .41708 Mdot
.30539 .48632 Mdot
.57136 .23064 Mdot
.76612 .62649 Mdot
.52411 .38145 Mdot
.71523 .69385 Mdot
.66486 .69784 Mdot
.54043 .52015 Mdot
.31982 .19522 Mdot
.39512 .43096 Mdot
.57138 .7246 Mdot
.76909 .34349 Mdot
.62372 .40729 Mdot
.63375 .23047 Mdot
.42485 .73566 Mdot
.22246 .32959 Mdot
.56363 .15952 Mdot
.76297 .60268 Mdot
.36315 .19587 Mdot
.7786 .30487 Mdot
.20192 .36343 Mdot
.19609 .44916 Mdot
.50494 .66757 Mdot
.49814 .09745 Mdot
.63879 .54444 Mdot
.19314 .54528 Mdot
.26903 .51888 Mdot
.75272 .48391 Mdot
.31525 .52557 Mdot
.41598 .31555 Mdot
.63151 .65007 Mdot
.37531 .52151 Mdot
.43216 .45947 Mdot
.236 .28502 Mdot
.16263 .43917 Mdot
.24353 .28328 Mdot
.80174 .39216 Mdot
.37167 .19266 Mdot
.48381 .26027 Mdot
.32963 .37579 Mdot
.54805 .24348 Mdot
.49335 .38308 Mdot
.61701 .2955 Mdot
.56627 .71578 Mdot
.7301 .62932 Mdot
.35311 .63978 Mdot
.35651 .52207 Mdot
.27205 .28984 Mdot
.23805 .24546 Mdot
.23021 .46794 Mdot
.27709 .41627 Mdot
.48748 .58398 Mdot
.65498 .33949 Mdot
.40154 .50154 Mdot
.70699 .6794 Mdot
.66661 .2385 Mdot
.45039 .24972 Mdot
.68346 .32001 Mdot
.77665 .62908 Mdot
.61561 .50457 Mdot
.62995 .73816 Mdot
.50549 .17398 Mdot
.52127 .27123 Mdot
.6077 .79293 Mdot
.52295 .32566 Mdot
.52956 .83538 Mdot
.79617 .56324 Mdot
.68285 .63291 Mdot
.69963 .34444 Mdot
.60844 .56705 Mdot
.63936 .29781 Mdot
.54981 .58354 Mdot
.49963 .23429 Mdot
.58058 .42838 Mdot
.63814 .29287 Mdot
.61314 .50637 Mdot
.29805 .24064 Mdot
.81913 .35279 Mdot
.15745 .48884 Mdot
.83451 .46487 Mdot
.4363 .49882 Mdot
.44452 .33308 Mdot
.72823 .27888 Mdot
.27628 .24782 Mdot
.58561 .1629 Mdot
.46903 .75119 Mdot
.7688 .50183 Mdot
.50166 .62964 Mdot
.16283 .50014 Mdot
.81213 .5444 Mdot
.59642 .19016 Mdot
.26155 .68749 Mdot
.42926 .62947 Mdot
.43695 .78634 Mdot
.17671 .51199 Mdot
.36296 .26191 Mdot
.24282 .41019 Mdot
.38433 .35876 Mdot
.3109 .30865 Mdot
.3266 .59687 Mdot
.51191 .76608 Mdot
.64559 .35326 Mdot
.64167 .57478 Mdot
.53701 .29019 Mdot
.36453 .35314 Mdot
.40017 .42729 Mdot
.66502 .64112 Mdot
.28816 .53456 Mdot
.2044 .53061 Mdot
.50867 .69436 Mdot
.41207 .16051 Mdot
.55749 .73932 Mdot
.37896 .4489 Mdot
.63998 .3802 Mdot
.72105 .6049 Mdot
.40942 .76366 Mdot
.49993 .6491 Mdot
.44605 .17899 Mdot
.43025 .53527 Mdot
.62703 .38182 Mdot
.3008 .31623 Mdot
.66128 .27651 Mdot
.50463 .37911 Mdot
.38879 .69574 Mdot
.34577 .42288 Mdot
.55122 .51239 Mdot
.3749 .58877 Mdot
.28272 .53776 Mdot
.87757 .50645 Mdot
.55417 .64344 Mdot
.6 .77519 Mdot
.45568 .18024 Mdot
.47446 .67385 Mdot
.34855 .52466 Mdot
.61905 .28361 Mdot
.70576 .313 Mdot
.34257 .44995 Mdot
.64478 .5196 Mdot
.71906 .46834 Mdot
.78196 .5995 Mdot
.40412 .1978 Mdot
.35695 .22833 Mdot
.4754 .84503 Mdot
.31807 .53078 Mdot
.63854 .25696 Mdot
.71038 .32553 Mdot
.34484 .53191 Mdot
.34752 .61426 Mdot
.29751 .63144 Mdot
.35786 .18734 Mdot
.39027 .74763 Mdot
.82587 .46044 Mdot
.59877 .43083 Mdot
.76671 .45819 Mdot
.72795 .58163 Mdot
.73091 .37621 Mdot
.46238 .18072 Mdot
.25103 .3759 Mdot
.35383 .25816 Mdot
.39195 .45765 Mdot
.23134 .56877 Mdot
.1615 .50955 Mdot
.51038 .55551 Mdot
.33586 .32418 Mdot
.44386 .71115 Mdot
.40427 .39152 Mdot
.20219 .32672 Mdot
.71999 .3022 Mdot
.36773 .76751 Mdot
.46137 .69532 Mdot
.423 .39345 Mdot
.42622 .33081 Mdot
.54973 .43007 Mdot
.36208 .69637 Mdot
.16898 .44742 Mdot
.73609 .37702 Mdot
.4825 .48939 Mdot
.28939 .33112 Mdot
.57137 .72688 Mdot
.50506 .18477 Mdot
.69731 .27186 Mdot
.55232 .55567 Mdot
.56244 .7217 Mdot
.59576 .46892 Mdot
.82545 .43954 Mdot
.61216 .62975 Mdot
.4832 .25492 Mdot
.25611 .63768 Mdot
.38879 .72077 Mdot
.7271 .60392 Mdot
.46379 .34382 Mdot
.47706 .76953 Mdot
.54413 .18494 Mdot
.49312 .86829 Mdot
.49927 .81299 Mdot
.22622 .2879 Mdot
.36079 .30417 Mdot
.39057 .72706 Mdot
.33347 .25977 Mdot
.47447 .87619 Mdot
.6344 .64165 Mdot
.30723 .25718 Mdot
.59618 .48449 Mdot
.43167 .18264 Mdot
.4795 .68835 Mdot
.32338 .71611 Mdot
.17872 .49197 Mdot
.36732 .18482 Mdot
.56917 .21296 Mdot
.47401 .18524 Mdot
.53492 .34073 Mdot
.33053 .20365 Mdot
.24428 .62834 Mdot
.63127 .66449 Mdot
.67356 .6067 Mdot
.46937 .74289 Mdot
.25807 .33109 Mdot
.40553 .60158 Mdot
.67181 .31906 Mdot
.62524 .70851 Mdot
.35715 .4299 Mdot
.33365 .27379 Mdot
.57634 .29559 Mdot
.40867 .72467 Mdot
.63736 .38391 Mdot
.57373 .17895 Mdot
.63274 .69703 Mdot
.72325 .55531 Mdot
.5731 .76576 Mdot
.80423 .44846 Mdot
.35808 .69204 Mdot
.5578 .65989 Mdot
.58494 .20685 Mdot
.80576 .52551 Mdot
.69741 .36122 Mdot
.89824 .47893 Mdot
.76703 .39088 Mdot
.31942 .62851 Mdot
.25954 .29346 Mdot
.68109 .25268 Mdot
.24459 .59467 Mdot
.471 .83129 Mdot
.23122 .56213 Mdot
.62718 .31889 Mdot
.48388 .38331 Mdot
.3 .21517 Mdot
.59242 .33177 Mdot
.26878 .27445 Mdot
.7618 .31262 Mdot
.311 .30303 Mdot
.3907 .4053 Mdot
.67458 .53552 Mdot
.50801 .58115 Mdot
.57239 .28625 Mdot
.36846 .24245 Mdot
.2272 .55074 Mdot
.69798 .55785 Mdot
.66238 .66166 Mdot
.64788 .52233 Mdot
.49166 .47242 Mdot
.55129 .7223 Mdot
.38405 .70871 Mdot
.65212 .41395 Mdot
.56658 .57503 Mdot
.66169 .3319 Mdot
.26275 .37471 Mdot
.36794 .26057 Mdot
.56245 .8213 Mdot
.42633 .6887 Mdot
.66289 .60118 Mdot
.42589 .22365 Mdot
.77439 .38909 Mdot
.43223 .72203 Mdot
.20897 .36603 Mdot
.42549 .76164 Mdot
.58066 .26036 Mdot
.53498 .22615 Mdot
.51928 .82604 Mdot
.80649 .64285 Mdot
.2353 .34405 Mdot
.22952 .57416 Mdot
.63772 .4343 Mdot
.3886 .29862 Mdot
.42165 .16554 Mdot
.71483 .35439 Mdot
.51001 .22628 Mdot
.48533 .5552 Mdot
.32154 .45921 Mdot
.30245 .30066 Mdot
.55401 .31641 Mdot
.57158 .48494 Mdot
.19291 .65017 Mdot
.34238 .51618 Mdot
.19248 .33733 Mdot
.47359 .63099 Mdot
.342 .77725 Mdot
.62878 .50683 Mdot
.5409 .5698 Mdot
.57232 .46661 Mdot
.38318 .68875 Mdot
.29211 .64501 Mdot
.80353 .4047 Mdot
.56152 .83128 Mdot
.65777 .53199 Mdot
.68361 .38007 Mdot
.82102 .4854 Mdot
.42292 .21639 Mdot
.45047 .45145 Mdot
.7822 .40583 Mdot
.50682 .55198 Mdot
.72838 .62925 Mdot
.73108 .28576 Mdot
.414 .68159 Mdot
.51006 .40777 Mdot
.65254 .34206 Mdot
.3036 .26204 Mdot
.54458 .15933 Mdot
.42725 .80747 Mdot
.42761 .49741 Mdot
.50768 .64926 Mdot
.49428 .27887 Mdot
.4064 .20537 Mdot
.62361 .43772 Mdot
.3462 .72089 Mdot
.68103 .34018 Mdot
.13674 .43831 Mdot
.1723 .42009 Mdot
.16925 .45025 Mdot
.63797 .3962 Mdot
.38321 .56514 Mdot
.23536 .60315 Mdot
.51594 .227 Mdot
.40635 .68548 Mdot
.7642 .36514 Mdot
.66417 .32092 Mdot
.41447 .84615 Mdot
.3522 .37675 Mdot
.78831 .48275 Mdot
.28499 .31256 Mdot
.27822 .50067 Mdot
.49137 .68261 Mdot
.6141 .31608 Mdot
.41683 .52052 Mdot
.4733 .61262 Mdot
.40289 .72042 Mdot
.32681 .69271 Mdot
.50657 .22629 Mdot
.33821 .41803 Mdot
.45466 .49517 Mdot
.46008 .21448 Mdot
.38055 .53037 Mdot
.73424 .58217 Mdot
.72282 .57212 Mdot
.51565 .49483 Mdot
.62587 .56091 Mdot
.45463 .46901 Mdot
.55626 .52199 Mdot
.58561 .48585 Mdot
.18348 .56713 Mdot
.66462 .42605 Mdot
.37279 .531 Mdot
.33065 .75725 Mdot
.35056 .5326 Mdot
.2614 .25105 Mdot
.70228 .68323 Mdot
.30081 .31999 Mdot
.77227 .58392 Mdot
.75221 .67127 Mdot
.25027 .73821 Mdot
.19219 .42861 Mdot
.45882 .55713 Mdot
.39573 .57526 Mdot
.2888 .56226 Mdot
.67288 .50975 Mdot
.65679 .66347 Mdot
.24988 .41224 Mdot
.57861 .70806 Mdot
.5642 .24967 Mdot
.33214 .60437 Mdot
.77758 .45713 Mdot
.39632 .48839 Mdot
.37443 .17677 Mdot
.66436 .59361 Mdot
.14755 .55794 Mdot
.47781 .32136 Mdot
.41319 .25273 Mdot
.71947 .26657 Mdot
.4278 .79783 Mdot
.69749 .63862 Mdot
.82409 .58653 Mdot
.41288 .42793 Mdot
.45576 .49284 Mdot
.32083 .57614 Mdot
.61233 .25454 Mdot
.67932 .43992 Mdot
.60255 .38247 Mdot
.43664 .61598 Mdot
.6308 .77823 Mdot
.54573 .73137 Mdot
.3784 .55716 Mdot
.40804 .52943 Mdot
.56999 .22094 Mdot
.29864 .6853 Mdot
.50642 .55009 Mdot
.41272 .22549 Mdot
.33961 .44512 Mdot
.32636 .60461 Mdot
.19937 .38435 Mdot
.71035 .33038 Mdot
.50749 .14892 Mdot
.40337 .31049 Mdot
.51274 .57339 Mdot
.28696 .68389 Mdot
.40083 .70925 Mdot
.25624 .39192 Mdot
.66172 .23521 Mdot
.63138 .37089 Mdot
.32135 .72702 Mdot
.63455 .29159 Mdot
.43831 .31501 Mdot
.59319 .62459 Mdot
.50463 .74806 Mdot
.37717 .8249 Mdot
.20178 .46623 Mdot
.46129 .80474 Mdot
.38491 .60627 Mdot
.57062 .72334 Mdot
.36373 .51789 Mdot
.7263 .50966 Mdot
.3335 .43654 Mdot
.68146 .66842 Mdot
.46055 .15133 Mdot
.67078 .23957 Mdot
.46537 .59202 Mdot
.59587 .5638 Mdot
.56473 .44407 Mdot
.37335 .4269 Mdot
.53049 .51199 Mdot
.40251 .40859 Mdot
.52275 .4518 Mdot
.41331 .79593 Mdot
.40126 .6914 Mdot
.40928 .32098 Mdot
.40685 .17881 Mdot
.51804 .1477 Mdot
.32032 .21512 Mdot
.63978 .44851 Mdot
.37105 .5646 Mdot
.2086 .34441 Mdot
.28389 .37793 Mdot
.5721 .17634 Mdot
.22935 .36292 Mdot
.87703 .48572 Mdot
.36396 .24908 Mdot
.45609 .71561 Mdot
.60861 .80117 Mdot
.31944 .65213 Mdot
.7378 .29989 Mdot
.63086 .66908 Mdot
.68983 .50357 Mdot
.74559 .3067 Mdot
.22646 .73493 Mdot
.19496 .46317 Mdot
.33414 .70339 Mdot
.42646 .26639 Mdot
.49704 .4978 Mdot
.58659 .69076 Mdot
.48811 .37103 Mdot
.62935 .6135 Mdot
.708 .63744 Mdot
.66675 .32941 Mdot
.38563 .28869 Mdot
.58805 .69707 Mdot
.57082 .28141 Mdot
.60692 .26073 Mdot
.73601 .37001 Mdot
.38028 .24351 Mdot
.25512 .40585 Mdot
.50582 .41766 Mdot
.38688 .55408 Mdot
.69435 .47043 Mdot
.70847 .57815 Mdot
.47865 .41511 Mdot
.68755 .64428 Mdot
.28254 .65607 Mdot
.22632 .29228 Mdot
.71259 .50865 Mdot
.7092 .30656 Mdot
.33409 .51202 Mdot
.37243 .69649 Mdot
.5078 .20027 Mdot
.46253 .77243 Mdot
.59606 .70472 Mdot
.27593 .52179 Mdot
.39189 .19681 Mdot
.41269 .7536 Mdot
.67385 .30119 Mdot
.20568 .62406 Mdot
.45786 .61162 Mdot
.20985 .52692 Mdot
.46426 .25263 Mdot
.44158 .76241 Mdot
.32318 .60775 Mdot
.47935 .71776 Mdot
.58375 .63443 Mdot
.43041 .74992 Mdot
.77176 .34526 Mdot
.61235 .2454 Mdot
.27006 .32975 Mdot
.36557 .22077 Mdot
.653 .61663 Mdot
.68006 .31784 Mdot
.49438 .70919 Mdot
.59238 .66681 Mdot
.28899 .69343 Mdot
.40883 .1673 Mdot
.54356 .50347 Mdot
.5829 .33399 Mdot
.40926 .39163 Mdot
.30232 .39706 Mdot
.39162 .68579 Mdot
.5946 .5216 Mdot
.58104 .77705 Mdot
.32662 .59181 Mdot
.5372 .75237 Mdot
.64248 .71639 Mdot
.61806 .32896 Mdot
.39627 .5276 Mdot
.25382 .57855 Mdot
.71675 .46476 Mdot
.63836 .69471 Mdot
.48289 .43686 Mdot
.58469 .34957 Mdot
.6352 .47279 Mdot
.20226 .50321 Mdot
.19121 .46506 Mdot
.41895 .22211 Mdot
.72728 .32487 Mdot
.42412 .71314 Mdot
.22773 .36262 Mdot
.29679 .64277 Mdot
.33631 .35988 Mdot
.5061 .78642 Mdot
.40976 .35435 Mdot
.72856 .50696 Mdot
.3661 .53042 Mdot
.40633 .21394 Mdot
.35278 .32875 Mdot
.56287 .31387 Mdot
.53125 .54206 Mdot
.52644 .20058 Mdot
.48391 .53568 Mdot
.7225 .27192 Mdot
.32241 .65135 Mdot
.64364 .35433 Mdot
.44145 .67263 Mdot
.60179 .48122 Mdot
.51356 .81831 Mdot
.49301 .16147 Mdot
.57147 .81989 Mdot
.55915 .37894 Mdot
.45399 .79807 Mdot
.22895 .58555 Mdot
.75339 .30755 Mdot
.63608 .34234 Mdot
.52821 .51357 Mdot
.39538 .48945 Mdot
.50552 .6075 Mdot
.65822 .71642 Mdot
.7392 .51149 Mdot
.26854 .39714 Mdot
.74428 .44561 Mdot
.68623 .66403 Mdot
.45728 .45393 Mdot
.23604 .64686 Mdot
.37594 .21119 Mdot
.3652 .45663 Mdot
.53104 .56706 Mdot
.74631 .59135 Mdot
.61391 .33767 Mdot
.83279 .6667 Mdot
.20162 .3262 Mdot
.40979 .38895 Mdot
.5828 .44529 Mdot
.60618 .37298 Mdot
.62622 .54264 Mdot
.24936 .42389 Mdot
.41552 .22013 Mdot
.49354 .65163 Mdot
.7633 .51219 Mdot
.47226 .73693 Mdot
.3802 .68033 Mdot
.54334 .30388 Mdot
.4245 .6138 Mdot
.24549 .2669 Mdot
.78667 .39758 Mdot
.40387 .70286 Mdot
.8643 .59042 Mdot
.48424 .7556 Mdot
.34048 .5051 Mdot
.5619 .20636 Mdot
.30114 .23736 Mdot
.62816 .4029 Mdot
.74787 .55949 Mdot
.18761 .47611 Mdot
.63755 .36 Mdot
.63342 .27647 Mdot
.57221 .76505 Mdot
.54447 .75643 Mdot
.61629 .65279 Mdot
.75404 .66853 Mdot
.19832 .57976 Mdot
.26712 .35069 Mdot
.34023 .2326 Mdot
.69169 .68403 Mdot
.42806 .85149 Mdot
.49786 .15494 Mdot
.60562 .29517 Mdot
.58962 .71632 Mdot
.58546 .2118 Mdot
.58762 .39301 Mdot
.27021 .53173 Mdot
.70027 .67729 Mdot
.33539 .46851 Mdot
.73922 .67613 Mdot
.52993 .79334 Mdot
.63858 .2956 Mdot
.26548 .51742 Mdot
.55112 .49719 Mdot
.40505 .23652 Mdot
.65755 .74855 Mdot
.65517 .3716 Mdot
.76761 .52461 Mdot
.56741 .36564 Mdot
.43885 .21288 Mdot
.57017 .19612 Mdot
.53012 .50536 Mdot
.22489 .72911 Mdot
.27701 .2737 Mdot
.47582 .78132 Mdot
.44007 .33057 Mdot
.45638 .14718 Mdot
.50332 .50648 Mdot
.21676 .37936 Mdot
.75682 .33833 Mdot
.71554 .55337 Mdot
.27491 .67007 Mdot
.40392 .36415 Mdot
.199 .40971 Mdot
.33672 .31683 Mdot
.27273 .50377 Mdot
.71233 .63095 Mdot
.63904 .37898 Mdot
.64786 .75045 Mdot
.54871 .32658 Mdot
.37128 .37836 Mdot
.36953 .53902 Mdot
.25716 .26569 Mdot
.48884 .28912 Mdot
.47374 .46631 Mdot
.51841 .32755 Mdot
.5682 .82513 Mdot
.84187 .58965 Mdot
.37399 .37534 Mdot
.40298 .75567 Mdot
.67298 .32137 Mdot
.5438 .23575 Mdot
.19171 .44471 Mdot
.44952 .91288 Mdot
.70873 .25533 Mdot
.2985 .53202 Mdot
.21786 .51934 Mdot
.65238 .38513 Mdot
.32691 .21478 Mdot
.77815 .62478 Mdot
.72109 .59758 Mdot
.56962 .84064 Mdot
.59861 .40484 Mdot
.49794 .39207 Mdot
.79624 .37368 Mdot
.50114 .16 Mdot
.66026 .75755 Mdot
.42615 .16624 Mdot
.38697 .38992 Mdot
.45475 .32396 Mdot
.63988 .8534 Mdot
.4242 .19476 Mdot
.39886 .42956 Mdot
.53555 .8379 Mdot
.27499 .57912 Mdot
.48929 .39395 Mdot
.57312 .66865 Mdot
.70796 .35298 Mdot
.61818 .26824 Mdot
.36579 .18568 Mdot
.37921 .57171 Mdot
.6893 .64485 Mdot
.4474 .66912 Mdot
.57271 .47034 Mdot
.51419 .36387 Mdot
.45426 .66299 Mdot
.59007 .26329 Mdot
.51859 .49806 Mdot
.43886 .6766 Mdot
.73035 .38288 Mdot
.82578 .38778 Mdot
.36257 .2947 Mdot
.48945 .59398 Mdot
.54437 .38292 Mdot
.35984 .44796 Mdot
.57278 .28441 Mdot
.54712 .25568 Mdot
.75648 .32355 Mdot
.77533 .27718 Mdot
.65661 .50552 Mdot
.42836 .30525 Mdot
.37947 .5086 Mdot
.26331 .3917 Mdot
.34943 .27694 Mdot
.45771 .69913 Mdot
.64756 .68255 Mdot
.39331 .37124 Mdot
.37192 .37294 Mdot
.43529 .61817 Mdot
.15494 .38724 Mdot
.48052 .35469 Mdot
.23498 .39307 Mdot
.55263 .17655 Mdot
.7338 .58601 Mdot
.38213 .28397 Mdot
.42355 .43942 Mdot
.24356 .61431 Mdot
.49496 .50798 Mdot
.52733 .4726 Mdot
.72577 .57469 Mdot
.34369 .21382 Mdot
.35417 .32641 Mdot
.25983 .34712 Mdot
.43904 .37448 Mdot
.6604 .41804 Mdot
.31985 .69631 Mdot
.18155 .43824 Mdot
.36372 .40838 Mdot
.56569 .1689 Mdot
.71518 .54593 Mdot
.74166 .43308 Mdot
.40865 .26969 Mdot
.26117 .27799 Mdot
.49515 .80871 Mdot
.33295 .28894 Mdot
.38383 .77635 Mdot
.54033 .69193 Mdot
.57919 .29694 Mdot
.66895 .53239 Mdot
.41465 .31699 Mdot
.28329 .59209 Mdot
.29057 .21219 Mdot
.18153 .44961 Mdot
.52391 .66714 Mdot
.69619 .55034 Mdot
.31889 .35731 Mdot
.56617 .47382 Mdot
.88032 .54568 Mdot
.81017 .58548 Mdot
.24091 .27105 Mdot
.59999 .24517 Mdot
.36926 .49727 Mdot
.41696 .73212 Mdot
.52107 .40564 Mdot
.66917 .56337 Mdot
.33234 .21465 Mdot
.38437 .32974 Mdot
.53049 .7865 Mdot
.49557 .3806 Mdot
.34358 .75357 Mdot
.44407 .51075 Mdot
.59787 .56674 Mdot
.608 .58274 Mdot
.47789 .82862 Mdot
.53916 .18979 Mdot
.48762 .51152 Mdot
.86696 .52041 Mdot
.34899 .24519 Mdot
.44845 .17843 Mdot
.64434 .52055 Mdot
.38762 .80917 Mdot
.40127 .59032 Mdot
.42556 .50925 Mdot
.51118 .68867 Mdot
.54783 .35002 Mdot
.4392 .75713 Mdot
.56027 .2403 Mdot
.30877 .66756 Mdot
.46582 .59347 Mdot
.86419 .35078 Mdot
.60911 .28706 Mdot
.36732 .44053 Mdot
.48541 .76886 Mdot
.43198 .17297 Mdot
.66919 .48779 Mdot
.81451 .38598 Mdot
.57244 .57287 Mdot
.50115 .34302 Mdot
.34082 .41449 Mdot
.41938 .25533 Mdot
.48161 .73557 Mdot
.21587 .69052 Mdot
.7676 .37837 Mdot
.72807 .46226 Mdot
.565 .57509 Mdot
.3433 .5305 Mdot
.31347 .52635 Mdot
.76636 .61511 Mdot
.84518 .43777 Mdot
.47582 .49871 Mdot
.40933 .20334 Mdot
.28721 .7675 Mdot
.64471 .27069 Mdot
.33694 .20427 Mdot
.39748 .61084 Mdot
.35875 .61296 Mdot
.57111 .2776 Mdot
.67325 .39914 Mdot
.61254 .57775 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0W_ooool3o`00
0:Sooooo000Looooo`;o0000Woooool3o`000:Sooooo000Looooo`03o`000?oooooooooo08Cooooo
0_l00033ooooo`007?ooool00ol0003oooooooooo`24ooooo`;o0000`oooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2/ooooo`;o0000Voooool001co
oooo00?o0000ooooooooool0[?ooool2o`0001?ooooo0_l00026ooooo`007?ooool00ol0003ooooo
ooooo`2aooooo`;o00000_ooool2o`0000;ooooo0_l00006ooooo`;o0000Q_ooool001cooooo00?o
0000ooooooooool0/Oooool2o`0000;ooooo0_l00002ooooo`;o0000S_ooool001cooooo00?o0000
ooooooooool0]Oooool2o`0000Sooooo0_l00028ooooo`007?ooool00ol0003oooooooooo`2Roooo
o`;o00006oooool2o`0008Sooooo000Looooo`03o`000?oooooooooo0:;ooooo0_l0002Uooooo`00
7?ooool00ol0003oooooooooo`3;ooooo`;o0000O?ooool001cooooo00?o0000ooooooooool0booo
ool2o`0007cooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0[Oooool2o`0009[ooooo000Looooo`03o`000?oooooooooo093ooooo0_l0000Kooooo`;o
0000V_ooool001cooooo00?o0000ooooooooool0T?ooool2o`0000oooooo0_l00002ooooo`;o0000
X_ooool001cooooo0_l0002Cooooo`;o00003Oooool2o`0000;ooooo0_l00007ooooo`;o00001ooo
ool2o`00093ooooo000Looooo`03o`000?oooooooooo09;ooooo0_l0000:ooooo`;o00002?ooool2
o`0000Cooooo0_l00007ooooo`;o0000T?ooool001cooooo00?o0000ooooooooool0R_ooool2o`00
00oooooo0_l000001?oooooo0000o`000?l00007ooooo`;o00000oooool2o`0000Cooooo0_l0002D
ooooo`007?ooool00ol0003oooooooooo`21ooooo`?o00001_ooool2o`0000Cooooo0_l00005oooo
o`;o00000_ooool3o`000003ooooool0003o000000cooooo0_l00004ooooo`;o00001Oooool2o`00
08gooooo000Looooo`03o`000?oooooooooo087ooooo0ol000000ooooooo0000o`000002o`0000Oo
oooo0_l00005ooooo`;o00000oooool2o`0000cooooo0_l0000>ooooo`;o0000SOooool001cooooo
00?o0000ooooooooool0POooool2o`0000;ooooo1?l0000Hooooo`;o00001oooool2o`0000Sooooo
0_l0000Vooooo`;o0000Joooool001cooooo00?o0000ooooooooool0POooool2o`0000Cooooo0_l0
000Fooooo`Co00004Oooool2o`0000Oooooo0ol0000Looooo`;o0000Joooool001cooooo00?o0000
ooooooooool0QOooool2o`0000;ooooo0_l0000?ooooo`;o000000?oooooo`000?l000001Ol00005
ooooo`;o00004_ooool5o`0008Oooooo000Looooo`03o`000?oooooooooo07Kooooo0_l0000=oooo
o`;o00000_ooool2o`000003ooooool0003o000000;o00001Oooool2o`0000?ooooo0_l000001?oo
oooo0000o`000?ooool4o`0000Gooooo0_l000000ooooooo0000o`000002ooooo`;o00001?ooool4
o`0000Kooooo0_l00027ooooo`007?ooool00ol0003oooooooooo`1fooooo`;o00001oooool3o`00
00[ooooo2?l000000ooooooo0000o`000009ooooo`Co00000_ooool2o`0000Cooooo0_l00002oooo
o`;o00001?ooool4o`0008oooooo000Looooo`03o`000?oooooooooo06kooooo0_l0000?ooooo`?o
00001_ooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`0000Kooooo0_l00004ooooo`Co
00000_ooool2o`0000Sooooo1?l00003ooooo`?o0000Soooool001cooooo00?o0000ooooooooool0
K_ooool2o`000003ooooool0003o000000?o00003_ooool2o`0000;ooooo0_l0000<ooooo`;o0000
0_ooool2o`0000Cooooo0ol0000:ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o0000
2?ooool2o`0008Oooooo000Looooo`03o`000?oooooooooo077ooooo1Ol00006ooooo`;o00001?oo
ool4o`00013ooooo0_l00008ooooo`;o00002Oooool4o`0000Oooooo0_l000001?oooooo0000o`00
0?ooool6o`000003ooooool0003o000000;ooooo0_l00020ooooo`0000Koooooonk^k_lb<S;o0000
oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0MOooool2o`0000;o
oooo1Ol00004ooooo`;o00009_ooool3o`0000Wooooo0_l000001?oooooo0000o`000?ooool4o`00
00?ooooo1_l00020ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0I?ooool2o`0000cooooo0_l0
00001?oooooo0000o`000?ooool8o`0000;ooooo0_l00002ooooo`;o00005_ooool2o`0000[ooooo
0_l000000ooooooo0000o`000006ooooo`?o000000?oooooo`000?l000002_ooool2o`0008;ooooo
00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00ol0003oooooooooo`1Tooooo`;o00003?ooool2o`0000Cooooo0_l00002ooooo`So00000_oo
ool2o`0001Kooooo0_l0000=ooooo`;o00001_ooool2o`0001?ooooo0_l0000Looooo`;o0000Gooo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06
ooooo`?o0000J_ooool2o`0000cooooo0_l00006ooooo`;o00007oooool2o`0000Cooooo0_l0000O
ooooo`Go00006oooool2o`0005oooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`1Nooooo`;o00002?ooool4o`00
00cooooo0_l00006ooooo`?o00001Oooool3o`0000gooooo1?l00005ooooo`;o00001?ooool2o`00
01cooooo0_l000001?oooooo0000o`000?ooool2o`0007cooooo00000ooooooo410@ooooo`02oooo
o`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Noooo
o`;o00002?ooool4o`0000Cooooo0_l0000>ooooo`?o00001Oooool3o`0000gooooo1?l0000;oooo
o`;o000000?oooooo`000?l000001oooool2o`0000Gooooo1?l00007ooooo`;o00001Oooool2o`00
07_ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@
4006ooooo`03o`000?oooooooooo05[ooooo0ol0000>ooooo`;o00000oooool2o`0000Cooooo0_l0
000_ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l00005ooooo`Co00000ooo
ool2o`0000Oooooo1?l0001kooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Jooooo`?o000000?oooooo`000?l0
00001?ooool6o`000004ooooool0003o0000o`0000Sooooo0_l00008ooooo`;o00002Oooool2o`00
00;ooooo0_l000000ooooooo0000o`000005ooooo`;o00004Oooool4o`0000Gooooo0_l00003oooo
o`;o00001Oooool2o`0000Oooooo0_l0001mooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o
00001?ooool6o`0000;ooooo0_l0000Booooo`;o00001?ooool2o`0000?ooooo0_l00002ooooo`;o
000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00001_ooool2o`0000Wooooo0ol00006oooo
o`;o00005Oooool2o`0007_ooooo000Looooo`03o`000?oooooooooo07?ooooo0_l0000>ooooo`;o
000000?oooooo`000?l000003?ooool3o`0000[ooooo0_l0000Booooo`;o00005Oooool2o`0007_o
oooo000Looooo`03o`000?oooooooooo07?ooooo0_l0000>ooooo`Oo00002_ooool2o`0001oooooo
0_l0000:ooooo`;o00002Oooool2o`0000?ooooo0ol0001eooooo`007?ooool00ol0003ooooooooo
o`1Yooooo`;o00005_ooool5o`000004ooooool0003o0000o`0001Oooooo1Ol00004ooooo`;o0000
5Oooool2o`0000Cooooo0_l00008ooooo`?o0000MOooool001cooooo00?o0000ooooooooool0JOoo
ool2o`0000Gooooo0_l0000?ooooo`?o00007Oooool6o`0000?ooooo0_l00005ooooo`;o00000ooo
ool2o`0000;ooooo0_l00002ooooo`;o00001oooool2o`000004ooooool0003o0000o`0000Gooooo
0ol0001dooooo`007?ooool00ol0003oooooooooo`1[ooooo`;o00000oooool2o`0002Wooooo0_l0
0005ooooo`;o000000Coooooo`000?l0003ooooo0_l00007ooooo`;o00000oooool2o`0000;ooooo
0_l00002ooooo`;o00001Oooool2o`0000?ooooo0ol00002ooooo`;o00000_ooool2o`0007Cooooo
000Looooo`03o`000?oooooooooo06_ooooo0_l00005ooooo`;o00001?ooool2o`0000Kooooo0_l0
000Iooooo`;o00000_ooool2o`0000Oooooo1?l000000ooooooo0000o`000008ooooo`;o00003?oo
ool2o`0000?ooooo0_l00003ooooo`;o000000Coooooo`000?l0003o0000M?ooool001cooooo00?o
0000ooooooooool0G_ooool2o`0000Cooooo0_l0000<ooooo`;o00001?ooool2o`0000Kooooo0_l0
000Mooooo`;o000000?oooooo`000?l000001_ooool5o`0000Sooooo0ol0000Hooooo`Ko0000LOoo
ool001cooooo00?o0000ooooooooool0Doooool2o`0000Sooooo0ol00004ooooo`;o00003_ooool2
o`0002Cooooo1_l00002ooooo`;o00002?ooool2o`0000Cooooo0_l00004ooooo`;o00005_ooool2
o`0000?ooooo1Ol00006ooooo`;o0000Ioooool001cooooo00?o0000ooooooooool0B_ooool2o`00
00Oooooo0_l00008ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Kooooo0_l00004oooo
o`;o00000_ooool2o`0000_ooooo0_l0000Cooooo`Ko00003_ooool2o`0000;ooooo0_l0000;oooo
o`;o00000_ooool2o`0000_ooooo0_l00003ooooo`;o000000?oooooo`000?l000001_ooool2o`00
06Oooooo000Looooo`03o`000?oooooooooo04[ooooo0_l0000:ooooo`;o00000_ooool2o`0000Co
oooo0_l00004ooooo`;o000000?oooooo`000?l000000oooool2o`0000;ooooo0_l00004ooooo`?o
00002_ooool2o`0000Gooooo0_l0000Pooooo`Co00001_ooool2o`0000Gooooo0_l00002ooooo`;o
00000_ooool2o`0000cooooo0_l00003ooooo`Co00006oooool2o`0004kooooo000Looooo`;o0000
D_ooool2o`0000?ooooo0_l00002ooooo`;o00003Oooool2o`0000Oooooo0_l00005ooooo`;o0000
4Oooool2o`000003ooooool0003o0000013ooooo0_l0000;ooooo`Co000000?oooooo`000?l00000
0oooool2o`0000gooooo0_l00007ooooo`;o00002?ooool6o`0001Wooooo0_l0001>ooooo`007?oo
ool00ol0003oooooooooo`1Aooooo`;o00000_ooool2o`0002_ooooo1?l00009ooooo`;o00000_oo
ool2o`0000Cooooo0_l00006ooooo`;o00002oooool2o`0000?ooooo0_l00008ooooo`;o00000ooo
ool3o`0000_ooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000000_l0
0002ooooo`;o0000IOooool001cooooo00?o0000ooooooooool0EOooool2o`0000Wooooo0_l0000=
ooooo`;o00004Oooool4o`0000gooooo0_l00004ooooo`;o00004oooool2o`0000gooooo0_l00003
ooooo`?o00001oooool2o`0000Gooooo1?l00002ooooo`;o000000Coooooo`000?l0003o00000_oo
ool3o`0006Gooooo000Looooo`03o`000?oooooooooo063ooooo0_l00006ooooo`?o00001?ooool2
o`0000?ooooo0_l00007ooooo`;o00000oooool2o`0000?ooooo0_l0000@ooooo`;o00004oooool3
o`0000;ooooo0_l00004ooooo`;o00000oooool2o`000003ooooool0003o000000Gooooo0_l00002
ooooo`?o00001_ooool2o`0000[ooooo0_l0001Vooooo`007?ooool00ol0003oooooooooo`1Ooooo
o`;o00001oooool3o`0000Oooooo1_l00005ooooo`;o00000oooool2o`0000?ooooo0_l0000:oooo
o`;o000000Coooooo`000?l0003ooooo0_l00009ooooo`;o00002Oooool2o`0000;ooooo0_l00004
ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000005ooooo`;o00000oooool2
o`00017ooooo0_l0001Wooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00000_ooool2o`00
0003ooooool0003o000000;ooooo0_l00006ooooo`;o00004Oooool2o`0000;ooooo0_l0000?oooo
o`;o00002_ooool2o`000003ooooool0003o000000cooooo0_l0000Fooooo`;o00003Oooool2o`00
017ooooo1Ol00003ooooo`;o0000HOooool001cooooo00?o0000ooooooooool0C?ooool2o`0000;o
oooo0_l000000ooooooo0000o`000002ooooo`;o0000:?ooool4o`0000;ooooo0_l0000=ooooo`;o
0000;Oooool2o`0000Cooooo0_l000000ooooooo0000o`00000>ooooo`;o000000?oooooo`000?l0
00000oooool2o`00067ooooo000Looooo`03o`000?oooooooooo04_ooooo0_l00009ooooo`;o0000
3Oooool2o`0000;ooooo0_l000000ooooooo0000o`00000Cooooo`Co00001oooool2o`0000;ooooo
0_l000000ooooooo0000o`00000Aooooo`;o00002?ooool2o`0001?ooooo1?l00005ooooo`;o0000
1oooool2o`0000Kooooo0_l00006ooooo`;o000000?oooooo`000?l00000GOooool001cooooo00?o
0000ooooooooool0Boooool2o`0000Oooooo1?l0000;ooooo`Co00000_ooool2o`000003ooooool0
003o000000;o00007?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000Aooooo`;o00002?oo
ool2o`0001?ooooo1?l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000000_oo
ool2o`0000Kooooo0_l00002ooooo`Ko000000?oooooo`000?l000005oooool2o`0004Cooooo000L
ooooo`03o`000?oooooooooo057ooooo1Ol0000;ooooo`Co00002Oooool2o`0000?ooooo0_l00004
ooooo`;o00008_ooool2o`0001Oooooo0_l0000Booooo`;o00001?ooool5o`0000Oooooo0_l00005
ooooo`Co00000_ooool2o`0000gooooo0_l00009ooooo`;o0000A?ooool001cooooo00?o0000oooo
ooooool0DOooool4o`0000Oooooo0_l00003ooooo`;o00003?ooool2o`0000;ooooo0_l00004oooo
o`;o00002_ooool2o`0000Cooooo0_l00009ooooo`;o00001Oooool2o`0000Gooooo0ol00003oooo
o`;o00002_ooool2o`0000Wooooo0_l00002ooooo`;o00001Oooool2o`0000Cooooo0_l00005oooo
o`;o000000?oooooo`000?l000002oooool2o`0000gooooo0_l0001?ooooo`007?ooool00ol0003o
ooooooooo`19ooooo`Co00003oooool2o`00017ooooo0_l00007ooooo`?o00002_ooool2o`000004
ooooool0003o0000ooooo`;o00001oooool4o`0000cooooo0ol00003ooooo`;o000000?oooooo`00
0?l000001oooool2o`0000Wooooo0_l00002ooooo`;o00001Oooool2o`0000_ooooo0_l0000=oooo
o`Co0000GOooool001cooooo00?o0000ooooooooool0AOooool3o`000003ooooool0003o000000;o
00006oooool2o`000003ooooool0003o000000;ooooo0_l00007ooooo`Co00002Oooool2o`000003
ooooool0003o000000Oooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l0000@oooo
o`;o00001?ooool2o`000004ooooool0003o0000o`0000Wooooo0_l000000ooooooo0000o`00000B
ooooo`;o00002?ooool4o`000003ooooool0003o000000?o0000G?ooool001cooooo00?o0000oooo
ooooool0AOooool3o`0000gooooo0_l0000Aooooo`;o000000?oooooo`000?l000003Oooool2o`00
01Cooooo0ol00004ooooo`;o00000_ooool2o`0000kooooo0_l00006ooooo`;o00000_ooool2o`00
00Wooooo0_l00006ooooo`;o00005oooool4o`0000Cooooo0_l0001Looooo`007?ooool00ol0003o
ooooooooo`16ooooo`;o00002Oooool2o`0000;ooooo0_l0000Eooooo`Co00000_ooool2o`0001Go
oooo0_l00005ooooo`;o000000?oooooo`000?l000000_l0000Dooooo`;o00000_ooool2o`0000?o
oooo0_l000001?oooooo0000o`000?l00007ooooo`;o00000_ooool2o`0000?ooooo1?l0000Coooo
o`;o00001?ooool2o`0000;ooooo0_l0001Looooo`007?ooool00ol0003oooooooooo`1Aooooo`;o
00006Oooool4o`000003ooooool0003o000000;o00001Oooool2o`0000gooooo0_l00008ooooo`Ko
00005_ooool3o`0000;ooooo0_l000001?oooooo0000o`000?l00007ooooo`;o000000Goooooo`00
0?l0003o0000ooooo`02o`0000;ooooo0_l0000Cooooo`;o00001?ooool2o`00063ooooo000Loooo
o`;o0000FOooool4o`0000?ooooo0_l0000@ooooo`Co00000_ooool2o`000003ooooool0003o0000
01Oooooo0ol000000ooooooo0000o`00000Gooooo`;o00001Oooool3o`0000[ooooo0_l00002oooo
o`;o00000_ooool2o`000003ooooool0003o000000Kooooo0_l00002ooooo`?o00001oooool2o`00
00Gooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`1Eooooo`;o000000?oooooo`000?l0
00000_l00003ooooo`Co00003_ooool2o`0000Cooooo0_l0000Kooooo`;o00001Oooool2o`00013o
oooo0_l00004ooooo`;o00006_ooool2o`0000Kooooo0_l00002ooooo`?o00001Oooool5o`0000Co
oooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00000oooool2o`0000Gooooo
0_l0000:ooooo`?o00000_ooool2o`0000Wooooo0_l0000Dooooo`;o00000oooool2o`0000gooooo
0_l0000@ooooo`;o00001?ooool2o`0001Oooooo0_l00005ooooo`;o00003_ooool2o`000003oooo
ool0003o000000Kooooo0_l000000ooooooo0000o`000006ooooo`;o0000C_ooool001cooooo00?o
0000ooooooooool0BOooool2o`0000?ooooo0_l0000Aooooo`?o000000Coooooo`000?l0003o0000
3Oooool2o`0000Oooooo1?l00005ooooo`;o00000oooool2o`0000[ooooo0_l00005ooooo`;o0000
3_ooool2o`0000Oooooo0_l0000Booooo`;o00001Oooool2o`0000Gooooo0_l000000ooooooo0000
o`000003ooooo`?o00002Oooool2o`000003ooooool0003o000000Kooooo0_l0001>ooooo`007?oo
ool00ol0003oooooooooo`1=ooooo`;o00002_ooool2o`0000Kooooo0ol000000ooooooo0000o`00
000;ooooo`;o000000?oooooo`000?l000001Oooool6o`0000Gooooo0_l0000:ooooo`Wo00000ooo
ool2o`0000Kooooo0_l00006ooooo`;o00000_ooool2o`0000?ooooo0_l0000Pooooo`;o000000?o
ooooo`000?l000000_ooool3o`00013ooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`0o
ooooo`;o00003?ooool2o`0000[ooooo0ol00002ooooo`;o000000?oooooo`000?l000001oooool2
o`0000Kooooo0_l00008ooooo`;o00001Oooool2o`000003ooooool0003o000000?ooooo0_l00005
ooooo`co00002Oooool2o`0000Oooooo0_l000000ooooooo0000o`00000?ooooo`;o00001_ooool2
o`0000Gooooo0_l0000;ooooo`?o00004Oooool2o`0005?ooooo000Looooo`03o`000?oooooooooo
03oooooo0_l00007ooooo`;o00002Oooool2o`0000Gooooo0_l00002ooooo`;o000000Coooooo`00
0?l0003o00001_ooool2o`0000kooooo0_l00007ooooo`;o000000?oooooo`000?l000000_l00000
0ooooooo0000o`000005ooooo`Go000000?oooooo`000?l000001?l00004ooooo`;o00003?ooool2
o`000003ooooool0003o000000oooooo0_l00002ooooo`?o000000?oooooo`000?l000001Oooool2
o`000004ooooool0003o0000ooooo`?o00000_ooool4o`0000;ooooo0_l0001Sooooo`007?ooool0
0ol0003oooooooooo`18ooooo`;o00000oooool2o`0000Cooooo0_l00009ooooo`;o00000_ooool2
o`0001Kooooo0_l00005ooooo`;o00001Oooool2o`0000?ooooo0ol00003ooooo`;o00000_ooool2
o`000004ooooool0003o0000o`0000Gooooo0_l0000Tooooo`Co00000_ooool2o`0000Cooooo2?l0
0002ooooo`;o00001?ooool2o`0000?ooooo0_l0001Nooooo`007?ooool00ol0003oooooooooo`0n
ooooo`;o00003Oooool2o`0001[ooooo0_l000000ooooooo0000o`000009ooooo`;o00002?ooool4
o`0000Cooooo0_l00002ooooo`Oo00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000006
ooooo`;o00003oooool2o`00017ooooo0_l00002ooooo`;o00001?ooool5o`0000Oooooo0_l00000
0ooooooo0000o`000003ooooo`?o00001_ooool3o`0000;ooooo0_l0001Aooooo`007?ooool00ol0
003oooooooooo`0nooooo`;o0000:Oooool5o`000003ooooool0003o000000;ooooo0_l00002oooo
o`;o00002_ooool2o`000004ooooool0003o0000ooooo`Co000000?oooooo`000?l000001Ol00002
ooooo`Co00000oooool4o`0000?ooooo0ol00006ooooo`;o00001oooool2o`0000cooooo0_l0000>
ooooo`;o00002Oooool2o`000004ooooool0003o0000ooooo`Ko00001Oooool3o`0000;ooooo0_l0
001Aooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00001Oooool2o`0000Wooooo0_l00002
ooooo`;o00001?ooool4o`0000?ooooo0_l00007ooooo`;o00000oooool2o`0000;ooooo0_l00004
ooooo`;o00002oooool4o`000005ooooool0003o0000o`000?ooool01_l000000ooooooo0000o`00
0004o`000003ooooool0003o000000?o00000oooool2o`0000Oooooo0_l0000=ooooo`;o00001_oo
ool2o`0000Cooooo0_l00006ooooo`Co00003?ooool2o`000003ooooool0003o000000;ooooo0_l0
0005ooooo`Co0000E?ooool001cooooo00?o0000ooooooooool0?Oooool2o`0000Kooooo0_l00009
ooooo`;o00000_ooool2o`0000Cooooo1?l00003ooooo`Co00002?ooool4o`0000Sooooo0_l00006
ooooo`Wo000000?oooooo`000?l000003?l000000ooooooo0000o`000003o`0001_ooooo0_l00000
0ooooooo0000o`000002ooooo`;o00002?ooool2o`0000?ooooo0_l000000ooooooo0000o`000002
o`000003ooooool0003o000000Wooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00001ooo
ool2o`0005Cooooo000Looooo`03o`000?oooooooooo03_ooooo1?l0000<ooooo`;o00001oooool2
o`0000;ooooo0_l00002ooooo`;o00001?ooool3o`000003ooooool0003o000000Gooooo1?l0000@
ooooo`[o00000_ooool<o`000003ooooool0003o000000?o00006oooool2o`0000Gooooo0_l00000
1Ooooooo0000o`000?l0003ooooo00;o00001_ooool3o`0000;ooooo0_l000000ooooooo0000o`00
000<ooooo`?o00002?ooool3o`0005Gooooo000Looooo`03o`000?oooooooooo03_ooooo0_l00007
ooooo`;o00001Oooool2o`0000_ooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l0000=
ooooo`;o000000?oooooo`000?l000002_l00002oooooa;o00002oooool2o`0001Oooooo1?l00000
0ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000001_ooool2o`0001Kooooo0ol0001E
ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00000_ooool2o`0000?ooooo0_l0000Doooo
o`;o00001Oooool2o`000003ooooool0003o000000cooooo0_l00003ooooo`co00001?oooolEo`00
00Wooooo0_l000000ooooooo0000o`00000=ooooo`Co000000?oooooo`000?l000001?l00004oooo
o`;o000000?oooooo`000?l000000ol00005ooooo`?o00001?ooool2o`00017ooooo0_l00002oooo
o`;o0000DOooool001cooooo00?o0000ooooooooool0@?ooool2o`0000Kooooo0ol00006ooooo`;o
00004oooool2o`000003ooooool0003o000000cooooo4_l000000ooooooo0000o`00000>o`0000;o
oooo0_l000001?oooooo0000o`000?l00004ooooo`;o00000_ooool2o`000003ooooool0003o0000
00;ooooo0_l00009ooooo`Co000000?oooooo`000?l000000_ooool2o`000004ooooool0003o0000
ooooo`;o000000?oooooo`000?l000001?l00004ooooo`;o00001Oooool2o`0000Sooooo0_l0000;
ooooo`?o0000D?ooool001cooooo0_l00019ooooo`?o00001_ooool6o`0000;ooooo0_l00008oooo
o`;o00005?ooool8o`000003ooooool0003o000000Go000000?oooooo`000?l000003_l00002oooo
o`Ko00000oooool3o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`00
00?ooooo0_l00005ooooo`;o00001Oooool2o`000003ooooool0003o000000Gooooo0_l0000;oooo
o`;o00002?ooool4o`0000[ooooo0_l0000Looooo`;o0000<_ooool001cooooo00?o0000oooooooo
ool0AOooool2o`0000;ooooo0_l00008ooooo`Co00000_ooool2o`0000Kooooo1?l0000>ooooo`;o
00001Oooool7o`000003ooooool0003o000001Ko00001?ooool2o`0000Gooooo1?l00003ooooo`Ko
00000oooool2o`0000?ooooo0_l00005ooooo`Co00000oooool2o`000004ooooool0003o0000oooo
o`;o00002Oooool2o`0000;ooooo1?l000000ooooooo0000o`000007ooooo`;o00003_ooool2o`00
00Wooooo0_l0000=ooooo`;o0000<_ooool001cooooo00?o0000ooooooooool0AOooool2o`0000ko
oooo0_l0000:ooooo`;o00004?ooool2o`0000?ooooo1_l00003oooooaWo000000?oooooo`000?l0
00001?ooool3o`000003ooooool0003o000000;o00000oooool2o`0000;ooooo0_l00008ooooo`Co
00000_ooool5o`0000Sooooo0ol000000ooooooo0000o`000006ooooo`;o00000_ooool2o`0000?o
oooo1?l00005ooooo`;o00003Oooool3o`0000Wooooo0_l00011ooooo`007?ooool00ol0003ooooo
ooooo`1Eooooo`;o00002?ooool2o`0000?ooooo0_l00004ooooo`;o00001oooool2o`0000;ooooo
1Ol00003oooooa_o000000Coooooo`000?l0003o00000_ooool4o`000004ooooool0003o0000o`00
00Wooooo0_l000000ooooooo0000o`000004ooooo`Co00000_ooool2o`0000;ooooo0_l00005oooo
o`Go000000?oooooo`000?l000002Oooool2o`0000Kooooo0_l0000Dooooo`;o000000?oooooo`00
0?l00000B_ooool001cooooo00?o0000ooooooooool0A_ooool3o`0000Gooooo0_l00005ooooo`?o
00001?ooool2o`000003ooooool0003o000000?ooooo0_l00004ooooo`;o00001oooool2o`0000;o
oooo1Ol000000ooooooo0000o`00000Ko`000003ooooool0003o000000Go000000Coooooo`000?l0
003ooooo0_l00009ooooo`;o000000?oooooo`000?l000000_ooool2o`0000[ooooo0_l00005oooo
o`Go00003?ooool5o`0000cooooo0_l0000>ooooo`;o0000B_ooool001cooooo00?o0000oooooooo
ool0?_ooool4o`000004ooooool0003o0000ooooo`Co00001?ooool2o`0000Kooooo1?l00002oooo
o`;o00000oooool2o`0000gooooo0_l00005ooooo`;o00001?oooolNo`0000;ooooo1?l00002oooo
o`Co00000_ooool2o`0000[ooooo1Ol0000:ooooo`;o00001_ooool3o`0000Sooooo0_l00005oooo
o`?o00002?ooool2o`0000;ooooo0_l00005ooooo`;o0000Doooool001cooooo00?o0000oooooooo
ool0?_ooool4o`000003ooooool0003o000000?ooooo0_l0000<ooooo`Co00001oooool2o`0000go
oooo0_l00005ooooo`?o00001?oooolQo`0000?ooooo1Ol00002ooooo`;o000000?oooooo`000?l0
00001?ooool2o`000003ooooool0003o000000;o00002oooool2o`0000Gooooo0_l00008ooooo`Co
00001_ooool3o`0000Oooooo0_l00002ooooo`Co00000_ooool3o`0000gooooo0_l00014ooooo`00
7?ooool00ol0003oooooooooo`14ooooo`;o00004?ooool2o`0001oooooo0ol00002ooooo`;o0000
0_oooolQo`000003ooooool0003o000000;o000000?oooooo`000?l000000oooool2o`0000Cooooo
0ol00008ooooo`;o00002_ooool4o`0000Cooooo0_l00002ooooo`;o00002?ooool3o`0000Oooooo
2?l00002ooooo`;o00002oooool2o`000003ooooool0003o000004Cooooo000Looooo`03o`000?oo
oooooooo04Cooooo0_l0000:ooooo`Co00000_ooool2o`0000[ooooo0_l0000Aooooo`?o00000ooo
oolOo`000003ooooool0003o000000Oo00000_ooool3o`0000;ooooo0_l00005ooooo`?o00002?oo
ool2o`0000;ooooo0_l00006ooooo`;o00001_ooool2o`0001Kooooo1?l0000Booooo`?o0000Aooo
ool001cooooo00?o0000ooooooooool0C_ooool6o`0000Cooooo0_l000000ooooooo0000o`000005
ooooo`;o00000_ooool3o`0000Kooooo0_l00004ooooo`?o00000_oooolZo`0000;ooooo0_l00003
ooooo`;o00001Oooool3o`0000Oooooo0_l00003ooooo`;o00009oooool3o`0000Wooooo0_l00007
ooooo`;o00006Oooool2o`0002gooooo000Looooo`03o`000?oooooooooo04?ooooo0_l00009oooo
o`Co00001_ooool2o`000003ooooool0003o000000Wooooo0ol00006ooooo`;o00001?ooool9o`00
0003ooooool0003o0000027o00001?ooool5o`0000;ooooo1?l000000ooooooo0000o`000002o`00
00Kooooo0_l0000>ooooo`;o00002_ooool4o`0000Cooooo0_l00008ooooo`?o00000oooool2o`00
00Cooooo0_l0000<ooooo`?o00004oooool2o`0002gooooo000Looooo`03o`000?oooooooooo03go
oooo0_l00004ooooo`;o00002_ooool3o`0001?ooooo0_l0000@ooooo`Co000000?oooooo`000?l0
00009?l000000ooooooo0000o`000006o`0000;ooooo1?l000000ooooooo0000o`000004o`0000Co
oooo0_l00002ooooo`;o00000oooool5o`000004ooooool0003o0000o`0000?ooooo0_l00005oooo
o`Co00001?ooool4o`0000Gooooo0_l00005ooooo`;o00004_ooool3o`0004;ooooo000Looooo`03
o`000?oooooooooo02oooooo0_l0000<ooooo`;o00004?ooool4o`0001;ooooo0_l0000Aooooo`?o
00000_ooool8o`0000;ooooo6ol000001Ooooooo0000o`000?l0003ooooo00;o00001?ooool2o`00
00Oooooo0_l00008ooooo`;o00000oooool5o`000003ooooool0003o000000?ooooo0ol000000ooo
oooo0000o`000003ooooo`?o00001_ooool2o`0000Gooooo0_l0000Jooooo`;o000000?oooooo`00
0?l00000?oooool001cooooo00?o0000ooooooooool0;oooool2o`0000Oooooo0_l0000Gooooo`;o
000000?oooooo`000?l000004oooool2o`0000gooooo7ol000000ooooooo0000o`00000:o`0000?o
oooo0_l00004ooooo`;o00001oooool2o`0000?ooooo0_l0000?ooooo`;o000000?oooooo`000?l0
00001Ol00004ooooo`;o00003oooool2o`0000Sooooo0_l000000ooooooo0000o`00000;ooooo`;o
000000Coooooo`000?l0003o0000?_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2
ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo03Sooooo0_l0000?
ooooo`;o00001Oooool6o`0001?ooooo0_l0000=ooooobco000000?oooooo`000?l000000_l00000
0ooooooo0000o`00000:ooooo`;o00000oooool2o`0000oooooo0_l000001?oooooo0000o`000?oo
ool2o`0000Kooooo0_l000000ooooooo0000o`000002ooooo`;o00002?ooool2o`0000Sooooo0_l0
00000ooooooo0000o`000007ooooo`;o00001Oooool3o`0003kooooo00001_ooooooMgMgoiRHV?oo
ooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
BOooool2o`0000Gooooo1_l00008ooooo`;o00000oooool2o`0000_ooooo0_l00008ooooo`;o0000
00?oooooo`000?l000003ol000000ooooooo0000o`00000@o`0000;ooooo2Ol000000ooooooo0000
o`000007ooooo`?o00000_ooool2o`0000Gooooo0_l00005ooooo`Co00000_ooool2o`0000Kooooo
1Ol000000ooooooo0000o`000002ooooo`;o00003_ooool2o`0000kooooo0_l00016ooooo`0000?o
oooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`Go00001_ooool00ol0003ooooooooo
o`0oooooo`;o00004oooool2o`0000Sooooo0_l00003ooooo`;o00002Oooool4o`0000Gooooo0_l0
00001?oooooo0000o`000?oooolAo`000003ooooool0003o000000oo00000oooool2o`0000;ooooo
1?l00002ooooo`;o00002?ooool2o`0000;ooooo0_l00004ooooo`?o00001Oooool4o`0000Cooooo
0_l00002ooooo`Oo00005Oooool2o`0000Kooooo0_l000000ooooooo0000o`000003ooooo`;o0000
A_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?m4A4CogMgMoooo
ool00007ooooo`?o0000?oooool3o`0000cooooo0_l00008ooooo`;o00001?ooool3o`0000gooooo
0_l00006ooooobOo000000?oooooo`000?l000001Ol00002ooooo`;o00003_ooool6o`0000Cooooo
0_l00003ooooo`Co00000oooool2o`0000;ooooo0_l00002ooooo`Co000000?oooooo`000?l00000
3Oooool2o`0000Cooooo0_l00008ooooo`;o000000?oooooo`000?l000007Oooool2o`0002cooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo0000
1oooool00ol0003oooooooooo`0nooooo`Co00003?ooool3o`0000;ooooo1?l000000ooooooo0000
o`000005ooooo`?o00005?ooool2o`000003ooooool0003o000002ko00002oooool=o`0000Gooooo
1Ol00002ooooo`;o00006_ooool2o`000004ooooool0003o0000ooooo`;o00002Oooool2o`0000Go
oooo0_l00005ooooo`;o00000_ooool2o`0000gooooo0_l0000/ooooo`0000?ooooooa0@4?ooool0
0_ooool00ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0
?_ooool2o`0000oooooo0_l00002ooooo`Co00002Oooool2o`00013ooooo0_l00005ooooo`Co0000
00?oooooo`000?l000008?l000001Ooooooo0000o`000?l0003ooooo00;o00002?ooool2o`0000?o
oooo1_l000000ooooooo0000o`000004o`0000Kooooo1?l0000Hooooo`;o00001oooool2o`0000co
oooo0_l00005ooooo`Co00000oooool2o`000004ooooool0003o0000o`0003_ooooo00001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0m
ooooo`;o00003?ooool4o`0002?ooooo0_l00005ooooo`Co00000_oooolFo`0000;ooooo3Ol00008
ooooo`;o000000?oooooo`000?l000000_ooool7o`0000;ooooo0ol00008ooooo`;o00000_ooool2
o`0000Sooooo0ol000000ooooooo0000o`000002o`0000Kooooo0_l000000ooooooo0000o`00000B
ooooo`;o00001Oooool4o`0000Gooooo0ol0000looooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^
k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0?Oooool2o`0000cooooo1?l0
0004ooooo`;o00005_ooool2o`0000kooooo0_l00003ooooob?o00002Oooool2o`0000Gooooo1?l0
00000ooooooo0000o`000004o`0000;ooooo0_l00008ooooo`?o00000oooool2o`000003ooooool0
003o000000Wo00000_ooool2o`0000Cooooo0_l00003ooooo`;o00003_ooool2o`0000Cooooo0_l0
0002ooooo`;o00000oooool4o`0003_ooooo000Looooo`03o`000?oooooooooo05?ooooo0_l00000
0ooooooo0000o`000002ooooo`;o00003_ooool3o`0000?ooooo0_l0000>ooooob?o00001_ooool2
o`0000[ooooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l00008ooooo`;o00001?ooool2
o`000003ooooool0003o000000ko00000_ooool2o`0000Cooooo0_l00002ooooo`;o00002_ooool2
o`0000?ooooo0_l00003ooooo`;o00001Oooool2o`0003_ooooo000Looooo`03o`000?oooooooooo
03Cooooo0_l0000Pooooo`;o00000_ooool2o`0000kooooo0_l00004ooooo`;o00001Oooool4o`00
00Cooooo7Ol00003ooooo`Co00001?ooool4o`0000[ooooo0_l000000ooooooo0000o`000006oooo
o`;o00002ooooolFo`0000;ooooo0_l00008ooooo`;o00003oooool4o`0000Wooooo0_l0000joooo
o`007?ooool00ol0003oooooooooo`0dooooo`;o00001?ooool3o`00013ooooo0_l0000Nooooo`;o
00002?ooool4o`0000Cooooo6?l000000ooooooo0000o`000005o`000004ooooool0003o0000o`00
00;ooooo1_l00006ooooo`;o000000Goooooo`000?l0003o0000ooooo`03o`0000Gooooo0_l00004
ooooo`;o00001OoooolFo`000003ooooool0003o000001cooooo0_l00009ooooo`;o0000>_ooool0
01cooooo00?o0000ooooooooool0>_ooool3o`00013ooooo0_l0000Iooooo`;o00000oooool2o`00
00Gooooo1?l00006ooooobGo00000_ooool2o`0000;ooooo0_l00006ooooo`;o000000Coooooo`00
0?l0003o00000_ooool2o`0000Oooooo0_l00002ooooo`;o00000_ooool2o`0000Kooooo4Ol00000
1?oooooo0000o`000?l0000Vooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0;?ooool2
o`0000gooooo0_l00005ooooo`;o00009?ooool2o`0000Kooooo2?l00005oooooago000000Cooooo
o`000?l0003ooooo1Ol0000<ooooo`;o00002?ooool3o`0000?ooooo0_l000000ooooooo0000o`00
0006ooooo`;o00001?ooool2o`0000;ooooo5?l0000Uooooo`;o0000>_ooool001cooooo00?o0000
ooooooooool0;?ooool2o`0000gooooo0_l00004ooooo`?o00009oooool2o`0000?ooooo1?l00004
ooooo`;o00000oooool5o`000003ooooool0003o000001Co000000Coooooo`000?l0003ooooo1_l0
0009ooooo`;o000000?oooooo`000?l000002?ooool3o`0000?ooooo1Ol0000<oooooaGo000000?o
ooooo`000?l000001Oooool2o`00023ooooo0_l0000<ooooo`;o0000:_ooool001cooooo00?o0000
ooooooooool0@Oooool4o`0002Cooooo1?l00009ooooo`Ko00000oooool4o`0000;ooooo2_l00000
0ooooooo0000o`000003o`0000Cooooo1ol00007ooooo`;o00000oooool2o`0000Sooooo0_l00005
ooooo`;o00000_ooool3o`0000Oooooo1Ol000000ooooooo0000o`00000Co`0000Oooooo0_l0000P
ooooo`;o00003?ooool2o`0002[ooooo000Looooo`03o`000?oooooooooo02Wooooo0_l00006oooo
o`;o00001?ooool3o`0000Wooooo0_l0000Tooooo`;o00002oooool2o`0000;ooooo0_l00003oooo
o`Co00000ooooolBo`000003ooooool0003o000000Ko00001_ooool2o`0000?ooooo0_l00003oooo
o`;o00000oooool2o`0000Gooooo1?l00006ooooo`;o00000_ooool5o`000003ooooool0003o0000
01[o00006oooool2o`0000Gooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0Yooooo`;o
00001Oooool3o`0000Cooooo0ol0000_ooooo`;o00002?ooool3o`0000Gooooo0_l00007oooooaCo
00000_ooool2o`000003ooooool0003o000000;o00002oooool2o`0000?ooooo0_l00009ooooo`Go
00001_ooool4o`0000Kooooo7?l0000Kooooo`;o00001Oooool2o`0003Sooooo000Looooo`03o`00
0?oooooooooo033ooooo0_l00005ooooo`;o00000_ooool2o`0002kooooo0_l00006ooooo`?o0000
1Oooool3o`0000Kooooo5?l00007ooooo`;o00003?ooool2o`0000;ooooo0_l000000ooooooo0000
o`000004ooooo`Co00000_ooool2o`0000Oooooo0_l00006oooooaGo00001?ooool6o`0005Wooooo
000Looooo`03o`000?oooooooooo03?ooooo0_l00006ooooo`?o0000;Oooool2o`0000Cooooo0_l0
0004ooooo`;o00000oooool2o`0000;ooooo4ol000000ooooooo0000o`000003o`0000Kooooo0_l0
000<ooooo`;o00001Oooool2o`0000Cooooo0_l00004ooooo`;o00002_ooool2o`0000Cooooo6?l0
0002ooooo`Co00004Oooool2o`0000;ooooo0_l00012ooooo`007?ooool2o`0003Cooooo0_l00002
ooooo`;o000000?oooooo`000?l000000_l0000^ooooo`;o00000oooool2o`0000Cooooo0_l00000
0ooooooo0000o`000002o`0000;ooooo2Ol00004ooooo`Ko00001?ooool2o`000003ooooool0003o
000000?ooooo0ol00002ooooo`Co00005?ooool3o`0000gooooo0_l00004oooooaSo00002Oooool2
o`0000Wooooo0_l000000ooooooo0000o`000002ooooo`;o0000@_ooool001cooooo00?o0000oooo
ooooool0<oooool2o`000005ooooool0003o0000o`000?ooool00_l0000`ooooo`;o00003?ooool3
o`0000Cooooo0_l000000ooooooo0000o`000002o`0000Cooooo1ol000000ooooooo0000o`000002
ooooo`Co00001?ooool2o`0000;ooooo1?l0000Aooooo`;o000000?oooooo`000?l000000_l00006
ooooo`;o00002ooooolCo`0000gooooo0_l000001?oooooo0000o`000?l00005ooooo`;o000000?o
ooooo`000?l00000A_ooool001cooooo00?o0000ooooooooool0=_ooool2o`0000Cooooo0_l00002
ooooo`;o00000oooool2o`0002cooooo1_l00003ooooo`;o00000oooool2o`0000?ooooo0ol00003
ooooo`Co000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00004Oooool2o`0000Sooooo0_l0
0002ooooo`?o000000Coooooo`000?l0003o00001_ooool2o`0000_ooooo5?l00004ooooo`;o0000
2?ooool6o`0000Kooooo0_l0000<ooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0??oo
ool2o`0000;ooooo0_l00003ooooo`;o00007_ooool2o`0000cooooo1_l00003ooooo`;o00000ooo
ool2o`0000?ooooo2_l00008ooooo`;o00001Oooool2o`0000[ooooo0_l00002ooooo`;o00001?oo
ool2o`0000?ooooo1Ol00006ooooo`;o00000_ooool2o`0000Cooooo0ol00002oooooa?o00001?oo
ool2o`0000Sooooo0_l00002ooooo`;o00003Oooool2o`0000Gooooo0_l0000hooooo`007?ooool0
0ol0003oooooooooo`0_ooooo`;o00001_ooool2o`0000?ooooo0_l0000Wooooo`;o00003_ooool2
o`0000Sooooo0ol00003ooooo`?o000000?oooooo`000?l000000_l000001?oooooo0000o`000?l0
0004ooooo`;o00002?ooool2o`000003ooooool0003o000000_ooooo0ol000000ooooooo0000o`00
0005ooooo`?o00002?ooool8o`0000;ooooo0ol00002oooooaCo000000?oooooo`000?l000005?oo
ool2o`0000Oooooo0_l000000ooooooo0000o`00000looooo`007?ooool00ol0003oooooooooo`0_
ooooo`;o00001_ooool2o`000003ooooool0003o000000Co00001oooool3o`0002Sooooo0_l00005
ooooo`;o00001?ooool4o`0000;ooooo0_l000001?oooooo0000o`000?l00002ooooo`Co000000Co
ooooo`000?l0003ooooo0ol0000:ooooo`;o00003?ooool2o`000004ooooool0003o0000ooooo`;o
00000_ooool3o`0000[ooooo0_l00002ooooo`;o00001ooooolDo`000003ooooool0003o000001Co
oooo0_l0000:ooooo`;o00001?ooool2o`0003Kooooo000Looooo`03o`000?oooooooooo02oooooo
0_l00008ooooo`?o00000_ooool3o`0000Kooooo0ol0000Kooooo`;o00000_ooool2o`0000Oooooo
0_l00005ooooo`;o00001Oooool3o`0000Gooooo1?l000001?oooooo0000o`000?ooool4o`0000;o
oooo0_l0000?ooooo`;o00003Oooool2o`0000Kooooo0_l0000DoooooaCo0000:Oooool2o`0003Ko
oooo000Looooo`03o`000?oooooooooo02Cooooo0_l00009ooooo`;o00002?ooool2o`0000Cooooo
0_l0000Tooooo`;o00000_ooool2o`0000?ooooo0_l0000Jooooo`;o00001?ooool4o`000004oooo
ool0003o0000o`0000Cooooo0ol00008ooooo`?o00002_ooool6o`0000Cooooo0_l0000;ooooo`;o
00001OoooolAo`000003ooooool0003o000000;o00003_ooool2o`0000_ooooo0_l000000ooooooo
0000o`000011ooooo`007?ooool00ol0003oooooooooo`0Tooooo`;o00004oooool2o`0003?ooooo
0_l00003ooooo`;o00003?ooool2o`0000Cooooo0ol00008ooooo`;o000000Coooooo`000?l0003o
00001?ooool3o`0000Wooooo0_l00009ooooo`?o000000Coooooo`000?l0003o00000_ooool2o`00
0003ooooool0003o000000[ooooo1?l00003ooooo`go00000oooool2o`000003ooooool0003o0000
00oooooo0_l0000;ooooo`;o000000?oooooo`000?l000000oooool2o`0003cooooo000Looooo`03
o`000?oooooooooo03Wooooo0_l0000booooo`;o00001?ooool2o`0000;ooooo0_l00005ooooo`;o
000000?oooooo`000?l000000oooool4o`0000?ooooo0_l0000Tooooo`;o00000_ooool3o`0000;o
oooo0_l000000ooooooo0000o`00000<ooooo`;o00001Oooool2o`000003ooooool0003o000000Co
00001Oooool2o`000003ooooool0003o000000Sooooo0_l00003ooooo`;o00005Oooool4o`0000;o
oooo0_l0000=ooooo`;o00009oooool001cooooo00?o0000ooooooooool0<oooool2o`0001Cooooo
0_l0000Rooooo`;o00001?ooool6o`0000Cooooo0ol00006ooooo`Co000000?oooooo`000?l00000
0ol0000>ooooo`;o00005Oooool6o`0000Gooooo0_l0000Booooo`Go00001oooool2o`0000gooooo
0_l00003ooooo`;o00001_ooool2o`0000Gooooo0_l00008ooooo`;o00000_ooool2o`0000gooooo
0_l0000Wooooo`007?ooool00ol0003oooooooooo`0cooooo`;o000000?oooooo`000?l000004Ooo
ool2o`0001Cooooo0_l0000Booooo`Co00001_ooool2o`0000Gooooo0_l000001Ooooooo0000o`00
0?l0003ooooo00;o000000?oooooo`000?l000001oooool2o`0000Gooooo0_l0000@ooooo`;o0000
00?oooooo`000?l000000ol000001?oooooo0000o`000?l00002ooooo`Co00004oooool2o`0000Wo
oooo0_l0000?ooooo`;o00002Oooool2o`0000Gooooo0_l00002ooooo`;o00004?ooool2o`0002ko
oooo000Looooo`03o`000?oooooooooo02oooooo0_l00005ooooo`;o00003Oooool2o`00017ooooo
0ol00004ooooo`;o00004?ooool2o`0000[ooooo1?l00002ooooo`?o000000?oooooo`000?l00000
1Oooool2o`0000Oooooo1?l0000<ooooo`;o00001oooool2o`000004ooooool0003o0000ooooo`;o
00000_ooool2o`0000;ooooo0_l0000Fooooo`;o00006Oooool2o`0000Wooooo0_l00009ooooo`;o
00001?ooool2o`0000[ooooo0_l0000^ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o0000
1Oooool2o`0000Wooooo0_l00002ooooo`;o000000?oooooo`000?l000003Oooool4o`0001Kooooo
0_l0000:ooooo`So00001Oooool2o`0000gooooo0_l0000<ooooo`;o00001Oooool2o`000004oooo
ool0003o0000ooooo`;o00004Oooool2o`0000Sooooo0ol00002ooooo`;o0000=Oooool2o`0003[o
oooo000Looooo`03o`000?oooooooooo03Kooooo0_l00009ooooo`;o00001Oooool2o`0000gooooo
0_l0000Dooooo`;o00002_ooool2o`0000Gooooo0ol00007ooooo`;o00001?ooool2o`0001;ooooo
0_l000000ooooooo0000o`000005ooooo`So00002?ooool2o`0000Kooooo0ol00008ooooo`?o0000
1_ooool2o`0000oooooo0_l0000@ooooo`;o00004?ooool2o`0003Sooooo000Looooo`03o`000?oo
oooooooo06gooooo0ol00004ooooo`;o00000oooool2o`0000;ooooo1?l00006ooooo`;o000000?o
ooooo`000?l000001?ooool2o`0000Gooooo0_l00005ooooo`;o00001?ooool3o`0000Sooooo0ol0
00000ooooooo0000o`000009ooooo`Co00001?ooool2o`0000;ooooo0_l00009ooooo`;o00000ooo
ool2o`0000oooooo0_l0000@ooooo`;o00004?ooool2o`0003Sooooo000Looooo`;o0000<_ooool3
o`000003ooooool0003o0000023ooooo0ol00008ooooo`;o00002_ooool2o`0000Cooooo0_l00007
ooooo`Co00001_ooool2o`000003ooooool0003o000000_ooooo0_l00005ooooo`;o00000_ooool2
o`000003ooooool0003o000000Sooooo0_l0000?ooooo`;o00002?ooool2o`0000Wooooo0_l00000
0ooooooo0000o`00000Cooooo`;o00001oooool2o`0000;ooooo0_l00006ooooo`;o00002?ooool2
o`0003_ooooo000Looooo`03o`000?oooooooooo02gooooo0_l00002ooooo`?o000000?oooooo`00
0?l000000_l00005ooooo`;o00004_ooool2o`000003ooooool0003o000000?o00002?ooool2o`00
00kooooo0_l0000;ooooo`;o00006oooool4o`0000;ooooo0ol00008ooooo`;o00005Oooool2o`00
01;ooooo0_l00002ooooo`;o00003oooool2o`0000Oooooo0_l00002ooooo`;o00001_ooool2o`00
00Sooooo0_l00002ooooo`;o0000=oooool001cooooo00?o0000ooooooooool0;?ooool3o`0000;o
oooo0_l00004ooooo`;o00000oooool6o`0000gooooo1Ol000000ooooooo0000o`000007ooooo`;o
00002oooool3o`0000Cooooo0_l00007ooooo`;o00000_ooool2o`0000oooooo0_l0000:ooooo`Ko
000000?oooooo`000?l000000oooool2o`0000?ooooo0_l0000Dooooo`?o00000_ooool2o`0000Oo
oooo0_l00009ooooo`;o00001oooool2o`0000;ooooo0_l0000Rooooo`;o000000?oooooo`000?l0
00001oooool2o`0002kooooo000Looooo`03o`000?oooooooooo02cooooo0_l00003ooooo`;o0000
2Oooool2o`000003ooooool0003o000000Co00002_ooool4o`0000Cooooo0_l00005ooooo`;o0000
2oooool6o`000004ooooool0003o0000ooooo`So00002Oooool2o`0000Cooooo0_l00002ooooo`;o
00002oooool2o`000004ooooool0003o0000o`0000Gooooo0_l00005ooooo`;o00004_ooool2o`00
00?ooooo0_l00007ooooo`;o00001?ooool2o`0000;ooooo0_l00007ooooo`?o000000Coooooo`00
0?l0003o00003?ooool2o`000003ooooool0003o0000017ooooo0_l0000:ooooo`;o00000oooool2
o`0002Wooooo000Looooo`03o`000?oooooooooo037ooooo0_l00003ooooo`;o00002_ooool3o`00
00Sooooo0_l00006ooooo`Co00004?ooool2o`0000;ooooo1?l000001?oooooo0000o`000?ooool7
o`0000[ooooo0_l00004ooooo`;o00003Oooool2o`0000Cooooo0_l00004ooooo`Co00000oooool3
o`0001gooooo0_l00005ooooo`Co00000_ooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2
o`0000;ooooo0_l00006ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Rooooo`;o0000:Ooo
ool001cooooo00?o0000ooooooooool0=_ooool2o`0001?ooooo1?l00003ooooo`;o000000?ooooo
o`000?l000003Oooool4o`000003ooooool0003o000000;o00002?ooool2o`0002Cooooo0_l0000:
ooooo`[o00005?ooool2o`0000Kooooo0ol00003ooooo`Co00002?ooool2o`0000_ooooo0_l00006
ooooo`;o00000_ooool2o`0000Gooooo1?l00016ooooo`007?ooool00ol0003oooooooooo`0ioooo
o`;o00001Oooool2o`000003ooooool0003o000000Kooooo0ol00004ooooo`Go00002?ooool2o`00
00?ooooo1?l000000ooooooo0000o`000004o`0000?ooooo0_l000000ooooooo0000o`000004oooo
o`;o00003oooool2o`0000;ooooo0_l0000;ooooo`;o00002_ooool6o`0001Kooooo0_l00006oooo
o`?o00000oooool2o`0002;ooooo0ol00005ooooo`Co00004oooool2o`00037ooooo000Looooo`03
o`000?oooooooooo03Wooooo0_l00005ooooo`;o000000?oooooo`000?l000003?ooool7o`0000Ko
oooo1Ol000001?oooooo0000o`000?ooool2o`0000;ooooo2Ol00002ooooo`;o00000oooool2o`00
00Oooooo1?l00004ooooo`?o000000Coooooo`000?l0003ooooo0_l00008ooooo`;o00002_ooool7
o`000003ooooool0003o000000;ooooo0_l00006ooooo`;o00002oooool7o`0000;ooooo0_l00007
ooooo`;o00006Oooool4o`0000Gooooo0_l0000Dooooo`;o0000<Oooool001cooooo00?o0000oooo
ooooool0@?ooool2o`0000gooooo1?l00003ooooo`;o00001_oooolEo`0000;ooooo0ol00003oooo
o`;o00001oooool4o`0000Gooooo0_l00004ooooo`;o00000_ooool2o`0000Gooooo0_l00003oooo
o`?o00001Oooool2o`000003ooooool0003o000000?o00000_ooool3o`0000;ooooo0_l000000ooo
oooo0000o`000005ooooo`;o00001?ooool8o`0000[ooooo0_l0000Hooooo`;o000000Coooooo`00
0?l0003ooooo0_l00002ooooo`Co00002oooool2o`0003Sooooo000Looooo`03o`000?oooooooooo
03Sooooo0_l00004ooooo`Co00003Oooool2o`0000_ooooo0_l000001?oooooo0000o`000?ooool>
o`000003ooooool0003o000000Co00001_ooool2o`0000;ooooo0_l00003ooooo`;o00003oooool2
o`0000Gooooo0_l00003ooooo`Co00001?ooool2o`000004ooooool0003o0000o`0000Gooooo0_l0
0002ooooo`;o00002?ooool2o`0000Cooooo0_l000000ooooooo0000o`000004o`0002?ooooo0_l0
0004ooooo`;o00001?ooool2o`0000_ooooo0_l000000ooooooo0000o`00000eooooo`007?ooool0
0ol0003oooooooooo`0hooooo`;o00001?ooool4o`0000oooooo0_l000000ooooooo0000o`000004
ooooo`Oo00000oooool<o`0000;ooooo2?l00003ooooo`;o00000_ooool2o`0000?ooooo0_l0000K
ooooo`Co00002?ooool2o`0001Gooooo0ol000001?oooooo0000o`000?ooool7o`0000;ooooo0_l0
0003ooooo`;o00006_ooool2o`0001Wooooo0_l0000eooooo`007?ooool00ol0003oooooooooo`0d
ooooo`;o00000oooool2o`0000Cooooo0_l0000@ooooo`;o000000?oooooo`000?l000001?ooool2
o`000003ooooool0003o000000;o000000?oooooo`000?l000003?l000000ooooooo0000o`000007
o`0000kooooo0_l00003ooooo`;o00002_ooool2o`0000?ooooo0_l000000ooooooo0000o`00000N
ooooo`;o00000oooool6o`000003ooooool0003o000000Go00000_ooool3o`0000;ooooo0_l0000J
ooooo`;o0000D?ooool001cooooo00?o0000ooooooooool0=?ooool2o`0000?ooooo0_l000000ooo
oooo0000o`00000Jooooo`Go000000Goooooo`000?l0003o0000ooooo`0Fo`00013ooooo0_l00003
ooooo`;o00001_ooool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000001?ooool2
o`0000gooooo0_l00009ooooo`;o00000_oooolAo`000004ooooool0003o0000ooooo`;o00002Ooo
ool2o`0001Cooooo0_l0000:ooooo`;o00001oooool2o`0003Oooooo000Looooo`03o`000?oooooo
oooo03cooooo0_l0000Aooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o
000001Wo000000?oooooo`000?l000007?ooool2o`00013ooooo0_l0000=ooooo`;o00003?oooolB
o`0000;ooooo1?l00002ooooo`;o00000_ooool2o`000003ooooool0003o000001;ooooo1?l0000:
ooooo`Co00001Oooool2o`0003Oooooo000Looooo`03o`000?oooooooooo04oooooo0_l000000ooo
oooo0000o`000007ooooo`co000000?oooooo`000?l000003?l000000ooooooo0000o`00000Doooo
o`;o00002Oooool2o`0000?ooooo0_l0000:ooooo`;o00005?ooool2o`0000?ooooo5_l00004oooo
o`;o00000_ooool2o`0001;ooooo0_l000000ooooooo0000o`000009ooooo`;o00000oooool2o`00
03kooooo000Looooo`03o`000?oooooooooo03_ooooo0_l0000>ooooo`;o000000Coooooo`000?l0
003o00002_oooolMo`0001Gooooo0_l00008ooooo`?o00000oooool2o`0000Cooooo0_l00004oooo
o`;o00004_ooool4o`0000?ooooo5_l00004ooooo`;o00001Oooool2o`0000oooooo0_l0000<oooo
o`;o00005?ooool2o`0002gooooo000Looooo`;o0000??ooool2o`0000Wooooo0_l00003ooooo`;o
000000Coooooo`000?l0003o00000oooool2o`000004ooooool0003o0000ooooo`;o000000?ooooo
o`000?l000003?l000000ooooooo0000o`00000;o`000003ooooool0003o000000;o00006Oooool3
o`0000Kooooo1Ol0000Aooooo`;o00000_ooool2o`000003ooooool0003o000000Cooooo1ol00000
0ooooooo0000o`00000>o`0000?ooooo0_l00005ooooo`;o00003oooool2o`0002;ooooo0_l0000]
ooooo`007?ooool00ol0003oooooooooo`16ooooo`;o00003?ooool2o`000004ooooool0003o0000
ooooo`Ko00000_oooolGo`000003ooooool0003o000000;o00006_ooool2o`0000Kooooo0ol0000C
ooooo`;o00000_ooool2o`0000Oooooo3Ol000000ooooooo0000o`000008o`0000?ooooo0ol00004
ooooo`;o000000?oooooo`000?l000003Oooool2o`00053ooooo000Looooo`03o`000?oooooooooo
05Sooooo0_l000000ooooooo0000o`000008o`000003ooooool0003o0000017o000000?oooooo`00
0?l000005Oooool2o`0000Oooooo0_l00005ooooo`?o00003?ooool2o`00017ooooo6Ol000000ooo
oooo0000o`000002o`0000;ooooo1ol0000=ooooo`Co00001oooool2o`0004Gooooo000Looooo`03
o`000?oooooooooo02cooooo0_l0000Zoooooa7o00000_ooool>o`0001Sooooo1_l00003ooooo`;o
000000?oooooo`000?l000000oooool2o`000003ooooool0003o000000Cooooo0_l00003ooooo`;o
00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000003oooooa_o000000?oooooo`000?l0
00000_l00002ooooo`;o00000_ooool2o`0000Kooooo0_l00008ooooo`;o00001oooool2o`0000co
oooo0_l0000gooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00005Oooool2o`0000;ooooo
0_l0000?oooooaoo00007?ooool4o`0000Kooooo0_l00002ooooo`;o00000_ooool2o`0000Cooooo
0_l00007ooooo`;o00000oooool5o`0000?ooooo6ol00003ooooo`;o00003_ooool2o`0000kooooo
0_l0000?ooooo`;o0000=oooool001cooooo00?o0000ooooooooool0@_ooool3o`0000;ooooo0_l0
0004ooooo`;o00002OoooolSo`0001Kooooo0_l00003ooooo`;o00002Oooool2o`0000Cooooo0_l0
000Aooooo`Ko000000?oooooo`000?l000006Ol000000ooooooo0000o`000004o`0001Cooooo0_l0
0006ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0>?ooool2o`0000Sooooo0_l00003
ooooo`?o000000?oooooo`000?l000001?l00004ooooo`;o00001?ooool6o`000003ooooool0003o
000001Oo000000?oooooo`000?l000004oooool2o`0000?ooooo0_l000000ooooooo0000o`00000<
ooooo`Co00002_ooool2o`0000Gooooo1?l000000ooooooo0000o`00000Po`000003ooooool0003o
000000;ooooo0_l00004ooooo`;o00001oooool2o`00053ooooo000Looooo`03o`000?oooooooooo
03Sooooo0_l0000=ooooo`?o000000Coooooo`000?l0003ooooo0ol000001?oooooo0000o`000?oo
ool2o`0000Gooooo3Ol000000ooooooo0000o`000009o`000004ooooool0003o0000o`0000?ooooo
0_l0000Hooooo`;o000000?oooooo`000?l000003_ooool2o`000003ooooool0003o000000Oooooo
0_l00004ooooo`;o000000?oooooo`000?l000000_ooool<o`0000;ooooo3ol000000ooooooo0000
o`000002ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`0005Wooooo000Looooo`03o`00
0?oooooooooo03Sooooo0_l0000=ooooo`;o00001Oooool3o`000004ooooool0003o0000ooooo`;o
00001?oooolNo`0000Cooooo0_l0000Gooooo`Go00002?ooool2o`0000Oooooo0_l00005ooooo`Go
00000_ooool3o`0000Oooooo6?l0000;ooooo`?o0000Goooool001cooooo00?o0000ooooooooool0
>?ooool2o`0000gooooo0_l00006ooooo`;o00001?ooool2o`0000;ooooo1?l000000ooooooo0000
o`00000Ao`000003ooooool0003o000000Go00001?ooool2o`00017ooooo0_l00005ooooo`;o0000
2_ooool2o`0000Cooooo0_l00007ooooo`Ko00000_ooool3o`0000Kooooo6Ol000000ooooooo0000
o`000003ooooo`;o00001?ooool4o`0001[ooooo0_l00011ooooo`007?ooool00ol0003ooooooooo
o`0mooooo`;o00001oooool2o`0000?ooooo0_l00002ooooo`;o00001Oooool2o`000003ooooool0
003o000001ko00001?ooool4o`0000Gooooo0_l00008ooooo`;o00000oooool3o`0000Wooooo0_l0
0006ooooo`;o00001oooool3o`0000Kooooo0_l00006ooooo`So000000?oooooo`000?l000003Ol0
0002ooooo`;o00000_ooool3o`0000Gooooo0ol0000Jooooo`?o0000@?ooool001cooooo00?o0000
ooooooooool0?Oooool2o`0000Kooooo0ol00003ooooo`;o00000_ooool2o`0000;ooooo0_l00000
0ooooooo0000o`000003oooooaco00000_ooool2o`0000Cooooo0_l00005ooooo`;o00003Oooool3
o`0000?ooooo0_l00004ooooo`;o00001oooool2o`0000?ooooo0_l00006ooooo`;o00000_ooool2
o`0000Cooooo6Ol00007ooooo`;o00001_ooool4o`0000[ooooo0_l0000>ooooo`;o0000@?ooool0
01cooooo00?o0000ooooooooool0@oooool6o`0000Kooooo0_l00002ooooo`;o00001ooooolFo`00
00;ooooo0_l000000ooooooo0000o`000002o`00023ooooo0_l00007ooooo`;o00000_ooool4o`00
00?ooooo0_l00006ooooo`;o00001ooooolJo`0000Oooooo0_l00008ooooo`;o00001_ooool3o`00
0003ooooool0003o000000[ooooo0_l00002ooooo`?o0000?oooool001cooooo00?o0000oooooooo
ool0?oooool6o`0000;ooooo0_l0000;ooooo`;o00001Oooool5o`000005ooooool0003o0000o`00
0?ooool02ol000000ooooooo0000o`000006o`0000Kooooo0_l0000Looooo`;o00001Oooool2o`00
00;ooooo0_l0000Fooooo`;o00000_oooolFo`0000Oooooo0_l00008ooooo`;o00001_ooool3o`00
00[ooooo0_l000000ooooooo0000o`000002ooooo`?o00001?ooool2o`0000Gooooo0_l0000boooo
o`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0<_ooool2o`0000_ooooo1?l00003ooooo`;o00003?oo
ool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`Go000000?oooooo`000?l000004Ol0
0007ooooo`;o00002Oooool2o`0000Oooooo0ol00005ooooo`Co00006_ooool2o`0000Oooooo6?l0
000Booooo`;o000000?oooooo`000?l000003oooool2o`000003ooooool0003o000000;ooooo0_l0
0005ooooo`;o00001Oooool2o`0003;ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo
0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0booooo`;o
00003?ooool2o`0000Cooooo0_l00004ooooo`;o00002?ooool4o`0000Gooooo4_l00002ooooo`;o
00000_ooool3o`00013ooooo0_l00007ooooo`?o00001Oooool2o`0000Oooooo0_l0000;ooooo`;o
00001_ooool2o`0000?ooooo7?l000000ooooooo0000o`00000?ooooo`;o000000?oooooo`000?l0
0000F?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool0@?ooool2o`0000[ooooo0_l00008ooooo`?o
00001oooool?o`0000?ooooo0_l00003ooooo`?o00000_ooool2o`00023ooooo0_l00004ooooo`;o
00002oooool2o`0000_ooooo8Ol00006ooooo`?o00004_ooool2o`0004gooooo00000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o
0000@Oooool2o`0000Kooooo0_l0000<ooooo`;o00001?ooool3o`0000;ooooo1?l000000ooooooo
0000o`000006o`0000?ooooo0_l00003ooooo`;o00000oooool2o`0000;ooooo0_l00007ooooo`?o
00001Oooool2o`000003ooooool0003o000000Kooooo1?l00004ooooo`;o00006oooool2o`000003
ooooool0003o000001Go000000Coooooo`000?l0003o00001_ooool3o`0000cooooo0_l00004oooo
o`;o0000COooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003o
EEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0@Oooool2o`0000;ooooo0_l00002oooo
o`;o00004_ooool4o`0000?ooooo1_l000000ooooooo0000o`000002o`0000?ooooo0_l00003oooo
o`Co00001Oooool2o`0000Oooooo0ol00004ooooo`Oo00001Oooool2o`0000Kooooo1?l0000Ioooo
o`;o000000?oooooo`000?l000004ol0000=ooooo`Co00002_ooool2o`00017ooooo0_l00010oooo
o`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`03oeEEEOn7QhOooooo00So
oooo00?o0000ooooooooool0AOooool2o`0000Cooooo0_l00002ooooo`?o00002oooool5o`0000;o
oooo1_l00002ooooo`Co00000_ooool2o`0000Cooooo0ol0000=ooooo`;o000000?oooooo`000?l0
00000oooool7o`0000Wooooo0_l00002ooooo`Go00007?ooool2o`000003ooooool0003o000000Go
000000?oooooo`000?l000001ol0000=ooooo`Co00001Oooool3o`0001Gooooo0_l00010ooooo`00
00KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000oooo
ooooool0?Oooool2o`0000cooooo0_l00002ooooo`?o00002oooool2o`000003ooooool0003o0000
00?ooooo1Ol00002ooooo`Co00000_ooool2o`000004ooooool0003o0000ooooo`;o00000oooool2
o`0000Wooooo1ol000000ooooooo0000o`000002o`000004ooooool0003o0000o`0000Sooooo0_l0
0002ooooo`;o000000?oooooo`000?l000005Oooool2o`0000Oooooo3ol000001?oooooo0000o`00
0?l0000Eooooo`?o00005_ooool2o`0003oooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPco
oooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`0mooooo`;o00002?ooool2o`00
00;ooooo0_l0000@ooooo`Co00003?ooool2o`0000;ooooo0ol000000ooooooo0000o`000003o`00
00?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo3ol0000Uooooo`;o00001oooool;o`00
0003ooooool0003o000000;o000000Coooooo`000?l0003o00001?ooool2o`0000[ooooo0_l00003
ooooo`;o00000oooool2o`00017ooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`17oooo
o`;o00000_ooool2o`00013ooooo1?l0000<ooooo`;o00000_ooool3o`0000?ooooo0ol00007oooo
o`;o00000_ooool3o`0000;ooooo3ol000000ooooooo0000o`00000@ooooo`;o00006oooool2o`00
0003ooooool0003o000000Wo00000_ooool5o`000003ooooool0003o000000[ooooo0_l00008oooo
o`;o0000D_ooool001cooooo00?o0000ooooooooool0Aoooool2o`0001Gooooo0_l0000Uooooo`;o
00000_oooolDo`0000Oooooo0_l00006ooooo`;o00000oooool2o`0000_ooooo0_l0000>ooooo`[o
00000_ooool4o`0000Gooooo0_l0001Tooooo`007?ooool00ol0003oooooooooo`0oooooo`;o0000
4oooool2o`0000Sooooo0_l00006ooooo`?o00000_ooool2o`0001cooooo5?l00007ooooo`Co0000
2Oooool2o`0000[ooooo0ol00002ooooo`;o00001?ooool3o`0000?ooooo0_l00003ooooo`Go0000
0_ooool3o`0000Kooooo0_l0000Dooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0>_oo
ool2o`0000?ooooo0_l0000Aooooo`Co00004?ooool3o`0000;ooooo0_l00006ooooo`;o00001_oo
ool2o`0000[ooooo0ol000000ooooooo0000o`00000@o`0000;ooooo0_l00003ooooo`Co00005Ooo
ool2o`0000?ooooo0ol00003ooooo`?o00000oooool2o`0000[ooooo1?l00005ooooo`;o00001ooo
ool2o`0000Oooooo0_l00002ooooo`;o00005?ooool2o`0003Sooooo000Looooo`03o`000?oooooo
oooo03[ooooo0_l0000:ooooo`;o00001?ooool2o`0000Cooooo0_l00008ooooo`;o00001_ooool3
o`0000Oooooo1?l000000ooooooo0000o`000002ooooo`;o00000_ooool2o`0000[ooooo5_l00000
1?oooooo0000o`000?l00003ooooo`;o00007Oooool2o`0000;ooooo0_l0000Aooooo`Co00001Ooo
ool3o`0000?ooooo0_l000000ooooooo0000o`000002o`0000Gooooo1Ol0000Eooooo`;o0000>?oo
ool001cooooo00?o0000ooooooooool0A_ooool2o`000004ooooool0003o0000ooooo`?o00003Ooo
ool3o`0000Gooooo0ol00007ooooo`Co00001Oooool2o`0000kooooo2_l000000ooooooo0000o`00
000?o`0001cooooo0_l00002ooooo`;o00000_ooool2o`0000Gooooo0_l0000:ooooo`;o00000ooo
ool2o`0000?ooooo0_l00003ooooo`;o00000oooool2o`0000Oooooo0ol00009ooooo`?o0000@ooo
ool001cooooo00?o0000ooooooooool0BOooool2o`0000;ooooo0_l0000>ooooo`;o00009_oooolN
o`0001Oooooo0_l00003ooooo`;o00002Oooool2o`0000;ooooo0_l0000:ooooo`;o00000oooool2
o`000003ooooool0003o000000?o00007?ooool3o`0000Oooooo0_l0000jooooo`007?ooool00ol0
003oooooooooo`19ooooo`;o00001?ooool2o`0000gooooo0_l0000?ooooo`;o00001Oooool2o`00
00gooooo0_l00002oooooa[o00000oooool2o`0000oooooo1Ol00009ooooo`;o00000oooool2o`00
013ooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000002Kooooo0_l0000j
ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o000000?oooooo`000?l000000oooool2o`00
0003ooooool0003o000000?ooooo0_l00003ooooo`;o00000_ooool3o`0000Gooooo0_l00008oooo
o`;o00001Oooool2o`0000Gooooo0_l0000:oooooa[o00000oooool2o`0000Oooooo0ol000000ooo
oooo0000o`000002ooooo`?o00002oooool2o`0000?ooooo0_l00003ooooo`;o00000oooool2o`00
00Kooooo0_l000000ooooooo0000o`000002o`0001oooooo0_l00015ooooo`007?ooool00ol0003o
ooooooooo`10ooooo`;o00000_ooool2o`000003ooooool0003o000000?ooooo0ol00002ooooo`;o
000000?oooooo`000?l000000oooool7o`0000Gooooo0ol0000Eooooo`;o00003?ooool?o`000003
ooooool0003o000000Go00003Oooool3o`000003ooooool0003o000001Gooooo0_l00003ooooo`;o
00000oooool2o`0000Kooooo1ol000001?oooooo0000o`000?l0000Kooooo`;o0000AOooool001co
oooo00?o0000ooooooooool0?oooool3o`0000Oooooo0_l00002ooooo`Ko00002?ooool5o`0000Ko
oooo0_l0000RoooooaWo00003?ooool2o`0002Wooooo2Ol000001?oooooo0000o`000?l0001Roooo
o`007?ooool2o`0003cooooo0_l00002ooooo`?o00001oooool3o`0000?ooooo0_l0000Cooooo`?o
00007Oooool2o`0000Cooooo6Ol00008ooooo`;o00005oooool2o`0000?ooooo0_l0000;ooooo`;o
00000_ooool2o`0000Gooooo0_l0001Vooooo`007?ooool00ol0003oooooooooo`0kooooo`;o0000
0oooool2o`0000Sooooo0_l00003ooooo`;o00001?ooool2o`0000Wooooo0_l00002ooooo`?o0000
7Oooool2o`0000Gooooo6Ol00006ooooo`Co00005_ooool2o`0000?ooooo0_l0000;ooooo`;o0000
LOooool001cooooo00?o0000ooooooooool0A_ooool2o`0000gooooo0_l000000ooooooo0000o`00
0006ooooo`;o00003oooool2o`0001Sooooo6Ol00002ooooo`;o00000_ooool5o`0003?ooooo0_l0
0002ooooo`?o0000H?ooool001cooooo00?o0000ooooooooool0A_ooool2o`0000Oooooo0_l00007
ooooo`;o00005oooool4o`000003ooooool0003o000001;ooooo6Ol00003ooooo`;o00001Oooool2
o`0000;ooooo0_l0000Fooooo`;o00002?ooool2o`0000gooooo0_l00002ooooo`?o0000H?ooool0
01cooooo00?o0000ooooooooool0C_ooool3o`0001oooooo0_l000001?oooooo0000o`000?ooool2
o`0000kooooo0_l00002oooooaCo000000Coooooo`000?l0003o00003oooool2o`0001Kooooo0_l0
0007ooooo`?o00001_ooool2o`0006cooooo000Looooo`03o`000?oooooooooo04_ooooo0_l00000
0ooooooo0000o`000002o`0000oooooo0_l000000ooooooo0000o`00000:ooooo`;o00001?ooool2
o`0000Kooooo0_l00006ooooo`;o00000ooooolBo`0000;ooooo0ol00004ooooo`Ko00001_ooool2
o`0000Wooooo0_l0000:ooooo`;o00000oooool2o`0000;ooooo0_l00007ooooo`;o0000;_ooool2
o`0003cooooo000Looooo`03o`000?oooooooooo04_ooooo0_l00002ooooo`?o00001?ooool2o`00
00Kooooo0_l000001?oooooo0000o`000?ooool2o`0001Sooooo0_l0000=oooooa;o000000?ooooo
o`000?l000000_l000000ooooooo0000o`000005o`0000Kooooo0_l00002ooooo`;o00001Oooool2
o`0000[ooooo0_l00003ooooo`?o00002Oooool2o`0000Sooooo0_l0000;ooooo`Co00005_ooool2
o`0003cooooo000Looooo`03o`000?oooooooooo04_ooooo0_l00003ooooo`;o00000oooool3o`00
00Kooooo0_l000000ooooooo0000o`00000<ooooo`;o00004oooool2o`0000Kooooo4ol00003oooo
o`;o000000Coooooo`000?l0003o00003_ooool2o`00017ooooo0_l00004ooooo`;o000000Cooooo
o`000?l0003o00001?ooool3o`0000Sooooo0_l000000ooooooo0000o`000008ooooo`Co0000E?oo
ool001cooooo00?o0000ooooooooool0B?ooool2o`0000_ooooo1?l00003ooooo`;o00000oooool2
o`0000cooooo0_l0000Cooooo`?o00000ooooolEo`0000Gooooo1?l0000Vooooo`Oo00000oooool3
o`0000Gooooo0_l00005ooooo`;o00000oooool2o`0005_ooooo000Looooo`03o`000?oooooooooo
04Gooooo0_l000000ooooooo0000o`00000=ooooo`;o00000oooool2o`0001[ooooo0ol0000:oooo
o`;o00000oooool3o`0000;ooooo0_l000000ooooooo0000o`00000;o`0000Gooooo0_l000001?oo
oooo0000o`000?ooool2o`00027ooooo2?l00003ooooo`;o00001_ooool4o`0000Sooooo0_l0001K
ooooo`007?ooool00ol0003oooooooooo`15ooooo`Co00004_ooool2o`0001Oooooo0_l00002oooo
o`?o00002?ooool2o`0000gooooo3_l00005ooooo`Co000000?oooooo`000?l000008?ooool=o`00
00Oooooo1_l0001Sooooo`007?ooool00ol0003oooooooooo`17ooooo`;o00003Oooool2o`000003
ooooool0003o000000Ko00004?ooool5o`0000Gooooo1?l000001?oooooo0000o`000?ooool2o`00
00Wooooo0_l00002ooooo`Go000000?oooooo`000?l000001_l00002ooooo`;o000000?oooooo`00
0?l000009Oooool=o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o0000Hoooool001co
oooo00?o0000ooooooooool0B?ooool2o`0000Oooooo0_l00003ooooo`;o000000?oooooo`000?l0
00000_ooool4o`00013ooooo1?l00004ooooo`Ko000000?oooooo`000?l000001Oooool2o`0000Go
oooo0_l00003ooooo`?o00000_ooool5o`000003ooooool0003o000000;ooooo0ol0000Yooooo`[o
00001Oooool2o`0001Wooooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`12ooooo`;o0000
1?ooool2o`0000Oooooo0_l0000Aooooo`Co00002Oooool2o`0000Kooooo0_l00003ooooo`?o0000
1_ooool2o`0000[ooooo0ol00002ooooo`Go00001Oooool3o`0000Oooooo0_l0000=ooooo`;o0000
4Oooool;o`0001oooooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00005_oo
ool2o`0000Sooooo1?l00009ooooo`;o00002?ooool2o`000005ooooool0003o0000o`000?ooool0
0_l00002ooooo`;o00002_ooool3o`0000cooooo0_l00003ooooo`;o00001?ooool2o`0000Cooooo
0_l00005ooooo`Co00000_ooool2o`0000_ooooo1ol000000ooooooo0000o`000003o`000003oooo
ool0003o000000Wooooo0_l0001Rooooo`007?ooool00ol0003oooooooooo`1Jooooo`;o00002?oo
ool3o`0000_ooooo0_l000001?oooooo0000o`000?l00003ooooo`;o00001Oooool2o`0000;ooooo
0_l0000:ooooo`;o00003Oooool2o`0000?ooooo0_l0000:ooooo`;o00001Oooool4o`0000;ooooo
0_l00009ooooo`oo000000?oooooo`000?l000000_ooool2o`0000Gooooo0_l00006ooooo`;o0000
F_ooool001cooooo0_l0001Fooooo`;o00000oooool2o`0000Sooooo0ol00002ooooo`;o00000ooo
ool2o`0000;ooooo0_l000001?oooooo0000o`000?l0000Iooooo`;o00000_ooool2o`0000Oooooo
0_l0000Kooooo`?o00001_ooool2o`0000Cooooo3ol00005ooooo`;o00003Oooool2o`0005[ooooo
000Looooo`03o`000?oooooooooo04Sooooo0_l0000;ooooo`;o00000oooool2o`000003ooooool0
003o000000[ooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l00003ooooo`;o00001Ooo
ool2o`00013ooooo0_l00002ooooo`Co00001Oooool2o`0001cooooo1?l00004ooooo`;o00001ooo
ool=o`0001?ooooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`18ooooo`;o00004oooool2
o`0000[ooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00002ooooo`?o00001Ooo
ool2o`0000;ooooo0_l0000Booooo`;o00007?ooool2o`000003ooooool0003o000000Cooooo0_l0
000>ooooo`co00004oooool2o`0005[ooooo000Looooo`03o`000?oooooooooo06_ooooo0_l00002
ooooo`;o00000_ooool3o`000003ooooool0003o000000?o00000_ooool2o`0000?ooooo0_l00003
ooooo`;o00000_ooool2o`0000oooooo0_l0000Fooooo`;o000000?oooooo`000?l000001Oooool2
o`0000;ooooo0_l00002ooooo`;o00001?ooool<o`00073ooooo000Looooo`03o`000?oooooooooo
05[ooooo0_l00008ooooo`;o00001Oooool2o`0000Oooooo0_l00003ooooo`?o00000_ooool2o`00
00Kooooo1?l00002ooooo`;o00003oooool2o`00023ooooo0_l00002ooooo`;o00000_ooool2o`00
00Cooooo0_l000000ooooooo0000o`000007o`0001oooooo0_l0001?ooooo`007?ooool00ol0003o
ooooooooo`1Jooooo`;o00002?ooool3o`0001oooooo0_l00004ooooo`;o00000_ooool2o`0001Ko
oooo1?l00008ooooo`;o00001_ooool2o`0000oooooo0_l000000ooooooo0000o`000007o`000003
ooooool0003o000000[ooooo0_l0000@ooooo`;o0000Coooool001cooooo00?o0000ooooooooool0
IOooool3o`0001Gooooo1?l0000;ooooo`;o00000_ooool2o`0000Kooooo0_l0000>ooooo`Co0000
2?ooool2o`000003ooooool0003o000000?ooooo0_l0000?ooooo`Wo00001?ooool2o`0000[ooooo
0_l0000Dooooo`;o0000Boooool001cooooo00?o0000ooooooooool0I_ooool2o`0000Gooooo0_l0
0004ooooo`;o00001_ooool6o`0000Sooooo0_l00002ooooo`Co00000_ooool2o`0000?ooooo0_l0
0005ooooo`;o00003_ooool2o`0000;ooooo0_l000001?oooooo0000o`000?l0000Fooooo`;o0000
00?oooooo`000?l000000ol0000Nooooo`;o00001Oooool2o`0004_ooooo000Looooo`03o`000?oo
oooooooo06Cooooo0_l00007ooooo`Go000000?oooooo`000?l000001_ooool2o`0000Cooooo0_l0
0006ooooo`;o00000_ooool4o`0000;ooooo0_l0000:ooooo`;o00003_ooool2o`0000;ooooo0_l0
00000ooooooo0000o`00000Mooooo`;o00007_ooool2o`0005;ooooo000Looooo`03o`000?oooooo
oooo04Gooooo0_l0000Kooooo`Go00002?ooool4o`0000Sooooo0_l00004ooooo`Co00002?ooool2
o`0001Kooooo0_l00003ooooo`;o00002_ooool2o`0001[ooooo0_l0001eooooo`007?ooool00ol0
003oooooooooo`15ooooo`;o00006?ooool2o`000004ooooool0003o0000ooooo`;o00002_ooool2
o`0000Cooooo0_l00002ooooo`;o00001_ooool3o`0001oooooo0_l00003ooooo`;o00000_ooool4
o`0000Cooooo0_l0000Jooooo`;o0000MOooool001cooooo00?o0000ooooooooool0A_ooool2o`00
01Oooooo1?l00003ooooo`;o000000?oooooo`000?l000002oooool3o`0000_ooooo1?l0000Aoooo
o`;o00003oooool2o`0000;ooooo1?l0000Kooooo`;o0000N_ooool001cooooo00?o0000oooooooo
ool0A_ooool2o`0000Kooooo0_l0000Aooooo`;o00000oooool5o`0000_ooooo0_l0000>ooooo`?o
00003Oooool2o`000003ooooool0003o000002cooooo1?l000001?oooooo0000o`000?l0001joooo
o`007?ooool00ol0003oooooooooo`1>ooooo`;o00005Oooool4o`0000?ooooo0_l0000=ooooo`;o
00002_ooool2o`0000Cooooo1_l00003ooooo`;o00006Oooool2o`0001Cooooo1?l000001?oooooo
0000o`000?l0000Oooooo`;o0000FOooool001cooooo00?o0000ooooooooool0IOooool2o`0000Go
oooo0_l00007ooooo`;o00001?ooool2o`0000Sooooo0_l00006ooooo`Ko00000_ooool2o`0001[o
oooo0_l00002ooooo`;o00005_ooool2o`0001oooooo0_l0001Iooooo`007?ooool00ol0003ooooo
ooooo`18ooooo`;o00006oooool5o`0000;ooooo1?l00002ooooo`;o000000?oooooo`000?l00000
1?ooool2o`0000?ooooo0_l00003ooooo`;o00003_ooool2o`0000Wooooo0_l0000Cooooo`;o0000
1oooool2o`0002cooooo0_l0001Kooooo`007?ooool2o`0004Wooooo0_l0000:ooooo`;o00003ooo
ool5o`0000;ooooo1?l00002ooooo`;o00001oooool2o`0000?ooooo0_l00006ooooo`;o00002ooo
ool2o`0000Wooooo0_l0000Looooo`;o00003?ooool2o`000004ooooool0003o0000ooooo`;o0000
6?ooool2o`0005_ooooo000Looooo`03o`000?oooooooooo05Cooooo0_l0000@ooooo`;o000000Co
ooooo`000?l0003ooooo0_l000000ooooooo0000o`000007ooooo`;o00000_ooool2o`0000Cooooo
0_l00004ooooo`;o00002oooool2o`0001Cooooo0_l0000@ooooo`;o000000?oooooo`000?l00000
2?ooool4o`000004ooooool0003o0000ooooo`;o0000MOooool001cooooo00?o0000ooooooooool0
I_ooool5o`000004ooooool0003o0000ooooo`;o00001oooool2o`000005ooooool0003o0000o`00
0?ooool00_l000001?oooooo0000o`000?ooool2o`0000Cooooo0_l00008ooooo`;o00000_ooool3
o`0000oooooo1Ol0000<ooooo`?o000000?oooooo`000?l000002?ooool3o`0000Kooooo0_l0001d
ooooo`007?ooool00ol0003oooooooooo`1Xooooo`;o00003oooool8o`0000Cooooo0_l00004oooo
o`;o00003?ooool3o`0000Sooooo0ol00006ooooo`?o00003?ooool2o`0000gooooo0_l000000ooo
oooo0000o`000003ooooo`;o00005_ooool2o`0005cooooo000Looooo`03o`000?oooooooooo07Co
oooo0_l00002ooooo`Go000000Coooooo`000?l0003ooooo0_l00002ooooo`?o00001?ooool2o`00
013ooooo0_l00004ooooo`?o00004_ooool4o`0000Oooooo0_l00008ooooo`;o00006oooool2o`00
05cooooo000Looooo`03o`000?oooooooooo05Sooooo0_l0000Jooooo`;o00000_ooool;o`0000;o
oooo1Ol00002ooooo`Co00003_ooool2o`0000?ooooo0_l00002ooooo`Co00002oooool2o`000003
ooooool0003o000000;o00001oooool2o`0000Oooooo0_l0000Eooooo`;o0000Hoooool001cooooo
00?o0000ooooooooool0F?ooool4o`0001Sooooo0_l00006ooooo`;o000000?oooooo`000?l00000
1_ooool3o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`Go00001oooool2o`0000;ooooo
1?l0000;ooooo`;o000000?oooooo`000?l000000oooool2o`0000gooooo0_l0000Eooooo`;o0000
Hoooool001cooooo00?o0000ooooooooool0F_ooool2o`0001Sooooo0_l000000ooooooo0000o`00
0003ooooo`;o00000_ooool2o`0000Oooooo0ol00005ooooo`?o00000_ooool6o`0002;ooooo0_l0
000=ooooo`Co00004oooool3o`0006;ooooo000Looooo`03o`000?oooooooooo07Oooooo0_l00003
ooooo`;o00000_ooool2o`0000Gooooo1ol00003ooooo`?o00000_ooool6o`0000?ooooo0_l0000K
ooooo`;o000000?oooooo`000?l000003?ooool4o`0000cooooo0_l00005ooooo`?o0000H_ooool0
01cooooo00?o0000ooooooooool0F_ooool2o`0000oooooo0_l0000<ooooo`;o00001Oooool2o`00
00Gooooo0_l00003ooooo`?o00000_ooool2o`0000cooooo0_l0000:ooooo`;o00003?ooool2o`00
0003ooooool0003o000000Go00001_ooool2o`0001;ooooo0_l0001Zooooo`007?ooool00ol0003o
ooooooooo`1Jooooo`;o00003oooool2o`0000Oooooo0_l00003ooooo`;o00001Oooool2o`0000;o
oooo0_l00007ooooo`;o00002?ooool2o`0000oooooo0_l000000ooooooo0000o`00000<ooooo`;o
00000oooool2o`000003ooooool0003o000000Kooooo0_l0001nooooo`007?ooool00ol0003ooooo
ooooo`1dooooo`;o00002_ooool2o`0000;ooooo1?l0000?ooooo`;o00001_ooool4o`0000Gooooo
0_l000000ooooooo0000o`000002o`0000?ooooo0_l00009ooooo`;o0000R_ooool001cooooo00?o
0000ooooooooool0K_ooool2o`0000Gooooo0_l0000=ooooo`Co00000_ooool2o`0000Oooooo0_l0
00000ooooooo0000o`000002ooooo`;o00000oooool4o`0000;ooooo0_l000000ooooooo0000o`00
0005o`0000?ooooo1Ol00006ooooo`;o0000R_ooool001cooooo00?o0000ooooooooool0K_ooool2
o`0000Gooooo0_l0000<ooooo`Go00000_ooool2o`0000Oooooo0_l000000ooooooo0000o`000002
ooooo`Go000000Coooooo`000?l0003o00000_ooool2o`000004ooooool0003o0000o`0000Wooooo
0ol00003ooooo`;o00007?ooool2o`0006oooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGo
oooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1ioooo
o`Co00001_ooool5o`0001Cooooo0ol000001?oooooo0000o`000?ooool3o`0000;ooooo0_l0000@
ooooo`;o00001_ooool3o`000003ooooool0003o0000013ooooo0_l0001_ooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo
00?o0000ooooooooool0NOooool4o`0000Kooooo0_l0000Nooooo`?o00000_ooool2o`0000Wooooo
0_l0000=ooooo`?o000000Coooooo`000?l0003o00000oooool2o`0007_ooooo00000ooooooo410@
ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo08?ooooo0_l00002ooooo`;o00001oooool2o`00027ooooo0_l0000=ooooo`;o
00000oooool2o`0000?ooooo0_l0001kooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooo
ooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`0008Kooooo0ol00004ooooo`;o
000000?oooooo`000?l000002?ooool2o`0001Oooooo0_l0000=ooooo`;o0000QOooool00003oooo
ool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Oo<c<co0000o`000?l0003oc<c<00Ko
oooo00?o0000ooooooooool0Ioooool2o`0001gooooo0_l00005ooooo`;o00000oooool2o`0000Ko
oooo0_l00009ooooo`;o00005_ooool4o`000003ooooool0003o000008Gooooo00000ooooooo410@
ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03
o`000?oooooooooo06Oooooo0_l0000Aooooo`;o00002oooool2o`0000Wooooo0_l00005ooooo`;o
000000Goooooo`000?l0003o0000ooooo`02o`0000?ooooo0_l0000Fooooo`Co0000R?ooool00006
oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o
0000ooooooooool0N_ooool2o`0000_ooooo0_l0000:ooooo`;o00001?ooool2o`000003ooooool0
003o000000Co00001oooool2o`0000oooooo0_l00008ooooo`?o0000P_ooool00006ooooooo^k^ko
<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000oooooooo
ool0J_ooool2o`0001[ooooo1?l00007ooooo`Co00001_ooool2o`000003ooooool0003o000000;o
00001oooool2o`0000oooooo0_l00008ooooo`?o00001oooool2o`0007Wooooo000Looooo`03o`00
0?oooooooooo06[ooooo0_l0000Jooooo`Co00001oooool2o`000003ooooool0003o000000Gooooo
0_l00006ooooo`;o0000:Oooool2o`0007Wooooo000Looooo`03o`000?oooooooooo06oooooo0_l0
000Cooooo`;o00003Oooool3o`0000;ooooo0_l00004ooooo`;o00000oooool2o`0000kooooo1Ol0
0007ooooo`;o0000R?ooool001cooooo00?o0000ooooooooool0Koooool2o`0000Kooooo0_l0000;
ooooo`;o00003Oooool7o`0000Cooooo0_l0000Cooooo`Go00001oooool2o`0008Sooooo000Loooo
o`03o`000?oooooooooo07Oooooo0_l0000Looooo`Co000000?oooooo`000?l000000_ooool2o`00
00Gooooo1Ol0000;ooooo`;o00002?ooool2o`0008Sooooo000Looooo`03o`000?oooooooooo08Wo
oooo0_l0000:ooooo`Co000000?oooooo`000?l000002Oooool5o`0000Wooooo0_l0000:ooooo`;o
0000R?ooool001cooooo00?o0000ooooooooool0Noooool2o`0000cooooo0_l0000:ooooo`Co0000
0oooool2o`0000Gooooo0_l00006ooooo`;o00001_ooool2o`0009Cooooo000Looooo`03o`000?oo
oooooooo07_ooooo0_l0000>ooooo`;o00003oooool2o`0000Gooooo0_l00003ooooo`;o000000?o
ooooo`000?l000006Oooool2o`00087ooooo000Looooo`03o`000?oooooooooo08Oooooo0_l00002
ooooo`;o00001_ooool2o`0001?ooooo1?l00009ooooo`?o00003_ooool2o`00087ooooo000Loooo
o`03o`000?oooooooooo07[ooooo0_l0000;ooooo`;o00002_ooool2o`0000Gooooo0_l00009oooo
o`;o00000oooool2o`0000Wooooo0ol00006ooooo`;o0000ROooool001cooooo00?o0000oooooooo
ool0N_ooool2o`0000Oooooo0_l0000Booooo`;o000000?oooooo`000?l000002Oooool2o`0000Go
oooo0_l00009ooooo`;o00001Oooool2o`0008Wooooo000Looooo`03o`000?oooooooooo06_ooooo
0_l0000Fooooo`;o00004_ooool2o`0001?ooooo0_l00008ooooo`?o0000T?ooool001cooooo0_l0
001/ooooo`;o00006_ooool2o`0002Wooooo0_l00002ooooo`;o00001oooool2o`0008Sooooo000L
ooooo`03o`000?oooooooooo08Oooooo0_l0000Nooooo`Co00001oooool2o`0000_ooooo0_l0000;
ooooo`;o0000Noooool001cooooo00?o0000ooooooooool0Yoooool4o`0000[ooooo0_l0000Eoooo
o`;o0000Noooool001cooooo00?o0000ooooooooool0Woooool2o`0001Cooooo0_l0002Booooo`00
7?ooool00ol0003oooooooooo`2Oooooo`;o0000Z?ooool001cooooo00?o0000ooooooooool0Vooo
ool3o`000:_ooooo000Looooo`03o`000?oooooooooo07_ooooo0_l0000Nooooo`?o0000Zoooool0
01cooooo00?o0000ooooooooool0Noooool2o`0002kooooo0_l0002Looooo`007?ooool00ol0003o
ooooooooo`2Fooooo`;o00002oooool2o`0000Kooooo0_l0002Looooo`007?ooool00ol0003ooooo
ooooo`2Fooooo`;o00002oooool2o`000:Cooooo000Looooo`03o`000?oooooooooo0:Kooooo0ol0
002Pooooo`007?ooool00ol0003oooooooooo`2Vooooo`?o0000X?ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo08?ooooo0_l00034ooooo`007?ooool00ol0003oooooooooo`23ooooo`;o0000a?oo
ool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo08kooooo0_l0002iooooo`007?ooool00ol0003oooooooooo`2>
ooooo`;o0000^Oooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`004_ooool4
o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000oooooooo
ool01Oooool3o`000?ooooooB_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?oo
ool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool0
01Cooooo00?o0000ooooooooool0oooooomBooooo`004_ooool00omEEEGoIVIVo`00003ooooooeCo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Uooooo`04oa0@4?l0003o0000
ooooo`;o000000?o410@ooooooooool05Oooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Gooooo00?o
0000onk^k_ooool00oooool01Oo^k^ko<S8bo`000?l@413oc<c<093ooooo002Vooooo`05o`000?oo
ooooooooooooool000002Oooool6o`0000Wooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@05ooooo`03
oeEEEOnYZJWooooo00?ooooo00GoEEEEogMgMoooooooV9RHob4Q8@2@ooooo`00Y_ooool01Ol0003o
oooooooooooooooo000001Sooooo00Go0000ooooooooooooooooo`000005ooooo`03ojVYZOmEEEGo
oooo00?ooooo00Go0000ooooooooooooooooo`00002@ooooo`00Y_ooool01Ol0003ooooooooooooo
oooo000000Wooooo1_l00009ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool00olQ8B7ooooo
ooooo`02ooooo`05o`000?nHV9SooooooiRHV?lQ8B40T?ooool00:Kooooo00Go0000ohN7Qooooooo
ZJVYo`00000Hooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00omEEEGoc<c<ooooo`02oooo
o`05o`000?mEEEGo0000oa0@4?o<c<`0T?ooool00:Gooooo00?o410@o`000?mgMgL00_l000000onH
V9Soooooooooo`0Fooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00onYZJWoMgMgooooo`02
ooooo`03oeEEEOn7QhOooooo09;ooooo0033ooooo`05o`000?nj^[[ooooookZj^_l000000oooool0
1Ol@413ooooooooooooooooo<S8b00?ooooo00?ogMgMoa0@4?nHV9P0T_ooool00<?ooooo00GoZJVY
oa0@4?l0003o410@ojVYZ@03ooooo`Go00001?ooool01?o<c<coA4A4o`000?l@412@ooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(882) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.35624 .52048 Mdot
.33244 .54519 Mdot
.62047 .62633 Mdot
.43028 .38499 Mdot
.39557 .48395 Mdot
.62579 .59873 Mdot
.46384 .64144 Mdot
.43168 .61272 Mdot
.64214 .60195 Mdot
.51517 .28986 Mdot
.42873 .63612 Mdot
.53572 .36621 Mdot
.44811 .65685 Mdot
.44894 .3904 Mdot
.83806 .4173 Mdot
.45447 .44605 Mdot
.29452 .55052 Mdot
.67294 .45681 Mdot
.50561 .32684 Mdot
.60756 .56942 Mdot
.32903 .48308 Mdot
.44841 .39719 Mdot
.35096 .51224 Mdot
.44977 .3905 Mdot
.43831 .35953 Mdot
.32927 .52278 Mdot
.29308 .5626 Mdot
.45105 .33815 Mdot
.46606 .35411 Mdot
.41788 .64346 Mdot
.64477 .41867 Mdot
.75543 .29652 Mdot
.50325 .43006 Mdot
.17879 .47035 Mdot
.44073 .61055 Mdot
.51542 .21449 Mdot
.6567 .57606 Mdot
.43692 .669 Mdot
.43255 .61385 Mdot
.45603 .60736 Mdot
.43556 .66442 Mdot
.32342 .52783 Mdot
.41335 .60605 Mdot
.39646 .6296 Mdot
.43594 .42381 Mdot
.36421 .69701 Mdot
.63667 .27105 Mdot
.49574 .36582 Mdot
.33886 .55592 Mdot
.61693 .55766 Mdot
.2096 .54866 Mdot
.42544 .6072 Mdot
.61199 .72207 Mdot
.62404 .12474 Mdot
.45229 .66608 Mdot
.42682 .4128 Mdot
.64341 .58083 Mdot
.46922 .40345 Mdot
.45736 .39272 Mdot
.27692 .4736 Mdot
.46572 .33946 Mdot
.709 .47567 Mdot
.34498 .48948 Mdot
.67301 .57378 Mdot
.63224 .59843 Mdot
.42472 .62537 Mdot
.29815 .54977 Mdot
.45258 .64957 Mdot
.43109 .33713 Mdot
.65579 .56319 Mdot
.49626 .36692 Mdot
.42412 .64499 Mdot
.36953 .51817 Mdot
.5031 .3952 Mdot
.39855 .76097 Mdot
.83935 .50863 Mdot
.66891 .49544 Mdot
.3034 .45061 Mdot
.37276 .43413 Mdot
.7855 .62151 Mdot
.46091 .36896 Mdot
.66233 .7938 Mdot
.83859 .43892 Mdot
.35388 .52139 Mdot
.42825 .31219 Mdot
.60991 .64428 Mdot
.49414 .41244 Mdot
.50613 .5081 Mdot
.41147 .38186 Mdot
.33842 .73983 Mdot
.64665 .59933 Mdot
.30776 .54089 Mdot
.43134 .38538 Mdot
.50325 .3517 Mdot
.28072 .38191 Mdot
.48979 .3296 Mdot
.42972 .35693 Mdot
.34697 .56933 Mdot
.43725 .6223 Mdot
.52319 .42454 Mdot
.42054 .68676 Mdot
.63204 .70342 Mdot
.44939 .42221 Mdot
.66267 .59314 Mdot
.35522 .5626 Mdot
.47943 .42324 Mdot
.47095 .63817 Mdot
.48145 .35527 Mdot
.4054 .60822 Mdot
.33223 .54989 Mdot
.50671 .35482 Mdot
.68894 .44635 Mdot
.4599 .81126 Mdot
.30339 .53641 Mdot
.59822 .76362 Mdot
.48617 .3502 Mdot
.45184 .40602 Mdot
.33023 .54342 Mdot
.61293 .58697 Mdot
.56665 .47606 Mdot
.32854 .5635 Mdot
.45531 .61035 Mdot
.2818 .52999 Mdot
.40497 .34924 Mdot
.63739 .61228 Mdot
.63353 .71609 Mdot
.62752 .73197 Mdot
.60349 .38321 Mdot
.48647 .4175 Mdot
.29392 .61669 Mdot
.61921 .59658 Mdot
.31324 .53946 Mdot
.44906 .64927 Mdot
.42874 .4288 Mdot
.3002 .51651 Mdot
.43794 .63731 Mdot
.71387 .45421 Mdot
.73215 .50554 Mdot
.34151 .55916 Mdot
.50793 .61929 Mdot
.46839 .60781 Mdot
.4619 .61096 Mdot
.18563 .50167 Mdot
.33752 .54324 Mdot
.68135 .47388 Mdot
.44436 .63736 Mdot
.69434 .35867 Mdot
.4195 .39946 Mdot
.57997 .37874 Mdot
.53435 .85536 Mdot
.20375 .55307 Mdot
.51437 .75932 Mdot
.67364 .48304 Mdot
.47027 .62036 Mdot
.45105 .35732 Mdot
.3428 .53624 Mdot
.33509 .5319 Mdot
.43613 .34072 Mdot
.43268 .36182 Mdot
.50228 .3742 Mdot
.49795 .3491 Mdot
.6865 .29905 Mdot
.50413 .36333 Mdot
.658 .51006 Mdot
.30459 .52605 Mdot
.45012 .34695 Mdot
.60855 .58694 Mdot
.484 .43301 Mdot
.42811 .65683 Mdot
.45788 .40143 Mdot
.42818 .37703 Mdot
.51751 .36536 Mdot
.4547 .66894 Mdot
.71672 .27466 Mdot
.51354 .84907 Mdot
.53846 .18281 Mdot
.55862 .76413 Mdot
.63099 .57409 Mdot
.46933 .419 Mdot
.69278 .47335 Mdot
.40276 .27413 Mdot
.46297 .37858 Mdot
.21212 .66146 Mdot
.42612 .37201 Mdot
.22322 .37201 Mdot
.41737 .46936 Mdot
.53751 .17604 Mdot
.60533 .48885 Mdot
.46964 .34952 Mdot
.29521 .33887 Mdot
.3528 .25039 Mdot
.41889 .57237 Mdot
.43984 .66538 Mdot
.60857 .59241 Mdot
.65102 .58385 Mdot
.43829 .59526 Mdot
.48063 .45148 Mdot
.52236 .44303 Mdot
.54165 .35069 Mdot
.62758 .71859 Mdot
.368 .51195 Mdot
.71371 .48956 Mdot
.36291 .54393 Mdot
.74404 .74599 Mdot
.30507 .71172 Mdot
.43101 .59019 Mdot
.69447 .50659 Mdot
.61653 .62101 Mdot
.62572 .72101 Mdot
.68847 .46846 Mdot
.48448 .37615 Mdot
.32729 .55624 Mdot
.24243 .32487 Mdot
.40486 .454 Mdot
.25288 .29251 Mdot
.2997 .50976 Mdot
.55712 .49878 Mdot
.43551 .64637 Mdot
.59783 .58964 Mdot
.44122 .40399 Mdot
.49485 .38833 Mdot
.36517 .48997 Mdot
.49386 .3673 Mdot
.39149 .49718 Mdot
.42513 .3858 Mdot
.58944 .58743 Mdot
.66385 .48442 Mdot
.4348 .59658 Mdot
.59894 .38882 Mdot
.35661 .50918 Mdot
.57467 .56922 Mdot
.62704 .55576 Mdot
.42173 .26129 Mdot
.42476 .64054 Mdot
.69521 .44637 Mdot
.62209 .56175 Mdot
.70523 .49783 Mdot
.50474 .41354 Mdot
.65689 .57301 Mdot
.68698 .49129 Mdot
.71374 .30053 Mdot
.43694 .42904 Mdot
.70987 .33209 Mdot
.46129 .63637 Mdot
.28208 .52559 Mdot
.4622 .33938 Mdot
.63427 .7328 Mdot
.52428 .39618 Mdot
.48314 .73137 Mdot
.6157 .73037 Mdot
.61377 .70367 Mdot
.80432 .57606 Mdot
.68108 .45376 Mdot
.46895 .77315 Mdot
.26081 .60728 Mdot
.29918 .55326 Mdot
.42806 .40209 Mdot
.60612 .18861 Mdot
.44395 .63803 Mdot
.48062 .37596 Mdot
.59415 .62467 Mdot
.44749 .63779 Mdot
.47381 .40593 Mdot
.46855 .65674 Mdot
.33844 .53566 Mdot
.68933 .68027 Mdot
.28816 .54338 Mdot
.43167 .42514 Mdot
.46901 .63983 Mdot
.63449 .56247 Mdot
.333 .52101 Mdot
.48095 .35884 Mdot
.44636 .40958 Mdot
.62535 .71013 Mdot
.46121 .3457 Mdot
.61745 .20094 Mdot
.47974 .34132 Mdot
.64263 .62376 Mdot
.48256 .32991 Mdot
.19199 .62167 Mdot
.70921 .54643 Mdot
.30234 .55251 Mdot
.61312 .70946 Mdot
.64101 .59613 Mdot
.75997 .60241 Mdot
.47466 .57588 Mdot
.4706 .3599 Mdot
.61988 .7016 Mdot
.59912 .46635 Mdot
.41474 .64269 Mdot
.48448 .32434 Mdot
.34022 .7227 Mdot
.60971 .57248 Mdot
.62537 .71784 Mdot
.48922 .31281 Mdot
.35646 .56224 Mdot
.43045 .38275 Mdot
.64288 .56068 Mdot
.28111 .53269 Mdot
.46844 .43258 Mdot
.58326 .25903 Mdot
.62053 .73144 Mdot
.461 .63878 Mdot
.45494 .47191 Mdot
.50219 .36689 Mdot
.64837 .57433 Mdot
.3389 .50366 Mdot
.4472 .61218 Mdot
.3192 .52284 Mdot
.29702 .27737 Mdot
.55057 .77315 Mdot
.65299 .2661 Mdot
.69861 .50675 Mdot
.52711 .70295 Mdot
.51363 .17552 Mdot
.48728 .78998 Mdot
.64785 .35883 Mdot
.38327 .19399 Mdot
.61445 .57337 Mdot
.69175 .51839 Mdot
.64003 .58993 Mdot
.44487 .37246 Mdot
.62912 .60007 Mdot
.53637 .17102 Mdot
.42435 .37587 Mdot
.63671 .57345 Mdot
.72114 .6328 Mdot
.4395 .35028 Mdot
.3016 .53417 Mdot
.82661 .40814 Mdot
.35857 .77632 Mdot
.23267 .63004 Mdot
.62178 .57572 Mdot
.32447 .47077 Mdot
.44768 .34059 Mdot
.49894 .42955 Mdot
.34565 .5312 Mdot
.47535 .32615 Mdot
.71486 .48668 Mdot
.71129 .49668 Mdot
.58305 .40282 Mdot
.59322 .80905 Mdot
.52666 .42366 Mdot
.33647 .52227 Mdot
.37392 .35595 Mdot
.39385 .75423 Mdot
.6401 .70984 Mdot
.4475 .687 Mdot
.72999 .29009 Mdot
.4978 .44965 Mdot
.50396 .61863 Mdot
.36233 .73486 Mdot
.3162 .55083 Mdot
.66533 .24557 Mdot
.44671 .66496 Mdot
.33554 .32171 Mdot
.21757 .42823 Mdot
.49088 .3842 Mdot
.42678 .63151 Mdot
.53918 .39775 Mdot
.30588 .72987 Mdot
.72452 .37344 Mdot
.79527 .66007 Mdot
.43536 .42591 Mdot
.45081 .76791 Mdot
.4538 .4036 Mdot
.57366 .44156 Mdot
.47999 .34087 Mdot
.32221 .51816 Mdot
.47632 .27656 Mdot
.46468 .53554 Mdot
.5726 .83129 Mdot
.29109 .70074 Mdot
.67607 .48745 Mdot
.44688 .40734 Mdot
.49119 .38595 Mdot
.69005 .45296 Mdot
.33402 .50977 Mdot
.48675 .34506 Mdot
.58024 .30086 Mdot
.49921 .37739 Mdot
.43155 .66475 Mdot
.61803 .43788 Mdot
.38392 .49755 Mdot
.51217 .356 Mdot
.29141 .55251 Mdot
.46007 .66432 Mdot
.42418 .6231 Mdot
.41629 .34678 Mdot
.47492 .63642 Mdot
.42816 .38632 Mdot
.71133 .41106 Mdot
.35471 .53565 Mdot
.39893 .45478 Mdot
.32786 .50665 Mdot
.36082 .44839 Mdot
.47269 .64315 Mdot
.63397 .72859 Mdot
.30442 .59274 Mdot
.44941 .66225 Mdot
.22591 .60889 Mdot
.55101 .3839 Mdot
.5282 .36855 Mdot
.28207 .7074 Mdot
.62247 .57063 Mdot
.62992 .72691 Mdot
.46877 .63082 Mdot
.50283 .36883 Mdot
.51057 .33746 Mdot
.43137 .67098 Mdot
.30598 .38237 Mdot
.76256 .58856 Mdot
.44182 .34286 Mdot
.32653 .51446 Mdot
.31281 .53697 Mdot
.48241 .42756 Mdot
.47493 .3649 Mdot
.63327 .62418 Mdot
.61441 .71994 Mdot
.63086 .69677 Mdot
.62696 .73094 Mdot
.59651 .61127 Mdot
.37759 .66924 Mdot
.45777 .60819 Mdot
.32834 .63221 Mdot
.46038 .72377 Mdot
.40237 .43672 Mdot
.64484 .56895 Mdot
.48622 .39565 Mdot
.43508 .39292 Mdot
.44864 .61291 Mdot
.54125 .72552 Mdot
.42099 .31945 Mdot
.35183 .54893 Mdot
.4749 .64139 Mdot
.53789 .41853 Mdot
.37074 .61714 Mdot
.70325 .49009 Mdot
.23187 .63456 Mdot
.42364 .63815 Mdot
.30761 .54881 Mdot
.44495 .67714 Mdot
.49523 .38362 Mdot
.42021 .36957 Mdot
.3244 .54672 Mdot
.67563 .46001 Mdot
.45408 .31671 Mdot
.4736 .40746 Mdot
.30355 .78846 Mdot
.40267 .76309 Mdot
.48919 .67551 Mdot
.45934 .35353 Mdot
.51749 .34655 Mdot
.68238 .49784 Mdot
.49659 .37788 Mdot
.44412 .41057 Mdot
.46778 .81793 Mdot
.47084 .69874 Mdot
.67947 .44534 Mdot
.34038 .31783 Mdot
.29783 .51189 Mdot
.66098 .22599 Mdot
.62821 .69771 Mdot
.41047 .62731 Mdot
.67863 .68416 Mdot
.62194 .72229 Mdot
.49446 .72099 Mdot
.66553 .23759 Mdot
.62778 .72987 Mdot
.59052 .63413 Mdot
.45557 .2912 Mdot
.43397 .34706 Mdot
.46 .40581 Mdot
.69351 .47875 Mdot
.33869 .54144 Mdot
.58261 .49335 Mdot
.76186 .39453 Mdot
.44904 .40044 Mdot
.2887 .49696 Mdot
.73513 .31316 Mdot
.62332 .71315 Mdot
.71514 .4689 Mdot
.72622 .46671 Mdot
.4543 .4081 Mdot
.50162 .81447 Mdot
.3313 .52318 Mdot
.48049 .35898 Mdot
.50985 .36746 Mdot
.625 .57237 Mdot
.31483 .55494 Mdot
.63097 .55563 Mdot
.61881 .73347 Mdot
.39342 .21885 Mdot
.2657 .75548 Mdot
.45148 .61707 Mdot
.57347 .20323 Mdot
.41588 .6322 Mdot
.81015 .60979 Mdot
.62026 .72611 Mdot
.4631 .37333 Mdot
.35964 .51017 Mdot
.48322 .35558 Mdot
.47886 .38213 Mdot
.48505 .37757 Mdot
.54843 .38792 Mdot
.2091 .65423 Mdot
.6977 .46334 Mdot
.39482 .40092 Mdot
.65003 .61668 Mdot
.59966 .20227 Mdot
.8167 .43691 Mdot
.49102 .39878 Mdot
.45545 .4122 Mdot
.29946 .52701 Mdot
.4419 .33586 Mdot
.41734 .65638 Mdot
.3406 .50366 Mdot
.51869 .37076 Mdot
.65331 .24235 Mdot
.49073 .34758 Mdot
.51346 .18287 Mdot
.44187 .67724 Mdot
.22903 .61285 Mdot
.39611 .39168 Mdot
.63025 .73076 Mdot
.62969 .72732 Mdot
.62684 .68774 Mdot
.42894 .67856 Mdot
.643 .57288 Mdot
.79495 .44781 Mdot
.47496 .44866 Mdot
.44749 .35832 Mdot
.51444 .34044 Mdot
.62232 .63873 Mdot
.50421 .50444 Mdot
.49461 .76929 Mdot
.54172 .41218 Mdot
.63 .61945 Mdot
.28272 .52118 Mdot
.60255 .7435 Mdot
.34247 .50507 Mdot
.67698 .44714 Mdot
.42853 .64066 Mdot
.70985 .48766 Mdot
.21704 .58019 Mdot
.33212 .54794 Mdot
.36992 .49238 Mdot
.63321 .57323 Mdot
.54118 .52146 Mdot
.58885 .12925 Mdot
.6637 .57018 Mdot
.605 .34629 Mdot
.34505 .52525 Mdot
.51397 .37047 Mdot
.60971 .45458 Mdot
.53418 .52094 Mdot
.63311 .5815 Mdot
.45398 .37825 Mdot
.56325 .81323 Mdot
.63037 .62419 Mdot
.48723 .32437 Mdot
.61502 .59887 Mdot
.43046 .65645 Mdot
.61701 .59548 Mdot
.34259 .50059 Mdot
.47368 .42346 Mdot
.61954 .13375 Mdot
.58501 .5286 Mdot
.47365 .34247 Mdot
.47477 .64218 Mdot
.55273 .27589 Mdot
.47601 .38999 Mdot
.71872 .48151 Mdot
.63577 .61437 Mdot
.76804 .55252 Mdot
.45423 .33834 Mdot
.62313 .58786 Mdot
.35577 .51599 Mdot
.41608 .67225 Mdot
.81345 .56708 Mdot
.63637 .71606 Mdot
.34716 .5371 Mdot
.60932 .72834 Mdot
.4698 .67012 Mdot
.50929 .33871 Mdot
.50761 .36883 Mdot
.31265 .5202 Mdot
.68638 .71649 Mdot
.4723 .33213 Mdot
.46078 .36924 Mdot
.6097 .61639 Mdot
.63756 .63563 Mdot
.69747 .69175 Mdot
.61726 .57069 Mdot
.49485 .32154 Mdot
.3134 .52044 Mdot
.43564 .38578 Mdot
.29993 .53848 Mdot
.42811 .39911 Mdot
.2754 .56004 Mdot
.35363 .52394 Mdot
.57294 .7878 Mdot
.44368 .38164 Mdot
.43147 .47064 Mdot
.48287 .38067 Mdot
.49718 .37119 Mdot
.64984 .61196 Mdot
.70173 .45749 Mdot
.41285 .41908 Mdot
.63075 .52606 Mdot
.71737 .46703 Mdot
.3133 .27365 Mdot
.62174 .57393 Mdot
.69714 .48456 Mdot
.71214 .32484 Mdot
.61514 .70272 Mdot
.69865 .47122 Mdot
.81509 .42503 Mdot
.45043 .61552 Mdot
.29318 .51153 Mdot
.43914 .35109 Mdot
.36292 .20805 Mdot
.6835 .40597 Mdot
.62185 .70544 Mdot
.47765 .34219 Mdot
.48264 .39483 Mdot
.3341 .56891 Mdot
.71275 .76928 Mdot
.62464 .63017 Mdot
.44179 .36987 Mdot
.29091 .54163 Mdot
.5697 .85215 Mdot
.65916 .60231 Mdot
.6963 .47389 Mdot
.43672 .67256 Mdot
.32579 .57959 Mdot
.63688 .71459 Mdot
.41393 .64887 Mdot
.6544 .67863 Mdot
.21769 .60172 Mdot
.48847 .35061 Mdot
.64974 .5702 Mdot
.2006 .56591 Mdot
.49467 .44365 Mdot
.49679 .64722 Mdot
.56297 .40723 Mdot
.31297 .54935 Mdot
.43259 .67045 Mdot
.69716 .49631 Mdot
.33927 .5018 Mdot
.33455 .51122 Mdot
.43508 .60857 Mdot
.64994 .65227 Mdot
.55283 .50298 Mdot
.42615 .65884 Mdot
.34985 .74248 Mdot
.26177 .30878 Mdot
.61585 .70763 Mdot
.71031 .45724 Mdot
.1912 .41278 Mdot
.32303 .52721 Mdot
.72726 .28694 Mdot
.20452 .60939 Mdot
.43011 .35627 Mdot
.68636 .48478 Mdot
.40932 .7076 Mdot
.79042 .43115 Mdot
.45104 .6372 Mdot
.45531 .52103 Mdot
.71846 .45106 Mdot
.45148 .33584 Mdot
.25135 .52082 Mdot
.45037 .37349 Mdot
.43139 .64261 Mdot
.37587 .45547 Mdot
.30601 .54803 Mdot
.47475 .66334 Mdot
.2285 .63126 Mdot
.43498 .39624 Mdot
.44947 .37852 Mdot
.62789 .41616 Mdot
.33099 .55666 Mdot
.63427 .70132 Mdot
.47667 .35316 Mdot
.46687 .40426 Mdot
.51499 .35177 Mdot
.48898 .46205 Mdot
.47441 .80736 Mdot
.44155 .37203 Mdot
.59789 .57477 Mdot
.50988 .41782 Mdot
.44509 .38381 Mdot
.29532 .55508 Mdot
.25926 .74187 Mdot
.62979 .73509 Mdot
.46047 .40234 Mdot
.4907 .34995 Mdot
.44196 .60857 Mdot
.58015 .48374 Mdot
.52584 .52454 Mdot
.66286 .57624 Mdot
.66382 .34135 Mdot
.54805 .38699 Mdot
.30056 .51352 Mdot
.70048 .44512 Mdot
.50422 .40547 Mdot
.29661 .52211 Mdot
.47103 .44054 Mdot
.6278 .62176 Mdot
.61484 .71334 Mdot
.25481 .64551 Mdot
.70329 .47582 Mdot
.65707 .42854 Mdot
.32484 .64691 Mdot
.6073 .59464 Mdot
.44445 .35711 Mdot
.41199 .63067 Mdot
.65934 .57355 Mdot
.62632 .70831 Mdot
.44283 .31324 Mdot
.33685 .52939 Mdot
.30545 .53816 Mdot
.58996 .4112 Mdot
.6562 .53352 Mdot
.40013 .82885 Mdot
.42999 .65464 Mdot
.51256 .41002 Mdot
.27272 .61246 Mdot
.30449 .53779 Mdot
.59225 .40578 Mdot
.69861 .48473 Mdot
.45271 .63679 Mdot
.63772 .69833 Mdot
.29817 .52313 Mdot
.33588 .55878 Mdot
.44367 .43157 Mdot
.48666 .4089 Mdot
.64059 .36093 Mdot
.5847 .40092 Mdot
.44967 .66949 Mdot
.6989 .45137 Mdot
.64087 .55332 Mdot
.44972 .36835 Mdot
.35355 .51904 Mdot
.23759 .34188 Mdot
.49826 .35376 Mdot
.63404 .62474 Mdot
.31524 .54792 Mdot
.68715 .45291 Mdot
.71891 .47588 Mdot
.49693 .37189 Mdot
.30085 .46195 Mdot
.46178 .6555 Mdot
.30243 .53716 Mdot
.24096 .56857 Mdot
.47641 .33218 Mdot
.48563 .41253 Mdot
.52211 .32652 Mdot
.41884 .6321 Mdot
.23445 .61406 Mdot
.68403 .44602 Mdot
.32851 .53443 Mdot
.47854 .34635 Mdot
.70835 .4762 Mdot
.24812 .60843 Mdot
.6183 .71878 Mdot
.61703 .59987 Mdot
.71764 .48457 Mdot
.68017 .46422 Mdot
.71472 .45778 Mdot
.74195 .30064 Mdot
.37037 .51618 Mdot
.37878 .35255 Mdot
.47536 .33831 Mdot
.59169 .41491 Mdot
.41391 .40417 Mdot
.42952 .67661 Mdot
.6226 .56851 Mdot
.48202 .384 Mdot
.4446 .43146 Mdot
.52101 .45586 Mdot
.4377 .46311 Mdot
.30697 .48654 Mdot
.32839 .55292 Mdot
.41875 .44698 Mdot
.62799 .56885 Mdot
.71029 .78118 Mdot
.5684 .14798 Mdot
.40073 .37142 Mdot
.56551 .50002 Mdot
.35044 .5129 Mdot
.43461 .60708 Mdot
.51109 .5304 Mdot
.45913 .67136 Mdot
.32278 .53644 Mdot
.44738 .36997 Mdot
.33459 .63548 Mdot
.6937 .5027 Mdot
.50369 .3725 Mdot
.4386 .6435 Mdot
.50306 .37317 Mdot
.42128 .66387 Mdot
.37053 .58694 Mdot
.36788 .74642 Mdot
.42617 .37068 Mdot
.49237 .33457 Mdot
.48805 .4705 Mdot
.4887 .40051 Mdot
.71568 .73137 Mdot
.34098 .50929 Mdot
.57896 .81005 Mdot
.46244 .4336 Mdot
.33835 .43462 Mdot
.47317 .33586 Mdot
.6613 .73142 Mdot
.49296 .40719 Mdot
.49802 .55297 Mdot
.43672 .34557 Mdot
.45588 .41802 Mdot
.46917 .64427 Mdot
.44111 .60848 Mdot
.35923 .53577 Mdot
.63682 .70641 Mdot
.55068 .18457 Mdot
.47781 .41035 Mdot
.59274 .59292 Mdot
.50374 .63982 Mdot
.68559 .4574 Mdot
.32164 .53422 Mdot
.57446 .85885 Mdot
.46631 .65923 Mdot
.65705 .55106 Mdot
.68812 .72533 Mdot
.60114 .58093 Mdot
.44824 .70092 Mdot
.53514 .31874 Mdot
.67637 .46154 Mdot
.45859 .33405 Mdot
.18378 .47193 Mdot
.41339 .75577 Mdot
.44059 .31859 Mdot
.47339 .66219 Mdot
.39786 .28487 Mdot
.19255 .41502 Mdot
.72574 .4779 Mdot
.68567 .49447 Mdot
.46696 .65256 Mdot
.60311 .60784 Mdot
.54155 .35749 Mdot
.69913 .4857 Mdot
.61269 .60867 Mdot
.62362 .68823 Mdot
.45424 .56114 Mdot
.32916 .52558 Mdot
.23594 .63647 Mdot
.33471 .68086 Mdot
.45278 .66908 Mdot
.59609 .54549 Mdot
.29505 .57132 Mdot
.36645 .55169 Mdot
.63786 .72014 Mdot
.65052 .61202 Mdot
.3559 .50433 Mdot
.47765 .31892 Mdot
.41536 .46236 Mdot
.45307 .40152 Mdot
.68698 .47616 Mdot
.49523 .39939 Mdot
.64422 .617 Mdot
.4498 .64098 Mdot
.65532 .59451 Mdot
.46654 .64368 Mdot
.3664 .66137 Mdot
.48169 .36447 Mdot
.45842 .41719 Mdot
.67854 .41141 Mdot
.35667 .54917 Mdot
.21595 .55478 Mdot
.59226 .60022 Mdot
.64292 .58489 Mdot
.43402 .40428 Mdot
.35012 .50746 Mdot
.662 .46509 Mdot
.67885 .41415 Mdot
.50836 .38166 Mdot
.34092 .50876 Mdot
.44475 .36448 Mdot
.70554 .30701 Mdot
.3918 .77472 Mdot
.31503 .52529 Mdot
.60949 .8106 Mdot
.45916 .35907 Mdot
.43224 .29318 Mdot
.51307 .33769 Mdot
.59914 .31119 Mdot
.47526 .33117 Mdot
.30072 .5085 Mdot
.45687 .3994 Mdot
.32954 .50135 Mdot
.60511 .60336 Mdot
.44394 .60376 Mdot
.34944 .53386 Mdot
.51111 .37822 Mdot
.72615 .26429 Mdot
.43178 .64819 Mdot
.4454 .40603 Mdot
.4405 .62433 Mdot
.28917 .53043 Mdot
.34389 .55444 Mdot
.80957 .45059 Mdot
.48395 .68773 Mdot
.43233 .65814 Mdot
.43718 .37021 Mdot
.30735 .67796 Mdot
.43799 .3809 Mdot
.63413 .36798 Mdot
.44807 .42746 Mdot
.47966 .33036 Mdot
.84716 .53073 Mdot
.41521 .629 Mdot
.41243 .82923 Mdot
.75726 .38203 Mdot
.75201 .31057 Mdot
.3488 .5763 Mdot
.72588 .4774 Mdot
.67573 .25176 Mdot
.6167 .73166 Mdot
.62462 .60838 Mdot
.48327 .38367 Mdot
.38338 .55104 Mdot
.43525 .66937 Mdot
.69815 .45751 Mdot
.42578 .37286 Mdot
.64015 .62284 Mdot
.79484 .55688 Mdot
.47296 .62635 Mdot
.32316 .52855 Mdot
.35298 .55033 Mdot
.55043 .85127 Mdot
.4799 .34572 Mdot
.45078 .41206 Mdot
.42977 .64008 Mdot
.46871 .45775 Mdot
.69016 .44834 Mdot
.71636 .61858 Mdot
.43307 .65806 Mdot
.54986 .57619 Mdot
.33551 .54949 Mdot
.48458 .39482 Mdot
.52091 .49776 Mdot
.53554 .63013 Mdot
.34051 .28246 Mdot
.69208 .47581 Mdot
.64229 .37989 Mdot
.3002 .50901 Mdot
.44616 .64667 Mdot
.74081 .4941 Mdot
.51937 .40485 Mdot
.47831 .39738 Mdot
.64213 .38432 Mdot
.59157 .47703 Mdot
.65784 .46603 Mdot
.42919 .34566 Mdot
.59117 .4717 Mdot
.43638 .40989 Mdot
.51832 .35816 Mdot
.44498 .32688 Mdot
.48352 .4171 Mdot
.34439 .50968 Mdot
.53025 .44615 Mdot
.62066 .5945 Mdot
.28751 .37267 Mdot
.46996 .52328 Mdot
.459 .34203 Mdot
.44442 .37463 Mdot
.37523 .26994 Mdot
.48907 .69324 Mdot
.34411 .51492 Mdot
.34585 .49554 Mdot
.47119 .62944 Mdot
.42661 .47129 Mdot
.61148 .62744 Mdot
.55523 .42107 Mdot
.65407 .59768 Mdot
.33812 .50682 Mdot
.64734 .58141 Mdot
.4667 .61999 Mdot
.65018 .57019 Mdot
.59538 .60822 Mdot
.42662 .66693 Mdot
.34289 .54807 Mdot
.50359 .39024 Mdot
.47347 .63803 Mdot
.62913 .41318 Mdot
.68798 .47736 Mdot
.80986 .44947 Mdot
.50275 .42252 Mdot
.4433 .50356 Mdot
.58542 .2603 Mdot
.65385 .59291 Mdot
.41365 .79455 Mdot
.35373 .5254 Mdot
.67665 .49907 Mdot
.34279 .50741 Mdot
.20851 .62681 Mdot
.70144 .45496 Mdot
.8149 .42157 Mdot
.68194 .61752 Mdot
.78901 .52973 Mdot
.42219 .35841 Mdot
.27246 .56197 Mdot
.65038 .56176 Mdot
.43711 .66955 Mdot
.65604 .65587 Mdot
.46033 .42173 Mdot
.49827 .78894 Mdot
.35243 .56036 Mdot
.62163 .69239 Mdot
.45123 .65101 Mdot
.47747 .6507 Mdot
.48729 .35281 Mdot
.73174 .64749 Mdot
.46387 .42609 Mdot
.68327 .54678 Mdot
.65526 .3582 Mdot
.5589 .41431 Mdot
.42703 .39149 Mdot
.66115 .58938 Mdot
.44392 .36448 Mdot
.41243 .28433 Mdot
.18473 .49563 Mdot
.51711 .32852 Mdot
.56409 .7777 Mdot
.71331 .42727 Mdot
.32853 .54609 Mdot
.39713 .39762 Mdot
.6302 .70496 Mdot
.45958 .35593 Mdot
.15519 .40545 Mdot
.7014 .47081 Mdot
.57945 .58868 Mdot
.48364 .33766 Mdot
.48001 .35299 Mdot
.21322 .48301 Mdot
.37893 .56565 Mdot
.63833 .69836 Mdot
.47339 .39869 Mdot
.67891 .35517 Mdot
.43338 .61954 Mdot
.47522 .42678 Mdot
.45761 .40632 Mdot
.34341 .25293 Mdot
.42066 .63254 Mdot
.65405 .58868 Mdot
.6129 .72362 Mdot
.63622 .55221 Mdot
.71196 .44137 Mdot
.51815 .54068 Mdot
.58321 .38415 Mdot
.39133 .77206 Mdot
.72376 .46566 Mdot
.50705 .35831 Mdot
.42177 .31753 Mdot
.46688 .3573 Mdot
.69093 .49757 Mdot
.41862 .64062 Mdot
.34981 .52067 Mdot
.26497 .65168 Mdot
.627 .71669 Mdot
.4901 .32527 Mdot
.70922 .49358 Mdot
.34149 .53364 Mdot
.57777 .55577 Mdot
.32961 .54027 Mdot
.44302 .66142 Mdot
.4448 .68305 Mdot
.70997 .46495 Mdot
.33846 .50519 Mdot
.61933 .5516 Mdot
.76166 .39815 Mdot
.43949 .42248 Mdot
.48394 .65573 Mdot
.35898 .51651 Mdot
.29825 .56475 Mdot
.35808 .55447 Mdot
.4898 .36575 Mdot
.57185 .49119 Mdot
.51974 .36441 Mdot
.46468 .65798 Mdot
.61671 .60689 Mdot
.57534 .36877 Mdot
.20632 .49621 Mdot
.56753 .54885 Mdot
.41071 .38993 Mdot
.44109 .3987 Mdot
.45407 .40794 Mdot
.42283 .41369 Mdot
.70783 .51885 Mdot
.47732 .3649 Mdot
.4683 .64322 Mdot
.64724 .60804 Mdot
.46935 .33931 Mdot
.62869 .70114 Mdot
.54743 .50033 Mdot
.70842 .44693 Mdot
.49228 .53674 Mdot
.66326 .21891 Mdot
.34304 .533 Mdot
.62717 .5596 Mdot
.6242 .60577 Mdot
.71336 .45363 Mdot
.44053 .6686 Mdot
.33512 .54058 Mdot
.60611 .30483 Mdot
.7091 .4535 Mdot
.46066 .40096 Mdot
.6692 .676 Mdot
.60869 .77811 Mdot
.45624 .33241 Mdot
.47131 .38302 Mdot
.61251 .71074 Mdot
.6048 .61587 Mdot
.29857 .23348 Mdot
.61418 .45882 Mdot
.70616 .46075 Mdot
.67626 .47906 Mdot
.36472 .5476 Mdot
.41262 .33811 Mdot
.4644 .64541 Mdot
.62294 .44129 Mdot
.55903 .29462 Mdot
.64442 .45139 Mdot
.80735 .60868 Mdot
.4996 .36176 Mdot
.22425 .4725 Mdot
.43058 .39071 Mdot
.34468 .56568 Mdot
.29976 .55195 Mdot
.34178 .51881 Mdot
.45719 .66257 Mdot
.36359 .43825 Mdot
.46769 .63651 Mdot
.62264 .1851 Mdot
.3138 .49964 Mdot
.74248 .52143 Mdot
.64298 .57699 Mdot
.427 .44054 Mdot
.68421 .45295 Mdot
.42628 .69459 Mdot
.43322 .33491 Mdot
.48861 .80857 Mdot
.64579 .56958 Mdot
.33941 .55303 Mdot
.52658 .30994 Mdot
.47078 .17424 Mdot
.54111 .5281 Mdot
.38256 .38319 Mdot
.228 .5257 Mdot
.69461 .45261 Mdot
.33771 .28787 Mdot
.67263 .46426 Mdot
.44212 .63694 Mdot
.46722 .42159 Mdot
.4908 .4155 Mdot
.42708 .39789 Mdot
.47878 .36597 Mdot
.45159 .6129 Mdot
.44468 .43764 Mdot
.19203 .62171 Mdot
.61415 .7101 Mdot
.70127 .29402 Mdot
.70252 .48817 Mdot
.4578 .67546 Mdot
.64946 .60434 Mdot
.63159 .69565 Mdot
.59192 .38401 Mdot
.43668 .34667 Mdot
.48198 .38204 Mdot
.63948 .7238 Mdot
.44662 .32859 Mdot
.54563 .4038 Mdot
.62216 .59423 Mdot
.56917 .54004 Mdot
.72018 .48516 Mdot
.70879 .48814 Mdot
.42082 .65079 Mdot
.34022 .50582 Mdot
.69626 .4819 Mdot
.60901 .61685 Mdot
.45433 .4404 Mdot
.51294 .38246 Mdot
.35975 .51809 Mdot
.20448 .61056 Mdot
.72775 .47409 Mdot
.52164 .30479 Mdot
.3112 .50307 Mdot
.37416 .52524 Mdot
.47564 .39618 Mdot
.5185 .32612 Mdot
.28764 .55942 Mdot
.72118 .47304 Mdot
.46086 .67387 Mdot
.78005 .49709 Mdot
.43592 .63941 Mdot
.33895 .53869 Mdot
.478 .4306 Mdot
.33992 .54894 Mdot
.46338 .35073 Mdot
.89049 .52939 Mdot
.49336 .4114 Mdot
.33818 .76219 Mdot
.60771 .32833 Mdot
.62742 .60649 Mdot
.61896 .55219 Mdot
.6221 .69981 Mdot
.30813 .50382 Mdot
.50407 .40764 Mdot
.67434 .47565 Mdot
.77465 .353 Mdot
.27499 .55564 Mdot
.62456 .61703 Mdot
.60675 .62199 Mdot
.41525 .64428 Mdot
.48442 .34023 Mdot
.48468 .3977 Mdot
.65221 .57281 Mdot
.60727 .26125 Mdot
.30451 .51285 Mdot
.44957 .41038 Mdot
.4413 .3926 Mdot
.62542 .6012 Mdot
.76136 .40037 Mdot
.32582 .59077 Mdot
.47038 .42004 Mdot
.73425 .45393 Mdot
.42821 .67709 Mdot
.42247 .4075 Mdot
.44253 .43714 Mdot
.67895 .47618 Mdot
.6474 .24768 Mdot
.17545 .4524 Mdot
.43305 .6759 Mdot
.63436 .70204 Mdot
.51394 .36391 Mdot
.64122 .57694 Mdot
.51219 .37847 Mdot
.51656 .20537 Mdot
.61725 .69938 Mdot
.46855 .36796 Mdot
.40843 .35296 Mdot
.31084 .55697 Mdot
.4762 .36115 Mdot
.37657 .2506 Mdot
.65635 .56048 Mdot
.47208 .3649 Mdot
.28021 .47527 Mdot
.42328 .62729 Mdot
.40099 .3731 Mdot
.69598 .49336 Mdot
.59445 .30528 Mdot
.33087 .65831 Mdot
.6265 .64192 Mdot
.70971 .48562 Mdot
.50632 .38703 Mdot
.60134 .6007 Mdot
.44451 .67202 Mdot
.48095 .79271 Mdot
.42279 .36923 Mdot
.43164 .64421 Mdot
.45045 .64269 Mdot
.70818 .47133 Mdot
.45041 .84246 Mdot
.41638 .4317 Mdot
.49147 .39924 Mdot
.38613 .2379 Mdot
.32609 .56442 Mdot
.49855 .39476 Mdot
.50254 .35593 Mdot
.46222 .63284 Mdot
.29285 .58998 Mdot
.37838 .30435 Mdot
.72007 .63347 Mdot
.42221 .66666 Mdot
.65745 .63837 Mdot
.60105 .59787 Mdot
.70071 .48803 Mdot
.32132 .54529 Mdot
.71046 .44444 Mdot
.6204 .58 Mdot
.48933 .34799 Mdot
.45687 .63148 Mdot
.27036 .33087 Mdot
.42449 .60905 Mdot
.67055 .59873 Mdot
.31811 .57057 Mdot
.2779 .62273 Mdot
.14705 .48028 Mdot
.34609 .68344 Mdot
.41302 .60609 Mdot
.68509 .4579 Mdot
.66106 .66153 Mdot
.44138 .395 Mdot
.32992 .30846 Mdot
.50382 .38132 Mdot
.24329 .5034 Mdot
.614 .57785 Mdot
.63879 .7185 Mdot
.46975 .42144 Mdot
.65404 .36928 Mdot
.45922 .60342 Mdot
.41464 .64645 Mdot
.47425 .37345 Mdot
.4485 .66273 Mdot
.48383 .40743 Mdot
.65142 .60767 Mdot
.38727 .80966 Mdot
.44282 .40218 Mdot
.52256 .35773 Mdot
.50532 .6716 Mdot
.81115 .44285 Mdot
.60476 .56068 Mdot
.22139 .47432 Mdot
.4393 .17989 Mdot
.45005 .66164 Mdot
.42878 .32147 Mdot
.65168 .56569 Mdot
.61255 .70972 Mdot
.62789 .54534 Mdot
.49988 .38245 Mdot
.49545 .37647 Mdot
.43349 .40347 Mdot
.44973 .37766 Mdot
.33448 .30269 Mdot
.48817 .45905 Mdot
.24257 .4558 Mdot
.47976 .38134 Mdot
.24979 .52542 Mdot
.46611 .62743 Mdot
.32548 .48419 Mdot
.73023 .47778 Mdot
.49802 .36003 Mdot
.39017 .50202 Mdot
.44049 .67905 Mdot
.62008 .18405 Mdot
.4168 .6393 Mdot
.64063 .59763 Mdot
.42661 .614 Mdot
.46295 .34644 Mdot
.31209 .53661 Mdot
.66369 .57233 Mdot
.46565 .76154 Mdot
.6252 .61008 Mdot
.47399 .34239 Mdot
.75974 .46112 Mdot
.62221 .6039 Mdot
.52363 .51149 Mdot
.31228 .54112 Mdot
.68346 .3618 Mdot
.29713 .5501 Mdot
.46912 .36475 Mdot
.46523 .36689 Mdot
.61827 .68905 Mdot
.4566 .60553 Mdot
.28801 .52856 Mdot
.31364 .79633 Mdot
.69113 .43773 Mdot
.3355 .51755 Mdot
.47774 .44582 Mdot
.58259 .48639 Mdot
.30771 .52815 Mdot
.6441 .31681 Mdot
.4415 .66969 Mdot
.36663 .51324 Mdot
.49978 .43325 Mdot
.50513 .60936 Mdot
.68835 .50441 Mdot
.65303 .61733 Mdot
.52253 .58219 Mdot
.64842 .55943 Mdot
.44832 .68007 Mdot
.66423 .61109 Mdot
.43674 .61669 Mdot
.2279 .57267 Mdot
.38426 .45079 Mdot
.42077 .6077 Mdot
.46108 .67695 Mdot
.62874 .57727 Mdot
.42339 .37584 Mdot
.43926 .53059 Mdot
.43081 .34205 Mdot
.41707 .37914 Mdot
.4316 .619 Mdot
.29223 .52313 Mdot
.29432 .50835 Mdot
.26016 .54717 Mdot
.35212 .55314 Mdot
.65447 .60155 Mdot
.38678 .77586 Mdot
.21659 .57624 Mdot
.42696 .63632 Mdot
.47175 .67331 Mdot
.43959 .37899 Mdot
.63749 .57571 Mdot
.60538 .59559 Mdot
.46121 .64203 Mdot
.29315 .32571 Mdot
.52177 .37019 Mdot
.30675 .56613 Mdot
.32083 .49851 Mdot
.31424 .52213 Mdot
.36151 .54884 Mdot
.357 .35011 Mdot
.43866 .67011 Mdot
.31058 .50161 Mdot
.47071 .37184 Mdot
.49684 .37853 Mdot
.63194 .7227 Mdot
.70524 .49078 Mdot
.47654 .44025 Mdot
.51849 .3336 Mdot
.47755 .39497 Mdot
.61785 .60105 Mdot
.39022 .38162 Mdot
.6257 .69531 Mdot
.63349 .62967 Mdot
.61101 .62899 Mdot
.63323 .72867 Mdot
.25639 .53388 Mdot
.44828 .16799 Mdot
.44208 .36956 Mdot
.38811 .4351 Mdot
.63884 .58056 Mdot
.43295 .81316 Mdot
.23953 .61326 Mdot
.42595 .39362 Mdot
.47924 .57371 Mdot
.6655 .58607 Mdot
.33715 .56348 Mdot
.50122 .38892 Mdot
.62364 .72978 Mdot
.70599 .44653 Mdot
.48486 .44372 Mdot
.61298 .72502 Mdot
.33075 .50414 Mdot
.69527 .51452 Mdot
.37183 .52323 Mdot
.66644 .58579 Mdot
.40649 .35807 Mdot
.58987 .12711 Mdot
.62752 .55621 Mdot
.77467 .3678 Mdot
.37831 .57303 Mdot
.44449 .40881 Mdot
.63346 .55583 Mdot
.33099 .56576 Mdot
.43219 .68048 Mdot
.58773 .46846 Mdot
.35427 .53376 Mdot
.63648 .70382 Mdot
.62724 .7251 Mdot
.62218 .59707 Mdot
.32353 .55353 Mdot
.4748 .42859 Mdot
.30073 .54697 Mdot
.42304 .61836 Mdot
.42899 .37488 Mdot
.53217 .17233 Mdot
.41661 .45837 Mdot
.30065 .51028 Mdot
.63828 .62518 Mdot
.68289 .49935 Mdot
.43103 .35739 Mdot
.75595 .3574 Mdot
.49433 .34678 Mdot
.43085 .62563 Mdot
.53813 .82614 Mdot
.29171 .3061 Mdot
.46945 .33663 Mdot
.44066 .37862 Mdot
.42916 .66962 Mdot
.4345 .34995 Mdot
.46926 .3333 Mdot
.49795 .65901 Mdot
.30731 .55335 Mdot
.45191 .39813 Mdot
.61049 .61055 Mdot
.19547 .50319 Mdot
.513 .35585 Mdot
.56938 .76096 Mdot
.67299 .36689 Mdot
.51178 .8362 Mdot
.5039 .39509 Mdot
.61071 .4253 Mdot
.45641 .37884 Mdot
.4945 .3631 Mdot
.43565 .37524 Mdot
.21811 .45723 Mdot
.6281 .57529 Mdot
.6371 .61941 Mdot
.69093 .50494 Mdot
.67299 .36328 Mdot
.68446 .48401 Mdot
.42012 .65761 Mdot
.79684 .589 Mdot
.61667 .70316 Mdot
.33835 .50454 Mdot
.49001 .41994 Mdot
.66424 .5686 Mdot
.48719 .39242 Mdot
.46048 .3491 Mdot
.66237 .597 Mdot
.60956 .57087 Mdot
.58583 .5603 Mdot
.67736 .4563 Mdot
.34742 .52462 Mdot
.43869 .43003 Mdot
.71727 .46732 Mdot
.48416 .42566 Mdot
.60309 .46904 Mdot
.3463 .5204 Mdot
.30251 .55085 Mdot
.28591 .54207 Mdot
.48967 .34796 Mdot
.45718 .34383 Mdot
.46705 .63464 Mdot
.35212 .50693 Mdot
.42277 .64899 Mdot
.65712 .5683 Mdot
.64098 .54796 Mdot
.49977 .38214 Mdot
.48802 .2787 Mdot
.67636 .47293 Mdot
.64546 .59711 Mdot
.64084 .72168 Mdot
.67549 .49576 Mdot
.48005 .3437 Mdot
.66115 .58733 Mdot
.7109 .48789 Mdot
.26642 .36843 Mdot
.4077 .18249 Mdot
.68403 .49815 Mdot
.47203 .37411 Mdot
.21222 .49016 Mdot
.75182 .40353 Mdot
.68732 .43923 Mdot
.4384 .62812 Mdot
.49805 .35144 Mdot
.52119 .24411 Mdot
.72409 .4596 Mdot
.21589 .54515 Mdot
.62977 .60721 Mdot
.43537 .58239 Mdot
.52243 .41743 Mdot
.31757 .32918 Mdot
.70262 .44011 Mdot
.33209 .53733 Mdot
.28962 .50522 Mdot
.46309 .38919 Mdot
.73116 .48015 Mdot
.41335 .64648 Mdot
.63538 .61165 Mdot
.59458 .58544 Mdot
.31873 .55387 Mdot
.32386 .70136 Mdot
.61766 .61724 Mdot
.50477 .29183 Mdot
.68723 .67966 Mdot
.41064 .46883 Mdot
.27285 .49344 Mdot
.43258 .74395 Mdot
.5162 .3735 Mdot
.67963 .49232 Mdot
.45947 .67232 Mdot
.46688 .64751 Mdot
.43734 .65924 Mdot
.6133 .55736 Mdot
.50737 .53149 Mdot
.64122 .56598 Mdot
.47611 .78412 Mdot
.70797 .47673 Mdot
.69466 .34796 Mdot
.50112 .40975 Mdot
.44182 .39964 Mdot
.5088 .41624 Mdot
.45459 .4246 Mdot
.45366 .38318 Mdot
.44081 .66748 Mdot
.60234 .57179 Mdot
.76505 .55582 Mdot
.3242 .51404 Mdot
.57327 .60966 Mdot
.6433 .57703 Mdot
.61311 .70892 Mdot
.69712 .46139 Mdot
.5754 .44208 Mdot
.64516 .63389 Mdot
.64685 .58248 Mdot
.45184 .4426 Mdot
.29732 .52878 Mdot
.55501 .38457 Mdot
.46012 .37011 Mdot
.6485 .59631 Mdot
.68034 .61267 Mdot
.39957 .25842 Mdot
.49928 .30758 Mdot
.66608 .49881 Mdot
.57597 .49071 Mdot
.677 .45094 Mdot
.53275 .36708 Mdot
.44188 .81711 Mdot
.62095 .58039 Mdot
.63422 .59725 Mdot
.70407 .49472 Mdot
.44128 .29 Mdot
.31868 .54979 Mdot
.63916 .71755 Mdot
.44483 .62257 Mdot
.46714 .35927 Mdot
.62909 .55086 Mdot
.40201 .3196 Mdot
.74626 .62308 Mdot
.4331 .65481 Mdot
.63187 .62963 Mdot
.48119 .3395 Mdot
.47218 .37609 Mdot
.69032 .45336 Mdot
.39914 .49324 Mdot
.44692 .4518 Mdot
.75125 .30905 Mdot
.36797 .74497 Mdot
.31436 .72123 Mdot
.47849 .39754 Mdot
.31912 .55553 Mdot
.62086 .72578 Mdot
.70864 .4553 Mdot
.45795 .43564 Mdot
.41829 .18002 Mdot
.27847 .53342 Mdot
.44171 .64255 Mdot
.62578 .72967 Mdot
.50718 .52953 Mdot
.49753 .34953 Mdot
.50362 .38201 Mdot
.48477 .36579 Mdot
.36309 .18669 Mdot
.62183 .61688 Mdot
.35271 .55783 Mdot
.6902 .47331 Mdot
.35083 .55703 Mdot
.63162 .61679 Mdot
.2767 .65671 Mdot
.45761 .33846 Mdot
.31178 .56804 Mdot
.32858 .53747 Mdot
.41539 .64541 Mdot
.42907 .68032 Mdot
.58163 .56477 Mdot
.49199 .41233 Mdot
.6219 .72966 Mdot
.2988 .5522 Mdot
.60157 .58523 Mdot
.70013 .45421 Mdot
.47265 .64016 Mdot
.48024 .38031 Mdot
.61904 .58836 Mdot
.44637 .31838 Mdot
.30383 .52838 Mdot
.64614 .58209 Mdot
.62968 .73706 Mdot
.68092 .48699 Mdot
.48945 .37887 Mdot
.66066 .48063 Mdot
.63672 .72719 Mdot
.43985 .39277 Mdot
.56901 .40551 Mdot
.67727 .43359 Mdot
.48176 .76621 Mdot
.63454 .56169 Mdot
.6332 .71207 Mdot
.30511 .55707 Mdot
.26816 .59188 Mdot
.63624 .60143 Mdot
.57268 .43032 Mdot
.40373 .52642 Mdot
.43566 .42849 Mdot
.32011 .5258 Mdot
.67195 .65232 Mdot
.70439 .26124 Mdot
.72652 .35051 Mdot
.44891 .40641 Mdot
.63712 .55613 Mdot
.71513 .48365 Mdot
.42679 .63527 Mdot
.57088 .76243 Mdot
.37265 .38575 Mdot
.65754 .61866 Mdot
.43845 .37472 Mdot
.29795 .54997 Mdot
.46016 .64375 Mdot
.34524 .63726 Mdot
.61656 .62464 Mdot
.61652 .57321 Mdot
.4711 .33845 Mdot
.70113 .48274 Mdot
.65602 .27893 Mdot
.64308 .6189 Mdot
.62848 .5519 Mdot
.65286 .7051 Mdot
.7071 .49551 Mdot
.46453 .38034 Mdot
.26055 .54844 Mdot
.42018 .40844 Mdot
.77658 .36636 Mdot
.62783 .69798 Mdot
.32283 .51304 Mdot
.50168 .37373 Mdot
.71492 .65266 Mdot
.64651 .60286 Mdot
.5624 .50245 Mdot
.67475 .57933 Mdot
.44402 .66921 Mdot
.63119 .5505 Mdot
.49576 .39244 Mdot
.45717 .60211 Mdot
.67683 .47439 Mdot
.47454 .4194 Mdot
.45488 .34468 Mdot
.33954 .565 Mdot
.44226 .63567 Mdot
.2153 .37697 Mdot
.47389 .66612 Mdot
.44385 .67732 Mdot
.30814 .49459 Mdot
.46134 .39545 Mdot
.64146 .59343 Mdot
.66596 .60442 Mdot
.45577 .43411 Mdot
.39275 .7912 Mdot
.31656 .55095 Mdot
.57711 .57106 Mdot
.31198 .22702 Mdot
.53395 .33269 Mdot
.63608 .73384 Mdot
.39973 .4842 Mdot
.41816 .66101 Mdot
.47659 .3772 Mdot
.30572 .50783 Mdot
.61861 .55654 Mdot
.61647 .61615 Mdot
.47811 .42966 Mdot
.45509 .6423 Mdot
.71838 .4552 Mdot
.61262 .57568 Mdot
.73243 .64444 Mdot
.48224 .36046 Mdot
.50567 .78816 Mdot
.61938 .56649 Mdot
.78942 .35398 Mdot
.7596 .58156 Mdot
.31973 .52279 Mdot
.4573 .34946 Mdot
.3532 .54616 Mdot
.68632 .47094 Mdot
.63374 .64652 Mdot
.45188 .64084 Mdot
.48325 .30192 Mdot
.16962 .50438 Mdot
.63248 .57309 Mdot
.34431 .51005 Mdot
.47105 .33685 Mdot
.51822 .31035 Mdot
.49266 .40148 Mdot
.27167 .57992 Mdot
.66724 .52249 Mdot
.42893 .62121 Mdot
.43264 .62557 Mdot
.43557 .39196 Mdot
.6989 .44866 Mdot
.65832 .60704 Mdot
.63546 .61023 Mdot
.76943 .74344 Mdot
.63122 .73771 Mdot
.63441 .3546 Mdot
.49307 .37676 Mdot
.59909 .59269 Mdot
.20427 .49259 Mdot
.4294 .64043 Mdot
.45562 .42596 Mdot
.59634 .59875 Mdot
.51593 .67268 Mdot
.59923 .47153 Mdot
.45805 .38323 Mdot
.54059 .40635 Mdot
.44156 .6231 Mdot
.65555 .42126 Mdot
.6456 .56779 Mdot
.4498 .42649 Mdot
.47855 .65856 Mdot
.69203 .69244 Mdot
.1979 .55246 Mdot
.34708 .52422 Mdot
.67382 .58886 Mdot
.44032 .66773 Mdot
.45833 .45311 Mdot
.70454 .48797 Mdot
.65487 .56145 Mdot
.62042 .60752 Mdot
.43595 .3648 Mdot
.43946 .44198 Mdot
.53295 .33079 Mdot
.33378 .50892 Mdot
.45834 .61985 Mdot
.46697 .4228 Mdot
.32942 .70615 Mdot
.43425 .4072 Mdot
.46213 .62533 Mdot
.74623 .21685 Mdot
.41907 .38897 Mdot
.49039 .40261 Mdot
.67804 .29682 Mdot
.35434 .53709 Mdot
.34939 .5568 Mdot
.37289 .75496 Mdot
.49273 .377 Mdot
.7806 .56187 Mdot
.34842 .5289 Mdot
.31254 .54866 Mdot
.72725 .53563 Mdot
.42678 .3825 Mdot
.67034 .4195 Mdot
.4643 .64241 Mdot
.46916 .65605 Mdot
.30338 .54915 Mdot
.44775 .45276 Mdot
.43857 .6737 Mdot
.35273 .30548 Mdot
.64273 .57306 Mdot
.44641 .81927 Mdot
.30402 .52231 Mdot
.43467 .51485 Mdot
.42905 .64706 Mdot
.62773 .18731 Mdot
.50067 .58739 Mdot
.43089 .39963 Mdot
.48637 .37479 Mdot
.6795 .48162 Mdot
.41638 .35229 Mdot
.63105 .69683 Mdot
.44762 .66322 Mdot
.61461 .24297 Mdot
.34089 .51879 Mdot
.49101 .41006 Mdot
.57821 .43591 Mdot
.35394 .65516 Mdot
.55962 .78108 Mdot
.32831 .54535 Mdot
.32658 .52457 Mdot
.62978 .56788 Mdot
.61305 .58784 Mdot
.45792 .39097 Mdot
.46516 .65458 Mdot
.35599 .50798 Mdot
.4505 .6198 Mdot
.61936 .58164 Mdot
.64414 .58608 Mdot
.61741 .6981 Mdot
.46662 .32184 Mdot
.65773 .60375 Mdot
.72126 .66698 Mdot
.31722 .69939 Mdot
.36556 .55132 Mdot
.16401 .43726 Mdot
.34532 .63549 Mdot
.59324 .2744 Mdot
.67901 .45136 Mdot
.62115 .67914 Mdot
.44472 .6069 Mdot
.43945 .38166 Mdot
.48498 .3866 Mdot
.62294 .71306 Mdot
.43824 .60099 Mdot
.69264 .4586 Mdot
.44775 .60175 Mdot
.71056 .47716 Mdot
.62942 .54681 Mdot
.5135 .35879 Mdot
.50677 .36196 Mdot
.43978 .66611 Mdot
.65415 .58556 Mdot
.64548 .61206 Mdot
.67297 .46047 Mdot
.59341 .44063 Mdot
.62094 .59592 Mdot
.3036 .52401 Mdot
.34932 .40094 Mdot
.62552 .72364 Mdot
.50036 .39091 Mdot
.59183 .41004 Mdot
.31836 .30128 Mdot
.43536 .42434 Mdot
.62925 .73109 Mdot
.68633 .79115 Mdot
.49837 .41025 Mdot
.61834 .82749 Mdot
.63395 .71449 Mdot
.35511 .53728 Mdot
.6322 .55778 Mdot
.62867 .69366 Mdot
.51653 .42622 Mdot
.67448 .44869 Mdot
.48897 .43096 Mdot
.35205 .53821 Mdot
.28913 .54941 Mdot
.29368 .71566 Mdot
.77722 .36961 Mdot
.67164 .47212 Mdot
.70529 .46363 Mdot
.63442 .60208 Mdot
.83585 .53506 Mdot
.49538 .43511 Mdot
.70264 .45915 Mdot
.6061 .24802 Mdot
.44381 .37242 Mdot
.63018 .3747 Mdot
.47961 .57158 Mdot
.31774 .55476 Mdot
.26024 .51981 Mdot
.64108 .60431 Mdot
.34566 .51188 Mdot
.29225 .68731 Mdot
.50709 .41747 Mdot
.34447 .51873 Mdot
.46096 .62594 Mdot
.49871 .72106 Mdot
.34622 .55143 Mdot
.60364 .4523 Mdot
.46382 .6475 Mdot
.68882 .589 Mdot
.65283 .29088 Mdot
.12664 .45023 Mdot
.4507 .66379 Mdot
.65879 .58004 Mdot
.66615 .58791 Mdot
.63353 .6079 Mdot
.35498 .5297 Mdot
.60485 .60404 Mdot
.32376 .5081 Mdot
.7678 .4161 Mdot
.59177 .43157 Mdot
.71093 .46569 Mdot
.49045 .68224 Mdot
.32626 .5315 Mdot
.43172 .78245 Mdot
.15079 .47745 Mdot
.47526 .37211 Mdot
.47602 .66286 Mdot
.70155 .49526 Mdot
.84628 .43346 Mdot
.6792 .47854 Mdot
.65006 .56442 Mdot
.45619 .82318 Mdot
.48313 .41001 Mdot
.43551 .24765 Mdot
.67654 .4832 Mdot
.33622 .54538 Mdot
.44012 .39543 Mdot
.65463 .53867 Mdot
.69796 .48721 Mdot
.71135 .44931 Mdot
.44853 .39029 Mdot
.33721 .55466 Mdot
.64388 .59006 Mdot
.45368 .60969 Mdot
.69912 .43299 Mdot
.459 .45645 Mdot
.42612 .42118 Mdot
.51852 .38857 Mdot
.53533 .52295 Mdot
.54455 .23663 Mdot
.45156 .66086 Mdot
.72304 .37751 Mdot
.61357 .59388 Mdot
.69737 .61558 Mdot
.38899 .74777 Mdot
.46598 .69616 Mdot
.62946 .69942 Mdot
.62261 .69631 Mdot
.45533 .38536 Mdot
.55146 .23629 Mdot
.58233 .80424 Mdot
.49765 .68304 Mdot
.62322 .72343 Mdot
.63889 .61225 Mdot
.28626 .50891 Mdot
.26164 .68453 Mdot
.4185 .41312 Mdot
.41554 .65965 Mdot
.61849 .59462 Mdot
.51255 .20575 Mdot
.70253 .47728 Mdot
.43327 .80617 Mdot
.46465 .3391 Mdot
.45804 .41675 Mdot
.45128 .65461 Mdot
.46743 .63721 Mdot
.54957 .76941 Mdot
.324 .73263 Mdot
.63396 .47456 Mdot
.33127 .60351 Mdot
.48665 .21229 Mdot
.31561 .48548 Mdot
.29804 .51371 Mdot
.61806 .73385 Mdot
.47521 .65524 Mdot
.50546 .3814 Mdot
.34553 .50503 Mdot
.55896 .78248 Mdot
.31121 .58143 Mdot
.63917 .37281 Mdot
.76748 .59157 Mdot
.47049 .34668 Mdot
.29637 .53528 Mdot
.347 .51538 Mdot
.36916 .52924 Mdot
.63154 .72969 Mdot
.4746 .39933 Mdot
.42489 .37001 Mdot
.4524 .41965 Mdot
.48596 .45426 Mdot
.47892 .36008 Mdot
.37389 .72833 Mdot
.55194 .57284 Mdot
.62648 .24276 Mdot
.43155 .41808 Mdot
.46524 .66235 Mdot
.51112 .40819 Mdot
.70303 .44888 Mdot
.43695 .37703 Mdot
.63329 .3638 Mdot
.43815 .64982 Mdot
.448 .2899 Mdot
.32236 .60397 Mdot
.45985 .33917 Mdot
.72355 .46938 Mdot
.56652 .24626 Mdot
.20549 .39389 Mdot
.57965 .62364 Mdot
.30289 .52592 Mdot
.63863 .63457 Mdot
.41936 .62353 Mdot
.63933 .59258 Mdot
.43325 .41356 Mdot
.62199 .73238 Mdot
.4075 .71262 Mdot
.43665 .51709 Mdot
.50569 .37137 Mdot
.39251 .38911 Mdot
.30478 .54023 Mdot
.6605 .58521 Mdot
.3805 .501 Mdot
.49177 .36728 Mdot
.69041 .4768 Mdot
.70414 .4844 Mdot
.33052 .72425 Mdot
.53672 .18665 Mdot
.25039 .5837 Mdot
.45144 .65638 Mdot
.63215 .62411 Mdot
.70806 .44212 Mdot
.37696 .38564 Mdot
.41731 .66756 Mdot
.41689 .65643 Mdot
.44935 .63503 Mdot
.46951 .35307 Mdot
.62933 .69686 Mdot
.57375 .22489 Mdot
.63439 .70018 Mdot
.45528 .34092 Mdot
.61949 .61118 Mdot
.62331 .69043 Mdot
.68549 .48806 Mdot
.42043 .64957 Mdot
.61835 .57912 Mdot
.47041 .36221 Mdot
.34387 .53041 Mdot
.59082 .44613 Mdot
.58599 .31575 Mdot
.73614 .33008 Mdot
.72996 .31918 Mdot
.28499 .52629 Mdot
.60444 .19023 Mdot
.48217 .66043 Mdot
.29525 .3242 Mdot
.75082 .45875 Mdot
.46046 .43263 Mdot
.32221 .76642 Mdot
.6464 .56707 Mdot
.66288 .59242 Mdot
.46175 .37836 Mdot
.60721 .57185 Mdot
.49216 .40689 Mdot
.61528 .57827 Mdot
.58073 .62271 Mdot
.41575 .40881 Mdot
.65946 .598 Mdot
.52913 .40311 Mdot
.43044 .36004 Mdot
.31039 .55368 Mdot
.64506 .55498 Mdot
.43461 .41042 Mdot
.85204 .5067 Mdot
.47071 .63891 Mdot
.63118 .72891 Mdot
.60968 .50566 Mdot
.4362 .66788 Mdot
.33157 .51677 Mdot
.41622 .3744 Mdot
.67955 .46079 Mdot
.33486 .53511 Mdot
.57985 .56767 Mdot
.68048 .48927 Mdot
.38811 .7764 Mdot
.30102 .53125 Mdot
.62548 .72108 Mdot
.67579 .475 Mdot
.3954 .37422 Mdot
.65433 .55636 Mdot
.5552 .29674 Mdot
.6376 .71051 Mdot
.48585 .39739 Mdot
.59464 .57711 Mdot
.4742 .64413 Mdot
.45651 .4077 Mdot
.6276 .55541 Mdot
.63327 .72992 Mdot
.46196 .35756 Mdot
.44456 .3815 Mdot
.23123 .63716 Mdot
.53342 .80421 Mdot
.69346 .45345 Mdot
.31309 .56434 Mdot
.47047 .37136 Mdot
.67919 .45372 Mdot
.75356 .66362 Mdot
.5173 .37519 Mdot
.3584 .53585 Mdot
.54835 .43537 Mdot
.61157 .59414 Mdot
.4224 .64979 Mdot
.67284 .59033 Mdot
.70183 .4455 Mdot
.36104 .83046 Mdot
.61922 .69373 Mdot
.5354 .38179 Mdot
.48343 .42487 Mdot
.65675 .65319 Mdot
.34346 .5121 Mdot
.63192 .46568 Mdot
.48913 .37853 Mdot
.41944 .46088 Mdot
.47377 .41745 Mdot
.76412 .56944 Mdot
.31672 .54998 Mdot
.49036 .39954 Mdot
.50708 .2896 Mdot
.50259 .3411 Mdot
.72275 .46102 Mdot
.69066 .32948 Mdot
.51497 .39162 Mdot
.51814 .09882 Mdot
.63889 .72624 Mdot
.65898 .60164 Mdot
.67087 .54293 Mdot
.81174 .63797 Mdot
.22804 .56774 Mdot
.32809 .50757 Mdot
.46235 .48601 Mdot
.64177 .59144 Mdot
.20906 .52772 Mdot
.63944 .20469 Mdot
.433 .35634 Mdot
.49162 .3468 Mdot
.65006 .56441 Mdot
.60149 .58383 Mdot
.61588 .72789 Mdot
.429 .40919 Mdot
.41854 .32422 Mdot
.63023 .6281 Mdot
.47948 .35327 Mdot
.55733 .40274 Mdot
.45305 .61113 Mdot
.31972 .559 Mdot
.42553 .63697 Mdot
.41704 .63573 Mdot
.32243 .36685 Mdot
.36633 .74315 Mdot
.46348 .62631 Mdot
.46824 .60699 Mdot
.62507 .36464 Mdot
.54055 .45528 Mdot
.71292 .44741 Mdot
.63375 .2262 Mdot
.62976 .60239 Mdot
.47272 .39972 Mdot
.29228 .51574 Mdot
.31126 .34349 Mdot
.54894 .64688 Mdot
.49432 .82992 Mdot
.49676 .36832 Mdot
.64272 .60676 Mdot
.63587 .7254 Mdot
.41788 .41514 Mdot
.70098 .58539 Mdot
.45228 .4131 Mdot
.66387 .56807 Mdot
.35828 .41282 Mdot
.56641 .37334 Mdot
.66192 .67158 Mdot
.3638 .50597 Mdot
.48906 .41808 Mdot
.31048 .51558 Mdot
.42942 .65256 Mdot
.69018 .44891 Mdot
.68994 .45519 Mdot
.44205 .39078 Mdot
.37876 .42308 Mdot
.4693 .56649 Mdot
.43457 .3525 Mdot
.43251 .37047 Mdot
.63366 .71263 Mdot
.43148 .37178 Mdot
.47944 .42611 Mdot
.45374 .42293 Mdot
.50769 .33929 Mdot
.44646 .67692 Mdot
.56937 .38123 Mdot
.4828 .32069 Mdot
.53039 .33501 Mdot
.46424 .6188 Mdot
.4253 .48647 Mdot
.4199 .63254 Mdot
.52923 .17223 Mdot
.43115 .62355 Mdot
.69863 .45524 Mdot
.5906 .59728 Mdot
.43283 .47393 Mdot
.35446 .50503 Mdot
.4331 .67891 Mdot
.69491 .46785 Mdot
.44192 .66205 Mdot
.61914 .6158 Mdot
.23852 .31387 Mdot
.31338 .58196 Mdot
.6197 .44832 Mdot
.49059 .59916 Mdot
.51231 .7869 Mdot
.63549 .56944 Mdot
.31301 .55171 Mdot
.41203 .24734 Mdot
.44159 .41439 Mdot
.67795 .48154 Mdot
.45291 .38869 Mdot
.4388 .67738 Mdot
.63813 .60731 Mdot
.74651 .36396 Mdot
.68522 .45617 Mdot
.18888 .57767 Mdot
.63169 .6114 Mdot
.42262 .36764 Mdot
.41776 .66315 Mdot
.16185 .44267 Mdot
.42628 .62733 Mdot
.59184 .42749 Mdot
.34211 .57015 Mdot
.24441 .51938 Mdot
.32068 .52912 Mdot
.58209 .77325 Mdot
.37691 .1689 Mdot
.72123 .28711 Mdot
.34399 .53808 Mdot
.67325 .68027 Mdot
.4796 .34574 Mdot
.51617 .39775 Mdot
.51374 .30085 Mdot
.35081 .56124 Mdot
.47473 .36684 Mdot
.63647 .71374 Mdot
.29176 .66962 Mdot
.71137 .61086 Mdot
.64148 .63291 Mdot
.4967 .39716 Mdot
.46346 .61903 Mdot
.44677 .60087 Mdot
.62657 .69145 Mdot
.42369 .62217 Mdot
.42446 .37854 Mdot
.32383 .53092 Mdot
.41765 .52556 Mdot
.68276 .47624 Mdot
.82332 .44347 Mdot
.73022 .47136 Mdot
.66872 .55014 Mdot
.40729 .35536 Mdot
.64476 .58549 Mdot
.50517 .88253 Mdot
.43425 .40206 Mdot
.35005 .52779 Mdot
.45171 .37317 Mdot
.47678 .42212 Mdot
.51692 .39775 Mdot
.61508 .62201 Mdot
.65908 .50896 Mdot
.47692 .35471 Mdot
.45083 .6398 Mdot
.67893 .27091 Mdot
.50158 .42289 Mdot
.60083 .64339 Mdot
.6655 .35224 Mdot
.46889 .78333 Mdot
.37403 .53419 Mdot
.65925 .58582 Mdot
.3368 .5205 Mdot
.34088 .49466 Mdot
.33163 .51662 Mdot
.57711 .22085 Mdot
.39401 .27365 Mdot
.68586 .78659 Mdot
.26958 .48661 Mdot
.2865 .35785 Mdot
.29871 .56011 Mdot
.73763 .69943 Mdot
.31243 .50317 Mdot
.33189 .51067 Mdot
.89508 .45187 Mdot
.31717 .50028 Mdot
.49766 .3841 Mdot
.43859 .43915 Mdot
.34407 .67253 Mdot
.61728 .37767 Mdot
.43215 .38389 Mdot
.46648 .37436 Mdot
.68231 .45274 Mdot
.41951 .27843 Mdot
.61251 .72682 Mdot
.38192 .77684 Mdot
.36966 .63881 Mdot
.44974 .3887 Mdot
.469 .36929 Mdot
.42465 .44204 Mdot
.32352 .18543 Mdot
.33282 .33275 Mdot
.28524 .54807 Mdot
.39211 .41114 Mdot
.79907 .38575 Mdot
.43417 .34673 Mdot
.50676 .35945 Mdot
.46365 .35055 Mdot
.6417 .5928 Mdot
.2788 .52217 Mdot
.39261 .41168 Mdot
.44412 .76509 Mdot
.47344 .34025 Mdot
.48028 .68586 Mdot
.66414 .4444 Mdot
.4954 .39148 Mdot
.36537 .54194 Mdot
.44579 .36456 Mdot
.30009 .52652 Mdot
.30673 .55385 Mdot
.42215 .44101 Mdot
.55714 .21008 Mdot
.35983 .54117 Mdot
.4576 .34236 Mdot
.65366 .59004 Mdot
.71612 .27452 Mdot
.48785 .39537 Mdot
.71371 .46075 Mdot
.48812 .37618 Mdot
.72238 .47251 Mdot
.43593 .35769 Mdot
.637 .70572 Mdot
.31149 .28854 Mdot
.63292 .59737 Mdot
.73268 .41783 Mdot
.60035 .60264 Mdot
.23362 .63991 Mdot
.35736 .53102 Mdot
.62287 .73979 Mdot
.45631 .83797 Mdot
.63274 .71599 Mdot
.58114 .4518 Mdot
.57077 .62012 Mdot
.46292 .66025 Mdot
.34563 .55948 Mdot
.71447 .3867 Mdot
.64528 .67893 Mdot
.62716 .53277 Mdot
.61394 .63126 Mdot
.3631 .81884 Mdot
.40422 .81903 Mdot
.47018 .35812 Mdot
.45934 .2365 Mdot
.24744 .44824 Mdot
.51477 .36872 Mdot
.42308 .35408 Mdot
.6547 .55429 Mdot
.49927 .41174 Mdot
.51998 .51654 Mdot
.62958 .57659 Mdot
.70011 .46662 Mdot
.32119 .51241 Mdot
.72019 .47616 Mdot
.63236 .54071 Mdot
.55889 .55844 Mdot
.61558 .58607 Mdot
.51423 .34663 Mdot
.45597 .37252 Mdot
.29839 .54487 Mdot
.38912 .51906 Mdot
.31478 .55772 Mdot
.69334 .49798 Mdot
.62596 .58479 Mdot
.32651 .32633 Mdot
.47222 .38107 Mdot
.32575 .53795 Mdot
.39509 .62106 Mdot
.47295 .37594 Mdot
.43425 .66203 Mdot
.48343 .34342 Mdot
.34622 .53955 Mdot
.43143 .37133 Mdot
.32485 .52929 Mdot
.6518 .57395 Mdot
.444 .33877 Mdot
.4614 .38096 Mdot
.16819 .47067 Mdot
.69039 .45939 Mdot
.35707 .53244 Mdot
.51263 .5637 Mdot
.42137 .37748 Mdot
.68042 .62686 Mdot
.50364 .39437 Mdot
.50146 .47359 Mdot
.53304 .39097 Mdot
.63507 .71863 Mdot
.45647 .31602 Mdot
.488 .39626 Mdot
.52008 .28745 Mdot
.27422 .46563 Mdot
.38087 .4993 Mdot
.43073 .67409 Mdot
.36238 .54613 Mdot
.64118 .54852 Mdot
.61036 .56253 Mdot
.60775 .58249 Mdot
.61282 .39756 Mdot
.42835 .4422 Mdot
.48249 .40884 Mdot
.44017 .68345 Mdot
.70678 .46706 Mdot
.32931 .54377 Mdot
.70833 .47149 Mdot
.37206 .76559 Mdot
.69189 .49706 Mdot
.62875 .6946 Mdot
.75836 .58492 Mdot
.34024 .29093 Mdot
.6803 .45503 Mdot
.31675 .55832 Mdot
.7603 .60118 Mdot
.45773 .43148 Mdot
.57812 .55957 Mdot
.6917 .47824 Mdot
.32731 .80476 Mdot
.50797 .38618 Mdot
.57403 .48237 Mdot
.44102 .61274 Mdot
.6994 .49007 Mdot
.43837 .63634 Mdot
.43496 .38708 Mdot
.49216 .76818 Mdot
.34417 .50895 Mdot
.47808 .63492 Mdot
.48325 .31903 Mdot
.71272 .485 Mdot
.61964 .60024 Mdot
.50294 .62246 Mdot
.46467 .66244 Mdot
.30585 .27359 Mdot
.72769 .35231 Mdot
.62688 .58252 Mdot
.60816 .78588 Mdot
.44649 .62987 Mdot
.51564 .37291 Mdot
.44333 .46877 Mdot
.42673 .39317 Mdot
.6105 .55895 Mdot
.66051 .5888 Mdot
.31596 .67737 Mdot
.45499 .37026 Mdot
.50628 .38978 Mdot
.28691 .56293 Mdot
.63724 .574 Mdot
.30995 .53354 Mdot
.3704 .52798 Mdot
.65731 .5765 Mdot
.31769 .52451 Mdot
.6791 .48601 Mdot
.27457 .6395 Mdot
.44729 .62919 Mdot
.44794 .64219 Mdot
.63802 .61173 Mdot
.65006 .61688 Mdot
.64483 .58317 Mdot
.48309 .34328 Mdot
.32537 .54848 Mdot
.45177 .3517 Mdot
.51824 .37242 Mdot
.37736 .52986 Mdot
.31945 .4982 Mdot
.45292 .35815 Mdot
.66984 .65313 Mdot
.68486 .43472 Mdot
.65662 .60077 Mdot
.45065 .61866 Mdot
.21324 .52269 Mdot
.43725 .68618 Mdot
.49775 .39804 Mdot
.52515 .65855 Mdot
.34329 .54413 Mdot
.67993 .48139 Mdot
.68163 .43158 Mdot
.67824 .46997 Mdot
.40791 .65777 Mdot
.36379 .51701 Mdot
.38775 .77501 Mdot
.49387 .40311 Mdot
.53215 .52391 Mdot
.71822 .38025 Mdot
.39814 .75516 Mdot
.46069 .62342 Mdot
.47042 .37378 Mdot
.63113 .71868 Mdot
.388 .26108 Mdot
.45674 .41455 Mdot
.44353 .42121 Mdot
.76213 .51782 Mdot
.53023 .33414 Mdot
.35159 .56235 Mdot
.29966 .72206 Mdot
.45052 .44065 Mdot
.27493 .5737 Mdot
.8249 .65958 Mdot
.49866 .40306 Mdot
.48747 .36352 Mdot
.47869 .39112 Mdot
.44535 .37322 Mdot
.35366 .56439 Mdot
.65516 .41284 Mdot
.41928 .66572 Mdot
.54629 .53306 Mdot
.45476 .63093 Mdot
.6606 .56507 Mdot
.56511 .48612 Mdot
.33695 .56039 Mdot
.67807 .4785 Mdot
.36104 .23991 Mdot
.34592 .75119 Mdot
.63151 .5677 Mdot
.35072 .34103 Mdot
.6852 .47487 Mdot
.45696 .43347 Mdot
.70359 .50188 Mdot
.59989 .58836 Mdot
.45944 .64173 Mdot
.43569 .43687 Mdot
.28938 .52699 Mdot
.3476 .5506 Mdot
.47519 .37067 Mdot
.77512 .35529 Mdot
.43004 .65986 Mdot
.4201 .68973 Mdot
.47039 .35092 Mdot
.44239 .42065 Mdot
.30933 .52676 Mdot
.65222 .59961 Mdot
.6969 .70652 Mdot
.69372 .46206 Mdot
.45697 .32873 Mdot
.44203 .37366 Mdot
.35477 .74448 Mdot
.42011 .65625 Mdot
.61559 .72003 Mdot
.46636 .35601 Mdot
.35971 .73667 Mdot
.46439 .35719 Mdot
.41193 .36223 Mdot
.64865 .58847 Mdot
.52086 .40825 Mdot
.49635 .35415 Mdot
.38618 .39209 Mdot
.44155 .63122 Mdot
.34761 .52052 Mdot
.30808 .57422 Mdot
.62408 .7301 Mdot
.43487 .66141 Mdot
.45035 .3608 Mdot
.42474 .66142 Mdot
.5163 .39385 Mdot
.47699 .35719 Mdot
.46086 .6241 Mdot
.31016 .53295 Mdot
.38851 .66741 Mdot
.57807 .42489 Mdot
.44867 .3718 Mdot
.42829 .42527 Mdot
.61829 .39159 Mdot
.54629 .84559 Mdot
.49929 .37197 Mdot
.3478 .54321 Mdot
.46814 .37982 Mdot
.43431 .64306 Mdot
.69645 .49571 Mdot
.34533 .53421 Mdot
.64337 .61613 Mdot
.65035 .56954 Mdot
.31507 .60349 Mdot
.62387 .69221 Mdot
.42295 .41633 Mdot
.36682 .47411 Mdot
.29808 .50784 Mdot
.85097 .55301 Mdot
.66574 .58779 Mdot
.7238 .46041 Mdot
.44183 .38382 Mdot
.50971 .61616 Mdot
.43481 .68274 Mdot
.51378 .09695 Mdot
.39225 .77428 Mdot
.72226 .49812 Mdot
.48407 .83223 Mdot
.62662 .71675 Mdot
.50502 .36374 Mdot
.69456 .4478 Mdot
.63161 .5621 Mdot
.49891 .41762 Mdot
.54269 .39803 Mdot
.62726 .47102 Mdot
.65717 .6362 Mdot
.42286 .65659 Mdot
.60915 .58998 Mdot
.67297 .4966 Mdot
.62975 .69547 Mdot
.34163 .55683 Mdot
.48659 .40016 Mdot
.41187 .4369 Mdot
.64977 .60856 Mdot
.63736 .70577 Mdot
.46981 .34619 Mdot
.35145 .55008 Mdot
.60839 .57285 Mdot
.44637 .39297 Mdot
.29553 .33063 Mdot
.35235 .49701 Mdot
.62337 .59363 Mdot
.48111 .42475 Mdot
.50769 .46587 Mdot
.6397 .61466 Mdot
.65407 .60791 Mdot
.47421 .36693 Mdot
.67628 .47981 Mdot
.48405 .33999 Mdot
.43481 .61881 Mdot
.6581 .50706 Mdot
.43677 .64352 Mdot
.75668 .444 Mdot
.41639 .34047 Mdot
.52753 .78742 Mdot
.30093 .55491 Mdot
.66713 .48853 Mdot
.19426 .44019 Mdot
.44056 .42226 Mdot
.58631 .19285 Mdot
.44499 .51469 Mdot
.83528 .43297 Mdot
.3696 .19495 Mdot
.69609 .47794 Mdot
.43775 .65995 Mdot
.48692 .3641 Mdot
.46987 .67583 Mdot
.69449 .45055 Mdot
.73261 .3833 Mdot
.47503 .42642 Mdot
.31401 .54881 Mdot
.47329 .34128 Mdot
.30286 .5252 Mdot
.47527 .37621 Mdot
.52302 .32847 Mdot
.71322 .50883 Mdot
.59314 .4251 Mdot
.45654 .43225 Mdot
.23698 .31352 Mdot
.51679 .59454 Mdot
.68887 .4715 Mdot
.45419 .34674 Mdot
.62104 .70627 Mdot
.43332 .60252 Mdot
.53508 .24853 Mdot
.64279 .58908 Mdot
.46261 .62208 Mdot
.31809 .51883 Mdot
.66589 .60115 Mdot
.63497 .73055 Mdot
.42084 .44945 Mdot
.72184 .46521 Mdot
.45881 .66319 Mdot
.49136 .39431 Mdot
.50767 .3852 Mdot
.68798 .66968 Mdot
.55984 .70541 Mdot
.27572 .53644 Mdot
.17885 .53993 Mdot
.36166 .55765 Mdot
.69954 .45868 Mdot
.6478 .58675 Mdot
.50118 .3757 Mdot
.45158 .40608 Mdot
.61819 .55415 Mdot
.35628 .52972 Mdot
.67316 .61346 Mdot
.33568 .35896 Mdot
.64919 .62281 Mdot
.66722 .38367 Mdot
.35046 .53288 Mdot
.66426 .38766 Mdot
.6724 .49664 Mdot
.5266 .1967 Mdot
.60617 .30941 Mdot
.44069 .6122 Mdot
.67156 .3801 Mdot
.33736 .54412 Mdot
.46306 .36568 Mdot
.62401 .71887 Mdot
.61907 .69666 Mdot
.3145 .51685 Mdot
.64916 .5629 Mdot
.70074 .48858 Mdot
.48644 .36056 Mdot
.45553 .79836 Mdot
.3277 .63742 Mdot
.63505 .62429 Mdot
.55273 .379 Mdot
.44361 .63629 Mdot
.49499 .35605 Mdot
.71648 .46583 Mdot
.45978 .65839 Mdot
.64486 .71317 Mdot
.29253 .66356 Mdot
.43886 .39099 Mdot
.31971 .72521 Mdot
.44089 .66548 Mdot
.6154 .78723 Mdot
.45556 .3931 Mdot
.44617 .62993 Mdot
.48133 .30752 Mdot
.43276 .74654 Mdot
.4741 .54275 Mdot
.65343 .21736 Mdot
.64147 .64368 Mdot
.64782 .56533 Mdot
.49934 .73222 Mdot
.73864 .48972 Mdot
.46994 .62884 Mdot
.63075 .69625 Mdot
.64615 .29915 Mdot
.43993 .63464 Mdot
.50228 .35246 Mdot
.50243 .3961 Mdot
.31907 .36186 Mdot
.50001 .53697 Mdot
.63531 .69978 Mdot
.24331 .59068 Mdot
.42428 .39281 Mdot
.52628 .34852 Mdot
.45836 .4051 Mdot
.28861 .54934 Mdot
.43944 .66975 Mdot
.16923 .41655 Mdot
.42723 .65406 Mdot
.46265 .80659 Mdot
.63052 .60303 Mdot
.6442 .62318 Mdot
.49703 .39186 Mdot
.56182 .79045 Mdot
.52443 .23654 Mdot
.42642 .36412 Mdot
.68763 .61392 Mdot
.7202 .34508 Mdot
.51805 .33137 Mdot
.33228 .57362 Mdot
.40592 .41979 Mdot
.34382 .48678 Mdot
.46631 .6461 Mdot
.70052 .48097 Mdot
.69158 .43409 Mdot
.46203 .6593 Mdot
.48032 .4086 Mdot
.68829 .5646 Mdot
.46688 .41791 Mdot
.46755 .35808 Mdot
.42692 .80674 Mdot
.71555 .44637 Mdot
.64529 .57983 Mdot
.68781 .45558 Mdot
.3336 .5104 Mdot
.82529 .29574 Mdot
.71102 .47287 Mdot
.3644 .46779 Mdot
.69394 .41082 Mdot
.67106 .3831 Mdot
.34781 .55245 Mdot
.67474 .49002 Mdot
.42358 .65194 Mdot
.83679 .41732 Mdot
.58782 .82173 Mdot
.44822 .68975 Mdot
.45206 .3969 Mdot
.32399 .56136 Mdot
.28507 .53398 Mdot
.48203 .64861 Mdot
.32386 .55602 Mdot
.41249 .33431 Mdot
.45622 .36623 Mdot
.47016 .62959 Mdot
.33511 .65971 Mdot
.46156 .66608 Mdot
.2689 .64691 Mdot
.46134 .3447 Mdot
.34821 .53206 Mdot
.39817 .40217 Mdot
.30518 .5776 Mdot
.61268 .71889 Mdot
.50015 .41726 Mdot
.69042 .49032 Mdot
.50935 .52731 Mdot
.62515 .59515 Mdot
.52691 .65288 Mdot
.3 .54485 Mdot
.38824 .64401 Mdot
.311 .55422 Mdot
.32701 .56381 Mdot
.41703 .63324 Mdot
.33208 .50526 Mdot
.48778 .36255 Mdot
.6704 .66868 Mdot
.30007 .52043 Mdot
.44664 .65274 Mdot
.69053 .48588 Mdot
.31456 .5275 Mdot
.6642 .56312 Mdot
.45096 .38095 Mdot
.61361 .58489 Mdot
.72644 .4967 Mdot
.34798 .55871 Mdot
.67607 .49026 Mdot
.66159 .59766 Mdot
.7171 .45621 Mdot
.75637 .3808 Mdot
.47345 .65819 Mdot
.50168 .8293 Mdot
.5609 .42918 Mdot
.29 .52493 Mdot
.61445 .53738 Mdot
.49944 .37552 Mdot
.44846 .38068 Mdot
.66948 .48692 Mdot
.28483 .53101 Mdot
.73535 .29751 Mdot
.48099 .47882 Mdot
.28237 .64549 Mdot
.46159 .67232 Mdot
.19785 .5597 Mdot
.32651 .70278 Mdot
.81992 .50266 Mdot
.51515 .42187 Mdot
.62613 .71666 Mdot
.48438 .41393 Mdot
.19458 .41073 Mdot
.70658 .49265 Mdot
.691 .7443 Mdot
.49094 .43742 Mdot
.63769 .58204 Mdot
.46658 .38967 Mdot
.51657 .26571 Mdot
.40436 .41092 Mdot
.67469 .46202 Mdot
.47873 .69464 Mdot
.35459 .50539 Mdot
.6833 .47542 Mdot
.64742 .56938 Mdot
.66969 .32714 Mdot
.494 .42195 Mdot
.4221 .39276 Mdot
.63852 .62924 Mdot
.31552 .55144 Mdot
.65686 .55979 Mdot
.44775 .62937 Mdot
.70633 .47543 Mdot
.44107 .38023 Mdot
.52851 .36687 Mdot
.68612 .59442 Mdot
.43913 .67045 Mdot
.65716 .61391 Mdot
.42467 .6372 Mdot
.62576 .71775 Mdot
.44161 .43441 Mdot
.63012 .62996 Mdot
.5106 .38232 Mdot
.18326 .45529 Mdot
.43614 .81222 Mdot
.29654 .45193 Mdot
.64459 .57681 Mdot
.65469 .36786 Mdot
.43555 .64926 Mdot
.4285 .62728 Mdot
.23847 .52367 Mdot
.56095 .24207 Mdot
.77693 .57133 Mdot
.31978 .25724 Mdot
.44841 .62907 Mdot
.44068 .64447 Mdot
.62714 .56168 Mdot
.32181 .5063 Mdot
.31138 .49128 Mdot
.6693 .60204 Mdot
.59448 .41556 Mdot
.32924 .54363 Mdot
.60025 .197 Mdot
.64779 .54858 Mdot
.51675 .42203 Mdot
.60834 .71392 Mdot
.7037 .4831 Mdot
.59327 .41684 Mdot
.50821 .26596 Mdot
.50406 .3745 Mdot
.27651 .70645 Mdot
.64951 .59808 Mdot
.63839 .43835 Mdot
.52166 .17372 Mdot
.46722 .42667 Mdot
.46846 .39743 Mdot
.47464 .40944 Mdot
.71335 .44343 Mdot
.20095 .42287 Mdot
.50497 .37304 Mdot
.60038 .43181 Mdot
.42843 .34804 Mdot
.57205 .29532 Mdot
.69035 .45472 Mdot
.29061 .58783 Mdot
.64039 .64109 Mdot
.42219 .76079 Mdot
.51548 .30329 Mdot
.43533 .62976 Mdot
.5836 .58755 Mdot
.46074 .63769 Mdot
.53928 .22332 Mdot
.61005 .31245 Mdot
.30109 .56393 Mdot
.49694 .36686 Mdot
.60361 .62026 Mdot
.30529 .55584 Mdot
.65061 .70802 Mdot
.88972 .42201 Mdot
.43495 .67206 Mdot
.54456 .8646 Mdot
.42707 .62834 Mdot
.61471 .70653 Mdot
.31033 .52391 Mdot
.37869 .30248 Mdot
.53093 .52327 Mdot
.31655 .52721 Mdot
.40558 .70818 Mdot
.36003 .56484 Mdot
.66395 .37136 Mdot
.3615 .50718 Mdot
.44242 .65293 Mdot
.41884 .60225 Mdot
.53739 .40126 Mdot
.49554 .37807 Mdot
.56592 .52846 Mdot
.403 .47476 Mdot
.49592 .37483 Mdot
.62981 .5766 Mdot
.5705 .81578 Mdot
.5964 .62514 Mdot
.30192 .51139 Mdot
.42329 .668 Mdot
.4678 .39567 Mdot
.45343 .36537 Mdot
.51346 .38442 Mdot
.16477 .47708 Mdot
.60726 .20237 Mdot
.47497 .35658 Mdot
.46638 .32799 Mdot
.6496 .57385 Mdot
.66305 .49426 Mdot
.26773 .29536 Mdot
.63525 .3012 Mdot
.44494 .41118 Mdot
.68695 .45956 Mdot
.72664 .46193 Mdot
.48139 .43021 Mdot
.46403 .78933 Mdot
.66773 .67953 Mdot
.49108 .39424 Mdot
.58652 .28853 Mdot
.60654 .55478 Mdot
.62747 .69119 Mdot
.64835 .60937 Mdot
.36747 .53859 Mdot
.6307 .70056 Mdot
.60094 .59722 Mdot
.37759 .29553 Mdot
.62485 .73152 Mdot
.40943 .73043 Mdot
.69344 .498 Mdot
.457 .40836 Mdot
.35075 .57027 Mdot
.61229 .55872 Mdot
.46379 .65832 Mdot
.33546 .52786 Mdot
.43824 .59964 Mdot
.70245 .51171 Mdot
.62077 .43221 Mdot
.62084 .69285 Mdot
.44093 .62663 Mdot
.29206 .66414 Mdot
.68764 .45811 Mdot
.42246 .62604 Mdot
.56531 .78632 Mdot
.4908 .43367 Mdot
.4655 .21755 Mdot
.44145 .3441 Mdot
.80127 .38112 Mdot
.42087 .63444 Mdot
.62627 .73567 Mdot
.48534 .40648 Mdot
.63277 .61214 Mdot
.44393 .31185 Mdot
.45 .41214 Mdot
.63295 .62073 Mdot
.46864 .35982 Mdot
.71532 .46101 Mdot
.35763 .49396 Mdot
.41585 .51651 Mdot
.21244 .67737 Mdot
.71941 .46179 Mdot
.64859 .72937 Mdot
.49863 .37073 Mdot
.74245 .36067 Mdot
.31488 .52962 Mdot
.45441 .42586 Mdot
.23532 .53683 Mdot
.3116 .51109 Mdot
.33342 .52175 Mdot
.43782 .36326 Mdot
.43331 .61472 Mdot
.62696 .60628 Mdot
.68492 .4594 Mdot
.83429 .50625 Mdot
.4446 .40002 Mdot
.46463 .38061 Mdot
.68469 .47557 Mdot
.43851 .64378 Mdot
.45113 .36628 Mdot
.53842 .65124 Mdot
.84968 .48529 Mdot
.41461 .64304 Mdot
.50541 .42084 Mdot
.4134 .22047 Mdot
.27775 .56226 Mdot
.54769 .85429 Mdot
.73114 .4276 Mdot
.6579 .58603 Mdot
.51941 .32572 Mdot
.57629 .1232 Mdot
.69978 .48273 Mdot
.40757 .76565 Mdot
.47727 .35089 Mdot
.47583 .38464 Mdot
.33887 .55175 Mdot
.45107 .35535 Mdot
.35159 .51629 Mdot
.24678 .72782 Mdot
.17863 .59547 Mdot
.30547 .546 Mdot
.29931 .51123 Mdot
.2559 .54279 Mdot
.25219 .31729 Mdot
.32173 .51441 Mdot
.5132 .40998 Mdot
.67874 .26131 Mdot
.43237 .45335 Mdot
.66746 .48186 Mdot
.73485 .46688 Mdot
.33863 .59306 Mdot
.6 .74729 Mdot
.42474 .48272 Mdot
.48482 .28987 Mdot
.47076 .5728 Mdot
.4402 .61913 Mdot
.44766 .4174 Mdot
.62325 .69172 Mdot
.60571 .59101 Mdot
.40804 .41154 Mdot
.45929 .41212 Mdot
.30135 .52403 Mdot
.69989 .43736 Mdot
.42555 .6136 Mdot
.46594 .37471 Mdot
.67384 .61659 Mdot
.69814 .464 Mdot
.29836 .51851 Mdot
.24758 .52417 Mdot
.69942 .44349 Mdot
.45717 .31496 Mdot
.48646 .37837 Mdot
.46969 .34706 Mdot
.52979 .32873 Mdot
.46979 .64306 Mdot
.62853 .54359 Mdot
.51979 .36992 Mdot
.37245 .76312 Mdot
.59301 .47373 Mdot
.52874 .38488 Mdot
.33244 .54826 Mdot
.43078 .68174 Mdot
.61571 .72408 Mdot
.695 .34732 Mdot
.43929 .39511 Mdot
.60705 .20436 Mdot
.33351 .34027 Mdot
.62976 .70137 Mdot
.30975 .56478 Mdot
.67844 .47768 Mdot
.4252 .38391 Mdot
.63283 .23826 Mdot
.5016 .39568 Mdot
.54418 .45071 Mdot
.65454 .59342 Mdot
.44469 .62003 Mdot
.84722 .45378 Mdot
.6053 .59499 Mdot
.33581 .52082 Mdot
.65981 .21581 Mdot
.29146 .50667 Mdot
.351 .50528 Mdot
.55646 .21398 Mdot
.46631 .6371 Mdot
.5592 .11722 Mdot
.57138 .83441 Mdot
.5072 .34927 Mdot
.43118 .64459 Mdot
.305 .52905 Mdot
.49391 .35579 Mdot
.30017 .50744 Mdot
.35364 .50976 Mdot
.50393 .41419 Mdot
.48253 .38131 Mdot
.57885 .44107 Mdot
.55874 .18076 Mdot
.67753 .46735 Mdot
.35457 .53816 Mdot
.28326 .37077 Mdot
.50493 .36902 Mdot
.49372 .40273 Mdot
.65251 .65916 Mdot
.67528 .46101 Mdot
.50013 .27395 Mdot
.4667 .35669 Mdot
.22024 .63586 Mdot
.42912 .42729 Mdot
.3342 .57537 Mdot
.41465 .64154 Mdot
.45297 .78476 Mdot
.61808 .55237 Mdot
.35724 .54074 Mdot
.71612 .48302 Mdot
.29416 .56688 Mdot
.3351 .467 Mdot
.4651 .63941 Mdot
.34621 .53958 Mdot
.66753 .57709 Mdot
.45863 .64981 Mdot
.42207 .62843 Mdot
.67873 .27013 Mdot
.66121 .61107 Mdot
.6961 .49916 Mdot
.4566 .63779 Mdot
.29228 .32735 Mdot
.44337 .65709 Mdot
.29798 .36801 Mdot
.4521 .33589 Mdot
.60723 .43097 Mdot
.34655 .71111 Mdot
.53829 .34048 Mdot
.47255 .65051 Mdot
.69059 .45202 Mdot
.43889 .3693 Mdot
.3267 .55587 Mdot
.71078 .47473 Mdot
.49892 .64087 Mdot
.6526 .61247 Mdot
.29613 .54627 Mdot
.41624 .66165 Mdot
.35302 .53395 Mdot
.70144 .39074 Mdot
.64164 .51084 Mdot
.47076 .5803 Mdot
.54647 .5158 Mdot
.51392 .37702 Mdot
.3857 .57358 Mdot
.42271 .41807 Mdot
.45901 .4141 Mdot
.62361 .59473 Mdot
.61337 .39945 Mdot
.30963 .53267 Mdot
.85167 .45936 Mdot
.44151 .6241 Mdot
.24791 .67236 Mdot
.48965 .47164 Mdot
.44025 .41661 Mdot
.30216 .51795 Mdot
.30274 .49901 Mdot
.27765 .46444 Mdot
.62581 .55166 Mdot
.54736 .39018 Mdot
.42606 .33316 Mdot
.53608 .39701 Mdot
.42098 .63575 Mdot
.52887 .67664 Mdot
.65164 .56117 Mdot
.69052 .79084 Mdot
.65508 .60137 Mdot
.73386 .53995 Mdot
.33035 .50464 Mdot
.69997 .49342 Mdot
.49406 .40041 Mdot
.54383 .46099 Mdot
.32491 .57139 Mdot
.69985 .42324 Mdot
.68588 .48896 Mdot
.49083 .72166 Mdot
.46518 .6287 Mdot
.47191 .43129 Mdot
.49183 .41867 Mdot
.44937 .35062 Mdot
.45456 .33802 Mdot
.4265 .66888 Mdot
.50409 .35472 Mdot
.47784 .64042 Mdot
.30614 .31815 Mdot
.21995 .6406 Mdot
.59376 .59647 Mdot
.54363 .2451 Mdot
.29033 .53163 Mdot
.27035 .35313 Mdot
.54607 .42079 Mdot
.44862 .81712 Mdot
.73831 .34371 Mdot
.4197 .39949 Mdot
.63658 .55802 Mdot
.48364 .24563 Mdot
.59906 .60838 Mdot
.32014 .83403 Mdot
.6755 .53118 Mdot
.6302 .19932 Mdot
.49514 .35977 Mdot
.65764 .65379 Mdot
.53517 .43995 Mdot
.49061 .42731 Mdot
.67635 .52449 Mdot
.23141 .59629 Mdot
.35599 .68872 Mdot
.71813 .45069 Mdot
.44855 .38511 Mdot
.34904 .50165 Mdot
.48904 .36149 Mdot
.49293 .40749 Mdot
.4918 .35066 Mdot
.41301 .64257 Mdot
.429 .43618 Mdot
.49299 .34587 Mdot
.56704 .69999 Mdot
.63387 .37438 Mdot
.60996 .59418 Mdot
.28824 .47318 Mdot
.7066 .46769 Mdot
.29882 .53259 Mdot
.52183 .49731 Mdot
.443 .61296 Mdot
.25023 .4765 Mdot
.48053 .34192 Mdot
.33386 .69885 Mdot
.41688 .66282 Mdot
.70816 .47828 Mdot
.62335 .72795 Mdot
.68627 .25448 Mdot
.59454 .59306 Mdot
.62331 .73121 Mdot
.62636 .59576 Mdot
.20659 .4281 Mdot
.3024 .52199 Mdot
.5149 .38201 Mdot
.44895 .63578 Mdot
.62493 .607 Mdot
.61045 .37857 Mdot
.46248 .40609 Mdot
.64224 .57339 Mdot
.51503 .37541 Mdot
.61824 .44639 Mdot
.69122 .67261 Mdot
.60151 .60929 Mdot
.40931 .62948 Mdot
.45489 .6481 Mdot
.68138 .48913 Mdot
.29731 .53639 Mdot
.34124 .5457 Mdot
.45929 .65767 Mdot
.50094 .85725 Mdot
.44969 .41327 Mdot
.49712 .35914 Mdot
.3729 .76104 Mdot
.48796 .36943 Mdot
.673 .34382 Mdot
.61149 .70559 Mdot
.29479 .53281 Mdot
.49022 .35289 Mdot
.449 .36953 Mdot
.43984 .3874 Mdot
.69613 .39396 Mdot
.65172 .60675 Mdot
.42452 .39108 Mdot
.68349 .44975 Mdot
.55635 .76959 Mdot
.50162 .36248 Mdot
.53027 .35942 Mdot
.34161 .54178 Mdot
.19062 .61638 Mdot
.43671 .61538 Mdot
.62971 .5724 Mdot
.66007 .60268 Mdot
.73989 .45712 Mdot
.37662 .51983 Mdot
.61166 .72461 Mdot
.81137 .61879 Mdot
.63304 .72535 Mdot
.68588 .46943 Mdot
.77645 .4941 Mdot
.6796 .60447 Mdot
.62486 .56905 Mdot
.46352 .60698 Mdot
.47416 .3397 Mdot
.42254 .37778 Mdot
.4115 .77008 Mdot
.4275 .40175 Mdot
.6884 .48755 Mdot
.47032 .62648 Mdot
.33636 .54136 Mdot
.70642 .48338 Mdot
.42625 .63657 Mdot
.31819 .55235 Mdot
.48696 .43516 Mdot
.48024 .43927 Mdot
.33243 .52582 Mdot
.31099 .5575 Mdot
.49248 .38776 Mdot
.55093 .70216 Mdot
.37092 .53255 Mdot
.34821 .53688 Mdot
.62688 .68712 Mdot
.59462 .59716 Mdot
.40135 .43036 Mdot
.42998 .64637 Mdot
.4705 .34831 Mdot
.59721 .60466 Mdot
.67257 .46856 Mdot
.31403 .53596 Mdot
.45124 .36957 Mdot
.46178 .37105 Mdot
.68382 .46231 Mdot
.69957 .44066 Mdot
.70488 .48689 Mdot
.47392 .67381 Mdot
.44328 .34697 Mdot
.3235 .51544 Mdot
.46441 .62996 Mdot
.72661 .46197 Mdot
.71036 .49806 Mdot
.58468 .70212 Mdot
.50347 .37899 Mdot
.47063 .54634 Mdot
.79633 .26853 Mdot
.65737 .31761 Mdot
.61415 .7228 Mdot
.64654 .62562 Mdot
.64171 .40352 Mdot
.68518 .65965 Mdot
.43497 .66593 Mdot
.62392 .269 Mdot
.66712 .48805 Mdot
.51505 .39085 Mdot
.43005 .42689 Mdot
.42822 .34288 Mdot
.70019 .46936 Mdot
.70739 .37736 Mdot
.28376 .52858 Mdot
.23686 .42474 Mdot
.70655 .46802 Mdot
.60092 .60711 Mdot
.62384 .63009 Mdot
.65535 .60076 Mdot
.44997 .43846 Mdot
.26768 .46556 Mdot
.27866 .35543 Mdot
.24983 .33669 Mdot
.46447 .62512 Mdot
.27811 .52268 Mdot
.75158 .37584 Mdot
.33081 .52281 Mdot
.60428 .59183 Mdot
.69644 .46749 Mdot
.34592 .54677 Mdot
.45187 .66879 Mdot
.44182 .64285 Mdot
.64844 .61432 Mdot
.63752 .6106 Mdot
.61478 .5943 Mdot
.36755 .52824 Mdot
.33135 .50509 Mdot
.43586 .39539 Mdot
.32191 .5343 Mdot
.297 .73021 Mdot
.72755 .49061 Mdot
.61219 .62377 Mdot
.43393 .658 Mdot
.30186 .52932 Mdot
.45465 .40512 Mdot
.77813 .53706 Mdot
.347 .60853 Mdot
.71453 .45507 Mdot
.67961 .69193 Mdot
.36803 .85776 Mdot
.49802 .4155 Mdot
.42145 .65531 Mdot
.48438 .79385 Mdot
.47073 .40715 Mdot
.64397 .59335 Mdot
.18607 .42663 Mdot
.6375 .71922 Mdot
.49539 .34851 Mdot
.43239 .40876 Mdot
.42272 .62344 Mdot
.70768 .40933 Mdot
.43249 .39362 Mdot
.29638 .69406 Mdot
.42259 .60932 Mdot
.63016 .55525 Mdot
.85491 .49437 Mdot
.65582 .53587 Mdot
.58704 .39635 Mdot
.61695 .7041 Mdot
.48146 .4214 Mdot
.62573 .57936 Mdot
.70901 .45097 Mdot
.6186 .58892 Mdot
.30592 .56495 Mdot
.61167 .59298 Mdot
.4658 .38168 Mdot
.3261 .51347 Mdot
.43927 .66526 Mdot
.30276 .72455 Mdot
.56589 .71578 Mdot
.63358 .61263 Mdot
.62749 .68492 Mdot
.50295 .35901 Mdot
.52422 .29856 Mdot
.433 .31522 Mdot
.50032 .36382 Mdot
.46127 .63635 Mdot
.30207 .51618 Mdot
.44976 .6774 Mdot
.51689 .34228 Mdot
.21187 .59509 Mdot
.42538 .6286 Mdot
.39291 .72169 Mdot
.685 .4736 Mdot
.5864 .42853 Mdot
.44923 .40637 Mdot
.45267 .63471 Mdot
.44525 .34583 Mdot
.31939 .49747 Mdot
.52942 .56343 Mdot
.56337 .7771 Mdot
.44858 .63671 Mdot
.7571 .31609 Mdot
.51578 .57055 Mdot
.40445 .4226 Mdot
.45141 .63103 Mdot
.21514 .47329 Mdot
.61636 .71201 Mdot
.6917 .46251 Mdot
.72493 .45891 Mdot
.71776 .45584 Mdot
.42902 .41305 Mdot
.537 .4189 Mdot
.70544 .49842 Mdot
.41829 .61834 Mdot
.6752 .45929 Mdot
.56068 .45548 Mdot
.75036 .30861 Mdot
.7145 .48131 Mdot
.45135 .39316 Mdot
.52963 .35275 Mdot
.63092 .37511 Mdot
.6055 .57747 Mdot
.58171 .19181 Mdot
.37623 .37188 Mdot
.49803 .38016 Mdot
.42211 .4544 Mdot
.29368 .54988 Mdot
.53092 .80143 Mdot
.45513 .47382 Mdot
.6798 .67282 Mdot
.31967 .50068 Mdot
.66847 .54834 Mdot
.29597 .53357 Mdot
.5057 .4037 Mdot
.47853 .35665 Mdot
.33448 .48674 Mdot
.50074 .69139 Mdot
.48244 .76186 Mdot
.81985 .43764 Mdot
.34974 .54146 Mdot
.44185 .63135 Mdot
.43342 .67213 Mdot
.45921 .621 Mdot
.63826 .54898 Mdot
.35065 .55714 Mdot
.43216 .36076 Mdot
.65419 .57547 Mdot
.45111 .41655 Mdot
.45927 .64398 Mdot
.84653 .44822 Mdot
.34001 .54165 Mdot
.48877 .39613 Mdot
.58558 .8217 Mdot
.63905 .60411 Mdot
.69207 .45693 Mdot
.62455 .44627 Mdot
.65703 .551 Mdot
.46808 .65989 Mdot
.30842 .49346 Mdot
.47558 .68924 Mdot
.48311 .50556 Mdot
.43274 .45104 Mdot
.51785 .40964 Mdot
.83536 .53032 Mdot
.60108 .767 Mdot
.43747 .42878 Mdot
.64635 .56855 Mdot
.60248 .57583 Mdot
.45074 .37352 Mdot
.34448 .55677 Mdot
.72518 .4777 Mdot
.68482 .44774 Mdot
.46542 .31627 Mdot
.53521 .52388 Mdot
.58833 .4387 Mdot
.45301 .35963 Mdot
.54469 .35494 Mdot
.65879 .60865 Mdot
.62962 .73171 Mdot
.37053 .74733 Mdot
.71323 .48794 Mdot
.47536 .35071 Mdot
.38082 .68584 Mdot
.34544 .50758 Mdot
.61286 .5912 Mdot
.46918 .65111 Mdot
.72189 .3911 Mdot
.66203 .56269 Mdot
.45189 .37194 Mdot
.45078 .36689 Mdot
.42318 .62413 Mdot
.33365 .57542 Mdot
.69756 .46956 Mdot
.65442 .57859 Mdot
.7121 .49036 Mdot
.33527 .50916 Mdot
.33757 .53872 Mdot
.43124 .45336 Mdot
.53347 .33948 Mdot
.64528 .61361 Mdot
.48802 .32442 Mdot
.60261 .6021 Mdot
.72759 .41284 Mdot
.42902 .67823 Mdot
.49244 .4206 Mdot
.28849 .50392 Mdot
.46156 .64497 Mdot
.48093 .38688 Mdot
.84075 .5861 Mdot
.44837 .42182 Mdot
.63795 .54186 Mdot
.2116 .60976 Mdot
.68172 .45464 Mdot
.37133 .46279 Mdot
.42087 .2961 Mdot
.48552 .36939 Mdot
.61328 .62175 Mdot
.43971 .31366 Mdot
.42332 .62832 Mdot
.31505 .50423 Mdot
.48975 .87637 Mdot
.44701 .65562 Mdot
.48751 .35817 Mdot
.70711 .4762 Mdot
.29909 .49997 Mdot
.63539 .70936 Mdot
.38443 .76664 Mdot
.40647 .391 Mdot
.4885 .43754 Mdot
.48268 .34537 Mdot
.27058 .2863 Mdot
.62569 .57558 Mdot
.30343 .52906 Mdot
.42065 .63938 Mdot
.45377 .66272 Mdot
.65378 .5984 Mdot
.33605 .68144 Mdot
.56022 .56679 Mdot
.65625 .14574 Mdot
.62837 .61847 Mdot
.67008 .47741 Mdot
.5555 .49961 Mdot
.60705 .60618 Mdot
.63535 .57777 Mdot
.66168 .60147 Mdot
.37271 .73053 Mdot
.32375 .55065 Mdot
.4626 .36912 Mdot
.37382 .53483 Mdot
.47877 .42258 Mdot
.56247 .33346 Mdot
.46381 .65281 Mdot
.31893 .50322 Mdot
.84206 .55347 Mdot
.40428 .47638 Mdot
.4668 .40147 Mdot
.76626 .40075 Mdot
.41965 .32597 Mdot
.68413 .37026 Mdot
.39706 .37233 Mdot
.62989 .6047 Mdot
.48768 .46177 Mdot
.53401 .36989 Mdot
.29445 .7242 Mdot
.43204 .65631 Mdot
.61445 .70523 Mdot
.41796 .40494 Mdot
.41245 .36099 Mdot
.32432 .49448 Mdot
.34687 .54623 Mdot
.70412 .49819 Mdot
.59567 .4877 Mdot
.43634 .66352 Mdot
.63179 .50337 Mdot
.49326 .37865 Mdot
.51136 .66899 Mdot
.25702 .50097 Mdot
.48155 .3883 Mdot
.66188 .25053 Mdot
.25856 .47243 Mdot
.43253 .39879 Mdot
.21456 .43761 Mdot
.43904 .64655 Mdot
.21948 .61752 Mdot
.48626 .32971 Mdot
.64245 .59309 Mdot
.3201 .50541 Mdot
.29591 .55242 Mdot
.71863 .47262 Mdot
.39338 .80339 Mdot
.47207 .65626 Mdot
.32599 .50369 Mdot
.46952 .41062 Mdot
.46943 .64665 Mdot
.62345 .69376 Mdot
.53239 .37174 Mdot
.60866 .25368 Mdot
.3251 .53588 Mdot
.46926 .32722 Mdot
.27226 .60468 Mdot
.60141 .45636 Mdot
.51646 .15949 Mdot
.45363 .61858 Mdot
.70926 .48809 Mdot
.39557 .40896 Mdot
.81059 .6164 Mdot
.42566 .34923 Mdot
.60517 .41929 Mdot
.32577 .59037 Mdot
.69648 .49545 Mdot
.4767 .40339 Mdot
.4351 .38458 Mdot
.52706 .51916 Mdot
.70156 .43955 Mdot
.4639 .4257 Mdot
.46046 .46066 Mdot
.31573 .55073 Mdot
.6126 .70457 Mdot
.3288 .53963 Mdot
.45259 .39662 Mdot
.53121 .42656 Mdot
.33594 .5548 Mdot
.79864 .48482 Mdot
.67287 .45153 Mdot
.43925 .61494 Mdot
.55091 .3811 Mdot
.46208 .33474 Mdot
.29098 .24428 Mdot
.61271 .71837 Mdot
.20155 .39519 Mdot
.67427 .58665 Mdot
.39225 .69094 Mdot
.68375 .60013 Mdot
.66629 .22549 Mdot
.3139 .72747 Mdot
.41086 .3871 Mdot
.58343 .27325 Mdot
.22711 .39956 Mdot
.46214 .66978 Mdot
.34 .28073 Mdot
.49585 .37791 Mdot
.48979 .41131 Mdot
.62717 .55957 Mdot
.32357 .68336 Mdot
.47393 .78943 Mdot
.54171 .53157 Mdot
.69486 .47284 Mdot
.34405 .51315 Mdot
.47359 .37463 Mdot
.56409 .5911 Mdot
.61209 .60313 Mdot
.51176 .62013 Mdot
.48522 .40091 Mdot
.47355 .81003 Mdot
.38732 .72857 Mdot
.47058 .64103 Mdot
.63555 .62803 Mdot
.66095 .55644 Mdot
.50098 .4043 Mdot
.46525 .66124 Mdot
.4348 .39728 Mdot
.52436 .58923 Mdot
.47319 .32266 Mdot
.71419 .47409 Mdot
.51083 .36557 Mdot
.49014 .52687 Mdot
.57429 .16103 Mdot
.41922 .46694 Mdot
.33536 .56208 Mdot
.64308 .54912 Mdot
.6519 .60462 Mdot
.34511 .54423 Mdot
.65064 .60386 Mdot
.24487 .43457 Mdot
.35638 .39364 Mdot
.69205 .47558 Mdot
.55375 .39646 Mdot
.7149 .46885 Mdot
.61325 .70917 Mdot
.5016 .37985 Mdot
.80955 .63305 Mdot
.63168 .61781 Mdot
.1851 .49991 Mdot
.44343 .65929 Mdot
.61337 .71109 Mdot
.42995 .3455 Mdot
.77377 .49398 Mdot
.60675 .58027 Mdot
.65096 .54049 Mdot
.4389 .38947 Mdot
.33757 .54892 Mdot
.43702 .38073 Mdot
.41098 .34264 Mdot
.62132 .72949 Mdot
.47507 .34034 Mdot
.42627 .63681 Mdot
.36242 .54594 Mdot
.70762 .26945 Mdot
.61078 .55949 Mdot
.50653 .38488 Mdot
.47076 .41001 Mdot
.30297 .50169 Mdot
.44469 .33518 Mdot
.44968 .67053 Mdot
.43536 .09785 Mdot
.68466 .47243 Mdot
.63671 .72827 Mdot
.63448 .54053 Mdot
.4206 .39798 Mdot
.44855 .36442 Mdot
.83888 .51592 Mdot
.53686 .75039 Mdot
.43211 .63088 Mdot
.43396 .32009 Mdot
.64923 .57462 Mdot
.70693 .47805 Mdot
.4293 .6078 Mdot
.4673 .34814 Mdot
.49038 .40508 Mdot
.7129 .47676 Mdot
.69482 .2782 Mdot
.67907 .67778 Mdot
.46179 .62169 Mdot
.48953 .46234 Mdot
.77325 .55783 Mdot
.44982 .41279 Mdot
.79675 .55055 Mdot
.34658 .53714 Mdot
.45412 .62828 Mdot
.25554 .32112 Mdot
.51621 .37713 Mdot
.44221 .6707 Mdot
.43503 .66163 Mdot
.50897 .34831 Mdot
.37524 .52604 Mdot
.36409 .5292 Mdot
.35278 .52883 Mdot
.21187 .648 Mdot
.58348 .33151 Mdot
.61508 .59605 Mdot
.43886 .64523 Mdot
.60114 .61285 Mdot
.72719 .45871 Mdot
.59018 .47687 Mdot
.59888 .59321 Mdot
.29389 .54918 Mdot
.62362 .63053 Mdot
.43772 .38438 Mdot
.43865 .66604 Mdot
.62303 .56994 Mdot
.4235 .41336 Mdot
.46836 .2753 Mdot
.48988 .56328 Mdot
.72095 .48589 Mdot
.71372 .42273 Mdot
.47488 .36319 Mdot
.61646 .72447 Mdot
.4935 .38953 Mdot
.4693 .62717 Mdot
.5005 .51319 Mdot
.42267 .40453 Mdot
.63903 .61423 Mdot
.38379 .41973 Mdot
.61897 .55858 Mdot
.41942 .3366 Mdot
.45357 .39374 Mdot
.45891 .41793 Mdot
.43222 .39467 Mdot
.37912 .71059 Mdot
.46285 .67168 Mdot
.46747 .27209 Mdot
.62563 .64219 Mdot
.32268 .52759 Mdot
.28357 .5468 Mdot
.76769 .59219 Mdot
.6354 .73267 Mdot
.43104 .64668 Mdot
.44697 .40926 Mdot
.64595 .53889 Mdot
.84477 .44094 Mdot
.80976 .50617 Mdot
.76204 .44177 Mdot
.63786 .56597 Mdot
.32736 .56249 Mdot
.60821 .59142 Mdot
.49405 .41286 Mdot
.52321 .37226 Mdot
.68097 .24125 Mdot
.43547 .59125 Mdot
.69764 .46776 Mdot
.46253 .42 Mdot
.58456 .39143 Mdot
.64967 .57392 Mdot
.66045 .60785 Mdot
.45049 .42116 Mdot
.35913 .54014 Mdot
.4354 .1545 Mdot
.47119 .64421 Mdot
.45704 .25807 Mdot
.39031 .50057 Mdot
.23481 .61844 Mdot
.45872 .66189 Mdot
.47932 .56978 Mdot
.66245 .5779 Mdot
.37473 .44435 Mdot
.32692 .52798 Mdot
.70072 .46605 Mdot
.52611 .37889 Mdot
.29444 .54817 Mdot
.6686 .60523 Mdot
.29389 .52703 Mdot
.51003 .39907 Mdot
.45975 .67272 Mdot
.65926 .5918 Mdot
.40781 .65714 Mdot
.33088 .48628 Mdot
.7071 .45442 Mdot
.58286 .43024 Mdot
.37269 .26461 Mdot
.25556 .47382 Mdot
.42453 .39054 Mdot
.61681 .65705 Mdot
.44119 .34992 Mdot
.34061 .49892 Mdot
.44879 .40393 Mdot
.35169 .59253 Mdot
.64266 .62349 Mdot
.4707 .32736 Mdot
.49897 .3508 Mdot
.33881 .30506 Mdot
.47307 .39646 Mdot
.48431 .33803 Mdot
.43041 .39711 Mdot
.3909 .51426 Mdot
.41461 .42661 Mdot
.32974 .55061 Mdot
.40012 .76149 Mdot
.63356 .57932 Mdot
.71971 .48935 Mdot
.69869 .4447 Mdot
.60327 .42481 Mdot
.59124 .42355 Mdot
.33845 .68762 Mdot
.32338 .54378 Mdot
.42484 .64565 Mdot
.43502 .39852 Mdot
.29024 .2905 Mdot
.73329 .49352 Mdot
.66242 .58293 Mdot
.62256 .54935 Mdot
.5277 .32877 Mdot
.2743 .281 Mdot
.45019 .32873 Mdot
.3907 .77709 Mdot
.47116 .31762 Mdot
.45621 .42604 Mdot
.65605 .55291 Mdot
.59589 .44526 Mdot
.42434 .39164 Mdot
.32221 .4945 Mdot
.70043 .46183 Mdot
.43559 .47932 Mdot
.69815 .60263 Mdot
.50767 .59367 Mdot
.36293 .31046 Mdot
.4368 .35085 Mdot
.65609 .58482 Mdot
.29655 .54638 Mdot
.36039 .74667 Mdot
.46318 .62904 Mdot
.34351 .71403 Mdot
.30207 .33406 Mdot
.7927 .44174 Mdot
.69853 .46427 Mdot
.68665 .27442 Mdot
.46622 .38065 Mdot
.64307 .54807 Mdot
.50729 .40984 Mdot
.84295 .43636 Mdot
.67398 .48809 Mdot
.33733 .57103 Mdot
.43967 .63168 Mdot
.32389 .4977 Mdot
.30242 .45132 Mdot
.45411 .57427 Mdot
.57208 .63491 Mdot
.59561 .59171 Mdot
.50791 .27545 Mdot
.31573 .515 Mdot
.46022 .35869 Mdot
.70828 .18419 Mdot
.3472 .53561 Mdot
.35612 .53281 Mdot
.7133 .41516 Mdot
.75554 .42713 Mdot
.47158 .30963 Mdot
.29284 .5236 Mdot
.61991 .6351 Mdot
.68216 .45912 Mdot
.43286 .37686 Mdot
.43199 .38993 Mdot
.3393 .55084 Mdot
.604 .58865 Mdot
.46717 .25242 Mdot
.63391 .60849 Mdot
.31213 .55087 Mdot
.63345 .59787 Mdot
.58983 .57811 Mdot
.63034 .56911 Mdot
.45965 .33345 Mdot
.44529 .40347 Mdot
.70914 .58356 Mdot
.33738 .53864 Mdot
.44638 .36174 Mdot
.474 .35518 Mdot
.31987 .51579 Mdot
.67353 .6158 Mdot
.31121 .27442 Mdot
.49647 .36792 Mdot
.45233 .38297 Mdot
.7027 .49323 Mdot
.6795 .5864 Mdot
.68498 .70295 Mdot
.43863 .36914 Mdot
.67452 .45619 Mdot
.36831 .52556 Mdot
.49122 .38949 Mdot
.56136 .4579 Mdot
.59227 .58475 Mdot
.51291 .36698 Mdot
.63508 .70599 Mdot
.42085 .38868 Mdot
.45353 .15824 Mdot
.50735 .37718 Mdot
.30656 .52836 Mdot
.31272 .50963 Mdot
.68448 .41818 Mdot
.33888 .52035 Mdot
.61823 .69908 Mdot
.45864 .64641 Mdot
.81632 .39989 Mdot
.6238 .6952 Mdot
.44879 .42531 Mdot
.57118 .83467 Mdot
.50002 .33111 Mdot
.41844 .40382 Mdot
.2341 .33559 Mdot
.62433 .69639 Mdot
.30528 .51704 Mdot
.48351 .70269 Mdot
.47328 .31681 Mdot
.46969 .65106 Mdot
.52969 .39436 Mdot
.51019 .3562 Mdot
.2637 .66613 Mdot
.21934 .54164 Mdot
.46328 .61779 Mdot
.39955 .43287 Mdot
.43897 .36832 Mdot
.58727 .74593 Mdot
.46045 .40687 Mdot
.71654 .47833 Mdot
.35483 .52887 Mdot
.61398 .61168 Mdot
.6812 .47346 Mdot
.48986 .37401 Mdot
.70299 .46989 Mdot
.61395 .5905 Mdot
.45948 .63315 Mdot
.50382 .39125 Mdot
.66733 .47736 Mdot
.69619 .4722 Mdot
.44413 .35081 Mdot
.32011 .50394 Mdot
.40833 .47255 Mdot
.48895 .3892 Mdot
.45787 .3635 Mdot
.34109 .54571 Mdot
.72087 .76327 Mdot
.50001 .4103 Mdot
.47332 .54957 Mdot
.33827 .56961 Mdot
.61471 .6907 Mdot
.61452 .57636 Mdot
.51464 .36055 Mdot
.46701 .64704 Mdot
.46372 .64837 Mdot
.64457 .62926 Mdot
.31699 .49717 Mdot
.60695 .57564 Mdot
.40355 .45091 Mdot
.53576 .34323 Mdot
.51725 .34847 Mdot
.46477 .86536 Mdot
.66584 .23471 Mdot
.34119 .55876 Mdot
.65418 .56294 Mdot
.54612 .53104 Mdot
.43662 .64146 Mdot
.62842 .6329 Mdot
.30653 .4953 Mdot
.31673 .56077 Mdot
.29054 .53305 Mdot
.69702 .49281 Mdot
.66353 .56943 Mdot
.33421 .57425 Mdot
.35939 .5349 Mdot
.4386 .38696 Mdot
.44049 .36628 Mdot
.27132 .56948 Mdot
.64588 .36444 Mdot
.7117 .45852 Mdot
.65254 .59279 Mdot
.2418 .26527 Mdot
.4686 .62571 Mdot
.3416 .3048 Mdot
.42127 .4038 Mdot
.88977 .39619 Mdot
.45245 .32679 Mdot
.46628 .4103 Mdot
.36823 .53559 Mdot
.6745 .49602 Mdot
.70738 .45992 Mdot
.31623 .51377 Mdot
.31137 .49107 Mdot
.71499 .48286 Mdot
.7315 .33342 Mdot
.75877 .31343 Mdot
.35007 .73199 Mdot
.31203 .52402 Mdot
.38858 .2613 Mdot
.46688 .66089 Mdot
.35025 .48847 Mdot
.45028 .61114 Mdot
.63667 .57857 Mdot
.66679 .58607 Mdot
.42489 .62158 Mdot
.43921 .39219 Mdot
.61529 .58258 Mdot
.41463 .43284 Mdot
.74126 .3252 Mdot
.50398 .21562 Mdot
.52094 .73751 Mdot
.42654 .42352 Mdot
.45991 .7872 Mdot
.49846 .78327 Mdot
.48072 .36558 Mdot
.4885 .48882 Mdot
.69957 .46792 Mdot
.37431 .49709 Mdot
.45277 .66982 Mdot
.50354 .1594 Mdot
.44851 .41142 Mdot
.30836 .53454 Mdot
.43093 .65365 Mdot
.65503 .43681 Mdot
.29214 .68724 Mdot
.47133 .42332 Mdot
.60138 .12657 Mdot
.37881 .50777 Mdot
.61477 .61238 Mdot
.49099 .84229 Mdot
.37219 .54208 Mdot
.72175 .42473 Mdot
.66986 .59262 Mdot
.81927 .4797 Mdot
.29909 .53366 Mdot
.6632 .61574 Mdot
.33827 .51186 Mdot
.71693 .47044 Mdot
.36034 .50328 Mdot
.65985 .5874 Mdot
.47591 .4001 Mdot
.64896 .60104 Mdot
.71152 .45702 Mdot
.63584 .54833 Mdot
.46014 .66621 Mdot
.61405 .71515 Mdot
.44816 .64497 Mdot
.60119 .46382 Mdot
.21234 .56878 Mdot
.44509 .61979 Mdot
.63973 .46994 Mdot
.43526 .42761 Mdot
.33045 .57703 Mdot
.62667 .62046 Mdot
.62538 .64108 Mdot
.57469 .49196 Mdot
.32228 .52351 Mdot
.65598 .59411 Mdot
.29617 .33354 Mdot
.64818 .80678 Mdot
.5388 .41528 Mdot
.58578 .31277 Mdot
.31849 .51778 Mdot
.6563 .61571 Mdot
.37329 .76041 Mdot
.28728 .54136 Mdot
.62738 .61756 Mdot
.44941 .63216 Mdot
.45526 .66273 Mdot
.44706 .41594 Mdot
.42617 .5936 Mdot
.62167 .62469 Mdot
.44843 .75199 Mdot
.3479 .50864 Mdot
.65223 .43766 Mdot
.72074 .46774 Mdot
.63642 .57431 Mdot
.53526 .37888 Mdot
.26725 .52132 Mdot
.59326 .60013 Mdot
.57289 .24765 Mdot
.22486 .29072 Mdot
.65324 .59662 Mdot
.35461 .52529 Mdot
.31203 .53755 Mdot
.42534 .32118 Mdot
.53678 .52109 Mdot
.61316 .56785 Mdot
.79412 .66013 Mdot
.60732 .4106 Mdot
.62608 .71844 Mdot
.60978 .77248 Mdot
.42354 .39452 Mdot
.45015 .34295 Mdot
.43559 .63934 Mdot
.46459 .39458 Mdot
.36183 .53541 Mdot
.4227 .36741 Mdot
.43595 .66998 Mdot
.66165 .57875 Mdot
.50273 .388 Mdot
.68595 .45376 Mdot
.47181 .62404 Mdot
.42702 .61727 Mdot
.62729 .58784 Mdot
.29186 .52682 Mdot
.57859 .55883 Mdot
.63875 .61064 Mdot
.43325 .35538 Mdot
.6299 .70428 Mdot
.51358 .38345 Mdot
.6691 .27946 Mdot
.28722 .51998 Mdot
.60709 .59893 Mdot
.30804 .56392 Mdot
.44669 .64905 Mdot
.63774 .63922 Mdot
.45765 .40067 Mdot
.62717 .61483 Mdot
.69299 .63985 Mdot
.70485 .30237 Mdot
.3184 .49644 Mdot
.68777 .60047 Mdot
.35689 .52772 Mdot
.62684 .72007 Mdot
.66888 .30156 Mdot
.69034 .46626 Mdot
.64654 .57564 Mdot
.64576 .22149 Mdot
.63923 .61625 Mdot
.47362 .39425 Mdot
.47904 .38154 Mdot
.62779 .56036 Mdot
.67502 .47591 Mdot
.19185 .61413 Mdot
.46061 .55741 Mdot
.30081 .52163 Mdot
.3748 .42132 Mdot
.28966 .22067 Mdot
.41866 .61118 Mdot
.43293 .63684 Mdot
.4331 .33183 Mdot
.44132 .41726 Mdot
.42482 .61673 Mdot
.42258 .66708 Mdot
.71546 .48958 Mdot
.66301 .5967 Mdot
.37507 .55314 Mdot
.43052 .60238 Mdot
.42268 .31055 Mdot
.58581 .40409 Mdot
.46358 .31257 Mdot
.48313 .44862 Mdot
.45031 .4407 Mdot
.61422 .44597 Mdot
.42037 .65657 Mdot
.4726 .36339 Mdot
.41032 .41372 Mdot
.44777 .62785 Mdot
.71636 .47032 Mdot
.23799 .56671 Mdot
.63782 .59524 Mdot
.83216 .65154 Mdot
.51082 .37486 Mdot
.47995 .39525 Mdot
.46483 .62578 Mdot
.60346 .75202 Mdot
.31419 .55714 Mdot
.291 .51751 Mdot
.62386 .5763 Mdot
.57883 .4909 Mdot
.43614 .34276 Mdot
.47834 .36423 Mdot
.6464 .58273 Mdot
.61417 .71837 Mdot
.49863 .73529 Mdot
.46096 .37315 Mdot
.43386 .65504 Mdot
.58359 .59476 Mdot
.42097 .65994 Mdot
.49952 .4152 Mdot
.47336 .39199 Mdot
.45753 .33333 Mdot
.44124 .41792 Mdot
.4364 .6084 Mdot
.47158 .3683 Mdot
.53516 .3605 Mdot
.30099 .51121 Mdot
.45457 .33726 Mdot
.61124 .42603 Mdot
.44968 .38958 Mdot
.69614 .45212 Mdot
.58227 .62758 Mdot
.45867 .4187 Mdot
.4606 .33659 Mdot
.46509 .55681 Mdot
.47836 .40618 Mdot
.467 .6244 Mdot
.31958 .53112 Mdot
.43914 .64467 Mdot
.42025 .63718 Mdot
.60939 .62717 Mdot
.71331 .49101 Mdot
.41397 .38101 Mdot
.71363 .45187 Mdot
.49947 .43752 Mdot
.51068 .39948 Mdot
.58744 .55537 Mdot
.39235 .7775 Mdot
.68647 .66439 Mdot
.45521 .40044 Mdot
.62905 .57632 Mdot
.61153 .60798 Mdot
.5789 .26358 Mdot
.40584 .42031 Mdot
.4284 .61053 Mdot
.45227 .63479 Mdot
.66787 .33543 Mdot
.27017 .67503 Mdot
.70579 .45428 Mdot
.56955 .52895 Mdot
.44326 .43728 Mdot
.4637 .36397 Mdot
.53116 .36607 Mdot
.59815 .59593 Mdot
.62629 .73238 Mdot
.66316 .58393 Mdot
.60633 .71878 Mdot
.42577 .66601 Mdot
.42305 .37502 Mdot
.51381 .20553 Mdot
.34378 .55257 Mdot
.3203 .53138 Mdot
.41987 .61881 Mdot
.60977 .56752 Mdot
.41516 .32696 Mdot
.49963 .88199 Mdot
.36346 .48643 Mdot
.70391 .50231 Mdot
.4831 .36243 Mdot
.62648 .58389 Mdot
.35067 .54864 Mdot
.68311 .44643 Mdot
.49229 .3504 Mdot
.64511 .64728 Mdot
.44749 .40007 Mdot
.22391 .40269 Mdot
.30355 .51114 Mdot
.8468 .43216 Mdot
.29247 .50607 Mdot
.4712 .62158 Mdot
.43862 .6237 Mdot
.47921 .3876 Mdot
.47483 .85895 Mdot
.35333 .56557 Mdot
.4118 .60733 Mdot
.6758 .49365 Mdot
.63482 .72991 Mdot
.6847 .49636 Mdot
.6076 .60909 Mdot
.69859 .46239 Mdot
.6591 .60396 Mdot
.65873 .33906 Mdot
.37515 .48733 Mdot
.68297 .47256 Mdot
.57983 .71301 Mdot
.42666 .43484 Mdot
.72653 .4637 Mdot
.53454 .34778 Mdot
.37989 .45392 Mdot
.64414 .58505 Mdot
.6748 .4735 Mdot
.4575 .36071 Mdot
.49932 .17514 Mdot
.4285 .62731 Mdot
.4317 .60804 Mdot
.43028 .44139 Mdot
.66324 .60033 Mdot
.32801 .48967 Mdot
.49096 .50602 Mdot
.61074 .70085 Mdot
.47556 .36502 Mdot
.42189 .38016 Mdot
.28157 .54342 Mdot
.27756 .52104 Mdot
.47419 .38922 Mdot
.30632 .30835 Mdot
.46857 .37691 Mdot
.46552 .65394 Mdot
.31431 .55914 Mdot
.3149 .53553 Mdot
.62759 .62725 Mdot
.3427 .50245 Mdot
.48663 .44816 Mdot
.39126 .59492 Mdot
.48507 .3185 Mdot
.44914 .65395 Mdot
.48773 .52057 Mdot
.61951 .55192 Mdot
.55154 .18499 Mdot
.28012 .5349 Mdot
.47281 .33903 Mdot
.35302 .51386 Mdot
.69978 .48746 Mdot
.33479 .53748 Mdot
.34711 .56128 Mdot
.48901 .38082 Mdot
.48007 .4217 Mdot
.62302 .69846 Mdot
.54332 .51914 Mdot
.33513 .50337 Mdot
.47498 .37089 Mdot
.49119 .32819 Mdot
.50188 .34721 Mdot
.50568 .5491 Mdot
.3421 .55998 Mdot
.31936 .36524 Mdot
.58786 .24095 Mdot
.32756 .50277 Mdot
.42938 .1691 Mdot
.63652 .7159 Mdot
.63534 .73169 Mdot
.42137 .60296 Mdot
.46025 .37233 Mdot
.63741 .55658 Mdot
.49612 .41022 Mdot
.42979 .45499 Mdot
.49195 .40587 Mdot
.67207 .46921 Mdot
.41192 .39392 Mdot
.62133 .71657 Mdot
.64272 .61011 Mdot
.49552 .35848 Mdot
.50182 .39116 Mdot
.63782 .73257 Mdot
.28201 .52403 Mdot
.30377 .55371 Mdot
.8022 .5326 Mdot
.69566 .48225 Mdot
.46223 .63435 Mdot
.4412 .40425 Mdot
.62776 .57553 Mdot
.64758 .60316 Mdot
.33512 .49982 Mdot
.64335 .59544 Mdot
.47182 .63841 Mdot
.46093 .40279 Mdot
.43065 .60971 Mdot
.67639 .45914 Mdot
.35429 .53352 Mdot
.44281 .4086 Mdot
.43906 .38638 Mdot
.31235 .50982 Mdot
.4359 .42836 Mdot
.70341 .493 Mdot
.64506 .61267 Mdot
.29981 .54292 Mdot
.45995 .64744 Mdot
.62371 .62811 Mdot
.44491 .3744 Mdot
.21553 .30872 Mdot
.46498 .39029 Mdot
.45319 .37243 Mdot
.72979 .28057 Mdot
.42879 .33247 Mdot
.63271 .62455 Mdot
.28627 .55296 Mdot
.46692 .44304 Mdot
.58616 .37204 Mdot
.81941 .57035 Mdot
.62786 .63453 Mdot
.49006 .36111 Mdot
.56946 .18492 Mdot
.4934 .35987 Mdot
.6292 .50448 Mdot
.72852 .64674 Mdot
.51684 .27066 Mdot
.49102 .44444 Mdot
.43792 .61175 Mdot
.62098 .69877 Mdot
.64828 .61864 Mdot
.2243 .47253 Mdot
.48403 .37614 Mdot
.21122 .47128 Mdot
.50463 .35541 Mdot
.4552 .66374 Mdot
.39642 .45831 Mdot
.65084 .59419 Mdot
.3532 .77472 Mdot
.43327 .35818 Mdot
.33701 .56042 Mdot
.61295 .62491 Mdot
.63563 .72598 Mdot
.45223 .36844 Mdot
.7029 .44678 Mdot
.403 .64297 Mdot
.54031 .35142 Mdot
.45255 .65469 Mdot
.47404 .3535 Mdot
.40483 .44104 Mdot
.43643 .83328 Mdot
.29989 .51469 Mdot
.43747 .63377 Mdot
.53757 .79373 Mdot
.44295 .43182 Mdot
.29871 .53616 Mdot
.32612 .52729 Mdot
.71766 .4629 Mdot
.54587 .57985 Mdot
.29185 .61318 Mdot
.45669 .21256 Mdot
.28876 .47113 Mdot
.64393 .62587 Mdot
.49858 .76914 Mdot
.43406 .37301 Mdot
.46821 .58196 Mdot
.45908 .61594 Mdot
.47907 .39752 Mdot
.25927 .49462 Mdot
.35226 .53237 Mdot
.45729 .38129 Mdot
.71543 .46993 Mdot
.52368 .65407 Mdot
.50649 .60612 Mdot
.33198 .22432 Mdot
.62424 .63564 Mdot
.52737 .37145 Mdot
.51307 .43054 Mdot
.62352 .68819 Mdot
.51351 .40098 Mdot
.63744 .62191 Mdot
.75322 .35923 Mdot
.67413 .47918 Mdot
.35305 .54373 Mdot
.63651 .71736 Mdot
.44602 .44172 Mdot
.49301 .33324 Mdot
.71857 .49069 Mdot
.46315 .3452 Mdot
.39959 .80472 Mdot
.64199 .7444 Mdot
.61897 .57577 Mdot
.2928 .53234 Mdot
.45159 .43836 Mdot
.62465 .73137 Mdot
.48522 .38097 Mdot
.38517 .30357 Mdot
.46633 .33953 Mdot
.26835 .61222 Mdot
.3218 .50519 Mdot
.45272 .65148 Mdot
.46813 .44942 Mdot
.48459 .41258 Mdot
.77572 .54714 Mdot
.42905 .4542 Mdot
.50812 .37713 Mdot
.31475 .49519 Mdot
.34288 .55611 Mdot
.33014 .54947 Mdot
.61115 .5951 Mdot
.36078 .73771 Mdot
.43796 .65352 Mdot
.42317 .3585 Mdot
.43113 .60239 Mdot
.40381 .29926 Mdot
.71285 .49657 Mdot
.44065 .18668 Mdot
.48054 .34125 Mdot
.32452 .54738 Mdot
.36804 .66623 Mdot
.36756 .52645 Mdot
.63281 .64638 Mdot
.43687 .66414 Mdot
.34962 .53303 Mdot
.47414 .41329 Mdot
.53047 .53023 Mdot
.35393 .22537 Mdot
.44216 .64035 Mdot
.52786 .35225 Mdot
.63123 .63939 Mdot
.60578 .56082 Mdot
.31046 .19113 Mdot
.43161 .62953 Mdot
.50511 .78176 Mdot
.48026 .36975 Mdot
.34147 .55288 Mdot
.44879 .61655 Mdot
.43211 .61928 Mdot
.64541 .58815 Mdot
.47259 .42248 Mdot
.46109 .41753 Mdot
.63582 .70893 Mdot
.4554 .63657 Mdot
.4387 .44422 Mdot
.50726 .3332 Mdot
.68429 .24345 Mdot
.24341 .53952 Mdot
.75355 .73839 Mdot
.40401 .45178 Mdot
.2717 .47843 Mdot
.55459 .49302 Mdot
.35376 .55437 Mdot
.46159 .421 Mdot
.46987 .43739 Mdot
.62879 .6265 Mdot
.46194 .39654 Mdot
.6316 .55333 Mdot
.42903 .64079 Mdot
.41269 .18198 Mdot
.36241 .60603 Mdot
.74275 .35489 Mdot
.46735 .39869 Mdot
.24872 .64284 Mdot
.68411 .48381 Mdot
.46956 .68439 Mdot
.31072 .55234 Mdot
.46434 .43291 Mdot
.646 .54442 Mdot
.64716 .5749 Mdot
.33638 .52691 Mdot
.44422 .76619 Mdot
.79164 .55102 Mdot
.49643 .41893 Mdot
.6133 .57632 Mdot
.4012 .69931 Mdot
.293 .31827 Mdot
.46202 .6014 Mdot
.67349 .48242 Mdot
.66173 .58144 Mdot
.41577 .63549 Mdot
.25757 .5348 Mdot
.34572 .52581 Mdot
.2948 .56007 Mdot
.73682 .59875 Mdot
.61714 .56222 Mdot
.67971 .4697 Mdot
.31421 .71813 Mdot
.29929 .71308 Mdot
.67175 .4757 Mdot
.66109 .57559 Mdot
.34745 .5531 Mdot
.30645 .54242 Mdot
.31847 .53107 Mdot
.34269 .7671 Mdot
.29504 .51083 Mdot
.34832 .34253 Mdot
.50051 .33271 Mdot
.55016 .34363 Mdot
.49301 .36146 Mdot
.4468 .60824 Mdot
.30457 .51111 Mdot
.56405 .49448 Mdot
.43955 .42266 Mdot
.34799 .22001 Mdot
.47737 .36226 Mdot
.47015 .60906 Mdot
.45684 .37682 Mdot
.35627 .28026 Mdot
.3421 .56826 Mdot
.45613 .39774 Mdot
.46302 .6754 Mdot
.69885 .47452 Mdot
.35822 .57581 Mdot
.46005 .41877 Mdot
.30595 .67334 Mdot
.42422 .34394 Mdot
.75053 .3485 Mdot
.66785 .40793 Mdot
.70058 .50405 Mdot
.45066 .46136 Mdot
.65407 .62176 Mdot
.35116 .58453 Mdot
.53948 .4249 Mdot
.44384 .64048 Mdot
.18904 .48568 Mdot
.64343 .57246 Mdot
.39987 .4689 Mdot
.43026 .32183 Mdot
.71449 .48842 Mdot
.27301 .55356 Mdot
.46365 .62179 Mdot
.42232 .41355 Mdot
.50697 .34698 Mdot
.72724 .34162 Mdot
.54752 .4111 Mdot
.44223 .33549 Mdot
.72644 .4766 Mdot
.32498 .36941 Mdot
.44579 .38802 Mdot
.66834 .623 Mdot
.29965 .56233 Mdot
.42615 .44015 Mdot
.3186 .36033 Mdot
.47595 .37183 Mdot
.34326 .5346 Mdot
.2844 .55445 Mdot
.34016 .6572 Mdot
.68219 .501 Mdot
.46655 .33965 Mdot
.72597 .3993 Mdot
.44098 .34849 Mdot
.4371 .65766 Mdot
.50192 .40836 Mdot
.64129 .57809 Mdot
.3838 .77398 Mdot
.61754 .60575 Mdot
.49675 .41228 Mdot
.31449 .52998 Mdot
.4463 .61272 Mdot
.71472 .59821 Mdot
.74819 .62451 Mdot
.34509 .34719 Mdot
.84305 .5634 Mdot
.68236 .48864 Mdot
.71573 .44611 Mdot
.47698 .6423 Mdot
.45334 .39702 Mdot
.68929 .412 Mdot
.45383 .32069 Mdot
.4521 .38184 Mdot
.49341 .40429 Mdot
.41054 .59677 Mdot
.43455 .64498 Mdot
.6393 .60159 Mdot
.47239 .39006 Mdot
.47335 .371 Mdot
.34347 .50996 Mdot
.69679 .47444 Mdot
.61586 .60743 Mdot
.68939 .47758 Mdot
.62417 .59941 Mdot
.44918 .15809 Mdot
.50602 .32754 Mdot
.70045 .47628 Mdot
.47759 .63924 Mdot
.34135 .54619 Mdot
.61591 .72998 Mdot
.6094 .61426 Mdot
.65368 .59326 Mdot
.47658 .36565 Mdot
.34451 .54215 Mdot
.33677 .50214 Mdot
.69586 .48913 Mdot
.45689 .62516 Mdot
.49498 .41337 Mdot
.50042 .41641 Mdot
.54196 .25714 Mdot
.60153 .60814 Mdot
.282 .34446 Mdot
.35064 .67974 Mdot
.45307 .39912 Mdot
.29466 .51882 Mdot
.49888 .38944 Mdot
.56268 .20019 Mdot
.29425 .54923 Mdot
.45668 .42573 Mdot
.26108 .6733 Mdot
.59872 .58653 Mdot
.29047 .63748 Mdot
.47049 .32978 Mdot
.83989 .50869 Mdot
.43707 .36297 Mdot
.6499 .20368 Mdot
.56515 .75321 Mdot
.42413 .36474 Mdot
.43576 .37935 Mdot
.44318 .21646 Mdot
.48726 .36988 Mdot
.62489 .72212 Mdot
.41354 .46324 Mdot
.31617 .56096 Mdot
.57343 .46925 Mdot
.66159 .63943 Mdot
.67205 .49031 Mdot
.62354 .57625 Mdot
.68214 .63081 Mdot
.71484 .47537 Mdot
.3116 .52272 Mdot
.43125 .39345 Mdot
.58463 .42609 Mdot
.60883 .63278 Mdot
.41676 .33626 Mdot
.4381 .66 Mdot
.68376 .57757 Mdot
.64231 .55243 Mdot
.45686 .6472 Mdot
.49801 .34875 Mdot
.33741 .25533 Mdot
.71528 .66412 Mdot
.82724 .40885 Mdot
.46226 .62229 Mdot
.45704 .66433 Mdot
.36241 .75363 Mdot
.67063 .48503 Mdot
.66389 .28428 Mdot
.25056 .62306 Mdot
.47125 .64973 Mdot
.69517 .34358 Mdot
.66552 .59845 Mdot
.2955 .6696 Mdot
.37409 .49694 Mdot
.52162 .35301 Mdot
.47697 .41347 Mdot
.45428 .62536 Mdot
.5636 .44145 Mdot
.46443 .83147 Mdot
.44795 .64376 Mdot
.52683 .41646 Mdot
.54064 .59871 Mdot
.63224 .7096 Mdot
.632 .6985 Mdot
.69061 .50314 Mdot
.79871 .49785 Mdot
.3319 .50962 Mdot
.71753 .48464 Mdot
.5229 .6288 Mdot
.47105 .3426 Mdot
.45042 .63752 Mdot
.62169 .73529 Mdot
.46051 .65569 Mdot
.71118 .46513 Mdot
.70349 .50207 Mdot
.29993 .51248 Mdot
.31315 .55662 Mdot
.26352 .48151 Mdot
.67363 .36281 Mdot
.49434 .35919 Mdot
.22026 .37089 Mdot
.34733 .50752 Mdot
.51485 .44692 Mdot
.67435 .45713 Mdot
.69797 .47811 Mdot
.23007 .4065 Mdot
.43666 .40391 Mdot
.66525 .4333 Mdot
.44486 .40707 Mdot
.64797 .2894 Mdot
.50631 .41455 Mdot
.64378 .59095 Mdot
.42388 .38104 Mdot
.58328 .54876 Mdot
.42608 .39974 Mdot
.5093 .3787 Mdot
.66369 .59093 Mdot
.52308 .33255 Mdot
.64281 .57777 Mdot
.4917 .41806 Mdot
.70462 .43643 Mdot
.62715 .57571 Mdot
.59441 .33659 Mdot
.47459 .55065 Mdot
.61828 .72272 Mdot
.70117 .44995 Mdot
.72032 .4624 Mdot
.59702 .42269 Mdot
.30802 .55113 Mdot
.27537 .49963 Mdot
.45364 .39507 Mdot
.65995 .60863 Mdot
.43374 .64035 Mdot
.47206 .37268 Mdot
.4943 .42498 Mdot
.4576 .33011 Mdot
.35211 .5212 Mdot
.61231 .5652 Mdot
.70399 .47322 Mdot
.61194 .58179 Mdot
.78628 .52242 Mdot
.66127 .56125 Mdot
.41137 .41922 Mdot
.51465 .4153 Mdot
.42272 .2676 Mdot
.2003 .47453 Mdot
.23573 .65926 Mdot
.34158 .52396 Mdot
.61959 .70583 Mdot
.70554 .50034 Mdot
.3786 .42185 Mdot
.3187 .55109 Mdot
.65883 .58449 Mdot
.44749 .40054 Mdot
.53792 .39115 Mdot
.49138 .61212 Mdot
.34713 .58801 Mdot
.61412 .40186 Mdot
.64755 .55083 Mdot
.62846 .71735 Mdot
.35842 .73879 Mdot
.38814 .47364 Mdot
.57866 .48474 Mdot
.48973 .39926 Mdot
.69908 .44599 Mdot
.35066 .54859 Mdot
.71718 .62705 Mdot
.45322 .63072 Mdot
.53872 .52088 Mdot
.4662 .39874 Mdot
.41371 .73164 Mdot
.31571 .52909 Mdot
.71417 .46392 Mdot
.45354 .62571 Mdot
.67244 .49292 Mdot
.63269 .69841 Mdot
.80768 .48609 Mdot
.44956 .34628 Mdot
.50646 .37427 Mdot
.46318 .60576 Mdot
.33447 .51164 Mdot
.70645 .42306 Mdot
.71637 .32263 Mdot
.61947 .56873 Mdot
.65911 .44462 Mdot
.3649 .54197 Mdot
.3681 .29876 Mdot
.61139 .58652 Mdot
.41944 .61905 Mdot
.60358 .45255 Mdot
.43307 .66968 Mdot
.4526 .41671 Mdot
.32007 .54204 Mdot
.42691 .63493 Mdot
.76752 .54826 Mdot
.56242 .16991 Mdot
.38416 .27123 Mdot
.43173 .35355 Mdot
.43032 .18631 Mdot
.74135 .31249 Mdot
.53455 .4698 Mdot
.45925 .66741 Mdot
.48766 .38713 Mdot
.51716 .39702 Mdot
.42983 .36416 Mdot
.4236 .64714 Mdot
.76422 .49264 Mdot
.65337 .58669 Mdot
.48236 .35879 Mdot
.71999 .47382 Mdot
.63656 .58376 Mdot
.60458 .54268 Mdot
.6461 .61724 Mdot
.32254 .56445 Mdot
.44625 .42179 Mdot
.3592 .72012 Mdot
.59824 .16167 Mdot
.43983 .64375 Mdot
.61845 .72247 Mdot
.50771 .36392 Mdot
.21784 .59938 Mdot
.3288 .5493 Mdot
.62152 .56635 Mdot
.48073 .39556 Mdot
.76804 .51347 Mdot
.61377 .74218 Mdot
.65232 .6078 Mdot
.30582 .54493 Mdot
.52052 .48047 Mdot
.46195 .39458 Mdot
.44013 .35834 Mdot
.32582 .5123 Mdot
.80874 .51402 Mdot
.38437 .77001 Mdot
.5008 .39058 Mdot
.45363 .65021 Mdot
.59525 .84637 Mdot
.4777 .33271 Mdot
.2597 .55124 Mdot
.63591 .72922 Mdot
.32067 .67432 Mdot
.27635 .35031 Mdot
.44135 .46215 Mdot
.46607 .20072 Mdot
.59152 .44678 Mdot
.42301 .17839 Mdot
.74816 .44258 Mdot
.55201 .64534 Mdot
.46288 .15452 Mdot
.47014 .66915 Mdot
.54437 .33274 Mdot
.4907 .24881 Mdot
.42461 .76708 Mdot
.5545 .47486 Mdot
.79577 .62151 Mdot
.76871 .57693 Mdot
.60329 .66783 Mdot
.63214 .61737 Mdot
.62532 .2752 Mdot
.49828 .40815 Mdot
.74798 .31802 Mdot
.31745 .30364 Mdot
.45765 .83766 Mdot
.44546 .17809 Mdot
.72684 .39748 Mdot
.36496 .22697 Mdot
.58114 .19234 Mdot
.45027 .24812 Mdot
.35242 .59645 Mdot
.7539 .71545 Mdot
.31438 .72217 Mdot
.7518 .39782 Mdot
.39468 .37418 Mdot
.56253 .57933 Mdot
.77788 .40102 Mdot
.34871 .38566 Mdot
.5053 .85542 Mdot
.6167 .6192 Mdot
.31134 .56895 Mdot
.52871 .24763 Mdot
.34703 .58211 Mdot
.38818 .64182 Mdot
.46329 .20027 Mdot
.64585 .20839 Mdot
.35104 .28385 Mdot
.84546 .52086 Mdot
.23363 .45378 Mdot
.20326 .65102 Mdot
.50032 .56689 Mdot
.30224 .56896 Mdot
.71693 .72571 Mdot
.29748 .71122 Mdot
.34387 .61407 Mdot
.37811 .39952 Mdot
.73342 .48817 Mdot
.61971 .36268 Mdot
.30856 .5334 Mdot
.27534 .3426 Mdot
.63535 .69655 Mdot
.28895 .59832 Mdot
.57499 .57427 Mdot
.53413 .18396 Mdot
.5863 .64451 Mdot
.3113 .68552 Mdot
.48485 .76078 Mdot
.21799 .30371 Mdot
.70294 .36973 Mdot
.6169 .2228 Mdot
.48698 .61551 Mdot
.55166 .47257 Mdot
.45274 .80604 Mdot
.66481 .37929 Mdot
.28581 .7028 Mdot
.19794 .36376 Mdot
.7801 .36032 Mdot
.2567 .28105 Mdot
.29285 .57345 Mdot
.45218 .33206 Mdot
.56635 .21642 Mdot
.29711 .46832 Mdot
.70806 .50307 Mdot
.30339 .24275 Mdot
.68433 .44775 Mdot
.32741 .58421 Mdot
.43868 .76767 Mdot
.35238 .31038 Mdot
.64678 .47002 Mdot
.67509 .44086 Mdot
.41043 .38695 Mdot
.21279 .72459 Mdot
.40893 .1896 Mdot
.33392 .66043 Mdot
.68415 .24244 Mdot
.5085 .66843 Mdot
.6601 .42585 Mdot
.42664 .64377 Mdot
.52522 .15649 Mdot
.3123 .54534 Mdot
.53257 .131 Mdot
.55465 .16094 Mdot
.57073 .81299 Mdot
.39763 .88613 Mdot
.53551 .71363 Mdot
.48784 .26954 Mdot
.58189 .3978 Mdot
.59792 .3715 Mdot
.46861 .82149 Mdot
.58986 .80606 Mdot
.50225 .68124 Mdot
.81247 .45338 Mdot
.48228 .15958 Mdot
.67735 .32225 Mdot
.77065 .43121 Mdot
.43979 .78219 Mdot
.48772 .54675 Mdot
.27074 .51452 Mdot
.4404 .54125 Mdot
.34463 .59632 Mdot
.29083 .25511 Mdot
.29327 .47796 Mdot
.51527 .87657 Mdot
.71664 .43199 Mdot
.60126 .76047 Mdot
.69353 .26299 Mdot
.59485 .32302 Mdot
.38587 .32583 Mdot
.38655 .74332 Mdot
.40914 .39376 Mdot
.36787 .743 Mdot
.41778 .48762 Mdot
.68676 .61421 Mdot
.35369 .74035 Mdot
.42037 .71147 Mdot
.71933 .33466 Mdot
.50061 .21881 Mdot
.25256 .65574 Mdot
.30434 .55812 Mdot
.64697 .4022 Mdot
.70353 .35919 Mdot
.68837 .24949 Mdot
.53562 .79352 Mdot
.82354 .39593 Mdot
.5533 .79672 Mdot
.45709 .32111 Mdot
.53074 .42991 Mdot
.39928 .35265 Mdot
.68132 .37794 Mdot
.47767 .32611 Mdot
.41881 .73151 Mdot
.71395 .26768 Mdot
.2536 .50142 Mdot
.69249 .55213 Mdot
.18338 .45383 Mdot
.80796 .38622 Mdot
.57084 .22351 Mdot
.55997 .76041 Mdot
.56243 .39767 Mdot
.15795 .56378 Mdot
.63138 .59064 Mdot
.68928 .33807 Mdot
.41834 .67126 Mdot
.73136 .60785 Mdot
.41996 .23441 Mdot
.55618 .81862 Mdot
.71984 .27145 Mdot
.39521 .76181 Mdot
.67713 .68047 Mdot
.60041 .50271 Mdot
.64697 .48621 Mdot
.18902 .43503 Mdot
.52658 .40789 Mdot
.40109 .31974 Mdot
.7242 .46157 Mdot
.32548 .45071 Mdot
.60129 .2439 Mdot
.74672 .66039 Mdot
.53735 .4137 Mdot
.68629 .72596 Mdot
.63 .72112 Mdot
.53508 .52566 Mdot
.34423 .17867 Mdot
.40451 .38412 Mdot
.53825 .73095 Mdot
.78797 .37277 Mdot
.64541 .42332 Mdot
.66119 .24736 Mdot
.38981 .72034 Mdot
.24107 .30338 Mdot
.58942 .16863 Mdot
.74583 .63896 Mdot
.39063 .18203 Mdot
.79811 .33005 Mdot
.2171 .33629 Mdot
.20668 .42019 Mdot
.46144 .6815 Mdot
.51521 .09813 Mdot
.64651 .56462 Mdot
.19114 .5108 Mdot
.28362 .47552 Mdot
.749 .52504 Mdot
.33941 .49312 Mdot
.47165 .3021 Mdot
.60106 .65837 Mdot
.3798 .51778 Mdot
.4192 .43648 Mdot
.25656 .26111 Mdot
.17242 .41251 Mdot
.2647 .25927 Mdot
.81436 .42208 Mdot
.39941 .17968 Mdot
.52427 .26601 Mdot
.35343 .33945 Mdot
.58013 .25532 Mdot
.50013 .41273 Mdot
.64601 .31442 Mdot
.53314 .7223 Mdot
.70662 .66629 Mdot
.3201 .61357 Mdot
.36875 .51332 Mdot
.29564 .26493 Mdot
.25841 .22474 Mdot
.24216 .43498 Mdot
.29239 .38259 Mdot
.48394 .58967 Mdot
.68254 .3627 Mdot
.39959 .48935 Mdot
.67838 .7134 Mdot
.69321 .25814 Mdot
.49034 .24742 Mdot
.70994 .34449 Mdot
.75812 .66151 Mdot
.62452 .51451 Mdot
.59295 .746 Mdot
.53356 .17691 Mdot
.55844 .28393 Mdot
.57712 .80284 Mdot
.55955 .35213 Mdot
.50202 .83754 Mdot
.78566 .59662 Mdot
.65273 .66356 Mdot
.72484 .3721 Mdot
.60652 .56235 Mdot
.66779 .31824 Mdot
.5368 .58687 Mdot
.53452 .23929 Mdot
.59116 .44496 Mdot
.66651 .31309 Mdot
.62191 .51577 Mdot
.32336 .2201 Mdot
.83431 .37805 Mdot
.16171 .46076 Mdot
.83687 .49398 Mdot
.42611 .49154 Mdot
.50262 .33875 Mdot
.75231 .30328 Mdot
.30022 .22645 Mdot
.61086 .1743 Mdot
.43248 .74573 Mdot
.76455 .53977 Mdot
.48175 .65157 Mdot
.16581 .47113 Mdot
.80445 .5763 Mdot
.62296 .20374 Mdot
.23757 .65861 Mdot
.41925 .60485 Mdot
.40373 .77696 Mdot
.1787 .48091 Mdot
.39669 .24362 Mdot
.25708 .37856 Mdot
.428 .32089 Mdot
.33861 .28178 Mdot
.2944 .5563 Mdot
.47888 .76717 Mdot
.67294 .37573 Mdot
.62815 .58731 Mdot
.57299 .30693 Mdot
.40053 .31623 Mdot
.41041 .37996 Mdot
.63489 .66398 Mdot
.30671 .48847 Mdot
.20545 .49507 Mdot
.46392 .7012 Mdot
.43867 .15272 Mdot
.52401 .7449 Mdot
.38615 .40902 Mdot
.66656 .40051 Mdot
.69867 .64481 Mdot
.37695 .74837 Mdot
.4656 .66736 Mdot
.47493 .17541 Mdot
.42281 .53173 Mdot
.65204 .40109 Mdot
.32677 .28843 Mdot
.68834 .29736 Mdot
.51569 .41285 Mdot
.35744 .67173 Mdot
.36311 .38126 Mdot
.54796 .51934 Mdot
.3434 .57714 Mdot
.29827 .48984 Mdot
.87574 .52893 Mdot
.52846 .65509 Mdot
.56824 .78406 Mdot
.48469 .17763 Mdot
.42957 .66303 Mdot
.36307 .51325 Mdot
.64795 .30212 Mdot
.73069 .33861 Mdot
.35653 .41154 Mdot
.65592 .54316 Mdot
.71004 .5123 Mdot
.7667 .63332 Mdot
.43377 .18833 Mdot
.38679 .2123 Mdot
.44767 .84052 Mdot
.33987 .49961 Mdot
.66637 .27546 Mdot
.73464 .35244 Mdot
.35697 .51914 Mdot
.30969 .58672 Mdot
.27003 .59492 Mdot
.3844 .17342 Mdot
.35882 .72839 Mdot
.82873 .49067 Mdot
.61157 .44647 Mdot
.76896 .4989 Mdot
.71039 .62401 Mdot
.75217 .41007 Mdot
.49144 .17873 Mdot
.26828 .34513 Mdot
.38605 .23919 Mdot
.39375 .42211 Mdot
.22684 .52676 Mdot
.16308 .48047 Mdot
.50306 .55933 Mdot
.36643 .29505 Mdot
.40252 .69377 Mdot
.4372 .34961 Mdot
.21941 .3018 Mdot
.74398 .3279 Mdot
.3371 .74687 Mdot
.41386 .67692 Mdot
.45049 .36312 Mdot
.48633 .3228 Mdot
.55398 .44839 Mdot
.33244 .67132 Mdot
.1783 .41978 Mdot
.75646 .41105 Mdot
.47042 .49149 Mdot
.31308 .30204 Mdot
.53822 .7332 Mdot
.53391 .18788 Mdot
.7229 .29406 Mdot
.54446 .55759 Mdot
.52907 .72804 Mdot
.60163 .48159 Mdot
.83059 .46929 Mdot
.58181 .63162 Mdot
.52273 .25973 Mdot
.23626 .60292 Mdot
.35669 .69938 Mdot
.70566 .64356 Mdot
.51048 .36484 Mdot
.44289 .76551 Mdot
.57228 .19287 Mdot
.46907 .86624 Mdot
.46898 .81188 Mdot
.24598 .26417 Mdot
.39704 .27938 Mdot
.35854 .70639 Mdot
.36319 .23883 Mdot
.45178 .87234 Mdot
.60189 .65021 Mdot
.33403 .23551 Mdot
.6009 .49548 Mdot
.46072 .17737 Mdot
.42856 .68076 Mdot
.29559 .69003 Mdot
.18356 .46171 Mdot
.39422 .17181 Mdot
.59801 .22496 Mdot
.50354 .18443 Mdot
.5666 .36844 Mdot
.35648 .18703 Mdot
.22694 .59255 Mdot
.60348 .67176 Mdot
.63818 .63748 Mdot
.43161 .73726 Mdot
.27921 .30302 Mdot
.38843 .58753 Mdot
.69914 .34252 Mdot
.59198 .70985 Mdot
.37252 .38723 Mdot
.36403 .25134 Mdot
.60762 .31438 Mdot
.37487 .70549 Mdot
.6635 .40353 Mdot
.6006 .18991 Mdot
.60256 .69904 Mdot
.7116 .60014 Mdot
.5412 .77161 Mdot
.80865 .48167 Mdot
.32881 .66651 Mdot
.52867 .67134 Mdot
.61272 .21998 Mdot
.79998 .55876 Mdot
.72349 .39031 Mdot
.8994 .49763 Mdot
.78205 .42484 Mdot
.28659 .59445 Mdot
.28184 .26832 Mdot
.70725 .2735 Mdot
.23262 .55295 Mdot
.44195 .82591 Mdot
.22845 .52003 Mdot
.65616 .33898 Mdot
.49201 .40654 Mdot
.32413 .19649 Mdot
.62192 .3521 Mdot
.29224 .25097 Mdot
.78281 .33954 Mdot
.33899 .27682 Mdot
.41448 .35639 Mdot
.67404 .58074 Mdot
.50035 .588 Mdot
.6043 .30395 Mdot
.40082 .22659 Mdot
.22678 .50986 Mdot
.68375 .60723 Mdot
.63913 .68585 Mdot
.65852 .54877 Mdot
.47832 .47828 Mdot
.51725 .72843 Mdot
.3524 .68588 Mdot
.68112 .4302 Mdot
.55517 .57431 Mdot
.68919 .35536 Mdot
.2808 .34364 Mdot
.4022 .24304 Mdot
.53427 .82647 Mdot
.39033 .66151 Mdot
.62736 .62507 Mdot
.45975 .21699 Mdot
.78905 .42192 Mdot
.39473 .70541 Mdot
.22433 .33827 Mdot
.39236 .74935 Mdot
.61146 .27608 Mdot
.56656 .23534 Mdot
.49054 .82745 Mdot
.78983 .67042 Mdot
.25393 .31624 Mdot
.22364 .53278 Mdot
.65633 .44352 Mdot
.43192 .27894 Mdot
.44912 .15898 Mdot
.73854 .38432 Mdot
.54325 .23217 Mdot
.47988 .55654 Mdot
.33775 .42243 Mdot
.32949 .27463 Mdot
.58664 .33772 Mdot
.57298 .4949 Mdot
.17811 .62141 Mdot
.36176 .49773 Mdot
.20837 .31239 Mdot
.46076 .63806 Mdot
.31337 .75651 Mdot
.63896 .52014 Mdot
.53069 .57337 Mdot
.57605 .47848 Mdot
.35278 .66396 Mdot
.26591 .61146 Mdot
.81408 .43535 Mdot
.53422 .83639 Mdot
.66472 .56841 Mdot
.71335 .40916 Mdot
.8203 .51629 Mdot
.45567 .20936 Mdot
.43245 .43735 Mdot
.79379 .43934 Mdot
.49971 .55551 Mdot
.70474 .6663 Mdot
.75473 .31081 Mdot
.3815 .65371 Mdot
.50527 .43418 Mdot
.68011 .3651 Mdot
.33021 .23989 Mdot
.57093 .1665 Mdot
.39537 .79655 Mdot
.41864 .48788 Mdot
.47457 .66984 Mdot
.53685 .29 Mdot
.43686 .196 Mdot
.63838 .44898 Mdot
.31706 .69682 Mdot
.70735 .36596 Mdot
.14484 .41515 Mdot
.18433 .39349 Mdot
.17826 .42245 Mdot
.66377 .41408 Mdot
.36409 .5644 Mdot
.22252 .56425 Mdot
.54884 .23378 Mdot
.3743 .65945 Mdot
.78205 .39662 Mdot
.69194 .34386 Mdot
.38855 .83577 Mdot
.37986 .33622 Mdot
.78741 .51877 Mdot
.3094 .2852 Mdot
.29665 .46136 Mdot
.44132 .6844 Mdot
.64345 .33559 Mdot
.41084 .51586 Mdot
.47173 .62198 Mdot
.36953 .70012 Mdot
.2991 .66585 Mdot
.54004 .23169 Mdot
.3564 .37746 Mdot
.44219 .49134 Mdot
.49344 .21286 Mdot
.37937 .53094 Mdot
.71739 .62369 Mdot
.70681 .61629 Mdot
.50962 .50086 Mdot
.62753 .56593 Mdot
.43698 .46173 Mdot
.55246 .52799 Mdot
.58863 .49632 Mdot
.17836 .53429 Mdot
.69279 .44439 Mdot
.37386 .52987 Mdot
.30185 .73443 Mdot
.35959 .52361 Mdot
.28418 .22936 Mdot
.67288 .71755 Mdot
.32653 .29178 Mdot
.75808 .61992 Mdot
.72921 .70248 Mdot
.22847 .71513 Mdot
.20447 .4005 Mdot
.45429 .55444 Mdot
.37836 .57123 Mdot
.29275 .50903 Mdot
.67455 .54323 Mdot
.63388 .68438 Mdot
.2642 .38007 Mdot
.54621 .71448 Mdot
.59555 .26352 Mdot
.29565 .56837 Mdot
.78067 .49538 Mdot
.39621 .46856 Mdot
.40099 .16476 Mdot
.63151 .62064 Mdot
.14367 .53179 Mdot
.52762 .34307 Mdot
.4514 .24265 Mdot
.7443 .28985 Mdot
.39522 .78685 Mdot
.66997 .67257 Mdot
.81298 .61532 Mdot
.41871 .38491 Mdot
.44282 .48909 Mdot
.3062 .53405 Mdot
.64134 .27137 Mdot
.69597 .46406 Mdot
.62549 .40269 Mdot
.43448 .60008 Mdot
.59834 .79073 Mdot
.51155 .73672 Mdot
.36188 .55791 Mdot
.40247 .52691 Mdot
.59936 .23348 Mdot
.27198 .65679 Mdot
.49933 .55351 Mdot
.44604 .21629 Mdot
.35426 .40615 Mdot
.2914 .56565 Mdot
.21369 .35681 Mdot
.73453 .35764 Mdot
.53343 .15158 Mdot
.45386 .29247 Mdot
.50478 .57887 Mdot
.26117 .65486 Mdot
.36757 .68734 Mdot
.2723 .36013 Mdot
.68847 .25444 Mdot
.65744 .39126 Mdot
.29351 .70144 Mdot
.663 .31152 Mdot
.49645 .3139 Mdot
.56712 .62594 Mdot
.46922 .74877 Mdot
.3506 .8102 Mdot
.21098 .43581 Mdot
.42985 .79815 Mdot
.35653 .59103 Mdot
.53748 .7297 Mdot
.37395 .50881 Mdot
.71914 .55105 Mdot
.3494 .3972 Mdot
.65472 .70201 Mdot
.48659 .14901 Mdot
.69727 .2595 Mdot
.46691 .59333 Mdot
.59351 .5583 Mdot
.57024 .45893 Mdot
.38802 .38129 Mdot
.52535 .51723 Mdot
.42401 .36188 Mdot
.51679 .46673 Mdot
.38094 .78231 Mdot
.3691 .66672 Mdot
.46441 .30368 Mdot
.43502 .17011 Mdot
.54361 .15164 Mdot
.34611 .19711 Mdot
.65344 .45592 Mdot
.3491 .5605 Mdot
.22527 .31783 Mdot
.30284 .34591 Mdot
.5989 .18701 Mdot
.24597 .33419 Mdot
.8774 .50831 Mdot
.39655 .23215 Mdot
.41281 .7026 Mdot
.57873 .81121 Mdot
.28953 .62224 Mdot
.7606 .32626 Mdot
.60353 .67552 Mdot
.68563 .53996 Mdot
.76782 .33354 Mdot
.20669 .71267 Mdot
.20388 .43338 Mdot
.30608 .67734 Mdot
.46912 .2588 Mdot
.48825 .5012 Mdot
.55574 .69691 Mdot
.50532 .40171 Mdot
.59699 .61409 Mdot
.68173 .67311 Mdot
.69404 .35319 Mdot
.4266 .27012 Mdot
.5567 .70286 Mdot
.60291 .29852 Mdot
.63623 .27757 Mdot
.75678 .40288 Mdot
.41391 .22899 Mdot
.26993 .37356 Mdot
.49577 .4404 Mdot
.37388 .55641 Mdot
.68507 .50061 Mdot
.6883 .62373 Mdot
.46611 .42521 Mdot
.6595 .67586 Mdot
.25774 .62409 Mdot
.24604 .26824 Mdot
.70602 .5497 Mdot
.73401 .33185 Mdot
.35617 .48786 Mdot
.34216 .67196 Mdot
.53801 .20425 Mdot
.42835 .76629 Mdot
.564 .70988 Mdot
.29217 .47793 Mdot
.42089 .18575 Mdot
.37997 .7384 Mdot
.70122 .32369 Mdot
.19261 .59103 Mdot
.45963 .6107 Mdot
.21205 .49082 Mdot
.50471 .25329 Mdot
.40737 .75292 Mdot
.28864 .56836 Mdot
.43471 .71315 Mdot
.55757 .6394 Mdot
.39615 .73751 Mdot
.79035 .37453 Mdot
.64115 .2618 Mdot
.29231 .30131 Mdot
.39532 .20605 Mdot
.61567 .63084 Mdot
.70684 .34186 Mdot
.44867 .70966 Mdot
.56307 .6731 Mdot
.26286 .66504 Mdot
.4361 .15893 Mdot
.54091 .51071 Mdot
.61242 .35496 Mdot
.44178 .35226 Mdot
.32071 .3623 Mdot
.36089 .66062 Mdot
.59932 .52633 Mdot
.54946 .78358 Mdot
.29698 .55079 Mdot
.50393 .75648 Mdot
.60416 .72041 Mdot
.64708 .34895 Mdot
.39294 .52578 Mdot
.24616 .5317 Mdot
.70777 .50853 Mdot
.60917 .69857 Mdot
.4636 .44497 Mdot
.61246 .37106 Mdot
.64224 .48192 Mdot
.20775 .46977 Mdot
.19969 .43532 Mdot
.45219 .21417 Mdot
.75025 .35267 Mdot
.38739 .69342 Mdot
.24427 .33399 Mdot
.26971 .60901 Mdot
.36338 .32475 Mdot
.47428 .78638 Mdot
.46349 .32892 Mdot
.72145 .54818 Mdot
.37001 .52724 Mdot
.43777 .20417 Mdot
.38686 .29856 Mdot
.59463 .33454 Mdot
.52345 .54598 Mdot
.55623 .20699 Mdot
.47726 .53608 Mdot
.7471 .2956 Mdot
.2921 .62171 Mdot
.67093 .37656 Mdot
.40776 .64117 Mdot
.60739 .49263 Mdot
.48393 .81925 Mdot
.52048 .16248 Mdot
.54323 .82586 Mdot
.57961 .40366 Mdot
.4218 .7908 Mdot
.22029 .54538 Mdot
.77513 .33431 Mdot
.66407 .3637 Mdot
.5227 .51839 Mdot
.39563 .47 Mdot
.49516 .62327 Mdot
.61626 .72971 Mdot
.73226 .55212 Mdot
.28467 .36476 Mdot
.74777 .49307 Mdot
.65913 .6974 Mdot
.43801 .44523 Mdot
.21754 .61398 Mdot
.40532 .19787 Mdot
.37458 .41949 Mdot
.52173 .57141 Mdot
.72917 .63054 Mdot
.64246 .3578 Mdot
.81745 .68942 Mdot
.21881 .30135 Mdot
.44408 .35068 Mdot
.59079 .45969 Mdot
.63056 .39333 Mdot
.63637 .55344 Mdot
.26323 .39154 Mdot
.4483 .21162 Mdot
.45762 .66542 Mdot
.75759 .55023 Mdot
.43308 .73161 Mdot
.35051 .65491 Mdot
.5782 .3233 Mdot
.41658 .59458 Mdot
.26697 .24406 Mdot
.79936 .42964 Mdot
.37045 .68012 Mdot
.85503 .61325 Mdot
.44877 .75296 Mdot
.36051 .481 Mdot
.59064 .21728 Mdot
.32655 .21712 Mdot
.65129 .41939 Mdot
.73625 .59978 Mdot
.19479 .44595 Mdot
.66448 .38143 Mdot
.66177 .29567 Mdot
.54027 .77083 Mdot
.51163 .76101 Mdot
.5861 .65836 Mdot
.73135 .69985 Mdot
.19151 .54445 Mdot
.28769 .32091 Mdot
.36879 .21466 Mdot
.66165 .71937 Mdot
.40241 .84262 Mdot
.52463 .15649 Mdot
.63511 .31396 Mdot
.55655 .72228 Mdot
.61352 .22517 Mdot
.60764 .4138 Mdot
.2825 .48506 Mdot
.6715 .71189 Mdot
.35061 .4333 Mdot
.7145 .70798 Mdot
.49881 .79632 Mdot
.66699 .31593 Mdot
.27933 .4745 Mdot
.54971 .50533 Mdot
.43962 .22569 Mdot
.61859 .76469 Mdot
.6833 .39479 Mdot
.76065 .56187 Mdot
.59235 .38953 Mdot
.47172 .20854 Mdot
.59785 .20736 Mdot
.52565 .51133 Mdot
.20517 .70637 Mdot
.30127 .25036 Mdot
.44262 .77693 Mdot
.49926 .33265 Mdot
.48184 .14445 Mdot
.49565 .50992 Mdot
.2317 .35066 Mdot
.77696 .36754 Mdot
.70409 .59972 Mdot
.2505 .63969 Mdot
.45289 .33124 Mdot
.21238 .3816 Mdot
.36783 .28888 Mdot
.28988 .46359 Mdot
.68692 .66766 Mdot
.66553 .3993 Mdot
.6098 .76415 Mdot
.58125 .34995 Mdot
.40353 .33417 Mdot
.3669 .53912 Mdot
.27966 .24283 Mdot
.53432 .30187 Mdot
.45586 .46737 Mdot
.55547 .35515 Mdot
.54042 .83083 Mdot
.83148 .61605 Mdot
.40814 .33164 Mdot
.37083 .73884 Mdot
.70015 .3451 Mdot
.57562 .24659 Mdot
.20257 .41615 Mdot
.43383 .90817 Mdot
.73393 .27759 Mdot
.32026 .48994 Mdot
.2222 .48275 Mdot
.68113 .40681 Mdot
.35322 .19718 Mdot
.76014 .65739 Mdot
.69958 .63854 Mdot
.54335 .8465 Mdot
.61724 .42372 Mdot
.49788 .42081 Mdot
.81139 .4028 Mdot
.52848 .16212 Mdot
.62377 .77443 Mdot
.45376 .16031 Mdot
.41866 .34321 Mdot
.51164 .33474 Mdot
.61813 .86449 Mdot
.4544 .18838 Mdot
.40819 .38251 Mdot
.50844 .8406 Mdot
.26669 .52642 Mdot
.48869 .41677 Mdot
.5435 .67731 Mdot
.73245 .3822 Mdot
.64713 .28596 Mdot
.39267 .1725 Mdot
.35571 .56786 Mdot
.66138 .67686 Mdot
.41447 .63921 Mdot
.57597 .4818 Mdot
.53641 .39841 Mdot
.42394 .63849 Mdot
.62029 .27959 Mdot
.51305 .50395 Mdot
.40367 .64541 Mdot
.7514 .41818 Mdot
.83781 .41513 Mdot
.39875 .2718 Mdot
.48614 .60264 Mdot
.56118 .4102 Mdot
.37134 .40849 Mdot
.60467 .30195 Mdot
.58001 .26841 Mdot
.77748 .35155 Mdot
.79505 .29975 Mdot
.66233 .52994 Mdot
.48314 .29821 Mdot
.38528 .49756 Mdot
.27972 .35973 Mdot
.38224 .25535 Mdot
.41139 .68075 Mdot
.62259 .69515 Mdot
.43633 .33113 Mdot
.4061 .33 Mdot
.43194 .60089 Mdot
.16703 .36435 Mdot
.51235 .38555 Mdot
.24992 .36243 Mdot
.58002 .18507 Mdot
.71612 .62719 Mdot
.42162 .26553 Mdot
.4186 .40296 Mdot
.22809 .57624 Mdot
.4866 .51031 Mdot
.52297 .48301 Mdot
.70952 .61814 Mdot
.37126 .19755 Mdot
.38876 .29677 Mdot
.28014 .31785 Mdot
.47382 .36444 Mdot
.69104 .43637 Mdot
.29238 .66921 Mdot
.19257 .4103 Mdot
.38487 .3628 Mdot
.59216 .17857 Mdot
.70567 .59194 Mdot
.74967 .48111 Mdot
.44993 .25767 Mdot
.28387 .25417 Mdot
.46459 .80693 Mdot
.3637 .26466 Mdot
.35222 .75752 Mdot
.50495 .70185 Mdot
.61019 .31591 Mdot
.67151 .57414 Mdot
.47043 .30275 Mdot
.2672 .54078 Mdot
.31369 .19359 Mdot
.19129 .42111 Mdot
.48799 .68333 Mdot
.68543 .59964 Mdot
.34343 .32433 Mdot
.5683 .48449 Mdot
.87492 .56714 Mdot
.79823 .61588 Mdot
.26198 .248 Mdot
.62923 .26097 Mdot
.37909 .47722 Mdot
.3826 .71508 Mdot
.52159 .43366 Mdot
.65292 .60367 Mdot
.35908 .19743 Mdot
.4304 .30164 Mdot
.49899 .78958 Mdot
.50445 .41183 Mdot
.31396 .73129 Mdot
.43429 .50635 Mdot
.59449 .5607 Mdot
.59681 .57494 Mdot
.44865 .82423 Mdot
.56777 .19734 Mdot
.47896 .51277 Mdot
.86341 .54451 Mdot
.37954 .22698 Mdot
.47729 .1751 Mdot
.65565 .54405 Mdot
.35821 .79366 Mdot
.38354 .58068 Mdot
.4178 .50234 Mdot
.46738 .69772 Mdot
.5764 .37644 Mdot
.4047 .7468 Mdot
.59142 .25317 Mdot
.28105 .63834 Mdot
.46755 .59521 Mdot
.87618 .36984 Mdot
.63841 .30544 Mdot
.37875 .39876 Mdot
.4515 .76614 Mdot
.46022 .16779 Mdot
.66672 .50907 Mdot
.82728 .41427 Mdot
.56204 .57085 Mdot
.53566 .3766 Mdot
.35967 .37348 Mdot
.45877 .24642 Mdot
.44231 .73243 Mdot
.19672 .66405 Mdot
.78408 .41094 Mdot
.72214 .50906 Mdot
.55354 .5747 Mdot
.35695 .51671 Mdot
.33754 .49282 Mdot
.74808 .64999 Mdot
.85028 .46483 Mdot
.46473 .49891 Mdot
.43978 .1945 Mdot
.26316 .74576 Mdot
.67244 .29036 Mdot
.36344 .18803 Mdot
.37488 .59423 Mdot
.32205 .58971 Mdot
.60318 .29433 Mdot
.70676 .42663 Mdot
.60396 .57226 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0R_ooool2o`00
01Oooooo0ol0002Sooooo`007?ooool2o`0008_ooooo0_l0000Gooooo`Co0000X_ooool001cooooo
00?o0000ooooooooool0YOooool2o`000:;ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
/_ooool2o`0009Gooooo000Looooo`03o`000?oooooooooo0;;ooooo0_l0002Eooooo`007?ooool0
0ol0003oooooooooo`2gooooo`;o00003_ooool2o`00083ooooo000Looooo`03o`000?oooooooooo
0;Oooooo0_l00003ooooo`;o00000_ooool2o`0000Gooooo0_l00020ooooo`007?ooool00ol0003o
ooooooooo`2Yooooo`;o00004?ooool3o`0000;ooooo0_l00027ooooo`007?ooool00ol0003ooooo
ooooo`2Yooooo`;o00004?ooool2o`0000Sooooo0_l00022ooooo`007?ooool00ol0003ooooooooo
o`35ooooo`;o0000P_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`2Iooooo`;o0000[_ooool001cooooo00?o0000ooooooooool0VOooool2o`0003Ko
oooo0_l0001fooooo`007?ooool00ol0003oooooooooo`2Jooooo`;o00006Oooool2o`0001[ooooo
0_l0001fooooo`007?ooool2o`0008cooooo0_l0000=ooooo`;o00003_ooool2o`000003ooooool0
003o000000Kooooo0_l0002Booooo`007?ooool00ol0003oooooooooo`2:ooooo`?o00001_ooool2
o`0001;ooooo0_l000001?oooooo0000o`000?ooool2o`0009[ooooo000Looooo`03o`000?oooooo
oooo08[ooooo0_l00002ooooo`Co000000?oooooo`000?l000001?ooool2o`0000Gooooo0_l00002
ooooo`;o000000?oooooo`000?l00000X?ooool001cooooo00?o0000ooooooooool0R_ooool2o`00
00;ooooo1?l00007ooooo`;o00001Oooool2o`0000;ooooo0ol000000ooooooo0000o`000006oooo
o`;o00001Oooool2o`0000Kooooo0_l00028ooooo`007?ooool00ol0003oooooooooo`1oooooo`;o
00003oooool2o`0001?ooooo0_l000000ooooooo0000o`000006ooooo`;o00001Oooool2o`0000Ko
oooo0_l00028ooooo`007?ooool00ol0003oooooooooo`1gooooo`;o00001_ooool2o`0000Oooooo
0_l00004ooooo`;o00000_ooool2o`0002;ooooo0_l00004ooooo`;o0000Roooool001cooooo00?o
0000ooooooooool0Moooool2o`0000?ooooo0_l0000:ooooo`Co00000_ooool2o`0000;ooooo0_l0
000Dooooo`Co00001oooool2o`000003ooooool0003o000000Cooooo0_l0002;ooooo`007?ooool0
0ol0003oooooooooo`1iooooo`;o000000?oooooo`000?l000003?ooool2o`0000Wooooo1?l00005
ooooo`;o00001_ooool6o`0000Oooooo0_l0000>ooooo`;o0000Q?ooool001cooooo00?o0000oooo
ooooool0NOooool2o`000003ooooool0003o000000Sooooo0_l00005ooooo`;o00000oooool2o`00
0003ooooool0003o000000;o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l000001?oo
oooo0000o`000?ooool4o`0001Kooooo0_l00024ooooo`007?ooool00ol0003oooooooooo`1/oooo
o`;o00004?ooool2o`0000Cooooo1?l00003ooooo`Co00000oooool2o`0000?ooooo0_l000000ooo
oooo0000o`000002o`0000Gooooo0_l00005ooooo`?o00001Oooool2o`0000Wooooo0_l0002:oooo
o`007?ooool00ol0003oooooooooo`1/ooooo`;o00003Oooool2o`000004ooooool0003o0000oooo
o`Go00001Oooool2o`0000oooooo0_l00002ooooo`;o000000?oooooo`000?l000001Oooool3o`00
00;ooooo0_l000000ooooooo0000o`000009ooooo`;o00001oooool2o`0001[ooooo0_l0001Uoooo
o`007?ooool00ol0003oooooooooo`1Uooooo`;o00002Oooool4o`0000Oooooo0_l00004ooooo`?o
000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00000Cooooo`;o000000?oooooo`00
0?l000001Oooool3o`0000;ooooo0_l00004ooooo`;o00000_ooool2o`0000Cooooo0_l00005oooo
o`Co00006?ooool2o`0006Gooooo000Looooo`03o`000?oooooooooo06Gooooo0_l00009ooooo`Co
00003Oooool2o`0000;ooooo0_l000000ooooooo0000o`000003o`0000?ooooo0_l0000Hooooo`?o
00000_ooool2o`0000Cooooo0_l00002ooooo`;o00001?ooool4o`0000?ooooo1?l0001oooooo`00
00Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000oooo
ooooool0HOooool3o`0000kooooo0_l0000=ooooo`;o00001_ooool2o`0000Gooooo0_l0000Hoooo
o`;o00002_ooool2o`000003ooooool0003o000000;o00000_ooool4o`0008Kooooo00001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_oo
ool00ol0003oooooooooo`1Qooooo`?o00000_ooool2o`0000cooooo0_l00003ooooo`;o00003ooo
ool3o`0001[ooooo0_l0000=ooooo`;o000000?oooooo`000?l000000_l0002<ooooo`0000?ooooo
oa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000
ooooooooool0I_ooool2o`0000Gooooo1_l000001?oooooo0000o`000?l00002ooooo`;o00001Ooo
ool2o`0000Sooooo0ol0000Jooooo`;o00003?ooool2o`0000Sooooo0_l00008ooooo`;o0000O_oo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06
ooooo`?o0000KOooool6o`0000;ooooo0_l00009ooooo`;o00004Oooool3o`0001gooooo1?l00008
ooooo`Co00000_ooool2o`0000;ooooo0_l0001nooooo`0000?oooooo`000?ooool00_ooool00ol0
003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0OOooool2o`00
00_ooooo0_l00007ooooo`?o00003Oooool3o`0000Gooooo0_l00006ooooo`;o00000_ooool2o`00
00Kooooo1?l00002ooooo`Co00000oooool2o`000003ooooool0003o000007Sooooo00000ooooooo
410@ooooo`02ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`1booooo`;o00002Oooool2o`0000_ooooo0_l00009ooooo`;o00003?ooool3o`0000Go
oooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo0_l000000ooooooo0000o`000004ooooo`;o
00000oooool5o`0007Sooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj
^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo07;ooooo0_l00006ooooo`;o00004_ooool4
o`0000?ooooo0_l00003ooooo`;o00005Oooool2o`0000_ooooo0_l0000>ooooo`;o0000NOooool0
0006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo
00?o0000ooooooooool0M?ooool2o`0000Cooooo0_l0000Booooo`Go00001oooool2o`000003oooo
ool0003o000000Gooooo0_l0000;ooooo`;o0000U_ooool001cooooo00?o0000ooooooooool0I_oo
ool2o`0000cooooo0_l0000Fooooo`Wo00002?ooool2o`000003ooooool0003o000000;ooooo0_l0
000;ooooo`;o000000?oooooo`000?l000001_ooool2o`0001;ooooo0_l000000ooooooo0000o`00
000Jooooo`;o0000F?ooool001cooooo00?o0000ooooooooool0F_ooool2o`0000Wooooo0ol00005
ooooo`;o00003Oooool2o`0000Gooooo0_l00007ooooo`?o00000oooool3o`0000[ooooo0ol0000B
ooooo`;o00000_ooool2o`0000;ooooo0_l00005ooooo`;o00002Oooool4o`000004ooooool0003o
0000o`0001Wooooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`1Jooooo`;o00002Oooool2
o`000003ooooool0003o000000?ooooo0_l0000=ooooo`;o00001Oooool2o`0001[ooooo0_l0000:
ooooo`;o00002Oooool4o`0000Wooooo1?l00007ooooo`;o00001?ooool2o`0007?ooooo000Loooo
o`03o`000?oooooooooo053ooooo0_l0000<ooooo`;o00000_ooool2o`0000Cooooo0_l00005oooo
o`;o00000_ooool2o`0000?ooooo0_l00004ooooo`;o00002oooool2o`0001kooooo0_l00009oooo
o`?o00001Oooool2o`0000Cooooo0ol00003ooooo`;o00001oooool4o`0007;ooooo000Looooo`03
o`000?oooooooooo053ooooo0_l00007ooooo`;o00000oooool2o`0000;ooooo0_l0000;ooooo`;o
00000_ooool2o`0000?ooooo0_l00004ooooo`;o00000oooool2o`0000Kooooo0_l0000Zooooo`;o
00001Oooool2o`0000Cooooo0_l00004ooooo`;o00001oooool4o`0007;ooooo000Looooo`03o`00
0?oooooooooo05Wooooo0_l00002ooooo`;o00007_ooool2o`0000Cooooo0_l0000Wooooo`Go0000
3_ooool2o`0008Sooooo000Looooo`03o`000?oooooooooo05gooooo0_l0000:ooooo`;o00004_oo
ool2o`0000Kooooo0_l0000:ooooo`;o00005?ooool2o`0000?ooooo1Ol00003ooooo`;o00002Ooo
ool2o`0001?ooooo0_l0001cooooo`007?ooool00ol0003oooooooooo`1Xooooo`?o00001oooool2
o`0000Kooooo0_l00009ooooo`;o00002_ooool2o`0001Cooooo0_l000001?oooooo0000o`000?oo
ool4o`0000?ooooo0_l0000Dooooo`;o00002?ooool2o`0007?ooooo000Looooo`03o`000?oooooo
oooo05Oooooo0_l00006ooooo`;o00001oooool2o`0000Sooooo0_l00006ooooo`;o00000oooool2
o`0000kooooo0_l0000Iooooo`;o00001_ooool2o`0000Oooooo0_l00007ooooo`;o00000_ooool4
o`0000Cooooo0_l00002ooooo`;o00000oooool3o`0006gooooo000Looooo`03o`000?oooooooooo
05?ooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo0_l0000Looooo`Co00003_ooool2o`00
00Sooooo0_l0000;ooooo`;o00001Oooool2o`0000?ooooo0_l00007ooooo`;o00000oooool2o`00
00;ooooo0_l00002ooooo`;o00001_ooool2o`0000;ooooo0_l00003ooooo`?o0000KOooool001co
oooo00?o0000ooooooooool0DOooool4o`0000Kooooo0_l0000Pooooo`;o00000oooool2o`0000Ko
oooo0_l00003ooooo`Co00001_ooool2o`000003ooooool0003o000000Sooooo1_l000000ooooooo
0000o`000005ooooo`Go00001oooool3o`0000cooooo0_l00002ooooo`?o00001?ooool2o`0006go
oooo000Looooo`;o0000D_ooool2o`0000Sooooo0_l000000ooooooo0000o`00000?ooooo`;o0000
0_ooool2o`0000;ooooo0_l00009ooooo`;o00001_ooool2o`0000?ooooo1?l00009ooooo`;o0000
2_ooool4o`0000Sooooo1Ol00008ooooo`;o00003?ooool2o`0000;ooooo0_l00003ooooo`;o0000
0_ooool2o`0006_ooooo000Looooo`03o`000?oooooooooo05Sooooo0_l000001?oooooo0000o`00
0?ooool2o`0000[ooooo1?l000000ooooooo0000o`000002ooooo`;o00000_ooool3o`0001[ooooo
0_l0000:ooooo`;o00005oooool2o`000003ooooool0003o000000Cooooo0_l0000?ooooo`;o0000
0oooool2o`000004ooooool0003o0000o`0006_ooooo000Looooo`03o`000?oooooooooo05Sooooo
0_l000000ooooooo0000o`000007ooooo`;o00001?ooool4o`0000[ooooo0_l00004ooooo`;o0000
3_ooool2o`000004ooooool0003o0000ooooo`;o00002_ooool2o`0000[ooooo0_l0000;ooooo`;o
000000?oooooo`000?l000001?ooool2o`0001Oooooo1?l0001Zooooo`007?ooool00ol0003ooooo
ooooo`1@ooooo`Co00004?ooool2o`0001Cooooo0_l00002ooooo`;o00001Oooool2o`0000Oooooo
0_l000000ooooooo0000o`000002ooooo`;o00003oooool2o`0000Cooooo0_l0000<ooooo`;o0000
1Oooool2o`0000Kooooo0_l0000>ooooo`;o00000_ooool6o`0006Kooooo000Looooo`03o`000?oo
oooooooo04cooooo0_l00002ooooo`Co00007_ooool2o`000003ooooool0003o000000?ooooo0_l0
0009ooooo`;o00003_ooool2o`0000oooooo0_l0000@ooooo`Co00000_ooool2o`000003ooooool0
003o000000Kooooo0_l000000ooooooo0000o`00000;ooooo`;o00000_ooool6o`0000Gooooo0_l0
001Oooooo`007?ooool00ol0003oooooooooo`1;ooooo`?o00003_ooool2o`0001Cooooo0_l00000
0ooooooo0000o`00000>ooooo`?o00006Oooool2o`000004ooooool0003o0000ooooo`;o00003ooo
ool2o`0000Cooooo0_l0000<ooooo`;o00000_ooool2o`0000_ooooo0_l00005ooooo`;o00000_oo
ool2o`0005oooooo000Looooo`03o`000?oooooooooo04_ooooo0ol0000:ooooo`;o00000_ooool2
o`0001Sooooo0_l0000=ooooo`Co00004_ooool2o`0000Cooooo0_l000001?oooooo0000o`000?oo
ool2o`00013ooooo0_l0000<ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`Co00006Ooo
ool2o`0004Sooooo000Looooo`03o`000?oooooooooo04cooooo0_l0000:ooooo`;o00001_ooool4
o`0001;ooooo0_l000001?oooooo0000o`000?ooool4o`0000Oooooo0_l0000;ooooo`;o00001Ooo
ool2o`0000;ooooo0_l00003ooooo`;o00004oooool3o`0000_ooooo0_l00002ooooo`Co00002_oo
ool2o`0000Oooooo0_l00002ooooo`;o00005oooool2o`0004Sooooo000Looooo`03o`000?oooooo
oooo063ooooo1?l00003ooooo`;o000000?oooooo`000?l000003Oooool2o`000003ooooool0003o
000000?o00004oooool2o`000003ooooool0003o000000Kooooo1?l0000=ooooo`;o00002?ooool2
o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o00000_ooool4o`0000Kooooo0_l00002
ooooo`Co00001Oooool2o`000004ooooool0003o0000o`00067ooooo000Looooo`03o`000?oooooo
oooo05gooooo0_l00002ooooo`;o00001?ooool2o`000003ooooool0003o0000017ooooo1?l00004
ooooo`;o00000_ooool2o`0000Wooooo0_l000000ooooooo0000o`000002ooooo`;o00001?ooool2
o`0000gooooo0_l0000;ooooo`;o00001?ooool2o`000004ooooool0003o0000o`0000;ooooo0_l0
0004ooooo`;o00000_ooool3o`0000?ooooo0_l000000ooooooo0000o`000005ooooo`;o00001?oo
ool2o`0005cooooo000Looooo`03o`000?oooooooooo053ooooo0_l00003ooooo`;o00001_ooool2
o`0000_ooooo0ol00003ooooo`;o00002oooool2o`0000Kooooo0_l00002ooooo`;o00004?ooool2
o`0002Wooooo0_l00003ooooo`;o00001?ooool2o`0000?ooooo0_l00006ooooo`;o00002Oooool4
o`0005cooooo000Looooo`03o`000?oooooooooo053ooooo0_l00002ooooo`?o00002_ooool2o`00
00Oooooo0ol000000ooooooo0000o`000002o`0000_ooooo0_l00003ooooo`;o0000;_ooool2o`00
01[ooooo0_l00004ooooo`;o00004oooool2o`0005kooooo000Looooo`03o`000?oooooooooo05Co
oooo0_l0000;ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`;o00001?ooool2o`0000Oo
oooo0_l00003ooooo`;o00008Oooool2o`0000_ooooo0_l00007ooooo`;o00004Oooool2o`0000Co
oooo0_l0000@ooooo`Co0000Goooool001cooooo00?o0000ooooooooool0AOooool2o`0001Cooooo
0_l00004ooooo`;o00000oooool2o`0000;ooooo0ol00007ooooo`;o00005_ooool6o`0000Sooooo
0_l00004ooooo`?o000000Coooooo`000?l0003o00001?ooool2o`0000kooooo0_l0000Booooo`?o
00001Oooool2o`0000gooooo1Ol00003ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0
AOooool2o`0000Oooooo0_l00003ooooo`;o00001_ooool2o`0000Wooooo0_l00003ooooo`;o0000
1_ooool2o`0000;ooooo0_l0000@ooooo`;o000000?oooooo`000?l000001?l00008ooooo`;o0000
1?ooool3o`000003ooooool0003o000000Gooooo0_l00005ooooo`;o00000_ooool2o`0000Sooooo
0_l0000=ooooo`?o00001Oooool2o`0000Oooooo0_l00005ooooo`Co00000oooool2o`0005Wooooo
000Looooo`03o`000?oooooooooo04kooooo0_l00003ooooo`;o00007_ooool2o`0000;ooooo0_l0
00001?oooooo0000o`000?l00008ooooo`;o00000_ooool2o`0000Gooooo0_l00007ooooo`;o0000
3?ooool2o`0000Sooooo0ol00002ooooo`;o00002?ooool2o`00017ooooo0_l00003ooooo`;o0000
0_ooool2o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000
o`00000Dooooo`;o0000?oooool001cooooo0_l00014ooooo`;o00005_ooool2o`0000Oooooo0_l0
000>ooooo`;o00001?ooool3o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l000003ooo
ool2o`0000Sooooo0_l00002ooooo`;o00002?ooool2o`0000Kooooo0_l00005ooooo`;o00002Ooo
ool2o`000003ooooool0003o000000?ooooo1?l000001?oooooo0000o`000?ooool3o`0000Kooooo
0_l00005ooooo`Ko000000?oooooo`000?l000002_ooool2o`0000Sooooo0_l0000oooooo`007?oo
ool00ol0003oooooooooo`13ooooo`?o00001Oooool2o`0000[ooooo0_l00002ooooo`;o00001Ooo
ool4o`0000?ooooo0_l00009ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o00001ooo
ool2o`0000Wooooo1?l00002ooooo`;o00002?ooool3o`0000Cooooo0_l0000=ooooo`;o00001_oo
ool2o`0000Sooooo0_l000001?oooooo0000o`000?l00004ooooo`;o00001?ooool2o`0000Cooooo
0_l000000ooooooo0000o`000007ooooo`;o00000_ooool2o`0000_ooooo0_l00019ooooo`007?oo
ool00ol0003oooooooooo`13ooooo`?o00001Oooool2o`0000[ooooo0_l00002ooooo`;o00001Ooo
ool3o`0000Cooooo1?l00002ooooo`;o00001_ooool4o`0001Sooooo1?l00002ooooo`;o00000ooo
ool2o`0000Cooooo1?l00002ooooo`;o00002_ooool2o`0000Gooooo0_l00002ooooo`;o00002Ooo
ool2o`000003ooooool0003o0000013ooooo0_l0000>ooooo`;o0000E_ooool001cooooo00?o0000
ooooooooool0@_ooool2o`0000gooooo0_l00008ooooo`;o00000oooool2o`0000Gooooo0_l00000
1?oooooo0000o`000?l00002ooooo`;o000000?oooooo`000?l000004_ooool2o`0000gooooo0_l0
0002ooooo`;o00000oooool2o`0000Gooooo1?l0000=ooooo`;o00001Oooool2o`0000;ooooo0_l0
0009ooooo`;o00004oooool2o`0000gooooo0ol0001Fooooo`007?ooool00ol0003oooooooooo`10
ooooo`Co00001Oooool3o`0000Gooooo0_l0000=ooooo`;o00001Oooool2o`0000Kooooo0_l00000
0ooooooo0000o`00000Booooo`?o00000_ooool3o`0000Gooooo1?l00004ooooo`;o000000?ooooo
o`000?l000001Oooool4o`0001;ooooo0_l00002ooooo`Go00001oooool2o`0000Oooooo0ol0000D
ooooo`Co000000?oooooo`000?l000000ol0001Dooooo`007?ooool00ol0003oooooooooo`10oooo
o`;o00001oooool3o`0000?ooooo0_l0000]ooooo`;o00001oooool7o`0000;ooooo1Ol000000ooo
oooo0000o`000003ooooo`;o000000?oooooo`000?l000006oooool2o`0000;ooooo0_l000000ooo
oooo0000o`000007ooooo`Go00001?ooool3o`0001Cooooo1?l00003ooooo`?o0000E?ooool001co
oooo00?o0000ooooooooool0AOooool2o`0000Oooooo0ol00006ooooo`;o00000_ooool2o`0000?o
oooo0_l00009ooooo`;o00004Oooool3o`0000Cooooo0_l00002ooooo`Ko000000?oooooo`000?l0
00002_l0000>ooooo`;o00003oooool2o`0000Gooooo0_l00009ooooo`?o00000_ooool2o`000003
ooooool0003o000001;ooooo0_l00004ooooo`;o000000?oooooo`000?l00000EOooool001cooooo
00?o0000ooooooooool0AOooool2o`0000Oooooo0ol00006ooooo`;o000000Coooooo`000?l0003o
00000oooool2o`0000Oooooo1?l0000Booooo`;o00001?ooool:o`000005ooooool0003o0000o`00
0?ooool02?l000000ooooooo0000o`00000;ooooo`;o00004Oooool2o`0001?ooooo0_l000001?oo
oooo0000o`000?ooool2o`0000_ooooo0_l00002ooooo`;o00001?ooool2o`0005Sooooo000Loooo
o`03o`000?oooooooooo04_ooooo0_l00002ooooo`;o00002Oooool4o`0000Sooooo0_l000001?oo
oooo0000o`000?ooool2o`0000Cooooo0_l00006ooooo`;o00002?ooool6o`0000Kooooo0ol00000
0ooooooo0000o`000009o`0000Kooooo0_l0000Aooooo`;o00000oooool2o`0001Wooooo0_l00006
ooooo`;o00000_ooool3o`0000Kooooo0_l00004ooooo`;o0000E?ooool001cooooo00?o0000oooo
ooooool0Boooool2o`0000kooooo0ol00005ooooo`;o000000?oooooo`000?l000001?ooool2o`00
00Cooooo0_l00006ooooo`;o00001oooool4o`0000Kooooo3?l000000ooooooo0000o`000002o`00
00;ooooo0ol000000ooooooo0000o`000004o`0000kooooo0_l00008ooooo`;o00004_ooool2o`00
00Sooooo0_l00002ooooo`;o00001oooool3o`0000?ooooo0_l0001Dooooo`007?ooool00ol0003o
ooooooooo`1Dooooo`;o00001Oooool3o`0000Gooooo0_l0000Kooooo`Go00000oooool4o`000003
ooooool0003o000000oo000000?oooooo`000?l000000_l000000ooooooo0000o`000005o`0000oo
oooo0_l00006ooooo`;o00004_ooool2o`0000Gooooo0_l00004ooooo`;o00001_ooool2o`000003
ooooool0003o000000oooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o0000
1_ooool2o`0000Kooooo1?l00008ooooo`;o00005Oooool5o`0000?ooooo3Ol000000ooooooo0000
o`00000=o`000003ooooool0003o000000Go000000?oooooo`000?l000001?ooool2o`0000Gooooo
0_l000000ooooooo0000o`00000Fooooo`;o00001_ooool2o`0000Cooooo0_l000000ooooooo0000
o`000002ooooo`?o00002Oooool4o`0000Gooooo0_l00018ooooo`007?ooool00ol0003ooooooooo
o`13ooooo`Co000000?oooooo`000?l000000_ooool3o`0000gooooo1?l00008ooooo`;o00003_oo
ool2o`0000Gooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000;o000000?o
ooooo`000?l000001_l000000ooooooo0000o`00000Eo`000003ooooool0003o000000Cooooo0_l0
0006ooooo`Co00003_ooool2o`0000Kooooo0_l00005ooooo`;o00002?ooool2o`0000;ooooo0_l0
000:ooooo`Co0000Coooool001cooooo00?o0000ooooooooool0@oooool4o`000003ooooool0003o
000000?ooooo0_l0000=ooooo`;o00002oooool2o`0000?ooooo0ol00007ooooo`;o00002?ooool4
o`0000;ooooo5?l00003ooooo`Ko00001Oooool3o`0000kooooo1?l0000>ooooo`;o00000_ooool5
o`0000Kooooo0_l0000:ooooo`Co00003_ooool2o`0004gooooo000Looooo`03o`000?oooooooooo
04Wooooo0_l0000;ooooo`Co00000_ooool2o`0000?ooooo0_l00006ooooo`;o00000_ooool4o`00
017ooooo6_l00003ooooo`Oo00000_ooool5o`0000;ooooo0_l0000Pooooo`Go000000?oooooo`00
0?l000001?ooool4o`000004ooooool0003o0000o`0000?ooooo0_l00002ooooo`;o00003?ooool2
o`0004gooooo000Looooo`03o`000?oooooooooo04Wooooo0_l00008ooooo`;o000000?oooooo`00
0?l000000_l00005ooooo`Co00002Oooool3o`0001?ooooo9?l00002ooooo`Co00000oooool2o`00
013ooooo0_l0000Dooooo`;o00001?ooool8o`000003ooooool0003o000000Cooooo0_l0001Koooo
o`007?ooool2o`0004Wooooo0_l00009ooooo`;o000000?oooooo`000?l000001oooool2o`0000_o
oooo0_l00002ooooo`;o00003_ooool2o`000003ooooool0003o000000;ooooo7ol000001?oooooo
0000o`000?ooool4o`0000_ooooo0_l00006ooooo`;o00002oooool2o`0000kooooo1?l00004oooo
o`Co00001_ooool2o`0005Oooooo000Looooo`03o`000?oooooooooo04Sooooo0_l0000:ooooo`Co
00006?ooool2o`0000Gooooo0_l00005ooooo`Go000000Coooooo`000?l0003ooooo8ol00002oooo
o`;o00001?ooool2o`0000Gooooo0_l0000;ooooo`;o00001_ooool2o`0000Cooooo0_l00008oooo
o`;o00002?ooool5o`0000?ooooo0_l00006ooooo`?o00000_ooool2o`0004[ooooo000Looooo`03
o`000?oooooooooo04;ooooo0_l0000@ooooo`;o000000?oooooo`000?l000007Oooool3o`0000Go
oooo0_l000000ooooooo0000o`00000Wo`0000;ooooo0ol00002ooooo`?o00003oooool2o`000003
ooooool0003o000000;ooooo0_l00008ooooo`;o00000oooool2o`000003ooooool0003o000000;o
00002Oooool6o`000003ooooool0003o000000Kooooo0ol00002ooooo`;o0000B_ooool001cooooo
00?o0000ooooooooool0@_ooool2o`00017ooooo1_l0000>ooooo`;o00002oooool2o`0000Sooooo
:_l00002ooooo`?o00000_ooool2o`00013ooooo0_l00005ooooo`;o000000?oooooo`000?l00000
1?l00006ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000008ooooo`Co0000
0_ooool3o`0000Cooooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00001_oo
ool6o`0000Wooooo0_l00003ooooo`;o00003_ooool2o`0000Gooooo1?l000000ooooooo0000o`00
000Wo`0001Sooooo0_l00004ooooo`Oo00001?ooool2o`000003ooooool0003o000000;ooooo0_l0
00000ooooooo0000o`000008ooooo`Co00000_ooool3o`0000Kooooo0_l0001=ooooo`007?ooool0
0ol0003oooooooooo`0cooooo`;o00002?ooool2o`0000kooooo0_l0000:ooooo`;o00002Oooool2
o`0001?ooooo0_l00007ooooo`;o00000_oooolQo`0000;ooooo0ol0000Jooooo`?o000000?ooooo
o`000?l000001?l00004ooooo`;o000000?oooooo`000?l000000ol00006ooooo`;o00002Oooool4
o`0000Oooooo1?l0001=ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00002?ooool2o`00
01Cooooo0_l00004ooooo`;o00000_ooool2o`0000Gooooo1?l0000Nooooob7o000000?oooooo`00
0?l000000_l00008ooooo`;o000000?oooooo`000?l000003_ooool2o`000003ooooool0003o0000
00;ooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000;o00001oooool2
o`0000_ooooo0_l00007ooooo`?o0000C_ooool001cooooo00?o0000ooooooooool0A?ooool3o`00
00cooooo0_l00003ooooo`;o00000oooool2o`0000Kooooo0ol0000>ooooo`;o00001Oooool3o`00
00Gooooo9ol00008ooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o0000
00?ooooo0_l00005ooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`;o000000?ooooo
o`000?l000001Oooool2o`0000Gooooo0_l0000>ooooo`?o00007_ooool2o`0002kooooo000Loooo
o`03o`000?oooooooooo04Cooooo0ol0000=ooooo`;o00000_ooool4o`0001Gooooo0_l00003oooo
o`;o00001?ooool5o`0000;ooooo:Ol00008ooooo`;o00001Oooool2o`000003ooooool0003o0000
00?ooooo0_l00004ooooo`Go00001_ooool2o`0000Cooooo0_l00005ooooo`;o00001Oooool2o`00
00oooooo0_l000001?oooooo0000o`000?l0000Jooooo`;o0000;_ooool001cooooo00?o0000oooo
ooooool0@_ooool2o`0000cooooo0_l00002ooooo`;o00001?ooool2o`0001Cooooo0ol00009oooo
o`Go00000_oooolSo`0000Cooooo0_l00008ooooo`;o000000?oooooo`000?l000002_ooool4o`00
00;ooooo1Ol00008ooooo`?o000000?oooooo`000?l000001_ooool2o`0000?ooooo0ol00006oooo
o`;o00002_ooool3o`0000cooooo0_l0000looooo`007?ooool00ol0003oooooooooo`11ooooo`?o
00003?ooool4o`0001cooooo1?l00006ooooo`?o00001OoooolTo`000004ooooool0003o0000oooo
o`;o00000oooool3o`0000?ooooo1_l00008ooooo`Co00001_ooool2o`0000Gooooo1Ol000000ooo
oooo0000o`000006ooooo`;o000000?oooooo`000?l000000_l00007ooooo`Co00003?ooool2o`00
00Wooooo0_l0000looooo`007?ooool00ol0003oooooooooo`11ooooo`;o00003oooool2o`0000?o
oooo0_l00002ooooo`;o00000oooool2o`00013ooooo0_l00005ooooo`Co00000ooooolUo`0000;o
oooo0_l000000ooooooo0000o`000003ooooo`Co00000_ooool2o`0000;ooooo1Ol00002ooooo`;o
00002oooool2o`0000Gooooo1?l0000=ooooo`;o00000oooool4o`0000Cooooo0_l0000<ooooo`;o
0000Aoooool001cooooo00?o0000ooooooooool0Eoooool2o`0000;ooooo0_l00003ooooo`;o0000
3?ooool2o`0000Gooooo1_l00005oooooa?o00000_ooool@o`0000?ooooo0_l00004ooooo`Go0000
1oooool4o`0000;ooooo0_l0000;ooooo`;o00001Oooool4o`0000cooooo0_l00004ooooo`Co0000
1?ooool2o`0000cooooo0_l000000ooooooo0000o`000014ooooo`007?ooool00ol0003ooooooooo
o`1^ooooo`;o00001Oooool4o`0000?ooooo0_l00002ooooobOo000000Coooooo`000?l0003o0000
0oooool2o`0000gooooo1?l0000Cooooo`;o00002_ooool2o`0000;ooooo0_l000000ooooooo0000
o`00000Gooooo`;o000000?oooooo`000?l00000A?ooool00006ooooooo^k^ko<S8bo`000?lb<S;o
k^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo03So
oooo0_l00005ooooo`;o00004Oooool2o`0001cooooo0_l00008ooooo`Go000000?oooooo`000?l0
00008Ol000001?oooooo0000o`000?l00002ooooo`Co000000?oooooo`000?l000002_ooool2o`00
0003ooooool0003o000000;o00001?ooool2o`0000;ooooo0_l00007ooooo`;o00002_ooool4o`00
00Gooooo0_l0001Pooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Sooooo0_l00004ooooo`?o00004Oooool2
o`0001cooooo0_l00008ooooo`;o000000?oooooo`000?l000000_ooool3o`000003ooooool0003o
000001_o00000_ooool2o`000003ooooool0003o000000Co00000oooool2o`0000Sooooo0ol00008
ooooo`;o00000_ooool2o`0000Oooooo0_l00006ooooo`;o00000_ooool2o`0000Oooooo0_l0000;
ooooo`;o00001?ooool2o`0000cooooo0_l0000Cooooo`;o0000:_ooool00003ooooool@413ooooo
00;ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo00?o0000ooooooooool0?_ooool2o`00
00Kooooo0_l0000Vooooo`;o00001oooool2o`0000Cooooo0_l00006ooooob7o000000?oooooo`00
0?l000001_l000001?oooooo0000o`000?ooool2o`0000Cooooo1?l00006ooooo`;o00003oooool2
o`0000Cooooo0_l0000<ooooo`;o00001_ooool2o`0000;ooooo0_l00004ooooo`;o00002Oooool2
o`000003ooooool0003o000001?ooooo0_l0000Zooooo`0000?oooooo`000?ooool00_ooool00ol0
003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0000oooooo`;o00001?ooool3
o`0002Kooooo0_l00007ooooo`;o00001?ooool3o`0000Cooooo8_l00002ooooo`Oo00000_ooool4
o`0000Cooooo0ol00007ooooo`?o000000?oooooo`000?l000001Oooool4o`0000;ooooo0ol0000A
ooooo`;o00001_ooool7o`0000;ooooo0_l00009ooooo`?o0000@_ooool00003ooooool0003ooooo
00;ooooo00?o0000ooooooooool02Oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooo
oooo02oooooo0_l0000>ooooo`;o00001?ooool2o`0002Oooooo0ol0000<ooooo`?o00000ooooolT
o`000004ooooool0003o0000ooooo`Co00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`00
0005o`0000Gooooo0_l000000ooooooo0000o`000004ooooo`Go00000_ooool3o`0000?ooooo0_l0
000Dooooo`Oo00000_ooool2o`0000Wooooo0_l00013ooooo`0000?ooooooa0@4?ooool00_ooool0
0ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0;oooool2
o`0001Kooooo0_l0000Vooooo`;o00001?ooool2o`0000?ooooo0_l000000ooooooo0000o`000004
ooooob7o000000?oooooo`000?l000000_l00003ooooo`?o00001?ooool4o`000004ooooool0003o
0000ooooo`Co00003_ooool2o`0000Gooooo0ol00002ooooo`?o00001_ooool4o`0000[ooooo0_l0
000Gooooo`;o0000?_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4
o`000007ooooo`03o`000?oooooooooo03Cooooo0_l00005ooooo`?o00002Oooool2o`0002Oooooo
0_l00003ooooo`;o00000oooool5o`000003ooooool0003o000000Go000000?oooooo`000?l00000
7ol00003ooooo`Co00000oooool2o`0000Oooooo0_l00003ooooo`;o00004_ooool2o`0000;ooooo
0_l000000ooooooo0000o`000002o`0000;ooooo1?l0000;ooooo`?o00001oooool2o`0000cooooo
0_l0000nooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Ko
oooo00?o0000ooooooooool0:oooool2o`0000Oooooo0_l00004ooooo`Co0000<_ooool3o`0000Wo
oooo0_l00002oooooa?o000000?oooooo`000?l000004?l00005ooooo`Go00000_ooool3o`0000Oo
oooo0ol00002ooooo`?o00001Oooool2o`0000Kooooo0_l000000ooooooo0000o`000003ooooo`;o
000000?oooooo`000?l000000_l00003ooooo`?o00000oooool2o`0000Kooooo0ol00007ooooo`;o
00003?ooool2o`000003ooooool0003o000003_ooooo000Looooo`03o`000?oooooooooo02_ooooo
0_l00006ooooo`;o00001Oooool3o`000003ooooool0003o0000037ooooo0_l0000?ooooobOo0000
0_ooool2o`0000Gooooo0_l00008ooooo`?o00000oooool2o`0000Cooooo0ol00003ooooo`;o0000
00Coooooo`000?l0003ooooo0_l00003ooooo`Co00001oooool2o`0000?ooooo0ol00004ooooo`;o
00001?ooool2o`00017ooooo0_l000000ooooooo0000o`00000kooooo`007?ooool00ol0003ooooo
ooooo`0cooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0ol0000eooooo`;o0000
00?oooooo`000?l000001Oooool4o`0000;ooooo1?l000000ooooooo0000o`00000Go`0000;ooooo
0ol00002ooooo`;o000000Coooooo`000?l0003ooooo0_l0000:ooooo`;o00000_ooool2o`0000Go
oooo0_l00004ooooo`Go00000oooool2o`0000?ooooo0_l0000=ooooo`;o00001?ooool2o`0000Co
oooo0_l0000=ooooo`;o00001Oooool2o`0003_ooooo000Looooo`03o`000?oooooooooo03Kooooo
0_l00002ooooo`;o00000_ooool3o`0000Sooooo0_l0000Oooooo`;o00002_ooool5o`000003oooo
ool0003o000000;ooooo1?l00003ooooo`;o000000?oooooo`000?l000005_l00002ooooo`Go0000
0_ooool2o`000004ooooool0003o0000ooooo`;o00001Oooool2o`0000;ooooo1ol00002ooooo`;o
00001oooool5o`0000?ooooo0_l00008ooooo`Ko000000?oooooo`000?l000004Oooool4o`0000Oo
oooo0_l0000Fooooo`;o0000:_ooool001cooooo00?o0000ooooooooool0=_ooool2o`000003oooo
ool0003o000000?ooooo0_l00009ooooo`;o00007oooool2o`0000_ooooo0_l00003ooooo`;o0000
0_ooool2o`000003ooooool0003o000000;ooooo1_l000000ooooooo0000o`00000Bo`0000;ooooo
2Ol0000;ooooo`[o000000?oooooo`000?l000000_l00007ooooo`;o00000oooool2o`0000_ooooo
1_l000001?oooooo0000o`000?ooool2o`0000Kooooo0_l00006ooooo`Co00001oooool2o`0001Ko
oooo0_l0000Zooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00001?ooool2o`0000;ooooo
0_l0000jooooo`;o00000_ooool2o`0000;ooooo1_l000000ooooooo0000o`00000Bo`000004oooo
ool0003o0000o`0000?ooooo0_l00007ooooo`;o00000_ooool2o`0000;ooooo1Ol00002ooooo`Co
00003Oooool3o`0000Cooooo0_l00007ooooo`Co00001?ooool2o`0000Kooooo0_l0000<ooooo`;o
00000oooool2o`0004;ooooo000Looooo`03o`000?oooooooooo03oooooo0_l00002ooooo`;o0000
:Oooool2o`0000Gooooo0_l00007ooooo`?o00000_ooool3o`0000;ooooo1ol000000ooooooo0000
o`00000@o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000001oooool2o`0000;o
oooo0_l00002ooooo`Co000000?oooooo`000?l000000_l00003ooooo`;o00002_ooool4o`0000;o
oooo1?l000000ooooooo0000o`000002o`0000Cooooo0_l0000@ooooo`;o00001?ooool2o`000003
ooooool0003o000000Wooooo0_l00002ooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0
>_ooool2o`000003ooooool0003o000000Co00002?ooool3o`0001cooooo0_l00002ooooo`;o0000
1Oooool2o`0000?ooooo0_l00002ooooo`?o000000?oooooo`000?l000000_l000000ooooooo0000
o`000006o`000003ooooool0003o000000Ko000000?oooooo`000?l000001ol00004ooooo`;o0000
1_ooool2o`0000Sooooo0_l00002ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Wooooo
0_l000000ooooooo0000o`000002ooooo`_o00000_ooool2o`00013ooooo0_l00004ooooo`;o0000
1_ooool2o`0000Cooooo0_l000001?oooooo0000o`000?l0000hooooo`007?ooool00ol0003ooooo
ooooo`0booooo`;o00001_ooool5o`0000;ooooo0ol00007ooooo`?o00007?ooool2o`0000Kooooo
0_l00006ooooo`;o00000oooool2o`000003ooooool0003o000000;o000000?oooooo`000?l00000
2_l00002ooooo`go00002?ooool2o`0000;ooooo0_l00008ooooo`;o000000?oooooo`000?l00000
2?ooool2o`0000Gooooo0_l00002ooooo`?o00002?ooool4o`000004ooooool0003o0000o`0001_o
oooo0_l00005ooooo`?o00001Oooool3o`0003Wooooo000Looooo`03o`000?oooooooooo037ooooo
0ol00007ooooo`;o00001Oooool2o`0002kooooo0_l0000<ooooo`;o00000oooool=o`0000;ooooo
1_l000000ooooooo0000o`000003o`0000Kooooo0_l00002ooooo`;o00001oooool2o`0000;ooooo
0ol000000ooooooo0000o`000002o`0000Kooooo1?l00003ooooo`;o00000_ooool2o`0000Gooooo
0_l00002ooooo`[o00002_ooool2o`0000?ooooo0_l00008ooooo`;o00001?ooool4o`0000Gooooo
1?l0000hooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00002Oooool2o`0003Sooooo0_l0
0008ooooo`;o00000oooool5o`000003ooooool0003o000000Go000000?oooooo`000?l000001?l0
00000ooooooo0000o`000003o`0000Oooooo1?l00009ooooo`;o00000_ooool3o`0000;ooooo1?l0
0003ooooo`Ko00002?ooool5o`000003ooooool0003o000000ko00002?ooool2o`000003ooooool0
003o000000;o00002?ooool2o`0000Cooooo0_l00002ooooo`;o00001Oooool2o`0003Sooooo000L
ooooo`03o`000?oooooooooo03cooooo0_l0000?ooooo`;o00008_ooool2o`0000?ooooo0_l0000<
ooooo`?o00001?ooool2o`0000?ooooo0_l000001Ooooooo0000o`000?l0003ooooo00So00001?oo
ool2o`0000?ooooo0_l00006ooooo`;o00002_ooool4o`0000?ooooo1_l00003ooooo`;o00000ooo
ool5o`000003ooooool0003o000000ko00002oooool2o`0000[ooooo0_l00003ooooo`;o00000ooo
ool2o`0000Gooooo0_l0000hooooo`007?ooool2o`0002Kooooo0_l0000>ooooo`;o00005_ooool2
o`0000kooooo1?l00005ooooo`;o00002Oooool2o`0000Kooooo0_l00004ooooo`;o00000oooool3
o`0000;ooooo0_l00002ooooo`;o00001Oooool2o`000003ooooool0003o000000?o00000_ooool2
o`0000?ooooo0_l00008ooooo`;o000000?oooooo`000?l000001oooool2o`000003ooooool0003o
000000;ooooo0_l00004ooooo`;o00001?ooool4o`0000Oooooo4Ol0000Fooooo`;o00000oooool2
o`0000[ooooo0_l0000>ooooo`;o0000:?ooool001cooooo00?o0000ooooooooool09Oooool2o`00
00kooooo0_l000000ooooooo0000o`00000>ooooo`;o00004oooool4o`0000Gooooo0_l0000>oooo
o`Go00000oooool4o`0000?ooooo0_l000001?oooooo0000o`000?l00002ooooo`?o000000?ooooo
o`000?l000001Oooool4o`0000;ooooo0_l0000<ooooo`?o00000oooool2o`0000Gooooo0_l00005
ooooo`Co00002_ooool2o`0000Oooooo4Ol00003ooooo`;o00005_ooool3o`0000Wooooo0_l0000>
ooooo`;o0000:?ooool001cooooo00?o0000ooooooooool0>?ooool2o`0000Wooooo0_l00003oooo
o`;o000000?oooooo`000?l00000:Oooool4o`0000?ooooo1Ol00002ooooo`?o000000Coooooo`00
0?l0003o00000oooool2o`000004ooooool0003o0000ooooo`;o00001?ooool2o`0000Wooooo0_l0
0005ooooo`;o00001?ooool3o`0000_ooooo1?l0000<ooooo`;o00001OoooolCo`000003ooooool0
003o000000;o000000?oooooo`000?l000004_ooool2o`0000Wooooo0_l0000hooooo`007?ooool0
0ol0003oooooooooo`0aooooo`;o00001Oooool2o`0000Wooooo0_l00006ooooo`;o00004?ooool2
o`0001kooooo0_l00005ooooo`?o00000oooool2o`0000?ooooo1ol00005ooooo`;o00002?ooool2
o`0000Kooooo0_l00004ooooo`Co00001Oooool2o`0000;ooooo0_l00002ooooo`;o00002_ooool2
o`0000Gooooo4ol00003ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Looooo`;o0000=_oo
ool001cooooo00?o0000ooooooooool0<Oooool2o`0000Gooooo0_l0000Looooo`;o00000_ooool2
o`000004ooooool0003o0000o`0001Gooooo0_l0000<ooooo`Co00000oooool4o`000004ooooool0
003o0000ooooo`;o00001oooool2o`00013ooooo0_l00006ooooo`;o00001Oooool2o`0000;ooooo
0_l00002ooooo`;o00004OoooolCo`0000Wooooo0_l0000Kooooo`?o0000=_ooool001cooooo00?o
0000ooooooooool0Doooool5o`0000;ooooo0_l00002ooooo`;o00002Oooool2o`0000Sooooo1?l0
000<ooooo`?o00001?ooool4o`0000;ooooo0_l00009ooooo`;o00001?ooool2o`000003ooooool0
003o000001Wooooo0ol00007ooooo`;o00001oooool3o`0000;ooooo4ol000000ooooooo0000o`00
000Sooooo`;o0000=oooool001cooooo00?o0000ooooooooool0<oooool2o`000003ooooool0003o
000000Sooooo0_l0000Aooooo`Co00001_ooool2o`0000Oooooo0_l000000ooooooo0000o`000008
ooooo`;o00002?ooool3o`0000;ooooo1?l00002ooooo`;o00000_ooool2o`0000;ooooo0_l00009
ooooo`;o00001?ooool2o`000003ooooool0003o000000Cooooo0_l0000:ooooo`;o00000oooool2
o`0000;ooooo0ol00006ooooo`?o000000?oooooo`000?l000000_l00002ooooo`?o00000_oooolC
o`000003ooooool0003o000001gooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0boooo
o`?o000000?oooooo`000?l000000_l00006ooooo`Co000000?oooooo`000?l000002?ooool3o`00
00Cooooo0_l00002ooooo`;o000000?oooooo`000?l000001oooool2o`0000_ooooo0_l00005oooo
o`;o000000Goooooo`000?l0003o0000ooooo`05o`000003ooooool0003o000000;o000000?ooooo
o`000?l000000_ooool2o`0000Wooooo0_l00002ooooo`;o00002Oooool2o`0000?ooooo0_l00005
ooooo`;o00000oooool7o`0000Kooooo0_l00002ooooo`Co00001_oooolEo`0001oooooo0_l0000m
ooooo`007?ooool00ol0003oooooooooo`0booooo`;o00001?ooool2o`0000?ooooo0_l00002oooo
o`Ko00001oooool4o`0000Cooooo1_l0000Gooooo`;o00000_ooool2o`000003ooooool0003o0000
00?ooooo1?l00004ooooo`Co00001Oooool2o`0000Wooooo0_l00002ooooo`;o00003_ooool3o`00
00;ooooo0_l00006ooooo`Go00002Oooool2o`0000[ooooo5Ol0001Nooooo`007?ooool00ol0003o
ooooooooo`0/ooooo`?o00000oooool2o`0000Wooooo0_l00005ooooo`;o00002?ooool2o`0000Go
oooo1Ol000001?oooooo0000o`000?l0000Iooooo`;o00001_ooool3o`0000Sooooo0_l0000<oooo
o`;o00005_ooool2o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o00003?ooool2o`00
00Wooooo5ol0000Jooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0;?ooool3o`0000;o
oooo0_l00003ooooo`;o00002_ooool4o`0000cooooo0_l000000ooooooo0000o`000004ooooo`?o
00002Oooool2o`0000Sooooo0_l0000Cooooo`;o00000_ooool2o`0000cooooo0_l0000;ooooo`?o
00003oooool2o`0000Oooooo0_l0000;ooooo`;o00001?ooool8o`000003ooooool0003o000000ko
00001?ooool2o`00017ooooo0_l000000ooooooo0000o`000011ooooo`007?ooool00ol0003ooooo
ooooo`0aooooo`;o00000oooool2o`0000;ooooo0_l00006ooooo`Co00003?ooool2o`0000Cooooo
0_l00009ooooo`;o000000?oooooo`000?l000000_l00007ooooo`?o00002Oooool3o`0000Kooooo
0_l0000:ooooo`;o00004Oooool3o`0000cooooo1ol00005ooooo`;o00002oooool3o`0000?ooooo
5Ol00008ooooo`;o00003_ooool2o`000003ooooool0003o000000_ooooo0_l0000gooooo`007?oo
ool00ol0003oooooooooo`0jooooo`;o00006?ooool2o`0000;ooooo0_l00006ooooo`;o000000Co
ooooo`000?l0003ooooo1Ol000000ooooooo0000o`000006o`0000;ooooo0_l00005ooooo`?o0000
1?ooool4o`0000Cooooo0_l00004ooooo`;o00001oooool2o`0001Oooooo0ol000001?oooooo0000
o`000?l00003ooooo`;o000000?oooooo`000?l000002oooool2o`0000Cooooo5?l00002ooooo`;o
00005?ooool2o`000003ooooool0003o000000_ooooo0_l0000gooooo`007?ooool00ol0003ooooo
ooooo`0oooooo`Co00004Oooool2o`0000Oooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o
000000?oooooo`000?l000000_l000000ooooooo0000o`000004o`000003ooooool0003o000000?o
00001_ooool2o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`;o00001oooool2o`0000Co
oooo0_l0000Iooooo`Co00001?ooool2o`000004ooooool0003o0000o`00017ooooo4ol000000ooo
oooo0000o`000003o`0000Kooooo0_l0000Cooooo`;o0000?_ooool001cooooo00?o0000oooooooo
ool0>?ooool2o`0000Gooooo1?l0000>ooooo`;o00000_ooool2o`0000Kooooo0_l000000ooooooo
0000o`000007o`000003ooooool0003o000000?o000000Coooooo`000?l0003ooooo0ol00008oooo
o`;o00001oooool2o`0000?ooooo0_l00007ooooo`;o00006Oooool2o`000004ooooool0003o0000
ooooo`Go00001?ooool2o`000003ooooool0003o0000013ooooo5?l000000ooooooo0000o`000006
o`0000?ooooo0_l00002ooooo`Co00003Oooool2o`000003ooooool0003o000000Cooooo0_l0000e
ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00001Oooool2o`00013ooooo0_l00002oooo
o`;o00000oooool2o`0000Cooooo0_l000000ooooooo0000o`000003o`0000;ooooo2_l00002oooo
o`;o000000?oooooo`000?l000000_l000000ooooooo0000o`00000Uooooo`?o00002?ooool5o`00
0004ooooool0003o0000ooooo`Co00000_ooool2o`0001?ooooo4_l000000ooooooo0000o`000003
o`000003ooooool0003o000000;o00001oooool4o`0000Cooooo0_l0000:ooooo`;o00001?ooool2
o`0000cooooo0_l0000Wooooo`007?ooool2o`0003Wooooo0ol00004ooooo`;o00003_ooool3o`00
00Cooooo0_l00002ooooo`;o000000?oooooo`000?l000004_l000000ooooooo0000o`000002oooo
o`Oo00005_ooool2o`0000Kooooo0_l00005ooooo`;o000000Coooooo`000?l0003o00001_ooool2
o`000004ooooool0003o0000ooooo`;o00001Oooool2o`0001Sooooo4Ol000001?oooooo0000o`00
0?l0000<ooooo`;o00000_ooool2o`0000Cooooo0_l0000Nooooo`;o00009oooool001cooooo00?o
0000ooooooooool0<oooool2o`0000?ooooo0ol000000ooooooo0000o`00000=ooooo`;o00000_oo
ool3o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l000005?l00005ooooo`;o000000?o
ooooo`000?l000001oooool2o`0000Kooooo0_l00005ooooo`;o00001_ooool2o`0000?ooooo1Ol0
0009ooooo`So00002Oooool2o`0000Sooooo0_l0000=ooooo`co00004_ooool2o`0000oooooo0_l0
0010ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00001oooool2o`0000gooooo0_l0000=
oooooa[o00000oooool2o`0000;ooooo0_l00007ooooo`;o00000oooool2o`000003ooooool0003o
000000_ooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000002_ooool3
o`000003ooooool0003o000000[ooooo0_l000000ooooooo0000o`000005ooooo`;o00001oooool2
o`0000Sooooo2?l00006ooooo`;o00005oooool2o`0000;ooooo0_l00002ooooo`;o00001?ooool2
o`0003Kooooo000Looooo`03o`000?oooooooooo03[ooooo0_l0000:ooooo`;o00004OoooolKo`00
00;ooooo0ol0000@ooooo`;o00003_ooool6o`0000;ooooo0_l00009ooooo`;o000000?oooooo`00
0?l000004Oooool2o`0000Wooooo0_l00003ooooo`;o000000?oooooo`000?l000001oooool3o`00
0003ooooool0003o000000;o000000Coooooo`000?l0003ooooo0_l0000Gooooo`;o00001_ooool4
o`0000;ooooo0_l00006ooooo`;o0000;_ooool001cooooo00?o0000ooooooooool0>_ooool2o`00
00[ooooo0_l0000Aoooooaoo00008?ooool4o`000003ooooool0003o000000Co00000oooool3o`00
00?ooooo0_l0000Oooooo`;o00000oooool2o`000003ooooool0003o000000Wooooo1_l000000ooo
oooo0000o`00000=ooooo`;o00002oooool2o`0000Sooooo0_l0000:ooooo`;o0000;_ooool001co
oooo00?o0000ooooooooool0E?ooool2o`0000Gooooo7?l00004ooooo`;o00001Oooool3o`0000Co
oooo0ol000000ooooooo0000o`000009ooooo`;o00001Oooool2o`0000Cooooo1?l00005ooooo`;o
00005_ooool3o`0001Gooooo1?l000000ooooooo0000o`00000Aooooo`;o00002oooool2o`0000;o
oooo0_l00004ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0Aoooool2o`0000?ooooo
0_l00003ooooo`;o000000?oooooo`000?l000001?oooolPo`000003ooooool0003o000000Gooooo
0ol00004ooooo`?o000000?oooooo`000?l000005_ooool4o`0000Cooooo0ol0000Fooooo`?o0000
0oooool2o`0000oooooo0ol00002ooooo`;o00004?ooool2o`0000Kooooo0_l00009ooooo`;o0000
1?ooool2o`0003[ooooo000Looooo`03o`000?oooooooooo04;ooooo0_l00003ooooo`;o00000ooo
ool4o`000003ooooool0003o000000;o000000?oooooo`000?l000006ol000000ooooooo0000o`00
0004o`000003ooooool0003o000001?ooooo0_l00003ooooo`;o00001?ooool2o`0000Wooooo2_l0
000Looooo`;o00001oooool2o`0000Kooooo0_l00003ooooo`;o00002Oooool2o`0000Gooooo0_l0
0006ooooo`;o00004Oooool2o`0003Sooooo000Looooo`03o`000?oooooooooo04;ooooo0_l00002
ooooo`;o00000_ooool2o`000004ooooool0003o0000o`0000?ooooo0_l000000ooooooo0000o`00
000Ko`000003ooooool0003o000000;o00001?ooool2o`000003ooooool0003o000000?ooooo0_l0
000:ooooo`;o00000oooool2o`0000Cooooo0_l0000:ooooo`Oo00004Oooool2o`0000Sooooo0_l0
000:ooooo`;o000000?oooooo`000?l000004oooool4o`0000_ooooo0_l0000Aooooo`;o0000>?oo
ool001cooooo00?o0000ooooooooool0@?ooool2o`0000Cooooo0_l00002ooooo`;o000000?ooooo
o`000?l000001?ooool2o`0000?ooooo8?l00004ooooo`;o000000?oooooo`000?l000000oooool2
o`0001Gooooo0_l00004ooooo`?o00000oooool7o`0000;ooooo0_l00002ooooo`?o00000oooool2
o`0000?ooooo0_l00008ooooo`;o00003Oooool2o`0001Gooooo0_l0000Xooooo`;o00000_ooool2
o`0002[ooooo000Looooo`03o`000?oooooooooo02_ooooo0_l0000Cooooo`;o00001?ooool2o`00
00Cooooo0_l0000:oooooa3o000000?oooooo`000?l000001ol000000ooooooo0000o`000004o`00
00Kooooo0_l00005ooooo`;o00000oooool2o`0000kooooo0_l00004ooooo`?o00001Oooool2o`00
0003ooooool0003o000000Co00000_ooool3o`0000?ooooo0_l0000Gooooo`;o00000oooool2o`00
02;ooooo0_l00003ooooo`;o00002Oooool2o`000003ooooool0003o000000Sooooo0_l00002oooo
o`;o0000:_ooool001cooooo00?o0000ooooooooool0:oooool2o`0000Wooooo0_l0000=ooooo`;o
00001Oooool2o`0000;ooooo0_l00005ooooob;o00003Oooool2o`0000?ooooo0_l00006ooooo`;o
00003?ooool3o`0000Gooooo0_l000000ooooooo0000o`000002o`0001Sooooo0_l00007ooooo`Co
00000oooool2o`0000kooooo0_l0000Booooo`;o00000oooool2o`0000Wooooo0_l000000ooooooo
0000o`00000hooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00003Oooool2o`0000;ooooo
0_l00005ooooo`;o00001?oooolRo`0001_ooooo0_l00002ooooo`;o00000oooool2o`000003oooo
ool0003o000000gooooo0_l0000Dooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000
o`00000Eooooo`;o00003oooool2o`00017ooooo0_l0000kooooo`007?ooool00ol0003ooooooooo
o`0fooooo`;o00003?ooool2o`0000?ooooo1?l00006ooooo`;o000000?oooooo`000?l000000_oo
ool:o`000003ooooool0003o000000oo00005Oooool2o`0000[ooooo0_l00003ooooo`;o000000?o
ooooo`000?l000001?ooool2o`0000kooooo0_l0000=ooooo`;o00001?ooool3o`000003ooooool0
003o000000?o00002?ooool2o`0000kooooo0_l00008ooooo`;o00000_ooool2o`0004kooooo000L
ooooo`03o`000?oooooooooo03Kooooo0_l00003ooooo`;o00001oooool2o`0000Gooooo0_l00002
ooooo`;o00000_ooool2o`0000?ooooo7ol0000Dooooo`;o00002Oooool2o`0000gooooo0_l0000>
ooooo`;o00002_ooool2o`0000Gooooo1Ol000000ooooooo0000o`000003o`0000?ooooo0ol00002
ooooo`;o00003_ooool2o`0000Sooooo0_l0000Nooooo`;o0000<_ooool001cooooo00?o0000oooo
ooooool0>oooool2o`0000Gooooo1?l00009ooooo`Co00001OoooolIo`000003ooooool0003o0000
00?o00007_ooool3o`0000?ooooo0_l00009ooooo`;o00005_ooool2o`000003ooooool0003o0000
00Gooooo0ol000000ooooooo0000o`000002o`000003ooooool0003o000000?ooooo0ol000000ooo
oooo0000o`000007ooooo`;o00004oooool2o`0001_ooooo0_l0000booooo`007?ooool2o`00047o
oooo1_l0000;ooooo`;o00001OoooolMo`0000Cooooo0_l0000Jooooo`?o00000oooool2o`0000?o
oooo0_l00004ooooo`;o00003Oooool2o`0000?ooooo0_l00002ooooo`;o00001_ooool;o`000004
ooooool0003o0000ooooo`;o00000oooool2o`0000Kooooo0ol000001?oooooo0000o`000?l00009
ooooo`;o00000_ooool4o`0000?ooooo1?l00018ooooo`007?ooool00ol0003oooooooooo`0moooo
o`Go00001_ooool2o`0000Oooooo0_l00002ooooo`;o00000_oooolLo`000004ooooool0003o0000
ooooo`;o00006oooool2o`0000Kooooo1?l0000Cooooo`;o00000oooool2o`0000Wooooo3ol00000
0ooooooo0000o`000006ooooo`;o00000oooool2o`0000;ooooo0ol000000ooooooo0000o`000006
ooooo`;o00000_ooool2o`0000Gooooo1?l0000=ooooo`;o000000?oooooo`000?l00000=_ooool0
01cooooo00?o0000ooooooooool0?Oooool3o`0000;ooooo0_l00004ooooo`;o00001oooool2o`00
00;ooooo0ol000000ooooooo0000o`00000Jo`000003ooooool0003o000001Sooooo0_l000000ooo
oooo0000o`000003ooooo`;o00001?ooool3o`0001Oooooo0_l000000ooooooo0000o`000004oooo
o`oo000000?oooooo`000?l000000_l00008ooooo`;o00002oooool2o`0000Wooooo0ol00006oooo
o`;o00003_ooool2o`000003ooooool0003o000003Kooooo000Looooo`03o`000?oooooooooo03go
oooo0_l00003ooooo`;o00004_ooool2o`000003ooooool0003o000001Wo00000_ooool2o`0001So
oooo1Ol00003ooooo`;o00001Oooool3o`0000_ooooo0_l00003ooooo`;o00001?ooool2o`000003
ooooool0003o000000;o00000_ooool6o`000003ooooool0003o000000?o000000?oooooo`000?l0
00001Ol0000Pooooo`Co00001Oooool4o`0004Oooooo000Looooo`03o`000?oooooooooo03gooooo
0_l0000Foooooaoo00007?ooool4o`0000Oooooo0_l00003ooooo`;o00001_ooool2o`0000?ooooo
0_l00003ooooo`;o00001?ooool2o`000003ooooool0003o000000;o00000_oooolEo`0001gooooo
0_l00002ooooo`;o000000?oooooo`000?l000001?ooool2o`0000cooooo0_l0000iooooo`007?oo
ool00ol0003oooooooooo`0`ooooo`;o00002oooool2o`0000Kooooo0_l0000>ooooob3o00000_oo
ool2o`0001Oooooo0_l00003ooooo`;o00001?ooool2o`0000Kooooo0_l00003ooooo`;o00003ooo
ool2o`0000;ooooo0_l00002oooooaGo00001_ooool2o`0001Gooooo0_l00005ooooo`;o00004_oo
ool2o`0003Wooooo000Looooo`03o`000?oooooooooo033ooooo0_l0000;ooooo`;o00000_ooool2
o`0000;ooooo0ol00002ooooo`?o00001oooool2o`0000Cooooo2_l000000ooooooo0000o`00000>
o`0000;ooooo0_l0000Looooo`;o00002?ooool2o`0000;ooooo0_l0000=ooooo`;o00000oooool4
o`0000Oooooo5?l00006ooooo`;o00005_ooool2o`0000kooooo0_l0000Booooo`;o0000;oooool0
01cooooo00?o0000ooooooooool0@Oooool2o`0000?ooooo0_l00002ooooo`?o00001oooool2o`00
00Cooooo1_l000000ooooooo0000o`000005o`000003ooooool0003o000000Oo00001Oooool2o`00
00_ooooo0_l0000Booooo`;o00001Oooool2o`0000?ooooo1?l0000:ooooo`?o00000_ooool4o`00
00Gooooo4Ol000000ooooooo0000o`000002o`0001kooooo0_l00003ooooo`;o00002Oooool4o`00
013ooooo0_l0000_ooooo`007?ooool00ol0003oooooooooo`16ooooo`;o00003_ooool2o`0000?o
oooo0ol00002ooooo`;o00000_ooool9o`000004ooooool0003o0000ooooo`;o00001?ooool2o`00
0003ooooool0003o000000Sooooo0_l0000:ooooo`;o00000oooool2o`000003ooooool0003o0000
00[ooooo1?l000000ooooooo0000o`000005ooooo`Go00000_ooool3o`0000Cooooo6ol0000Poooo
o`;o00002oooool2o`00047ooooo000Looooo`03o`000?oooooooooo03[ooooo0_l00007ooooo`;o
000000?oooooo`000?l000003_ooool2o`0000?ooooo0_l00002ooooo`?o00001_ooool3o`000003
ooooool0003o000000;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000001Co
oooo0_l00003ooooo`Go00001_ooool2o`0000Oooooo0_l00004ooooo`Co00001?ooool2o`0000?o
oooo7Ol000000ooooooo0000o`00000Jooooo`;o00002Oooool2o`0004Kooooo000Looooo`03o`00
0?oooooooooo03[ooooo0_l00007ooooo`;o000000?oooooo`000?l000003Oooool2o`0000Sooooo
1Ol00002ooooo`Co00000_ooool4o`0000Wooooo0_l0000Iooooo`Co00002?ooool2o`0000cooooo
0ol00002ooooo`;o00001ooooolDo`000003ooooool0003o000000Ko000000?oooooo`000?l00000
5oooool2o`000003ooooool0003o000000Wooooo0_l00016ooooo`007?ooool00ol0003ooooooooo
o`13ooooo`;o00002Oooool2o`0000Gooooo0_l0000:ooooo`?o00000_ooool3o`0000Cooooo0ol0
0009ooooo`;o00003oooool2o`0000Sooooo0ol0000?ooooo`;o00001_ooool2o`0000?ooooo0_l0
0008oooooaWo000000?oooooo`000?l000002_ooool2o`0000kooooo0_l0001Dooooo`007?ooool0
0ol0003oooooooooo`1>ooooo`;o00002oooool2o`0000Cooooo0_l00004ooooo`;o00001?ooool3
o`0000Gooooo0_l00003ooooo`;o00003_ooool2o`0001?ooooo0_l00005ooooo`;o00000oooool2
o`0000gooooo3?l000001Ooooooo0000o`000?l0003ooooo013o00001Oooool2o`000003ooooool0
003o000000kooooo0_l0000Hooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0>oooool2
o`0000kooooo0_l0000>ooooo`;o00001?ooool2o`0000;ooooo0ol00005ooooo`;o000000?ooooo
o`000?l000000oooool2o`0000?ooooo0_l0000<ooooo`Co00003Oooool2o`0000Cooooo0_l00006
ooooo`;o00000_ooool2o`0000Kooooo0_l00003oooooa?o000000?oooooo`000?l000003Ol00000
0ooooooo0000o`000002ooooo`;o00004_ooool2o`0000Wooooo0_l0000<ooooo`;o0000>_ooool0
0006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@
olc<c006ooooo`03o`000?oooooooooo03_ooooo0_l00009ooooo`;o00000oooool2o`0000Kooooo
0_l00006ooooo`;o00000_ooool2o`0000Cooooo0ol00002ooooo`;o00000oooool3o`0000Cooooo
0_l0000?ooooo`Go00002?ooool2o`0000?ooooo0_l00006ooooo`;o00001?ooool2o`0000[ooooo
0_l00003ooooo`;o00000oooool>o`000003ooooool0003o000000_o00000oooool2o`0000?ooooo
0_l0000Aooooo`Co00001oooool2o`0004Sooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0foooo
o`;o00002Oooool2o`0000?ooooo0ol0000:ooooo`?o00000oooool2o`0000Cooooo0_l00009oooo
o`Co000000?oooooo`000?l000001Oooool2o`0000?ooooo0_l00005ooooo`Co000000?oooooo`00
0?l000001?l00007ooooo`;o00002oooool2o`000003ooooool0003o000001Cooooo7_l00003oooo
o`;o00001?ooool2o`0001;ooooo0ol00003ooooo`;o0000C?ooool00003ooooool@413ooooo00;o
oooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool0=_ooool2o`0000Wooooo1?l00002ooooo`;o00002oooool2o`0000?ooooo0ol0000@oooo
o`;o000000?oooooo`000?l000002_ooool2o`0000Gooooo1?l00003ooooo`Co00001oooool2o`00
00Kooooo0_l00006ooooo`;o00001_ooool2o`0000cooooo7_l00002ooooo`Co00000oooool5o`00
00Gooooo0ol0000=ooooo`;o0000C?ooool00003ooooool0003ooooo00;ooooo00?o0000oooooooo
ool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol00013ooooo`;o00001?ooool2o`00
00oooooo0_l00007ooooo`;o00000oooool2o`0001[ooooo0ol000000ooooooo0000o`000006o`00
0004ooooool0003o0000o`0000Kooooo1?l0000>ooooo`;o00003ooooolKo`0000;ooooo1?l00000
0ooooooo0000o`000005o`0000Gooooo0ol00005ooooo`;o0000E?ooool00003ooooool0003ooooo
00;ooooo00?o0000ooooooooool02Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000
ooooooooool0@oooool2o`0000Cooooo0_l0000:ooooo`;o00003?ooool4o`000003ooooool0003o
000000Sooooo0_l0000>ooooo`Go000000?oooooo`000?l000001_l000000ooooooo0000o`000002
o`0000Gooooo0_l00005ooooo`;o00006ooooolJo`000003ooooool0003o000000Cooooo0_l0000B
ooooo`;o0000E?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool00omE
EEGoQhN7ooooo`08ooooo`03o`000?oooooooooo03oooooo0_l00005ooooo`;o00001Oooool2o`00
00;ooooo0_l000001?oooooo0000o`000?l0000>ooooo`;o00001_ooool2o`0000?ooooo0_l0000<
ooooo`oo000000?oooooo`000?l000001Ol00009ooooo`?o00004oooool2o`0000Kooooo6Ol00002
ooooo`?o00003_ooool2o`0001Kooooo0_l00015ooooo`0000KoooooogMgMonHV9SooooooiRHV?mg
MgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0?oooool4o`0000?ooooo0_l0
0005ooooo`;o00000_ooool6o`0001Kooooo0_l0000AoooooaOo00001Oooool2o`0000;ooooo0_l0
000Dooooo`;o00001_oooolHo`0000?ooooo0ol00007ooooo`;o00001Oooool2o`0001Kooooo0ol0
0014ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co0000oa0@40Ko
oooo00?o0000ooooooooool0>oooool2o`0000;ooooo1_l00002ooooo`Go00001oooool4o`0000Co
oooo0_l00007ooooo`;o00001_ooool2o`0001Kooooo4?l00006ooooo`Co00008?oooolHo`000003
ooooool0003o000000Go000000?oooooo`000?l000000_ooool2o`0001[ooooo0_l00002ooooo`?o
00003?ooool2o`0003Gooooo000Looooo`03o`000?oooooooooo03[ooooo0ol00006ooooo`?o0000
00?oooooo`000?l000000ol0000?ooooo`?o00001_ooool2o`0000Kooooo0_l00007ooooo`;o0000
3OoooolAo`0000Gooooo0_l00004ooooo`Co00006_oooolHo`000004ooooool0003o0000ooooo`Co
000000Coooooo`000?l0003ooooo1Ol0000Hooooo`;o00000_ooool3o`0000Cooooo0_l00006oooo
o`;o0000=Oooool001cooooo00?o0000ooooooooool0=_ooool2o`0000;ooooo0ol00007ooooo`;o
00000oooool2o`00013ooooo0ol0000Gooooo`;o00001_ooool2o`0000Gooooo4ol00009ooooo`Co
00004_ooool2o`0000Sooooo5?l00003ooooo`;o000000?oooooo`000?l000001_ooool5o`0000_o
oooo0_l00007ooooo`;o00000_ooool2o`0000;ooooo0ol00004ooooo`;o0000?Oooool001cooooo
00?o0000ooooooooool0=_ooool2o`0000?ooooo0_l0000Aooooo`Co00001Oooool2o`000004oooo
ool0003o0000o`00023ooooo0_l00005oooooaCo00001Oooool2o`000003ooooool0003o000000;o
00004_ooool2o`000003ooooool0003o000000;ooooo5_l00002ooooo`;o00001Oooool2o`0000Go
oooo1?l00008ooooo`;o000000?oooooo`000?l000001oooool2o`0000;ooooo0_l00018ooooo`00
7?ooool00ol0003oooooooooo`10ooooo`;o00003?ooool4o`0000Gooooo0_l000000ooooooo0000
o`00000VoooooaKo00001Oooool2o`000003ooooool0003o000001;ooooo0_l00003ooooo`;o0000
0_ooool3o`0000;ooooo3ol00004ooooo`;o00000_ooool2o`000003ooooool0003o000000Gooooo
1?l00008ooooo`;o0000F?ooool001cooooo00?o0000ooooooooool0@?ooool2o`0000Gooooo0ol0
000cooooo`;o00000_oooolGo`0000kooooo0_l00002ooooo`;o00002?ooool2o`0000?ooooo0_l0
0007ooooo`ko00002Oooool3o`0000Wooooo0_l00002ooooo`;o0000G_ooool001cooooo00?o0000
ooooooooool0Aoooool3o`0001gooooo0_l0000Dooooo`;o00000_oooolFo`0000oooooo0_l00002
ooooo`;o00003Oooool2o`000003ooooool0003o000000Cooooo1?l000000ooooooo0000o`000007
o`0000[ooooo0_l0000:ooooo`;o000000?oooooo`000?l000002_ooool2o`0000cooooo0_l00014
ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o000000?oooooo`000?l000000_l0000Loooo
o`Co000000?oooooo`000?l000005OoooolCo`000004ooooool0003o0000o`0001cooooo0_l00000
1?oooooo0000o`000?ooool2o`0000Cooooo0_l00002ooooo`Co000000?oooooo`000?l000000ol0
0002ooooo`;o00004_ooool2o`0000gooooo0_l0000<ooooo`;o0000A?ooool001cooooo00?o0000
ooooooooool0A?ooool2o`000003ooooool0003o000000;o00000oooool2o`0000Gooooo0_l00000
1?oooooo0000o`000?ooool2o`0000[ooooo1?l000000ooooooo0000o`000006ooooo`;o00003Ooo
oolGo`0000Kooooo0_l0000?ooooo`;o00000oooool2o`0000kooooo2?l00004ooooo`?o00002?oo
ool4o`0000gooooo0_l0000Dooooo`;o0000@oooool001cooooo00?o0000ooooooooool0A?ooool2
o`0000;ooooo0_l00003ooooo`?o00001Oooool2o`000004ooooool0003o0000ooooo`;o00005ooo
ool2o`0000Cooooo0_l00003oooooa[o00001Oooool4o`0000oooooo0_l0000<ooooo`;o00001Ooo
ool8o`0000Cooooo0ol00008ooooo`Ko00002oooool2o`0001Cooooo0_l00013ooooo`007?ooool0
0ol0003oooooooooo`14ooooo`;o00001oooool4o`0000Oooooo0_l0000Pooooo`;o00000ooooolJ
o`0000Gooooo0_l0000@ooooo`;o00002Oooool2o`0000;ooooo0_l000000ooooooo0000o`000003
ooooo`So00004?ooool4o`0000Oooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`11oooo
o`;o00003?ooool2o`0000?ooooo0_l00002ooooo`;o00003?ooool2o`0001;ooooo0_l00003oooo
o`;o00000_oooolEo`000003ooooool0003o000000?ooooo0_l0000?ooooo`?o00002Oooool2o`00
00Gooooo0_l00006ooooo`;o000000Coooooo`000?l0003o00003oooool2o`0000Sooooo0ol0001M
ooooo`007?ooool2o`0003oooooo0_l000000ooooooo0000o`00000?ooooo`Co00004?ooool2o`00
01_ooooo6?l00003ooooo`;o00002oooool2o`0000;ooooo0_l0000?ooooo`;o00003?ooool3o`00
00Gooooo0_l0000<ooooo`;o00000oooool3o`0000?ooooo0_l0000Iooooo`;o0000?Oooool001co
oooo00?o0000ooooooooool0?_ooool4o`0000cooooo0_l000001?oooooo0000o`000?l0000Joooo
o`?o00001oooool2o`0000_ooooo5_l0000;ooooo`Co000000?oooooo`000?l000004oooool2o`00
00gooooo1Ol00002ooooo`;o00003?ooool2o`0000Wooooo0_l0000Iooooo`;o0000?Oooool001co
oooo00?o0000ooooooooool0@?ooool2o`0000Oooooo0_l00003ooooo`;o000000?oooooo`000?l0
00000_ooool3o`00013ooooo0_l000001?oooooo0000o`000?ooool3o`0000Oooooo0_l00007oooo
o`;o000000?oooooo`000?l000005Ol00003ooooo`;o00001_ooool4o`00017ooooo0_l00002oooo
o`;o00001?ooool2o`0000[ooooo0ol00002ooooo`;o00006oooool2o`0005Cooooo000Looooo`03
o`000?oooooooooo047ooooo0_l00006ooooo`;o00002_ooool3o`00013ooooo1Ol00004ooooo`Co
000000?oooooo`000?l000000oooool2o`0000Cooooo6_l00003ooooo`;o00001oooool2o`0001;o
oooo0_l00002ooooo`;o00001?ooool2o`0000Wooooo0_l000000ooooooo0000o`000006ooooo`;o
00004_ooool2o`000004ooooool0003o0000o`0000Wooooo0ol00007ooooo`;o0000?oooool001co
oooo00?o0000ooooooooool0??ooool2o`0000?ooooo0_l00006ooooo`;o00001oooool2o`0000Oo
oooo0_l0000<ooooo`;o00001?ooool6o`000003ooooool0003o000000?ooooo0_l00006oooooaSo
0000;oooool2o`0000Cooooo0_l000000ooooooo0000o`000006ooooo`;o00002?ooool2o`0000So
oooo1Ol0000:ooooo`?o00001oooool2o`0003oooooo000Looooo`03o`000?oooooooooo03cooooo
0_l0000Dooooo`;o00001oooool4o`0000Sooooo0_l00006ooooo`;o00000oooool2o`0000Cooooo
0_l00008oooooa7o000000Coooooo`000?l0003o00009oooool2o`0000Sooooo0_l00004ooooo`;o
00002Oooool2o`0000Cooooo0ol000001?oooooo0000o`000?l00009ooooo`;o0000E_ooool001co
oooo00?o0000ooooooooool0D_ooool2o`0000Oooooo1?l00008ooooo`?o00002_ooool2o`000004
ooooool0003o0000ooooo`;o00002?oooolDo`0000Wooooo0ol00004ooooo`;o00005_ooool2o`00
01Cooooo0_l00003ooooo`?o00000oooool3o`0000;ooooo0_l0000Eooooo`;o0000B_ooool001co
oooo00?o0000ooooooooool0COooool2o`0000;ooooo0_l00008ooooo`?o00000_ooool2o`0000;o
oooo0_l00002ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0000Gooooo0_l0000:oooo
o`?o000000?oooooo`000?l000003ol00008ooooo`Ko00000_ooool2o`0000Wooooo0_l0000;oooo
o`;o00004Oooool2o`000004ooooool0003o0000ooooo`Ko00007_ooool2o`0004[ooooo000Loooo
o`03o`000?oooooooooo047ooooo0_l0000:ooooo`;o00000_ooool2o`000003ooooool0003o0000
00[ooooo0_l000001?oooooo0000o`000?l00005ooooo`?o00000_ooool2o`00017ooooo0_l00002
ooooo`Wo000000?oooooo`000?l000001Ol00003ooooo`;o00000oooool2o`0000;ooooo0_l00002
ooooo`;o00000oooool2o`0000Cooooo0_l0000;ooooo`;o00004?ooool3o`000004ooooool0003o
0000ooooo`?o000000?oooooo`000?l00000J_ooool001cooooo00?o0000ooooooooool0@Oooool2
o`00017ooooo0_l0000:ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Gooooo0_l0000<
ooooo`;o00000_ooool9o`000003ooooool0003o000000Co00001?ooool2o`0000_ooooo0_l00003
ooooo`;o00004Oooool2o`0000Cooooo0_l00006ooooo`;o000000?oooooo`000?l000002ol0001[
ooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o00000oooool2o`0000;ooooo0_l00002oooo
o`?o00001Oooool2o`0000_ooooo0_l00003ooooo`Wo00000_ooool2o`0000Oooooo1_l0000Uoooo
o`;o00001_ooool2o`000003ooooool0003o000000;ooooo2Ol0001[ooooo`007?ooool00ol0003o
ooooooooo`1Aooooo`;o00003_ooool2o`0000;ooooo0_l00002ooooo`;o00000_ooool4o`0000Oo
oooo0_l00008ooooo`;o00000oooool8o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`00
0003ooooool0003o000000Co00009oooool6o`0000_ooooo0_l0001^ooooo`007?ooool00ol0003o
ooooooooo`1Aooooo`;o00002?ooool2o`0000Cooooo0_l00007ooooo`;o00000oooool3o`0000;o
oooo0_l00002ooooo`;o00002oooool2o`0000?ooooo1_l00005ooooo`Ko0000:_ooool9o`0000_o
oooo0_l0000[ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0Foooool3o`0000cooooo
0_l00004ooooo`;o00000_ooool2o`0000Kooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo
1?l00004ooooo`;o00008oooool6o`0000oooooo0_l00002ooooo`Co00009Oooool2o`00047ooooo
000Looooo`03o`000?oooooooooo05cooooo0ol0000Kooooo`Co000000?oooooo`000?l000001_oo
ool2o`0000oooooo0_l000000ooooooo0000o`000002ooooo`;o00008oooool7o`0000kooooo0_l0
0002ooooo`Co0000J?ooool001cooooo00?o0000ooooooooool0GOooool2o`0000Cooooo0_l00004
ooooo`;o00002?ooool2o`0000Gooooo0_l00003ooooo`;o00001_ooool2o`0000_ooooo0ol00000
1?oooooo0000o`000?ooool2o`0001Cooooo0_l0000=ooooo`Co000000?oooooo`000?l000001ol0
0004ooooo`;o0000MOooool001cooooo0_l0001Looooo`?o00001Oooool4o`0000;ooooo0_l00005
ooooo`;o000000Coooooo`000?l0003o00002Oooool2o`0000gooooo0_l00003ooooo`Co00002Ooo
ool2o`0000oooooo0_l000000ooooooo0000o`000004ooooo`;o00001?ooool>o`0000?ooooo0ol0
000Fooooo`Co0000Foooool001cooooo00?o0000ooooooooool0FOooool5o`0000Gooooo1Ol00008
ooooo`;o00000_ooool2o`0000Wooooo0_l000000ooooooo0000o`00000:ooooo`;o00000oooool2
o`0000Cooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo1?l000000ooooooo0000o`000004
ooooo`;o00001oooool:o`0000?ooooo0ol00008ooooo`;o00003?ooool5o`0005_ooooo000Loooo
o`03o`000?oooooooooo03oooooo0_l0000Eooooo`Go00002oooool3o`0000Sooooo0_l00003oooo
o`;o00001?ooool2o`0000;ooooo1?l0000Eooooo`;o00003?ooool2o`0000Kooooo1Ol0000?oooo
o`[o00000oooool2o`0000Wooooo0_l00002ooooo`;o00000oooool2o`0000?ooooo0_l0001Noooo
o`007?ooool00ol0003oooooooooo`0oooooo`;o00005Oooool4o`0000?ooooo0_l00008ooooo`;o
00001?ooool2o`0000;ooooo0_l00003ooooo`?o00000oooool2o`0000;ooooo0ol0000;ooooo`;o
00008_ooool3o`0000Sooooo0_l00004ooooo`_o00000_ooool2o`0000gooooo0_l00003ooooo`;o
0000Hoooool001cooooo00?o0000ooooooooool0?oooool2o`0001cooooo1?l0000;ooooo`?o0000
2?ooool2o`0000Sooooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo0_l0000Jooooo`;o0000
0_ooool2o`0000?ooooo0_l00004ooooo`;o00000_ooool2o`0000?ooooo1?l000001?oooooo0000
o`000?ooool6o`0000Kooooo0_l000000ooooooo0000o`00001^ooooo`007?ooool00ol0003ooooo
ooooo`0oooooo`;o00001_ooool2o`0001?ooooo1Ol0000;ooooo`;o00002oooool2o`0000Kooooo
0_l00002ooooo`;o00000_ooool2o`0001oooooo0_l00002ooooo`;o00001?ooool2o`0000?ooooo
0_l00007ooooo`ko00001_ooool7o`0001Cooooo0_l0001Fooooo`007?ooool00ol0003ooooooooo
o`17ooooo`;o00004oooool2o`0000Cooooo0_l0000=ooooo`;o00001_ooool4o`0003Oooooo0_l0
000:ooooo`ko00001Oooool2o`0000;ooooo0_l00002ooooo`;o00005?ooool2o`0005Kooooo000L
ooooo`03o`000?oooooooooo05kooooo0_l00002ooooo`;o00001oooool2o`0000Cooooo0_l00008
ooooo`?o00007_ooool4o`0000Wooooo0_l00006ooooo`;o00003Oooool>o`0000Gooooo0_l0001d
ooooo`007?ooool00ol0003oooooooooo`11ooooo`;o00006Oooool5o`000003ooooool0003o0000
00;o00000_ooool2o`000003ooooool0003o000000oooooo0_l0000Dooooo`;o00002?ooool4o`00
00Wooooo0_l000000ooooooo0000o`000003ooooo`;o00004?ooool;o`0000gooooo0ol00007oooo
o`;o0000H_ooool001cooooo00?o0000ooooooooool0@Oooool2o`0000Wooooo0_l0000>ooooo`;o
000000?oooooo`000?l000001Ol00002ooooo`;o00001oooool2o`0000?ooooo0_l00002ooooo`;o
00005_ooool2o`00013ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00005?ooool<o`00
0003ooooool0003o000000[ooooo0ol00007ooooo`;o0000H_ooool001cooooo00?o0000oooooooo
ool0C?ooool2o`0000oooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00006ooooo`;o
000000?oooooo`000?l000000_ooool3o`0000;ooooo0_l00005ooooo`Go00000oooool2o`000003
ooooool0003o000000_ooooo0_l00003ooooo`;o00001?ooool2o`0000;ooooo0_l000000ooooooo
0000o`00000Eooooo`_o00000_ooool2o`0000;ooooo0_l0000@ooooo`;o0000H_ooool001cooooo
00?o0000ooooooooool0GOooool3o`0000;ooooo0_l00002ooooo`;o00001_ooool2o`0000;ooooo
0_l000000ooooooo0000o`00000:ooooo`Go00000oooool2o`000003ooooool0003o000000_ooooo
0_l00003ooooo`;o00002oooool2o`0001Oooooo2Ol00006ooooo`;o00004?ooool2o`0006;ooooo
000Looooo`03o`000?oooooooooo05kooooo0_l0000Aooooo`?o000000Coooooo`000?l0003ooooo
0_l00003ooooo`;o00002Oooool2o`0001Cooooo0_l00002ooooo`;o000000?oooooo`000?l00000
1?ooool2o`0001Sooooo2?l0000Tooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0DOoo
ool2o`0001Oooooo0_l00003ooooo`Co00000_ooool2o`000003ooooool0003o000000?ooooo0_l0
0009ooooo`;o00006?ooool2o`000003ooooool0003o000001gooooo0_l000000ooooooo0000o`00
0002o`0002Kooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o00005oooool2
o`0000;ooooo1?l000001?oooooo0000o`000?l00004ooooo`;o00003Oooool2o`0001_ooooo0_l0
000Hooooo`;o00000_ooool2o`000003ooooool0003o000000Cooooo0_l0000>ooooo`;o00005ooo
ool2o`00057ooooo000Looooo`03o`000?oooooooooo05;ooooo0_l0000Fooooo`;o00000_ooool9
o`0000?ooooo0ol00003ooooo`;o00001oooool2o`0001_ooooo0_l0000Cooooo`Oo00002oooool2
o`0000kooooo0_l0000?ooooo`;o00001_ooool2o`00057ooooo000Looooo`;o0000Doooool2o`00
01Kooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000ol00002oooo
o`?o00000_ooool2o`0000Oooooo0_l0000:ooooo`;o00005?ooool2o`0000kooooo1_l0000]oooo
o`;o0000FOooool001cooooo00?o0000ooooooooool0KOooool2o`0000?ooooo0_l00003ooooo`;o
00000oooool2o`0000?ooooo0_l0000;ooooo`;o00001Oooool2o`0001Cooooo0_l00007ooooo`;o
00002_ooool2o`0008Oooooo000Looooo`03o`000?oooooooooo05?ooooo0_l0000=ooooo`;o0000
2oooool2o`000004ooooool0003o0000ooooo`;o00001Oooool4o`000003ooooool0003o000000;o
00002Oooool2o`00013ooooo0_l0000Booooo`;o00002_ooool2o`0008Oooooo000Looooo`03o`00
0?oooooooooo05?ooooo0_l0000=ooooo`;o00002oooool2o`0000Cooooo0ol00006ooooo`;o0000
0oooool2o`0001_ooooo0_l000000ooooooo0000o`00000=ooooo`;o00003?ooool2o`0008Oooooo
000Looooo`03o`000?oooooooooo06[ooooo0_l00009ooooo`?o00001Oooool4o`0000Cooooo0_l0
000=ooooo`;o00000oooool3o`0000Kooooo0ol0000=ooooo`;o000000Coooooo`000?l0003o0000
1oooool3o`0002Cooooo0_l0001Qooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o00000ooo
ool2o`0000Wooooo0_l00002ooooo`;o00000_ooool6o`0000;ooooo1?l00003ooooo`Go00000ooo
ool2o`0000?ooooo0ol00006ooooo`;o00003_ooool2o`000004ooooool0003o0000o`0000Oooooo
0_l000001?oooooo0000o`000?ooool2o`0001oooooo0_l0001Qooooo`007?ooool00ol0003ooooo
ooooo`1Uooooo`;o00001Oooool2o`0000Oooooo0_l00002ooooo`;o00001_ooool2o`0000?ooooo
0ol00002ooooo`Ko00001oooool3o`000003ooooool0003o000000;o00003oooool5o`0000_ooooo
0_l000001?oooooo0000o`000?ooool2o`0001gooooo0_l0001Sooooo`007?ooool00ol0003ooooo
ooooo`1/ooooo`;o00002oooool4o`0000Gooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo
0_l00007ooooo`;o00000_ooool4o`0000cooooo0_l000000ooooooo0000o`000002o`0000cooooo
0_l000000ooooooo0000o`00000Pooooo`;o0000Hoooool001cooooo00?o0000ooooooooool0Kooo
ool2o`0000Sooooo1Ol00004ooooo`;o00004Oooool2o`0001Gooooo0_l000000ooooooo0000o`00
0008ooooo`;o00001oooool2o`0000?ooooo0_l00020ooooo`007?ooool00ol0003oooooooooo`1_
ooooo`Co00001Oooool6o`000003ooooool0003o000000_ooooo0_l00007ooooo`;o00006?ooool2
o`0000;ooooo0_l00004ooooo`;o00001oooool2o`0000?ooooo0_l00020ooooo`007?ooool00ol0
003oooooooooo`1aooooo`;o00001Oooool6o`000003ooooool0003o000000[ooooo0ol0000Boooo
o`;o00004?ooool3o`0000gooooo0_l0000Oooooo`;o0000I?ooool001cooooo00?o0000oooooooo
ool0N?ooool2o`0000kooooo0_l000000ooooooo0000o`000002ooooo`;o00001?ooool4o`0000Go
oooo1?l0000=ooooo`;o000000Coooooo`000?l0003ooooo0_l0000/ooooo`;o0000I?ooool001co
oooo00?o0000ooooooooool0N?ooool2o`0000?ooooo0_l00009ooooo`;o00001Oooool2o`000004
ooooool0003o0000ooooo`Co00001Oooool4o`000003ooooool0003o000000?ooooo0_l00005oooo
o`;o000000?oooooo`000?l000001?l0000:ooooo`Co00005Oooool2o`0006cooooo000Looooo`03
o`000?oooooooooo05oooooo0_l0000Kooooo`?o00001_ooool2o`0000_ooooo0ol000000ooooooo
0000o`000003ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000003ooooo`;o
00002Oooool5o`0000Oooooo0_l000000ooooooo0000o`000002o`0001Gooooo1?l0001Zooooo`00
00Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0Goooool2o`00013ooooo0_l00009ooooo`;o00001Oooool4
o`0000cooooo0_l000000ooooooo0000o`000005o`000003ooooool0003o000000[ooooo0ol00006
ooooo`;o00002_ooool2o`0001;ooooo0_l00006ooooo`Co0000J_ooool00006oooooomgMgOoV9RH
oooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`00
0?oooooooooo06;ooooo0_l0000=ooooo`;o00002_ooool2o`0000Cooooo0_l0000Cooooo`Co0000
0_ooool2o`0000[ooooo0ol00003ooooo`;o00008Oooool2o`0007Cooooo00000ooooooo410@oooo
o`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo06;ooooo0_l0000Iooooo`;o00002Oooool2o`0000Kooooo0_l0000<ooooo`;o0000
4?ooool2o`0009Oooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go
<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000O?ooool2o`0000[ooooo0_l00006ooooo`;o0000
5oooool2o`0000gooooo0_l0002?ooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooooooo
o`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`1Wooooo`;o0000
4oooool4o`0000Oooooo1?l00004ooooo`;o00000_ooool2o`0001Cooooo0ol0000<ooooo`?o0000
00?oooooo`000?l000004Oooool2o`0007Sooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oo
oooooooo00Wooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo06Oooooo
0_l0000Aooooo`;o00000_ooool2o`0000Oooooo1?l00004ooooo`;o00000_ooool2o`000003oooo
ool0003o000000?ooooo0_l0000=ooooo`;o00003Oooool2o`000004ooooool0003o0000o`00013o
oooo0_l0001hooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooo
okZj^_l000001_ooool00ol0003oooooooooo`1^ooooo`;o00002_ooool2o`0000kooooo0_l00006
ooooo`Ko00000oooool2o`0001Wooooo1?l00003ooooo`;o00000oooool2o`0008Gooooo00001_oo
ooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`00
0?oooooooooo06kooooo0_l0000Iooooo`?o00001_ooool2o`000004ooooool0003o0000o`0000Oo
oooo0_l0000Booooo`;o000000?oooooo`000?l000000_l00008ooooo`;o0000QOooool001cooooo
00?o0000ooooooooool0L_ooool2o`0000cooooo0_l00007ooooo`;o000000?oooooo`000?l00000
0_l00004ooooo`;o00002Oooool2o`00013ooooo1?l000000ooooooo0000o`00002Aooooo`007?oo
ool00ol0003oooooooooo`1booooo`;o00003?ooool2o`0000[ooooo1?l00004ooooo`;o00000ooo
ool2o`0001Kooooo0_l00007ooooo`?o0000S?ooool001cooooo00?o0000ooooooooool0SOooool5
o`0000;ooooo0_l00003ooooo`;o00007oooool3o`0008cooooo000Looooo`03o`000?oooooooooo
08cooooo1_l0000:ooooo`;o00003?ooool5o`0001Kooooo0_l00022ooooo`007?ooool00ol0003o
ooooooooo`1booooo`;o00002_ooool2o`0000;ooooo0_l00008ooooo`;o00001Oooool2o`0000Oo
oooo1Ol00009ooooo`Go00001oooool2o`0000gooooo0_l00022ooooo`007?ooool00ol0003ooooo
ooooo`1Tooooo`;o00003?ooool2o`0000[ooooo0_l00002ooooo`;o00001_ooool2o`0000Oooooo
0_l00004ooooo`;o00000_ooool4o`0000_ooooo0_l00008ooooo`;o0000TOooool001cooooo00?o
0000ooooooooool0I?ooool2o`0001Cooooo0_l0000>ooooo`;o00001Oooool2o`0000Kooooo0_l0
0004ooooo`;o000000?oooooo`000?l000001_ooool2o`0000[ooooo0_l0002Aooooo`007?ooool0
0ol0003oooooooooo`1jooooo`;o00004_ooool5o`0000cooooo1Ol00006ooooo`;o00002_ooool2
o`00097ooooo000Looooo`03o`000?oooooooooo07oooooo0_l0000=ooooo`Co00002_ooool2o`00
00?ooooo0_l0002Vooooo`007?ooool00ol0003oooooooooo`1oooooo`;o00003_ooool2o`0000_o
oooo0_l0000?ooooo`?o00003_ooool2o`0008Wooooo000Looooo`03o`000?oooooooooo0:?ooooo
0_l00008ooooo`?o00003_ooool2o`0008Wooooo000Looooo`;o0000Y?ooool2o`0000[ooooo0_l0
0004ooooo`;o0000T_ooool001cooooo00?o0000ooooooooool0X?ooool2o`0000Sooooo0_l00002
ooooo`?o00001?ooool2o`0009;ooooo000Looooo`03o`000?oooooooooo07Cooooo0_l0000Poooo
o`;o00001oooool3o`0000Sooooo0_l00002ooooo`;o00001oooool2o`00093ooooo000Looooo`03
o`000?oooooooooo07Cooooo0_l0000Pooooo`;o00001oooool2o`0001Kooooo0_l0002@ooooo`00
7?ooool00ol0003oooooooooo`2Cooooo`;o00006?ooool2o`0001Kooooo0_l00022ooooo`007?oo
ool00ol0003oooooooooo`2Cooooo`Co00005_ooool2o`0001Kooooo0_l00022ooooo`007?ooool0
0ol0003oooooooooo`2Eooooo`;o0000/_ooool001cooooo00?o0000ooooooooool0Soooool2o`00
0;Sooooo000Looooo`03o`000?oooooooooo08oooooo0_l0000:ooooo`;o00001oooool2o`000:?o
oooo000Looooo`03o`000?oooooooooo09_ooooo0_l00007ooooo`;o0000Xoooool001cooooo00?o
0000ooooooooool0Woooool3o`000:Oooooo000Looooo`03o`000?oooooooooo07gooooo0_l0000P
ooooo`?o0000Yoooool001cooooo00?o0000ooooooooool0OOooool2o`000<[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo08Wooooo0_l0002nooooo`00
7?ooool00ol0003oooooooooo`29ooooo`;o0000__ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001;ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooo
oooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooo
od[ooooo000Dooooo`03o`000?oooooooooo00Gooooo0ol0003ooooood[ooooo000Dooooo`03o`00
0?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool0
0ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001;o
oooo00?oEEEEofIVI_l00000oooooomDooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00YOooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo01Gooooo00Goc<c<
ob4Q8Ol0003o8B4Qolc<c003ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`00oooool5o`00093ooooo
002Vooooo`05o`000?ooooooooooooooool000002Oooool6o`0000Wooooo00Go8B4QoiRHV?oooooo
V9RHob4Q8@03ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B400oooool01OnHV9So8B4Qonk^k_oooooo
A4A4093ooooo002Vooooo`05o`000?ooooooooooooooool000006?ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000004ooooo`03oiRHV?lQ8B7ok^k^097ooooo
002Vooooo`05o`000?ooooooooooooooool000002Oooool6o`0000Wooooo00Go<S8boiRHV?oooooo
V9RHoc8b<P03ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801Oooool00onHV9So8B4Qonk^kP2@oooo
o`00Y_ooool01Ol0003oQhN7oooooonYZJWo000001Sooooo00Goc<c<o`000?l0003o0000olc<c003
ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00omgMgOoIVIVooooo`2?ooooo`00YOooool0
0ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo01Kooooo00Go410@okZj^_oooooo^[Zjoa0@
4003ooooo`05oa0@4?nj^[[ooooookZj^_l@41001oooool00ol0003oooooooooo`2>ooooo`00`ooo
ool01Ol0003o^[Zjoooooonj^[[o000000?ooooo00Go0000okZj^_oooooo^[Zjo`000003ooooo`05
o`000?nj^[[ooooooiRHV?l@4100T?ooool00<?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03oooo
o`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01OnHV9So410@o`000?lQ8B7oc<c<093ooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(888) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.35289 .5167 Mdot
.31717 .51614 Mdot
.58821 .62547 Mdot
.46481 .35079 Mdot
.39862 .471 Mdot
.60894 .60588 Mdot
.43376 .65054 Mdot
.43198 .60405 Mdot
.61578 .62192 Mdot
.55936 .30786 Mdot
.41756 .61642 Mdot
.55308 .40548 Mdot
.41185 .6449 Mdot
.47152 .36858 Mdot
.84709 .44462 Mdot
.44005 .42768 Mdot
.28807 .49791 Mdot
.69609 .47394 Mdot
.55087 .35809 Mdot
.61261 .57281 Mdot
.35651 .46046 Mdot
.46561 .3726 Mdot
.35654 .50599 Mdot
.47186 .36931 Mdot
.48813 .3402 Mdot
.33531 .50054 Mdot
.27768 .50988 Mdot
.50851 .33551 Mdot
.5104 .36 Mdot
.4034 .61276 Mdot
.66541 .43929 Mdot
.77716 .32176 Mdot
.48298 .43954 Mdot
.18621 .43931 Mdot
.44037 .61006 Mdot
.54819 .22015 Mdot
.64286 .61627 Mdot
.39709 .64418 Mdot
.43224 .60571 Mdot
.45231 .61597 Mdot
.39954 .63918 Mdot
.32747 .49938 Mdot
.41226 .58697 Mdot
.38219 .598 Mdot
.43884 .38803 Mdot
.33437 .67003 Mdot
.66432 .29136 Mdot
.51747 .39185 Mdot
.31337 .52763 Mdot
.62706 .56899 Mdot
.20632 .51022 Mdot
.42801 .59479 Mdot
.5779 .7229 Mdot
.64256 .13617 Mdot
.4079 .65485 Mdot
.44096 .37186 Mdot
.63177 .60973 Mdot
.47178 .39314 Mdot
.47399 .37679 Mdot
.30102 .43476 Mdot
.51997 .34955 Mdot
.70643 .51445 Mdot
.36659 .47527 Mdot
.65729 .62125 Mdot
.61296 .61093 Mdot
.42098 .60683 Mdot
.29144 .49834 Mdot
.42025 .64519 Mdot
.48812 .31944 Mdot
.65015 .60365 Mdot
.51682 .39286 Mdot
.40781 .61773 Mdot
.3654 .51822 Mdot
.49817 .41501 Mdot
.36586 .74565 Mdot
.83639 .53756 Mdot
.66913 .50639 Mdot
.3292 .41757 Mdot
.38862 .39818 Mdot
.76816 .65221 Mdot
.4959 .36462 Mdot
.63287 .81008 Mdot
.84419 .4673 Mdot
.35069 .51596 Mdot
.48249 .29805 Mdot
.57614 .64314 Mdot
.48039 .41925 Mdot
.49784 .51033 Mdot
.44846 .33962 Mdot
.30948 .71496 Mdot
.62003 .62422 Mdot
.30627 .49597 Mdot
.46534 .35172 Mdot
.53443 .38631 Mdot
.30037 .3513 Mdot
.53953 .35607 Mdot
.48107 .3321 Mdot
.31437 .544 Mdot
.43246 .61678 Mdot
.51032 .44486 Mdot
.37925 .65785 Mdot
.60136 .72335 Mdot
.4471 .39394 Mdot
.63517 .63302 Mdot
.32482 .54423 Mdot
.46435 .41641 Mdot
.44223 .65232 Mdot
.51835 .37409 Mdot
.39977 .58497 Mdot
.31327 .51884 Mdot
.53428 .39055 Mdot
.71467 .47681 Mdot
.42985 .80483 Mdot
.30773 .49023 Mdot
.56067 .76908 Mdot
.52497 .37462 Mdot
.46023 .3816 Mdot
.31731 .51346 Mdot
.60793 .58869 Mdot
.56678 .48799 Mdot
.3011 .52627 Mdot
.45066 .61898 Mdot
.29302 .47693 Mdot
.45049 .31556 Mdot
.60631 .6251 Mdot
.59614 .73502 Mdot
.58405 .743 Mdot
.62494 .40891 Mdot
.472 .4167 Mdot
.26993 .58206 Mdot
.60603 .59956 Mdot
.31083 .49894 Mdot
.41857 .64183 Mdot
.43175 .39169 Mdot
.32114 .47555 Mdot
.42213 .62555 Mdot
.72613 .50178 Mdot
.71644 .54909 Mdot
.3132 .53181 Mdot
.48892 .63081 Mdot
.46078 .62071 Mdot
.45507 .62372 Mdot
.18892 .46797 Mdot
.32196 .51896 Mdot
.69301 .49104 Mdot
.42574 .63156 Mdot
.71764 .38593 Mdot
.44537 .35588 Mdot
.60047 .4076 Mdot
.50895 .85727 Mdot
.19973 .51577 Mdot
.48151 .75895 Mdot
.68044 .49414 Mdot
.45517 .63644 Mdot
.49848 .34912 Mdot
.33125 .51907 Mdot
.33043 .51066 Mdot
.4931 .32563 Mdot
.48196 .33736 Mdot
.51413 .40139 Mdot
.53293 .38136 Mdot
.71136 .32265 Mdot
.52486 .39603 Mdot
.65796 .52501 Mdot
.31725 .48481 Mdot
.50485 .3416 Mdot
.60455 .58575 Mdot
.46482 .4295 Mdot
.40121 .62813 Mdot
.46698 .38295 Mdot
.46861 .34404 Mdot
.534 .40323 Mdot
.40851 .65936 Mdot
.74074 .29802 Mdot
.48751 .84893 Mdot
.56703 .18991 Mdot
.52583 .76591 Mdot
.62902 .59389 Mdot
.46006 .40493 Mdot
.69972 .49974 Mdot
.44205 .25853 Mdot
.48893 .3721 Mdot
.19434 .63327 Mdot
.46988 .33941 Mdot
.24079 .34431 Mdot
.41439 .45089 Mdot
.56566 .18282 Mdot
.60962 .50219 Mdot
.51576 .36014 Mdot
.31829 .31082 Mdot
.38308 .23158 Mdot
.4161 .56306 Mdot
.4011 .64331 Mdot
.60081 .58949 Mdot
.63379 .61802 Mdot
.44166 .59269 Mdot
.4611 .44762 Mdot
.50891 .4577 Mdot
.56798 .38867 Mdot
.59057 .73201 Mdot
.36866 .51079 Mdot
.70044 .52809 Mdot
.34116 .53723 Mdot
.72056 .76874 Mdot
.27916 .68428 Mdot
.43361 .58296 Mdot
.68083 .53259 Mdot
.58754 .61719 Mdot
.58806 .73236 Mdot
.70132 .49301 Mdot
.50262 .38788 Mdot
.30514 .51962 Mdot
.26241 .29858 Mdot
.40838 .42531 Mdot
.27464 .26819 Mdot
.32444 .47048 Mdot
.55472 .5072 Mdot
.4138 .62792 Mdot
.59221 .58306 Mdot
.45651 .37182 Mdot
.4977 .40412 Mdot
.37831 .48 Mdot
.51514 .39116 Mdot
.39321 .49125 Mdot
.45998 .34831 Mdot
.58363 .57935 Mdot
.67126 .49344 Mdot
.43811 .59183 Mdot
.61915 .41465 Mdot
.36236 .50583 Mdot
.57109 .56547 Mdot
.63557 .57494 Mdot
.46212 .25081 Mdot
.41159 .61564 Mdot
.71939 .48164 Mdot
.6294 .57641 Mdot
.69006 .5293 Mdot
.48916 .42828 Mdot
.64502 .61387 Mdot
.6831 .50893 Mdot
.73736 .32466 Mdot
.43621 .39519 Mdot
.73346 .35807 Mdot
.43618 .64558 Mdot
.29628 .47369 Mdot
.51767 .34639 Mdot
.58997 .74901 Mdot
.5202 .42676 Mdot
.44608 .72875 Mdot
.57664 .73332 Mdot
.58693 .70899 Mdot
.79224 .60779 Mdot
.70542 .47695 Mdot
.43659 .76792 Mdot
.24278 .57062 Mdot
.28912 .50186 Mdot
.44985 .36216 Mdot
.63277 .2032 Mdot
.425 .63152 Mdot
.5008 .38445 Mdot
.5685 .61603 Mdot
.42714 .63467 Mdot
.47263 .39847 Mdot
.42592 .66244 Mdot
.32904 .51544 Mdot
.6586 .71192 Mdot
.28903 .48939 Mdot
.43555 .38805 Mdot
.43923 .65251 Mdot
.63811 .58779 Mdot
.33901 .50215 Mdot
.51523 .37576 Mdot
.45479 .38023 Mdot
.5936 .72351 Mdot
.51322 .35021 Mdot
.64399 .2171 Mdot
.52739 .36272 Mdot
.60413 .64003 Mdot
.53486 .35255 Mdot
.17913 .59128 Mdot
.69502 .58709 Mdot
.29198 .50225 Mdot
.58394 .71323 Mdot
.61932 .61713 Mdot
.74229 .63733 Mdot
.46965 .5787 Mdot
.50881 .36753 Mdot
.59324 .71201 Mdot
.60455 .48198 Mdot
.40076 .61045 Mdot
.5379 .3466 Mdot
.31171 .69737 Mdot
.61342 .57629 Mdot
.58946 .72951 Mdot
.54251 .33293 Mdot
.32632 .5448 Mdot
.46658 .34935 Mdot
.64408 .59231 Mdot
.29038 .47878 Mdot
.45293 .4183 Mdot
.6143 .27641 Mdot
.57934 .7373 Mdot
.43404 .6469 Mdot
.4416 .46272 Mdot
.52035 .39724 Mdot
.63913 .60885 Mdot
.35588 .49088 Mdot
.44419 .61564 Mdot
.32941 .49312 Mdot
.32238 .25397 Mdot
.51816 .77466 Mdot
.67982 .28661 Mdot
.68359 .5354 Mdot
.49378 .7056 Mdot
.5422 .17893 Mdot
.45594 .78725 Mdot
.673 .38278 Mdot
.41129 .18183 Mdot
.61755 .57988 Mdot
.67833 .54813 Mdot
.62331 .6124 Mdot
.48368 .35376 Mdot
.61 .60947 Mdot
.56423 .17751 Mdot
.4658 .341 Mdot
.63291 .59863 Mdot
.69634 .66934 Mdot
.49373 .33502 Mdot
.30851 .48768 Mdot
.83726 .43607 Mdot
.32816 .75563 Mdot
.21552 .59763 Mdot
.62234 .58688 Mdot
.35191 .44342 Mdot
.50472 .33471 Mdot
.47884 .43638 Mdot
.33739 .51802 Mdot
.53126 .34321 Mdot
.7028 .52674 Mdot
.69528 .53243 Mdot
.59788 .42839 Mdot
.56232 .8176 Mdot
.5154 .44515 Mdot
.33988 .50566 Mdot
.4076 .32094 Mdot
.36146 .73773 Mdot
.60444 .73492 Mdot
.39768 .67154 Mdot
.75319 .31436 Mdot
.47836 .45418 Mdot
.48535 .63118 Mdot
.33226 .71193 Mdot
.30216 .50833 Mdot
.6915 .26563 Mdot
.40506 .64891 Mdot
.3636 .2945 Mdot
.23282 .39808 Mdot
.49904 .39821 Mdot
.41922 .61219 Mdot
.54123 .42951 Mdot
.279 .70375 Mdot
.74527 .40352 Mdot
.77666 .68705 Mdot
.43718 .39046 Mdot
.41756 .76026 Mdot
.46308 .38128 Mdot
.57809 .45985 Mdot
.52783 .36253 Mdot
.33509 .49214 Mdot
.52408 .28108 Mdot
.45816 .53308 Mdot
.54433 .83732 Mdot
.26658 .67201 Mdot
.67909 .49919 Mdot
.45676 .37883 Mdot
.49774 .39955 Mdot
.71275 .48338 Mdot
.34885 .49391 Mdot
.52905 .37076 Mdot
.6121 .32336 Mdot
.50945 .40098 Mdot
.3971 .63639 Mdot
.63119 .45732 Mdot
.38766 .49259 Mdot
.5374 .39369 Mdot
.28411 .49873 Mdot
.4147 .6606 Mdot
.42163 .60496 Mdot
.46714 .31729 Mdot
.44717 .65267 Mdot
.46216 .35042 Mdot
.735 .44522 Mdot
.34002 .52662 Mdot
.40455 .42583 Mdot
.34723 .48703 Mdot
.378 .41731 Mdot
.43996 .6565 Mdot
.59081 .74534 Mdot
.27726 .55315 Mdot
.40833 .64927 Mdot
.21205 .57447 Mdot
.5636 .41791 Mdot
.54299 .40799 Mdot
.25786 .679 Mdot
.62558 .58377 Mdot
.58809 .74073 Mdot
.44604 .64582 Mdot
.51908 .39877 Mdot
.5495 .37308 Mdot
.39276 .64234 Mdot
.32739 .35082 Mdot
.74635 .62378 Mdot
.49852 .33158 Mdot
.3407 .49258 Mdot
.31289 .49717 Mdot
.46526 .42297 Mdot
.50699 .37381 Mdot
.59785 .63246 Mdot
.58073 .72265 Mdot
.60318 .7163 Mdot
.58395 .74166 Mdot
.57728 .60121 Mdot
.34975 .63746 Mdot
.45324 .6181 Mdot
.30248 .60121 Mdot
.4198 .71724 Mdot
.41081 .39917 Mdot
.64051 .60158 Mdot
.48749 .40142 Mdot
.46191 .35951 Mdot
.44491 .61733 Mdot
.50826 .72638 Mdot
.47394 .30037 Mdot
.3279 .53322 Mdot
.44346 .65626 Mdot
.53271 .44338 Mdot
.34802 .59042 Mdot
.69264 .52067 Mdot
.21431 .60259 Mdot
.4123 .61346 Mdot
.29872 .50127 Mdot
.39787 .65853 Mdot
.50173 .40152 Mdot
.46519 .33425 Mdot
.31086 .51118 Mdot
.69732 .47775 Mdot
.51374 .31749 Mdot
.47134 .39943 Mdot
.27947 .76817 Mdot
.36976 .74864 Mdot
.44767 .68326 Mdot
.50662 .35372 Mdot
.54866 .38522 Mdot
.67659 .51315 Mdot
.50748 .39924 Mdot
.45292 .37933 Mdot
.43804 .8128 Mdot
.42463 .69563 Mdot
.70669 .46919 Mdot
.36933 .2911 Mdot
.32146 .47087 Mdot
.687 .24521 Mdot
.60101 .71527 Mdot
.4033 .59887 Mdot
.64696 .71494 Mdot
.5849 .73035 Mdot
.4572 .72044 Mdot
.69164 .25743 Mdot
.58501 .7414 Mdot
.5628 .62825 Mdot
.50836 .29023 Mdot
.48914 .32853 Mdot
.46449 .38767 Mdot
.69575 .50402 Mdot
.32421 .51886 Mdot
.58349 .50478 Mdot
.77771 .4275 Mdot
.46324 .37531 Mdot
.31579 .45563 Mdot
.75748 .33873 Mdot
.59066 .72411 Mdot
.71509 .51492 Mdot
.72652 .51714 Mdot
.45983 .38508 Mdot
.4721 .81342 Mdot
.33612 .50234 Mdot
.51486 .37546 Mdot
.52526 .40194 Mdot
.6263 .5873 Mdot
.29774 .51045 Mdot
.63863 .57807 Mdot
.57725 .73811 Mdot
.42475 .20661 Mdot
.24318 .73297 Mdot
.44507 .62365 Mdot
.60226 .21515 Mdot
.40764 .60504 Mdot
.79586 .63887 Mdot
.5818 .73232 Mdot
.49343 .369 Mdot
.36364 .50764 Mdot
.5191 .37579 Mdot
.49469 .3867 Mdot
.50171 .38919 Mdot
.5584 .42147 Mdot
.19204 .62545 Mdot
.71029 .49737 Mdot
.41945 .35637 Mdot
.61232 .63994 Mdot
.62702 .21689 Mdot
.82326 .46751 Mdot
.48791 .40753 Mdot
.4573 .38927 Mdot
.3129 .48193 Mdot
.50016 .32623 Mdot
.39376 .62157 Mdot
.35689 .49185 Mdot
.5306 .40777 Mdot
.67986 .26168 Mdot
.52958 .3757 Mdot
.54268 .1865 Mdot
.39557 .65623 Mdot
.21436 .57872 Mdot
.42521 .34739 Mdot
.5868 .74414 Mdot
.58771 .74088 Mdot
.60192 .70344 Mdot
.38713 .64966 Mdot
.63704 .60368 Mdot
.80042 .48222 Mdot
.45563 .44131 Mdot
.49538 .34684 Mdot
.55045 .37739 Mdot
.58521 .6412 Mdot
.4956 .50671 Mdot
.46224 .76732 Mdot
.53998 .4394 Mdot
.59774 .62478 Mdot
.29966 .47063 Mdot
.56365 .74349 Mdot
.35712 .49441 Mdot
.70366 .46908 Mdot
.41417 .61871 Mdot
.69845 .52373 Mdot
.20779 .54321 Mdot
.31471 .51754 Mdot
.38017 .48433 Mdot
.63092 .59527 Mdot
.53566 .52683 Mdot
.60971 .13864 Mdot
.65138 .61537 Mdot
.63112 .37189 Mdot
.34216 .51342 Mdot
.52604 .40604 Mdot
.61826 .47171 Mdot
.52804 .52549 Mdot
.6254 .60083 Mdot
.48423 .36483 Mdot
.53309 .81755 Mdot
.59592 .63002 Mdot
.53964 .34802 Mdot
.6013 .59825 Mdot
.40293 .62964 Mdot
.60512 .59734 Mdot
.35989 .48933 Mdot
.46019 .41217 Mdot
.63946 .14553 Mdot
.58769 .53505 Mdot
.52295 .35866 Mdot
.44273 .65677 Mdot
.58828 .29403 Mdot
.48666 .38939 Mdot
.70854 .52589 Mdot
.60409 .62531 Mdot
.75591 .58894 Mdot
.51131 .33836 Mdot
.615 .59633 Mdot
.35631 .5123 Mdot
.38223 .63734 Mdot
.8028 .59813 Mdot
.59841 .73727 Mdot
.33339 .52269 Mdot
.573 .72774 Mdot
.42274 .67185 Mdot
.54789 .37435 Mdot
.52226 .40181 Mdot
.32745 .48664 Mdot
.65399 .74484 Mdot
.52746 .3479 Mdot
.49559 .36467 Mdot
.58528 .60991 Mdot
.59786 .64796 Mdot
.66714 .72258 Mdot
.62147 .57962 Mdot
.54533 .3477 Mdot
.32775 .48734 Mdot
.46807 .35495 Mdot
.30349 .48937 Mdot
.45223 .35973 Mdot
.26519 .50727 Mdot
.34845 .51779 Mdot
.54033 .79266 Mdot
.47595 .35865 Mdot
.42382 .45556 Mdot
.498 .38922 Mdot
.51364 .39591 Mdot
.61449 .63601 Mdot
.7169 .4965 Mdot
.42661 .37548 Mdot
.63915 .54198 Mdot
.71783 .51544 Mdot
.34043 .25096 Mdot
.62333 .58558 Mdot
.69319 .51136 Mdot
.73578 .35035 Mdot
.58856 .70929 Mdot
.7044 .5032 Mdot
.82377 .45504 Mdot
.44514 .62133 Mdot
.31674 .46808 Mdot
.49305 .33529 Mdot
.39076 .19324 Mdot
.7091 .43369 Mdot
.5931 .71674 Mdot
.52557 .36174 Mdot
.48626 .39788 Mdot
.30302 .53505 Mdot
.68691 .79013 Mdot
.5895 .63241 Mdot
.48366 .34962 Mdot
.29283 .48885 Mdot
.54416 .85791 Mdot
.62676 .63662 Mdot
.70106 .50293 Mdot
.39476 .64743 Mdot
.29404 .5421 Mdot
.59954 .73649 Mdot
.39611 .61423 Mdot
.62389 .70567 Mdot
.20551 .56701 Mdot
.52598 .37657 Mdot
.6426 .60621 Mdot
.19437 .52982 Mdot
.47397 .44672 Mdot
.46609 .66261 Mdot
.57113 .43422 Mdot
.30147 .5051 Mdot
.39377 .64251 Mdot
.68563 .52192 Mdot
.35721 .489 Mdot
.34806 .49551 Mdot
.43662 .60366 Mdot
.61404 .67428 Mdot
.54981 .51083 Mdot
.39843 .62795 Mdot
.32021 .71852 Mdot
.2839 .28316 Mdot
.58714 .71376 Mdot
.72166 .50297 Mdot
.20575 .38453 Mdot
.32781 .49871 Mdot
.75062 .31101 Mdot
.19237 .57645 Mdot
.48174 .33193 Mdot
.68747 .50296 Mdot
.37115 .68567 Mdot
.79917 .46484 Mdot
.42958 .63754 Mdot
.44766 .51764 Mdot
.73145 .49978 Mdot
.50941 .3339 Mdot
.25921 .47287 Mdot
.48615 .35887 Mdot
.41441 .62226 Mdot
.38864 .42675 Mdot
.29847 .49978 Mdot
.43079 .67049 Mdot
.21157 .5991 Mdot
.45916 .36177 Mdot
.48159 .36136 Mdot
.64623 .4378 Mdot
.30745 .52251 Mdot
.60388 .72327 Mdot
.5173 .3687 Mdot
.46975 .39189 Mdot
.54298 .39065 Mdot
.47099 .46269 Mdot
.44406 .80305 Mdot
.48194 .3508 Mdot
.60027 .57175 Mdot
.49355 .43451 Mdot
.47495 .36121 Mdot
.28483 .50243 Mdot
.23708 .71819 Mdot
.58528 .74762 Mdot
.46765 .3856 Mdot
.52778 .37766 Mdot
.44201 .60881 Mdot
.58161 .49598 Mdot
.51856 .5278 Mdot
.64691 .6205 Mdot
.68948 .36545 Mdot
.5583 .42079 Mdot
.32322 .4737 Mdot
.72358 .48434 Mdot
.49231 .42271 Mdot
.3142 .47704 Mdot
.45252 .42921 Mdot
.59525 .6253 Mdot
.58392 .71755 Mdot
.23466 .61395 Mdot
.70309 .50993 Mdot
.67976 .4482 Mdot
.30015 .61601 Mdot
.59825 .5903 Mdot
.49411 .34355 Mdot
.40378 .60175 Mdot
.64618 .61608 Mdot
.59517 .72288 Mdot
.5006 .30674 Mdot
.3337 .51052 Mdot
.30747 .49268 Mdot
.60417 .43499 Mdot
.65815 .56209 Mdot
.37269 .81639 Mdot
.40407 .62813 Mdot
.49954 .43073 Mdot
.25233 .57653 Mdot
.30719 .4918 Mdot
.60813 .4303 Mdot
.6938 .51263 Mdot
.43086 .63879 Mdot
.6075 .72282 Mdot
.31484 .47865 Mdot
.30931 .52743 Mdot
.43851 .40148 Mdot
.47828 .41068 Mdot
.66561 .38474 Mdot
.60036 .42666 Mdot
.4044 .6553 Mdot
.71944 .48923 Mdot
.64599 .58257 Mdot
.48979 .35507 Mdot
.35245 .51368 Mdot
.25634 .31466 Mdot
.52941 .38566 Mdot
.5981 .63367 Mdot
.30414 .50568 Mdot
.71063 .48103 Mdot
.71231 .5223 Mdot
.51289 .3961 Mdot
.32807 .42874 Mdot
.42062 .65639 Mdot
.30646 .49001 Mdot
.23179 .52645 Mdot
.5301 .35098 Mdot
.47501 .41242 Mdot
.56241 .3596 Mdot
.41114 .60675 Mdot
.21907 .57981 Mdot
.71062 .47292 Mdot
.32436 .5071 Mdot
.52336 .36563 Mdot
.70565 .51429 Mdot
.23184 .57265 Mdot
.58418 .72438 Mdot
.6021 .60033 Mdot
.70603 .52722 Mdot
.69895 .48361 Mdot
.72391 .5059 Mdot
.7644 .32581 Mdot
.36759 .51603 Mdot
.41426 .31786 Mdot
.52661 .35667 Mdot
.60534 .43807 Mdot
.43691 .35924 Mdot
.38848 .6476 Mdot
.62669 .58226 Mdot
.49477 .39057 Mdot
.43907 .40182 Mdot
.50844 .46721 Mdot
.42807 .44628 Mdot
.33728 .4548 Mdot
.3084 .51808 Mdot
.41851 .41568 Mdot
.63024 .58726 Mdot
.68509 .8008 Mdot
.59282 .15683 Mdot
.4394 .33086 Mdot
.56394 .50909 Mdot
.3557 .50628 Mdot
.43686 .60201 Mdot
.5031 .53224 Mdot
.41133 .66501 Mdot
.31927 .50392 Mdot
.48708 .3542 Mdot
.30901 .60496 Mdot
.68106 .52684 Mdot
.51649 .40142 Mdot
.4178 .62926 Mdot
.51551 .40136 Mdot
.39135 .62961 Mdot
.34517 .56812 Mdot
.33695 .72505 Mdot
.47072 .33856 Mdot
.53903 .36351 Mdot
.47202 .47096 Mdot
.48538 .40672 Mdot
.68804 .75683 Mdot
.35325 .49769 Mdot
.54837 .81657 Mdot
.44845 .41573 Mdot
.35985 .40118 Mdot
.52651 .35253 Mdot
.62384 .75787 Mdot
.48332 .41476 Mdot
.49001 .55475 Mdot
.4925 .32958 Mdot
.45333 .39462 Mdot
.43575 .65553 Mdot
.44147 .60825 Mdot
.34339 .52947 Mdot
.60338 .72959 Mdot
.57916 .19326 Mdot
.47179 .4048 Mdot
.58418 .5845 Mdot
.47724 .65431 Mdot
.70724 .4832 Mdot
.32066 .50179 Mdot
.55004 .865 Mdot
.42249 .66228 Mdot
.65629 .58972 Mdot
.65598 .75232 Mdot
.60196 .57701 Mdot
.40074 .6884 Mdot
.57397 .34877 Mdot
.69713 .47924 Mdot
.51615 .33813 Mdot
.1914 .44027 Mdot
.37965 .74256 Mdot
.49914 .31052 Mdot
.42946 .66897 Mdot
.4375 .26685 Mdot
.20698 .38659 Mdot
.71756 .52692 Mdot
.68036 .51099 Mdot
.42696 .65897 Mdot
.58543 .59954 Mdot
.56455 .396 Mdot
.6934 .51383 Mdot
.59275 .60448 Mdot
.59924 .70169 Mdot
.45071 .55843 Mdot
.33275 .50229 Mdot
.21787 .60456 Mdot
.30821 .65199 Mdot
.40694 .65774 Mdot
.60325 .5498 Mdot
.27443 .52213 Mdot
.34266 .54356 Mdot
.5977 .7417 Mdot
.61495 .63664 Mdot
.36563 .50021 Mdot
.53425 .33578 Mdot
.41373 .43986 Mdot
.4644 .37924 Mdot
.69441 .49703 Mdot
.48993 .41147 Mdot
.60808 .63521 Mdot
.42589 .63843 Mdot
.62869 .62846 Mdot
.43404 .6536 Mdot
.3404 .63044 Mdot
.51097 .37932 Mdot
.45519 .39568 Mdot
.70466 .43792 Mdot
.33218 .53678 Mdot
.21129 .5157 Mdot
.5794 .59012 Mdot
.62853 .61185 Mdot
.45213 .3672 Mdot
.3599 .50119 Mdot
.67916 .47618 Mdot
.70539 .44066 Mdot
.51249 .40999 Mdot
.35361 .49718 Mdot
.48939 .34856 Mdot
.72963 .33132 Mdot
.35947 .75871 Mdot
.32477 .49167 Mdot
.57888 .82124 Mdot
.50262 .35709 Mdot
.48248 .28277 Mdot
.55113 .37378 Mdot
.62838 .33471 Mdot
.52975 .34902 Mdot
.32603 .47022 Mdot
.46813 .38079 Mdot
.35154 .48288 Mdot
.59018 .59628 Mdot
.44527 .60499 Mdot
.33771 .52216 Mdot
.51702 .40992 Mdot
.74986 .28736 Mdot
.41027 .62569 Mdot
.45704 .37664 Mdot
.43361 .62127 Mdot
.30045 .4795 Mdot
.31802 .53052 Mdot
.81405 .48298 Mdot
.44057 .69123 Mdot
.40263 .63213 Mdot
.48023 .34621 Mdot
.28296 .64826 Mdot
.47325 .35364 Mdot
.65831 .39179 Mdot
.44317 .39888 Mdot
.53288 .35126 Mdot
.8416 .55806 Mdot
.40849 .60269 Mdot
.38456 .81774 Mdot
.77447 .41377 Mdot
.77331 .33679 Mdot
.31547 .55136 Mdot
.71809 .52651 Mdot
.70158 .27263 Mdot
.57671 .73516 Mdot
.60137 .61187 Mdot
.49569 .39144 Mdot
.36684 .54655 Mdot
.39594 .64322 Mdot
.71499 .49368 Mdot
.46907 .33974 Mdot
.60283 .63704 Mdot
.78404 .59074 Mdot
.45279 .64332 Mdot
.32668 .49962 Mdot
.32814 .53491 Mdot
.52459 .85486 Mdot
.52459 .36632 Mdot
.45511 .38567 Mdot
.41538 .61947 Mdot
.45114 .44951 Mdot
.71483 .47952 Mdot
.69278 .65744 Mdot
.40309 .6327 Mdot
.5394 .57474 Mdot
.31572 .52103 Mdot
.48726 .39949 Mdot
.51422 .503 Mdot
.51324 .63518 Mdot
.37071 .26 Mdot
.69737 .50083 Mdot
.6653 .40354 Mdot
.32531 .47025 Mdot
.41921 .63784 Mdot
.73016 .54098 Mdot
.50988 .4309 Mdot
.48197 .39594 Mdot
.66474 .40782 Mdot
.59499 .49105 Mdot
.67371 .47627 Mdot
.48399 .32422 Mdot
.59507 .48627 Mdot
.44924 .3733 Mdot
.54078 .39757 Mdot
.50518 .3213 Mdot
.47036 .41413 Mdot
.35487 .49994 Mdot
.51984 .46148 Mdot
.60854 .59914 Mdot
.30793 .34246 Mdot
.46222 .52104 Mdot
.5142 .34577 Mdot
.48178 .35477 Mdot
.40943 .25097 Mdot
.44781 .69651 Mdot
.3504 .50432 Mdot
.36446 .48416 Mdot
.44906 .6456 Mdot
.42041 .45537 Mdot
.58116 .62255 Mdot
.55702 .44523 Mdot
.62575 .62948 Mdot
.35335 .49368 Mdot
.63351 .61341 Mdot
.45284 .63515 Mdot
.64286 .60652 Mdot
.578 .59789 Mdot
.3927 .63515 Mdot
.32165 .5259 Mdot
.50236 .41198 Mdot
.44463 .6533 Mdot
.648 .43506 Mdot
.69401 .49867 Mdot
.81452 .48175 Mdot
.48445 .43338 Mdot
.43494 .4983 Mdot
.61631 .27796 Mdot
.62881 .62627 Mdot
.38215 .78226 Mdot
.34737 .51891 Mdot
.67252 .51321 Mdot
.35569 .49696 Mdot
.1938 .59525 Mdot
.71861 .49435 Mdot
.82416 .45137 Mdot
.64971 .65693 Mdot
.78095 .56554 Mdot
.472 .32805 Mdot
.26165 .51017 Mdot
.64774 .59839 Mdot
.39683 .64482 Mdot
.6219 .68082 Mdot
.45314 .40112 Mdot
.46689 .78746 Mdot
.32269 .54078 Mdot
.59741 .70471 Mdot
.41829 .64469 Mdot
.43942 .66384 Mdot
.52358 .37736 Mdot
.70698 .68163 Mdot
.45262 .40799 Mdot
.67406 .58843 Mdot
.68037 .38241 Mdot
.56373 .44008 Mdot
.45739 .35343 Mdot
.63643 .62942 Mdot
.48884 .34789 Mdot
.45557 .26925 Mdot
.18887 .46237 Mdot
.55816 .36207 Mdot
.53121 .78099 Mdot
.73675 .46671 Mdot
.31394 .51376 Mdot
.42357 .35272 Mdot
.59939 .72327 Mdot
.50508 .35545 Mdot
.16735 .38074 Mdot
.70615 .50517 Mdot
.57074 .5803 Mdot
.53197 .36196 Mdot
.5193 .37145 Mdot
.22231 .4473 Mdot
.35757 .55566 Mdot
.60794 .72331 Mdot
.47807 .39306 Mdot
.70353 .38086 Mdot
.43061 .61093 Mdot
.45984 .41669 Mdot
.46283 .3862 Mdot
.373 .23336 Mdot
.41293 .60814 Mdot
.63198 .62369 Mdot
.57784 .72505 Mdot
.64344 .57823 Mdot
.73257 .48586 Mdot
.50963 .54292 Mdot
.60281 .41202 Mdot
.35899 .75584 Mdot
.72495 .51573 Mdot
.53151 .39359 Mdot
.47471 .29924 Mdot
.50868 .36279 Mdot
.68155 .51862 Mdot
.40595 .61154 Mdot
.34888 .51278 Mdot
.24371 .62044 Mdot
.59118 .73003 Mdot
.54122 .35069 Mdot
.69471 .52813 Mdot
.33264 .51662 Mdot
.578 .55527 Mdot
.31973 .51121 Mdot
.40564 .64308 Mdot
.39588 .66489 Mdot
.71537 .50834 Mdot
.35464 .49224 Mdot
.63024 .56482 Mdot
.77718 .43157 Mdot
.44175 .38772 Mdot
.44545 .66938 Mdot
.35788 .51465 Mdot
.27986 .5138 Mdot
.33137 .54092 Mdot
.51427 .38696 Mdot
.57154 .50176 Mdot
.53696 .40316 Mdot
.42139 .66019 Mdot
.59698 .60532 Mdot
.5977 .39905 Mdot
.2124 .46004 Mdot
.56516 .55016 Mdot
.44289 .34599 Mdot
.46066 .36791 Mdot
.45984 .38479 Mdot
.43768 .37134 Mdot
.69053 .55467 Mdot
.50827 .37583 Mdot
.43587 .65434 Mdot
.61489 .63079 Mdot
.52234 .35261 Mdot
.59998 .71877 Mdot
.54409 .50793 Mdot
.7276 .49108 Mdot
.48466 .53709 Mdot
.68896 .23798 Mdot
.33416 .51737 Mdot
.63421 .5788 Mdot
.60293 .60969 Mdot
.72623 .50097 Mdot
.39932 .64662 Mdot
.32272 .51564 Mdot
.6352 .32766 Mdot
.72381 .4986 Mdot
.46891 .38481 Mdot
.63762 .70558 Mdot
.57227 .78762 Mdot
.51446 .33467 Mdot
.48983 .38123 Mdot
.58289 .71381 Mdot
.58174 .60766 Mdot
.32336 .21382 Mdot
.62272 .47534 Mdot
.71677 .50247 Mdot
.68566 .4913 Mdot
.34195 .54031 Mdot
.46261 .31012 Mdot
.43091 .65311 Mdot
.63638 .45978 Mdot
.59407 .31666 Mdot
.66076 .46567 Mdot
.79292 .6381 Mdot
.52326 .39244 Mdot
.23656 .43671 Mdot
.4607 .35495 Mdot
.31305 .53927 Mdot
.29071 .50083 Mdot
.34581 .50627 Mdot
.41294 .65669 Mdot
.3807 .40416 Mdot
.44077 .64956 Mdot
.64826 .20086 Mdot
.34118 .47135 Mdot
.72916 .56263 Mdot
.63426 .60676 Mdot
.42538 .40783 Mdot
.70831 .47878 Mdot
.38216 .67139 Mdot
.49097 .31924 Mdot
.4584 .80618 Mdot
.64068 .60283 Mdot
.31572 .52617 Mdot
.56862 .33655 Mdot
.49975 .17341 Mdot
.53487 .53262 Mdot
.41248 .34197 Mdot
.23066 .48312 Mdot
.71615 .48685 Mdot
.36747 .26468 Mdot
.6918 .47892 Mdot
.42482 .62925 Mdot
.45707 .40564 Mdot
.4762 .41865 Mdot
.45245 .35823 Mdot
.50816 .37761 Mdot
.447 .61931 Mdot
.4362 .41051 Mdot
.17916 .59132 Mdot
.58461 .71449 Mdot
.72546 .31763 Mdot
.69346 .51847 Mdot
.40874 .66722 Mdot
.61855 .63009 Mdot
.60401 .71566 Mdot
.61252 .41082 Mdot
.49211 .33031 Mdot
.49639 .3893 Mdot
.5979 .74572 Mdot
.50645 .32394 Mdot
.5482 .43334 Mdot
.60982 .60002 Mdot
.56808 .54346 Mdot
.70789 .52942 Mdot
.69736 .5233 Mdot
.40086 .6191 Mdot
.35528 .49393 Mdot
.69469 .50855 Mdot
.58444 .6101 Mdot
.44113 .41968 Mdot
.5155 .41356 Mdot
.35711 .51652 Mdot
.19218 .57773 Mdot
.72261 .52397 Mdot
.56517 .32907 Mdot
.33762 .4727 Mdot
.36558 .52549 Mdot
.48145 .39309 Mdot
.55995 .35887 Mdot
.27599 .50525 Mdot
.71628 .52166 Mdot
.412 .66827 Mdot
.77644 .53622 Mdot
.4194 .62475 Mdot
.32671 .51753 Mdot
.46081 .42279 Mdot
.31899 .52408 Mdot
.5111 .35543 Mdot
.88677 .54971 Mdot
.48063 .41792 Mdot
.30912 .73913 Mdot
.63504 .35309 Mdot
.60443 .61268 Mdot
.62986 .56515 Mdot
.59584 .71236 Mdot
.33469 .47132 Mdot
.49104 .42398 Mdot
.68665 .48769 Mdot
.79255 .38202 Mdot
.26746 .50199 Mdot
.59537 .61804 Mdot
.57966 .61432 Mdot
.40031 .61171 Mdot
.53094 .36499 Mdot
.48512 .40145 Mdot
.64234 .61029 Mdot
.63651 .28025 Mdot
.32685 .47583 Mdot
.45577 .38336 Mdot
.46576 .36388 Mdot
.60694 .60737 Mdot
.77669 .43407 Mdot
.29415 .55572 Mdot
.45999 .40653 Mdot
.74201 .50557 Mdot
.38747 .64746 Mdot
.44173 .36476 Mdot
.43522 .40879 Mdot
.68986 .4907 Mdot
.67433 .26701 Mdot
.18486 .42267 Mdot
.39084 .64883 Mdot
.60361 .72395 Mdot
.53198 .40089 Mdot
.6333 .60522 Mdot
.51767 .41079 Mdot
.54807 .21055 Mdot
.59196 .70814 Mdot
.50096 .37023 Mdot
.45477 .31888 Mdot
.29355 .51008 Mdot
.51078 .37294 Mdot
.40949 .23385 Mdot
.65194 .60124 Mdot
.50547 .37144 Mdot
.30522 .43656 Mdot
.4188 .60675 Mdot
.43918 .33212 Mdot
.68669 .51811 Mdot
.62456 .32821 Mdot
.30598 .62793 Mdot
.58896 .64775 Mdot
.69971 .52205 Mdot
.50699 .41181 Mdot
.58842 .59277 Mdot
.39974 .65313 Mdot
.44976 .78917 Mdot
.46821 .33544 Mdot
.41333 .62334 Mdot
.42482 .63986 Mdot
.70934 .51097 Mdot
.42289 .83524 Mdot
.42266 .392 Mdot
.48784 .40821 Mdot
.41895 .22348 Mdot
.29876 .5255 Mdot
.49505 .4113 Mdot
.53038 .38971 Mdot
.43961 .64377 Mdot
.26895 .54826 Mdot
.41473 .28051 Mdot
.69501 .66996 Mdot
.39003 .63278 Mdot
.61871 .6644 Mdot
.59006 .59044 Mdot
.69257 .51697 Mdot
.31023 .50812 Mdot
.73021 .48908 Mdot
.61874 .58874 Mdot
.52844 .37504 Mdot
.43749 .6388 Mdot
.29234 .30339 Mdot
.42674 .59546 Mdot
.64043 .64072 Mdot
.29028 .52796 Mdot
.25634 .5886 Mdot
.15134 .45328 Mdot
.31853 .65495 Mdot
.41174 .58685 Mdot
.70658 .48315 Mdot
.62841 .6886 Mdot
.46384 .3656 Mdot
.3579 .28272 Mdot
.50935 .40655 Mdot
.25434 .46006 Mdot
.61496 .58292 Mdot
.59927 .74113 Mdot
.45869 .40729 Mdot
.67828 .39352 Mdot
.45604 .61324 Mdot
.3984 .61273 Mdot
.49946 .37786 Mdot
.40751 .64879 Mdot
.47765 .40735 Mdot
.61801 .63414 Mdot
.35789 .79489 Mdot
.45876 .37173 Mdot
.54503 .39776 Mdot
.47027 .68066 Mdot
.8169 .47453 Mdot
.61345 .56485 Mdot
.23299 .43863 Mdot
.46826 .17469 Mdot
.4091 .64942 Mdot
.48479 .30603 Mdot
.64631 .60323 Mdot
.58332 .71303 Mdot
.63821 .56394 Mdot
.50561 .40447 Mdot
.50807 .39749 Mdot
.45243 .36625 Mdot
.48242 .36101 Mdot
.36327 .2777 Mdot
.46945 .45931 Mdot
.25957 .42049 Mdot
.49583 .38695 Mdot
.25556 .47741 Mdot
.44663 .64177 Mdot
.35373 .46052 Mdot
.72298 .52749 Mdot
.52386 .39027 Mdot
.39095 .49869 Mdot
.39391 .65714 Mdot
.64578 .19957 Mdot
.40484 .60972 Mdot
.61806 .61775 Mdot
.42721 .60072 Mdot
.51379 .35222 Mdot
.3128 .49644 Mdot
.65008 .61743 Mdot
.43232 .75608 Mdot
.60055 .61352 Mdot
.52321 .35888 Mdot
.76359 .50644 Mdot
.60292 .6069 Mdot
.51694 .51552 Mdot
.30871 .49928 Mdot
.7074 .38832 Mdot
.29038 .49835 Mdot
.50398 .36892 Mdot
.50005 .36694 Mdot
.59399 .69875 Mdot
.4534 .61417 Mdot
.30076 .47767 Mdot
.28923 .77684 Mdot
.71908 .47 Mdot
.34339 .50132 Mdot
.45779 .43948 Mdot
.58409 .49858 Mdot
.31765 .48828 Mdot
.67049 .33975 Mdot
.39922 .64843 Mdot
.36666 .51209 Mdot
.47863 .43999 Mdot
.48929 .61977 Mdot
.67722 .52548 Mdot
.61439 .64289 Mdot
.51052 .58513 Mdot
.64782 .59458 Mdot
.39939 .6641 Mdot
.6276 .64616 Mdot
.4345 .61186 Mdot
.21905 .53347 Mdot
.39496 .41994 Mdot
.42306 .59179 Mdot
.41112 .67082 Mdot
.62564 .5941 Mdot
.46492 .34039 Mdot
.43256 .52639 Mdot
.4868 .32279 Mdot
.45647 .33947 Mdot
.42938 .60884 Mdot
.30923 .47538 Mdot
.31948 .46645 Mdot
.25753 .49565 Mdot
.3258 .53603 Mdot
.62366 .63236 Mdot
.35466 .75894 Mdot
.20796 .53891 Mdot
.41619 .61501 Mdot
.42397 .67515 Mdot
.47569 .35369 Mdot
.6319 .60095 Mdot
.59588 .59013 Mdot
.43151 .64879 Mdot
.31703 .29852 Mdot
.53451 .40811 Mdot
.28472 .51822 Mdot
.34717 .47474 Mdot
.32691 .48906 Mdot
.33757 .53952 Mdot
.38717 .31783 Mdot
.39734 .64655 Mdot
.33767 .47102 Mdot
.49887 .37415 Mdot
.50705 .3998 Mdot
.59164 .73903 Mdot
.6934 .52277 Mdot
.45675 .43212 Mdot
.55712 .36906 Mdot
.48348 .39379 Mdot
.60187 .60176 Mdot
.4223 .33943 Mdot
.59998 .71091 Mdot
.59552 .63823 Mdot
.58026 .62426 Mdot
.59012 .7448 Mdot
.25968 .48339 Mdot
.47651 .16412 Mdot
.48407 .34965 Mdot
.40056 .39781 Mdot
.6294 .60545 Mdot
.40309 .80304 Mdot
.22371 .57865 Mdot
.45498 .35435 Mdot
.47323 .57674 Mdot
.64255 .62951 Mdot
.30745 .53205 Mdot
.50146 .40947 Mdot
.58225 .73818 Mdot
.72637 .48926 Mdot
.46413 .44128 Mdot
.57723 .72646 Mdot
.35066 .4865 Mdot
.68054 .54405 Mdot
.36438 .52344 Mdot
.64366 .62972 Mdot
.45103 .32187 Mdot
.61039 .13646 Mdot
.63578 .57579 Mdot
.7914 .39783 Mdot
.35652 .56031 Mdot
.45443 .37814 Mdot
.64048 .58045 Mdot
.30178 .52996 Mdot
.38808 .65383 Mdot
.59156 .48311 Mdot
.34126 .52503 Mdot
.60431 .72705 Mdot
.58704 .73702 Mdot
.6078 .602 Mdot
.30466 .51514 Mdot
.45892 .41827 Mdot
.29592 .49664 Mdot
.42261 .60086 Mdot
.47069 .34318 Mdot
.56018 .17824 Mdot
.41498 .43377 Mdot
.32501 .47145 Mdot
.60063 .63771 Mdot
.67614 .5154 Mdot
.48228 .33332 Mdot
.77476 .38695 Mdot
.5324 .37714 Mdot
.42567 .61265 Mdot
.5097 .82798 Mdot
.31645 .28029 Mdot
.52368 .35013 Mdot
.4766 .3543 Mdot
.39239 .6395 Mdot
.48881 .33091 Mdot
.52488 .34659 Mdot
.46362 .67192 Mdot
.29446 .5051 Mdot
.46659 .376 Mdot
.58974 .60503 Mdot
.19928 .46802 Mdot
.53816 .39388 Mdot
.53581 .76319 Mdot
.69719 .39265 Mdot
.48437 .83586 Mdot
.49896 .41548 Mdot
.62515 .44696 Mdot
.48506 .36715 Mdot
.51912 .38943 Mdot
.4757 .34823 Mdot
.23124 .42384 Mdot
.6265 .59216 Mdot
.60235 .63103 Mdot
.67879 .52795 Mdot
.6974 .38889 Mdot
.68704 .50091 Mdot
.39518 .62356 Mdot
.78314 .62084 Mdot
.58975 .7108 Mdot
.35499 .49149 Mdot
.47383 .42161 Mdot
.65272 .61393 Mdot
.4905 .40017 Mdot
.51042 .35183 Mdot
.63258 .6354 Mdot
.61398 .57502 Mdot
.58886 .55936 Mdot
.70089 .47623 Mdot
.34411 .51442 Mdot
.43664 .39723 Mdot
.71754 .51557 Mdot
.46729 .42244 Mdot
.60871 .48436 Mdot
.34706 .51038 Mdot
.29359 .50079 Mdot
.2881 .48757 Mdot
.52867 .37526 Mdot
.5119 .34552 Mdot
.44172 .6479 Mdot
.36145 .5017 Mdot
.40368 .61929 Mdot
.64805 .60969 Mdot
.64738 .57567 Mdot
.50578 .4042 Mdot
.53518 .28702 Mdot
.69026 .4868 Mdot
.62095 .62174 Mdot
.60006 .74495 Mdot
.67334 .50846 Mdot
.52607 .36494 Mdot
.63784 .62797 Mdot
.69904 .52472 Mdot
.28589 .3386 Mdot
.43587 .17306 Mdot
.6774 .51437 Mdot
.4977 .37648 Mdot
.22001 .45384 Mdot
.76795 .43806 Mdot
.71545 .46906 Mdot
.42939 .62127 Mdot
.53117 .38355 Mdot
.55788 .2532 Mdot
.72996 .51009 Mdot
.21331 .50546 Mdot
.60533 .61504 Mdot
.4376 .5771 Mdot
.51035 .44002 Mdot
.34323 .30154 Mdot
.72699 .47992 Mdot
.32381 .51149 Mdot
.315 .46199 Mdot
.48009 .37893 Mdot
.72274 .52954 Mdot
.39705 .61219 Mdot
.6055 .62279 Mdot
.5912 .5789 Mdot
.30113 .51214 Mdot
.29709 .67399 Mdot
.59062 .61427 Mdot
.5516 .30832 Mdot
.65635 .71123 Mdot
.41013 .44914 Mdot
.2946 .4496 Mdot
.39682 .73308 Mdot
.52558 .40911 Mdot
.67813 .50523 Mdot
.41128 .66603 Mdot
.43115 .65606 Mdot
.40444 .63685 Mdot
.62375 .56644 Mdot
.49934 .53305 Mdot
.64024 .59636 Mdot
.44449 .77976 Mdot
.70502 .51432 Mdot
.71859 .37437 Mdot
.48725 .4231 Mdot
.46028 .36911 Mdot
.49271 .43277 Mdot
.44839 .4002 Mdot
.48001 .36773 Mdot
.40021 .64588 Mdot
.60641 .57159 Mdot
.75235 .59226 Mdot
.33957 .49057 Mdot
.55538 .60189 Mdot
.63441 .60704 Mdot
.58415 .71278 Mdot
.71152 .4956 Mdot
.58024 .46023 Mdot
.60492 .652 Mdot
.63245 .61371 Mdot
.43891 .42134 Mdot
.30973 .48176 Mdot
.56848 .41763 Mdot
.49448 .36466 Mdot
.62317 .62392 Mdot
.64835 .65325 Mdot
.43629 .24414 Mdot
.54937 .32896 Mdot
.66591 .51019 Mdot
.5762 .50177 Mdot
.70257 .47202 Mdot
.5491 .40661 Mdot
.41229 .80808 Mdot
.61885 .58942 Mdot
.6149 .61183 Mdot
.69047 .52541 Mdot
.49221 .28316 Mdot
.30463 .50928 Mdot
.60006 .74063 Mdot
.43753 .62388 Mdot
.5074 .36422 Mdot
.63846 .57122 Mdot
.44692 .29445 Mdot
.72567 .6585 Mdot
.40569 .63072 Mdot
.59447 .63688 Mdot
.52941 .36218 Mdot
.49611 .37772 Mdot
.71276 .48393 Mdot
.3994 .48479 Mdot
.43436 .43256 Mdot
.77269 .33513 Mdot
.3371 .72353 Mdot
.28728 .69494 Mdot
.48194 .39618 Mdot
.3001 .51365 Mdot
.58238 .73251 Mdot
.72221 .50006 Mdot
.44491 .41554 Mdot
.44667 .17185 Mdot
.28686 .4789 Mdot
.42027 .63169 Mdot
.58373 .73971 Mdot
.49918 .53105 Mdot
.53233 .3815 Mdot
.50867 .40682 Mdot
.51153 .38265 Mdot
.38939 .17306 Mdot
.59372 .61624 Mdot
.32422 .53936 Mdot
.6984 .49765 Mdot
.3227 .53749 Mdot
.60015 .62369 Mdot
.25444 .62579 Mdot
.51426 .34139 Mdot
.28704 .5224 Mdot
.32165 .50887 Mdot
.39979 .61245 Mdot
.38635 .65196 Mdot
.58166 .56193 Mdot
.47911 .4174 Mdot
.58114 .73674 Mdot
.28979 .50078 Mdot
.59997 .58028 Mdot
.71838 .49272 Mdot
.44221 .65452 Mdot
.49695 .38671 Mdot
.61167 .59378 Mdot
.50571 .31413 Mdot
.31487 .48574 Mdot
.63234 .61286 Mdot
.58489 .74943 Mdot
.68288 .50045 Mdot
.50281 .39377 Mdot
.67052 .48885 Mdot
.59397 .74632 Mdot
.46486 .36285 Mdot
.57966 .43199 Mdot
.70567 .45816 Mdot
.44911 .7627 Mdot
.6386 .58718 Mdot
.59797 .73154 Mdot
.28986 .50762 Mdot
.25046 .55105 Mdot
.61302 .6164 Mdot
.57863 .45095 Mdot
.39666 .52421 Mdot
.4358 .39395 Mdot
.32742 .49569 Mdot
.63901 .68285 Mdot
.72909 .28381 Mdot
.74787 .37882 Mdot
.45849 .37966 Mdot
.64285 .58357 Mdot
.70471 .52473 Mdot
.41679 .61429 Mdot
.53719 .76491 Mdot
.40023 .34588 Mdot
.61837 .6473 Mdot
.47799 .35008 Mdot
.2911 .49847 Mdot
.42938 .64889 Mdot
.32001 .60735 Mdot
.58602 .62142 Mdot
.61956 .58109 Mdot
.52389 .35333 Mdot
.6965 .51305 Mdot
.68267 .3003 Mdot
.60645 .63588 Mdot
.63776 .57193 Mdot
.61841 .73525 Mdot
.69231 .52838 Mdot
.48832 .37439 Mdot
.25732 .49692 Mdot
.43941 .36487 Mdot
.7933 .39623 Mdot
.60065 .71522 Mdot
.33946 .48881 Mdot
.51415 .4007 Mdot
.68752 .68687 Mdot
.61763 .62646 Mdot
.56034 .51107 Mdot
.65592 .62709 Mdot
.40097 .65015 Mdot
.64026 .57246 Mdot
.49512 .40748 Mdot
.45506 .61042 Mdot
.68963 .48808 Mdot
.4631 .40916 Mdot
.50981 .34415 Mdot
.30873 .53506 Mdot
.42589 .62874 Mdot
.23256 .34947 Mdot
.42887 .67175 Mdot
.39699 .65786 Mdot
.33723 .46306 Mdot
.47391 .38167 Mdot
.62151 .61585 Mdot
.63222 .6426 Mdot
.44421 .41227 Mdot
.36109 .77607 Mdot
.30228 .50865 Mdot
.57374 .56667 Mdot
.33739 .20823 Mdot
.5693 .36777 Mdot
.5916 .75121 Mdot
.40125 .47141 Mdot
.391 .62585 Mdot
.49761 .38182 Mdot
.33071 .47294 Mdot
.62878 .56912 Mdot
.59048 .61277 Mdot
.4612 .4219 Mdot
.4277 .64378 Mdot
.72853 .50441 Mdot
.61478 .58043 Mdot
.70804 .6789 Mdot
.51459 .37773 Mdot
.47426 .78736 Mdot
.62524 .57797 Mdot
.8063 .38238 Mdot
.74397 .61731 Mdot
.32978 .49347 Mdot
.50814 .34935 Mdot
.33074 .53253 Mdot
.69813 .49298 Mdot
.59588 .65826 Mdot
.42711 .64025 Mdot
.53693 .3153 Mdot
.17168 .4731 Mdot
.63056 .59451 Mdot
.35453 .50022 Mdot
.52468 .35177 Mdot
.56261 .33653 Mdot
.48703 .41069 Mdot
.25497 .53495 Mdot
.66383 .54721 Mdot
.42628 .60798 Mdot
.42708 .61433 Mdot
.46301 .35917 Mdot
.72102 .48679 Mdot
.62364 .63923 Mdot
.60646 .62182 Mdot
.74868 .76528 Mdot
.58634 .7512 Mdot
.66002 .37841 Mdot
.50652 .39567 Mdot
.59155 .58579 Mdot
.21075 .45699 Mdot
.41489 .61933 Mdot
.44815 .4024 Mdot
.58454 .59003 Mdot
.48291 .68042 Mdot
.60408 .48664 Mdot
.48232 .37123 Mdot
.5402 .4354 Mdot
.43519 .62159 Mdot
.67808 .44207 Mdot
.64162 .60101 Mdot
.44468 .39897 Mdot
.43709 .66935 Mdot
.66103 .72318 Mdot
.19402 .51613 Mdot
.34424 .51391 Mdot
.64958 .63469 Mdot
.39978 .6457 Mdot
.44251 .43926 Mdot
.69477 .51986 Mdot
.65055 .60121 Mdot
.59919 .6082 Mdot
.48289 .34179 Mdot
.43164 .41471 Mdot
.56918 .36534 Mdot
.3493 .49299 Mdot
.44737 .63095 Mdot
.45621 .40665 Mdot
.30201 .67934 Mdot
.44999 .36979 Mdot
.44549 .63789 Mdot
.76566 .23509 Mdot
.45242 .34745 Mdot
.48494 .40956 Mdot
.7033 .32008 Mdot
.33853 .5274 Mdot
.32137 .53628 Mdot
.34143 .73478 Mdot
.50613 .39552 Mdot
.76824 .59684 Mdot
.34111 .51816 Mdot
.30182 .50432 Mdot
.71218 .57561 Mdot
.46368 .34697 Mdot
.69611 .44339 Mdot
.43332 .65138 Mdot
.42691 .66246 Mdot
.29572 .49959 Mdot
.43486 .4343 Mdot
.39515 .64997 Mdot
.3841 .2806 Mdot
.63676 .60362 Mdot
.41693 .81088 Mdot
.31985 .48203 Mdot
.42747 .51021 Mdot
.40954 .62279 Mdot
.65322 .2035 Mdot
.49 .59351 Mdot
.45374 .3617 Mdot
.50475 .38877 Mdot
.68608 .49523 Mdot
.46606 .32103 Mdot
.60329 .71649 Mdot
.4067 .64837 Mdot
.64296 .26108 Mdot
.34532 .50573 Mdot
.48011 .41507 Mdot
.58462 .45525 Mdot
.32872 .62489 Mdot
.5271 .78397 Mdot
.31445 .51315 Mdot
.33219 .49971 Mdot
.63197 .5881 Mdot
.60742 .58938 Mdot
.47576 .3761 Mdot
.42378 .65871 Mdot
.36291 .50431 Mdot
.44281 .62556 Mdot
.61673 .58923 Mdot
.62832 .61368 Mdot
.59256 .70713 Mdot
.52559 .33213 Mdot
.62491 .63648 Mdot
.69416 .69963 Mdot
.29106 .67162 Mdot
.34165 .54295 Mdot
.17418 .40953 Mdot
.31996 .60566 Mdot
.6238 .2939 Mdot
.70448 .47362 Mdot
.59587 .69032 Mdot
.44457 .60867 Mdot
.47359 .35525 Mdot
.49413 .3947 Mdot
.59045 .72371 Mdot
.4419 .59917 Mdot
.71112 .4899 Mdot
.44865 .60483 Mdot
.70622 .51668 Mdot
.63937 .56673 Mdot
.5361 .39659 Mdot
.52803 .39631 Mdot
.40058 .64388 Mdot
.63436 .62166 Mdot
.61143 .63228 Mdot
.69431 .47651 Mdot
.60181 .45956 Mdot
.60775 .60031 Mdot
.31818 .48283 Mdot
.37214 .3639 Mdot
.58661 .7344 Mdot
.49916 .4102 Mdot
.60666 .43395 Mdot
.3454 .276 Mdot
.43817 .38846 Mdot
.58579 .7436 Mdot
.65933 .80907 Mdot
.4848 .42123 Mdot
.59092 .83845 Mdot
.5973 .73407 Mdot
.33895 .52801 Mdot
.63878 .5814 Mdot
.60252 .71144 Mdot
.5006 .44348 Mdot
.70041 .46888 Mdot
.46957 .43091 Mdot
.33586 .52673 Mdot
.28491 .495 Mdot
.26831 .68804 Mdot
.79363 .39966 Mdot
.68655 .48383 Mdot
.71399 .50366 Mdot
.61158 .61529 Mdot
.82928 .56382 Mdot
.47387 .43883 Mdot
.71615 .49846 Mdot
.63514 .26606 Mdot
.48307 .35287 Mdot
.65348 .39857 Mdot
.4735 .57431 Mdot
.29976 .51216 Mdot
.27074 .47007 Mdot
.61359 .6226 Mdot
.35379 .50259 Mdot
.26819 .65775 Mdot
.49038 .43256 Mdot
.34741 .50782 Mdot
.44424 .63765 Mdot
.4621 .72097 Mdot
.32178 .53048 Mdot
.61167 .46967 Mdot
.42877 .65379 Mdot
.66716 .63565 Mdot
.67944 .31277 Mdot
.13324 .42786 Mdot
.4081 .6516 Mdot
.64142 .62102 Mdot
.64197 .63112 Mdot
.607 .61857 Mdot
.34501 .52263 Mdot
.58949 .59676 Mdot
.34367 .48558 Mdot
.78049 .45142 Mdot
.60164 .45196 Mdot
.7153 .50958 Mdot
.44937 .68846 Mdot
.32576 .50369 Mdot
.39924 .77212 Mdot
.15558 .44986 Mdot
.50114 .37792 Mdot
.43251 .67089 Mdot
.68857 .52407 Mdot
.85266 .46057 Mdot
.68823 .49259 Mdot
.64608 .60084 Mdot
.42685 .81636 Mdot
.47531 .40864 Mdot
.47444 .24051 Mdot
.68268 .4951 Mdot
.3194 .51916 Mdot
.46283 .3649 Mdot
.65712 .56964 Mdot
.69174 .51416 Mdot
.72792 .49521 Mdot
.4714 .36818 Mdot
.31312 .52558 Mdot
.62525 .61591 Mdot
.44974 .61714 Mdot
.72626 .4692 Mdot
.44322 .444 Mdot
.43476 .38111 Mdot
.51675 .42045 Mdot
.5291 .52744 Mdot
.57793 .24803 Mdot
.41047 .65027 Mdot
.7439 .4079 Mdot
.60363 .59388 Mdot
.67037 .65615 Mdot
.35691 .73011 Mdot
.41839 .69144 Mdot
.60124 .71782 Mdot
.59741 .70949 Mdot
.47908 .37046 Mdot
.5841 .24859 Mdot
.55109 .81108 Mdot
.45918 .68972 Mdot
.58517 .73238 Mdot
.60721 .62645 Mdot
.30956 .46323 Mdot
.23909 .65524 Mdot
.43497 .36932 Mdot
.38973 .62387 Mdot
.60684 .59774 Mdot
.5443 .21044 Mdot
.7015 .51026 Mdot
.40286 .796 Mdot
.51941 .34826 Mdot
.4553 .39502 Mdot
.41532 .64658 Mdot
.43998 .64993 Mdot
.51713 .7707 Mdot
.29592 .70726 Mdot
.64295 .48653 Mdot
.30106 .57182 Mdot
.52022 .21409 Mdot
.34565 .45775 Mdot
.32076 .47226 Mdot
.57659 .73803 Mdot
.43421 .66566 Mdot
.51048 .40779 Mdot
.35897 .49614 Mdot
.52653 .78535 Mdot
.28266 .53943 Mdot
.66285 .39653 Mdot
.75124 .62621 Mdot
.51821 .35894 Mdot
.30333 .48563 Mdot
.35167 .50643 Mdot
.3579 .52846 Mdot
.5883 .74429 Mdot
.47823 .3944 Mdot
.46989 .33728 Mdot
.45041 .39358 Mdot
.46655 .4533 Mdot
.51312 .37469 Mdot
.3429 .70634 Mdot
.54241 .57133 Mdot
.65426 .26127 Mdot
.44017 .37955 Mdot
.42044 .66347 Mdot
.49854 .42878 Mdot
.72335 .48998 Mdot
.47536 .35037 Mdot
.65796 .38764 Mdot
.41245 .63208 Mdot
.49967 .28573 Mdot
.2929 .57027 Mdot
.51598 .34404 Mdot
.72175 .51902 Mdot
.59844 .26113 Mdot
.222 .36614 Mdot
.55652 .6163 Mdot
.31618 .48356 Mdot
.59878 .64763 Mdot
.41642 .60172 Mdot
.62101 .61341 Mdot
.44455 .37525 Mdot
.57986 .73921 Mdot
.37018 .69187 Mdot
.42937 .51267 Mdot
.51872 .4022 Mdot
.42214 .34558 Mdot
.30515 .49345 Mdot
.63879 .62609 Mdot
.38397 .49851 Mdot
.51403 .3894 Mdot
.69572 .5002 Mdot
.69702 .51673 Mdot
.30239 .69874 Mdot
.56558 .19362 Mdot
.23711 .54299 Mdot
.41393 .64762 Mdot
.59715 .63141 Mdot
.72974 .48511 Mdot
.40518 .34507 Mdot
.38588 .63214 Mdot
.39332 .62148 Mdot
.43035 .63485 Mdot
.51325 .3624 Mdot
.60209 .71527 Mdot
.60388 .23858 Mdot
.60443 .7223 Mdot
.51163 .34153 Mdot
.59602 .6103 Mdot
.59896 .70387 Mdot
.68455 .50487 Mdot
.40145 .61805 Mdot
.61773 .58674 Mdot
.50681 .36862 Mdot
.33695 .51633 Mdot
.59784 .46406 Mdot
.61617 .34015 Mdot
.75775 .35719 Mdot
.75249 .34493 Mdot
.29913 .47504 Mdot
.63122 .20474 Mdot
.44143 .67182 Mdot
.31938 .29714 Mdot
.75562 .50667 Mdot
.4476 .41333 Mdot
.29484 .74362 Mdot
.64249 .60088 Mdot
.63582 .63265 Mdot
.48843 .37103 Mdot
.61125 .57437 Mdot
.48303 .41389 Mdot
.6158 .58408 Mdot
.55776 .61502 Mdot
.4355 .36422 Mdot
.62947 .63397 Mdot
.52437 .43205 Mdot
.48063 .33461 Mdot
.29608 .5069 Mdot
.64792 .58725 Mdot
.44776 .37281 Mdot
.8497 .53384 Mdot
.44145 .65272 Mdot
.58824 .74337 Mdot
.6149 .51745 Mdot
.39745 .64262 Mdot
.34188 .49799 Mdot
.45814 .33582 Mdot
.70051 .48089 Mdot
.32741 .51235 Mdot
.57834 .56395 Mdot
.68092 .50204 Mdot
.35595 .75976 Mdot
.31063 .48555 Mdot
.58787 .73222 Mdot
.68834 .48793 Mdot
.4315 .33299 Mdot
.65267 .59493 Mdot
.59088 .31933 Mdot
.60208 .7337 Mdot
.48599 .40224 Mdot
.59503 .57282 Mdot
.44064 .6579 Mdot
.4612 .38642 Mdot
.63612 .57505 Mdot
.58978 .74585 Mdot
.50545 .35859 Mdot
.47654 .35928 Mdot
.21345 .60544 Mdot
.50298 .80529 Mdot
.71494 .4866 Mdot
.28997 .51869 Mdot
.49915 .37368 Mdot
.70377 .47554 Mdot
.73054 .69446 Mdot
.52536 .41067 Mdot
.34269 .52901 Mdot
.54514 .45547 Mdot
.60193 .5927 Mdot
.40279 .61954 Mdot
.6477 .63547 Mdot
.72428 .48559 Mdot
.33615 .81545 Mdot
.59518 .70425 Mdot
.54373 .41833 Mdot
.46695 .42112 Mdot
.62194 .67846 Mdot
.35237 .50152 Mdot
.64238 .4792 Mdot
.50295 .3933 Mdot
.41642 .43813 Mdot
.46403 .40709 Mdot
.74993 .60528 Mdot
.30324 .50809 Mdot
.48699 .40747 Mdot
.55304 .30588 Mdot
.54178 .37536 Mdot
.72772 .5112 Mdot
.71559 .35452 Mdot
.5114 .42034 Mdot
.53551 .10121 Mdot
.59655 .74713 Mdot
.62696 .63602 Mdot
.66655 .58089 Mdot
.79534 .66495 Mdot
.22011 .52792 Mdot
.34676 .48802 Mdot
.4501 .48097 Mdot
.62313 .61489 Mdot
.20989 .48893 Mdot
.6653 .22218 Mdot
.48479 .33406 Mdot
.53069 .3756 Mdot
.64609 .60082 Mdot
.60088 .57915 Mdot
.57793 .73109 Mdot
.44507 .36896 Mdot
.47102 .3028 Mdot
.59407 .63402 Mdot
.51879 .37118 Mdot
.56497 .4316 Mdot
.44874 .61835 Mdot
.29773 .51664 Mdot
.41467 .61421 Mdot
.40707 .60783 Mdot
.34605 .33532 Mdot
.33564 .72134 Mdot
.44563 .63949 Mdot
.46096 .61958 Mdot
.64957 .38871 Mdot
.5341 .46971 Mdot
.73003 .49369 Mdot
.66062 .24415 Mdot
.60874 .61165 Mdot
.47683 .39324 Mdot
.31378 .47048 Mdot
.33548 .31476 Mdot
.52303 .64999 Mdot
.46603 .82797 Mdot
.5159 .394 Mdot
.61289 .6258 Mdot
.59374 .7443 Mdot
.43317 .37135 Mdot
.68205 .63033 Mdot
.45509 .38769 Mdot
.65274 .61326 Mdot
.37927 .37496 Mdot
.58637 .40533 Mdot
.63029 .6995 Mdot
.36969 .50333 Mdot
.4737 .41927 Mdot
.32937 .48185 Mdot
.4054 .62638 Mdot
.71462 .48004 Mdot
.7116 .48509 Mdot
.46764 .36328 Mdot
.39585 .38375 Mdot
.46475 .56701 Mdot
.48791 .33269 Mdot
.47646 .34283 Mdot
.59803 .73236 Mdot
.47475 .34295 Mdot
.46337 .41928 Mdot
.44894 .39781 Mdot
.54645 .37472 Mdot
.3991 .65954 Mdot
.5874 .41177 Mdot
.53753 .34098 Mdot
.56558 .37094 Mdot
.45198 .63314 Mdot
.4192 .4763 Mdot
.41211 .60764 Mdot
.55728 .17771 Mdot
.42698 .61163 Mdot
.71684 .49234 Mdot
.57929 .58742 Mdot
.42483 .46042 Mdot
.36426 .50055 Mdot
.38936 .65242 Mdot
.70525 .49793 Mdot
.4046 .64254 Mdot
.59265 .61377 Mdot
.25877 .28848 Mdot
.28426 .54078 Mdot
.63113 .46599 Mdot
.47975 .60919 Mdot
.48085 .78651 Mdot
.6347 .59449 Mdot
.29938 .50678 Mdot
.4488 .23614 Mdot
.44878 .38069 Mdot
.68505 .49426 Mdot
.47501 .37066 Mdot
.39336 .65402 Mdot
.60991 .62207 Mdot
.76561 .39393 Mdot
.70759 .482 Mdot
.18154 .54433 Mdot
.6035 .61952 Mdot
.46884 .33427 Mdot
.38917 .62772 Mdot
.17138 .41493 Mdot
.42122 .6094 Mdot
.60261 .44856 Mdot
.30962 .54153 Mdot
.25134 .47339 Mdot
.32476 .49812 Mdot
.54771 .77814 Mdot
.40236 .15718 Mdot
.74476 .31097 Mdot
.33043 .521 Mdot
.64163 .71053 Mdot
.5244 .36608 Mdot
.50911 .42487 Mdot
.55929 .32244 Mdot
.32063 .54025 Mdot
.50527 .37464 Mdot
.59963 .73548 Mdot
.26847 .63931 Mdot
.6883 .6513 Mdot
.60137 .6481 Mdot
.49231 .41127 Mdot
.45127 .63311 Mdot
.44832 .60338 Mdot
.6014 .70744 Mdot
.42163 .60394 Mdot
.46426 .34288 Mdot
.32491 .50154 Mdot
.41087 .52193 Mdot
.69203 .49375 Mdot
.82858 .4737 Mdot
.72727 .52202 Mdot
.66392 .59125 Mdot
.4527 .32021 Mdot
.62909 .61383 Mdot
.48362 .88193 Mdot
.45402 .36558 Mdot
.34307 .51837 Mdot
.48718 .35976 Mdot
.463 .41328 Mdot
.50993 .42528 Mdot
.58597 .61767 Mdot
.65887 .52339 Mdot
.51627 .36989 Mdot
.4274 .6388 Mdot
.70432 .29273 Mdot
.48321 .43286 Mdot
.56902 .64003 Mdot
.69075 .37683 Mdot
.43723 .77794 Mdot
.36014 .5334 Mdot
.63745 .62565 Mdot
.3416 .50458 Mdot
.36205 .48097 Mdot
.34204 .49791 Mdot
.60672 .23452 Mdot
.43158 .25664 Mdot
.65831 .80493 Mdot
.29094 .44431 Mdot
.3077 .32855 Mdot
.28322 .50851 Mdot
.71244 .7277 Mdot
.3386 .47359 Mdot
.34691 .4933 Mdot
.89871 .47086 Mdot
.34376 .47423 Mdot
.50278 .40379 Mdot
.43224 .41018 Mdot
.31765 .64314 Mdot
.63996 .40219 Mdot
.46708 .35123 Mdot
.49443 .37228 Mdot
.70684 .47712 Mdot
.46308 .26577 Mdot
.57606 .72787 Mdot
.35003 .75912 Mdot
.34649 .60821 Mdot
.47334 .36813 Mdot
.50008 .37134 Mdot
.42356 .40922 Mdot
.34673 .16973 Mdot
.35998 .30424 Mdot
.28293 .4924 Mdot
.41208 .36777 Mdot
.81297 .41529 Mdot
.48946 .32845 Mdot
.53029 .39439 Mdot
.51139 .35555 Mdot
.62209 .61567 Mdot
.29428 .47036 Mdot
.41235 .36829 Mdot
.41049 .75653 Mdot
.52428 .35681 Mdot
.43526 .68876 Mdot
.68807 .46153 Mdot
.49563 .40656 Mdot
.34484 .53713 Mdot
.49001 .34946 Mdot
.31375 .48204 Mdot
.29365 .50527 Mdot
.42255 .40666 Mdot
.58736 .2206 Mdot
.33953 .53371 Mdot
.51301 .34479 Mdot
.63071 .62429 Mdot
.74016 .29785 Mdot
.48858 .40262 Mdot
.72078 .50832 Mdot
.50445 .39107 Mdot
.71794 .52165 Mdot
.48709 .33714 Mdot
.60384 .72911 Mdot
.33828 .26429 Mdot
.6141 .61077 Mdot
.75107 .45598 Mdot
.58621 .59407 Mdot
.21538 .60837 Mdot
.34573 .52497 Mdot
.57884 .74759 Mdot
.4283 .83142 Mdot
.59558 .73433 Mdot
.58583 .46837 Mdot
.54938 .61437 Mdot
.41881 .66017 Mdot
.31637 .53512 Mdot
.73634 .41743 Mdot
.61627 .70338 Mdot
.63691 .54878 Mdot
.58161 .62833 Mdot
.33665 .80294 Mdot
.37545 .8064 Mdot
.50994 .36615 Mdot
.49713 .23441 Mdot
.26571 .41373 Mdot
.52834 .40501 Mdot
.47428 .32579 Mdot
.65377 .59259 Mdot
.4848 .42292 Mdot
.51287 .51957 Mdot
.62657 .59439 Mdot
.70887 .50145 Mdot
.33889 .48714 Mdot
.71304 .52341 Mdot
.64223 .56123 Mdot
.55335 .55796 Mdot
.61061 .58985 Mdot
.54611 .38484 Mdot
.49013 .36279 Mdot
.29611 .49406 Mdot
.3834 .51967 Mdot
.29547 .51279 Mdot
.68266 .5209 Mdot
.61894 .59654 Mdot
.35325 .29873 Mdot
.49197 .38068 Mdot
.31959 .50698 Mdot
.382 .59228 Mdot
.49667 .37824 Mdot
.40062 .63627 Mdot
.52823 .36712 Mdot
.33063 .52348 Mdot
.475 .34261 Mdot
.32697 .50134 Mdot
.64136 .611 Mdot
.50163 .33021 Mdot
.48605 .37238 Mdot
.17486 .44083 Mdot
.70923 .48858 Mdot
.3444 .5258 Mdot
.5032 .56638 Mdot
.46196 .3404 Mdot
.64697 .66341 Mdot
.49928 .41481 Mdot
.48792 .47792 Mdot
.53554 .42454 Mdot
.5961 .73827 Mdot
.51608 .3183 Mdot
.48801 .40333 Mdot
.56292 .30558 Mdot
.29772 .42792 Mdot
.38485 .49573 Mdot
.39056 .64541 Mdot
.33965 .53832 Mdot
.64737 .57652 Mdot
.61862 .56913 Mdot
.607 .58215 Mdot
.63242 .42187 Mdot
.42553 .41089 Mdot
.47578 .40729 Mdot
.39236 .66222 Mdot
.71199 .50713 Mdot
.31644 .51296 Mdot
.70929 .51119 Mdot
.34043 .74565 Mdot
.68235 .51879 Mdot
.60235 .71251 Mdot
.74235 .62067 Mdot
.37021 .26751 Mdot
.70423 .47729 Mdot
.2963 .5144 Mdot
.74275 .63612 Mdot
.44648 .41021 Mdot
.57817 .55808 Mdot
.69524 .50224 Mdot
.30242 .78626 Mdot
.50894 .41242 Mdot
.57478 .49418 Mdot
.43968 .61236 Mdot
.69053 .51769 Mdot
.42312 .62546 Mdot
.46661 .35531 Mdot
.45971 .76592 Mdot
.35534 .49918 Mdot
.45122 .65249 Mdot
.5381 .33897 Mdot
.70218 .52389 Mdot
.60374 .6024 Mdot
.48292 .63593 Mdot
.41985 .66308 Mdot
.33214 .25073 Mdot
.74885 .3808 Mdot
.62102 .5959 Mdot
.57319 .79574 Mdot
.43277 .62951 Mdot
.52554 .40846 Mdot
.43209 .45571 Mdot
.45592 .35447 Mdot
.62038 .56632 Mdot
.6363 .62861 Mdot
.29107 .64785 Mdot
.49148 .36059 Mdot
.50493 .41355 Mdot
.27307 .50965 Mdot
.63288 .5995 Mdot
.31435 .49312 Mdot
.36006 .52747 Mdot
.64294 .61706 Mdot
.32709 .49309 Mdot
.68244 .4986 Mdot
.25306 .60741 Mdot
.43377 .6298 Mdot
.42389 .63732 Mdot
.60701 .62525 Mdot
.61226 .64014 Mdot
.63083 .61244 Mdot
.52813 .36678 Mdot
.30992 .51299 Mdot
.50282 .34609 Mdot
.52874 .40889 Mdot
.36648 .52992 Mdot
.34623 .47356 Mdot
.49919 .35121 Mdot
.63671 .68307 Mdot
.7137 .46315 Mdot
.62569 .63353 Mdot
.44364 .62463 Mdot
.21532 .48329 Mdot
.38996 .6642 Mdot
.49233 .41272 Mdot
.49614 .66649 Mdot
.32493 .52393 Mdot
.68653 .49534 Mdot
.71036 .45837 Mdot
.69372 .48602 Mdot
.38384 .6207 Mdot
.36142 .51601 Mdot
.35558 .75823 Mdot
.48666 .4128 Mdot
.52552 .52794 Mdot
.73958 .4106 Mdot
.36545 .73946 Mdot
.44603 .63545 Mdot
.49709 .37502 Mdot
.59299 .73517 Mdot
.42335 .24475 Mdot
.45622 .3922 Mdot
.44481 .38856 Mdot
.75281 .55793 Mdot
.56582 .36981 Mdot
.321 .54158 Mdot
.27352 .69507 Mdot
.43856 .41784 Mdot
.25908 .52591 Mdot
.80885 .68363 Mdot
.48958 .41675 Mdot
.51489 .3838 Mdot
.48719 .39224 Mdot
.48339 .35463 Mdot
.32259 .5445 Mdot
.67781 .43482 Mdot
.38859 .63068 Mdot
.54029 .53722 Mdot
.43671 .63683 Mdot
.65209 .60895 Mdot
.56432 .49662 Mdot
.30905 .5294 Mdot
.68748 .49182 Mdot
.39136 .22264 Mdot
.31623 .72745 Mdot
.6332 .5895 Mdot
.38028 .31069 Mdot
.69445 .49474 Mdot
.44519 .41219 Mdot
.68778 .53257 Mdot
.59563 .58242 Mdot
.43063 .64722 Mdot
.43169 .40577 Mdot
.30345 .47686 Mdot
.32338 .53105 Mdot
.50232 .37707 Mdot
.79282 .38447 Mdot
.39995 .63151 Mdot
.37853 .6622 Mdot
.51526 .36175 Mdot
.44461 .38711 Mdot
.3199 .48856 Mdot
.62326 .62921 Mdot
.66622 .73576 Mdot
.70918 .49321 Mdot
.516 .33183 Mdot
.48107 .35222 Mdot
.32473 .72118 Mdot
.39623 .62249 Mdot
.58156 .72355 Mdot
.50927 .36149 Mdot
.32973 .71352 Mdot
.50725 .3605 Mdot
.45748 .32604 Mdot
.629 .61908 Mdot
.5107 .43366 Mdot
.52789 .38484 Mdot
.41362 .34938 Mdot
.4289 .62581 Mdot
.34772 .51128 Mdot
.28199 .52895 Mdot
.58239 .73879 Mdot
.40142 .63633 Mdot
.49566 .35078 Mdot
.39552 .62907 Mdot
.51127 .42254 Mdot
.51439 .37143 Mdot
.44561 .63611 Mdot
.315 .49291 Mdot
.36047 .63317 Mdot
.58659 .44643 Mdot
.48649 .35641 Mdot
.43351 .38691 Mdot
.63906 .41576 Mdot
.51981 .84867 Mdot
.51418 .39797 Mdot
.32871 .52681 Mdot
.49076 .37682 Mdot
.41573 .62511 Mdot
.68557 .52077 Mdot
.33463 .51967 Mdot
.60793 .63369 Mdot
.64335 .60605 Mdot
.28661 .56843 Mdot
.59924 .70624 Mdot
.43596 .3743 Mdot
.38173 .45436 Mdot
.32382 .46814 Mdot
.8433 .57913 Mdot
.64164 .63085 Mdot
.72912 .51082 Mdot
.47322 .35855 Mdot
.4916 .62675 Mdot
.38904 .65827 Mdot
.53084 .09886 Mdot
.3599 .75833 Mdot
.70542 .54036 Mdot
.45576 .82913 Mdot
.59088 .72975 Mdot
.5251 .39678 Mdot
.71832 .48249 Mdot
.63636 .5849 Mdot
.48221 .42679 Mdot
.54609 .42945 Mdot
.63594 .48441 Mdot
.618 .66224 Mdot
.39796 .6243 Mdot
.60292 .58823 Mdot
.67129 .50893 Mdot
.60278 .71413 Mdot
.31479 .53032 Mdot
.48442 .4047 Mdot
.41732 .39965 Mdot
.61629 .63339 Mdot
.60409 .72942 Mdot
.51812 .358 Mdot
.32692 .53365 Mdot
.61198 .57577 Mdot
.46807 .36818 Mdot
.31922 .30314 Mdot
.36748 .48869 Mdot
.61107 .60051 Mdot
.46513 .41921 Mdot
.49346 .47261 Mdot
.60636 .62916 Mdot
.61985 .63648 Mdot
.50492 .37425 Mdot
.68509 .49194 Mdot
.53087 .36453 Mdot
.43205 .61173 Mdot
.65848 .5205 Mdot
.41674 .6276 Mdot
.76566 .48684 Mdot
.46805 .31313 Mdot
.49611 .78782 Mdot
.28891 .50398 Mdot
.67157 .49833 Mdot
.20607 .40993 Mdot
.4425 .3879 Mdot
.61399 .20555 Mdot
.43715 .51028 Mdot
.8419 .46148 Mdot
.39691 .18147 Mdot
.69767 .50552 Mdot
.40408 .63762 Mdot
.51411 .38363 Mdot
.42091 .67574 Mdot
.7171 .48498 Mdot
.75228 .41483 Mdot
.45982 .41617 Mdot
.30259 .50544 Mdot
.52352 .35748 Mdot
.31673 .48308 Mdot
.49772 .38021 Mdot
.56245 .36229 Mdot
.69483 .54572 Mdot
.6047 .44659 Mdot
.44545 .4104 Mdot
.25713 .2882 Mdot
.50323 .59973 Mdot
.69913 .49538 Mdot
.50795 .34493 Mdot
.5921 .71672 Mdot
.43679 .59693 Mdot
.57057 .26033 Mdot
.62539 .61434 Mdot
.44832 .63545 Mdot
.33203 .48961 Mdot
.63374 .64036 Mdot
.59119 .74768 Mdot
.41925 .41992 Mdot
.72347 .51498 Mdot
.41401 .65865 Mdot
.4913 .40493 Mdot
.50938 .41161 Mdot
.65747 .70188 Mdot
.52859 .70585 Mdot
.2815 .4816 Mdot
.17673 .50676 Mdot
.33411 .54505 Mdot
.71486 .49567 Mdot
.6298 .61725 Mdot
.51213 .40146 Mdot
.46006 .38144 Mdot
.62891 .56652 Mdot
.34593 .52342 Mdot
.63825 .65179 Mdot
.36142 .32723 Mdot
.60961 .64452 Mdot
.69084 .409 Mdot
.33925 .52212 Mdot
.68777 .41254 Mdot
.67089 .50884 Mdot
.55656 .20265 Mdot
.63496 .33267 Mdot
.43967 .61164 Mdot
.69524 .406 Mdot
.32114 .51933 Mdot
.49988 .36445 Mdot
.58802 .72915 Mdot
.59447 .70706 Mdot
.33123 .48561 Mdot
.64643 .59872 Mdot
.6922 .51744 Mdot
.51681 .38137 Mdot
.42471 .79111 Mdot
.30235 .60645 Mdot
.59895 .6341 Mdot
.56781 .41352 Mdot
.42615 .63031 Mdot
.5255 .38546 Mdot
.71826 .51402 Mdot
.41685 .65623 Mdot
.6075 .74048 Mdot
.26943 .63305 Mdot
.46577 .36087 Mdot
.29211 .6994 Mdot
.4016 .64425 Mdot
.58059 .79843 Mdot
.4727 .37562 Mdot
.43254 .62928 Mdot
.53654 .32217 Mdot
.39734 .73586 Mdot
.46764 .54155 Mdot
.67941 .2359 Mdot
.60251 .66004 Mdot
.64428 .60018 Mdot
.46398 .73137 Mdot
.72856 .53755 Mdot
.4485 .64461 Mdot
.60325 .71568 Mdot
.67285 .32128 Mdot
.42535 .62606 Mdot
.53314 .38658 Mdot
.49695 .41514 Mdot
.34272 .33104 Mdot
.49211 .53804 Mdot
.60525 .72255 Mdot
.22994 .55219 Mdot
.45421 .35289 Mdot
.55479 .38778 Mdot
.4642 .38588 Mdot
.28457 .49475 Mdot
.398 .64682 Mdot
.18173 .38935 Mdot
.40285 .62568 Mdot
.43233 .80051 Mdot
.60873 .61271 Mdot
.60542 .6408 Mdot
.49625 .40819 Mdot
.52973 .79399 Mdot
.55978 .24502 Mdot
.47454 .33445 Mdot
.65803 .65493 Mdot
.74234 .37271 Mdot
.55781 .36607 Mdot
.30048 .53884 Mdot
.42042 .37654 Mdot
.36641 .47088 Mdot
.43186 .65486 Mdot
.69749 .51122 Mdot
.7201 .46629 Mdot
.41829 .6588 Mdot
.47462 .40543 Mdot
.67464 .61113 Mdot
.45932 .40222 Mdot
.50848 .36385 Mdot
.39653 .79589 Mdot
.73232 .49338 Mdot
.63355 .61067 Mdot
.70985 .48365 Mdot
.34812 .49418 Mdot
.84085 .31538 Mdot
.70971 .51423 Mdot
.38035 .44451 Mdot
.72018 .44123 Mdot
.69472 .40892 Mdot
.32243 .53235 Mdot
.67631 .50151 Mdot
.40202 .62173 Mdot
.84586 .4448 Mdot
.55852 .82968 Mdot
.39842 .67531 Mdot
.4677 .37531 Mdot
.29917 .52146 Mdot
.29352 .48095 Mdot
.44626 .66412 Mdot
.30297 .51715 Mdot
.46247 .3075 Mdot
.4955 .3591 Mdot
.44812 .64533 Mdot
.31004 .62945 Mdot
.41549 .6631 Mdot
.24762 .61539 Mdot
.51399 .34965 Mdot
.33837 .52019 Mdot
.42238 .35718 Mdot
.27892 .53264 Mdot
.57995 .72041 Mdot
.4834 .42749 Mdot
.68562 .51086 Mdot
.50143 .52899 Mdot
.61117 .6029 Mdot
.49921 .66074 Mdot
.29742 .49453 Mdot
.36733 .60972 Mdot
.29598 .50768 Mdot
.29978 .52554 Mdot
.40841 .60638 Mdot
.35074 .48842 Mdot
.51587 .38356 Mdot
.63869 .69832 Mdot
.31835 .47812 Mdot
.41442 .64135 Mdot
.68883 .50716 Mdot
.32255 .49272 Mdot
.65576 .60809 Mdot
.48041 .36412 Mdot
.60992 .58769 Mdot
.71047 .54094 Mdot
.31906 .53644 Mdot
.67709 .50208 Mdot
.63148 .63528 Mdot
.7268 .50517 Mdot
.77374 .41242 Mdot
.43077 .66655 Mdot
.47351 .82811 Mdot
.56334 .45082 Mdot
.30563 .47562 Mdot
.62529 .54867 Mdot
.5112 .40008 Mdot
.4793 .36192 Mdot
.67438 .49721 Mdot
.29548 .47862 Mdot
.75819 .32226 Mdot
.46674 .4775 Mdot
.26012 .61404 Mdot
.41329 .66766 Mdot
.19271 .52372 Mdot
.29946 .6756 Mdot
.8171 .53432 Mdot
.49941 .43992 Mdot
.59061 .72925 Mdot
.47322 .41246 Mdot
.20956 .3825 Mdot
.69319 .52538 Mdot
.66001 .76826 Mdot
.46935 .43825 Mdot
.6277 .60534 Mdot
.48166 .38192 Mdot
.55702 .27791 Mdot
.42381 .36613 Mdot
.69516 .47855 Mdot
.43408 .69509 Mdot
.36406 .50099 Mdot
.69297 .49361 Mdot
.64174 .6038 Mdot
.69531 .35117 Mdot
.47662 .42648 Mdot
.45243 .35178 Mdot
.59918 .64191 Mdot
.3012 .50829 Mdot
.65259 .6008 Mdot
.4339 .63029 Mdot
.70508 .51214 Mdot
.47562 .35565 Mdot
.54444 .40659 Mdot
.66184 .64039 Mdot
.39741 .64725 Mdot
.61929 .64338 Mdot
.41381 .61369 Mdot
.58977 .72977 Mdot
.43599 .40452 Mdot
.59319 .63597 Mdot
.51375 .41191 Mdot
.19286 .42475 Mdot
.40621 .80244 Mdot
.32234 .41809 Mdot
.63529 .60794 Mdot
.67906 .39213 Mdot
.41151 .62953 Mdot
.42294 .61143 Mdot
.24285 .4789 Mdot
.59309 .25606 Mdot
.76329 .60607 Mdot
.34726 .23642 Mdot
.43451 .63066 Mdot
.41817 .63166 Mdot
.63319 .58057 Mdot
.34364 .48272 Mdot
.34091 .46166 Mdot
.63728 .64254 Mdot
.60847 .43859 Mdot
.31653 .51283 Mdot
.62743 .21141 Mdot
.65134 .58045 Mdot
.50157 .44071 Mdot
.57789 .71365 Mdot
.69766 .51536 Mdot
.60675 .43968 Mdot
.54996 .27661 Mdot
.51502 .40282 Mdot
.25274 .67808 Mdot
.62258 .62591 Mdot
.65548 .45594 Mdot
.54995 .17813 Mdot
.45438 .41083 Mdot
.47629 .38846 Mdot
.4705 .40171 Mdot
.73255 .48899 Mdot
.21518 .39374 Mdot
.51685 .40262 Mdot
.61174 .45236 Mdot
.48241 .32531 Mdot
.60508 .31716 Mdot
.71212 .48505 Mdot
.26747 .5452 Mdot
.60098 .65629 Mdot
.3883 .74911 Mdot
.56069 .32617 Mdot
.4263 .61924 Mdot
.57642 .57873 Mdot
.43476 .64608 Mdot
.57192 .2327 Mdot
.63834 .33593 Mdot
.28223 .51359 Mdot
.51726 .39334 Mdot
.5781 .61161 Mdot
.29099 .5065 Mdot
.61525 .73783 Mdot
.89616 .44095 Mdot
.39407 .64562 Mdot
.52044 .86764 Mdot
.42125 .6107 Mdot
.58658 .71202 Mdot
.32289 .48743 Mdot
.41506 .27902 Mdot
.52425 .52721 Mdot
.32405 .49396 Mdot
.36838 .68582 Mdot
.32982 .54888 Mdot
.68807 .39637 Mdot
.36723 .50444 Mdot
.41211 .6376 Mdot
.42093 .58668 Mdot
.53733 .43193 Mdot
.50672 .39849 Mdot
.56391 .53406 Mdot
.40461 .45722 Mdot
.50975 .39695 Mdot
.62671 .5946 Mdot
.54055 .82119 Mdot
.57014 .61658 Mdot
.3255 .47307 Mdot
.38985 .63466 Mdot
.47738 .38679 Mdot
.4944 .35621 Mdot
.51465 .41503 Mdot
.17033 .44739 Mdot
.63428 .21771 Mdot
.51376 .36935 Mdot
.524 .33851 Mdot
.64015 .60932 Mdot
.66562 .50348 Mdot
.29057 .27056 Mdot
.66241 .32334 Mdot
.45287 .38049 Mdot
.70696 .48582 Mdot
.73052 .51283 Mdot
.4636 .42487 Mdot
.43269 .78329 Mdot
.63607 .70913 Mdot
.49119 .40465 Mdot
.61795 .30948 Mdot
.61631 .56086 Mdot
.60213 .70783 Mdot
.61484 .63274 Mdot
.34921 .53565 Mdot
.60165 .7198 Mdot
.59039 .58989 Mdot
.41347 .27322 Mdot
.58219 .7406 Mdot
.37389 .71388 Mdot
.68271 .52099 Mdot
.46094 .38729 Mdot
.31823 .54731 Mdot
.62237 .56706 Mdot
.42038 .65966 Mdot
.33429 .50851 Mdot
.44187 .59766 Mdot
.68563 .54378 Mdot
.63549 .45231 Mdot
.59671 .70458 Mdot
.43209 .62287 Mdot
.26896 .63365 Mdot
.70836 .48536 Mdot
.41869 .60535 Mdot
.53287 .79013 Mdot
.47027 .43464 Mdot
.49991 .21639 Mdot
.49782 .33222 Mdot
.8155 .4102 Mdot
.41201 .60941 Mdot
.5821 .74555 Mdot
.47925 .40791 Mdot
.60362 .62093 Mdot
.50156 .30604 Mdot
.45467 .38515 Mdot
.59911 .62864 Mdot
.50782 .36583 Mdot
.72161 .50933 Mdot
.37211 .48542 Mdot
.40982 .51267 Mdot
.19419 .65087 Mdot
.72412 .51139 Mdot
.60764 .75439 Mdot
.51488 .39678 Mdot
.76203 .39027 Mdot
.32088 .49424 Mdot
.44754 .40146 Mdot
.23518 .4924 Mdot
.33331 .47935 Mdot
.3386 .50297 Mdot
.48533 .34223 Mdot
.4325 .60707 Mdot
.60429 .61218 Mdot
.70561 .48406 Mdot
.83148 .53588 Mdot
.46138 .37155 Mdot
.48815 .37463 Mdot
.69363 .49482 Mdot
.41752 .62932 Mdot
.49226 .3549 Mdot
.51169 .65672 Mdot
.84982 .51276 Mdot
.40043 .61057 Mdot
.48761 .43388 Mdot
.44621 .21072 Mdot
.26601 .50965 Mdot
.52218 .8576 Mdot
.74892 .46922 Mdot
.6364 .62481 Mdot
.56073 .35839 Mdot
.5968 .13126 Mdot
.69582 .51199 Mdot
.37446 .75215 Mdot
.51933 .36775 Mdot
.49096 .38582 Mdot
.31624 .52495 Mdot
.49981 .34787 Mdot
.35358 .51 Mdot
.22562 .70352 Mdot
.16968 .56493 Mdot
.30006 .49782 Mdot
.32325 .4713 Mdot
.25501 .49234 Mdot
.27328 .29133 Mdot
.33772 .48904 Mdot
.50036 .43103 Mdot
.70431 .28265 Mdot
.42532 .42986 Mdot
.67597 .49159 Mdot
.73508 .51887 Mdot
.30629 .56299 Mdot
.56158 .74816 Mdot
.41884 .47117 Mdot
.53544 .29999 Mdot
.46638 .5746 Mdot
.43632 .61735 Mdot
.44965 .38805 Mdot
.5988 .70523 Mdot
.59953 .5867 Mdot
.42684 .36672 Mdot
.45923 .392 Mdot
.31658 .48132 Mdot
.72598 .47505 Mdot
.42648 .59956 Mdot
.49384 .37206 Mdot
.63868 .65421 Mdot
.70999 .49816 Mdot
.31827 .47573 Mdot
.25342 .47688 Mdot
.7236 .48191 Mdot
.51658 .31755 Mdot
.50173 .39088 Mdot
.51746 .3585 Mdot
.56743 .36261 Mdot
.43733 .65501 Mdot
.63878 .56232 Mdot
.53245 .40747 Mdot
.34082 .74314 Mdot
.5969 .48823 Mdot
.53311 .41976 Mdot
.31466 .51797 Mdot
.38679 .65471 Mdot
.57964 .72741 Mdot
.71894 .3737 Mdot
.46263 .36406 Mdot
.63413 .21976 Mdot
.36034 .31082 Mdot
.60063 .7198 Mdot
.28748 .51774 Mdot
.68837 .49144 Mdot
.46134 .34702 Mdot
.66017 .25672 Mdot
.49656 .41424 Mdot
.53882 .46657 Mdot
.6289 .62714 Mdot
.43921 .62188 Mdot
.85072 .48128 Mdot
.59625 .58962 Mdot
.34077 .50413 Mdot
.68552 .2346 Mdot
.31674 .46385 Mdot
.36207 .49951 Mdot
.58704 .2247 Mdot
.4392 .64923 Mdot
.57929 .12358 Mdot
.54345 .84036 Mdot
.5391 .38556 Mdot
.41277 .62315 Mdot
.31511 .48695 Mdot
.52505 .38453 Mdot
.32607 .46909 Mdot
.36009 .50529 Mdot
.48807 .42815 Mdot
.49729 .38933 Mdot
.58459 .45944 Mdot
.5868 .1903 Mdot
.69485 .48377 Mdot
.33779 .5283 Mdot
.30348 .34072 Mdot
.52024 .40033 Mdot
.48682 .41242 Mdot
.6191 .68273 Mdot
.69635 .47822 Mdot
.54457 .28446 Mdot
.50901 .36224 Mdot
.20356 .60445 Mdot
.43282 .38986 Mdot
.30184 .54187 Mdot
.40136 .60971 Mdot
.42106 .7771 Mdot
.62905 .56473 Mdot
.33769 .53177 Mdot
.7058 .52502 Mdot
.27594 .5158 Mdot
.3599 .44067 Mdot
.43641 .65004 Mdot
.3306 .52349 Mdot
.65034 .6232 Mdot
.42342 .65071 Mdot
.41694 .60658 Mdot
.70414 .2919 Mdot
.62431 .64422 Mdot
.68367 .52421 Mdot
.43227 .64268 Mdot
.31599 .30005 Mdot
.40925 .64076 Mdot
.31937 .3378 Mdot
.50996 .33444 Mdot
.61993 .45179 Mdot
.31786 .68518 Mdot
.56967 .37716 Mdot
.43388 .66143 Mdot
.71361 .48306 Mdot
.48209 .34696 Mdot
.30503 .51897 Mdot
.70819 .51525 Mdot
.47136 .65655 Mdot
.61633 .63868 Mdot
.29304 .49455 Mdot
.38895 .62591 Mdot
.34019 .52441 Mdot
.72478 .42059 Mdot
.64604 .52482 Mdot
.46668 .58365 Mdot
.54205 .52231 Mdot
.5203 .41081 Mdot
.36817 .56141 Mdot
.43463 .37618 Mdot
.45766 .39345 Mdot
.61046 .60143 Mdot
.63271 .42362 Mdot
.31491 .49237 Mdot
.85452 .48629 Mdot
.43439 .62206 Mdot
.22664 .64283 Mdot
.47402 .47261 Mdot
.44644 .38177 Mdot
.32161 .47786 Mdot
.3313 .46397 Mdot
.30188 .4272 Mdot
.63562 .56959 Mdot
.55593 .4233 Mdot
.48171 .31338 Mdot
.53709 .42896 Mdot
.41129 .61025 Mdot
.49722 .68237 Mdot
.64879 .59865 Mdot
.66396 .80896 Mdot
.62421 .63272 Mdot
.71934 .57965 Mdot
.35009 .48673 Mdot
.68874 .52116 Mdot
.48855 .41115 Mdot
.53862 .47448 Mdot
.29474 .53198 Mdot
.72687 .45742 Mdot
.68412 .50595 Mdot
.45312 .72065 Mdot
.44495 .64238 Mdot
.45587 .41912 Mdot
.47578 .422 Mdot
.50186 .34339 Mdot
.51167 .33835 Mdot
.39131 .63708 Mdot
.53251 .38934 Mdot
.44708 .65678 Mdot
.33141 .29155 Mdot
.20283 .60965 Mdot
.58317 .58758 Mdot
.57777 .2575 Mdot
.30065 .48078 Mdot
.29094 .32412 Mdot
.54403 .44523 Mdot
.41899 .80903 Mdot
.75907 .37203 Mdot
.44551 .35597 Mdot
.64182 .58533 Mdot
.52346 .24878 Mdot
.58139 .59887 Mdot
.29877 .81812 Mdot
.66957 .56353 Mdot
.65617 .21622 Mdot
.52238 .38813 Mdot
.6231 .67944 Mdot
.52648 .45768 Mdot
.47211 .4287 Mdot
.66933 .5529 Mdot
.21865 .55985 Mdot
.32733 .66077 Mdot
.73145 .49926 Mdot
.4757 .36485 Mdot
.36316 .49406 Mdot
.51748 .38407 Mdot
.48309 .41494 Mdot
.52788 .37904 Mdot
.3991 .60929 Mdot
.42833 .40217 Mdot
.53221 .37551 Mdot
.5367 .69995 Mdot
.65726 .39816 Mdot
.60067 .59163 Mdot
.31505 .43647 Mdot
.71139 .50738 Mdot
.30786 .48501 Mdot
.51526 .50273 Mdot
.44095 .61379 Mdot
.26715 .43699 Mdot
.5275 .36381 Mdot
.30639 .6715 Mdot
.38869 .62716 Mdot
.70394 .51551 Mdot
.58297 .73637 Mdot
.71172 .27604 Mdot
.58613 .58505 Mdot
.58132 .73917 Mdot
.61148 .60429 Mdot
.2208 .39841 Mdot
.31892 .48072 Mdot
.51738 .41459 Mdot
.42953 .63492 Mdot
.60252 .61113 Mdot
.63286 .4037 Mdot
.4657 .38979 Mdot
.63626 .60349 Mdot
.52276 .41008 Mdot
.62975 .4645 Mdot
.66092 .70488 Mdot
.58306 .60041 Mdot
.40096 .59949 Mdot
.42275 .64653 Mdot
.68156 .50246 Mdot
.30317 .48681 Mdot
.32232 .52323 Mdot
.41714 .6554 Mdot
.47571 .85592 Mdot
.45368 .3859 Mdot
.5241 .38904 Mdot
.34129 .74105 Mdot
.51015 .38729 Mdot
.69836 .3685 Mdot
.58397 .70895 Mdot
.30405 .48322 Mdot
.52523 .37966 Mdot
.48845 .35523 Mdot
.46924 .35927 Mdot
.72008 .42338 Mdot
.61876 .63373 Mdot
.45565 .35178 Mdot
.70895 .47565 Mdot
.5237 .77149 Mdot
.5239 .39412 Mdot
.55152 .39942 Mdot
.32575 .5213 Mdot
.17851 .58564 Mdot
.43505 .61076 Mdot
.62927 .59151 Mdot
.62728 .63758 Mdot
.74549 .50842 Mdot
.3707 .52107 Mdot
.57644 .72518 Mdot
.79641 .64717 Mdot
.5912 .74205 Mdot
.69904 .49162 Mdot
.77302 .53422 Mdot
.64957 .64747 Mdot
.62803 .58464 Mdot
.45773 .61904 Mdot
.52506 .35695 Mdot
.46293 .34125 Mdot
.3784 .75728 Mdot
.44971 .36159 Mdot
.68648 .50681 Mdot
.45058 .64265 Mdot
.32283 .51702 Mdot
.69913 .51778 Mdot
.41548 .61457 Mdot
.30206 .51068 Mdot
.46656 .43357 Mdot
.45984 .4334 Mdot
.3344 .50491 Mdot
.29321 .51063 Mdot
.4969 .40174 Mdot
.51959 .70335 Mdot
.35761 .53161 Mdot
.33428 .52329 Mdot
.60198 .70276 Mdot
.58368 .58833 Mdot
.41221 .39035 Mdot
.41064 .62316 Mdot
.51711 .36007 Mdot
.58185 .59506 Mdot
.68946 .48176 Mdot
.31455 .49743 Mdot
.48981 .35709 Mdot
.49462 .36657 Mdot
.70288 .48517 Mdot
.72476 .47883 Mdot
.69574 .51928 Mdot
.42645 .6767 Mdot
.49863 .33578 Mdot
.33802 .49109 Mdot
.44341 .64296 Mdot
.73046 .51286 Mdot
.69404 .53308 Mdot
.55527 .70008 Mdot
.51095 .40496 Mdot
.46461 .545 Mdot
.81404 .28841 Mdot
.68335 .34087 Mdot
.57913 .72516 Mdot
.60674 .645 Mdot
.66292 .42587 Mdot
.65446 .69217 Mdot
.39813 .63994 Mdot
.65223 .28891 Mdot
.67184 .49784 Mdot
.51195 .41991 Mdot
.43359 .3897 Mdot
.48343 .32164 Mdot
.70671 .50328 Mdot
.72959 .40672 Mdot
.29616 .47642 Mdot
.2543 .39372 Mdot
.7111 .50755 Mdot
.58393 .59816 Mdot
.589 .63182 Mdot
.62477 .63252 Mdot
.43887 .41444 Mdot
.28968 .42752 Mdot
.29958 .32627 Mdot
.26966 .30937 Mdot
.44726 .63896 Mdot
.29312 .47063 Mdot
.76964 .40699 Mdot
.33617 .50172 Mdot
.59763 .58667 Mdot
.70632 .49898 Mdot
.32473 .52748 Mdot
.40632 .65666 Mdot
.4201 .63194 Mdot
.61228 .63666 Mdot
.60741 .62393 Mdot
.60425 .59499 Mdot
.35688 .52734 Mdot
.35041 .48779 Mdot
.46038 .36178 Mdot
.32074 .50204 Mdot
.27081 .70391 Mdot
.71362 .53676 Mdot
.58302 .61841 Mdot
.4036 .63336 Mdot
.31276 .48496 Mdot
.46229 .38305 Mdot
.76841 .57369 Mdot
.31816 .58052 Mdot
.72591 .50296 Mdot
.64751 .72258 Mdot
.34633 .84518 Mdot
.48219 .42453 Mdot
.39795 .62252 Mdot
.45325 .7908 Mdot
.46978 .39697 Mdot
.62289 .61803 Mdot
.1988 .39766 Mdot
.59783 .74069 Mdot
.53176 .37933 Mdot
.44761 .37021 Mdot
.42031 .6039 Mdot
.73191 .44251 Mdot
.45966 .35829 Mdot
.27184 .66504 Mdot
.42477 .59425 Mdot
.63814 .57699 Mdot
.8541 .52113 Mdot
.65803 .56576 Mdot
.60428 .42251 Mdot
.58961 .71177 Mdot
.46659 .41622 Mdot
.62246 .59283 Mdot
.72548 .4959 Mdot
.61093 .59388 Mdot
.28485 .51649 Mdot
.6028 .59197 Mdot
.48789 .37618 Mdot
.34123 .49153 Mdot
.40088 .64277 Mdot
.2763 .69788 Mdot
.53373 .71528 Mdot
.60379 .62198 Mdot
.60229 .70067 Mdot
.52796 .39234 Mdot
.56689 .32076 Mdot
.48924 .30299 Mdot
.52185 .3942 Mdot
.4362 .64556 Mdot
.32279 .47658 Mdot
.40151 .66261 Mdot
.55107 .37995 Mdot
.20104 .56015 Mdot
.41984 .60931 Mdot
.35909 .70106 Mdot
.69533 .49372 Mdot
.59585 .44939 Mdot
.45868 .37988 Mdot
.43249 .63755 Mdot
.50084 .33662 Mdot
.34639 .47275 Mdot
.51971 .56522 Mdot
.53051 .78026 Mdot
.42859 .63508 Mdot
.77775 .34286 Mdot
.50558 .57341 Mdot
.41785 .38018 Mdot
.43471 .63425 Mdot
.22596 .4384 Mdot
.58578 .71757 Mdot
.70772 .49179 Mdot
.73118 .50956 Mdot
.72758 .50495 Mdot
.44223 .37295 Mdot
.5313 .4435 Mdot
.69003 .53006 Mdot
.4173 .59766 Mdot
.69726 .47699 Mdot
.56052 .47093 Mdot
.77188 .33462 Mdot
.70579 .52259 Mdot
.47045 .3723 Mdot
.55519 .39241 Mdot
.65418 .39896 Mdot
.60734 .5773 Mdot
.60955 .20394 Mdot
.40785 .33339 Mdot
.50633 .40168 Mdot
.41902 .42821 Mdot
.28799 .49701 Mdot
.50028 .8023 Mdot
.44203 .46514 Mdot
.64867 .70398 Mdot
.34547 .4762 Mdot
.66422 .58862 Mdot
.30452 .48426 Mdot
.49475 .42261 Mdot
.51566 .37245 Mdot
.36015 .46756 Mdot
.46296 .69632 Mdot
.44954 .75846 Mdot
.82617 .46794 Mdot
.33144 .52718 Mdot
.42898 .62615 Mdot
.39319 .6448 Mdot
.44698 .63247 Mdot
.64552 .57544 Mdot
.32247 .53743 Mdot
.482 .3363 Mdot
.64175 .61399 Mdot
.45199 .38984 Mdot
.42865 .64829 Mdot
.85078 .47573 Mdot
.32484 .51999 Mdot
.48853 .4039 Mdot
.55626 .82937 Mdot
.61264 .62068 Mdot
.7119 .4882 Mdot
.63737 .46381 Mdot
.6563 .58963 Mdot
.4241 .66402 Mdot
.33769 .46215 Mdot
.42922 .68965 Mdot
.47335 .50468 Mdot
.42589 .42638 Mdot
.50634 .43314 Mdot
.82933 .55929 Mdot
.56352 .77353 Mdot
.43665 .39505 Mdot
.64161 .60225 Mdot
.60505 .57442 Mdot
.48634 .35919 Mdot
.31705 .53247 Mdot
.71705 .52665 Mdot
.71078 .47498 Mdot
.52474 .32458 Mdot
.52887 .52827 Mdot
.59616 .4578 Mdot
.49825 .35223 Mdot
.56914 .39264 Mdot
.62324 .64074 Mdot
.58592 .74444 Mdot
.33943 .72644 Mdot
.70086 .5265 Mdot
.51836 .36596 Mdot
.3498 .65651 Mdot
.35713 .49865 Mdot
.60494 .59157 Mdot
.4301 .65973 Mdot
.74288 .42294 Mdot
.65442 .60694 Mdot
.48831 .35913 Mdot
.49157 .355 Mdot
.42039 .60474 Mdot
.30136 .5416 Mdot
.70523 .50124 Mdot
.6397 .61669 Mdot
.69866 .52756 Mdot
.35002 .49415 Mdot
.32583 .51649 Mdot
.42464 .42949 Mdot
.56599 .37646 Mdot
.61048 .63335 Mdot
.54013 .34849 Mdot
.58871 .59431 Mdot
.74747 .44931 Mdot
.38735 .64928 Mdot
.47566 .42411 Mdot
.31401 .46062 Mdot
.42931 .65065 Mdot
.49183 .39144 Mdot
.82999 .61256 Mdot
.44686 .3928 Mdot
.64638 .5658 Mdot
.19885 .57629 Mdot
.70556 .47811 Mdot
.38509 .43725 Mdot
.46896 .28136 Mdot
.5089 .38515 Mdot
.58474 .6166 Mdot
.49705 .3053 Mdot
.41826 .60742 Mdot
.34021 .47627 Mdot
.46721 .87406 Mdot
.41228 .64323 Mdot
.5194 .38095 Mdot
.70493 .51328 Mdot
.32752 .46268 Mdot
.60094 .73102 Mdot
.35239 .74886 Mdot
.43745 .34658 Mdot
.46713 .43685 Mdot
.52644 .36824 Mdot
.29367 .26213 Mdot
.62484 .59022 Mdot
.31405 .48588 Mdot
.40877 .61209 Mdot
.41057 .65363 Mdot
.6251 .62971 Mdot
.3094 .65264 Mdot
.55328 .56483 Mdot
.67549 .15954 Mdot
.59711 .62242 Mdot
.68147 .48764 Mdot
.55291 .50786 Mdot
.58997 .59953 Mdot
.62926 .60041 Mdot
.6294 .63787 Mdot
.34184 .70866 Mdot
.30704 .51326 Mdot
.49671 .36609 Mdot
.35948 .53395 Mdot
.46417 .41526 Mdot
.59319 .36412 Mdot
.4243 .65665 Mdot
.34364 .47808 Mdot
.83391 .58084 Mdot
.40527 .45984 Mdot
.47197 .38989 Mdot
.78101 .43428 Mdot
.47268 .3046 Mdot
.70767 .39731 Mdot
.43423 .3315 Mdot
.60717 .61338 Mdot
.46958 .46192 Mdot
.54887 .40892 Mdot
.26864 .69726 Mdot
.40394 .63077 Mdot
.58689 .71077 Mdot
.44005 .36072 Mdot
.45858 .32537 Mdot
.35092 .47237 Mdot
.3258 .52789 Mdot
.68913 .5289 Mdot
.59874 .50097 Mdot
.4006 .63907 Mdot
.63757 .51572 Mdot
.50498 .39693 Mdot
.47825 .67791 Mdot
.27211 .4558 Mdot
.49098 .39285 Mdot
.68819 .27056 Mdot
.27793 .43314 Mdot
.45553 .36202 Mdot
.22882 .40667 Mdot
.41559 .63119 Mdot
.20502 .58441 Mdot
.53725 .3543 Mdot
.62228 .61652 Mdot
.34312 .48079 Mdot
.28749 .50014 Mdot
.71445 .52 Mdot
.363 .78892 Mdot
.42998 .66456 Mdot
.34792 .48305 Mdot
.4664 .39864 Mdot
.43401 .65724 Mdot
.59866 .70756 Mdot
.54578 .41064 Mdot
.63767 .27224 Mdot
.3211 .50534 Mdot
.5265 .34005 Mdot
.25247 .56712 Mdot
.6085 .47315 Mdot
.54386 .16294 Mdot
.44548 .62658 Mdot
.69774 .52362 Mdot
.41645 .36478 Mdot
.79577 .64501 Mdot
.47879 .32421 Mdot
.62 .44181 Mdot
.29406 .55523 Mdot
.68572 .52054 Mdot
.47633 .39885 Mdot
.4686 .35379 Mdot
.52038 .52287 Mdot
.72646 .47867 Mdot
.45283 .40759 Mdot
.44464 .45013 Mdot
.30195 .50794 Mdot
.58544 .7089 Mdot
.31983 .51024 Mdot
.4682 .37555 Mdot
.52169 .44782 Mdot
.31217 .52475 Mdot
.7981 .52032 Mdot
.6978 .47012 Mdot
.43734 .61283 Mdot
.56464 .41567 Mdot
.51897 .3418 Mdot
.31541 .22362 Mdot
.5802 .72 Mdot
.21787 .36751 Mdot
.65136 .63305 Mdot
.35868 .66214 Mdot
.65663 .6449 Mdot
.69213 .24498 Mdot
.28658 .70152 Mdot
.44473 .34366 Mdot
.61486 .29219 Mdot
.2444 .37074 Mdot
.41475 .66622 Mdot
.37016 .25843 Mdot
.50703 .39865 Mdot
.47847 .41489 Mdot
.63422 .57878 Mdot
.29779 .65444 Mdot
.4426 .78482 Mdot
.53516 .53571 Mdot
.7012 .50107 Mdot
.35184 .50276 Mdot
.49811 .37801 Mdot
.55154 .58569 Mdot
.59618 .59947 Mdot
.49235 .63069 Mdot
.48313 .40404 Mdot
.44337 .80563 Mdot
.35474 .70848 Mdot
.43967 .65407 Mdot
.59759 .63827 Mdot
.65664 .5989 Mdot
.49029 .41949 Mdot
.4208 .66274 Mdot
.45819 .36239 Mdot
.51103 .59262 Mdot
.53039 .33761 Mdot
.71069 .51752 Mdot
.52781 .40095 Mdot
.48221 .52673 Mdot
.6001 .1712 Mdot
.41575 .44747 Mdot
.30694 .52965 Mdot
.64836 .57841 Mdot
.62007 .63236 Mdot
.32606 .52538 Mdot
.61964 .63076 Mdot
.26307 .40197 Mdot
.38066 .35579 Mdot
.69754 .50067 Mdot
.56225 .42736 Mdot
.715 .51471 Mdot
.58418 .71309 Mdot
.50892 .40415 Mdot
.7933 .66059 Mdot
.59966 .62467 Mdot
.18861 .46637 Mdot
.40753 .64211 Mdot
.58352 .71472 Mdot
.48495 .32462 Mdot
.77004 .53473 Mdot
.60744 .57997 Mdot
.65467 .57053 Mdot
.46703 .35988 Mdot
.31749 .52224 Mdot
.47276 .35278 Mdot
.45995 .31265 Mdot
.58084 .73614 Mdot
.5252 .35819 Mdot
.41533 .61472 Mdot
.33977 .53823 Mdot
.73205 .29236 Mdot
.62049 .56692 Mdot
.50873 .41062 Mdot
.46764 .39914 Mdot
.33073 .46634 Mdot
.50301 .32786 Mdot
.40392 .65621 Mdot
.45168 .09323 Mdot
.69602 .49267 Mdot
.59361 .74716 Mdot
.64395 .56219 Mdot
.44739 .35505 Mdot
.49194 .35161 Mdot
.83485 .5448 Mdot
.50384 .75095 Mdot
.42339 .6168 Mdot
.49137 .30785 Mdot
.63942 .60972 Mdot
.7034 .51437 Mdot
.43183 .59825 Mdot
.51528 .35716 Mdot
.48322 .4112 Mdot
.70793 .51825 Mdot
.71941 .30094 Mdot
.64776 .70871 Mdot
.44807 .63468 Mdot
.47166 .46321 Mdot
.76087 .59356 Mdot
.4541 .38557 Mdot
.78679 .5845 Mdot
.33296 .5223 Mdot
.43842 .63443 Mdot
.27671 .29479 Mdot
.5226 .41173 Mdot
.39903 .64993 Mdot
.40134 .63661 Mdot
.54109 .38518 Mdot
.36625 .52632 Mdot
.35273 .52712 Mdot
.34413 .52071 Mdot
.19494 .61829 Mdot
.61219 .35833 Mdot
.60328 .59639 Mdot
.41656 .63036 Mdot
.5805 .60373 Mdot
.73325 .5098 Mdot
.59346 .49078 Mdot
.59095 .58616 Mdot
.28874 .49641 Mdot
.58866 .63221 Mdot
.47044 .35564 Mdot
.40002 .64293 Mdot
.62633 .58374 Mdot
.43835 .37124 Mdot
.51606 .27723 Mdot
.48243 .56547 Mdot
.70829 .53044 Mdot
.73713 .46066 Mdot
.50838 .37288 Mdot
.57999 .72828 Mdot
.49607 .40371 Mdot
.44927 .64289 Mdot
.49212 .51434 Mdot
.44405 .36192 Mdot
.60618 .62819 Mdot
.40115 .37898 Mdot
.62846 .57127 Mdot
.47246 .31198 Mdot
.47112 .37445 Mdot
.45494 .39668 Mdot
.45862 .35888 Mdot
.34719 .68626 Mdot
.41476 .66814 Mdot
.51427 .27347 Mdot
.58829 .64757 Mdot
.32727 .49868 Mdot
.28256 .49072 Mdot
.75139 .62678 Mdot
.59113 .74974 Mdot
.41104 .62421 Mdot
.45534 .38044 Mdot
.65166 .56556 Mdot
.85005 .46854 Mdot
.80605 .53953 Mdot
.771 .48267 Mdot
.63831 .59385 Mdot
.30083 .52461 Mdot
.60121 .58859 Mdot
.48009 .41946 Mdot
.53462 .40993 Mdot
.70671 .26213 Mdot
.43851 .58654 Mdot
.70671 .50016 Mdot
.45544 .40099 Mdot
.60258 .41841 Mdot
.64014 .60944 Mdot
.62507 .64141 Mdot
.44838 .39367 Mdot
.33967 .53254 Mdot
.46189 .14886 Mdot
.4377 .65648 Mdot
.49968 .25582 Mdot
.39148 .49655 Mdot
.21884 .58473 Mdot
.4144 .65764 Mdot
.47325 .57217 Mdot
.64549 .62169 Mdot
.38877 .41133 Mdot
.32933 .50209 Mdot
.70964 .50157 Mdot
.53347 .41522 Mdot
.29003 .49566 Mdot
.63485 .64448 Mdot
.30797 .47882 Mdot
.50189 .4222 Mdot
.41138 .66656 Mdot
.63327 .62978 Mdot
.38413 .62011 Mdot
.35759 .46546 Mdot
.72204 .49819 Mdot
.59125 .45075 Mdot
.40617 .24598 Mdot
.27406 .4344 Mdot
.45605 .3514 Mdot
.58306 .66253 Mdot
.49549 .33613 Mdot
.35962 .48626 Mdot
.46036 .37766 Mdot
.32051 .56719 Mdot
.60426 .6398 Mdot
.52761 .34136 Mdot
.53226 .38354 Mdot
.36807 .27991 Mdot
.47975 .39133 Mdot
.53219 .36278 Mdot
.45543 .35954 Mdot
.38714 .51351 Mdot
.42386 .38503 Mdot
.31107 .51748 Mdot
.36734 .7465 Mdot
.62715 .59982 Mdot
.70567 .53209 Mdot
.72255 .48262 Mdot
.61662 .4465 Mdot
.60278 .44528 Mdot
.31119 .65938 Mdot
.31286 .50864 Mdot
.40781 .61868 Mdot
.45733 .36342 Mdot
.31504 .2659 Mdot
.72014 .53991 Mdot
.64196 .6256 Mdot
.63323 .56477 Mdot
.56584 .3627 Mdot
.29768 .25721 Mdot
.50995 .32677 Mdot
.35846 .76097 Mdot
.52962 .3302 Mdot
.44843 .40288 Mdot
.65506 .59162 Mdot
.60389 .46353 Mdot
.4551 .35208 Mdot
.34937 .47121 Mdot
.71291 .49859 Mdot
.42706 .46826 Mdot
.67427 .64593 Mdot
.49521 .60017 Mdot
.39604 .28499 Mdot
.49081 .33329 Mdot
.63613 .62262 Mdot
.29326 .49479 Mdot
.32989 .72417 Mdot
.44327 .64152 Mdot
.31498 .68824 Mdot
.32601 .30632 Mdot
.7994 .47602 Mdot
.70996 .49866 Mdot
.71163 .29672 Mdot
.489 .37587 Mdot
.64859 .57699 Mdot
.49338 .4276 Mdot
.84892 .46405 Mdot
.67706 .49938 Mdot
.30527 .53928 Mdot
.42745 .6243 Mdot
.34964 .47574 Mdot
.3283 .41818 Mdot
.4528 .57338 Mdot
.54673 .63182 Mdot
.58822 .58422 Mdot
.55134 .28805 Mdot
.33339 .48513 Mdot
.50356 .35776 Mdot
.72801 .20079 Mdot
.33469 .52181 Mdot
.34339 .52549 Mdot
.73673 .45066 Mdot
.76813 .46599 Mdot
.52901 .32007 Mdot
.30951 .476 Mdot
.58436 .63547 Mdot
.70366 .48168 Mdot
.47249 .34722 Mdot
.46232 .35529 Mdot
.31716 .52471 Mdot
.59976 .58401 Mdot
.50876 .25247 Mdot
.60679 .61929 Mdot
.29959 .50559 Mdot
.61404 .61157 Mdot
.58829 .57261 Mdot
.63161 .58956 Mdot
.51725 .33846 Mdot
.45898 .37459 Mdot
.6912 .62693 Mdot
.32579 .5163 Mdot
.49234 .34813 Mdot
.51429 .36765 Mdot
.33552 .48871 Mdot
.63839 .65356 Mdot
.3381 .25159 Mdot
.51607 .39356 Mdot
.47947 .36653 Mdot
.69036 .52302 Mdot
.6573 .63374 Mdot
.65278 .73279 Mdot
.482 .34665 Mdot
.69804 .47442 Mdot
.35947 .52508 Mdot
.49489 .40174 Mdot
.56124 .47287 Mdot
.58868 .57788 Mdot
.52828 .4029 Mdot
.6023 .72791 Mdot
.45432 .34802 Mdot
.48087 .15512 Mdot
.5151 .4067 Mdot
.31673 .48761 Mdot
.33512 .479 Mdot
.71194 .44631 Mdot
.34288 .50582 Mdot
.59293 .70864 Mdot
.42627 .64897 Mdot
.82834 .42837 Mdot
.59863 .70933 Mdot
.44484 .39691 Mdot
.54328 .8406 Mdot
.54557 .36258 Mdot
.44127 .35972 Mdot
.25294 .30883 Mdot
.59868 .71093 Mdot
.32462 .47931 Mdot
.44151 .70297 Mdot
.5312 .33038 Mdot
.43058 .66008 Mdot
.52898 .42631 Mdot
.5357 .39311 Mdot
.24166 .63567 Mdot
.21758 .50116 Mdot
.45204 .63181 Mdot
.41001 .39371 Mdot
.48281 .3464 Mdot
.55142 .74564 Mdot
.46387 .38877 Mdot
.70912 .52211 Mdot
.34553 .52197 Mdot
.59165 .60773 Mdot
.69323 .49064 Mdot
.50722 .39138 Mdot
.70773 .50587 Mdot
.60625 .59183 Mdot
.43764 .64203 Mdot
.50177 .41282 Mdot
.67886 .48703 Mdot
.70239 .50177 Mdot
.49778 .33915 Mdot
.34402 .47952 Mdot
.4083 .45451 Mdot
.49399 .39965 Mdot
.49861 .35878 Mdot
.32221 .52312 Mdot
.69561 .78477 Mdot
.48605 .42257 Mdot
.46728 .54877 Mdot
.30638 .5385 Mdot
.59019 .69796 Mdot
.6162 .58217 Mdot
.53554 .3985 Mdot
.43165 .65588 Mdot
.42797 .6542 Mdot
.60446 .64689 Mdot
.34458 .471 Mdot
.60945 .5769 Mdot
.40809 .42037 Mdot
.5661 .38085 Mdot
.54717 .38751 Mdot
.44056 .86032 Mdot
.6919 .25449 Mdot
.31322 .53131 Mdot
.64933 .60226 Mdot
.54028 .53548 Mdot
.41825 .62642 Mdot
.59084 .63801 Mdot
.33559 .46282 Mdot
.29455 .51664 Mdot
.2997 .48195 Mdot
.68758 .51838 Mdot
.65169 .61455 Mdot
.30199 .54068 Mdot
.34422 .52895 Mdot
.4689 .358 Mdot
.4853 .34629 Mdot
.25771 .52051 Mdot
.67052 .38836 Mdot
.72146 .50505 Mdot
.62806 .62513 Mdot
.26261 .24302 Mdot
.44985 .64127 Mdot
.37126 .27976 Mdot
.44353 .3607 Mdot
.8982 .41381 Mdot
.51243 .32668 Mdot
.4646 .39587 Mdot
.35238 .53351 Mdot
.67256 .50855 Mdot
.71807 .5029 Mdot
.33462 .48459 Mdot
.34093 .46144 Mdot
.70513 .52406 Mdot
.75334 .36062 Mdot
.77945 .34001 Mdot
.32082 .7076 Mdot
.32393 .48871 Mdot
.42403 .24502 Mdot
.42253 .66378 Mdot
.37007 .47526 Mdot
.44677 .61652 Mdot
.62951 .60216 Mdot
.64383 .63008 Mdot
.42286 .6046 Mdot
.46497 .36197 Mdot
.61286 .58718 Mdot
.42089 .39366 Mdot
.76264 .35209 Mdot
.53746 .21981 Mdot
.4872 .73769 Mdot
.43355 .3841 Mdot
.42837 .78054 Mdot
.46679 .78178 Mdot
.50953 .37905 Mdot
.47637 .4892 Mdot
.70755 .50184 Mdot
.38109 .49233 Mdot
.40666 .65835 Mdot
.53099 .16145 Mdot
.45447 .38342 Mdot
.31248 .49259 Mdot
.40542 .62824 Mdot
.67663 .45444 Mdot
.26809 .65768 Mdot
.45863 .41023 Mdot
.6213 .13676 Mdot
.37941 .50739 Mdot
.59176 .60875 Mdot
.46383 .83976 Mdot
.35332 .53948 Mdot
.74259 .4648 Mdot
.64302 .63613 Mdot
.81971 .51154 Mdot
.30716 .48582 Mdot
.62511 .64883 Mdot
.3497 .49837 Mdot
.71502 .5173 Mdot
.36916 .49989 Mdot
.63675 .62719 Mdot
.47838 .39591 Mdot
.62026 .62738 Mdot
.72253 .5035 Mdot
.64407 .57308 Mdot
.41409 .66201 Mdot
.58254 .71844 Mdot
.42168 .63886 Mdot
.60724 .47973 Mdot
.20513 .53127 Mdot
.43958 .62193 Mdot
.65069 .48143 Mdot
.43608 .39263 Mdot
.29835 .54153 Mdot
.59504 .62299 Mdot
.58791 .64596 Mdot
.57466 .50275 Mdot
.33068 .49582 Mdot
.62938 .62874 Mdot
.31969 .30586 Mdot
.61931 .82109 Mdot
.53486 .44136 Mdot
.61625 .33676 Mdot
.3331 .48915 Mdot
.61798 .64409 Mdot
.34168 .74047 Mdot
.28988 .48742 Mdot
.59691 .62069 Mdot
.43265 .63328 Mdot
.41151 .65503 Mdot
.45041 .38629 Mdot
.42859 .58359 Mdot
.58975 .62428 Mdot
.41343 .74402 Mdot
.35769 .50101 Mdot
.67289 .45491 Mdot
.72022 .5171 Mdot
.63218 .59898 Mdot
.54516 .41616 Mdot
.27942 .47006 Mdot
.58049 .5903 Mdot
.60436 .26317 Mdot
.24469 .2674 Mdot
.6259 .62813 Mdot
.34806 .51935 Mdot
.31189 .49696 Mdot
.48014 .3039 Mdot
.53087 .52596 Mdot
.61892 .57486 Mdot
.7754 .68722 Mdot
.62417 .43414 Mdot
.58962 .73059 Mdot
.57215 .7817 Mdot
.45239 .35374 Mdot
.50641 .33867 Mdot
.41926 .6244 Mdot
.47647 .3836 Mdot
.34587 .53074 Mdot
.46904 .33416 Mdot
.39591 .64432 Mdot
.6443 .62193 Mdot
.50339 .4099 Mdot
.70929 .48074 Mdot
.45359 .64064 Mdot
.42627 .60344 Mdot
.61766 .59968 Mdot
.30614 .47775 Mdot
.57884 .55752 Mdot
.6081 .62506 Mdot
.48544 .33362 Mdot
.59948 .72245 Mdot
.51537 .41455 Mdot
.69499 .30141 Mdot
.30584 .47106 Mdot
.595 .59351 Mdot
.28686 .51609 Mdot
.4175 .63951 Mdot
.5983 .65221 Mdot
.4675 .38225 Mdot
.59847 .61837 Mdot
.66274 .67523 Mdot
.72893 .32644 Mdot
.3459 .47106 Mdot
.66175 .64506 Mdot
.34787 .52239 Mdot
.58929 .73254 Mdot
.69457 .32471 Mdot
.70407 .49309 Mdot
.63721 .60861 Mdot
.67208 .23979 Mdot
.60521 .63009 Mdot
.48189 .39028 Mdot
.49528 .38648 Mdot
.63433 .58001 Mdot
.68704 .4882 Mdot
.17995 .58305 Mdot
.45626 .55549 Mdot
.318 .47941 Mdot
.39281 .38224 Mdot
.31316 .20165 Mdot
.41976 .59301 Mdot
.41958 .62064 Mdot
.49106 .31686 Mdot
.44654 .38309 Mdot
.42465 .60119 Mdot
.39 .63337 Mdot
.70192 .52935 Mdot
.63332 .63565 Mdot
.3542 .54706 Mdot
.43383 .59462 Mdot
.47474 .2941 Mdot
.60092 .42923 Mdot
.52231 .31883 Mdot
.46309 .44572 Mdot
.43841 .4178 Mdot
.62505 .46439 Mdot
.39617 .62288 Mdot
.50699 .37106 Mdot
.42763 .36916 Mdot
.43511 .62941 Mdot
.71476 .51678 Mdot
.22946 .52485 Mdot
.61828 .61372 Mdot
.81703 .67541 Mdot
.51934 .40782 Mdot
.48452 .39588 Mdot
.447 .63971 Mdot
.564 .75547 Mdot
.29552 .51195 Mdot
.31147 .47104 Mdot
.62329 .58911 Mdot
.57939 .50225 Mdot
.49261 .32711 Mdot
.50937 .37634 Mdot
.63202 .61349 Mdot
.58133 .72109 Mdot
.46351 .73415 Mdot
.49238 .36718 Mdot
.40593 .63148 Mdot
.57282 .58513 Mdot
.39403 .62585 Mdot
.48358 .42551 Mdot
.48359 .38862 Mdot
.51539 .33657 Mdot
.44601 .38366 Mdot
.43782 .60465 Mdot
.50233 .37288 Mdot
.55597 .40008 Mdot
.32481 .47233 Mdot
.51183 .33768 Mdot
.62561 .44757 Mdot
.47258 .36864 Mdot
.71737 .4877 Mdot
.55769 .62074 Mdot
.45431 .39719 Mdot
.5173 .34229 Mdot
.46027 .55547 Mdot
.47524 .40216 Mdot
.44966 .63943 Mdot
.32232 .49851 Mdot
.41717 .63034 Mdot
.4097 .61058 Mdot
.57966 .62143 Mdot
.69935 .52895 Mdot
.45186 .33975 Mdot
.72766 .49912 Mdot
.47829 .44354 Mdot
.50231 .42286 Mdot
.59133 .55595 Mdot
.36006 .76171 Mdot
.65588 .69675 Mdot
.46639 .38017 Mdot
.62643 .59372 Mdot
.59234 .60324 Mdot
.61045 .28113 Mdot
.42009 .37719 Mdot
.43012 .59961 Mdot
.4322 .63726 Mdot
.69352 .35956 Mdot
.24745 .64491 Mdot
.72145 .49717 Mdot
.56842 .53455 Mdot
.43557 .40933 Mdot
.50169 .364 Mdot
.54796 .40577 Mdot
.58828 .58819 Mdot
.58293 .74243 Mdot
.64186 .62678 Mdot
.57446 .71647 Mdot
.39281 .63378 Mdot
.46511 .33962 Mdot
.54547 .21036 Mdot
.31916 .52928 Mdot
.32251 .49918 Mdot
.41927 .59885 Mdot
.61568 .57265 Mdot
.46632 .30336 Mdot
.47795 .88079 Mdot
.37831 .47407 Mdot
.68792 .53327 Mdot
.51342 .37949 Mdot
.61986 .59642 Mdot
.32708 .53219 Mdot
.70971 .4726 Mdot
.52837 .37919 Mdot
.60713 .66627 Mdot
.46278 .37384 Mdot
.24094 .37389 Mdot
.32702 .47396 Mdot
.85336 .45914 Mdot
.31816 .46389 Mdot
.45495 .63793 Mdot
.43275 .6191 Mdot
.49033 .39044 Mdot
.44967 .85485 Mdot
.32198 .5452 Mdot
.40977 .58714 Mdot
.67471 .50589 Mdot
.5912 .74706 Mdot
.67871 .51243 Mdot
.58844 .6024 Mdot
.7115 .49747 Mdot
.62587 .6377 Mdot
.68455 .36287 Mdot
.38507 .47651 Mdot
.69494 .49142 Mdot
.54843 .71064 Mdot
.42763 .39931 Mdot
.72911 .51447 Mdot
.56259 .38653 Mdot
.39158 .42451 Mdot
.62907 .61303 Mdot
.68857 .48632 Mdot
.5004 .3567 Mdot
.52814 .17706 Mdot
.42293 .61143 Mdot
.43396 .60037 Mdot
.42688 .4104 Mdot
.63145 .63818 Mdot
.35489 .46853 Mdot
.48159 .50626 Mdot
.58516 .70456 Mdot
.50722 .3744 Mdot
.46085 .34256 Mdot
.28316 .48743 Mdot
.29326 .46937 Mdot
.48631 .38747 Mdot
.33206 .28243 Mdot
.49344 .37541 Mdot
.42456 .65867 Mdot
.29409 .51385 Mdot
.31546 .49778 Mdot
.59271 .63119 Mdot
.35889 .49161 Mdot
.4664 .44708 Mdot
.37711 .57553 Mdot
.53939 .3391 Mdot
.41472 .64427 Mdot
.47951 .52 Mdot
.63037 .56525 Mdot
.58004 .19379 Mdot
.28784 .48016 Mdot
.52462 .35526 Mdot
.35642 .50868 Mdot
.69249 .51579 Mdot
.32526 .51365 Mdot
.31695 .53754 Mdot
.50093 .39456 Mdot
.46547 .41542 Mdot
.59705 .71189 Mdot
.53828 .52503 Mdot
.3538 .48836 Mdot
.50201 .37702 Mdot
.54094 .35501 Mdot
.53695 .38138 Mdot
.49724 .55113 Mdot
.31311 .53282 Mdot
.34278 .33409 Mdot
.61795 .25718 Mdot
.34946 .48314 Mdot
.45729 .16249 Mdot
.5986 .73726 Mdot
.59129 .74889 Mdot
.42398 .58869 Mdot
.49267 .36611 Mdot
.64289 .58431 Mdot
.48318 .4194 Mdot
.42353 .43158 Mdot
.48362 .41304 Mdot
.6886 .48198 Mdot
.44173 .34951 Mdot
.58746 .72506 Mdot
.61082 .62827 Mdot
.52373 .3875 Mdot
.50019 .41136 Mdot
.59372 .75134 Mdot
.29719 .47251 Mdot
.29187 .50388 Mdot
.79462 .56653 Mdot
.69413 .50835 Mdot
.43842 .64485 Mdot
.4563 .37199 Mdot
.62615 .59203 Mdot
.6181 .62762 Mdot
.35585 .48445 Mdot
.62104 .61878 Mdot
.4428 .65291 Mdot
.46754 .38627 Mdot
.43237 .60083 Mdot
.69857 .4776 Mdot
.34147 .52488 Mdot
.45375 .37666 Mdot
.46963 .35798 Mdot
.33472 .47889 Mdot
.43601 .39386 Mdot
.69091 .52333 Mdot
.61083 .63239 Mdot
.29914 .49284 Mdot
.42616 .65065 Mdot
.58973 .62947 Mdot
.48224 .35502 Mdot
.23417 .28444 Mdot
.48025 .38109 Mdot
.48864 .3605 Mdot
.75322 .30452 Mdot
.48539 .31459 Mdot
.59731 .63235 Mdot
.2799 .49761 Mdot
.44909 .43006 Mdot
.6087 .40027 Mdot
.80879 .60047 Mdot
.5898 .63944 Mdot
.51838 .38472 Mdot
.59744 .19558 Mdot
.5213 .38685 Mdot
.63506 .51691 Mdot
.70338 .68114 Mdot
.558 .28395 Mdot
.47029 .44553 Mdot
.43764 .60887 Mdot
.59539 .71054 Mdot
.61018 .64013 Mdot
.23661 .43674 Mdot
.50241 .38748 Mdot
.22183 .43697 Mdot
.5323 .39017 Mdot
.41098 .65573 Mdot
.40239 .4311 Mdot
.626 .6246 Mdot
.3232 .7536 Mdot
.48429 .33546 Mdot
.30908 .52948 Mdot
.58318 .62016 Mdot
.59328 .74457 Mdot
.4913 .35718 Mdot
.72445 .48771 Mdot
.38655 .6075 Mdot
.56627 .38976 Mdot
.41594 .64777 Mdot
.51556 .36663 Mdot
.41118 .40552 Mdot
.40829 .82409 Mdot
.32204 .47409 Mdot
.42453 .62331 Mdot
.50633 .79486 Mdot
.438 .40148 Mdot
.30459 .48726 Mdot
.32949 .50106 Mdot
.7217 .51199 Mdot
.53442 .57887 Mdot
.2681 .57782 Mdot
.49019 .20984 Mdot
.31551 .43482 Mdot
.60443 .6431 Mdot
.46622 .76761 Mdot
.47603 .3456 Mdot
.46473 .58558 Mdot
.4505 .62779 Mdot
.48226 .39662 Mdot
.27629 .45069 Mdot
.34094 .52285 Mdot
.48352 .3694 Mdot
.7145 .5158 Mdot
.49546 .66256 Mdot
.49135 .61544 Mdot
.35875 .20644 Mdot
.587 .63848 Mdot
.54009 .41028 Mdot
.49524 .44512 Mdot
.59915 .70158 Mdot
.50458 .42541 Mdot
.60148 .63377 Mdot
.7721 .38889 Mdot
.6838 .49048 Mdot
.33219 .53094 Mdot
.5979 .73841 Mdot
.4355 .41711 Mdot
.54009 .36226 Mdot
.70405 .53229 Mdot
.51476 .35156 Mdot
.36923 .79101 Mdot
.59846 .76349 Mdot
.62033 .58467 Mdot
.30254 .48211 Mdot
.43994 .41528 Mdot
.58214 .74031 Mdot
.49893 .39141 Mdot
.42323 .28043 Mdot
.52032 .35014 Mdot
.24869 .57628 Mdot
.34436 .48174 Mdot
.41873 .64627 Mdot
.44989 .43883 Mdot
.47433 .41164 Mdot
.76469 .58333 Mdot
.42321 .43008 Mdot
.51569 .40722 Mdot
.34316 .46756 Mdot
.3162 .53079 Mdot
.3122 .51702 Mdot
.60096 .59306 Mdot
.3307 .71476 Mdot
.40935 .63399 Mdot
.47314 .32872 Mdot
.43447 .59509 Mdot
.4471 .27964 Mdot
.69666 .53338 Mdot
.47026 .18157 Mdot
.52792 .36324 Mdot
.31036 .51169 Mdot
.34124 .63541 Mdot
.35812 .52577 Mdot
.59501 .65746 Mdot
.40043 .64 Mdot
.33854 .5217 Mdot
.46732 .40421 Mdot
.52308 .53362 Mdot
.38247 .20871 Mdot
.42224 .63103 Mdot
.55385 .39192 Mdot
.59259 .64763 Mdot
.6145 .56545 Mdot
.33316 .1746 Mdot
.42391 .6156 Mdot
.47336 .7809 Mdot
.50583 .38079 Mdot
.31727 .52765 Mdot
.44356 .62126 Mdot
.42968 .60953 Mdot
.62748 .61607 Mdot
.45993 .41039 Mdot
.45635 .39785 Mdot
.60146 .73102 Mdot
.43257 .64096 Mdot
.43067 .41788 Mdot
.54953 .36699 Mdot
.70991 .26456 Mdot
.24278 .49303 Mdot
.73091 .76152 Mdot
.40824 .42177 Mdot
.29425 .43812 Mdot
.55218 .50177 Mdot
.3269 .53794 Mdot
.45428 .40128 Mdot
.45254 .42481 Mdot
.59383 .63124 Mdot
.47334 .38285 Mdot
.63986 .57608 Mdot
.4144 .6192 Mdot
.44102 .17312 Mdot
.33622 .58117 Mdot
.76259 .38405 Mdot
.47461 .38845 Mdot
.22917 .61117 Mdot
.687 .50048 Mdot
.42064 .68266 Mdot
.29744 .50594 Mdot
.44994 .41607 Mdot
.65101 .57356 Mdot
.63807 .60847 Mdot
.33567 .50863 Mdot
.41068 .75764 Mdot
.78127 .58554 Mdot
.47962 .42586 Mdot
.61512 .58133 Mdot
.36487 .67352 Mdot
.31732 .2916 Mdot
.45866 .61143 Mdot
.68077 .49347 Mdot
.64248 .62408 Mdot
.40581 .60692 Mdot
.26061 .48391 Mdot
.34207 .51425 Mdot
.2806 .50739 Mdot
.71835 .63681 Mdot
.62537 .57295 Mdot
.69501 .48692 Mdot
.2873 .69163 Mdot
.27368 .68545 Mdot
.68428 .48665 Mdot
.64601 .61897 Mdot
.32175 .53247 Mdot
.30407 .496 Mdot
.32171 .49768 Mdot
.31334 .74469 Mdot
.31911 .46857 Mdot
.37735 .31207 Mdot
.54523 .36479 Mdot
.57925 .37871 Mdot
.51971 .38736 Mdot
.44547 .61126 Mdot
.32793 .47461 Mdot
.5626 .50386 Mdot
.44166 .38797 Mdot
.37566 .2033 Mdot
.51048 .37451 Mdot
.46158 .6226 Mdot
.48699 .3662 Mdot
.38833 .25887 Mdot
.31003 .53976 Mdot
.46913 .37911 Mdot
.41361 .671 Mdot
.70179 .50544 Mdot
.32684 .55602 Mdot
.45497 .39821 Mdot
.28188 .64338 Mdot
.47826 .31972 Mdot
.77017 .37744 Mdot
.6922 .4323 Mdot
.68526 .5332 Mdot
.4371 .44764 Mdot
.61441 .64731 Mdot
.31847 .5598 Mdot
.53399 .44786 Mdot
.42307 .63267 Mdot
.19512 .45246 Mdot
.63756 .60367 Mdot
.40327 .44773 Mdot
.48684 .30715 Mdot
.70168 .52778 Mdot
.26691 .49999 Mdot
.44926 .63566 Mdot
.43743 .37101 Mdot
.54061 .3831 Mdot
.749 .36932 Mdot
.54855 .43843 Mdot
.50055 .3262 Mdot
.71933 .52591 Mdot
.34867 .33744 Mdot
.47186 .36449 Mdot
.6308 .65694 Mdot
.28228 .51123 Mdot
.42507 .40692 Mdot
.34232 .32968 Mdot
.50175 .37833 Mdot
.33294 .51846 Mdot
.27714 .49923 Mdot
.31498 .62699 Mdot
.67499 .51742 Mdot
.5204 .35045 Mdot
.74633 .43266 Mdot
.49589 .33499 Mdot
.40558 .63568 Mdot
.48866 .42283 Mdot
.63253 .60606 Mdot
.35177 .75642 Mdot
.59837 .60496 Mdot
.4825 .42127 Mdot
.32032 .49417 Mdot
.44334 .61562 Mdot
.69459 .63974 Mdot
.72763 .6596 Mdot
.37321 .31622 Mdot
.83408 .59035 Mdot
.68245 .50285 Mdot
.73259 .49314 Mdot
.44487 .65772 Mdot
.46826 .37641 Mdot
.71587 .4413 Mdot
.51441 .32177 Mdot
.48029 .36562 Mdot
.48558 .4132 Mdot
.40763 .57956 Mdot
.41437 .62632 Mdot
.61454 .61918 Mdot
.48462 .38662 Mdot
.50103 .37579 Mdot
.35413 .49968 Mdot
.70085 .50369 Mdot
.59598 .60524 Mdot
.69457 .49994 Mdot
.60741 .60512 Mdot
.47644 .15434 Mdot
.5509 .35913 Mdot
.70118 .5079 Mdot
.44767 .65581 Mdot
.32202 .5236 Mdot
.57696 .73308 Mdot
.58643 .60783 Mdot
.62845 .62634 Mdot
.50725 .37559 Mdot
.32731 .52373 Mdot
.35551 .48798 Mdot
.68931 .51414 Mdot
.44244 .63407 Mdot
.48056 .42057 Mdot
.4839 .42707 Mdot
.57734 .27117 Mdot
.58381 .59933 Mdot
.30395 .31599 Mdot
.32311 .65093 Mdot
.46637 .37758 Mdot
.31468 .47375 Mdot
.49922 .40815 Mdot
.59185 .2107 Mdot
.28897 .49659 Mdot
.44886 .40285 Mdot
.23889 .64331 Mdot
.59556 .58069 Mdot
.26752 .6054 Mdot
.52692 .34391 Mdot
.83694 .53755 Mdot
.48494 .34147 Mdot
.67535 .22153 Mdot
.53184 .75449 Mdot
.47179 .33337 Mdot
.47291 .35095 Mdot
.4767 .2112 Mdot
.50939 .38691 Mdot
.58696 .73261 Mdot
.4125 .44097 Mdot
.29406 .51655 Mdot
.5752 .48272 Mdot
.62395 .66749 Mdot
.67418 .50121 Mdot
.62312 .58879 Mdot
.64919 .66673 Mdot
.71014 .51885 Mdot
.3247 .48755 Mdot
.45896 .35737 Mdot
.59425 .44738 Mdot
.57738 .62818 Mdot
.46872 .31043 Mdot
.40423 .63793 Mdot
.66588 .62574 Mdot
.64709 .58231 Mdot
.42461 .64781 Mdot
.53323 .38107 Mdot
.3666 .23526 Mdot
.68754 .69726 Mdot
.83778 .43676 Mdot
.44793 .63544 Mdot
.41208 .65786 Mdot
.33145 .73177 Mdot
.67653 .49553 Mdot
.69005 .30629 Mdot
.23247 .58936 Mdot
.4331 .66029 Mdot
.71933 .36967 Mdot
.63479 .63828 Mdot
.27209 .63932 Mdot
.38101 .49207 Mdot
.54759 .39287 Mdot
.46896 .40649 Mdot
.44077 .63236 Mdot
.56524 .45997 Mdot
.4358 .82596 Mdot
.42258 .63809 Mdot
.51684 .44052 Mdot
.525 .59938 Mdot
.59854 .72878 Mdot
.60335 .71884 Mdot
.67897 .52522 Mdot
.79594 .53336 Mdot
.34767 .49237 Mdot
.7059 .52718 Mdot
.50093 .63716 Mdot
.52129 .35656 Mdot
.42898 .63718 Mdot
.57847 .7417 Mdot
.41957 .65543 Mdot
.71589 .50942 Mdot
.68767 .53273 Mdot
.3232 .47256 Mdot
.29529 .51094 Mdot
.28352 .44024 Mdot
.69804 .38846 Mdot
.52242 .38717 Mdot
.23776 .34337 Mdot
.35827 .49968 Mdot
.49902 .45853 Mdot
.69744 .47498 Mdot
.69846 .50714 Mdot
.24738 .37719 Mdot
.45405 .36851 Mdot
.69041 .4536 Mdot
.45596 .37704 Mdot
.67484 .31102 Mdot
.49045 .43005 Mdot
.62455 .61637 Mdot
.46215 .34427 Mdot
.58591 .55053 Mdot
.45025 .35918 Mdot
.51532 .40895 Mdot
.6376 .63203 Mdot
.56101 .36783 Mdot
.63361 .60715 Mdot
.47588 .42139 Mdot
.72933 .47616 Mdot
.62566 .59161 Mdot
.62168 .36284 Mdot
.4685 .55008 Mdot
.58215 .72788 Mdot
.72165 .48973 Mdot
.72438 .51218 Mdot
.60982 .44462 Mdot
.29685 .50347 Mdot
.29728 .45428 Mdot
.47004 .37537 Mdot
.62423 .6416 Mdot
.41747 .62319 Mdot
.49891 .3757 Mdot
.476 .4293 Mdot
.51623 .33363 Mdot
.3498 .51468 Mdot
.61934 .5723 Mdot
.70556 .5088 Mdot
.6108 .58439 Mdot
.77894 .55901 Mdot
.65463 .60504 Mdot
.4253 .37562 Mdot
.50037 .43525 Mdot
.4645 .25684 Mdot
.20912 .44094 Mdot
.21587 .62928 Mdot
.34128 .5103 Mdot
.59115 .71518 Mdot
.68954 .53213 Mdot
.39602 .38231 Mdot
.30349 .51016 Mdot
.63819 .62434 Mdot
.46241 .37418 Mdot
.54232 .42491 Mdot
.47639 .6264 Mdot
.31423 .56126 Mdot
.63313 .42579 Mdot
.65069 .58343 Mdot
.59182 .73181 Mdot
.32843 .71562 Mdot
.39523 .4546 Mdot
.57983 .49673 Mdot
.48684 .40676 Mdot
.72227 .48425 Mdot
.32711 .53216 Mdot
.69246 .66458 Mdot
.436 .63551 Mdot
.53302 .52601 Mdot
.47391 .38759 Mdot
.37775 .716 Mdot
.32186 .49451 Mdot
.71847 .51103 Mdot
.44008 .63211 Mdot
.67286 .5042 Mdot
.60386 .71928 Mdot
.80709 .51998 Mdot
.50463 .34065 Mdot
.51674 .40444 Mdot
.45792 .61737 Mdot
.34769 .49582 Mdot
.73185 .45922 Mdot
.73978 .34811 Mdot
.62428 .57977 Mdot
.68115 .4606 Mdot
.34429 .53694 Mdot
.40222 .27535 Mdot
.60705 .58734 Mdot
.4186 .59879 Mdot
.61156 .46988 Mdot
.39453 .642 Mdot
.45263 .39108 Mdot
.31248 .50527 Mdot
.4171 .61421 Mdot
.7558 .585 Mdot
.58955 .17946 Mdot
.41983 .25316 Mdot
.48446 .3313 Mdot
.45955 .17966 Mdot
.7633 .33835 Mdot
.52755 .48051 Mdot
.41285 .66212 Mdot
.49503 .3973 Mdot
.51054 .42497 Mdot
.47798 .33678 Mdot
.40573 .61869 Mdot
.75963 .53567 Mdot
.63305 .6218 Mdot
.51605 .37693 Mdot
.71453 .52172 Mdot
.62584 .60541 Mdot
.61372 .55012 Mdot
.60924 .63709 Mdot
.29619 .52336 Mdot
.4458 .39121 Mdot
.3297 .69567 Mdot
.62309 .17396 Mdot
.4183 .63053 Mdot
.5824 .72776 Mdot
.5269 .39823 Mdot
.20595 .5644 Mdot
.31146 .51595 Mdot
.62688 .57964 Mdot
.48469 .39674 Mdot
.76006 .55332 Mdot
.57196 .74544 Mdot
.6186 .63497 Mdot
.30132 .49718 Mdot
.51177 .48778 Mdot
.47498 .38157 Mdot
.49026 .34087 Mdot
.34196 .49045 Mdot
.80379 .54738 Mdot
.35231 .75236 Mdot
.4998 .41028 Mdot
.4203 .64645 Mdot
.56972 .85471 Mdot
.5307 .35252 Mdot
.25512 .50039 Mdot
.59245 .74734 Mdot
.29565 .64471 Mdot
.29753 .32146 Mdot
.43046 .44587 Mdot
.49797 .19954 Mdot
.59856 .46464 Mdot
.4514 .17086 Mdot
.75884 .48715 Mdot
.52626 .6477 Mdot
.48981 .1526 Mdot
.42344 .67143 Mdot
.57786 .36659 Mdot
.53086 .25354 Mdot
.39108 .75588 Mdot
.55237 .48614 Mdot
.77929 .65112 Mdot
.75398 .61208 Mdot
.57339 .66991 Mdot
.60017 .62467 Mdot
.65355 .2955 Mdot
.48597 .4198 Mdot
.76917 .34462 Mdot
.3443 .27814 Mdot
.4296 .83129 Mdot
.47443 .17383 Mdot
.74708 .43058 Mdot
.39461 .21109 Mdot
.60903 .20444 Mdot
.49018 .24415 Mdot
.32218 .57092 Mdot
.73086 .74102 Mdot
.28725 .69593 Mdot
.76846 .43148 Mdot
.43057 .33301 Mdot
.5531 .57516 Mdot
.79154 .4338 Mdot
.37355 .34936 Mdot
.4799 .85451 Mdot
.58864 .61546 Mdot
.2863 .52332 Mdot
.56494 .2584 Mdot
.31334 .55565 Mdot
.36781 .60789 Mdot
.49513 .19865 Mdot
.67167 .22627 Mdot
.38249 .26177 Mdot
.84103 .54872 Mdot
.24922 .41951 Mdot
.18694 .62237 Mdot
.49151 .57 Mdot
.28027 .5203 Mdot
.68931 .75186 Mdot
.27208 .6834 Mdot
.31568 .58517 Mdot
.40219 .35802 Mdot
.72215 .53587 Mdot
.6444 .38696 Mdot
.31361 .49205 Mdot
.297 .31424 Mdot
.60637 .71926 Mdot
.26581 .55916 Mdot
.57004 .56931 Mdot
.56287 .19049 Mdot
.55727 .6414 Mdot
.28625 .65641 Mdot
.4519 .75768 Mdot
.237 .27969 Mdot
.72539 .39832 Mdot
.64429 .23984 Mdot
.47115 .63149 Mdot
.54888 .4841 Mdot
.42244 .79843 Mdot
.6885 .40441 Mdot
.26153 .6741 Mdot
.21466 .33774 Mdot
.79709 .38966 Mdot
.27871 .25742 Mdot
.2721 .52492 Mdot
.51093 .33114 Mdot
.59639 .22852 Mdot
.32492 .43415 Mdot
.69099 .53676 Mdot
.32882 .22263 Mdot
.71035 .47463 Mdot
.29514 .54839 Mdot
.40517 .75832 Mdot
.38356 .28479 Mdot
.65893 .48016 Mdot
.70276 .4632 Mdot
.44432 .3435 Mdot
.19438 .7025 Mdot
.43777 .18011 Mdot
.30886 .63018 Mdot
.70977 .26351 Mdot
.47494 .67784 Mdot
.68365 .44639 Mdot
.41055 .61894 Mdot
.55224 .16104 Mdot
.30476 .50195 Mdot
.55569 .1355 Mdot
.58124 .16931 Mdot
.54049 .81837 Mdot
.37885 .87684 Mdot
.50262 .71503 Mdot
.53286 .27624 Mdot
.59775 .42428 Mdot
.62104 .39805 Mdot
.43908 .81653 Mdot
.55865 .81404 Mdot
.46522 .68839 Mdot
.8164 .48551 Mdot
.50981 .15984 Mdot
.70275 .34653 Mdot
.78066 .46827 Mdot
.40735 .77281 Mdot
.48047 .54729 Mdot
.28674 .46449 Mdot
.43446 .53689 Mdot
.31306 .56837 Mdot
.31539 .2336 Mdot
.32161 .4419 Mdot
.49287 .87695 Mdot
.73829 .47419 Mdot
.56271 .76594 Mdot
.71853 .28517 Mdot
.62341 .34794 Mdot
.42479 .2974 Mdot
.35458 .72496 Mdot
.4388 .34909 Mdot
.33709 .72144 Mdot
.41364 .47733 Mdot
.65681 .65511 Mdot
.32391 .71671 Mdot
.37996 .69283 Mdot
.74208 .36135 Mdot
.53471 .22274 Mdot
.23183 .62485 Mdot
.28851 .50834 Mdot
.66884 .4248 Mdot
.72616 .38712 Mdot
.71382 .27101 Mdot
.50441 .79451 Mdot
.83564 .42347 Mdot
.52177 .79949 Mdot
.51771 .32458 Mdot
.52063 .45003 Mdot
.44188 .31722 Mdot
.70483 .40501 Mdot
.53295 .34478 Mdot
.38217 .71673 Mdot
.73821 .29074 Mdot
.2676 .45659 Mdot
.68067 .59509 Mdot
.19314 .42337 Mdot
.82154 .41489 Mdot
.60107 .23678 Mdot
.5271 .76204 Mdot
.57332 .42687 Mdot
.15297 .53553 Mdot
.61811 .60506 Mdot
.71411 .36344 Mdot
.38442 .63657 Mdot
.71131 .64622 Mdot
.45535 .22508 Mdot
.52669 .82218 Mdot
.74382 .29479 Mdot
.36271 .7459 Mdot
.64562 .71114 Mdot
.60412 .51433 Mdot
.65417 .4955 Mdot
.20102 .40538 Mdot
.51892 .43487 Mdot
.4456 .29439 Mdot
.72859 .51201 Mdot
.3498 .41973 Mdot
.63052 .26136 Mdot
.72302 .69211 Mdot
.53315 .44013 Mdot
.65383 .7529 Mdot
.591 .73612 Mdot
.52855 .52987 Mdot
.36838 .1643 Mdot
.43879 .3408 Mdot
.50505 .73176 Mdot
.80346 .40247 Mdot
.66576 .44323 Mdot
.6875 .26723 Mdot
.35644 .69903 Mdot
.26192 .27871 Mdot
.61549 .18057 Mdot
.72365 .67304 Mdot
.41798 .17096 Mdot
.81532 .35561 Mdot
.235 .31017 Mdot
.22161 .39113 Mdot
.41049 .675 Mdot
.53247 .10021 Mdot
.64394 .59859 Mdot
.19349 .47586 Mdot
.30953 .43745 Mdot
.73671 .56548 Mdot
.36197 .47836 Mdot
.52739 .31037 Mdot
.5695 .65928 Mdot
.37473 .51931 Mdot
.42254 .39924 Mdot
.27846 .23889 Mdot
.18554 .38529 Mdot
.2872 .23711 Mdot
.82356 .45197 Mdot
.42699 .16952 Mdot
.56349 .27953 Mdot
.38362 .30924 Mdot
.61132 .27209 Mdot
.48506 .42428 Mdot
.67237 .33728 Mdot
.4999 .72327 Mdot
.67788 .69948 Mdot
.29222 .58067 Mdot
.36829 .51247 Mdot
.32074 .24268 Mdot
.27934 .20538 Mdot
.25998 .40251 Mdot
.31282 .35167 Mdot
.47598 .59737 Mdot
.7065 .38918 Mdot
.40038 .47914 Mdot
.64496 .74247 Mdot
.71834 .28016 Mdot
.53022 .25196 Mdot
.73292 .37151 Mdot
.73572 .69219 Mdot
.63117 .52736 Mdot
.55607 .74585 Mdot
.56182 .18314 Mdot
.5935 .30383 Mdot
.54581 .80889 Mdot
.58557 .38614 Mdot
.47462 .83626 Mdot
.77038 .62916 Mdot
.62043 .6877 Mdot
.74559 .40208 Mdot
.61462 .56699 Mdot
.69346 .34199 Mdot
.52366 .58774 Mdot
.5692 .24963 Mdot
.59842 .46309 Mdot
.69223 .33662 Mdot
.62886 .52835 Mdot
.34916 .20216 Mdot
.84706 .40302 Mdot
.16931 .43213 Mdot
.83589 .52337 Mdot
.41982 .48279 Mdot
.54335 .37281 Mdot
.77398 .32899 Mdot
.32484 .20729 Mdot
.63646 .18845 Mdot
.39697 .73496 Mdot
.75342 .5774 Mdot
.44433 .666 Mdot
.17228 .44156 Mdot
.79236 .608 Mdot
.64937 .22036 Mdot
.21762 .62848 Mdot
.42145 .58882 Mdot
.37109 .76316 Mdot
.18457 .44925 Mdot
.43128 .23027 Mdot
.27583 .34864 Mdot
.48367 .30513 Mdot
.3686 .2593 Mdot
.28318 .50332 Mdot
.44626 .76329 Mdot
.69671 .40175 Mdot
.61854 .60008 Mdot
.60541 .33061 Mdot
.44449 .29175 Mdot
.44823 .33793 Mdot
.60353 .67972 Mdot
.33686 .45652 Mdot
.21164 .45911 Mdot
.41703 .69528 Mdot
.46504 .14753 Mdot
.49059 .7451 Mdot
.40705 .36644 Mdot
.69034 .42519 Mdot
.66943 .67984 Mdot
.34552 .72865 Mdot
.41911 .66713 Mdot
.504 .17505 Mdot
.41606 .52736 Mdot
.67448 .42405 Mdot
.35524 .26468 Mdot
.71312 .32091 Mdot
.50254 .43415 Mdot
.3304 .64215 Mdot
.39032 .34332 Mdot
.54342 .52556 Mdot
.30982 .54902 Mdot
.32801 .4538 Mdot
.87158 .55185 Mdot
.50039 .66259 Mdot
.53555 .78815 Mdot
.51389 .17824 Mdot
.39724 .63349 Mdot
.36385 .51159 Mdot
.6745 .32446 Mdot
.75234 .36624 Mdot
.3778 .37381 Mdot
.65736 .57733 Mdot
.6919 .54797 Mdot
.74695 .66561 Mdot
.46332 .18213 Mdot
.41683 .19966 Mdot
.41997 .83289 Mdot
.35882 .48676 Mdot
.69244 .29704 Mdot
.75523 .3812 Mdot
.35443 .51593 Mdot
.28119 .54619 Mdot
.25159 .55484 Mdot
.41068 .16215 Mdot
.32919 .70459 Mdot
.82794 .5212 Mdot
.62186 .46487 Mdot
.76361 .54023 Mdot
.6849 .66235 Mdot
.76758 .44569 Mdot
.52067 .17999 Mdot
.28925 .31667 Mdot
.419 .22467 Mdot
.40913 .38042 Mdot
.22912 .48438 Mdot
.16806 .45087 Mdot
.49446 .56183 Mdot
.40021 .27215 Mdot
.36624 .66583 Mdot
.4917 .33276 Mdot
.23859 .27787 Mdot
.76503 .35516 Mdot
.3081 .72239 Mdot
.37835 .64277 Mdot
.49414 .35237 Mdot
.53952 .34553 Mdot
.55202 .46516 Mdot
.30681 .64171 Mdot
.19122 .3916 Mdot
.77116 .4466 Mdot
.45858 .48829 Mdot
.33961 .27663 Mdot
.50497 .73397 Mdot
.56292 .19451 Mdot
.74622 .31819 Mdot
.53634 .55846 Mdot
.4956 .72885 Mdot
.60591 .49568 Mdot
.83232 .49936 Mdot
.55623 .62589 Mdot
.56131 .27171 Mdot
.22208 .56705 Mdot
.32743 .67257 Mdot
.67751 .67892 Mdot
.52819 .40024 Mdot
.40927 .75677 Mdot
.60059 .20403 Mdot
.445 .86168 Mdot
.43891 .80683 Mdot
.26709 .2419 Mdot
.43584 .26205 Mdot
.32902 .68041 Mdot
.39365 .22184 Mdot
.4289 .86625 Mdot
.57001 .64892 Mdot
.36167 .21691 Mdot
.6044 .50808 Mdot
.48994 .17533 Mdot
.38586 .65229 Mdot
.27126 .66072 Mdot
.19249 .43074 Mdot
.42089 .16149 Mdot
.62653 .24079 Mdot
.53318 .18704 Mdot
.58809 .40066 Mdot
.38237 .17286 Mdot
.21516 .556 Mdot
.57449 .67418 Mdot
.59852 .65053 Mdot
.39473 .72557 Mdot
.30294 .27749 Mdot
.37253 .57063 Mdot
.72308 .36877 Mdot
.56191 .70675 Mdot
.39972 .34723 Mdot
.39553 .23329 Mdot
.63595 .33807 Mdot
.3435 .68002 Mdot
.68712 .4275 Mdot
.62754 .20401 Mdot
.57646 .69849 Mdot
.69071 .64197 Mdot
.50894 .77237 Mdot
.80875 .51535 Mdot
.30371 .63651 Mdot
.49783 .67758 Mdot
.64017 .23659 Mdot
.78935 .59195 Mdot
.74426 .42215 Mdot
.89894 .51642 Mdot
.79228 .4593 Mdot
.26416 .55397 Mdot
.30575 .24553 Mdot
.73158 .29651 Mdot
.2278 .51035 Mdot
.41298 .81705 Mdot
.23267 .47767 Mdot
.68204 .3627 Mdot
.48318 .41354 Mdot
.34833 .18006 Mdot
.64769 .37635 Mdot
.31687 .22984 Mdot
.801 .36711 Mdot
.36902 .25486 Mdot
.46248 .32303 Mdot
.65442 .62826 Mdot
.48966 .59427 Mdot
.6336 .32671 Mdot
.43366 .21491 Mdot
.23315 .46887 Mdot
.65447 .65001 Mdot
.61126 .70929 Mdot
.65792 .58745 Mdot
.46398 .47621 Mdot
.48311 .72894 Mdot
.32421 .65764 Mdot
.70974 .4568 Mdot
.54581 .5721 Mdot
.71306 .38194 Mdot
.30274 .3152 Mdot
.4373 .23058 Mdot
.50589 .82799 Mdot
.36404 .62624 Mdot
.59351 .62862 Mdot
.49398 .21482 Mdot
.79941 .45506 Mdot
.35987 .68109 Mdot
.24255 .31171 Mdot
.36004 .73235 Mdot
.64062 .29621 Mdot
.59787 .24927 Mdot
.46193 .82516 Mdot
.77039 .6971 Mdot
.27519 .29031 Mdot
.22414 .49108 Mdot
.67751 .45951 Mdot
.47802 .26956 Mdot
.4765 .15522 Mdot
.7575 .41621 Mdot
.5764 .24289 Mdot
.47352 .55707 Mdot
.35933 .38754 Mdot
.35845 .25245 Mdot
.61434 .36492 Mdot
.57255 .50519 Mdot
.16625 .5929 Mdot
.37287 .49182 Mdot
.22632 .28826 Mdot
.43447 .64632 Mdot
.28624 .73273 Mdot
.6451 .53666 Mdot
.51978 .57489 Mdot
.57747 .49091 Mdot
.32684 .63392 Mdot
.24669 .57543 Mdot
.82103 .46616 Mdot
.50682 .83813 Mdot
.6532 .6139 Mdot
.73647 .44325 Mdot
.81545 .54765 Mdot
.48867 .20646 Mdot
.42971 .40522 Mdot
.80088 .47318 Mdot
.49151 .55759 Mdot
.6758 .69952 Mdot
.77582 .33712 Mdot
.35714 .62031 Mdot
.48498 .444 Mdot
.70411 .39148 Mdot
.35776 .22081 Mdot
.59744 .17665 Mdot
.3642 .78203 Mdot
.41424 .4777 Mdot
.42852 .67451 Mdot
.57621 .31063 Mdot
.4673 .19001 Mdot
.65369 .46455 Mdot
.29104 .66882 Mdot
.72958 .39457 Mdot
.15547 .39129 Mdot
.1997 .36677 Mdot
.19091 .3941 Mdot
.68791 .43712 Mdot
.33516 .55069 Mdot
.21565 .52497 Mdot
.58156 .24545 Mdot
.34848 .62739 Mdot
.79588 .42856 Mdot
.71631 .36978 Mdot
.36258 .82287 Mdot
.41673 .3053 Mdot
.78063 .55539 Mdot
.33605 .26124 Mdot
.32355 .42738 Mdot
.393 .66418 Mdot
.66972 .35902 Mdot
.40524 .51247 Mdot
.45505 .63848 Mdot
.33893 .67362 Mdot
.27571 .63547 Mdot
.57345 .24192 Mdot
.3833 .34096 Mdot
.43299 .48408 Mdot
.52696 .21553 Mdot
.36817 .53108 Mdot
.6932 .66172 Mdot
.68186 .65622 Mdot
.50148 .50419 Mdot
.6315 .58451 Mdot
.42761 .44404 Mdot
.54793 .53316 Mdot
.59027 .50793 Mdot
.17697 .50121 Mdot
.71836 .47786 Mdot
.36261 .52954 Mdot
.27515 .70861 Mdot
.35274 .5211 Mdot
.30767 .20959 Mdot
.63849 .74642 Mdot
.35484 .26767 Mdot
.73866 .65414 Mdot
.70297 .73084 Mdot
.2088 .69107 Mdot
.2207 .37251 Mdot
.44997 .55151 Mdot
.35659 .55916 Mdot
.31739 .46613 Mdot
.66879 .582 Mdot
.60741 .70419 Mdot
.28316 .34984 Mdot
.51378 .71547 Mdot
.62566 .28215 Mdot
.2762 .51808 Mdot
.77748 .53447 Mdot
.40096 .44695 Mdot
.42736 .15534 Mdot
.59822 .62729 Mdot
.14228 .50558 Mdot
.55921 .38116 Mdot
.49007 .23891 Mdot
.76693 .31454 Mdot
.36316 .77192 Mdot
.63836 .70217 Mdot
.79844 .64378 Mdot
.45469 .3443 Mdot
.43334 .48152 Mdot
.31155 .49079 Mdot
.66877 .29183 Mdot
.7088 .4964 Mdot
.64524 .42575 Mdot
.43805 .5954 Mdot
.5647 .79932 Mdot
.47739 .73645 Mdot
.33427 .54534 Mdot
.39525 .52483 Mdot
.62828 .25003 Mdot
.24998 .62583 Mdot
.4912 .55543 Mdot
.47967 .21157 Mdot
.37638 .36848 Mdot
.27469 .5137 Mdot
.23117 .33009 Mdot
.75488 .38676 Mdot
.55969 .15703 Mdot
.50699 .29089 Mdot
.49461 .58313 Mdot
.23996 .6238 Mdot
.33797 .65905 Mdot
.29253 .33067 Mdot
.71385 .27612 Mdot
.68057 .41526 Mdot
.26883 .67283 Mdot
.68885 .33483 Mdot
.54737 .33734 Mdot
.54444 .6221 Mdot
.43423 .74384 Mdot
.32418 .79291 Mdot
.22497 .40525 Mdot
.3987 .78759 Mdot
.32627 .56753 Mdot
.50428 .73053 Mdot
.37521 .50797 Mdot
.70433 .59164 Mdot
.37273 .36022 Mdot
.62108 .73243 Mdot
.51269 .14944 Mdot
.72224 .28176 Mdot
.46373 .60094 Mdot
.59982 .55897 Mdot
.57205 .47397 Mdot
.41972 .33948 Mdot
.51863 .52085 Mdot
.47284 .33145 Mdot
.50499 .47536 Mdot
.34924 .76479 Mdot
.34218 .63582 Mdot
.52109 .30857 Mdot
.46316 .16425 Mdot
.5696 .15833 Mdot
.37197 .18165 Mdot
.67141 .46842 Mdot
.31923 .53847 Mdot
.24431 .29246 Mdot
.32601 .31725 Mdot
.6258 .20079 Mdot
.26566 .30717 Mdot
.87555 .53116 Mdot
.42974 .21954 Mdot
.37336 .67955 Mdot
.54827 .81773 Mdot
.26634 .58835 Mdot
.78058 .35376 Mdot
.57545 .67825 Mdot
.67615 .57876 Mdot
.78716 .36139 Mdot
.18884 .68998 Mdot
.21734 .4033 Mdot
.2818 .64758 Mdot
.51221 .25959 Mdot
.47825 .50115 Mdot
.52505 .69803 Mdot
.49557 .42104 Mdot
.57611 .60422 Mdot
.65071 .70451 Mdot
.71767 .37999 Mdot
.46956 .26002 Mdot
.52555 .70362 Mdot
.63261 .32073 Mdot
.66386 .29821 Mdot
.77235 .43714 Mdot
.44802 .21903 Mdot
.28934 .34346 Mdot
.47458 .44407 Mdot
.35151 .54888 Mdot
.67678 .51822 Mdot
.65752 .66213 Mdot
.4544 .40852 Mdot
.62829 .70366 Mdot
.23873 .59032 Mdot
.2672 .24569 Mdot
.69208 .591 Mdot
.75572 .35903 Mdot
.37373 .47561 Mdot
.31589 .64251 Mdot
.56847 .21212 Mdot
.39472 .75556 Mdot
.53243 .70978 Mdot
.32027 .44157 Mdot
.44979 .17779 Mdot
.34843 .71852 Mdot
.72563 .34879 Mdot
.18352 .55806 Mdot
.45365 .62239 Mdot
.21971 .45445 Mdot
.54464 .26101 Mdot
.37395 .73862 Mdot
.27136 .51731 Mdot
.39206 .69851 Mdot
.53245 .64007 Mdot
.36294 .71996 Mdot
.80557 .40418 Mdot
.66858 .28172 Mdot
.31723 .27585 Mdot
.42521 .19467 Mdot
.583 .62852 Mdot
.73022 .36849 Mdot
.40373 .69874 Mdot
.53425 .67477 Mdot
.24092 .63453 Mdot
.46321 .15329 Mdot
.53628 .51708 Mdot
.63784 .37987 Mdot
.49499 .3382 Mdot
.34449 .33133 Mdot
.33509 .63017 Mdot
.6053 .53468 Mdot
.51742 .78537 Mdot
.28967 .49895 Mdot
.47088 .75543 Mdot
.57191 .71719 Mdot
.67287 .37271 Mdot
.38536 .52538 Mdot
.24884 .48438 Mdot
.69005 .54267 Mdot
.58431 .70156 Mdot
.44645 .43084 Mdot
.63596 .39598 Mdot
.65049 .49198 Mdot
.21813 .43593 Mdot
.21252 .40521 Mdot
.48578 .21061 Mdot
.76969 .38185 Mdot
.35458 .66553 Mdot
.26385 .30704 Mdot
.25005 .57243 Mdot
.39632 .2968 Mdot
.44278 .78179 Mdot
.52147 .33716 Mdot
.7066 .58853 Mdot
.36013 .52677 Mdot
.46917 .19809 Mdot
.42504 .27661 Mdot
.62209 .3606 Mdot
.51463 .54838 Mdot
.58625 .21721 Mdot
.47021 .53493 Mdot
.76943 .32067 Mdot
.26854 .58782 Mdot
.69471 .40237 Mdot
.39358 .60668 Mdot
.61181 .5056 Mdot
.45441 .81635 Mdot
.54805 .16651 Mdot
.51472 .82817 Mdot
.59351 .42934 Mdot
.38995 .77938 Mdot
.21766 .50494 Mdot
.79405 .36192 Mdot
.68868 .38856 Mdot
.5157 .52156 Mdot
.40041 .44916 Mdot
.47507 .63913 Mdot
.57733 .73305 Mdot
.71739 .59167 Mdot
.30528 .33504 Mdot
.73941 .53962 Mdot
.62619 .72815 Mdot
.43005 .41921 Mdot
.20373 .58061 Mdot
.43481 .1878 Mdot
.39304 .38012 Mdot
.51113 .57392 Mdot
.70582 .66688 Mdot
.66774 .38161 Mdot
.80024 .71187 Mdot
.23796 .27749 Mdot
.4978 .33902 Mdot
.59595 .47566 Mdot
.6517 .4167 Mdot
.64321 .57984 Mdot
.28213 .36095 Mdot
.48134 .20735 Mdot
.41217 .6592 Mdot
.74477 .58763 Mdot
.39507 .71963 Mdot
.32531 .6247 Mdot
.60844 .3494 Mdot
.41682 .58004 Mdot
.28942 .22297 Mdot
.80796 .46189 Mdot
.34132 .65066 Mdot
.84343 .6364 Mdot
.41389 .74504 Mdot
.37733 .46497 Mdot
.61912 .23194 Mdot
.35241 .19948 Mdot
.67307 .44015 Mdot
.71762 .63788 Mdot
.20607 .41525 Mdot
.68812 .40648 Mdot
.68788 .31821 Mdot
.508 .77153 Mdot
.47887 .76051 Mdot
.55634 .65795 Mdot
.70537 .7284 Mdot
.18892 .50901 Mdot
.3115 .29402 Mdot
.39766 .19998 Mdot
.62518 .74855 Mdot
.37665 .8312 Mdot
.55166 .16096 Mdot
.66191 .33684 Mdot
.5238 .72254 Mdot
.6412 .24212 Mdot
.62391 .43698 Mdot
.30826 .44486 Mdot
.63733 .74154 Mdot
.37034 .399 Mdot
.68634 .73641 Mdot
.46781 .79494 Mdot
.69269 .33957 Mdot
.30409 .4358 Mdot
.54626 .5128 Mdot
.47446 .21969 Mdot
.57811 .77513 Mdot
.70759 .42238 Mdot
.74702 .59833 Mdot
.61186 .41588 Mdot
.50484 .20831 Mdot
.62544 .22206 Mdot
.51918 .51563 Mdot
.18748 .68325 Mdot
.32671 .22959 Mdot
.40984 .76798 Mdot
.54444 .36423 Mdot
.50738 .14437 Mdot
.48685 .51065 Mdot
.24989 .32327 Mdot
.79356 .39747 Mdot
.68211 .64272 Mdot
.23106 .60774 Mdot
.51176 .33097 Mdot
.22946 .35405 Mdot
.40176 .26696 Mdot
.3162 .42827 Mdot
.65635 .69988 Mdot
.68918 .42391 Mdot
.57036 .77211 Mdot
.60757 .37885 Mdot
.44939 .30493 Mdot
.34815 .53583 Mdot
.30313 .22193 Mdot
.57457 .32592 Mdot
.44173 .45734 Mdot
.58036 .3903 Mdot
.51244 .83301 Mdot
.81824 .64247 Mdot
.45616 .30435 Mdot
.33999 .71749 Mdot
.72385 .37163 Mdot
.60684 .26225 Mdot
.21756 .38741 Mdot
.41758 .90212 Mdot
.75723 .30151 Mdot
.34888 .46501 Mdot
.2327 .44595 Mdot
.70677 .434 Mdot
.3796 .18219 Mdot
.73817 .68831 Mdot
.67065 .67447 Mdot
.51697 .84926 Mdot
.63294 .44527 Mdot
.48035 .42847 Mdot
.82325 .43193 Mdot
.55592 .16727 Mdot
.58601 .78701 Mdot
.48136 .15725 Mdot
.47096 .31602 Mdot
.55172 .3698 Mdot
.59672 .87389 Mdot
.48469 .18541 Mdot
.44412 .33974 Mdot
.48143 .83994 Mdot
.27623 .47441 Mdot
.47398 .4179 Mdot
.51339 .68121 Mdot
.75216 .41361 Mdot
.67411 .30737 Mdot
.41931 .16201 Mdot
.32421 .54847 Mdot
.63003 .70519 Mdot
.40241 .60824 Mdot
.57706 .49386 Mdot
.53699 .42992 Mdot
.41232 .61387 Mdot
.64881 .30011 Mdot
.50539 .50745 Mdot
.38626 .60941 Mdot
.76595 .4555 Mdot
.84714 .44235 Mdot
.43697 .25581 Mdot
.47505 .61456 Mdot
.5679 .43673 Mdot
.39274 .36845 Mdot
.63405 .3245 Mdot
.61162 .28658 Mdot
.79529 .38036 Mdot
.81303 .32272 Mdot
.66168 .55822 Mdot
.53611 .31019 Mdot
.38863 .49246 Mdot
.30038 .33032 Mdot
.41627 .23884 Mdot
.37504 .64751 Mdot
.59769 .70831 Mdot
.49498 .31854 Mdot
.45318 .30268 Mdot
.43534 .59427 Mdot
.18163 .34122 Mdot
.513 .41497 Mdot
.26869 .33348 Mdot
.60761 .19678 Mdot
.69121 .66475 Mdot
.46282 .25472 Mdot
.44203 .35893 Mdot
.21863 .53746 Mdot
.4774 .50982 Mdot
.51497 .49037 Mdot
.68477 .65756 Mdot
.39888 .1841 Mdot
.42729 .27536 Mdot
.30354 .29116 Mdot
.50678 .37262 Mdot
.71928 .46848 Mdot
.2691 .63889 Mdot
.20746 .38216 Mdot
.42069 .32508 Mdot
.61895 .19127 Mdot
.68572 .63552 Mdot
.74535 .5294 Mdot
.49211 .25367 Mdot
.30782 .23255 Mdot
.43427 .80115 Mdot
.39604 .2453 Mdot
.3219 .73483 Mdot
.46813 .70501 Mdot
.63823 .33968 Mdot
.65572 .62146 Mdot
.52644 .31057 Mdot
.26862 .48743 Mdot
.33686 .17699 Mdot
.20499 .39231 Mdot
.44597 .68888 Mdot
.65901 .6445 Mdot
.37259 .29673 Mdot
.56807 .4955 Mdot
.86728 .58914 Mdot
.78242 .64564 Mdot
.28411 .22664 Mdot
.65723 .28057 Mdot
.38909 .46003 Mdot
.35021 .69189 Mdot
.50736 .4506 Mdot
.6213 .63255 Mdot
.38589 .18287 Mdot
.48274 .28982 Mdot
.46765 .78819 Mdot
.48951 .42694 Mdot
.2865 .70556 Mdot
.42699 .50101 Mdot
.60118 .56089 Mdot
.59876 .57168 Mdot
.41948 .81626 Mdot
.59653 .20823 Mdot
.46997 .51133 Mdot
.8572 .56914 Mdot
.4106 .21256 Mdot
.50632 .17498 Mdot
.65706 .57855 Mdot
.32929 .77491 Mdot
.36479 .5658 Mdot
.41282 .49645 Mdot
.42032 .69343 Mdot
.59697 .40611 Mdot
.37125 .7316 Mdot
.62165 .27065 Mdot
.25895 .6062 Mdot
.46402 .60355 Mdot
.88677 .38805 Mdot
.66528 .32782 Mdot
.40311 .35715 Mdot
.41814 .75862 Mdot
.48858 .16567 Mdot
.6635 .52535 Mdot
.83715 .44249 Mdot
.5545 .56802 Mdot
.54696 .41434 Mdot
.38767 .33705 Mdot
.49868 .24436 Mdot
.40393 .72247 Mdot
.18034 .6375 Mdot
.79625 .44388 Mdot
.70445 .54975 Mdot
.54387 .57273 Mdot
.35642 .51369 Mdot
.36087 .4771 Mdot
.72521 .68271 Mdot
.85253 .49202 Mdot
.4543 .49531 Mdot
.47018 .18901 Mdot
.24067 .72231 Mdot
.69804 .31308 Mdot
.38986 .17436 Mdot
.35219 .57392 Mdot
.29087 .55327 Mdot
.633 .31611 Mdot
.7321 .46397 Mdot
.60786 .57281 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo08oooooo0_l0002hooooo`007?ooool00ol0003oooooooooo`2?oooo
o`;o0000^?ooool001cooooo0_l0002Zooooo`?o0000WOooool001cooooo00?o0000ooooooooool0
ZOooool3o`0009gooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0;Sooooo0_l0002?
ooooo`007?ooool00ol0003oooooooooo`2hooooo`;o0000Soooool001cooooo00?o0000oooooooo
ool0__ooool2o`0008Wooooo000Looooo`03o`000?oooooooooo0;kooooo0_l00029ooooo`007?oo
ool00ol0003oooooooooo`2aooooo`;o00003oooool2o`0000;ooooo0_l00005ooooo`;o0000N_oo
ool001cooooo00?o0000ooooooooool0/Oooool2o`0000oooooo0_l00002ooooo`;o00001Oooool2
o`0007[ooooo000Looooo`03o`000?oooooooooo0:7ooooo0_l0000Oooooo`;o0000QOooool001co
oooo00?o0000ooooooooool0Toooool2o`0000cooooo0_l0000Yooooo`;o0000Noooool001cooooo
00?o0000ooooooooool0T_ooool3o`0000kooooo0_l0000Wooooo`;o0000Noooool001cooooo0_l0
002Cooooo`?o00001_ooool2o`0000Kooooo0_l0002Tooooo`007?ooool00ol0003oooooooooo`27
ooooo`;o00002_ooool2o`0000;ooooo0ol000000ooooooo0000o`00000Pooooo`;o0000R_ooool0
01cooooo00?o0000ooooooooool0Ooooool2o`0000Kooooo0_l0000>ooooo`Co00001oooool2o`00
00kooooo0_l000000ooooooo0000o`000006ooooo`;o00006Oooool2o`0006oooooo000Looooo`03
o`000?oooooooooo07oooooo0_l000000ooooooo0000o`000003o`0000[ooooo0_l00006ooooo`;o
00001oooool2o`0000Gooooo0_l00002ooooo`Oo000000?oooooo`000?l000008Oooool2o`0006oo
oooo000Looooo`03o`000?oooooooooo07Cooooo0_l0000<ooooo`Go00002_ooool4o`0000;ooooo
0_l00002ooooo`;o00003?ooool2o`0000;ooooo1Ol0002Gooooo`007?ooool00ol0003ooooooooo
o`1dooooo`;o00007Oooool2o`0000;ooooo0_l00002ooooo`;o00004Oooool2o`000003ooooool0
003o000009Kooooo000Looooo`03o`000?oooooooooo06gooooo0_l0000Eooooo`;o000000?ooooo
o`000?l000001?ooool4o`0001gooooo0_l000000ooooooo0000o`000006ooooo`;o00001?ooool2
o`0008Sooooo000Looooo`03o`000?oooooooooo06Sooooo0_l00003ooooo`;o00002Oooool2o`00
0003ooooool0003o000000Oooooo0_l000001?oooooo0000o`000?ooool7o`0000?ooooo1?l00003
ooooo`;o00000_ooool4o`0001Kooooo0_l00004ooooo`;o00001_ooool2o`00083ooooo000Loooo
o`03o`000?oooooooooo06Sooooo1?l0000<ooooo`;o000000?oooooo`000?l000003Oooool6o`00
00Cooooo1?l00003ooooo`;o00000_ooool6o`0000?ooooo0_l00005ooooo`Oo00002?ooool2o`00
00Oooooo0_l00020ooooo`007?ooool00ol0003oooooooooo`1Zooooo`;o000000?oooooo`000?l0
00003_ooool2o`0000_ooooo0_l00002ooooo`;o00000_ooool2o`0000oooooo1?l000000ooooooo
0000o`000002ooooo`;o000000?oooooo`000?l000001Ol00006ooooo`Co00001?ooool2o`0008?o
oooo000Looooo`03o`000?oooooooooo06gooooo0_l00006ooooo`;o000000?oooooo`000?l00000
0_l000001?oooooo0000o`000?l00002ooooo`;o00001_ooool2o`0000Kooooo1Ol0000>ooooo`;o
00001Oooool2o`0000Gooooo0ol00006ooooo`;o00001_ooool2o`0008?ooooo000Looooo`03o`00
0?oooooooooo07Gooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00002ooooo`;o0000
3oooool4o`0000?ooooo0_l0000=ooooo`;o00000_ooool2o`0000Cooooo0ol0002Cooooo`007?oo
ool00ol0003oooooooooo`29ooooo`;o00002Oooool3o`0000?ooooo0_l0000=ooooo`;o00000_oo
ool2o`0000Cooooo0ol00005ooooo`;o00003_ooool2o`0007cooooo00001_ooooook^k^oc8b<_l0
003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`1kooooo`;o0000
3?ooool2o`0000Wooooo0ol0000Looooo`?o00000_ooool5o`0000Sooooo0_l00004ooooo`;o0000
O?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A006ooooo`03o`000?oooooooooo07_ooooo0_l00009ooooo`;o0000:oooool3o`00
00;ooooo0ol00003ooooo`;o00000_ooool2o`000003ooooool0003o000008;ooooo00000ooooooo
410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003o
ooooooooo`1_ooooo`;o00003?ooool2o`0000Gooooo1?l0000=ooooo`;o00001_ooool3o`0001?o
oooo0_l00009ooooo`;o00000_ooool2o`0000[ooooo0_l0001iooooo`0000?oooooo`000?ooool0
0_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0001Rooooo`;o0000
2_ooool3o`0000cooooo0_l00005ooooo`;o00003oooool2o`0000Kooooo0ol0000Aooooo`;o0000
5?ooool2o`0000Gooooo0ol0000Hooooo`;o0000G_ooool00003ooooool0003ooooo00;ooooo00?o
0000ooooooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo05Oooooo0_l0
0009ooooo`;o00002_ooool2o`0000Kooooo0_l0000iooooo`;o00003?ooool2o`000003ooooool0
003o000000;o000000?oooooo`000?l000000ol00003ooooo`?o00005oooool2o`0005kooooo0000
0ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1Gooooo`;o00003Oooool2o`0000;ooooo0_l00005ooooo`;o00000oooool2
o`000003ooooool0003o000000_ooooo0_l0000Aooooo`Co00000oooool2o`0001cooooo0ol00000
0ooooooo0000o`000002o`0000;ooooo1?l00004ooooo`;o0000Moooool00006oooooomgMgOoV9RH
oooooonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
H?ooool2o`0000Cooooo0_l00002ooooo`;o00001Oooool2o`0000Kooooo0_l000000ooooooo0000
o`000008ooooo`;o00001Oooool2o`0000Sooooo1_l00003ooooo`;o00002oooool3o`0000Gooooo
0_l00005ooooo`Co00002?ooool2o`0007oooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo063ooooo0_l00003oooo
o`;o00005Oooool2o`0000Cooooo0_l00005ooooo`;o00000_ooool2o`0000Sooooo2?l00006oooo
o`;o00001_ooool3o`0000Gooooo0_l00005ooooo`;o00000_ooool2o`0000Kooooo0_l0001ooooo
o`007?ooool00ol0003oooooooooo`1Uooooo`;o00002oooool2o`0000kooooo0_l00005ooooo`;o
00004_ooool4o`0000Cooooo1?l0000Booooo`;o00000oooool2o`0000Kooooo1?l000000ooooooo
0000o`000002ooooo`;o0000M_ooool001cooooo00?o0000ooooooooool0L?ooool4o`0001Cooooo
0_l00004ooooo`;o00001_ooool2o`0000Oooooo0_l00006ooooo`;o00000_ooool2o`000003oooo
ool0003o000000_ooooo0_l0000;ooooo`Co000000?oooooo`000?l000001?l00005ooooo`;o0000
Koooool001cooooo00?o0000ooooooooool0F_ooool2o`0000?ooooo0_l00002ooooo`;o00000_oo
ool2o`0000Oooooo0_l00009ooooo`?o00001_ooool2o`0000;ooooo0_l00004ooooo`;o00001_oo
ool2o`0001;ooooo0ol000000ooooooo0000o`00000;ooooo`;o00002_ooool2o`000003ooooool0
003o000000?ooooo0_l00003ooooo`;o00000_ooool2o`0006oooooo000Looooo`03o`000?oooooo
oooo05Wooooo0ol00003ooooo`;o00000_ooool2o`0000;ooooo0_l0000Booooo`?o00001_ooool2
o`0000[ooooo0_l0000Hooooo`;o00003oooool2o`0000[ooooo0_l0000;ooooo`Co0000LOooool0
01cooooo00?o0000ooooooooool0FOooool2o`0000Sooooo0_l000000ooooooo0000o`00000Poooo
o`Co00001?ooool2o`0002Wooooo0_l000000ooooooo0000o`00000Fooooo`;o0000LOooool001co
oooo00?o0000ooooooooool0H?ooool2o`000004ooooool0003o0000ooooo`;o00003Oooool2o`00
00;ooooo0_l00002ooooo`;o00000_ooool2o`0000Gooooo1?l0000Zooooo`;o00001_ooool2o`00
00Gooooo0_l00022ooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o000000?oooooo`000?l0
00002?ooool2o`0000Cooooo1?l00002ooooo`;o00000_ooool2o`0000;ooooo0_l0000;ooooo`;o
00003_ooool2o`0001Kooooo0_l00007ooooo`Co00000_ooool2o`0000Gooooo0_l0000;ooooo`Co
00006?ooool2o`0005;ooooo000Looooo`03o`000?oooooooooo05Oooooo0_l000000ooooooo0000
o`00000Aooooo`;o00001?ooool2o`0000kooooo0_l00009ooooo`;o00002oooool2o`000003oooo
ool0003o000001oooooo1?l00009ooooo`?o00002?ooool7o`0001Oooooo0_l0001Booooo`007?oo
ool00ol0003oooooooooo`1Booooo`?o00000_ooool2o`000003ooooool0003o000000Sooooo0_l0
000Mooooo`;o00004Oooool2o`0000?ooooo0_l0000Jooooo`;o00001oooool2o`0000Kooooo0_l0
0002ooooo`?o00002?ooool2o`0000?ooooo0_l0001[ooooo`007?ooool00ol0003oooooooooo`1B
ooooo`?o00002oooool2o`0000;ooooo0_l0000Gooooo`;o000000?oooooo`000?l000001?ooool2
o`0000;ooooo0_l0000:ooooo`;o00000oooool2o`000003ooooool0003o000001;ooooo0_l00003
ooooo`Co00003Oooool2o`0000;ooooo0_l00005ooooo`;o00001_ooool4o`0006[ooooo000Loooo
o`03o`000?oooooooooo05?ooooo0_l0000;ooooo`;o00006oooool2o`000003ooooool0003o0000
00Cooooo0_l00002ooooo`;o00003oooool2o`000003ooooool0003o000000Kooooo0_l0000:oooo
o`;o00001?ooool4o`0000;ooooo0_l0000Cooooo`;o00001_ooool4o`0006[ooooo000Looooo`;o
0000JOooool5o`0001Cooooo0_l0000?ooooo`;o00004_ooool4o`0000_ooooo0_l000000ooooooo
0000o`000002o`0000;ooooo0_l00008ooooo`;o0000Ooooool001cooooo00?o0000ooooooooool0
IOooool2o`000003ooooool0003o000000?o00001?ooool2o`000003ooooool0003o000000_ooooo
0_l00002ooooo`;o00002oooool3o`0000Oooooo0_l00003ooooo`;o00001Oooool3o`0000Kooooo
0_l00002ooooo`;o00004Oooool2o`0001?ooooo0_l0001Zooooo`007?ooool00ol0003ooooooooo
o`1Gooooo`;o00001?ooool2o`0000Kooooo0_l0000:ooooo`;o000000Coooooo`000?l0003o0000
3_ooool2o`000003ooooool0003o000000Co00001Oooool2o`0000Oooooo0_l000000ooooooo0000
o`000002o`0000Kooooo0_l00006ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo
0_l00006ooooo`;o00003?ooool2o`0000Sooooo0_l0001Zooooo`007?ooool00ol0003ooooooooo
o`1Gooooo`;o00001?ooool2o`0000[ooooo0_l00009ooooo`?o00000oooool2o`0000cooooo1_l0
0005ooooo`Co00002?ooool2o`0000;ooooo0_l00008ooooo`;o00001Oooool6o`0000?ooooo1?l0
0004ooooo`;o00000_ooool2o`0000;ooooo0_l00002ooooo`Co00002?ooool2o`0006[ooooo000L
ooooo`03o`000?oooooooooo05cooooo0_l0000;ooooo`?o00001?ooool2o`0000;ooooo0ol00002
ooooo`?o00003_ooool2o`0000Wooooo0_l0000<ooooo`;o00002?ooool2o`0000Oooooo0_l00007
ooooo`Co00001_ooool2o`0000;ooooo0_l00002ooooo`;o00001_ooool2o`0000Oooooo0ol0001T
ooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00003_ooool2o`0000Gooooo0_l00005oooo
o`;o00001?ooool2o`0000;ooooo0ol00002ooooo`;o00001?ooool2o`0000Wooooo0_l00007oooo
o`;o0000;?ooool2o`0000Sooooo0_l0000:ooooo`Co000000Coooooo`000?l0003o00000oooool3
o`0006Cooooo000Looooo`03o`000?oooooooooo04cooooo0_l00007ooooo`;o00001?ooool2o`00
00Kooooo0_l0000;ooooo`;o00000oooool2o`0000Sooooo0_l00009ooooo`;o00001?ooool2o`00
0003ooooool0003o000000?ooooo0_l0000/ooooo`;o00000oooool2o`0000[ooooo0_l00003oooo
o`?o0000J_ooool001cooooo00?o0000ooooooooool0EOooool2o`0000Cooooo0_l0000Qooooo`;o
00000oooool2o`0000_ooooo0_l00006ooooo`;o00002Oooool2o`0000kooooo0_l00003ooooo`;o
00002Oooool2o`000003ooooool0003o000000?ooooo0_l0000?ooooo`;o00000_ooool2o`0000;o
oooo0_l0001Sooooo`007?ooool00ol0003oooooooooo`1Sooooo`;o00001_ooool3o`00013ooooo
0ol00002ooooo`;o000000Coooooo`000?l0003o00006_ooool2o`0000Cooooo0_l00004ooooo`;o
00000_ooool2o`0000?ooooo0_l00009ooooo`?o00001Oooool2o`0001?ooooo0_l000001?oooooo
0000o`000?l0001Sooooo`007?ooool00ol0003oooooooooo`19ooooo`?o00001Oooool2o`0000co
oooo0_l00002ooooo`;o00001_ooool3o`0000Cooooo1Ol00008ooooo`;o00000_ooool2o`000004
ooooool0003o0000o`0000Cooooo0_l0000Eooooo`;o00000oooool2o`0000Cooooo1_l0000?oooo
o`;o00007Oooool3o`0006?ooooo000Looooo`03o`000?oooooooooo04Wooooo0ol00005ooooo`;o
00001_ooool2o`0000Cooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`Ko
00000_ooool2o`0000Sooooo0_l000000ooooooo0000o`000005ooooo`;o00001_ooool2o`0000;o
oooo0_l000000ooooooo0000o`000006ooooo`Co00002Oooool4o`0000kooooo0ol000000ooooooo
0000o`000002ooooo`;o00001Oooool2o`000003ooooool0003o000000[ooooo0_l00003ooooo`?o
0000H?ooool001cooooo00?o0000ooooooooool0B?ooool2o`0000oooooo0_l00008ooooo`;o0000
0oooool2o`0000Oooooo0_l00006ooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000
o`00000=ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o00001Oooool2o`0000Go
oooo0_l00002ooooo`;o00004?ooool2o`0000;ooooo0_l00002ooooo`;o00001Oooool2o`000003
ooooool0003o000000[ooooo0_l00003ooooo`Go0000G_ooool001cooooo00?o0000ooooooooool0
A_ooool4o`0000Kooooo0_l0000Wooooo`;o00000_ooool2o`00023ooooo0_l00009ooooo`;o0000
00?oooooo`000?l000001?l0000@ooooo`;o00002oooool2o`0000Oooooo0_l0000;ooooo`;o0000
00?oooooo`000?l000001Oooool2o`0001?ooooo0_l00012ooooo`007?ooool00ol0003ooooooooo
o`16ooooo`;o00001?ooool2o`0000;ooooo0_l00003ooooo`?o00001oooool2o`0000;ooooo0_l0
0003ooooo`;o00002_ooool2o`0001Oooooo0_l0000:ooooo`;o00001_ooool2o`0000Oooooo0_l0
0003ooooo`;o00004_ooool3o`0000[ooooo0_l00002ooooo`?o00000_ooool2o`0000Kooooo0_l0
0007ooooo`Co00000_ooool2o`0001?ooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`1<
ooooo`;o00001oooool3o`0000Oooooo1_l00003ooooo`;o00002?ooool4o`0001Oooooo0_l00007
ooooo`;o000000?oooooo`000?l000001_ooool2o`0001Sooooo0_l00007ooooo`;o000000?ooooo
o`000?l000002?ooool2o`000004ooooool0003o0000o`0000[ooooo0_l00007ooooo`Ko0000FOoo
ool001cooooo00?o0000ooooooooool0D_ooool2o`0000;ooooo0_l00009ooooo`Go00003?ooool2
o`000003ooooool0003o000000Kooooo0_l00007ooooo`;o00001Oooool2o`0000Oooooo0_l00000
0ooooooo0000o`00000Pooooo`;o00002_ooool2o`0000?ooooo0_l00003ooooo`;o000000?ooooo
o`000?l000001oooool2o`0000;ooooo1?l00005ooooo`;o000000Coooooo`000?l0003o0000FOoo
ool001cooooo0_l0001Cooooo`;o00003oooool3o`0000Kooooo0_l000000ooooooo0000o`000004
ooooo`;o00001_ooool2o`0000Oooooo0_l0000>ooooo`;o000000?oooooo`000?l000003oooool2
o`00023ooooo0_l000000ooooooo0000o`000003ooooo`;o00001?ooool2o`000004ooooool0003o
0000o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000ooo
ool2o`0005Gooooo000Looooo`03o`000?oooooooooo05_ooooo0_l00006ooooo`?o00001_ooool2
o`000003ooooool0003o000000;o00007?ooool3o`0000;ooooo1_l000000ooooooo0000o`00000=
ooooo`;o00004Oooool2o`00013ooooo0_l00009ooooo`;o00000_ooool2o`0000Kooooo0_l00009
ooooo`?o0000EOooool001cooooo00?o0000ooooooooool0D_ooool3o`0000Kooooo0_l00007oooo
o`Co00002Oooool2o`00017ooooo0_l00008oooooa?o00003oooool5o`0000Sooooo0_l0000Hoooo
o`;o00000oooool2o`0001?ooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`19ooooo`;o
00000oooool2o`0000;ooooo1?l0000>ooooo`Co00002Oooool2o`0000Gooooo0ol00009ooooo`;o
00002?ooool2o`0000;ooooo1Ol00002ooooo`So00001Oooool6o`0000?ooooo1_l00002ooooo`;o
00003?ooool2o`00013ooooo0_l00003ooooo`;o0000Joooool001cooooo00?o0000ooooooooool0
BOooool4o`000003ooooool0003o000000Cooooo0_l0000>ooooo`;o00002oooool2o`0000Cooooo
1?l0000Gooooo`Ko000000?oooooo`000?l000000oooool2o`0000Kooooo1_l00003ooooo`;o0000
1_ooool2o`0000cooooo0_l0000@ooooo`Co00001?ooool2o`0000gooooo1?l0001Gooooo`007?oo
ool00ol0003oooooooooo`1;ooooo`;o00000oooool2o`0000Sooooo0_l000000ooooooo0000o`00
0002o`0000Sooooo0_l0000:ooooo`Co00005_ooool2o`000003ooooool0003o000000Co000000?o
ooooo`000?l000000ol00003ooooo`;o00002?ooool2o`00013ooooo0_l0000;ooooo`;o00002ooo
ool4o`0000Cooooo0_l0000=ooooo`Go00000_ooool2o`0001Kooooo0_l0000jooooo`007?ooool0
0ol0003oooooooooo`1@ooooo`;o00002?ooool2o`000003ooooool0003o000000;o00001Oooool2
o`000003ooooool0003o000000[ooooo0_l00003ooooo`;o00001oooool2o`0000Oooooo0_l00000
1?oooooo0000o`000?l00002ooooo`?o000000?oooooo`000?l000001Ol00002ooooo`Wo000000?o
ooooo`000?l000003oooool3o`0000;ooooo0_l00007ooooo`;o00004?ooool2o`0000?ooooo0_l0
0005ooooo`;o00001Oooool4o`0000;ooooo0_l0000Fooooo`;o0000>_ooool001cooooo00?o0000
ooooooooool0GOooool2o`0000Oooooo0_l0000Booooo`;o00001Oooool4o`0000Oooooo0_l00000
0ooooooo0000o`000005o`0000;ooooo1ol000001?oooooo0000o`000?ooool7o`000003ooooool0
003o000000Gooooo1?l00006ooooo`;o00000oooool2o`0000Oooooo0_l0000;ooooo`;o00000ooo
ool2o`0000?ooooo1Ol00002ooooo`;o00001Oooool2o`000003ooooool0003o000000;ooooo0_l0
00000ooooooo0000o`000009ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0COooool2
o`0000cooooo1Ol0000Qooooo`;o00000_ooool2o`0000Sooooo3ol000000ooooooo0000o`000005
o`000003ooooool0003o000000;ooooo0_l00005ooooo`Co000000?oooooo`000?l000002_ooool2
o`0000Gooooo0_l00007ooooo`;o00000_ooool2o`0000Gooooo0_l00003ooooo`?o00001_ooool2
o`0000Cooooo1_l000000ooooooo0000o`000009ooooo`;o0000@oooool001cooooo00?o0000oooo
ooooool0COooool2o`0000cooooo0_l000000ooooooo0000o`000002o`00013ooooo0_l0000Aoooo
o`;o00002_ooool2o`0000?ooooo2?l000000ooooooo0000o`000005o`000003ooooool0003o0000
00Kooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000[ooooo0_l00002oooo
o`;o000000Coooooo`000?l0003o00001_ooool3o`000003ooooool0003o000000Gooooo0_l00009
ooooo`;o000000?oooooo`000?l000001_ooool2o`0000;ooooo0_l0001?ooooo`007?ooool00ol0
003oooooooooo`17ooooo`;o00004_ooool2o`000003ooooool0003o000000;o00002Oooool3o`00
00Cooooo0_l0000Eooooo`Co00002Oooool2o`000003ooooool0003o000000_o000000?oooooo`00
0?l000000_l00004ooooo`;o00000oooool2o`0000_ooooo0_l00004ooooo`;o000000Coooooo`00
0?l0003o00001oooool2o`0001?ooooo0_l0000=ooooo`;o0000Coooool001cooooo00?o0000oooo
ooooool0Aoooool2o`0000_ooooo0_l00005ooooo`;o000000Coooooo`000?l0003o00002_ooool4
o`0001;ooooo0_l00005ooooo`Go00001_oooolCo`000003ooooool0003o000000;o000000?ooooo
o`000?l000004oooool2o`0000Gooooo1?l0000@ooooo`;o00002oooool2o`0000cooooo0_l0001@
ooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00004?ooool2o`0000?ooooo0_l00004oooo
o`;o00000oooool2o`0000Kooooo1?l0000:ooooo`;o00001Oooool2o`0000Gooooo0_l00004oooo
o`;o000000?oooooo`000?l000005Ol000000ooooooo0000o`000005o`0000?ooooo1?l0000=oooo
o`;o00000_ooool6o`0000Gooooo0_l00002ooooo`;o00000oooool3o`0001Gooooo0_l000001?oo
oooo0000o`000?l0001?ooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00002Oooool2o`00
01Gooooo0_l00004ooooo`;o00000oooool2o`0000Sooooo0_l00009ooooo`?o00002Oooool2o`00
00Cooooo3?l000000ooooooo0000o`00000Co`000003ooooool0003o000000?ooooo1?l0000=oooo
o`;o00001Oooool3o`0000Gooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o000000?ooooo
o`000?l000004oooool4o`000003ooooool0003o000000;o0000C_ooool001cooooo00?o0000oooo
ooooool0=oooool2o`00017ooooo0ol0000=ooooo`;o00000oooool3o`0001Oooooo1?l00005oooo
o`;o000000?oooooo`000?l000001?oooolRo`0001Oooooo0_l00006ooooo`;o00002?ooool2o`00
00;ooooo0_l000000ooooooo0000o`00000Cooooo`;o00000_ooool2o`000003ooooool0003o0000
04kooooo000Looooo`03o`000?oooooooooo04[ooooo0ol0000=ooooo`;o00001?ooool2o`0001Wo
oooo0_l000000ooooooo0000o`000004o`000004ooooool0003o0000o`0000;ooooo9Ol0000^oooo
o`;o000000?oooooo`000?l000003oooool2o`0000?ooooo0_l000000ooooooo0000o`00001>oooo
o`007?ooool2o`0004Wooooo0_l0000<ooooo`Co00003Oooool2o`0000gooooo0_l00006ooooo`Co
000000?oooooo`000?l000000ol00002ooooo`Co000000?oooooo`000?l000006Ol000000ooooooo
0000o`000002o`0000Sooooo0_l00009ooooo`;o00000oooool2o`0001Oooooo0_l00006ooooo`;o
000000Coooooo`000?l0003o00000oooool2o`0005Kooooo000Looooo`03o`000?oooooooooo04Oo
oooo0ol0000<ooooo`Co00001?ooool2o`0000;ooooo0_l00003ooooo`;o00003Oooool2o`0000_o
oooo0_l000000ooooooo0000o`000003ooooo`?o000000?oooooo`000?l000003ol000000ooooooo
0000o`00000;o`0000Wooooo0_l00009ooooo`;o00000oooool2o`000003ooooool0003o000001;o
oooo0_l00008ooooo`;o000000Coooooo`000?l0003o00001_ooool2o`0000Cooooo0_l0001=oooo
o`007?ooool00ol0003oooooooooo`17ooooo`;o00005Oooool2o`0000;ooooo0_l0000Dooooo`;o
00001Oooool2o`0000Cooooo0ol00005oooooaSo000000?oooooo`000?l000001_l0000Looooo`;o
00004_ooool2o`0000Gooooo0_l0000=ooooo`?o00000oooool2o`0000Wooooo0_l00012ooooo`00
7?ooool00ol0003oooooooooo`1eooooo`;o000000?oooooo`000?l000001Oooool2o`0000Cooooo
0_l00003oooooaoo00000_ooool3o`000004ooooool0003o0000ooooo`?o00003_ooool2o`00017o
oooo0_l00005ooooo`;o00001_ooool2o`0000?ooooo0_l00006ooooo`;o000000?oooooo`000?l0
00003_ooool2o`0004;ooooo000Looooo`03o`000?oooooooooo05Sooooo0_l0000Kooooo`;o0000
2?ooool2o`0000Cooooo0_l00003ooooob7o000000?oooooo`000?l000000ol000000ooooooo0000
o`000003o`0000cooooo0_l000000ooooooo0000o`00000>ooooo`;o00000_ooool5o`0000_ooooo
0_l000000ooooooo0000o`000002ooooo`?o00002?ooool4o`0004Wooooo000Looooo`03o`000?oo
oooooooo04Cooooo0_l0000Booooo`;o00006oooool2o`0000gooooo1?l00002ooooobGo00000_oo
ool6o`0000Kooooo0_l00005ooooo`Co00004_ooool4o`0000Kooooo0_l00007ooooo`;o00000_oo
ool2o`0000Wooooo1?l00019ooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00001?ooool3
o`0002oooooo1?l00003ooooo`;o00000_ooool9o`000003ooooool0003o000002So000000Cooooo
o`000?l0003ooooo0_l00003ooooo`;o00001Oooool2o`0001Kooooo0_l000000ooooooo0000o`00
0003ooooo`;o000000?oooooo`000?l000000_l00004ooooo`Co00003Oooool2o`0004Oooooo000L
ooooo`03o`000?oooooooooo03gooooo0_l00004ooooo`?o00001_ooool2o`0002Wooooo0_l00003
ooooo`;o00000_ooool4o`0000?ooooo8ol00005ooooo`So000000?oooooo`000?l000003oooool2
o`0001Cooooo0_l00004ooooo`Oo00000oooool2o`0000;ooooo0_l0000;ooooo`;o0000Aoooool0
01cooooo00?o0000ooooooooool0A?ooool2o`0000Gooooo0ol0000Yooooo`;o00003OoooolUo`00
0003ooooool0003o000000?o00000oooool2o`0001?ooooo0_l0000<ooooo`;o00003?ooool4o`00
0004ooooool0003o0000ooooo`;o00001?ooool2o`0005Cooooo000Looooo`03o`000?oooooooooo
04_ooooo1?l0000Xooooo`;o00003?oooolDo`0000;ooooo4?l000000ooooooo0000o`000003o`00
00?ooooo0ol000000ooooooo0000o`00000Eooooo`;o00000_ooool2o`0000;ooooo0_l00004oooo
o`;o00001oooool2o`0000Gooooo0_l00007ooooo`;o0000DOooool001cooooo00?o0000oooooooo
ool0<oooool2o`0001Sooooo0_l0000]ooooo`;o000000?oooooo`000?l000000_l000001?oooooo
0000o`000?l00002oooooa7o000000?oooooo`000?l000004?l00002ooooo`;o000000?oooooo`00
0?l000000ol000000ooooooo0000o`000008ooooo`;o00001oooool2o`0000;ooooo0_l00002oooo
o`Co00001_ooool2o`0000;ooooo0_l00002ooooo`;o00002?ooool2o`000003ooooool0003o0000
00;ooooo0_l00007ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0<oooool2o`0000[o
oooo0ol0000jooooo`Oo000000?oooooo`000?l000000ooooolXo`000003ooooool0003o000000;o
00003?ooool2o`0000Oooooo0_l00007ooooo`Oo00001_ooool2o`000004ooooool0003o0000o`00
00Sooooo0_l000000ooooooo0000o`000004o`0000Kooooo0ol000000ooooooo0000o`000015oooo
o`007?ooool00ol0003oooooooooo`0iooooo`;o00001?ooool3o`000003ooooool0003o000002co
oooo0_l00009ooooo`?o00001oooool2o`000004ooooool0003o0000ooooobKo000000?oooooo`00
0?l000001Oooool2o`0001;ooooo0_l00002ooooo`Co000000?oooooo`000?l000000_l00009oooo
o`?o000000?oooooo`000?l000001oooool2o`000003ooooool0003o000000Co00001?ooool2o`00
00;ooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`0gooooo`Co00001Oooool2o`000003
ooooool0003o000002cooooo0_l0000?ooooo`;o00000_ooool2o`000003ooooool0003o000002Oo
000000?oooooo`000?l000000_l00002ooooo`?o00004_ooool3o`000003ooooool0003o000000;o
oooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l000001?oooooo0000o`000?ooool2
o`0000Oooooo0_l000001?oooooo0000o`000?ooool3o`0000Gooooo0_l0000Kooooo`;o0000:ooo
ool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413ooooo
ooooo`04ooooo`03o`000?oooooooooo02oooooo0_l00006ooooo`;o000000?oooooo`000?l00000
0oooool2o`000003ooooool0003o000000;o00002Oooool2o`00033ooooo0ol000000ooooooo0000
o`00000/o`000004ooooool0003o0000o`0000;ooooo0_l0000Dooooo`;o000000?oooooo`000?l0
00000_ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000000ol0000@oooo
o`Go00001_ooool2o`0001_ooooo0_l0000[ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5
ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02oooooo0_l00009
ooooo`;o00000oooool2o`000003ooooool0003o000000;o00002Oooool2o`00033ooooo0_l00002
ooooo`Oo000000?oooooo`000?l000007_l000000ooooooo0000o`000003o`000004ooooool0003o
0000o`0001Cooooo0_l00005ooooo`Co00000oooool2o`000004ooooool0003o0000ooooo`Co0000
1_ooool2o`0000[ooooo0_l00007ooooo`;o0000BOooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02Oooool5o`0000Kooooo00?o0000ooooooooool0?Oooool2o`0000Gooooo0_l0
0002ooooo`;o0000:oooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool7o`000003ooooool0
003o000000Ko000000?oooooo`000?l000007_l000000ooooooo0000o`000008ooooo`;o00000_oo
ool2o`0000;ooooo0_l00003ooooo`;o00000oooool6o`0000Kooooo0_l00004ooooo`;o00001?oo
ool3o`0001;ooooo0ol00019ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09
ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0000mooooo`;o00001?ooool3o`0000;ooooo0_l0
0007ooooo`?o00007Oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo1ol0
00000ooooooo0000o`000007o`000003ooooool0003o000000?o000000?oooooo`000?l000005ol0
0008ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00004ooooo`;o00000_oo
ool4o`0000[ooooo0ol000000ooooooo0000o`000004ooooo`;o00001?ooool2o`0000gooooo0ol0
00000ooooooo0000o`00000<ooooo`;o0000>?ooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool02Oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo03kooooo0_l0
00000ooooooo0000o`000004o`0000[ooooo0ol0000Mooooo`;o00001Oooool2o`0000Sooooo0_l0
0003ooooo`Ko000000?oooooo`000?l000007Ol000000ooooooo0000o`000002o`0000Wooooo0_l0
00000ooooooo0000o`00000:ooooo`Co00001_ooool2o`0000Kooooo1ol0000;ooooo`;o00004Ooo
ool3o`0000_ooooo0_l0000hooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:
ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0?_ooool2o`000003ooooool0003o
000000;ooooo1?l0000_ooooo`;o00002?ooool2o`0000;ooooo1_l00003oooooago000000?ooooo
o`000?l000000ol00009ooooo`;o000000Coooooo`000?l0003o00001_ooool2o`000003ooooool0
003o000000Sooooo0_l00006ooooo`Co000000?oooooo`000?l000001_ooool2o`0000?ooooo0_l0
0006ooooo`;o00002_ooool2o`0004Gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo
00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0eooooo`;o00002?ooool2o`0000Kooooo
0_l0000booooo`;o00002Oooool6o`000003ooooool0003o000002;o00002_ooool2o`0000;ooooo
0ol000000ooooooo0000o`000002ooooo`;o00002oooool2o`0000Kooooo1?l00009ooooo`;o0000
00?oooooo`000?l000000_l00006ooooo`Co00002oooool2o`0004;ooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`0dooooo`?o
00002?ooool2o`0001;ooooo0_l0000Vooooo`;o00002OoooolSo`000003ooooool0003o000000Co
00001?ooool3o`0000Cooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l0000Booooo`;o
000000?oooooo`000?l000003_ooool2o`0000?ooooo0_l00005ooooo`;o00002_ooool5o`0001Oo
oooo0_l0000Wooooo`007?ooool00ol0003oooooooooo`0dooooo`;o00002Oooool2o`0001;ooooo
0_l0000@ooooo`Co00003_ooool2o`0000_ooooo0_l00002oooooa[o000000Coooooo`000?l0003o
00001?ooool2o`000004ooooool0003o0000o`0000?ooooo1?l00009ooooo`;o000000?oooooo`00
0?l000000_l00005ooooo`;o00000_ooool2o`0000Oooooo0_l0000@ooooo`;o00001?ooool3o`00
00Cooooo0_l0000:ooooo`;o000000?oooooo`000?l000005oooool2o`0002Oooooo000Looooo`03
o`000?oooooooooo04gooooo0_l00002ooooo`;o00004_ooool4o`0000Gooooo0_l00007ooooo`;o
00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002oooooaOo00000oooool4o`0000?o
oooo0_l00002ooooo`;o00000oooool5o`0000Wooooo0_l000000ooooooo0000o`000007ooooo`;o
00000_ooool2o`0001Kooooo0_l000000ooooooo0000o`000005ooooo`;o0000EOooool001cooooo
00?o0000ooooooooool0>?ooool2o`000003ooooool0003o000000[ooooo0_l00004ooooo`;o0000
0_ooool2o`0001_ooooo0_l0000;ooooo`Co00000_ooool2o`000003ooooool0003o000000;ooooo
0_l000001Ooooooo0000o`000?l0003ooooo01;o000000?oooooo`000?l000000_l00003ooooo`Go
00000oooool3o`0000[ooooo0_l000000ooooooo0000o`000007ooooo`;o00002Oooool4o`0000?o
oooo0_l00004ooooo`;o00000_ooool4o`0000Cooooo0_l0000Looooo`;o0000>oooool001cooooo
00?o0000ooooooooool0:?ooool2o`0000kooooo0_l000000ooooooo0000o`00000:ooooo`;o0000
4Oooool2o`000004ooooool0003o0000o`0000Gooooo0_l0000Dooooo`;o00000oooool3o`0000Co
oooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l0
00002ol000001?oooooo0000o`000?ooool6o`0000?ooooo1?l000000ooooooo0000o`000006oooo
o`Go00001oooool2o`0000;ooooo0_l00004ooooo`Go00000_ooool3o`0000Cooooo0_l00002oooo
o`;o00001_ooool2o`0000Wooooo0_l0000Aooooo`;o0000>oooool001cooooo00?o0000oooooooo
ool0:?ooool2o`00017ooooo0_l0000Mooooo`;o000000Coooooo`000?l0003o00000oooool6o`00
01;ooooo0_l00003ooooo`?o000000?oooooo`000?l000000ol00002ooooo`Ko00000_oooolAo`00
0004ooooool0003o0000ooooo`;o000000?oooooo`000?l000000ol00003ooooo`;o000000?ooooo
o`000?l000001Oooool4o`000003ooooool0003o000000Kooooo0_l00002ooooo`;o00001?ooool2
o`0000Gooooo0ol0000Aooooo`;o00002?ooool2o`0000Cooooo0_l00008ooooo`;o0000?_ooool0
01cooooo00?o0000ooooooooool0<oooool2o`0000Kooooo0_l0000Jooooo`;o00002_ooool2o`00
0004ooooool0003o0000o`0001Kooooo0_l00002ooooo`Go000000?oooooo`000?l000000_oooolG
o`0000?ooooo0_l00002ooooo`Go00001?ooool2o`0000?ooooo0_l00002ooooo`Oo00000oooool2
o`0001Cooooo0_l00003ooooo`?o00002_ooool2o`0000Gooooo1Ol00002ooooo`Co00001oooool3
o`0003kooooo000Looooo`03o`000?oooooooooo03?ooooo0_l0000>ooooo`?o00000oooool2o`00
00Sooooo1_l00005ooooo`?o00000_ooool2o`000003ooooool0003o000001Oooooo0_l00002oooo
o`;o000000Coooooo`000?l0003ooooo0ol00005ooooo`Ko000000?oooooo`000?l000002_l00000
0ooooooo0000o`000002o`0000;ooooo1Ol00004ooooo`Co000000?oooooo`000?l000001Oooool3
o`0000Cooooo0_l00006ooooo`;o00001oooool2o`0000;ooooo0ol00003ooooo`?o00002_ooool2
o`0000Gooooo1_l000000ooooooo0000o`000009ooooo`;o00000_ooool2o`0003_ooooo000Loooo
o`03o`000?oooooooooo03Wooooo0ol00007ooooo`So00002?ooool4o`000003ooooool0003o0000
00;ooooo2Ol0000Dooooo`;o00002?ooool3o`0000Cooooo1_l000001?oooooo0000o`000?ooool7
o`0000;ooooo1?l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l000000ooooooo0000o`00
0002o`0000?ooooo1Ol00008ooooo`Co00000oooool2o`0000Gooooo0ol00003ooooo`;o000000Co
ooooo`000?l0003o00000_ooool2o`0000?ooooo0_l0000Cooooo`?o000000?oooooo`000?l00000
4?ooool2o`0003_ooooo000Looooo`03o`000?oooooooooo03Cooooo0ol00002ooooo`?o00001?oo
ool2o`0000Cooooo1?l0000>ooooo`;o00000_ooool2o`0000?ooooo0_l000001?oooooo0000o`00
0?l0000:ooooo`;o00001_ooool2o`0000Oooooo1?l00006ooooo`oo00000oooool3o`000003oooo
ool0003o000000;o00000oooool7o`0000?ooooo0_l0000<ooooo`?o00000_ooool2o`0000Kooooo
0_l00004ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`000003ooooool0003o000000;o
oooo0ol00002ooooo`?o00002Oooool2o`0001Cooooo0_l000000ooooooo0000o`00000>ooooo`;o
0000:?ooool001cooooo00?o0000ooooooooool0=?ooool3o`0000Wooooo0_l00006ooooo`;o0000
4Oooool2o`0000?ooooo0_l00002ooooo`?o00002?ooool4o`0000Gooooo0_l00008ooooo`;o0000
0oooool3o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000001ol000000ooooooo0000
o`000002o`000003ooooool0003o000000;o00000oooool3o`000003ooooool0003o000000;ooooo
0_l00008ooooo`;o00000oooool4o`0000;ooooo0_l00002ooooo`;o00002?ooool2o`0000;ooooo
1?l00002ooooo`;o000000?oooooo`000?l000001Ol00002ooooo`?o00002Oooool2o`0000Oooooo
0_l0000;ooooo`;o000000?oooooo`000?l000003_ooool2o`0002Sooooo000Looooo`03o`000?oo
oooooooo03Cooooo0_l00002ooooo`;o00002oooool2o`000003ooooool0003o0000017ooooo0_l0
0003ooooo`;o00003Oooool2o`0000Oooooo0_l00004ooooo`Oo00000_ooool7o`000004ooooool0
003o0000ooooo`[o000000?oooooo`000?l000000_l000000ooooooo0000o`000004o`000005oooo
ool0003o0000o`000?ooool00_l00002ooooo`;o00002?ooool9o`000003ooooool0003o000000;o
000000?oooooo`000?l000003Oooool3o`0000Oooooo0_l00006ooooo`;o00000_ooool2o`0000Go
oooo0ol00006ooooo`;o00003_ooool2o`0003Sooooo000Looooo`;o0000<?ooool2o`0000;ooooo
0ol00002ooooo`;o00000_ooool2o`0000Oooooo0_l0000?ooooo`;o00001?ooool2o`00023ooooo
1ol00005ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000004o`0000Wooooo
0_l00002ooooo`?o00000_ooool2o`0000Oooooo0_l00003ooooo`;o00000_ooool=o`0000;ooooo
0_l0000<ooooo`;o00004Oooool2o`000003ooooool0003o000000Kooooo0_l000000ooooooo0000
o`00000<ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0;Oooool4o`0000;ooooo0_l0
0007ooooo`;o00001_ooool2o`00013ooooo0_l00004ooooo`?o00001?ooool2o`0000;ooooo0_l0
00000ooooooo0000o`00000<ooooo`;o00000oooool2o`0000;ooooo1ol000000ooooooo0000o`00
0002ooooo`;o00001Oooool2o`0000;ooooo0_l00007ooooo`;o00000_ooool2o`0000Kooooo0_l0
0004ooooo`;o00000oooool6o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo
0_l0000:ooooo`?o00000_ooool2o`0000kooooo0_l00007ooooo`;o00000oooool2o`0000Cooooo
0_l00006ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0;Oooool2o`0001;ooooo0_l0
00000ooooooo0000o`00000=ooooo`Co00001_ooool2o`0000Cooooo0_l00002ooooo`;o000000Co
ooooo`000?l0003ooooo0_l00009ooooo`;o00000oooool2o`000004ooooool0003o0000o`0000;o
oooo0ol000001?oooooo0000o`000?ooool2o`0000Kooooo0_l00002ooooo`;o00001?ooool2o`00
00;ooooo0_l00003ooooo`;o00001?ooool2o`0000_ooooo0_l00002ooooo`;o00002Oooool2o`00
00Kooooo0_l00004ooooo`?o00000_ooool2o`0000?ooooo1?l00003ooooo`;o00001_ooool2o`00
00?ooooo0_l00009ooooo`;o00001_ooool2o`0003oooooo000Looooo`03o`000?oooooooooo047o
oooo0_l0000<ooooo`;o00000_ooool4o`0000_ooooo0_l00006ooooo`So00002Oooool2o`0000?o
oooo0_l00004ooooo`;o00001?ooool2o`0000Oooooo0_l00007ooooo`;o00000_ooool2o`000003
ooooool0003o000000;o00002oooool2o`0000;ooooo1?l00002ooooo`Co00001oooool4o`0000Co
oooo0_l00005ooooo`?o000000?oooooo`000?l000000oooool4o`0000?ooooo1_l00002ooooo`;o
00003?ooool2o`0000kooooo0_l000000ooooooo0000o`00000fooooo`007?ooool00ol0003ooooo
ooooo`0jooooo`;o00001Oooool2o`0000cooooo0_l00008ooooo`;o00001_ooool5o`000003oooo
ool0003o000000Co00000_ooool3o`0000Wooooo0_l00003ooooo`;o00001?ooool2o`0000Cooooo
0_l00007ooooo`;o00003_ooool2o`0000gooooo0_l00002ooooo`Co00000_ooool4o`0000Cooooo
1ol00004ooooo`;o00001Oooool3o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o0000
1?ooool5o`0000oooooo1?l000000ooooooo0000o`000009ooooo`Go0000=_ooool001cooooo00?o
0000ooooooooool0>_ooool2o`000003ooooool0003o000001[ooooo0_l00006ooooo`Go000000?o
ooooo`000?l000002_l00004ooooo`;o00004oooool2o`0000Oooooo0_l0000:ooooo`;o00002?oo
ool2o`0000?ooooo0_l0000<ooooo`Co00001?ooool7o`0000Cooooo1?l0000;ooooo`;o00000_oo
ool4o`0000;ooooo1Ol00007ooooo`;o00002?ooool2o`000003ooooool0003o000000;ooooo1?l0
0003ooooo`Co0000=oooool001cooooo00?o0000ooooooooool0>_ooool2o`000003ooooool0003o
000000Wooooo0_l0000:ooooo`;o000000?oooooo`000?l000000_oooolJo`0000;ooooo0_l00005
ooooo`;o00001oooool2o`0000?ooooo0_l00008ooooo`;o00002Oooool2o`0000Oooooo0ol00003
ooooo`Co00001oooool2o`0000Kooooo0_l00004ooooo`;o00002?ooool2o`000003ooooool0003o
000000Oooooo1Ol000000ooooooo0000o`000003o`0000;ooooo0_l000000ooooooo0000o`000005
ooooo`;o00000_ooool2o`0000_ooooo1?l00003ooooo`Co00003_ooool2o`0002Oooooo000Loooo
o`03o`000?oooooooooo03Cooooo0_l0000Booooo`;o00001?ooool4o`0000;ooooo0_l000000ooo
oooo0000o`000002oooooaOo000000?oooooo`000?l000000_ooool2o`0000Gooooo0ol00003oooo
o`;o000000?oooooo`000?l000003Oooool2o`0000Gooooo0_l0000;ooooo`;o00001_ooool3o`00
0003ooooool0003o000000?ooooo0_l00005ooooo`Go00003oooool2o`0000Kooooo3?l00002oooo
o`;o000000?oooooo`000?l000002Oooool2o`0000Cooooo0_l00007ooooo`;o00001Oooool2o`00
00kooooo0_l0000Wooooo`007?ooool00ol0003oooooooooo`0dooooo`;o00001Oooool2o`00017o
oooo1?l00004ooooo`;o00000ooooolEo`000003ooooool0003o000000So00001?ooool2o`0000?o
oooo0_l0000=ooooo`;o000000?oooooo`000?l000001Oooool2o`000003ooooool0003o000000Wo
oooo0_l00006ooooo`;o000000?oooooo`000?l000001_ooool2o`0000;ooooo0_l000001?oooooo
0000o`000?l0000?ooooo`Co00000oooool8o`0000;ooooo0ol000000ooooooo0000o`00000Boooo
o`;o00001?ooool2o`000003ooooool0003o000000Kooooo0_l0000fooooo`007?ooool00ol0003o
ooooooooo`0kooooo`;o00002oooool2o`000003ooooool0003o000000;ooooo0_l00005ooooo`;o
000000?oooooo`000?l000005Ol000000ooooooo0000o`000008o`0000?ooooo0_l00003ooooo`?o
00003Oooool3o`0000Gooooo0_l00003ooooo`;o00002Oooool2o`00017ooooo0_l000000ooooooo
0000o`000003ooooo`;o00001Oooool2o`0000?ooooo0_l00003ooooo`Co00000_ooool>o`0001Go
oooo0_l00004ooooo`;o00002Oooool2o`0003Kooooo000Looooo`03o`000?oooooooooo04;ooooo
0_l00003ooooo`?o000000?oooooo`000?l000000_ooool4o`0000Gooooo4ol000000ooooooo0000
o`000002o`0000;ooooo0_l00003ooooo`;o00001Oooool2o`0000?ooooo1?l00002ooooo`;o0000
0oooool2o`0000Cooooo0_l00005ooooo`;o00002oooool2o`0000gooooo0_l00003ooooo`;o0000
0oooool2o`0000[ooooo0_l000000ooooooo0000o`000002o`0000Sooooo3_l0000=ooooo`;o0000
1oooool2o`0000?ooooo0_l0000:ooooo`;o0000=_ooool001cooooo00?o0000ooooooooool0@_oo
ool2o`0000?ooooo0_l00004ooooo`;o00000_ooool2o`0000Gooooo0_l00002ooooo`[o000000?o
ooooo`000?l000000_l000000ooooooo0000o`000009o`000003ooooool0003o000000Cooooo0_l0
0005ooooo`;o00000_ooool2o`0000?ooooo0_l0000Hooooo`;o00001Oooool3o`0000Gooooo0_l0
0003ooooo`Co000000Coooooo`000?l0003o00001oooool2o`0000?ooooo0_l00009oooooa7o0000
2oooool2o`0000Oooooo0_l00003ooooo`;o00002_ooool3o`0003Gooooo000Looooo`03o`000?oo
oooooooo043ooooo0_l00005ooooo`;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`00
0002ooooo`Go00000_oooolHo`000003ooooool0003o000000Cooooo0_l00009ooooo`;o00001_oo
ool2o`0000Cooooo0_l00009ooooo`;o00002oooool3o`0000;ooooo0_l00008ooooo`Ko00001ooo
ool4o`0000Oooooo0_l000000ooooooo0000o`00000Ao`0000Oooooo1?l0000>ooooo`;o00002ooo
ool2o`0003Gooooo000Looooo`03o`000?oooooooooo043ooooo0_l00003ooooo`;o00000_ooool2
o`0000Cooooo0_l00003ooooo`;o00000_ooool5o`0000;ooooo5?l000001Ooooooo0000o`000?l0
003ooooo00Ko00004oooool2o`0000Cooooo0_l00009ooooo`Co00003_ooool2o`0000;ooooo0_l0
0003ooooo`Go00002oooool2o`000003ooooool0003o000000Cooooo2ol000000ooooooo0000o`00
0008o`0000Oooooo1?l0000Jooooo`;o0000=_ooool001cooooo00?o0000ooooooooool0AOooool2
o`0000;ooooo1?l00002ooooo`?o00001_oooolLo`000004ooooool0003o0000ooooo`Ko00004_oo
ool2o`0001;ooooo0_l0000?ooooo`Go00000oooool2o`0000;ooooo0_l0000=ooooo`?o00000ooo
oolFo`0002Gooooo0_l0000fooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o00000oooool2
o`0000Gooooo4ol000000ooooooo0000o`000007o`0000Gooooo1?l00005ooooo`;o00001_ooool2
o`0000Cooooo0_l0000Rooooo`So00001Oooool2o`0000kooooo0_l00003oooooaKo0000GOooool0
01cooooo0_l0000gooooo`;o00002oooool2o`0000[ooooo0ol000001?oooooo0000o`000?oooolP
o`0000?ooooo1?l00005ooooo`;o00000oooool2o`000003ooooool0003o000000cooooo0_l0000F
ooooo`;o00000_ooool8o`0000?ooooo0_l0000Eooooo`Oo000000?oooooo`000?l000003?l0000O
ooooo`;o0000??ooool001cooooo00?o0000ooooooooool0=_ooool2o`0000_ooooo0_l0000:oooo
o`;o00000_ooool2o`000003ooooool0003o000000_o000000?oooooo`000?l000004?l0000Aoooo
o`;o00003Oooool4o`0000Gooooo0_l00002ooooo`?o00002_ooool2o`000004ooooool0003o0000
ooooo`Ko00000oooool2o`000003ooooool0003o0000013ooooo0_l000000ooooooo0000o`00000C
o`0001oooooo0_l0000looooo`007?ooool00ol0003oooooooooo`0[ooooo`;o00002Oooool2o`00
00[ooooo0ol0000=ooooo`?o000000?oooooo`000?l000002Ol000000ooooooo0000o`00000Fo`00
01cooooo0_l000000ooooooo0000o`000002ooooo`Go000000Coooooo`000?l0003o00001oooool2
o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000001_l00003ooooo`Co00003ooo
oolGo`0000;ooooo0_l00003ooooo`Co0000Doooool001cooooo00?o0000ooooooooool0:oooool2
o`0000Wooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo0_l00009
ooooobWo00003Oooool2o`000003ooooool0003o000000_ooooo1Ol000000ooooooo0000o`000003
o`0000_ooooo2?l000000ooooooo0000o`000004ooooo`;o00000oooool4o`00013ooooo5ol00000
1?oooooo0000o`000?l00002ooooo`Co0000Doooool001cooooo00?o0000ooooooooool0>_ooool2
o`0000?ooooo0_l00005ooooo`;o00002OoooolUo`0000Cooooo0_l00004ooooo`?o00001?ooool5
o`0000Wooooo1?l000000ooooooo0000o`000002ooooo`;o00003_ooool3o`000004ooooool0003o
0000o`00023ooooo5ol00002ooooo`;o00005_ooool2o`0000Sooooo0_l0000gooooo`007?ooool0
0ol0003oooooooooo`0kooooo`Co00000_ooool2o`00017ooooo1ol000000ooooooo0000o`00000H
o`0000Cooooo0_l00004ooooo`?o00001Oooool2o`0000_ooooo0_l00005ooooo`;o00001_ooool3
o`0000?ooooo0_l00002ooooo`;o00004?ooool2o`0000Wooooo0_l0000:ooooo`Co000000?ooooo
o`000?l000003Ol0000Hooooo`;o000000?oooooo`000?l000002?ooool2o`0000kooooo0_l0000W
ooooo`007?ooool00ol0003oooooooooo`0kooooo`Co00000_ooool2o`00017ooooo9?l000000ooo
oooo0000o`00000Cooooo`;o00002?ooool2o`0000;ooooo0_l00005ooooo`Co00000oooool2o`00
01Cooooo0_l00002ooooo`;o00001Oooool2o`0000[ooooo5_l0000Booooo`;o000000Coooooo`00
0?l0003o00006oooool2o`0002Oooooo000Looooo`03o`000?oooooooooo053ooooo0_l00003oooo
oaco00000_ooool5o`000003ooooool0003o000000Oooooo0_l0000:ooooo`;o00000_ooool2o`00
00Cooooo0_l00009ooooo`Co00001Oooool2o`0001Kooooo0_l0000<ooooo`;o00000ooooolCo`00
0003ooooool0003o000001;ooooo0_l000000ooooooo0000o`000005ooooo`;o000000?oooooo`00
0?l000001?ooool2o`0003Gooooo000Looooo`03o`000?oooooooooo03_ooooo0_l00005ooooo`;o
00000oooool3o`0000Kooooo0_l00003ooooo`;o00000_oooolNo`0000;ooooo0_l00002ooooo`;o
00000oooool2o`0000Gooooo0_l00007ooooo`;o00004?ooool3o`000003ooooool0003o000000Go
00007oooool2o`0000;ooooo1?l00002oooooa;o00007oooool2o`000003ooooool0003o000000Co
oooo0_l0000eooooo`007?ooool00ol0003oooooooooo`0kooooo`;o00001Oooool4o`000004oooo
ool0003o0000o`0000Kooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo6_l00004oooo
o`;o00000_ooool2o`0000Cooooo0_l00004ooooo`;o00003_ooool2o`0000Cooooo0_l00004oooo
o`[o00006Oooool3o`0000?ooooo0_l00002ooooo`Co00000_ooool<o`000003ooooool0003o0000
00;o00001Oooool2o`0005Wooooo000Looooo`03o`000?oooooooooo03_ooooo0_l00002ooooo`;o
00000oooool2o`00017ooooo0ol000000ooooooo0000o`00000Io`0000gooooo0_l0000Dooooo`;o
00000oooool4o`0000?ooooo1ol0000Looooo`?o00003_ooool2o`000003ooooool0003o000000Ko
000000?oooooo`000?l000000_l00005ooooo`;o0000:Oooool2o`0002kooooo000Looooo`03o`00
0?oooooooooo02kooooo0_l0000;ooooo`;o00000_ooool2o`0000;ooooo0_l0000:ooooo`;o0000
1_ooool2o`0000?ooooo6_l0000Kooooo`;o00000_ooool2o`0000Oooooo1?l00004ooooo`[o0000
0oooool4o`0000Cooooo0_l00004ooooo`;o00005_ooool7o`000004ooooool0003o0000o`0000oo
oooo0_l000000ooooooo0000o`000003o`0000Cooooo0_l00005ooooo`;o00002?ooool2o`0000Oo
oooo0_l0000^ooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00004oooool2o`0000[ooooo
0_l0000=ooooo`co000000?oooooo`000?l000001_l0000Fooooo`;o00001_ooool2o`0000;ooooo
0_l00003ooooo`Ko00001_ooool2o`0000;ooooo1_l00003ooooo`Co00001?ooool2o`0000Cooooo
0_l0000;ooooo`;o00002_ooool6o`0000Cooooo0_l000000ooooooo0000o`000002o`0000Sooooo
0_l000000ooooooo0000o`000003o`0000Cooooo0_l00005ooooo`;o00000_ooool4o`0000;ooooo
0_l0000gooooo`007?ooool00ol0003oooooooooo`10ooooo`;o000000?oooooo`000?l000004ooo
ool3o`0000;ooooo5?l0000Hooooo`;o00002Oooool2o`0000Cooooo1?l0000>ooooo`;o00008?oo
ool2o`0000gooooo0_l00002ooooo`[o000000?oooooo`000?l000001_ooool2o`0000;ooooo0_l0
0008ooooo`;o00001_ooool4o`0003_ooooo000Looooo`03o`000?oooooooooo03Oooooo0_l00007
ooooo`;o00001oooool2o`0000gooooo0ol000000ooooooo0000o`00000@o`000003ooooool0003o
000002;ooooo0ol0000<ooooo`;o00004Oooool2o`0001Gooooo0_l0000;ooooo`Go00000oooool4
o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000001_ooool2o`0000cooooo0_l0
0007ooooo`;o0000??ooool001cooooo00?o0000ooooooooool0=oooool2o`0000Oooooo0_l00007
ooooo`;o00002?ooool2o`0000?ooooo0_l00002ooooo`;o00001?ooool6o`000003ooooool0003o
000000?o000000?oooooo`000?l000000_ooool2o`0001kooooo0_l00003ooooo`;o00002?ooool2
o`00017ooooo0_l0000Eooooo`;o00001_ooool2o`0000?ooooo1ol0000Qooooo`;o00000_ooool2
o`0000Cooooo0_l0000looooo`007?ooool2o`0004oooooo0_l00003ooooo`?o00000_ooool2o`00
00;ooooo0_l00003ooooo`;o000000?oooooo`000?l000001Ol00003ooooo`?o00000_ooool2o`00
01oooooo0_l00002ooooo`;o00001?ooool2o`0000?ooooo0_l0000?ooooo`;o00001Oooool2o`00
00?ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Oooooo0_l00003oooo
o`;o00000_ooool3o`000003ooooool0003o000000;ooooo0_l0000Jooooo`;o00000_ooool2o`00
00Kooooo0_l0000=ooooo`;o0000:oooool001cooooo00?o0000ooooooooool0Aoooool2o`0000Go
oooo0_l00002ooooo`Ko00000oooool3o`0000?ooooo1?l000000ooooooo0000o`000003o`0000?o
oooo0_l0000Nooooo`;o00001?ooool2o`0000Sooooo0_l00003ooooo`;o00003oooool2o`0000Go
oooo0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo0_l00009ooooo`;o
00002Oooool2o`0000;ooooo0_l0000<ooooo`;o00006?ooool2o`0000Sooooo0_l00003ooooo`;o
0000:oooool001cooooo00?o0000ooooooooool0@_ooool2o`0000?ooooo0_l00005ooooo`;o0000
0_ooool2o`0000;ooooo0_l00003ooooo`?o00001?ooool3o`000003ooooool0003o000000Sooooo
0_l0000Looooo`Ko00000_ooool2o`0000?ooooo0ol0000Jooooo`;o00000_ooool2o`0001Sooooo
0_l00005ooooo`;o00005?ooool2o`0000Gooooo0_l0000Kooooo`;o0000<?ooool001cooooo00?o
0000ooooooooool0>?ooool2o`0000Cooooo0_l00002ooooo`?o00002Oooool2o`0000?ooooo0_l0
0007ooooo`;o00001?ooool6o`0000Sooooo0_l0000Mooooo`Go00000_ooool2o`0000?ooooo0ol0
000<ooooo`;o00001?ooool2o`0000Kooooo0_l00002ooooo`;o000000?oooooo`000?l000004_oo
ool2o`0000Sooooo0_l0000Booooo`;o00001_ooool3o`0000kooooo0_l00002ooooo`;o0000>Ooo
ool001cooooo00?o0000ooooooooool0>?ooool2o`0000Cooooo0_l00003ooooo`;o00003_ooool2
o`0000_ooooo1_l0000:ooooo`;o00000_ooool2o`0000gooooo0_l0000:ooooo`;o00002oooool3
o`0000_ooooo0_l00004ooooo`;o00001_ooool3o`000004ooooool0003o0000ooooo`?o00000_oo
ool2o`0000Kooooo0ol00003ooooo`?o000000?oooooo`000?l000004Oooool2o`0000Kooooo0_l0
0006ooooo`;o00003oooool2o`0000;ooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`0c
ooooo`;o00002_ooool2o`0001oooooo1?l0000?ooooo`?o00003Oooool2o`0001Cooooo0_l00002
ooooo`;o000000?oooooo`000?l000000oooool2o`0000Wooooo0_l00004ooooo`Go00001Oooool2
o`000003ooooool0003o000000oo00000_ooool2o`00017ooooo1?l0000=ooooo`;o00000_ooool2
o`0000[ooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00002_ooool2o`00
00?ooooo0_l00008ooooo`;o00002Oooool2o`0000Oooooo1_l00004ooooo`;o00001Oooool2o`00
01kooooo0_l00004ooooo`;o00001Oooool2o`0000?ooooo0_l00009ooooo`;o00000oooool5o`00
00Wooooo4Ol0000Gooooo`;o00003Oooool2o`0000;ooooo0_l0000:ooooo`;o00001oooool2o`00
03Cooooo000Looooo`03o`000?oooooooooo03oooooo0_l00003ooooo`;o00000_ooool2o`000004
ooooool0003o0000ooooo`;o00002Oooool4o`000003ooooool0003o000000;ooooo1_l00004oooo
o`;o00001oooool2o`0001cooooo0_l000000ooooooo0000o`000004ooooo`;o00003_ooool6o`00
00?ooooo1?l00002ooooo`;o00000_ooool4o`000003ooooool0003o000000Co000000Coooooo`00
0?l0003o00000oooool3o`0003oooooo0_l0000dooooo`007?ooool00ol0003oooooooooo`11oooo
o`;o00001Oooool2o`000003ooooool0003o000000?o00002oooool2o`000003ooooool0003o0000
00Gooooo0_l00008ooooo`;o00001?ooool4o`0001Kooooo0_l00003ooooo`Co00001?ooool2o`00
00;ooooo1?l000000ooooooo0000o`000004ooooo`Oo00002Oooool2o`000003ooooool0003o0000
00[o000000?oooooo`000?l000001_l0000Aooooo`;o00004?ooool2o`00057ooooo000Looooo`03
o`000?oooooooooo03_ooooo1?l00002ooooo`?o000000?oooooo`000?l000001Oooool4o`0000?o
oooo0_l0000Jooooo`;o00001_ooool2o`00017ooooo0_l00003ooooo`;o00000oooool4o`0000So
oooo1?l000000ooooooo0000o`000003ooooo`?o00000oooool2o`0000Gooooo0_l00002oooooaWo
00001?ooool2o`0000[ooooo0_l0000;ooooo`;o00000oooool2o`00057ooooo000Looooo`03o`00
0?oooooooooo03_ooooo1Ol00002ooooo`Go00001_ooool3o`0000?ooooo0_l00006ooooo`;o0000
1oooool2o`0000?ooooo0_l0000Fooooo`;o000000?oooooo`000?l000001?ooool2o`0000Wooooo
0ol0000Booooo`;o00002_ooool3o`000003ooooool0003o000001So000000Coooooo`000?l0003o
oooo0_l0000<ooooo`;o00002Oooool2o`0001Sooooo0_l000000ooooooo0000o`00000iooooo`00
7?ooool00ol0003oooooooooo`0gooooo`;o00001Oooool3o`0000;ooooo0_l0000?ooooo`;o0000
1Oooool2o`0000Oooooo0_l00003ooooo`;o00004oooool2o`000004ooooool0003o0000ooooo`;o
000000?oooooo`000?l000000_l00009ooooo`;o00001oooool2o`0001Oooooo0_l00002oooooaSo
00000oooool2o`0000oooooo0_l0000:ooooo`;o000000?oooooo`000?l000001Oooool2o`0000go
oooo0_l000000ooooooo0000o`00000iooooo`007?ooool00ol0003oooooooooo`0fooooo`?o0000
1_ooool2o`0000;ooooo0_l0000?ooooo`;o00003Oooool2o`0001Wooooo0_l000001Ooooooo0000
o`000?l0003ooooo00So00001_ooool3o`0000Oooooo0_l00003ooooo`;o00000_ooool2o`0000Oo
oooo0_l00005oooooako00002_ooool2o`0000kooooo0_l00002ooooo`;o000000?oooooo`000?l0
00000oooool4o`0004_ooooo000Looooo`03o`000?oooooooooo03Kooooo0_l0000@ooooo`Co0000
1?ooool2o`000004ooooool0003o0000o`0000gooooo0_l00008ooooo`;o00004_ooool3o`000004
ooooool0003o0000o`0000?ooooo0_l00006ooooo`;o00003Oooool2o`0000;ooooo0_l00007oooo
o`;o00001OoooolPo`000003ooooool0003o000000Cooooo0ol00002ooooo`;o00002_ooool2o`00
00;ooooo0_l00006ooooo`?o00003_ooool2o`0000Wooooo0_l0000aooooo`0000Koooooonk^k_lb
<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o
0000ooooooooool0<_ooool2o`0000;ooooo0ol0000?ooooo`Co00001?ooool2o`000003ooooool0
003o000001Sooooo0_l00009ooooo`;o00002oooool3o`0000;ooooo1?l0000=ooooo`;o00001Ooo
ool2o`0001Cooooo5ol00002ooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o0000
0_ooool3o`000003ooooool0003o000000[ooooo1?l00006ooooo`Co00003?ooool2o`0000Wooooo
0_l0000aooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGo
MgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0<_ooool2o`0000;ooooo0ol00002oooo
o`;o0000>oooool2o`0000_ooooo2Ol00009ooooo`;o00000_ooool2o`0000Gooooo0_l0000Eoooo
oa[o00001_ooool2o`0000Kooooo0_l00002ooooo`;o00002_ooool4o`000003ooooool0003o0000
00Gooooo0_l0001:ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0kooooo`;o00001?ooool3o`00
03Cooooo0_l00005ooooo`;o00000oooool2o`000003ooooool0003o000000Go00002Oooool2o`00
00Cooooo0_l000000ooooooo0000o`000005ooooo`;o00003ooooolLo`0000Gooooo0_l0000Doooo
o`;o00001Oooool2o`0000Wooooo1?l00014ooooo`0000?oooooo`000?ooool00_ooool00ol0003o
ooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`00047ooooo0ol0000Koooo
o`;o00005oooool2o`0000Gooooo1?l000000ooooooo0000o`00000:o`0000?ooooo0_l00008oooo
o`;o000000?oooooo`000?l000001Oooool2o`0000Sooooo0_l00005oooooaco00006oooool2o`00
013ooooo1?l00014ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05
o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0nooooo`;o00000_ooool3o`00
00_ooooo0_l000000ooooooo0000o`000009ooooo`Go000000?oooooo`000?l000006Oooool4o`00
0003ooooool0003o000000Ko000000Coooooo`000?l0003o00000oooool2o`0001cooooo0_l00004
oooooaco00007Oooool2o`0000;ooooo0_l0001Cooooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0?_ooool2o`00
00;ooooo0ol00002ooooo`;o00001Oooool4o`000003ooooool0003o000000Wooooo0_l000001?oo
oooo0000o`000?ooool2o`0000Oooooo0_l00005ooooo`;o00001?oooolFo`0000Sooooo0_l0000M
oooooa3o000000?oooooo`000?l000002Ol0000Mooooo`;o00000_ooool2o`0000Sooooo0_l00019
ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o
0000ooooooooool0?_ooool2o`0000;ooooo0_l00003ooooo`;o00001Oooool2o`0001Cooooo0_l0
0007ooooo`;o00001Oooool2o`0000Cooooo5Ol000001?oooooo0000o`000?l00005ooooo`;o0000
7_ooool>o`000003ooooool0003o000000[o00001?ooool2o`0001Sooooo0_l0000;ooooo`;o0000
2_ooool2o`0003gooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0
003o410@1_ooool00ol0003oooooooooo`17ooooo`Co00000_ooool2o`0000;ooooo0_l0000Zoooo
oa;o000000Coooooo`000?l0003o00001?ooool2o`0000?ooooo0_l0000Aooooo`Co00001OoooolD
o`000003ooooool0003o000000?o00001Oooool2o`0001Sooooo0_l0000Gooooo`;o0000?Oooool0
01cooooo00?o0000ooooooooool0??ooool2o`0000_ooooo0_l00002ooooo`;o00000_ooool2o`00
00_ooooo0_l0000MoooooaKo00001?ooool2o`0000?ooooo0_l0000Aooooo`Co00000_ooool2o`00
00;ooooo6Ol0000Looooo`;o0000FOooool001cooooo00?o0000ooooooooool0??ooool2o`0000go
oooo0_l0000Aooooo`;o00004?ooool2o`0000Oooooo0_l000000ooooooo0000o`00000Fo`0000Oo
oooo0_l0000Dooooo`;o00000_ooool2o`0000;ooooo6ol0000Iooooo`?o00002oooool2o`0004co
oooo000Looooo`03o`000?oooooooooo03Wooooo0_l0000=ooooo`Go00006Oooool3o`0000Oooooo
0_l00007oooooaKo000000?oooooo`000?l000000_l00007ooooo`;o00004?ooool2o`0000;ooooo
0_l00006oooooa_o00006Oooool4o`0000[ooooo0_l0001<ooooo`007?ooool00ol0003ooooooooo
o`0iooooo`Co00002oooool4o`000003ooooool0003o000000;o00003oooool2o`000004ooooool0
003o0000ooooo`?o00001?ooool2o`0000Cooooo0_l00006oooooaWo00000oooool2o`0000?ooooo
0_l0000?ooooo`;o00000_ooool2o`0000Gooooo6ol00002ooooo`;o00001_ooool2o`00013ooooo
0ol0001Gooooo`007?ooool00ol0003oooooooooo`0kooooo`;o00001Oooool3o`0000Sooooo1?l0
000?ooooo`Go00001?ooool6o`0000Cooooo0_l00005oooooaOo00001_ooool2o`000003ooooool0
003o000000;o00004oooool4o`0000?ooooo5ol00002ooooo`;o00000_ooool2o`0000?ooooo0_l0
00000ooooooo0000o`00000Aooooo`;o00001?ooool2o`00057ooooo000Looooo`03o`000?oooooo
oooo03_ooooo0_l00005ooooo`?o00003oooool2o`0000_ooooo0_l00003ooooo`;o000000?ooooo
o`000?l000000_l00004ooooo`;o00001ooooolGo`0000Cooooo0_l00003ooooo`Co00004?ooool2
o`0000?ooooo0_l00004oooooaKo000000?oooooo`000?l000000_l00006ooooo`;o00006_ooool2
o`00057ooooo000Looooo`03o`000?oooooooooo03_ooooo0_l0000>ooooo`;o00001oooool4o`00
00Oooooo0_l00005ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`;o00001OoooolJ
o`0000?ooooo0_l00002ooooo`;o00001?ooool2o`0000;ooooo0_l00009ooooo`;o00002_oooolJ
o`000003ooooool0003o000000Cooooo0_l00009ooooo`;o00001Oooool2o`0001oooooo0_l0000i
ooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00004_ooool2o`0000Kooooo1Ol00007oooo
o`;o00002_ooool2o`000003ooooool0003o000000Sooooo6_l00005ooooo`Co00001?ooool2o`00
00;ooooo0_l00004ooooo`;o00002_ooool2o`0000?ooooo4_l000000ooooooo0000o`000002o`00
00;ooooo1?l00004ooooo`;o000000?oooooo`000?l000001Oooool3o`0000Gooooo0_l0000?oooo
o`?o00003Oooool2o`0003Wooooo000Looooo`03o`000?oooooooooo03Oooooo0_l0000=ooooo`;o
00000_ooool2o`0000Oooooo1?l000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l0
00000oooool2o`0000gooooo0_l00003oooooaKo00001Oooool2o`00013ooooo0_l00006ooooo`;o
00000_ooool4o`000003ooooool0003o000001;o00001Oooool2o`0000Gooooo0_l000001?oooooo
0000o`000?l00005ooooo`;o00005oooool3o`0000Gooooo0_l00011ooooo`007?ooool00ol0003o
ooooooooo`16ooooo`;o00000_ooool2o`000003ooooool0003o000000Wooooo0_l00002ooooo`;o
00000_ooool2o`000003ooooool0003o000000?ooooo0_l0000=ooooo`;o00000_oooolGo`0001oo
oooo0_l00004ooooo`;o000000Coooooo`000?l0003o00000_ooool?o`0000Cooooo0ol00002oooo
o`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o00005Oooool2o`0000?ooooo0ol00004
ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0COooool2o`0000Wooooo0_l000001?oo
oooo0000o`000?l0000Hooooo`;o00000_oooolFo`0001Oooooo0_l0000<ooooo`;o00001?oooolA
o`0000?ooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00002_ooool2o`0001Gooooo0_l0
0003ooooo`?o0000Aoooool001cooooo0_l0000looooo`;o00006oooool2o`000003ooooool0003o
000000?ooooo0ol00002ooooo`;o00001?ooool2o`0000Wooooo0_l00002ooooo`_o000000?ooooo
o`000?l000002Ol0000Eooooo`?o00003?ooool2o`0000Cooooo2?l000000ooooooo0000o`000003
o`0000?ooooo0_l000000ooooooo0000o`000002o`0000Wooooo0_l0000Hooooo`;o000000?ooooo
o`000?l000001?ooool2o`0004Sooooo000Looooo`03o`000?oooooooooo03_ooooo0_l0000=oooo
o`;o00004Oooool2o`000005ooooool0003o0000o`000?ooool00ol00004ooooo`;o00003OoooolG
o`0000Kooooo0_l0000=ooooo`;o00005oooool4o`0000Wooooo0_l000000ooooooo0000o`000003
o`0000Sooooo0_l0000>ooooo`;o00002?ooool2o`000003ooooool0003o000004kooooo000Loooo
o`03o`000?oooooooooo04[ooooo0_l00007ooooo`;o00001?ooool2o`0000;ooooo0_l00005oooo
o`Co00001_ooool2o`0000Oooooo0_l000000ooooooo0000o`00000Do`0000Gooooo1?l00009oooo
o`;o00003Oooool2o`0000[ooooo1?l00008ooooo`;o000000Coooooo`000?l0003ooooo0_l00000
0ooooooo0000o`000002ooooo`;o00000_ooool5o`0000Wooooo0_l00002ooooo`;o0000Foooool0
01cooooo00?o0000ooooooooool0Doooool3o`0000?ooooo0_l00006ooooo`;o00000oooool3o`00
0003ooooool0003o000000;ooooo0_l00007ooooo`;o00000_oooolDo`0000Kooooo0_l00007oooo
o`;o00000_ooool2o`0000gooooo0_l00002ooooo`;o00001_ooool5o`0000Oooooo0_l00004oooo
o`;o00001Oooool2o`0000;ooooo1Ol00009ooooo`?o00004oooool2o`0004Wooooo000Looooo`03
o`000?oooooooooo05Cooooo0ol0000:ooooo`;o00001?ooool2o`000003ooooool0003o000000Go
oooo0_l00004ooooo`;o00000_oooolDo`0000Gooooo0_l00007ooooo`Co00005?ooool2o`0000?o
oooo0_l00004ooooo`;o00000oooool2o`0000Oooooo0_l00002ooooo`;o00001oooool4o`0000[o
oooo0_l0000Cooooo`?o0000B?ooool001cooooo00?o0000ooooooooool0EOooool2o`0001Sooooo
1_l00002ooooo`;o00000_oooolDo`0000Gooooo0_l00007ooooo`Co00006Oooool2o`0000Gooooo
0_l00002ooooo`Co00001Oooool3o`000003ooooool0003o000000Oooooo1?l00002ooooo`;o0000
3?ooool2o`0000kooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`1Kooooo`;o00003?oo
ool2o`0000Cooooo0_l00002ooooo`;o00003?ooool5o`0000;ooooo1?l000000ooooooo0000o`00
000>ooooo`;o00005oooool2o`0000Wooooo0_l00004ooooo`;o00001_ooool2o`0000gooooo0_l0
00000ooooooo0000o`00000<ooooo`;o0000F?ooool001cooooo00?o0000ooooooooool0DOooool5
o`0000Gooooo1?l000000ooooooo0000o`000005ooooo`Go00001oooool2o`0000?ooooo0_l00003
ooooo`;o00000oooool3o`000003ooooool0003o000000Oo00001?ooool2o`00027ooooo0ol0000;
ooooo`;o00006?ooool2o`0000Oooooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`1Aoooo
o`Go00001Oooool7o`0000Gooooo0_l000000ooooooo0000o`000007ooooo`;o00000oooool2o`00
00?ooooo0ol00002ooooo`;o000000?oooooo`000?l000000ol00002ooooo`;o00001Oooool2o`00
01Gooooo0_l0000;ooooo`;o00002oooool2o`0000gooooo0_l000000ooooooo0000o`00000?oooo
o`;o00007Oooool2o`00047ooooo000Looooo`03o`000?oooooooooo04kooooo1?l0000<ooooo`;o
00001oooool2o`0000?ooooo0_l00008ooooo`;o00001_ooool2o`0000;ooooo0_l000000ooooooo
0000o`000002o`0000kooooo1?l00003ooooo`;o00002_ooool2o`0000_ooooo0_l00007ooooo`;o
00001?ooool3o`0000[ooooo0_l000000ooooooo0000o`000002o`0000Sooooo0_l0000Rooooo`;o
0000@Oooool001cooooo00?o0000ooooooooool0>Oooool2o`0001?ooooo1?l00003ooooo`;o0000
1oooool2o`0000Oooooo0_l00003ooooo`;o00000oooool2o`0000?ooooo0_l0000=ooooo`;o0000
1oooool2o`0000Gooooo1_l00003ooooo`;o00000oooool2o`0001;ooooo0_l00007ooooo`;o0000
0oooool4o`0000;ooooo0ol00008ooooo`Co00001oooool3o`0000Cooooo0_l0000Iooooo`;o0000
A?ooool001cooooo00?o0000ooooooooool0>Oooool2o`0001[ooooo1?l0000;ooooo`;o00001ooo
ool2o`0000;ooooo0_l000001?oooooo0000o`000?l0000>ooooo`;o00001oooool2o`0000Gooooo
0_l00007ooooo`;o00000oooool2o`00023ooooo0ol00003ooooo`?o00004oooool3o`0000Cooooo
0_l0000Iooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0Doooool6o`0000[ooooo0ol0
0007ooooo`;o00001Oooool3o`0000Oooooo0_l00008ooooo`Co000000Goooooo`000?l0003o0000
ooooo`04o`00037ooooo1?l0000Booooo`;o00003_ooool2o`0000[ooooo0_l0001?ooooo`007?oo
ool00ol0003oooooooooo`0jooooo`;o00001?ooool2o`00017ooooo0_l00005ooooo`;o00001ooo
ool2o`0000Wooooo0_l00005ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Cooooo0_l0
0002ooooo`So000000?oooooo`000?l000000_l0000Yooooo`;o00001_ooool4o`0000Oooooo0_l0
0009ooooo`;o00002Oooool2o`0000;ooooo0ol0000:ooooo`;o0000Coooool001cooooo00?o0000
ooooooooool0>_ooool2o`0000Cooooo0_l0000Cooooo`;o00000oooool2o`0000_ooooo0_l00005
ooooo`;o00001Oooool2o`000003ooooool0003o000000[ooooo1?l000000ooooooo0000o`000002
o`00037ooooo0_l0000Aooooo`;o00005?ooool6o`0005cooooo000Looooo`03o`000?oooooooooo
05Cooooo1?l00002ooooo`;o00000oooool2o`000003ooooool0003o000000?ooooo0_l00007oooo
o`;o00002_ooool2o`000003ooooool0003o000000?ooooo1?l000000ooooooo0000o`000003oooo
o`;o00000oooool2o`0001;ooooo0_l0000>ooooo`;o00000oooool3o`0000gooooo0_l00003oooo
o`;o00002Oooool2o`0000_ooooo0_l0000;ooooo`;o0000DOooool001cooooo0_l0001Eooooo`Co
000000?oooooo`000?l000000_l00002ooooo`;o000000?oooooo`000?l000003?ooool3o`0000Wo
oooo0_l000000ooooooo0000o`00000=ooooo`;o00000oooool2o`0001;ooooo0_l00002ooooo`;o
00001?ooool2o`0000Cooooo0_l000000ooooooo0000o`000006o`0000Oooooo0_l000000ooooooo
0000o`000003ooooo`?o00001?ooool2o`0000;ooooo1?l0000Fooooo`;o0000DOooool001cooooo
00?o0000ooooooooool0>oooool2o`0000Wooooo0_l0000<ooooo`;o000000?oooooo`000?l00000
1?l0000:ooooo`;o00002?ooool2o`0001Wooooo0_l00006ooooo`;o00003oooool4o`0000;ooooo
0_l00004ooooo`;o00001oooool2o`0000;ooooo2?l00002ooooo`?o000000Coooooo`000?l0003o
oooo1_l00003ooooo`;o00001?ooool2o`0006Wooooo000Looooo`03o`000?oooooooooo03_ooooo
0_l00009ooooo`;o00003?ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l00000
1_ooool2o`000003ooooool0003o000000?ooooo0_l0000Nooooo`;o00001_ooool2o`0000Oooooo
0_l00006ooooo`Go00002Oooool2o`0000Gooooo0_l000000ooooooo0000o`000007o`000003oooo
ool0003o000000Go000000Goooooo`000?l0003o0000ooooo`02o`0007Cooooo000Looooo`03o`00
0?oooooooooo05Kooooo0_l000001?oooooo0000o`000?ooool2o`0000Kooooo0_l00005ooooo`?o
00000_ooool2o`0002_ooooo0_l00009ooooo`?o00000oooool2o`0000?ooooo0_l00005ooooo`So
000000?oooooo`000?l000000_ooool2o`0000;ooooo2?l0001fooooo`007?ooool00ol0003ooooo
ooooo`1Fooooo`;o00003oooool3o`000003ooooool0003o000000?ooooo0_l00004ooooo`;o0000
<Oooool2o`0000?ooooo0_l00008ooooo`[o000000?oooooo`000?l000001_ooool9o`0002cooooo
0_l00017ooooo`007?ooool00ol0003oooooooooo`1Qooooo`;o00000_ooool5o`000003ooooool0
003o000000Wooooo1?l0000;ooooo`;o00006Oooool2o`000003ooooool0003o000000Gooooo0_l0
000:ooooo`co00003?ooool2o`0000;ooooo0_l0000/ooooo`;o0000Aoooool001cooooo00?o0000
ooooooooool0BOooool2o`0001Kooooo0_l000000ooooooo0000o`000004o`000003ooooool0003o
000000;o00000oooool2o`0000?ooooo0ol00003ooooo`;o00001_ooool2o`0000[ooooo0_l0000=
ooooo`;o000000?oooooo`000?l000001Oooool2o`0000[ooooo3Ol0000;ooooo`;o0000NOooool0
01cooooo00?o0000ooooooooool0BOooool3o`0001Cooooo0_l00002ooooo`Co000000Goooooo`00
0?l0003o0000ooooo`02o`0000?ooooo0_l00009ooooo`Co00003_ooool5o`0000_ooooo0_l00005
ooooo`;o00004?ooool<o`0000_ooooo0_l00002ooooo`Co0000L_ooool001cooooo00?o0000oooo
ooooool0B_ooool2o`0001Cooooo0_l00004ooooo`Oo00000_ooool2o`0000_ooooo0_l000000ooo
oooo0000o`00000>ooooo`;o000000?oooooo`000?l000002oooool4o`0000?ooooo0_l0000?oooo
o`go00002oooool2o`0000;ooooo1?l0001booooo`007?ooool00ol0003oooooooooo`1Sooooo`;o
00000_ooool2o`000003ooooool0003o000000Go00002oooool2o`0000oooooo0_l0000:ooooo`;o
00000_ooool2o`0000;ooooo0_l0000Cooooo`So000000?oooooo`000?l000000_l00005ooooo`;o
00005oooool2o`000003ooooool0003o000006?ooooo000Looooo`03o`000?oooooooooo05Wooooo
0_l00008ooooo`;o00000oooool2o`0000?ooooo0_l000001?oooooo0000o`000?l00002ooooo`;o
00005_ooool2o`0000Cooooo0_l00004ooooo`;o00000_ooool2o`000003ooooool0003o000001Co
oooo3Ol00003ooooo`Co00001_ooool2o`0000oooooo0_l000000ooooooo0000o`00001Sooooo`00
7?ooool00ol0003oooooooooo`1;ooooo`;o00003?ooool2o`0000[ooooo0_l000001?oooooo0000
o`000?ooool2o`0000?ooooo0ol00002ooooo`;o00001_ooool2o`0001Cooooo0_l0000;ooooo`;o
00005_ooool;o`0000;ooooo0ol00008ooooo`;o00000oooool2o`0000[ooooo0_l0001Vooooo`00
7?ooool00ol0003oooooooooo`1;ooooo`;o00006?ooool2o`0000Cooooo0_l00005ooooo`;o0000
0_ooool2o`0000Gooooo0_l0000Dooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o0000
5_ooool;o`000004ooooool0003o0000o`0000kooooo0_l00004ooooo`;o0000K?ooool001cooooo
00?o0000ooooooooool0HOooool2o`0000Sooooo0_l00005ooooo`?o000000?oooooo`000?l00000
7oooool2o`0000;ooooo0_l0000Kooooo`Wo000000?oooooo`000?l000000_l00005ooooo`;o0000
3_ooool2o`0000gooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1Looooo`;o00000ooo
ool3o`0000Oooooo0_l00006ooooo`;o00000oooool2o`0000Wooooo0_l00004ooooo`;o00004Ooo
ool2o`0001Gooooo0_l00003ooooo`Wo000000?oooooo`000?l000001oooool2o`000004ooooool0
003o0000ooooo`;o00005oooool2o`0005gooooo000Looooo`03o`000?oooooooooo05cooooo0_l0
0004ooooo`;o00001oooool2o`0000Gooooo1?l00002ooooo`;o00002Oooool2o`0000Cooooo0_l0
000Aooooo`;o00004Oooool6o`000003ooooool0003o000000Wo00002oooool4o`000003ooooool0
003o000007Kooooo000Looooo`;o0000K?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002
o`0000Cooooo0_l0000Tooooo`;o00003Oooool6o`000003ooooool0003o000000So00001oooool2
o`0000?ooooo0_l0001kooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o00002?ooool2o`00
00?ooooo1?l00002ooooo`;o00009?ooool2o`0000Oooooo0_l0000?ooooo`Go00000oooool2o`00
00?ooooo0_l00008ooooo`;o00002Oooool2o`0006_ooooo000Looooo`03o`000?oooooooooo06Go
oooo1?l00006ooooo`Co00000oooool3o`0000;ooooo0ol00003ooooo`?o00001Oooool2o`0000[o
oooo0_l0000Booooo`;o00002?ooool2o`0000gooooo0_l0000=ooooo`;o00002Oooool2o`0006_o
oooo000Looooo`03o`000?oooooooooo06Oooooo0_l00005ooooo`Go00001?ooool2o`0000;ooooo
0ol00002ooooo`Ko00000oooool2o`0000?ooooo0ol00004ooooo`;o000000Coooooo`000?l0003o
00006?ooool2o`0001;ooooo0_l0000Cooooo`;o0000Joooool001cooooo00?o0000ooooooooool0
K_ooool5o`0000;ooooo0_l00009ooooo`Ko00001oooool4o`0000Oooooo0ol0000<ooooo`;o0000
00?oooooo`000?l000004oooool2o`0000Kooooo0_l0000Qooooo`;o0000GOooool001cooooo00?o
0000ooooooooool0K_ooool2o`000003ooooool0003o000000;ooooo0_l0000Fooooo`?o00000_oo
ool2o`0001?ooooo0_l000001?oooooo0000o`000?l00006ooooo`;o00002_ooool2o`0002Wooooo
0_l00003ooooo`;o0000F?ooool001cooooo00?o0000ooooooooool0Eoooool2o`0001Gooooo0_l0
000Aooooo`;o00001oooool2o`0000Kooooo1?l0000Aooooo`;o00000_ooool2o`0000Gooooo0ol0
000Nooooo`;o00004Oooool2o`0000Oooooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`1G
ooooo`;o00006Oooool2o`0000[ooooo0_l000000ooooooo0000o`000007ooooo`;o00001_ooool4
o`0000_ooooo1ol0000:ooooo`;o000000?oooooo`000?l000007?ooool2o`00017ooooo0_l0001Q
ooooo`007?ooool00ol0003oooooooooo`1Wooooo`;o00002Oooool2o`0000[ooooo0_l000000ooo
oooo0000o`00000Nooooo`Oo00002oooool4o`000003ooooool0003o000008oooooo000Looooo`03
o`000?oooooooooo05[ooooo0_l0000;ooooo`;o00002Oooool2o`00017ooooo0_l00003ooooo`;o
00006Oooool2o`0000Oooooo0_l00003ooooo`;o00000oooool2o`0008oooooo000Looooo`03o`00
0?oooooooooo05[ooooo0_l0000Gooooo`;o00001_ooool2o`0000Sooooo1?l000000ooooooo0000
o`000003o`0000Gooooo1?l0000Aooooo`;o00000oooool2o`0000Kooooo0_l0002Aooooo`007?oo
ool00ol0003oooooooooo`1cooooo`;o00000oooool2o`000003ooooool0003o000000[ooooo1?l0
00001?oooooo0000o`000?l00005ooooo`Co00003oooool4o`0000_ooooo0_l0000Vooooo`;o0000
JOooool001cooooo00?o0000ooooooooool0Goooool2o`0001Oooooo0_l00004ooooo`;o00002Ooo
ool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`Ko00000oooool2o`0000Gooooo0_l0
00001?oooooo0000o`000?ooool2o`0000[ooooo0_l00003ooooo`;o00008Oooool2o`0006Wooooo
000Looooo`03o`000?oooooooooo05oooooo0_l0000Aooooo`Co00002?ooool2o`0000Kooooo0_l0
0006ooooo`Co00000_ooool6o`0000?ooooo0_l00005ooooo`;o000000?oooooo`000?l000000ol0
000:ooooo`;o00000oooool2o`0001kooooo0_l0001/ooooo`0000Koooooonk^k_lb<S;o0000oc8b
<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000oooooooo
ool0I_ooool2o`0000[ooooo1?l0000@ooooo`;o00001_ooool3o`0000oooooo0_l00006ooooo`?o
000000?oooooo`000?l00000;Oooool2o`0006cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMg
M`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1V
ooooo`;o00002Oooool2o`0000[ooooo1?l0000Cooooo`;o00002_ooool3o`0000Gooooo0_l00002
ooooo`;o00002?ooool2o`00097ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo
00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo077ooooo0_l0000:
ooooo`Co00001?ooool2o`0000;ooooo0_l00009ooooo`;o00002oooool2o`0000?ooooo0_l0000<
ooooo`Co000000?oooooo`000?l00000S_ooool00003ooooool0003ooooo00;ooooo00?o0000oooo
ooooool02Oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0001Zooooo`;o00004oooool3
o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000004Oooool2o`0000Gooooo0_l0000<
ooooo`;o00000oooool2o`00023ooooo0_l0001/ooooo`0000?oooooo`000?ooool00_ooool00ol0
003oooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`1Z
ooooo`;o00002_ooool2o`0000Oooooo0ol00006ooooo`Ko00000oooool2o`0000cooooo0ol0000`
ooooo`;o00001oooool2o`0006cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo
00Wooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo07Kooooo0_l0000:
ooooo`Co00000_ooool2o`000004ooooool0003o0000o`0000?ooooo0_l0000=ooooo`;o00003?oo
ool2o`0002;ooooo1?l0001cooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`00
0?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`22ooooo`Co00001Oooool2o`00027o
oooo0ol0000Iooooo`;o00001_ooool4o`0007?ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^
kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo06Wooooo0_l0000I
ooooo`;o00001Oooool2o`0000Wooooo0_l0000Gooooo`;o000000?oooooo`000?l000005_ooool2
o`0007gooooo000Looooo`03o`000?oooooooooo05gooooo0_l0000:ooooo`;o00002_ooool2o`00
00;ooooo0_l00007ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00000oooool2o`00
00Cooooo0_l0000Aooooo`;o000000?oooooo`000?l000000_l00002ooooo`?o0000U?ooool001co
oooo00?o0000ooooooooool0GOooool2o`0001Kooooo0_l00002ooooo`;o00001oooool2o`000003
ooooool0003o000000;o00000_ooool2o`0000?ooooo0_l0000Eooooo`Co000000?oooooo`000?l0
00000_l00003ooooo`;o00000oooool2o`0000_ooooo0_l00022ooooo`007?ooool00ol0003ooooo
ooooo`1booooo`;o00003Oooool2o`0000oooooo0_l0000Cooooo`;o00000oooool2o`0000[ooooo
0_l0000;ooooo`;o0000P_ooool001cooooo00?o0000ooooooooool0L_ooool2o`0000gooooo0_l0
0007ooooo`;o00001_ooool6o`0000Wooooo1?l0002Tooooo`007?ooool00ol0003oooooooooo`1g
ooooo`;o00003_ooool5o`0000Cooooo0_l00002ooooo`Co00002Oooool4o`0000cooooo0ol0002E
ooooo`007?ooool00ol0003oooooooooo`1gooooo`;o00003?ooool5o`0000Kooooo0_l0000Aoooo
o`;o00003?ooool3o`0009Gooooo000Looooo`03o`000?oooooooooo08Gooooo0ol0000>ooooo`;o
00000_ooool2o`0000Oooooo0_l00008ooooo`;o0000V_ooool001cooooo00?o0000ooooooooool0
Q_ooool2o`0000_ooooo0_l000001?oooooo0000o`000?ooool3o`0000Gooooo0_l0000:ooooo`;o
00003Oooool2o`0008_ooooo000Looooo`03o`000?oooooooooo09?ooooo0_l00004ooooo`;o0000
1_ooool2o`0000[ooooo0_l0000=ooooo`;o0000Roooool001cooooo00?o0000ooooooooool0KOoo
ool2o`000=[ooooo000Looooo`03o`000?oooooooooo06gooooo0_l0000/ooooo`;o00001oooool3
o`000:;ooooo000Looooo`;o0000W?ooool2o`0000Oooooo0ol0002Rooooo`007?ooool00ol0003o
ooooooooo`2>ooooo`;o00001oooool3o`0000gooooo0_l0000<ooooo`;o0000T_ooool001cooooo
00?o0000ooooooooool0S_ooool2o`0000Oooooo0ol00008ooooo`;o00000_ooool3o`0000Cooooo
0_l00006ooooo`;o0000T_ooool001cooooo00?o0000ooooooooool0Roooool4o`0001?ooooo0_l0
0002ooooo`;o00001Oooool2o`0009[ooooo000Looooo`03o`000?oooooooooo08_ooooo1?l0000P
ooooo`;o0000V?ooool001cooooo00?o0000ooooooooool0R?ooool2o`0001_ooooo0_l00008oooo
o`;o0000V?ooool001cooooo00?o0000ooooooooool0R?ooool2o`0001_ooooo0_l0002Rooooo`00
7?ooool00ol0003oooooooooo`2Dooooo`;o0000:?ooool2o`0008Wooooo000Looooo`03o`000?oo
oooooooo07Oooooo0_l0000Kooooo`;o00001_ooool2o`00023ooooo0_l00029ooooo`007?ooool0
0ol0003oooooooooo`1gooooo`;o00007_ooool2o`0000?ooooo0_l0002[ooooo`007?ooool00ol0
003oooooooooo`2Gooooo`Co0000[_ooool001cooooo00?o0000ooooooooool0VOooool2o`000:ko
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo0_l00025ooooo`;o0000`oooool001cooooo00?o0000ooooooooool0
Q?ooool2o`000<?ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?oooooo
Boooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom:ooooo`00
5?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o
0000ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o0000ooooooooool0oooooomB
ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?oo
ooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`004_ooool00omEEEGoIVIVo`00
003ooooooeCooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Uooooo`04oa0@
4?l0003o0000ooooo`;o000000?o410@ooooooooool05Oooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<
00?ooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c003ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0T?oo
ool00:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00002Oooool01OlQ8B7oV9RHoooo
oonHV9So8B4Q00?ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@03ooooo`05ob4Q8OnHV9SooooooiRH
V?lQ8B40T?ooool00:Kooooo00Go0000ooooooooooooooooo`00000Hooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`00002@ooooo`00Y_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l00009ooooo`05oc8b
<_nHV9SooooooiRHV?lb<S800oooool01Olb<S;oV9RHoooooonHV9So<S8b00?ooooo00Go<S8boiRH
V?ooooooV9RHoc8b<P2@ooooo`00Y_ooool01Ol0003oQhN7oooooonYZJWo000001Sooooo00Goc<c<
o`000?l0003o0000olc<c003ooooo`05olc<c?l0003o0000o`000?o<c<`00oooool01Oo<c<co0000
o`000?l0003oc<c<093ooooo002Uooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool0
5_ooool01Ol@413o^[Zjoooooonj^[[o410@00?ooooo00Go410@okZj^_oooooo^[Zjoa0@4003oooo
o`05oa0@4?nj^[[ooooookZj^_l@4100T?ooool00<?ooooo00Go0000okZj^_oooooo^[Zjo`000003
ooooo`05o`000?nj^[[ooooookZj^_l000000oooool01Ol0003o^[Zjoooooonj^[[o0000093ooooo
0033ooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01OnYZJWo410@o`000?l@413oZJVY00?o
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@2@ooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(894) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.33642 .50469 Mdot
.31297 .47805 Mdot
.56958 .61442 Mdot
.5173 .34275 Mdot
.40324 .46119 Mdot
.59833 .61381 Mdot
.39377 .64267 Mdot
.4273 .60833 Mdot
.59046 .63056 Mdot
.59708 .33742 Mdot
.4105 .60829 Mdot
.54917 .43745 Mdot
.38506 .62001 Mdot
.50829 .35956 Mdot
.85323 .47148 Mdot
.44344 .394 Mdot
.30683 .44868 Mdot
.71846 .50502 Mdot
.57261 .40165 Mdot
.61962 .59003 Mdot
.37823 .44943 Mdot
.5017 .35706 Mdot
.34714 .49944 Mdot
.50792 .36026 Mdot
.539 .35535 Mdot
.33694 .48242 Mdot
.28599 .45461 Mdot
.55493 .36545 Mdot
.53893 .38702 Mdot
.40391 .59312 Mdot
.68377 .46354 Mdot
.79635 .34776 Mdot
.46548 .42587 Mdot
.19759 .4078 Mdot
.4282 .61965 Mdot
.58072 .2303 Mdot
.61019 .65014 Mdot
.37665 .60868 Mdot
.42633 .61008 Mdot
.43359 .62926 Mdot
.38248 .60707 Mdot
.33339 .47595 Mdot
.41755 .57746 Mdot
.37817 .57156 Mdot
.47084 .35043 Mdot
.30886 .63785 Mdot
.6898 .315 Mdot
.51528 .41054 Mdot
.301 .48249 Mdot
.63052 .59448 Mdot
.20836 .472 Mdot
.42883 .59545 Mdot
.55036 .72004 Mdot
.66186 .14918 Mdot
.37481 .62356 Mdot
.48406 .33947 Mdot
.6078 .63651 Mdot
.48907 .3748 Mdot
.50331 .36624 Mdot
.33354 .40292 Mdot
.55297 .38551 Mdot
.69532 .54536 Mdot
.37806 .47134 Mdot
.62303 .661 Mdot
.59719 .62076 Mdot
.41944 .60413 Mdot
.30998 .45043 Mdot
.38914 .62736 Mdot
.54583 .33367 Mdot
.62425 .64465 Mdot
.51414 .41054 Mdot
.40428 .60035 Mdot
.34781 .51211 Mdot
.48616 .41017 Mdot
.33458 .72613 Mdot
.83001 .56688 Mdot
.67697 .51727 Mdot
.35907 .38956 Mdot
.41358 .36206 Mdot
.74687 .68151 Mdot
.52672 .37772 Mdot
.60345 .82343 Mdot
.84684 .49546 Mdot
.33505 .50288 Mdot
.53826 .30434 Mdot
.54932 .63095 Mdot
.47365 .40051 Mdot
.48873 .50972 Mdot
.5052 .32212 Mdot
.28309 .68681 Mdot
.59092 .63577 Mdot
.32373 .45831 Mdot
.51696 .3438 Mdot
.53412 .41957 Mdot
.32426 .32385 Mdot
.5627 .39911 Mdot
.53741 .34175 Mdot
.29178 .49996 Mdot
.41866 .62068 Mdot
.48939 .44696 Mdot
.35207 .61705 Mdot
.56423 .73941 Mdot
.47251 .35927 Mdot
.59539 .6552 Mdot
.29865 .50606 Mdot
.46632 .38753 Mdot
.39943 .6508 Mdot
.5314 .40161 Mdot
.40268 .569 Mdot
.30816 .47663 Mdot
.53103 .42183 Mdot
.72889 .52046 Mdot
.40012 .7946 Mdot
.32945 .4556 Mdot
.52265 .76776 Mdot
.53539 .40663 Mdot
.49133 .35838 Mdot
.31542 .47665 Mdot
.60837 .60039 Mdot
.56378 .49941 Mdot
.29379 .47499 Mdot
.42999 .63173 Mdot
.32434 .43666 Mdot
.50615 .30343 Mdot
.58279 .62496 Mdot
.55433 .74492 Mdot
.5432 .74282 Mdot
.64165 .43659 Mdot
.47073 .39277 Mdot
.2537 .54464 Mdot
.60093 .60698 Mdot
.32411 .46354 Mdot
.39103 .62403 Mdot
.46136 .35165 Mdot
.34835 .45373 Mdot
.40613 .61857 Mdot
.71743 .5504 Mdot
.6921 .58572 Mdot
.29786 .48591 Mdot
.46475 .63893 Mdot
.43816 .63476 Mdot
.43047 .63689 Mdot
.1964 .43403 Mdot
.31348 .48322 Mdot
.70766 .51761 Mdot
.40309 .6249 Mdot
.73657 .41539 Mdot
.49705 .33131 Mdot
.6141 .43721 Mdot
.4833 .85627 Mdot
.20069 .47871 Mdot
.44916 .75346 Mdot
.69594 .51152 Mdot
.42184 .64731 Mdot
.53997 .37036 Mdot
.31872 .49048 Mdot
.32547 .4849 Mdot
.54831 .34452 Mdot
.53635 .34775 Mdot
.50622 .41323 Mdot
.53628 .41589 Mdot
.73338 .34848 Mdot
.51779 .41845 Mdot
.6579 .53613 Mdot
.33968 .4587 Mdot
.54897 .36909 Mdot
.60735 .59553 Mdot
.45838 .40248 Mdot
.39262 .60163 Mdot
.49423 .36452 Mdot
.52394 .34155 Mdot
.5234 .42867 Mdot
.37177 .62776 Mdot
.76254 .32296 Mdot
.46132 .84561 Mdot
.59573 .20031 Mdot
.49283 .76184 Mdot
.6178 .62203 Mdot
.47219 .37509 Mdot
.70501 .52928 Mdot
.48224 .25038 Mdot
.51644 .37579 Mdot
.17998 .60496 Mdot
.52642 .33885 Mdot
.26181 .31791 Mdot
.41896 .42972 Mdot
.594 .19283 Mdot
.61235 .51706 Mdot
.54188 .39129 Mdot
.34433 .28644 Mdot
.41388 .21695 Mdot
.41571 .55479 Mdot
.38017 .61064 Mdot
.60268 .59556 Mdot
.60284 .64392 Mdot
.43884 .60048 Mdot
.44995 .42856 Mdot
.49022 .45924 Mdot
.57634 .42643 Mdot
.55251 .73765 Mdot
.35636 .50781 Mdot
.68344 .55385 Mdot
.31446 .51108 Mdot
.69613 .78936 Mdot
.25671 .65415 Mdot
.4353 .58299 Mdot
.67019 .54899 Mdot
.57428 .60709 Mdot
.55092 .73583 Mdot
.71099 .52579 Mdot
.51098 .396 Mdot
.30226 .471 Mdot
.28472 .27429 Mdot
.42247 .39181 Mdot
.29802 .24596 Mdot
.35322 .45082 Mdot
.55019 .51497 Mdot
.40017 .61238 Mdot
.59724 .58551 Mdot
.49676 .34935 Mdot
.49483 .40176 Mdot
.38422 .47832 Mdot
.51455 .4083 Mdot
.39222 .48894 Mdot
.51493 .33692 Mdot
.58803 .57828 Mdot
.68661 .50688 Mdot
.43656 .5978 Mdot
.63451 .44221 Mdot
.35246 .5023 Mdot
.57213 .56523 Mdot
.63306 .60761 Mdot
.50292 .2474 Mdot
.40776 .60227 Mdot
.72863 .5283 Mdot
.62885 .60504 Mdot
.67711 .54823 Mdot
.47305 .41585 Mdot
.61338 .65006 Mdot
.68818 .52395 Mdot
.75817 .35042 Mdot
.46304 .35575 Mdot
.75351 .3858 Mdot
.39863 .64174 Mdot
.32887 .4358 Mdot
.55381 .38126 Mdot
.54547 .75356 Mdot
.49996 .43594 Mdot
.40975 .71997 Mdot
.54293 .72873 Mdot
.56119 .71379 Mdot
.77581 .63908 Mdot
.72356 .51495 Mdot
.40505 .758 Mdot
.23173 .53288 Mdot
.30482 .45169 Mdot
.49869 .33825 Mdot
.65928 .22074 Mdot
.40274 .62424 Mdot
.51306 .39253 Mdot
.55474 .60306 Mdot
.40127 .62776 Mdot
.48538 .37892 Mdot
.38123 .64415 Mdot
.32059 .48664 Mdot
.62394 .73867 Mdot
.3137 .44355 Mdot
.4678 .3492 Mdot
.39668 .6486 Mdot
.62656 .62301 Mdot
.33777 .48619 Mdot
.52808 .40018 Mdot
.48903 .35351 Mdot
.55957 .73307 Mdot
.54824 .38205 Mdot
.67014 .23619 Mdot
.54721 .40006 Mdot
.57058 .63513 Mdot
.56136 .39462 Mdot
.1699 .56111 Mdot
.6738 .62724 Mdot
.30733 .45319 Mdot
.55814 .71561 Mdot
.59597 .63046 Mdot
.71939 .6699 Mdot
.46191 .58217 Mdot
.53181 .39011 Mdot
.5653 .722 Mdot
.60739 .49897 Mdot
.40253 .58938 Mdot
.56807 .38921 Mdot
.28627 .66845 Mdot
.61894 .5941 Mdot
.55351 .73458 Mdot
.57928 .37262 Mdot
.29958 .50769 Mdot
.51939 .34337 Mdot
.62711 .63122 Mdot
.3207 .43683 Mdot
.45757 .38515 Mdot
.64354 .29858 Mdot
.54267 .73369 Mdot
.39624 .64066 Mdot
.43544 .44761 Mdot
.51302 .41572 Mdot
.61247 .64204 Mdot
.35893 .48768 Mdot
.42709 .62676 Mdot
.33973 .47333 Mdot
.34907 .23374 Mdot
.4855 .77085 Mdot
.70462 .31002 Mdot
.67054 .55414 Mdot
.4604 .7025 Mdot
.57096 .18566 Mdot
.42502 .78008 Mdot
.69426 .40961 Mdot
.43903 .17269 Mdot
.62025 .6007 Mdot
.66457 .57424 Mdot
.60151 .63094 Mdot
.52714 .36124 Mdot
.59647 .61718 Mdot
.59231 .18716 Mdot
.52246 .33649 Mdot
.61648 .62909 Mdot
.66629 .7015 Mdot
.5453 .35508 Mdot
.33192 .45442 Mdot
.84487 .46366 Mdot
.29923 .73165 Mdot
.20324 .56486 Mdot
.61897 .61072 Mdot
.37804 .42307 Mdot
.5528 .36236 Mdot
.46378 .41951 Mdot
.32331 .49471 Mdot
.56526 .38391 Mdot
.68552 .55401 Mdot
.67836 .55567 Mdot
.60719 .45403 Mdot
.5308 .82284 Mdot
.49503 .44967 Mdot
.33525 .48904 Mdot
.44915 .29659 Mdot
.33063 .71695 Mdot
.56147 .75117 Mdot
.35882 .63738 Mdot
.77384 .33994 Mdot
.46178 .44341 Mdot
.46054 .64031 Mdot
.3046 .68498 Mdot
.31025 .4627 Mdot
.71614 .28822 Mdot
.37794 .61707 Mdot
.39453 .27254 Mdot
.25295 .36846 Mdot
.5004 .3987 Mdot
.41449 .60676 Mdot
.52677 .44895 Mdot
.25491 .675 Mdot
.76113 .43506 Mdot
.75537 .71283 Mdot
.46755 .35172 Mdot
.38513 .74799 Mdot
.49328 .36041 Mdot
.57806 .4775 Mdot
.5477 .40012 Mdot
.34385 .47664 Mdot
.56918 .2976 Mdot
.45179 .52918 Mdot
.51555 .84029 Mdot
.24575 .64093 Mdot
.69184 .51442 Mdot
.49143 .35399 Mdot
.49863 .39856 Mdot
.72345 .52696 Mdot
.35149 .48599 Mdot
.54146 .40703 Mdot
.63976 .35136 Mdot
.50376 .40917 Mdot
.38279 .60383 Mdot
.64172 .479 Mdot
.38637 .49169 Mdot
.53226 .4256 Mdot
.30181 .44789 Mdot
.37459 .63305 Mdot
.42109 .60283 Mdot
.52627 .31554 Mdot
.40401 .6545 Mdot
.51579 .34023 Mdot
.75061 .48283 Mdot
.31887 .50237 Mdot
.41935 .39301 Mdot
.35619 .47986 Mdot
.40004 .3861 Mdot
.39474 .65173 Mdot
.54722 .75035 Mdot
.26296 .50724 Mdot
.3795 .61989 Mdot
.20332 .53984 Mdot
.56157 .44693 Mdot
.53334 .43628 Mdot
.23709 .64852 Mdot
.62256 .61002 Mdot
.54665 .74335 Mdot
.40689 .64946 Mdot
.51111 .41559 Mdot
.56097 .41499 Mdot
.37468 .60518 Mdot
.35332 .32327 Mdot
.72457 .65694 Mdot
.55003 .35494 Mdot
.34709 .48036 Mdot
.32687 .46396 Mdot
.4623 .39432 Mdot
.5255 .39214 Mdot
.572 .62519 Mdot
.55276 .7217 Mdot
.56938 .73425 Mdot
.54356 .74123 Mdot
.5722 .5917 Mdot
.32937 .60137 Mdot
.43294 .63146 Mdot
.28259 .56642 Mdot
.38062 .70335 Mdot
.43552 .35887 Mdot
.61852 .63727 Mdot
.49173 .39187 Mdot
.50941 .34588 Mdot
.42642 .62852 Mdot
.47577 .72173 Mdot
.53028 .30217 Mdot
.30652 .49785 Mdot
.39813 .65421 Mdot
.51581 .45593 Mdot
.32833 .56115 Mdot
.68411 .54057 Mdot
.20146 .57022 Mdot
.40967 .60136 Mdot
.31406 .45626 Mdot
.36573 .62162 Mdot
.49905 .4031 Mdot
.52332 .33005 Mdot
.31334 .4706 Mdot
.718 .50965 Mdot
.56476 .3455 Mdot
.4838 .37866 Mdot
.25634 .74605 Mdot
.33815 .72994 Mdot
.40149 .67771 Mdot
.54167 .37998 Mdot
.55223 .42348 Mdot
.68023 .52422 Mdot
.504 .40645 Mdot
.48847 .35162 Mdot
.4085 .80394 Mdot
.37931 .68029 Mdot
.72763 .50663 Mdot
.40105 .26988 Mdot
.35102 .4493 Mdot
.71189 .26692 Mdot
.5685 .73173 Mdot
.40733 .58246 Mdot
.61121 .74083 Mdot
.55039 .73155 Mdot
.42041 .71356 Mdot
.71637 .27976 Mdot
.54436 .74174 Mdot
.54335 .61583 Mdot
.55859 .30558 Mdot
.54457 .34467 Mdot
.48895 .36572 Mdot
.69942 .52921 Mdot
.31487 .48488 Mdot
.58283 .51665 Mdot
.78878 .46089 Mdot
.49818 .3568 Mdot
.3506 .42954 Mdot
.77681 .36543 Mdot
.55762 .73106 Mdot
.70004 .55266 Mdot
.70799 .56189 Mdot
.48823 .3604 Mdot
.4426 .80827 Mdot
.3359 .48415 Mdot
.52815 .3997 Mdot
.51394 .42218 Mdot
.62075 .61393 Mdot
.30503 .46131 Mdot
.63297 .61342 Mdot
.54075 .73336 Mdot
.45599 .19824 Mdot
.22228 .70917 Mdot
.42156 .63367 Mdot
.63088 .23056 Mdot
.41026 .59096 Mdot
.778 .66735 Mdot
.54721 .73099 Mdot
.52173 .37792 Mdot
.35266 .50404 Mdot
.53034 .40317 Mdot
.50787 .38852 Mdot
.5094 .39593 Mdot
.55324 .44869 Mdot
.17844 .59663 Mdot
.7113 .53646 Mdot
.46273 .3231 Mdot
.57582 .64108 Mdot
.65408 .23472 Mdot
.82632 .49826 Mdot
.48694 .39645 Mdot
.48322 .3616 Mdot
.33898 .45334 Mdot
.55312 .34996 Mdot
.38982 .59245 Mdot
.35882 .48901 Mdot
.5171 .42923 Mdot
.70497 .28377 Mdot
.53786 .41048 Mdot
.57207 .19358 Mdot
.36584 .6186 Mdot
.20482 .54435 Mdot
.47272 .31788 Mdot
.54471 .74605 Mdot
.54634 .7432 Mdot
.57305 .71882 Mdot
.36413 .60947 Mdot
.61504 .63638 Mdot
.80117 .51704 Mdot
.44789 .41777 Mdot
.53953 .36623 Mdot
.55935 .41843 Mdot
.55748 .62913 Mdot
.48626 .50588 Mdot
.43056 .76052 Mdot
.52522 .45562 Mdot
.57755 .61854 Mdot
.33318 .4352 Mdot
.52825 .73395 Mdot
.3568 .49116 Mdot
.72544 .50476 Mdot
.40709 .60682 Mdot
.68492 .54777 Mdot
.20384 .50626 Mdot
.31021 .47698 Mdot
.38355 .48347 Mdot
.61782 .62469 Mdot
.52886 .53049 Mdot
.63123 .14989 Mdot
.61886 .65439 Mdot
.65239 .40066 Mdot
.33014 .4956 Mdot
.51258 .42513 Mdot
.62413 .49093 Mdot
.52053 .52824 Mdot
.61103 .62472 Mdot
.51912 .36817 Mdot
.50244 .81797 Mdot
.57239 .62211 Mdot
.56854 .39101 Mdot
.59867 .60216 Mdot
.39273 .60386 Mdot
.60178 .60459 Mdot
.36336 .48724 Mdot
.46674 .38121 Mdot
.66004 .15904 Mdot
.59077 .54405 Mdot
.54757 .39467 Mdot
.39709 .65402 Mdot
.62081 .31895 Mdot
.50103 .38369 Mdot
.68946 .55724 Mdot
.58131 .62341 Mdot
.73729 .62414 Mdot
.55515 .37006 Mdot
.6084 .61231 Mdot
.3427 .50354 Mdot
.36768 .59789 Mdot
.788 .62913 Mdot
.55522 .74868 Mdot
.31701 .49444 Mdot
.54305 .72177 Mdot
.37574 .65106 Mdot
.55829 .41561 Mdot
.51128 .41986 Mdot
.344 .4674 Mdot
.61882 .76745 Mdot
.5593 .38733 Mdot
.52648 .37749 Mdot
.57701 .60013 Mdot
.56366 .642 Mdot
.63334 .74864 Mdot
.6227 .6031 Mdot
.57386 .39085 Mdot
.34361 .46813 Mdot
.51631 .34824 Mdot
.32703 .45201 Mdot
.50229 .33839 Mdot
.27279 .45408 Mdot
.33173 .50266 Mdot
.50693 .79266 Mdot
.51854 .3575 Mdot
.42421 .43667 Mdot
.50749 .39272 Mdot
.51001 .4096 Mdot
.579 .63914 Mdot
.71485 .54133 Mdot
.46544 .33767 Mdot
.64174 .56068 Mdot
.7016 .55512 Mdot
.36878 .23191 Mdot
.62029 .61018 Mdot
.69175 .53297 Mdot
.75605 .37754 Mdot
.56242 .71534 Mdot
.70399 .53558 Mdot
.829 .48506 Mdot
.42347 .6319 Mdot
.34885 .44343 Mdot
.54472 .35482 Mdot
.4185 .18153 Mdot
.72898 .46581 Mdot
.56332 .72672 Mdot
.54672 .39842 Mdot
.49391 .3887 Mdot
.28899 .48458 Mdot
.66063 .80844 Mdot
.56603 .62154 Mdot
.52998 .35841 Mdot
.31814 .445 Mdot
.51839 .86117 Mdot
.58728 .65074 Mdot
.70286 .53259 Mdot
.37217 .61019 Mdot
.27878 .49108 Mdot
.55639 .74894 Mdot
.39555 .5891 Mdot
.58915 .73034 Mdot
.19838 .53222 Mdot
.53452 .40842 Mdot
.61658 .64255 Mdot
.19285 .49401 Mdot
.45842 .43148 Mdot
.42707 .66793 Mdot
.57031 .45812 Mdot
.31263 .4604 Mdot
.37538 .6058 Mdot
.67978 .53691 Mdot
.36152 .48637 Mdot
.34958 .48674 Mdot
.43019 .61088 Mdot
.57839 .68606 Mdot
.54479 .51777 Mdot
.39037 .59958 Mdot
.29296 .69089 Mdot
.30808 .26 Mdot
.56057 .71866 Mdot
.71254 .54929 Mdot
.22417 .35632 Mdot
.33414 .47577 Mdot
.77148 .33644 Mdot
.18455 .54369 Mdot
.53798 .34216 Mdot
.69536 .5226 Mdot
.33791 .65546 Mdot
.80329 .49874 Mdot
.40018 .63141 Mdot
.44085 .51261 Mdot
.72417 .54997 Mdot
.5563 .36419 Mdot
.27966 .42814 Mdot
.52501 .36664 Mdot
.40475 .60947 Mdot
.40681 .39645 Mdot
.31516 .45519 Mdot
.38265 .65594 Mdot
.19933 .56662 Mdot
.50605 .34505 Mdot
.52014 .36416 Mdot
.66179 .46198 Mdot
.30132 .47451 Mdot
.56601 .74127 Mdot
.5355 .3976 Mdot
.48878 .37248 Mdot
.54127 .42587 Mdot
.45679 .45237 Mdot
.41391 .79487 Mdot
.52807 .35773 Mdot
.60874 .58098 Mdot
.47436 .426 Mdot
.51605 .3582 Mdot
.29971 .45074 Mdot
.21682 .69327 Mdot
.5426 .74892 Mdot
.49251 .36675 Mdot
.53498 .41031 Mdot
.43015 .61926 Mdot
.58079 .50858 Mdot
.51029 .52924 Mdot
.61153 .65575 Mdot
.71136 .3923 Mdot
.55318 .44823 Mdot
.35073 .45331 Mdot
.72946 .53241 Mdot
.47758 .41214 Mdot
.34279 .45022 Mdot
.45082 .39897 Mdot
.57533 .61758 Mdot
.55747 .71963 Mdot
.2195 .58134 Mdot
.6976 .53918 Mdot
.70074 .47366 Mdot
.28102 .58178 Mdot
.59997 .5944 Mdot
.54078 .36271 Mdot
.40742 .58521 Mdot
.6132 .65231 Mdot
.56081 .73388 Mdot
.55551 .32484 Mdot
.32745 .4873 Mdot
.32725 .45705 Mdot
.61353 .45956 Mdot
.65105 .5958 Mdot
.3456 .80118 Mdot
.3947 .60383 Mdot
.48006 .42609 Mdot
.23922 .53904 Mdot
.3278 .45627 Mdot
.61914 .45587 Mdot
.69099 .5344 Mdot
.39984 .63317 Mdot
.56918 .74315 Mdot
.34237 .45208 Mdot
.2986 .47955 Mdot
.46 .3625 Mdot
.4791 .39165 Mdot
.6867 .41146 Mdot
.6105 .45269 Mdot
.37239 .62172 Mdot
.72254 .53637 Mdot
.6346 .62192 Mdot
.53019 .36732 Mdot
.33828 .50238 Mdot
.27784 .28931 Mdot
.5301 .41578 Mdot
.57131 .6264 Mdot
.31386 .46264 Mdot
.72401 .52308 Mdot
.69372 .55657 Mdot
.50944 .4091 Mdot
.35899 .40221 Mdot
.3811 .63483 Mdot
.32873 .45454 Mdot
.23013 .4841 Mdot
.5589 .39126 Mdot
.47578 .39099 Mdot
.58411 .40214 Mdot
.41272 .59539 Mdot
.20903 .54522 Mdot
.72862 .51349 Mdot
.32509 .47832 Mdot
.54184 .40003 Mdot
.69503 .54459 Mdot
.22166 .53622 Mdot
.55385 .72586 Mdot
.59794 .6043 Mdot
.68717 .5568 Mdot
.71585 .51624 Mdot
.71236 .55253 Mdot
.78411 .35205 Mdot
.35185 .51133 Mdot
.4577 .29496 Mdot
.55182 .39478 Mdot
.61437 .46214 Mdot
.4858 .32904 Mdot
.36686 .60795 Mdot
.62406 .6093 Mdot
.5046 .39081 Mdot
.46016 .36303 Mdot
.49211 .46882 Mdot
.42911 .4226 Mdot
.36727 .43731 Mdot
.30572 .47255 Mdot
.43449 .3775 Mdot
.6228 .61672 Mdot
.6597 .81813 Mdot
.61766 .16824 Mdot
.49351 .31068 Mdot
.56052 .51788 Mdot
.34625 .49917 Mdot
.43139 .60941 Mdot
.49432 .53203 Mdot
.37016 .63536 Mdot
.32491 .47277 Mdot
.52907 .36447 Mdot
.28907 .57073 Mdot
.67357 .54096 Mdot
.50763 .41512 Mdot
.40105 .61676 Mdot
.50707 .4143 Mdot
.38281 .59578 Mdot
.31982 .54106 Mdot
.30808 .69975 Mdot
.52734 .33884 Mdot
.55648 .40526 Mdot
.45866 .4629 Mdot
.48628 .39387 Mdot
.65889 .77879 Mdot
.35127 .49144 Mdot
.51718 .81937 Mdot
.45636 .38099 Mdot
.38607 .36992 Mdot
.55509 .39117 Mdot
.58388 .77617 Mdot
.47866 .39841 Mdot
.48127 .55495 Mdot
.54664 .34847 Mdot
.47622 .36322 Mdot
.39211 .64759 Mdot
.43014 .61842 Mdot
.32 .50696 Mdot
.56251 .74617 Mdot
.60772 .20528 Mdot
.47979 .38285 Mdot
.58733 .58214 Mdot
.44344 .66135 Mdot
.7207 .52271 Mdot
.32749 .47251 Mdot
.52564 .86883 Mdot
.37892 .64104 Mdot
.63764 .63294 Mdot
.62159 .77394 Mdot
.60937 .58669 Mdot
.35888 .66239 Mdot
.60011 .38767 Mdot
.7172 .51094 Mdot
.55842 .37241 Mdot
.20313 .40817 Mdot
.34723 .72496 Mdot
.55462 .32913 Mdot
.3818 .65337 Mdot
.47844 .25703 Mdot
.22532 .3582 Mdot
.69539 .5643 Mdot
.68503 .52359 Mdot
.38385 .6423 Mdot
.58257 .59282 Mdot
.56885 .43207 Mdot
.68981 .5351 Mdot
.58717 .60074 Mdot
.57151 .71491 Mdot
.44686 .5559 Mdot
.33398 .48162 Mdot
.20458 .57216 Mdot
.28639 .61941 Mdot
.37208 .62535 Mdot
.61145 .56154 Mdot
.27351 .46767 Mdot
.31404 .51735 Mdot
.55338 .75204 Mdot
.57898 .64012 Mdot
.35925 .49909 Mdot
.57192 .37566 Mdot
.42148 .41282 Mdot
.4957 .36015 Mdot
.70446 .52311 Mdot
.48477 .40101 Mdot
.57613 .63362 Mdot
.39751 .62867 Mdot
.59285 .64627 Mdot
.39207 .64487 Mdot
.32064 .59597 Mdot
.52258 .39864 Mdot
.47657 .36511 Mdot
.72532 .4696 Mdot
.3076 .5041 Mdot
.21227 .4768 Mdot
.57929 .58388 Mdot
.60455 .63516 Mdot
.49705 .34318 Mdot
.353 .49809 Mdot
.70095 .4973 Mdot
.72637 .47276 Mdot
.49858 .41741 Mdot
.35197 .49126 Mdot
.53446 .36254 Mdot
.75072 .35743 Mdot
.32835 .73882 Mdot
.33833 .469 Mdot
.54793 .8288 Mdot
.5367 .37901 Mdot
.53357 .28657 Mdot
.56246 .41566 Mdot
.65356 .36265 Mdot
.56011 .38931 Mdot
.35443 .45154 Mdot
.49664 .36403 Mdot
.36252 .47859 Mdot
.58876 .59357 Mdot
.43504 .61618 Mdot
.32029 .49753 Mdot
.50196 .42085 Mdot
.77159 .3118 Mdot
.4001 .60781 Mdot
.49333 .3528 Mdot
.41585 .62508 Mdot
.33072 .4428 Mdot
.30183 .48822 Mdot
.81454 .51571 Mdot
.39474 .68234 Mdot
.39043 .60517 Mdot
.53014 .35314 Mdot
.26312 .61569 Mdot
.52048 .35191 Mdot
.67855 .41841 Mdot
.46556 .36165 Mdot
.56074 .39269 Mdot
.83281 .58594 Mdot
.41165 .58972 Mdot
.35702 .80333 Mdot
.78719 .44608 Mdot
.79175 .36382 Mdot
.29023 .50992 Mdot
.69598 .56429 Mdot
.72572 .29582 Mdot
.54195 .73043 Mdot
.58908 .61195 Mdot
.50436 .39206 Mdot
.34541 .5319 Mdot
.37656 .60739 Mdot
.71631 .53774 Mdot
.52563 .33842 Mdot
.57188 .63179 Mdot
.76808 .62415 Mdot
.41559 .65125 Mdot
.33273 .47553 Mdot
.30567 .49944 Mdot
.49846 .8556 Mdot
.54207 .40126 Mdot
.48481 .35751 Mdot
.40722 .60848 Mdot
.44332 .42951 Mdot
.72736 .52387 Mdot
.663 .69136 Mdot
.3903 .60585 Mdot
.5302 .57241 Mdot
.30786 .4798 Mdot
.49316 .39046 Mdot
.50546 .50529 Mdot
.49015 .63683 Mdot
.4023 .24226 Mdot
.70304 .5281 Mdot
.68461 .42995 Mdot
.35393 .45114 Mdot
.39468 .62251 Mdot
.70685 .58167 Mdot
.48895 .43312 Mdot
.49306 .38422 Mdot
.68373 .4341 Mdot
.59597 .50617 Mdot
.69423 .49536 Mdot
.54158 .3358 Mdot
.59631 .50192 Mdot
.49033 .34521 Mdot
.53437 .42952 Mdot
.55803 .34661 Mdot
.47167 .38944 Mdot
.35045 .49416 Mdot
.50344 .46699 Mdot
.60271 .60882 Mdot
.33227 .31567 Mdot
.45496 .51683 Mdot
.55208 .37869 Mdot
.52514 .3602 Mdot
.44444 .2377 Mdot
.40495 .68978 Mdot
.34361 .49471 Mdot
.37107 .4824 Mdot
.41018 .65107 Mdot
.42197 .43629 Mdot
.5648 .60982 Mdot
.54964 .46436 Mdot
.59025 .64434 Mdot
.35479 .48841 Mdot
.60601 .64056 Mdot
.42002 .64564 Mdot
.61653 .64299 Mdot
.57436 .58939 Mdot
.38013 .60011 Mdot
.30757 .48739 Mdot
.4908 .41111 Mdot
.4011 .65315 Mdot
.664 .4595 Mdot
.70301 .52395 Mdot
.81521 .51437 Mdot
.4683 .41889 Mdot
.4287 .49213 Mdot
.64534 .30036 Mdot
.59433 .64489 Mdot
.35148 .76629 Mdot
.32997 .50267 Mdot
.67637 .52378 Mdot
.35361 .49232 Mdot
.18322 .56377 Mdot
.71744 .54108 Mdot
.82994 .48115 Mdot
.60927 .68427 Mdot
.76703 .60129 Mdot
.53087 .33006 Mdot
.26696 .45767 Mdot
.6257 .63879 Mdot
.37593 .60901 Mdot
.58686 .69849 Mdot
.47068 .36831 Mdot
.4358 .78152 Mdot
.29866 .50093 Mdot
.56963 .71714 Mdot
.38854 .62538 Mdot
.39148 .65688 Mdot
.53212 .40718 Mdot
.67791 .71219 Mdot
.46482 .3742 Mdot
.65395 .63211 Mdot
.70159 .40945 Mdot
.55924 .46185 Mdot
.51022 .3382 Mdot
.59806 .6537 Mdot
.53453 .3616 Mdot
.50002 .2636 Mdot
.19715 .42882 Mdot
.57799 .40505 Mdot
.49762 .77892 Mdot
.74781 .51253 Mdot
.31304 .4743 Mdot
.46934 .32113 Mdot
.563 .73779 Mdot
.53942 .37992 Mdot
.18224 .35544 Mdot
.70305 .53841 Mdot
.57018 .57564 Mdot
.55146 .40153 Mdot
.53429 .40077 Mdot
.2372 .41169 Mdot
.33332 .53522 Mdot
.56934 .7438 Mdot
.49306 .37942 Mdot
.72396 .40906 Mdot
.42179 .61398 Mdot
.46327 .38532 Mdot
.48914 .36347 Mdot
.40323 .21776 Mdot
.41352 .59809 Mdot
.59804 .64602 Mdot
.54889 .72195 Mdot
.63566 .61594 Mdot
.73485 .53677 Mdot
.50049 .54326 Mdot
.61608 .44074 Mdot
.32792 .7357 Mdot
.70714 .56007 Mdot
.5261 .42166 Mdot
.53075 .30134 Mdot
.53565 .38726 Mdot
.67999 .53094 Mdot
.40646 .59442 Mdot
.33589 .49969 Mdot
.22752 .58783 Mdot
.55411 .73648 Mdot
.56812 .39399 Mdot
.6803 .54998 Mdot
.32162 .49012 Mdot
.58187 .5588 Mdot
.3189 .47722 Mdot
.38319 .61386 Mdot
.36035 .62814 Mdot
.70488 .54819 Mdot
.35692 .48803 Mdot
.63384 .59087 Mdot
.78781 .46537 Mdot
.47351 .3515 Mdot
.39841 .66549 Mdot
.34249 .50599 Mdot
.28538 .45809 Mdot
.30487 .50718 Mdot
.51751 .40544 Mdot
.56922 .51223 Mdot
.52708 .43044 Mdot
.37929 .63833 Mdot
.59013 .60429 Mdot
.61237 .43046 Mdot
.22375 .42381 Mdot
.56391 .55278 Mdot
.49714 .32324 Mdot
.50246 .35011 Mdot
.48848 .36021 Mdot
.48092 .33766 Mdot
.67156 .58678 Mdot
.52436 .39438 Mdot
.39294 .64693 Mdot
.58315 .63584 Mdot
.55215 .38932 Mdot
.566 .73432 Mdot
.53837 .51435 Mdot
.72734 .5406 Mdot
.47663 .53571 Mdot
.71366 .25942 Mdot
.32191 .49176 Mdot
.63015 .61107 Mdot
.59176 .61158 Mdot
.71817 .54972 Mdot
.37624 .61167 Mdot
.31681 .48191 Mdot
.66068 .35475 Mdot
.71784 .54692 Mdot
.49389 .3672 Mdot
.60223 .73133 Mdot
.53496 .79225 Mdot
.5593 .36782 Mdot
.50981 .38132 Mdot
.55717 .71536 Mdot
.57463 .59727 Mdot
.34859 .19665 Mdot
.62901 .49389 Mdot
.71002 .54536 Mdot
.702 .51261 Mdot
.31384 .51407 Mdot
.51979 .30523 Mdot
.39017 .64182 Mdot
.64765 .48093 Mdot
.62436 .34557 Mdot
.67787 .4853 Mdot
.77484 .66684 Mdot
.51922 .41524 Mdot
.25522 .40164 Mdot
.51174 .34192 Mdot
.29301 .49348 Mdot
.30728 .45169 Mdot
.33867 .49338 Mdot
.37633 .62869 Mdot
.40477 .37014 Mdot
.3998 .64798 Mdot
.67378 .21926 Mdot
.36369 .46119 Mdot
.7072 .60076 Mdot
.61128 .63646 Mdot
.44436 .36751 Mdot
.72414 .519 Mdot
.34837 .63494 Mdot
.54807 .33554 Mdot
.4283 .79981 Mdot
.61774 .63843 Mdot
.30362 .48316 Mdot
.59905 .37412 Mdot
.52889 .17576 Mdot
.52764 .53563 Mdot
.45546 .31244 Mdot
.24039 .44103 Mdot
.72249 .53249 Mdot
.39882 .24624 Mdot
.71327 .50677 Mdot
.4045 .62288 Mdot
.46966 .37407 Mdot
.47174 .39728 Mdot
.50329 .33758 Mdot
.52272 .39529 Mdot
.42661 .63097 Mdot
.4514 .37157 Mdot
.16993 .56115 Mdot
.5585 .71731 Mdot
.74693 .34314 Mdot
.68615 .53913 Mdot
.36752 .63625 Mdot
.58559 .6384 Mdot
.57025 .73415 Mdot
.62768 .43915 Mdot
.54611 .34898 Mdot
.50656 .39142 Mdot
.55245 .75587 Mdot
.55812 .35059 Mdot
.53669 .45408 Mdot
.60285 .61053 Mdot
.56742 .54795 Mdot
.68727 .56038 Mdot
.68462 .54655 Mdot
.39889 .5954 Mdot
.35592 .48972 Mdot
.69488 .53188 Mdot
.57603 .59999 Mdot
.44875 .38345 Mdot
.49877 .42218 Mdot
.34044 .50687 Mdot
.18417 .54509 Mdot
.70097 .565 Mdot
.59813 .36521 Mdot
.36054 .46094 Mdot
.34521 .5172 Mdot
.49502 .38202 Mdot
.58184 .40182 Mdot
.28745 .45072 Mdot
.69685 .5589 Mdot
.36932 .63959 Mdot
.76581 .57556 Mdot
.40541 .61565 Mdot
.31746 .48605 Mdot
.45973 .39228 Mdot
.30739 .48418 Mdot
.54302 .38463 Mdot
.88117 .57062 Mdot
.47478 .39944 Mdot
.28189 .71296 Mdot
.65797 .38163 Mdot
.59068 .61481 Mdot
.63349 .59109 Mdot
.56676 .72453 Mdot
.35963 .45796 Mdot
.47618 .41248 Mdot
.70476 .51045 Mdot
.80699 .41143 Mdot
.27875 .44893 Mdot
.58024 .61211 Mdot
.56812 .60256 Mdot
.40167 .58992 Mdot
.54794 .40353 Mdot
.49044 .39008 Mdot
.61353 .64568 Mdot
.66383 .30335 Mdot
.35179 .45779 Mdot
.48715 .35627 Mdot
.50854 .35186 Mdot
.59608 .61314 Mdot
.78703 .46815 Mdot
.27477 .51047 Mdot
.47089 .37633 Mdot
.73218 .55677 Mdot
.36606 .60752 Mdot
.48918 .33486 Mdot
.45185 .36947 Mdot
.70566 .51502 Mdot
.69971 .28928 Mdot
.19807 .3925 Mdot
.36792 .60986 Mdot
.56544 .74167 Mdot
.52203 .42607 Mdot
.61189 .63453 Mdot
.50203 .42192 Mdot
.57944 .21986 Mdot
.56511 .71679 Mdot
.52531 .3849 Mdot
.51231 .30878 Mdot
.30161 .4594 Mdot
.52823 .39489 Mdot
.44279 .2219 Mdot
.62733 .64324 Mdot
.52675 .38947 Mdot
.33826 .40577 Mdot
.41826 .60236 Mdot
.49327 .31153 Mdot
.68313 .53392 Mdot
.65073 .35582 Mdot
.28644 .59412 Mdot
.55752 .63826 Mdot
.68657 .54691 Mdot
.49364 .4145 Mdot
.58847 .59014 Mdot
.37119 .61727 Mdot
.41902 .78125 Mdot
.52574 .33372 Mdot
.4034 .60917 Mdot
.39576 .62849 Mdot
.69954 .54519 Mdot
.39544 .825 Mdot
.45169 .35106 Mdot
.48634 .39689 Mdot
.45195 .21353 Mdot
.29257 .47362 Mdot
.48758 .40494 Mdot
.52789 .4187 Mdot
.40234 .64355 Mdot
.25779 .50166 Mdot
.45361 .26472 Mdot
.6647 .70201 Mdot
.37953 .59689 Mdot
.57912 .67563 Mdot
.59127 .58951 Mdot
.6869 .53715 Mdot
.31565 .46845 Mdot
.73087 .53931 Mdot
.61569 .60948 Mdot
.53755 .40931 Mdot
.40367 .63883 Mdot
.31707 .2787 Mdot
.4278 .59551 Mdot
.59752 .66526 Mdot
.28404 .47384 Mdot
.24148 .55277 Mdot
.15836 .4258 Mdot
.29576 .62231 Mdot
.41696 .57704 Mdot
.72039 .52211 Mdot
.5937 .71075 Mdot
.5061 .35131 Mdot
.38816 .26175 Mdot
.49934 .4127 Mdot
.27544 .41894 Mdot
.61662 .60132 Mdot
.55484 .75271 Mdot
.46945 .37627 Mdot
.6986 .42062 Mdot
.43861 .6268 Mdot
.39895 .58947 Mdot
.51816 .38777 Mdot
.37943 .6189 Mdot
.48141 .3886 Mdot
.58235 .64073 Mdot
.3292 .77724 Mdot
.49828 .35102 Mdot
.54028 .43091 Mdot
.43169 .68107 Mdot
.81881 .50648 Mdot
.62206 .58206 Mdot
.25078 .4035 Mdot
.49708 .17255 Mdot
.37981 .62061 Mdot
.54189 .31505 Mdot
.6214 .64231 Mdot
.55765 .71496 Mdot
.63919 .59425 Mdot
.49878 .40829 Mdot
.50569 .4059 Mdot
.49798 .34278 Mdot
.52095 .36468 Mdot
.3942 .25761 Mdot
.4554 .44738 Mdot
.28346 .387 Mdot
.50828 .38962 Mdot
.27359 .43192 Mdot
.40981 .64728 Mdot
.37645 .44924 Mdot
.70035 .56803 Mdot
.52153 .41443 Mdot
.38685 .49814 Mdot
.36397 .61897 Mdot
.67141 .21776 Mdot
.40628 .59217 Mdot
.59484 .62975 Mdot
.42688 .60223 Mdot
.54708 .38407 Mdot
.32742 .46342 Mdot
.6164 .65533 Mdot
.39965 .74568 Mdot
.58733 .61251 Mdot
.54755 .39498 Mdot
.75792 .55216 Mdot
.59374 .60961 Mdot
.50896 .51738 Mdot
.32247 .46219 Mdot
.72693 .41734 Mdot
.30893 .44993 Mdot
.52805 .38678 Mdot
.52743 .38237 Mdot
.56828 .70783 Mdot
.43572 .62767 Mdot
.3317 .44156 Mdot
.2656 .75543 Mdot
.73498 .51355 Mdot
.34138 .48834 Mdot
.44973 .41534 Mdot
.58352 .51125 Mdot
.33709 .46147 Mdot
.69355 .36592 Mdot
.3747 .61297 Mdot
.35324 .5082 Mdot
.46257 .42421 Mdot
.46893 .62786 Mdot
.67187 .53875 Mdot
.57645 .64633 Mdot
.49776 .58583 Mdot
.62824 .63523 Mdot
.3631 .62818 Mdot
.5848 .6603 Mdot
.42341 .61743 Mdot
.21626 .4943 Mdot
.41358 .38647 Mdot
.426 .58897 Mdot
.36789 .64217 Mdot
.6159 .61961 Mdot
.52185 .3352 Mdot
.42652 .52115 Mdot
.54409 .33643 Mdot
.51405 .32746 Mdot
.42256 .61122 Mdot
.33972 .44528 Mdot
.35153 .44342 Mdot
.26914 .44556 Mdot
.30343 .49867 Mdot
.58716 .64453 Mdot
.3238 .73825 Mdot
.20466 .50162 Mdot
.41076 .60601 Mdot
.37617 .65568 Mdot
.52198 .35411 Mdot
.61427 .63016 Mdot
.5976 .59279 Mdot
.39321 .63962 Mdot
.3435 .27488 Mdot
.522 .4318 Mdot
.28651 .463 Mdot
.36518 .4673 Mdot
.34172 .46878 Mdot
.31038 .51034 Mdot
.42284 .29316 Mdot
.37487 .61059 Mdot
.36176 .45925 Mdot
.52095 .3852 Mdot
.50331 .40644 Mdot
.54964 .74467 Mdot
.68296 .54319 Mdot
.45211 .40409 Mdot
.57253 .41147 Mdot
.49563 .38401 Mdot
.59672 .60516 Mdot
.46943 .3118 Mdot
.56982 .72637 Mdot
.56648 .62951 Mdot
.56296 .61115 Mdot
.54688 .74928 Mdot
.27729 .43582 Mdot
.50467 .1633 Mdot
.53022 .35878 Mdot
.42558 .35926 Mdot
.6097 .63143 Mdot
.37366 .78932 Mdot
.21347 .54361 Mdot
.50757 .33692 Mdot
.46507 .57968 Mdot
.60332 .65868 Mdot
.29403 .48305 Mdot
.49236 .40856 Mdot
.54399 .73643 Mdot
.72776 .53836 Mdot
.45317 .41964 Mdot
.54749 .72285 Mdot
.35899 .48134 Mdot
.66627 .56757 Mdot
.34416 .51531 Mdot
.60429 .65966 Mdot
.50823 .30926 Mdot
.6316 .14761 Mdot
.63272 .60876 Mdot
.80432 .42813 Mdot
.33269 .53843 Mdot
.49042 .3519 Mdot
.63256 .61727 Mdot
.2916 .47886 Mdot
.362 .61375 Mdot
.59259 .49864 Mdot
.3208 .50223 Mdot
.56441 .74479 Mdot
.54747 .73887 Mdot
.60031 .61017 Mdot
.30587 .4682 Mdot
.46154 .38668 Mdot
.31561 .4517 Mdot
.42384 .59939 Mdot
.52601 .34281 Mdot
.58842 .18738 Mdot
.42436 .40354 Mdot
.35314 .45222 Mdot
.57012 .6312 Mdot
.67807 .52649 Mdot
.53806 .34405 Mdot
.78965 .41714 Mdot
.53901 .41319 Mdot
.41777 .61232 Mdot
.48084 .82611 Mdot
.34331 .25784 Mdot
.55502 .38775 Mdot
.52211 .3553 Mdot
.37666 .60281 Mdot
.54354 .34693 Mdot
.55843 .38493 Mdot
.42302 .67396 Mdot
.3071 .45623 Mdot
.49958 .3599 Mdot
.58421 .5991 Mdot
.20772 .43265 Mdot
.53301 .42618 Mdot
.50184 .75913 Mdot
.71707 .42114 Mdot
.45688 .83199 Mdot
.48617 .41113 Mdot
.63619 .4703 Mdot
.51783 .37006 Mdot
.51823 .41059 Mdot
.52591 .35061 Mdot
.2499 .39095 Mdot
.6177 .61863 Mdot
.57591 .62648 Mdot
.67136 .542 Mdot
.71756 .41719 Mdot
.69658 .52082 Mdot
.39026 .5946 Mdot
.76501 .65181 Mdot
.56304 .71782 Mdot
.35779 .48765 Mdot
.46826 .39861 Mdot
.62098 .65393 Mdot
.49435 .39335 Mdot
.54536 .38142 Mdot
.5922 .65477 Mdot
.61992 .59326 Mdot
.59621 .56566 Mdot
.72116 .51083 Mdot
.3308 .49762 Mdot
.46178 .35784 Mdot
.70131 .555 Mdot
.46387 .39513 Mdot
.61196 .50134 Mdot
.33619 .497 Mdot
.31013 .45302 Mdot
.31377 .44195 Mdot
.53754 .40959 Mdot
.55079 .37714 Mdot
.40168 .64767 Mdot
.35407 .49913 Mdot
.40103 .59774 Mdot
.6187 .64853 Mdot
.63954 .61378 Mdot
.49911 .40825 Mdot
.57873 .30737 Mdot
.70816 .51224 Mdot
.59329 .63494 Mdot
.5546 .75666 Mdot
.68019 .51953 Mdot
.5443 .40105 Mdot
.59989 .65392 Mdot
.68464 .54923 Mdot
.30909 .31147 Mdot
.46387 .16668 Mdot
.68001 .52556 Mdot
.51837 .38544 Mdot
.23353 .41754 Mdot
.77861 .47313 Mdot
.73315 .51089 Mdot
.41342 .62205 Mdot
.53321 .41586 Mdot
.59368 .26829 Mdot
.71569 .55811 Mdot
.21646 .46599 Mdot
.58965 .61714 Mdot
.43834 .57699 Mdot
.4885 .44206 Mdot
.3718 .27839 Mdot
.73482 .52867 Mdot
.32104 .48042 Mdot
.34952 .43607 Mdot
.50539 .37228 Mdot
.69957 .56957 Mdot
.39744 .58827 Mdot
.58411 .62266 Mdot
.59774 .58185 Mdot
.30627 .46408 Mdot
.27411 .64326 Mdot
.57893 .60623 Mdot
.59128 .33806 Mdot
.62152 .73788 Mdot
.41652 .42725 Mdot
.32812 .41494 Mdot
.36242 .71698 Mdot
.51057 .42668 Mdot
.68697 .51828 Mdot
.3697 .63649 Mdot
.38855 .64395 Mdot
.38772 .60934 Mdot
.62921 .58937 Mdot
.49067 .53257 Mdot
.62199 .63255 Mdot
.41351 .77089 Mdot
.69471 .5441 Mdot
.73844 .40291 Mdot
.47457 .40885 Mdot
.5013 .35056 Mdot
.47424 .42349 Mdot
.46817 .36522 Mdot
.51413 .36614 Mdot
.37748 .61159 Mdot
.61453 .58462 Mdot
.73317 .62732 Mdot
.34804 .47827 Mdot
.54445 .59273 Mdot
.61116 .63679 Mdot
.55838 .71534 Mdot
.71327 .53623 Mdot
.5808 .478 Mdot
.5673 .65106 Mdot
.60521 .63986 Mdot
.44617 .3852 Mdot
.3368 .45092 Mdot
.56875 .44671 Mdot
.5258 .37658 Mdot
.59279 .63834 Mdot
.60721 .68053 Mdot
.47346 .23596 Mdot
.58585 .36706 Mdot
.6716 .52027 Mdot
.57455 .51293 Mdot
.72396 .50745 Mdot
.54284 .43721 Mdot
.38305 .79552 Mdot
.61532 .61014 Mdot
.59762 .62308 Mdot
.67971 .54386 Mdot
.54292 .2909 Mdot
.31103 .46501 Mdot
.55562 .75286 Mdot
.4161 .6295 Mdot
.53377 .38701 Mdot
.63655 .60488 Mdot
.49621 .28376 Mdot
.70028 .69081 Mdot
.39361 .60675 Mdot
.56665 .62785 Mdot
.54919 .40063 Mdot
.51647 .38473 Mdot
.72305 .52755 Mdot
.39983 .4801 Mdot
.43761 .40141 Mdot
.79129 .36204 Mdot
.30831 .69816 Mdot
.26336 .66569 Mdot
.49285 .38434 Mdot
.30409 .46439 Mdot
.54746 .73157 Mdot
.71517 .54754 Mdot
.45411 .3797 Mdot
.47485 .16673 Mdot
.31655 .43548 Mdot
.40026 .62022 Mdot
.54404 .73886 Mdot
.49054 .53051 Mdot
.53567 .41556 Mdot
.4987 .41232 Mdot
.51987 .40092 Mdot
.41536 .16206 Mdot
.58013 .60971 Mdot
.30044 .50056 Mdot
.70611 .52672 Mdot
.3004 .49769 Mdot
.58006 .61932 Mdot
.2373 .59313 Mdot
.5551 .37465 Mdot
.28535 .46752 Mdot
.32207 .47734 Mdot
.40082 .5901 Mdot
.36186 .61139 Mdot
.58686 .56504 Mdot
.47432 .398 Mdot
.54414 .7344 Mdot
.30637 .45127 Mdot
.60658 .5881 Mdot
.71876 .53952 Mdot
.39803 .65219 Mdot
.5091 .39043 Mdot
.60805 .60746 Mdot
.55934 .33719 Mdot
.33754 .45766 Mdot
.60579 .63918 Mdot
.54177 .75073 Mdot
.6939 .51777 Mdot
.50604 .3994 Mdot
.68728 .5034 Mdot
.54923 .75366 Mdot
.50876 .35046 Mdot
.58272 .45677 Mdot
.72823 .4928 Mdot
.41727 .7543 Mdot
.62722 .62276 Mdot
.55728 .74362 Mdot
.30038 .45626 Mdot
.24176 .50852 Mdot
.59327 .62447 Mdot
.57932 .47063 Mdot
.38725 .51968 Mdot
.46368 .35445 Mdot
.33644 .47355 Mdot
.60295 .70689 Mdot
.75185 .30816 Mdot
.76509 .40859 Mdot
.49184 .35581 Mdot
.63198 .62176 Mdot
.68769 .55328 Mdot
.41162 .60604 Mdot
.50306 .76114 Mdot
.43862 .31495 Mdot
.57777 .65448 Mdot
.52604 .35381 Mdot
.30955 .45035 Mdot
.39168 .63777 Mdot
.30004 .57392 Mdot
.57015 .61008 Mdot
.62085 .60325 Mdot
.55264 .39067 Mdot
.69194 .53671 Mdot
.70695 .32454 Mdot
.57475 .63299 Mdot
.63581 .60534 Mdot
.57703 .75765 Mdot
.67884 .54854 Mdot
.51426 .37647 Mdot
.26831 .44662 Mdot
.48655 .33379 Mdot
.80627 .42635 Mdot
.5683 .73143 Mdot
.34945 .4769 Mdot
.50673 .41281 Mdot
.65558 .71676 Mdot
.58792 .63519 Mdot
.55645 .51926 Mdot
.61931 .66456 Mdot
.37442 .61533 Mdot
.63699 .60749 Mdot
.49073 .40217 Mdot
.43948 .62359 Mdot
.70699 .51282 Mdot
.47086 .38052 Mdot
.55041 .37458 Mdot
.29282 .48677 Mdot
.40546 .62351 Mdot
.25329 .32298 Mdot
.38077 .65572 Mdot
.36561 .62066 Mdot
.36508 .44897 Mdot
.4994 .3691 Mdot
.59804 .63159 Mdot
.58951 .66055 Mdot
.45592 .37578 Mdot
.33038 .75745 Mdot
.31004 .46297 Mdot
.57576 .56647 Mdot
.36308 .19211 Mdot
.5876 .40877 Mdot
.54605 .75698 Mdot
.40506 .46148 Mdot
.38468 .59331 Mdot
.51372 .3883 Mdot
.35606 .45736 Mdot
.63151 .59568 Mdot
.57979 .60506 Mdot
.46055 .39135 Mdot
.39418 .63317 Mdot
.71792 .55321 Mdot
.61789 .59902 Mdot
.67923 .70977 Mdot
.52594 .40077 Mdot
.44308 .78195 Mdot
.62568 .60389 Mdot
.82001 .41086 Mdot
.72245 .65102 Mdot
.33964 .47383 Mdot
.54579 .37783 Mdot
.30886 .49948 Mdot
.70942 .52313 Mdot
.55977 .65553 Mdot
.39664 .63069 Mdot
.58044 .34736 Mdot
.17731 .44158 Mdot
.61815 .62373 Mdot
.34997 .49417 Mdot
.55442 .38965 Mdot
.59395 .37537 Mdot
.48388 .39808 Mdot
.24969 .48782 Mdot
.65666 .57069 Mdot
.42146 .60845 Mdot
.41733 .61476 Mdot
.51031 .34659 Mdot
.72569 .53429 Mdot
.58405 .6504 Mdot
.58543 .62272 Mdot
.72703 .78565 Mdot
.54222 .75365 Mdot
.68172 .40521 Mdot
.50632 .40357 Mdot
.59513 .5871 Mdot
.22235 .4213 Mdot
.40705 .60792 Mdot
.4662 .36709 Mdot
.58541 .58606 Mdot
.44771 .68126 Mdot
.60649 .50309 Mdot
.51286 .36992 Mdot
.5253 .45271 Mdot
.41654 .62632 Mdot
.69822 .46769 Mdot
.61961 .63758 Mdot
.46657 .36241 Mdot
.38885 .65984 Mdot
.62645 .74894 Mdot
.19478 .48002 Mdot
.3313 .49739 Mdot
.60924 .6669 Mdot
.37733 .61121 Mdot
.44037 .41194 Mdot
.6857 .54129 Mdot
.62615 .64264 Mdot
.58995 .60785 Mdot
.53473 .3523 Mdot
.44505 .37614 Mdot
.58861 .40649 Mdot
.35259 .48555 Mdot
.41743 .64049 Mdot
.4683 .37453 Mdot
.27828 .64904 Mdot
.49345 .34343 Mdot
.41087 .64422 Mdot
.78431 .2541 Mdot
.5078 .33032 Mdot
.48371 .39555 Mdot
.72577 .34575 Mdot
.31732 .50172 Mdot
.30025 .49563 Mdot
.31175 .71064 Mdot
.50624 .40316 Mdot
.75018 .63083 Mdot
.32569 .49771 Mdot
.31355 .4602 Mdot
.69052 .6133 Mdot
.51869 .3392 Mdot
.71782 .4733 Mdot
.3929 .64283 Mdot
.38191 .64501 Mdot
.31308 .45342 Mdot
.43726 .40406 Mdot
.37044 .61246 Mdot
.41787 .26173 Mdot
.61493 .63612 Mdot
.38776 .799 Mdot
.34338 .45847 Mdot
.42144 .50495 Mdot
.40184 .60532 Mdot
.67853 .22232 Mdot
.47672 .59812 Mdot
.50218 .3408 Mdot
.51127 .39833 Mdot
.6999 .51594 Mdot
.52584 .31859 Mdot
.56935 .73452 Mdot
.37933 .61799 Mdot
.67004 .28284 Mdot
.33879 .49269 Mdot
.47667 .39653 Mdot
.58645 .47444 Mdot
.30904 .59115 Mdot
.49398 .78169 Mdot
.31389 .47434 Mdot
.33582 .47961 Mdot
.62315 .61878 Mdot
.60764 .60051 Mdot
.50491 .36723 Mdot
.38186 .63934 Mdot
.35395 .50146 Mdot
.41823 .63406 Mdot
.61411 .60814 Mdot
.60309 .63622 Mdot
.56573 .71617 Mdot
.56787 .36906 Mdot
.58601 .649 Mdot
.66315 .72829 Mdot
.26871 .64069 Mdot
.31303 .51614 Mdot
.1877 .38122 Mdot
.29986 .57225 Mdot
.65189 .31806 Mdot
.72452 .51055 Mdot
.5687 .69817 Mdot
.43212 .62001 Mdot
.51952 .35324 Mdot
.50077 .39277 Mdot
.55776 .73055 Mdot
.43629 .60898 Mdot
.71763 .5316 Mdot
.43771 .61648 Mdot
.69358 .547 Mdot
.6389 .5989 Mdot
.5292 .42633 Mdot
.52067 .42083 Mdot
.37936 .6106 Mdot
.60085 .64676 Mdot
.58017 .63405 Mdot
.71628 .5063 Mdot
.60666 .47949 Mdot
.60144 .60896 Mdot
.34177 .45788 Mdot
.40214 .33159 Mdot
.54884 .73633 Mdot
.49058 .40732 Mdot
.6167 .45883 Mdot
.37442 .255 Mdot
.46991 .35051 Mdot
.54419 .74475 Mdot
.63231 .82439 Mdot
.4745 .40527 Mdot
.56357 .84686 Mdot
.5556 .74511 Mdot
.31726 .50248 Mdot
.63103 .61712 Mdot
.57123 .72869 Mdot
.4792 .44051 Mdot
.72301 .50261 Mdot
.46042 .40681 Mdot
.31588 .49911 Mdot
.30541 .44556 Mdot
.24622 .65804 Mdot
.80624 .42994 Mdot
.70649 .50734 Mdot
.70777 .54389 Mdot
.59331 .6225 Mdot
.81915 .593 Mdot
.45996 .42016 Mdot
.71293 .5421 Mdot
.66274 .28805 Mdot
.52736 .36011 Mdot
.67283 .4251 Mdot
.46545 .57678 Mdot
.3052 .46332 Mdot
.29641 .42592 Mdot
.58878 .62915 Mdot
.34747 .49549 Mdot
.24824 .62581 Mdot
.47261 .42169 Mdot
.33853 .49545 Mdot
.40987 .6433 Mdot
.4259 .71469 Mdot
.3042 .49091 Mdot
.61674 .48881 Mdot
.38824 .64035 Mdot
.63286 .67352 Mdot
.70339 .33762 Mdot
.14188 .40469 Mdot
.37749 .62127 Mdot
.6063 .6522 Mdot
.60209 .65935 Mdot
.58827 .62085 Mdot
.32529 .50344 Mdot
.58785 .59347 Mdot
.35498 .4767 Mdot
.78785 .487 Mdot
.60761 .4732 Mdot
.70394 .54898 Mdot
.40496 .68306 Mdot
.32877 .47734 Mdot
.36761 .75766 Mdot
.16327 .42172 Mdot
.51897 .38928 Mdot
.38426 .65767 Mdot
.67968 .54114 Mdot
.85635 .48746 Mdot
.70329 .51531 Mdot
.62283 .64013 Mdot
.39773 .80598 Mdot
.47894 .3881 Mdot
.51342 .23972 Mdot
.69727 .51367 Mdot
.31175 .48141 Mdot
.50604 .35004 Mdot
.64817 .60761 Mdot
.68873 .53417 Mdot
.72435 .5448 Mdot
.50853 .35923 Mdot
.30247 .48084 Mdot
.59986 .63497 Mdot
.43054 .62984 Mdot
.73972 .51458 Mdot
.43946 .41951 Mdot
.4717 .34362 Mdot
.49774 .42841 Mdot
.52157 .53018 Mdot
.61061 .26458 Mdot
.3799 .62226 Mdot
.75968 .43979 Mdot
.60263 .60085 Mdot
.63572 .6891 Mdot
.32646 .70807 Mdot
.37258 .67259 Mdot
.56731 .7344 Mdot
.56869 .72268 Mdot
.5114 .36682 Mdot
.61606 .26587 Mdot
.51912 .814 Mdot
.41812 .68689 Mdot
.54927 .7335 Mdot
.58228 .62664 Mdot
.34441 .43434 Mdot
.22045 .62445 Mdot
.47903 .33516 Mdot
.38427 .59134 Mdot
.6026 .60634 Mdot
.57593 .21926 Mdot
.69662 .53816 Mdot
.37294 .78215 Mdot
.55356 .38399 Mdot
.47719 .36467 Mdot
.38549 .62394 Mdot
.39886 .64763 Mdot
.48452 .76658 Mdot
.27062 .67878 Mdot
.65202 .50165 Mdot
.27886 .53283 Mdot
.55378 .22024 Mdot
.37197 .44363 Mdot
.34987 .45027 Mdot
.54032 .73296 Mdot
.38649 .65414 Mdot
.49905 .4144 Mdot
.35663 .4936 Mdot
.49351 .78311 Mdot
.27147 .48755 Mdot
.68269 .42307 Mdot
.72965 .65891 Mdot
.5443 .39213 Mdot
.32954 .4493 Mdot
.34288 .49697 Mdot
.33518 .51563 Mdot
.54571 .74731 Mdot
.4921 .38039 Mdot
.52685 .3369 Mdot
.47511 .36075 Mdot
.45309 .43824 Mdot
.5279 .39785 Mdot
.31446 .67976 Mdot
.534 .56923 Mdot
.68069 .28315 Mdot
.4782 .34458 Mdot
.37693 .64043 Mdot
.47982 .42333 Mdot
.72488 .5382 Mdot
.52416 .35169 Mdot
.67865 .41433 Mdot
.39617 .61351 Mdot
.55035 .29696 Mdot
.27258 .53006 Mdot
.55438 .37809 Mdot
.70246 .5606 Mdot
.62913 .28109 Mdot
.24229 .33896 Mdot
.5409 .60563 Mdot
.34003 .45699 Mdot
.56438 .64195 Mdot
.41902 .59583 Mdot
.59961 .62955 Mdot
.48494 .34385 Mdot
.54196 .73566 Mdot
.337 .66362 Mdot
.42321 .5074 Mdot
.50849 .41734 Mdot
.46867 .31602 Mdot
.32511 .45589 Mdot
.60163 .65344 Mdot
.37955 .49946 Mdot
.51536 .40648 Mdot
.70273 .52636 Mdot
.68918 .54014 Mdot
.2773 .6699 Mdot
.59454 .20395 Mdot
.23148 .50148 Mdot
.38391 .62343 Mdot
.57226 .62393 Mdot
.73327 .53513 Mdot
.44526 .31434 Mdot
.37562 .5947 Mdot
.38939 .59211 Mdot
.40284 .63059 Mdot
.53853 .3907 Mdot
.56919 .73245 Mdot
.6334 .25645 Mdot
.56697 .7408 Mdot
.55335 .37333 Mdot
.58589 .60716 Mdot
.5709 .71733 Mdot
.69199 .52202 Mdot
.40002 .5951 Mdot
.61632 .60691 Mdot
.52983 .38904 Mdot
.32446 .49333 Mdot
.60148 .48289 Mdot
.64142 .36937 Mdot
.77597 .38549 Mdot
.77185 .37199 Mdot
.33126 .43847 Mdot
.65786 .22224 Mdot
.39345 .66499 Mdot
.34605 .27369 Mdot
.7484 .55468 Mdot
.45747 .37809 Mdot
.26912 .71816 Mdot
.62025 .63805 Mdot
.59608 .65548 Mdot
.51695 .37483 Mdot
.61795 .59062 Mdot
.47919 .39746 Mdot
.6166 .60299 Mdot
.54282 .60412 Mdot
.48208 .33189 Mdot
.59053 .65101 Mdot
.5039 .44258 Mdot
.53644 .34391 Mdot
.30686 .4582 Mdot
.63291 .62785 Mdot
.48948 .34395 Mdot
.84436 .56135 Mdot
.39845 .65048 Mdot
.54596 .74629 Mdot
.61861 .53117 Mdot
.3782 .60776 Mdot
.34325 .48499 Mdot
.51634 .32572 Mdot
.71848 .5151 Mdot
.32231 .48361 Mdot
.58243 .56536 Mdot
.69131 .51769 Mdot
.32501 .73934 Mdot
.33492 .45442 Mdot
.55091 .73555 Mdot
.70606 .51178 Mdot
.48247 .30946 Mdot
.63176 .63747 Mdot
.62132 .34909 Mdot
.55963 .74856 Mdot
.49026 .39126 Mdot
.60306 .57901 Mdot
.39445 .65317 Mdot
.48798 .36238 Mdot
.63331 .60812 Mdot
.5463 .7501 Mdot
.53719 .38219 Mdot
.51845 .35842 Mdot
.2003 .5733 Mdot
.47221 .80195 Mdot
.72205 .53156 Mdot
.29074 .46506 Mdot
.52149 .38519 Mdot
.72328 .51223 Mdot
.70424 .72274 Mdot
.50966 .4275 Mdot
.31961 .50609 Mdot
.5337 .46955 Mdot
.60196 .59869 Mdot
.40034 .59714 Mdot
.60679 .66634 Mdot
.72901 .53394 Mdot
.31141 .79834 Mdot
.56811 .71493 Mdot
.5314 .44267 Mdot
.46455 .39354 Mdot
.58623 .69545 Mdot
.34736 .49385 Mdot
.65243 .49598 Mdot
.5065 .39926 Mdot
.42388 .41002 Mdot
.47306 .37947 Mdot
.72965 .63948 Mdot
.31116 .46335 Mdot
.48651 .39568 Mdot
.59248 .33475 Mdot
.55042 .41495 Mdot
.71256 .55812 Mdot
.73698 .38173 Mdot
.49276 .42458 Mdot
.55324 .10505 Mdot
.55097 .75625 Mdot
.58767 .65041 Mdot
.65015 .62394 Mdot
.77608 .69126 Mdot
.21841 .48824 Mdot
.35505 .48035 Mdot
.44168 .47229 Mdot
.59957 .63241 Mdot
.21604 .45035 Mdot
.69059 .24235 Mdot
.53957 .34685 Mdot
.53878 .41119 Mdot
.62285 .64012 Mdot
.60777 .58781 Mdot
.54522 .72741 Mdot
.48981 .3397 Mdot
.52775 .30308 Mdot
.56828 .62496 Mdot
.53422 .40022 Mdot
.5617 .45612 Mdot
.42881 .63066 Mdot
.29921 .4658 Mdot
.41048 .60405 Mdot
.40887 .59266 Mdot
.37406 .30852 Mdot
.30709 .69562 Mdot
.41009 .64529 Mdot
.43909 .63364 Mdot
.66993 .41556 Mdot
.52214 .47854 Mdot
.72736 .54391 Mdot
.68651 .26513 Mdot
.59419 .6176 Mdot
.49216 .37859 Mdot
.34565 .44394 Mdot
.36296 .29031 Mdot
.49757 .64921 Mdot
.43776 .82237 Mdot
.51275 .4104 Mdot
.58592 .63076 Mdot
.54965 .75151 Mdot
.47578 .33603 Mdot
.65307 .66951 Mdot
.48311 .359 Mdot
.62131 .65345 Mdot
.40855 .34079 Mdot
.59653 .43678 Mdot
.59567 .72424 Mdot
.36181 .50218 Mdot
.46983 .3962 Mdot
.34888 .46487 Mdot
.39693 .60384 Mdot
.7269 .52437 Mdot
.72158 .52793 Mdot
.51012 .35309 Mdot
.42496 .34635 Mdot
.45847 .56776 Mdot
.54227 .34805 Mdot
.53011 .34767 Mdot
.55691 .74433 Mdot
.52901 .34634 Mdot
.46366 .38944 Mdot
.47057 .3634 Mdot
.55635 .41552 Mdot
.36584 .62302 Mdot
.59656 .44157 Mdot
.57142 .38264 Mdot
.58172 .4123 Mdot
.42038 .64387 Mdot
.4175 .46627 Mdot
.41314 .59696 Mdot
.58556 .18643 Mdot
.41924 .61226 Mdot
.7182 .53827 Mdot
.58024 .5819 Mdot
.42404 .44395 Mdot
.35759 .49914 Mdot
.36404 .61266 Mdot
.70876 .53266 Mdot
.38303 .61274 Mdot
.58088 .60725 Mdot
.28111 .26494 Mdot
.27212 .48917 Mdot
.64033 .48608 Mdot
.46288 .61889 Mdot
.44955 .7815 Mdot
.6203 .62678 Mdot
.30972 .45993 Mdot
.48577 .23053 Mdot
.48439 .35003 Mdot
.69972 .51453 Mdot
.50873 .36359 Mdot
.36595 .61572 Mdot
.5872 .6257 Mdot
.78048 .42464 Mdot
.72174 .52189 Mdot
.17832 .51118 Mdot
.58534 .61876 Mdot
.52658 .33321 Mdot
.38177 .59326 Mdot
.18421 .38655 Mdot
.41769 .60643 Mdot
.60931 .47049 Mdot
.28966 .49459 Mdot
.2689 .42942 Mdot
.33291 .47319 Mdot
.51237 .77752 Mdot
.4273 .14797 Mdot
.76579 .33632 Mdot
.31664 .49103 Mdot
.60591 .73644 Mdot
.54214 .40097 Mdot
.48973 .42708 Mdot
.59495 .35715 Mdot
.29746 .49889 Mdot
.52388 .39111 Mdot
.55683 .74818 Mdot
.24994 .60663 Mdot
.65826 .68623 Mdot
.56601 .64394 Mdot
.48618 .40276 Mdot
.41967 .6436 Mdot
.43836 .61469 Mdot
.5719 .72336 Mdot
.4218 .60191 Mdot
.5206 .33664 Mdot
.33011 .47542 Mdot
.40376 .51716 Mdot
.70524 .51893 Mdot
.83042 .50409 Mdot
.70656 .56583 Mdot
.64327 .6359 Mdot
.5101 .30873 Mdot
.60337 .637 Mdot
.46186 .8791 Mdot
.49971 .34352 Mdot
.32697 .49931 Mdot
.52501 .36803 Mdot
.46772 .3839 Mdot
.49037 .42801 Mdot
.57252 .60691 Mdot
.65925 .53395 Mdot
.53387 .39754 Mdot
.39799 .63018 Mdot
.72759 .31688 Mdot
.46763 .41747 Mdot
.54444 .62798 Mdot
.7121 .40412 Mdot
.40623 .76811 Mdot
.33699 .52016 Mdot
.6008 .65204 Mdot
.33728 .48954 Mdot
.37144 .47866 Mdot
.34342 .48502 Mdot
.63581 .25217 Mdot
.47003 .24654 Mdot
.63067 .82053 Mdot
.32322 .40937 Mdot
.33244 .30267 Mdot
.29308 .45474 Mdot
.68482 .75292 Mdot
.3605 .46236 Mdot
.35069 .48442 Mdot
.90086 .48961 Mdot
.36335 .46538 Mdot
.49776 .40553 Mdot
.44849 .37067 Mdot
.29632 .60985 Mdot
.65841 .42913 Mdot
.51836 .34501 Mdot
.51979 .38042 Mdot
.72427 .51615 Mdot
.50754 .26234 Mdot
.54566 .72343 Mdot
.31943 .73766 Mdot
.32849 .57594 Mdot
.50973 .36084 Mdot
.52392 .38474 Mdot
.44201 .36923 Mdot
.36962 .15616 Mdot
.39038 .28097 Mdot
.30472 .44319 Mdot
.44968 .33111 Mdot
.82338 .44469 Mdot
.54484 .34486 Mdot
.5243 .42128 Mdot
.5431 .38493 Mdot
.59846 .63199 Mdot
.32738 .43224 Mdot
.44986 .33151 Mdot
.37773 .74333 Mdot
.55004 .39384 Mdot
.38803 .67747 Mdot
.71162 .48869 Mdot
.49175 .4019 Mdot
.31801 .51363 Mdot
.53428 .36371 Mdot
.33947 .45405 Mdot
.30619 .45597 Mdot
.44268 .36615 Mdot
.61735 .23498 Mdot
.31463 .50715 Mdot
.55199 .37709 Mdot
.59682 .6453 Mdot
.76198 .32278 Mdot
.49133 .39352 Mdot
.70812 .55231 Mdot
.50915 .39933 Mdot
.69815 .56004 Mdot
.53988 .35177 Mdot
.56311 .74611 Mdot
.36666 .24391 Mdot
.59794 .62167 Mdot
.76157 .49632 Mdot
.58556 .58971 Mdot
.20179 .57633 Mdot
.32444 .50554 Mdot
.53821 .74483 Mdot
.40032 .82168 Mdot
.55423 .74387 Mdot
.58701 .48519 Mdot
.53343 .60565 Mdot
.37755 .63613 Mdot
.29758 .49101 Mdot
.75256 .45005 Mdot
.58341 .72556 Mdot
.64035 .57029 Mdot
.56193 .61523 Mdot
.31056 .78471 Mdot
.34722 .79074 Mdot
.53358 .39025 Mdot
.53497 .23821 Mdot
.29068 .38126 Mdot
.51569 .42611 Mdot
.53331 .32969 Mdot
.63401 .63546 Mdot
.47339 .40698 Mdot
.50478 .52058 Mdot
.61619 .62059 Mdot
.70733 .53814 Mdot
.35049 .47528 Mdot
.69369 .55811 Mdot
.64233 .59096 Mdot
.54884 .5581 Mdot
.6097 .60346 Mdot
.54917 .42262 Mdot
.52452 .37203 Mdot
.31765 .4502 Mdot
.37086 .51666 Mdot
.30083 .46212 Mdot
.67893 .53407 Mdot
.61054 .61592 Mdot
.38288 .27593 Mdot
.51154 .38281 Mdot
.32252 .47476 Mdot
.37706 .56775 Mdot
.51634 .3855 Mdot
.38562 .60615 Mdot
.54395 .40391 Mdot
.31475 .49275 Mdot
.52935 .34629 Mdot
.33145 .4768 Mdot
.61236 .64543 Mdot
.55267 .35549 Mdot
.51436 .37358 Mdot
.18505 .41039 Mdot
.71784 .52899 Mdot
.32285 .50514 Mdot
.49282 .5673 Mdot
.51925 .3326 Mdot
.60719 .68926 Mdot
.48688 .41087 Mdot
.47424 .47468 Mdot
.51899 .44283 Mdot
.55305 .74767 Mdot
.5662 .34752 Mdot
.49044 .39356 Mdot
.59996 .33428 Mdot
.32911 .39579 Mdot
.382 .49599 Mdot
.37038 .60673 Mdot
.31264 .51087 Mdot
.63906 .61488 Mdot
.62517 .58975 Mdot
.61105 .59451 Mdot
.6481 .44818 Mdot
.44261 .37122 Mdot
.4803 .38735 Mdot
.35953 .62406 Mdot
.70399 .54463 Mdot
.31531 .47572 Mdot
.69934 .54531 Mdot
.31045 .72191 Mdot
.68038 .53144 Mdot
.57066 .72972 Mdot
.7205 .65426 Mdot
.4019 .24902 Mdot
.7227 .51448 Mdot
.30007 .46362 Mdot
.71996 .66873 Mdot
.45896 .37432 Mdot
.58244 .56111 Mdot
.70071 .52749 Mdot
.27812 .76572 Mdot
.49435 .41639 Mdot
.57302 .50593 Mdot
.42619 .62145 Mdot
.68535 .53632 Mdot
.4067 .61938 Mdot
.51516 .3472 Mdot
.42802 .75882 Mdot
.35144 .49384 Mdot
.40869 .65667 Mdot
.57299 .38024 Mdot
.68676 .55057 Mdot
.59757 .60705 Mdot
.45603 .64545 Mdot
.3767 .63957 Mdot
.35966 .23127 Mdot
.76585 .4107 Mdot
.61219 .61725 Mdot
.53756 .80146 Mdot
.40861 .62956 Mdot
.5108 .42625 Mdot
.42975 .43711 Mdot
.50839 .3377 Mdot
.62706 .5874 Mdot
.5984 .65305 Mdot
.2708 .61521 Mdot
.52711 .372 Mdot
.49099 .41422 Mdot
.28065 .45484 Mdot
.61583 .6298 Mdot
.33113 .46239 Mdot
.33795 .5161 Mdot
.60981 .65072 Mdot
.33844 .47162 Mdot
.69485 .51614 Mdot
.23732 .57377 Mdot
.40895 .63052 Mdot
.39741 .62634 Mdot
.58308 .62561 Mdot
.57572 .64124 Mdot
.6053 .63758 Mdot
.54417 .40359 Mdot
.31116 .47089 Mdot
.54481 .37152 Mdot
.51434 .42869 Mdot
.34591 .52048 Mdot
.36536 .46556 Mdot
.53895 .3724 Mdot
.60076 .7065 Mdot
.73364 .5023 Mdot
.58793 .64727 Mdot
.41966 .63374 Mdot
.223 .44416 Mdot
.35671 .62581 Mdot
.48501 .40387 Mdot
.46508 .6689 Mdot
.31108 .48857 Mdot
.70016 .51631 Mdot
.73186 .49485 Mdot
.71112 .51418 Mdot
.37831 .58636 Mdot
.34489 .50882 Mdot
.32467 .73765 Mdot
.48197 .39938 Mdot
.5176 .53017 Mdot
.75567 .44262 Mdot
.33429 .71944 Mdot
.41289 .64306 Mdot
.51923 .38411 Mdot
.55205 .74235 Mdot
.45923 .23418 Mdot
.48011 .3631 Mdot
.47521 .35372 Mdot
.7353 .59681 Mdot
.58258 .41124 Mdot
.29712 .50063 Mdot
.25051 .66562 Mdot
.44814 .38066 Mdot
.25677 .4756 Mdot
.79058 .70732 Mdot
.48031 .40478 Mdot
.52055 .40433 Mdot
.49898 .38588 Mdot
.52633 .36156 Mdot
.29692 .50488 Mdot
.69747 .46092 Mdot
.37959 .59467 Mdot
.53345 .54035 Mdot
.40481 .63701 Mdot
.62295 .64983 Mdot
.56095 .50644 Mdot
.29696 .48123 Mdot
.70317 .5142 Mdot
.42195 .20937 Mdot
.28872 .70029 Mdot
.62288 .62103 Mdot
.41421 .28713 Mdot
.70611 .52149 Mdot
.45664 .37603 Mdot
.67415 .55148 Mdot
.60143 .58699 Mdot
.39356 .63786 Mdot
.45108 .36565 Mdot
.33428 .44269 Mdot
.30476 .49252 Mdot
.52028 .38986 Mdot
.80701 .414 Mdot
.38895 .60282 Mdot
.34925 .62262 Mdot
.54023 .39188 Mdot
.4762 .3525 Mdot
.33815 .46332 Mdot
.58885 .64188 Mdot
.63259 .7601 Mdot
.71421 .53255 Mdot
.56169 .3652 Mdot
.5265 .35791 Mdot
.29698 .69409 Mdot
.39197 .59461 Mdot
.5527 .72312 Mdot
.53706 .38698 Mdot
.30218 .68644 Mdot
.53673 .38478 Mdot
.51673 .31704 Mdot
.59941 .64039 Mdot
.48904 .43616 Mdot
.52941 .41428 Mdot
.45604 .3178 Mdot
.40946 .62436 Mdot
.33604 .498 Mdot
.27652 .47417 Mdot
.54373 .73706 Mdot
.38613 .60678 Mdot
.53703 .36926 Mdot
.38691 .59831 Mdot
.49222 .42645 Mdot
.53148 .39699 Mdot
.41207 .64321 Mdot
.33169 .46272 Mdot
.34249 .59552 Mdot
.58987 .46769 Mdot
.52708 .36541 Mdot
.46655 .34773 Mdot
.65594 .44221 Mdot
.49301 .84866 Mdot
.50876 .41122 Mdot
.3111 .49351 Mdot
.51394 .37971 Mdot
.4033 .61249 Mdot
.68058 .53567 Mdot
.32022 .49353 Mdot
.57718 .6324 Mdot
.61721 .64291 Mdot
.2678 .52743 Mdot
.57067 .72038 Mdot
.47728 .33905 Mdot
.3962 .438 Mdot
.35388 .44791 Mdot
.83255 .60575 Mdot
.60188 .65892 Mdot
.71432 .55836 Mdot
.51691 .35499 Mdot
.46912 .63415 Mdot
.35961 .61869 Mdot
.54821 .10217 Mdot
.32876 .7385 Mdot
.68232 .5715 Mdot
.4275 .82249 Mdot
.55413 .73599 Mdot
.51744 .41906 Mdot
.72733 .52882 Mdot
.62749 .61885 Mdot
.46973 .40952 Mdot
.53377 .45076 Mdot
.64364 .50077 Mdot
.57785 .67232 Mdot
.39266 .59691 Mdot
.60488 .5962 Mdot
.67778 .51973 Mdot
.5702 .73174 Mdot
.29992 .48571 Mdot
.48742 .39172 Mdot
.44192 .35854 Mdot
.58189 .63875 Mdot
.56319 .74653 Mdot
.54503 .39138 Mdot
.3056 .49747 Mdot
.61801 .59253 Mdot
.50659 .35639 Mdot
.34565 .27929 Mdot
.37029 .48751 Mdot
.60325 .61195 Mdot
.46478 .39054 Mdot
.47832 .47017 Mdot
.57971 .62792 Mdot
.58241 .6444 Mdot
.52404 .39059 Mdot
.70113 .51276 Mdot
.5483 .40313 Mdot
.42206 .61567 Mdot
.65993 .53035 Mdot
.40187 .61488 Mdot
.76609 .53136 Mdot
.52645 .31188 Mdot
.46462 .78342 Mdot
.30273 .45317 Mdot
.68467 .51061 Mdot
.22224 .3795 Mdot
.47396 .35202 Mdot
.64156 .22153 Mdot
.43063 .50485 Mdot
.84549 .48971 Mdot
.42398 .17088 Mdot
.69905 .53174 Mdot
.38687 .60949 Mdot
.52028 .40361 Mdot
.37358 .65422 Mdot
.72461 .53102 Mdot
.76683 .44755 Mdot
.46363 .3848 Mdot
.31306 .46139 Mdot
.54894 .39403 Mdot
.34072 .45702 Mdot
.5152 .38751 Mdot
.5827 .40477 Mdot
.67467 .57445 Mdot
.61211 .46905 Mdot
.45812 .37417 Mdot
.27936 .26467 Mdot
.48798 .60254 Mdot
.70826 .52572 Mdot
.54874 .37401 Mdot
.56279 .72585 Mdot
.43424 .60387 Mdot
.60485 .27811 Mdot
.60112 .63406 Mdot
.41511 .64418 Mdot
.34418 .47277 Mdot
.59132 .65976 Mdot
.54679 .75305 Mdot
.43295 .38316 Mdot
.70619 .55869 Mdot
.37557 .631 Mdot
.49085 .39727 Mdot
.49528 .41615 Mdot
.62295 .72917 Mdot
.49834 .70136 Mdot
.30874 .43551 Mdot
.17849 .47359 Mdot
.30571 .51314 Mdot
.71464 .53905 Mdot
.6012 .6399 Mdot
.50496 .41166 Mdot
.49135 .35814 Mdot
.63247 .59238 Mdot
.32553 .50464 Mdot
.59523 .67343 Mdot
.39177 .30096 Mdot
.57263 .64451 Mdot
.71024 .43736 Mdot
.32134 .49873 Mdot
.70715 .44058 Mdot
.67743 .51961 Mdot
.58661 .21238 Mdot
.65995 .36015 Mdot
.42668 .62074 Mdot
.71457 .4348 Mdot
.31267 .48282 Mdot
.52928 .38092 Mdot
.55295 .73307 Mdot
.56711 .71756 Mdot
.34701 .46921 Mdot
.6245 .63842 Mdot
.68635 .5373 Mdot
.52388 .40455 Mdot
.3945 .77977 Mdot
.28282 .57193 Mdot
.57158 .62716 Mdot
.5686 .44393 Mdot
.40432 .62458 Mdot
.5269 .41293 Mdot
.70275 .55439 Mdot
.37899 .6316 Mdot
.56318 .75751 Mdot
.25133 .60021 Mdot
.51076 .35001 Mdot
.26753 .67051 Mdot
.3797 .61157 Mdot
.54518 .80575 Mdot
.50346 .36453 Mdot
.40867 .62924 Mdot
.57863 .35725 Mdot
.36316 .72007 Mdot
.46104 .5389 Mdot
.70446 .25699 Mdot
.56442 .66067 Mdot
.62197 .63855 Mdot
.42918 .72482 Mdot
.70504 .5784 Mdot
.41015 .65013 Mdot
.56974 .73365 Mdot
.69669 .34658 Mdot
.40735 .6216 Mdot
.53274 .41885 Mdot
.48544 .40933 Mdot
.37049 .30482 Mdot
.48373 .53721 Mdot
.56744 .74159 Mdot
.22312 .51314 Mdot
.50758 .33538 Mdot
.55891 .42659 Mdot
.49022 .36429 Mdot
.30519 .44527 Mdot
.37513 .61112 Mdot
.19751 .36184 Mdot
.39584 .60129 Mdot
.40237 .79053 Mdot
.59345 .61831 Mdot
.57099 .63682 Mdot
.49073 .40358 Mdot
.49697 .79277 Mdot
.5945 .2591 Mdot
.53146 .33834 Mdot
.61972 .68556 Mdot
.76049 .40191 Mdot
.57514 .40878 Mdot
.28494 .48824 Mdot
.45719 .33794 Mdot
.38029 .46526 Mdot
.38977 .64378 Mdot
.69395 .53597 Mdot
.73708 .50886 Mdot
.37805 .63465 Mdot
.48107 .38516 Mdot
.64754 .65456 Mdot
.47387 .37255 Mdot
.53468 .38771 Mdot
.36671 .78148 Mdot
.72954 .54425 Mdot
.60805 .63868 Mdot
.72173 .5252 Mdot
.35076 .48577 Mdot
.85504 .33463 Mdot
.69723 .54787 Mdot
.39728 .42287 Mdot
.73911 .47625 Mdot
.71401 .43774 Mdot
.30333 .49291 Mdot
.6877 .51473 Mdot
.39821 .59802 Mdot
.852 .47181 Mdot
.52874 .83453 Mdot
.35831 .6429 Mdot
.50076 .36037 Mdot
.29618 .4701 Mdot
.32326 .43987 Mdot
.39956 .66193 Mdot
.30299 .46809 Mdot
.5191 .30259 Mdot
.5308 .37446 Mdot
.40934 .65036 Mdot
.29025 .59569 Mdot
.3737 .63597 Mdot
.23166 .58241 Mdot
.54913 .38204 Mdot
.3222 .49681 Mdot
.46665 .32397 Mdot
.27177 .47939 Mdot
.55354 .71918 Mdot
.47003 .41108 Mdot
.6882 .52715 Mdot
.49274 .5286 Mdot
.60165 .6137 Mdot
.46939 .66353 Mdot
.31847 .45128 Mdot
.35508 .5772 Mdot
.30606 .45865 Mdot
.29335 .4739 Mdot
.41056 .5927 Mdot
.35744 .48287 Mdot
.52131 .40499 Mdot
.60373 .72382 Mdot
.3451 .45416 Mdot
.38938 .62018 Mdot
.69294 .52663 Mdot
.33619 .46809 Mdot
.62712 .65049 Mdot
.51721 .3646 Mdot
.61035 .60119 Mdot
.68635 .57453 Mdot
.29856 .49409 Mdot
.68809 .51549 Mdot
.59143 .65376 Mdot
.71562 .55327 Mdot
.78663 .44463 Mdot
.38342 .65205 Mdot
.44531 .8232 Mdot
.55849 .46944 Mdot
.33666 .44308 Mdot
.63152 .56674 Mdot
.50543 .41003 Mdot
.51823 .36249 Mdot
.68842 .51067 Mdot
.32635 .43914 Mdot
.77835 .34821 Mdot
.45506 .46978 Mdot
.24349 .58064 Mdot
.37038 .63966 Mdot
.19217 .48796 Mdot
.27618 .645 Mdot
.81018 .56646 Mdot
.47759 .43573 Mdot
.5543 .73533 Mdot
.47466 .38987 Mdot
.22845 .35442 Mdot
.68116 .54578 Mdot
.62782 .78786 Mdot
.45729 .41703 Mdot
.60891 .62992 Mdot
.50405 .37522 Mdot
.59486 .29833 Mdot
.46599 .33042 Mdot
.71607 .50882 Mdot
.38865 .68354 Mdot
.35711 .49943 Mdot
.70596 .51953 Mdot
.61774 .63996 Mdot
.71741 .37783 Mdot
.46681 .40574 Mdot
.50623 .33332 Mdot
.56662 .63469 Mdot
.30965 .46199 Mdot
.62815 .64312 Mdot
.40862 .63091 Mdot
.69658 .5425 Mdot
.52051 .35529 Mdot
.53593 .43601 Mdot
.62502 .6758 Mdot
.37434 .61119 Mdot
.57967 .65096 Mdot
.41036 .60289 Mdot
.55351 .73507 Mdot
.45559 .36501 Mdot
.56636 .62648 Mdot
.49804 .41965 Mdot
.20651 .39381 Mdot
.37669 .78902 Mdot
.35291 .38953 Mdot
.61098 .63818 Mdot
.69948 .41926 Mdot
.39777 .61122 Mdot
.41715 .60934 Mdot
.25644 .4351 Mdot
.62421 .27512 Mdot
.74406 .6396 Mdot
.37555 .219 Mdot
.40867 .63162 Mdot
.3993 .61839 Mdot
.62855 .61224 Mdot
.35722 .47419 Mdot
.36791 .44834 Mdot
.59413 .66438 Mdot
.61801 .46276 Mdot
.31547 .47572 Mdot
.65438 .22896 Mdot
.63942 .62091 Mdot
.47963 .43796 Mdot
.55248 .71199 Mdot
.69057 .53942 Mdot
.61576 .46354 Mdot
.58915 .29591 Mdot
.50573 .41483 Mdot
.23235 .64777 Mdot
.59094 .63912 Mdot
.67159 .47732 Mdot
.57844 .18587 Mdot
.46384 .3776 Mdot
.49557 .37516 Mdot
.48144 .3797 Mdot
.73277 .53991 Mdot
.23364 .36472 Mdot
.50701 .41615 Mdot
.61941 .47438 Mdot
.54009 .33575 Mdot
.63407 .34507 Mdot
.72187 .52824 Mdot
.25744 .49784 Mdot
.56357 .65485 Mdot
.35556 .73311 Mdot
.59517 .36207 Mdot
.41324 .61815 Mdot
.57844 .5753 Mdot
.39728 .64078 Mdot
.60426 .24656 Mdot
.6628 .36348 Mdot
.28791 .45848 Mdot
.51403 .41115 Mdot
.56798 .60008 Mdot
.30253 .45577 Mdot
.57278 .75888 Mdot
.90117 .45923 Mdot
.37312 .60836 Mdot
.49615 .86817 Mdot
.41675 .60746 Mdot
.56042 .71651 Mdot
.34078 .46469 Mdot
.45382 .26348 Mdot
.51627 .52933 Mdot
.33599 .46999 Mdot
.33584 .65563 Mdot
.30145 .51447 Mdot
.70805 .42421 Mdot
.35847 .50269 Mdot
.39141 .61616 Mdot
.42556 .5819 Mdot
.52116 .4489 Mdot
.50418 .40537 Mdot
.56155 .53984 Mdot
.4109 .43995 Mdot
.50703 .40699 Mdot
.61611 .62087 Mdot
.5101 .82291 Mdot
.55631 .60348 Mdot
.35258 .4542 Mdot
.37796 .59813 Mdot
.49756 .37493 Mdot
.5323 .37183 Mdot
.49738 .42262 Mdot
.17928 .41718 Mdot
.66095 .23617 Mdot
.53294 .39524 Mdot
.56332 .37635 Mdot
.61273 .64325 Mdot
.67469 .51437 Mdot
.31513 .24828 Mdot
.68659 .34895 Mdot
.48756 .35234 Mdot
.71871 .52475 Mdot
.71469 .56035 Mdot
.46018 .39579 Mdot
.40203 .77287 Mdot
.60038 .7349 Mdot
.49103 .39699 Mdot
.64613 .33558 Mdot
.62484 .57898 Mdot
.57225 .72431 Mdot
.58163 .63715 Mdot
.32322 .51547 Mdot
.56648 .73655 Mdot
.59188 .58932 Mdot
.45125 .25821 Mdot
.54272 .73866 Mdot
.34075 .69172 Mdot
.67889 .5342 Mdot
.48711 .36277 Mdot
.2931 .50591 Mdot
.62815 .58938 Mdot
.37893 .63707 Mdot
.32953 .48654 Mdot
.43711 .60717 Mdot
.66916 .56834 Mdot
.64763 .47478 Mdot
.56914 .71645 Mdot
.41367 .625 Mdot
.25083 .60083 Mdot
.71974 .52553 Mdot
.41924 .60123 Mdot
.49971 .78899 Mdot
.45913 .41229 Mdot
.53442 .21979 Mdot
.5493 .35516 Mdot
.82637 .43918 Mdot
.41217 .5982 Mdot
.54107 .74434 Mdot
.48193 .39008 Mdot
.58442 .61985 Mdot
.55616 .32433 Mdot
.48496 .35683 Mdot
.57563 .62254 Mdot
.53269 .38829 Mdot
.70803 .55356 Mdot
.37631 .48464 Mdot
.40368 .50853 Mdot
.17894 .62419 Mdot
.70888 .5565 Mdot
.56243 .76893 Mdot
.51005 .4111 Mdot
.77742 .42078 Mdot
.33397 .46789 Mdot
.46655 .36597 Mdot
.24304 .44843 Mdot
.35309 .46513 Mdot
.33682 .4864 Mdot
.53596 .35462 Mdot
.42556 .61155 Mdot
.59094 .61436 Mdot
.71923 .5221 Mdot
.82509 .5659 Mdot
.50006 .35296 Mdot
.51396 .37646 Mdot
.70555 .52091 Mdot
.40087 .61655 Mdot
.5319 .36926 Mdot
.48411 .65793 Mdot
.84698 .54045 Mdot
.40219 .58921 Mdot
.47029 .42147 Mdot
.47892 .20515 Mdot
.27231 .45626 Mdot
.4964 .85811 Mdot
.75664 .51415 Mdot
.60043 .65059 Mdot
.58293 .40121 Mdot
.61799 .14109 Mdot
.6925 .53536 Mdot
.34255 .73437 Mdot
.5375 .39857 Mdot
.50652 .38493 Mdot
.30495 .48274 Mdot
.54168 .37051 Mdot
.34192 .50049 Mdot
.20664 .67818 Mdot
.16422 .53467 Mdot
.318 .45507 Mdot
.35202 .4509 Mdot
.2673 .44347 Mdot
.29658 .26761 Mdot
.34813 .47605 Mdot
.48063 .42698 Mdot
.72798 .30629 Mdot
.43272 .39735 Mdot
.69273 .50725 Mdot
.7172 .56602 Mdot
.28268 .52241 Mdot
.52536 .7398 Mdot
.41799 .45941 Mdot
.58002 .32509 Mdot
.45948 .57718 Mdot
.42057 .62374 Mdot
.47919 .35592 Mdot
.57054 .71884 Mdot
.60303 .59261 Mdot
.46984 .33125 Mdot
.48219 .36492 Mdot
.34186 .45555 Mdot
.73684 .52225 Mdot
.42679 .6004 Mdot
.51959 .37982 Mdot
.59598 .67603 Mdot
.71053 .53677 Mdot
.34635 .4519 Mdot
.27084 .43179 Mdot
.73122 .52977 Mdot
.5667 .34667 Mdot
.50796 .39688 Mdot
.54422 .3913 Mdot
.58801 .40414 Mdot
.39363 .6486 Mdot
.64007 .59193 Mdot
.51961 .43018 Mdot
.31086 .71931 Mdot
.59825 .50394 Mdot
.51634 .4383 Mdot
.3098 .47718 Mdot
.36034 .6143 Mdot
.54883 .72516 Mdot
.73881 .4022 Mdot
.50656 .34935 Mdot
.66083 .23833 Mdot
.39075 .28673 Mdot
.56583 .73577 Mdot
.28935 .46347 Mdot
.70408 .51453 Mdot
.51666 .33718 Mdot
.68625 .27835 Mdot
.48596 .40834 Mdot
.52738 .47702 Mdot
.59383 .64556 Mdot
.41876 .62911 Mdot
.85134 .50886 Mdot
.59825 .59265 Mdot
.33714 .48869 Mdot
.71029 .25578 Mdot
.3504 .43902 Mdot
.35636 .4976 Mdot
.61735 .23943 Mdot
.39867 .64655 Mdot
.60002 .13173 Mdot
.51509 .84327 Mdot
.53959 .42156 Mdot
.40326 .60854 Mdot
.33669 .45869 Mdot
.52727 .41211 Mdot
.35501 .45033 Mdot
.35061 .50091 Mdot
.47245 .41498 Mdot
.50702 .39218 Mdot
.58609 .47778 Mdot
.61494 .203 Mdot
.71312 .51317 Mdot
.31626 .50177 Mdot
.32754 .31394 Mdot
.51073 .41739 Mdot
.48237 .39922 Mdot
.58506 .69976 Mdot
.71711 .50938 Mdot
.58563 .30534 Mdot
.53629 .3872 Mdot
.19115 .57282 Mdot
.46375 .35017 Mdot
.28431 .49237 Mdot
.4033 .58934 Mdot
.38995 .7652 Mdot
.63311 .59009 Mdot
.3142 .50424 Mdot
.68819 .55437 Mdot
.27941 .46049 Mdot
.38371 .41914 Mdot
.39606 .64466 Mdot
.31473 .49274 Mdot
.614 .65957 Mdot
.38673 .63353 Mdot
.41729 .60055 Mdot
.72745 .31599 Mdot
.58303 .65592 Mdot
.67705 .53855 Mdot
.39766 .63659 Mdot
.34234 .27626 Mdot
.38722 .61542 Mdot
.34466 .31146 Mdot
.55641 .36511 Mdot
.62919 .4743 Mdot
.29266 .65521 Mdot
.58367 .41709 Mdot
.38744 .65011 Mdot
.72415 .52713 Mdot
.53079 .35524 Mdot
.30276 .47056 Mdot
.69566 .54743 Mdot
.43504 .66373 Mdot
.5791 .64338 Mdot
.31439 .44882 Mdot
.38249 .59207 Mdot
.32042 .50099 Mdot
.74228 .45301 Mdot
.64794 .5376 Mdot
.45851 .58895 Mdot
.53614 .52733 Mdot
.50438 .42393 Mdot
.34978 .54301 Mdot
.47463 .33996 Mdot
.48001 .36494 Mdot
.60225 .61207 Mdot
.64819 .44975 Mdot
.3321 .4623 Mdot
.85456 .51334 Mdot
.41567 .62615 Mdot
.20934 .61224 Mdot
.46063 .46537 Mdot
.48176 .34948 Mdot
.3473 .45618 Mdot
.36073 .44729 Mdot
.33352 .39583 Mdot
.63551 .6007 Mdot
.54924 .44927 Mdot
.54036 .32172 Mdot
.52086 .44665 Mdot
.41117 .59816 Mdot
.46475 .68233 Mdot
.62633 .63954 Mdot
.63738 .82458 Mdot
.58733 .64529 Mdot
.69766 .61713 Mdot
.3584 .48121 Mdot
.68186 .53832 Mdot
.48431 .39966 Mdot
.52851 .48359 Mdot
.28496 .47937 Mdot
.74341 .49813 Mdot
.69095 .52249 Mdot
.41593 .71314 Mdot
.40781 .64663 Mdot
.45894 .38683 Mdot
.4691 .40027 Mdot
.54596 .36866 Mdot
.55538 .37025 Mdot
.37755 .60054 Mdot
.53017 .41996 Mdot
.40142 .65706 Mdot
.3591 .26894 Mdot
.18988 .57847 Mdot
.58487 .58367 Mdot
.61085 .27548 Mdot
.3303 .44392 Mdot
.31487 .29795 Mdot
.53127 .46143 Mdot
.38969 .79734 Mdot
.77606 .40148 Mdot
.49719 .33146 Mdot
.63021 .62305 Mdot
.56277 .25875 Mdot
.57836 .59052 Mdot
.27742 .80074 Mdot
.65763 .59931 Mdot
.68171 .23588 Mdot
.52208 .41218 Mdot
.58748 .69725 Mdot
.51035 .46576 Mdot
.46301 .40556 Mdot
.65908 .58142 Mdot
.21157 .52314 Mdot
.30335 .6281 Mdot
.72453 .54952 Mdot
.51372 .36103 Mdot
.36226 .49244 Mdot
.52184 .40649 Mdot
.4784 .39841 Mdot
.53397 .41114 Mdot
.40115 .58746 Mdot
.45067 .36142 Mdot
.54012 .412 Mdot
.50754 .6954 Mdot
.67677 .42466 Mdot
.60155 .59698 Mdot
.34826 .40829 Mdot
.7035 .54432 Mdot
.33334 .45203 Mdot
.50657 .50521 Mdot
.42603 .62359 Mdot
.29298 .40055 Mdot
.54633 .40094 Mdot
.28288 .64043 Mdot
.38157 .59264 Mdot
.69327 .54421 Mdot
.54548 .73537 Mdot
.73539 .29973 Mdot
.58935 .58356 Mdot
.54288 .73664 Mdot
.60087 .61492 Mdot
.2395 .36894 Mdot
.3438 .45679 Mdot
.50012 .42435 Mdot
.40233 .62994 Mdot
.59045 .61228 Mdot
.65078 .43105 Mdot
.48798 .36807 Mdot
.61475 .63562 Mdot
.50713 .42527 Mdot
.6389 .48486 Mdot
.62659 .73227 Mdot
.57974 .59206 Mdot
.40501 .58137 Mdot
.38942 .63034 Mdot
.6915 .5184 Mdot
.32868 .45004 Mdot
.3101 .48611 Mdot
.37974 .63123 Mdot
.45041 .85162 Mdot
.4837 .35674 Mdot
.52277 .41391 Mdot
.31136 .71719 Mdot
.51518 .40218 Mdot
.71984 .39576 Mdot
.55883 .71157 Mdot
.33154 .44804 Mdot
.53142 .40962 Mdot
.52922 .36629 Mdot
.51399 .352 Mdot
.73821 .45577 Mdot
.58308 .64108 Mdot
.50946 .33572 Mdot
.72629 .51583 Mdot
.49077 .76782 Mdot
.51842 .41666 Mdot
.54895 .43341 Mdot
.31367 .48752 Mdot
.17004 .55515 Mdot
.4245 .61674 Mdot
.61953 .62005 Mdot
.58732 .65205 Mdot
.73527 .55879 Mdot
.35283 .51589 Mdot
.54763 .72124 Mdot
.77811 .67493 Mdot
.54849 .74732 Mdot
.71084 .52286 Mdot
.7622 .57442 Mdot
.60847 .67641 Mdot
.62329 .61258 Mdot
.43639 .63293 Mdot
.55048 .3943 Mdot
.51988 .33413 Mdot
.34639 .74028 Mdot
.49889 .3378 Mdot
.69181 .52473 Mdot
.41337 .65005 Mdot
.31567 .48278 Mdot
.68932 .54254 Mdot
.41068 .60505 Mdot
.30814 .46394 Mdot
.45742 .40896 Mdot
.45347 .40656 Mdot
.3327 .48445 Mdot
.30078 .45972 Mdot
.49639 .39944 Mdot
.48887 .69952 Mdot
.33413 .51761 Mdot
.31715 .49553 Mdot
.57321 .71802 Mdot
.58515 .58445 Mdot
.4411 .34993 Mdot
.40215 .60658 Mdot
.54271 .39221 Mdot
.58045 .58789 Mdot
.71001 .50759 Mdot
.32765 .46537 Mdot
.52872 .3686 Mdot
.52439 .37768 Mdot
.71704 .52079 Mdot
.73399 .52661 Mdot
.6866 .54146 Mdot
.37834 .65919 Mdot
.54824 .35948 Mdot
.34659 .47775 Mdot
.40606 .64594 Mdot
.71461 .56035 Mdot
.67734 .55572 Mdot
.52791 .69475 Mdot
.50159 .41295 Mdot
.45834 .54243 Mdot
.83043 .3083 Mdot
.70601 .36705 Mdot
.5499 .72283 Mdot
.57052 .64303 Mdot
.68104 .45122 Mdot
.61961 .71935 Mdot
.38081 .60658 Mdot
.67841 .31248 Mdot
.68525 .51029 Mdot
.49334 .42459 Mdot
.46463 .35019 Mdot
.54175 .33261 Mdot
.70489 .53757 Mdot
.7467 .43814 Mdot
.32785 .43786 Mdot
.27712 .36392 Mdot
.70323 .5442 Mdot
.58153 .59103 Mdot
.56603 .62079 Mdot
.58782 .64565 Mdot
.45071 .37662 Mdot
.31994 .39433 Mdot
.32398 .30024 Mdot
.29221 .28428 Mdot
.41196 .64594 Mdot
.326 .43193 Mdot
.78326 .4388 Mdot
.33645 .4838 Mdot
.60127 .59134 Mdot
.70833 .5343 Mdot
.30823 .4909 Mdot
.37253 .62406 Mdot
.39998 .62021 Mdot
.57733 .6378 Mdot
.58434 .62498 Mdot
.60253 .60214 Mdot
.33437 .51426 Mdot
.35773 .48221 Mdot
.50684 .34606 Mdot
.32733 .47272 Mdot
.24739 .67521 Mdot
.68949 .57145 Mdot
.56916 .60669 Mdot
.3901 .60665 Mdot
.3368 .45555 Mdot
.49138 .36095 Mdot
.75228 .6097 Mdot
.29444 .54604 Mdot
.71633 .55126 Mdot
.61137 .74785 Mdot
.32433 .83089 Mdot
.47101 .40699 Mdot
.39379 .59576 Mdot
.4225 .78339 Mdot
.48479 .37592 Mdot
.59708 .63424 Mdot
.21543 .36845 Mdot
.55373 .75122 Mdot
.53684 .41399 Mdot
.49122 .34211 Mdot
.42115 .60108 Mdot
.74833 .47923 Mdot
.50883 .34321 Mdot
.25118 .6335 Mdot
.42668 .59286 Mdot
.63334 .61183 Mdot
.85042 .54811 Mdot
.64995 .60174 Mdot
.61596 .44936 Mdot
.56277 .7187 Mdot
.46783 .38882 Mdot
.61511 .61604 Mdot
.72166 .54478 Mdot
.60752 .60691 Mdot
.28802 .46161 Mdot
.60296 .59884 Mdot
.51259 .37705 Mdot
.34833 .47989 Mdot
.38049 .61015 Mdot
.25285 .66866 Mdot
.50299 .70965 Mdot
.5837 .62076 Mdot
.57386 .71565 Mdot
.52363 .4185 Mdot
.60126 .35394 Mdot
.54538 .31406 Mdot
.51654 .41518 Mdot
.39865 .64173 Mdot
.34882 .45582 Mdot
.36533 .62736 Mdot
.55851 .42041 Mdot
.19514 .52528 Mdot
.41698 .60521 Mdot
.32812 .67472 Mdot
.70734 .52143 Mdot
.6011 .47062 Mdot
.49177 .35609 Mdot
.40178 .63388 Mdot
.54927 .36185 Mdot
.36599 .46464 Mdot
.50948 .56524 Mdot
.49696 .77805 Mdot
.40169 .62923 Mdot
.79547 .37033 Mdot
.49444 .57437 Mdot
.45235 .3407 Mdot
.4058 .63387 Mdot
.24248 .40376 Mdot
.55881 .72121 Mdot
.71469 .53022 Mdot
.71742 .55801 Mdot
.71655 .5534 Mdot
.48455 .34091 Mdot
.514 .45547 Mdot
.67669 .54922 Mdot
.42061 .59231 Mdot
.7183 .50887 Mdot
.55571 .48449 Mdot
.79057 .36149 Mdot
.68952 .55195 Mdot
.50473 .3608 Mdot
.55723 .42976 Mdot
.67351 .42547 Mdot
.6137 .59064 Mdot
.63732 .2194 Mdot
.44954 .30585 Mdot
.50144 .40706 Mdot
.42918 .39494 Mdot
.30741 .44807 Mdot
.46935 .79866 Mdot
.43555 .45104 Mdot
.61359 .73041 Mdot
.36309 .46832 Mdot
.64473 .63297 Mdot
.33128 .44913 Mdot
.47908 .41392 Mdot
.53126 .39859 Mdot
.37792 .46051 Mdot
.42376 .69303 Mdot
.4173 .75009 Mdot
.82907 .49836 Mdot
.31263 .49593 Mdot
.40923 .62462 Mdot
.3731 .60728 Mdot
.41588 .64145 Mdot
.63853 .61302 Mdot
.30027 .49747 Mdot
.53679 .34676 Mdot
.61072 .64777 Mdot
.47928 .35871 Mdot
.39155 .63674 Mdot
.85217 .50324 Mdot
.31425 .48602 Mdot
.49025 .39437 Mdot
.52645 .83386 Mdot
.58977 .62701 Mdot
.71931 .53091 Mdot
.64829 .48417 Mdot
.6377 .63284 Mdot
.37923 .64398 Mdot
.36566 .44788 Mdot
.38209 .67549 Mdot
.46432 .50082 Mdot
.43455 .39219 Mdot
.48519 .43305 Mdot
.81968 .58868 Mdot
.52528 .77393 Mdot
.46354 .35573 Mdot
.61874 .63859 Mdot
.6127 .58641 Mdot
.5249 .36699 Mdot
.29979 .48908 Mdot
.6951 .56372 Mdot
.72771 .51613 Mdot
.57012 .35871 Mdot
.52126 .53091 Mdot
.60026 .47753 Mdot
.53764 .37237 Mdot
.57642 .42931 Mdot
.58327 .65152 Mdot
.54402 .74578 Mdot
.3103 .70156 Mdot
.68456 .55239 Mdot
.53845 .39676 Mdot
.32525 .62097 Mdot
.35315 .49449 Mdot
.60472 .6002 Mdot
.38557 .64551 Mdot
.75808 .45642 Mdot
.62635 .64908 Mdot
.52622 .36859 Mdot
.53139 .36876 Mdot
.42061 .60188 Mdot
.2841 .49187 Mdot
.70599 .53494 Mdot
.60747 .64804 Mdot
.68278 .55206 Mdot
.35209 .48685 Mdot
.31787 .48478 Mdot
.43243 .39679 Mdot
.5794 .41697 Mdot
.57885 .63408 Mdot
.56864 .39157 Mdot
.58811 .59136 Mdot
.75987 .4879 Mdot
.36459 .60918 Mdot
.46768 .40245 Mdot
.34888 .43411 Mdot
.39055 .63882 Mdot
.50224 .38898 Mdot
.81623 .63922 Mdot
.47328 .3582 Mdot
.6432 .59907 Mdot
.19071 .54291 Mdot
.72298 .5163 Mdot
.40197 .41161 Mdot
.51877 .27977 Mdot
.51642 .39997 Mdot
.572 .60563 Mdot
.55241 .32113 Mdot
.41745 .60237 Mdot
.35958 .46595 Mdot
.44447 .86938 Mdot
.38668 .61939 Mdot
.52595 .40624 Mdot
.69555 .54324 Mdot
.35849 .44364 Mdot
.55977 .74557 Mdot
.32178 .72715 Mdot
.48999 .32089 Mdot
.45639 .41398 Mdot
.54168 .40375 Mdot
.31828 .24048 Mdot
.61813 .61563 Mdot
.33694 .45716 Mdot
.40835 .59724 Mdot
.37728 .62464 Mdot
.58968 .64391 Mdot
.28744 .62008 Mdot
.54826 .56347 Mdot
.69521 .17489 Mdot
.57872 .61633 Mdot
.7 .50725 Mdot
.54819 .51536 Mdot
.58716 .59561 Mdot
.6133 .62762 Mdot
.58885 .65413 Mdot
.31343 .68231 Mdot
.30907 .46894 Mdot
.52605 .37915 Mdot
.33605 .52022 Mdot
.46703 .38641 Mdot
.61486 .39937 Mdot
.38344 .63834 Mdot
.36058 .46951 Mdot
.82246 .6086 Mdot
.41074 .44394 Mdot
.49174 .37282 Mdot
.79103 .46805 Mdot
.52986 .30598 Mdot
.72656 .42699 Mdot
.48632 .30919 Mdot
.592 .61748 Mdot
.45563 .45097 Mdot
.54168 .43857 Mdot
.24583 .66799 Mdot
.39245 .60535 Mdot
.56087 .71552 Mdot
.48919 .3313 Mdot
.51797 .31719 Mdot
.36912 .46552 Mdot
.30856 .49202 Mdot
.67684 .54711 Mdot
.60005 .51544 Mdot
.38332 .60776 Mdot
.64158 .52864 Mdot
.5045 .40298 Mdot
.44195 .67921 Mdot
.29948 .41556 Mdot
.50059 .3892 Mdot
.71287 .29323 Mdot
.30635 .39787 Mdot
.50328 .34238 Mdot
.24807 .37617 Mdot
.39845 .61585 Mdot
.1953 .5512 Mdot
.56205 .39696 Mdot
.59792 .63272 Mdot
.35831 .47207 Mdot
.3045 .4499 Mdot
.69633 .55614 Mdot
.33336 .77129 Mdot
.38336 .64951 Mdot
.35991 .47697 Mdot
.4813 .37475 Mdot
.38982 .64721 Mdot
.57001 .7215 Mdot
.5365 .43884 Mdot
.66504 .29477 Mdot
.32475 .47493 Mdot
.56406 .37893 Mdot
.2406 .52787 Mdot
.6127 .49152 Mdot
.57131 .16941 Mdot
.41952 .63615 Mdot
.68462 .54716 Mdot
.45641 .32891 Mdot
.77753 .67299 Mdot
.53748 .33176 Mdot
.63102 .46592 Mdot
.27481 .50976 Mdot
.68083 .53554 Mdot
.48743 .38181 Mdot
.51747 .34795 Mdot
.51248 .52476 Mdot
.73519 .52698 Mdot
.46528 .37392 Mdot
.43905 .42924 Mdot
.31044 .46234 Mdot
.56003 .71259 Mdot
.31982 .47675 Mdot
.50087 .36091 Mdot
.50286 .45513 Mdot
.30254 .47958 Mdot
.79247 .55624 Mdot
.72061 .50226 Mdot
.42443 .62029 Mdot
.56352 .44543 Mdot
.55785 .37753 Mdot
.34049 .20543 Mdot
.55385 .71901 Mdot
.23793 .3403 Mdot
.61174 .66682 Mdot
.33222 .62578 Mdot
.61775 .67745 Mdot
.71683 .26684 Mdot
.26216 .67268 Mdot
.49992 .32269 Mdot
.6438 .31622 Mdot
.26596 .34303 Mdot
.37187 .63889 Mdot
.40165 .24077 Mdot
.50422 .40572 Mdot
.47586 .39531 Mdot
.63017 .61105 Mdot
.27643 .62218 Mdot
.41186 .77578 Mdot
.52778 .53845 Mdot
.7045 .53144 Mdot
.34594 .49445 Mdot
.51732 .38665 Mdot
.54341 .58014 Mdot
.59327 .59957 Mdot
.46866 .63786 Mdot
.48727 .39028 Mdot
.41335 .79742 Mdot
.32451 .68336 Mdot
.39605 .64995 Mdot
.56783 .63035 Mdot
.63281 .64273 Mdot
.4785 .40754 Mdot
.37752 .64004 Mdot
.50493 .34468 Mdot
.49695 .5935 Mdot
.56818 .37713 Mdot
.69552 .55125 Mdot
.51721 .42339 Mdot
.4741 .52456 Mdot
.62621 .18417 Mdot
.42072 .42442 Mdot
.29541 .48045 Mdot
.63863 .61756 Mdot
.58476 .64125 Mdot
.31061 .49042 Mdot
.58564 .63976 Mdot
.28727 .37113 Mdot
.41293 .32388 Mdot
.70326 .52812 Mdot
.55825 .45318 Mdot
.70012 .55243 Mdot
.55836 .71565 Mdot
.501 .41079 Mdot
.77398 .68742 Mdot
.57898 .61971 Mdot
.19629 .43258 Mdot
.3851 .61481 Mdot
.55756 .71668 Mdot
.54223 .33699 Mdot
.75867 .57541 Mdot
.61256 .59306 Mdot
.64636 .60831 Mdot
.51223 .35049 Mdot
.30796 .48191 Mdot
.5208 .35094 Mdot
.51721 .30601 Mdot
.5443 .73367 Mdot
.54953 .39539 Mdot
.41049 .60502 Mdot
.31278 .51088 Mdot
.75434 .31701 Mdot
.627 .58819 Mdot
.49567 .41497 Mdot
.48169 .37595 Mdot
.35941 .44991 Mdot
.55449 .35358 Mdot
.37141 .62223 Mdot
.46749 .08978 Mdot
.70847 .52121 Mdot
.54873 .75423 Mdot
.64298 .59284 Mdot
.49957 .33207 Mdot
.53405 .3668 Mdot
.82738 .57407 Mdot
.47112 .74597 Mdot
.41341 .61386 Mdot
.54812 .32141 Mdot
.61202 .64294 Mdot
.69396 .54285 Mdot
.43065 .60229 Mdot
.54405 .38885 Mdot
.48145 .39538 Mdot
.6934 .54966 Mdot
.74164 .32568 Mdot
.61242 .73493 Mdot
.41537 .64353 Mdot
.45736 .45322 Mdot
.74239 .62815 Mdot
.48424 .35677 Mdot
.77169 .61817 Mdot
.31706 .49386 Mdot
.40781 .63706 Mdot
.30019 .27082 Mdot
.50623 .42622 Mdot
.37331 .6141 Mdot
.38584 .60688 Mdot
.54241 .42176 Mdot
.34598 .518 Mdot
.33001 .51168 Mdot
.32595 .50155 Mdot
.18172 .58855 Mdot
.63492 .38943 Mdot
.60112 .60236 Mdot
.39958 .61626 Mdot
.57519 .59396 Mdot
.7197 .5586 Mdot
.59427 .50571 Mdot
.59427 .58702 Mdot
.30866 .44798 Mdot
.56551 .62107 Mdot
.51728 .35073 Mdot
.37979 .60962 Mdot
.62297 .6105 Mdot
.48173 .33786 Mdot
.56191 .29083 Mdot
.47367 .56661 Mdot
.68707 .56171 Mdot
.75002 .50373 Mdot
.52703 .39281 Mdot
.54855 .72614 Mdot
.49433 .40019 Mdot
.41187 .64951 Mdot
.48326 .5129 Mdot
.49304 .33444 Mdot
.58035 .62708 Mdot
.43249 .34129 Mdot
.6305 .5982 Mdot
.53098 .31371 Mdot
.50344 .36258 Mdot
.47557 .36574 Mdot
.50771 .34276 Mdot
.31877 .65617 Mdot
.37119 .64114 Mdot
.55963 .28571 Mdot
.55708 .63779 Mdot
.33386 .47536 Mdot
.30529 .44195 Mdot
.72978 .65944 Mdot
.54612 .75513 Mdot
.40159 .6076 Mdot
.48922 .35403 Mdot
.6463 .59992 Mdot
.85251 .49597 Mdot
.79763 .57327 Mdot
.7725 .52492 Mdot
.62265 .62887 Mdot
.29489 .47336 Mdot
.60342 .5952 Mdot
.47333 .40051 Mdot
.52137 .43293 Mdot
.73092 .28516 Mdot
.438 .59049 Mdot
.7075 .53545 Mdot
.47233 .36937 Mdot
.61466 .44602 Mdot
.61264 .64333 Mdot
.58439 .65372 Mdot
.47362 .35974 Mdot
.31531 .50637 Mdot
.4881 .1459 Mdot
.39297 .64986 Mdot
.54222 .26172 Mdot
.38836 .49551 Mdot
.20811 .55066 Mdot
.37655 .63058 Mdot
.46537 .57423 Mdot
.6096 .65561 Mdot
.41055 .3769 Mdot
.33217 .47898 Mdot
.70756 .53886 Mdot
.51801 .43553 Mdot
.31055 .44807 Mdot
.59155 .66423 Mdot
.33716 .44734 Mdot
.48425 .41928 Mdot
.36954 .63716 Mdot
.59546 .65124 Mdot
.37894 .58607 Mdot
.37728 .45733 Mdot
.71667 .54588 Mdot
.59516 .47139 Mdot
.44035 .23272 Mdot
.30159 .39867 Mdot
.50999 .33578 Mdot
.55054 .65743 Mdot
.54597 .35752 Mdot
.36564 .48407 Mdot
.4946 .35596 Mdot
.29409 .5316 Mdot
.57079 .63497 Mdot
.56396 .38073 Mdot
.53417 .4166 Mdot
.39958 .25992 Mdot
.49544 .37959 Mdot
.55094 .40227 Mdot
.50494 .34068 Mdot
.37801 .51177 Mdot
.45696 .34504 Mdot
.30794 .47422 Mdot
.33593 .72727 Mdot
.61265 .62543 Mdot
.68459 .56183 Mdot
.73 .53026 Mdot
.62622 .46979 Mdot
.61007 .46783 Mdot
.28838 .62723 Mdot
.31685 .47067 Mdot
.40368 .60102 Mdot
.50358 .34467 Mdot
.34151 .24445 Mdot
.69523 .57762 Mdot
.60455 .65562 Mdot
.63576 .59252 Mdot
.58624 .40453 Mdot
.32246 .23598 Mdot
.55955 .35598 Mdot
.32739 .74105 Mdot
.5714 .36753 Mdot
.466 .36766 Mdot
.63557 .63485 Mdot
.60855 .48298 Mdot
.50881 .33549 Mdot
.36886 .46368 Mdot
.71141 .53951 Mdot
.4244 .45524 Mdot
.64128 .68156 Mdot
.48024 .60463 Mdot
.43191 .26646 Mdot
.54405 .35106 Mdot
.6015 .64891 Mdot
.31444 .44909 Mdot
.30155 .6979 Mdot
.40677 .64497 Mdot
.28983 .65859 Mdot
.35285 .28246 Mdot
.80132 .51061 Mdot
.71011 .5371 Mdot
.73437 .32119 Mdot
.51354 .37779 Mdot
.63956 .61577 Mdot
.47621 .41814 Mdot
.85209 .4915 Mdot
.68986 .51346 Mdot
.28791 .49013 Mdot
.4099 .62235 Mdot
.36611 .46937 Mdot
.35831 .39016 Mdot
.44927 .57454 Mdot
.52548 .62411 Mdot
.59213 .58412 Mdot
.59107 .31078 Mdot
.34868 .47027 Mdot
.53674 .38018 Mdot
.7475 .21861 Mdot
.31853 .49491 Mdot
.32218 .50419 Mdot
.75147 .48991 Mdot
.77397 .50598 Mdot
.57425 .35318 Mdot
.33969 .44601 Mdot
.56008 .62303 Mdot
.71975 .51836 Mdot
.52462 .34716 Mdot
.51253 .34351 Mdot
.30572 .48326 Mdot
.60455 .59078 Mdot
.55005 .26008 Mdot
.5876 .62118 Mdot
.31094 .45937 Mdot
.59735 .62215 Mdot
.59451 .57558 Mdot
.62202 .61993 Mdot
.55894 .3733 Mdot
.49618 .35297 Mdot
.66434 .66573 Mdot
.318 .48464 Mdot
.53671 .36469 Mdot
.53469 .39466 Mdot
.34703 .47443 Mdot
.59558 .67523 Mdot
.36624 .23236 Mdot
.51319 .41031 Mdot
.51473 .36507 Mdot
.68131 .54131 Mdot
.61954 .66973 Mdot
.6171 .75703 Mdot
.53094 .35496 Mdot
.71992 .50685 Mdot
.33792 .51413 Mdot
.49535 .39786 Mdot
.55674 .48616 Mdot
.59462 .57975 Mdot
.51665 .42484 Mdot
.56238 .74403 Mdot
.50962 .33211 Mdot
.50812 .15485 Mdot
.50289 .41733 Mdot
.33711 .46033 Mdot
.35443 .46589 Mdot
.73281 .48066 Mdot
.33704 .49121 Mdot
.56573 .7181 Mdot
.38963 .635 Mdot
.83708 .45662 Mdot
.56951 .72352 Mdot
.46839 .3607 Mdot
.51495 .84349 Mdot
.56389 .40573 Mdot
.49097 .33135 Mdot
.27433 .28384 Mdot
.56901 .72536 Mdot
.34808 .45951 Mdot
.39917 .69392 Mdot
.57236 .3681 Mdot
.38571 .64616 Mdot
.50999 .44068 Mdot
.53073 .42421 Mdot
.22416 .60373 Mdot
.22181 .46092 Mdot
.42133 .64291 Mdot
.43722 .3534 Mdot
.53162 .35547 Mdot
.51704 .73694 Mdot
.48769 .36601 Mdot
.69175 .55401 Mdot
.32614 .50338 Mdot
.58406 .60231 Mdot
.70805 .51748 Mdot
.51024 .40186 Mdot
.70314 .54021 Mdot
.60555 .60143 Mdot
.40185 .64087 Mdot
.48979 .41128 Mdot
.69757 .50532 Mdot
.70439 .53291 Mdot
.54591 .36208 Mdot
.35983 .47125 Mdot
.41402 .43558 Mdot
.49659 .3957 Mdot
.53297 .3768 Mdot
.31012 .48596 Mdot
.66976 .80381 Mdot
.47426 .40747 Mdot
.46081 .54686 Mdot
.28911 .48963 Mdot
.56552 .70446 Mdot
.61795 .60166 Mdot
.52748 .427 Mdot
.389 .64426 Mdot
.38743 .6399 Mdot
.56843 .64404 Mdot
.36602 .46197 Mdot
.61553 .59177 Mdot
.42405 .38504 Mdot
.57736 .42054 Mdot
.54883 .4247 Mdot
.41626 .85276 Mdot
.71665 .27672 Mdot
.29822 .48547 Mdot
.62446 .64302 Mdot
.53353 .53879 Mdot
.40353 .61557 Mdot
.56343 .62754 Mdot
.36407 .448 Mdot
.29647 .46481 Mdot
.32882 .44415 Mdot
.68337 .53482 Mdot
.6196 .65393 Mdot
.28493 .49084 Mdot
.32099 .50719 Mdot
.51467 .3509 Mdot
.53328 .35749 Mdot
.25762 .46973 Mdot
.69127 .41514 Mdot
.71088 .55057 Mdot
.59461 .64347 Mdot
.28445 .2224 Mdot
.41332 .64881 Mdot
.40319 .26002 Mdot
.49308 .33333 Mdot
.90532 .43054 Mdot
.56127 .35713 Mdot
.4824 .37152 Mdot
.32744 .51594 Mdot
.67933 .51952 Mdot
.71028 .54671 Mdot
.34987 .47061 Mdot
.36799 .44803 Mdot
.68827 .5529 Mdot
.77168 .38912 Mdot
.79728 .36728 Mdot
.29433 .67945 Mdot
.34032 .46636 Mdot
.46001 .23456 Mdot
.37823 .64246 Mdot
.38052 .47162 Mdot
.4285 .62848 Mdot
.61216 .62913 Mdot
.60431 .66003 Mdot
.42198 .60325 Mdot
.50948 .35001 Mdot
.61277 .60318 Mdot
.44895 .35246 Mdot
.78078 .38006 Mdot
.57076 .22857 Mdot
.45398 .7324 Mdot
.4684 .34554 Mdot
.39757 .76954 Mdot
.43548 .77571 Mdot
.5221 .39726 Mdot
.4653 .48474 Mdot
.70645 .5373 Mdot
.3801 .49277 Mdot
.37144 .62571 Mdot
.55852 .16654 Mdot
.48625 .35546 Mdot
.33047 .46067 Mdot
.39548 .60502 Mdot
.69767 .47854 Mdot
.24815 .62574 Mdot
.46716 .37879 Mdot
.64193 .14869 Mdot
.37092 .50675 Mdot
.58346 .60312 Mdot
.43664 .83388 Mdot
.32726 .52067 Mdot
.75307 .50906 Mdot
.60131 .66366 Mdot
.81626 .54372 Mdot
.33228 .45212 Mdot
.5822 .66111 Mdot
.34823 .48987 Mdot
.69848 .55443 Mdot
.3631 .49939 Mdot
.59948 .65247 Mdot
.491 .38147 Mdot
.58859 .63806 Mdot
.71284 .55015 Mdot
.6389 .60941 Mdot
.37335 .63395 Mdot
.55619 .71933 Mdot
.39503 .62521 Mdot
.61063 .49715 Mdot
.20319 .4939 Mdot
.41895 .6294 Mdot
.6626 .49691 Mdot
.46493 .35332 Mdot
.28204 .49112 Mdot
.57675 .61552 Mdot
.55732 .63552 Mdot
.57279 .51359 Mdot
.33818 .476 Mdot
.59318 .64709 Mdot
.34605 .28184 Mdot
.59057 .83269 Mdot
.5184 .45513 Mdot
.64196 .36565 Mdot
.3452 .47317 Mdot
.57854 .65067 Mdot
.31175 .71663 Mdot
.31586 .44261 Mdot
.57972 .61494 Mdot
.40541 .63166 Mdot
.37676 .62638 Mdot
.48114 .35506 Mdot
.43161 .58154 Mdot
.57163 .61399 Mdot
.37953 .73104 Mdot
.35153 .49666 Mdot
.69318 .47813 Mdot
.70223 .55813 Mdot
.61585 .62881 Mdot
.53399 .4419 Mdot
.30866 .42698 Mdot
.58068 .58415 Mdot
.63455 .28362 Mdot
.26603 .24543 Mdot
.59122 .64354 Mdot
.33019 .50341 Mdot
.32644 .46308 Mdot
.53725 .3098 Mdot
.52362 .52906 Mdot
.6234 .59638 Mdot
.754 .71308 Mdot
.63712 .45933 Mdot
.5529 .73564 Mdot
.53364 .78561 Mdot
.50538 .33462 Mdot
.55184 .36747 Mdot
.40561 .61532 Mdot
.49946 .37226 Mdot
.32166 .50965 Mdot
.52679 .33329 Mdot
.37565 .60817 Mdot
.60835 .65495 Mdot
.49307 .41037 Mdot
.7235 .52186 Mdot
.41787 .64971 Mdot
.42458 .60424 Mdot
.60761 .61712 Mdot
.33619 .44519 Mdot
.58326 .56083 Mdot
.58386 .62633 Mdot
.54019 .34694 Mdot
.56355 .73716 Mdot
.49824 .4228 Mdot
.71852 .32593 Mdot
.33865 .43933 Mdot
.59498 .59466 Mdot
.29017 .46193 Mdot
.39244 .62187 Mdot
.56286 .64805 Mdot
.49509 .36447 Mdot
.58245 .61442 Mdot
.62741 .70421 Mdot
.7501 .35233 Mdot
.36679 .46245 Mdot
.62475 .67915 Mdot
.32785 .50528 Mdot
.55149 .73702 Mdot
.71734 .3505 Mdot
.71211 .52816 Mdot
.61156 .64025 Mdot
.69745 .26084 Mdot
.57836 .62771 Mdot
.49752 .38057 Mdot
.50838 .38888 Mdot
.62951 .61249 Mdot
.70483 .51111 Mdot
.17178 .55215 Mdot
.45137 .55326 Mdot
.34408 .45505 Mdot
.422 .34545 Mdot
.33691 .18473 Mdot
.42345 .58863 Mdot
.40858 .61321 Mdot
.54837 .33263 Mdot
.48085 .35047 Mdot
.42513 .60111 Mdot
.37907 .59728 Mdot
.68359 .55625 Mdot
.59269 .65559 Mdot
.32785 .52692 Mdot
.43294 .59888 Mdot
.52919 .29569 Mdot
.61069 .45477 Mdot
.57018 .35016 Mdot
.45153 .42616 Mdot
.44806 .38058 Mdot
.63328 .48478 Mdot
.39169 .59482 Mdot
.52788 .39058 Mdot
.46982 .33312 Mdot
.41005 .63136 Mdot
.69864 .55383 Mdot
.22824 .4829 Mdot
.59799 .62732 Mdot
.79969 .69908 Mdot
.50507 .42127 Mdot
.49453 .38613 Mdot
.41129 .64624 Mdot
.52566 .75028 Mdot
.30167 .46149 Mdot
.34353 .44292 Mdot
.61806 .61348 Mdot
.57819 .51383 Mdot
.54756 .34585 Mdot
.52447 .39562 Mdot
.60514 .63934 Mdot
.5542 .72079 Mdot
.429 .72745 Mdot
.52249 .37613 Mdot
.39312 .6074 Mdot
.57209 .57939 Mdot
.38783 .59525 Mdot
.47118 .40895 Mdot
.49987 .38082 Mdot
.55885 .37037 Mdot
.47999 .35061 Mdot
.43024 .61262 Mdot
.52387 .38755 Mdot
.5552 .43483 Mdot
.35254 .453 Mdot
.55589 .36965 Mdot
.63664 .47083 Mdot
.50887 .36049 Mdot
.72249 .53394 Mdot
.54064 .60949 Mdot
.47473 .36577 Mdot
.55643 .37718 Mdot
.45481 .55367 Mdot
.4841 .38322 Mdot
.41411 .6475 Mdot
.3312 .47168 Mdot
.39989 .6168 Mdot
.40983 .59699 Mdot
.56394 .60857 Mdot
.68238 .5541 Mdot
.50923 .32431 Mdot
.72095 .54846 Mdot
.46161 .42898 Mdot
.48442 .42025 Mdot
.59908 .56359 Mdot
.3289 .7421 Mdot
.62129 .72406 Mdot
.49611 .36229 Mdot
.61657 .61991 Mdot
.58765 .59959 Mdot
.64004 .30376 Mdot
.45647 .33842 Mdot
.42907 .60282 Mdot
.40186 .63348 Mdot
.71548 .38635 Mdot
.22902 .61305 Mdot
.71708 .54475 Mdot
.56719 .54081 Mdot
.45175 .37013 Mdot
.5307 .38217 Mdot
.54143 .43644 Mdot
.59036 .58693 Mdot
.54262 .74133 Mdot
.6039 .65631 Mdot
.54842 .71265 Mdot
.3812 .59936 Mdot
.52219 .33471 Mdot
.57701 .21933 Mdot
.30347 .48807 Mdot
.33074 .47224 Mdot
.42196 .595 Mdot
.62207 .59194 Mdot
.52257 .30083 Mdot
.45607 .87734 Mdot
.38705 .46945 Mdot
.6739 .5526 Mdot
.52369 .4008 Mdot
.61116 .61664 Mdot
.30658 .49638 Mdot
.72819 .51259 Mdot
.53423 .41156 Mdot
.57006 .67155 Mdot
.49908 .35551 Mdot
.26226 .34608 Mdot
.35307 .45609 Mdot
.85727 .48589 Mdot
.35147 .43988 Mdot
.42077 .64832 Mdot
.41709 .62291 Mdot
.50224 .38719 Mdot
.42447 .84798 Mdot
.29625 .50534 Mdot
.41474 .57616 Mdot
.68324 .51755 Mdot
.54699 .75241 Mdot
.68273 .52395 Mdot
.58437 .59653 Mdot
.71173 .53754 Mdot
.58623 .65093 Mdot
.70663 .38952 Mdot
.39121 .47171 Mdot
.70866 .51941 Mdot
.51943 .70411 Mdot
.45199 .35839 Mdot
.71218 .56107 Mdot
.56997 .42526 Mdot
.40966 .39297 Mdot
.60396 .63644 Mdot
.70707 .51066 Mdot
.53567 .37701 Mdot
.55708 .18223 Mdot
.41714 .60933 Mdot
.43081 .60599 Mdot
.444 .3706 Mdot
.59031 .6561 Mdot
.374 .46132 Mdot
.47232 .50341 Mdot
.56051 .70814 Mdot
.5251 .39268 Mdot
.51765 .33338 Mdot
.30798 .43999 Mdot
.32642 .43102 Mdot
.50241 .3822 Mdot
.35993 .26044 Mdot
.51673 .38119 Mdot
.38241 .64001 Mdot
.29862 .46248 Mdot
.32789 .46625 Mdot
.56925 .62169 Mdot
.36059 .48936 Mdot
.45342 .42919 Mdot
.36631 .5552 Mdot
.57389 .3806 Mdot
.38708 .62208 Mdot
.47132 .51724 Mdot
.63379 .59153 Mdot
.6086 .20592 Mdot
.31725 .43674 Mdot
.55158 .39271 Mdot
.34527 .50116 Mdot
.68778 .53605 Mdot
.32 .48272 Mdot
.29651 .49381 Mdot
.50443 .39822 Mdot
.46772 .3874 Mdot
.56766 .72503 Mdot
.53184 .52923 Mdot
.3596 .48454 Mdot
.52017 .38956 Mdot
.56479 .39833 Mdot
.5402 .41804 Mdot
.4882 .55131 Mdot
.29711 .48677 Mdot
.37045 .30755 Mdot
.64693 .27772 Mdot
.3609 .47792 Mdot
.48499 .15878 Mdot
.55537 .74883 Mdot
.54651 .75437 Mdot
.42729 .58573 Mdot
.52352 .37583 Mdot
.63152 .62255 Mdot
.47502 .40246 Mdot
.4309 .39994 Mdot
.48018 .39714 Mdot
.70914 .5072 Mdot
.49474 .32498 Mdot
.5553 .72912 Mdot
.5829 .63076 Mdot
.52374 .4128 Mdot
.49014 .40897 Mdot
.5476 .75848 Mdot
.33013 .43537 Mdot
.30575 .45425 Mdot
.78191 .60057 Mdot
.69478 .53131 Mdot
.40075 .64322 Mdot
.49649 .3493 Mdot
.6176 .61824 Mdot
.58727 .63637 Mdot
.36428 .48151 Mdot
.59559 .63307 Mdot
.3996 .65159 Mdot
.4919 .3671 Mdot
.42963 .60546 Mdot
.71894 .51044 Mdot
.32106 .5023 Mdot
.49111 .35047 Mdot
.51512 .35152 Mdot
.35427 .46554 Mdot
.46393 .35442 Mdot
.68135 .542 Mdot
.57977 .63367 Mdot
.32114 .4513 Mdot
.38839 .63594 Mdot
.56819 .61878 Mdot
.52528 .36078 Mdot
.25462 .26136 Mdot
.50379 .37365 Mdot
.52538 .36963 Mdot
.7743 .32977 Mdot
.54373 .32571 Mdot
.57171 .62485 Mdot
.29773 .4459 Mdot
.44822 .39943 Mdot
.62502 .4302 Mdot
.79429 .63063 Mdot
.5618 .62865 Mdot
.52187 .4075 Mdot
.6255 .20949 Mdot
.52222 .41074 Mdot
.63896 .53007 Mdot
.6738 .71181 Mdot
.59603 .30609 Mdot
.45616 .42826 Mdot
.42734 .61665 Mdot
.56708 .72217 Mdot
.57426 .63948 Mdot
.25529 .40166 Mdot
.51122 .3956 Mdot
.23782 .40279 Mdot
.52938 .42027 Mdot
.37592 .62648 Mdot
.41611 .40078 Mdot
.59375 .64129 Mdot
.29469 .72918 Mdot
.53872 .34786 Mdot
.29693 .48131 Mdot
.56823 .60819 Mdot
.54924 .75144 Mdot
.52961 .36989 Mdot
.72748 .53619 Mdot
.38461 .57943 Mdot
.5736 .42738 Mdot
.38486 .62519 Mdot
.53627 .39505 Mdot
.43297 .36577 Mdot
.38016 .81175 Mdot
.34974 .45291 Mdot
.40914 .61941 Mdot
.47482 .79129 Mdot
.45958 .36236 Mdot
.32944 .45134 Mdot
.33313 .47846 Mdot
.7064 .55545 Mdot
.52418 .57654 Mdot
.25246 .53964 Mdot
.52376 .21141 Mdot
.34847 .40661 Mdot
.56949 .63902 Mdot
.4345 .76123 Mdot
.52796 .34919 Mdot
.45657 .59173 Mdot
.42293 .63916 Mdot
.49268 .38487 Mdot
.30506 .41194 Mdot
.32202 .50053 Mdot
.51507 .36995 Mdot
.69909 .55288 Mdot
.46474 .66563 Mdot
.47239 .62278 Mdot
.38568 .19155 Mdot
.56034 .62684 Mdot
.52855 .43625 Mdot
.47445 .43946 Mdot
.57147 .71471 Mdot
.48565 .42443 Mdot
.5734 .62824 Mdot
.78698 .41922 Mdot
.70081 .51083 Mdot
.31079 .49934 Mdot
.55445 .74926 Mdot
.44639 .37941 Mdot
.55848 .40458 Mdot
.68347 .56103 Mdot
.54818 .38416 Mdot
.33962 .77409 Mdot
.5534 .77367 Mdot
.61926 .60723 Mdot
.33101 .44618 Mdot
.45091 .37783 Mdot
.5428 .7383 Mdot
.5061 .39474 Mdot
.46379 .26607 Mdot
.55275 .38623 Mdot
.23612 .539 Mdot
.35845 .47368 Mdot
.3875 .62668 Mdot
.44511 .41273 Mdot
.47597 .38991 Mdot
.74738 .61865 Mdot
.43125 .3977 Mdot
.50288 .41811 Mdot
.36717 .45729 Mdot
.30048 .48713 Mdot
.30907 .47482 Mdot
.60107 .5982 Mdot
.30298 .68788 Mdot
.39297 .61179 Mdot
.53165 .33163 Mdot
.43329 .59994 Mdot
.49268 .27086 Mdot
.67869 .55778 Mdot
.49967 .17973 Mdot
.54715 .40071 Mdot
.31257 .47051 Mdot
.32077 .60067 Mdot
.3362 .5139 Mdot
.55939 .6541 Mdot
.38246 .60816 Mdot
.32118 .4979 Mdot
.47742 .37944 Mdot
.51457 .53521 Mdot
.41106 .19546 Mdot
.40176 .6216 Mdot
.5556 .42914 Mdot
.56011 .63942 Mdot
.62293 .5833 Mdot
.35561 .16009 Mdot
.41459 .61338 Mdot
.44192 .7753 Mdot
.51875 .39497 Mdot
.30347 .48543 Mdot
.4223 .63111 Mdot
.42225 .61206 Mdot
.60087 .63706 Mdot
.4679 .37951 Mdot
.47551 .36744 Mdot
.56021 .74595 Mdot
.39906 .63583 Mdot
.44232 .38024 Mdot
.56507 .40983 Mdot
.73396 .28778 Mdot
.25186 .44706 Mdot
.70718 .7827 Mdot
.42365 .38692 Mdot
.32645 .40455 Mdot
.54728 .50957 Mdot
.30313 .50121 Mdot
.47131 .36903 Mdot
.45315 .39288 Mdot
.57004 .6222 Mdot
.49812 .36938 Mdot
.6348 .61193 Mdot
.40688 .60738 Mdot
.46917 .1673 Mdot
.31284 .55069 Mdot
.77843 .41421 Mdot
.49452 .37387 Mdot
.21457 .57864 Mdot
.69687 .52048 Mdot
.37316 .66241 Mdot
.30892 .4583 Mdot
.45711 .38181 Mdot
.64282 .61175 Mdot
.61214 .64086 Mdot
.33022 .48766 Mdot
.378 .74446 Mdot
.76549 .6196 Mdot
.46882 .40685 Mdot
.61763 .60007 Mdot
.33494 .63931 Mdot
.34403 .26843 Mdot
.44193 .62492 Mdot
.69659 .51123 Mdot
.60571 .65502 Mdot
.4081 .59092 Mdot
.2784 .43608 Mdot
.32939 .49606 Mdot
.29133 .45303 Mdot
.69375 .67152 Mdot
.628 .59827 Mdot
.7115 .51592 Mdot
.26366 .66216 Mdot
.25147 .65531 Mdot
.70319 .50811 Mdot
.61146 .65413 Mdot
.3028 .4925 Mdot
.32223 .45677 Mdot
.33155 .47071 Mdot
.28568 .71918 Mdot
.35042 .44544 Mdot
.41068 .28818 Mdot
.56188 .40766 Mdot
.59486 .41667 Mdot
.52047 .4099 Mdot
.43109 .62302 Mdot
.35323 .45728 Mdot
.55898 .51285 Mdot
.47325 .35165 Mdot
.40335 .18974 Mdot
.52668 .39553 Mdot
.43771 .6366 Mdot
.51981 .37117 Mdot
.42165 .24272 Mdot
.29077 .49258 Mdot
.49858 .36379 Mdot
.36947 .64388 Mdot
.70099 .53492 Mdot
.29874 .52094 Mdot
.47431 .36693 Mdot
.26252 .61059 Mdot
.53785 .32659 Mdot
.78606 .40721 Mdot
.71241 .4611 Mdot
.67245 .5513 Mdot
.43466 .42494 Mdot
.57505 .6514 Mdot
.29182 .52188 Mdot
.51812 .46006 Mdot
.40083 .62318 Mdot
.20549 .41893 Mdot
.61533 .63679 Mdot
.41225 .42543 Mdot
.54394 .31767 Mdot
.68431 .55436 Mdot
.27925 .44732 Mdot
.4159 .64474 Mdot
.48085 .33732 Mdot
.54332 .42022 Mdot
.76694 .39843 Mdot
.53718 .45774 Mdot
.5534 .35017 Mdot
.69723 .5646 Mdot
.37693 .31028 Mdot
.51169 .35747 Mdot
.58821 .67381 Mdot
.2899 .45661 Mdot
.44467 .3664 Mdot
.37009 .30361 Mdot
.51892 .39005 Mdot
.32024 .49145 Mdot
.2932 .44642 Mdot
.2952 .59318 Mdot
.67557 .52855 Mdot
.55257 .38654 Mdot
.76047 .4676 Mdot
.54678 .3567 Mdot
.38939 .6096 Mdot
.47549 .40956 Mdot
.61087 .63451 Mdot
.32107 .73507 Mdot
.59156 .605 Mdot
.47328 .40377 Mdot
.33371 .46744 Mdot
.42645 .62641 Mdot
.66689 .67637 Mdot
.70236 .69167 Mdot
.40574 .29154 Mdot
.82193 .61766 Mdot
.69188 .51924 Mdot
.72995 .54409 Mdot
.39861 .65616 Mdot
.50022 .36148 Mdot
.73562 .47561 Mdot
.56417 .3516 Mdot
.51595 .36527 Mdot
.48107 .39881 Mdot
.41068 .56787 Mdot
.40169 .61195 Mdot
.59193 .62763 Mdot
.50212 .38035 Mdot
.52074 .38801 Mdot
.35017 .49351 Mdot
.70212 .53292 Mdot
.58936 .60354 Mdot
.70233 .52529 Mdot
.59795 .61198 Mdot
.50358 .15343 Mdot
.57196 .40267 Mdot
.69858 .53615 Mdot
.40267 .65681 Mdot
.30961 .48611 Mdot
.54332 .72866 Mdot
.57956 .59889 Mdot
.59405 .64463 Mdot
.52406 .39337 Mdot
.31263 .4903 Mdot
.36112 .48488 Mdot
.68754 .53238 Mdot
.4108 .63988 Mdot
.47275 .40186 Mdot
.47053 .41093 Mdot
.61098 .29156 Mdot
.58098 .59171 Mdot
.32902 .29073 Mdot
.30061 .61786 Mdot
.49818 .36067 Mdot
.34478 .44759 Mdot
.4923 .40585 Mdot
.62092 .22475 Mdot
.30878 .44818 Mdot
.46633 .36782 Mdot
.22091 .61187 Mdot
.60226 .58565 Mdot
.25069 .5711 Mdot
.56172 .38309 Mdot
.83059 .56679 Mdot
.5362 .35374 Mdot
.70019 .24186 Mdot
.49858 .74933 Mdot
.52944 .33497 Mdot
.52221 .3499 Mdot
.51027 .21031 Mdot
.51513 .40134 Mdot
.55015 .73512 Mdot
.42029 .41458 Mdot
.29612 .46459 Mdot
.57383 .49611 Mdot
.58459 .68253 Mdot
.68573 .51369 Mdot
.61818 .61306 Mdot
.61048 .69329 Mdot
.69432 .55191 Mdot
.3417 .4661 Mdot
.50896 .34203 Mdot
.59942 .4689 Mdot
.55798 .61438 Mdot
.52667 .30955 Mdot
.3867 .60978 Mdot
.63283 .66631 Mdot
.63548 .62201 Mdot
.38948 .63277 Mdot
.53675 .41595 Mdot
.39646 .21907 Mdot
.65565 .72617 Mdot
.84528 .46432 Mdot
.41473 .644 Mdot
.37497 .6289 Mdot
.30253 .70622 Mdot
.69155 .51037 Mdot
.7137 .331 Mdot
.22003 .55493 Mdot
.38738 .64849 Mdot
.73952 .39789 Mdot
.5929 .6589 Mdot
.25345 .60656 Mdot
.38016 .49248 Mdot
.54637 .42837 Mdot
.47666 .38227 Mdot
.41107 .63758 Mdot
.5612 .47647 Mdot
.40711 .81701 Mdot
.39613 .6256 Mdot
.49577 .44591 Mdot
.51021 .59746 Mdot
.55911 .74186 Mdot
.56814 .73685 Mdot
.67327 .53865 Mdot
.78784 .56924 Mdot
.35199 .48415 Mdot
.68712 .55667 Mdot
.47635 .64194 Mdot
.54822 .39212 Mdot
.40016 .6307 Mdot
.53984 .73745 Mdot
.38115 .63327 Mdot
.70439 .54932 Mdot
.67402 .55166 Mdot
.35136 .45217 Mdot
.30241 .46064 Mdot
.31375 .40452 Mdot
.71819 .41678 Mdot
.52292 .41168 Mdot
.25864 .31706 Mdot
.35306 .49598 Mdot
.48035 .45647 Mdot
.71927 .507 Mdot
.698 .53353 Mdot
.26926 .34901 Mdot
.49757 .3454 Mdot
.71346 .48196 Mdot
.49232 .35226 Mdot
.69908 .33574 Mdot
.47339 .41882 Mdot
.59916 .63465 Mdot
.51836 .33585 Mdot
.59124 .55709 Mdot
.50071 .33666 Mdot
.5013 .41892 Mdot
.5978 .65653 Mdot
.57789 .41005 Mdot
.61064 .63622 Mdot
.46958 .39972 Mdot
.73843 .52479 Mdot
.61763 .6175 Mdot
.64371 .39272 Mdot
.46192 .54841 Mdot
.55028 .72732 Mdot
.72377 .53748 Mdot
.70864 .5572 Mdot
.61852 .46783 Mdot
.31062 .45646 Mdot
.33153 .42 Mdot
.50208 .36226 Mdot
.58373 .65323 Mdot
.40562 .61291 Mdot
.51969 .38609 Mdot
.46494 .40875 Mdot
.56101 .36744 Mdot
.33524 .5015 Mdot
.62462 .59379 Mdot
.69965 .54044 Mdot
.61273 .59923 Mdot
.76543 .59556 Mdot
.62753 .64765 Mdot
.46372 .33764 Mdot
.47947 .43135 Mdot
.50685 .25392 Mdot
.2228 .40718 Mdot
.20017 .59863 Mdot
.33213 .49299 Mdot
.56294 .72351 Mdot
.67533 .55178 Mdot
.42555 .34501 Mdot
.30952 .46468 Mdot
.60202 .65178 Mdot
.49859 .35543 Mdot
.52864 .44632 Mdot
.45233 .63796 Mdot
.28864 .52233 Mdot
.64839 .45171 Mdot
.63719 .62437 Mdot
.55331 .73853 Mdot
.30082 .68856 Mdot
.4052 .43655 Mdot
.57876 .50898 Mdot
.48701 .39505 Mdot
.72861 .53195 Mdot
.30662 .49637 Mdot
.66209 .69739 Mdot
.4055 .63565 Mdot
.52599 .5294 Mdot
.49475 .37281 Mdot
.34412 .69467 Mdot
.3343 .46877 Mdot
.70476 .55242 Mdot
.41081 .63692 Mdot
.68239 .51572 Mdot
.56826 .73762 Mdot
.80199 .55417 Mdot
.54947 .36814 Mdot
.50566 .41719 Mdot
.43768 .63125 Mdot
.34906 .48676 Mdot
.74658 .5014 Mdot
.75987 .37518 Mdot
.62425 .60516 Mdot
.70375 .48521 Mdot
.31753 .5131 Mdot
.43839 .2587 Mdot
.60841 .59866 Mdot
.42146 .59449 Mdot
.61658 .48898 Mdot
.37642 .60577 Mdot
.47868 .36005 Mdot
.31961 .46851 Mdot
.41185 .60627 Mdot
.73743 .62057 Mdot
.61687 .192 Mdot
.4563 .24126 Mdot
.54025 .34374 Mdot
.48855 .17618 Mdot
.78227 .36521 Mdot
.51642 .48667 Mdot
.37254 .63326 Mdot
.49908 .39506 Mdot
.491 .42814 Mdot
.53372 .34367 Mdot
.40253 .59915 Mdot
.74587 .57784 Mdot
.5999 .64572 Mdot
.52747 .4015 Mdot
.69554 .55769 Mdot
.60792 .62837 Mdot
.62227 .56537 Mdot
.57536 .63584 Mdot
.29218 .47101 Mdot
.47384 .35633 Mdot
.30312 .66684 Mdot
.64825 .18884 Mdot
.40028 .6179 Mdot
.55051 .72741 Mdot
.5181 .42119 Mdot
.19917 .52935 Mdot
.30953 .47365 Mdot
.62571 .60681 Mdot
.49394 .3868 Mdot
.74424 .59237 Mdot
.53404 .73852 Mdot
.58228 .64194 Mdot
.31937 .45557 Mdot
.50041 .49019 Mdot
.50013 .36986 Mdot
.53993 .35757 Mdot
.34975 .47949 Mdot
.79403 .58115 Mdot
.32164 .73084 Mdot
.49083 .40787 Mdot
.38818 .62814 Mdot
.54423 .86072 Mdot
.55817 .39294 Mdot
.26395 .45007 Mdot
.54784 .7536 Mdot
.27539 .61185 Mdot
.32202 .29565 Mdot
.43076 .42203 Mdot
.53003 .20219 Mdot
.60224 .48344 Mdot
.47961 .16632 Mdot
.75916 .53391 Mdot
.5013 .6462 Mdot
.51673 .15346 Mdot
.37638 .65112 Mdot
.59772 .40582 Mdot
.57022 .26529 Mdot
.35858 .74039 Mdot
.54664 .49586 Mdot
.75913 .67963 Mdot
.73351 .64563 Mdot
.54365 .66521 Mdot
.57932 .62007 Mdot
.67946 .31943 Mdot
.47612 .40471 Mdot
.78729 .37214 Mdot
.3732 .25692 Mdot
.40158 .8217 Mdot
.50332 .17266 Mdot
.76122 .46519 Mdot
.42427 .19885 Mdot
.63685 .21987 Mdot
.53018 .24703 Mdot
.2962 .53637 Mdot
.70614 .76435 Mdot
.26325 .66675 Mdot
.77991 .46572 Mdot
.48115 .30922 Mdot
.54693 .57154 Mdot
.80094 .46667 Mdot
.40513 .31901 Mdot
.45443 .85058 Mdot
.57643 .60614 Mdot
.28405 .46816 Mdot
.60005 .27522 Mdot
.28817 .51474 Mdot
.35589 .57597 Mdot
.52709 .20083 Mdot
.69681 .24675 Mdot
.41535 .24487 Mdot
.83338 .57705 Mdot
.27118 .38646 Mdot
.174 .59379 Mdot
.48154 .57151 Mdot
.28071 .46436 Mdot
.66 .77443 Mdot
.25014 .6531 Mdot
.29298 .55067 Mdot
.4392 .32413 Mdot
.69782 .57474 Mdot
.66476 .4141 Mdot
.33159 .46114 Mdot
.32174 .28886 Mdot
.57012 .7392 Mdot
.25292 .51642 Mdot
.57027 .56778 Mdot
.59173 .20035 Mdot
.53299 .63183 Mdot
.26547 .62433 Mdot
.41959 .74957 Mdot
.25774 .25692 Mdot
.74299 .42906 Mdot
.67091 .26014 Mdot
.4435 .64408 Mdot
.54225 .49363 Mdot
.39259 .78696 Mdot
.70809 .43243 Mdot
.24085 .64322 Mdot
.23435 .31233 Mdot
.81056 .41924 Mdot
.30211 .2359 Mdot
.26959 .47132 Mdot
.55854 .36187 Mdot
.62609 .24462 Mdot
.35683 .40791 Mdot
.67407 .55931 Mdot
.35486 .20525 Mdot
.72767 .51547 Mdot
.27734 .50011 Mdot
.37257 .74445 Mdot
.41739 .26535 Mdot
.67382 .49593 Mdot
.72553 .49745 Mdot
.49945 .32233 Mdot
.17777 .6801 Mdot
.4664 .17376 Mdot
.28906 .59644 Mdot
.73384 .28668 Mdot
.4377 .67908 Mdot
.70498 .47296 Mdot
.405 .60367 Mdot
.57939 .16848 Mdot
.31756 .46093 Mdot
.57926 .14217 Mdot
.60806 .18057 Mdot
.50974 .81995 Mdot
.35948 .86596 Mdot
.47013 .71102 Mdot
.57543 .29297 Mdot
.60777 .45076 Mdot
.63886 .4268 Mdot
.40972 .80787 Mdot
.52674 .81846 Mdot
.42578 .68684 Mdot
.81647 .51796 Mdot
.5375 .16307 Mdot
.72474 .37326 Mdot
.78482 .50589 Mdot
.37576 .75925 Mdot
.47267 .54637 Mdot
.31884 .42493 Mdot
.42928 .53147 Mdot
.28813 .53095 Mdot
.34078 .21471 Mdot
.35489 .41607 Mdot
.47029 .87494 Mdot
.74584 .52308 Mdot
.52398 .76406 Mdot
.74154 .30934 Mdot
.64722 .3771 Mdot
.4685 .28048 Mdot
.32435 .70216 Mdot
.49114 .32318 Mdot
.30843 .69592 Mdot
.41306 .46832 Mdot
.61813 .6853 Mdot
.29655 .68927 Mdot
.34433 .66541 Mdot
.76124 .3896 Mdot
.56865 .23143 Mdot
.21572 .59288 Mdot
.29842 .45636 Mdot
.68753 .45049 Mdot
.74437 .41703 Mdot
.73758 .29459 Mdot
.47296 .79079 Mdot
.84478 .45072 Mdot
.48967 .79773 Mdot
.56551 .35667 Mdot
.50201 .45667 Mdot
.49506 .30096 Mdot
.72371 .4348 Mdot
.5654 .38617 Mdot
.34788 .69608 Mdot
.7604 .31542 Mdot
.29337 .41594 Mdot
.65837 .63829 Mdot
.20695 .39252 Mdot
.83183 .44337 Mdot
.63075 .25423 Mdot
.49406 .75765 Mdot
.57441 .45308 Mdot
.15092 .50755 Mdot
.60408 .62133 Mdot
.73511 .39107 Mdot
.37078 .59773 Mdot
.68527 .6808 Mdot
.49074 .22078 Mdot
.49672 .82189 Mdot
.76565 .31965 Mdot
.33162 .72585 Mdot
.61002 .73716 Mdot
.60649 .52747 Mdot
.66407 .50713 Mdot
.21713 .37548 Mdot
.49747 .44189 Mdot
.49452 .28327 Mdot
.71298 .55908 Mdot
.37663 .39228 Mdot
.65849 .2828 Mdot
.69584 .72097 Mdot
.51588 .45342 Mdot
.61914 .77432 Mdot
.55033 .74149 Mdot
.52079 .53234 Mdot
.39214 .15221 Mdot
.49277 .31763 Mdot
.47234 .72702 Mdot
.81542 .43222 Mdot
.6842 .46702 Mdot
.71226 .28975 Mdot
.32598 .67204 Mdot
.28462 .25587 Mdot
.64171 .19535 Mdot
.69722 .70409 Mdot
.44506 .1628 Mdot
.83003 .38121 Mdot
.25534 .28536 Mdot
.2409 .36234 Mdot
.36639 .64725 Mdot
.55005 .10372 Mdot
.62282 .63693 Mdot
.20023 .44077 Mdot
.34291 .40785 Mdot
.71605 .60357 Mdot
.37296 .47519 Mdot
.57444 .3388 Mdot
.54023 .65207 Mdot
.35909 .5154 Mdot
.44718 .35803 Mdot
.30132 .2186 Mdot
.202 .35778 Mdot
.31063 .21705 Mdot
.82927 .48186 Mdot
.45434 .16231 Mdot
.6001 .30092 Mdot
.41825 .28606 Mdot
.6409 .29372 Mdot
.4727 .40859 Mdot
.69546 .36334 Mdot
.46712 .71871 Mdot
.645 .72804 Mdot
.27221 .54291 Mdot
.35491 .50896 Mdot
.34688 .22334 Mdot
.30057 .18758 Mdot
.28373 .37162 Mdot
.33762 .32431 Mdot
.46351 .60546 Mdot
.72603 .41821 Mdot
.40226 .47248 Mdot
.60825 .76503 Mdot
.74161 .30419 Mdot
.56938 .26338 Mdot
.75189 .40034 Mdot
.71009 .72047 Mdot
.63487 .54141 Mdot
.52112 .73679 Mdot
.5903 .19264 Mdot
.62489 .33044 Mdot
.51383 .8108 Mdot
.60039 .4217 Mdot
.44717 .83146 Mdot
.75045 .66034 Mdot
.58708 .70687 Mdot
.7615 .43351 Mdot
.62277 .58507 Mdot
.7158 .36842 Mdot
.51087 .5864 Mdot
.60312 .26543 Mdot
.60228 .48214 Mdot
.71474 .36288 Mdot
.63277 .54242 Mdot
.37512 .18695 Mdot
.85727 .42747 Mdot
.18018 .4029 Mdot
.83144 .55305 Mdot
.417 .47486 Mdot
.55407 .41342 Mdot
.79294 .35551 Mdot
.34976 .19056 Mdot
.66214 .20527 Mdot
.36273 .71904 Mdot
.73522 .6138 Mdot
.39712 .66216 Mdot
.18217 .41139 Mdot
.77592 .63927 Mdot
.67531 .23989 Mdot
.20188 .59764 Mdot
.42548 .58464 Mdot
.33947 .74533 Mdot
.19442 .41718 Mdot
.46609 .22189 Mdot
.29856 .32107 Mdot
.54072 .31332 Mdot
.39995 .24144 Mdot
.29722 .45088 Mdot
.41445 .75455 Mdot
.7161 .43058 Mdot
.60783 .61818 Mdot
.63274 .36013 Mdot
.49241 .28068 Mdot
.50515 .32071 Mdot
.57162 .68813 Mdot
.36661 .43962 Mdot
.22303 .42308 Mdot
.37235 .67689 Mdot
.49117 .145 Mdot
.45761 .73981 Mdot
.44356 .33033 Mdot
.71003 .45362 Mdot
.63522 .70925 Mdot
.31589 .70478 Mdot
.37447 .64305 Mdot
.53324 .17785 Mdot
.40957 .52186 Mdot
.69357 .45028 Mdot
.3853 .24526 Mdot
.73507 .34665 Mdot
.48161 .43163 Mdot
.30886 .60829 Mdot
.4261 .31315 Mdot
.53752 .53036 Mdot
.28701 .50453 Mdot
.36057 .43263 Mdot
.86513 .57537 Mdot
.47055 .66498 Mdot
.50209 .78717 Mdot
.54324 .1821 Mdot
.3851 .60221 Mdot
.3504 .50685 Mdot
.69811 .34992 Mdot
.7703 .39518 Mdot
.40711 .33993 Mdot
.64499 .61827 Mdot
.67263 .57691 Mdot
.72319 .6957 Mdot
.49261 .1792 Mdot
.44681 .19053 Mdot
.39233 .82223 Mdot
.36463 .48445 Mdot
.71626 .32125 Mdot
.77175 .41119 Mdot
.33839 .50502 Mdot
.26782 .49705 Mdot
.24194 .51295 Mdot
.43662 .15352 Mdot
.30227 .67673 Mdot
.82348 .55203 Mdot
.62937 .48518 Mdot
.75008 .58105 Mdot
.65332 .69533 Mdot
.77719 .48195 Mdot
.55006 .18457 Mdot
.31331 .29098 Mdot
.45214 .21466 Mdot
.44158 .34147 Mdot
.23833 .44245 Mdot
.17638 .42081 Mdot
.48505 .56261 Mdot
.43584 .2557 Mdot
.33779 .62904 Mdot
.54488 .35124 Mdot
.25948 .25521 Mdot
.78277 .38345 Mdot
.2814 .69458 Mdot
.35976 .6017 Mdot
.53492 .36911 Mdot
.57008 .38828 Mdot
.54415 .47856 Mdot
.28615 .60853 Mdot
.20773 .36319 Mdot
.78015 .48266 Mdot
.44916 .4815 Mdot
.36808 .25533 Mdot
.47222 .72918 Mdot
.59203 .20452 Mdot
.76688 .34377 Mdot
.52826 .55844 Mdot
.46256 .72408 Mdot
.60818 .51118 Mdot
.83059 .52967 Mdot
.53721 .61495 Mdot
.59788 .29101 Mdot
.21367 .5308 Mdot
.30227 .64103 Mdot
.64431 .70906 Mdot
.51805 .42323 Mdot
.37653 .74341 Mdot
.62886 .21862 Mdot
.4208 .85459 Mdot
.40904 .79801 Mdot
.28922 .22134 Mdot
.47571 .25233 Mdot
.30315 .64971 Mdot
.42433 .20884 Mdot
.40577 .85786 Mdot
.5425 .63855 Mdot
.38963 .20159 Mdot
.60651 .52194 Mdot
.51923 .17644 Mdot
.36122 .61156 Mdot
.25094 .62891 Mdot
.20546 .39934 Mdot
.44721 .15391 Mdot
.65434 .26036 Mdot
.56297 .19309 Mdot
.5999 .43301 Mdot
.40791 .16126 Mdot
.20889 .51926 Mdot
.54517 .6705 Mdot
.56344 .6458 Mdot
.35969 .70827 Mdot
.32864 .25487 Mdot
.35824 .55074 Mdot
.74306 .39705 Mdot
.53516 .70064 Mdot
.43777 .31599 Mdot
.42746 .21973 Mdot
.66032 .36587 Mdot
.31608 .64886 Mdot
.7069 .45539 Mdot
.65435 .22115 Mdot
.5524 .69756 Mdot
.6621 .67847 Mdot
.47663 .76789 Mdot
.80443 .54935 Mdot
.28367 .60311 Mdot
.46575 .6782 Mdot
.66691 .25653 Mdot
.77382 .62479 Mdot
.75931 .45555 Mdot
.89686 .53545 Mdot
.7977 .49389 Mdot
.2526 .50985 Mdot
.33077 .22534 Mdot
.75369 .32127 Mdot
.23024 .46785 Mdot
.38424 .80492 Mdot
.24404 .43594 Mdot
.70419 .38928 Mdot
.47955 .39726 Mdot
.37235 .16596 Mdot
.66926 .40366 Mdot
.34226 .2113 Mdot
.81609 .39496 Mdot
.40028 .23742 Mdot
.52219 .31784 Mdot
.61704 .66475 Mdot
.47627 .59906 Mdot
.65929 .3538 Mdot
.46651 .20748 Mdot
.24656 .42852 Mdot
.61483 .68052 Mdot
.57811 .73078 Mdot
.64014 .63069 Mdot
.45259 .46778 Mdot
.44944 .7238 Mdot
.30081 .62493 Mdot
.7315 .49263 Mdot
.53801 .56961 Mdot
.73269 .41083 Mdot
.32779 .28995 Mdot
.4726 .22319 Mdot
.47712 .82577 Mdot
.34856 .58925 Mdot
.57166 .61964 Mdot
.5283 .21718 Mdot
.80535 .48832 Mdot
.32968 .64956 Mdot
.26332 .28664 Mdot
.32937 .71096 Mdot
.66737 .32039 Mdot
.62834 .26791 Mdot
.43334 .81917 Mdot
.74846 .72246 Mdot
.29865 .26666 Mdot
.23114 .44963 Mdot
.69918 .48317 Mdot
.52485 .27067 Mdot
.50374 .15433 Mdot
.77143 .44909 Mdot
.609 .25856 Mdot
.4664 .55653 Mdot
.38654 .35558 Mdot
.38861 .23439 Mdot
.63611 .39582 Mdot
.57036 .51549 Mdot
.15746 .56476 Mdot
.37279 .49154 Mdot
.24612 .26517 Mdot
.39692 .64068 Mdot
.26108 .70639 Mdot
.64579 .55304 Mdot
.50866 .57449 Mdot
.57622 .50348 Mdot
.30633 .60015 Mdot
.23449 .53815 Mdot
.8244 .49711 Mdot
.47908 .83644 Mdot
.6215 .65412 Mdot
.75186 .48041 Mdot
.80643 .57955 Mdot
.52172 .20768 Mdot
.44977 .36483 Mdot
.80333 .50737 Mdot
.48258 .55802 Mdot
.64272 .72801 Mdot
.79408 .36419 Mdot
.34083 .58535 Mdot
.46608 .43283 Mdot
.72363 .42048 Mdot
.38575 .20502 Mdot
.62421 .18973 Mdot
.33383 .76411 Mdot
.41345 .46876 Mdot
.38032 .65832 Mdot
.61004 .34004 Mdot
.49765 .1876 Mdot
.66873 .4842 Mdot
.26889 .63766 Mdot
.74705 .42516 Mdot
.16856 .3667 Mdot
.21844 .34005 Mdot
.20717 .36549 Mdot
.70844 .46502 Mdot
.30635 .51959 Mdot
.21466 .48578 Mdot
.61369 .26204 Mdot
.32978 .59233 Mdot
.80558 .46061 Mdot
.73672 .39788 Mdot
.33677 .80753 Mdot
.45941 .28551 Mdot
.76775 .5921 Mdot
.36418 .24102 Mdot
.35489 .39996 Mdot
.35882 .62651 Mdot
.69226 .38554 Mdot
.39902 .5087 Mdot
.42061 .64873 Mdot
.31266 .64167 Mdot
.25722 .60252 Mdot
.60633 .25712 Mdot
.41754 .31154 Mdot
.42764 .4759 Mdot
.56034 .22258 Mdot
.3481 .52184 Mdot
.66316 .69498 Mdot
.65003 .6901 Mdot
.49201 .50434 Mdot
.62519 .61494 Mdot
.42938 .41912 Mdot
.5425 .5375 Mdot
.59053 .52036 Mdot
.17947 .46806 Mdot
.73049 .52343 Mdot
.3408 .51868 Mdot
.25114 .68033 Mdot
.333 .50756 Mdot
.33154 .19193 Mdot
.60087 .76804 Mdot
.38487 .24793 Mdot
.7146 .68583 Mdot
.6743 .75583 Mdot
.19146 .66635 Mdot
.2408 .345 Mdot
.4456 .5482 Mdot
.33257 .53755 Mdot
.35012 .44183 Mdot
.65157 .62518 Mdot
.57682 .72293 Mdot
.30624 .32218 Mdot
.48192 .71115 Mdot
.6538 .3052 Mdot
.27802 .4628 Mdot
.7673 .57381 Mdot
.41089 .42434 Mdot
.4532 .14858 Mdot
.57601 .62091 Mdot
.14345 .47932 Mdot
.56818 .42142 Mdot
.52883 .24148 Mdot
.7871 .34024 Mdot
.33211 .75335 Mdot
.60323 .72786 Mdot
.78054 .67168 Mdot
.51114 .32976 Mdot
.42809 .47269 Mdot
.33139 .45877 Mdot
.69402 .3155 Mdot
.71148 .53454 Mdot
.66165 .45118 Mdot
.43562 .60273 Mdot
.53026 .80374 Mdot
.4438 .73069 Mdot
.30579 .51354 Mdot
.38551 .52024 Mdot
.65626 .27043 Mdot
.23302 .59327 Mdot
.48236 .5557 Mdot
.51335 .21122 Mdot
.40634 .33523 Mdot
.27954 .45862 Mdot
.25161 .30448 Mdot
.77101 .41709 Mdot
.58628 .16522 Mdot
.55765 .30603 Mdot
.48284 .58568 Mdot
.22362 .59146 Mdot
.3136 .62547 Mdot
.31632 .30414 Mdot
.73744 .29988 Mdot
.69987 .44244 Mdot
.24782 .6418 Mdot
.71152 .36094 Mdot
.58117 .37828 Mdot
.52587 .61441 Mdot
.4002 .73365 Mdot
.29826 .77328 Mdot
.24376 .37501 Mdot
.36823 .77325 Mdot
.29935 .53394 Mdot
.47157 .72581 Mdot
.36571 .5066 Mdot
.68223 .63067 Mdot
.40319 .32832 Mdot
.58069 .75588 Mdot
.53893 .15265 Mdot
.7453 .30592 Mdot
.4515 .61219 Mdot
.60905 .56941 Mdot
.57018 .48831 Mdot
.46575 .31141 Mdot
.51079 .52261 Mdot
.53076 .33401 Mdot
.49056 .47622 Mdot
.31879 .74368 Mdot
.32169 .60095 Mdot
.57027 .33493 Mdot
.49111 .16138 Mdot
.59588 .16772 Mdot
.39763 .1688 Mdot
.69176 .4888 Mdot
.29744 .49613 Mdot
.26544 .2686 Mdot
.35245 .29254 Mdot
.65263 .2176 Mdot
.28795 .28226 Mdot
.87145 .55439 Mdot
.463 .21138 Mdot
.34021 .64708 Mdot
.51722 .82058 Mdot
.25026 .55206 Mdot
.79743 .38193 Mdot
.54663 .67565 Mdot
.65881 .62042 Mdot
.80331 .3898 Mdot
.17299 .66711 Mdot
.23527 .37336 Mdot
.26207 .61498 Mdot
.5548 .26887 Mdot
.46872 .49775 Mdot
.49514 .69435 Mdot
.48039 .41306 Mdot
.56947 .59382 Mdot
.61572 .73109 Mdot
.7371 .40895 Mdot
.51296 .25843 Mdot
.49528 .69947 Mdot
.65895 .34738 Mdot
.68913 .32221 Mdot
.78265 .47184 Mdot
.48212 .21366 Mdot
.31262 .31616 Mdot
.45915 .42798 Mdot
.32447 .52704 Mdot
.67648 .52971 Mdot
.61977 .6915 Mdot
.46561 .37544 Mdot
.5934 .72872 Mdot
.22561 .5556 Mdot
.28947 .22488 Mdot
.67042 .63186 Mdot
.77398 .38744 Mdot
.38295 .47218 Mdot
.29471 .60923 Mdot
.59884 .22389 Mdot
.36212 .74046 Mdot
.50211 .70472 Mdot
.3537 .41533 Mdot
.47848 .17296 Mdot
.3189 .69422 Mdot
.74661 .37582 Mdot
.17862 .52519 Mdot
.43009 .63544 Mdot
.23308 .4181 Mdot
.5832 .27601 Mdot
.34197 .71981 Mdot
.27341 .46297 Mdot
.35374 .67454 Mdot
.50894 .63683 Mdot
.33178 .69768 Mdot
.81729 .43383 Mdot
.6941 .30482 Mdot
.34411 .25374 Mdot
.455 .18664 Mdot
.56309 .61573 Mdot
.74967 .39697 Mdot
.36253 .67727 Mdot
.50633 .67182 Mdot
.22356 .60258 Mdot
.48998 .15048 Mdot
.53002 .52178 Mdot
.65867 .40771 Mdot
.54457 .35907 Mdot
.37246 .30503 Mdot
.31513 .59607 Mdot
.61053 .54679 Mdot
.48496 .78221 Mdot
.30771 .45002 Mdot
.43843 .74921 Mdot
.5455 .71203 Mdot
.69484 .39942 Mdot
.3729 .52088 Mdot
.26239 .43835 Mdot
.6719 .56805 Mdot
.5603 .70465 Mdot
.44618 .39997 Mdot
.65493 .42337 Mdot
.66036 .50484 Mdot
.23362 .40212 Mdot
.22973 .37511 Mdot
.51941 .21138 Mdot
.78527 .41186 Mdot
.32772 .63054 Mdot
.28602 .28214 Mdot
.23778 .5344 Mdot
.43302 .27651 Mdot
.41192 .77271 Mdot
.56248 .37383 Mdot
.6847 .62722 Mdot
.33821 .51565 Mdot
.50054 .19584 Mdot
.46539 .26308 Mdot
.64437 .39044 Mdot
.5053 .54892 Mdot
.61608 .23116 Mdot
.46315 .53212 Mdot
.7892 .3467 Mdot
.25219 .55139 Mdot
.71417 .431 Mdot
.39445 .58249 Mdot
.61482 .52017 Mdot
.42503 .80957 Mdot
.5757 .17361 Mdot
.48575 .82681 Mdot
.60152 .45473 Mdot
.35895 .76411 Mdot
.22106 .46473 Mdot
.80986 .38997 Mdot
.70925 .41622 Mdot
.50766 .52289 Mdot
.40999 .42775 Mdot
.44533 .64986 Mdot
.54363 .72881 Mdot
.6954 .62916 Mdot
.32965 .30867 Mdot
.7189 .58194 Mdot
.58731 .7528 Mdot
.4411 .38205 Mdot
.19466 .54717 Mdot
.46416 .18098 Mdot
.4228 .34348 Mdot
.49994 .57437 Mdot
.67744 .69936 Mdot
.68914 .40837 Mdot
.78128 .73381 Mdot
.25879 .25487 Mdot
.546 .36198 Mdot
.5981 .49262 Mdot
.66929 .44265 Mdot
.63456 .61781 Mdot
.30545 .33287 Mdot
.51441 .20723 Mdot
.37407 .63011 Mdot
.72507 .62341 Mdot
.35916 .70141 Mdot
.30559 .59098 Mdot
.6327 .38049 Mdot
.4216 .57284 Mdot
.31251 .20386 Mdot
.81245 .49437 Mdot
.31822 .61605 Mdot
.82951 .65983 Mdot
.3801 .73216 Mdot
.39029 .45581 Mdot
.64711 .25029 Mdot
.37837 .18458 Mdot
.69246 .46512 Mdot
.69288 .67259 Mdot
.22181 .38435 Mdot
.70764 .43449 Mdot
.71119 .34353 Mdot
.4757 .76698 Mdot
.44664 .75489 Mdot
.52898 .65142 Mdot
.6769 .75364 Mdot
.19073 .47369 Mdot
.33776 .27044 Mdot
.42644 .18866 Mdot
.58488 .76887 Mdot
.35097 .81727 Mdot
.57881 .16832 Mdot
.68537 .36321 Mdot
.49192 .7174 Mdot
.66804 .26246 Mdot
.63638 .46181 Mdot
.34259 .41509 Mdot
.59937 .76401 Mdot
.39597 .36615 Mdot
.65575 .76086 Mdot
.43705 .78923 Mdot
.7151 .36593 Mdot
.33697 .40471 Mdot
.5409 .51919 Mdot
.50934 .21853 Mdot
.53731 .7795 Mdot
.72671 .45338 Mdot
.72697 .63316 Mdot
.62613 .44363 Mdot
.53806 .21219 Mdot
.6527 .24012 Mdot
.51136 .51781 Mdot
.17194 .65999 Mdot
.3529 .21163 Mdot
.37792 .75472 Mdot
.56143 .4071 Mdot
.533 .14692 Mdot
.47776 .50852 Mdot
.27101 .29754 Mdot
.80639 .42765 Mdot
.65161 .67935 Mdot
.21672 .57495 Mdot
.55917 .36208 Mdot
.25009 .32739 Mdot
.43723 .25127 Mdot
.34829 .3997 Mdot
.6218 .72714 Mdot
.7088 .45215 Mdot
.53057 .77356 Mdot
.62709 .41079 Mdot
.50224 .29376 Mdot
.32197 .51492 Mdot
.32721 .20326 Mdot
.60642 .35955 Mdot
.43608 .43976 Mdot
.59229 .42603 Mdot
.48404 .83165 Mdot
.80215 .66868 Mdot
.51073 .29622 Mdot
.31134 .69198 Mdot
.74353 .40015 Mdot
.63681 .28272 Mdot
.23674 .35895 Mdot
.40066 .89468 Mdot
.77827 .32665 Mdot
.37192 .45527 Mdot
.24967 .40971 Mdot
.72684 .46575 Mdot
.40575 .16989 Mdot
.7129 .71688 Mdot
.6364 .70449 Mdot
.49029 .84895 Mdot
.64561 .4689 Mdot
.4678 .41033 Mdot
.83169 .46087 Mdot
.58347 .17542 Mdot
.54749 .79474 Mdot
.50887 .15708 Mdot
.5302 .31699 Mdot
.5657 .41231 Mdot
.57581 .88156 Mdot
.51495 .18577 Mdot
.49994 .31957 Mdot
.45433 .83583 Mdot
.30349 .42941 Mdot
.47099 .39511 Mdot
.4833 .68009 Mdot
.7668 .44619 Mdot
.69854 .33188 Mdot
.44561 .15424 Mdot
.297 .51056 Mdot
.59485 .73054 Mdot
.40471 .58914 Mdot
.57565 .506 Mdot
.5207 .4473 Mdot
.40939 .60167 Mdot
.67489 .32441 Mdot
.49622 .50804 Mdot
.38393 .58049 Mdot
.77417 .49372 Mdot
.8536 .4691 Mdot
.47602 .24683 Mdot
.45628 .62633 Mdot
.56541 .45974 Mdot
.42525 .33337 Mdot
.65993 .3514 Mdot
.64101 .30992 Mdot
.80976 .40952 Mdot
.82909 .34578 Mdot
.65395 .58995 Mdot
.58031 .33984 Mdot
.38737 .49133 Mdot
.32463 .30406 Mdot
.45074 .2275 Mdot
.35354 .60608 Mdot
.56917 .72157 Mdot
.55114 .33718 Mdot
.50653 .29333 Mdot
.43408 .5994 Mdot
.19869 .31795 Mdot
.4959 .42132 Mdot
.29089 .30677 Mdot
.63523 .2117 Mdot
.66062 .69751 Mdot
.50454 .25141 Mdot
.49212 .3313 Mdot
.21511 .49865 Mdot
.46857 .50659 Mdot
.50445 .49338 Mdot
.65347 .69134 Mdot
.42627 .17362 Mdot
.46787 .26241 Mdot
.3293 .26752 Mdot
.52641 .39128 Mdot
.73571 .51157 Mdot
.25057 .60619 Mdot
.2262 .35412 Mdot
.46696 .30123 Mdot
.64578 .20696 Mdot
.65689 .67345 Mdot
.72839 .57456 Mdot
.53439 .25761 Mdot
.3326 .21337 Mdot
.40428 .79148 Mdot
.42911 .23093 Mdot
.29356 .7086 Mdot
.43087 .70112 Mdot
.66233 .36744 Mdot
.62105 .66059 Mdot
.57379 .33892 Mdot
.28815 .43785 Mdot
.3598 .16251 Mdot
.22264 .36345 Mdot
.40077 .68221 Mdot
.62101 .67798 Mdot
.40486 .27497 Mdot
.56527 .50605 Mdot
.8574 .61186 Mdot
.76285 .67441 Mdot
.30695 .20721 Mdot
.68337 .30364 Mdot
.39969 .44594 Mdot
.32106 .663 Mdot
.4873 .45144 Mdot
.58546 .64251 Mdot
.41247 .17113 Mdot
.53601 .29479 Mdot
.43658 .78232 Mdot
.47387 .41459 Mdot
.26182 .67698 Mdot
.42134 .49547 Mdot
.61029 .57176 Mdot
.60723 .58004 Mdot
.39053 .80488 Mdot
.62521 .22261 Mdot
.4616 .50735 Mdot
.84829 .59432 Mdot
.44166 .20208 Mdot
.5355 .17803 Mdot
.64421 .61979 Mdot
.30129 .75331 Mdot
.34571 .5453 Mdot
.40887 .49172 Mdot
.37469 .67591 Mdot
.61016 .43627 Mdot
.33944 .71174 Mdot
.65033 .29254 Mdot
.2428 .57226 Mdot
.45055 .61538 Mdot
.89599 .40534 Mdot
.68909 .35362 Mdot
.44055 .32342 Mdot
.38557 .74643 Mdot
.51696 .16657 Mdot
.66212 .53663 Mdot
.84384 .47038 Mdot
.54947 .56591 Mdot
.5371 .44142 Mdot
.42317 .30831 Mdot
.53864 .24914 Mdot
.36736 .70621 Mdot
.16683 .61116 Mdot
.80405 .47693 Mdot
.68149 .58314 Mdot
.53558 .57029 Mdot
.34183 .50455 Mdot
.37292 .47344 Mdot
.69856 .71259 Mdot
.85188 .51935 Mdot
.4459 .48904 Mdot
.50049 .18705 Mdot
.22001 .69757 Mdot
.721 .33833 Mdot
.41596 .16334 Mdot
.33012 .5482 Mdot
.27302 .50673 Mdot
.65966 .34232 Mdot
.74552 .50837 Mdot
.61555 .58675 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Dooooo`;o0000/ooo
ool001cooooo00?o0000ooooooooool0U?ooool2o`000;?ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0:kooooo
0ol0002Hooooo`007?ooool00ol0003oooooooooo`2^ooooo`Co0000Uoooool001cooooo00?o0000
ooooooooool0/?ooool2o`0009Oooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0;oo
oooo0_l00028ooooo`007?ooool00ol0003oooooooooo`2oooooo`;o0000R?ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`35ooooo`;o0000P_ooool0
01cooooo00?o0000ooooooooool0^?ooool2o`0000_ooooo0_l00022ooooo`007?ooool00ol0003o
ooooooooo`2Kooooo`?o00002oooool2o`0000gooooo0_l0000?ooooo`;o0000O_ooool001cooooo
00?o0000ooooooooool0Qoooool2o`0000Kooooo0_l0000:ooooo`?o00002oooool2o`0001kooooo
0_l00002ooooo`;o00001?ooool2o`0007Cooooo000Looooo`;o0000OOooool2o`0000Wooooo0_l0
00000ooooooo0000o`000003ooooo`;o00002_ooool2o`0000?ooooo0_l00002ooooo`;o00001Ooo
ool2o`0001cooooo0_l00002ooooo`;o00001?ooool2o`0007Cooooo000Looooo`03o`000?oooooo
oooo07Cooooo0_l00006ooooo`;o00003?ooool2o`000004ooooool0003o0000o`00013ooooo0ol0
00000ooooooo0000o`000005ooooo`;o0000W?ooool001cooooo00?o0000ooooooooool0M?ooool2
o`0001Oooooo0ol0000:ooooo`;o00001?ooool4o`0002oooooo0_l0001dooooo`007?ooool00ol0
003oooooooooo`1`ooooo`?o00003_ooool4o`0000Sooooo0_l000000ooooooo0000o`000008oooo
o`Co00001?ooool2o`0000Oooooo0_l0000Vooooo`;o0000M?ooool001cooooo00?o0000oooooooo
ool0L?ooool3o`0000;ooooo0_l0000:ooooo`Co00002?ooool2o`000003ooooool0003o000000[o
oooo0_l00002ooooo`;o00002Oooool2o`0000kooooo0_l0002<ooooo`007?ooool00ol0003ooooo
ooooo`1eooooo`;o00001_ooool2o`0000Cooooo0_l0000>ooooo`Oo00001_ooool2o`0000;ooooo
0_l0000<ooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`;o00001Oooool2o`0008;o
oooo000Looooo`03o`000?oooooooooo07gooooo0_l000000ooooooo0000o`000002o`0000;ooooo
0_l0000;ooooo`Oo00002_ooool2o`0000cooooo0_l00002ooooo`Co00001?ooool2o`0000Gooooo
0_l00022ooooo`007?ooool00ol0003oooooooooo`20ooooo`Co00000_ooool3o`0000;ooooo0_l0
0007ooooo`;o00000_ooool2o`0000Cooooo1?l0000Dooooo`?o00009Oooool2o`0006Wooooo000L
ooooo`03o`000?oooooooooo08Oooooo0_l00002ooooo`;o00001oooool2o`0000;ooooo0_l00000
1?oooooo0000o`000?ooool4o`0000?ooooo0_l000000ooooooo0000o`000002o`0000_ooooo0_l0
00000ooooooo0000o`00000Rooooo`;o0000JOooool001cooooo00?o0000ooooooooool0Q?ooool2
o`0000gooooo0_l00006ooooo`?o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o
000000;o00003_ooool2o`0000Kooooo0_l00025ooooo`007?ooool00ol0003oooooooooo`1goooo
o`;o00002oooool2o`0000gooooo0_l00007ooooo`;o000000?oooooo`000?l000003?ooool6o`00
00oooooo0_l00004ooooo`;o0000Ooooool001cooooo00?o0000ooooooooool0G_ooool2o`0000[o
oooo0_l0000:ooooo`?o00005oooool2o`0000cooooo0ol00003ooooo`;o00001oooool6o`0000?o
oooo2Ol00009ooooo`;o0000Ooooool001cooooo00?o0000ooooooooool0G_ooool2o`0000[ooooo
0_l00002ooooo`;o00001_ooool2o`0000Oooooo0_l00006ooooo`;o00001?ooool2o`000003oooo
ool0003o000000cooooo0ol00003ooooo`;o00004?ooool9o`0000Sooooo0_l00006ooooo`;o0000
N?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03
o`000?oooooooooo06Sooooo0_l00004ooooo`;o00000_ooool2o`0000Kooooo0_l00003ooooo`;o
00001_ooool2o`0000Cooooo0_l0000Tooooo`;o000000?oooooo`000?l000001?ooool3o`0000Ko
oooo1?l00006ooooo`;o0000N?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q
8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo06Sooooo0_l00004
ooooo`;o00000_ooool2o`0000Kooooo0_l00006ooooo`;o00006oooool2o`0001;ooooo0_l00000
0ooooooo0000o`000004ooooo`?o00001_ooool2o`0000Kooooo0_l0001jooooo`0000?ooooooa0@
4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000oooo
ooooool0K_ooool2o`0001;ooooo0_l00002ooooo`;o00002?ooool2o`0000gooooo0_l0000/oooo
o`;o0000N_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So
8B4Qonk^kP06ooooo`?o0000Noooool2o`0000Wooooo0_l00004ooooo`;o00000_ooool2o`0001Go
oooo0ol0000Booooo`Co00001?ooool2o`0008?ooooo00000ooooooo0000ooooo`02ooooo`03o`00
0?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`1Rooooo`;o0000
0oooool2o`0000;ooooo0_l00003ooooo`;o00002?ooool3o`0000oooooo0_l0000:ooooo`;o0000
3Oooool3o`0001;ooooo1?l00002ooooo`Co00003Oooool2o`0007Cooooo00000ooooooo410@oooo
o`02ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`1Pooooo`Co00000oooool2o`0000;ooooo0_l00003ooooo`;o00002?ooool2o`0000[ooooo0_l0
000<ooooo`;o00000_ooool2o`0000Wooooo0_l000000ooooooo0000o`00000Eooooo`;o00000ooo
ool2o`0000[ooooo0_l00003ooooo`;o0000M?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
2oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0H?ooool2o`0000Wo
oooo0_l00002ooooo`;o00005?ooool3o`0000_ooooo0ol0000<ooooo`Ko00000oooool2o`0001[o
oooo0_l00002ooooo`;o000000?oooooo`000?l00000NOooool00006ooooooo^k^ko<S8bo`000?lb
<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0J?ooool2
o`000003ooooool0003o000000;ooooo0_l0000Dooooo`;o00002?ooool2o`0000;ooooo0_l00004
ooooo`;o00001oooool6o`0000?ooooo0_l0000>ooooo`;o00002_ooool2o`0000;ooooo0_l0001l
ooooo`007?ooool00ol0003oooooooooo`1Qooooo`;o00001Oooool2o`000003ooooool0003o0000
01;ooooo0_l00002ooooo`;o00002_ooool2o`0000Sooooo0_l00007ooooo`;o00001?ooool2o`00
017ooooo0_l0000Cooooo`;o00001?ooool2o`00077ooooo000Looooo`03o`000?oooooooooo05[o
oooo0_l00002ooooo`;o000000?oooooo`000?l000004oooool2o`0000Gooooo1?l00002ooooo`;o
00000_ooool2o`0001?ooooo0_l00004ooooo`;o00001?ooool4o`0000Cooooo0_l00005ooooo`?o
00003_ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000000_l00002ooooo`?o
00005_ooool2o`0005Sooooo000Looooo`03o`000?oooooooooo05Wooooo0ol00002ooooo`;o0000
3Oooool2o`0000Oooooo0_l00005ooooo`;o00002?ooool2o`0000?ooooo0_l00006ooooo`Co0000
1?ooool2o`0000cooooo0_l00004ooooo`Co00000oooool3o`0000Gooooo0_l00006ooooo`?o0000
00?oooooo`000?l000000_l00002ooooo`?o00000oooool4o`0001Cooooo0_l0001Hooooo`007?oo
ool00ol0003oooooooooo`1Iooooo`?o00003?ooool2o`0000?ooooo0_l0000Mooooo`;o000000?o
ooooo`000?l000000oooool4o`0001[ooooo0_l0000;ooooo`;o00001Oooool3o`0000Wooooo0_l0
0005ooooo`;o0000K_ooool001cooooo00?o0000ooooooooool0F_ooool2o`0000cooooo0_l0000U
ooooo`;o00002Oooool2o`0001[ooooo0_l000000ooooooo0000o`00000;ooooo`;o000000?ooooo
o`000?l000001_ooool2o`0007Kooooo000Looooo`03o`000?oooooooooo06kooooo0_l000000ooo
oooo0000o`000003o`0001;ooooo0_l000000ooooooo0000o`00000=ooooo`;o00006Oooool3o`00
0003ooooool0003o000000Wooooo0_l00003ooooo`;o00001_ooool2o`0007Kooooo000Looooo`03
o`000?oooooooooo05kooooo0_l00005ooooo`;o00001oooool2o`000003ooooool0003o000000?o
00001?ooool2o`0000cooooo0_l000000ooooooo0000o`000004ooooo`?o00000_ooool2o`0001go
oooo0_l0000=ooooo`?o00002_ooool4o`000003ooooool0003o000000;ooooo0_l0001]ooooo`00
7?ooool00ol0003oooooooooo`1Nooooo`;o00001Oooool2o`0001?ooooo0_l00002ooooo`;o0000
3Oooool2o`0000;ooooo0ol00002ooooo`;o00002oooool2o`0000Gooooo0_l0000Iooooo`;o0000
2_ooool4o`000003ooooool0003o000000Co0000KOooool001cooooo00?o0000ooooooooool0I?oo
ool2o`0000gooooo0_l00009ooooo`?o00001?ooool2o`0000Kooooo0_l000000ooooooo0000o`00
000Aooooo`;o00000oooool4o`0001Wooooo0_l00009ooooo`;o000000?oooooo`000?l000000ooo
ool2o`0000?ooooo0_l000000ooooooo0000o`00001Wooooo`007?ooool00ol0003oooooooooo`1C
ooooo`;o00002?ooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000Cooooo0_l00003
ooooo`?o00000_ooool4o`0000Wooooo0_l0000Fooooo`;o00007_ooool2o`0000Kooooo0_l0000;
ooooo`;o000000?oooooo`000?l00000Ioooool001cooooo00?o0000ooooooooool0Doooool2o`00
00Sooooo0_l00004ooooo`;o00001_ooool2o`0000Kooooo0_l00004ooooo`;o00000oooool3o`00
00;ooooo0_l0000@ooooo`Co00001oooool2o`0000Kooooo0_l000000ooooooo0000o`00000Doooo
o`;o00001Oooool2o`0001Gooooo0_l0001Xooooo`007?ooool2o`0006Cooooo0_l0000Dooooo`;o
00001?ooool2o`0000Wooooo0_l00009ooooo`Ko00001Oooool2o`0000Kooooo0_l000000ooooooo
0000o`00000Dooooo`;o00002?ooool2o`000003ooooool0003o000000oooooo0_l0001Xooooo`00
7?ooool00ol0003oooooooooo`1@ooooo`?o00005?ooool2o`0000?ooooo0_l00006ooooo`Co0000
4_ooool2o`0000_ooooo1?l00005ooooo`?o00009_ooool4o`000003ooooool0003o000002_ooooo
0_l0001<ooooo`007?ooool00ol0003oooooooooo`1@ooooo`?o00001_ooool2o`0000cooooo0_l0
0003ooooo`;o00001_ooool4o`0000Cooooo0_l0000<ooooo`;o00000oooool2o`0000Oooooo0_l0
0007ooooo`Co00001Oooool2o`0001Gooooo0ol00005ooooo`?o00002Oooool2o`0000[ooooo1?l0
000Fooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0Coooool3o`0000Oooooo0_l00005
ooooo`;o00002_ooool2o`0000?ooooo0_l00002ooooo`;o00001Oooool5o`0000Wooooo0ol00002
ooooo`;o00001oooool2o`0000Wooooo0_l00005ooooo`;o00000oooool2o`0000;ooooo0_l00008
ooooo`;o00000_ooool3o`0000Kooooo0_l00005ooooo`;o00000_ooool3o`0000Oooooo1ol0001S
ooooo`007?ooool00ol0003oooooooooo`1?ooooo`;o00001_ooool2o`0000Oooooo0_l0000?oooo
o`;o00001oooool2o`0000;ooooo0ol00003ooooo`;o00001Oooool2o`0000?ooooo0_l000001?oo
oooo0000o`000?l00009ooooo`Co00002Oooool2o`000003ooooool0003o000000;ooooo1?l00006
ooooo`;o00001?ooool3o`0000_ooooo0_l00002ooooo`?o00001oooool2o`0000?ooooo0_l0001S
ooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00002Oooool3o`0000?ooooo0_l00008oooo
o`;o00004Oooool2o`0000Sooooo0_l00003ooooo`;o00001Oooool2o`000004ooooool0003o0000
o`0000Wooooo1?l00009ooooo`;o00001oooool2o`0000Wooooo0_l000001?oooooo0000o`000?l0
000?ooooo`;o00001?ooool2o`0000Kooooo1?l0001Rooooo`007?ooool00ol0003oooooooooo`1<
ooooo`;o00001Oooool2o`0000?ooooo0_l00003ooooo`?o00001oooool2o`000003ooooool0003o
000000;o00000oooool2o`0000cooooo0_l00003ooooo`;o00000oooool2o`0000Sooooo0_l00007
ooooo`;o00002Oooool2o`0000Oooooo0_l00003ooooo`;o00001_ooool2o`000003ooooool0003o
000000;ooooo0_l00002ooooo`;o00001oooool2o`0000Sooooo0_l00006ooooo`Co0000H_ooool0
01cooooo00?o0000ooooooooool0Doooool2o`0000Wooooo0_l0000:ooooo`Go00000_ooool2o`00
00Wooooo0_l000000ooooooo0000o`00000Kooooo`;o00002Oooool2o`0000Oooooo0_l0000;oooo
o`;o00002Oooool2o`0000Oooooo0_l0001fooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o
00004?ooool4o`0000[ooooo0_l000000ooooooo0000o`000002ooooo`;o00001oooool2o`0002oo
oooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo0_l0000Looooo`;o0000H_ooool001cooooo
00?o0000ooooooooool0FOooool2o`0000Sooooo0_l00006ooooo`Co00001_ooool2o`0000;ooooo
0_l00005ooooo`;o00001oooool2o`0001[ooooo0_l0000Cooooo`;o00000oooool6o`0000;ooooo
0_l00005ooooo`;o00002oooool2o`0000Sooooo0_l0001Rooooo`007?ooool00ol0003ooooooooo
o`1Iooooo`?o00001oooool2o`0000Sooooo1?l00004ooooo`;o00001?ooool2o`0001Oooooo0_l0
0006ooooo`;o00001oooool2o`0001[ooooo0_l00006ooooo`Co000000?oooooo`000?l000000_oo
ool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000Sooooo0_l0001Rooooo`007?ooool0
0ol0003oooooooooo`1?ooooo`;o00001?ooool2o`0000;ooooo1?l0000@ooooo`Co00002_ooool2
o`0000Oooooo0_l0000;ooooo`;o000000?oooooo`000?l000001_ooool3o`0001?ooooo0_l0000E
ooooo`Co00001Oooool2o`0000;ooooo0_l000000ooooooo0000o`000006ooooo`;o00001oooool2
o`0005gooooo000Looooo`03o`000?oooooooooo04oooooo0_l000001?oooooo0000o`000?ooool4
o`0000;ooooo0_l00008ooooo`;o00001Oooool2o`0000gooooo0_l00005ooooo`Co00002oooool2
o`0000[ooooo0_l0000;ooooo`;o00001_ooool2o`0001Kooooo0_l00007ooooo`;o00002_ooool4
o`0000;ooooo0_l00003ooooo`?o0000G?ooool001cooooo00?o0000ooooooooool0D_ooool2o`00
00?ooooo0_l00009ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o00001?ooool2o`00
00Oooooo0_l00003ooooo`Go00009Oooool2o`000003ooooool0003o000000Cooooo0_l00009oooo
o`;o00000oooool2o`0000kooooo0_l0000:ooooo`;o00000oooool3o`0000Cooooo0_l0001Loooo
o`007?ooool00ol0003oooooooooo`1Rooooo`;o00000oooool2o`0000Kooooo0_l000000ooooooo
0000o`00000<ooooo`;o00001?ooool2o`0000Wooooo0_l0000<ooooo`Co00001oooool2o`000003
ooooool0003o000000Cooooo0_l00002ooooo`;o00001Oooool2o`0000?ooooo0_l00007ooooo`;o
000000?oooooo`000?l000000oooool2o`0000kooooo0_l00006ooooo`;o0000Foooool001cooooo
00?o0000ooooooooool0E?ooool2o`0000gooooo1?l00008ooooo`;o00005Oooool2o`0000Kooooo
0_l000000ooooooo0000o`00000<ooooo`Go00001?ooool4o`0000?ooooo0_l00004ooooo`Co0000
0oooool3o`0000gooooo1Ol00003ooooo`;o00003_ooool2o`0000;ooooo0_l00002ooooo`;o0000
Foooool001cooooo0_l0001Eooooo`;o00003Oooool5o`0001Cooooo0_l0000@ooooo`;o00001?oo
ool2o`0000Oooooo0_l00003ooooo`;o00000_ooool5o`0000Cooooo0_l00004ooooo`;o00001Ooo
ool5o`0000cooooo0ol0000Hooooo`;o000000Coooooo`000?l0003o0000Foooool001cooooo00?o
0000ooooooooool0C_ooool2o`0001?ooooo0_l000000ooooooo0000o`000002o`0000[ooooo0_l0
0006ooooo`;o00005_ooool2o`0000Oooooo0_l00002ooooo`;o00000_ooool8o`0001;ooooo0_l0
000;ooooo`Co00001?ooool2o`0000Cooooo0_l0000?ooooo`Co0000F_ooool001cooooo00?o0000
ooooooooool0C_ooool2o`0000_ooooo0_l00006ooooo`;o000000?oooooo`000?l000000_l0000:
ooooo`?o00005oooool2o`00017ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o000000?o
ooooo`000?l000001?ooool3o`0000Cooooo1?l00002ooooo`;o00003?ooool2o`0000?ooooo0_l0
00000ooooooo0000o`000004ooooo`;o00000_ooool2o`0000Wooooo0_l00002ooooo`?o0000FOoo
ool001cooooo00?o0000ooooooooool0Foooool2o`0000[ooooo0_l0000<ooooo`Co00003Oooool2
o`0000Kooooo0_l00009ooooo`?o000000?oooooo`000?l000000_ooool9o`000003ooooool0003o
000000Cooooo0ol00004ooooo`So00003?ooool2o`0000?ooooo0_l0000;ooooo`;o000000?ooooo
o`000?l000001_ooool2o`0000;ooooo1Ol0000Hooooo`;o0000?Oooool001cooooo00?o0000oooo
ooooool0B?ooool2o`0001Oooooo0_l00004ooooo`;o00000oooool2o`0000Sooooo0ol0000;oooo
o`Go00001oooool2o`0000;ooooo0ol00002ooooo`Ko00000_ooool4o`0000;ooooo1ol0000>oooo
o`;o00003_ooool2o`0000_ooooo0_l00006ooooo`;o00002_ooool2o`000003ooooool0003o0000
00Gooooo0_l0000Aooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0B?ooool2o`0000Ko
oooo0_l0000?ooooo`?o00000oooool3o`0000;ooooo0_l0000Fooooo`;o000000Coooooo`000?l0
003ooooo1Ol000000ooooooo0000o`000002ooooo`?o00001Oooool2o`0000Kooooo0_l000000ooo
oooo0000o`000002o`000004ooooool0003o0000o`0001kooooo0_l0000:ooooo`;o000000?ooooo
o`000?l000000_l00008ooooo`?o00001_ooool4o`0000;ooooo0_l0001@ooooo`007?ooool00ol0
003oooooooooo`0mooooo`;o00004Oooool3o`0000oooooo0_l00004ooooo`;o00005_ooool2o`00
00Sooooo1Ol000000ooooooo0000o`000002ooooo`Co00001?ooool2o`000003ooooool0003o0000
00?ooooo1_l00002ooooo`?o00005oooool2o`0000Gooooo0_l000000ooooooo0000o`000007oooo
o`;o000000?oooooo`000?l000000_l00008ooooo`?o00001_ooool6o`0005;ooooo000Looooo`03
o`000?oooooooooo03gooooo0_l0000@ooooo`Co00002_ooool2o`000003ooooool0003o000001ko
oooo0_l0000>ooooo`;o000000?oooooo`000?l000000ol00003ooooo`Oo00000_ooool5o`0000?o
oooo1_l0000Dooooo`;o00002?ooool2o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l0
00001oooool2o`0000Cooooo0_l00004ooooo`;o000000Coooooo`000?l0003o0000D_ooool001co
oooo00?o0000ooooooooool0Coooool2o`0000cooooo0_l000000ooooooo0000o`000004ooooo`;o
00000_ooool2o`0000?ooooo0_l0000Aooooo`;o00001oooool2o`0000Kooooo1?l00004ooooo`_o
00001_ooool7o`0000Kooooo0_l0000Jooooo`Co00000oooool2o`0000Cooooo0_l000001?oooooo
0000o`000?l00003ooooo`Co00000_ooool2o`000003ooooool0003o000005?ooooo000Looooo`03
o`000?oooooooooo04kooooo0_l0000Fooooo`;o00000_ooool2o`0000?ooooo0_l0000>ooooo`;o
000000?oooooo`000?l000001oooool2o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`;o
000000?oooooo`000?l000000oooool4o`0000Gooooo1?l000001?oooooo0000o`000?l00006oooo
o`;o00007?ooool2o`0000Wooooo0_l00002ooooo`;o00001Oooool2o`0000[ooooo0_l0001>oooo
o`007?ooool00ol0003oooooooooo`1>ooooo`;o0000;oooool2o`0000_ooooo1?l000001?oooooo
0000o`000?ooool3o`0000;ooooo3?l000001?oooooo0000o`000?ooool4o`0000?ooooo0_l0000E
ooooo`;o00005_ooool2o`0000?ooooo0_l0000Booooo`?o0000C_ooool001cooooo00?o0000oooo
ooooool0Goooool2o`0001kooooo0ol00004ooooo`;o00001?ooool4o`0000Cooooo0ol000000ooo
oooo0000o`00000Fo`0000Gooooo0_l00006ooooo`Co00001_ooool2o`0000Gooooo0_l0000?oooo
o`;o00000oooool2o`0001;ooooo0_l0000Hooooo`;o0000=Oooool001cooooo00?o0000oooooooo
ool0Goooool2o`0001oooooo0_l00004ooooo`;o00002OoooolJo`000003ooooool0003o000000?o
000000Coooooo`000?l0003ooooo0_l00005ooooo`Go00003Oooool2o`0000oooooo1?l00003oooo
o`;o00003Oooool4o`0001Wooooo0_l0000eooooo`007?ooool00ol0003oooooooooo`13ooooo`;o
00001Oooool3o`0003Cooooo0_l00006ooooo`;o000000Coooooo`000?l0003ooooo1_l000000ooo
oooo0000o`000005o`000003ooooool0003o000000_o000000?oooooo`000?l000000ol000000ooo
oooo0000o`000003ooooo`Co000000?oooooo`000?l000000_l00002ooooo`;o00006oooool4o`00
00?ooooo0_l0000=ooooo`Go00000_ooool2o`0004_ooooo000Looooo`03o`000?oooooooooo04?o
oooo0_l00005ooooo`?o00001_ooool2o`0002cooooo0_l00003ooooo`;o000000Coooooo`000?l0
003ooooo0_l000000ooooooo0000o`000004oooooa_o00001oooool4o`0000Oooooo0_l0000>oooo
o`;o00003oooool2o`0000[ooooo0_l00004ooooo`;o000000?oooooo`000?l000000_ooool2o`00
04_ooooo000Looooo`03o`000?oooooooooo04_ooooo0_l00004ooooo`Co0000<?ooool3o`0000Wo
oooo0_l000001Ooooooo0000o`000?l0003ooooo01So000000Coooooo`000?l0003ooooo0_l00003
ooooo`;o00003?ooool2o`000003ooooool0003o000000Kooooo0_l0000;ooooo`;o00000_ooool2
o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o00001?ooool2o`0000Kooooo1?l00008
ooooo`;o0000?_ooool001cooooo0_l0001<ooooo`;o00001?ooool2o`000003ooooool0003o0000
02oooooo0ol00004ooooo`;o00000oooool6o`000003ooooool0003o000001go00000_ooool2o`00
00_ooooo0ol000000ooooooo0000o`000006ooooo`;o00001oooool2o`0000;ooooo0_l00004oooo
o`;o000000?oooooo`000?l000000ol00005ooooo`;o00001Oooool2o`0000;ooooo1?l00008oooo
o`;o0000?_ooool001cooooo00?o0000ooooooooool0E?ooool2o`0003Cooooo1ol000000ooooooo
0000o`00000Uo`0000Oooooo0_l00004ooooo`;o00001?ooool2o`0000Cooooo0ol00006ooooo`?o
000000?oooooo`000?l000001?ooool2o`0000?ooooo0_l00004ooooo`Co00001Oooool4o`0004co
oooo000Looooo`03o`000?oooooooooo03Sooooo0_l0000;ooooo`Co0000<Oooool2o`0000kooooo
0_l00002ooooo`?o000000?oooooo`000?l000008_l000000ooooooo0000o`000004ooooo`;o0000
00?oooooo`000?l000002_ooool2o`0000;ooooo1Ol00007ooooo`;o00004_ooool2o`0000Wooooo
0_l000000ooooooo0000o`000019ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00001?oo
ool2o`0000Gooooo1_l0000_ooooo`;o00002_ooool2o`0000;ooooo1ol000001Ooooooo0000o`00
0?l0003ooooo027o000000?oooooo`000?l000000oooool2o`0000;ooooo0_l00007ooooo`;o0000
1?ooool2o`000003ooooool0003o000001_ooooo0_l0000<ooooo`;o0000BOooool001cooooo00?o
0000ooooooooool0??ooool6o`0000?ooooo0_l00002ooooo`Co0000=_ooool2o`000003ooooool0
003o000000;ooooo1ol000000ooooooo0000o`00000Po`000004ooooool0003o0000ooooo`;o0000
1?ooool2o`000003ooooool0003o000000Oooooo0_l00005ooooo`Co00001_ooool2o`0000Kooooo
0ol0000:ooooo`;o00002oooool2o`0004[ooooo000Looooo`03o`000?oooooooooo03cooooo0_l0
0002ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`;o00002Oooool2o`0002Gooooo
0_l00004ooooo`;o00001?ooool2o`000003ooooool0003o000002Oo00002Oooool3o`0000cooooo
0_l00002ooooo`Go00001Oooool5o`0000?ooooo0ol0000Cooooo`?o000000Coooooo`000?l0003o
0000BOooool001cooooo00?o0000ooooooooool0<oooool2o`0000_ooooo1?l000001?oooooo0000
o`000?ooool4o`0000;ooooo0_l00006ooooo`;o00009Oooool2o`0000[ooooo0_l000000ooooooo
0000o`000004o`0000;ooooo6Ol000000ooooooo0000o`000008o`0000?ooooo0_l00002ooooo`;o
00003?ooool2o`0000Cooooo0ol00007ooooo`?o00000_ooool5o`0001;ooooo0ol000000ooooooo
0000o`000002o`0004Sooooo000Looooo`03o`000?oooooooooo03?ooooo0_l0000=ooooo`;o0000
1_ooool2o`0000;ooooo0_l00008ooooo`Co00007_ooool2o`0000Cooooo0_l0000:ooooo`Go0000
0ooooolPo`000004ooooool0003o0000o`0000?ooooo0_l0000@ooooo`;o00001?ooool2o`0000go
oooo0_l000000ooooooo0000o`00000@ooooo`;o00000oooool2o`000003ooooool0003o000004So
oooo000Looooo`03o`000?oooooooooo04?ooooo0_l00002ooooo`Ko00002oooool4o`0001kooooo
0_l00004ooooo`;o00002_ooool<o`000003ooooool0003o000000Oo000000?oooooo`000?l00000
4?l00003ooooo`;o00000oooool4o`0002Oooooo0_l00009ooooo`;o00000_ooool2o`0000?ooooo
0_l000000ooooooo0000o`000018ooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00000_oo
ool8o`0003?ooooo0_l00005ooooo`;o00000_ooool;o`000003ooooool0003o000000Oo000000?o
ooooo`000?l000001ol00002ooooo`go00000_ooool4o`0000gooooo0_l0000Eooooo`;o000000?o
ooooo`000?l000001Oooool2o`000004ooooool0003o0000o`0005Cooooo000Looooo`03o`000?oo
oooooooo03Wooooo0_l00009ooooo`;o00001oooool2o`0000cooooo0_l0000Uooooo`;o00001Ooo
ool2o`000003ooooool0003o000001?o000000?oooooo`000?l000005ol0000?ooooo`;o00000_oo
ool2o`0000;ooooo0_l0000Aooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`;o0000
1_ooool2o`0000kooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00002Ooo
ool2o`0001Gooooo0_l0000/ooooo`;o000000?oooooo`000?l000004ol000000ooooooo0000o`00
000>o`000003ooooool0003o000000Co00004Oooool2o`0000Kooooo0_l0000Hooooo`;o00003?oo
ool2o`0000?ooooo0_l00009ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0>?ooool2
o`0000[ooooo0_l0000>ooooo`;o00000_ooool2o`0002Cooooo0_l00003ooooo`;o000000Cooooo
o`000?l0003ooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000?o000000?o
ooooo`000?l000007ol00007ooooo`;o00007?ooool2o`0000Kooooo0_l0000:ooooo`;o00001Ooo
ool4o`0000?ooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00004oooool2
o`0000Gooooo0_l00002ooooo`;o00005Oooool4o`0000_ooooo0_l00003ooooo`;o000000?ooooo
o`000?l000001Oooool2o`0000;ooooo7_l000000ooooooo0000o`000007o`0000Kooooo0_l00009
ooooo`;o00000_ooool2o`0000gooooo0_l00002ooooo`?o000000?oooooo`000?l000002_ooool4
o`0000;ooooo0ol00007ooooo`Co0000A?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Ooo
ool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo03gooooo1Ol0
000;ooooo`;o00008?ooool4o`0000Cooooo0_l00008ooooo`;o000000Coooooo`000?l0003o0000
0_ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000008?l000000ooooooo
0000o`000002o`00017ooooo0_l000001?oooooo0000o`000?l0000Aooooo`Co00001_ooool2o`00
00Kooooo0_l00002ooooo`;o00002?ooool4o`0004Cooooo00001_ooooooMgMgoiRHV?ooooooV9RH
ogMgM`Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0?Oooool5
o`0002;ooooo0_l000000ooooooo0000o`000002o`0000cooooo0_l00007ooooo`?o000000Gooooo
o`000?l0003o0000ooooo`03o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l00000
8ol0000Dooooo`Co00005?ooool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000
o`000002o`0000Cooooo0_l0000=ooooo`;o0000@_ooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02Oooool5o`0000Kooooo00?o0000ooooooooool0?oooool2o`0001gooooo1?l0
0002ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o000000?oooooo`000?l000003_oo
ool2o`0000Kooooo0ol00002ooooo`Co000000?oooooo`000?l000007Ol00002ooooo`?o00003_oo
ool2o`0000Gooooo0_l0000Aooooo`;o00001_ooool2o`0000Cooooo1_l00003ooooo`?o00003Ooo
ool2o`0004;ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CoA4A4
omgMgOoooooo00001oooool3o`0003Oooooo0_l00006ooooo`;o00001oooool4o`0000?ooooo0_l0
000:ooooo`;o000000?oooooo`000?l000000_l00007ooooo`;o00000_ooool2o`000004ooooool0
003o0000o`00013ooooo0_l00003ooooo`Co000000?oooooo`000?l000001?l000000ooooooo0000
o`00000Ko`0000;ooooo1Ol000001?oooooo0000o`000?l00008ooooo`;o00002_ooool2o`0000co
oooo0_l0000<ooooo`Ko000000?oooooo`000?l000000_l000000ooooooo0000o`00001?ooooo`00
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oo
oooo00?o0000ooooooooool0:_ooool2o`0000_ooooo0_l0000?ooooo`Go000000Coooooo`000?l0
003o00002_ooool2o`0000Gooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00001Oooool2
o`00013ooooo0_l000000ooooooo0000o`000002ooooo`;o00000ooooolVo`000003ooooool0003o
000000Go000000?oooooo`000?l000004?ooool2o`0000Cooooo0_l00002ooooo`;o00002?ooool2
o`0000Kooooo0_l00002ooooo`;o000000?oooooo`000?l000000oooool2o`0002Gooooo0_l0000X
ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co0000
00Oooooo00?o0000ooooooooool0:_ooool2o`00013ooooo1?l00005ooooo`;o00001?ooool2o`00
0003ooooool0003o000001;ooooo0_l000001?oooooo0000o`000?l00002ooooo`Go000000?ooooo
o`000?l000005?ooool2o`0000;ooooo0_l00003ooooob7o000000?oooooo`000?l000000_l00002
ooooo`Ko000000?oooooo`000?l000004_ooool2o`0000;ooooo0_l00002ooooo`Co00000_ooool2
o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o00001oooool2o`0000Gooooo0_l0000Q
ooooo`;o0000:?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`00
0007ooooo`03o`000?oooooooooo03Oooooo0ol00002ooooo`Co00001Oooool2o`0000;ooooo0_l0
0002ooooo`;o00004?ooool2o`0000Cooooo0_l00005ooooo`?o000000?oooooo`000?l000003Ooo
ool2o`0000Gooooo0_l00003ooooo`;o00000ooooolNo`0000Gooooo2_l0000;ooooo`;o00002?oo
ool2o`0000Oooooo1ol00005ooooo`;o000000?oooooo`000?l000000_l00007ooooo`Co00000_oo
ool3o`0000Cooooo0ol00002ooooo`;o0000@?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^
3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo03Oooooo0ol0000?ooooo`;o0000
0_ooool2o`0000oooooo0ol00006ooooo`;o00000oooool2o`000003ooooool0003o000000kooooo
0_l00004ooooo`?o00000oooool8o`000003ooooool0003o000001So000000?oooooo`000?l00000
2_l0000=ooooo`;o00002_ooool4o`000003ooooool0003o000000Go00002_ooool3o`0000Sooooo
2?l00005ooooo`?o00000_ooool2o`00043ooooo000Looooo`03o`000?oooooooooo03Oooooo0_l0
0002ooooo`;o00002oooool2o`0001;ooooo1?l00007ooooo`;o00000oooool2o`000004ooooool0
003o0000o`0001?ooooo0_l00006ooooo`Ko000000?oooooo`000?l000001?l00002oooooa;o0000
00?oooooo`000?l000001?l00003ooooo`Co000000?oooooo`000?l000005Oooool4o`000003oooo
ool0003o000000;ooooo0_l00004ooooo`Co000000Coooooo`000?l0003ooooo0_l000000ooooooo
0000o`000007ooooo`Co00000_ooool2o`0000?ooooo0_l00015ooooo`007?ooool00ol0003ooooo
ooooo`0aooooo`;o00000oooool3o`0000;ooooo0_l00002ooooo`;o00001?ooool2o`000003oooo
ool0003o000000cooooo0_l00004ooooo`;o00002_ooool2o`0000Kooooo0_l00007ooooo`;o0000
3Oooool2o`000004ooooool0003o0000ooooo`_o000000Coooooo`000?l0003ooooo4_l00003oooo
o`;o000000Coooooo`000?l0003ooooo1?l000000ooooooo0000o`000002o`0001Sooooo0_l00004
ooooo`;o00000_ooool7o`0000Cooooo0_l00007ooooo`Co000000Coooooo`000?l0003o00001?oo
ool2o`0004Cooooo000Looooo`03o`000?oooooooooo037ooooo0_l00003ooooo`;o00001oooool2
o`0000Cooooo0_l0000?ooooo`;o00004?ooool2o`0000gooooo1?l00002ooooo`;o00000oooool2
o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0
003o0000023o000000Coooooo`000?l0003ooooo0_l00005ooooo`;o00004?ooool2o`0000Gooooo
1?l00003ooooo`;o000000Coooooo`000?l0003ooooo1?l0000@ooooo`Go00001Oooool2o`0004Co
oooo000Looooo`03o`000?oooooooooo033ooooo0_l0000Cooooo`;o00005_ooool2o`0000;ooooo
0_l000000ooooooo0000o`00000Aooooo`;o00001?ooool2o`0000;ooooo1_l000001?oooooo0000
o`000?l00004ooooo`Ko000000?oooooo`000?l000004ol000001?oooooo0000o`000?ooool5o`00
0003ooooool0003o000000;o00001?ooool2o`0000gooooo0_l00003ooooo`;o00001?ooool5o`00
00Kooooo0_l00004ooooo`;o00001Oooool2o`0000Wooooo0_l00006ooooo`;o00003oooool2o`00
03Cooooo000Looooo`03o`000?oooooooooo033ooooo0_l0000:ooooo`;o00003_ooool2o`0000Ko
oooo0_l000000ooooooo0000o`000004ooooo`Ko000000?oooooo`000?l000000_l00006ooooo`;o
00004Oooool5o`0000?ooooo3?l000000ooooooo0000o`000002o`000003ooooool0003o000000?o
000000?oooooo`000?l000003Ol000001Ooooooo0000o`000?l0003ooooo00Co00001?ooool2o`00
00Cooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo1?l00003ooooo`;o00000_ooool2o`00
00Oooooo0ol000000ooooooo0000o`000004ooooo`?o00004?ooool3o`0000oooooo0_l0000=oooo
o`;o00009Oooool001cooooo00?o0000ooooooooool0??ooool2o`0000;ooooo0_l0000:ooooo`;o
00001_ooool5o`0000Kooooo0_l00005ooooo`?o00001Oooool2o`000003ooooool0003o0000017o
oooo0_l00005ooooo`_o00000_ooool8o`0000?ooooo1_l000000ooooooo0000o`000007o`0000;o
oooo1?l00006ooooo`;o00000_ooool2o`0000;ooooo0_l00007ooooo`Co00001_ooool3o`0000Go
oooo1Ol00007ooooo`;o00001?ooool2o`0000_ooooo0ol000001?oooooo0000o`000?l0000Joooo
o`;o00009Oooool001cooooo00?o0000ooooooooool0??ooool2o`0000;ooooo0_l0000:ooooo`;o
00000_ooool2o`0000;ooooo1Ol00008ooooo`[o000000?oooooo`000?l000000_l000000ooooooo
0000o`00000=ooooo`;o000000?oooooo`000?l000001Ol00007ooooo`;o000000Coooooo`000?l0
003ooooo1_l00002ooooo`;o00001?ooool>o`0000;ooooo0_l00007ooooo`?o000000?oooooo`00
0?l000000_l00007ooooo`;o00002oooool2o`0000Kooooo1?l000000ooooooo0000o`00000:oooo
o`?o00003oooool3o`00047ooooo000Looooo`03o`000?oooooooooo04cooooo0_l00002ooooo`Co
00000_ooool3o`000003ooooool0003o000000Cooooo4?l00003ooooo`?o00001oooool2o`000003
ooooool0003o000000[o00000oooool2o`0000Gooooo1?l000000ooooooo0000o`000002ooooo`;o
00000oooool3o`000003ooooool0003o000000Wo00002oooool2o`0000;ooooo1?l00002ooooo`;o
00000oooool2o`0001?ooooo1?l000000ooooooo0000o`000006ooooo`;o00000_ooool2o`0000Ko
oooo0_l0000<ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0=_ooool2o`0000Gooooo
0_l0000;ooooo`;o00001_ooool2o`0000Kooooo0_l00003oooooa7o00000oooool3o`0000Oooooo
0_l00003ooooo`;o00001_ooool2o`0000?ooooo0_l00005ooooo`Co000000Coooooo`000?l0003o
oooo2Ol00002ooooo`Go000000?oooooo`000?l000003Oooool2o`0000Cooooo0_l00002ooooo`Co
00001Oooool2o`0000?ooooo0_l00008ooooo`Ko00002Oooool2o`000004ooooool0003o0000o`00
00Kooooo0_l0000<ooooo`?o0000?Oooool001cooooo00?o0000ooooooooool0=_ooool2o`0000Go
oooo0_l00006ooooo`;o00000oooool2o`0000Oooooo0ol00006ooooo`Go000000?oooooo`000?l0
00000_l000000ooooooo0000o`000007o`000003ooooool0003o000000;ooooo0_l00007ooooo`;o
00000_ooool2o`0000;ooooo0_l0000:ooooo`;o00001?ooool2o`000003ooooool0003o000000Oo
000000Coooooo`000?l0003ooooo1Ol00006ooooo`Co00001oooool2o`0000Cooooo0_l00002oooo
o`Co00001Oooool2o`0000?ooooo0_l00008ooooo`Co00003_ooool2o`000003ooooool0003o0000
00Gooooo0_l0000:ooooo`Co0000?Oooool001cooooo00?o0000ooooooooool0AOooool2o`0000Co
oooo0_l000000ooooooo0000o`000003ooooo`?o000000?oooooo`000?l000000oooool:o`000003
ooooool0003o0000013o00001Oooool2o`0000;ooooo0_l00002ooooo`;o00000_ooool2o`0000Co
oooo1?l00007ooooo`Co00001_ooool5o`0000Gooooo0ol000000ooooooo0000o`000002o`0000go
oooo0_l00002ooooo`;o00001Oooool2o`0002Cooooo1?l00003ooooo`;o00002_ooool2o`0003oo
oooo000Looooo`;o0000@oooool2o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l00000
0_ooool3o`0000;ooooo0_l000001?oooooo0000o`000?oooolIo`000003ooooool0003o0000017o
oooo0_l00004ooooo`?o00002?ooool4o`0000Kooooo1?l000000ooooooo0000o`000003ooooo`?o
000000?oooooo`000?l000000_l0000;ooooo`Co00002Oooool2o`0000;ooooo0_l00004ooooo`;o
000000Coooooo`000?l0003o00000oooool2o`0000gooooo0_l00002ooooo`Co00005_ooool2o`00
03Sooooo000Looooo`03o`000?oooooooooo04;ooooo0_l00003ooooo`;o00002Oooool2o`000003
ooooool0003o000001co00000_ooool2o`0000oooooo0_l00002ooooo`;o00001?ooool3o`0000So
oooo1?l000001?oooooo0000o`000?ooool6o`000004ooooool0003o0000o`0000Gooooo0_l00003
ooooo`;o00001oooool5o`0000[ooooo0_l00002ooooo`;o00001?ooool2o`000004ooooool0003o
0000o`0000?ooooo0ol00003ooooo`;o00000oooool2o`0000;ooooo1?l0000Jooooo`;o0000>?oo
ool001cooooo00?o0000ooooooooool0DooooolPo`000003ooooool0003o000000?o00000_ooool2
o`0000Wooooo0_l00009ooooo`;o00001Oooool2o`0000Gooooo0ol000000ooooooo0000o`000004
o`0000;ooooo0_l00005ooooo`Oo000000?oooooo`000?l000001?ooool7o`0001_ooooo0ol00003
ooooo`;o00000_ooool3o`0000?ooooo0ol0000Gooooo`;o0000>oooool001cooooo00?o0000oooo
ooooool0A?ooool2o`0000gooooo2Ol000000ooooooo0000o`00000Jo`0000;ooooo0_l00002oooo
o`?o00000_ooool2o`0001;ooooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool3o`00
00;ooooo1?l00005ooooo`Go00000oooool2o`0000Sooooo0ol00004ooooo`;o00001oooool2o`00
00Wooooo0_l00003ooooo`;o00001_ooool2o`0000Cooooo0_l00008ooooo`;o00001?ooool2o`00
00Kooooo1?l0000Cooooo`;o00009_ooool001cooooo00?o0000ooooooooool0A?ooool2o`0000oo
oooo6ol000000ooooooo0000o`000006o`0000Kooooo0ol00002ooooo`;o00002oooool2o`0000So
oooo0_l00008ooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`000002o`0000ko
oooo0ol00004ooooo`;o00001_ooool3o`0000Cooooo0_l00003ooooo`;o00000oooool2o`0001Ko
oooo0_l00004ooooo`;o00001_ooool2o`0000?ooooo0_l0000@ooooo`;o00009_ooool001cooooo
00?o0000ooooooooool0@oooool3o`000003ooooool0003o000000cooooo3ol000000ooooooo0000
o`00000?o`0000;ooooo0_l0000:ooooo`;o00002Oooool5o`0000cooooo1?l0000;ooooo`;o0000
2oooool2o`0000Cooooo1Ol00002ooooo`;o00002?ooool2o`0000Gooooo0_l000000ooooooo0000
o`000002o`000003ooooool0003o000000Cooooo0ol00008ooooo`;o00001Oooool4o`0000;ooooo
0_l0000=ooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0=oooool2o`0000[ooooo0_l0
0002ooooo`;o00001oooool2o`0000?ooooo0_l00002ooooo`go000000?oooooo`000?l000003Ol0
0002ooooo`Co00001_ooool4o`0000Wooooo1Ol00004ooooo`;o00000_ooool2o`0000;ooooo1?l0
0006ooooo`;o00001_ooool2o`0000Cooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo
1Ol000000ooooooo0000o`000003o`000003ooooool0003o000000[ooooo0_l000000ooooooo0000
o`000002o`000003ooooool0003o000000Cooooo0ol00008ooooo`;o00001Oooool5o`000003oooo
ool0003o000000cooooo0_l000000ooooooo0000o`00000fooooo`007?ooool00ol0003ooooooooo
o`0fooooo`?o000000?oooooo`000?l000001?ooool2o`0000kooooo0_l00002ooooo`Co000000?o
ooooo`000?l000008_l00002ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0000?ooooo
0_l00002ooooo`;o00001_ooool2o`0000;ooooo0_l0000<ooooo`;o00001_ooool2o`0000Cooooo
0_l00004ooooo`?o000000Coooooo`000?l0003o00000oooool2o`000004ooooool0003o0000oooo
o`;o00004?ooool3o`0000;ooooo0_l000000ooooooo0000o`00000?ooooo`Ko00003oooool2o`00
0003ooooool0003o000003Kooooo000Looooo`03o`000?oooooooooo03Kooooo0_l00002ooooo`;o
00001?ooool3o`0000gooooo0_l00002ooooo`Co000000?oooooo`000?l000006?l00002ooooo`So
00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`;o00002?ooool2o`0000Co
oooo0_l0000:ooooo`;o00002Oooool2o`0000Kooooo0_l000000ooooooo0000o`000002ooooo`;o
000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l0000?ooooo`?o00000_ooool2o`000004
ooooool0003o0000ooooo`?o00002oooool3o`0000Gooooo0_l0000>ooooo`;o0000=_ooool001co
oooo00?o0000ooooooooool0:oooool2o`0000oooooo0ol00002ooooo`;o00003Oooool2o`0000?o
oooo0_l00002oooooa_o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l00004ooooo`;o
000000?oooooo`000?l000003Oooool2o`0000Cooooo0_l00008ooooo`Co00000oooool2o`0000Co
oooo0_l00003ooooo`Go00000_ooool4o`0000;ooooo0_l00002ooooo`;o00000_ooool4o`0000Go
oooo0_l00005ooooo`Co00002_ooool3o`000003ooooool0003o0000013ooooo0_l00016ooooo`00
7?ooool00ol0003oooooooooo`0[ooooo`;o00003oooool3o`0000Oooooo0_l0000=ooooo`;o0000
0_oooolCo`000003ooooool0003o000000So00000_ooool2o`0000?ooooo0_l0000>ooooo`;o0000
5_ooool2o`0000Gooooo0_l00009ooooo`Go00000_ooool5o`0000Wooooo1?l00005ooooo`;o0000
1Oooool4o`0000?ooooo0_l00004ooooo`;o00000oooool3o`0000Oooooo0ol0000>ooooo`;o0000
?Oooool001cooooo00?o0000ooooooooool0@_ooool2o`0000;ooooo0ol0000Aooooob7o00004ooo
ool2o`0000?ooooo0_l0000Cooooo`;o00001oooool2o`0000Sooooo0_l00003ooooo`Co00001Ooo
ool5o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000005ooooo`Co000000?o
ooooo`000?l000001?ooool2o`0000Cooooo0_l00007ooooo`?o00003Oooool3o`0000Oooooo0_l0
000dooooo`007?ooool00ol0003oooooooooo`0kooooo`;o00001Oooool3o`0000;ooooo0_l00004
ooooo`;o00001Oooool3o`0000;ooooo8_l000000ooooooo0000o`00000?ooooo`;o00001?ooool2
o`0000oooooo0_l00002ooooo`;o00001oooool2o`0000;ooooo0_l00004ooooo`;o00002?ooool2
o`0000;ooooo1Ol000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000000oooool2
o`0000;ooooo1?l0000>ooooo`;o00001oooool2o`0000Cooooo0_l00005ooooo`;o00001oooool3
o`0003Cooooo000Looooo`03o`000?oooooooooo03_ooooo0_l00006ooooo`;o00002?ooool2o`00
00Gooooo8?l000001?oooooo0000o`000?ooool6o`0000?ooooo0_l00005ooooo`;o00000oooool2
o`00013ooooo0_l00003ooooo`;o00003oooool2o`0000Sooooo0_l00002ooooo`Ko00005?ooool2
o`0000Cooooo0_l00005ooooo`;o00001?ooool2o`000003ooooool0003o000000Oooooo0_l00004
ooooo`;o00002oooool5o`0000gooooo0_l0000Vooooo`007?ooool00ol0003oooooooooo`0koooo
o`;o000000?oooooo`000?l000000oooool2o`0001;ooooo7Ol000001?oooooo0000o`000?ooool4
o`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l000005Oooool3o`0000[ooooo0_l0000A
ooooo`;o00000_ooool2o`0000;ooooo1?l0000Cooooo`;o00002Oooool3o`0000Cooooo0_l00006
ooooo`;o00001Oooool2o`0000?ooooo0_l00009ooooo`Co00003_ooool2o`0002Kooooo000Loooo
o`03o`000?oooooooooo03_ooooo0_l000000ooooooo0000o`000002ooooo`?o00002oooool2o`00
0003ooooool0003o000000Gooooo6?l00006ooooo`Co00002Oooool2o`0000kooooo0_l00009oooo
o`;o00002_ooool4o`0000Oooooo0_l00004ooooo`;o00001?ooool2o`0000Cooooo0_l00005oooo
o`;o000000?oooooo`000?l000000_ooool2o`0000Gooooo1?l00006ooooo`Co00000_ooool2o`00
00Cooooo0_l00002ooooo`;o00001Oooool4o`000003ooooool0003o000000;ooooo0ol00004oooo
o`Co0000=_ooool001cooooo0_l00010ooooo`;o000000?oooooo`000?l000000oooool2o`0000Oo
oooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo6Ol00004ooooo`Co00005oooool4o`00
01Oooooo0_l00003ooooo`;o00000_ooool2o`0000Cooooo0ol00002ooooo`?o00002?ooool2o`00
0004ooooool0003o0000ooooo`;o00000_ooool2o`0000Oooooo0_l00006ooooo`;o00001?ooool3
o`0000?ooooo0_l0000;ooooo`;o00001Oooool3o`0000Kooooo0_l0000fooooo`007?ooool00ol0
003oooooooooo`0oooooo`;o00001_ooool2o`0000Oooooo0_l00004ooooo`;o00000_oooolJo`00
00Cooooo0_l0000;ooooo`;o000000?oooooo`000?l000002Oooool2o`000003ooooool0003o0000
00Cooooo0_l0000Eooooo`;o00000_ooool2o`0000Gooooo1ol00008ooooo`;o000000Coooooo`00
0?l0003ooooo0_l00006ooooo`;o00002Oooool4o`000003ooooool0003o000000;ooooo0ol0000H
ooooo`;o00001Oooool2o`0003Kooooo000Looooo`03o`000?oooooooooo02gooooo0_l0000@oooo
o`;o00004Oooool2o`000003ooooool0003o000000?ooooo7Ol0000>ooooo`Go00002?ooool6o`00
00;ooooo1Ol000001?oooooo0000o`000?l0000?ooooo`Oo00001?ooool6o`00013ooooo0ol00005
oooooa;o00000oooool2o`0000Kooooo0_l000000ooooooo0000o`000004ooooo`;o00000oooool2
o`0000;ooooo0_l00005ooooo`;o0000=_ooool001cooooo00?o0000ooooooooool0;Oooool2o`00
013ooooo0_l0000:ooooo`;o000000?oooooo`000?l000000_ooool2o`000004ooooool0003o0000
o`0000?ooooo5ol000000ooooooo0000o`000002o`0000Oooooo0ol00005ooooo`;o00002_ooool4
o`000004ooooool0003o0000ooooo`Go000000Coooooo`000?l0003o00002oooool2o`0000;ooooo
2Ol00002ooooo`?o00005?ooool2o`0000Gooooo5Ol000000ooooooo0000o`000005ooooo`;o0000
00?oooooo`000?l000000oooool3o`0000?ooooo0_l00009ooooo`;o0000=_ooool001cooooo00?o
0000ooooooooool0=_ooool2o`0000gooooo0_l00004ooooo`;o000000?oooooo`000?l000001_oo
ool2o`0000?ooooo1?l000000ooooooo0000o`00000@o`0000Gooooo0_l00005ooooo`?o00002_oo
ool2o`0000[ooooo1_l0000Aooooo`;o00000_ooool2o`000003ooooool0003o000000Go00001_oo
ool2o`0001Oooooo6Ol0000<ooooo`;o00003oooool3o`0003Gooooo000Looooo`03o`000?oooooo
oooo03Kooooo0_l0000=ooooo`;o00001?ooool2o`000003ooooool0003o000000[ooooo0_l00002
oooooaGo00000_ooool4o`0000Kooooo0_l0000:ooooo`;o00000oooool2o`0000?ooooo0_l00002
ooooo`;o00004?ooool2o`000005ooooool0003o0000o`000?ooool00_l000000ooooooo0000o`00
0005o`0000?ooooo0_l000001?oooooo0000o`000?l0000BoooooaOo000000Coooooo`000?l0003o
oooo0_l0000<ooooo`;o00000oooool2o`0000_ooooo0_l0000eooooo`007?ooool00ol0003ooooo
ooooo`10ooooo`;o00003?ooool2o`0000[ooooo0_l00002ooooo`Ko000000?oooooo`000?l00000
3?l00002ooooo`;o00000_ooool3o`0000?ooooo0_l0000?ooooo`;o00000oooool2o`0000_ooooo
0_l00007ooooo`Wo000000?oooooo`000?l000000oooool4o`000003ooooool0003o000000;ooooo
0ol0000@oooooaGo000000?oooooo`000?l000004_ooool2o`0000?ooooo0_l0000:ooooo`;o0000
=_ooool001cooooo00?o0000ooooooooool0@?ooool3o`0001Gooooo1ol000000ooooooo0000o`00
0002o`0000?ooooo2?l00006ooooo`;o00000_ooool3o`0000Gooooo0_l00004ooooo`;o00005ooo
ool4o`0000Cooooo0_l00002ooooo`?o00000_ooool3o`0000Sooooo0_l00003ooooo`;o000000?o
ooooo`000?l000004?oooolEo`000003ooooool0003o000000;o00005Oooool2o`0000[ooooo0_l0
000fooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00001?ooool2o`0000?ooooo0_l0000E
ooooo`Oo00002?ooool2o`0000Cooooo0_l00006ooooo`;o00002_ooool2o`0000Cooooo0_l0000=
ooooo`;o00002?ooool5o`0000?ooooo0_l0000Gooooo`;o00005OoooolCo`000003ooooool0003o
000000;o00001oooool2o`00053ooooo000Looooo`03o`000?oooooooooo03Kooooo0_l00004oooo
o`?o00002oooool2o`0000Oooooo0_l0000Aooooo`?o00009_ooool2o`0000Gooooo0_l00004oooo
o`;o00001?ooool:o`0001Gooooo0_l0000:ooooo`;o00002OoooolFo`0000Wooooo0_l0001@oooo
o`007?ooool00ol0003oooooooooo`0mooooo`;o00000oooool2o`0000Kooooo0_l00007ooooo`Co
00000oooool4o`0000Sooooo0ol00003ooooo`;o00006_ooool2o`0000Gooooo0_l00002ooooo`;o
00001oooool3o`0000?ooooo2ol0000Dooooo`;o00000_ooool2o`0000Gooooo0ol00004ooooo`;o
00000oooool3o`000003ooooool0003o000000oo00002?ooool2o`0001?ooooo0_l0000mooooo`00
7?ooool00ol0003oooooooooo`0booooo`;o00002Oooool2o`0000?ooooo0_l00004ooooo`Co0000
2Oooool4o`000003ooooool0003o000000Co00002Oooool2o`000003ooooool0003o000001[ooooo
0_l00009ooooo`;o00000_ooool2o`0000?ooooo0ol00004ooooo`Oo000000?oooooo`000?l00000
6?ooool2o`0000Gooooo0_l00004ooooo`?o00000ooooolDo`0000Oooooo1?l0000Cooooo`;o0000
4oooool2o`0002Sooooo000Looooo`03o`000?oooooooooo03;ooooo0_l0000@ooooo`;o00000_oo
ool4o`0000_ooooo0_l00003ooooo`Co00002?ooool3o`0002cooooo1?l00008ooooo`;o00000ooo
ool6o`00027ooooo0_l000001Ooooooo0000o`000?l0003ooooo01Oo00001_ooool2o`0002[ooooo
0_l0000Xooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00001?ooool2o`0000;ooooo1?l0
0002ooooo`;o00003?ooool2o`0000Kooooo0_l00002ooooo`;o0000:?ooool2o`0000Gooooo0_l0
000=ooooo`Ko00001Oooool3o`0001Cooooo0_l00003ooooo`;o000000Goooooo`000?l0003o0000
ooooo`0Go`0002;ooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0hooooo`Co00000_oo
ool3o`000003ooooool0003o000000Gooooo0ol00002ooooo`?o00001?ooool2o`0000gooooo0_l0
0008ooooo`;o00008Oooool3o`0000_ooooo0_l00009ooooo`;o00001oooool3o`0000Kooooo0_l0
000<ooooo`;o00002_oooolFo`0001Wooooo0_l00008ooooo`;o0000>?ooool001cooooo00?o0000
ooooooooool0>?ooool6o`000003ooooool0003o000000?o00002oooool2o`0000Cooooo0_l00005
ooooo`;o00003oooool3o`00027ooooo0ol00002ooooo`;o00001oooool2o`0001Cooooo0_l00005
ooooo`;o00001Oooool2o`0000Gooooo0_l0000:oooooaGo00006_ooool2o`0000Wooooo0_l0000g
ooooo`007?ooool2o`0003Wooooo0_l00002ooooo`;o00000_ooool2o`0001Wooooo0ol00004oooo
o`;o00001?ooool2o`0000?ooooo0_l00002ooooo`;o00006_ooool2o`0000?ooooo0_l00002oooo
o`;o00002?ooool2o`0001?ooooo0_l0000<ooooo`;o00004OoooolDo`0001Oooooo0_l0000=oooo
o`;o0000=oooool001cooooo00?o0000ooooooooool0=?ooool2o`0000Kooooo0_l00002ooooo`;o
00002Oooool2o`000003ooooool0003o000000_ooooo0_l00005ooooo`;o00001?ooool2o`0000Oo
oooo0_l0000Jooooo`Oo00001oooool2o`0000?ooooo0_l0000Aooooo`;o00006Oooool2o`0000Ko
oooo5?l00008ooooo`;o00003Oooool2o`0000Gooooo1?l0000mooooo`007?ooool00ol0003ooooo
ooooo`0dooooo`;o00003_ooool4o`0000?ooooo0_l000000ooooooo0000o`00000Sooooo`;o0000
3_ooool2o`0000Sooooo1Ol00002ooooo`;o00000oooool4o`0001Kooooo0_l00007ooooo`;o0000
4?ooool2o`0000Kooooo4Ol00003ooooo`;o00000oooool2o`000003ooooool0003o000000[ooooo
0_l000000ooooooo0000o`000005ooooo`Co00002oooool2o`00033ooooo000Looooo`03o`000?oo
oooooooo03Cooooo0_l0000>ooooo`Co0000:oooool2o`0000kooooo0_l00008ooooo`;o00001Ooo
ool2o`0000?ooooo0_l0000=ooooo`;o00001Oooool2o`0000Sooooo0_l000000ooooooo0000o`00
000Ioooooa7o00000_ooool3o`0000;ooooo0_l0000=ooooo`;o00005oooool2o`00033ooooo000L
ooooo`03o`000?oooooooooo03?ooooo0ol0000aooooo`;o0000<?ooool3o`0000cooooo0_l00004
ooooo`?o00002?ooool3o`0000Oooooo0_l00008ooooo`;o00002?ooool6o`000003ooooool0003o
000000So00000oooool2o`00027ooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`0_oooo
o`;o00000_ooool3o`0000;ooooo0_l00003ooooo`?o00006?ooool2o`0000gooooo0_l0000]oooo
o`;o00000_ooool2o`0000Kooooo0_l0000:ooooo`?o00001Oooool7o`000004ooooool0003o0000
o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`;o00002oooool3o`000003ooooool0003o
000000Oo00007?ooool2o`0000?ooooo0_l00004ooooo`;o0000>Oooool001cooooo00?o0000oooo
ooooool0;oooool2o`0000Oooooo0_l00003ooooo`?o00006?ooool2o`0001gooooo0_l00006oooo
o`;o000000?oooooo`000?l000003Oooool2o`0000?ooooo0_l00004ooooo`;o00001?ooool2o`00
00Kooooo0ol00002ooooo`;o00001?ooool8o`000005ooooool0003o0000o`000?ooool00_l00002
ooooo`;o000000?oooooo`000?l000002_ooool3o`0000Kooooo1_l000000ooooooo0000o`00000E
ooooo`;o00001Oooool2o`0000?ooooo1?l0000mooooo`007?ooool00ol0003oooooooooo`0noooo
o`?o00002_ooool2o`000003ooooool0003o000000Sooooo1?l00002ooooo`;o00005oooool2o`00
00Kooooo0_l000000ooooooo0000o`00000=ooooo`;o00001_ooool2o`000003ooooool0003o0000
00[ooooo1Ol000000ooooooo0000o`000005ooooo`;o00002oooool2o`0000Gooooo0_l000000ooo
oooo0000o`000004ooooo`;o000000Coooooo`000?l0003o00000_ooool4o`000004ooooool0003o
0000o`0001[ooooo0_l0000<ooooo`;o00003_ooool2o`0002gooooo000Looooo`03o`000?oooooo
oooo03[ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00004ooooo`Co000000?ooooo
o`000?l000002?ooool4o`0000;ooooo0_l0000Gooooo`;o00003?ooool2o`0000Oooooo0_l00003
ooooo`;o00001?ooool2o`0000;ooooo1_l00005ooooo`Co00000_ooool2o`0000Gooooo0_l00000
0ooooooo0000o`000003ooooo`;o00000oooool2o`0000Sooooo0_l00004ooooo`Co000000Cooooo
o`000?l0003ooooo1?l000000ooooooo0000o`000008ooooo`;o00002?ooool4o`0000Sooooo0_l0
0008ooooo`;o00002_ooool2o`0000?ooooo0_l0000]ooooo`007?ooool00ol0003oooooooooo`0j
ooooo`;o000000Coooooo`000?l0003o00000_ooool3o`0000Cooooo0_l0000Cooooo`;o00001ooo
ool2o`0000Oooooo0_l0000Aooooo`Co00001?ooool2o`000003ooooool0003o000000;ooooo0ol0
0008ooooo`Ko00001?ooool2o`0000cooooo0_l000001?oooooo0000o`000?ooool4o`0001Gooooo
0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000ol00006ooooo`;o0000
0oooool2o`0000?ooooo1?l00008ooooo`;o00002?ooool4o`0000Sooooo0_l0000booooo`007?oo
ool00ol0003oooooooooo`0jooooo`;o00000_ooool2o`0000;ooooo1?l00005ooooo`;o00002ooo
ool2o`0000gooooo0_l00007ooooo`;o00001oooool2o`0000Gooooo0_l000000ooooooo0000o`00
0005o`000003ooooool0003o000000Gooooo0ol0000Booooo`;o00001?ooool2o`0000Oooooo0_l0
00000ooooooo0000o`000009o`0000?ooooo0_l00009ooooo`;o00000oooool2o`0000Gooooo0_l0
00001?oooooo0000o`000?l00002ooooo`;o00001_ooool4o`0000cooooo0_l00002ooooo`;o0000
1oooool2o`0003cooooo000Looooo`03o`000?oooooooooo04Cooooo0_l00002ooooo`;o000000?o
ooooo`000?l000002oooool2o`0001oooooo0_l000000ooooooo0000o`000002ooooo`?o00000ooo
ool6o`0000Kooooo0ol0000Hooooo`;o00001ooooolCo`0000Wooooo0_l00006ooooo`;o00001_oo
ool2o`0000;ooooo0_l00008ooooo`;o00003?ooool2o`0000;ooooo0_l00015ooooo`007?ooool0
0ol0003oooooooooo`16ooooo`Co00008Oooool2o`0000[ooooo0_l00003ooooo`;o000000?ooooo
o`000?l000000_l00003ooooo`?o000000?oooooo`000?l000001_ooool2o`0000Gooooo0_l00003
ooooo`;o00000_ooool2o`0001Cooooo4_l0000<ooooo`;o00000_ooool2o`000003ooooool0003o
000002cooooo0_l0000looooo`007?ooool00ol0003oooooooooo`0gooooo`;o00003Oooool2o`00
01Sooooo0ol00008ooooo`Co00002?ooool2o`0000Cooooo1ol00002ooooo`?o00000_ooool2o`00
00Cooooo0_l00006ooooo`;o00000oooool2o`0000;ooooo0_l0000CoooooaGo000000?oooooo`00
0?l000000_ooool2o`0000?ooooo0_l00005ooooo`;o00009oooool2o`0000?ooooo0_l0000loooo
o`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0=Oooool4o`0000Wooooo0_l000001?oooooo0000o`00
0?ooool3o`0000kooooo0_l000000ooooooo0000o`000002ooooo`?o00001?ooool2o`0000Cooooo
0_l00009ooooo`co000000?oooooo`000?l000000_l00002ooooo`;o00001?ooool2o`0000_ooooo
0_l0000=ooooo`;o00001_oooolJo`0000;ooooo0_l0000Kooooo`;o00001_ooool2o`0000kooooo
0_l00008ooooo`;o0000=oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Co
oooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo03Gooooo0ol0000:oooo
o`;o000000Coooooo`000?l0003ooooo0ol0000>ooooo`Go00001Oooool3o`000003ooooool0003o
000000?ooooo0_l00008oooooaCo00001oooool2o`0000_ooooo0_l0000=ooooo`;o00001_oooolJ
o`000003ooooool0003o000001Wooooo0_l000000ooooooo0000o`000005ooooo`?o00003_ooool2
o`0000Sooooo0_l0000gooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0fooooo`;o00001Oooool3
o`0000kooooo0_l0000:ooooo`?o00000oooool2o`000004ooooool0003o0000o`0000Kooooo0_l0
0006oooooaWo00002_ooool2o`0000Wooooo0_l0000AoooooaKo000000?oooooo`000?l000001_l0
000Gooooo`;o00002?ooool2o`0005;ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo00Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000?Oooool3o`0000Gooooo0_l0
0007ooooo`Co00001_ooool2o`0000Kooooo0_l00002ooooo`Go00002?ooool2o`000003ooooool0
003o000001Oo00002_ooool2o`0000;ooooo0_l00005ooooo`;o00003?ooool3o`0000;ooooo7?l0
00000ooooooo0000o`00000>ooooo`;o000000?oooooo`000?l000003_ooool2o`0000?ooooo0_l0
001=ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?mEEEGo
0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0gooooo`;o00003?ooool2o`0000Kooooo1Ol0
0006ooooo`;o00002_ooool5o`0000Kooooo1?l00003oooooaKo00001oooool2o`0000?ooooo0_l0
00000ooooooo0000o`00000=ooooo`Go000000Coooooo`000?l0003o00000_oooolEo`000003oooo
ool0003o000000;ooooo0_l0000Aooooo`;o000000?oooooo`000?l000003_ooool2o`0000?ooooo
0_l0000?ooooo`;o0000??ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Ooo
ool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo03Oooooo0_l0000<ooooo`;o00001_oo
ool4o`0000Sooooo0_l000000ooooooo0000o`000003ooooo`;o00003?ooool2o`0000;ooooo6Ol0
0007ooooo`;o00000oooool2o`00013ooooo1Ol00004oooooako00008?ooool2o`0001Cooooo0_l0
0002ooooo`;o0000??ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@
oiRHV008ooooo`03o`000?oooooooooo03;ooooo0_l0000<ooooo`;o00000_ooool2o`0000cooooo
0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0ol00002ooooo`;o00003ooooolJo`0000?o
oooo0_l0000Kooooo`;o00001OoooolNo`00023ooooo0_l0000Dooooo`;o00002_ooool2o`0003Co
oooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool0
0ol0003oooooooooo`0booooo`;o00003?ooool2o`0000;ooooo0_l000000ooooooo0000o`000008
ooooo`Oo00001Oooool2o`0001;ooooo6Ol000000ooooooo0000o`000002ooooo`;o00005_ooool2
o`0000;ooooo1?l00002oooooako00003_ooool2o`0000cooooo0_l0000Vooooo`;o0000=?ooool0
01cooooo00?o0000ooooooooool0Aoooool2o`0000Sooooo1Ol00008ooooo`;o00001?ooool2o`00
00Wooooo7_l00002ooooo`;o00000_ooool2o`0001;ooooo0_l00002ooooo`Co00000_oooolOo`00
00gooooo1?l0000:ooooo`;o00000_ooool2o`0000Kooooo0_l0000>ooooo`;o0000@?ooool001co
oooo00?o0000ooooooooool0FOooool3o`0000;ooooo0_l00004ooooo`Co00001ooooolMo`0000Oo
oooo0_l0000Ooooooaco00000_ooool2o`0000_ooooo0_l0000;ooooo`;o000000?oooooo`000?l0
00001?ooool4o`0000kooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0fooooo`;o0000
3?ooool2o`0000gooooo0_l000001?oooooo0000o`000?ooool7o`0000Kooooo0_l00006ooooo`;o
000000?oooooo`000?l000006ol00008ooooo`;o00003oooool2o`0000Wooooo4?l000000ooooooo
0000o`00000<o`000003ooooool0003o000001Cooooo0_l00002ooooo`;o00001oooool5o`0004oo
oooo000Looooo`03o`000?oooooooooo03Kooooo0_l0000<ooooo`;o00001oooool2o`0000Cooooo
0_l000000ooooooo0000o`000002ooooo`Oo000000?oooooo`000?l000001?ooool2o`0000Cooooo
8?l00002ooooo`;o00000oooool3o`0000oooooo0_l00004ooooo`;o00000oooool>o`0000?ooooo
2_l00002ooooo`?o00001Oooool2o`0000;ooooo0_l0000;ooooo`Oo00001oooool4o`0004oooooo
000Looooo`03o`000?oooooooooo04gooooo0ol0000:ooooo`;o00000oooool2o`000003ooooool0
003o000000?ooooo1Ol00004oooooago00000oooool2o`0000?ooooo0_l0000Fooooob7o00000_oo
ool2o`0000Gooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00002_ooool2o`000004oooo
ool0003o0000ooooo`;o00002_ooool4o`0004Wooooo000Looooo`03o`000?oooooooooo04kooooo
0_l0000Gooooo`;o000000?oooooo`000?l000002OoooolHo`0000Sooooo0_l0000Booooo`;o0000
1?oooolKo`000003ooooool0003o000000?o000000?oooooo`000?l000000oooool2o`0000;ooooo
0_l00002ooooo`;o00002?ooool2o`0000Kooooo0_l0000:ooooo`Co0000BOooool001cooooo00?o
0000ooooooooool0C_ooool2o`0001gooooo0_l00002ooooo`;o000000?oooooo`000?l000005ol0
0008ooooo`;o00001?ooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`000003ooooool0
003o000001[o000000?oooooo`000?l000000oooool2o`00013ooooo0_l0001Oooooo`007?ooool0
0ol0003oooooooooo`1Dooooo`;o00000_ooool2o`0000Oooooo0_l00006ooooo`;o00000_ooool2
o`0000;ooooo0_l000000ooooooo0000o`00000Go`0000;ooooo0_l000000ooooooo0000o`000002
o`0000Gooooo0_l00005ooooo`;o00002?ooool2o`0000?ooooo7_l00003ooooo`;o00005Oooool2
o`0000?ooooo0_l00008ooooo`;o00002oooool2o`0004;ooooo000Looooo`03o`000?oooooooooo
04_ooooo1?l00005ooooo`?o000000?oooooo`000?l000001?ooool2o`000004ooooool0003o0000
o`0000Gooooo0_l00006ooooo`;o000000?oooooo`000?l000004_l00007ooooo`;o000000?ooooo
o`000?l000000_l000000ooooooo0000o`00000Cooooo`;o00000ooooolKo`0000Kooooo0_l0000E
ooooo`;o00000oooool2o`0000Sooooo0_l0000;ooooo`;o0000@_ooool001cooooo00?o0000oooo
ooooool0Boooool4o`0000Gooooo1?l00006ooooo`;o00000_ooool2o`0000gooooo0_l000000ooo
oooo0000o`00000Ao`0000Gooooo0_l00002ooooo`;o00001Oooool2o`0000Kooooo0_l0000Boooo
oaWo00007_ooool2o`0005gooooo000Looooo`03o`000?oooooooooo04Sooooo0ol0000;ooooo`?o
00001_ooool2o`0000;ooooo0_l00002ooooo`;o00000_ooool2o`0000Kooooo0ol000000ooooooo
0000o`00000>o`0000Gooooo0_l00002ooooo`;o00003?ooool3o`0001;ooooo5ol0000Pooooo`;o
0000GOooool001cooooo0_l00019ooooo`?o00003?ooool2o`0000Kooooo0_l00002ooooo`;o0000
0_ooool2o`0000;ooooo0_l00006ooooo`;o000000?oooooo`000?l000003ol00006ooooo`;o0000
3oooool2o`0000Sooooo0_l00002ooooo`;o00001OoooolGo`0001gooooo0_l0000<ooooo`;o0000
D_ooool001cooooo00?o0000ooooooooool0C_ooool4o`0000Wooooo0_l0000<ooooo`?o00002_oo
ool?o`0000Sooooo0_l0000Iooooo`;o00000_ooool2o`0000Cooooo6?l00005ooooo`;o00005Ooo
ool3o`0000cooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`1<ooooo`Ko00002?ooool3
o`0000Oooooo0_l00003ooooo`?o00002_ooool=o`0001Kooooo0_l0000Dooooo`;o000000Cooooo
o`000?l0003o00000oooool@o`0000Oooooo0_l0000Eooooo`Go0000G_ooool001cooooo00?o0000
ooooooooool0=?ooool2o`0001Kooooo0_l0000<ooooo`;o00002?ooool2o`00017ooooo1_l00000
0ooooooo0000o`000003o`0000Wooooo0_l0000;ooooo`;o00005?ooool2o`0000?ooooo0_l00003
ooooo`[o000000?oooooo`000?l000000ol0000Oooooo`?o00001Oooool2o`0001Sooooo0_l0000m
ooooo`007?ooool00ol0003oooooooooo`0dooooo`;o00007?ooool2o`00017ooooo0_l00003oooo
o`;o00001Oooool2o`0000;ooooo1?l00002ooooo`Go00002_ooool4o`0000Oooooo0_l0000Moooo
o`;o00000oooool6o`000005ooooool0003o0000o`000?ooool01Ol0000Pooooo`;o00001Oooool2
o`0001Sooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0dooooo`;o00001?ooool2o`00
013ooooo1?l00002ooooo`;o00002oooool2o`0000Cooooo0_l00003ooooo`Co00000oooool2o`00
00;ooooo0_l00005ooooo`Co00001oooool2o`000003ooooool0003o000000Oooooo1?l0000Foooo
o`;o00003Oooool;o`0000?ooooo0_l00008ooooo`;o00008_ooool3o`0004kooooo000Looooo`03
o`000?oooooooooo03Cooooo0_l00004ooooo`;o00004?ooool4o`0000;ooooo0ol000001?oooooo
0000o`000?ooool2o`0000Cooooo0_l0000;ooooo`;o00004?ooool2o`0000Oooooo0_l0000:oooo
o`;o00006?ooool2o`0000oooooo0_l000000ooooooo0000o`000004o`0000?ooooo0_l00004oooo
o`;o00000_ooool2o`00013ooooo0_l0000@ooooo`?o00001_ooool2o`0004Kooooo000Looooo`03
o`000?oooooooooo04kooooo0_l000000ooooooo0000o`000002o`000004ooooool0003o0000oooo
o`;o00002oooool2o`0000gooooo0_l0000?ooooo`;o00002oooool2o`0000cooooo0_l0000:oooo
o`;o00001_ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000001Oooool2
o`0000?ooooo0_l00004ooooo`Co00002Oooool3o`0000Kooooo0_l0000<ooooo`;o00000oooool3
o`0000Gooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`1=ooooo`Ko00002oooool2o`00
00Kooooo0ol00006ooooo`;o000000Coooooo`000?l0003ooooo1ol0000:ooooo`;o00006Oooool2
o`0000_ooooo0_l00005ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00
0002ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000006ooooo`;o000000?o
ooooo`000?l000001_ooool3o`0001Cooooo0_l00003ooooo`?o0000COooool001cooooo00?o0000
ooooooooool0=_ooool2o`0000Oooooo0_l0000<ooooo`Ko000000?oooooo`000?l000001_ooool4
o`0000;ooooo0_l00003ooooo`;o00001_ooool2o`000004ooooool0003o0000ooooo`Oo00000ooo
ool2o`0000Wooooo1?l00006ooooo`;o00000oooool2o`0001?ooooo0_l00008ooooo`;o00001?oo
ool2o`000003ooooool0003o000000Ko00001oooool2o`000003ooooool0003o000000;o00007?oo
ool2o`0000Cooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00001oooool2
o`0000gooooo0_l00004ooooo`;o00001_ooool2o`0000Cooooo0_l00002ooooo`;o00003oooool2
o`0000;ooooo1ol00006ooooo`So00000oooool3o`0000?ooooo0_l0000Oooooo`;o00001Oooool2
o`000003ooooool0003o000000?o00001?ooool2o`000004ooooool0003o0000ooooo`;o00001_oo
ool2o`0001;ooooo0_l00002ooooo`;o0000E?ooool001cooooo00?o0000ooooooooool0G_ooool3
o`000003ooooool0003o000000;ooooo0_l0000Cooooo`Oo00001_ooool2o`0000Cooooo0_l00003
ooooo`;o00008oooool4o`0000Kooooo0_l000001?oooooo0000o`000?l00005ooooo`;o00000ooo
ool2o`0000Oooooo0_l00007ooooo`;o00002Oooool2o`0005Sooooo000Looooo`03o`000?oooooo
oooo05Sooooo0_l00003ooooo`Co00007oooool2o`0000;ooooo0_l000000ooooooo0000o`00000]
ooooo`Co00001oooool3o`000004ooooool0003o0000o`0000?ooooo0_l00005ooooo`;o00004?oo
ool2o`0001;ooooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o000000?ooooo
o`000?l000001_l00008ooooo`;o00004oooool2o`0000;ooooo0_l000000ooooooo0000o`00000]
ooooo`;o00002Oooool2o`0000?ooooo0_l00003ooooo`;o00000_ooool3o`0000;ooooo0_l0000:
ooooo`;o00005_ooool2o`0004oooooo000Looooo`03o`000?oooooooooo04?ooooo0_l0000Coooo
o`;o000000?oooooo`000?l000000_l000001Ooooooo0000o`000?l0003ooooo00;o00001Oooool3
o`00013ooooo0_l00006ooooo`;o00005Oooool2o`0000;ooooo0_l00005ooooo`;o00004Oooool2
o`0000Kooooo0_l000000ooooooo0000o`000007ooooo`?o00000_ooool2o`0000[ooooo0_l00005
ooooo`;o00003oooool2o`0004oooooo000Looooo`03o`000?oooooooooo04?ooooo0ol0000Boooo
o`;o00000oooool5o`0000;ooooo0_l00002ooooo`;o00000_ooool3o`0000oooooo0_l00006oooo
o`;o00005Oooool2o`0000;ooooo0_l00005ooooo`;o00001_ooool2o`0000?ooooo0_l00004oooo
o`;o00001_ooool2o`0000_ooooo0_l000001?oooooo0000o`000?l0000Aooooo`;o0000H?ooool0
01cooooo0_l00015ooooo`;o00005?ooool2o`0000;ooooo1Ol00005ooooo`;o00000oooool2o`00
00;ooooo0_l0000Eooooo`;o00004Oooool5o`0000[ooooo0_l00004ooooo`;o00000oooool2o`00
00?ooooo0ol0000Fooooo`Co000000?oooooo`000?l000009_ooool2o`0004Oooooo000Looooo`03
o`000?oooooooooo05[ooooo0_l00004ooooo`Go000000?oooooo`000?l000002Oooool2o`0000Go
oooo0_l0000>ooooo`;o00002?ooool2o`0000Oooooo1_l00004ooooo`;o00000oooool2o`0000Ko
oooo1?l00004ooooo`;o00003?ooool2o`000003ooooool0003o000000Oooooo0ol000000ooooooo
0000o`000005ooooo`;o00007oooool2o`0004Oooooo000Looooo`03o`000?oooooooooo057ooooo
0_l0000<ooooo`;o00000_ooool2o`000003ooooool0003o000000Wooooo0_l000000ooooooo0000
o`000002ooooo`;o00006?ooool2o`0000_ooooo0_l00004ooooo`;o00002oooool5o`0000Cooooo
0_l00002ooooo`?o00001_ooool2o`000003ooooool0003o000001;ooooo0_l0000Looooo`;o0000
B_ooool001cooooo00?o0000ooooooooool0A?ooool2o`0000_ooooo0_l00009ooooo`;o000000Co
ooooo`000?l0003ooooo0_l00002ooooo`?o00002?ooool2o`000003ooooool0003o000001oooooo
0_l00002ooooo`;o00001Oooool2o`00013ooooo0_l000000ooooooo0000o`000004ooooo`Oo0000
2Oooool2o`000003ooooool0003o000000Wooooo0_l0000Rooooo`;o0000B_ooool001cooooo00?o
0000ooooooooool0A?ooool2o`0001;ooooo0_l00002ooooo`;o00001?ooool2o`0000?ooooo0_l0
0002ooooo`;o00005_ooool4o`0000kooooo0_l00002ooooo`;o00001Oooool2o`0000_ooooo2?l0
0008ooooo`;o00003?ooool2o`000003ooooool0003o000000Oooooo1?l00004ooooo`;o00004?oo
ool3o`0005Gooooo000Looooo`03o`000?oooooooooo05Sooooo0_l00007ooooo`?o00001?ooool2
o`000003ooooool0003o000000Gooooo0_l0000?ooooo`Ko00004oooool2o`0000oooooo3?l0000H
ooooo`;o00001?ooool3o`0000Gooooo0_l00003ooooo`;o00002oooool3o`0005Gooooo000Loooo
o`03o`000?oooooooooo05Cooooo0_l00003ooooo`;o00001_ooool3o`0000Cooooo1Ol00005oooo
o`;o00003Oooool2o`0000Cooooo0_l0000;ooooo`;o00001_ooool2o`00017ooooo2_l0000<oooo
o`;o00002_ooool2o`00013ooooo0ol0001Sooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o
00000oooool2o`0000Kooooo0_l00006ooooo`Co00001Oooool2o`0000gooooo0_l0000Aooooo`;o
000000?oooooo`000?l000005?ooool=o`0000_ooooo0_l0000Gooooo`;o000000?oooooo`000?l0
00000_l0000:ooooo`;o0000F?ooool001cooooo00?o0000ooooooooool0HOooool2o`0000Gooooo
0ol00002ooooo`;o00006Oooool2o`0000Cooooo0_l00003ooooo`Ko00005?ooool?o`0000;ooooo
1?l00004ooooo`;o00002Oooool2o`0000_ooooo0_l000000ooooooo0000o`00000<ooooo`;o0000
F?ooool001cooooo00?o0000ooooooooool0G?ooool2o`0000Oooooo0_l000001?oooooo0000o`00
0?l00002ooooo`;o00006Oooool2o`0000Cooooo0_l00003ooooo`Go00005Oooool;o`0000;ooooo
0_l000000ooooooo0000o`000003o`0000Cooooo0ol00004ooooo`?o000000Coooooo`000?l0003o
oooo0_l0001cooooo`007?ooool00ol0003oooooooooo`1Looooo`?o00001_ooool2o`0000;ooooo
0ol0000<ooooo`;o00003_ooool2o`0000;ooooo0_l00002ooooo`;o00001?ooool2o`0001Cooooo
1ol00002ooooo`Go00000_ooool3o`000003ooooool0003o000000;ooooo1_l00003ooooo`?o0000
1?ooool2o`0007?ooooo000Looooo`03o`000?oooooooooo05gooooo0_l00006ooooo`Co000000?o
ooooo`000?l000000_l00002ooooo`;o00001_ooool2o`0000Cooooo0_l0000<ooooo`;o00000_oo
ool2o`0001Kooooo0_l00002ooooo`_o000000?oooooo`000?l000000_ooool6o`000004ooooool0
003o0000o`0000;ooooo0_l0000`ooooo`;o0000COooool001cooooo00?o0000ooooooooool0I?oo
ool5o`0000?ooooo0_l00002ooooo`;o00003?ooool2o`0002Cooooo4ol00008ooooo`Ko000000Co
ooooo`000?l0003o0000<Oooool2o`0004gooooo000Looooo`03o`000?oooooooooo06Cooooo1Ol0
0004ooooo`;o00000_ooool3o`0001gooooo0_l0000Aooooo`Go000000?oooooo`000?l000002ol0
000:ooooo`Co000000Coooooo`000?l0003o0000P?ooool001cooooo00?o0000ooooooooool0I?oo
ool5o`0000Cooooo0_l00002ooooo`?o000000?oooooo`000?l000000_l0000Hooooo`;o00005?oo
ool2o`0000;ooooo3?l0000<ooooo`;o0000Q?ooool001cooooo00?o0000ooooooooool0D?ooool2
o`0001;ooooo0_l00005ooooo`;o00002?ooool7o`0000;ooooo0_l0000Eooooo`;o00005?ooool<
o`0000cooooo0_l00024ooooo`007?ooool2o`00057ooooo0_l0000Iooooo`;o00003?ooool3o`00
00;ooooo0_l00004ooooo`?o00001?ooool2o`0000Sooooo0_l00007ooooo`;o00001oooool2o`00
00?ooooo2Ol0000>ooooo`;o00000oooool4o`0007gooooo000Looooo`03o`000?oooooooooo05ko
oooo0_l00008ooooo`;o00006_ooool3o`0000Cooooo0_l000000ooooooo0000o`00000>ooooo`;o
00001oooool2o`0000?ooooo2Ol00006ooooo`;o00002oooool4o`0000cooooo0_l000000ooooooo
0000o`00001/ooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00002Oooool2o`0000Sooooo
0_l0000=ooooo`;o00002_ooool3o`0000Oooooo0ol0000Looooo`Wo00001?ooool4o`0000Sooooo
0_l0000@ooooo`?o000000?oooooo`000?l00000K?ooool001cooooo00?o0000ooooooooool0Dooo
ool2o`0001?ooooo0_l0000:ooooo`Go00001oooool2o`000003ooooool0003o000000;ooooo0ol0
0003ooooo`;o00003_ooool4o`0000gooooo1?l000001?oooooo0000o`000?ooool5o`0000[ooooo
0_l00003ooooo`;o00002oooool2o`00073ooooo000Looooo`03o`000?oooooooooo07Cooooo1?l0
0008ooooo`;o00001Oooool4o`00017ooooo1_l0000<ooooo`;o00001_ooool4o`00013ooooo0_l0
0005ooooo`;o0000M_ooool001cooooo00?o0000ooooooooool0Eoooool2o`00013ooooo0_l00003
ooooo`;o000000?oooooo`000?l000002?ooool2o`0000cooooo0_l0000?ooooo`Co00000_ooool2
o`0000Cooooo0_l0000Gooooo`;o000000?oooooo`000?l000003Oooool2o`0000oooooo0_l0001U
ooooo`007?ooool00ol0003oooooooooo`1Gooooo`;o00004?ooool2o`0000?ooooo0_l000000ooo
oooo0000o`000008ooooo`Co000000?oooooo`000?l000005Oooool2o`000003ooooool0003o0000
00;o00002?ooool2o`0000_ooooo0_l00005ooooo`;o00000oooool2o`000004ooooool0003o0000
ooooo`;o00006oooool2o`0006Gooooo000Looooo`03o`000?oooooooooo06Wooooo0_l0000Boooo
o`So00004_ooool2o`000003ooooool0003o000000;o00002?ooool2o`0000_ooooo0_l00005oooo
o`;o00000oooool2o`0000Cooooo0_l00022ooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o
00002_ooool4o`0000Oooooo0_l00009ooooo`;o000000Coooooo`000?l0003o00001Oooool4o`00
00cooooo0_l0000;ooooo`Co00001Oooool2o`0001?ooooo0ol0000;ooooo`;o0000M?ooool001co
oooo00?o0000ooooooooool0GOooool2o`0000Sooooo0_l00002ooooo`;o00001oooool2o`0000co
oooo0_l00006ooooo`Co00004?ooool2o`0000?ooooo0_l00002ooooo`Co00001Oooool2o`0000So
oooo0_l00009ooooo`?o00002_ooool3o`0007Cooooo000Looooo`03o`000?oooooooooo06Oooooo
0_l0000:ooooo`Co00001Oooool2o`0000Kooooo1?l00002ooooo`Ko00002_ooool2o`000004oooo
ool0003o0000o`0000?ooooo0_l00006ooooo`;o00003Oooool2o`0001Kooooo0_l0001eooooo`00
7?ooool00ol0003oooooooooo`1Qooooo`;o00004?ooool4o`0000Gooooo0_l00006ooooo`Co0000
0_ooool6o`0000?ooooo0_l00005ooooo`;o000000?oooooo`000?l000003?ooool2o`0003Gooooo
0_l0001Uooooo`007?ooool00ol0003oooooooooo`1Qooooo`;o00006Oooool2o`0000Oooooo0_l0
0003ooooo`;o00001oooool2o`0000Sooooo1?l00009ooooo`;o00007?ooool2o`0001Sooooo0_l0
0004ooooo`;o0000Goooool001cooooo00?o0000ooooooooool0KOooool2o`0000Oooooo0ol00003
ooooo`;o000000Coooooo`000?l0003o00002?ooool2o`0000[ooooo0_l00007ooooo`;o00002Ooo
ool2o`0001cooooo0_l0000Dooooo`;o00002?ooool2o`0005oooooo00001_ooooook^k^oc8b<_l0
003o<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003o
ooooooooo`1]ooooo`;o00001oooool3o`0000Kooooo0ol00008ooooo`;o00002_ooool2o`0000Ko
oooo1Ol00007ooooo`;o0000<_ooool2o`0006Wooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMg
M`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1i
ooooo`Co000000?oooooo`000?l000000oooool2o`0001Wooooo0_l000000ooooooo0000o`000007
ooooo`;o00000_ooool2o`0009Wooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo
00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo067ooooo0_l0000F
ooooo`Co000000Coooooo`000?l0003ooooo1?l00002ooooo`;o00003?ooool2o`0000Cooooo0_l0
000Aooooo`;o0000VOooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool0
1Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0001Fooooo`;o00002Oooool2o`0000[ooooo0_l0
00000ooooooo0000o`000008ooooo`;o00001Oooool2o`0000Cooooo0_l0000<ooooo`?o00000ooo
ool2o`0000_ooooo0_l000000ooooooo0000o`00000Yooooo`;o0000LOooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool02Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o
0000ooooooooool0E_ooool2o`0001Gooooo0_l000000ooooooo0000o`000007ooooo`Ko00000_oo
ool2o`0001?ooooo0_l0000@ooooo`;o000000?oooooo`000?l000000_l0000Wooooo`;o0000LOoo
ool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol@413o^[Zjoooooonj
^[[o410@00Kooooo00?o0000ooooooooool0J_ooool2o`0000gooooo1_l00002ooooo`;o00000ooo
ool2o`0000Cooooo0_l0000Oooooo`;o00009?ooool2o`0007Cooooo00001_ooooooMgMgoiRHV?oo
ooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo06[o
oooo0_l0000<ooooo`;o00001oooool2o`0000?ooooo0_l00004ooooo`;o00005Oooool2o`0002ko
oooo0_l0001dooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000
oa0@4?nYZJT01_ooool00ol0003oooooooooo`1hooooo`;o0000:Oooool4o`000:;ooooo000Loooo
o`03o`000?oooooooooo06kooooo0_l0000Aooooo`;o00001_ooool2o`0001Cooooo0_l00004oooo
o`Co0000:Oooool2o`0007Gooooo000Looooo`03o`000?oooooooooo06kooooo0_l0000<ooooo`Oo
00001_ooool2o`0001?ooooo0ol000000ooooooo0000o`000002o`000003ooooool0003o0000023o
oooo0_l00007ooooo`;o0000MOooool001cooooo00?o0000ooooooooool0O?ooool5o`0000Kooooo
0_l000001?oooooo0000o`000?ooool2o`0000oooooo0_l00002ooooo`Co00000oooool2o`0001Go
oooo0_l00007ooooo`Co0000O?ooool001cooooo00?o0000ooooooooool0OOooool2o`0000Sooooo
0_l000001?oooooo0000o`000?ooool2o`0000Sooooo1Ol00006ooooo`;o00001Oooool2o`0001Go
oooo0_l00008ooooo`?o0000O?ooool001cooooo00?o0000ooooooooool0I_ooool2o`0002Kooooo
0_l00007ooooo`Go00004_ooool2o`0009Wooooo000Looooo`03o`000?oooooooooo06Kooooo0_l0
000Rooooo`;o00000_ooool2o`000003ooooool0003o000000Kooooo0_l0000<ooooo`?o00001?oo
ool2o`0000cooooo0_l0002;ooooo`007?ooool00ol0003oooooooooo`2:ooooo`;o00001?ooool3
o`0000Gooooo0ol0000<ooooo`?o00004_ooool2o`0008_ooooo000Looooo`03o`000?oooooooooo
093ooooo0_l00006ooooo`;o00002_ooool2o`000:?ooooo000Looooo`03o`000?oooooooooo0:Co
oooo0_l0002Sooooo`007?ooool00ol0003oooooooooo`2Booooo`;o00004?ooool2o`0000gooooo
0_l0002Dooooo`007?ooool00ol0003oooooooooo`26ooooo`;o00002_ooool2o`0000Sooooo0_l0
000Eooooo`;o0000U?ooool001cooooo0_l00024ooooo`;o000000?oooooo`000?l000001oooool3
o`0000[ooooo0_l0002[ooooo`007?ooool00ol0003oooooooooo`23ooooo`Co00002?ooool3o`00
00cooooo0_l0002Yooooo`007?ooool00ol0003oooooooooo`20ooooo`;o00000oooool2o`0001;o
oooo0_l00002ooooo`?o0000ZOooool001cooooo00?o0000ooooooooool0P?ooool2o`0001Oooooo
0_l00002ooooo`;o00001_ooool2o`0000Kooooo0_l0002Jooooo`007?ooool00ol0003ooooooooo
o`2Uooooo`;o00001_ooool2o`0009[ooooo000Looooo`03o`000?oooooooooo077ooooo0_l0000Z
ooooo`;o0000Z_ooool001cooooo00?o0000ooooooooool0LOooool2o`0001[ooooo0_l0000>oooo
o`;o00002?ooool2o`000:3ooooo000Looooo`03o`000?oooooooooo08gooooo0_l0000Hooooo`;o
0000X?ooool001cooooo00?o0000ooooooooool0T?ooool2o`0000?ooooo0_l0002booooo`007?oo
ool00ol0003oooooooooo`2@ooooo`Co000000?oooooo`000?l00000/_ooool001cooooo00?o0000
ooooooooool0T_ooool2o`0002?ooooo0_l0002@ooooo`007?ooool00ol0003oooooooooo`2goooo
o`;o0000T?ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo07kooooo0_l00039ooooo`007?ooool0
0ol0003oooooooooo`1nooooo`;o0000bOooool001cooooo0_l0003ooooood_ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o
0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Booooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooo
od[ooooo000Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`00
5?ooool00ol0003oooooooooo`05ooooo`?o0000oooooom:ooooo`005?ooool00ol0003ooooooooo
o`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000oooo
ooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Booooo`03oeEE
EOmVIVKo00000?ooooooE?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Go
oooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0Eooooo`05olc<c?lQ8B7o0000
ob4Q8Oo<c<`00oooool01?l@413o0000odA4A?o<c<`6ooooo`;o000000?o410@ooooooooool0S_oo
ool00:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00002Oooool01OlQ8B7oV9RHoooo
oonHV9So8B4Q00Gooooo00?oV9RHoa0@4?oMgMd01_ooool00ol0003oooooooooo`2?ooooo`00Y_oo
ool01Ol0003ooooooooooooooooo000001Sooooo00Go0000ooooooooooooooooo`000006ooooo`03
ohN7QomEEEGooooo00;ooooo1Ol0002@ooooo`00Y_ooool01Ol0003ooooooooooooooooo000000Wo
oooo1_l00009ooooo`05oc8b<_nHV9SooooooiRHV?lb<S800oooool01Oo<c<co8B4Qo`000?mEEEGo
000000?ooooo00CoA4A4omgMgOoooooo0000TOooool00:Kooooo00Go0000ohN7QoooooooZJVYo`00
000Hooooo`05olc<c?l0003o0000o`000?o<c<`00oooool01OlQ8B7oQhN7oooooonHV9So000000?o
oooo00CogMgMoeEEEOoooooo0000TOooool00:Gooooo00?o410@o`000?mgMgL00_l000000onHV9So
ooooooooo`0Fooooo`05oa0@4?nj^[[ooooookZj^_l@41000oooool01Ol0003ooooooooooooooooo
000000Cooooo00?oMgMgolc<c?l00000TOooool00<?ooooo00Go0000okZj^_oooooo^[Zjo`000003
ooooo`05ob4Q8OnHV9SoooooogMgMomEEED01?ooool00oo^k^koA4A4o`00002Aooooo`00`oooool0
1OnYZJWo410@o`000?l@413oZJVY00?ooooo00Goc<c<oa0@4?l0003o<S8bonk^kP05ooooo`03ogMg
Mol0003ooooo093ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(900) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.31794 .47425 Mdot
.32462 .4395 Mdot
.56589 .60684 Mdot
.56332 .36784 Mdot
.40737 .45582 Mdot
.58756 .62781 Mdot
.35858 .61418 Mdot
.40692 .61635 Mdot
.57082 .6328 Mdot
.62509 .37591 Mdot
.39602 .60696 Mdot
.53037 .4531 Mdot
.37267 .59284 Mdot
.5459 .37181 Mdot
.85657 .49798 Mdot
.47037 .35751 Mdot
.34242 .41639 Mdot
.7293 .54805 Mdot
.57052 .43972 Mdot
.61563 .62048 Mdot
.39165 .44633 Mdot
.54412 .36437 Mdot
.32986 .47877 Mdot
.54516 .37191 Mdot
.56728 .39325 Mdot
.33464 .46044 Mdot
.31619 .4094 Mdot
.57243 .40921 Mdot
.5423 .41372 Mdot
.40353 .58988 Mdot
.69866 .49122 Mdot
.81275 .37416 Mdot
.4666 .3961 Mdot
.21289 .37619 Mdot
.39857 .62531 Mdot
.61277 .24485 Mdot
.56886 .66394 Mdot
.37445 .58013 Mdot
.40451 .61738 Mdot
.39866 .63386 Mdot
.38078 .58349 Mdot
.3382 .45391 Mdot
.4196 .57888 Mdot
.38213 .55268 Mdot
.52468 .33574 Mdot
.28912 .60173 Mdot
.71252 .34148 Mdot
.50873 .40736 Mdot
.31326 .43419 Mdot
.61985 .62931 Mdot
.21571 .4343 Mdot
.41869 .60486 Mdot
.52562 .71781 Mdot
.68182 .1637 Mdot
.36234 .58747 Mdot
.54181 .33748 Mdot
.57574 .65209 Mdot
.52323 .36508 Mdot
.53804 .37153 Mdot
.3697 .37933 Mdot
.55531 .42248 Mdot
.68486 .56882 Mdot
.37795 .47177 Mdot
.57793 .68397 Mdot
.58185 .63205 Mdot
.4048 .6094 Mdot
.34402 .41975 Mdot
.36866 .60043 Mdot
.58628 .37444 Mdot
.58287 .67154 Mdot
.50806 .40644 Mdot
.39943 .59717 Mdot
.32595 .48895 Mdot
.49188 .38566 Mdot
.30524 .70281 Mdot
.82027 .59657 Mdot
.69166 .53569 Mdot
.39149 .36615 Mdot
.44884 .33126 Mdot
.72194 .70879 Mdot
.54241 .39871 Mdot
.57424 .83371 Mdot
.84656 .52346 Mdot
.31785 .47179 Mdot
.58744 .33012 Mdot
.53413 .61413 Mdot
.49242 .37085 Mdot
.47973 .50604 Mdot
.56322 .3366 Mdot
.26001 .6558 Mdot
.56699 .63638 Mdot
.34804 .43524 Mdot
.56239 .36838 Mdot
.51658 .4287 Mdot
.35157 .30029 Mdot
.55752 .43521 Mdot
.57588 .38024 Mdot
.29073 .44642 Mdot
.38947 .62067 Mdot
.47481 .43097 Mdot
.3412 .57486 Mdot
.52219 .74623 Mdot
.52182 .34263 Mdot
.55656 .65483 Mdot
.29158 .4544 Mdot
.49723 .35791 Mdot
.35712 .62638 Mdot
.52582 .4156 Mdot
.40731 .56159 Mdot
.32299 .4352 Mdot
.51309 .42795 Mdot
.72495 .56923 Mdot
.37098 .78066 Mdot
.35356 .43723 Mdot
.48483 .75889 Mdot
.52454 .42148 Mdot
.53666 .35636 Mdot
.32731 .44043 Mdot
.60256 .62387 Mdot
.55788 .50954 Mdot
.31311 .42553 Mdot
.39273 .63449 Mdot
.3616 .4165 Mdot
.56196 .31407 Mdot
.57067 .62311 Mdot
.51332 .74338 Mdot
.50758 .73318 Mdot
.65372 .46561 Mdot
.49664 .36396 Mdot
.2451 .50605 Mdot
.59376 .62444 Mdot
.34393 .43905 Mdot
.37246 .60009 Mdot
.51326 .33073 Mdot
.36635 .44678 Mdot
.38434 .60991 Mdot
.69317 .58875 Mdot
.66506 .61691 Mdot
.30791 .4348 Mdot
.43618 .64184 Mdot
.40097 .63912 Mdot
.38989 .63819 Mdot
.20805 .40031 Mdot
.32021 .44324 Mdot
.71474 .55567 Mdot
.37736 .61109 Mdot
.75062 .44638 Mdot
.55504 .34034 Mdot
.62205 .46654 Mdot
.45721 .85243 Mdot
.20656 .44203 Mdot
.4176 .74286 Mdot
.71133 .54174 Mdot
.37755 .64097 Mdot
.55664 .40453 Mdot
.3168 .45172 Mdot
.32557 .45316 Mdot
.58174 .38758 Mdot
.57105 .38519 Mdot
.50106 .40132 Mdot
.52006 .42788 Mdot
.75211 .37602 Mdot
.50359 .41388 Mdot
.66125 .54648 Mdot
.35685 .4463 Mdot
.56447 .40939 Mdot
.60489 .61838 Mdot
.47883 .36677 Mdot
.39107 .58855 Mdot
.53423 .36251 Mdot
.56792 .37184 Mdot
.50423 .42766 Mdot
.35676 .58821 Mdot
.78175 .34906 Mdot
.43469 .83908 Mdot
.6244 .21408 Mdot
.4601 .75152 Mdot
.59165 .64939 Mdot
.51142 .3527 Mdot
.70357 .56335 Mdot
.52248 .24956 Mdot
.53813 .38882 Mdot
.16908 .5767 Mdot
.57112 .37099 Mdot
.28597 .29331 Mdot
.43115 .40706 Mdot
.62238 .206 Mdot
.61294 .5334 Mdot
.5411 .41816 Mdot
.37262 .26615 Mdot
.44477 .20653 Mdot
.41587 .54885 Mdot
.37646 .58381 Mdot
.60202 .61541 Mdot
.5681 .65279 Mdot
.42337 .61104 Mdot
.4544 .40043 Mdot
.47562 .44776 Mdot
.56957 .45609 Mdot
.51597 .73503 Mdot
.33587 .49099 Mdot
.67176 .56926 Mdot
.29893 .46598 Mdot
.67117 .80763 Mdot
.23824 .62192 Mdot
.42979 .58841 Mdot
.66587 .56067 Mdot
.5744 .60435 Mdot
.51631 .7322 Mdot
.70925 .56499 Mdot
.51864 .39599 Mdot
.32367 .42778 Mdot
.30898 .25234 Mdot
.45001 .35785 Mdot
.32264 .22611 Mdot
.3719 .44574 Mdot
.54361 .52123 Mdot
.38704 .60154 Mdot
.60236 .60197 Mdot
.54647 .35518 Mdot
.50454 .38608 Mdot
.38047 .47824 Mdot
.51021 .40554 Mdot
.38644 .48631 Mdot
.56548 .36085 Mdot
.59525 .58885 Mdot
.70424 .53231 Mdot
.42322 .60811 Mdot
.64531 .47091 Mdot
.33343 .48441 Mdot
.57571 .56967 Mdot
.61218 .64507 Mdot
.54325 .25108 Mdot
.40006 .60102 Mdot
.71808 .57681 Mdot
.61122 .64075 Mdot
.67196 .56137 Mdot
.47863 .38497 Mdot
.57143 .66687 Mdot
.69853 .5471 Mdot
.77585 .37734 Mdot
.51377 .33439 Mdot
.7696 .41471 Mdot
.36187 .61776 Mdot
.36531 .41812 Mdot
.55926 .4206 Mdot
.50399 .74689 Mdot
.48421 .42001 Mdot
.37501 .70548 Mdot
.51609 .72007 Mdot
.53431 .71916 Mdot
.7551 .66943 Mdot
.72569 .56157 Mdot
.37453 .74373 Mdot
.22722 .49491 Mdot
.33891 .4172 Mdot
.55456 .34863 Mdot
.68538 .24112 Mdot
.37776 .6104 Mdot
.52276 .39581 Mdot
.55272 .59362 Mdot
.3741 .61124 Mdot
.51784 .36497 Mdot
.35064 .60643 Mdot
.3212 .45047 Mdot
.58649 .7594 Mdot
.35085 .4168 Mdot
.52164 .33296 Mdot
.3566 .62194 Mdot
.59655 .65599 Mdot
.33199 .46331 Mdot
.52494 .41218 Mdot
.53841 .35147 Mdot
.5225 .73705 Mdot
.55392 .41731 Mdot
.69549 .25807 Mdot
.53925 .42674 Mdot
.55373 .6218 Mdot
.55832 .4321 Mdot
.16428 .53132 Mdot
.64448 .6647 Mdot
.34015 .41992 Mdot
.53191 .71909 Mdot
.57388 .63751 Mdot
.69189 .69933 Mdot
.45114 .58519 Mdot
.53523 .40991 Mdot
.53285 .73128 Mdot
.60748 .51681 Mdot
.4049 .58539 Mdot
.57063 .43069 Mdot
.26474 .63658 Mdot
.61288 .62471 Mdot
.51844 .73327 Mdot
.59345 .41871 Mdot
.29118 .45649 Mdot
.56408 .37002 Mdot
.59149 .66326 Mdot
.35876 .4146 Mdot
.49093 .35203 Mdot
.67009 .32524 Mdot
.51266 .72447 Mdot
.36133 .61487 Mdot
.4372 .43053 Mdot
.50304 .40842 Mdot
.5748 .66005 Mdot
.34747 .47873 Mdot
.39289 .62972 Mdot
.34422 .45687 Mdot
.37656 .21694 Mdot
.45299 .76131 Mdot
.72689 .33588 Mdot
.66281 .56638 Mdot
.42762 .69381 Mdot
.5998 .19565 Mdot
.39473 .76862 Mdot
.71103 .43864 Mdot
.46645 .1666 Mdot
.60909 .63234 Mdot
.64947 .59778 Mdot
.57643 .64273 Mdot
.55532 .38863 Mdot
.58416 .62887 Mdot
.62044 .19986 Mdot
.57028 .36606 Mdot
.58582 .65389 Mdot
.63224 .72846 Mdot
.57217 .39627 Mdot
.35601 .438 Mdot
.84937 .49079 Mdot
.2724 .70478 Mdot
.19578 .53209 Mdot
.6008 .64055 Mdot
.40221 .40676 Mdot
.57286 .40582 Mdot
.46972 .38719 Mdot
.31606 .45766 Mdot
.5703 .42641 Mdot
.6728 .57035 Mdot
.66711 .5701 Mdot
.61113 .47911 Mdot
.49894 .82451 Mdot
.47876 .43637 Mdot
.32812 .4631 Mdot
.49492 .28408 Mdot
.30197 .69229 Mdot
.51564 .75481 Mdot
.33776 .59264 Mdot
.79162 .3664 Mdot
.45688 .42208 Mdot
.43045 .64348 Mdot
.28034 .65454 Mdot
.33595 .42818 Mdot
.73879 .31295 Mdot
.36973 .58593 Mdot
.42703 .25603 Mdot
.27792 .34022 Mdot
.51037 .3887 Mdot
.39963 .60834 Mdot
.50571 .45045 Mdot
.23427 .64418 Mdot
.77195 .46733 Mdot
.73165 .73697 Mdot
.52044 .33449 Mdot
.35401 .73147 Mdot
.53657 .35922 Mdot
.57353 .4935 Mdot
.53973 .4271 Mdot
.34412 .46167 Mdot
.60906 .32554 Mdot
.44566 .52385 Mdot
.48639 .84013 Mdot
.2292 .60812 Mdot
.70687 .5417 Mdot
.53973 .35371 Mdot
.50951 .3872 Mdot
.71485 .57399 Mdot
.342 .47285 Mdot
.5293 .42663 Mdot
.66202 .38353 Mdot
.50302 .39696 Mdot
.38302 .58178 Mdot
.6495 .50262 Mdot
.37878 .48901 Mdot
.51302 .43197 Mdot
.33804 .41264 Mdot
.35485 .59374 Mdot
.40694 .60941 Mdot
.57912 .34111 Mdot
.35887 .6338 Mdot
.56411 .3646 Mdot
.75819 .52167 Mdot
.3074 .4604 Mdot
.44638 .35974 Mdot
.35015 .47179 Mdot
.42916 .35631 Mdot
.35377 .62337 Mdot
.50652 .74406 Mdot
.26157 .45853 Mdot
.36889 .58859 Mdot
.19972 .50533 Mdot
.54825 .46609 Mdot
.51124 .44163 Mdot
.22021 .61655 Mdot
.60338 .64227 Mdot
.50946 .73585 Mdot
.36279 .6314 Mdot
.50201 .40677 Mdot
.54851 .44357 Mdot
.37481 .57658 Mdot
.38267 .30055 Mdot
.69777 .68721 Mdot
.576 .39823 Mdot
.34315 .46621 Mdot
.34513 .4414 Mdot
.48839 .36107 Mdot
.53 .40591 Mdot
.56227 .61561 Mdot
.52651 .72131 Mdot
.52835 .74554 Mdot
.50873 .7318 Mdot
.57628 .59128 Mdot
.31664 .56396 Mdot
.39646 .63525 Mdot
.26978 .52906 Mdot
.34433 .68298 Mdot
.47722 .32779 Mdot
.58147 .66173 Mdot
.51146 .3783 Mdot
.55655 .36362 Mdot
.39106 .63053 Mdot
.44431 .7118 Mdot
.5816 .32396 Mdot
.30339 .44853 Mdot
.35474 .62873 Mdot
.49621 .45244 Mdot
.3126 .5283 Mdot
.68348 .55702 Mdot
.19333 .5378 Mdot
.40186 .60151 Mdot
.34334 .42675 Mdot
.35566 .58089 Mdot
.50576 .38993 Mdot
.57369 .35911 Mdot
.33155 .43519 Mdot
.72611 .55366 Mdot
.59417 .39113 Mdot
.51705 .36355 Mdot
.23453 .72248 Mdot
.30839 .70748 Mdot
.35682 .65859 Mdot
.55034 .41159 Mdot
.53499 .44444 Mdot
.69194 .54237 Mdot
.50555 .3957 Mdot
.53931 .34984 Mdot
.37931 .79146 Mdot
.33932 .6538 Mdot
.734 .55264 Mdot
.43428 .25428 Mdot
.37172 .44338 Mdot
.73525 .2908 Mdot
.52886 .74281 Mdot
.41171 .58038 Mdot
.57236 .76006 Mdot
.51879 .7281 Mdot
.38486 .70063 Mdot
.73931 .30422 Mdot
.50896 .73275 Mdot
.53265 .6025 Mdot
.60128 .3361 Mdot
.57885 .38633 Mdot
.53005 .35893 Mdot
.7012 .55913 Mdot
.31951 .44532 Mdot
.58034 .52875 Mdot
.79516 .49412 Mdot
.54217 .36111 Mdot
.38195 .41718 Mdot
.79284 .39289 Mdot
.52283 .73365 Mdot
.68088 .57863 Mdot
.68053 .59319 Mdot
.53323 .35513 Mdot
.4131 .79912 Mdot
.33254 .46067 Mdot
.52536 .41199 Mdot
.49894 .41361 Mdot
.59931 .64464 Mdot
.33311 .42369 Mdot
.608 .65058 Mdot
.51147 .72302 Mdot
.48701 .19363 Mdot
.2033 .68449 Mdot
.38296 .63101 Mdot
.65896 .24936 Mdot
.40872 .59127 Mdot
.75675 .69485 Mdot
.51737 .72513 Mdot
.53943 .39461 Mdot
.33293 .4858 Mdot
.52394 .41557 Mdot
.52316 .3892 Mdot
.51779 .39462 Mdot
.53694 .46406 Mdot
.16839 .56794 Mdot
.69993 .57355 Mdot
.51788 .3107 Mdot
.55317 .629 Mdot
.68043 .25564 Mdot
.82587 .52892 Mdot
.50475 .37732 Mdot
.52897 .3519 Mdot
.36107 .44154 Mdot
.58188 .39483 Mdot
.39434 .57927 Mdot
.34672 .4795 Mdot
.49886 .42313 Mdot
.7282 .30828 Mdot
.52421 .42575 Mdot
.6014 .204 Mdot
.35782 .57872 Mdot
.20041 .51007 Mdot
.52979 .31112 Mdot
.50684 .73753 Mdot
.50936 .73548 Mdot
.53943 .7324 Mdot
.36108 .57185 Mdot
.57997 .65814 Mdot
.79734 .5521 Mdot
.45906 .38488 Mdot
.55948 .40149 Mdot
.54551 .44488 Mdot
.54456 .61323 Mdot
.47724 .50176 Mdot
.39974 .74901 Mdot
.505 .45681 Mdot
.57088 .61504 Mdot
.36849 .41941 Mdot
.49909 .71937 Mdot
.34367 .47964 Mdot
.73374 .54963 Mdot
.39557 .60371 Mdot
.67791 .56334 Mdot
.2051 .46959 Mdot
.32394 .43685 Mdot
.37779 .48272 Mdot
.58971 .65155 Mdot
.5208 .53229 Mdot
.65331 .16299 Mdot
.57478 .67525 Mdot
.6684 .43148 Mdot
.31965 .46316 Mdot
.49664 .41535 Mdot
.62706 .51152 Mdot
.51197 .5289 Mdot
.58596 .64632 Mdot
.54541 .38633 Mdot
.47123 .81445 Mdot
.56444 .61391 Mdot
.57016 .432 Mdot
.59548 .6186 Mdot
.38971 .59017 Mdot
.59586 .62311 Mdot
.35222 .48093 Mdot
.5024 .35366 Mdot
.68114 .17425 Mdot
.59313 .55561 Mdot
.54343 .42397 Mdot
.35417 .6277 Mdot
.64865 .34995 Mdot
.52339 .38083 Mdot
.67232 .57637 Mdot
.57091 .62103 Mdot
.71257 .65704 Mdot
.5692 .41292 Mdot
.59396 .63453 Mdot
.32381 .47839 Mdot
.36891 .56726 Mdot
.76909 .65964 Mdot
.51226 .74789 Mdot
.3125 .45326 Mdot
.51919 .71416 Mdot
.34263 .61164 Mdot
.5448 .44255 Mdot
.49858 .40945 Mdot
.35195 .45553 Mdot
.58205 .7841 Mdot
.56053 .42688 Mdot
.54245 .39837 Mdot
.5808 .60037 Mdot
.54263 .6253 Mdot
.59726 .76902 Mdot
.60875 .63599 Mdot
.57736 .4335 Mdot
.35108 .45579 Mdot
.55885 .37119 Mdot
.35488 .43283 Mdot
.55693 .35183 Mdot
.29752 .40676 Mdot
.31564 .46919 Mdot
.47274 .78749 Mdot
.55315 .37931 Mdot
.4324 .41636 Mdot
.51943 .39126 Mdot
.50641 .40249 Mdot
.55698 .62924 Mdot
.69767 .57985 Mdot
.5214 .32331 Mdot
.63821 .57869 Mdot
.67973 .58203 Mdot
.39778 .21663 Mdot
.60193 .64099 Mdot
.69389 .55659 Mdot
.77265 .40585 Mdot
.53485 .72209 Mdot
.69739 .56757 Mdot
.8307 .51483 Mdot
.3859 .6311 Mdot
.37465 .43604 Mdot
.57191 .39579 Mdot
.44587 .17298 Mdot
.74166 .50073 Mdot
.52875 .73434 Mdot
.5399 .4255 Mdot
.51532 .37814 Mdot
.30049 .4312 Mdot
.63427 .82406 Mdot
.55905 .60944 Mdot
.55916 .38907 Mdot
.3534 .42091 Mdot
.49246 .8619 Mdot
.55452 .6448 Mdot
.69965 .56439 Mdot
.36918 .57779 Mdot
.28539 .43576 Mdot
.51291 .749 Mdot
.40064 .58116 Mdot
.54914 .74948 Mdot
.19617 .49766 Mdot
.52263 .42176 Mdot
.57723 .66394 Mdot
.196 .45859 Mdot
.45897 .40405 Mdot
.38334 .65977 Mdot
.56149 .4769 Mdot
.33941 .42847 Mdot
.37515 .57747 Mdot
.68397 .55137 Mdot
.35065 .47945 Mdot
.33995 .4721 Mdot
.40727 .61944 Mdot
.54411 .68802 Mdot
.53784 .52294 Mdot
.39077 .58518 Mdot
.26894 .66032 Mdot
.33383 .23963 Mdot
.5324 .72455 Mdot
.69027 .58468 Mdot
.24626 .32856 Mdot
.3388 .45439 Mdot
.78954 .36281 Mdot
.1811 .51107 Mdot
.57598 .38093 Mdot
.70456 .55086 Mdot
.31215 .61772 Mdot
.803 .53259 Mdot
.37059 .6125 Mdot
.43497 .5062 Mdot
.69922 .59219 Mdot
.57463 .40864 Mdot
.31281 .39008 Mdot
.54999 .39029 Mdot
.39191 .60363 Mdot
.43301 .36623 Mdot
.34486 .42681 Mdot
.34465 .62066 Mdot
.19178 .5342 Mdot
.55508 .36015 Mdot
.54901 .38472 Mdot
.67424 .4885 Mdot
.32007 .42938 Mdot
.52295 .74915 Mdot
.53146 .41677 Mdot
.52484 .36324 Mdot
.52156 .43907 Mdot
.45161 .43538 Mdot
.38432 .78269 Mdot
.5585 .38713 Mdot
.6121 .60294 Mdot
.47214 .39795 Mdot
.55122 .37765 Mdot
.33463 .41327 Mdot
.19875 .66754 Mdot
.50412 .73963 Mdot
.53148 .36251 Mdot
.52181 .42324 Mdot
.40091 .62573 Mdot
.57772 .52107 Mdot
.50122 .5284 Mdot
.56809 .67004 Mdot
.72898 .42114 Mdot
.5368 .46367 Mdot
.3682 .44739 Mdot
.71546 .58077 Mdot
.48473 .38217 Mdot
.36596 .44084 Mdot
.47441 .36247 Mdot
.56946 .61281 Mdot
.53021 .72317 Mdot
.20953 .54825 Mdot
.69131 .56558 Mdot
.71688 .50437 Mdot
.26839 .54532 Mdot
.60094 .61258 Mdot
.56302 .39998 Mdot
.4103 .58348 Mdot
.57045 .66853 Mdot
.52262 .7388 Mdot
.59619 .36387 Mdot
.32469 .4561 Mdot
.35111 .43683 Mdot
.61833 .48431 Mdot
.63316 .63394 Mdot
.31912 .78339 Mdot
.39101 .59188 Mdot
.47565 .39901 Mdot
.23306 .50107 Mdot
.35206 .43663 Mdot
.62566 .48191 Mdot
.69224 .55716 Mdot
.36902 .61328 Mdot
.52512 .75283 Mdot
.36415 .44232 Mdot
.31393 .43081 Mdot
.50752 .33707 Mdot
.50381 .36852 Mdot
.7033 .4404 Mdot
.61546 .47845 Mdot
.36172 .58466 Mdot
.70622 .58101 Mdot
.60374 .65885 Mdot
.55261 .39497 Mdot
.32059 .47401 Mdot
.30168 .26623 Mdot
.51458 .4226 Mdot
.56091 .61589 Mdot
.33853 .43076 Mdot
.71891 .5706 Mdot
.67488 .57814 Mdot
.5065 .40173 Mdot
.39071 .38117 Mdot
.35794 .59876 Mdot
.35399 .43594 Mdot
.23592 .44222 Mdot
.55726 .42921 Mdot
.50198 .36581 Mdot
.58689 .44156 Mdot
.40761 .59758 Mdot
.20421 .51068 Mdot
.73019 .56135 Mdot
.33129 .4489 Mdot
.534 .423 Mdot
.68541 .56798 Mdot
.21743 .49976 Mdot
.52432 .72593 Mdot
.59364 .61978 Mdot
.67148 .57461 Mdot
.71979 .56041 Mdot
.68813 .58723 Mdot
.80078 .37892 Mdot
.33028 .49095 Mdot
.50518 .28495 Mdot
.54759 .4268 Mdot
.61898 .48652 Mdot
.54507 .32951 Mdot
.36481 .5728 Mdot
.60482 .64251 Mdot
.51942 .38781 Mdot
.50744 .3375 Mdot
.478 .46041 Mdot
.44181 .3946 Mdot
.38985 .43005 Mdot
.32487 .431 Mdot
.46915 .34235 Mdot
.59848 .64837 Mdot
.63441 .83298 Mdot
.64279 .18211 Mdot
.5515 .31553 Mdot
.5552 .52566 Mdot
.32921 .47795 Mdot
.40972 .61855 Mdot
.48535 .5296 Mdot
.34946 .59368 Mdot
.33621 .44539 Mdot
.55407 .39223 Mdot
.27589 .53379 Mdot
.67465 .55351 Mdot
.50032 .4036 Mdot
.38354 .60471 Mdot
.50067 .40266 Mdot
.38695 .57628 Mdot
.29989 .50477 Mdot
.28197 .67098 Mdot
.57166 .37158 Mdot
.54686 .43543 Mdot
.45187 .4497 Mdot
.50655 .37533 Mdot
.62893 .797 Mdot
.33822 .47637 Mdot
.48543 .81847 Mdot
.49247 .34848 Mdot
.41772 .34227 Mdot
.55331 .42695 Mdot
.54306 .78691 Mdot
.49784 .37247 Mdot
.47209 .5533 Mdot
.57785 .39089 Mdot
.52257 .34775 Mdot
.35451 .61711 Mdot
.40143 .62515 Mdot
.30497 .46509 Mdot
.51844 .75091 Mdot
.63611 .22059 Mdot
.5113 .36326 Mdot
.59387 .59201 Mdot
.40433 .65832 Mdot
.71673 .56923 Mdot
.3379 .44724 Mdot
.50123 .87039 Mdot
.3515 .60238 Mdot
.60063 .66943 Mdot
.58598 .79013 Mdot
.61053 .61003 Mdot
.32672 .62475 Mdot
.61242 .42835 Mdot
.72479 .55491 Mdot
.5707 .41591 Mdot
.21899 .37607 Mdot
.31679 .70336 Mdot
.59425 .3699 Mdot
.34535 .61697 Mdot
.51973 .25521 Mdot
.24743 .3303 Mdot
.67128 .58867 Mdot
.69635 .54481 Mdot
.35354 .60631 Mdot
.58739 .5981 Mdot
.5579 .45787 Mdot
.69102 .55686 Mdot
.58869 .60828 Mdot
.54019 .72709 Mdot
.44188 .55336 Mdot
.33354 .45771 Mdot
.19608 .53961 Mdot
.27016 .58411 Mdot
.35888 .58663 Mdot
.61552 .57908 Mdot
.29265 .41632 Mdot
.29574 .4731 Mdot
.50969 .75018 Mdot
.5562 .62989 Mdot
.34196 .48635 Mdot
.58332 .42183 Mdot
.44007 .38285 Mdot
.53827 .36109 Mdot
.70873 .55798 Mdot
.49936 .37849 Mdot
.55918 .62384 Mdot
.37157 .60848 Mdot
.56076 .64564 Mdot
.35618 .61458 Mdot
.3074 .55967 Mdot
.52301 .40696 Mdot
.52164 .3492 Mdot
.73855 .50456 Mdot
.29903 .45474 Mdot
.21887 .43846 Mdot
.58568 .58846 Mdot
.57493 .64832 Mdot
.55088 .35128 Mdot
.33617 .48188 Mdot
.71913 .53038 Mdot
.73948 .50837 Mdot
.49326 .39929 Mdot
.33897 .47669 Mdot
.55889 .39528 Mdot
.76844 .38483 Mdot
.29902 .71548 Mdot
.34712 .45301 Mdot
.51697 .83315 Mdot
.54749 .40749 Mdot
.58168 .30413 Mdot
.55044 .4447 Mdot
.67373 .394 Mdot
.56016 .42841 Mdot
.37212 .4469 Mdot
.53597 .36431 Mdot
.35641 .47457 Mdot
.59287 .6033 Mdot
.40819 .62501 Mdot
.31193 .45757 Mdot
.4926 .40405 Mdot
.79107 .33724 Mdot
.39113 .59898 Mdot
.54183 .35452 Mdot
.3846 .62135 Mdot
.36325 .4268 Mdot
.30886 .43856 Mdot
.81106 .54864 Mdot
.35183 .66132 Mdot
.38731 .589 Mdot
.56317 .38557 Mdot
.24845 .58114 Mdot
.55848 .37719 Mdot
.69434 .44718 Mdot
.51377 .33974 Mdot
.55861 .43076 Mdot
.82089 .6143 Mdot
.41032 .59073 Mdot
.33 .78613 Mdot
.79523 .47835 Mdot
.80705 .39132 Mdot
.28329 .45793 Mdot
.67162 .58895 Mdot
.74772 .32095 Mdot
.51421 .72107 Mdot
.58329 .61875 Mdot
.51823 .38831 Mdot
.32375 .50551 Mdot
.37524 .57928 Mdot
.7014 .57801 Mdot
.57095 .37004 Mdot
.55745 .61987 Mdot
.74704 .65646 Mdot
.37012 .63982 Mdot
.33819 .45315 Mdot
.30154 .44914 Mdot
.47188 .85357 Mdot
.53339 .42385 Mdot
.53279 .3506 Mdot
.39409 .60484 Mdot
.44929 .40253 Mdot
.72087 .57224 Mdot
.62862 .71942 Mdot
.38675 .58931 Mdot
.52217 .5695 Mdot
.31995 .43706 Mdot
.51345 .37859 Mdot
.49567 .50408 Mdot
.4668 .63487 Mdot
.43459 .2293 Mdot
.70374 .56094 Mdot
.69954 .4586 Mdot
.37211 .44631 Mdot
.3755 .6024 Mdot
.67679 .6146 Mdot
.47773 .41118 Mdot
.51839 .37468 Mdot
.69834 .46266 Mdot
.59457 .52167 Mdot
.71331 .52518 Mdot
.58232 .37575 Mdot
.59501 .51787 Mdot
.54507 .34722 Mdot
.51365 .43671 Mdot
.58793 .39223 Mdot
.5001 .36222 Mdot
.33593 .47761 Mdot
.48711 .46105 Mdot
.59348 .62736 Mdot
.35979 .29299 Mdot
.44833 .51091 Mdot
.55966 .41797 Mdot
.5549 .38638 Mdot
.47967 .23002 Mdot
.36355 .67318 Mdot
.32971 .47308 Mdot
.3633 .47986 Mdot
.3649 .63551 Mdot
.43089 .41618 Mdot
.56362 .60087 Mdot
.53508 .47574 Mdot
.56044 .64183 Mdot
.34322 .47661 Mdot
.57203 .6533 Mdot
.3757 .63855 Mdot
.57698 .66422 Mdot
.57923 .59045 Mdot
.38321 .57729 Mdot
.31304 .44193 Mdot
.4938 .3895 Mdot
.35718 .63007 Mdot
.67678 .48631 Mdot
.70734 .55758 Mdot
.81195 .54717 Mdot
.47311 .38744 Mdot
.42396 .48557 Mdot
.67162 .32718 Mdot
.56255 .64588 Mdot
.32206 .74696 Mdot
.31439 .46795 Mdot
.6883 .5401 Mdot
.33996 .47842 Mdot
.17677 .53241 Mdot
.6994 .58137 Mdot
.83224 .51063 Mdot
.56706 .70023 Mdot
.74705 .63619 Mdot
.5783 .36358 Mdot
.28797 .40935 Mdot
.58629 .6682 Mdot
.37355 .5798 Mdot
.55203 .71059 Mdot
.51457 .3473 Mdot
.40523 .77105 Mdot
.29536 .44863 Mdot
.5381 .72878 Mdot
.37005 .59875 Mdot
.34963 .62703 Mdot
.52183 .41913 Mdot
.64557 .73828 Mdot
.50539 .34779 Mdot
.62026 .67115 Mdot
.71828 .43865 Mdot
.54712 .4768 Mdot
.56189 .35824 Mdot
.559 .65581 Mdot
.55964 .39473 Mdot
.54423 .26729 Mdot
.20958 .39543 Mdot
.57703 .44331 Mdot
.46374 .77107 Mdot
.74635 .56108 Mdot
.32805 .43723 Mdot
.52622 .31235 Mdot
.52192 .7439 Mdot
.54867 .41 Mdot
.19974 .32981 Mdot
.69439 .56905 Mdot
.57458 .57765 Mdot
.54299 .43029 Mdot
.52825 .41747 Mdot
.25777 .37688 Mdot
.31148 .50309 Mdot
.52507 .75348 Mdot
.52209 .37146 Mdot
.73966 .43908 Mdot
.39725 .61817 Mdot
.49625 .35478 Mdot
.53174 .35773 Mdot
.43367 .20621 Mdot
.40646 .60101 Mdot
.56398 .64998 Mdot
.52405 .71848 Mdot
.60844 .65398 Mdot
.71789 .58572 Mdot
.49093 .54146 Mdot
.6241 .46941 Mdot
.29873 .71207 Mdot
.68055 .59074 Mdot
.50882 .42376 Mdot
.58185 .32301 Mdot
.53975 .41147 Mdot
.68818 .54709 Mdot
.40431 .59267 Mdot
.32055 .47023 Mdot
.2166 .55448 Mdot
.5175 .73539 Mdot
.56794 .43374 Mdot
.67303 .5638 Mdot
.31875 .45347 Mdot
.58659 .56723 Mdot
.32881 .44343 Mdot
.37635 .58793 Mdot
.34518 .58476 Mdot
.68684 .57829 Mdot
.34537 .47771 Mdot
.62399 .62524 Mdot
.79366 .49899 Mdot
.52716 .33825 Mdot
.35246 .64204 Mdot
.3226 .48011 Mdot
.31392 .41136 Mdot
.29509 .45717 Mdot
.51437 .40642 Mdot
.56469 .52214 Mdot
.5068 .43205 Mdot
.3539 .60021 Mdot
.58855 .61348 Mdot
.62057 .46124 Mdot
.24042 .38809 Mdot
.56308 .55706 Mdot
.55647 .33203 Mdot
.54949 .36053 Mdot
.53353 .35521 Mdot
.53896 .33341 Mdot
.65063 .61821 Mdot
.52753 .40618 Mdot
.35539 .61715 Mdot
.56228 .63014 Mdot
.55174 .42406 Mdot
.52558 .74336 Mdot
.53073 .51864 Mdot
.70725 .58663 Mdot
.46864 .53228 Mdot
.737 .28296 Mdot
.31756 .45474 Mdot
.60758 .64718 Mdot
.58522 .62062 Mdot
.69409 .58869 Mdot
.37208 .5816 Mdot
.32332 .44475 Mdot
.68171 .38526 Mdot
.69539 .58631 Mdot
.53195 .36396 Mdot
.56307 .7512 Mdot
.49724 .7917 Mdot
.57486 .41257 Mdot
.5301 .38659 Mdot
.53123 .71803 Mdot
.57842 .59684 Mdot
.37387 .18211 Mdot
.63265 .51423 Mdot
.69184 .57971 Mdot
.7151 .54687 Mdot
.297 .46908 Mdot
.57409 .3235 Mdot
.35735 .61057 Mdot
.6566 .50433 Mdot
.6482 .37977 Mdot
.6941 .51033 Mdot
.75325 .69451 Mdot
.50707 .41318 Mdot
.28057 .36841 Mdot
.56055 .36261 Mdot
.29687 .44024 Mdot
.34098 .41883 Mdot
.32704 .46841 Mdot
.35959 .59158 Mdot
.4374 .33976 Mdot
.35876 .62401 Mdot
.69886 .24024 Mdot
.37123 .45956 Mdot
.67911 .63488 Mdot
.57772 .65507 Mdot
.48592 .33516 Mdot
.72269 .56637 Mdot
.32879 .59108 Mdot
.58688 .37726 Mdot
.3985 .78938 Mdot
.58023 .66195 Mdot
.31435 .4364 Mdot
.61525 .41611 Mdot
.55799 .18123 Mdot
.51932 .53693 Mdot
.50629 .29914 Mdot
.25738 .40052 Mdot
.70933 .578 Mdot
.431 .2326 Mdot
.72519 .54808 Mdot
.37976 .61106 Mdot
.50998 .35041 Mdot
.49368 .36764 Mdot
.55793 .35188 Mdot
.52587 .40533 Mdot
.38963 .63226 Mdot
.49253 .33991 Mdot
.1643 .53136 Mdot
.53187 .72144 Mdot
.76533 .37006 Mdot
.68575 .55734 Mdot
.34652 .59356 Mdot
.56182 .63356 Mdot
.52912 .74601 Mdot
.63781 .46823 Mdot
.5771 .39115 Mdot
.52 .38976 Mdot
.50748 .75377 Mdot
.58556 .39663 Mdot
.51699 .46098 Mdot
.59233 .62888 Mdot
.56665 .55373 Mdot
.66896 .57929 Mdot
.67882 .56204 Mdot
.39908 .58914 Mdot
.34356 .47817 Mdot
.69651 .55797 Mdot
.5797 .59973 Mdot
.48252 .34845 Mdot
.48976 .40347 Mdot
.32043 .47922 Mdot
.18053 .51258 Mdot
.67441 .59252 Mdot
.61715 .40741 Mdot
.36872 .45873 Mdot
.32247 .49156 Mdot
.52125 .37481 Mdot
.58375 .44139 Mdot
.31969 .40748 Mdot
.67469 .58273 Mdot
.34552 .59718 Mdot
.74784 .61418 Mdot
.38662 .60767 Mdot
.31994 .4479 Mdot
.48779 .35832 Mdot
.31575 .43967 Mdot
.54759 .41514 Mdot
.87375 .59222 Mdot
.49418 .37073 Mdot
.25719 .68416 Mdot
.67585 .41284 Mdot
.58262 .6223 Mdot
.62365 .62548 Mdot
.53216 .73474 Mdot
.37051 .45534 Mdot
.48347 .38199 Mdot
.71798 .54671 Mdot
.81782 .44082 Mdot
.30799 .40392 Mdot
.57706 .612 Mdot
.57009 .59755 Mdot
.40406 .5855 Mdot
.53794 .42922 Mdot
.51219 .37629 Mdot
.57347 .66358 Mdot
.68852 .33005 Mdot
.365 .45242 Mdot
.53523 .3517 Mdot
.55183 .36707 Mdot
.58679 .62542 Mdot
.79256 .50205 Mdot
.27055 .45994 Mdot
.5095 .35267 Mdot
.70608 .60012 Mdot
.3641 .57202 Mdot
.54738 .3375 Mdot
.49423 .33855 Mdot
.71567 .55183 Mdot
.72303 .31407 Mdot
.21496 .3622 Mdot
.36512 .57459 Mdot
.52238 .74907 Mdot
.50394 .42423 Mdot
.5794 .6542 Mdot
.49189 .40507 Mdot
.61054 .23321 Mdot
.53576 .72568 Mdot
.53581 .40177 Mdot
.56863 .32425 Mdot
.33163 .42016 Mdot
.5293 .40955 Mdot
.47603 .21469 Mdot
.58627 .67253 Mdot
.53288 .4055 Mdot
.37391 .38345 Mdot
.40566 .60739 Mdot
.55146 .31633 Mdot
.6882 .55137 Mdot
.67197 .38715 Mdot
.27303 .55797 Mdot
.53902 .62093 Mdot
.67953 .56355 Mdot
.49258 .39393 Mdot
.59335 .60001 Mdot
.36373 .58122 Mdot
.38894 .76913 Mdot
.57361 .3651 Mdot
.39152 .60242 Mdot
.37092 .60683 Mdot
.68689 .57182 Mdot
.36801 .81179 Mdot
.50111 .32604 Mdot
.504 .37715 Mdot
.48471 .20797 Mdot
.31284 .42412 Mdot
.49744 .38299 Mdot
.51139 .42286 Mdot
.36282 .62242 Mdot
.25877 .45317 Mdot
.49361 .25682 Mdot
.63042 .7288 Mdot
.38369 .5746 Mdot
.54283 .67249 Mdot
.59607 .60151 Mdot
.6878 .55636 Mdot
.33484 .43562 Mdot
.71171 .58694 Mdot
.59998 .63718 Mdot
.5246 .42479 Mdot
.36684 .62021 Mdot
.34392 .25725 Mdot
.41786 .60485 Mdot
.55566 .66853 Mdot
.30274 .42178 Mdot
.23326 .51628 Mdot
.16812 .39799 Mdot
.27879 .5866 Mdot
.41912 .578 Mdot
.71706 .56859 Mdot
.55724 .72968 Mdot
.55084 .36453 Mdot
.41973 .24571 Mdot
.49746 .39612 Mdot
.30701 .38261 Mdot
.6066 .63042 Mdot
.5103 .75183 Mdot
.50832 .35173 Mdot
.71435 .44987 Mdot
.40625 .63347 Mdot
.40268 .58365 Mdot
.52949 .39737 Mdot
.36958 .58799 Mdot
.50781 .3683 Mdot
.55796 .63254 Mdot
.30168 .757 Mdot
.54628 .35755 Mdot
.51933 .44215 Mdot
.39167 .67225 Mdot
.81698 .53847 Mdot
.62084 .61031 Mdot
.275 .36992 Mdot
.52571 .17357 Mdot
.36859 .58921 Mdot
.58952 .34697 Mdot
.58114 .6677 Mdot
.53163 .71791 Mdot
.62547 .63118 Mdot
.50094 .39272 Mdot
.50701 .39683 Mdot
.55173 .35175 Mdot
.54909 .38572 Mdot
.42626 .24249 Mdot
.45153 .42837 Mdot
.31416 .35713 Mdot
.52248 .39017 Mdot
.30399 .39197 Mdot
.36589 .63188 Mdot
.39031 .44639 Mdot
.67304 .59597 Mdot
.50909 .41458 Mdot
.37751 .49403 Mdot
.35544 .57836 Mdot
.69664 .23853 Mdot
.40554 .59027 Mdot
.57383 .63607 Mdot
.41188 .61114 Mdot
.55139 .41764 Mdot
.3459 .44145 Mdot
.57227 .674 Mdot
.36829 .73077 Mdot
.58185 .61777 Mdot
.5432 .42413 Mdot
.74168 .5965 Mdot
.58766 .62067 Mdot
.49998 .51657 Mdot
.34416 .43693 Mdot
.74153 .44813 Mdot
.34345 .41867 Mdot
.53581 .4051 Mdot
.53905 .40211 Mdot
.53965 .71562 Mdot
.40222 .63334 Mdot
.36459 .42609 Mdot
.24312 .73245 Mdot
.73448 .56325 Mdot
.3326 .46738 Mdot
.46214 .38132 Mdot
.58082 .52399 Mdot
.35297 .44682 Mdot
.71268 .39459 Mdot
.36973 .58125 Mdot
.33239 .48936 Mdot
.46573 .39318 Mdot
.44456 .63163 Mdot
.67475 .55098 Mdot
.54996 .63405 Mdot
.48495 .58418 Mdot
.5903 .66703 Mdot
.34812 .58538 Mdot
.5477 .65286 Mdot
.39543 .62161 Mdot
.21941 .45547 Mdot
.44288 .35394 Mdot
.42034 .5959 Mdot
.34258 .59936 Mdot
.59239 .64604 Mdot
.57055 .36423 Mdot
.42109 .51469 Mdot
.58364 .37741 Mdot
.56876 .34959 Mdot
.40041 .61652 Mdot
.36771 .43445 Mdot
.37641 .43698 Mdot
.29496 .401 Mdot
.30077 .44739 Mdot
.55834 .63931 Mdot
.29481 .71418 Mdot
.20661 .46465 Mdot
.39827 .60553 Mdot
.34071 .61775 Mdot
.55769 .37988 Mdot
.5838 .65298 Mdot
.60012 .60947 Mdot
.36061 .61152 Mdot
.37185 .25519 Mdot
.50205 .42942 Mdot
.31284 .41486 Mdot
.36817 .4653 Mdot
.34936 .45503 Mdot
.29664 .46306 Mdot
.46172 .27677 Mdot
.37151 .57997 Mdot
.37118 .45714 Mdot
.53312 .39824 Mdot
.50517 .39512 Mdot
.51056 .73956 Mdot
.68072 .55826 Mdot
.47206 .36764 Mdot
.56661 .44554 Mdot
.52006 .37662 Mdot
.59231 .61949 Mdot
.52414 .30412 Mdot
.53296 .73865 Mdot
.55439 .61557 Mdot
.56115 .60074 Mdot
.50678 .74259 Mdot
.3089 .39513 Mdot
.53269 .16547 Mdot
.55903 .38951 Mdot
.46409 .32793 Mdot
.58035 .65017 Mdot
.34504 .77236 Mdot
.20861 .50857 Mdot
.56089 .35478 Mdot
.45454 .5818 Mdot
.56077 .66535 Mdot
.30685 .43116 Mdot
.49697 .3887 Mdot
.51188 .72775 Mdot
.70928 .58503 Mdot
.4619 .38691 Mdot
.52264 .71824 Mdot
.35112 .47463 Mdot
.65287 .58604 Mdot
.32163 .48918 Mdot
.56138 .66736 Mdot
.56516 .32246 Mdot
.65338 .16057 Mdot
.61106 .64611 Mdot
.81337 .45826 Mdot
.3115 .5063 Mdot
.54048 .35158 Mdot
.60508 .65387 Mdot
.30775 .4273 Mdot
.35633 .57402 Mdot
.59088 .51422 Mdot
.3087 .46151 Mdot
.52049 .75105 Mdot
.51252 .73225 Mdot
.59121 .62655 Mdot
.3286 .42845 Mdot
.4937 .35487 Mdot
.34753 .4246 Mdot
.41188 .60789 Mdot
.56823 .37429 Mdot
.61671 .19959 Mdot
.44673 .37048 Mdot
.37068 .4472 Mdot
.55648 .61848 Mdot
.6889 .54278 Mdot
.57473 .38279 Mdot
.80045 .44759 Mdot
.52385 .42837 Mdot
.39632 .61444 Mdot
.45154 .82045 Mdot
.37152 .23911 Mdot
.55552 .42511 Mdot
.55685 .38078 Mdot
.37813 .57652 Mdot
.57659 .3881 Mdot
.56122 .42504 Mdot
.37959 .66369 Mdot
.33804 .4218 Mdot
.5408 .36427 Mdot
.58743 .60462 Mdot
.22088 .39769 Mdot
.5135 .43301 Mdot
.46851 .74825 Mdot
.7321 .45155 Mdot
.42908 .82456 Mdot
.49102 .38638 Mdot
.64388 .49529 Mdot
.54326 .38641 Mdot
.51042 .40979 Mdot
.56257 .38052 Mdot
.27425 .35946 Mdot
.59409 .64655 Mdot
.56451 .61916 Mdot
.67172 .55412 Mdot
.73292 .44742 Mdot
.70666 .5503 Mdot
.3934 .58127 Mdot
.74269 .68138 Mdot
.53414 .72546 Mdot
.34639 .47801 Mdot
.48985 .36686 Mdot
.57692 .67654 Mdot
.51163 .38108 Mdot
.55208 .41495 Mdot
.55499 .65197 Mdot
.61399 .62445 Mdot
.603 .57982 Mdot
.72726 .55609 Mdot
.31852 .46493 Mdot
.51157 .33501 Mdot
.67968 .58171 Mdot
.48909 .36235 Mdot
.61254 .51947 Mdot
.32269 .46874 Mdot
.34252 .42171 Mdot
.35153 .41543 Mdot
.52443 .42496 Mdot
.55976 .41618 Mdot
.36008 .62531 Mdot
.33663 .48325 Mdot
.399 .59271 Mdot
.57645 .67032 Mdot
.61298 .65345 Mdot
.50116 .3929 Mdot
.61556 .33912 Mdot
.71885 .55093 Mdot
.56896 .63793 Mdot
.50848 .75593 Mdot
.69413 .53897 Mdot
.53563 .42534 Mdot
.55988 .65745 Mdot
.67646 .56464 Mdot
.33537 .28766 Mdot
.49159 .16332 Mdot
.69115 .54318 Mdot
.53149 .39621 Mdot
.25273 .38195 Mdot
.78385 .50822 Mdot
.73496 .55956 Mdot
.38506 .61768 Mdot
.51726 .42528 Mdot
.62764 .28938 Mdot
.6882 .59415 Mdot
.22539 .4272 Mdot
.58054 .62327 Mdot
.4339 .58045 Mdot
.47486 .42376 Mdot
.40229 .25998 Mdot
.72362 .57841 Mdot
.32709 .44704 Mdot
.37852 .42626 Mdot
.53461 .37717 Mdot
.67203 .59757 Mdot
.40241 .58165 Mdot
.57334 .62267 Mdot
.60359 .59845 Mdot
.33199 .42623 Mdot
.2557 .60994 Mdot
.57941 .60649 Mdot
.61991 .37791 Mdot
.58383 .75846 Mdot
.43028 .40396 Mdot
.36607 .39206 Mdot
.33021 .69629 Mdot
.4946 .41543 Mdot
.70096 .54191 Mdot
.34821 .59448 Mdot
.35491 .61096 Mdot
.38263 .58916 Mdot
.62189 .62206 Mdot
.48184 .52988 Mdot
.5868 .66089 Mdot
.38341 .7578 Mdot
.68569 .56735 Mdot
.75381 .43287 Mdot
.48561 .37795 Mdot
.54848 .35983 Mdot
.47353 .39448 Mdot
.51422 .34368 Mdot
.54413 .38084 Mdot
.37325 .58246 Mdot
.61487 .61062 Mdot
.70798 .65992 Mdot
.34561 .46543 Mdot
.53905 .58525 Mdot
.57742 .6552 Mdot
.53212 .71895 Mdot
.70112 .57475 Mdot
.57703 .49444 Mdot
.54046 .63559 Mdot
.57204 .6521 Mdot
.47863 .34958 Mdot
.36185 .43827 Mdot
.55822 .46817 Mdot
.54279 .39723 Mdot
.56602 .63956 Mdot
.56421 .69447 Mdot
.5106 .2336 Mdot
.60346 .41235 Mdot
.68428 .53589 Mdot
.57077 .52381 Mdot
.73119 .55262 Mdot
.52231 .44912 Mdot
.35445 .77956 Mdot
.59928 .63753 Mdot
.58032 .63401 Mdot
.6778 .5576 Mdot
.58964 .31255 Mdot
.33475 .43014 Mdot
.51074 .7525 Mdot
.38167 .62437 Mdot
.53884 .40985 Mdot
.61671 .64332 Mdot
.54614 .28738 Mdot
.671 .71919 Mdot
.38822 .59272 Mdot
.55571 .61436 Mdot
.54104 .42835 Mdot
.53102 .39418 Mdot
.71401 .5743 Mdot
.39738 .47755 Mdot
.4603 .36554 Mdot
.80677 .38943 Mdot
.28234 .66926 Mdot
.2432 .63415 Mdot
.51817 .3746 Mdot
.33011 .42493 Mdot
.51714 .72582 Mdot
.6932 .58504 Mdot
.49084 .34673 Mdot
.50278 .16463 Mdot
.3555 .41075 Mdot
.38009 .60599 Mdot
.51044 .72994 Mdot
.48175 .52772 Mdot
.51966 .42715 Mdot
.4974 .39546 Mdot
.51958 .40595 Mdot
.4409 .15377 Mdot
.57843 .61003 Mdot
.29701 .44851 Mdot
.70629 .56211 Mdot
.29943 .44557 Mdot
.57266 .61734 Mdot
.22558 .5594 Mdot
.56571 .41639 Mdot
.3086 .41753 Mdot
.33047 .44596 Mdot
.40344 .58524 Mdot
.35721 .57239 Mdot
.59292 .57502 Mdot
.49504 .36953 Mdot
.51325 .72601 Mdot
.34047 .41793 Mdot
.60808 .60997 Mdot
.70135 .58102 Mdot
.35561 .62659 Mdot
.52227 .39131 Mdot
.59735 .63015 Mdot
.59414 .38102 Mdot
.35649 .44412 Mdot
.57282 .65215 Mdot
.50279 .74136 Mdot
.70699 .54585 Mdot
.51289 .3937 Mdot
.70557 .52965 Mdot
.50635 .7492 Mdot
.55296 .36632 Mdot
.57857 .47846 Mdot
.73978 .53398 Mdot
.38635 .74131 Mdot
.5972 .65614 Mdot
.51576 .74454 Mdot
.3325 .41731 Mdot
.2415 .46555 Mdot
.57706 .63129 Mdot
.57478 .48826 Mdot
.37735 .51037 Mdot
.51499 .33391 Mdot
.34208 .45478 Mdot
.56516 .72633 Mdot
.77228 .3339 Mdot
.77803 .43912 Mdot
.53876 .35518 Mdot
.60161 .6576 Mdot
.67454 .57066 Mdot
.39869 .60608 Mdot
.46939 .75055 Mdot
.48425 .29653 Mdot
.54632 .64323 Mdot
.56025 .38289 Mdot
.34372 .4194 Mdot
.36132 .60899 Mdot
.28631 .53769 Mdot
.56872 .60412 Mdot
.60752 .63508 Mdot
.55123 .42512 Mdot
.69077 .55958 Mdot
.72832 .35116 Mdot
.55867 .6225 Mdot
.61584 .64364 Mdot
.53147 .76908 Mdot
.67311 .56201 Mdot
.53639 .38739 Mdot
.29347 .40171 Mdot
.54501 .3344 Mdot
.81546 .45631 Mdot
.52888 .74241 Mdot
.34775 .46542 Mdot
.50172 .40152 Mdot
.62028 .74135 Mdot
.56572 .63351 Mdot
.55078 .52626 Mdot
.5739 .68482 Mdot
.36787 .58241 Mdot
.61513 .64639 Mdot
.5018 .38342 Mdot
.40908 .6314 Mdot
.71782 .55066 Mdot
.50652 .35546 Mdot
.56143 .41421 Mdot
.30248 .43386 Mdot
.37968 .61223 Mdot
.27726 .298 Mdot
.34359 .61936 Mdot
.35621 .58011 Mdot
.38184 .44629 Mdot
.53366 .36992 Mdot
.57411 .64006 Mdot
.55045 .65596 Mdot
.49528 .34452 Mdot
.30117 .73576 Mdot
.3356 .4282 Mdot
.58066 .57184 Mdot
.38874 .17875 Mdot
.58983 .44605 Mdot
.50291 .75133 Mdot
.40884 .45571 Mdot
.38947 .57588 Mdot
.5266 .39394 Mdot
.36833 .45366 Mdot
.61971 .63108 Mdot
.58097 .60606 Mdot
.48923 .35797 Mdot
.36629 .6083 Mdot
.69196 .59133 Mdot
.60897 .62909 Mdot
.64708 .7362 Mdot
.5232 .41077 Mdot
.41232 .772 Mdot
.61002 .63823 Mdot
.83046 .43916 Mdot
.69567 .68178 Mdot
.34373 .45715 Mdot
.55526 .41314 Mdot
.3034 .45132 Mdot
.71094 .56169 Mdot
.53271 .63975 Mdot
.36949 .60893 Mdot
.6069 .39185 Mdot
.18654 .40998 Mdot
.59061 .65103 Mdot
.33548 .4773 Mdot
.55366 .42572 Mdot
.60915 .41862 Mdot
.50145 .37606 Mdot
.25553 .44054 Mdot
.64564 .59233 Mdot
.4022 .61382 Mdot
.39376 .61585 Mdot
.55663 .36493 Mdot
.71048 .58094 Mdot
.55271 .64233 Mdot
.57409 .62375 Mdot
.70481 .80431 Mdot
.50186 .74521 Mdot
.69882 .43428 Mdot
.50941 .39612 Mdot
.60017 .60215 Mdot
.23913 .38605 Mdot
.39452 .60439 Mdot
.51119 .34373 Mdot
.59126 .59424 Mdot
.41131 .67486 Mdot
.60637 .52039 Mdot
.54058 .3821 Mdot
.50471 .4537 Mdot
.38422 .62265 Mdot
.71388 .49762 Mdot
.58195 .66284 Mdot
.51433 .34085 Mdot
.34679 .62893 Mdot
.58949 .7687 Mdot
.20022 .44422 Mdot
.31903 .46516 Mdot
.56448 .67978 Mdot
.3734 .58213 Mdot
.45662 .37786 Mdot
.68372 .55869 Mdot
.58527 .67139 Mdot
.58628 .61619 Mdot
.56667 .38811 Mdot
.48236 .34198 Mdot
.59196 .44451 Mdot
.34318 .47327 Mdot
.37478 .63264 Mdot
.50847 .34989 Mdot
.25901 .61598 Mdot
.54845 .34858 Mdot
.36802 .63023 Mdot
.80199 .27367 Mdot
.56361 .34804 Mdot
.50352 .37441 Mdot
.74496 .37332 Mdot
.30689 .45887 Mdot
.30116 .44352 Mdot
.28464 .68312 Mdot
.50972 .39585 Mdot
.72666 .66302 Mdot
.31513 .46134 Mdot
.34019 .42902 Mdot
.66327 .64853 Mdot
.56655 .36609 Mdot
.73239 .50772 Mdot
.35801 .61356 Mdot
.35043 .60764 Mdot
.34449 .42405 Mdot
.45848 .36857 Mdot
.36616 .5779 Mdot
.45292 .24887 Mdot
.58007 .65786 Mdot
.35913 .7837 Mdot
.35926 .44835 Mdot
.41595 .49889 Mdot
.39424 .59905 Mdot
.70333 .24369 Mdot
.46115 .60068 Mdot
.55562 .3538 Mdot
.51681 .39751 Mdot
.71193 .54848 Mdot
.5786 .34525 Mdot
.52821 .74575 Mdot
.3702 .5874 Mdot
.6952 .30792 Mdot
.32763 .46807 Mdot
.49802 .36999 Mdot
.58393 .49243 Mdot
.29552 .55515 Mdot
.46037 .77391 Mdot
.32853 .43787 Mdot
.33641 .45793 Mdot
.59719 .65039 Mdot
.60204 .62349 Mdot
.53818 .37356 Mdot
.35468 .60258 Mdot
.33527 .48476 Mdot
.37993 .62895 Mdot
.60013 .63491 Mdot
.57338 .64768 Mdot
.53637 .72531 Mdot
.58281 .41563 Mdot
.55479 .64224 Mdot
.62932 .75216 Mdot
.2509 .60737 Mdot
.29545 .4712 Mdot
.20446 .3527 Mdot
.28606 .53597 Mdot
.67655 .34635 Mdot
.72959 .55665 Mdot
.54082 .70202 Mdot
.40257 .62695 Mdot
.55694 .37733 Mdot
.51566 .38577 Mdot
.52325 .73332 Mdot
.41486 .61927 Mdot
.70721 .57422 Mdot
.41098 .62586 Mdot
.68265 .56886 Mdot
.62244 .637 Mdot
.51004 .43019 Mdot
.50447 .41833 Mdot
.37574 .58322 Mdot
.56509 .65304 Mdot
.56173 .62684 Mdot
.72724 .54887 Mdot
.60791 .49975 Mdot
.59268 .62648 Mdot
.35879 .44689 Mdot
.43791 .30667 Mdot
.51489 .73097 Mdot
.49705 .38666 Mdot
.6223 .48412 Mdot
.40463 .23836 Mdot
.52359 .33519 Mdot
.50718 .73578 Mdot
.60553 .83699 Mdot
.48884 .37481 Mdot
.53649 .85264 Mdot
.51405 .74461 Mdot
.30631 .45948 Mdot
.60396 .6531 Mdot
.5325 .74191 Mdot
.46905 .41963 Mdot
.73326 .5461 Mdot
.47719 .37152 Mdot
.30798 .45582 Mdot
.34248 .41318 Mdot
.2279 .62622 Mdot
.81501 .46001 Mdot
.72044 .54468 Mdot
.69184 .5769 Mdot
.57857 .63002 Mdot
.80541 .62255 Mdot
.46671 .38726 Mdot
.69597 .57917 Mdot
.68823 .31363 Mdot
.55629 .38811 Mdot
.68783 .45371 Mdot
.45536 .57832 Mdot
.33174 .42503 Mdot
.33507 .3926 Mdot
.57098 .63051 Mdot
.33243 .47642 Mdot
.23293 .59216 Mdot
.47379 .39186 Mdot
.32542 .4696 Mdot
.36776 .62867 Mdot
.3908 .70251 Mdot
.30799 .44206 Mdot
.61853 .50916 Mdot
.35745 .60785 Mdot
.59087 .69956 Mdot
.72409 .3649 Mdot
.15256 .38084 Mdot
.36619 .58801 Mdot
.56497 .66192 Mdot
.55966 .66491 Mdot
.57716 .62482 Mdot
.31069 .46538 Mdot
.59214 .60251 Mdot
.35184 .46885 Mdot
.79024 .52241 Mdot
.6096 .49462 Mdot
.68571 .57825 Mdot
.36166 .66588 Mdot
.33426 .45117 Mdot
.33726 .73942 Mdot
.17382 .3933 Mdot
.52871 .39893 Mdot
.34488 .62376 Mdot
.68029 .55487 Mdot
.85729 .51412 Mdot
.71417 .55038 Mdot
.58321 .66714 Mdot
.36897 .7922 Mdot
.50661 .36607 Mdot
.5519 .24517 Mdot
.71145 .54456 Mdot
.32085 .44083 Mdot
.5517 .36362 Mdot
.62451 .64831 Mdot
.69123 .55539 Mdot
.702 .58838 Mdot
.54629 .37182 Mdot
.31563 .43408 Mdot
.57252 .6439 Mdot
.39461 .63335 Mdot
.73728 .56562 Mdot
.45149 .38826 Mdot
.52792 .33149 Mdot
.48551 .40965 Mdot
.51297 .53089 Mdot
.64187 .28619 Mdot
.36736 .59021 Mdot
.77023 .47244 Mdot
.59882 .62046 Mdot
.59643 .71397 Mdot
.29846 .68211 Mdot
.33457 .64115 Mdot
.52657 .74433 Mdot
.53446 .73416 Mdot
.54211 .37893 Mdot
.64654 .28805 Mdot
.48653 .81294 Mdot
.37701 .67414 Mdot
.51692 .7289 Mdot
.56898 .62378 Mdot
.37605 .42235 Mdot
.20595 .59268 Mdot
.53727 .32991 Mdot
.38968 .574 Mdot
.59514 .62521 Mdot
.60728 .23215 Mdot
.69178 .56407 Mdot
.34395 .76493 Mdot
.55697 .42203 Mdot
.52243 .34936 Mdot
.36965 .59537 Mdot
.3584 .6229 Mdot
.4522 .75661 Mdot
.24877 .64774 Mdot
.66069 .52042 Mdot
.26749 .48944 Mdot
.58707 .23077 Mdot
.39038 .43952 Mdot
.37021 .44393 Mdot
.51139 .72241 Mdot
.34779 .62046 Mdot
.49591 .39722 Mdot
.34223 .48113 Mdot
.45995 .77546 Mdot
.27941 .43372 Mdot
.69814 .4518 Mdot
.7032 .68894 Mdot
.54251 .4203 Mdot
.35842 .43227 Mdot
.32763 .474 Mdot
.31326 .48318 Mdot
.5069 .73959 Mdot
.52078 .37135 Mdot
.57258 .36933 Mdot
.5232 .34538 Mdot
.45242 .41489 Mdot
.52672 .41082 Mdot
.28952 .64911 Mdot
.52684 .56694 Mdot
.70519 .30804 Mdot
.53471 .3369 Mdot
.35059 .60092 Mdot
.47715 .39527 Mdot
.70676 .58363 Mdot
.56076 .37993 Mdot
.69485 .44321 Mdot
.38408 .59866 Mdot
.59558 .32248 Mdot
.26296 .48639 Mdot
.56228 .41865 Mdot
.67704 .58823 Mdot
.65784 .30586 Mdot
.2662 .31288 Mdot
.53256 .59497 Mdot
.35851 .44512 Mdot
.54332 .62541 Mdot
.4113 .60231 Mdot
.57651 .64013 Mdot
.54166 .34184 Mdot
.51095 .72581 Mdot
.30977 .62837 Mdot
.41776 .50123 Mdot
.49901 .40566 Mdot
.52413 .30748 Mdot
.35075 .43444 Mdot
.56118 .65857 Mdot
.36745 .49407 Mdot
.51222 .40523 Mdot
.70511 .55932 Mdot
.68646 .56022 Mdot
.25602 .63835 Mdot
.62345 .2178 Mdot
.2331 .45995 Mdot
.36911 .59385 Mdot
.56326 .61499 Mdot
.71724 .58406 Mdot
.49303 .29761 Mdot
.37961 .57029 Mdot
.39414 .57866 Mdot
.37259 .61433 Mdot
.53881 .41554 Mdot
.52903 .74389 Mdot
.66185 .27837 Mdot
.52383 .74945 Mdot
.56505 .41469 Mdot
.58401 .61242 Mdot
.53879 .72966 Mdot
.70273 .54806 Mdot
.39999 .58964 Mdot
.60226 .63531 Mdot
.53496 .40776 Mdot
.31785 .45754 Mdot
.60172 .50188 Mdot
.66074 .4021 Mdot
.79057 .41449 Mdot
.78777 .39986 Mdot
.36581 .4224 Mdot
.68404 .24262 Mdot
.34887 .63855 Mdot
.37456 .25425 Mdot
.7286 .59986 Mdot
.49555 .34681 Mdot
.24559 .69053 Mdot
.58218 .6637 Mdot
.55678 .65561 Mdot
.53915 .38866 Mdot
.61425 .62006 Mdot
.49901 .37226 Mdot
.60533 .63193 Mdot
.53539 .59361 Mdot
.54096 .32932 Mdot
.55632 .64752 Mdot
.48541 .4303 Mdot
.57378 .38173 Mdot
.33663 .42294 Mdot
.59859 .66328 Mdot
.54533 .34572 Mdot
.83606 .58932 Mdot
.35666 .62522 Mdot
.50754 .73854 Mdot
.62013 .5467 Mdot
.37656 .58071 Mdot
.33655 .46669 Mdot
.57074 .34901 Mdot
.72225 .56029 Mdot
.32492 .44995 Mdot
.58814 .57343 Mdot
.70502 .54408 Mdot
.29589 .71552 Mdot
.35775 .43991 Mdot
.51649 .73195 Mdot
.71794 .54895 Mdot
.53916 .30815 Mdot
.59269 .67075 Mdot
.64461 .38421 Mdot
.5153 .75104 Mdot
.51111 .37684 Mdot
.60829 .59783 Mdot
.35297 .62477 Mdot
.53172 .35614 Mdot
.61198 .64569 Mdot
.50604 .74322 Mdot
.54515 .40972 Mdot
.5524 .37981 Mdot
.19182 .54108 Mdot
.44114 .79424 Mdot
.70978 .57704 Mdot
.31687 .41776 Mdot
.53343 .39869 Mdot
.72761 .55833 Mdot
.67541 .74777 Mdot
.49363 .41563 Mdot
.30522 .46402 Mdot
.51718 .47467 Mdot
.59978 .61799 Mdot
.39893 .59172 Mdot
.56259 .67729 Mdot
.71381 .58192 Mdot
.28718 .77937 Mdot
.53821 .72523 Mdot
.50975 .4467 Mdot
.49092 .36145 Mdot
.55142 .7057 Mdot
.33331 .47527 Mdot
.66163 .51615 Mdot
.51328 .39401 Mdot
.44334 .37862 Mdot
.50906 .35615 Mdot
.70383 .67107 Mdot
.33611 .42923 Mdot
.50515 .37655 Mdot
.62185 .37356 Mdot
.53511 .4377 Mdot
.68557 .59231 Mdot
.75434 .41047 Mdot
.48446 .40253 Mdot
.57142 .11035 Mdot
.50636 .75327 Mdot
.55495 .64476 Mdot
.61848 .66422 Mdot
.75405 .71651 Mdot
.22281 .44896 Mdot
.3489 .47137 Mdot
.4376 .46212 Mdot
.57429 .64197 Mdot
.22762 .41257 Mdot
.71492 .26496 Mdot
.57379 .38625 Mdot
.52462 .42693 Mdot
.58323 .66715 Mdot
.60898 .61035 Mdot
.51849 .72052 Mdot
.54733 .34258 Mdot
.57982 .32413 Mdot
.55923 .613 Mdot
.52862 .41712 Mdot
.54948 .47308 Mdot
.39216 .63318 Mdot
.32519 .42256 Mdot
.3999 .60394 Mdot
.40685 .59227 Mdot
.40512 .28721 Mdot
.28148 .66637 Mdot
.36696 .63045 Mdot
.40288 .6385 Mdot
.68571 .44449 Mdot
.50702 .47992 Mdot
.70544 .58905 Mdot
.71095 .28884 Mdot
.58267 .62731 Mdot
.52219 .37017 Mdot
.37228 .43542 Mdot
.39273 .27059 Mdot
.473 .64472 Mdot
.40946 .8131 Mdot
.50736 .40521 Mdot
.56802 .62918 Mdot
.50756 .74708 Mdot
.53363 .32839 Mdot
.61647 .70031 Mdot
.5306 .3502 Mdot
.57738 .6764 Mdot
.44524 .31402 Mdot
.59847 .46543 Mdot
.55708 .74436 Mdot
.34339 .48994 Mdot
.49309 .36591 Mdot
.35708 .45688 Mdot
.39244 .59388 Mdot
.72005 .57262 Mdot
.71258 .57393 Mdot
.5518 .36927 Mdot
.4655 .31828 Mdot
.4507 .56782 Mdot
.57491 .3886 Mdot
.5672 .38119 Mdot
.51523 .74492 Mdot
.56751 .37933 Mdot
.49345 .35794 Mdot
.51755 .34401 Mdot
.54235 .44145 Mdot
.35471 .58203 Mdot
.59816 .46881 Mdot
.57866 .42744 Mdot
.58018 .44823 Mdot
.37636 .63746 Mdot
.41819 .45843 Mdot
.40691 .59955 Mdot
.6139 .19824 Mdot
.39723 .61535 Mdot
.70199 .57969 Mdot
.58696 .58738 Mdot
.42979 .42712 Mdot
.34024 .48538 Mdot
.35951 .57383 Mdot
.70215 .56875 Mdot
.37709 .58717 Mdot
.58057 .60856 Mdot
.30516 .24354 Mdot
.27922 .43523 Mdot
.64706 .50831 Mdot
.44018 .62545 Mdot
.41859 .7718 Mdot
.58967 .6551 Mdot
.33768 .42609 Mdot
.52245 .23045 Mdot
.53753 .34555 Mdot
.71268 .54706 Mdot
.54308 .37464 Mdot
.35983 .57673 Mdot
.57278 .62706 Mdot
.7909 .45576 Mdot
.71827 .56882 Mdot
.17927 .47837 Mdot
.57699 .62099 Mdot
.57435 .36498 Mdot
.38674 .57358 Mdot
.20022 .35792 Mdot
.40174 .61004 Mdot
.61188 .49263 Mdot
.29307 .44067 Mdot
.29758 .3899 Mdot
.34039 .45187 Mdot
.4766 .77063 Mdot
.45176 .14129 Mdot
.78396 .3627 Mdot
.31514 .45067 Mdot
.5667 .75586 Mdot
.53365 .42375 Mdot
.48108 .40364 Mdot
.6168 .39958 Mdot
.29606 .44634 Mdot
.52995 .40405 Mdot
.51354 .74858 Mdot
.23663 .57243 Mdot
.6231 .71462 Mdot
.54343 .62775 Mdot
.49861 .38059 Mdot
.37569 .63674 Mdot
.4128 .62461 Mdot
.53618 .73664 Mdot
.40823 .60905 Mdot
.56909 .36493 Mdot
.33677 .45105 Mdot
.39735 .51004 Mdot
.71254 .55506 Mdot
.82891 .53442 Mdot
.6783 .59664 Mdot
.60604 .67344 Mdot
.56672 .32293 Mdot
.57298 .64846 Mdot
.43969 .87406 Mdot
.55232 .35368 Mdot
.31472 .46334 Mdot
.54895 .39116 Mdot
.50129 .35604 Mdot
.48097 .40512 Mdot
.57278 .60317 Mdot
.66368 .54464 Mdot
.53052 .41544 Mdot
.37055 .60982 Mdot
.74824 .34289 Mdot
.4738 .38558 Mdot
.52974 .61218 Mdot
.72895 .43341 Mdot
.37623 .75407 Mdot
.31382 .48874 Mdot
.56161 .65682 Mdot
.32901 .46496 Mdot
.36589 .4769 Mdot
.33665 .46684 Mdot
.66391 .2737 Mdot
.5087 .2432 Mdot
.6032 .83325 Mdot
.36104 .38434 Mdot
.3599 .28077 Mdot
.32549 .41218 Mdot
.65554 .77467 Mdot
.36756 .46002 Mdot
.3425 .47127 Mdot
.90158 .50818 Mdot
.36789 .4632 Mdot
.50281 .39032 Mdot
.48951 .33834 Mdot
.28115 .57385 Mdot
.67237 .45789 Mdot
.56234 .37046 Mdot
.53635 .39447 Mdot
.7252 .56318 Mdot
.5514 .268 Mdot
.521 .71741 Mdot
.2908 .71296 Mdot
.31535 .54208 Mdot
.54572 .37383 Mdot
.53516 .4005 Mdot
.48212 .33607 Mdot
.39201 .14478 Mdot
.42274 .26325 Mdot
.34265 .41092 Mdot
.50058 .31158 Mdot
.8302 .47371 Mdot
.57892 .38663 Mdot
.50739 .42191 Mdot
.54741 .41536 Mdot
.57402 .6407 Mdot
.36503 .41311 Mdot
.50085 .31193 Mdot
.34645 .72591 Mdot
.54645 .42514 Mdot
.34546 .65278 Mdot
.72836 .52457 Mdot
.50264 .38396 Mdot
.30003 .47076 Mdot
.55789 .3959 Mdot
.36074 .44241 Mdot
.33748 .42101 Mdot
.48434 .33385 Mdot
.64679 .25309 Mdot
.30135 .46199 Mdot
.56085 .41679 Mdot
.56374 .64838 Mdot
.78122 .34888 Mdot
.50981 .37892 Mdot
.68537 .58416 Mdot
.51473 .39626 Mdot
.67471 .58484 Mdot
.57052 .39078 Mdot
.51895 .75129 Mdot
.39598 .22755 Mdot
.58155 .6333 Mdot
.76435 .53768 Mdot
.59072 .59754 Mdot
.19285 .54411 Mdot
.3088 .46661 Mdot
.50304 .73267 Mdot
.3724 .80879 Mdot
.51372 .74227 Mdot
.58469 .50146 Mdot
.52299 .59603 Mdot
.35448 .59762 Mdot
.30306 .43881 Mdot
.76292 .48363 Mdot
.5445 .74391 Mdot
.63532 .59362 Mdot
.55769 .60345 Mdot
.28525 .76444 Mdot
.31981 .77231 Mdot
.53613 .4114 Mdot
.5723 .24775 Mdot
.32199 .35267 Mdot
.4987 .41889 Mdot
.57999 .36441 Mdot
.59584 .67003 Mdot
.48648 .3758 Mdot
.49582 .51906 Mdot
.59182 .64704 Mdot
.69653 .57203 Mdot
.3498 .465 Mdot
.67375 .57986 Mdot
.62929 .6272 Mdot
.54489 .55914 Mdot
.60114 .62763 Mdot
.53123 .44204 Mdot
.5456 .39328 Mdot
.34992 .42488 Mdot
.35481 .50435 Mdot
.32918 .42135 Mdot
.68538 .54879 Mdot
.59235 .63911 Mdot
.41432 .25827 Mdot
.52985 .38891 Mdot
.33305 .44474 Mdot
.37922 .54882 Mdot
.53032 .39452 Mdot
.38347 .58553 Mdot
.53356 .4267 Mdot
.31258 .45055 Mdot
.56774 .37953 Mdot
.33631 .45292 Mdot
.57275 .6624 Mdot
.57777 .39981 Mdot
.53866 .38568 Mdot
.19879 .37976 Mdot
.70959 .57236 Mdot
.30796 .4652 Mdot
.48214 .56613 Mdot
.57015 .35942 Mdot
.56628 .70547 Mdot
.49168 .38666 Mdot
.4641 .46522 Mdot
.49741 .43869 Mdot
.51136 .74531 Mdot
.59428 .39341 Mdot
.50928 .37828 Mdot
.62835 .37153 Mdot
.36499 .37085 Mdot
.37196 .492 Mdot
.36933 .57449 Mdot
.29784 .46479 Mdot
.61193 .65427 Mdot
.61923 .62173 Mdot
.60776 .61976 Mdot
.65978 .476 Mdot
.48192 .33772 Mdot
.50811 .36663 Mdot
.34683 .58133 Mdot
.68938 .5747 Mdot
.3281 .43978 Mdot
.6867 .57177 Mdot
.2829 .69503 Mdot
.68812 .54773 Mdot
.53155 .74246 Mdot
.69347 .68482 Mdot
.43447 .23552 Mdot
.7255 .56078 Mdot
.32751 .42176 Mdot
.69253 .69823 Mdot
.49943 .34485 Mdot
.58754 .56954 Mdot
.70326 .55872 Mdot
.25481 .74348 Mdot
.49144 .39588 Mdot
.56881 .51719 Mdot
.39542 .62566 Mdot
.68762 .55467 Mdot
.38389 .61083 Mdot
.55895 .36947 Mdot
.39716 .74703 Mdot
.33703 .47807 Mdot
.36249 .6395 Mdot
.58195 .42581 Mdot
.67639 .56718 Mdot
.59166 .62173 Mdot
.42352 .64766 Mdot
.35109 .60004 Mdot
.38788 .2154 Mdot
.77851 .44134 Mdot
.59219 .64141 Mdot
.50154 .8027 Mdot
.37663 .61858 Mdot
.49494 .41515 Mdot
.43631 .41606 Mdot
.56104 .35624 Mdot
.62151 .6188 Mdot
.55961 .65558 Mdot
.2559 .58037 Mdot
.54715 .39543 Mdot
.49122 .39201 Mdot
.30863 .40803 Mdot
.58494 .65392 Mdot
.34884 .44343 Mdot
.3156 .48551 Mdot
.56833 .66405 Mdot
.3449 .45488 Mdot
.70861 .5451 Mdot
.22745 .53935 Mdot
.37614 .61946 Mdot
.37349 .60701 Mdot
.57034 .62375 Mdot
.55297 .62908 Mdot
.57364 .65063 Mdot
.53397 .42668 Mdot
.32991 .43378 Mdot
.55934 .4086 Mdot
.4968 .42039 Mdot
.3227 .49488 Mdot
.3696 .4638 Mdot
.55436 .40509 Mdot
.56322 .72556 Mdot
.74018 .54872 Mdot
.55708 .64226 Mdot
.38126 .62977 Mdot
.23644 .40589 Mdot
.34237 .58239 Mdot
.4969 .38047 Mdot
.43268 .66542 Mdot
.31407 .44517 Mdot
.71182 .549 Mdot
.74166 .53766 Mdot
.71919 .55511 Mdot
.38428 .56568 Mdot
.32389 .48418 Mdot
.29564 .71366 Mdot
.49913 .37545 Mdot
.50882 .53034 Mdot
.76632 .47554 Mdot
.30521 .69551 Mdot
.37005 .63097 Mdot
.53304 .39616 Mdot
.51305 .73899 Mdot
.49515 .22914 Mdot
.52576 .35046 Mdot
.52764 .3409 Mdot
.70996 .63262 Mdot
.58176 .44757 Mdot
.2944 .44809 Mdot
.2311 .6342 Mdot
.48349 .34605 Mdot
.26787 .42636 Mdot
.77023 .73036 Mdot
.49327 .37769 Mdot
.51707 .40829 Mdot
.52047 .38046 Mdot
.55459 .38817 Mdot
.2911 .45278 Mdot
.71258 .49058 Mdot
.38427 .573 Mdot
.52575 .54216 Mdot
.36882 .62004 Mdot
.58 .67462 Mdot
.55503 .51535 Mdot
.31113 .43107 Mdot
.71479 .54924 Mdot
.45246 .20015 Mdot
.2641 .67026 Mdot
.59538 .65217 Mdot
.45076 .27072 Mdot
.71086 .55789 Mdot
.49592 .34499 Mdot
.66724 .56411 Mdot
.60501 .60584 Mdot
.3622 .61071 Mdot
.4953 .33557 Mdot
.3657 .42876 Mdot
.30696 .44355 Mdot
.52897 .40037 Mdot
.81758 .44351 Mdot
.38785 .58623 Mdot
.33522 .57919 Mdot
.53917 .41739 Mdot
.52932 .34082 Mdot
.35199 .44887 Mdot
.56117 .63863 Mdot
.59719 .779 Mdot
.70472 .57256 Mdot
.57906 .41114 Mdot
.55742 .386 Mdot
.27234 .66395 Mdot
.39463 .58266 Mdot
.52553 .72255 Mdot
.54094 .41235 Mdot
.27799 .65598 Mdot
.5426 .41086 Mdot
.57243 .33795 Mdot
.56847 .64715 Mdot
.47666 .41543 Mdot
.51475 .42098 Mdot
.50798 .3036 Mdot
.38102 .61603 Mdot
.32187 .46927 Mdot
.29307 .42124 Mdot
.51132 .72815 Mdot
.3834 .58634 Mdot
.5555 .4016 Mdot
.38899 .58137 Mdot
.48303 .40433 Mdot
.52952 .41324 Mdot
.36937 .63041 Mdot
.34887 .44406 Mdot
.33313 .55899 Mdot
.58824 .48756 Mdot
.55216 .3912 Mdot
.52066 .33116 Mdot
.66876 .47036 Mdot
.46567 .84565 Mdot
.50429 .40234 Mdot
.30982 .44859 Mdot
.53368 .38909 Mdot
.38845 .6042 Mdot
.68542 .55096 Mdot
.31515 .45478 Mdot
.56086 .62379 Mdot
.5775 .66476 Mdot
.25966 .48346 Mdot
.53706 .73291 Mdot
.53491 .33191 Mdot
.41085 .4248 Mdot
.37469 .44283 Mdot
.81879 .63285 Mdot
.55957 .66421 Mdot
.68693 .59358 Mdot
.55415 .37632 Mdot
.44294 .637 Mdot
.35025 .57718 Mdot
.56601 .1069 Mdot
.29942 .7152 Mdot
.66077 .59438 Mdot
.3993 .81233 Mdot
.51784 .735 Mdot
.50297 .41402 Mdot
.71647 .57697 Mdot
.60013 .65287 Mdot
.48168 .37706 Mdot
.51328 .45626 Mdot
.65007 .51996 Mdot
.54201 .66701 Mdot
.39378 .58502 Mdot
.60301 .61745 Mdot
.69165 .53785 Mdot
.53017 .74393 Mdot
.30981 .43561 Mdot
.50905 .37493 Mdot
.48599 .32831 Mdot
.5592 .63098 Mdot
.51885 .75172 Mdot
.54376 .42038 Mdot
.30317 .44762 Mdot
.61322 .6223 Mdot
.54738 .3683 Mdot
.3741 .2595 Mdot
.36025 .4834 Mdot
.59153 .63033 Mdot
.49354 .3593 Mdot
.46701 .46005 Mdot
.5662 .62271 Mdot
.55535 .63553 Mdot
.53046 .4039 Mdot
.71452 .54639 Mdot
.53857 .42921 Mdot
.3958 .61962 Mdot
.66572 .54189 Mdot
.38561 .60435 Mdot
.75745 .57634 Mdot
.57934 .33595 Mdot
.43318 .77417 Mdot
.33627 .41683 Mdot
.70145 .53445 Mdot
.24263 .34942 Mdot
.52737 .33891 Mdot
.66873 .24056 Mdot
.42497 .49853 Mdot
.84613 .51767 Mdot
.45068 .16324 Mdot
.69876 .56089 Mdot
.38199 .58853 Mdot
.51753 .40769 Mdot
.33972 .61497 Mdot
.71226 .57783 Mdot
.77615 .48076 Mdot
.49694 .35459 Mdot
.33894 .4294 Mdot
.54523 .42453 Mdot
.3589 .44555 Mdot
.52806 .39473 Mdot
.58395 .44332 Mdot
.65541 .59834 Mdot
.61535 .49186 Mdot
.49863 .34436 Mdot
.30329 .24324 Mdot
.47167 .60255 Mdot
.7081 .5629 Mdot
.56047 .41288 Mdot
.52903 .73312 Mdot
.41692 .61408 Mdot
.63702 .30177 Mdot
.57387 .64445 Mdot
.37131 .63368 Mdot
.34759 .45931 Mdot
.55178 .65619 Mdot
.50506 .74699 Mdot
.46492 .34751 Mdot
.68048 .58873 Mdot
.35723 .59266 Mdot
.50625 .38065 Mdot
.49221 .39626 Mdot
.58541 .75067 Mdot
.46972 .69219 Mdot
.34833 .4065 Mdot
.1841 .44056 Mdot
.29212 .46478 Mdot
.69937 .5779 Mdot
.5698 .64843 Mdot
.50163 .39937 Mdot
.53684 .35624 Mdot
.62231 .62701 Mdot
.31009 .46654 Mdot
.55328 .67773 Mdot
.42507 .28096 Mdot
.54832 .63064 Mdot
.72447 .46797 Mdot
.31161 .45913 Mdot
.72142 .471 Mdot
.69131 .5376 Mdot
.61651 .22585 Mdot
.68031 .39094 Mdot
.39637 .62539 Mdot
.72865 .4657 Mdot
.32011 .44241 Mdot
.54129 .40284 Mdot
.51913 .73151 Mdot
.53647 .72776 Mdot
.35235 .45871 Mdot
.58542 .66712 Mdot
.68737 .5561 Mdot
.51888 .41109 Mdot
.36509 .76462 Mdot
.27008 .53497 Mdot
.56064 .61656 Mdot
.55778 .46613 Mdot
.37821 .61194 Mdot
.51369 .41804 Mdot
.68085 .58216 Mdot
.35921 .59513 Mdot
.51525 .76198 Mdot
.23867 .56586 Mdot
.55443 .36774 Mdot
.24663 .63918 Mdot
.37532 .58401 Mdot
.50954 .80885 Mdot
.53943 .3706 Mdot
.3769 .61843 Mdot
.60056 .40347 Mdot
.33109 .69984 Mdot
.45433 .53472 Mdot
.72819 .28035 Mdot
.53432 .64671 Mdot
.58329 .66534 Mdot
.39564 .71266 Mdot
.67491 .61041 Mdot
.36518 .63465 Mdot
.52892 .74527 Mdot
.71702 .37443 Mdot
.38224 .61265 Mdot
.51562 .42703 Mdot
.49221 .38455 Mdot
.40112 .28386 Mdot
.47521 .53436 Mdot
.52401 .75042 Mdot
.22263 .47416 Mdot
.56162 .35328 Mdot
.54397 .45012 Mdot
.53188 .35909 Mdot
.34238 .41282 Mdot
.37142 .58048 Mdot
.21648 .33422 Mdot
.39343 .59114 Mdot
.37306 .77671 Mdot
.58176 .62724 Mdot
.55274 .62335 Mdot
.50052 .38431 Mdot
.46365 .78647 Mdot
.62791 .27859 Mdot
.5744 .37359 Mdot
.57768 .70622 Mdot
.77445 .43207 Mdot
.57142 .44468 Mdot
.29358 .43376 Mdot
.5109 .31926 Mdot
.3838 .46545 Mdot
.35566 .61173 Mdot
.69242 .56045 Mdot
.73878 .5582 Mdot
.35607 .59678 Mdot
.51032 .3658 Mdot
.60895 .68819 Mdot
.51457 .35211 Mdot
.5388 .41095 Mdot
.33783 .76378 Mdot
.70763 .59014 Mdot
.57442 .65382 Mdot
.71518 .57179 Mdot
.34157 .47223 Mdot
.86778 .35333 Mdot
.68355 .57234 Mdot
.41691 .40212 Mdot
.74978 .51366 Mdot
.728 .46873 Mdot
.30576 .44284 Mdot
.70314 .53946 Mdot
.397 .5907 Mdot
.85532 .49845 Mdot
.49863 .8362 Mdot
.33413 .59867 Mdot
.54112 .36563 Mdot
.31915 .42361 Mdot
.35968 .41931 Mdot
.35357 .63838 Mdot
.32654 .42646 Mdot
.57306 .31965 Mdot
.54742 .40004 Mdot
.36444 .63422 Mdot
.27661 .55951 Mdot
.35178 .5957 Mdot
.22124 .54873 Mdot
.55467 .41791 Mdot
.31368 .45834 Mdot
.52318 .3134 Mdot
.28416 .4259 Mdot
.52811 .71947 Mdot
.48055 .37884 Mdot
.69633 .54962 Mdot
.4839 .52591 Mdot
.58941 .63045 Mdot
.43814 .6608 Mdot
.34979 .4263 Mdot
.35 .54791 Mdot
.33569 .42269 Mdot
.31348 .42462 Mdot
.40788 .59334 Mdot
.34886 .47464 Mdot
.51696 .40926 Mdot
.5653 .74431 Mdot
.364 .4456 Mdot
.37496 .59646 Mdot
.69981 .55242 Mdot
.34669 .45094 Mdot
.5841 .67797 Mdot
.54702 .38252 Mdot
.60313 .62597 Mdot
.66227 .60011 Mdot
.30114 .4418 Mdot
.70319 .54031 Mdot
.55516 .65052 Mdot
.69012 .58995 Mdot
.79484 .47682 Mdot
.34699 .61626 Mdot
.417 .81458 Mdot
.54743 .48266 Mdot
.36702 .43041 Mdot
.63013 .58785 Mdot
.5033 .39887 Mdot
.54919 .3821 Mdot
.70511 .53649 Mdot
.36212 .42037 Mdot
.79549 .37492 Mdot
.44858 .45861 Mdot
.23281 .54626 Mdot
.34632 .59757 Mdot
.19623 .45255 Mdot
.25746 .61172 Mdot
.79913 .59881 Mdot
.46953 .41233 Mdot
.51835 .73458 Mdot
.50208 .36434 Mdot
.25105 .32692 Mdot
.67726 .55983 Mdot
.59504 .80311 Mdot
.46698 .38311 Mdot
.58102 .64843 Mdot
.53162 .37793 Mdot
.62849 .32685 Mdot
.5228 .3182 Mdot
.72553 .55185 Mdot
.34702 .66076 Mdot
.33957 .48528 Mdot
.71241 .55612 Mdot
.5793 .66307 Mdot
.73551 .40644 Mdot
.48279 .37233 Mdot
.56154 .35001 Mdot
.5506 .61985 Mdot
.33605 .42732 Mdot
.58715 .67291 Mdot
.37565 .61943 Mdot
.68792 .56744 Mdot
.55594 .37951 Mdot
.5141 .44324 Mdot
.5817 .69855 Mdot
.37064 .57994 Mdot
.5495 .64031 Mdot
.40086 .60303 Mdot
.51812 .73369 Mdot
.50112 .33682 Mdot
.55635 .61321 Mdot
.49117 .40079 Mdot
.22411 .36284 Mdot
.34799 .77229 Mdot
.38615 .36616 Mdot
.57639 .65604 Mdot
.71535 .44855 Mdot
.3869 .5988 Mdot
.39877 .61185 Mdot
.27932 .39405 Mdot
.65359 .299 Mdot
.71954 .67109 Mdot
.40419 .20509 Mdot
.37516 .61992 Mdot
.38126 .60411 Mdot
.6056 .64753 Mdot
.35547 .46858 Mdot
.38435 .44573 Mdot
.55324 .66457 Mdot
.62327 .48748 Mdot
.3282 .4399 Mdot
.68075 .24951 Mdot
.60853 .65991 Mdot
.47002 .41585 Mdot
.5281 .71065 Mdot
.68776 .56066 Mdot
.62045 .48787 Mdot
.62414 .32377 Mdot
.49946 .40192 Mdot
.21575 .61603 Mdot
.56438 .6384 Mdot
.68599 .50243 Mdot
.607 .19674 Mdot
.50222 .34963 Mdot
.52682 .37063 Mdot
.51478 .36241 Mdot
.71344 .58793 Mdot
.25628 .33646 Mdot
.49913 .40375 Mdot
.62322 .49727 Mdot
.58136 .37512 Mdot
.6575 .37764 Mdot
.71249 .57433 Mdot
.25988 .4489 Mdot
.53594 .63918 Mdot
.32458 .71307 Mdot
.61522 .40488 Mdot
.38832 .61511 Mdot
.58517 .58058 Mdot
.36181 .61588 Mdot
.63571 .26497 Mdot
.68268 .39414 Mdot
.3172 .41241 Mdot
.50748 .40668 Mdot
.57034 .59566 Mdot
.33458 .41843 Mdot
.52643 .76831 Mdot
.90476 .4769 Mdot
.37125 .57738 Mdot
.47151 .86629 Mdot
.40026 .61023 Mdot
.5333 .72201 Mdot
.35234 .45155 Mdot
.49363 .25573 Mdot
.50748 .52935 Mdot
.34492 .4521 Mdot
.31034 .61827 Mdot
.28859 .46546 Mdot
.72331 .45414 Mdot
.3395 .48839 Mdot
.37937 .59599 Mdot
.42375 .58601 Mdot
.50023 .44712 Mdot
.50661 .39527 Mdot
.55819 .54566 Mdot
.42131 .42393 Mdot
.50685 .39854 Mdot
.59156 .64721 Mdot
.4791 .82097 Mdot
.55492 .59408 Mdot
.36864 .44907 Mdot
.38161 .57437 Mdot
.52814 .37217 Mdot
.55044 .39957 Mdot
.48862 .40314 Mdot
.19162 .38671 Mdot
.68684 .25761 Mdot
.53177 .4135 Mdot
.57319 .42035 Mdot
.57422 .66115 Mdot
.6898 .53263 Mdot
.34095 .22883 Mdot
.70711 .37737 Mdot
.53818 .34956 Mdot
.71369 .5698 Mdot
.68647 .59559 Mdot
.48546 .36131 Mdot
.37226 .75844 Mdot
.56072 .75425 Mdot
.5066 .38063 Mdot
.67008 .36604 Mdot
.62365 .60612 Mdot
.53589 .73783 Mdot
.56028 .62981 Mdot
.30335 .47573 Mdot
.52496 .74556 Mdot
.59668 .6018 Mdot
.48991 .25032 Mdot
.50969 .72896 Mdot
.31098 .66435 Mdot
.68525 .54887 Mdot
.53088 .35569 Mdot
.28763 .45335 Mdot
.62123 .62184 Mdot
.35468 .59903 Mdot
.32661 .45724 Mdot
.41707 .61757 Mdot
.65432 .58748 Mdot
.65707 .49926 Mdot
.53815 .72769 Mdot
.38314 .61971 Mdot
.23812 .56652 Mdot
.7135 .5711 Mdot
.40719 .60714 Mdot
.46589 .78259 Mdot
.472 .37729 Mdot
.56874 .22783 Mdot
.57526 .39813 Mdot
.83382 .46778 Mdot
.40554 .60021 Mdot
.50534 .73354 Mdot
.50695 .36965 Mdot
.57569 .62107 Mdot
.59678 .3632 Mdot
.53334 .35029 Mdot
.56696 .61646 Mdot
.53719 .40966 Mdot
.6845 .58518 Mdot
.3687 .48258 Mdot
.39719 .50257 Mdot
.16672 .59755 Mdot
.68348 .58844 Mdot
.51671 .77367 Mdot
.50517 .40335 Mdot
.78837 .45175 Mdot
.34564 .44924 Mdot
.51222 .34318 Mdot
.25914 .40617 Mdot
.35954 .45975 Mdot
.33123 .46271 Mdot
.56577 .39077 Mdot
.40247 .61824 Mdot
.58306 .62216 Mdot
.71628 .56809 Mdot
.81521 .59627 Mdot
.54605 .36031 Mdot
.53624 .38713 Mdot
.71108 .55699 Mdot
.38364 .60444 Mdot
.55219 .39759 Mdot
.45641 .65479 Mdot
.84113 .56842 Mdot
.40479 .58505 Mdot
.47248 .39111 Mdot
.51142 .20379 Mdot
.29606 .4082 Mdot
.47021 .85592 Mdot
.75388 .56098 Mdot
.56234 .65543 Mdot
.58552 .44095 Mdot
.63979 .15277 Mdot
.69222 .55896 Mdot
.31238 .71288 Mdot
.53195 .41887 Mdot
.52535 .38601 Mdot
.31554 .43703 Mdot
.55776 .40585 Mdot
.32463 .47557 Mdot
.19006 .65219 Mdot
.16231 .50467 Mdot
.34688 .42876 Mdot
.37104 .44543 Mdot
.29288 .39958 Mdot
.32164 .24646 Mdot
.34754 .46401 Mdot
.47548 .40034 Mdot
.74928 .33182 Mdot
.45775 .3619 Mdot
.70997 .5359 Mdot
.68748 .60224 Mdot
.2725 .47495 Mdot
.49403 .72412 Mdot
.42056 .44949 Mdot
.61399 .36319 Mdot
.45031 .5794 Mdot
.38889 .62393 Mdot
.52962 .34523 Mdot
.53781 .73116 Mdot
.60374 .61266 Mdot
.52764 .32096 Mdot
.52603 .35319 Mdot
.36086 .44503 Mdot
.72996 .57296 Mdot
.41334 .6096 Mdot
.53672 .39394 Mdot
.5539 .68178 Mdot
.69927 .57325 Mdot
.36667 .44406 Mdot
.30007 .39169 Mdot
.71933 .57873 Mdot
.59518 .39242 Mdot
.51616 .39394 Mdot
.54312 .41978 Mdot
.59183 .44288 Mdot
.35482 .61931 Mdot
.62729 .62822 Mdot
.50059 .42606 Mdot
.28339 .6923 Mdot
.59714 .52006 Mdot
.49551 .4318 Mdot
.32351 .43669 Mdot
.35385 .57407 Mdot
.52212 .72129 Mdot
.75424 .43211 Mdot
.55248 .36361 Mdot
.68672 .2599 Mdot
.42338 .26841 Mdot
.5248 .74443 Mdot
.31617 .41615 Mdot
.71511 .55022 Mdot
.56642 .36251 Mdot
.71053 .30282 Mdot
.49341 .3842 Mdot
.51206 .47995 Mdot
.56181 .64596 Mdot
.38388 .62609 Mdot
.84913 .53647 Mdot
.60064 .60977 Mdot
.3296 .46434 Mdot
.73377 .2791 Mdot
.37783 .43064 Mdot
.33982 .48361 Mdot
.647 .25804 Mdot
.35889 .62176 Mdot
.62138 .14164 Mdot
.48639 .84313 Mdot
.52114 .4346 Mdot
.39203 .60196 Mdot
.35512 .44442 Mdot
.51461 .41789 Mdot
.37349 .44579 Mdot
.33229 .48219 Mdot
.47894 .38381 Mdot
.51962 .39057 Mdot
.58352 .49511 Mdot
.64294 .2189 Mdot
.72095 .55547 Mdot
.3062 .45822 Mdot
.35474 .29109 Mdot
.50027 .40749 Mdot
.49952 .37564 Mdot
.55085 .71182 Mdot
.72576 .55298 Mdot
.62092 .33615 Mdot
.54022 .41192 Mdot
.18315 .54126 Mdot
.51662 .33109 Mdot
.28994 .43759 Mdot
.40539 .58575 Mdot
.35985 .74928 Mdot
.62393 .62395 Mdot
.30312 .45903 Mdot
.67391 .57221 Mdot
.30459 .41135 Mdot
.4074 .40012 Mdot
.35856 .61787 Mdot
.31258 .45052 Mdot
.56938 .67589 Mdot
.36221 .60225 Mdot
.40666 .60548 Mdot
.74816 .34196 Mdot
.54894 .64731 Mdot
.68012 .55179 Mdot
.36524 .61347 Mdot
.37062 .25641 Mdot
.37768 .59206 Mdot
.37295 .28952 Mdot
.57406 .40943 Mdot
.63496 .49804 Mdot
.27196 .62194 Mdot
.58192 .45144 Mdot
.35043 .61631 Mdot
.71527 .57439 Mdot
.56201 .38756 Mdot
.32441 .42781 Mdot
.6832 .57078 Mdot
.39305 .6586 Mdot
.55385 .63254 Mdot
.34841 .42153 Mdot
.38777 .57322 Mdot
.30934 .46025 Mdot
.75358 .4868 Mdot
.6498 .54974 Mdot
.44629 .59414 Mdot
.52873 .53049 Mdot
.49202 .40846 Mdot
.33216 .51778 Mdot
.53194 .33077 Mdot
.52447 .35155 Mdot
.59092 .62963 Mdot
.65976 .47744 Mdot
.34946 .44404 Mdot
.8518 .54049 Mdot
.38373 .62189 Mdot
.1962 .58106 Mdot
.45321 .45284 Mdot
.53593 .34313 Mdot
.36358 .44864 Mdot
.37985 .44377 Mdot
.36913 .3715 Mdot
.61895 .63829 Mdot
.53173 .46281 Mdot
.58709 .35643 Mdot
.49966 .44435 Mdot
.40494 .59949 Mdot
.43196 .67648 Mdot
.58657 .66915 Mdot
.61107 .83754 Mdot
.55796 .6401 Mdot
.67008 .65165 Mdot
.35075 .47415 Mdot
.6841 .55378 Mdot
.50031 .37732 Mdot
.51489 .48689 Mdot
.29999 .4262 Mdot
.74926 .54234 Mdot
.70165 .54774 Mdot
.38014 .69951 Mdot
.36468 .62969 Mdot
.49111 .35383 Mdot
.48914 .36847 Mdot
.56238 .40741 Mdot
.56928 .41317 Mdot
.38023 .57571 Mdot
.51289 .42573 Mdot
.35604 .63438 Mdot
.38842 .25063 Mdot
.18121 .54727 Mdot
.59119 .59178 Mdot
.64202 .2989 Mdot
.36236 .4277 Mdot
.34145 .27515 Mdot
.51247 .46564 Mdot
.36096 .78221 Mdot
.78913 .43161 Mdot
.55513 .3406 Mdot
.59936 .65787 Mdot
.6007 .27543 Mdot
.58368 .59339 Mdot
.25639 .78212 Mdot
.63677 .63796 Mdot
.70644 .25811 Mdot
.51132 .41377 Mdot
.5524 .70894 Mdot
.49294 .46178 Mdot
.48011 .37102 Mdot
.64393 .61064 Mdot
.21004 .48653 Mdot
.28533 .59203 Mdot
.69983 .592 Mdot
.54777 .3774 Mdot
.34856 .48373 Mdot
.516 .41049 Mdot
.49766 .3723 Mdot
.52047 .4229 Mdot
.40517 .58277 Mdot
.4966 .33254 Mdot
.52541 .42855 Mdot
.48022 .68637 Mdot
.69194 .45327 Mdot
.60054 .61608 Mdot
.38194 .38798 Mdot
.68941 .57407 Mdot
.35883 .43701 Mdot
.49677 .50418 Mdot
.39387 .62708 Mdot
.32711 .36971 Mdot
.53777 .42668 Mdot
.2642 .60649 Mdot
.38674 .57297 Mdot
.68495 .56636 Mdot
.51354 .72772 Mdot
.75688 .32515 Mdot
.59553 .59465 Mdot
.511 .72724 Mdot
.58812 .63078 Mdot
.26267 .34037 Mdot
.36095 .44719 Mdot
.48919 .40638 Mdot
.37285 .61348 Mdot
.58398 .62011 Mdot
.66411 .46001 Mdot
.52774 .35958 Mdot
.58029 .65735 Mdot
.49299 .41158 Mdot
.64541 .50731 Mdot
.58935 .75386 Mdot
.58485 .59551 Mdot
.41003 .57791 Mdot
.36629 .60246 Mdot
.70483 .54477 Mdot
.35734 .43231 Mdot
.31565 .44282 Mdot
.36001 .59541 Mdot
.42475 .84435 Mdot
.53249 .34925 Mdot
.51028 .41529 Mdot
.28396 .69009 Mdot
.51579 .40278 Mdot
.73701 .42482 Mdot
.53291 .71463 Mdot
.36061 .43244 Mdot
.51938 .41986 Mdot
.55279 .39352 Mdot
.55477 .37185 Mdot
.74989 .48984 Mdot
.55816 .63333 Mdot
.56265 .35519 Mdot
.72684 .5634 Mdot
.45794 .75812 Mdot
.50542 .41334 Mdot
.52997 .4498 Mdot
.31649 .44625 Mdot
.16526 .52505 Mdot
.39697 .62163 Mdot
.59404 .64911 Mdot
.55377 .64605 Mdot
.70961 .60226 Mdot
.33081 .49528 Mdot
.52325 .71686 Mdot
.75664 .70171 Mdot
.50867 .74156 Mdot
.71181 .56253 Mdot
.74356 .6136 Mdot
.56445 .69009 Mdot
.60184 .64503 Mdot
.39981 .63734 Mdot
.54657 .42568 Mdot
.56988 .36167 Mdot
.31599 .71959 Mdot
.55487 .34838 Mdot
.7006 .55012 Mdot
.36813 .63712 Mdot
.32188 .44447 Mdot
.68453 .56217 Mdot
.3991 .60478 Mdot
.33349 .42744 Mdot
.47317 .37321 Mdot
.47152 .37032 Mdot
.33032 .45841 Mdot
.33073 .41982 Mdot
.50748 .38595 Mdot
.45935 .69091 Mdot
.31185 .48446 Mdot
.31169 .45412 Mdot
.53992 .73161 Mdot
.5913 .59265 Mdot
.48692 .32228 Mdot
.39327 .6 Mdot
.54106 .41925 Mdot
.58619 .59254 Mdot
.72282 .54729 Mdot
.34435 .4429 Mdot
.55074 .39459 Mdot
.54112 .39671 Mdot
.71642 .56549 Mdot
.72431 .5764 Mdot
.68404 .55945 Mdot
.34058 .62318 Mdot
.57123 .40145 Mdot
.34505 .46415 Mdot
.36378 .62762 Mdot
.68639 .59555 Mdot
.66638 .56999 Mdot
.50264 .68545 Mdot
.4986 .39773 Mdot
.45191 .5384 Mdot
.84536 .32796 Mdot
.72482 .39548 Mdot
.52425 .72006 Mdot
.54772 .62838 Mdot
.69527 .47921 Mdot
.58182 .74103 Mdot
.37988 .58188 Mdot
.70177 .3392 Mdot
.70213 .53448 Mdot
.48482 .40287 Mdot
.51764 .33162 Mdot
.58407 .37193 Mdot
.69594 .56978 Mdot
.75834 .47071 Mdot
.36375 .41986 Mdot
.30505 .33653 Mdot
.68938 .57377 Mdot
.5867 .59588 Mdot
.55946 .60891 Mdot
.55804 .64081 Mdot
.48884 .34335 Mdot
.35583 .36799 Mdot
.35104 .27788 Mdot
.31697 .26182 Mdot
.36813 .63253 Mdot
.36395 .41199 Mdot
.79218 .47076 Mdot
.33317 .46088 Mdot
.60319 .6103 Mdot
.70046 .56973 Mdot
.31039 .44481 Mdot
.36016 .58614 Mdot
.37997 .60574 Mdot
.55682 .62738 Mdot
.57163 .62433 Mdot
.59789 .62154 Mdot
.31285 .48132 Mdot
.34954 .47439 Mdot
.55489 .36155 Mdot
.33762 .44723 Mdot
.22729 .6447 Mdot
.66507 .59629 Mdot
.56958 .60109 Mdot
.38608 .58963 Mdot
.35787 .44197 Mdot
.53495 .35798 Mdot
.72973 .64406 Mdot
.27931 .5064 Mdot
.69183 .58874 Mdot
.57239 .76614 Mdot
.30227 .81494 Mdot
.48477 .37483 Mdot
.39525 .58507 Mdot
.39235 .77176 Mdot
.51977 .36242 Mdot
.57156 .64089 Mdot
.23588 .33949 Mdot
.51025 .74953 Mdot
.5215 .4271 Mdot
.54772 .34582 Mdot
.40849 .60811 Mdot
.75687 .51723 Mdot
.55794 .36112 Mdot
.23504 .60013 Mdot
.41869 .6014 Mdot
.60939 .64926 Mdot
.84388 .57541 Mdot
.62931 .64157 Mdot
.62278 .47636 Mdot
.53353 .72622 Mdot
.49748 .35962 Mdot
.59464 .64254 Mdot
.69955 .58698 Mdot
.59747 .62929 Mdot
.31563 .41447 Mdot
.60029 .61878 Mdot
.53502 .38633 Mdot
.34443 .4667 Mdot
.37707 .58376 Mdot
.23298 .63742 Mdot
.47429 .6994 Mdot
.57462 .62114 Mdot
.54135 .72922 Mdot
.50778 .419 Mdot
.6241 .39434 Mdot
.59189 .34628 Mdot
.50557 .41099 Mdot
.36189 .61778 Mdot
.36484 .44904 Mdot
.35102 .58531 Mdot
.54394 .44571 Mdot
.19405 .49068 Mdot
.40243 .60871 Mdot
.30139 .64306 Mdot
.71149 .55875 Mdot
.6022 .49151 Mdot
.53852 .35531 Mdot
.36944 .61543 Mdot
.57026 .40388 Mdot
.37084 .46312 Mdot
.49922 .5635 Mdot
.46318 .77002 Mdot
.3731 .61249 Mdot
.80997 .39818 Mdot
.48304 .57319 Mdot
.50409 .31927 Mdot
.37172 .61892 Mdot
.2648 .37015 Mdot
.5299 .72572 Mdot
.70703 .57109 Mdot
.68967 .59508 Mdot
.69078 .59063 Mdot
.54202 .33912 Mdot
.49454 .45104 Mdot
.67087 .56226 Mdot
.41454 .59923 Mdot
.7268 .5528 Mdot
.54655 .49474 Mdot
.80615 .38885 Mdot
.67656 .57034 Mdot
.543 .36944 Mdot
.5414 .4515 Mdot
.6885 .45407 Mdot
.61151 .61725 Mdot
.66473 .23793 Mdot
.49737 .292 Mdot
.50357 .39388 Mdot
.45541 .35996 Mdot
.34329 .41632 Mdot
.43827 .79054 Mdot
.4364 .43532 Mdot
.57537 .75101 Mdot
.36543 .46575 Mdot
.60858 .67142 Mdot
.35968 .43324 Mdot
.48416 .38439 Mdot
.52811 .4139 Mdot
.38418 .46089 Mdot
.38475 .68146 Mdot
.38613 .73703 Mdot
.82855 .52867 Mdot
.30863 .45133 Mdot
.38069 .616 Mdot
.37192 .57672 Mdot
.37306 .63216 Mdot
.61264 .65235 Mdot
.29953 .44532 Mdot
.57203 .38455 Mdot
.57036 .66261 Mdot
.52794 .34707 Mdot
.36211 .60825 Mdot
.85075 .53071 Mdot
.31814 .44565 Mdot
.50848 .37859 Mdot
.49626 .83516 Mdot
.57321 .62999 Mdot
.70865 .57484 Mdot
.65716 .50693 Mdot
.60074 .66937 Mdot
.34951 .60525 Mdot
.38304 .44501 Mdot
.34095 .64795 Mdot
.45671 .4942 Mdot
.46233 .35619 Mdot
.47536 .40985 Mdot
.80645 .61845 Mdot
.48701 .76734 Mdot
.51434 .33467 Mdot
.58077 .66288 Mdot
.61287 .61169 Mdot
.54966 .39041 Mdot
.30673 .43795 Mdot
.67134 .58774 Mdot
.72758 .56416 Mdot
.59143 .40569 Mdot
.51261 .53154 Mdot
.60069 .49713 Mdot
.5535 .40408 Mdot
.56934 .45798 Mdot
.55155 .64292 Mdot
.50654 .73681 Mdot
.28387 .67318 Mdot
.67363 .56801 Mdot
.53394 .41869 Mdot
.30869 .58208 Mdot
.33832 .47958 Mdot
.6005 .62124 Mdot
.35222 .61034 Mdot
.76735 .49065 Mdot
.58361 .6764 Mdot
.54924 .39252 Mdot
.55225 .39685 Mdot
.40745 .60843 Mdot
.2901 .43708 Mdot
.69884 .56855 Mdot
.56803 .65986 Mdot
.67287 .56688 Mdot
.34189 .47381 Mdot
.32131 .44735 Mdot
.45774 .36136 Mdot
.57557 .45091 Mdot
.56077 .62595 Mdot
.56995 .4324 Mdot
.59278 .60083 Mdot
.76483 .52741 Mdot
.36172 .57199 Mdot
.48619 .36963 Mdot
.379 .42332 Mdot
.35988 .60873 Mdot
.51966 .38485 Mdot
.79946 .66594 Mdot
.52315 .34246 Mdot
.6254 .63809 Mdot
.18714 .50973 Mdot
.7242 .56298 Mdot
.42415 .38587 Mdot
.56713 .29107 Mdot
.5184 .40266 Mdot
.57299 .60191 Mdot
.5951 .35809 Mdot
.4052 .60691 Mdot
.36401 .46296 Mdot
.42129 .8623 Mdot
.37413 .59379 Mdot
.51871 .41365 Mdot
.68682 .56727 Mdot
.38092 .43919 Mdot
.5166 .74833 Mdot
.29339 .70198 Mdot
.55033 .32469 Mdot
.46853 .3792 Mdot
.53148 .42494 Mdot
.34396 .22163 Mdot
.59656 .64432 Mdot
.35656 .44334 Mdot
.40376 .5967 Mdot
.36345 .5898 Mdot
.56037 .64099 Mdot
.27107 .58475 Mdot
.5445 .56335 Mdot
.71525 .19169 Mdot
.57319 .61421 Mdot
.71582 .54026 Mdot
.54143 .52126 Mdot
.59092 .60388 Mdot
.58508 .6503 Mdot
.55344 .64907 Mdot
.28841 .65202 Mdot
.33018 .43113 Mdot
.54089 .39903 Mdot
.31294 .48819 Mdot
.49875 .35745 Mdot
.6275 .43543 Mdot
.35642 .60285 Mdot
.36208 .4663 Mdot
.8077 .6367 Mdot
.41977 .4299 Mdot
.52634 .36589 Mdot
.79635 .50161 Mdot
.58157 .32913 Mdot
.74032 .45838 Mdot
.54335 .30993 Mdot
.58159 .62544 Mdot
.451 .43349 Mdot
.52099 .44954 Mdot
.22651 .63689 Mdot
.38849 .59087 Mdot
.53386 .72114 Mdot
.54801 .33418 Mdot
.57333 .33892 Mdot
.37309 .46458 Mdot
.30962 .44582 Mdot
.67261 .56024 Mdot
.59932 .53076 Mdot
.38089 .58458 Mdot
.64469 .54277 Mdot
.5089 .3943 Mdot
.40408 .67251 Mdot
.3373 .38428 Mdot
.51858 .38363 Mdot
.73545 .31811 Mdot
.34201 .36933 Mdot
.55522 .35586 Mdot
.27232 .34685 Mdot
.3831 .60195 Mdot
.19026 .51818 Mdot
.5579 .43371 Mdot
.57318 .64067 Mdot
.35791 .46782 Mdot
.33968 .41574 Mdot
.67642 .57935 Mdot
.30505 .75085 Mdot
.34829 .61318 Mdot
.35528 .47221 Mdot
.5185 .35884 Mdot
.35345 .61504 Mdot
.53599 .7337 Mdot
.51487 .44625 Mdot
.6901 .32084 Mdot
.33416 .44658 Mdot
.57226 .42248 Mdot
.23627 .48804 Mdot
.61379 .51094 Mdot
.59887 .17883 Mdot
.37937 .63129 Mdot
.6783 .56259 Mdot
.50989 .31237 Mdot
.75606 .69998 Mdot
.58177 .36907 Mdot
.63831 .49126 Mdot
.2709 .45898 Mdot
.68566 .55103 Mdot
.51688 .36856 Mdot
.55971 .37194 Mdot
.50369 .52436 Mdot
.72517 .57697 Mdot
.50601 .34783 Mdot
.44638 .4026 Mdot
.33636 .4281 Mdot
.53366 .71678 Mdot
.32975 .44387 Mdot
.54077 .36606 Mdot
.48512 .4461 Mdot
.31678 .4333 Mdot
.78148 .59239 Mdot
.73189 .54505 Mdot
.39443 .62408 Mdot
.55078 .46567 Mdot
.56627 .41958 Mdot
.36583 .18987 Mdot
.52836 .71954 Mdot
.2616 .31404 Mdot
.56662 .68155 Mdot
.31492 .5853 Mdot
.57377 .6967 Mdot
.74 .29076 Mdot
.24132 .64155 Mdot
.55899 .33345 Mdot
.66924 .34481 Mdot
.29154 .31722 Mdot
.34804 .59749 Mdot
.43379 .22783 Mdot
.50632 .3955 Mdot
.49846 .3687 Mdot
.60761 .64717 Mdot
.26035 .5874 Mdot
.38191 .76262 Mdot
.51939 .5396 Mdot
.7014 .56469 Mdot
.33175 .47464 Mdot
.52993 .39602 Mdot
.53875 .57598 Mdot
.59357 .6121 Mdot
.44127 .64026 Mdot
.51013 .37393 Mdot
.38383 .78527 Mdot
.29782 .65374 Mdot
.35548 .62267 Mdot
.55507 .61677 Mdot
.59215 .6752 Mdot
.48955 .37859 Mdot
.3513 .60083 Mdot
.55467 .35891 Mdot
.48281 .59177 Mdot
.57815 .42243 Mdot
.6799 .574 Mdot
.50085 .41762 Mdot
.46632 .52012 Mdot
.65236 .19986 Mdot
.4346 .39897 Mdot
.31032 .42985 Mdot
.60989 .65657 Mdot
.5591 .63472 Mdot
.31219 .44611 Mdot
.56078 .63441 Mdot
.31704 .3434 Mdot
.45125 .30058 Mdot
.70382 .56112 Mdot
.54442 .46955 Mdot
.6811 .57847 Mdot
.53206 .71932 Mdot
.50004 .39582 Mdot
.75178 .71312 Mdot
.57151 .61688 Mdot
.20812 .39899 Mdot
.37688 .58998 Mdot
.53136 .71993 Mdot
.58206 .37733 Mdot
.73906 .61475 Mdot
.60952 .61921 Mdot
.62245 .64899 Mdot
.55492 .36934 Mdot
.31813 .43853 Mdot
.55939 .37676 Mdot
.57212 .3232 Mdot
.51383 .72544 Mdot
.54487 .42565 Mdot
.39902 .60465 Mdot
.29793 .46487 Mdot
.77414 .343 Mdot
.6211 .61991 Mdot
.49338 .39556 Mdot
.51782 .35998 Mdot
.3769 .44645 Mdot
.5806 .39876 Mdot
.36054 .58427 Mdot
.48284 .08754 Mdot
.71221 .55942 Mdot
.50578 .74954 Mdot
.62876 .62991 Mdot
.55711 .34321 Mdot
.55542 .3977 Mdot
.8165 .60378 Mdot
.43916 .73544 Mdot
.39239 .61256 Mdot
.59219 .35773 Mdot
.57397 .66032 Mdot
.68644 .56578 Mdot
.41501 .61207 Mdot
.54496 .41826 Mdot
.50223 .37265 Mdot
.68028 .57099 Mdot
.76116 .35199 Mdot
.57394 .75499 Mdot
.37179 .63337 Mdot
.4519 .43653 Mdot
.71809 .66069 Mdot
.53286 .34969 Mdot
.75141 .65093 Mdot
.31299 .45289 Mdot
.37061 .62262 Mdot
.32552 .24954 Mdot
.49194 .41197 Mdot
.3677 .58091 Mdot
.38313 .58615 Mdot
.52388 .43689 Mdot
.32313 .49277 Mdot
.31 .47597 Mdot
.31244 .46432 Mdot
.17229 .55883 Mdot
.65107 .42277 Mdot
.59689 .62072 Mdot
.38328 .60317 Mdot
.57956 .59449 Mdot
.69143 .59689 Mdot
.59269 .52094 Mdot
.5994 .60143 Mdot
.34442 .41708 Mdot
.55875 .60887 Mdot
.55756 .37376 Mdot
.37682 .58294 Mdot
.60325 .64295 Mdot
.53975 .33421 Mdot
.60356 .31578 Mdot
.46414 .56602 Mdot
.66798 .58102 Mdot
.75246 .54921 Mdot
.53031 .4075 Mdot
.5213 .72193 Mdot
.50565 .38482 Mdot
.36687 .63548 Mdot
.47463 .50864 Mdot
.55103 .34023 Mdot
.56731 .62264 Mdot
.4763 .31511 Mdot
.61738 .63395 Mdot
.58239 .3408 Mdot
.54092 .36939 Mdot
.52042 .3489 Mdot
.55757 .35983 Mdot
.29558 .62113 Mdot
.34588 .59932 Mdot
.60154 .30864 Mdot
.53885 .62047 Mdot
.339 .45392 Mdot
.3436 .41028 Mdot
.70333 .68942 Mdot
.50374 .74913 Mdot
.39206 .60011 Mdot
.53818 .35195 Mdot
.62732 .6394 Mdot
.85216 .5233 Mdot
.78439 .60722 Mdot
.76631 .56797 Mdot
.58973 .65842 Mdot
.31546 .425 Mdot
.60267 .61552 Mdot
.49218 .37069 Mdot
.50116 .43001 Mdot
.75321 .31001 Mdot
.42831 .59913 Mdot
.69905 .57005 Mdot
.51537 .34904 Mdot
.62164 .47358 Mdot
.57411 .66113 Mdot
.551 .64579 Mdot
.52255 .34369 Mdot
.3023 .46165 Mdot
.51411 .14561 Mdot
.35377 .62013 Mdot
.58352 .27571 Mdot
.38011 .49193 Mdot
.20253 .51663 Mdot
.35831 .5929 Mdot
.45563 .57528 Mdot
.56651 .66811 Mdot
.44227 .34514 Mdot
.33478 .45478 Mdot
.696 .57276 Mdot
.49761 .43003 Mdot
.34591 .4184 Mdot
.55148 .6626 Mdot
.36474 .43522 Mdot
.48286 .39185 Mdot
.34755 .59503 Mdot
.55909 .65176 Mdot
.38501 .56584 Mdot
.38573 .45692 Mdot
.69526 .58472 Mdot
.59484 .49126 Mdot
.47468 .22466 Mdot
.33681 .36929 Mdot
.56296 .3557 Mdot
.52442 .64284 Mdot
.57089 .39866 Mdot
.35621 .47978 Mdot
.54046 .35756 Mdot
.27921 .48797 Mdot
.55402 .62177 Mdot
.57092 .42375 Mdot
.5178 .4266 Mdot
.43226 .24517 Mdot
.52336 .37352 Mdot
.54199 .43038 Mdot
.5573 .35597 Mdot
.36468 .50261 Mdot
.50956 .32404 Mdot
.32501 .43352 Mdot
.30644 .70426 Mdot
.58633 .64812 Mdot
.6666 .58023 Mdot
.71775 .57895 Mdot
.63203 .49405 Mdot
.61309 .49055 Mdot
.27099 .59215 Mdot
.33357 .43788 Mdot
.39864 .59739 Mdot
.55386 .35775 Mdot
.36907 .22645 Mdot
.66754 .60682 Mdot
.56246 .66334 Mdot
.62427 .62797 Mdot
.58915 .44316 Mdot
.34819 .21758 Mdot
.5833 .4024 Mdot
.29808 .71773 Mdot
.58746 .41436 Mdot
.51064 .34399 Mdot
.59771 .67015 Mdot
.60976 .50298 Mdot
.56234 .35442 Mdot
.3741 .46288 Mdot
.69727 .57605 Mdot
.42684 .44276 Mdot
.60241 .70849 Mdot
.46315 .60642 Mdot
.46921 .25478 Mdot
.57411 .39213 Mdot
.56405 .65517 Mdot
.34828 .42177 Mdot
.27615 .66834 Mdot
.36474 .62742 Mdot
.269 .62578 Mdot
.38174 .26293 Mdot
.7987 .54538 Mdot
.69878 .57322 Mdot
.75443 .34738 Mdot
.53498 .38759 Mdot
.6118 .65528 Mdot
.47877 .38831 Mdot
.85242 .51876 Mdot
.70555 .53969 Mdot
.29497 .43611 Mdot
.38288 .61511 Mdot
.36751 .46736 Mdot
.39081 .36687 Mdot
.44241 .57688 Mdot
.50871 .61341 Mdot
.59805 .5971 Mdot
.62465 .34297 Mdot
.35261 .46047 Mdot
.54654 .40823 Mdot
.76653 .23751 Mdot
.31302 .45461 Mdot
.30818 .464 Mdot
.75762 .53062 Mdot
.77309 .54652 Mdot
.59845 .39947 Mdot
.36722 .43521 Mdot
.5513 .60886 Mdot
.72018 .56447 Mdot
.56437 .37701 Mdot
.56001 .36451 Mdot
.31556 .4379 Mdot
.60559 .61167 Mdot
.59001 .27518 Mdot
.57655 .62449 Mdot
.33896 .42659 Mdot
.58088 .63314 Mdot
.6019 .59002 Mdot
.59565 .65067 Mdot
.57059 .41676 Mdot
.54357 .35701 Mdot
.63046 .69785 Mdot
.32151 .44735 Mdot
.55875 .39836 Mdot
.53328 .41459 Mdot
.34813 .46222 Mdot
.55348 .68041 Mdot
.39505 .21687 Mdot
.5077 .40552 Mdot
.54528 .3807 Mdot
.68136 .5557 Mdot
.57452 .68991 Mdot
.5792 .77478 Mdot
.56232 .38748 Mdot
.72906 .55084 Mdot
.31602 .48364 Mdot
.50828 .38431 Mdot
.54807 .49644 Mdot
.60145 .59457 Mdot
.49991 .41851 Mdot
.51916 .74888 Mdot
.56424 .35153 Mdot
.53531 .15743 Mdot
.49586 .40182 Mdot
.35396 .44597 Mdot
.35989 .46109 Mdot
.7445 .51878 Mdot
.32755 .46579 Mdot
.53544 .72756 Mdot
.36253 .60555 Mdot
.84259 .48442 Mdot
.53449 .73551 Mdot
.5171 .34087 Mdot
.48629 .84334 Mdot
.55612 .43945 Mdot
.54973 .33563 Mdot
.29791 .26098 Mdot
.53305 .7371 Mdot
.36119 .45218 Mdot
.35891 .67607 Mdot
.58816 .41489 Mdot
.35186 .61107 Mdot
.49014 .43088 Mdot
.51211 .42965 Mdot
.21139 .57088 Mdot
.23213 .42138 Mdot
.37759 .63736 Mdot
.48078 .32417 Mdot
.56235 .38838 Mdot
.48632 .72197 Mdot
.52903 .3581 Mdot
.67593 .57402 Mdot
.3113 .46589 Mdot
.5856 .60712 Mdot
.71504 .55584 Mdot
.51317 .39851 Mdot
.69279 .57051 Mdot
.60018 .62295 Mdot
.36429 .61997 Mdot
.49306 .38895 Mdot
.71454 .53687 Mdot
.70002 .56577 Mdot
.5674 .40237 Mdot
.35994 .46768 Mdot
.42523 .41669 Mdot
.51086 .38407 Mdot
.54688 .40329 Mdot
.3158 .44274 Mdot
.64374 .82022 Mdot
.48666 .37659 Mdot
.45399 .54353 Mdot
.2965 .43585 Mdot
.53828 .70936 Mdot
.60708 .63165 Mdot
.5083 .42942 Mdot
.35492 .61157 Mdot
.35738 .60685 Mdot
.54535 .62858 Mdot
.37271 .46075 Mdot
.61211 .61978 Mdot
.45443 .35062 Mdot
.57175 .45258 Mdot
.53048 .44329 Mdot
.3917 .8426 Mdot
.73965 .30107 Mdot
.30863 .43462 Mdot
.5836 .67047 Mdot
.52582 .54081 Mdot
.38579 .60611 Mdot
.55253 .61305 Mdot
.3818 .44502 Mdot
.32333 .42036 Mdot
.36122 .42703 Mdot
.6877 .5522 Mdot
.57559 .67546 Mdot
.29164 .43625 Mdot
.30552 .46596 Mdot
.55597 .37167 Mdot
.56189 .39105 Mdot
.27107 .42088 Mdot
.70756 .44412 Mdot
.6883 .58461 Mdot
.56366 .64505 Mdot
.30704 .2036 Mdot
.36833 .63603 Mdot
.43629 .24566 Mdot
.55124 .33918 Mdot
.91111 .44642 Mdot
.58409 .40381 Mdot
.52161 .35753 Mdot
.30656 .47866 Mdot
.69329 .53851 Mdot
.69091 .58099 Mdot
.35315 .46145 Mdot
.38463 .44533 Mdot
.67515 .57058 Mdot
.78627 .41843 Mdot
.81197 .39489 Mdot
.2714 .64817 Mdot
.3506 .45246 Mdot
.49606 .22964 Mdot
.34997 .6034 Mdot
.38036 .47199 Mdot
.39323 .63158 Mdot
.58337 .6505 Mdot
.56133 .66779 Mdot
.40721 .61015 Mdot
.5537 .36664 Mdot
.60307 .62948 Mdot
.49705 .32604 Mdot
.79544 .40862 Mdot
.60359 .24188 Mdot
.42173 .72178 Mdot
.52347 .33081 Mdot
.36771 .75452 Mdot
.40485 .76505 Mdot
.52389 .40586 Mdot
.45707 .47659 Mdot
.69687 .57073 Mdot
.37057 .48932 Mdot
.35809 .58649 Mdot
.58611 .1746 Mdot
.53515 .35047 Mdot
.34994 .44175 Mdot
.39067 .59333 Mdot
.71461 .50874 Mdot
.23285 .59209 Mdot
.50448 .35222 Mdot
.66317 .16231 Mdot
.35447 .4972 Mdot
.58472 .6073 Mdot
.4094 .82478 Mdot
.30518 .48365 Mdot
.75279 .55558 Mdot
.55865 .66958 Mdot
.80889 .57617 Mdot
.3581 .43641 Mdot
.54584 .65259 Mdot
.33667 .47328 Mdot
.67874 .57915 Mdot
.34603 .48871 Mdot
.56058 .65602 Mdot
.51929 .37119 Mdot
.56386 .63579 Mdot
.68991 .5856 Mdot
.61532 .64891 Mdot
.35318 .59385 Mdot
.52971 .72185 Mdot
.37336 .60426 Mdot
.61117 .5156 Mdot
.20644 .45691 Mdot
.38381 .62642 Mdot
.67521 .51755 Mdot
.51688 .3339 Mdot
.28871 .43598 Mdot
.57187 .61228 Mdot
.5405 .61851 Mdot
.5688 .52406 Mdot
.34098 .45759 Mdot
.56043 .64657 Mdot
.37449 .26193 Mdot
.56219 .84138 Mdot
.49846 .45279 Mdot
.66188 .3982 Mdot
.34794 .46022 Mdot
.54888 .63948 Mdot
.28435 .68953 Mdot
.35301 .41736 Mdot
.5749 .61383 Mdot
.37312 .61723 Mdot
.3617 .59048 Mdot
.5317 .34619 Mdot
.42796 .58605 Mdot
.56803 .60782 Mdot
.34732 .71344 Mdot
.33556 .47997 Mdot
.71013 .50716 Mdot
.67819 .58547 Mdot
.58566 .65318 Mdot
.51243 .44758 Mdot
.34897 .39824 Mdot
.58701 .58955 Mdot
.66263 .30872 Mdot
.28859 .22509 Mdot
.56157 .64204 Mdot
.31407 .46869 Mdot
.34563 .44049 Mdot
.58673 .33768 Mdot
.5152 .53013 Mdot
.61413 .62946 Mdot
.73016 .73726 Mdot
.64635 .48604 Mdot
.51745 .73366 Mdot
.49476 .78374 Mdot
.56047 .35064 Mdot
.56817 .4095 Mdot
.38702 .60764 Mdot
.53128 .37201 Mdot
.30461 .46876 Mdot
.57445 .3652 Mdot
.37383 .57909 Mdot
.56566 .66633 Mdot
.49579 .39046 Mdot
.71964 .56923 Mdot
.37272 .6402 Mdot
.40831 .61203 Mdot
.58994 .63784 Mdot
.3655 .43248 Mdot
.58839 .56958 Mdot
.57025 .6248 Mdot
.57416 .38664 Mdot
.52258 .7438 Mdot
.48902 .4038 Mdot
.73917 .35253 Mdot
.37019 .42687 Mdot
.59736 .60914 Mdot
.31809 .41551 Mdot
.375 .60009 Mdot
.53842 .63114 Mdot
.53476 .36323 Mdot
.57748 .61538 Mdot
.58889 .72686 Mdot
.76804 .37954 Mdot
.37307 .46135 Mdot
.58198 .70163 Mdot
.31132 .46863 Mdot
.51585 .73367 Mdot
.73667 .37837 Mdot
.70767 .56768 Mdot
.57536 .65799 Mdot
.72144 .28433 Mdot
.56536 .62164 Mdot
.52383 .3759 Mdot
.52315 .38984 Mdot
.6061 .64821 Mdot
.71764 .54741 Mdot
.16738 .52166 Mdot
.4457 .55044 Mdot
.36263 .44587 Mdot
.46174 .31758 Mdot
.36062 .17002 Mdot
.41871 .59518 Mdot
.39044 .60868 Mdot
.58848 .37359 Mdot
.53454 .34305 Mdot
.41142 .6097 Mdot
.3831 .57455 Mdot
.66994 .5723 Mdot
.55477 .65302 Mdot
.30516 .49117 Mdot
.41955 .609 Mdot
.57984 .31464 Mdot
.61544 .48011 Mdot
.59634 .39631 Mdot
.45677 .39662 Mdot
.48344 .34597 Mdot
.63859 .50697 Mdot
.39431 .5826 Mdot
.53261 .40701 Mdot
.52732 .32238 Mdot
.37622 .62087 Mdot
.67929 .5787 Mdot
.23422 .44143 Mdot
.57734 .63722 Mdot
.78024 .72235 Mdot
.49411 .40633 Mdot
.51775 .37709 Mdot
.36748 .63223 Mdot
.49085 .73549 Mdot
.33031 .42152 Mdot
.3715 .43334 Mdot
.59819 .64236 Mdot
.57494 .52532 Mdot
.5803 .38865 Mdot
.52657 .40691 Mdot
.57235 .65168 Mdot
.52781 .72164 Mdot
.39576 .71523 Mdot
.54126 .39416 Mdot
.38742 .59267 Mdot
.57763 .58147 Mdot
.39124 .57982 Mdot
.48317 .37686 Mdot
.52501 .37804 Mdot
.57259 .41446 Mdot
.53378 .34248 Mdot
.40574 .62093 Mdot
.53286 .40208 Mdot
.53845 .45419 Mdot
.36963 .44781 Mdot
.57022 .41287 Mdot
.64434 .49574 Mdot
.54552 .37288 Mdot
.70817 .57911 Mdot
.53123 .59799 Mdot
.51971 .34833 Mdot
.56504 .41882 Mdot
.44863 .55103 Mdot
.51373 .36689 Mdot
.3694 .63559 Mdot
.34075 .44962 Mdot
.38295 .60374 Mdot
.40483 .59739 Mdot
.56338 .59954 Mdot
.67094 .56911 Mdot
.56605 .34223 Mdot
.69704 .58938 Mdot
.46244 .39998 Mdot
.48216 .39286 Mdot
.60534 .57843 Mdot
.29949 .71908 Mdot
.58362 .74572 Mdot
.53701 .36275 Mdot
.59253 .64678 Mdot
.58969 .6077 Mdot
.66658 .33108 Mdot
.50993 .31927 Mdot
.41321 .61224 Mdot
.3698 .61525 Mdot
.73325 .4151 Mdot
.21524 .5801 Mdot
.69639 .58407 Mdot
.56511 .54755 Mdot
.49373 .33899 Mdot
.54106 .40472 Mdot
.52053 .4475 Mdot
.59578 .59846 Mdot
.50803 .73137 Mdot
.56175 .66339 Mdot
.52474 .70872 Mdot
.38437 .57761 Mdot
.57099 .36391 Mdot
.60827 .23235 Mdot
.30999 .43958 Mdot
.33999 .4496 Mdot
.41381 .60297 Mdot
.61613 .62377 Mdot
.57553 .3189 Mdot
.43377 .87164 Mdot
.38846 .46853 Mdot
.66625 .56533 Mdot
.52187 .40898 Mdot
.59213 .64016 Mdot
.30468 .44749 Mdot
.73056 .56018 Mdot
.52045 .42338 Mdot
.53691 .66312 Mdot
.54363 .36108 Mdot
.28765 .32 Mdot
.36734 .45123 Mdot
.85844 .5124 Mdot
.37816 .43216 Mdot
.37616 .64108 Mdot
.38691 .62092 Mdot
.52115 .38384 Mdot
.39901 .83826 Mdot
.29029 .45321 Mdot
.41737 .57574 Mdot
.69782 .53922 Mdot
.50546 .74634 Mdot
.69425 .54367 Mdot
.58836 .60254 Mdot
.69919 .5747 Mdot
.55377 .64423 Mdot
.7245 .41826 Mdot
.39169 .47015 Mdot
.71379 .55804 Mdot
.49335 .69393 Mdot
.49937 .33098 Mdot
.68413 .59486 Mdot
.56006 .45358 Mdot
.4368 .36174 Mdot
.5737 .64863 Mdot
.71922 .54856 Mdot
.54845 .40552 Mdot
.58616 .19067 Mdot
.39877 .61184 Mdot
.41209 .61544 Mdot
.48395 .33748 Mdot
.55313 .6519 Mdot
.38018 .46185 Mdot
.46418 .49773 Mdot
.53456 .7114 Mdot
.52934 .40587 Mdot
.56884 .35915 Mdot
.34695 .41024 Mdot
.36442 .41112 Mdot
.52535 .38108 Mdot
.38919 .24265 Mdot
.53402 .39233 Mdot
.35447 .60345 Mdot
.32699 .42013 Mdot
.3437 .44365 Mdot
.56193 .61153 Mdot
.34828 .48082 Mdot
.45656 .40104 Mdot
.35911 .53384 Mdot
.58283 .42613 Mdot
.37213 .5956 Mdot
.46361 .51217 Mdot
.62361 .62616 Mdot
.63699 .22134 Mdot
.35586 .41247 Mdot
.54877 .42553 Mdot
.32723 .47859 Mdot
.68916 .55616 Mdot
.3244 .44763 Mdot
.29962 .4412 Mdot
.51301 .39174 Mdot
.49854 .35853 Mdot
.53241 .73585 Mdot
.52406 .53159 Mdot
.34968 .47714 Mdot
.52915 .40011 Mdot
.56092 .43538 Mdot
.52291 .43257 Mdot
.47881 .54953 Mdot
.30648 .43514 Mdot
.40109 .2863 Mdot
.67406 .30234 Mdot
.35541 .47336 Mdot
.51237 .15807 Mdot
.5123 .74816 Mdot
.5043 .74841 Mdot
.42297 .59149 Mdot
.54208 .39484 Mdot
.60074 .65806 Mdot
.4917 .37297 Mdot
.45464 .36504 Mdot
.49993 .37278 Mdot
.72237 .54629 Mdot
.55406 .3321 Mdot
.52291 .73001 Mdot
.56612 .62683 Mdot
.51181 .41545 Mdot
.49531 .3875 Mdot
.50325 .75391 Mdot
.36635 .41824 Mdot
.3382 .41957 Mdot
.76404 .63436 Mdot
.69693 .55745 Mdot
.36208 .62075 Mdot
.54633 .35492 Mdot
.59432 .64617 Mdot
.56441 .63369 Mdot
.35597 .4775 Mdot
.57166 .63882 Mdot
.35687 .62729 Mdot
.53085 .36223 Mdot
.41149 .61468 Mdot
.72616 .55496 Mdot
.30881 .46173 Mdot
.54195 .35123 Mdot
.55576 .37248 Mdot
.36005 .46073 Mdot
.5153 .33404 Mdot
.68082 .55626 Mdot
.56175 .62632 Mdot
.35156 .42816 Mdot
.36112 .60515 Mdot
.56242 .60893 Mdot
.55455 .38684 Mdot
.27662 .23976 Mdot
.53266 .37668 Mdot
.54795 .39247 Mdot
.79273 .35593 Mdot
.58808 .36314 Mdot
.56223 .6152 Mdot
.33443 .40885 Mdot
.47159 .3628 Mdot
.63564 .4606 Mdot
.77594 .66044 Mdot
.54996 .61355 Mdot
.51516 .41106 Mdot
.65332 .22652 Mdot
.51263 .4131 Mdot
.64151 .54444 Mdot
.64085 .73782 Mdot
.62892 .33667 Mdot
.45897 .39935 Mdot
.39973 .62285 Mdot
.53379 .73266 Mdot
.55323 .62701 Mdot
.28065 .36843 Mdot
.51912 .39597 Mdot
.25926 .36942 Mdot
.5121 .42534 Mdot
.36098 .58998 Mdot
.4403 .36903 Mdot
.5646 .64262 Mdot
.26834 .70207 Mdot
.57252 .3867 Mdot
.31103 .43111 Mdot
.56785 .60165 Mdot
.50733 .7467 Mdot
.55028 .39614 Mdot
.71059 .5832 Mdot
.39082 .56351 Mdot
.56534 .45598 Mdot
.36822 .5956 Mdot
.53391 .41605 Mdot
.47184 .33276 Mdot
.35241 .79634 Mdot
.36791 .44658 Mdot
.38507 .61276 Mdot
.44306 .78297 Mdot
.5071 .33678 Mdot
.3569 .43391 Mdot
.3358 .45521 Mdot
.68236 .58577 Mdot
.51485 .57309 Mdot
.24466 .50036 Mdot
.55717 .21724 Mdot
.38213 .38594 Mdot
.54981 .62451 Mdot
.40363 .75005 Mdot
.56483 .38095 Mdot
.44369 .59814 Mdot
.3804 .63559 Mdot
.51765 .3748 Mdot
.34304 .38236 Mdot
.31067 .46093 Mdot
.54179 .384 Mdot
.68026 .57814 Mdot
.43235 .66274 Mdot
.44997 .62632 Mdot
.41249 .17973 Mdot
.54942 .61182 Mdot
.50625 .43817 Mdot
.46625 .41746 Mdot
.54024 .72682 Mdot
.48005 .39835 Mdot
.56132 .61849 Mdot
.79767 .44982 Mdot
.71514 .54434 Mdot
.30469 .45255 Mdot
.51153 .74794 Mdot
.4822 .34476 Mdot
.54953 .43621 Mdot
.66651 .57867 Mdot
.55224 .41845 Mdot
.31124 .75426 Mdot
.509 .77523 Mdot
.60361 .63761 Mdot
.36146 .43036 Mdot
.48837 .34429 Mdot
.50996 .72867 Mdot
.51693 .39122 Mdot
.50543 .26036 Mdot
.55457 .42273 Mdot
.23023 .50135 Mdot
.35676 .46902 Mdot
.36839 .59865 Mdot
.46007 .37835 Mdot
.50301 .36523 Mdot
.72396 .65207 Mdot
.45611 .36252 Mdot
.49525 .4024 Mdot
.37727 .45606 Mdot
.30896 .43691 Mdot
.32519 .43468 Mdot
.59955 .61696 Mdot
.27855 .6576 Mdot
.38387 .59498 Mdot
.57819 .36605 Mdot
.41907 .61012 Mdot
.53859 .27273 Mdot
.66583 .57294 Mdot
.52886 .18111 Mdot
.53878 .42708 Mdot
.33116 .43457 Mdot
.30721 .5639 Mdot
.31455 .48221 Mdot
.53291 .63792 Mdot
.38005 .58411 Mdot
.31216 .45842 Mdot
.51233 .35916 Mdot
.50547 .53478 Mdot
.4395 .18565 Mdot
.37959 .60803 Mdot
.53915 .45025 Mdot
.54097 .62225 Mdot
.62083 .61221 Mdot
.37768 .14764 Mdot
.39351 .61306 Mdot
.4111 .76508 Mdot
.52393 .40196 Mdot
.31228 .43781 Mdot
.3854 .62982 Mdot
.39939 .61698 Mdot
.57157 .64621 Mdot
.50467 .35312 Mdot
.51927 .34995 Mdot
.51677 .74902 Mdot
.36652 .61424 Mdot
.47703 .34497 Mdot
.55609 .44228 Mdot
.75605 .31276 Mdot
.2706 .40351 Mdot
.68277 .80166 Mdot
.45326 .35256 Mdot
.3634 .37979 Mdot
.53995 .51569 Mdot
.29839 .44987 Mdot
.51469 .34817 Mdot
.48099 .3572 Mdot
.56234 .61239 Mdot
.53271 .369 Mdot
.61044 .64992 Mdot
.39493 .60393 Mdot
.49705 .16453 Mdot
.29541 .51419 Mdot
.79001 .44482 Mdot
.52718 .3689 Mdot
.205 .54574 Mdot
.7071 .55024 Mdot
.33626 .62625 Mdot
.33816 .42445 Mdot
.49272 .34939 Mdot
.61713 .65223 Mdot
.57533 .65892 Mdot
.32609 .45843 Mdot
.34678 .72709 Mdot
.74432 .65251 Mdot
.48334 .374 Mdot
.60808 .62995 Mdot
.31376 .59888 Mdot
.37243 .24914 Mdot
.41146 .63273 Mdot
.71193 .5419 Mdot
.56354 .66389 Mdot
.40741 .58999 Mdot
.31045 .39549 Mdot
.3188 .46287 Mdot
.32398 .41034 Mdot
.66404 .70195 Mdot
.61572 .63329 Mdot
.71796 .55698 Mdot
.24389 .6304 Mdot
.23316 .62322 Mdot
.71778 .54324 Mdot
.56849 .66852 Mdot
.3058 .4422 Mdot
.34833 .43305 Mdot
.34182 .44929 Mdot
.26039 .69105 Mdot
.3744 .4391 Mdot
.44663 .27124 Mdot
.55249 .4397 Mdot
.59873 .45171 Mdot
.51229 .41122 Mdot
.39964 .62865 Mdot
.36641 .45252 Mdot
.55321 .5208 Mdot
.5268 .33817 Mdot
.43082 .17941 Mdot
.5279 .40864 Mdot
.39948 .64034 Mdot
.54354 .3888 Mdot
.45554 .23193 Mdot
.29563 .43898 Mdot
.53727 .36584 Mdot
.34267 .60161 Mdot
.69674 .5648 Mdot
.28414 .47385 Mdot
.51863 .34877 Mdot
.2485 .57589 Mdot
.584 .36233 Mdot
.79804 .43737 Mdot
.72676 .49335 Mdot
.6661 .56351 Mdot
.44502 .39691 Mdot
.54601 .63878 Mdot
.27928 .47432 Mdot
.49889 .45837 Mdot
.37777 .60815 Mdot
.22025 .38557 Mdot
.57987 .65868 Mdot
.42769 .40228 Mdot
.59036 .35133 Mdot
.67184 .57024 Mdot
.3092 .40299 Mdot
.37182 .63477 Mdot
.53893 .33307 Mdot
.52527 .43644 Mdot
.7809 .42843 Mdot
.51833 .46466 Mdot
.58197 .39514 Mdot
.67223 .58999 Mdot
.40836 .2888 Mdot
.54936 .37346 Mdot
.54868 .6742 Mdot
.32063 .41203 Mdot
.48682 .33438 Mdot
.40067 .28277 Mdot
.52805 .39933 Mdot
.31683 .4534 Mdot
.32884 .40693 Mdot
.28165 .55699 Mdot
.68543 .54316 Mdot
.55417 .42279 Mdot
.76835 .5032 Mdot
.57213 .39834 Mdot
.38348 .59072 Mdot
.48561 .37895 Mdot
.57883 .65334 Mdot
.29241 .71038 Mdot
.58906 .61518 Mdot
.48926 .37308 Mdot
.34589 .44875 Mdot
.39248 .62916 Mdot
.63348 .70683 Mdot
.67329 .71991 Mdot
.441 .27368 Mdot
.80656 .64522 Mdot
.70464 .54572 Mdot
.70815 .59016 Mdot
.35435 .63122 Mdot
.53997 .36582 Mdot
.747 .51277 Mdot
.59018 .39808 Mdot
.54581 .38186 Mdot
.49906 .37445 Mdot
.41377 .56303 Mdot
.38815 .60259 Mdot
.57391 .6322 Mdot
.52664 .37966 Mdot
.53073 .3997 Mdot
.33603 .47699 Mdot
.69904 .56411 Mdot
.58848 .61225 Mdot
.70586 .55816 Mdot
.58862 .62605 Mdot
.5306 .15534 Mdot
.56916 .44013 Mdot
.6945 .56397 Mdot
.3571 .63507 Mdot
.31536 .44249 Mdot
.51641 .72027 Mdot
.58365 .60094 Mdot
.56256 .64543 Mdot
.52819 .4054 Mdot
.31347 .44742 Mdot
.35093 .47829 Mdot
.69198 .55321 Mdot
.37045 .62691 Mdot
.49055 .3714 Mdot
.48103 .37881 Mdot
.64178 .31809 Mdot
.58608 .59607 Mdot
.35648 .26923 Mdot
.28419 .58177 Mdot
.53941 .36354 Mdot
.3693 .43915 Mdot
.49937 .38684 Mdot
.64959 .24225 Mdot
.3444 .4173 Mdot
.51086 .34428 Mdot
.20741 .57956 Mdot
.60606 .60485 Mdot
.24022 .5356 Mdot
.56656 .42478 Mdot
.8209 .59641 Mdot
.56658 .39023 Mdot
.72407 .26446 Mdot
.46635 .73728 Mdot
.57518 .36871 Mdot
.56097 .37713 Mdot
.54369 .21382 Mdot
.51648 .4023 Mdot
.51636 .73099 Mdot
.43835 .38543 Mdot
.32314 .42003 Mdot
.56946 .50851 Mdot
.54731 .68536 Mdot
.70166 .53751 Mdot
.59857 .64207 Mdot
.5701 .71152 Mdot
.67881 .5737 Mdot
.35167 .45314 Mdot
.55879 .36034 Mdot
.60034 .48985 Mdot
.55282 .60229 Mdot
.57946 .33274 Mdot
.38167 .58856 Mdot
.5901 .69353 Mdot
.60446 .65927 Mdot
.36429 .60401 Mdot
.52046 .4283 Mdot
.42664 .20681 Mdot
.6208 .74996 Mdot
.84968 .49143 Mdot
.37109 .63323 Mdot
.3584 .59087 Mdot
.27629 .67741 Mdot
.70803 .53802 Mdot
.73433 .35792 Mdot
.21317 .52037 Mdot
.3513 .61452 Mdot
.75539 .42748 Mdot
.55302 .65625 Mdot
.24009 .57219 Mdot
.37076 .48912 Mdot
.52694 .4444 Mdot
.50961 .36054 Mdot
.37231 .62565 Mdot
.55191 .48918 Mdot
.37871 .80471 Mdot
.37353 .60544 Mdot
.4794 .43154 Mdot
.49656 .59309 Mdot
.51764 .74438 Mdot
.52621 .74694 Mdot
.67625 .55115 Mdot
.7742 .60521 Mdot
.3437 .47194 Mdot
.67155 .57442 Mdot
.4498 .64228 Mdot
.546 .42298 Mdot
.37115 .61205 Mdot
.50828 .72634 Mdot
.35922 .59778 Mdot
.68567 .57889 Mdot
.66701 .56428 Mdot
.36957 .44648 Mdot
.33148 .42149 Mdot
.35107 .37704 Mdot
.73355 .44702 Mdot
.51225 .41417 Mdot
.28262 .29245 Mdot
.3374 .48052 Mdot
.46814 .44234 Mdot
.72858 .55082 Mdot
.69658 .56152 Mdot
.29543 .32281 Mdot
.5497 .35323 Mdot
.7294 .51699 Mdot
.54154 .35335 Mdot
.72008 .36298 Mdot
.47643 .38847 Mdot
.57238 .64305 Mdot
.56814 .36242 Mdot
.59643 .5688 Mdot
.55662 .34883 Mdot
.4937 .40209 Mdot
.55708 .65782 Mdot
.57515 .44625 Mdot
.57751 .65437 Mdot
.48997 .36825 Mdot
.72961 .57568 Mdot
.59488 .64558 Mdot
.65993 .42487 Mdot
.45491 .54533 Mdot
.5215 .72432 Mdot
.70635 .58253 Mdot
.68293 .58893 Mdot
.62311 .49173 Mdot
.34066 .42441 Mdot
.36919 .39927 Mdot
.54041 .36798 Mdot
.55087 .6449 Mdot
.38921 .60627 Mdot
.5317 .39769 Mdot
.47898 .37486 Mdot
.57683 .41276 Mdot
.31889 .47097 Mdot
.61663 .6269 Mdot
.69108 .56808 Mdot
.60588 .62574 Mdot
.74556 .63127 Mdot
.58525 .67601 Mdot
.51932 .3223 Mdot
.47254 .40623 Mdot
.54863 .25882 Mdot
.24129 .37376 Mdot
.18867 .56763 Mdot
.32296 .46308 Mdot
.53061 .731 Mdot
.66788 .56473 Mdot
.46647 .3173 Mdot
.33394 .42886 Mdot
.56248 .65771 Mdot
.54339 .36061 Mdot
.5073 .44876 Mdot
.41968 .64244 Mdot
.27693 .47474 Mdot
.65981 .47921 Mdot
.60458 .66201 Mdot
.51579 .73646 Mdot
.27652 .6582 Mdot
.41821 .42029 Mdot
.57542 .52105 Mdot
.506 .37656 Mdot
.71502 .58011 Mdot
.30471 .44752 Mdot
.62745 .72455 Mdot
.37023 .61977 Mdot
.51772 .53082 Mdot
.52814 .36839 Mdot
.31375 .66815 Mdot
.34505 .45007 Mdot
.68345 .58185 Mdot
.37262 .62501 Mdot
.69764 .53734 Mdot
.52599 .74767 Mdot
.79222 .58851 Mdot
.56562 .40891 Mdot
.49754 .40353 Mdot
.4025 .63644 Mdot
.33953 .47178 Mdot
.7506 .54656 Mdot
.77637 .4033 Mdot
.60812 .63871 Mdot
.72118 .51789 Mdot
.29995 .46991 Mdot
.47557 .24862 Mdot
.60367 .62222 Mdot
.4138 .6022 Mdot
.61835 .50928 Mdot
.3762 .57821 Mdot
.52662 .34747 Mdot
.33708 .43869 Mdot
.39861 .60638 Mdot
.7128 .65379 Mdot
.64416 .20755 Mdot
.49297 .23541 Mdot
.5764 .38358 Mdot
.51736 .17591 Mdot
.79798 .39274 Mdot
.50331 .48691 Mdot
.35309 .59288 Mdot
.51279 .38567 Mdot
.48131 .40563 Mdot
.57222 .37995 Mdot
.39909 .59495 Mdot
.72259 .6172 Mdot
.56524 .65144 Mdot
.52353 .41238 Mdot
.67494 .58057 Mdot
.58163 .64649 Mdot
.62396 .58581 Mdot
.5569 .6249 Mdot
.31432 .42226 Mdot
.52476 .34164 Mdot
.28066 .63426 Mdot
.67348 .20615 Mdot
.38216 .60468 Mdot
.52157 .72459 Mdot
.50237 .41638 Mdot
.19738 .49452 Mdot
.32652 .43429 Mdot
.60779 .64103 Mdot
.51688 .37703 Mdot
.72055 .62904 Mdot
.50262 .72522 Mdot
.557 .63333 Mdot
.34744 .43013 Mdot
.48864 .48712 Mdot
.53349 .37104 Mdot
.56628 .39559 Mdot
.34577 .46735 Mdot
.77939 .61509 Mdot
.29309 .70591 Mdot
.4967 .3872 Mdot
.3675 .60008 Mdot
.5189 .86435 Mdot
.55524 .42982 Mdot
.28624 .40423 Mdot
.50549 .74826 Mdot
.2607 .57671 Mdot
.34906 .2734 Mdot
.44337 .39344 Mdot
.56209 .2086 Mdot
.60255 .50246 Mdot
.50757 .16483 Mdot
.74859 .58076 Mdot
.47756 .64112 Mdot
.5437 .15716 Mdot
.343 .61191 Mdot
.60501 .44367 Mdot
.60784 .28396 Mdot
.32767 .7209 Mdot
.53793 .50278 Mdot
.73553 .70649 Mdot
.7078 .67671 Mdot
.51693 .65298 Mdot
.5716 .61738 Mdot
.70234 .34647 Mdot
.49052 .37516 Mdot
.80209 .40017 Mdot
.40336 .24009 Mdot
.37363 .80895 Mdot
.53203 .17461 Mdot
.76929 .50042 Mdot
.45376 .19032 Mdot
.66429 .23839 Mdot
.56954 .25664 Mdot
.28045 .49451 Mdot
.68022 .78511 Mdot
.24298 .63527 Mdot
.78615 .5 Mdot
.5376 .30723 Mdot
.54316 .56953 Mdot
.80598 .49917 Mdot
.44162 .29644 Mdot
.42855 .84363 Mdot
.57706 .60489 Mdot
.30653 .41762 Mdot
.63306 .29809 Mdot
.27946 .464 Mdot
.35087 .54717 Mdot
.55903 .20674 Mdot
.72088 .26959 Mdot
.44888 .23325 Mdot
.82251 .60586 Mdot
.29959 .35604 Mdot
.16449 .56547 Mdot
.47069 .57115 Mdot
.30436 .41425 Mdot
.62971 .79315 Mdot
.23214 .62089 Mdot
.27833 .51172 Mdot
.4858 .30359 Mdot
.66959 .60373 Mdot
.6804 .44327 Mdot
.35016 .44286 Mdot
.34886 .26699 Mdot
.52715 .75012 Mdot
.24953 .47222 Mdot
.57361 .5712 Mdot
.6206 .21363 Mdot
.51504 .61869 Mdot
.24963 .59006 Mdot
.38836 .73674 Mdot
.27992 .23567 Mdot
.75546 .46104 Mdot
.69623 .28351 Mdot
.40635 .64648 Mdot
.53258 .49985 Mdot
.36347 .7718 Mdot
.72269 .46264 Mdot
.22428 .61074 Mdot
.2568 .28787 Mdot
.82045 .44875 Mdot
.32652 .21673 Mdot
.28555 .41957 Mdot
.57835 .40749 Mdot
.65503 .26453 Mdot
.38861 .3882 Mdot
.6619 .57416 Mdot
.38111 .19079 Mdot
.72806 .56337 Mdot
.27822 .44594 Mdot
.34145 .72648 Mdot
.45266 .25206 Mdot
.69011 .51845 Mdot
.73673 .53974 Mdot
.55865 .33274 Mdot
.16302 .65766 Mdot
.49479 .1706 Mdot
.2754 .56031 Mdot
.75598 .31162 Mdot
.39878 .67175 Mdot
.72079 .50466 Mdot
.3974 .6003 Mdot
.60664 .17874 Mdot
.34229 .43246 Mdot
.60312 .15101 Mdot
.63499 .19464 Mdot
.47842 .81777 Mdot
.33959 .85351 Mdot
.43847 .70173 Mdot
.61369 .31961 Mdot
.61221 .47664 Mdot
.65151 .45677 Mdot
.38066 .79566 Mdot
.49439 .81924 Mdot
.38585 .67612 Mdot
.81264 .55063 Mdot
.56524 .16929 Mdot
.74287 .4018 Mdot
.78342 .54376 Mdot
.34537 .74184 Mdot
.46474 .54361 Mdot
.35856 .40042 Mdot
.42467 .52522 Mdot
.27492 .48667 Mdot
.36661 .19863 Mdot
.38661 .39875 Mdot
.44729 .87055 Mdot
.73836 .57393 Mdot
.48606 .75407 Mdot
.76216 .33509 Mdot
.66544 .40929 Mdot
.51429 .27501 Mdot
.29675 .67541 Mdot
.55118 .32779 Mdot
.28267 .66683 Mdot
.41376 .46184 Mdot
.57597 .70532 Mdot
.27247 .65875 Mdot
.31531 .63004 Mdot
.77647 .41887 Mdot
.60204 .24482 Mdot
.20439 .56035 Mdot
.33058 .41616 Mdot
.70211 .47894 Mdot
.75773 .44819 Mdot
.75926 .31987 Mdot
.44129 .78233 Mdot
.85083 .47748 Mdot
.45722 .79114 Mdot
.58831 .40352 Mdot
.4846 .44779 Mdot
.55061 .3056 Mdot
.73712 .46643 Mdot
.56905 .42792 Mdot
.31683 .67014 Mdot
.78016 .34132 Mdot
.32998 .38314 Mdot
.62455 .67599 Mdot
.2247 .36164 Mdot
.83886 .4715 Mdot
.65943 .2757 Mdot
.46147 .74688 Mdot
.56678 .47408 Mdot
.15189 .47978 Mdot
.58495 .6382 Mdot
.7519 .42022 Mdot
.37286 .56915 Mdot
.65443 .71071 Mdot
.52579 .22138 Mdot
.46623 .81783 Mdot
.78501 .34563 Mdot
.30255 .70206 Mdot
.5712 .75678 Mdot
.60723 .54216 Mdot
.67664 .52524 Mdot
.23724 .34584 Mdot
.48103 .42672 Mdot
.54418 .28624 Mdot
.68551 .59344 Mdot
.40637 .36782 Mdot
.68448 .30797 Mdot
.66596 .74618 Mdot
.49596 .44949 Mdot
.58321 .7902 Mdot
.5125 .73678 Mdot
.51207 .53284 Mdot
.41531 .14244 Mdot
.55248 .32282 Mdot
.44062 .71687 Mdot
.82364 .46172 Mdot
.69939 .4946 Mdot
.73498 .3145 Mdot
.29986 .63978 Mdot
.30877 .23516 Mdot
.66794 .21281 Mdot
.66744 .7312 Mdot
.47176 .15757 Mdot
.8421 .40661 Mdot
.27783 .26215 Mdot
.26444 .33455 Mdot
.33829 .60434 Mdot
.56808 .10868 Mdot
.58481 .66479 Mdot
.21141 .406 Mdot
.37775 .38668 Mdot
.68855 .63792 Mdot
.37011 .47411 Mdot
.60543 .38215 Mdot
.5166 .63791 Mdot
.33862 .49839 Mdot
.49318 .32921 Mdot
.32482 .20044 Mdot
.22164 .33029 Mdot
.33466 .19928 Mdot
.83147 .51145 Mdot
.48135 .15801 Mdot
.63252 .32996 Mdot
.45548 .27027 Mdot
.66794 .3199 Mdot
.48454 .37697 Mdot
.71471 .39189 Mdot
.4352 .70895 Mdot
.60917 .7512 Mdot
.26112 .50255 Mdot
.33405 .49099 Mdot
.37362 .20713 Mdot
.32186 .17148 Mdot
.31308 .34365 Mdot
.36581 .30131 Mdot
.4456 .61174 Mdot
.74061 .44901 Mdot
.40264 .46885 Mdot
.56973 .78072 Mdot
.76259 .3298 Mdot
.60691 .28162 Mdot
.7666 .43029 Mdot
.68186 .74568 Mdot
.63579 .55581 Mdot
.49065 .72137 Mdot
.61881 .20533 Mdot
.65107 .3628 Mdot
.48113 .80853 Mdot
.60563 .45507 Mdot
.41954 .82321 Mdot
.72617 .68963 Mdot
.55227 .72328 Mdot
.7724 .46567 Mdot
.61997 .61471 Mdot
.73433 .39687 Mdot
.49896 .58298 Mdot
.63551 .28664 Mdot
.60268 .50135 Mdot
.73354 .39121 Mdot
.63371 .55705 Mdot
.40095 .17459 Mdot
.86497 .45136 Mdot
.19434 .37333 Mdot
.82361 .58302 Mdot
.41573 .4684 Mdot
.54026 .43887 Mdot
.80893 .3825 Mdot
.37467 .17636 Mdot
.68763 .2246 Mdot
.33063 .69863 Mdot
.7104 .64767 Mdot
.35168 .63703 Mdot
.19551 .381 Mdot
.75522 .66959 Mdot
.70037 .26217 Mdot
.1904 .56641 Mdot
.42229 .58981 Mdot
.30946 .72399 Mdot
.20816 .38507 Mdot
.50069 .21847 Mdot
.32467 .29649 Mdot
.5889 .34406 Mdot
.432 .22826 Mdot
.33187 .41192 Mdot
.38359 .74127 Mdot
.73038 .4614 Mdot
.58924 .63884 Mdot
.65367 .39381 Mdot
.54104 .28277 Mdot
.5634 .33493 Mdot
.54022 .68834 Mdot
.38847 .43366 Mdot
.23968 .38753 Mdot
.33439 .64732 Mdot
.51712 .1451 Mdot
.42551 .72926 Mdot
.49202 .30918 Mdot
.72419 .48502 Mdot
.59772 .73266 Mdot
.28885 .67732 Mdot
.34691 .60251 Mdot
.5625 .18386 Mdot
.40362 .51451 Mdot
.70828 .47931 Mdot
.41624 .23027 Mdot
.75381 .37407 Mdot
.47375 .40703 Mdot
.29383 .57175 Mdot
.4677 .29319 Mdot
.53024 .53355 Mdot
.28397 .45062 Mdot
.38724 .42303 Mdot
.85642 .59952 Mdot
.43949 .66194 Mdot
.46791 .78083 Mdot
.57272 .18927 Mdot
.38556 .58261 Mdot
.32981 .48646 Mdot
.71816 .37791 Mdot
.78439 .42499 Mdot
.44358 .31336 Mdot
.61553 .65884 Mdot
.65346 .6024 Mdot
.69597 .72295 Mdot
.52167 .17952 Mdot
.47645 .18486 Mdot
.36479 .80856 Mdot
.35489 .47966 Mdot
.7373 .3476 Mdot
.784 .4418 Mdot
.31947 .47613 Mdot
.27048 .44502 Mdot
.24063 .47056 Mdot
.46202 .14766 Mdot
.27902 .6453 Mdot
.81544 .58314 Mdot
.63387 .50703 Mdot
.72785 .61971 Mdot
.61731 .72188 Mdot
.78103 .51822 Mdot
.57957 .19246 Mdot
.33984 .26856 Mdot
.48506 .20909 Mdot
.48901 .31658 Mdot
.25456 .40204 Mdot
.18801 .39046 Mdot
.47504 .56152 Mdot
.47238 .24552 Mdot
.31996 .58725 Mdot
.5746 .39266 Mdot
.28177 .2341 Mdot
.79701 .41226 Mdot
.25776 .66405 Mdot
.35766 .56557 Mdot
.55422 .39989 Mdot
.57379 .43069 Mdot
.53147 .48649 Mdot
.27139 .57287 Mdot
.22772 .33488 Mdot
.78367 .51866 Mdot
.44312 .47284 Mdot
.39782 .23829 Mdot
.44046 .71897 Mdot
.6211 .2181 Mdot
.78458 .37035 Mdot
.5199 .55747 Mdot
.43043 .71392 Mdot
.6082 .52779 Mdot
.82547 .5602 Mdot
.52519 .60289 Mdot
.63113 .31755 Mdot
.21082 .4946 Mdot
.2824 .60579 Mdot
.60759 .73339 Mdot
.50159 .41822 Mdot
.34527 .72585 Mdot
.6568 .23638 Mdot
.39633 .8449 Mdot
.37967 .78535 Mdot
.31207 .2027 Mdot
.51588 .25002 Mdot
.28219 .61515 Mdot
.45493 .19992 Mdot
.38231 .84719 Mdot
.52324 .62287 Mdot
.41761 .18961 Mdot
.60686 .53721 Mdot
.54844 .18073 Mdot
.35626 .57239 Mdot
.23522 .59531 Mdot
.22248 .36791 Mdot
.47302 .1491 Mdot
.68085 .28348 Mdot
.59269 .20253 Mdot
.60359 .46297 Mdot
.43299 .15229 Mdot
.20807 .48269 Mdot
.51796 .65922 Mdot
.54013 .62893 Mdot
.32721 .68591 Mdot
.35573 .23553 Mdot
.34632 .52748 Mdot
.75876 .42663 Mdot
.51152 .69217 Mdot
.48322 .29718 Mdot
.45946 .21066 Mdot
.67994 .39678 Mdot
.29416 .61296 Mdot
.72128 .48643 Mdot
.68075 .2412 Mdot
.52823 .69385 Mdot
.62778 .70835 Mdot
.44463 .7579 Mdot
.79559 .58348 Mdot
.26962 .56735 Mdot
.43322 .67307 Mdot
.69247 .2796 Mdot
.75348 .65673 Mdot
.76854 .48966 Mdot
.8932 .55487 Mdot
.79843 .52831 Mdot
.2511 .46438 Mdot
.35649 .20798 Mdot
.77321 .34736 Mdot
.23985 .42631 Mdot
.35594 .78948 Mdot
.26287 .39591 Mdot
.72213 .41803 Mdot
.49942 .3724 Mdot
.39605 .15427 Mdot
.6861 .43319 Mdot
.36803 .19554 Mdot
.82806 .42278 Mdot
.43211 .22453 Mdot
.57625 .34232 Mdot
.57158 .68341 Mdot
.46048 .60176 Mdot
.68049 .38436 Mdot
.49908 .20428 Mdot
.26731 .38984 Mdot
.5714 .69852 Mdot
.53754 .74712 Mdot
.60427 .66846 Mdot
.44674 .45624 Mdot
.41674 .71314 Mdot
.28332 .58896 Mdot
.74204 .53444 Mdot
.53175 .56739 Mdot
.74756 .44132 Mdot
.3552 .2684 Mdot
.50771 .22088 Mdot
.44796 .81976 Mdot
.34188 .55525 Mdot
.56512 .61178 Mdot
.5624 .22407 Mdot
.80696 .52136 Mdot
.30629 .61181 Mdot
.28631 .26341 Mdot
.30099 .6856 Mdot
.69085 .34802 Mdot
.65737 .29101 Mdot
.40482 .80948 Mdot
.72435 .74603 Mdot
.32384 .24563 Mdot
.24465 .40946 Mdot
.7167 .5141 Mdot
.57016 .28214 Mdot
.53087 .15627 Mdot
.78023 .48238 Mdot
.64038 .27908 Mdot
.45854 .55458 Mdot
.41924 .32854 Mdot
.41933 .22052 Mdot
.6515 .42866 Mdot
.56615 .52532 Mdot
.15177 .53708 Mdot
.36167 .48685 Mdot
.26751 .24339 Mdot
.36169 .61549 Mdot
.23843 .67798 Mdot
.64324 .56722 Mdot
.49773 .5722 Mdot
.57242 .51559 Mdot
.29218 .56387 Mdot
.22888 .50055 Mdot
.82419 .52796 Mdot
.45085 .83122 Mdot
.57738 .67708 Mdot
.75952 .51865 Mdot
.79316 .61164 Mdot
.55468 .21302 Mdot
.494 .33459 Mdot
.80134 .54166 Mdot
.47312 .55662 Mdot
.60669 .75105 Mdot
.80922 .39168 Mdot
.33115 .55136 Mdot
.46343 .40635 Mdot
.73819 .45128 Mdot
.41382 .1926 Mdot
.65097 .20568 Mdot
.30489 .74319 Mdot
.414 .46225 Mdot
.34217 .62264 Mdot
.63605 .37636 Mdot
.5278 .18873 Mdot
.68294 .50798 Mdot
.25138 .60414 Mdot
.75957 .45689 Mdot
.18409 .34156 Mdot
.24045 .31372 Mdot
.22697 .33699 Mdot
.72334 .4969 Mdot
.28964 .47338 Mdot
.21951 .44705 Mdot
.64448 .28347 Mdot
.31774 .5564 Mdot
.81119 .49218 Mdot
.75278 .42744 Mdot
.31144 .78992 Mdot
.50486 .27709 Mdot
.74852 .62812 Mdot
.3932 .22472 Mdot
.38754 .37839 Mdot
.34444 .58321 Mdot
.71053 .4144 Mdot
.39165 .50255 Mdot
.37592 .64129 Mdot
.29212 .60542 Mdot
.24422 .56789 Mdot
.63804 .2772 Mdot
.45669 .29109 Mdot
.42504 .468 Mdot
.59343 .23407 Mdot
.32523 .49744 Mdot
.62872 .72255 Mdot
.61337 .71704 Mdot
.48267 .50104 Mdot
.60134 .64819 Mdot
.44364 .38962 Mdot
.53587 .541 Mdot
.58919 .53348 Mdot
.18586 .43501 Mdot
.72381 .57257 Mdot
.3177 .48985 Mdot
.2303 .65011 Mdot
.3139 .47413 Mdot
.35547 .17654 Mdot
.56159 .7824 Mdot
.41585 .23269 Mdot
.68661 .7142 Mdot
.64401 .77701 Mdot
.17653 .64126 Mdot
.26468 .31852 Mdot
.44063 .54434 Mdot
.31121 .5053 Mdot
.37633 .43444 Mdot
.6196 .66531 Mdot
.53996 .73868 Mdot
.33271 .29782 Mdot
.45122 .70176 Mdot
.67907 .33229 Mdot
.30147 .41284 Mdot
.74984 .61252 Mdot
.42704 .40102 Mdot
.47863 .14449 Mdot
.56825 .61564 Mdot
.14723 .45304 Mdot
.5577 .45055 Mdot
.56714 .25024 Mdot
.80453 .36658 Mdot
.30265 .73154 Mdot
.56444 .74808 Mdot
.75943 .69868 Mdot
.56614 .35017 Mdot
.42598 .46422 Mdot
.35205 .44097 Mdot
.71653 .3419 Mdot
.70167 .57218 Mdot
.67442 .47868 Mdot
.419 .61304 Mdot
.49529 .80373 Mdot
.41129 .7196 Mdot
.29196 .46531 Mdot
.37514 .51051 Mdot
.68264 .2945 Mdot
.22134 .55974 Mdot
.47306 .55413 Mdot
.54689 .21528 Mdot
.44285 .30958 Mdot
.30561 .41011 Mdot
.27472 .28036 Mdot
.78268 .44799 Mdot
.61293 .17606 Mdot
.60061 .33664 Mdot
.46977 .58614 Mdot
.21233 .55838 Mdot
.29585 .58825 Mdot
.34294 .28106 Mdot
.75885 .32533 Mdot
.7144 .47208 Mdot
.2311 .60898 Mdot
.7305 .38923 Mdot
.59293 .42361 Mdot
.51146 .60481 Mdot
.36757 .71849 Mdot
.2733 .75163 Mdot
.26737 .34577 Mdot
.33878 .75546 Mdot
.28277 .49163 Mdot
.43983 .71571 Mdot
.34746 .49508 Mdot
.65311 .66651 Mdot
.43925 .30397 Mdot
.53598 .76877 Mdot
.56539 .15868 Mdot
.76606 .3316 Mdot
.4296 .62187 Mdot
.61388 .58829 Mdot
.5646 .50106 Mdot
.51941 .3022 Mdot
.502 .52201 Mdot
.57648 .36841 Mdot
.47778 .46913 Mdot
.29013 .71947 Mdot
.30816 .56411 Mdot
.60361 .37755 Mdot
.51886 .16154 Mdot
.62237 .17978 Mdot
.42294 .15863 Mdot
.7102 .51756 Mdot
.29838 .44357 Mdot
.28835 .24654 Mdot
.38123 .27225 Mdot
.67911 .23729 Mdot
.3124 .25984 Mdot
.86514 .57809 Mdot
.49599 .20758 Mdot
.31634 .60674 Mdot
.48563 .81978 Mdot
.24125 .51479 Mdot
.81089 .4104 Mdot
.51928 .66563 Mdot
.62968 .66076 Mdot
.81606 .41833 Mdot
.1592 .64426 Mdot
.2577 .34414 Mdot
.24752 .58045 Mdot
.59556 .28639 Mdot
.46061 .4912 Mdot
.46654 .68604 Mdot
.48579 .38406 Mdot
.57272 .59165 Mdot
.57763 .75181 Mdot
.75185 .4394 Mdot
.55567 .26517 Mdot
.46643 .69061 Mdot
.68093 .37759 Mdot
.71143 .34906 Mdot
.78788 .50642 Mdot
.51596 .21284 Mdot
.33913 .29232 Mdot
.46125 .3986 Mdot
.30223 .48971 Mdot
.68575 .54439 Mdot
.57887 .71244 Mdot
.50535 .34906 Mdot
.55401 .74848 Mdot
.21832 .52069 Mdot
.31254 .20603 Mdot
.63997 .66938 Mdot
.78856 .41661 Mdot
.38265 .47212 Mdot
.27964 .57327 Mdot
.62884 .23956 Mdot
.33108 .72132 Mdot
.47368 .69506 Mdot
.3858 .39765 Mdot
.50696 .17128 Mdot
.2923 .66597 Mdot
.76385 .40416 Mdot
.1779 .49262 Mdot
.39043 .63703 Mdot
.25213 .38245 Mdot
.61936 .29811 Mdot
.31211 .697 Mdot
.29486 .41285 Mdot
.32131 .64224 Mdot
.48753 .63029 Mdot
.30338 .67096 Mdot
.8253 .46321 Mdot
.71716 .33062 Mdot
.37226 .23531 Mdot
.48448 .182 Mdot
.55887 .60411 Mdot
.7649 .42665 Mdot
.32753 .6464 Mdot
.48003 .66449 Mdot
.21092 .56974 Mdot
.51653 .15045 Mdot
.52224 .52429 Mdot
.67449 .43757 Mdot
.56865 .3993 Mdot
.40331 .28408 Mdot
.30158 .55982 Mdot
.61337 .56176 Mdot
.45217 .77374 Mdot
.34235 .41793 Mdot
.40693 .73797 Mdot
.52221 .70639 Mdot
.71245 .42834 Mdot
.35784 .508 Mdot
.28702 .39606 Mdot
.65606 .58722 Mdot
.53486 .70675 Mdot
.46928 .36333 Mdot
.66918 .4525 Mdot
.67162 .52319 Mdot
.25432 .36895 Mdot
.25133 .34557 Mdot
.55291 .21648 Mdot
.79681 .44221 Mdot
.30905 .59109 Mdot
.31034 .25969 Mdot
.23252 .49592 Mdot
.47182 .26381 Mdot
.3819 .75948 Mdot
.57401 .4182 Mdot
.65613 .66292 Mdot
.31593 .48526 Mdot
.53176 .19747 Mdot
.50659 .25795 Mdot
.6609 .42262 Mdot
.49549 .54742 Mdot
.64543 .24879 Mdot
.45619 .52753 Mdot
.80609 .3733 Mdot
.24303 .51388 Mdot
.72855 .46168 Mdot
.40132 .57373 Mdot
.61575 .53639 Mdot
.39582 .79908 Mdot
.60355 .18369 Mdot
.4563 .8217 Mdot
.60393 .47898 Mdot
.32917 .7453 Mdot
.23058 .42514 Mdot
.82242 .41808 Mdot
.72517 .44594 Mdot
.49871 .52178 Mdot
.42508 .40612 Mdot
.40815 .65064 Mdot
.51652 .72061 Mdot
.66718 .66345 Mdot
.35694 .28624 Mdot
.68904 .6177 Mdot
.54421 .76768 Mdot
.47467 .3464 Mdot
.19028 .51392 Mdot
.49315 .17747 Mdot
.46303 .31611 Mdot
.48861 .57276 Mdot
.64511 .72706 Mdot
.70604 .43734 Mdot
.76074 .75494 Mdot
.28102 .23378 Mdot
.56755 .40234 Mdot
.59728 .50981 Mdot
.68295 .47068 Mdot
.60635 .65519 Mdot
.33257 .30812 Mdot
.54738 .21135 Mdot
.35676 .5912 Mdot
.69915 .65635 Mdot
.32624 .67769 Mdot
.29204 .55494 Mdot
.65008 .4145 Mdot
.42245 .57323 Mdot
.33593 .18691 Mdot
.81291 .5267 Mdot
.30228 .57841 Mdot
.81327 .68345 Mdot
.34796 .71467 Mdot
.39848 .45193 Mdot
.67411 .27217 Mdot
.40416 .17253 Mdot
.70796 .49396 Mdot
.66305 .70297 Mdot
.24183 .35376 Mdot
.72211 .46472 Mdot
.73117 .37108 Mdot
.44375 .75692 Mdot
.4152 .74427 Mdot
.50567 .6399 Mdot
.64673 .77512 Mdot
.19694 .43868 Mdot
.36581 .25061 Mdot
.45492 .18074 Mdot
.54302 .78068 Mdot
.32556 .80092 Mdot
.60606 .17851 Mdot
.70487 .39227 Mdot
.46165 .70712 Mdot
.69355 .28598 Mdot
.64519 .48814 Mdot
.37764 .39566 Mdot
.55949 .77876 Mdot
.42844 .3373 Mdot
.6236 .78087 Mdot
.40667 .77912 Mdot
.73376 .39433 Mdot
.37278 .38199 Mdot
.53373 .52365 Mdot
.54397 .22214 Mdot
.49656 .77738 Mdot
.73958 .48653 Mdot
.70113 .66527 Mdot
.63548 .47203 Mdot
.57116 .2203 Mdot
.67914 .26135 Mdot
.50253 .51741 Mdot
.15859 .63677 Mdot
.37942 .19666 Mdot
.34725 .73747 Mdot
.55211 .43916 Mdot
.55876 .15212 Mdot
.46937 .5036 Mdot
.29469 .27392 Mdot
.81543 .45763 Mdot
.615 .70816 Mdot
.20756 .5418 Mdot
.57877 .40788 Mdot
.27407 .30212 Mdot
.4734 .24166 Mdot
.3821 .37758 Mdot
.58416 .74867 Mdot
.72301 .4833 Mdot
.491 .76786 Mdot
.63992 .44356 Mdot
.55565 .30079 Mdot
.30255 .47442 Mdot
.35157 .18698 Mdot
.62752 .39912 Mdot
.44003 .41897 Mdot
.59343 .45785 Mdot
.45514 .82665 Mdot
.78332 .69452 Mdot
.56447 .30754 Mdot
.28569 .66277 Mdot
.75885 .42996 Mdot
.66471 .30774 Mdot
.25996 .33134 Mdot
.38297 .88575 Mdot
.79675 .3526 Mdot
.38262 .4545 Mdot
.27329 .37495 Mdot
.7398 .50038 Mdot
.43155 .16042 Mdot
.68491 .74241 Mdot
.59867 .72827 Mdot
.46306 .84562 Mdot
.65516 .49428 Mdot
.47966 .37738 Mdot
.83669 .48938 Mdot
.61122 .18652 Mdot
.50914 .79737 Mdot
.53633 .15982 Mdot
.58166 .34521 Mdot
.55601 .44397 Mdot
.55546 .88753 Mdot
.54519 .18955 Mdot
.55939 .32999 Mdot
.42693 .82832 Mdot
.34335 .3983 Mdot
.49493 .36575 Mdot
.45384 .67409 Mdot
.77624 .4793 Mdot
.71983 .35895 Mdot
.4714 .14927 Mdot
.28769 .45979 Mdot
.55526 .75018 Mdot
.40637 .58628 Mdot
.57182 .51776 Mdot
.49959 .445 Mdot
.40144 .60157 Mdot
.6977 .35194 Mdot
.48685 .50541 Mdot
.39022 .56413 Mdot
.77614 .5321 Mdot
.85726 .49548 Mdot
.51517 .24475 Mdot
.42957 .63296 Mdot
.55495 .47697 Mdot
.4669 .30861 Mdot
.68139 .38178 Mdot
.66708 .33793 Mdot
.8207 .43865 Mdot
.84309 .36866 Mdot
.63774 .62524 Mdot
.60994 .38251 Mdot
.38007 .48865 Mdot
.35169 .28155 Mdot
.48517 .22125 Mdot
.34743 .56742 Mdot
.53543 .73328 Mdot
.58813 .38002 Mdot
.55968 .30218 Mdot
.42011 .60961 Mdot
.21809 .29472 Mdot
.4886 .40104 Mdot
.31598 .28278 Mdot
.66261 .22962 Mdot
.62575 .72452 Mdot
.54579 .25563 Mdot
.55073 .33644 Mdot
.21743 .4601 Mdot
.4608 .50072 Mdot
.49302 .4914 Mdot
.61744 .71847 Mdot
.45329 .16614 Mdot
.5092 .25792 Mdot
.3568 .24737 Mdot
.53122 .4062 Mdot
.73626 .56112 Mdot
.2373 .57195 Mdot
.24859 .32659 Mdot
.51846 .29373 Mdot
.67241 .22543 Mdot
.62139 .70378 Mdot
.69966 .61312 Mdot
.57562 .26936 Mdot
.35784 .19683 Mdot
.37493 .77795 Mdot
.46241 .22154 Mdot
.26794 .6795 Mdot
.39412 .69028 Mdot
.68175 .39824 Mdot
.57572 .68232 Mdot
.60485 .38242 Mdot
.32397 .39913 Mdot
.38241 .15018 Mdot
.24418 .33499 Mdot
.35727 .66339 Mdot
.57746 .69889 Mdot
.43892 .25918 Mdot
.55992 .51581 Mdot
.84526 .63529 Mdot
.73974 .70167 Mdot
.3302 .18988 Mdot
.70701 .32973 Mdot
.41054 .43587 Mdot
.29669 .629 Mdot
.47311 .43667 Mdot
.55863 .63621 Mdot
.43869 .16227 Mdot
.58497 .31587 Mdot
.40601 .77194 Mdot
.48018 .38372 Mdot
.24056 .6461 Mdot
.41665 .48948 Mdot
.61475 .59181 Mdot
.61122 .60105 Mdot
.362 .79015 Mdot
.6535 .24033 Mdot
.45433 .50106 Mdot
.83673 .6202 Mdot
.47251 .19552 Mdot
.56475 .1843 Mdot
.61385 .66023 Mdot
.27478 .72917 Mdot
.32784 .51833 Mdot
.40439 .48716 Mdot
.33595 .64645 Mdot
.61696 .46566 Mdot
.30994 .68766 Mdot
.67661 .31856 Mdot
.23275 .5374 Mdot
.4269 .62499 Mdot
.90378 .4217 Mdot
.70917 .38215 Mdot
.4876 .30332 Mdot
.35435 .72994 Mdot
.54528 .17051 Mdot
.6658 .54727 Mdot
.84745 .49783 Mdot
.54619 .56541 Mdot
.51584 .44912 Mdot
.4636 .28906 Mdot
.5778 .26062 Mdot
.33351 .68441 Mdot
.15629 .58512 Mdot
.80759 .5096 Mdot
.65772 .61241 Mdot
.52878 .56787 Mdot
.32262 .47849 Mdot
.37132 .47252 Mdot
.6689 .73875 Mdot
.84834 .54686 Mdot
.43996 .48125 Mdot
.53061 .18861 Mdot
.2015 .67195 Mdot
.7408 .36561 Mdot
.44166 .15508 Mdot
.31121 .51577 Mdot
.27068 .4554 Mdot
.68216 .37214 Mdot
.74644 .5562 Mdot
.61462 .61386 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0VOooool2o`000:kooooo000Looooo`03o`000?oooooooooo09Wooooo0_l0
002^ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0]?ooool2o`0009?ooooo000Looooo`03o`000?oooooo
oooo0;Cooooo1?l0002Aooooo`007?ooool00ol0003oooooooooo`2eooooo`?o0000TOooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo08oooooo0_l0002hooooo`007?ooool00ol0
003oooooooooo`23ooooo`;o00002_ooool2o`0000Oooooo0_l0000/ooooo`;o0000POooool001co
oooo00?o0000ooooooooool0Moooool2o`0000?ooooo0_l00005ooooo`;o00003Oooool2o`0000Co
oooo0_l00009ooooo`?o00008?ooool2o`00087ooooo000Looooo`03o`000?oooooooooo07Oooooo
0ol00002ooooo`;o00005?ooool2o`000004ooooool0003o0000o`0000_ooooo0ol0002Sooooo`00
7?ooool2o`0007Wooooo0_l0000?ooooo`Co00002?ooool3o`0000cooooo0_l0000<ooooo`;o0000
3?ooool2o`0000[ooooo0_l0001kooooo`007?ooool00ol0003oooooooooo`1mooooo`;o00002_oo
ool5o`0001_ooooo0_l00007ooooo`;o00003?ooool2o`0000[ooooo0_l0001kooooo`007?ooool0
0ol0003oooooooooo`1mooooo`;o00001oooool2o`0000Cooooo0_l00007ooooo`;o00000_ooool2
o`0000Sooooo0_l00004ooooo`?o000000?oooooo`000?l000001Oooool2o`0009?ooooo000Loooo
o`03o`000?oooooooooo08Kooooo1?l000000ooooooo0000o`000008ooooo`;o00000_ooool2o`00
00Sooooo1?l00003ooooo`;o000000?oooooo`000?l000001Oooool2o`0001[ooooo0_l00002oooo
o`;o0000Loooool001cooooo00?o0000ooooooooool0R?ooool2o`000003ooooool0003o000000;o
oooo0_l0000;ooooo`Oo00000_ooool2o`0000;ooooo0_l0000Uooooo`;o00000_ooool2o`0000Co
oooo0_l0001]ooooo`007?ooool00ol0003oooooooooo`2?ooooo`;o00000oooool2o`0000Kooooo
1ol00006ooooo`;o0000;oooool2o`0006gooooo000Looooo`03o`000?oooooooooo06Gooooo0_l0
000:ooooo`;o00008Oooool2o`0000Oooooo0_l00002ooooo`;o00002_ooool2o`0000Gooooo0_l0
002Cooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o00002_ooool2o`0000cooooo0ol0000;
ooooo`;o00003_ooool2o`0000;ooooo0_l00004ooooo`Co00000_ooool2o`0000Gooooo0_l00005
ooooo`;o00007?ooool2o`0006kooooo000Looooo`03o`000?oooooooooo073ooooo0_l00004oooo
o`;o00001oooool3o`0000_ooooo0_l0000=ooooo`;o00001_ooool2o`000003ooooool0003o0000
00;o00004?ooool2o`0000Kooooo0_l0000Dooooo`;o0000K_ooool001cooooo00?o0000oooooooo
ool0L?ooool2o`0000Cooooo0_l00003ooooo`;o00001Oooool2o`0000Cooooo0_l00006ooooo`;o
00002_ooool2o`0000Kooooo1_l00004ooooo`;o000000?oooooo`000?l000003?ooool6o`000003
ooooool0003o0000087ooooo000Looooo`03o`000?oooooooooo07Kooooo0_l00003ooooo`;o0000
1Oooool2o`0000Cooooo0_l00006ooooo`;o00002?ooool2o`0000[ooooo1?l00004ooooo`;o0000
00?oooooo`000?l000000ol00009ooooo`Co00000oooool2o`0000Gooooo0_l0001jooooo`007?oo
ool00ol0003oooooooooo`1Yooooo`;o00000oooool2o`0000Kooooo0_l0000Cooooo`;o00002_oo
ool2o`000003ooooool0003o000001Oooooo0ol0000:ooooo`;o000000?oooooo`000?l000002?oo
ool2o`0007[ooooo000Looooo`03o`000?oooooooooo06Sooooo0ol00003ooooo`;o00000oooool2
o`0000?ooooo0_l0000:ooooo`;o00001Oooool2o`0000?ooooo0_l00005ooooo`;o00003oooool3
o`0000;ooooo0_l00007ooooo`;o00000oooool2o`0000Kooooo0_l00024ooooo`0000Koooooonk^
k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0J?oo
ool2o`0000Wooooo0_l00003ooooo`;o00002Oooool3o`0000[ooooo0_l00008ooooo`;o00003?oo
ool3o`0000;ooooo0_l00007ooooo`Co000000?oooooo`000?l00000:?ooool2o`0006;ooooo0000
1_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01_ooool00ol0003oooooooooo`1aooooo`;o000000?oooooo`000?l000000_ooool2o`0000Wo
oooo0_l0000Aooooo`;o00000_ooool2o`0001cooooo0_l00005ooooo`Co00001oooool2o`0001Wo
oooo0_l0001Rooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0JOooool2o`0000Kooooo1Ol00002ooooo`;o0000
5_ooool2o`0000Cooooo0_l0000Aooooo`;o00005?ooool4o`000003ooooool0003o000000;o0000
0_ooool2o`0000Cooooo0_l0001gooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooooooo
o`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0001Rooooo`;o00000_ooool2o`000003ooooool0
003o000000Sooooo0_l0000Jooooo`?o00005oooool2o`0001;ooooo0_l00005ooooo`Co00002?oo
ool2o`0007Oooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oMgMg
ofIVI_ooool01Oooool00ol0003oooooooooo`1Pooooo`Co00000_ooool2o`0001Sooooo0_l00007
ooooo`;o00001?ooool2o`0000gooooo0_l00002ooooo`;o00006Oooool2o`000003ooooool0003o
000000?ooooo0ol00008ooooo`;o00001Oooool2o`00073ooooo00000ooooooo410@ooooo`02oooo
o`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Poooo
o`Co00003?ooool2o`0000Cooooo0_l00008ooooo`;o00001Oooool4o`0000;ooooo0_l0000;oooo
o`;o000000Coooooo`000?l0003o00000_ooool2o`0000kooooo0ol0000;ooooo`;o00000oooool3
o`0000Gooooo0_l000000ooooooo0000o`000005ooooo`;o0000L?ooool00006oooooomgMgOoV9RH
oooooonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
L?ooool2o`0000Cooooo0_l0000?ooooo`;o00001?ooool2o`0000;ooooo0_l00007ooooo`;o0000
00?oooooo`000?l000003oooool2o`0000;ooooo0ol0000Hooooo`;o0000N_ooool00006ooooooo^
k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000oooo
ooooool0N_ooool2o`0001Gooooo0_l00004ooooo`;o00002oooool2o`0000Oooooo1Ol0000Doooo
o`?o00003?ooool2o`0007;ooooo000Looooo`03o`000?oooooooooo06Kooooo0_l00005ooooo`;o
00002?ooool2o`000004ooooool0003o0000ooooo`;o00006?ooool2o`0000Kooooo0_l00003oooo
o`;o00001oooool6o`0001?ooooo0ol0000<ooooo`;o0000L_ooool001cooooo00?o0000oooooooo
ool0I_ooool2o`0000Gooooo0_l00008ooooo`;o00001?ooool2o`0000Gooooo0_l0000<ooooo`;o
00001_ooool2o`0000?ooooo1?l00004ooooo`;o00001oooool3o`0000?ooooo0_l0000>ooooo`?o
00000_ooool4o`0007[ooooo000Looooo`03o`000?oooooooooo06cooooo0_l0000Fooooo`;o0000
0oooool2o`0000Oooooo0_l00002ooooo`;o00000_ooool2o`0000Gooooo0_l00004ooooo`;o0000
1?ooool2o`0000Cooooo0_l000000ooooooo0000o`00000Cooooo`Co00003Oooool2o`0006_ooooo
000Looooo`03o`000?oooooooooo05[ooooo0_l00009ooooo`;o00001Oooool2o`0000Kooooo0_l0
0006ooooo`?o00002_ooool2o`0000_ooooo0_l0000Eooooo`;o00001?ooool2o`0000oooooo0_l0
000:ooooo`;o00001Oooool2o`0000?ooooo0_l0001[ooooo`007?ooool00ol0003oooooooooo`1J
ooooo`;o00002Oooool2o`0000Cooooo0_l00007ooooo`;o00001_ooool3o`0000Cooooo0_l00004
ooooo`;o00003Oooool2o`0000?ooooo0_l00007ooooo`;o00003Oooool2o`0000Cooooo0_l00007
ooooo`;o00002_ooool2o`000003ooooool0003o000000;ooooo0_l0001`ooooo`007?ooool00ol0
003oooooooooo`1Hooooo`;o00004Oooool2o`0001Kooooo0_l00003ooooo`?o00000oooool4o`00
00Kooooo0_l00003ooooo`;o00000oooool2o`0000;ooooo0_l0000=ooooo`;o00001?ooool2o`00
00Cooooo1?l0000>ooooo`;o0000M?ooool001cooooo00?o0000ooooooooool0Eoooool3o`0000Oo
oooo0_l0000=ooooo`;o00000oooool2o`0000cooooo0_l00003ooooo`?o00000oooool4o`0000[o
oooo0_l00004ooooo`;o00006Oooool2o`0000;ooooo1?l0000=ooooo`;o0000MOooool001cooooo
00?o0000ooooooooool0E_ooool4o`0000Oooooo0_l00006ooooo`;o00001Oooool2o`0000?ooooo
0_l00006ooooo`Go00001oooool2o`00017ooooo0_l0000Oooooo`;o00002Oooool2o`0000Sooooo
1?l00003ooooo`;o00000oooool2o`0001Gooooo0_l0001Booooo`007?ooool00ol0003ooooooooo
o`1Fooooo`;o00004Oooool2o`0000[ooooo0_l00004ooooo`Oo00001Oooool2o`0000gooooo0_l0
000Xooooo`;o00001_ooool2o`0000Gooooo0ol00002ooooo`?o00000_ooool4o`000004ooooool0
003o0000o`0001Cooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00002_oo
ool2o`0000Cooooo0_l0000Dooooo`;o00002?ooool7o`0000[ooooo0_l00009ooooo`;o000000?o
ooooo`000?l000002_ooool2o`0000kooooo0_l000000ooooooo0000o`00000:ooooo`?o00000ooo
ool2o`0000;ooooo1?l00002ooooo`Co0000I_ooool001cooooo00?o0000ooooooooool0Doooool2
o`0000Gooooo0_l00003ooooo`;o00001?ooool2o`0000Wooooo0_l00003ooooo`;o00003_ooool2
o`0000;ooooo0ol00003ooooo`;o00001Oooool3o`0000Sooooo0_l000000ooooooo0000o`00000:
ooooo`;o00001?ooool2o`0000Sooooo0_l000000ooooooo0000o`000009ooooo`;o00004Oooool2
o`0006Kooooo000Looooo`;o0000Foooool2o`0000Gooooo0_l00002ooooo`?o00002?ooool2o`00
0003ooooool0003o000000;o00000oooool2o`0001?ooooo0_l00006ooooo`;o00000_ooool2o`00
00Oooooo1?l00005ooooo`;o00001Oooool4o`0001Kooooo0_l00002ooooo`;o00001Oooool2o`00
06kooooo000Looooo`03o`000?oooooooooo067ooooo0_l00003ooooo`;o00002oooool5o`0000;o
oooo0_l0000=ooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00001oooool4o`0000Go
oooo0_l00005ooooo`;o00006?ooool2o`0000;ooooo0_l00005ooooo`;o0000K_ooool001cooooo
00?o0000ooooooooool0K?ooool2o`0000Oooooo0ol0000;ooooo`;o00000_ooool4o`0000[ooooo
0_l00006ooooo`;o00000_ooool3o`000003ooooool0003o000000Oooooo0_l00005ooooo`;o0000
5oooool2o`0000Wooooo1?l000000ooooooo0000o`000002ooooo`;o0000IOooool001cooooo00?o
0000ooooooooool0GOooool2o`0000;ooooo0ol00008ooooo`;o00001oooool3o`0000Oooooo0_l0
0002ooooo`;o00000_ooool2o`0000;ooooo0_l0000@ooooo`;o000000?oooooo`000?l000000_l0
000:ooooo`;o00001Oooool2o`000003ooooool0003o000001Cooooo0_l00009ooooo`Co000000?o
ooooo`000?l000000_ooool2o`0006Gooooo000Looooo`03o`000?oooooooooo05Oooooo1?l00002
ooooo`;o00000_ooool4o`00017ooooo1?l00005ooooo`;o00001Oooool2o`0000?ooooo0_l00009
ooooo`;o00002?ooool2o`0000cooooo0_l00008ooooo`;o00005oooool2o`0000Kooooo1?l00003
ooooo`;o00001Oooool2o`00063ooooo000Looooo`03o`000?oooooooooo05Oooooo1?l00003oooo
o`;o00000oooool2o`0000Wooooo0_l00005ooooo`Go00003?ooool2o`0000kooooo0_l0000Eoooo
o`;o00000_ooool2o`0001Sooooo0_l00004ooooo`;o00003Oooool2o`0000;ooooo0_l000000ooo
oooo0000o`00001Pooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o00002oooool2o`000003
ooooool0003o000000;o00000oooool2o`0000Gooooo0_l00008ooooo`;o00001oooool3o`0001_o
oooo1_l00004ooooo`;o00004_ooool2o`0001Oooooo1?l0001Qooooo`007?ooool00ol0003ooooo
ooooo`1Looooo`;o00003Oooool2o`000003ooooool0003o000000;o00001_ooool2o`0000;ooooo
0_l00008ooooo`;o00001?ooool6o`0001Wooooo0_l00002ooooo`;o00001_ooool2o`0001_ooooo
0_l000000ooooooo0000o`00000=ooooo`;o00006Oooool2o`0004Kooooo000Looooo`03o`000?oo
oooooooo05cooooo0_l0000=ooooo`;o000000?oooooo`000?l000002?ooool2o`0001;ooooo0ol0
0003ooooo`;o00003oooool2o`0000Kooooo0_l0000=ooooo`Co000000?oooooo`000?l000004Ooo
ool4o`000003ooooool0003o000002Sooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`1[
ooooo`;o000000?oooooo`000?l000008_ooool2o`0000cooooo0_l000000ooooooo0000o`00000E
ooooo`Co000000?oooooo`000?l000001oooool2o`000004ooooool0003o0000o`0000Cooooo0ol0
0008ooooo`;o00003?ooool2o`0005cooooo000Looooo`03o`000?oooooooooo05Kooooo0_l0000;
ooooo`;o00001oooool7o`0000_ooooo0_l00006ooooo`;o00006?ooool2o`0000[ooooo0_l00007
ooooo`;o00002_ooool2o`0000Gooooo0_l000001?oooooo0000o`000?l00005ooooo`;o00002?oo
ool2o`0000[ooooo1Ol0001Kooooo`007?ooool00ol0003oooooooooo`1Fooooo`;o00002oooool2
o`0000Oooooo0_l000000ooooooo0000o`000002o`0000_ooooo0ol00005ooooo`;o00005Oooool2
o`000003ooooool0003o000000[ooooo0ol00006ooooo`;o00002_ooool3o`0000Wooooo0ol00009
ooooo`;o00000_ooool3o`0000Oooooo1?l000000ooooooo0000o`00001Kooooo`007?ooool00ol0
003oooooooooo`1@ooooo`;o00005oooool2o`0000Gooooo0_l0000=ooooo`Co00004?ooool2o`00
00Sooooo0_l000000ooooooo0000o`00000;ooooo`?o00003_ooool2o`0000;ooooo0_l00004oooo
o`;o000000?oooooo`000?l000000ol00009ooooo`;o00000_ooool3o`0000?ooooo0_l00002oooo
o`;o0000H?ooool001cooooo00?o0000ooooooooool0D?ooool2o`0000Kooooo0_l0000?ooooo`?o
00001?ooool2o`0000?ooooo0_l00009ooooo`?o00003_ooool4o`0000Wooooo0_l0000>ooooo`;o
00001?ooool2o`0000Sooooo0_l00008ooooo`;o000000Coooooo`000?l0003ooooo0_l00002oooo
o`;o00003oooool2o`0000Kooooo1?l0001Jooooo`007?ooool00ol0003oooooooooo`13ooooo`;o
00004oooool3o`0000oooooo0_l00004ooooo`?o00000_ooool2o`0001[ooooo0_l000000ooooooo
0000o`000008ooooo`;o00001Oooool2o`0000gooooo0_l0000Looooo`;o00001_ooool2o`0000oo
oooo1?l0001Jooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00004Oooool2o`000003oooo
ool0003o000000_ooooo1?l00007ooooo`;o00006Oooool2o`0000Kooooo0_l00003ooooo`Go0000
1oooool2o`0001kooooo0_l00003ooooo`;o00003_ooool2o`0006gooooo000Looooo`;o0000Eooo
ool2o`0000kooooo1?l00004ooooo`;o00000oooool2o`0000Cooooo0_l0000Aooooo`;o000000?o
ooooo`000?l000002?ooool5o`0000?ooooo0_l0000>ooooo`;o00004_ooool2o`0000?ooooo0_l0
00000ooooooo0000o`000002ooooo`;o00006Oooool2o`0005_ooooo000Looooo`03o`000?oooooo
oooo05Gooooo0_l0000Gooooo`;o00000oooool2o`0000Cooooo0_l0000@ooooo`;o00000_ooool2
o`0000Wooooo0ol00004ooooo`;o00000_ooool3o`0000Wooooo0ol00005ooooo`;o00004?ooool4
o`0000;ooooo0_l00004ooooo`;o00002_ooool2o`0000Oooooo0_l0001Kooooo`007?ooool00ol0
003oooooooooo`1Eooooo`;o0000<oooool3o`0000gooooo0ol00004ooooo`;o00000_ooool3o`00
00?ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o00004?ooool2o`00
00Gooooo1?l000000ooooooo0000o`00000:ooooo`;o00001oooool2o`0005_ooooo000Looooo`03
o`000?oooooooooo06Sooooo0_l0000Pooooo`Co00001_ooool2o`0000Kooooo0_l00006ooooo`Co
00000oooool6o`0000?ooooo0_l0000:ooooo`;o00004?ooool4o`0000Gooooo0_l000001?oooooo
0000o`000?ooool2o`0000Kooooo0_l00006ooooo`;o0000E_ooool001cooooo00?o0000oooooooo
ool0B_ooool2o`0000Oooooo0_l0000Cooooo`;o00008_ooool3o`0000Gooooo0_l00006ooooo`;o
000000Coooooo`000?l0003ooooo2?l000000ooooooo0000o`000002o`0000gooooo0_l00002oooo
o`;o00004Oooool2o`0000Kooooo1Ol000000ooooooo0000o`000006ooooo`;o000000?oooooo`00
0?l000000oooool3o`0005Gooooo000Looooo`03o`000?oooooooooo04[ooooo0_l00005ooooo`Co
0000=oooool3o`0000Cooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo
0000o`000002ooooo`Co00001Oooool2o`0000;ooooo0_l00004ooooo`Go00000_ooool2o`0001[o
oooo0_l00009ooooo`;o00000_ooool3o`0000Cooooo0_l0001Eooooo`007?ooool00ol0003ooooo
ooooo`1Aooooo`?o00001_ooool3o`0003Gooooo1?l000000ooooooo0000o`000002ooooo`;o0000
0oooool4o`0000;ooooo0_l00007ooooo`;o00000_ooool2o`000003ooooool0003o000000Co0000
1?ooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000Kooooo0_l000000ooooooo0000
o`00000=ooooo`;o00000_ooool2o`0000Kooooo0_l0001Dooooo`007?ooool00ol0003ooooooooo
o`1Booooo`;o00001_ooool4o`0003Cooooo1?l00004ooooo`;o00001?ooool4o`000003ooooool0
003o000000?o00001_ooool2o`0000;ooooo1ol00003ooooo`;o00001?ooool2o`0000?ooooo0_l0
0002ooooo`;o00001_ooool2o`000003ooooool0003o000000;ooooo0_l0000=ooooo`;o00000_oo
ool2o`0000;ooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`1Looooo`;o0000>_ooool4
o`0000;ooooo0ol000001?oooooo0000o`000?ooool5o`0000Gooooo0ol00002ooooo`Oo00000ooo
ool2o`0000;ooooo0_l00003ooooo`;o00003Oooool2o`0000Cooooo0_l0000Aooooo`;o000000Co
ooooo`000?l0003o0000E?ooool001cooooo00?o0000ooooooooool0C?ooool4o`0003Cooooo0_l0
000=ooooo`;o00000_ooool:o`000003ooooool0003o000000;ooooo0_l00002ooooo`Co000000?o
ooooo`000?l000001?ooool6o`0000Oooooo0_l00003ooooo`?o00003?ooool2o`0001[ooooo0ol0
000Jooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0?Oooool2o`0000Gooooo0_l00006
ooooo`Co000000?oooooo`000?l00000<Oooool2o`0000Sooooo0_l00003ooooo`;o00000_ooool2
o`000003ooooool0003o000000Co00000ooooolAo`0000Gooooo1?l0000;ooooo`Co00002Oooool3
o`000004ooooool0003o0000ooooo`;o00001?ooool2o`000003ooooool0003o000000Wooooo0_l0
0002ooooo`?o00006?ooool2o`0003Sooooo000Looooo`03o`000?oooooooooo03gooooo0_l00004
ooooo`Go00001?ooool3o`0000;ooooo0ol0000jooooo`;o00001_ooool2o`0000;ooooo0_l00000
1?oooooo0000o`000?l00002oooooa?o00000oooool2o`000003ooooool0003o000000gooooo0_l0
0009ooooo`;o00000_ooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`00
0009ooooo`;o00000_ooool5o`00053ooooo000Looooo`03o`000?oooooooooo04?ooooo0_l00000
0ooooooo0000o`000004ooooo`;o00000_ooool4o`0000_ooooo0_l0000Vooooo`;o00003Oooool2
o`000003ooooool0003o000000ko000000?oooooo`000?l000001Ol000001Ooooooo0000o`000?l0
003ooooo00Co000000?oooooo`000?l000000_ooool3o`0000Cooooo0_l000000ooooooo0000o`00
000:ooooo`;o00004Oooool2o`0000[ooooo0_l000000ooooooo0000o`000004ooooo`;o0000B_oo
ool001cooooo00?o0000ooooooooool0>?ooool2o`0000cooooo0_l000000ooooooo0000o`000005
ooooo`Co00000oooool2o`0000Kooooo0_l0000Vooooo`;o000000?oooooo`000?l000003Oooool=
o`000003ooooool0003o000000co000000?oooooo`000?l000001Ol00002ooooo`?o00000_ooool4
o`000003ooooool0003o000000[ooooo0_l00009ooooo`;o00000_ooool2o`0000;ooooo0_l0000@
ooooo`;o000000?oooooo`000?l00000B_ooool001cooooo00?o0000ooooooooool0>?ooool2o`00
00oooooo0_l00005ooooo`Co00000oooool2o`0000Wooooo0ol0000Oooooo`;o00001?ooool2o`00
00Wooooo0_l00002ooooo`Oo00000_oooolAo`000003ooooool0003o000000Go000000?oooooo`00
0?l000001_ooool2o`000003ooooool0003o000000gooooo0_l00008ooooo`;o00000_ooool3o`00
00Sooooo0_l00007ooooo`Co0000COooool001cooooo00?o0000ooooooooool0BOooool2o`0000?o
oooo1?l000000ooooooo0000o`000002o`0000_ooooo0ol0000Oooooo`;o00001_ooool2o`0000Go
oooo7Ol000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000;o000000?oooooo`00
0?l000002Oooool2o`0000gooooo1?l00006ooooo`;o00000oooool2o`0000Gooooo0_l000000ooo
oooo0000o`000002o`0000Cooooo0ol000000ooooooo0000o`00001<ooooo`007?ooool2o`0004[o
oooo1?l000000ooooooo0000o`000003ooooo`Co0000=Oooool2o`0000;ooooo0_l000001?oooooo
0000o`000?ooool5o`000003ooooool0003o000001go000000?oooooo`000?l000004Oooool2o`00
00Oooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l00007ooooo`;o00000oooool2
o`0000Cooooo0_l000001?oooooo0000o`000?l0001<ooooo`007?ooool00ol0003oooooooooo`0o
ooooo`;o00002_ooool2o`0001Sooooo0_l0000Uooooo`;o000000Coooooo`000?l0003o00001_oo
ool3o`000004ooooool0003o0000oooooaWo00001?ooool2o`00017ooooo0_l0000<ooooo`Co0000
0_ooool2o`0000Cooooo0_l000000ooooooo0000o`000005ooooo`;o00001Oooool2o`0000?ooooo
0_l0000Eooooo`;o0000<Oooool001cooooo00?o0000ooooooooool0?oooool2o`0000[ooooo0_l0
000Aooooo`;o00000_ooool2o`000003ooooool0003o0000027ooooo0_l00002ooooo`;o000000Co
ooooo`000?l0003ooooo0_l00008ooooo`Wo00000_ooool?o`0000Gooooo0ol0000Qooooo`;o0000
2?ooool2o`000003ooooool0003o000000Gooooo0_l00009ooooo`?o00005Oooool2o`00037ooooo
000Looooo`03o`000?oooooooooo03gooooo0_l0000Fooooo`;o00001oooool2o`0000;ooooo0_l0
000Tooooo`;o00000oooool7o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l00000
7?l00002ooooo`Go00009_ooool2o`0000?ooooo0_l0000Aooooo`;o0000BOooool001cooooo00?o
0000ooooooooool0?Oooool2o`0000?ooooo0_l000000ooooooo0000o`00000>ooooo`;o0000<ooo
ool2o`000003ooooool0003o000000Co00000_ooool<o`000003ooooool0003o000001Go000000?o
ooooo`000?l000001?l00004ooooo`;o00002_ooool2o`0001Cooooo0_l00003ooooo`;o00003_oo
ool4o`0004[ooooo000Looooo`03o`000?oooooooooo04;ooooo0_l000000ooooooo0000o`00000c
ooooo`?o00003?ooool3o`0000Cooooo1?l000001?oooooo0000o`000?l00002ooooob?o000000?o
ooooo`000?l000001?ooool2o`0000[ooooo0_l00004ooooo`;o00003_ooool3o`0000Cooooo0_l0
000<ooooo`Co0000B_ooool001cooooo00?o0000ooooooooool0AOooool2o`0000Sooooo1?l00004
ooooo`;o00004Oooool3o`0000?ooooo0_l00008ooooo`?o00000oooool2o`0000Oooooo1?l00003
ooooo`Co000000?oooooo`000?l000000ol000000ooooooo0000o`00000No`0000?ooooo0_l0000F
ooooo`;o00003oooool2o`0000Cooooo0_l0000>ooooo`;o00000oooool2o`0000[ooooo0_l0000i
ooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00002?ooool5o`0000;ooooo0ol0000>oooo
o`;o000000Coooooo`000?l0003o00000oooool2o`000004ooooool0003o0000o`0000Gooooo0_l0
0003ooooo`;o00002Oooool4o`0000;ooooo0_l00002ooooobOo000000?oooooo`000?l000002Ooo
ool2o`00013ooooo0_l0000>ooooo`;o00002Oooool2o`0000Cooooo1?l00003ooooo`;o00002_oo
ool2o`0003Wooooo000Looooo`03o`000?oooooooooo03_ooooo0_l0000>ooooo`;o00001Oooool2
o`000004ooooool0003o0000o`0000oooooo0_l0000:ooooo`?o00005oooool2o`0000Kooooo:_l0
0007ooooo`Co00004?ooool2o`0000Wooooo0_l00003ooooo`;o00000_ooool2o`000003ooooool0
003o000000;ooooo0_l00004ooooo`;o00000_ooool2o`000003ooooool0003o000000;o0000@ooo
ool001cooooo00?o0000ooooooooool0>oooool2o`0000Cooooo1?l00006ooooo`;o00000oooool2
o`0000?ooooo0_l0000Gooooo`;o00002?ooool4o`00013ooooo0_l00003ooooo`?o00000_oooolW
o`0000?ooooo0_l00004ooooo`?o00000_ooool2o`0000Gooooo0_l00005ooooo`;o00001oooool2
o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000003o`0000Gooooo0_l00005
ooooo`;o000000?oooooo`000?l000000_l00013ooooo`007?ooool00ol0003oooooooooo`0^oooo
o`;o00003?ooool3o`0000;ooooo1?l0000;ooooo`;o00007?ooool2o`0000;ooooo1?l00002oooo
o`Go00003oooool2o`0000?ooooo;_l000000ooooooo0000o`000004ooooo`?o00000_ooool2o`00
00;ooooo0_l000000ooooooo0000o`000005ooooo`?o00001_ooool2o`000003ooooool0003o0000
00Cooooo0_l00003ooooo`;o00001?ooool4o`0000Kooooo0_l00017ooooo`007?ooool00ol0003o
ooooooooo`0^ooooo`;o00003?ooool3o`0000oooooo0_l0000@ooooo`;o00001Oooool2o`000003
ooooool0003o000000;o00001?ooool6o`0000?ooooo0_l0000>ooooo`;o00001Oooool4o`0000;o
oooo3?l000000ooooooo0000o`000002o`0000?ooooo3Ol00002ooooo`Co00000_ooool3o`0000[o
oooo0ol00002ooooo`;o00001?ooool3o`0000Oooooo0_l0000Aooooo`;o00002?ooool2o`000003
ooooool0003o000004Cooooo000Looooo`03o`000?oooooooooo03_ooooo0_l00003ooooo`;o0000
0_ooool2o`0000Cooooo0_l00002ooooo`;o00004?ooool2o`0000Gooooo0_l000000ooooooo0000
o`000002o`0000Cooooo0_l000000ooooooo0000o`000003o`0000cooooo0_l00003ooooo`;o0000
1?oooolTo`000003ooooool0003o000000?o00001_ooool3o`0000[ooooo0_l00003ooooo`;o0000
00Coooooo`000?l0003ooooo0ol00007ooooo`;o00004Oooool2o`0000_ooooo0_l00014ooooo`00
7?ooool00ol0003oooooooooo`0iooooo`Co00000oooool2o`0000;ooooo0_l00004ooooo`;o0000
1oooool2o`0000Sooooo0_l00003ooooo`;o00004oooool5o`0000[ooooo0_l00003ooooo`?o0000
00?oooooo`000?l000002Ol00002oooooaoo00006oooool2o`000004ooooool0003o0000o`0000go
oooo0_l0000Gooooo`;o0000AOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q
8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo03Gooooo0_l00002oooo
o`;o00003oooool2o`0000Oooooo0_l00002ooooo`;o00001?ooool4o`000003ooooool0003o0000
00Gooooo0_l00008ooooo`;o00000oooool4o`00013ooooo0_l000000ooooooo0000o`000003oooo
o`Oo000000?oooooo`000?l000008_l000000ooooooo0000o`00000>ooooo`;o00001?ooool4o`00
00Kooooo0_l000000ooooooo0000o`000003ooooo`?o00004_ooool3o`000004ooooool0003o0000
o`0004Cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0=Oooool2o`0000Wooooo0_l0000@ooooo`;o00000ooo
ool2o`000003ooooool0003o000000;ooooo1Ol00006ooooo`;o00002?ooool2o`0000;ooooo0_l0
000Cooooo`?o00000_ooool2o`000003ooooool0003o000000Go000000?oooooo`000?l000008_l0
00000ooooooo0000o`000004ooooo`;o00002?ooool2o`0000Cooooo1Ol00005ooooo`;o000000?o
ooooo`000?l000000_ooool5o`00017ooooo0ol000000ooooooo0000o`000002o`0004?ooooo0000
0ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006ooooo`03o`000?oooooo
oooo03?ooooo0_l0000;ooooo`;o00000_ooool2o`0000cooooo0_l00006ooooo`?o00001?ooool2
o`0000?ooooo0_l00004ooooo`Co00001?ooool2o`000004ooooool0003o0000ooooo`;o00001Ooo
ool2o`0000Kooooo0_l000001?oooooo0000o`000?l00002ooooo`Wo00000_oooolUo`0000Cooooo
1Ol00009ooooo`;o00001?ooool3o`0000Sooooo0_l00002ooooo`;o000000?oooooo`000?l00000
3oooool2o`0000?ooooo1Ol00013ooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooooooo
o`09ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0000cooooo`;o00002oooool2o`0000;ooooo
0_l00009ooooo`?o00002Oooool3o`0000?ooooo0_l00003ooooo`;o00001?ooool4o`000004oooo
ool0003o0000ooooo`;o00001?ooool2o`0000Gooooo0_l000001?oooooo0000o`000?ooool4o`00
00;ooooo1ol00002ooooobSo000000?oooooo`000?l000001?ooool2o`000003ooooool0003o0000
00Wooooo0_l00005ooooo`;o00004Oooool2o`0000Wooooo0_l00002ooooo`;o00000oooool4o`00
04Cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoo
oooo00001oooool00ol0003oooooooooo`10ooooo`?o00001_ooool2o`0000Cooooo0ol00002oooo
o`;o00000oooool2o`000003ooooool0003o000000;ooooo0ol0000>ooooo`;o00004Oooool6o`00
00?ooooo2?l000000ooooooo0000o`00000Lo`000004ooooool0003o0000o`0000;ooooo1?l00000
0ooooooo0000o`000003ooooo`;o00003Oooool2o`0001Sooooo0_l00005ooooo`;o000000Cooooo
o`000?l0003o0000Coooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool0
0omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo047ooooo0_l00006ooooo`;o000000?ooooo
o`000?l000000_ooool2o`0000;ooooo0_l00003ooooo`Ko000000?oooooo`000?l000001?l00000
0ooooooo0000o`000002o`0000;ooooo0_l0000@ooooo`;o00001Oooool4o`0000Oooooo1?l00000
0ooooooo0000o`00000Vo`000003ooooool0003o000000?ooooo0ol0000=ooooo`;o00005Oooool2
o`0000Oooooo0_l000000ooooooo0000o`000006ooooo`;o00003Oooool2o`0003Wooooo00001_oo
ooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l000001oooool00ol0003ooooooooo
o`0iooooo`;o00002oooool2o`0000Cooooo0_l0000<oooooa7o000000Goooooo`000?l0003o0000
ooooo`05o`0000[ooooo0_l00007ooooo`;o00002oooool4o`000003ooooool0003o000001Go0000
00?oooooo`000?l000001_l00006ooooo`;o00000oooool2o`0000gooooo0_l0000Eooooo`;o0000
1?ooool2o`0000cooooo0_l00003ooooo`;o00002?ooool2o`0003Wooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`0iooooo`;o
00002oooool2o`0001Cooooo6Ol0000Jooooo`;o00001?ooool4o`000003ooooool0003o0000027o
00000oooool2o`0000gooooo0_l00007ooooo`;o00002Oooool2o`0000Gooooo0_l00005ooooo`;o
00000oooool2o`0000Gooooo1?l00003ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0
Foooool;o`0000;ooooo3Ol00003ooooo`;o00003?ooool6o`0000?ooooo0_l00003ooooo`Go0000
1?oooolRo`0000?ooooo1?l00009ooooo`;o00001oooool2o`0000Wooooo0_l00002ooooo`Go0000
2_ooool2o`0000Cooooo0ol00006ooooo`Co0000@?ooool001cooooo00?o0000ooooooooool0B?oo
ool2o`0000[ooooo0_l00003ooooo`Co00000_oooolGo`0000;ooooo0_l0000:ooooo`Wo00001ooo
ool3o`0000?ooooo0_l00002oooooa_o000000Coooooo`000?l0003ooooo0_l00003ooooo`Co0000
8Oooool4o`0000Gooooo0_l00006ooooo`;o00000_ooool2o`0000Oooooo1?l0000Iooooo`;o0000
9Oooool001cooooo00?o0000ooooooooool0B?ooool2o`0000[ooooo0_l00003ooooo`Co00000_oo
ool2o`000003ooooool0003o000001Go000000?oooooo`000?l000001_ooool5o`0000Cooooo0_l0
0004ooooo`;o00000_ooool3o`0000;ooooo0_l00002oooooako000000?oooooo`000?l000004Ooo
ool2o`000003ooooool0003o000001Cooooo0_l000000ooooooo0000o`000002ooooo`;o00001_oo
ool2o`0000oooooo0_l0000Gooooo`;o00009Oooool001cooooo00?o0000ooooooooool0A_ooool3
o`000003ooooool0003o000000Oooooo0_l00004ooooo`;o00000ooooolBo`0000;ooooo1ol00000
0ooooooo0000o`000006ooooo`;o000000Coooooo`000?l0003ooooo0_l00007ooooo`;o00000ooo
ool4o`0000Cooooo7_l000000ooooooo0000o`00000Aooooo`;o000000?oooooo`000?l000005ooo
ool2o`0000?ooooo1_l00004ooooo`;o00003?ooool2o`0003kooooo000Looooo`03o`000?oooooo
oooo04Kooooo0ol000000ooooooo0000o`000007ooooo`;o00001?ooool2o`0000?ooooo4_l00002
ooooo`Oo00000_ooool2o`0000Sooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l00005
ooooo`Oo000000?oooooo`000?l000007?l00007ooooo`;o00002oooool2o`0001;ooooo0_l0000;
ooooo`Ko00000oooool3o`0004cooooo000Looooo`03o`000?oooooooooo05Oooooo0_l00003oooo
oago000000Coooooo`000?l0003o00002?ooool2o`0000?ooooo0_l00003ooooo`;o00001OoooolC
o`0000;ooooo1?l00002ooooo`?o000000?oooooo`000?l000000ol00009ooooo`;o00002oooool2
o`0000?ooooo0_l00004ooooo`;o00001oooool2o`0000?ooooo0_l00006ooooo`Ko000000?ooooo
o`000?l000000_l000000ooooooo0000o`00001:ooooo`007?ooool00ol0003oooooooooo`0ioooo
o`;o00001oooool2o`0001?ooooo8_l000000ooooooo0000o`000006ooooo`;o00001_ooool2o`00
00?ooooo0_l00005ooooo`Co00000oooool2o`0000;ooooo1?l000001?oooooo0000o`000?l00005
ooooo`Ko000000Coooooo`000?l0003ooooo0_l0000>ooooo`;o00002oooool2o`0000Cooooo0_l0
0002ooooo`;o00002?ooool2o`0000Kooooo0_l00005ooooo`;o00000oooool2o`0004[ooooo000L
ooooo`03o`000?oooooooooo03Wooooo0_l000000ooooooo0000o`000004ooooo`?o00004_oooolS
o`000003ooooool0003o000000Gooooo0_l00006ooooo`;o00000oooool2o`0000Gooooo1?l00004
ooooo`;o000000?oooooo`000?l000000_l000001Ooooooo0000o`000?l0003ooooo00[o000000Co
ooooo`000?l0003o00004?ooool2o`0000gooooo0_l00006ooooo`;o000000Goooooo`000?l0003o
0000ooooo`02o`0000Cooooo0_l00002ooooo`;o00001oooool2o`0000Cooooo0_l00006ooooo`;o
000000?oooooo`000?l00000?Oooool001cooooo00?o0000ooooooooool0>?ooool2o`0000;ooooo
0_l000000ooooooo0000o`000002ooooo`;o00000oooool3o`0000Cooooo0_l00009ooooob3o0000
00?oooooo`000?l000002_ooool2o`0000_ooooo0_l00008ooooo`;o000000?oooooo`000?l00000
1Ol000000ooooooo0000o`000004o`000004ooooool0003o0000o`0000;ooooo2Ol0000Iooooo`Co
00000oooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000001?ooool2o`000004
ooooool0003o0000o`0000Oooooo1?l00002ooooo`;o00001Oooool3o`000003ooooool0003o0000
03gooooo000Looooo`03o`000?oooooooooo03Sooooo0_l00003ooooo`Co00001oooool3o`0000Co
oooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool@o`000003ooooool0003o000000oo
00002_ooool2o`0000_ooooo0_l00004ooooo`;o00000oooool2o`000003ooooool0003o000000oo
000000?oooooo`000?l000002Ol00002ooooo`;o00002Oooool2o`0000_ooooo1?l000001?oooooo
0000o`000?ooool3o`0000Cooooo0_l00005ooooo`?o00001oooool8o`0000Gooooo0_l0000Loooo
o`;o00008oooool001cooooo00?o0000ooooooooool0?Oooool2o`0000Gooooo0ol0000:ooooo`;o
000000Coooooo`000?l0003ooooo0_l00002ooooob;o00002?ooool2o`00013ooooo0_l000001?oo
oooo0000o`000?ooool<o`000004ooooool0003o0000ooooo`Ko000000?oooooo`000?l000001Ol0
00001?oooooo0000o`000?l00002ooooo`;o00002Oooool2o`0000gooooo0_l000000ooooooo0000
o`000002ooooo`;o000000Coooooo`000?l0003ooooo1?l000001?oooooo0000o`000?ooool4o`00
00Kooooo0_l000001?oooooo0000o`000?ooool2o`0000Cooooo0ol0000Kooooo`;o00008oooool0
01cooooo0_l0000mooooo`;o00001_ooool3o`0000[ooooo0_l00006ooooo`;o000000?oooooo`00
0?l000006Ol00007ooooo`;o00001Oooool2o`0000Sooooo0_l00006ooooo`;o000000Coooooo`00
0?l0003ooooo3Ol000000ooooooo0000o`000002o`0000;ooooo0_l00003ooooo`Go00001?ooool2
o`0001Gooooo0_l00006ooooo`?o00000oooool3o`0000?ooooo1Ol00003ooooo`;o00001_ooool4
o`000004ooooool0003o0000o`0000Gooooo0_l0000<ooooo`;o0000<_ooool001cooooo00?o0000
ooooooooool0;?ooool2o`0000kooooo0_l00006ooooo`;o00002_ooool2o`0000;ooooo0_l00003
ooooo`oo000000?oooooo`000?l000001_l000000ooooooo0000o`000003o`0000;ooooo0_l00003
ooooo`;o000000?oooooo`000?l000003?ooool2o`0000cooooo1_l00005ooooo`Oo00000_ooool3
o`0000;ooooo1Ol00004ooooo`Co00004oooool2o`0000Cooooo1Ol00003ooooo`;o000000Cooooo
o`000?l0003ooooo1?l0000>ooooo`;o000000?oooooo`000?l000005?ooool2o`0003;ooooo000L
ooooo`03o`000?oooooooooo02cooooo0_l0000>ooooo`;o000000?oooooo`000?l000000oooool2
o`0000[ooooo0ol000000ooooooo0000o`000002ooooo`Oo000000?oooooo`000?l000004?l00002
ooooo`So00001Oooool2o`000003ooooool0003o000000Oooooo1?l0000=ooooo`Co000000?ooooo
o`000?l000001?ooool4o`0000Cooooo1_l00006ooooo`;o00000_ooool2o`0000gooooo0_l00005
ooooo`;o00000oooool5o`0000Kooooo0_l00004ooooo`;o00001?ooool2o`0000Sooooo0_l00005
ooooo`?o0000@_ooool001cooooo00?o0000ooooooooool0??ooool2o`000003ooooool0003o0000
00;ooooo0_l00003ooooo`;o00001oooool2o`000003ooooool0003o000000;ooooo6ol000000ooo
oooo0000o`000006o`0000Gooooo1Ol00007ooooo`?o00001?ooool2o`0000;ooooo2_l000001?oo
oooo0000o`000?l0000;ooooo`;o000000Coooooo`000?l0003o00001_ooool2o`0000Oooooo0_l0
0003ooooo`;o00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000006ooooo`;o00002?oo
ool2o`0000;ooooo0_l00003ooooo`?o00002?ooool2o`0000Gooooo0ol000000ooooooo0000o`00
000oooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00000_ooool2o`0000?ooooo0_l00004
ooooo`;o00001?ooool2o`000004ooooool0003o0000oooooa7o000000?oooooo`000?l000003Ol0
0008ooooo`;o00000_ooool2o`000003ooooool0003o000000Sooooo0_l00002ooooo`Ko00001_oo
ool3o`0000;ooooo1?l0000Cooooo`;o00001?ooool2o`0000?ooooo0_l00007ooooo`;o00002Ooo
ool2o`0000Kooooo1?l00007ooooo`;o00004Oooool2o`000003ooooool0003o000003oooooo000L
ooooo`03o`000?oooooooooo03oooooo0_l0000:ooooo`;o000000?oooooo`000?l000001oooool2
o`000003ooooool0003o000001Co000000?oooooo`000?l000001Ol000000ooooooo0000o`000008
ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000Oooooo0_l0000>ooooo`Co00000_oo
ool4o`000003ooooool0003o000000?o00003?ooool3o`0000?ooooo0ol00009ooooo`;o00003?oo
ool2o`0000Kooooo1?l000000ooooooo0000o`000009ooooo`;o00003oooool2o`000003ooooool0
003o000003cooooo000Looooo`03o`000?oooooooooo03oooooo0_l00009ooooo`?o00003OoooolL
o`0000?ooooo1?l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000_ooooo0_l00002
ooooo`;o00002_ooool2o`0000Sooooo1ol0000;ooooo`;o00001?ooool4o`0000;ooooo0_l00000
1?oooooo0000o`000?ooool2o`0000;ooooo0_l00003ooooo`;o00002oooool4o`000003ooooool0
003o000000Gooooo0_l00002ooooo`;o00001Oooool2o`0000_ooooo0_l0000looooo`007?ooool0
0ol0003oooooooooo`0oooooo`;o00001?ooool2o`0000?ooooo0_l000000ooooooo0000o`00000:
oooooa3o000000?oooooo`000?l000001_l00002ooooo`Wo00000_ooool2o`0000;ooooo0_l00007
ooooo`;o00002Oooool2o`0001Cooooo1?l000000ooooooo0000o`000002o`0000Wooooo0_l00005
ooooo`?o00000_ooool2o`000003ooooool0003o000000Gooooo0_l00003ooooo`;o00002?ooool2
o`000003ooooool0003o000000;o00002?ooool2o`000003ooooool0003o000000Kooooo0_l0000:
ooooo`;o000000?oooooo`000?l00000>_ooool001cooooo00?o0000ooooooooool0AOooool2o`00
00Kooooo0_l00006ooooo`Wo000000?oooooo`000?l000004Ol000000ooooooo0000o`000006o`00
017ooooo0_l00003ooooo`;o00004Oooool2o`0000Cooooo0_l00002ooooo`Co000000Coooooo`00
0?l0003o00003Oooool2o`000004ooooool0003o0000o`0000;ooooo0_l00006ooooo`;o00003ooo
ool2o`0000oooooo0ol00006ooooo`;o00002_ooool2o`000003ooooool0003o000001?ooooo0_l0
000Uooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00001oooool2o`0001cooooo1?l00006
ooooo`Co000000?oooooo`000?l000003ol00003ooooo`;o00000oooool2o`0001;ooooo0_l0000>
ooooo`Go00001?ooool2o`0000;ooooo1?l000000ooooooo0000o`000003ooooo`;o00001_ooool2
o`000005ooooool0003o0000o`000?ooool00_l0000:ooooo`;o00000_ooool2o`0000Gooooo1_l0
000Aooooo`;o000000?oooooo`000?l000001?ooool2o`00017ooooo0_l0000?ooooo`;o00009Ooo
ool001cooooo00?o0000ooooooooool0;_ooool2o`0000Oooooo0_l00007ooooo`;o00007_oooolF
o`000004ooooool0003o0000o`0000?ooooo0_l0000<ooooo`;o00005?ooool4o`0000Wooooo0_l0
0008ooooo`;o00001_ooool2o`000005ooooool0003o0000o`000?ooool00_l0000:ooooo`;o0000
0_ooool2o`0000Gooooo1_l00003ooooo`;o00003oooool4o`0000;ooooo0_l0000Aooooo`;o0000
=_ooool001cooooo00?o0000ooooooooool0@?ooool2o`0000oooooo0ol0000;ooooo`;o000000?o
ooooo`000?l000003ol000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000[ooooo
0_l00003ooooo`;o00007?ooool2o`0000?ooooo0_l0000Eooooo`Co00001Oooool2o`0000Sooooo
0_l0000<ooooo`?o00002oooool2o`0000;ooooo1?l0000Booooo`;o0000>Oooool001cooooo00?o
0000ooooooooool0@Oooool2o`0000Kooooo0_l00006ooooo`Co000000Coooooo`000?l0003o0000
1_ooool2o`000003ooooool0003o000000_o00000oooool2o`000003ooooool0003o000000Go0000
1?ooool2o`0000;ooooo1?l0000Cooooo`;o00000oooool2o`000003ooooool0003o000000Cooooo
0_l00005ooooo`;o00001Oooool2o`0000;ooooo0_l00008ooooo`Co00001Oooool2o`0000Oooooo
0ol0000<ooooo`?o00000oooool2o`0000?ooooo0_l000000ooooooo0000o`00000Fooooo`Co0000
>Oooool001cooooo00?o0000ooooooooool0=_ooool2o`0000?ooooo0_l00004ooooo`;o00001_oo
ool2o`0000Sooooo0_l000000ooooooo0000o`000002o`0000Cooooo0ol000000ooooooo0000o`00
000;o`0000?ooooo0_l000000ooooooo0000o`000003o`0000Kooooo0_l00002ooooo`;o00003?oo
ool2o`0000Oooooo0ol00002ooooo`;o000000?oooooo`000?l000002oooool2o`0000Gooooo0_l0
00000ooooooo0000o`000006o`000003ooooool0003o000000Co00000oooool4o`0000Oooooo0_l0
0006ooooo`;o00000oooool2o`0000Kooooo0_l00002ooooo`?o00000_ooool3o`0000cooooo0_l0
0006ooooo`;o00000_ooool2o`0003Oooooo000Looooo`03o`000?oooooooooo03Kooooo0_l00003
ooooo`?o00000oooool2o`0000?ooooo0_l0000?ooooo`?o00001?ooool3o`0000;ooooo1?l00000
1Ooooooo0000o`000?l0003ooooo00?o00001Oooool6o`0001Oooooo0ol00008ooooo`;o00004?oo
ool2o`0000Oooooo1Ol000000ooooooo0000o`000007o`000004ooooool0003o0000ooooo`Ko0000
00?oooooo`000?l000003?ooool2o`000003ooooool0003o000000;o00000_ooool2o`0000Kooooo
0_l00003ooooo`?o00001_ooool2o`0000Cooooo0_l0000:ooooo`;o000000?oooooo`000?l00000
=?ooool001cooooo00?o0000ooooooooool0??ooool2o`0000?ooooo0_l00003ooooo`Co00003Ooo
ool2o`0000cooooo1ol000000ooooooo0000o`000002o`0000?ooooo0_l000000ooooooo0000o`00
000=ooooo`;o00002Oooool4o`0001Wooooo0_l00007ooooo`Go00000oooool2o`000003ooooool0
003o000000?ooooo0_l000001?oooooo0000o`000?ooool3o`000003ooooool0003o000000cooooo
0_l000000ooooooo0000o`000002o`000004ooooool0003o0000o`0001Cooooo0_l0000?ooooo`;o
000000Coooooo`000?l0003o0000=?ooool001cooooo0_l0000mooooo`;o00001Oooool2o`0000;o
oooo0ol00002ooooo`;o00006?ooool2o`0000;ooooo0_l00003ooooo`;o00004_ooool5o`0000So
oooo1Ol00002ooooo`Co00003_ooool2o`0000?ooooo0_l00004ooooo`;o00001?ooool2o`0000?o
oooo1Ol00003ooooo`;o000000?oooooo`000?l000001_ooool2o`00013ooooo0_l000000ooooooo
0000o`000004ooooo`;o00001oooool2o`0000Cooooo1Ol000000ooooooo0000o`00000;ooooo`;o
000000?oooooo`000?l00000=Oooool001cooooo00?o0000ooooooooool0<Oooool2o`00013ooooo
0_l00002ooooo`?o00000_ooool2o`0000?ooooo0_l0000;ooooo`;o000000?oooooo`000?l00000
3Oooool2o`000003ooooool0003o000000Kooooo1?l00004ooooo`?o00002_ooool4o`000003oooo
ool0003o000000Co00000_ooool3o`0000Wooooo1?l00007ooooo`;o00001?ooool2o`0000Cooooo
1?l0000;ooooo`Go00001oooool2o`0000Sooooo0ol00004ooooo`?o00001oooool2o`0000Cooooo
1Ol000000ooooooo0000o`000015ooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00002_oo
ool2o`0000gooooo0_l00003ooooo`;o00001?ooool2o`0000Gooooo0_l000000ooooooo0000o`00
0002ooooo`;o00002Oooool5o`0000Kooooo1?l0000;ooooo`;o00002Oooool2o`000003ooooool0
003o000000;o000000Coooooo`000?l0003o00002oooool2o`0001?ooooo1?l00006ooooo`[o0000
1_ooool3o`0000Kooooo1Ol00002ooooo`Co00002?ooool2o`0000Cooooo1?l00019ooooo`007?oo
ool00ol0003oooooooooo`0gooooo`Co00000_ooool5o`0000[ooooo0_l00009ooooo`;o00002?oo
ool2o`0000;ooooo0_l0000:ooooo`;o00000oooool3o`0000Cooooo0_l0000;ooooo`;o00000_oo
ool2o`0000Kooooo1_l0000Eooooo`;o00000_ooool2o`0000Oooooo0_l00004ooooo`?o00000ooo
ool6o`0000;ooooo0_l00006ooooo`;o00000_ooool2o`0000?ooooo0ol00004ooooo`Co00003Ooo
ool3o`0000Gooooo0_l00006ooooo`;o00005?ooool2o`0002Kooooo000Looooo`03o`000?oooooo
oooo03Oooooo1Ol000000ooooooo0000o`000003o`0000Wooooo0_l0000:ooooo`;o00000oooool2
o`0001Sooooo0ol00004ooooo`;o00003oooool2o`0000?ooooo0_l000000ooooooo0000o`00000I
ooooo`;o00000_ooool2o`0000Gooooo1?l00004ooooo`?o000000?oooooo`000?l000000_l00002
ooooo`;o00003_ooool2o`0000Cooooo0ol00005ooooo`;o000000Coooooo`000?l0003o00002Ooo
ool2o`0000Kooooo0_l00005ooooo`?o00001_ooool2o`0000cooooo0_l0000Vooooo`007?ooool0
0ol0003oooooooooo`0gooooo`;o000000?oooooo`000?l000000_ooool2o`0000Sooooo0_l00000
0ooooooo0000o`00000:ooooo`;o00000oooool2o`0000?ooooo0_l0000Looooo`;o00001?ooool2
o`0000cooooo0_l0000:ooooo`;o00002oooool2o`0000?ooooo0ol000001?oooooo0000o`000?l0
0004ooooo`;o00001?ooool3o`0000?ooooo1?l00007ooooo`;o00004?ooool2o`0000;ooooo0_l0
0004ooooo`Go00005_ooool2o`0000Oooooo0_l0000dooooo`007?ooool00ol0003oooooooooo`0j
ooooo`;o00000_ooool2o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l000005?ooool2
o`0000Cooooo0ol0000Eooooo`;o00001?ooool2o`0000gooooo0_l00007ooooo`Co00002?ooool2
o`000003ooooool0003o000000?ooooo0ol000001?oooooo0000o`000?l00005ooooo`?o000000?o
ooooo`000?l000000_l0000:ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00001Ooo
ool2o`000004ooooool0003o0000ooooo`;o00000oooool2o`0000;ooooo0ol00005ooooo`?o0000
3Oooool2o`0000?ooooo1?l0000fooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00001Ooo
ool2o`0000Kooooo0ol0000Rooooo`?o0000:_ooool2o`0000Oooooo1?l00008ooooo`Ko000000?o
ooooo`000?l000000_ooool6o`0000?ooooo0ol000000ooooooo0000o`000002o`0000[ooooo0_l0
0002ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00001Oooool2o`000003ooooool0
003o000000Kooooo0_l00002ooooo`?o00001Oooool5o`0000?ooooo0_l0000;ooooo`Co0000=_oo
ool001cooooo00?o0000ooooooooool0<_ooool3o`0000kooooo0_l00011ooooo`;o00001Oooool2
o`0000[ooooo0_l00003ooooo`Co00001?ooool2o`0000;ooooo2Ol000000ooooooo0000o`000005
o`0000;ooooo0_l0000Dooooo`;o000000?oooooo`000?l000000_l0000:ooooo`;o00000oooool2
o`0000Oooooo0_l00009ooooo`;o00000oooool2o`0000_ooooo1?l0000fooooo`007?ooool00ol0
003oooooooooo`0booooo`;o00008?ooool2o`0000cooooo0_l00009ooooo`;o00005oooool2o`00
00Gooooo0_l000000ooooooo0000o`000007ooooo`?o00000oooool6o`000003ooooool0003o0000
00;ooooo0_l00003ooooo`Co000000?oooooo`000?l000001Ol00007ooooo`;o00005?ooool2o`00
00Oooooo0_l000000ooooooo0000o`000003ooooo`;o00002_ooool2o`0000Wooooo0_l00002oooo
o`;o00000_ooool3o`0003kooooo000Looooo`03o`000?oooooooooo03;ooooo0_l00002ooooo`;o
00001?ooool2o`0001Kooooo0_l0000<ooooo`;o00002Oooool2o`00027ooooo0_l00002ooooo`;o
00000oooool3o`0000?ooooo2ol0000?ooooo`;o00001?ooool2o`000003ooooool0003o000001So
oooo0_l00003ooooo`;o00000oooool2o`0000[ooooo0_l000001?oooooo0000o`000?ooool2o`00
00Kooooo0ol000000ooooooo0000o`000002ooooo`?o00001_ooool2o`0003Kooooo000Looooo`03
o`000?oooooooooo03;ooooo0_l00002ooooo`;o00000oooool3o`0000cooooo0_l00008ooooo`Co
00006Oooool2o`0001gooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l00005ooooo`[o
00004_ooool2o`000003ooooool0003o000000;ooooo0_l0000Gooooo`?o000000Coooooo`000?l0
003o00000oooool2o`0000Cooooo0ol00003ooooo`;o00001?ooool2o`0000Oooooo0_l00006oooo
o`;o00001_ooool2o`0003Kooooo000Looooo`03o`000?oooooooooo02kooooo0_l0000;ooooo`;o
00002oooool4o`0000Sooooo1?l000000ooooooo0000o`00000Fooooo`;o00007?ooool3o`0000Go
oooo0_l00007ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`00000Booooo`;o
00000oooool5o`0001Cooooo0_l000000ooooooo0000o`000007o`0000Kooooo0ol00005ooooo`;o
00004?ooool2o`000003ooooool0003o000000Gooooo0_l0000gooooo`007?ooool00ol0003ooooo
ooooo`0^ooooo`;o00002?ooool2o`000004ooooool0003o0000o`0000;ooooo0_l00004ooooo`Co
00003oooool2o`0003Cooooo0_l0000;ooooo`;o00001oooool4o`000003ooooool0003o000001Go
oooo0_l000000ooooooo0000o`00000>ooooo`;o00001?ooool=o`0000Gooooo0ol00005ooooo`;o
00002_ooool2o`0000Cooooo0_l00008ooooo`?o0000=_ooool001cooooo00?o0000ooooooooool0
>?ooool2o`000004ooooool0003o0000o`0000;ooooo0_l00004ooooo`;o00006oooool2o`0002Ko
oooo0_l00003ooooo`;o000000?oooooo`000?l000001oooool2o`0000Oooooo1?l000000ooooooo
0000o`00000Eooooo`;o00002_ooool3o`0000Cooooo0_l00005ooooo`go00000_ooool4o`0000;o
oooo0_l00009ooooo`;o00000oooool2o`0000oooooo0_l0000fooooo`007?ooool00ol0003ooooo
ooooo`0gooooo`;o00000_ooool2o`0000;ooooo0_l00007ooooo`;o00002Oooool2o`0000kooooo
0_l00009ooooo`;o00006oooool2o`0000?ooooo0_l000000ooooooo0000o`000008ooooo`;o0000
2?ooool2o`0000Wooooo1?l0000;ooooo`;o00000oooool2o`0000Gooooo0ol00003ooooo`?o0000
1OoooolAo`0000Cooooo0_l00005ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o0000
2_ooool2o`0003Oooooo000Looooo`;o0000>?ooool2o`0000Kooooo0ol00002ooooo`;o00000_oo
ool2o`0000Wooooo0_l0000Iooooo`;o00001oooool2o`0000[ooooo0_l00008ooooo`Go00001_oo
ool2o`0000?ooooo0_l0000Cooooo`Co00004?ooool2o`0000Oooooo0_l00002ooooo`?o000000Go
ooooo`000?l0003o0000ooooo`0Do`000004ooooool0003o0000o`0000Cooooo0_l00007ooooo`;o
00000_ooool2o`0000[ooooo0_l0000gooooo`007?ooool00ol0003oooooooooo`10ooooo`;o0000
0_ooool2o`0002;ooooo0_l0000=ooooo`?o00002Oooool2o`0000Oooooo1?l00006ooooo`Co0000
6_ooool2o`0001Wooooo0_l00005oooooaWo00000_ooool2o`0000cooooo0_l00003ooooo`;o0000
@oooool001cooooo00?o0000ooooooooool0@oooool2o`0001?ooooo0_l000001?oooooo0000o`00
0?l00005ooooo`;o00000oooool2o`000003ooooool0003o000000_ooooo0_l0000Booooo`;o0000
0oooool2o`0000?ooooo0_l0000Kooooo`?o00001oooool2o`0000_ooooo0ol00009ooooo`co0000
00?oooooo`000?l000002?l00002ooooo`Co00003?ooool2o`0001gooooo0_l0000Yooooo`007?oo
ool00ol0003oooooooooo`0dooooo`;o00002Oooool9o`0000gooooo1Ol000000ooooooo0000o`00
0005o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`00000Tooooo`;o00000ooo
ool2o`0000gooooo0_l00006ooooo`;o00001?ooool2o`0000Sooooo0_l0000;ooooo`?o00002_oo
oolGo`000003ooooool0003o000000;o00005Oooool2o`0001Cooooo0_l0000Yooooo`007?ooool0
0ol0003oooooooooo`0dooooo`;o00002Oooool4o`000003ooooool0003o000000;o00003Oooool3
o`0000Kooooo1?l00006ooooo`;o00004Oooool2o`0000Cooooo1?l0000Booooo`;o00001Oooool2
o`0000Gooooo0_l00006ooooo`;o00005?ooool2o`00013ooooo6Ol000000ooooooo0000o`000002
o`0001Gooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0booooo`;o00001_ooool2o`00
00kooooo0_l0000?ooooo`;o00000oooool2o`000003ooooool0003o000000_ooooo0_l00007oooo
o`Co00001?ooool4o`0000kooooo0_l00002ooooo`Co00000oooool2o`0000gooooo0ol0000Coooo
o`;o00003ooooolJo`000003ooooool0003o000000;o0000E_ooool001cooooo00?o0000oooooooo
ool0<_ooool3o`0000Gooooo0_l0000>ooooo`Co00001_ooool2o`0000Gooooo0_l00003ooooo`;o
000000?oooooo`000?l000002?ooool2o`000003ooooool0003o000000;ooooo0ol00002ooooo`Co
00004_ooool2o`0000;ooooo0_l00004ooooo`;o00002oooool5o`0000;ooooo0ol00007ooooo`;o
00000_ooool2o`000003ooooool0003o000000gooooo0_l00005oooooaOo000000?oooooo`000?l0
00001oooool2o`0001Kooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`0cooooo`;o0000
1Oooool2o`0000Gooooo0_l00006ooooo`Go00001_ooool2o`0000Kooooo0_l0000?ooooo`;o0000
00?oooooo`000?l000001Ol000000ooooooo0000o`00000Eooooo`;o00001?ooool2o`0000Cooooo
0_l000000ooooooo0000o`000006ooooo`Go00000_ooool2o`0000Sooooo1_l000000ooooooo0000
o`00000=ooooo`;o00001_oooolEo`0000_ooooo0_l0000Fooooo`;o0000>_ooool001cooooo00?o
0000ooooooooool0@Oooool2o`0000Kooooo0ol00008ooooo`;o000000Coooooo`000?l0003o0000
0_ooool2o`0000gooooo0_l00002ooooo`Oo00000_ooool5o`0000;ooooo0_l00003ooooo`?o0000
2Oooool2o`0000?ooooo0_l00002ooooo`Co000000?oooooo`000?l000000oooool2o`0001;ooooo
2?l0000DoooooaSo000000?oooooo`000?l000008?ooool2o`0003Wooooo000Looooo`03o`000?oo
oooooooo03?ooooo0_l0000Hooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`?o0000
1?ooool2o`0000_ooooo0_l000000ooooooo0000o`00000>o`000003ooooool0003o000000;o0000
00Coooooo`000?l0003o00001Oooool2o`0000;ooooo0_l00007ooooo`;o00002?ooool2o`0000Ko
oooo0_l0000:ooooo`;o00000_ooool4o`0000;ooooo0_l00009ooooo`;o00001OoooolHo`000003
ooooool0003o000000Cooooo0_l0000?ooooo`;o00002Oooool2o`0000Gooooo0_l0000booooo`00
7?ooool00ol0003oooooooooo`0cooooo`;o00001oooool2o`0000;ooooo1?l00009ooooo`Ko0000
1_ooool2o`0000?ooooo0_l00009ooooo`;o00000_oooolJo`0000;ooooo0_l000001?oooooo0000
o`000?ooool3o`0001Wooooo0_l0000:ooooo`Go00001?ooool3o`000003ooooool0003o000000Ko
oooo0_l00007oooooaGo00001Oooool2o`000003ooooool0003o000000oooooo0_l0000@ooooo`;o
0000<_ooool001cooooo00?o0000ooooooooool0??ooool2o`0000;ooooo1?l00009ooooo`Co0000
0oooool2o`0000?ooooo0_l00006ooooo`;o00001_oooolKo`0000Gooooo0_l00004ooooo`?o0000
2?ooool2o`0000;ooooo0_l0000Hooooo`Co00001?ooool2o`0000;ooooo0_l0000?oooooa;o0000
2?ooool2o`0000kooooo0_l00004ooooo`;o000000?oooooo`000?l00000?oooool001cooooo00?o
0000ooooooooool0;oooool2o`00023ooooo0_l000001?oooooo0000o`000?ooool2o`0000Sooooo
1Ol00005oooooaWo00000_ooool3o`0000Kooooo0_l00004ooooo`;o00000oooool2o`0000;ooooo
0_l0000;ooooo`;o00003_ooool2o`0000[ooooo1?l00005ooooo`?o00000oooool;o`000003oooo
ool0003o000000?o00006?ooool2o`0000Cooooo0_l000000ooooooo0000o`00000oooooo`007?oo
ool00ol0003oooooooooo`0_ooooo`;o00007?ooool2o`0000;ooooo0_l00004ooooo`?o00000_oo
ool2o`0000?ooooo1Ol000000ooooooo0000o`000004oooooaOo000000?oooooo`000?l000000ol0
0005ooooo`;o00001?ooool2o`0001Cooooo0_l0000;ooooo`Go000000?oooooo`000?l000000_l0
0002ooooo`;o000000?oooooo`000?l000000_l00005ooooo`?o00000ooooolAo`0001Oooooo0_l0
000<ooooo`;o0000>oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo
00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo03oooooo0_l00007ooooo`;o
00000oooool2o`0000Gooooo0_l00002ooooo`?o000000?oooooo`000?l000000oooool2o`0000Co
oooo0_l000001?oooooo0000o`000?oooolGo`000003ooooool0003o000000?o00000oooool2o`00
00[ooooo0_l00003ooooo`;o00002_ooool2o`0000Cooooo0_l00004ooooo`co00000_ooool2o`00
00Gooooo0_l000000ooooooo0000o`000006ooooo`ko00005_ooool2o`0000;ooooo0_l0000<oooo
o`;o00002_ooool2o`0002oooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44
ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0oooooo`;o00001ooo
ool3o`0000Wooooo0_l00003ooooo`;o00003oooool2o`000003ooooool0003o000000Co000000?o
ooooo`000?l000003Ol000000ooooooo0000o`000002o`0000Gooooo0_l0000:ooooo`;o00000ooo
ool2o`0000Kooooo0_l000001?oooooo0000o`000?l00004ooooo`;o00000oooool=o`0000;ooooo
0_l00005ooooo`;o000000?oooooo`000?l000000oooool3o`000003ooooool0003o000000Wo0000
2oooool2o`0000_ooooo0_l00009ooooo`Co00003oooool2o`0002oooooo00000ooooooo410@oooo
o`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo03;ooooo0_l0000Eooooo`;o00005oooool2o`0000Gooooo0_l000000ooooooo0000
o`000005o`000003ooooool0003o000001?o00000oooool2o`0001Sooooo0_l000000ooooooo0000
o`000008ooooo`Co000000?oooooo`000?l000002_l0000;ooooo`Oo000000?oooooo`000?l00000
1_l00003ooooo`;o00001Oooool2o`0000;ooooo0_l0000Aooooo`;o00000oooool4o`0000Wooooo
0_l0000eooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?nH
V9SooooooiRHV?lQ8B401_ooool3o`0003;ooooo0_l0000Eooooo`;o00003oooool2o`0000Kooooo
0_l00005ooooo`;o000000?oooooo`000?l000002_l000000ooooooo0000o`00000;o`000003oooo
ool0003o000000?ooooo0_l00004ooooo`;o000000?oooooo`000?l000004?ooool4o`0000Gooooo
2?l000000ooooooo0000o`00000:o`0000[ooooo1_l00002ooooo`;o00000oooool2o`0000Cooooo
0ol00004ooooo`;o00005Oooool2o`00013ooooo0_l0000eooooo`0000?oooooo`000?ooool00_oo
ool00ol0003oooooooooo`09ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003ooooo
ooooo`1>ooooo`;o00000_ooool2o`0000Cooooo1Ol0000=ooooo`_o000000?oooooo`000?l00000
3_l0000<ooooo`Go00002oooool2o`0000?ooooo1?l00005oooooaGo00000_ooool2o`0000Oooooo
0_l00004ooooo`;o00001?ooool2o`0000Gooooo0_l0000Cooooo`;o00002oooool4o`00043ooooo
00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qoooool02?oo
ool00ol0003oooooooooo`17ooooo`;o00001Oooool2o`0000;ooooo0_l00004ooooo`;o000000?o
ooooo`000?l000001_ooool2o`0000Gooooo0_l00002oooooa[o00002oooool2o`0000gooooo0_l0
000;ooooo`;o000000?oooooo`000?l000003ol00004ooooo`;o00003?ooool3o`00023ooooo0_l0
00000ooooooo0000o`000008ooooo`Co0000@?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo04Gooooo1?l00005ooooo`Co0000
3_ooool2o`000003ooooool0003o000000Oooooo7?l00005ooooo`;o00006Oooool2o`0000Gooooo
0_l000000ooooooo0000o`00000Do`0000Gooooo0_l00003ooooo`;o000000?oooooo`000?l00000
0_l0000Gooooo`;o00002Oooool2o`000003ooooool0003o000004Wooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`15oooo
o`;o00002?ooool3o`0000Kooooo0_l00002ooooo`;o00000_ooool2o`0000Wooooo7Ol00005oooo
o`;o00004_ooool2o`0000Gooooo1?l000000ooooooo0000o`00000Io`0000Gooooo0_l00003oooo
o`;o00000oooool3o`0000Gooooo0_l0000;ooooo`Ko00001oooool2o`0000?ooooo0_l00007oooo
o`;o0000@?ooool001cooooo00?o0000ooooooooool0@_ooool4o`0000[ooooo0_l00006ooooo`;o
00000_ooool2o`0000?ooooo0ol00007oooooa_o00006oooool2o`000003ooooool0003o000000Co
oooo7_l00008ooooo`;o00000_ooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l0
00001_ooool2o`0000?ooooo1Ol00008ooooo`;o00001oooool2o`0000?ooooo0_l00010ooooo`00
7?ooool00ol0003oooooooooo`12ooooo`Co00000_ooool4o`0000Cooooo0_l00003ooooo`;o0000
1Oooool2o`0000?ooooo0ol00007oooooa_o00000_ooool2o`0001[ooooo0_l00005ooooo`?o0000
00?oooooo`000?l000005ol00008ooooo`;o00000_ooool2o`0000Kooooo0_l00009ooooo`Co0000
5oooool2o`0000Sooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`18ooooo`Co00002Ooo
ool2o`0000Gooooo0_l00008ooooo`;o00000ooooolJo`0000;ooooo0ol0000Looooo`;o00000ooo
ool3o`000003ooooool0003o000001So00008?ooool2o`0001Oooooo0_l00008ooooo`;o0000>ooo
ool001cooooo00?o0000ooooooooool0A_ooool4o`0000[ooooo0_l0000@ooooo`;o00000_ooool=
o`000003ooooool0003o000000[o00000oooool2o`0000;ooooo0_l000000ooooooo0000o`00000F
ooooo`;o00001?oooolQo`0002;ooooo0_l0000Aooooo`;o0000AOooool001cooooo00?o0000oooo
ooooool0A_ooool2o`0000Cooooo0_l00006ooooo`;o00001oooool2o`0000;ooooo1?l00005oooo
o`;o000000?oooooo`000?l000004_l000000ooooooo0000o`000007ooooo`;o000000?oooooo`00
0?l000002oooool2o`0000kooooo8_l0000Iooooo`;o00001_ooool3o`0005Sooooo000Looooo`03
o`000?oooooooooo04Oooooo0_l00002ooooo`?o00002Oooool2o`0000Cooooo0_l00002ooooo`Co
00002?oooolGo`0000Cooooo0_l00003ooooo`;o00003?ooool2o`0000kooooo8Ol0000Gooooo`;o
000000?oooooo`000?l000001_ooool2o`0000Cooooo0_l0000@ooooo`;o0000@Oooool001cooooo
00?o0000ooooooooool0<?ooool2o`0001Cooooo1?l000000ooooooo0000o`000005ooooo`;o0000
0oooool2o`0001Kooooo2ol000000ooooooo0000o`000007o`0000Cooooo0_l00002ooooo`?o0000
1Oooool2o`0001Kooooo0_l000000ooooooo0000o`00000:o`0000;ooooo2ol00002ooooo`;o0000
3Oooool2o`0000Sooooo0_l0000:ooooo`;o00000oooool2o`0000gooooo0_l000000ooooooo0000
o`000007ooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0<?ooool2o`0001Cooooo1?l0
00001Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`000?l000002_ooool2o`0000kooooo
3?l000000ooooooo0000o`000004o`0000_ooooo0_l00006ooooo`;o00002_ooool2o`0000;ooooo
0_l00003oooooa_o000000?oooooo`000?l000000ol000000ooooooo0000o`00000<ooooo`;o0000
00?oooooo`000?l000004Oooool2o`0001;ooooo0_l0000:ooooo`;o0000>?ooool001cooooo00?o
0000ooooooooool0=_ooool2o`0001?ooooo0ol000000ooooooo0000o`00000=ooooo`;o00001Ooo
ool2o`0000;ooooo0_l00003ooooo`?o000000?oooooo`000?l000001Ol00002ooooo`;o000000Co
ooooo`000?l0003o00001?ooool2o`000003ooooool0003o000000Ko00001oooool2o`0000Oooooo
0_l00002ooooo`;o000000?oooooo`000?l000000ol00002ooooo`_o000000?oooooo`000?l00000
4Ol0000?ooooo`;o0000Joooool001cooooo00?o0000ooooooooool0<?ooool2o`0000Cooooo0_l0
000>ooooo`Oo00002_ooool2o`0000Gooooo0_l00005ooooo`Ko00001?ooool2o`0000Gooooo0ol0
0007ooooo`;o00000oooool2o`000003ooooool0003o000000;o00000_ooool2o`0000Kooooo0ol0
000>ooooo`;o000000?oooooo`000?l000000_oooolIo`0000;ooooo0_l0000Nooooo`;o00005ooo
ool2o`0004Gooooo000Looooo`03o`000?oooooooooo033ooooo0_l0000Dooooo`Ko000000?ooooo
o`000?l000001Oooool2o`000004ooooool0003o0000ooooo`;o00002oooool6o`0001?ooooo0_l0
0004ooooo`;o00003_ooool2o`0001;ooooo0_l00003oooooa[o00002oooool2o`0000gooooo0_l0
0004ooooo`;o00005oooool2o`0004Gooooo000Looooo`;o0000>oooool2o`0000_ooooo0_l00004
ooooo`;o00001Oooool2o`0000Cooooo0_l0000=ooooo`Go00004oooool2o`0000?ooooo0_l0000V
oooooa_o00002oooool4o`0000_ooooo0_l00002ooooo`;o00001Oooool4o`0005Oooooo000Loooo
o`03o`000?oooooooooo03[ooooo0_l0000;ooooo`;o00002?ooool2o`0000Cooooo0_l000001?oo
oooo0000o`000?ooool2o`0000_ooooo1?l0000Cooooo`;o00003_ooool2o`00017ooooo0_l00008
oooooaWo00003oooool2o`0000cooooo0_l000000ooooooo0000o`000005ooooo`Co0000Eoooool0
01cooooo00?o0000ooooooooool0<Oooool2o`0001kooooo0_l00002ooooo`Co00001?ooool2o`00
00_ooooo0_l00004ooooo`;o00002_ooool2o`0000;ooooo0_l0000?ooooo`;o00004Oooool2o`00
00Wooooo5ol0000Iooooo`;o00000oooool2o`0000Wooooo1?l0001Fooooo`007?ooool00ol0003o
ooooooooo`0aooooo`;o00008Oooool5o`0001Cooooo1Ol00007ooooo`;o000000?oooooo`000?l0
00000_ooool2o`0000Wooooo0_l0000Gooooo`;o00002OoooolGo`0000?ooooo0_l0000Dooooo`;o
000000?oooooo`000?l000000ol00008ooooo`Co00000oooool4o`0004oooooo000Looooo`03o`00
0?oooooooooo053ooooo0_l00002ooooo`?o00000_ooool2o`0000Kooooo0_l0000:ooooo`Go0000
1_ooool3o`0000kooooo1?l0000;ooooo`;o00002_ooool2o`0000Gooooo0_l00002ooooo`oo0000
00?oooooo`000?l000001_l00002ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo
0_l0000;ooooo`;o000000Coooooo`000?l0003ooooo0_l0000<ooooo`Co0000Coooool001cooooo
00?o0000ooooooooool0?Oooool2o`00017ooooo0_l00003ooooo`;o000000?oooooo`000?l00000
0ol00004ooooo`?o00003?ooool4o`0000Cooooo0_l0000?ooooo`;o00003Oooool2o`0000_ooooo
0_l00004ooooo`?o000000?oooooo`000?l000003Ol000000ooooooo0000o`000004ooooo`;o0000
1oooool5o`0000;ooooo0_l00009ooooo`;o00001_ooool2o`0001Kooooo0_l00017ooooo`007?oo
ool00ol0003oooooooooo`0mooooo`;o00004oooool2o`0000;ooooo1?l000000ooooooo0000o`00
0002ooooo`;o000000Coooooo`000?l0003o00003Oooool2o`0001Gooooo0_l0000Jooooo`;o0000
1Oooool2o`0000?ooooo4_l00002ooooo`?o00001?ooool2o`0000;ooooo0_l0000>ooooo`?o0000
0oooool2o`0000Wooooo0ol0000<ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0?_oo
ool2o`0001;ooooo0_l00002ooooo`Co00001Oooool2o`0000;ooooo0_l0000=ooooo`;o00000ooo
ool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000Oooooo0_l00005ooooo`;o00006ooo
ool3o`000005ooooool0003o0000o`000?ooool01?l000000ooooooo0000o`000008o`0000;ooooo
0_l00004ooooo`;o00004oooool2o`0000?ooooo0_l00009ooooo`?o0000EOooool001cooooo00?o
0000ooooooooool0?_ooool2o`0001Kooooo1_l000000ooooooo0000o`00000Booooo`?o00000ooo
ool2o`000005ooooool0003o0000o`000?ooool01_l00005ooooo`;o00001Oooool2o`0001_ooooo
0ol00003ooooo`co00000_ooool3o`0000?ooooo0_l0000Iooooo`;o0000IOooool001cooooo00?o
0000ooooooooool0B_ooool2o`0000Oooooo0_l000000ooooooo0000o`000002ooooo`;o000000?o
ooooo`000?l000001oooool2o`0000Wooooo0_l00007ooooo`;o00001_ooool2o`0000Gooooo0_l0
000Uooooo`;o000000?oooooo`000?l000001ol000000ooooooo0000o`000008ooooo`;o00006Ooo
ool2o`0006Gooooo000Looooo`03o`000?oooooooooo04[ooooo0_l00007ooooo`;o00001?ooool2
o`0000;ooooo0_l00007ooooo`;o00001?ooool2o`0000_ooooo0_l0000eooooo`;o00000_ooool5
o`000003ooooool0003o000002;ooooo0_l0000=ooooo`;o00005Oooool2o`0004?ooooo000Loooo
o`03o`000?oooooooooo03kooooo0_l0000@ooooo`;o00001oooool2o`0000;ooooo0ol00007oooo
o`Co000000?oooooo`000?l000002oooool2o`0001Wooooo0_l00002ooooo`;o00001_ooool2o`00
00cooooo1?l00002ooooo`Ko00008oooool3o`0000gooooo0_l0000Eooooo`;o0000@oooool001co
oooo00?o0000ooooooooool0?_ooool2o`00013ooooo0_l00007ooooo`;o00000oooool2o`000003
ooooool0003o000000Cooooo1?l0000Yooooo`;o00000_ooool2o`0000Kooooo0_l0000:ooooo`Co
00001oooool3o`0000Sooooo0_l0000Iooooo`Ko00001Oooool2o`0005oooooo000Looooo`03o`00
0?oooooooooo04cooooo0_l00003ooooo`;o00001Oooool3o`0000?ooooo0_l000000ooooooo0000
o`00000Iooooo`;o00004oooool2o`000004ooooool0003o0000o`0000_ooooo0_l00008ooooo`?o
00001Oooool2o`000003ooooool0003o000000Wooooo0_l0000Kooooo`Co00001Oooool2o`0005oo
oooo000Looooo`03o`000?oooooooooo04cooooo0_l00003ooooo`;o00001Oooool3o`0000?ooooo
0ol0000Kooooo`;o00002Oooool2o`0000Sooooo0_l000000ooooooo0000o`000002o`0000Cooooo
0_l00004ooooo`;o00001?ooool2o`0000[ooooo0_l000000ooooooo0000o`000003ooooo`;o0000
<oooool3o`0000Oooooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o00001Ooo
ool2o`000003ooooool0003o000000Cooooo0_l0000Mooooo`;o00003Oooool2o`0000Cooooo0_l0
000:ooooo`;o00002_ooool7o`000003ooooool0003o000000_ooooo0_l0000Booooo`;o00004_oo
ool4o`0000Kooooo0_l0001<ooooo`007?ooool2o`0005Cooooo0_l00007ooooo`;o000000Cooooo
o`000?l0003ooooo0_l00004ooooo`;o00003_ooool3o`00013ooooo0_l00002ooooo`;o00001Ooo
ool2o`0001Cooooo0_l00006ooooo`Oo000000?oooooo`000?l000001_ooool2o`0000?ooooo0_l0
0009ooooo`;o00001oooool2o`0000gooooo0_l00004ooooo`?o0000E?ooool001cooooo00?o0000
ooooooooool0Doooool4o`0000Gooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00000ooo
ool2o`0000kooooo1Ol0000>ooooo`;o00000_ooool2o`0000Gooooo0_l0000Dooooo`;o00001_oo
ool2o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`Co00003?ooool2o`0000Oooooo0_l0
000=ooooo`;o00001?ooool2o`0005Gooooo000Looooo`03o`000?oooooooooo05Gooooo0_l00004
ooooo`;o00000_ooool3o`000003ooooool0003o0000017ooooo0_l00003ooooo`;o00005Oooool2
o`0001;ooooo0_l00002ooooo`;o00000oooool2o`0000?ooooo0_l000001?oooooo0000o`000?l0
000:ooooo`Co00000_ooool2o`0000Sooooo0_l0000Eooooo`;o0000G?ooool001cooooo00?o0000
ooooooooool0Foooool2o`0000?ooooo0_l0000Dooooo`;o00004_ooool2o`0000Kooooo0_l0000B
ooooo`Oo00000_ooool3o`0000;ooooo0_l000001?oooooo0000o`000?l00006ooooo`;o00000_oo
ool2o`0000;ooooo1?l00005ooooo`;o00005?ooool2o`0000;ooooo0_l0001Looooo`007?ooool0
0ol0003oooooooooo`1Kooooo`Co00000oooool2o`0000;ooooo0_l00005ooooo`;o00003_ooool2
o`0000Gooooo0_l00002ooooo`Co000000?oooooo`000?l000005_ooool8o`0000;ooooo0ol00003
ooooo`;o000000?oooooo`000?l000001?ooool4o`0000Kooooo0_l00007ooooo`;o00002?ooool2
o`0000[ooooo0_l00007ooooo`;o0000Eoooool001cooooo00?o0000ooooooooool0Foooool5o`00
00;ooooo0_l00002ooooo`;o00001Oooool2o`0000kooooo0_l00005ooooo`;o00000_ooool2o`00
0003ooooool0003o000000;o00005_ooool3o`000003ooooool0003o000000?o000000?oooooo`00
0?l000001?ooool2o`000003ooooool0003o000000Cooooo0_l00003ooooo`;o00000_ooool2o`00
01;ooooo0_l0000Cooooo`?o0000E_ooool001cooooo00?o0000ooooooooool0Foooool5o`0000?o
oooo0_l00008ooooo`;o00001Oooool2o`0000Oooooo0_l00003ooooo`;o00001oooool2o`00017o
oooo0_l00004ooooo`[o00005Oooool7o`0000cooooo0ol0000Hooooo`;o0000E_ooool001cooooo
00?o0000ooooooooool0B?ooool2o`00017ooooo1Ol00003ooooo`;o00000_ooool3o`0000[ooooo
0_l0000<ooooo`;o000000?oooooo`000?l000001?ooool2o`0000gooooo1_l00002ooooo`[o0000
1?ooool2o`0001?ooooo0_l000000ooooooo0000o`00000<ooooo`?o00001Oooool2o`0001[ooooo
0_l0001=ooooo`007?ooool00ol0003oooooooooo`18ooooo`;o00005oooool2o`0000Cooooo0ol0
00000ooooooo0000o`000002o`0001Kooooo0_l0000Cooooo`Go000000?oooooo`000?l000002ol0
0003ooooo`;o000000Coooooo`000?l0003o00003oooool5o`0001Cooooo0_l0000Jooooo`;o0000
COooool001cooooo00?o0000ooooooooool0E_ooool2o`0000Wooooo0_l00008ooooo`Co00005ooo
ool2o`0001Gooooo0_l000000ooooooo0000o`00000<o`0000?ooooo1Ol00006ooooo`;o000000?o
ooooo`000?l000001_ooool5o`0000;ooooo0_l0001iooooo`007?ooool00ol0003oooooooooo`1;
ooooo`;o00002Oooool2o`0000Oooooo0_l0000<ooooo`Co00000oooool2o`00013ooooo0_l0000H
ooooo`So000000?oooooo`000?l000000ol00003ooooo`;o00002Oooool5o`0000Sooooo0ol00002
ooooo`;o00001Oooool2o`0001oooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`1;oooo
o`;o00004Oooool3o`0000kooooo0_l00003ooooo`;o00005Oooool2o`0000oooooo0_l00002oooo
o`ko00004?ooool2o`0000;ooooo0_l0000Aooooo`;o00007oooool2o`00057ooooo000Looooo`03
o`000?oooooooooo05kooooo0_l0000=ooooo`;o00002oooool2o`0000Cooooo0_l00009ooooo`;o
00001oooool2o`0000Kooooo0_l00002ooooo`ko00005?ooool2o`0000Sooooo1?l00005ooooo`;o
00004_ooool3o`0005gooooo000Looooo`03o`000?oooooooooo06[ooooo1Ol0000:ooooo`?o0000
1?ooool2o`0001;ooooo0_l0000:ooooo`So000000?oooooo`000?l000000ol0000;ooooo`;o0000
2oooool2o`0000Cooooo1?l00005ooooo`;o00004_ooool3o`0005gooooo000Looooo`03o`000?oo
oooooooo04oooooo0_l0000>ooooo`;o00002Oooool4o`0000Sooooo0_l000001?oooooo0000o`00
0?l00007ooooo`?o00006Oooool<o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l00000
0oooool2o`0000_ooooo0_l0000Cooooo`;o0000K?ooool001cooooo00?o0000ooooooooool0Cooo
ool2o`0000kooooo0_l00004ooooo`Co00003Oooool2o`0000Gooooo0_l00004ooooo`?o00003?oo
ool4o`0000Wooooo4?l00002ooooo`;o000000?oooooo`000?l000001?ooool2o`0001Wooooo0_l0
00000ooooooo0000o`000003o`0000[ooooo0_l0001Pooooo`007?ooool2o`00063ooooo0_l00004
ooooo`Co00002?ooool2o`0000[ooooo1?l0000Aooooo`Go00002Oooool:o`000003ooooool0003o
000000;ooooo1ol000001?oooooo0000o`000?ooool2o`0000Gooooo0ol00002ooooo`;o00003Ooo
ool2o`000003ooooool0003o000000;o00002oooool2o`00063ooooo000Looooo`03o`000?oooooo
oooo05Gooooo0_l00008ooooo`Co00003_ooool2o`000003ooooool0003o000000;o00001_ooool3
o`00017ooooo0_l000000ooooooo0000o`000003ooooo`;o00001?ooool9o`0000Kooooo1_l00002
ooooo`Oo00000oooool3o`0000;ooooo0_l000000ooooooo0000o`00001nooooo`007?ooool00ol0
003oooooooooo`1Eooooo`;o00001oooool2o`000003ooooool0003o000000Oooooo0_l00008oooo
o`Co00005?ooool2o`000004ooooool0003o0000ooooo`;o00001_ooool2o`0000Cooooo2Ol00009
ooooo`So00000_ooool2o`0000_ooooo0_l0000Xooooo`;o0000E?ooool001cooooo00?o0000oooo
ooooool0G_ooool2o`0000[ooooo0_l00009ooooo`;o000000Coooooo`000?l0003o00004Oooool7
o`0000Oooooo0_l00005ooooo`;o000000?oooooo`000?l000003_ooool5o`000004ooooool0003o
0000o`0003Kooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`1eooooo`;o000000Cooooo
o`000?l0003o00004_ooool6o`0000Oooooo0_l00008ooooo`;o00004?ooool2o`0000;ooooo0ol0
002<ooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o00003oooool4o`0000Gooooo0_l00003
ooooo`;o00001_ooool4o`0000_ooooo0_l0000Cooooo`;o00004?ooool2o`00097ooooo000Loooo
o`03o`000?oooooooooo05Wooooo0_l0000?ooooo`Co00001Oooool2o`0000Kooooo0ol00002oooo
o`Co00005_ooool4o`0000Wooooo1Ol000000ooooooo0000o`000007ooooo`;o00001?ooool4o`00
08Wooooo000Looooo`03o`000?oooooooooo06Cooooo0_l00006ooooo`?o00000oooool2o`0000Oo
oooo0ol00002ooooo`Ko00003Oooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000Wo
oooo1Ol000000ooooooo0000o`00000=ooooo`Co0000ROooool001cooooo00?o0000ooooooooool0
I?ooool2o`0000Kooooo0ol00003ooooo`;o00002?ooool2o`0000;ooooo1_l00003ooooo`;o0000
1?ooool2o`000004ooooool0003o0000o`0000;ooooo0_l00009ooooo`Co00004_ooool2o`0001Co
oooo0_l000000ooooooo0000o`00001fooooo`007?ooool00ol0003oooooooooo`1eooooo`?o0000
2?ooool2o`0000Oooooo0_l00004ooooo`;o000000?oooooo`000?l000002_ooool2o`0000;ooooo
1?l0000<ooooo`;o00001?ooool2o`0000Cooooo0_l0000=ooooo`?o000000?oooooo`000?l00000
M_ooool001cooooo00?o0000ooooooooool0D?ooool2o`0000Sooooo0_l0000Cooooo`;o000000Co
ooooo`000?l0003ooooo0ol00008ooooo`;o00004_ooool2o`0000Sooooo0_l0000=ooooo`;o0000
0oooool2o`000003ooooool0003o000000Oooooo0_l00007ooooo`;o00001?ooool2o`0007[ooooo
000Looooo`03o`000?oooooooooo053ooooo0_l00008ooooo`;o00002?ooool2o`0000Wooooo1Ol0
00000ooooooo0000o`000002ooooo`;o00004Oooool2o`0000Kooooo0_l00007ooooo`;o00003_oo
ool2o`0000Cooooo1?l00002ooooo`;o00003?ooool2o`00013ooooo0_l0001^ooooo`007?ooool0
0ol0003oooooooooo`1Tooooo`;o000000?oooooo`000?l000002?ooool2o`0000Gooooo0ol0000A
ooooo`;o00001Oooool5o`0000Gooooo0_l0000>ooooo`;o00001?ooool2o`0000Cooooo0_l0000N
ooooo`;o0000K_ooool001cooooo00?o0000ooooooooool0HOooool2o`0000Cooooo0_l00007oooo
o`Co00000oooool3o`0000Cooooo0_l0000;ooooo`;o00001?ooool4o`000003ooooool0003o0000
01Gooooo0_l0000;ooooo`?o0000S?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2
ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo067ooooo0_l0
000=ooooo`Ko000000?oooooo`000?l000001Oooool2o`0000_ooooo0ol00003ooooo`;o00002ooo
ool2o`0001[ooooo0ol0000<ooooo`;o0000O_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo06oo
oooo0_l00003ooooo`;o00000_ooool2o`0001;ooooo0_l0000@ooooo`;o00000_ooool2o`0002Go
oooo0_l0001nooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`1_ooooo`;o00001oooool2o`0000?o
oooo0_l00003ooooo`;o00007_ooool2o`0002Gooooo0_l0001nooooo`0000?oooooo`000?ooool0
0_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`0006Ko
oooo0_l0000Eooooo`;o00000oooool2o`0001Wooooo1?l0000Mooooo`;o00006_ooool2o`0006go
oooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Goc<c<o`000?l0003o
0000olc<c006ooooo`03o`000?oooooooooo06Kooooo0_l0000?ooooo`;o00009?ooool4o`0001go
oooo0_l0000Jooooo`;o00001Oooool2o`0006Kooooo00000ooooooo410@ooooo`02ooooo`03oa0@
4?oooooooooo00Wooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo07?o
oooo1_l00007ooooo`;o00005oooool2o`0000Oooooo0_l0000booooo`;o00002Oooool2o`0006Ko
oooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zjo`000006
ooooo`03o`000?oooooooooo07?ooooo1Ol00006ooooo`Co00005oooool3o`0000Kooooo0_l0000b
ooooo`;o0000LOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`00
0?l@413oZJVY00Kooooo00?o0000ooooooooool0G_ooool2o`0001Cooooo0_l00008ooooo`;o0000
00Coooooo`000?l0003ooooo0_l0000?ooooo`;o00000oooool2o`000:gooooo000Looooo`03o`00
0?oooooooooo05kooooo0_l0000Qooooo`;o000000?oooooo`000?l000003_ooool3o`000003oooo
ool0003o000000;o0000[Oooool001cooooo00?o0000ooooooooool0S_ooool4o`0000;ooooo0_l0
0002ooooo`Co000000?oooooo`000?l00000;_ooool2o`0007[ooooo000Looooo`03o`000?oooooo
oooo087ooooo0_l00002ooooo`;o000000?oooooo`000?l000001?ooool4o`0000Kooooo1?l00000
1?oooooo0000o`000?l0000Zooooo`;o000000?oooooo`000?l00000N_ooool001cooooo00?o0000
ooooooooool0POooool2o`0000;ooooo1Ol00006ooooo`;o00003?ooool2o`0002[ooooo0_l0001m
ooooo`007?ooool00ol0003oooooooooo`27ooooo`;o00001_ooool3o`000;Oooooo000Looooo`03
o`000?oooooooooo08oooooo0_l0000Cooooo`;o00004Oooool2o`0000Oooooo0_l00008ooooo`;o
0000OOooool001cooooo00?o0000ooooooooool0WOooool3o`0000Cooooo0_l0000Aooooo`;o0000
1oooool5o`0000Gooooo0_l0001mooooo`007?ooool00ol0003oooooooooo`1nooooo`;o00002Ooo
ool2o`0000oooooo0_l000001?oooooo0000o`000?l0000Qooooo`Co0000Q?ooool001cooooo00?o
0000ooooooooool0Noooool2o`000003ooooool0003o000000Oooooo1?l0000?ooooo`;o00005ooo
ool2o`0009Cooooo000Looooo`03o`000?oooooooooo07_ooooo1?l00007ooooo`?o00002_ooool3
o`0000Cooooo0_l0000Gooooo`;o0000U?ooool001cooooo00?o0000ooooooooool0N?ooool2o`00
00?ooooo0_l00007ooooo`;o00002oooool3o`000;?ooooo000Looooo`;o0000NOooool2o`0001Oo
oooo0_l0000Hooooo`;o0000W?ooool001cooooo00?o0000ooooooooool0Joooool2o`0002Cooooo
0_l00002ooooo`?o00004oooool2o`0009cooooo000Looooo`03o`000?oooooooooo06_ooooo0_l0
000Xooooo`?o0000/Oooool001cooooo00?o0000ooooooooool0QOooool2o`0001Gooooo0_l0002[
ooooo`007?ooool00ol0003oooooooooo`25ooooo`;o00005Oooool2o`0000Oooooo0_l0002Roooo
o`007?ooool00ol0003oooooooooo`2Eooooo`;o00003_ooool2o`000:;ooooo000Looooo`03o`00
0?oooooooooo08kooooo0_l00005ooooo`;o00002?ooool2o`000:Sooooo000Looooo`03o`000?oo
oooooooo08Wooooo1?l000000ooooooo0000o`00000?ooooo`;o0000Z?ooool001cooooo00?o0000
ooooooooool0ROooool4o`000;cooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`1iooooo`;o0000
c_ooool001cooooo00?o0000ooooooooool0NOooool2o`0003Kooooo0_l0002Fooooo`007?ooool0
0ol0003oooooooooo`2aooooo`;o0000U_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0
oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB_oo
ool001Cooooo00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o0000oooo
ooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`00
0?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`004_ooool0
0omEEEGoIVIVo`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
002Uooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05Oooool01?l@413o0000
odA4A?o<c<`4ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^093ooooo002Vooooo`05o`000?ooooooooooooooool000002Oooool6o`0000_ooooo00?oV9RH
oa0@4?oMgMd00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`2@ooooo`00Y_ooool01Ol0003ooooooooooooooooo000001_ooooo00?oQhN7oeEEEOooool0
0_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@402@oooo
o`00Y_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l00009ooooo`05olc<c?lQ8B7o0000
oeEEEOl000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`00002@ooooo`00Y_ooool01Ol0003oQhN7oooooonYZJWo000001Sooooo00Go8B4QohN7Qooooooo
V9RHo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
0000093ooooo002Uooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool05_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oo
ooooooooooooool@4100T?ooool00<?ooooo00Go8B4QoiRHV?ooooooMgMgoeEEE@03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg093ooooo0033ooooo`05
olc<c?l@413o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP2@ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(906) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.31452 .42862 Mdot
.34877 .41023 Mdot
.56887 .61137 Mdot
.58288 .40968 Mdot
.40862 .4527 Mdot
.56928 .64524 Mdot
.34201 .57534 Mdot
.37148 .61282 Mdot
.5565 .635 Mdot
.64089 .41884 Mdot
.36966 .60027 Mdot
.51001 .44808 Mdot
.36829 .57418 Mdot
.56913 .39892 Mdot
.85709 .52415 Mdot
.51868 .33455 Mdot
.37766 .40462 Mdot
.72372 .59607 Mdot
.55194 .4609 Mdot
.59321 .65481 Mdot
.39589 .44662 Mdot
.57417 .39281 Mdot
.31962 .43924 Mdot
.56863 .39839 Mdot
.5667 .42853 Mdot
.33605 .42987 Mdot
.35936 .38232 Mdot
.5625 .44192 Mdot
.53294 .42081 Mdot
.39017 .59452 Mdot
.70858 .5217 Mdot
.82623 .40079 Mdot
.49267 .36354 Mdot
.23193 .34506 Mdot
.35837 .6129 Mdot
.64378 .26373 Mdot
.53343 .65654 Mdot
.37798 .56791 Mdot
.3683 .61188 Mdot
.35608 .61961 Mdot
.38061 .57596 Mdot
.34388 .4285 Mdot
.41131 .58539 Mdot
.38824 .54253 Mdot
.5796 .35481 Mdot
.27631 .563 Mdot
.73188 .37029 Mdot
.51814 .3893 Mdot
.34531 .39873 Mdot
.59023 .66476 Mdot
.22808 .39741 Mdot
.39339 .61066 Mdot
.49929 .71692 Mdot
.70221 .17965 Mdot
.36495 .56191 Mdot
.59116 .36896 Mdot
.54479 .65243 Mdot
.5613 .37665 Mdot
.56499 .3925 Mdot
.40589 .36283 Mdot
.53891 .43718 Mdot
.67864 .58948 Mdot
.36762 .46505 Mdot
.53349 .68913 Mdot
.56288 .64382 Mdot
.375 .60768 Mdot
.37661 .40906 Mdot
.35979 .57459 Mdot
.59832 .42407 Mdot
.53845 .67691 Mdot
.51852 .38821 Mdot
.38046 .59725 Mdot
.31221 .44756 Mdot
.52568 .36421 Mdot
.27867 .67639 Mdot
.80729 .62652 Mdot
.7049 .56672 Mdot
.42633 .34706 Mdot
.49237 .31152 Mdot
.69385 .73346 Mdot
.54524 .41282 Mdot
.54539 .84077 Mdot
.84338 .55124 Mdot
.31627 .42645 Mdot
.62302 .37169 Mdot
.52982 .60126 Mdot
.53695 .35579 Mdot
.47177 .49961 Mdot
.60444 .37817 Mdot
.2409 .62264 Mdot
.55179 .63413 Mdot
.36629 .42385 Mdot
.5818 .40947 Mdot
.50699 .41163 Mdot
.38151 .28129 Mdot
.53695 .44799 Mdot
.58319 .42563 Mdot
.31388 .39544 Mdot
.35404 .60278 Mdot
.47753 .40434 Mdot
.34377 .53919 Mdot
.47957 .7411 Mdot
.57454 .35896 Mdot
.5323 .63998 Mdot
.30861 .40164 Mdot
.54788 .35081 Mdot
.33078 .58466 Mdot
.5213 .40742 Mdot
.40837 .56146 Mdot
.35137 .40631 Mdot
.50533 .4085 Mdot
.70226 .61431 Mdot
.34267 .76319 Mdot
.36781 .42858 Mdot
.44912 .74172 Mdot
.51608 .41023 Mdot
.57605 .38148 Mdot
.3496 .41274 Mdot
.58124 .65211 Mdot
.54908 .51747 Mdot
.35092 .3928 Mdot
.35006 .61608 Mdot
.39014 .4129 Mdot
.60939 .34501 Mdot
.5636 .62821 Mdot
.47568 .73153 Mdot
.47942 .71858 Mdot
.66124 .49529 Mdot
.54442 .35466 Mdot
.24395 .46736 Mdot
.5755 .64703 Mdot
.3604 .42351 Mdot
.36216 .57764 Mdot
.57096 .34099 Mdot
.36932 .44206 Mdot
.35943 .5925 Mdot
.66523 .61323 Mdot
.63623 .64562 Mdot
.34029 .3957 Mdot
.40416 .63761 Mdot
.35744 .62522 Mdot
.3466 .61752 Mdot
.22382 .36714 Mdot
.34278 .4093 Mdot
.70642 .59879 Mdot
.35472 .58745 Mdot
.75966 .47813 Mdot
.59756 .37955 Mdot
.62469 .49488 Mdot
.43058 .84578 Mdot
.21714 .40604 Mdot
.38731 .72737 Mdot
.71575 .58376 Mdot
.33531 .61246 Mdot
.55022 .42749 Mdot
.33291 .41176 Mdot
.33705 .41885 Mdot
.58457 .43274 Mdot
.57524 .42628 Mdot
.51873 .37972 Mdot
.50953 .41303 Mdot
.76722 .4048 Mdot
.50982 .3897 Mdot
.66876 .56304 Mdot
.36147 .43677 Mdot
.55412 .43657 Mdot
.58695 .64857 Mdot
.52567 .34417 Mdot
.38286 .58589 Mdot
.56992 .38361 Mdot
.58301 .41531 Mdot
.50011 .40255 Mdot
.35965 .55802 Mdot
.79811 .37595 Mdot
.40758 .82944 Mdot
.65274 .23101 Mdot
.4286 .73477 Mdot
.55521 .66422 Mdot
.56145 .35841 Mdot
.69258 .5986 Mdot
.5622 .25572 Mdot
.55081 .40357 Mdot
.16163 .54857 Mdot
.58625 .41634 Mdot
.31288 .27105 Mdot
.45163 .38454 Mdot
.65051 .22222 Mdot
.61115 .55072 Mdot
.52924 .42242 Mdot
.40235 .25039 Mdot
.47553 .20023 Mdot
.41443 .54513 Mdot
.37738 .57254 Mdot
.58721 .64439 Mdot
.54045 .64638 Mdot
.39504 .61604 Mdot
.47714 .36969 Mdot
.47169 .4279 Mdot
.5519 .47331 Mdot
.48295 .72624 Mdot
.31909 .45605 Mdot
.66873 .58367 Mdot
.30665 .41269 Mdot
.64601 .82336 Mdot
.22433 .5882 Mdot
.41531 .59517 Mdot
.6689 .57489 Mdot
.57632 .61546 Mdot
.48527 .72406 Mdot
.69405 .60332 Mdot
.53353 .39136 Mdot
.35776 .40176 Mdot
.3348 .23304 Mdot
.49147 .33196 Mdot
.34815 .20889 Mdot
.37518 .44408 Mdot
.53497 .52534 Mdot
.36847 .59042 Mdot
.59622 .62994 Mdot
.58278 .38862 Mdot
.5337 .37454 Mdot
.36922 .47062 Mdot
.5205 .38931 Mdot
.37616 .47837 Mdot
.59002 .40548 Mdot
.59658 .60973 Mdot
.71522 .56903 Mdot
.39671 .61379 Mdot
.65152 .50001 Mdot
.31915 .44721 Mdot
.57953 .57942 Mdot
.57375 .67471 Mdot
.58259 .26163 Mdot
.37751 .60009 Mdot
.69071 .61706 Mdot
.57533 .67079 Mdot
.67468 .57769 Mdot
.51454 .35613 Mdot
.53363 .66223 Mdot
.70417 .58191 Mdot
.79013 .40506 Mdot
.57106 .34508 Mdot
.78162 .44435 Mdot
.34082 .57988 Mdot
.39184 .41561 Mdot
.54331 .43927 Mdot
.46799 .72981 Mdot
.49115 .38938 Mdot
.34262 .6858 Mdot
.49235 .71289 Mdot
.50357 .72424 Mdot
.73034 .69819 Mdot
.70888 .60877 Mdot
.34555 .72532 Mdot
.229 .45729 Mdot
.37497 .40343 Mdot
.59216 .3884 Mdot
.71057 .26403 Mdot
.35553 .58738 Mdot
.53609 .39477 Mdot
.55722 .59236 Mdot
.35299 .58492 Mdot
.5581 .37233 Mdot
.34235 .56517 Mdot
.33687 .41417 Mdot
.54747 .77325 Mdot
.38281 .40957 Mdot
.57801 .34967 Mdot
.33407 .58014 Mdot
.55472 .67324 Mdot
.33203 .42969 Mdot
.52361 .40488 Mdot
.58059 .37931 Mdot
.48478 .73302 Mdot
.54025 .43274 Mdot
.71956 .28246 Mdot
.5235 .42713 Mdot
.55177 .6144 Mdot
.53842 .44626 Mdot
.16237 .50174 Mdot
.60734 .69576 Mdot
.37408 .40692 Mdot
.50238 .72274 Mdot
.5546 .64077 Mdot
.66068 .72483 Mdot
.43775 .58635 Mdot
.53167 .41271 Mdot
.49484 .73567 Mdot
.60471 .53494 Mdot
.39514 .59127 Mdot
.55335 .45463 Mdot
.24793 .60238 Mdot
.58797 .65779 Mdot
.48559 .72661 Mdot
.58712 .45712 Mdot
.30653 .40327 Mdot
.58167 .41166 Mdot
.54794 .67555 Mdot
.38929 .40981 Mdot
.54491 .3417 Mdot
.69296 .35582 Mdot
.48828 .71461 Mdot
.34308 .57764 Mdot
.44641 .41349 Mdot
.51392 .38558 Mdot
.53876 .65753 Mdot
.33246 .45295 Mdot
.35172 .61215 Mdot
.34491 .43463 Mdot
.40453 .20368 Mdot
.42105 .74598 Mdot
.74613 .36372 Mdot
.66233 .57806 Mdot
.39576 .67992 Mdot
.62843 .20877 Mdot
.36534 .75298 Mdot
.72285 .46924 Mdot
.49353 .16357 Mdot
.57935 .66279 Mdot
.63163 .61961 Mdot
.55199 .64659 Mdot
.56092 .417 Mdot
.56654 .6434 Mdot
.6484 .21556 Mdot
.58947 .41201 Mdot
.54872 .66261 Mdot
.59542 .74948 Mdot
.56925 .4337 Mdot
.36872 .43052 Mdot
.85083 .51754 Mdot
.24836 .67571 Mdot
.19324 .49947 Mdot
.56724 .6645 Mdot
.42582 .3932 Mdot
.56467 .44006 Mdot
.50291 .35558 Mdot
.32691 .41475 Mdot
.55388 .45155 Mdot
.66873 .58499 Mdot
.66421 .58241 Mdot
.61055 .50319 Mdot
.46693 .82264 Mdot
.47826 .41111 Mdot
.3298 .42662 Mdot
.54203 .28344 Mdot
.27631 .66446 Mdot
.47186 .74563 Mdot
.33592 .55052 Mdot
.80638 .39345 Mdot
.46699 .39652 Mdot
.39605 .63851 Mdot
.26024 .62124 Mdot
.36539 .41107 Mdot
.75905 .33942 Mdot
.3712 .56758 Mdot
.46028 .24504 Mdot
.30751 .31446 Mdot
.53497 .38078 Mdot
.37132 .60368 Mdot
.49165 .43426 Mdot
.21749 .61178 Mdot
.77769 .49987 Mdot
.70581 .75904 Mdot
.57667 .35035 Mdot
.3248 .71108 Mdot
.57388 .38335 Mdot
.56495 .50671 Mdot
.52369 .4278 Mdot
.34097 .43776 Mdot
.64045 .36358 Mdot
.44001 .51704 Mdot
.45694 .83692 Mdot
.21733 .5741 Mdot
.71294 .5812 Mdot
.57985 .3821 Mdot
.53575 .37933 Mdot
.68996 .61323 Mdot
.33164 .44426 Mdot
.51604 .41855 Mdot
.67798 .4186 Mdot
.52367 .37886 Mdot
.38316 .57596 Mdot
.65454 .52772 Mdot
.36657 .47819 Mdot
.50303 .41286 Mdot
.37721 .39836 Mdot
.35434 .56025 Mdot
.37714 .60884 Mdot
.61257 .38733 Mdot
.32673 .59377 Mdot
.58604 .40775 Mdot
.75811 .5608 Mdot
.31801 .412 Mdot
.48644 .33339 Mdot
.33828 .44951 Mdot
.46623 .33183 Mdot
.33106 .58029 Mdot
.47137 .72792 Mdot
.27223 .41028 Mdot
.36894 .56846 Mdot
.20104 .4712 Mdot
.5289 .47167 Mdot
.49759 .42389 Mdot
.2076 .58351 Mdot
.56794 .66751 Mdot
.4787 .72218 Mdot
.33039 .59277 Mdot
.51467 .38372 Mdot
.52691 .44891 Mdot
.37987 .56517 Mdot
.41444 .28328 Mdot
.66678 .71368 Mdot
.57177 .43744 Mdot
.33689 .44024 Mdot
.35895 .42575 Mdot
.53842 .34643 Mdot
.53188 .40614 Mdot
.56258 .61587 Mdot
.4984 .7217 Mdot
.48443 .74503 Mdot
.48117 .71816 Mdot
.58194 .603 Mdot
.31138 .52711 Mdot
.35353 .61925 Mdot
.26455 .49044 Mdot
.31224 .6571 Mdot
.53023 .31539 Mdot
.54205 .66562 Mdot
.54402 .37602 Mdot
.58193 .40223 Mdot
.34988 .61153 Mdot
.41449 .69702 Mdot
.62077 .36273 Mdot
.32544 .40165 Mdot
.32757 .58635 Mdot
.48497 .43521 Mdot
.30284 .49195 Mdot
.68779 .58028 Mdot
.19004 .50548 Mdot
.37866 .60148 Mdot
.37109 .415 Mdot
.36179 .55236 Mdot
.53126 .37752 Mdot
.59739 .40758 Mdot
.35669 .41254 Mdot
.71631 .60182 Mdot
.59781 .43846 Mdot
.5587 .37075 Mdot
.21444 .69785 Mdot
.28127 .68186 Mdot
.31957 .6277 Mdot
.54063 .42635 Mdot
.51396 .44047 Mdot
.70234 .57353 Mdot
.52622 .38023 Mdot
.58227 .37876 Mdot
.35069 .77546 Mdot
.30776 .61807 Mdot
.72426 .60159 Mdot
.46812 .24428 Mdot
.37669 .44243 Mdot
.75667 .3165 Mdot
.48568 .74302 Mdot
.40435 .58669 Mdot
.53178 .77159 Mdot
.48971 .72243 Mdot
.35138 .68196 Mdot
.76004 .3304 Mdot
.48062 .71915 Mdot
.5299 .59297 Mdot
.63145 .3788 Mdot
.58201 .43109 Mdot
.57012 .3779 Mdot
.69563 .59398 Mdot
.34049 .41002 Mdot
.57588 .54049 Mdot
.79686 .52694 Mdot
.57568 .38916 Mdot
.40475 .41391 Mdot
.80537 .42078 Mdot
.48753 .73038 Mdot
.66668 .59594 Mdot
.65478 .61278 Mdot
.57482 .37781 Mdot
.38381 .78599 Mdot
.33455 .42841 Mdot
.52403 .40516 Mdot
.50706 .38649 Mdot
.56345 .66652 Mdot
.36705 .40556 Mdot
.56689 .67677 Mdot
.48792 .71244 Mdot
.51762 .19275 Mdot
.18644 .65928 Mdot
.34342 .60612 Mdot
.68597 .27128 Mdot
.39342 .59757 Mdot
.73232 .72085 Mdot
.49115 .71876 Mdot
.54685 .40812 Mdot
.31823 .44828 Mdot
.52022 .40579 Mdot
.54194 .39171 Mdot
.53421 .38997 Mdot
.51696 .464 Mdot
.16188 .5394 Mdot
.68053 .6035 Mdot
.57451 .3219 Mdot
.54733 .61867 Mdot
.70557 .27934 Mdot
.82192 .55932 Mdot
.54065 .3697 Mdot
.57429 .37204 Mdot
.36907 .43575 Mdot
.58031 .43797 Mdot
.39248 .58112 Mdot
.33143 .45301 Mdot
.49948 .39572 Mdot
.74909 .33477 Mdot
.51322 .41381 Mdot
.63053 .21777 Mdot
.36473 .55233 Mdot
.20098 .47615 Mdot
.58521 .32878 Mdot
.47594 .72184 Mdot
.47891 .72179 Mdot
.49854 .74107 Mdot
.36903 .5495 Mdot
.54276 .66068 Mdot
.78917 .58716 Mdot
.49182 .35334 Mdot
.55433 .42804 Mdot
.52387 .44817 Mdot
.54436 .60305 Mdot
.46952 .49483 Mdot
.37023 .73304 Mdot
.49053 .44289 Mdot
.56894 .62221 Mdot
.39346 .41774 Mdot
.47688 .70288 Mdot
.32894 .45085 Mdot
.72626 .59828 Mdot
.3719 .59826 Mdot
.67888 .58156 Mdot
.21131 .43352 Mdot
.3506 .40807 Mdot
.36505 .4729 Mdot
.55258 .66421 Mdot
.5119 .53191 Mdot
.67576 .17792 Mdot
.53202 .67495 Mdot
.67884 .4635 Mdot
.32447 .42045 Mdot
.50395 .38714 Mdot
.62706 .5331 Mdot
.5028 .5271 Mdot
.55417 .65739 Mdot
.55692 .40776 Mdot
.43957 .80693 Mdot
.56484 .61617 Mdot
.55252 .45522 Mdot
.58094 .64319 Mdot
.38058 .58609 Mdot
.57776 .64729 Mdot
.3359 .45807 Mdot
.5541 .35179 Mdot
.70254 .19105 Mdot
.59352 .56947 Mdot
.52818 .42854 Mdot
.32795 .58496 Mdot
.67019 .38586 Mdot
.5491 .38724 Mdot
.66317 .59012 Mdot
.56526 .62694 Mdot
.68253 .68631 Mdot
.55706 .44219 Mdot
.56777 .65498 Mdot
.3158 .43507 Mdot
.37762 .55173 Mdot
.74616 .68912 Mdot
.47249 .73557 Mdot
.32842 .40989 Mdot
.496 .70815 Mdot
.33118 .56592 Mdot
.52316 .44523 Mdot
.51027 .38313 Mdot
.35097 .4393 Mdot
.54471 .79488 Mdot
.54225 .44444 Mdot
.54554 .41267 Mdot
.58277 .61583 Mdot
.53829 .6099 Mdot
.55996 .78329 Mdot
.57639 .6657 Mdot
.56181 .46061 Mdot
.35019 .43885 Mdot
.57725 .40873 Mdot
.37282 .42619 Mdot
.5913 .39287 Mdot
.33747 .37133 Mdot
.31665 .42319 Mdot
.43797 .77715 Mdot
.56707 .4094 Mdot
.44844 .39625 Mdot
.53802 .38968 Mdot
.52087 .38456 Mdot
.55026 .62168 Mdot
.67386 .60701 Mdot
.57889 .33884 Mdot
.63152 .59417 Mdot
.66289 .59895 Mdot
.427 .20523 Mdot
.56774 .66558 Mdot
.69436 .587 Mdot
.78525 .43488 Mdot
.50215 .72755 Mdot
.68542 .59736 Mdot
.82898 .54425 Mdot
.34553 .60833 Mdot
.38506 .4372 Mdot
.56929 .43323 Mdot
.47295 .16756 Mdot
.74699 .53681 Mdot
.49015 .73558 Mdot
.52463 .42672 Mdot
.54651 .37917 Mdot
.33475 .38919 Mdot
.60814 .83689 Mdot
.56258 .60872 Mdot
.5632 .42016 Mdot
.38198 .41574 Mdot
.46638 .86018 Mdot
.53772 .63026 Mdot
.68964 .59668 Mdot
.37502 .56116 Mdot
.31305 .38725 Mdot
.47232 .73722 Mdot
.39529 .58643 Mdot
.50467 .7583 Mdot
.19874 .46351 Mdot
.51483 .40909 Mdot
.53845 .66408 Mdot
.20363 .42365 Mdot
.47944 .37281 Mdot
.34129 .63773 Mdot
.5466 .48829 Mdot
.36725 .4137 Mdot
.37972 .56627 Mdot
.69156 .57624 Mdot
.33489 .45581 Mdot
.33072 .4421 Mdot
.36936 .61477 Mdot
.51263 .67936 Mdot
.52918 .52591 Mdot
.38563 .58343 Mdot
.24883 .62732 Mdot
.3607 .22234 Mdot
.49926 .72859 Mdot
.66637 .60711 Mdot
.27183 .30193 Mdot
.34381 .42923 Mdot
.80462 .38983 Mdot
.18201 .47879 Mdot
.58275 .4262 Mdot
.70504 .58888 Mdot
.29588 .57492 Mdot
.79839 .56604 Mdot
.35014 .58292 Mdot
.42975 .49852 Mdot
.66714 .62039 Mdot
.56515 .44301 Mdot
.35541 .36333 Mdot
.55642 .41382 Mdot
.36951 .59538 Mdot
.46872 .3401 Mdot
.372 .41605 Mdot
.32644 .57436 Mdot
.18902 .50192 Mdot
.58386 .39879 Mdot
.56028 .40959 Mdot
.68316 .5171 Mdot
.35411 .40025 Mdot
.47909 .74448 Mdot
.52369 .41299 Mdot
.56367 .37668 Mdot
.50522 .42619 Mdot
.45684 .41585 Mdot
.35538 .76681 Mdot
.56427 .41843 Mdot
.60214 .63274 Mdot
.49718 .36525 Mdot
.56731 .40684 Mdot
.37449 .39706 Mdot
.18309 .64137 Mdot
.47261 .72236 Mdot
.56826 .38142 Mdot
.51338 .40981 Mdot
.36042 .61489 Mdot
.57233 .53277 Mdot
.49195 .52502 Mdot
.53039 .66358 Mdot
.74184 .45134 Mdot
.51673 .46349 Mdot
.37056 .4434 Mdot
.68605 .61874 Mdot
.52255 .35752 Mdot
.37362 .43778 Mdot
.52227 .33936 Mdot
.56891 .61916 Mdot
.49898 .72591 Mdot
.2047 .51497 Mdot
.68468 .59169 Mdot
.72606 .53874 Mdot
.26275 .50771 Mdot
.58848 .64103 Mdot
.55847 .42974 Mdot
.40102 .58996 Mdot
.53238 .66351 Mdot
.48353 .7346 Mdot
.61493 .41378 Mdot
.33385 .4199 Mdot
.36664 .42683 Mdot
.61896 .50897 Mdot
.60117 .67056 Mdot
.29361 .7632 Mdot
.37983 .58804 Mdot
.5 .36643 Mdot
.23351 .4633 Mdot
.36743 .42726 Mdot
.62789 .50796 Mdot
.693 .58628 Mdot
.34866 .58219 Mdot
.47946 .74956 Mdot
.37085 .43788 Mdot
.34833 .39693 Mdot
.56493 .34263 Mdot
.5468 .3635 Mdot
.71493 .47098 Mdot
.61597 .50354 Mdot
.3661 .5596 Mdot
.67839 .61368 Mdot
.5591 .68071 Mdot
.55435 .41873 Mdot
.31655 .42951 Mdot
.32748 .24577 Mdot
.50968 .40434 Mdot
.56149 .61506 Mdot
.36479 .41471 Mdot
.69568 .61284 Mdot
.66329 .59299 Mdot
.52157 .38419 Mdot
.42322 .36405 Mdot
.35378 .5655 Mdot
.36932 .42792 Mdot
.24851 .40154 Mdot
.538 .44326 Mdot
.54756 .36027 Mdot
.57514 .47066 Mdot
.38703 .60219 Mdot
.20453 .47648 Mdot
.71354 .60968 Mdot
.3443 .42052 Mdot
.52136 .4196 Mdot
.67969 .58925 Mdot
.21887 .46367 Mdot
.49412 .72467 Mdot
.57898 .64307 Mdot
.66412 .58811 Mdot
.70501 .60548 Mdot
.66326 .6087 Mdot
.81428 .40615 Mdot
.31453 .45229 Mdot
.55356 .28781 Mdot
.53017 .43388 Mdot
.61951 .51095 Mdot
.59585 .36073 Mdot
.3727 .55331 Mdot
.56889 .66862 Mdot
.54094 .38791 Mdot
.56482 .34298 Mdot
.47076 .44508 Mdot
.46764 .36639 Mdot
.40406 .4292 Mdot
.35604 .4049 Mdot
.51932 .32331 Mdot
.56042 .66876 Mdot
.60949 .84531 Mdot
.66798 .19835 Mdot
.60213 .34399 Mdot
.54799 .5321 Mdot
.31966 .43803 Mdot
.37256 .61574 Mdot
.47652 .5247 Mdot
.34929 .55652 Mdot
.35025 .42196 Mdot
.55737 .41824 Mdot
.27008 .49537 Mdot
.68284 .5725 Mdot
.51634 .38045 Mdot
.36363 .58911 Mdot
.51735 .38018 Mdot
.38842 .57277 Mdot
.2904 .46116 Mdot
.2595 .6394 Mdot
.58623 .41706 Mdot
.52561 .43974 Mdot
.45229 .4345 Mdot
.54328 .37 Mdot
.59864 .81134 Mdot
.32695 .44403 Mdot
.45332 .81371 Mdot
.54798 .34015 Mdot
.4546 .32061 Mdot
.53498 .43847 Mdot
.50243 .79089 Mdot
.54002 .36103 Mdot
.46286 .54955 Mdot
.57779 .43405 Mdot
.57242 .36365 Mdot
.33684 .57491 Mdot
.36115 .61482 Mdot
.31218 .41456 Mdot
.47523 .74311 Mdot
.66401 .23911 Mdot
.55539 .36604 Mdot
.59476 .6131 Mdot
.36316 .64417 Mdot
.69523 .61066 Mdot
.34954 .42424 Mdot
.47683 .86973 Mdot
.3458 .56328 Mdot
.55345 .68792 Mdot
.54995 .80096 Mdot
.59678 .64183 Mdot
.30761 .57911 Mdot
.61279 .46507 Mdot
.71399 .60274 Mdot
.55746 .44508 Mdot
.23875 .34457 Mdot
.28907 .67842 Mdot
.60954 .42009 Mdot
.32984 .57112 Mdot
.56059 .26098 Mdot
.2731 .30355 Mdot
.65222 .60411 Mdot
.7042 .57846 Mdot
.34474 .56707 Mdot
.5882 .617 Mdot
.5378 .46845 Mdot
.69262 .58521 Mdot
.58388 .62906 Mdot
.5025 .73584 Mdot
.43549 .55031 Mdot
.33777 .42737 Mdot
.19249 .50712 Mdot
.26034 .54708 Mdot
.36273 .5585 Mdot
.61293 .59916 Mdot
.32982 .37619 Mdot
.29846 .4203 Mdot
.46981 .73665 Mdot
.54916 .62153 Mdot
.32508 .45565 Mdot
.5718 .45634 Mdot
.4713 .35436 Mdot
.57345 .38598 Mdot
.70079 .59743 Mdot
.53647 .36588 Mdot
.55616 .61965 Mdot
.35422 .58131 Mdot
.54145 .63523 Mdot
.34011 .57404 Mdot
.30104 .52276 Mdot
.52681 .40053 Mdot
.57096 .36405 Mdot
.74397 .54133 Mdot
.3162 .40383 Mdot
.2308 .40089 Mdot
.58956 .60437 Mdot
.54714 .64909 Mdot
.58815 .38863 Mdot
.32233 .44698 Mdot
.7263 .57231 Mdot
.74444 .54579 Mdot
.51514 .37329 Mdot
.32726 .44488 Mdot
.55819 .4239 Mdot
.78255 .41312 Mdot
.27222 .6893 Mdot
.3499 .43422 Mdot
.48622 .83417 Mdot
.54136 .42172 Mdot
.62313 .33431 Mdot
.52885 .45135 Mdot
.68823 .42769 Mdot
.54138 .44518 Mdot
.37456 .44496 Mdot
.56955 .38619 Mdot
.34233 .4561 Mdot
.58933 .62624 Mdot
.36859 .61908 Mdot
.324 .41225 Mdot
.51049 .37613 Mdot
.80806 .36337 Mdot
.37328 .59236 Mdot
.58053 .38438 Mdot
.35025 .59949 Mdot
.38414 .4251 Mdot
.33828 .39868 Mdot
.80377 .5814 Mdot
.31618 .63042 Mdot
.38018 .58382 Mdot
.56898 .42081 Mdot
.23937 .54529 Mdot
.57217 .41215 Mdot
.70521 .47757 Mdot
.56982 .35031 Mdot
.53908 .44553 Mdot
.80583 .64302 Mdot
.39533 .59748 Mdot
.30387 .76634 Mdot
.79875 .51044 Mdot
.8191 .41897 Mdot
.29689 .40467 Mdot
.65223 .60459 Mdot
.76721 .34763 Mdot
.49066 .71254 Mdot
.57365 .63527 Mdot
.53983 .38718 Mdot
.30831 .46761 Mdot
.37896 .56793 Mdot
.6774 .608 Mdot
.58684 .41551 Mdot
.55645 .61565 Mdot
.72105 .68679 Mdot
.33056 .60679 Mdot
.34453 .42803 Mdot
.32327 .40117 Mdot
.44481 .84884 Mdot
.52045 .41972 Mdot
.57762 .3741 Mdot
.36992 .59772 Mdot
.47084 .37346 Mdot
.69612 .61501 Mdot
.59096 .74101 Mdot
.37957 .58368 Mdot
.51482 .56586 Mdot
.34792 .4053 Mdot
.54501 .3779 Mdot
.48644 .49945 Mdot
.44395 .62924 Mdot
.46693 .22104 Mdot
.69512 .59694 Mdot
.70946 .48891 Mdot
.37497 .44456 Mdot
.36163 .58133 Mdot
.64552 .6422 Mdot
.49241 .37857 Mdot
.55105 .37935 Mdot
.70804 .49293 Mdot
.59076 .53694 Mdot
.7232 .5639 Mdot
.59322 .4241 Mdot
.59105 .53353 Mdot
.58748 .38081 Mdot
.5012 .4189 Mdot
.58942 .43765 Mdot
.54816 .35625 Mdot
.3246 .44319 Mdot
.47752 .44591 Mdot
.57309 .64913 Mdot
.38961 .27497 Mdot
.44258 .50339 Mdot
.54496 .43797 Mdot
.56245 .41525 Mdot
.51464 .22759 Mdot
.32665 .64785 Mdot
.32323 .43473 Mdot
.34777 .46446 Mdot
.32941 .59879 Mdot
.44719 .39649 Mdot
.56969 .60467 Mdot
.51776 .47637 Mdot
.54387 .6324 Mdot
.33027 .44809 Mdot
.54209 .65007 Mdot
.33483 .60855 Mdot
.53817 .66415 Mdot
.58442 .60358 Mdot
.38536 .57156 Mdot
.33895 .40349 Mdot
.52392 .36783 Mdot
.32813 .58872 Mdot
.68581 .51519 Mdot
.70042 .59632 Mdot
.80493 .57978 Mdot
.50662 .35616 Mdot
.41966 .47857 Mdot
.69417 .35782 Mdot
.54237 .6368 Mdot
.29443 .72468 Mdot
.31673 .42156 Mdot
.70051 .56927 Mdot
.32685 .447 Mdot
.17452 .50138 Mdot
.67372 .60957 Mdot
.8311 .53974 Mdot
.5269 .7076 Mdot
.72102 .66908 Mdot
.59801 .41302 Mdot
.32389 .37026 Mdot
.54219 .67622 Mdot
.37746 .56679 Mdot
.51693 .71959 Mdot
.56664 .3569 Mdot
.37541 .75635 Mdot
.31757 .39821 Mdot
.49997 .73647 Mdot
.36195 .57492 Mdot
.32544 .58256 Mdot
.51634 .40657 Mdot
.61098 .75927 Mdot
.55935 .3498 Mdot
.57609 .69825 Mdot
.72997 .46932 Mdot
.53027 .48227 Mdot
.58959 .40151 Mdot
.53325 .64208 Mdot
.55919 .42411 Mdot
.58691 .28 Mdot
.22609 .3626 Mdot
.56096 .46728 Mdot
.43007 .75723 Mdot
.73166 .60989 Mdot
.35282 .41129 Mdot
.58237 .32842 Mdot
.4802 .73865 Mdot
.54038 .42407 Mdot
.21969 .30424 Mdot
.68262 .59632 Mdot
.57996 .58733 Mdot
.52465 .43284 Mdot
.52119 .41053 Mdot
.28394 .34407 Mdot
.29924 .46058 Mdot
.47919 .75016 Mdot
.55575 .38009 Mdot
.75041 .4701 Mdot
.36165 .60722 Mdot
.5485 .34771 Mdot
.57204 .37842 Mdot
.46403 .19863 Mdot
.38328 .60373 Mdot
.54027 .64091 Mdot
.49818 .71671 Mdot
.56557 .67969 Mdot
.68595 .62391 Mdot
.48149 .53754 Mdot
.62697 .49739 Mdot
.27213 .68557 Mdot
.65638 .6094 Mdot
.50547 .40133 Mdot
.62119 .36134 Mdot
.53306 .41742 Mdot
.697 .5754 Mdot
.38835 .59703 Mdot
.31931 .42628 Mdot
.21094 .52075 Mdot
.48351 .72768 Mdot
.54944 .45492 Mdot
.67388 .57999 Mdot
.33263 .41409 Mdot
.58951 .58018 Mdot
.34781 .41559 Mdot
.37448 .57492 Mdot
.34789 .54813 Mdot
.67016 .59872 Mdot
.33133 .45059 Mdot
.59682 .66165 Mdot
.79475 .53213 Mdot
.58058 .35926 Mdot
.31891 .60273 Mdot
.31392 .43605 Mdot
.35662 .38266 Mdot
.31016 .40442 Mdot
.52216 .39301 Mdot
.55803 .53084 Mdot
.49916 .40913 Mdot
.34936 .56359 Mdot
.58046 .63415 Mdot
.62315 .4905 Mdot
.26226 .35374 Mdot
.56193 .5634 Mdot
.60232 .36935 Mdot
.58032 .39473 Mdot
.57495 .37811 Mdot
.59082 .36239 Mdot
.62432 .65024 Mdot
.53017 .40411 Mdot
.33738 .57543 Mdot
.55365 .62623 Mdot
.53503 .43528 Mdot
.48301 .74107 Mdot
.52174 .52041 Mdot
.67604 .61927 Mdot
.46085 .5268 Mdot
.75856 .30823 Mdot
.33067 .41399 Mdot
.56841 .67387 Mdot
.57337 .63812 Mdot
.66583 .61367 Mdot
.37541 .56679 Mdot
.34334 .41242 Mdot
.69756 .41819 Mdot
.66817 .61188 Mdot
.56743 .38275 Mdot
.52102 .76237 Mdot
.45963 .78567 Mdot
.56365 .44562 Mdot
.54816 .39586 Mdot
.50254 .72104 Mdot
.58253 .61051 Mdot
.39907 .17032 Mdot
.63362 .53587 Mdot
.67109 .60305 Mdot
.71428 .5911 Mdot
.30243 .41561 Mdot
.6159 .36126 Mdot
.34419 .57225 Mdot
.66313 .5297 Mdot
.66442 .41713 Mdot
.70642 .54074 Mdot
.7284 .72053 Mdot
.51243 .39184 Mdot
.31241 .33859 Mdot
.58522 .40425 Mdot
.32578 .39297 Mdot
.37527 .40633 Mdot
.32489 .4293 Mdot
.36028 .56218 Mdot
.47786 .31775 Mdot
.33368 .58307 Mdot
.72309 .26354 Mdot
.36408 .45345 Mdot
.64685 .66497 Mdot
.54359 .65625 Mdot
.54152 .32558 Mdot
.70233 .61131 Mdot
.32397 .54837 Mdot
.59709 .42647 Mdot
.36913 .77509 Mdot
.54117 .66472 Mdot
.34441 .40091 Mdot
.61818 .4559 Mdot
.58712 .18985 Mdot
.51035 .53618 Mdot
.55934 .30325 Mdot
.28167 .36287 Mdot
.68282 .61313 Mdot
.46329 .2237 Mdot
.72035 .59567 Mdot
.35594 .58937 Mdot
.56152 .35552 Mdot
.53992 .35475 Mdot
.59187 .39352 Mdot
.52988 .40222 Mdot
.34805 .61201 Mdot
.5494 .33356 Mdot
.16238 .50178 Mdot
.50095 .72514 Mdot
.78039 .398 Mdot
.68899 .582 Mdot
.34642 .55446 Mdot
.55073 .62813 Mdot
.48491 .74597 Mdot
.64318 .49752 Mdot
.57683 .43386 Mdot
.53963 .3894 Mdot
.46698 .73979 Mdot
.584 .44017 Mdot
.49926 .45228 Mdot
.57124 .64952 Mdot
.56518 .56118 Mdot
.65838 .59167 Mdot
.68087 .5809 Mdot
.38748 .59149 Mdot
.32967 .44959 Mdot
.69445 .58986 Mdot
.58234 .61451 Mdot
.53637 .33353 Mdot
.50875 .37442 Mdot
.31297 .43422 Mdot
.18124 .4804 Mdot
.65152 .61039 Mdot
.6224 .44891 Mdot
.36216 .45172 Mdot
.30891 .44909 Mdot
.55269 .38169 Mdot
.5705 .4693 Mdot
.36337 .38263 Mdot
.65915 .59781 Mdot
.34352 .55603 Mdot
.72207 .65064 Mdot
.36272 .59319 Mdot
.33842 .4118 Mdot
.53903 .34406 Mdot
.3429 .40397 Mdot
.53616 .42612 Mdot
.86451 .61443 Mdot
.5385 .35706 Mdot
.23556 .65341 Mdot
.6882 .44581 Mdot
.5706 .63739 Mdot
.59634 .66188 Mdot
.49181 .73857 Mdot
.3667 .45006 Mdot
.52148 .35673 Mdot
.71608 .59256 Mdot
.82503 .47015 Mdot
.35097 .37367 Mdot
.5745 .6247 Mdot
.57578 .60576 Mdot
.39436 .59113 Mdot
.52126 .42798 Mdot
.54602 .37537 Mdot
.53631 .66014 Mdot
.70974 .35983 Mdot
.36364 .44536 Mdot
.57845 .37693 Mdot
.57637 .40071 Mdot
.57064 .6429 Mdot
.79323 .53541 Mdot
.28151 .40885 Mdot
.56 .35683 Mdot
.67055 .63165 Mdot
.37215 .55209 Mdot
.59449 .37212 Mdot
.55127 .33364 Mdot
.71044 .59602 Mdot
.74386 .34096 Mdot
.23542 .33235 Mdot
.37264 .55507 Mdot
.47869 .74399 Mdot
.50215 .39835 Mdot
.54503 .65714 Mdot
.50906 .37656 Mdot
.64094 .2505 Mdot
.50048 .73178 Mdot
.53882 .4091 Mdot
.61215 .36144 Mdot
.36854 .4016 Mdot
.52843 .40737 Mdot
.50896 .21206 Mdot
.54033 .68058 Mdot
.53396 .40843 Mdot
.40883 .36783 Mdot
.3775 .60697 Mdot
.60213 .3451 Mdot
.69455 .579 Mdot
.68751 .42103 Mdot
.26647 .52054 Mdot
.53494 .60633 Mdot
.68022 .58237 Mdot
.51923 .3697 Mdot
.59141 .62283 Mdot
.36934 .55901 Mdot
.35981 .75297 Mdot
.59291 .41265 Mdot
.37035 .59446 Mdot
.35536 .57986 Mdot
.6766 .59314 Mdot
.34085 .79569 Mdot
.55933 .32762 Mdot
.54033 .36896 Mdot
.5171 .20672 Mdot
.35141 .39166 Mdot
.53175 .36691 Mdot
.50761 .40234 Mdot
.33729 .58394 Mdot
.27114 .40593 Mdot
.53376 .25629 Mdot
.59336 .7496 Mdot
.38693 .56904 Mdot
.51405 .65553 Mdot
.59239 .6262 Mdot
.691 .58265 Mdot
.35827 .41517 Mdot
.6797 .62192 Mdot
.56923 .66133 Mdot
.51401 .41319 Mdot
.34136 .58508 Mdot
.37227 .23942 Mdot
.39246 .6104 Mdot
.52364 .65427 Mdot
.34146 .38427 Mdot
.23147 .47979 Mdot
.18055 .37014 Mdot
.26852 .54901 Mdot
.41141 .58433 Mdot
.69603 .61033 Mdot
.51683 .74363 Mdot
.57786 .39834 Mdot
.45183 .23466 Mdot
.52094 .37415 Mdot
.34751 .3548 Mdot
.57899 .65986 Mdot
.46956 .73905 Mdot
.55957 .35517 Mdot
.72498 .48064 Mdot
.36453 .62395 Mdot
.3948 .58914 Mdot
.53873 .4014 Mdot
.36983 .56874 Mdot
.54943 .3666 Mdot
.54862 .6246 Mdot
.2757 .73451 Mdot
.58084 .39016 Mdot
.5026 .42869 Mdot
.35263 .65398 Mdot
.81142 .57026 Mdot
.60389 .64413 Mdot
.30545 .33932 Mdot
.55411 .17775 Mdot
.3683 .56854 Mdot
.61762 .39469 Mdot
.5391 .67149 Mdot
.5028 .72113 Mdot
.59444 .66778 Mdot
.52607 .37492 Mdot
.52609 .38199 Mdot
.58828 .38965 Mdot
.55953 .41028 Mdot
.4587 .23243 Mdot
.45956 .40657 Mdot
.35069 .33285 Mdot
.54073 .39165 Mdot
.34508 .36202 Mdot
.33197 .59509 Mdot
.39436 .44671 Mdot
.64865 .61525 Mdot
.5125 .39435 Mdot
.36555 .48181 Mdot
.36202 .55038 Mdot
.72103 .26164 Mdot
.39152 .59564 Mdot
.55564 .63977 Mdot
.38106 .61226 Mdot
.53788 .43081 Mdot
.35933 .42631 Mdot
.53119 .67169 Mdot
.3387 .71165 Mdot
.57353 .63342 Mdot
.52792 .42846 Mdot
.71449 .63708 Mdot
.57477 .63989 Mdot
.49083 .51288 Mdot
.36247 .42241 Mdot
.75099 .4798 Mdot
.37691 .40759 Mdot
.53604 .41076 Mdot
.54047 .41203 Mdot
.50806 .72279 Mdot
.36001 .62147 Mdot
.38572 .42474 Mdot
.22222 .7083 Mdot
.71674 .61187 Mdot
.32914 .43286 Mdot
.49758 .35036 Mdot
.57601 .53618 Mdot
.3586 .43447 Mdot
.72739 .42512 Mdot
.37384 .56437 Mdot
.31658 .45179 Mdot
.49386 .36083 Mdot
.41737 .63002 Mdot
.68413 .57061 Mdot
.5413 .61966 Mdot
.47242 .5801 Mdot
.54543 .67815 Mdot
.35133 .5504 Mdot
.52695 .63416 Mdot
.35777 .60791 Mdot
.22818 .41738 Mdot
.48311 .32897 Mdot
.40081 .60402 Mdot
.33924 .55601 Mdot
.558 .66232 Mdot
.59112 .41065 Mdot
.41646 .50718 Mdot
.5935 .42572 Mdot
.60047 .39588 Mdot
.36541 .6086 Mdot
.38082 .43362 Mdot
.38584 .43842 Mdot
.33403 .36618 Mdot
.32408 .39957 Mdot
.54414 .62925 Mdot
.26842 .68741 Mdot
.21353 .42832 Mdot
.37251 .60121 Mdot
.32496 .57086 Mdot
.56949 .41322 Mdot
.54809 .66012 Mdot
.59005 .63738 Mdot
.34562 .57495 Mdot
.40145 .23977 Mdot
.49765 .40413 Mdot
.35463 .38481 Mdot
.35757 .4565 Mdot
.34964 .43712 Mdot
.30683 .40966 Mdot
.50207 .26857 Mdot
.37585 .56506 Mdot
.36595 .45167 Mdot
.54017 .40501 Mdot
.5265 .37963 Mdot
.47674 .72612 Mdot
.68513 .57938 Mdot
.51703 .34203 Mdot
.54704 .46301 Mdot
.55059 .38199 Mdot
.57841 .64197 Mdot
.57865 .31725 Mdot
.49024 .74247 Mdot
.55488 .61043 Mdot
.5678 .60298 Mdot
.47248 .72656 Mdot
.35147 .3665 Mdot
.5605 .17062 Mdot
.56277 .42034 Mdot
.51231 .31129 Mdot
.54844 .65521 Mdot
.31755 .75232 Mdot
.20906 .47387 Mdot
.59157 .39794 Mdot
.44207 .58215 Mdot
.52821 .65261 Mdot
.34142 .39274 Mdot
.52689 .3696 Mdot
.48595 .71694 Mdot
.67855 .619 Mdot
.49392 .35508 Mdot
.49734 .71541 Mdot
.33758 .4524 Mdot
.64036 .60086 Mdot
.30912 .44582 Mdot
.52755 .65549 Mdot
.61033 .35802 Mdot
.67559 .17529 Mdot
.57212 .67502 Mdot
.81842 .48818 Mdot
.29911 .46495 Mdot
.58179 .38106 Mdot
.56257 .67758 Mdot
.34471 .39075 Mdot
.36357 .54771 Mdot
.58639 .5293 Mdot
.31801 .41354 Mdot
.4766 .74465 Mdot
.48312 .72128 Mdot
.57238 .64694 Mdot
.36049 .40586 Mdot
.54619 .34582 Mdot
.37547 .41589 Mdot
.38357 .61029 Mdot
.5813 .41729 Mdot
.64484 .21486 Mdot
.48361 .34213 Mdot
.373 .44448 Mdot
.55597 .61395 Mdot
.69972 .57207 Mdot
.58008 .42706 Mdot
.80712 .4779 Mdot
.51156 .41612 Mdot
.36396 .60445 Mdot
.42182 .81113 Mdot
.40064 .22432 Mdot
.53787 .43905 Mdot
.5682 .41317 Mdot
.38227 .56776 Mdot
.57828 .43161 Mdot
.54356 .44378 Mdot
.33865 .64086 Mdot
.37146 .40729 Mdot
.57238 .39005 Mdot
.58519 .62442 Mdot
.23861 .3636 Mdot
.50279 .41438 Mdot
.4369 .73018 Mdot
.74175 .48314 Mdot
.401 .8136 Mdot
.52439 .3641 Mdot
.64818 .52116 Mdot
.55564 .40611 Mdot
.51712 .39212 Mdot
.57239 .41721 Mdot
.30414 .33069 Mdot
.55871 .66401 Mdot
.56274 .62038 Mdot
.67925 .57189 Mdot
.74304 .47881 Mdot
.70667 .58955 Mdot
.39053 .58233 Mdot
.71642 .70883 Mdot
.49966 .73055 Mdot
.33199 .45159 Mdot
.53691 .35136 Mdot
.53265 .67801 Mdot
.54198 .37791 Mdot
.53999 .42976 Mdot
.53318 .63657 Mdot
.58901 .65801 Mdot
.60374 .59956 Mdot
.71513 .60442 Mdot
.32215 .42107 Mdot
.56907 .34402 Mdot
.66314 .59858 Mdot
.53848 .34781 Mdot
.61032 .53818 Mdot
.32187 .42621 Mdot
.37435 .4101 Mdot
.3841 .40835 Mdot
.51382 .41323 Mdot
.54596 .43696 Mdot
.3334 .58488 Mdot
.32205 .44862 Mdot
.38427 .59391 Mdot
.53509 .67046 Mdot
.57026 .68172 Mdot
.52605 .3752 Mdot
.64238 .38004 Mdot
.71305 .59696 Mdot
.55174 .6368 Mdot
.46683 .74313 Mdot
.70572 .57141 Mdot
.52144 .42293 Mdot
.53268 .644 Mdot
.67646 .58198 Mdot
.36412 .26762 Mdot
.51904 .16295 Mdot
.70129 .57381 Mdot
.54092 .40253 Mdot
.27754 .34822 Mdot
.78387 .54275 Mdot
.71984 .60865 Mdot
.35342 .59753 Mdot
.50945 .40864 Mdot
.6587 .31603 Mdot
.65891 .61717 Mdot
.23981 .38939 Mdot
.56873 .63643 Mdot
.42316 .58498 Mdot
.48121 .39425 Mdot
.43382 .24667 Mdot
.69499 .62081 Mdot
.34354 .41645 Mdot
.39651 .42618 Mdot
.55846 .39349 Mdot
.64718 .61755 Mdot
.39625 .58731 Mdot
.56533 .63008 Mdot
.59897 .62557 Mdot
.36445 .40675 Mdot
.24246 .57467 Mdot
.57898 .62154 Mdot
.63456 .42228 Mdot
.54448 .772 Mdot
.45226 .38087 Mdot
.4017 .37866 Mdot
.30108 .67169 Mdot
.50237 .38669 Mdot
.70895 .57813 Mdot
.3476 .55617 Mdot
.34213 .57091 Mdot
.37726 .58091 Mdot
.5971 .6581 Mdot
.4732 .52477 Mdot
.54577 .66951 Mdot
.35451 .74063 Mdot
.68042 .589 Mdot
.76445 .46366 Mdot
.52634 .35539 Mdot
.58031 .39348 Mdot
.50146 .36225 Mdot
.56828 .35386 Mdot
.56068 .40327 Mdot
.37582 .56853 Mdot
.59944 .64338 Mdot
.67763 .68874 Mdot
.33911 .44147 Mdot
.53799 .58135 Mdot
.54335 .65609 Mdot
.50256 .72271 Mdot
.68004 .60523 Mdot
.56925 .50841 Mdot
.53023 .61725 Mdot
.54295 .64923 Mdot
.53127 .33214 Mdot
.37277 .43373 Mdot
.54066 .47867 Mdot
.54667 .41229 Mdot
.54892 .63538 Mdot
.52485 .69763 Mdot
.54734 .23685 Mdot
.60272 .4539 Mdot
.69782 .56314 Mdot
.56491 .53376 Mdot
.72175 .60129 Mdot
.50354 .43916 Mdot
.3268 .76048 Mdot
.56854 .66111 Mdot
.56058 .64394 Mdot
.68344 .57713 Mdot
.6285 .34657 Mdot
.36301 .41159 Mdot
.46959 .74014 Mdot
.34631 .59947 Mdot
.53387 .4158 Mdot
.57899 .67533 Mdot
.59337 .30453 Mdot
.63867 .74294 Mdot
.37733 .58676 Mdot
.55683 .61039 Mdot
.52408 .42982 Mdot
.54234 .40103 Mdot
.68907 .61299 Mdot
.39098 .47257 Mdot
.50273 .33819 Mdot
.81903 .417 Mdot
.26004 .63755 Mdot
.22741 .60086 Mdot
.55098 .37912 Mdot
.36425 .40442 Mdot
.49054 .7192 Mdot
.66775 .60921 Mdot
.54658 .33773 Mdot
.53047 .16556 Mdot
.38938 .40388 Mdot
.36067 .58692 Mdot
.48363 .71775 Mdot
.47319 .52245 Mdot
.50971 .41204 Mdot
.52146 .37375 Mdot
.5256 .39699 Mdot
.46593 .14822 Mdot
.57649 .62407 Mdot
.31945 .39872 Mdot
.69529 .59939 Mdot
.32437 .39767 Mdot
.56873 .62559 Mdot
.21931 .52505 Mdot
.55164 .44185 Mdot
.34941 .38443 Mdot
.34648 .41824 Mdot
.39408 .59072 Mdot
.36477 .54704 Mdot
.596 .59115 Mdot
.53993 .35702 Mdot
.48793 .71642 Mdot
.3755 .40511 Mdot
.59509 .6411 Mdot
.6751 .61053 Mdot
.32969 .58425 Mdot
.53963 .39206 Mdot
.57321 .65398 Mdot
.60303 .43049 Mdot
.36319 .43505 Mdot
.5433 .64994 Mdot
.47053 .7234 Mdot
.71022 .5855 Mdot
.53216 .38535 Mdot
.71688 .56642 Mdot
.46828 .7335 Mdot
.57763 .40115 Mdot
.56834 .49538 Mdot
.73953 .5793 Mdot
.35699 .72392 Mdot
.55511 .67387 Mdot
.47626 .73451 Mdot
.37084 .39961 Mdot
.24878 .42325 Mdot
.56088 .63923 Mdot
.56554 .50251 Mdot
.36862 .49581 Mdot
.5722 .34552 Mdot
.34539 .43178 Mdot
.52501 .74073 Mdot
.79009 .36067 Mdot
.78649 .47006 Mdot
.57819 .38237 Mdot
.55782 .67831 Mdot
.66981 .58601 Mdot
.37241 .60181 Mdot
.43736 .73262 Mdot
.53321 .29169 Mdot
.53175 .62495 Mdot
.56884 .41704 Mdot
.37663 .40851 Mdot
.34823 .57389 Mdot
.2798 .49952 Mdot
.57218 .61104 Mdot
.57606 .6643 Mdot
.53408 .43558 Mdot
.69009 .58706 Mdot
.74632 .37968 Mdot
.55645 .61839 Mdot
.57802 .67517 Mdot
.48544 .76965 Mdot
.67533 .57863 Mdot
.55102 .40132 Mdot
.33197 .36625 Mdot
.59447 .3671 Mdot
.82072 .48611 Mdot
.48582 .74268 Mdot
.34058 .44301 Mdot
.51895 .38034 Mdot
.5827 .75995 Mdot
.55321 .63121 Mdot
.54323 .53173 Mdot
.53071 .68784 Mdot
.37183 .56351 Mdot
.57597 .67702 Mdot
.53418 .37079 Mdot
.36837 .62397 Mdot
.71269 .59615 Mdot
.55632 .35651 Mdot
.54848 .43713 Mdot
.33542 .39195 Mdot
.35488 .58998 Mdot
.30409 .2751 Mdot
.32648 .57287 Mdot
.36266 .55221 Mdot
.3849 .44685 Mdot
.56379 .38802 Mdot
.55282 .64269 Mdot
.52721 .63822 Mdot
.55184 .33926 Mdot
.27403 .71146 Mdot
.36517 .41084 Mdot
.58498 .58328 Mdot
.41425 .16828 Mdot
.5798 .47458 Mdot
.46494 .73472 Mdot
.41027 .45221 Mdot
.39039 .5739 Mdot
.53994 .3971 Mdot
.36586 .44785 Mdot
.58893 .66632 Mdot
.58024 .6221 Mdot
.54057 .34483 Mdot
.35172 .57708 Mdot
.66289 .61555 Mdot
.58174 .65991 Mdot
.61258 .75751 Mdot
.52375 .40262 Mdot
.38222 .75757 Mdot
.57587 .66818 Mdot
.83758 .46723 Mdot
.66448 .70864 Mdot
.34439 .43447 Mdot
.54374 .43135 Mdot
.32297 .40359 Mdot
.69838 .60171 Mdot
.51838 .61986 Mdot
.35278 .57992 Mdot
.61388 .43784 Mdot
.19931 .37866 Mdot
.55346 .66458 Mdot
.32448 .44258 Mdot
.5359 .43793 Mdot
.60937 .45811 Mdot
.5396 .36615 Mdot
.27163 .39524 Mdot
.63147 .61179 Mdot
.36911 .60838 Mdot
.36096 .60328 Mdot
.58092 .4031 Mdot
.68169 .61618 Mdot
.53801 .6272 Mdot
.56493 .63145 Mdot
.68228 .82105 Mdot
.46746 .72709 Mdot
.71099 .46497 Mdot
.52807 .3836 Mdot
.59464 .62943 Mdot
.26095 .35208 Mdot
.37058 .59782 Mdot
.56592 .35143 Mdot
.59226 .61449 Mdot
.3747 .6611 Mdot
.60355 .538 Mdot
.5577 .40127 Mdot
.49056 .43851 Mdot
.34907 .60011 Mdot
.72313 .53067 Mdot
.54187 .66719 Mdot
.56981 .3517 Mdot
.32217 .58387 Mdot
.55129 .78202 Mdot
.21014 .40898 Mdot
.32231 .4215 Mdot
.52478 .67438 Mdot
.37611 .56843 Mdot
.49259 .34752 Mdot
.68673 .58163 Mdot
.54008 .67863 Mdot
.57727 .63526 Mdot
.56972 .42495 Mdot
.53693 .32866 Mdot
.58295 .47405 Mdot
.33223 .44549 Mdot
.33699 .60173 Mdot
.56062 .35391 Mdot
.24491 .58083 Mdot
.58856 .38438 Mdot
.33417 .5946 Mdot
.81853 .29359 Mdot
.5981 .39224 Mdot
.54213 .36689 Mdot
.76052 .40225 Mdot
.31897 .41063 Mdot
.32759 .39724 Mdot
.26073 .65282 Mdot
.52849 .38373 Mdot
.69809 .69235 Mdot
.32286 .41663 Mdot
.36728 .41465 Mdot
.63036 .67986 Mdot
.58662 .41014 Mdot
.73867 .54455 Mdot
.34218 .57456 Mdot
.34135 .56578 Mdot
.37392 .41349 Mdot
.49909 .34036 Mdot
.37266 .55862 Mdot
.48834 .24182 Mdot
.54297 .66053 Mdot
.33135 .76517 Mdot
.36164 .4396 Mdot
.41073 .49141 Mdot
.3752 .59475 Mdot
.72719 .26725 Mdot
.4439 .60017 Mdot
.58908 .39398 Mdot
.53117 .39052 Mdot
.71114 .59083 Mdot
.60997 .3928 Mdot
.48425 .74512 Mdot
.37063 .56894 Mdot
.71779 .33587 Mdot
.32551 .42952 Mdot
.54196 .35969 Mdot
.57724 .50837 Mdot
.28879 .51788 Mdot
.42703 .76038 Mdot
.35255 .41204 Mdot
.3393 .42962 Mdot
.55831 .66931 Mdot
.5812 .65149 Mdot
.56341 .39393 Mdot
.34829 .56558 Mdot
.32036 .449 Mdot
.34236 .60199 Mdot
.57112 .65965 Mdot
.54684 .64729 Mdot
.50107 .73179 Mdot
.57256 .45216 Mdot
.53961 .62858 Mdot
.59361 .77064 Mdot
.23816 .57231 Mdot
.29955 .41812 Mdot
.22428 .32439 Mdot
.27952 .49765 Mdot
.69681 .37807 Mdot
.71683 .60537 Mdot
.5114 .70128 Mdot
.36172 .61691 Mdot
.57104 .41108 Mdot
.5405 .38376 Mdot
.488 .73042 Mdot
.37842 .61865 Mdot
.68416 .60889 Mdot
.37182 .62124 Mdot
.67745 .58816 Mdot
.58804 .67225 Mdot
.50217 .40886 Mdot
.50684 .39357 Mdot
.37724 .57146 Mdot
.5387 .64405 Mdot
.55585 .62359 Mdot
.72139 .59677 Mdot
.60568 .51984 Mdot
.5733 .6479 Mdot
.36245 .43832 Mdot
.47734 .29053 Mdot
.4854 .72195 Mdot
.52858 .36858 Mdot
.62369 .50939 Mdot
.43539 .22638 Mdot
.57896 .35344 Mdot
.47735 .72056 Mdot
.57919 .84682 Mdot
.53133 .35555 Mdot
.50972 .8557 Mdot
.4753 .73328 Mdot
.31797 .41078 Mdot
.56204 .67623 Mdot
.489 .74477 Mdot
.47871 .39013 Mdot
.72838 .59426 Mdot
.52127 .34667 Mdot
.32259 .40898 Mdot
.37975 .40127 Mdot
.21385 .5931 Mdot
.8198 .48986 Mdot
.71952 .59125 Mdot
.67375 .60059 Mdot
.56263 .63961 Mdot
.7882 .65224 Mdot
.49934 .35543 Mdot
.6736 .60528 Mdot
.71092 .34233 Mdot
.56197 .41741 Mdot
.69789 .4839 Mdot
.44368 .57823 Mdot
.36523 .40569 Mdot
.37832 .37354 Mdot
.55828 .6336 Mdot
.32288 .43943 Mdot
.22263 .55745 Mdot
.50385 .36 Mdot
.32295 .42888 Mdot
.33499 .59279 Mdot
.3576 .68469 Mdot
.33481 .40031 Mdot
.61712 .5301 Mdot
.34644 .57065 Mdot
.54663 .71482 Mdot
.74109 .3941 Mdot
.16517 .35653 Mdot
.36739 .56566 Mdot
.53251 .65136 Mdot
.5278 .65144 Mdot
.56576 .63474 Mdot
.31617 .41766 Mdot
.58931 .62493 Mdot
.34131 .4485 Mdot
.78767 .55723 Mdot
.60788 .51577 Mdot
.66965 .59803 Mdot
.32384 .63842 Mdot
.34401 .42399 Mdot
.30875 .71781 Mdot
.18718 .36484 Mdot
.53694 .40151 Mdot
.32435 .57763 Mdot
.68705 .5766 Mdot
.85545 .54054 Mdot
.71083 .59385 Mdot
.54069 .67264 Mdot
.34084 .77509 Mdot
.55038 .3642 Mdot
.58953 .25673 Mdot
.71392 .58678 Mdot
.3453 .40831 Mdot
.57908 .39846 Mdot
.58512 .68195 Mdot
.69384 .58424 Mdot
.67105 .61794 Mdot
.56934 .39923 Mdot
.34726 .40027 Mdot
.54919 .64392 Mdot
.35207 .6164 Mdot
.71845 .61394 Mdot
.48121 .35746 Mdot
.58323 .35262 Mdot
.50007 .37862 Mdot
.50379 .52923 Mdot
.67079 .31248 Mdot
.36676 .56801 Mdot
.77558 .50529 Mdot
.58154 .64694 Mdot
.5549 .73101 Mdot
.27367 .65294 Mdot
.30716 .59976 Mdot
.48342 .74269 Mdot
.49376 .73961 Mdot
.56115 .40045 Mdot
.67473 .31476 Mdot
.45357 .80775 Mdot
.3388 .65212 Mdot
.48808 .7217 Mdot
.56221 .62732 Mdot
.39733 .42177 Mdot
.19577 .56028 Mdot
.59055 .35698 Mdot
.39134 .57192 Mdot
.57573 .64859 Mdot
.63795 .249 Mdot
.68637 .59096 Mdot
.31624 .74455 Mdot
.54061 .43827 Mdot
.57146 .36482 Mdot
.36442 .57284 Mdot
.3344 .58185 Mdot
.42065 .74082 Mdot
.23098 .61479 Mdot
.66869 .54327 Mdot
.26711 .44434 Mdot
.61969 .24547 Mdot
.39824 .44067 Mdot
.37493 .44205 Mdot
.48806 .71182 Mdot
.32912 .57508 Mdot
.5189 .3737 Mdot
.32713 .45102 Mdot
.42662 .76214 Mdot
.30548 .38527 Mdot
.70862 .48213 Mdot
.67262 .71537 Mdot
.52919 .4251 Mdot
.37577 .42759 Mdot
.32121 .43376 Mdot
.30573 .43558 Mdot
.47456 .72373 Mdot
.55504 .37898 Mdot
.58877 .41565 Mdot
.57413 .36228 Mdot
.46685 .38826 Mdot
.52582 .40575 Mdot
.26916 .61497 Mdot
.52027 .56427 Mdot
.72721 .3355 Mdot
.58671 .36358 Mdot
.34606 .56176 Mdot
.50462 .36343 Mdot
.67729 .6163 Mdot
.57154 .41553 Mdot
.70612 .4737 Mdot
.3694 .58661 Mdot
.63095 .36065 Mdot
.26394 .44156 Mdot
.54707 .44056 Mdot
.65606 .60504 Mdot
.68353 .33498 Mdot
.29335 .28858 Mdot
.52961 .58747 Mdot
.36377 .43691 Mdot
.53914 .61014 Mdot
.38715 .6066 Mdot
.55397 .64487 Mdot
.58874 .37342 Mdot
.48635 .7146 Mdot
.29048 .5875 Mdot
.41256 .49365 Mdot
.51376 .38079 Mdot
.57951 .32131 Mdot
.36867 .42498 Mdot
.53267 .64579 Mdot
.3526 .47796 Mdot
.52193 .39066 Mdot
.69749 .59653 Mdot
.6873 .58455 Mdot
.23924 .60472 Mdot
.65199 .23489 Mdot
.24142 .41939 Mdot
.36527 .57157 Mdot
.56355 .61613 Mdot
.68612 .62226 Mdot
.54396 .29598 Mdot
.38618 .56244 Mdot
.3926 .58026 Mdot
.34951 .58559 Mdot
.52914 .41874 Mdot
.48549 .74406 Mdot
.68848 .30402 Mdot
.47965 .74542 Mdot
.55179 .44028 Mdot
.5785 .63039 Mdot
.49988 .73781 Mdot
.70615 .58525 Mdot
.38765 .59247 Mdot
.57218 .66138 Mdot
.53331 .41139 Mdot
.32827 .41581 Mdot
.5986 .52047 Mdot
.67357 .43684 Mdot
.80134 .44383 Mdot
.8 .42819 Mdot
.38961 .42123 Mdot
.70929 .26557 Mdot
.31806 .59677 Mdot
.40425 .23913 Mdot
.69646 .63806 Mdot
.55165 .34122 Mdot
.22479 .66129 Mdot
.54162 .66826 Mdot
.53191 .6408 Mdot
.55152 .40427 Mdot
.59246 .65394 Mdot
.54096 .36186 Mdot
.57693 .66044 Mdot
.5335 .58687 Mdot
.59324 .35845 Mdot
.5372 .6335 Mdot
.48595 .40258 Mdot
.58 .42584 Mdot
.36979 .40737 Mdot
.55295 .681 Mdot
.58857 .37955 Mdot
.82491 .61752 Mdot
.33141 .58332 Mdot
.47568 .72317 Mdot
.6191 .56363 Mdot
.37923 .57036 Mdot
.33223 .43547 Mdot
.60218 .39599 Mdot
.70691 .60655 Mdot
.33957 .41654 Mdot
.59182 .58754 Mdot
.71016 .58259 Mdot
.26935 .689 Mdot
.36811 .43286 Mdot
.48555 .72398 Mdot
.7142 .59465 Mdot
.59233 .3292 Mdot
.54601 .68352 Mdot
.65964 .42226 Mdot
.47308 .74105 Mdot
.54493 .3748 Mdot
.60235 .62523 Mdot
.3294 .5814 Mdot
.57317 .37731 Mdot
.57322 .67512 Mdot
.4716 .7268 Mdot
.53798 .42102 Mdot
.56621 .40913 Mdot
.18809 .50892 Mdot
.40995 .78193 Mdot
.68386 .61265 Mdot
.35791 .38953 Mdot
.53997 .4055 Mdot
.71345 .60657 Mdot
.64474 .76894 Mdot
.50149 .38669 Mdot
.31325 .41381 Mdot
.50124 .46928 Mdot
.58394 .64541 Mdot
.3851 .59318 Mdot
.52461 .66989 Mdot
.68402 .61883 Mdot
.26385 .75875 Mdot
.50227 .73278 Mdot
.49513 .43035 Mdot
.54062 .34853 Mdot
.51698 .71127 Mdot
.32424 .43926 Mdot
.66969 .54 Mdot
.53211 .38583 Mdot
.47664 .34973 Mdot
.55788 .35909 Mdot
.6732 .6989 Mdot
.36462 .41194 Mdot
.54148 .36956 Mdot
.63814 .41739 Mdot
.51501 .43306 Mdot
.65834 .61359 Mdot
.76745 .44024 Mdot
.50518 .37158 Mdot
.59014 .11712 Mdot
.46643 .73862 Mdot
.53806 .6305 Mdot
.57411 .69231 Mdot
.72949 .74027 Mdot
.23302 .41037 Mdot
.33756 .44829 Mdot
.4368 .45258 Mdot
.55149 .64416 Mdot
.24447 .37602 Mdot
.73784 .28973 Mdot
.57687 .4288 Mdot
.51282 .41525 Mdot
.5407 .67266 Mdot
.59549 .64181 Mdot
.49401 .71512 Mdot
.59163 .37769 Mdot
.61952 .36291 Mdot
.56126 .61163 Mdot
.5217 .41068 Mdot
.53191 .47947 Mdot
.34989 .61456 Mdot
.36256 .39902 Mdot
.37502 .60161 Mdot
.39089 .59779 Mdot
.43808 .27188 Mdot
.25961 .63433 Mdot
.33342 .59414 Mdot
.3597 .62581 Mdot
.69645 .47502 Mdot
.49339 .47316 Mdot
.67326 .62053 Mdot
.73343 .3149 Mdot
.56687 .64108 Mdot
.55679 .37928 Mdot
.38359 .43608 Mdot
.4239 .25599 Mdot
.44984 .63672 Mdot
.38122 .80027 Mdot
.51913 .38691 Mdot
.55771 .63023 Mdot
.47018 .73178 Mdot
.58826 .35292 Mdot
.57515 .72202 Mdot
.57646 .37203 Mdot
.53296 .67815 Mdot
.48686 .29735 Mdot
.59382 .49035 Mdot
.51473 .75603 Mdot
.32572 .46022 Mdot
.54034 .35316 Mdot
.35337 .44381 Mdot
.3789 .59028 Mdot
.6951 .61495 Mdot
.68821 .6119 Mdot
.57457 .40206 Mdot
.51328 .30422 Mdot
.44132 .56671 Mdot
.57636 .43095 Mdot
.57527 .42101 Mdot
.47576 .73448 Mdot
.57687 .42008 Mdot
.54456 .34789 Mdot
.57061 .35669 Mdot
.52073 .44227 Mdot
.36025 .5525 Mdot
.59358 .49275 Mdot
.56455 .45738 Mdot
.56576 .47248 Mdot
.33577 .60783 Mdot
.41937 .4526 Mdot
.38485 .6031 Mdot
.64208 .21312 Mdot
.36391 .60563 Mdot
.67643 .60978 Mdot
.59069 .60367 Mdot
.44135 .41136 Mdot
.32382 .45342 Mdot
.36722 .54986 Mdot
.68637 .60152 Mdot
.37553 .57519 Mdot
.57871 .62444 Mdot
.33053 .22458 Mdot
.30463 .38633 Mdot
.6514 .53219 Mdot
.41286 .62595 Mdot
.38825 .75749 Mdot
.55052 .66691 Mdot
.3681 .41067 Mdot
.55864 .23575 Mdot
.58392 .37378 Mdot
.71274 .58993 Mdot
.56523 .39847 Mdot
.36715 .55237 Mdot
.56179 .63269 Mdot
.7969 .48675 Mdot
.69676 .6111 Mdot
.18435 .44596 Mdot
.56851 .63185 Mdot
.59359 .41287 Mdot
.38948 .56971 Mdot
.21929 .3294 Mdot
.37175 .60604 Mdot
.61065 .51456 Mdot
.32079 .39203 Mdot
.33665 .35839 Mdot
.3469 .42878 Mdot
.44092 .75716 Mdot
.4758 .13714 Mdot
.79913 .38983 Mdot
.33272 .41005 Mdot
.5252 .76692 Mdot
.52071 .41988 Mdot
.50136 .37165 Mdot
.6239 .44266 Mdot
.32017 .39686 Mdot
.5334 .40515 Mdot
.47288 .7371 Mdot
.22879 .53727 Mdot
.5844 .73595 Mdot
.5382 .61184 Mdot
.53439 .36649 Mdot
.33565 .60663 Mdot
.37447 .62126 Mdot
.49373 .74294 Mdot
.37874 .60931 Mdot
.58944 .41054 Mdot
.34556 .42573 Mdot
.39168 .50033 Mdot
.70573 .59707 Mdot
.82404 .5646 Mdot
.65148 .61718 Mdot
.55899 .6946 Mdot
.61123 .35905 Mdot
.54606 .64748 Mdot
.4169 .86685 Mdot
.58721 .39176 Mdot
.32081 .41799 Mdot
.55512 .41352 Mdot
.55205 .35268 Mdot
.50006 .37297 Mdot
.57566 .61313 Mdot
.67223 .56234 Mdot
.52424 .41146 Mdot
.35252 .58127 Mdot
.7659 .37035 Mdot
.50878 .35487 Mdot
.52404 .59944 Mdot
.74084 .46399 Mdot
.34753 .73606 Mdot
.30379 .44238 Mdot
.53411 .64458 Mdot
.32881 .42848 Mdot
.35161 .46373 Mdot
.33219 .43565 Mdot
.69037 .29875 Mdot
.54708 .24621 Mdot
.57612 .84305 Mdot
.3987 .36834 Mdot
.38937 .26327 Mdot
.36755 .39045 Mdot
.62522 .7926 Mdot
.35989 .45216 Mdot
.33298 .44345 Mdot
.90087 .52662 Mdot
.3582 .45478 Mdot
.52918 .37527 Mdot
.54584 .33032 Mdot
.27275 .53623 Mdot
.68158 .48791 Mdot
.58013 .4108 Mdot
.54521 .4056 Mdot
.70712 .60983 Mdot
.59346 .28246 Mdot
.49649 .71325 Mdot
.2648 .68565 Mdot
.30797 .50683 Mdot
.56736 .40006 Mdot
.53949 .40791 Mdot
.53676 .32407 Mdot
.4139 .13562 Mdot
.45603 .25125 Mdot
.38122 .39893 Mdot
.55639 .31308 Mdot
.83354 .50233 Mdot
.58188 .43133 Mdot
.5059 .3986 Mdot
.53588 .4261 Mdot
.5523 .64306 Mdot
.39437 .40862 Mdot
.55679 .31358 Mdot
.31727 .70467 Mdot
.53005 .43182 Mdot
.31205 .61709 Mdot
.73405 .56539 Mdot
.53425 .3718 Mdot
.30398 .41755 Mdot
.557 .42352 Mdot
.368 .4362 Mdot
.37166 .40622 Mdot
.53963 .32361 Mdot
.67503 .27471 Mdot
.31198 .41024 Mdot
.54663 .43824 Mdot
.54129 .63954 Mdot
.79761 .37578 Mdot
.54253 .37501 Mdot
.66416 .60383 Mdot
.53103 .38814 Mdot
.65737 .60014 Mdot
.57115 .42925 Mdot
.47544 .74385 Mdot
.42577 .2154 Mdot
.56177 .64446 Mdot
.75971 .57894 Mdot
.59069 .61827 Mdot
.18868 .51193 Mdot
.31378 .41774 Mdot
.47633 .71538 Mdot
.34478 .79288 Mdot
.47659 .73079 Mdot
.57886 .51646 Mdot
.51636 .58716 Mdot
.35154 .56241 Mdot
.33296 .39536 Mdot
.76757 .51742 Mdot
.50036 .75255 Mdot
.62301 .61684 Mdot
.56378 .60307 Mdot
.26121 .74239 Mdot
.29365 .75135 Mdot
.53096 .41426 Mdot
.60858 .26299 Mdot
.3584 .32976 Mdot
.50256 .39104 Mdot
.59889 .41427 Mdot
.54889 .68518 Mdot
.52858 .35454 Mdot
.4869 .51491 Mdot
.55694 .66261 Mdot
.68058 .59999 Mdot
.34229 .44419 Mdot
.66102 .59427 Mdot
.60069 .66393 Mdot
.5412 .56096 Mdot
.57746 .65441 Mdot
.51092 .43527 Mdot
.55147 .41216 Mdot
.37679 .41761 Mdot
.33885 .48074 Mdot
.36616 .40095 Mdot
.69401 .57504 Mdot
.56325 .65721 Mdot
.44665 .24584 Mdot
.54608 .39703 Mdot
.34906 .41936 Mdot
.38506 .53677 Mdot
.54164 .40062 Mdot
.38099 .57923 Mdot
.51913 .4222 Mdot
.33098 .40832 Mdot
.57689 .42037 Mdot
.34365 .42651 Mdot
.5364 .65812 Mdot
.57272 .43956 Mdot
.55369 .40202 Mdot
.21589 .3493 Mdot
.68734 .60898 Mdot
.31431 .41615 Mdot
.47148 .5627 Mdot
.59449 .40639 Mdot
.52663 .71517 Mdot
.52469 .36468 Mdot
.45931 .45219 Mdot
.48993 .41591 Mdot
.47339 .73214 Mdot
.59685 .44009 Mdot
.5427 .37416 Mdot
.64562 .41352 Mdot
.40241 .35279 Mdot
.35803 .47811 Mdot
.3766 .5586 Mdot
.30661 .41138 Mdot
.56882 .6818 Mdot
.59511 .65724 Mdot
.58791 .65119 Mdot
.66744 .50495 Mdot
.5365 .32521 Mdot
.55088 .36574 Mdot
.35067 .54691 Mdot
.67482 .59711 Mdot
.35064 .41291 Mdot
.67656 .59297 Mdot
.25839 .66551 Mdot
.69662 .57591 Mdot
.48804 .74458 Mdot
.66216 .71142 Mdot
.46716 .22689 Mdot
.70933 .6081 Mdot
.36474 .40008 Mdot
.66133 .72381 Mdot
.55601 .34276 Mdot
.59081 .58294 Mdot
.69709 .59495 Mdot
.23291 .71994 Mdot
.5167 .37018 Mdot
.56211 .52715 Mdot
.35558 .61081 Mdot
.69202 .58123 Mdot
.35836 .59263 Mdot
.57868 .40775 Mdot
.3677 .73077 Mdot
.32509 .44442 Mdot
.32598 .60265 Mdot
.56927 .4582 Mdot
.67431 .58395 Mdot
.57634 .64346 Mdot
.38647 .64071 Mdot
.34707 .56156 Mdot
.41642 .20323 Mdot
.78669 .47235 Mdot
.5614 .65877 Mdot
.46562 .79925 Mdot
.34783 .5914 Mdot
.50285 .38648 Mdot
.45203 .39464 Mdot
.59056 .39931 Mdot
.59899 .65449 Mdot
.5338 .6422 Mdot
.24684 .5441 Mdot
.55068 .41467 Mdot
.51981 .36769 Mdot
.3514 .37726 Mdot
.54816 .66183 Mdot
.35922 .42954 Mdot
.30637 .43921 Mdot
.53308 .65624 Mdot
.347 .43384 Mdot
.71173 .58568 Mdot
.22356 .50467 Mdot
.34681 .59156 Mdot
.35647 .58204 Mdot
.56296 .62839 Mdot
.54709 .61858 Mdot
.54482 .64958 Mdot
.51947 .42255 Mdot
.35691 .41045 Mdot
.54981 .43206 Mdot
.50002 .3923 Mdot
.30826 .45338 Mdot
.3598 .45597 Mdot
.54813 .42596 Mdot
.52326 .73977 Mdot
.73239 .59791 Mdot
.54123 .63026 Mdot
.34279 .60371 Mdot
.25555 .3692 Mdot
.3448 .54487 Mdot
.53336 .36504 Mdot
.39945 .65569 Mdot
.33689 .40612 Mdot
.71065 .59125 Mdot
.73973 .58405 Mdot
.70954 .60076 Mdot
.3912 .55977 Mdot
.31276 .44108 Mdot
.26921 .68694 Mdot
.5386 .36386 Mdot
.49952 .52798 Mdot
.77156 .50867 Mdot
.27904 .66837 Mdot
.33497 .59671 Mdot
.54188 .40383 Mdot
.47851 .72743 Mdot
.53071 .22942 Mdot
.57307 .36835 Mdot
.5797 .36206 Mdot
.67814 .66366 Mdot
.56798 .47275 Mdot
.31691 .39756 Mdot
.21582 .60136 Mdot
.53797 .33235 Mdot
.29151 .38119 Mdot
.74798 .75244 Mdot
.53289 .36053 Mdot
.52215 .39618 Mdot
.54773 .3848 Mdot
.56083 .41616 Mdot
.30933 .40033 Mdot
.72172 .52286 Mdot
.38804 .56767 Mdot
.51737 .54218 Mdot
.34253 .5864 Mdot
.53528 .67808 Mdot
.54672 .52226 Mdot
.34574 .39525 Mdot
.71214 .59314 Mdot
.48275 .19491 Mdot
.24308 .63793 Mdot
.55599 .66926 Mdot
.48848 .26137 Mdot
.70208 .59853 Mdot
.55243 .34012 Mdot
.66802 .57802 Mdot
.59564 .63534 Mdot
.34728 .57557 Mdot
.55251 .3319 Mdot
.38426 .42764 Mdot
.3327 .40061 Mdot
.53589 .40247 Mdot
.82447 .47294 Mdot
.38297 .58234 Mdot
.33541 .54075 Mdot
.52821 .42018 Mdot
.58098 .36332 Mdot
.35628 .43506 Mdot
.54659 .63092 Mdot
.56096 .79228 Mdot
.68406 .60603 Mdot
.56916 .44737 Mdot
.56441 .41692 Mdot
.25152 .63128 Mdot
.39014 .58407 Mdot
.49711 .72228 Mdot
.53304 .4189 Mdot
.25789 .62282 Mdot
.53533 .41952 Mdot
.60955 .38218 Mdot
.54474 .64264 Mdot
.48832 .38342 Mdot
.51094 .4031 Mdot
.5624 .30877 Mdot
.35235 .5933 Mdot
.32093 .42614 Mdot
.32933 .37958 Mdot
.48532 .71687 Mdot
.38028 .57972 Mdot
.55133 .4249 Mdot
.3876 .57959 Mdot
.50244 .37281 Mdot
.52547 .40945 Mdot
.33487 .59568 Mdot
.35867 .42993 Mdot
.33141 .52544 Mdot
.58205 .50523 Mdot
.557 .4161 Mdot
.57755 .347 Mdot
.67724 .49986 Mdot
.43776 .83962 Mdot
.51976 .38283 Mdot
.33067 .40542 Mdot
.54811 .40022 Mdot
.36687 .5929 Mdot
.69283 .57684 Mdot
.32895 .41244 Mdot
.55767 .62085 Mdot
.53823 .66522 Mdot
.26179 .43879 Mdot
.49647 .74005 Mdot
.58841 .35798 Mdot
.42579 .41479 Mdot
.37975 .4435 Mdot
.80206 .66028 Mdot
.52814 .65059 Mdot
.65844 .61586 Mdot
.57015 .4083 Mdot
.41423 .63415 Mdot
.35565 .54618 Mdot
.58432 .11306 Mdot
.27259 .68904 Mdot
.64156 .6121 Mdot
.37125 .79875 Mdot
.48398 .7276 Mdot
.50934 .38933 Mdot
.68926 .61633 Mdot
.55898 .67348 Mdot
.52303 .35249 Mdot
.4966 .44465 Mdot
.65507 .5418 Mdot
.51519 .6481 Mdot
.38762 .5852 Mdot
.58637 .64678 Mdot
.70413 .56892 Mdot
.48644 .74488 Mdot
.34134 .39741 Mdot
.54514 .37187 Mdot
.54184 .32027 Mdot
.55075 .62446 Mdot
.47521 .74425 Mdot
.53016 .42623 Mdot
.32602 .40095 Mdot
.59 .65576 Mdot
.57283 .39791 Mdot
.40382 .24414 Mdot
.34367 .46537 Mdot
.56964 .65004 Mdot
.54404 .34897 Mdot
.46241 .44538 Mdot
.56155 .62433 Mdot
.5445 .62464 Mdot
.53384 .40552 Mdot
.71434 .59033 Mdot
.52175 .42849 Mdot
.35946 .60694 Mdot
.67537 .56084 Mdot
.36509 .59064 Mdot
.73928 .62023 Mdot
.61508 .38006 Mdot
.40214 .76003 Mdot
.37353 .40148 Mdot
.71266 .5702 Mdot
.26707 .32036 Mdot
.58048 .36008 Mdot
.69505 .26242 Mdot
.42008 .49112 Mdot
.84381 .54538 Mdot
.47698 .15856 Mdot
.69273 .59358 Mdot
.37747 .58012 Mdot
.52292 .39621 Mdot
.32583 .56827 Mdot
.68519 .61473 Mdot
.78028 .51393 Mdot
.54919 .34811 Mdot
.3662 .41405 Mdot
.52935 .4304 Mdot
.36369 .43743 Mdot
.54013 .39877 Mdot
.5709 .47073 Mdot
.63565 .61929 Mdot
.61474 .51464 Mdot
.55538 .34174 Mdot
.32854 .22421 Mdot
.45508 .59959 Mdot
.69551 .60106 Mdot
.54834 .43554 Mdot
.49123 .73469 Mdot
.3847 .61618 Mdot
.66576 .33088 Mdot
.54946 .64549 Mdot
.33424 .60043 Mdot
.34509 .43866 Mdot
.52803 .63905 Mdot
.46867 .73034 Mdot
.51308 .32592 Mdot
.65775 .6068 Mdot
.35728 .56122 Mdot
.53903 .37302 Mdot
.51696 .37088 Mdot
.54593 .76515 Mdot
.44333 .67876 Mdot
.38682 .39605 Mdot
.19355 .40786 Mdot
.30108 .41104 Mdot
.67636 .60651 Mdot
.54449 .64469 Mdot
.52075 .37907 Mdot
.57625 .38154 Mdot
.59403 .66329 Mdot
.31478 .41832 Mdot
.5193 .66644 Mdot
.45998 .26752 Mdot
.54196 .61633 Mdot
.73308 .49991 Mdot
.32232 .41318 Mdot
.73008 .50288 Mdot
.70395 .56849 Mdot
.64589 .24293 Mdot
.69534 .42405 Mdot
.35649 .61133 Mdot
.73711 .49781 Mdot
.34345 .40873 Mdot
.54122 .41419 Mdot
.48729 .72563 Mdot
.49958 .73437 Mdot
.34875 .44166 Mdot
.54212 .67444 Mdot
.69091 .58217 Mdot
.52094 .39925 Mdot
.33694 .74586 Mdot
.26467 .49678 Mdot
.56104 .61537 Mdot
.53966 .47647 Mdot
.3544 .58863 Mdot
.51255 .4002 Mdot
.66341 .59957 Mdot
.3574 .56413 Mdot
.46916 .75411 Mdot
.23175 .5306 Mdot
.57733 .40321 Mdot
.23001 .606 Mdot
.37643 .57158 Mdot
.47415 .80757 Mdot
.56652 .39299 Mdot
.3481 .59152 Mdot
.60112 .44771 Mdot
.30196 .67583 Mdot
.44766 .52909 Mdot
.75019 .30566 Mdot
.51704 .62605 Mdot
.54157 .67088 Mdot
.36386 .69544 Mdot
.64484 .63658 Mdot
.33003 .5979 Mdot
.48497 .74519 Mdot
.7334 .40423 Mdot
.35588 .59228 Mdot
.50739 .40927 Mdot
.52684 .36376 Mdot
.43352 .26862 Mdot
.46688 .52931 Mdot
.47944 .74648 Mdot
.22806 .43582 Mdot
.59317 .39684 Mdot
.5223 .4526 Mdot
.57113 .37946 Mdot
.37991 .40084 Mdot
.37552 .56536 Mdot
.23838 .30707 Mdot
.38202 .58913 Mdot
.34465 .75928 Mdot
.56643 .6403 Mdot
.55004 .61476 Mdot
.53272 .37016 Mdot
.42986 .77505 Mdot
.65914 .30319 Mdot
.58705 .41983 Mdot
.53563 .71909 Mdot
.784 .46276 Mdot
.55322 .46521 Mdot
.32513 .38775 Mdot
.56947 .32771 Mdot
.37632 .46239 Mdot
.34207 .57189 Mdot
.69015 .58885 Mdot
.72478 .60762 Mdot
.35348 .56298 Mdot
.55286 .36696 Mdot
.56391 .70925 Mdot
.56412 .36054 Mdot
.53293 .41633 Mdot
.3103 .74303 Mdot
.67454 .62271 Mdot
.5429 .65251 Mdot
.69186 .61174 Mdot
.33171 .44344 Mdot
.87905 .37137 Mdot
.67445 .59153 Mdot
.44076 .38272 Mdot
.75251 .55172 Mdot
.73629 .50097 Mdot
.33227 .39945 Mdot
.71171 .57672 Mdot
.38473 .59118 Mdot
.85577 .52475 Mdot
.46842 .83477 Mdot
.32862 .5545 Mdot
.57147 .39117 Mdot
.35737 .39548 Mdot
.38721 .41638 Mdot
.32107 .59791 Mdot
.36068 .40292 Mdot
.61609 .35534 Mdot
.5472 .41755 Mdot
.32983 .59701 Mdot
.26985 .522 Mdot
.35026 .55936 Mdot
.21637 .51474 Mdot
.54058 .43374 Mdot
.32457 .41376 Mdot
.57995 .32809 Mdot
.31506 .38065 Mdot
.5003 .72087 Mdot
.52077 .35304 Mdot
.70117 .58298 Mdot
.47527 .52066 Mdot
.56832 .6486 Mdot
.40618 .65236 Mdot
.37553 .41869 Mdot
.35032 .5217 Mdot
.36938 .40651 Mdot
.35176 .39241 Mdot
.39086 .59906 Mdot
.33569 .45077 Mdot
.5213 .39668 Mdot
.524 .75701 Mdot
.36811 .44006 Mdot
.36659 .57797 Mdot
.70114 .58762 Mdot
.35139 .43261 Mdot
.538 .68525 Mdot
.56093 .40663 Mdot
.58002 .6542 Mdot
.63958 .62111 Mdot
.32892 .39614 Mdot
.71131 .57768 Mdot
.53429 .63537 Mdot
.66258 .61294 Mdot
.79852 .50885 Mdot
.33183 .57097 Mdot
.38865 .80232 Mdot
.53205 .48831 Mdot
.38384 .42962 Mdot
.62142 .60945 Mdot
.52217 .3801 Mdot
.56247 .40807 Mdot
.71445 .57442 Mdot
.38833 .41823 Mdot
.80947 .40212 Mdot
.44737 .44635 Mdot
.22813 .51134 Mdot
.34407 .55681 Mdot
.20474 .41764 Mdot
.24393 .57642 Mdot
.78401 .63128 Mdot
.4839 .38063 Mdot
.48455 .72764 Mdot
.5485 .35935 Mdot
.27719 .3007 Mdot
.68131 .57851 Mdot
.56223 .81404 Mdot
.50237 .35205 Mdot
.55006 .65459 Mdot
.55616 .39171 Mdot
.65597 .36252 Mdot
.58018 .3338 Mdot
.71742 .5999 Mdot
.31274 .62884 Mdot
.32335 .45282 Mdot
.70466 .59789 Mdot
.54011 .66505 Mdot
.74919 .43644 Mdot
.527 .35008 Mdot
.59544 .39345 Mdot
.5492 .61101 Mdot
.36615 .4105 Mdot
.54094 .68166 Mdot
.34658 .59118 Mdot
.68135 .59063 Mdot
.56865 .41168 Mdot
.49889 .42742 Mdot
.53786 .71054 Mdot
.37521 .56424 Mdot
.53671 .62385 Mdot
.37659 .60171 Mdot
.48511 .72672 Mdot
.55864 .33724 Mdot
.55803 .60993 Mdot
.51221 .37318 Mdot
.24554 .33253 Mdot
.32041 .75243 Mdot
.42148 .34741 Mdot
.54225 .65579 Mdot
.72609 .47933 Mdot
.37088 .58896 Mdot
.36785 .6049 Mdot
.31169 .35815 Mdot
.68025 .32735 Mdot
.69026 .6995 Mdot
.4329 .19483 Mdot
.34591 .59112 Mdot
.36298 .58693 Mdot
.56644 .673 Mdot
.34429 .4509 Mdot
.38809 .4463 Mdot
.52401 .64842 Mdot
.62449 .51233 Mdot
.35059 .41306 Mdot
.70604 .27278 Mdot
.5633 .68445 Mdot
.48201 .38498 Mdot
.50244 .70872 Mdot
.68757 .58576 Mdot
.62111 .51229 Mdot
.65289 .35927 Mdot
.51725 .37881 Mdot
.20331 .58338 Mdot
.5488 .6333 Mdot
.69677 .53136 Mdot
.63539 .21074 Mdot
.55598 .34862 Mdot
.55923 .3832 Mdot
.55817 .3682 Mdot
.68088 .62363 Mdot
.28286 .30959 Mdot
.51546 .37965 Mdot
.62341 .52055 Mdot
.59266 .42337 Mdot
.67441 .41335 Mdot
.68786 .61216 Mdot
.27401 .40155 Mdot
.52251 .61977 Mdot
.29607 .68963 Mdot
.62049 .44724 Mdot
.35765 .59863 Mdot
.58948 .59483 Mdot
.34246 .57863 Mdot
.66561 .28762 Mdot
.6973 .42706 Mdot
.3597 .38542 Mdot
.51797 .38791 Mdot
.57627 .60395 Mdot
.37149 .40199 Mdot
.47998 .76676 Mdot
.90691 .49406 Mdot
.37678 .56265 Mdot
.44638 .86211 Mdot
.37032 .60513 Mdot
.50136 .72655 Mdot
.35428 .437 Mdot
.53358 .25523 Mdot
.49817 .52678 Mdot
.34936 .43209 Mdot
.29391 .57598 Mdot
.29717 .41195 Mdot
.73311 .4854 Mdot
.32253 .45588 Mdot
.36927 .58144 Mdot
.41068 .59337 Mdot
.48881 .42831 Mdot
.52719 .38088 Mdot
.55406 .55152 Mdot
.43534 .40989 Mdot
.52452 .38271 Mdot
.55665 .66254 Mdot
.44772 .81538 Mdot
.5603 .59367 Mdot
.36971 .44476 Mdot
.38562 .56763 Mdot
.55882 .38525 Mdot
.54945 .41969 Mdot
.50811 .3737 Mdot
.20723 .35634 Mdot
.71148 .2817 Mdot
.52661 .41156 Mdot
.55893 .4495 Mdot
.53787 .65814 Mdot
.70358 .56268 Mdot
.36762 .21245 Mdot
.72345 .40786 Mdot
.58176 .37764 Mdot
.6925 .60944 Mdot
.657 .61825 Mdot
.53538 .34455 Mdot
.34376 .74018 Mdot
.51822 .76454 Mdot
.53926 .37331 Mdot
.68865 .39969 Mdot
.60837 .63847 Mdot
.49301 .74377 Mdot
.55248 .62448 Mdot
.30298 .42346 Mdot
.48183 .74259 Mdot
.59261 .62691 Mdot
.52857 .24919 Mdot
.48371 .7164 Mdot
.28542 .63282 Mdot
.69388 .57503 Mdot
.57296 .37632 Mdot
.3049 .40041 Mdot
.59668 .65777 Mdot
.35084 .56341 Mdot
.33397 .42196 Mdot
.38218 .61853 Mdot
.64069 .60262 Mdot
.6637 .52554 Mdot
.5007 .73536 Mdot
.35057 .59724 Mdot
.2311 .53129 Mdot
.69122 .61032 Mdot
.37921 .60765 Mdot
.43175 .77081 Mdot
.51194 .34861 Mdot
.6025 .2403 Mdot
.5711 .43689 Mdot
.8379 .49608 Mdot
.38302 .60285 Mdot
.4777 .71738 Mdot
.54787 .36678 Mdot
.56777 .63085 Mdot
.6159 .41296 Mdot
.57818 .37431 Mdot
.56558 .6202 Mdot
.53305 .41429 Mdot
.66283 .60449 Mdot
.35357 .46927 Mdot
.39035 .49337 Mdot
.15757 .57102 Mdot
.65971 .60778 Mdot
.47211 .76906 Mdot
.51941 .3841 Mdot
.79494 .48271 Mdot
.35223 .43082 Mdot
.567 .35186 Mdot
.28327 .36711 Mdot
.35281 .4474 Mdot
.33205 .42873 Mdot
.56715 .42595 Mdot
.3658 .61098 Mdot
.57095 .63763 Mdot
.69588 .60956 Mdot
.80188 .62684 Mdot
.57854 .39183 Mdot
.55115 .40103 Mdot
.70308 .59789 Mdot
.36394 .58906 Mdot
.55208 .41994 Mdot
.42932 .64731 Mdot
.83239 .59658 Mdot
.39533 .59093 Mdot
.503 .35919 Mdot
.54357 .20652 Mdot
.33541 .37179 Mdot
.44352 .85109 Mdot
.74049 .60805 Mdot
.53548 .6439 Mdot
.57308 .46974 Mdot
.66208 .16618 Mdot
.69139 .58761 Mdot
.28469 .68814 Mdot
.52224 .41452 Mdot
.54591 .39175 Mdot
.34484 .40213 Mdot
.55024 .42916 Mdot
.31816 .43297 Mdot
.17605 .62588 Mdot
.164 .47487 Mdot
.37157 .41877 Mdot
.37462 .44345 Mdot
.33113 .36454 Mdot
.34805 .22819 Mdot
.34147 .44185 Mdot
.49875 .3676 Mdot
.7678 .35881 Mdot
.50059 .33536 Mdot
.71799 .5763 Mdot
.65511 .62736 Mdot
.27647 .42537 Mdot
.4699 .70573 Mdot
.4247 .44225 Mdot
.63346 .4088 Mdot
.43865 .58037 Mdot
.35143 .60463 Mdot
.57883 .36728 Mdot
.49821 .73875 Mdot
.59027 .64249 Mdot
.58421 .34003 Mdot
.57153 .37062 Mdot
.36577 .43809 Mdot
.7053 .61858 Mdot
.38388 .61195 Mdot
.54585 .40558 Mdot
.51862 .67265 Mdot
.68055 .60282 Mdot
.37166 .44037 Mdot
.34007 .36052 Mdot
.69054 .61917 Mdot
.59845 .43962 Mdot
.53384 .38824 Mdot
.52995 .42527 Mdot
.58267 .47291 Mdot
.33513 .57691 Mdot
.59804 .665 Mdot
.49874 .39956 Mdot
.25899 .66261 Mdot
.59345 .53599 Mdot
.49198 .4062 Mdot
.35048 .40765 Mdot
.36046 .54612 Mdot
.49622 .71871 Mdot
.76496 .46286 Mdot
.57954 .39908 Mdot
.7113 .28415 Mdot
.45706 .25604 Mdot
.48209 .74143 Mdot
.3577 .38782 Mdot
.7115 .59424 Mdot
.58937 .40728 Mdot
.73251 .3297 Mdot
.52802 .36443 Mdot
.49769 .47433 Mdot
.54187 .63627 Mdot
.34667 .60253 Mdot
.84411 .56408 Mdot
.59018 .638 Mdot
.32969 .42853 Mdot
.75556 .30424 Mdot
.39252 .43129 Mdot
.32418 .45141 Mdot
.67535 .28026 Mdot
.33564 .58109 Mdot
.64327 .15325 Mdot
.45737 .84005 Mdot
.50694 .42095 Mdot
.37108 .59463 Mdot
.36199 .43441 Mdot
.51321 .40075 Mdot
.37662 .44488 Mdot
.3194 .4442 Mdot
.5157 .35547 Mdot
.53872 .38948 Mdot
.57703 .51057 Mdot
.67044 .23785 Mdot
.71034 .60196 Mdot
.31901 .40981 Mdot
.38426 .27271 Mdot
.51304 .38282 Mdot
.53871 .3643 Mdot
.51602 .72132 Mdot
.71662 .60108 Mdot
.64769 .3753 Mdot
.53296 .41805 Mdot
.17949 .50972 Mdot
.57404 .34385 Mdot
.31843 .38926 Mdot
.39525 .5917 Mdot
.33132 .72966 Mdot
.59764 .6603 Mdot
.31587 .40887 Mdot
.66798 .58705 Mdot
.34605 .37781 Mdot
.43282 .3831 Mdot
.33878 .57774 Mdot
.33101 .4083 Mdot
.52884 .67207 Mdot
.35448 .57051 Mdot
.38 .60641 Mdot
.76589 .36938 Mdot
.5315 .62951 Mdot
.68859 .57413 Mdot
.34653 .5795 Mdot
.40018 .24083 Mdot
.37193 .57818 Mdot
.40332 .27256 Mdot
.56415 .44314 Mdot
.63733 .52265 Mdot
.25657 .58606 Mdot
.56849 .47558 Mdot
.33462 .57226 Mdot
.69002 .61375 Mdot
.56653 .42125 Mdot
.35821 .40233 Mdot
.67586 .59002 Mdot
.35072 .64024 Mdot
.5454 .62154 Mdot
.37825 .41354 Mdot
.39035 .56991 Mdot
.3196 .41288 Mdot
.75867 .5211 Mdot
.6534 .56468 Mdot
.42982 .59726 Mdot
.52016 .53157 Mdot
.5062 .37939 Mdot
.31856 .48516 Mdot
.58652 .35469 Mdot
.57154 .36813 Mdot
.56983 .64907 Mdot
.66737 .50626 Mdot
.35902 .43033 Mdot
.84634 .5677 Mdot
.3493 .59918 Mdot
.18733 .54956 Mdot
.45262 .4382 Mdot
.58434 .37042 Mdot
.36534 .44197 Mdot
.38433 .44485 Mdot
.40602 .35372 Mdot
.58387 .67215 Mdot
.51177 .46027 Mdot
.61048 .40652 Mdot
.48927 .42428 Mdot
.38302 .60212 Mdot
.3994 .66497 Mdot
.54194 .67738 Mdot
.58518 .84781 Mdot
.54332 .62947 Mdot
.63728 .68199 Mdot
.33751 .45177 Mdot
.69029 .57823 Mdot
.53795 .36596 Mdot
.50141 .48317 Mdot
.33649 .38574 Mdot
.74452 .58842 Mdot
.70568 .58431 Mdot
.34661 .68014 Mdot
.33261 .59198 Mdot
.54423 .34316 Mdot
.53537 .35189 Mdot
.55325 .43378 Mdot
.55701 .4424 Mdot
.38407 .56823 Mdot
.50659 .40611 Mdot
.3247 .59349 Mdot
.41871 .23687 Mdot
.17674 .5161 Mdot
.59294 .61134 Mdot
.6702 .32736 Mdot
.38272 .42569 Mdot
.37012 .25611 Mdot
.49594 .45672 Mdot
.33309 .76377 Mdot
.79809 .46193 Mdot
.59746 .37991 Mdot
.55588 .67696 Mdot
.63616 .29853 Mdot
.58719 .6093 Mdot
.23603 .76247 Mdot
.60354 .67405 Mdot
.72989 .2826 Mdot
.51444 .39544 Mdot
.51732 .71694 Mdot
.48158 .44773 Mdot
.52494 .34764 Mdot
.62183 .64126 Mdot
.21381 .45043 Mdot
.27419 .55387 Mdot
.66765 .62051 Mdot
.56553 .40397 Mdot
.3316 .4579 Mdot
.51975 .39674 Mdot
.54002 .36078 Mdot
.51284 .40857 Mdot
.39751 .58889 Mdot
.55408 .33024 Mdot
.51249 .41741 Mdot
.45547 .67327 Mdot
.70218 .48349 Mdot
.58579 .64416 Mdot
.41451 .37307 Mdot
.67546 .59661 Mdot
.37165 .43131 Mdot
.48746 .49971 Mdot
.35362 .61072 Mdot
.36693 .34706 Mdot
.52242 .42584 Mdot
.25108 .57042 Mdot
.38975 .56904 Mdot
.68101 .5878 Mdot
.48709 .71812 Mdot
.77577 .3519 Mdot
.59505 .61746 Mdot
.48562 .71587 Mdot
.56733 .64786 Mdot
.29008 .31353 Mdot
.3641 .43964 Mdot
.50577 .37651 Mdot
.35038 .58526 Mdot
.57303 .63683 Mdot
.67266 .49003 Mdot
.56821 .37651 Mdot
.54338 .66029 Mdot
.5043 .38246 Mdot
.6494 .53123 Mdot
.55031 .7686 Mdot
.58741 .61248 Mdot
.40464 .5838 Mdot
.35677 .57371 Mdot
.70956 .58318 Mdot
.37498 .42709 Mdot
.34006 .40581 Mdot
.35794 .56485 Mdot
.39858 .83419 Mdot
.57831 .37281 Mdot
.51263 .39572 Mdot
.25964 .66028 Mdot
.52606 .3922 Mdot
.74936 .45511 Mdot
.50437 .71723 Mdot
.3772 .42875 Mdot
.51443 .40541 Mdot
.55559 .418 Mdot
.57417 .40603 Mdot
.75512 .52445 Mdot
.54821 .62525 Mdot
.59242 .39909 Mdot
.70852 .61053 Mdot
.42592 .74231 Mdot
.51134 .39071 Mdot
.50967 .44389 Mdot
.33766 .40842 Mdot
.1642 .4952 Mdot
.3589 .60908 Mdot
.55698 .66587 Mdot
.53632 .63077 Mdot
.674 .63493 Mdot
.31441 .45787 Mdot
.49805 .71407 Mdot
.73224 .727 Mdot
.47429 .72665 Mdot
.69806 .60286 Mdot
.71667 .65018 Mdot
.52477 .69072 Mdot
.56503 .66858 Mdot
.35655 .62313 Mdot
.52988 .43229 Mdot
.59257 .40825 Mdot
.2879 .69562 Mdot
.59252 .38832 Mdot
.70344 .58598 Mdot
.33061 .60247 Mdot
.3427 .41123 Mdot
.68451 .58459 Mdot
.37374 .60145 Mdot
.36446 .40876 Mdot
.51557 .34619 Mdot
.51504 .34372 Mdot
.33519 .4254 Mdot
.36818 .4007 Mdot
.53558 .37699 Mdot
.43157 .67786 Mdot
.30414 .4365 Mdot
.32703 .40992 Mdot
.49943 .74053 Mdot
.59276 .61251 Mdot
.54243 .3158 Mdot
.37369 .59455 Mdot
.52862 .42311 Mdot
.58918 .6096 Mdot
.7191 .59449 Mdot
.35712 .4261 Mdot
.55351 .41701 Mdot
.54611 .41068 Mdot
.69815 .60766 Mdot
.69689 .61951 Mdot
.68639 .58238 Mdot
.32114 .5762 Mdot
.56534 .43624 Mdot
.33969 .44015 Mdot
.33367 .58938 Mdot
.65697 .61816 Mdot
.66366 .58202 Mdot
.47982 .67185 Mdot
.52033 .37583 Mdot
.44538 .53309 Mdot
.85877 .34725 Mdot
.73934 .42561 Mdot
.49795 .71889 Mdot
.54256 .61453 Mdot
.70468 .50932 Mdot
.5419 .7558 Mdot
.38094 .57402 Mdot
.72165 .36856 Mdot
.71313 .57058 Mdot
.50519 .37198 Mdot
.57489 .34518 Mdot
.59772 .42148 Mdot
.68256 .59793 Mdot
.76443 .5038 Mdot
.38978 .41781 Mdot
.33752 .31289 Mdot
.67575 .59634 Mdot
.58856 .61395 Mdot
.56317 .60857 Mdot
.54289 .63 Mdot
.54474 .33383 Mdot
.39416 .34908 Mdot
.38016 .25961 Mdot
.34351 .24237 Mdot
.33296 .59721 Mdot
.39423 .407 Mdot
.79659 .50255 Mdot
.33477 .42903 Mdot
.59151 .63979 Mdot
.68461 .60107 Mdot
.33441 .40349 Mdot
.36417 .55921 Mdot
.36084 .58669 Mdot
.55152 .62029 Mdot
.56321 .62985 Mdot
.58017 .64726 Mdot
.30636 .43333 Mdot
.33638 .45107 Mdot
.58262 .39965 Mdot
.34939 .42404 Mdot
.2109 .61281 Mdot
.6434 .61499 Mdot
.57418 .60889 Mdot
.37888 .58347 Mdot
.36622 .43437 Mdot
.57382 .38119 Mdot
.70107 .67539 Mdot
.27412 .46357 Mdot
.66442 .6125 Mdot
.53208 .77699 Mdot
.28043 .79744 Mdot
.5275 .35292 Mdot
.3885 .58615 Mdot
.36305 .75605 Mdot
.56123 .37211 Mdot
.55093 .64099 Mdot
.25989 .31137 Mdot
.47048 .73623 Mdot
.51083 .41322 Mdot
.58992 .38123 Mdot
.37976 .60887 Mdot
.75785 .55561 Mdot
.5848 .40149 Mdot
.22379 .56555 Mdot
.39564 .60825 Mdot
.56885 .67652 Mdot
.83456 .60296 Mdot
.59338 .6774 Mdot
.62498 .50298 Mdot
.49881 .73095 Mdot
.54731 .35228 Mdot
.56194 .66149 Mdot
.67025 .61509 Mdot
.57395 .65338 Mdot
.35757 .38614 Mdot
.58367 .64643 Mdot
.55113 .39957 Mdot
.33738 .44152 Mdot
.37785 .57309 Mdot
.21716 .60467 Mdot
.44829 .68499 Mdot
.56714 .63003 Mdot
.50214 .73864 Mdot
.5083 .39654 Mdot
.63413 .43655 Mdot
.61989 .39359 Mdot
.51332 .38922 Mdot
.34082 .57991 Mdot
.36618 .44288 Mdot
.35475 .55224 Mdot
.5223 .44794 Mdot
.19765 .45653 Mdot
.37339 .60582 Mdot
.28013 .60682 Mdot
.70159 .59962 Mdot
.59938 .51157 Mdot
.57796 .38226 Mdot
.34697 .58385 Mdot
.56307 .43712 Mdot
.3615 .45598 Mdot
.48921 .55983 Mdot
.42964 .75597 Mdot
.35138 .58486 Mdot
.8212 .42613 Mdot
.47165 .56962 Mdot
.5623 .32314 Mdot
.34501 .58782 Mdot
.29275 .33886 Mdot
.49709 .72825 Mdot
.68682 .60644 Mdot
.65931 .619 Mdot
.66253 .6141 Mdot
.59046 .37089 Mdot
.48413 .43299 Mdot
.6729 .57798 Mdot
.39272 .60571 Mdot
.71769 .60106 Mdot
.53413 .5001 Mdot
.81849 .4164 Mdot
.67164 .58662 Mdot
.56945 .39509 Mdot
.51985 .45248 Mdot
.69855 .48425 Mdot
.59245 .65018 Mdot
.69134 .25934 Mdot
.54724 .2921 Mdot
.52664 .37769 Mdot
.49806 .33375 Mdot
.37824 .40501 Mdot
.40707 .77775 Mdot
.44392 .41996 Mdot
.53498 .76406 Mdot
.35442 .45544 Mdot
.5619 .69402 Mdot
.37578 .42895 Mdot
.52023 .35869 Mdot
.52408 .40856 Mdot
.37782 .45907 Mdot
.34782 .66192 Mdot
.35655 .71952 Mdot
.82463 .55874 Mdot
.32727 .4064 Mdot
.35218 .59302 Mdot
.37759 .56269 Mdot
.33618 .60002 Mdot
.57044 .68069 Mdot
.32467 .39754 Mdot
.57647 .42658 Mdot
.53494 .65621 Mdot
.5766 .36744 Mdot
.34937 .574 Mdot
.84655 .55807 Mdot
.33932 .40923 Mdot
.54197 .37366 Mdot
.46593 .8333 Mdot
.55983 .63509 Mdot
.68462 .61026 Mdot
.66382 .53189 Mdot
.55358 .68793 Mdot
.3422 .56369 Mdot
.38707 .44573 Mdot
.30978 .60953 Mdot
.45085 .4857 Mdot
.50812 .33167 Mdot
.4912 .37711 Mdot
.7897 .64839 Mdot
.44931 .75349 Mdot
.5715 .34579 Mdot
.5411 .66618 Mdot
.59732 .64435 Mdot
.55613 .41363 Mdot
.33691 .39697 Mdot
.65296 .60286 Mdot
.70869 .61132 Mdot
.58784 .44787 Mdot
.50341 .5298 Mdot
.59753 .51607 Mdot
.54817 .42469 Mdot
.55196 .47482 Mdot
.53668 .627 Mdot
.47624 .72101 Mdot
.261 .64193 Mdot
.67129 .58346 Mdot
.52365 .41622 Mdot
.30077 .54245 Mdot
.32502 .44662 Mdot
.58195 .64868 Mdot
.34068 .56871 Mdot
.77096 .52483 Mdot
.53763 .68293 Mdot
.55422 .41457 Mdot
.55269 .41956 Mdot
.37843 .60854 Mdot
.31891 .38897 Mdot
.68508 .59908 Mdot
.53543 .65155 Mdot
.67149 .58226 Mdot
.33099 .44492 Mdot
.33976 .41248 Mdot
.50074 .33495 Mdot
.55942 .47219 Mdot
.55585 .62225 Mdot
.55219 .45535 Mdot
.59062 .62342 Mdot
.76282 .56666 Mdot
.36968 .55012 Mdot
.53193 .35056 Mdot
.39903 .42271 Mdot
.3475 .57275 Mdot
.54358 .38658 Mdot
.77979 .69238 Mdot
.57561 .35988 Mdot
.5906 .67389 Mdot
.18809 .4769 Mdot
.70634 .60935 Mdot
.45362 .36162 Mdot
.6111 .3144 Mdot
.5277 .39436 Mdot
.5764 .6121 Mdot
.6169 .40768 Mdot
.37743 .60644 Mdot
.35434 .45256 Mdot
.39747 .85281 Mdot
.3684 .57594 Mdot
.51882 .40077 Mdot
.681 .58974 Mdot
.38849 .44086 Mdot
.47499 .73906 Mdot
.26781 .67401 Mdot
.60028 .3565 Mdot
.50664 .34913 Mdot
.5184 .41885 Mdot
.37032 .20578 Mdot
.56184 .66426 Mdot
.36398 .43456 Mdot
.38422 .59973 Mdot
.36435 .56431 Mdot
.5444 .6318 Mdot
.26114 .54766 Mdot
.5415 .56446 Mdot
.73535 .20982 Mdot
.57084 .62341 Mdot
.71962 .58473 Mdot
.53271 .52493 Mdot
.58779 .6257 Mdot
.55073 .65939 Mdot
.53401 .63319 Mdot
.26779 .61838 Mdot
.35932 .40887 Mdot
.54409 .41182 Mdot
.30337 .44138 Mdot
.54936 .35169 Mdot
.63189 .46985 Mdot
.34949 .56695 Mdot
.35085 .45385 Mdot
.78968 .6649 Mdot
.4315 .41831 Mdot
.56255 .37964 Mdot
.79696 .53466 Mdot
.61928 .3703 Mdot
.74864 .49066 Mdot
.59579 .3333 Mdot
.56768 .63886 Mdot
.45703 .41351 Mdot
.50254 .43907 Mdot
.21111 .60448 Mdot
.3792 .58577 Mdot
.50217 .726 Mdot
.59634 .36832 Mdot
.6097 .38367 Mdot
.36351 .45801 Mdot
.33291 .40363 Mdot
.67626 .57703 Mdot
.59634 .54633 Mdot
.37998 .57689 Mdot
.64754 .55945 Mdot
.52935 .38229 Mdot
.36602 .65745 Mdot
.37931 .36454 Mdot
.54399 .38506 Mdot
.75551 .3448 Mdot
.38152 .349 Mdot
.58729 .39555 Mdot
.30139 .31984 Mdot
.36591 .58738 Mdot
.18988 .48548 Mdot
.53764 .44713 Mdot
.5519 .64229 Mdot
.34664 .45207 Mdot
.37635 .40243 Mdot
.66318 .59489 Mdot
.27846 .72797 Mdot
.33535 .56885 Mdot
.34234 .45351 Mdot
.563 .36867 Mdot
.33793 .57268 Mdot
.49515 .74015 Mdot
.49864 .43185 Mdot
.71212 .34997 Mdot
.34804 .42122 Mdot
.55721 .4503 Mdot
.2389 .44852 Mdot
.61179 .5308 Mdot
.62647 .19103 Mdot
.34071 .60372 Mdot
.67989 .58112 Mdot
.56687 .31933 Mdot
.73157 .72544 Mdot
.59735 .41855 Mdot
.64195 .51739 Mdot
.28236 .40778 Mdot
.69296 .57705 Mdot
.55479 .37402 Mdot
.57719 .40984 Mdot
.49454 .5213 Mdot
.69749 .62022 Mdot
.5598 .35034 Mdot
.46798 .37433 Mdot
.36571 .41129 Mdot
.50431 .7209 Mdot
.34797 .41652 Mdot
.57092 .39116 Mdot
.47928 .42464 Mdot
.34872 .40057 Mdot
.76508 .62839 Mdot
.72804 .5929 Mdot
.35555 .60888 Mdot
.53155 .47247 Mdot
.5509 .44426 Mdot
.39123 .17706 Mdot
.50038 .72112 Mdot
.2885 .2894 Mdot
.52571 .67825 Mdot
.30769 .54453 Mdot
.53135 .70507 Mdot
.76125 .31638 Mdot
.22457 .60868 Mdot
.60328 .37233 Mdot
.69007 .3772 Mdot
.32076 .29411 Mdot
.34573 .55792 Mdot
.46601 .21955 Mdot
.52684 .38076 Mdot
.54315 .35924 Mdot
.56845 .67388 Mdot
.25015 .55099 Mdot
.35309 .74548 Mdot
.51042 .5388 Mdot
.69014 .59811 Mdot
.3236 .43755 Mdot
.54014 .40107 Mdot
.53644 .57391 Mdot
.58437 .63592 Mdot
.41136 .63655 Mdot
.54656 .37214 Mdot
.35493 .76947 Mdot
.27567 .6202 Mdot
.33274 .58035 Mdot
.55513 .61175 Mdot
.54505 .68779 Mdot
.52947 .35826 Mdot
.34672 .56219 Mdot
.58459 .39756 Mdot
.46905 .58738 Mdot
.56478 .45388 Mdot
.67059 .59115 Mdot
.50515 .39058 Mdot
.4591 .5135 Mdot
.67833 .21811 Mdot
.45858 .37344 Mdot
.34573 .39395 Mdot
.56584 .68253 Mdot
.54793 .62685 Mdot
.33466 .40544 Mdot
.54938 .62789 Mdot
.3516 .32042 Mdot
.49299 .28718 Mdot
.69498 .59713 Mdot
.52569 .47355 Mdot
.66695 .5959 Mdot
.50234 .72309 Mdot
.52288 .37589 Mdot
.72691 .73722 Mdot
.56833 .62427 Mdot
.22405 .36594 Mdot
.3732 .57647 Mdot
.50162 .72334 Mdot
.59184 .42527 Mdot
.71092 .6509 Mdot
.58957 .65138 Mdot
.58251 .68188 Mdot
.57632 .40459 Mdot
.3455 .40493 Mdot
.57312 .41257 Mdot
.61468 .36053 Mdot
.48862 .71635 Mdot
.5285 .43092 Mdot
.37379 .60132 Mdot
.30663 .41147 Mdot
.79115 .36995 Mdot
.59791 .65567 Mdot
.51846 .37118 Mdot
.56183 .36892 Mdot
.37938 .44689 Mdot
.57644 .44037 Mdot
.36541 .55832 Mdot
.49786 .08651 Mdot
.70136 .60058 Mdot
.46774 .73364 Mdot
.59855 .66672 Mdot
.59712 .38392 Mdot
.55405 .4226 Mdot
.80232 .63372 Mdot
.40863 .7197 Mdot
.36256 .60043 Mdot
.61437 .40762 Mdot
.53816 .657 Mdot
.68224 .58844 Mdot
.38393 .61415 Mdot
.53224 .42585 Mdot
.5427 .36474 Mdot
.67383 .58873 Mdot
.77765 .37947 Mdot
.53342 .76737 Mdot
.33469 .60038 Mdot
.45665 .4173 Mdot
.68859 .68994 Mdot
.57826 .37345 Mdot
.72607 .68192 Mdot
.32913 .40998 Mdot
.34129 .58966 Mdot
.35228 .2313 Mdot
.50317 .38257 Mdot
.37249 .56229 Mdot
.38027 .57944 Mdot
.50769 .42512 Mdot
.30899 .45084 Mdot
.30766 .42672 Mdot
.31834 .41765 Mdot
.16661 .52931 Mdot
.66049 .45692 Mdot
.5802 .64593 Mdot
.36489 .58812 Mdot
.58399 .60842 Mdot
.65961 .62203 Mdot
.58868 .53587 Mdot
.59456 .62818 Mdot
.3785 .40642 Mdot
.56254 .60807 Mdot
.57437 .40933 Mdot
.37819 .57232 Mdot
.56741 .66795 Mdot
.59111 .36386 Mdot
.63814 .35088 Mdot
.45392 .56342 Mdot
.65625 .5935 Mdot
.74441 .59584 Mdot
.53074 .40721 Mdot
.49543 .71877 Mdot
.53539 .37484 Mdot
.33059 .59975 Mdot
.46704 .50194 Mdot
.59522 .37735 Mdot
.56218 .62517 Mdot
.52717 .30487 Mdot
.58505 .66786 Mdot
.61512 .3869 Mdot
.56833 .39339 Mdot
.57022 .36282 Mdot
.58559 .40028 Mdot
.27895 .58212 Mdot
.34273 .55759 Mdot
.63737 .34123 Mdot
.53486 .60601 Mdot
.34433 .42909 Mdot
.38216 .39866 Mdot
.67276 .71582 Mdot
.46659 .73235 Mdot
.37282 .5937 Mdot
.58012 .3795 Mdot
.59206 .67534 Mdot
.84902 .55043 Mdot
.7663 .641 Mdot
.7525 .61068 Mdot
.54886 .66975 Mdot
.3534 .39395 Mdot
.58756 .64486 Mdot
.53684 .35551 Mdot
.49673 .40469 Mdot
.77325 .33631 Mdot
.40788 .60661 Mdot
.68366 .6003 Mdot
.56634 .35888 Mdot
.62382 .50058 Mdot
.53782 .65802 Mdot
.53428 .62907 Mdot
.57453 .3604 Mdot
.313 .41045 Mdot
.53994 .14794 Mdot
.33375 .57711 Mdot
.62203 .29737 Mdot
.36868 .48108 Mdot
.20204 .4829 Mdot
.35811 .56213 Mdot
.44449 .5747 Mdot
.53022 .65984 Mdot
.48351 .32203 Mdot
.34112 .4265 Mdot
.67962 .60016 Mdot
.49436 .40418 Mdot
.37863 .40869 Mdot
.52392 .64541 Mdot
.37784 .43277 Mdot
.51291 .36303 Mdot
.34665 .55607 Mdot
.53614 .63864 Mdot
.39164 .5603 Mdot
.38231 .45581 Mdot
.66914 .61016 Mdot
.59049 .50976 Mdot
.50876 .2216 Mdot
.37655 .34822 Mdot
.59225 .3997 Mdot
.50778 .62365 Mdot
.56662 .4343 Mdot
.34031 .45985 Mdot
.57749 .38544 Mdot
.27772 .44008 Mdot
.55209 .61458 Mdot
.55522 .45023 Mdot
.50895 .41029 Mdot
.46531 .23566 Mdot
.55496 .38247 Mdot
.52382 .43214 Mdot
.58845 .3969 Mdot
.35065 .48396 Mdot
.56796 .33167 Mdot
.35401 .40668 Mdot
.27967 .67812 Mdot
.55301 .65894 Mdot
.65594 .59216 Mdot
.689 .61853 Mdot
.63421 .51896 Mdot
.61221 .51307 Mdot
.25988 .55513 Mdot
.35553 .41566 Mdot
.37972 .59682 Mdot
.58503 .39612 Mdot
.3973 .21206 Mdot
.64061 .63125 Mdot
.53028 .65127 Mdot
.59522 .66453 Mdot
.5786 .47243 Mdot
.37451 .20217 Mdot
.5781 .44369 Mdot
.27123 .69163 Mdot
.57943 .45287 Mdot
.56536 .35119 Mdot
.55057 .68663 Mdot
.60762 .52304 Mdot
.5928 .39824 Mdot
.36529 .45717 Mdot
.67693 .60355 Mdot
.43267 .43258 Mdot
.56047 .72681 Mdot
.4449 .6049 Mdot
.50691 .24968 Mdot
.57345 .4325 Mdot
.53663 .64484 Mdot
.378 .41371 Mdot
.25447 .6362 Mdot
.33433 .58974 Mdot
.25329 .59047 Mdot
.41191 .24807 Mdot
.79176 .57998 Mdot
.68038 .60245 Mdot
.77149 .37488 Mdot
.55007 .40033 Mdot
.56828 .68251 Mdot
.51198 .35861 Mdot
.84993 .54579 Mdot
.7132 .57828 Mdot
.32577 .38968 Mdot
.35416 .59424 Mdot
.35609 .4577 Mdot
.42564 .3479 Mdot
.43189 .57898 Mdot
.49623 .60189 Mdot
.59585 .62213 Mdot
.64939 .38281 Mdot
.34753 .44302 Mdot
.54012 .42135 Mdot
.7849 .25727 Mdot
.32757 .41101 Mdot
.31548 .41527 Mdot
.7556 .57174 Mdot
.76582 .58689 Mdot
.59968 .44495 Mdot
.37976 .43399 Mdot
.55397 .6037 Mdot
.70169 .6088 Mdot
.57643 .41631 Mdot
.58331 .40528 Mdot
.34416 .4027 Mdot
.59221 .6422 Mdot
.6273 .29743 Mdot
.56568 .634 Mdot
.36852 .41199 Mdot
.56153 .64379 Mdot
.60092 .61351 Mdot
.55709 .66831 Mdot
.55699 .44555 Mdot
.57971 .3876 Mdot
.59161 .72222 Mdot
.33988 .41263 Mdot
.55588 .42564 Mdot
.5266 .41343 Mdot
.34319 .44102 Mdot
.51868 .67043 Mdot
.42413 .20523 Mdot
.51906 .38736 Mdot
.56143 .40409 Mdot
.68724 .57792 Mdot
.53138 .69567 Mdot
.54024 .78588 Mdot
.56683 .42141 Mdot
.72133 .59914 Mdot
.30751 .43723 Mdot
.53739 .37681 Mdot
.53615 .50221 Mdot
.59912 .61989 Mdot
.50376 .39099 Mdot
.47648 .74149 Mdot
.59614 .39622 Mdot
.5625 .16286 Mdot
.51489 .3764 Mdot
.35991 .43464 Mdot
.35203 .44855 Mdot
.74732 .55826 Mdot
.32723 .4279 Mdot
.49907 .7335 Mdot
.35193 .57268 Mdot
.84482 .51179 Mdot
.49281 .74096 Mdot
.57189 .35384 Mdot
.4573 .84025 Mdot
.53495 .45045 Mdot
.59676 .37106 Mdot
.32332 .24059 Mdot
.49091 .74131 Mdot
.36022 .44331 Mdot
.3233 .65052 Mdot
.5803 .45338 Mdot
.33986 .56892 Mdot
.48886 .40413 Mdot
.50375 .40967 Mdot
.20352 .53756 Mdot
.24831 .38322 Mdot
.33672 .60858 Mdot
.53465 .31418 Mdot
.56618 .422 Mdot
.46086 .70332 Mdot
.57009 .37652 Mdot
.66779 .58953 Mdot
.31619 .41837 Mdot
.58265 .62599 Mdot
.70642 .5991 Mdot
.52819 .38791 Mdot
.68046 .59624 Mdot
.58045 .64991 Mdot
.34021 .58308 Mdot
.52384 .36699 Mdot
.72057 .57986 Mdot
.6884 .59792 Mdot
.56109 .43424 Mdot
.34833 .45342 Mdot
.44196 .39897 Mdot
.53913 .3789 Mdot
.5443 .4189 Mdot
.34024 .40587 Mdot
.61786 .83389 Mdot
.52825 .35514 Mdot
.44704 .53881 Mdot
.32779 .3901 Mdot
.50862 .71213 Mdot
.57839 .66116 Mdot
.50155 .40677 Mdot
.34167 .5713 Mdot
.3472 .56999 Mdot
.54012 .6131 Mdot
.36476 .45499 Mdot
.59104 .65296 Mdot
.49853 .32672 Mdot
.5543 .47156 Mdot
.51019 .43632 Mdot
.36688 .82986 Mdot
.76053 .32714 Mdot
.34105 .39602 Mdot
.53941 .67638 Mdot
.51737 .54098 Mdot
.36361 .59168 Mdot
.55378 .60745 Mdot
.38568 .44578 Mdot
.36258 .39599 Mdot
.38248 .42477 Mdot
.69373 .57934 Mdot
.53237 .67579 Mdot
.32136 .3888 Mdot
.31188 .41556 Mdot
.57505 .40684 Mdot
.56379 .42337 Mdot
.29733 .37691 Mdot
.71882 .4747 Mdot
.66535 .60587 Mdot
.54362 .63709 Mdot
.3301 .1868 Mdot
.33126 .60131 Mdot
.46974 .23664 Mdot
.59593 .37623 Mdot
.91558 .46158 Mdot
.57846 .44488 Mdot
.56586 .37023 Mdot
.30341 .42787 Mdot
.70523 .57048 Mdot
.66957 .60367 Mdot
.34714 .44407 Mdot
.38865 .44596 Mdot
.67035 .58621 Mdot
.7969 .44809 Mdot
.82345 .42263 Mdot
.25286 .61441 Mdot
.35247 .43635 Mdot
.53172 .23009 Mdot
.34383 .56287 Mdot
.37056 .46613 Mdot
.35137 .61394 Mdot
.54971 .65804 Mdot
.52733 .65601 Mdot
.37681 .60941 Mdot
.57779 .40194 Mdot
.57727 .65712 Mdot
.55493 .32497 Mdot
.80643 .43746 Mdot
.63547 .25964 Mdot
.39093 .70609 Mdot
.57988 .34864 Mdot
.33925 .73571 Mdot
.37507 .75006 Mdot
.52825 .40075 Mdot
.45216 .46634 Mdot
.68203 .59928 Mdot
.35594 .47537 Mdot
.36206 .55784 Mdot
.61382 .18549 Mdot
.57925 .37593 Mdot
.36137 .4293 Mdot
.37828 .58876 Mdot
.72434 .54342 Mdot
.22256 .55739 Mdot
.55642 .3524 Mdot
.68483 .17761 Mdot
.337 .47384 Mdot
.582 .62565 Mdot
.38205 .81228 Mdot
.29961 .433 Mdot
.74177 .60283 Mdot
.52498 .65687 Mdot
.79773 .60863 Mdot
.3717 .4305 Mdot
.52552 .63329 Mdot
.32779 .44039 Mdot
.66487 .59557 Mdot
.32831 .46078 Mdot
.53407 .6432 Mdot
.55426 .3777 Mdot
.55039 .63119 Mdot
.6655 .6079 Mdot
.57485 .67915 Mdot
.35271 .55916 Mdot
.49958 .72429 Mdot
.35888 .58048 Mdot
.6088 .53449 Mdot
.21458 .42061 Mdot
.34645 .60276 Mdot
.68697 .54345 Mdot
.57381 .34695 Mdot
.31753 .38795 Mdot
.57087 .62065 Mdot
.53772 .60486 Mdot
.56276 .53355 Mdot
.34235 .43281 Mdot
.54061 .63561 Mdot
.40425 .24652 Mdot
.53419 .84707 Mdot
.48639 .43603 Mdot
.67535 .43299 Mdot
.34461 .43951 Mdot
.53673 .62289 Mdot
.26004 .65971 Mdot
.38388 .41137 Mdot
.57212 .62451 Mdot
.34723 .58782 Mdot
.36269 .56317 Mdot
.5797 .36973 Mdot
.41477 .5928 Mdot
.57004 .61378 Mdot
.31754 .69171 Mdot
.32289 .44478 Mdot
.7204 .54074 Mdot
.65893 .60206 Mdot
.54905 .66193 Mdot
.49671 .43261 Mdot
.38876 .38491 Mdot
.59041 .60635 Mdot
.68766 .33799 Mdot
.31207 .20659 Mdot
.54445 .63342 Mdot
.31593 .42204 Mdot
.36006 .42556 Mdot
.6197 .38238 Mdot
.5061 .52886 Mdot
.58542 .66259 Mdot
.70419 .75931 Mdot
.65176 .51339 Mdot
.48478 .72617 Mdot
.45619 .7759 Mdot
.59431 .39366 Mdot
.55782 .43928 Mdot
.36297 .5935 Mdot
.56075 .38756 Mdot
.30899 .41755 Mdot
.5935 .41308 Mdot
.37799 .56646 Mdot
.53047 .65693 Mdot
.52456 .36976 Mdot
.69742 .61213 Mdot
.33218 .6087 Mdot
.37641 .61111 Mdot
.56287 .65443 Mdot
.38089 .43095 Mdot
.59158 .58326 Mdot
.56213 .62905 Mdot
.57694 .42928 Mdot
.48071 .7391 Mdot
.50787 .37437 Mdot
.75655 .38078 Mdot
.38926 .42659 Mdot
.58859 .63529 Mdot
.35977 .38851 Mdot
.36345 .57977 Mdot
.52995 .61364 Mdot
.56969 .38451 Mdot
.57271 .62795 Mdot
.5485 .74282 Mdot
.78245 .40768 Mdot
.36482 .45559 Mdot
.5386 .71447 Mdot
.314 .42069 Mdot
.48391 .72498 Mdot
.75218 .40776 Mdot
.6904 .60436 Mdot
.54036 .65628 Mdot
.74359 .30993 Mdot
.56189 .62292 Mdot
.55338 .38444 Mdot
.5414 .39203 Mdot
.56647 .67383 Mdot
.7153 .59303 Mdot
.16679 .49148 Mdot
.43903 .54672 Mdot
.36667 .43955 Mdot
.50818 .30276 Mdot
.38408 .15763 Mdot
.39967 .60315 Mdot
.36424 .59682 Mdot
.60116 .42383 Mdot
.58346 .3693 Mdot
.38168 .61117 Mdot
.38655 .56865 Mdot
.6649 .5854 Mdot
.53231 .6374 Mdot
.29677 .44287 Mdot
.39155 .61376 Mdot
.62145 .34897 Mdot
.61583 .50489 Mdot
.59817 .4426 Mdot
.48191 .36506 Mdot
.53791 .33226 Mdot
.64106 .5304 Mdot
.38999 .58382 Mdot
.53253 .40896 Mdot
.58389 .34153 Mdot
.34566 .59261 Mdot
.66564 .59534 Mdot
.24681 .40114 Mdot
.55658 .64362 Mdot
.75888 .74488 Mdot
.50965 .37858 Mdot
.54881 .38044 Mdot
.33274 .59646 Mdot
.46248 .7151 Mdot
.36676 .40184 Mdot
.3848 .43372 Mdot
.56427 .66398 Mdot
.56965 .5361 Mdot
.58211 .43319 Mdot
.52898 .40364 Mdot
.54342 .6492 Mdot
.49879 .72287 Mdot
.36426 .69805 Mdot
.54826 .40928 Mdot
.37689 .58617 Mdot
.5831 .59283 Mdot
.39 .57957 Mdot
.52466 .35323 Mdot
.55234 .38675 Mdot
.56025 .44537 Mdot
.58329 .36822 Mdot
.36702 .6148 Mdot
.5368 .40669 Mdot
.5171 .45365 Mdot
.37158 .44438 Mdot
.5582 .44283 Mdot
.64869 .52158 Mdot
.56803 .39929 Mdot
.68111 .61332 Mdot
.52783 .58949 Mdot
.56999 .3618 Mdot
.54984 .44285 Mdot
.44162 .54735 Mdot
.55415 .3704 Mdot
.33213 .60144 Mdot
.34907 .42766 Mdot
.3642 .58814 Mdot
.38457 .60078 Mdot
.56984 .60329 Mdot
.66815 .58322 Mdot
.60325 .38639 Mdot
.66721 .61613 Mdot
.48549 .36765 Mdot
.51141 .36346 Mdot
.60559 .59785 Mdot
.27245 .69324 Mdot
.54387 .76033 Mdot
.57139 .38602 Mdot
.55757 .66297 Mdot
.58484 .62907 Mdot
.68908 .36252 Mdot
.56848 .32707 Mdot
.3817 .61353 Mdot
.34731 .58401 Mdot
.74643 .44516 Mdot
.20632 .54656 Mdot
.67021 .61021 Mdot
.5622 .55488 Mdot
.55073 .33366 Mdot
.53952 .41502 Mdot
.50229 .43622 Mdot
.59372 .62243 Mdot
.481 .71733 Mdot
.52985 .65091 Mdot
.50085 .70428 Mdot
.38601 .57259 Mdot
.59172 .41057 Mdot
.63885 .24932 Mdot
.33845 .40005 Mdot
.34864 .42712 Mdot
.38932 .60793 Mdot
.5912 .65814 Mdot
.61787 .35461 Mdot
.41083 .86375 Mdot
.38156 .46503 Mdot
.66629 .57856 Mdot
.52444 .40053 Mdot
.56232 .6578 Mdot
.32742 .40173 Mdot
.7148 .6088 Mdot
.51252 .409 Mdot
.5125 .64326 Mdot
.57654 .39034 Mdot
.3168 .29653 Mdot
.36682 .44565 Mdot
.85685 .53868 Mdot
.3916 .43302 Mdot
.33424 .61169 Mdot
.3521 .601 Mdot
.54529 .38721 Mdot
.37335 .82573 Mdot
.30808 .40054 Mdot
.41109 .58144 Mdot
.70831 .57364 Mdot
.46931 .72982 Mdot
.70333 .57612 Mdot
.5868 .62267 Mdot
.67908 .60385 Mdot
.53755 .62934 Mdot
.73763 .44847 Mdot
.38534 .46641 Mdot
.70361 .60027 Mdot
.47044 .68 Mdot
.55716 .3308 Mdot
.65596 .6163 Mdot
.53962 .46575 Mdot
.47426 .33568 Mdot
.5463 .64823 Mdot
.71527 .595 Mdot
.54354 .4214 Mdot
.61513 .20222 Mdot
.36786 .6049 Mdot
.37785 .615 Mdot
.53909 .32617 Mdot
.53188 .63552 Mdot
.37267 .4589 Mdot
.45769 .48945 Mdot
.50603 .71332 Mdot
.53152 .40554 Mdot
.59373 .40559 Mdot
.38436 .40024 Mdot
.39501 .40582 Mdot
.55001 .38888 Mdot
.41925 .22928 Mdot
.54563 .40245 Mdot
.34748 .56597 Mdot
.36552 .39844 Mdot
.35608 .42609 Mdot
.56399 .61239 Mdot
.33218 .45523 Mdot
.47895 .36989 Mdot
.35593 .51195 Mdot
.57044 .45884 Mdot
.36571 .57511 Mdot
.4568 .50492 Mdot
.59583 .66259 Mdot
.66487 .23999 Mdot
.38863 .4062 Mdot
.53179 .43392 Mdot
.31795 .43723 Mdot
.692 .58342 Mdot
.34139 .41486 Mdot
.32795 .39491 Mdot
.5339 .3845 Mdot
.54869 .35232 Mdot
.49114 .73978 Mdot
.5153 .53179 Mdot
.33512 .45332 Mdot
.53622 .4025 Mdot
.54079 .45089 Mdot
.509 .41986 Mdot
.46949 .54559 Mdot
.33878 .39503 Mdot
.4336 .27084 Mdot
.69857 .33059 Mdot
.34193 .45448 Mdot
.53956 .16021 Mdot
.47237 .7359 Mdot
.46736 .73172 Mdot
.4064 .59962 Mdot
.54818 .41033 Mdot
.55687 .67811 Mdot
.53497 .35655 Mdot
.49549 .3375 Mdot
.54118 .36291 Mdot
.71962 .59329 Mdot
.60084 .36848 Mdot
.49035 .72725 Mdot
.55846 .62708 Mdot
.51342 .39697 Mdot
.52671 .3677 Mdot
.46409 .73821 Mdot
.39253 .41585 Mdot
.37307 .40533 Mdot
.74098 .66712 Mdot
.69514 .58977 Mdot
.33832 .58215 Mdot
.5829 .38831 Mdot
.55913 .6639 Mdot
.55229 .63026 Mdot
.3409 .45798 Mdot
.55251 .63969 Mdot
.32994 .58553 Mdot
.56809 .38074 Mdot
.37777 .61425 Mdot
.71516 .6031 Mdot
.31791 .41378 Mdot
.58293 .38196 Mdot
.57427 .40718 Mdot
.35241 .44841 Mdot
.57243 .34588 Mdot
.68653 .57799 Mdot
.55627 .62325 Mdot
.37497 .42102 Mdot
.35131 .57146 Mdot
.56542 .61064 Mdot
.56186 .41527 Mdot
.29986 .2199 Mdot
.55777 .3917 Mdot
.5535 .41353 Mdot
.80834 .38269 Mdot
.60734 .41375 Mdot
.56273 .61551 Mdot
.37599 .39231 Mdot
.51859 .33858 Mdot
.64104 .49077 Mdot
.75383 .68943 Mdot
.55063 .60629 Mdot
.51882 .39648 Mdot
.68054 .24652 Mdot
.51573 .39596 Mdot
.64326 .56083 Mdot
.6056 .75856 Mdot
.65452 .37441 Mdot
.48243 .36755 Mdot
.36045 .61198 Mdot
.49444 .73764 Mdot
.54861 .61745 Mdot
.31251 .33861 Mdot
.53383 .39175 Mdot
.28594 .33797 Mdot
.50637 .40516 Mdot
.36248 .56224 Mdot
.47642 .34161 Mdot
.5459 .6362 Mdot
.2448 .67278 Mdot
.57551 .42819 Mdot
.34562 .39522 Mdot
.57261 .6082 Mdot
.47025 .73122 Mdot
.55202 .41756 Mdot
.68064 .61815 Mdot
.3964 .56031 Mdot
.54649 .47097 Mdot
.36336 .57171 Mdot
.52575 .41475 Mdot
.52307 .31713 Mdot
.32529 .7781 Mdot
.3709 .4427 Mdot
.35742 .59467 Mdot
.41126 .76966 Mdot
.56454 .34201 Mdot
.37318 .42806 Mdot
.34135 .42752 Mdot
.66115 .60413 Mdot
.50655 .56866 Mdot
.24447 .46104 Mdot
.59016 .22737 Mdot
.41506 .37053 Mdot
.54651 .61352 Mdot
.374 .73439 Mdot
.57371 .41911 Mdot
.42555 .60231 Mdot
.33943 .60864 Mdot
.55051 .37884 Mdot
.38406 .3635 Mdot
.31999 .41408 Mdot
.55679 .40343 Mdot
.66678 .59517 Mdot
.39887 .65349 Mdot
.42511 .62511 Mdot
.43906 .17098 Mdot
.55061 .60477 Mdot
.49584 .41712 Mdot
.47764 .38797 Mdot
.5027 .73558 Mdot
.50487 .36668 Mdot
.56076 .61737 Mdot
.80412 .4803 Mdot
.71635 .58869 Mdot
.32297 .40506 Mdot
.47203 .73518 Mdot
.5365 .33064 Mdot
.52823 .44253 Mdot
.65719 .59022 Mdot
.53818 .43202 Mdot
.28453 .7319 Mdot
.46613 .76844 Mdot
.57134 .66407 Mdot
.37971 .4275 Mdot
.54406 .33425 Mdot
.48407 .71635 Mdot
.53661 .38756 Mdot
.54706 .2627 Mdot
.53812 .43672 Mdot
.23078 .46394 Mdot
.34508 .45215 Mdot
.3611 .57346 Mdot
.49662 .3479 Mdot
.54867 .36073 Mdot
.69483 .68235 Mdot
.49824 .33571 Mdot
.51394 .3764 Mdot
.37302 .45359 Mdot
.33961 .3977 Mdot
.35319 .40758 Mdot
.58455 .64434 Mdot
.25817 .6246 Mdot
.37263 .58468 Mdot
.59613 .41504 Mdot
.39019 .61437 Mdot
.58299 .28478 Mdot
.66122 .58417 Mdot
.55794 .18584 Mdot
.52298 .427 Mdot
.35699 .41185 Mdot
.30076 .52662 Mdot
.30711 .43499 Mdot
.5195 .61841 Mdot
.37973 .576 Mdot
.32339 .41294 Mdot
.55875 .36398 Mdot
.49593 .53186 Mdot
.46762 .17927 Mdot
.35857 .58758 Mdot
.51773 .44969 Mdot
.53724 .60745 Mdot
.60271 .64658 Mdot
.39926 .13729 Mdot
.36298 .60156 Mdot
.38107 .7503 Mdot
.53154 .39883 Mdot
.34169 .40041 Mdot
.34575 .60684 Mdot
.36423 .60813 Mdot
.54701 .64468 Mdot
.55612 .35323 Mdot
.56881 .36272 Mdot
.47484 .73991 Mdot
.34652 .58093 Mdot
.52984 .32802 Mdot
.53488 .45302 Mdot
.77586 .33914 Mdot
.29911 .36459 Mdot
.65802 .81822 Mdot
.49665 .32809 Mdot
.40077 .363 Mdot
.5306 .5192 Mdot
.31973 .4002 Mdot
.56628 .35765 Mdot
.53232 .33878 Mdot
.56395 .61338 Mdot
.56397 .38667 Mdot
.56951 .67762 Mdot
.37126 .5979 Mdot
.52471 .16476 Mdot
.28666 .4732 Mdot
.79733 .47551 Mdot
.56077 .38232 Mdot
.2005 .51271 Mdot
.70696 .58974 Mdot
.31542 .57954 Mdot
.36966 .4097 Mdot
.54794 .34101 Mdot
.57522 .68258 Mdot
.53969 .65695 Mdot
.33259 .42227 Mdot
.31763 .70592 Mdot
.7179 .68331 Mdot
.52659 .35151 Mdot
.58042 .66023 Mdot
.30337 .55617 Mdot
.40196 .23401 Mdot
.37104 .62609 Mdot
.71603 .58427 Mdot
.53056 .65255 Mdot
.39336 .59606 Mdot
.35337 .36742 Mdot
.32413 .41977 Mdot
.3668 .38783 Mdot
.63043 .7272 Mdot
.58405 .6666 Mdot
.70706 .60167 Mdot
.22859 .59691 Mdot
.2193 .58972 Mdot
.7188 .58902 Mdot
.53123 .66195 Mdot
.3328 .39908 Mdot
.3685 .42258 Mdot
.34998 .42819 Mdot
.23808 .66087 Mdot
.3821 .4404 Mdot
.48379 .26124 Mdot
.53102 .44795 Mdot
.59344 .48068 Mdot
.51704 .39446 Mdot
.35816 .61621 Mdot
.3649 .44612 Mdot
.54532 .52703 Mdot
.58035 .35891 Mdot
.45799 .17227 Mdot
.52834 .40568 Mdot
.35557 .62535 Mdot
.55387 .40781 Mdot
.48937 .22616 Mdot
.32502 .39174 Mdot
.5691 .38821 Mdot
.338 .55776 Mdot
.68792 .59494 Mdot
.28791 .42174 Mdot
.56894 .3613 Mdot
.2402 .54 Mdot
.60402 .41293 Mdot
.806 .46759 Mdot
.73441 .52743 Mdot
.66727 .57715 Mdot
.46966 .36814 Mdot
.53443 .62114 Mdot
.28335 .42271 Mdot
.48611 .44387 Mdot
.35755 .58615 Mdot
.23924 .35295 Mdot
.54244 .6611 Mdot
.45062 .37958 Mdot
.61615 .40011 Mdot
.66804 .5845 Mdot
.35242 .37346 Mdot
.33403 .60196 Mdot
.59089 .36193 Mdot
.50881 .42548 Mdot
.79061 .45879 Mdot
.50053 .45741 Mdot
.58025 .43821 Mdot
.65187 .60621 Mdot
.44175 .27348 Mdot
.56971 .40274 Mdot
.51748 .65953 Mdot
.3632 .38719 Mdot
.54265 .32552 Mdot
.43298 .2676 Mdot
.53621 .40115 Mdot
.3314 .41274 Mdot
.37184 .38725 Mdot
.27492 .5193 Mdot
.69666 .5703 Mdot
.53774 .43642 Mdot
.77029 .53857 Mdot
.56799 .43493 Mdot
.37632 .58231 Mdot
.52566 .35602 Mdot
.54537 .65605 Mdot
.26641 .683 Mdot
.57959 .63607 Mdot
.53277 .35482 Mdot
.3528 .43069 Mdot
.35157 .61139 Mdot
.59587 .73042 Mdot
.64121 .74364 Mdot
.47754 .26262 Mdot
.78806 .67281 Mdot
.70882 .58402 Mdot
.67498 .62299 Mdot
.3256 .58908 Mdot
.57067 .39037 Mdot
.7503 .55078 Mdot
.58932 .44234 Mdot
.56078 .40525 Mdot
.53932 .3632 Mdot
.41243 .56378 Mdot
.36816 .59185 Mdot
.55855 .63721 Mdot
.55194 .38902 Mdot
.53751 .40366 Mdot
.32505 .44278 Mdot
.68965 .59605 Mdot
.58124 .63293 Mdot
.69904 .59599 Mdot
.57124 .64469 Mdot
.55758 .16004 Mdot
.5502 .46034 Mdot
.68772 .59279 Mdot
.32497 .59475 Mdot
.34015 .40541 Mdot
.49253 .71334 Mdot
.5844 .61809 Mdot
.54269 .63649 Mdot
.53122 .40429 Mdot
.33448 .40706 Mdot
.33564 .45512 Mdot
.69583 .58303 Mdot
.33779 .59308 Mdot
.53496 .35474 Mdot
.52128 .35328 Mdot
.66834 .35018 Mdot
.58806 .61383 Mdot
.38574 .25179 Mdot
.27467 .54388 Mdot
.57216 .38847 Mdot
.37782 .43823 Mdot
.52995 .37057 Mdot
.67733 .26298 Mdot
.37834 .40665 Mdot
.56538 .35159 Mdot
.19851 .54673 Mdot
.59695 .63438 Mdot
.23623 .49961 Mdot
.5497 .44782 Mdot
.80797 .6263 Mdot
.56819 .42619 Mdot
.74654 .28899 Mdot
.43636 .71931 Mdot
.59145 .41624 Mdot
.57391 .41396 Mdot
.57672 .22158 Mdot
.52687 .39254 Mdot
.48621 .72306 Mdot
.46836 .35736 Mdot
.36261 .3956 Mdot
.56197 .51931 Mdot
.51449 .67592 Mdot
.71167 .57379 Mdot
.56472 .66404 Mdot
.52995 .72451 Mdot
.67011 .59046 Mdot
.35262 .43755 Mdot
.58594 .40148 Mdot
.59718 .50976 Mdot
.55827 .59956 Mdot
.61651 .37549 Mdot
.37726 .5799 Mdot
.54472 .70778 Mdot
.55955 .68151 Mdot
.35431 .57307 Mdot
.50954 .41374 Mdot
.4567 .19848 Mdot
.58396 .76796 Mdot
.85107 .51816 Mdot
.33434 .59981 Mdot
.35958 .5609 Mdot
.25354 .64609 Mdot
.71566 .57773 Mdot
.75152 .38657 Mdot
.21179 .486 Mdot
.33673 .5712 Mdot
.76664 .45796 Mdot
.52889 .63966 Mdot
.23232 .53681 Mdot
.35616 .47529 Mdot
.50734 .4356 Mdot
.55609 .36281 Mdot
.33977 .59332 Mdot
.53867 .49635 Mdot
.35056 .78918 Mdot
.35789 .58123 Mdot
.48097 .40407 Mdot
.48439 .58668 Mdot
.47737 .73577 Mdot
.4823 .74478 Mdot
.68559 .57145 Mdot
.75477 .64079 Mdot
.33339 .44487 Mdot
.66434 .58796 Mdot
.42213 .63761 Mdot
.53074 .42994 Mdot
.35082 .58308 Mdot
.48397 .71325 Mdot
.3556 .56577 Mdot
.66902 .59861 Mdot
.66769 .57807 Mdot
.3725 .44344 Mdot
.36753 .40261 Mdot
.39051 .35861 Mdot
.74368 .47841 Mdot
.51466 .3964 Mdot
.30931 .27007 Mdot
.32386 .44669 Mdot
.46771 .42157 Mdot
.72093 .59907 Mdot
.6911 .59251 Mdot
.3255 .29955 Mdot
.58607 .38946 Mdot
.73571 .55554 Mdot
.5812 .38329 Mdot
.73736 .39222 Mdot
.50944 .35782 Mdot
.54975 .6432 Mdot
.59068 .40807 Mdot
.59868 .58494 Mdot
.59325 .38977 Mdot
.51305 .37535 Mdot
.53063 .643 Mdot
.55845 .46847 Mdot
.54399 .65557 Mdot
.53627 .35235 Mdot
.70336 .62051 Mdot
.5599 .6639 Mdot
.6701 .45803 Mdot
.44772 .54084 Mdot
.49393 .72111 Mdot
.67757 .61509 Mdot
.65902 .60813 Mdot
.62384 .51587 Mdot
.37124 .41132 Mdot
.40247 .38901 Mdot
.56918 .39209 Mdot
.53478 .62825 Mdot
.3655 .59457 Mdot
.53978 .40349 Mdot
.52146 .34968 Mdot
.56589 .44698 Mdot
.3176 .42618 Mdot
.5893 .66127 Mdot
.68214 .5933 Mdot
.58205 .6555 Mdot
.71924 .66484 Mdot
.53903 .68373 Mdot
.57713 .33637 Mdot
.4912 .37333 Mdot
.58913 .27134 Mdot
.26438 .34152 Mdot
.18141 .5365 Mdot
.32665 .42275 Mdot
.49369 .73393 Mdot
.66826 .57872 Mdot
.51443 .3037 Mdot
.3636 .4101 Mdot
.53398 .64592 Mdot
.57678 .38983 Mdot
.49304 .43238 Mdot
.38067 .63579 Mdot
.28085 .42385 Mdot
.66737 .50789 Mdot
.55884 .68385 Mdot
.4818 .72733 Mdot
.25621 .62521 Mdot
.43421 .40603 Mdot
.56978 .53223 Mdot
.54199 .37029 Mdot
.68596 .61799 Mdot
.32742 .40176 Mdot
.58985 .74545 Mdot
.34349 .58725 Mdot
.50871 .52995 Mdot
.56174 .38271 Mdot
.28747 .63742 Mdot
.35117 .43092 Mdot
.66514 .60041 Mdot
.34043 .59303 Mdot
.70895 .57152 Mdot
.4819 .74528 Mdot
.77789 .62294 Mdot
.55553 .43712 Mdot
.51458 .37848 Mdot
.35969 .624 Mdot
.33066 .44152 Mdot
.74381 .5932 Mdot
.78898 .43207 Mdot
.57399 .66761 Mdot
.72957 .55572 Mdot
.30452 .41666 Mdot
.51284 .2449 Mdot
.58325 .65132 Mdot
.38986 .60745 Mdot
.6169 .53017 Mdot
.38018 .56789 Mdot
.57546 .36672 Mdot
.35679 .4186 Mdot
.3721 .60191 Mdot
.6827 .68334 Mdot
.67113 .2259 Mdot
.52931 .23523 Mdot
.58122 .4283 Mdot
.54594 .17888 Mdot
.81029 .42057 Mdot
.4912 .48085 Mdot
.35326 .5585 Mdot
.53893 .38132 Mdot
.49993 .37354 Mdot
.58001 .42374 Mdot
.38229 .5955 Mdot
.69043 .65119 Mdot
.53993 .64299 Mdot
.5226 .40374 Mdot
.66116 .59554 Mdot
.55181 .65379 Mdot
.61734 .60818 Mdot
.55332 .6187 Mdot
.35373 .39126 Mdot
.57721 .36045 Mdot
.26319 .59862 Mdot
.69841 .22575 Mdot
.36293 .58796 Mdot
.49376 .7214 Mdot
.50711 .39055 Mdot
.2004 .46013 Mdot
.35436 .40829 Mdot
.57223 .66924 Mdot
.54832 .3797 Mdot
.68956 .66139 Mdot
.47924 .70913 Mdot
.5473 .62443 Mdot
.37066 .42005 Mdot
.47895 .47908 Mdot
.5628 .38863 Mdot
.56427 .42926 Mdot
.33787 .44298 Mdot
.75967 .64866 Mdot
.26729 .67822 Mdot
.52792 .36859 Mdot
.35943 .57343 Mdot
.4938 .86558 Mdot
.53565 .442 Mdot
.32164 .36639 Mdot
.46825 .73201 Mdot
.25213 .54015 Mdot
.37805 .25512 Mdot
.46977 .36472 Mdot
.59391 .21887 Mdot
.59952 .52115 Mdot
.5353 .16637 Mdot
.72637 .62521 Mdot
.45555 .63275 Mdot
.57071 .16367 Mdot
.33137 .56622 Mdot
.60215 .476 Mdot
.64247 .30915 Mdot
.29905 .69802 Mdot
.52672 .50587 Mdot
.70884 .73122 Mdot
.67749 .70425 Mdot
.49671 .63537 Mdot
.56809 .62475 Mdot
.72155 .37606 Mdot
.53254 .35699 Mdot
.81351 .42834 Mdot
.4341 .22792 Mdot
.34597 .79315 Mdot
.5605 .17973 Mdot
.77153 .53541 Mdot
.48296 .18543 Mdot
.69093 .25979 Mdot
.60745 .27285 Mdot
.27706 .44826 Mdot
.65356 .803 Mdot
.22703 .60204 Mdot
.78734 .53373 Mdot
.59091 .32731 Mdot
.54098 .56939 Mdot
.80675 .53113 Mdot
.48082 .28236 Mdot
.40215 .83374 Mdot
.57803 .61807 Mdot
.34706 .38339 Mdot
.66274 .3265 Mdot
.28918 .41086 Mdot
.35118 .5214 Mdot
.59081 .21648 Mdot
.74343 .29448 Mdot
.48241 .22659 Mdot
.80855 .63497 Mdot
.33404 .33002 Mdot
.1584 .53732 Mdot
.45952 .56842 Mdot
.34524 .37983 Mdot
.59899 .80785 Mdot
.21863 .58732 Mdot
.27283 .47015 Mdot
.53701 .29882 Mdot
.64296 .62668 Mdot
.69096 .47392 Mdot
.36049 .43012 Mdot
.37776 .24896 Mdot
.48198 .74834 Mdot
.25513 .42837 Mdot
.5776 .5802 Mdot
.64914 .23011 Mdot
.50319 .60508 Mdot
.23922 .55432 Mdot
.35871 .7194 Mdot
.30326 .21618 Mdot
.76254 .49376 Mdot
.71968 .30959 Mdot
.36337 .63424 Mdot
.52098 .50158 Mdot
.33545 .75314 Mdot
.73179 .4942 Mdot
.21223 .57713 Mdot
.28172 .26477 Mdot
.82666 .47805 Mdot
.35161 .20016 Mdot
.31892 .37668 Mdot
.56973 .44469 Mdot
.68251 .288 Mdot
.41993 .37261 Mdot
.65697 .58446 Mdot
.40736 .17929 Mdot
.70979 .61082 Mdot
.29831 .3945 Mdot
.31247 .70481 Mdot
.48841 .24471 Mdot
.70356 .54824 Mdot
.73491 .58697 Mdot
.60336 .37119 Mdot
.15019 .63536 Mdot
.52295 .17056 Mdot
.26861 .52284 Mdot
.77584 .33795 Mdot
.36002 .65542 Mdot
.72933 .5396 Mdot
.37612 .59782 Mdot
.63391 .19173 Mdot
.36552 .41837 Mdot
.62732 .162 Mdot
.66182 .21146 Mdot
.44668 .81172 Mdot
.31927 .83944 Mdot
.40818 .68754 Mdot
.64523 .35518 Mdot
.61199 .50144 Mdot
.6591 .48722 Mdot
.3521 .77996 Mdot
.46183 .81621 Mdot
.3477 .65654 Mdot
.80507 .58318 Mdot
.59297 .17832 Mdot
.75673 .43163 Mdot
.77668 .5812 Mdot
.3167 .72092 Mdot
.45676 .53906 Mdot
.39508 .38996 Mdot
.42036 .51814 Mdot
.27435 .43935 Mdot
.39262 .18549 Mdot
.41552 .38648 Mdot
.42366 .86389 Mdot
.71518 .62063 Mdot
.45128 .73503 Mdot
.78004 .36203 Mdot
.67756 .44327 Mdot
.56009 .28035 Mdot
.27256 .64533 Mdot
.6002 .36122 Mdot
.26064 .6349 Mdot
.41322 .4572 Mdot
.53406 .71749 Mdot
.25237 .62571 Mdot
.29504 .58823 Mdot
.78763 .44871 Mdot
.63437 .26285 Mdot
.19784 .52745 Mdot
.37011 .39731 Mdot
.71139 .50959 Mdot
.7661 .4801 Mdot
.77854 .34647 Mdot
.40964 .7689 Mdot
.85391 .50389 Mdot
.42438 .77967 Mdot
.58433 .44568 Mdot
.4784 .42703 Mdot
.60069 .32988 Mdot
.74492 .49909 Mdot
.55198 .45169 Mdot
.2899 .63984 Mdot
.79723 .36809 Mdot
.37229 .36155 Mdot
.58175 .703 Mdot
.24628 .33144 Mdot
.8426 .49929 Mdot
.68637 .30092 Mdot
.4304 .72964 Mdot
.55225 .48782 Mdot
.15592 .4521 Mdot
.55983 .65077 Mdot
.76421 .45034 Mdot
.38148 .55699 Mdot
.61996 .73504 Mdot
.56041 .22676 Mdot
.43531 .8099 Mdot
.80162 .37236 Mdot
.27628 .67522 Mdot
.53035 .76849 Mdot
.60579 .55821 Mdot
.68947 .55043 Mdot
.26114 .31707 Mdot
.48472 .39715 Mdot
.59143 .30256 Mdot
.65764 .61501 Mdot
.44027 .34668 Mdot
.7078 .33637 Mdot
.63419 .76719 Mdot
.48544 .43104 Mdot
.54688 .80063 Mdot
.47981 .72514 Mdot
.50281 .53098 Mdot
.43793 .13507 Mdot
.60203 .35472 Mdot
.41045 .70179 Mdot
.82825 .49092 Mdot
.70948 .52523 Mdot
.75528 .34107 Mdot
.27936 .60302 Mdot
.33402 .21687 Mdot
.69376 .23276 Mdot
.63511 .75376 Mdot
.49806 .15525 Mdot
.85148 .43175 Mdot
.30215 .24085 Mdot
.29205 .30845 Mdot
.33094 .55932 Mdot
.58662 .11509 Mdot
.5428 .67161 Mdot
.22693 .37191 Mdot
.41138 .37174 Mdot
.65617 .66768 Mdot
.35734 .46373 Mdot
.61621 .42978 Mdot
.50033 .62102 Mdot
.32077 .46607 Mdot
.55053 .32518 Mdot
.34869 .18457 Mdot
.24425 .30334 Mdot
.35901 .18396 Mdot
.83023 .54068 Mdot
.50797 .15664 Mdot
.65886 .36574 Mdot
.49384 .26171 Mdot
.69155 .35009 Mdot
.52593 .35414 Mdot
.72963 .42226 Mdot
.40476 .69415 Mdot
.57143 .76817 Mdot
.25905 .4612 Mdot
.31753 .45474 Mdot
.40063 .19417 Mdot
.34303 .15717 Mdot
.34736 .32023 Mdot
.39653 .28327 Mdot
.42342 .61389 Mdot
.75002 .48072 Mdot
.39941 .46553 Mdot
.53045 .78973 Mdot
.78095 .35661 Mdot
.64164 .30625 Mdot
.77683 .46091 Mdot
.65174 .76725 Mdot
.63529 .57059 Mdot
.46631 .7031 Mdot
.6471 .22112 Mdot
.6705 .3992 Mdot
.44801 .80192 Mdot
.60326 .4841 Mdot
.39175 .81145 Mdot
.69797 .71622 Mdot
.51404 .73593 Mdot
.77829 .4981 Mdot
.60047 .64953 Mdot
.74862 .42682 Mdot
.48816 .57773 Mdot
.66535 .31287 Mdot
.59971 .5202 Mdot
.74823 .42108 Mdot
.63291 .57196 Mdot
.42654 .16513 Mdot
.87016 .47472 Mdot
.21156 .34383 Mdot
.81254 .61314 Mdot
.41388 .46303 Mdot
.51869 .43789 Mdot
.82181 .40972 Mdot
.39937 .16483 Mdot
.71252 .24622 Mdot
.30151 .67441 Mdot
.67981 .67759 Mdot
.3206 .5955 Mdot
.21213 .35072 Mdot
.73048 .69833 Mdot
.72405 .28688 Mdot
.18324 .53504 Mdot
.40684 .59776 Mdot
.28167 .69956 Mdot
.22573 .35339 Mdot
.53487 .21976 Mdot
.35356 .27557 Mdot
.61854 .39094 Mdot
.46413 .21974 Mdot
.37296 .39409 Mdot
.3543 .72363 Mdot
.73907 .4934 Mdot
.56169 .65464 Mdot
.66744 .42981 Mdot
.58783 .29743 Mdot
.60536 .37598 Mdot
.51027 .67888 Mdot
.40041 .43391 Mdot
.26145 .3533 Mdot
.30529 .60878 Mdot
.54291 .14779 Mdot
.39485 .71365 Mdot
.54582 .30645 Mdot
.73224 .51809 Mdot
.55809 .74936 Mdot
.26517 .64683 Mdot
.34182 .56025 Mdot
.59181 .193 Mdot
.39912 .50575 Mdot
.71741 .51052 Mdot
.44743 .21976 Mdot
.76898 .40271 Mdot
.4918 .37411 Mdot
.28604 .53385 Mdot
.51212 .28416 Mdot
.52187 .53483 Mdot
.30253 .39816 Mdot
.40613 .42087 Mdot
.84549 .62424 Mdot
.40789 .65334 Mdot
.43352 .76893 Mdot
.6022 .19955 Mdot
.38445 .57835 Mdot
.31578 .44689 Mdot
.73421 .4078 Mdot
.79437 .45507 Mdot
.48477 .29665 Mdot
.57125 .68704 Mdot
.63241 .62614 Mdot
.66593 .74665 Mdot
.55055 .18316 Mdot
.50572 .18267 Mdot
.33754 .792 Mdot
.339 .45888 Mdot
.75515 .37566 Mdot
.79191 .47263 Mdot
.31427 .43092 Mdot
.28865 .39507 Mdot
.24672 .42875 Mdot
.48703 .14449 Mdot
.26033 .61103 Mdot
.80382 .61436 Mdot
.63541 .52998 Mdot
.69714 .65397 Mdot
.57832 .74163 Mdot
.77944 .55394 Mdot
.609 .20351 Mdot
.36827 .24977 Mdot
.5176 .20788 Mdot
.54381 .31176 Mdot
.27792 .36426 Mdot
.20288 .36024 Mdot
.46506 .55826 Mdot
.50894 .24144 Mdot
.31337 .54554 Mdot
.57359 .43316 Mdot
.30519 .21478 Mdot
.80758 .44132 Mdot
.23778 .63133 Mdot
.36554 .54174 Mdot
.55163 .42291 Mdot
.55745 .45664 Mdot
.51673 .48692 Mdot
.26324 .53573 Mdot
.25095 .30729 Mdot
.78193 .55407 Mdot
.4401 .4635 Mdot
.42814 .22579 Mdot
.41024 .70378 Mdot
.64979 .23496 Mdot
.79914 .39766 Mdot
.51155 .55523 Mdot
.39974 .69875 Mdot
.60577 .54499 Mdot
.81703 .59082 Mdot
.51909 .59234 Mdot
.65953 .35063 Mdot
.21334 .45884 Mdot
.2689 .56791 Mdot
.5685 .75112 Mdot
.50517 .39144 Mdot
.31614 .7045 Mdot
.68395 .25713 Mdot
.37152 .83261 Mdot
.35096 .76911 Mdot
.33537 .18613 Mdot
.5557 .25472 Mdot
.26723 .57768 Mdot
.48528 .19498 Mdot
.35854 .83417 Mdot
.51264 .60695 Mdot
.44538 .18099 Mdot
.60492 .55347 Mdot
.57756 .18819 Mdot
.36365 .54639 Mdot
.22451 .56057 Mdot
.24336 .33712 Mdot
.49845 .14706 Mdot
.70545 .30981 Mdot
.6222 .21539 Mdot
.60075 .48955 Mdot
.45756 .14601 Mdot
.21245 .44666 Mdot
.4963 .64178 Mdot
.53334 .6121 Mdot
.2983 .65936 Mdot
.38375 .21966 Mdot
.33754 .50042 Mdot
.76994 .45706 Mdot
.48924 .6795 Mdot
.53214 .29192 Mdot
.49118 .20603 Mdot
.69418 .4299 Mdot
.27923 .57363 Mdot
.72963 .51935 Mdot
.70626 .26391 Mdot
.50311 .68464 Mdot
.58937 .73108 Mdot
.41341 .74244 Mdot
.78235 .61778 Mdot
.26221 .5302 Mdot
.40065 .66215 Mdot
.71626 .30545 Mdot
.72844 .68699 Mdot
.77217 .5237 Mdot
.88798 .57471 Mdot
.79463 .56226 Mdot
.25901 .41953 Mdot
.38257 .19357 Mdot
.78983 .37441 Mdot
.25635 .38633 Mdot
.32839 .77103 Mdot
.28925 .3591 Mdot
.73531 .44826 Mdot
.54113 .36227 Mdot
.41925 .14507 Mdot
.69778 .46427 Mdot
.39392 .18267 Mdot
.83664 .4504 Mdot
.46402 .2162 Mdot
.60995 .38871 Mdot
.5291 .68429 Mdot
.44294 .6013 Mdot
.69647 .4174 Mdot
.53129 .20518 Mdot
.29552 .35455 Mdot
.52987 .70671 Mdot
.49212 .75214 Mdot
.55739 .68921 Mdot
.44635 .44375 Mdot
.38549 .6974 Mdot
.27266 .55102 Mdot
.74131 .57945 Mdot
.52641 .56548 Mdot
.75748 .47263 Mdot
.3844 .25087 Mdot
.54238 .22338 Mdot
.41839 .81004 Mdot
.34189 .52452 Mdot
.56622 .61495 Mdot
.59604 .23542 Mdot
.80433 .55391 Mdot
.29166 .57021 Mdot
.31118 .24235 Mdot
.27579 .65702 Mdot
.71031 .37853 Mdot
.68404 .31829 Mdot
.37642 .79624 Mdot
.69838 .76737 Mdot
.35035 .22752 Mdot
.26475 .37126 Mdot
.72623 .55024 Mdot
.61207 .30344 Mdot
.55796 .16105 Mdot
.78397 .51545 Mdot
.66977 .30414 Mdot
.45017 .55114 Mdot
.45647 .3085 Mdot
.45015 .21087 Mdot
.66047 .46209 Mdot
.55995 .53413 Mdot
.14922 .50974 Mdot
.34502 .46903 Mdot
.29021 .22315 Mdot
.34274 .57829 Mdot
.2188 .64809 Mdot
.6403 .58015 Mdot
.48732 .56791 Mdot
.56599 .5265 Mdot
.28506 .52626 Mdot
.22963 .46323 Mdot
.82041 .55854 Mdot
.42219 .82258 Mdot
.53279 .67901 Mdot
.75983 .5571 Mdot
.77568 .64376 Mdot
.58728 .22251 Mdot
.55116 .33019 Mdot
.79509 .57568 Mdot
.46359 .5531 Mdot
.56875 .76782 Mdot
.82114 .41933 Mdot
.32725 .51847 Mdot
.48223 .37458 Mdot
.74748 .48308 Mdot
.44175 .18357 Mdot
.67743 .22431 Mdot
.27783 .7197 Mdot
.41336 .45754 Mdot
.32287 .57591 Mdot
.65238 .41646 Mdot
.55781 .19345 Mdot
.69424 .53624 Mdot
.23902 .56887 Mdot
.76686 .48932 Mdot
.20192 .31624 Mdot
.26535 .28834 Mdot
.25004 .30919 Mdot
.7314 .53101 Mdot
.29295 .42093 Mdot
.2299 .40908 Mdot
.67316 .30939 Mdot
.31215 .52055 Mdot
.81269 .5233 Mdot
.76418 .45792 Mdot
.28689 .77018 Mdot
.55084 .2796 Mdot
.7228 .66221 Mdot
.42269 .21248 Mdot
.42104 .36113 Mdot
.34726 .54666 Mdot
.72405 .44492 Mdot
.38383 .49245 Mdot
.33399 .61179 Mdot
.27867 .56625 Mdot
.23709 .53226 Mdot
.66778 .30186 Mdot
.49833 .28017 Mdot
.42358 .46111 Mdot
.62575 .24979 Mdot
.30975 .45777 Mdot
.59121 .74381 Mdot
.57353 .73657 Mdot
.47447 .4945 Mdot
.56266 .67065 Mdot
.472 .36053 Mdot
.52844 .54296 Mdot
.58585 .54679 Mdot
.19607 .4023 Mdot
.69876 .61643 Mdot
.30616 .44519 Mdot
.21313 .61844 Mdot
.31176 .42676 Mdot
.37923 .16351 Mdot
.52177 .78993 Mdot
.44711 .22201 Mdot
.65548 .73858 Mdot
.61277 .79409 Mdot
.16411 .616 Mdot
.29197 .29378 Mdot
.43508 .53962 Mdot
.29894 .4635 Mdot
.388 .43558 Mdot
.57548 .69354 Mdot
.49658 .74671 Mdot
.36194 .27734 Mdot
.42221 .6877 Mdot
.70058 .36281 Mdot
.34201 .37736 Mdot
.72462 .64927 Mdot
.45058 .37822 Mdot
.5037 .14312 Mdot
.56684 .62057 Mdot
.15366 .42674 Mdot
.53646 .46151 Mdot
.60432 .26505 Mdot
.81894 .39322 Mdot
.2753 .70701 Mdot
.52278 .76001 Mdot
.73535 .72428 Mdot
.59831 .39559 Mdot
.42521 .45713 Mdot
.36333 .43019 Mdot
.73573 .37051 Mdot
.68274 .6037 Mdot
.68313 .5079 Mdot
.388 .61634 Mdot
.46017 .79917 Mdot
.3803 .70348 Mdot
.30052 .41163 Mdot
.36595 .49516 Mdot
.70681 .32181 Mdot
.215 .52566 Mdot
.46371 .55044 Mdot
.58001 .22363 Mdot
.48358 .29346 Mdot
.34753 .37739 Mdot
.30015 .25814 Mdot
.78992 .47909 Mdot
.63969 .18951 Mdot
.63073 .37964 Mdot
.45621 .58392 Mdot
.20611 .52492 Mdot
.2858 .5492 Mdot
.37178 .26191 Mdot
.77768 .35207 Mdot
.72348 .50348 Mdot
.21906 .5749 Mdot
.74539 .41912 Mdot
.58558 .46025 Mdot
.50112 .59465 Mdot
.33704 .69885 Mdot
.24977 .72835 Mdot
.29558 .31856 Mdot
.31085 .73449 Mdot
.27974 .44417 Mdot
.40964 .70069 Mdot
.32928 .46789 Mdot
.61754 .69676 Mdot
.47872 .28841 Mdot
.49031 .7711 Mdot
.59199 .16745 Mdot
.78418 .35842 Mdot
.39885 .624 Mdot
.60953 .61192 Mdot
.55549 .5113 Mdot
.57374 .31278 Mdot
.49295 .51872 Mdot
.59284 .41642 Mdot
.46962 .45654 Mdot
.26392 .69273 Mdot
.30183 .52686 Mdot
.61617 .42593 Mdot
.54639 .16462 Mdot
.6489 .19438 Mdot
.44777 .15123 Mdot
.72106 .55314 Mdot
.32482 .39587 Mdot
.3127 .22657 Mdot
.41153 .25683 Mdot
.70477 .25962 Mdot
.3386 .24029 Mdot
.85669 .60226 Mdot
.5286 .20803 Mdot
.30395 .56276 Mdot
.45369 .8152 Mdot
.2392 .47737 Mdot
.82097 .43894 Mdot
.49632 .64849 Mdot
.58866 .69236 Mdot
.82532 .44693 Mdot
.14748 .62159 Mdot
.28438 .31648 Mdot
.23856 .54464 Mdot
.63273 .31173 Mdot
.45458 .48237 Mdot
.43995 .6734 Mdot
.52196 .35938 Mdot
.5786 .60125 Mdot
.53747 .7651 Mdot
.76174 .47063 Mdot
.59669 .28012 Mdot
.43964 .67745 Mdot
.69785 .41044 Mdot
.73016 .37819 Mdot
.78804 .54044 Mdot
.54944 .21647 Mdot
.36821 .27244 Mdot
.48522 .36638 Mdot
.29508 .4407 Mdot
.69636 .57155 Mdot
.53746 .7268 Mdot
.55868 .35074 Mdot
.51064 .75866 Mdot
.21672 .48593 Mdot
.33612 .1893 Mdot
.60152 .69951 Mdot
.79924 .44612 Mdot
.37338 .46695 Mdot
.27134 .53573 Mdot
.65799 .25889 Mdot
.30234 .69871 Mdot
.44775 .68118 Mdot
.41517 .38518 Mdot
.5352 .17277 Mdot
.2694 .63451 Mdot
.77697 .43342 Mdot
.18131 .4604 Mdot
.34735 .61681 Mdot
.27678 .34864 Mdot
.65167 .32678 Mdot
.2851 .6708 Mdot
.33339 .37458 Mdot
.29674 .60286 Mdot
.46859 .62101 Mdot
.27869 .64065 Mdot
.82977 .49227 Mdot
.73722 .35868 Mdot
.40122 .22075 Mdot
.51356 .18075 Mdot
.56462 .60432 Mdot
.77572 .45706 Mdot
.3005 .60789 Mdot
.45612 .65332 Mdot
.20318 .53645 Mdot
.54291 .1531 Mdot
.51335 .52438 Mdot
.68507 .46876 Mdot
.5641 .43318 Mdot
.43594 .26894 Mdot
.29483 .52261 Mdot
.61275 .57843 Mdot
.41967 .75984 Mdot
.37668 .4062 Mdot
.37687 .72201 Mdot
.49977 .70001 Mdot
.72511 .45884 Mdot
.34384 .48583 Mdot
.32269 .36067 Mdot
.64223 .602 Mdot
.50716 .7063 Mdot
.51537 .33829 Mdot
.67844 .48286 Mdot
.68324 .54743 Mdot
.28003 .33744 Mdot
.27708 .31734 Mdot
.58598 .2259 Mdot
.80422 .47258 Mdot
.29961 .55024 Mdot
.33641 .24003 Mdot
.23388 .45771 Mdot
.51118 .25862 Mdot
.35307 .74221 Mdot
.56062 .44864 Mdot
.62121 .69349 Mdot
.30671 .43905 Mdot
.56282 .20291 Mdot
.54774 .26056 Mdot
.67133 .45593 Mdot
.48577 .54381 Mdot
.67368 .26989 Mdot
.44957 .52125 Mdot
.81991 .40017 Mdot
.24097 .47619 Mdot
.73734 .49358 Mdot
.39992 .57783 Mdot
.61427 .55376 Mdot
.36695 .78488 Mdot
.63127 .19662 Mdot
.42642 .81295 Mdot
.60155 .50164 Mdot
.30117 .72338 Mdot
.24594 .3868 Mdot
.83154 .44607 Mdot
.73581 .47699 Mdot
.48974 .51807 Mdot
.44653 .38523 Mdot
.3662 .63865 Mdot
.49253 .71378 Mdot
.63361 .69298 Mdot
.38639 .26825 Mdot
.65526 .64661 Mdot
.49969 .77269 Mdot
.52648 .32808 Mdot
.19053 .48103 Mdot
.52189 .17724 Mdot
.50971 .30192 Mdot
.4775 .56885 Mdot
.61002 .74931 Mdot
.71797 .46794 Mdot
.7388 .77496 Mdot
.30437 .21446 Mdot
.56125 .43432 Mdot
.59344 .52664 Mdot
.69206 .50046 Mdot
.56301 .67944 Mdot
.36275 .28747 Mdot
.58002 .21959 Mdot
.3578 .55997 Mdot
.66805 .68516 Mdot
.29741 .64936 Mdot
.28531 .51752 Mdot
.66025 .44965 Mdot
.41576 .57801 Mdot
.35946 .17223 Mdot
.80935 .55867 Mdot
.29405 .53972 Mdot
.79481 .70705 Mdot
.31822 .69307 Mdot
.40073 .45122 Mdot
.69952 .29727 Mdot
.42968 .16333 Mdot
.71748 .5258 Mdot
.62936 .72813 Mdot
.26598 .32417 Mdot
.7311 .49634 Mdot
.74743 .40033 Mdot
.4126 .74142 Mdot
.38502 .72878 Mdot
.48742 .62555 Mdot
.61557 .79254 Mdot
.20747 .4041 Mdot
.39509 .23478 Mdot
.48308 .17618 Mdot
.50086 .78463 Mdot
.30065 .7823 Mdot
.63334 .19142 Mdot
.71982 .42331 Mdot
.43354 .69234 Mdot
.71713 .3123 Mdot
.65025 .51514 Mdot
.40933 .3837 Mdot
.51876 .78609 Mdot
.46712 .31577 Mdot
.59063 .7962 Mdot
.37683 .76484 Mdot
.74823 .42426 Mdot
.40811 .36606 Mdot
.52503 .52584 Mdot
.57816 .23046 Mdot
.45687 .76812 Mdot
.74602 .52084 Mdot
.67029 .69345 Mdot
.64027 .50071 Mdot
.60382 .23258 Mdot
.70423 .28547 Mdot
.49334 .51408 Mdot
.14741 .61372 Mdot
.40603 .18475 Mdot
.3184 .7166 Mdot
.53066 .44718 Mdot
.58471 .16004 Mdot
.46232 .49619 Mdot
.32055 .25279 Mdot
.82052 .48744 Mdot
.57448 .7288 Mdot
.20357 .50858 Mdot
.57007 .44519 Mdot
.30102 .27885 Mdot
.50947 .23793 Mdot
.4165 .36062 Mdot
.54452 .76314 Mdot
.73119 .51612 Mdot
.45217 .75468 Mdot
.64654 .47597 Mdot
.60385 .32484 Mdot
.3033 .42185 Mdot
.37599 .1732 Mdot
.63691 .44003 Mdot
.45389 .39739 Mdot
.58592 .48364 Mdot
.42581 .81815 Mdot
.76193 .71966 Mdot
.61098 .33632 Mdot
.2639 .63057 Mdot
.76959 .46058 Mdot
.68964 .33682 Mdot
.28702 .30524 Mdot
.36449 .87536 Mdot
.81249 .37909 Mdot
.38015 .4538 Mdot
.30343 .34322 Mdot
.74539 .53645 Mdot
.4569 .15373 Mdot
.65489 .76437 Mdot
.55874 .74521 Mdot
.43527 .83923 Mdot
.66161 .5211 Mdot
.52071 .35164 Mdot
.8383 .51742 Mdot
.63882 .20045 Mdot
.47133 .79476 Mdot
.56372 .16545 Mdot
.61227 .39288 Mdot
.5348 .45454 Mdot
.53565 .89178 Mdot
.57533 .19672 Mdot
.60488 .36765 Mdot
.39925 .81739 Mdot
.38475 .38336 Mdot
.542 .3545 Mdot
.42547 .66347 Mdot
.78054 .51237 Mdot
.73746 .38805 Mdot
.49681 .14707 Mdot
.30024 .40624 Mdot
.51191 .76024 Mdot
.39562 .5924 Mdot
.5655 .52836 Mdot
.48901 .4252 Mdot
.37825 .60126 Mdot
.71656 .38207 Mdot
.47835 .49969 Mdot
.39576 .56077 Mdot
.77223 .56999 Mdot
.85813 .52153 Mdot
.55396 .24917 Mdot
.39645 .63134 Mdot
.53903 .48565 Mdot
.51385 .29697 Mdot
.69774 .41468 Mdot
.68879 .36997 Mdot
.82809 .46765 Mdot
.85496 .39126 Mdot
.61015 .66122 Mdot
.62154 .42926 Mdot
.36824 .4784 Mdot
.38087 .26322 Mdot
.51925 .21992 Mdot
.35214 .5373 Mdot
.49508 .73935 Mdot
.59672 .42894 Mdot
.60706 .32787 Mdot
.39181 .61434 Mdot
.23962 .27185 Mdot
.50993 .37211 Mdot
.34344 .262 Mdot
.68934 .25037 Mdot
.58792 .74521 Mdot
.58588 .26717 Mdot
.59701 .37264 Mdot
.22527 .4223 Mdot
.45448 .49262 Mdot
.48298 .48464 Mdot
.57823 .73854 Mdot
.47996 .1617 Mdot
.55042 .26118 Mdot
.38556 .23091 Mdot
.53237 .40734 Mdot
.72017 .61011 Mdot
.22954 .53675 Mdot
.27447 .30027 Mdot
.57032 .30253 Mdot
.69844 .24652 Mdot
.58148 .72605 Mdot
.66468 .64333 Mdot
.61461 .28872 Mdot
.38325 .18304 Mdot
.34643 .76078 Mdot
.4955 .217 Mdot
.24568 .64809 Mdot
.35903 .67284 Mdot
.69585 .43119 Mdot
.5318 .68529 Mdot
.61537 .43012 Mdot
.3686 .37678 Mdot
.40453 .14009 Mdot
.26934 .3076 Mdot
.32018 .63432 Mdot
.53441 .70944 Mdot
.47368 .24936 Mdot
.55213 .52383 Mdot
.83096 .65937 Mdot
.71341 .72685 Mdot
.35362 .17478 Mdot
.72754 .35835 Mdot
.42057 .42943 Mdot
.27846 .59073 Mdot
.47369 .41271 Mdot
.54651 .62748 Mdot
.46449 .15626 Mdot
.62477 .35111 Mdot
.37615 .7573 Mdot
.51704 .35602 Mdot
.22326 .61349 Mdot
.41176 .48262 Mdot
.60895 .61712 Mdot
.60264 .63005 Mdot
.33417 .77221 Mdot
.68091 .26113 Mdot
.44839 .49302 Mdot
.82259 .64657 Mdot
.50298 .19278 Mdot
.59404 .19367 Mdot
.56902 .68733 Mdot
.25029 .70311 Mdot
.31444 .48428 Mdot
.39854 .48092 Mdot
.30661 .6074 Mdot
.61849 .49365 Mdot
.28356 .66008 Mdot
.69969 .34816 Mdot
.22887 .50217 Mdot
.39429 .62597 Mdot
.91018 .43724 Mdot
.72503 .41265 Mdot
.53912 .29931 Mdot
.32506 .70955 Mdot
.5734 .17742 Mdot
.67452 .56485 Mdot
.848 .52488 Mdot
.54392 .56664 Mdot
.49882 .43618 Mdot
.50639 .27977 Mdot
.61524 .27872 Mdot
.30347 .658 Mdot
.14861 .55943 Mdot
.80685 .5417 Mdot
.63183 .64055 Mdot
.52277 .56538 Mdot
.31494 .43454 Mdot
.35925 .46305 Mdot
.63703 .7606 Mdot
.84208 .57446 Mdot
.43594 .47287 Mdot
.56059 .19373 Mdot
.18539 .64581 Mdot
.75709 .39438 Mdot
.46684 .14957 Mdot
.29958 .47697 Mdot
.28387 .40436 Mdot
.69972 .40469 Mdot
.73444 .60524 Mdot
.59713 .64737 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0W_ooool2o`000:Wooooo000Looooo`03o`000?oooooooooo09kooooo0_l0
002Yooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0;[ooooo0_l0002=ooooo`007?ooool00ol0003o
ooooooooo`2jooooo`?o0000S?ooool001cooooo00?o0000ooooooooool0^oooool3o`0008_ooooo
000Looooo`03o`000?oooooooooo0;cooooo0_l0002;ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2;ooooo`;o0000_?ooool001cooooo00?o
0000ooooooooool0O_ooool2o`0000?ooooo0_l00006ooooo`;o00002_ooool2o`000;3ooooo000L
ooooo`03o`000?oooooooooo07kooooo1?l000000ooooooo0000o`00000Booooo`;o0000/?ooool0
01cooooo00?o0000ooooooooool0P?ooool2o`0001Sooooo0_l00004ooooo`;o0000Yoooool001co
oooo00?o0000ooooooooool0Q?ooool2o`0000_ooooo0_l00007ooooo`;o00000_ooool4o`000:Oo
oooo000Looooo`03o`000?oooooooooo08Cooooo0_l0000;ooooo`;o000000?oooooo`000?l00000
2?ooool2o`0000cooooo0ol0002Jooooo`007?ooool2o`0008oooooo0_l000001?oooooo0000o`00
0?ooool2o`0001Kooooo0ol0000Nooooo`;o0000N_ooool001cooooo00?o0000ooooooooool0S_oo
ool2o`000003ooooool0003o000000;o00002Oooool2o`000003ooooool0003o000000[ooooo0_l0
000Nooooo`;o0000N_ooool001cooooo00?o0000ooooooooool0K?ooool2o`0000_ooooo0_l0000H
ooooo`;o00000_ooool2o`0000Gooooo0_l000000ooooooo0000o`00002Vooooo`007?ooool00ol0
003oooooooooo`1/ooooo`;o00002oooool2o`0001cooooo0ol0000;ooooo`;o00001?ooool2o`00
00Cooooo1?l00005ooooo`;o00003?ooool2o`0007oooooo000Looooo`03o`000?oooooooooo07Oo
oooo0_l00005ooooo`;o00001oooool3o`0000kooooo0_l00003ooooo`;o00001_ooool8o`000004
ooooool0003o0000ooooo`Co000000?oooooo`000?l000000_ooool2o`0000cooooo0_l0001ooooo
o`007?ooool00ol0003oooooooooo`1gooooo`;o00001Oooool2o`0000?ooooo0_l00002ooooo`?o
00003?ooool2o`0000Gooooo0_l00008ooooo`Go00000_ooool2o`0000?ooooo0_l000000ooooooo
0000o`000005ooooo`;o00005?ooool2o`0007Cooooo000Looooo`03o`000?oooooooooo077ooooo
0_l0000;ooooo`;o00000oooool2o`0000Kooooo0_l00004ooooo`;o00000oooool2o`0000kooooo
0_l00002ooooo`;o00001_ooool2o`0000Wooooo0_l0000Dooooo`;o0000M?ooool001cooooo00?o
0000ooooooooool0Koooool4o`0000?ooooo0_l00006ooooo`;o00002oooool2o`0000Cooooo0_l0
000Cooooo`;o00000_ooool2o`0000Kooooo0_l0000Tooooo`;o0000Koooool001cooooo00?o0000
ooooooooool0Koooool2o`0000Gooooo0_l00003ooooo`;o00007?ooool2o`0000_ooooo0_l00002
ooooo`;o00001?ooool2o`0000Cooooo0_l00005ooooo`;o00006Oooool2o`000003ooooool0003o
000006cooooo000Looooo`03o`000?oooooooooo07_ooooo0_l00004ooooo`;o00002_ooool2o`00
00Gooooo0_l00003ooooo`;o00002?ooool2o`000003ooooool0003o000000Kooooo1_l00002oooo
o`;o00001Oooool2o`0001Wooooo0_l000000ooooooo0000o`000003ooooo`;o0000Ioooool001co
oooo00?o0000ooooooooool0K_ooool2o`000003ooooool0003o000000Kooooo0_l000000ooooooo
0000o`000003ooooo`;o00002Oooool3o`0000Gooooo0_l0000;ooooo`Co00002Oooool3o`000003
ooooool0003o000002cooooo0_l0001Wooooo`007?ooool00ol0003oooooooooo`1Xooooo`?o0000
0oooool2o`000003ooooool0003o000000Kooooo0_l000000ooooooo0000o`000002ooooo`;o0000
2_ooool2o`0000_ooooo0_l00006ooooo`;o00003?ooool4o`00017ooooo0_l00023ooooo`007?oo
ool00ol0003oooooooooo`1Xooooo`?o00004Oooool2o`0000;ooooo0_l0000Gooooo`;o00005_oo
ool2o`0000Gooooo0_l000000ooooooo0000o`000007ooooo`;o00001_ooool2o`0007_ooooo0000
1_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003ooooo
ooooo`1Yooooo`;o00003_ooool2o`0002Gooooo0_l00002ooooo`;o00002oooool3o`0000Cooooo
0_l000000ooooooo0000o`000002o`0000Wooooo1_l0000Booooo`;o0000Ioooool00006oooooomg
MgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006oooo
o`03o`000?oooooooooo07Wooooo0_l00003ooooo`;o00002Oooool2o`0000kooooo0ol00004oooo
o`;o00000_ooool2o`0000_ooooo0ol00003ooooo`;o00000oooool3o`0000Wooooo1?l00003oooo
o`;o00003oooool2o`0006Oooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[o
oooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`1nooooo`;o00002Oooool2o`0000Ko
oooo1?l00004ooooo`?o00006oooool2o`0000Oooooo0_l00007ooooo`;o00001?ooool2o`0000Co
oooo0_l0001booooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRH
V?lQ8B7ok^k^00Kooooo0ol0001^ooooo`;o00001_ooool2o`0001Wooooo1?l00002ooooo`;o0000
6_ooool2o`0000_ooooo0_l00002ooooo`;o00001_ooool2o`0000Oooooo0_l0001booooo`0000?o
ooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00Gooooo00?o
0000ooooooooool0K_ooool2o`0000Gooooo0ol00008ooooo`;o00000_ooool5o`0000kooooo0_l0
0003ooooo`;o00002oooool2o`0000Sooooo0_l0000=ooooo`Co00001_ooool2o`0007_ooooo0000
0ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1Rooooo`;o00002Oooool2o`0000Kooooo0_l00009ooooo`;o00000_ooool5
o`0001?ooooo0_l00006ooooo`;o00000_ooool3o`0000;ooooo0_l0000Cooooo`;o00001?ooool2
o`0007oooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RH
oa0@4006ooooo`03o`000?oooooooooo06;ooooo0_l00009ooooo`;o00003_ooool2o`0000oooooo
0_l0000Booooo`Co00000_ooool2o`0000?ooooo0_l0000Iooooo`;o000000?oooooo`000?l00000
1_ooool2o`0001Kooooo0_l0001Looooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Oooooo`;o00004oooool2o`00
00Oooooo0_l00007ooooo`?o00001Oooool2o`0001;ooooo0_l0000Rooooo`;o00000oooool5o`00
00?ooooo0_l0000Fooooo`;o0000G?ooool001cooooo00?o0000ooooooooool0Goooool2o`0000So
oooo0_l00009ooooo`;o00004?ooool3o`0000[ooooo0_l00008ooooo`;o00004?ooool2o`0000_o
oooo0_l00008ooooo`;o000000?oooooo`000?l000000_ooool4o`0000Sooooo0_l0001^ooooo`00
7?ooool00ol0003oooooooooo`1Nooooo`?o00002?ooool2o`0000kooooo0_l00004ooooo`;o0000
3Oooool2o`0000?ooooo0ol00007ooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o0000
0oooool2o`0000Oooooo0ol000001?oooooo0000o`000?l0000:ooooo`;o00000oooool3o`0000So
oooo0_l0001^ooooo`007?ooool00ol0003oooooooooo`1Kooooo`;o000000?oooooo`000?l00000
1oooool3o`0000Oooooo0_l00006ooooo`;o00000oooool3o`0000cooooo0ol00003ooooo`?o0000
2oooool2o`0000;ooooo0_l00003ooooo`Co00002_ooool7o`0000oooooo1?l00006ooooo`;o0000
Koooool001cooooo00?o0000ooooooooool0Foooool2o`0000Gooooo0_l00003ooooo`?o00001?oo
ool2o`000003ooooool0003o000000_ooooo0_l00007ooooo`;o000000Coooooo`000?l0003ooooo
0_l00004ooooo`?o00000oooool4o`0000Kooooo0_l00007ooooo`;o00001?ooool2o`0000Gooooo
1Ol0000Booooo`;o00001?ooool4o`0000Gooooo0_l0001Xooooo`007?ooool00ol0003ooooooooo
o`1Rooooo`;o00002Oooool3o`0001Cooooo0_l000000ooooooo0000o`000003o`0000Sooooo0_l0
0003ooooo`Co00001_ooool2o`0000Cooooo0_l00007ooooo`;o00001?ooool2o`000004ooooool0
003o0000o`00017ooooo0_l00005ooooo`;o00001oooool2o`0006Sooooo000Looooo`03o`000?oo
oooooooo06Wooooo0_l00002ooooo`Co00002Oooool2o`0000Sooooo0_l00003ooooo`;o00001_oo
ool2o`0001Kooooo0_l0000=ooooo`;o00001_ooool2o`0000gooooo0ol0000<ooooo`;o0000JOoo
ool001cooooo00?o0000ooooooooool0JOooool2o`0000Cooooo0_l00009ooooo`;o000000?ooooo
o`000?l000000_l00003ooooo`;o00002Oooool8o`00017ooooo0_l00004ooooo`;o00000_ooool2
o`0000[ooooo1?l0000=ooooo`?o00003?ooool2o`0006Wooooo000Looooo`03o`000?oooooooooo
06[ooooo0_l00009ooooo`;o00001_ooool5o`0000;ooooo0_l00009ooooo`;o00000_ooool4o`00
00_ooooo0_l00004ooooo`;o00001?ooool2o`0000;ooooo0_l0000:ooooo`;o00003oooool3o`00
00;ooooo1?l0001aooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o000000?oooooo`000?l0
00000_ooool2o`0000?ooooo1?l00007ooooo`;o00001oooool4o`0001Wooooo0_l00005ooooo`;o
00007?ooool2o`0000cooooo0_l00004ooooo`Co0000LOooool001cooooo00?o0000ooooooooool0
G_ooool2o`000003ooooool0003o000000;ooooo1?l000000ooooooo0000o`000002o`00013ooooo
0ol0000<ooooo`;o00000oooool4o`0000Gooooo0_l00005ooooo`?o00002Oooool2o`00013ooooo
0_l00004ooooo`;o00001_ooool2o`0001Cooooo0_l0001Sooooo`007?ooool00ol0003ooooooooo
o`1Wooooo`;o00003_ooool2o`0000Kooooo1Ol00005ooooo`;o00000_ooool2o`0000?ooooo1?l0
0005ooooo`;o00001_ooool2o`0000?ooooo0_l00004ooooo`Co00005?ooool2o`0000?ooooo0ol0
000;ooooo`;o00001?ooool2o`0000?ooooo0_l0001Sooooo`007?ooool2o`0007Gooooo0_l00000
0ooooooo0000o`000003o`0000?ooooo1Ol00005ooooo`;o00001Oooool2o`0000Cooooo0_l00009
ooooo`;o00001Oooool2o`0000Kooooo0_l0000Eooooo`;o00000_ooool3o`0000_ooooo0_l00000
1?oooooo0000o`000?ooool2o`0006Sooooo000Looooo`03o`000?oooooooooo06Cooooo0_l0000>
ooooo`;o000000?oooooo`000?l000000ol00003ooooo`;o00003oooool2o`0000Cooooo0_l00009
ooooo`;o00001oooool2o`0000Gooooo0_l0000Dooooo`;o00000oooool2o`0000kooooo0_l0001[
ooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o00001?ooool2o`0000kooooo0_l000000ooo
oooo0000o`000009ooooo`;o00000_ooool2o`0000Wooooo0_l0000Gooooo`;o00001Oooool4o`00
00Oooooo0_l0000Looooo`;o00007oooool2o`0004cooooo000Looooo`03o`000?oooooooooo05ko
oooo0_l0000Dooooo`;o00000_ooool2o`0000Sooooo0_l00002ooooo`;o00002Oooool2o`0000Ko
oooo1?l00005ooooo`;o00001_ooool2o`0000;ooooo0ol000001?oooooo0000o`000?l00004oooo
o`;o000000?oooooo`000?l000003Oooool2o`0000Gooooo0_l00005ooooo`?o000000?oooooo`00
0?l000000_ooool2o`0000?ooooo0_l0000Cooooo`;o0000C?ooool001cooooo00?o0000oooooooo
ool0K?ooool2o`0000Oooooo0_l000001?oooooo0000o`000?ooool2o`0001[ooooo2?l00003oooo
o`;o00002_ooool3o`000003ooooool0003o000000Gooooo0_l00007ooooo`;o00001_ooool5o`00
00?ooooo0_l00004ooooo`?o00000_ooool3o`000003ooooool0003o000000;o000000Coooooo`00
0?l0003o0000H?ooool001cooooo00?o0000ooooooooool0F?ooool2o`0001;ooooo0_l00005oooo
o`Co000000Coooooo`000?l0003ooooo0_l0000<ooooo`;o00001oooool2o`0000?ooooo0_l00004
ooooo`;o00003oooool2o`0000_ooooo0_l00004ooooo`?o00001_ooool2o`000003ooooool0003o
000000Wooooo0_l00004ooooo`;o00000_ooool3o`0000;ooooo0ol0001Oooooo`007?ooool00ol0
003oooooooooo`1Hooooo`;o00001oooool2o`00013ooooo0_l00005ooooo`;o00003Oooool3o`00
00Kooooo0_l0000;ooooo`;o00006_ooool2o`0000Cooooo0_l0000Dooooo`;o00002_ooool2o`00
00?ooooo0_l0001Oooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o00005Oooool3o`00013o
oooo0_l00003ooooo`?o00000oooool2o`0000Sooooo1Ol0000Aooooo`;o00006oooool2o`0000Co
oooo0_l0000Cooooo`;o00000_ooool2o`0000Gooooo0_l0001Uooooo`007?ooool00ol0003ooooo
ooooo`1:ooooo`;o00004oooool2o`000003ooooool0003o000000_ooooo0_l00003ooooo`;o0000
0oooool4o`0000;ooooo0_l0000:ooooo`?o0000;_ooool2o`0000Cooooo0_l0000Cooooo`;o0000
0_ooool2o`0000Gooooo0_l0001Uooooo`007?ooool00ol0003oooooooooo`1Nooooo`?o00003_oo
ool2o`000003ooooool0003o000000Oooooo0_l0000Tooooo`;o00003?ooool2o`0000[ooooo0_l0
00000ooooooo0000o`000004ooooo`;o00004Oooool2o`0000Sooooo0_l0001Vooooo`007?ooool0
0ol0003oooooooooo`1Nooooo`;o00004_ooool2o`0000Cooooo0_l0000Nooooo`;o00001?ooool2
o`000003ooooool0003o000000cooooo0_l000000ooooooo0000o`000007ooooo`Go00001?ooool2
o`0001;ooooo0_l00007ooooo`Co000000Coooooo`000?l0003ooooo0_l0001Nooooo`007?ooool0
0ol0003oooooooooo`1hooooo`;o00000oooool2o`0000Cooooo0_l0000Cooooo`;o00001?ooool2
o`0000?ooooo0_l00007ooooo`;o00001?ooool2o`0000Kooooo0_l000000ooooooo0000o`00000I
ooooo`;o00001oooool4o`000004ooooool0003o0000ooooo`;o0000G_ooool001cooooo00?o0000
ooooooooool0D_ooool2o`0000Sooooo0_l0000Dooooo`;o00002Oooool2o`0000Cooooo0_l0000C
ooooo`;o00000_ooool2o`0000Gooooo0_l00007ooooo`;o00000_ooool2o`0000Sooooo0_l00008
ooooo`;o00003_ooool2o`0000Cooooo0_l00005ooooo`Co00000_ooool2o`0000Kooooo0_l0001H
ooooo`007?ooool00ol0003oooooooooo`1Booooo`;o00001_ooool4o`0001Cooooo0_l0000Soooo
o`?o00000_ooool2o`0000_ooooo0_l00003ooooo`Co00004_ooool2o`0000kooooo0_l00004oooo
o`;o00002oooool2o`0000?ooooo0_l000000ooooooo0000o`00001Hooooo`007?ooool00ol0003o
ooooooooo`1Jooooo`?o00001oooool2o`00037ooooo1?l0000>ooooo`;o00000oooool2o`0003co
oooo1?l0000Fooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0Foooool2o`0000Kooooo
0ol0000cooooo`?o00001oooool2o`0000Sooooo0_l0000<ooooo`;o00002Oooool4o`000003oooo
ool0003o000001;ooooo0_l0000=ooooo`;o00005_ooool2o`00047ooooo000Looooo`;o0000E_oo
ool3o`0000_ooooo0_l000000ooooooo0000o`00000booooo`;o00001oooool2o`0000Kooooo1?l0
000<ooooo`;o00002Oooool4o`000003ooooool0003o000000kooooo0ol000000ooooooo0000o`00
001Xooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00001_ooool2o`0000Oooooo0ol0000>
ooooo`;o0000>Oooool4o`0000Kooooo0_l00005ooooo`;o000000?oooooo`000?l000001Oooool3
o`0000Cooooo0_l0000=ooooo`;o000000Coooooo`000?l0003o00000oooool3o`0001Cooooo0_l0
001Eooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00001?ooool6o`0000Cooooo0ol00003
ooooo`;o0000AOooool4o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`000003ooooool0003o
000000Gooooo0ol00004ooooo`;o00002?ooool2o`0000?ooooo0_l000001?oooooo0000o`000?l0
0004ooooo`;o00001oooool2o`0000Wooooo1?l0001Eooooo`007?ooool00ol0003oooooooooo`1:
ooooo`;o00000_ooool2o`0000Cooooo0_l00002ooooo`Go0000=?ooool2o`0001Cooooo0_l00005
ooooo`;o00000oooool2o`0001Sooooo0_l00008ooooo`;o00002?ooool2o`0000;ooooo0ol00006
ooooo`Co000000?oooooo`000?l00000E?ooool001cooooo00?o0000ooooooooool0C_ooool2o`00
0003ooooool0003o000000Gooooo0_l000000ooooooo0000o`00000=ooooo`;o00009Oooool2o`00
00Wooooo0_l00005ooooo`;o00002?ooool2o`0000;ooooo1?l00002ooooo`;o00004Oooool2o`00
0003ooooool0003o000000Gooooo1Ol00008ooooo`;o00000_ooool3o`0000Kooooo0_l00003oooo
o`;o0000E?ooool001cooooo00?o0000ooooooooool0?_ooool2o`00017ooooo0_l00006ooooo`Co
00000oooool2o`0000Sooooo0_l0000Xooooo`;o00001_ooool2o`0000Gooooo0_l00003ooooo`Oo
00000_ooool2o`0000Cooooo0_l0000:ooooo`;o00001Oooool2o`0000Kooooo1ol0000<ooooo`;o
00000oooool2o`0000Kooooo0ol0001Dooooo`007?ooool00ol0003oooooooooo`0nooooo`;o0000
4Oooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool6o`0003;ooooo0_l000000ooooooo
0000o`00000=ooooo`So00001_ooool2o`0000;ooooo0_l00009ooooo`;o00003Oooool2o`0000?o
oooo0_l000000ooooooo0000o`00000>ooooo`;o00001_ooool3o`0005Cooooo000Looooo`03o`00
0?oooooooooo05?ooooo0_l000000ooooooo0000o`000004ooooo`Co00003Oooool3o`00023ooooo
0_l00005ooooo`Co00002oooool2o`0000Cooooo0_l00005ooooo`?o000000Coooooo`000?l0003o
00008?ooool2o`0000Kooooo0_l0001Uooooo`007?ooool00ol0003oooooooooo`15ooooo`;o0000
3?ooool2o`0001Sooooo0ol0000Pooooo`;o00001oooool2o`0000Sooooo1?l00004ooooo`Oo0000
00?oooooo`000?l000000_ooool3o`0000Kooooo0_l0000Pooooo`;o0000IOooool001cooooo00?o
0000ooooooooool0A?ooool3o`0000cooooo0_l00014ooooo`;o00000oooool2o`0000?ooooo1ol0
00000ooooooo0000o`000007o`000003ooooool0003o000000;ooooo1_l000001?oooooo0000o`00
0?l0000=ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00000Hooooo`;o
0000E?ooool001cooooo00?o0000ooooooooool0A?ooool2o`0000?ooooo0_l000000ooooooo0000
o`00000Aooooo`;o00002?ooool2o`0000Kooooo0_l0000Qooooo`;o00000oooool2o`000003oooo
ool0003o000000;o000000?oooooo`000?l000001?ooool6o`000003ooooool0003o000000Co0000
00?oooooo`000?l000000_ooool:o`0000gooooo0_l000000ooooooo0000o`000003o`000003oooo
ool0003o000000Cooooo0_l00009ooooo`;o00001oooool2o`0005Cooooo000Looooo`03o`000?oo
oooooooo04Wooooo0_l000000ooooooo0000o`00000Aooooo`;o00002?ooool2o`0000?ooooo0_l0
00000ooooooo0000o`00000Qooooo`;o00001?ooool9o`0000;ooooo0_l00002ooooo`[o00000_oo
ool2o`0000;ooooo0_l00003ooooo`?o00001_ooool2o`0000_ooooo0_l00004ooooo`;o00000ooo
ool2o`0000Oooooo1?l00004ooooo`;o000000?oooooo`000?l00000E?ooool001cooooo00?o0000
ooooooooool0Boooool3o`0000Wooooo1?l00007ooooo`;o00002_ooool2o`0002Kooooo0_l00002
ooooo`;o000000?oooooo`000?l000000ol00002ooooo`?o00000oooool2o`000003ooooool0003o
000000;o000000?oooooo`000?l000001?ooool3o`0000?ooooo0_l00003ooooo`;o00000_ooool2
o`00017ooooo1?l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l00006ooooo`;o00001Ooo
ool3o`0004oooooo000Looooo`03o`000?oooooooooo04_ooooo0_l00005ooooo`;o00000oooool6
o`0000;ooooo0_l000000ooooooo0000o`00000aooooo`Co00001?ooool5o`0000;ooooo1?l00000
0ooooooo0000o`000002ooooo`Oo00000_ooool6o`0000Oooooo0_l00006ooooo`;o00003oooool2
o`0000Cooooo0_l000000ooooooo0000o`000007ooooo`;o00000_ooool3o`0000;ooooo0ol0001?
ooooo`007?ooool00ol0003oooooooooo`11ooooo`;o00001oooool2o`0000Kooooo0_l00005oooo
o`Co00000_ooool2o`0003Cooooo1_l00003ooooo`;o00001?ooool?o`000003ooooool0003o0000
00Ko00001?ooool2o`0000Wooooo0_l0000Fooooo`;o00002Oooool2o`0000;ooooo0ol00003oooo
o`;o0000Coooool001cooooo00?o0000ooooooooool0@Oooool2o`0000Gooooo1?l0000=ooooo`;o
00001?ooool2o`0001;ooooo0_l0000@ooooo`Co00000_ooool2o`0000cooooo0_l000000ooooooo
0000o`000002o`0000Cooooo1Ol000000ooooooo0000o`000004o`000004ooooool0003o0000oooo
o`Ko00001_ooool4o`0000Cooooo0_l0000Iooooo`;o00003Oooool2o`000003ooooool0003o0000
00;ooooo0_l0000Hooooo`;o0000=?ooool001cooooo0_l00012ooooo`?o00001?ooool2o`0000co
oooo0_l0000Kooooo`;o00000_ooool3o`0000;ooooo0_l00007ooooo`Co00000_ooool2o`0000[o
oooo0_l00003ooooo`Co000000?oooooo`000?l000004Ol000000ooooooo0000o`000004o`0000Go
oooo1?l00002ooooo`Co00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`000006ooooo`Co
00000oooool2o`0000oooooo0_l00002ooooo`;o00006?ooool2o`0003Cooooo000Looooo`03o`00
0?oooooooooo047ooooo0ol00002ooooo`;o00000_ooool2o`0000Gooooo0_l00003ooooo`;o0000
7oooool3o`0000;ooooo0_l000001?oooooo0000o`000?l0000Eooooo`;o00000ooooolQo`0000Wo
oooo0ol00003ooooo`;o00001?ooool2o`000003ooooool0003o000000Kooooo1?l00003ooooo`;o
00004_ooool3o`0004kooooo000Looooo`03o`000?oooooooooo03;ooooo0_l0000<ooooo`;o0000
1?ooool2o`0000;ooooo0_l00005ooooo`;o00002Oooool2o`0000oooooo0_l0000@ooooo`?o0000
4oooool2o`0000Gooooo8_l000001?oooooo0000o`000?l00002ooooo`Go00001Oooool2o`0000go
oooo0_l0000Iooooo`Co0000COooool001cooooo00?o0000ooooooooool0<_ooool2o`0000cooooo
0_l0000Hooooo`Co00001?ooool2o`0000Kooooo0_l000000ooooooo0000o`00000<ooooo`;o0000
5oooool3o`0000;ooooo0_l00002oooooa?o000000?oooooo`000?l000005?l00007ooooo`Co0000
2oooool3o`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l000002?ooool2o`0000;ooooo
0ol0001<ooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00001_ooool2o`00013ooooo1?l0
0006ooooo`;o000000?oooooo`000?l000000oooool4o`0000Oooooo0_l00004ooooo`;o000000?o
ooooo`000?l000000_l00002ooooo`?o00002Oooool2o`0000;ooooo1?l000000ooooooo0000o`00
0002oooooa?o000000?oooooo`000?l000003_l000000ooooooo0000o`000004o`000003ooooool0
003o000000Gooooo0ol00009ooooo`Ko000000?oooooo`000?l000001?ooool2o`000003ooooool0
003o000000Sooooo0_l00002ooooo`Go0000B_ooool001cooooo00?o0000ooooooooool0>Oooool2
o`0000?ooooo0_l00005ooooo`?o00000_ooool2o`0000_ooooo0ol00003ooooo`;o00001_ooool2
o`000003ooooool0003o000000Co00000_ooool2o`0000?ooooo1_l00003ooooo`Go000000?ooooo
o`000?l000000_l00008ooooo`;o00000_ooool4o`000003ooooool0003o000000[o00000_oooolJ
o`0000;ooooo1Ol000001?oooooo0000o`000?ooool2o`0000?ooooo0ol00008ooooo`;o00000_oo
ool2o`0000gooooo0_l00009ooooo`;o000000?oooooo`000?l000001?ooool2o`0004Cooooo000L
ooooo`03o`000?oooooooooo03Wooooo0_l0000:ooooo`;o00000oooool2o`0000?ooooo0_l00006
ooooo`?o00000oooool2o`0000Kooooo0_l000001?oooooo0000o`000?l00003ooooo`Co00001Ooo
ool4o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`;o00003?ooool3o`0000;ooooo2ol0
00000ooooooo0000o`00000>o`000003ooooool0003o000000_o00002Oooool2o`0000Cooooo0_l0
000Cooooo`;o00001_ooool2o`0000Cooooo0_l00008ooooo`;o00000_ooool2o`0004Cooooo000L
ooooo`03o`000?oooooooooo03Oooooo0_l0000<ooooo`?o00001oooool2o`000003ooooool0003o
000000Cooooo0_l0000;ooooo`;o00000_ooool3o`0000;ooooo0ol0000=ooooo`;o000000?ooooo
o`000?l000000_l0000@ooooo`Oo00000_oooolUo`0000;ooooo1?l0000Cooooo`;o00002Oooool2
o`000004ooooool0003o0000o`0000Sooooo0_l00006ooooo`Ko00005oooool2o`0002gooooo000L
ooooo`03o`000?oooooooooo03Oooooo0_l0000=ooooo`;o00002_ooool2o`00017ooooo0_l00002
ooooo`?o00000_ooool3o`0000Kooooo0_l00009ooooo`Go00002_ooool2o`000003ooooool0003o
000000Go000000Coooooo`000?l0003ooooo8ol00002ooooo`Go00001_ooool4o`0000Wooooo0_l0
000<ooooo`?o00002?ooool4o`0000Cooooo0_l00002ooooo`;o00005oooool2o`0002gooooo000L
ooooo`03o`000?oooooooooo03gooooo0_l0000=ooooo`;o00003oooool2o`0000Gooooo0_l00000
0ooooooo0000o`000008o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`;o00000_ooool4
o`0000Sooooo1?l000001Ooooooo0000o`000?l0003ooooo00?o000000Coooooo`000?l0003ooooo
4ol000000ooooooo0000o`00000;o`000004ooooool0003o0000ooooo`;o00002Oooool4o`0000Wo
oooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool4o`0000Kooooo0_l00004ooooo`;o
00001?ooool4o`0004Sooooo000Looooo`03o`000?oooooooooo03gooooo0_l0000=ooooo`;o0000
3Oooool4o`0000Cooooo0ol000000ooooooo0000o`000002ooooo`Go00001?ooool2o`0000Wooooo
0_l0000>ooooo`;o00002?ooool2o`000004ooooool0003o0000ooooob7o000000Coooooo`000?l0
003ooooo0_l00003ooooo`;o00000_ooool2o`0000gooooo0_l000000ooooooo0000o`000002oooo
o`;o00000_ooool4o`0000Cooooo1Ol00005ooooo`;o00001?ooool2o`0000?ooooo0_l00013oooo
o`007?ooool00ol0003oooooooooo`1=ooooo`;o00003?ooool2o`0000Kooooo0_l00002ooooo`;o
00000_ooool9o`0000Gooooo0_l00006ooooo`;o00001_ooool4o`0000;ooooo0_l00008ooooo`Co
00000ooooolPo`0000;ooooo1_l000000ooooooo0000o`000002ooooo`Co00005?ooool2o`0000So
oooo0_l000000ooooooo0000o`000005ooooo`;o00002?ooool3o`0004?ooooo000Looooo`03o`00
0?oooooooooo04cooooo0ol000000ooooooo0000o`00000=ooooo`Ko000000?oooooo`000?l00000
0_ooool=o`0000;ooooo1?l00004ooooo`Co00001?ooool8o`0000Sooooo1?l00002oooooako0000
00?oooooo`000?l000002?l00007ooooo`;o00001Oooool2o`0000gooooo0_l00009ooooo`;o0000
4Oooool2o`0004Cooooo000Looooo`03o`000?oooooooooo04[ooooo1?l00002ooooo`;o00003Ooo
ool?o`0000;ooooo1ol00004ooooo`Ko00000_ooool2o`0000Sooooo0_l00005ooooo`;o000000?o
ooooo`000?l000000_l000001?oooooo0000o`000?oooolPo`000003ooooool0003o000000Go0000
3oooool2o`0001Cooooo0_l00002ooooo`;o00003_ooool4o`0004Gooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003o
ooooooooo`1:ooooo`;o00006?ooool?o`000003ooooool0003o000000;o00001Oooool4o`0000Ko
oooo0_l0000;ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`000003ooooool0003o0000
023o000000?oooooo`000?l000001?l0000Tooooo`?o00004Oooool4o`0000;ooooo0_l0000:oooo
o`;o0000=Oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1Eooooo`;o00000oooool2o`000003ooooool0003o
000000?ooooo4_l000001?oooooo0000o`000?l00002ooooo`;o00002oooool2o`0000Gooooo0ol0
0003ooooo`;o00000oooool3o`0000;ooooo4_l000000ooooooo0000o`00000Eo`0002Cooooo0ol0
0003ooooo`;o00003_ooool2o`0000;ooooo0_l0000:ooooo`;o0000=Oooool00003ooooool@413o
oooo00;ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo00?o0000ooooooooool0A_ooool2
o`0000gooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`00000H
o`00013ooooo1_l00002ooooo`;o00000oooool3o`0000;ooooo4ol00003ooooo`ko00000_ooool3
o`0000oooooo0_l00004ooooo`;o00005?ooool2o`0000Kooooo0_l00004ooooo`;o00001Oooool2
o`00043ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgM
gOoooooo00001oooool3o`0003cooooo0_l00008ooooo`?o00000oooool3o`0000Kooooo0_l00008
oooooaco00004Oooool2o`0000;ooooo0_l00008ooooo`;o00000_oooolQo`0000Gooooo0_l0000@
ooooo`;o00001?ooool2o`00017ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2
o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`Co0000?_ooool00003ooooool0003ooooo
00;ooooo00?o0000ooooooooool02Oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooo
oooo03cooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo0ol00005
ooooo`?o000000?oooooo`000?l000000ooooolMo`000003ooooool0003o000000;o00002_ooool2
o`0000cooooo:?l0000Pooooo`;o00002Oooool2o`0000?ooooo0_l00002ooooo`Go00001Oooool2
o`0000Cooooo1?l00002ooooo`;o0000?_ooool00003ooooool@413ooooo00;ooooo00?o410@oooo
ooooool02_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo03_ooooo0_l00003oooo
o`Go00000_ooool2o`0000_ooooo0_l00002ooooo`;o00000oooool3o`000003ooooool0003o0000
01co00002_ooool2o`0000Oooooo0_l00003ooooo`?o000000?oooooo`000?l000008ol00003oooo
o`Co00000oooool2o`0001?ooooo0_l00006ooooo`;o000000Coooooo`000?l0003o00001?ooool2
o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000001_ooool2o`0004;ooooo00001_oo
ooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l000001oooool00ol0003ooooooooo
o`0kooooo`;o00001?ooool2o`0000Cooooo0ol0000;ooooo`;o000000?oooooo`000?l000000_l0
00000ooooooo0000o`00000Oo`0000cooooo1?l00004ooooo`;o00001?ooool2o`0000Cooooo8_l0
0003ooooo`Co00000oooool2o`0001?ooooo0_l00006ooooo`;o00000_ooool2o`0000Cooooo0_l0
0007ooooo`;o00002oooool2o`00043ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPgooooo
00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`18ooooo`;o00002oooool2o`0000?ooooo
0_l000000ooooooo0000o`00000Oo`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l00000
0ol00002ooooo`;o00000oooool4o`0000Kooooo9_l00008ooooo`;o00001oooool2o`0000Kooooo
0_l00007ooooo`;o00004?ooool2o`0000_ooooo0_l00010ooooo`007?ooool00ol0003ooooooooo
o`0oooooo`;o00001Oooool2o`0001Kooooo8?l00002ooooo`;o00001Oooool3o`0000?ooooo0_l0
0002ooooo`;o00000oooool2o`0000?ooooo1?l000000ooooooo0000o`00000To`0000Kooooo1_l0
0002ooooo`;o000000Coooooo`000?l0003o00001?ooool3o`0000Oooooo0_l0000@ooooo`;o0000
2_ooool2o`00047ooooo000Looooo`03o`000?oooooooooo03oooooo0_l000000ooooooo0000o`00
0002ooooo`;o00000oooool2o`0000?ooooo0_l00008oooooaSo000000?oooooo`000?l000002_l0
00000ooooooo0000o`000006ooooo`;o00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`00
0005ooooobGo00000_ooool2o`0000Sooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo0_l0
0002ooooo`Go00003Oooool3o`00017ooooo0ol000001?oooooo0000o`000?l00010ooooo`007?oo
ool00ol0003oooooooooo`0nooooo`;o00000_ooool2o`000003ooooool0003o000000Cooooo1?l0
00000ooooooo0000o`000006ooooo`Wo000000?oooooo`000?l000003?l000000ooooooo0000o`00
0005o`000003ooooool0003o000000Oo00002_ooool2o`0000Kooooo0_l00002ooooo`;o000000Co
ooooo`000?l0003ooooo1_l000000ooooooo0000o`00000Jo`000003ooooool0003o000000Kooooo
1?l00004ooooo`;o00002?ooool4o`0000Kooooo0_l000000ooooooo0000o`000003ooooo`?o0000
4Oooool3o`000003ooooool0003o000000;o0000?oooool001cooooo00?o0000ooooooooool0;_oo
ool2o`0000kooooo0_l00005ooooo`;o00001_ooool2o`0000Oooooo1?l00005ooooob7o00005Ooo
ool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000001?l000000ooooooo0000
o`00000Jo`0000?ooooo0_l00004ooooo`;o00001_ooool2o`0000Sooooo1Ol00005ooooo`Go0000
00Coooooo`000?l0003ooooo0_l0000Fooooo`?o0000?oooool001cooooo00?o0000ooooooooool0
;_ooool2o`0001;ooooo0_l00008ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Oooooo
8?l000000ooooooo0000o`000003ooooo`;o00003_ooool2o`000003ooooool0003o000000[o0000
0_oooolLo`0000;ooooo1?l0000=ooooo`;o00001Oooool5o`0000Oooooo0_l00002ooooo`;o0000
00?oooooo`000?l000003oooool2o`0000;ooooo0_l000000ooooooo0000o`000010ooooo`007?oo
ool00ol0003oooooooooo`11ooooo`?o00002?ooool2o`000003ooooool0003o000000gooooo9?l0
0003ooooo`;o00000_ooool2o`0000oooooo1ol00003oooooaSo00000_ooool4o`0000;ooooo1?l0
000=ooooo`;o000000?oooooo`000?l000001?ooool2o`0001;ooooo0_l00005ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0000;ooooo0_l0000;ooooo`;o0000=_ooool001cooooo00?o0000
ooooooooool0@Oooool2o`0000?ooooo0_l0000Fooooo`co000000?oooooo`000?l000004ol00009
ooooo`;o00001?ooool2o`0000Wooooo8_l0000>ooooo`;o00002oooool3o`0000Cooooo0_l0000@
ooooo`Co00001Oooool5o`0001?ooooo0_l0000Aooooo`;o00008oooool001cooooo00?o0000oooo
ooooool0A_ooool2o`0000Wooooo0_l00002ooooo`?o00001ooooolMo`0001?ooooo0_l00009oooo
o`[o000000?oooooo`000?l000000_l000000ooooooo0000o`00000<o`000003ooooool0003o0000
00Ko00000oooool2o`0000Cooooo0ol0000:ooooo`;o00005oooool2o`0000?ooooo0_l00004oooo
o`;o00001Oooool2o`0000?ooooo0_l0000Kooooo`;o00008oooool001cooooo00?o0000oooooooo
ool0DOooool3o`000004ooooool0003o0000o`0000Cooooo8?l00002ooooo`;o00001_ooool2o`00
00Oooooo0_l0000;ooooo`;o000000Goooooo`000?l0003o0000ooooo`0No`0000?ooooo0_l00000
0ooooooo0000o`000002ooooo`;o00002oooool2o`0001_ooooo0_l0000;ooooo`?o00000_ooool2
o`00043ooooo000Looooo`03o`000?oooooooooo03Sooooo0_l0000Hooooo`?o00000_ooool2o`00
00?ooooo8Ol000000ooooooo0000o`000006ooooo`;o00001Oooool3o`0000;ooooo0_l000000ooo
oooo0000o`000002o`000003ooooool0003o000000Co00000_oooolLo`000003ooooool0003o0000
00Kooooo0_l0000?ooooo`;o00000_ooool2o`0000Wooooo0_l00006ooooo`;o00002Oooool2o`00
00Cooooo0_l000000ooooooo0000o`000005ooooo`;o0000?Oooool001cooooo00?o0000oooooooo
ool0>?ooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`000004ooooool0003o0000o`00
00Oooooo4Ol000000ooooooo0000o`00000;o`0000kooooo0ol00002ooooo`;o000000?oooooo`00
0?l000001Ol00002ooooo`;o00000_ooool2o`0000;ooooo4Ol000000ooooooo0000o`000003o`00
00;ooooo0_l00005ooooo`;o00005?ooool2o`0000Wooooo0_l00002ooooo`?o000000?oooooo`00
0?l000002Oooool4o`000004ooooool0003o0000o`0000Kooooo1?l0000mooooo`007?ooool2o`00
033ooooo0_l0000@ooooo`?o00001_ooool2o`0000[ooooo0_l00009oooooaCo00000_ooool4o`00
0003ooooool0003o000000;o00000_ooool4o`0000Cooooo0_l00005ooooo`;o00001_ooool2o`00
00?ooooo0_l00002ooooo`co000000?oooooo`000?l000001ol00003ooooo`;o00000_ooool2o`00
00Gooooo0_l0000;ooooo`;o00005_ooool4o`0000Gooooo0_l00006ooooo`;o000000?oooooo`00
0?l000001oooool2o`0000;ooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o
00004Oooool2o`0001cooooo5ol000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l0
00000ol00004ooooo`;o00001Oooool2o`0000_ooooo0_l00004ooooo`[o000000?oooooo`000?l0
00000_l000000ooooooo0000o`000005o`0000Gooooo0_l0000Aooooo`;o00006?ooool2o`000003
ooooool0003o000000;ooooo0_l00008ooooo`;o00003?ooool2o`0003_ooooo000Looooo`03o`00
0?oooooooooo03gooooo0_l00008ooooo`?o00005_oooolGo`000003ooooool0003o000000Oooooo
1?l000000ooooooo0000o`00000=ooooo`;o00001_ooool4o`0000?ooooo0_l00004ooooo`;o0000
0oooool4o`000003ooooool0003o000000Oo00000oooool4o`000003ooooool0003o000000cooooo
0_l000000ooooooo0000o`00000Hooooo`;o00000_ooool6o`0000?ooooo0ol00019ooooo`007?oo
ool00ol0003oooooooooo`0gooooo`;o00001?ooool2o`0000?ooooo0_l00003ooooo`?o00000_oo
ool2o`0000;ooooo0_l00009ooooo`Co00000_ooool<o`0000?ooooo2_l00008ooooo`?o000000?o
ooooo`000?l000003Oooool2o`0000Kooooo1?l000000ooooooo0000o`000006ooooo`;o00000ooo
ool9o`0000;ooooo0ol00005ooooo`;o000000?oooooo`000?l000003?ooool2o`000003ooooool0
003o0000013ooooo0_l0000:ooooo`Oo00000_ooool2o`0002Oooooo0_l0000Qooooo`007?ooool0
0ol0003oooooooooo`0gooooo`;o00001?ooool2o`0000?ooooo0ol00002ooooo`?o00000_ooool2
o`0000;ooooo0_l00003ooooo`;o00001?ooool4o`0000Oooooo0ol000000ooooooo0000o`000007
o`0000;ooooo1?l0000:ooooo`;o000000?oooooo`000?l000000oooool2o`0001Gooooo1?l00004
ooooo`;o00000_ooool4o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0001Oooooo0_l0
0004ooooo`;o00001?ooool2o`0000Oooooo0_l00003ooooo`;o00001_ooool3o`000003ooooool0
003o000000;o00000_ooool2o`0002Gooooo0_l0000Qooooo`007?ooool00ol0003oooooooooo`0m
ooooo`;o00001?ooool2o`0000;ooooo0ol00002ooooo`;o00001oooool2o`0000Kooooo0_l00000
0ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000oooool7o`000003ooooool0003o
000000Go00000oooool2o`0000?ooooo0_l00006ooooo`;o00000_ooool2o`0001?ooooo0_l00006
ooooo`So00003oooool2o`0000kooooo0_l00004ooooo`;o00001?ooool2o`0000;ooooo1?l00006
ooooo`;o00001_ooool2o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l000001Oooool2
o`000003ooooool0003o000003_ooooo000Looooo`03o`000?oooooooooo04cooooo0_l00007oooo
o`;o00002Oooool2o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`00
0?l000000oooool7o`0000?ooooo0_l0000?ooooo`;o00003_ooool2o`0000[ooooo2Ol00002oooo
o`?o00002_ooool2o`0000Cooooo0_l0000@ooooo`;o00001_ooool8o`0000Gooooo0_l00002oooo
o`;o00001_ooool2o`0000Cooooo0_l00004ooooo`?o000000?oooooo`000?l00000>oooool001co
oooo00?o0000ooooooooool0?_ooool4o`0001?ooooo0_l00002ooooo`;o00003oooool4o`000003
ooooool0003o000000;ooooo0ol00005ooooo`;o00003Oooool2o`00017ooooo1?l00006ooooo`Ko
000000?oooooo`000?l000003?l0000=ooooo`;o00004?ooool4o`0000?ooooo1?l000000ooooooo
0000o`000002o`0000Gooooo1_l00006ooooo`?o00000_ooool2o`0000Gooooo0_l0000oooooo`00
7?ooool00ol0003oooooooooo`0booooo`;o00001Oooool2o`0000?ooooo1?l00009ooooo`;o0000
3?ooool2o`0000?ooooo0_l0000:ooooo`;o00001?ooool2o`000003ooooool0003o000000Kooooo
0_l0000=ooooo`;o00004Oooool3o`0000Cooooo0_l000000ooooooo0000o`000002o`000003oooo
ool0003o000000;ooooo1ol000000ooooooo0000o`000002o`0000Cooooo0_l0000<ooooo`;o0000
3Oooool3o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0000Gooooo0_l00008ooooo`Oo0000
1Oooool2o`0000gooooo0_l0000`ooooo`007?ooool00ol0003oooooooooo`0booooo`;o00000ooo
ool4o`0000?ooooo0ol00006ooooo`;o000000Coooooo`000?l0003o00004Oooool2o`0000oooooo
2Ol0000=ooooo`;o00004Oooool2o`0000Cooooo0_l00004ooooo`;o00000oooool2o`000003oooo
ool0003o000000;ooooo0_l00003ooooo`;o00000_ooool2o`0000Gooooo0_l0000<ooooo`;o0000
3_ooool2o`000003ooooool0003o000000?ooooo1?l000001?oooooo0000o`000?ooool4o`000003
ooooool0003o000000;o00001_ooool7o`0000Gooooo0_l0000<ooooo`;o0000<?ooool001cooooo
00?o0000ooooooooool0=oooool2o`000003ooooool0003o000000;ooooo0_l00007ooooo`;o0000
00?oooooo`000?l000007_ooool2o`0000?ooooo2Ol00006ooooo`;o00000_ooool2o`000003oooo
ool0003o000000Wooooo0_l00006ooooo`;o00000_ooool2o`000003ooooool0003o000000Oooooo
0ol000000ooooooo0000o`00000?ooooo`;o00006_ooool2o`0000Kooooo0ol00004ooooo`;o0000
0oooool5o`000003ooooool0003o000000;o00001_ooool3o`000004ooooool0003o0000o`0000Go
oooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0gooooo`;o000000?oooooo`000?l00000
0_ooool2o`000003ooooool0003o000000;o00007Oooool4o`0000Cooooo1_l00003ooooo`?o0000
2?ooool2o`0000;ooooo0_l0000;ooooo`?o00001oooool2o`000004ooooool0003o0000ooooo`;o
00001oooool2o`000003ooooool0003o000000kooooo1?l000000ooooooo0000o`00000Gooooo`;o
00001?ooool5o`0000Cooooo1?l000000ooooooo0000o`000003o`0000cooooo0_l00007ooooo`;o
0000@?ooool001cooooo00?o0000ooooooooool0>_ooool2o`0000Gooooo1?l0000Mooooo`Co0000
1_ooool4o`0001oooooo1?l00006ooooo`;o00002Oooool2o`0000?ooooo1?l000000ooooooo0000
o`000002o`0000Wooooo0_l00002ooooo`?o00004?ooool2o`0000Kooooo0_l00003ooooo`?o0000
00?oooooo`000?l000001Oooool2o`0000Wooooo0_l00008ooooo`;o00001Oooool3o`00043ooooo
000Looooo`03o`000?oooooooooo03;ooooo0_l0000Nooooo`;o00002oooool2o`0001Sooooo0_l0
0007ooooo`;o000000?oooooo`000?l000002Oooool3o`00017ooooo0_l00003ooooo`;o00000ooo
ool4o`0000_ooooo1?l00006ooooo`;o00000oooool2o`0000Cooooo0_l00003ooooo`;o000000?o
ooooo`000?l000001oooool2o`0000[ooooo0_l00004ooooo`;o00002?ooool2o`0000Gooooo1_l0
000mooooo`007?ooool00ol0003oooooooooo`0booooo`;o00007_ooool4o`0000Wooooo0_l0000B
ooooo`;o00001?ooool4o`0000Gooooo0_l000000ooooooo0000o`000007ooooo`Co00000oooool3
o`0001gooooo0_l00006ooooo`;o00001_ooool4o`0000?ooooo0_l00005ooooo`;o00000_ooool2
o`0000Wooooo0_l00006ooooo`Co000000?oooooo`000?l000000oooool2o`00013ooooo0_l00000
1?oooooo0000o`000?l0000Gooooo`;o00009?ooool001cooooo00?o0000ooooooooool0<_ooool2
o`0001kooooo1?l000000ooooooo0000o`00000Jooooo`?o00001Oooool2o`0000Gooooo0_l00004
ooooo`;o00001?ooool2o`0000;ooooo0_l000001?oooooo0000o`000?l0000Cooooo`;o00002?oo
ool2o`0000Kooooo0_l00006ooooo`Go00000oooool2o`0000Cooooo0_l0000=ooooo`;o00001_oo
ool4o`0000Kooooo0_l00003ooooo`;o00004Oooool2o`0001Gooooo0_l0000Tooooo`007?ooool2
o`0003;ooooo0_l00002ooooo`;o00000oooool3o`0000cooooo0_l00007ooooo`;o00000oooool2
o`00017ooooo0_l00008ooooo`;o00001Oooool2o`0000_ooooo0_l00008ooooo`;o000000Cooooo
o`000?l0003ooooo1Ol00008ooooo`;o00000oooool3o`0001?ooooo0_l000000ooooooo0000o`00
0002ooooo`?o00000_ooool3o`000003ooooool0003o000000Kooooo0_l00003ooooo`;o00002ooo
ool6o`0000Wooooo0_l0000Aooooo`Co0000>Oooool001cooooo00?o0000ooooooooool0<Oooool2
o`0000;ooooo0_l00003ooooo`?o00002?ooool6o`0000cooooo0_l0000Aooooo`;o00003oooool2
o`0000oooooo0_l00003ooooo`;o000000Goooooo`000?l0003o0000ooooo`05o`0000Sooooo0_l0
0003ooooo`;o00002?ooool2o`0000[ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o0000
0oooool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000000oooool2o`0000Sooooo
1_l000000ooooooo0000o`000004ooooo`;o00000oooool2o`0000Cooooo0_l0000:ooooo`;o0000
00?oooooo`000?l000000_ooool2o`0003Gooooo000Looooo`03o`000?oooooooooo03[ooooo0ol0
0008ooooo`Co00002Oooool2o`0000cooooo0_l0000Looooo`;o00001?ooool2o`0000Kooooo0_l0
0003ooooo`;o000000?oooooo`000?l000004Oooool2o`000003ooooool0003o000000Sooooo0_l0
0003ooooo`;o00002?ooool3o`000004ooooool0003o0000o`0000_ooooo0_l00003ooooo`;o0000
2oooool4o`0000Wooooo0_l00002ooooo`;o00001Oooool2o`0000[ooooo0_l00005ooooo`;o0000
=Oooool001cooooo00?o0000ooooooooool0;Oooool2o`0000Sooooo1_l000000ooooooo0000o`00
000Booooo`;o00003?ooool2o`0001cooooo0_l00004ooooo`;o00008Oooool2o`0000_ooooo0ol0
00001Ooooooo0000o`000?l0003ooooo00Co00001Oooool5o`0000_ooooo0_l00003ooooo`;o0000
1Oooool6o`00013ooooo0ol00006ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0;Ooo
ool2o`0000Sooooo1Ol000001?oooooo0000o`000?l00006ooooo`;o0000:?ooool2o`0001oooooo
0_l00009ooooo`;o00004oooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`Go0000
0_ooool6o`0000Oooooo0_l0000?ooooo`Ko00004?ooool2o`000003ooooool0003o000000Cooooo
0_l0000=ooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0=_ooool2o`0000;ooooo0_l0
00000ooooooo0000o`000002o`0000;ooooo0_l000000ooooooo0000o`00000Xooooo`;o00006Ooo
ool2o`0000Cooooo0_l00007ooooo`Co00004oooool2o`0000Gooooo0_l00004ooooo`?o000000?o
ooooo`000?l000001Ol00006ooooo`?o00002?ooool3o`0000gooooo0_l0000>ooooo`?o00004_oo
ool2o`0003Sooooo000Looooo`03o`000?oooooooooo03Kooooo0_l00007ooooo`;o00000_ooool2
o`00017ooooo0_l000001?oooooo0000o`000?l0000;ooooo`;o00007?ooool2o`0000Cooooo0_l0
000=ooooo`Co00002?ooool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o00000ooo
ool2o`0000Cooooo2?l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000;o0000
2Oooool3o`0000cooooo0ol0000:ooooo`;o00000oooool2o`0000oooooo0_l00003ooooo`;o0000
=_ooool001cooooo00?o0000ooooooooool0@Oooool2o`00013ooooo1Ol000000ooooooo0000o`00
0005o`0000;ooooo0_l00003ooooo`;o00001Oooool2o`0001Gooooo0_l00007ooooo`;o00001_oo
ool3o`0000;ooooo1?l00007ooooo`;o000000?oooooo`000?l000000oooool3o`0000;ooooo0_l0
000:ooooo`Go00000oooool2o`000003ooooool0003o000000Go00000_ooool2o`0000gooooo0_l0
0003ooooo`Go00000oooool2o`0000;ooooo0_l000000ooooooo0000o`00000<ooooo`;o00001_oo
ool2o`0000?ooooo1?l0000dooooo`007?ooool00ol0003oooooooooo`0oooooo`Oo00003Oooool3
o`0000?ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00004ooooo`;o000000Cooooo
o`000?l0003ooooo0_l0000Nooooo`;o00001_ooool3o`0000?ooooo0ol00004ooooo`;o00000_oo
ool5o`0000;ooooo1?l00002ooooo`;o00002Oooool2o`000003ooooool0003o000000?ooooo0_l0
0002ooooo`;o00000_ooool2o`0000;ooooo0ol0000<ooooo`Oo00001_ooool6o`0000;ooooo0_l0
000;ooooo`;o00002_ooool5o`0003Cooooo000Looooo`03o`000?oooooooooo03;ooooo0_l00009
ooooo`Co000000?oooooo`000?l000000_l0000Cooooo`;o00000oooool2o`000003ooooool0003o
000000Gooooo0_l000000ooooooo0000o`00000Qooooo`;o00000_ooool7o`0000?ooooo2Ol00002
ooooo`Go000000Coooooo`000?l0003ooooo0_l000001?oooooo0000o`000?l00005ooooo`Co0000
4_ooool2o`000003ooooool0003o000000gooooo1?l00004ooooo`;o00001?ooool2o`0000Cooooo
0_l00006ooooo`;o00003oooool5o`0000cooooo0_l0000Vooooo`007?ooool00ol0003ooooooooo
o`0booooo`;o00002Oooool2o`0000Sooooo1?l00006ooooo`;o00002oooool2o`000003ooooool0
003o000002_ooooo0_l00002ooooo`Co00001oooool:o`0000Kooooo0ol000000ooooooo0000o`00
0004o`0000Cooooo1?l00004ooooo`Co00001?ooool3o`000003ooooool0003o000000;o000000?o
ooooo`000?l000002Oooool2o`0000Kooooo0_l000001?oooooo0000o`000?l0000Aooooo`?o0000
00?oooooo`000?l000007Oooool2o`0002Kooooo000Looooo`03o`000?oooooooooo03Sooooo0_l0
000=ooooo`Co00001_ooool5o`0000?ooooo0_l0000booooo`;o00003_ooool2o`000003ooooool0
003o000000Ko00001Oooool3o`000003ooooool0003o000000Go00001?ooool2o`0000?ooooo1_l0
00001?oooooo0000o`000?ooool3o`000004ooooool0003o0000o`0000;ooooo0_l00009ooooo`;o
00001_ooool2o`000003ooooool0003o000000_ooooo0_l00003ooooo`Go000000?oooooo`000?l0
0000AOooool001cooooo00?o0000ooooooooool0<?ooool2o`0000Gooooo0ol00004ooooo`;o0000
1oooool3o`0000Sooooo1Ol00002ooooo`;o00005?ooool2o`0000Sooooo0_l0000Booooo`;o0000
2_ooool2o`0000Oooooo0_l00002ooooo`;o00002_ooool7o`0000;ooooo1?l000000ooooooo0000
o`000002o`0000Cooooo1?l0000Booooo`;o00002?ooool2o`0000Cooooo0ol00005ooooo`?o0000
0oooool5o`0001;ooooo0_l0000dooooo`007?ooool00ol0003oooooooooo`0`ooooo`?o00001?oo
ool2o`0000Gooooo0_l00007ooooo`Go00000_ooool2o`0000Gooooo0_l00005ooooo`;o00002ooo
ool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000Cooooo0_l0000?ooooo`;o0000
00Goooooo`000?l0003o0000ooooo`02o`0000Kooooo0_l00007ooooo`Co00003oooool4o`0000;o
oooo1?l000000ooooooo0000o`000002o`0000Kooooo0_l00005ooooo`;o00000oooool2o`0000Ko
oooo0_l00002ooooo`;o00000_ooool5o`0000?ooooo0ol00005ooooo`;o00001?ooool2o`0000Co
oooo0_l00006ooooo`;o00001_ooool3o`0003Cooooo000Looooo`03o`000?oooooooooo037ooooo
0_l0000Gooooo`Ko00001_ooool2o`0000Cooooo1_l00007ooooo`;o000000?oooooo`000?l00000
1Oooool2o`0000Gooooo0_l0000>ooooo`;o00000_ooool2o`000003ooooool0003o000000Oooooo
0_l00008ooooo`;o00000_ooool2o`0000gooooo0_l00008ooooo`;o00003_ooool2o`0000;ooooo
0ol00003ooooo`;o00001Oooool2o`0000;ooooo1Ol000000ooooooo0000o`000002o`0000_ooooo
0ol00004ooooo`;o00001Oooool3o`0000Kooooo0_l0000eooooo`007?ooool00ol0003ooooooooo
o`0mooooo`Co00002Oooool4o`0000?ooooo0_l00003ooooo`;o00001_ooool6o`0000Sooooo2Ol0
0005ooooo`;o00001oooool2o`0000Kooooo0ol00007ooooo`;o00000oooool2o`0000Sooooo0_l0
0002ooooo`;o00004Oooool2o`000004ooooool0003o0000ooooo`;o00004_ooool2o`0000?ooooo
0ol0000:ooooo`;o00000oooool4o`0000_ooooo0_l0000<ooooo`;o00000oooool4o`0003Oooooo
000Looooo`;o0000<_ooool2o`0000Kooooo0_l00002ooooo`Co00002Oooool2o`0000;ooooo0_l0
00001?oooooo0000o`000?ooool3o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo
0_l000000ooooooo0000o`000002ooooo`Wo00003Oooool2o`0000Gooooo1_l00003ooooo`Co0000
9?ooool2o`000003ooooool0003o000000?ooooo0_l0000Eooooo`Co00000oooool2o`0000Gooooo
0_l00004ooooo`Co00007?ooool4o`0003Oooooo000Looooo`03o`000?oooooooooo037ooooo0_l0
0006ooooo`;o00004oooool2o`0000Cooooo0ol00002ooooo`;o00000oooool2o`0000Kooooo0_l0
00000ooooooo0000o`000003ooooo`_o00004Oooool2o`0000;ooooo0_l00003ooooo`;o00006ooo
ool2o`0000oooooo1Ol0000Fooooo`;o00000oooool2o`0000?ooooo1?l00006ooooo`?o00001_oo
ool3o`0000Gooooo0_l0000;ooooo`Co0000=oooool001cooooo00?o0000ooooooooool0B_ooool2
o`0000Gooooo0_l00002ooooo`;o00002?ooool2o`0000Kooooo0_l000000ooooooo0000o`00000>
o`0001Wooooo0_l0000=ooooo`;o00003?ooool2o`000003ooooool0003o000000cooooo0_l00000
0ooooooo0000o`00000Pooooo`;o000000?oooooo`000?l000000_l00004ooooo`Co00001?ooool5
o`0000?ooooo0_l0000;ooooo`;o0000>Oooool001cooooo00?o0000ooooooooool0;Oooool2o`00
00gooooo0_l00007ooooo`;o00000oooool2o`0000Gooooo0_l0000<ooooo`;o00001_oooolCo`00
0003ooooool0003o000000;o00005?ooool2o`0000Kooooo0_l00005ooooo`;o00003oooool2o`00
00cooooo0_l0000<ooooo`;o00006?ooool4o`0000;ooooo0_l000001?oooooo0000o`000?l00007
ooooo`;o00001Oooool2o`0000;ooooo0ol00005ooooo`;o0000>?ooool001cooooo00?o0000oooo
ooooool0;Oooool2o`0000gooooo0_l00007ooooo`;o00003oooool2o`0000Oooooo0_l00007oooo
oa7o000000?oooooo`000?l000000ol00002ooooo`;o00003Oooool2o`000003ooooool0003o0000
00;o00001?ooool2o`0000oooooo0_l00005ooooo`?o00002oooool2o`0000[ooooo1?l00004oooo
o`Go00001Oooool4o`0000cooooo0_l000000ooooooo0000o`00000:ooooo`;o00000oooool2o`00
00;ooooo0ol00005ooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0AOooool2o`0000oo
oooo0ol00006ooooo`;o00001oooool2o`000003ooooool0003o000000oo000000?oooooo`000?l0
00000_ooool3o`0000cooooo0_l00003ooooo`;o00003?ooool6o`0000?ooooo0_l00005ooooo`?o
00003oooool2o`0000Kooooo0_l000000ooooooo0000o`000003ooooo`Go00001Oooool4o`0000;o
oooo1?l00002ooooo`;o00001Oooool2o`0000[ooooo1?l00006ooooo`;o00001?ooool2o`0003Wo
oooo000Looooo`03o`000?oooooooooo04Gooooo0_l00003ooooo`;o00002?ooool2o`000003oooo
ool0003o000000gooooo5ol00005ooooo`;o00002?ooool2o`0000Cooooo0_l000000ooooooo0000
o`000002o`0000;ooooo0_l00004ooooo`So00000oooool3o`0000kooooo0_l00006ooooo`;o0000
2Oooool2o`0000Gooooo0_l00007ooooo`?o00000_ooool4o`0000;ooooo0_l00007ooooo`;o0000
2_ooool2o`0000Kooooo0_l00004ooooo`?o0000>?ooool001cooooo00?o0000ooooooooool0;ooo
ool2o`0001Wooooo0_l00002ooooo`;o00001?ooool2o`0000Gooooo0_l00009ooooo`_o000000?o
ooooo`000?l000002Ol0000?ooooo`;o00001?ooool2o`000003ooooool0003o000000;o00000_oo
ool2o`0000Cooooo0_l00009ooooo`?o00003_ooool2o`0000_ooooo0ol0000<ooooo`Co000000?o
ooooo`000?l000001ol000000ooooooo0000o`000008ooooo`Co000000?oooooo`000?l000002ooo
ool2o`0000Wooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00004_ooool2
o`0000Gooooo0ol000000ooooooo0000o`000007ooooo`;o00000_ooool3o`0000Sooooo5ol0000@
ooooo`;o00006oooool2o`0001kooooo0ol00008ooooo`;o00000_ooool=o`0000;ooooo0_l00008
ooooo`;o00000oooool2o`0000Gooooo0_l00004ooooo`;o00002?ooool2o`0000gooooo0_l0000Z
ooooo`007?ooool00ol0003oooooooooo`11ooooo`Co00001_ooool3o`0000Gooooo0_l00002oooo
o`;o00000oooool2o`0000Oooooo6?l000000ooooooo0000o`000003ooooo`;o00001oooool3o`00
00cooooo0_l0000=ooooo`;o00005oooool2o`0000kooooo5?l0000<ooooo`;o00002Oooool2o`00
00kooooo0_l0000=ooooo`;o0000:_ooool001cooooo00?o0000ooooooooool0@Oooool2o`0000Wo
oooo0_l00005ooooo`;o00001oooool2o`0000;ooooo0_l000000ooooooo0000o`00000Ko`0000;o
oooo0ol00004ooooo`Go00002?ooool2o`0000?ooooo0_l0000>ooooo`;o00002oooool2o`0000;o
oooo0_l00005ooooo`;o00001oooool2o`0000Gooooo3Ol000000ooooooo0000o`000005o`0000Co
oooo0ol00004ooooo`;o00000oooool2o`0000?ooooo0_l00002ooooo`?o0000AOooool001cooooo
00?o0000ooooooooool0?_ooool4o`0000[ooooo0_l00009ooooo`;o00001oooool2o`000003oooo
ool0003o000001Wo00000_ooool4o`0000;ooooo0_l000000ooooooo0000o`000003o`0000;ooooo
0_l00004ooooo`;o00004oooool2o`0000_ooooo1_l000000ooooooo0000o`00000;ooooo`;o0000
1?oooolFo`0000Cooooo0ol00009ooooo`;o00000oooool2o`0000;ooooo0ol00015ooooo`007?oo
ool00ol0003oooooooooo`0nooooo`Co000000?oooooo`000?l000002oooool2o`0000Gooooo0_l0
0002ooooo`;o00002?oooolJo`000003ooooool0003o000000;o00000_ooool2o`0000;ooooo1?l0
0002ooooo`;o00000oooool2o`0000?ooooo0_l00008ooooo`;o00000_ooool4o`0000gooooo1Ol0
00000ooooooo0000o`00000AoooooaKo00000oooool3o`0000Oooooo0_l00006ooooo`;o00000ooo
ool2o`0004Gooooo000Looooo`03o`000?oooooooooo04?ooooo1?l00008ooooo`?o00001Oooool2
o`0000;ooooo0ol00008oooooako00001_ooool2o`0000Wooooo0_l00003ooooo`;o00002?ooool2
o`0000;ooooo1?l0000=ooooo`;o000000?oooooo`000?l000000_l0000BoooooaKo00000oooool2
o`000003ooooool0003o000000Gooooo0_l00006ooooo`;o00001oooool2o`00047ooooo00001_oo
ooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0
1_ooool00ol0003oooooooooo`12ooooo`Go00002?ooool2o`0000Kooooo0_l00003ooooo`;o0000
2?oooolKo`000004ooooool0003o0000o`00023ooooo0_l000000ooooooo0000o`000007ooooo`?o
00001_ooool2o`0000;ooooo0_l00009ooooo`;o00001_ooool?o`000003ooooool0003o000000Go
000000?oooooo`000?l000000oooool2o`0001Kooooo0_l00011ooooo`0000KoooooogMgMonHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000
ooooooooool0@_ooool2o`0000?ooooo0_l0000Koooooa_o00000oooool3o`0000?ooooo0_l0000E
ooooo`;o00001?ooool2o`000003ooooool0003o000000Oooooo0ol00006ooooo`Co00002oooool2
o`0000Kooooo6_l00003ooooo`;o00006oooool2o`0003cooooo00000ooooooo410@ooooo`02oooo
o`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo04Oooooo0_l00009ooooo`;o00003?ooool2o`0000;ooooo1ol00002oooooa;o000000Cooooo
o`000?l0003ooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo0_l0000=ooooo`;o00001Ooo
ool2o`0000[ooooo0_l00008ooooo`;o00000_ooool5o`0000gooooo6_l00002ooooo`;o00006ooo
ool2o`0003cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000
oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000@_ooool2o`0000;ooooo0_l00005ooooo`;o00000ooo
ool2o`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l000000_oooolNo`0000Cooooo0_l0
0004ooooo`;o00000_ooool2o`0000_ooooo0_l00007ooooo`Co00000oooool2o`0000?ooooo1Ol0
00000ooooooo0000o`000002o`0000Cooooo1Ol00007ooooo`?o000000?oooooo`000?l000006_l0
00000ooooooo0000o`00000Looooo`;o00001Oooool2o`0003Gooooo00000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oo
oooooooo047ooooo1?l000001Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`000?l00000
2?ooool2o`0000Cooooo0_l00005ooooo`go000000?oooooo`000?l000003?l000000ooooooo0000
o`000003ooooo`;o00001?ooool3o`0000kooooo0_l000000ooooooo0000o`000006ooooo`[o0000
00?oooooo`000?l000002Ol0000>ooooo`?o000000?oooooo`000?l000005ol00002ooooo`Co0000
7?ooool2o`0000Gooooo0_l0000eooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0@Oooool8o`000003ooooool0
003o000000_ooooo0_l00005ooooo`Go00001OoooolHo`000003ooooool0003o000000[ooooo0_l0
000Aooooo`;o000000?oooooo`000?l000001Oooool3o`0000;ooooo0ol000000ooooooo0000o`00
0004o`000003ooooool0003o000000Co00001Oooool3o`0000Sooooo6_l000000ooooooo0000o`00
0002o`00013ooooo0_l00018ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgM
gOl@413oV9RH00Sooooo00?o0000ooooooooool0@Oooool6o`0000[ooooo0_l00004ooooo`;o0000
1Oooool5o`0000Gooooo5ol0000Tooooo`;o00001?ooool4o`0000;ooooo4Ol00002ooooo`;o0000
00Goooooo`000?l0003o0000ooooo`02o`0000;ooooo0_l000000ooooooo0000o`00000Jo`000003
ooooool0003o000000;ooooo0_l0000<ooooo`;o0000B?ooool00006ooooooo^k^ko<S8bo`000?lb
<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo02cooooo0_l0000C
ooooo`So00001Oooool2o`000004ooooool0003o0000ooooo`;o00004oooool2o`0000;ooooo4_l0
0007ooooo`;o00008?oooolIo`000003ooooool0003o000000Gooooo0_l00002oooooa_o00000_oo
ool2o`0000Gooooo0_l0000>ooooo`;o000000?oooooo`000?l000003oooool2o`0003;ooooo000L
ooooo`03o`000?oooooooooo02cooooo0_l00004ooooo`;o00003_ooool2o`000003ooooool0003o
000000;o00001Oooool2o`0000?ooooo0ol0000:ooooo`Co00002OoooolBo`0000Oooooo0_l0000M
ooooo`;o000000?oooooo`000?l000000_oooolEo`000003ooooool0003o000000?ooooo0_l00004
oooooaKo00000oooool2o`0001;ooooo0_l00005ooooo`;o000000?oooooo`000?l000000_ooool2
o`0000_ooooo0_l0000booooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00001?ooool2o`00
00kooooo0_l0000=ooooo`Co000000?oooooo`000?l000002?ooool4o`0000Wooooo3ol000000ooo
oooo0000o`00000Eooooo`;o00002Oooool2o`0000Cooooo7?l000000ooooooo0000o`000003oooo
o`go000000?oooooo`000?l000003?l00002ooooo`;o00001Oooool2o`0000cooooo0_l0000<oooo
o`;o0000?oooool001cooooo00?o0000ooooooooool0;?ooool2o`0001gooooo0_l00003ooooo`?o
00000oooool2o`0001Oooooo2Ol00006ooooo`;o00001_ooool2o`0000cooooo0_l00009ooooo`Co
00000_ooool3o`000003ooooool0003o000001Ko00002?ooool5o`0000Cooooo0_l000000ooooooo
0000o`00000<o`0000;ooooo0_l00005ooooo`;o00002oooool2o`0001Cooooo0_l0000hooooo`00
7?ooool00ol0003oooooooooo`0eooooo`;o00005?ooool7o`0001;ooooo0_l0000:ooooo`Oo0000
1Oooool4o`0000;ooooo0_l00002ooooo`;o00004oooool2o`0000Cooooo0_l000000ooooooo0000
o`000003oooooaWo00002?ooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`Ko0000
2oooool2o`0000oooooo0_l00006ooooo`Co00002_ooool2o`0003Sooooo000Looooo`03o`000?oo
oooooooo03Gooooo0_l0000Fooooo`Oo00003_ooool4o`0000[ooooo0ol00002ooooo`;o00001Ooo
ool2o`0000Cooooo1?l00006ooooo`;o00003Oooool2o`0000Oooooo0_l00003oooooaWo00002?oo
ool5o`0000;ooooo0_l0000Eooooo`;o00002oooool2o`0000Cooooo0_l00004ooooo`Co0000A?oo
ool001cooooo00?o0000ooooooooool0B_ooool2o`0000;ooooo0_l000001?oooooo0000o`000?l0
0005ooooo`;o00001oooool4o`0000cooooo0_l00009ooooo`;o00001?ooool3o`0000Kooooo0_l0
0002ooooo`;o00005OoooolEo`000003ooooool0003o000000?o00002_ooool2o`0000Sooooo0_l0
000Mooooo`;o00001?ooool2o`0000Cooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`0]
ooooo`;o00006oooool2o`0000?ooooo1?l000000ooooooo0000o`000003ooooo`?o00002?ooool2
o`0000cooooo0_l00004ooooo`;o00000oooool2o`0000?ooooo0ol00009ooooo`Co00003?ooool2
o`0000Oooooo6ol0000<ooooo`;o00001_ooool3o`0000_ooooo0_l0000Kooooo`Co0000A?ooool0
01cooooo00?o0000ooooooooool0;Oooool2o`0001cooooo0_l00002ooooo`Co000000?oooooo`00
0?l000001?ooool2o`0000Wooooo0_l00004ooooo`;o000000?oooooo`000?l000000oooool2o`00
00?ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000007oooo
o`;o00003_ooool2o`0000Oooooo6Ol00002ooooo`;o00001Oooool2o`0000?ooooo0_l00007oooo
o`;o00001Oooool2o`0000Cooooo0_l0000Mooooo`;o0000A?ooool001cooooo00?o0000oooooooo
ool0>?ooool2o`00017ooooo0_l00004ooooo`;o00001?ooool2o`000003ooooool0003o000000Wo
oooo0_l00003ooooo`?o000000?oooooo`000?l000000oooool2o`0000Gooooo0_l000001?oooooo
0000o`000?ooool2o`0000?ooooo0_l0000Fooooo`;o00001?ooool2o`0000;ooooo6_l000000ooo
oooo0000o`000002ooooo`;o000000?oooooo`000?l000000oooool2o`0000Cooooo0_l00008oooo
o`;o00004Oooool2o`0000;ooooo0_l0000;ooooo`;o0000AOooool001cooooo00?o0000oooooooo
ool0>?ooool3o`0001Cooooo1?l00002ooooo`Co00004Oooool2o`0000Kooooo0_l00006ooooo`;o
00008Oooool2o`0000Cooooo0_l000001?oooooo0000o`000?oooolIo`0000Cooooo0_l00003oooo
o`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00000Kooooo`;o00000_ooool2
o`000003ooooool0003o000000Sooooo0_l00003ooooo`;o0000@?ooool001cooooo00?o0000oooo
ooooool0>Oooool2o`0000Sooooo0_l00007ooooo`;o000000Coooooo`000?l0003ooooo0_l00000
0ooooooo0000o`000006ooooo`;o00001oooool2o`0000[ooooo0_l0000Dooooo`;o00004oooool2
o`0000Gooooo1?l000000ooooooo0000o`00000Bo`000003ooooool0003o000000;o00002Oooool2
o`0000Cooooo0_l0000Eooooo`;o00002Oooool2o`0000?ooooo0_l00003ooooo`;o00002?ooool2
o`00043ooooo000Looooo`;o0000A?ooool2o`0000Oooooo0_l00003ooooo`?o00002Oooool2o`00
00Kooooo0ol00002ooooo`;o00005?ooool2o`0000Kooooo0_l0000Cooooo`;o00001Oooool<o`00
00;ooooo0_l000000ooooooo0000o`00000:o`0000Kooooo0_l0000Cooooo`;o00001Oooool7o`00
00Wooooo0_l00007ooooo`?o0000B_ooool001cooooo00?o0000ooooooooool0BOooool2o`0000Ko
oooo0_l00002ooooo`;o00003_ooool2o`0000?ooooo0_l00003ooooo`Co00002oooool5o`0000go
oooo0_l0000Aooooo`;o000000?oooooo`000?l000002Ol000000ooooooo0000o`00000=o`0000Ko
oooo0_l0000Cooooo`;o000000?oooooo`000?l000000_ooool6o`0001?ooooo0_l0001;ooooo`00
7?ooool00ol0003oooooooooo`19ooooo`;o00002_ooool3o`0000Oooooo0_l000000ooooooo0000
o`000009ooooo`So00002Oooool2o`000003ooooool0003o000000gooooo0_l0000Aooooo`;o0000
00?oooooo`000?l000002_l000000ooooooo0000o`00000<o`0001kooooo0_l0001Xooooo`007?oo
ool00ol0003oooooooooo`0iooooo`;o00002_ooool2o`0000?ooooo0_l00005ooooo`;o00000ooo
ool4o`0000?ooooo1?l000000ooooooo0000o`000009ooooo`;o00001?ooool2o`000003ooooool0
003o000002cooooo0_l000000ooooooo0000o`000009o`000003ooooool0003o000000_o00000_oo
ool2o`0001Sooooo0_l0000Sooooo`;o00001oooool2o`0003gooooo000Looooo`03o`000?oooooo
oooo03Wooooo0_l0000:ooooo`;o00000oooool2o`0000Cooooo0ol00003ooooo`Co00000oooool2
o`0000kooooo0_l00007ooooo`;o00001_ooool2o`0000Kooooo0_l0000Looooo`;o00000_oooolI
o`000003ooooool0003o000000[ooooo0_l00008ooooo`;o00000_ooool2o`0000Sooooo0ol0000D
ooooo`;o00000_ooool2o`0000Oooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`1@oooo
o`;o00001?ooool2o`0002Kooooo0_l00006ooooo`;o00007Oooool2o`0000;ooooo6?l0000=oooo
o`;o000000?oooooo`000?l000001Oooool2o`0000cooooo0ol00004ooooo`;o00003_ooool2o`00
04[ooooo000Looooo`03o`000?oooooooooo053ooooo0_l00005ooooo`Co0000B_ooool4o`000003
ooooool0003o000000go000000?oooooo`000?l000001Ol0000@ooooo`;o00004oooool2o`0000Go
oooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00001Oooool2o`0000;ooooo
1?l00003ooooo`;o00004Oooool2o`0001Sooooo0_l00003ooooo`;o00001_ooool2o`0000_ooooo
5?l000000ooooooo0000o`000002o`000004ooooool0003o0000o`0002Cooooo0_l0000Dooooo`;o
0000Boooool001cooooo00?o0000ooooooooool0C?ooool3o`0000Cooooo0_l000001?oooooo0000
o`000?l00005ooooo`;o00004Oooool2o`0001Sooooo0_l00003ooooo`;o00001_ooool2o`0000Wo
oooo7?l000000ooooooo0000o`00000Nooooo`;o00006_ooool2o`0004_ooooo000Looooo`03o`00
0?oooooooooo04gooooo0_l00004ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000;o
oooo0_l0000=ooooo`;o00003_ooool2o`0000Wooooo0_l000001?oooooo0000o`000?l00007oooo
o`;o00001?ooool2o`0000Gooooo0ol00002ooooo`Wo000000?oooooo`000?l000001ol00003oooo
o`;o00002_ooool2o`0000kooooo0_l00005ooooo`;o0000Ioooool001cooooo00?o0000oooooooo
ool0Doooool2o`0000;ooooo1Ol0000Aooooo`?o00003Oooool2o`0000Wooooo0_l00002ooooo`Co
00001Oooool2o`0000Cooooo0_l00005ooooo`?o00000_oooolEo`0000gooooo1?l0000<ooooo`?o
00000_ooool2o`0000Gooooo0_l000000ooooooo0000o`00001Oooooo`007?ooool00ol0003ooooo
ooooo`1Booooo`Go000000?oooooo`000?l000004_ooool6o`0001cooooo0_l0000@ooooo`;o0000
1_oooolDo`0000oooooo0_l00008ooooo`;o00000oooool2o`0000;ooooo0_l00005ooooo`;o0000
00?oooooo`000?l00000Goooool001cooooo00?o0000ooooooooool0D_ooool5o`0000;ooooo0_l0
00000ooooooo0000o`00000>ooooo`;o00000_ooool2o`0000oooooo0_l00002ooooo`;o00001ooo
ool2o`00013ooooo0_l00006oooooa3o00007Oooool2o`000003ooooool0003o000000;o00002_oo
ool2o`000003ooooool0003o000000Cooooo1?l0001Fooooo`007?ooool00ol0003oooooooooo`1B
ooooo`Go00000_ooool2o`000003ooooool0003o000000Gooooo0_l0000Looooo`;o00000_ooool2
o`0000;ooooo0_l0000Looooo`Go000000Coooooo`000?l0003ooooo0ol00002ooooo`Co00000_oo
ool2o`0001_ooooo0_l00002ooooo`;o000000?oooooo`000?l000001Oooool2o`000003ooooool0
003o000000Cooooo1?l00006ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0D_ooool5
o`0000?ooooo0_l00007ooooo`?o00003?ooool2o`0000cooooo0_l00007ooooo`;o00007?ooool4
o`0000Oooooo0ol00002ooooo`;o00000_ooool2o`0000Gooooo0_l00002ooooo`;o00000_ooool2
o`0000[ooooo0_l00004ooooo`;o000000?oooooo`000?l000006?ooool2o`0004kooooo000Loooo
o`03o`000?oooooooooo04;ooooo0_l0000Aooooo`;o00000oooool2o`000004ooooool0003o0000
o`0000Cooooo0_l00004ooooo`;o00001_ooool3o`0000Cooooo0_l00003ooooo`Co000000?ooooo
o`000?l000008_ooool4o`0000Oooooo0ol00002ooooo`;o00002Oooool2o`000004ooooool0003o
0000o`0000;ooooo0_l0000:ooooo`?o00004?ooool2o`0005kooooo000Looooo`;o0000@oooool2
o`0001Cooooo0_l00003ooooo`?o00002_ooool2o`0000Oooooo0_l00004ooooo`;o00000oooool2
o`000003ooooool0003o000000;o00006_ooool2o`000003ooooool0003o000000?ooooo0_l0000>
ooooo`;o00001oooool2o`0000?ooooo0_l0000@ooooo`;o00000oooool2o`0000_ooooo0_l0001N
ooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o00002?ooool2o`0000Sooooo0ol0000Coooo
o`;o00001oooool3o`0000kooooo1?l000000ooooooo0000o`000006ooooo`;o000000?oooooo`00
0?l000001Oooool2o`0000kooooo0_l00005ooooo`;o00005_ooool2o`0000;ooooo0_l0001[oooo
o`007?ooool00ol0003oooooooooo`14ooooo`;o00002?ooool2o`0000Kooooo0_l0000:ooooo`?o
00004oooool2o`000003ooooool0003o000000Gooooo0_l0000>ooooo`Oo00001?ooool6o`0000Co
oooo1?l00002ooooo`;o00002_ooool2o`0001gooooo0_l0000Tooooo`;o0000BOooool001cooooo
00?o0000ooooooooool0A?ooool2o`00013ooooo0_l0000;ooooo`;o000000?oooooo`000?l00000
4oooool2o`0001Sooooo0_l000000ooooooo0000o`000003ooooo`Ko000000Coooooo`000?l0003o
oooo2?l00004ooooo`;o00007oooool2o`0000oooooo0_l0000Gooooo`;o0000BOooool001cooooo
00?o0000ooooooooool0EOooool2o`0000oooooo0_l00002ooooo`;o00004Oooool2o`0001Wooooo
2ol000000ooooooo0000o`000004ooooo`?o00001_ooool2o`0001kooooo1?l0000>ooooo`;o0000
H_ooool001cooooo00?o0000ooooooooool0EOooool2o`0000gooooo0_l00004ooooo`;o00004Ooo
ool2o`0001?ooooo0_l00003ooooo`co000000Coooooo`000?l0003ooooo0_l000001Ooooooo0000
o`000?l0003ooooo00;o00008oooool6o`0000Kooooo0_l0001Xooooo`007?ooool00ol0003ooooo
ooooo`18ooooo`;o00003Oooool2o`0000Sooooo0_l000000ooooooo0000o`00000:ooooo`?o0000
3_ooool2o`0000Oooooo0_l00006ooooo`;o00000oooool;o`0000;ooooo0_l000001?oooooo0000
o`000?ooool2o`0000;ooooo0_l0000Wooooo`;o00001_ooool2o`0000Sooooo0_l00009ooooo`;o
0000Doooool001cooooo00?o0000ooooooooool0B?ooool2o`0000gooooo0_l00005ooooo`;o0000
00?oooooo`000?l000000_l0000:ooooo`Co00001?ooool2o`0000Sooooo0_l00007ooooo`;o0000
2Oooool>o`000003ooooool0003o000000Cooooo0_l0000;ooooo`;o00000oooool2o`0002_ooooo
0ol00008ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0G?ooool4o`0000?ooooo0_l0
0008ooooo`Go00001Oooool2o`0001cooooo3_l000000ooooooo0000o`000002ooooo`;o000000?o
ooooo`000?l000002_ooool4o`000003ooooool0003o000001Gooooo0_l0000Eooooo`?o0000G?oo
ool001cooooo00?o0000ooooooooool0COooool2o`0000Sooooo0_l00003ooooo`;o00002_ooool2
o`0000?ooooo0_l000000ooooooo0000o`000007ooooo`?o00003?ooool2o`0000[ooooo3_l00006
ooooo`;o000000?oooooo`000?l000001Oooool2o`0000?ooooo1?l0000>ooooo`;o00002?ooool2
o`0000oooooo0_l00004ooooo`?o0000G?ooool001cooooo00?o0000ooooooooool0COooool2o`00
00Sooooo1?l0000=ooooo`;o00002_ooool2o`0000?ooooo0ol0000<ooooo`Co00002?ooool=o`00
00oooooo1?l00003ooooo`;o00000oooool4o`0000Wooooo0_l0000Gooooo`Co00001?ooool2o`00
05gooooo000Looooo`03o`000?oooooooooo05Kooooo0_l000000ooooooo0000o`000006ooooo`;o
00001oooool2o`0000Sooooo1?l0000?ooooo`;o000000?oooooo`000?l000000oooool2o`0000;o
oooo3ol000000ooooooo0000o`00000;ooooo`;o00002?ooool6o`0000Kooooo0_l0000Fooooo`;o
00000_ooool2o`0006Gooooo000Looooo`03o`000?oooooooooo05Kooooo0_l00009ooooo`;o0000
1oooool2o`000003ooooool0003o000000Kooooo0ol0000?ooooo`;o00001_ooool2o`0000;ooooo
3ol000000ooooooo0000o`00000Booooo`Go00002_ooool2o`0000Wooooo0_l0000;ooooo`;o0000
2?ooool2o`0005oooooo000Looooo`03o`000?oooooooooo06cooooo1Ol0000Aooooo`;o000000?o
ooooo`000?l000001oooool2o`0000?ooooo2?l000000ooooooo0000o`000003o`0000Gooooo0ol0
000>ooooo`?o00000_ooool2o`0001?ooooo0_l0000Eooooo`?o0000G_ooool001cooooo00?o0000
ooooooooool0DOooool2o`0000kooooo1?l00007ooooo`;o000000?oooooo`000?l000004Oooool7
o`0000Gooooo0_l00004ooooo`co00001?ooool5o`0000Gooooo0_l00002ooooo`;o00001?ooool2
o`000004ooooool0003o0000o`0000kooooo0_l0000Kooooo`;o00002?ooool2o`0005Cooooo000L
ooooo`03o`000?oooooooooo057ooooo0_l0000>ooooo`Co00001Oooool2o`0000?ooooo0_l0000B
ooooo`Ko00002oooool<o`0000Cooooo0_l00008ooooo`;o00000_ooool2o`0000Oooooo0ol0000>
ooooo`;o00001oooool2o`0001cooooo0_l0001Dooooo`007?ooool2o`0005gooooo0_l0000<oooo
o`;o00000oooool2o`0000Gooooo1?l0000;ooooo`;o00003oooool6o`0000;ooooo0_l0000Boooo
o`;o000000?oooooo`000?l000001Oooool4o`0000;ooooo0_l0000Aooooo`;o0000L_ooool001co
oooo00?o0000ooooooooool0G?ooool2o`0000Gooooo0ol00003ooooo`;o00001_ooool4o`000003
ooooool0003o000000;o00005?ooool2o`0000Gooooo0_l000000ooooooo0000o`000002ooooo`;o
000000?oooooo`000?l000004Oooool2o`000003ooooool0003o000000Kooooo0ol00002ooooo`;o
00001oooool2o`0002;ooooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`1Sooooo`?o0000
0oooool2o`0000Kooooo1?l000000ooooooo0000o`000004o`0000cooooo0_l000001?oooooo0000
o`000?ooool3o`0000Cooooo0_l00005ooooo`;o000000?oooooo`000?l000000_ooool2o`000003
ooooool0003o000000Cooooo0_l0000Eooooo`;o00001_ooool2o`0002;ooooo0_l0001Hooooo`00
7?ooool00ol0003oooooooooo`1Booooo`;o00004_ooool2o`0000Cooooo0_l00004ooooo`;o0000
0_ooool6o`0000?ooooo0_l00004ooooo`Go000000?oooooo`000?l000000_ooool2o`0000oooooo
1Ol000000ooooooo0000o`000004ooooo`?o00002oooool2o`0000Gooooo1?l00006ooooo`;o0000
5?ooool2o`0006Kooooo000Looooo`03o`000?oooooooooo04Wooooo0_l00007ooooo`;o00002?oo
ool2o`0000Sooooo0_l00004ooooo`?o00004?ooool2o`0000Cooooo1?l0000Gooooo`So00001Ooo
ool2o`0000_ooooo0_l00005ooooo`Co00001_ooool2o`0001Cooooo0_l0001Vooooo`007?ooool0
0ol0003oooooooooo`19ooooo`;o00004Oooool2o`000003ooooool0003o000000Oooooo0_l00002
ooooo`?o000000?oooooo`000?l000001Oooool2o`0000kooooo0_l0000?ooooo`;o00002oooool2
o`0000?ooooo1_l0000Qooooo`;o0000M_ooool001cooooo00?o0000ooooooooool0Goooool2o`00
00Oooooo0_l00004ooooo`Co00001Oooool2o`0000Sooooo0ol00005ooooo`;o00001_ooool2o`00
0003ooooool0003o000000Ko00002Oooool8o`000004ooooool0003o0000o`0000Cooooo0ol00002
ooooo`;o00003_ooool2o`0000;ooooo1Ol0000<ooooo`;o0000J?ooool001cooooo00?o0000oooo
ooooool0FOooool2o`0000cooooo1?l00003ooooo`Co00003oooool3o`0000Cooooo0ol00006oooo
o`;o000000?oooooo`000?l000000_l00002ooooo`Co000000?oooooo`000?l000001_ooool5o`00
0003ooooool0003o000000;o00001?ooool3o`0000;ooooo0_l000000ooooooo0000o`00000;oooo
o`;o00000_ooool4o`0000gooooo0_l0001Xooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o
00003?ooool6o`000003ooooool0003o000000Cooooo0_l0000Booooo`;o00001_ooool2o`0000[o
oooo0_l000000ooooooo0000o`000008ooooo`;o00000_ooool3o`0000gooooo0_l0000]ooooo`;o
0000Foooool001cooooo00?o0000ooooooooool0I_ooool2o`0000?ooooo0_l000000ooooooo0000
o`000004ooooo`;o00002_ooool2o`0000Kooooo0_l000000ooooooo0000o`000003ooooo`;o0000
5oooool2o`0000?ooooo0_l0000looooo`;o0000Foooool001cooooo00?o0000ooooooooool0I_oo
ool2o`0000Oooooo0_l0000?ooooo`?o00000oooool2o`0000?ooooo0_l0000Looooo`;o00001?oo
ool2o`0009Sooooo000Looooo`03o`000?oooooooooo05kooooo0_l0000?ooooo`;o00000_ooool2
o`0000cooooo0_l00003ooooo`;o00005oooool2o`0000kooooo0_l000000ooooooo0000o`00002E
ooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o00004oooool2o`0000Cooooo0_l0000Goooo
o`;o00002oooool2o`0000Cooooo0_l00005ooooo`;o00001?ooool2o`0009Gooooo000Looooo`03
o`000?oooooooooo06kooooo0_l00009ooooo`;o00005oooool2o`0000_ooooo0_l00004ooooo`?o
000000Coooooo`000?l0003ooooo0_l0002Kooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5
ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0J_oo
ool6o`0002oooooo0_l00005ooooo`;o000000?oooooo`000?l000001oooool2o`0000oooooo0ol0
00000ooooooo0000o`000020ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0Eoooool2o`00017o
oooo1Ol00008ooooo`;o00007?ooool2o`0001Kooooo0_l00003ooooo`;o00002?ooool2o`0000Go
oooo0ol000000ooooooo0000o`000020ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooo
ooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`1Gooooo`;o
00004_ooool2o`0000Sooooo1Ol0000Hooooo`Go00005_ooool3o`0000cooooo0_l0002;ooooo`00
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb
<S801_ooool3o`0007Gooooo0_l000001?oooooo0000o`000?ooool2o`00017ooooo0_l00002oooo
o`?o00006Oooool3o`00023ooooo0_l0001fooooo`0000?oooooo`000?ooool00_ooool00ol0003o
ooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`1koooo
o`;o00004Oooool2o`0001oooooo0_l0000Pooooo`;o0000M_ooool00003ooooool@413ooooo00;o
oooo00?o410@ooooooooool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000oooo
ooooool0R_ooool3o`0000?ooooo0_l00004ooooo`;o00009oooool2o`0008Sooooo00001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oo
oooooooo07Sooooo0_l00002ooooo`;o00001_ooool5o`000003ooooool0003o000000?o000000?o
ooooo`000?l000001?ooool2o`0002Oooooo0_l00028ooooo`0000Koooooonk^k_lb<S;o0000oc8b
<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`1hooooo`;o
00000_ooool2o`000003ooooool0003o000000?ooooo1Ol00004ooooo`Go00008Oooool2o`0000[o
oooo0_l00028ooooo`007?ooool00ol0003oooooooooo`1nooooo`?o00001_ooool2o`0000Gooooo
1_l0000Oooooo`;o00007Oooool2o`0007Gooooo000Looooo`03o`000?oooooooooo07kooooo0_l0
0007ooooo`;o00002Oooool2o`0003kooooo0_l00006ooooo`;o0000KOooool001cooooo00?o0000
ooooooooool0QOooool2o`0000gooooo0_l0000hooooo`;o00002_ooool2o`0006gooooo000Loooo
o`03o`000?oooooooooo07Kooooo0_l0000=ooooo`;o00003Oooool2o`0003Sooooo0_l0001ioooo
o`007?ooool00ol0003oooooooooo`1cooooo`;o000000?oooooo`000?l000002Oooool2o`000<Ko
oooo000Looooo`03o`000?oooooooooo077ooooo1_l00007ooooo`Go00004Oooool2o`0000Cooooo
0_l0000Yooooo`;o0000P_ooool001cooooo00?o0000ooooooooool0LOooool2o`0000;ooooo0_l0
0007ooooo`?o00004?ooool2o`000003ooooool0003o000000Cooooo0_l0000Vooooo`;o000000?o
ooooo`000?l00000P_ooool001cooooo00?o0000ooooooooool0I?ooool2o`0002Cooooo0_l00005
ooooo`;o000000?oooooo`000?l000005oooool2o`0001?ooooo0_l00025ooooo`007?ooool00ol0
003oooooooooo`1Tooooo`;o00009?ooool2o`0000Gooooo0_l0000Jooooo`;o00002?ooool2o`00
093ooooo000Looooo`03o`000?oooooooooo08Sooooo0_l0000]ooooo`?o00002?ooool2o`0008Go
oooo000Looooo`03o`000?oooooooooo08Sooooo0_l00003ooooo`;o00006oooool2o`0000cooooo
1?l00006ooooo`;o0000QOooool001cooooo0_l0001nooooo`;o00003Oooool3o`0001_ooooo0_l0
000>ooooo`;o0000SOooool001cooooo00?o0000ooooooooool0OOooool2o`0000gooooo0_l0000D
ooooo`;o0000YOooool001cooooo00?o0000ooooooooool0X_ooool2o`000:Gooooo000Looooo`03
o`000?oooooooooo08gooooo0_l00005ooooo`;o0000/oooool001cooooo00?o0000ooooooooool0
P_ooool2o`0000;ooooo0_l00005ooooo`;o00001Oooool2o`000;?ooooo000Looooo`03o`000?oo
oooooooo08;ooooo1_l0000Eooooo`;o0000Z_ooool001cooooo00?o0000ooooooooool0Q?ooool2
o`00017ooooo0_l00004ooooo`;o0000Z_ooool001cooooo00?o0000ooooooooool0Uoooool2o`00
0;3ooooo000Looooo`03o`000?oooooooooo07?ooooo0_l0003Dooooo`007?ooool00ol0003ooooo
ooooo`1cooooo`;o0000e?ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0Z_ooool2o`0009gooooo000Looooo`03o`000?oooooooooo0:[ooooo
0_l0002Mooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo
00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000D
ooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBoooo
o`004_ooool00omEEEGoIVIVo`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo002Uooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05Oooool0
1?l@413o0000odA4A?o<c<`4ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8b
o`000?l@413oc<c<093ooooo002Vooooo`05o`000?ooooooooooooooool000002Oooool6o`0000_o
oooo00?oV9RHoa0@4?oMgMd00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoEEEEogMg
MoooooooV9RHob4Q8@2@ooooo`00Y_ooool01Ol0003ooooooooooooooooo000001_ooooo00?oQhN7
oeEEEOooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go0000oooooooooooooooo
o`00002@ooooo`00Y_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l00009ooooo`05olc<
c?lQ8B7o0000oeEEEOl000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oiRH
V?ooooooV9RHob4Q8@2@ooooo`00Y_ooool01Ol0003oQhN7oooooonYZJWo000001Sooooo00Go8B4Q
ohN7QoooooooV9RHo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003oEEEE
o`000?l@413oc<c<093ooooo002Uooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool0
5_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@4003oooo
o`03oeEEEOn7QhOooooo09;ooooo0033ooooo`05ob4Q8OnHV9SoooooogMgMomEEED00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00?ogMgMoa0@4?nHV9P0T_ooool00<?ooooo00Goc<c<oa0@
4?l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool01?o<c<coA4A4o`00
0?l@412@ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(912) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.33501 .38122 Mdot
.37536 .39313 Mdot
.56667 .6292 Mdot
.57459 .44307 Mdot
.40547 .44861 Mdot
.54153 .65867 Mdot
.34355 .54188 Mdot
.3341 .58794 Mdot
.54265 .64062 Mdot
.64397 .46121 Mdot
.34041 .57777 Mdot
.50242 .42682 Mdot
.36104 .56368 Mdot
.57383 .42551 Mdot
.85471 .55004 Mdot
.57625 .33738 Mdot
.39981 .40589 Mdot
.70133 .64263 Mdot
.52991 .46022 Mdot
.55319 .68171 Mdot
.39048 .44331 Mdot
.5818 .42611 Mdot
.3304 .39128 Mdot
.57395 .4248 Mdot
.55122 .4414 Mdot
.34916 .39493 Mdot
.40185 .3754 Mdot
.54252 .44883 Mdot
.53401 .40824 Mdot
.36123 .5908 Mdot
.71221 .55414 Mdot
.83662 .42738 Mdot
.54063 .34522 Mdot
.25449 .31504 Mdot
.32484 .57848 Mdot
.67321 .28668 Mdot
.51455 .63877 Mdot
.37211 .56691 Mdot
.33226 .58471 Mdot
.32008 .58414 Mdot
.36726 .57416 Mdot
.3555 .3998 Mdot
.39261 .58933 Mdot
.39177 .54026 Mdot
.61404 .39983 Mdot
.27135 .523 Mdot
.74743 .40093 Mdot
.55197 .37658 Mdot
.38215 .3836 Mdot
.54568 .68787 Mdot
.24509 .36187 Mdot
.35719 .60261 Mdot
.46864 .71566 Mdot
.7228 .19695 Mdot
.36791 .55273 Mdot
.61223 .41817 Mdot
.52397 .64335 Mdot
.5863 .40598 Mdot
.57637 .41847 Mdot
.44198 .35166 Mdot
.52718 .42614 Mdot
.67366 .61512 Mdot
.35409 .44414 Mdot
.49655 .67957 Mdot
.53908 .65246 Mdot
.33938 .58698 Mdot
.39498 .40905 Mdot
.35557 .55725 Mdot
.58431 .46198 Mdot
.50407 .66364 Mdot
.55307 .37629 Mdot
.3503 .58544 Mdot
.31799 .39733 Mdot
.5747 .3683 Mdot
.25548 .6475 Mdot
.79124 .65635 Mdot
.70725 .60776 Mdot
.46418 .3331 Mdot
.54018 .30518 Mdot
.66306 .75478 Mdot
.54756 .41313 Mdot
.51691 .84473 Mdot
.8373 .57885 Mdot
.33835 .38048 Mdot
.63969 .42196 Mdot
.5329 .59594 Mdot
.58646 .37189 Mdot
.46555 .49071 Mdot
.61713 .43025 Mdot
.22629 .58794 Mdot
.54103 .63589 Mdot
.37408 .41342 Mdot
.57386 .4421 Mdot
.52519 .38482 Mdot
.41338 .26736 Mdot
.52086 .4361 Mdot
.56632 .45336 Mdot
.35598 .35978 Mdot
.3284 .56705 Mdot
.50103 .37692 Mdot
.35424 .51436 Mdot
.44107 .724 Mdot
.60795 .40173 Mdot
.52455 .6251 Mdot
.34706 .36098 Mdot
.59563 .37633 Mdot
.32682 .54083 Mdot
.53833 .39008 Mdot
.40117 .56549 Mdot
.38051 .39275 Mdot
.5265 .38151 Mdot
.66683 .64679 Mdot
.31556 .74246 Mdot
.37132 .41738 Mdot
.41753 .71653 Mdot
.53296 .38815 Mdot
.59199 .42023 Mdot
.37365 .39508 Mdot
.54456 .67262 Mdot
.53843 .5222 Mdot
.39019 .3824 Mdot
.31745 .57691 Mdot
.40331 .41616 Mdot
.64083 .39104 Mdot
.55146 .64167 Mdot
.44565 .71298 Mdot
.45641 .70403 Mdot
.66408 .52534 Mdot
.59139 .3771 Mdot
.24968 .42936 Mdot
.54402 .66468 Mdot
.37061 .40903 Mdot
.35446 .56077 Mdot
.61549 .38017 Mdot
.36297 .42662 Mdot
.34025 .56532 Mdot
.64218 .62788 Mdot
.6031 .67215 Mdot
.38069 .37812 Mdot
.37034 .62591 Mdot
.31929 .59171 Mdot
.31431 .57686 Mdot
.24341 .33505 Mdot
.37213 .38835 Mdot
.68209 .63817 Mdot
.34174 .55904 Mdot
.76359 .5103 Mdot
.6094 .43028 Mdot
.62256 .52182 Mdot
.40354 .83639 Mdot
.23218 .37117 Mdot
.3588 .70736 Mdot
.70377 .63021 Mdot
.30925 .56757 Mdot
.54058 .42673 Mdot
.36315 .38262 Mdot
.35978 .38934 Mdot
.56513 .45942 Mdot
.55911 .44712 Mdot
.55935 .37175 Mdot
.52593 .38707 Mdot
.77845 .43446 Mdot
.54552 .37065 Mdot
.67735 .58841 Mdot
.36053 .41773 Mdot
.53751 .43649 Mdot
.55142 .67356 Mdot
.5827 .35181 Mdot
.36109 .58147 Mdot
.58654 .41706 Mdot
.57104 .44655 Mdot
.52706 .37446 Mdot
.36617 .54516 Mdot
.81147 .40341 Mdot
.38006 .81676 Mdot
.68035 .25095 Mdot
.39948 .71208 Mdot
.52061 .6617 Mdot
.59965 .39324 Mdot
.67275 .62983 Mdot
.60065 .26837 Mdot
.5585 .41295 Mdot
.15759 .52047 Mdot
.57356 .44964 Mdot
.34212 .25172 Mdot
.48145 .36482 Mdot
.67804 .24133 Mdot
.60686 .56873 Mdot
.53068 .4066 Mdot
.43308 .23937 Mdot
.50599 .19802 Mdot
.41064 .54302 Mdot
.36799 .56947 Mdot
.5544 .67043 Mdot
.52623 .63541 Mdot
.35792 .60689 Mdot
.51771 .34692 Mdot
.48109 .40549 Mdot
.53113 .47503 Mdot
.45409 .71351 Mdot
.31763 .40815 Mdot
.67078 .60494 Mdot
.33847 .36722 Mdot
.62091 .83647 Mdot
.21535 .55338 Mdot
.39274 .5969 Mdot
.67534 .59854 Mdot
.56829 .63809 Mdot
.45688 .71336 Mdot
.66923 .63391 Mdot
.55781 .39154 Mdot
.38844 .39392 Mdot
.36185 .21667 Mdot
.54209 .32199 Mdot
.37429 .19445 Mdot
.36691 .43215 Mdot
.52515 .52677 Mdot
.34759 .57208 Mdot
.57173 .66033 Mdot
.59079 .42949 Mdot
.57119 .38207 Mdot
.35609 .45071 Mdot
.55338 .37858 Mdot
.36556 .46196 Mdot
.58392 .44533 Mdot
.58564 .63575 Mdot
.71306 .61331 Mdot
.36081 .60629 Mdot
.65335 .5292 Mdot
.3237 .39814 Mdot
.58012 .59422 Mdot
.5269 .68563 Mdot
.62029 .27865 Mdot
.34598 .58438 Mdot
.65559 .64286 Mdot
.52953 .68324 Mdot
.67999 .60405 Mdot
.56901 .35284 Mdot
.51045 .64434 Mdot
.69653 .62514 Mdot
.80084 .43325 Mdot
.61372 .38521 Mdot
.7894 .47437 Mdot
.33932 .54371 Mdot
.40259 .41903 Mdot
.52883 .43079 Mdot
.44088 .70724 Mdot
.52632 .36236 Mdot
.31328 .66159 Mdot
.46701 .70598 Mdot
.46722 .72575 Mdot
.70176 .72451 Mdot
.67659 .6461 Mdot
.3186 .70323 Mdot
.23671 .42056 Mdot
.39884 .40399 Mdot
.59769 .43574 Mdot
.73431 .28916 Mdot
.34229 .5597 Mdot
.55624 .39572 Mdot
.56315 .60153 Mdot
.3429 .55639 Mdot
.58738 .40076 Mdot
.35026 .53605 Mdot
.36384 .38673 Mdot
.50785 .77994 Mdot
.39965 .41149 Mdot
.61599 .3935 Mdot
.33316 .53984 Mdot
.51479 .6698 Mdot
.34671 .39211 Mdot
.54161 .3904 Mdot
.59657 .42192 Mdot
.45005 .72049 Mdot
.53069 .42322 Mdot
.74182 .30896 Mdot
.52383 .40602 Mdot
.55403 .62044 Mdot
.52249 .435 Mdot
.16407 .47226 Mdot
.56405 .71749 Mdot
.39505 .40633 Mdot
.46727 .72379 Mdot
.53741 .64316 Mdot
.62656 .74557 Mdot
.42253 .58435 Mdot
.53954 .402 Mdot
.45372 .73013 Mdot
.59921 .55288 Mdot
.36907 .59142 Mdot
.53178 .45419 Mdot
.23634 .56661 Mdot
.5466 .68128 Mdot
.4553 .71581 Mdot
.5674 .48029 Mdot
.34352 .36125 Mdot
.57216 .44332 Mdot
.50983 .66744 Mdot
.40517 .41298 Mdot
.59802 .36477 Mdot
.71125 .38949 Mdot
.46381 .70555 Mdot
.34264 .5441 Mdot
.46246 .39787 Mdot
.55183 .37114 Mdot
.51697 .64285 Mdot
.32884 .41081 Mdot
.32056 .57359 Mdot
.3508 .40433 Mdot
.43274 .19407 Mdot
.3907 .72493 Mdot
.76194 .3931 Mdot
.66746 .59751 Mdot
.36551 .66106 Mdot
.65664 .22493 Mdot
.33725 .7335 Mdot
.72933 .50081 Mdot
.52026 .16361 Mdot
.53669 .67956 Mdot
.61015 .64009 Mdot
.53183 .64506 Mdot
.55513 .429 Mdot
.54136 .65515 Mdot
.67581 .23405 Mdot
.57934 .44906 Mdot
.51816 .65468 Mdot
.5569 .76407 Mdot
.55084 .44748 Mdot
.37065 .41917 Mdot
.84923 .54398 Mdot
.22771 .64502 Mdot
.19552 .46703 Mdot
.52754 .67185 Mdot
.45039 .38234 Mdot
.54479 .44893 Mdot
.55602 .34465 Mdot
.35627 .37993 Mdot
.533 .45133 Mdot
.6699 .60586 Mdot
.66724 .6015 Mdot
.60588 .52571 Mdot
.43502 .8171 Mdot
.49772 .38397 Mdot
.34799 .3887 Mdot
.58809 .29396 Mdot
.25432 .63415 Mdot
.43361 .72476 Mdot
.34672 .51972 Mdot
.81795 .42088 Mdot
.49323 .37225 Mdot
.35946 .62441 Mdot
.24501 .58591 Mdot
.38528 .40495 Mdot
.77656 .36726 Mdot
.3682 .56172 Mdot
.49346 .23953 Mdot
.34118 .2923 Mdot
.56701 .38701 Mdot
.33914 .58117 Mdot
.49562 .40889 Mdot
.20504 .5783 Mdot
.77854 .53226 Mdot
.67816 .77858 Mdot
.61472 .39371 Mdot
.29803 .68729 Mdot
.58917 .41986 Mdot
.55295 .51615 Mdot
.52344 .40677 Mdot
.3455 .40336 Mdot
.66025 .4086 Mdot
.435 .50891 Mdot
.42748 .83067 Mdot
.21028 .53935 Mdot
.70369 .62701 Mdot
.5939 .42331 Mdot
.56853 .38685 Mdot
.65795 .63909 Mdot
.3343 .40249 Mdot
.52591 .39455 Mdot
.68708 .45491 Mdot
.56283 .37563 Mdot
.36913 .57587 Mdot
.65679 .55415 Mdot
.35465 .4571 Mdot
.52104 .38483 Mdot
.4046 .39994 Mdot
.36157 .54322 Mdot
.34045 .58966 Mdot
.61985 .43935 Mdot
.31633 .54563 Mdot
.57875 .44412 Mdot
.75132 .59916 Mdot
.35128 .37228 Mdot
.53552 .32158 Mdot
.33496 .41083 Mdot
.50971 .31711 Mdot
.33032 .53816 Mdot
.44486 .70735 Mdot
.29386 .36573 Mdot
.36611 .56065 Mdot
.20721 .43755 Mdot
.51195 .4625 Mdot
.50797 .39501 Mdot
.19949 .54965 Mdot
.52616 .67493 Mdot
.45397 .70694 Mdot
.32024 .54602 Mdot
.55379 .37064 Mdot
.5135 .43204 Mdot
.37551 .56643 Mdot
.44776 .27186 Mdot
.63249 .73539 Mdot
.55168 .45267 Mdot
.34078 .40235 Mdot
.36769 .4093 Mdot
.59183 .36443 Mdot
.54471 .39825 Mdot
.56046 .63039 Mdot
.4654 .72059 Mdot
.44148 .73132 Mdot
.45773 .70473 Mdot
.57907 .6256 Mdot
.31304 .49151 Mdot
.31846 .58231 Mdot
.26687 .45162 Mdot
.28529 .62675 Mdot
.58532 .3246 Mdot
.51274 .65261 Mdot
.57556 .3918 Mdot
.57949 .43767 Mdot
.31957 .57187 Mdot
.38687 .67787 Mdot
.64218 .41216 Mdot
.36487 .37151 Mdot
.32281 .54006 Mdot
.48939 .41118 Mdot
.30089 .45264 Mdot
.68747 .61411 Mdot
.19142 .47327 Mdot
.34577 .58611 Mdot
.38529 .41107 Mdot
.37019 .54105 Mdot
.56774 .38171 Mdot
.59016 .45122 Mdot
.37837 .40005 Mdot
.68903 .64469 Mdot
.58092 .47135 Mdot
.58895 .40015 Mdot
.19638 .67255 Mdot
.25739 .65375 Mdot
.29283 .5877 Mdot
.53476 .4182 Mdot
.50872 .41815 Mdot
.70192 .61561 Mdot
.5632 .37878 Mdot
.59809 .42262 Mdot
.32297 .75613 Mdot
.28633 .57564 Mdot
.69805 .64693 Mdot
.50183 .23986 Mdot
.36901 .43206 Mdot
.77585 .34364 Mdot
.44326 .73007 Mdot
.38315 .59054 Mdot
.49073 .77536 Mdot
.46029 .71523 Mdot
.32095 .65832 Mdot
.77823 .35794 Mdot
.45694 .70535 Mdot
.53128 .58893 Mdot
.64501 .42771 Mdot
.56311 .45626 Mdot
.59107 .41351 Mdot
.67921 .62878 Mdot
.36995 .38712 Mdot
.56952 .55172 Mdot
.79405 .55915 Mdot
.58567 .42493 Mdot
.41834 .41513 Mdot
.81433 .44888 Mdot
.45353 .72038 Mdot
.6601 .61217 Mdot
.63485 .6256 Mdot
.59407 .41687 Mdot
.35489 .76903 Mdot
.34949 .39302 Mdot
.54158 .39092 Mdot
.54542 .36696 Mdot
.52398 .67057 Mdot
.39144 .40197 Mdot
.52071 .6826 Mdot
.46477 .70283 Mdot
.54778 .19548 Mdot
.17188 .63388 Mdot
.31885 .56316 Mdot
.7113 .29605 Mdot
.36231 .59446 Mdot
.70499 .74475 Mdot
.46313 .71225 Mdot
.55231 .41201 Mdot
.3222 .39904 Mdot
.53914 .38812 Mdot
.56201 .39921 Mdot
.55929 .39139 Mdot
.50324 .44959 Mdot
.15886 .51087 Mdot
.66101 .62591 Mdot
.62201 .35506 Mdot
.54924 .62041 Mdot
.72893 .30544 Mdot
.81452 .58928 Mdot
.57856 .385 Mdot
.59816 .41237 Mdot
.36723 .42255 Mdot
.55932 .46012 Mdot
.37356 .58387 Mdot
.32809 .41029 Mdot
.53154 .36925 Mdot
.76723 .36282 Mdot
.52798 .38934 Mdot
.65907 .23474 Mdot
.37218 .54292 Mdot
.20645 .44266 Mdot
.62849 .36758 Mdot
.45208 .70489 Mdot
.45433 .70672 Mdot
.45266 .7375 Mdot
.37637 .54275 Mdot
.51666 .64826 Mdot
.77684 .62144 Mdot
.54207 .33809 Mdot
.54311 .43067 Mdot
.51172 .43004 Mdot
.55032 .60503 Mdot
.46376 .48535 Mdot
.34239 .71287 Mdot
.48995 .4204 Mdot
.55919 .6403 Mdot
.40246 .42127 Mdot
.45913 .68704 Mdot
.32784 .40682 Mdot
.70275 .64473 Mdot
.34355 .57872 Mdot
.68081 .6096 Mdot
.22225 .39842 Mdot
.37848 .39324 Mdot
.35209 .45074 Mdot
.51914 .65943 Mdot
.50256 .52885 Mdot
.69838 .19449 Mdot
.50156 .65838 Mdot
.68356 .49607 Mdot
.34972 .38146 Mdot
.54203 .3656 Mdot
.62402 .55522 Mdot
.49372 .5225 Mdot
.52467 .65494 Mdot
.55942 .42023 Mdot
.40771 .79545 Mdot
.56151 .63201 Mdot
.53098 .45424 Mdot
.55039 .66577 Mdot
.35913 .57993 Mdot
.54534 .66654 Mdot
.32866 .4179 Mdot
.59898 .38205 Mdot
.72393 .20934 Mdot
.59113 .58516 Mdot
.5256 .41088 Mdot
.32416 .53937 Mdot
.68416 .42495 Mdot
.56995 .40264 Mdot
.66214 .60601 Mdot
.55339 .64195 Mdot
.64807 .71075 Mdot
.53802 .44434 Mdot
.53364 .66457 Mdot
.3308 .3865 Mdot
.38142 .55081 Mdot
.71945 .7169 Mdot
.44055 .71469 Mdot
.36141 .37838 Mdot
.47152 .70166 Mdot
.33846 .52874 Mdot
.51248 .42612 Mdot
.55067 .36697 Mdot
.35103 .41168 Mdot
.50737 .7999 Mdot
.52586 .43541 Mdot
.54788 .4133 Mdot
.57193 .64194 Mdot
.54303 .60678 Mdot
.52239 .79142 Mdot
.53289 .67975 Mdot
.53903 .46681 Mdot
.35084 .41083 Mdot
.57125 .43791 Mdot
.37679 .41952 Mdot
.59389 .43809 Mdot
.38498 .35281 Mdot
.34139 .37841 Mdot
.40355 .76129 Mdot
.56455 .42969 Mdot
.47282 .37806 Mdot
.56147 .39463 Mdot
.55719 .37637 Mdot
.54963 .62536 Mdot
.65358 .62506 Mdot
.62155 .38032 Mdot
.62465 .6082 Mdot
.65454 .6129 Mdot
.45634 .19782 Mdot
.52721 .67314 Mdot
.6853 .62331 Mdot
.79387 .46435 Mdot
.46426 .72787 Mdot
.66995 .62459 Mdot
.82389 .57329 Mdot
.31877 .56636 Mdot
.38061 .4333 Mdot
.55106 .44715 Mdot
.49969 .16529 Mdot
.7455 .57274 Mdot
.45109 .72662 Mdot
.52478 .40656 Mdot
.57463 .39573 Mdot
.37925 .36894 Mdot
.58236 .84687 Mdot
.56411 .62272 Mdot
.55438 .43291 Mdot
.3933 .41624 Mdot
.44025 .85606 Mdot
.53532 .62169 Mdot
.67299 .62678 Mdot
.37556 .56017 Mdot
.35735 .35383 Mdot
.43932 .71606 Mdot
.37276 .58837 Mdot
.45781 .75573 Mdot
.20604 .42984 Mdot
.53309 .38657 Mdot
.5119 .6488 Mdot
.21549 .3896 Mdot
.51954 .34932 Mdot
.30713 .60356 Mdot
.52926 .48998 Mdot
.38402 .40788 Mdot
.37452 .56712 Mdot
.69293 .61295 Mdot
.32908 .41505 Mdot
.33538 .40018 Mdot
.33168 .58802 Mdot
.48719 .66037 Mdot
.51942 .52613 Mdot
.36532 .58193 Mdot
.23326 .59261 Mdot
.38835 .20839 Mdot
.46156 .72712 Mdot
.64881 .62188 Mdot
.30049 .27718 Mdot
.35479 .40018 Mdot
.81655 .41725 Mdot
.18721 .44693 Mdot
.56567 .45339 Mdot
.69043 .63091 Mdot
.29072 .53058 Mdot
.7897 .59891 Mdot
.34286 .55297 Mdot
.4254 .48973 Mdot
.63776 .63702 Mdot
.54447 .45209 Mdot
.40044 .35039 Mdot
.55438 .42317 Mdot
.34416 .57527 Mdot
.5127 .32387 Mdot
.38491 .41232 Mdot
.32927 .53172 Mdot
.19092 .46978 Mdot
.58368 .43678 Mdot
.56025 .42407 Mdot
.68739 .54755 Mdot
.38711 .39049 Mdot
.43861 .72726 Mdot
.53506 .3957 Mdot
.58784 .40782 Mdot
.51214 .39912 Mdot
.47221 .39664 Mdot
.32749 .74739 Mdot
.55627 .43269 Mdot
.5748 .6644 Mdot
.54614 .34807 Mdot
.56661 .42844 Mdot
.40352 .39763 Mdot
.17003 .61503 Mdot
.44916 .70329 Mdot
.58719 .4144 Mdot
.53146 .38633 Mdot
.32527 .58176 Mdot
.56484 .54321 Mdot
.48324 .51909 Mdot
.50745 .6442 Mdot
.74981 .48239 Mdot
.50314 .44886 Mdot
.36323 .4284 Mdot
.65115 .64216 Mdot
.57594 .36048 Mdot
.36943 .42698 Mdot
.58077 .3447 Mdot
.56156 .63741 Mdot
.46314 .72461 Mdot
.20496 .48161 Mdot
.6752 .6204 Mdot
.72724 .57456 Mdot
.26422 .46974 Mdot
.55768 .66827 Mdot
.54482 .43536 Mdot
.37686 .59264 Mdot
.50875 .64509 Mdot
.44816 .72091 Mdot
.61065 .45952 Mdot
.35669 .38763 Mdot
.37184 .41548 Mdot
.61558 .53286 Mdot
.55648 .6967 Mdot
.26942 .74087 Mdot
.35705 .58038 Mdot
.54937 .3501 Mdot
.24019 .42638 Mdot
.37206 .41631 Mdot
.62598 .53362 Mdot
.68516 .62192 Mdot
.34258 .55134 Mdot
.43645 .73334 Mdot
.36712 .42509 Mdot
.38552 .3843 Mdot
.61077 .37925 Mdot
.58677 .38596 Mdot
.7212 .50254 Mdot
.61228 .52741 Mdot
.36985 .55141 Mdot
.65012 .63353 Mdot
.51383 .68115 Mdot
.54933 .42437 Mdot
.33606 .38278 Mdot
.3549 .22828 Mdot
.53345 .38028 Mdot
.56036 .62894 Mdot
.38152 .40692 Mdot
.66236 .64199 Mdot
.66028 .60801 Mdot
.55784 .3768 Mdot
.45805 .35086 Mdot
.35816 .54657 Mdot
.37291 .41807 Mdot
.26734 .3629 Mdot
.52333 .43141 Mdot
.58959 .38424 Mdot
.55498 .48563 Mdot
.35242 .59322 Mdot
.20987 .44273 Mdot
.68114 .64877 Mdot
.36302 .39547 Mdot
.52849 .39824 Mdot
.67458 .6156 Mdot
.22573 .42822 Mdot
.46114 .72031 Mdot
.54913 .66435 Mdot
.66411 .60523 Mdot
.67536 .64186 Mdot
.64509 .62244 Mdot
.82449 .43363 Mdot
.31667 .40306 Mdot
.6001 .30271 Mdot
.52336 .41721 Mdot
.61611 .53471 Mdot
.62192 .41114 Mdot
.37727 .54952 Mdot
.52613 .6766 Mdot
.56448 .3962 Mdot
.61053 .3796 Mdot
.47228 .42716 Mdot
.50669 .3447 Mdot
.40847 .42991 Mdot
.38483 .39511 Mdot
.5753 .32688 Mdot
.52076 .67014 Mdot
.58503 .85502 Mdot
.69296 .21677 Mdot
.63568 .39026 Mdot
.53928 .53633 Mdot
.33142 .39042 Mdot
.33369 .59124 Mdot
.46857 .51752 Mdot
.35922 .53555 Mdot
.36558 .4007 Mdot
.5518 .4267 Mdot
.2718 .45656 Mdot
.68887 .60403 Mdot
.55725 .37014 Mdot
.34571 .56734 Mdot
.55811 .37085 Mdot
.3762 .57586 Mdot
.29336 .41401 Mdot
.24133 .60575 Mdot
.57318 .45007 Mdot
.51691 .42044 Mdot
.45919 .41985 Mdot
.57983 .38739 Mdot
.56839 .82178 Mdot
.33144 .39952 Mdot
.42103 .80509 Mdot
.60069 .36543 Mdot
.49528 .30723 Mdot
.52384 .42476 Mdot
.46262 .78846 Mdot
.58473 .37859 Mdot
.45384 .54384 Mdot
.55815 .45496 Mdot
.60321 .40472 Mdot
.33947 .53807 Mdot
.32582 .58221 Mdot
.34366 .37057 Mdot
.43715 .72362 Mdot
.691 .26056 Mdot
.59023 .39443 Mdot
.58229 .64014 Mdot
.32468 .61823 Mdot
.66378 .64002 Mdot
.36303 .40146 Mdot
.4525 .86688 Mdot
.3538 .53778 Mdot
.50882 .68715 Mdot
.51405 .80658 Mdot
.56444 .67195 Mdot
.30355 .53232 Mdot
.60427 .49533 Mdot
.68601 .64433 Mdot
.53757 .44755 Mdot
.2622 .31438 Mdot
.26474 .65071 Mdot
.6009 .46312 Mdot
.33448 .53151 Mdot
.60021 .27384 Mdot
.30193 .27873 Mdot
.63977 .61599 Mdot
.69954 .62169 Mdot
.35088 .53939 Mdot
.57494 .6446 Mdot
.51875 .46182 Mdot
.68592 .62089 Mdot
.56295 .65549 Mdot
.459 .73541 Mdot
.42811 .54631 Mdot
.35251 .39464 Mdot
.19367 .47473 Mdot
.25724 .50925 Mdot
.36801 .54781 Mdot
.6042 .61885 Mdot
.37745 .35377 Mdot
.32383 .37025 Mdot
.43792 .71423 Mdot
.54915 .62431 Mdot
.32206 .40943 Mdot
.54899 .4697 Mdot
.51435 .33515 Mdot
.58682 .42123 Mdot
.6791 .63414 Mdot
.5792 .37883 Mdot
.55435 .62892 Mdot
.34669 .55575 Mdot
.53469 .62805 Mdot
.34315 .53957 Mdot
.30164 .48583 Mdot
.54684 .3905 Mdot
.60195 .40403 Mdot
.74216 .57802 Mdot
.35473 .36641 Mdot
.2476 .36477 Mdot
.58369 .62803 Mdot
.52767 .64274 Mdot
.59457 .43316 Mdot
.32616 .39928 Mdot
.72 .61833 Mdot
.74189 .58317 Mdot
.56138 .36488 Mdot
.331 .40042 Mdot
.54854 .43117 Mdot
.79285 .44201 Mdot
.24854 .66089 Mdot
.35449 .40775 Mdot
.45573 .83187 Mdot
.53822 .41511 Mdot
.65455 .37486 Mdot
.51406 .43589 Mdot
.69659 .46267 Mdot
.52498 .43565 Mdot
.36598 .43234 Mdot
.58427 .4184 Mdot
.33439 .41921 Mdot
.569 .6548 Mdot
.32934 .59143 Mdot
.35616 .37652 Mdot
.5556 .36296 Mdot
.82237 .38993 Mdot
.34909 .57707 Mdot
.59253 .42527 Mdot
.32863 .56218 Mdot
.38813 .42403 Mdot
.37727 .37882 Mdot
.79283 .61366 Mdot
.28985 .59181 Mdot
.36054 .57848 Mdot
.55764 .43813 Mdot
.2363 .50875 Mdot
.56567 .43562 Mdot
.71058 .50896 Mdot
.61025 .39061 Mdot
.5232 .43458 Mdot
.78791 .67171 Mdot
.36458 .59537 Mdot
.279 .74418 Mdot
.79781 .54215 Mdot
.82772 .44669 Mdot
.32962 .35935 Mdot
.63938 .61645 Mdot
.78383 .37545 Mdot
.46625 .70453 Mdot
.5517 .65458 Mdot
.56444 .39484 Mdot
.30574 .42186 Mdot
.37272 .56766 Mdot
.65468 .62773 Mdot
.57461 .44953 Mdot
.55699 .62567 Mdot
.69042 .71402 Mdot
.30935 .55994 Mdot
.35634 .4 Mdot
.36319 .36961 Mdot
.41746 .84146 Mdot
.52786 .39766 Mdot
.59872 .41616 Mdot
.34259 .57674 Mdot
.50822 .35026 Mdot
.6611 .64402 Mdot
.5513 .75567 Mdot
.36024 .57793 Mdot
.50804 .56183 Mdot
.37898 .38971 Mdot
.5747 .39375 Mdot
.4789 .49126 Mdot
.42221 .61991 Mdot
.49902 .21751 Mdot
.6759 .63036 Mdot
.71388 .52023 Mdot
.36652 .43234 Mdot
.35108 .5621 Mdot
.61235 .66642 Mdot
.53422 .35501 Mdot
.57736 .39951 Mdot
.71215 .52424 Mdot
.58464 .55171 Mdot
.72111 .60714 Mdot
.57794 .45922 Mdot
.58473 .5485 Mdot
.59992 .42754 Mdot
.51482 .39014 Mdot
.56963 .4663 Mdot
.59262 .3815 Mdot
.33056 .39739 Mdot
.47798 .42648 Mdot
.54099 .66441 Mdot
.42116 .26203 Mdot
.43788 .49446 Mdot
.53068 .43084 Mdot
.55739 .42919 Mdot
.54902 .23015 Mdot
.29652 .6155 Mdot
.33657 .39016 Mdot
.33572 .43074 Mdot
.31448 .55095 Mdot
.47136 .37873 Mdot
.57025 .62185 Mdot
.50368 .46611 Mdot
.53828 .62781 Mdot
.33057 .40499 Mdot
.52441 .63939 Mdot
.31128 .56285 Mdot
.5117 .64872 Mdot
.58051 .62657 Mdot
.37457 .57372 Mdot
.3742 .38232 Mdot
.57106 .36905 Mdot
.32154 .54195 Mdot
.68994 .54583 Mdot
.6799 .63321 Mdot
.79423 .61192 Mdot
.56027 .34738 Mdot
.41553 .47048 Mdot
.71212 .39149 Mdot
.53414 .62991 Mdot
.26908 .6999 Mdot
.3428 .37734 Mdot
.70308 .60991 Mdot
.32911 .40198 Mdot
.17638 .47048 Mdot
.65096 .62737 Mdot
.82666 .5685 Mdot
.48954 .70941 Mdot
.68911 .6985 Mdot
.58819 .45488 Mdot
.3705 .34526 Mdot
.50644 .66478 Mdot
.37269 .56579 Mdot
.47931 .72547 Mdot
.60418 .39545 Mdot
.34673 .73747 Mdot
.359 .36383 Mdot
.45648 .73444 Mdot
.35661 .55927 Mdot
.32359 .53636 Mdot
.5362 .38576 Mdot
.57505 .77466 Mdot
.60355 .3839 Mdot
.52739 .7109 Mdot
.73641 .50089 Mdot
.51394 .47677 Mdot
.58636 .44248 Mdot
.52403 .62725 Mdot
.54908 .43217 Mdot
.62683 .30111 Mdot
.24639 .33089 Mdot
.53899 .47363 Mdot
.39749 .73725 Mdot
.70376 .65347 Mdot
.37706 .39659 Mdot
.62664 .36662 Mdot
.44324 .7221 Mdot
.53604 .4162 Mdot
.24184 .27921 Mdot
.66944 .62215 Mdot
.58118 .60396 Mdot
.52049 .41242 Mdot
.53573 .39202 Mdot
.31548 .31473 Mdot
.3011 .41149 Mdot
.43609 .73393 Mdot
.57993 .40372 Mdot
.75598 .50177 Mdot
.33023 .57576 Mdot
.59762 .37375 Mdot
.59186 .41527 Mdot
.49407 .19506 Mdot
.34808 .59129 Mdot
.52992 .63135 Mdot
.46814 .71458 Mdot
.51898 .68477 Mdot
.64878 .64755 Mdot
.47249 .53131 Mdot
.62527 .52431 Mdot
.24873 .65683 Mdot
.63897 .62186 Mdot
.53271 .37588 Mdot
.64329 .4104 Mdot
.5367 .40608 Mdot
.69705 .61562 Mdot
.35736 .59114 Mdot
.34097 .38197 Mdot
.21056 .48688 Mdot
.45337 .71514 Mdot
.52867 .45186 Mdot
.67796 .60538 Mdot
.36093 .38364 Mdot
.58841 .59663 Mdot
.36986 .39533 Mdot
.36422 .56877 Mdot
.35919 .52648 Mdot
.65962 .61629 Mdot
.32961 .40795 Mdot
.55385 .68853 Mdot
.79128 .56458 Mdot
.61182 .40484 Mdot
.30256 .55418 Mdot
.32833 .3866 Mdot
.39964 .37476 Mdot
.34757 .36337 Mdot
.55104 .38215 Mdot
.54957 .53768 Mdot
.52086 .38017 Mdot
.35617 .54119 Mdot
.5568 .65824 Mdot
.62057 .5179 Mdot
.28894 .32167 Mdot
.5598 .5718 Mdot
.62129 .42138 Mdot
.58422 .43178 Mdot
.59392 .41717 Mdot
.6169 .41145 Mdot
.58982 .67965 Mdot
.54546 .39558 Mdot
.33959 .53874 Mdot
.54793 .63167 Mdot
.52575 .42191 Mdot
.44302 .72629 Mdot
.51182 .51913 Mdot
.64433 .63857 Mdot
.45382 .51932 Mdot
.77801 .33488 Mdot
.35962 .38219 Mdot
.52285 .68086 Mdot
.54934 .65656 Mdot
.64218 .62857 Mdot
.37141 .56428 Mdot
.36979 .39042 Mdot
.70771 .45273 Mdot
.64534 .62736 Mdot
.58564 .4146 Mdot
.47783 .76457 Mdot
.42266 .77409 Mdot
.5425 .45329 Mdot
.56262 .40672 Mdot
.46832 .72235 Mdot
.5753 .63557 Mdot
.42412 .16131 Mdot
.63186 .55838 Mdot
.65589 .62028 Mdot
.69608 .63626 Mdot
.3315 .3678 Mdot
.63856 .41117 Mdot
.34716 .54207 Mdot
.66679 .55708 Mdot
.67221 .45558 Mdot
.71096 .57497 Mdot
.70056 .74431 Mdot
.54603 .37363 Mdot
.35026 .31437 Mdot
.58065 .44127 Mdot
.36935 .36573 Mdot
.39645 .4064 Mdot
.34234 .38737 Mdot
.36457 .54946 Mdot
.52306 .30702 Mdot
.33055 .54151 Mdot
.74593 .28874 Mdot
.35307 .4315 Mdot
.61073 .69012 Mdot
.52044 .64537 Mdot
.59769 .34317 Mdot
.66863 .64456 Mdot
.33122 .5125 Mdot
.58203 .4629 Mdot
.34051 .75702 Mdot
.51292 .65107 Mdot
.37996 .38449 Mdot
.6106 .48937 Mdot
.61612 .20144 Mdot
.50099 .53283 Mdot
.60909 .32395 Mdot
.31298 .32945 Mdot
.65332 .63514 Mdot
.49542 .21959 Mdot
.69796 .64161 Mdot
.34081 .56097 Mdot
.60163 .39085 Mdot
.58878 .37351 Mdot
.59387 .43889 Mdot
.54688 .39422 Mdot
.31804 .57132 Mdot
.60326 .35852 Mdot
.16408 .47229 Mdot
.4649 .72511 Mdot
.79183 .42667 Mdot
.68669 .6162 Mdot
.35698 .53118 Mdot
.54499 .63055 Mdot
.44137 .73267 Mdot
.64396 .5265 Mdot
.55734 .45402 Mdot
.56255 .3959 Mdot
.43384 .7159 Mdot
.56279 .46458 Mdot
.49304 .43187 Mdot
.53954 .66328 Mdot
.56242 .57027 Mdot
.65636 .6056 Mdot
.68264 .61031 Mdot
.36088 .5875 Mdot
.32916 .40604 Mdot
.68261 .62537 Mdot
.57254 .64028 Mdot
.59348 .34898 Mdot
.55523 .36065 Mdot
.32902 .38486 Mdot
.18623 .44862 Mdot
.6342 .62258 Mdot
.6162 .48489 Mdot
.35211 .42877 Mdot
.31439 .39856 Mdot
.57663 .40222 Mdot
.54923 .48173 Mdot
.4048 .37708 Mdot
.65225 .61099 Mdot
.35401 .53008 Mdot
.68848 .68285 Mdot
.3417 .56843 Mdot
.36697 .38659 Mdot
.59309 .36257 Mdot
.3766 .3854 Mdot
.53209 .41477 Mdot
.8535 .63712 Mdot
.5866 .37429 Mdot
.21763 .62129 Mdot
.69473 .47963 Mdot
.54822 .65397 Mdot
.55323 .68853 Mdot
.44982 .73036 Mdot
.35668 .43056 Mdot
.57527 .35891 Mdot
.69645 .63794 Mdot
.82862 .49923 Mdot
.39659 .36134 Mdot
.56039 .64604 Mdot
.57376 .62654 Mdot
.36832 .59098 Mdot
.52177 .40569 Mdot
.57728 .39302 Mdot
.51358 .64372 Mdot
.72685 .39208 Mdot
.35636 .42488 Mdot
.59705 .41876 Mdot
.57675 .43257 Mdot
.54409 .65802 Mdot
.78932 .56805 Mdot
.30633 .36276 Mdot
.59974 .39092 Mdot
.63461 .65232 Mdot
.37741 .54775 Mdot
.61246 .42245 Mdot
.6046 .35997 Mdot
.6882 .63826 Mdot
.76174 .36951 Mdot
.25907 .30361 Mdot
.37647 .55145 Mdot
.43867 .72651 Mdot
.53213 .3723 Mdot
.52048 .64717 Mdot
.55405 .36218 Mdot
.67019 .27154 Mdot
.46023 .73066 Mdot
.54633 .4057 Mdot
.63514 .41184 Mdot
.39596 .39972 Mdot
.54197 .39604 Mdot
.54135 .21382 Mdot
.5031 .66904 Mdot
.54406 .40128 Mdot
.44343 .35707 Mdot
.34163 .58863 Mdot
.6352 .39176 Mdot
.69267 .61733 Mdot
.69679 .45638 Mdot
.26697 .48266 Mdot
.53971 .6023 Mdot
.68106 .61103 Mdot
.56694 .3661 Mdot
.57307 .65173 Mdot
.37238 .55326 Mdot
.332 .73311 Mdot
.58263 .4516 Mdot
.34545 .57555 Mdot
.34859 .55604 Mdot
.66895 .61636 Mdot
.31423 .7769 Mdot
.61113 .35688 Mdot
.57895 .38425 Mdot
.54894 .20956 Mdot
.39133 .3817 Mdot
.57594 .3754 Mdot
.53361 .37772 Mdot
.3329 .54422 Mdot
.29372 .3624 Mdot
.57296 .26264 Mdot
.55461 .7639 Mdot
.37794 .57202 Mdot
.49819 .63195 Mdot
.57135 .65557 Mdot
.68737 .618 Mdot
.37693 .40268 Mdot
.64493 .64291 Mdot
.53068 .67075 Mdot
.52906 .38924 Mdot
.33528 .5473 Mdot
.40177 .22541 Mdot
.35603 .60196 Mdot
.50856 .63238 Mdot
.38691 .36886 Mdot
.23574 .44384 Mdot
.19553 .34252 Mdot
.26545 .51058 Mdot
.39327 .58845 Mdot
.66462 .64023 Mdot
.47278 .748 Mdot
.57959 .43234 Mdot
.48398 .2286 Mdot
.56471 .37032 Mdot
.39233 .33844 Mdot
.53809 .67695 Mdot
.43614 .71632 Mdot
.60055 .38918 Mdot
.73012 .51229 Mdot
.32472 .59404 Mdot
.37025 .58996 Mdot
.55223 .40165 Mdot
.36643 .56146 Mdot
.58606 .39019 Mdot
.54654 .62612 Mdot
.25181 .71013 Mdot
.58823 .42919 Mdot
.50849 .40121 Mdot
.3177 .62703 Mdot
.80225 .60161 Mdot
.57 .67576 Mdot
.34186 .31381 Mdot
.58238 .18501 Mdot
.36566 .56024 Mdot
.62177 .44552 Mdot
.50743 .65737 Mdot
.46844 .72256 Mdot
.54923 .69221 Mdot
.56698 .37541 Mdot
.56186 .37967 Mdot
.5939 .43393 Mdot
.55926 .42382 Mdot
.49108 .22731 Mdot
.47977 .38532 Mdot
.39116 .31607 Mdot
.56135 .39811 Mdot
.39117 .34581 Mdot
.31956 .54847 Mdot
.38846 .44296 Mdot
.62802 .62909 Mdot
.5441 .37524 Mdot
.3545 .46035 Mdot
.37124 .53921 Mdot
.7441 .28673 Mdot
.36177 .59223 Mdot
.53865 .64333 Mdot
.34235 .59537 Mdot
.53029 .41996 Mdot
.36744 .40991 Mdot
.50285 .65387 Mdot
.31145 .6888 Mdot
.55306 .65303 Mdot
.52549 .41061 Mdot
.67703 .66998 Mdot
.54885 .65892 Mdot
.48256 .50618 Mdot
.37294 .40984 Mdot
.75517 .51201 Mdot
.39657 .40799 Mdot
.54342 .40429 Mdot
.54506 .40864 Mdot
.4713 .72629 Mdot
.32214 .58841 Mdot
.39004 .42429 Mdot
.20326 .68338 Mdot
.68352 .65151 Mdot
.34205 .39241 Mdot
.55053 .33826 Mdot
.5691 .54747 Mdot
.36019 .41425 Mdot
.73733 .45699 Mdot
.37238 .56156 Mdot
.31851 .40278 Mdot
.54305 .34385 Mdot
.38819 .62193 Mdot
.69057 .60291 Mdot
.54403 .61636 Mdot
.46077 .57365 Mdot
.50706 .66888 Mdot
.36237 .53163 Mdot
.52317 .6174 Mdot
.32714 .57352 Mdot
.24213 .38064 Mdot
.53098 .31729 Mdot
.36905 .602 Mdot
.34993 .52653 Mdot
.52332 .66238 Mdot
.5819 .44923 Mdot
.41258 .49843 Mdot
.57769 .46046 Mdot
.60046 .44465 Mdot
.33198 .57975 Mdot
.37841 .42921 Mdot
.38063 .43446 Mdot
.38096 .34587 Mdot
.36485 .3692 Mdot
.54074 .62572 Mdot
.2452 .65849 Mdot
.22521 .39301 Mdot
.3417 .58074 Mdot
.32905 .52873 Mdot
.56323 .43396 Mdot
.51968 .652 Mdot
.56149 .66571 Mdot
.34618 .54485 Mdot
.43182 .22885 Mdot
.52344 .37523 Mdot
.39744 .3764 Mdot
.34647 .42957 Mdot
.35188 .40936 Mdot
.34047 .36539 Mdot
.5424 .26829 Mdot
.37307 .56347 Mdot
.35537 .43131 Mdot
.55035 .40472 Mdot
.56378 .37867 Mdot
.45012 .70908 Mdot
.68655 .61171 Mdot
.57533 .34351 Mdot
.52585 .45976 Mdot
.57501 .4007 Mdot
.54955 .66313 Mdot
.62506 .34949 Mdot
.44631 .73274 Mdot
.55778 .61935 Mdot
.56949 .61881 Mdot
.44662 .70681 Mdot
.39732 .35299 Mdot
.58819 .17866 Mdot
.55398 .43267 Mdot
.56427 .31183 Mdot
.52359 .64848 Mdot
.29168 .72949 Mdot
.21467 .43967 Mdot
.59052 .44154 Mdot
.42819 .57957 Mdot
.51362 .6325 Mdot
.38331 .37661 Mdot
.57133 .37283 Mdot
.46122 .70662 Mdot
.64611 .63923 Mdot
.54453 .34002 Mdot
.46838 .71226 Mdot
.33272 .41309 Mdot
.63071 .61289 Mdot
.3167 .39497 Mdot
.51115 .63484 Mdot
.6355 .40788 Mdot
.69801 .19162 Mdot
.52546 .68471 Mdot
.81962 .51782 Mdot
.29971 .4176 Mdot
.59598 .4239 Mdot
.5171 .6801 Mdot
.38706 .37718 Mdot
.3731 .53728 Mdot
.57948 .54339 Mdot
.35022 .37314 Mdot
.43705 .72606 Mdot
.45734 .70915 Mdot
.5421 .6623 Mdot
.38693 .39856 Mdot
.59709 .37006 Mdot
.38759 .41394 Mdot
.34553 .59593 Mdot
.56841 .44638 Mdot
.67242 .23297 Mdot
.53196 .32745 Mdot
.36479 .43089 Mdot
.55748 .62366 Mdot
.70103 .61316 Mdot
.56286 .45181 Mdot
.80974 .50811 Mdot
.52483 .39056 Mdot
.33355 .57549 Mdot
.39182 .79808 Mdot
.43039 .21361 Mdot
.5254 .42714 Mdot
.56247 .43284 Mdot
.37523 .56943 Mdot
.5595 .45354 Mdot
.52704 .43555 Mdot
.30526 .60752 Mdot
.39283 .40547 Mdot
.58293 .42301 Mdot
.5673 .6516 Mdot
.26059 .33106 Mdot
.51964 .3862 Mdot
.40864 .70621 Mdot
.74603 .5153 Mdot
.37273 .79923 Mdot
.57411 .36709 Mdot
.64915 .54771 Mdot
.55981 .4183 Mdot
.54911 .37729 Mdot
.56227 .43881 Mdot
.33916 .30617 Mdot
.52269 .66448 Mdot
.55729 .63481 Mdot
.68633 .60146 Mdot
.74785 .51082 Mdot
.69106 .63212 Mdot
.37075 .58384 Mdot
.68653 .73333 Mdot
.46049 .7291 Mdot
.32939 .40925 Mdot
.5887 .36789 Mdot
.50036 .66266 Mdot
.57292 .39127 Mdot
.53229 .42053 Mdot
.52723 .62327 Mdot
.54742 .68204 Mdot
.59601 .62178 Mdot
.6859 .64594 Mdot
.3475 .38031 Mdot
.61288 .38298 Mdot
.65513 .61264 Mdot
.59134 .36583 Mdot
.60536 .55697 Mdot
.34289 .38345 Mdot
.3923 .40892 Mdot
.40185 .41085 Mdot
.5289 .38916 Mdot
.53193 .43067 Mdot
.32888 .54251 Mdot
.32477 .40063 Mdot
.35603 .5867 Mdot
.50581 .65422 Mdot
.52251 .69032 Mdot
.56676 .37557 Mdot
.65625 .42604 Mdot
.68972 .64004 Mdot
.53902 .63779 Mdot
.43172 .71972 Mdot
.70541 .61389 Mdot
.52583 .4009 Mdot
.52246 .62822 Mdot
.67852 .60843 Mdot
.39475 .25189 Mdot
.54626 .16554 Mdot
.70103 .61567 Mdot
.55275 .40408 Mdot
.30761 .31752 Mdot
.77892 .57643 Mdot
.68891 .65053 Mdot
.33229 .56323 Mdot
.52961 .38342 Mdot
.68557 .34758 Mdot
.63443 .63143 Mdot
.25928 .3533 Mdot
.54786 .65184 Mdot
.4067 .58643 Mdot
.51109 .36672 Mdot
.46581 .23846 Mdot
.65742 .64853 Mdot
.36627 .3927 Mdot
.40084 .42853 Mdot
.57139 .41375 Mdot
.62515 .63251 Mdot
.37319 .5893 Mdot
.55092 .64445 Mdot
.57699 .65592 Mdot
.38865 .4014 Mdot
.23487 .53824 Mdot
.56539 .64586 Mdot
.63514 .46481 Mdot
.50456 .77822 Mdot
.48362 .36098 Mdot
.43383 .37137 Mdot
.27577 .64387 Mdot
.54077 .36448 Mdot
.70316 .62264 Mdot
.35776 .53373 Mdot
.34664 .53945 Mdot
.36101 .57462 Mdot
.55559 .68587 Mdot
.46546 .51747 Mdot
.51218 .65934 Mdot
.32727 .71975 Mdot
.67529 .61588 Mdot
.77029 .49481 Mdot
.57961 .36209 Mdot
.5852 .43098 Mdot
.55253 .34832 Mdot
.60715 .39341 Mdot
.56528 .42096 Mdot
.37027 .56571 Mdot
.56594 .67423 Mdot
.64306 .71266 Mdot
.34122 .4046 Mdot
.53916 .58189 Mdot
.52044 .64506 Mdot
.46741 .72386 Mdot
.65898 .6269 Mdot
.55816 .51912 Mdot
.53178 .60782 Mdot
.52552 .63942 Mdot
.58914 .34368 Mdot
.37158 .42395 Mdot
.52199 .47616 Mdot
.54892 .41406 Mdot
.53869 .63431 Mdot
.49022 .69231 Mdot
.58327 .24525 Mdot
.58865 .4844 Mdot
.70347 .60133 Mdot
.5571 .54226 Mdot
.69525 .64623 Mdot
.50239 .41395 Mdot
.30051 .73845 Mdot
.53037 .67002 Mdot
.53782 .65061 Mdot
.68694 .60869 Mdot
.65565 .39015 Mdot
.38328 .4038 Mdot
.43544 .71743 Mdot
.32608 .55958 Mdot
.53839 .40567 Mdot
.5312 .68988 Mdot
.63481 .33398 Mdot
.60425 .76146 Mdot
.35629 .57777 Mdot
.55945 .62097 Mdot
.52221 .40896 Mdot
.55483 .40451 Mdot
.65754 .6384 Mdot
.38191 .46216 Mdot
.5574 .33147 Mdot
.82788 .44464 Mdot
.24211 .60374 Mdot
.21633 .5663 Mdot
.5775 .39931 Mdot
.39065 .39968 Mdot
.46257 .71233 Mdot
.64764 .62444 Mdot
.60042 .36156 Mdot
.5579 .16946 Mdot
.41009 .40687 Mdot
.34578 .56384 Mdot
.45944 .70593 Mdot
.46559 .515 Mdot
.5269 .38634 Mdot
.5653 .37054 Mdot
.54929 .38744 Mdot
.49056 .14542 Mdot
.56202 .64666 Mdot
.36083 .36537 Mdot
.67366 .63203 Mdot
.36607 .36813 Mdot
.55642 .64327 Mdot
.21861 .49053 Mdot
.53377 .4395 Mdot
.39336 .37347 Mdot
.36655 .39581 Mdot
.36832 .59059 Mdot
.37416 .53729 Mdot
.59273 .61078 Mdot
.58743 .37547 Mdot
.46264 .70738 Mdot
.39773 .40552 Mdot
.56336 .67078 Mdot
.6509 .62895 Mdot
.3262 .53992 Mdot
.56039 .39738 Mdot
.53781 .66805 Mdot
.58924 .46832 Mdot
.36313 .41793 Mdot
.52515 .64024 Mdot
.44682 .70304 Mdot
.69783 .63033 Mdot
.56206 .38701 Mdot
.71539 .61027 Mdot
.43881 .7106 Mdot
.57714 .43388 Mdot
.55391 .5062 Mdot
.72835 .62501 Mdot
.3296 .70258 Mdot
.51463 .67073 Mdot
.44386 .71593 Mdot
.39907 .39884 Mdot
.26308 .3828 Mdot
.54151 .64747 Mdot
.55257 .51222 Mdot
.36272 .4768 Mdot
.61427 .38624 Mdot
.3536 .40292 Mdot
.48211 .74711 Mdot
.80511 .38818 Mdot
.79055 .50094 Mdot
.59263 .42232 Mdot
.5135 .67716 Mdot
.67012 .60723 Mdot
.34119 .58098 Mdot
.40862 .70852 Mdot
.58165 .30004 Mdot
.53208 .61406 Mdot
.56013 .43568 Mdot
.3955 .40862 Mdot
.34864 .54659 Mdot
.28086 .46062 Mdot
.56879 .63074 Mdot
.5335 .67836 Mdot
.52495 .42153 Mdot
.68272 .62063 Mdot
.76055 .40968 Mdot
.5554 .62813 Mdot
.53039 .68908 Mdot
.44053 .76067 Mdot
.68011 .60518 Mdot
.56036 .41194 Mdot
.37882 .34505 Mdot
.6162 .41742 Mdot
.82224 .51561 Mdot
.44354 .72982 Mdot
.34094 .40664 Mdot
.55905 .37231 Mdot
.54386 .77208 Mdot
.54392 .63497 Mdot
.53428 .53484 Mdot
.49524 .67639 Mdot
.37181 .55954 Mdot
.52815 .68941 Mdot
.57429 .38008 Mdot
.32783 .59639 Mdot
.69012 .63933 Mdot
.59759 .38805 Mdot
.53348 .43263 Mdot
.3786 .37171 Mdot
.33964 .56035 Mdot
.33339 .25486 Mdot
.32992 .53081 Mdot
.37085 .54145 Mdot
.37616 .44027 Mdot
.57916 .4149 Mdot
.53515 .64298 Mdot
.52133 .62041 Mdot
.60365 .3673 Mdot
.24958 .68509 Mdot
.38534 .40466 Mdot
.58488 .59971 Mdot
.43955 .16071 Mdot
.56182 .49164 Mdot
.43538 .71017 Mdot
.40766 .44809 Mdot
.37702 .57748 Mdot
.55639 .40045 Mdot
.35693 .42827 Mdot
.54372 .68842 Mdot
.5657 .64716 Mdot
.59394 .36463 Mdot
.34852 .55142 Mdot
.63857 .62997 Mdot
.54015 .67891 Mdot
.57665 .77317 Mdot
.54357 .38908 Mdot
.35319 .7389 Mdot
.53113 .68142 Mdot
.84137 .49508 Mdot
.62989 .73052 Mdot
.35059 .40384 Mdot
.53381 .42452 Mdot
.36149 .37086 Mdot
.67345 .63546 Mdot
.51625 .60467 Mdot
.34695 .55383 Mdot
.60425 .47574 Mdot
.21543 .34795 Mdot
.51941 .66053 Mdot
.33095 .3968 Mdot
.52476 .42488 Mdot
.5985 .48932 Mdot
.58069 .38174 Mdot
.2969 .35399 Mdot
.61478 .62907 Mdot
.33466 .5825 Mdot
.33242 .57233 Mdot
.57799 .43755 Mdot
.65016 .63754 Mdot
.53787 .61952 Mdot
.54962 .64518 Mdot
.65962 .83572 Mdot
.44205 .70464 Mdot
.7177 .49672 Mdot
.5616 .38236 Mdot
.57082 .65947 Mdot
.28744 .3203 Mdot
.34298 .57737 Mdot
.60706 .38969 Mdot
.5796 .64182 Mdot
.33981 .63987 Mdot
.59804 .55553 Mdot
.5649 .41743 Mdot
.4922 .41458 Mdot
.32736 .56179 Mdot
.72514 .56513 Mdot
.51158 .65414 Mdot
.60943 .39205 Mdot
.31939 .53608 Mdot
.5129 .78888 Mdot
.2243 .37474 Mdot
.34726 .38068 Mdot
.49749 .65481 Mdot
.37053 .56586 Mdot
.54398 .33421 Mdot
.68564 .61449 Mdot
.504 .66647 Mdot
.55395 .65707 Mdot
.55553 .44148 Mdot
.59392 .34368 Mdot
.56568 .49269 Mdot
.33373 .40385 Mdot
.31778 .55624 Mdot
.60205 .38878 Mdot
.23642 .54436 Mdot
.59802 .43067 Mdot
.32164 .54938 Mdot
.8338 .31365 Mdot
.60038 .44123 Mdot
.58155 .3844 Mdot
.77211 .43222 Mdot
.35318 .37211 Mdot
.3692 .37013 Mdot
.24088 .62045 Mdot
.56168 .38281 Mdot
.66509 .71757 Mdot
.35173 .37817 Mdot
.38314 .40853 Mdot
.59197 .7051 Mdot
.57768 .44604 Mdot
.73704 .58196 Mdot
.34421 .5416 Mdot
.34918 .5356 Mdot
.38876 .41136 Mdot
.55288 .33149 Mdot
.37493 .55544 Mdot
.52346 .24032 Mdot
.51688 .64829 Mdot
.30479 .74369 Mdot
.35852 .41956 Mdot
.40605 .48221 Mdot
.34858 .57983 Mdot
.74961 .29267 Mdot
.42602 .59586 Mdot
.59137 .43729 Mdot
.55737 .38894 Mdot
.69355 .63492 Mdot
.61371 .44351 Mdot
.44132 .73129 Mdot
.36675 .56217 Mdot
.7372 .36616 Mdot
.34256 .38789 Mdot
.58678 .37928 Mdot
.56721 .52144 Mdot
.28919 .48019 Mdot
.39453 .74109 Mdot
.3762 .39682 Mdot
.35149 .3971 Mdot
.51923 .66895 Mdot
.54492 .67213 Mdot
.57424 .418 Mdot
.35429 .54161 Mdot
.32331 .40026 Mdot
.32137 .55917 Mdot
.53285 .67084 Mdot
.52892 .64114 Mdot
.46068 .73101 Mdot
.5497 .46634 Mdot
.5383 .62166 Mdot
.55693 .78338 Mdot
.23099 .5361 Mdot
.32651 .36874 Mdot
.24689 .2969 Mdot
.28063 .45857 Mdot
.71185 .41242 Mdot
.68716 .64724 Mdot
.4824 .69594 Mdot
.3253 .58469 Mdot
.56573 .43403 Mdot
.56752 .39345 Mdot
.45375 .72076 Mdot
.33792 .5983 Mdot
.65789 .63215 Mdot
.33122 .59578 Mdot
.6741 .61346 Mdot
.54096 .69266 Mdot
.52364 .38078 Mdot
.54001 .37137 Mdot
.36878 .56867 Mdot
.52669 .6325 Mdot
.5511 .63161 Mdot
.69821 .64271 Mdot
.60032 .53911 Mdot
.54199 .66368 Mdot
.36013 .41936 Mdot
.51834 .28346 Mdot
.45827 .71149 Mdot
.57299 .37368 Mdot
.62102 .53419 Mdot
.46635 .21893 Mdot
.61447 .39811 Mdot
.45384 .70461 Mdot
.55333 .85385 Mdot
.58313 .36671 Mdot
.48325 .85604 Mdot
.4441 .7143 Mdot
.35212 .37157 Mdot
.5172 .67824 Mdot
.44449 .73419 Mdot
.51033 .36339 Mdot
.70804 .64165 Mdot
.57823 .35049 Mdot
.35751 .3737 Mdot
.40426 .4037 Mdot
.20432 .5591 Mdot
.82078 .51938 Mdot
.70075 .63778 Mdot
.65994 .61981 Mdot
.5421 .64923 Mdot
.76765 .68167 Mdot
.5516 .34257 Mdot
.65518 .62342 Mdot
.73006 .37356 Mdot
.55552 .43014 Mdot
.70262 .51513 Mdot
.43072 .57526 Mdot
.39013 .4011 Mdot
.41725 .36689 Mdot
.54457 .64114 Mdot
.33245 .39332 Mdot
.21762 .52208 Mdot
.55616 .34826 Mdot
.34139 .38592 Mdot
.32378 .54867 Mdot
.32717 .66193 Mdot
.37362 .3775 Mdot
.61269 .55096 Mdot
.34978 .54314 Mdot
.50342 .72251 Mdot
.75389 .42469 Mdot
.17965 .33208 Mdot
.36731 .55769 Mdot
.51773 .63359 Mdot
.51406 .63127 Mdot
.54749 .64828 Mdot
.3455 .37443 Mdot
.56994 .65344 Mdot
.33762 .41161 Mdot
.78036 .59119 Mdot
.60283 .536 Mdot
.65999 .61548 Mdot
.29469 .60271 Mdot
.35965 .39724 Mdot
.28264 .6933 Mdot
.20319 .33671 Mdot
.55106 .40018 Mdot
.32551 .53259 Mdot
.68968 .61042 Mdot
.85088 .56672 Mdot
.69052 .63696 Mdot
.50764 .65964 Mdot
.31368 .75491 Mdot
.58842 .38926 Mdot
.62569 .27407 Mdot
.69966 .63242 Mdot
.37469 .3896 Mdot
.58033 .43329 Mdot
.5362 .69943 Mdot
.68758 .62098 Mdot
.64212 .63525 Mdot
.57371 .42586 Mdot
.38243 .38603 Mdot
.53258 .64067 Mdot
.31871 .57832 Mdot
.68472 .65358 Mdot
.52671 .33817 Mdot
.61785 .39859 Mdot
.54373 .35787 Mdot
.49462 .52477 Mdot
.69633 .34295 Mdot
.36516 .5588 Mdot
.77589 .53794 Mdot
.54821 .66899 Mdot
.51226 .74024 Mdot
.25279 .62121 Mdot
.2933 .5519 Mdot
.44218 .72817 Mdot
.45015 .73268 Mdot
.56774 .4198 Mdot
.69957 .34546 Mdot
.42053 .7986 Mdot
.30615 .62219 Mdot
.45987 .71325 Mdot
.55143 .63988 Mdot
.40434 .4247 Mdot
.19012 .52756 Mdot
.62036 .40561 Mdot
.37945 .57573 Mdot
.54308 .66598 Mdot
.6675 .26965 Mdot
.67687 .62099 Mdot
.29035 .72134 Mdot
.52765 .42818 Mdot
.60171 .40496 Mdot
.35982 .56006 Mdot
.33214 .54115 Mdot
.39093 .71938 Mdot
.21765 .5804 Mdot
.6749 .57034 Mdot
.27691 .39965 Mdot
.65121 .26429 Mdot
.39476 .43979 Mdot
.36767 .43057 Mdot
.46518 .70218 Mdot
.33187 .53365 Mdot
.56378 .36827 Mdot
.3265 .40594 Mdot
.39401 .74316 Mdot
.34721 .34923 Mdot
.71363 .51348 Mdot
.63874 .73733 Mdot
.52865 .40871 Mdot
.37814 .4224 Mdot
.33604 .3883 Mdot
.32108 .38437 Mdot
.44993 .70568 Mdot
.5803 .40248 Mdot
.57655 .45097 Mdot
.60534 .40451 Mdot
.49706 .36424 Mdot
.54198 .39281 Mdot
.25423 .5783 Mdot
.51407 .56119 Mdot
.7462 .36501 Mdot
.61299 .41126 Mdot
.35475 .53693 Mdot
.55603 .35104 Mdot
.64731 .63579 Mdot
.56287 .43707 Mdot
.71187 .5052 Mdot
.35137 .57115 Mdot
.65253 .40742 Mdot
.27449 .39747 Mdot
.53074 .43463 Mdot
.64241 .61758 Mdot
.70524 .36764 Mdot
.32334 .26679 Mdot
.52979 .58419 Mdot
.36221 .41947 Mdot
.54388 .60748 Mdot
.35066 .59614 Mdot
.53403 .64554 Mdot
.60688 .42158 Mdot
.4627 .7043 Mdot
.28083 .54351 Mdot
.40806 .48453 Mdot
.55516 .36822 Mdot
.62545 .35563 Mdot
.37469 .41582 Mdot
.52138 .6295 Mdot
.34085 .44921 Mdot
.55295 .38061 Mdot
.6778 .63155 Mdot
.68342 .61706 Mdot
.22743 .56965 Mdot
.67974 .25508 Mdot
.25592 .3805 Mdot
.36137 .55991 Mdot
.56082 .63121 Mdot
.64946 .64585 Mdot
.59353 .30899 Mdot
.38236 .56543 Mdot
.3743 .58337 Mdot
.34024 .55371 Mdot
.5335 .40393 Mdot
.44261 .73102 Mdot
.7125 .33286 Mdot
.43845 .72862 Mdot
.53426 .43796 Mdot
.55843 .65367 Mdot
.45542 .73554 Mdot
.69486 .62874 Mdot
.36028 .58815 Mdot
.53254 .67306 Mdot
.54145 .40248 Mdot
.35635 .38147 Mdot
.59247 .538 Mdot
.67969 .47222 Mdot
.80831 .47328 Mdot
.80855 .45674 Mdot
.39628 .42305 Mdot
.73304 .29077 Mdot
.30559 .5479 Mdot
.43467 .22853 Mdot
.65646 .66596 Mdot
.60265 .36933 Mdot
.20717 .63098 Mdot
.51076 .65517 Mdot
.52376 .62541 Mdot
.55843 .4139 Mdot
.55298 .68069 Mdot
.58464 .37996 Mdot
.53633 .67586 Mdot
.53472 .58511 Mdot
.62139 .40806 Mdot
.53254 .62379 Mdot
.51153 .3737 Mdot
.56328 .45089 Mdot
.39162 .4047 Mdot
.50974 .67711 Mdot
.60174 .42709 Mdot
.81107 .64583 Mdot
.3284 .54033 Mdot
.45113 .7059 Mdot
.61571 .58148 Mdot
.37093 .56947 Mdot
.34179 .39613 Mdot
.60248 .44492 Mdot
.67621 .64358 Mdot
.36355 .38992 Mdot
.5902 .60577 Mdot
.70041 .62763 Mdot
.24594 .66031 Mdot
.36853 .42014 Mdot
.45708 .7135 Mdot
.69288 .63885 Mdot
.63313 .36916 Mdot
.50491 .67621 Mdot
.66596 .46087 Mdot
.43715 .72025 Mdot
.57706 .39178 Mdot
.58002 .65568 Mdot
.32801 .53791 Mdot
.59343 .41532 Mdot
.52635 .68562 Mdot
.44577 .70652 Mdot
.53673 .41213 Mdot
.56422 .42881 Mdot
.18895 .47682 Mdot
.37893 .76528 Mdot
.65436 .63521 Mdot
.39723 .3828 Mdot
.54984 .40482 Mdot
.68277 .64667 Mdot
.61282 .78584 Mdot
.53989 .36401 Mdot
.3453 .37061 Mdot
.49122 .45475 Mdot
.55107 .66938 Mdot
.35738 .58686 Mdot
.4997 .64914 Mdot
.64975 .64133 Mdot
.24181 .73671 Mdot
.46094 .73256 Mdot
.50114 .40326 Mdot
.59236 .36831 Mdot
.48222 .71364 Mdot
.33347 .39403 Mdot
.67548 .56755 Mdot
.56165 .38723 Mdot
.52204 .33195 Mdot
.59683 .39127 Mdot
.63879 .72191 Mdot
.38398 .40504 Mdot
.57913 .3856 Mdot
.64091 .46052 Mdot
.514 .40972 Mdot
.63693 .62676 Mdot
.77605 .47056 Mdot
.55321 .35655 Mdot
.6094 .12536 Mdot
.43417 .71448 Mdot
.53544 .62211 Mdot
.52461 .70381 Mdot
.70267 .76207 Mdot
.2485 .37335 Mdot
.3353 .40936 Mdot
.43796 .44406 Mdot
.53343 .64287 Mdot
.26622 .34134 Mdot
.75889 .31627 Mdot
.55936 .45029 Mdot
.52646 .39038 Mdot
.50763 .65967 Mdot
.56328 .67152 Mdot
.4667 .70977 Mdot
.60565 .42678 Mdot
.64093 .41259 Mdot
.56204 .62519 Mdot
.53588 .39254 Mdot
.51498 .47373 Mdot
.31808 .57516 Mdot
.39367 .3942 Mdot
.34316 .58308 Mdot
.35939 .59312 Mdot
.47196 .26262 Mdot
.24223 .60021 Mdot
.32144 .54865 Mdot
.32076 .59356 Mdot
.7018 .50645 Mdot
.485 .45983 Mdot
.64168 .6391 Mdot
.75351 .34288 Mdot
.54327 .65377 Mdot
.58126 .40407 Mdot
.37972 .43199 Mdot
.45581 .24656 Mdot
.42883 .62545 Mdot
.35318 .78394 Mdot
.55443 .37611 Mdot
.54689 .63817 Mdot
.44145 .71001 Mdot
.62116 .40033 Mdot
.53149 .73479 Mdot
.59956 .41382 Mdot
.50045 .66299 Mdot
.53078 .29141 Mdot
.58372 .51046 Mdot
.46983 .75727 Mdot
.32004 .41495 Mdot
.58987 .37243 Mdot
.34946 .41647 Mdot
.35464 .58077 Mdot
.66035 .6434 Mdot
.65786 .63699 Mdot
.57463 .43183 Mdot
.56353 .30541 Mdot
.43073 .56357 Mdot
.55802 .45143 Mdot
.56178 .44361 Mdot
.44354 .71562 Mdot
.56346 .44437 Mdot
.5951 .37092 Mdot
.60689 .39748 Mdot
.5123 .42183 Mdot
.36913 .54021 Mdot
.58387 .5124 Mdot
.54147 .46538 Mdot
.5446 .48215 Mdot
.31241 .56224 Mdot
.41907 .44759 Mdot
.34983 .59214 Mdot
.66974 .23085 Mdot
.33276 .57631 Mdot
.6524 .62884 Mdot
.5848 .62715 Mdot
.45824 .39737 Mdot
.32266 .4064 Mdot
.37498 .54197 Mdot
.66629 .62797 Mdot
.36466 .56973 Mdot
.56304 .64837 Mdot
.35695 .20827 Mdot
.34587 .34968 Mdot
.65319 .55757 Mdot
.38194 .61852 Mdot
.35894 .73877 Mdot
.51632 .66029 Mdot
.3874 .40625 Mdot
.59408 .246 Mdot
.60309 .41971 Mdot
.69576 .63483 Mdot
.5718 .42203 Mdot
.37381 .54459 Mdot
.54698 .64353 Mdot
.79844 .51759 Mdot
.66453 .64126 Mdot
.19338 .4141 Mdot
.55131 .64821 Mdot
.58328 .45216 Mdot
.37955 .57318 Mdot
.24109 .30159 Mdot
.33792 .58306 Mdot
.60597 .53562 Mdot
.36488 .36166 Mdot
.38242 .33888 Mdot
.35721 .40219 Mdot
.4068 .73668 Mdot
.49937 .13551 Mdot
.81104 .41742 Mdot
.36444 .38157 Mdot
.48308 .76971 Mdot
.52788 .39795 Mdot
.54885 .35416 Mdot
.61833 .48049 Mdot
.36235 .36459 Mdot
.54628 .39901 Mdot
.43976 .71632 Mdot
.22667 .50165 Mdot
.54364 .74988 Mdot
.54255 .60822 Mdot
.57764 .37743 Mdot
.31314 .56087 Mdot
.33346 .59759 Mdot
.44844 .73578 Mdot
.34145 .59132 Mdot
.58025 .44811 Mdot
.35909 .3994 Mdot
.3878 .48856 Mdot
.68317 .63669 Mdot
.81589 .59438 Mdot
.62881 .63155 Mdot
.51139 .69915 Mdot
.63571 .40907 Mdot
.5284 .64064 Mdot
.39343 .85757 Mdot
.59157 .43457 Mdot
.34907 .37756 Mdot
.55369 .42187 Mdot
.59716 .38132 Mdot
.54665 .35429 Mdot
.56949 .63515 Mdot
.68147 .58925 Mdot
.53656 .39515 Mdot
.34568 .55425 Mdot
.78029 .39889 Mdot
.56306 .34791 Mdot
.52453 .59187 Mdot
.74763 .49537 Mdot
.32064 .71445 Mdot
.31448 .39058 Mdot
.52313 .62965 Mdot
.34567 .38926 Mdot
.33909 .43227 Mdot
.34162 .39623 Mdot
.71445 .32688 Mdot
.58455 .25504 Mdot
.5495 .84993 Mdot
.43441 .35885 Mdot
.42021 .25057 Mdot
.4032 .38746 Mdot
.5944 .80652 Mdot
.35007 .42756 Mdot
.33579 .40261 Mdot
.89866 .54503 Mdot
.34764 .42853 Mdot
.56835 .37843 Mdot
.60103 .35189 Mdot
.27165 .49807 Mdot
.68561 .51885 Mdot
.57161 .44155 Mdot
.55319 .4093 Mdot
.67413 .64598 Mdot
.63255 .30522 Mdot
.46908 .70883 Mdot
.24202 .65625 Mdot
.30705 .47042 Mdot
.57186 .42468 Mdot
.54767 .40565 Mdot
.59321 .33826 Mdot
.43532 .12869 Mdot
.48945 .24489 Mdot
.40721 .40142 Mdot
.6085 .33572 Mdot
.83338 .5306 Mdot
.56291 .45633 Mdot
.53525 .37425 Mdot
.53193 .41454 Mdot
.53464 .64278 Mdot
.41098 .41163 Mdot
.60888 .33656 Mdot
.29078 .68014 Mdot
.52457 .41522 Mdot
.29001 .57357 Mdot
.72913 .60823 Mdot
.57355 .3808 Mdot
.33225 .36951 Mdot
.54798 .42989 Mdot
.36606 .42206 Mdot
.39397 .40473 Mdot
.59581 .33959 Mdot
.70138 .29953 Mdot
.34634 .3678 Mdot
.53161 .43221 Mdot
.53152 .63112 Mdot
.81098 .40325 Mdot
.57546 .38997 Mdot
.65047 .61805 Mdot
.55926 .38751 Mdot
.64821 .61296 Mdot
.55435 .44572 Mdot
.43683 .72455 Mdot
.4557 .20751 Mdot
.53803 .65198 Mdot
.74824 .61935 Mdot
.57586 .64652 Mdot
.18911 .47975 Mdot
.34314 .37329 Mdot
.45553 .69922 Mdot
.31775 .77412 Mdot
.4468 .71291 Mdot
.57025 .5294 Mdot
.51274 .58036 Mdot
.35837 .54231 Mdot
.37482 .37264 Mdot
.7668 .55086 Mdot
.45343 .74886 Mdot
.60388 .63954 Mdot
.56668 .6169 Mdot
.23886 .71889 Mdot
.2691 .72817 Mdot
.53797 .40242 Mdot
.64308 .28357 Mdot
.39817 .3141 Mdot
.53788 .36752 Mdot
.58866 .45616 Mdot
.50627 .68035 Mdot
.58162 .36336 Mdot
.4788 .50791 Mdot
.52255 .66173 Mdot
.66457 .62339 Mdot
.34122 .40862 Mdot
.65728 .60819 Mdot
.55763 .69154 Mdot
.5374 .56324 Mdot
.54037 .67162 Mdot
.5098 .4112 Mdot
.55224 .41804 Mdot
.38692 .41589 Mdot
.32885 .44632 Mdot
.39478 .39782 Mdot
.69539 .61338 Mdot
.52949 .66256 Mdot
.47917 .23877 Mdot
.56035 .40561 Mdot
.36719 .39835 Mdot
.38926 .53191 Mdot
.55468 .40371 Mdot
.3648 .57655 Mdot
.52495 .39912 Mdot
.36461 .37938 Mdot
.56332 .44458 Mdot
.35714 .39845 Mdot
.51517 .64194 Mdot
.55187 .45524 Mdot
.56163 .41452 Mdot
.23609 .31957 Mdot
.65982 .6341 Mdot
.34483 .37255 Mdot
.46131 .55712 Mdot
.58783 .44872 Mdot
.48777 .72152 Mdot
.57383 .36773 Mdot
.46005 .43833 Mdot
.50653 .38684 Mdot
.44357 .71219 Mdot
.57944 .47204 Mdot
.57623 .38957 Mdot
.65084 .45591 Mdot
.44038 .34091 Mdot
.34612 .45247 Mdot
.37785 .55864 Mdot
.3392 .36638 Mdot
.5213 .68946 Mdot
.55386 .68442 Mdot
.55056 .67612 Mdot
.67067 .53472 Mdot
.59311 .33941 Mdot
.58759 .39074 Mdot
.36205 .52754 Mdot
.66401 .61799 Mdot
.37417 .39593 Mdot
.66909 .61622 Mdot
.23765 .63412 Mdot
.69641 .61586 Mdot
.44393 .73331 Mdot
.62752 .73301 Mdot
.49964 .22316 Mdot
.67747 .64585 Mdot
.39443 .3963 Mdot
.6272 .74464 Mdot
.60486 .37411 Mdot
.58953 .60011 Mdot
.67912 .6303 Mdot
.21282 .69547 Mdot
.5648 .36425 Mdot
.55339 .53518 Mdot
.32398 .57473 Mdot
.68924 .61755 Mdot
.33949 .5645 Mdot
.57283 .43855 Mdot
.33996 .71037 Mdot
.32993 .39873 Mdot
.30871 .55446 Mdot
.54644 .46972 Mdot
.67523 .60853 Mdot
.54713 .66269 Mdot
.34755 .62306 Mdot
.35563 .53768 Mdot
.44517 .19486 Mdot
.79041 .50329 Mdot
.52742 .66225 Mdot
.43011 .79107 Mdot
.33412 .55554 Mdot
.5414 .36459 Mdot
.47747 .37514 Mdot
.58871 .44173 Mdot
.55927 .68368 Mdot
.52436 .62772 Mdot
.24408 .50711 Mdot
.54973 .41872 Mdot
.56882 .36535 Mdot
.39638 .3659 Mdot
.51844 .65352 Mdot
.36461 .41176 Mdot
.31896 .38785 Mdot
.51456 .63829 Mdot
.35287 .40538 Mdot
.69888 .63088 Mdot
.22544 .47009 Mdot
.33334 .5549 Mdot
.34741 .55802 Mdot
.55097 .6413 Mdot
.54906 .62014 Mdot
.52618 .64119 Mdot
.52489 .39956 Mdot
.38046 .399 Mdot
.53742 .42968 Mdot
.53459 .367 Mdot
.31133 .4034 Mdot
.3485 .4307 Mdot
.54008 .42382 Mdot
.48018 .7461 Mdot
.71052 .64477 Mdot
.5383 .6241 Mdot
.32031 .56083 Mdot
.27997 .33482 Mdot
.3561 .52087 Mdot
.57819 .37557 Mdot
.3665 .63977 Mdot
.37067 .3824 Mdot
.69272 .63505 Mdot
.72634 .63035 Mdot
.68324 .641 Mdot
.38785 .56359 Mdot
.32326 .39058 Mdot
.24595 .65804 Mdot
.58186 .37932 Mdot
.49049 .52298 Mdot
.77162 .54158 Mdot
.2565 .63869 Mdot
.32048 .55128 Mdot
.55238 .40557 Mdot
.45052 .71132 Mdot
.56555 .23473 Mdot
.60018 .40879 Mdot
.6092 .40713 Mdot
.64187 .68864 Mdot
.54711 .48368 Mdot
.35853 .36298 Mdot
.20497 .56751 Mdot
.59486 .34877 Mdot
.32659 .34331 Mdot
.72411 .77323 Mdot
.58131 .37216 Mdot
.54832 .38394 Mdot
.571 .40005 Mdot
.55568 .42839 Mdot
.34858 .3605 Mdot
.72416 .5564 Mdot
.37992 .5709 Mdot
.5084 .54006 Mdot
.33503 .54885 Mdot
.50175 .66384 Mdot
.53665 .52632 Mdot
.38488 .38137 Mdot
.69232 .63701 Mdot
.5127 .19357 Mdot
.22622 .60403 Mdot
.51796 .66703 Mdot
.52628 .25886 Mdot
.67897 .6356 Mdot
.60368 .36871 Mdot
.67324 .6005 Mdot
.5675 .66568 Mdot
.34683 .54668 Mdot
.60576 .35855 Mdot
.38654 .42593 Mdot
.37171 .37614 Mdot
.54972 .39975 Mdot
.82774 .50212 Mdot
.36385 .57969 Mdot
.34524 .51098 Mdot
.53183 .40416 Mdot
.60914 .40886 Mdot
.35812 .41293 Mdot
.54079 .62905 Mdot
.52463 .8 Mdot
.66055 .62987 Mdot
.54675 .45936 Mdot
.55742 .43186 Mdot
.23518 .59681 Mdot
.3691 .5847 Mdot
.46432 .72028 Mdot
.53554 .40703 Mdot
.24253 .58769 Mdot
.53636 .40916 Mdot
.61966 .43465 Mdot
.53137 .63601 Mdot
.52636 .35759 Mdot
.53547 .38006 Mdot
.61253 .33242 Mdot
.33525 .56002 Mdot
.34228 .38284 Mdot
.37695 .35678 Mdot
.4609 .70613 Mdot
.3639 .57633 Mdot
.54307 .4259 Mdot
.36993 .58085 Mdot
.54952 .35551 Mdot
.53881 .39489 Mdot
.32127 .55052 Mdot
.36392 .41158 Mdot
.33533 .4949 Mdot
.57202 .51998 Mdot
.55309 .42504 Mdot
.61711 .39023 Mdot
.681 .53039 Mdot
.40956 .83068 Mdot
.55781 .37443 Mdot
.36674 .37757 Mdot
.55925 .40895 Mdot
.34451 .57183 Mdot
.69329 .6143 Mdot
.35972 .38014 Mdot
.5542 .63114 Mdot
.51099 .64989 Mdot
.27305 .39511 Mdot
.45146 .73508 Mdot
.61816 .40605 Mdot
.44048 .40782 Mdot
.37131 .43495 Mdot
.78252 .6877 Mdot
.51492 .63066 Mdot
.63513 .62969 Mdot
.56724 .43167 Mdot
.38389 .62478 Mdot
.36672 .53041 Mdot
.60315 .12061 Mdot
.2489 .66064 Mdot
.62419 .62609 Mdot
.34352 .78185 Mdot
.45369 .71543 Mdot
.54539 .37013 Mdot
.65507 .64142 Mdot
.51706 .67337 Mdot
.57789 .35678 Mdot
.494 .42197 Mdot
.65842 .56625 Mdot
.50272 .62565 Mdot
.36584 .58404 Mdot
.5521 .67187 Mdot
.70565 .61036 Mdot
.44278 .73254 Mdot
.38032 .38002 Mdot
.57946 .39011 Mdot
.5974 .33699 Mdot
.54777 .62786 Mdot
.43646 .72485 Mdot
.52839 .41038 Mdot
.36581 .3715 Mdot
.54963 .68085 Mdot
.57686 .42803 Mdot
.43439 .23341 Mdot
.33224 .4297 Mdot
.53816 .66244 Mdot
.59426 .37155 Mdot
.46477 .4296 Mdot
.55346 .63707 Mdot
.54431 .62263 Mdot
.54624 .39959 Mdot
.69682 .63563 Mdot
.52171 .40641 Mdot
.32891 .57393 Mdot
.68494 .5891 Mdot
.34531 .56928 Mdot
.71127 .66085 Mdot
.62673 .43228 Mdot
.37198 .74112 Mdot
.39954 .40187 Mdot
.71075 .61417 Mdot
.29514 .29326 Mdot
.61118 .40561 Mdot
.71993 .28685 Mdot
.41572 .48244 Mdot
.83855 .57286 Mdot
.5029 .15682 Mdot
.67789 .62673 Mdot
.36179 .57432 Mdot
.54866 .38464 Mdot
.33119 .5275 Mdot
.65348 .63781 Mdot
.77948 .54667 Mdot
.59783 .37468 Mdot
.38302 .40744 Mdot
.52505 .41342 Mdot
.36177 .41973 Mdot
.55513 .4015 Mdot
.54999 .48334 Mdot
.61398 .63814 Mdot
.61056 .53671 Mdot
.6049 .37253 Mdot
.35484 .20777 Mdot
.43908 .59342 Mdot
.67224 .63326 Mdot
.53434 .43125 Mdot
.45236 .72667 Mdot
.34511 .60094 Mdot
.68986 .36458 Mdot
.5315 .64206 Mdot
.31684 .55399 Mdot
.34752 .40696 Mdot
.5216 .62153 Mdot
.44114 .70801 Mdot
.56861 .32611 Mdot
.64235 .61954 Mdot
.36306 .54639 Mdot
.57511 .38575 Mdot
.56447 .36489 Mdot
.50567 .77205 Mdot
.41997 .66163 Mdot
.41354 .39759 Mdot
.20657 .37573 Mdot
.33234 .36441 Mdot
.65554 .62593 Mdot
.52974 .63728 Mdot
.56108 .37312 Mdot
.59207 .42041 Mdot
.55021 .68861 Mdot
.34364 .37417 Mdot
.4976 .6437 Mdot
.49527 .26057 Mdot
.54521 .61426 Mdot
.73574 .53246 Mdot
.35415 .37584 Mdot
.73272 .53543 Mdot
.70575 .60977 Mdot
.67439 .26342 Mdot
.70459 .45863 Mdot
.32435 .57581 Mdot
.73974 .53048 Mdot
.37307 .38851 Mdot
.54384 .41042 Mdot
.45687 .71626 Mdot
.45775 .73235 Mdot
.34765 .41161 Mdot
.50739 .66263 Mdot
.68774 .61757 Mdot
.54508 .3846 Mdot
.3104 .72384 Mdot
.26664 .45833 Mdot
.55992 .62899 Mdot
.52097 .47293 Mdot
.34052 .55931 Mdot
.53915 .37903 Mdot
.65433 .61365 Mdot
.36154 .54889 Mdot
.42845 .73488 Mdot
.2307 .49494 Mdot
.5754 .4348 Mdot
.21806 .57146 Mdot
.36818 .56814 Mdot
.43934 .80191 Mdot
.57695 .42 Mdot
.33418 .5558 Mdot
.58591 .47938 Mdot
.27645 .64861 Mdot
.44146 .52185 Mdot
.77009 .33252 Mdot
.51336 .60886 Mdot
.50913 .65812 Mdot
.33449 .67365 Mdot
.61334 .65965 Mdot
.31571 .55025 Mdot
.44174 .73185 Mdot
.74532 .43543 Mdot
.33827 .56228 Mdot
.52748 .38303 Mdot
.57565 .36905 Mdot
.46681 .25921 Mdot
.45925 .52215 Mdot
.43777 .7297 Mdot
.23908 .39867 Mdot
.5926 .44192 Mdot
.50916 .4353 Mdot
.5905 .41531 Mdot
.40474 .40334 Mdot
.37263 .56342 Mdot
.2629 .28097 Mdot
.35792 .58256 Mdot
.31752 .7385 Mdot
.54362 .65285 Mdot
.55248 .61931 Mdot
.57399 .37838 Mdot
.39641 .75832 Mdot
.68702 .33244 Mdot
.57257 .45239 Mdot
.49445 .72661 Mdot
.78922 .4935 Mdot
.53153 .46622 Mdot
.37077 .36126 Mdot
.61806 .3615 Mdot
.36356 .44692 Mdot
.34598 .53998 Mdot
.68108 .62194 Mdot
.69561 .65116 Mdot
.35945 .54452 Mdot
.58793 .39311 Mdot
.51767 .71909 Mdot
.59995 .39678 Mdot
.53746 .40528 Mdot
.28462 .7196 Mdot
.6411 .6421 Mdot
.52296 .64191 Mdot
.66051 .63896 Mdot
.33498 .40186 Mdot
.88886 .38875 Mdot
.66905 .61392 Mdot
.47031 .36617 Mdot
.74813 .58938 Mdot
.73866 .53377 Mdot
.37209 .37508 Mdot
.70612 .62178 Mdot
.35862 .58553 Mdot
.8533 .55077 Mdot
.43829 .83015 Mdot
.33736 .51915 Mdot
.58149 .423 Mdot
.39264 .38816 Mdot
.39754 .41849 Mdot
.3078 .54901 Mdot
.38951 .39655 Mdot
.64173 .40378 Mdot
.5451 .41732 Mdot
.31628 .54937 Mdot
.27019 .48405 Mdot
.35906 .53884 Mdot
.21696 .48066 Mdot
.53032 .42428 Mdot
.35538 .37776 Mdot
.62508 .36559 Mdot
.36053 .34995 Mdot
.467 .72104 Mdot
.57578 .35534 Mdot
.69331 .62471 Mdot
.46764 .5132 Mdot
.53845 .66035 Mdot
.37439 .63805 Mdot
.38486 .41615 Mdot
.3548 .49878 Mdot
.39213 .40385 Mdot
.39104 .38253 Mdot
.35833 .59385 Mdot
.33241 .41054 Mdot
.54747 .38346 Mdot
.48084 .7604 Mdot
.36331 .42446 Mdot
.35685 .56459 Mdot
.68884 .62803 Mdot
.35684 .40785 Mdot
.49994 .67487 Mdot
.56288 .42297 Mdot
.54231 .67334 Mdot
.61644 .63928 Mdot
.3709 .3703 Mdot
.70518 .62278 Mdot
.5289 .62317 Mdot
.64061 .62683 Mdot
.79774 .54051 Mdot
.33678 .53251 Mdot
.36035 .78649 Mdot
.51646 .48471 Mdot
.3847 .42725 Mdot
.6067 .62985 Mdot
.56115 .37501 Mdot
.56273 .42506 Mdot
.70958 .61983 Mdot
.39694 .42041 Mdot
.82018 .42965 Mdot
.45005 .43485 Mdot
.22936 .47634 Mdot
.35438 .53121 Mdot
.21739 .38366 Mdot
.23607 .53992 Mdot
.76504 .6634 Mdot
.52206 .35532 Mdot
.45398 .7159 Mdot
.59079 .3843 Mdot
.30643 .27651 Mdot
.68462 .6086 Mdot
.52965 .82067 Mdot
.55629 .34189 Mdot
.52484 .64935 Mdot
.57122 .41088 Mdot
.67525 .4035 Mdot
.62403 .3738 Mdot
.69161 .64379 Mdot
.28757 .58993 Mdot
.32274 .40552 Mdot
.68154 .63664 Mdot
.51214 .65071 Mdot
.75827 .46731 Mdot
.58184 .3581 Mdot
.59679 .44125 Mdot
.55273 .61533 Mdot
.3863 .40499 Mdot
.50289 .67081 Mdot
.33354 .5545 Mdot
.67433 .61757 Mdot
.56382 .43234 Mdot
.50652 .39917 Mdot
.49662 .71541 Mdot
.37332 .56246 Mdot
.53814 .61628 Mdot
.34415 .58448 Mdot
.45498 .71555 Mdot
.60889 .36932 Mdot
.56057 .62146 Mdot
.55915 .36245 Mdot
.27044 .30358 Mdot
.29442 .7297 Mdot
.45931 .33393 Mdot
.52012 .64399 Mdot
.73137 .51099 Mdot
.35032 .57346 Mdot
.3359 .57898 Mdot
.35304 .33061 Mdot
.7031 .3594 Mdot
.65694 .7237 Mdot
.46147 .18824 Mdot
.33316 .55401 Mdot
.34717 .56582 Mdot
.5219 .67859 Mdot
.33837 .41547 Mdot
.38036 .44094 Mdot
.51245 .62729 Mdot
.62178 .53685 Mdot
.374 .39598 Mdot
.72968 .2984 Mdot
.51643 .68882 Mdot
.51732 .35881 Mdot
.47479 .70545 Mdot
.68247 .6181 Mdot
.61785 .53624 Mdot
.67326 .40051 Mdot
.55899 .36995 Mdot
.19525 .54994 Mdot
.54016 .63269 Mdot
.70196 .56334 Mdot
.6633 .22768 Mdot
.60194 .3803 Mdot
.57989 .40835 Mdot
.59048 .39803 Mdot
.64503 .64531 Mdot
.31298 .28508 Mdot
.55719 .36894 Mdot
.62002 .54381 Mdot
.57751 .45841 Mdot
.68406 .45045 Mdot
.65741 .63701 Mdot
.29861 .3584 Mdot
.52192 .60546 Mdot
.27069 .66329 Mdot
.61361 .48345 Mdot
.334 .56698 Mdot
.58718 .61485 Mdot
.34155 .54409 Mdot
.69307 .31418 Mdot
.70623 .46138 Mdot
.40115 .37929 Mdot
.55295 .37568 Mdot
.57493 .62456 Mdot
.39768 .4014 Mdot
.43518 .75533 Mdot
.90761 .51088 Mdot
.37556 .56254 Mdot
.42082 .85572 Mdot
.33748 .58124 Mdot
.46431 .72656 Mdot
.35519 .41269 Mdot
.57258 .26151 Mdot
.48923 .52162 Mdot
.35592 .40603 Mdot
.28818 .53189 Mdot
.32662 .36417 Mdot
.73746 .51739 Mdot
.32015 .40858 Mdot
.35561 .56861 Mdot
.38747 .59582 Mdot
.49684 .40182 Mdot
.56323 .38004 Mdot
.54878 .55733 Mdot
.45271 .39804 Mdot
.56052 .37865 Mdot
.52243 .66142 Mdot
.41607 .80599 Mdot
.56595 .6043 Mdot
.36179 .42875 Mdot
.378 .57041 Mdot
.57802 .40924 Mdot
.54514 .42063 Mdot
.55514 .35975 Mdot
.22585 .3266 Mdot
.73431 .3081 Mdot
.53772 .39718 Mdot
.53753 .45312 Mdot
.516 .64286 Mdot
.70759 .60206 Mdot
.39486 .19932 Mdot
.73504 .43994 Mdot
.59863 .42148 Mdot
.66282 .63748 Mdot
.63222 .63287 Mdot
.59025 .36008 Mdot
.31702 .71843 Mdot
.47479 .76589 Mdot
.57501 .38614 Mdot
.70114 .43553 Mdot
.57755 .6703 Mdot
.44766 .73606 Mdot
.54866 .62936 Mdot
.32715 .3735 Mdot
.44135 .72695 Mdot
.57102 .65636 Mdot
.56643 .25436 Mdot
.4602 .70458 Mdot
.26529 .59792 Mdot
.69531 .61328 Mdot
.59406 .41449 Mdot
.34263 .35888 Mdot
.5553 .68545 Mdot
.35732 .54241 Mdot
.35493 .38886 Mdot
.34176 .60091 Mdot
.62979 .6149 Mdot
.66715 .55342 Mdot
.45785 .73395 Mdot
.33073 .561 Mdot
.22992 .49567 Mdot
.66122 .63743 Mdot
.34266 .59056 Mdot
.398 .75348 Mdot
.56846 .34531 Mdot
.63526 .2571 Mdot
.55127 .45165 Mdot
.83862 .5241 Mdot
.34834 .59053 Mdot
.45563 .70187 Mdot
.58497 .38908 Mdot
.55168 .64688 Mdot
.61228 .45909 Mdot
.59891 .41669 Mdot
.55897 .63643 Mdot
.53909 .40408 Mdot
.64883 .61825 Mdot
.34078 .43975 Mdot
.38501 .48128 Mdot
.15146 .54456 Mdot
.64319 .62075 Mdot
.42963 .7561 Mdot
.55666 .37483 Mdot
.79704 .51355 Mdot
.35891 .40736 Mdot
.60751 .39069 Mdot
.31514 .33278 Mdot
.34687 .41872 Mdot
.34758 .39153 Mdot
.55312 .44 Mdot
.33094 .58199 Mdot
.54825 .6544 Mdot
.66512 .63955 Mdot
.78534 .65724 Mdot
.58534 .42868 Mdot
.56066 .41191 Mdot
.6803 .63577 Mdot
.34594 .56758 Mdot
.54688 .42314 Mdot
.40334 .63545 Mdot
.8209 .62473 Mdot
.36953 .59131 Mdot
.5553 .3472 Mdot
.57522 .21314 Mdot
.38296 .35226 Mdot
.41653 .84368 Mdot
.71645 .65204 Mdot
.52453 .63014 Mdot
.55231 .48363 Mdot
.68466 .18123 Mdot
.68297 .62184 Mdot
.26012 .66085 Mdot
.53306 .39552 Mdot
.56437 .40263 Mdot
.37934 .38557 Mdot
.53952 .42791 Mdot
.33451 .38604 Mdot
.16471 .59945 Mdot
.16921 .44534 Mdot
.382 .41403 Mdot
.3667 .43132 Mdot
.37769 .34301 Mdot
.37546 .21308 Mdot
.34244 .40638 Mdot
.54732 .35028 Mdot
.78327 .38685 Mdot
.55428 .32811 Mdot
.71096 .62304 Mdot
.62495 .64582 Mdot
.29372 .37793 Mdot
.45195 .6874 Mdot
.42755 .43704 Mdot
.63697 .45435 Mdot
.42501 .5786 Mdot
.32531 .56666 Mdot
.6047 .41145 Mdot
.45355 .73518 Mdot
.55826 .6702 Mdot
.62467 .38341 Mdot
.59748 .40938 Mdot
.36292 .42162 Mdot
.668 .65166 Mdot
.34538 .59734 Mdot
.55363 .40984 Mdot
.49408 .65135 Mdot
.6617 .62542 Mdot
.36598 .42718 Mdot
.38624 .34242 Mdot
.65427 .6447 Mdot
.58175 .47245 Mdot
.56052 .39011 Mdot
.52897 .40942 Mdot
.56504 .49157 Mdot
.3364 .53837 Mdot
.55416 .69152 Mdot
.528 .37171 Mdot
.23844 .63102 Mdot
.5874 .55141 Mdot
.51582 .37673 Mdot
.37876 .39291 Mdot
.37081 .53349 Mdot
.46593 .71578 Mdot
.77089 .49395 Mdot
.58014 .43401 Mdot
.73403 .31074 Mdot
.49096 .24955 Mdot
.44226 .72599 Mdot
.39829 .38104 Mdot
.69077 .63752 Mdot
.58221 .44602 Mdot
.75168 .3585 Mdot
.57578 .37052 Mdot
.48829 .46132 Mdot
.53422 .62914 Mdot
.32385 .56212 Mdot
.83632 .5916 Mdot
.56117 .66631 Mdot
.34621 .38985 Mdot
.77528 .3308 Mdot
.3933 .43124 Mdot
.32424 .40458 Mdot
.70162 .30577 Mdot
.33385 .5414 Mdot
.66553 .16651 Mdot
.42832 .83407 Mdot
.51742 .39391 Mdot
.3458 .57626 Mdot
.36267 .41669 Mdot
.53912 .37982 Mdot
.3679 .43373 Mdot
.32624 .39533 Mdot
.57032 .35323 Mdot
.562 .39515 Mdot
.56739 .52341 Mdot
.69703 .25958 Mdot
.68305 .64218 Mdot
.3538 .37167 Mdot
.41551 .25922 Mdot
.55313 .36888 Mdot
.5816 .37971 Mdot
.47804 .72698 Mdot
.6899 .6443 Mdot
.66342 .41961 Mdot
.53616 .40642 Mdot
.18014 .47825 Mdot
.61627 .38498 Mdot
.36331 .35819 Mdot
.36888 .59174 Mdot
.30476 .70674 Mdot
.55522 .6878 Mdot
.35144 .36916 Mdot
.66795 .60683 Mdot
.39198 .36411 Mdot
.46178 .3688 Mdot
.33916 .5411 Mdot
.36464 .37939 Mdot
.5012 .6534 Mdot
.35526 .55033 Mdot
.34391 .59037 Mdot
.78038 .39788 Mdot
.52995 .61705 Mdot
.69227 .60903 Mdot
.34341 .54811 Mdot
.43056 .22975 Mdot
.35993 .56882 Mdot
.43515 .26089 Mdot
.54359 .45138 Mdot
.6364 .54766 Mdot
.24712 .54836 Mdot
.54839 .48676 Mdot
.33914 .53496 Mdot
.65756 .63957 Mdot
.5558 .43638 Mdot
.38832 .39465 Mdot
.67134 .61376 Mdot
.31415 .6093 Mdot
.54694 .62109 Mdot
.39209 .41322 Mdot
.38014 .57355 Mdot
.35217 .37377 Mdot
.7579 .55517 Mdot
.65859 .58458 Mdot
.4102 .596 Mdot
.51079 .53003 Mdot
.54954 .36192 Mdot
.31273 .44626 Mdot
.61887 .40188 Mdot
.59936 .40756 Mdot
.53898 .66188 Mdot
.6706 .53596 Mdot
.36381 .41208 Mdot
.8382 .59487 Mdot
.32828 .56131 Mdot
.18277 .51783 Mdot
.45809 .42405 Mdot
.60602 .41688 Mdot
.35975 .4237 Mdot
.37588 .43858 Mdot
.44358 .34171 Mdot
.53672 .69019 Mdot
.5002 .44354 Mdot
.60735 .45386 Mdot
.49997 .39667 Mdot
.34877 .59009 Mdot
.36775 .64788 Mdot
.50566 .66602 Mdot
.55977 .85535 Mdot
.54015 .62518 Mdot
.59971 .70648 Mdot
.33298 .41243 Mdot
.69063 .61393 Mdot
.57993 .38018 Mdot
.49107 .47274 Mdot
.38204 .36703 Mdot
.72934 .63383 Mdot
.6954 .62782 Mdot
.3163 .65579 Mdot
.32261 .54675 Mdot
.59706 .36582 Mdot
.58747 .36707 Mdot
.53867 .43375 Mdot
.53792 .4445 Mdot
.37626 .57048 Mdot
.52954 .38012 Mdot
.31468 .54501 Mdot
.44948 .22781 Mdot
.17646 .48501 Mdot
.58211 .63768 Mdot
.69415 .36012 Mdot
.38623 .42399 Mdot
.40033 .24125 Mdot
.48928 .43821 Mdot
.30646 .74233 Mdot
.80301 .49235 Mdot
.60905 .43058 Mdot
.51319 .67437 Mdot
.66787 .32761 Mdot
.5793 .63459 Mdot
.21666 .74203 Mdot
.55886 .69981 Mdot
.7516 .30899 Mdot
.54458 .37724 Mdot
.48044 .72258 Mdot
.48088 .42784 Mdot
.58097 .35426 Mdot
.59025 .67093 Mdot
.22261 .4151 Mdot
.27066 .51476 Mdot
.63801 .63731 Mdot
.56773 .42534 Mdot
.32556 .41548 Mdot
.54666 .38211 Mdot
.58492 .37842 Mdot
.53213 .38511 Mdot
.37349 .59081 Mdot
.60712 .35738 Mdot
.52439 .39206 Mdot
.43423 .65662 Mdot
.70699 .51477 Mdot
.55339 .66953 Mdot
.44691 .36225 Mdot
.6649 .61803 Mdot
.37238 .42172 Mdot
.47979 .49163 Mdot
.32264 .57337 Mdot
.40879 .33356 Mdot
.52413 .40409 Mdot
.24404 .53303 Mdot
.38029 .57257 Mdot
.6768 .61543 Mdot
.46124 .70868 Mdot
.79182 .37961 Mdot
.57964 .64584 Mdot
.46159 .70524 Mdot
.53846 .65902 Mdot
.32133 .2894 Mdot
.36041 .42134 Mdot
.55099 .3599 Mdot
.34106 .55431 Mdot
.55011 .65535 Mdot
.67621 .52072 Mdot
.59091 .41114 Mdot
.51726 .6484 Mdot
.54558 .36278 Mdot
.65074 .55648 Mdot
.51056 .77602 Mdot
.57747 .63887 Mdot
.38525 .58834 Mdot
.35436 .55416 Mdot
.69944 .62803 Mdot
.37785 .42156 Mdot
.37315 .38448 Mdot
.36145 .54986 Mdot
.37207 .82117 Mdot
.60014 .41566 Mdot
.54306 .3762 Mdot
.23922 .62852 Mdot
.55356 .38522 Mdot
.75683 .4861 Mdot
.47153 .71899 Mdot
.37847 .42409 Mdot
.53593 .38376 Mdot
.55072 .42499 Mdot
.57139 .43376 Mdot
.75426 .55886 Mdot
.54583 .62626 Mdot
.59044 .44286 Mdot
.67515 .64714 Mdot
.39578 .72046 Mdot
.54605 .37221 Mdot
.50406 .42138 Mdot
.36932 .38423 Mdot
.16683 .4655 Mdot
.32722 .57529 Mdot
.52058 .66471 Mdot
.53373 .62112 Mdot
.63658 .6571 Mdot
.31329 .40975 Mdot
.46951 .71095 Mdot
.70514 .75025 Mdot
.44797 .70797 Mdot
.67227 .63605 Mdot
.68175 .68161 Mdot
.49136 .67981 Mdot
.5237 .67363 Mdot
.31921 .58862 Mdot
.52415 .41553 Mdot
.58483 .44865 Mdot
.26278 .66899 Mdot
.59802 .43593 Mdot
.69206 .62815 Mdot
.3125 .55507 Mdot
.3704 .38933 Mdot
.6817 .61533 Mdot
.34239 .58191 Mdot
.38682 .4028 Mdot
.57285 .34593 Mdot
.57303 .34361 Mdot
.35262 .39167 Mdot
.39639 .39868 Mdot
.57025 .38527 Mdot
.4062 .66092 Mdot
.31885 .38499 Mdot
.36034 .37739 Mdot
.45357 .73762 Mdot
.58125 .63923 Mdot
.59722 .33187 Mdot
.34767 .57846 Mdot
.52979 .40667 Mdot
.58051 .63512 Mdot
.69771 .64031 Mdot
.36622 .40818 Mdot
.54995 .42253 Mdot
.54982 .41273 Mdot
.66825 .63947 Mdot
.65952 .6483 Mdot
.68477 .61485 Mdot
.32266 .5301 Mdot
.54658 .44618 Mdot
.34264 .40398 Mdot
.3256 .5456 Mdot
.63226 .63275 Mdot
.66689 .60094 Mdot
.46069 .65379 Mdot
.56315 .37079 Mdot
.439 .52626 Mdot
.87064 .36607 Mdot
.74927 .45679 Mdot
.46679 .71729 Mdot
.5461 .61328 Mdot
.70842 .54091 Mdot
.50078 .76265 Mdot
.36908 .57314 Mdot
.73749 .40001 Mdot
.71088 .61479 Mdot
.55301 .35681 Mdot
.61622 .38696 Mdot
.58442 .45999 Mdot
.66777 .62319 Mdot
.76517 .53685 Mdot
.39868 .42057 Mdot
.37373 .29436 Mdot
.66534 .61802 Mdot
.5773 .64088 Mdot
.56457 .62288 Mdot
.53954 .6252 Mdot
.59986 .35549 Mdot
.43321 .33707 Mdot
.41074 .2458 Mdot
.37145 .22622 Mdot
.31856 .55064 Mdot
.41209 .40991 Mdot
.79645 .53405 Mdot
.34908 .39354 Mdot
.56105 .66842 Mdot
.66576 .62659 Mdot
.37095 .37912 Mdot
.36869 .54956 Mdot
.34608 .56388 Mdot
.55137 .62542 Mdot
.54995 .6426 Mdot
.54698 .66831 Mdot
.32342 .38242 Mdot
.33267 .41119 Mdot
.58203 .43648 Mdot
.36312 .40123 Mdot
.19862 .57995 Mdot
.62382 .62954 Mdot
.57116 .6294 Mdot
.35996 .57727 Mdot
.36597 .41969 Mdot
.59084 .41842 Mdot
.66705 .70215 Mdot
.27869 .42002 Mdot
.6423 .62679 Mdot
.49143 .78038 Mdot
.25908 .77851 Mdot
.58131 .361 Mdot
.36596 .58507 Mdot
.33499 .73659 Mdot
.58962 .40297 Mdot
.53558 .6401 Mdot
.28709 .28489 Mdot
.43868 .71419 Mdot
.52673 .38781 Mdot
.60142 .42915 Mdot
.34251 .59186 Mdot
.75218 .5933 Mdot
.58238 .43918 Mdot
.21779 .53015 Mdot
.36086 .60225 Mdot
.52235 .6838 Mdot
.82263 .63053 Mdot
.54585 .69927 Mdot
.62283 .52885 Mdot
.45965 .72888 Mdot
.59447 .37727 Mdot
.52611 .665 Mdot
.64385 .63167 Mdot
.53869 .66816 Mdot
.39923 .37926 Mdot
.55016 .66998 Mdot
.56176 .41113 Mdot
.34009 .40364 Mdot
.36783 .57018 Mdot
.20576 .57087 Mdot
.42577 .66701 Mdot
.55198 .64578 Mdot
.45662 .73771 Mdot
.53896 .37411 Mdot
.63233 .47577 Mdot
.62509 .44419 Mdot
.54869 .37274 Mdot
.3393 .54373 Mdot
.35989 .42493 Mdot
.36509 .53616 Mdot
.51075 .4293 Mdot
.20586 .42288 Mdot
.33928 .58433 Mdot
.26557 .56711 Mdot
.67757 .63601 Mdot
.59312 .53012 Mdot
.59257 .42208 Mdot
.34017 .55067 Mdot
.54439 .44495 Mdot
.34995 .43189 Mdot
.47974 .55422 Mdot
.39725 .73577 Mdot
.342 .55499 Mdot
.82898 .45401 Mdot
.46088 .56373 Mdot
.61354 .35217 Mdot
.33546 .5514 Mdot
.3261 .31144 Mdot
.46044 .72538 Mdot
.66182 .63182 Mdot
.63337 .63389 Mdot
.63955 .62816 Mdot
.61019 .41984 Mdot
.48992 .40852 Mdot
.67809 .60323 Mdot
.35768 .5991 Mdot
.69103 .64468 Mdot
.52054 .49963 Mdot
.82742 .44404 Mdot
.67114 .60877 Mdot
.57709 .42361 Mdot
.50753 .43455 Mdot
.70327 .51548 Mdot
.55529 .67754 Mdot
.71659 .28335 Mdot
.59548 .30566 Mdot
.56524 .37762 Mdot
.55089 .32575 Mdot
.39992 .40641 Mdot
.37625 .76053 Mdot
.4569 .40627 Mdot
.49376 .7691 Mdot
.34431 .42647 Mdot
.51365 .69981 Mdot
.37722 .42321 Mdot
.57367 .35943 Mdot
.53882 .39315 Mdot
.36573 .44512 Mdot
.3149 .63542 Mdot
.32905 .698 Mdot
.81734 .58839 Mdot
.36333 .37565 Mdot
.3354 .55973 Mdot
.37603 .56314 Mdot
.31858 .55433 Mdot
.52279 .68932 Mdot
.36642 .36827 Mdot
.56001 .4484 Mdot
.51574 .63935 Mdot
.60314 .41031 Mdot
.34932 .54767 Mdot
.83958 .58536 Mdot
.36982 .38587 Mdot
.57621 .38865 Mdot
.43563 .82823 Mdot
.54415 .6436 Mdot
.65689 .63352 Mdot
.66773 .55914 Mdot
.5089 .68724 Mdot
.35072 .5349 Mdot
.37916 .44024 Mdot
.29116 .56366 Mdot
.44681 .47596 Mdot
.56335 .32875 Mdot
.53333 .35374 Mdot
.76966 .67809 Mdot
.41428 .73148 Mdot
.61368 .38628 Mdot
.51187 .65255 Mdot
.56341 .67435 Mdot
.55432 .42281 Mdot
.37725 .37665 Mdot
.6415 .6149 Mdot
.67485 .64777 Mdot
.56755 .47319 Mdot
.49423 .52529 Mdot
.59117 .53371 Mdot
.54093 .42296 Mdot
.53134 .47686 Mdot
.53664 .61851 Mdot
.45276 .70434 Mdot
.24235 .60856 Mdot
.67308 .60633 Mdot
.53247 .39782 Mdot
.3012 .50366 Mdot
.32819 .40058 Mdot
.54734 .67058 Mdot
.34704 .53683 Mdot
.76915 .55852 Mdot
.50061 .67127 Mdot
.55226 .4217 Mdot
.54758 .42343 Mdot
.34159 .59052 Mdot
.36396 .35826 Mdot
.66802 .6255 Mdot
.51946 .6357 Mdot
.67413 .60559 Mdot
.33337 .40265 Mdot
.3673 .3879 Mdot
.55443 .32786 Mdot
.53802 .47809 Mdot
.55214 .63062 Mdot
.53069 .45414 Mdot
.57203 .65222 Mdot
.75432 .60502 Mdot
.37654 .54386 Mdot
.58562 .36283 Mdot
.40581 .42527 Mdot
.34898 .54528 Mdot
.56708 .39766 Mdot
.75735 .71817 Mdot
.60805 .40314 Mdot
.54332 .69526 Mdot
.19353 .44451 Mdot
.67361 .64526 Mdot
.49128 .34259 Mdot
.64788 .34853 Mdot
.55252 .38788 Mdot
.57055 .63443 Mdot
.61552 .45552 Mdot
.34184 .5882 Mdot
.34545 .42395 Mdot
.37313 .84099 Mdot
.35964 .56481 Mdot
.54265 .3838 Mdot
.67496 .61675 Mdot
.3823 .43709 Mdot
.43971 .7194 Mdot
.24574 .64387 Mdot
.62801 .40662 Mdot
.5622 .34239 Mdot
.52726 .39591 Mdot
.39713 .19307 Mdot
.52438 .66732 Mdot
.36409 .4182 Mdot
.35137 .58965 Mdot
.36612 .55431 Mdot
.53902 .62781 Mdot
.25796 .50977 Mdot
.53869 .56672 Mdot
.75521 .22911 Mdot
.55931 .64259 Mdot
.70615 .63213 Mdot
.52284 .52589 Mdot
.56824 .65381 Mdot
.52149 .65356 Mdot
.53007 .62135 Mdot
.2524 .58233 Mdot
.38345 .39975 Mdot
.54759 .41162 Mdot
.31475 .38953 Mdot
.59605 .37829 Mdot
.62955 .50161 Mdot
.35425 .54358 Mdot
.34206 .42254 Mdot
.76862 .69286 Mdot
.44484 .40936 Mdot
.58488 .40884 Mdot
.79312 .56702 Mdot
.63666 .42113 Mdot
.7515 .5233 Mdot
.63461 .37523 Mdot
.54541 .65279 Mdot
.47357 .39393 Mdot
.50172 .41371 Mdot
.19996 .57107 Mdot
.35836 .57872 Mdot
.46523 .72652 Mdot
.61686 .41911 Mdot
.61888 .43595 Mdot
.35103 .43499 Mdot
.36974 .37813 Mdot
.68182 .60442 Mdot
.59114 .56203 Mdot
.36606 .57429 Mdot
.65051 .57961 Mdot
.56323 .38281 Mdot
.33034 .63412 Mdot
.41945 .35495 Mdot
.56852 .39711 Mdot
.77266 .37288 Mdot
.42189 .33683 Mdot
.58883 .43707 Mdot
.33478 .29638 Mdot
.34858 .56853 Mdot
.19416 .45309 Mdot
.52164 .43553 Mdot
.53503 .64188 Mdot
.33958 .418 Mdot
.40076 .40368 Mdot
.65867 .60939 Mdot
.25414 .70306 Mdot
.34187 .53307 Mdot
.33566 .41676 Mdot
.59334 .40192 Mdot
.34213 .53723 Mdot
.45056 .7342 Mdot
.5032 .40465 Mdot
.73036 .38157 Mdot
.36482 .39863 Mdot
.53596 .45255 Mdot
.24799 .41009 Mdot
.60689 .55049 Mdot
.6539 .20591 Mdot
.31887 .55968 Mdot
.68185 .60987 Mdot
.61684 .34865 Mdot
.70433 .74883 Mdot
.58501 .45793 Mdot
.64196 .5438 Mdot
.30786 .36184 Mdot
.69321 .61457 Mdot
.58391 .39925 Mdot
.57044 .43851 Mdot
.48591 .51553 Mdot
.65981 .64925 Mdot
.60357 .38478 Mdot
.5044 .35143 Mdot
.38527 .40529 Mdot
.46957 .72304 Mdot
.3691 .39595 Mdot
.58117 .42256 Mdot
.49047 .3992 Mdot
.38321 .38722 Mdot
.74338 .66369 Mdot
.70858 .64048 Mdot
.32503 .57291 Mdot
.51412 .46447 Mdot
.53257 .44145 Mdot
.41653 .1671 Mdot
.46691 .7213 Mdot
.3182 .26711 Mdot
.49626 .66034 Mdot
.30988 .50617 Mdot
.49279 .70606 Mdot
.78028 .34334 Mdot
.21229 .57453 Mdot
.62009 .42456 Mdot
.70538 .41248 Mdot
.35309 .27466 Mdot
.35572 .53361 Mdot
.49794 .21592 Mdot
.56313 .37964 Mdot
.58775 .37991 Mdot
.52288 .6809 Mdot
.24627 .5137 Mdot
.32583 .7247 Mdot
.50104 .53547 Mdot
.67184 .628 Mdot
.33447 .39239 Mdot
.55336 .40268 Mdot
.53524 .5743 Mdot
.55817 .66192 Mdot
.38004 .62627 Mdot
.5801 .39145 Mdot
.32703 .75017 Mdot
.25899 .58371 Mdot
.33181 .53919 Mdot
.5576 .62083 Mdot
.50347 .68228 Mdot
.5806 .36733 Mdot
.35504 .53782 Mdot
.58521 .43649 Mdot
.4563 .58055 Mdot
.54166 .46203 Mdot
.66681 .61127 Mdot
.54069 .36851 Mdot
.45299 .5051 Mdot
.70375 .23873 Mdot
.49358 .35237 Mdot
.38584 .38043 Mdot
.51878 .68828 Mdot
.5445 .6272 Mdot
.36965 .38044 Mdot
.54447 .62921 Mdot
.38965 .30369 Mdot
.53589 .28369 Mdot
.67564 .63039 Mdot
.50958 .46403 Mdot
.66032 .61231 Mdot
.46704 .72407 Mdot
.56454 .37312 Mdot
.69965 .75924 Mdot
.55725 .64185 Mdot
.24377 .33397 Mdot
.36215 .56875 Mdot
.46643 .7239 Mdot
.57581 .45922 Mdot
.67489 .68123 Mdot
.55189 .67723 Mdot
.5335 .69802 Mdot
.57376 .43474 Mdot
.37761 .38778 Mdot
.56596 .43666 Mdot
.63787 .41048 Mdot
.46306 .70777 Mdot
.52417 .41326 Mdot
.34251 .58189 Mdot
.33917 .36644 Mdot
.80517 .39757 Mdot
.55755 .68428 Mdot
.56532 .36634 Mdot
.59238 .40126 Mdot
.36986 .43709 Mdot
.55501 .45894 Mdot
.36992 .54956 Mdot
.51272 .08673 Mdot
.6765 .6365 Mdot
.4383 .71046 Mdot
.5543 .693 Mdot
.60564 .43399 Mdot
.54653 .4267 Mdot
.785 .66355 Mdot
.38016 .69918 Mdot
.33559 .57182 Mdot
.61211 .45515 Mdot
.51703 .64203 Mdot
.67693 .61665 Mdot
.34484 .59894 Mdot
.52991 .41164 Mdot
.58348 .38341 Mdot
.67106 .6116 Mdot
.79078 .40776 Mdot
.49226 .77183 Mdot
.3172 .55412 Mdot
.4713 .39837 Mdot
.65466 .71465 Mdot
.59962 .41612 Mdot
.69592 .71005 Mdot
.36187 .37894 Mdot
.33125 .55013 Mdot
.38007 .21637 Mdot
.54441 .36217 Mdot
.37307 .5591 Mdot
.36413 .57614 Mdot
.51468 .39864 Mdot
.31339 .40058 Mdot
.32987 .37727 Mdot
.34737 .37572 Mdot
.16469 .49981 Mdot
.66339 .49076 Mdot
.54792 .66736 Mdot
.34732 .56799 Mdot
.57761 .63319 Mdot
.63152 .63802 Mdot
.58237 .55021 Mdot
.57165 .65811 Mdot
.39885 .40763 Mdot
.56429 .62198 Mdot
.56904 .43582 Mdot
.36869 .56995 Mdot
.52556 .67492 Mdot
.61604 .41306 Mdot
.66244 .39372 Mdot
.44364 .55874 Mdot
.65272 .60676 Mdot
.72604 .64117 Mdot
.54327 .39787 Mdot
.46546 .71529 Mdot
.57181 .38376 Mdot
.31464 .55215 Mdot
.46108 .49303 Mdot
.60894 .4277 Mdot
.55312 .63822 Mdot
.57911 .31176 Mdot
.53929 .68738 Mdot
.62293 .43879 Mdot
.57776 .42173 Mdot
.60238 .40261 Mdot
.58391 .43895 Mdot
.27018 .54078 Mdot
.35301 .53072 Mdot
.66435 .38161 Mdot
.53966 .60201 Mdot
.35526 .40048 Mdot
.40815 .40112 Mdot
.63891 .73776 Mdot
.43818 .70877 Mdot
.34773 .57731 Mdot
.59611 .42175 Mdot
.54463 .69706 Mdot
.84313 .57738 Mdot
.74337 .6741 Mdot
.7311 .65179 Mdot
.51371 .66187 Mdot
.39105 .38477 Mdot
.55437 .67098 Mdot
.58655 .37154 Mdot
.52206 .3756 Mdot
.79076 .36371 Mdot
.37851 .60514 Mdot
.66599 .62547 Mdot
.6026 .39692 Mdot
.62157 .52658 Mdot
.51607 .64272 Mdot
.53301 .61848 Mdot
.60696 .40309 Mdot
.34731 .36844 Mdot
.56557 .1528 Mdot
.33497 .53767 Mdot
.65643 .32625 Mdot
.35766 .46109 Mdot
.20655 .44954 Mdot
.36313 .54779 Mdot
.43226 .57141 Mdot
.50997 .64025 Mdot
.53083 .31177 Mdot
.35548 .39658 Mdot
.66384 .62294 Mdot
.51991 .37493 Mdot
.39691 .40949 Mdot
.5141 .62469 Mdot
.37628 .42692 Mdot
.56538 .35664 Mdot
.3569 .5328 Mdot
.5283 .62683 Mdot
.38784 .5642 Mdot
.3713 .44538 Mdot
.64759 .62597 Mdot
.58264 .5263 Mdot
.54229 .22331 Mdot
.41747 .3357 Mdot
.58987 .44313 Mdot
.50075 .6064 Mdot
.5484 .4457 Mdot
.33119 .42198 Mdot
.58975 .42382 Mdot
.28925 .39215 Mdot
.55424 .62088 Mdot
.5344 .45096 Mdot
.52781 .38456 Mdot
.49824 .23128 Mdot
.57755 .4045 Mdot
.52043 .41126 Mdot
.58872 .43874 Mdot
.34024 .4552 Mdot
.61653 .36647 Mdot
.38196 .39483 Mdot
.25625 .6495 Mdot
.52293 .65514 Mdot
.65329 .60561 Mdot
.65339 .64334 Mdot
.63282 .54407 Mdot
.60776 .5347 Mdot
.25541 .51709 Mdot
.37474 .40101 Mdot
.35008 .58463 Mdot
.58666 .43587 Mdot
.4259 .20143 Mdot
.6119 .65349 Mdot
.51616 .63228 Mdot
.55109 .6901 Mdot
.55974 .4891 Mdot
.40118 .1899 Mdot
.55603 .46307 Mdot
.24749 .66334 Mdot
.55741 .47194 Mdot
.60685 .38916 Mdot
.50714 .68356 Mdot
.60243 .54249 Mdot
.59135 .44257 Mdot
.35293 .43545 Mdot
.65888 .62388 Mdot
.4401 .42464 Mdot
.51717 .73677 Mdot
.42637 .59974 Mdot
.54418 .25083 Mdot
.55488 .45013 Mdot
.52472 .63164 Mdot
.39172 .41326 Mdot
.23717 .60215 Mdot
.32581 .54624 Mdot
.24324 .5534 Mdot
.44285 .23808 Mdot
.78065 .61393 Mdot
.66198 .62504 Mdot
.78523 .40331 Mdot
.56047 .41064 Mdot
.52076 .68991 Mdot
.56573 .3528 Mdot
.84466 .5726 Mdot
.70612 .62398 Mdot
.3707 .36322 Mdot
.33555 .56192 Mdot
.3448 .4296 Mdot
.46341 .334 Mdot
.41828 .57867 Mdot
.48766 .59056 Mdot
.57698 .6516 Mdot
.6629 .4269 Mdot
.34577 .41165 Mdot
.53774 .41392 Mdot
.80239 .27768 Mdot
.35986 .37837 Mdot
.34665 .37255 Mdot
.74627 .61225 Mdot
.75242 .62622 Mdot
.58371 .47682 Mdot
.37704 .42896 Mdot
.55905 .6121 Mdot
.67003 .64237 Mdot
.56546 .4417 Mdot
.57826 .44063 Mdot
.37843 .38547 Mdot
.56013 .67072 Mdot
.66067 .32633 Mdot
.54802 .64766 Mdot
.38645 .40742 Mdot
.53842 .6513 Mdot
.58649 .64105 Mdot
.51915 .66705 Mdot
.53706 .44761 Mdot
.58947 .4268 Mdot
.54976 .7384 Mdot
.36725 .38806 Mdot
.54578 .43036 Mdot
.53625 .39838 Mdot
.34427 .40708 Mdot
.49513 .64853 Mdot
.45336 .19755 Mdot
.55405 .37629 Mdot
.56512 .42201 Mdot
.68892 .61174 Mdot
.49421 .69037 Mdot
.50143 .79055 Mdot
.55588 .43674 Mdot
.69633 .64452 Mdot
.3215 .38614 Mdot
.5713 .38674 Mdot
.52273 .50252 Mdot
.58103 .64915 Mdot
.53906 .3681 Mdot
.43895 .72264 Mdot
.59554 .44351 Mdot
.58954 .171 Mdot
.559 .36653 Mdot
.36095 .41532 Mdot
.34564 .41905 Mdot
.74208 .59766 Mdot
.34513 .38785 Mdot
.45803 .73125 Mdot
.35199 .54925 Mdot
.84383 .53883 Mdot
.44874 .73318 Mdot
.60956 .39545 Mdot
.42828 .83427 Mdot
.51873 .43781 Mdot
.61519 .42198 Mdot
.35026 .22295 Mdot
.44737 .73211 Mdot
.35491 .42103 Mdot
.29401 .61872 Mdot
.55849 .47299 Mdot
.34633 .53627 Mdot
.51382 .37493 Mdot
.52426 .38199 Mdot
.20051 .50391 Mdot
.26992 .34712 Mdot
.31257 .5633 Mdot
.58954 .32564 Mdot
.55508 .43659 Mdot
.44127 .68313 Mdot
.59211 .41256 Mdot
.66604 .60842 Mdot
.34492 .37492 Mdot
.56437 .65204 Mdot
.68182 .63838 Mdot
.55814 .38481 Mdot
.66827 .62079 Mdot
.54541 .67045 Mdot
.33609 .54534 Mdot
.57164 .36845 Mdot
.7106 .62773 Mdot
.67104 .6268 Mdot
.54391 .4408 Mdot
.34023 .42035 Mdot
.4646 .38321 Mdot
.57058 .3895 Mdot
.5421 .41557 Mdot
.37323 .38464 Mdot
.59229 .84477 Mdot
.58117 .36359 Mdot
.44006 .53257 Mdot
.37245 .36492 Mdot
.47672 .71282 Mdot
.53693 .67754 Mdot
.52484 .37866 Mdot
.34608 .53927 Mdot
.35072 .54342 Mdot
.54423 .61042 Mdot
.35315 .43326 Mdot
.55223 .67927 Mdot
.5509 .32035 Mdot
.53314 .47432 Mdot
.50866 .41225 Mdot
.34188 .8146 Mdot
.77894 .35456 Mdot
.38107 .37887 Mdot
.50487 .66341 Mdot
.50829 .53891 Mdot
.34352 .56849 Mdot
.55773 .6156 Mdot
.37736 .43982 Mdot
.39583 .39124 Mdot
.3866 .42324 Mdot
.69189 .6171 Mdot
.50133 .65963 Mdot
.36664 .35965 Mdot
.34267 .37107 Mdot
.57132 .43497 Mdot
.55264 .43553 Mdot
.33513 .34128 Mdot
.72474 .50623 Mdot
.6493 .62038 Mdot
.53469 .6311 Mdot
.35345 .17207 Mdot
.31391 .55397 Mdot
.50301 .23283 Mdot
.61046 .42682 Mdot
.91875 .47617 Mdot
.55634 .46436 Mdot
.5941 .40508 Mdot
.32446 .37715 Mdot
.70557 .6126 Mdot
.65432 .62008 Mdot
.34471 .41209 Mdot
.38116 .44085 Mdot
.67043 .60769 Mdot
.80365 .47795 Mdot
.83158 .45024 Mdot
.23924 .57889 Mdot
.35446 .41096 Mdot
.56666 .23558 Mdot
.35242 .53574 Mdot
.35717 .44698 Mdot
.31943 .57531 Mdot
.52203 .65169 Mdot
.51061 .63525 Mdot
.33991 .58979 Mdot
.57662 .43447 Mdot
.53856 .67353 Mdot
.60815 .35088 Mdot
.81371 .4664 Mdot
.66578 .28164 Mdot
.36218 .68585 Mdot
.61779 .39299 Mdot
.31264 .71347 Mdot
.34659 .73085 Mdot
.54735 .39191 Mdot
.45015 .45564 Mdot
.66612 .62377 Mdot
.34368 .4482 Mdot
.36785 .54667 Mdot
.64139 .19908 Mdot
.59833 .41859 Mdot
.36627 .41316 Mdot
.35539 .57954 Mdot
.7255 .58005 Mdot
.21756 .52202 Mdot
.60017 .38438 Mdot
.70668 .19443 Mdot
.32657 .43712 Mdot
.56418 .65142 Mdot
.3547 .79662 Mdot
.31679 .38124 Mdot
.71989 .64786 Mdot
.50809 .63525 Mdot
.78303 .64076 Mdot
.37297 .42127 Mdot
.5221 .61596 Mdot
.33484 .39703 Mdot
.65928 .61079 Mdot
.32176 .41697 Mdot
.52396 .62863 Mdot
.58075 .40109 Mdot
.54253 .63252 Mdot
.64744 .62235 Mdot
.52678 .69072 Mdot
.36092 .54087 Mdot
.46453 .72358 Mdot
.35016 .55935 Mdot
.60365 .55327 Mdot
.22737 .38538 Mdot
.32352 .56215 Mdot
.69411 .57461 Mdot
.61468 .38866 Mdot
.36273 .35673 Mdot
.56149 .64003 Mdot
.54342 .60259 Mdot
.55482 .5415 Mdot
.3507 .40131 Mdot
.5338 .62773 Mdot
.4349 .23579 Mdot
.50655 .84981 Mdot
.49014 .41198 Mdot
.68215 .46851 Mdot
.34646 .40713 Mdot
.53849 .6156 Mdot
.23964 .62792 Mdot
.39901 .41326 Mdot
.55918 .6444 Mdot
.3369 .55302 Mdot
.36567 .55212 Mdot
.60339 .41404 Mdot
.39322 .59501 Mdot
.5659 .63253 Mdot
.29085 .66647 Mdot
.32821 .39771 Mdot
.7224 .57663 Mdot
.64784 .61509 Mdot
.51881 .65434 Mdot
.50101 .40591 Mdot
.42151 .38188 Mdot
.58323 .63079 Mdot
.70871 .37063 Mdot
.33622 .1901 Mdot
.53784 .62905 Mdot
.34168 .37727 Mdot
.36857 .40999 Mdot
.63047 .43382 Mdot
.4969 .52475 Mdot
.54183 .68348 Mdot
.67643 .77879 Mdot
.6534 .54127 Mdot
.45518 .71484 Mdot
.41849 .76167 Mdot
.59572 .44064 Mdot
.53939 .4422 Mdot
.3416 .56878 Mdot
.57752 .41217 Mdot
.33809 .37118 Mdot
.58308 .45224 Mdot
.37329 .56596 Mdot
.5123 .63754 Mdot
.56997 .37084 Mdot
.66419 .64244 Mdot
.30929 .56251 Mdot
.33877 .59069 Mdot
.53112 .66015 Mdot
.38047 .42729 Mdot
.59015 .60059 Mdot
.55002 .64112 Mdot
.5592 .45069 Mdot
.44318 .72285 Mdot
.55446 .35999 Mdot
.77033 .41028 Mdot
.39263 .42679 Mdot
.56179 .66328 Mdot
.39922 .38259 Mdot
.35348 .56293 Mdot
.53199 .60511 Mdot
.58568 .41745 Mdot
.55685 .64792 Mdot
.50684 .75116 Mdot
.79314 .43644 Mdot
.35299 .4338 Mdot
.49698 .72132 Mdot
.341 .37538 Mdot
.45552 .71315 Mdot
.76349 .43828 Mdot
.66599 .63244 Mdot
.51879 .64292 Mdot
.76352 .33724 Mdot
.55477 .63626 Mdot
.57496 .40442 Mdot
.56143 .39891 Mdot
.52143 .67935 Mdot
.69532 .63809 Mdot
.16999 .46147 Mdot
.43184 .54182 Mdot
.36254 .42313 Mdot
.55727 .30228 Mdot
.40723 .14761 Mdot
.36769 .60104 Mdot
.33963 .57143 Mdot
.58805 .46328 Mdot
.60628 .41546 Mdot
.34338 .59508 Mdot
.37794 .57157 Mdot
.66642 .60386 Mdot
.52602 .62328 Mdot
.30761 .39059 Mdot
.35385 .60368 Mdot
.64895 .39461 Mdot
.6121 .52853 Mdot
.5814 .47445 Mdot
.52561 .34368 Mdot
.59481 .34863 Mdot
.64073 .55466 Mdot
.36913 .58448 Mdot
.54288 .40038 Mdot
.62385 .38532 Mdot
.33167 .55476 Mdot
.65999 .6111 Mdot
.26547 .3628 Mdot
.53618 .64693 Mdot
.73582 .76633 Mdot
.55323 .36383 Mdot
.57508 .39836 Mdot
.319 .54993 Mdot
.44169 .6931 Mdot
.39452 .39897 Mdot
.38285 .43061 Mdot
.52602 .66905 Mdot
.56239 .54577 Mdot
.56247 .45787 Mdot
.54527 .39425 Mdot
.52578 .63976 Mdot
.46493 .72185 Mdot
.33516 .67634 Mdot
.55234 .4138 Mdot
.35647 .57712 Mdot
.58301 .61148 Mdot
.37219 .58196 Mdot
.57897 .35879 Mdot
.57247 .40495 Mdot
.53975 .45023 Mdot
.60699 .41439 Mdot
.32997 .58629 Mdot
.547 .40273 Mdot
.50531 .43561 Mdot
.3636 .42981 Mdot
.53878 .44599 Mdot
.64975 .54813 Mdot
.57287 .4248 Mdot
.65209 .63445 Mdot
.52785 .58522 Mdot
.60297 .40168 Mdot
.5321 .43913 Mdot
.43409 .54225 Mdot
.5862 .39642 Mdot
.31447 .55435 Mdot
.35963 .40312 Mdot
.34689 .56739 Mdot
.3509 .5905 Mdot
.5708 .62024 Mdot
.6706 .60427 Mdot
.61025 .43716 Mdot
.641 .63186 Mdot
.52958 .34605 Mdot
.56362 .35581 Mdot
.59818 .61912 Mdot
.24851 .66519 Mdot
.50315 .7672 Mdot
.58553 .4197 Mdot
.52268 .66259 Mdot
.56361 .65596 Mdot
.70655 .39713 Mdot
.61747 .3602 Mdot
.34263 .59681 Mdot
.34024 .55104 Mdot
.75482 .47611 Mdot
.20226 .51262 Mdot
.64821 .62645 Mdot
.55771 .56296 Mdot
.60421 .35961 Mdot
.54213 .40947 Mdot
.50334 .41005 Mdot
.57512 .65174 Mdot
.45801 .70379 Mdot
.51609 .63175 Mdot
.476 .69811 Mdot
.37426 .57482 Mdot
.58256 .44956 Mdot
.6683 .27007 Mdot
.37645 .37985 Mdot
.35984 .40249 Mdot
.35271 .59853 Mdot
.54939 .68336 Mdot
.64358 .40257 Mdot
.38723 .85371 Mdot
.36937 .45223 Mdot
.67126 .59995 Mdot
.5457 .3884 Mdot
.52856 .66224 Mdot
.36663 .37301 Mdot
.68307 .64869 Mdot
.53154 .38526 Mdot
.50154 .62138 Mdot
.58525 .42631 Mdot
.34917 .27662 Mdot
.35884 .42732 Mdot
.85253 .5647 Mdot
.39115 .43222 Mdot
.30895 .5665 Mdot
.32859 .56449 Mdot
.5676 .39946 Mdot
.34754 .8105 Mdot
.34687 .36009 Mdot
.39432 .58608 Mdot
.70584 .61728 Mdot
.442 .70786 Mdot
.70069 .61881 Mdot
.56977 .65042 Mdot
.65982 .62533 Mdot
.53586 .62085 Mdot
.74588 .47958 Mdot
.3739 .45514 Mdot
.67848 .63761 Mdot
.45128 .66259 Mdot
.60922 .35995 Mdot
.63291 .63024 Mdot
.51994 .45919 Mdot
.5197 .3209 Mdot
.52793 .6414 Mdot
.69359 .6395 Mdot
.53977 .41655 Mdot
.64382 .21681 Mdot
.33591 .57898 Mdot
.33839 .59491 Mdot
.5956 .34225 Mdot
.52679 .62162 Mdot
.36017 .44177 Mdot
.45315 .47958 Mdot
.47459 .7139 Mdot
.54499 .39759 Mdot
.5875 .44776 Mdot
.40876 .40306 Mdot
.41372 .40856 Mdot
.56926 .40432 Mdot
.44972 .2204 Mdot
.5559 .40802 Mdot
.35348 .54114 Mdot
.39611 .39503 Mdot
.36556 .4074 Mdot
.56328 .62753 Mdot
.32736 .41297 Mdot
.52 .34708 Mdot
.35634 .49004 Mdot
.54775 .47118 Mdot
.35872 .56234 Mdot
.4513 .49601 Mdot
.5524 .68889 Mdot
.69182 .26155 Mdot
.40756 .4093 Mdot
.52441 .4184 Mdot
.33075 .38902 Mdot
.68727 .61922 Mdot
.36628 .39032 Mdot
.37055 .36869 Mdot
.56356 .38812 Mdot
.59528 .37837 Mdot
.44853 .73089 Mdot
.50595 .52935 Mdot
.33047 .41264 Mdot
.54988 .40005 Mdot
.52304 .44182 Mdot
.51979 .39339 Mdot
.46058 .53972 Mdot
.37987 .37656 Mdot
.46707 .26131 Mdot
.71968 .36182 Mdot
.33488 .41745 Mdot
.56656 .16521 Mdot
.44025 .71491 Mdot
.4392 .70858 Mdot
.37812 .60047 Mdot
.55147 .41429 Mdot
.51305 .67625 Mdot
.58487 .37079 Mdot
.54785 .32767 Mdot
.58399 .38087 Mdot
.69919 .6395 Mdot
.62056 .4203 Mdot
.45731 .71988 Mdot
.5497 .63649 Mdot
.5426 .37747 Mdot
.57264 .37146 Mdot
.43254 .71345 Mdot
.40307 .41935 Mdot
.39578 .40466 Mdot
.71273 .69788 Mdot
.68311 .62574 Mdot
.33526 .54367 Mdot
.5911 .42937 Mdot
.52299 .66474 Mdot
.54417 .63348 Mdot
.33245 .42035 Mdot
.53727 .64055 Mdot
.32545 .5409 Mdot
.58761 .41384 Mdot
.33863 .59427 Mdot
.68692 .64506 Mdot
.34997 .3732 Mdot
.59603 .42526 Mdot
.57059 .4345 Mdot
.34601 .41922 Mdot
.61426 .38679 Mdot
.6884 .61135 Mdot
.55159 .63173 Mdot
.38216 .41765 Mdot
.35245 .54799 Mdot
.56504 .62644 Mdot
.55701 .42872 Mdot
.32407 .20194 Mdot
.57232 .41217 Mdot
.55254 .42047 Mdot
.82097 .40988 Mdot
.60003 .4585 Mdot
.56075 .6301 Mdot
.40781 .39199 Mdot
.57677 .34127 Mdot
.64149 .52038 Mdot
.72818 .71696 Mdot
.55527 .61213 Mdot
.54639 .38116 Mdot
.70665 .26924 Mdot
.54502 .37847 Mdot
.64474 .58003 Mdot
.56901 .77354 Mdot
.67061 .41692 Mdot
.52548 .34555 Mdot
.32675 .57903 Mdot
.45199 .73152 Mdot
.55059 .62045 Mdot
.35039 .31441 Mdot
.55763 .39202 Mdot
.31769 .30988 Mdot
.53019 .37926 Mdot
.36603 .55115 Mdot
.52246 .32573 Mdot
.53658 .63233 Mdot
.22465 .64196 Mdot
.55847 .44871 Mdot
.38483 .38127 Mdot
.57062 .6277 Mdot
.4419 .70954 Mdot
.54848 .42155 Mdot
.64805 .63915 Mdot
.39137 .56499 Mdot
.52614 .46928 Mdot
.36012 .55863 Mdot
.53476 .39856 Mdot
.57814 .32261 Mdot
.2991 .75717 Mdot
.3639 .42817 Mdot
.33718 .56471 Mdot
.37998 .75159 Mdot
.6108 .37832 Mdot
.3758 .42087 Mdot
.35472 .39735 Mdot
.64779 .61752 Mdot
.4988 .56312 Mdot
.25121 .42251 Mdot
.6225 .24154 Mdot
.4483 .35927 Mdot
.54977 .61543 Mdot
.34598 .71443 Mdot
.56183 .44109 Mdot
.40347 .60103 Mdot
.3144 .56401 Mdot
.5774 .39877 Mdot
.42327 .35363 Mdot
.35167 .37469 Mdot
.56265 .41784 Mdot
.66087 .61169 Mdot
.36548 .63773 Mdot
.39874 .61823 Mdot
.46538 .16533 Mdot
.55568 .6107 Mdot
.51149 .38768 Mdot
.51014 .36166 Mdot
.45935 .73529 Mdot
.55511 .3533 Mdot
.55849 .63082 Mdot
.80641 .51065 Mdot
.70002 .63474 Mdot
.36059 .37173 Mdot
.44052 .71406 Mdot
.59362 .34568 Mdot
.51711 .42479 Mdot
.65589 .60426 Mdot
.52976 .4212 Mdot
.25993 .70737 Mdot
.42515 .75388 Mdot
.53046 .67463 Mdot
.38172 .4244 Mdot
.59931 .35551 Mdot
.46045 .70475 Mdot
.56244 .39222 Mdot
.58771 .27256 Mdot
.52694 .42524 Mdot
.23739 .42732 Mdot
.33836 .41709 Mdot
.35731 .55784 Mdot
.54955 .33604 Mdot
.58992 .38547 Mdot
.66092 .70806 Mdot
.55129 .32738 Mdot
.55832 .36574 Mdot
.36169 .43777 Mdot
.3789 .37907 Mdot
.38063 .39477 Mdot
.55228 .66894 Mdot
.24249 .58962 Mdot
.35497 .57295 Mdot
.58513 .45502 Mdot
.35201 .60327 Mdot
.62439 .30637 Mdot
.6635 .60102 Mdot
.58692 .19378 Mdot
.52361 .40554 Mdot
.3792 .39987 Mdot
.30146 .48952 Mdot
.32287 .38402 Mdot
.51793 .60378 Mdot
.36664 .57352 Mdot
.35514 .37648 Mdot
.5939 .39549 Mdot
.48683 .52656 Mdot
.49544 .17632 Mdot
.34394 .56236 Mdot
.50702 .43054 Mdot
.54234 .60432 Mdot
.5675 .67779 Mdot
.4204 .12908 Mdot
.33497 .57283 Mdot
.35231 .73125 Mdot
.55055 .39383 Mdot
.37846 .38232 Mdot
.31992 .56506 Mdot
.33143 .57844 Mdot
.531 .63935 Mdot
.59948 .38494 Mdot
.60152 .40159 Mdot
.439 .72011 Mdot
.34227 .54884 Mdot
.58713 .33818 Mdot
.51812 .44091 Mdot
.79309 .36655 Mdot
.33682 .33278 Mdot
.63317 .83221 Mdot
.54865 .32073 Mdot
.43735 .35232 Mdot
.52023 .5197 Mdot
.36045 .36652 Mdot
.60341 .39586 Mdot
.58972 .3519 Mdot
.56271 .62857 Mdot
.58034 .41425 Mdot
.5226 .68541 Mdot
.34339 .578 Mdot
.55209 .16799 Mdot
.28791 .4299 Mdot
.80029 .5061 Mdot
.58162 .40906 Mdot
.20098 .47967 Mdot
.69111 .63238 Mdot
.31358 .53254 Mdot
.38936 .40637 Mdot
.60036 .36634 Mdot
.52663 .69444 Mdot
.51793 .64297 Mdot
.35372 .38807 Mdot
.29112 .68146 Mdot
.68658 .71074 Mdot
.58105 .35899 Mdot
.53893 .67826 Mdot
.30347 .51498 Mdot
.43215 .22324 Mdot
.32994 .60047 Mdot
.70357 .63076 Mdot
.51552 .63353 Mdot
.36342 .59354 Mdot
.39897 .35465 Mdot
.35004 .38083 Mdot
.40448 .38428 Mdot
.59406 .74656 Mdot
.53887 .68574 Mdot
.68026 .6404 Mdot
.21813 .56216 Mdot
.21018 .55526 Mdot
.70192 .63567 Mdot
.50913 .64289 Mdot
.37275 .37521 Mdot
.37659 .41424 Mdot
.35975 .40411 Mdot
.21932 .62933 Mdot
.37494 .43431 Mdot
.52106 .25796 Mdot
.51664 .43263 Mdot
.58115 .50232 Mdot
.54716 .3785 Mdot
.32311 .58168 Mdot
.357 .42632 Mdot
.53583 .53068 Mdot
.61189 .40439 Mdot
.48485 .16834 Mdot
.54329 .3949 Mdot
.31796 .59095 Mdot
.55728 .41773 Mdot
.52282 .2253 Mdot
.36921 .36431 Mdot
.58239 .4193 Mdot
.34851 .52702 Mdot
.67378 .62458 Mdot
.30936 .37198 Mdot
.60264 .40057 Mdot
.238 .50349 Mdot
.59577 .45736 Mdot
.81002 .49775 Mdot
.73518 .56222 Mdot
.67289 .59944 Mdot
.50866 .34597 Mdot
.53629 .61297 Mdot
.30312 .37372 Mdot
.48598 .42228 Mdot
.34456 .56085 Mdot
.26216 .32173 Mdot
.51618 .64843 Mdot
.4823 .36017 Mdot
.61749 .45006 Mdot
.66965 .6051 Mdot
.39779 .36165 Mdot
.31546 .55548 Mdot
.61727 .41101 Mdot
.51519 .39938 Mdot
.79621 .4893 Mdot
.49262 .43875 Mdot
.55918 .46026 Mdot
.63776 .61801 Mdot
.47606 .26441 Mdot
.5712 .42814 Mdot
.49965 .63606 Mdot
.40245 .38237 Mdot
.59863 .34381 Mdot
.46616 .25821 Mdot
.55092 .39935 Mdot
.36122 .38205 Mdot
.40827 .38476 Mdot
.27539 .48124 Mdot
.70002 .60993 Mdot
.52687 .42472 Mdot
.76667 .57324 Mdot
.54929 .44739 Mdot
.35925 .57466 Mdot
.57888 .36201 Mdot
.52148 .64661 Mdot
.24369 .6535 Mdot
.55478 .65938 Mdot
.58442 .36738 Mdot
.3594 .4077 Mdot
.32083 .57269 Mdot
.55575 .7467 Mdot
.60705 .76224 Mdot
.51427 .25825 Mdot
.7666 .70005 Mdot
.6981 .62861 Mdot
.64122 .64258 Mdot
.31903 .54117 Mdot
.58164 .42187 Mdot
.74631 .5885 Mdot
.56926 .46974 Mdot
.56383 .4221 Mdot
.58274 .37949 Mdot
.40396 .56705 Mdot
.34619 .57245 Mdot
.54194 .64401 Mdot
.57043 .40595 Mdot
.54975 .40176 Mdot
.33117 .39732 Mdot
.67363 .62638 Mdot
.55824 .65761 Mdot
.67931 .63217 Mdot
.54309 .65979 Mdot
.58451 .16752 Mdot
.52831 .45843 Mdot
.67581 .62305 Mdot
.31392 .54623 Mdot
.37353 .38431 Mdot
.46687 .70664 Mdot
.57144 .64495 Mdot
.53456 .62993 Mdot
.54583 .39662 Mdot
.36818 .3812 Mdot
.32999 .41475 Mdot
.68993 .62139 Mdot
.32569 .55036 Mdot
.58583 .36924 Mdot
.57615 .35595 Mdot
.68922 .38674 Mdot
.57702 .64069 Mdot
.41621 .23877 Mdot
.27265 .50535 Mdot
.58407 .42184 Mdot
.37254 .43019 Mdot
.57223 .37617 Mdot
.70356 .28666 Mdot
.39853 .40776 Mdot
.60662 .38957 Mdot
.19431 .5136 Mdot
.56921 .6651 Mdot
.23848 .46372 Mdot
.53069 .44435 Mdot
.79201 .65607 Mdot
.55369 .44103 Mdot
.76721 .31512 Mdot
.40991 .69642 Mdot
.57924 .453 Mdot
.56546 .43815 Mdot
.60926 .23347 Mdot
.55366 .38614 Mdot
.45802 .71315 Mdot
.51002 .33748 Mdot
.39614 .39086 Mdot
.55231 .52759 Mdot
.48966 .6556 Mdot
.70805 .61833 Mdot
.52625 .66946 Mdot
.48903 .73189 Mdot
.66704 .61049 Mdot
.35359 .41181 Mdot
.58332 .43996 Mdot
.59047 .52798 Mdot
.56391 .61031 Mdot
.63085 .42736 Mdot
.36184 .57402 Mdot
.50164 .71247 Mdot
.51405 .68253 Mdot
.35326 .5516 Mdot
.52534 .38768 Mdot
.48651 .1941 Mdot
.54607 .77981 Mdot
.84939 .54458 Mdot
.31742 .55344 Mdot
.36478 .54782 Mdot
.2349 .61287 Mdot
.70831 .62403 Mdot
.76488 .41652 Mdot
.21574 .45202 Mdot
.34201 .53547 Mdot
.77319 .48881 Mdot
.52199 .62253 Mdot
.23037 .50095 Mdot
.34388 .44823 Mdot
.50717 .41064 Mdot
.59302 .39266 Mdot
.32699 .55156 Mdot
.52388 .49661 Mdot
.32306 .77058 Mdot
.34894 .55886 Mdot
.50501 .37579 Mdot
.47378 .57865 Mdot
.44365 .71773 Mdot
.44036 .72958 Mdot
.69139 .60457 Mdot
.72939 .67517 Mdot
.33495 .40401 Mdot
.66438 .60526 Mdot
.39436 .6279 Mdot
.52622 .41404 Mdot
.34314 .55364 Mdot
.462 .70138 Mdot
.35927 .54845 Mdot
.65903 .61552 Mdot
.67288 .60035 Mdot
.36487 .42982 Mdot
.39444 .40003 Mdot
.42901 .34783 Mdot
.7485 .51042 Mdot
.54394 .37798 Mdot
.3383 .25046 Mdot
.32738 .39994 Mdot
.48048 .39935 Mdot
.69595 .64438 Mdot
.67802 .62502 Mdot
.35887 .28029 Mdot
.59246 .43227 Mdot
.73289 .59523 Mdot
.59385 .425 Mdot
.75044 .42294 Mdot
.56307 .35047 Mdot
.53337 .64065 Mdot
.58304 .44734 Mdot
.59567 .60352 Mdot
.59757 .43738 Mdot
.55833 .36442 Mdot
.52153 .62607 Mdot
.53668 .47329 Mdot
.52116 .64515 Mdot
.58784 .36828 Mdot
.66539 .65233 Mdot
.52343 .6654 Mdot
.67409 .49143 Mdot
.44052 .53481 Mdot
.46332 .71701 Mdot
.64845 .63463 Mdot
.64228 .62099 Mdot
.6208 .53981 Mdot
.38891 .40839 Mdot
.43027 .38502 Mdot
.57934 .42168 Mdot
.53398 .61821 Mdot
.34227 .57143 Mdot
.55128 .40362 Mdot
.57744 .35315 Mdot
.54402 .45639 Mdot
.33971 .38096 Mdot
.54609 .6847 Mdot
.67218 .61986 Mdot
.54304 .67572 Mdot
.68665 .69464 Mdot
.50102 .67296 Mdot
.62127 .37641 Mdot
.53502 .35124 Mdot
.62745 .29097 Mdot
.29184 .31146 Mdot
.17836 .50521 Mdot
.34924 .38429 Mdot
.45435 .72781 Mdot
.67315 .60115 Mdot
.56472 .30532 Mdot
.38502 .4032 Mdot
.52221 .63052 Mdot
.58581 .42616 Mdot
.49796 .40624 Mdot
.33991 .61611 Mdot
.29959 .37537 Mdot
.67061 .5375 Mdot
.51313 .68501 Mdot
.45265 .71356 Mdot
.24056 .5903 Mdot
.45331 .39403 Mdot
.56208 .54203 Mdot
.57886 .3865 Mdot
.65163 .64137 Mdot
.36661 .37304 Mdot
.55041 .75958 Mdot
.33494 .55002 Mdot
.49943 .5263 Mdot
.58197 .41008 Mdot
.26643 .60333 Mdot
.35813 .40665 Mdot
.65472 .61511 Mdot
.32772 .55175 Mdot
.70755 .61489 Mdot
.43985 .72984 Mdot
.7592 .65693 Mdot
.53827 .43815 Mdot
.55737 .36751 Mdot
.32115 .59128 Mdot
.33579 .39967 Mdot
.72649 .63881 Mdot
.79769 .46125 Mdot
.53011 .67956 Mdot
.72811 .59556 Mdot
.33344 .3691 Mdot
.54955 .24713 Mdot
.54658 .67342 Mdot
.35348 .59858 Mdot
.61246 .55098 Mdot
.37354 .56852 Mdot
.60294 .40904 Mdot
.37282 .40361 Mdot
.3409 .58077 Mdot
.6481 .70795 Mdot
.69739 .24681 Mdot
.5649 .24039 Mdot
.56335 .4536 Mdot
.57432 .18497 Mdot
.81904 .44859 Mdot
.483 .46953 Mdot
.36162 .54078 Mdot
.56858 .39072 Mdot
.54621 .35458 Mdot
.56413 .44944 Mdot
.35314 .58603 Mdot
.65237 .67762 Mdot
.52828 .63259 Mdot
.54206 .38882 Mdot
.65633 .60931 Mdot
.52628 .65024 Mdot
.60374 .62951 Mdot
.55339 .62565 Mdot
.39318 .38254 Mdot
.60872 .40443 Mdot
.25158 .56079 Mdot
.72267 .24743 Mdot
.34626 .56623 Mdot
.46306 .71719 Mdot
.5425 .3696 Mdot
.20812 .42624 Mdot
.38077 .396 Mdot
.52797 .67961 Mdot
.57535 .39751 Mdot
.65318 .68755 Mdot
.46033 .69451 Mdot
.54597 .62487 Mdot
.38022 .41428 Mdot
.47302 .46736 Mdot
.57803 .41445 Mdot
.54899 .43987 Mdot
.33926 .40507 Mdot
.73493 .68126 Mdot
.2449 .64839 Mdot
.57263 .3731 Mdot
.35628 .55637 Mdot
.4689 .8644 Mdot
.5223 .4286 Mdot
.36731 .34081 Mdot
.43974 .70926 Mdot
.25006 .50293 Mdot
.40846 .24112 Mdot
.5099 .34321 Mdot
.6252 .23278 Mdot
.5935 .53885 Mdot
.56276 .17087 Mdot
.69248 .66355 Mdot
.4359 .62143 Mdot
.5976 .17281 Mdot
.33861 .52906 Mdot
.59187 .50138 Mdot
.67259 .34028 Mdot
.27334 .67218 Mdot
.51465 .50403 Mdot
.67942 .7531 Mdot
.64345 .72725 Mdot
.48425 .61667 Mdot
.55673 .64212 Mdot
.73651 .40768 Mdot
.58317 .36901 Mdot
.82126 .45667 Mdot
.46508 .22031 Mdot
.31889 .77448 Mdot
.5889 .18793 Mdot
.7683 .56973 Mdot
.51179 .18413 Mdot
.7162 .28381 Mdot
.64305 .29526 Mdot
.28564 .40141 Mdot
.62647 .81784 Mdot
.21577 .56754 Mdot
.78373 .56675 Mdot
.63248 .36627 Mdot
.53947 .57135 Mdot
.80336 .56251 Mdot
.521 .27677 Mdot
.37539 .82093 Mdot
.56742 .64188 Mdot
.39174 .37103 Mdot
.68778 .35972 Mdot
.31602 .36347 Mdot
.35559 .49884 Mdot
.62206 .22981 Mdot
.76407 .32105 Mdot
.51559 .22488 Mdot
.79165 .66408 Mdot
.37333 .31035 Mdot
.15569 .50929 Mdot
.44847 .5633 Mdot
.39105 .36609 Mdot
.56824 .81853 Mdot
.20987 .55283 Mdot
.27639 .428 Mdot
.58764 .30949 Mdot
.61605 .64644 Mdot
.69605 .50543 Mdot
.36498 .41302 Mdot
.40798 .23505 Mdot
.43853 .73336 Mdot
.26877 .38635 Mdot
.57852 .59459 Mdot
.677 .24965 Mdot
.49633 .59276 Mdot
.23468 .51779 Mdot
.33113 .69802 Mdot
.32748 .19865 Mdot
.76437 .5266 Mdot
.74074 .33793 Mdot
.32361 .60622 Mdot
.50908 .49803 Mdot
.30888 .73133 Mdot
.73508 .52641 Mdot
.20485 .54283 Mdot
.30872 .24347 Mdot
.82933 .50711 Mdot
.37719 .18629 Mdot
.3653 .34854 Mdot
.54798 .45739 Mdot
.70784 .31465 Mdot
.45228 .3607 Mdot
.65854 .59987 Mdot
.43351 .17089 Mdot
.6763 .64795 Mdot
.33502 .35318 Mdot
.28618 .67999 Mdot
.52392 .24306 Mdot
.70912 .58344 Mdot
.71991 .63425 Mdot
.62096 .42342 Mdot
.13927 .61337 Mdot
.55081 .17361 Mdot
.26889 .48492 Mdot
.79317 .36532 Mdot
.32436 .63044 Mdot
.72991 .57572 Mdot
.34682 .58209 Mdot
.661 .2073 Mdot
.37857 .4096 Mdot
.65164 .17502 Mdot
.68817 .23076 Mdot
.4147 .8018 Mdot
.29868 .82382 Mdot
.37973 .66895 Mdot
.66744 .39742 Mdot
.60757 .52457 Mdot
.66173 .51782 Mdot
.32431 .76099 Mdot
.42924 .80927 Mdot
.31395 .62903 Mdot
.79393 .61525 Mdot
.62075 .19014 Mdot
.76616 .46228 Mdot
.76495 .61784 Mdot
.29032 .69695 Mdot
.44909 .5328 Mdot
.42355 .38831 Mdot
.41657 .51047 Mdot
.28598 .39235 Mdot
.41868 .17542 Mdot
.44311 .37771 Mdot
.3994 .85508 Mdot
.67859 .65716 Mdot
.42203 .70938 Mdot
.79497 .38982 Mdot
.68346 .4778 Mdot
.60404 .29575 Mdot
.25248 .61271 Mdot
.62501 .41229 Mdot
.24309 .60086 Mdot
.41022 .45187 Mdot
.49329 .72481 Mdot
.2369 .59087 Mdot
.28553 .54299 Mdot
.79466 .47881 Mdot
.66499 .28533 Mdot
.19613 .49437 Mdot
.40017 .39601 Mdot
.71487 .54151 Mdot
.76952 .51214 Mdot
.79507 .37399 Mdot
.37854 .75073 Mdot
.854 .53006 Mdot
.39175 .76335 Mdot
.5631 .46924 Mdot
.48821 .40233 Mdot
.63876 .37056 Mdot
.74699 .532 Mdot
.53147 .45012 Mdot
.26816 .60612 Mdot
.8114 .39545 Mdot
.414 .35101 Mdot
.53464 .71786 Mdot
.27131 .3026 Mdot
.84304 .52676 Mdot
.71081 .32937 Mdot
.40205 .70673 Mdot
.53461 .4918 Mdot
.16299 .42448 Mdot
.53232 .65492 Mdot
.77179 .48098 Mdot
.38206 .55848 Mdot
.58306 .75323 Mdot
.59445 .2367 Mdot
.4041 .79821 Mdot
.81529 .3996 Mdot
.2534 .64598 Mdot
.48894 .77223 Mdot
.60171 .57525 Mdot
.69751 .58295 Mdot
.28844 .29002 Mdot
.51353 .36896 Mdot
.63324 .331 Mdot
.6352 .62856 Mdot
.47877 .33116 Mdot
.72774 .36743 Mdot
.6012 .7835 Mdot
.49217 .40587 Mdot
.51067 .80578 Mdot
.45295 .71027 Mdot
.49359 .5264 Mdot
.46004 .13002 Mdot
.63042 .40434 Mdot
.38244 .68224 Mdot
.82931 .51977 Mdot
.71309 .55801 Mdot
.77275 .36906 Mdot
.26572 .56288 Mdot
.36011 .20116 Mdot
.71875 .25499 Mdot
.60108 .77124 Mdot
.52401 .15585 Mdot
.85812 .45657 Mdot
.32798 .22175 Mdot
.32326 .28511 Mdot
.34006 .52391 Mdot
.60569 .12293 Mdot
.50936 .65974 Mdot
.24649 .33906 Mdot
.44449 .36125 Mdot
.62009 .69216 Mdot
.34431 .4362 Mdot
.60862 .47057 Mdot
.49118 .60486 Mdot
.31472 .42138 Mdot
.60483 .3485 Mdot
.3728 .1711 Mdot
.2695 .27757 Mdot
.38356 .1712 Mdot
.82566 .56954 Mdot
.53431 .15818 Mdot
.67717 .40644 Mdot
.53218 .26015 Mdot
.71074 .38346 Mdot
.57969 .36067 Mdot
.73983 .45398 Mdot
.37619 .67494 Mdot
.53275 .77855 Mdot
.26517 .42033 Mdot
.31731 .40639 Mdot
.42781 .18459 Mdot
.36396 .14469 Mdot
.3853 .3029 Mdot
.42901 .27071 Mdot
.3984 .61004 Mdot
.75414 .51296 Mdot
.39203 .45798 Mdot
.49147 .79241 Mdot
.79645 .38428 Mdot
.67207 .33681 Mdot
.78255 .49171 Mdot
.62027 .7847 Mdot
.63447 .58721 Mdot
.44794 .68399 Mdot
.6748 .23984 Mdot
.68218 .43784 Mdot
.4148 .79107 Mdot
.59482 .50819 Mdot
.36385 .79634 Mdot
.66639 .73926 Mdot
.47021 .74087 Mdot
.77931 .53041 Mdot
.56355 .67988 Mdot
.75842 .45773 Mdot
.47843 .57063 Mdot
.6916 .34359 Mdot
.59369 .538 Mdot
.75846 .45199 Mdot
.63155 .58841 Mdot
.45188 .15861 Mdot
.87286 .49768 Mdot
.23168 .31494 Mdot
.79836 .64315 Mdot
.40987 .45657 Mdot
.51342 .41618 Mdot
.83141 .43694 Mdot
.42393 .15598 Mdot
.73637 .26985 Mdot
.27609 .647 Mdot
.64477 .70225 Mdot
.30911 .5466 Mdot
.23176 .32111 Mdot
.70193 .72464 Mdot
.74587 .31361 Mdot
.18037 .5035 Mdot
.37945 .59921 Mdot
.25672 .67268 Mdot
.2468 .3227 Mdot
.56845 .22558 Mdot
.38472 .25883 Mdot
.62475 .44204 Mdot
.49601 .21585 Mdot
.40448 .39357 Mdot
.32701 .70209 Mdot
.7421 .52592 Mdot
.53036 .65931 Mdot
.67365 .46651 Mdot
.63 .32348 Mdot
.6195 .42841 Mdot
.4857 .65964 Mdot
.40111 .43475 Mdot
.28799 .32132 Mdot
.28761 .56359 Mdot
.56851 .153 Mdot
.36621 .69346 Mdot
.59811 .32217 Mdot
.73377 .55183 Mdot
.51714 .75865 Mdot
.24556 .61409 Mdot
.35168 .53214 Mdot
.62098 .20514 Mdot
.396 .49564 Mdot
.72061 .5428 Mdot
.47857 .2138 Mdot
.78033 .43221 Mdot
.53547 .35191 Mdot
.28568 .49563 Mdot
.55698 .28576 Mdot
.51267 .53361 Mdot
.34016 .35665 Mdot
.41539 .42208 Mdot
.83248 .64924 Mdot
.37664 .63909 Mdot
.39955 .75133 Mdot
.63146 .21292 Mdot
.36814 .57831 Mdot
.3213 .39714 Mdot
.74577 .43903 Mdot
.80037 .4854 Mdot
.52815 .29029 Mdot
.52254 .69672 Mdot
.60718 .64909 Mdot
.63371 .76628 Mdot
.57935 .19001 Mdot
.5346 .18384 Mdot
.31093 .77276 Mdot
.33063 .42032 Mdot
.7695 .40503 Mdot
.79544 .50339 Mdot
.33292 .38282 Mdot
.32058 .35257 Mdot
.25968 .38848 Mdot
.51174 .14404 Mdot
.24685 .57468 Mdot
.78891 .64536 Mdot
.63399 .55359 Mdot
.65996 .68152 Mdot
.53756 .75415 Mdot
.77284 .58876 Mdot
.63815 .21769 Mdot
.39811 .23494 Mdot
.54959 .2108 Mdot
.59761 .32764 Mdot
.30803 .33031 Mdot
.22075 .33058 Mdot
.45516 .55276 Mdot
.54496 .24305 Mdot
.3172 .50759 Mdot
.55475 .45076 Mdot
.32945 .19745 Mdot
.81443 .47044 Mdot
.22201 .59721 Mdot
.37485 .53117 Mdot
.54461 .42479 Mdot
.53463 .45919 Mdot
.50355 .47946 Mdot
.262 .49793 Mdot
.27705 .28106 Mdot
.77521 .58859 Mdot
.43891 .45457 Mdot
.45877 .21774 Mdot
.38221 .6841 Mdot
.67772 .25497 Mdot
.8103 .42535 Mdot
.50328 .55151 Mdot
.37098 .67908 Mdot
.60075 .56254 Mdot
.80542 .62118 Mdot
.51683 .58475 Mdot
.68125 .3889 Mdot
.221 .42374 Mdot
.26257 .52853 Mdot
.52803 .76174 Mdot
.54007 .3691 Mdot
.2897 .67989 Mdot
.70976 .28063 Mdot
.34647 .8178 Mdot
.32328 .74945 Mdot
.35895 .17173 Mdot
.59435 .26592 Mdot
.25906 .53839 Mdot
.51527 .19393 Mdot
.33456 .81889 Mdot
.50923 .59512 Mdot
.47287 .17577 Mdot
.60042 .57052 Mdot
.60659 .19875 Mdot
.37332 .53579 Mdot
.21911 .52507 Mdot
.26779 .30767 Mdot
.52357 .1478 Mdot
.72752 .33882 Mdot
.65117 .23149 Mdot
.59251 .51189 Mdot
.48175 .14239 Mdot
.22175 .41142 Mdot
.48233 .62202 Mdot
.53654 .60577 Mdot
.27378 .62936 Mdot
.4124 .2075 Mdot
.33316 .46968 Mdot
.77649 .48782 Mdot
.46927 .66142 Mdot
.58061 .29991 Mdot
.52252 .20564 Mdot
.70257 .46437 Mdot
.27237 .53255 Mdot
.73136 .55304 Mdot
.7303 .2889 Mdot
.47954 .66762 Mdot
.54859 .74624 Mdot
.38373 .72165 Mdot
.76498 .65155 Mdot
.26173 .49247 Mdot
.36883 .64558 Mdot
.73772 .33364 Mdot
.69897 .7146 Mdot
.77045 .55726 Mdot
.88119 .59497 Mdot
.78652 .59552 Mdot
.27542 .37702 Mdot
.40886 .18225 Mdot
.80337 .40213 Mdot
.27908 .3489 Mdot
.30196 .74974 Mdot
.32296 .32718 Mdot
.74359 .47943 Mdot
.58443 .38038 Mdot
.44216 .13837 Mdot
.70395 .49635 Mdot
.4198 .17283 Mdot
.84197 .47787 Mdot
.49561 .21235 Mdot
.61614 .44012 Mdot
.49552 .67017 Mdot
.42465 .59704 Mdot
.7067 .45205 Mdot
.56294 .20999 Mdot
.33092 .32445 Mdot
.49162 .70843 Mdot
.44577 .74387 Mdot
.51121 .69117 Mdot
.44988 .43228 Mdot
.35626 .67703 Mdot
.2695 .51221 Mdot
.72994 .62486 Mdot
.5214 .56357 Mdot
.76231 .50448 Mdot
.41483 .2377 Mdot
.57638 .23048 Mdot
.38858 .79661 Mdot
.34688 .49789 Mdot
.56304 .63154 Mdot
.62879 .25105 Mdot
.7976 .58584 Mdot
.28699 .52734 Mdot
.33765 .22373 Mdot
.25439 .62585 Mdot
.72505 .41127 Mdot
.70751 .3491 Mdot
.34834 .7795 Mdot
.67086 .7861 Mdot
.37783 .21262 Mdot
.29104 .33599 Mdot
.7264 .5885 Mdot
.64869 .33384 Mdot
.58496 .16859 Mdot
.78288 .54807 Mdot
.6961 .33331 Mdot
.44159 .54589 Mdot
.49651 .29686 Mdot
.48078 .2055 Mdot
.66323 .49526 Mdot
.55197 .54135 Mdot
.14977 .48254 Mdot
.33295 .43457 Mdot
.31393 .20466 Mdot
.34197 .54415 Mdot
.20261 .61724 Mdot
.63905 .59424 Mdot
.47766 .56175 Mdot
.55741 .53556 Mdot
.28517 .4883 Mdot
.23638 .4267 Mdot
.81311 .58866 Mdot
.39309 .81066 Mdot
.49993 .66403 Mdot
.75366 .59475 Mdot
.75412 .67543 Mdot
.61931 .23588 Mdot
.605 .35544 Mdot
.78476 .60915 Mdot
.45421 .54748 Mdot
.5299 .77788 Mdot
.82968 .44695 Mdot
.32851 .48649 Mdot
.5225 .35072 Mdot
.75142 .51537 Mdot
.46941 .17798 Mdot
.70321 .24541 Mdot
.25329 .69409 Mdot
.41031 .45214 Mdot
.32472 .53075 Mdot
.65843 .45708 Mdot
.58748 .20149 Mdot
.70005 .56824 Mdot
.2323 .53254 Mdot
.76911 .52179 Mdot
.22179 .29113 Mdot
.29282 .26454 Mdot
.27602 .28275 Mdot
.73233 .56601 Mdot
.31632 .37079 Mdot
.24536 .37254 Mdot
.69865 .33931 Mdot
.31303 .4853 Mdot
.81021 .55387 Mdot
.77083 .4888 Mdot
.26348 .74855 Mdot
.59535 .29225 Mdot
.69064 .69274 Mdot
.45234 .20441 Mdot
.45653 .34815 Mdot
.35859 .5245 Mdot
.73249 .47667 Mdot
.37782 .47893 Mdot
.30873 .56659 Mdot
.27326 .52573 Mdot
.23597 .49615 Mdot
.69454 .3307 Mdot
.54055 .27856 Mdot
.42166 .45447 Mdot
.65685 .26964 Mdot
.31005 .40897 Mdot
.55179 .75828 Mdot
.53197 .74849 Mdot
.46823 .4851 Mdot
.52098 .6736 Mdot
.5139 .33986 Mdot
.52025 .54284 Mdot
.58061 .56031 Mdot
.20985 .37018 Mdot
.66264 .64666 Mdot
.31466 .39383 Mdot
.20002 .58578 Mdot
.33396 .37872 Mdot
.40285 .15291 Mdot
.48235 .79101 Mdot
.47839 .21593 Mdot
.62196 .75826 Mdot
.58114 .80688 Mdot
.15422 .5908 Mdot
.32224 .27158 Mdot
.42913 .53411 Mdot
.29993 .41562 Mdot
.38524 .433 Mdot
.52607 .70574 Mdot
.45021 .74136 Mdot
.39337 .26136 Mdot
.39543 .66953 Mdot
.71757 .39607 Mdot
.38876 .36163 Mdot
.69149 .68203 Mdot
.48276 .35886 Mdot
.52848 .1444 Mdot
.55935 .63751 Mdot
.16276 .40046 Mdot
.51758 .45221 Mdot
.63965 .28554 Mdot
.83037 .42007 Mdot
.25071 .68031 Mdot
.47962 .7628 Mdot
.70853 .74792 Mdot
.59815 .44402 Mdot
.42437 .45065 Mdot
.36691 .41512 Mdot
.75118 .40087 Mdot
.66207 .62736 Mdot
.68706 .53849 Mdot
.34884 .60323 Mdot
.42525 .79 Mdot
.35144 .68279 Mdot
.3313 .36466 Mdot
.35959 .47505 Mdot
.72804 .35181 Mdot
.21406 .4914 Mdot
.45458 .54474 Mdot
.6126 .23613 Mdot
.52616 .28721 Mdot
.39323 .36431 Mdot
.32754 .23819 Mdot
.79263 .51006 Mdot
.66629 .20539 Mdot
.64389 .42877 Mdot
.44283 .579 Mdot
.20497 .49125 Mdot
.28389 .50975 Mdot
.40226 .24708 Mdot
.79368 .37974 Mdot
.72653 .53567 Mdot
.21192 .54004 Mdot
.7558 .45011 Mdot
.56582 .48211 Mdot
.49372 .58462 Mdot
.30921 .67532 Mdot
.22812 .70383 Mdot
.32797 .29451 Mdot
.28496 .71075 Mdot
.28975 .39607 Mdot
.38157 .6812 Mdot
.32055 .42633 Mdot
.57679 .71924 Mdot
.51958 .2818 Mdot
.44543 .76394 Mdot
.61862 .17873 Mdot
.79948 .38604 Mdot
.36182 .614 Mdot
.59466 .63734 Mdot
.5439 .51781 Mdot
.62142 .34172 Mdot
.48442 .51261 Mdot
.58072 .45396 Mdot
.46803 .44147 Mdot
.24078 .66402 Mdot
.30261 .48989 Mdot
.60921 .46795 Mdot
.5737 .17061 Mdot
.67518 .21138 Mdot
.47222 .14663 Mdot
.72199 .59217 Mdot
.36726 .36719 Mdot
.3382 .2089 Mdot
.44282 .24643 Mdot
.72908 .28425 Mdot
.36617 .22389 Mdot
.84611 .62667 Mdot
.56064 .21253 Mdot
.30325 .51995 Mdot
.42156 .80679 Mdot
.24362 .44053 Mdot
.82742 .46737 Mdot
.48089 .62786 Mdot
.54051 .71011 Mdot
.83107 .4753 Mdot
.13782 .59917 Mdot
.31492 .29135 Mdot
.23558 .50816 Mdot
.6645 .34406 Mdot
.45071 .47227 Mdot
.41609 .65703 Mdot
.57494 .36148 Mdot
.57753 .62232 Mdot
.49655 .77051 Mdot
.76667 .50224 Mdot
.6349 .30277 Mdot
.41565 .66053 Mdot
.70908 .44505 Mdot
.74485 .40912 Mdot
.78343 .57365 Mdot
.5823 .22436 Mdot
.39921 .25711 Mdot
.52964 .34511 Mdot
.30705 .38859 Mdot
.6991 .61119 Mdot
.49556 .73456 Mdot
.6026 .38436 Mdot
.46478 .75812 Mdot
.22061 .45159 Mdot
.36003 .17481 Mdot
.5573 .71976 Mdot
.80609 .47578 Mdot
.36029 .44942 Mdot
.27027 .49763 Mdot
.68571 .2817 Mdot
.27648 .67308 Mdot
.42515 .6637 Mdot
.44331 .37621 Mdot
.56314 .17731 Mdot
.25112 .60053 Mdot
.78601 .4632 Mdot
.18876 .42863 Mdot
.31517 .57634 Mdot
.30666 .31781 Mdot
.67843 .36119 Mdot
.26171 .64187 Mdot
.38102 .35404 Mdot
.28196 .55846 Mdot
.45239 .60954 Mdot
.25849 .60748 Mdot
.83069 .52098 Mdot
.75384 .38853 Mdot
.43073 .21021 Mdot
.54233 .18278 Mdot
.56687 .61877 Mdot
.78206 .48772 Mdot
.28368 .56361 Mdot
.4354 .63897 Mdot
.20032 .50283 Mdot
.56917 .15843 Mdot
.50395 .52157 Mdot
.69004 .50072 Mdot
.54681 .44262 Mdot
.46942 .25971 Mdot
.29528 .48526 Mdot
.60894 .5956 Mdot
.38803 .74055 Mdot
.39765 .4068 Mdot
.34871 .70166 Mdot
.47612 .69101 Mdot
.73263 .49035 Mdot
.3343 .45435 Mdot
.36753 .33609 Mdot
.63185 .61381 Mdot
.47847 .70313 Mdot
.57304 .33887 Mdot
.68249 .51392 Mdot
.69123 .57794 Mdot
.31046 .30881 Mdot
.30656 .29133 Mdot
.61844 .23938 Mdot
.80757 .50288 Mdot
.29933 .51017 Mdot
.36387 .22348 Mdot
.24148 .42048 Mdot
.5501 .26046 Mdot
.32587 .72129 Mdot
.53915 .45367 Mdot
.58112 .71666 Mdot
.31939 .38775 Mdot
.59355 .21198 Mdot
.58787 .27041 Mdot
.67557 .48953 Mdot
.47632 .53801 Mdot
.70019 .29415 Mdot
.44374 .5133 Mdot
.83063 .42719 Mdot
.24551 .43908 Mdot
.74043 .52605 Mdot
.38341 .58324 Mdot
.61034 .57195 Mdot
.33862 .76719 Mdot
.6588 .21229 Mdot
.39621 .80052 Mdot
.59504 .52209 Mdot
.27545 .69877 Mdot
.26669 .3504 Mdot
.83729 .47389 Mdot
.74124 .5088 Mdot
.48138 .51155 Mdot
.47558 .36705 Mdot
.32635 .61278 Mdot
.46663 .70719 Mdot
.59558 .71622 Mdot
.41739 .2551 Mdot
.62004 .6705 Mdot
.45532 .76865 Mdot
.58364 .33599 Mdot
.19541 .44851 Mdot
.55031 .18019 Mdot
.55881 .302 Mdot
.46714 .5628 Mdot
.57316 .76556 Mdot
.7246 .49953 Mdot
.71566 .79363 Mdot
.32856 .1971 Mdot
.544 .44101 Mdot
.58698 .54253 Mdot
.69595 .53147 Mdot
.51702 .68257 Mdot
.39528 .27164 Mdot
.61216 .23177 Mdot
.36407 .5457 Mdot
.63294 .70868 Mdot
.27356 .61733 Mdot
.28574 .47962 Mdot
.66349 .48449 Mdot
.40116 .582 Mdot
.38298 .15993 Mdot
.80193 .59008 Mdot
.29396 .50123 Mdot
.77426 .73035 Mdot
.29151 .66795 Mdot
.39584 .44778 Mdot
.72269 .32515 Mdot
.45493 .15708 Mdot
.7203 .55937 Mdot
.59294 .74736 Mdot
.29388 .29655 Mdot
.73421 .52861 Mdot
.7595 .43082 Mdot
.38302 .72063 Mdot
.35659 .70883 Mdot
.4744 .61021 Mdot
.58395 .80568 Mdot
.22202 .37046 Mdot
.42514 .22323 Mdot
.5109 .17495 Mdot
.45958 .78146 Mdot
.27659 .76158 Mdot
.66044 .20692 Mdot
.72986 .4558 Mdot
.40831 .67353 Mdot
.73822 .34097 Mdot
.65162 .54269 Mdot
.43867 .37594 Mdot
.47849 .78659 Mdot
.50974 .30388 Mdot
.55737 .80678 Mdot
.3479 .74648 Mdot
.75822 .45518 Mdot
.44325 .35511 Mdot
.5153 .52522 Mdot
.61164 .24324 Mdot
.41835 .75197 Mdot
.74618 .55512 Mdot
.63558 .71658 Mdot
.64064 .52918 Mdot
.63565 .24875 Mdot
.72744 .3121 Mdot
.48487 .50772 Mdot
.13843 .59089 Mdot
.43262 .17608 Mdot
.29192 .69258 Mdot
.51669 .43153 Mdot
.61075 .17041 Mdot
.45711 .48667 Mdot
.34825 .23453 Mdot
.82185 .51694 Mdot
.53195 .74121 Mdot
.2047 .47542 Mdot
.54814 .45812 Mdot
.33056 .25819 Mdot
.54501 .23966 Mdot
.45223 .34821 Mdot
.50403 .76993 Mdot
.73293 .54964 Mdot
.41623 .73312 Mdot
.6473 .50742 Mdot
.64175 .36332 Mdot
.32868 .37234 Mdot
.40034 .162 Mdot
.63565 .47837 Mdot
.4782 .37743 Mdot
.57199 .5022 Mdot
.39608 .80617 Mdot
.73818 .74363 Mdot
.6448 .37904 Mdot
.24677 .59614 Mdot
.77565 .49149 Mdot
.7107 .3692 Mdot
.31748 .28164 Mdot
.34523 .86347 Mdot
.82539 .40598 Mdot
.36929 .44265 Mdot
.33985 .31673 Mdot
.74411 .5724 Mdot
.48185 .14993 Mdot
.62342 .78222 Mdot
.51745 .75467 Mdot
.40716 .82996 Mdot
.66463 .5492 Mdot
.57616 .35415 Mdot
.83653 .54504 Mdot
.66611 .21707 Mdot
.43431 .78689 Mdot
.59093 .17379 Mdot
.61635 .44393 Mdot
.51773 .44275 Mdot
.51631 .89431 Mdot
.60521 .20719 Mdot
.62475 .41956 Mdot
.37134 .80318 Mdot
.41953 .38001 Mdot
.59009 .37499 Mdot
.39881 .64868 Mdot
.77992 .54505 Mdot
.75098 .41869 Mdot
.52191 .14763 Mdot
.33363 .36106 Mdot
.46647 .75994 Mdot
.36877 .59235 Mdot
.5571 .53722 Mdot
.4991 .39788 Mdot
.34563 .58563 Mdot
.73086 .41424 Mdot
.47156 .49108 Mdot
.39063 .56535 Mdot
.76279 .60695 Mdot
.85611 .54732 Mdot
.59174 .25959 Mdot
.359 .61877 Mdot
.5219 .48399 Mdot
.56226 .29859 Mdot
.70838 .44926 Mdot
.70514 .40511 Mdot
.83192 .49638 Mdot
.86469 .41348 Mdot
.57003 .69099 Mdot
.61643 .47087 Mdot
.3565 .45816 Mdot
.41156 .24945 Mdot
.55276 .22319 Mdot
.36277 .51769 Mdot
.45109 .73345 Mdot
.58084 .46435 Mdot
.64369 .36756 Mdot
.35402 .60421 Mdot
.26295 .24974 Mdot
.55792 .36006 Mdot
.37285 .24494 Mdot
.71487 .27369 Mdot
.54827 .75906 Mdot
.62406 .28554 Mdot
.61421 .42361 Mdot
.23828 .38572 Mdot
.44985 .48305 Mdot
.47618 .47394 Mdot
.53719 .75121 Mdot
.50626 .16027 Mdot
.59062 .27173 Mdot
.41515 .21846 Mdot
.54404 .39934 Mdot
.68849 .65161 Mdot
.22751 .50109 Mdot
.3034 .27588 Mdot
.61754 .32651 Mdot
.72339 .26994 Mdot
.53909 .74 Mdot
.62811 .66641 Mdot
.65013 .31529 Mdot
.40872 .17212 Mdot
.31916 .74024 Mdot
.52816 .21704 Mdot
.22741 .61503 Mdot
.32677 .64949 Mdot
.70416 .46548 Mdot
.49663 .67264 Mdot
.60732 .47068 Mdot
.40958 .37036 Mdot
.42628 .13224 Mdot
.29773 .28208 Mdot
.29236 .59694 Mdot
.49429 .71333 Mdot
.50844 .24534 Mdot
.54253 .52931 Mdot
.81463 .68386 Mdot
.68419 .74932 Mdot
.37709 .16202 Mdot
.74445 .38901 Mdot
.42821 .42589 Mdot
.2677 .54961 Mdot
.49183 .38714 Mdot
.54328 .62645 Mdot
.48987 .15319 Mdot
.65094 .39673 Mdot
.34742 .7385 Mdot
.57143 .3547 Mdot
.21031 .5796 Mdot
.40669 .47381 Mdot
.59104 .6446 Mdot
.57707 .66133 Mdot
.3074 .75137 Mdot
.70689 .28478 Mdot
.44398 .48366 Mdot
.80612 .6732 Mdot
.53301 .19375 Mdot
.6232 .20604 Mdot
.52058 .69576 Mdot
.22832 .67563 Mdot
.30943 .44463 Mdot
.39195 .47101 Mdot
.28933 .56152 Mdot
.61512 .51965 Mdot
.2611 .6297 Mdot
.71872 .38064 Mdot
.23098 .46704 Mdot
.3554 .6136 Mdot
.91525 .45211 Mdot
.73613 .44469 Mdot
.58987 .31092 Mdot
.29826 .68572 Mdot
.6015 .1873 Mdot
.68353 .59252 Mdot
.84544 .55163 Mdot
.54185 .56957 Mdot
.50054 .41022 Mdot
.54951 .28016 Mdot
.65001 .30313 Mdot
.27814 .62777 Mdot
.14382 .53395 Mdot
.80201 .57321 Mdot
.60029 .66769 Mdot
.51716 .5626 Mdot
.3305 .38578 Mdot
.34612 .4368 Mdot
.60372 .77765 Mdot
.83302 .60203 Mdot
.43327 .46418 Mdot
.59026 .20216 Mdot
.17185 .61949 Mdot
.76948 .4243 Mdot
.49163 .14685 Mdot
.298 .4338 Mdot
.31112 .35916 Mdot
.71169 .43911 Mdot
.70946 .65032 Mdot
.56147 .6769 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0Xoooool2o`000:Cooooo000Looooo`03o`000?oooooooooo0:?ooooo0_l0
002Tooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0<3ooooo0ol00026ooooo`007?ooool00ol0003oooooooooo`30ooooo`Co0000QOooool0
01cooooo00?o0000ooooooooool0QOooool2o`0000?ooooo0_l0000fooooo`;o0000QOooool001co
oooo00?o0000ooooooooool0QOooool4o`000003ooooool0003o000000Kooooo0_l0002eooooo`00
7?ooool00ol0003oooooooooo`27ooooo`;o00002Oooool2o`000;Gooooo000Looooo`03o`000?oo
oooooooo08cooooo0_l0000@ooooo`;o0000ZOooool001cooooo00?o0000ooooooooool0S?ooool2
o`00013ooooo0_l0002Yooooo`007?ooool00ol0003oooooooooo`2Iooooo`;o00001oooool2o`00
00Cooooo0_l0002Oooooo`007?ooool00ol0003oooooooooo`1booooo`;o00003Oooool2o`0001?o
oooo0_l000001?oooooo0000o`000?ooool2o`0000Cooooo0_l00002ooooo`Co0000Woooool001co
oooo00?o0000ooooooooool0L_ooool2o`0000gooooo0_l0000Cooooo`;o000000Coooooo`000?l0
003ooooo0_l00008ooooo`;o0000XOooool001cooooo0_l00020ooooo`;o00006?ooool4o`0000Wo
oooo0_l0000<ooooo`?o0000T_ooool001cooooo00?o0000ooooooooool0Ooooool2o`0000Gooooo
0_l0000Cooooo`;o00000oooool2o`0000Cooooo0_l0000<ooooo`?o0000T_ooool001cooooo00?o
0000ooooooooool0NOooool2o`0000_ooooo0_l00007ooooo`?o00003_ooool2o`0000Cooooo0_l0
0002ooooo`;o00002Oooool2o`0009;ooooo000Looooo`03o`000?oooooooooo07Oooooo1?l00003
ooooo`;o00001_ooool2o`0000?ooooo0_l00002ooooo`?o00003oooool2o`0000Oooooo0_l00009
ooooo`;o0000T_ooool001cooooo00?o0000ooooooooool0Moooool2o`0000Gooooo0_l00006oooo
o`;o00000oooool2o`0000Kooooo0_l0000:ooooo`Co00000_ooool2o`0000Oooooo0_l00004oooo
o`;o0000Toooool001cooooo00?o0000ooooooooool0Q?ooool2o`0000gooooo0_l00005ooooo`;o
00000oooool2o`0000Cooooo0_l00007ooooo`Co00000_ooool2o`0000Cooooo0_l0000Hooooo`;o
0000Loooool001cooooo00?o0000ooooooooool0Koooool4o`0000;ooooo0_l00002ooooo`;o0000
1_ooool2o`000003ooooool0003o000000?ooooo0_l0000?ooooo`;o00005?ooool5o`0000;ooooo
0_l000000ooooooo0000o`000002o`0000Gooooo0_l0000?ooooo`;o0000Loooool001cooooo00?o
0000ooooooooool0Koooool4o`0000;ooooo0_l00002ooooo`;o00001_ooool2o`0000;ooooo0_l0
0002ooooo`;o00005oooool2o`0000_ooooo1_l00002ooooo`;o00000oooool4o`0000?ooooo0_l0
000;ooooo`;o0000Moooool001cooooo00?o0000ooooooooool0LOooool2o`00017ooooo0ol00002
ooooo`;o00002_ooool3o`0000Gooooo0_l00003ooooo`;o00002oooool2o`0000;ooooo0_l00007
ooooo`Co00004?ooool2o`0007Oooooo000Looooo`03o`000?oooooooooo08Cooooo0_l00003oooo
o`;o00002_ooool3o`0000Gooooo0_l0000@ooooo`;o00000_ooool2o`0000Kooooo0_l00008oooo
o`;o00005?ooool2o`0006cooooo000Looooo`03o`000?oooooooooo087ooooo0_l00004ooooo`;o
00006Oooool2o`0000Kooooo1?l000000ooooooo0000o`00000:ooooo`;o00002?ooool2o`0001Co
oooo0_l0001/ooooo`007?ooool00ol0003oooooooooo`1gooooo`;o00002?ooool2o`0000Cooooo
0_l0000Iooooo`;o00001_ooool4o`0000Wooooo1?l00005ooooo`;o0000Qoooool001cooooo00?o
0000ooooooooool0JOooool2o`0000cooooo0_l00006ooooo`;o00004Oooool2o`0002?ooooo1?l0
00000ooooooo0000o`000002ooooo`;o00001?ooool2o`00087ooooo00001_ooooook^k^oc8b<_l0
003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`1Yooooo`;o0000
4_ooool4o`00017ooooo0_l0000?ooooo`;o00001?ooool2o`0000gooooo0_l000001?oooooo0000
o`000?l00008ooooo`;o00005oooool2o`0006Sooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMg
M`Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1f
ooooo`;o00001Oooool2o`0000[ooooo0_l00002ooooo`;o00002oooool2o`000003ooooool0003o
000000Cooooo0ol00003ooooo`;o00000oooool2o`0000_ooooo0_l0000Rooooo`;o000000?ooooo
o`000?l000000oooool2o`00063ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo
00[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`1Wooooo`;o00003Oooool2o`00
00Gooooo0_l0000:ooooo`;o00000_ooool2o`000003ooooool0003o000000Sooooo0_l000000ooo
oooo0000o`000002ooooo`;o000000?oooooo`000?l000002?ooool2o`00017ooooo0_l0000:oooo
o`;o00004?ooool2o`000003ooooool0003o000000?ooooo0_l0001Pooooo`0000?oooooo`000?oo
ool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0001Vooooo`?o
00002?ooool2o`0000[ooooo0_l00008ooooo`;o00001oooool2o`0000oooooo0_l0000Hooooo`?o
00000oooool2o`000003ooooool0003o000000Oooooo0_l0001jooooo`0000?oooooo`000?ooool0
0_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0
H_ooool2o`0000;ooooo0_l00009ooooo`;o00005?ooool2o`0000Kooooo0_l00007ooooo`;o0000
3?ooool2o`0001?ooooo0ol00006ooooo`Go00002?ooool2o`0000;ooooo0_l0001booooo`0000?o
oooooa0@4?ooool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0H_ooool2o`0000Kooooo0_l00004ooooo`;o00002?ooool2o`0000Kooooo0_l0
000;ooooo`?o00001_ooool2o`0000cooooo0_l0000Iooooo`;o00000oooool3o`0000Sooooo1_l0
001booooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@
41001_ooool00ol0003oooooooooo`1Zooooo`;o00001?ooool2o`0000Sooooo0_l00006ooooo`;o
00001?ooool2o`0000Kooooo0_l0000;ooooo`;o00004?ooool2o`0000;ooooo0_l00008ooooo`;o
00000_ooool2o`0000oooooo0ol00003ooooo`;o00003Oooool2o`00063ooooo00001_ooooook^k^
oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooo
oooo07Kooooo0ol0000?ooooo`;o00003_ooool2o`0000?ooooo0_l0000=ooooo`;o000000Cooooo
o`000?l0003ooooo0ol00002ooooo`;o00001?ooool2o`0000[ooooo0_l00007ooooo`;o00001?oo
ool2o`0000gooooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`1booooo`;o00000_ooool4
o`0000Wooooo0_l00003ooooo`;o00001oooool2o`0000Gooooo0_l00003ooooo`?o00002?ooool2
o`0000;ooooo0_l00004ooooo`;o00000oooool2o`00013ooooo0_l000001?oooooo0000o`000?l0
0006ooooo`;o00001_ooool2o`0006[ooooo000Looooo`03o`000?oooooooooo07;ooooo0_l00004
ooooo`;o00002Oooool2o`0000Wooooo0_l000000ooooooo0000o`000003o`0000;ooooo0_l00003
ooooo`?o00002?ooool2o`0002;ooooo0ol00006ooooo`;o00001_ooool2o`0006[ooooo000Loooo
o`03o`000?oooooooooo06Oooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool3o`00
017ooooo0_l000000ooooooo0000o`000003ooooo`;o00000oooool3o`0000Oooooo1?l0000;oooo
o`;o00000_ooool2o`0000Oooooo0_l0002>ooooo`007?ooool00ol0003oooooooooo`1Wooooo`;o
000000?oooooo`000?l000000_ooool2o`0000;ooooo1Ol00008ooooo`;o00001Oooool2o`000003
ooooool0003o0000017ooooo0_l000000ooooooo0000o`000003ooooo`Co00001?ooool2o`0000;o
oooo0_l00003ooooo`;o00000_ooool2o`0001Oooooo1?l0001cooooo`007?ooool00ol0003ooooo
ooooo`1`ooooo`;o00000oooool2o`0000Sooooo0_l00007ooooo`?o00000oooool2o`0000Wooooo
0_l000000ooooooo0000o`000006ooooo`Co00001oooool2o`0000Cooooo1?l0000=ooooo`;o0000
2_ooool6o`0000Cooooo0_l0000Dooooo`;o0000EOooool001cooooo00?o0000ooooooooool0L?oo
ool2o`0001Kooooo0ol00003ooooo`;o00002Oooool2o`0000?ooooo1?l0000=ooooo`;o00001_oo
ool2o`0000Wooooo0ol000001?oooooo0000o`000?l00007ooooo`;o00001?ooool3o`0000?ooooo
0_l0000Dooooo`;o0000EOooool001cooooo00?o0000ooooooooool0KOooool2o`0000oooooo0_l0
00000ooooooo0000o`000006ooooo`?o00004_ooool4o`0001;ooooo0_l00007ooooo`;o00000ooo
ool7o`0000Oooooo1?l00003ooooo`?o0000Koooool001cooooo00?o0000ooooooooool0Ioooool2
o`0000Cooooo0_l0000?ooooo`;o000000?oooooo`000?l000000_l00004ooooo`Go00001_ooool2
o`0000;ooooo0_l00003ooooo`Co00003?ooool2o`0000Gooooo0_l00007ooooo`;o00001?ooool4
o`0000_ooooo0_l00003ooooo`?o00001oooool2o`0006Kooooo000Looooo`03o`000?oooooooooo
06Oooooo0_l0000Eooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o000000?oooooo`00
0?l000001_ooool2o`0000;ooooo0_l00003ooooo`Co00001Oooool2o`0000Gooooo0_l00005oooo
o`;o00003oooool3o`0000oooooo0ol00007ooooo`;o0000I_ooool001cooooo00?o0000oooooooo
ool0HOooool2o`0001;ooooo0_l00007ooooo`;o000000Coooooo`000?l0003o00005oooool2o`00
00Cooooo0_l00003ooooo`;o00001Oooool2o`0000Gooooo0_l00004ooooo`;o000000?oooooo`00
0?l000001?ooool2o`000003ooooool0003o0000013ooooo0_l00007ooooo`;o0000I_ooool001co
oooo00?o0000ooooooooool0HOooool2o`0001;ooooo0_l00008ooooo`;o000000?oooooo`000?l0
00002?ooool2o`0000;ooooo0_l00009ooooo`;o00001?ooool2o`0000cooooo0_l00009ooooo`;o
000000?oooooo`000?l000001?ooool2o`0000Kooooo0_l0000Booooo`Co00001?ooool2o`00063o
oooo000Looooo`;o0000Doooool2o`0001Kooooo0ol0000?ooooo`;o000000Coooooo`000?l0003o
oooo0_l000000ooooooo0000o`000005ooooo`;o00000_ooool2o`0000[ooooo0_l0000?ooooo`Co
00005oooool2o`000003ooooool0003o000000_ooooo0ol00004ooooo`;o00001_ooool2o`00063o
oooo000Looooo`03o`000?oooooooooo05;ooooo0_l0000Eooooo`Co00003oooool2o`0000Cooooo
1Ol0000Eooooo`;o00003oooool2o`0000Gooooo0_l00004ooooo`;o00003?ooool2o`0000kooooo
0ol0000;ooooo`;o0000HOooool001cooooo00?o0000ooooooooool0J?ooool3o`0001?ooooo0_l0
0004ooooo`;o00003_ooool2o`0000gooooo1?l0000=ooooo`;o00001?ooool2o`0000oooooo0_l0
000;ooooo`?o00002oooool2o`00067ooooo000Looooo`03o`000?oooooooooo06Sooooo0_l0000?
ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o00001Oooool2o`0000Sooooo0ol00006
ooooo`;o00001?ooool8o`0000Cooooo0_l00005ooooo`;o00001?ooool2o`0000gooooo0_l0000@
ooooo`Co0000J?ooool001cooooo00?o0000ooooooooool0Foooool2o`0001cooooo0_l000000ooo
oooo0000o`000005ooooo`Co00000oooool2o`0000Sooooo1Ol00004ooooo`;o00002?ooool4o`00
00Cooooo0_l00005ooooo`;o00001?ooool2o`0001;ooooo0_l00005ooooo`;o00001?ooool4o`00
06Sooooo000Looooo`03o`000?oooooooooo05_ooooo0_l00007ooooo`?o00007?ooool4o`0000oo
oooo0ol0000Mooooo`;o00001Oooool2o`00017ooooo0_l00005ooooo`;o0000L?ooool001cooooo
00?o0000ooooooooool0I?ooool3o`0001cooooo0_l00003ooooo`;o00008_ooool2o`0000gooooo
1_l0000Aooooo`;o000000?oooooo`000?l000002oooool2o`0000?ooooo0_l00002ooooo`;o0000
G?ooool001cooooo00?o0000ooooooooool0IOooool2o`0001Kooooo0_l00009ooooo`;o00001?oo
ool2o`0001cooooo0_l0000=ooooo`?o000000?oooooo`000?l000004Oooool2o`000004ooooool0
003o0000o`0000[ooooo1?l000000ooooooo0000o`000002ooooo`;o0000G?ooool001cooooo00?o
0000ooooooooool0Goooool3o`0000?ooooo0_l00007ooooo`?o00003?ooool2o`0000oooooo0_l0
000Eooooo`;o00005?ooool3o`000003ooooool0003o000000Kooooo0_l0000=ooooo`;o00003?oo
ool2o`0006?ooooo000Looooo`03o`000?oooooooooo04_ooooo0_l00007ooooo`;o00002?ooool4
o`0000cooooo0ol0000dooooo`;o00001Oooool2o`0001Sooooo0ol0000hooooo`;o0000A_ooool0
01cooooo00?o0000ooooooooool0Boooool2o`0000Gooooo1_l00005ooooo`?o00000oooool2o`00
00cooooo0_l0000booooo`;o00001Oooool2o`000003ooooool0003o000001Gooooo0_l0000<oooo
o`;o00001Oooool2o`0000Kooooo0_l0000Looooo`;o0000A_ooool001cooooo00?o0000oooooooo
ool0D_ooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000000oooool5o`0000[o
oooo0_l0000booooo`;o00000oooool2o`0000?ooooo1?l0000Dooooo`;o00000oooool3o`0000Go
oooo0_l00005ooooo`;o00001Oooool5o`0000;ooooo0_l0001Nooooo`007?ooool00ol0003ooooo
ooooo`1Jooooo`;o00001_ooool2o`000003ooooool0003o000003kooooo1?l000000ooooooo0000
o`000005ooooo`;o00005?ooool2o`0000?ooooo0ol00005ooooo`;o000000?oooooo`000?l00000
2?ooool3o`000005ooooool0003o0000o`000?ooool01?l000000ooooooo0000o`00001Iooooo`00
7?ooool00ol0003oooooooooo`14ooooo`;o00005?ooool2o`0000Cooooo0_l000000ooooooo0000
o`000002o`0000Cooooo0_l0000jooooo`Co00004oooool2o`0000Sooooo0_l0000=ooooo`;o0000
2?ooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000005Wooooo
000Looooo`03o`000?oooooooooo04Cooooo0_l0000Dooooo`Co00000_ooool2o`000003ooooool0
003o000000Co00000_ooool2o`0000Wooooo0_l0000`ooooo`?o00004?ooool2o`000003ooooool0
003o000000Sooooo0_l00003ooooo`;o00004Oooool2o`0000Sooooo0_l00004ooooo`;o0000Eooo
ool001cooooo00?o0000ooooooooool0C?ooool2o`0000kooooo0_l00009ooooo`Co00002oooool2
o`0002Kooooo0_l0000Cooooo`;o00001_ooool2o`0000?ooooo0_l0000;ooooo`;o00004Oooool2
o`000003ooooool0003o000000Cooooo0_l00005ooooo`;o0000Eoooool001cooooo0_l0001<oooo
o`?o00003_ooool2o`0000_ooooo0_l0000cooooo`;o00004oooool2o`0000Cooooo0_l00005oooo
o`;o00001_ooool2o`0001Kooooo0_l000000ooooooo0000o`000004ooooo`;o0000G_ooool001co
oooo00?o0000ooooooooool0Boooool2o`0000?ooooo0_l00002ooooo`;o00008oooool4o`0002Go
oooo0_l0000=ooooo`?o00001Oooool2o`0000Cooooo0_l00007ooooo`Co00000oooool2o`0000oo
oooo0_l0001Wooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o000000Coooooo`000?l0003o
00005?ooool2o`0000gooooo1?l0000Pooooo`;o00000oooool2o`0000;ooooo0_l00004ooooo`;o
00000oooool5o`0000Sooooo0ol00006ooooo`;o000000?oooooo`000?l000000oooool2o`0000oo
oooo0_l00007ooooo`;o0000G_ooool001cooooo00?o0000ooooooooool0Doooool2o`0000cooooo
1?l00005ooooo`;o00002_ooool2o`0002Gooooo0_l00007ooooo`;o00001?ooool2o`0000Gooooo
0ol00005ooooo`Go00001oooool2o`000003ooooool0003o000001Cooooo0_l00007ooooo`Ko0000
00?oooooo`000?l00000Eoooool001cooooo00?o0000ooooooooool0Foooool2o`0000Cooooo1?l0
00000ooooooo0000o`000003ooooo`;o00002Oooool2o`00037ooooo0_l00009ooooo`;o00000_oo
ool2o`000003ooooool0003o000000;o0000:Oooool2o`000003ooooool0003o000000Go00006Ooo
ool2o`0003cooooo000Looooo`03o`000?oooooooooo04Sooooo0_l00005ooooo`Co00002?ooool2
o`0000Kooooo0_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000002oooool2
o`000003ooooool0003o000002Wooooo0_l00009ooooo`;o00000_ooool2o`0001Gooooo0_l0000<
ooooo`;o00000oooool2o`0000Cooooo0_l00004ooooo`;o00000oooool4o`0001Cooooo0_l0000l
ooooo`007?ooool00ol0003oooooooooo`18ooooo`?o00001?ooool4o`0000gooooo0_l000000ooo
oooo0000o`000006ooooo`;o000000?oooooo`000?l000002oooool2o`000003ooooool0003o0000
02;ooooo0_l00005ooooo`;o00009?ooool2o`0000cooooo0_l00003ooooo`;o00003oooool4o`00
05;ooooo000Looooo`03o`000?oooooooooo04Sooooo0ol000000ooooooo0000o`000003ooooo`;o
00001oooool2o`0000Cooooo0_l00010ooooo`;o000000?oooooo`000?l000000_ooool8o`0000Oo
oooo0_l00005ooooo`;o0000<oooool2o`0005?ooooo000Looooo`03o`000?oooooooooo04Sooooo
0_l00002ooooo`;o00000oooool2o`0000Oooooo0_l0000<ooooo`;o0000>Oooool5o`0000;ooooo
1ol00004ooooo`;o000000?oooooo`000?l000001?l000001?oooooo0000o`000?ooool2o`0000Go
oooo0_l00006ooooo`Co00004_ooool2o`0000_ooooo0_l0001Cooooo`007?ooool00ol0003ooooo
ooooo`16ooooo`;o00007Oooool2o`000003ooooool0003o000003Wooooo0_l000001?oooooo0000
o`000?ooool2o`0000?ooooo1?l000000ooooooo0000o`000004o`000003ooooool0003o000000Co
00000_ooool2o`000003ooooool0003o000000;ooooo0_l00006ooooo`Ko00003?ooool3o`000003
ooooool0003o0000063ooooo000Looooo`03o`000?oooooooooo03Oooooo0_l0000;ooooo`Co0000
1?ooool2o`0000?ooooo0_l0000=ooooo`Co000000?oooooo`000?l000002?ooool2o`0002Oooooo
0_l0000<ooooo`;o000000?oooooo`000?l000000oooool7o`0000;ooooo0_l00005ooooo`;o0000
0oooool4o`0000?ooooo0_l00009ooooo`;o00001?ooool2o`000003ooooool0003o000000?ooooo
0ol0000Booooo`;o0000Coooool001cooooo00?o0000ooooooooool0=oooool2o`0000_ooooo0_l0
0005ooooo`?o00000oooool2o`0000Cooooo0_l00007ooooo`Go00001Oooool2o`0000?ooooo0_l0
000@ooooo`;o00003_ooool4o`0000?ooooo0_l00009ooooo`;o000000?oooooo`000?l000001Ooo
ool2o`000004ooooool0003o0000o`0000_ooooo0_l00003ooooo`;o00001Oooool2o`0000?ooooo
0_l0000:ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Kooooo0_l00008ooooo`Go0000
C_ooool001cooooo00?o0000ooooooooool0?_ooool2o`0000_ooooo0_l0000:ooooo`;o00000_oo
ool2o`0000Kooooo0_l00005ooooo`;o00002?ooool2o`0000Kooooo0_l00003ooooo`;o000000Co
ooooo`000?l0003o00000_ooool2o`0000Kooooo1?l0000=ooooo`?o00000_ooool2o`0000?ooooo
1Ol00006ooooo`;o000000?oooooo`000?l000001?l00002ooooo`;o00001_ooool2o`0000?ooooo
0_l00006ooooo`;o00001Oooool2o`0000Cooooo0_l00006ooooo`?o00001Oooool4o`000003oooo
ool0003o000004kooooo000Looooo`03o`000?oooooooooo03kooooo0_l0000<ooooo`;o00001Ooo
ool2o`0000Kooooo0_l0000<ooooo`;o00002Oooool2o`0000;ooooo0_l00002ooooo`;o00001_oo
ool3o`0000;ooooo1Ol0000Dooooo`?o00000_ooool2o`0000?ooooo1Ol00005ooooo`[o00000_oo
ool2o`0000;ooooo0_l0000?ooooo`;o00001_ooool2o`0000Sooooo0_l000001?oooooo0000o`00
0?l00005ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0??ooool2o`0000kooooo0_l0
0005ooooo`;o00004Oooool2o`000003ooooool0003o000000Wooooo0_l000000ooooooo0000o`00
0003o`0000oooooo0ol0000>ooooo`;o00000oooool4o`0000;ooooo0_l00004ooooo`So000000?o
ooooo`000?l000000ol000000ooooooo0000o`000003o`0000Gooooo0_l0000<ooooo`;o000000?o
ooooo`000?l000001?ooool4o`0000Sooooo0_l000000ooooooo0000o`000003ooooo`;o00001Ooo
ool4o`0004gooooo000Looooo`03o`000?oooooooooo03cooooo0_l0000Fooooo`;o00004?ooool2
o`0000gooooo2?l0000;ooooo`;o00004_ooool2o`0000?ooooo2Ol00002ooooo`oo000000?ooooo
o`000?l000000ol0000Cooooo`;o00001Oooool6o`00013ooooo0_l00005ooooo`Co0000COooool0
01cooooo0_l00013ooooo`;o00003oooool3o`000003ooooool0003o000001Cooooo0_l00002oooo
o`Wo000000Coooooo`000?l0003ooooo0_l00008ooooo`;o00001Oooool4o`0000kooooo0_l00000
0ooooooo0000o`000004o`0000;ooooo3_l00003ooooo`;o00000_ooool3o`000003ooooool0003o
000000;o00001_ooool2o`0000[ooooo0_l00002ooooo`;o000000?oooooo`000?l00000IOooool0
01cooooo00?o0000ooooooooool0@_ooool2o`0000gooooo1?l00002ooooo`;o00001?ooool2o`00
00Gooooo0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o000000?o00000_ooool4o`00
00;ooooo0ol00003ooooo`;o000000?oooooo`000?l000000_ooool4o`000003ooooool0003o0000
00;o00002_ooool2o`000004ooooool0003o0000o`0000;ooooo0ol000001?oooooo0000o`000?l0
0002ooooo`Wo000000?oooooo`000?l000003ol00006ooooo`;o00004Oooool2o`0000Gooooo0_l0
001Nooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o00002_ooool2o`0000Gooooo0_l00003
ooooo`Co00000oooool4o`0000?ooooo1?l00002ooooo`?o00000oooool5o`0000;ooooo1?l0000?
ooooo`;o000000?oooooo`000?l000001?ooool2o`000004ooooool0003o0000o`0000;ooooo4?l0
00000ooooooo0000o`000008o`00023ooooo0_l0000>ooooo`;o0000C_ooool001cooooo00?o0000
ooooooooool0GOooool2o`0000;ooooo0_l00004ooooo`;o00000_ooool4o`000003ooooool0003o
000000?o00000_ooool2o`0000Gooooo0_l00005ooooo`;o00000_ooool2o`000003ooooool0003o
000000;o00002Oooool2o`0000Wooooo1Ol000001?oooooo0000o`000?ooool>o`000004ooooool0
003o0000ooooo`[o00004oooool4o`000003ooooool0003o000000gooooo0_l00007ooooo`;o0000
C_ooool001cooooo00?o0000ooooooooool0C?ooool2o`0000Gooooo0_l00007ooooo`?o000000Co
ooooo`000?l0003o00001?ooool4o`000003ooooool0003o000000Wo00001?ooool4o`0000[ooooo
0_l00002ooooo`Co00002?ooool2o`0000Oooooo1?l000000ooooooo0000o`000004ooooo`Oo0000
0oooool=o`000003ooooool0003o000001;ooooo0_l000000ooooooo0000o`000002o`000003oooo
ool0003o000000?ooooo0_l00008ooooo`;o00000oooool2o`0000;ooooo0_l0001>ooooo`007?oo
ool00ol0003oooooooooo`1<ooooo`?o00001?ooool2o`0000Oooooo0_l00002ooooo`;o000000Co
ooooo`000?l0003ooooo2_l000000ooooooo0000o`000004o`0000Cooooo1?l0000>ooooo`Co0000
1?ooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00003oooooaGo0000
1?ooool4o`000004ooooool0003o0000ooooo`;o00002_ooool2o`000003ooooool0003o000000So
oooo0_l00004ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Kooooo0ol0000Gooooo`;o
0000<?ooool001cooooo00?o0000ooooooooool0COooool2o`0000gooooo0_l00005ooooo`;o0000
00?oooooo`000?l000005ol00005ooooo`;o00003?ooool2o`000003ooooool0003o000000Co0000
0oooool2o`0000;ooooo0ol00004oooooago000000?oooooo`000?l000000ol000000ooooooo0000
o`00000=ooooo`;o00000oooool4o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0000Ko
oooo0ol00003ooooo`?o00005oooool2o`00033ooooo000Looooo`03o`000?oooooooooo043ooooo
0_l00002ooooo`;o00000_ooool2o`0000;ooooo0_l0000Coooooago00000oooool2o`000003oooo
ool0003o000000?ooooo0_l00007ooooo`;o00000oooool2o`0000?ooooo0_l00004ooooo`?o0000
0ooooolNo`0000;ooooo1ol0000Booooo`Co00001?ooool2o`0000Wooooo0_l000001?oooooo0000
o`000?l00004ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0@?ooool2o`0000;ooooo
0ol000000ooooooo0000o`000002ooooo`?o00003ooooolKo`0000?ooooo1ol00006ooooo`;o0000
3?ooool2o`0000?ooooo0_l00004oooooako000000?oooooo`000?l000001?ooool2o`000003oooo
ool0003o000000;o00000oooool2o`0000oooooo0_l00005ooooo`;o00002Oooool2o`000003oooo
ool0003o000000;ooooo0_l000000ooooooo0000o`000019ooooo`007?ooool00ol0003ooooooooo
o`0oooooo`;o00001?ooool2o`0000Kooooo0_l00007ooooo`;o00001?ooool5o`0000Gooooo0ol0
0002oooooaOo00002Oooool3o`0000Sooooo1?l00005ooooob7o000000?oooooo`000?l000000_l0
00001Ooooooo0000o`000?l0003ooooo00;o00001Oooool2o`0001Kooooo0_l0000<ooooo`;o0000
0_ooool2o`000003ooooool0003o000004Wooooo000Looooo`03o`000?oooooooooo03oooooo0_l0
000:ooooo`;o00000_ooool2o`0000Gooooo0_l00004ooooo`;o00001Oooool2o`000003ooooool0
003o000001[o00000oooool2o`0000Cooooo0ol00007ooooo`Go00001Oooool3o`0000;ooooo7_l0
00000ooooooo0000o`000003o`0000Kooooo0_l00004ooooo`;o00004?ooool2o`000003ooooool0
003o000001;ooooo0ol00019ooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00001_ooool2
o`0000;ooooo0_l000000ooooooo0000o`00000?ooooob3o00000_ooool2o`0000Sooooo0_l00002
ooooo`Co00001oooool2o`0000Gooooo7Ol000000ooooooo0000o`000004o`0000Gooooo0_l00004
ooooo`;o00003Oooool2o`000004ooooool0003o0000ooooo`;o00004_ooool4o`0004Sooooo000L
ooooo`03o`000?oooooooooo04?ooooo0_l000000ooooooo0000o`000002ooooo`;o00001_ooool4
o`0000kooooo7ol00002ooooo`;o000000?oooooo`000?l000001Oooool2o`0000;ooooo0_l00003
ooooo`;o00000_ooool4o`000005ooooool0003o0000o`000?ooool01ol000000ooooooo0000o`00
000?o`000005ooooool0003o0000o`000?ooool00ol000000ooooooo0000o`00000Cooooo`;o0000
1Oooool2o`0001Kooooo0_l00002ooooo`?o0000Aoooool001cooooo00?o0000ooooooooool0@_oo
ool2o`0000;ooooo0_l00002ooooo`;o00001Oooool2o`000003ooooool0003o000000[ooooo8Ol0
0005ooooo`Co00003_ooool2o`0000;ooooo0_l00003ooooobSo00000_ooool2o`0000Cooooo0_l0
0006ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Wooooo0_l000000ooooooo0000o`00
0008ooooo`;o000000?oooooo`000?l000001?l00003ooooo`;o00005?ooool2o`0002[ooooo0000
1_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0
1?ooool00ol0003oooooooooo`12ooooo`;o000000?oooooo`000?l000002_ooool2o`0000Kooooo
0ol00004ooooo`Oo000000?oooooo`000?l000005Ol000001?oooooo0000o`000?l00003ooooo`;o
00001oooool2o`0000Gooooo0_l0000;ooooobCo00001?ooool3o`0000?ooooo1?l00004ooooo`;o
00002?ooool3o`0000;ooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l00008oooo
o`;o00000_ooool2o`0000?ooooo0_l0000Dooooo`;o0000:_ooool00006oooooomgMgOoV9RHoooo
oonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`15
ooooo`;o00003_ooool2o`0000;ooooo0ol00006ooooob7o00003?ooool2o`0000Gooooo0_l00007
ooooo`Co000000?oooooo`000?l000008Ol00004ooooo`?o000000Goooooo`000?l0003o0000oooo
o`02o`0000gooooo1Ol000000ooooooo0000o`00000:ooooo`;o00003_ooool2o`0004?ooooo0000
0ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006ooooo`03o`000?oooooo
oooo04Cooooo0_l00004ooooo`;o00002Oooool3o`0000;ooooo0_l00006ooooo`_o000000?ooooo
o`000?l000004_l000000ooooooo0000o`00000:ooooo`Go000000?oooooo`000?l000000ol00002
ooooo`[o000000?oooooo`000?l000007_l00008ooooo`?o00000oooool2o`0000_ooooo0_l00000
0ooooooo0000o`000005ooooo`;o00003?ooool2o`0000Kooooo1Ol00012ooooo`0000?oooooo`00
0?ooool00_ooool00ol0003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0000a
ooooo`;o00004Oooool2o`0000Cooooo0_l00009ooooo`?o000000?oooooo`000?l000001oooool;
o`000003ooooool0003o000001Go00002_ooool5o`000004ooooool0003o0000ooooo`;o000000?o
ooooo`000?l000002Ol000000ooooooo0000o`00000Fo`000003ooooool0003o000000Ko00001Ooo
ool2o`0000Kooooo1?l0000Cooooo`;o000000Coooooo`000?l0003o00002?ooool3o`0000Cooooo
1_l00012ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmE
EEGoooooo`0000Oooooo00?o0000ooooooooool0<Oooool2o`0002Kooooo0_l00006ooooob;o0000
3_ooool2o`0000Kooooo2_l00003oooooaWo000000?oooooo`000?l000001_l000000ooooooo0000
o`000002ooooo`;o00002?ooool3o`0000Oooooo0_l0000<ooooo`?o00001?ooool2o`0000?ooooo
0_l00004ooooo`;o000000?oooooo`000?l000000_ooool2o`0003oooooo00000ooooooo410@oooo
o`02ooooo`03oa0@4?oooooooooo00[ooooo00?oMgMgolc<c?l000001oooool00ol0003ooooooooo
o`1QoooooaKo000000?oooooo`000?l000002ol00006ooooo`Co00000_ooool2o`0000Kooooo2Ol0
0004ooooobWo000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00001oooool2o`0000Sooooo
0_l000000ooooooo0000o`000006ooooo`;o00001Oooool2o`0000Gooooo0_l00002ooooo`;o0000
?oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03
o`000?oooooooooo04Cooooo0_l00007ooooo`;o00003oooool2o`000003ooooool0003o000002;o
00001_ooool4o`0000cooooo6_l000000ooooooo0000o`00000Bo`000003ooooool0003o000000;o
000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00001oooool4o`0000?ooooo0_l000001?oo
oooo0000o`000?ooool2o`0000?ooooo0_l000000ooooooo0000o`000005ooooo`;o00002?ooool2
o`00043ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_oo
ool00ol0003oooooooooo`0kooooo`;o00001oooool3o`0000Kooooo0_l0000=ooooo`Co00000_oo
oolTo`0001Gooooo0ol000000ooooooo0000o`00000Do`000003ooooool0003o0000017o00000_oo
ool4o`0001;ooooo1?l00003ooooo`Co00001oooool2o`000003ooooool0003o000000oooooo0_l0
000<ooooo`;o0000<_ooool001cooooo00?o0000ooooooooool0>oooool2o`0000Sooooo0_l0000E
ooooo`Co00001?oooolNo`0000;ooooo0_l0000Fooooo`;o000000?oooooo`000?l000001?l00000
0ooooooo0000o`00000No`00013ooooo0_l0000Booooo`;o00001?ooool2o`0000?ooooo0_l0000=
ooooo`?o00003_ooool2o`0003;ooooo000Looooo`03o`000?oooooooooo04Wooooo1?l00005oooo
o`;o00000oooool2o`0000Gooooo0_l00003oooooako00004?ooool2o`0000Sooooo0_l00003oooo
obWo00000_ooool2o`0000Oooooo1?l0000Hooooo`;o00000oooool2o`0000gooooo1?l00002oooo
o`;o0000?Oooool001cooooo00?o0000ooooooooool0<Oooool2o`0000cooooo0_l00003ooooo`;o
00000oooool4o`000003ooooool0003o000000;ooooo0_l00003ooooo`;o00001oooool2o`000003
ooooool0003o000000?ooooo1ol000000ooooooo0000o`00000@o`000003ooooool0003o000000Ko
oooo0_l00004ooooo`;o00001oooool5o`000004ooooool0003o0000ooooobKo00000_ooool3o`00
00Kooooo0_l0000Jooooo`?o00000oooool2o`0000kooooo0_l00002ooooo`;o0000?Oooool001co
oooo00?o0000ooooooooool0<Oooool2o`0000cooooo0ol00002ooooo`;o00000oooool3o`0000;o
oooo0_l00006ooooo`;o00002?ooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l0
00004_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00002ooooo`;o00001?ooool2o`00
00?ooooo1_l000000ooooooo0000o`000002o`0000;ooooo9Ol000001?oooooo0000o`000?ooool4
o`000004ooooool0003o0000ooooo`;o00001?ooool2o`0001Cooooo0ol00003ooooo`;o00001Ooo
ool2o`0000Cooooo0_l00005ooooo`Co0000>oooool001cooooo00?o0000ooooooooool0>_ooool2
o`0000?ooooo0ol00004ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000Oooooo0_l0
0002ooooo`;o00002?ooool2o`0000;ooooo0ol000000ooooooo0000o`00000Eo`0000Cooooo0_l0
000:ooooo`;o000000?oooooo`000?l000000_l00005ooooo`Ko000000?oooooo`000?l000007ol0
0002ooooo`;o00000_ooool3o`000004ooooool0003o0000ooooo`;o00001?ooool2o`0001Oooooo
0_l00008ooooo`;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0003_ooooo
000Looooo`03o`000?oooooooooo03[ooooo0_l00003ooooo`;o00001Oooool2o`0000Gooooo0_l0
000;ooooo`;o000000?oooooo`000?l000002OoooolHo`000003ooooool0003o000000_ooooo0_l0
0003ooooo`;o00001oooool2o`0000?ooooo8ol000001?oooooo0000o`000?ooool3o`0000;ooooo
0_l0000Tooooo`;o00000_ooool2o`000003ooooool0003o000000Cooooo0_l00005ooooo`?o0000
?oooool001cooooo00?o0000ooooooooool0GOooool2o`0000Oooooo3?l000000ooooooo0000o`00
0009o`000003ooooool0003o000000Kooooo0_l00005ooooo`;o00003?ooool2o`0000;ooooo8?l0
00001Ooooooo0000o`000?l0003ooooo00Ko00005Oooool2o`0000cooooo0_l00007ooooo`Go0000
0_ooool4o`0000Kooooo1?l0000mooooo`007?ooool00ol0003oooooooooo`10ooooo`Co00002?oo
ool2o`0001Sooooo1?l000000ooooooo0000o`000004o`000003ooooool0003o000000Ko00000_oo
ool2o`000003ooooool0003o000000Kooooo0_l00005ooooo`;o00000_ooool2o`0000Oooooo0ol0
0002ooooob3o00000_ooool7o`00017ooooo0_l00004ooooo`;o000000?oooooo`000?l000001_oo
ool2o`000003ooooool0003o000000Cooooo0_l00003ooooo`;o00000oooool2o`0000[ooooo0_l0
000mooooo`007?ooool00ol0003oooooooooo`0oooooo`Go00001oooool3o`0001gooooo0_l00004
ooooo`go00005?ooool4o`0000Gooooo0ol00006ooooo`Co000000?oooooo`000?l000005_l00003
ooooo`Go00004Oooool2o`0000Oooooo0_l00006ooooo`;o000000?oooooo`000?l000001?ooool2
o`0000Sooooo0_l00019ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00001_ooool2o`00
00;ooooo0ol00007ooooo`Co00005?ooool3o`0000?ooooo0_l00006ooooo`So000000?oooooo`00
0?l000000ol0000>ooooo`;o00001oooool2o`0000Wooooo0_l00003ooooo`Co000000?oooooo`00
0?l000005ol00002ooooo`Go00006_ooool2o`0000Kooooo0_l0000Aooooo`;o00002Oooool2o`00
03kooooo000Looooo`03o`000?oooooooooo03?ooooo0_l00004ooooo`Go000000?oooooo`000?l0
00002?ooool2o`0001Kooooo0ol00003ooooo`;o00000_ooool3o`000003ooooool0003o000000Ko
00001_ooool2o`000005ooooool0003o0000o`000?ooool00_l00005ooooo`;o00004_ooool3o`00
00Oooooo5?l000000ooooooo0000o`000002o`0000;ooooo1Ol0000Iooooo`?o00001_ooool2o`00
01Sooooo0ol000001?oooooo0000o`000?l0000mooooo`007?ooool2o`0003[ooooo0_l000001?oo
oooo0000o`000?ooool2o`000003ooooool0003o000000;o00003Oooool2o`0000Wooooo0_l0000;
ooooo`_o00001oooool2o`000003ooooool0003o000000Ko00006?ooool2o`0000;ooooo0_l00002
ooooo`go000000?oooooo`000?l000001_l00007ooooo`;o00004oooool2o`0000Kooooo0_l0000>
ooooo`?o00004?ooool3o`000004ooooool0003o0000o`0001Wooooo0_l0000Rooooo`007?ooool0
0ol0003oooooooooo`0kooooo`;o00001Oooool4o`0000gooooo0_l00009ooooo`;o00002Oooool9
o`0000;ooooo1?l0000:ooooo`;o000000Coooooo`000?l0003o00000oooool2o`000003ooooool0
003o000000cooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo5_l00004ooooo`Go00001?oo
ool2o`0000[ooooo0_l000001?oooooo0000o`000?l00005ooooo`;o00002Oooool2o`0000?ooooo
0ol0000Dooooo`?o00006Oooool2o`0002;ooooo000Looooo`03o`000?oooooooooo03_ooooo0_l0
000Fooooo`Ko00004?ooool4o`0000;ooooo0ol00004ooooo`;o00001?ooool2o`0000?ooooo0_l0
0002ooooo`;o00001?ooool2o`000003ooooool0003o000000cooooo0_l0000:ooooo`ko00000_oo
ool5o`000005ooooool0003o0000o`000?ooool01?l00005ooooo`;o00000oooool4o`0000?ooooo
0_l00002ooooo`;o00000_ooool5o`0000Gooooo0_l000001Ooooooo0000o`000?l0003ooooo00Go
00003_ooool2o`0000;ooooo1?l00008ooooo`;o0000=?ooool001cooooo00?o0000ooooooooool0
=?ooool2o`0001gooooo1ol0000Eooooo`?o00002_ooool2o`0000?ooooo0_l0000Gooooo`?o0000
2?ooool7o`000005ooooool0003o0000o`000?ooool01Ol000000ooooooo0000o`000004o`000004
ooooool0003o0000o`0000;ooooo0_l00007ooooo`?o000000?oooooo`000?l000000_l000000ooo
oooo0000o`000008ooooo`Go00001Oooool2o`000003ooooool0003o000000;ooooo0_l000000ooo
oooo0000o`00000:ooooo`;o00000_ooool2o`0000;ooooo0_l0000:ooooo`;o0000=?ooool001co
oooo00?o0000ooooooooool0=?ooool2o`0001Cooooo0_l0000<ooooo`;o00005Oooool3o`000003
ooooool0003o000000?ooooo0_l0000?ooooo`;o00003oooool3o`0000Gooooo3_l000000ooooooo
0000o`000003o`000003ooooool0003o000000Co00000_ooool2o`0000;ooooo0_l00006ooooo`Co
00001_ooool2o`0000Oooooo1_l0000Aooooo`;o00001Oooool5o`0004Sooooo000Looooo`03o`00
0?oooooooooo03;ooooo0_l00008ooooo`;o00002Oooool2o`000003ooooool0003o000002Oooooo
0_l00003ooooo`;o00003oooool2o`0000_ooooo0_l00008ooooo`Go00001?ooool5o`000003oooo
ool0003o000000Ko00000_ooool4o`0000;ooooo0_l000000ooooooo0000o`000007ooooo`;o0000
2_ooool2o`0000Gooooo1Ol0000?ooooo`;o000000?oooooo`000?l000001Oooool4o`0000Cooooo
0_l00003ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0<_ooool2o`0000;ooooo0_l0
0002ooooo`Co00002?ooool3o`0000Wooooo0_l0000<ooooo`;o00001_ooool2o`0001;ooooo0_l0
0005ooooo`;o00004Oooool2o`000003ooooool0003o000000Gooooo0_l00005ooooo`[o00000_oo
ool4o`0000Gooooo0_l00003ooooo`Go00004Oooool2o`000003ooooool0003o000000Gooooo0_l0
000?ooooo`;o00001?ooool2o`0000[ooooo0ol00002ooooo`;o0000?_ooool001cooooo00?o0000
ooooooooool0<_ooool2o`0000;ooooo0_l00002ooooo`;o00002_ooool2o`0000[ooooo0_l0000<
ooooo`;o00001_ooool2o`0001;ooooo0_l00002ooooo`;o000000?oooooo`000?l000002_ooool2
o`0000Kooooo1?l000000ooooooo0000o`000006ooooo`Go00000_ooool2o`000003ooooool0003o
000000Oo000000Goooooo`000?l0003o0000ooooo`02o`0000?ooooo1Ol0000Cooooo`?o00007?oo
ool2o`0000Wooooo1?l00005ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0<_ooool2
o`0000Kooooo0ol00002ooooo`;o00001_ooool2o`0002Sooooo0ol0000<ooooo`;o00002oooool4
o`0000Kooooo0_l00003ooooo`;o00001Oooool5o`000003ooooool0003o000000;o000000Cooooo
o`000?l0003ooooo0ol000001?oooooo0000o`000?ooool4o`0000Cooooo0_l00008ooooo`;o0000
3Oooool2o`0000oooooo0_l00005ooooo`;o00002_ooool2o`0000?ooooo0ol00005ooooo`Co0000
6Oooool2o`00023ooooo000Looooo`03o`000?oooooooooo03Oooooo0_l000001Ooooooo0000o`00
0?l0003ooooo00?o00001_ooool2o`00013ooooo0ol0000Eooooo`?o00000oooool2o`0001Cooooo
1?l0000?ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000002o`0000So
oooo0_l00002ooooo`Co00000oooool2o`0000Sooooo0ol0000=ooooo`;o00000_ooool2o`0000[o
oooo0_l00002ooooo`;o000000?oooooo`000?l000002_ooool3o`000004ooooool0003o0000o`00
00Kooooo0_l00002ooooo`;o00005oooool2o`00023ooooo000Looooo`03o`000?oooooooooo02go
oooo0_l00008ooooo`;o000000?oooooo`000?l000000_ooool3o`0000;ooooo0_l0000>ooooo`;o
000000Coooooo`000?l0003ooooo0ol0000Kooooo`Co00001Oooool2o`000003ooooool0003o0000
00Wooooo0ol0000?ooooo`;o00002Oooool6o`0000?ooooo0ol00004ooooo`;o00002?ooool2o`00
00Cooooo0_l0000=ooooo`;o00000_ooool2o`0000kooooo1?l00005ooooo`;o00001Oooool2o`00
0003ooooool0003o000000_ooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o
00001oooool2o`0000Oooooo0_l00002ooooo`;o00003_ooool5o`0000Cooooo1?l00002ooooo`;o
00000oooool2o`00013ooooo0_l00005ooooo`Go00001oooool4o`0000?ooooo0ol0000>ooooo`Co
00001Oooool6o`000003ooooool0003o000000Gooooo0_l00007ooooo`?o00003Oooool2o`0001[o
oooo1?l00003ooooo`;o00001oooool2o`0004Oooooo000Looooo`03o`000?oooooooooo03Kooooo
0_l00009ooooo`;o00004Oooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`0000;ooooo
0_l00003ooooo`;o00004Oooool2o`0000Gooooo0_l00009ooooo`;o00000oooool5o`0000kooooo
1?l00006ooooo`Ko00001oooool2o`0000;ooooo0_l00002ooooo`?o00003_ooool2o`0000;ooooo
0_l0000Hooooo`;o00000oooool5o`0000?ooooo0ol00017ooooo`007?ooool00ol0003ooooooooo
o`0oooooo`Ko00003?ooool2o`0000Kooooo0_l00003ooooo`?o000000?oooooo`000?l000003?oo
ool2o`0000Sooooo0_l0000:ooooo`;o00002Oooool6o`000003ooooool0003o000000kooooo1?l0
0002ooooo`;o00000_ooool4o`0000Wooooo0_l00002ooooo`;o00003oooool2o`000004ooooool0
003o0000o`00013ooooo0_l0000;ooooo`Go00000oooool4o`0004Kooooo000Looooo`03o`000?oo
oooooooo03cooooo0_l000001?oooooo0000o`000?ooool3o`0000;ooooo0_l00008ooooo`;o0000
1_ooool2o`0000Cooooo0_l000000ooooooo0000o`000005ooooo`;o00001Oooool2o`0000_ooooo
0_l00007ooooo`;o00000_ooool2o`0000Kooooo1Ol000000ooooooo0000o`00000>ooooo`Co0000
1oooool3o`0000_ooooo0_l0000Aooooo`;o000000?oooooo`000?l000004Oooool2o`0000?ooooo
0_l00005ooooo`Ko000000?oooooo`000?l000000_ooool2o`0000[ooooo0_l0000jooooo`007?oo
ool00ol0003oooooooooo`0looooo`;o00002Oooool4o`0000Kooooo0_l000001?oooooo0000o`00
0?l00002ooooo`;o00003_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000;ooooo`;o0000
0oooool2o`0000Kooooo0_l00003ooooo`;o000000?oooooo`000?l000003_ooool2o`0000;ooooo
0_l0000Iooooo`;o00004Oooool2o`0000Cooooo0_l00005ooooo`;o00000_ooool2o`0000Sooooo
0_l00005ooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`;o000000?oooooo`000?l00000
2Oooool2o`0002oooooo000Looooo`;o0000<oooool2o`0001;ooooo1Ol00006ooooo`;o000000Co
ooooo`000?l0003o00001Oooool2o`0000oooooo0_l000000ooooooo0000o`00000@ooooo`;o0000
2oooool2o`00017ooooo0_l000001?oooooo0000o`000?l0000Dooooo`;o00002oooool2o`0000oo
oooo1?l00003ooooo`;o00000_ooool2o`000003ooooool0003o000000?o00001Oooool2o`0000Wo
oooo0_l00004ooooo`;o00001?ooool3o`0000cooooo0_l0000_ooooo`007?ooool00ol0003ooooo
ooooo`0booooo`;o00000oooool2o`0000Cooooo0_l00007ooooo`?o000000?oooooo`000?l00000
0_ooool2o`0000cooooo1?l00013ooooo`Go00003_ooool2o`000004ooooool0003o0000ooooo`;o
00002oooool2o`00017ooooo0_l00008ooooo`Oo00001Oooool5o`0000Kooooo1?l00002ooooo`;o
00001?ooool2o`0003kooooo000Looooo`03o`000?oooooooooo03Kooooo0ol00004ooooo`;o0000
2oooool6o`0000Gooooo0_l00007ooooo`;o000000?oooooo`000?l000000_l0000Zooooo`;o0000
1oooool4o`0000Oooooo0_l000000ooooooo0000o`000008ooooo`;o00001?ooool2o`000003oooo
ool0003o000001?ooooo0_l0000>ooooo`Co000000Coooooo`000?l0003ooooo1?l0000:ooooo`?o
00001_ooool5o`000003ooooool0003o000000Cooooo0ol0000mooooo`007?ooool00ol0003ooooo
ooooo`0_ooooo`?o00001?ooool2o`00017ooooo0_l000000ooooooo0000o`000002ooooo`;o0000
00?oooooo`000?l000000_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l00000
0_l00007ooooo`;o00005_ooool2o`0000Cooooo0_l00003ooooo`;o00001oooool4o`0001Cooooo
0_l00008ooooo`;o000000?oooooo`000?l000003oooool2o`0000kooooo1?l000000ooooooo0000
o`000003ooooo`Co000000?oooooo`000?l000000_l00003ooooo`;o00002?ooool7o`0000Gooooo
0_l0000Gooooo`;o00009?ooool001cooooo00?o0000ooooooooool0;oooool3o`0000Wooooo0_l0
00000ooooooo0000o`000009ooooo`;o000000?oooooo`000?l000000_ooool2o`000004ooooool0
003o0000o`0000;ooooo0_l00004ooooo`;o00002?ooool2o`0000;ooooo0_l0000Fooooo`;o0000
1?ooool4o`0000Kooooo0_l00003ooooo`?o00005?ooool2o`0000Sooooo0_l000000ooooooo0000
o`00000Kooooo`;o00001oooool3o`0000?ooooo0ol000000ooooooo0000o`000004o`000003oooo
ool0003o000000;o00001_ooool3o`000004ooooool0003o0000o`0001kooooo0_l0000Tooooo`00
7?ooool00ol0003oooooooooo`0kooooo`;o000000?oooooo`000?l000003?ooool2o`000003oooo
ool0003o000000?ooooo0_l00009ooooo`;o00001oooool2o`0000Gooooo0_l0000Kooooo`;o0000
1Oooool3o`0000?ooooo0ol0000Dooooo`;o00002?ooool2o`000003ooooool0003o000001_ooooo
0_l00004ooooo`Ko00000oooool2o`0000Cooooo1?l00003ooooo`;o00001oooool2o`0000Kooooo
0_l00010ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00003oooool2o`0000Cooooo0_l0
0003ooooo`;o00002Oooool2o`0000Wooooo0_l000000ooooooo0000o`000002o`000003ooooool0
003o000001cooooo0_l000001?oooooo0000o`000?l00003ooooo`?o00001_ooool2o`000003oooo
ool0003o000000Kooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l0000<ooooo`Co0000
1Oooool2o`0000Cooooo0_l00006ooooo`;o00000oooool6o`0000Kooooo0_l000001?oooooo0000
o`000?l0000>ooooo`;o00001?ooool3o`000003ooooool0003o000003gooooo000Looooo`03o`00
0?oooooooooo02oooooo0_l00007ooooo`;o00002Oooool2o`0000Cooooo0_l00009ooooo`;o0000
2Oooool2o`0000Wooooo0_l000001?oooooo0000o`000?ooool4o`0001Sooooo0_l00002ooooo`Ko
00000oooool6o`000003ooooool0003o000000;o000000?oooooo`000?l000001?ooool4o`0000?o
oooo1_l00006ooooo`;o00001?ooool4o`0000Gooooo0_l00004ooooo`;o00000oooool2o`000003
ooooool0003o000000Oooooo0_l00006ooooo`;o00000_ooool2o`0000Cooooo0_l00008ooooo`;o
00001?ooool3o`000003ooooool0003o000003gooooo000Looooo`03o`000?oooooooooo02oooooo
0_l0000Booooo`;o00003oooool3o`0001Cooooo0_l000000ooooooo0000o`000003o`0001Sooooo
0ol00003ooooo`;o00001oooool8o`0000;ooooo1?l00003ooooo`;o00001oooool3o`0000;ooooo
0_l00003ooooo`;o000000Coooooo`000?l0003o00000_ooool3o`0000Cooooo0_l00005ooooo`;o
00000_ooool2o`0000[ooooo0_l00005ooooo`Co000000?oooooo`000?l000001?ooool2o`0001;o
oooo0_l000000ooooooo0000o`00000jooooo`007?ooool00ol0003oooooooooo`0jooooo`;o0000
1oooool2o`0000gooooo0_l000000ooooooo0000o`000003ooooo`;o00002oooool9o`000004oooo
ool0003o0000o`0001Oooooo0_l0000=ooooo`;o000000?oooooo`000?l000001?l000000ooooooo
0000o`000003o`0000;ooooo0ol00002ooooo`;o00000oooool2o`0000;ooooo0_l000000ooooooo
0000o`000003ooooo`Co000000Coooooo`000?l0003o00000oooool3o`000003ooooool0003o0000
00;ooooo0_l0000>ooooo`;o00001Oooool4o`0000Gooooo0_l0000Gooooo`?o0000>Oooool001co
oooo00?o0000ooooooooool0>_ooool2o`0000Oooooo0_l00003ooooo`;o00002?ooool2o`000003
ooooool0003o000000?ooooo0ol00002ooooo`;o000000Coooooo`000?l0003ooooo1ol000000ooo
oooo0000o`000006o`000003ooooool0003o000000?ooooo0_l0000>ooooo`;o00002Oooool2o`00
00Oooooo1Ol00003ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00000oooool2o`00
00Gooooo0ol00004ooooo`;o000000Coooooo`000?l0003o00000oooool2o`0000;ooooo0_l00007
ooooo`;o00000oooool2o`0000_ooooo0ol000000ooooooo0000o`000003ooooo`;o00000oooool2
o`00013ooooo0_l000000ooooooo0000o`000002ooooo`;o0000=Oooool001cooooo00?o0000oooo
ooooool0:oooool2o`0001Kooooo0_l00003ooooo`;o00000_ooool2o`0000Oooooo0_l00003oooo
o`?o00000_ooool2o`000004ooooool0003o0000ooooo`So000000?oooooo`000?l000002?l00003
ooooo`;o00002oooool2o`000004ooooool0003o0000ooooo`;o00001_ooool2o`0000Oooooo0_l0
00001?oooooo0000o`000?l00005ooooo`;o00001?ooool3o`0000Wooooo0ol00002ooooo`Wo0000
3?ooool2o`000003ooooool0003o000000?ooooo0_l00008ooooo`Ko000000?oooooo`000?l00000
2?ooool2o`0000Cooooo0_l0000:ooooo`;o00001Oooool2o`0003Gooooo000Looooo`03o`000?oo
oooooooo02_ooooo0_l0000Jooooo`Co000000?oooooo`000?l000000_ooool2o`0001;ooooo5?l0
000@ooooo`;o000000Coooooo`000?l0003ooooo0_l00007ooooo`;o00001_ooool2o`0000;ooooo
0_l00005ooooo`?o00000_ooool4o`0000Wooooo0ol000000ooooooo0000o`000008o`0000cooooo
0_l00003ooooo`;o00002oooool6o`0000Oooooo0_l000000ooooooo0000o`000005ooooo`;o0000
3Oooool2o`0003Wooooo000Looooo`03o`000?oooooooooo047ooooo0_l00004ooooo`Co00001Ooo
ool2o`0000;ooooo0_l0000>oooooaCo00001?ooool2o`0000_ooooo0_l00007ooooo`;o00000ooo
ool2o`0000Sooooo0_l00008ooooo`;o00000_ooool4o`0000[ooooo1Ol000000ooooooo0000o`00
0003o`0000Sooooo0_l00004ooooo`;o00000oooool2o`0000Gooooo1?l0000?ooooo`Go00001Ooo
ool2o`0000gooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00003oooool4
o`0000Kooooo0_l00009ooooo`;o00000_ooool3o`0000Oooooo5ol00003ooooo`;o00001?ooool2
o`0000Gooooo0_l00005ooooo`Co00003Oooool2o`0000;ooooo0_l00009ooooo`Ko00000_ooool2
o`000003ooooool0003o000000;ooooo0ol00004ooooo`;o00000_ooool2o`000004ooooool0003o
0000ooooo`;o00004?ooool6o`0000oooooo0_l000000ooooooo0000o`000003ooooo`;o00002ooo
ool2o`0000;ooooo0_l0000>ooooo`;o00009oooool001cooooo00?o0000ooooooooool0;_ooool2
o`0000oooooo0_l00008ooooo`;o00003Oooool3o`0000Gooooo6Ol00009ooooo`;o00000oooool4
o`000003ooooool0003o000000;ooooo0_l0000Cooooo`;o00002_ooool6o`000004ooooool0003o
0000ooooo`;o00000oooool2o`0000Cooooo0_l00002ooooo`So00002Oooool3o`0000Sooooo0_l0
000Aooooo`?o00000oooool2o`0000_ooooo0_l00002ooooo`Co00003?ooool2o`0002Oooooo000L
ooooo`;o0000?Oooool3o`0000kooooo0_l00004ooooo`;o00002ooooolFo`000004ooooool0003o
0000o`0000gooooo0_l00003ooooo`;o00000_ooool2o`00027ooooo1?l00002ooooo`?o00001Ooo
ool4o`0000Kooooo0_l00002ooooo`;o00000oooool2o`0000Gooooo0ol0000<ooooo`;o00002Ooo
ool2o`0000;ooooo0ol0000Eooooo`?o0000=Oooool001cooooo00?o0000ooooooooool0??ooool3
o`000003ooooool0003o000000;o00001oooool4o`0000Cooooo0_l00007ooooo`;o000000?ooooo
o`000?l000006Ol0000Fooooo`;o00001_ooool2o`0000Kooooo0_l0000Cooooo`;o00000_ooool4
o`0000;ooooo1_l00005ooooo`;o00001_ooool5o`0000gooooo0_l00004ooooo`?o00002?ooool2
o`0000cooooo0_l0000:ooooo`Go0000=Oooool001cooooo00?o0000ooooooooool0@?ooool4o`00
00Oooooo0_l0000?ooooo`;o000000?oooooo`000?l000004Ol000000ooooooo0000o`000004o`00
01Oooooo1?l00004ooooo`;o00001_ooool2o`0000cooooo0_l00005ooooo`;o00000oooool3o`00
0003ooooool0003o000000?o00001?ooool2o`000003ooooool0003o000000;o00000_ooool4o`00
0003ooooool0003o000000gooooo0_l000001?oooooo0000o`000?ooool3o`0000;ooooo0_l00000
0ooooooo0000o`000002ooooo`;o00002oooool2o`0000[ooooo0_l0000hooooo`007?ooool00ol0
003oooooooooo`0oooooo`Co00005Oooool2o`0000Oooooo6Ol0000Booooo`;o00001?ooool2o`00
01[ooooo0_l00009ooooo`;o00000oooool2o`000003ooooool0003o000000Cooooo1?l000000ooo
oooo0000o`000002ooooo`;o00000oooool2o`0000gooooo1Ol00006ooooo`Go00000_ooool2o`00
00Kooooo0_l00019ooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00000_ooool2o`0000Wo
oooo0_l00003ooooo`;o00000oooool4o`0000Gooooo6Ol0000Booooo`Co00001?ooool2o`000003
ooooool0003o000000Gooooo0_l000000ooooooo0000o`000003o`0000Gooooo0_l00004ooooo`;o
00001_ooool2o`000004ooooool0003o0000ooooo`;o00002?ooool2o`0000Gooooo0_l00003oooo
o`;o00002Oooool2o`0000;ooooo1?l00003ooooo`;o00001?ooool2o`0000?ooooo0_l00006oooo
o`;o000000?oooooo`000?l00000A_ooool001cooooo00?o0000ooooooooool0@oooool2o`0000Co
oooo0_l00003ooooo`;o00000oooool2o`0000?ooooo1Ol00004oooooaco00000_ooool2o`0000Oo
oooo0_l00004ooooo`;o00000_ooool4o`000003ooooool0003o000000Gooooo0_l000000ooooooo
0000o`000005o`0000?ooooo0_l00004ooooo`;o00002Oooool2o`000003ooooool0003o0000017o
oooo0_l0000<ooooo`;o00001_ooool5o`00013ooooo0_l00002ooooo`;o00003_ooool2o`0003Ko
oooo000Looooo`03o`000?oooooooooo03oooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o
000000?oooooo`000?l000002?ooool2o`0000?ooooo1Ol00004oooooaco00000_ooool2o`0000Oo
oooo0_l00008ooooo`;o00004_ooool2o`0000?ooooo0ol0000Cooooo`;o00003oooool2o`0000Co
oooo0_l00006ooooo`;o00001_ooool4o`0000oooooo1Ol00008ooooo`?o00001_ooool2o`0003Ko
oooo000Looooo`03o`000?oooooooooo03gooooo1?l000001Ooooooo0000o`000?l0003ooooo00;o
00002oooool2o`0000cooooo0_l000000ooooooo0000o`00000Do`0000Gooooo0_l00008ooooo`;o
00003Oooool2o`00017ooooo0ol00004ooooo`?o00002_ooool5o`0001?ooooo0ol00006ooooo`;o
00003?ooool2o`0000Kooooo0_l00003ooooo`Go00002?ooool3o`0000Cooooo1?l0000fooooo`00
7?ooool00ol0003oooooooooo`0mooooo`So00001oooool2o`0000_ooooo0ol00008oooooaKo0000
3_ooool3o`0000Oooooo0_l00004ooooo`;o00004?ooool3o`0000Gooooo0ol0000:ooooo`Go0000
4oooool2o`0000Gooooo0_l00003ooooo`;o00000oooool3o`0000?ooooo0_l00005ooooo`?o0000
0oooool2o`0000Cooooo0_l00005ooooo`;o00000oooool4o`0003Sooooo000Looooo`03o`000?oo
oooooooo03oooooo1?l00007ooooo`Co000000?oooooo`000?l000002?ooool3o`0000Kooooo6?l0
000:ooooo`Ko00002?ooool2o`0000;ooooo0_l0000Booooo`;o00005?ooool2o`0001_ooooo0ol0
0003ooooo`;o00000_ooool4o`0000;ooooo0_l00006ooooo`;o00000_ooool4o`0000Cooooo0_l0
0005ooooo`;o00000_ooool4o`0003Wooooo000Looooo`03o`000?oooooooooo03gooooo2?l00005
ooooo`;o00000oooool2o`00017ooooo5ol00006ooooo`;o00000oooool5o`0000?ooooo0_l00002
ooooo`;o00001?ooool2o`0000_ooooo0_l00006ooooo`;o00005oooool2o`0000Sooooo1?l0000;
ooooo`;o00002?ooool3o`0000;ooooo0ol0000:ooooo`;o00004Oooool4o`0003Wooooo000Loooo
o`03o`000?oooooooooo03gooooo0_l00002ooooo`Co00002Oooool4o`0001;ooooo5?l000000ooo
oooo0000o`000004ooooo`;o00001Oooool3o`0000?ooooo0_l00002ooooo`;o00002oooool2o`00
00Cooooo0ol00002ooooo`;o000000?oooooo`000?l000005oooool2o`0000Sooooo1_l0000;oooo
o`;o00000_ooool2o`0000?ooooo0_l00002ooooo`?o0000F_ooool001cooooo00?o0000oooooooo
ool0?Oooool2o`0000Oooooo0_l00003ooooo`Oo00002Oooool2o`0000Oooooo5?l000001?oooooo
0000o`000?ooool2o`0000;ooooo0_l00004ooooo`;o00005Oooool2o`0000Gooooo0_l00002oooo
o`Co00004?ooool2o`0000cooooo0_l00006ooooo`;o00002oooool2o`0000;ooooo0_l00008oooo
o`;o00004?ooool2o`0000cooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`0Yooooo`;o
00000oooool2o`0000gooooo0_l00007ooooo`;o000000?oooooo`000?l000000ol0000<ooooo`?o
00001ooooolDo`000004ooooool0003o0000ooooo`;o00000_ooool2o`0001Wooooo0_l0000;oooo
o`Co00004?ooool2o`0000_ooooo0ol0000<ooooo`Go00002oooool2o`0000Gooooo0_l00006oooo
o`Go00000oooool4o`000003ooooool0003o000000;o00001Oooool2o`0003[ooooo00001_oooooo
k^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_oo
ool00ol0003oooooooooo`0Yooooo`;o00000oooool2o`0001Sooooo1Ol0000=ooooo`;o00002?oo
oolGo`000003ooooool0003o000000gooooo0_l0000>ooooo`Co00002?ooool4o`0000kooooo0_l0
000>ooooo`;o000000?oooooo`000?l000002_ooool5o`0000[ooooo0ol00005ooooo`Co00001?oo
ool5o`0000Gooooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l0000kooooo`0000Kooooo
ogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Ko
oooo00?o0000ooooooooool0A?ooool2o`0000;ooooo0ol000000ooooooo0000o`00000<ooooo`?o
00001ooooolBo`000004ooooool0003o0000ooooo`Co00001?ooool2o`0000;ooooo0ol00002oooo
o`;o00004?ooool2o`0000?ooooo0_l00003ooooo`Co00003Oooool5o`0000Gooooo0_l00008oooo
o`;o00003?ooool2o`0000_ooooo1Ol00005ooooo`;o00002Oooool2o`0000Oooooo0_l00005oooo
o`;o00003?ooool2o`0002gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wo
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo02Wooooo0_l00007oooo
o`;o00004?ooool2o`0000?ooooo1Ol00004ooooo`;o00001oooool2o`0000[ooooo3_l00002oooo
o`Oo00001?ooool2o`0000;ooooo0ol0000Iooooo`;o00001Oooool2o`0000gooooo1_l00004oooo
o`;o00003_ooool2o`000003ooooool0003o000000?o00003oooool3o`000004ooooool0003o0000
ooooo`?o00002Oooool3o`0000Kooooo0_l00005ooooo`;o00003?ooool2o`0002gooooo00000ooo
oooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@06
ooooo`?o0000:Oooool2o`0000Oooooo0_l0000Eooooo`Co000000?oooooo`000?l000000_ooool3
o`0000Oooooo0_l00002ooooo`;o00001Oooool<o`000004ooooool0003o0000ooooo`?o00001Ooo
ool2o`0000Kooooo0_l0000Sooooo`?o00001?ooool2o`0000Gooooo1_l0000Booooo`So000000?o
ooooo`000?l000000_l00002ooooo`?o00002Oooool2o`000003ooooool0003o000000_ooooo0_l0
0002ooooo`;o00002?ooool2o`0003cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo04Kooooo0_l0
00000ooooooo0000o`000002o`000003ooooool0003o000000?ooooo0_l00007ooooo`;o00000_oo
ool2o`0000?ooooo0_l00004ooooo`So000000Coooooo`000?l0003ooooo0_l00006ooooo`;o0000
6oooool2o`000003ooooool0003o000000?ooooo1?l000000ooooooo0000o`000006o`0000;ooooo
0ol00003ooooo`;o000000?oooooo`000?l000000_l0000@ooooo`oo00000_ooool3o`0000gooooo
0_l0000>ooooo`;o00002?ooool2o`0003cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oo
oooooooo00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`16ooooo`;o00000ooo
ool2o`0000?ooooo0_l000000ooooooo0000o`00000:ooooo`;o000000Coooooo`000?l0003ooooo
0_l00008ooooo`Co00001?ooool2o`0001Kooooo0_l0000;ooooo`;o000000?oooooo`000?l00000
0_ooool5o`000003ooooool0003o000000Ko00000oooool2o`0000?ooooo0_l000000ooooooo0000
o`000009ooooo`;o00001oooool?o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l00000
1_ooool2o`000003ooooool0003o000000Gooooo0_l0001<ooooo`0000KoooooogMgMonHV9Sooooo
oiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0Boooool2o`000003
ooooool0003o000000;o00003Oooool2o`000003ooooool0003o000000;ooooo0_l00009ooooo`;o
00002oooool2o`0000oooooo0_l00005ooooo`;o00002oooool2o`0000Cooooo0_l000001?oooooo
0000o`000?l00002ooooo`Co00001Oooool2o`000003ooooool0003o000000Sooooo0_l00007oooo
oaCo000000Goooooo`000?l0003o0000ooooo`02o`0000Cooooo0_l00003ooooo`;o00001Oooool2
o`000003ooooool0003o000004Wooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo00Co
c<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`0Zooooo`;o00002?ooool2o`00013ooooo
0_l000001?oooooo0000o`000?ooool4o`0000gooooo0_l00007ooooo`;o00002?ooool4o`0000[o
oooo0_l0000Fooooo`;o00004Oooool<o`0000Gooooo1Ol0000:ooooo`;o00000_oooolJo`0000So
oooo0_l00009ooooo`;o00000_ooool2o`0004Wooooo000Looooo`03o`000?oooooooooo02[ooooo
0_l00008ooooo`;o00002?ooool2o`0000Kooooo0_l000001?oooooo0000o`000?ooool2o`0000Oo
oooo0_l00005ooooo`?o00001oooool2o`0000?ooooo0_l00003ooooo`Co00001?ooool2o`0000Co
oooo0_l0000Jooooo`;o00002_ooool=o`000004ooooool0003o0000o`0000Cooooo0_l00003oooo
o`;o00001ooooolOo`0000gooooo0_l00003ooooo`;o00000_ooool2o`0004Wooooo000Looooo`03
o`000?oooooooooo03Cooooo0_l00008ooooo`;o00000oooool2o`0000Kooooo0_l000000ooooooo
0000o`000005ooooo`;o00001Oooool2o`0000Sooooo0_l00003ooooo`;o00001?ooool2o`0000Go
oooo1?l00002ooooo`;o00001Oooool2o`0000?ooooo0_l0000=ooooo`?o00000oooool2o`0000Go
oooo4_l00006ooooo`Co00002OoooolJo`000003ooooool0003o000000Oooooo0_l00004ooooo`;o
00000_ooool2o`0000Oooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`0dooooo`;o0000
3Oooool2o`0000Kooooo0_l000000ooooooo0000o`00000@ooooo`;o00002oooool2o`0000;ooooo
0_l00006ooooo`?o00002Oooool2o`0000?ooooo0_l0000=ooooo`;o00001?ooool2o`0000;ooooo
0_l000000ooooooo0000o`00000Bo`0000Cooooo0ol00009oooooa_o00001?ooool2o`0000Cooooo
0_l00008ooooo`;o00001oooool2o`0000?ooooo0_l00010ooooo`007?ooool00ol0003ooooooooo
o`1:ooooo`;o00000oooool2o`0000Kooooo1?l00005ooooo`;o000000?oooooo`000?l000002?oo
ool2o`0000;ooooo0_l00002ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000[ooooo
0_l0000>ooooo`;o00001_ooool2o`000004ooooool0003o0000oooooaKo00002oooool2o`000003
ooooool0003o000001Wo00001?ooool2o`0000Kooooo0_l0000Dooooo`;o00001_ooool2o`0003So
oooo000Looooo`03o`000?oooooooooo043ooooo0_l00002ooooo`;o00001?ooool2o`0000?ooooo
1?l00002ooooo`Ko00001oooool3o`000003ooooool0003o000000gooooo0_l000000ooooooo0000
o`000002ooooo`;o00002_ooool2o`0000kooooo0_l00006ooooo`;o000000Coooooo`000?l0003o
oooo5_l00004ooooo`?o000000Coooooo`000?l0003ooooo7_l00003ooooo`;o00001oooool2o`00
01Cooooo0_l00006ooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0=?ooool2o`0000[o
oooo0_l00002ooooo`;o00000oooool3o`0000?ooooo1?l00002ooooo`;o00002oooool2o`0000;o
oooo1?l0000dooooo`;o000000?oooooo`000?l000006Ol00004ooooo`?o000000Coooooo`000?l0
003ooooo5?l000000ooooooo0000o`000006o`0000;ooooo1Ol0000Looooo`;o0000@?ooool001co
oooo00?o0000ooooooooool0=?ooool2o`0001?ooooo0_l00004ooooo`;o00004_ooool2o`0000?o
oooo0_l0000Eooooo`;o00007OoooolNo`000003ooooool0003o000000Sooooo5Ol000000ooooooo
0000o`000005o`0000;ooooo0_l000000ooooooo0000o`00000Vooooo`;o0000=_ooool001cooooo
00?o0000ooooooooool0D?ooool2o`00017ooooo0_l00006ooooo`;o00001_ooool2o`000004oooo
ool0003o0000o`0000Kooooo0_l00009ooooo`;o00004ooooolMo`000004ooooool0003o0000oooo
o`Ko00000ooooolKo`0000Cooooo0_l0000Wooooo`;o0000=_ooool001cooooo00?o0000oooooooo
ool0AOooool2o`0000Wooooo0ol0000Hooooo`;o00001_ooool2o`000004ooooool0003o0000o`00
017ooooo0_l0000Foooooa_o00000oooool6o`0000?ooooo0_l000000ooooooo0000o`00000Fo`00
00Cooooo0_l0000Aooooo`;o00000oooool2o`0004Oooooo000Looooo`03o`000?oooooooooo04Go
oooo0ol00004ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o00007?ooool2o`0002So
oooo0_l000000ooooooo0000o`00000Ko`0000Kooooo0_l000000ooooooo0000o`000003oooooaWo
00000oooool2o`00017ooooo0ol00002ooooo`;o00000_ooool2o`0004?ooooo000Looooo`03o`00
0?oooooooooo04Kooooo0_l00004ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`0000ko
oooo0_l0000<ooooo`;o00002?ooool2o`0001gooooo7_l000000ooooooo0000o`000003ooooo`;o
000000Coooooo`000?l0003ooooo0_l00005oooooaCo000000Coooooo`000?l0003ooooo0_l0000D
ooooo`;o00001_ooool2o`0000Gooooo0_l0000looooo`007?ooool2o`0004gooooo0_l000000ooo
oooo0000o`000003o`0000;ooooo0_l0000>ooooo`;o00003?ooool2o`0000Sooooo0_l0000Moooo
o`Co000000?oooooo`000?l000001Ol000000ooooooo0000o`00000?o`0000Kooooo0_l00007oooo
o`;o00000oooool2o`000003ooooool0003o000000go00000_ooool5o`0000;ooooo0_l00009oooo
o`;o00005?ooool2o`0003cooooo000Looooo`03o`000?oooooooooo04_ooooo0_l00003ooooo`Co
00003oooool2o`0002gooooo0_l00007ooooob3o00002?ooool2o`0000Gooooo0_l00008ooooo`?o
00000oooool6o`000003ooooool0003o000000Co00000oooool2o`0000Wooooo0_l0001Booooo`00
7?ooool00ol0003oooooooooo`1;ooooo`Co000000?oooooo`000?l000004Oooool4o`0001cooooo
0_l00004ooooo`;o00001oooool2o`0000Oooooo0_l000000ooooooo0000o`000004o`000003oooo
ool0003o000001Co00002?ooool2o`0000Kooooo0_l0000<ooooo`Co00001?ooool2o`00013ooooo
0_l00006ooooo`Co0000B_ooool001cooooo00?o0000ooooooooool0Boooool4o`0000;ooooo0_l0
000?ooooo`;o000000?oooooo`000?l000000_l0000:ooooo`;o00002oooool2o`000003ooooool0
003o000000;o00000_ooool2o`0000[ooooo0_l00003ooooo`;o000000?oooooo`000?l000002Ol0
00000ooooooo0000o`00000:o`000003ooooool0003o000000;o00002Oooool2o`0000Kooooo0_l0
000<ooooo`;o00002?ooool2o`0000kooooo0_l00006ooooo`Co0000B_ooool001cooooo00?o0000
ooooooooool0Boooool4o`0000;ooooo0_l000000ooooooo0000o`00000<ooooo`;o00000oooool2
o`0000[ooooo0_l0000;ooooo`;o000000?oooooo`000?l000000ol00007ooooo`;o00001?ooool2
o`0000?ooooo0_l000000ooooooo0000o`00000Ko`0000Wooooo0_l0000Hooooo`;o00001?ooool2
o`0000Wooooo0_l00005ooooo`;o00001?ooool4o`0004[ooooo000Looooo`03o`000?oooooooooo
04_ooooo1?l00005ooooo`;o00001Oooool2o`0002Wooooo0ol00006ooooo`;o00001oooool2o`00
00Gooooo6_l00006ooooo`;o00000_ooool2o`0000?ooooo0_l00007ooooo`;o00002_ooool2o`00
00oooooo0_l00005ooooo`;o00001?ooool4o`0004[ooooo000Looooo`03o`000?oooooooooo05;o
oooo0_l00007ooooo`;o00006oooool2o`0000?ooooo0_l00008ooooo`;o00003oooool2o`0000?o
oooo6_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000_ooool2o`000003
ooooool0003o000000;o00001oooool2o`0000Gooooo0_l0001_ooooo`007?ooool00ol0003ooooo
ooooo`0looooo`;o00004_ooool4o`000004ooooool0003o0000o`00017ooooo0_l0000=ooooo`;o
00000oooool2o`0000;ooooo0_l0000JoooooaWo00000_ooool2o`0000;ooooo0_l00002ooooo`;o
00001?ooool2o`00013ooooo0_l0000Dooooo`;o00003?ooool2o`0000Cooooo0_l00015ooooo`00
7?ooool00ol0003oooooooooo`0looooo`;o00002?ooool2o`0000Sooooo0_l00003ooooo`?o0000
2Oooool2o`0000Kooooo0_l00005ooooo`;o00001?ooool2o`0000Wooooo0_l0000JoooooaGo0000
00?oooooo`000?l000000_l00009ooooo`;o00009oooool2o`0000?ooooo0_l000000ooooooo0000
o`000009ooooo`;o00001?ooool2o`0004Gooooo000Looooo`03o`000?oooooooooo04Kooooo0_l0
0006ooooo`;o00002Oooool4o`0000Cooooo0_l00006ooooo`;o00001Oooool2o`0000?ooooo0ol0
0002ooooo`;o00008?oooolKo`0000Gooooo0_l0000Booooo`;o00005oooool2o`0000Kooooo0_l0
0003ooooo`;o0000DOooool001cooooo00?o0000ooooooooool0?_ooool2o`0000kooooo0_l00009
ooooo`Co00004Oooool2o`0000Gooooo0_l000000ooooooo0000o`000002o`00013ooooo0_l0000>
oooooa_o00001Oooool2o`0001;ooooo0_l000000ooooooo0000o`000002ooooo`;o000000?ooooo
o`000?l000000ol0000<ooooo`;o00002Oooool2o`00057ooooo000Looooo`03o`000?oooooooooo
03kooooo0_l0000=ooooo`;o00003?ooool4o`0000oooooo0_l00002ooooo`;o00001?ooool2o`00
01;ooooo1?l0000@oooooaCo00007oooool2o`0000;ooooo0_l000000ooooooo0000o`000003o`00
00cooooo0_l00009ooooo`;o00003Oooool2o`0004;ooooo000Looooo`03o`000?oooooooooo04go
oooo0_l0000>ooooo`;o00000_ooool2o`0000oooooo0_l00004ooooo`;o00005?ooool5o`0000oo
oooo4_l0000Iooooo`;o000000?oooooo`000?l00000:?ooool2o`0000Wooooo0_l00012ooooo`00
7?ooool00ol0003oooooooooo`1Kooooo`Co00000_ooool2o`0002cooooo1?l00004ooooo`;o0000
0_ooool4o`0000?ooooo4Ol00002ooooo`;o00003?ooool2o`000003ooooool0003o000000Gooooo
0_l000000ooooooo0000o`00000;ooooo`;o00005oooool2o`0000;ooooo0_l0001=ooooo`007?oo
ool00ol0003oooooooooo`11ooooo`;o00003?ooool2o`0000Oooooo0_l000000ooooooo0000o`00
000Fooooo`;o00005oooool2o`0000Cooooo0_l00003ooooo`So00000oooool2o`000003ooooool0
003o000000co00000_ooool2o`0000cooooo0_l000000ooooooo0000o`00000Cooooo`Co00005ooo
ool2o`00057ooooo000Looooo`03o`000?oooooooooo047ooooo0_l0000<ooooo`;o00001Oooool4
o`000003ooooool0003o000000[ooooo0ol00009ooooo`;o00003?ooool2o`0000Wooooo0_l00004
ooooo`;o00000oooool4o`0000[ooooo1?l000001?oooooo0000o`000?ooool2o`000004ooooool0
003o0000o`0002Sooooo0ol00006ooooo`;o0000Hoooool001cooooo0_l0001Eooooo`Co00000ooo
ool2o`0000Wooooo1?l00004ooooo`;o00002?ooool2o`0000Oooooo0_l0000=ooooo`Co000000?o
ooooo`000?l000000_l00009ooooo`?o000000?oooooo`000?l000000_ooool2o`000005ooooool0
003o0000o`000?ooool00ol0000Qooooo`;o00001Oooool2o`0000Kooooo0_l0000?ooooo`;o0000
D_ooool001cooooo00?o0000ooooooooool0A_ooool2o`0000Oooooo0_l00003ooooo`;o00003_oo
ool5o`0000Gooooo0_l00008ooooo`;o00004_ooool;o`000003ooooool0003o000000Sooooo0ol0
0002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00009ooooo`;o00003ooo
ool2o`0000Gooooo0_l0000Nooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0A_ooool2
o`0000Oooooo1?l0000<ooooo`;o00000oooool2o`000003ooooool0003o000000Sooooo0_l0000<
ooooo`Co00002?ooool?o`0000;ooooo0_l00009ooooo`;o00005?ooool4o`0000gooooo0ol00002
ooooo`;o0000M?ooool001cooooo00?o0000ooooooooool0C_ooool2o`000003ooooool0003o0000
00Kooooo0_l00004ooooo`;o00002_ooool2o`0000?ooooo0ol0000<ooooo`Co00000_ooool2o`00
00?ooooo3_l00003ooooo`?o00002Oooool3o`0000;ooooo0_l0000Aooooo`;o00002Oooool2o`00
00?ooooo0_l00002ooooo`;o00001_ooool2o`000003ooooool0003o000006Wooooo000Looooo`03
o`000?oooooooooo04kooooo0_l00009ooooo`;o00001oooool4o`0000Gooooo1?l000000ooooooo
0000o`00000<ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo6?l00007ooooo`;o
00000_ooool2o`0001cooooo0_l000000ooooooo0000o`000002o`0000[ooooo1Ol0001Yooooo`00
7?ooool00ol0003oooooooooo`1Rooooo`Co00001Oooool4o`0000oooooo0_l00004ooooo`;o0000
0ooooolBo`0000;ooooo1?l0000Booooo`;o00001?ooool2o`0000?ooooo0_l0000;ooooo`Co0000
0_ooool2o`0000Wooooo0_l000000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l00000
G_ooool001cooooo00?o0000ooooooooool0B_ooool2o`0000gooooo0_l00008ooooo`;o00000_oo
ool2o`00013ooooo1_l00005ooooo`;o00000_ooool?o`0000Oooooo0_l00004ooooo`;o00001?oo
ool2o`0000Gooooo1?l00003ooooo`?o00000oooool2o`0000_ooooo0_l00004ooooo`;o000000?o
ooooo`000?l000002Oooool2o`0000Gooooo0_l000000ooooooo0000o`000007ooooo`;o0000EOoo
ool001cooooo00?o0000ooooooooool0B_ooool2o`0000gooooo1?l00006ooooo`;o000000Cooooo
o`000?l0003o00004?ooool6o`0000Wooooo3ol000001?oooooo0000o`000?ooool2o`000003oooo
ool0003o000000;o00000_ooool2o`0000Cooooo0_l00005ooooo`;o00001Oooool2o`0001;ooooo
0_l00004ooooo`Co00007?ooool2o`0005Gooooo000Looooo`03o`000?oooooooooo05_ooooo0_l0
0004ooooo`;o00000oooool2o`00017ooooo1?l0000<ooooo`ko000000Coooooo`000?l0003ooooo
1ol0000Zooooo`;o00001?ooool2o`0000cooooo0_l0001Wooooo`007?ooool00ol0003ooooooooo
o`1Dooooo`;o00001Oooool3o`0000?ooooo0_l00003ooooo`;o00004oooool2o`0000cooooo1Ol0
00000ooooooo0000o`000006o`000003ooooool0003o000000;ooooo0ol0000^ooooo`;o00004Ooo
ool2o`0006Oooooo000Looooo`03o`000?oooooooooo05Cooooo0_l00005ooooo`?o00000oooool2
o`0000[ooooo1?l0000Booooo`;o00001Oooool;o`0000?ooooo0_l000000ooooooo0000o`00000/
ooooo`;o00000_ooool2o`0002Wooooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`1Qoooo
o`;o00001Oooool4o`000003ooooool0003o000000;o00003?ooool2o`0000Cooooo0_l00002oooo
o`;o000000?oooooo`000?l000002?l00007ooooo`Co00002_ooool2o`0001gooooo1?l0000?oooo
o`;o00006oooool2o`0004oooooo000Looooo`03o`000?oooooooooo04_ooooo0_l0000Aooooo`;o
00000oooool2o`0000?ooooo1?l000000ooooooo0000o`000004o`0000[ooooo0_l000001?oooooo
0000o`000?ooool2o`0000;ooooo0_l000000ooooooo0000o`000007o`0000[ooooo0_l00005oooo
o`;o00000oooool2o`0000Cooooo0_l0000Gooooo`Ko00003Oooool2o`0006cooooo000Looooo`03
o`000?oooooooooo04?ooooo0_l00006ooooo`;o00001oooool2o`0000Sooooo0_l00003ooooo`?o
00000oooool2o`0000;ooooo1_l00002ooooo`;o00000oooool5o`000003ooooool0003o000000co
oooo1Ol00002ooooo`;o00003?ooool3o`0000?ooooo1?l00002ooooo`;o00006oooool2o`0000Oo
oooo0_l0001booooo`007?ooool00ol0003oooooooooo`13ooooo`;o00003oooool2o`000003oooo
ool0003o000000Kooooo0ol000001?oooooo0000o`000?l0000?ooooo`;o00000oooool4o`0000oo
oooo0ol00005ooooo`;o00003?ooool2o`0000Cooooo1?l0000Kooooo`;o00002oooool2o`0000Wo
oooo0ol00009ooooo`;o0000Foooool001cooooo00?o0000ooooooooool0Eoooool2o`0000Kooooo
0ol000000ooooooo0000o`000002ooooo`;o00001?ooool2o`0000gooooo0_l0000?ooooo`;o0000
1oooool5o`0001?ooooo0_l000000ooooooo0000o`00000:ooooo`;o00002Oooool2o`0001Kooooo
1?l00008ooooo`;o0000Foooool001cooooo0_l0001Cooooo`;o00002_ooool4o`0000?ooooo1?l0
0004ooooo`;o00002?ooool2o`0000Gooooo0_l0000@ooooo`;o00001?ooool5o`0000Kooooo0_l0
0006ooooo`Oo000000?oooooo`000?l000002_ooool2o`0000Wooooo0_l0000@ooooo`;o00001Ooo
ool3o`0006Gooooo000Looooo`03o`000?oooooooooo05;ooooo0_l0000:ooooo`Co00000oooool4
o`0000kooooo0ol00004ooooo`;o00001?ooool4o`0000Sooooo0_l0000?ooooo`;o00001_ooool6
o`0000_ooooo0_l0000Mooooo`?o00001Oooool2o`0006Kooooo000Looooo`03o`000?oooooooooo
05gooooo0_l00003ooooo`;o000000?oooooo`000?l000001?ooool2o`0000_ooooo0_l00004oooo
o`;o00001?ooool8o`0000Gooooo0_l00002ooooo`;o00003Oooool2o`0000Gooooo0_l00002oooo
o`;o00002Oooool2o`0001Sooooo0_l00003ooooo`;o0000K_ooool001cooooo00?o0000oooooooo
ool0GOooool2o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`;o00002Oooool2o`0000Go
oooo0_l00009ooooo`Go00001?ooool6o`000003ooooool0003o000000[ooooo0_l00008ooooo`?o
00005Oooool2o`0000cooooo0_l00009ooooo`;o0000J?ooool001cooooo00?o0000ooooooooool0
E_ooool2o`0000kooooo0_l0000>ooooo`;o00001?ooool5o`0000?ooooo0_l00005ooooo`;o0000
1_ooool3o`0000;ooooo0_l00005ooooo`;o00000oooool2o`0000;ooooo0_l00004ooooo`?o0000
3oooool3o`0000?ooooo0_l0000Gooooo`?o0000Ioooool001cooooo00?o0000ooooooooool0E_oo
ool2o`0000kooooo0_l0000?ooooo`;o00000oooool2o`000003ooooool0003o000000?ooooo0_l0
0007ooooo`;o00001oooool4o`0000Gooooo0_l00007ooooo`;o00001_ooool3o`0000?ooooo0_l0
0008ooooo`?o00001oooool2o`0001Cooooo0_l00009ooooo`;o0000G?ooool001cooooo00?o0000
ooooooooool0J_ooool2o`0000Cooooo0_l00005ooooo`;o00005?ooool2o`000003ooooool0003o
000000Cooooo1Ol00002ooooo`;o000000?oooooo`000?l000003_ooool3o`0000?ooooo0_l0000B
ooooo`;o00007oooool2o`0005cooooo000Looooo`03o`000?oooooooooo067ooooo0_l00002oooo
o`;o00000oooool2o`0000Cooooo0_l0000Nooooo`;o00001oooool9o`0000_ooooo0_l0000@oooo
o`;o0000R?ooool001cooooo00?o0000ooooooooool0HOooool6o`0001oooooo0_l0000Cooooo`Wo
00002Oooool2o`0000Kooooo1Ol00005ooooo`;o00009_ooool2o`00063ooooo000Looooo`03o`00
0?oooooooooo053ooooo0_l0000@ooooo`Co00008?ooool2o`0001Cooooo0_l00002ooooo`Co0000
1?ooool3o`0000[ooooo1Ol00006ooooo`;o00005_ooool2o`0000gooooo0_l0001Pooooo`007?oo
ool00ol0003oooooooooo`1@ooooo`;o00004?ooool2o`0000Sooooo0ol0000Sooooo`;o00002?oo
ool2o`0000;ooooo0ol00005ooooo`?o00000oooool2o`00013ooooo0_l00005ooooo`;o00003ooo
ool2o`0006oooooo000Looooo`03o`000?oooooooooo06cooooo1Ol0000Qooooo`;o00002?ooool2
o`0000?ooooo0_l0000;ooooo`;o000000?oooooo`000?l000003Oooool2o`0000Cooooo0ol00020
ooooo`007?ooool00ol0003oooooooooo`1_ooooo`Co00005_ooool2o`0000gooooo0_l0000Goooo
o`;o00003Oooool2o`000004ooooool0003o0000ooooo`;o00003_ooool2o`00077ooooo000Loooo
o`03o`000?oooooooooo077ooooo0_l0000@ooooo`;o000000?oooooo`000?l000000ol00008oooo
o`;o00000oooool3o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l000006oooool2o`00
017ooooo0_l0001aooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool0
1Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0Poooool2o`000003ooooool0
003o000000;o00002Oooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo
0_l000000ooooooo0000o`00000mooooo`;o0000H_ooool00006oooooomgMgOoV9RHoooooonHV9So
MgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo
06oooooo0_l000000ooooooo0000o`000006ooooo`;o00001Oooool2o`0001Wooooo0_l00017oooo
o`;o0000H_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool0Koooool2o`000004ooooool0003o0000
ooooo`;o00000oooool5o`000004ooooool0003o0000o`0000;ooooo0_l0000Jooooo`;o00001?oo
ool2o`000:3ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8b
oiRHV?ooooooV9RHoc8b<P06ooooo`?o0000MOooool2o`0000Gooooo0ol000001?oooooo0000o`00
0?ooool4o`0000Cooooo0_l0000Dooooo`;o00001?ooool2o`000:3ooooo00000ooooooo0000oooo
o`02ooooo`03o`000?oooooooooo00Wooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`00
0?oooooooooo07Gooooo0_l00006ooooo`;o00001?ooool4o`0000Cooooo0_l0000Eooooo`?o0000
3?ooool2o`0000Kooooo0ol000000ooooooo0000o`00002:ooooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooo
ooooo`1mooooo`;o00001?ooool4o`000003ooooool0003o000001Sooooo0ol0000<ooooo`;o0000
1_ooool3o`000003ooooool0003o000008[ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_o
oooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo06gooooo0_l0000=oooo
o`;o00002_ooool2o`000;oooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoZJVY
oa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo06_ooooo1?l0000=ooooo`;o0000booo
ool001cooooo00?o0000ooooooooool0JOooool6o`0000Wooooo0_l0000@ooooo`;o0000:Oooool2
o`00017ooooo0_l0001oooooo`007?ooool00ol0003oooooooooo`1Yooooo`;o00000_ooool2o`00
00Kooooo1Ol0000@ooooo`;o00007?ooool2o`0000_ooooo0_l0000Aooooo`;o0000Ooooool001co
oooo00?o0000ooooooooool0GOooool2o`0001Kooooo0ol0000`ooooo`;o00002oooool2o`0009;o
oooo000Looooo`03o`000?oooooooooo05gooooo0_l0000[ooooo`;o0000_Oooool001cooooo00?o
0000ooooooooool0POooool2o`0000Cooooo0_l000001?oooooo0000o`000?l0002looooo`007?oo
ool00ol0003oooooooooo`21ooooo`;o00001?ooool2o`0000;ooooo0_l00003ooooo`;o0000>?oo
ool2o`0007gooooo000Looooo`03o`000?oooooooooo07oooooo0_l00006ooooo`;o00001oooool2
o`0003Cooooo0_l00002ooooo`;o00001_ooool2o`0007Gooooo000Looooo`03o`000?oooooooooo
07oooooo0_l00015ooooo`;o00002_ooool2o`0007Gooooo000Looooo`03o`000?oooooooooo07Go
oooo0_l0000=ooooo`;o0000`oooool001cooooo00?o0000ooooooooool0MOooool2o`0000gooooo
0_l0000Nooooo`;o00004oooool2o`0000;ooooo0_l0002:ooooo`007?ooool00ol0003ooooooooo
o`2Qooooo`;o000000?oooooo`000?l000002Oooool2o`0000Sooooo0_l00002ooooo`;o0000R_oo
ool001cooooo0_l0002Rooooo`;o00003?ooool2o`0009Sooooo000Looooo`03o`000?oooooooooo
07[ooooo0_l00002ooooo`;o00001Oooool2o`0000Cooooo0_l0000<ooooo`;o00005Oooool4o`00
00Kooooo0_l0002=ooooo`007?ooool00ol0003oooooooooo`1jooooo`Ko00001Oooool2o`0000Co
oooo0_l0000<ooooo`;o00005Oooool4o`0000Kooooo0_l0002=ooooo`007?ooool00ol0003ooooo
ooooo`1looooo`;o0000boooool001cooooo00?o0000ooooooooool0K?ooool2o`0002Oooooo0_l0
002booooo`007?ooool00ol0003oooooooooo`1/ooooo`;o00008Oooool2o`0000Cooooo0_l0002b
ooooo`007?ooool00ol0003oooooooooo`2?ooooo`;o0000^?ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Tooooo`;o0000Xooo
ool001cooooo00?o0000ooooooooool0Y?ooool2o`000:?ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooo
ooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB_ooool001Cooooo00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o
0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Doooo
o`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`00
4_ooool00omEEEGoIVIVo`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo002Uooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05Oooool01?l@
413o0000odA4A?o<c<`5ooooo`Co000000?o410@ooooooooool01Ol0002@ooooo`00Y_ooool01Ol0
003ooooooooooooooooo000000Wooooo1_l0000;ooooo`03oiRHV?l@413ogMgM00Kooooo00?o0000
ooooooooool00_ooool01OnHV9So8B4Qonk^k_ooooooA4A4093ooooo002Vooooo`05o`000?oooooo
ooooooooool000006oooool00on7QhOoEEEEooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o
V9RHob4Q8Oo^k^h0TOooool00:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00002Ooo
ool01Oo<c<co8B4Qo`000?mEEEGo000000Kooooo00?o0000ooooooooool01?ooool00onHV9So8B4Q
onk^kP2@ooooo`00Y_ooool01Ol0003oQhN7oooooonYZJWo000001Sooooo00Go8B4QohN7Qooooooo
V9RHo`000006ooooo`03o`000?oooooooooo00Gooooo00?oMgMgofIVI_ooool0Soooool00:Gooooo
00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Fooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo08kooooo0033ooooo`05ob4Q
8OnHV9SoooooogMgMomEEED01_ooool00ol0003oooooooooo`02ooooo`05o`000?nj^[[ooooooiRH
V?l@4100T?ooool00<?ooooo00Goc<c<oa0@4?l0003o<S8bonk^kP04ooooo`03oeEEEOmVIVKo0000
00Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c02@ooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(918) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.37555 .34789 Mdot
.39592 .38389 Mdot
.54869 .65344 Mdot
.55758 .45097 Mdot
.39792 .43961 Mdot
.50984 .66133 Mdot
.35143 .52402 Mdot
.31089 .54509 Mdot
.52488 .64798 Mdot
.63571 .4991 Mdot
.32218 .54129 Mdot
.51597 .40166 Mdot
.34455 .55231 Mdot
.56911 .43862 Mdot
.84949 .57572 Mdot
.62762 .36771 Mdot
.40481 .40679 Mdot
.66428 .6794 Mdot
.51983 .44108 Mdot
.50517 .69101 Mdot
.38022 .42901 Mdot
.57341 .44619 Mdot
.36403 .3514 Mdot
.5697 .4383 Mdot
.54448 .4306 Mdot
.37682 .36561 Mdot
.43101 .38109 Mdot
.5342 .43234 Mdot
.55954 .39411 Mdot
.32707 .56852 Mdot
.70935 .58715 Mdot
.84397 .45414 Mdot
.59692 .35316 Mdot
.28001 .28682 Mdot
.31166 .53152 Mdot
.70033 .31327 Mdot
.51034 .62514 Mdot
.35101 .56243 Mdot
.31203 .54093 Mdot
.30381 .5354 Mdot
.34165 .56296 Mdot
.37717 .37275 Mdot
.36612 .58455 Mdot
.38721 .54282 Mdot
.61657 .45052 Mdot
.27455 .48316 Mdot
.75875 .43297 Mdot
.59531 .38909 Mdot
.40931 .38308 Mdot
.49719 .69211 Mdot
.26622 .32833 Mdot
.31966 .57551 Mdot
.43315 .70942 Mdot
.74328 .21541 Mdot
.35846 .55054 Mdot
.60297 .46236 Mdot
.51408 .63467 Mdot
.59063 .43679 Mdot
.57582 .43663 Mdot
.4786 .34549 Mdot
.53973 .40465 Mdot
.66417 .64689 Mdot
.34832 .40846 Mdot
.47043 .65846 Mdot
.51355 .65427 Mdot
.3147 .54724 Mdot
.39757 .40654 Mdot
.3468 .54391 Mdot
.55839 .47606 Mdot
.48587 .64112 Mdot
.59608 .38985 Mdot
.32219 .55483 Mdot
.34599 .34999 Mdot
.61287 .40243 Mdot
.23625 .61676 Mdot
.77241 .68558 Mdot
.69503 .65348 Mdot
.50475 .3259 Mdot
.58823 .31229 Mdot
.63002 .77207 Mdot
.56328 .40794 Mdot
.48885 .84557 Mdot
.82836 .60615 Mdot
.37926 .3496 Mdot
.63598 .4706 Mdot
.53762 .59968 Mdot
.61645 .41374 Mdot
.46155 .47986 Mdot
.6028 .47262 Mdot
.21665 .55218 Mdot
.52802 .64317 Mdot
.37785 .3941 Mdot
.55771 .44957 Mdot
.57056 .37306 Mdot
.44654 .25895 Mdot
.52748 .41111 Mdot
.54633 .45294 Mdot
.40489 .34662 Mdot
.32327 .52522 Mdot
.54364 .36022 Mdot
.36609 .5008 Mdot
.41086 .69819 Mdot
.60984 .44859 Mdot
.52707 .62175 Mdot
.39631 .34172 Mdot
.61872 .42316 Mdot
.33934 .50909 Mdot
.57756 .38574 Mdot
.38595 .56648 Mdot
.39983 .38744 Mdot
.57356 .37175 Mdot
.62979 .66381 Mdot
.29009 .7188 Mdot
.37316 .39451 Mdot
.39254 .68628 Mdot
.57585 .38029 Mdot
.58414 .45072 Mdot
.39301 .3836 Mdot
.50253 .67639 Mdot
.52684 .52311 Mdot
.41634 .38593 Mdot
.30656 .52803 Mdot
.40122 .41475 Mdot
.65151 .44328 Mdot
.52837 .6553 Mdot
.42198 .6919 Mdot
.43453 .69083 Mdot
.66207 .55537 Mdot
.61531 .42105 Mdot
.26169 .39281 Mdot
.50737 .66874 Mdot
.37909 .38877 Mdot
.34336 .54475 Mdot
.63188 .43368 Mdot
.36135 .39456 Mdot
.3321 .53423 Mdot
.62692 .63955 Mdot
.56343 .69371 Mdot
.41255 .37802 Mdot
.33627 .60522 Mdot
.29857 .54365 Mdot
.30374 .52728 Mdot
.26634 .30464 Mdot
.39809 .37909 Mdot
.64779 .66551 Mdot
.33807 .53228 Mdot
.76252 .5424 Mdot
.59327 .46932 Mdot
.61611 .54728 Mdot
.37622 .82438 Mdot
.25113 .33798 Mdot
.33266 .68329 Mdot
.67447 .67261 Mdot
.30503 .51803 Mdot
.54873 .41184 Mdot
.39679 .3691 Mdot
.38891 .37025 Mdot
.54255 .45803 Mdot
.54564 .4418 Mdot
.60257 .39228 Mdot
.57008 .37492 Mdot
.78562 .46478 Mdot
.59483 .37909 Mdot
.68063 .62311 Mdot
.36603 .38644 Mdot
.53938 .41823 Mdot
.50652 .68241 Mdot
.62808 .39078 Mdot
.33172 .56183 Mdot
.58297 .44431 Mdot
.5533 .45075 Mdot
.57707 .36743 Mdot
.36324 .54358 Mdot
.82173 .43127 Mdot
.35243 .80111 Mdot
.70676 .27356 Mdot
.37392 .68483 Mdot
.49771 .64772 Mdot
.60901 .4378 Mdot
.64885 .65485 Mdot
.6371 .28682 Mdot
.56936 .4172 Mdot
.15688 .49234 Mdot
.55296 .45537 Mdot
.37327 .2358 Mdot
.5211 .35205 Mdot
.70456 .26302 Mdot
.59986 .58718 Mdot
.55856 .39095 Mdot
.46442 .23332 Mdot
.53606 .19978 Mdot
.40384 .54147 Mdot
.34554 .56099 Mdot
.51022 .68178 Mdot
.52081 .63059 Mdot
.32007 .58052 Mdot
.56968 .34203 Mdot
.50406 .38575 Mdot
.51654 .46172 Mdot
.42651 .69827 Mdot
.33766 .35862 Mdot
.6693 .63705 Mdot
.38562 .34083 Mdot
.59592 .84684 Mdot
.21145 .51798 Mdot
.36474 .58949 Mdot
.67645 .63392 Mdot
.54216 .66184 Mdot
.42806 .70011 Mdot
.64236 .65517 Mdot
.58537 .40319 Mdot
.4045 .39336 Mdot
.38991 .20342 Mdot
.5948 .3305 Mdot
.40092 .18296 Mdot
.36137 .40277 Mdot
.5148 .52489 Mdot
.33064 .54429 Mdot
.5298 .68249 Mdot
.57679 .45583 Mdot
.59985 .40916 Mdot
.34937 .41811 Mdot
.59452 .39165 Mdot
.35867 .43693 Mdot
.56213 .46094 Mdot
.56005 .66217 Mdot
.69694 .65943 Mdot
.32283 .58175 Mdot
.65069 .55819 Mdot
.35176 .35256 Mdot
.57571 .61198 Mdot
.48509 .67723 Mdot
.65549 .30142 Mdot
.32031 .55029 Mdot
.62455 .65651 Mdot
.48773 .67586 Mdot
.67679 .64227 Mdot
.6193 .38297 Mdot
.50392 .62673 Mdot
.67134 .66625 Mdot
.80796 .46191 Mdot
.62674 .43798 Mdot
.79299 .50462 Mdot
.34785 .52163 Mdot
.39792 .41656 Mdot
.5373 .40952 Mdot
.42182 .68438 Mdot
.5805 .35842 Mdot
.28788 .63376 Mdot
.43948 .69853 Mdot
.42523 .71791 Mdot
.66973 .74761 Mdot
.63828 .66807 Mdot
.29424 .67793 Mdot
.24983 .38524 Mdot
.40517 .40521 Mdot
.57827 .46532 Mdot
.75611 .31612 Mdot
.33785 .5331 Mdot
.58115 .40433 Mdot
.56216 .61955 Mdot
.34081 .53196 Mdot
.59494 .43421 Mdot
.35875 .52496 Mdot
.39386 .37193 Mdot
.46847 .77985 Mdot
.4002 .41056 Mdot
.62299 .44589 Mdot
.34566 .51374 Mdot
.48848 .65252 Mdot
.37743 .36229 Mdot
.57903 .38864 Mdot
.58605 .45541 Mdot
.41875 .70097 Mdot
.54479 .40348 Mdot
.76184 .33715 Mdot
.55378 .38688 Mdot
.54754 .63897 Mdot
.52948 .41076 Mdot
.16936 .44284 Mdot
.51771 .72876 Mdot
.3995 .4051 Mdot
.42609 .71624 Mdot
.52049 .64556 Mdot
.59037 .76082 Mdot
.40652 .57838 Mdot
.56801 .39393 Mdot
.41371 .71232 Mdot
.59121 .57025 Mdot
.33406 .57519 Mdot
.52392 .4343 Mdot
.23038 .52968 Mdot
.49998 .68611 Mdot
.42523 .70103 Mdot
.54381 .48492 Mdot
.39282 .33958 Mdot
.55597 .44905 Mdot
.48715 .64755 Mdot
.40616 .41301 Mdot
.62896 .41335 Mdot
.72407 .42528 Mdot
.43791 .69675 Mdot
.34955 .52482 Mdot
.48488 .38488 Mdot
.59886 .38509 Mdot
.50973 .62971 Mdot
.34637 .36356 Mdot
.31193 .52595 Mdot
.37009 .37191 Mdot
.4612 .1882 Mdot
.36296 .69863 Mdot
.77402 .42367 Mdot
.67038 .62817 Mdot
.33759 .63768 Mdot
.68404 .24384 Mdot
.31094 .7105 Mdot
.73036 .53272 Mdot
.54674 .16672 Mdot
.49355 .67671 Mdot
.58389 .65926 Mdot
.51649 .64232 Mdot
.5556 .42486 Mdot
.51237 .65827 Mdot
.70232 .25507 Mdot
.5568 .45971 Mdot
.50194 .63997 Mdot
.51773 .77203 Mdot
.5402 .43579 Mdot
.37137 .39512 Mdot
.8446 .57025 Mdot
.2109 .61321 Mdot
.20249 .43479 Mdot
.49392 .66241 Mdot
.47734 .37414 Mdot
.53559 .43354 Mdot
.61164 .3637 Mdot
.39417 .36229 Mdot
.5263 .43143 Mdot
.66809 .63728 Mdot
.66853 .63185 Mdot
.59759 .54636 Mdot
.40342 .80795 Mdot
.53686 .36532 Mdot
.3812 .36125 Mdot
.63057 .31447 Mdot
.23651 .60194 Mdot
.4045 .6961 Mdot
.36065 .5037 Mdot
.82616 .44854 Mdot
.53459 .35691 Mdot
.32377 .59995 Mdot
.23536 .54918 Mdot
.39249 .39736 Mdot
.79103 .396 Mdot
.35109 .55696 Mdot
.52619 .23934 Mdot
.37835 .27513 Mdot
.59361 .40851 Mdot
.31879 .5424 Mdot
.52051 .38549 Mdot
.19702 .54396 Mdot
.77462 .5643 Mdot
.64898 .7952 Mdot
.62156 .4458 Mdot
.27426 .6607 Mdot
.58259 .44824 Mdot
.53972 .52059 Mdot
.55289 .38721 Mdot
.36697 .36775 Mdot
.66639 .45553 Mdot
.43084 .49968 Mdot
.39807 .82141 Mdot
.20832 .5042 Mdot
.67695 .67029 Mdot
.58328 .45421 Mdot
.59452 .40974 Mdot
.62948 .65361 Mdot
.35848 .36028 Mdot
.56482 .37981 Mdot
.68885 .49157 Mdot
.60129 .39798 Mdot
.34213 .5653 Mdot
.65561 .58187 Mdot
.34891 .42595 Mdot
.5662 .37065 Mdot
.41459 .40415 Mdot
.36161 .54017 Mdot
.31353 .55043 Mdot
.60369 .47972 Mdot
.32655 .50434 Mdot
.5595 .45551 Mdot
.73842 .63607 Mdot
.39546 .35363 Mdot
.58746 .32714 Mdot
.35196 .36596 Mdot
.55619 .31446 Mdot
.34368 .51 Mdot
.42503 .68675 Mdot
.32479 .32698 Mdot
.35035 .55487 Mdot
.21798 .40464 Mdot
.50576 .44277 Mdot
.54495 .37382 Mdot
.19614 .51542 Mdot
.49113 .66457 Mdot
.4313 .69235 Mdot
.33068 .50712 Mdot
.60031 .38649 Mdot
.52352 .4064 Mdot
.35467 .56411 Mdot
.48196 .26655 Mdot
.59573 .75148 Mdot
.53774 .44178 Mdot
.36414 .36402 Mdot
.37709 .38679 Mdot
.62536 .41027 Mdot
.57374 .39596 Mdot
.54327 .65183 Mdot
.42679 .71227 Mdot
.40582 .70611 Mdot
.43492 .69245 Mdot
.5617 .65124 Mdot
.32081 .45727 Mdot
.30369 .53322 Mdot
.27635 .41359 Mdot
.26395 .59292 Mdot
.63351 .35375 Mdot
.50029 .6346 Mdot
.59429 .41881 Mdot
.56388 .45152 Mdot
.31238 .52425 Mdot
.36208 .65495 Mdot
.6431 .46241 Mdot
.40643 .36305 Mdot
.33574 .50537 Mdot
.51119 .38881 Mdot
.30756 .41186 Mdot
.67448 .65441 Mdot
.1974 .44112 Mdot
.31899 .55142 Mdot
.38805 .401 Mdot
.36901 .54172 Mdot
.59846 .406 Mdot
.56573 .47087 Mdot
.39174 .38957 Mdot
.65028 .67417 Mdot
.555 .48319 Mdot
.59633 .43509 Mdot
.18061 .64695 Mdot
.23731 .62373 Mdot
.27842 .54176 Mdot
.55185 .40177 Mdot
.52932 .39293 Mdot
.68453 .66086 Mdot
.59885 .4003 Mdot
.58666 .45703 Mdot
.29654 .7338 Mdot
.27684 .52932 Mdot
.65872 .68065 Mdot
.53494 .24078 Mdot
.363 .40436 Mdot
.79235 .37183 Mdot
.40776 .70566 Mdot
.35203 .58305 Mdot
.4503 .77188 Mdot
.4283 .70413 Mdot
.29445 .63053 Mdot
.79357 .38645 Mdot
.43405 .69263 Mdot
.53367 .59108 Mdot
.64131 .47432 Mdot
.54268 .45331 Mdot
.58827 .44564 Mdot
.65424 .65831 Mdot
.39768 .37682 Mdot
.56146 .56193 Mdot
.78698 .5906 Mdot
.57671 .44871 Mdot
.42223 .41709 Mdot
.81962 .47721 Mdot
.42058 .70347 Mdot
.65675 .63613 Mdot
.62079 .63691 Mdot
.58783 .4502 Mdot
.32676 .74851 Mdot
.37868 .36477 Mdot
.57855 .38894 Mdot
.59671 .37625 Mdot
.49294 .65866 Mdot
.39955 .40025 Mdot
.48319 .6698 Mdot
.44018 .69374 Mdot
.57732 .20175 Mdot
.15976 .60856 Mdot
.3184 .51711 Mdot
.73435 .32323 Mdot
.32661 .57228 Mdot
.67507 .76603 Mdot
.43242 .70318 Mdot
.56672 .4112 Mdot
.34946 .35259 Mdot
.57974 .38522 Mdot
.58137 .41161 Mdot
.58619 .40439 Mdot
.50392 .42677 Mdot
.15928 .48232 Mdot
.64498 .64567 Mdot
.6519 .40469 Mdot
.54475 .63607 Mdot
.74998 .33356 Mdot
.8038 .61877 Mdot
.60128 .41709 Mdot
.59357 .45055 Mdot
.36678 .39478 Mdot
.53838 .45463 Mdot
.34156 .5732 Mdot
.34609 .36292 Mdot
.58405 .36683 Mdot
.78229 .39199 Mdot
.57067 .37758 Mdot
.68663 .25455 Mdot
.36912 .5441 Mdot
.21658 .40985 Mdot
.65115 .41983 Mdot
.43137 .68905 Mdot
.43165 .69238 Mdot
.40984 .71943 Mdot
.37229 .54563 Mdot
.50585 .63369 Mdot
.76066 .6546 Mdot
.59818 .34727 Mdot
.54734 .41667 Mdot
.52322 .40439 Mdot
.55204 .61912 Mdot
.46046 .47423 Mdot
.31683 .68903 Mdot
.5061 .39747 Mdot
.53375 .65939 Mdot
.39672 .41807 Mdot
.44276 .66947 Mdot
.3487 .3602 Mdot
.6651 .6814 Mdot
.3232 .54451 Mdot
.67353 .64759 Mdot
.23757 .36469 Mdot
.39797 .38623 Mdot
.3464 .41619 Mdot
.49873 .64473 Mdot
.4936 .52306 Mdot
.72086 .21257 Mdot
.48749 .63502 Mdot
.68238 .52856 Mdot
.3883 .35831 Mdot
.59497 .37231 Mdot
.61796 .57752 Mdot
.4853 .51529 Mdot
.50511 .64482 Mdot
.56443 .42255 Mdot
.37614 .78003 Mdot
.54253 .65379 Mdot
.52335 .43405 Mdot
.51047 .67462 Mdot
.33138 .55917 Mdot
.50692 .67147 Mdot
.34073 .36963 Mdot
.61671 .42947 Mdot
.74501 .22892 Mdot
.58558 .60219 Mdot
.55134 .3913 Mdot
.33729 .50593 Mdot
.68975 .46539 Mdot
.58328 .4209 Mdot
.66212 .6326 Mdot
.52915 .65684 Mdot
.61038 .72916 Mdot
.5341 .42581 Mdot
.50194 .66025 Mdot
.36795 .34866 Mdot
.37109 .5547 Mdot
.68921 .74216 Mdot
.41719 .69007 Mdot
.39887 .36515 Mdot
.44477 .69434 Mdot
.35334 .50809 Mdot
.52697 .40054 Mdot
.60039 .38089 Mdot
.36419 .37623 Mdot
.47042 .79943 Mdot
.5317 .4125 Mdot
.56332 .40833 Mdot
.54207 .66635 Mdot
.54628 .6175 Mdot
.48496 .79358 Mdot
.4914 .67417 Mdot
.52335 .45299 Mdot
.36475 .3756 Mdot
.55871 .44402 Mdot
.37538 .40022 Mdot
.57369 .464 Mdot
.42861 .35134 Mdot
.38329 .35036 Mdot
.37015 .74012 Mdot
.56058 .43276 Mdot
.50596 .36423 Mdot
.58458 .40827 Mdot
.59802 .39353 Mdot
.54113 .64089 Mdot
.63989 .64128 Mdot
.63751 .43447 Mdot
.61892 .62232 Mdot
.65112 .63375 Mdot
.48566 .19441 Mdot
.49288 .66347 Mdot
.66406 .65912 Mdot
.79837 .49408 Mdot
.42207 .71782 Mdot
.65249 .65016 Mdot
.81552 .60182 Mdot
.31578 .5196 Mdot
.37171 .41439 Mdot
.54055 .43564 Mdot
.52614 .16615 Mdot
.73783 .60792 Mdot
.41458 .70706 Mdot
.55413 .38775 Mdot
.59081 .4205 Mdot
.41774 .36873 Mdot
.55697 .85403 Mdot
.55222 .64643 Mdot
.55238 .42696 Mdot
.39111 .4096 Mdot
.41426 .84956 Mdot
.53586 .62805 Mdot
.65218 .65329 Mdot
.35878 .56009 Mdot
.40749 .3412 Mdot
.4153 .69054 Mdot
.33915 .57565 Mdot
.41275 .74281 Mdot
.21778 .39698 Mdot
.57704 .37946 Mdot
.50228 .63103 Mdot
.23131 .35681 Mdot
.57195 .34461 Mdot
.28469 .56029 Mdot
.51447 .48167 Mdot
.38928 .39814 Mdot
.35324 .56396 Mdot
.67958 .65548 Mdot
.34319 .36708 Mdot
.36143 .35946 Mdot
.30931 .54393 Mdot
.47252 .63503 Mdot
.50936 .52316 Mdot
.33463 .56575 Mdot
.22264 .55673 Mdot
.41666 .1979 Mdot
.42031 .71532 Mdot
.63878 .63684 Mdot
.33167 .25503 Mdot
.37637 .37245 Mdot
.82517 .44494 Mdot
.19657 .41547 Mdot
.54592 .45249 Mdot
.66085 .66637 Mdot
.29649 .48861 Mdot
.77713 .63083 Mdot
.34344 .53019 Mdot
.42206 .47987 Mdot
.6143 .64744 Mdot
.5335 .43695 Mdot
.44095 .3494 Mdot
.55933 .42038 Mdot
.32627 .54302 Mdot
.561 .32118 Mdot
.38681 .4015 Mdot
.34442 .5038 Mdot
.19738 .43777 Mdot
.56708 .45467 Mdot
.56215 .42559 Mdot
.68614 .57911 Mdot
.40671 .39031 Mdot
.40668 .70044 Mdot
.57072 .38658 Mdot
.5903 .43926 Mdot
.54764 .37731 Mdot
.49738 .38054 Mdot
.30108 .72476 Mdot
.55363 .42824 Mdot
.53137 .68691 Mdot
.60239 .35987 Mdot
.56271 .43387 Mdot
.41501 .40226 Mdot
.15964 .58874 Mdot
.43033 .68562 Mdot
.58526 .44309 Mdot
.57576 .37813 Mdot
.30947 .53472 Mdot
.55579 .55205 Mdot
.47564 .51044 Mdot
.50166 .62478 Mdot
.75263 .51386 Mdot
.50415 .42591 Mdot
.36051 .39629 Mdot
.62165 .65469 Mdot
.61926 .39645 Mdot
.36576 .40012 Mdot
.6293 .38013 Mdot
.5378 .65836 Mdot
.42276 .71419 Mdot
.21027 .44836 Mdot
.66016 .65117 Mdot
.721 .61032 Mdot
.27256 .43235 Mdot
.51379 .68212 Mdot
.54501 .42136 Mdot
.34323 .58114 Mdot
.50218 .62625 Mdot
.41745 .69993 Mdot
.5899 .49034 Mdot
.38827 .367 Mdot
.3749 .39369 Mdot
.60862 .55552 Mdot
.50551 .70688 Mdot
.2469 .71669 Mdot
.32976 .55754 Mdot
.6055 .36444 Mdot
.25253 .39079 Mdot
.37443 .39439 Mdot
.62013 .55863 Mdot
.66532 .65827 Mdot
.3445 .52907 Mdot
.40122 .70651 Mdot
.36519 .3967 Mdot
.41116 .38524 Mdot
.6283 .43188 Mdot
.60539 .42404 Mdot
.72194 .53447 Mdot
.60483 .54966 Mdot
.36106 .55029 Mdot
.62874 .64618 Mdot
.48026 .66502 Mdot
.55551 .41718 Mdot
.37561 .34951 Mdot
.38364 .21399 Mdot
.5808 .37581 Mdot
.54444 .65053 Mdot
.38807 .3957 Mdot
.63026 .65777 Mdot
.65967 .63308 Mdot
.598 .39439 Mdot
.49605 .34281 Mdot
.35679 .54069 Mdot
.37373 .39621 Mdot
.29165 .3273 Mdot
.53272 .40783 Mdot
.60852 .42492 Mdot
.53419 .48506 Mdot
.31939 .56301 Mdot
.22 .40971 Mdot
.64091 .67279 Mdot
.38575 .37588 Mdot
.56382 .38387 Mdot
.6643 .64779 Mdot
.23775 .39384 Mdot
.42451 .70907 Mdot
.51059 .67238 Mdot
.66403 .63314 Mdot
.63983 .66406 Mdot
.63488 .63584 Mdot
.83125 .46119 Mdot
.34031 .35419 Mdot
.64193 .32826 Mdot
.54438 .39523 Mdot
.6092 .55735 Mdot
.61777 .46116 Mdot
.3684 .55191 Mdot
.48999 .66625 Mdot
.58494 .41192 Mdot
.62784 .43218 Mdot
.48279 .4105 Mdot
.55544 .33707 Mdot
.40352 .4258 Mdot
.40078 .39172 Mdot
.62623 .35291 Mdot
.49157 .65608 Mdot
.56103 .86219 Mdot
.71735 .23715 Mdot
.64623 .44361 Mdot
.5295 .53793 Mdot
.36575 .35139 Mdot
.30849 .54841 Mdot
.46194 .50823 Mdot
.3645 .53083 Mdot
.38288 .38047 Mdot
.55528 .42073 Mdot
.2809 .4183 Mdot
.68323 .64516 Mdot
.6026 .38925 Mdot
.33346 .54007 Mdot
.60258 .39054 Mdot
.34906 .57008 Mdot
.30882 .36782 Mdot
.22796 .57056 Mdot
.55247 .45542 Mdot
.5361 .39585 Mdot
.47123 .40779 Mdot
.60012 .41959 Mdot
.53835 .8283 Mdot
.35836 .35698 Mdot
.38901 .79278 Mdot
.63026 .41507 Mdot
.53768 .30335 Mdot
.53831 .40206 Mdot
.42414 .78017 Mdot
.61003 .41759 Mdot
.44559 .53643 Mdot
.54043 .44861 Mdot
.60349 .44812 Mdot
.3512 .51759 Mdot
.30953 .53539 Mdot
.3894 .34676 Mdot
.40822 .69614 Mdot
.71659 .28462 Mdot
.60118 .43233 Mdot
.55325 .6669 Mdot
.2946 .58182 Mdot
.63286 .65663 Mdot
.38065 .37906 Mdot
.42827 .86181 Mdot
.35996 .52982 Mdot
.47395 .67152 Mdot
.47864 .80719 Mdot
.51817 .68914 Mdot
.31308 .49112 Mdot
.58966 .51817 Mdot
.64748 .67213 Mdot
.53169 .429 Mdot
.2888 .28622 Mdot
.24432 .6209 Mdot
.5773 .4883 Mdot
.34929 .50763 Mdot
.63755 .29301 Mdot
.33335 .25662 Mdot
.63473 .62955 Mdot
.67718 .66517 Mdot
.35729 .52865 Mdot
.54291 .66943 Mdot
.51116 .44177 Mdot
.66689 .65812 Mdot
.52508 .67401 Mdot
.41522 .72127 Mdot
.42013 .54089 Mdot
.37947 .36783 Mdot
.1995 .44239 Mdot
.26124 .47136 Mdot
.36251 .54653 Mdot
.59026 .63674 Mdot
.42289 .35052 Mdot
.36722 .33489 Mdot
.4152 .68848 Mdot
.54167 .63963 Mdot
.34111 .36067 Mdot
.52957 .46116 Mdot
.56433 .33115 Mdot
.58013 .44726 Mdot
.64894 .66123 Mdot
.60664 .41371 Mdot
.54097 .64693 Mdot
.34334 .53505 Mdot
.53067 .63221 Mdot
.35256 .52191 Mdot
.3089 .44972 Mdot
.58138 .39316 Mdot
.60287 .44697 Mdot
.73388 .6139 Mdot
.40143 .35178 Mdot
.2687 .33073 Mdot
.56395 .65389 Mdot
.51647 .63705 Mdot
.57704 .46123 Mdot
.35339 .35434 Mdot
.70081 .66403 Mdot
.73271 .61963 Mdot
.60844 .38881 Mdot
.35717 .35731 Mdot
.55018 .42127 Mdot
.79931 .47129 Mdot
.22843 .63085 Mdot
.3699 .37638 Mdot
.42557 .82623 Mdot
.55658 .40184 Mdot
.67259 .42226 Mdot
.52132 .4105 Mdot
.6986 .49807 Mdot
.53087 .41237 Mdot
.36059 .4022 Mdot
.58063 .44336 Mdot
.34468 .37196 Mdot
.5305 .67648 Mdot
.30564 .54654 Mdot
.39658 .36006 Mdot
.606 .38215 Mdot
.83387 .41667 Mdot
.32753 .54841 Mdot
.581 .45442 Mdot
.32711 .52283 Mdot
.38172 .41157 Mdot
.40958 .37668 Mdot
.77835 .64511 Mdot
.27444 .54771 Mdot
.33339 .55965 Mdot
.55056 .43297 Mdot
.23927 .47209 Mdot
.55695 .43743 Mdot
.71031 .54072 Mdot
.61965 .44176 Mdot
.53032 .41067 Mdot
.76739 .69987 Mdot
.32834 .57476 Mdot
.25576 .71993 Mdot
.79256 .57328 Mdot
.83299 .47438 Mdot
.37654 .33015 Mdot
.63395 .62988 Mdot
.7974 .40407 Mdot
.43999 .69651 Mdot
.51832 .6656 Mdot
.58596 .41103 Mdot
.31781 .37385 Mdot
.35108 .56323 Mdot
.63827 .64351 Mdot
.55366 .45613 Mdot
.5452 .64562 Mdot
.65551 .73696 Mdot
.31012 .51195 Mdot
.37757 .37345 Mdot
.40671 .36058 Mdot
.38993 .8316 Mdot
.56381 .38311 Mdot
.5914 .45339 Mdot
.32423 .54254 Mdot
.55725 .34171 Mdot
.62771 .6592 Mdot
.51087 .76316 Mdot
.33356 .55908 Mdot
.5014 .55705 Mdot
.40154 .3848 Mdot
.59234 .41931 Mdot
.47388 .48027 Mdot
.40251 .60707 Mdot
.53063 .21851 Mdot
.65044 .6571 Mdot
.71265 .55185 Mdot
.36098 .40263 Mdot
.34049 .54232 Mdot
.57496 .68704 Mdot
.58996 .35743 Mdot
.58966 .42525 Mdot
.71061 .55589 Mdot
.57631 .56554 Mdot
.70753 .65124 Mdot
.55295 .46807 Mdot
.57618 .56233 Mdot
.58487 .4616 Mdot
.55619 .37163 Mdot
.54553 .46974 Mdot
.61266 .4251 Mdot
.35935 .35522 Mdot
.48942 .40775 Mdot
.50586 .66607 Mdot
.45378 .25447 Mdot
.43435 .4844 Mdot
.53864 .41032 Mdot
.55679 .42673 Mdot
.58245 .23738 Mdot
.27423 .57784 Mdot
.37094 .35426 Mdot
.33928 .38426 Mdot
.32162 .50699 Mdot
.50389 .36512 Mdot
.55765 .64659 Mdot
.49841 .44755 Mdot
.5328 .63502 Mdot
.35285 .36007 Mdot
.51711 .63203 Mdot
.31037 .51478 Mdot
.50218 .63084 Mdot
.56214 .65244 Mdot
.34885 .56782 Mdot
.40479 .37739 Mdot
.61043 .40023 Mdot
.33367 .50561 Mdot
.68852 .57747 Mdot
.65039 .6612 Mdot
.78004 .64326 Mdot
.61477 .36998 Mdot
.41165 .46049 Mdot
.72458 .42723 Mdot
.529 .63312 Mdot
.24647 .67312 Mdot
.38514 .35069 Mdot
.68991 .65562 Mdot
.35403 .35742 Mdot
.18232 .43951 Mdot
.63557 .64162 Mdot
.81892 .59678 Mdot
.45288 .70718 Mdot
.65186 .72271 Mdot
.56297 .47238 Mdot
.41929 .33717 Mdot
.48677 .64326 Mdot
.35231 .56213 Mdot
.43706 .72313 Mdot
.61113 .44189 Mdot
.31969 .71487 Mdot
.40625 .35269 Mdot
.4136 .71862 Mdot
.34572 .54593 Mdot
.33743 .50321 Mdot
.58005 .3814 Mdot
.53848 .78411 Mdot
.61892 .4333 Mdot
.48045 .71124 Mdot
.73753 .53276 Mdot
.50389 .46185 Mdot
.56535 .46093 Mdot
.52524 .6229 Mdot
.54979 .42238 Mdot
.66251 .32973 Mdot
.26999 .30089 Mdot
.52211 .46237 Mdot
.36727 .71151 Mdot
.66364 .68766 Mdot
.39394 .38688 Mdot
.65003 .41893 Mdot
.41372 .69769 Mdot
.55434 .40112 Mdot
.26582 .25526 Mdot
.6547 .64846 Mdot
.57487 .6244 Mdot
.546 .39015 Mdot
.57438 .38479 Mdot
.35181 .2902 Mdot
.31797 .36328 Mdot
.40064 .70712 Mdot
.5883 .43013 Mdot
.75643 .53355 Mdot
.31769 .53207 Mdot
.62207 .42222 Mdot
.58754 .44741 Mdot
.52376 .19542 Mdot
.31736 .55772 Mdot
.52565 .63069 Mdot
.43367 .70812 Mdot
.48099 .67186 Mdot
.61527 .65994 Mdot
.46457 .52297 Mdot
.61921 .55008 Mdot
.22904 .62645 Mdot
.62885 .63425 Mdot
.58206 .37226 Mdot
.64526 .46069 Mdot
.56301 .39445 Mdot
.68047 .65921 Mdot
.32393 .56547 Mdot
.38079 .35229 Mdot
.21541 .45308 Mdot
.42479 .69906 Mdot
.52304 .43036 Mdot
.67435 .6421 Mdot
.39446 .368 Mdot
.5826 .61488 Mdot
.39029 .3809 Mdot
.34289 .55769 Mdot
.3692 .52018 Mdot
.65312 .63881 Mdot
.34943 .36167 Mdot
.50382 .69783 Mdot
.78349 .59622 Mdot
.61119 .45281 Mdot
.30491 .50596 Mdot
.36516 .34747 Mdot
.4295 .38044 Mdot
.39601 .34409 Mdot
.59049 .39182 Mdot
.53989 .54199 Mdot
.56812 .36746 Mdot
.35949 .53534 Mdot
.51914 .67241 Mdot
.61363 .54323 Mdot
.31996 .29293 Mdot
.55594 .58201 Mdot
.61143 .46836 Mdot
.57083 .45185 Mdot
.58752 .45027 Mdot
.61185 .4599 Mdot
.54626 .70092 Mdot
.57638 .395 Mdot
.35096 .51824 Mdot
.535 .64527 Mdot
.54218 .40028 Mdot
.41034 .70154 Mdot
.50215 .51435 Mdot
.619 .64948 Mdot
.44793 .51014 Mdot
.79501 .36257 Mdot
.39471 .36615 Mdot
.48542 .66897 Mdot
.5156 .66558 Mdot
.62631 .64011 Mdot
.3521 .56051 Mdot
.39465 .37837 Mdot
.71168 .48797 Mdot
.63052 .63978 Mdot
.58418 .44196 Mdot
.43538 .75824 Mdot
.38688 .75697 Mdot
.53158 .43742 Mdot
.57627 .41694 Mdot
.42773 .71555 Mdot
.55035 .66149 Mdot
.44907 .15513 Mdot
.62734 .5815 Mdot
.64635 .63949 Mdot
.66212 .67267 Mdot
.37757 .33707 Mdot
.63901 .46224 Mdot
.35346 .52741 Mdot
.66641 .58631 Mdot
.67153 .49329 Mdot
.70724 .61065 Mdot
.67007 .76525 Mdot
.59362 .38172 Mdot
.39273 .29795 Mdot
.56233 .45511 Mdot
.41333 .36106 Mdot
.40076 .4059 Mdot
.37807 .35649 Mdot
.35867 .54645 Mdot
.5696 .30863 Mdot
.34261 .51271 Mdot
.76695 .31553 Mdot
.3518 .39308 Mdot
.57045 .70885 Mdot
.51047 .6338 Mdot
.64021 .3848 Mdot
.63274 .66262 Mdot
.34544 .48547 Mdot
.55621 .47523 Mdot
.31306 .7356 Mdot
.50145 .63348 Mdot
.40694 .38249 Mdot
.59585 .51499 Mdot
.64469 .21589 Mdot
.492 .52691 Mdot
.65023 .35876 Mdot
.35059 .30191 Mdot
.62968 .64858 Mdot
.52712 .22011 Mdot
.66088 .67706 Mdot
.33596 .53247 Mdot
.61236 .43719 Mdot
.61654 .41659 Mdot
.57327 .46453 Mdot
.57821 .3954 Mdot
.31129 .52347 Mdot
.63663 .40757 Mdot
.16937 .44287 Mdot
.42371 .71583 Mdot
.79965 .4558 Mdot
.67196 .65551 Mdot
.36548 .52474 Mdot
.53432 .64233 Mdot
.40493 .70761 Mdot
.6403 .5549 Mdot
.54049 .44712 Mdot
.58415 .41002 Mdot
.41032 .68827 Mdot
.54028 .46272 Mdot
.50288 .40857 Mdot
.50581 .66387 Mdot
.55798 .58097 Mdot
.65718 .62918 Mdot
.67422 .64909 Mdot
.32826 .56574 Mdot
.35062 .36018 Mdot
.66006 .65859 Mdot
.54393 .66509 Mdot
.63556 .39171 Mdot
.60702 .37991 Mdot
.36703 .34668 Mdot
.19536 .41722 Mdot
.62256 .63439 Mdot
.60193 .51283 Mdot
.35261 .38986 Mdot
.34074 .35039 Mdot
.58736 .42642 Mdot
.52869 .47755 Mdot
.43257 .38278 Mdot
.6502 .63119 Mdot
.36433 .52189 Mdot
.64807 .70806 Mdot
.33041 .53712 Mdot
.3961 .37425 Mdot
.62747 .40894 Mdot
.40384 .38088 Mdot
.55293 .39763 Mdot
.84072 .66004 Mdot
.61461 .41576 Mdot
.2038 .5884 Mdot
.69517 .51363 Mdot
.51673 .66256 Mdot
.50327 .69745 Mdot
.4114 .70996 Mdot
.35483 .3943 Mdot
.61996 .39441 Mdot
.66138 .67391 Mdot
.82867 .52809 Mdot
.43488 .36363 Mdot
.52971 .66462 Mdot
.55666 .65213 Mdot
.33345 .57431 Mdot
.55236 .38566 Mdot
.59435 .421 Mdot
.50666 .62823 Mdot
.73924 .42611 Mdot
.35792 .38884 Mdot
.5885 .45375 Mdot
.56568 .4456 Mdot
.51165 .66281 Mdot
.78105 .59984 Mdot
.34316 .32535 Mdot
.61077 .43619 Mdot
.6006 .66683 Mdot
.36976 .55042 Mdot
.60065 .46548 Mdot
.63668 .40971 Mdot
.653 .66932 Mdot
.77632 .39929 Mdot
.28552 .27668 Mdot
.36634 .55322 Mdot
.40726 .69969 Mdot
.58318 .36937 Mdot
.50917 .63523 Mdot
.60538 .38012 Mdot
.69771 .29593 Mdot
.41777 .71764 Mdot
.56847 .40196 Mdot
.63434 .46269 Mdot
.40536 .40132 Mdot
.57431 .39233 Mdot
.57298 .21974 Mdot
.4814 .64663 Mdot
.57087 .39722 Mdot
.47868 .35068 Mdot
.31488 .55032 Mdot
.64491 .44522 Mdot
.67546 .65911 Mdot
.69955 .49226 Mdot
.27448 .44516 Mdot
.54429 .61072 Mdot
.67249 .64879 Mdot
.61051 .39445 Mdot
.53622 .67521 Mdot
.36158 .55295 Mdot
.30601 .70984 Mdot
.55855 .46481 Mdot
.32675 .54433 Mdot
.34411 .53692 Mdot
.65999 .64464 Mdot
.28853 .75564 Mdot
.64297 .40701 Mdot
.60209 .41695 Mdot
.58005 .21633 Mdot
.41784 .3858 Mdot
.6078 .40884 Mdot
.58204 .3742 Mdot
.34318 .5165 Mdot
.32503 .32457 Mdot
.61064 .27535 Mdot
.51524 .77153 Mdot
.35353 .56881 Mdot
.49633 .61242 Mdot
.53207 .67821 Mdot
.67076 .65707 Mdot
.3884 .38987 Mdot
.61596 .65425 Mdot
.49628 .66368 Mdot
.57171 .37823 Mdot
.34283 .52042 Mdot
.43218 .21548 Mdot
.31871 .57402 Mdot
.50838 .61681 Mdot
.42325 .37136 Mdot
.24575 .40893 Mdot
.21286 .3155 Mdot
.26984 .47228 Mdot
.36726 .58403 Mdot
.63328 .65717 Mdot
.42709 .74056 Mdot
.56754 .44808 Mdot
.51592 .22746 Mdot
.60634 .39595 Mdot
.43627 .33385 Mdot
.49598 .6753 Mdot
.41225 .68945 Mdot
.61268 .4354 Mdot
.72973 .54416 Mdot
.30106 .54784 Mdot
.33581 .57503 Mdot
.57454 .40449 Mdot
.34992 .55557 Mdot
.60165 .42629 Mdot
.53873 .63973 Mdot
.23034 .68424 Mdot
.57526 .45355 Mdot
.54169 .3787 Mdot
.28947 .59306 Mdot
.78964 .6323 Mdot
.5228 .69471 Mdot
.38322 .29536 Mdot
.61036 .19519 Mdot
.35037 .55429 Mdot
.60541 .48452 Mdot
.49314 .63606 Mdot
.42771 .71579 Mdot
.4987 .69869 Mdot
.60341 .40142 Mdot
.59747 .39969 Mdot
.576 .46124 Mdot
.56174 .42463 Mdot
.5231 .22709 Mdot
.51221 .36882 Mdot
.43322 .3079 Mdot
.58182 .41034 Mdot
.43489 .3429 Mdot
.32891 .50807 Mdot
.378 .42772 Mdot
.61068 .64021 Mdot
.59147 .38113 Mdot
.34924 .43019 Mdot
.37082 .54026 Mdot
.76534 .3134 Mdot
.3269 .57006 Mdot
.52087 .64673 Mdot
.31155 .55756 Mdot
.54724 .40065 Mdot
.37644 .38696 Mdot
.49167 .63112 Mdot
.28713 .66283 Mdot
.5202 .66527 Mdot
.55147 .39104 Mdot
.63377 .69199 Mdot
.51378 .66729 Mdot
.47623 .49683 Mdot
.37989 .391 Mdot
.75414 .54428 Mdot
.39965 .407 Mdot
.56809 .39859 Mdot
.56551 .40283 Mdot
.4289 .7205 Mdot
.30258 .54058 Mdot
.3834 .41299 Mdot
.1865 .65806 Mdot
.64198 .67641 Mdot
.37367 .35921 Mdot
.60675 .35305 Mdot
.56055 .5575 Mdot
.36852 .38414 Mdot
.74223 .48946 Mdot
.3548 .5595 Mdot
.34258 .35426 Mdot
.5994 .35357 Mdot
.35829 .60689 Mdot
.68516 .64441 Mdot
.5444 .62897 Mdot
.45043 .5649 Mdot
.48428 .64792 Mdot
.36856 .52738 Mdot
.52762 .61424 Mdot
.31735 .52857 Mdot
.2607 .3458 Mdot
.58122 .3211 Mdot
.33177 .58302 Mdot
.36288 .51502 Mdot
.49852 .65029 Mdot
.55874 .46217 Mdot
.40988 .48907 Mdot
.5526 .46917 Mdot
.57804 .4736 Mdot
.3156 .53628 Mdot
.37137 .40911 Mdot
.37138 .41544 Mdot
.42729 .34126 Mdot
.40807 .36131 Mdot
.53574 .6355 Mdot
.22564 .62804 Mdot
.24124 .35922 Mdot
.32059 .54421 Mdot
.34479 .50096 Mdot
.55675 .43437 Mdot
.50497 .63865 Mdot
.5181 .68225 Mdot
.35111 .52849 Mdot
.46281 .22253 Mdot
.57286 .36569 Mdot
.42667 .38228 Mdot
.34809 .38721 Mdot
.36673 .37545 Mdot
.38846 .34081 Mdot
.58162 .27528 Mdot
.35421 .561 Mdot
.35356 .3943 Mdot
.57128 .4048 Mdot
.59921 .40073 Mdot
.42757 .69172 Mdot
.67587 .65202 Mdot
.62599 .37543 Mdot
.51723 .43942 Mdot
.58745 .42405 Mdot
.5116 .67159 Mdot
.65646 .39658 Mdot
.40792 .71016 Mdot
.55061 .64019 Mdot
.55934 .64285 Mdot
.42665 .68738 Mdot
.43788 .35277 Mdot
.61562 .18945 Mdot
.55231 .42649 Mdot
.61408 .32879 Mdot
.50993 .63845 Mdot
.26788 .70424 Mdot
.22519 .40629 Mdot
.56916 .4637 Mdot
.41398 .57337 Mdot
.51331 .61981 Mdot
.41555 .37784 Mdot
.60761 .40329 Mdot
.43573 .6967 Mdot
.61995 .65051 Mdot
.6009 .3509 Mdot
.43568 .70581 Mdot
.34807 .36663 Mdot
.62498 .62638 Mdot
.34599 .34809 Mdot
.50965 .62012 Mdot
.63684 .45959 Mdot
.72032 .20941 Mdot
.48467 .67523 Mdot
.81703 .54713 Mdot
.31388 .37014 Mdot
.58433 .45622 Mdot
.48278 .66516 Mdot
.41801 .38005 Mdot
.37304 .53867 Mdot
.57051 .55599 Mdot
.39402 .35341 Mdot
.40637 .69858 Mdot
.43169 .69679 Mdot
.50784 .66504 Mdot
.39911 .39507 Mdot
.6245 .41848 Mdot
.38791 .40439 Mdot
.31333 .56025 Mdot
.5518 .44842 Mdot
.6991 .25365 Mdot
.58454 .33118 Mdot
.36041 .39988 Mdot
.54712 .6441 Mdot
.68571 .65841 Mdot
.54515 .44895 Mdot
.80836 .53807 Mdot
.56679 .37652 Mdot
.31996 .53434 Mdot
.36201 .78148 Mdot
.4605 .20715 Mdot
.53758 .40482 Mdot
.55713 .43303 Mdot
.35241 .56572 Mdot
.54208 .44816 Mdot
.53247 .41311 Mdot
.28226 .56609 Mdot
.39826 .40311 Mdot
.57642 .44523 Mdot
.53102 .67297 Mdot
.28625 .30073 Mdot
.56393 .37088 Mdot
.3852 .67845 Mdot
.74491 .54751 Mdot
.34459 .78159 Mdot
.61349 .40099 Mdot
.64668 .5747 Mdot
.56607 .42173 Mdot
.59332 .38707 Mdot
.55275 .43685 Mdot
.37858 .28768 Mdot
.49664 .65174 Mdot
.53754 .65371 Mdot
.683 .6415 Mdot
.7473 .54293 Mdot
.66037 .66741 Mdot
.33862 .57121 Mdot
.65335 .75399 Mdot
.41857 .71639 Mdot
.34815 .36256 Mdot
.62093 .41178 Mdot
.48354 .63898 Mdot
.59325 .41624 Mdot
.54819 .40213 Mdot
.52996 .62259 Mdot
.50039 .68745 Mdot
.58037 .64305 Mdot
.64668 .67327 Mdot
.38743 .35599 Mdot
.62756 .4358 Mdot
.65183 .63386 Mdot
.62404 .41144 Mdot
.59765 .57558 Mdot
.38138 .35455 Mdot
.39541 .40466 Mdot
.40352 .41065 Mdot
.57162 .37807 Mdot
.53969 .41069 Mdot
.34057 .51197 Mdot
.35087 .35464 Mdot
.32523 .56085 Mdot
.49412 .63241 Mdot
.48059 .6813 Mdot
.60318 .40134 Mdot
.65638 .47145 Mdot
.65324 .67135 Mdot
.5256 .64289 Mdot
.40608 .69076 Mdot
.68913 .6599 Mdot
.55953 .38421 Mdot
.52365 .62233 Mdot
.67278 .64516 Mdot
.42689 .24076 Mdot
.57313 .17108 Mdot
.68368 .66066 Mdot
.57299 .40649 Mdot
.34246 .2913 Mdot
.7695 .60913 Mdot
.6476 .67847 Mdot
.32874 .52646 Mdot
.57568 .37504 Mdot
.70703 .38328 Mdot
.61571 .64181 Mdot
.28314 .31978 Mdot
.51812 .66058 Mdot
.38643 .58228 Mdot
.55985 .35473 Mdot
.49788 .23537 Mdot
.62129 .66261 Mdot
.39029 .37686 Mdot
.39363 .42257 Mdot
.57624 .42924 Mdot
.60517 .64428 Mdot
.33935 .57658 Mdot
.52575 .65705 Mdot
.53757 .68006 Mdot
.3978 .39788 Mdot
.23323 .50105 Mdot
.53345 .66729 Mdot
.62393 .50098 Mdot
.4649 .77751 Mdot
.52459 .34869 Mdot
.46359 .36798 Mdot
.25472 .61358 Mdot
.59459 .37042 Mdot
.6798 .66704 Mdot
.36459 .52805 Mdot
.3547 .52486 Mdot
.33642 .55798 Mdot
.5061 .69641 Mdot
.45901 .50807 Mdot
.49481 .64041 Mdot
.30221 .69555 Mdot
.6645 .64843 Mdot
.7713 .52597 Mdot
.62009 .40052 Mdot
.57202 .45218 Mdot
.60852 .36512 Mdot
.61508 .44211 Mdot
.5674 .42818 Mdot
.35011 .56056 Mdot
.51896 .69177 Mdot
.6054 .73052 Mdot
.36253 .36565 Mdot
.53992 .58695 Mdot
.5107 .63356 Mdot
.42618 .71637 Mdot
.64244 .64522 Mdot
.54542 .52539 Mdot
.53655 .61163 Mdot
.5177 .63291 Mdot
.63473 .38244 Mdot
.369 .39938 Mdot
.50987 .46146 Mdot
.56329 .40969 Mdot
.5281 .64009 Mdot
.46055 .67917 Mdot
.61784 .25841 Mdot
.5673 .5011 Mdot
.6957 .64575 Mdot
.54806 .54894 Mdot
.65602 .67869 Mdot
.52526 .38923 Mdot
.27603 .7138 Mdot
.49661 .66275 Mdot
.51452 .65176 Mdot
.67863 .64946 Mdot
.66805 .43852 Mdot
.39194 .39519 Mdot
.41092 .6901 Mdot
.32727 .51931 Mdot
.56435 .3954 Mdot
.48628 .68528 Mdot
.66739 .37371 Mdot
.5685 .77425 Mdot
.3311 .55536 Mdot
.55042 .64281 Mdot
.55012 .38832 Mdot
.57374 .4086 Mdot
.6298 .65287 Mdot
.37437 .44451 Mdot
.61217 .3493 Mdot
.83337 .47228 Mdot
.22905 .56839 Mdot
.2104 .531 Mdot
.58988 .42523 Mdot
.4007 .39843 Mdot
.43203 .70292 Mdot
.63536 .63822 Mdot
.63275 .41062 Mdot
.585 .17624 Mdot
.41657 .41021 Mdot
.33633 .53832 Mdot
.43518 .69491 Mdot
.45933 .50548 Mdot
.57149 .37505 Mdot
.60647 .39661 Mdot
.58515 .39343 Mdot
.51495 .14538 Mdot
.53038 .66608 Mdot
.40718 .35545 Mdot
.64727 .65668 Mdot
.40959 .36118 Mdot
.52967 .65987 Mdot
.22336 .45605 Mdot
.5345 .41946 Mdot
.42523 .3783 Mdot
.38773 .37866 Mdot
.33357 .57403 Mdot
.3738 .53915 Mdot
.58279 .63088 Mdot
.61416 .41721 Mdot
.43598 .69824 Mdot
.40278 .40585 Mdot
.51757 .68761 Mdot
.63402 .64277 Mdot
.33912 .50796 Mdot
.58187 .40903 Mdot
.50177 .66682 Mdot
.56372 .48562 Mdot
.3675 .38852 Mdot
.51694 .63323 Mdot
.42878 .68396 Mdot
.66823 .67006 Mdot
.59122 .40421 Mdot
.70089 .65571 Mdot
.41817 .68603 Mdot
.56501 .44681 Mdot
.53806 .50955 Mdot
.70695 .66885 Mdot
.3048 .67775 Mdot
.48771 .65344 Mdot
.41872 .69303 Mdot
.40922 .40188 Mdot
.28343 .34508 Mdot
.51871 .65227 Mdot
.53832 .51597 Mdot
.36112 .4543 Mdot
.62653 .43901 Mdot
.37326 .37309 Mdot
.43781 .74285 Mdot
.81709 .41613 Mdot
.79023 .53172 Mdot
.58309 .45258 Mdot
.48268 .66018 Mdot
.66738 .63853 Mdot
.32011 .54394 Mdot
.38471 .6804 Mdot
.62639 .32033 Mdot
.53618 .61816 Mdot
.55375 .43313 Mdot
.3983 .40666 Mdot
.35138 .53189 Mdot
.28932 .42206 Mdot
.54905 .65544 Mdot
.49262 .67319 Mdot
.54189 .39961 Mdot
.66485 .65608 Mdot
.7707 .44079 Mdot
.54225 .64686 Mdot
.48603 .68376 Mdot
.39916 .74336 Mdot
.67609 .64337 Mdot
.57114 .41824 Mdot
.42586 .33959 Mdot
.60765 .46367 Mdot
.82003 .54482 Mdot
.4081 .70554 Mdot
.36054 .36668 Mdot
.602 .39241 Mdot
.50461 .77771 Mdot
.53015 .64482 Mdot
.52442 .53525 Mdot
.47122 .65414 Mdot
.35583 .55787 Mdot
.48447 .68294 Mdot
.60305 .41061 Mdot
.30179 .55181 Mdot
.65409 .67114 Mdot
.61125 .43283 Mdot
.53933 .41309 Mdot
.41545 .37102 Mdot
.33576 .53117 Mdot
.36471 .23787 Mdot
.3453 .50351 Mdot
.36919 .54232 Mdot
.36631 .41769 Mdot
.58008 .43688 Mdot
.51966 .64351 Mdot
.52581 .61546 Mdot
.63107 .41787 Mdot
.22815 .65715 Mdot
.39276 .39724 Mdot
.57889 .61876 Mdot
.46477 .15612 Mdot
.54162 .49573 Mdot
.41512 .6842 Mdot
.40068 .43952 Mdot
.34881 .57155 Mdot
.57752 .4074 Mdot
.35623 .39224 Mdot
.49547 .69139 Mdot
.53275 .6685 Mdot
.62648 .4115 Mdot
.34773 .53449 Mdot
.6213 .64079 Mdot
.496 .67882 Mdot
.54004 .78289 Mdot
.58111 .38953 Mdot
.32574 .71629 Mdot
.48955 .67483 Mdot
.84183 .52269 Mdot
.59274 .74654 Mdot
.37035 .37149 Mdot
.54594 .40616 Mdot
.40459 .36025 Mdot
.64377 .65861 Mdot
.5212 .59912 Mdot
.34501 .53431 Mdot
.58431 .50065 Mdot
.23454 .31833 Mdot
.498 .64587 Mdot
.36023 .35506 Mdot
.53893 .40253 Mdot
.58087 .51035 Mdot
.6051 .41674 Mdot
.33009 .31856 Mdot
.59597 .64392 Mdot
.31515 .54039 Mdot
.32175 .53154 Mdot
.56306 .45004 Mdot
.62483 .64977 Mdot
.53896 .62851 Mdot
.52449 .65666 Mdot
.6369 .84826 Mdot
.42414 .68277 Mdot
.71892 .52886 Mdot
.59502 .40106 Mdot
.52943 .68135 Mdot
.31814 .29173 Mdot
.32395 .54324 Mdot
.61763 .43934 Mdot
.54928 .6681 Mdot
.30877 .61182 Mdot
.59013 .57259 Mdot
.56973 .42571 Mdot
.51253 .39131 Mdot
.32655 .52156 Mdot
.72018 .59971 Mdot
.49847 .63514 Mdot
.61794 .44243 Mdot
.33313 .49992 Mdot
.4748 .78954 Mdot
.24222 .34201 Mdot
.38697 .35604 Mdot
.48562 .63095 Mdot
.35025 .56082 Mdot
.59951 .34434 Mdot
.6728 .65381 Mdot
.48382 .64412 Mdot
.51807 .66933 Mdot
.54698 .43393 Mdot
.6377 .38428 Mdot
.54551 .49878 Mdot
.35677 .36085 Mdot
.32239 .51166 Mdot
.61418 .43592 Mdot
.2339 .50699 Mdot
.5814 .46221 Mdot
.33032 .51018 Mdot
.84773 .33369 Mdot
.57871 .47107 Mdot
.60346 .41908 Mdot
.77956 .4629 Mdot
.39719 .35493 Mdot
.41021 .36456 Mdot
.22549 .58661 Mdot
.59467 .4014 Mdot
.62843 .73754 Mdot
.39219 .35781 Mdot
.38809 .39789 Mdot
.54923 .72185 Mdot
.55767 .45599 Mdot
.72859 .61849 Mdot
.35199 .52439 Mdot
.35835 .52361 Mdot
.39072 .40363 Mdot
.60806 .34673 Mdot
.36197 .55594 Mdot
.55779 .24408 Mdot
.50598 .63385 Mdot
.27989 .71953 Mdot
.36326 .3861 Mdot
.40264 .4713 Mdot
.32512 .54952 Mdot
.77017 .31964 Mdot
.409 .58743 Mdot
.57203 .46147 Mdot
.58742 .40128 Mdot
.66044 .67046 Mdot
.59474 .48019 Mdot
.40574 .70601 Mdot
.34959 .55621 Mdot
.75281 .39825 Mdot
.3778 .35696 Mdot
.6107 .41952 Mdot
.55482 .5306 Mdot
.29668 .44289 Mdot
.36396 .71624 Mdot
.39315 .38636 Mdot
.37666 .36844 Mdot
.49158 .65397 Mdot
.50306 .67623 Mdot
.57489 .43442 Mdot
.35806 .53382 Mdot
.34966 .35384 Mdot
.32411 .5152 Mdot
.49734 .66544 Mdot
.51827 .63688 Mdot
.41803 .71825 Mdot
.53047 .45695 Mdot
.53757 .6305 Mdot
.52001 .79031 Mdot
.22961 .49927 Mdot
.37111 .33512 Mdot
.27184 .27079 Mdot
.28921 .41985 Mdot
.72098 .44847 Mdot
.6473 .67498 Mdot
.45411 .68625 Mdot
.30736 .53765 Mdot
.55813 .43647 Mdot
.58865 .41289 Mdot
.42039 .70395 Mdot
.30728 .5584 Mdot
.63618 .64801 Mdot
.30432 .55238 Mdot
.66587 .64603 Mdot
.49191 .69422 Mdot
.57088 .36948 Mdot
.5905 .37483 Mdot
.34677 .56115 Mdot
.52308 .62887 Mdot
.53681 .64733 Mdot
.66068 .67792 Mdot
.59213 .55726 Mdot
.50689 .6662 Mdot
.3645 .3871 Mdot
.55911 .28497 Mdot
.43033 .6995 Mdot
.60773 .40527 Mdot
.61456 .55815 Mdot
.49724 .21621 Mdot
.61811 .44949 Mdot
.43265 .68991 Mdot
.52792 .85804 Mdot
.61862 .40714 Mdot
.45702 .85367 Mdot
.42005 .69193 Mdot
.39658 .35375 Mdot
.48408 .66307 Mdot
.40594 .71089 Mdot
.5593 .35211 Mdot
.67299 .68141 Mdot
.62604 .38652 Mdot
.39964 .35928 Mdot
.41169 .4065 Mdot
.19956 .52443 Mdot
.81799 .54859 Mdot
.66605 .67608 Mdot
.65026 .6413 Mdot
.51753 .65411 Mdot
.74412 .71031 Mdot
.6078 .35838 Mdot
.64275 .6411 Mdot
.74505 .40676 Mdot
.55502 .42594 Mdot
.70167 .5467 Mdot
.4176 .56903 Mdot
.39912 .39882 Mdot
.4493 .36768 Mdot
.52535 .64987 Mdot
.36457 .35371 Mdot
.2179 .4865 Mdot
.6114 .36779 Mdot
.37838 .35497 Mdot
.33263 .51151 Mdot
.30042 .63498 Mdot
.40793 .37327 Mdot
.60545 .57142 Mdot
.35437 .53067 Mdot
.46071 .72299 Mdot
.76234 .45635 Mdot
.19588 .30785 Mdot
.35376 .55383 Mdot
.51624 .62315 Mdot
.51451 .61913 Mdot
.52086 .65751 Mdot
.38912 .35074 Mdot
.53213 .67577 Mdot
.35367 .3678 Mdot
.76879 .62405 Mdot
.59474 .55501 Mdot
.6541 .63843 Mdot
.27529 .56102 Mdot
.38207 .37436 Mdot
.25943 .6664 Mdot
.22161 .30933 Mdot
.57506 .40252 Mdot
.34033 .50171 Mdot
.6792 .65198 Mdot
.84362 .59268 Mdot
.65607 .66993 Mdot
.49155 .63839 Mdot
.28788 .73198 Mdot
.60386 .42748 Mdot
.65962 .29653 Mdot
.66827 .67227 Mdot
.39868 .38163 Mdot
.56733 .44938 Mdot
.48663 .69978 Mdot
.66805 .65911 Mdot
.62006 .64587 Mdot
.56878 .43872 Mdot
.40733 .38481 Mdot
.52043 .63956 Mdot
.30669 .52952 Mdot
.64236 .67881 Mdot
.5802 .33875 Mdot
.62134 .45059 Mdot
.59945 .36737 Mdot
.48604 .5178 Mdot
.71745 .37691 Mdot
.35121 .55304 Mdot
.77135 .57016 Mdot
.50707 .67591 Mdot
.46933 .74127 Mdot
.23638 .58753 Mdot
.29435 .50483 Mdot
.40842 .70306 Mdot
.41023 .71261 Mdot
.56971 .42967 Mdot
.71999 .37944 Mdot
.38788 .78538 Mdot
.28086 .58627 Mdot
.42972 .70215 Mdot
.52987 .65394 Mdot
.39861 .42115 Mdot
.18902 .49462 Mdot
.61938 .45668 Mdot
.35266 .57195 Mdot
.50601 .66917 Mdot
.69535 .29366 Mdot
.66063 .65256 Mdot
.26672 .6957 Mdot
.53845 .40668 Mdot
.60197 .44751 Mdot
.34678 .54932 Mdot
.34416 .51381 Mdot
.36399 .69288 Mdot
.2093 .54516 Mdot
.67667 .60138 Mdot
.29541 .35771 Mdot
.68102 .28678 Mdot
.38527 .42799 Mdot
.3627 .40192 Mdot
.44078 .69301 Mdot
.34635 .50748 Mdot
.60737 .39358 Mdot
.34815 .35908 Mdot
.36324 .71871 Mdot
.39753 .331 Mdot
.71302 .54513 Mdot
.60232 .75395 Mdot
.55538 .39131 Mdot
.37447 .40334 Mdot
.37185 .35283 Mdot
.35799 .34285 Mdot
.42956 .68847 Mdot
.58938 .42961 Mdot
.55398 .45888 Mdot
.60554 .44913 Mdot
.54133 .3508 Mdot
.5771 .39041 Mdot
.2455 .53976 Mdot
.50782 .55767 Mdot
.76164 .39609 Mdot
.60808 .45787 Mdot
.361 .52976 Mdot
.61085 .37076 Mdot
.62414 .6474 Mdot
.55433 .43614 Mdot
.71199 .53709 Mdot
.33336 .54723 Mdot
.65779 .4562 Mdot
.29325 .35624 Mdot
.53585 .41378 Mdot
.63667 .63119 Mdot
.72188 .40309 Mdot
.35567 .24823 Mdot
.5306 .58532 Mdot
.36573 .38874 Mdot
.54685 .61876 Mdot
.3168 .56426 Mdot
.51704 .64456 Mdot
.59518 .4622 Mdot
.43808 .69469 Mdot
.28145 .49967 Mdot
.40487 .47383 Mdot
.60269 .38592 Mdot
.65438 .40503 Mdot
.37648 .39611 Mdot
.52215 .62238 Mdot
.33837 .40898 Mdot
.59266 .39254 Mdot
.65057 .65895 Mdot
.66877 .65433 Mdot
.221 .53363 Mdot
.7062 .27803 Mdot
.27576 .34405 Mdot
.34778 .55065 Mdot
.54278 .65274 Mdot
.61721 .65823 Mdot
.63771 .33499 Mdot
.36275 .56632 Mdot
.34254 .5734 Mdot
.34145 .52825 Mdot
.56273 .39082 Mdot
.40671 .70636 Mdot
.73317 .36442 Mdot
.40561 .70181 Mdot
.53598 .41826 Mdot
.52308 .66957 Mdot
.41242 .71901 Mdot
.66677 .66755 Mdot
.32747 .5657 Mdot
.49569 .6673 Mdot
.56859 .3958 Mdot
.39303 .36325 Mdot
.58372 .5541 Mdot
.67906 .50725 Mdot
.81139 .50278 Mdot
.81326 .48554 Mdot
.38976 .41593 Mdot
.75484 .31786 Mdot
.31167 .50239 Mdot
.46565 .22258 Mdot
.61526 .68304 Mdot
.6289 .4198 Mdot
.19311 .60003 Mdot
.49718 .6356 Mdot
.52638 .62135 Mdot
.5686 .41775 Mdot
.50526 .68992 Mdot
.60886 .41851 Mdot
.49578 .6729 Mdot
.53619 .58854 Mdot
.61909 .45868 Mdot
.53266 .62732 Mdot
.55872 .35968 Mdot
.54596 .44841 Mdot
.39779 .40184 Mdot
.48048 .65843 Mdot
.58669 .46265 Mdot
.79472 .67373 Mdot
.3411 .51006 Mdot
.43021 .68946 Mdot
.61047 .60012 Mdot
.34819 .56307 Mdot
.37029 .36115 Mdot
.58031 .47518 Mdot
.63938 .66583 Mdot
.39092 .37339 Mdot
.58223 .62554 Mdot
.67299 .66959 Mdot
.22611 .63006 Mdot
.36928 .3941 Mdot
.42805 .70037 Mdot
.65717 .67245 Mdot
.65456 .42095 Mdot
.47805 .65538 Mdot
.6636 .49818 Mdot
.41059 .69307 Mdot
.59516 .42004 Mdot
.54089 .68052 Mdot
.34158 .50791 Mdot
.58849 .4487 Mdot
.48477 .67692 Mdot
.42616 .68657 Mdot
.55812 .39865 Mdot
.56104 .43195 Mdot
.19435 .44474 Mdot
.34867 .74439 Mdot
.63041 .64903 Mdot
.42169 .38862 Mdot
.57095 .40442 Mdot
.64344 .67205 Mdot
.58012 .79818 Mdot
.59413 .36934 Mdot
.3909 .34796 Mdot
.49109 .43554 Mdot
.50862 .6784 Mdot
.32608 .56219 Mdot
.49128 .62618 Mdot
.6212 .6535 Mdot
.2214 .71351 Mdot
.41774 .71985 Mdot
.5312 .3802 Mdot
.6228 .41446 Mdot
.44486 .71176 Mdot
.36503 .3547 Mdot
.6768 .59858 Mdot
.59084 .40399 Mdot
.57342 .33104 Mdot
.60828 .43466 Mdot
.60148 .73907 Mdot
.39143 .39643 Mdot
.60112 .41793 Mdot
.63163 .49839 Mdot
.54177 .38629 Mdot
.62216 .63808 Mdot
.78024 .50127 Mdot
.60734 .37429 Mdot
.62912 .13507 Mdot
.41149 .68723 Mdot
.5356 .62846 Mdot
.4781 .70126 Mdot
.67384 .78148 Mdot
.2686 .33843 Mdot
.35348 .36515 Mdot
.43918 .43663 Mdot
.519 .64196 Mdot
.29228 .30931 Mdot
.7777 .34421 Mdot
.5439 .44496 Mdot
.56853 .37727 Mdot
.49152 .63841 Mdot
.51721 .6882 Mdot
.43653 .70249 Mdot
.59072 .46499 Mdot
.64133 .46301 Mdot
.54869 .64804 Mdot
.57401 .38523 Mdot
.50508 .45777 Mdot
.30842 .52666 Mdot
.4084 .39632 Mdot
.31963 .54701 Mdot
.3246 .56881 Mdot
.50599 .25952 Mdot
.22981 .5646 Mdot
.33057 .50962 Mdot
.29862 .54621 Mdot
.70143 .53833 Mdot
.48415 .44295 Mdot
.61618 .64967 Mdot
.77065 .37235 Mdot
.51436 .65866 Mdot
.58887 .43143 Mdot
.37137 .41256 Mdot
.48808 .24252 Mdot
.41052 .61127 Mdot
.32567 .76442 Mdot
.59689 .39093 Mdot
.52897 .64942 Mdot
.42074 .68697 Mdot
.62392 .4524 Mdot
.4875 .73874 Mdot
.59357 .45254 Mdot
.4834 .63934 Mdot
.57445 .2957 Mdot
.56992 .52517 Mdot
.4254 .7487 Mdot
.33522 .36524 Mdot
.61807 .41642 Mdot
.35912 .37833 Mdot
.32796 .55557 Mdot
.62767 .65837 Mdot
.63132 .65173 Mdot
.56494 .44317 Mdot
.6118 .32088 Mdot
.41961 .55813 Mdot
.54241 .44508 Mdot
.54945 .44065 Mdot
.41873 .6926 Mdot
.55002 .44266 Mdot
.62255 .41837 Mdot
.61194 .44492 Mdot
.53024 .39645 Mdot
.36882 .54054 Mdot
.57058 .52714 Mdot
.52535 .45199 Mdot
.5252 .4762 Mdot
.31203 .51462 Mdot
.41553 .44084 Mdot
.31811 .55993 Mdot
.69651 .25118 Mdot
.31884 .53422 Mdot
.63536 .64325 Mdot
.56564 .65277 Mdot
.48009 .38595 Mdot
.34402 .35819 Mdot
.37178 .54439 Mdot
.64648 .64989 Mdot
.34258 .55855 Mdot
.52985 .66806 Mdot
.38423 .1948 Mdot
.39609 .33071 Mdot
.65184 .58437 Mdot
.34961 .60272 Mdot
.33121 .71599 Mdot
.49649 .64375 Mdot
.39322 .39968 Mdot
.62818 .26078 Mdot
.59263 .45871 Mdot
.66273 .67163 Mdot
.57048 .43468 Mdot
.36916 .54619 Mdot
.52454 .65349 Mdot
.79565 .54808 Mdot
.63239 .65802 Mdot
.20629 .38285 Mdot
.52284 .6602 Mdot
.55895 .46587 Mdot
.35447 .57046 Mdot
.26529 .27505 Mdot
.31666 .54297 Mdot
.59812 .55552 Mdot
.41163 .35422 Mdot
.42837 .33287 Mdot
.37632 .37526 Mdot
.37575 .70966 Mdot
.52269 .13641 Mdot
.81963 .44535 Mdot
.39851 .36944 Mdot
.44168 .76466 Mdot
.56359 .38332 Mdot
.60446 .36814 Mdot
.60365 .50973 Mdot
.40868 .35571 Mdot
.57383 .39774 Mdot
.41553 .69093 Mdot
.23024 .46599 Mdot
.50202 .75612 Mdot
.54575 .61894 Mdot
.60699 .41155 Mdot
.31381 .51376 Mdot
.30486 .55566 Mdot
.40759 .71489 Mdot
.31304 .55269 Mdot
.55794 .4598 Mdot
.37988 .3751 Mdot
.38677 .4757 Mdot
.64982 .66528 Mdot
.80454 .62371 Mdot
.60977 .64249 Mdot
.47052 .69198 Mdot
.63649 .46054 Mdot
.51836 .6361 Mdot
.36948 .84631 Mdot
.57389 .45979 Mdot
.39045 .35545 Mdot
.55986 .41896 Mdot
.61592 .42786 Mdot
.60252 .36638 Mdot
.54572 .6597 Mdot
.68378 .62516 Mdot
.57213 .38739 Mdot
.34398 .53338 Mdot
.79118 .42821 Mdot
.61668 .37268 Mdot
.52725 .59085 Mdot
.7492 .527 Mdot
.29604 .68964 Mdot
.34589 .34476 Mdot
.52305 .62391 Mdot
.37903 .35993 Mdot
.34123 .38638 Mdot
.37007 .36109 Mdot
.73541 .35758 Mdot
.62038 .26917 Mdot
.52333 .85384 Mdot
.4689 .35418 Mdot
.45214 .24286 Mdot
.42325 .39374 Mdot
.56342 .81626 Mdot
.35182 .38745 Mdot
.35969 .36118 Mdot
.89492 .56352 Mdot
.3495 .38689 Mdot
.60155 .40454 Mdot
.63878 .39822 Mdot
.2779 .46023 Mdot
.68418 .55004 Mdot
.55667 .44713 Mdot
.56927 .41021 Mdot
.63629 .6666 Mdot
.66708 .33538 Mdot
.43869 .7024 Mdot
.22297 .62545 Mdot
.31288 .4331 Mdot
.56856 .43633 Mdot
.56919 .40307 Mdot
.63859 .37605 Mdot
.45644 .12397 Mdot
.52254 .24408 Mdot
.4166 .40586 Mdot
.64891 .37589 Mdot
.82975 .55857 Mdot
.54252 .45324 Mdot
.5851 .37304 Mdot
.553 .39737 Mdot
.5196 .64292 Mdot
.41463 .4136 Mdot
.64899 .37721 Mdot
.26746 .65293 Mdot
.547 .39414 Mdot
.28138 .52612 Mdot
.71459 .65082 Mdot
.60208 .41042 Mdot
.37778 .33864 Mdot
.55076 .41994 Mdot
.36634 .39351 Mdot
.39972 .4035 Mdot
.63996 .3789 Mdot
.72524 .32712 Mdot
.39312 .34667 Mdot
.53829 .41194 Mdot
.5267 .63184 Mdot
.82126 .43114 Mdot
.59566 .41759 Mdot
.64365 .6352 Mdot
.5895 .40208 Mdot
.64516 .63057 Mdot
.54348 .43684 Mdot
.40729 .69693 Mdot
.48572 .20396 Mdot
.51348 .65304 Mdot
.73055 .65804 Mdot
.54239 .67134 Mdot
.1941 .44758 Mdot
.38751 .34825 Mdot
.43642 .68453 Mdot
.29168 .75275 Mdot
.42278 .69263 Mdot
.55936 .53957 Mdot
.51043 .57565 Mdot
.36015 .53795 Mdot
.41222 .3699 Mdot
.76083 .58365 Mdot
.40807 .73317 Mdot
.57741 .66134 Mdot
.55854 .64028 Mdot
.21852 .69427 Mdot
.24656 .7031 Mdot
.56678 .39294 Mdot
.67496 .309 Mdot
.4393 .30659 Mdot
.59066 .37033 Mdot
.56326 .47389 Mdot
.47631 .66098 Mdot
.62028 .40309 Mdot
.47252 .4985 Mdot
.49864 .64914 Mdot
.65015 .64616 Mdot
.35911 .36808 Mdot
.65665 .63165 Mdot
.50675 .70271 Mdot
.53282 .56573 Mdot
.50077 .67215 Mdot
.53592 .38705 Mdot
.56198 .41515 Mdot
.38594 .40515 Mdot
.32995 .40358 Mdot
.40584 .3995 Mdot
.68108 .65669 Mdot
.50129 .6551 Mdot
.51162 .23686 Mdot
.57584 .4142 Mdot
.38593 .38044 Mdot
.38784 .53241 Mdot
.57426 .40796 Mdot
.33793 .56226 Mdot
.56025 .38249 Mdot
.40032 .36818 Mdot
.5498 .44273 Mdot
.37941 .3732 Mdot
.50895 .62789 Mdot
.53644 .44469 Mdot
.56992 .42102 Mdot
.25898 .29118 Mdot
.63561 .65022 Mdot
.38945 .34896 Mdot
.45198 .54937 Mdot
.56418 .46694 Mdot
.4463 .72147 Mdot
.61286 .4013 Mdot
.46543 .42609 Mdot
.5473 .3676 Mdot
.42105 .68995 Mdot
.55363 .48296 Mdot
.59641 .41798 Mdot
.64478 .49495 Mdot
.47933 .33486 Mdot
.3421 .41561 Mdot
.36204 .55999 Mdot
.38675 .34071 Mdot
.48017 .67949 Mdot
.50502 .69398 Mdot
.50477 .68408 Mdot
.6691 .56495 Mdot
.63829 .37771 Mdot
.60221 .42784 Mdot
.37037 .52236 Mdot
.65508 .64249 Mdot
.39259 .38441 Mdot
.6602 .64464 Mdot
.22117 .60144 Mdot
.67975 .65919 Mdot
.40613 .70963 Mdot
.59043 .74874 Mdot
.53164 .22418 Mdot
.63916 .66835 Mdot
.40703 .39822 Mdot
.59096 .75997 Mdot
.62713 .42534 Mdot
.58302 .61889 Mdot
.65268 .65909 Mdot
.19489 .67041 Mdot
.61069 .39115 Mdot
.54329 .54051 Mdot
.31393 .52804 Mdot
.67258 .65772 Mdot
.3323 .53317 Mdot
.55927 .44596 Mdot
.31458 .68636 Mdot
.3576 .35572 Mdot
.31243 .50786 Mdot
.52776 .45996 Mdot
.67028 .64298 Mdot
.51043 .66936 Mdot
.31209 .5942 Mdot
.36111 .53122 Mdot
.47403 .1903 Mdot
.78974 .53409 Mdot
.50056 .65322 Mdot
.39548 .77819 Mdot
.33587 .52397 Mdot
.59502 .37103 Mdot
.51296 .361 Mdot
.56758 .46236 Mdot
.51003 .69659 Mdot
.5251 .62352 Mdot
.24772 .47006 Mdot
.56005 .41357 Mdot
.61201 .39539 Mdot
.43212 .36932 Mdot
.50303 .63915 Mdot
.37323 .38595 Mdot
.35342 .34421 Mdot
.51062 .62478 Mdot
.3707 .3739 Mdot
.66878 .67092 Mdot
.23295 .43583 Mdot
.33581 .52296 Mdot
.3419 .53687 Mdot
.52843 .65468 Mdot
.54486 .63572 Mdot
.51683 .63473 Mdot
.55983 .38278 Mdot
.39413 .39057 Mdot
.54442 .41224 Mdot
.58808 .36739 Mdot
.33383 .35407 Mdot
.349 .38957 Mdot
.55065 .40933 Mdot
.43543 .74137 Mdot
.6751 .684 Mdot
.53567 .6323 Mdot
.32182 .5157 Mdot
.30901 .30359 Mdot
.36782 .51113 Mdot
.60883 .41068 Mdot
.33503 .61734 Mdot
.40221 .37475 Mdot
.65954 .67006 Mdot
.70226 .67389 Mdot
.64679 .66807 Mdot
.37048 .56619 Mdot
.35675 .34771 Mdot
.22637 .6276 Mdot
.60775 .41602 Mdot
.48218 .51536 Mdot
.76668 .57401 Mdot
.23806 .60708 Mdot
.32819 .5103 Mdot
.57168 .40711 Mdot
.42623 .69391 Mdot
.59926 .24465 Mdot
.59771 .44951 Mdot
.6072 .45306 Mdot
.60292 .70683 Mdot
.52728 .47918 Mdot
.40613 .35153 Mdot
.19879 .5329 Mdot
.63647 .39193 Mdot
.37119 .31659 Mdot
.69888 .79242 Mdot
.6133 .41045 Mdot
.58774 .39054 Mdot
.58566 .42016 Mdot
.55636 .42489 Mdot
.3979 .34231 Mdot
.72007 .59002 Mdot
.35641 .56914 Mdot
.49923 .53543 Mdot
.34156 .5211 Mdot
.48388 .64061 Mdot
.52567 .52697 Mdot
.41327 .38287 Mdot
.65783 .671 Mdot
.54224 .19605 Mdot
.21399 .56893 Mdot
.49227 .65131 Mdot
.56328 .26267 Mdot
.64751 .66202 Mdot
.6301 .41939 Mdot
.6738 .63459 Mdot
.52344 .68534 Mdot
.35027 .53028 Mdot
.63831 .40818 Mdot
.37947 .41205 Mdot
.40761 .37091 Mdot
.57478 .40109 Mdot
.82744 .53107 Mdot
.33492 .56319 Mdot
.35802 .4911 Mdot
.56138 .38995 Mdot
.60595 .45426 Mdot
.36823 .3819 Mdot
.53318 .638 Mdot
.48852 .80233 Mdot
.64051 .64785 Mdot
.53112 .44662 Mdot
.5549 .42855 Mdot
.22372 .5611 Mdot
.3366 .57054 Mdot
.4264 .71125 Mdot
.56151 .39431 Mdot
.23262 .55122 Mdot
.56029 .39633 Mdot
.60466 .47653 Mdot
.52311 .63524 Mdot
.58055 .35464 Mdot
.58261 .37724 Mdot
.65206 .37163 Mdot
.33318 .52729 Mdot
.38131 .35374 Mdot
.42181 .35425 Mdot
.43587 .69597 Mdot
.33736 .5614 Mdot
.55077 .41323 Mdot
.33936 .56871 Mdot
.60472 .37006 Mdot
.57368 .38899 Mdot
.32933 .51052 Mdot
.37294 .38535 Mdot
.34353 .46693 Mdot
.5596 .53069 Mdot
.55723 .42061 Mdot
.6265 .44313 Mdot
.67953 .56145 Mdot
.38115 .81895 Mdot
.59981 .39279 Mdot
.40313 .36853 Mdot
.57277 .41534 Mdot
.3292 .54142 Mdot
.67868 .65678 Mdot
.3964 .365 Mdot
.53899 .64877 Mdot
.50095 .6313 Mdot
.29221 .35436 Mdot
.40982 .71604 Mdot
.61651 .45667 Mdot
.45436 .40349 Mdot
.36363 .40894 Mdot
.76059 .71463 Mdot
.51571 .61917 Mdot
.6178 .64025 Mdot
.56071 .43636 Mdot
.35299 .60829 Mdot
.37191 .52748 Mdot
.62244 .12958 Mdot
.22879 .6306 Mdot
.60853 .63802 Mdot
.31644 .7619 Mdot
.42472 .69953 Mdot
.59501 .37858 Mdot
.62532 .65495 Mdot
.48727 .65748 Mdot
.62272 .39388 Mdot
.50985 .39799 Mdot
.65918 .5936 Mdot
.50335 .60903 Mdot
.33393 .56753 Mdot
.50783 .6814 Mdot
.69189 .65634 Mdot
.40589 .70817 Mdot
.41095 .37958 Mdot
.59779 .42098 Mdot
.64151 .37551 Mdot
.53807 .64204 Mdot
.40679 .69709 Mdot
.55385 .39238 Mdot
.40706 .36365 Mdot
.50248 .68781 Mdot
.56903 .44289 Mdot
.46554 .22748 Mdot
.33704 .3827 Mdot
.50564 .66198 Mdot
.62151 .41846 Mdot
.47348 .41562 Mdot
.53338 .65316 Mdot
.54019 .63524 Mdot
.57332 .39804 Mdot
.6633 .67269 Mdot
.55173 .38617 Mdot
.31827 .52988 Mdot
.68633 .6257 Mdot
.33167 .54073 Mdot
.67328 .6952 Mdot
.61481 .47691 Mdot
.34335 .71781 Mdot
.40751 .40403 Mdot
.69411 .66043 Mdot
.3263 .26887 Mdot
.61007 .45302 Mdot
.74284 .31343 Mdot
.41234 .47218 Mdot
.83035 .60007 Mdot
.52855 .15804 Mdot
.65547 .65636 Mdot
.3372 .55851 Mdot
.58729 .39124 Mdot
.34706 .50136 Mdot
.62722 .65103 Mdot
.77392 .57885 Mdot
.6215 .42315 Mdot
.38882 .39714 Mdot
.54883 .39299 Mdot
.36525 .38856 Mdot
.57612 .40695 Mdot
.52955 .47995 Mdot
.58925 .65519 Mdot
.60316 .55774 Mdot
.62831 .42375 Mdot
.38199 .19412 Mdot
.42465 .58413 Mdot
.64508 .65656 Mdot
.54101 .41221 Mdot
.41521 .70804 Mdot
.31081 .5654 Mdot
.70783 .40186 Mdot
.51884 .63967 Mdot
.32266 .50984 Mdot
.36545 .37113 Mdot
.52593 .6166 Mdot
.42165 .68516 Mdot
.62078 .34862 Mdot
.63495 .63276 Mdot
.3601 .54333 Mdot
.59882 .4147 Mdot
.61009 .39143 Mdot
.46555 .77164 Mdot
.40047 .64157 Mdot
.42616 .40369 Mdot
.22291 .34467 Mdot
.37944 .33518 Mdot
.64073 .64283 Mdot
.52136 .6348 Mdot
.60243 .39477 Mdot
.58406 .4509 Mdot
.50068 .69571 Mdot
.38755 .3492 Mdot
.49153 .62137 Mdot
.53017 .26002 Mdot
.54615 .62736 Mdot
.73269 .56491 Mdot
.39562 .35813 Mdot
.72954 .56789 Mdot
.69239 .65573 Mdot
.70138 .28695 Mdot
.70767 .49378 Mdot
.31336 .52908 Mdot
.73673 .56301 Mdot
.39858 .37988 Mdot
.56344 .40304 Mdot
.42566 .70254 Mdot
.41529 .71747 Mdot
.36167 .374 Mdot
.48906 .64138 Mdot
.67144 .65696 Mdot
.58569 .38817 Mdot
.286 .69891 Mdot
.27566 .42056 Mdot
.54412 .65033 Mdot
.50958 .45689 Mdot
.33714 .53138 Mdot
.58608 .37951 Mdot
.65043 .63418 Mdot
.35697 .54452 Mdot
.39465 .70617 Mdot
.2355 .45937 Mdot
.56332 .44579 Mdot
.21128 .5361 Mdot
.34661 .56043 Mdot
.40527 .79204 Mdot
.57505 .4381 Mdot
.33572 .52416 Mdot
.56246 .49451 Mdot
.25507 .61894 Mdot
.43615 .51317 Mdot
.7875 .36058 Mdot
.51736 .60132 Mdot
.49379 .63758 Mdot
.30832 .6479 Mdot
.57779 .6802 Mdot
.32356 .50698 Mdot
.40565 .70686 Mdot
.75253 .46767 Mdot
.33332 .53101 Mdot
.57382 .37337 Mdot
.61278 .40377 Mdot
.50038 .2557 Mdot
.4528 .51302 Mdot
.40442 .70273 Mdot
.25514 .3633 Mdot
.57087 .46566 Mdot
.51706 .41015 Mdot
.58666 .44635 Mdot
.41249 .40639 Mdot
.35382 .56072 Mdot
.28964 .25652 Mdot
.3289 .55969 Mdot
.29211 .71471 Mdot
.51525 .65819 Mdot
.54747 .63693 Mdot
.60432 .40927 Mdot
.36405 .73649 Mdot
.71066 .36567 Mdot
.5507 .45688 Mdot
.45225 .7266 Mdot
.79006 .52423 Mdot
.51864 .44962 Mdot
.41621 .35707 Mdot
.64561 .4134 Mdot
.35479 .41694 Mdot
.35401 .52474 Mdot
.66242 .65579 Mdot
.65441 .68238 Mdot
.35919 .5404 Mdot
.60066 .42968 Mdot
.47277 .7202 Mdot
.60663 .44054 Mdot
.56413 .39445 Mdot
.26121 .69386 Mdot
.61331 .65318 Mdot
.51453 .63286 Mdot
.6315 .65436 Mdot
.35962 .36026 Mdot
.89729 .40547 Mdot
.66197 .643 Mdot
.50686 .35468 Mdot
.73737 .62591 Mdot
.7353 .56638 Mdot
.40863 .37032 Mdot
.68361 .66703 Mdot
.32763 .56233 Mdot
.84795 .57657 Mdot
.40838 .82238 Mdot
.35307 .49661 Mdot
.57554 .444 Mdot
.41319 .39131 Mdot
.39316 .41362 Mdot
.31406 .50377 Mdot
.4028 .39573 Mdot
.64639 .45522 Mdot
.55861 .40885 Mdot
.32474 .50666 Mdot
.27762 .44645 Mdot
.3626 .53459 Mdot
.22296 .44679 Mdot
.54362 .40426 Mdot
.39513 .36026 Mdot
.64921 .41792 Mdot
.41096 .33859 Mdot
.42754 .71365 Mdot
.62234 .3908 Mdot
.66899 .66438 Mdot
.46142 .50366 Mdot
.50714 .66033 Mdot
.34375 .61755 Mdot
.38401 .40389 Mdot
.3623 .47965 Mdot
.39881 .40175 Mdot
.4169 .38634 Mdot
.32347 .56852 Mdot
.34988 .36467 Mdot
.58778 .38953 Mdot
.43807 .75494 Mdot
.36288 .39307 Mdot
.34152 .5489 Mdot
.66212 .66382 Mdot
.37143 .37811 Mdot
.47552 .65247 Mdot
.56449 .42727 Mdot
.50074 .67527 Mdot
.59118 .6555 Mdot
.41121 .36572 Mdot
.68182 .66761 Mdot
.53102 .62387 Mdot
.62622 .63847 Mdot
.79265 .57163 Mdot
.35103 .51042 Mdot
.33251 .76738 Mdot
.50476 .47274 Mdot
.37726 .41194 Mdot
.5866 .64844 Mdot
.60098 .3961 Mdot
.56289 .42839 Mdot
.68884 .66586 Mdot
.39138 .41444 Mdot
.82742 .45733 Mdot
.45537 .42553 Mdot
.23642 .44162 Mdot
.36394 .52336 Mdot
.23389 .35098 Mdot
.2342 .5026 Mdot
.74261 .69452 Mdot
.57512 .35042 Mdot
.42448 .70013 Mdot
.60925 .42581 Mdot
.33821 .25515 Mdot
.67705 .64857 Mdot
.49746 .82309 Mdot
.61194 .36085 Mdot
.50981 .64016 Mdot
.57819 .42731 Mdot
.68472 .44701 Mdot
.64368 .42773 Mdot
.65318 .675 Mdot
.27303 .54593 Mdot
.3448 .35748 Mdot
.64852 .66422 Mdot
.50118 .63269 Mdot
.76252 .49872 Mdot
.62409 .39793 Mdot
.57507 .46843 Mdot
.55026 .63289 Mdot
.39323 .39815 Mdot
.4801 .64851 Mdot
.33625 .52292 Mdot
.6623 .64887 Mdot
.55825 .43379 Mdot
.54067 .37694 Mdot
.45615 .71488 Mdot
.35511 .56056 Mdot
.54081 .62551 Mdot
.31917 .54882 Mdot
.42528 .70057 Mdot
.63364 .42126 Mdot
.55076 .64393 Mdot
.60866 .38487 Mdot
.29832 .27678 Mdot
.27049 .7045 Mdot
.49943 .32692 Mdot
.51125 .63252 Mdot
.73115 .54289 Mdot
.331 .5475 Mdot
.31857 .53837 Mdot
.40013 .31478 Mdot
.72114 .39448 Mdot
.62038 .74264 Mdot
.48993 .18537 Mdot
.33635 .52233 Mdot
.33544 .5406 Mdot
.48642 .66589 Mdot
.35111 .37069 Mdot
.37006 .42122 Mdot
.51454 .61526 Mdot
.61537 .56073 Mdot
.39243 .38431 Mdot
.75117 .326 Mdot
.47751 .6766 Mdot
.56904 .35091 Mdot
.44455 .70027 Mdot
.66712 .65441 Mdot
.6111 .5592 Mdot
.68345 .44452 Mdot
.6037 .39068 Mdot
.19175 .51623 Mdot
.53007 .64014 Mdot
.70001 .59692 Mdot
.69035 .24729 Mdot
.62026 .42988 Mdot
.58509 .43316 Mdot
.59876 .43494 Mdot
.61408 .65702 Mdot
.3461 .26387 Mdot
.60338 .38829 Mdot
.61338 .56656 Mdot
.55272 .46686 Mdot
.68599 .48784 Mdot
.63097 .6516 Mdot
.33225 .32176 Mdot
.52723 .60281 Mdot
.24889 .63478 Mdot
.59819 .51081 Mdot
.3269 .52989 Mdot
.57563 .63723 Mdot
.34891 .52385 Mdot
.71742 .34409 Mdot
.70914 .49623 Mdot
.42783 .38564 Mdot
.59645 .38932 Mdot
.55917 .6499 Mdot
.40586 .4031 Mdot
.39472 .73536 Mdot
.90683 .52757 Mdot
.35727 .56166 Mdot
.39515 .8471 Mdot
.31777 .5412 Mdot
.42262 .71671 Mdot
.36641 .3797 Mdot
.61006 .27406 Mdot
.48108 .51375 Mdot
.3723 .37644 Mdot
.29313 .48973 Mdot
.37215 .33212 Mdot
.73632 .54948 Mdot
.33991 .35945 Mdot
.33763 .54982 Mdot
.3572 .58778 Mdot
.52664 .37923 Mdot
.59779 .4011 Mdot
.54249 .56248 Mdot
.47324 .38872 Mdot
.59773 .3979 Mdot
.49882 .64879 Mdot
.38457 .79305 Mdot
.56382 .62362 Mdot
.35933 .39563 Mdot
.35464 .56787 Mdot
.58336 .43221 Mdot
.55599 .41115 Mdot
.60744 .37906 Mdot
.24714 .29799 Mdot
.75482 .33637 Mdot
.57107 .38955 Mdot
.52837 .43525 Mdot
.50902 .6291 Mdot
.69867 .64646 Mdot
.42255 .18958 Mdot
.74164 .47284 Mdot
.58778 .45672 Mdot
.63446 .65417 Mdot
.61228 .64338 Mdot
.62754 .40475 Mdot
.29248 .6936 Mdot
.43228 .75878 Mdot
.59845 .41485 Mdot
.70697 .47248 Mdot
.53263 .6925 Mdot
.40697 .7147 Mdot
.53735 .64391 Mdot
.37037 .33856 Mdot
.40877 .70137 Mdot
.53134 .67874 Mdot
.60283 .26532 Mdot
.43648 .6938 Mdot
.25138 .56054 Mdot
.68111 .65657 Mdot
.58947 .44866 Mdot
.39243 .33705 Mdot
.50596 .69584 Mdot
.35944 .53739 Mdot
.38605 .36635 Mdot
.30865 .56353 Mdot
.62284 .62781 Mdot
.66644 .58281 Mdot
.41483 .71908 Mdot
.32942 .52397 Mdot
.23458 .4601 Mdot
.63337 .65342 Mdot
.31421 .55279 Mdot
.36568 .73076 Mdot
.62094 .37329 Mdot
.66645 .27781 Mdot
.53806 .44041 Mdot
.83601 .55193 Mdot
.31795 .55727 Mdot
.43524 .68786 Mdot
.60183 .42472 Mdot
.52412 .65944 Mdot
.59207 .49072 Mdot
.59117 .45388 Mdot
.53707 .65608 Mdot
.56605 .39486 Mdot
.64205 .63449 Mdot
.33978 .39591 Mdot
.38257 .46676 Mdot
.14834 .51808 Mdot
.63467 .63394 Mdot
.39076 .73539 Mdot
.59894 .39204 Mdot
.79479 .54407 Mdot
.37318 .37933 Mdot
.6173 .44033 Mdot
.35386 .30497 Mdot
.35536 .37819 Mdot
.37855 .36257 Mdot
.54658 .43093 Mdot
.31321 .53766 Mdot
.51643 .66294 Mdot
.63422 .65681 Mdot
.76587 .68693 Mdot
.57376 .45083 Mdot
.57134 .41849 Mdot
.64829 .66293 Mdot
.33338 .5404 Mdot
.55502 .41433 Mdot
.37913 .61946 Mdot
.80679 .65256 Mdot
.33459 .57545 Mdot
.61088 .36597 Mdot
.60617 .22355 Mdot
.42726 .35021 Mdot
.38934 .83386 Mdot
.68163 .68974 Mdot
.52351 .6254 Mdot
.53152 .48132 Mdot
.70724 .19779 Mdot
.66382 .65691 Mdot
.23911 .63162 Mdot
.56953 .38501 Mdot
.58021 .41589 Mdot
.40554 .38273 Mdot
.54719 .41199 Mdot
.37204 .35054 Mdot
.15615 .5731 Mdot
.17797 .41589 Mdot
.38315 .4005 Mdot
.36162 .40183 Mdot
.42495 .33673 Mdot
.4037 .2013 Mdot
.36196 .36749 Mdot
.6035 .36296 Mdot
.7955 .41568 Mdot
.60875 .34357 Mdot
.68803 .66863 Mdot
.59576 .6605 Mdot
.3221 .3359 Mdot
.43733 .66874 Mdot
.4277 .43215 Mdot
.62625 .49345 Mdot
.41055 .57295 Mdot
.32149 .52244 Mdot
.59994 .45383 Mdot
.41123 .71747 Mdot
.51331 .68419 Mdot
.6387 .43758 Mdot
.59519 .44808 Mdot
.36463 .39076 Mdot
.62816 .66908 Mdot
.31258 .56164 Mdot
.56909 .41093 Mdot
.48376 .62731 Mdot
.646 .64575 Mdot
.36319 .3975 Mdot
.4316 .33777 Mdot
.62195 .65807 Mdot
.55605 .48485 Mdot
.58785 .40471 Mdot
.55505 .39199 Mdot
.5446 .49716 Mdot
.34885 .51527 Mdot
.50327 .70082 Mdot
.57928 .36617 Mdot
.22218 .5981 Mdot
.57909 .5659 Mdot
.5632 .36309 Mdot
.39846 .38626 Mdot
.37318 .5329 Mdot
.43121 .70811 Mdot
.77202 .52507 Mdot
.56671 .44967 Mdot
.75439 .33919 Mdot
.52453 .24881 Mdot
.41008 .70084 Mdot
.42402 .38725 Mdot
.65594 .67042 Mdot
.5605 .45996 Mdot
.76756 .38875 Mdot
.6117 .40507 Mdot
.48661 .4441 Mdot
.52961 .63262 Mdot
.32387 .51879 Mdot
.82584 .6188 Mdot
.51752 .6826 Mdot
.37893 .36065 Mdot
.79262 .35846 Mdot
.38502 .42045 Mdot
.34706 .35727 Mdot
.72523 .33413 Mdot
.34544 .51541 Mdot
.68789 .18133 Mdot
.39933 .82516 Mdot
.55697 .37521 Mdot
.32639 .54505 Mdot
.3682 .38745 Mdot
.5857 .38003 Mdot
.36147 .4051 Mdot
.3566 .3519 Mdot
.62003 .38447 Mdot
.58445 .40906 Mdot
.55534 .53266 Mdot
.72223 .28382 Mdot
.64598 .66882 Mdot
.39796 .3551 Mdot
.44795 .25095 Mdot
.60105 .38458 Mdot
.60727 .4161 Mdot
.43542 .72397 Mdot
.6513 .67439 Mdot
.66672 .46478 Mdot
.56239 .39431 Mdot
.18508 .44676 Mdot
.6293 .43826 Mdot
.4113 .34941 Mdot
.33375 .57528 Mdot
.28074 .68094 Mdot
.50524 .69797 Mdot
.39722 .35147 Mdot
.66605 .63684 Mdot
.4298 .3669 Mdot
.49574 .35853 Mdot
.34935 .51967 Mdot
.40033 .36821 Mdot
.49034 .6303 Mdot
.35224 .54005 Mdot
.3151 .5535 Mdot
.79138 .42716 Mdot
.53393 .61934 Mdot
.68218 .65147 Mdot
.34731 .52803 Mdot
.46158 .22328 Mdot
.33991 .55396 Mdot
.46781 .25481 Mdot
.53335 .4357 Mdot
.63221 .57274 Mdot
.24413 .50967 Mdot
.52888 .48368 Mdot
.35214 .51461 Mdot
.62875 .65392 Mdot
.55073 .43041 Mdot
.40372 .39378 Mdot
.6637 .6444 Mdot
.28826 .56828 Mdot
.54287 .63536 Mdot
.39221 .407 Mdot
.35487 .57102 Mdot
.39531 .3553 Mdot
.75167 .58846 Mdot
.66258 .61122 Mdot
.38922 .58911 Mdot
.50142 .52564 Mdot
.60234 .37596 Mdot
.31767 .40311 Mdot
.62016 .45349 Mdot
.59793 .44814 Mdot
.50643 .66215 Mdot
.66906 .56615 Mdot
.37248 .38555 Mdot
.82742 .6218 Mdot
.32754 .52207 Mdot
.1825 .4859 Mdot
.46823 .41236 Mdot
.59738 .45848 Mdot
.36106 .38992 Mdot
.36636 .41587 Mdot
.48252 .33541 Mdot
.48981 .68892 Mdot
.50404 .41988 Mdot
.58518 .48453 Mdot
.5338 .37491 Mdot
.31848 .55725 Mdot
.338 .62538 Mdot
.48533 .64427 Mdot
.53481 .86013 Mdot
.53584 .63464 Mdot
.55832 .72332 Mdot
.34886 .36627 Mdot
.677 .65557 Mdot
.60592 .41518 Mdot
.48646 .45751 Mdot
.42092 .36782 Mdot
.7047 .6762 Mdot
.66804 .66729 Mdot
.29016 .62738 Mdot
.33268 .50947 Mdot
.62759 .41413 Mdot
.62084 .41027 Mdot
.54224 .41622 Mdot
.53393 .42593 Mdot
.35278 .56693 Mdot
.57723 .37286 Mdot
.32483 .50312 Mdot
.48053 .2235 Mdot
.18033 .45379 Mdot
.55486 .66452 Mdot
.71262 .39631 Mdot
.38002 .4103 Mdot
.43173 .23079 Mdot
.49577 .41684 Mdot
.28152 .71815 Mdot
.80388 .52269 Mdot
.5927 .46934 Mdot
.48435 .65678 Mdot
.69462 .36186 Mdot
.55471 .66125 Mdot
.19852 .72102 Mdot
.50845 .71089 Mdot
.77112 .3369 Mdot
.59079 .38298 Mdot
.43879 .72103 Mdot
.49192 .40822 Mdot
.62588 .39298 Mdot
.54807 .69383 Mdot
.2362 .38096 Mdot
.27493 .47587 Mdot
.6143 .64775 Mdot
.56563 .43302 Mdot
.33977 .36681 Mdot
.58858 .38805 Mdot
.61028 .4176 Mdot
.5771 .37787 Mdot
.3394 .57779 Mdot
.63992 .40692 Mdot
.56534 .37729 Mdot
.41728 .63744 Mdot
.70614 .54636 Mdot
.51001 .68025 Mdot
.48099 .35521 Mdot
.65569 .64308 Mdot
.3709 .39831 Mdot
.47469 .48067 Mdot
.31393 .52644 Mdot
.44994 .32886 Mdot
.55556 .38565 Mdot
.24338 .49504 Mdot
.35573 .57041 Mdot
.66589 .64912 Mdot
.4342 .69879 Mdot
.80484 .40801 Mdot
.54653 .6717 Mdot
.43686 .69528 Mdot
.50801 .65914 Mdot
.35582 .26908 Mdot
.36321 .3886 Mdot
.6045 .37558 Mdot
.34144 .52927 Mdot
.51685 .66512 Mdot
.67455 .55156 Mdot
.58983 .44397 Mdot
.50615 .63418 Mdot
.59904 .3732 Mdot
.64898 .58292 Mdot
.47092 .77646 Mdot
.54955 .66497 Mdot
.35544 .58246 Mdot
.34867 .54121 Mdot
.6717 .66939 Mdot
.37478 .40249 Mdot
.40224 .37787 Mdot
.3561 .54508 Mdot
.34536 .80545 Mdot
.59277 .45414 Mdot
.59026 .3809 Mdot
.22313 .5954 Mdot
.58897 .39579 Mdot
.75921 .51741 Mdot
.43247 .71423 Mdot
.37376 .40489 Mdot
.58105 .37998 Mdot
.55588 .41872 Mdot
.56162 .44138 Mdot
.7478 .59249 Mdot
.53821 .63943 Mdot
.56858 .46461 Mdot
.63644 .66812 Mdot
.36871 .6933 Mdot
.59438 .3807 Mdot
.52164 .39602 Mdot
.39973 .37478 Mdot
.1731 .43586 Mdot
.31597 .52998 Mdot
.49541 .65056 Mdot
.53537 .62632 Mdot
.60046 .6725 Mdot
.3319 .35984 Mdot
.43741 .70485 Mdot
.67565 .77099 Mdot
.42686 .68928 Mdot
.64242 .6583 Mdot
.64054 .70527 Mdot
.46674 .65873 Mdot
.49072 .66161 Mdot
.30027 .54005 Mdot
.54643 .39418 Mdot
.56147 .46431 Mdot
.24106 .64036 Mdot
.57848 .46569 Mdot
.66468 .66575 Mdot
.31674 .50934 Mdot
.39602 .37829 Mdot
.66921 .65224 Mdot
.32007 .54557 Mdot
.39533 .39728 Mdot
.6238 .3771 Mdot
.62443 .37419 Mdot
.38206 .36624 Mdot
.40659 .4008 Mdot
.5967 .41028 Mdot
.3839 .6406 Mdot
.35486 .34239 Mdot
.39887 .36372 Mdot
.41042 .7201 Mdot
.55287 .66595 Mdot
.64208 .36787 Mdot
.32567 .54793 Mdot
.55789 .39046 Mdot
.55538 .66187 Mdot
.66117 .67607 Mdot
.37709 .38507 Mdot
.55722 .41639 Mdot
.56481 .40956 Mdot
.6365 .65835 Mdot
.62308 .66285 Mdot
.67183 .65363 Mdot
.33777 .49766 Mdot
.53847 .43159 Mdot
.3642 .36618 Mdot
.33597 .51119 Mdot
.61242 .64326 Mdot
.66857 .63116 Mdot
.44646 .63277 Mdot
.60521 .39495 Mdot
.4334 .51813 Mdot
.88101 .38436 Mdot
.75438 .48876 Mdot
.43053 .71 Mdot
.54713 .62675 Mdot
.70614 .573 Mdot
.45975 .76149 Mdot
.34399 .56376 Mdot
.74883 .43299 Mdot
.69382 .66106 Mdot
.60711 .37437 Mdot
.62789 .44004 Mdot
.55859 .47411 Mdot
.65253 .648 Mdot
.76076 .56949 Mdot
.39289 .41561 Mdot
.41253 .28225 Mdot
.65601 .64335 Mdot
.54784 .66677 Mdot
.55243 .6467 Mdot
.53549 .63415 Mdot
.6361 .40278 Mdot
.47243 .33145 Mdot
.44245 .23673 Mdot
.40052 .21367 Mdot
.32661 .50866 Mdot
.41715 .41275 Mdot
.79199 .56512 Mdot
.37794 .36477 Mdot
.51642 .68438 Mdot
.6476 .64876 Mdot
.40496 .37277 Mdot
.36164 .54826 Mdot
.33645 .53861 Mdot
.54212 .642 Mdot
.5268 .65496 Mdot
.50674 .67436 Mdot
.36199 .34258 Mdot
.34959 .36524 Mdot
.56621 .45301 Mdot
.38089 .37899 Mdot
.19057 .54649 Mdot
.60582 .64148 Mdot
.55213 .65473 Mdot
.33382 .55847 Mdot
.36798 .39182 Mdot
.58466 .44864 Mdot
.62884 .72284 Mdot
.29213 .37799 Mdot
.62805 .63868 Mdot
.45149 .77694 Mdot
.23847 .75834 Mdot
.62182 .4006 Mdot
.33353 .56832 Mdot
.30864 .71366 Mdot
.59478 .4375 Mdot
.52224 .64168 Mdot
.31696 .2608 Mdot
.41593 .68877 Mdot
.57042 .37586 Mdot
.58513 .46378 Mdot
.31344 .55401 Mdot
.74053 .62965 Mdot
.56469 .45515 Mdot
.21703 .49444 Mdot
.32312 .57778 Mdot
.4834 .67228 Mdot
.80819 .65784 Mdot
.495 .70415 Mdot
.61656 .55373 Mdot
.4181 .71559 Mdot
.61718 .42321 Mdot
.49792 .65472 Mdot
.62514 .64294 Mdot
.50216 .66763 Mdot
.42619 .38562 Mdot
.50766 .67827 Mdot
.57253 .41898 Mdot
.36246 .36434 Mdot
.34492 .56126 Mdot
.19899 .53627 Mdot
.40768 .64633 Mdot
.52518 .65881 Mdot
.41256 .72201 Mdot
.5883 .3759 Mdot
.62107 .50906 Mdot
.61014 .48458 Mdot
.59591 .38347 Mdot
.34783 .52162 Mdot
.36031 .39099 Mdot
.36804 .53386 Mdot
.52277 .40367 Mdot
.21839 .39008 Mdot
.31649 .54489 Mdot
.25882 .52552 Mdot
.64617 .66143 Mdot
.58386 .54682 Mdot
.58322 .45238 Mdot
.34365 .52658 Mdot
.53794 .42913 Mdot
.3494 .3916 Mdot
.47103 .54663 Mdot
.36732 .70982 Mdot
.34141 .53044 Mdot
.83342 .48183 Mdot
.45105 .5558 Mdot
.64693 .40073 Mdot
.33999 .52291 Mdot
.36425 .28955 Mdot
.42049 .713 Mdot
.63937 .64974 Mdot
.61262 .64435 Mdot
.62392 .63941 Mdot
.59976 .4626 Mdot
.51349 .38627 Mdot
.67593 .64031 Mdot
.32098 .57253 Mdot
.65224 .67531 Mdot
.50845 .49263 Mdot
.83299 .47169 Mdot
.66712 .64045 Mdot
.57244 .44043 Mdot
.51598 .40944 Mdot
.7023 .54705 Mdot
.50807 .68865 Mdot
.73994 .30959 Mdot
.63873 .33107 Mdot
.60077 .40136 Mdot
.60484 .33902 Mdot
.40454 .40717 Mdot
.34626 .73905 Mdot
.47456 .39514 Mdot
.45292 .7664 Mdot
.34815 .38281 Mdot
.47161 .69332 Mdot
.37338 .40325 Mdot
.61874 .39377 Mdot
.57518 .38796 Mdot
.35653 .41595 Mdot
.28766 .6034 Mdot
.30424 .67299 Mdot
.80681 .61758 Mdot
.40221 .36472 Mdot
.33349 .52726 Mdot
.35735 .56225 Mdot
.32445 .51085 Mdot
.48115 .68002 Mdot
.40971 .36147 Mdot
.54544 .44366 Mdot
.51095 .62631 Mdot
.59929 .45218 Mdot
.351 .53316 Mdot
.8299 .61236 Mdot
.39869 .37607 Mdot
.59711 .41739 Mdot
.40555 .81998 Mdot
.52312 .65139 Mdot
.63404 .6486 Mdot
.66762 .58849 Mdot
.47395 .67167 Mdot
.35971 .52433 Mdot
.36905 .41972 Mdot
.28697 .51567 Mdot
.44465 .46544 Mdot
.61691 .34931 Mdot
.58895 .35573 Mdot
.74659 .70702 Mdot
.38392 .70228 Mdot
.62594 .43893 Mdot
.49979 .63398 Mdot
.5164 .69068 Mdot
.55955 .42009 Mdot
.4111 .37476 Mdot
.63749 .62895 Mdot
.63583 .66848 Mdot
.54317 .47657 Mdot
.48563 .51829 Mdot
.58204 .54965 Mdot
.55179 .4094 Mdot
.51644 .46435 Mdot
.53879 .62656 Mdot
.43212 .68891 Mdot
.22845 .5736 Mdot
.67012 .63969 Mdot
.56718 .38601 Mdot
.30952 .46721 Mdot
.35433 .35609 Mdot
.5055 .67671 Mdot
.35636 .52288 Mdot
.76223 .59141 Mdot
.47819 .64831 Mdot
.55916 .41769 Mdot
.55519 .41511 Mdot
.3136 .55201 Mdot
.41178 .34984 Mdot
.65025 .64949 Mdot
.51627 .62584 Mdot
.67137 .63975 Mdot
.35749 .35991 Mdot
.39519 .3752 Mdot
.60883 .34336 Mdot
.52088 .46825 Mdot
.53826 .64709 Mdot
.5232 .43383 Mdot
.53488 .67536 Mdot
.74013 .64183 Mdot
.3717 .54668 Mdot
.62294 .40515 Mdot
.40061 .42189 Mdot
.35248 .53138 Mdot
.58523 .41515 Mdot
.73242 .74286 Mdot
.60894 .44963 Mdot
.49284 .69845 Mdot
.20336 .41251 Mdot
.63629 .66572 Mdot
.53604 .33348 Mdot
.67455 .3914 Mdot
.5862 .39646 Mdot
.54726 .65931 Mdot
.59631 .48935 Mdot
.31529 .55009 Mdot
.35062 .38141 Mdot
.34839 .82694 Mdot
.34284 .55161 Mdot
.58529 .3856 Mdot
.66348 .64877 Mdot
.37251 .41894 Mdot
.41335 .69337 Mdot
.22774 .61219 Mdot
.62823 .45801 Mdot
.61691 .3655 Mdot
.56479 .38154 Mdot
.42428 .18362 Mdot
.49542 .65566 Mdot
.3679 .38941 Mdot
.32049 .55909 Mdot
.35574 .5508 Mdot
.53319 .63563 Mdot
.26192 .47181 Mdot
.53509 .5699 Mdot
.77455 .24932 Mdot
.53185 .66123 Mdot
.6759 .67454 Mdot
.51255 .52354 Mdot
.53045 .67528 Mdot
.50465 .6413 Mdot
.53305 .62349 Mdot
.24296 .54445 Mdot
.39559 .39311 Mdot
.5645 .40694 Mdot
.3469 .34409 Mdot
.61747 .42494 Mdot
.62169 .53023 Mdot
.35678 .53527 Mdot
.34891 .37805 Mdot
.74484 .72005 Mdot
.45891 .40317 Mdot
.58778 .43752 Mdot
.78503 .59852 Mdot
.63218 .46983 Mdot
.74903 .55581 Mdot
.65293 .42781 Mdot
.51615 .65951 Mdot
.5004 .37771 Mdot
.52464 .38907 Mdot
.19324 .53708 Mdot
.33175 .5578 Mdot
.42332 .71729 Mdot
.60738 .46513 Mdot
.60326 .47708 Mdot
.34898 .39576 Mdot
.40483 .37114 Mdot
.67789 .64337 Mdot
.58369 .57768 Mdot
.34057 .56207 Mdot
.65239 .60415 Mdot
.59538 .40275 Mdot
.29993 .60347 Mdot
.45575 .35283 Mdot
.58642 .41608 Mdot
.78662 .40191 Mdot
.4616 .33198 Mdot
.57036 .45923 Mdot
.37194 .27778 Mdot
.33398 .54329 Mdot
.20294 .42102 Mdot
.52847 .41091 Mdot
.52053 .64257 Mdot
.35015 .37306 Mdot
.40757 .40556 Mdot
.65733 .63331 Mdot
.23246 .67655 Mdot
.35482 .5152 Mdot
.34771 .37045 Mdot
.59782 .43983 Mdot
.35322 .51911 Mdot
.40971 .71452 Mdot
.53281 .38134 Mdot
.74426 .41501 Mdot
.38418 .37884 Mdot
.52763 .434 Mdot
.26279 .37343 Mdot
.59917 .56972 Mdot
.68083 .2232 Mdot
.32114 .51445 Mdot
.67402 .64836 Mdot
.65075 .39583 Mdot
.67464 .76965 Mdot
.55945 .47262 Mdot
.63854 .57021 Mdot
.34552 .32486 Mdot
.67838 .65698 Mdot
.59384 .4304 Mdot
.55783 .44371 Mdot
.47848 .50692 Mdot
.62269 .6639 Mdot
.6183 .43392 Mdot
.55217 .34175 Mdot
.39221 .39755 Mdot
.42837 .71684 Mdot
.38925 .38065 Mdot
.57567 .44345 Mdot
.51977 .37813 Mdot
.40682 .386 Mdot
.71673 .69731 Mdot
.67416 .68078 Mdot
.31627 .52704 Mdot
.50675 .44537 Mdot
.53226 .42084 Mdot
.44184 .16002 Mdot
.42731 .71383 Mdot
.35027 .24785 Mdot
.48129 .63578 Mdot
.3199 .47124 Mdot
.45651 .7027 Mdot
.79668 .37127 Mdot
.20494 .53957 Mdot
.60864 .47009 Mdot
.71438 .44965 Mdot
.38804 .25972 Mdot
.36343 .5268 Mdot
.52942 .21678 Mdot
.59809 .40077 Mdot
.61078 .42067 Mdot
.48541 .66902 Mdot
.24894 .47621 Mdot
.30063 .70065 Mdot
.49199 .52961 Mdot
.65014 .65326 Mdot
.36728 .35427 Mdot
.57435 .40614 Mdot
.53354 .57693 Mdot
.51783 .67669 Mdot
.34836 .60857 Mdot
.59715 .42234 Mdot
.30054 .72769 Mdot
.24875 .54508 Mdot
.3447 .51208 Mdot
.5494 .64153 Mdot
.47344 .66304 Mdot
.61673 .40599 Mdot
.36069 .53094 Mdot
.56827 .4558 Mdot
.44511 .57149 Mdot
.52669 .4477 Mdot
.66237 .63962 Mdot
.59244 .37334 Mdot
.44821 .49513 Mdot
.72823 .26143 Mdot
.5382 .34145 Mdot
.41479 .38259 Mdot
.47913 .6767 Mdot
.53669 .63934 Mdot
.40303 .37271 Mdot
.53509 .64092 Mdot
.42966 .2943 Mdot
.57809 .28935 Mdot
.65022 .65696 Mdot
.50349 .44479 Mdot
.65685 .63635 Mdot
.42578 .71636 Mdot
.60409 .39778 Mdot
.67025 .7787 Mdot
.53136 .65929 Mdot
.26683 .30368 Mdot
.3414 .55592 Mdot
.42539 .71584 Mdot
.5512 .46631 Mdot
.63348 .70324 Mdot
.50541 .686 Mdot
.4849 .69681 Mdot
.56237 .44423 Mdot
.40236 .38283 Mdot
.55635 .43834 Mdot
.6385 .46174 Mdot
.43593 .69886 Mdot
.54827 .39247 Mdot
.32016 .54566 Mdot
.3867 .34074 Mdot
.81603 .42563 Mdot
.50831 .69612 Mdot
.60953 .39332 Mdot
.59768 .4386 Mdot
.36174 .40996 Mdot
.53631 .45062 Mdot
.36258 .54878 Mdot
.52759 .08821 Mdot
.64499 .66108 Mdot
.41778 .68567 Mdot
.50322 .70227 Mdot
.58721 .46965 Mdot
.55219 .41657 Mdot
.7649 .69271 Mdot
.35443 .67451 Mdot
.32408 .5339 Mdot
.59165 .48771 Mdot
.51029 .62913 Mdot
.66484 .64998 Mdot
.31148 .563 Mdot
.55394 .39412 Mdot
.60539 .41992 Mdot
.66513 .64263 Mdot
.80046 .43659 Mdot
.45158 .76875 Mdot
.32301 .51008 Mdot
.49544 .38237 Mdot
.61735 .73367 Mdot
.59204 .45407 Mdot
.66134 .73409 Mdot
.39877 .36585 Mdot
.33783 .51858 Mdot
.40872 .20492 Mdot
.59852 .37173 Mdot
.3573 .55815 Mdot
.33768 .56149 Mdot
.55085 .37764 Mdot
.3382 .35182 Mdot
.37195 .34242 Mdot
.39006 .35298 Mdot
.16647 .47026 Mdot
.66002 .52346 Mdot
.50794 .67421 Mdot
.33376 .54185 Mdot
.55443 .65954 Mdot
.60746 .64932 Mdot
.57394 .56347 Mdot
.53094 .68053 Mdot
.40237 .40766 Mdot
.55298 .64573 Mdot
.55876 .4405 Mdot
.34583 .56176 Mdot
.49083 .66416 Mdot
.61002 .4606 Mdot
.67398 .44042 Mdot
.43355 .55168 Mdot
.65288 .62828 Mdot
.69787 .68243 Mdot
.57337 .39453 Mdot
.43131 .7074 Mdot
.59874 .4107 Mdot
.32108 .50789 Mdot
.4571 .48236 Mdot
.59401 .46739 Mdot
.53219 .65383 Mdot
.62672 .33442 Mdot
.4925 .68728 Mdot
.608 .48038 Mdot
.57425 .43989 Mdot
.6043 .44616 Mdot
.56583 .45634 Mdot
.27007 .49891 Mdot
.36341 .52194 Mdot
.68001 .42707 Mdot
.54428 .61036 Mdot
.37644 .37294 Mdot
.41786 .40593 Mdot
.60254 .75438 Mdot
.41859 .68428 Mdot
.32661 .54732 Mdot
.58584 .45495 Mdot
.49373 .70111 Mdot
.83443 .60415 Mdot
.71589 .70565 Mdot
.7022 .68952 Mdot
.49374 .64378 Mdot
.41494 .38809 Mdot
.50993 .68225 Mdot
.61678 .41352 Mdot
.57118 .36513 Mdot
.80545 .39185 Mdot
.34356 .59075 Mdot
.64895 .64824 Mdot
.60874 .4421 Mdot
.61512 .55139 Mdot
.50915 .62903 Mdot
.53631 .6234 Mdot
.608 .44901 Mdot
.39375 .34787 Mdot
.59114 .1602 Mdot
.34794 .51349 Mdot
.68515 .36142 Mdot
.35186 .43248 Mdot
.21587 .41674 Mdot
.35902 .5445 Mdot
.41992 .56525 Mdot
.50579 .62341 Mdot
.5796 .31564 Mdot
.37988 .37101 Mdot
.65012 .64546 Mdot
.56902 .36345 Mdot
.39888 .40807 Mdot
.51723 .61421 Mdot
.37079 .40552 Mdot
.61553 .38449 Mdot
.36457 .52655 Mdot
.528 .62608 Mdot
.37015 .56663 Mdot
.36152 .41993 Mdot
.63389 .63935 Mdot
.57186 .54018 Mdot
.57498 .22948 Mdot
.45759 .33102 Mdot
.56796 .46434 Mdot
.50071 .59437 Mdot
.53989 .43225 Mdot
.34018 .37407 Mdot
.58013 .45128 Mdot
.31206 .348 Mdot
.54733 .63951 Mdot
.52747 .43156 Mdot
.57333 .37454 Mdot
.53067 .23192 Mdot
.58634 .42869 Mdot
.54687 .38922 Mdot
.56922 .46027 Mdot
.3379 .41723 Mdot
.6415 .41936 Mdot
.39899 .38952 Mdot
.23672 .61901 Mdot
.5041 .64371 Mdot
.65395 .62767 Mdot
.62243 .65648 Mdot
.62799 .56903 Mdot
.60007 .55514 Mdot
.25801 .4788 Mdot
.38843 .38738 Mdot
.32255 .55404 Mdot
.56964 .45661 Mdot
.45491 .19464 Mdot
.57865 .67412 Mdot
.51576 .62118 Mdot
.50097 .69768 Mdot
.53911 .49163 Mdot
.42815 .18087 Mdot
.53548 .45623 Mdot
.22724 .63345 Mdot
.53546 .46865 Mdot
.61783 .43883 Mdot
.47492 .66569 Mdot
.5944 .56104 Mdot
.56951 .46513 Mdot
.35016 .39742 Mdot
.64543 .64331 Mdot
.44699 .41908 Mdot
.47384 .73841 Mdot
.40886 .59061 Mdot
.58038 .25776 Mdot
.5412 .44151 Mdot
.52258 .62664 Mdot
.39187 .40679 Mdot
.22466 .56673 Mdot
.33583 .51176 Mdot
.23938 .51536 Mdot
.47427 .23308 Mdot
.76566 .64679 Mdot
.6466 .64567 Mdot
.79552 .43243 Mdot
.57218 .41751 Mdot
.47967 .67989 Mdot
.61716 .3804 Mdot
.83655 .59924 Mdot
.68191 .66872 Mdot
.41554 .35928 Mdot
.33188 .52852 Mdot
.34683 .3862 Mdot
.50388 .32678 Mdot
.4026 .57424 Mdot
.48199 .57989 Mdot
.54015 .67619 Mdot
.66442 .471 Mdot
.36018 .37284 Mdot
.55726 .40065 Mdot
.81882 .29848 Mdot
.39781 .36399 Mdot
.3911 .35032 Mdot
.73023 .65116 Mdot
.73356 .66374 Mdot
.5592 .49059 Mdot
.37042 .40784 Mdot
.55592 .63286 Mdot
.63538 .66147 Mdot
.55287 .44195 Mdot
.56126 .45246 Mdot
.40501 .38209 Mdot
.51462 .68583 Mdot
.68865 .36109 Mdot
.52162 .65743 Mdot
.39161 .39966 Mdot
.5142 .65281 Mdot
.55711 .66751 Mdot
.49293 .65197 Mdot
.5313 .42887 Mdot
.57782 .453 Mdot
.50689 .74612 Mdot
.39502 .37524 Mdot
.54913 .41854 Mdot
.56918 .38912 Mdot
.36283 .36908 Mdot
.48631 .62505 Mdot
.48262 .19383 Mdot
.59657 .39072 Mdot
.56653 .42868 Mdot
.67759 .653 Mdot
.46379 .67549 Mdot
.46312 .78914 Mdot
.55052 .43071 Mdot
.6579 .67812 Mdot
.35748 .34415 Mdot
.59602 .41206 Mdot
.5104 .49668 Mdot
.54587 .67487 Mdot
.59135 .37169 Mdot
.41037 .69592 Mdot
.57312 .46911 Mdot
.61634 .18174 Mdot
.60603 .38808 Mdot
.36818 .38534 Mdot
.35416 .37764 Mdot
.72982 .63584 Mdot
.37978 .35874 Mdot
.41589 .71662 Mdot
.35134 .53651 Mdot
.83966 .5657 Mdot
.40912 .71221 Mdot
.61565 .44496 Mdot
.39932 .82537 Mdot
.52434 .41248 Mdot
.60397 .46636 Mdot
.3784 .2083 Mdot
.40893 .71016 Mdot
.3596 .38491 Mdot
.2718 .58229 Mdot
.53615 .47062 Mdot
.35623 .52177 Mdot
.56128 .36118 Mdot
.57098 .37066 Mdot
.20239 .47018 Mdot
.29629 .31398 Mdot
.31147 .5155 Mdot
.63664 .35658 Mdot
.55015 .43001 Mdot
.42725 .66211 Mdot
.58959 .44585 Mdot
.66366 .63691 Mdot
.38837 .35065 Mdot
.52834 .67189 Mdot
.64741 .66547 Mdot
.59135 .39951 Mdot
.65534 .64692 Mdot
.50444 .67508 Mdot
.34477 .51994 Mdot
.61119 .40022 Mdot
.6844 .67216 Mdot
.65087 .65209 Mdot
.54057 .42485 Mdot
.34895 .3751 Mdot
.49386 .37068 Mdot
.59338 .41312 Mdot
.55837 .40521 Mdot
.40216 .37801 Mdot
.56708 .85282 Mdot
.61986 .40299 Mdot
.4336 .52487 Mdot
.41587 .36186 Mdot
.4411 .70938 Mdot
.49496 .67495 Mdot
.57303 .36883 Mdot
.35446 .52421 Mdot
.35475 .53175 Mdot
.54677 .62242 Mdot
.35117 .3951 Mdot
.50504 .68809 Mdot
.60358 .33297 Mdot
.51803 .46134 Mdot
.53382 .38788 Mdot
.31693 .79693 Mdot
.79456 .38295 Mdot
.41231 .3789 Mdot
.48664 .64118 Mdot
.49912 .53424 Mdot
.33136 .53873 Mdot
.55311 .63615 Mdot
.36748 .41807 Mdot
.41305 .39498 Mdot
.38073 .40996 Mdot
.67506 .65858 Mdot
.48648 .63613 Mdot
.41351 .35295 Mdot
.38823 .3464 Mdot
.56073 .44208 Mdot
.54948 .42745 Mdot
.38204 .31813 Mdot
.72508 .5381 Mdot
.64061 .63613 Mdot
.52841 .63444 Mdot
.37697 .15949 Mdot
.3191 .50896 Mdot
.53572 .23408 Mdot
.59618 .46759 Mdot
.92063 .4904 Mdot
.53546 .45808 Mdot
.59606 .44255 Mdot
.36559 .33968 Mdot
.69024 .65868 Mdot
.6452 .63854 Mdot
.35898 .37244 Mdot
.37083 .42164 Mdot
.6673 .63911 Mdot
.80642 .50783 Mdot
.83639 .47784 Mdot
.23113 .54218 Mdot
.36728 .37817 Mdot
.60045 .24572 Mdot
.36027 .52661 Mdot
.35004 .41373 Mdot
.30957 .52707 Mdot
.50646 .64007 Mdot
.50893 .62011 Mdot
.31313 .55018 Mdot
.56429 .44671 Mdot
.49853 .67249 Mdot
.64387 .39825 Mdot
.81723 .49541 Mdot
.69394 .30743 Mdot
.33601 .66155 Mdot
.62523 .44572 Mdot
.28837 .68822 Mdot
.31995 .70789 Mdot
.5804 .39443 Mdot
.45071 .44525 Mdot
.65081 .64732 Mdot
.34049 .40838 Mdot
.36328 .54551 Mdot
.6686 .21515 Mdot
.58948 .45464 Mdot
.37317 .38802 Mdot
.32928 .55552 Mdot
.71862 .61673 Mdot
.21784 .48644 Mdot
.61589 .43183 Mdot
.72841 .21263 Mdot
.32997 .39115 Mdot
.52861 .67125 Mdot
.3277 .77796 Mdot
.35404 .33932 Mdot
.68749 .68726 Mdot
.50664 .61861 Mdot
.76503 .67199 Mdot
.3716 .39846 Mdot
.52672 .61217 Mdot
.36368 .35727 Mdot
.65694 .63469 Mdot
.33537 .36751 Mdot
.52423 .62384 Mdot
.59061 .42905 Mdot
.53144 .64193 Mdot
.63713 .63659 Mdot
.48313 .68399 Mdot
.36273 .53769 Mdot
.42427 .71425 Mdot
.34225 .54007 Mdot
.59576 .57165 Mdot
.24436 .35172 Mdot
.32361 .51854 Mdot
.69356 .60913 Mdot
.6252 .44125 Mdot
.41114 .34738 Mdot
.5354 .66051 Mdot
.54707 .61275 Mdot
.54571 .5475 Mdot
.37256 .37018 Mdot
.53043 .63125 Mdot
.46613 .22994 Mdot
.47925 .84962 Mdot
.51163 .38937 Mdot
.68207 .5039 Mdot
.36451 .37051 Mdot
.54133 .62502 Mdot
.22358 .59475 Mdot
.39808 .41148 Mdot
.53024 .66256 Mdot
.33973 .52501 Mdot
.35726 .54902 Mdot
.59685 .45501 Mdot
.36584 .58834 Mdot
.54522 .65615 Mdot
.26778 .63848 Mdot
.35679 .35424 Mdot
.71642 .61279 Mdot
.64353 .63187 Mdot
.50258 .64011 Mdot
.52925 .3824 Mdot
.44582 .38449 Mdot
.56143 .65706 Mdot
.72476 .40586 Mdot
.36086 .17569 Mdot
.53162 .63556 Mdot
.38418 .34983 Mdot
.37707 .38783 Mdot
.61963 .47842 Mdot
.48823 .51809 Mdot
.49571 .68489 Mdot
.64715 .7953 Mdot
.65114 .56941 Mdot
.42597 .70014 Mdot
.38247 .74132 Mdot
.57424 .46718 Mdot
.53655 .42417 Mdot
.33006 .53723 Mdot
.58103 .43372 Mdot
.38358 .34334 Mdot
.55875 .46577 Mdot
.35278 .56257 Mdot
.50915 .62284 Mdot
.6085 .40068 Mdot
.6312 .65891 Mdot
.30839 .51395 Mdot
.31187 .55045 Mdot
.50385 .65424 Mdot
.37369 .40906 Mdot
.58347 .61942 Mdot
.52808 .65388 Mdot
.54357 .44523 Mdot
.41309 .69835 Mdot
.60686 .37868 Mdot
.78023 .44073 Mdot
.38509 .41656 Mdot
.51969 .68022 Mdot
.42354 .38886 Mdot
.34107 .54495 Mdot
.53703 .60901 Mdot
.58217 .44387 Mdot
.52614 .66375 Mdot
.46495 .75126 Mdot
.80007 .46563 Mdot
.35085 .3956 Mdot
.45505 .72179 Mdot
.3845 .34811 Mdot
.42753 .69897 Mdot
.77044 .46951 Mdot
.6416 .65241 Mdot
.51103 .63089 Mdot
.78079 .36588 Mdot
.53481 .65339 Mdot
.58489 .42645 Mdot
.58127 .41091 Mdot
.48567 .66645 Mdot
.66014 .67337 Mdot
.17691 .43151 Mdot
.4245 .53578 Mdot
.36331 .39151 Mdot
.60504 .31513 Mdot
.4302 .13999 Mdot
.33039 .58138 Mdot
.3268 .53701 Mdot
.56202 .48009 Mdot
.59865 .45756 Mdot
.31236 .55793 Mdot
.35382 .56853 Mdot
.66652 .63338 Mdot
.52924 .62161 Mdot
.33647 .34428 Mdot
.31651 .5742 Mdot
.65896 .44486 Mdot
.60468 .55064 Mdot
.55608 .4867 Mdot
.57956 .34306 Mdot
.63651 .39172 Mdot
.63755 .57953 Mdot
.33672 .57042 Mdot
.57105 .39569 Mdot
.6367 .43928 Mdot
.33474 .52147 Mdot
.6574 .63527 Mdot
.28944 .32741 Mdot
.51682 .64746 Mdot
.71134 .78635 Mdot
.6039 .38073 Mdot
.58916 .42258 Mdot
.32751 .50853 Mdot
.42729 .6718 Mdot
.40455 .4002 Mdot
.37446 .41358 Mdot
.49504 .65849 Mdot
.55372 .55404 Mdot
.54136 .45441 Mdot
.57745 .39404 Mdot
.51761 .63336 Mdot
.42562 .71303 Mdot
.30917 .65074 Mdot
.56534 .4124 Mdot
.33167 .55517 Mdot
.57355 .63381 Mdot
.34099 .57102 Mdot
.62206 .3968 Mdot
.58309 .42464 Mdot
.53152 .43272 Mdot
.6001 .45713 Mdot
.30942 .54126 Mdot
.5711 .40061 Mdot
.51318 .41071 Mdot
.36007 .39792 Mdot
.53354 .42778 Mdot
.64737 .57516 Mdot
.56906 .43733 Mdot
.6294 .64759 Mdot
.52882 .58555 Mdot
.60553 .4458 Mdot
.53357 .41845 Mdot
.42659 .536 Mdot
.59724 .43042 Mdot
.31956 .50939 Mdot
.37712 .3775 Mdot
.33402 .54115 Mdot
.31971 .55941 Mdot
.55934 .64472 Mdot
.66951 .63634 Mdot
.5917 .47431 Mdot
.62218 .64264 Mdot
.58439 .34708 Mdot
.61476 .38219 Mdot
.58405 .63906 Mdot
.22801 .63552 Mdot
.46256 .76638 Mdot
.58045 .44522 Mdot
.49805 .65001 Mdot
.52527 .67481 Mdot
.71808 .43392 Mdot
.64588 .41176 Mdot
.31101 .55929 Mdot
.34341 .52684 Mdot
.75822 .50747 Mdot
.20318 .47854 Mdot
.63401 .63992 Mdot
.55216 .57128 Mdot
.63663 .40918 Mdot
.5633 .40098 Mdot
.52917 .38588 Mdot
.53823 .67578 Mdot
.43567 .69158 Mdot
.51605 .62072 Mdot
.44918 .6894 Mdot
.34779 .56826 Mdot
.55916 .46303 Mdot
.69606 .29418 Mdot
.40827 .37706 Mdot
.37777 .37731 Mdot
.31722 .56806 Mdot
.50161 .69008 Mdot
.64916 .45373 Mdot
.36316 .84162 Mdot
.36025 .42694 Mdot
.67257 .63286 Mdot
.58267 .39095 Mdot
.50109 .65409 Mdot
.40649 .36529 Mdot
.64274 .67382 Mdot
.57649 .37752 Mdot
.50219 .60549 Mdot
.57543 .44924 Mdot
.38428 .26117 Mdot
.3581 .39249 Mdot
.84554 .59048 Mdot
.38253 .42001 Mdot
.30542 .51707 Mdot
.32532 .52402 Mdot
.58422 .41677 Mdot
.32184 .79266 Mdot
.39642 .34084 Mdot
.3693 .58257 Mdot
.68693 .66313 Mdot
.42246 .68552 Mdot
.68075 .66327 Mdot
.53392 .67306 Mdot
.6447 .64468 Mdot
.53681 .62788 Mdot
.74896 .51117 Mdot
.36505 .43297 Mdot
.64539 .66297 Mdot
.43625 .64233 Mdot
.63994 .41056 Mdot
.61504 .64076 Mdot
.51312 .43816 Mdot
.56898 .32052 Mdot
.51759 .63627 Mdot
.65744 .67325 Mdot
.55631 .40402 Mdot
.6719 .23415 Mdot
.31858 .53839 Mdot
.30931 .5548 Mdot
.63918 .38278 Mdot
.5306 .62094 Mdot
.353 .4087 Mdot
.45068 .46868 Mdot
.43879 .70982 Mdot
.57444 .39581 Mdot
.56417 .46589 Mdot
.41737 .40736 Mdot
.42002 .41228 Mdot
.58171 .42138 Mdot
.4804 .21616 Mdot
.57167 .41177 Mdot
.35785 .53264 Mdot
.40974 .398 Mdot
.3773 .38414 Mdot
.54759 .65071 Mdot
.3433 .3649 Mdot
.57255 .34308 Mdot
.36037 .4688 Mdot
.5285 .46256 Mdot
.34434 .54947 Mdot
.44732 .48568 Mdot
.50246 .69729 Mdot
.71734 .28573 Mdot
.41185 .41114 Mdot
.5442 .39664 Mdot
.36614 .35017 Mdot
.66951 .65785 Mdot
.39238 .37566 Mdot
.41209 .3642 Mdot
.591 .40617 Mdot
.61688 .42454 Mdot
.41034 .70964 Mdot
.49684 .5241 Mdot
.3464 .36553 Mdot
.5746 .40142 Mdot
.52511 .41737 Mdot
.55989 .37584 Mdot
.45255 .53195 Mdot
.41303 .37617 Mdot
.5008 .25777 Mdot
.73654 .39543 Mdot
.34648 .37068 Mdot
.59324 .17298 Mdot
.41684 .69006 Mdot
.41964 .68462 Mdot
.34325 .58708 Mdot
.56449 .41199 Mdot
.48302 .65889 Mdot
.61641 .41177 Mdot
.60211 .33949 Mdot
.60773 .41863 Mdot
.66324 .67634 Mdot
.61097 .46746 Mdot
.42284 .70592 Mdot
.53184 .65019 Mdot
.5893 .38139 Mdot
.60935 .40338 Mdot
.41052 .68575 Mdot
.39828 .41693 Mdot
.40144 .40446 Mdot
.67949 .72524 Mdot
.66004 .65911 Mdot
.34524 .51814 Mdot
.5771 .456 Mdot
.49659 .65219 Mdot
.53151 .64391 Mdot
.34222 .37257 Mdot
.52259 .64346 Mdot
.33796 .50802 Mdot
.58592 .44306 Mdot
.30978 .5542 Mdot
.64806 .67322 Mdot
.39376 .35326 Mdot
.58345 .45713 Mdot
.56061 .4411 Mdot
.35431 .37799 Mdot
.62613 .4395 Mdot
.67752 .65246 Mdot
.53698 .64772 Mdot
.38063 .40299 Mdot
.35256 .53625 Mdot
.54982 .65032 Mdot
.5569 .42612 Mdot
.34898 .18605 Mdot
.57792 .42909 Mdot
.56024 .41707 Mdot
.83043 .43725 Mdot
.57561 .48397 Mdot
.5437 .65175 Mdot
.42413 .39843 Mdot
.62746 .3733 Mdot
.63732 .54905 Mdot
.6992 .74241 Mdot
.55353 .63067 Mdot
.58927 .38726 Mdot
.73114 .29435 Mdot
.59032 .38424 Mdot
.64551 .60293 Mdot
.53182 .78246 Mdot
.67593 .46083 Mdot
.5794 .34449 Mdot
.31265 .53283 Mdot
.41195 .71259 Mdot
.54551 .63691 Mdot
.39287 .29801 Mdot
.58487 .40332 Mdot
.35389 .28648 Mdot
.5782 .37274 Mdot
.35835 .54844 Mdot
.57298 .32572 Mdot
.5285 .63689 Mdot
.20834 .61009 Mdot
.5443 .44282 Mdot
.41332 .38277 Mdot
.55313 .65294 Mdot
.42137 .68684 Mdot
.55713 .41451 Mdot
.62164 .65086 Mdot
.37416 .56739 Mdot
.51412 .45251 Mdot
.3481 .54881 Mdot
.56808 .38814 Mdot
.62789 .34841 Mdot
.27425 .73384 Mdot
.36113 .39664 Mdot
.33069 .53136 Mdot
.34997 .72896 Mdot
.62898 .43098 Mdot
.37381 .40039 Mdot
.3787 .37088 Mdot
.64173 .63348 Mdot
.49161 .55686 Mdot
.26423 .38563 Mdot
.65365 .25945 Mdot
.48328 .35202 Mdot
.54838 .63125 Mdot
.3202 .6907 Mdot
.55102 .43842 Mdot
.37928 .5931 Mdot
.31296 .51658 Mdot
.59021 .42479 Mdot
.45965 .35057 Mdot
.39433 .35554 Mdot
.56809 .42397 Mdot
.65776 .6362 Mdot
.33346 .61514 Mdot
.37236 .60564 Mdot
.49149 .16287 Mdot
.55442 .62917 Mdot
.55329 .3691 Mdot
.5592 .35078 Mdot
.41554 .72138 Mdot
.60964 .37247 Mdot
.54174 .65103 Mdot
.8046 .54072 Mdot
.66717 .67389 Mdot
.40331 .36021 Mdot
.41757 .68958 Mdot
.63692 .38711 Mdot
.53268 .39983 Mdot
.65729 .62788 Mdot
.54581 .40139 Mdot
.23787 .6811 Mdot
.38755 .73177 Mdot
.49355 .6673 Mdot
.37598 .40761 Mdot
.63574 .40263 Mdot
.43652 .69413 Mdot
.58703 .40765 Mdot
.62616 .2892 Mdot
.54029 .40374 Mdot
.24957 .39202 Mdot
.34981 .3718 Mdot
.34725 .5458 Mdot
.60551 .3499 Mdot
.60776 .42598 Mdot
.6232 .72792 Mdot
.60562 .34108 Mdot
.60616 .38686 Mdot
.35534 .40498 Mdot
.41057 .37787 Mdot
.39809 .38855 Mdot
.50967 .6789 Mdot
.23219 .55327 Mdot
.33392 .55151 Mdot
.56001 .47001 Mdot
.31508 .57245 Mdot
.66088 .33635 Mdot
.66574 .62925 Mdot
.61544 .20473 Mdot
.55399 .38642 Mdot
.39247 .39008 Mdot
.3089 .45349 Mdot
.36037 .34337 Mdot
.52316 .59914 Mdot
.34158 .56212 Mdot
.39589 .35928 Mdot
.60294 .43576 Mdot
.47844 .5186 Mdot
.52298 .17676 Mdot
.33659 .53591 Mdot
.51814 .40521 Mdot
.54604 .61428 Mdot
.51966 .69544 Mdot
.44119 .12297 Mdot
.32292 .53397 Mdot
.32536 .70823 Mdot
.58021 .39829 Mdot
.40784 .38025 Mdot
.31803 .51885 Mdot
.3163 .53491 Mdot
.52058 .63732 Mdot
.61495 .43181 Mdot
.60434 .44495 Mdot
.41229 .69364 Mdot
.34615 .52743 Mdot
.63472 .37368 Mdot
.52155 .41577 Mdot
.80749 .39467 Mdot
.38208 .31124 Mdot
.60833 .84356 Mdot
.60134 .3323 Mdot
.47367 .34681 Mdot
.50968 .5165 Mdot
.40635 .3562 Mdot
.6102 .44176 Mdot
.63195 .39419 Mdot
.54632 .65138 Mdot
.58124 .43742 Mdot
.4827 .67453 Mdot
.32368 .54395 Mdot
.57913 .17413 Mdot
.29897 .38697 Mdot
.79906 .5365 Mdot
.58564 .43502 Mdot
.20638 .44671 Mdot
.6602 .66759 Mdot
.32693 .49421 Mdot
.39476 .40116 Mdot
.62937 .41593 Mdot
.48167 .68902 Mdot
.51036 .6304 Mdot
.38585 .36502 Mdot
.26776 .65432 Mdot
.65077 .73351 Mdot
.62307 .39838 Mdot
.49556 .67719 Mdot
.31313 .47764 Mdot
.46292 .21693 Mdot
.3013 .5579 Mdot
.67381 .67292 Mdot
.51435 .62175 Mdot
.3279 .57242 Mdot
.43874 .35499 Mdot
.38902 .35818 Mdot
.42703 .39053 Mdot
.55599 .75939 Mdot
.49278 .68519 Mdot
.64464 .66585 Mdot
.21287 .5267 Mdot
.20601 .52022 Mdot
.66872 .6753 Mdot
.5037 .62483 Mdot
.40898 .37085 Mdot
.37886 .39656 Mdot
.37637 .37813 Mdot
.20457 .59694 Mdot
.36677 .4111 Mdot
.55762 .2609 Mdot
.52615 .40715 Mdot
.56462 .51595 Mdot
.59148 .38618 Mdot
.30789 .53387 Mdot
.35747 .39051 Mdot
.52542 .5313 Mdot
.61156 .45254 Mdot
.51143 .16765 Mdot
.57592 .39277 Mdot
.29799 .54253 Mdot
.56502 .41918 Mdot
.55553 .22917 Mdot
.414 .35964 Mdot
.57885 .44242 Mdot
.36171 .51453 Mdot
.65498 .65257 Mdot
.34623 .33179 Mdot
.60608 .4448 Mdot
.24191 .46696 Mdot
.57064 .48016 Mdot
.81015 .52781 Mdot
.72961 .59657 Mdot
.67409 .63334 Mdot
.55799 .33856 Mdot
.54021 .62058 Mdot
.33655 .33256 Mdot
.50043 .40066 Mdot
.33812 .5357 Mdot
.28852 .29266 Mdot
.50542 .63351 Mdot
.52307 .34814 Mdot
.59919 .48615 Mdot
.66833 .63646 Mdot
.43562 .36402 Mdot
.3201 .51045 Mdot
.61249 .45977 Mdot
.55089 .37832 Mdot
.7976 .51981 Mdot
.49887 .41641 Mdot
.53825 .4547 Mdot
.63078 .63099 Mdot
.51046 .26164 Mdot
.56561 .43783 Mdot
.49718 .61558 Mdot
.42661 .38872 Mdot
.6406 .38605 Mdot
.49963 .25467 Mdot
.57567 .40189 Mdot
.39593 .36728 Mdot
.43032 .39073 Mdot
.28303 .4435 Mdot
.68732 .65498 Mdot
.54065 .40325 Mdot
.75784 .60689 Mdot
.53933 .43456 Mdot
.33517 .55641 Mdot
.61975 .39993 Mdot
.5102 .63546 Mdot
.2248 .62253 Mdot
.51715 .67196 Mdot
.61884 .40861 Mdot
.37321 .37987 Mdot
.31288 .5253 Mdot
.5144 .7553 Mdot
.57156 .77523 Mdot
.5504 .26015 Mdot
.74245 .72647 Mdot
.66994 .66911 Mdot
.61305 .65376 Mdot
.33148 .50321 Mdot
.57647 .44344 Mdot
.73581 .62513 Mdot
.54489 .47358 Mdot
.5657 .42759 Mdot
.60813 .41679 Mdot
.38881 .56721 Mdot
.3296 .54324 Mdot
.52175 .64995 Mdot
.58122 .42347 Mdot
.57322 .40238 Mdot
.36 .35549 Mdot
.65301 .65347 Mdot
.52045 .67288 Mdot
.651 .66024 Mdot
.50996 .66357 Mdot
.61111 .17753 Mdot
.51955 .43822 Mdot
.65787 .65302 Mdot
.32336 .50359 Mdot
.40266 .37807 Mdot
.43893 .69921 Mdot
.5394 .66874 Mdot
.52921 .63348 Mdot
.57567 .39593 Mdot
.40139 .37209 Mdot
.34423 .36703 Mdot
.66947 .66059 Mdot
.3333 .51402 Mdot
.61819 .41115 Mdot
.62222 .39176 Mdot
.70291 .42624 Mdot
.54774 .66653 Mdot
.44759 .23043 Mdot
.2782 .46717 Mdot
.57799 .44543 Mdot
.36648 .40541 Mdot
.60531 .40639 Mdot
.72772 .31296 Mdot
.40189 .40765 Mdot
.61736 .439 Mdot
.19487 .48035 Mdot
.52537 .68553 Mdot
.24683 .42844 Mdot
.52897 .42298 Mdot
.77328 .68525 Mdot
.5462 .43216 Mdot
.78575 .3425 Mdot
.38806 .67037 Mdot
.55523 .46302 Mdot
.55505 .43899 Mdot
.64085 .24907 Mdot
.58821 .39641 Mdot
.42883 .70074 Mdot
.55913 .33193 Mdot
.41368 .39478 Mdot
.54102 .53235 Mdot
.47711 .63044 Mdot
.68835 .66438 Mdot
.49488 .65907 Mdot
.44612 .73073 Mdot
.66304 .63917 Mdot
.36597 .37807 Mdot
.56479 .45651 Mdot
.5807 .54405 Mdot
.56023 .6315 Mdot
.62206 .47387 Mdot
.33744 .55839 Mdot
.46097 .7108 Mdot
.47953 .66687 Mdot
.35016 .5389 Mdot
.56913 .37493 Mdot
.51595 .19365 Mdot
.50782 .78549 Mdot
.84469 .57083 Mdot
.32365 .50976 Mdot
.36016 .54519 Mdot
.22091 .57834 Mdot
.68433 .6691 Mdot
.77414 .44746 Mdot
.22483 .41868 Mdot
.35397 .51749 Mdot
.77501 .51978 Mdot
.52611 .61773 Mdot
.23426 .46506 Mdot
.34063 .40852 Mdot
.53328 .38645 Mdot
.60442 .43314 Mdot
.33362 .51577 Mdot
.51086 .48922 Mdot
.29655 .74919 Mdot
.34201 .5387 Mdot
.54932 .35977 Mdot
.465 .56922 Mdot
.41731 .69426 Mdot
.40629 .70365 Mdot
.68475 .64658 Mdot
.69823 .70708 Mdot
.35775 .36156 Mdot
.66422 .63333 Mdot
.36703 .6126 Mdot
.54925 .39401 Mdot
.34307 .53078 Mdot
.43935 .69055 Mdot
.35588 .54266 Mdot
.65321 .63797 Mdot
.67361 .63423 Mdot
.361 .39895 Mdot
.40364 .40084 Mdot
.46664 .34317 Mdot
.74799 .54253 Mdot
.58997 .38293 Mdot
.36919 .23411 Mdot
.35406 .35531 Mdot
.50651 .38047 Mdot
.65755 .67781 Mdot
.6573 .65551 Mdot
.39492 .266 Mdot
.57607 .45899 Mdot
.72211 .63427 Mdot
.58209 .45527 Mdot
.75905 .45483 Mdot
.6161 .3757 Mdot
.52083 .64021 Mdot
.56046 .46169 Mdot
.58786 .62222 Mdot
.57735 .46633 Mdot
.60704 .38583 Mdot
.52455 .62003 Mdot
.5206 .46114 Mdot
.51108 .63411 Mdot
.62012 .41157 Mdot
.62568 .6689 Mdot
.49633 .65313 Mdot
.672 .52426 Mdot
.43374 .52726 Mdot
.42857 .70768 Mdot
.62627 .6466 Mdot
.63349 .63394 Mdot
.61426 .56316 Mdot
.39296 .402 Mdot
.45358 .3845 Mdot
.57522 .44131 Mdot
.53712 .62397 Mdot
.3283 .53926 Mdot
.57259 .4049 Mdot
.62444 .38931 Mdot
.53096 .44181 Mdot
.38028 .3508 Mdot
.49854 .68917 Mdot
.65878 .6489 Mdot
.49958 .67804 Mdot
.64841 .71871 Mdot
.47744 .65036 Mdot
.63959 .43058 Mdot
.5908 .35472 Mdot
.66244 .31704 Mdot
.32308 .28444 Mdot
.17951 .47381 Mdot
.38575 .35959 Mdot
.41551 .71059 Mdot
.67334 .63514 Mdot
.61285 .3212 Mdot
.3937 .39616 Mdot
.52192 .6238 Mdot
.57589 .44961 Mdot
.52522 .38283 Mdot
.30531 .58272 Mdot
.33097 .33362 Mdot
.66912 .56767 Mdot
.47757 .66982 Mdot
.42572 .69725 Mdot
.23018 .55407 Mdot
.47571 .38457 Mdot
.55291 .55009 Mdot
.60027 .41826 Mdot
.62266 .65401 Mdot
.40647 .36529 Mdot
.51033 .76674 Mdot
.34064 .52169 Mdot
.49063 .52003 Mdot
.58515 .43597 Mdot
.2513 .5667 Mdot
.37325 .37838 Mdot
.64971 .63541 Mdot
.33404 .51649 Mdot
.69045 .66106 Mdot
.40577 .7037 Mdot
.73652 .68965 Mdot
.5387 .42003 Mdot
.60443 .38737 Mdot
.30016 .54357 Mdot
.36223 .35939 Mdot
.6992 .68062 Mdot
.80242 .49064 Mdot
.49009 .67203 Mdot
.71769 .63532 Mdot
.37932 .33904 Mdot
.58519 .25488 Mdot
.50319 .67872 Mdot
.31783 .56875 Mdot
.6052 .5714 Mdot
.35131 .56422 Mdot
.60006 .45113 Mdot
.38494 .38733 Mdot
.32011 .54356 Mdot
.61024 .72643 Mdot
.72252 .27006 Mdot
.59936 .25044 Mdot
.54438 .45097 Mdot
.60243 .19412 Mdot
.82424 .47672 Mdot
.48032 .45462 Mdot
.36326 .53787 Mdot
.59136 .41213 Mdot
.6021 .3663 Mdot
.54734 .44773 Mdot
.32371 .55782 Mdot
.61212 .69584 Mdot
.52388 .63023 Mdot
.58064 .38808 Mdot
.65509 .63203 Mdot
.50975 .64203 Mdot
.58359 .64939 Mdot
.54314 .64344 Mdot
.41857 .38715 Mdot
.60863 .4509 Mdot
.24641 .5215 Mdot
.74584 .27086 Mdot
.33464 .53999 Mdot
.42826 .70767 Mdot
.59323 .37566 Mdot
.22032 .3932 Mdot
.39707 .38928 Mdot
.48894 .67059 Mdot
.58992 .42226 Mdot
.6137 .70641 Mdot
.44147 .68006 Mdot
.53939 .63825 Mdot
.38146 .39937 Mdot
.4715 .45358 Mdot
.57973 .43564 Mdot
.54426 .42776 Mdot
.36052 .36468 Mdot
.70528 .71187 Mdot
.22647 .61705 Mdot
.60802 .40456 Mdot
.3479 .5441 Mdot
.44419 .86084 Mdot
.53409 .40488 Mdot
.41612 .33089 Mdot
.41975 .68543 Mdot
.25468 .46575 Mdot
.43994 .23172 Mdot
.55951 .33667 Mdot
.65552 .25006 Mdot
.58486 .55519 Mdot
.58989 .17824 Mdot
.64939 .69122 Mdot
.41915 .60759 Mdot
.62435 .18454 Mdot
.35341 .50854 Mdot
.57655 .51921 Mdot
.69688 .37645 Mdot
.25103 .64409 Mdot
.50402 .49735 Mdot
.64761 .77147 Mdot
.60654 .74471 Mdot
.47855 .59995 Mdot
.53084 .65916 Mdot
.74681 .44073 Mdot
.61688 .40919 Mdot
.82554 .48495 Mdot
.49603 .21746 Mdot
.29275 .75318 Mdot
.61696 .199 Mdot
.75992 .60309 Mdot
.54028 .18638 Mdot
.73955 .31008 Mdot
.67526 .32329 Mdot
.30476 .35716 Mdot
.59921 .82951 Mdot
.20963 .53228 Mdot
.77558 .59893 Mdot
.65537 .41762 Mdot
.53716 .57524 Mdot
.79596 .59328 Mdot
.56071 .27906 Mdot
.34841 .80538 Mdot
.53821 .66478 Mdot
.42549 .37508 Mdot
.70683 .39675 Mdot
.35732 .32768 Mdot
.363 .48006 Mdot
.65244 .24651 Mdot
.78241 .34894 Mdot
.5481 .22794 Mdot
.77216 .69262 Mdot
.41541 .29878 Mdot
.15629 .48124 Mdot
.43797 .55586 Mdot
.42796 .36911 Mdot
.53766 .82513 Mdot
.20608 .51778 Mdot
.28841 .38713 Mdot
.63314 .33406 Mdot
.58636 .66454 Mdot
.69547 .53732 Mdot
.37248 .38698 Mdot
.43913 .22563 Mdot
.40267 .70716 Mdot
.28928 .34729 Mdot
.57446 .61224 Mdot
.70368 .27193 Mdot
.49295 .58272 Mdot
.2361 .48097 Mdot
.30623 .67309 Mdot
.35233 .18317 Mdot
.76114 .55916 Mdot
.75881 .36809 Mdot
.29533 .56428 Mdot
.4994 .48908 Mdot
.28427 .70669 Mdot
.73279 .55865 Mdot
.20246 .50807 Mdot
.33736 .22441 Mdot
.82844 .53592 Mdot
.40313 .17521 Mdot
.41502 .33908 Mdot
.53291 .44494 Mdot
.73036 .344 Mdot
.48724 .35272 Mdot
.66214 .62556 Mdot
.45962 .16557 Mdot
.63702 .66944 Mdot
.38331 .32802 Mdot
.26309 .65259 Mdot
.55864 .24682 Mdot
.70494 .62123 Mdot
.69236 .67774 Mdot
.61017 .46962 Mdot
.13028 .59176 Mdot
.57829 .17963 Mdot
.27625 .44736 Mdot
.80768 .39339 Mdot
.2948 .59802 Mdot
.72324 .6116 Mdot
.32246 .54947 Mdot
.68755 .22518 Mdot
.3837 .39514 Mdot
.6759 .18995 Mdot
.71367 .25228 Mdot
.38295 .78817 Mdot
.27802 .80672 Mdot
.35376 .64644 Mdot
.67811 .44291 Mdot
.59939 .5458 Mdot
.65931 .54809 Mdot
.2977 .73905 Mdot
.39701 .79862 Mdot
.28664 .5954 Mdot
.77932 .64654 Mdot
.64819 .20452 Mdot
.77096 .49345 Mdot
.74861 .65295 Mdot
.26674 .67043 Mdot
.44218 .52471 Mdot
.44431 .3907 Mdot
.41348 .5024 Mdot
.30803 .34895 Mdot
.44477 .16842 Mdot
.47096 .37184 Mdot
.37474 .84414 Mdot
.63555 .67916 Mdot
.40037 .6804 Mdot
.80667 .41817 Mdot
.68287 .51215 Mdot
.64405 .32004 Mdot
.23719 .57811 Mdot
.62106 .46229 Mdot
.2305 .56528 Mdot
.40431 .44317 Mdot
.4513 .72487 Mdot
.22649 .55479 Mdot
.28752 .49865 Mdot
.79759 .50905 Mdot
.69329 .31173 Mdot
.19919 .46126 Mdot
.41271 .4002 Mdot
.71228 .57377 Mdot
.76803 .54409 Mdot
.80872 .4022 Mdot
.34871 .72804 Mdot
.8511 .55609 Mdot
.35995 .7423 Mdot
.54004 .46877 Mdot
.51496 .38123 Mdot
.65916 .42147 Mdot
.74354 .56467 Mdot
.52595 .42948 Mdot
.25231 .56976 Mdot
.82261 .42326 Mdot
.45195 .34899 Mdot
.48725 .72161 Mdot
.29931 .27593 Mdot
.84027 .55409 Mdot
.73195 .36058 Mdot
.3776 .67967 Mdot
.5188 .48555 Mdot
.17313 .39693 Mdot
.50862 .6508 Mdot
.77472 .51187 Mdot
.36648 .56152 Mdot
.54486 .76483 Mdot
.6274 .25072 Mdot
.37311 .7827 Mdot
.82602 .42725 Mdot
.23452 .61495 Mdot
.44814 .76844 Mdot
.59487 .59288 Mdot
.69603 .62024 Mdot
.3186 .26548 Mdot
.56275 .35702 Mdot
.66662 .36973 Mdot
.61878 .63935 Mdot
.52105 .32376 Mdot
.74355 .40056 Mdot
.56752 .79489 Mdot
.51801 .38348 Mdot
.47497 .80586 Mdot
.42842 .69475 Mdot
.48498 .51935 Mdot
.48183 .12736 Mdot
.63248 .4564 Mdot
.35721 .65882 Mdot
.82682 .54838 Mdot
.70999 .59141 Mdot
.78709 .39801 Mdot
.25999 .52104 Mdot
.38691 .18823 Mdot
.74248 .27919 Mdot
.56604 .78327 Mdot
.54977 .15935 Mdot
.86206 .48133 Mdot
.35502 .20505 Mdot
.35753 .26548 Mdot
.35525 .50404 Mdot
.62522 .13222 Mdot
.49266 .63932 Mdot
.26959 .30803 Mdot
.4787 .35467 Mdot
.58067 .7103 Mdot
.34353 .39301 Mdot
.58894 .49827 Mdot
.48781 .5919 Mdot
.32633 .37173 Mdot
.64273 .39433 Mdot
.39707 .16006 Mdot
.29692 .25357 Mdot
.40823 .16105 Mdot
.81779 .59791 Mdot
.56045 .16263 Mdot
.68601 .44944 Mdot
.56966 .265 Mdot
.72461 .41908 Mdot
.62116 .39921 Mdot
.74507 .48638 Mdot
.35024 .65175 Mdot
.49385 .78245 Mdot
.27856 .38109 Mdot
.33858 .35705 Mdot
.45507 .17843 Mdot
.38471 .13404 Mdot
.42537 .29284 Mdot
.46266 .26401 Mdot
.37181 .59941 Mdot
.75302 .54524 Mdot
.3842 .44385 Mdot
.45317 .78918 Mdot
.80887 .41254 Mdot
.69702 .37238 Mdot
.78377 .52254 Mdot
.58791 .79777 Mdot
.63372 .60694 Mdot
.43404 .66421 Mdot
.70152 .26119 Mdot
.68552 .47708 Mdot
.38206 .77599 Mdot
.58199 .52683 Mdot
.33621 .77806 Mdot
.63196 .75792 Mdot
.4238 .73252 Mdot
.77558 .56239 Mdot
.51502 .69548 Mdot
.76356 .48931 Mdot
.47007 .56212 Mdot
.71311 .37807 Mdot
.58503 .55444 Mdot
.76413 .48362 Mdot
.63008 .60756 Mdot
.47709 .15509 Mdot
.87311 .52042 Mdot
.25421 .28725 Mdot
.78131 .67256 Mdot
.40425 .44717 Mdot
.53603 .39166 Mdot
.83772 .46426 Mdot
.4483 .14984 Mdot
.75872 .29516 Mdot
.25482 .61713 Mdot
.60656 .72052 Mdot
.31685 .50245 Mdot
.25403 .29273 Mdot
.66993 .74774 Mdot
.76537 .34195 Mdot
.18176 .47183 Mdot
.34528 .58692 Mdot
.23517 .64395 Mdot
.27094 .29369 Mdot
.60104 .2356 Mdot
.41754 .2468 Mdot
.60997 .48305 Mdot
.52745 .21645 Mdot
.41942 .39935 Mdot
.30232 .67713 Mdot
.73962 .55835 Mdot
.50418 .65293 Mdot
.67239 .5025 Mdot
.66492 .35943 Mdot
.60646 .47235 Mdot
.47132 .6344 Mdot
.39306 .42723 Mdot
.31881 .2926 Mdot
.28293 .51638 Mdot
.59406 .16073 Mdot
.34016 .66921 Mdot
.64257 .35414 Mdot
.72923 .58529 Mdot
.47606 .76021 Mdot
.23065 .57966 Mdot
.36188 .52248 Mdot
.64968 .22011 Mdot
.39481 .48528 Mdot
.71768 .57527 Mdot
.50945 .2123 Mdot
.7877 .46235 Mdot
.5913 .35562 Mdot
.29273 .45817 Mdot
.60034 .29693 Mdot
.5033 .52963 Mdot
.3898 .33366 Mdot
.415 .42173 Mdot
.81749 .67424 Mdot
.34656 .61899 Mdot
.3672 .72816 Mdot
.66017 .22904 Mdot
.33952 .5659 Mdot
.3499 .35101 Mdot
.7526 .47126 Mdot
.80226 .51568 Mdot
.57134 .29392 Mdot
.47822 .69059 Mdot
.57569 .67085 Mdot
.59993 .78128 Mdot
.60775 .19991 Mdot
.56311 .18836 Mdot
.28534 .75105 Mdot
.34071 .37226 Mdot
.78002 .43537 Mdot
.79468 .534 Mdot
.3724 .34763 Mdot
.36373 .32143 Mdot
.27859 .35075 Mdot
.53623 .14629 Mdot
.2393 .53699 Mdot
.77095 .6756 Mdot
.62959 .57758 Mdot
.61929 .70082 Mdot
.49625 .75915 Mdot
.76163 .62244 Mdot
.66667 .23467 Mdot
.42906 .22439 Mdot
.58084 .21768 Mdot
.64238 .36184 Mdot
.34429 .30177 Mdot
.24128 .30199 Mdot
.44604 .54526 Mdot
.58004 .24994 Mdot
.32858 .47444 Mdot
.54076 .44203 Mdot
.35433 .18218 Mdot
.81752 .49958 Mdot
.21094 .562 Mdot
.37689 .53155 Mdot
.55249 .41367 Mdot
.52344 .44159 Mdot
.49571 .46499 Mdot
.2679 .46036 Mdot
.30556 .25682 Mdot
.76402 .62199 Mdot
.43874 .44598 Mdot
.48941 .2144 Mdot
.35696 .66052 Mdot
.70435 .27778 Mdot
.81806 .45342 Mdot
.49506 .54598 Mdot
.3449 .65534 Mdot
.59318 .58011 Mdot
.79073 .65102 Mdot
.5164 .58085 Mdot
.69464 .43047 Mdot
.23358 .38967 Mdot
.26377 .48882 Mdot
.48733 .76502 Mdot
.59168 .37324 Mdot
.26644 .65263 Mdot
.73372 .30654 Mdot
.32141 .8006 Mdot
.29706 .72671 Mdot
.38268 .15954 Mdot
.63109 .28297 Mdot
.25817 .49836 Mdot
.54484 .19671 Mdot
.31054 .80145 Mdot
.50969 .5879 Mdot
.50013 .17396 Mdot
.59334 .58798 Mdot
.63514 .21218 Mdot
.37387 .53687 Mdot
.21903 .48932 Mdot
.29529 .28035 Mdot
.54848 .15124 Mdot
.74635 .37003 Mdot
.67922 .25054 Mdot
.58021 .52956 Mdot
.5057 .14145 Mdot
.23573 .3774 Mdot
.47587 .60389 Mdot
.54128 .61294 Mdot
.25409 .59663 Mdot
.44152 .19916 Mdot
.33426 .43558 Mdot
.7784 .5187 Mdot
.45408 .63874 Mdot
.62549 .31985 Mdot
.55327 .20938 Mdot
.70492 .49928 Mdot
.27414 .49144 Mdot
.72692 .58653 Mdot
.75239 .31581 Mdot
.46224 .64384 Mdot
.50672 .75352 Mdot
.35653 .69604 Mdot
.74382 .68411 Mdot
.26828 .45502 Mdot
.33879 .62339 Mdot
.75628 .36372 Mdot
.66543 .7385 Mdot
.76367 .59004 Mdot
.87275 .61561 Mdot
.77438 .62776 Mdot
.29905 .33813 Mdot
.43528 .17409 Mdot
.81367 .43029 Mdot
.30728 .31503 Mdot
.27705 .72588 Mdot
.36315 .30228 Mdot
.74669 .51109 Mdot
.60839 .41864 Mdot
.46482 .13415 Mdot
.70437 .52875 Mdot
.4457 .166 Mdot
.84397 .50513 Mdot
.52679 .2129 Mdot
.59854 .47885 Mdot
.47485 .64634 Mdot
.40717 .58854 Mdot
.71069 .48741 Mdot
.5939 .2186 Mdot
.37268 .3021 Mdot
.45482 .7059 Mdot
.40301 .7234 Mdot
.47349 .67856 Mdot
.45597 .42313 Mdot
.32972 .6525 Mdot
.27401 .47364 Mdot
.70885 .66835 Mdot
.51635 .56153 Mdot
.76214 .5363 Mdot
.44617 .22915 Mdot
.60931 .24184 Mdot
.35898 .77963 Mdot
.35499 .47506 Mdot
.54399 .65412 Mdot
.66011 .27057 Mdot
.78702 .617 Mdot
.29234 .4862 Mdot
.36541 .20777 Mdot
.23735 .59271 Mdot
.73461 .44558 Mdot
.72676 .38281 Mdot
.32091 .75957 Mdot
.64208 .80184 Mdot
.40612 .20108 Mdot
.32276 .30467 Mdot
.71787 .62682 Mdot
.67805 .3719 Mdot
.61164 .17869 Mdot
.77714 .58011 Mdot
.71854 .36596 Mdot
.43329 .53898 Mdot
.53743 .29403 Mdot
.51116 .20438 Mdot
.65995 .52742 Mdot
.54288 .54654 Mdot
.1534 .45532 Mdot
.33563 .38856 Mdot
.33837 .18803 Mdot
.34912 .52426 Mdot
.19016 .58581 Mdot
.64003 .61313 Mdot
.46901 .554 Mdot
.54735 .54208 Mdot
.29247 .45094 Mdot
.24864 .39148 Mdot
.80245 .6183 Mdot
.36396 .79544 Mdot
.48227 .64027 Mdot
.74168 .63102 Mdot
.72874 .70594 Mdot
.65032 .25289 Mdot
.63951 .40391 Mdot
.7706 .64156 Mdot
.44559 .54008 Mdot
.49086 .78139 Mdot
.83489 .47456 Mdot
.33426 .45531 Mdot
.57569 .34705 Mdot
.75007 .54768 Mdot
.49689 .17585 Mdot
.72789 .26869 Mdot
.23162 .66687 Mdot
.40445 .44341 Mdot
.33988 .49962 Mdot
.6546 .49556 Mdot
.61674 .21283 Mdot
.69838 .60241 Mdot
.23144 .49563 Mdot
.76641 .55406 Mdot
.24338 .26671 Mdot
.32237 .24288 Mdot
.30444 .25829 Mdot
.72661 .60073 Mdot
.35666 .33256 Mdot
.26526 .33801 Mdot
.72005 .3726 Mdot
.31985 .45068 Mdot
.80387 .58393 Mdot
.77269 .51982 Mdot
.24151 .72528 Mdot
.6364 .314 Mdot
.65254 .71768 Mdot
.48215 .20052 Mdot
.495 .34049 Mdot
.36935 .51736 Mdot
.73561 .50889 Mdot
.37541 .46212 Mdot
.30513 .51707 Mdot
.27628 .48542 Mdot
.2409 .46014 Mdot
.71744 .36307 Mdot
.58176 .28537 Mdot
.41853 .4469 Mdot
.68612 .29319 Mdot
.32884 .35921 Mdot
.51167 .76574 Mdot
.48983 .75254 Mdot
.4646 .47379 Mdot
.48929 .65991 Mdot
.56436 .33502 Mdot
.51146 .54046 Mdot
.57323 .57363 Mdot
.22693 .33917 Mdot
.62662 .66217 Mdot
.34411 .34705 Mdot
.19107 .55241 Mdot
.37587 .34566 Mdot
.42624 .14479 Mdot
.4438 .78614 Mdot
.50941 .21437 Mdot
.58676 .77271 Mdot
.54948 .81531 Mdot
.14689 .56564 Mdot
.35501 .25268 Mdot
.423 .52759 Mdot
.31493 .3679 Mdot
.37609 .41718 Mdot
.47923 .7042 Mdot
.40675 .72237 Mdot
.42635 .25026 Mdot
.37156 .64775 Mdot
.72927 .43119 Mdot
.42895 .36347 Mdot
.65128 .70801 Mdot
.52383 .34703 Mdot
.55303 .1483 Mdot
.53632 .65722 Mdot
.17453 .37426 Mdot
.51446 .42931 Mdot
.67218 .31123 Mdot
.83862 .44706 Mdot
.22926 .65197 Mdot
.43707 .75695 Mdot
.6793 .76912 Mdot
.57565 .47147 Mdot
.4219 .44353 Mdot
.37206 .38969 Mdot
.76253 .43257 Mdot
.64424 .64713 Mdot
.68554 .56985 Mdot
.31274 .5704 Mdot
.39111 .77621 Mdot
.32535 .65806 Mdot
.3781 .33479 Mdot
.35773 .45098 Mdot
.7456 .38397 Mdot
.21844 .45716 Mdot
.44622 .53734 Mdot
.64416 .25239 Mdot
.56848 .29038 Mdot
.4306 .36731 Mdot
.35651 .2209 Mdot
.79095 .54081 Mdot
.69235 .22345 Mdot
.63955 .47528 Mdot
.43029 .57112 Mdot
.20889 .45759 Mdot
.29009 .4713 Mdot
.43404 .23684 Mdot
.80668 .40808 Mdot
.7237 .56792 Mdot
.20987 .50476 Mdot
.76163 .48186 Mdot
.54286 .48625 Mdot
.4887 .57567 Mdot
.28471 .64854 Mdot
.20871 .6784 Mdot
.36395 .27483 Mdot
.26154 .68466 Mdot
.31139 .35118 Mdot
.35624 .65784 Mdot
.32919 .37743 Mdot
.53297 .73271 Mdot
.56011 .28362 Mdot
.40362 .74861 Mdot
.64513 .19249 Mdot
.81168 .4142 Mdot
.32437 .5903 Mdot
.56874 .66192 Mdot
.53133 .51977 Mdot
.65628 .38574 Mdot
.47737 .50372 Mdot
.55623 .4652 Mdot
.47274 .42695 Mdot
.22109 .6339 Mdot
.31007 .45405 Mdot
.58926 .4964 Mdot
.60071 .17937 Mdot
.7009 .23055 Mdot
.49644 .14478 Mdot
.71336 .63185 Mdot
.411 .36108 Mdot
.36463 .19367 Mdot
.47467 .24133 Mdot
.75153 .3108 Mdot
.39489 .21089 Mdot
.83344 .65119 Mdot
.59195 .22094 Mdot
.31328 .48175 Mdot
.38966 .79474 Mdot
.25409 .40479 Mdot
.83052 .49565 Mdot
.47358 .60836 Mdot
.49146 .71422 Mdot
.83338 .50353 Mdot
.13017 .57706 Mdot
.34877 .26978 Mdot
.2386 .47158 Mdot
.68923 .38233 Mdot
.44902 .46144 Mdot
.39568 .63758 Mdot
.61799 .39665 Mdot
.56293 .64739 Mdot
.45596 .76835 Mdot
.7667 .5338 Mdot
.66888 .33237 Mdot
.39525 .64053 Mdot
.71409 .48055 Mdot
.75506 .44145 Mdot
.77436 .60592 Mdot
.6143 .23619 Mdot
.43174 .24663 Mdot
.58446 .34633 Mdot
.33674 .34282 Mdot
.68568 .65589 Mdot
.45261 .73395 Mdot
.61782 .43311 Mdot
.42024 .74787 Mdot
.22978 .4179 Mdot
.38415 .16262 Mdot
.51055 .72936 Mdot
.80901 .50547 Mdot
.35237 .41842 Mdot
.27651 .45984 Mdot
.71147 .30756 Mdot
.25402 .64511 Mdot
.40679 .64347 Mdot
.47179 .37022 Mdot
.59074 .18482 Mdot
.23802 .56469 Mdot
.79072 .49337 Mdot
.20017 .3974 Mdot
.30488 .52703 Mdot
.34133 .29141 Mdot
.69807 .40012 Mdot
.24242 .61092 Mdot
.42543 .35206 Mdot
.27843 .51269 Mdot
.43931 .59645 Mdot
.24343 .57204 Mdot
.82811 .54946 Mdot
.76664 .4197 Mdot
.46062 .20382 Mdot
.57069 .18807 Mdot
.55741 .6427 Mdot
.7839 .51848 Mdot
.27853 .51731 Mdot
.41838 .62221 Mdot
.20232 .46915 Mdot
.59532 .16641 Mdot
.49506 .51575 Mdot
.68926 .53284 Mdot
.54103 .42826 Mdot
.50312 .25643 Mdot
.30271 .44847 Mdot
.60264 .61295 Mdot
.3582 .71612 Mdot
.40169 .40668 Mdot
.32307 .67745 Mdot
.45258 .67693 Mdot
.73477 .52229 Mdot
.33349 .41519 Mdot
.4155 .32554 Mdot
.62602 .62718 Mdot
.44817 .69827 Mdot
.62521 .36794 Mdot
.68105 .54514 Mdot
.69133 .61274 Mdot
.3451 .28432 Mdot
.33924 .26855 Mdot
.64977 .25664 Mdot
.80693 .533 Mdot
.30766 .47269 Mdot
.39248 .21025 Mdot
.25468 .38466 Mdot
.58785 .26875 Mdot
.30082 .69708 Mdot
.52915 .43648 Mdot
.53767 .73096 Mdot
.35402 .3443 Mdot
.62373 .22451 Mdot
.62593 .28681 Mdot
.67367 .5226 Mdot
.4678 .53019 Mdot
.72437 .32115 Mdot
.43889 .50397 Mdot
.83807 .45432 Mdot
.25619 .40313 Mdot
.73799 .55845 Mdot
.3538 .57863 Mdot
.60391 .59074 Mdot
.31127 .7463 Mdot
.68571 .23041 Mdot
.36613 .78453 Mdot
.585 .53991 Mdot
.25251 .67201 Mdot
.29215 .31687 Mdot
.83967 .50164 Mdot
.74125 .5408 Mdot
.47461 .50242 Mdot
.51316 .35465 Mdot
.29599 .57428 Mdot
.43839 .69971 Mdot
.55431 .73175 Mdot
.44959 .24704 Mdot
.58218 .68974 Mdot
.41326 .75661 Mdot
.63274 .36912 Mdot
.20479 .41635 Mdot
.57834 .18626 Mdot
.60647 .31533 Mdot
.45778 .55483 Mdot
.53549 .77544 Mdot
.72571 .5315 Mdot
.69157 .81072 Mdot
.35334 .18179 Mdot
.54048 .42508 Mdot
.57811 .55704 Mdot
.69424 .56301 Mdot
.48117 .66817 Mdot
.42952 .26117 Mdot
.6434 .24758 Mdot
.36135 .54318 Mdot
.59483 .72591 Mdot
.25524 .58242 Mdot
.2933 .44215 Mdot
.66004 .51806 Mdot
.37984 .57968 Mdot
.40647 .15004 Mdot
.79084 .62085 Mdot
.30148 .464 Mdot
.75189 .75303 Mdot
.26838 .64007 Mdot
.38662 .43553 Mdot
.74297 .35529 Mdot
.48002 .15381 Mdot
.71633 .59319 Mdot
.55488 .76007 Mdot
.32495 .27167 Mdot
.73168 .56088 Mdot
.76726 .46218 Mdot
.35593 .69507 Mdot
.3305 .68482 Mdot
.46616 .59536 Mdot
.55228 .81444 Mdot
.24018 .33823 Mdot
.45587 .216 Mdot
.53842 .17704 Mdot
.41993 .77191 Mdot
.25371 .73902 Mdot
.68701 .22473 Mdot
.7346 .48896 Mdot
.38675 .65147 Mdot
.75619 .37151 Mdot
.64923 .57048 Mdot
.46677 .37144 Mdot
.43922 .78079 Mdot
.55368 .3026 Mdot
.52419 .81268 Mdot
.32036 .72442 Mdot
.76358 .48681 Mdot
.47902 .34875 Mdot
.5055 .52151 Mdot
.64389 .26011 Mdot
.38258 .72876 Mdot
.74048 .58885 Mdot
.59792 .73367 Mdot
.63671 .557 Mdot
.66614 .26856 Mdot
.74818 .34078 Mdot
.47825 .49861 Mdot
.13155 .56832 Mdot
.45921 .17059 Mdot
.26833 .66594 Mdot
.52702 .40609 Mdot
.63673 .18318 Mdot
.45385 .47581 Mdot
.37747 .21943 Mdot
.81944 .54615 Mdot
.48893 .74533 Mdot
.21084 .44239 Mdot
.53262 .44587 Mdot
.3622 .24079 Mdot
.57959 .24647 Mdot
.49031 .34097 Mdot
.46369 .76924 Mdot
.72862 .58294 Mdot
.38517 .70393 Mdot
.64274 .53758 Mdot
.66492 .41208 Mdot
.37254 .3386 Mdot
.42466 .15344 Mdot
.62565 .51154 Mdot
.51309 .36273 Mdot
.5547 .51206 Mdot
.36638 .79076 Mdot
.71237 .76602 Mdot
.6614 .42965 Mdot
.23489 .56009 Mdot
.77703 .52245 Mdot
.7269 .40412 Mdot
.35081 .26141 Mdot
.32531 .85015 Mdot
.83521 .43297 Mdot
.35973 .41538 Mdot
.38161 .29757 Mdot
.73657 .60763 Mdot
.50654 .14896 Mdot
.59096 .79568 Mdot
.47595 .7563 Mdot
.37882 .81788 Mdot
.66358 .57837 Mdot
.62318 .38966 Mdot
.83143 .57244 Mdot
.6927 .2361 Mdot
.39852 .77398 Mdot
.61795 .18479 Mdot
.59822 .4815 Mdot
.51999 .41792 Mdot
.49732 .89513 Mdot
.6346 .22078 Mdot
.61673 .46784 Mdot
.34351 .7858 Mdot
.44483 .38314 Mdot
.61618 .4186 Mdot
.37438 .63 Mdot
.77455 .57719 Mdot
.76008 .45054 Mdot
.5468 .15092 Mdot
.38163 .3335 Mdot
.42232 .75029 Mdot
.33344 .57564 Mdot
.5473 .5437 Mdot
.53197 .37593 Mdot
.31924 .55093 Mdot
.74019 .44784 Mdot
.46709 .48017 Mdot
.37305 .56768 Mdot
.74836 .64238 Mdot
.85124 .5729 Mdot
.62778 .27543 Mdot
.32212 .59389 Mdot
.50883 .47226 Mdot
.60881 .31257 Mdot
.71282 .48462 Mdot
.71532 .44229 Mdot
.83228 .52493 Mdot
.87232 .43538 Mdot
.52112 .70721 Mdot
.59936 .50137 Mdot
.35046 .42816 Mdot
.44347 .24053 Mdot
.5854 .23082 Mdot
.37212 .50896 Mdot
.41041 .71405 Mdot
.55506 .47587 Mdot
.66503 .41671 Mdot
.31663 .57491 Mdot
.28769 .22883 Mdot
.60915 .38172 Mdot
.40381 .23188 Mdot
.73873 .29922 Mdot
.508 .76588 Mdot
.65929 .31005 Mdot
.60204 .46703 Mdot
.25592 .35099 Mdot
.447 .47235 Mdot
.47341 .46064 Mdot
.4955 .75618 Mdot
.53229 .16185 Mdot
.62865 .28883 Mdot
.44537 .21008 Mdot
.57249 .39605 Mdot
.64677 .6791 Mdot
.23122 .4654 Mdot
.33482 .25419 Mdot
.65599 .36342 Mdot
.74676 .29532 Mdot
.49602 .74552 Mdot
.59078 .68436 Mdot
.68094 .34814 Mdot
.43423 .16414 Mdot
.29358 .71665 Mdot
.56008 .22151 Mdot
.21366 .58081 Mdot
.29877 .62104 Mdot
.70653 .50021 Mdot
.47433 .6494 Mdot
.58726 .4978 Mdot
.44062 .37363 Mdot
.4477 .12664 Mdot
.32883 .25916 Mdot
.27496 .55374 Mdot
.45502 .71223 Mdot
.54258 .24696 Mdot
.5317 .53142 Mdot
.79652 .70834 Mdot
.65241 .76834 Mdot
.40057 .1516 Mdot
.75728 .42115 Mdot
.43139 .42327 Mdot
.26531 .50747 Mdot
.52763 .36816 Mdot
.5366 .63791 Mdot
.51498 .15302 Mdot
.6603 .44647 Mdot
.32028 .71596 Mdot
.62016 .38703 Mdot
.20207 .54488 Mdot
.40242 .46292 Mdot
.55999 .67028 Mdot
.53497 .68486 Mdot
.2821 .72786 Mdot
.73087 .31097 Mdot
.44109 .47318 Mdot
.78749 .69961 Mdot
.56253 .19839 Mdot
.65187 .22121 Mdot
.47735 .6885 Mdot
.20933 .64715 Mdot
.31517 .40137 Mdot
.38703 .45707 Mdot
.28578 .51399 Mdot
.60759 .54335 Mdot
.24299 .59714 Mdot
.73294 .41523 Mdot
.23893 .43237 Mdot
.31807 .5865 Mdot
.91908 .46646 Mdot
.74225 .47745 Mdot
.63514 .33658 Mdot
.27449 .65908 Mdot
.62923 .19986 Mdot
.68462 .62976 Mdot
.83981 .57817 Mdot
.53905 .57407 Mdot
.52572 .38602 Mdot
.59138 .28917 Mdot
.681 .33314 Mdot
.25792 .59457 Mdot
.14185 .50851 Mdot
.79323 .60402 Mdot
.56105 .69014 Mdot
.51146 .55969 Mdot
.36806 .34805 Mdot
.34468 .39485 Mdot
.56951 .78957 Mdot
.82137 .62933 Mdot
.43118 .45486 Mdot
.61951 .21387 Mdot
.16092 .59319 Mdot
.77779 .45506 Mdot
.51617 .14691 Mdot
.30749 .38953 Mdot
.35045 .32362 Mdot
.71757 .47458 Mdot
.67203 .68743 Mdot
.51375 .69186 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0Z?ooool2o`0009oooooo000Looooo`03o`000?oooooooooo0:Sooooo0_l0
002Oooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo08cooooo0_l0002kooooo`007?ooool00ol0003oooooooooo`2<ooooo`;o00000oooool2
o`000;Kooooo000Looooo`03o`000?oooooooooo08kooooo0_l000000ooooooo0000o`000006oooo
o`;o0000[_ooool001cooooo00?o0000ooooooooool0S_ooool2o`0000Wooooo0_l0000[ooooo`?o
0000P?ooool001cooooo00?o0000ooooooooool0NOooool2o`0001Sooooo0_l0000aooooo`Go0000
O_ooool001cooooo00?o0000ooooooooool0NOooool2o`0001Sooooo0_l0000Aooooo`;o00008Ooo
ool2o`0007kooooo000Looooo`03o`000?oooooooooo08Sooooo0_l0000Gooooo`;o00000oooool2
o`000:7ooooo000Looooo`03o`000?oooooooooo08Sooooo0_l0000Gooooo`;o0000Y_ooool001co
oooo00?o0000ooooooooool0Qoooool2o`0001Gooooo0_l00004ooooo`;o00001?ooool2o`0009go
oooo000Looooo`03o`000?oooooooooo083ooooo0_l00005ooooo`;o00001Oooool2o`0000kooooo
0_l000001?oooooo0000o`000?ooool2o`0000Cooooo0_l00004ooooo`;o0000Uoooool001cooooo
0_l0001oooooo`Co00001?ooool2o`0000Kooooo0_l00008ooooo`;o00001oooool2o`000003oooo
ool0003o000000Sooooo1?l0002Gooooo`007?ooool00ol0003oooooooooo`1nooooo`;o00001_oo
ool2o`0000Kooooo0_l00003ooooo`;o00000_ooool3o`0000[ooooo0_l00008ooooo`;o0000VOoo
ool001cooooo00?o0000ooooooooool0Moooool4o`0001?ooooo0_l00003ooooo`;o00000_ooool2
o`0000oooooo0_l00005ooooo`;o0000V?ooool001cooooo00?o0000ooooooooool0Moooool4o`00
00;ooooo0_l00002ooooo`;o00002Oooool2o`0000kooooo0_l0000:ooooo`?o00001?ooool2o`00
0003ooooool0003o000000Sooooo0ol0002:ooooo`007?ooool00ol0003oooooooooo`1iooooo`;o
00000_ooool2o`0000;ooooo0_l00006ooooo`;o000000Coooooo`000?l0003o00000oooool2o`00
00Sooooo0_l00009ooooo`Co00001oooool2o`0000Sooooo0ol0002:ooooo`007?ooool00ol0003o
ooooooooo`29ooooo`;o00000_ooool2o`0000?ooooo0_l0000>ooooo`;o00000oooool2o`0000Go
oooo0_l0000>ooooo`;o0000ROooool001cooooo00?o0000ooooooooool0SOooool2o`0000;ooooo
0_l0000?ooooo`;o00002_ooool2o`0000Kooooo0_l00006ooooo`;o0000ROooool001cooooo00?o
0000ooooooooool0Ooooool2o`0000Wooooo0_l00005ooooo`;o00003?ooool2o`0001Gooooo1?l0
0003ooooo`;o0000R_ooool001cooooo00?o0000ooooooooool0LOooool2o`0000cooooo0_l00009
ooooo`;o00001?ooool2o`0000cooooo0ol00005ooooo`;o00000oooool2o`0000_ooooo1ol00004
ooooo`;o0000Q?ooool001cooooo00?o0000ooooooooool0LOooool2o`0001Cooooo0_l00007oooo
o`;o00003?ooool2o`0000Kooooo0_l00003ooooo`;o00002oooool6o`000003ooooool0003o0000
00;ooooo0_l0000Gooooo`;o0000Joooool001cooooo00?o0000ooooooooool0Koooool2o`0000go
oooo0_l00006ooooo`?o0000;oooool2o`0000Gooooo0_l00002ooooo`?o000000?oooooo`000?l0
00000_ooool2o`0000oooooo0_l0001[ooooo`007?ooool00ol0003oooooooooo`1^ooooo`?o0000
3Oooool2o`0000Kooooo0_l0000Cooooo`;o00003oooool2o`0000[ooooo0_l00002ooooo`;o0000
1_ooool5o`0000;ooooo0_l0001looooo`007?ooool00ol0003oooooooooo`1Zooooo`;o00000_oo
ool2o`0000[ooooo0_l0000:ooooo`;o00002_ooool2o`0000;ooooo0_l00003ooooo`;o00003ooo
ool2o`0000Gooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00006ooooo`?o00004Ooo
ool2o`0006oooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go0000
1_ooool00ol0003oooooooooo`1Zooooo`;o00001oooool2o`0000Gooooo0_l0000:ooooo`;o0000
2_ooool2o`0000;ooooo0_l000000ooooooo0000o`000009ooooo`;o00003Oooool2o`000003oooo
ool0003o000000cooooo0_l00008ooooo`;o00002?ooool2o`0006oooooo00001_ooooooMgMgoiRH
V?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0
003oooooooooo`1cooooo`;o00000oooool3o`0001Gooooo0_l00007ooooo`?o00002?ooool4o`00
00Cooooo0ol0000Aooooo`Co00002_ooool2o`0007Wooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`1hooooo`?o
00002Oooool2o`0000Kooooo0_l00002ooooo`;o00002?ooool2o`0000[ooooo0_l00002ooooo`Go
00001?ooool2o`0000_ooooo1?l000000ooooooo0000o`000002ooooo`;o00005oooool2o`0006Go
oooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h0
1_ooool3o`0007oooooo0ol00002ooooo`;o00001_ooool2o`0000_ooooo0_l0000?ooooo`;o0000
1oooool2o`0000?ooooo0_l00008ooooo`;o000000?oooooo`000?l000000_ooool2o`0001Oooooo
0_l0001Uooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomV
IVKooooo00Gooooo00?o0000ooooooooool0L?ooool2o`0000Wooooo0_l00002ooooo`Co00003ooo
ool2o`0000Gooooo0ol00006ooooo`;o00005?ooool2o`0000[ooooo0_l00009ooooo`;o0000N?oo
ool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool03Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo073ooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool2
o`0000Cooooo0_l0000?ooooo`;o00001_ooool2o`0000Kooooo0_l0000Pooooo`;o00002Oooool2
o`0007Sooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RH
oa0@4006ooooo`03o`000?oooooooooo07?ooooo0_l00002ooooo`;o00000oooool3o`0000kooooo
0_l00003ooooo`;o00003_ooool2o`0000cooooo0_l0000Iooooo`;o00006Oooool2o`00067ooooo
00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006oooo
o`03o`000?oooooooooo07Wooooo0_l000000ooooooo0000o`000002o`0000gooooo0_l0000<oooo
o`;o00001Oooool2o`0000?ooooo0_l00007ooooo`;o00004oooool2o`0000Cooooo0_l00008oooo
o`;o00003oooool2o`000003ooooool0003o000000?ooooo0_l0001Iooooo`007?ooool00ol0003o
ooooooooo`1iooooo`;o00000oooool2o`0000Wooooo0_l00005ooooo`;o000000?oooooo`000?l0
00000oooool2o`000003ooooool0003o000000?o00000_ooool2o`0000?ooooo1?l0000>ooooo`;o
00002_ooool2o`0000Oooooo0_l00005ooooo`;o00003oooool2o`000003ooooool0003o000000?o
oooo0_l0001Iooooo`007?ooool00ol0003oooooooooo`1`ooooo`;o00001Oooool2o`00013ooooo
0_l00005ooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo0ol00007ooooo`Co0000
1oooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00002oooool2o`0000;ooooo
1?l0001gooooo`007?ooool00ol0003oooooooooo`1Zooooo`;o00001?ooool2o`0000Gooooo0_l0
000?ooooo`;o00002?ooool4o`0000;ooooo0_l0000=ooooo`Co00001oooool2o`0000;ooooo0_l0
0005ooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`?o00001ooo
ool2o`0000;ooooo0_l0001Zooooo`007?ooool00ol0003oooooooooo`1Zooooo`;o00007?ooool2
o`000003ooooool0003o000000Gooooo1?l00002ooooo`;o00002_ooool4o`000003ooooool0003o
000001Kooooo0_l00004ooooo`;o00004?ooool6o`0006[ooooo000Looooo`03o`000?oooooooooo
05[ooooo0_l0000/ooooo`;o000000?oooooo`000?l000000ol00003ooooo`?o00003_ooool4o`00
00Kooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000005oooool2o`00
00Kooooo0ol00002ooooo`;o00003?ooool2o`0005Wooooo000Looooo`03o`000?oooooooooo05[o
oooo0_l0000Sooooo`;o00001oooool2o`000003ooooool0003o000000?o00000oooool5o`00017o
oooo0_l00003ooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000001Oo
oooo0_l00006ooooo`;o00000oooool2o`0000cooooo0_l0001Iooooo`007?ooool00ol0003ooooo
ooooo`1dooooo`Co00001oooool2o`0000Sooooo1Ol00005ooooo`;o000000?oooooo`000?l00000
1_ooool2o`0000;ooooo0_l00005ooooo`?o00004oooool2o`0000?ooooo0_l0000?ooooo`?o0000
1Oooool2o`0006[ooooo000Looooo`03o`000?oooooooooo07?ooooo1Ol0000Aooooo`;o000000?o
ooooo`000?l000004?ooool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000003Ooo
ool2o`0000Cooooo0_l00003ooooo`;o00003oooool3o`0000Gooooo0_l00006ooooo`;o0000H_oo
ool001cooooo00?o0000ooooooooool0IOooool2o`0000_ooooo0ol0000Booooo`;o00000oooool2
o`000003ooooool0003o000000Gooooo0_l00003ooooo`;o00002_ooool2o`000003ooooool0003o
000000gooooo0_l00007ooooo`;o00008Oooool2o`0006;ooooo000Looooo`03o`000?oooooooooo
06Gooooo0_l0000;ooooo`;o00004oooool2o`0000?ooooo0_l000000ooooooo0000o`000005oooo
o`;o00000oooool2o`0000Wooooo0_l00002ooooo`;o00001Oooool2o`0000cooooo0_l000000ooo
oooo0000o`00000Fooooo`;o0000KOooool001cooooo00?o0000ooooooooool0K_ooool4o`0001;o
oooo0_l00002ooooo`;o00001?ooool2o`0001Kooooo0ol00003ooooo`;o00000oooool3o`0000Co
oooo0_l00005ooooo`;o00002oooool3o`000003ooooool0003o000000Sooooo1?l0000Jooooo`;o
0000Coooool001cooooo0_l0001_ooooo`Co00004_ooool2o`000004ooooool0003o0000o`0000Co
oooo0_l0000Gooooo`;o00000oooool2o`0000Cooooo0_l00004ooooo`?o00001?ooool2o`0000Oo
oooo0_l00002ooooo`?o000000Coooooo`000?l0003o00001_ooool2o`000003ooooool0003o0000
00;o00001?ooool2o`0001;ooooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o
00002?ooool2o`0000Wooooo1?l00004ooooo`;o00005Oooool2o`0000Gooooo1?l00002ooooo`;o
00002Oooool2o`0001Sooooo0ol00003ooooo`;o00001oooool2o`0000?ooooo1_l00006ooooo`Co
000000?oooooo`000?l000000_l00002ooooo`;o0000Hoooool001cooooo00?o0000ooooooooool0
Doooool2o`0000Gooooo0_l000000ooooooo0000o`000003o`0000Kooooo1?l00004ooooo`;o0000
7_ooool2o`0000;ooooo0_l00009ooooo`?o00005oooool3o`0000Wooooo0_l00008ooooo`;o0000
2_ooool2o`0000;ooooo0ol0001Wooooo`007?ooool00ol0003oooooooooo`1Jooooo`;o00000ooo
ool3o`000003ooooool0003o000000;ooooo1?l00003ooooo`;o00002Oooool3o`0000cooooo0_l0
0003ooooo`;o00004?ooool5o`0000Cooooo0_l00005ooooo`Co00001_ooool2o`0000[ooooo0_l0
00000ooooooo0000o`000003ooooo`Ko00003Oooool2o`0000Oooooo0_l0001Nooooo`007?ooool0
0ol0003oooooooooo`1Sooooo`;o00000_ooool2o`0000Cooooo0ol00009ooooo`?o00003?ooool2
o`0000?ooooo0_l00004ooooo`;o00003?ooool3o`0000Cooooo0_l00005ooooo`Ko00004oooool2
o`0000?ooooo0_l00002ooooo`;o00003Oooool3o`0000Kooooo0_l0001Nooooo`007?ooool00ol0
003oooooooooo`1;ooooo`;o00005oooool2o`0000Oooooo0_l000000ooooooo0000o`00000;oooo
o`;o00005?ooool2o`0000Cooooo0_l0000Hooooo`Co00002Oooool2o`0001oooooo0_l0001Voooo
o`007?ooool00ol0003oooooooooo`1;ooooo`;o00002?ooool2o`0000gooooo1?l00002ooooo`;o
00000_ooool4o`0000_ooooo0_l0000Jooooo`;o00006_ooool2o`0000Cooooo0_l00003ooooo`;o
00001?ooool2o`0000_ooooo1?l0000@ooooo`Co00000oooool2o`0005Wooooo000Looooo`03o`00
0?oooooooooo05Gooooo0_l0000?ooooo`;o00000_ooool2o`0000;ooooo1?l00019ooooo`;o0000
2Oooool2o`0000_ooooo1?l0000:ooooo`?o00000oooool4o`0000?ooooo0_l0001Iooooo`007?oo
ool00ol0003oooooooooo`1Booooo`;o00001Oooool2o`0000;ooooo0ol00006ooooo`;o00002_oo
ool2o`0000?ooooo0_l00010ooooo`;o00001oooool3o`0000?ooooo0_l0000Gooooo`?o0000IOoo
ool001cooooo00?o0000ooooooooool0D_ooool2o`0000Gooooo0_l00002ooooo`?o00004_ooool2
o`000003ooooool0003o000000;o0000>Oooool2o`0000Gooooo0_l00007ooooo`?o00000oooool2
o`0000_ooooo0_l0000:ooooo`?o00002Oooool2o`0005[ooooo000Looooo`03o`000?oooooooooo
05cooooo0_l0000Gooooo`;o00002oooool2o`0002kooooo0_l0000Eooooo`;o00002_ooool2o`00
00[ooooo0ol00009ooooo`;o0000F_ooool001cooooo00?o0000ooooooooool0F_ooool4o`0000Oo
oooo0_l00005ooooo`;o00005?ooool2o`0002kooooo0_l00005ooooo`;o00003_ooool2o`0001[o
oooo1?l0001Pooooo`007?ooool00ol0003oooooooooo`1?ooooo`;o00001_ooool2o`000003oooo
ool0003o000000Wooooo0_l00005ooooo`;o000000?oooooo`000?l000001_ooool2o`0003Wooooo
0_l00004ooooo`?o000000?oooooo`000?l000002_ooool2o`000003ooooool0003o000000cooooo
0_l00005ooooo`;o00000oooool4o`00063ooooo000Looooo`03o`000?oooooooooo04oooooo0ol0
0005ooooo`;o00002oooool2o`0000Gooooo0ol000000ooooooo0000o`000002ooooo`;o00000_oo
ool2o`0003cooooo0_l000000ooooooo0000o`000002ooooo`;o00002_ooool2o`000003ooooool0
003o000000cooooo0_l00005ooooo`;o0000Ioooool001cooooo00?o0000ooooooooool0Coooool3
o`0000;ooooo0_l00004ooooo`;o00002?ooool2o`0000Gooooo0ol000000ooooooo0000o`000002
ooooo`;o00001?ooool2o`0000_ooooo1?l0000Qooooo`;o00002?ooool3o`0001?ooooo0_l0000>
ooooo`;o000000?oooooo`000?l000002_ooool2o`0000?ooooo0_l00002ooooo`;o0000E?ooool0
01cooooo00?o0000ooooooooool0COooool4o`0000?ooooo0_l00004ooooo`;o00002?ooool2o`00
01;ooooo0ol000000ooooooo0000o`000008ooooo`Co00008Oooool2o`0000Wooooo0ol00006oooo
o`;o00002_ooool2o`0000Gooooo0_l00007ooooo`;o000000Coooooo`000?l0003o00002Oooool2
o`0000?ooooo0_l00002ooooo`;o00004Oooool2o`00047ooooo000Looooo`;o0000C_ooool2o`00
00Gooooo0_l00003ooooo`;o00007Oooool2o`0000;ooooo0_l00005ooooo`;o0000<_ooool2o`00
00Kooooo0_l0000@ooooo`?o00002oooool2o`0000_ooooo0_l0000Hooooo`;o0000@Oooool001co
oooo00?o0000ooooooooool0Boooool2o`0000Kooooo0ol00003ooooo`;o00001_ooool2o`0000;o
oooo0_l00005ooooo`Co00000_ooool2o`000003ooooool0003o000000cooooo0_l0000Vooooo`;o
00000oooool2o`0001oooooo0_l0000Iooooo`;o0000Foooool001cooooo00?o0000ooooooooool0
??ooool2o`0000gooooo0_l00006ooooo`;o00003?ooool2o`0000;ooooo0_l00005ooooo`Go0000
00Coooooo`000?l0003ooooo0_l0000Dooooo`;o00007_ooool2o`0000?ooooo0_l0000/ooooo`;o
00000oooool2o`0000Kooooo0_l0001Looooo`007?ooool00ol0003oooooooooo`0looooo`;o0000
1_ooool2o`0000kooooo0_l00005ooooo`;o00004_ooool2o`0001Sooooo1?l0000Xooooo`;o0000
6oooool2o`0000?ooooo0_l00005ooooo`;o00000oooool2o`0000Kooooo1?l000000ooooooo0000
o`00001Gooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00003_ooool2o`0000Gooooo1?l0
000Iooooo`;o00003oooool2o`0002[ooooo0_l00004ooooo`;o00001Oooool2o`0000Oooooo0_l0
0005ooooo`;o00000oooool2o`0000Cooooo0_l000000ooooooo0000o`000007ooooo`Ko000000?o
ooooo`000?l000000oooool2o`0005;ooooo000Looooo`03o`000?oooooooooo047ooooo0_l0000H
ooooo`Co000000?oooooo`000?l000004oooool2o`000003ooooool0003o000000Cooooo0_l0000a
ooooo`;o00001Oooool2o`000003ooooool0003o000000Cooooo0ol00005ooooo`Co00001_ooool2
o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l000001oooool3o`000003ooooool0003o
000000;ooooo0ol000000ooooooo0000o`00001Booooo`007?ooool00ol0003oooooooooo`11oooo
o`;o00001Oooool2o`0000kooooo0_l000000ooooooo0000o`000003ooooo`;o00001Oooool2o`00
00cooooo0_l000000ooooooo0000o`000004ooooo`;o0000<Oooool2o`0000Gooooo0_l00007oooo
o`;o00001?ooool4o`0000;ooooo0_l00004ooooo`;o00007?ooool3o`000004ooooool0003o0000
o`00057ooooo000Looooo`03o`000?oooooooooo04Sooooo0_l0000>ooooo`;o00003Oooool3o`00
00Sooooo0_l00004ooooo`;o0000>?ooool2o`000003ooooool0003o000000;ooooo0_l00008oooo
o`;o00000_ooool3o`0000?ooooo0_l0000Hooooo`;o00000_ooool2o`0000Cooooo0_l00003oooo
o`;o0000DOooool001cooooo00?o0000ooooooooool0I_ooool4o`0000;ooooo1?l00002ooooo`;o
00003oooool2o`0001_ooooo0_l00003ooooo`;o00002oooool2o`000005ooooool0003o0000o`00
0?ooool00_l00008ooooo`;o00000oooool2o`0000kooooo0_l0000=ooooo`;o00000_ooool2o`00
00?ooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00001Oooool3o`0000Wo
oooo0_l00004ooooo`Ko00001oooool2o`0000Sooooo0_l00009ooooo`;o00003_ooool4o`0000?o
oooo0_l0000?ooooo`;o00000oooool2o`0000Oooooo0_l00007ooooo`;o00002Oooool2o`0000ko
oooo0_l00006ooooo`;o0000Eoooool001cooooo00?o0000ooooooooool0Doooool3o`0000Cooooo
0ol00009ooooo`;o00001Oooool2o`000003ooooool0003o000000?ooooo1_l00002ooooo`;o0000
1?ooool2o`0000Wooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00001_ooool4o`00013o
oooo1_l00002ooooo`Go000000?oooooo`000?l000000_ooool2o`0000Kooooo0ol00004ooooo`Co
00004Oooool2o`0005oooooo000Looooo`03o`000?oooooooooo05Cooooo0_l0000Booooo`Co0000
00Coooooo`000?l0003ooooo0_l00002ooooo`Ko000000?oooooo`000?l000000_l00004ooooo`;o
00000_ooool2o`000003ooooool0003o000000Gooooo0ol00002ooooo`Go00003oooool2o`0000Ko
oooo1_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l00006ooooo`Ko00001Oooool4o`00
00;ooooo0_l0000=ooooo`;o00001_ooool2o`0001kooooo0_l0000gooooo`007?ooool00ol0003o
ooooooooo`1:ooooo`;o00000_ooool2o`0000;ooooo1?l00007ooooo`;o00001_ooool2o`000003
ooooool0003o000000;o00001?ooool2o`0000;ooooo1_l000001?oooooo0000o`000?l00004oooo
o`[o00003?ooool3o`0000oooooo0_l00005ooooo`Go00002_ooool2o`0000Kooooo1Ol00006oooo
o`Co00000_ooool2o`0000gooooo0_l00006ooooo`?o000000Coooooo`000?l0003ooooo0_l0000G
ooooo`;o0000=oooool001cooooo00?o0000ooooooooool0A_ooool2o`0000;ooooo0_l00002oooo
o`;o00000_ooool4o`0000Oooooo0_l00006ooooo`;o00002?ooool2o`0000;ooooo1_l000000ooo
oooo0000o`000003o`0000;ooooo2Ol0000Booooo`?o00003?ooool2o`0000Cooooo0ol00005oooo
o`;o00001Oooool3o`0000Sooooo0_l00006ooooo`;o00006_ooool4o`000004ooooool0003o0000
ooooo`;o0000D?ooool001cooooo00?o0000ooooooooool0AOooool3o`0000?ooooo0_l00009oooo
o`;o00004_ooool2o`000003ooooool0003o0000017o000000?oooooo`000?l000000_l00002oooo
o`;o000000?oooooo`000?l000002?ooool2o`0000Kooooo0ol0000<ooooo`;o00000oooool3o`00
00;ooooo1_l00004ooooo`Go00008Oooool2o`0000;ooooo0_l00004ooooo`Co00000_ooool2o`00
00;ooooo1?l0001<ooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00001?ooool2o`0000Co
oooo0_l00003ooooo`Ko00003_ooool>o`000003ooooool0003o000000Wo00001_ooool2o`0000So
oooo1_l00003ooooo`;o00001oooool2o`0000Sooooo0_l00003ooooo`Oo00000oooool2o`000003
ooooool0003o0000027ooooo0_l00002ooooo`;o00002_ooool2o`0000;ooooo1?l0001<ooooo`00
7?ooool2o`0004Wooooo0_l00005ooooo`Co00001?ooool5o`0000Cooooo1?l00007ooooo`Co0000
00Coooooo`000?l0003ooooo2ol00002ooooo`Co00000_ooool3o`0000;ooooo0_l00002ooooo`;o
000000?oooooo`000?l000000_ooool4o`0000cooooo0ol00003ooooo`;o00001?ooool2o`000003
ooooool0003o000000;o000000?oooooo`000?l000000oooool;o`0000oooooo0_l0000Oooooo`;o
0000COooool001cooooo00?o0000ooooooooool0B?ooool2o`0000;ooooo0_l000000ooooooo0000
o`000006ooooo`;o00001oooool4o`0000Gooooo2Ol000000ooooooo0000o`00000@o`000005oooo
ool0003o0000o`000?ooool00ol00002ooooo`Go00001?ooool5o`0000Wooooo0ol00003ooooo`;o
00001?ooool2o`000003ooooool0003o000000;o00001Oooool>o`0000gooooo0_l0000Oooooo`;o
0000COooool001cooooo00?o0000ooooooooool0Aoooool2o`0000?ooooo0_l0000=ooooo`?o0000
0oooool2o`0000Kooooo8?l000001?oooooo0000o`000?l00003ooooo`;o00000oooool2o`000003
ooooool0003o000000?o00001?ooool4o`000003ooooool0003o000000;ooooo0_l00006ooooo`?o
00001?ooool2o`000003ooooool0003o000000Go00001Oooool7o`0001oooooo0_l0001Iooooo`00
7?ooool00ol0003oooooooooo`17ooooo`;o00000_ooool2o`0000kooooo0ol000000ooooooo0000
o`000006ooooob3o00001?ooool2o`0000Sooooo0_l000000ooooooo0000o`000003ooooo`;o0000
0_ooool4o`0000Gooooo0_l000000ooooooo0000o`000002o`000004ooooool0003o0000o`0000Co
oooo0_l000000ooooooo0000o`000002ooooo`Co00001oooool6o`0000?ooooo0_l0000Eooooo`;o
000000?oooooo`000?l000003_ooool2o`0004Wooooo000Looooo`03o`000?oooooooooo04_ooooo
0_l00002ooooo`;o00002oooool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000
o`00000Lo`0001Sooooo0_l00004ooooo`;o00002?ooool4o`000004ooooool0003o0000o`0000Co
oooo0_l000000ooooooo0000o`000002ooooo`Go00002?ooool4o`0000?ooooo0_l00005ooooo`Go
00001Oooool2o`0000?ooooo0ol0000?ooooo`Co0000BOooool001cooooo00?o0000ooooooooool0
BOooool2o`0000Cooooo0_l0000Cooooo`;o00000ooooolLo`0000?ooooo1?l0000Dooooo`Go0000
1_ooool2o`0000Kooooo1ol00006ooooo`Oo00001_ooool2o`0000;ooooo0_l00008ooooo`Go0000
0oooool5o`0000;ooooo0_l00006ooooo`;o00001_ooool6o`0004Wooooo000Looooo`03o`000?oo
oooooooo04Wooooo0_l0000Fooooo`Co00001?ooool<o`0000;ooooo5Ol00002ooooo`;o00000ooo
ool2o`0000_ooooo1Ol00003ooooo`;o000000Coooooo`000?l0003ooooo1?l00003oooooaOo0000
00?oooooo`000?l000000_ooool2o`00013ooooo0_l000000ooooooo0000o`000002ooooo`;o0000
1_ooool3o`0000Gooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`1Qooooo`Co000000Co
ooooo`000?l0003ooooo8_l00003ooooo`;o00000oooool4o`0000Kooooo0_l00004ooooo`;o0000
0oooool2o`0000Cooooo6?l000000ooooooo0000o`000003o`000004ooooool0003o0000ooooo`;o
00000oooool2o`000003ooooool0003o000000Gooooo0_l0000>ooooo`;o000000Coooooo`000?l0
003o00000_ooool2o`0000Gooooo0ol00018ooooo`007?ooool00ol0003oooooooooo`0eooooo`;o
00006oooool2o`0000kooooo1_l00003ooooo`Go000000?oooooo`000?l000001ol000000ooooooo
0000o`000008o`000003ooooool0003o000000?ooooo0_l00007ooooo`Go00001?ooool2o`0000_o
oooo0_l000000ooooooo0000o`000002oooooa_o000000Coooooo`000?l0003ooooo0_l00003oooo
o`;o000000?oooooo`000?l000001Oooool2o`0000Gooooo0_l00007ooooo`;o000000?oooooo`00
0?l000000oooool2o`0000Gooooo0ol00018ooooo`007?ooool00ol0003oooooooooo`0eooooo`;o
00004_ooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`000003ooooool0003o000000;o
oooo0_l000000ooooooo0000o`00000Eo`000003ooooool0003o000000?ooooo0_l0000:ooooo`;o
00001_ooool2o`0000Cooooo0_l00002ooooobSo00001?ooool2o`0000Sooooo0_l00003ooooo`Co
0000HOooool001cooooo00?o0000ooooooooool0BOooool2o`0000cooooo0_l00002ooooo`;o0000
2_ooool2o`0000Gooooo7?l0000Dooooo`Go000000?oooooo`000?l000001Ol000000ooooooo0000
o`000003o`000003ooooool0003o000001Oo000000Coooooo`000?l0003ooooo0_l0000>ooooo`;o
00000oooool4o`00067ooooo000Looooo`03o`000?oooooooooo03oooooo0_l00008ooooo`;o0000
1?ooool2o`0000Kooooo0_l0000Aooooo`;o000000Coooooo`000?l0003o00000ooooolCo`000003
ooooool0003o000000;o00000_ooool2o`000003ooooool0003o000000Gooooo0_l00004ooooo`?o
000000Coooooo`000?l0003ooooo1ol00007ooooo`Co000000?oooooo`000?l000003ol000000ooo
oooo0000o`000003o`0000kooooo0_l00004ooooo`;o00000_ooool4o`0000Cooooo0_l0000>oooo
o`;o00006_ooool2o`0002gooooo000Looooo`03o`000?oooooooooo03oooooo0_l0000<ooooo`Co
000000?oooooo`000?l000001_ooool2o`000003ooooool0003o000000_ooooo8Ol00002ooooo`;o
000000?oooooo`000?l000001Oooool5o`000004ooooool0003o0000ooooo`;o000000?oooooo`00
0?l000002Ol000000ooooooo0000o`00000Mo`0000?ooooo0_l00009ooooo`;o00001?ooool2o`00
00Cooooo0_l00004ooooo`;o00003_ooool2o`0001[ooooo0_l0000]ooooo`007?ooool00ol0003o
ooooooooo`13ooooo`;o00000oooool2o`0000?ooooo0ol00002ooooo`;o00001_ooool2o`000004
ooooool0003o0000ooooo`;o00001ooooolQo`0000?ooooo0_l00007ooooo`Ko00001?oooolTo`00
00;ooooo1?l000001?oooooo0000o`000?l00003ooooo`;o00008oooool2o`0000Kooooo0_l00019
ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo00Cooooo00?o0000ooooooooool0@oooool3o`0000;ooooo1?l000001Ooooooo0000o`00
0?l0003ooooo00;o00003Oooool2o`0000Gooooo1?l000000ooooooo0000o`00000Lo`0000?ooooo
0_l00007ooooo`;o00002_ooool3o`0000;ooooo1Ol00002oooooaco000000?oooooo`000?l00000
2_ooool2o`0001gooooo0_l00002ooooo`;o00001_ooool3o`0004Cooooo00001_ooooooMgMgoiRH
V?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0=Oooool2o`0000cooooo0ol00004ooooo`;o000000?oooooo`000?l000000_ooool2o`0001Co
oooo0_l00002oooooa[o000000?oooooo`000?l000003_ooool2o`0000_ooooo0_l000000ooooooo
0000o`000004o`000003ooooool0003o0000023o000000Coooooo`000?l0003o00001?ooool2o`00
00Wooooo1_l00003ooooo`;o00001oooool2o`0000Cooooo0_l000000ooooooo0000o`000003oooo
o`?o0000A?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool5o`0000Ko
oooo00?o0000ooooooooool0=Oooool2o`0000Kooooo0_l00004ooooo`;o00009_oooolMo`0000ko
oooo0_l00009ooooo`?o00000_oooolUo`000005ooooool0003o0000o`000?ooool00ol0000<oooo
o`;o000000?oooooo`000?l000001?l00003ooooo`;o00001?ooool2o`000003ooooool0003o0000
00;ooooo0_l00002ooooo`?o00000oooool2o`0004Gooooo00000ooooooo0000ooooo`02ooooo`03
o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`0003gooooo0_l0000Aoooo
o`;o00004Oooool2o`0000Wooooo0_l000000ooooooo0000o`00000Eo`0000Wooooo0_l0000<oooo
o`Oo000000?oooooo`000?l000007?l000001?oooooo0000o`000?l00002ooooo`Go00003oooool2
o`000003ooooool0003o000000?ooooo0_l00005ooooo`;o000000?oooooo`000?l000001Oooool2
o`0000;ooooo0_l00005ooooo`;o0000A?ooool00003ooooool0003ooooo00;ooooo00?o0000oooo
ooooool02Oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo04?ooooo1?l00008
ooooo`?o00004Oooool2o`0000;ooooo0_l00007oooooaKo000000?oooooo`000?l000001oooool3
o`0000cooooo0_l00003ooooo`Go000000?oooooo`000?l000007_l000000ooooooo0000o`000006
o`0000oooooo0_l00003ooooo`?o00001?ooool2o`0000cooooo0_l000000ooooooo0000o`000002
ooooo`;o00006oooool2o`0002Oooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo
00[ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`13ooooo`Co00001Oooool2o`00
0003ooooool0003o000001Kooooo0_l000000ooooooo0000o`00000<o`000003ooooool0003o0000
00_o000000?oooooo`000?l000001oooool2o`0000?ooooo0_l00004ooooo`?o00000_ooool2o`00
00;ooooo9_l000000ooooooo0000o`000002o`000004ooooool0003o0000o`0001Gooooo0_l00004
ooooo`;o00003oooool2o`000003ooooool0003o000001cooooo0_l0000Wooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0?_oo
ool2o`0000?ooooo0ol00006ooooo`;o00004_ooool2o`0000Sooooo1ol000000ooooooo0000o`00
0006o`000003ooooool0003o000000[o00003Oooool3o`0000;ooooo1Ol00002ooooo`;o000000?o
ooooo`000?l00000:ol00004ooooo`;o00006?ooool2o`0001;ooooo0ol00014ooooo`0000Kooooo
onk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0
??ooool4o`0000?ooooo0ol0000@ooooo`;o00002?ooool2o`0000Oooooo1?l000001?oooooo0000
o`000?oooolFo`0000gooooo1?l000000ooooooo0000o`000008ooooobgo00001?ooool2o`0001Co
oooo0_l00002ooooo`;o00004oooool3o`0004?ooooo000Looooo`03o`000?oooooooooo03Kooooo
0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000002o`0000go
oooo1?l0000?ooooo`oo000000?oooooo`000?l000001ol000000ooooooo0000o`000002o`0000oo
oooo0_l00005ooooo`?o00001OoooolVo`0000?ooooo1Ol000000ooooooo0000o`00000Dooooo`;o
00000_ooool2o`0000oooooo0_l000000ooooooo0000o`000004o`0000?ooooo0_l0000looooo`00
7?ooool00ol0003oooooooooo`0fooooo`;o00001?ooool5o`000004ooooool0003o0000ooooo`Co
00003Oooool6o`0000kooooo0_l000000ooooooo0000o`000009o`000003ooooool0003o000000Go
00000oooool4o`0000Kooooo0_l0000>ooooo`Go00000ooooolWo`000003ooooool0003o000000Oo
00004_ooool2o`0000Sooooo0_l000000ooooooo0000o`000008ooooo`;o000000?oooooo`000?l0
00000_ooool2o`0000?ooooo0_l0000looooo`007?ooool00ol0003oooooooooo`0nooooo`;o0000
5_ooool2o`0000;ooooo0_l0000Fooooo`Go00000_ooool2o`000003ooooool0003o000000;o0000
0oooool2o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000003_ooool2o`0000Kooooo
4?l000000ooooooo0000o`00000Ao`000003ooooool0003o000000Go00000oooool2o`0000oooooo
0_l00008ooooo`;o000000Coooooo`000?l0003ooooo0_l0000=ooooo`;o0000@?ooool001cooooo
00?o0000ooooooooool0F_ooool2o`0001;ooooo0_l000000ooooooo0000o`000004ooooo`Co0000
00?oooooo`000?l000000ol00007ooooo`;o00001_ooool2o`000004ooooool0003o0000ooooo`;o
00002?ooool2o`0000Kooooo3ol000000ooooooo0000o`00000@o`0000?ooooo0_l000000ooooooo
0000o`000005ooooo`Co00001_ooool2o`0000Cooooo0ol00002ooooo`;o00002_ooool2o`0000?o
oooo0_l00006ooooo`Go0000?oooool001cooooo00?o0000ooooooooool0C?ooool2o`00023ooooo
0_l000000ooooooo0000o`000004ooooo`Co000000Coooooo`000?l0003ooooo0_l0000?ooooo`;o
000000Coooooo`000?l0003ooooo0_l00008ooooo`;o000000Coooooo`000?l0003ooooo9Ol00000
1Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`000?l000001?ooool2o`0000?ooooo0_l0
00000ooooooo0000o`000004ooooo`?o00000_ooool2o`0000oooooo0_l00005ooooo`?o000000?o
ooooo`000?l00000?oooool001cooooo00?o0000ooooooooool0=_ooool2o`0001;ooooo1?l00007
ooooo`;o00002oooool2o`0000[ooooo0ol00002ooooo`;o00000oooool2o`0000gooooo0_l0000J
ooooo`;o000000?oooooo`000?l000008ol000000ooooooo0000o`000005ooooo`;o00002Oooool2
o`0000Gooooo0_l00002ooooo`;o00001?ooool2o`0000;ooooo0ol00007ooooo`Co00000oooool2
o`000003ooooool0003o000000;ooooo0_l0000looooo`007?ooool00ol0003oooooooooo`0eoooo
o`?o00001_ooool2o`0000Sooooo1?l00009ooooo`;o00002oooool2o`0000Gooooo0_l00004oooo
o`Ko00001Oooool2o`0000_ooooo0_l00002ooooo`;o00003oooool2o`0000Sooooo8Ol000000ooo
oooo0000o`000003o`0001Sooooo0_l00002ooooo`;o00001?ooool2o`0000;ooooo0ol00004oooo
o`;o00000oooool3o`0000Gooooo0_l00002ooooo`;o00002oooool2o`0002oooooo000Looooo`03
o`000?oooooooooo03Gooooo0_l000000ooooooo0000o`000002ooooo`Co00002?ooool2o`0001oo
oooo0_l00006ooooo`;o00001oooool2o`0000;ooooo0_l0000;ooooo`;o00003oooool2o`0000Go
oooo9?l000000ooooooo0000o`000004o`0000Oooooo0_l0000Sooooo`;o00001?ooool2o`0000So
oooo0_l0000<ooooo`;o0000;oooool001cooooo00?o0000ooooooooool0<oooool2o`0000?ooooo
0_l00002ooooo`?o00000_ooool2o`0000Kooooo0_l0000Aooooo`?o00007oooool4o`000003oooo
ool0003o000001Gooooo0_l00005ooooo`Oo000000?oooooo`000?l000005Ol000000ooooooo0000
o`00000;o`0000;ooooo0_l00003ooooo`Go00002oooool2o`0000Sooooo1?l00004ooooo`;o0000
00?oooooo`000?l000003_ooool2o`0003gooooo000Looooo`03o`000?oooooooooo03?ooooo0_l0
0006ooooo`Co00000_ooool2o`0000Kooooo0_l0000:ooooo`Go00000_ooool3o`0001Oooooo0_l0
00000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o00000_oo
ool2o`0000Wooooo0_l00004ooooo`Co000000Goooooo`000?l0003o0000ooooo`0Go`000003oooo
ool0003o000000Oo00001?ooool7o`0000;ooooo1Ol00009ooooo`;o00001?ooool2o`0000;ooooo
1?l00004ooooo`;o000000?oooooo`000?l000002_ooool4o`0003oooooo000Looooo`03o`000?oo
oooooooo03Sooooo0_l000000ooooooo0000o`000002ooooo`Co00000_ooool2o`0000kooooo1Ol0
0005ooooo`;o00005Oooool2o`000003ooooool0003o000000Gooooo0_l00002ooooo`?o00001?oo
ool2o`0000;ooooo0_l00009ooooo`;o00000_ooool5o`0000Cooooo8_l00005ooooo`;o00000_oo
ool3o`0000Gooooo0ol00009ooooo`;o00000oooool4o`0000Wooooo0_l0000<ooooo`Go00000_oo
ool2o`0003[ooooo000Looooo`;o0000>Oooool2o`000003ooooool0003o000000;ooooo1?l00002
ooooo`;o00003oooool2o`0000?ooooo0_l00002ooooo`Co000000?oooooo`000?l000002_ooool2
o`0000kooooo0_l00002ooooo`;o00006?ooool2o`0000?ooooo9_l0000Booooo`;o00001oooool4
o`0000Gooooo0_l00004ooooo`;o00000oooool2o`0000oooooo0_l00002ooooo`;o0000>_ooool0
01cooooo00?o0000ooooooooool0;_ooool2o`0000Oooooo0_l00009ooooo`;o00003oooool2o`00
00Kooooo0_l00004ooooo`;o000000?oooooo`000?l000000oooool2o`0000Gooooo1?l0000Doooo
o`;o00002oooool2o`000003ooooool0003o000000Wooooo1_l000000ooooooo0000o`00000Mo`00
00Gooooo0ol00004ooooo`;o00003Oooool2o`0000gooooo0_l00004ooooo`;o00002oooool2o`00
00Cooooo1?l0000iooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00001oooool2o`0000Oo
oooo1ol0000<ooooo`;o00001_ooool2o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`;o
00001oooool2o`0000Kooooo0_l0000<ooooo`;o00002oooool2o`000003ooooool0003o000000;o
00001?ooool4o`0000;ooooo0_l000000ooooooo0000o`00000Qo`0000;ooooo0ol000001?oooooo
0000o`000?ooool2o`0001cooooo0ol00003ooooo`;o00001Oooool2o`0000Cooooo0_l000001?oo
oooo0000o`000?ooool4o`0003Wooooo000Looooo`03o`000?oooooooooo03gooooo0_l000001?oo
oooo0000o`000?ooool4o`000003ooooool0003o000000?o00001_ooool2o`000004ooooool0003o
0000o`0000;ooooo0_l00007ooooo`;o00005?ooool2o`0000Kooooo0_l0000:ooooo`;o00001_oo
ool2o`0000;ooooo0_l00004ooooo`Oo000000?oooooo`000?l000001?l000000ooooooo0000o`00
000@o`000003ooooool0003o000000?o000000?oooooo`000?l000001_l00002ooooo`;o00001?oo
ool2o`0001[ooooo0_l0000:ooooo`;o00001oooool3o`0003gooooo000Looooo`03o`000?oooooo
oooo03gooooo0_l00009ooooo`Go00001_ooool2o`000004ooooool0003o0000o`0000Gooooo0_l0
000Fooooo`;o00001oooool2o`000003ooooool0003o000000[ooooo0_l00006ooooo`;o00002?oo
ool:o`0000;ooooo0_l00002ooooo`go000000?oooooo`000?l000002?l00002ooooo`Ko00001Ooo
ool2o`000003ooooool0003o000001_ooooo0_l00002ooooo`Go00001Oooool2o`0000Gooooo1?l0
000kooooo`007?ooool00ol0003oooooooooo`17ooooo`?o000000?oooooo`000?l000000_ooool2
o`0000Kooooo0_l00005ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Sooooo0_l00000
0ooooooo0000o`000004ooooo`;o00003?ooool2o`0000kooooo0_l00005ooooo`Ko00000_ooool2
o`000003ooooool0003o000001Oo00000_ooool5o`0000Kooooo0_l00005ooooo`;o00004oooool2
o`0000;ooooo0_l00002ooooo`Go00000_ooool2o`000003ooooool0003o000000Oooooo0_l0000I
ooooo`;o00008?ooool001cooooo00?o0000ooooooooool0<_ooool2o`0000[ooooo0_l00007oooo
o`?o000000?oooooo`000?l000001?l00006ooooo`;o00002?ooool2o`0000Wooooo0_l00003oooo
o`;o00001_ooool2o`0001;ooooo1?l0000<ooooo`;o00001_ooool2o`0000?ooooo4?l000000ooo
oooo0000o`00000:o`0000?ooooo0ol00007ooooo`;o00001_ooool2o`0001?ooooo0_l00003oooo
o`;o00002?ooool2o`0002Gooooo0_l0000Pooooo`007?ooool00ol0003oooooooooo`0booooo`;o
00000oooool2o`0000Gooooo0_l0000:ooooo`;o000000?oooooo`000?l000000_ooool2o`000004
ooooool0003o0000o`0000Cooooo0_l00003ooooo`;o00000_ooool2o`0000_ooooo0_l0000<oooo
o`Go00002?ooool5o`0000;ooooo0_l0000;ooooo`Co000000?oooooo`000?l000000oooool5o`00
0003ooooool0003o000000So000000?oooooo`000?l000000_l000000ooooooo0000o`000003o`00
0003ooooool0003o000000;ooooo0ol00004ooooo`;o000000?oooooo`000?l000003?ooool2o`00
00Wooooo0_l00002ooooo`;o00000oooool2o`0000Sooooo0_l00009ooooo`;o0000??ooool001co
oooo00?o0000ooooooooool0=oooool2o`00017ooooo0_l000000ooooooo0000o`000002ooooo`;o
000000?oooooo`000?l000000_l00003ooooo`;o00000oooool2o`0000;ooooo0_l000000ooooooo
0000o`000007ooooo`;o00002?ooool2o`0000?ooooo1Ol00008ooooo`?o000000?oooooo`000?l0
00000ol0000;ooooo`Co00000oooool2o`0000Cooooo0_l00002ooooo`Co00000_ooool4o`000003
ooooool0003o000000;ooooo0ol000000ooooooo0000o`000002o`0000Cooooo0ol00002ooooo`;o
00002?ooool2o`0000Gooooo0_l000000ooooooo0000o`000006ooooo`;o00000_ooool2o`0000go
oooo0_l00004ooooo`Co000000?oooooo`000?l00000??ooool001cooooo00?o0000ooooooooool0
??ooool4o`0000gooooo0_l000000ooooooo0000o`000004ooooo`;o00002_ooool2o`0000?ooooo
0_l00007ooooo`Co00001_ooool2o`0000Wooooo0_l00009ooooo`So00003oooool3o`0000?ooooo
0_l00002ooooo`Co000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000005o`000004
ooooool0003o0000o`0000Gooooo0ol0000<ooooo`;o00002?ooool2o`0000Kooooo0_l0000Goooo
o`Co000000Coooooo`000?l0003o0000>oooool001cooooo00?o0000ooooooooool0;oooool3o`00
00[ooooo1?l00009ooooo`;o00001Oooool2o`0000?ooooo0_l0000;ooooo`;o00003_ooool2o`00
017ooooo0_l0000:ooooo`Oo00002oooool2o`0000?ooooo0ol00005ooooo`Go000000?oooooo`00
0?l000001Oooool7o`000003ooooool0003o000001gooooo0_l00007ooooo`;o00001Oooool2o`00
01Gooooo0ol00006ooooo`;o0000<oooool001cooooo00?o0000ooooooooool0;oooool3o`0000Ko
oooo0_l00009ooooo`;o00001?ooool2o`0000[ooooo0ol00003ooooo`;o00001Oooool2o`0000So
oooo0_l0000?ooooo`;o00002_ooool2o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`;o
00002oooool4o`000003ooooool0003o000000;o000000Coooooo`000?l0003ooooo1Ol00002oooo
o`;o000000?oooooo`000?l000000oooool5o`00023ooooo0_l00008ooooo`;o00001?ooool2o`00
00kooooo0_l00002ooooo`;o000000?oooooo`000?l000001oooool2o`0003?ooooo000Looooo`03
o`000?oooooooooo03Sooooo0_l00009ooooo`;o00003Oooool2o`0000;ooooo0_l00003ooooo`Co
00003Oooool2o`0000oooooo0_l00002ooooo`;o00001_ooool2o`0000?ooooo0_l0000>ooooo`;o
00000_ooool2o`000004ooooool0003o0000ooooo`Co000000?oooooo`000?l000000_ooool4o`00
00;ooooo3Ol0000Gooooo`;o00001_ooool3o`0000Gooooo1Ol000001?oooooo0000o`000?ooool2
o`0000kooooo0_l00002ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0;oooool2o`00
01;ooooo0_l0000=ooooo`;o000000?oooooo`000?l000001?ooool4o`0000?ooooo0_l0000=oooo
o`;o00003_ooool2o`0001_ooooo0_l000001?oooooo0000o`000?l00007ooooo`;o00001?ooool3
o`0000Cooooo0_l00002ooooo`Co00006oooool3o`000003ooooool0003o000000;ooooo0_l00006
ooooo`Co00000_ooool2o`000003ooooool0003o000000_ooooo0_l0000Tooooo`;o00008?ooool0
01cooooo00?o0000ooooooooool0;oooool2o`0000Wooooo0_l00007ooooo`;o00000_ooool2o`00
00;ooooo0_l00008ooooo`;o00001?ooool2o`0000Gooooo0_l00002ooooo`;o00002Oooool2o`00
01_ooooo0_l0000Aooooo`;o00002?ooool3o`0000Cooooo0ol00007ooooo`?o00002Oooool2o`00
00Cooooo0_l000000ooooooo0000o`000003ooooo`;o00001?ooool2o`000004ooooool0003o0000
ooooo`;o00004oooool2o`0000Cooooo0_l000001?oooooo0000o`000?l00003ooooo`;o00000_oo
ool2o`0001_ooooo0_l0000Pooooo`007?ooool00ol0003oooooooooo`0jooooo`;o00001oooool2
o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0000Sooooo0_l0000:ooooo`;o00000_ooool2
o`0000?ooooo0_l0000Mooooo`;o00001_ooool4o`0000Kooooo1?l00008ooooo`?o00001?ooool2
o`0000Kooooo0ol0000:ooooo`?o00000oooool2o`000004ooooool0003o0000ooooo`Co00001ooo
ool2o`000004ooooool0003o0000o`0000oooooo0_l000000ooooooo0000o`000004ooooo`;o0000
00?oooooo`000?l000001?ooool2o`0000;ooooo0_l0000mooooo`007?ooool2o`0004Sooooo0ol0
0006ooooo`;o00000_ooool2o`0000;ooooo1?l0000<ooooo`Wo00000_ooool2o`0001?ooooo0_l0
000<ooooo`Co00001_ooool4o`0000Wooooo0_l00006ooooo`;o00000oooool4o`000003ooooool0
003o000000Kooooo1_l00007ooooo`;o00002Oooool6o`0000oooooo0_l00004ooooo`;o00002_oo
ool2o`0000Gooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00001Oooool3
o`0000[ooooo0_l00002ooooo`;o00000_ooool2o`0000Cooooo3Ol000000ooooooo0000o`000003
o`0000kooooo0_l00003ooooo`;o000000?oooooo`000?l000001Oooool2o`0000;ooooo0ol0000L
ooooo`;o00000oooool2o`0000?ooooo0_l00006ooooo`;o00000_ooool2o`0000[ooooo0_l00000
0ooooooo0000o`000005ooooo`?o00005_ooool2o`0000;ooooo0_l00004ooooo`Co00000oooool4
o`0003[ooooo000Looooo`03o`000?oooooooooo03kooooo1?l00006ooooo`;o00002?ooool2o`00
00Sooooo0_l000001?oooooo0000o`000?oooolAo`00013ooooo0_l00006ooooo`;o00001?ooool3
o`0000;ooooo1?l0000mooooo`Go00005_ooool2o`0000[ooooo0_l00002ooooo`Co00001Oooool2
o`000003ooooool0003o000003Wooooo000Looooo`03o`000?oooooooooo02[ooooo0_l0000Boooo
o`;o00002?ooool2o`0000;ooooo0_l00004ooooo`;o00002oooool2o`000003ooooool0003o0000
00go00000oooool3o`0001Oooooo0_l000001?oooooo0000o`000?l00003ooooo`?o00004Oooool2
o`0000cooooo0_l00004ooooo`?o00001?ooool2o`00017ooooo0_l0000@ooooo`;o00000_ooool2
o`000003ooooool0003o000000_ooooo0_l000001?oooooo0000o`000?l00009ooooo`;o0000>Ooo
ool001cooooo00?o0000ooooooooool0:_ooool2o`00023ooooo0_l00009ooooo`Co00001OoooolA
o`0000?ooooo0ol0000Cooooo`;o00000_ooool3o`000003ooooool0003o000000?ooooo1?l0000@
ooooo`;o00000oooool2o`0000Oooooo0_l00004ooooo`?o00001?ooool3o`00017ooooo0_l00002
ooooo`;o00002oooool2o`0000;ooooo1?l00005ooooo`;o00001Oooool2o`0004Sooooo000Loooo
o`03o`000?oooooooooo03_ooooo0ol0000<ooooo`;o00002oooool4o`0000Cooooo5Ol0000Foooo
o`;o00000oooool2o`0000Sooooo0ol000000ooooooo0000o`000002o`000003ooooool0003o0000
00Oooooo0_l00003ooooo`;o00000_ooool2o`0000Sooooo1?l00005ooooo`;o00004Oooool2o`00
00;ooooo0_l0000Aooooo`;o00001Oooool2o`0000Oooooo0_l00016ooooo`007?ooool00ol0003o
ooooooooo`0/ooooo`;o00003Oooool3o`000003ooooool0003o000000;o00001oooool2o`0000_o
oooo1?l00004oooooaOo00004oooool2o`0000gooooo2Ol000000ooooooo0000o`000005ooooo`Co
00001oooool2o`0000;ooooo0_l00002ooooo`Co00004oooool2o`0001kooooo0_l00002ooooo`Ko
00000_ooool4o`0004Kooooo000Looooo`03o`000?oooooooooo02cooooo0_l0000Aooooo`Co0000
2Oooool2o`0000?ooooo0_l0000<oooooaSo00004_ooool2o`0000Sooooo0_l00003ooooo`Oo0000
00?oooooo`000?l000000_l00003ooooo`Co000000?oooooo`000?l000002_ooool2o`0000;ooooo
0_l0000Eooooo`;o00000_ooool2o`0001;ooooo0_l00006ooooo`;o00000_ooool6o`0000;ooooo
1?l0000;ooooo`;o00002?ooool2o`0002oooooo000Looooo`03o`000?oooooooooo03gooooo0_l0
000=ooooo`;o00000_ooool3o`0000Gooooo0_l00007ooooo`?o000000?oooooo`000?l000004?l0
000Booooo`;o000000?oooooo`000?l000001Oooool2o`0000Sooooo2?l00002ooooo`;o00000ooo
ool3o`0000Kooooo0_l0000Looooo`;o000000Coooooo`000?l0003o00004_ooool2o`0000[ooooo
2?l00002ooooo`;o00002?ooool2o`000003ooooool0003o000000Sooooo0_l0000_ooooo`007?oo
ool00ol0003oooooooooo`0mooooo`;o00000_ooool2o`0000gooooo0_l00004ooooo`Co00001Ooo
oolHo`0000oooooo0_l000001?oooooo0000o`000?ooool2o`0000kooooo1_l000000ooooooo0000
o`000002ooooo`;o00001?ooool2o`0000Kooooo0ol000000ooooooo0000o`00000Hooooo`;o0000
00?oooooo`000?l000000_ooool2o`0000Gooooo0_l00003ooooo`;o00002?ooool2o`0000Gooooo
0_l00004ooooo`;o00001?ooool2o`0000Cooooo1?l0000Fooooo`;o00009?ooool001cooooo00?o
0000ooooooooool0@?ooool3o`0000Cooooo0_l0000=ooooo`;o00001ooooolJo`000003ooooool0
003o000000[ooooo0_l000000ooooooo0000o`000004ooooo`;o00000oooool2o`0000Kooooo0_l0
0002ooooo`;o00001Oooool4o`000003ooooool0003o000000;ooooo1?l00002ooooo`;o000000?o
ooooo`000?l000002oooool2o`0000_ooooo0_l00005ooooo`;o00001Oooool2o`0000?ooooo1Ol0
0005ooooo`;o00002oooool2o`0000Cooooo0_l00004ooooo`;o00006?ooool2o`0002Cooooo000L
ooooo`03o`000?oooooooooo03gooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o000000?o
ooooo`000?l000005_oooolJo`000003ooooool0003o000000[ooooo0_l00007ooooo`;o00000ooo
ool2o`0000Sooooo0_l00007ooooo`Co000000?oooooo`000?l000000_ooool4o`0001;ooooo0_l0
000Dooooo`;o00002Oooool4o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`00
0006ooooo`?o00000_ooool2o`0000Gooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0k
ooooo`Co00000_ooool2o`000003ooooool0003o000000Cooooo0_l0000CoooooaWo00003_ooool3
o`0000Cooooo0_l0000?ooooo`;o00001oooool3o`0002?ooooo0_l0000=ooooo`Ko000000?ooooo
o`000?l000000_ooool3o`0000;ooooo0_l00004ooooo`Go00001_ooool8o`0000Cooooo0_l0000n
ooooo`007?ooool00ol0003oooooooooo`0kooooo`So00001oooool4o`0000Wooooo0_l00005oooo
oa[o00001oooool2o`0000Cooooo1_l00002ooooo`;o00004oooool2o`0000Cooooo0_l00003oooo
o`;o00000oooool2o`0000;ooooo0_l00002ooooo`;o00004Oooool2o`0000oooooo1?l000000ooo
oooo0000o`000003ooooo`;o00000oooool2o`0000Gooooo0_l00007ooooo`;o000000?oooooo`00
0?l000000ol00004ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0??ooool5o`0000Ko
oooo0_l00002ooooo`?o00002Oooool2o`0000Cooooo6ol00002ooooo`;o00000oooool2o`0000Co
oooo0_l00002ooooo`;o00000_ooool2o`0001?ooooo0_l00008ooooo`Co00000_ooool2o`0000;o
oooo0_l000001?oooooo0000o`000?l00006ooooo`Co00007Oooool2o`0000Cooooo0ol000000ooo
oooo0000o`000004o`000003ooooool0003o000000;o00001Oooool3o`0000;ooooo0_l00003oooo
o`;o0000@?ooool001cooooo00?o0000ooooooooool0>_ooool8o`0000Gooooo0_l00002ooooo`Co
00001_ooool2o`0000Kooooo4_l000000ooooooo0000o`000005o`0000?ooooo0_l0000Aooooo`;o
00001_ooool2o`0000Kooooo0_l0000=ooooo`Co00002Oooool3o`0000;ooooo0ol000000ooooooo
0000o`000002o`0000cooooo0_l00005ooooo`;o00001Oooool6o`0000?ooooo0ol00002ooooo`Go
000000?oooooo`000?l000000_l00006ooooo`?o00001Oooool3o`00043ooooo000Looooo`;o0000
>oooool2o`0000Cooooo0_l00007ooooo`;o00000_ooool2o`0000Kooooo0_l00006oooooa;o0000
00?oooooo`000?l000001Ol0000Fooooo`Co00001?ooool2o`0000Kooooo0_l0000>ooooo`Go0000
1oooool3o`0000;ooooo1Ol000001?oooooo0000o`000?l00004ooooo`;o00001Oooool2o`0000Go
oooo0ol00004ooooo`Ko00001Oooool2o`000003ooooool0003o000000?o00003?ooool2o`0000Go
oooo0_l000000ooooooo0000o`00000nooooo`007?ooool00ol0003oooooooooo`0jooooo`;o0000
1oooool2o`0000;ooooo1?l0000;ooooo`;o00001_oooolHo`0001?ooooo0_l00004ooooo`;o0000
1?ooool2o`0001Oooooo1Ol00006ooooo`?o00001Oooool2o`000004ooooool0003o0000o`0000Co
oooo0_l0000:ooooo`;o000000?oooooo`000?l000002?ooool2o`0000Gooooo0_l00008ooooo`;o
00003oooool2o`000004ooooool0003o0000ooooo`?o0000>_ooool001cooooo00?o0000oooooooo
ool0>_ooool2o`0000Oooooo1ol0000<ooooo`;o00001_oooolCo`000003ooooool0003o000000?o
00004_ooool4o`0000;ooooo1?l00002ooooo`;o00001Oooool2o`000003ooooool0003o000000oo
oooo0ol00003ooooo`Ko000000?oooooo`000?l000000_l000000ooooooo0000o`000002o`0000Go
oooo0ol00005ooooo`;o00000_ooool2o`0000[ooooo0ol00009ooooo`;o00001?ooool2o`0001Go
oooo0ol00002ooooo`;o0000=_ooool001cooooo00?o0000ooooooooool0AOooool3o`000003oooo
ool0003o000000kooooo0_l00003oooooaKo000000?oooooo`000?l000003_ooool2o`0000Cooooo
0_l00002ooooo`Co00002Oooool2o`000003ooooool0003o000000?o00003_ooool2o`0000;ooooo
1_l000000ooooooo0000o`000009o`0000?ooooo0ol00002ooooo`;o000000?oooooo`000?l00000
3_ooool2o`0000Gooooo1?l000000ooooooo0000o`000002ooooo`;o00005Oooool2o`0000Gooooo
0_l0000fooooo`007?ooool00ol0003oooooooooo`11ooooo`;o00000_ooool2o`0000;ooooo0_l0
0003ooooo`;o00001_ooool2o`000003ooooool0003o000000?ooooo5ol0000@ooooo`;o00003_oo
ool2o`0000[ooooo1Ol00006ooooo`;o00001?ooool3o`0000;ooooo0_l00004ooooo`;o000000Co
ooooo`000?l0003ooooo1Ol00008ooooo`;o00001oooool2o`0000?ooooo0_l0000:ooooo`Co0000
1Oooool2o`0000?ooooo0_l0000@ooooo`;o00004oooool2o`0002Sooooo000Looooo`03o`000?oo
oooooooo02cooooo0_l0000Cooooo`;o00000_ooool4o`000003ooooool0003o000000;ooooo0_l0
0006ooooo`Co00000_ooool2o`0000?ooooo5_l00003ooooo`;o00002Oooool2o`0000Sooooo0_l0
0004ooooo`;o00003Oooool2o`0000?ooooo0_l000000ooooooo0000o`000005ooooo`;o00000_oo
ool3o`0000?ooooo0_l00004ooooo`?o00004?ooool2o`000003ooooool0003o000000?ooooo0_l0
000:ooooo`Ko00002?ooool2o`0000?ooooo0_l0000>ooooo`;o00004?ooool2o`0002Sooooo000L
ooooo`03o`000?oooooooooo02Oooooo0_l00003ooooo`;o00005?ooool2o`000003ooooool0003o
000000;o000000?oooooo`000?l000000_ooool2o`0000Sooooo1_l00003oooooa?o000000Cooooo
o`000?l0003o00000_ooool3o`0000Oooooo0ol00008ooooo`;o00000_ooool2o`0001Cooooo0_l0
000<ooooo`?o00002Oooool2o`0000?ooooo0_l00006ooooo`;o00001?ooool2o`0000oooooo1_l0
00000ooooooo0000o`000003ooooo`;o00000oooool2o`0000?ooooo0_l0000>ooooo`;o0000>_oo
ool001cooooo00?o0000ooooooooool09oooool2o`0001Wooooo0_l000000ooooooo0000o`000002
o`0000;ooooo0_l000000ooooooo0000o`00000:ooooo`;o00001_ooool@o`0000?ooooo0ol00003
ooooo`;o00001oooool2o`0000;ooooo0_l00003ooooo`;o00001?ooool2o`0001Gooooo0_l00004
ooooo`;o00002_ooool7o`0000Gooooo1_l000001?oooooo0000o`000?l00004ooooo`;o00000ooo
ool2o`0000[ooooo1?l00008ooooo`;o00000_ooool2o`0000Gooooo0_l0000:ooooo`;o00000ooo
ool2o`0003Sooooo000Looooo`03o`000?oooooooooo02oooooo0_l0000Eooooo`?o00000_ooool2
o`000003ooooool0003o000000cooooo0_l00004oooooa3o00003Oooool2o`000004ooooool0003o
0000o`0000?ooooo0_l00003ooooo`;o00003?ooool2o`0000Gooooo0_l00006ooooo`?o00000ooo
ool2o`0000Cooooo0_l00004ooooo`Oo00001oooool7o`0000[ooooo0_l00005ooooo`Go00003_oo
ool4o`0000Gooooo0_l0000:ooooo`;o00000oooool4o`0003Kooooo000Looooo`03o`000?oooooo
oooo02Oooooo0_l00006ooooo`;o00004oooool2o`000003ooooool0003o000000;o00002_ooool2
o`0000Gooooo0_l00005ooooo`_o000000?oooooo`000?l000003_ooool6o`0001Kooooo0_l00005
ooooo`;o00001_ooool3o`0000Wooooo0_l00002ooooo`;o00000_ooool2o`0000Gooooo0_l00002
ooooo`;o00000oooool2o`0000Cooooo0_l00006ooooo`;o00001?ooool5o`0000kooooo0_l00000
0ooooooo0000o`000004ooooo`;o00003Oooool2o`000004ooooool0003o0000o`0003Kooooo000L
ooooo`03o`000?oooooooooo02Oooooo0_l0000Iooooo`Co000000?oooooo`000?l000000_l0000:
ooooo`;o00001Oooool2o`0000Kooooo0ol000001?oooooo0000o`000?ooool3o`000003ooooool0
003o000000Oooooo0_l00006ooooo`;o00005oooool2o`0000Wooooo0_l00004ooooo`;o00001Ooo
ool2o`0000Oooooo0_l000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l000000ol0
0004ooooo`;o000000?oooooo`000?l000001Oooool3o`0001[ooooo0ol0000Booooo`;o000000?o
ooooo`000?l00000=oooool001cooooo00?o0000ooooooooool0@_ooool2o`0000?ooooo0_l00006
ooooo`;o00001?ooool2o`0000Gooooo0_l000000ooooooo0000o`000003ooooo`?o000000?ooooo
o`000?l000000_ooool2o`000005ooooool0003o0000o`000?ooool00ol00002ooooo`Co00002_oo
ool2o`00017ooooo0_l000000ooooooo0000o`000006ooooo`;o00002oooool2o`0000[ooooo0_l0
0009ooooo`;o000000?oooooo`000?l000000_ooool4o`0000;ooooo0_l00004ooooo`;o00003?oo
ool2o`0000Sooooo0_l00004ooooo`;o00001_ooool2o`0004Kooooo000Looooo`03o`000?oooooo
oooo03[ooooo0_l0000:ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Cooooo0_l00000
0ooooooo0000o`000005ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`;o000000Gooooo
o`000?l0003o0000ooooo`03o`0000Cooooo0_l00005ooooo`;o00000oooool2o`0001Cooooo0_l0
0004ooooo`;o00001?ooool3o`000003ooooool0003o000000oooooo1?l0000>ooooo`?o00000ooo
ool2o`0000cooooo0_l00003ooooo`?o00002?ooool2o`0000cooooo0_l00016ooooo`007?ooool0
0ol0003oooooooooo`0`ooooo`;o00002?ooool2o`0000?ooooo0_l00005ooooo`;o000000?ooooo
o`000?l000003Oooool2o`0000[ooooo1?l00004ooooo`;o00000_ooool2o`000003ooooool0003o
000000Kooooo0_l00004ooooo`;o00007oooool2o`0000Cooooo1_l0000?ooooo`Go00004oooool2
o`0000cooooo0_l000000ooooooo0000o`000003o`0000;ooooo0_l000000ooooooo0000o`000002
ooooo`;o00001_ooool2o`00017ooooo0_l0000hooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^
k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0
9oooool2o`0000Oooooo0ol0000<ooooo`;o00002?ooool2o`0000Oooooo0_l00006ooooo`;o0000
1_ooool2o`000004ooooool0003o0000o`0000Cooooo0_l00005ooooo`;o00000_ooool2o`0000;o
oooo0_l00004ooooo`;o00006?ooool2o`0000_ooooo1?l0000Aooooo`;o000000?oooooo`000?l0
00004?ooool2o`000003ooooool0003o000000cooooo1Ol00005ooooo`Go00000_ooool2o`0000Ko
oooo0_l000000ooooooo0000o`00000=ooooo`?o0000>?ooool00006oooooomgMgOoV9RHoooooonH
V9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooo
oooo02Oooooo0_l00008ooooo`;o00003?ooool2o`0000Cooooo0_l00002ooooo`Co00000_ooool5
o`0000Gooooo0ol00006ooooo`;o000000?oooooo`000?l000004?ooool2o`0001;ooooo0_l00007
ooooo`;o00001Oooool2o`0000;ooooo0_l0000Looooo`;o00004oooool2o`0000cooooo0_l00000
0ooooooo0000o`000002o`0000;ooooo0_l00004ooooo`;o00000oooool2o`0000Gooooo0_l00002
ooooo`;o00001Oooool2o`0000Kooooo0_l0000iooooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0k
ooooo`;o00000_ooool2o`0000?ooooo0ol00004ooooo`;o00000_ooool3o`0000Oooooo0_l00000
0ooooooo0000o`000007ooooo`;o00003_ooool2o`0001Cooooo0_l00007ooooo`;o00000_ooool2
o`0000Gooooo0_l00005ooooo`;o00000oooool2o`0001Kooooo0_l0000Cooooo`;o00001_ooool2
o`0000Cooooo0_l000000ooooooo0000o`00000=ooooo`Go00002Oooool2o`0000;ooooo1?l0000k
ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9Sooooo
oiRHV?lQ8B401_ooool3o`0003_ooooo0_l00007ooooo`;o00000oooool2o`0000oooooo1_l00005
ooooo`;o00001oooool2o`0000Gooooo0_l0000Qooooo`;o00002_ooool5o`0000;ooooo0_l0000=
ooooo`;o00001oooool2o`0000Wooooo0_l00008ooooo`;o00001Oooool2o`0000Gooooo1?l00009
ooooo`;o00000oooool5o`0000Sooooo0ol00002ooooo`Co0000>oooool00003ooooool0003ooooo
00;ooooo00?o0000ooooooooool02Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000
ooooooooool0A?ooool2o`0000?ooooo0_l0000?ooooo`;o00000_ooool2o`0000[ooooo0_l00002
ooooo`;o00001Oooool2o`00023ooooo0_l00006ooooo`;o00000oooool2o`000003ooooool0003o
0000017ooooo0_l0000Booooo`Co00001_ooool2o`0000Gooooo0_l00007ooooo`;o00002Oooool2
o`0000?ooooo0_l00004ooooo`;o00001Oooool2o`0000;ooooo1?l0000looooo`0000?ooooooa0@
4?ooool00_ooool00ol@413oooooooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000oooo
ooooool0<?ooool2o`0001Sooooo0_l0000Nooooo`;o000000?oooooo`000?l000001?l00002oooo
o`;o00002?ooool2o`0000?ooooo0_l0000@ooooo`?o00001_ooool3o`0000Wooooo0_l0000Loooo
o`?o00001?ooool2o`0000_ooooo0_l0000<ooooo`?o00001?ooool2o`0000;ooooo1?l00004oooo
o`;o00002Oooool4o`0003cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00?ogMgM
oa0@4?nHV9P02?ooool00ol0003oooooooooo`0`ooooo`;o00003_ooool2o`0000Cooooo0_l00002
ooooo`?o00005?ooool2o`0000[ooooo2?l0000:ooooo`;o000000?oooooo`000?l000000_l0000@
ooooo`;o00001Oooool2o`000003ooooool0003o000000Gooooo0_l00002ooooo`Go00001oooool2
o`00013ooooo0ol00007ooooo`;o00002?ooool2o`0000?ooooo0_l000000ooooooo0000o`000002
o`0000;ooooo0ol00004ooooo`;o00000_ooool2o`0001;ooooo0_l0000mooooo`0000Koooooonk^
k_lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0
@?ooool3o`0000?ooooo1?l000000ooooooo0000o`000002ooooo`;o00004?ooool2o`0000Kooooo
0_l00008ooooo`;o00003Oooool2o`0001Wooooo0ol00003ooooo`?o000000Goooooo`000?l0003o
0000ooooo`05o`0000Oooooo1?l00005ooooo`;o00002_ooool2o`0000Gooooo0_l00008ooooo`;o
00000oooool2o`000003ooooool0003o000000;o00000_ooool2o`0001gooooo0_l0000<ooooo`;o
0000;oooool001cooooo00?o0000ooooooooool0@Oooool2o`0000?ooooo1Ol00004ooooo`;o0000
6?ooool2o`000003ooooool0003o0000033ooooo0_l000000ooooooo0000o`000003o`000003oooo
ool0003o000000Oo00002?ooool4o`0000Cooooo0_l0000:ooooo`;o00006?ooool2o`000003oooo
ool0003o000000;o00003oooool2o`0000?ooooo0ol00004ooooo`;o00003_ooool2o`0002oooooo
000Looooo`03o`000?oooooooooo04Kooooo0_l000001?oooooo0000o`000?ooool2o`000003oooo
ool0003o000000cooooo0_l0000:ooooo`;o000000Coooooo`000?l0003o00002?ooool2o`0002?o
oooo0_l00003ooooo`Go000000?oooooo`000?l000002Ol000000ooooooo0000o`000003ooooo`Co
00008_ooool2o`000003ooooool0003o000000?ooooo0_l000001?oooooo0000o`000?l00008oooo
o`;o00001_ooool3o`0000;ooooo0ol00004ooooo`?o0000?_ooool001cooooo00?o0000oooooooo
ool0AOooool2o`0000;ooooo0_l000000ooooooo0000o`00000?ooooo`;o00002oooool2o`000003
ooooool0003o000000Sooooo0_l0000;ooooo`;o00005?ooool4o`000003ooooool0003o0000017o
000000?oooooo`000?l000000_ooool2o`000004ooooool0003o0000o`0000Sooooo0_l0000Boooo
o`;o00000oooool2o`000003ooooool0003o000000Oooooo0ol00007ooooo`Co00001Oooool2o`00
00?ooooo0_l00005ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0AOooool6o`00013o
oooo0_l0000=ooooo`;o00006?ooool2o`0001?ooooo1Ol000000ooooooo0000o`00000?o`0000?o
oooo0_l00002ooooo`Ko00002?ooool5o`0000Oooooo1?l000001?oooooo0000o`000?ooool4o`00
00Sooooo0_l00004ooooo`?o00001_ooool6o`0000Sooooo0_l00015ooooo`007?ooool00ol0003o
ooooooooo`15ooooo`Co00004_ooool3o`0000cooooo0_l0000:ooooo`;o00007oooool7o`000003
ooooool0003o0000017o00001oooool3o`0000_ooooo1_l000000ooooooo0000o`000008o`0000;o
oooo0ol00008ooooo`;o00001Oooool3o`0000Wooooo0ol0000<ooooo`;o0000@?ooool001cooooo
00?o0000ooooooooool0A?ooool5o`000003ooooool0003o000000kooooo1?l0000Hooooo`;o0000
5Oooool2o`0000Sooooo0_l000000ooooooo0000o`00000Ho`0000?ooooo0_l000000ooooooo0000
o`00000<oooooa;o000000?oooooo`000?l000001oooool2o`000003ooooool0003o000000Cooooo
0_l0000:ooooo`;o00000_ooool2o`0000Sooooo0_l00010ooooo`007?ooool00ol0003ooooooooo
o`14ooooo`Co00000_ooool2o`000003ooooool0003o000000_ooooo0_l00002ooooo`;o00009?oo
ool2o`0000Oooooo0_l00006ooooo`?o000000?oooooo`000?l000006Ol00003ooooo`;o00000ooo
ool2o`0000Sooooo5?l0000:ooooo`Oo000000?oooooo`000?l000003oooool2o`0004[ooooo000L
ooooo`03o`000?oooooooooo04Kooooo0_l00003ooooo`Co00001?ooool2o`0000Wooooo0_l0000:
ooooo`;o00004Oooool2o`0000Gooooo0_l0000:ooooo`;o00000oooool3o`000003ooooool0003o
000001Wo00000oooool2o`000003ooooool0003o000000;o00001?oooolHo`0000_ooooo0_l00002
ooooo`;o000000?oooooo`000?l00000Foooool001cooooo00?o0000ooooooooool0Boooool2o`00
00Kooooo0_l0000Eooooo`;o00003Oooool2o`0000;ooooo1Ol00008ooooo`;o00001?ooool2o`00
00Oooooo6ol00005ooooo`?o00001OoooolKo`00017ooooo1?l00006ooooo`;o000000?oooooo`00
0?l00000COooool001cooooo00?o0000ooooooooool0BOooool2o`0000?ooooo0ol0000Nooooo`;o
00002?ooool2o`0000?ooooo1Ol00007ooooo`;o00001_ooool2o`0000;ooooo0_l000000ooooooo
0000o`00000Io`0000Gooooo0_l00003ooooo`;o000000?oooooo`000?l000006_l000001?oooooo
0000o`000?l0000<ooooo`Co00001_ooool5o`0004gooooo000Looooo`03o`000?oooooooooo03Oo
oooo0_l00007ooooo`;o00001oooool2o`0000?ooooo0ol00008ooooo`;o00001Oooool2o`0000go
oooo0_l00004ooooo`;o00002_ooool2o`0000oooooo0_l00002ooooo`Ko000000?oooooo`000?l0
00000ol00002oooooa7o00001Oooool3o`000004ooooool0003o0000oooooaco000000Coooooo`00
0?l0003o00005?ooool2o`0000;ooooo0_l0001>ooooo`007?ooool2o`0003Sooooo0_l00007oooo
o`;o00001Oooool2o`0000Wooooo0ol00004ooooo`;o00001Oooool3o`0000Cooooo0_l00005oooo
o`;o00001Oooool2o`0000?ooooo0_l0000Jooooo`[o000000?oooooo`000?l000004ol00004oooo
o`?o00001OoooolJo`0000Kooooo1?l00003ooooo`;o00002_ooool2o`0000Kooooo0_l00003oooo
o`;o00001oooool2o`0003cooooo000Looooo`03o`000?oooooooooo04Oooooo0_l00009ooooo`?o
00003?ooool2o`0000Cooooo0_l00003ooooo`Co00000_ooool2o`0000Kooooo0_l0000Iooooo`Go
000000?oooooo`000?l000006Ol00006ooooo`;o00001OoooolSo`0000?ooooo0_l00004ooooo`;o
00000_ooool2o`0000Sooooo0_l00003ooooo`;o00001oooool2o`0003cooooo000Looooo`03o`00
0?oooooooooo03Wooooo0_l0000;ooooo`;o00002oooool2o`00017ooooo0_l00004ooooo`;o0000
0_ooool4o`00023ooooo0ol000000ooooooo0000o`000008o`000003ooooool0003o000000go0000
00?oooooo`000?l000001oooool2o`0000Gooooo7ol00007ooooo`;o00001?ooool2o`0000;ooooo
0_l0000>ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0>Oooool2o`0000_ooooo0_l0
000=ooooo`;o00003oooool2o`000003ooooool0003o000000Gooooo0_l0000Eooooo`;o00002ooo
oolSo`000003ooooool0003o000000;o00000_ooool2o`0000Cooooo7Ol00008ooooo`;o00006?oo
ool2o`0000Sooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`1Eooooo`;o00000oooool2
o`0000gooooo0_l00005ooooo`;o00005Oooool4o`0000_ooooo7_l000001?oooooo0000o`000?oo
ool5o`000003ooooool0003o000000Cooooo3_l000000ooooooo0000o`00000=o`0000Sooooo0_l0
000Qooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0B?ooool2o`0000Oooooo1?l00005
ooooo`;o0000;Oooool2o`0000_ooooo7_l00007ooooo`;o00000_ooool2o`0000Gooooo2ol00002
ooooo`_o00000_ooool2o`0000Sooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`0loooo
o`;o00002_ooool2o`0000Oooooo1?l0000Fooooo`;o00003Oooool2o`0000kooooo1?l00009oooo
oago00000oooool2o`0000Kooooo0_l00006ooooo`?o000000?oooooo`000?l000004Ol00004oooo
o`;o0000IOooool001cooooo00?o0000ooooooooool0??ooool2o`0000kooooo1?l00003ooooo`;o
00002_ooool3o`0000Wooooo0_l0000=ooooo`;o00002oooool2o`000003ooooool0003o000000;o
00002?oooolJo`0000;ooooo0_l00003ooooo`?o00001Oooool2o`0000Kooooo0ol000000ooooooo
0000o`00000Ao`0000;ooooo1?l0000Aooooo`;o00000oooool2o`0000;ooooo0_l00006ooooo`;o
0000@Oooool001cooooo00?o0000ooooooooool0B?ooool2o`0000;ooooo1?l0000>ooooo`Co0000
0oooool2o`0000Sooooo0_l0000Fooooo`;o00001_ooool2o`0000;ooooo0_l000000ooooooo0000
o`00000Ho`0000Sooooo0_l00005ooooo`;o00002oooool>o`000003ooooool0003o000000?ooooo
0ol0000Booooo`Co000000?oooooo`000?l000000_ooool2o`0000Kooooo0_l00011ooooo`007?oo
ool00ol0003oooooooooo`10ooooo`;o00001_ooool2o`0001;ooooo1Ol00004ooooo`;o00002?oo
ool2o`0000Kooooo1?l00003ooooo`;o00003?ooool2o`000004ooooool0003o0000ooooo`?o0000
00?oooooo`000?l000006?l00008ooooo`;o00004Oooool<o`000003ooooool0003o000000?ooooo
0_l00002ooooo`;o00005?ooool2o`00053ooooo000Looooo`03o`000?oooooooooo043ooooo0_l0
0008ooooo`;o00002oooool2o`0000?ooooo0_l000000ooooooo0000o`000007ooooo`;o00003Ooo
ool4o`0000?ooooo0_l00006ooooo`;o00001?ooool2o`0000Cooooo0_l00002ooooo`Ko000000?o
ooooo`000?l000002?l000000ooooooo0000o`000004o`0000[ooooo0_l0000:ooooo`;o00001Ooo
ool;o`000003ooooool0003o000000Cooooo1?l0001Xooooo`007?ooool00ol0003oooooooooo`17
ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Cooooo0_l00009ooooo`;o00001?ooool2
o`0000cooooo0_l00004ooooo`;o00001?ooool:o`0000Cooooo0_l00006oooooaCo00004?ooool2
o`0000Kooooo0_l0000;ooooo`Go000000?oooooo`000?l000001_ooool2o`0000gooooo0_l00007
ooooo`;o0000D?ooool001cooooo00?o0000ooooooooool0Aoooool2o`0000Sooooo0_l00007oooo
o`Co00001?ooool3o`0000?ooooo0_l0000<ooooo`;o00001?ooool2o`0000Cooooo2_l00002oooo
o`Co00001OoooolEo`0000_ooooo1?l000000ooooooo0000o`00000Fooooo`;o000000Coooooo`00
0?l0003ooooo1?l00002ooooo`;o00002Oooool2o`000003ooooool0003o000000Gooooo1?l0001@
ooooo`007?ooool00ol0003oooooooooo`1Jooooo`Co00001Oooool3o`0000gooooo0_l0000;oooo
o`go000000?oooooo`000?l000001OoooolBo`0000;ooooo0_l00007ooooo`;o00000oooool4o`00
00oooooo0_l00003ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`Co00000_ooool2
o`0000Wooooo0_l00008ooooo`Co0000D?ooool001cooooo00?o0000ooooooooool0@oooool2o`00
00cooooo1?l00006ooooo`;o000000?oooooo`000?l000001?ooool2o`0000[ooooo0_l000001?oo
oooo0000o`000?l0000:ooooo`oo00001_ooool2o`000003ooooool0003o000000;ooooo3?l00000
0ooooooo0000o`000003ooooo`;o00000_ooool3o`0000kooooo0_l00005ooooo`;o00000oooool2
o`0000Kooooo0_l0000Dooooo`;o00001_ooool4o`00053ooooo000Looooo`03o`000?oooooooooo
04?ooooo0_l0000<ooooo`Co00001?ooool4o`000003ooooool0003o0000013ooooo1_l0000:oooo
oa3o00001Oooool2o`0000?ooooo3_l00006ooooo`;o00000oooool2o`0000kooooo0_l0000Boooo
o`;o00003?ooool2o`0000Kooooo0_l0001Jooooo`007?ooool2o`0005[ooooo0_l00003ooooo`;o
00004?ooool4o`0000cooooo4?l00008ooooo`co00002_ooool2o`0001Gooooo0_l0000Nooooo`;o
00003_ooool2o`0000Gooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o0000
1Oooool3o`0000Sooooo0_l0000Iooooo`;o00001Oooool?o`0000;ooooo0_l00005ooooo`Co0000
00Coooooo`000?l0003ooooo0ol0000;ooooo`;o00005Oooool2o`0000?ooooo0_l0000Yooooo`;o
00001Oooool2o`0004_ooooo000Looooo`03o`000?oooooooooo04cooooo0_l00005ooooo`?o0000
0oooool2o`0000Wooooo1?l0000Aooooo`;o000000?oooooo`000?l000003ol00002ooooo`Co0000
1Oooool2o`0000?ooooo0_l000001?oooooo0000o`000?l00003ooooo`;o00006?ooool2o`0000;o
oooo0_l00004ooooo`Co000000Coooooo`000?l0003o00003Oooool2o`0000Cooooo0_l00002oooo
o`;o00001?ooool2o`0005Sooooo000Looooo`03o`000?oooooooooo05Wooooo0_l00005ooooo`?o
000000?oooooo`000?l000000_l0000<ooooo`Co00001?ooool9o`000003ooooool0003o000000Ko
000000?oooooo`000?l000000ol00004ooooo`;o00001_ooool3o`0000?ooooo0_l0000>ooooo`;o
000000?oooooo`000?l000001Oooool2o`0000;ooooo0_l00006ooooo`;o000000Coooooo`000?l0
003o00003Oooool2o`0000Cooooo0_l00002ooooo`;o00000oooool3o`0000kooooo0_l00018oooo
o`007?ooool00ol0003oooooooooo`14ooooo`;o00004?ooool2o`0000Sooooo0ol0000Aooooo`Co
00002?ooool?o`000003ooooool0003o000000;o00001?ooool2o`0000;ooooo0_l00003ooooo`;o
00004oooool2o`000003ooooool0003o000002Kooooo0_l0000;ooooo`;o00003oooool2o`0004So
oooo000Looooo`03o`000?oooooooooo04Cooooo0_l00006ooooo`;o00002?ooool2o`0000?ooooo
0ol00003ooooo`;o000000?oooooo`000?l000001?l00007ooooo`Go00002_ooool;o`0000;ooooo
0_l000000ooooooo0000o`00000:ooooo`;o0000@oooool2o`00013ooooo0_l0001Dooooo`007?oo
ool00ol0003oooooooooo`1<ooooo`;o000000?oooooo`000?l000001_ooool3o`000004ooooool0
003o0000o`0000Kooooo1_l00002ooooo`;o00000oooool3o`0000cooooo2_l00006ooooo`;o0000
1?ooool2o`0002Wooooo0_l0000<ooooo`?o00007?ooool2o`0000?ooooo0_l0001Dooooo`007?oo
ool00ol0003oooooooooo`0mooooo`;o00004?ooool2o`0000Kooooo0ol000000ooooooo0000o`00
000?ooooo`;o00001?ooool2o`0000_ooooo4?l000000ooooooo0000o`000002o`0000;ooooo0_l0
0003ooooo`;o00004_ooool2o`000003ooooool0003o000000gooooo0_l00005ooooo`;o00001Ooo
ool3o`0001cooooo0_l0001Iooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00003?ooool2
o`0000Wooooo0_l00005ooooo`?o00001?ooool2o`0001Wooooo1_l00005ooooo`[o00001oooool2
o`0001;ooooo0_l000000ooooooo0000o`000009ooooo`;o00000oooool2o`0000Cooooo0_l00006
ooooo`;o00001oooool2o`0001;ooooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`1;oooo
o`;o00002Oooool4o`0000?ooooo0ol00004ooooo`;o00002?ooool2o`0000Cooooo0_l00003oooo
o`;o00003oooool2o`0000?ooooo0_l0000Aooooo`Co00005oooool2o`0000?ooooo0_l00003oooo
o`;o00004?ooool2o`0001;ooooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`1Hooooo`Co
00000_ooool2o`0000kooooo0_l00003ooooo`?o00000oooool3o`0000[ooooo0_l00005ooooo`;o
00004oooool4o`0000?ooooo1?l00003ooooo`;o00003oooool3o`0000?ooooo0_l00020ooooo`00
7?ooool00ol0003oooooooooo`1Eooooo`;o00000oooool2o`000003ooooool0003o000000?ooooo
0_l0000?ooooo`;o00001Oooool4o`0000?ooooo0_l00003ooooo`;o00001Oooool4o`0001Sooooo
1?l00003ooooo`;o00003?ooool2o`000003ooooool0003o000000;ooooo0_l00009ooooo`;o0000
00?oooooo`000?l00000M?ooool001cooooo00?o0000ooooooooool0Coooool2o`0000Cooooo0_l0
0006ooooo`;o00000oooool2o`0000Wooooo0_l00004ooooo`;o00001_ooool3o`0000?ooooo0_l0
000<ooooo`;o00001Oooool2o`0000?ooooo0_l0000Qooooo`Co00000oooool2o`000003ooooool0
003o000000Kooooo1_l0001cooooo`007?ooool00ol0003oooooooooo`1?ooooo`;o00003?ooool2
o`0000kooooo0_l00004ooooo`Co00000_ooool2o`0000cooooo0_l000000ooooooo0000o`000009
ooooo`?o00000oooool2o`0002?ooooo0_l00006ooooo`;o00001oooool2o`000003ooooool0003o
000000Kooooo0_l0001[ooooo`007?ooool00ol0003oooooooooo`1^ooooo`;o000000?oooooo`00
0?l000000_ooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l000000ooo
oooo0000o`000009ooooo`;o0000:_ooool2o`0000?ooooo0_l0000Dooooo`;o000000?oooooo`00
0?l000002Oooool2o`0005gooooo000Looooo`03o`000?oooooooooo067ooooo0_l0000;ooooo`;o
000000?oooooo`000?l000002oooool2o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o
00003oooool4o`0000;ooooo0_l0000Jooooo`;o00000_ooool2o`0000?ooooo0_l0000>ooooo`;o
00001oooool2o`0000Wooooo0_l0001Mooooo`007?ooool2o`0005[ooooo0_l00002ooooo`;o0000
0_ooool2o`0000?ooooo0_l0000Gooooo`;o00001?ooool3o`0000_ooooo0_l00006ooooo`Co0000
0_ooool2o`0001Wooooo0ol0000Gooooo`;o0000LOooool001cooooo00?o0000ooooooooool0FOoo
ool6o`0000Oooooo0_l0000Gooooo`;o00001?ooool3o`0000_ooooo0_l00006ooooo`;o00001?oo
ool2o`0001Wooooo1_l0000>ooooo`;o00007_ooool2o`0005Oooooo000Looooo`03o`000?oooooo
oooo05[ooooo0ol0000Mooooo`;o00001_ooool2o`0000Kooooo0ol0000:ooooo`;o00000_ooool:
o`0001Wooooo1?l0000>ooooo`;o00007_ooool2o`0005Oooooo000Looooo`03o`000?oooooooooo
04[ooooo0_l0000>ooooo`;o00002Oooool2o`0001?ooooo0_l00006ooooo`;o00001Oooool4o`00
00[ooooo0_l00004ooooo`Co00000_ooool2o`0000_ooooo0ol00009ooooo`;o00002oooool2o`00
07kooooo000Looooo`03o`000?oooooooooo04[ooooo0_l0000Gooooo`Co00008_ooool3o`0000Ko
oooo0_l00003ooooo`;o00001?ooool2o`0000?ooooo0_l0000<ooooo`?o00002Oooool2o`0000_o
oooo0_l0001nooooo`007?ooool00ol0003oooooooooo`1Sooooo`;o000000?oooooo`000?l00000
9?ooool2o`000004ooooool0003o0000ooooo`?o00001_ooool2o`0000Cooooo0ol00009ooooo`;o
00003Oooool2o`0001Sooooo0ol0000;ooooo`;o0000Hoooool001cooooo00?o0000ooooooooool0
I_ooool4o`0002;ooooo1_l000000ooooooo0000o`000006ooooo`;o00001?ooool3o`0000Wooooo
0_l0000Qooooo`;o00001?ooool5o`0000Wooooo0_l0001Sooooo`007?ooool00ol0003ooooooooo
o`1Xooooo`;o00006oooool2o`0000Oooooo1?l000000ooooooo0000o`00000?ooooo`;o00005Ooo
ool2o`0000cooooo0_l00004ooooo`?o00001Oooool4o`0006kooooo000Looooo`03o`000?oooooo
oooo07Sooooo0_l00004ooooo`;o00001Oooool2o`0000Sooooo0_l00002ooooo`;o00003oooool2
o`0000Cooooo0_l00009ooooo`?o00000oooool2o`0000cooooo0_l00004ooooo`;o00001oooool2
o`0006oooooo000Looooo`03o`000?oooooooooo06Oooooo1?l0000=ooooo`;o000000?oooooo`00
0?l000000ol0000?ooooo`;o00000_ooool4o`0000Wooooo0_l00008ooooo`;o00002Oooool3o`00
01kooooo0_l0001aooooo`007?ooool00ol0003oooooooooo`1Wooooo`Co000000?oooooo`000?l0
00000oooool3o`0000;ooooo0_l00003ooooo`Co00001oooool2o`0000?ooooo0_l00002ooooo`;o
00000_ooool4o`0000Gooooo0_l00002ooooo`;o00007Oooool2o`0001Gooooo0ol0001`ooooo`00
7?ooool00ol0003oooooooooo`1/ooooo`;o00000oooool7o`0000kooooo0_l00003ooooo`;o0000
1oooool2o`0000Kooooo0ol0000:ooooo`Go00001_ooool2o`0000Wooooo0_l0000Fooooo`;o0000
L?ooool001cooooo00?o0000ooooooooool0K?ooool2o`0000Gooooo1?l00002ooooo`?o00004?oo
ool2o`0000oooooo0_l00002ooooo`;o00001_ooool5o`0000Kooooo0_l0000]ooooo`;o0000I?oo
ool001cooooo00?o0000ooooooooool0K?ooool2o`0000Gooooo0_l00004ooooo`?o00004?ooool2
o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000009ooooo`;o00000_ooool2
o`0000kooooo0_l0000/ooooo`;o0000I?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Ooo
ool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo06Gooooo
0_l0000<ooooo`;o00001?ooool4o`0000?ooooo0_l0000=ooooo`;o00000_ooool2o`000003oooo
ool0003o000000;ooooo0_l00009ooooo`;o00003_ooool2o`0002Sooooo0_l0001Xooooo`0000Ko
ooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q
00Kooooo00?o0000ooooooooool0Hoooool4o`0000_ooooo0_l00005ooooo`Co00000oooool2o`00
01Sooooo0_l0000Iooooo`;o00001Oooool2o`00013ooooo0ol0000>ooooo`;o0000J?ooool00003
ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool0Hoooool4o`0000_ooooo0_l00007ooooo`Co00005_ooool2o`00
01kooooo0_l00002ooooo`Go00004?ooool3o`0007Sooooo00000ooooooo0000ooooo`02ooooo`03
o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000HOooool2o`00
00;ooooo0_l00008ooooo`;o00003?ooool2o`0001Kooooo0_l00004ooooo`;o00007?ooool4o`00
013ooooo0_l0001jooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05
olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`1Gooooo`;o00002?ooool2o`00
00Wooooo1Ol0000Vooooo`;o00000_ooool2o`00033ooooo0_l0001jooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0
003oooooooooo`1Gooooo`;o00004oooool3o`00013ooooo0_l0000Fooooo`?o0000[oooool00006
oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o
0000ooooooooool0Ooooool2o`0001Oooooo0_l0000=ooooo`;o0000=?ooool2o`0006[ooooo0000
1_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03
o`000?oooooooooo0:Oooooo0_l00006ooooo`?o0000:oooool2o`0006[ooooo000Looooo`03o`00
0?oooooooooo07Oooooo0ol0000eooooo`?o000000?oooooo`000?l00000U?ooool001cooooo00?o
0000ooooooooool0Moooool3o`0000Cooooo1?l0000aooooo`;o0000U?ooool001cooooo00?o0000
ooooooooool0M_ooool2o`0000Kooooo1Ol0000Kooooo`;o00002oooool2o`0009cooooo000Loooo
o`03o`000?oooooooooo06gooooo0_l00007ooooo`;o00001_ooool2o`000003ooooool0003o0000
00?ooooo0_l0000Fooooo`;o00002oooool2o`0009cooooo000Looooo`03o`000?oooooooooo06go
oooo0_l0000Gooooo`;o00008oooool2o`0001;ooooo0_l00028ooooo`007?ooool00ol0003ooooo
ooooo`1kooooo`;o0000@_ooool2o`0008Sooooo000Looooo`03o`000?oooooooooo07_ooooo0_l0
003<ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
07;ooooo0_l0001>ooooo`;o0000QOooool001cooooo00?o0000ooooooooool0L_ooool6o`0002?o
oooo0_l0000Qooooo`;o00000_ooool2o`0008Gooooo000Looooo`03o`000?oooooooooo07Cooooo
1?l00005ooooo`;o00001?ooool2o`0001?ooooo0_l000000ooooooo0000o`00000Qooooo`;o0000
2oooool2o`0007cooooo000Looooo`;o0000Ioooool2o`0001Gooooo0_l00004ooooo`;o00004ooo
ool2o`0001[ooooo0_l0000Eooooo`;o0000O?ooool001cooooo00?o0000ooooooooool0I_ooool2
o`0002Wooooo0_l0000Cooooo`;o00002Oooool2o`000003ooooool0003o000009?ooooo000Loooo
o`03o`000?oooooooooo097ooooo0_l0000Cooooo`Co00001oooool2o`0009Kooooo000Looooo`03
o`000?oooooooooo08Oooooo0_l00004ooooo`;o00006Oooool4o`0000Kooooo0_l0002Eooooo`00
7?ooool00ol0003oooooooooo`27ooooo`;o00001?ooool2o`0001_ooooo0_l00006ooooo`;o0000
UOooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0W_ooool2o`000:Wooooo000Looooo`03o`000?oooooooooo09kooooo0_l0
002Yooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001;ooooo1?l00000
0ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Go
oooo0ol0003ooooood[ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o
0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Doooo
o`03o`000?oooooooooo0?ooooooD_ooool001;ooooo00?oEEEEofIVI_l00000oooooomDooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00YOooool01?l@413o0000o`000?ooool2
o`000003oa0@4?oooooooooo01Gooooo00Co410@o`000?m4A4Coc<c<1Oooool4o`000008oa0@4?oo
ooooooooolc<c?lQ8B7o0000ob4Q8Oo<c<b@ooooo`00Y_ooool01Ol0003ooooooooooooooooo0000
00Wooooo1_l0000;ooooo`03oiRHV?l@413ogMgM00Kooooo00?o0000ooooooooool00_ooool01OlQ
8B7oV9RHoooooonHV9So8B4Q093ooooo002Vooooo`05o`000?ooooooooooooooool000006oooool0
0on7QhOoEEEEooooo`05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
002@ooooo`00Y_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l00009ooooo`05olc<c?lQ
8B7o0000oeEEEOl000001_ooool00ol0003oooooooooo`02ooooo`05oc8b<_nHV9SooooooiRHV?lb
<S80T?ooool00:Kooooo00Go0000ohN7QoooooooZJVYo`00000Hooooo`05ob4Q8On7QhOooooooiRH
V?l000001_ooool00ol0003oooooooooo`02ooooo`05olc<c?l0003o0000o`000?o<c<`0T?ooool0
0:Gooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Fooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`02ooooo`05oa0@4?nj^[[ooooookZj^_l@4100T?oo
ool00<?ooooo00Go8B4QoiRHV?ooooooMgMgoeEEE@06ooooo`03o`000?oooooooooo00;ooooo00Go
0000okZj^_oooooo^[Zjo`00002@ooooo`00`oooool01Oo<c<co410@o`000?lb<S;ok^k^00Cooooo
00?oEEEEofIVI_l000001?ooool01OnYZJWo410@o`000?l@413oZJVY093ooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(924) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.42312 .338 Mdot
.40965 .37448 Mdot
.5124 .67129 Mdot
.55365 .43932 Mdot
.39155 .42279 Mdot
.48312 .65291 Mdot
.35148 .51754 Mdot
.31106 .49848 Mdot
.50187 .65245 Mdot
.61874 .5299 Mdot
.32288 .50231 Mdot
.55082 .38508 Mdot
.32504 .52913 Mdot
.57006 .43893 Mdot
.84145 .60136 Mdot
.65905 .4182 Mdot
.4 .3952 Mdot
.619 .70037 Mdot
.53184 .41633 Mdot
.46014 .6826 Mdot
.37499 .40143 Mdot
.56614 .44745 Mdot
.41058 .33186 Mdot
.57062 .43917 Mdot
.56228 .41563 Mdot
.41207 .34979 Mdot
.44475 .38888 Mdot
.55244 .41158 Mdot
.60177 .40048 Mdot
.30404 .52701 Mdot
.70024 .61968 Mdot
.84824 .48081 Mdot
.6449 .38769 Mdot
.30794 .261 Mdot
.32139 .48909 Mdot
.72445 .34285 Mdot
.51208 .62487 Mdot
.32287 .54129 Mdot
.31517 .49604 Mdot
.31108 .48788 Mdot
.3157 .53325 Mdot
.40671 .35366 Mdot
.33519 .56807 Mdot
.37375 .54332 Mdot
.59415 .48383 Mdot
.28568 .44478 Mdot
.7655 .46599 Mdot
.62456 .42702 Mdot
.41954 .38383 Mdot
.45456 .68021 Mdot
.2907 .2975 Mdot
.29546 .53094 Mdot
.39493 .69359 Mdot
.76334 .23481 Mdot
.33589 .53982 Mdot
.57693 .4827 Mdot
.50775 .63482 Mdot
.58289 .45457 Mdot
.57514 .44289 Mdot
.51699 .34457 Mdot
.57857 .39485 Mdot
.64354 .68102 Mdot
.35888 .36351 Mdot
.45851 .63228 Mdot
.49099 .64929 Mdot
.31237 .50221 Mdot
.39421 .38946 Mdot
.33273 .52629 Mdot
.53865 .46588 Mdot
.48325 .62151 Mdot
.62429 .42815 Mdot
.31152 .51202 Mdot
.3911 .31833 Mdot
.62235 .44893 Mdot
.22127 .58484 Mdot
.75112 .71358 Mdot
.66863 .69644 Mdot
.54757 .3269 Mdot
.6327 .33137 Mdot
.59517 .78475 Mdot
.59274 .41259 Mdot
.46118 .84331 Mdot
.81665 .63307 Mdot
.42517 .34177 Mdot
.61579 .50752 Mdot
.53758 .6122 Mdot
.61533 .45875 Mdot
.46014 .46808 Mdot
.57516 .49132 Mdot
.21227 .51585 Mdot
.50787 .65139 Mdot
.38943 .36526 Mdot
.55486 .43831 Mdot
.62175 .39333 Mdot
.48062 .25639 Mdot
.56087 .39398 Mdot
.54503 .43382 Mdot
.44557 .35264 Mdot
.33484 .4939 Mdot
.59709 .36434 Mdot
.37398 .49677 Mdot
.38986 .66999 Mdot
.58884 .47778 Mdot
.52465 .63353 Mdot
.44267 .34449 Mdot
.61014 .46639 Mdot
.35401 .49499 Mdot
.61858 .40961 Mdot
.36496 .56031 Mdot
.40939 .37938 Mdot
.6244 .39452 Mdot
.60006 .67157 Mdot
.26676 .69261 Mdot
.38582 .36209 Mdot
.37624 .65484 Mdot
.62159 .40429 Mdot
.56817 .45926 Mdot
.40815 .37203 Mdot
.46751 .6638 Mdot
.51573 .51967 Mdot
.42373 .3896 Mdot
.31806 .4841 Mdot
.39414 .39909 Mdot
.64106 .4907 Mdot
.49676 .66024 Mdot
.40197 .67125 Mdot
.41067 .67646 Mdot
.65518 .58496 Mdot
.60932 .46242 Mdot
.27935 .35832 Mdot
.4759 .65852 Mdot
.39466 .36332 Mdot
.33026 .52374 Mdot
.61818 .48032 Mdot
.37762 .35453 Mdot
.33317 .50746 Mdot
.61817 .65456 Mdot
.5169 .70596 Mdot
.42587 .38239 Mdot
.30593 .57566 Mdot
.30067 .49235 Mdot
.31522 .48227 Mdot
.29198 .27659 Mdot
.41496 .37351 Mdot
.61409 .67995 Mdot
.33761 .51191 Mdot
.75662 .57416 Mdot
.56602 .48107 Mdot
.60593 .57082 Mdot
.34905 .80982 Mdot
.27344 .3071 Mdot
.30967 .65567 Mdot
.63218 .70152 Mdot
.32054 .47622 Mdot
.58062 .40512 Mdot
.42278 .36694 Mdot
.41681 .36166 Mdot
.53866 .43692 Mdot
.55352 .42459 Mdot
.62547 .43467 Mdot
.62069 .39473 Mdot
.78862 .4955 Mdot
.63227 .41868 Mdot
.67193 .66325 Mdot
.38712 .35201 Mdot
.56828 .40381 Mdot
.46502 .67293 Mdot
.64364 .44648 Mdot
.31119 .52413 Mdot
.57275 .45398 Mdot
.55118 .43644 Mdot
.62834 .39278 Mdot
.34419 .53867 Mdot
.82864 .45935 Mdot
.325 .78278 Mdot
.73147 .29839 Mdot
.35328 .65419 Mdot
.48833 .63345 Mdot
.5938 .46943 Mdot
.62497 .67508 Mdot
.67056 .31032 Mdot
.58768 .42337 Mdot
.15949 .46407 Mdot
.54737 .44001 Mdot
.40604 .22378 Mdot
.56844 .35097 Mdot
.7295 .28687 Mdot
.59036 .60566 Mdot
.60312 .39763 Mdot
.49623 .23225 Mdot
.56566 .20546 Mdot
.39425 .53793 Mdot
.31952 .53543 Mdot
.46737 .6744 Mdot
.51477 .63701 Mdot
.29366 .53781 Mdot
.62192 .35862 Mdot
.54023 .37411 Mdot
.51554 .43959 Mdot
.39957 .6796 Mdot
.37636 .31936 Mdot
.6563 .67684 Mdot
.43456 .33817 Mdot
.57104 .85451 Mdot
.21293 .48224 Mdot
.33395 .57153 Mdot
.66384 .6757 Mdot
.50103 .67438 Mdot
.39889 .68221 Mdot
.61952 .67123 Mdot
.60763 .42687 Mdot
.40854 .3862 Mdot
.41882 .19342 Mdot
.642 .35586 Mdot
.4281 .17444 Mdot
.3719 .3613 Mdot
.50507 .51957 Mdot
.32462 .51178 Mdot
.48091 .68664 Mdot
.55998 .45648 Mdot
.6095 .44239 Mdot
.35554 .37606 Mdot
.62199 .42809 Mdot
.35976 .40432 Mdot
.54854 .44999 Mdot
.51927 .68127 Mdot
.66754 .70114 Mdot
.29512 .5406 Mdot
.64357 .58656 Mdot
.39705 .32358 Mdot
.56621 .6307 Mdot
.45716 .6562 Mdot
.68717 .32906 Mdot
.31408 .5075 Mdot
.60109 .66424 Mdot
.45979 .65567 Mdot
.65791 .68403 Mdot
.64329 .43617 Mdot
.50671 .62124 Mdot
.63313 .69577 Mdot
.81135 .49091 Mdot
.60999 .48112 Mdot
.79229 .53497 Mdot
.35111 .51267 Mdot
.39096 .39838 Mdot
.57303 .39672 Mdot
.40682 .66392 Mdot
.63297 .38479 Mdot
.26703 .60312 Mdot
.40746 .6867 Mdot
.38477 .69667 Mdot
.6346 .76652 Mdot
.60412 .67748 Mdot
.27299 .64993 Mdot
.26783 .35185 Mdot
.401 .39426 Mdot
.55606 .46626 Mdot
.77561 .34451 Mdot
.33686 .51217 Mdot
.60462 .42401 Mdot
.55096 .64146 Mdot
.33923 .51424 Mdot
.58718 .45594 Mdot
.35511 .52378 Mdot
.41848 .36637 Mdot
.42999 .77338 Mdot
.39444 .39481 Mdot
.6025 .48459 Mdot
.35503 .50381 Mdot
.47852 .63201 Mdot
.41495 .34844 Mdot
.61706 .4128 Mdot
.56643 .46413 Mdot
.393 .67705 Mdot
.58394 .39694 Mdot
.77908 .36662 Mdot
.60196 .39151 Mdot
.52394 .66005 Mdot
.56351 .39435 Mdot
.17818 .4133 Mdot
.47146 .72967 Mdot
.39628 .38987 Mdot
.38613 .69557 Mdot
.50212 .6475 Mdot
.55279 .76998 Mdot
.39122 .56818 Mdot
.60716 .40695 Mdot
.38102 .68431 Mdot
.58081 .58678 Mdot
.30506 .53886 Mdot
.54062 .41089 Mdot
.23039 .49213 Mdot
.45921 .67379 Mdot
.3965 .68132 Mdot
.52676 .47299 Mdot
.44085 .34058 Mdot
.55421 .4368 Mdot
.48078 .62722 Mdot
.39957 .40101 Mdot
.62703 .46458 Mdot
.73073 .46247 Mdot
.40794 .68408 Mdot
.34978 .51654 Mdot
.51394 .37652 Mdot
.62958 .4266 Mdot
.50849 .62784 Mdot
.38515 .32639 Mdot
.32498 .48536 Mdot
.40195 .34764 Mdot
.48991 .18608 Mdot
.339 .66802 Mdot
.78211 .45507 Mdot
.66275 .66744 Mdot
.31301 .61022 Mdot
.71021 .26515 Mdot
.28697 .68437 Mdot
.72595 .56448 Mdot
.57305 .17284 Mdot
.46249 .65943 Mdot
.55169 .6761 Mdot
.50335 .6422 Mdot
.57433 .41891 Mdot
.48691 .65189 Mdot
.72738 .27821 Mdot
.54639 .44589 Mdot
.49677 .62976 Mdot
.47867 .77331 Mdot
.5549 .41678 Mdot
.3841 .3613 Mdot
.83702 .59653 Mdot
.19817 .58081 Mdot
.21405 .40289 Mdot
.47413 .64418 Mdot
.50759 .36943 Mdot
.55278 .413 Mdot
.65076 .40939 Mdot
.42707 .36095 Mdot
.5452 .40868 Mdot
.6552 .67657 Mdot
.65935 .6712 Mdot
.58638 .56487 Mdot
.37258 .79533 Mdot
.58877 .36579 Mdot
.41853 .35072 Mdot
.66795 .34334 Mdot
.22326 .56851 Mdot
.38571 .66531 Mdot
.36979 .50031 Mdot
.83105 .47641 Mdot
.58571 .3581 Mdot
.29452 .56564 Mdot
.23145 .51138 Mdot
.39685 .37914 Mdot
.80229 .42547 Mdot
.32616 .5378 Mdot
.55828 .24434 Mdot
.41822 .26414 Mdot
.60694 .43677 Mdot
.31955 .50087 Mdot
.56418 .37528 Mdot
.19374 .50915 Mdot
.7661 .59581 Mdot
.61848 .80859 Mdot
.60101 .48367 Mdot
.254 .63192 Mdot
.56933 .45632 Mdot
.52662 .51955 Mdot
.60101 .39114 Mdot
.40266 .34318 Mdot
.65871 .49943 Mdot
.42796 .48961 Mdot
.36912 .80925 Mdot
.21158 .46888 Mdot
.63623 .70149 Mdot
.56509 .4609 Mdot
.60634 .43821 Mdot
.60899 .66399 Mdot
.40046 .33286 Mdot
.61484 .39471 Mdot
.68339 .52725 Mdot
.61984 .4374 Mdot
.31476 .53557 Mdot
.64998 .61054 Mdot
.3533 .38687 Mdot
.61917 .38742 Mdot
.41122 .40026 Mdot
.34492 .53544 Mdot
.309 .50397 Mdot
.57607 .49878 Mdot
.34611 .48005 Mdot
.5512 .44402 Mdot
.72033 .6708 Mdot
.43411 .35482 Mdot
.63523 .34888 Mdot
.39018 .33107 Mdot
.60179 .32402 Mdot
.35631 .49899 Mdot
.4076 .66797 Mdot
.36321 .29592 Mdot
.32684 .53589 Mdot
.2332 .37273 Mdot
.51518 .4204 Mdot
.59738 .37607 Mdot
.19759 .48092 Mdot
.47074 .64489 Mdot
.4074 .67668 Mdot
.34854 .48617 Mdot
.62918 .42877 Mdot
.5586 .38976 Mdot
.32511 .54556 Mdot
.51639 .26742 Mdot
.55728 .76128 Mdot
.54781 .42017 Mdot
.4031 .33911 Mdot
.39491 .36065 Mdot
.62599 .46073 Mdot
.60844 .41288 Mdot
.50891 .6674 Mdot
.38886 .69227 Mdot
.38038 .67396 Mdot
.40961 .67832 Mdot
.52831 .67311 Mdot
.33336 .42473 Mdot
.31217 .48635 Mdot
.29253 .37723 Mdot
.24864 .55657 Mdot
.66809 .39835 Mdot
.49902 .62456 Mdot
.59865 .4437 Mdot
.55686 .44369 Mdot
.32633 .48445 Mdot
.3407 .62877 Mdot
.62613 .5034 Mdot
.43472 .36819 Mdot
.35277 .48835 Mdot
.54949 .37614 Mdot
.32289 .37111 Mdot
.64515 .69104 Mdot
.20788 .40921 Mdot
.3122 .50765 Mdot
.39105 .37769 Mdot
.35131 .54035 Mdot
.61151 .43948 Mdot
.5454 .46351 Mdot
.40248 .3741 Mdot
.60947 .68754 Mdot
.53436 .47427 Mdot
.58728 .45769 Mdot
.16729 .62132 Mdot
.22138 .59249 Mdot
.27782 .4934 Mdot
.59111 .40014 Mdot
.57296 .3828 Mdot
.65074 .69972 Mdot
.6166 .4367 Mdot
.56602 .46587 Mdot
.2719 .70889 Mdot
.28021 .4827 Mdot
.61355 .69819 Mdot
.56724 .24685 Mdot
.37195 .36376 Mdot
.80604 .40077 Mdot
.38215 .67453 Mdot
.3181 .55902 Mdot
.41138 .7618 Mdot
.39564 .68596 Mdot
.27276 .59955 Mdot
.80586 .41566 Mdot
.40891 .67814 Mdot
.53365 .59886 Mdot
.62323 .51155 Mdot
.54232 .432 Mdot
.57474 .45919 Mdot
.62555 .68019 Mdot
.41664 .37194 Mdot
.55212 .57116 Mdot
.77588 .62127 Mdot
.56581 .45178 Mdot
.41761 .41279 Mdot
.82134 .50556 Mdot
.39194 .68036 Mdot
.64765 .66961 Mdot
.61288 .65068 Mdot
.57098 .46196 Mdot
.29995 .72484 Mdot
.41409 .35077 Mdot
.61658 .41258 Mdot
.63527 .4173 Mdot
.47667 .64001 Mdot
.39929 .3865 Mdot
.46149 .64707 Mdot
.41198 .68182 Mdot
.60613 .21145 Mdot
.15009 .58346 Mdot
.33514 .48392 Mdot
.75464 .35233 Mdot
.30147 .53062 Mdot
.64295 .78404 Mdot
.39891 .68752 Mdot
.5916 .41733 Mdot
.39429 .32207 Mdot
.62015 .41115 Mdot
.59836 .42876 Mdot
.60695 .42823 Mdot
.52158 .40572 Mdot
.1631 .45364 Mdot
.63086 .66819 Mdot
.65839 .46022 Mdot
.5243 .65671 Mdot
.76819 .36317 Mdot
.78988 .64755 Mdot
.60378 .44831 Mdot
.57492 .46678 Mdot
.38124 .35817 Mdot
.53799 .43261 Mdot
.31089 .54223 Mdot
.38518 .32587 Mdot
.63307 .39748 Mdot
.79407 .42203 Mdot
.61989 .39764 Mdot
.71278 .27689 Mdot
.35029 .54192 Mdot
.23123 .37791 Mdot
.64937 .47305 Mdot
.41004 .67327 Mdot
.4076 .67689 Mdot
.3739 .68988 Mdot
.35333 .54406 Mdot
.50331 .62786 Mdot
.741 .68606 Mdot
.64595 .37995 Mdot
.57562 .40765 Mdot
.55929 .38834 Mdot
.54316 .64056 Mdot
.45978 .46242 Mdot
.29416 .66194 Mdot
.53857 .38231 Mdot
.49684 .66714 Mdot
.38963 .39894 Mdot
.42829 .64839 Mdot
.3899 .32583 Mdot
.61903 .70257 Mdot
.32083 .5051 Mdot
.65038 .68667 Mdot
.25683 .33281 Mdot
.40904 .37732 Mdot
.35411 .37301 Mdot
.49121 .63162 Mdot
.48558 .5146 Mdot
.74282 .23193 Mdot
.48758 .61774 Mdot
.67536 .56025 Mdot
.42577 .35406 Mdot
.63686 .41184 Mdot
.60931 .59963 Mdot
.47868 .50548 Mdot
.49535 .63558 Mdot
.5808 .42365 Mdot
.34544 .76104 Mdot
.50679 .66838 Mdot
.54022 .4106 Mdot
.47281 .66675 Mdot
.31303 .52176 Mdot
.47354 .66112 Mdot
.37487 .32739 Mdot
.60486 .46908 Mdot
.76544 .24953 Mdot
.57649 .61951 Mdot
.59705 .39292 Mdot
.35372 .49016 Mdot
.68666 .50511 Mdot
.59159 .43677 Mdot
.6542 .66977 Mdot
.49594 .66196 Mdot
.57056 .7407 Mdot
.55745 .40673 Mdot
.48027 .64687 Mdot
.41561 .33295 Mdot
.34732 .54965 Mdot
.65585 .76404 Mdot
.39991 .66691 Mdot
.42757 .36582 Mdot
.41499 .68362 Mdot
.36294 .50358 Mdot
.56618 .38683 Mdot
.63377 .42425 Mdot
.39378 .34514 Mdot
.43439 .79377 Mdot
.56499 .39624 Mdot
.59242 .41287 Mdot
.49794 .67816 Mdot
.53965 .63818 Mdot
.44818 .79005 Mdot
.46328 .65535 Mdot
.52691 .42887 Mdot
.39473 .34526 Mdot
.56008 .43477 Mdot
.38285 .3673 Mdot
.55357 .46135 Mdot
.46214 .3603 Mdot
.42766 .34497 Mdot
.33869 .71411 Mdot
.57052 .42816 Mdot
.54822 .35892 Mdot
.60279 .42917 Mdot
.62207 .43214 Mdot
.51716 .65859 Mdot
.63012 .6627 Mdot
.62496 .48279 Mdot
.61508 .63975 Mdot
.64485 .66421 Mdot
.51503 .19501 Mdot
.47267 .64467 Mdot
.63207 .68711 Mdot
.79882 .52395 Mdot
.38261 .69467 Mdot
.63219 .67522 Mdot
.80399 .62991 Mdot
.3319 .48364 Mdot
.37238 .37916 Mdot
.55527 .41688 Mdot
.55245 .17019 Mdot
.72467 .64152 Mdot
.3855 .67977 Mdot
.60168 .39234 Mdot
.59559 .44227 Mdot
.43899 .37718 Mdot
.53191 .85834 Mdot
.52161 .66727 Mdot
.57067 .41815 Mdot
.38811 .38687 Mdot
.3884 .84072 Mdot
.52545 .64489 Mdot
.62893 .6765 Mdot
.33055 .54605 Mdot
.4508 .3472 Mdot
.39827 .66626 Mdot
.30834 .54293 Mdot
.37195 .72118 Mdot
.23376 .36521 Mdot
.62287 .40466 Mdot
.50276 .62323 Mdot
.2507 .32575 Mdot
.62465 .36272 Mdot
.2763 .51122 Mdot
.5066 .4656 Mdot
.39403 .37695 Mdot
.32397 .54427 Mdot
.64922 .69434 Mdot
.37931 .3269 Mdot
.4038 .33467 Mdot
.31066 .49674 Mdot
.47028 .61306 Mdot
.50019 .51686 Mdot
.31007 .52972 Mdot
.21742 .5201 Mdot
.44551 .19104 Mdot
.38295 .69108 Mdot
.63224 .65936 Mdot
.36478 .23608 Mdot
.40636 .35288 Mdot
.83046 .47284 Mdot
.21008 .38449 Mdot
.54511 .43318 Mdot
.62372 .68887 Mdot
.31163 .4512 Mdot
.76097 .66155 Mdot
.34212 .51519 Mdot
.42016 .46928 Mdot
.59628 .65633 Mdot
.5481 .4149 Mdot
.47504 .35565 Mdot
.58 .41837 Mdot
.32353 .50704 Mdot
.60847 .33237 Mdot
.38983 .377 Mdot
.35915 .49276 Mdot
.20831 .40601 Mdot
.556 .44822 Mdot
.57718 .4242 Mdot
.67884 .61097 Mdot
.41251 .38607 Mdot
.38501 .66965 Mdot
.61415 .40435 Mdot
.58082 .45616 Mdot
.60004 .38047 Mdot
.53229 .37084 Mdot
.27664 .69935 Mdot
.57038 .41993 Mdot
.48131 .69176 Mdot
.6467 .40018 Mdot
.5707 .43055 Mdot
.41208 .3993 Mdot
.15196 .56255 Mdot
.4118 .66893 Mdot
.57503 .45499 Mdot
.62288 .40246 Mdot
.31716 .49024 Mdot
.54573 .55873 Mdot
.47006 .49998 Mdot
.50584 .61802 Mdot
.75043 .54529 Mdot
.52232 .40491 Mdot
.37577 .35532 Mdot
.59949 .66227 Mdot
.63211 .44804 Mdot
.37665 .36159 Mdot
.65284 .43468 Mdot
.50012 .66894 Mdot
.38517 .69152 Mdot
.22049 .41542 Mdot
.63659 .68075 Mdot
.70836 .6449 Mdot
.28745 .39619 Mdot
.46917 .67704 Mdot
.57016 .40942 Mdot
.30978 .5514 Mdot
.50576 .61958 Mdot
.39308 .67535 Mdot
.5637 .50147 Mdot
.41919 .35939 Mdot
.38768 .36282 Mdot
.59847 .57695 Mdot
.45635 .70218 Mdot
.22641 .69102 Mdot
.31347 .51931 Mdot
.64679 .40799 Mdot
.27002 .3571 Mdot
.38679 .36291 Mdot
.61084 .58262 Mdot
.63382 .68754 Mdot
.3436 .5153 Mdot
.37625 .67253 Mdot
.37873 .3586 Mdot
.4195 .38639 Mdot
.61474 .4776 Mdot
.60089 .45652 Mdot
.71716 .56621 Mdot
.59425 .5703 Mdot
.3384 .54148 Mdot
.61462 .65925 Mdot
.46291 .641 Mdot
.58055 .41345 Mdot
.42231 .33919 Mdot
.41356 .20314 Mdot
.62729 .40468 Mdot
.51084 .66718 Mdot
.3951 .37452 Mdot
.60582 .667 Mdot
.65202 .66887 Mdot
.62131 .43265 Mdot
.53777 .34182 Mdot
.34131 .53221 Mdot
.38486 .36356 Mdot
.32029 .29571 Mdot
.56914 .39356 Mdot
.6022 .45969 Mdot
.52027 .47129 Mdot
.30324 .5172 Mdot
.23476 .37761 Mdot
.60235 .68191 Mdot
.41002 .36215 Mdot
.61151 .3968 Mdot
.64279 .68161 Mdot
.25444 .36098 Mdot
.38964 .68787 Mdot
.4746 .66444 Mdot
.65528 .67115 Mdot
.60908 .67523 Mdot
.62875 .65648 Mdot
.83469 .48891 Mdot
.3819 .31777 Mdot
.67678 .36266 Mdot
.58837 .3913 Mdot
.59913 .57883 Mdot
.59267 .49227 Mdot
.34548 .54665 Mdot
.4687 .64606 Mdot
.59982 .43178 Mdot
.61406 .47759 Mdot
.50133 .39805 Mdot
.60626 .3468 Mdot
.3945 .41064 Mdot
.40688 .38249 Mdot
.6634 .39652 Mdot
.47799 .63681 Mdot
.5374 .86676 Mdot
.74073 .25918 Mdot
.63373 .49089 Mdot
.51933 .53629 Mdot
.41224 .33315 Mdot
.30664 .49965 Mdot
.45706 .49726 Mdot
.35513 .53058 Mdot
.40428 .36216 Mdot
.57748 .41579 Mdot
.29674 .38156 Mdot
.66131 .68841 Mdot
.62808 .43243 Mdot
.3293 .51204 Mdot
.62697 .43339 Mdot
.31796 .54557 Mdot
.33472 .32672 Mdot
.21972 .53427 Mdot
.54702 .43974 Mdot
.57952 .38746 Mdot
.48727 .39942 Mdot
.60111 .44894 Mdot
.50856 .83091 Mdot
.40214 .33094 Mdot
.35769 .77685 Mdot
.6271 .46639 Mdot
.57976 .309 Mdot
.57861 .39249 Mdot
.38751 .76663 Mdot
.60855 .45597 Mdot
.43855 .52717 Mdot
.54439 .42686 Mdot
.58374 .47277 Mdot
.35571 .51174 Mdot
.31682 .49073 Mdot
.43447 .34572 Mdot
.38908 .66699 Mdot
.74027 .31081 Mdot
.59206 .45935 Mdot
.50862 .68318 Mdot
.27587 .53792 Mdot
.60949 .66725 Mdot
.40396 .35961 Mdot
.40412 .8545 Mdot
.35212 .52765 Mdot
.45324 .64734 Mdot
.44391 .80299 Mdot
.46974 .68752 Mdot
.33221 .45839 Mdot
.57155 .53303 Mdot
.60836 .68426 Mdot
.55257 .40823 Mdot
.31792 .26073 Mdot
.22816 .58975 Mdot
.55188 .49169 Mdot
.36097 .50072 Mdot
.67159 .31763 Mdot
.36677 .23779 Mdot
.63158 .6518 Mdot
.63971 .69858 Mdot
.35139 .52493 Mdot
.49662 .68122 Mdot
.52178 .418 Mdot
.63524 .68847 Mdot
.48086 .67556 Mdot
.37627 .69461 Mdot
.412 .53374 Mdot
.41234 .35299 Mdot
.20991 .41031 Mdot
.27229 .4344 Mdot
.34189 .54007 Mdot
.57243 .65164 Mdot
.45739 .35975 Mdot
.41864 .32088 Mdot
.39946 .66441 Mdot
.51873 .65796 Mdot
.38013 .322 Mdot
.52664 .43878 Mdot
.61423 .34413 Mdot
.56879 .45364 Mdot
.61892 .67829 Mdot
.60952 .45074 Mdot
.5113 .66275 Mdot
.33809 .5182 Mdot
.51924 .64522 Mdot
.35369 .51692 Mdot
.32211 .41482 Mdot
.61445 .41766 Mdot
.58388 .47148 Mdot
.71997 .64809 Mdot
.43966 .35625 Mdot
.2933 .29952 Mdot
.52932 .67536 Mdot
.50752 .6384 Mdot
.55699 .46124 Mdot
.39808 .32574 Mdot
.67043 .70466 Mdot
.71781 .65425 Mdot
.63169 .43579 Mdot
.40072 .33023 Mdot
.57385 .4127 Mdot
.80186 .50088 Mdot
.2123 .59972 Mdot
.3982 .34965 Mdot
.39591 .81752 Mdot
.59455 .40343 Mdot
.67548 .47148 Mdot
.55354 .39197 Mdot
.69406 .53291 Mdot
.5641 .39588 Mdot
.37174 .3603 Mdot
.57223 .45144 Mdot
.3781 .33063 Mdot
.48295 .68115 Mdot
.3057 .49669 Mdot
.43046 .36092 Mdot
.63584 .42869 Mdot
.84257 .44372 Mdot
.31985 .51122 Mdot
.56337 .45907 Mdot
.33876 .4959 Mdot
.38027 .38111 Mdot
.42449 .37995 Mdot
.76071 .6753 Mdot
.27116 .50068 Mdot
.31367 .52375 Mdot
.56442 .42122 Mdot
.24829 .43602 Mdot
.56461 .42879 Mdot
.70442 .57218 Mdot
.60086 .47958 Mdot
.56458 .39454 Mdot
.74465 .72688 Mdot
.30145 .5346 Mdot
.23452 .69399 Mdot
.78336 .60378 Mdot
.83483 .50216 Mdot
.42836 .32176 Mdot
.63063 .65167 Mdot
.80766 .43323 Mdot
.40952 .68484 Mdot
.48365 .66277 Mdot
.60107 .432 Mdot
.34378 .33014 Mdot
.32253 .54193 Mdot
.62659 .66299 Mdot
.54721 .44107 Mdot
.51569 .6641 Mdot
.6171 .75439 Mdot
.32838 .47425 Mdot
.40643 .35433 Mdot
.43708 .36649 Mdot
.36262 .8192 Mdot
.61201 .39625 Mdot
.57163 .46706 Mdot
.3229 .50489 Mdot
.60919 .35226 Mdot
.60193 .6672 Mdot
.47067 .76353 Mdot
.3142 .52348 Mdot
.4951 .55113 Mdot
.41258 .37916 Mdot
.5973 .44257 Mdot
.47204 .46759 Mdot
.38554 .59103 Mdot
.56159 .22403 Mdot
.62393 .67716 Mdot
.70576 .58313 Mdot
.37173 .36094 Mdot
.3308 .51979 Mdot
.53177 .70106 Mdot
.6396 .38968 Mdot
.59127 .44497 Mdot
.70335 .58715 Mdot
.56625 .57853 Mdot
.68406 .69302 Mdot
.53869 .45247 Mdot
.56593 .57507 Mdot
.56253 .46817 Mdot
.60992 .38089 Mdot
.53317 .45176 Mdot
.60473 .46308 Mdot
.40411 .33069 Mdot
.51125 .3937 Mdot
.47733 .65483 Mdot
.48722 .25265 Mdot
.43233 .47348 Mdot
.57382 .39792 Mdot
.57347 .42109 Mdot
.61456 .24894 Mdot
.26044 .53647 Mdot
.41538 .33882 Mdot
.36442 .33759 Mdot
.34124 .47852 Mdot
.54521 .35953 Mdot
.52718 .66874 Mdot
.50494 .42708 Mdot
.51796 .64893 Mdot
.39467 .32858 Mdot
.51147 .63522 Mdot
.32794 .47648 Mdot
.50283 .62302 Mdot
.52802 .6741 Mdot
.31867 .54355 Mdot
.42064 .37733 Mdot
.62278 .44582 Mdot
.35122 .48702 Mdot
.68109 .60926 Mdot
.62004 .67916 Mdot
.76266 .67338 Mdot
.64935 .41899 Mdot
.40915 .44853 Mdot
.73091 .46432 Mdot
.51757 .64492 Mdot
.227 .6448 Mdot
.42875 .34635 Mdot
.66103 .69755 Mdot
.39738 .32797 Mdot
.19223 .4087 Mdot
.62535 .66039 Mdot
.80805 .62462 Mdot
.41369 .69863 Mdot
.61052 .73993 Mdot
.54301 .46369 Mdot
.46141 .3437 Mdot
.4829 .62367 Mdot
.32407 .54218 Mdot
.39273 .7081 Mdot
.59324 .4739 Mdot
.29487 .68899 Mdot
.44257 .35923 Mdot
.37679 .69078 Mdot
.33056 .52649 Mdot
.35455 .48717 Mdot
.62321 .40872 Mdot
.50192 .7876 Mdot
.60442 .47322 Mdot
.43703 .70232 Mdot
.73328 .56447 Mdot
.50416 .44179 Mdot
.5503 .45199 Mdot
.52284 .6335 Mdot
.57268 .41322 Mdot
.69237 .36473 Mdot
.29624 .27328 Mdot
.52018 .43952 Mdot
.34078 .6806 Mdot
.61663 .70756 Mdot
.40604 .37449 Mdot
.64838 .47238 Mdot
.39231 .67124 Mdot
.59352 .40137 Mdot
.29114 .23288 Mdot
.63537 .67584 Mdot
.56103 .64447 Mdot
.59291 .38889 Mdot
.61759 .40622 Mdot
.3922 .27208 Mdot
.34756 .32136 Mdot
.37534 .67298 Mdot
.58678 .44769 Mdot
.75186 .56509 Mdot
.32666 .4932 Mdot
.61369 .46781 Mdot
.57287 .45984 Mdot
.5531 .19968 Mdot
.30597 .51162 Mdot
.51758 .64062 Mdot
.39617 .69269 Mdot
.45843 .64864 Mdot
.58802 .66669 Mdot
.45803 .51271 Mdot
.60941 .57427 Mdot
.2134 .595 Mdot
.62336 .65224 Mdot
.62972 .40207 Mdot
.62929 .5026 Mdot
.60388 .40336 Mdot
.64716 .69696 Mdot
.30421 .522 Mdot
.42444 .3446 Mdot
.22534 .41954 Mdot
.39793 .67931 Mdot
.54248 .40739 Mdot
.65607 .68311 Mdot
.42227 .36463 Mdot
.57205 .63285 Mdot
.40873 .36843 Mdot
.32015 .53087 Mdot
.36719 .52196 Mdot
.64291 .66932 Mdot
.38989 .3271 Mdot
.45642 .69044 Mdot
.77162 .62698 Mdot
.58807 .48175 Mdot
.32283 .4673 Mdot
.41344 .33002 Mdot
.44324 .38843 Mdot
.44092 .34662 Mdot
.61991 .42475 Mdot
.52956 .54338 Mdot
.6215 .38574 Mdot
.34744 .53076 Mdot
.4788 .67017 Mdot
.60295 .56626 Mdot
.35439 .26837 Mdot
.54985 .59345 Mdot
.58487 .49382 Mdot
.56016 .44907 Mdot
.57071 .46176 Mdot
.58647 .48737 Mdot
.49673 .70946 Mdot
.61052 .4145 Mdot
.35515 .51216 Mdot
.50946 .65769 Mdot
.58349 .39337 Mdot
.38706 .67242 Mdot
.49415 .50603 Mdot
.60055 .65839 Mdot
.44351 .49961 Mdot
.80934 .39097 Mdot
.42405 .36375 Mdot
.46365 .64695 Mdot
.48235 .66089 Mdot
.61709 .65461 Mdot
.32479 .5409 Mdot
.41348 .37052 Mdot
.70932 .52318 Mdot
.62169 .65657 Mdot
.57532 .45334 Mdot
.39491 .74442 Mdot
.35301 .73481 Mdot
.54588 .41479 Mdot
.59133 .4284 Mdot
.38764 .69591 Mdot
.50867 .67795 Mdot
.47406 .15178 Mdot
.62012 .60502 Mdot
.6374 .66568 Mdot
.62051 .6938 Mdot
.42805 .32944 Mdot
.62038 .50233 Mdot
.35005 .52127 Mdot
.66083 .61689 Mdot
.66281 .52872 Mdot
.69591 .64585 Mdot
.63729 .78273 Mdot
.62966 .42012 Mdot
.43757 .29136 Mdot
.55314 .44541 Mdot
.44173 .36962 Mdot
.3968 .39148 Mdot
.41941 .34537 Mdot
.33847 .53737 Mdot
.6141 .32174 Mdot
.35399 .50066 Mdot
.7858 .34354 Mdot
.37097 .34856 Mdot
.52647 .71935 Mdot
.50614 .63143 Mdot
.65864 .44057 Mdot
.60392 .67161 Mdot
.36064 .46756 Mdot
.53763 .4637 Mdot
.28729 .71111 Mdot
.50063 .62442 Mdot
.41818 .38179 Mdot
.57697 .53203 Mdot
.67239 .23293 Mdot
.48388 .51846 Mdot
.6789 .40435 Mdot
.39354 .28234 Mdot
.61365 .66105 Mdot
.55818 .2252 Mdot
.61701 .69636 Mdot
.33643 .51004 Mdot
.59683 .4714 Mdot
.61327 .46055 Mdot
.55306 .46159 Mdot
.61106 .41628 Mdot
.32558 .48325 Mdot
.63873 .46339 Mdot
.17818 .41333 Mdot
.38483 .69372 Mdot
.80366 .4854 Mdot
.64189 .69022 Mdot
.36087 .52558 Mdot
.51189 .65524 Mdot
.37863 .67493 Mdot
.63247 .58227 Mdot
.54564 .42557 Mdot
.60107 .42993 Mdot
.39572 .66168 Mdot
.53368 .44183 Mdot
.52927 .39095 Mdot
.47911 .65267 Mdot
.55136 .5926 Mdot
.6522 .6636 Mdot
.64965 .68789 Mdot
.30646 .52498 Mdot
.39209 .32711 Mdot
.62945 .68417 Mdot
.50039 .67801 Mdot
.64943 .4484 Mdot
.63818 .42721 Mdot
.41553 .33082 Mdot
.20866 .38627 Mdot
.6165 .64945 Mdot
.58285 .53219 Mdot
.37387 .3463 Mdot
.38398 .31571 Mdot
.58919 .4441 Mdot
.51853 .45977 Mdot
.44577 .39005 Mdot
.64539 .66144 Mdot
.36199 .52284 Mdot
.60379 .72392 Mdot
.3301 .50754 Mdot
.41787 .36935 Mdot
.62899 .46072 Mdot
.41709 .37862 Mdot
.5945 .39816 Mdot
.82621 .68299 Mdot
.6127 .45851 Mdot
.19436 .55488 Mdot
.6895 .54695 Mdot
.48521 .65866 Mdot
.45621 .68972 Mdot
.38135 .68059 Mdot
.37273 .35071 Mdot
.63435 .44677 Mdot
.61911 .6942 Mdot
.82523 .55682 Mdot
.46105 .37239 Mdot
.49065 .66931 Mdot
.52184 .67278 Mdot
.30502 .53749 Mdot
.60155 .38971 Mdot
.59696 .44536 Mdot
.50751 .62441 Mdot
.74631 .46128 Mdot
.37914 .34823 Mdot
.56922 .46497 Mdot
.56265 .44088 Mdot
.48269 .6555 Mdot
.76868 .63066 Mdot
.38942 .29972 Mdot
.59612 .46955 Mdot
.56777 .67749 Mdot
.34786 .5463 Mdot
.57398 .48343 Mdot
.6372 .46519 Mdot
.61498 .68537 Mdot
.78731 .4299 Mdot
.31412 .25216 Mdot
.34234 .54651 Mdot
.386 .66932 Mdot
.63162 .39977 Mdot
.50436 .6315 Mdot
.63709 .4265 Mdot
.72288 .32308 Mdot
.37999 .69201 Mdot
.60065 .4125 Mdot
.61376 .50135 Mdot
.40322 .3916 Mdot
.61172 .41111 Mdot
.60358 .22961 Mdot
.4762 .62408 Mdot
.60597 .41133 Mdot
.51588 .34912 Mdot
.3101 .50464 Mdot
.63156 .49186 Mdot
.64224 .69414 Mdot
.69559 .52767 Mdot
.28868 .40881 Mdot
.5411 .62919 Mdot
.64842 .68683 Mdot
.62802 .44159 Mdot
.48809 .68302 Mdot
.33739 .54353 Mdot
.28237 .68359 Mdot
.54391 .45187 Mdot
.32275 .50821 Mdot
.33697 .51994 Mdot
.64264 .6772 Mdot
.26414 .73224 Mdot
.64656 .4627 Mdot
.60436 .44892 Mdot
.61019 .22685 Mdot
.42549 .38999 Mdot
.61409 .44887 Mdot
.62883 .4041 Mdot
.3518 .50439 Mdot
.36351 .2942 Mdot
.64583 .29357 Mdot
.47603 .77244 Mdot
.32242 .5482 Mdot
.50146 .6039 Mdot
.48371 .68363 Mdot
.6395 .69033 Mdot
.40004 .37155 Mdot
.59319 .66138 Mdot
.47442 .64673 Mdot
.62024 .39907 Mdot
.34907 .50756 Mdot
.46326 .20976 Mdot
.2957 .52879 Mdot
.51312 .61572 Mdot
.44233 .38067 Mdot
.26112 .37535 Mdot
.23227 .28948 Mdot
.28153 .43509 Mdot
.33675 .56808 Mdot
.60937 .66777 Mdot
.38376 .72274 Mdot
.56158 .44398 Mdot
.54738 .23119 Mdot
.62429 .43991 Mdot
.47618 .33851 Mdot
.46493 .65898 Mdot
.39665 .66366 Mdot
.59812 .47034 Mdot
.72391 .57575 Mdot
.30059 .49607 Mdot
.30625 .53983 Mdot
.60135 .41883 Mdot
.32609 .53593 Mdot
.59688 .45509 Mdot
.51682 .65631 Mdot
.21159 .65726 Mdot
.56107 .45377 Mdot
.59318 .37825 Mdot
.26957 .55387 Mdot
.77374 .66201 Mdot
.47162 .69602 Mdot
.42782 .28617 Mdot
.63776 .20817 Mdot
.32722 .53555 Mdot
.57861 .50477 Mdot
.49202 .62169 Mdot
.38751 .69613 Mdot
.45264 .68942 Mdot
.61796 .44107 Mdot
.61644 .43521 Mdot
.55631 .46038 Mdot
.57775 .4232 Mdot
.55453 .23169 Mdot
.55588 .36262 Mdot
.47476 .30857 Mdot
.59968 .4283 Mdot
.4721 .34931 Mdot
.34687 .48561 Mdot
.37336 .39877 Mdot
.59718 .65086 Mdot
.62906 .41802 Mdot
.35302 .39293 Mdot
.35409 .54004 Mdot
.78444 .3413 Mdot
.30299 .52849 Mdot
.50119 .64863 Mdot
.30204 .50845 Mdot
.58791 .39649 Mdot
.3943 .36022 Mdot
.49336 .61703 Mdot
.26633 .63436 Mdot
.48485 .66371 Mdot
.59733 .39283 Mdot
.59024 .70239 Mdot
.48016 .66136 Mdot
.47228 .48546 Mdot
.39337 .36517 Mdot
.74812 .57609 Mdot
.39548 .39147 Mdot
.60343 .41002 Mdot
.5984 .41082 Mdot
.38648 .70125 Mdot
.30694 .49076 Mdot
.3808 .3837 Mdot
.17213 .63264 Mdot
.6012 .68574 Mdot
.41423 .34383 Mdot
.65104 .39181 Mdot
.55079 .56591 Mdot
.39084 .35253 Mdot
.74189 .52226 Mdot
.3276 .54246 Mdot
.3849 .31895 Mdot
.64642 .38963 Mdot
.32942 .58455 Mdot
.6638 .68815 Mdot
.53018 .65043 Mdot
.44178 .55459 Mdot
.47825 .6261 Mdot
.36169 .52842 Mdot
.52895 .62589 Mdot
.32866 .4908 Mdot
.28319 .31365 Mdot
.62837 .33945 Mdot
.30081 .54664 Mdot
.36516 .51472 Mdot
.48691 .63601 Mdot
.54573 .44919 Mdot
.40873 .47959 Mdot
.53791 .45371 Mdot
.55225 .47445 Mdot
.32189 .49458 Mdot
.37452 .37312 Mdot
.37171 .38021 Mdot
.46619 .34828 Mdot
.43744 .36768 Mdot
.51913 .65117 Mdot
.21006 .5966 Mdot
.26117 .32745 Mdot
.31938 .50319 Mdot
.35998 .48931 Mdot
.56708 .42649 Mdot
.49953 .63083 Mdot
.47186 .67985 Mdot
.34783 .52014 Mdot
.49423 .22095 Mdot
.62573 .38758 Mdot
.43871 .38931 Mdot
.37146 .34249 Mdot
.39645 .3467 Mdot
.43698 .33972 Mdot
.61872 .28866 Mdot
.32623 .54299 Mdot
.37167 .35017 Mdot
.5995 .41651 Mdot
.6164 .43724 Mdot
.4056 .67423 Mdot
.64853 .69043 Mdot
.65356 .42849 Mdot
.53014 .41482 Mdot
.5911 .44235 Mdot
.47573 .6643 Mdot
.66764 .45121 Mdot
.37888 .67894 Mdot
.52551 .66207 Mdot
.53194 .66604 Mdot
.40822 .66941 Mdot
.47038 .36038 Mdot
.64258 .20289 Mdot
.57101 .41778 Mdot
.65652 .35935 Mdot
.50266 .63442 Mdot
.24658 .67697 Mdot
.24041 .374 Mdot
.55073 .45754 Mdot
.40068 .56365 Mdot
.51756 .62287 Mdot
.4289 .3835 Mdot
.61854 .44561 Mdot
.40657 .68297 Mdot
.60091 .65921 Mdot
.64775 .38641 Mdot
.39908 .69174 Mdot
.38544 .32905 Mdot
.62194 .64473 Mdot
.39189 .31721 Mdot
.51427 .62017 Mdot
.61751 .49992 Mdot
.74218 .22844 Mdot
.4584 .6537 Mdot
.81079 .57608 Mdot
.34022 .32772 Mdot
.56469 .46328 Mdot
.4647 .64196 Mdot
.42988 .38589 Mdot
.35761 .53941 Mdot
.56 .56687 Mdot
.43323 .35384 Mdot
.38591 .66805 Mdot
.40392 .68109 Mdot
.47909 .65513 Mdot
.40302 .38316 Mdot
.61875 .46636 Mdot
.38871 .37999 Mdot
.30125 .51159 Mdot
.55209 .43365 Mdot
.72437 .27653 Mdot
.63348 .3527 Mdot
.37317 .35808 Mdot
.51872 .66381 Mdot
.65384 .69868 Mdot
.54737 .4298 Mdot
.80302 .56774 Mdot
.61769 .39349 Mdot
.32684 .49635 Mdot
.33293 .76151 Mdot
.49106 .20497 Mdot
.57626 .39386 Mdot
.56842 .42581 Mdot
.32254 .54491 Mdot
.54597 .42723 Mdot
.56544 .39693 Mdot
.27153 .51922 Mdot
.39656 .38742 Mdot
.5685 .44925 Mdot
.48533 .67807 Mdot
.31489 .27334 Mdot
.61731 .38585 Mdot
.36787 .64861 Mdot
.73853 .57931 Mdot
.31714 .76089 Mdot
.62404 .44831 Mdot
.64033 .6019 Mdot
.5823 .42424 Mdot
.62524 .42398 Mdot
.56246 .42553 Mdot
.42114 .27692 Mdot
.48452 .63615 Mdot
.50342 .66521 Mdot
.6639 .68517 Mdot
.74159 .5747 Mdot
.6225 .68915 Mdot
.30969 .53804 Mdot
.61746 .77006 Mdot
.38124 .69114 Mdot
.38791 .32674 Mdot
.62061 .4599 Mdot
.48225 .61858 Mdot
.60025 .4411 Mdot
.58787 .398 Mdot
.52575 .63606 Mdot
.45868 .67569 Mdot
.55664 .6617 Mdot
.60696 .6848 Mdot
.42673 .35176 Mdot
.6119 .48002 Mdot
.64539 .66475 Mdot
.62381 .46099 Mdot
.58747 .59368 Mdot
.42329 .3465 Mdot
.39374 .3863 Mdot
.39735 .39731 Mdot
.62027 .39886 Mdot
.57455 .39871 Mdot
.35335 .49858 Mdot
.39502 .32417 Mdot
.30839 .51867 Mdot
.49507 .61936 Mdot
.4511 .66062 Mdot
.61791 .44084 Mdot
.64372 .5113 Mdot
.61371 .68688 Mdot
.50697 .64943 Mdot
.39038 .66173 Mdot
.65711 .70046 Mdot
.60835 .39371 Mdot
.52233 .63203 Mdot
.65199 .68468 Mdot
.46004 .23462 Mdot
.59971 .17942 Mdot
.64986 .69924 Mdot
.59883 .41893 Mdot
.38134 .27076 Mdot
.7558 .64049 Mdot
.60515 .69025 Mdot
.33722 .4997 Mdot
.62444 .39956 Mdot
.72216 .42209 Mdot
.60246 .65287 Mdot
.31065 .28953 Mdot
.48743 .65771 Mdot
.36414 .57123 Mdot
.61433 .36699 Mdot
.5298 .23741 Mdot
.59257 .66897 Mdot
.41208 .36629 Mdot
.38614 .40134 Mdot
.58136 .43767 Mdot
.58702 .65442 Mdot
.30818 .54404 Mdot
.49391 .6598 Mdot
.48809 .6881 Mdot
.39997 .38374 Mdot
.23769 .46384 Mdot
.49104 .67411 Mdot
.60478 .52856 Mdot
.42625 .77035 Mdot
.57253 .34882 Mdot
.49286 .36776 Mdot
.23835 .58148 Mdot
.6378 .40948 Mdot
.64126 .7011 Mdot
.35747 .52842 Mdot
.35275 .52066 Mdot
.31647 .52516 Mdot
.45857 .68973 Mdot
.45428 .49714 Mdot
.49097 .62601 Mdot
.27983 .66847 Mdot
.64233 .68209 Mdot
.76758 .55698 Mdot
.62931 .45151 Mdot
.56051 .45025 Mdot
.64823 .41011 Mdot
.59655 .47681 Mdot
.57772 .43003 Mdot
.32319 .53923 Mdot
.46946 .6909 Mdot
.56569 .74151 Mdot
.4006 .33868 Mdot
.53784 .59609 Mdot
.50644 .63142 Mdot
.38611 .69575 Mdot
.62908 .66635 Mdot
.53225 .52624 Mdot
.53548 .62795 Mdot
.51119 .63631 Mdot
.65554 .43786 Mdot
.37933 .36295 Mdot
.50966 .44037 Mdot
.5912 .41378 Mdot
.51083 .6494 Mdot
.43747 .65902 Mdot
.65053 .27581 Mdot
.54564 .50324 Mdot
.67398 .68963 Mdot
.53819 .55321 Mdot
.61208 .69481 Mdot
.56952 .37904 Mdot
.25384 .68702 Mdot
.47536 .64601 Mdot
.4937 .64787 Mdot
.65335 .69013 Mdot
.66452 .48588 Mdot
.39811 .3774 Mdot
.39518 .66349 Mdot
.34097 .49366 Mdot
.60396 .40504 Mdot
.45186 .66726 Mdot
.68794 .42075 Mdot
.532 .78103 Mdot
.31593 .51887 Mdot
.52296 .66401 Mdot
.59783 .39014 Mdot
.59733 .42087 Mdot
.61002 .66366 Mdot
.37264 .41999 Mdot
.65509 .38813 Mdot
.83546 .50002 Mdot
.22117 .53191 Mdot
.20979 .49517 Mdot
.5914 .44512 Mdot
.40159 .38631 Mdot
.39887 .68707 Mdot
.62774 .65829 Mdot
.63267 .4643 Mdot
.61174 .18586 Mdot
.41218 .40555 Mdot
.33204 .51372 Mdot
.40773 .68091 Mdot
.45487 .49444 Mdot
.62163 .39601 Mdot
.62378 .44047 Mdot
.616 .4211 Mdot
.53924 .14811 Mdot
.48999 .6711 Mdot
.44141 .3623 Mdot
.62195 .67495 Mdot
.43871 .3682 Mdot
.49397 .66487 Mdot
.23349 .42191 Mdot
.56276 .4023 Mdot
.43946 .38631 Mdot
.40896 .36519 Mdot
.30521 .53726 Mdot
.35819 .53993 Mdot
.56644 .64876 Mdot
.61134 .45905 Mdot
.40538 .68467 Mdot
.39849 .39296 Mdot
.4698 .68548 Mdot
.62283 .66013 Mdot
.35429 .49366 Mdot
.60084 .4275 Mdot
.47473 .65302 Mdot
.54044 .48135 Mdot
.38657 .35433 Mdot
.5105 .63596 Mdot
.41181 .66641 Mdot
.62762 .69604 Mdot
.60951 .43238 Mdot
.67447 .6983 Mdot
.40308 .66369 Mdot
.56132 .44115 Mdot
.52364 .50523 Mdot
.67685 .70784 Mdot
.28313 .64999 Mdot
.47733 .63245 Mdot
.39901 .67037 Mdot
.40637 .39487 Mdot
.30867 .31112 Mdot
.49508 .65123 Mdot
.52475 .51345 Mdot
.36485 .42927 Mdot
.60927 .48173 Mdot
.40348 .35072 Mdot
.39471 .72872 Mdot
.82598 .44445 Mdot
.78553 .5622 Mdot
.56604 .45962 Mdot
.46848 .63679 Mdot
.65363 .67739 Mdot
.31928 .50271 Mdot
.36709 .65012 Mdot
.66513 .35039 Mdot
.53233 .63554 Mdot
.56631 .42351 Mdot
.39468 .39014 Mdot
.34527 .52248 Mdot
.30476 .38476 Mdot
.51133 .67287 Mdot
.46473 .65489 Mdot
.58359 .39278 Mdot
.63541 .68617 Mdot
.77652 .47274 Mdot
.51227 .66346 Mdot
.45277 .66511 Mdot
.36168 .71923 Mdot
.65639 .68474 Mdot
.5877 .42543 Mdot
.46579 .34642 Mdot
.58139 .48731 Mdot
.81423 .57374 Mdot
.38249 .67458 Mdot
.39814 .33763 Mdot
.62505 .43437 Mdot
.46573 .7769 Mdot
.50736 .65404 Mdot
.51442 .53226 Mdot
.4614 .62857 Mdot
.32944 .54226 Mdot
.45238 .66363 Mdot
.61001 .44591 Mdot
.2984 .50008 Mdot
.61458 .68733 Mdot
.59855 .46746 Mdot
.57234 .40018 Mdot
.43476 .37828 Mdot
.33733 .50908 Mdot
.39767 .22461 Mdot
.35983 .49304 Mdot
.35123 .5408 Mdot
.36733 .38033 Mdot
.57717 .44653 Mdot
.50367 .64543 Mdot
.5274 .62627 Mdot
.62606 .46872 Mdot
.21014 .62816 Mdot
.39712 .37929 Mdot
.56733 .63746 Mdot
.49008 .15447 Mdot
.52513 .4876 Mdot
.40169 .66044 Mdot
.394 .4238 Mdot
.31726 .54661 Mdot
.60019 .42303 Mdot
.37533 .34981 Mdot
.45379 .67853 Mdot
.48973 .67481 Mdot
.62606 .46214 Mdot
.34103 .52131 Mdot
.61063 .65334 Mdot
.46218 .66308 Mdot
.50339 .78658 Mdot
.61736 .41517 Mdot
.30051 .69023 Mdot
.46168 .65527 Mdot
.839 .55022 Mdot
.55392 .75602 Mdot
.4025 .34765 Mdot
.58322 .39934 Mdot
.43585 .3653 Mdot
.61733 .67378 Mdot
.52538 .60365 Mdot
.33963 .51908 Mdot
.56099 .5105 Mdot
.25624 .29029 Mdot
.48987 .63213 Mdot
.40507 .33126 Mdot
.57899 .3931 Mdot
.5606 .52057 Mdot
.60627 .45133 Mdot
.37012 .29056 Mdot
.57536 .65625 Mdot
.31823 .49736 Mdot
.32979 .49634 Mdot
.55763 .44205 Mdot
.60725 .66001 Mdot
.52688 .64727 Mdot
.49366 .65865 Mdot
.61411 .85865 Mdot
.40936 .66326 Mdot
.71447 .56085 Mdot
.61405 .4339 Mdot
.4808 .68532 Mdot
.35213 .26716 Mdot
.32223 .50502 Mdot
.60013 .47654 Mdot
.50364 .68277 Mdot
.28387 .57823 Mdot
.57978 .58892 Mdot
.58091 .42997 Mdot
.55048 .37793 Mdot
.33917 .49453 Mdot
.70911 .63326 Mdot
.49711 .62398 Mdot
.59899 .47893 Mdot
.35216 .4802 Mdot
.43747 .78434 Mdot
.26352 .31132 Mdot
.42638 .35149 Mdot
.4871 .61372 Mdot
.32315 .53952 Mdot
.64685 .37644 Mdot
.64412 .68982 Mdot
.48004 .62269 Mdot
.48066 .66633 Mdot
.56118 .41964 Mdot
.65679 .43999 Mdot
.52811 .49283 Mdot
.39837 .33186 Mdot
.3404 .4832 Mdot
.59906 .47177 Mdot
.23755 .46947 Mdot
.55968 .46586 Mdot
.34721 .48879 Mdot
.8603 .35351 Mdot
.55382 .47231 Mdot
.60349 .45146 Mdot
.78267 .49412 Mdot
.43445 .35692 Mdot
.43624 .37108 Mdot
.21486 .55176 Mdot
.61359 .43379 Mdot
.58914 .75125 Mdot
.42887 .35627 Mdot
.39339 .3758 Mdot
.50391 .72882 Mdot
.54974 .44335 Mdot
.71403 .65336 Mdot
.35152 .51825 Mdot
.35589 .52266 Mdot
.39116 .38174 Mdot
.65255 .38299 Mdot
.33602 .54572 Mdot
.59092 .25274 Mdot
.50329 .62807 Mdot
.25713 .6931 Mdot
.3853 .3498 Mdot
.40144 .45943 Mdot
.31769 .51006 Mdot
.78852 .34778 Mdot
.39359 .57538 Mdot
.55363 .45736 Mdot
.61026 .42752 Mdot
.6204 .69113 Mdot
.56705 .49308 Mdot
.38039 .67383 Mdot
.32546 .53604 Mdot
.76422 .43167 Mdot
.41889 .34547 Mdot
.60749 .45774 Mdot
.54155 .53491 Mdot
.31066 .40674 Mdot
.33668 .68648 Mdot
.40598 .37359 Mdot
.40978 .35111 Mdot
.47958 .63499 Mdot
.4679 .66392 Mdot
.57645 .4405 Mdot
.34777 .52874 Mdot
.39394 .32291 Mdot
.34043 .48756 Mdot
.47356 .64906 Mdot
.5087 .63966 Mdot
.37976 .69279 Mdot
.53008 .43413 Mdot
.52449 .64814 Mdot
.48342 .79152 Mdot
.23417 .46242 Mdot
.42231 .32345 Mdot
.29859 .24664 Mdot
.30481 .38245 Mdot
.72377 .4854 Mdot
.60648 .68662 Mdot
.42794 .67165 Mdot
.31329 .49119 Mdot
.56612 .42894 Mdot
.6008 .4353 Mdot
.39144 .68064 Mdot
.29828 .50744 Mdot
.62072 .66415 Mdot
.3004 .5008 Mdot
.64561 .68154 Mdot
.45029 .68144 Mdot
.6232 .39 Mdot
.633 .41143 Mdot
.32033 .53666 Mdot
.51739 .63737 Mdot
.50849 .6603 Mdot
.61643 .69696 Mdot
.58145 .57397 Mdot
.4777 .65564 Mdot
.38545 .35132 Mdot
.59826 .2943 Mdot
.40072 .68297 Mdot
.61692 .44681 Mdot
.60486 .58085 Mdot
.52801 .21815 Mdot
.5961 .4841 Mdot
.41021 .67472 Mdot
.50281 .8594 Mdot
.62248 .45548 Mdot
.43104 .84861 Mdot
.40071 .67016 Mdot
.43482 .35555 Mdot
.4673 .6402 Mdot
.37701 .67865 Mdot
.61336 .36392 Mdot
.62735 .70697 Mdot
.64544 .4415 Mdot
.43315 .36212 Mdot
.40745 .39991 Mdot
.19977 .48938 Mdot
.8116 .57742 Mdot
.62215 .69883 Mdot
.6388 .66918 Mdot
.49289 .65188 Mdot
.71813 .73738 Mdot
.65037 .4001 Mdot
.63306 .66435 Mdot
.75532 .44134 Mdot
.57311 .41926 Mdot
.69502 .57795 Mdot
.40523 .55971 Mdot
.40011 .38533 Mdot
.47577 .37204 Mdot
.50033 .65415 Mdot
.40992 .33373 Mdot
.2236 .45099 Mdot
.64852 .41493 Mdot
.42072 .34465 Mdot
.34837 .49197 Mdot
.27818 .60466 Mdot
.42649 .37654 Mdot
.59533 .59134 Mdot
.34803 .52399 Mdot
.41758 .71442 Mdot
.76601 .48869 Mdot
.2137 .28418 Mdot
.33013 .53811 Mdot
.5174 .62789 Mdot
.51869 .62313 Mdot
.49128 .65689 Mdot
.43156 .34878 Mdot
.48454 .68135 Mdot
.39076 .33316 Mdot
.75322 .6555 Mdot
.58405 .57252 Mdot
.64392 .66967 Mdot
.26688 .51525 Mdot
.40888 .3584 Mdot
.23953 .63764 Mdot
.24213 .28311 Mdot
.60334 .41797 Mdot
.35685 .48732 Mdot
.65168 .69204 Mdot
.83347 .61856 Mdot
.61709 .68785 Mdot
.48941 .6226 Mdot
.26392 .70665 Mdot
.59733 .45779 Mdot
.69042 .32334 Mdot
.62634 .69753 Mdot
.41318 .37534 Mdot
.5604 .44466 Mdot
.44427 .68805 Mdot
.63539 .68971 Mdot
.60481 .6563 Mdot
.5698 .43873 Mdot
.41687 .38338 Mdot
.50774 .64327 Mdot
.31738 .48522 Mdot
.60055 .68845 Mdot
.63114 .36002 Mdot
.59918 .48687 Mdot
.64205 .40881 Mdot
.47906 .50817 Mdot
.73339 .41361 Mdot
.32864 .53551 Mdot
.76221 .60171 Mdot
.47015 .66598 Mdot
.42725 .73377 Mdot
.22476 .55251 Mdot
.30874 .46331 Mdot
.38451 .67266 Mdot
.37866 .68264 Mdot
.57767 .4329 Mdot
.7353 .41604 Mdot
.35613 .7684 Mdot
.26395 .54596 Mdot
.39809 .68505 Mdot
.49873 .66025 Mdot
.39053 .40308 Mdot
.19253 .46153 Mdot
.59534 .49004 Mdot
.32064 .55002 Mdot
.4749 .65807 Mdot
.72089 .32049 Mdot
.63557 .68173 Mdot
.24576 .66807 Mdot
.57603 .39548 Mdot
.58288 .47118 Mdot
.32852 .52938 Mdot
.35414 .50275 Mdot
.34095 .66248 Mdot
.20603 .50926 Mdot
.67097 .63471 Mdot
.32079 .32049 Mdot
.70847 .31238 Mdot
.37884 .40245 Mdot
.37337 .36133 Mdot
.41303 .68113 Mdot
.35927 .49845 Mdot
.62697 .43889 Mdot
.38981 .32485 Mdot
.33553 .68936 Mdot
.44573 .33206 Mdot
.70679 .57652 Mdot
.56413 .76455 Mdot
.60039 .39563 Mdot
.3801 .36934 Mdot
.41706 .3386 Mdot
.40782 .3216 Mdot
.40933 .67191 Mdot
.58774 .44812 Mdot
.54533 .44357 Mdot
.58488 .47505 Mdot
.59289 .35475 Mdot
.61466 .41227 Mdot
.24363 .50018 Mdot
.50157 .55302 Mdot
.77319 .42832 Mdot
.58322 .48316 Mdot
.35296 .52824 Mdot
.64655 .41861 Mdot
.60842 .65833 Mdot
.56408 .42607 Mdot
.70648 .56868 Mdot
.32354 .51594 Mdot
.64711 .50014 Mdot
.31849 .31956 Mdot
.56857 .39881 Mdot
.63297 .65408 Mdot
.7326 .44057 Mdot
.38988 .23351 Mdot
.52969 .5904 Mdot
.38509 .35321 Mdot
.53936 .63982 Mdot
.30063 .51718 Mdot
.50149 .64423 Mdot
.5704 .47666 Mdot
.40978 .68204 Mdot
.29245 .45871 Mdot
.40372 .46244 Mdot
.63091 .42987 Mdot
.66103 .46021 Mdot
.38685 .36542 Mdot
.52146 .63121 Mdot
.35108 .36287 Mdot
.62033 .42706 Mdot
.62226 .67814 Mdot
.64019 .68774 Mdot
.22028 .49714 Mdot
.7309 .30325 Mdot
.29999 .31087 Mdot
.32812 .53104 Mdot
.50781 .66777 Mdot
.59147 .66479 Mdot
.67342 .3716 Mdot
.33236 .55321 Mdot
.31157 .5432 Mdot
.34255 .51228 Mdot
.60612 .40071 Mdot
.38085 .67464 Mdot
.74984 .39805 Mdot
.38317 .67028 Mdot
.56516 .40207 Mdot
.48313 .66986 Mdot
.3758 .69061 Mdot
.62799 .69357 Mdot
.30605 .52443 Mdot
.47113 .65009 Mdot
.606 .40861 Mdot
.42551 .36078 Mdot
.57272 .56834 Mdot
.67167 .54091 Mdot
.81061 .53227 Mdot
.81419 .51447 Mdot
.38453 .39174 Mdot
.77425 .34638 Mdot
.33137 .46768 Mdot
.49702 .22137 Mdot
.57628 .69192 Mdot
.62248 .46919 Mdot
.1828 .56886 Mdot
.49573 .62361 Mdot
.52453 .63274 Mdot
.58684 .42319 Mdot
.46063 .68131 Mdot
.60714 .45559 Mdot
.46672 .65613 Mdot
.53512 .59665 Mdot
.59459 .4913 Mdot
.52414 .64217 Mdot
.61357 .37155 Mdot
.54833 .42989 Mdot
.39706 .38616 Mdot
.46786 .63448 Mdot
.56349 .47054 Mdot
.77607 .70086 Mdot
.35469 .4972 Mdot
.40899 .67324 Mdot
.60353 .61953 Mdot
.32033 .53929 Mdot
.41019 .34237 Mdot
.55312 .47752 Mdot
.60706 .67629 Mdot
.4154 .36493 Mdot
.56821 .64373 Mdot
.63247 .69874 Mdot
.21026 .5988 Mdot
.38345 .35922 Mdot
.39866 .68244 Mdot
.6163 .69033 Mdot
.65329 .47377 Mdot
.4675 .63118 Mdot
.65334 .53257 Mdot
.39309 .66573 Mdot
.59812 .44526 Mdot
.49118 .68995 Mdot
.35594 .49541 Mdot
.57248 .46148 Mdot
.45719 .65571 Mdot
.40846 .66834 Mdot
.59781 .40246 Mdot
.57142 .42793 Mdot
.20417 .41282 Mdot
.31987 .71965 Mdot
.61407 .66165 Mdot
.42821 .39283 Mdot
.59968 .416 Mdot
.60502 .68238 Mdot
.54687 .80576 Mdot
.63811 .40789 Mdot
.43472 .34753 Mdot
.50178 .41737 Mdot
.46897 .66965 Mdot
.30787 .52042 Mdot
.49456 .61298 Mdot
.59999 .66138 Mdot
.20286 .68944 Mdot
.3786 .69433 Mdot
.57996 .3749 Mdot
.6202 .46263 Mdot
.40431 .70109 Mdot
.40979 .33467 Mdot
.67094 .63147 Mdot
.60952 .43193 Mdot
.62327 .34787 Mdot
.59517 .4666 Mdot
.56225 .74957 Mdot
.39682 .37771 Mdot
.60302 .44872 Mdot
.61355 .5284 Mdot
.5911 .38389 Mdot
.61387 .6518 Mdot
.77997 .53213 Mdot
.64234 .42135 Mdot
.64919 .14626 Mdot
.39725 .66139 Mdot
.52498 .6451 Mdot
.43763 .68983 Mdot
.64339 .79808 Mdot
.29253 .3064 Mdot
.39231 .33168 Mdot
.43951 .42941 Mdot
.50483 .64385 Mdot
.32176 .2807 Mdot
.79384 .37315 Mdot
.54975 .42588 Mdot
.61855 .39561 Mdot
.48937 .62261 Mdot
.46935 .68594 Mdot
.40212 .6892 Mdot
.56569 .47562 Mdot
.62361 .50344 Mdot
.51672 .66733 Mdot
.61706 .4062 Mdot
.50699 .4368 Mdot
.32082 .484 Mdot
.40946 .3908 Mdot
.31633 .50469 Mdot
.30239 .52573 Mdot
.53967 .26245 Mdot
.22265 .52785 Mdot
.34762 .4885 Mdot
.29898 .49475 Mdot
.69535 .56977 Mdot
.49087 .4265 Mdot
.59689 .65804 Mdot
.78463 .40288 Mdot
.48745 .65352 Mdot
.58607 .44914 Mdot
.37293 .37691 Mdot
.52036 .24381 Mdot
.39554 .5947 Mdot
.29917 .742 Mdot
.62376 .42951 Mdot
.50248 .65638 Mdot
.40452 .66596 Mdot
.60159 .4896 Mdot
.44437 .73402 Mdot
.57376 .46817 Mdot
.48197 .61878 Mdot
.6158 .30911 Mdot
.55426 .53355 Mdot
.38368 .73155 Mdot
.36998 .32278 Mdot
.61439 .46161 Mdot
.38805 .3424 Mdot
.31418 .51653 Mdot
.60263 .66655 Mdot
.61263 .66362 Mdot
.56425 .43869 Mdot
.6541 .34827 Mdot
.40882 .54988 Mdot
.54865 .42502 Mdot
.55701 .42619 Mdot
.39932 .66999 Mdot
.55568 .42807 Mdot
.61686 .46541 Mdot
.59244 .47665 Mdot
.5723 .38539 Mdot
.35167 .53951 Mdot
.55536 .53604 Mdot
.52924 .42806 Mdot
.5164 .4576 Mdot
.32979 .47739 Mdot
.4106 .42991 Mdot
.30471 .51378 Mdot
.72192 .27373 Mdot
.32613 .4954 Mdot
.62381 .66116 Mdot
.53219 .67453 Mdot
.50712 .3786 Mdot
.38503 .32201 Mdot
.35329 .54308 Mdot
.62807 .67123 Mdot
.31934 .53111 Mdot
.48822 .67265 Mdot
.41218 .18428 Mdot
.44462 .33118 Mdot
.64649 .61236 Mdot
.3186 .5775 Mdot
.30576 .68957 Mdot
.49019 .62959 Mdot
.39557 .38111 Mdot
.66027 .27959 Mdot
.56986 .47198 Mdot
.62167 .69348 Mdot
.57398 .43718 Mdot
.3493 .54329 Mdot
.49658 .65623 Mdot
.78873 .57824 Mdot
.60768 .668 Mdot
.22288 .3525 Mdot
.49 .66057 Mdot
.54351 .45328 Mdot
.3228 .55023 Mdot
.29129 .2504 Mdot
.31736 .50012 Mdot
.58756 .57403 Mdot
.44565 .36277 Mdot
.46957 .33797 Mdot
.40403 .35422 Mdot
.34949 .67683 Mdot
.54601 .13987 Mdot
.82479 .47351 Mdot
.42356 .36834 Mdot
.40211 .75249 Mdot
.61172 .39622 Mdot
.64441 .41255 Mdot
.58372 .52967 Mdot
.44236 .36316 Mdot
.60697 .41403 Mdot
.39819 .66673 Mdot
.2395 .43078 Mdot
.46085 .75481 Mdot
.53842 .63998 Mdot
.61145 .44975 Mdot
.33192 .47793 Mdot
.29838 .50413 Mdot
.37538 .68366 Mdot
.30688 .50546 Mdot
.547 .4466 Mdot
.40674 .357 Mdot
.38874 .46312 Mdot
.61585 .681 Mdot
.79013 .65231 Mdot
.59423 .65256 Mdot
.43686 .6773 Mdot
.61692 .5005 Mdot
.50931 .63916 Mdot
.34524 .83317 Mdot
.5556 .45715 Mdot
.42926 .35328 Mdot
.58146 .41775 Mdot
.60525 .46743 Mdot
.64424 .40928 Mdot
.50527 .67455 Mdot
.67366 .66628 Mdot
.61441 .40607 Mdot
.33983 .51769 Mdot
.79841 .45808 Mdot
.64894 .4231 Mdot
.52832 .59596 Mdot
.74557 .55852 Mdot
.27429 .66212 Mdot
.39279 .31508 Mdot
.52091 .6331 Mdot
.41783 .34829 Mdot
.36519 .33977 Mdot
.41006 .34216 Mdot
.7527 .39029 Mdot
.65397 .28802 Mdot
.49747 .85477 Mdot
.50371 .35374 Mdot
.48464 .24047 Mdot
.42654 .39686 Mdot
.53232 .82183 Mdot
.3748 .34413 Mdot
.40109 .33423 Mdot
.88956 .58223 Mdot
.37301 .34279 Mdot
.61434 .44125 Mdot
.64786 .45493 Mdot
.29116 .42373 Mdot
.6772 .58088 Mdot
.55622 .43578 Mdot
.59373 .41856 Mdot
.60364 .67577 Mdot
.69556 .37168 Mdot
.40367 .69024 Mdot
.20793 .59375 Mdot
.32563 .39549 Mdot
.57165 .43686 Mdot
.60001 .41379 Mdot
.66271 .42998 Mdot
.47751 .12142 Mdot
.55501 .24867 Mdot
.41312 .40271 Mdot
.67126 .42815 Mdot
.82273 .58623 Mdot
.54227 .43187 Mdot
.63117 .40537 Mdot
.59473 .39803 Mdot
.50419 .64497 Mdot
.4092 .40672 Mdot
.67068 .42988 Mdot
.24784 .62369 Mdot
.59145 .39213 Mdot
.28683 .47939 Mdot
.692 .69077 Mdot
.60963 .44499 Mdot
.42804 .33122 Mdot
.57532 .41216 Mdot
.38189 .35695 Mdot
.39731 .38885 Mdot
.66215 .43353 Mdot
.74604 .35696 Mdot
.43715 .34756 Mdot
.57228 .39882 Mdot
.51735 .64229 Mdot
.82818 .45924 Mdot
.60031 .44391 Mdot
.6379 .66105 Mdot
.61054 .42974 Mdot
.64138 .6581 Mdot
.55629 .41959 Mdot
.38777 .66717 Mdot
.51584 .20472 Mdot
.49208 .64822 Mdot
.70763 .69391 Mdot
.49517 .68261 Mdot
.2035 .41554 Mdot
.4321 .34584 Mdot
.41648 .66932 Mdot
.26701 .72913 Mdot
.40195 .67238 Mdot
.54731 .54639 Mdot
.50814 .57256 Mdot
.34572 .53296 Mdot
.43303 .37607 Mdot
.75005 .61538 Mdot
.36853 .70744 Mdot
.54244 .67973 Mdot
.5332 .6638 Mdot
.20046 .66884 Mdot
.2264 .67649 Mdot
.60722 .40532 Mdot
.70328 .33856 Mdot
.48011 .30736 Mdot
.63563 .4066 Mdot
.54256 .46575 Mdot
.46244 .63597 Mdot
.62729 .45343 Mdot
.46847 .48726 Mdot
.48789 .63514 Mdot
.63432 .67173 Mdot
.39584 .33723 Mdot
.65056 .6657 Mdot
.45716 .69782 Mdot
.52715 .56793 Mdot
.46996 .65803 Mdot
.58419 .38159 Mdot
.58578 .41658 Mdot
.38684 .37893 Mdot
.34567 .35721 Mdot
.40492 .3908 Mdot
.64987 .69574 Mdot
.4844 .64189 Mdot
.54361 .24014 Mdot
.59344 .42617 Mdot
.40633 .36464 Mdot
.3789 .53386 Mdot
.59814 .42086 Mdot
.31414 .52953 Mdot
.61 .39304 Mdot
.42583 .3687 Mdot
.55548 .42798 Mdot
.40797 .35566 Mdot
.50924 .62588 Mdot
.54424 .42229 Mdot
.58482 .42657 Mdot
.28405 .26471 Mdot
.61824 .66494 Mdot
.43301 .34756 Mdot
.44402 .53999 Mdot
.54609 .45773 Mdot
.40248 .7101 Mdot
.62333 .44815 Mdot
.47374 .41626 Mdot
.60062 .37225 Mdot
.40277 .66895 Mdot
.53351 .47343 Mdot
.60039 .44478 Mdot
.6295 .52819 Mdot
.51928 .33483 Mdot
.35129 .37162 Mdot
.3337 .54837 Mdot
.43557 .33871 Mdot
.4522 .658 Mdot
.45883 .68618 Mdot
.46307 .67394 Mdot
.66244 .59512 Mdot
.6615 .43207 Mdot
.59604 .45672 Mdot
.36678 .5241 Mdot
.64114 .67283 Mdot
.40723 .37212 Mdot
.64279 .67733 Mdot
.20924 .56798 Mdot
.64642 .69657 Mdot
.37803 .67748 Mdot
.55173 .75796 Mdot
.56289 .22983 Mdot
.60463 .67799 Mdot
.40689 .39092 Mdot
.55328 .7692 Mdot
.61707 .47245 Mdot
.57139 .6368 Mdot
.62368 .67956 Mdot
.17932 .6451 Mdot
.63103 .43905 Mdot
.53252 .54266 Mdot
.32593 .48802 Mdot
.64066 .69175 Mdot
.33407 .50702 Mdot
.55881 .43656 Mdot
.29215 .65913 Mdot
.40201 .32966 Mdot
.33178 .47251 Mdot
.52597 .43713 Mdot
.65196 .68204 Mdot
.4769 .66123 Mdot
.28592 .55583 Mdot
.35187 .52927 Mdot
.50307 .18963 Mdot
.78466 .56457 Mdot
.48566 .63976 Mdot
.36217 .76099 Mdot
.34282 .50466 Mdot
.63766 .41045 Mdot
.55803 .35708 Mdot
.55058 .45493 Mdot
.46125 .69186 Mdot
.52234 .63397 Mdot
.25778 .4337 Mdot
.58617 .41408 Mdot
.62812 .44321 Mdot
.45398 .37839 Mdot
.498 .62983 Mdot
.39284 .35713 Mdot
.4023 .31947 Mdot
.51252 .62481 Mdot
.40084 .34908 Mdot
.62764 .69697 Mdot
.246 .40238 Mdot
.34349 .50388 Mdot
.33585 .51801 Mdot
.49735 .65982 Mdot
.52472 .65645 Mdot
.50937 .63698 Mdot
.60951 .39293 Mdot
.4032 .37661 Mdot
.57707 .40269 Mdot
.63533 .40115 Mdot
.37273 .31537 Mdot
.37077 .34468 Mdot
.58415 .40455 Mdot
.39199 .72641 Mdot
.62955 .71024 Mdot
.52192 .64848 Mdot
.33842 .48589 Mdot
.34179 .27647 Mdot
.37087 .51054 Mdot
.61318 .45078 Mdot
.30731 .5887 Mdot
.42128 .37401 Mdot
.61991 .69026 Mdot
.66877 .71151 Mdot
.611 .68103 Mdot
.34232 .55704 Mdot
.40477 .3241 Mdot
.2108 .59615 Mdot
.60838 .4531 Mdot
.47574 .50533 Mdot
.75705 .60563 Mdot
.22409 .57424 Mdot
.34558 .48711 Mdot
.59765 .41832 Mdot
.40304 .67551 Mdot
.63152 .25887 Mdot
.57859 .46926 Mdot
.5844 .47906 Mdot
.56235 .71791 Mdot
.517 .46196 Mdot
.44326 .35803 Mdot
.19748 .49786 Mdot
.65013 .44864 Mdot
.42104 .30451 Mdot
.67259 .80972 Mdot
.61591 .45429 Mdot
.61967 .42158 Mdot
.59336 .43806 Mdot
.57474 .41946 Mdot
.44339 .3457 Mdot
.71003 .62282 Mdot
.32504 .55071 Mdot
.4908 .52834 Mdot
.34789 .5071 Mdot
.4818 .62001 Mdot
.51497 .52359 Mdot
.42294 .38613 Mdot
.61783 .68976 Mdot
.57139 .20226 Mdot
.20657 .53322 Mdot
.48197 .6332 Mdot
.59874 .27222 Mdot
.6171 .67786 Mdot
.62405 .4694 Mdot
.66143 .67567 Mdot
.47492 .68627 Mdot
.34592 .52062 Mdot
.64017 .46398 Mdot
.37856 .38045 Mdot
.42844 .37465 Mdot
.60447 .41684 Mdot
.82367 .5599 Mdot
.3119 .52778 Mdot
.36976 .48082 Mdot
.60579 .39907 Mdot
.58273 .479 Mdot
.39244 .3511 Mdot
.51541 .65151 Mdot
.45299 .79947 Mdot
.625 .66656 Mdot
.53804 .42334 Mdot
.57088 .42104 Mdot
.21757 .52451 Mdot
.30863 .53579 Mdot
.38929 .69108 Mdot
.60298 .4021 Mdot
.22832 .51372 Mdot
.60086 .40251 Mdot
.57704 .49635 Mdot
.51266 .64223 Mdot
.63314 .38004 Mdot
.62757 .40761 Mdot
.67574 .42178 Mdot
.33896 .50434 Mdot
.4238 .34592 Mdot
.45411 .3642 Mdot
.40728 .6823 Mdot
.31441 .52837 Mdot
.58087 .40745 Mdot
.31121 .53619 Mdot
.64346 .41504 Mdot
.61403 .40844 Mdot
.34634 .48826 Mdot
.39313 .35657 Mdot
.35451 .44164 Mdot
.5459 .5365 Mdot
.57868 .41706 Mdot
.6075 .48461 Mdot
.67256 .59227 Mdot
.35301 .80443 Mdot
.62358 .43304 Mdot
.42743 .37051 Mdot
.59095 .42462 Mdot
.32621 .50886 Mdot
.64729 .69463 Mdot
.42612 .36412 Mdot
.50837 .66275 Mdot
.50172 .62245 Mdot
.31758 .31811 Mdot
.37609 .68607 Mdot
.59223 .48815 Mdot
.46635 .40106 Mdot
.3696 .36875 Mdot
.73663 .74049 Mdot
.51961 .62415 Mdot
.60653 .65228 Mdot
.56764 .43076 Mdot
.32372 .5842 Mdot
.36477 .529 Mdot
.6421 .14 Mdot
.21266 .59947 Mdot
.59583 .64916 Mdot
.29044 .73922 Mdot
.3975 .67968 Mdot
.63274 .41833 Mdot
.60334 .66343 Mdot
.47402 .63597 Mdot
.63692 .44755 Mdot
.54373 .38241 Mdot
.65483 .62349 Mdot
.50866 .60466 Mdot
.30858 .53084 Mdot
.46636 .67251 Mdot
.66301 .69837 Mdot
.37892 .67596 Mdot
.42327 .3827 Mdot
.59873 .44798 Mdot
.66535 .42897 Mdot
.51422 .65754 Mdot
.38721 .66707 Mdot
.5985 .3953 Mdot
.43465 .36893 Mdot
.45971 .67719 Mdot
.56656 .44175 Mdot
.4971 .22638 Mdot
.36284 .33605 Mdot
.48062 .6508 Mdot
.61581 .46495 Mdot
.4874 .40534 Mdot
.50136 .66205 Mdot
.52186 .65373 Mdot
.60645 .4138 Mdot
.62155 .6946 Mdot
.60064 .38967 Mdot
.32856 .49231 Mdot
.67548 .66697 Mdot
.32793 .51076 Mdot
.6275 .71895 Mdot
.58839 .50323 Mdot
.31715 .69054 Mdot
.40377 .39514 Mdot
.66331 .7016 Mdot
.35988 .24804 Mdot
.58695 .48112 Mdot
.76335 .34167 Mdot
.41076 .46096 Mdot
.81933 .62691 Mdot
.55409 .16223 Mdot
.62827 .68008 Mdot
.31645 .52618 Mdot
.61886 .42163 Mdot
.36148 .49144 Mdot
.60892 .66154 Mdot
.7639 .6102 Mdot
.61255 .46811 Mdot
.39447 .37596 Mdot
.59377 .39249 Mdot
.38488 .35276 Mdot
.59992 .42163 Mdot
.51836 .4633 Mdot
.5604 .67002 Mdot
.59281 .57765 Mdot
.61937 .47177 Mdot
.40982 .18336 Mdot
.41235 .57232 Mdot
.62037 .67353 Mdot
.57447 .40054 Mdot
.38511 .68102 Mdot
.29581 .51611 Mdot
.71873 .4417 Mdot
.5069 .64214 Mdot
.34121 .48188 Mdot
.39883 .34363 Mdot
.52703 .62765 Mdot
.40623 .66463 Mdot
.66067 .38933 Mdot
.63044 .65434 Mdot
.34157 .53643 Mdot
.60432 .44471 Mdot
.63042 .43894 Mdot
.42643 .76443 Mdot
.38563 .61961 Mdot
.42617 .40428 Mdot
.24228 .31504 Mdot
.43003 .32851 Mdot
.62966 .66406 Mdot
.51201 .64055 Mdot
.62323 .43632 Mdot
.56798 .45932 Mdot
.45524 .68635 Mdot
.43148 .34661 Mdot
.49559 .60924 Mdot
.56427 .26547 Mdot
.53281 .64939 Mdot
.72426 .59666 Mdot
.43109 .35872 Mdot
.72094 .59968 Mdot
.66402 .69799 Mdot
.72636 .31301 Mdot
.70441 .52872 Mdot
.3247 .48837 Mdot
.72837 .59479 Mdot
.41459 .37431 Mdot
.5972 .40939 Mdot
.39545 .68293 Mdot
.37855 .69048 Mdot
.3935 .34211 Mdot
.48576 .62351 Mdot
.64022 .69068 Mdot
.62067 .4183 Mdot
.26424 .67152 Mdot
.29133 .38426 Mdot
.51075 .66686 Mdot
.51164 .43497 Mdot
.33787 .51051 Mdot
.62768 .41236 Mdot
.64406 .66417 Mdot
.33852 .53483 Mdot
.36998 .67147 Mdot
.24611 .42442 Mdot
.5613 .43915 Mdot
.20976 .50016 Mdot
.32062 .53602 Mdot
.37231 .778 Mdot
.57354 .44332 Mdot
.3426 .50467 Mdot
.54049 .4927 Mdot
.2382 .58757 Mdot
.43187 .50349 Mdot
.80217 .38946 Mdot
.52242 .60456 Mdot
.49172 .62324 Mdot
.28607 .61892 Mdot
.53631 .69541 Mdot
.34292 .48014 Mdot
.37972 .67457 Mdot
.7547 .50055 Mdot
.33623 .50671 Mdot
.62396 .39637 Mdot
.62112 .44978 Mdot
.53375 .25803 Mdot
.44786 .50252 Mdot
.38153 .67049 Mdot
.2756 .33043 Mdot
.55097 .46099 Mdot
.54811 .39102 Mdot
.57321 .45838 Mdot
.40837 .40038 Mdot
.32606 .54248 Mdot
.31799 .23428 Mdot
.31131 .52026 Mdot
.26896 .68833 Mdot
.48825 .65373 Mdot
.52576 .6584 Mdot
.6118 .44622 Mdot
.3338 .70998 Mdot
.72915 .402 Mdot
.54482 .43989 Mdot
.40845 .7164 Mdot
.78657 .55477 Mdot
.52483 .42502 Mdot
.4473 .36674 Mdot
.64567 .4681 Mdot
.3597 .37531 Mdot
.35244 .52007 Mdot
.63377 .68444 Mdot
.60944 .6977 Mdot
.34307 .53381 Mdot
.59372 .45689 Mdot
.42945 .71258 Mdot
.59033 .46966 Mdot
.60454 .40424 Mdot
.24052 .66625 Mdot
.59085 .6607 Mdot
.5093 .63383 Mdot
.61035 .66525 Mdot
.40163 .33372 Mdot
.90439 .42158 Mdot
.64561 .67755 Mdot
.55019 .35153 Mdot
.72123 .66044 Mdot
.72663 .59821 Mdot
.42978 .37471 Mdot
.64574 .70296 Mdot
.30863 .52159 Mdot
.83975 .60234 Mdot
.37899 .8116 Mdot
.36599 .48764 Mdot
.56903 .44771 Mdot
.41697 .39133 Mdot
.38798 .39213 Mdot
.33408 .4702 Mdot
.40539 .38631 Mdot
.63161 .49896 Mdot
.5895 .40976 Mdot
.34401 .48083 Mdot
.29176 .41007 Mdot
.35036 .53234 Mdot
.23427 .41337 Mdot
.58243 .39677 Mdot
.42929 .36017 Mdot
.64784 .4716 Mdot
.45461 .34477 Mdot
.3886 .69402 Mdot
.63916 .44477 Mdot
.63222 .69318 Mdot
.45708 .49252 Mdot
.48273 .65025 Mdot
.31585 .59089 Mdot
.3862 .37631 Mdot
.3715 .46442 Mdot
.39778 .3869 Mdot
.42402 .3901 Mdot
.30188 .52479 Mdot
.38868 .32898 Mdot
.62053 .42097 Mdot
.39708 .74157 Mdot
.3798 .3544 Mdot
.32607 .5244 Mdot
.62676 .68828 Mdot
.39798 .35168 Mdot
.46666 .62802 Mdot
.577 .42717 Mdot
.46749 .6615 Mdot
.56256 .66949 Mdot
.43601 .37239 Mdot
.64329 .70245 Mdot
.52551 .63791 Mdot
.61822 .65358 Mdot
.78358 .60212 Mdot
.36022 .50471 Mdot
.30558 .74527 Mdot
.50124 .45472 Mdot
.37715 .37924 Mdot
.56101 .66441 Mdot
.62132 .43608 Mdot
.57527 .42678 Mdot
.6531 .70424 Mdot
.38631 .39153 Mdot
.8313 .48518 Mdot
.46128 .41815 Mdot
.2492 .40772 Mdot
.36058 .52411 Mdot
.25387 .32014 Mdot
.23848 .46525 Mdot
.71716 .72381 Mdot
.62838 .37142 Mdot
.39686 .68007 Mdot
.60201 .4609 Mdot
.37197 .23717 Mdot
.65268 .68883 Mdot
.46579 .82142 Mdot
.65211 .40531 Mdot
.50148 .63556 Mdot
.58389 .43772 Mdot
.68349 .49032 Mdot
.63592 .47936 Mdot
.61148 .68989 Mdot
.27032 .49931 Mdot
.38635 .32201 Mdot
.61586 .67967 Mdot
.50096 .62364 Mdot
.762 .53029 Mdot
.63474 .45126 Mdot
.55255 .46704 Mdot
.53173 .65568 Mdot
.39676 .38022 Mdot
.47379 .62539 Mdot
.34375 .50422 Mdot
.6403 .68096 Mdot
.56843 .42715 Mdot
.59212 .37635 Mdot
.41474 .70613 Mdot
.32723 .5434 Mdot
.53028 .64568 Mdot
.31451 .50579 Mdot
.39692 .68094 Mdot
.62678 .47214 Mdot
.5223 .66493 Mdot
.63513 .43257 Mdot
.32854 .25274 Mdot
.24908 .67721 Mdot
.54167 .32757 Mdot
.50751 .63108 Mdot
.72549 .57451 Mdot
.32223 .5139 Mdot
.32268 .49787 Mdot
.44766 .31285 Mdot
.73349 .43183 Mdot
.58151 .75541 Mdot
.51838 .18623 Mdot
.34422 .50387 Mdot
.32982 .51418 Mdot
.46669 .6441 Mdot
.38615 .33302 Mdot
.3687 .38661 Mdot
.51914 .61884 Mdot
.60581 .58348 Mdot
.40722 .37195 Mdot
.77001 .35508 Mdot
.45241 .65403 Mdot
.62285 .36832 Mdot
.40995 .69035 Mdot
.63874 .68677 Mdot
.60119 .58104 Mdot
.68246 .48843 Mdot
.62745 .43425 Mdot
.19288 .48222 Mdot
.51176 .65085 Mdot
.69108 .63028 Mdot
.71612 .26922 Mdot
.60738 .47184 Mdot
.58275 .44758 Mdot
.58874 .45946 Mdot
.58886 .66393 Mdot
.38155 .24673 Mdot
.62931 .43222 Mdot
.60379 .58847 Mdot
.53922 .45087 Mdot
.68032 .52412 Mdot
.6124 .66338 Mdot
.37351 .29347 Mdot
.52975 .61116 Mdot
.23109 .60466 Mdot
.57811 .52854 Mdot
.33374 .50008 Mdot
.55481 .65752 Mdot
.35014 .51531 Mdot
.73784 .37668 Mdot
.70581 .5309 Mdot
.43808 .39184 Mdot
.62492 .42807 Mdot
.52631 .67168 Mdot
.40267 .39323 Mdot
.35883 .70823 Mdot
.90454 .54433 Mdot
.32849 .5459 Mdot
.36942 .8364 Mdot
.31973 .49943 Mdot
.38362 .69391 Mdot
.39281 .34856 Mdot
.64512 .29205 Mdot
.4749 .50361 Mdot
.40001 .35157 Mdot
.30754 .45155 Mdot
.4239 .32122 Mdot
.72972 .58114 Mdot
.3791 .32073 Mdot
.32346 .52136 Mdot
.32433 .56645 Mdot
.57403 .37271 Mdot
.61538 .43624 Mdot
.53523 .56689 Mdot
.49712 .3829 Mdot
.61812 .43442 Mdot
.48829 .63495 Mdot
.35369 .77661 Mdot
.55025 .64607 Mdot
.37538 .35404 Mdot
.32373 .54836 Mdot
.5826 .44552 Mdot
.58601 .40946 Mdot
.63906 .42657 Mdot
.27061 .27111 Mdot
.77248 .36603 Mdot
.61217 .40662 Mdot
.54447 .41225 Mdot
.50845 .62684 Mdot
.6767 .69002 Mdot
.45066 .18329 Mdot
.74287 .50633 Mdot
.56703 .46656 Mdot
.61342 .66648 Mdot
.5968 .65328 Mdot
.63224 .4578 Mdot
.27068 .66616 Mdot
.39199 .74431 Mdot
.60399 .44449 Mdot
.70577 .50946 Mdot
.48124 .69785 Mdot
.37508 .68319 Mdot
.51205 .65831 Mdot
.42104 .32626 Mdot
.38605 .67141 Mdot
.48298 .68375 Mdot
.63727 .2814 Mdot
.4095 .68036 Mdot
.24413 .5212 Mdot
.65 .69568 Mdot
.57319 .46224 Mdot
.44081 .33734 Mdot
.45871 .68895 Mdot
.34573 .53204 Mdot
.41819 .35732 Mdot
.29555 .51339 Mdot
.61922 .64487 Mdot
.66059 .61322 Mdot
.37727 .69195 Mdot
.33936 .49878 Mdot
.24501 .42514 Mdot
.61309 .66554 Mdot
.30764 .50619 Mdot
.33585 .70312 Mdot
.65131 .42503 Mdot
.69537 .30188 Mdot
.54925 .41916 Mdot
.83015 .57953 Mdot
.30673 .51157 Mdot
.4134 .67328 Mdot
.59818 .45406 Mdot
.49123 .66074 Mdot
.56592 .50317 Mdot
.57118 .46723 Mdot
.5013 .66667 Mdot
.60534 .40602 Mdot
.63687 .65957 Mdot
.3585 .3484 Mdot
.38414 .45101 Mdot
.14814 .49145 Mdot
.62961 .65506 Mdot
.35595 .70794 Mdot
.6238 .43185 Mdot
.78836 .57429 Mdot
.39832 .35366 Mdot
.59936 .47701 Mdot
.39828 .28617 Mdot
.38481 .33986 Mdot
.41561 .34946 Mdot
.5635 .41716 Mdot
.3187 .49428 Mdot
.48478 .65883 Mdot
.6106 .66798 Mdot
.74384 .71526 Mdot
.56253 .45078 Mdot
.58759 .42576 Mdot
.61688 .67883 Mdot
.329 .51216 Mdot
.58265 .41109 Mdot
.35732 .59946 Mdot
.7902 .67977 Mdot
.30529 .53949 Mdot
.64917 .41225 Mdot
.63604 .23742 Mdot
.46149 .35908 Mdot
.36232 .82157 Mdot
.63749 .71769 Mdot
.52013 .6347 Mdot
.51932 .46554 Mdot
.72949 .21562 Mdot
.63385 .68591 Mdot
.22216 .60101 Mdot
.61444 .40227 Mdot
.59417 .43073 Mdot
.41699 .3809 Mdot
.57939 .40424 Mdot
.41854 .33726 Mdot
.15033 .54675 Mdot
.19026 .38662 Mdot
.38798 .37326 Mdot
.37269 .36059 Mdot
.46604 .34303 Mdot
.43265 .19302 Mdot
.39873 .33914 Mdot
.64623 .4051 Mdot
.80421 .44494 Mdot
.6531 .37863 Mdot
.65056 .70563 Mdot
.56539 .67269 Mdot
.359 .30183 Mdot
.42428 .64762 Mdot
.42466 .42498 Mdot
.60588 .52268 Mdot
.39672 .56353 Mdot
.3352 .49049 Mdot
.57796 .47409 Mdot
.37602 .6883 Mdot
.46804 .6791 Mdot
.62529 .48535 Mdot
.5776 .46632 Mdot
.38277 .35385 Mdot
.59417 .67563 Mdot
.29972 .51248 Mdot
.59301 .41891 Mdot
.4859 .61007 Mdot
.63158 .66887 Mdot
.37677 .35796 Mdot
.47135 .34369 Mdot
.59684 .66477 Mdot
.53491 .47702 Mdot
.60747 .4298 Mdot
.59969 .39587 Mdot
.52736 .49032 Mdot
.35585 .50766 Mdot
.45487 .69403 Mdot
.63025 .39305 Mdot
.21054 .56434 Mdot
.56887 .5795 Mdot
.61763 .37774 Mdot
.40933 .3777 Mdot
.36221 .53414 Mdot
.39443 .69132 Mdot
.76842 .55605 Mdot
.55985 .44437 Mdot
.77183 .36906 Mdot
.55742 .25367 Mdot
.38739 .6717 Mdot
.43219 .39222 Mdot
.61664 .68809 Mdot
.54836 .44814 Mdot
.77987 .42006 Mdot
.61929 .44992 Mdot
.49322 .42693 Mdot
.51833 .64488 Mdot
.33873 .49011 Mdot
.81268 .6457 Mdot
.47136 .67989 Mdot
.41725 .34864 Mdot
.80732 .38688 Mdot
.37924 .39283 Mdot
.3893 .32315 Mdot
.74553 .36477 Mdot
.35381 .50514 Mdot
.71006 .19756 Mdot
.37074 .81347 Mdot
.61023 .38463 Mdot
.32201 .50828 Mdot
.38794 .35417 Mdot
.62713 .41251 Mdot
.37045 .36354 Mdot
.40276 .32664 Mdot
.64259 .43801 Mdot
.60204 .42956 Mdot
.5424 .53743 Mdot
.74554 .31004 Mdot
.60971 .68109 Mdot
.43488 .35751 Mdot
.48128 .24825 Mdot
.63113 .42774 Mdot
.60804 .45275 Mdot
.39107 .70813 Mdot
.61022 .68831 Mdot
.65791 .50648 Mdot
.60357 .40279 Mdot
.19415 .41544 Mdot
.6129 .48256 Mdot
.4485 .35731 Mdot
.30482 .53874 Mdot
.25977 .65279 Mdot
.45733 .69126 Mdot
.43684 .35391 Mdot
.65402 .67538 Mdot
.45314 .37629 Mdot
.5353 .35447 Mdot
.3533 .51222 Mdot
.42582 .36873 Mdot
.49229 .61569 Mdot
.33902 .52837 Mdot
.30771 .50722 Mdot
.79873 .45698 Mdot
.53026 .63539 Mdot
.65512 .69296 Mdot
.34601 .51689 Mdot
.49305 .22155 Mdot
.32132 .52585 Mdot
.50105 .25442 Mdot
.54897 .41388 Mdot
.62467 .5977 Mdot
.24797 .47087 Mdot
.5169 .46849 Mdot
.3582 .50965 Mdot
.60796 .6639 Mdot
.56673 .41948 Mdot
.4076 .38586 Mdot
.64554 .67935 Mdot
.27592 .52046 Mdot
.52355 .65526 Mdot
.39024 .38558 Mdot
.32301 .55097 Mdot
.43285 .35616 Mdot
.74039 .62062 Mdot
.66042 .64443 Mdot
.36799 .57641 Mdot
.4929 .51834 Mdot
.63841 .42044 Mdot
.33422 .35916 Mdot
.59696 .48822 Mdot
.57955 .46847 Mdot
.48085 .65146 Mdot
.66243 .59634 Mdot
.39263 .35631 Mdot
.81405 .64844 Mdot
.3395 .49579 Mdot
.18661 .45389 Mdot
.48177 .40418 Mdot
.57376 .47547 Mdot
.38079 .35099 Mdot
.36812 .37816 Mdot
.52277 .33525 Mdot
.45161 .67343 Mdot
.52531 .39979 Mdot
.55842 .49177 Mdot
.58387 .37195 Mdot
.30711 .5118 Mdot
.31163 .59777 Mdot
.4812 .62364 Mdot
.51017 .86217 Mdot
.51997 .65053 Mdot
.51435 .73134 Mdot
.38659 .32924 Mdot
.64662 .69302 Mdot
.60795 .45104 Mdot
.48868 .44081 Mdot
.44284 .37731 Mdot
.67168 .71317 Mdot
.62936 .69426 Mdot
.26896 .59595 Mdot
.34921 .4901 Mdot
.62511 .46454 Mdot
.62179 .45877 Mdot
.57216 .40415 Mdot
.55717 .40676 Mdot
.32239 .54614 Mdot
.62644 .39872 Mdot
.34498 .47748 Mdot
.51171 .22405 Mdot
.18822 .42265 Mdot
.51166 .68188 Mdot
.7247 .43497 Mdot
.37973 .37888 Mdot
.46409 .22502 Mdot
.51587 .39945 Mdot
.25875 .69168 Mdot
.80073 .55287 Mdot
.56547 .48067 Mdot
.47228 .63416 Mdot
.71525 .40014 Mdot
.51349 .67924 Mdot
.18179 .69965 Mdot
.45921 .70783 Mdot
.78802 .36595 Mdot
.62727 .41886 Mdot
.39492 .70689 Mdot
.51445 .39335 Mdot
.6401 .44813 Mdot
.49795 .70365 Mdot
.25408 .34845 Mdot
.28676 .43833 Mdot
.59604 .65656 Mdot
.57287 .4322 Mdot
.37518 .3252 Mdot
.62216 .4207 Mdot
.60869 .45617 Mdot
.62387 .40339 Mdot
.30776 .54533 Mdot
.64293 .46286 Mdot
.61638 .39298 Mdot
.40504 .61693 Mdot
.69962 .57767 Mdot
.46824 .67253 Mdot
.51757 .35283 Mdot
.64103 .67355 Mdot
.38135 .36326 Mdot
.47276 .46797 Mdot
.32677 .48696 Mdot
.48946 .33129 Mdot
.60424 .39186 Mdot
.24934 .45725 Mdot
.324 .55117 Mdot
.64272 .68332 Mdot
.40376 .68433 Mdot
.81467 .43686 Mdot
.49919 .68461 Mdot
.40851 .68206 Mdot
.48417 .64978 Mdot
.39296 .25351 Mdot
.38335 .35146 Mdot
.63985 .42129 Mdot
.34174 .51296 Mdot
.48331 .66128 Mdot
.66754 .58194 Mdot
.57698 .45925 Mdot
.50318 .62844 Mdot
.63849 .41552 Mdot
.64345 .61035 Mdot
.43214 .77031 Mdot
.50573 .68038 Mdot
.32195 .56062 Mdot
.33596 .52628 Mdot
.63132 .69784 Mdot
.38087 .36879 Mdot
.41861 .3758 Mdot
.3375 .53454 Mdot
.31882 .78724 Mdot
.57228 .46869 Mdot
.62866 .41685 Mdot
.2117 .56139 Mdot
.61577 .4258 Mdot
.75667 .54861 Mdot
.39193 .69753 Mdot
.37861 .3703 Mdot
.62485 .40858 Mdot
.57948 .41479 Mdot
.56399 .43491 Mdot
.73615 .62493 Mdot
.51682 .65575 Mdot
.54995 .45812 Mdot
.60246 .67697 Mdot
.34595 .66222 Mdot
.63084 .4198 Mdot
.56127 .38249 Mdot
.41966 .37231 Mdot
.18295 .40609 Mdot
.32653 .49067 Mdot
.48463 .63443 Mdot
.52647 .64301 Mdot
.56473 .68357 Mdot
.36781 .31851 Mdot
.40094 .69188 Mdot
.64417 .78864 Mdot
.40702 .67148 Mdot
.61651 .67282 Mdot
.59661 .71904 Mdot
.45471 .63238 Mdot
.47292 .64167 Mdot
.30492 .4894 Mdot
.5909 .39182 Mdot
.54592 .45302 Mdot
.22312 .61027 Mdot
.55604 .46678 Mdot
.62742 .6911 Mdot
.3361 .47656 Mdot
.41437 .37153 Mdot
.64248 .68692 Mdot
.31787 .50388 Mdot
.39881 .38141 Mdot
.65086 .43033 Mdot
.65321 .42666 Mdot
.41545 .35418 Mdot
.40461 .39218 Mdot
.60696 .44036 Mdot
.36538 .61754 Mdot
.40449 .31917 Mdot
.42884 .36485 Mdot
.37388 .69092 Mdot
.50865 .68234 Mdot
.66945 .41831 Mdot
.31932 .50936 Mdot
.60292 .39682 Mdot
.5139 .67991 Mdot
.61772 .69571 Mdot
.39636 .35974 Mdot
.58221 .41408 Mdot
.59208 .41482 Mdot
.61127 .66996 Mdot
.59421 .6693 Mdot
.64343 .68918 Mdot
.35574 .48039 Mdot
.55692 .41284 Mdot
.40157 .34025 Mdot
.35081 .4944 Mdot
.59707 .6532 Mdot
.65979 .67042 Mdot
.43801 .61154 Mdot
.62456 .43841 Mdot
.42866 .50899 Mdot
.88994 .40208 Mdot
.75453 .52101 Mdot
.39275 .69257 Mdot
.53407 .64904 Mdot
.69794 .60471 Mdot
.41984 .75288 Mdot
.31683 .53599 Mdot
.75522 .46702 Mdot
.66259 .70199 Mdot
.64215 .42132 Mdot
.61041 .48313 Mdot
.53955 .46343 Mdot
.6343 .6742 Mdot
.75152 .60132 Mdot
.38707 .39382 Mdot
.45263 .27763 Mdot
.64101 .67391 Mdot
.50281 .68119 Mdot
.5216 .66754 Mdot
.52021 .6499 Mdot
.64165 .45919 Mdot
.5121 .33192 Mdot
.47493 .23264 Mdot
.43062 .2049 Mdot
.34488 .48422 Mdot
.41232 .40758 Mdot
.78345 .59565 Mdot
.41354 .3502 Mdot
.47004 .6812 Mdot
.63 .6714 Mdot
.42485 .37447 Mdot
.3401 .54058 Mdot
.33187 .514 Mdot
.51675 .65994 Mdot
.49631 .6589 Mdot
.47119 .66411 Mdot
.412 .32408 Mdot
.38803 .32909 Mdot
.55688 .44639 Mdot
.40418 .35978 Mdot
.18698 .51256 Mdot
.58982 .65203 Mdot
.51498 .67348 Mdot
.31481 .52326 Mdot
.3843 .35677 Mdot
.57018 .4583 Mdot
.588 .73628 Mdot
.31327 .3394 Mdot
.61995 .65462 Mdot
.41298 .76732 Mdot
.21885 .73719 Mdot
.63068 .4523 Mdot
.30787 .53129 Mdot
.28454 .68769 Mdot
.58464 .45831 Mdot
.50656 .64609 Mdot
.34887 .23969 Mdot
.3998 .66505 Mdot
.62051 .39587 Mdot
.56182 .4703 Mdot
.30612 .50669 Mdot
.72369 .664 Mdot
.55437 .44696 Mdot
.22171 .45872 Mdot
.29668 .53528 Mdot
.45977 .6499 Mdot
.79139 .68459 Mdot
.44838 .69567 Mdot
.60682 .57714 Mdot
.38144 .69006 Mdot
.60903 .46528 Mdot
.48283 .63948 Mdot
.61334 .65587 Mdot
.47426 .65408 Mdot
.43604 .3915 Mdot
.4686 .66891 Mdot
.58778 .42702 Mdot
.40148 .33795 Mdot
.31891 .53504 Mdot
.19706 .50119 Mdot
.3948 .62425 Mdot
.49224 .66089 Mdot
.37422 .69418 Mdot
.63122 .41085 Mdot
.60356 .53514 Mdot
.58405 .50761 Mdot
.62942 .42319 Mdot
.3511 .51264 Mdot
.37945 .35126 Mdot
.3561 .53412 Mdot
.55909 .38774 Mdot
.23504 .35842 Mdot
.31564 .50146 Mdot
.26066 .48342 Mdot
.61662 .67671 Mdot
.57211 .56107 Mdot
.56628 .45959 Mdot
.34507 .5129 Mdot
.55843 .41081 Mdot
.36982 .34647 Mdot
.46343 .53766 Mdot
.3412 .67872 Mdot
.34079 .51373 Mdot
.8344 .50969 Mdot
.44278 .54606 Mdot
.6551 .4569 Mdot
.34577 .50727 Mdot
.40625 .27491 Mdot
.38461 .68894 Mdot
.62218 .66684 Mdot
.5965 .654 Mdot
.61496 .65323 Mdot
.57392 .48042 Mdot
.55374 .37462 Mdot
.65884 .68207 Mdot
.29793 .5278 Mdot
.61052 .68964 Mdot
.50053 .48001 Mdot
.83515 .49944 Mdot
.65181 .67879 Mdot
.5703 .44281 Mdot
.54702 .39038 Mdot
.69565 .5783 Mdot
.46297 .68127 Mdot
.76093 .33757 Mdot
.67436 .36627 Mdot
.61665 .43887 Mdot
.65046 .37083 Mdot
.39957 .39529 Mdot
.31791 .7137 Mdot
.49639 .38782 Mdot
.41349 .75658 Mdot
.37448 .33925 Mdot
.43696 .6791 Mdot
.37946 .36867 Mdot
.63405 .44562 Mdot
.61561 .40905 Mdot
.36129 .37423 Mdot
.26713 .56736 Mdot
.28268 .64505 Mdot
.79313 .64613 Mdot
.43022 .36737 Mdot
.33914 .50462 Mdot
.32829 .54638 Mdot
.34243 .48434 Mdot
.45243 .65891 Mdot
.43855 .36849 Mdot
.55184 .42587 Mdot
.51166 .62622 Mdot
.57833 .4724 Mdot
.34402 .52298 Mdot
.81755 .63903 Mdot
.41791 .37226 Mdot
.60123 .44498 Mdot
.37601 .80867 Mdot
.49788 .65367 Mdot
.61817 .6632 Mdot
.66209 .61931 Mdot
.45314 .64754 Mdot
.35624 .52399 Mdot
.36848 .38422 Mdot
.2973 .47094 Mdot
.44399 .45438 Mdot
.65808 .38948 Mdot
.63925 .38672 Mdot
.72108 .7344 Mdot
.36033 .66801 Mdot
.60863 .48138 Mdot
.49902 .62378 Mdot
.46793 .68828 Mdot
.58036 .41833 Mdot
.42751 .3793 Mdot
.63476 .65274 Mdot
.6016 .67707 Mdot
.52877 .46074 Mdot
.47862 .50864 Mdot
.57065 .5634 Mdot
.58486 .40536 Mdot
.51414 .44288 Mdot
.52828 .64541 Mdot
.41062 .6734 Mdot
.21964 .53754 Mdot
.6548 .67953 Mdot
.61223 .40103 Mdot
.32404 .43371 Mdot
.39831 .32743 Mdot
.46875 .66588 Mdot
.35524 .52072 Mdot
.75059 .62311 Mdot
.47178 .62489 Mdot
.58216 .41636 Mdot
.58211 .41176 Mdot
.30782 .50525 Mdot
.44859 .35794 Mdot
.63125 .67345 Mdot
.51544 .62994 Mdot
.65573 .6801 Mdot
.39965 .33191 Mdot
.4165 .36919 Mdot
.65317 .37835 Mdot
.51618 .44716 Mdot
.50948 .66113 Mdot
.54022 .41039 Mdot
.48692 .68246 Mdot
.72099 .67634 Mdot
.35208 .54458 Mdot
.62786 .45602 Mdot
.39206 .40506 Mdot
.34633 .52299 Mdot
.59725 .43416 Mdot
.70545 .76597 Mdot
.58756 .47789 Mdot
.44898 .68751 Mdot
.21737 .38122 Mdot
.60443 .67511 Mdot
.5839 .33756 Mdot
.68836 .43973 Mdot
.61388 .42378 Mdot
.507 .67494 Mdot
.56988 .50418 Mdot
.31058 .50468 Mdot
.37791 .33936 Mdot
.32355 .81079 Mdot
.32463 .52716 Mdot
.62256 .41623 Mdot
.64126 .68164 Mdot
.37112 .38494 Mdot
.39506 .66752 Mdot
.2141 .57955 Mdot
.60596 .49569 Mdot
.65307 .41341 Mdot
.61369 .39595 Mdot
.4518 .1775 Mdot
.48057 .63879 Mdot
.38615 .35518 Mdot
.30695 .51432 Mdot
.3335 .53786 Mdot
.51762 .64968 Mdot
.27297 .4348 Mdot
.53006 .57341 Mdot
.79307 .27019 Mdot
.49432 .66755 Mdot
.63258 .70359 Mdot
.50303 .51777 Mdot
.48339 .68 Mdot
.49762 .63257 Mdot
.52697 .63883 Mdot
.24 .50564 Mdot
.40219 .37922 Mdot
.59423 .41282 Mdot
.39426 .31528 Mdot
.60815 .46662 Mdot
.60941 .55548 Mdot
.34579 .5287 Mdot
.3786 .33634 Mdot
.71878 .74582 Mdot
.47261 .3994 Mdot
.58078 .45293 Mdot
.77293 .62915 Mdot
.61054 .50575 Mdot
.74139 .58772 Mdot
.64828 .47909 Mdot
.48747 .65544 Mdot
.53724 .36855 Mdot
.56874 .37873 Mdot
.19115 .50269 Mdot
.31429 .52109 Mdot
.38374 .69492 Mdot
.58087 .48829 Mdot
.57555 .4959 Mdot
.36676 .34987 Mdot
.42626 .37325 Mdot
.65789 .68534 Mdot
.57373 .59296 Mdot
.31569 .53165 Mdot
.65008 .63335 Mdot
.61277 .43512 Mdot
.27681 .56725 Mdot
.48935 .35542 Mdot
.59706 .43572 Mdot
.7972 .43175 Mdot
.50068 .33333 Mdot
.55406 .45387 Mdot
.41206 .2654 Mdot
.32699 .51431 Mdot
.21614 .38953 Mdot
.56219 .39414 Mdot
.50495 .64542 Mdot
.3835 .33389 Mdot
.40325 .39632 Mdot
.65007 .66762 Mdot
.21372 .64888 Mdot
.35943 .51241 Mdot
.38252 .33113 Mdot
.58463 .46245 Mdot
.35595 .51493 Mdot
.377 .68436 Mdot
.58189 .37629 Mdot
.75327 .44975 Mdot
.40651 .3624 Mdot
.54466 .41106 Mdot
.28264 .3394 Mdot
.58883 .58822 Mdot
.70684 .2426 Mdot
.33834 .48428 Mdot
.65013 .68737 Mdot
.66208 .45171 Mdot
.64289 .7873 Mdot
.54069 .46195 Mdot
.63142 .59637 Mdot
.39254 .30036 Mdot
.64683 .69457 Mdot
.58948 .45216 Mdot
.55978 .43397 Mdot
.47325 .49641 Mdot
.59299 .67029 Mdot
.60357 .47322 Mdot
.60365 .35023 Mdot
.39651 .37903 Mdot
.38761 .6975 Mdot
.40828 .36745 Mdot
.56954 .44745 Mdot
.56472 .37012 Mdot
.41566 .38369 Mdot
.68538 .72799 Mdot
.62871 .70711 Mdot
.32869 .48901 Mdot
.51483 .42287 Mdot
.55938 .40242 Mdot
.46722 .1558 Mdot
.38833 .69404 Mdot
.38415 .23223 Mdot
.48117 .61507 Mdot
.3351 .44027 Mdot
.41907 .6939 Mdot
.81033 .39987 Mdot
.20253 .50397 Mdot
.58164 .49334 Mdot
.71653 .48755 Mdot
.42503 .2501 Mdot
.35743 .52708 Mdot
.56028 .22212 Mdot
.61581 .43632 Mdot
.60671 .45857 Mdot
.4636 .64701 Mdot
.25818 .43931 Mdot
.278 .67377 Mdot
.48385 .5213 Mdot
.62749 .67517 Mdot
.4121 .3361 Mdot
.59979 .41975 Mdot
.53014 .58108 Mdot
.47481 .6737 Mdot
.31868 .583 Mdot
.59737 .44852 Mdot
.27596 .70248 Mdot
.24561 .50501 Mdot
.35557 .5016 Mdot
.52316 .66271 Mdot
.45859 .63735 Mdot
.62198 .45369 Mdot
.35177 .52883 Mdot
.5557 .44987 Mdot
.43586 .56048 Mdot
.53337 .4238 Mdot
.64895 .67568 Mdot
.63492 .41124 Mdot
.4452 .48402 Mdot
.75133 .28578 Mdot
.58786 .34541 Mdot
.42461 .38661 Mdot
.45355 .65421 Mdot
.51604 .65475 Mdot
.42361 .37327 Mdot
.51365 .6548 Mdot
.4701 .29305 Mdot
.61799 .30312 Mdot
.62392 .67695 Mdot
.51165 .42303 Mdot
.64756 .66984 Mdot
.38586 .6955 Mdot
.62147 .4395 Mdot
.63909 .79515 Mdot
.49539 .6655 Mdot
.29256 .27574 Mdot
.32061 .52839 Mdot
.3859 .69476 Mdot
.53863 .44944 Mdot
.59036 .71553 Mdot
.46237 .67662 Mdot
.44453 .68363 Mdot
.56209 .43738 Mdot
.41461 .37865 Mdot
.56346 .42903 Mdot
.61969 .50184 Mdot
.4048 .68529 Mdot
.59359 .3918 Mdot
.31786 .50399 Mdot
.43551 .33871 Mdot
.82363 .45402 Mdot
.46021 .69043 Mdot
.62844 .44011 Mdot
.58545 .46142 Mdot
.36777 .36878 Mdot
.53935 .42815 Mdot
.34072 .54152 Mdot
.54264 .09101 Mdot
.61601 .67581 Mdot
.40297 .66315 Mdot
.45453 .69585 Mdot
.56078 .47702 Mdot
.57902 .41076 Mdot
.74234 .72057 Mdot
.33224 .64635 Mdot
.32932 .49984 Mdot
.565 .49956 Mdot
.50925 .62783 Mdot
.64112 .68311 Mdot
.29797 .51352 Mdot
.59749 .39652 Mdot
.60398 .45364 Mdot
.64829 .67917 Mdot
.8066 .46591 Mdot
.41238 .75877 Mdot
.34144 .48239 Mdot
.52905 .37244 Mdot
.57772 .74608 Mdot
.57175 .46806 Mdot
.62294 .75269 Mdot
.42689 .36621 Mdot
.34756 .50215 Mdot
.43809 .19719 Mdot
.63909 .41348 Mdot
.33047 .54363 Mdot
.31452 .52872 Mdot
.60361 .38264 Mdot
.37979 .31553 Mdot
.42171 .33086 Mdot
.43069 .35112 Mdot
.17188 .44066 Mdot
.65075 .55426 Mdot
.4719 .6647 Mdot
.32803 .51332 Mdot
.51423 .67783 Mdot
.58648 .65819 Mdot
.56388 .5758 Mdot
.48224 .68528 Mdot
.39733 .39407 Mdot
.52296 .66697 Mdot
.56308 .43224 Mdot
.31928 .53623 Mdot
.47089 .64431 Mdot
.58443 .48661 Mdot
.67165 .48653 Mdot
.42461 .54269 Mdot
.64883 .66014 Mdot
.66054 .71677 Mdot
.60946 .41171 Mdot
.39496 .69073 Mdot
.60764 .44233 Mdot
.3405 .47883 Mdot
.45535 .47075 Mdot
.56727 .47996 Mdot
.50012 .66174 Mdot
.66563 .36966 Mdot
.45422 .67201 Mdot
.58078 .50226 Mdot
.57167 .44391 Mdot
.58545 .47199 Mdot
.55403 .44859 Mdot
.27871 .45836 Mdot
.36119 .52275 Mdot
.6829 .47393 Mdot
.54121 .62872 Mdot
.40602 .35318 Mdot
.41453 .40355 Mdot
.56438 .765 Mdot
.4044 .66222 Mdot
.32029 .50975 Mdot
.56654 .46362 Mdot
.44838 .69136 Mdot
.82305 .63058 Mdot
.68426 .73458 Mdot
.66616 .72213 Mdot
.48809 .62803 Mdot
.42065 .3906 Mdot
.46695 .67476 Mdot
.6157 .45886 Mdot
.62457 .38566 Mdot
.81716 .42049 Mdot
.31012 .56217 Mdot
.63152 .67201 Mdot
.59114 .47234 Mdot
.60518 .57455 Mdot
.50858 .62689 Mdot
.529 .64082 Mdot
.58704 .47676 Mdot
.4368 .34892 Mdot
.61648 .17006 Mdot
.35649 .50531 Mdot
.70687 .40133 Mdot
.35482 .39667 Mdot
.22983 .38471 Mdot
.34001 .53635 Mdot
.40823 .55623 Mdot
.51001 .62008 Mdot
.62555 .33261 Mdot
.41011 .35494 Mdot
.63494 .67134 Mdot
.62284 .38231 Mdot
.39445 .39173 Mdot
.52169 .61968 Mdot
.37631 .36926 Mdot
.63963 .436 Mdot
.35865 .5271 Mdot
.52223 .63806 Mdot
.3418 .5572 Mdot
.3632 .38075 Mdot
.62544 .65816 Mdot
.55929 .55082 Mdot
.60649 .23985 Mdot
.49671 .33278 Mdot
.54967 .45735 Mdot
.5035 .58875 Mdot
.55753 .41407 Mdot
.37155 .33013 Mdot
.56548 .45629 Mdot
.3436 .3106 Mdot
.52325 .66041 Mdot
.54632 .40906 Mdot
.62311 .39709 Mdot
.56234 .23746 Mdot
.58689 .44506 Mdot
.59427 .38878 Mdot
.55276 .45399 Mdot
.34773 .37333 Mdot
.63704 .47313 Mdot
.40722 .37991 Mdot
.22142 .58732 Mdot
.49558 .63404 Mdot
.64999 .66013 Mdot
.59878 .66371 Mdot
.61985 .59363 Mdot
.58955 .57424 Mdot
.26772 .44124 Mdot
.40214 .37025 Mdot
.3124 .51163 Mdot
.55574 .45145 Mdot
.48427 .19175 Mdot
.53878 .69031 Mdot
.51854 .62601 Mdot
.45458 .68901 Mdot
.52323 .48136 Mdot
.45541 .17514 Mdot
.53453 .434 Mdot
.21091 .6025 Mdot
.52678 .44867 Mdot
.60056 .47632 Mdot
.45805 .64053 Mdot
.58388 .57838 Mdot
.55032 .4594 Mdot
.36673 .35167 Mdot
.6333 .66721 Mdot
.45167 .41449 Mdot
.4314 .73151 Mdot
.39332 .57793 Mdot
.6149 .2699 Mdot
.55078 .42154 Mdot
.51873 .63522 Mdot
.39012 .38513 Mdot
.21734 .53033 Mdot
.35045 .4948 Mdot
.24196 .477 Mdot
.50593 .23314 Mdot
.74722 .67806 Mdot
.63212 .66921 Mdot
.80217 .46201 Mdot
.58881 .42569 Mdot
.45152 .65854 Mdot
.64391 .43263 Mdot
.82568 .6256 Mdot
.64275 .70315 Mdot
.44504 .36873 Mdot
.33737 .50387 Mdot
.37091 .34125 Mdot
.54664 .32765 Mdot
.38674 .56512 Mdot
.47861 .57 Mdot
.49129 .68581 Mdot
.65446 .51126 Mdot
.3932 .34038 Mdot
.59586 .40315 Mdot
.83406 .31942 Mdot
.42791 .36439 Mdot
.43327 .34963 Mdot
.70866 .68737 Mdot
.71002 .69849 Mdot
.5376 .48607 Mdot
.37467 .37135 Mdot
.53687 .65633 Mdot
.6074 .67166 Mdot
.55812 .42939 Mdot
.55465 .44271 Mdot
.41704 .38016 Mdot
.46836 .68175 Mdot
.71005 .40029 Mdot
.4917 .65734 Mdot
.39449 .37978 Mdot
.49261 .64852 Mdot
.51291 .68472 Mdot
.48195 .63412 Mdot
.55228 .40801 Mdot
.56285 .4555 Mdot
.4643 .74547 Mdot
.41636 .36909 Mdot
.57536 .41011 Mdot
.61143 .40479 Mdot
.39824 .34059 Mdot
.48914 .60961 Mdot
.51196 .19412 Mdot
.62379 .42912 Mdot
.57687 .42974 Mdot
.64925 .69189 Mdot
.44242 .65304 Mdot
.42575 .78205 Mdot
.56633 .41957 Mdot
.61393 .69542 Mdot
.40687 .32219 Mdot
.60512 .44082 Mdot
.50181 .48533 Mdot
.49751 .68696 Mdot
.63535 .40871 Mdot
.391 .66792 Mdot
.55095 .46639 Mdot
.64279 .19503 Mdot
.63096 .43367 Mdot
.38961 .35292 Mdot
.38409 .33884 Mdot
.71162 .67175 Mdot
.41921 .3481 Mdot
.37945 .68991 Mdot
.34145 .52538 Mdot
.8324 .5925 Mdot
.37821 .68166 Mdot
.5957 .47924 Mdot
.37075 .81369 Mdot
.55613 .3941 Mdot
.57712 .48672 Mdot
.40761 .19676 Mdot
.37957 .67946 Mdot
.38341 .34662 Mdot
.25731 .54256 Mdot
.52632 .45133 Mdot
.356 .51995 Mdot
.61602 .37458 Mdot
.62292 .39129 Mdot
.20918 .43654 Mdot
.32642 .28463 Mdot
.3289 .47769 Mdot
.66956 .40249 Mdot
.5667 .41881 Mdot
.41702 .6404 Mdot
.57535 .46041 Mdot
.65218 .67433 Mdot
.43108 .34825 Mdot
.4844 .67545 Mdot
.61385 .67973 Mdot
.61365 .42991 Mdot
.63727 .67546 Mdot
.4695 .66346 Mdot
.35049 .50871 Mdot
.62325 .44631 Mdot
.64406 .7064 Mdot
.62918 .67509 Mdot
.56402 .40916 Mdot
.38079 .3345 Mdot
.53009 .3639 Mdot
.60291 .43925 Mdot
.5926 .40705 Mdot
.41843 .37582 Mdot
.54214 .85807 Mdot
.62701 .45317 Mdot
.42805 .5161 Mdot
.44318 .37111 Mdot
.40147 .69767 Mdot
.46465 .65807 Mdot
.62505 .3911 Mdot
.35311 .52008 Mdot
.34739 .52495 Mdot
.53696 .64436 Mdot
.36909 .34994 Mdot
.46122 .67896 Mdot
.64917 .36214 Mdot
.51709 .43886 Mdot
.58124 .38124 Mdot
.29235 .77707 Mdot
.80721 .41203 Mdot
.42497 .38291 Mdot
.48387 .62199 Mdot
.49069 .52707 Mdot
.32933 .50934 Mdot
.53151 .65921 Mdot
.368 .3814 Mdot
.41429 .39339 Mdot
.38036 .3789 Mdot
.64229 .69363 Mdot
.48612 .61803 Mdot
.44795 .36192 Mdot
.43387 .34478 Mdot
.56294 .43472 Mdot
.56839 .41655 Mdot
.43237 .31096 Mdot
.71998 .56974 Mdot
.63457 .6599 Mdot
.51613 .64555 Mdot
.40062 .14905 Mdot
.33842 .47808 Mdot
.56753 .24024 Mdot
.56922 .48174 Mdot
.92128 .50448 Mdot
.53319 .43601 Mdot
.58174 .46307 Mdot
.4163 .32418 Mdot
.65934 .6998 Mdot
.63716 .66434 Mdot
.39246 .3393 Mdot
.36911 .38752 Mdot
.65309 .67783 Mdot
.80521 .5377 Mdot
.83777 .50552 Mdot
.22879 .50461 Mdot
.3947 .34846 Mdot
.63276 .26016 Mdot
.35487 .52579 Mdot
.35767 .37033 Mdot
.32189 .48484 Mdot
.49954 .63297 Mdot
.51358 .61957 Mdot
.30889 .50357 Mdot
.56104 .44051 Mdot
.46852 .65713 Mdot
.65336 .45465 Mdot
.81701 .52444 Mdot
.71921 .33635 Mdot
.31327 .63377 Mdot
.60514 .48572 Mdot
.26698 .66045 Mdot
.29573 .68163 Mdot
.61292 .41757 Mdot
.45245 .43539 Mdot
.63373 .67275 Mdot
.353 .36232 Mdot
.34322 .53989 Mdot
.69503 .23341 Mdot
.56946 .46641 Mdot
.39107 .35823 Mdot
.3149 .51749 Mdot
.70508 .65216 Mdot
.22355 .45094 Mdot
.60273 .4701 Mdot
.74968 .23198 Mdot
.35084 .34413 Mdot
.48505 .67498 Mdot
.30144 .75652 Mdot
.4042 .3164 Mdot
.64538 .71783 Mdot
.5114 .61624 Mdot
.74412 .7017 Mdot
.38171 .36378 Mdot
.52891 .62283 Mdot
.40717 .33519 Mdot
.64887 .66859 Mdot
.36908 .32431 Mdot
.52162 .63374 Mdot
.58881 .44863 Mdot
.51075 .65299 Mdot
.63066 .65824 Mdot
.45079 .66481 Mdot
.3479 .5345 Mdot
.38609 .69254 Mdot
.33346 .52013 Mdot
.58544 .58931 Mdot
.26511 .32024 Mdot
.33865 .48969 Mdot
.6847 .64454 Mdot
.60681 .48259 Mdot
.44965 .35499 Mdot
.49711 .66918 Mdot
.54241 .63212 Mdot
.53581 .55099 Mdot
.40528 .34877 Mdot
.51989 .64423 Mdot
.49778 .22898 Mdot
.4523 .84651 Mdot
.54993 .37655 Mdot
.67518 .53805 Mdot
.39854 .3426 Mdot
.531 .64547 Mdot
.21219 .56068 Mdot
.39251 .39398 Mdot
.49244 .66774 Mdot
.34409 .50861 Mdot
.33575 .53798 Mdot
.57497 .4725 Mdot
.33524 .571 Mdot
.50726 .67158 Mdot
.24882 .60845 Mdot
.40182 .32817 Mdot
.70381 .64786 Mdot
.63949 .65836 Mdot
.49711 .63027 Mdot
.57703 .37577 Mdot
.46285 .3885 Mdot
.5241 .67756 Mdot
.73499 .443 Mdot
.38579 .1634 Mdot
.51683 .64863 Mdot
.42865 .34512 Mdot
.39403 .36118 Mdot
.5944 .50723 Mdot
.48105 .50871 Mdot
.45758 .67028 Mdot
.61656 .80851 Mdot
.64458 .59747 Mdot
.39768 .68097 Mdot
.34892 .71547 Mdot
.55254 .46512 Mdot
.56108 .40659 Mdot
.32985 .50728 Mdot
.58023 .44492 Mdot
.43216 .33956 Mdot
.54346 .45305 Mdot
.32425 .54289 Mdot
.51291 .62222 Mdot
.62127 .44475 Mdot
.6057 .66818 Mdot
.32594 .47478 Mdot
.30773 .50308 Mdot
.4865 .64276 Mdot
.3761 .3743 Mdot
.57171 .63724 Mdot
.49792 .65899 Mdot
.54931 .42587 Mdot
.3914 .67138 Mdot
.63901 .42588 Mdot
.7861 .47188 Mdot
.38062 .38866 Mdot
.47353 .67864 Mdot
.43046 .39329 Mdot
.32898 .52178 Mdot
.53651 .6248 Mdot
.57266 .45304 Mdot
.48916 .66618 Mdot
.42393 .74331 Mdot
.80314 .49519 Mdot
.36848 .35025 Mdot
.41175 .7125 Mdot
.43006 .34401 Mdot
.39956 .68085 Mdot
.77277 .50126 Mdot
.62159 .66945 Mdot
.5085 .6297 Mdot
.79514 .39541 Mdot
.502 .66316 Mdot
.5879 .44222 Mdot
.59892 .42824 Mdot
.46576 .64436 Mdot
.61832 .69298 Mdot
.18753 .40152 Mdot
.4174 .52785 Mdot
.38126 .35354 Mdot
.64785 .33935 Mdot
.45308 .13478 Mdot
.30031 .54382 Mdot
.32842 .50414 Mdot
.53931 .47305 Mdot
.57519 .47577 Mdot
.30232 .50918 Mdot
.32277 .54821 Mdot
.65698 .67235 Mdot
.52599 .6347 Mdot
.37944 .31027 Mdot
.29421 .52842 Mdot
.65095 .49169 Mdot
.59415 .57121 Mdot
.53503 .47957 Mdot
.63131 .36488 Mdot
.65033 .44841 Mdot
.63106 .60496 Mdot
.30877 .53576 Mdot
.60734 .41054 Mdot
.62198 .48593 Mdot
.34397 .50188 Mdot
.64879 .66936 Mdot
.31763 .29586 Mdot
.49869 .64619 Mdot
.68576 .80468 Mdot
.6358 .42616 Mdot
.59312 .44256 Mdot
.34564 .48487 Mdot
.41598 .6512 Mdot
.40331 .39026 Mdot
.37456 .37963 Mdot
.478 .64108 Mdot
.54411 .5603 Mdot
.5405 .43279 Mdot
.61183 .41482 Mdot
.51081 .63658 Mdot
.38764 .69222 Mdot
.287 .62193 Mdot
.58986 .41713 Mdot
.31637 .5192 Mdot
.55453 .65472 Mdot
.31136 .53969 Mdot
.634 .44956 Mdot
.58847 .43945 Mdot
.54954 .411 Mdot
.57653 .4766 Mdot
.3127 .49484 Mdot
.60314 .41366 Mdot
.54251 .39138 Mdot
.3743 .3563 Mdot
.55537 .40795 Mdot
.64106 .60246 Mdot
.57109 .43797 Mdot
.61417 .66036 Mdot
.52824 .59001 Mdot
.58663 .47265 Mdot
.5626 .40117 Mdot
.41948 .52787 Mdot
.59129 .4548 Mdot
.33872 .47881 Mdot
.40275 .35596 Mdot
.32871 .51316 Mdot
.3062 .51415 Mdot
.53044 .66756 Mdot
.65701 .67623 Mdot
.56382 .48468 Mdot
.61012 .65475 Mdot
.63571 .37254 Mdot
.64097 .43347 Mdot
.56352 .65619 Mdot
.21137 .60476 Mdot
.42306 .75846 Mdot
.57062 .45254 Mdot
.48682 .63551 Mdot
.48036 .67649 Mdot
.72297 .47181 Mdot
.64698 .46672 Mdot
.30036 .50956 Mdot
.34474 .51289 Mdot
.7567 .53892 Mdot
.20907 .44453 Mdot
.62515 .65857 Mdot
.54518 .57961 Mdot
.63755 .46475 Mdot
.59897 .4079 Mdot
.57599 .37813 Mdot
.48969 .68453 Mdot
.4108 .67773 Mdot
.51909 .62588 Mdot
.42204 .67706 Mdot
.31762 .54298 Mdot
.5454 .45031 Mdot
.72149 .32108 Mdot
.42319 .37946 Mdot
.40339 .3564 Mdot
.29828 .5212 Mdot
.45822 .67961 Mdot
.63568 .4982 Mdot
.33886 .82758 Mdot
.36078 .39014 Mdot
.66168 .67347 Mdot
.61692 .41742 Mdot
.48518 .64087 Mdot
.43278 .36988 Mdot
.60324 .68359 Mdot
.62367 .40254 Mdot
.50771 .60066 Mdot
.5647 .4511 Mdot
.42151 .25102 Mdot
.37667 .351 Mdot
.83568 .61622 Mdot
.37755 .39088 Mdot
.32134 .47569 Mdot
.33689 .49501 Mdot
.59542 .43448 Mdot
.29661 .77242 Mdot
.44328 .34367 Mdot
.33954 .56775 Mdot
.65233 .70195 Mdot
.4066 .66542 Mdot
.64479 .6994 Mdot
.48718 .67983 Mdot
.6315 .66748 Mdot
.52613 .64535 Mdot
.74695 .5428 Mdot
.36411 .40072 Mdot
.61463 .67715 Mdot
.42605 .62065 Mdot
.64034 .46607 Mdot
.60246 .65204 Mdot
.52627 .41408 Mdot
.61638 .33444 Mdot
.50873 .6387 Mdot
.61608 .69113 Mdot
.59248 .40473 Mdot
.69886 .25389 Mdot
.32267 .49788 Mdot
.30252 .50503 Mdot
.65908 .43826 Mdot
.52723 .6349 Mdot
.36222 .36444 Mdot
.45014 .45723 Mdot
.39915 .69707 Mdot
.60891 .41335 Mdot
.54659 .4565 Mdot
.41369 .40416 Mdot
.41578 .40887 Mdot
.59043 .43591 Mdot
.51122 .2166 Mdot
.59353 .4214 Mdot
.34858 .52784 Mdot
.40932 .39278 Mdot
.3973 .35942 Mdot
.51348 .66885 Mdot
.38064 .32561 Mdot
.62493 .36129 Mdot
.3679 .44875 Mdot
.525 .44031 Mdot
.32706 .52728 Mdot
.44518 .47434 Mdot
.45574 .68917 Mdot
.74094 .31204 Mdot
.40655 .4033 Mdot
.58738 .39214 Mdot
.41318 .33263 Mdot
.63772 .68999 Mdot
.41439 .3673 Mdot
.43807 .37157 Mdot
.60769 .43327 Mdot
.60795 .46592 Mdot
.3809 .67968 Mdot
.48859 .51612 Mdot
.38406 .32756 Mdot
.6041 .41691 Mdot
.55397 .3977 Mdot
.61268 .38732 Mdot
.44582 .52243 Mdot
.4278 .38129 Mdot
.53432 .26015 Mdot
.74857 .4308 Mdot
.38098 .33065 Mdot
.61958 .18347 Mdot
.39965 .6667 Mdot
.40504 .66308 Mdot
.30946 .55791 Mdot
.58979 .41623 Mdot
.46971 .63565 Mdot
.6168 .45751 Mdot
.64857 .37059 Mdot
.60637 .45474 Mdot
.61948 .69726 Mdot
.58448 .49276 Mdot
.39114 .68397 Mdot
.50321 .65892 Mdot
.62781 .41646 Mdot
.61935 .44712 Mdot
.39718 .65965 Mdot
.39118 .39897 Mdot
.39803 .39088 Mdot
.64173 .74775 Mdot
.62898 .68439 Mdot
.35192 .50745 Mdot
.55999 .45684 Mdot
.48413 .6365 Mdot
.50892 .65437 Mdot
.37486 .32997 Mdot
.50504 .64758 Mdot
.35348 .49286 Mdot
.57542 .45549 Mdot
.30332 .50483 Mdot
.60817 .68549 Mdot
.43314 .35357 Mdot
.56353 .46322 Mdot
.56369 .43395 Mdot
.38397 .33913 Mdot
.60859 .48187 Mdot
.64967 .69151 Mdot
.50821 .66069 Mdot
.38441 .37283 Mdot
.3424 .52613 Mdot
.51596 .66941 Mdot
.57403 .42073 Mdot
.37435 .17228 Mdot
.58232 .43889 Mdot
.58326 .41668 Mdot
.83673 .46487 Mdot
.54981 .48533 Mdot
.50931 .66759 Mdot
.42455 .4005 Mdot
.6559 .42583 Mdot
.62879 .57627 Mdot
.66732 .76501 Mdot
.53645 .65396 Mdot
.62315 .42077 Mdot
.75359 .32135 Mdot
.62607 .41946 Mdot
.64324 .63007 Mdot
.49474 .78528 Mdot
.67018 .50277 Mdot
.63136 .36654 Mdot
.32152 .49054 Mdot
.37977 .68353 Mdot
.52415 .65767 Mdot
.43772 .29146 Mdot
.60728 .42652 Mdot
.39385 .2692 Mdot
.62713 .39943 Mdot
.33703 .53839 Mdot
.6216 .34166 Mdot
.514 .64747 Mdot
.19611 .57763 Mdot
.55177 .42449 Mdot
.42306 .38608 Mdot
.5174 .67241 Mdot
.40504 .66617 Mdot
.58376 .41267 Mdot
.60264 .65983 Mdot
.34746 .55914 Mdot
.51842 .42906 Mdot
.32966 .53024 Mdot
.61139 .40321 Mdot
.6653 .39008 Mdot
.25119 .70853 Mdot
.37596 .35599 Mdot
.33463 .50446 Mdot
.32206 .70219 Mdot
.61598 .47729 Mdot
.3817 .36652 Mdot
.40935 .35394 Mdot
.63715 .65864 Mdot
.48513 .54949 Mdot
.28282 .35107 Mdot
.68304 .28063 Mdot
.52102 .34985 Mdot
.5315 .65369 Mdot
.29728 .66368 Mdot
.55996 .42558 Mdot
.35453 .57843 Mdot
.33011 .47941 Mdot
.59191 .44504 Mdot
.49437 .3522 Mdot
.43198 .3558 Mdot
.5815 .42742 Mdot
.64835 .6703 Mdot
.3054 .58595 Mdot
.34672 .58701 Mdot
.5176 .16356 Mdot
.53839 .65234 Mdot
.60713 .37678 Mdot
.61301 .36249 Mdot
.37643 .69492 Mdot
.64481 .42025 Mdot
.50835 .66597 Mdot
.79872 .57046 Mdot
.62433 .69794 Mdot
.43497 .3647 Mdot
.40049 .66666 Mdot
.6541 .44318 Mdot
.57358 .38847 Mdot
.65279 .66228 Mdot
.58615 .39616 Mdot
.21869 .65356 Mdot
.35405 .70293 Mdot
.46995 .64895 Mdot
.37838 .37407 Mdot
.64138 .45904 Mdot
.40924 .68072 Mdot
.6045 .43079 Mdot
.66144 .31169 Mdot
.57968 .39456 Mdot
.2668 .3585 Mdot
.38397 .33298 Mdot
.33148 .52776 Mdot
.65078 .3867 Mdot
.60093 .45985 Mdot
.58301 .74089 Mdot
.65103 .374 Mdot
.63206 .43276 Mdot
.36611 .36077 Mdot
.42424 .38133 Mdot
.40732 .37869 Mdot
.46909 .67085 Mdot
.22744 .51588 Mdot
.32036 .5189 Mdot
.54212 .45891 Mdot
.29427 .5259 Mdot
.69055 .37333 Mdot
.65894 .66757 Mdot
.64333 .21867 Mdot
.60243 .39133 Mdot
.40254 .37498 Mdot
.32231 .41895 Mdot
.41017 .32359 Mdot
.52686 .60456 Mdot
.31622 .53257 Mdot
.4305 .35985 Mdot
.59065 .46338 Mdot
.47175 .50856 Mdot
.55032 .18064 Mdot
.33405 .5126 Mdot
.55211 .38777 Mdot
.54106 .63403 Mdot
.46881 .69538 Mdot
.46187 .11887 Mdot
.32866 .49882 Mdot
.30087 .68176 Mdot
.6095 .41965 Mdot
.42036 .38119 Mdot
.33423 .4849 Mdot
.32358 .49405 Mdot
.50968 .64177 Mdot
.60203 .46942 Mdot
.58612 .47116 Mdot
.39408 .66712 Mdot
.34583 .51554 Mdot
.66103 .42687 Mdot
.55069 .39577 Mdot
.81893 .42328 Mdot
.43075 .30306 Mdot
.58349 .85225 Mdot
.64742 .36055 Mdot
.51108 .34619 Mdot
.5006 .50932 Mdot
.44027 .36264 Mdot
.5925 .47315 Mdot
.64425 .45064 Mdot
.51182 .66871 Mdot
.57735 .44785 Mdot
.45763 .65224 Mdot
.32155 .50517 Mdot
.60587 .18306 Mdot
.31892 .3467 Mdot
.79369 .56659 Mdot
.58159 .44943 Mdot
.2166 .41407 Mdot
.62222 .68913 Mdot
.34696 .46924 Mdot
.39553 .38329 Mdot
.6256 .46662 Mdot
.44646 .672 Mdot
.50841 .62883 Mdot
.41911 .35644 Mdot
.24806 .62516 Mdot
.61141 .75032 Mdot
.63354 .45117 Mdot
.46321 .66097 Mdot
.32979 .44522 Mdot
.49404 .21524 Mdot
.29344 .50644 Mdot
.63133 .70133 Mdot
.51718 .62536 Mdot
.30218 .53159 Mdot
.47019 .36273 Mdot
.42637 .35444 Mdot
.4339 .3951 Mdot
.51712 .7653 Mdot
.45573 .66936 Mdot
.61137 .67859 Mdot
.21306 .49078 Mdot
.20706 .4848 Mdot
.62502 .69987 Mdot
.50765 .61963 Mdot
.42955 .37529 Mdot
.38817 .36746 Mdot
.40169 .35566 Mdot
.19408 .56395 Mdot
.37042 .37274 Mdot
.59276 .26957 Mdot
.56157 .39093 Mdot
.54729 .52104 Mdot
.62509 .42185 Mdot
.31609 .48886 Mdot
.37756 .3492 Mdot
.51506 .5282 Mdot
.58854 .48182 Mdot
.53789 .17024 Mdot
.61216 .41276 Mdot
.30068 .49142 Mdot
.58386 .42157 Mdot
.5872 .2375 Mdot
.44345 .36878 Mdot
.57204 .44934 Mdot
.36457 .51394 Mdot
.63161 .678 Mdot
.39407 .30606 Mdot
.58759 .47234 Mdot
.25193 .43111 Mdot
.54515 .47765 Mdot
.80637 .55764 Mdot
.71831 .62973 Mdot
.6625 .67444 Mdot
.60933 .34935 Mdot
.5333 .64057 Mdot
.38032 .30248 Mdot
.52924 .38531 Mdot
.33495 .51391 Mdot
.31758 .26637 Mdot
.50316 .6274 Mdot
.57063 .34811 Mdot
.5722 .50256 Mdot
.65604 .67594 Mdot
.46165 .37262 Mdot
.33887 .48014 Mdot
.58719 .48772 Mdot
.60359 .38325 Mdot
.79485 .55024 Mdot
.52022 .39821 Mdot
.53784 .43268 Mdot
.62684 .65091 Mdot
.54444 .26503 Mdot
.56893 .4356 Mdot
.50226 .60706 Mdot
.43456 .39375 Mdot
.65816 .44195 Mdot
.53292 .25692 Mdot
.60419 .41805 Mdot
.42383 .36527 Mdot
.43814 .39579 Mdot
.29731 .40718 Mdot
.65833 .69666 Mdot
.58033 .39445 Mdot
.74439 .63909 Mdot
.55523 .4154 Mdot
.31708 .52304 Mdot
.62954 .45092 Mdot
.50484 .63244 Mdot
.21 .59063 Mdot
.47817 .66838 Mdot
.62143 .45663 Mdot
.39791 .35395 Mdot
.32631 .48549 Mdot
.47328 .7563 Mdot
.53526 .78231 Mdot
.58524 .26784 Mdot
.71616 .75149 Mdot
.62982 .69654 Mdot
.59013 .66116 Mdot
.35021 .48271 Mdot
.56998 .44809 Mdot
.71981 .65978 Mdot
.53097 .45684 Mdot
.57734 .42831 Mdot
.60802 .45389 Mdot
.369 .56081 Mdot
.32496 .51024 Mdot
.49859 .65162 Mdot
.58849 .43712 Mdot
.60259 .41645 Mdot
.40462 .33133 Mdot
.62934 .67712 Mdot
.47912 .6715 Mdot
.62136 .67905 Mdot
.48129 .6551 Mdot
.63743 .19017 Mdot
.53348 .41376 Mdot
.63319 .68012 Mdot
.34366 .47681 Mdot
.4187 .37621 Mdot
.40649 .68715 Mdot
.4941 .67889 Mdot
.51738 .64536 Mdot
.60939 .41446 Mdot
.42307 .37188 Mdot
.38063 .32733 Mdot
.63544 .6914 Mdot
.34765 .49473 Mdot
.61871 .45814 Mdot
.63829 .44557 Mdot
.70836 .46741 Mdot
.50286 .68095 Mdot
.47966 .22691 Mdot
.29098 .43044 Mdot
.56915 .45066 Mdot
.37356 .36672 Mdot
.61472 .44541 Mdot
.74932 .34133 Mdot
.39692 .3937 Mdot
.60005 .47612 Mdot
.20017 .44704 Mdot
.47643 .68751 Mdot
.26088 .39423 Mdot
.55426 .40288 Mdot
.7521 .71322 Mdot
.56219 .41782 Mdot
.8018 .37077 Mdot
.37194 .64243 Mdot
.54309 .44808 Mdot
.56208 .42863 Mdot
.67098 .268 Mdot
.61487 .42551 Mdot
.39879 .68324 Mdot
.60905 .34288 Mdot
.41496 .39372 Mdot
.52926 .53295 Mdot
.47725 .61023 Mdot
.65338 .70317 Mdot
.47743 .64153 Mdot
.40207 .71891 Mdot
.64983 .67572 Mdot
.39376 .34741 Mdot
.55335 .44806 Mdot
.56854 .55738 Mdot
.54182 .655 Mdot
.5971 .50468 Mdot
.31666 .52631 Mdot
.42053 .70228 Mdot
.46099 .64276 Mdot
.33875 .52602 Mdot
.62001 .39397 Mdot
.5451 .19709 Mdot
.47005 .78515 Mdot
.83704 .59708 Mdot
.3421 .48267 Mdot
.34043 .53768 Mdot
.21175 .54295 Mdot
.64542 .70453 Mdot
.77908 .47913 Mdot
.23888 .38619 Mdot
.35744 .51396 Mdot
.7722 .55064 Mdot
.52663 .62902 Mdot
.24395 .42974 Mdot
.35304 .36252 Mdot
.58121 .38006 Mdot
.59348 .46254 Mdot
.34693 .49647 Mdot
.5026 .47558 Mdot
.27151 .72537 Mdot
.33444 .51914 Mdot
.60354 .36657 Mdot
.45808 .55876 Mdot
.39718 .67062 Mdot
.38242 .67212 Mdot
.66175 .68979 Mdot
.66149 .73493 Mdot
.39893 .33296 Mdot
.6553 .67142 Mdot
.34121 .59188 Mdot
.59353 .39342 Mdot
.34144 .51529 Mdot
.414 .67795 Mdot
.33916 .5328 Mdot
.64362 .66877 Mdot
.66155 .67524 Mdot
.37423 .35771 Mdot
.40208 .38999 Mdot
.50426 .34372 Mdot
.74232 .57429 Mdot
.62691 .41817 Mdot
.40164 .22147 Mdot
.39837 .32677 Mdot
.54532 .37027 Mdot
.61377 .69493 Mdot
.63038 .68088 Mdot
.43294 .25761 Mdot
.55734 .45826 Mdot
.70437 .67136 Mdot
.5636 .46063 Mdot
.76287 .4874 Mdot
.6466 .42681 Mdot
.50732 .64402 Mdot
.54706 .44969 Mdot
.57556 .63908 Mdot
.55499 .46656 Mdot
.6334 .43243 Mdot
.52441 .63047 Mdot
.51955 .43815 Mdot
.5063 .63212 Mdot
.62002 .45941 Mdot
.59207 .67525 Mdot
.48322 .63713 Mdot
.66398 .55577 Mdot
.42788 .51855 Mdot
.39305 .68926 Mdot
.61154 .65853 Mdot
.62837 .65443 Mdot
.60467 .58549 Mdot
.39374 .38239 Mdot
.47321 .38591 Mdot
.57104 .44565 Mdot
.52912 .64191 Mdot
.32744 .5068 Mdot
.60004 .41759 Mdot
.64194 .44409 Mdot
.54172 .41858 Mdot
.42511 .34326 Mdot
.45667 .67702 Mdot
.63778 .6787 Mdot
.46473 .66394 Mdot
.60626 .73519 Mdot
.46979 .62657 Mdot
.62923 .48076 Mdot
.64063 .38651 Mdot
.69294 .34855 Mdot
.35739 .26145 Mdot
.18485 .44238 Mdot
.42303 .35309 Mdot
.38337 .68365 Mdot
.6607 .6761 Mdot
.65495 .34893 Mdot
.39857 .37942 Mdot
.52036 .63233 Mdot
.56464 .45171 Mdot
.57149 .37476 Mdot
.28329 .53872 Mdot
.37204 .30155 Mdot
.66252 .59789 Mdot
.45734 .6456 Mdot
.39997 .67823 Mdot
.22532 .51686 Mdot
.5019 .3787 Mdot
.54282 .55583 Mdot
.60226 .4482 Mdot
.60123 .66208 Mdot
.43275 .36987 Mdot
.47049 .76697 Mdot
.34698 .50684 Mdot
.48306 .51102 Mdot
.58059 .44978 Mdot
.24249 .5281 Mdot
.39916 .35326 Mdot
.64284 .66478 Mdot
.34681 .49742 Mdot
.65815 .70145 Mdot
.38198 .67192 Mdot
.71037 .72027 Mdot
.56632 .40465 Mdot
.63067 .43213 Mdot
.30264 .49213 Mdot
.40457 .33525 Mdot
.66273 .71572 Mdot
.8031 .52024 Mdot
.46419 .65232 Mdot
.69988 .67336 Mdot
.42936 .33255 Mdot
.61915 .26763 Mdot
.46602 .66679 Mdot
.29823 .52218 Mdot
.59506 .59126 Mdot
.32225 .54285 Mdot
.57944 .47226 Mdot
.39984 .36737 Mdot
.3196 .50243 Mdot
.57028 .73792 Mdot
.74605 .29512 Mdot
.6322 .265 Mdot
.54529 .43096 Mdot
.62994 .20613 Mdot
.82594 .50487 Mdot
.48329 .43921 Mdot
.34818 .53495 Mdot
.60275 .43698 Mdot
.64405 .40893 Mdot
.54977 .43024 Mdot
.30997 .51523 Mdot
.57144 .70652 Mdot
.51686 .63902 Mdot
.61831 .41382 Mdot
.64906 .66508 Mdot
.50012 .63684 Mdot
.55675 .66671 Mdot
.51605 .66155 Mdot
.42534 .39117 Mdot
.58669 .47856 Mdot
.24836 .48177 Mdot
.76752 .29569 Mdot
.32992 .51309 Mdot
.39288 .68906 Mdot
.6339 .4143 Mdot
.23673 .36135 Mdot
.40609 .37829 Mdot
.46462 .65023 Mdot
.59374 .4429 Mdot
.57292 .71762 Mdot
.42254 .66355 Mdot
.5186 .65559 Mdot
.3877 .37117 Mdot
.47419 .43995 Mdot
.57799 .44533 Mdot
.56447 .41343 Mdot
.39959 .33662 Mdot
.67108 .73937 Mdot
.21228 .58477 Mdot
.61767 .44667 Mdot
.33319 .52732 Mdot
.41962 .85491 Mdot
.57244 .39227 Mdot
.46002 .3355 Mdot
.40467 .66393 Mdot
.26593 .42937 Mdot
.47223 .22709 Mdot
.61052 .348 Mdot
.68437 .27035 Mdot
.57393 .56976 Mdot
.61665 .18847 Mdot
.60317 .70518 Mdot
.40577 .59178 Mdot
.65067 .19868 Mdot
.36271 .50413 Mdot
.55907 .52914 Mdot
.71412 .41646 Mdot
.23247 .61435 Mdot
.49679 .48601 Mdot
.61377 .78578 Mdot
.5677 .75583 Mdot
.47822 .58701 Mdot
.49518 .66505 Mdot
.75199 .47479 Mdot
.61932 .45604 Mdot
.82631 .51323 Mdot
.52686 .21931 Mdot
.268 .72961 Mdot
.64443 .21288 Mdot
.74693 .63506 Mdot
.5685 .19216 Mdot
.76053 .3381 Mdot
.70296 .35612 Mdot
.33231 .31863 Mdot
.57179 .83792 Mdot
.20876 .49648 Mdot
.76323 .63 Mdot
.65589 .47107 Mdot
.53297 .58028 Mdot
.78481 .62322 Mdot
.59874 .28852 Mdot
.3216 .7873 Mdot
.49606 .67469 Mdot
.44193 .38403 Mdot
.71886 .43657 Mdot
.40793 .30861 Mdot
.37205 .46516 Mdot
.68143 .26617 Mdot
.79807 .37772 Mdot
.57963 .23548 Mdot
.75036 .72001 Mdot
.4581 .29645 Mdot
.16018 .45305 Mdot
.42887 .54639 Mdot
.44939 .3786 Mdot
.50732 .82768 Mdot
.20749 .4824 Mdot
.30784 .34897 Mdot
.67018 .36997 Mdot
.55218 .68019 Mdot
.68914 .56868 Mdot
.39144 .35711 Mdot
.47113 .22069 Mdot
.3771 .67357 Mdot
.31525 .31246 Mdot
.56499 .63113 Mdot
.72866 .29648 Mdot
.4913 .57512 Mdot
.24352 .44456 Mdot
.28458 .64519 Mdot
.3776 .16984 Mdot
.75307 .59116 Mdot
.77354 .39956 Mdot
.28385 .51444 Mdot
.49356 .47567 Mdot
.26214 .67963 Mdot
.72503 .59027 Mdot
.20513 .47311 Mdot
.36718 .20789 Mdot
.82415 .56463 Mdot
.42949 .16701 Mdot
.45745 .34578 Mdot
.54093 .42192 Mdot
.74939 .37548 Mdot
.52561 .35011 Mdot
.65767 .66212 Mdot
.4859 .1634 Mdot
.60182 .67814 Mdot
.43458 .32272 Mdot
.24367 .62328 Mdot
.59206 .25558 Mdot
.69187 .65884 Mdot
.65325 .7127 Mdot
.58336 .494 Mdot
.12316 .5706 Mdot
.60542 .18861 Mdot
.29033 .41097 Mdot
.81924 .42196 Mdot
.27316 .5602 Mdot
.71022 .64621 Mdot
.31619 .50818 Mdot
.71314 .24507 Mdot
.3926 .3706 Mdot
.69978 .20663 Mdot
.73785 .27566 Mdot
.35191 .77097 Mdot
.25755 .78829 Mdot
.33098 .62038 Mdot
.67638 .48798 Mdot
.58821 .56488 Mdot
.65189 .57757 Mdot
.27274 .71455 Mdot
.36558 .78429 Mdot
.26709 .55714 Mdot
.76159 .67657 Mdot
.67496 .22127 Mdot
.7712 .52482 Mdot
.72818 .68599 Mdot
.24642 .64189 Mdot
.43649 .51528 Mdot
.45771 .39377 Mdot
.41134 .49431 Mdot
.33817 .31177 Mdot
.47105 .16452 Mdot
.50042 .3691 Mdot
.34985 .83125 Mdot
.59459 .68692 Mdot
.38763 .6518 Mdot
.81516 .44696 Mdot
.67593 .54541 Mdot
.67852 .35183 Mdot
.22698 .54211 Mdot
.59637 .49517 Mdot
.22316 .52854 Mdot
.39836 .42891 Mdot
.40743 .71454 Mdot
.22159 .51788 Mdot
.30033 .45808 Mdot
.79635 .53933 Mdot
.71849 .34138 Mdot
.2069 .42822 Mdot
.41036 .39628 Mdot
.70383 .60557 Mdot
.76182 .57569 Mdot
.81933 .43087 Mdot
.32101 .70126 Mdot
.84538 .58213 Mdot
.32983 .71691 Mdot
.52998 .4493 Mdot
.55728 .37143 Mdot
.65903 .47381 Mdot
.73479 .59659 Mdot
.54624 .40707 Mdot
.2427 .53134 Mdot
.83057 .45125 Mdot
.4866 .35234 Mdot
.44178 .71558 Mdot
.32963 .25203 Mdot
.83443 .58135 Mdot
.74921 .3939 Mdot
.35828 .64973 Mdot
.5091 .47064 Mdot
.18632 .36948 Mdot
.4919 .64295 Mdot
.77301 .54279 Mdot
.33806 .55206 Mdot
.50611 .76955 Mdot
.65869 .26847 Mdot
.34287 .76378 Mdot
.83349 .45505 Mdot
.21993 .58278 Mdot
.40894 .75775 Mdot
.58578 .61069 Mdot
.68482 .65848 Mdot
.351 .24408 Mdot
.61748 .37124 Mdot
.68862 .41586 Mdot
.60854 .65186 Mdot
.56553 .32641 Mdot
.75474 .4352 Mdot
.53345 .80106 Mdot
.56112 .37346 Mdot
.43999 .80109 Mdot
.40365 .67752 Mdot
.47788 .50969 Mdot
.50358 .12708 Mdot
.61192 .49633 Mdot
.33544 .63205 Mdot
.82088 .57672 Mdot
.70056 .62424 Mdot
.79814 .42778 Mdot
.26297 .47901 Mdot
.4143 .17816 Mdot
.76451 .30492 Mdot
.53053 .78959 Mdot
.57541 .16574 Mdot
.86328 .50611 Mdot
.38288 .19091 Mdot
.39427 .25047 Mdot
.36633 .49956 Mdot
.6451 .14298 Mdot
.48985 .62395 Mdot
.29554 .27953 Mdot
.51496 .35264 Mdot
.53828 .72099 Mdot
.36355 .3462 Mdot
.56478 .51007 Mdot
.48764 .58233 Mdot
.3553 .32731 Mdot
.65471 .45086 Mdot
.42153 .15149 Mdot
.32599 .2319 Mdot
.4331 .15349 Mdot
.80676 .62585 Mdot
.58633 .16994 Mdot
.68455 .49217 Mdot
.60548 .27568 Mdot
.73241 .45627 Mdot
.63129 .451 Mdot
.74512 .51917 Mdot
.32754 .62507 Mdot
.45552 .78005 Mdot
.29836 .34476 Mdot
.37828 .31879 Mdot
.48257 .17571 Mdot
.40517 .12513 Mdot
.46601 .29102 Mdot
.49688 .26336 Mdot
.34505 .5818 Mdot
.74687 .57706 Mdot
.38025 .42233 Mdot
.41595 .78049 Mdot
.81815 .44124 Mdot
.71522 .41182 Mdot
.78052 .55323 Mdot
.5549 .80622 Mdot
.63169 .63082 Mdot
.42254 .64238 Mdot
.72669 .28475 Mdot
.68049 .51519 Mdot
.35041 .75695 Mdot
.56638 .53974 Mdot
.30932 .75682 Mdot
.59526 .77143 Mdot
.3802 .71227 Mdot
.76726 .59388 Mdot
.46526 .69305 Mdot
.76395 .52111 Mdot
.46317 .5526 Mdot
.72908 .41546 Mdot
.57405 .56904 Mdot
.76504 .51554 Mdot
.62775 .63036 Mdot
.50234 .15453 Mdot
.87094 .54313 Mdot
.27875 .26131 Mdot
.76169 .70092 Mdot
.39925 .43315 Mdot
.58173 .3847 Mdot
.84077 .49174 Mdot
.4727 .14644 Mdot
.77924 .32172 Mdot
.23813 .58552 Mdot
.56639 .73167 Mdot
.33722 .47084 Mdot
.27843 .26619 Mdot
.63485 .76667 Mdot
.78206 .37151 Mdot
.18742 .4402 Mdot
.31132 .55887 Mdot
.21723 .61391 Mdot
.29752 .26694 Mdot
.63232 .24955 Mdot
.45167 .23981 Mdot
.58353 .50604 Mdot
.5583 .22154 Mdot
.41757 .40042 Mdot
.28077 .64929 Mdot
.73173 .59013 Mdot
.48784 .64182 Mdot
.66389 .53651 Mdot
.69018 .40283 Mdot
.57912 .49378 Mdot
.46886 .61239 Mdot
.38549 .40631 Mdot
.35299 .26797 Mdot
.29169 .47166 Mdot
.61936 .17089 Mdot
.31742 .64146 Mdot
.67438 .39867 Mdot
.71907 .61781 Mdot
.43575 .75447 Mdot
.22064 .54403 Mdot
.3595 .52303 Mdot
.67746 .23765 Mdot
.39574 .47554 Mdot
.70893 .60721 Mdot
.54001 .2153 Mdot
.79097 .49291 Mdot
.64085 .38804 Mdot
.30651 .42244 Mdot
.64028 .31645 Mdot
.49468 .52279 Mdot
.43909 .33207 Mdot
.40792 .41278 Mdot
.80062 .69891 Mdot
.31913 .59305 Mdot
.33751 .69989 Mdot
.68787 .24769 Mdot
.3127 .53381 Mdot
.39551 .32142 Mdot
.7544 .50408 Mdot
.80014 .54595 Mdot
.61234 .30644 Mdot
.44317 .67426 Mdot
.536 .688 Mdot
.56501 .79127 Mdot
.63555 .21276 Mdot
.59116 .19627 Mdot
.26115 .72724 Mdot
.37327 .3291 Mdot
.78659 .46645 Mdot
.78965 .56431 Mdot
.42029 .33546 Mdot
.41419 .30603 Mdot
.30238 .31654 Mdot
.56061 .1512 Mdot
.23796 .49849 Mdot
.75027 .70454 Mdot
.62217 .60176 Mdot
.57792 .71175 Mdot
.45549 .75686 Mdot
.74616 .65455 Mdot
.69406 .25414 Mdot
.46093 .21818 Mdot
.61109 .22834 Mdot
.67213 .40972 Mdot
.38578 .28038 Mdot
.26404 .27498 Mdot
.43814 .53604 Mdot
.61358 .26166 Mdot
.3443 .44659 Mdot
.55004 .42164 Mdot
.37961 .16907 Mdot
.81688 .52871 Mdot
.20468 .52617 Mdot
.36703 .53344 Mdot
.58165 .40889 Mdot
.53491 .41731 Mdot
.49539 .44705 Mdot
.28067 .42387 Mdot
.33586 .23526 Mdot
.74863 .65387 Mdot
.4385 .43703 Mdot
.52007 .21565 Mdot
.33522 .63359 Mdot
.72922 .30291 Mdot
.82231 .48166 Mdot
.48709 .53886 Mdot
.32205 .62813 Mdot
.58322 .59737 Mdot
.77323 .67986 Mdot
.51549 .57999 Mdot
.69854 .47334 Mdot
.2506 .35707 Mdot
.27281 .45002 Mdot
.44727 .76129 Mdot
.63458 .4106 Mdot
.24688 .62337 Mdot
.75534 .33434 Mdot
.29663 .78116 Mdot
.27277 .7013 Mdot
.40657 .14961 Mdot
.66495 .30513 Mdot
.26502 .45883 Mdot
.574 .20319 Mdot
.2868 .78201 Mdot
.51084 .58548 Mdot
.52732 .17557 Mdot
.5839 .6055 Mdot
.66293 .22838 Mdot
.35999 .53788 Mdot
.22443 .45363 Mdot
.32519 .25578 Mdot
.57329 .15739 Mdot
.76147 .40288 Mdot
.70587 .27219 Mdot
.56538 .54215 Mdot
.52959 .14323 Mdot
.25389 .34505 Mdot
.47543 .58991 Mdot
.53812 .63183 Mdot
.23956 .56194 Mdot
.47113 .19471 Mdot
.34253 .39858 Mdot
.77575 .5495 Mdot
.44664 .6156 Mdot
.66442 .34961 Mdot
.58328 .21711 Mdot
.70099 .53387 Mdot
.28434 .45186 Mdot
.71678 .61914 Mdot
.77213 .34422 Mdot
.45535 .61886 Mdot
.46521 .75304 Mdot
.33272 .66641 Mdot
.71938 .71469 Mdot
.28155 .41865 Mdot
.31207 .59586 Mdot
.77151 .39517 Mdot
.62828 .75749 Mdot
.7522 .62167 Mdot
.86259 .63661 Mdot
.7585 .65872 Mdot
.3283 .30414 Mdot
.46194 .16911 Mdot
.82061 .45879 Mdot
.33988 .28565 Mdot
.25411 .69991 Mdot
.4084 .28685 Mdot
.74466 .5428 Mdot
.60675 .45529 Mdot
.48743 .13241 Mdot
.69897 .56081 Mdot
.47176 .16221 Mdot
.84262 .53233 Mdot
.5574 .21784 Mdot
.57075 .49433 Mdot
.46905 .62255 Mdot
.39129 .57628 Mdot
.7083 .52273 Mdot
.62386 .23078 Mdot
.41875 .28993 Mdot
.416 .69733 Mdot
.36738 .69274 Mdot
.44795 .65672 Mdot
.4626 .4161 Mdot
.30664 .62448 Mdot
.28594 .4363 Mdot
.67947 .70723 Mdot
.51063 .55897 Mdot
.75709 .56786 Mdot
.47821 .22537 Mdot
.6408 .25715 Mdot
.33014 .7593 Mdot
.36547 .45605 Mdot
.50773 .66943 Mdot
.68935 .29352 Mdot
.77271 .64715 Mdot
.30656 .44855 Mdot
.39413 .19466 Mdot
.22502 .55825 Mdot
.73856 .4808 Mdot
.74112 .41879 Mdot
.29461 .73679 Mdot
.6122 .81435 Mdot
.43508 .19308 Mdot
.3589 .27849 Mdot
.7022 .66375 Mdot
.69797 .41563 Mdot
.63802 .19141 Mdot
.76705 .61136 Mdot
.73628 .40133 Mdot
.42583 .53044 Mdot
.57764 .29975 Mdot
.54122 .2075 Mdot
.65101 .55791 Mdot
.53305 .54916 Mdot
.16012 .42794 Mdot
.35813 .34127 Mdot
.36327 .17331 Mdot
.34995 .51578 Mdot
.18165 .55415 Mdot
.63983 .63925 Mdot
.4617 .54471 Mdot
.53655 .54551 Mdot
.30636 .41503 Mdot
.2659 .35803 Mdot
.78853 .6472 Mdot
.33517 .77716 Mdot
.48055 .61889 Mdot
.7246 .66528 Mdot
.70018 .73443 Mdot
.67977 .27305 Mdot
.64456 .46022 Mdot
.75297 .67257 Mdot
.43816 .53091 Mdot
.4524 .77853 Mdot
.83668 .50227 Mdot
.3445 .42462 Mdot
.62849 .36766 Mdot
.7436 .57952 Mdot
.52431 .1772 Mdot
.75103 .29368 Mdot
.21314 .63851 Mdot
.39856 .42921 Mdot
.35693 .48436 Mdot
.64196 .52977 Mdot
.64515 .22725 Mdot
.68925 .63655 Mdot
.23656 .45882 Mdot
.75896 .58596 Mdot
.26632 .24349 Mdot
.3534 .2239 Mdot
.33471 .23651 Mdot
.71497 .63427 Mdot
.40753 .3125 Mdot
.28887 .30623 Mdot
.7366 .40856 Mdot
.33184 .41689 Mdot
.79385 .61341 Mdot
.76987 .55073 Mdot
.22129 .7007 Mdot
.67246 .34343 Mdot
.6102 .73502 Mdot
.51215 .20086 Mdot
.53676 .33988 Mdot
.36886 .51869 Mdot
.73339 .54118 Mdot
.37759 .44339 Mdot
.32097 .47557 Mdot
.28746 .44678 Mdot
.25181 .42484 Mdot
.73573 .39822 Mdot
.62074 .2996 Mdot
.41477 .43629 Mdot
.71292 .31984 Mdot
.36375 .31784 Mdot
.47175 .76621 Mdot
.44834 .74886 Mdot
.46388 .46156 Mdot
.47341 .63928 Mdot
.61516 .34835 Mdot
.50252 .53549 Mdot
.56391 .58675 Mdot
.24697 .30969 Mdot
.59835 .66933 Mdot
.38983 .31546 Mdot
.18661 .51861 Mdot
.42439 .33649 Mdot
.44965 .13915 Mdot
.40653 .77581 Mdot
.5401 .21738 Mdot
.55045 .78149 Mdot
.51789 .8193 Mdot
.14208 .54058 Mdot
.38979 .23775 Mdot
.4172 .51977 Mdot
.34223 .32558 Mdot
.37422 .38456 Mdot
.43732 .69367 Mdot
.37038 .69235 Mdot
.46053 .2446 Mdot
.35118 .62289 Mdot
.7351 .46756 Mdot
.45474 .37301 Mdot
.60684 .72468 Mdot
.57148 .34732 Mdot
.57746 .15479 Mdot
.49999 .66705 Mdot
.18897 .34824 Mdot
.53332 .40614 Mdot
.70097 .34129 Mdot
.8438 .47424 Mdot
.21132 .62252 Mdot
.3964 .74345 Mdot
.64801 .78735 Mdot
.55162 .47067 Mdot
.41809 .43391 Mdot
.3889 .35835 Mdot
.76939 .46524 Mdot
.62887 .66846 Mdot
.67831 .60125 Mdot
.2939 .5227 Mdot
.35825 .75817 Mdot
.30273 .62996 Mdot
.42891 .32737 Mdot
.36147 .42382 Mdot
.75903 .41773 Mdot
.22805 .42315 Mdot
.43909 .52808 Mdot
.67418 .27194 Mdot
.60875 .30199 Mdot
.45371 .37662 Mdot
.38676 .20653 Mdot
.78492 .57125 Mdot
.71751 .2434 Mdot
.62083 .51186 Mdot
.41944 .56071 Mdot
.21777 .42409 Mdot
.30368 .43502 Mdot
.46674 .23153 Mdot
.81652 .43685 Mdot
.71532 .59962 Mdot
.2131 .46931 Mdot
.76265 .51395 Mdot
.52594 .47463 Mdot
.48522 .56738 Mdot
.26416 .6193 Mdot
.1918 .65239 Mdot
.40286 .2607 Mdot
.24105 .6567 Mdot
.34208 .31307 Mdot
.33435 .6311 Mdot
.35629 .3317 Mdot
.48837 .73665 Mdot
.59903 .29311 Mdot
.36549 .72649 Mdot
.67116 .20849 Mdot
.82078 .44279 Mdot
.29447 .55302 Mdot
.5308 .6816 Mdot
.51934 .51675 Mdot
.67289 .43885 Mdot
.47257 .49296 Mdot
.5423 .45101 Mdot
.48261 .41518 Mdot
.20523 .60295 Mdot
.32344 .41967 Mdot
.56458 .50807 Mdot
.62733 .19088 Mdot
.72559 .25155 Mdot
.52063 .1457 Mdot
.69669 .67027 Mdot
.43989 .3687 Mdot
.39172 .18105 Mdot
.50673 .24154 Mdot
.77172 .33885 Mdot
.42461 .20149 Mdot
.81872 .67555 Mdot
.6222 .233 Mdot
.33085 .44946 Mdot
.35846 .77909 Mdot
.27008 .37068 Mdot
.83006 .52392 Mdot
.47297 .59316 Mdot
.44539 .70733 Mdot
.83217 .5317 Mdot
.12449 .55527 Mdot
.38527 .25273 Mdot
.24765 .43558 Mdot
.70534 .42488 Mdot
.44902 .45039 Mdot
.37948 .61587 Mdot
.63103 .44753 Mdot
.53255 .67011 Mdot
.41668 .75922 Mdot
.7619 .56512 Mdot
.69724 .36777 Mdot
.37921 .61832 Mdot
.7127 .51617 Mdot
.76053 .47466 Mdot
.76113 .637 Mdot
.64498 .25174 Mdot
.46527 .2414 Mdot
.63571 .37162 Mdot
.38008 .30944 Mdot
.65572 .69693 Mdot
.40944 .72368 Mdot
.6036 .47234 Mdot
.37884 .72918 Mdot
.24406 .38518 Mdot
.40848 .15275 Mdot
.46443 .72864 Mdot
.808 .53515 Mdot
.35749 .37694 Mdot
.28974 .42332 Mdot
.7347 .33593 Mdot
.23531 .61544 Mdot
.39342 .62172 Mdot
.50201 .36747 Mdot
.6179 .1953 Mdot
.23041 .52755 Mdot
.79123 .52369 Mdot
.21537 .36688 Mdot
.31663 .48261 Mdot
.38001 .27059 Mdot
.70932 .44203 Mdot
.22759 .57861 Mdot
.45882 .36143 Mdot
.28639 .469 Mdot
.42953 .58216 Mdot
.23394 .5352 Mdot
.82211 .57767 Mdot
.77522 .45187 Mdot
.49097 .2016 Mdot
.59857 .19664 Mdot
.53008 .66555 Mdot
.78131 .54918 Mdot
.28558 .47264 Mdot
.40547 .60393 Mdot
.20923 .43555 Mdot
.62106 .17689 Mdot
.48757 .50689 Mdot
.6827 .56433 Mdot
.56162 .4119 Mdot
.53654 .25903 Mdot
.31623 .41302 Mdot
.59477 .63002 Mdot
.33131 .68714 Mdot
.39718 .39278 Mdot
.30059 .64992 Mdot
.43254 .65735 Mdot
.73149 .55415 Mdot
.34483 .37092 Mdot
.46026 .32855 Mdot
.62289 .64579 Mdot
.41475 .6886 Mdot
.65728 .41829 Mdot
.67405 .57592 Mdot
.68247 .64908 Mdot
.38325 .26516 Mdot
.37442 .24974 Mdot
.67944 .27717 Mdot
.80228 .56287 Mdot
.32297 .43889 Mdot
.4221 .20055 Mdot
.27295 .35096 Mdot
.62363 .28277 Mdot
.27841 .67003 Mdot
.5443 .41344 Mdot
.49299 .73575 Mdot
.40295 .31994 Mdot
.65288 .24027 Mdot
.66094 .30887 Mdot
.66576 .55436 Mdot
.46066 .5204 Mdot
.74568 .35038 Mdot
.43543 .49351 Mdot
.84238 .48165 Mdot
.27242 .36889 Mdot
.73013 .59019 Mdot
.32045 .55635 Mdot
.59489 .60971 Mdot
.28537 .72254 Mdot
.71158 .25067 Mdot
.33672 .76519 Mdot
.5723 .55451 Mdot
.23276 .64355 Mdot
.32141 .28703 Mdot
.83855 .52937 Mdot
.73596 .57252 Mdot
.47004 .4915 Mdot
.55832 .35204 Mdot
.27956 .52726 Mdot
.40569 .68741 Mdot
.51126 .73875 Mdot
.48252 .24442 Mdot
.54021 .70291 Mdot
.37445 .73788 Mdot
.66192 .42057 Mdot
.21849 .38488 Mdot
.60591 .19548 Mdot
.64903 .33992 Mdot
.44996 .5452 Mdot
.49766 .77888 Mdot
.72131 .56333 Mdot
.66677 .82607 Mdot
.37852 .16861 Mdot
.56376 .40927 Mdot
.56745 .56991 Mdot
.68683 .59427 Mdot
.46128 .64463 Mdot
.46475 .25664 Mdot
.67322 .26658 Mdot
.3427 .53721 Mdot
.55467 .73607 Mdot
.2427 .54531 Mdot
.30746 .4059 Mdot
.65033 .54935 Mdot
.35479 .56878 Mdot
.43001 .14249 Mdot
.77621 .65066 Mdot
.31546 .42924 Mdot
.72808 .77472 Mdot
.24931 .61015 Mdot
.38067 .41293 Mdot
.75988 .38718 Mdot
.50513 .15348 Mdot
.70629 .62619 Mdot
.51602 .76586 Mdot
.35856 .25039 Mdot
.7237 .59251 Mdot
.77032 .49416 Mdot
.33223 .66553 Mdot
.30751 .65731 Mdot
.4618 .58146 Mdot
.52063 .81876 Mdot
.26154 .30798 Mdot
.48702 .21334 Mdot
.56572 .18246 Mdot
.38257 .75669 Mdot
.23233 .71495 Mdot
.71263 .24456 Mdot
.73388 .52235 Mdot
.36967 .62694 Mdot
.77068 .40344 Mdot
.64268 .59823 Mdot
.49543 .36993 Mdot
.40155 .76934 Mdot
.59637 .31127 Mdot
.49133 .8139 Mdot
.29475 .6991 Mdot
.7642 .51867 Mdot
.51672 .34739 Mdot
.49678 .51448 Mdot
.67437 .28049 Mdot
.3506 .69907 Mdot
.72941 .62141 Mdot
.55831 .74382 Mdot
.62873 .58377 Mdot
.69465 .29149 Mdot
.76591 .371 Mdot
.47403 .48741 Mdot
.12674 .54598 Mdot
.486 .16836 Mdot
.2481 .63726 Mdot
.56325 .39049 Mdot
.66238 .19823 Mdot
.45274 .46425 Mdot
.40795 .2078 Mdot
.81343 .57502 Mdot
.44661 .74121 Mdot
.22185 .40978 Mdot
.53993 .42281 Mdot
.39555 .22716 Mdot
.61276 .258 Mdot
.5313 .34029 Mdot
.4244 .76161 Mdot
.71871 .61533 Mdot
.36108 .66944 Mdot
.63348 .56592 Mdot
.67 .46418 Mdot
.42311 .32773 Mdot
.449 .14752 Mdot
.60951 .53869 Mdot
.55811 .35843 Mdot
.53779 .5128 Mdot
.33717 .77217 Mdot
.68487 .78644 Mdot
.65883 .4799 Mdot
.22847 .52283 Mdot
.7738 .55329 Mdot
.73747 .44094 Mdot
.38644 .24532 Mdot
.30495 .83546 Mdot
.84209 .46028 Mdot
.36374 .37417 Mdot
.42677 .28805 Mdot
.7235 .64127 Mdot
.53117 .15087 Mdot
.55777 .80449 Mdot
.43525 .75039 Mdot
.35073 .80304 Mdot
.65761 .60832 Mdot
.64071 .44406 Mdot
.82307 .5995 Mdot
.71819 .25724 Mdot
.36437 .7564 Mdot
.64454 .19834 Mdot
.57066 .49693 Mdot
.54748 .39697 Mdot
.47853 .89419 Mdot
.66305 .23731 Mdot
.59086 .49683 Mdot
.31627 .76546 Mdot
.46214 .38771 Mdot
.61161 .46151 Mdot
.35278 .60778 Mdot
.76473 .60855 Mdot
.76445 .48313 Mdot
.57159 .15691 Mdot
.43223 .32788 Mdot
.38117 .73255 Mdot
.30447 .53893 Mdot
.53674 .54727 Mdot
.58141 .37205 Mdot
.31279 .50741 Mdot
.74411 .48233 Mdot
.46547 .468 Mdot
.34582 .55899 Mdot
.72955 .67578 Mdot
.84361 .59844 Mdot
.66124 .29604 Mdot
.29295 .5572 Mdot
.50466 .4537 Mdot
.65048 .33701 Mdot
.71091 .52002 Mdot
.71866 .48037 Mdot
.82919 .55335 Mdot
.8779 .45699 Mdot
.47058 .70837 Mdot
.57626 .51895 Mdot
.35408 .39026 Mdot
.47609 .23673 Mdot
.61679 .24251 Mdot
.37492 .50836 Mdot
.37776 .68421 Mdot
.53667 .46405 Mdot
.66819 .4684 Mdot
.2939 .52938 Mdot
.31339 .20949 Mdot
.63799 .43004 Mdot
.43615 .22329 Mdot
.76052 .3265 Mdot
.46802 .76573 Mdot
.69046 .3398 Mdot
.57502 .48578 Mdot
.27756 .31883 Mdot
.44595 .46103 Mdot
.47472 .44679 Mdot
.45435 .75365 Mdot
.55821 .16649 Mdot
.66353 .31161 Mdot
.47611 .20599 Mdot
.60775 .41192 Mdot
.6042 .69058 Mdot
.24064 .43018 Mdot
.36817 .23575 Mdot
.68189 .40991 Mdot
.7682 .32223 Mdot
.45351 .74273 Mdot
.5511 .6974 Mdot
.70548 .38606 Mdot
.45992 .15903 Mdot
.27019 .69044 Mdot
.59103 .23015 Mdot
.20455 .54601 Mdot
.27617 .5887 Mdot
.70268 .53465 Mdot
.46699 .62508 Mdot
.56301 .50863 Mdot
.46153 .38083 Mdot
.46903 .12321 Mdot
.36198 .23953 Mdot
.26938 .50701 Mdot
.41434 .70351 Mdot
.57566 .25386 Mdot
.52073 .52971 Mdot
.77687 .73237 Mdot
.61847 .78337 Mdot
.42414 .1435 Mdot
.76565 .45439 Mdot
.42958 .41813 Mdot
.27184 .46613 Mdot
.57678 .36513 Mdot
.51736 .6536 Mdot
.54 .15578 Mdot
.65243 .49287 Mdot
.29534 .69013 Mdot
.6406 .44052 Mdot
.19859 .50944 Mdot
.40029 .44997 Mdot
.51543 .68742 Mdot
.48497 .69141 Mdot
.25873 .70208 Mdot
.75238 .33911 Mdot
.43973 .46208 Mdot
.767 .72529 Mdot
.59143 .20663 Mdot
.67962 .23893 Mdot
.44384 .6712 Mdot
.19355 .6181 Mdot
.33224 .35779 Mdot
.38598 .43985 Mdot
.29599 .46973 Mdot
.59659 .56488 Mdot
.22965 .56313 Mdot
.74166 .45131 Mdot
.25248 .39863 Mdot
.29078 .54595 Mdot
.9217 .48047 Mdot
.74305 .51074 Mdot
.67148 .37368 Mdot
.25428 .63024 Mdot
.65641 .21506 Mdot
.6724 .6723 Mdot
.83113 .60454 Mdot
.53439 .5795 Mdot
.57129 .37708 Mdot
.63054 .3058 Mdot
.70704 .36786 Mdot
.24317 .55916 Mdot
.14262 .48298 Mdot
.78072 .63395 Mdot
.51387 .70284 Mdot
.50547 .55593 Mdot
.416 .33261 Mdot
.3635 .34807 Mdot
.53486 .79609 Mdot
.80713 .65622 Mdot
.42955 .44475 Mdot
.6479 .22862 Mdot
.15271 .56702 Mdot
.78176 .48645 Mdot
.54061 .14976 Mdot
.32735 .34733 Mdot
.39875 .30156 Mdot
.71711 .51032 Mdot
.62587 .71157 Mdot
.46565 .68817 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2/ooooo`;o0000Vooo
ool001cooooo00?o0000ooooooooool0[?ooool2o`0009_ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Booooo`;o0000]Oooool001cooooo00?o
0000ooooooooool0T_ooool2o`0000?ooooo0_l0002`ooooo`007?ooool00ol0003oooooooooo`20
ooooo`;o00004oooool4o`000;3ooooo000Looooo`03o`000?oooooooooo083ooooo0_l0000Coooo
o`;o00002Oooool2o`000:Oooooo000Looooo`03o`000?oooooooooo0:3ooooo0_l0002Wooooo`00
7?ooool00ol0003oooooooooo`2?ooooo`;o00002_ooool2o`000:cooooo000Looooo`03o`000?oo
oooooooo08oooooo0_l0000:ooooo`;o0000[?ooool001cooooo00?o0000ooooooooool0S_ooool2
o`0001kooooo0_l0000Mooooo`;o0000N_ooool001cooooo00?o0000ooooooooool0Q_ooool4o`00
00Cooooo0_l0000Hooooo`;o00001?ooool2o`0001gooooo0ol0001iooooo`007?ooool00ol0003o
ooooooooo`26ooooo`Co00001?ooool2o`0000Kooooo0_l0000=ooooo`;o000000?oooooo`000?l0
00009?ooool3o`0007Sooooo000Looooo`03o`000?oooooooooo07kooooo1?l0000<ooooo`;o0000
1_ooool2o`0000gooooo0_l00004ooooo`?o00008Oooool2o`0007Sooooo000Looooo`;o0000Oooo
ool5o`0000;ooooo0_l00002ooooo`;o00002oooool2o`0000Sooooo0_l00007ooooo`Go00001?oo
ool2o`0009Gooooo000Looooo`03o`000?oooooooooo087ooooo0_l00002ooooo`;o00000_ooool2
o`0000Wooooo1?l00003ooooo`;o00000_ooool3o`0000Oooooo0_l000000ooooooo0000o`000004
ooooo`;o00000_ooool4o`0008oooooo000Looooo`03o`000?oooooooooo09;ooooo1?l00005oooo
o`;o00000_ooool2o`0000_ooooo0_l00008ooooo`Co0000Soooool001cooooo00?o0000oooooooo
ool0T_ooool2o`000003ooooool0003o000001Wooooo0_l00004ooooo`;o0000TOooool001cooooo
00?o0000ooooooooool0N_ooool2o`0001Wooooo0_l00003ooooo`;o00002?ooool2o`0000[ooooo
0_l00005ooooo`;o0000T?ooool001cooooo00?o0000ooooooooool0Moooool5o`0000cooooo0_l0
0008ooooo`;o000000?oooooo`000?l000000oooool2o`0000Sooooo0_l0000<ooooo`;o00000ooo
ool2o`00093ooooo000Looooo`03o`000?oooooooooo07Kooooo1?l0000>ooooo`;o00002?ooool2
o`0000Kooooo0_l0000?ooooo`;o00000oooool4o`0000Oooooo0_l00007ooooo`?o0000P_ooool0
01cooooo00?o0000ooooooooool0L_ooool2o`0000;ooooo0ol0000>ooooo`;o00001oooool2o`00
01Wooooo0_l00003ooooo`;o00001?ooool2o`0000?ooooo0_l00007ooooo`?o0000P_ooool001co
oooo00?o0000ooooooooool0L_ooool2o`0000oooooo0_l00002ooooo`;o00001_ooool3o`0000Oo
oooo0_l0000<ooooo`?o00003?ooool2o`0000kooooo0_l00021ooooo`007?ooool00ol0003ooooo
ooooo`1looooo`;o00001Oooool2o`0000[ooooo0_l00008ooooo`;o00003?ooool3o`0000Gooooo
0_l0000>ooooo`;o00001Oooool2o`00087ooooo000Looooo`03o`000?oooooooooo07cooooo0_l0
0003ooooo`?o00002oooool2o`0001kooooo0_l00003ooooo`;o00002Oooool4o`0000;ooooo0_l0
0022ooooo`007?ooool00ol0003oooooooooo`21ooooo`?o00002oooool2o`0000[ooooo0_l00008
ooooo`;o00003Oooool2o`0000_ooooo1_l00022ooooo`007?ooool00ol0003oooooooooo`2Koooo
o`;o00000oooool2o`0000?ooooo0_l0000Jooooo`Ko00001?ooool2o`0007cooooo00001_oooooo
k^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`1i
ooooo`;o00002Oooool2o`0000?ooooo0ol000000ooooooo0000o`00000;ooooo`;o00001?ooool2
o`0001?ooooo0_l0000:ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o0000O?oo
ool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A006ooooo`03o`000?oooooooooo07Wooooo0_l000000ooooooo0000o`000003ooooo`;o
000000?oooooo`000?l000000oooool3o`000003ooooool0003o000000Kooooo0_l00003ooooo`;o
00001oooool3o`0000oooooo0_l00005ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o
000000Coooooo`000?l0003ooooo1?l0001jooooo`0000?ooooooa0@4?ooool00_ooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0O?ooool2o`0000?o
oooo0_l00008ooooo`;o00002?ooool2o`0000cooooo0ol00007ooooo`;o000000?oooooo`000?l0
00002_ooool2o`000003ooooool0003o000000;o00000_ooool2o`0000Kooooo1Ol000000ooooooo
0000o`00000>ooooo`;o0000I?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
2oooool00onHV9So8B4Qonk^kP06ooooo`?o0000QOooool3o`0000?ooooo0_l0000?ooooo`;o0000
1Oooool2o`0000Sooooo0_l000000ooooooo0000o`000004ooooo`;o00005Oooool5o`000003oooo
ool0003o000000kooooo0_l0001Tooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooooooo
o`0<ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0Poooool7o`0000gooooo0_l0
0003ooooo`;o00001Oooool3o`0000kooooo1Ol0000@ooooo`;o00000_ooool2o`0007[ooooo0000
0ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1dooooo`;o00001?ooool2o`0000Gooooo1?l00003ooooo`;o00003Oooool2
o`0000?ooooo0_l00006ooooo`;o00001_ooool2o`0000Kooooo0_l000000ooooooo0000o`000003
ooooo`;o00002oooool4o`0000Wooooo0_l00008ooooo`;o0000Ioooool00006oooooomgMgOoV9RH
oooooonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
H_ooool2o`00013ooooo0_l00004ooooo`;o00001Oooool2o`00013ooooo0_l0000Gooooo`;o0000
3_ooool2o`0000?ooooo0_l00008ooooo`;o00002Oooool2o`0000Sooooo0_l0001Wooooo`0000Ko
ooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0
003oooooooooo`1Rooooo`;o0000;oooool2o`0000Gooooo0_l000000ooooooo0000o`00000=oooo
o`;o00004oooool2o`0000Sooooo0_l000001?oooooo0000o`000?ooool2o`0007Kooooo000Loooo
o`03o`000?oooooooooo09;ooooo0_l00006ooooo`;o000000?oooooo`000?l000000oooool2o`00
0004ooooool0003o0000ooooo`;o00000_ooool2o`0000?ooooo0_l00007ooooo`;o00003oooool2
o`000004ooooool0003o0000ooooo`;o00005_ooool2o`0005kooooo000Looooo`03o`000?oooooo
oooo07oooooo0_l0000Aooooo`;o000000?oooooo`000?l000001Oooool4o`0000;ooooo0_l00000
0ooooooo0000o`000003o`0000;ooooo0_l00003ooooo`?o00001_ooool2o`00017ooooo0_l00008
ooooo`;o00004?ooool2o`0005kooooo000Looooo`03o`000?oooooooooo06oooooo0_l0000<oooo
o`Go00002?ooool2o`0000Wooooo0_l00005ooooo`Co00000_ooool2o`0000?ooooo0_l00009oooo
o`?o00006?ooool2o`0000Sooooo0_l0001`ooooo`007?ooool00ol0003oooooooooo`1_ooooo`;o
00003?ooool2o`000003ooooool0003o000000Sooooo0_l00007ooooo`;o000000?oooooo`000?l0
00000_l00004ooooo`;o00000_ooool2o`0000kooooo0ol0000=ooooo`;o00002_ooool2o`0007Wo
oooo000Looooo`03o`000?oooooooooo07gooooo0_l0000Dooooo`;o000000?oooooo`000?l00000
0_l00004ooooo`;o00004_ooool3o`0000Oooooo0_l00002ooooo`Go00000_ooool2o`0000Gooooo
0ol00003ooooo`;o00005oooool2o`0005[ooooo000Looooo`03o`000?oooooooooo05_ooooo0_l0
0009ooooo`;o00004Oooool4o`0001Oooooo0_l000000ooooooo0000o`000004ooooo`?o000000?o
ooooo`000?l000002oooool4o`000003ooooool0003o000000Oooooo0_l00002ooooo`;o000000Co
ooooo`000?l0003ooooo0ol00006ooooo`;o00000oooool2o`000003ooooool0003o000000Gooooo
0_l0000=ooooo`;o000000?oooooo`000?l00000Eoooool001cooooo00?o0000ooooooooool0Fooo
ool2o`0000Oooooo1?l000000ooooooo0000o`000008ooooo`?o00000oooool4o`0001Gooooo1?l0
00000ooooooo0000o`000004ooooo`;o00000_ooool2o`0000_ooooo1?l00007ooooo`;o00002ooo
ool2o`0000oooooo0_l00005ooooo`;o00003Oooool2o`000003ooooool0003o000000;ooooo0_l0
001Cooooo`007?ooool00ol0003oooooooooo`1Tooooo`;o00000oooool2o`0000?ooooo0_l00002
ooooo`Go00001?ooool2o`0001;ooooo0_l000000ooooooo0000o`000003ooooo`;o00003oooool2
o`0000Wooooo0_l00004ooooo`Co00001?ooool2o`0000Sooooo0_l00007ooooo`;o00000_ooool3
o`0001Wooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`1^ooooo`;o00000_ooool5o`00
00Cooooo0_l0000Booooo`;o00000_ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`00
00?ooooo0_l00004ooooo`Co00001?ooool2o`0000Cooooo0_l00002ooooo`;o00001?ooool2o`00
00?ooooo0_l00002ooooo`;o00000_ooool3o`0000Oooooo0_l0001Uooooo`007?ooool00ol0003o
ooooooooo`1Cooooo`;o00006Oooool2o`0000[ooooo0_l0000Fooooo`?o00001?ooool3o`0000Go
oooo0_l00002ooooo`;o00001_ooool2o`0000?ooooo0_l000000ooooooo0000o`00000>ooooo`;o
00002Oooool2o`00013ooooo1Ol0001Rooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o0000
2?ooool2o`0000oooooo0_l000000ooooooo0000o`000005ooooo`Co00005_ooool2o`0000Gooooo
0_l0000:ooooo`;o00002_ooool5o`0000kooooo0_l0000Fooooo`;o00001_ooool3o`0006;ooooo
000Looooo`;o0000G?ooool4o`0000?ooooo0_l00003ooooo`;o00002?ooool2o`0000?ooooo1?l0
0002ooooo`;o00001oooool3o`00017ooooo0_l0000Fooooo`;o000000?oooooo`000?l000003_oo
ool2o`0000Cooooo0_l00002ooooo`;o00003?ooool2o`0000Gooooo0_l00003ooooo`;o00002ooo
ool2o`0005;ooooo000Looooo`03o`000?oooooooooo05_ooooo0_l00005ooooo`;o00000oooool2
o`0000Sooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l00007ooooo`?o00004ooo
ool2o`0000;ooooo0_l0000@ooooo`;o00001?ooool2o`0000?ooooo0_l0000<ooooo`;o00000_oo
ool2o`0000kooooo0ol00002ooooo`;o00000oooool2o`0000_ooooo0_l0001Booooo`007?ooool0
0ol0003oooooooooo`1Vooooo`?o00004?ooool2o`000003ooooool0003o000000_ooooo0_l00008
ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo0_l00008ooooo`?o00001Oooool2
o`0000Cooooo0_l00003ooooo`?o00001?ooool2o`0000Oooooo0_l0000@ooooo`?o00001?ooool2
o`0006;ooooo000Looooo`03o`000?oooooooooo05Oooooo0_l00007ooooo`;o00000_ooool4o`00
00Sooooo0_l0000=ooooo`;o00002?ooool2o`0000Sooooo0_l00003ooooo`;o00003oooool4o`00
013ooooo0_l00004ooooo`;o00001?ooool5o`0001Oooooo0_l00006ooooo`;o0000F_ooool001co
oooo00?o0000ooooooooool0Eoooool4o`0000Gooooo0_l00002ooooo`;o00002_ooool2o`0000go
oooo0_l00003ooooo`;o00006?ooool2o`0000[ooooo1?l0000Fooooo`;o00000oooool3o`00027o
oooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`1Gooooo`Co00000_ooool2o`0000Cooooo
0_l0000:ooooo`;o00002?ooool2o`0000Oooooo1?l0000Hooooo`;o00001?ooool2o`0000Kooooo
0ol00005ooooo`;o00003_ooool3o`0000?ooooo0_l0000;ooooo`;o000000?oooooo`000?l00000
1oooool2o`0006Cooooo000Looooo`03o`000?oooooooooo05Oooooo0_l00004ooooo`;o00001?oo
ool2o`0000[ooooo0_l00007ooooo`?o000000?oooooo`000?l000001?ooool2o`00023ooooo0_l0
0007ooooo`;o00001Oooool2o`0000Cooooo0_l000000ooooooo0000o`000005ooooo`?o00000ooo
ool2o`0000Kooooo0_l00002ooooo`?o000000Coooooo`000?l0003o00001_ooool4o`0001Oooooo
0_l00019ooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o00001oooool2o`0000Cooooo0_l0
000:ooooo`;o00001oooool2o`0000;ooooo0_l0000looooo`;o000000?oooooo`000?l000000_l0
0003ooooo`;o00003?ooool2o`0000;ooooo1ol00004ooooo`;o00000_ooool4o`0001Gooooo0_l0
0019ooooo`007?ooool00ol0003oooooooooo`1Booooo`Co00001Oooool4o`0000Cooooo0_l00006
ooooo`;o00003oooool2o`0000;ooooo0_l00003ooooo`;o0000>?ooool4o`0000gooooo0_l00005
ooooo`Co00001_ooool2o`000004ooooool0003o0000ooooo`;o00000oooool2o`0005_ooooo000L
ooooo`03o`000?oooooooooo05;ooooo0_l00007ooooo`?o00003Oooool2o`0000Cooooo0_l0000=
ooooo`;o00000oooool2o`0000Sooooo0_l0000`ooooo`;o00003Oooool2o`000003ooooool0003o
000000Cooooo0_l00009ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0005_ooooo000L
ooooo`03o`000?oooooooooo04_ooooo0_l0000?ooooo`;o00001oooool2o`0000[ooooo0_l00007
ooooo`Co00004Oooool2o`0003Kooooo0_l00002ooooo`;o00001_ooool2o`0000;ooooo1Ol0000<
ooooo`;o0000Goooool001cooooo00?o0000ooooooooool0@_ooool2o`0000Oooooo0_l0000Hoooo
o`?o00000oooool2o`0000gooooo1_l00007ooooo`;o0000?_ooool2o`0000;ooooo0_l0000:oooo
o`;o000000?oooooo`000?l000003?ooool2o`0000Kooooo0_l0001Gooooo`007?ooool00ol0003o
ooooooooo`12ooooo`;o00008Oooool3o`0000?ooooo0_l0000Aooooo`;o000000?oooooo`000?l0
00001?ooool2o`0003Kooooo0_l00004ooooo`;o00002_ooool2o`0001Gooooo0ol00005ooooo`;o
0000Eoooool001cooooo00?o0000ooooooooool0B?ooool2o`0000Kooooo0_l0000?ooooo`;o0000
0_ooool2o`0000gooooo0_l0000;ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo
0000o`000008ooooo`;o0000:Oooool2o`0000Cooooo0_l00007ooooo`;o000000?oooooo`000?l0
00002oooool2o`0000Wooooo0_l0001Nooooo`007?ooool00ol0003oooooooooo`18ooooo`;o0000
1_ooool2o`0000oooooo0_l0000?ooooo`Ko00003?ooool2o`0000Cooooo0_l00008ooooo`?o0000
:?ooool2o`0000gooooo0_l0000<ooooo`Co00003oooool3o`0005Oooooo000Looooo`03o`000?oo
oooooooo05_ooooo0_l00006ooooo`?o00003?ooool2o`0000;ooooo0_l0000Iooooo`;o00000_oo
ool2o`0002Sooooo0_l0000=ooooo`;o00000oooool2o`0000Oooooo0_l0000;ooooo`?o00000ooo
ool3o`0000Cooooo0_l0001Aooooo`007?ooool2o`0005cooooo0ol00005ooooo`?o00003?ooool2
o`000003ooooool0003o000000Cooooo1Ol0000Aooooo`;o00009Oooool2o`0000cooooo0_l0000;
ooooo`;o00005?ooool3o`0000[ooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`1Loooo
o`;o00002Oooool2o`0000Sooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo1Ol00005
ooooo`;o000000?oooooo`000?l00000;_ooool2o`0000Sooooo0_l000001?oooooo0000o`000?l0
000Fooooo`;o00002Oooool3o`0005gooooo000Looooo`03o`000?oooooooooo05Gooooo0_l00003
ooooo`?o00002_ooool2o`0000Sooooo0_l00005ooooo`;o00000_ooool2o`0000Gooooo1?l00000
0ooooooo0000o`00000>ooooo`;o0000:?ooool5o`0000;ooooo0_l00009ooooo`;o00002?ooool2
o`0000Wooooo0ol00009ooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0COooool2o`00
00;ooooo0_l00002ooooo`;o00000oooool3o`000003ooooool0003o000000cooooo0_l0000:oooo
o`;o00000_ooool2o`0000?ooooo1?l0000Aooooo`Co00007oooool2o`0000Sooooo0ol00003oooo
o`;o00002?ooool5o`0001Gooooo0ol00005ooooo`;o0000D_ooool001cooooo00?o0000oooooooo
ool0COooool2o`0000;ooooo0ol00004ooooo`;o00001?ooool2o`000003ooooool0003o000000;o
00001Oooool4o`0000[ooooo0_l00007ooooo`;o00001_ooool2o`0000?ooooo0_l00006ooooo`;o
00008Oooool2o`0000?ooooo0_l00004ooooo`;o00003Oooool5o`0000[ooooo0_l00004ooooo`;o
00000oooool3o`0005Wooooo000Looooo`03o`000?oooooooooo04_ooooo0_l00005ooooo`;o0000
1?ooool2o`0000Gooooo1_l00005ooooo`?o00002?ooool2o`000003ooooool0003o000000Co0000
0_ooool3o`0000Kooooo0_l00003ooooo`;o0000;_ooool2o`0000cooooo0_l00005ooooo`?o0000
3?ooool2o`0000Cooooo0_l00003ooooo`;o0000F_ooool001cooooo00?o0000ooooooooool0Booo
ool2o`0000;ooooo0_l00005ooooo`;o00001oooool2o`0000;ooooo0ol00002ooooo`;o00002?oo
ool<o`000004ooooool0003o0000o`0004[ooooo0_l00008ooooo`;o00003?ooool2o`0002Gooooo
0_l0000looooo`007?ooool00ol0003oooooooooo`1?ooooo`;o000000?oooooo`000?l000000_oo
ool2o`0000_ooooo0ol00002ooooo`;o00000oooool2o`0000?ooooo1?l000000ooooooo0000o`00
000:o`000003ooooool0003o000000Go0000>Oooool2o`00013ooooo0_l0000<ooooo`Go00002?oo
ool2o`0000?ooooo0_l000000ooooooo0000o`00000@ooooo`;o0000??ooool001cooooo00?o0000
ooooooooool0C_ooool2o`0000;ooooo0_l0000@ooooo`;o00001Oooool4o`0000Gooooo5ol0000e
ooooo`;o00000_ooool2o`0001Kooooo0_l00008ooooo`?o00002?ooool2o`0000?ooooo0_l00000
0ooooooo0000o`00001>ooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o000000?oooooo`00
0?l000005_ooool4o`0000?ooooo0_l00002oooooaOo00001oooool2o`0001Sooooo1?l00004oooo
o`;o00002_ooool2o`0001Wooooo0ol0000Eooooo`;o0000E?ooool001cooooo00?o0000oooooooo
ool0DOooool2o`0000?ooooo0_l0000Aooooo`Go00000_ooool2o`0000?ooooo6_l00003ooooo`;o
00001oooool2o`0000Kooooo0_l00007ooooo`Co00001?ooool2o`0000cooooo0_l00006ooooo`;o
00003oooool2o`0001Kooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o0000
1?ooool2o`0001Cooooo0_l00002ooooo`;o00000ooooolEo`000003ooooool0003o000000;o0000
0oooool2o`0000Oooooo0_l000001?oooooo0000o`000?l00002ooooo`Go00006_ooool4o`000004
ooooool0003o0000ooooo`;o00009_ooool2o`0005Gooooo000Looooo`03o`000?oooooooooo053o
oooo0_l0000Pooooo`?o00000_oooolFo`0000Gooooo0_l000000ooooooo0000o`000002o`0000Go
oooo0ol00004ooooo`?o00004_ooool2o`0000Sooooo0_l000000ooooooo0000o`000007ooooo`;o
00003oooool2o`0000?ooooo0_l00003ooooo`;o00001Oooool3o`0005Cooooo000Looooo`03o`00
0?oooooooooo05Sooooo0_l00008ooooo`;o00003Oooool:o`000003ooooool0003o000000?o0000
00?oooooo`000?l000001?l000000ooooooo0000o`000002o`0000Sooooo1?l0000@ooooo`Co0000
3Oooool2o`0000[ooooo1?l00005ooooo`?o00002_ooool2o`0000;ooooo0ol00003ooooo`;o0000
0oooool2o`0000?ooooo1_l000000ooooooo0000o`000002ooooo`;o0000C?ooool001cooooo00?o
0000ooooooooool0F?ooool2o`0000?ooooo0_l00003ooooo`;o00002_ooool2o`000003ooooool0
003o000001_o00000_ooool7o`0000Wooooo0_l00002ooooo`;o00000oooool4o`0001Gooooo2?l0
0005ooooo`;o00001?ooool4o`0000?ooooo0_l00002ooooo`;o00001?ooool4o`0000Kooooo0ol0
00001?oooooo0000o`000?ooool3o`000003ooooool0003o000004cooooo000Looooo`03o`000?oo
oooooooo04oooooo0_l0000<ooooo`;o00001Oooool2o`000003ooooool0003o000000Gooooo0_l0
0002ooooo`Ko000000?oooooo`000?l000004ol000000ooooooo0000o`000006o`0000Wooooo1_l0
0005ooooo`;o00002Oooool2o`0000?ooooo0_l00004ooooo`Go000000?oooooo`000?l000003?oo
ool4o`0000oooooo0_l0000=ooooo`?o000000Coooooo`000?l0003o0000Boooool001cooooo0_l0
000kooooo`;o00004oooool2o`0000Cooooo0_l00009ooooo`;o00000_ooool2o`000003ooooool0
003o000000Sooooo2_l000000ooooooo0000o`00000@o`000003ooooool0003o000000;o000000?o
ooooo`000?l000000_l0000:ooooo`Oo00003?ooool3o`0000?ooooo0_l00003ooooo`Ko000000?o
ooooo`000?l000000_ooool2o`0000Cooooo0_l000000ooooooo0000o`000007ooooo`;o00003ooo
ool2o`0000Sooooo0_l00002ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0>_ooool2
o`0000Wooooo0_l00008ooooo`;o00000_ooool4o`000003ooooool0003o000000Kooooo0_l0000?
oooooa_o000000?oooooo`000?l000001Oooool4o`0000;ooooo0_l000001?oooooo0000o`000?oo
ool2o`0000;ooooo1Ol00006ooooo`;o000000Coooooo`000?l0003ooooo0ol00008ooooo`Ko0000
1?ooool3o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`;o00000_ooool2o`0000oooooo
0_l000000ooooooo0000o`00000Qooooo`;o0000<oooool001cooooo00?o0000ooooooooool0AOoo
ool2o`0000Oooooo0_l00003ooooo`?o00000_ooool2o`0001Wooooo0_l000000ooooooo0000o`00
000Ho`0000Oooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000;ooooo0_l0
0004ooooo`;o00000oooool5o`0000Wooooo0_l00003ooooo`;o00001_ooool2o`000003ooooool0
003o000000[ooooo0_l00006ooooo`;o00003?ooool4o`0000?ooooo0_l0000Looooo`;o0000<ooo
ool001cooooo00?o0000ooooooooool0BOooool2o`0000?ooooo0_l00003ooooo`?o000000?ooooo
o`000?l000003oooool3o`0000;ooooo0_l00006oooooa7o000000?oooooo`000?l000001ol00000
1?oooooo0000o`000?l00003ooooo`;o00000_ooool2o`0000gooooo0_l000001Ooooooo0000o`00
0?l0003ooooo00?o00001_ooool2o`000003ooooool0003o000000Oooooo0_l000000ooooooo0000
o`000002ooooo`;o00000_ooool2o`0000kooooo0_l0000<ooooo`;o00001Oooool2o`00057ooooo
000Looooo`03o`000?oooooooooo04Wooooo0_l00004ooooo`;o00000_ooool2o`0000;ooooo0_l0
000?ooooo`?o00000_ooool4o`0000;ooooo4?l000000ooooooo0000o`00000:o`000005ooooool0
003o0000o`000?ooool00_l0000Fooooo`?o000000Coooooo`000?l0003o00001_ooool2o`0000Oo
oooo0_l000000ooooooo0000o`000003o`0000Cooooo1?l00005ooooo`;o00007?ooool2o`00057o
oooo000Looooo`03o`000?oooooooooo04Sooooo0ol00004ooooo`;o00007OoooolAo`000003oooo
ool0003o000001;o000000?oooooo`000?l000004Oooool2o`0000Oooooo0_l00005ooooo`;o0000
00Coooooo`000?l0003ooooo0_l00003ooooo`;o00000_ooool4o`0000Cooooo0_l00006ooooo`?o
00000oooool2o`0000oooooo0_l00006ooooo`?o00000oooool2o`0004_ooooo000Looooo`03o`00
0?oooooooooo04;ooooo0_l00004ooooo`;o00002oooool2o`0001[ooooo8Ol0000:ooooo`;o0000
00?oooooo`000?l000000_l00005ooooo`;o000000?oooooo`000?l000002oooool2o`000004oooo
ool0003o0000ooooo`Co000000Goooooo`000?l0003o0000ooooo`04o`0000cooooo0_l00004oooo
o`Co000000?oooooo`000?l000002_ooool2o`0000Oooooo1?l000000ooooooo0000o`00001;oooo
o`007?ooool00ol0003oooooooooo`0iooooo`;o00001oooool2o`00013ooooo0ol0000>ooooo`;o
00001Oooool6o`0000;ooooo7?l00002ooooo`;o00000oooool2o`0000?ooooo1ol00005ooooo`Oo
00000_ooool2o`000003ooooool0003o000000?ooooo0ol00003ooooo`?o00000_ooool9o`0000;o
oooo0_l00003ooooo`Go00001Oooool3o`000003ooooool0003o0000017ooooo1ol00005ooooo`;o
0000A_ooool001cooooo00?o0000ooooooooool0>Oooool2o`0000gooooo1?l00005ooooo`;o0000
00?oooooo`000?l000003oooool2o`0000Gooooo2?l000000ooooooo0000o`00000Go`0000;ooooo
1?l00003ooooo`;o00001?ooool2o`0000Wooooo0ol000001Ooooooo0000o`000?l0003ooooo00co
00000oooool2o`0000?ooooo0ol000001?oooooo0000o`000?ooool2o`0000;ooooo0ol00002oooo
o`Go00001?ooool3o`00013ooooo0_l00003ooooo`;o00000oooool2o`0000;ooooo0_l000000ooo
oooo0000o`000016ooooo`007?ooool00ol0003oooooooooo`17ooooo`Go00001Oooool2o`0000So
oooo0_l0000@ooooobOo00002oooool6o`0000Oooooo0_l000000ooooooo0000o`000004o`000003
ooooool0003o000000?o00000_ooool3o`000004ooooool0003o0000ooooo`?o00001oooool4o`00
00Cooooo0_l00005ooooo`;o00003Oooool2o`0000;ooooo0_l0000<ooooo`?o0000B?ooool001co
oooo00?o0000ooooooooool0@oooool2o`0000;ooooo1?l0000@ooooo`Co00004OoooolTo`0000_o
oooo1_l0000:ooooo`;o00001?ooool7o`000003ooooool0003o000000Go000000?oooooo`000?l0
00000oooool2o`0000;ooooo1?l0000Jooooo`;o00004Oooool2o`0004Sooooo000Looooo`03o`00
0?oooooooooo047ooooo1?l00002ooooo`;o00004_ooool6o`00017ooooo6?l00002ooooo`;o0000
1?ooool2o`0000[ooooo0_l0000;ooooo`Co00001?ooool5o`000003ooooool0003o000000?o0000
00?oooooo`000?l000000ol00003ooooo`;o000000?oooooo`000?l000000_ooool4o`0007Oooooo
000Looooo`03o`000?oooooooooo03[ooooo0_l00004ooooo`Go00000_ooool2o`000003ooooool0
003o000000;o00003Oooool2o`0000;ooooo0_l0000>ooooo`;o00000ooooolFo`000004ooooool0
003o0000o`0000Cooooo0_l00002ooooo`;o00001Oooool3o`0000Sooooo0_l000000ooooooo0000
o`00000>o`000003ooooool0003o000000;ooooo2Ol000000ooooooo0000o`000006o`0000oooooo
0_l0000@ooooo`;o00003Oooool2o`0004Gooooo000Looooo`03o`000?oooooooooo03[ooooo0_l0
0004ooooo`;o000000?oooooo`000?l000001Oooool4o`00027ooooo1?l000000ooooooo0000o`00
000>o`000003ooooool0003o000000?o000000?oooooo`000?l000000_l00003ooooo`?o000000?o
ooooo`000?l000001Oooool2o`0000Wooooo0_l00004ooooo`co00000oooool5o`000003ooooool0
003o000000Co00000oooool:o`0000_ooooo0_l0000>ooooo`Co00003?ooool4o`0004Cooooo0000
1_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0
1?ooool00ol0003oooooooooo`13ooooo`;o0000:_ooool4o`0000Cooooo6?l00002ooooo`Co0000
3Oooool3o`0000?ooooo0_l00002oooooaoo000000?oooooo`000?l000002?l0000Jooooo`?o0000
3_ooool4o`0004Cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0DOooool2o`0000Oooooo0_l0000:ooooo`;o
00001oooool3o`0000Gooooo5_l00004ooooo`;o00003oooool3o`0000Oooooo7ol00005ooooo`;o
00000_ooool2o`0001[ooooo0_l00005ooooo`;o00001Oooool2o`0004Wooooo00000ooooooo410@
ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006ooooo`03o`000?oooooooooo04kooooo
0_l000000ooooooo0000o`000007ooooo`;o00002_ooool2o`0000Cooooo0_l00002ooooo`;o0000
1?ooool2o`0000?ooooo2Ol00003ooooo`Ko00002Oooool2o`0000?ooooo0_l00002ooooo`;o0000
0oooool5o`0000Gooooo1?l000000ooooooo0000o`00000Go`0000;ooooo0ol00003ooooo`Go0000
3?ooool2o`0000Cooooo0_l00003ooooo`;o00001Oooool2o`0000Gooooo0_l00003ooooo`;o0000
A?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?m4A4CogMgMoooo
ool00007ooooo`?o0000>Oooool2o`0000Oooooo0_l00008ooooo`Co00007?ooool2o`0000Gooooo
0_l000001Ooooooo0000o`000?l0003ooooo00ko00003?ooool4o`0000?ooooo0_l00002ooooo`;o
00000oooool5o`0000Oooooo7Ol000001?oooooo0000o`000?l00004ooooo`Co00000oooool2o`00
00Cooooo1Ol00002ooooo`Co00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000002oooo
o`;o00001Oooool3o`0001Sooooo0_l0000Zooooo`0000?oooooo`000?ooool00_ooool00ol0003o
ooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0>?ooool3o`00
00Gooooo1?l00008ooooo`;o00004_ooool2o`0000oooooo1?l000000ooooooo0000o`00000Ao`00
00_ooooo0_l00003ooooo`Co00002Oooool2o`000003ooooool0003o000000Gooooo3?l000000ooo
oooo0000o`00000>o`000003ooooool0003o000000;o00001?ooool2o`000004ooooool0003o0000
ooooo`;o00001?ooool3o`0000Cooooo1?l00007ooooo`;o000000?oooooo`000?l000000_ooool2
o`0000Gooooo0_l0000Iooooo`;o0000:_ooool00003ooooool@413ooooo00;ooooo00?o410@oooo
ooooool02_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo03Sooooo0_l000000ooo
oooo0000o`000003ooooo`;o00002oooool2o`0000_ooooo0_l000001?oooooo0000o`000?ooool3
o`0000kooooo0_l00006ooooo`;o000000?oooooo`000?l000000oooool4o`0000;ooooo0_l0000@
ooooo`Co00002Oooool2o`000004ooooool0003o0000ooooobKo00001oooool2o`00013ooooo0_l0
000:ooooo`;o0000D?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4
o`000007ooooo`03o`000?oooooooooo03_ooooo0_l00003ooooo`;o00000_ooool2o`0000Oooooo
0_l0000;ooooo`Go00000_ooool2o`0001Wooooo0_l00003ooooo`Co00009ooooolVo`0000Gooooo
0_l000000ooooooo0000o`000009ooooo`;o00001?ooool2o`0001Gooooo0_l00015ooooo`0000Ko
ooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000oooooooo
ool0=_ooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`000004ooooool0003o0000o`00
00;ooooo0_l0000Aooooo`;o00000oooool2o`000003ooooool0003o000000;o00004Oooool2o`00
00;ooooo0_l00003ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Sooooo0_l0000<oooo
ob_o00001Oooool2o`000003ooooool0003o000000?ooooo0_l00004ooooo`;o00000_ooool3o`00
01Kooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00000oooool2o`000004
ooooool0003o0000o`0000;ooooo0ol00002ooooo`;o00003_ooool2o`0000Kooooo0_l000000ooo
oooo0000o`000002o`000003ooooool0003o000000kooooo0_l00007ooooo`;o000000?oooooo`00
0?l000000_ooool2o`0000Gooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o000000?ooooo
o`000?l000001?ooool2o`0000Gooooo;_l00002ooooo`;o00001?ooool2o`000003ooooool0003o
000000?ooooo0_l00003ooooo`Co00001_ooool2o`0000gooooo0_l00015ooooo`007?ooool00ol0
003oooooooooo`15ooooo`;o00004Oooool2o`0000_ooooo0_l000000ooooooo0000o`00000;oooo
o`;o00004Oooool2o`0000Sooooo0ol000000ooooooo0000o`000007ooooo`;o00000oooool4o`00
0003ooooool0003o000002Ko000000Goooooo`000?l0003o0000ooooo`04o`0000;ooooo0_l00006
ooooo`;o00001Oooool4o`0000Cooooo0_l00005ooooo`;o00002_ooool2o`0001[ooooo0_l0000U
ooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00002?ooool7o`0000;ooooo1?l00007oooo
o`;o000000Coooooo`000?l0003o00000oooool2o`0000?ooooo0_l00002ooooo`;o000000?ooooo
o`000?l000001?ooool2o`000004ooooool0003o0000ooooo`;o000000Coooooo`000?l0003o0000
9?ooool4o`0000?ooooo:?l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o0000
1?ooool2o`0000Cooooo0_l0000;ooooo`;o00000_ooool2o`0000Kooooo0_l0000Jooooo`;o0000
9Oooool001cooooo00?o0000ooooooooool0<?ooool2o`0000Oooooo0_l00008ooooo`;o000000?o
ooooo`000?l000000_l00002ooooo`Co00001oooool2o`000004ooooool0003o0000o`0000?ooooo
0_l00007ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Cooooo0_l000001?oooooo0000
o`000?l00008ooooo`;o00005?ooool2o`0000;ooooo1Ol00002ooooobko00003?ooool2o`0000Co
oooo0_l0000Eooooo`Go00000oooool2o`00047ooooo000Looooo`03o`000?oooooooooo033ooooo
0_l0000>ooooo`;o00002?ooool4o`0000Gooooo0_l00006ooooo`;o00001_ooool2o`0000kooooo
0_l00009ooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o00003oooool2o`0000;ooooo
0_l00003ooooo`Go000000?oooooo`000?l00000:ol0000Gooooo`;o00001_ooool2o`0000?ooooo
0_l000000ooooooo0000o`000002o`0000?ooooo0_l00011ooooo`007?ooool00ol0003ooooooooo
o`10ooooo`;o00002?ooool8o`000003ooooool0003o000000Kooooo0_l00006ooooo`;o000000?o
ooooo`000?l000002oooool2o`0000Wooooo0_l00002ooooo`Co00001Oooool2o`0001Sooooo5_l0
00000ooooooo0000o`00000Ao`000003ooooool0003o000000Ko00004_ooool2o`0000?ooooo0_l0
0003ooooo`;o000000?oooooo`000?l000000oooool2o`000003ooooool0003o000000;ooooo0_l0
00000ooooooo0000o`000011ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00002oooool5
o`0000?ooooo0_l000001?oooooo0000o`000?l00004ooooo`;o00001Oooool2o`0001Kooooo0_l0
0003ooooo`?o00001Oooool2o`0000;ooooo0_l0000@ooooo`?o00000ooooolCo`000003ooooool0
003o000001;o000000Coooooo`000?l0003ooooo0_l0000Aooooo`Ko00001Oooool2o`000003oooo
ool0003o000000Wooooo0_l00002ooooo`Co0000@_ooool001cooooo00?o0000ooooooooool0>Ooo
ool2o`0000Gooooo0_l0000;ooooo`;o000000?oooooo`000?l000000oooool2o`000004ooooool0
003o0000o`0000Cooooo0_l00004ooooo`;o00000_ooool2o`0000oooooo0_l00007ooooo`;o0000
1_ooool2o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l000001_oooolZo`000005oooo
ool0003o0000o`000?ooool01?l00003ooooo`;o00000oooool2o`0000Sooooo1?l00007ooooo`;o
00004_ooool2o`0004;ooooo000Looooo`03o`000?oooooooooo03Cooooo0_l00002ooooo`?o0000
5Oooool2o`000003ooooool0003o000000Cooooo0_l0000:ooooo`;o00000_ooool2o`0000Cooooo
0_l00006ooooo`;o000000?oooooo`000?l000006_ooool2o`000003ooooool0003o000000;o0000
0oooool9o`000004ooooool0003o0000oooooako000000?oooooo`000?l000000_l000001?oooooo
0000o`000?l00003ooooo`;o00000oooool2o`0000Gooooo0_l000000ooooooo0000o`000002oooo
o`Co00001?ooool2o`0001;ooooo0ol00010ooooo`007?ooool00ol0003oooooooooo`0dooooo`;o
00000_ooool2o`0000Kooooo0_l00009ooooo`;o00001_ooool2o`0000Cooooo0_l0000<ooooo`;o
00001_ooool2o`0000Kooooo0_l0000?ooooo`;o00004Oooool2o`0000?ooooo1Ol00005ooooo`;o
000000?oooooo`000?l000008Ol000001?oooooo0000o`000?l0000?ooooo`;o000000?oooooo`00
0?l000000_ooool4o`0000Cooooo0_l0000=ooooo`;o00000oooool4o`0000Cooooo0_l0000ioooo
o`007?ooool00ol0003oooooooooo`0mooooo`;o000000?oooooo`000?l000002Oooool2o`0000co
oooo0ol00004ooooo`;o00001Oooool3o`0000;ooooo0_l00006ooooo`;o00002oooool2o`0000Go
oooo0_l0000<ooooo`;o00001Oooool2o`0000Gooooo0_l000001Ooooooo0000o`000?l0003ooooo
02Ko0000<?ooool2o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`;o0000>Oooool001co
oooo0_l0000nooooo`;o00001_ooool2o`0000kooooo0_l00002ooooo`?o00001?ooool4o`0000Co
oooo0_l00002ooooo`;o00001_ooool2o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l0
00002oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`000003ooooool0003o000002ko
00005_ooool2o`0000;ooooo0_l00005ooooo`;o00002oooool2o`0000?ooooo0_l0000mooooo`00
7?ooool00ol0003oooooooooo`0`ooooo`?o00001_ooool2o`0000[ooooo0_l0000>ooooo`;o0000
0_ooool2o`0000Gooooo1?l0000Eooooo`;o00000oooool2o`0000cooooo1?l0000?ooooo`?o0000
1OoooolUo`000003ooooool0003o000000So00005_ooool2o`0000;ooooo0_l00002ooooo`;o0000
00?oooooo`000?l000000_l0000<ooooo`Go0000??ooool001cooooo00?o0000ooooooooool0<?oo
ool3o`0000Kooooo0_l00009ooooo`?o00001_ooool2o`0000Sooooo0_l00002ooooo`;o000000?o
ooooo`000?l000002?ooool2o`0000Wooooo0_l0000Gooooo`Co00003oooool3o`0000;ooooo0_l0
0003ooooob?o00000oooool4o`0001Oooooo0_l00009ooooo`;o00000oooool2o`0000Cooooo0_l0
0005ooooo`?o000000?oooooo`000?l000003?ooool2o`0002kooooo000Looooo`03o`000?oooooo
oooo03_ooooo0_l00007ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000oooool2
o`0000;ooooo0_l000000ooooooo0000o`000008ooooo`;o00002Oooool2o`0000[ooooo0_l00000
0ooooooo0000o`000009ooooo`?o00000oooool2o`0000oooooo0ol000001Ooooooo0000o`000?l0
003ooooo023o000000Goooooo`000?l0003o0000ooooo`04o`0001Gooooo0_l00003ooooo`;o0000
3oooool2o`0000Gooooo1?l00003ooooo`;o00002Oooool2o`0002kooooo000Looooo`03o`000?oo
oooooooo033ooooo0_l00009ooooo`;o00002oooool4o`0000Kooooo0_l0000=ooooo`;o00004_oo
ool2o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l000001oooool6o`000004ooooool0
003o0000o`0000oooooo0ol000001?oooooo0000o`000?oooolUo`0000;ooooo0ol000000ooooooo
0000o`00000Booooo`;o00000oooool2o`00013ooooo0_l00006ooooo`;o000000?oooooo`000?l0
00000_l0000iooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00005_ooool4o`0000Wooooo
0_l0000:ooooo`;o00000_ooool2o`000003ooooool0003o000000Oooooo0_l00002ooooo`;o0000
1?ooool2o`0000;ooooo0_l0000:ooooo`;o00000_ooool2o`000005ooooool0003o0000o`000?oo
ool00_l00009ooooo`;o000000Coooooo`000?l0003o00001?oooolUo`0000Kooooo0_l0000:oooo
o`;o00001_ooool3o`0000Gooooo0_l000001?oooooo0000o`000?l00004ooooo`;o00000oooool3
o`0000Sooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`11ooooo`?o00001Oooool3o`00
0003ooooool0003o000000Kooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00001_ooool2
o`000003ooooool0003o000000;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l0000>
ooooo`;o00002Oooool5o`000003ooooool0003o000000Wooooo1_l00004ooooo`?o000000?ooooo
o`000?l000002Ol00002ooooo`ko000000?oooooo`000?l000000ol000000ooooooo0000o`000002
ooooo`;o00002oooool2o`0000Oooooo0_l00005ooooo`;o000000Coooooo`000?l0003o00001?oo
ool2o`0000Cooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`0oooooo`Go00001Oooool2
o`0000;ooooo0_l0000:ooooo`Ko00002Oooool4o`000003ooooool0003o000001Kooooo0_l00002
ooooo`;o00001Oooool4o`0000kooooo1ol000001?oooooo0000o`000?l00002ooooo`?o000000?o
ooooo`000?l000005Ol000001?oooooo0000o`000?ooool6o`000004ooooool0003o0000ooooo`Co
00000oooool2o`0000Kooooo0_l0000?ooooo`;o00000_ooool2o`0000[ooooo1?l0000mooooo`00
7?ooool00ol0003oooooooooo`0oooooo`;o00002_ooool2o`0000cooooo1?l00007ooooo`Oo0000
00?oooooo`000?l000003oooool2o`0000[ooooo0_l00002ooooo`;o00003_ooool4o`0000Cooooo
1?l000001?oooooo0000o`000?l00003oooooaCo000000Coooooo`000?l0003ooooo0_l000000ooo
oooo0000o`000002ooooo`Go00001?ooool4o`0000?ooooo0_l00006ooooo`;o00001oooool2o`00
0003ooooool0003o000000?ooooo0_l00002ooooo`;o00002_ooool4o`0000;ooooo0_l0000ioooo
o`007?ooool00ol0003oooooooooo`1;ooooo`;o00001Oooool2o`0000Gooooo0_l00009ooooo`go
00003?ooool2o`0000;ooooo0_l0000:ooooo`;o00003_ooool4o`0000Kooooo0_l000001?oooooo
0000o`000?ooool2o`000003ooooool0003o000000Oo000000?oooooo`000?l000001Ol00002oooo
o`Co00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000Looooo`;o000000?oooooo`00
0?l000001?ooool2o`0000oooooo0_l00002ooooo`;o0000>Oooool001cooooo00?o0000oooooooo
ool0:oooool2o`0000kooooo0ol00002ooooo`?o00002_ooool2o`0000;ooooo0ol00003ooooo`Co
00002?ooool2o`000003ooooool0003o000000[o00000_ooool2o`0000_ooooo0_l0000Looooo`;o
00001Oooool2o`0000;ooooo1Ol000000ooooooo0000o`000002ooooo`Wo000000?oooooo`000?l0
00003Ol00002ooooo`;o000000?oooooo`000?l000004_ooool2o`0000Cooooo1?l00005ooooo`;o
00000_ooool2o`0000cooooo0_l00005ooooo`Co00005_ooool2o`0001oooooo000Looooo`03o`00
0?oooooooooo02_ooooo0_l0000>ooooo`?o00000_ooool3o`0000[ooooo0_l00002ooooo`;o0000
1?ooool2o`0000Wooooo4?l00002ooooo`;o00005oooool2o`0000Oooooo0_l00006ooooo`?o0000
1Oooool2o`0000?ooooo0ol000000ooooooo0000o`000002oooooa;o000000?oooooo`000?l00000
0ol00009ooooo`;o00004?ooool3o`0000?ooooo1?l00005ooooo`;o00000oooool2o`0000Gooooo
0_l00004ooooo`;o000000?oooooo`000?l000000_ooool4o`0001Kooooo0_l0000Oooooo`007?oo
ool00ol0003oooooooooo`0mooooo`;o000000?oooooo`000?l000007OoooolFo`0001Sooooo0_l0
0005ooooo`Co00001_ooool3o`0000Kooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo0_l0
0002ooooo`go00000_ooool3o`0000_ooooo2?l00009ooooo`Co00002oooool3o`0000?ooooo0_l0
0005ooooo`;o00001oooool3o`0003cooooo000Looooo`03o`000?oooooooooo02cooooo0_l0000?
ooooo`;o00000oooool2o`0000?ooooo0_l0000EoooooaOo00004_ooool2o`0000Sooooo0_l00000
0ooooooo0000o`000002o`0000oooooo0ol00005ooooo`;o000000?oooooo`000?l000000oooool;
o`0000Oooooo1Ol00002ooooo`;o00001?ooool7o`0000Sooooo0_l0000=ooooo`?o00003Oooool2
o`0000Gooooo1?l0000jooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00004_ooool4o`00
00?ooooo0_l0000>ooooo`;o00001?oooolGo`0000kooooo0_l00003ooooo`;o000000?oooooo`00
0?l000001?ooool3o`0000;ooooo0ol0000@ooooo`;o00000_ooool2o`000004ooooool0003o0000
ooooo`[o000000Goooooo`000?l0003o0000ooooo`02o`0000Kooooo1Ol00002ooooo`;o00002?oo
ool3o`0001Wooooo0_l00002ooooo`Go00000_ooool2o`000003ooooool0003o000000Oooooo0_l0
000jooooo`007?ooool00ol0003oooooooooo`0looooo`;o00000_ooool2o`0000;ooooo0_l00004
ooooo`;o00002oooool2o`0000Cooooo5_l00003ooooo`;o00002_ooool2o`0000Kooooo0_l00004
ooooo`?o00000oooool2o`00013ooooo0_l00002ooooo`;o00001_ooool<o`000003ooooool0003o
000000;o00001_ooool2o`0000?ooooo0_l0000Tooooo`;o00000_ooool5o`0000;ooooo0_l00016
ooooo`007?ooool2o`0003gooooo0_l00002ooooo`;o00000_ooool2o`0000Cooooo0ol00007oooo
o`;o00001ooooolKo`0001Cooooo0_l00002ooooo`?o00000_ooool3o`0001_ooooo1ol00002oooo
o`;o00001Oooool5o`000003ooooool0003o000000;o000000?oooooo`000?l000000_ooool2o`00
01gooooo0_l00004ooooo`;o00002?ooool2o`0000Sooooo0ol0000kooooo`007?ooool00ol0003o
ooooooooo`0jooooo`So00001Oooool2o`0000;ooooo0ol00006ooooo`;o00001ooooolIo`0001?o
oooo0_l000000ooooooo0000o`000002o`0000Gooooo1?l0000Dooooo`;o00001?ooool:o`000003
ooooool0003o000000Cooooo1ol00003ooooo`;o00000_ooool2o`0000;ooooo0_l0000Iooooo`;o
00001?ooool2o`0000Sooooo0_l00005ooooo`;o000000Coooooo`000?l0003o00006Oooool2o`00
023ooooo000Looooo`03o`000?oooooooooo03[ooooo0_l00002ooooo`;o00001oooool2o`000003
ooooool0003o000000;o00001_ooool2o`0000Kooooo6?l0000Eooooo`;o00000oooool2o`0000Oo
oooo0ol000000ooooooo0000o`000002o`0000Oooooo0_l00005ooooo`;o00001Oooool<o`0000?o
oooo2?l00007ooooo`;o00000_ooool2o`0000?ooooo0_l0000@ooooo`;o00000_ooool2o`0001Co
oooo0ol000001?oooooo0000o`000?l00007ooooo`;o00004?ooool2o`00023ooooo000Looooo`03
o`000?oooooooooo03_ooooo1_l00009ooooo`;o00002?ooool2o`0000Kooooo5ol00002ooooo`?o
00003oooool2o`0000cooooo3?l00005ooooo`;o00002_ooool4o`0000Cooooo0_l000000ooooooo
0000o`000004ooooo`?o00003?ooool2o`0000Oooooo0_l00004ooooo`;o00000_ooool2o`0000Ko
oooo0ol0000Gooooo`;o00000_ooool3o`0000Oooooo0_l0000booooo`007?ooool00ol0003ooooo
ooooo`0iooooo`So00001Oooool3o`0000gooooo0_l00004oooooaco00003oooool2o`0000Sooooo
0_l00002ooooo`Ko00001?ooool2o`0000Kooooo0_l00002ooooo`;o00001Oooool4o`00013ooooo
0ol00004ooooo`;o00000_ooool2o`0000kooooo0_l00002ooooo`;o00001oooool2o`0000Cooooo
0_l0000Cooooo`Co0000??ooool001cooooo00?o0000ooooooooool0>Oooool2o`0000Kooooo0_l0
0002ooooo`Co00002_ooool2o`000003ooooool0003o000000;o00000_oooolIo`0001;ooooo0_l0
00000ooooooo0000o`000005ooooo`;o00001oooool3o`000004ooooool0003o0000o`0000Cooooo
1?l00002ooooo`;o00006Oooool3o`0000Cooooo0_l00002ooooo`;o00001_ooool2o`0000Wooooo
0_l0000>ooooo`?o00003_ooool2o`0000;ooooo0_l0000nooooo`007?ooool00ol0003ooooooooo
o`0iooooo`;o00001_ooool7o`0000_ooooo0ol00002ooooo`;o00000_oooolFo`000004ooooool0
003o0000o`0000kooooo0_l000001?oooooo0000o`000?ooool2o`0000Kooooo0_l00005ooooo`Wo
00000_ooool5o`0000kooooo0_l0000Pooooo`;o00002?ooool3o`0000Sooooo0_l00004ooooo`?o
00002_ooool2o`0000;ooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`0iooooo`;o0000
2?ooool3o`000003ooooool0003o000000?ooooo0_l00006ooooo`Co00001?oooolJo`0000kooooo
0_l000000ooooooo0000o`000004ooooo`;o00000oooool2o`0000Gooooo0_l000001Ooooooo0000
o`000?l0003ooooo00;o00000_ooool2o`000003ooooool0003o000000Gooooo0_l00002ooooo`;o
00000oooool2o`0000Sooooo0_l0000Oooooo`?o00001_ooool5o`000004ooooool0003o0000oooo
o`;o00002oooool2o`0004Kooooo000Looooo`03o`000?oooooooooo03oooooo0_l00002ooooo`;o
00000_ooool2o`0000?ooooo0_l00008ooooo`;o00001?oooolJo`0001Oooooo0_l0000:ooooo`;o
00000_ooool2o`0000Gooooo0_l00003ooooo`;o00000oooool2o`0000;ooooo0_l0000=ooooo`;o
00005_ooool2o`0000Oooooo0ol00006ooooo`Co00000_ooool2o`000004ooooool0003o0000oooo
o`;o00001?ooool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o0000?Oooool001co
oooo00?o0000ooooooooool0?oooool2o`0000;ooooo1_l00002ooooo`;o00002_ooool2o`0000?o
oooo6Ol0000?ooooo`?o00001?ooool2o`0000oooooo0_l00006ooooo`;o00000oooool2o`0000Oo
oooo0_l00004ooooo`;o00001oooool2o`000003ooooool0003o000000?ooooo0_l00009ooooo`;o
00000oooool3o`0000;ooooo0_l000000ooooooo0000o`00000Dooooo`;o00001?ooool2o`000003
ooooool0003o000000Cooooo0_l00002ooooo`;o000000?oooooo`000?l00000>_ooool001cooooo
00?o0000ooooooooool0@oooool6o`0000;ooooo0_l0000:ooooo`;o00000ooooolIo`0000oooooo
1Ol00002ooooo`;o00003oooool2o`0000Gooooo1?l0000;ooooo`;o00001?ooool4o`0000Gooooo
0_l000001?oooooo0000o`000?l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000;o
oooo0_l00004ooooo`;o00000_ooool2o`000003ooooool0003o0000017ooooo0_l00004ooooo`;o
00001oooool2o`000003ooooool0003o000000;ooooo0_l000001?oooooo0000o`000?l0000ioooo
o`007?ooool00ol0003oooooooooo`0oooooo`;o00000_ooool3o`0000;ooooo0_l000000ooooooo
0000o`00000?ooooo`[o000000Coooooo`000?l0003ooooo2ol00002ooooo`;o00002Oooool2o`00
00?ooooo0_l00002ooooo`;o00004_ooool2o`0000;ooooo1?l000000ooooooo0000o`000002oooo
o`;o00000_ooool2o`0000Cooooo1_l00004ooooo`;o00000oooool2o`0000Kooooo0_l000000ooo
oooo0000o`00000<ooooo`Go00004Oooool2o`0000Cooooo0_l00002ooooo`;o00000oooool2o`00
00Gooooo0_l00002ooooo`;o0000>Oooool001cooooo00?o0000ooooooooool0?oooool2o`0000?o
oooo0_l00002ooooo`;o00001oooool2o`0000?ooooo1?l00002oooooa?o000000?oooooo`000?l0
00000ol00002ooooo`;o00000oooool2o`0000Cooooo0_l00007ooooo`;o00001_ooool2o`0000Go
oooo0_l00003ooooo`;o00001?ooool2o`000003ooooool0003o000000;ooooo1ol00003ooooo`;o
00002?ooool4o`00013ooooo0_l00002ooooo`;o00001?ooool4o`0001cooooo0_l00002ooooo`?o
0000A?ooool001cooooo00?o0000ooooooooool0:_ooool2o`0001Sooooo0_l0000;ooooo`;o0000
0oooool4o`0000;ooooo0_l000000ooooooo0000o`00000Bo`0000Wooooo0_l0000=ooooo`?o0000
1Oooool2o`0000Gooooo0_l00009ooooo`;o00001Oooool4o`000004ooooool0003o0000ooooo`;o
00003?ooool2o`00013ooooo1_l0000@ooooo`;o00001_ooool2o`0000_ooooo0_l000000ooooooo
0000o`000015ooooo`007?ooool00ol0003oooooooooo`0Zooooo`;o00005Oooool2o`000003oooo
ool0003o000000;o00002?ooool2o`0000[ooooo5ol00003ooooo`;o00003_ooool2o`0000Cooooo
0_l00004ooooo`;o00005?ooool3o`0000Wooooo0_l0000Pooooo`;o00004_ooool2o`0000;ooooo
0ol000000ooooooo0000o`000003ooooo`;o00001_ooool2o`0001Kooooo0_l00009ooooo`;o0000
9Oooool001cooooo00?o0000ooooooooool09Oooool2o`0000Kooooo0_l0000@ooooo`Co000000?o
ooooo`000?l000000_l00003ooooo`;o00000oooool4o`0000Oooooo0_l000000ooooooo0000o`00
000Ao`0000Gooooo0_l0000>ooooo`Co00000_ooool4o`0000;ooooo0_l0000Dooooo`Go000000?o
ooooo`000?l000001?ooool2o`0002;ooooo0_l00002ooooo`;o00004?ooool4o`0000Gooooo0_l0
0007ooooo`;o00005Oooool2o`0000Wooooo0_l0000Uooooo`007?ooool2o`0002Kooooo0_l00006
ooooo`;o00004?ooool2o`0000[ooooo0_l00005ooooo`;o00001oooool2o`000003ooooool0003o
000000;o000000?oooooo`000?l000002_l0000Booooo`;o00001Oooool2o`0000;ooooo1?l0000:
ooooo`;o000000?oooooo`000?l000002_ooool4o`000003ooooool0003o000000;ooooo0_l0000K
ooooo`;o00001oooool2o`0000;ooooo0_l0000Booooo`Co00000_ooool6o`0000;ooooo1?l0000;
ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0=oooool2o`0000Wooooo0_l000000ooo
oooo0000o`00000=ooooo`;o00001_ooool2o`0000?ooooo0_l000000ooooooo0000o`000006o`00
0003ooooool0003o000001;ooooo0_l0000@ooooo`;o00001Oooool2o`000003ooooool0003o0000
00;o00002?ooool4o`0000Gooooo0_l0000Kooooo`?o00006?ooool2o`0000Kooooo0_l00002oooo
o`Ko00000_ooool4o`0000Sooooo0_l000000ooooooo0000o`00000jooooo`007?ooool00ol0003o
ooooooooo`0Uooooo`;o00004?ooool2o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l0
00001_ooool2o`0000Cooooo0ol00003ooooo`Go00000oooool2o`000003ooooool0003o000000;o
oooo1Ol0000Dooooo`;o00002Oooool2o`0000Gooooo0_l0000:ooooo`?o00002Oooool4o`0000Oo
oooo0_l0000:ooooo`;o00003?ooool2o`0000;ooooo0_l0000Dooooo`;o00002_ooool8o`0000;o
oooo0_l00006ooooo`Co0000?Oooool001cooooo00?o0000ooooooooool09Oooool2o`0001Cooooo
0_l00008ooooo`;o00001?ooool4o`0000Cooooo1?l00002ooooo`Co00001?ooool2o`000003oooo
ool0003o000000Gooooo1?l00004ooooo`;o00002oooool3o`0000Wooooo0_l00003ooooo`;o0000
3Oooool4o`0000Wooooo0ol00005ooooo`?o00002_ooool2o`0000cooooo0_l00002ooooo`;o0000
0_ooool2o`0001Cooooo0_l00006ooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`;o0000
?oooool001cooooo00?o0000ooooooooool0;_ooool2o`00017ooooo0_l00002ooooo`Co000000Co
ooooo`000?l0003o00002?ooool2o`0000[ooooo0_l000001?oooooo0000o`000?l00006ooooo`;o
00001?ooool3o`0000Oooooo0_l000000ooooooo0000o`000003ooooo`;o00000oooool2o`0000Go
oooo0_l0000?ooooo`;o00002Oooool3o`0000Gooooo0ol0000Hooooo`;o00001_ooool2o`0000Go
oooo0_l00003ooooo`Co00001_ooool2o`0000_ooooo0_l00004ooooo`?o00001?ooool2o`0003oo
oooo000Looooo`03o`000?oooooooooo02kooooo0_l0000;ooooo`;o00001?ooool2o`0000Cooooo
0_l000000ooooooo0000o`00000@ooooo`;o00000oooool2o`0000;ooooo0ol0000<ooooo`;o0000
1?ooool2o`000004ooooool0003o0000o`0000Gooooo0_l00003ooooo`;o00008oooool2o`0000Go
oooo0_l00003ooooo`;o000000?oooooo`000?l000000_l00008ooooo`;o00003_ooool2o`0000?o
oooo0_l00003ooooo`So00001?ooool2o`0000;ooooo0_l00005ooooo`Go000000?oooooo`000?l0
00001Oooool2o`0003oooooo000Looooo`03o`000?oooooooooo02kooooo0_l00008ooooo`;o0000
00?oooooo`000?l000000oooool3o`0000;ooooo0_l0000<ooooo`;o000000?oooooo`000?l00000
1?ooool2o`0000Sooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l00008ooooo`?o0000
00?oooooo`000?l000006_ooool2o`0000_ooooo0_l000000ooooooo0000o`000003ooooo`;o0000
00?oooooo`000?l000000_ooool3o`0000;ooooo0_l000000ooooooo0000o`000002o`0000Sooooo
0_l0000>ooooo`Co00001?ooool2o`000004ooooool0003o0000ooooo`Co00001?ooool6o`0000Go
oooo1Ol000000ooooooo0000o`000005ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0
9?ooool2o`0000Sooooo0_l00008ooooo`;o00001_ooool2o`0000?ooooo0_l0000<ooooo`;o0000
00?oooooo`000?l000004Oooool4o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`;o0000
1Oooool2o`0001Cooooo1?l00005ooooo`;o00001?ooool2o`000003ooooool0003o000000Cooooo
1?l000000ooooooo0000o`000002o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0001Wo
oooo1?l000001?oooooo0000o`000?l00002ooooo`;o00000oooool2o`0000Gooooo0_l00007oooo
o`;o00000oooool3o`0004Kooooo000Looooo`03o`000?oooooooooo02Cooooo0_l0000Oooooo`;o
00006Oooool2o`0000Oooooo0_l00008ooooo`;o00001oooool2o`0000Cooooo0_l0000Dooooo`;o
00000_ooool2o`0000?ooooo0_l00005ooooo`;o00001_ooool2o`000003ooooool0003o000000[o
00000_ooool3o`0001[ooooo0_l000000ooooooo0000o`000003ooooo`Co000000?oooooo`000?l0
00000_l00003ooooo`Co00001Oooool3o`0000;ooooo0_l00002ooooo`?o0000@_ooool001cooooo
00?o0000ooooooooool0??ooool2o`0000Oooooo0ol0000@ooooo`;o00001_ooool2o`0000;ooooo
0_l00009ooooo`;o00000oooool2o`0000Gooooo0ol0000Nooooo`;o00002_ooool2o`0000Wooooo
0ol00003ooooo`_o00001?ooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool3o`000003oooo
ool0003o000000?ooooo0ol00003ooooo`Co000000?oooooo`000?l000000_l00006ooooo`;o0000
1_ooool5o`00043ooooo000Looooo`03o`000?oooooooooo03cooooo0ol00003ooooo`;o00000_oo
ool2o`0000;ooooo0_l0000<ooooo`;o00002_ooool2o`0000Kooooo0_l000000ooooooo0000o`00
0003ooooo`;o00001Oooool3o`0001Cooooo0_l0000@ooooo`;o00000_ooool4o`000003ooooool0
003o000000Gooooo0ol00003ooooo`;o000000?oooooo`000?l000001?l00005ooooo`;o00001_oo
ool2o`0000?ooooo1Ol00004ooooo`?o000000?oooooo`000?l000001Oooool2o`000003ooooool0
003o000000?o00002oooool2o`0000Kooooo0_l000001?oooooo0000o`000?ooool3o`0003cooooo
000Looooo`03o`000?oooooooooo02gooooo0_l0000>ooooo`;o00000_ooool5o`0000Cooooo0_l0
000Hooooo`Go00000oooool2o`0001[ooooo0_l00008ooooo`;o00001oooool2o`0000Oooooo0_l0
0002ooooo`Co000000?oooooo`000?l000001_ooool2o`0000Wooooo1Ol00003ooooo`Co00001Ooo
ool2o`0000;ooooo0_l000000ooooooo0000o`000007ooooo`;o00001_ooool2o`000003ooooool0
003o000000;o00006_ooool3o`0000;ooooo0_l0000<ooooo`;o0000:_ooool001cooooo00?o0000
ooooooooool0;Oooool2o`0001;ooooo0_l000000ooooooo0000o`000004ooooo`;o00004oooool2
o`0000?ooooo1Ol00004ooooo`;o00006Oooool2o`0000kooooo0_l000000ooooooo0000o`000005
ooooo`;o00003oooool2o`0000Cooooo0_l00006ooooo`Co00000oooool4o`000003ooooool0003o
000000;ooooo0_l0000>ooooo`;o00002_ooool2o`0000Cooooo0_l0000Booooo`;o00001_ooool2
o`0000cooooo0_l0000Zooooo`007?ooool00ol0003oooooooooo`11ooooo`;o000000?oooooo`00
0?l000000_l00002ooooo`;o00002_ooool2o`0000Oooooo0ol000000ooooooo0000o`000008oooo
o`;o00002_ooool2o`0001cooooo0ol00006ooooo`Co00001?ooool2o`0000Wooooo0_l00004oooo
o`Co000000?oooooo`000?l000000ol0000:ooooo`;o00004_ooool2o`0000Gooooo1?l000000ooo
oooo0000o`000002ooooo`Co00004_ooool2o`00043ooooo00001_ooooook^k^oc8b<_l0003o<S8b
onk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003ooooooooo
o`10ooooo`?o000000?oooooo`000?l000000_l0000>ooooo`;o00002?ooool2o`000004ooooool0
003o0000o`0000Gooooo0_l0000<ooooo`;o00001Oooool2o`0001Cooooo0ol00007ooooo`;o0000
1_ooool2o`0000Gooooo0_l00006ooooo`Ko000000?oooooo`000?l000000_l00004ooooo`;o0000
3oooool2o`0000;ooooo0_l0000:ooooo`Go00001Oooool2o`0000;ooooo0_l0000Dooooo`;o0000
??ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMgMooo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo043ooooo1_l0000>ooooo`;o00003?ooool4o`00
00Gooooo0_l0000@ooooo`;o000000?oooooo`000?l000005?ooool2o`00013ooooo1Ol00002oooo
o`;o00001_ooool2o`000005ooooool0003o0000o`000?ooool00_l00006ooooo`;o000000?ooooo
o`000?l000002?ooool2o`0000;ooooo0_l00002ooooo`;o00002_ooool6o`0000Sooooo0_l00004
ooooo`;o00003_ooool3o`0003_ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo
00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo047ooooo0ol0000@
ooooo`?o00002oooool2o`0000cooooo0_l0000;ooooo`;o0000:Oooool5o`0000gooooo0_l00006
ooooo`;o00000oooool4o`0000;ooooo0ol00003ooooo`;o00004?ooool8o`0000Sooooo0_l00004
ooooo`;o00002oooool2o`0000;ooooo1?l0000iooooo`0000?oooooo`000?ooool00_ooool00ol0
003oooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0003oooooo1?l00000
0ooooooo0000o`00000=ooooo`Co00002oooool2o`0000cooooo0_l0000_ooooo`;o00001oooool2
o`0001Kooooo0_l00002ooooo`?o00000oooool4o`0000?ooooo0_l00004ooooo`;o00002_ooool5
o`0000Kooooo0_l00002ooooo`;o00001Oooool2o`0000_ooooo0_l00003ooooo`?o0000>Oooool0
0003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oEEEEo`000?l@413o
c<c<00Kooooo00?o0000ooooooooool0?oooool4o`000004ooooool0003o0000ooooo`;o00002_oo
ool2o`0000;ooooo0_l0000Wooooo`;o00007Oooool4o`0000?ooooo0ol0000Aooooo`Co00002?oo
ool2o`000004ooooool0003o0000ooooo`;o00002oooool2o`0000Cooooo1?l0000=ooooo`Ko0000
1Oooool2o`0000gooooo0_l000001?oooooo0000o`000?l0000iooooo`0000?ooooooa0@4?ooool0
0_ooool00ol@413oooooooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0
@Oooool2o`0000Cooooo0_l00004ooooo`;o00002?ooool2o`0001Kooooo0_l0000?ooooo`;o0000
6Oooool8o`0000?ooooo0ol0000Aooooo`Go00001oooool2o`000003ooooool0003o000000Oooooo
0_l00005ooooo`;o00001?ooool5o`0000kooooo0_l000000ooooooo0000o`000004ooooo`;o0000
3Oooool2o`0003gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nH
V9P02?ooool00ol0003oooooooooo`15ooooo`;o00001_ooool2o`0001?ooooo0_l0000;ooooo`;o
00006_ooool2o`0000Sooooo1?l000000ooooooo0000o`000005o`0000Oooooo0_l000000ooooooo
0000o`00000>ooooo`Co00003_ooool4o`000003ooooool0003o000000Gooooo0_l00007ooooo`;o
00004?ooool3o`0005;ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4
A?l0003o410@1_ooool00ol0003oooooooooo`13ooooo`Co000000Coooooo`000?l0003o00000_oo
ool2o`0001?ooooo0_l0000Dooooo`;o00004Oooool4o`0000Kooooo2_l00004ooooo`;o00000ooo
ool2o`000003ooooool0003o000000kooooo0_l0000@ooooo`Co00000_ooool2o`0000Cooooo0_l0
000;ooooo`;o00002?ooool2o`0000;ooooo0ol00007ooooo`;o0000BOooool001cooooo00?o0000
ooooooooool0>oooool2o`0000Kooooo0_l00003ooooo`?o00003_ooool2o`0001Sooooo0_l00002
ooooo`?o00001_ooool2o`0000_ooooo0_l000000ooooooo0000o`000003ooooo`;o000000?ooooo
o`000?l000001Ol00002ooooo`Ko0000;?ooool2o`00017ooooo0_l00008ooooo`;o00003?ooool2
o`0000_ooooo0ol0000kooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00001_ooool2o`00
01Gooooo0_l00005ooooo`?o00003?ooool2o`0000Wooooo0_l00002ooooo`;o000000?oooooo`00
0?l000000_l00002ooooo`;o00001Oooool2o`0000Oooooo0_l00006ooooo`Oo00000_ooool7o`00
00oooooo0_l00007ooooo`;o00004Oooool2o`0000_ooooo0_l00003ooooo`?o000000?oooooo`00
0?l000000_ooool2o`0000;ooooo0_l00005ooooo`;o00004Oooool3o`0003_ooooo000Looooo`03
o`000?oooooooooo03?ooooo0_l0000<ooooo`;o00002?ooool4o`0000?ooooo0_l00006ooooo`;o
00001?ooool2o`0000Gooooo0ol00004ooooo`;o00002_ooool5o`0000Sooooo0_l0000;oooooaKo
000000?oooooo`000?l000002_ooool2o`0000Oooooo0_l0000?ooooo`Co00002oooool2o`000003
ooooool0003o000000;o00000_ooool6o`000004ooooool0003o0000o`0000Gooooo0_l000000ooo
oooo0000o`000006ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0@Oooool2o`0000So
oooo1?l0000Aooooo`;o00000oooool4o`0000Gooooo0_l00004ooooo`;o00001oooool2o`0001Go
oooo6Ol0000Tooooo`;o00003Oooool5o`0000Kooooo0_l00003ooooo`;o00001Oooool2o`0000;o
oooo0_l00005ooooo`?o000000?oooooo`000?l000000_l0000oooooo`007?ooool00ol0003ooooo
ooooo`11ooooo`;o00002_ooool4o`0000kooooo0_l00004ooooo`;o00000_ooool4o`0000Oooooo
0_l0000Looooo`So000000?oooooo`000?l000004Ol00006ooooo`;o00001oooool2o`0000Wooooo
0ol00002ooooo`;o00003_ooool2o`0000?ooooo0_l00002ooooo`;o00003?ooool5o`0000Sooooo
0ol00002ooooo`Co0000?oooool001cooooo00?o0000ooooooooool0=?ooool2o`0001Wooooo0_l0
0002ooooo`;o00002_ooool2o`000003ooooool0003o000000Gooooo1?l0000SoooooaWo00000_oo
ool3o`0000Kooooo1?l00005ooooo`;o00002Oooool3o`0000;ooooo1?l00005ooooo`;o00001Ooo
ool2o`0000Cooooo1Ol0000<ooooo`Go000000?oooooo`000?l000001Oooool2o`0000;ooooo0_l0
00000ooooooo0000o`00000oooooo`007?ooool00ol0003oooooooooo`0dooooo`;o00005oooool4
o`0000;ooooo0_l0000=ooooo`;o00001Oooool2o`0002Gooooo7_l00007ooooo`?o00005oooool2
o`0000Gooooo0_l00004ooooo`;o00001Oooool3o`0000Wooooo0_l00002ooooo`;o00001Oooool2
o`0000Wooooo0_l0000=ooooo`;o0000<oooool001cooooo00?o0000ooooooooool0@_ooool2o`00
00Kooooo0_l000000ooooooo0000o`00000eooooo`;o00002ooooolMo`0000Oooooo1?l0000;oooo
o`;o00001_ooool2o`0000Sooooo0_l00004ooooo`;o00004?ooool3o`000004ooooool0003o0000
o`00017ooooo0_l0000<ooooo`;o0000<oooool001cooooo00?o0000ooooooooool0@_ooool2o`00
00Cooooo1_l0000Eooooo`;o00004?ooool2o`0000gooooo1?l00009ooooo`go00000_oooolAo`00
00Kooooo0_l0000;ooooo`;o00001_ooool2o`0001Wooooo0ol00004ooooo`;o00000_ooool2o`00
01;ooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00003Oooool4o`0000;o
oooo0_l0000:ooooo`?o00002?ooool2o`0000?ooooo0_l0000;ooooo`;o00003oooool2o`0000Wo
oooo8?l000001?oooooo0000o`000?ooool2o`0000kooooo1?l0000:ooooo`;o00001_ooool2o`00
0003ooooool0003o000000;ooooo0ol00002ooooo`?o00005?ooool2o`0000Cooooo0_l00013oooo
o`007?ooool00ol0003oooooooooo`0gooooo`;o00002Oooool2o`0000;ooooo0_l0000?ooooo`Co
00003Oooool2o`0000Oooooo0_l000000ooooooo0000o`00000@ooooo`?o00001_oooolNo`0000;o
oooo0_l000000ooooooo0000o`000003o`0000Oooooo0_l00004ooooo`Go00002_ooool2o`0000Go
oooo0ol000001?oooooo0000o`000?ooool4o`000003ooooool0003o000000oooooo0_l00003oooo
o`Co00001?ooool3o`0004;ooooo000Looooo`;o0000??ooool2o`0000Gooooo0_l0000=ooooo`;o
00000_ooool5o`0000Cooooo0_l0000Aooooo`;o000000?oooooo`000?l000001?ooool2o`0000Oo
oooo0_l000001?oooooo0000o`000?l00006oooooako00001oooool4o`0000Cooooo2_l000000ooo
oooo0000o`000003o`0000kooooo0_l00005ooooo`;o00000oooool2o`0000oooooo0ol00002oooo
o`?o00001_ooool2o`0004;ooooo000Looooo`03o`000?oooooooooo03_ooooo0_l00006ooooo`;o
00003?ooool2o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l0
00003?ooool2o`0000?ooooo1?l00002ooooo`;o00001oooool2o`0000Oooooo0_l000000ooooooo
0000o`00000Mo`0000;ooooo0_l00004ooooo`;o00000ooooolAo`0001Gooooo0_l000001?oooooo
0000o`000?l00008ooooo`Co00001Oooool2o`0000?ooooo0_l0001:ooooo`007?ooool00ol0003o
ooooooooo`11ooooo`Co00001_ooool2o`0001?ooooo0ol0000<ooooo`;o00001Oooool2o`00017o
oooo9Ol00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l000000ooooooo
0000o`00000?o`0000cooooo1?l00005ooooo`?o00002?ooool6o`0000gooooo0_l00015ooooo`00
7?ooool00ol0003oooooooooo`11ooooo`;o00002?ooool2o`0000Kooooo0_l00006ooooo`?o0000
0_ooool2o`0001Wooooo1_l00008ooooo`?o00000_oooolOo`0000?ooooo1Ol00002ooooo`;o0000
0_oooolFo`0000[ooooo1?l00007ooooo`;o00002oooool2o`0000?ooooo0_l00008ooooo`;o0000
AOooool001cooooo00?o0000ooooooooool0Doooool4o`0000Cooooo1?l0000<ooooo`Co00003?oo
ool8o`0000?ooooo0_l00007ooooo`;o000000?oooooo`000?l000005ol00006ooooo`?o00002?oo
oolHo`0000;ooooo0_l00008ooooo`;o00001?ooool3o`0000[ooooo0_l00003ooooo`;o0000Cooo
ool001cooooo00?o0000ooooooooool0B_ooool4o`0000Kooooo0ol00006ooooo`;o00002Oooool7
o`0000;ooooo0_l00007ooooo`[o00000_ooool2o`0000Oooooo0_l000000ooooooo0000o`00000G
o`0000Kooooo0ol00007oooooa[o000000?oooooo`000?l000000_l00006ooooo`;o00001Oooool3
o`0005oooooo000Looooo`03o`000?oooooooooo03gooooo0_l0000;ooooo`Co00001_ooool2o`00
0003ooooool0003o000000oooooo1?l00005ooooo`?o00001?ooool>o`0000Kooooo0_l000000ooo
oooo0000o`000002o`000003ooooool0003o000001Go00001_ooool4o`0000Kooooo6_l00002oooo
o`?o00001Oooool2o`0000Gooooo1?l0001Oooooo`007?ooool00ol0003oooooooooo`0mooooo`;o
00004oooool2o`0000?ooooo0_l0000IoooooaCo000000?oooooo`000?l000000ooooolOo`0000Oo
oooo1?l00007oooooaSo00000_ooool2o`0000Kooooo1_l000000ooooooo0000o`000009ooooo`;o
000000?oooooo`000?l00000Doooool001cooooo00?o0000ooooooooool0A_ooool2o`0000Cooooo
0ol00003ooooo`;o00000oooool2o`0001Gooooo0_l00004ooooo`[o000000?oooooo`000?l00000
2?l000000ooooooo0000o`00000Oo`0000Cooooo0_l00003ooooo`?o00001_oooolIo`000003oooo
ool0003o000000Oooooo1Ol000001?oooooo0000o`000?ooool2o`0000Kooooo1Ol0000@ooooo`;o
0000@Oooool001cooooo00?o0000ooooooooool0A_ooool2o`0000Cooooo0ol00002ooooo`;o0000
6?ooool2o`000003ooooool0003o000000Oooooo1?l000000ooooooo0000o`000009o`0000?ooooo
0_l00004oooooaGo000000?oooooo`000?l000000ol000001?oooooo0000o`000?ooool3o`0000?o
oooo0_l00006ooooo`;o000000?oooooo`000?l000005?l0000@ooooo`;o000000?oooooo`000?l0
00001?ooool2o`0000;ooooo0ol000000ooooooo0000o`000004ooooo`;o00001oooool2o`00047o
oooo000Looooo`03o`000?oooooooooo057ooooo0_l00005ooooo`;o00000_ooool4o`0000_ooooo
0_l00009ooooo`oo00001Oooool2o`000003ooooool0003o000000Wo000000?oooooo`000?l00000
3Ol000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00002ooooo`;o00002_oooolDo`0001_o
oooo0_l00006ooooo`;o00001?ooool2o`0000[ooooo0_l0000nooooo`007?ooool00ol0003ooooo
ooooo`1Hooooo`?o000000?oooooo`000?l000000_l0000:ooooo`?o00002Oooool?o`0000Sooooo
6_l00002ooooo`;o00002Oooool2o`0000[ooooo1_l00003ooooo`go00004oooool2o`0000;ooooo
0_l0000>ooooo`;o00002_ooool2o`0003kooooo000Looooo`03o`000?oooooooooo03kooooo0_l0
000?ooooo`;o00000oooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o00001_oo
ool4o`0000[ooooo3ol00005ooooo`;o000000?oooooo`000?l000001?l000000ooooooo0000o`00
000:o`0000?ooooo0ol00004ooooo`;o00004OoooolIo`000003ooooool0003o000000Wooooo0_l0
0005ooooo`;o00000_ooool2o`0000kooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`0n
ooooo`;o00001_ooool2o`0000Oooooo0ol000001?oooooo0000o`000?l00003ooooo`;o000000?o
ooooo`000?l000001?l000000ooooooo0000o`000003ooooo`?o00002OoooolAo`0000Gooooo0_l0
00000ooooooo0000o`00000Ao`0000Cooooo0_l00004ooooo`?o00002_ooool2o`0000Cooooo5Ol0
00001Ooooooo0000o`000?l0003ooooo00?o00000oooool2o`0000?ooooo0_l0001Uooooo`007?oo
ool00ol0003oooooooooo`16ooooo`Co00001_ooool2o`000004ooooool0003o0000o`0000Kooooo
1?l00003ooooo`;o00003oooool?o`000003ooooool0003o000000Cooooo0_l00002ooooo`Wo0000
0_ooool5o`0000cooooo0ol0000:ooooo`;o00001ooooolCo`0000Gooooo1?l000000ooooooo0000
o`000003ooooo`;o0000IOooool001cooooo00?o0000ooooooooool0B?ooool2o`0000Kooooo0_l0
000Looooo`;o00001_ooool;o`0000;ooooo0ol00004ooooo`;o00000_ooool9o`0000;ooooo0_l0
000?ooooo`;o00000oooool2o`00017ooooo5ol000000ooooooo0000o`000006ooooo`?o00006ooo
ool2o`0004Oooooo000Looooo`;o0000>?ooool2o`0000_ooooo0_l00009ooooo`?o00000oooool3
o`0000Cooooo0_l00007ooooo`;o00000oooool2o`0000;ooooo0_l00009ooooo`Wo000000?ooooo
o`000?l000003?ooool2o`0000;ooooo0_l00002ooooo`;o00003_ooool2o`0000Cooooo0_l0000A
oooooaOo00002_ooool2o`0000Wooooo0_l00004ooooo`;o00000_ooool2o`0000Kooooo0_l00017
ooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00002oooool2o`0000Wooooo0ol00003oooo
o`?o00001?ooool2o`0000Oooooo0_l00002ooooo`?o00000oooool2o`0000Wooooo0_l00004oooo
o`;o000000?oooooo`000?l000000_l00003ooooo`;o00001?ooool2o`0000cooooo0_l00003oooo
o`;o00001?ooool2o`000003ooooool0003o000000kooooo0_l00002ooooo`;o00000ooooolCo`00
01Kooooo1?l00002ooooo`;o00000_ooool2o`0004oooooo000Looooo`03o`000?oooooooooo05;o
oooo0_l00002ooooo`;o00003Oooool2o`0000;ooooo0_l00004ooooo`Co000000?oooooo`000?l0
00001Oooool4o`0000Cooooo1?l00003ooooo`;o000000Coooooo`000?l0003ooooo0ol0000;oooo
o`;o00000oooool3o`0000Kooooo0_l00008ooooo`;o00001?ooool2o`0000;ooooo0_l00003oooo
o`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000003o`0000Cooooo1Ol0000Eoooo
o`;o0000Eoooool001cooooo00?o0000ooooooooool0C_ooool2o`0000;ooooo0_l000000ooooooo
0000o`000003ooooo`;o00003Oooool2o`0000Gooooo0ol000000ooooooo0000o`000005ooooo`Ko
00000_ooool2o`0000Sooooo0_l00002ooooo`;o00000_ooool2o`0000Oooooo0_l00004ooooo`;o
00004?ooool2o`0000gooooo0_l000001?oooooo0000o`000?l00002ooooo`;o000000?oooooo`00
0?l000001_ooool3o`0006kooooo000Looooo`03o`000?oooooooooo04kooooo0_l00005ooooo`;o
00000oooool2o`0000Sooooo0_l00003ooooo`?o00003?ooool2o`0000Gooooo0_l000000ooooooo
0000o`000002o`0000;ooooo0_l0000;ooooo`;o00001oooool2o`0001Sooooo0_l0000>ooooo`?o
00001Oooool2o`0000?ooooo0ol0000Hooooo`;o0000Eoooool001cooooo00?o0000ooooooooool0
B?ooool2o`0000_ooooo0_l0000=ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o
00002?ooool2o`0000Oooooo1Ol00002ooooo`;o00000_ooool2o`0002[ooooo0_l00002ooooo`;o
00002_ooool2o`0000Kooooo0_l000000ooooooo0000o`000003o`0000kooooo0_l00006ooooo`Co
0000Eoooool001cooooo00?o0000ooooooooool0B?ooool2o`0000_ooooo0_l0000=ooooo`;o0000
00?oooooo`000?l000001Oooool2o`0000;ooooo0_l0000;ooooo`Co00002Oooool2o`0001Wooooo
0_l0000:ooooo`;o000000?oooooo`000?l000001?ooool4o`0000Sooooo0_l000001?oooooo0000
o`000?ooool2o`0000?ooooo0_l0000>ooooo`;o000000?oooooo`000?l000001Oooool5o`0005Oo
oooo000Looooo`03o`000?oooooooooo05Wooooo0_l00009ooooo`;o00003?ooool2o`000003oooo
ool0003o000000;ooooo0_l00004ooooo`Co00009?ooool2o`0000;ooooo0_l00006ooooo`;o0000
00?oooooo`000?l000001_ooool2o`0000Sooooo0_l000001?oooooo0000o`000?ooool2o`0000Go
oooo0_l0000<ooooo`;o00002?ooool2o`000003ooooool0003o000005Oooooo000Looooo`03o`00
0?oooooooooo05Cooooo0_l00003ooooo`;o00000oooool2o`0001?ooooo1?l00002ooooo`;o0000
00?oooooo`000?l000000oooool2o`0002Sooooo0_l0000Cooooo`?o00004_ooool2o`0000kooooo
0_l0000>ooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0DOooool5o`0000Sooooo0_l0
000Cooooo`;o00000_ooool2o`0000?ooooo0_l0000Eooooo`Co00002Oooool2o`0001kooooo0ol0
000Hooooo`;o00002?ooool2o`0000Oooooo0_l00005ooooo`;o0000D_ooool001cooooo00?o0000
ooooooooool0DOooool4o`0002;ooooo1?l000000ooooooo0000o`00000:ooooo`;o00002Oooool4
o`0000Wooooo0_l000000ooooooo0000o`00000?ooooo`;o00009Oooool2o`00017ooooo0_l00009
ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0D_ooool2o`0001_ooooo0_l00007oooo
o`?o00003?ooool3o`0000?ooooo0_l0000=ooooo`;o00001Oooool2o`0000oooooo0_l0000;oooo
o`?o00003oooool2o`0000Gooooo0_l00004ooooo`;o00001?ooool2o`00017ooooo0_l0001>oooo
o`007?ooool00ol0003oooooooooo`13ooooo`;o00005oooool2o`00017ooooo0_l00005ooooo`;o
00003oooool2o`0000Cooooo0_l0000<ooooo`?o00001?ooool2o`0000cooooo0_l00003ooooo`;o
00001?ooool2o`0000Cooooo0ol0000?ooooo`;o00001Oooool2o`0000Cooooo0_l00003ooooo`?o
0000HOooool001cooooo00?o0000ooooooooool0@oooool2o`0001Kooooo1?l0000Gooooo`;o0000
1Oooool2o`0000kooooo0_l0000<ooooo`;o00001Oooool2o`0000cooooo0_l00002ooooo`Co0000
0_ooool3o`0000Kooooo0_l0000Aooooo`;o00003Oooool2o`0000Cooooo0_l0001Looooo`007?oo
ool00ol0003oooooooooo`1Kooooo`Co000000?oooooo`000?l000006_ooool3o`0000Oooooo0_l0
0005ooooo`;o000000?oooooo`000?l000008?ooool6o`0000;ooooo0_l00007ooooo`;o00004Ooo
ool2o`0001?ooooo0_l0001Looooo`007?ooool00ol0003oooooooooo`1Pooooo`;o00006_ooool3
o`0000Oooooo0_l00008ooooo`;o000000?oooooo`000?l000007Oooool2o`0000Cooooo0_l0000C
ooooo`;o00005oooool2o`00067ooooo000Looooo`;o0000Roooool2o`0000;ooooo0_l00003oooo
o`;o00007_ooool2o`0000?ooooo0_l00002ooooo`;o00001Oooool2o`0000Sooooo0_l0000Goooo
o`;o0000HOooool001cooooo00?o0000ooooooooool0Ooooool2o`0000Cooooo0_l00003ooooo`;o
00000_ooool4o`000003ooooool0003o000001kooooo0_l00007ooooo`;o00001Oooool6o`0001co
oooo0_l0001Rooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o000000?oooooo`000?l00000
2oooool2o`0000?ooooo0_l00004ooooo`;o00001?ooool2o`0000;ooooo1?l00003ooooo`;o0000
1?ooool5o`000003ooooool0003o000001Sooooo0_l00003ooooo`;o00000_ooool2o`0000[ooooo
1Ol0000Kooooo`;o0000H_ooool001cooooo00?o0000ooooooooool0G_ooool2o`000003ooooool0
003o000000Gooooo0_l00004ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o00001_oo
ool7o`0000Sooooo1?l00002ooooo`;o00005oooool3o`0000?ooooo0_l00002ooooo`;o00003Ooo
ool2o`0007oooooo000Looooo`03o`000?oooooooooo06?ooooo0_l00003ooooo`;o00000_ooool2
o`0000?ooooo0ol0000=ooooo`Oo00001_ooool2o`0000Gooooo0_l0000Hooooo`Co0000U_ooool0
01cooooo00?o0000ooooooooool0Hoooool2o`0000?ooooo1_l00004ooooo`;o00001_ooool2o`00
00Kooooo0_l00002ooooo`?o00001Oooool2o`0000Cooooo0ol0000=ooooo`;o00002oooool5o`00
01Cooooo0_l00005ooooo`;o00000_ooool2o`0000[ooooo0_l0001Vooooo`007?ooool00ol0003o
ooooooooo`1Sooooo`;o00001Oooool4o`0000;ooooo0_l00008ooooo`;o00000oooool2o`000003
ooooool0003o000000?ooooo0_l0000;ooooo`?o00002_ooool2o`000003ooooool0003o000000[o
oooo0_l000001?oooooo0000o`000?l0000Dooooo`;o00001Oooool2o`0000;ooooo0_l0000:oooo
o`;o0000I_ooool001cooooo00?o0000ooooooooool0GOooool2o`0000_ooooo0_l00003ooooo`?o
00003Oooool2o`000003ooooool0003o000000?ooooo1?l0000:ooooo`Co00002?ooool2o`0000go
oooo0_l0000<ooooo`;o00001Oooool2o`0008;ooooo000Looooo`03o`000?oooooooooo05gooooo
0_l0000;ooooo`;o00000oooool2o`0000oooooo0_l00005ooooo`Co00003?ooool3o`0001Kooooo
0_l0000<ooooo`;o00001Oooool2o`0002;ooooo0_l0001Nooooo`007?ooool00ol0003ooooooooo
o`1Kooooo`;o00003?ooool2o`0000Cooooo1?l00002ooooo`;o00002Oooool2o`0000Kooooo0_l0
0005ooooo`;o00000oooool2o`0000;ooooo0_l00004ooooo`;o0000BOooool2o`0005kooooo000L
ooooo`03o`000?oooooooooo05Wooooo1_l0000:ooooo`;o00001?ooool4o`0000;ooooo0_l0000<
ooooo`;o00000_ooool2o`0000Kooooo0ol00002ooooo`;o00002?ooool2o`0000Wooooo0_l00004
ooooo`;o0000V?ooool001cooooo00?o0000ooooooooool0FOooool2o`0000;ooooo0_l00007oooo
o`;o00002oooool2o`0000kooooo0_l00002ooooo`;o000000?oooooo`000?l000001?ooool2o`00
00?ooooo0_l00006ooooo`;o00002_ooool3o`0000?ooooo0_l0000=ooooo`;o00001Oooool2o`00
00Cooooo1?l0001jooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00004_ooool4o`0000_o
oooo0_l0000Eooooo`;o00002Oooool2o`0000Kooooo1Ol00008ooooo`;o00004_ooool2o`0000Co
oooo0ol00004ooooo`Ko00002_ooool2o`0006cooooo000Looooo`03o`000?oooooooooo053ooooo
0_l0000Booooo`?o00009oooool2o`0000oooooo0ol00007ooooo`;o00002Oooool2o`0000kooooo
0_l00007ooooo`Co00002_ooool2o`0006cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGo
oooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`29oooo
o`;o00000oooool2o`0000Wooooo0_l0000>ooooo`;o00002Oooool2o`0001Oooooo0_l0001joooo
o`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonH
V9So8B4Q00Kooooo00?o0000ooooooooool0MOooool2o`0001;ooooo0_l0000>ooooo`;o00003ooo
ool2o`00023ooooo0_l0001kooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`1eooooo`;o00006?oo
ool2o`0001Wooooo0_l0000Pooooo`?o0000N_ooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool02Oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0001^ooooo`;o00006ooo
ool3o`000003ooooool0003o000001Wooooo0_l0000Qooooo`;o0000N_ooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool02Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o
0000ooooooooool0K_ooool3o`0001[ooooo0ol0000Looooo`;o00000_ooool5o`0002Sooooo0_l0
001/ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[o
oooookZj^_l@41001_ooool00ol0003oooooooooo`1^ooooo`?o00000oooool4o`0003Kooooo1Ol0
000Aooooo`?o00004?ooool2o`0000;ooooo0_l0001/ooooo`0000KoooooogMgMonHV9SooooooiRH
V?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`1Uooooo`;o
00001oooool2o`0000Cooooo1Ol0001;ooooo`?o00004?ooool2o`00073ooooo00001_ooooook^k^
oc8b<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooo
oooo06Gooooo0_l0000>ooooo`Co00008oooool2o`0002Gooooo0_l00024ooooo`007?ooool00ol0
003oooooooooo`1booooo`;o000000?oooooo`000?l000001_ooool2o`0001gooooo0_l00007oooo
o`;o00007?ooool2o`0008Cooooo000Looooo`03o`000?oooooooooo07;ooooo0_l00009ooooo`;o
00005Oooool2o`0000kooooo0ol00002ooooo`;o0000W_ooool001cooooo00?o0000ooooooooool0
L_ooool2o`00023ooooo0_l0000>ooooo`;o00000oooool2o`0009kooooo000Looooo`03o`000?oo
oooooooo06[ooooo0_l0000eooooo`;o0000<_ooool2o`0007;ooooo000Looooo`03o`000?oooooo
oooo06[ooooo0_l00002ooooo`;o0000<Oooool2o`0003;ooooo0_l0001booooo`007?ooool00ol0
003oooooooooo`1/ooooo`Co0000<Oooool2o`000:Kooooo000Looooo`03o`000?oooooooooo05oo
oooo0_l0000;ooooo`;o00001_ooool2o`000=?ooooo000Looooo`03o`000?oooooooooo05oooooo
0_l0000Cooooo`;o00001?ooool2o`0003[ooooo0_l0002Aooooo`007?ooool00ol0003ooooooooo
o`1jooooo`;o00005_ooool2o`0002;ooooo0_l0002Aooooo`007?ooool00ol0003oooooooooo`2?
ooooo`;o000000?oooooo`000?l00000]Oooool001cooooo00?o0000ooooooooool0R?ooool2o`00
00Gooooo0_l0002hooooo`007?ooool2o`0008Wooooo0_l0000`ooooo`;o0000SOooool001cooooo
00?o0000ooooooooool0P?ooool2o`0000?ooooo0_l0000Gooooo`;o00005_ooool2o`0000;ooooo
0_l0002=ooooo`007?ooool00ol0003oooooooooo`20ooooo`;o00000oooool2o`0001Oooooo0_l0
0009ooooo`;o000000?oooooo`000?l000002?ooool2o`0000cooooo0_l00023ooooo`007?ooool0
0ol0003oooooooooo`2Pooooo`Co00001Oooool2o`000003ooooool0003o000001Kooooo0_l00023
ooooo`007?ooool00ol0003oooooooooo`2Pooooo`Co0000YOooool001cooooo00?o0000oooooooo
ool0Zoooool2o`0009cooooo000Looooo`03o`000?oooooooooo0:_ooooo0_l0002Looooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
09Sooooo0_l0002_ooooo`007?ooool00ol0003oooooooooo`2Hooooo`;o0000[oooool001cooooo
0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Booooo`Co000000?o410@ooooooooool0
0oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`?o0000oooooom:
ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?oo
ooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003ooooooooo
o`3ooooooe;ooooo000Booooo`03oeEEEOmVIVKo00000?ooooooE?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00:Gooooo00Co410@o`000?l0003ooooo0_l000000ol@413ooooo
ooooo`0Eooooo`04oa0@4?l0003oA4A4olc<c0Cooooo1Ol00005ooooo`;o000000?o410@oooooooo
ool0S_ooool00:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00002oooool00onHV9So
410@omgMg@03ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`2?oooo
o`00Y_ooool01Ol0003ooooooooooooooooo000001_ooooo00?oQhN7oeEEEOooool00oooool00onH
V9So8B4Qonk^kP04ooooo`Go0000T?ooool00:Kooooo00Go0000ooooooooooooooooo`000009oooo
o`Ko00002Oooool01Oo<c<co8B4Qo`000?mEEEGo000000Gooooo00?oV9RHob4Q8Oo^k^h00oooool0
1?m4A4CogMgMooooool0002Aooooo`00Y_ooool01Ol0003oQhN7oooooonYZJWo000001Sooooo00Go
8B4QohN7QoooooooV9RHo`000006ooooo`03ogMgMomVIVKooooo00;ooooo00CogMgMoeEEEOoooooo
0000TOooool00:Gooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Fooooo`05o`00
0?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03ogMgMoo<c<co0000097o
oooo0033ooooo`05ob4Q8OnHV9SoooooogMgMomEEED00oooool01Ol0003o^[ZjoooooonHV9So410@
00Cooooo00?ok^k^odA4A?l00000TOooool00<?ooooo00Goc<c<oa0@4?l0003o<S8bonk^kP03oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01Oooool00omgMgOo0000ooooo`2@ooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(930) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.46125 .34713 Mdot
.42163 .35893 Mdot
.4675 .67229 Mdot
.57382 .42731 Mdot
.39168 .39926 Mdot
.46605 .63988 Mdot
.33835 .50831 Mdot
.33007 .46217 Mdot
.47664 .65108 Mdot
.59678 .5526 Mdot
.33571 .47471 Mdot
.59988 .38874 Mdot
.31475 .49349 Mdot
.58444 .43809 Mdot
.83063 .62707 Mdot
.66322 .47634 Mdot
.40133 .36618 Mdot
.57569 .70456 Mdot
.56647 .40276 Mdot
.42487 .66234 Mdot
.38249 .36269 Mdot
.57467 .44066 Mdot
.45427 .33456 Mdot
.58455 .43864 Mdot
.59905 .41752 Mdot
.44323 .3476 Mdot
.44641 .3899 Mdot
.59315 .40853 Mdot
.63759 .43579 Mdot
.30451 .47784 Mdot
.68555 .65075 Mdot
.84938 .50758 Mdot
.67124 .44043 Mdot
.33757 .23826 Mdot
.34266 .46293 Mdot
.74502 .37463 Mdot
.50613 .63717 Mdot
.3042 .50169 Mdot
.33465 .46343 Mdot
.33477 .45394 Mdot
.30635 .49029 Mdot
.43636 .34535 Mdot
.30659 .53886 Mdot
.3535 .53517 Mdot
.56772 .48907 Mdot
.30431 .40945 Mdot
.76735 .49975 Mdot
.62569 .47015 Mdot
.42054 .37264 Mdot
.42262 .65912 Mdot
.31778 .26998 Mdot
.29344 .4801 Mdot
.36024 .6661 Mdot
.78266 .25489 Mdot
.3126 .51031 Mdot
.55574 .47499 Mdot
.49651 .6431 Mdot
.57888 .45655 Mdot
.58401 .44406 Mdot
.55736 .35003 Mdot
.62534 .41431 Mdot
.61131 .70961 Mdot
.3893 .32045 Mdot
.46012 .61091 Mdot
.47404 .64173 Mdot
.32897 .4658 Mdot
.40111 .3572 Mdot
.32069 .49808 Mdot
.53846 .44263 Mdot
.48794 .61499 Mdot
.62453 .47067 Mdot
.3214 .47194 Mdot
.44321 .30861 Mdot
.6058 .48251 Mdot
.2108 .55228 Mdot
.72777 .73983 Mdot
.63013 .73105 Mdot
.59086 .33723 Mdot
.67095 .35995 Mdot
.55892 .79228 Mdot
.62244 .43706 Mdot
.43383 .83792 Mdot
.80221 .65958 Mdot
.45997 .35084 Mdot
.58754 .52829 Mdot
.53004 .62998 Mdot
.59439 .48339 Mdot
.46105 .45615 Mdot
.55213 .48515 Mdot
.21308 .47908 Mdot
.48071 .6545 Mdot
.41605 .33735 Mdot
.5756 .4274 Mdot
.65346 .44175 Mdot
.51499 .26005 Mdot
.6096 .40123 Mdot
.57153 .41888 Mdot
.47008 .36611 Mdot
.3477 .4786 Mdot
.64603 .39203 Mdot
.37248 .49784 Mdot
.37586 .64308 Mdot
.56599 .47806 Mdot
.50775 .65204 Mdot
.47325 .35863 Mdot
.58642 .4852 Mdot
.35692 .49266 Mdot
.63816 .45489 Mdot
.34099 .54497 Mdot
.41766 .36156 Mdot
.65407 .4443 Mdot
.57858 .6767 Mdot
.24605 .66436 Mdot
.41578 .33271 Mdot
.3681 .62527 Mdot
.64444 .45289 Mdot
.56537 .44921 Mdot
.42266 .35629 Mdot
.4463 .64221 Mdot
.50642 .51155 Mdot
.42182 .37981 Mdot
.34233 .45565 Mdot
.39575 .36766 Mdot
.61457 .52464 Mdot
.46634 .65362 Mdot
.38283 .65034 Mdot
.38478 .65817 Mdot
.64333 .61341 Mdot
.58826 .4814 Mdot
.30181 .32663 Mdot
.45631 .64076 Mdot
.42102 .34055 Mdot
.3216 .49433 Mdot
.58748 .50343 Mdot
.4144 .32192 Mdot
.33644 .48742 Mdot
.60977 .67835 Mdot
.46662 .70555 Mdot
.42694 .37595 Mdot
.28344 .53847 Mdot
.32204 .45134 Mdot
.34016 .45193 Mdot
.31963 .25141 Mdot
.42575 .36264 Mdot
.58716 .6883 Mdot
.33473 .4941 Mdot
.74603 .6052 Mdot
.54916 .46754 Mdot
.59264 .59243 Mdot
.3224 .79293 Mdot
.29857 .27906 Mdot
.29046 .62506 Mdot
.58679 .71301 Mdot
.34561 .4496 Mdot
.62043 .42334 Mdot
.43707 .3646 Mdot
.4372 .35738 Mdot
.56258 .41827 Mdot
.58629 .41761 Mdot
.61957 .47575 Mdot
.65184 .44291 Mdot
.78732 .52658 Mdot
.63738 .47052 Mdot
.65121 .70333 Mdot
.42368 .32802 Mdot
.61175 .4137 Mdot
.43639 .65125 Mdot
.62689 .49476 Mdot
.31126 .48042 Mdot
.57295 .44919 Mdot
.57445 .42398 Mdot
.65758 .44384 Mdot
.31901 .51652 Mdot
.83229 .4877 Mdot
.29834 .76201 Mdot
.75395 .32487 Mdot
.33829 .6216 Mdot
.48502 .62822 Mdot
.57451 .47494 Mdot
.60102 .69353 Mdot
.70014 .33785 Mdot
.60986 .43992 Mdot
.1654 .43556 Mdot
.56815 .42424 Mdot
.44 .21599 Mdot
.61769 .36568 Mdot
.7524 .31239 Mdot
.57842 .62362 Mdot
.64051 .43449 Mdot
.52822 .23641 Mdot
.59468 .21504 Mdot
.38317 .53062 Mdot
.3068 .49446 Mdot
.43653 .65371 Mdot
.49845 .64933 Mdot
.28674 .48704 Mdot
.66426 .39321 Mdot
.58663 .37617 Mdot
.53139 .41932 Mdot
.37368 .65662 Mdot
.42747 .29815 Mdot
.62721 .71445 Mdot
.47063 .35151 Mdot
.54612 .85945 Mdot
.21988 .44648 Mdot
.30609 .54219 Mdot
.63595 .71611 Mdot
.45716 .6687 Mdot
.37105 .65834 Mdot
.59966 .68803 Mdot
.61733 .4571 Mdot
.4123 .36548 Mdot
.44861 .18679 Mdot
.67855 .39372 Mdot
.45576 .16891 Mdot
.40452 .32288 Mdot
.4973 .51058 Mdot
.32913 .48223 Mdot
.43558 .67312 Mdot
.56275 .44206 Mdot
.60458 .46791 Mdot
.37883 .33173 Mdot
.62321 .46899 Mdot
.37106 .36628 Mdot
.56015 .43194 Mdot
.46874 .68423 Mdot
.62707 .73363 Mdot
.2861 .49018 Mdot
.63203 .6139 Mdot
.44802 .31862 Mdot
.55182 .64751 Mdot
.44498 .63189 Mdot
.71439 .36039 Mdot
.32673 .47067 Mdot
.58525 .67349 Mdot
.44777 .6319 Mdot
.62345 .7195 Mdot
.63263 .48797 Mdot
.50528 .63071 Mdot
.59039 .70899 Mdot
.81101 .52021 Mdot
.58015 .49834 Mdot
.78748 .56527 Mdot
.34211 .50462 Mdot
.39418 .36528 Mdot
.61991 .41186 Mdot
.39242 .64459 Mdot
.66511 .4347 Mdot
.25126 .57059 Mdot
.37355 .66649 Mdot
.35169 .66411 Mdot
.5968 .78025 Mdot
.57909 .6814 Mdot
.25539 .61983 Mdot
.29006 .32096 Mdot
.40251 .36592 Mdot
.55138 .44855 Mdot
.79235 .37383 Mdot
.33419 .49357 Mdot
.61854 .45302 Mdot
.52887 .66079 Mdot
.33353 .49688 Mdot
.58037 .46028 Mdot
.33635 .51513 Mdot
.43433 .36121 Mdot
.3931 .76114 Mdot
.39817 .36296 Mdot
.57334 .49627 Mdot
.35124 .50104 Mdot
.4791 .6205 Mdot
.44644 .34897 Mdot
.63457 .45588 Mdot
.56006 .45138 Mdot
.37207 .65055 Mdot
.62841 .41989 Mdot
.79334 .39691 Mdot
.64399 .42794 Mdot
.48418 .67063 Mdot
.61222 .4033 Mdot
.19047 .38385 Mdot
.4274 .72075 Mdot
.40217 .35874 Mdot
.35329 .66339 Mdot
.48163 .6479 Mdot
.51443 .77271 Mdot
.37762 .55425 Mdot
.63496 .44448 Mdot
.35811 .64956 Mdot
.56819 .60242 Mdot
.29532 .48938 Mdot
.58077 .40207 Mdot
.23658 .45448 Mdot
.43173 .65118 Mdot
.37041 .65612 Mdot
.52392 .45178 Mdot
.47444 .35487 Mdot
.57644 .42603 Mdot
.48391 .61806 Mdot
.39818 .37254 Mdot
.60076 .49666 Mdot
.73061 .5003 Mdot
.37591 .66437 Mdot
.33798 .50648 Mdot
.54998 .3751 Mdot
.6291 .47348 Mdot
.50195 .63766 Mdot
.43566 .31026 Mdot
.34678 .46244 Mdot
.4376 .3384 Mdot
.51898 .1877 Mdot
.3199 .6342 Mdot
.78599 .48715 Mdot
.64015 .70848 Mdot
.29289 .57926 Mdot
.73464 .28843 Mdot
.26585 .65559 Mdot
.71639 .59552 Mdot
.59918 .18202 Mdot
.44695 .63614 Mdot
.5117 .68746 Mdot
.48752 .64522 Mdot
.60535 .42791 Mdot
.46923 .64123 Mdot
.75052 .30304 Mdot
.56204 .42793 Mdot
.49329 .63151 Mdot
.44045 .7681 Mdot
.5923 .41344 Mdot
.41506 .33093 Mdot
.82645 .6227 Mdot
.18974 .54831 Mdot
.22999 .37163 Mdot
.46747 .62803 Mdot
.54249 .37014 Mdot
.59261 .40968 Mdot
.66121 .46786 Mdot
.44539 .36418 Mdot
.58734 .40268 Mdot
.62631 .7138 Mdot
.63444 .71154 Mdot
.57292 .58095 Mdot
.34273 .77938 Mdot
.63923 .39016 Mdot
.44726 .35272 Mdot
.69853 .37854 Mdot
.21479 .53438 Mdot
.37598 .63708 Mdot
.36655 .50174 Mdot
.83256 .50451 Mdot
.63576 .37974 Mdot
.27568 .52412 Mdot
.23372 .47303 Mdot
.41024 .35101 Mdot
.81022 .45538 Mdot
.30854 .50103 Mdot
.58944 .25437 Mdot
.45987 .26054 Mdot
.60819 .46241 Mdot
.33489 .47074 Mdot
.61617 .38766 Mdot
.19524 .47398 Mdot
.75331 .62644 Mdot
.58689 .81842 Mdot
.57253 .49417 Mdot
.2377 .60151 Mdot
.56874 .44823 Mdot
.51562 .51242 Mdot
.64354 .42688 Mdot
.44125 .33647 Mdot
.63886 .53601 Mdot
.42664 .47917 Mdot
.34092 .7943 Mdot
.22013 .43369 Mdot
.59026 .71545 Mdot
.56194 .44805 Mdot
.60667 .46277 Mdot
.59463 .67747 Mdot
.4458 .32794 Mdot
.64879 .43964 Mdot
.67091 .56084 Mdot
.61363 .47332 Mdot
.30393 .4915 Mdot
.63923 .63951 Mdot
.37146 .34383 Mdot
.6558 .43318 Mdot
.4073 .37998 Mdot
.32128 .51489 Mdot
.32508 .46464 Mdot
.55096 .49553 Mdot
.36174 .4714 Mdot
.56778 .42895 Mdot
.6978 .70269 Mdot
.45659 .36421 Mdot
.67394 .38311 Mdot
.43878 .31804 Mdot
.64329 .34439 Mdot
.35533 .49816 Mdot
.38978 .64914 Mdot
.40685 .27378 Mdot
.31037 .5 Mdot
.25258 .3422 Mdot
.54042 .40489 Mdot
.64629 .40742 Mdot
.20398 .44617 Mdot
.46448 .62676 Mdot
.38189 .65745 Mdot
.36021 .48054 Mdot
.627 .47456 Mdot
.60804 .39652 Mdot
.30272 .50732 Mdot
.55043 .27449 Mdot
.51793 .76428 Mdot
.5836 .4116 Mdot
.44413 .33427 Mdot
.42318 .33932 Mdot
.60132 .49307 Mdot
.63044 .44934 Mdot
.46794 .66705 Mdot
.35728 .66127 Mdot
.36511 .64137 Mdot
.38221 .65965 Mdot
.48073 .68184 Mdot
.35011 .3937 Mdot
.33631 .45341 Mdot
.31444 .34352 Mdot
.2395 .51876 Mdot
.68425 .45199 Mdot
.49858 .62925 Mdot
.59818 .46017 Mdot
.57227 .43207 Mdot
.34802 .46257 Mdot
.32341 .59982 Mdot
.59825 .52922 Mdot
.44568 .37297 Mdot
.36094 .48527 Mdot
.5989 .38115 Mdot
.34627 .33285 Mdot
.60471 .71523 Mdot
.22268 .37777 Mdot
.32525 .4694 Mdot
.40753 .3459 Mdot
.32488 .52317 Mdot
.60794 .46775 Mdot
.5459 .44137 Mdot
.41761 .35276 Mdot
.5763 .69063 Mdot
.5295 .45302 Mdot
.57904 .46156 Mdot
.15649 .59589 Mdot
.20981 .56052 Mdot
.29126 .44827 Mdot
.63151 .42764 Mdot
.62411 .3999 Mdot
.60519 .72383 Mdot
.61267 .47024 Mdot
.55843 .45265 Mdot
.24947 .68188 Mdot
.29638 .44031 Mdot
.57181 .70011 Mdot
.59843 .25788 Mdot
.40282 .32471 Mdot
.8167 .43017 Mdot
.3663 .6426 Mdot
.29291 .51944 Mdot
.37466 .74586 Mdot
.36612 .65945 Mdot
.25646 .56635 Mdot
.81504 .44534 Mdot
.38179 .6593 Mdot
.52872 .61076 Mdot
.59675 .53576 Mdot
.57028 .41645 Mdot
.56961 .45377 Mdot
.59688 .69595 Mdot
.42822 .36303 Mdot
.54174 .57913 Mdot
.76094 .65084 Mdot
.57064 .44303 Mdot
.41183 .39768 Mdot
.81944 .53415 Mdot
.36859 .6525 Mdot
.62483 .70591 Mdot
.60599 .67188 Mdot
.56481 .45297 Mdot
.27506 .69856 Mdot
.44391 .34968 Mdot
.63454 .45539 Mdot
.64083 .47092 Mdot
.47227 .62604 Mdot
.40639 .35789 Mdot
.45568 .62434 Mdot
.3812 .66349 Mdot
.63402 .22446 Mdot
.14287 .5587 Mdot
.35368 .46881 Mdot
.77171 .38281 Mdot
.2995 .48007 Mdot
.60895 .7983 Mdot
.36687 .66282 Mdot
.61763 .4391 Mdot
.44576 .31486 Mdot
.63754 .45707 Mdot
.61122 .45091 Mdot
.61578 .45738 Mdot
.5556 .39485 Mdot
.17032 .42482 Mdot
.6119 .69494 Mdot
.64098 .50817 Mdot
.48669 .66861 Mdot
.78325 .39383 Mdot
.77299 .67543 Mdot
.59684 .467 Mdot
.56398 .45953 Mdot
.41502 .32682 Mdot
.56517 .41503 Mdot
.29654 .49528 Mdot
.43583 .30991 Mdot
.65701 .45131 Mdot
.80235 .45249 Mdot
.64921 .44571 Mdot
.73694 .30123 Mdot
.32323 .52359 Mdot
.25012 .34728 Mdot
.62597 .51443 Mdot
.38708 .65502 Mdot
.38186 .65771 Mdot
.34823 .65283 Mdot
.32581 .52728 Mdot
.49886 .63459 Mdot
.7184 .71519 Mdot
.67587 .42909 Mdot
.6148 .42144 Mdot
.60908 .39582 Mdot
.51967 .66138 Mdot
.46123 .4507 Mdot
.27502 .63211 Mdot
.58451 .3819 Mdot
.46033 .65967 Mdot
.39308 .36528 Mdot
.4195 .62485 Mdot
.4405 .31404 Mdot
.57504 .70705 Mdot
.33267 .47472 Mdot
.61333 .71676 Mdot
.27953 .30327 Mdot
.41906 .36008 Mdot
.37894 .32886 Mdot
.48824 .62891 Mdot
.47985 .5038 Mdot
.76392 .25228 Mdot
.49233 .6144 Mdot
.66276 .59034 Mdot
.45013 .3592 Mdot
.64713 .46684 Mdot
.59784 .62131 Mdot
.47453 .49401 Mdot
.48817 .63484 Mdot
.60527 .43532 Mdot
.31631 .73871 Mdot
.46573 .66658 Mdot
.58045 .40171 Mdot
.44673 .64732 Mdot
.3144 .4799 Mdot
.45247 .64203 Mdot
.42409 .3029 Mdot
.58126 .48314 Mdot
.78487 .27088 Mdot
.56479 .63616 Mdot
.63996 .42583 Mdot
.36019 .48774 Mdot
.67507 .54246 Mdot
.6001 .45088 Mdot
.63066 .7087 Mdot
.46428 .65454 Mdot
.52965 .74478 Mdot
.60083 .40838 Mdot
.4698 .63348 Mdot
.45787 .33864 Mdot
.31853 .52783 Mdot
.61973 .78172 Mdot
.38509 .64532 Mdot
.44163 .36737 Mdot
.38249 .66581 Mdot
.35766 .50467 Mdot
.61652 .39898 Mdot
.63368 .47498 Mdot
.43319 .32986 Mdot
.39956 .78328 Mdot
.61305 .40583 Mdot
.622 .437 Mdot
.45207 .67076 Mdot
.51756 .6593 Mdot
.41244 .78117 Mdot
.45091 .63254 Mdot
.55303 .4106 Mdot
.43382 .33076 Mdot
.58224 .42851 Mdot
.40973 .33359 Mdot
.55366 .44311 Mdot
.48545 .37207 Mdot
.45935 .35427 Mdot
.31036 .68401 Mdot
.59458 .43129 Mdot
.59612 .36671 Mdot
.61299 .45464 Mdot
.6196 .47164 Mdot
.4798 .6656 Mdot
.6157 .6916 Mdot
.59445 .50999 Mdot
.61065 .66338 Mdot
.62659 .7007 Mdot
.54453 .1997 Mdot
.46605 .62763 Mdot
.59591 .70351 Mdot
.79512 .55396 Mdot
.35156 .66089 Mdot
.60684 .69895 Mdot
.78943 .65738 Mdot
.35184 .46606 Mdot
.39232 .33705 Mdot
.59256 .41375 Mdot
.5787 .17744 Mdot
.70673 .67301 Mdot
.36499 .64824 Mdot
.64329 .42855 Mdot
.5976 .45715 Mdot
.44237 .38075 Mdot
.50698 .85976 Mdot
.47748 .67447 Mdot
.60351 .42492 Mdot
.39883 .3514 Mdot
.36286 .8295 Mdot
.4977 .66112 Mdot
.60301 .69701 Mdot
.30582 .51181 Mdot
.47978 .36167 Mdot
.38441 .64386 Mdot
.29444 .49503 Mdot
.33663 .69285 Mdot
.25377 .33488 Mdot
.6448 .45392 Mdot
.50168 .63029 Mdot
.27322 .29684 Mdot
.66595 .39982 Mdot
.2835 .46229 Mdot
.50837 .44645 Mdot
.41011 .34762 Mdot
.30278 .50522 Mdot
.60655 .71974 Mdot
.42942 .30574 Mdot
.44729 .33183 Mdot
.33059 .46057 Mdot
.47554 .60033 Mdot
.49314 .50719 Mdot
.306 .48386 Mdot
.21746 .483 Mdot
.475 .18783 Mdot
.35427 .65695 Mdot
.61984 .69055 Mdot
.39911 .2209 Mdot
.43672 .34467 Mdot
.83241 .501 Mdot
.22755 .35424 Mdot
.57214 .4185 Mdot
.58758 .69875 Mdot
.33333 .41977 Mdot
.74158 .69062 Mdot
.33422 .49991 Mdot
.42033 .45835 Mdot
.58416 .66733 Mdot
.58687 .40826 Mdot
.50418 .36507 Mdot
.6095 .43147 Mdot
.33246 .47836 Mdot
.65084 .3558 Mdot
.40724 .34463 Mdot
.36192 .49265 Mdot
.22352 .37477 Mdot
.56761 .43441 Mdot
.60244 .43321 Mdot
.66573 .64186 Mdot
.41482 .36865 Mdot
.37244 .64018 Mdot
.64068 .44801 Mdot
.5762 .45614 Mdot
.64718 .41437 Mdot
.57575 .37206 Mdot
.25463 .67168 Mdot
.60194 .42587 Mdot
.43408 .67931 Mdot
.66475 .45717 Mdot
.59249 .43298 Mdot
.40835 .37969 Mdot
.14694 .53653 Mdot
.39234 .65092 Mdot
.5735 .45139 Mdot
.64678 .45196 Mdot
.3391 .46035 Mdot
.53478 .56314 Mdot
.46685 .48806 Mdot
.50668 .62704 Mdot
.74315 .57641 Mdot
.55697 .39435 Mdot
.4122 .32116 Mdot
.58465 .67182 Mdot
.61424 .48907 Mdot
.40875 .32565 Mdot
.64502 .48928 Mdot
.46094 .66315 Mdot
.35546 .6584 Mdot
.23545 .38308 Mdot
.60544 .70439 Mdot
.69025 .67723 Mdot
.30809 .36228 Mdot
.43534 .65741 Mdot
.60932 .41879 Mdot
.29023 .5062 Mdot
.5058 .62865 Mdot
.37356 .64925 Mdot
.54257 .49384 Mdot
.44073 .35796 Mdot
.41662 .33457 Mdot
.58553 .59672 Mdot
.41224 .68635 Mdot
.20825 .66421 Mdot
.31674 .47842 Mdot
.65889 .46578 Mdot
.29197 .3259 Mdot
.4159 .33392 Mdot
.59831 .60523 Mdot
.59708 .70504 Mdot
.335 .50117 Mdot
.36189 .63869 Mdot
.41267 .32518 Mdot
.41912 .37446 Mdot
.58519 .49851 Mdot
.5882 .47057 Mdot
.70696 .5971 Mdot
.5811 .58883 Mdot
.31312 .51379 Mdot
.60362 .67892 Mdot
.46103 .61937 Mdot
.61394 .42877 Mdot
.45973 .34765 Mdot
.44445 .19581 Mdot
.6473 .45619 Mdot
.46944 .66804 Mdot
.4127 .34704 Mdot
.58889 .67712 Mdot
.62935 .70721 Mdot
.61866 .47143 Mdot
.58184 .34973 Mdot
.32075 .50955 Mdot
.41399 .33283 Mdot
.35205 .26884 Mdot
.61771 .40657 Mdot
.58642 .47388 Mdot
.51915 .45024 Mdot
.31142 .47034 Mdot
.25382 .34691 Mdot
.57358 .68385 Mdot
.43208 .3524 Mdot
.64552 .43968 Mdot
.61012 .70932 Mdot
.27537 .33011 Mdot
.36102 .65744 Mdot
.44995 .6457 Mdot
.63062 .71012 Mdot
.58633 .68286 Mdot
.61883 .68656 Mdot
.83468 .51684 Mdot
.43389 .30079 Mdot
.70289 .40361 Mdot
.63445 .41818 Mdot
.58624 .59878 Mdot
.56388 .49762 Mdot
.31724 .52389 Mdot
.46215 .6266 Mdot
.60927 .4538 Mdot
.58462 .49802 Mdot
.52726 .39138 Mdot
.65136 .37285 Mdot
.39322 .38326 Mdot
.41385 .36144 Mdot
.681 .45078 Mdot
.47533 .62415 Mdot
.5139 .8687 Mdot
.76271 .28249 Mdot
.60543 .52157 Mdot
.50967 .53092 Mdot
.45493 .33671 Mdot
.32555 .46001 Mdot
.45439 .48532 Mdot
.33311 .51947 Mdot
.42817 .34784 Mdot
.60998 .4281 Mdot
.3185 .34735 Mdot
.62432 .72364 Mdot
.62321 .47613 Mdot
.33097 .48663 Mdot
.62166 .47597 Mdot
.29845 .50261 Mdot
.3684 .29331 Mdot
.2167 .49736 Mdot
.56808 .42389 Mdot
.62898 .40851 Mdot
.50647 .39514 Mdot
.59486 .46539 Mdot
.47893 .82958 Mdot
.44821 .32793 Mdot
.32759 .75756 Mdot
.60011 .49805 Mdot
.61961 .32347 Mdot
.62639 .41235 Mdot
.35321 .7484 Mdot
.59278 .47606 Mdot
.43309 .51677 Mdot
.57599 .41416 Mdot
.56604 .47047 Mdot
.34611 .50694 Mdot
.3386 .4605 Mdot
.46455 .35792 Mdot
.37744 .64017 Mdot
.76157 .33855 Mdot
.58075 .46619 Mdot
.45829 .68095 Mdot
.27041 .48949 Mdot
.5928 .67932 Mdot
.42991 .34625 Mdot
.38012 .84497 Mdot
.33152 .51552 Mdot
.44713 .6229 Mdot
.41003 .79422 Mdot
.42776 .67056 Mdot
.35452 .43482 Mdot
.55285 .54018 Mdot
.57792 .68789 Mdot
.59536 .40635 Mdot
.34881 .23858 Mdot
.21648 .55768 Mdot
.5361 .47688 Mdot
.35762 .50197 Mdot
.70135 .34653 Mdot
.40148 .22283 Mdot
.62309 .68341 Mdot
.59471 .71555 Mdot
.33251 .5132 Mdot
.44908 .67336 Mdot
.55108 .40296 Mdot
.59754 .70653 Mdot
.4436 .66022 Mdot
.34708 .65894 Mdot
.40452 .5246 Mdot
.4409 .34946 Mdot
.22472 .37872 Mdot
.29007 .39933 Mdot
.31636 .51554 Mdot
.55183 .66316 Mdot
.47947 .37219 Mdot
.46617 .32936 Mdot
.38664 .64264 Mdot
.48134 .66618 Mdot
.43138 .30279 Mdot
.54627 .41778 Mdot
.65752 .37183 Mdot
.5708 .44623 Mdot
.59303 .69051 Mdot
.59757 .47323 Mdot
.47298 .66482 Mdot
.32978 .4981 Mdot
.49291 .65806 Mdot
.34053 .50931 Mdot
.34051 .38149 Mdot
.62892 .45695 Mdot
.567 .46956 Mdot
.70117 .67997 Mdot
.46081 .36757 Mdot
.32061 .27174 Mdot
.48121 .68382 Mdot
.49332 .64561 Mdot
.55618 .44451 Mdot
.44823 .32129 Mdot
.63064 .73669 Mdot
.69807 .68641 Mdot
.6229 .48084 Mdot
.44757 .3264 Mdot
.60986 .42357 Mdot
.80042 .53081 Mdot
.20034 .56801 Mdot
.43342 .33625 Mdot
.36688 .80561 Mdot
.6311 .4325 Mdot
.66307 .5168 Mdot
.60186 .39527 Mdot
.68303 .56619 Mdot
.61234 .40493 Mdot
.40505 .32208 Mdot
.57486 .44728 Mdot
.42701 .3074 Mdot
.44025 .66744 Mdot
.32605 .45723 Mdot
.4482 .36617 Mdot
.63156 .4791 Mdot
.84835 .47077 Mdot
.32747 .47762 Mdot
.56256 .44573 Mdot
.34803 .4832 Mdot
.39734 .34192 Mdot
.42731 .37336 Mdot
.74013 .70381 Mdot
.2809 .45469 Mdot
.31307 .48179 Mdot
.59698 .42263 Mdot
.26331 .40116 Mdot
.59036 .42767 Mdot
.69306 .60256 Mdot
.5737 .48972 Mdot
.61321 .40419 Mdot
.72016 .7521 Mdot
.29606 .48414 Mdot
.21565 .66676 Mdot
.77019 .63358 Mdot
.83322 .5301 Mdot
.47332 .33286 Mdot
.62235 .68284 Mdot
.81464 .46284 Mdot
.3766 .66558 Mdot
.45667 .64832 Mdot
.60967 .45493 Mdot
.38028 .29562 Mdot
.30357 .50206 Mdot
.61248 .6895 Mdot
.56708 .42488 Mdot
.47507 .66863 Mdot
.57607 .76499 Mdot
.3521 .4526 Mdot
.43564 .34547 Mdot
.44959 .37293 Mdot
.33575 .80444 Mdot
.64619 .43948 Mdot
.56137 .45733 Mdot
.33388 .47644 Mdot
.6544 .38074 Mdot
.58408 .67535 Mdot
.43156 .75703 Mdot
.31362 .48194 Mdot
.48904 .5439 Mdot
.41971 .36405 Mdot
.59838 .4585 Mdot
.47335 .45469 Mdot
.3721 .57238 Mdot
.59181 .2339 Mdot
.59831 .69357 Mdot
.69356 .61323 Mdot
.4046 .32254 Mdot
.32515 .49249 Mdot
.48302 .70457 Mdot
.66645 .44304 Mdot
.59247 .45603 Mdot
.69079 .6172 Mdot
.55445 .59045 Mdot
.65253 .72928 Mdot
.54951 .42978 Mdot
.55408 .58652 Mdot
.55441 .45298 Mdot
.65329 .42006 Mdot
.54414 .4285 Mdot
.58527 .47836 Mdot
.44984 .32919 Mdot
.54284 .38716 Mdot
.46072 .63836 Mdot
.52089 .25679 Mdot
.43212 .46217 Mdot
.61996 .41335 Mdot
.6029 .42871 Mdot
.64498 .26447 Mdot
.256 .49287 Mdot
.45437 .34333 Mdot
.40805 .30377 Mdot
.35941 .46623 Mdot
.59243 .36635 Mdot
.48191 .67829 Mdot
.52303 .4114 Mdot
.48847 .65976 Mdot
.44395 .32037 Mdot
.49823 .64584 Mdot
.35156 .45495 Mdot
.50186 .63014 Mdot
.48001 .68243 Mdot
.30025 .50107 Mdot
.4265 .36913 Mdot
.60848 .48088 Mdot
.36102 .48302 Mdot
.66789 .64009 Mdot
.59325 .69165 Mdot
.74234 .70188 Mdot
.65267 .47625 Mdot
.41 .4353 Mdot
.7305 .502 Mdot
.49228 .65674 Mdot
.21095 .61538 Mdot
.45911 .35575 Mdot
.61899 .72873 Mdot
.44638 .3222 Mdot
.20603 .37809 Mdot
.61338 .68729 Mdot
.79412 .65194 Mdot
.37314 .67935 Mdot
.56708 .74871 Mdot
.54399 .44046 Mdot
.49352 .35701 Mdot
.48712 .61668 Mdot
.30427 .50332 Mdot
.35277 .68108 Mdot
.57104 .47795 Mdot
.27283 .66023 Mdot
.46165 .37049 Mdot
.34994 .6545 Mdot
.31948 .49626 Mdot
.3628 .48472 Mdot
.64129 .45745 Mdot
.46567 .78513 Mdot
.57884 .48643 Mdot
.39593 .68553 Mdot
.72384 .59553 Mdot
.51562 .42358 Mdot
.55974 .43424 Mdot
.50643 .65123 Mdot
.6086 .4231 Mdot
.71512 .40452 Mdot
.32444 .24858 Mdot
.5375 .41872 Mdot
.31915 .64569 Mdot
.57137 .71189 Mdot
.41943 .35594 Mdot
.62466 .51361 Mdot
.37653 .64544 Mdot
.63206 .43028 Mdot
.31733 .21246 Mdot
.60891 .70153 Mdot
.54001 .66063 Mdot
.63888 .41898 Mdot
.6407 .45185 Mdot
.43576 .26168 Mdot
.38654 .28946 Mdot
.36069 .63866 Mdot
.58724 .45479 Mdot
.74245 .59604 Mdot
.34376 .47116 Mdot
.58829 .48918 Mdot
.56783 .45287 Mdot
.58206 .20785 Mdot
.31738 .4682 Mdot
.49655 .65377 Mdot
.36158 .66594 Mdot
.45158 .62513 Mdot
.56595 .67193 Mdot
.45357 .50115 Mdot
.59638 .59669 Mdot
.20206 .563 Mdot
.61601 .67999 Mdot
.65109 .45483 Mdot
.60183 .52987 Mdot
.6363 .43945 Mdot
.60284 .71982 Mdot
.30859 .47429 Mdot
.45702 .35234 Mdot
.24024 .38673 Mdot
.37298 .65538 Mdot
.58497 .40053 Mdot
.62213 .71806 Mdot
.43862 .36298 Mdot
.5582 .64859 Mdot
.42599 .35473 Mdot
.31082 .49131 Mdot
.35048 .52009 Mdot
.62092 .70321 Mdot
.4401 .315 Mdot
.41692 .67174 Mdot
.75592 .65655 Mdot
.56406 .48197 Mdot
.34746 .44132 Mdot
.45758 .33483 Mdot
.44439 .38924 Mdot
.46984 .36032 Mdot
.62501 .46544 Mdot
.51906 .54104 Mdot
.65799 .43192 Mdot
.32593 .51385 Mdot
.44703 .65337 Mdot
.5893 .587 Mdot
.39115 .24872 Mdot
.54088 .60591 Mdot
.558 .49416 Mdot
.56968 .43748 Mdot
.5648 .45264 Mdot
.56111 .48746 Mdot
.44676 .70379 Mdot
.62997 .45199 Mdot
.34538 .50688 Mdot
.47547 .65984 Mdot
.62986 .41656 Mdot
.37191 .64345 Mdot
.48877 .49505 Mdot
.58891 .67019 Mdot
.44091 .48817 Mdot
.82082 .41981 Mdot
.4407 .36375 Mdot
.45769 .62489 Mdot
.45777 .64602 Mdot
.60864 .67763 Mdot
.30554 .50265 Mdot
.4273 .35973 Mdot
.70067 .55757 Mdot
.61241 .68237 Mdot
.57513 .45059 Mdot
.3578 .72435 Mdot
.32181 .70836 Mdot
.58454 .40712 Mdot
.60761 .44552 Mdot
.35406 .66451 Mdot
.45967 .67601 Mdot
.49928 .15129 Mdot
.61003 .62865 Mdot
.61923 .69758 Mdot
.58076 .69966 Mdot
.47003 .34097 Mdot
.59137 .52541 Mdot
.33416 .50982 Mdot
.64909 .64769 Mdot
.64695 .56055 Mdot
.67822 .67907 Mdot
.60259 .79614 Mdot
.63463 .46958 Mdot
.48177 .29605 Mdot
.56805 .43094 Mdot
.45232 .37666 Mdot
.40152 .36066 Mdot
.45234 .35008 Mdot
.31573 .51065 Mdot
.65387 .34445 Mdot
.35276 .49809 Mdot
.80207 .37229 Mdot
.41152 .31403 Mdot
.48014 .72012 Mdot
.49805 .6393 Mdot
.64887 .49476 Mdot
.58323 .67841 Mdot
.37438 .45756 Mdot
.53913 .4402 Mdot
.26371 .68416 Mdot
.49966 .63015 Mdot
.42094 .37017 Mdot
.55728 .54076 Mdot
.69882 .25231 Mdot
.47774 .50772 Mdot
.69169 .45612 Mdot
.44016 .27265 Mdot
.60145 .67918 Mdot
.58853 .23473 Mdot
.57582 .69977 Mdot
.33576 .49194 Mdot
.57482 .47863 Mdot
.5919 .48307 Mdot
.55309 .44309 Mdot
.62861 .45349 Mdot
.348 .46074 Mdot
.61364 .50319 Mdot
.19047 .38388 Mdot
.35368 .66074 Mdot
.80386 .51539 Mdot
.6022 .71241 Mdot
.34144 .51972 Mdot
.47903 .65984 Mdot
.36275 .64138 Mdot
.62061 .60834 Mdot
.57815 .41394 Mdot
.61151 .45371 Mdot
.38571 .63821 Mdot
.55272 .42066 Mdot
.56997 .38578 Mdot
.46391 .63752 Mdot
.54211 .60499 Mdot
.63338 .70281 Mdot
.61164 .71685 Mdot
.30766 .47793 Mdot
.44222 .317 Mdot
.59641 .70043 Mdot
.45379 .67182 Mdot
.63321 .49814 Mdot
.63445 .47968 Mdot
.45891 .33677 Mdot
.22589 .35601 Mdot
.61011 .67311 Mdot
.56249 .54296 Mdot
.41599 .3143 Mdot
.43632 .30061 Mdot
.59194 .45407 Mdot
.5233 .43727 Mdot
.4475 .3909 Mdot
.62916 .69883 Mdot
.34374 .51862 Mdot
.55939 .72928 Mdot
.335 .48465 Mdot
.43132 .36245 Mdot
.6042 .4952 Mdot
.42281 .36734 Mdot
.63507 .42857 Mdot
.80999 .70573 Mdot
.59299 .48115 Mdot
.18939 .52135 Mdot
.67786 .57879 Mdot
.46159 .64573 Mdot
.41717 .67086 Mdot
.36125 .64676 Mdot
.41218 .31639 Mdot
.61711 .48972 Mdot
.57928 .69929 Mdot
.81847 .58555 Mdot
.47681 .38124 Mdot
.45466 .6582 Mdot
.47385 .6787 Mdot
.29641 .48791 Mdot
.64454 .42574 Mdot
.59563 .46011 Mdot
.50368 .63403 Mdot
.74766 .49725 Mdot
.41984 .31927 Mdot
.56126 .45393 Mdot
.57836 .4342 Mdot
.46325 .64176 Mdot
.75249 .66021 Mdot
.44095 .28918 Mdot
.57574 .47672 Mdot
.53305 .68513 Mdot
.31965 .52534 Mdot
.55346 .47416 Mdot
.61133 .50353 Mdot
.58321 .69201 Mdot
.79455 .46117 Mdot
.34421 .23064 Mdot
.31445 .52137 Mdot
.37347 .64044 Mdot
.65427 .45325 Mdot
.49692 .63818 Mdot
.63414 .47862 Mdot
.74513 .35227 Mdot
.35158 .65675 Mdot
.62698 .44301 Mdot
.58393 .52088 Mdot
.40554 .36538 Mdot
.63357 .45075 Mdot
.63294 .24325 Mdot
.48067 .61262 Mdot
.63064 .44645 Mdot
.55564 .35381 Mdot
.32557 .46585 Mdot
.60287 .52137 Mdot
.59977 .71468 Mdot
.68492 .56159 Mdot
.30877 .37468 Mdot
.52526 .65055 Mdot
.61124 .71553 Mdot
.6155 .48215 Mdot
.44234 .67171 Mdot
.31151 .51473 Mdot
.26159 .65482 Mdot
.55464 .43133 Mdot
.33118 .47838 Mdot
.32782 .4981 Mdot
.6139 .70734 Mdot
.24146 .70714 Mdot
.62382 .50645 Mdot
.5966 .46786 Mdot
.63912 .24091 Mdot
.42353 .38124 Mdot
.60139 .47576 Mdot
.64875 .45642 Mdot
.34875 .49938 Mdot
.40691 .27245 Mdot
.67774 .31644 Mdot
.43773 .76687 Mdot
.29965 .50833 Mdot
.50565 .60694 Mdot
.4391 .67064 Mdot
.59987 .71065 Mdot
.41813 .34935 Mdot
.57679 .66901 Mdot
.46579 .63024 Mdot
.64827 .4474 Mdot
.34471 .49977 Mdot
.49496 .20853 Mdot
.29534 .4779 Mdot
.5122 .62847 Mdot
.44558 .38398 Mdot
.28129 .34377 Mdot
.25347 .26484 Mdot
.30008 .40024 Mdot
.30809 .53965 Mdot
.5923 .67949 Mdot
.34561 .69679 Mdot
.57501 .43539 Mdot
.57822 .23967 Mdot
.61423 .47831 Mdot
.51192 .34858 Mdot
.4491 .6365 Mdot
.38515 .64058 Mdot
.57627 .47877 Mdot
.713 .60643 Mdot
.32103 .45398 Mdot
.29538 .49072 Mdot
.62171 .44733 Mdot
.30994 .49949 Mdot
.58704 .46664 Mdot
.48123 .66384 Mdot
.19577 .62952 Mdot
.566 .4409 Mdot
.64265 .40773 Mdot
.25882 .51137 Mdot
.75486 .69039 Mdot
.42569 .68159 Mdot
.47287 .28797 Mdot
.66436 .22388 Mdot
.31083 .50003 Mdot
.55311 .50517 Mdot
.49588 .62197 Mdot
.35384 .66469 Mdot
.41472 .67026 Mdot
.60965 .47403 Mdot
.61387 .46922 Mdot
.55646 .4435 Mdot
.60372 .43296 Mdot
.58521 .24093 Mdot
.60572 .37235 Mdot
.51427 .3174 Mdot
.6123 .45165 Mdot
.50323 .35992 Mdot
.35966 .47887 Mdot
.38223 .35887 Mdot
.58758 .6642 Mdot
.63605 .46784 Mdot
.36899 .3513 Mdot
.32788 .52485 Mdot
.80099 .36999 Mdot
.30263 .47836 Mdot
.48005 .64802 Mdot
.31614 .46365 Mdot
.63153 .4224 Mdot
.4231 .33859 Mdot
.49783 .61799 Mdot
.24954 .60395 Mdot
.45644 .64978 Mdot
.64019 .42595 Mdot
.55033 .70339 Mdot
.45608 .64529 Mdot
.47123 .47298 Mdot
.41878 .3405 Mdot
.73727 .60727 Mdot
.40071 .35996 Mdot
.63051 .44363 Mdot
.6272 .44024 Mdot
.35014 .67025 Mdot
.3296 .45354 Mdot
.39593 .34447 Mdot
.16025 .60735 Mdot
.56951 .68685 Mdot
.44962 .34585 Mdot
.67346 .4462 Mdot
.54001 .5728 Mdot
.42611 .33144 Mdot
.7362 .55477 Mdot
.30604 .50613 Mdot
.43693 .30414 Mdot
.67126 .44317 Mdot
.30448 .55501 Mdot
.62762 .72452 Mdot
.49723 .66692 Mdot
.43527 .54294 Mdot
.48207 .61548 Mdot
.34135 .52192 Mdot
.51709 .6461 Mdot
.3463 .47072 Mdot
.30886 .28479 Mdot
.66829 .36934 Mdot
.28685 .49786 Mdot
.35238 .51414 Mdot
.48228 .62914 Mdot
.55852 .43011 Mdot
.40913 .4708 Mdot
.54765 .43063 Mdot
.54316 .45532 Mdot
.34002 .46803 Mdot
.39856 .33288 Mdot
.39102 .3378 Mdot
.49675 .36043 Mdot
.44893 .37385 Mdot
.48702 .66201 Mdot
.19872 .56462 Mdot
.28446 .29818 Mdot
.33325 .47216 Mdot
.365 .48853 Mdot
.59397 .42785 Mdot
.49435 .6343 Mdot
.43456 .66171 Mdot
.33358 .50739 Mdot
.52596 .22426 Mdot
.65933 .43611 Mdot
.43789 .38847 Mdot
.41509 .31053 Mdot
.43416 .3331 Mdot
.47161 .3534 Mdot
.65285 .3076 Mdot
.30492 .50561 Mdot
.41142 .31541 Mdot
.62287 .4445 Mdot
.61212 .47041 Mdot
.38274 .65457 Mdot
.60858 .7173 Mdot
.65006 .48473 Mdot
.56476 .40152 Mdot
.59471 .45421 Mdot
.45074 .64605 Mdot
.65678 .5027 Mdot
.36035 .6444 Mdot
.48441 .67285 Mdot
.48897 .67827 Mdot
.38905 .65077 Mdot
.49624 .3702 Mdot
.66878 .21887 Mdot
.60402 .42491 Mdot
.68839 .39983 Mdot
.49376 .63922 Mdot
.22814 .64808 Mdot
.25997 .34323 Mdot
.55501 .43877 Mdot
.38923 .55091 Mdot
.51082 .63866 Mdot
.42937 .37877 Mdot
.6063 .47733 Mdot
.37567 .6629 Mdot
.58883 .6708 Mdot
.67395 .43862 Mdot
.36404 .66673 Mdot
.43511 .31242 Mdot
.61684 .67191 Mdot
.44409 .30815 Mdot
.51052 .63408 Mdot
.5877 .52148 Mdot
.76323 .24844 Mdot
.44793 .62981 Mdot
.8009 .60473 Mdot
.37568 .29392 Mdot
.55961 .44969 Mdot
.46185 .62111 Mdot
.42958 .38105 Mdot
.33202 .5267 Mdot
.5482 .57613 Mdot
.45661 .36314 Mdot
.37425 .63939 Mdot
.37529 .66018 Mdot
.4615 .63952 Mdot
.41103 .35863 Mdot
.5928 .49193 Mdot
.40414 .34585 Mdot
.31349 .46536 Mdot
.57761 .42269 Mdot
.74771 .30114 Mdot
.67265 .38792 Mdot
.40791 .3213 Mdot
.47745 .6703 Mdot
.60928 .72525 Mdot
.5769 .41751 Mdot
.79384 .5971 Mdot
.65116 .43987 Mdot
.34191 .47393 Mdot
.30521 .73861 Mdot
.52204 .20716 Mdot
.62384 .41183 Mdot
.59543 .42832 Mdot
.30153 .50487 Mdot
.57736 .41516 Mdot
.61323 .40671 Mdot
.27457 .47082 Mdot
.40396 .3567 Mdot
.5745 .44337 Mdot
.44425 .66497 Mdot
.34565 .24952 Mdot
.65562 .43022 Mdot
.35769 .6184 Mdot
.72721 .61032 Mdot
.29095 .73752 Mdot
.60738 .48345 Mdot
.62974 .629 Mdot
.60567 .43672 Mdot
.62873 .46876 Mdot
.59199 .42408 Mdot
.46529 .27552 Mdot
.48058 .62755 Mdot
.46601 .66187 Mdot
.62968 .72273 Mdot
.73092 .60582 Mdot
.58636 .69821 Mdot
.29904 .49029 Mdot
.57929 .78061 Mdot
.35305 .65628 Mdot
.43828 .31297 Mdot
.59726 .48837 Mdot
.48735 .61149 Mdot
.60139 .45964 Mdot
.63065 .42362 Mdot
.50642 .65452 Mdot
.42965 .65354 Mdot
.52507 .67567 Mdot
.5761 .68756 Mdot
.45287 .35826 Mdot
.58203 .49868 Mdot
.62664 .70133 Mdot
.59926 .49163 Mdot
.57476 .61087 Mdot
.45449 .353 Mdot
.40286 .35393 Mdot
.39862 .3672 Mdot
.64846 .44721 Mdot
.62014 .4145 Mdot
.35391 .49564 Mdot
.44595 .31734 Mdot
.31402 .47461 Mdot
.49916 .62204 Mdot
.43658 .63495 Mdot
.60982 .47384 Mdot
.62121 .5425 Mdot
.58076 .69228 Mdot
.48218 .65256 Mdot
.3817 .63602 Mdot
.61264 .72837 Mdot
.64607 .43445 Mdot
.5073 .64978 Mdot
.6166 .71667 Mdot
.49404 .23382 Mdot
.62598 .19064 Mdot
.60439 .72296 Mdot
.62033 .44542 Mdot
.42323 .25701 Mdot
.7383 .67028 Mdot
.5702 .69141 Mdot
.34439 .48545 Mdot
.65019 .44998 Mdot
.73011 .46287 Mdot
.59408 .6676 Mdot
.34078 .26329 Mdot
.46376 .6462 Mdot
.34164 .55325 Mdot
.65874 .40254 Mdot
.56128 .24448 Mdot
.57064 .67368 Mdot
.42998 .35622 Mdot
.38987 .36653 Mdot
.59263 .44478 Mdot
.57187 .66366 Mdot
.29358 .49631 Mdot
.46524 .6516 Mdot
.44019 .67749 Mdot
.40875 .3564 Mdot
.24842 .42725 Mdot
.45103 .66332 Mdot
.58214 .54649 Mdot
.38927 .75739 Mdot
.62144 .36471 Mdot
.52332 .37067 Mdot
.22685 .54827 Mdot
.65005 .46491 Mdot
.59494 .71841 Mdot
.33649 .5196 Mdot
.33662 .51139 Mdot
.31353 .48468 Mdot
.41888 .67106 Mdot
.45169 .4853 Mdot
.49208 .6245 Mdot
.26069 .639 Mdot
.6093 .7092 Mdot
.7592 .58748 Mdot
.60939 .48932 Mdot
.56884 .43841 Mdot
.65845 .46826 Mdot
.57178 .48333 Mdot
.5974 .43736 Mdot
.30584 .50005 Mdot
.42581 .67466 Mdot
.52491 .74509 Mdot
.44243 .33187 Mdot
.53171 .60776 Mdot
.49823 .63949 Mdot
.35317 .66359 Mdot
.61191 .69283 Mdot
.52026 .52139 Mdot
.52114 .64884 Mdot
.49711 .64655 Mdot
.64648 .49217 Mdot
.41011 .32831 Mdot
.52327 .42105 Mdot
.62048 .43666 Mdot
.4842 .65522 Mdot
.42405 .63469 Mdot
.68071 .29685 Mdot
.53015 .49217 Mdot
.64037 .72714 Mdot
.52765 .5547 Mdot
.57294 .69693 Mdot
.62145 .39438 Mdot
.23436 .65845 Mdot
.46702 .63017 Mdot
.47687 .64244 Mdot
.61388 .72027 Mdot
.64653 .52673 Mdot
.41238 .35102 Mdot
.38419 .63975 Mdot
.35086 .48266 Mdot
.63497 .44071 Mdot
.43167 .64278 Mdot
.69407 .47111 Mdot
.49518 .78162 Mdot
.31863 .47975 Mdot
.48092 .67283 Mdot
.64179 .42359 Mdot
.61777 .44544 Mdot
.59596 .67796 Mdot
.37854 .3904 Mdot
.67837 .44085 Mdot
.83409 .52793 Mdot
.21859 .49479 Mdot
.21455 .45911 Mdot
.59241 .45621 Mdot
.40796 .35969 Mdot
.36716 .6624 Mdot
.61687 .68741 Mdot
.60662 .50019 Mdot
.63795 .19833 Mdot
.40698 .38639 Mdot
.33077 .4901 Mdot
.3784 .66142 Mdot
.45259 .48255 Mdot
.65141 .4448 Mdot
.61345 .47827 Mdot
.62648 .46025 Mdot
.56362 .15359 Mdot
.45281 .65969 Mdot
.45794 .37194 Mdot
.5986 .69127 Mdot
.44991 .37468 Mdot
.46052 .65595 Mdot
.24884 .3887 Mdot
.60838 .40887 Mdot
.43967 .38688 Mdot
.42886 .35316 Mdot
.29675 .48772 Mdot
.33244 .52739 Mdot
.54503 .66259 Mdot
.59185 .48046 Mdot
.37338 .66389 Mdot
.40165 .36302 Mdot
.42907 .66807 Mdot
.61134 .68543 Mdot
.35803 .49156 Mdot
.61358 .4521 Mdot
.46075 .63551 Mdot
.53092 .462 Mdot
.42172 .3289 Mdot
.49706 .64584 Mdot
.39446 .64807 Mdot
.58534 .70542 Mdot
.61321 .46188 Mdot
.63789 .73317 Mdot
.3898 .64339 Mdot
.57735 .43345 Mdot
.5137 .49398 Mdot
.63943 .73973 Mdot
.26517 .61986 Mdot
.47781 .62021 Mdot
.38162 .64811 Mdot
.40582 .37098 Mdot
.33764 .28165 Mdot
.4743 .64579 Mdot
.51425 .50446 Mdot
.37389 .40274 Mdot
.5794 .49841 Mdot
.43636 .34124 Mdot
.35556 .70642 Mdot
.83161 .47301 Mdot
.7767 .59228 Mdot
.56371 .44792 Mdot
.46785 .61897 Mdot
.62408 .7136 Mdot
.33353 .47175 Mdot
.35663 .61943 Mdot
.69591 .38776 Mdot
.51261 .65599 Mdot
.5962 .42539 Mdot
.401 .35816 Mdot
.33007 .50678 Mdot
.32637 .34978 Mdot
.46553 .67299 Mdot
.45238 .6326 Mdot
.63021 .41612 Mdot
.59965 .70568 Mdot
.77785 .50534 Mdot
.47311 .66597 Mdot
.43424 .64029 Mdot
.32889 .68948 Mdot
.62126 .71913 Mdot
.60802 .44118 Mdot
.49719 .35866 Mdot
.55749 .48371 Mdot
.80488 .60237 Mdot
.36656 .6428 Mdot
.44113 .3291 Mdot
.61955 .47526 Mdot
.42796 .76997 Mdot
.47786 .65592 Mdot
.50524 .52571 Mdot
.46432 .60897 Mdot
.30726 .50732 Mdot
.4352 .6385 Mdot
.60186 .47054 Mdot
.31691 .4558 Mdot
.58116 .69299 Mdot
.57861 .47696 Mdot
.61753 .41403 Mdot
.43711 .3792 Mdot
.33695 .49221 Mdot
.43187 .21541 Mdot
.36226 .49305 Mdot
.32461 .52344 Mdot
.38715 .33693 Mdot
.58215 .44769 Mdot
.48448 .64759 Mdot
.51558 .64618 Mdot
.59831 .49914 Mdot
.19573 .59852 Mdot
.4103 .35131 Mdot
.55099 .65313 Mdot
.51562 .15576 Mdot
.51731 .47077 Mdot
.39095 .63947 Mdot
.39356 .40136 Mdot
.29738 .50339 Mdot
.61731 .44893 Mdot
.41539 .31741 Mdot
.42344 .65701 Mdot
.44964 .66343 Mdot
.60083 .49415 Mdot
.32863 .50247 Mdot
.60269 .6725 Mdot
.44339 .63975 Mdot
.46701 .78425 Mdot
.63256 .4576 Mdot
.27807 .66123 Mdot
.44966 .63202 Mdot
.83294 .57773 Mdot
.51414 .75844 Mdot
.438 .33885 Mdot
.62648 .42125 Mdot
.44937 .37163 Mdot
.59554 .68752 Mdot
.52272 .61617 Mdot
.32977 .49996 Mdot
.54099 .50605 Mdot
.28008 .26432 Mdot
.48698 .62833 Mdot
.45026 .33028 Mdot
.62646 .41314 Mdot
.54151 .52042 Mdot
.59546 .47101 Mdot
.41486 .27152 Mdot
.55383 .66588 Mdot
.3362 .467 Mdot
.34348 .47651 Mdot
.57425 .43153 Mdot
.59574 .6745 Mdot
.49668 .66349 Mdot
.46625 .65055 Mdot
.59124 .86699 Mdot
.39492 .64418 Mdot
.70453 .59196 Mdot
.61391 .46647 Mdot
.43619 .67152 Mdot
.38837 .24733 Mdot
.33346 .47592 Mdot
.57434 .48604 Mdot
.45385 .67821 Mdot
.26642 .54064 Mdot
.56721 .60449 Mdot
.59953 .43945 Mdot
.60025 .38304 Mdot
.34928 .48227 Mdot
.69266 .66493 Mdot
.49772 .62743 Mdot
.57264 .48753 Mdot
.3653 .47486 Mdot
.40133 .7737 Mdot
.28767 .28321 Mdot
.4528 .35789 Mdot
.49231 .60989 Mdot
.3056 .50028 Mdot
.67771 .42388 Mdot
.60462 .71387 Mdot
.48478 .61374 Mdot
.45162 .65021 Mdot
.59569 .41941 Mdot
.64682 .49398 Mdot
.51855 .47753 Mdot
.44479 .32555 Mdot
.3571 .4717 Mdot
.5759 .48064 Mdot
.24756 .43246 Mdot
.5542 .4496 Mdot
.35767 .48219 Mdot
.87149 .37293 Mdot
.54559 .45363 Mdot
.59392 .46893 Mdot
.78132 .52571 Mdot
.45515 .36573 Mdot
.44459 .37555 Mdot
.20914 .51633 Mdot
.61379 .46602 Mdot
.54826 .75784 Mdot
.45079 .3624 Mdot
.41059 .34647 Mdot
.4583 .72567 Mdot
.56719 .42773 Mdot
.69443 .68574 Mdot
.33778 .50885 Mdot
.33776 .51484 Mdot
.40448 .34873 Mdot
.67901 .43366 Mdot
.30977 .51569 Mdot
.62233 .26602 Mdot
.4987 .63475 Mdot
.23695 .66489 Mdot
.42377 .32524 Mdot
.40357 .44766 Mdot
.32724 .47507 Mdot
.80428 .37663 Mdot
.38077 .56021 Mdot
.55733 .43994 Mdot
.61793 .45959 Mdot
.58295 .69809 Mdot
.54625 .48352 Mdot
.36521 .64128 Mdot
.30953 .4991 Mdot
.77108 .4661 Mdot
.45186 .34982 Mdot
.59082 .4765 Mdot
.5285 .53365 Mdot
.3304 .37254 Mdot
.31367 .65248 Mdot
.42012 .35538 Mdot
.44053 .34649 Mdot
.47786 .6235 Mdot
.44644 .64248 Mdot
.58691 .44342 Mdot
.32734 .5128 Mdot
.44528 .31533 Mdot
.35488 .47663 Mdot
.46336 .63166 Mdot
.49271 .64732 Mdot
.35087 .65763 Mdot
.55401 .4146 Mdot
.49369 .66314 Mdot
.4475 .78708 Mdot
.24479 .42615 Mdot
.46792 .33321 Mdot
.32658 .22494 Mdot
.32661 .34744 Mdot
.71975 .5223 Mdot
.57419 .68877 Mdot
.40479 .65311 Mdot
.33551 .45815 Mdot
.59115 .4288 Mdot
.60664 .45664 Mdot
.36805 .65242 Mdot
.31307 .46093 Mdot
.60629 .6858 Mdot
.31873 .45732 Mdot
.6128 .71128 Mdot
.41839 .66057 Mdot
.65648 .43822 Mdot
.64466 .46495 Mdot
.30627 .49598 Mdot
.4996 .65121 Mdot
.47289 .66111 Mdot
.57492 .69997 Mdot
.56877 .58913 Mdot
.46016 .63923 Mdot
.42288 .32625 Mdot
.63453 .31049 Mdot
.37154 .66003 Mdot
.60452 .47677 Mdot
.59207 .60223 Mdot
.55857 .22475 Mdot
.56899 .49087 Mdot
.38592 .65645 Mdot
.47782 .85789 Mdot
.60128 .48681 Mdot
.40529 .84084 Mdot
.38294 .64876 Mdot
.45663 .36504 Mdot
.46496 .62109 Mdot
.3588 .64344 Mdot
.65811 .39787 Mdot
.58049 .71559 Mdot
.63168 .4923 Mdot
.44954 .36834 Mdot
.4043 .37671 Mdot
.20503 .45409 Mdot
.80161 .60596 Mdot
.57905 .70454 Mdot
.6176 .70062 Mdot
.47249 .64488 Mdot
.69024 .76217 Mdot
.66774 .45705 Mdot
.6168 .6943 Mdot
.76055 .47701 Mdot
.60426 .4273 Mdot
.68298 .60797 Mdot
.39484 .54766 Mdot
.40772 .35769 Mdot
.49851 .37798 Mdot
.47418 .65126 Mdot
.4527 .33558 Mdot
.23478 .41606 Mdot
.65503 .47258 Mdot
.45397 .35043 Mdot
.356 .48595 Mdot
.26116 .57199 Mdot
.43182 .37268 Mdot
.58267 .61026 Mdot
.33068 .50997 Mdot
.37559 .69611 Mdot
.76482 .52153 Mdot
.23295 .2614 Mdot
.31049 .50433 Mdot
.50743 .64332 Mdot
.51137 .63962 Mdot
.46668 .64778 Mdot
.45945 .35883 Mdot
.44111 .66833 Mdot
.43816 .31989 Mdot
.73413 .68521 Mdot
.57125 .58831 Mdot
.62151 .70398 Mdot
.27073 .4686 Mdot
.43421 .34955 Mdot
.22334 .60756 Mdot
.26442 .25849 Mdot
.62345 .44839 Mdot
.36414 .48561 Mdot
.61071 .72023 Mdot
.82069 .64418 Mdot
.58294 .69453 Mdot
.49335 .62074 Mdot
.2422 .67943 Mdot
.58513 .4689 Mdot
.71721 .35347 Mdot
.58337 .70582 Mdot
.42309 .3623 Mdot
.57371 .435 Mdot
.40871 .6688 Mdot
.59664 .7072 Mdot
.59539 .671 Mdot
.58447 .43779 Mdot
.41914 .37022 Mdot
.48865 .64902 Mdot
.34148 .45616 Mdot
.56695 .68916 Mdot
.6706 .39757 Mdot
.57018 .49624 Mdot
.65414 .46544 Mdot
.47451 .49681 Mdot
.7435 .45213 Mdot
.31158 .5011 Mdot
.74874 .63225 Mdot
.44589 .64543 Mdot
.38726 .71834 Mdot
.21821 .51663 Mdot
.33251 .43094 Mdot
.36973 .6423 Mdot
.35751 .64714 Mdot
.59471 .43923 Mdot
.74487 .45434 Mdot
.32585 .74794 Mdot
.25625 .503 Mdot
.36829 .6602 Mdot
.46737 .6548 Mdot
.39197 .37097 Mdot
.20075 .42834 Mdot
.56646 .49693 Mdot
.29757 .50919 Mdot
.45615 .63989 Mdot
.74354 .34938 Mdot
.60369 .70401 Mdot
.22788 .63885 Mdot
.62298 .41301 Mdot
.56656 .46864 Mdot
.31621 .49644 Mdot
.35137 .49976 Mdot
.32289 .62909 Mdot
.20792 .47296 Mdot
.65737 .6683 Mdot
.35141 .28899 Mdot
.73295 .34038 Mdot
.38482 .36469 Mdot
.40591 .3236 Mdot
.38273 .66309 Mdot
.35762 .49952 Mdot
.61693 .47964 Mdot
.44069 .31319 Mdot
.31193 .6558 Mdot
.4839 .34648 Mdot
.69521 .60677 Mdot
.52501 .76856 Mdot
.64038 .43073 Mdot
.40608 .3329 Mdot
.45588 .34424 Mdot
.45757 .3245 Mdot
.38772 .65354 Mdot
.58747 .4557 Mdot
.56321 .42575 Mdot
.56523 .47304 Mdot
.64145 .37833 Mdot
.6339 .45375 Mdot
.24906 .46022 Mdot
.49544 .54692 Mdot
.78056 .46137 Mdot
.56008 .47994 Mdot
.33193 .51653 Mdot
.65022 .47519 Mdot
.59805 .67431 Mdot
.5925 .42554 Mdot
.69546 .59928 Mdot
.32523 .48371 Mdot
.62364 .53411 Mdot
.34868 .28832 Mdot
.61517 .41038 Mdot
.62343 .68639 Mdot
.73679 .47931 Mdot
.42543 .223 Mdot
.52552 .59848 Mdot
.42134 .32704 Mdot
.51595 .66083 Mdot
.30943 .46873 Mdot
.48456 .64527 Mdot
.55455 .4651 Mdot
.37909 .66313 Mdot
.31249 .42258 Mdot
.40567 .45125 Mdot
.62724 .47647 Mdot
.64477 .50864 Mdot
.41413 .33543 Mdot
.50739 .64868 Mdot
.38041 .31976 Mdot
.62314 .46716 Mdot
.59601 .69274 Mdot
.60255 .71 Mdot
.22523 .46034 Mdot
.75326 .3302 Mdot
.32759 .28165 Mdot
.31473 .49731 Mdot
.46691 .66667 Mdot
.572 .67085 Mdot
.69842 .41579 Mdot
.30489 .5207 Mdot
.29629 .49674 Mdot
.33689 .49855 Mdot
.63967 .43925 Mdot
.36507 .64209 Mdot
.7621 .43308 Mdot
.37038 .63977 Mdot
.61047 .41035 Mdot
.44977 .65499 Mdot
.34928 .65406 Mdot
.58725 .70394 Mdot
.30786 .47726 Mdot
.46085 .63119 Mdot
.63298 .4447 Mdot
.4443 .36309 Mdot
.56007 .58092 Mdot
.65797 .57221 Mdot
.80606 .56178 Mdot
.81134 .54357 Mdot
.39344 .35426 Mdot
.79086 .37586 Mdot
.35468 .44633 Mdot
.52864 .22507 Mdot
.53887 .69555 Mdot
.59472 .497 Mdot
.17635 .53753 Mdot
.49705 .62614 Mdot
.50832 .65132 Mdot
.60949 .43922 Mdot
.42623 .6608 Mdot
.59235 .47467 Mdot
.45277 .63447 Mdot
.5298 .60797 Mdot
.56553 .49782 Mdot
.49937 .65849 Mdot
.65794 .40871 Mdot
.57776 .41805 Mdot
.40515 .35599 Mdot
.46855 .61679 Mdot
.55344 .45567 Mdot
.75536 .72675 Mdot
.3557 .49526 Mdot
.38626 .65473 Mdot
.59533 .6396 Mdot
.30418 .49811 Mdot
.44777 .34215 Mdot
.54214 .45912 Mdot
.58328 .6823 Mdot
.43339 .35808 Mdot
.54951 .65798 Mdot
.58823 .7108 Mdot
.19858 .56697 Mdot
.41601 .32921 Mdot
.37073 .65838 Mdot
.58015 .69566 Mdot
.63139 .5161 Mdot
.46963 .614 Mdot
.6363 .56266 Mdot
.38118 .64092 Mdot
.59643 .46083 Mdot
.44234 .6807 Mdot
.35771 .49441 Mdot
.5662 .45371 Mdot
.44535 .63145 Mdot
.39014 .64973 Mdot
.63374 .43424 Mdot
.59536 .43175 Mdot
.21829 .3813 Mdot
.29328 .69172 Mdot
.60144 .67975 Mdot
.42541 .38501 Mdot
.62342 .44433 Mdot
.57608 .68496 Mdot
.51331 .80848 Mdot
.65171 .46349 Mdot
.46326 .35947 Mdot
.52203 .40498 Mdot
.44177 .64893 Mdot
.31226 .47552 Mdot
.49937 .61426 Mdot
.586 .67154 Mdot
.18636 .66477 Mdot
.34898 .65917 Mdot
.6318 .3963 Mdot
.59551 .4901 Mdot
.36355 .67823 Mdot
.45207 .3362 Mdot
.65758 .66453 Mdot
.61361 .46162 Mdot
.66494 .37912 Mdot
.57733 .47381 Mdot
.52195 .75294 Mdot
.41132 .35017 Mdot
.5961 .46667 Mdot
.59094 .54934 Mdot
.63939 .41265 Mdot
.60656 .67336 Mdot
.77525 .56296 Mdot
.64366 .47642 Mdot
.66945 .15902 Mdot
.38701 .63858 Mdot
.49711 .66107 Mdot
.40145 .67162 Mdot
.61155 .81154 Mdot
.31945 .27789 Mdot
.44028 .3203 Mdot
.43838 .42014 Mdot
.48662 .64736 Mdot
.35376 .25628 Mdot
.80716 .40276 Mdot
.58195 .41629 Mdot
.65004 .4427 Mdot
.49332 .62072 Mdot
.42849 .6685 Mdot
.36782 .6661 Mdot
.55196 .46177 Mdot
.59528 .5281 Mdot
.47351 .67169 Mdot
.64046 .45145 Mdot
.52153 .41871 Mdot
.34459 .45772 Mdot
.41012 .36993 Mdot
.33033 .47057 Mdot
.3045 .47582 Mdot
.57261 .27113 Mdot
.22096 .49049 Mdot
.35809 .48218 Mdot
.31943 .45228 Mdot
.68371 .60008 Mdot
.50389 .41402 Mdot
.58409 .66857 Mdot
.79517 .43417 Mdot
.4679 .64284 Mdot
.58554 .45524 Mdot
.39441 .33532 Mdot
.55234 .25042 Mdot
.38443 .57645 Mdot
.27421 .71716 Mdot
.62301 .47116 Mdot
.47308 .65427 Mdot
.38911 .64623 Mdot
.57114 .5009 Mdot
.40327 .72113 Mdot
.5622 .45981 Mdot
.48708 .61149 Mdot
.65316 .33013 Mdot
.53871 .53533 Mdot
.34646 .70746 Mdot
.4188 .29678 Mdot
.59197 .48476 Mdot
.43062 .32322 Mdot
.31954 .4769 Mdot
.58544 .67533 Mdot
.59866 .67968 Mdot
.58123 .43391 Mdot
.68781 .38465 Mdot
.39945 .53911 Mdot
.58148 .41516 Mdot
.58794 .4208 Mdot
.38214 .64792 Mdot
.58532 .42117 Mdot
.59181 .48969 Mdot
.56902 .47982 Mdot
.6229 .40176 Mdot
.32561 .52285 Mdot
.53998 .53887 Mdot
.55674 .41022 Mdot
.52222 .43547 Mdot
.35277 .45727 Mdot
.40842 .4142 Mdot
.31488 .46893 Mdot
.74544 .29807 Mdot
.34208 .47251 Mdot
.61142 .68661 Mdot
.48511 .68421 Mdot
.54014 .37708 Mdot
.43656 .30678 Mdot
.326 .52652 Mdot
.60697 .69429 Mdot
.31017 .49097 Mdot
.45047 .66041 Mdot
.44086 .17672 Mdot
.48331 .34548 Mdot
.63616 .64104 Mdot
.29352 .54351 Mdot
.28321 .66009 Mdot
.489 .62664 Mdot
.4079 .35128 Mdot
.68976 .30181 Mdot
.55698 .46042 Mdot
.58195 .70011 Mdot
.58839 .43961 Mdot
.3218 .52394 Mdot
.47017 .65046 Mdot
.77772 .60788 Mdot
.59025 .67862 Mdot
.24287 .32341 Mdot
.46237 .64995 Mdot
.5531 .43222 Mdot
.29881 .51081 Mdot
.31855 .2281 Mdot
.33399 .46832 Mdot
.57472 .59082 Mdot
.46252 .3736 Mdot
.50503 .34939 Mdot
.43406 .34348 Mdot
.32941 .64049 Mdot
.56947 .14586 Mdot
.82653 .50193 Mdot
.43649 .36593 Mdot
.36527 .73437 Mdot
.64606 .43926 Mdot
.65307 .46952 Mdot
.56252 .54016 Mdot
.45837 .3728 Mdot
.62873 .4489 Mdot
.38402 .64427 Mdot
.25437 .39663 Mdot
.4211 .74627 Mdot
.51486 .66092 Mdot
.59934 .47417 Mdot
.35401 .4594 Mdot
.31495 .45864 Mdot
.35387 .64702 Mdot
.32229 .46435 Mdot
.56194 .42872 Mdot
.43379 .34712 Mdot
.39371 .45226 Mdot
.58786 .68997 Mdot
.77284 .68 Mdot
.58294 .66423 Mdot
.4095 .65747 Mdot
.58715 .52173 Mdot
.49349 .6474 Mdot
.32108 .81821 Mdot
.55897 .44065 Mdot
.45364 .36072 Mdot
.61097 .43212 Mdot
.58252 .4821 Mdot
.65566 .46638 Mdot
.45991 .67115 Mdot
.6515 .70662 Mdot
.6393 .44942 Mdot
.331 .49935 Mdot
.80187 .48836 Mdot
.64905 .47945 Mdot
.525 .60561 Mdot
.73699 .58951 Mdot
.25591 .63237 Mdot
.44523 .3068 Mdot
.50546 .64994 Mdot
.44872 .35086 Mdot
.40847 .30552 Mdot
.44784 .34194 Mdot
.76587 .42432 Mdot
.68458 .31084 Mdot
.47175 .85269 Mdot
.5403 .35809 Mdot
.51751 .24352 Mdot
.42213 .38712 Mdot
.50118 .82309 Mdot
.41803 .31364 Mdot
.44545 .32935 Mdot
.88254 .60131 Mdot
.41678 .31162 Mdot
.60778 .47117 Mdot
.62825 .50188 Mdot
.31062 .38969 Mdot
.6649 .61049 Mdot
.57878 .42663 Mdot
.6178 .4414 Mdot
.57984 .68032 Mdot
.71657 .41261 Mdot
.36823 .66784 Mdot
.19716 .56154 Mdot
.34512 .35879 Mdot
.58728 .43781 Mdot
.62553 .44329 Mdot
.65991 .48651 Mdot
.49874 .12101 Mdot
.58645 .2585 Mdot
.40823 .38388 Mdot
.67151 .48324 Mdot
.81243 .61375 Mdot
.57032 .41634 Mdot
.64906 .45864 Mdot
.6353 .42863 Mdot
.48519 .64765 Mdot
.40432 .38578 Mdot
.66986 .48493 Mdot
.23229 .59302 Mdot
.63634 .42107 Mdot
.3057 .43823 Mdot
.66284 .72603 Mdot
.60246 .46965 Mdot
.46928 .34284 Mdot
.61132 .42424 Mdot
.41635 .32663 Mdot
.40348 .35841 Mdot
.65715 .48964 Mdot
.7633 .38841 Mdot
.46548 .36025 Mdot
.61826 .41297 Mdot
.49473 .65482 Mdot
.83183 .48761 Mdot
.599 .46144 Mdot
.62317 .69478 Mdot
.61604 .46114 Mdot
.628 .69427 Mdot
.59183 .41616 Mdot
.37632 .63965 Mdot
.54595 .20987 Mdot
.47567 .64162 Mdot
.68047 .72592 Mdot
.44742 .67424 Mdot
.21725 .38387 Mdot
.46239 .35702 Mdot
.39597 .65169 Mdot
.24411 .70372 Mdot
.38181 .65138 Mdot
.53464 .54899 Mdot
.50495 .57053 Mdot
.32334 .51387 Mdot
.4374 .3768 Mdot
.73488 .64575 Mdot
.33569 .67428 Mdot
.49803 .69011 Mdot
.49175 .67718 Mdot
.18487 .64289 Mdot
.20893 .64873 Mdot
.63637 .4434 Mdot
.72728 .3712 Mdot
.51928 .31587 Mdot
.65099 .46149 Mdot
.542 .44245 Mdot
.46303 .61516 Mdot
.60641 .4891 Mdot
.46712 .47496 Mdot
.48354 .62918 Mdot
.61174 .699 Mdot
.43962 .32683 Mdot
.63042 .70414 Mdot
.41433 .68096 Mdot
.52036 .56956 Mdot
.45324 .63755 Mdot
.63461 .40591 Mdot
.6147 .43446 Mdot
.40365 .34397 Mdot
.37602 .31562 Mdot
.40713 .36613 Mdot
.60638 .72095 Mdot
.47654 .63191 Mdot
.57496 .24844 Mdot
.61085 .44569 Mdot
.42758 .35077 Mdot
.36333 .52902 Mdot
.61821 .44606 Mdot
.30852 .4864 Mdot
.64738 .4348 Mdot
.43792 .36774 Mdot
.58525 .42099 Mdot
.43569 .3474 Mdot
.50373 .63638 Mdot
.57866 .41118 Mdot
.60516 .4399 Mdot
.31069 .24071 Mdot
.60334 .68436 Mdot
.46173 .3587 Mdot
.4378 .52918 Mdot
.55133 .43678 Mdot
.36072 .68716 Mdot
.60702 .4828 Mdot
.48297 .4097 Mdot
.64899 .40407 Mdot
.38538 .64855 Mdot
.52925 .452 Mdot
.59824 .46206 Mdot
.60807 .55403 Mdot
.56043 .34172 Mdot
.37656 .32777 Mdot
.30714 .51651 Mdot
.47112 .3522 Mdot
.43937 .63242 Mdot
.42131 .6667 Mdot
.43422 .65204 Mdot
.65059 .62459 Mdot
.6571 .48854 Mdot
.5852 .46719 Mdot
.34927 .52131 Mdot
.61645 .70418 Mdot
.42204 .35558 Mdot
.61391 .7075 Mdot
.20196 .53409 Mdot
.60232 .71908 Mdot
.36056 .64299 Mdot
.51213 .76012 Mdot
.59331 .23997 Mdot
.57925 .68191 Mdot
.40837 .3679 Mdot
.51483 .77196 Mdot
.58893 .49568 Mdot
.55627 .65188 Mdot
.59591 .69433 Mdot
.16622 .61976 Mdot
.6198 .48254 Mdot
.52152 .5409 Mdot
.34611 .4658 Mdot
.59987 .71222 Mdot
.33719 .48798 Mdot
.57984 .42882 Mdot
.2733 .62925 Mdot
.44886 .32692 Mdot
.35489 .45263 Mdot
.54655 .41654 Mdot
.6186 .71531 Mdot
.45433 .64363 Mdot
.27168 .51057 Mdot
.33043 .51637 Mdot
.5324 .1928 Mdot
.77544 .59462 Mdot
.47891 .63109 Mdot
.33085 .73994 Mdot
.34335 .49344 Mdot
.64906 .4658 Mdot
.60761 .36818 Mdot
.55726 .43662 Mdot
.41963 .67402 Mdot
.50569 .65139 Mdot
.27406 .39882 Mdot
.61708 .4332 Mdot
.61428 .48327 Mdot
.46299 .3857 Mdot
.49406 .63246 Mdot
.42434 .33568 Mdot
.45348 .31865 Mdot
.50643 .63739 Mdot
.43575 .3382 Mdot
.58482 .70614 Mdot
.26414 .37023 Mdot
.34435 .49331 Mdot
.32888 .49602 Mdot
.46706 .65364 Mdot
.48725 .66867 Mdot
.49555 .64585 Mdot
.64719 .43436 Mdot
.41608 .35479 Mdot
.61944 .41911 Mdot
.65554 .45606 Mdot
.4226 .29291 Mdot
.41329 .31151 Mdot
.62346 .42557 Mdot
.35286 .70305 Mdot
.58105 .71984 Mdot
.49142 .66194 Mdot
.35466 .47344 Mdot
.37718 .25417 Mdot
.36188 .51104 Mdot
.59938 .47626 Mdot
.28553 .55474 Mdot
.42989 .36759 Mdot
.5833 .69734 Mdot
.62714 .74065 Mdot
.58328 .68716 Mdot
.31283 .53133 Mdot
.45402 .32469 Mdot
.19947 .56415 Mdot
.59505 .47391 Mdot
.47167 .49375 Mdot
.74301 .63614 Mdot
.2148 .54068 Mdot
.35802 .47956 Mdot
.62023 .44417 Mdot
.3797 .65474 Mdot
.66178 .27695 Mdot
.56493 .46414 Mdot
.56239 .47601 Mdot
.5205 .72157 Mdot
.52049 .44005 Mdot
.46335 .36985 Mdot
.20109 .46245 Mdot
.634 .49852 Mdot
.46972 .30948 Mdot
.6456 .82492 Mdot
.59797 .48078 Mdot
.62783 .4633 Mdot
.60004 .45288 Mdot
.60516 .42854 Mdot
.47307 .3598 Mdot
.69462 .65396 Mdot
.3 .51279 Mdot
.48349 .51877 Mdot
.34432 .49869 Mdot
.48685 .61256 Mdot
.5056 .51607 Mdot
.42238 .37665 Mdot
.58195 .69602 Mdot
.59998 .21218 Mdot
.20405 .49698 Mdot
.4809 .6235 Mdot
.63199 .28697 Mdot
.59179 .68911 Mdot
.5961 .49829 Mdot
.63339 .71561 Mdot
.43182 .67059 Mdot
.33197 .50619 Mdot
.61511 .50441 Mdot
.39649 .34043 Mdot
.43495 .37292 Mdot
.62503 .44863 Mdot
.81655 .58868 Mdot
.30866 .48358 Mdot
.37673 .47844 Mdot
.64082 .4377 Mdot
.5613 .47475 Mdot
.42824 .33203 Mdot
.48456 .65974 Mdot
.41838 .79166 Mdot
.60825 .69004 Mdot
.5711 .40907 Mdot
.6013 .42692 Mdot
.21664 .48741 Mdot
.30024 .48762 Mdot
.3584 .66033 Mdot
.63687 .43787 Mdot
.22998 .47569 Mdot
.63543 .43656 Mdot
.55215 .49279 Mdot
.49221 .65172 Mdot
.66759 .42769 Mdot
.64474 .45892 Mdot
.6799 .4764 Mdot
.34155 .49051 Mdot
.4554 .35289 Mdot
.47226 .37554 Mdot
.37683 .66253 Mdot
.30964 .4857 Mdot
.61893 .42509 Mdot
.30141 .48964 Mdot
.65018 .47138 Mdot
.63703 .45077 Mdot
.3576 .48113 Mdot
.42494 .33562 Mdot
.36812 .41835 Mdot
.53227 .53671 Mdot
.60975 .42974 Mdot
.57716 .49999 Mdot
.66024 .62212 Mdot
.32555 .78742 Mdot
.61975 .47332 Mdot
.43762 .36987 Mdot
.61076 .44297 Mdot
.33221 .48191 Mdot
.60434 .71857 Mdot
.44194 .36542 Mdot
.47105 .66296 Mdot
.50161 .62904 Mdot
.34769 .28718 Mdot
.35275 .64946 Mdot
.56492 .49258 Mdot
.47483 .39943 Mdot
.39712 .32758 Mdot
.71112 .76459 Mdot
.51131 .64121 Mdot
.59903 .66934 Mdot
.59043 .43104 Mdot
.29906 .55293 Mdot
.34501 .52364 Mdot
.662 .15195 Mdot
.20071 .56775 Mdot
.58622 .66256 Mdot
.26602 .71428 Mdot
.37238 .65543 Mdot
.63796 .4706 Mdot
.58866 .67409 Mdot
.47277 .62131 Mdot
.61909 .49176 Mdot
.59143 .38369 Mdot
.64403 .65458 Mdot
.51076 .61119 Mdot
.30423 .48373 Mdot
.43761 .6512 Mdot
.62146 .73013 Mdot
.36239 .64224 Mdot
.42448 .3744 Mdot
.59434 .46305 Mdot
.66382 .4851 Mdot
.47862 .66293 Mdot
.37595 .63927 Mdot
.63948 .42906 Mdot
.44494 .37342 Mdot
.42911 .65548 Mdot
.57989 .43746 Mdot
.52887 .23035 Mdot
.40627 .3022 Mdot
.46659 .63681 Mdot
.59121 .4885 Mdot
.50501 .39933 Mdot
.46722 .6579 Mdot
.48686 .66532 Mdot
.62869 .44836 Mdot
.58095 .7007 Mdot
.64395 .42506 Mdot
.3454 .47204 Mdot
.65299 .70703 Mdot
.33142 .48463 Mdot
.5788 .72862 Mdot
.56062 .50852 Mdot
.29409 .6599 Mdot
.40387 .36906 Mdot
.62092 .73224 Mdot
.39507 .23126 Mdot
.56344 .48034 Mdot
.78107 .37112 Mdot
.41194 .4495 Mdot
.80549 .6534 Mdot
.57967 .16945 Mdot
.5992 .69791 Mdot
.31264 .48541 Mdot
.62738 .46273 Mdot
.36479 .49109 Mdot
.59633 .67625 Mdot
.74966 .64046 Mdot
.58728 .48854 Mdot
.41117 .3474 Mdot
.63785 .42306 Mdot
.42148 .3266 Mdot
.61844 .44789 Mdot
.5212 .44123 Mdot
.5262 .68108 Mdot
.57994 .59591 Mdot
.59106 .49684 Mdot
.43833 .17551 Mdot
.4029 .55856 Mdot
.59848 .68956 Mdot
.61893 .41577 Mdot
.36373 .649 Mdot
.30512 .46632 Mdot
.7217 .48263 Mdot
.48935 .64769 Mdot
.35813 .47057 Mdot
.43799 .33342 Mdot
.51429 .64752 Mdot
.39143 .64524 Mdot
.68214 .44188 Mdot
.62125 .68545 Mdot
.31829 .51268 Mdot
.60022 .46512 Mdot
.61944 .48204 Mdot
.38906 .75112 Mdot
.37604 .59691 Mdot
.41979 .39323 Mdot
.26431 .28731 Mdot
.47205 .34058 Mdot
.61421 .69205 Mdot
.49354 .65016 Mdot
.61665 .47522 Mdot
.5652 .44911 Mdot
.41857 .6667 Mdot
.46121 .35727 Mdot
.50069 .6106 Mdot
.59713 .27657 Mdot
.50094 .66695 Mdot
.71067 .6272 Mdot
.45061 .36518 Mdot
.7071 .63017 Mdot
.62302 .73036 Mdot
.74877 .34095 Mdot
.69488 .56268 Mdot
.34515 .46509 Mdot
.71493 .62541 Mdot
.42483 .36282 Mdot
.62775 .43842 Mdot
.36845 .65675 Mdot
.35154 .6546 Mdot
.43493 .32783 Mdot
.48976 .6187 Mdot
.60026 .71136 Mdot
.63134 .46199 Mdot
.24555 .64214 Mdot
.31272 .3504 Mdot
.46961 .66773 Mdot
.52867 .41628 Mdot
.336 .49352 Mdot
.64039 .46304 Mdot
.62595 .7003 Mdot
.31733 .50883 Mdot
.35587 .63576 Mdot
.26231 .39067 Mdot
.57907 .43218 Mdot
.21363 .46393 Mdot
.30694 .49567 Mdot
.3408 .76008 Mdot
.58267 .44326 Mdot
.34323 .49329 Mdot
.52769 .47719 Mdot
.22606 .55504 Mdot
.42908 .49307 Mdot
.81386 .41885 Mdot
.52062 .61699 Mdot
.49458 .62295 Mdot
.26843 .58742 Mdot
.48829 .70071 Mdot
.35981 .46943 Mdot
.36407 .64154 Mdot
.75168 .53364 Mdot
.3384 .48977 Mdot
.65246 .44626 Mdot
.60438 .48206 Mdot
.56642 .26599 Mdot
.44482 .49099 Mdot
.36869 .63921 Mdot
.29978 .3006 Mdot
.5521 .44166 Mdot
.59553 .39179 Mdot
.56935 .45221 Mdot
.40492 .37793 Mdot
.30517 .50503 Mdot
.34739 .2147 Mdot
.31459 .47767 Mdot
.24852 .65981 Mdot
.46814 .64349 Mdot
.48689 .67049 Mdot
.60247 .47221 Mdot
.30653 .67957 Mdot
.74185 .44043 Mdot
.56602 .42287 Mdot
.36658 .69603 Mdot
.77894 .58501 Mdot
.55224 .40779 Mdot
.46148 .37672 Mdot
.62163 .50971 Mdot
.38338 .33099 Mdot
.33689 .51077 Mdot
.59977 .70374 Mdot
.56873 .6986 Mdot
.3209 .51219 Mdot
.58367 .46563 Mdot
.38761 .69601 Mdot
.5723 .47266 Mdot
.63593 .44059 Mdot
.2229 .63718 Mdot
.574 .66812 Mdot
.49816 .64332 Mdot
.59517 .67892 Mdot
.44618 .32946 Mdot
.91027 .4371 Mdot
.61623 .70937 Mdot
.5975 .36071 Mdot
.70049 .6924 Mdot
.71284 .62881 Mdot
.43595 .37386 Mdot
.59863 .72278 Mdot
.3118 .47687 Mdot
.82873 .62811 Mdot
.35032 .7979 Mdot
.37075 .48664 Mdot
.57617 .44281 Mdot
.41505 .37634 Mdot
.39554 .35665 Mdot
.35676 .45105 Mdot
.41028 .3629 Mdot
.60388 .52757 Mdot
.62283 .4329 Mdot
.36018 .47102 Mdot
.31181 .37594 Mdot
.32757 .51721 Mdot
.25057 .38085 Mdot
.6274 .41866 Mdot
.44786 .36506 Mdot
.624 .51288 Mdot
.48547 .35925 Mdot
.35588 .6629 Mdot
.62291 .49137 Mdot
.59123 .70667 Mdot
.455 .48055 Mdot
.46842 .63753 Mdot
.29314 .55867 Mdot
.40522 .34174 Mdot
.38124 .45385 Mdot
.40512 .3571 Mdot
.42193 .38038 Mdot
.30488 .47482 Mdot
.43824 .31527 Mdot
.62884 .46356 Mdot
.35944 .72153 Mdot
.41637 .32346 Mdot
.31918 .49098 Mdot
.59051 .70035 Mdot
.43181 .33716 Mdot
.46982 .61108 Mdot
.59959 .435 Mdot
.44844 .63989 Mdot
.52951 .68013 Mdot
.44313 .37632 Mdot
.5963 .72076 Mdot
.50454 .6559 Mdot
.6103 .67766 Mdot
.77054 .63196 Mdot
.35431 .50485 Mdot
.28017 .72061 Mdot
.50698 .43622 Mdot
.39624 .33884 Mdot
.52989 .67663 Mdot
.61566 .47363 Mdot
.59885 .43359 Mdot
.60681 .72843 Mdot
.39475 .35504 Mdot
.83174 .51326 Mdot
.46571 .41209 Mdot
.26723 .37513 Mdot
.34165 .51866 Mdot
.27685 .29156 Mdot
.24911 .42849 Mdot
.68936 .75047 Mdot
.66726 .41342 Mdot
.37168 .65534 Mdot
.58539 .47465 Mdot
.40703 .22311 Mdot
.61406 .7192 Mdot
.43473 .81569 Mdot
.66548 .46315 Mdot
.4922 .6392 Mdot
.59424 .44645 Mdot
.67186 .53081 Mdot
.60757 .51318 Mdot
.57626 .69312 Mdot
.28026 .45377 Mdot
.4379 .3079 Mdot
.58903 .68924 Mdot
.50038 .62966 Mdot
.75658 .56179 Mdot
.6147 .49282 Mdot
.54832 .44781 Mdot
.49498 .67111 Mdot
.40935 .35158 Mdot
.47785 .61251 Mdot
.34422 .49375 Mdot
.60843 .70727 Mdot
.59421 .42921 Mdot
.64208 .40486 Mdot
.3726 .68687 Mdot
.30526 .50675 Mdot
.50144 .6635 Mdot
.3283 .46985 Mdot
.37097 .65608 Mdot
.5978 .5023 Mdot
.4797 .67313 Mdot
.62796 .48109 Mdot
.36035 .2321 Mdot
.23054 .64825 Mdot
.58462 .33706 Mdot
.49912 .63986 Mdot
.71478 .60525 Mdot
.32633 .48133 Mdot
.33854 .47134 Mdot
.49057 .3236 Mdot
.73958 .47061 Mdot
.54116 .76138 Mdot
.54693 .19087 Mdot
.34475 .49381 Mdot
.32942 .48835 Mdot
.46203 .62392 Mdot
.4342 .31573 Mdot
.3845 .34358 Mdot
.51436 .63563 Mdot
.59313 .60501 Mdot
.42217 .35547 Mdot
.78584 .38521 Mdot
.44216 .62881 Mdot
.66438 .40732 Mdot
.3733 .67063 Mdot
.60205 .70847 Mdot
.58835 .60151 Mdot
.67069 .52936 Mdot
.62125 .47688 Mdot
.19878 .44794 Mdot
.48326 .65683 Mdot
.6759 .66232 Mdot
.74007 .29303 Mdot
.58163 .48761 Mdot
.5848 .45206 Mdot
.57861 .46388 Mdot
.56893 .67008 Mdot
.4187 .23433 Mdot
.6242 .47686 Mdot
.59122 .60941 Mdot
.55139 .42868 Mdot
.66727 .55799 Mdot
.59858 .67941 Mdot
.41999 .27529 Mdot
.52488 .62763 Mdot
.21748 .57354 Mdot
.55729 .53669 Mdot
.34254 .48294 Mdot
.52461 .67297 Mdot
.33928 .50584 Mdot
.75387 .41126 Mdot
.69632 .56463 Mdot
.43645 .38976 Mdot
.62498 .47108 Mdot
.47907 .68001 Mdot
.40423 .36639 Mdot
.32813 .67508 Mdot
.90074 .56138 Mdot
.30462 .51014 Mdot
.34403 .82355 Mdot
.33591 .46987 Mdot
.35275 .66045 Mdot
.43021 .33094 Mdot
.67699 .31462 Mdot
.47109 .49194 Mdot
.43334 .3388 Mdot
.32906 .41915 Mdot
.47008 .33134 Mdot
.71813 .61188 Mdot
.43047 .30108 Mdot
.32064 .4868 Mdot
.2968 .53177 Mdot
.62627 .39065 Mdot
.61249 .46897 Mdot
.52694 .57022 Mdot
.52501 .3814 Mdot
.61531 .47012 Mdot
.48394 .62932 Mdot
.32398 .75694 Mdot
.52499 .66491 Mdot
.41269 .3201 Mdot
.30038 .50937 Mdot
.58649 .45065 Mdot
.62081 .43017 Mdot
.63582 .47961 Mdot
.29574 .24645 Mdot
.78703 .39665 Mdot
.63775 .44812 Mdot
.58443 .40475 Mdot
.50261 .63676 Mdot
.64384 .72742 Mdot
.47924 .18053 Mdot
.7386 .53975 Mdot
.55859 .45381 Mdot
.59748 .68157 Mdot
.58621 .66565 Mdot
.60876 .49541 Mdot
.25215 .63655 Mdot
.35512 .72374 Mdot
.60026 .46472 Mdot
.69766 .54557 Mdot
.43259 .68648 Mdot
.35392 .64653 Mdot
.47661 .66203 Mdot
.46567 .33552 Mdot
.37195 .64211 Mdot
.43854 .6705 Mdot
.66899 .30187 Mdot
.38029 .66152 Mdot
.24405 .48104 Mdot
.60654 .721 Mdot
.56605 .45476 Mdot
.47668 .35174 Mdot
.41943 .67012 Mdot
.32389 .51327 Mdot
.44167 .35614 Mdot
.30657 .46421 Mdot
.6141 .6705 Mdot
.64888 .64363 Mdot
.34953 .65599 Mdot
.34613 .48618 Mdot
.26103 .39136 Mdot
.59781 .6809 Mdot
.32251 .46533 Mdot
.30938 .67136 Mdot
.65013 .48152 Mdot
.72137 .32863 Mdot
.58565 .41168 Mdot
.82109 .60706 Mdot
.31803 .46863 Mdot
.38989 .65569 Mdot
.58867 .46684 Mdot
.46287 .6508 Mdot
.54395 .49713 Mdot
.56094 .45713 Mdot
.46351 .66184 Mdot
.63483 .44244 Mdot
.62339 .69312 Mdot
.39625 .30921 Mdot
.39006 .43573 Mdot
.15079 .4646 Mdot
.62029 .68576 Mdot
.32582 .67494 Mdot
.62093 .4727 Mdot
.7778 .604 Mdot
.4306 .33848 Mdot
.57362 .48587 Mdot
.44629 .27859 Mdot
.4297 .31888 Mdot
.4461 .35 Mdot
.59899 .41935 Mdot
.33813 .46496 Mdot
.46118 .64562 Mdot
.59345 .68037 Mdot
.71968 .74164 Mdot
.56956 .44014 Mdot
.60766 .4413 Mdot
.59071 .68945 Mdot
.33074 .48642 Mdot
.61727 .42877 Mdot
.33863 .57573 Mdot
.77128 .70606 Mdot
.29498 .4901 Mdot
.65763 .47049 Mdot
.66451 .25455 Mdot
.48525 .37125 Mdot
.33568 .80699 Mdot
.58814 .73124 Mdot
.5036 .6508 Mdot
.52102 .44359 Mdot
.75104 .23454 Mdot
.59852 .70438 Mdot
.20936 .56962 Mdot
.64263 .44669 Mdot
.60719 .44895 Mdot
.42087 .36864 Mdot
.62014 .42184 Mdot
.45797 .34415 Mdot
.14724 .52048 Mdot
.20598 .35762 Mdot
.40888 .34099 Mdot
.40579 .32274 Mdot
.49907 .35521 Mdot
.4624 .18832 Mdot
.44071 .33058 Mdot
.6607 .46276 Mdot
.80949 .47471 Mdot
.68122 .42735 Mdot
.60343 .72784 Mdot
.53187 .68185 Mdot
.40204 .27734 Mdot
.41562 .62475 Mdot
.42087 .41284 Mdot
.58141 .54032 Mdot
.38435 .55072 Mdot
.35019 .47577 Mdot
.56128 .46757 Mdot
.35106 .65172 Mdot
.43288 .65963 Mdot
.59497 .51243 Mdot
.56622 .46111 Mdot
.41912 .3255 Mdot
.56826 .67818 Mdot
.31161 .46509 Mdot
.61707 .44108 Mdot
.49159 .60538 Mdot
.61192 .69576 Mdot
.41137 .32346 Mdot
.50467 .3546 Mdot
.57929 .6721 Mdot
.52857 .45649 Mdot
.6146 .45871 Mdot
.63982 .43043 Mdot
.51842 .47423 Mdot
.34917 .5042 Mdot
.41395 .67597 Mdot
.65853 .44492 Mdot
.2036 .53014 Mdot
.55686 .59209 Mdot
.65906 .4192 Mdot
.41893 .36054 Mdot
.33978 .52578 Mdot
.36144 .66359 Mdot
.76019 .58654 Mdot
.57364 .43444 Mdot
.78612 .39987 Mdot
.58909 .26392 Mdot
.37273 .64308 Mdot
.42993 .38685 Mdot
.58234 .69446 Mdot
.56168 .43048 Mdot
.78831 .45212 Mdot
.60327 .48067 Mdot
.50694 .41385 Mdot
.49273 .65722 Mdot
.35234 .47799 Mdot
.79703 .67205 Mdot
.43422 .66161 Mdot
.448 .35066 Mdot
.81918 .41575 Mdot
.38923 .3526 Mdot
.44062 .31139 Mdot
.76208 .39709 Mdot
.34953 .50118 Mdot
.73173 .21509 Mdot
.34282 .79906 Mdot
.65203 .42501 Mdot
.33079 .47775 Mdot
.42284 .32994 Mdot
.63995 .46281 Mdot
.40147 .32397 Mdot
.45113 .32527 Mdot
.63063 .48889 Mdot
.6123 .45427 Mdot
.52945 .53697 Mdot
.76652 .33769 Mdot
.58196 .68649 Mdot
.45506 .36631 Mdot
.51495 .2514 Mdot
.62913 .47528 Mdot
.59517 .47341 Mdot
.3515 .68054 Mdot
.57638 .6915 Mdot
.63851 .54143 Mdot
.63661 .4388 Mdot
.20729 .38429 Mdot
.58226 .50183 Mdot
.46998 .37016 Mdot
.29524 .48919 Mdot
.24232 .62283 Mdot
.4171 .67282 Mdot
.45992 .36485 Mdot
.62609 .71254 Mdot
.46272 .38426 Mdot
.57949 .36003 Mdot
.344 .50573 Mdot
.43788 .36774 Mdot
.49696 .61566 Mdot
.32215 .50499 Mdot
.32192 .46612 Mdot
.80233 .48722 Mdot
.51084 .6554 Mdot
.61387 .72282 Mdot
.33516 .50398 Mdot
.52485 .22473 Mdot
.31569 .48837 Mdot
.53423 .25993 Mdot
.58839 .40803 Mdot
.6138 .62224 Mdot
.25888 .43283 Mdot
.5172 .44758 Mdot
.34946 .50708 Mdot
.5936 .67679 Mdot
.59982 .42309 Mdot
.41195 .36443 Mdot
.6146 .71024 Mdot
.27908 .47056 Mdot
.48711 .66725 Mdot
.40109 .35136 Mdot
.29854 .51177 Mdot
.45434 .36445 Mdot
.72453 .65119 Mdot
.64761 .68085 Mdot
.34777 .55822 Mdot
.48618 .50826 Mdot
.64062 .47466 Mdot
.36143 .31916 Mdot
.5682 .49609 Mdot
.56614 .4642 Mdot
.46613 .63746 Mdot
.65058 .62587 Mdot
.42476 .33505 Mdot
.79827 .67456 Mdot
.34848 .48361 Mdot
.19514 .4218 Mdot
.49712 .39955 Mdot
.55752 .46593 Mdot
.41945 .3222 Mdot
.38932 .33503 Mdot
.56439 .34234 Mdot
.42609 .65053 Mdot
.5627 .39117 Mdot
.54062 .47863 Mdot
.63531 .39512 Mdot
.31816 .46903 Mdot
.29026 .56571 Mdot
.48558 .61539 Mdot
.48565 .86144 Mdot
.48811 .66215 Mdot
.46951 .72999 Mdot
.43615 .31359 Mdot
.60477 .71728 Mdot
.59654 .47216 Mdot
.49685 .4263 Mdot
.44768 .382 Mdot
.63117 .74253 Mdot
.58799 .70534 Mdot
.25323 .5624 Mdot
.3578 .48473 Mdot
.59899 .49526 Mdot
.59883 .4885 Mdot
.6146 .41662 Mdot
.60057 .40822 Mdot
.30074 .50606 Mdot
.65202 .44999 Mdot
.36195 .46707 Mdot
.54286 .2295 Mdot
.20013 .39168 Mdot
.46132 .68114 Mdot
.72961 .4752 Mdot
.39854 .33979 Mdot
.49721 .22418 Mdot
.5485 .39068 Mdot
.2386 .66336 Mdot
.79365 .58285 Mdot
.549 .46686 Mdot
.47256 .61888 Mdot
.72878 .44101 Mdot
.46322 .67962 Mdot
.16658 .67814 Mdot
.41362 .69354 Mdot
.80212 .39571 Mdot
.63433 .46708 Mdot
.35461 .6805 Mdot
.54762 .3867 Mdot
.62199 .494 Mdot
.44659 .69791 Mdot
.27579 .31806 Mdot
.30562 .40359 Mdot
.58373 .66737 Mdot
.59233 .43554 Mdot
.42504 .30161 Mdot
.62995 .46455 Mdot
.5927 .47632 Mdot
.6465 .45331 Mdot
.29246 .49771 Mdot
.61895 .505 Mdot
.65082 .43854 Mdot
.39768 .5966 Mdot
.68772 .60776 Mdot
.43872 .65188 Mdot
.55735 .35697 Mdot
.61574 .70452 Mdot
.41155 .32996 Mdot
.47404 .45501 Mdot
.34714 .46545 Mdot
.52754 .33936 Mdot
.6451 .4299 Mdot
.26196 .42047 Mdot
.29912 .51263 Mdot
.60861 .71 Mdot
.37253 .66277 Mdot
.8212 .4661 Mdot
.44976 .67812 Mdot
.37803 .66273 Mdot
.46975 .63797 Mdot
.4322 .24351 Mdot
.42119 .32455 Mdot
.64117 .47581 Mdot
.33584 .49833 Mdot
.45793 .64686 Mdot
.65534 .61123 Mdot
.57099 .45538 Mdot
.49837 .63499 Mdot
.64515 .47055 Mdot
.63327 .6384 Mdot
.39491 .75823 Mdot
.45614 .67681 Mdot
.29536 .52319 Mdot
.32223 .50094 Mdot
.58766 .7093 Mdot
.40709 .33311 Mdot
.42628 .36678 Mdot
.31699 .50774 Mdot
.29294 .76678 Mdot
.56078 .45914 Mdot
.63687 .46679 Mdot
.20502 .52692 Mdot
.622 .46294 Mdot
.74918 .57948 Mdot
.35583 .66842 Mdot
.40413 .33275 Mdot
.64229 .4583 Mdot
.61214 .42886 Mdot
.58445 .43127 Mdot
.71987 .65566 Mdot
.48167 .66347 Mdot
.55391 .43887 Mdot
.57758 .68037 Mdot
.32863 .6284 Mdot
.63559 .47022 Mdot
.61238 .39234 Mdot
.43008 .36547 Mdot
.19635 .37653 Mdot
.34511 .46878 Mdot
.48185 .62632 Mdot
.5004 .66016 Mdot
.52734 .69109 Mdot
.41598 .2927 Mdot
.36526 .66789 Mdot
.61099 .8028 Mdot
.38627 .65251 Mdot
.5956 .68655 Mdot
.55326 .72299 Mdot
.45539 .61044 Mdot
.46831 .62534 Mdot
.32778 .45137 Mdot
.63607 .42039 Mdot
.55529 .43308 Mdot
.20927 .57929 Mdot
.55097 .44902 Mdot
.58861 .70213 Mdot
.35704 .46048 Mdot
.42704 .36103 Mdot
.60538 .71135 Mdot
.33188 .47131 Mdot
.40975 .35394 Mdot
.64562 .48555 Mdot
.65101 .48323 Mdot
.44219 .35246 Mdot
.40613 .36708 Mdot
.60512 .46456 Mdot
.35132 .59244 Mdot
.45539 .31979 Mdot
.44345 .36762 Mdot
.34753 .65398 Mdot
.45842 .68017 Mdot
.67475 .47428 Mdot
.32871 .476 Mdot
.64099 .43364 Mdot
.4635 .68042 Mdot
.57691 .69965 Mdot
.42481 .34004 Mdot
.61452 .43035 Mdot
.62012 .43794 Mdot
.59273 .68172 Mdot
.5726 .67408 Mdot
.60448 .71307 Mdot
.36747 .47644 Mdot
.59646 .41213 Mdot
.44225 .33372 Mdot
.35557 .48989 Mdot
.58662 .6657 Mdot
.6354 .71098 Mdot
.43561 .59236 Mdot
.61568 .47755 Mdot
.42524 .49896 Mdot
.8975 .41922 Mdot
.74961 .55319 Mdot
.35952 .66381 Mdot
.50262 .66701 Mdot
.6843 .63516 Mdot
.38212 .73766 Mdot
.30479 .49319 Mdot
.75636 .50175 Mdot
.61981 .73217 Mdot
.6435 .47635 Mdot
.57993 .50062 Mdot
.54117 .43973 Mdot
.6095 .70005 Mdot
.7377 .63204 Mdot
.39405 .35804 Mdot
.49283 .28142 Mdot
.6154 .7047 Mdot
.45359 .6762 Mdot
.47728 .67466 Mdot
.48887 .66187 Mdot
.61862 .50196 Mdot
.55234 .33878 Mdot
.50797 .23377 Mdot
.46166 .20012 Mdot
.35923 .4759 Mdot
.4069 .38881 Mdot
.77087 .62561 Mdot
.44396 .34895 Mdot
.43235 .66283 Mdot
.60845 .69578 Mdot
.43229 .37035 Mdot
.31471 .51447 Mdot
.33047 .4901 Mdot
.47859 .66627 Mdot
.4674 .65232 Mdot
.44827 .64395 Mdot
.45947 .32898 Mdot
.43759 .31477 Mdot
.56989 .43378 Mdot
.42993 .34652 Mdot
.18784 .47832 Mdot
.57692 .66243 Mdot
.46771 .67557 Mdot
.31417 .48219 Mdot
.41835 .32845 Mdot
.5675 .45004 Mdot
.54601 .74186 Mdot
.34045 .30551 Mdot
.6116 .67965 Mdot
.37652 .75209 Mdot
.20043 .71535 Mdot
.61014 .49079 Mdot
.30345 .48362 Mdot
.26319 .65915 Mdot
.57685 .46014 Mdot
.48527 .65006 Mdot
.38206 .22212 Mdot
.3864 .64345 Mdot
.65089 .4441 Mdot
.55246 .45471 Mdot
.32085 .46479 Mdot
.70245 .69571 Mdot
.56757 .43266 Mdot
.23193 .42337 Mdot
.29122 .48458 Mdot
.45202 .62654 Mdot
.77239 .71044 Mdot
.40817 .67772 Mdot
.59392 .599 Mdot
.35398 .65519 Mdot
.58632 .48341 Mdot
.47718 .62903 Mdot
.60424 .67597 Mdot
.45951 .63612 Mdot
.43434 .38846 Mdot
.44223 .648 Mdot
.60665 .44219 Mdot
.44353 .33212 Mdot
.30675 .49376 Mdot
.20006 .46575 Mdot
.38711 .6021 Mdot
.46327 .65152 Mdot
.34577 .65803 Mdot
.644 .46362 Mdot
.58297 .55337 Mdot
.55762 .51188 Mdot
.63188 .47127 Mdot
.34213 .5046 Mdot
.41815 .32133 Mdot
.33264 .52232 Mdot
.60898 .39523 Mdot
.25549 .3283 Mdot
.33194 .46781 Mdot
.27169 .44237 Mdot
.59235 .68828 Mdot
.55878 .57293 Mdot
.56389 .44807 Mdot
.33791 .50079 Mdot
.59906 .41176 Mdot
.41134 .31209 Mdot
.45759 .52714 Mdot
.32003 .64379 Mdot
.33469 .49797 Mdot
.83194 .53767 Mdot
.43625 .53499 Mdot
.63739 .5053 Mdot
.34292 .49738 Mdot
.451 .26917 Mdot
.35701 .65548 Mdot
.60558 .68811 Mdot
.58551 .66599 Mdot
.60713 .67519 Mdot
.55471 .47064 Mdot
.60415 .38173 Mdot
.62588 .71888 Mdot
.29841 .47702 Mdot
.57558 .69254 Mdot
.49869 .46421 Mdot
.83385 .52736 Mdot
.62111 .71349 Mdot
.58115 .44074 Mdot
.59429 .39083 Mdot
.6836 .60833 Mdot
.4278 .66118 Mdot
.77921 .36679 Mdot
.70033 .4086 Mdot
.61087 .4716 Mdot
.68184 .41584 Mdot
.40103 .36607 Mdot
.29195 .68514 Mdot
.52272 .38502 Mdot
.37631 .74058 Mdot
.4199 .31044 Mdot
.40815 .65963 Mdot
.40606 .33204 Mdot
.61756 .48879 Mdot
.63724 .45233 Mdot
.3855 .33012 Mdot
.25387 .52871 Mdot
.26499 .61477 Mdot
.77652 .67384 Mdot
.4424 .36998 Mdot
.34141 .49087 Mdot
.30424 .51049 Mdot
.35774 .47436 Mdot
.43894 .63334 Mdot
.44948 .37481 Mdot
.58392 .41743 Mdot
.50497 .63815 Mdot
.56265 .46645 Mdot
.32892 .50604 Mdot
.80264 .66529 Mdot
.42883 .36417 Mdot
.59852 .46282 Mdot
.34726 .7944 Mdot
.47337 .64935 Mdot
.60452 .68349 Mdot
.6502 .65051 Mdot
.4469 .62305 Mdot
.33727 .51598 Mdot
.38574 .34108 Mdot
.3194 .43387 Mdot
.4447 .44312 Mdot
.68004 .44239 Mdot
.66795 .43875 Mdot
.69367 .75951 Mdot
.34511 .63231 Mdot
.57899 .49758 Mdot
.49915 .62867 Mdot
.42614 .67101 Mdot
.60977 .43169 Mdot
.43028 .37501 Mdot
.62546 .6859 Mdot
.5765 .68007 Mdot
.53285 .43746 Mdot
.47401 .49728 Mdot
.5576 .57503 Mdot
.6233 .42663 Mdot
.5277 .42229 Mdot
.4997 .66265 Mdot
.38743 .65529 Mdot
.21596 .50081 Mdot
.62351 .71543 Mdot
.64258 .44413 Mdot
.34277 .40327 Mdot
.44741 .3226 Mdot
.44513 .6448 Mdot
.33856 .51305 Mdot
.7347 .65334 Mdot
.4759 .61108 Mdot
.61259 .43175 Mdot
.61636 .4288 Mdot
.32327 .46475 Mdot
.46963 .37065 Mdot
.60766 .69754 Mdot
.50473 .6439 Mdot
.62401 .71621 Mdot
.44575 .32665 Mdot
.43049 .36133 Mdot
.68136 .42694 Mdot
.52784 .42562 Mdot
.47294 .6624 Mdot
.58057 .40157 Mdot
.4419 .67059 Mdot
.69763 .70796 Mdot
.32438 .52686 Mdot
.60553 .49122 Mdot
.39228 .37431 Mdot
.33033 .50796 Mdot
.60586 .45323 Mdot
.67707 .78702 Mdot
.56508 .4772 Mdot
.41301 .66794 Mdot
.23545 .35082 Mdot
.58125 .68035 Mdot
.62988 .35562 Mdot
.68738 .48926 Mdot
.62302 .46023 Mdot
.4608 .67244 Mdot
.54676 .50023 Mdot
.32595 .46622 Mdot
.42358 .31294 Mdot
.29902 .79269 Mdot
.31621 .49176 Mdot
.63422 .46201 Mdot
.6087 .70824 Mdot
.38751 .34225 Mdot
.38128 .64349 Mdot
.20492 .54646 Mdot
.57513 .51028 Mdot
.66042 .4721 Mdot
.64728 .44024 Mdot
.47973 .17475 Mdot
.47602 .62715 Mdot
.42083 .32903 Mdot
.31626 .47068 Mdot
.31252 .50683 Mdot
.48755 .66003 Mdot
.29078 .39971 Mdot
.52363 .57682 Mdot
.81052 .29141 Mdot
.45843 .6586 Mdot
.58636 .71515 Mdot
.49565 .50841 Mdot
.44143 .6663 Mdot
.49183 .63423 Mdot
.5049 .65716 Mdot
.24385 .46632 Mdot
.41344 .35542 Mdot
.62315 .43831 Mdot
.44662 .30814 Mdot
.58493 .48379 Mdot
.594 .57709 Mdot
.32595 .51114 Mdot
.42552 .3115 Mdot
.69112 .76951 Mdot
.48482 .39782 Mdot
.57895 .45412 Mdot
.75706 .6586 Mdot
.58146 .5238 Mdot
.72891 .61871 Mdot
.62394 .51828 Mdot
.46602 .64439 Mdot
.58243 .37129 Mdot
.6207 .39362 Mdot
.1937 .46795 Mdot
.31574 .48025 Mdot
.35214 .66164 Mdot
.55683 .48456 Mdot
.5513 .49144 Mdot
.40595 .31284 Mdot
.43442 .37062 Mdot
.62247 .72022 Mdot
.56153 .6079 Mdot
.30766 .48906 Mdot
.64049 .66599 Mdot
.61227 .46616 Mdot
.26179 .52741 Mdot
.52224 .36158 Mdot
.60437 .45401 Mdot
.80426 .46192 Mdot
.53962 .34032 Mdot
.5609 .43737 Mdot
.45428 .26049 Mdot
.32808 .48588 Mdot
.23351 .35881 Mdot
.61092 .40224 Mdot
.48513 .64848 Mdot
.43134 .31398 Mdot
.40287 .36975 Mdot
.62857 .70556 Mdot
.19818 .62044 Mdot
.34842 .50978 Mdot
.43145 .3113 Mdot
.57386 .4632 Mdot
.34384 .50935 Mdot
.35479 .6481 Mdot
.63344 .39896 Mdot
.75701 .48546 Mdot
.4295 .34976 Mdot
.58532 .40405 Mdot
.30676 .30854 Mdot
.57603 .60559 Mdot
.7315 .26376 Mdot
.35539 .47154 Mdot
.61252 .71693 Mdot
.64892 .50296 Mdot
.60939 .80135 Mdot
.54345 .4382 Mdot
.62049 .62199 Mdot
.4446 .29171 Mdot
.60391 .71822 Mdot
.58501 .45942 Mdot
.58276 .42779 Mdot
.47057 .4844 Mdot
.5703 .67459 Mdot
.57823 .48573 Mdot
.64972 .37636 Mdot
.41011 .35068 Mdot
.35302 .6663 Mdot
.42653 .35383 Mdot
.5767 .44301 Mdot
.6165 .38305 Mdot
.41823 .36947 Mdot
.65044 .7549 Mdot
.58159 .71639 Mdot
.34733 .46906 Mdot
.53889 .40667 Mdot
.60546 .40668 Mdot
.49285 .1545 Mdot
.35569 .66277 Mdot
.41925 .2206 Mdot
.48667 .60743 Mdot
.35309 .41292 Mdot
.38033 .67616 Mdot
.82105 .42892 Mdot
.20526 .46801 Mdot
.55594 .49149 Mdot
.71142 .52517 Mdot
.46354 .24646 Mdot
.33701 .51872 Mdot
.59046 .23181 Mdot
.61263 .46936 Mdot
.58976 .4765 Mdot
.45762 .62492 Mdot
.27387 .40389 Mdot
.25844 .64453 Mdot
.47734 .51068 Mdot
.60302 .69543 Mdot
.45319 .339 Mdot
.62009 .44667 Mdot
.52474 .58637 Mdot
.44156 .65566 Mdot
.29441 .55017 Mdot
.59303 .46245 Mdot
.25371 .67503 Mdot
.25006 .46443 Mdot
.35305 .4999 Mdot
.48192 .67202 Mdot
.45836 .61513 Mdot
.60206 .48524 Mdot
.33059 .51601 Mdot
.56589 .43532 Mdot
.42891 .54837 Mdot
.56488 .40796 Mdot
.62094 .71026 Mdot
.64621 .46558 Mdot
.44412 .47228 Mdot
.77258 .31133 Mdot
.63527 .36558 Mdot
.42385 .37814 Mdot
.44309 .62923 Mdot
.48198 .6623 Mdot
.43235 .36879 Mdot
.48047 .66074 Mdot
.50959 .30027 Mdot
.65418 .32368 Mdot
.59848 .69347 Mdot
.53421 .40722 Mdot
.62456 .70601 Mdot
.35316 .66318 Mdot
.61278 .47588 Mdot
.60646 .80817 Mdot
.46079 .65733 Mdot
.32028 .25067 Mdot
.31315 .48977 Mdot
.35367 .66235 Mdot
.55199 .42742 Mdot
.54812 .71878 Mdot
.43141 .65517 Mdot
.41196 .66356 Mdot
.5811 .43158 Mdot
.42128 .36539 Mdot
.58943 .42705 Mdot
.59048 .52457 Mdot
.37249 .66412 Mdot
.63804 .42227 Mdot
.33179 .47138 Mdot
.47108 .35219 Mdot
.82784 .48265 Mdot
.41966 .67208 Mdot
.61698 .48148 Mdot
.57512 .463 Mdot
.39532 .32702 Mdot
.56977 .41263 Mdot
.3148 .51575 Mdot
.55805 .09516 Mdot
.59259 .68748 Mdot
.3901 .64278 Mdot
.41302 .67821 Mdot
.54779 .46119 Mdot
.61503 .42594 Mdot
.7178 .7465 Mdot
.31432 .61535 Mdot
.34074 .47883 Mdot
.54367 .49163 Mdot
.50242 .63812 Mdot
.60733 .70875 Mdot
.30919 .46505 Mdot
.63807 .42943 Mdot
.59232 .47083 Mdot
.61735 .71179 Mdot
.80909 .49564 Mdot
.3754 .74275 Mdot
.35805 .47136 Mdot
.5713 .3728 Mdot
.53688 .75117 Mdot
.5608 .45824 Mdot
.58165 .76441 Mdot
.44079 .36711 Mdot
.34796 .49477 Mdot
.46826 .19325 Mdot
.64745 .46902 Mdot
.30707 .5094 Mdot
.30941 .48604 Mdot
.64868 .41888 Mdot
.4317 .29743 Mdot
.46411 .34014 Mdot
.45671 .36002 Mdot
.1809 .41094 Mdot
.63626 .58244 Mdot
.44813 .64484 Mdot
.32936 .48623 Mdot
.46419 .67879 Mdot
.56924 .66608 Mdot
.55227 .58688 Mdot
.43719 .67201 Mdot
.40034 .36362 Mdot
.47895 .67495 Mdot
.58631 .42889 Mdot
.30602 .49494 Mdot
.465 .62637 Mdot
.55989 .48504 Mdot
.65627 .52785 Mdot
.41716 .53183 Mdot
.63292 .6988 Mdot
.615 .74142 Mdot
.63197 .44939 Mdot
.36217 .66337 Mdot
.60376 .46634 Mdot
.35887 .46621 Mdot
.45578 .45884 Mdot
.55058 .46686 Mdot
.46678 .65686 Mdot
.69298 .41386 Mdot
.42942 .64877 Mdot
.55445 .50282 Mdot
.58103 .44234 Mdot
.56766 .47105 Mdot
.56581 .43356 Mdot
.29586 .42077 Mdot
.34286 .51815 Mdot
.67288 .51822 Mdot
.52565 .65006 Mdot
.43624 .34455 Mdot
.40924 .38573 Mdot
.52531 .76906 Mdot
.39178 .64216 Mdot
.32885 .47711 Mdot
.56054 .45102 Mdot
.41019 .67253 Mdot
.80901 .65671 Mdot
.64927 .75994 Mdot
.62333 .74747 Mdot
.48868 .62395 Mdot
.41831 .37855 Mdot
.43596 .65397 Mdot
.59455 .48377 Mdot
.65974 .43305 Mdot
.82584 .4495 Mdot
.28695 .52123 Mdot
.60917 .69713 Mdot
.57091 .47527 Mdot
.59212 .59604 Mdot
.50265 .63688 Mdot
.50479 .65943 Mdot
.56543 .47586 Mdot
.46401 .36127 Mdot
.64155 .18237 Mdot
.35123 .50299 Mdot
.72029 .44432 Mdot
.36929 .35601 Mdot
.24814 .35387 Mdot
.31727 .51125 Mdot
.39849 .54464 Mdot
.50799 .63152 Mdot
.6653 .3601 Mdot
.43776 .34873 Mdot
.61259 .69923 Mdot
.6605 .42776 Mdot
.39992 .35969 Mdot
.51559 .63756 Mdot
.40291 .33079 Mdot
.62886 .48624 Mdot
.33834 .51944 Mdot
.50192 .65455 Mdot
.31231 .53115 Mdot
.38329 .33682 Mdot
.615 .68595 Mdot
.54564 .55773 Mdot
.63653 .25418 Mdot
.53529 .3401 Mdot
.5544 .43813 Mdot
.5048 .58869 Mdot
.59622 .41335 Mdot
.41931 .30265 Mdot
.56639 .44552 Mdot
.38143 .28159 Mdot
.48338 .67049 Mdot
.58839 .40345 Mdot
.65144 .4467 Mdot
.59308 .24772 Mdot
.58963 .45317 Mdot
.63991 .41981 Mdot
.5598 .43688 Mdot
.3719 .32989 Mdot
.60946 .50907 Mdot
.41596 .36008 Mdot
.21059 .55497 Mdot
.48943 .63386 Mdot
.63389 .69904 Mdot
.58263 .67228 Mdot
.60844 .61746 Mdot
.57666 .59158 Mdot
.2844 .40551 Mdot
.42044 .35036 Mdot
.32235 .47223 Mdot
.56445 .43641 Mdot
.51402 .1928 Mdot
.49193 .69742 Mdot
.50943 .64232 Mdot
.4164 .66987 Mdot
.51764 .46277 Mdot
.48306 .17274 Mdot
.5599 .41516 Mdot
.19866 .57095 Mdot
.53928 .42603 Mdot
.57473 .48616 Mdot
.4563 .61774 Mdot
.57118 .59432 Mdot
.55302 .44005 Mdot
.40497 .31406 Mdot
.61473 .69605 Mdot
.45288 .40908 Mdot
.39093 .71651 Mdot
.38056 .56229 Mdot
.64715 .2867 Mdot
.58576 .41406 Mdot
.50233 .65034 Mdot
.40132 .35088 Mdot
.21515 .49337 Mdot
.35507 .49002 Mdot
.25137 .43895 Mdot
.53761 .23835 Mdot
.72569 .7073 Mdot
.61208 .69629 Mdot
.80513 .49206 Mdot
.60849 .44211 Mdot
.43841 .63283 Mdot
.63591 .48568 Mdot
.8121 .65166 Mdot
.59548 .72091 Mdot
.45718 .3772 Mdot
.34119 .48891 Mdot
.41496 .30944 Mdot
.58999 .33784 Mdot
.37182 .5516 Mdot
.47634 .56105 Mdot
.44338 .67614 Mdot
.63462 .54469 Mdot
.43579 .32653 Mdot
.63207 .43327 Mdot
.84798 .34021 Mdot
.44311 .36675 Mdot
.46021 .36029 Mdot
.68266 .71982 Mdot
.68265 .72958 Mdot
.52708 .46839 Mdot
.39995 .3316 Mdot
.50065 .67288 Mdot
.58721 .68021 Mdot
.5858 .42364 Mdot
.57159 .43008 Mdot
.42149 .36822 Mdot
.43087 .66301 Mdot
.72367 .44234 Mdot
.46647 .64838 Mdot
.4082 .34961 Mdot
.47566 .6422 Mdot
.46221 .68434 Mdot
.48025 .62419 Mdot
.5952 .40604 Mdot
.5655 .44319 Mdot
.42342 .73694 Mdot
.43048 .36116 Mdot
.61285 .42291 Mdot
.63892 .44622 Mdot
.43947 .33107 Mdot
.49464 .60686 Mdot
.54149 .19844 Mdot
.62337 .47093 Mdot
.59713 .4366 Mdot
.60829 .71852 Mdot
.43288 .62716 Mdot
.38974 .76969 Mdot
.59949 .42287 Mdot
.574 .69786 Mdot
.45658 .32446 Mdot
.60388 .46335 Mdot
.4987 .47037 Mdot
.44801 .67988 Mdot
.64886 .46338 Mdot
.3782 .64194 Mdot
.54767 .44651 Mdot
.66863 .21077 Mdot
.62413 .47894 Mdot
.42494 .33061 Mdot
.42966 .31762 Mdot
.68853 .7046 Mdot
.44993 .35162 Mdot
.35266 .65422 Mdot
.32563 .50528 Mdot
.822 .61913 Mdot
.35781 .6462 Mdot
.57027 .48519 Mdot
.34285 .7993 Mdot
.60441 .39837 Mdot
.55463 .4802 Mdot
.43774 .18852 Mdot
.36062 .64507 Mdot
.42439 .32176 Mdot
.25097 .50066 Mdot
.53689 .42846 Mdot
.33979 .51299 Mdot
.65896 .41406 Mdot
.65548 .43971 Mdot
.22084 .40331 Mdot
.35938 .25987 Mdot
.35208 .45702 Mdot
.68352 .45667 Mdot
.60027 .42263 Mdot
.4106 .61787 Mdot
.56896 .45499 Mdot
.62514 .71109 Mdot
.45949 .35822 Mdot
.44585 .66166 Mdot
.58712 .68804 Mdot
.61725 .46376 Mdot
.61084 .70276 Mdot
.44787 .6426 Mdot
.34476 .50148 Mdot
.60839 .48156 Mdot
.59581 .72427 Mdot
.60448 .69665 Mdot
.60469 .4144 Mdot
.42851 .31206 Mdot
.57289 .36666 Mdot
.60421 .46065 Mdot
.62699 .43345 Mdot
.42612 .36667 Mdot
.51731 .86046 Mdot
.60633 .48873 Mdot
.42372 .50613 Mdot
.45291 .37808 Mdot
.36248 .67362 Mdot
.44966 .63555 Mdot
.65679 .44038 Mdot
.33739 .51121 Mdot
.32956 .51006 Mdot
.50964 .66411 Mdot
.40872 .3138 Mdot
.42859 .65794 Mdot
.68276 .40331 Mdot
.53388 .41851 Mdot
.63212 .4037 Mdot
.26856 .7553 Mdot
.81677 .44157 Mdot
.42586 .37571 Mdot
.48843 .6159 Mdot
.48339 .5174 Mdot
.3332 .48505 Mdot
.49234 .67356 Mdot
.38706 .33812 Mdot
.41219 .37599 Mdot
.399 .34017 Mdot
.60016 .71444 Mdot
.49096 .61366 Mdot
.46595 .37345 Mdot
.46478 .35698 Mdot
.58399 .43043 Mdot
.60306 .42231 Mdot
.47854 .32039 Mdot
.70962 .60053 Mdot
.62134 .69217 Mdot
.49083 .65624 Mdot
.42429 .14067 Mdot
.3579 .4639 Mdot
.59835 .25114 Mdot
.55097 .46971 Mdot
.92076 .51859 Mdot
.5567 .41637 Mdot
.57143 .46161 Mdot
.46281 .33134 Mdot
.61582 .72922 Mdot
.6201 .6966 Mdot
.43587 .32522 Mdot
.38433 .34461 Mdot
.62318 .71363 Mdot
.80013 .56752 Mdot
.83575 .53333 Mdot
.23255 .46667 Mdot
.43167 .33255 Mdot
.66304 .27846 Mdot
.33502 .51629 Mdot
.38417 .32619 Mdot
.34497 .45941 Mdot
.49281 .6359 Mdot
.51048 .63307 Mdot
.32524 .46428 Mdot
.57773 .43286 Mdot
.45314 .63613 Mdot
.63575 .50343 Mdot
.81314 .55353 Mdot
.74095 .36757 Mdot
.29456 .60311 Mdot
.57492 .49938 Mdot
.24897 .63062 Mdot
.27449 .65245 Mdot
.62829 .45572 Mdot
.45427 .42603 Mdot
.61033 .69903 Mdot
.38299 .31914 Mdot
.31755 .51655 Mdot
.72022 .25359 Mdot
.56033 .45524 Mdot
.42233 .33479 Mdot
.31917 .47807 Mdot
.68584 .68513 Mdot
.23473 .41601 Mdot
.57925 .48225 Mdot
.77015 .25221 Mdot
.38717 .30524 Mdot
.44662 .66143 Mdot
.27645 .73269 Mdot
.45534 .31635 Mdot
.5965 .73518 Mdot
.5109 .62811 Mdot
.72072 .72934 Mdot
.41144 .33055 Mdot
.51901 .64255 Mdot
.44964 .33467 Mdot
.62674 .70581 Mdot
.41744 .29734 Mdot
.50537 .65085 Mdot
.58769 .45674 Mdot
.48062 .65756 Mdot
.61925 .68885 Mdot
.43284 .63979 Mdot
.32431 .5167 Mdot
.35533 .65997 Mdot
.32604 .49509 Mdot
.57268 .60597 Mdot
.28904 .29141 Mdot
.35259 .47753 Mdot
.66806 .67875 Mdot
.5772 .49743 Mdot
.47301 .36844 Mdot
.45884 .66171 Mdot
.52472 .6535 Mdot
.52535 .5515 Mdot
.43914 .34168 Mdot
.49424 .65781 Mdot
.5296 .23316 Mdot
.42564 .84044 Mdot
.59949 .38167 Mdot
.66178 .56985 Mdot
.43844 .33256 Mdot
.50234 .66358 Mdot
.20555 .52613 Mdot
.39742 .36107 Mdot
.45709 .65769 Mdot
.34085 .49719 Mdot
.31374 .50876 Mdot
.56023 .4642 Mdot
.30722 .54217 Mdot
.46359 .66961 Mdot
.23434 .57709 Mdot
.44958 .32571 Mdot
.68537 .68064 Mdot
.62628 .69354 Mdot
.49315 .63214 Mdot
.62907 .39559 Mdot
.47331 .39166 Mdot
.4744 .68335 Mdot
.73886 .48125 Mdot
.41084 .15331 Mdot
.48818 .65878 Mdot
.46006 .35485 Mdot
.4222 .33887 Mdot
.56627 .51691 Mdot
.47637 .49743 Mdot
.4336 .64677 Mdot
.58489 .81812 Mdot
.63359 .62508 Mdot
.37139 .65659 Mdot
.31893 .685 Mdot
.54978 .44599 Mdot
.60409 .41066 Mdot
.3351 .48425 Mdot
.58549 .44872 Mdot
.46756 .35211 Mdot
.55325 .43203 Mdot
.30388 .50411 Mdot
.50835 .63521 Mdot
.60844 .47901 Mdot
.58786 .67764 Mdot
.35009 .45162 Mdot
.32456 .46316 Mdot
.47728 .63394 Mdot
.39905 .3345 Mdot
.55653 .65218 Mdot
.46817 .65335 Mdot
.58154 .41605 Mdot
.37579 .64506 Mdot
.63636 .4791 Mdot
.78772 .50357 Mdot
.39262 .34901 Mdot
.43663 .66087 Mdot
.4277 .38664 Mdot
.32268 .49202 Mdot
.52393 .64548 Mdot
.57373 .44855 Mdot
.45654 .6544 Mdot
.38518 .72804 Mdot
.80228 .52512 Mdot
.40785 .31371 Mdot
.36954 .69266 Mdot
.46217 .35473 Mdot
.3726 .65762 Mdot
.77041 .5333 Mdot
.60294 .6888 Mdot
.50068 .63929 Mdot
.80634 .42555 Mdot
.46671 .65924 Mdot
.5928 .452 Mdot
.61197 .45103 Mdot
.46115 .62363 Mdot
.57965 .6982 Mdot
.20174 .37177 Mdot
.41105 .51858 Mdot
.41812 .32411 Mdot
.68326 .37231 Mdot
.47601 .13189 Mdot
.28821 .49422 Mdot
.33696 .48095 Mdot
.53427 .4512 Mdot
.55829 .46708 Mdot
.31593 .46433 Mdot
.29986 .50858 Mdot
.63133 .71163 Mdot
.50779 .65352 Mdot
.43113 .29292 Mdot
.29413 .47743 Mdot
.62786 .52845 Mdot
.58105 .58973 Mdot
.5275 .45989 Mdot
.67025 .40461 Mdot
.63437 .49842 Mdot
.62099 .63058 Mdot
.30034 .48767 Mdot
.63201 .44701 Mdot
.59133 .51098 Mdot
.34618 .49204 Mdot
.62606 .70628 Mdot
.34887 .26888 Mdot
.48116 .64467 Mdot
.65947 .82112 Mdot
.63351 .47754 Mdot
.59579 .45569 Mdot
.35935 .47719 Mdot
.40698 .6294 Mdot
.40644 .36432 Mdot
.39383 .33817 Mdot
.47253 .62763 Mdot
.53356 .56456 Mdot
.56786 .4161 Mdot
.63029 .4532 Mdot
.49667 .64653 Mdot
.35654 .66052 Mdot
.26935 .59062 Mdot
.61675 .43772 Mdot
.31862 .48028 Mdot
.52574 .67087 Mdot
.29872 .49275 Mdot
.61497 .49127 Mdot
.59564 .45056 Mdot
.59063 .40648 Mdot
.55868 .46865 Mdot
.33326 .46061 Mdot
.62722 .44565 Mdot
.58844 .38952 Mdot
.41015 .32086 Mdot
.59817 .40788 Mdot
.63049 .62971 Mdot
.58592 .43817 Mdot
.60246 .67921 Mdot
.5244 .59766 Mdot
.56796 .47237 Mdot
.609 .40798 Mdot
.41329 .51832 Mdot
.58387 .46241 Mdot
.35783 .46504 Mdot
.43186 .34335 Mdot
.32978 .48675 Mdot
.3158 .47009 Mdot
.48631 .67875 Mdot
.6284 .7144 Mdot
.54614 .47093 Mdot
.6016 .67318 Mdot
.67166 .4168 Mdot
.63208 .48519 Mdot
.53746 .66944 Mdot
.1988 .57337 Mdot
.38551 .74418 Mdot
.5729 .44684 Mdot
.48257 .6287 Mdot
.44252 .66104 Mdot
.72065 .50996 Mdot
.62366 .50928 Mdot
.31394 .46346 Mdot
.33771 .50054 Mdot
.7502 .57013 Mdot
.2199 .41087 Mdot
.61447 .68603 Mdot
.53647 .58776 Mdot
.61185 .50342 Mdot
.62998 .43882 Mdot
.62792 .39746 Mdot
.4427 .67408 Mdot
.38378 .65937 Mdot
.50986 .64255 Mdot
.39451 .66037 Mdot
.30003 .49987 Mdot
.55726 .4308 Mdot
.74403 .35004 Mdot
.4267 .37218 Mdot
.43196 .3441 Mdot
.30427 .47084 Mdot
.42592 .65841 Mdot
.60875 .52863 Mdot
.31464 .81167 Mdot
.37644 .34742 Mdot
.63518 .71401 Mdot
.6303 .45867 Mdot
.4778 .63163 Mdot
.44239 .37303 Mdot
.57325 .68546 Mdot
.64714 .45245 Mdot
.51035 .60536 Mdot
.57058 .44184 Mdot
.4604 .24694 Mdot
.41585 .31911 Mdot
.82319 .64174 Mdot
.38909 .34997 Mdot
.3463 .44957 Mdot
.34781 .48108 Mdot
.60454 .45208 Mdot
.2723 .75012 Mdot
.47449 .35789 Mdot
.31074 .54065 Mdot
.60634 .72633 Mdot
.3911 .64618 Mdot
.59916 .71965 Mdot
.44394 .6677 Mdot
.61303 .69505 Mdot
.49782 .66177 Mdot
.73981 .57408 Mdot
.37499 .36137 Mdot
.59013 .68721 Mdot
.42145 .59995 Mdot
.61488 .50594 Mdot
.59438 .66703 Mdot
.55942 .40064 Mdot
.65798 .36027 Mdot
.49365 .64668 Mdot
.57929 .69604 Mdot
.6288 .43184 Mdot
.72423 .27569 Mdot
.33853 .47135 Mdot
.31856 .46152 Mdot
.6507 .49319 Mdot
.50863 .65411 Mdot
.39239 .32195 Mdot
.45127 .44584 Mdot
.36103 .67188 Mdot
.63024 .45 Mdot
.55279 .43606 Mdot
.40841 .38582 Mdot
.40991 .39237 Mdot
.60015 .44956 Mdot
.54209 .22173 Mdot
.61516 .44293 Mdot
.3285 .51288 Mdot
.40895 .3715 Mdot
.42565 .34066 Mdot
.47006 .67094 Mdot
.4312 .30589 Mdot
.66623 .39786 Mdot
.37838 .43041 Mdot
.54308 .41902 Mdot
.31722 .49377 Mdot
.44493 .46256 Mdot
.41715 .67015 Mdot
.76213 .33989 Mdot
.40261 .3798 Mdot
.63333 .41824 Mdot
.45599 .33686 Mdot
.59854 .70914 Mdot
.43064 .35861 Mdot
.44614 .37665 Mdot
.61161 .46094 Mdot
.58521 .48306 Mdot
.36158 .64584 Mdot
.48244 .50559 Mdot
.43424 .31015 Mdot
.62478 .44837 Mdot
.60129 .39979 Mdot
.65229 .42974 Mdot
.44079 .51177 Mdot
.42925 .37651 Mdot
.56717 .26824 Mdot
.75533 .46745 Mdot
.43008 .30968 Mdot
.64541 .1966 Mdot
.38506 .64499 Mdot
.3917 .64326 Mdot
.2874 .51501 Mdot
.6175 .43712 Mdot
.46952 .61871 Mdot
.59615 .48369 Mdot
.68061 .41538 Mdot
.59265 .47347 Mdot
.57745 .70169 Mdot
.55805 .49261 Mdot
.36504 .65489 Mdot
.47098 .65658 Mdot
.63677 .46592 Mdot
.6055 .47893 Mdot
.38802 .63679 Mdot
.39402 .36608 Mdot
.40266 .36077 Mdot
.60011 .76368 Mdot
.59581 .70017 Mdot
.34664 .50154 Mdot
.56242 .44232 Mdot
.48008 .62754 Mdot
.47832 .65722 Mdot
.4234 .30465 Mdot
.48303 .64998 Mdot
.35815 .49023 Mdot
.57331 .45198 Mdot
.31942 .46182 Mdot
.57672 .68862 Mdot
.45676 .36292 Mdot
.55889 .44904 Mdot
.58513 .43043 Mdot
.42942 .3177 Mdot
.57882 .49804 Mdot
.609 .71862 Mdot
.47244 .66123 Mdot
.40665 .33826 Mdot
.32559 .50659 Mdot
.47144 .67286 Mdot
.60358 .42886 Mdot
.3999 .16064 Mdot
.59215 .44618 Mdot
.61302 .43273 Mdot
.8399 .4928 Mdot
.5363 .46794 Mdot
.46807 .66745 Mdot
.41859 .38896 Mdot
.65454 .48324 Mdot
.61638 .60201 Mdot
.63292 .78416 Mdot
.50173 .67108 Mdot
.63042 .46529 Mdot
.77356 .3497 Mdot
.63316 .46658 Mdot
.63486 .66115 Mdot
.4581 .78205 Mdot
.65416 .54007 Mdot
.67011 .40703 Mdot
.34204 .46433 Mdot
.35778 .64832 Mdot
.4859 .66918 Mdot
.48191 .2962 Mdot
.61748 .45662 Mdot
.4367 .25929 Mdot
.65182 .45104 Mdot
.31421 .51018 Mdot
.66317 .37062 Mdot
.48778 .6561 Mdot
.18817 .54518 Mdot
.58481 .41652 Mdot
.42252 .3767 Mdot
.47035 .67605 Mdot
.38934 .64662 Mdot
.61669 .43057 Mdot
.5906 .67191 Mdot
.31815 .53633 Mdot
.54112 .41077 Mdot
.31609 .498 Mdot
.64027 .44508 Mdot
.68569 .44195 Mdot
.23028 .68163 Mdot
.41193 .3217 Mdot
.3395 .48686 Mdot
.29701 .67191 Mdot
.58635 .49913 Mdot
.40942 .33226 Mdot
.43801 .34761 Mdot
.62422 .69251 Mdot
.47939 .54083 Mdot
.30611 .3195 Mdot
.71003 .30452 Mdot
.5618 .35462 Mdot
.49614 .66963 Mdot
.2779 .6338 Mdot
.59045 .4224 Mdot
.33065 .55676 Mdot
.35239 .4599 Mdot
.5928 .4565 Mdot
.52922 .35777 Mdot
.45386 .36379 Mdot
.60226 .43819 Mdot
.6249 .70668 Mdot
.28371 .5512 Mdot
.32338 .56242 Mdot
.54393 .1674 Mdot
.50519 .67034 Mdot
.65277 .41323 Mdot
.65786 .39574 Mdot
.347 .65934 Mdot
.64712 .47613 Mdot
.46863 .66553 Mdot
.78901 .59985 Mdot
.5814 .70499 Mdot
.44904 .37084 Mdot
.38568 .64535 Mdot
.64175 .49567 Mdot
.62343 .40534 Mdot
.63481 .70173 Mdot
.63044 .42084 Mdot
.20265 .62509 Mdot
.32545 .66864 Mdot
.46091 .62962 Mdot
.40112 .33543 Mdot
.61836 .50172 Mdot
.37978 .66176 Mdot
.61234 .45694 Mdot
.69255 .3389 Mdot
.62638 .41487 Mdot
.28845 .32735 Mdot
.43219 .3138 Mdot
.3189 .49786 Mdot
.67595 .43902 Mdot
.58559 .47305 Mdot
.54161 .74626 Mdot
.68131 .42048 Mdot
.62564 .47911 Mdot
.39887 .32025 Mdot
.42614 .37411 Mdot
.41697 .35945 Mdot
.44075 .65031 Mdot
.22856 .47794 Mdot
.32129 .48272 Mdot
.54722 .43591 Mdot
.2962 .47493 Mdot
.71198 .41547 Mdot
.63657 .70814 Mdot
.67024 .23537 Mdot
.64439 .4281 Mdot
.41695 .35332 Mdot
.34056 .38627 Mdot
.45831 .32751 Mdot
.52371 .61777 Mdot
.3072 .49011 Mdot
.44916 .36555 Mdot
.577 .46815 Mdot
.46732 .49694 Mdot
.57753 .18798 Mdot
.33259 .49127 Mdot
.60096 .39137 Mdot
.52209 .65537 Mdot
.42376 .68006 Mdot
.48259 .11675 Mdot
.34121 .47748 Mdot
.27943 .65229 Mdot
.62482 .45429 Mdot
.42299 .37135 Mdot
.35267 .46922 Mdot
.34135 .46912 Mdot
.49111 .64938 Mdot
.57921 .48111 Mdot
.56867 .47087 Mdot
.38088 .64266 Mdot
.33618 .50301 Mdot
.65984 .48405 Mdot
.59783 .39653 Mdot
.82726 .45219 Mdot
.47727 .30963 Mdot
.55851 .85826 Mdot
.6818 .40088 Mdot
.55022 .35129 Mdot
.49428 .49892 Mdot
.45635 .37175 Mdot
.57114 .47686 Mdot
.62553 .49766 Mdot
.469 .66986 Mdot
.58113 .44863 Mdot
.44827 .6283 Mdot
.33299 .4754 Mdot
.63215 .19492 Mdot
.34599 .31111 Mdot
.7844 .5963 Mdot
.58246 .45247 Mdot
.23141 .38195 Mdot
.58614 .69804 Mdot
.36569 .45627 Mdot
.40622 .35275 Mdot
.59858 .49718 Mdot
.42293 .64896 Mdot
.50123 .63848 Mdot
.44303 .35636 Mdot
.23239 .59454 Mdot
.56965 .7598 Mdot
.61357 .49198 Mdot
.44607 .6379 Mdot
.34952 .41782 Mdot
.52552 .21826 Mdot
.30792 .45862 Mdot
.58611 .71231 Mdot
.50898 .64082 Mdot
.29929 .48116 Mdot
.49494 .37208 Mdot
.45029 .35979 Mdot
.43086 .38979 Mdot
.47809 .76422 Mdot
.43292 .6456 Mdot
.58575 .68592 Mdot
.21875 .45471 Mdot
.21337 .44929 Mdot
.58115 .7072 Mdot
.50688 .62974 Mdot
.43529 .37403 Mdot
.41349 .33763 Mdot
.43136 .34232 Mdot
.18798 .53101 Mdot
.39513 .33107 Mdot
.62587 .28346 Mdot
.61095 .39929 Mdot
.53175 .51761 Mdot
.63048 .46736 Mdot
.33889 .45834 Mdot
.41779 .31869 Mdot
.50571 .52126 Mdot
.56437 .48242 Mdot
.56434 .17611 Mdot
.6323 .45215 Mdot
.32229 .45067 Mdot
.60907 .43616 Mdot
.61757 .25012 Mdot
.45518 .37667 Mdot
.57657 .44588 Mdot
.35227 .51336 Mdot
.60382 .69959 Mdot
.44742 .29881 Mdot
.56877 .47279 Mdot
.2679 .39661 Mdot
.53627 .45719 Mdot
.79879 .58731 Mdot
.7019 .66106 Mdot
.63538 .71491 Mdot
.65418 .37705 Mdot
.50912 .66045 Mdot
.43108 .28663 Mdot
.57083 .38206 Mdot
.3319 .49284 Mdot
.34859 .24356 Mdot
.49909 .63411 Mdot
.61935 .36338 Mdot
.54827 .49894 Mdot
.62765 .71377 Mdot
.47758 .38134 Mdot
.35746 .46688 Mdot
.56151 .48841 Mdot
.64845 .4196 Mdot
.78805 .58038 Mdot
.55527 .38986 Mdot
.56494 .41503 Mdot
.61948 .68044 Mdot
.57752 .27426 Mdot
.58679 .43511 Mdot
.50598 .61134 Mdot
.43201 .3892 Mdot
.64762 .49562 Mdot
.56553 .26477 Mdot
.62379 .44912 Mdot
.43926 .36442 Mdot
.43535 .39239 Mdot
.31746 .37302 Mdot
.61584 .72681 Mdot
.62696 .41524 Mdot
.7268 .6695 Mdot
.59342 .41274 Mdot
.31571 .48355 Mdot
.61 .48912 Mdot
.49653 .63925 Mdot
.19955 .55823 Mdot
.4483 .65123 Mdot
.59979 .48676 Mdot
.43012 .33828 Mdot
.34756 .46362 Mdot
.43328 .74986 Mdot
.49858 .78327 Mdot
.61827 .2809 Mdot
.68831 .77446 Mdot
.587 .70725 Mdot
.57263 .66833 Mdot
.3631 .47745 Mdot
.57641 .44369 Mdot
.69915 .69185 Mdot
.53787 .4334 Mdot
.59876 .43598 Mdot
.59421 .47418 Mdot
.34682 .54634 Mdot
.33055 .48163 Mdot
.47576 .64833 Mdot
.59778 .44907 Mdot
.62447 .44689 Mdot
.44987 .33002 Mdot
.60277 .69757 Mdot
.44602 .65495 Mdot
.59444 .6925 Mdot
.46283 .64068 Mdot
.66319 .20528 Mdot
.56998 .40152 Mdot
.60316 .70158 Mdot
.36139 .46532 Mdot
.42599 .36709 Mdot
.37246 .66647 Mdot
.44907 .66975 Mdot
.49174 .65691 Mdot
.62947 .45108 Mdot
.43312 .3676 Mdot
.43071 .30709 Mdot
.5954 .70807 Mdot
.35359 .48805 Mdot
.59696 .48564 Mdot
.62161 .49134 Mdot
.70482 .50851 Mdot
.4537 .67598 Mdot
.51224 .22839 Mdot
.31025 .3963 Mdot
.57366 .44467 Mdot
.40228 .32758 Mdot
.60457 .47409 Mdot
.76791 .37116 Mdot
.40028 .36301 Mdot
.57445 .48555 Mdot
.21023 .41389 Mdot
.43214 .67257 Mdot
.28022 .36182 Mdot
.60033 .40375 Mdot
.72886 .73946 Mdot
.59757 .4189 Mdot
.81511 .39955 Mdot
.3628 .61436 Mdot
.55723 .42815 Mdot
.58896 .42584 Mdot
.69899 .28977 Mdot
.62186 .46206 Mdot
.37013 .65911 Mdot
.6531 .36877 Mdot
.41262 .37681 Mdot
.51815 .52873 Mdot
.48347 .60078 Mdot
.60737 .72787 Mdot
.47178 .62768 Mdot
.36084 .69701 Mdot
.62173 .71074 Mdot
.43169 .33114 Mdot
.56579 .43283 Mdot
.55504 .56793 Mdot
.50781 .67275 Mdot
.56828 .51531 Mdot
.31266 .48564 Mdot
.3793 .68436 Mdot
.45814 .62028 Mdot
.32377 .50327 Mdot
.65202 .44173 Mdot
.57402 .20449 Mdot
.43312 .77901 Mdot
.82642 .62322 Mdot
.35832 .47215 Mdot
.31673 .51257 Mdot
.20749 .50698 Mdot
.59783 .72374 Mdot
.77959 .5114 Mdot
.2575 .3551 Mdot
.34573 .50961 Mdot
.7648 .58118 Mdot
.51293 .64871 Mdot
.25934 .39556 Mdot
.38295 .3193 Mdot
.63236 .40254 Mdot
.57929 .46957 Mdot
.35191 .48918 Mdot
.5016 .45864 Mdot
.24833 .69961 Mdot
.3273 .4954 Mdot
.65109 .39772 Mdot
.45302 .54764 Mdot
.38022 .64739 Mdot
.36835 .64087 Mdot
.62396 .72463 Mdot
.61953 .75667 Mdot
.44456 .32674 Mdot
.63044 .71034 Mdot
.31828 .56565 Mdot
.63724 .42378 Mdot
.33376 .4994 Mdot
.38634 .66032 Mdot
.31909 .50804 Mdot
.62199 .70326 Mdot
.63382 .71534 Mdot
.40916 .3217 Mdot
.40583 .36306 Mdot
.54256 .3494 Mdot
.73171 .60543 Mdot
.63477 .46636 Mdot
.43531 .21286 Mdot
.44785 .32222 Mdot
.59318 .37485 Mdot
.57425 .69747 Mdot
.60017 .69979 Mdot
.47224 .25595 Mdot
.55919 .4423 Mdot
.68108 .70523 Mdot
.56123 .44694 Mdot
.76174 .52049 Mdot
.64368 .48175 Mdot
.4877 .64922 Mdot
.55919 .43107 Mdot
.56094 .6533 Mdot
.55041 .44838 Mdot
.62684 .47982 Mdot
.51008 .64932 Mdot
.53756 .41767 Mdot
.49765 .63997 Mdot
.59709 .48756 Mdot
.56582 .67788 Mdot
.47903 .6274 Mdot
.65047 .5853 Mdot
.42323 .5086 Mdot
.36205 .66082 Mdot
.601 .67642 Mdot
.61948 .68455 Mdot
.59202 .60671 Mdot
.40573 .35089 Mdot
.48984 .38866 Mdot
.57916 .44296 Mdot
.50386 .66028 Mdot
.3344 .48175 Mdot
.6222 .44555 Mdot
.62618 .49247 Mdot
.57792 .40761 Mdot
.45868 .3518 Mdot
.427 .65508 Mdot
.60829 .70447 Mdot
.44439 .64138 Mdot
.56245 .74288 Mdot
.47344 .61147 Mdot
.59942 .51074 Mdot
.66898 .43859 Mdot
.7179 .38427 Mdot
.39377 .24305 Mdot
.19442 .411 Mdot
.44878 .35695 Mdot
.36035 .6502 Mdot
.63229 .71571 Mdot
.68841 .38557 Mdot
.41112 .35253 Mdot
.50575 .649 Mdot
.56999 .44217 Mdot
.62374 .39134 Mdot
.27724 .48804 Mdot
.42005 .28165 Mdot
.65067 .6275 Mdot
.45243 .62217 Mdot
.37514 .65574 Mdot
.22619 .47913 Mdot
.53279 .37768 Mdot
.53191 .55895 Mdot
.59616 .46575 Mdot
.58705 .67244 Mdot
.44237 .37301 Mdot
.43171 .76052 Mdot
.34397 .49789 Mdot
.47797 .49993 Mdot
.58153 .45203 Mdot
.24041 .48874 Mdot
.43147 .33898 Mdot
.62443 .7001 Mdot
.35112 .48997 Mdot
.6138 .7296 Mdot
.36809 .64052 Mdot
.68149 .74786 Mdot
.60961 .41292 Mdot
.6252 .47775 Mdot
.32444 .45213 Mdot
.44755 .33282 Mdot
.61807 .74147 Mdot
.79978 .54996 Mdot
.45404 .63002 Mdot
.67596 .70802 Mdot
.46969 .3446 Mdot
.65093 .28482 Mdot
.4426 .6448 Mdot
.30351 .47162 Mdot
.5824 .61011 Mdot
.30277 .50274 Mdot
.56351 .46711 Mdot
.42128 .34696 Mdot
.33391 .47185 Mdot
.52923 .74188 Mdot
.76754 .3215 Mdot
.66291 .28358 Mdot
.57402 .41719 Mdot
.65669 .221 Mdot
.82409 .53324 Mdot
.4907 .42612 Mdot
.32437 .51721 Mdot
.60609 .45918 Mdot
.65577 .46601 Mdot
.57875 .41908 Mdot
.31786 .4732 Mdot
.5308 .71047 Mdot
.49772 .65215 Mdot
.63425 .45746 Mdot
.62955 .70309 Mdot
.49041 .63917 Mdot
.52271 .67942 Mdot
.47707 .66697 Mdot
.42293 .38203 Mdot
.56417 .47723 Mdot
.25776 .4425 Mdot
.78732 .32148 Mdot
.33037 .48782 Mdot
.36209 .66052 Mdot
.64254 .46786 Mdot
.2571 .33104 Mdot
.41653 .35819 Mdot
.45602 .62823 Mdot
.59587 .45633 Mdot
.53148 .7213 Mdot
.40572 .64417 Mdot
.48301 .66451 Mdot
.4103 .3395 Mdot
.47966 .4284 Mdot
.5837 .4475 Mdot
.60216 .41756 Mdot
.44284 .32966 Mdot
.63273 .76235 Mdot
.20253 .55202 Mdot
.60501 .47729 Mdot
.32007 .49912 Mdot
.39519 .84653 Mdot
.62116 .40779 Mdot
.49599 .34892 Mdot
.39079 .6441 Mdot
.28354 .39476 Mdot
.50516 .22747 Mdot
.65498 .37568 Mdot
.71113 .29313 Mdot
.56136 .58276 Mdot
.64282 .20148 Mdot
.56112 .70641 Mdot
.39625 .57486 Mdot
.67635 .21519 Mdot
.35707 .50508 Mdot
.5418 .53108 Mdot
.72336 .45868 Mdot
.218 .58348 Mdot
.49409 .4717 Mdot
.57818 .79545 Mdot
.52766 .76007 Mdot
.47997 .57819 Mdot
.46107 .6568 Mdot
.75172 .50945 Mdot
.59875 .4847 Mdot
.82351 .54165 Mdot
.5575 .22585 Mdot
.24502 .70422 Mdot
.671 .22941 Mdot
.72981 .66534 Mdot
.59639 .20141 Mdot
.77878 .36736 Mdot
.72527 .39262 Mdot
.36603 .28723 Mdot
.5442 .84301 Mdot
.21324 .46044 Mdot
.74694 .65975 Mdot
.6354 .51495 Mdot
.52687 .58596 Mdot
.77005 .65231 Mdot
.63412 .30432 Mdot
.29546 .76691 Mdot
.45368 .66636 Mdot
.44396 .38603 Mdot
.72305 .47771 Mdot
.45904 .30924 Mdot
.38154 .45503 Mdot
.70844 .28837 Mdot
.8109 .40711 Mdot
.61002 .24747 Mdot
.72665 .7457 Mdot
.49932 .3038 Mdot
.16733 .4247 Mdot
.42145 .53526 Mdot
.4563 .38478 Mdot
.47717 .82613 Mdot
.21416 .44697 Mdot
.3333 .31476 Mdot
.69632 .41393 Mdot
.5114 .69048 Mdot
.67723 .59892 Mdot
.42337 .33449 Mdot
.50378 .22051 Mdot
.36207 .63981 Mdot
.34525 .28262 Mdot
.55031 .64814 Mdot
.75141 .32275 Mdot
.48999 .56925 Mdot
.25707 .40914 Mdot
.26681 .61491 Mdot
.40304 .15864 Mdot
.74038 .62212 Mdot
.7846 .4319 Mdot
.29157 .46441 Mdot
.49315 .46025 Mdot
.2429 .65059 Mdot
.71219 .62081 Mdot
.21286 .43822 Mdot
.39764 .19423 Mdot
.81651 .59323 Mdot
.45623 .16158 Mdot
.48799 .35988 Mdot
.57527 .40936 Mdot
.76458 .40849 Mdot
.56744 .35516 Mdot
.63898 .7023 Mdot
.51243 .16437 Mdot
.57595 .68079 Mdot
.4779 .33496 Mdot
.22829 .59262 Mdot
.6237 .26902 Mdot
.67163 .69407 Mdot
.60572 .73477 Mdot
.55692 .49341 Mdot
.11784 .54984 Mdot
.63198 .20059 Mdot
.31034 .37684 Mdot
.82772 .45082 Mdot
.26015 .51886 Mdot
.69184 .67851 Mdot
.32768 .4727 Mdot
.73736 .26664 Mdot
.41409 .34289 Mdot
.72295 .22488 Mdot
.76026 .30049 Mdot
.32218 .75047 Mdot
.23753 .76875 Mdot
.31214 .59121 Mdot
.66258 .52899 Mdot
.57472 .58148 Mdot
.63971 .60561 Mdot
.24991 .68797 Mdot
.33529 .76653 Mdot
.25586 .51602 Mdot
.74097 .70497 Mdot
.70072 .24019 Mdot
.76671 .55624 Mdot
.70432 .71622 Mdot
.22975 .61187 Mdot
.43229 .5048 Mdot
.46381 .39532 Mdot
.4098 .48641 Mdot
.37411 .28218 Mdot
.49763 .16377 Mdot
.53301 .37056 Mdot
.3251 .81644 Mdot
.56154 .68771 Mdot
.38154 .62608 Mdot
.8202 .47609 Mdot
.6629 .57663 Mdot
.70597 .3894 Mdot
.22207 .50511 Mdot
.56647 .50346 Mdot
.2213 .49115 Mdot
.39759 .40933 Mdot
.36546 .69372 Mdot
.22222 .48051 Mdot
.32189 .42362 Mdot
.79104 .56949 Mdot
.73991 .37346 Mdot
.21934 .39558 Mdot
.40801 .37551 Mdot
.68998 .636 Mdot
.75105 .60664 Mdot
.82672 .45984 Mdot
.29618 .67101 Mdot
.83686 .6084 Mdot
.30232 .68793 Mdot
.54247 .42639 Mdot
.60819 .3806 Mdot
.63961 .51741 Mdot
.72117 .62733 Mdot
.58947 .4021 Mdot
.23976 .49211 Mdot
.83538 .47955 Mdot
.51971 .35937 Mdot
.39927 .70043 Mdot
.36152 .23153 Mdot
.82541 .6085 Mdot
.76212 .42867 Mdot
.34505 .61839 Mdot
.50895 .45165 Mdot
.2025 .34228 Mdot
.48057 .63779 Mdot
.7667 .57351 Mdot
.30964 .52351 Mdot
.46752 .76746 Mdot
.68779 .28945 Mdot
.31407 .74165 Mdot
.83789 .48319 Mdot
.20985 .55002 Mdot
.37209 .74111 Mdot
.57407 .62795 Mdot
.66498 .69511 Mdot
.38484 .22638 Mdot
.6605 .40976 Mdot
.6968 .46572 Mdot
.6012 .67021 Mdot
.60946 .33969 Mdot
.76094 .47101 Mdot
.49922 .80204 Mdot
.61277 .3843 Mdot
.40596 .79173 Mdot
.37827 .65685 Mdot
.47315 .49834 Mdot
.52553 .12914 Mdot
.5813 .51468 Mdot
.31772 .60242 Mdot
.81159 .60493 Mdot
.68543 .65558 Mdot
.80573 .4579 Mdot
.2752 .43839 Mdot
.44225 .17094 Mdot
.7844 .33168 Mdot
.49481 .79008 Mdot
.60091 .175 Mdot
.86179 .53101 Mdot
.41133 .17948 Mdot
.43296 .24085 Mdot
.36358 .501 Mdot
.66521 .1553 Mdot
.49279 .62213 Mdot
.32362 .25407 Mdot
.55417 .35674 Mdot
.49362 .72321 Mdot
.40378 .30919 Mdot
.54362 .50672 Mdot
.48811 .57607 Mdot
.3972 .2945 Mdot
.6391 .50109 Mdot
.44619 .14529 Mdot
.35605 .21303 Mdot
.4582 .14849 Mdot
.79268 .65323 Mdot
.61202 .18005 Mdot
.67307 .53223 Mdot
.63884 .29157 Mdot
.73352 .49426 Mdot
.6115 .49038 Mdot
.73988 .55172 Mdot
.30889 .59539 Mdot
.41833 .77175 Mdot
.32332 .31212 Mdot
.4298 .299 Mdot
.51039 .17644 Mdot
.42548 .11787 Mdot
.50575 .29784 Mdot
.53109 .26905 Mdot
.32015 .55704 Mdot
.73589 .60824 Mdot
.38376 .39505 Mdot
.38035 .76678 Mdot
.82409 .47026 Mdot
.72576 .45358 Mdot
.77298 .5836 Mdot
.5215 .80986 Mdot
.62533 .65917 Mdot
.4154 .61959 Mdot
.7498 .31004 Mdot
.66734 .55047 Mdot
.32055 .73436 Mdot
.54988 .54678 Mdot
.28372 .73304 Mdot
.55689 .77899 Mdot
.34311 .6826 Mdot
.75468 .62452 Mdot
.42187 .67634 Mdot
.75948 .55299 Mdot
.45796 .54203 Mdot
.73877 .4548 Mdot
.56143 .58203 Mdot
.76111 .54761 Mdot
.62192 .65761 Mdot
.52783 .15694 Mdot
.86635 .56605 Mdot
.30471 .2376 Mdot
.73978 .72771 Mdot
.39902 .41501 Mdot
.63167 .40737 Mdot
.84043 .51934 Mdot
.49733 .14577 Mdot
.79749 .34904 Mdot
.22621 .55279 Mdot
.52521 .73525 Mdot
.35903 .45369 Mdot
.3044 .24196 Mdot
.5971 .78045 Mdot
.79578 .40183 Mdot
.19737 .40861 Mdot
.28837 .51695 Mdot
.2034 .58312 Mdot
.32588 .24302 Mdot
.66185 .26709 Mdot
.48667 .23832 Mdot
.55701 .50949 Mdot
.58851 .23101 Mdot
.41246 .38461 Mdot
.26293 .61914 Mdot
.71889 .62085 Mdot
.47887 .63414 Mdot
.64893 .5675 Mdot
.70347 .45076 Mdot
.55416 .49056 Mdot
.474 .59919 Mdot
.3879 .37304 Mdot
.38946 .24817 Mdot
.31215 .43315 Mdot
.64439 .18348 Mdot
.29878 .61079 Mdot
.6899 .45075 Mdot
.70373 .64874 Mdot
.39724 .74193 Mdot
.2157 .50767 Mdot
.34096 .51734 Mdot
.70389 .25749 Mdot
.3979 .46776 Mdot
.69482 .63771 Mdot
.57025 .2228 Mdot
.79004 .52386 Mdot
.66825 .44079 Mdot
.32588 .38927 Mdot
.67538 .34258 Mdot
.48738 .51318 Mdot
.47809 .34615 Mdot
.40307 .39246 Mdot
.782 .72291 Mdot
.29636 .56166 Mdot
.3115 .6674 Mdot
.71402 .26851 Mdot
.30419 .48875 Mdot
.44704 .3153 Mdot
.75102 .53704 Mdot
.794 .576 Mdot
.64959 .32645 Mdot
.41813 .65221 Mdot
.48849 .69517 Mdot
.52939 .79593 Mdot
.66244 .22844 Mdot
.61865 .2074 Mdot
.23875 .70176 Mdot
.42171 .30301 Mdot
.78896 .49809 Mdot
.7806 .59422 Mdot
.46053 .34361 Mdot
.46425 .30904 Mdot
.32999 .28651 Mdot
.58507 .15881 Mdot
.24327 .45971 Mdot
.72728 .7316 Mdot
.61169 .62578 Mdot
.53702 .71512 Mdot
.41615 .74757 Mdot
.72694 .68476 Mdot
.71983 .27573 Mdot
.49354 .2167 Mdot
.64011 .24255 Mdot
.6822 .46443 Mdot
.43106 .26775 Mdot
.28853 .25013 Mdot
.43197 .52537 Mdot
.6451 .27777 Mdot
.36143 .42299 Mdot
.58498 .41373 Mdot
.40507 .15811 Mdot
.81261 .55787 Mdot
.20333 .48979 Mdot
.34647 .52723 Mdot
.61833 .42661 Mdot
.57019 .40418 Mdot
.50298 .43033 Mdot
.29978 .38955 Mdot
.36724 .21679 Mdot
.72956 .68392 Mdot
.43802 .42688 Mdot
.55063 .22158 Mdot
.31752 .60381 Mdot
.75173 .3298 Mdot
.82307 .51014 Mdot
.48027 .52975 Mdot
.30331 .59794 Mdot
.57067 .61394 Mdot
.75313 .70739 Mdot
.51272 .58122 Mdot
.69244 .5154 Mdot
.27165 .32644 Mdot
.2894 .41334 Mdot
.40867 .75099 Mdot
.64656 .46485 Mdot
.23138 .59269 Mdot
.77423 .36347 Mdot
.27256 .75979 Mdot
.25084 .67374 Mdot
.43052 .14184 Mdot
.6951 .33144 Mdot
.27972 .4211 Mdot
.60256 .21339 Mdot
.26374 .76086 Mdot
.51003 .58688 Mdot
.55456 .18062 Mdot
.57173 .62248 Mdot
.68954 .24705 Mdot
.33535 .52718 Mdot
.23539 .41848 Mdot
.35677 .23461 Mdot
.59814 .16633 Mdot
.7725 .43681 Mdot
.7306 .29596 Mdot
.54944 .54931 Mdot
.5536 .14772 Mdot
.27579 .31482 Mdot
.47758 .58032 Mdot
.52086 .65303 Mdot
.2304 .52599 Mdot
.5012 .19426 Mdot
.35898 .36011 Mdot
.76863 .58001 Mdot
.44667 .59624 Mdot
.69546 .38672 Mdot
.61245 .22878 Mdot
.6908 .56726 Mdot
.30269 .41562 Mdot
.70142 .6501 Mdot
.78909 .37363 Mdot
.45809 .59988 Mdot
.4251 .74511 Mdot
.31332 .63347 Mdot
.6923 .74245 Mdot
.301 .38446 Mdot
.29043 .56364 Mdot
.78314 .42754 Mdot
.58821 .77026 Mdot
.73648 .65188 Mdot
.85067 .65793 Mdot
.73928 .68803 Mdot
.36178 .27601 Mdot
.48896 .16733 Mdot
.82407 .48753 Mdot
.37563 .26171 Mdot
.23353 .67222 Mdot
.45608 .28322 Mdot
.73746 .57413 Mdot
.59239 .47415 Mdot
.51026 .13312 Mdot
.68791 .59175 Mdot
.49811 .1615 Mdot
.83799 .55963 Mdot
.58748 .22713 Mdot
.54849 .48691 Mdot
.47349 .60781 Mdot
.37803 .5608 Mdot
.69957 .55721 Mdot
.65252 .24631 Mdot
.46593 .29044 Mdot
.37601 .67866 Mdot
.34106 .65503 Mdot
.43634 .63068 Mdot
.46767 .4105 Mdot
.28787 .59353 Mdot
.3048 .40161 Mdot
.64331 .73954 Mdot
.50444 .55531 Mdot
.7473 .59876 Mdot
.5108 .22653 Mdot
.67036 .27603 Mdot
.30272 .73605 Mdot
.37737 .44064 Mdot
.46557 .66803 Mdot
.71587 .31915 Mdot
.75506 .67604 Mdot
.32753 .416 Mdot
.42372 .18456 Mdot
.21767 .52294 Mdot
.73646 .51637 Mdot
.75007 .45632 Mdot
.26994 .71162 Mdot
.58137 .82339 Mdot
.46484 .1887 Mdot
.39804 .2583 Mdot
.68058 .69766 Mdot
.70678 .46238 Mdot
.66384 .20663 Mdot
.7528 .64152 Mdot
.74879 .43854 Mdot
.41972 .52023 Mdot
.6158 .31329 Mdot
.57093 .21488 Mdot
.63696 .58599 Mdot
.52276 .54868 Mdot
.16987 .40042 Mdot
.39828 .30432 Mdot
.38829 .16061 Mdot
.33876 .50605 Mdot
.17716 .5223 Mdot
.63242 .67202 Mdot
.45593 .53428 Mdot
.52533 .54523 Mdot
.32594 .3814 Mdot
.28753 .32693 Mdot
.77161 .67518 Mdot
.30732 .7562 Mdot
.48576 .61064 Mdot
.70321 .69688 Mdot
.66913 .75998 Mdot
.70701 .29592 Mdot
.62191 .504 Mdot
.73222 .70169 Mdot
.43239 .52041 Mdot
.41519 .76972 Mdot
.83504 .53012 Mdot
.3588 .39433 Mdot
.66809 .40789 Mdot
.73226 .61066 Mdot
.5518 .18202 Mdot
.77218 .31991 Mdot
.19811 .6094 Mdot
.39779 .40977 Mdot
.36618 .48208 Mdot
.62267 .55832 Mdot
.67246 .24455 Mdot
.6735 .66926 Mdot
.2478 .42267 Mdot
.74702 .61692 Mdot
.29017 .22189 Mdot
.38534 .20799 Mdot
.36607 .21783 Mdot
.69819 .66584 Mdot
.45844 .3137 Mdot
.31542 .27784 Mdot
.74769 .4463 Mdot
.34884 .38405 Mdot
.7803 .64218 Mdot
.76239 .5813 Mdot
.20306 .67513 Mdot
.702 .37868 Mdot
.56599 .74334 Mdot
.5422 .20547 Mdot
.58056 .34796 Mdot
.35399 .51827 Mdot
.72579 .57307 Mdot
.38446 .42436 Mdot
.346 .4492 Mdot
.30629 .41141 Mdot
.26849 .39091 Mdot
.74884 .43524 Mdot
.65614 .32015 Mdot
.41333 .42246 Mdot
.73661 .34881 Mdot
.41014 .29037 Mdot
.43288 .75994 Mdot
.40866 .73793 Mdot
.4656 .44951 Mdot
.47025 .62367 Mdot
.65872 .3775 Mdot
.4947 .52774 Mdot
.55244 .59945 Mdot
.26958 .28224 Mdot
.57801 .67495 Mdot
.44223 .30485 Mdot
.18654 .4845 Mdot
.46333 .34653 Mdot
.47315 .13595 Mdot
.37121 .7605 Mdot
.57045 .22492 Mdot
.51345 .78427 Mdot
.48635 .81881 Mdot
.13982 .51563 Mdot
.42601 .22723 Mdot
.41198 .51094 Mdot
.37871 .29235 Mdot
.39028 .3426 Mdot
.39914 .67586 Mdot
.34381 .65495 Mdot
.4954 .24468 Mdot
.3349 .59553 Mdot
.73451 .50445 Mdot
.46697 .38206 Mdot
.56197 .73057 Mdot
.62004 .3628 Mdot
.60196 .16399 Mdot
.46237 .66139 Mdot
.20601 .32258 Mdot
.57302 .39655 Mdot
.72513 .37468 Mdot
.84576 .50146 Mdot
.19713 .59242 Mdot
.35904 .72351 Mdot
.615 .80215 Mdot
.54509 .45105 Mdot
.41593 .42061 Mdot
.4207 .33308 Mdot
.77151 .49864 Mdot
.61001 .6937 Mdot
.66553 .63163 Mdot
.29831 .47182 Mdot
.32735 .73634 Mdot
.28429 .59906 Mdot
.47157 .33903 Mdot
.37107 .39464 Mdot
.76794 .45266 Mdot
.24277 .38995 Mdot
.43357 .51766 Mdot
.70197 .29434 Mdot
.64558 .3208 Mdot
.46339 .38453 Mdot
.41788 .1953 Mdot
.77472 .60117 Mdot
.74135 .26493 Mdot
.59412 .53504 Mdot
.41083 .54847 Mdot
.23148 .39116 Mdot
.32338 .40201 Mdot
.50016 .23144 Mdot
.82308 .466 Mdot
.70161 .62999 Mdot
.22168 .43398 Mdot
.75878 .54619 Mdot
.52248 .45386 Mdot
.48238 .5596 Mdot
.24801 .58826 Mdot
.17754 .62611 Mdot
.44404 .2532 Mdot
.22387 .62728 Mdot
.37927 .28329 Mdot
.31648 .6015 Mdot
.3979 .29762 Mdot
.4447 .7313 Mdot
.63507 .30931 Mdot
.33173 .69878 Mdot
.69639 .22656 Mdot
.82653 .47165 Mdot
.27913 .50614 Mdot
.48219 .68897 Mdot
.50965 .50826 Mdot
.66843 .49228 Mdot
.47042 .4808 Mdot
.55403 .42998 Mdot
.49557 .40733 Mdot
.19333 .57149 Mdot
.34155 .38715 Mdot
.54333 .50373 Mdot
.65336 .20504 Mdot
.74883 .27405 Mdot
.54499 .14942 Mdot
.67341 .7056 Mdot
.45081 .37546 Mdot
.41925 .17098 Mdot
.53882 .24711 Mdot
.78927 .36793 Mdot
.45525 .19579 Mdot
.80206 .69956 Mdot
.65112 .2485 Mdot
.3514 .42324 Mdot
.32843 .76013 Mdot
.29097 .33882 Mdot
.82616 .55221 Mdot
.47561 .58282 Mdot
.40242 .69146 Mdot
.82757 .55987 Mdot
.12074 .53373 Mdot
.42378 .24091 Mdot
.26266 .40078 Mdot
.71158 .46981 Mdot
.45038 .43936 Mdot
.36816 .59283 Mdot
.6136 .48803 Mdot
.4873 .68129 Mdot
.37951 .74394 Mdot
.75244 .59585 Mdot
.71871 .4076 Mdot
.36821 .59491 Mdot
.70485 .55109 Mdot
.76092 .50853 Mdot
.7441 .66664 Mdot
.67391 .27058 Mdot
.49943 .24177 Mdot
.67189 .41542 Mdot
.43185 .29263 Mdot
.61237 .72544 Mdot
.36843 .7042 Mdot
.57865 .48493 Mdot
.34229 .70374 Mdot
.26299 .35398 Mdot
.43292 .14515 Mdot
.42076 .71839 Mdot
.80319 .56482 Mdot
.38032 .33253 Mdot
.3092 .38922 Mdot
.75483 .36607 Mdot
.22069 .58457 Mdot
.38521 .59968 Mdot
.53549 .36916 Mdot
.64437 .20864 Mdot
.22864 .48945 Mdot
.78743 .55416 Mdot
.23426 .33732 Mdot
.34141 .45322 Mdot
.42166 .25646 Mdot
.71113 .48531 Mdot
.2174 .54546 Mdot
.48036 .37333 Mdot
.30527 .43019 Mdot
.42314 .56749 Mdot
.23026 .4971 Mdot
.81278 .60577 Mdot
.77948 .48478 Mdot
.52175 .20365 Mdot
.62582 .20835 Mdot
.48715 .67722 Mdot
.77441 .5796 Mdot
.30419 .43298 Mdot
.39694 .58526 Mdot
.221 .40237 Mdot
.64649 .18993 Mdot
.48268 .49578 Mdot
.67054 .5946 Mdot
.60099 .41459 Mdot
.56922 .26729 Mdot
.3353 .3794 Mdot
.58673 .64761 Mdot
.30831 .65415 Mdot
.40097 .36218 Mdot
.28193 .6196 Mdot
.4197 .63397 Mdot
.72304 .58545 Mdot
.36972 .32798 Mdot
.4984 .34123 Mdot
.61749 .67348 Mdot
.3788 .67028 Mdot
.66121 .47673 Mdot
.66175 .60537 Mdot
.66523 .6844 Mdot
.42402 .25224 Mdot
.41139 .2356 Mdot
.70677 .30049 Mdot
.79379 .59248 Mdot
.34231 .40901 Mdot
.45265 .19446 Mdot
.29558 .31994 Mdot
.65666 .30179 Mdot
.2592 .64063 Mdot
.58356 .40546 Mdot
.44897 .73107 Mdot
.45402 .31964 Mdot
.68062 .2589 Mdot
.69194 .33555 Mdot
.65227 .58414 Mdot
.45538 .50917 Mdot
.76362 .38122 Mdot
.43358 .48253 Mdot
.84338 .50904 Mdot
.29359 .337 Mdot
.71728 .62087 Mdot
.29519 .51694 Mdot
.58377 .62847 Mdot
.26139 .69649 Mdot
.73598 .2727 Mdot
.30862 .7429 Mdot
.55815 .5658 Mdot
.21652 .61389 Mdot
.35343 .26162 Mdot
.83414 .55706 Mdot
.72556 .60353 Mdot
.4681 .4793 Mdot
.60707 .36348 Mdot
.27978 .47619 Mdot
.37163 .66636 Mdot
.46784 .73696 Mdot
.51582 .24746 Mdot
.49393 .70766 Mdot
.33954 .71368 Mdot
.66488 .47815 Mdot
.23635 .35429 Mdot
.63281 .20775 Mdot
.68417 .37318 Mdot
.44376 .53437 Mdot
.46022 .77596 Mdot
.71165 .59438 Mdot
.64159 .83962 Mdot
.40386 .15755 Mdot
.60441 .4143 Mdot
.55521 .58124 Mdot
.67394 .62446 Mdot
.45721 .62204 Mdot
.50054 .25858 Mdot
.70099 .28836 Mdot
.31859 .51421 Mdot
.51338 .73859 Mdot
.23631 .50703 Mdot
.3274 .37169 Mdot
.63519 .57771 Mdot
.32867 .54833 Mdot
.45369 .13724 Mdot
.75838 .67927 Mdot
.33454 .39722 Mdot
.70333 .79502 Mdot
.23468 .57887 Mdot
.38408 .38084 Mdot
.77299 .4202 Mdot
.53049 .1561 Mdot
.6907 .65754 Mdot
.47706 .76469 Mdot
.39385 .23321 Mdot
.71059 .62301 Mdot
.76862 .52653 Mdot
.31291 .63271 Mdot
.28825 .62682 Mdot
.46033 .56906 Mdot
.489 .8186 Mdot
.28563 .28019 Mdot
.51863 .21528 Mdot
.59282 .19123 Mdot
.34801 .73665 Mdot
.21277 .68975 Mdot
.73688 .26607 Mdot
.72755 .55543 Mdot
.35795 .60095 Mdot
.78135 .43625 Mdot
.63179 .62559 Mdot
.52615 .37186 Mdot
.36608 .75277 Mdot
.63572 .32882 Mdot
.45886 .81049 Mdot
.27161 .67097 Mdot
.75996 .55066 Mdot
.55679 .35239 Mdot
.49022 .50436 Mdot
.7023 .30389 Mdot
.32355 .66427 Mdot
.71344 .6523 Mdot
.51766 .74664 Mdot
.61692 .60936 Mdot
.72057 .31696 Mdot
.78036 .40229 Mdot
.47273 .47497 Mdot
.12398 .5238 Mdot
.51306 .16938 Mdot
.23164 .60705 Mdot
.61277 .40003 Mdot
.68743 .21542 Mdot
.45364 .4525 Mdot
.43951 .19971 Mdot
.80386 .60362 Mdot
.40624 .72935 Mdot
.23755 .37786 Mdot
.5737 .40944 Mdot
.43016 .21765 Mdot
.64398 .27378 Mdot
.57428 .3476 Mdot
.38697 .74778 Mdot
.70359 .64618 Mdot
.34565 .63342 Mdot
.61993 .59207 Mdot
.65665 .51191 Mdot
.46672 .3378 Mdot
.47355 .14422 Mdot
.5899 .55906 Mdot
.6079 .36947 Mdot
.52428 .5047 Mdot
.30905 .75072 Mdot
.6562 .80458 Mdot
.63872 .52158 Mdot
.22789 .48482 Mdot
.76607 .58375 Mdot
.74191 .4789 Mdot
.4237 .23405 Mdot
.28442 .81949 Mdot
.84586 .48765 Mdot
.38787 .33057 Mdot
.47232 .29006 Mdot
.70562 .67281 Mdot
.55595 .15564 Mdot
.52413 .80845 Mdot
.39649 .73747 Mdot
.32331 .7857 Mdot
.64614 .63802 Mdot
.62486 .49182 Mdot
.81144 .62628 Mdot
.74207 .28009 Mdot
.33249 .73473 Mdot
.67046 .21433 Mdot
.54788 .4904 Mdot
.59375 .39576 Mdot
.45975 .89141 Mdot
.69011 .25642 Mdot
.5619 .50181 Mdot
.29017 .74254 Mdot
.47249 .39121 Mdot
.59026 .48251 Mdot
.33465 .58234 Mdot
.75068 .63883 Mdot
.76388 .51632 Mdot
.59643 .16568 Mdot
.47411 .34044 Mdot
.3445 .70821 Mdot
.29484 .48929 Mdot
.5257 .54735 Mdot
.63315 .39392 Mdot
.32588 .46965 Mdot
.74228 .51725 Mdot
.46653 .45563 Mdot
.31623 .53527 Mdot
.70694 .7066 Mdot
.83322 .62414 Mdot
.69138 .32063 Mdot
.2764 .51204 Mdot
.51115 .43437 Mdot
.68522 .36956 Mdot
.70262 .55465 Mdot
.71466 .51841 Mdot
.8228 .58174 Mdot
.88148 .4784 Mdot
.42292 .69635 Mdot
.55324 .52366 Mdot
.37084 .34785 Mdot
.50924 .23829 Mdot
.64665 .25796 Mdot
.36774 .50898 Mdot
.35556 .6482 Mdot
.53798 .44066 Mdot
.65341 .51482 Mdot
.29309 .47839 Mdot
.3396 .19204 Mdot
.63201 .4814 Mdot
.46958 .21934 Mdot
.77975 .355 Mdot
.42917 .75887 Mdot
.71662 .37346 Mdot
.55339 .47771 Mdot
.30251 .28978 Mdot
.44661 .44942 Mdot
.47926 .43431 Mdot
.41477 .74398 Mdot
.58409 .17422 Mdot
.6943 .33895 Mdot
.50741 .20622 Mdot
.63097 .4482 Mdot
.56907 .69151 Mdot
.25568 .39606 Mdot
.40275 .22111 Mdot
.69223 .46148 Mdot
.78725 .35019 Mdot
.41289 .73217 Mdot
.50737 .70358 Mdot
.72261 .42753 Mdot
.48587 .15685 Mdot
.24947 .66207 Mdot
.62081 .24284 Mdot
.2003 .51064 Mdot
.25965 .55369 Mdot
.69266 .56799 Mdot
.47086 .60889 Mdot
.54227 .50399 Mdot
.47369 .38692 Mdot
.49049 .1219 Mdot
.39647 .2237 Mdot
.27666 .46044 Mdot
.37252 .68417 Mdot
.60726 .26584 Mdot
.51071 .52365 Mdot
.75595 .75545 Mdot
.58265 .79373 Mdot
.44783 .13763 Mdot
.76922 .48846 Mdot
.42545 .4076 Mdot
.28719 .4271 Mdot
.62849 .38392 Mdot
.48381 .66241 Mdot
.56514 .16146 Mdot
.62992 .5297 Mdot
.27315 .66141 Mdot
.62679 .48957 Mdot
.20011 .47363 Mdot
.4022 .43612 Mdot
.4644 .68789 Mdot
.43703 .68015 Mdot
.23769 .6745 Mdot
.77099 .36866 Mdot
.43997 .45044 Mdot
.74499 .74972 Mdot
.61959 .21834 Mdot
.70599 .25893 Mdot
.42123 .64826 Mdot
.18117 .58895 Mdot
.35944 .31838 Mdot
.39023 .42102 Mdot
.31762 .43256 Mdot
.58292 .58383 Mdot
.22125 .52806 Mdot
.74439 .4883 Mdot
.27123 .36641 Mdot
.27965 .49644 Mdot
.92317 .49429 Mdot
.7384 .54387 Mdot
.69639 .41881 Mdot
.23806 .59978 Mdot
.68266 .23273 Mdot
.64725 .713 Mdot
.81945 .63071 Mdot
.52791 .58528 Mdot
.62346 .39355 Mdot
.66569 .32873 Mdot
.72719 .40616 Mdot
.2341 .52249 Mdot
.14605 .45722 Mdot
.7647 .66286 Mdot
.46261 .70164 Mdot
.49943 .55086 Mdot
.45837 .3386 Mdot
.40286 .31044 Mdot
.49994 .79716 Mdot
.79043 .68251 Mdot
.42928 .43319 Mdot
.67517 .24623 Mdot
.14717 .54104 Mdot
.78135 .51831 Mdot
.56514 .15541 Mdot
.35586 .31033 Mdot
.45122 .29649 Mdot
.71012 .54553 Mdot
.57751 .71963 Mdot
.42466 .67037 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0;;ooooo0_l0002Eooooo`007?ooool00ol0003oooooooooo`2boooo
o`;o0000UOooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0VOooool2o`000:kooooo000Looooo`03o`000?oooooooooo08Kooooo0_l0000Aooooo`;o0000
[_ooool001cooooo00?o0000ooooooooool0Q_ooool2o`0001Cooooo1?l0002Yooooo`007?ooool0
0ol0003oooooooooo`2Looooo`Co0000ZOooool001cooooo00?o0000ooooooooool0Yoooool2o`00
0:3ooooo000Looooo`03o`000?oooooooooo09Oooooo0_l0000>ooooo`;o0000X?ooool001cooooo
00?o0000ooooooooool0Uoooool2o`0000Wooooo0_l0002Uooooo`007?ooool00ol0003ooooooooo
o`2>ooooo`Co00001?ooool2o`0000[ooooo0_l0002Uooooo`007?ooool00ol0003oooooooooo`26
ooooo`;o00001_ooool4o`0000Cooooo0_l0002aooooo`007?ooool00ol0003oooooooooo`26oooo
o`Co00003?ooool2o`000;7ooooo000Looooo`03o`000?oooooooooo08Sooooo0ol00002ooooo`;o
00001oooool2o`0000Kooooo0_l0000Eooooo`;o0000T_ooool001cooooo00?o0000ooooooooool0
ROooool2o`0000;ooooo0_l00002ooooo`;o00002oooool2o`0000gooooo0_l000000ooooooo0000
o`000003ooooo`;o0000T_ooool001cooooo0_l00023ooooo`;o00003Oooool2o`0000_ooooo0_l0
000=ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Nooooo`;o0000M?ooool001cooooo00?o
0000ooooooooool0P_ooool2o`0001Kooooo1_l00004ooooo`;o00000oooool2o`0000Kooooo1Ol0
000Mooooo`?o0000Loooool001cooooo00?o0000ooooooooool0Ooooool3o`0001Sooooo1?l00006
ooooo`;o00000_ooool3o`0000Kooooo0_l000000ooooooo0000o`000004ooooo`;o00006?ooool4
o`00077ooooo000Looooo`03o`000?oooooooooo07[ooooo0_l00002ooooo`Co00003_ooool2o`00
00cooooo0_l00008ooooo`;o00002_ooool2o`0000Cooooo0_l0000Jooooo`;o0000LOooool001co
oooo00?o0000ooooooooool0N_ooool2o`0000;ooooo0_l0000@ooooo`;o00003?ooool2o`0000?o
oooo0_l0000?ooooo`;o00002?ooool4o`0008Oooooo000Looooo`03o`000?oooooooooo093ooooo
0_l00009ooooo`;o000000?oooooo`000?l000000oooool2o`0000Sooooo0_l0000?ooooo`Co0000
Qoooool001cooooo00?o0000ooooooooool0Q?ooool2o`0000Kooooo0_l00002ooooo`;o00002Ooo
ool2o`0000Kooooo0_l00008ooooo`;o00002_ooool2o`0000Cooooo0_l00028ooooo`007?ooool0
0ol0003oooooooooo`24ooooo`;o00001_ooool2o`0000[ooooo0ol00008ooooo`;o00005?ooool3
o`0000?ooooo0_l00028ooooo`007?ooool00ol0003oooooooooo`2;ooooo`;o00002oooool3o`00
00Oooooo0_l0000@ooooo`;o00000_ooool4o`0000?ooooo0_l00028ooooo`007?ooool00ol0003o
ooooooooo`22ooooo`;o00001oooool2o`0000_ooooo0_l00008ooooo`;o00003?ooool2o`0000;o
oooo0_l00002ooooo`;o00002Oooool2o`0008Cooooo000Looooo`03o`000?oooooooooo08;ooooo
0_l00002ooooo`;o00004?ooool2o`0001Gooooo0ol0000=ooooo`;o00000_ooool2o`0000Sooooo
0ol0001iooooo`007?ooool00ol0003oooooooooo`26ooooo`;o00001_ooool2o`0001Gooooo0_l0
0008ooooo`;o00003_ooool2o`0000cooooo0ol0001iooooo`007?ooool00ol0003oooooooooo`2:
ooooo`;o00000_ooool2o`0000;ooooo0ol00002ooooo`;o00003?ooool2o`00017ooooo0_l0000>
ooooo`;o00001?ooool2o`0007Wooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ
8B44ooooo`Go00001_ooool00ol0003oooooooooo`1[ooooo`;o00007Oooool2o`0000Kooooo1?l0
00000ooooooo0000o`00000:ooooo`;o00001?ooool2o`0000?ooooo0_l00008ooooo`;o00000ooo
ool2o`0000Wooooo0_l00004ooooo`;o0000NOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo06_o
oooo0_l0000@ooooo`;o00001Oooool2o`0000Oooooo1Ol00002ooooo`;o00002Oooool2o`0000;o
oooo0_l00004ooooo`;o00000oooool2o`0000gooooo0_l0000;ooooo`;o00000_ooool2o`0007Wo
oooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h0
1oooool00ol0003oooooooooo`1mooooo`;o00001Oooool2o`0000Gooooo1ol0000=ooooo`;o0000
2oooool3o`0001_ooooo0ol000000ooooooo0000o`00001iooooo`0000?oooooo`000?ooool00_oo
ool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0002;ooooo`;o00001Ooo
ool2o`0001Sooooo0ol0000?ooooo`;o00002_ooool5o`0007[ooooo00000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`2B
ooooo`;o00004_ooool2o`0000Cooooo0_l00009ooooo`;o00001Oooool2o`0000[ooooo0_l00000
1?oooooo0000o`000?ooool2o`0000;ooooo0_l0001cooooo`0000?ooooooa0@4?ooool00_ooool0
0ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0NOooool2
o`0002;ooooo0_l00002ooooo`;o00000oooool2o`0000Cooooo0_l00009ooooo`Co00002_ooool2
o`000003ooooool0003o000000;o00000_ooool4o`0000;ooooo0_l0001cooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003ooooo
ooooo`1iooooo`;o00008_ooool2o`0000;ooooo0_l00003ooooo`;o00001_ooool2o`0000Wooooo
0_l00004ooooo`;o00001?ooool2o`000003ooooool0003o000000;o00000_ooool2o`0000Cooooo
0ol0001booooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01_ooool00ol0003oooooooooo`1Sooooo`;o00002?ooool2o`000003ooooool0003o0000
01Oooooo0ol0000Iooooo`;o00001oooool2o`0000Kooooo0_l00005ooooo`Go00004oooool5o`00
00;ooooo0_l0000<ooooo`;o0000GOooool001cooooo00?o0000ooooooooool0Hoooool2o`0000So
oooo0_l000001?oooooo0000o`000?ooool3o`0001;ooooo1Ol0000@ooooo`;o00001_ooool4o`00
00gooooo0_l00005ooooo`;o000000?oooooo`000?l000000oooool2o`0000oooooo1?l00002oooo
o`;o00003?ooool2o`0005gooooo000Looooo`03o`000?oooooooooo07?ooooo0ol00008ooooo`?o
00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000008ooooo`;o00001_ooool2o`000003
ooooool0003o000000Gooooo0_l00006ooooo`;o00005?ooool2o`0000_ooooo0_l000000ooooooo
0000o`00001booooo`007?ooool00ol0003oooooooooo`1Kooooo`;o00006oooool2o`0000?ooooo
1Ol00002ooooo`Co00003Oooool2o`0000Oooooo1?l00005ooooo`;o00000oooool2o`000003oooo
ool0003o000000Cooooo0_l0000Cooooo`;o00001_ooool5o`0007;ooooo000Looooo`03o`000?oo
oooooooo05_ooooo0_l00009ooooo`;o00004?ooool3o`0000;ooooo1Ol00004ooooo`?o00005Ooo
ool6o`0000?ooooo0ol00002ooooo`;o00000oooool3o`000004ooooool0003o0000o`0000?ooooo
0_l0000=ooooo`;o00002?ooool2o`0000Sooooo0_l00007ooooo`;o0000H?ooool001cooooo00?o
0000ooooooooool0I?ooool4o`0000Cooooo0_l0000;ooooo`;o00003?ooool2o`0001Oooooo1Ol0
0002ooooo`?o00000oooool2o`0000;ooooo0ol00002ooooo`;o00000oooool2o`0000Kooooo0_l0
000>ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Oooooo0_l0001Pooooo`007?ooool0
0ol0003oooooooooo`1Tooooo`;o00001_ooool2o`0000?ooooo0ol00008ooooo`?o00007_ooool8
o`0000?ooooo0_l00003ooooo`;o00003?ooool3o`0000Gooooo0_l0000>ooooo`;o000000?ooooo
o`000?l000000_ooool2o`0006gooooo000Looooo`03o`000?oooooooooo073ooooo1?l00008oooo
o`?o00000oooool6o`0001Gooooo1_l00005ooooo`;o00004Oooool3o`0001Sooooo0_l00002oooo
o`;o00005?ooool2o`0005Oooooo000Looooo`03o`000?oooooooooo05oooooo0_l00009ooooo`;o
00000_ooool4o`00013ooooo1_l0000Booooo`;o00001_ooool2o`0000Cooooo0_l000000ooooooo
0000o`00000;ooooo`;o000000?oooooo`000?l000000_l0000Gooooo`;o00006?ooool2o`0005Oo
oooo000Looooo`03o`000?oooooooooo05oooooo1?l00003ooooo`;o00000_ooool2o`0000;ooooo
0_l0000<ooooo`;o00002?ooool2o`000003ooooool0003o000000oooooo0_l00002ooooo`;o0000
0_ooool2o`0000Oooooo0_l0000;ooooo`Co000000?oooooo`000?l000001oooool2o`0000Cooooo
0_l0000Booooo`;o0000Ioooool001cooooo00?o0000ooooooooool0Goooool4o`0000?ooooo0_l0
0006ooooo`;o00003?ooool2o`0000Sooooo0_l000000ooooooo0000o`00000Booooo`?o00001?oo
ool2o`0000gooooo0_l00005ooooo`;o00002_ooool2o`0000;ooooo1?l00009ooooo`?o00001_oo
ool2o`0006Oooooo000Looooo`03o`000?oooooooooo05cooooo0_l00008ooooo`;o00001_ooool2
o`0000[ooooo0ol0000<ooooo`;o00001oooool3o`0000Sooooo0_l00005ooooo`;o00001Oooool2
o`0000Kooooo0_l00002ooooo`;o00001?ooool2o`0000?ooooo0_l00006ooooo`;o00001?ooool2
o`0000Gooooo0ol00002ooooo`;o00005_ooool2o`0005?ooooo000Looooo`;o0000Foooool4o`00
00Kooooo1?l00005ooooo`;o00002oooool3o`0000Wooooo0_l0000:ooooo`?o00003oooool2o`00
00Gooooo0_l00003ooooo`;o00001Oooool2o`0000Cooooo1?l000001?oooooo0000o`000?ooool2
o`0000Wooooo0_l0000:ooooo`;o000000?oooooo`000?l000004oooool4o`00057ooooo000Loooo
o`03o`000?oooooooooo05[ooooo0_l00008ooooo`?o00001_ooool2o`0000Sooooo0_l0000=oooo
o`;o00001?ooool2o`0001Kooooo0_l0000:ooooo`;o00002_ooool2o`000003ooooool0003o0000
00Cooooo0_l00004ooooo`;o00001oooool2o`0000Wooooo0_l00005ooooo`;o00003?ooool4o`00
00;ooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`1Booooo`;o00004Oooool2o`0000So
oooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0ol00004ooooo`;o00002?ooool2o`0000go
oooo0_l0000Dooooo`?o000000?oooooo`000?l000002_ooool2o`000003ooooool0003o000000Co
oooo0_l00006ooooo`;o00000oooool2o`0000?ooooo0_l0000Booooo`;o0000COooool001cooooo
00?o0000ooooooooool0B?ooool2o`0000Sooooo0_l0000Kooooo`Co00002oooool2o`0000Gooooo
0ol00002ooooo`;o00001?ooool4o`0000;ooooo0_l00007ooooo`;o00000oooool3o`0000?ooooo
0_l0000?ooooo`;o00000_ooool2o`0000gooooo0_l00009ooooo`;o000000?oooooo`000?l00000
0oooool3o`0006Gooooo000Looooo`03o`000?oooooooooo04Sooooo0_l0000=ooooo`;o00004_oo
ool2o`0000;ooooo1?l00003ooooo`;o00004_ooool2o`0000Cooooo1?l0000;ooooo`;o00000ooo
ool2o`0000Cooooo0_l0000@ooooo`;o00004?ooool2o`0000Wooooo0_l00007ooooo`;o00001_oo
ool2o`0005gooooo000Looooo`03o`000?oooooooooo04oooooo0_l00006ooooo`;o00004_ooool2
o`0000Wooooo0_l0000@ooooo`Co0000:?ooool3o`0000Gooooo0_l00003ooooo`;o00000oooool2
o`0000Kooooo0_l00003ooooo`;o00005Oooool5o`0005[ooooo000Looooo`03o`000?oooooooooo
04oooooo0_l0000Cooooo`;o00002?ooool3o`0001Oooooo0_l00005ooooo`;o00006?ooool2o`00
00Wooooo0ol0000:ooooo`;o00000oooool3o`0000[ooooo0_l00002ooooo`;o00002oooool2o`00
00Kooooo0ol0000<ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0I?ooool2o`0000So
oooo0ol0000?ooooo`;o000000?oooooo`000?l000001_ooool2o`0000;ooooo0_l0000Hooooo`;o
00002Oooool4o`0000oooooo0_l00004ooooo`;o00002?ooool2o`0000_ooooo0_l00005ooooo`;o
00003_ooool2o`0004cooooo000Looooo`03o`000?oooooooooo06Cooooo0_l0000<ooooo`;o0000
3?ooool2o`000003ooooool0003o000000;o00001?ooool2o`0000Kooooo0_l0000Jooooo`;o0000
1Oooool4o`0000Cooooo0_l0000=ooooo`;o00001?ooool2o`000003ooooool0003o000000kooooo
0ol00002ooooo`;o00000_ooool2o`0005Sooooo000Looooo`03o`000?oooooooooo05gooooo0_l0
0004ooooo`?o00003?ooool2o`0000_ooooo0_l00004ooooo`;o00001_ooool2o`0000Cooooo0_l0
000Jooooo`;o00001oooool2o`0000Cooooo0_l0000>ooooo`;o00000oooool5o`0000kooooo0ol0
0004ooooo`Co0000F?ooool001cooooo00?o0000ooooooooool0E?ooool2o`0000?ooooo0ol00000
0ooooooo0000o`000004ooooo`?o000000Coooooo`000?l0003ooooo1?l00008ooooo`Co00001Ooo
ool2o`0000Cooooo0_l00006ooooo`;o000000?oooooo`000?l000002_ooool2o`0002Oooooo0_l0
0007ooooo`;o00001?ooool2o`0001Oooooo0_l00005ooooo`;o0000Doooool001cooooo00?o0000
ooooooooool0E?ooool2o`0000?ooooo0ol00005ooooo`;o00001?ooool2o`000003ooooool0003o
000000;o00002?ooool4o`0000_ooooo0_l00009ooooo`;o00002_ooool2o`0002Oooooo0_l00000
0ooooooo0000o`000006ooooo`;o00000_ooool2o`0001kooooo0_l0001Cooooo`007?ooool00ol0
003oooooooooo`1Booooo`;o00003Oooool2o`0000Cooooo0_l00004ooooo`?o00000oooool2o`00
00;ooooo0_l0000?ooooo`;o000000?oooooo`000?l000002Oooool2o`00033ooooo1?l00002oooo
o`Co00000_ooool2o`0000[ooooo1?l00007ooooo`;o0000G?ooool001cooooo00?o0000oooooooo
ool0D_ooool2o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0000Kooooo0_l00004ooooo`?o
00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`;o00001Oooool2o`000003
ooooool0003o000000;o00001Oooool4o`0003;ooooo1_l0000<ooooo`;o000000?oooooo`000?l0
00000ol00007ooooo`;o00005_ooool2o`0004Cooooo000Looooo`03o`000?oooooooooo05Kooooo
0_l00002ooooo`;o00000oooool2o`0001?ooooo1Ol000001?oooooo0000o`000?ooool2o`0000;o
oooo1?l000000ooooooo0000o`000003o`0000;ooooo0_l00005ooooo`Co0000=?ooool2o`0000ko
oooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00002?ooool2o`0001Cooooo0_l00014oooo
o`007?ooool00ol0003oooooooooo`1Eooooo`;o00000_ooool2o`0001Wooooo1_l00003ooooo`?o
00000oooool8o`0000Cooooo0_l00008ooooo`;o00001_ooool2o`0003Kooooo0_l00005ooooo`Go
00001Oooool2o`000004ooooool0003o0000o`0005Wooooo000Looooo`;o0000E_ooool2o`0000;o
oooo0_l00003ooooo`;o00006?ooool2o`0000Cooooo0_l00004ooooo`So00000_ooool3o`0000So
oooo0_l00006ooooo`?o0000=Oooool2o`0000Oooooo0_l00006ooooo`Oo00000_ooool2o`0005Co
oooo000Looooo`03o`000?oooooooooo05Oooooo0_l00005ooooo`;o00007_ooool5o`000003oooo
ool0003o000000Ko00000_ooool2o`0000kooooo0_l00002ooooo`;o00009_ooool2o`0000Kooooo
0_l00002ooooo`;o00001?ooool2o`0000;ooooo1Ol00007ooooo`;o000000Goooooo`000?l0003o
0000ooooo`02o`0005Cooooo000Looooo`03o`000?oooooooooo05Oooooo0_l0000Booooo`;o0000
3Oooool2o`0000;ooooo1Ol000000ooooooo0000o`000009o`0000oooooo0_l0000Zooooo`;o0000
1?ooool4o`0000;ooooo0_l00004ooooo`;o00000_ooool2o`000003ooooool0003o000000_ooooo
0_l0001Gooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o00002Oooool2o`0000?ooooo0_l0
0008ooooo`;o000000?oooooo`000?l000004?l00002ooooo`So0000<Oooool3o`0000?ooooo0_l0
0009ooooo`;o00004oooool2o`0005Oooooo000Looooo`03o`000?oooooooooo063ooooo0_l00003
ooooo`;o00001_ooool2o`000003ooooool0003o000000_ooooo4_l00002ooooo`So0000:oooool2
o`0000Cooooo0ol0000>ooooo`;o00004oooool3o`0000Cooooo0_l0001@ooooo`007?ooool00ol0
003oooooooooo`1Fooooo`;o00003Oooool2o`0000;ooooo0_l00002ooooo`;o00001oooool2o`00
00Sooooo3ol000001?oooooo0000o`000?l0000Booooo`;o00007Oooool2o`0001;ooooo0_l0000<
ooooo`;o00002Oooool2o`0000Cooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`1Foooo
o`;o00001?ooool2o`0000;ooooo0_l00007ooooo`;o00001_ooool3o`0000;ooooo1Ol00005oooo
o`Oo000000?oooooo`000?l000002?l0000Aooooo`Co0000:_ooool2o`0000Gooooo0_l0000;oooo
o`?o00003oooool2o`00053ooooo000Looooo`03o`000?oooooooooo03oooooo0_l0000Eooooo`;o
00000oooool3o`0000;ooooo0_l0000?ooooo`?o00001?oooolBo`000003ooooool0003o000000Go
00001_ooool2o`0000Wooooo0_l0000Yooooo`;o000000?oooooo`000?l000002_ooool2o`0000Ko
oooo0_l00009ooooo`;o00001?ooool3o`0000?ooooo0_l0001;ooooo`007?ooool00ol0003ooooo
ooooo`0oooooo`;o00002_ooool2o`0000kooooo0_l0000Loooooa[o00001Oooool2o`0000;ooooo
0_l0000Wooooo`;o00001oooool2o`000003ooooool0003o000000[ooooo0_l0000Aooooo`?o0000
0oooool2o`0000Cooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o00000_oo
ool2o`0000Cooooo0_l00003ooooo`?o000000?oooooo`000?l000005?ooool2o`000003ooooool0
003o000000;o00000_ooool;o`0000;ooooo2Ol000000ooooooo0000o`000006ooooo`;o00009ooo
ool2o`0000Cooooo0_l00002ooooo`Co000000?oooooo`000?l000004Oooool2o`0000Sooooo0_l0
001Fooooo`007?ooool00ol0003oooooooooo`1?ooooo`?o00000oooool3o`0000;ooooo0_l00002
ooooo`;o00005?ooool8o`000003ooooool0003o000001So0000=?ooool2o`0000;ooooo0ol00002
ooooo`;o00002?ooool2o`0000Oooooo0_l00007ooooo`?o00002?ooool2o`0004cooooo000Loooo
o`03o`000?oooooooooo04oooooo0ol00004ooooo`;o00005Oooool2o`0000Kooooo9?l0000goooo
o`;o00002oooool3o`00013ooooo0ol00008ooooo`;o0000C?ooool001cooooo00?o0000oooooooo
ool0B?ooool2o`0000Gooooo0_l0000;ooooo`;o00003oooool2o`0000Wooooo6ol000000ooooooo
0000o`000003o`00027ooooo1?l0000Oooooo`;o000000?oooooo`000?l000004_ooool3o`0005;o
oooo000Looooo`03o`000?oooooooooo04Sooooo0_l0000Aooooo`?o00006ooooolEo`000003oooo
ool0003o000000Oo00001_ooool2o`0000Sooooo1_l00002ooooo`Co00001_ooool4o`0000Cooooo
0_l0000Iooooo`Go00002?ooool2o`0000?ooooo0_l00003ooooo`?o00006Oooool2o`0003Oooooo
000Looooo`03o`000?oooooooooo03kooooo0_l0000>ooooo`;o000000?oooooo`000?l000001Ooo
ool2o`000003ooooool0003o000000Gooooo0_l0000Aooooo`;o00000_oooolDo`000003ooooool0
003o000000So00001_ooool2o`0000Sooooo1_l00002ooooo`Ko00003?ooool2o`0000Wooooo0_l0
0002ooooo`;o00001Oooool2o`0000?ooooo0ol0000:ooooo`;o00000oooool2o`0000?ooooo0_l0
000Jooooo`;o0000=oooool001cooooo00?o0000ooooooooool0?_ooool2o`0000kooooo1Ol00005
ooooo`;o00002?ooool6o`0000gooooo8_l000001?oooooo0000o`000?l0000Iooooo`;o000000?o
ooooo`000?l000005?ooool2o`0000;ooooo0_l00005ooooo`;o00001_ooool2o`0006Oooooo000L
ooooo`;o0000B_ooool2o`0000?ooooo0ol0000Aooooo`Ko00003Oooool4o`0000;ooooo0ol00000
0ooooooo0000o`00000Do`0000?ooooo0ol00002ooooo`;o000000Coooooo`000?l0003ooooo0_l0
0007ooooo`;o00000oooool2o`0000Cooooo1?l0000Uooooo`;o00002Oooool2o`000003ooooool0
003o000000Oooooo0_l00003ooooo`;o000000?oooooo`000?l00000B?ooool001cooooo00?o0000
ooooooooool0BOooool2o`0000;ooooo0_l00003ooooo`;o00003_ooool2o`0000;ooooo0_l0000<
ooooo`;o00001OoooolNo`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0000Oooooo0_l0
00000ooooooo0000o`000002o`0000Kooooo0_l0000Zooooo`;o00001?ooool2o`000003ooooool0
003o000000Oooooo0_l00003ooooo`;o000000?oooooo`000?l00000B?ooool001cooooo00?o0000
ooooooooool0A_ooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000002
o`00023ooooo0_l00005oooooa3o000000?oooooo`000?l000002ol00004ooooo`Go00003Oooool8
o`0001;ooooo0_l00005ooooo`;o00004oooool2o`0000Oooooo0_l00009ooooo`;o0000C_ooool0
01cooooo00?o0000ooooooooool0?oooool2o`0000Gooooo1Ol00005ooooo`;o00006_ooool2o`00
00?ooooo0_l000000ooooooo0000o`000002ooooo`;o00000_oooolIo`000003ooooool0003o0000
00;ooooo2?l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo1ol000000ooo
oooo0000o`00000?ooooo`;o00001Oooool2o`0000;ooooo1?l0000Qooooo`;o0000C_ooool001co
oooo00?o0000ooooooooool0?oooool2o`0000Oooooo0_l0000=ooooo`;o00001oooool2o`0000[o
oooo0_l00003ooooo`;o00000oooool5o`000003ooooool0003o000001oo000000?oooooo`000?l0
00000_l00003ooooo`Go00000_ooool2o`0000[ooooo0_l00004ooooo`;o00001_ooool2o`0000[o
oooo1_l0000<ooooo`;o0000Hoooool001cooooo00?o0000ooooooooool0Eoooool2o`0000Oooooo
0_l0000Cooooo`?o000000Coooooo`000?l0003ooooo6ol000000ooooooo0000o`000004ooooo`Co
00001?ooool2o`0001Gooooo0ol000000ooooooo0000o`000002ooooo`?o00000oooool2o`0000Go
oooo0_l0000@ooooo`;o00002oooool2o`0000Gooooo0_l0001?ooooo`007?ooool00ol0003ooooo
ooooo`1Dooooo`;o00007oooool2o`0000;ooooo6ol000001?oooooo0000o`000?l00008ooooo`;o
00002?ooool2o`0000[ooooo0_l00005ooooo`?o000000Goooooo`000?l0003o0000ooooo`03o`00
00?ooooo0_l00003ooooo`;o00000oooool2o`0001Kooooo0_l00002ooooo`;o00001?ooool4o`00
00;ooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00001oooool2o`0000Wo
oooo1?l0000Aooooo`?o00004OoooolQo`000003ooooool0003o000000Oooooo2?l00008ooooo`Go
00000oooool2o`000004ooooool0003o0000o`0000cooooo1ol00003ooooo`?o00002oooool2o`00
00?ooooo0_l00007ooooo`Ko000000Coooooo`000?l0003ooooo0ol00016ooooo`007?ooool00ol0
003oooooooooo`0nooooo`;o00001Oooool4o`0000Wooooo0ol0000<ooooo`Co00000_ooool3o`00
013ooooo2Ol000000ooooooo0000o`00000Fo`000003ooooool0003o000000Oooooo1Ol000001?oo
oooo0000o`000?ooool2o`0000Gooooo1Ol00002ooooo`;o00000_ooool2o`0000gooooo1_l00004
ooooo`?o00002?ooool2o`000003ooooool0003o000000?ooooo0ol00006ooooo`;o00000_ooool2
o`000003ooooool0003o000000Co00005?ooool2o`00033ooooo000Looooo`03o`000?oooooooooo
03cooooo0_l000000ooooooo0000o`000004ooooo`;o00000_ooool2o`0000Sooooo0_l0000<oooo
o`Co00005Oooool4o`0000;ooooo6_l00004ooooo`;o00002Oooool2o`000004ooooool0003o0000
ooooo`;o00001Oooool2o`0000?ooooo1?l0000>ooooo`Oo00001_ooool2o`0000?ooooo0ol00003
ooooo`;o000000?oooooo`000?l000000oooool3o`0000gooooo0ol000000ooooooo0000o`00000D
ooooo`;o0000<?ooool001cooooo00?o0000ooooooooool0??ooool2o`000003ooooool0003o0000
00;ooooo1?l00002ooooo`;o00000oooool2o`00017ooooo0ol00002ooooo`;o000000?oooooo`00
0?l000000_l0000<ooooo`;o00001?oooolEo`0000?ooooo0_l00005ooooo`;o00001oooool4o`00
0003ooooool0003o000000gooooo0_l00002ooooo`Go00001oooool;o`0000Wooooo0ol0000Boooo
o`;o00001oooool2o`0000;ooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`0jooooo`;o
00001?ooool2o`000003ooooool0003o000000Ko00000oooool2o`0000kooooo0_l00006ooooo`;o
000000?oooooo`000?l000000_l000000ooooooo0000o`000009ooooo`;o000000Coooooo`000?l0
003ooooo1Ol000000ooooooo0000o`00000;o`000005ooooool0003o0000o`000?ooool00_l0000>
ooooo`;o00003Oooool2o`0000;ooooo1?l000000ooooooo0000o`000005o`0000;ooooo0_l00000
0ooooooo0000o`000004ooooo`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00001ooo
ool2o`0000gooooo0_l000000ooooooo0000o`00001@ooooo`007?ooool00ol0003oooooooooo`0j
ooooo`;o00001?ooool2o`000003ooooool0003o000000;ooooo1Ol0000Booooo`;o00002oooool2
o`000003ooooool0003o000000cooooo0_l00002ooooo`Co000000?oooooo`000?l000000ol00000
0ooooooo0000o`000005o`000003ooooool0003o000000?o00003_ooool2o`0000Gooooo0ol00005
ooooo`?o00000_ooool4o`000003ooooool0003o000000;ooooo0ol00002ooooo`;o00003Oooool2
o`0000?ooooo1?l00005ooooo`;o00004?ooool2o`0000;ooooo0_l0001<ooooo`007?ooool00ol0
003oooooooooo`1:ooooo`Go00000_ooool2o`000003ooooool0003o000000Sooooo0_l000000ooo
oooo0000o`000003ooooo`;o00000oooool2o`0000[ooooo0_l00007ooooo`?o000000?oooooo`00
0?l000002_l00003ooooo`;o000000?oooooo`000?l000000oooool2o`0000Wooooo0_l00005oooo
o`?o000000?oooooo`000?l000000_ooool2o`0000Cooooo1_l00003ooooo`;o00000_ooool2o`00
00;ooooo0_l00009ooooo`;o00000oooool4o`0000;ooooo0_l0000@ooooo`;o00001Oooool2o`00
04cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool01?ooool00ol0003oooooooooo`0mooooo`;o00002?ooool2o`0000;ooooo1?l00002
ooooo`;o000000?oooooo`000?l000002?ooool2o`000003ooooool0003o000000?ooooo0_l00006
ooooo`;o00001oooool2o`0000Kooooo1?l000001Ooooooo0000o`000?l0003ooooo00Co000000Co
ooooo`000?l0003o00001_ooool2o`0000?ooooo0_l0000;ooooo`;o00001?ooool2o`000003oooo
ool0003o000000;o00001_ooool6o`0000;ooooo0_l000000ooooooo0000o`000008o`0000Cooooo
0_l00003ooooo`;o00001oooool2o`0000Cooooo0_l0000:ooooo`;o00001Oooool2o`0004cooooo
00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0?Oooool2o`0000Gooooo0_l000000ooooooo0000o`000006ooooo`Ko
00000oooool2o`0000Oooooo0_l0000;ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;o
oooo0_l00004ooooo`Co00000_ooool2o`0000?ooooo0_l00007ooooo`;o000000?oooooo`000?l0
00002Oooool2o`0000Gooooo0_l00007ooooo`Co000000?oooooo`000?l000001Oooool8o`000003
ooooool0003o000000Go000000?oooooo`000?l000000_ooool4o`0000?ooooo0_l0000=ooooo`;o
00002_ooool2o`0000Gooooo1Ol000000ooooooo0000o`000016ooooo`0000?ooooooa0@4?ooool0
0_ooool00ol@413oooooooooo`09ooooo`Go00001_ooool00ol0003oooooooooo`14ooooo`;o0000
2Oooool8o`000004ooooool0003o0000ooooo`;o000000Coooooo`000?l0003ooooo0_l00006oooo
o`;o00001_ooool2o`0000;ooooo0_l00002ooooo`Co00001Oooool2o`0000oooooo0_l000000ooo
oooo0000o`000002ooooo`;o00000_ooool5o`0000kooooo0_l00003ooooo`;o00001Oooool@o`00
00?ooooo1?l000001?oooooo0000o`000?l00004ooooo`;o00005_ooool2o`0000Kooooo1?l00000
0ooooooo0000o`000002ooooo`;o0000@_ooool00003ooooool0003ooooo00;ooooo00?o0000oooo
ooooool02Oooool01?m4A4CogMgMooooool00007ooooo`?o0000<oooool2o`0000oooooo0_l0000<
ooooo`;o000000?oooooo`000?l000001?ooool2o`000004ooooool0003o0000o`0000Cooooo0_l0
0002ooooo`;o000000?oooooo`000?l000002?ooool2o`0000?ooooo0ol00004ooooo`;o00004_oo
ool2o`0000;ooooo0_l00002ooooo`Co00003Oooool2o`000003ooooool0003o000000?o00000_oo
ool5o`0000;ooooo1_l000000ooooooo0000o`000003o`0000Cooooo1?l000001?oooooo0000o`00
0?l00002ooooo`Co00007?ooool4o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l0
0000@_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?oMgMgoEEEE
ooooool00007ooooo`03o`000?oooooooooo03?ooooo0_l0000?ooooo`;o00003?ooool2o`000003
ooooool0003o000000;ooooo0_l00004ooooo`?o00000oooool2o`0000Gooooo0_l00008ooooo`;o
00001?ooool2o`0002Sooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo1Ol00002oooo
o`So000000Coooooo`000?l0003o00000_ooool2o`000004ooooool0003o0000ooooo`Co000000?o
ooooo`000?l000000_ooool2o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l000000_oo
ool2o`00013ooooo0_l00003ooooo`;o000000?oooooo`000?l00000AOooool00003ooooool@413o
oooo00;ooooo00?o410@ooooooooool02_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooo
oooo03cooooo0_l0000Booooo`;o00000oooool2o`0000;ooooo0_l00004ooooo`?o00002Oooool2
o`00013ooooo0_l00007ooooo`;o00001oooool2o`0000cooooo0_l00007ooooo`;o00000_ooool4
o`0000;ooooo0_l00002oooooaSo000000?oooooo`000?l000000_l000000ooooooo0000o`000004
o`0000Sooooo0ol000000ooooooo0000o`000004o`0000_ooooo0_l0000=ooooo`;o0000@oooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oo
oooooooo03Oooooo0_l00002ooooo`?o00001_ooool2o`0000[ooooo0_l0000=ooooo`?o00002Ooo
ool2o`00013ooooo0_l00007ooooo`;o00001oooool2o`0000?ooooo0_l00003ooooo`;o00000_oo
ool2o`0000Oooooo0_l00002ooooo`Co00000_ooool3o`000003ooooool0003o000001Go00000_oo
ool3o`0000;ooooo1_l00008ooooo`;o00001?ooool2o`0000Wooooo0_l00002ooooo`;o00003Ooo
ool2o`0004?ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool0
1_ooool00ol0003oooooooooo`0gooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000
o`00000Dooooo`;o00000oooool3o`0000gooooo0_l0000<ooooo`?o000000?oooooo`000?l00000
0_ooool2o`0000gooooo0_l00003ooooo`;o00001Oooool3o`0000?ooooo0_l00004ooooo`;o0000
0_ooool<o`000003ooooool0003o000000_o00000_ooool<o`000003ooooool0003o000000;ooooo
0ol00003ooooo`Co00002_ooool2o`0005Kooooo000Looooo`03o`000?oooooooooo047ooooo0_l0
0006ooooo`;o00003oooool2o`0000?ooooo0_l00006ooooo`;o00001Oooool3o`0000?ooooo0_l0
0008ooooo`;o000000?oooooo`000?l000000_ooool2o`0001Wooooo0ol00003ooooo`Oo000000?o
ooooo`000?l000009?l000001Ooooooo0000o`000?l0003ooooo00?o000000?oooooo`000?l00000
0_l00002ooooo`Co00007oooool2o`00047ooooo000Looooo`03o`000?oooooooooo03cooooo0_l0
000;ooooo`;o00001_ooool2o`0000Cooooo0_l00003ooooo`;o00002Oooool4o`0000?ooooo0_l0
0004ooooo`;o00001Oooool2o`0000Kooooo0_l00006ooooo`;o00006OoooolXo`000003ooooool0
003o000000?o00000_ooool2o`0000;ooooo0_l00002ooooo`?o00005_ooool2o`0000cooooo1?l0
000Gooooo`;o00009oooool001cooooo00?o0000ooooooooool0<oooool3o`0000Kooooo0_l0000:
ooooo`;o00000oooool2o`0000;ooooo0_l00004ooooo`;o00000oooool2o`0000Cooooo0_l00000
0ooooooo0000o`000004o`0000?ooooo0_l00002ooooo`;o00001Oooool4o`0000Kooooo0_l00006
ooooo`;o00005oooool7o`0000;ooooo0_l000000ooooooo0000o`000002ooooob3o00001?ooool4
o`0000;ooooo0_l0000Eooooo`Co00003?ooool4o`0001Oooooo0_l0000Wooooo`007?ooool00ol0
003oooooooooo`0cooooo`?o00004_ooool2o`0000;ooooo0ol0000;ooooo`;o00001_ooool2o`00
0003ooooool0003o000000Oooooo0_l00002ooooo`;o00001Oooool2o`0000Sooooo0_l00006oooo
o`;o00000oooool2o`0000[ooooo1?l00004ooooo`;o00000_ooool2o`000004ooooool0003o0000
o`0000;ooooo0_l000000ooooooo0000o`00000Mo`000003ooooool0003o000000;o000000?ooooo
o`000?l000000_l0000;ooooo`;o00003?ooool2o`0000Cooooo0_l00005ooooo`;o0000AOooool0
01cooooo00?o0000ooooooooool0?_ooool2o`0000cooooo0ol0000;ooooo`;o00000oooool2o`00
00Oooooo0_l0000=ooooo`;o00004_ooool2o`0000?ooooo0_l00006ooooo`;o00000_ooool6o`00
00Kooooo0_l000000ooooooo0000o`00000Zo`000003ooooool0003o000000;o00002oooool2o`00
00_ooooo0_l00005ooooo`;o00001Oooool2o`000003ooooool0003o000000;o0000@?ooool001co
oooo00?o0000ooooooooool0?_ooool2o`0000Cooooo0_l00007ooooo`;o000000?oooooo`000?l0
00003Oooool2o`000003ooooool0003o000000;o00000_ooool2o`0000gooooo0_l0000?ooooo`;o
00003_ooool2o`0000Kooooo0_l00009ooooob[o00000oooool3o`0001Wooooo0_l00005ooooo`;o
00002?ooool4o`00043ooooo000Looooo`03o`000?oooooooooo03;ooooo0_l0000@ooooo`;o0000
1oooool2o`000003ooooool0003o000000gooooo0_l000000ooooooo0000o`000002o`0000Wooooo
0_l0000:ooooo`;o00000_ooool4o`0000Gooooo0_l0000>ooooo`;o00001oooool3o`0000;ooooo
0_l00003ooooo`;o000000?oooooo`000?l000009_l00003ooooo`;o00005?ooool2o`0000?ooooo
0_l000001?oooooo0000o`000?ooool3o`000003ooooool0003o000002Cooooo0_l0000Sooooo`00
7?ooool00ol0003oooooooooo`0booooo`;o00003Oooool2o`0000_ooooo0_l00006ooooo`;o0000
1Oooool2o`000003ooooool0003o000000gooooo0_l0000:ooooo`;o00000_ooool4o`0000cooooo
0_l00007ooooo`;o00001oooool3o`000005ooooool0003o0000o`000?ooool0<Ol0000Eooooo`;o
00001_ooool2o`000003ooooool0003o000000;ooooo0_l0000Tooooo`;o00008oooool001cooooo
00?o0000ooooooooool0@Oooool2o`0000_ooooo1?l00003ooooo`?o00001Oooool2o`000003oooo
ool0003o000000_ooooo0_l00008ooooo`;o00005?ooool4o`0001Cooooo0ol000000ooooooo0000
o`00000Yo`000003ooooool0003o000000Ko00002_ooool4o`0000;ooooo1?l0000Dooooo`;o0000
@_ooool001cooooo00?o0000ooooooooool0?oooool2o`0000?ooooo0_l0000:ooooo`;o00000ooo
ool2o`0001Kooooo1?l00006ooooo`;o00005?ooool4o`00013ooooo0_l00002ooooo`?o00000ooo
oolDo`0000;ooooo4ol000000ooooooo0000o`000006o`0000Wooooo1Ol00002ooooo`Co00005?oo
ool2o`0004;ooooo000Looooo`03o`000?oooooooooo03gooooo1?l000000ooooooo0000o`000002
o`0001Gooooo0_l0000@ooooo`Co00003_ooool2o`000003ooooool0003o000000Wooooo1?l00002
ooooo`;o00003?ooool2o`000004ooooool0003o0000o`0000Oooooo9_l00003ooooo`;o00003Ooo
ool2o`0000Oooooo0_l0000Dooooo`;o000000?oooooo`000?l00000?oooool001cooooo0_l0000n
ooooo`;o00000oooool2o`0001Oooooo0_l00007ooooo`Go00000_ooool7o`0000[ooooo0_l00000
0ooooooo0000o`000003o`0000Oooooo1?l000000ooooooo0000o`000003o`0000gooooo2_l00000
0ooooooo0000o`00000Uo`0000Gooooo1Ol00003ooooo`;o00002oooool2o`0000cooooo0_l00003
ooooo`;o00001Oooool3o`0003kooooo000Looooo`03o`000?oooooooooo03oooooo0_l00002oooo
o`;o00001?ooool2o`0000cooooo0ol0000:ooooo`oo00001Oooool2o`0000;ooooo0_l00002oooo
o`;o00002Oooool2o`0000?ooooo2?l0000:ooooo`;o000000?oooooo`000?l000001Ol000001?oo
oooo0000o`000?oooolTo`0000Gooooo1Ol00003ooooo`;o00001Oooool2o`0000;ooooo1?l00006
ooooo`;o00001?ooool2o`0000?ooooo1?l00004ooooo`;o0000?_ooool001cooooo00?o0000oooo
ooooool0;?ooool2o`00017ooooo0_l00002ooooo`;o00001?ooool2o`0000cooooo0ol00006oooo
o`;o000000?oooooo`000?l000004?l000000ooooooo0000o`000002o`0000_ooooo0_l0000;oooo
o`Ko00001oooool2o`0000Gooooo1_l000001?oooooo0000o`000?oooolSo`000004ooooool0003o
0000o`0000?ooooo0_l000000ooooooo0000o`000008ooooo`?o00000_ooool6o`0000Cooooo0_l0
000:ooooo`?o0000A?ooool001cooooo00?o0000ooooooooool0;?ooool2o`0001Cooooo0_l00000
0ooooooo0000o`000004ooooo`Co00001oooool2o`0000Sooooo4_l000001?oooooo0000o`000?oo
ool2o`0000gooooo0_l00009ooooo`Co00002?ooool2o`000003ooooool0003o000000Oooooo:ol0
00001?oooooo0000o`000?l00003ooooo`;o000000?oooooo`000?l000002?ooool2o`0000Oooooo
0_l00008ooooo`;o00000_ooool2o`0000;ooooo0_l00005ooooo`;o0000?_ooool001cooooo00?o
0000ooooooooool0;Oooool2o`0000oooooo0_l00002ooooo`;o000000?oooooo`000?l000001?oo
ool5o`0000Kooooo1?l000000ooooooo0000o`000003oooooa?o00005_ooool2o`0000;ooooo0_l0
00000ooooooo0000o`00000:ooooo`Co00001?ooool2o`0000;ooooo0ol000000ooooooo0000o`00
000>o`000003ooooool0003o000001?o000000Coooooo`000?l0003o00001?ooool2o`000003oooo
ool0003o000000?ooooo0_l00005ooooo`;o00003oooool2o`0000;ooooo0_l000000ooooooo0000
o`000002ooooo`;o00000_ooool2o`0003kooooo000Looooo`03o`000?oooooooooo02gooooo0_l0
000<ooooo`Ko000000?oooooo`000?l000001?ooool2o`0000;ooooo1?l00008ooooo`;o000000?o
ooooo`000?l000000_oooolEo`0000[ooooo0_l00009ooooo`;o00000_ooool2o`0000oooooo0_l0
0004ooooo`;o00000oooool3o`0000?ooooo1ol000000ooooooo0000o`00000Mo`0000Cooooo0_l0
0003ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Oooooo0_l00003ooooo`;o00002?oo
ool2o`0000;ooooo1Ol0000oooooo`007?ooool00ol0003oooooooooo`0kooooo`Ko00001oooool2
o`0000;ooooo0_l00006ooooo`Go00001_oooolEo`0000[ooooo0_l000000ooooooo0000o`00000K
ooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`;o00000_ooool9o`000003ooooool0
003o000000co000000?oooooo`000?l000003?l00009ooooo`?o00000_ooool2o`0000Oooooo0_l0
0004ooooo`?o00000_ooool2o`0000kooooo0ol00006ooooo`;o0000=oooool001cooooo00?o0000
ooooooooool0??ooool3o`000003ooooool0003o000000Kooooo0_l0000:ooooo`Go00001?oooolG
o`0000gooooo0_l0000:ooooo`;o00001_ooool2o`0000Kooooo0ol00004ooooo`;o000000?ooooo
o`000?l000001OoooolWo`0000Wooooo0_l00003ooooo`;o00001oooool2o`0000Gooooo0_l0000C
ooooo`Co00001?ooool2o`0003Oooooo000Looooo`03o`000?oooooooooo03cooooo0ol000000ooo
oooo0000o`000005ooooo`?o00003Oooool2o`0000?ooooo6_l0000Gooooo`;o00001Oooool4o`00
00Gooooo0_l00006ooooo`;o000000?oooooo`000?l000000_l00004ooooobKo000000?oooooo`00
0?l000000_l0000>ooooo`;o00002?ooool2o`0000kooooo0_l00002ooooo`Go0000?Oooool001co
oooo00?o0000ooooooooool0>Oooool2o`0000Oooooo0_l00002ooooo`?o00003_ooool2o`0000;o
oooo2ol000000ooooooo0000o`00000=o`000003ooooool0003o000000kooooo0_l0000;ooooo`Co
00003Oooool2o`000003ooooool0003o000000Co00000_oooolRo`000005ooooool0003o0000o`00
0?ooool01?l0000<ooooo`Co000000Coooooo`000?l0003o00001?ooool2o`0000kooooo0_l00002
ooooo`;o00000oooool2o`0000cooooo0_l0000]ooooo`007?ooool00ol0003oooooooooo`0ioooo
o`;o00001oooool7o`0000?ooooo0_l0000=oooooa[o00000_ooool2o`0000kooooo1?l00004oooo
o`?o00000_ooool3o`0000kooooo0_l00005ooooo`;o00000_oooolSo`000003ooooool0003o0000
00;o00003oooool2o`0000?ooooo0ol0000Jooooo`;o000000?oooooo`000?l000003?ooool2o`00
02gooooo000Looooo`03o`000?oooooooooo03Wooooo0_l00008ooooo`Go00001?ooool2o`0000go
oooo6_l0000<ooooo`;o00001_ooool2o`0000Cooooo0ol00003ooooo`;o00005ooooolZo`0000_o
oooo0_l00002ooooo`;o00000oooool2o`0000Cooooo0_l00005ooooo`;o00003_ooool2o`000003
ooooool0003o000003_ooooo000Looooo`03o`000?oooooooooo03Wooooo0_l00008ooooo`;o0000
00Goooooo`000?l0003o0000ooooo`02o`0000Sooooo1?l000000ooooooo0000o`00000Lo`0000[o
oooo0_l00008ooooo`;o00000_ooool3o`0000;ooooo0ol0000GoooooaWo000000?oooooo`000?l0
00000ol000001Ooooooo0000o`000?l0003ooooo00Ko00000oooool2o`0000Kooooo0_l00009oooo
o`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l00005oooo
o`Go00000_ooool2o`0003Sooooo000Looooo`03o`000?oooooooooo03kooooo0_l00003ooooo`?o
000000Coooooo`000?l0003ooooo0_l00008ooooo`Co000000Coooooo`000?l0003ooooo6ol0000D
ooooo`Co00001Oooool3o`00017ooooo0_l00003oooooaoo00000_ooool2o`0000;ooooo0_l00000
0ooooooo0000o`000004ooooo`;o00004Oooool2o`0000Kooooo0_l00003ooooo`;o00001?ooool3
o`0000Cooooo1Ol00002ooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0?_ooool2o`00
00;ooooo1?l00004ooooo`;o00000oooool2o`0000Sooooo7?l0000Cooooo`;o00000oooool2o`00
00Kooooo0ol00003ooooo`;o00001_ooool2o`0000?ooooo0_l00002ooooo`go00000oooool?o`00
00;ooooo1ol000000ooooooo0000o`00000Cooooo`;o00005_ooool3o`0000Sooooo0_l0000Ioooo
o`;o00007oooool001cooooo00?o0000ooooooooool0?oooool2o`000004ooooool0003o0000o`00
00;ooooo0_l00006ooooo`;o00001_ooool;o`000003ooooool0003o000000oo000000?oooooo`00
0?l000004Oooool2o`0000[ooooo2Ol00006ooooo`;o00001ooooolPo`000003ooooool0003o0000
00?o00006?ooool2o`0000?ooooo0_l00006ooooo`;o00000oooool2o`0000Gooooo0_l00008oooo
o`;o00006Oooool2o`0001oooooo000Looooo`;o0000@?ooool2o`000004ooooool0003o0000o`00
00;ooooo0_l00005ooooo`;o00001ooooolPo`0000oooooo0_l00008ooooo`;o00000_ooool7o`00
00;ooooo0_l0000>ooooo`?o00000oooool@o`0000;ooooo2Ol0000Looooo`;o00000oooool2o`00
0004ooooool0003o0000ooooo`Co00000oooool2o`0000_ooooo1?l00002ooooo`;o0000>?ooool0
01cooooo00?o0000ooooooooool0@_ooool2o`0000[ooooo1?l0000;ooooo`Ko000000?oooooo`00
0?l000003ol0000Aooooo`;o000000?oooooo`000?l000001Oooool2o`0000Kooooo0_l000000ooo
oooo0000o`000002o`0000Cooooo0_l00002ooooo`;o00000oooool6o`000003ooooool0003o0000
00So000000?oooooo`000?l000002_l000001Ooooooo0000o`000?l0003ooooo00;o000000?ooooo
o`000?l000005Oooool4o`0000Gooooo0_l000000ooooooo0000o`000005ooooo`;o00002oooool4
o`0000;ooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`10ooooo`Ko00000oooool2o`00
00Gooooo0_l00005ooooo`;o00000_oooolGo`0001Cooooo0_l000000ooooooo0000o`00000<oooo
o`Oo00001Oooool2o`0000;ooooo0_l00003ooooo`?o000000?oooooo`000?l000000_ooool2o`00
00Gooooo0_l000000ooooooo0000o`000003ooooo`Ko00000_ooool2o`0000;ooooo0_l000000ooo
oooo0000o`00000Eooooo`Co00003?ooool2o`000003ooooool0003o000000gooooo0_l00003oooo
o`;o0000=oooool001cooooo00?o0000ooooooooool0?Oooool2o`000003ooooool0003o000000Co
00000oooool2o`0000[ooooo1?l00002oooooa_o00003?ooool2o`0000;ooooo0_l00008ooooo`;o
00001Oooool9o`0000;ooooo0_l00008ooooo`?o000000?oooooo`000?l000000_l00003ooooo`;o
00000oooool5o`000003ooooool0003o000000Go00000_ooool5o`00017ooooo0_l00003ooooo`;o
00002?ooool2o`000003ooooool0003o000000Cooooo0_l0000=ooooo`;o00001?ooool4o`0003Oo
oooo000Looooo`03o`000?oooooooooo03gooooo0_l0000Aooooo`;o00000oooool3o`0000Gooooo
5?l000000ooooooo0000o`000002o`0000cooooo0_l00002ooooo`;o00000oooool2o`0000?ooooo
0_l00005ooooo`;o000000?oooooo`000?l000001?l000000ooooooo0000o`000003o`0000_ooooo
0ol00003ooooo`;o00000oooool5o`000003ooooool0003o000000;ooooo0ol00003ooooo`Co0000
0_ooool2o`0000gooooo0_l00003ooooo`;o00002?ooool2o`000003ooooool0003o000000Cooooo
0_l0000=ooooo`Co00000_ooool2o`0003Wooooo000Looooo`03o`000?oooooooooo02[ooooo0_l0
000Dooooo`;o000000?oooooo`000?l000002_ooool3o`0000Cooooo0_l00002oooooa?o00000_oo
ool2o`0001Sooooo1?l0000>ooooo`;o00000oooool3o`000003ooooool0003o000000_ooooo0_l0
00001?oooooo0000o`000?l00002ooooo`;o00000_ooool2o`0000?ooooo0_l00003ooooo`Ko0000
0oooool6o`0000Oooooo0_l0000<ooooo`Co00001Oooool2o`0000?ooooo0_l00006ooooo`;o0000
1oooool3o`0003cooooo000Looooo`03o`000?oooooooooo02[ooooo0_l0000Dooooo`;o000000?o
ooooo`000?l000001Oooool2o`0000?ooooo1?l00007ooooo`Co00000_oooolAo`00017ooooo1Ol0
0002ooooo`;o00003_ooool2o`0000Gooooo0_l00007ooooo`;o00002Oooool3o`0000;ooooo0_l0
000<ooooo`Oo00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`;o00001Ooo
ool2o`0000Gooooo1?l00005ooooo`;o00001?ooool2o`0000Gooooo0_l000000ooooooo0000o`00
0005ooooo`Co00006?ooool2o`00023ooooo000Looooo`03o`000?oooooooooo02cooooo0_l00008
ooooo`;o00000_ooool2o`0000Oooooo0_l00003ooooo`Co00001Oooool2o`0000Kooooo1Ol00000
1?oooooo0000o`000?ooool2o`0000;ooooo2ol0000Aooooo`Go00000_ooool2o`0000kooooo0_l0
0006ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000<ooooo`?o00000ooo
ool3o`0000Cooooo0_l00003ooooo`;o00002Oooool2o`0000_ooooo1?l0000<ooooo`?o00000ooo
ool2o`0000Sooooo0_l00007ooooo`;o00006?ooool2o`00023ooooo000Looooo`03o`000?oooooo
oooo02Gooooo0_l00005ooooo`;o00002?ooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2
o`0000;ooooo0ol0000<ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00
0009o`000003ooooool0003o000000?o00004?ooool2o`0000Oooooo0_l0000Eooooo`Co000000?o
ooooo`000?l000001Oooool2o`0000;ooooo0_l00007ooooo`Go00000_ooool3o`000003ooooool0
003o000000Kooooo0_l0000Eooooo`;o000000?oooooo`000?l000003?ooool4o`0000;ooooo0_l0
00000ooooooo0000o`000002ooooo`;o0000A_ooool001cooooo00?o0000ooooooooool09Oooool2
o`0001Sooooo0_l00003ooooo`;o000000?oooooo`000?l000001_ooool4o`0000?ooooo0_l00009
ooooo`ko00000oooool2o`0000cooooo0_l00007ooooo`?o00001Oooool2o`0000[ooooo0_l00000
0ooooooo0000o`000002o`000003ooooool0003o000000Wooooo0_l00007ooooo`go00000_ooool2
o`0000Cooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000_ooooo0_l0000A
ooooo`;o00000_ooool5o`0000;ooooo0_l00008ooooo`;o0000??ooool001cooooo00?o0000oooo
ooooool0>Oooool2o`0000?ooooo0ol00003ooooo`;o00002Oooool4o`0000[ooooo0_l00003oooo
o`Wo00000_ooool2o`0000?ooooo0_l00005ooooo`;o00002Oooool2o`0000Cooooo0_l00005oooo
o`;o00001Oooool2o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000001Oooool2o`00
00gooooo0_l000000ooooooo0000o`000004o`0000Cooooo0ol00003ooooo`;o000000?oooooo`00
0?l000000_l000001?oooooo0000o`000?l0000Sooooo`;o00000_ooool2o`0000Wooooo0_l00007
ooooo`;o0000<oooool001cooooo00?o0000ooooooooool09?ooool2o`0001?ooooo0_l00003oooo
o`;o00000_ooool2o`0001Wooooo0_l00003ooooo`?o00002_ooool2o`0000Sooooo0_l00009oooo
o`?o00000oooool4o`0000;ooooo0_l00006ooooo`;o00002?ooool2o`0000Cooooo0_l000001?oo
oooo0000o`000?l0000?ooooo`Go00001Oooool4o`0000_ooooo0ol0000Gooooo`;o00001?ooool2
o`0000Sooooo0_l00004ooooo`Co000000Coooooo`000?l0003o00001_ooool2o`0003?ooooo000L
ooooo`03o`000?oooooooooo02Cooooo0_l00006ooooo`;o00002?ooool2o`0000Kooooo0_l00002
ooooo`;o00005?ooool2o`0000Kooooo0_l000001?oooooo0000o`000?l00009ooooo`;o00005?oo
ool2o`0000?ooooo1?l00002ooooo`;o00005_ooool6o`0000?ooooo0_l0000:ooooo`?o00001ooo
ool2o`0000?ooooo0_l0000Rooooo`;o00001?ooool2o`0000kooooo2?l0000kooooo`007?ooool0
0ol0003oooooooooo`0/ooooo`;o00002?ooool2o`0000[ooooo0_l0000?ooooo`;o00000oooool2
o`0000Kooooo0ol000000ooooooo0000o`00000Hooooo`;o00006?ooool2o`0000_ooooo1_l00000
0ooooooo0000o`000002ooooo`Go00001?ooool2o`00017ooooo0_l00003ooooo`;o00006Oooool2
o`0000;ooooo0_l0000Fooooo`Co0000?Oooool001cooooo00?o0000ooooooooool0;?ooool2o`00
01Cooooo0_l0000?ooooo`;o00001oooool2o`0000;ooooo0ol00008ooooo`;o00004Oooool2o`00
00[ooooo0_l00005ooooo`;o00001Oooool2o`000003ooooool0003o000000Sooooo0ol00008oooo
o`Go00001?ooool2o`0000_ooooo0_l00002ooooo`Co00000oooool2o`0000Cooooo0_l0000Coooo
o`;o00005_ooool2o`0000;ooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0iooooo`;o
00001?ooool2o`0000;ooooo0_l0000Gooooo`;o00000_ooool2o`0000Wooooo1?l0000>ooooo`?o
00002_ooool2o`0000?ooooo1?l00008ooooo`Co00002?ooool2o`0000Kooooo0_l00002ooooo`;o
00001?ooool2o`0000_ooooo0_l00002ooooo`;o00002oooool2o`0000Kooooo0_l00002ooooo`;o
00001oooool2o`0000Gooooo0_l0000?ooooo`;o0000@oooool001cooooo0_l0000Tooooo`;o0000
5?ooool3o`0000?ooooo0ol000001?oooooo0000o`000?ooool2o`00013ooooo0_l00002ooooo`;o
00002Oooool2o`0000Cooooo0_l0000:ooooo`Ko00000oooool2o`0000Cooooo0_l00005ooooo`;o
00003?ooool3o`0000Kooooo0ol000000ooooooo0000o`000003ooooo`;o00002?ooool2o`000003
ooooool0003o000001Oooooo0_l00008ooooo`Ko00003_ooool2o`0000_ooooo0_l00017ooooo`00
7?ooool00ol0003oooooooooo`0Sooooo`;o00005Oooool2o`0000;ooooo1Ol00003ooooo`;o0000
2Oooool2o`0000Gooooo0_l00002ooooo`?o00002?ooool2o`0000;ooooo0_l00008ooooo`So0000
1Oooool2o`0000Cooooo0_l0000Dooooo`;o00001_ooool3o`000003ooooool0003o000000?ooooo
0_l00009ooooo`Ko00000_ooool2o`00017ooooo0_l0000:ooooo`;o00002_ooool2o`000004oooo
ool0003o0000ooooo`;o00001oooool6o`0000;ooooo0_l00003ooooo`;o0000?_ooool001cooooo
00?o0000ooooooooool0?_ooool2o`000003ooooool0003o000000?ooooo0_l00009ooooo`;o0000
1_ooool2o`0000;ooooo1?l00003ooooo`;o00000_ooool2o`000003ooooool0003o000000Sooooo
1?l0000Wooooo`;o00001Oooool3o`00013ooooo0_l00002ooooo`;o00000_ooool2o`0001_ooooo
0ol00007ooooo`Ko000000Coooooo`000?l0003ooooo1?l00005ooooo`Co00001?ooool2o`0000?o
oooo1?l0000looooo`007?ooool00ol0003oooooooooo`0[ooooo`;o00004?ooool2o`0000;ooooo
1?l000000ooooooo0000o`00000Aooooo`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o
00000_ooool2o`0000?ooooo0_l00009ooooo`;o00001Oooool2o`0001Sooooo0_l00005ooooo`;o
00001_ooool3o`0000;ooooo0_l0000=ooooo`;o00002?ooool2o`0000gooooo0_l00008ooooo`?o
00001oooool4o`0000Sooooo0_l0000=ooooo`;o00000oooool5o`0003_ooooo000Looooo`03o`00
0?oooooooooo02_ooooo0_l0000?ooooo`Ko000000?oooooo`000?l000002_ooool2o`0000_ooooo
0ol00006ooooo`;o00001_ooool2o`0000Sooooo0ol00005ooooo`;o00005_ooool4o`0000kooooo
0ol000000ooooooo0000o`00000=ooooo`;o00002?ooool2o`0000?ooooo0_l000000ooooooo0000
o`000005ooooo`?o00000oooool2o`000003ooooool0003o000000;o00004?ooool2o`0000Cooooo
0_l00008ooooo`Co00000oooool2o`000003ooooool0003o000001?ooooo0_l0000Vooooo`007?oo
ool00ol0003oooooooooo`0looooo`Ko00003Oooool3o`0000Wooooo1?l00005ooooo`?o00004?oo
ool3o`0001gooooo0_l0000Aooooo`;o00001_ooool2o`0001Oooooo0_l000000ooooooo0000o`00
0006ooooo`;o00000_ooool3o`000003ooooool0003o000001;ooooo0_l00004ooooo`;o00000_oo
ool2o`0000?ooooo0ol0000Booooo`;o00002Oooool2o`0002Kooooo000Looooo`03o`000?oooooo
oooo03gooooo0_l000000ooooooo0000o`00000>ooooo`;o00002Oooool2o`0000Oooooo0_l0000P
ooooo`;o00002_ooool2o`0000Oooooo0_l00008ooooo`;o00000oooool2o`0000Gooooo0ol0000K
ooooo`;o00002Oooool2o`000004ooooool0003o0000o`0001cooooo0ol000001?oooooo0000o`00
0?l0000Cooooo`;o0000<Oooool001cooooo00?o0000ooooooooool0>oooool4o`000003ooooool0
003o000000cooooo0_l000000ooooooo0000o`00000Rooooo`;o00003oooool2o`0000[ooooo0_l0
0007ooooo`;o00000oooool2o`0000?ooooo1?l00008ooooo`;o00007?ooool2o`000004ooooool0
003o0000o`0000Sooooo0_l0000Aooooo`;o00002oooool2o`000003ooooool0003o000004Oooooo
000Looooo`03o`000?oooooooooo03_ooooo1?l00004ooooo`;o00002Oooool2o`000003ooooool0
003o000001Oooooo0_l00009ooooo`;o00001_ooool2o`00027ooooo0_l00005ooooo`;o00000ooo
ool2o`0000?ooooo0ol0000Nooooo`?o00004oooool2o`0000;ooooo0ol000000ooooooo0000o`00
0003ooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0?Oooool2o`0000Cooooo0_l00003
ooooo`?o00007oooool2o`0000gooooo0_l00002ooooo`;o00006Oooool2o`000003ooooool0003o
000000Wooooo0_l00004ooooo`Co000000Coooooo`000?l0003o00002Oooool2o`0000cooooo0_l0
0007ooooo`;o00000_ooool2o`0000kooooo0_l00002ooooo`Co00001Oooool2o`0000Oooooo0_l0
000;ooooo`;o0000??ooool001cooooo00?o0000ooooooooool0@?ooool2o`0000Kooooo0ol0000@
ooooo`;o00007?ooool2o`0001cooooo0ol000000ooooooo0000o`000006ooooo`;o000000?ooooo
o`000?l000001?ooool4o`000004ooooool0003o0000o`0000;ooooo0ol00004ooooo`;o00003?oo
ool2o`0000Oooooo0_l00002ooooo`;o00005?ooool4o`0000;ooooo1_l00002ooooo`Co00001ooo
ool2o`0000;ooooo0_l0000looooo`007?ooool00ol0003oooooooooo`0nooooo`Co000000Cooooo
o`000?l0003o00005Oooool2o`0000cooooo0_l0000/ooooo`;o00002_ooool2o`0000Oooooo0_l0
0003ooooo`Co000000Goooooo`000?l0003o0000ooooo`02o`0000oooooo0_l00003ooooo`;o0000
7_ooool2o`0000;ooooo1ol000000ooooooo0000o`000002o`0000Oooooo0_l00010ooooo`007?oo
ool00ol0003oooooooooo`0nooooo`;o00000oooool3o`0000gooooo0_l0000Dooooo`;o00004_oo
ool2o`0001Sooooo0_l00009ooooo`;o00000oooool5o`0000Cooooo0_l000000ooooooo0000o`00
0005ooooo`Co00003Oooool2o`0000?ooooo0_l0000Eooooo`;o00002_ooool8o`0000?ooooo1?l0
0004ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0=oooool2o`0001Cooooo0_l00004
ooooo`?o00003?ooool2o`0001Wooooo0_l0000Qooooo`Co00000oooool5o`0000Cooooo0_l00003
ooooo`Ko000000?oooooo`000?l000003Oooool2o`0000?ooooo0_l000000ooooooo0000o`00000B
ooooo`;o00000oooool2o`0000Gooooo0_l0000;ooooo`;o00000oooool3o`00047ooooo00001_oo
ooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0
1_ooool00ol0003oooooooooo`0gooooo`;o00000oooool2o`0000Sooooo1?l00003ooooo`;o0000
1Oooool2o`0000Cooooo0_l00006ooooo`;o00002_ooool2o`0000Cooooo0_l0000Dooooo`;o0000
5?ooool2o`0000kooooo0ol00002ooooo`Ko00000_ooool2o`0000Oooooo0_l0000;ooooo`;o0000
1oooool2o`0000?ooooo0_l00009ooooo`;o00002_ooool4o`0000;ooooo0_l00005ooooo`;o0000
@_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMgMooo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo02oooooo0_l0000;ooooo`;o00002?ooool4o`00
013ooooo0_l00005ooooo`;o00001_ooool2o`0000?ooooo0_l00004ooooo`Co00001Oooool2o`00
00_ooooo0_l000000ooooooo0000o`00000Rooooo`;o00000oooool6o`000004ooooool0003o0000
o`0000Kooooo0_l0000>ooooo`;o00001?ooool2o`0000?ooooo2?l00004ooooo`;o00000_ooool2
o`0000Gooooo1Ol000000ooooooo0000o`000005ooooo`;o0000@_ooool00003ooooool@413ooooo
00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool0;oooool2o`0000_ooooo0_l0000:ooooo`Co00003Oooool2o`0000Cooooo1?l00002
ooooo`;o00000_ooool2o`0000Wooooo1?l000000ooooooo0000o`000002ooooo`;o00001_ooool2
o`0000Kooooo0_l00002ooooo`;o00000oooool3o`0000kooooo0_l00007ooooo`;o00001oooool7
o`0001Kooooo1_l00002ooooo`;o00000_ooool7o`0000Cooooo1_l00005ooooo`;o000000?ooooo
o`000?l000000ol00019ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09oooo
o`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0003cooooo0_l0000<ooooo`;o00003Oooool2
o`000004ooooool0003o0000ooooo`;o00000_ooool4o`0000[ooooo0_l00006ooooo`?o00002Ooo
ool2o`0000[ooooo0_l00003ooooo`Go00003?ooool2o`0000Oooooo0_l00003ooooo`;o00001?oo
ool4o`0000Gooooo0_l0000Booooo`Co000000Coooooo`000?l0003o00000oooool2o`0000?ooooo
0_l00005ooooo`;o00001oooool2o`0000;ooooo0_l00004ooooo`;o00005oooool2o`0002cooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oeEEEOl0003o410@
olc<c006ooooo`03o`000?oooooooooo04[ooooo0_l000000ooooooo0000o`00000=ooooo`;o0000
1Oooool2o`0000cooooo0_l00007ooooo`;o00007Oooool2o`000003ooooool0003o000000Cooooo
0_l00003ooooo`;o00000oooool2o`0000Kooooo1Ol00002ooooo`Ko00000oooool2o`0000Kooooo
0_l00005ooooo`;o00002?ooool2o`0000Cooooo0ol00002ooooo`Co00000oooool3o`0000Kooooo
0ol00005ooooo`Ko00005Oooool2o`0002cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oo
oooooooo00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`0`ooooo`;o00002ooo
ool2o`0000Kooooo0_l000000ooooooo0000o`000003ooooo`;o00005?ooool2o`0002kooooo1Ol0
0002ooooo`Go000000?oooooo`000?l000000_l00003ooooo`Co000000?oooooo`000?l000001Ooo
ool6o`0000?ooooo1Ol00004ooooo`?o00001?ooool2o`0000Gooooo0_l00005ooooo`Ko00001?oo
ool2o`0000Cooooo1?l000001?oooooo0000o`000?l00007ooooo`;o00001Oooool3o`000004oooo
ool0003o0000ooooo`?o00000_ooool2o`0003_ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMg
M`_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0`ooooo`;o00002oooool2o`00
00Kooooo1Ol0000Cooooo`;o0000<OoooolDo`0000Cooooo0ol00008ooooo`;o00000_ooool4o`00
0004ooooool0003o0000o`0000Kooooo0ol00009ooooo`;o000000?oooooo`000?l000001?ooool6
o`0000Gooooo0_l000000ooooooo0000o`000004o`0000_ooooo0_l0000<ooooo`?o00000_ooool2
o`0003_ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@
1_ooool00ol0003oooooooooo`11ooooo`Co00000_ooool2o`0000Wooooo0ol00008ooooo`;o0000
0oooool2o`0000kooooo0_l0000LoooooaCo00001?ooool2o`0000cooooo1Ol0000?ooooo`;o0000
00?oooooo`000?l000000_ooool2o`000003ooooool0003o000000Oooooo0_l00006ooooo`;o0000
00?oooooo`000?l000000_l0000Hooooo`;o0000@oooool001cooooo00?o0000ooooooooool0@Ooo
ool4o`0000gooooo0ol0000=ooooo`;o00002?ooool2o`0000;ooooo1?l0000>ooooo`;o00003?oo
ool8o`000003ooooool0003o000000Go00001Oooool3o`0000kooooo0_l0000:ooooo`;o00001_oo
ool2o`000003ooooool0003o000000kooooo0_l0000:ooooo`;o00001?ooool2o`0001?ooooo0_l0
0013ooooo`007?ooool00ol0003oooooooooo`0booooo`;o00002Oooool2o`00013ooooo0_l00000
0ooooooo0000o`000004ooooo`;o00004?ooool4o`0000;ooooo0_l0000@ooooo`?o00002oooool@
o`0000Gooooo0ol0000Fooooo`;o00000_ooool2o`0000;ooooo0_l0000Eooooo`;o00001Oooool4
o`000003ooooool0003o000000Cooooo0_l0000Fooooo`;o0000@?ooool001cooooo00?o0000oooo
ooooool0<_ooool2o`0000Wooooo0ol0000;ooooo`;o00000_ooool2o`000003ooooool0003o0000
00Cooooo0_l000000ooooooo0000o`00000=ooooo`;o00001?ooool2o`00017ooooo1?l00006oooo
o`go000000?oooooo`000?l000000ol0000Fooooo`Co00001?ooool2o`0000Cooooo1?l00002oooo
o`;o00001?ooool2o`000003ooooool0003o000000;ooooo0_l0000:ooooo`Go00001Oooool2o`00
00;ooooo0_l0000Dooooo`Ko0000??ooool001cooooo00?o0000ooooooooool0=_ooool2o`0000Ko
oooo0_l00005ooooo`;o00001?ooool2o`0000gooooo0ol0000Gooooo`;o00000_ooool2o`0000Wo
oooo1?l00002ooooo`;o00000_oooolCo`000004ooooool0003o0000o`0000?ooooo0_l0000=oooo
o`Co00002Oooool3o`0000?ooooo0ol00004ooooo`;o000000?oooooo`000?l000000_ooool2o`00
00[ooooo1Ol00005ooooo`;o00000_ooool2o`0000Cooooo0_l0000;ooooo`;o00000oooool4o`00
03cooooo000Looooo`03o`000?oooooooooo03Kooooo0_l00004ooooo`;o00001oooool2o`0000Ko
oooo0_l00006ooooo`;o00000oooool2o`0000Wooooo1?l0000;ooooo`;o00000_ooool2o`0000Ko
oooo0_l00007oooooaCo000000?oooooo`000?l000001Ol00002ooooo`?o00003Oooool2o`000003
ooooool0003o000000Kooooo0ol000001?oooooo0000o`000?ooool2o`0000Gooooo0_l0000>oooo
o`So00002Oooool2o`0000Cooooo0_l0000;ooooo`Co000000Coooooo`000?l0003o0000?Oooool0
01cooooo00?o0000ooooooooool0??ooool2o`0000oooooo1?l00004ooooo`Co00002Oooool7o`00
00?ooooo0ol0000Aooooo`;o00000oooool2o`0000?ooooo6ol00003ooooo`;o00004?ooool2o`00
00Kooooo0_l00002ooooo`;o000000?oooooo`000?l000002Oooool2o`0000[ooooo1_l00006oooo
o`;o000000?oooooo`000?l000001Oooool2o`0000kooooo0_l00011ooooo`007?ooool00ol0003o
ooooooooo`15ooooo`;o00001oooool3o`0000Gooooo0ol00009ooooo`Co00001_ooool3o`000003
ooooool0003o000000Cooooo1_l00009ooooo`?o00000_ooool7o`000003ooooool0003o000000Ko
000000?oooooo`000?l000002?l0000?ooooo`;o00007_ooool2o`0000Cooooo1?l0000>ooooo`Go
00001Oooool2o`00057ooooo000Looooo`03o`000?oooooooooo04Gooooo0ol00006ooooo`;o0000
00?oooooo`000?l000005?ooool2o`0000Oooooo3Ol00009ooooo`;o000000?oooooo`000?l00000
3?l000001?oooooo0000o`000?ooool;o`0000kooooo0_l00008ooooo`;o00002_ooool6o`0000Go
oooo0_l00003ooooo`Ko00003_ooool4o`0005Oooooo000Looooo`03o`000?oooooooooo03Sooooo
0_l0000<ooooo`;o00001?ooool2o`0000;ooooo0ol0000Dooooo`;o00002?ooool=o`0000[ooooo
4_l00002ooooo`_o00005oooool2o`0000[ooooo1ol00003ooooo`?o00001oooool2o`00013ooooo
0ol00007ooooo`;o00003?ooool2o`0003oooooo000Looooo`03o`000?oooooooooo03Sooooo0_l0
000Booooo`;o00000_ooool2o`0001;ooooo0_l00009oooooa3o000000?oooooo`000?l000001_oo
ool3o`000003ooooool0003o000001[o00008oooool2o`0000;ooooo0_l00003ooooo`;o00002ooo
ool2o`0000Sooooo0_l00004ooooo`;o00001oooool2o`0000_ooooo0ol0000oooooo`007?ooool0
0ol0003oooooooooo`10ooooo`;o00001?ooool3o`0000Oooooo0_l0000Booooo`;o00002Oooool6
o`000003ooooool0003o000000Oo000000?oooooo`000?l000000oooool6o`000003ooooool0003o
000001[o00001oooool2o`000003ooooool0003o000000Oooooo0_l0000Booooo`;o00004?ooool2
o`0000Sooooo0_l0000Jooooo`;o0000@?ooool001cooooo0_l00011ooooo`;o00001?ooool3o`00
00;ooooo0_l00008ooooo`Co00002Oooool2o`0000Wooooo4_l00005ooooob7o000000Coooooo`00
0?l0003o00001_ooool5o`0000Oooooo0_l0000Booooo`;o00002_ooool2o`0000?ooooo0ol00000
0ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000001_ooool2o`000003ooooool0003o
000000Kooooo0_l00004ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0Boooool2o`00
00Cooooo2?l00007ooooo`Co00001ooooolDo`000003ooooool0003o000000;ooooo0_l000000ooo
oooo0000o`00000Ko`000003ooooool0003o000000;o00001_ooool5o`0001Wooooo1?l0000:oooo
o`;o000000?oooooo`000?l000000_l00002ooooo`Ko000000?oooooo`000?l000001_ooool2o`00
0003ooooool0003o000000Kooooo0_l00002ooooo`Co0000@oooool001cooooo00?o0000oooooooo
ool0B?ooool2o`0000Oooooo1?l0000;ooooo`Co00001ooooolBo`0000?ooooo0ol00003ooooob?o
00001_ooool2o`000003ooooool0003o000001;ooooo0_l00005ooooo`;o00003?ooool5o`0000Ko
oooo0_l00003ooooo`;o00001Oooool2o`0000Wooooo0ol00002ooooo`?o00002oooool2o`0003Oo
oooo000Looooo`03o`000?oooooooooo04Sooooo0_l00003ooooo`;o00000oooool2o`000003oooo
ool0003o000000?o00000_ooool2o`0000oooooo4Ol00003ooooo`;o000000?oooooo`000?l00000
8Ol000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000005Oooool3o`000003oooo
ool0003o0000017ooooo0_l000000ooooooo0000o`00000=ooooo`Go00002Oooool2o`0000;ooooo
1?l0000;ooooo`;o0000=oooool001cooooo00?o0000ooooooooool0>Oooool2o`0000Gooooo0_l0
0007ooooo`Ko00000oooool2o`000003ooooool0003o000000?o00000_ooool2o`0000Oooooo0_l0
0006oooooa7o00000ooooolYo`0000;ooooo1Ol00005ooooo`Oo00001_ooool2o`0000;ooooo0_l0
00000ooooooo0000o`000006ooooo`;o00001?ooool2o`0000?ooooo0_l000000ooooooo0000o`00
000=ooooo`Co00000_ooool2o`0000[ooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`0i
ooooo`;o00001Oooool4o`0000Gooooo1Ol0000Cooooo`;o00000_ooool2o`0000Sooooo3?l00007
ooooob;o00000oooool2o`0000Cooooo1Ol00003ooooo`[o00001?ooool2o`0000Oooooo0_l00004
ooooo`;o00001?ooool2o`0000?ooooo1?l00008ooooo`;o00000oooool2o`0000Gooooo0_l0000:
ooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0@_ooool2o`00017ooooo0_l00005oooo
o`;o00000oooool2o`0000?ooooo0_l00006ooooo`go00001_oooolQo`0000Gooooo0_l00002oooo
o`;o00000oooool2o`0000?ooooo3Ol00002ooooo`;o00001_ooool2o`0000Cooooo0_l00003oooo
o`;o00001_ooool2o`0000Oooooo0ol000000ooooooo0000o`000002o`00017ooooo0_l00016oooo
o`007?ooool00ol0003oooooooooo`18ooooo`;o00001?ooool3o`0000Cooooo0_l00005ooooo`?o
00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`Ko00000_ooool3o`0000Ko
oooo9?l00004ooooo`;o00000_ooool2o`0000Oooooo4ol00003ooooo`;o00001_ooool2o`0000?o
oooo0_l00008ooooo`?o00001?ooool2o`0000;ooooo0_l0000:ooooo`;o00001Oooool2o`0004So
oooo000Looooo`03o`000?oooooooooo03kooooo0_l00008ooooo`Co00000_ooool3o`0000cooooo
0_l00002ooooo`;o00000oooool5o`0000Oooooo0_l00004ooooo`;o00001?ooool3o`000003oooo
ool0003o000001[o000000?oooooo`000?l000000_l00004ooooo`?o00002_ooool@o`000003oooo
ool0003o000000?ooooo0_l0000@ooooo`;o00000oooool3o`0000gooooo0_l00004ooooo`?o0000
1Oooool2o`0004Sooooo000Looooo`03o`000?oooooooooo03;ooooo0_l0000:ooooo`;o00002_oo
ool3o`0000;ooooo0_l0000?ooooo`;o00001?ooool3o`0000Gooooo0ol000001?oooooo0000o`00
0?ooool5o`0000Cooooo0_l000000ooooooo0000o`00000Ko`0000Sooooo1?l0000:oooooa?o0000
3_ooool2o`0000;ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00003oooool4o`0000;o
oooo0_l00006ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0<_ooool2o`0001?ooooo
0_l00002ooooo`Co00004Oooool2o`0000[ooooo1Ol000001?oooooo0000o`000?ooool3o`0000Wo
oooo1?l000000ooooooo0000o`00000=o`000003ooooool0003o000000Go00002Oooool5o`0000Wo
oooo5Ol00006ooooo`;o00001?ooool2o`0000;ooooo1_l000000ooooooo0000o`00000Aooooo`;o
00000_ooool2o`0000Cooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`17ooooo`;o0000
1?ooool2o`0000?ooooo0_l00007ooooo`;o00001?ooool2o`000003ooooool0003o000000Kooooo
0_l000000ooooooo0000o`000004ooooo`Co00001?ooool2o`0000?ooooo0ol00002ooooo`Co0000
00?oooooo`000?l000000oooool3o`000003ooooool0003o000000Ko00002_ooool4o`0000_ooooo
4ol00006ooooo`;o00000oooool2o`0000Gooooo0_l000001?oooooo0000o`000?l00007ooooo`Go
00004?ooool2o`0004[ooooo000Looooo`03o`000?oooooooooo047ooooo0_l0000:ooooo`;o0000
0oooool2o`0000Oooooo0_l000001?oooooo0000o`000?ooool2o`000004ooooool0003o0000oooo
o`;o00002?ooool2o`0000;ooooo1?l00004ooooo`;o00000oooool2o`0000Gooooo0_l00007oooo
o`Go00000_ooool3o`0000Kooooo0_l00005ooooo`;o00002?oooolFo`0000_ooooo0_l00005oooo
o`;o000000Coooooo`000?l0003o00001oooool6o`0005_ooooo000Looooo`03o`000?oooooooooo
047ooooo0_l0000:ooooo`;o00003Oooool4o`0000Oooooo0_l000000ooooooo0000o`000005oooo
o`;o000000Coooooo`000?l0003o00002?ooool2o`0001;ooooo0_l00004ooooo`;o00000oooool2
o`0000;ooooo0_l00004ooooo`;o00002OoooolFo`0001Kooooo0ol0000:ooooo`?o00000_ooool2
o`0005Kooooo000Looooo`03o`000?oooooooooo05cooooo0_l0000<ooooo`;o00001oooool3o`00
00Wooooo0_l00002ooooo`;o00005_ooool2o`000003ooooool0003o000000;ooooo0_l00004oooo
o`;o000000?oooooo`000?l000002?oooolEo`0000[ooooo1?l00007ooooo`?o00002oooool2o`00
00;ooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o00000oooool2o`00013o
oooo0_l00003ooooo`;o00000_ooool4o`000003ooooool0003o000000;ooooo0_l00007ooooo`;o
000000?oooooo`000?l000001Oooool2o`0000cooooo0ol0000=ooooo`;o00002?ooool8o`000003
ooooool0003o000000co00002?ooool4o`000003ooooool0003o000000Gooooo0ol0001Vooooo`00
7?ooool2o`0004_ooooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool2o`00013ooooo
0_l00003ooooo`;o00000_ooool4o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o0000
1_ooool2o`0000Gooooo0_l00004ooooo`;o00001_ooool3o`0001Oooooo5ol0000=ooooo`;o0000
1_ooool2o`0000Oooooo0_l000000ooooooo0000o`00000Booooo`;o0000A_ooool001cooooo00?o
0000ooooooooool0B_ooool5o`0001cooooo0_l00002ooooo`;o00000oooool2o`0000Sooooo0_l0
000=ooooo`;o00001?ooool2o`0000Cooooo1?l00004ooooo`;o00003?ooool2o`0000Gooooo6?l0
0002ooooo`;o00001oooool2o`000004ooooool0003o0000ooooo`;o00002Oooool2o`000003oooo
ool0003o000001;ooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`1;ooooo`?o00007Ooo
ool7o`0000;ooooo0_l0000Gooooo`;o00001Oooool2o`0000?ooooo0_l00002ooooo`;o00000_oo
ool2o`0000cooooo0_l000000ooooooo0000o`000003oooooaOo00000_ooool2o`0000Gooooo1?l0
00001?oooooo0000o`000?ooool2o`000003ooooool0003o000000Cooooo0_l00003ooooo`;o0000
0_ooool2o`0000Cooooo0_l0000:ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0Booo
ool2o`0001Sooooo0_l00005ooooo`?o000000?oooooo`000?l000008_ooool2o`0000Oooooo0_l0
000:ooooo`;o00001oooool2o`0000?ooooo5ol00002ooooo`;o00001Oooool3o`0000Gooooo0_l0
00000ooooooo0000o`000004ooooo`;o00001oooool2o`0000Cooooo0_l0000:ooooo`;o0000A?oo
ool001cooooo00?o0000ooooooooool0Doooool3o`0000oooooo0_l00004ooooo`;o0000??ooool2
o`0000_ooooo0_l00003ooooo`?o000000?oooooo`000?l000003ol0000Wooooo`;o0000D?ooool0
01cooooo00?o0000ooooooooool0?Oooool2o`0001Cooooo1?l0000Dooooo`;o00003_ooool2o`00
02kooooo0_l00009ooooo`;o000000?oooooo`000?l000004_l000000ooooooo0000o`00000Aoooo
o`;o00000oooool2o`00067ooooo000Looooo`03o`000?oooooooooo03gooooo0_l0000Fooooo`Co
00008Oooool3o`0000Sooooo0_l0000Aooooo`;o00004Oooool2o`000003ooooool0003o000000So
oooo5Ol0000=ooooo`;o00001Oooool2o`0000?ooooo0_l0001Qooooo`007?ooool00ol0003ooooo
ooooo`1Gooooo`;o00006?ooool2o`0000Oooooo0_l00003ooooo`;o00001?ooool4o`0000oooooo
0_l00003ooooo`;o00001_ooool2o`0000;ooooo0_l00003ooooo`Co00001_ooool3o`0000;ooooo
3_l0000?ooooo`;o00007_ooool2o`0004gooooo000Looooo`03o`000?oooooooooo073ooooo0ol0
000<ooooo`;o00001_ooool2o`0000Sooooo0_l0000:ooooo`;o00001_ooool2o`0000;ooooo0_l0
0005ooooo`;o00003?ooool8o`000003ooooool0003o000000;o00002Oooool2o`0000?ooooo0_l0
000Gooooo`;o00001_ooool2o`0004gooooo000Looooo`03o`000?oooooooooo073ooooo0_l00007
ooooo`;o00001Oooool2o`0000oooooo0_l0000Oooooo`;o00001?ooool2o`0000Cooooo3?l00002
ooooo`?o000000?oooooo`000?l000000_ooool2o`0000?ooooo0ol0000:ooooo`;o00001?ooool2
o`0000Cooooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`1Fooooo`;o00008Oooool2o`00
00Gooooo1?l00009ooooo`?o00001Oooool2o`0001_ooooo0ol00003ooooo`;o000000?oooooo`00
0?l000000oooool;o`000005ooooool0003o0000o`000?ooool00_l00008ooooo`;o00002_ooool4
o`0000;ooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`1Fooooo`Co00002_ooool2o`00
00;ooooo0_l00009ooooo`;o00003Oooool2o`0000Wooooo0ol00005ooooo`;o00004?ooool2o`00
00[ooooo0_l00006ooooo`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`Oo00006oooool2
o`0005oooooo000Looooo`03o`000?oooooooooo05Sooooo0_l000000ooooooo0000o`000002oooo
o`;o00000_ooool3o`000004ooooool0003o0000o`0000?ooooo0_l00004ooooo`;o00000oooool2
o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000cooooo0_l0000=ooooo`;o00000_ooool2
o`0001Gooooo0_l000000ooooooo0000o`000005ooooo`Go0000O?ooool001cooooo00?o0000oooo
ooooool0Foooool2o`0000;ooooo0_l000001?oooooo0000o`000?l00002ooooo`?o00000oooool2
o`0000Kooooo1Ol00003ooooo`;o00000_ooool2o`0000?ooooo0_l0000<ooooo`;o00003Oooool2
o`0000?ooooo0_l00004ooooo`;o00005?ooool3o`000005ooooool0003o0000o`000?ooool00ol0
000Gooooo`;o000000?oooooo`000?l00000G_ooool001cooooo00?o0000ooooooooool0Foooool2
o`0000Cooooo0ol00004ooooo`;o00002oooool6o`0000;ooooo0_l00004ooooo`;o000000?ooooo
o`000?l000007oooool3o`0000Cooooo0_l00003ooooo`?o00003_ooool3o`000005ooooool0003o
0000o`000?ooool00ol0000>ooooo`;o00001oooool2o`000003ooooool0003o000005kooooo000L
ooooo`03o`000?oooooooooo05_ooooo0_l00004ooooo`;o00000oooool2o`0000kooooo1_l00007
ooooo`Go00007?ooool2o`000004ooooool0003o0000o`0000;ooooo0_l00005ooooo`?o00004Ooo
ool4o`0000oooooo0_l000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l00000Gooo
ool001cooooo0_l0001Fooooo`;o00002_ooool2o`0000;ooooo0ol00007ooooo`;o00001Oooool2
o`0000;ooooo0ol00004ooooo`Ko00000_ooool2o`0001Wooooo0_l00005ooooo`?o00001_ooool2
o`00017ooooo0_l0000Aooooo`Co00001oooool2o`000003ooooool0003o000000Cooooo0_l0001I
ooooo`007?ooool00ol0003oooooooooo`1Eooooo`;o00002_ooool2o`0000;ooooo0_l00008oooo
o`;o00000_ooool2o`0000;ooooo0_l00002ooooo`;o00001?ooool2o`0000Kooooo0_l0000Koooo
o`;o00000oooool2o`0000Oooooo0_l0000Vooooo`;o00002?ooool2o`0000Kooooo0_l0001Ioooo
o`007?ooool00ol0003oooooooooo`1Dooooo`;o00002_ooool2o`0000Cooooo0ol0000:ooooo`;o
00000_ooool2o`0000;ooooo0_l0000;ooooo`;o00007?ooool2o`0001gooooo0_l00008ooooo`;o
00005Oooool2o`0000[ooooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`1Dooooo`?o0000
2Oooool2o`0000Cooooo0ol00002ooooo`;o00002?ooool2o`0000Cooooo1?l00009ooooo`?o0000
6?ooool2o`0000?ooooo0_l00004ooooo`;o00001Oooool2o`0000kooooo0_l00008ooooo`;o0000
1Oooool2o`0000Kooooo0_l0000Booooo`;o0000EOooool001cooooo00?o0000ooooooooool0D_oo
ool2o`000003ooooool0003o000000Kooooo0_l00008ooooo`;o00000_ooool2o`0000Sooooo0_l0
0005ooooo`?o00002Oooool3o`0001Sooooo0_l00003ooooo`;o00000_ooool4o`0000Gooooo0_l0
0008ooooo`;o00002Oooool2o`0000?ooooo0_l00005ooooo`;o00001?ooool4o`0006Wooooo000L
ooooo`03o`000?oooooooooo05;ooooo0_l00007ooooo`Co00002_ooool2o`0000gooooo0_l00002
ooooo`;o00006Oooool3o`0000[ooooo0_l00006ooooo`;o00002Oooool4o`0000Cooooo0_l00009
ooooo`;o00004?ooool2o`0000Gooooo0_l0001Tooooo`007?ooool00ol0003oooooooooo`19oooo
o`;o00004?ooool3o`0000_ooooo0_l0000=ooooo`;o000000?oooooo`000?l000001_ooool2o`00
00Gooooo0ol00007ooooo`;o000000Coooooo`000?l0003o00002_ooool2o`000003ooooool0003o
000000kooooo1?l0000Rooooo`;o00001?ooool2o`0006Cooooo000Looooo`03o`000?oooooooooo
04Wooooo0_l0000Aooooo`;o00007Oooool2o`0000Kooooo0ol000001?oooooo0000o`000?ooool3
o`0000Oooooo0_l0000=ooooo`;o00000_ooool2o`0001;ooooo0_l0000Pooooo`;o0000J_ooool0
01cooooo00?o0000ooooooooool0Ooooool2o`0000?ooooo0_l000000ooooooo0000o`000009oooo
o`;o00003oooool2o`0001Kooooo0_l0000Oooooo`;o0000Joooool001cooooo00?o0000oooooooo
ool0Ooooool2o`0000Sooooo0_l00007ooooo`;o00007Oooool2o`0002Wooooo0_l0001[ooooo`00
7?ooool00ol0003oooooooooo`1/ooooo`;o00005?ooool2o`0000Gooooo0_l00006ooooo`;o0000
2_ooool2o`0001;ooooo0_l00005ooooo`;o00001?ooool2o`0000Kooooo0_l00021ooooo`007?oo
ool00ol0003oooooooooo`1/ooooo`;o00004?ooool2o`0000;ooooo0_l0000=ooooo`;o000000?o
ooooo`000?l000001oooool3o`0000?ooooo0_l0000Cooooo`;o00001?ooool2o`0000Kooooo0_l0
0002ooooo`;o0000OOooool001cooooo00?o0000ooooooooool0IOooool3o`0001Kooooo0_l0000>
ooooo`;o00001?ooool2o`0000Sooooo0_l00003ooooo`;o00009Oooool2o`0000cooooo0_l0001_
ooooo`007?ooool00ol0003oooooooooo`1Uooooo`?o00009_ooool2o`0000gooooo0_l0000ioooo
o`;o0000Koooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<
ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo05gooooo0_l00006ooooo`;o00001?oo
ool4o`00017ooooo0ol000000ooooooo0000o`00000Gooooo`;o00004oooool2o`0000Gooooo0_l0
002>ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RH
oooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0GOooool2o`0000Kooooo0_l00004ooooo`Co
00004Oooool3o`000003ooooool0003o000001Wooooo0_l00007ooooo`;o00002?ooool2o`0000Co
oooo0ol00005ooooo`;o00007oooool2o`0006Kooooo00000ooooooo410@ooooo`02ooooo`03oa0@
4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo06co
oooo1?l0000_ooooo`;o00001oooool2o`0000kooooo0_l00006ooooo`Co00007Oooool2o`0006Ko
oooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?oooooo
V9RHoc8b<P06ooooo`?o0000K?ooool4o`0002kooooo0_l0000Rooooo`Co0000Poooool00003oooo
ool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Oo<c<co0000o`000?l0003oc<c<00Ko
oooo00?o0000ooooooooool0JOooool2o`0000Sooooo0_l0000Yooooo`;o00008_ooool4o`0000_o
oooo0_l0001fooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05oa0@
4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`1Yooooo`;o00002?ooool2o`0002ko
oooo0_l000000ooooooo0000o`00000Iooooo`;o00003_ooool2o`0007Kooooo00001_ooooooMgMg
oiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooo
oooo06;ooooo0_l00005ooooo`;o00009_ooool2o`00013ooooo0_l000000ooooooo0000o`00000I
ooooo`Co0000Q?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`00
0?l@413oZJVY00Kooooo00?o0000ooooooooool0H_ooool2o`0002Gooooo0_l00006ooooo`;o0000
<?ooool2o`0008Cooooo000Looooo`03o`000?oooooooooo06Gooooo0ol0000Qooooo`;o00003ooo
ool3o`0001gooooo0ol0002<ooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o00002_ooool3
o`0003;ooooo0ol0000Mooooo`?o00005Oooool2o`0007Gooooo000Looooo`03o`000?oooooooooo
05Wooooo0_l0000Aooooo`;o0000<Oooool2o`0001Sooooo0_l0000Cooooo`;o00000_ooool2o`00
07Gooooo000Looooo`03o`000?oooooooooo06cooooo0_l0000Yooooo`;o00001_ooool2o`0001So
oooo0_l0000Cooooo`;o0000NOooool001cooooo00?o0000ooooooooool0L_ooool2o`0002?ooooo
0ol0002_ooooo`007?ooool00ol0003oooooooooo`1booooo`;o00009?ooool2o`000:oooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0Qoooool4o`00
04;ooooo0_l0001jooooo`007?ooool00ol0003oooooooooo`20ooooo`;o00001Oooool4o`0002;o
oooo0_l0000Nooooo`;o0000N_ooool001cooooo00?o0000ooooooooool0N?ooool2o`0000?ooooo
0_l000000ooooooo0000o`00000[ooooo`;o0000V_ooool001cooooo00?o0000ooooooooool0N?oo
ool2o`0000?ooooo0_l0003:ooooo`007?ooool2o`0009Kooooo0_l0002booooo`007?ooool00ol0
003oooooooooo`2Eooooo`;o0000/_ooool001cooooo00?o0000ooooooooool0Uoooool2o`0001Wo
oooo0_l0002Eooooo`007?ooool00ol0003oooooooooo`2Gooooo`;o000000?oooooo`000?l00000
1Oooool2o`000003ooooool0003o000000Sooooo0_l00002ooooo`;o0000UOooool001cooooo00?o
0000ooooooooool0V_ooool2o`0000Gooooo0_l000000ooooooo0000o`000008ooooo`;o0000VOoo
ool001cooooo00?o0000ooooooooool0_?ooool2o`0008_ooooo000Looooo`03o`000?oooooooooo
0:?ooooo0_l0000Gooooo`;o0000Roooool001cooooo00?o0000ooooooooool0Xoooool2o`000:Co
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`2Booooo`;o0000]Oooool001cooooo00?o0000ooooooooool0T_ooool2o`000;Gooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o
0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Booooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooo
od[ooooo000Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`00
5?ooool00ol0003oooooooooo`05ooooo`?o0000oooooom:ooooo`005?ooool00ol0003ooooooooo
o`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000oooo
ooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Booooo`03oeEE
EOmVIVKo00000?ooooooE?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Go
oooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0Eooooo`04oa0@4?l0003oA4A4
olc<c0Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
T?ooool00:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00002oooool00onHV9So410@
omgMg@03ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg
093ooooo002Vooooo`05o`000?ooooooooooooooool000006oooool00on7QhOoEEEEooooo`06oooo
o`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`2>ooooo`00Y_ooool01Ol0
003ooooooooooooooooo000000Wooooo1_l00009ooooo`05olc<c?lQ8B7o0000oeEEEOl000001_oo
ool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool00000T?ooool00:Kooooo00Go
0000ohN7QoooooooZJVYo`00000Hooooo`05ob4Q8On7QhOooooooiRHV?l000001Oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool00000T?ooool00:Gooooo00?o410@o`000?mg
MgL00_l000000onHV9Soooooooooo`0Fooooo`05o`000?ooooooooooooooool000001_ooool00onj
^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@4100T?ooool00<?ooooo00Go8B4QoiRH
V?ooooooMgMgoeEEE@03ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg093ooooo0033ooooo`05olc<c?l@413o0000oc8b<_o^k^h00oooool01OnYZJWo410@
o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP2@ooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(936) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.48076 .36114 Mdot
.44055 .33792 Mdot
.42666 .65486 Mdot
.61019 .43545 Mdot
.40079 .37089 Mdot
.45654 .63019 Mdot
.32088 .48443 Mdot
.35343 .44407 Mdot
.45246 .64419 Mdot
.57324 .5669 Mdot
.34727 .45954 Mdot
.64737 .41774 Mdot
.32109 .45586 Mdot
.60908 .44955 Mdot
.81714 .65278 Mdot
.64013 .52492 Mdot
.42148 .32953 Mdot
.54221 .70003 Mdot
.61433 .41281 Mdot
.40101 .63687 Mdot
.40726 .32174 Mdot
.59998 .44369 Mdot
.48348 .34994 Mdot
.6087 .44992 Mdot
.63543 .44699 Mdot
.46407 .34942 Mdot
.44275 .37891 Mdot
.63647 .43495 Mdot
.64507 .4859 Mdot
.32635 .43823 Mdot
.66595 .67962 Mdot
.84743 .53459 Mdot
.67089 .49805 Mdot
.36818 .21887 Mdot
.36 .45389 Mdot
.76154 .4078 Mdot
.48541 .6526 Mdot
.30717 .45421 Mdot
.35529 .44881 Mdot
.36044 .43811 Mdot
.31846 .44813 Mdot
.46091 .34291 Mdot
.28771 .49861 Mdot
.33108 .51629 Mdot
.55617 .47247 Mdot
.32888 .37821 Mdot
.76418 .53397 Mdot
.60654 .49791 Mdot
.42923 .346 Mdot
.40159 .63393 Mdot
.34668 .24622 Mdot
.31417 .43426 Mdot
.33381 .62913 Mdot
.80093 .27538 Mdot
.30475 .46641 Mdot
.5573 .45487 Mdot
.47251 .65175 Mdot
.58938 .45467 Mdot
.60382 .45226 Mdot
.59887 .36395 Mdot
.65468 .46062 Mdot
.57121 .72582 Mdot
.43603 .29217 Mdot
.46744 .60176 Mdot
.46017 .63672 Mdot
.35061 .44682 Mdot
.42829 .32234 Mdot
.32008 .46305 Mdot
.56142 .42519 Mdot
.48832 .62243 Mdot
.6054 .49732 Mdot
.34215 .44602 Mdot
.48994 .32129 Mdot
.58518 .49029 Mdot
.20502 .51935 Mdot
.7028 .76378 Mdot
.58305 .75285 Mdot
.63182 .35715 Mdot
.70134 .39535 Mdot
.52162 .794 Mdot
.635 .47663 Mdot
.40676 .82931 Mdot
.78523 .68547 Mdot
.47648 .36251 Mdot
.5604 .53254 Mdot
.51326 .64856 Mdot
.57763 .48253 Mdot
.46393 .44465 Mdot
.54757 .4643 Mdot
.21913 .44223 Mdot
.45139 .64881 Mdot
.45415 .32117 Mdot
.61146 .43678 Mdot
.65143 .49773 Mdot
.54901 .2703 Mdot
.65143 .43804 Mdot
.61469 .42842 Mdot
.47995 .37564 Mdot
.3499 .47064 Mdot
.67888 .43761 Mdot
.36039 .4953 Mdot
.36519 .6184 Mdot
.56311 .46091 Mdot
.47298 .66353 Mdot
.48838 .37226 Mdot
.57131 .47882 Mdot
.34569 .48664 Mdot
.62737 .49861 Mdot
.31783 .51979 Mdot
.43595 .33628 Mdot
.64984 .49981 Mdot
.56468 .68586 Mdot
.22831 .63451 Mdot
.45735 .31821 Mdot
.36656 .59964 Mdot
.63385 .50151 Mdot
.58586 .44116 Mdot
.44336 .33731 Mdot
.44 .62111 Mdot
.50067 .49967 Mdot
.4253 .35302 Mdot
.36385 .44471 Mdot
.4162 .32862 Mdot
.58243 .54028 Mdot
.44363 .63984 Mdot
.36399 .62707 Mdot
.35838 .63364 Mdot
.62695 .64015 Mdot
.57533 .47656 Mdot
.32819 .2984 Mdot
.44876 .62539 Mdot
.45488 .32732 Mdot
.32393 .46142 Mdot
.56096 .49873 Mdot
.4624 .31004 Mdot
.33621 .46929 Mdot
.59338 .70939 Mdot
.41814 .69143 Mdot
.43138 .35358 Mdot
.27129 .49588 Mdot
.35134 .42699 Mdot
.36465 .4388 Mdot
.34861 .2296 Mdot
.44007 .34324 Mdot
.5659 .69737 Mdot
.32967 .47209 Mdot
.73104 .6352 Mdot
.55649 .44659 Mdot
.57677 .61172 Mdot
.29666 .77383 Mdot
.32585 .25426 Mdot
.2757 .59205 Mdot
.54739 .71044 Mdot
.36869 .438 Mdot
.64516 .46607 Mdot
.44582 .35306 Mdot
.45166 .34939 Mdot
.60645 .42201 Mdot
.62654 .43793 Mdot
.59821 .49639 Mdot
.64914 .49783 Mdot
.78173 .55798 Mdot
.61422 .50705 Mdot
.62057 .73846 Mdot
.46579 .32235 Mdot
.64637 .45243 Mdot
.42258 .62669 Mdot
.59339 .51636 Mdot
.32984 .44457 Mdot
.59145 .44663 Mdot
.61334 .43382 Mdot
.6532 .50103 Mdot
.30405 .47605 Mdot
.83263 .51629 Mdot
.27296 .73913 Mdot
.7737 .3525 Mdot
.33056 .58862 Mdot
.478 .63385 Mdot
.57132 .46369 Mdot
.57493 .71128 Mdot
.72517 .36838 Mdot
.62485 .46894 Mdot
.17459 .40672 Mdot
.60819 .42964 Mdot
.47499 .21275 Mdot
.66065 .39573 Mdot
.77278 .33906 Mdot
.56439 .64056 Mdot
.64822 .4863 Mdot
.56018 .24588 Mdot
.62314 .2284 Mdot
.3722 .51888 Mdot
.31518 .45117 Mdot
.42044 .62887 Mdot
.46751 .65681 Mdot
.30142 .4378 Mdot
.69125 .43984 Mdot
.63468 .39715 Mdot
.562 .41002 Mdot
.35114 .62766 Mdot
.48081 .2993 Mdot
.58464 .74093 Mdot
.48908 .36716 Mdot
.52095 .86163 Mdot
.23233 .41104 Mdot
.28719 .50311 Mdot
.59519 .74643 Mdot
.42228 .64758 Mdot
.34772 .6276 Mdot
.57797 .70782 Mdot
.61379 .48403 Mdot
.42939 .33502 Mdot
.47911 .18361 Mdot
.70188 .43967 Mdot
.48388 .16635 Mdot
.45327 .30276 Mdot
.49245 .49869 Mdot
.33776 .45987 Mdot
.4013 .64805 Mdot
.58967 .43569 Mdot
.59685 .48014 Mdot
.41808 .29664 Mdot
.60605 .4953 Mdot
.39463 .32672 Mdot
.59523 .42867 Mdot
.42057 .66757 Mdot
.57873 .75294 Mdot
.29849 .4403 Mdot
.6162 .63959 Mdot
.48874 .33399 Mdot
.53423 .65995 Mdot
.44593 .61263 Mdot
.73644 .39428 Mdot
.34602 .44933 Mdot
.57381 .6886 Mdot
.44849 .61403 Mdot
.57762 .7409 Mdot
.60112 .51521 Mdot
.49 .64699 Mdot
.55334 .7096 Mdot
.80696 .54986 Mdot
.55832 .48874 Mdot
.77851 .5955 Mdot
.32545 .48503 Mdot
.4165 .32596 Mdot
.65274 .45538 Mdot
.37876 .62423 Mdot
.66877 .49259 Mdot
.24085 .53682 Mdot
.34306 .6356 Mdot
.3288 .6246 Mdot
.55675 .78785 Mdot
.56237 .68856 Mdot
.24185 .58804 Mdot
.3158 .29318 Mdot
.42249 .32987 Mdot
.57356 .43269 Mdot
.80616 .40366 Mdot
.32989 .4713 Mdot
.61826 .4827 Mdot
.49681 .67323 Mdot
.3268 .4728 Mdot
.58726 .45764 Mdot
.3157 .48795 Mdot
.44656 .34903 Mdot
.35828 .74369 Mdot
.42153 .32526 Mdot
.55532 .48339 Mdot
.33458 .4894 Mdot
.48003 .62413 Mdot
.46545 .35257 Mdot
.6244 .49648 Mdot
.57991 .43885 Mdot
.35568 .62241 Mdot
.65283 .46777 Mdot
.80424 .42763 Mdot
.6564 .48218 Mdot
.44031 .66249 Mdot
.65228 .44185 Mdot
.20623 .35457 Mdot
.38686 .70311 Mdot
.42784 .32406 Mdot
.33061 .62426 Mdot
.45866 .64535 Mdot
.47595 .76874 Mdot
.36674 .5371 Mdot
.63516 .4904 Mdot
.34563 .61466 Mdot
.55344 .61667 Mdot
.30997 .44143 Mdot
.62909 .42068 Mdot
.24905 .41733 Mdot
.4182 .62578 Mdot
.34932 .62562 Mdot
.53677 .4327 Mdot
.4922 .37008 Mdot
.61317 .43653 Mdot
.48436 .62399 Mdot
.41483 .33433 Mdot
.57189 .49835 Mdot
.72332 .53795 Mdot
.34611 .63483 Mdot
.32183 .48279 Mdot
.59211 .38419 Mdot
.60585 .50251 Mdot
.48156 .65112 Mdot
.48363 .31811 Mdot
.36261 .45606 Mdot
.46724 .34035 Mdot
.54842 .19315 Mdot
.30628 .59815 Mdot
.78556 .51977 Mdot
.60452 .74272 Mdot
.27823 .54556 Mdot
.75684 .31324 Mdot
.24806 .62477 Mdot
.70182 .62526 Mdot
.62518 .19431 Mdot
.4451 .61682 Mdot
.46433 .68811 Mdot
.46481 .64749 Mdot
.63174 .45855 Mdot
.45748 .6332 Mdot
.7713 .32908 Mdot
.60003 .42771 Mdot
.48092 .64143 Mdot
.40361 .75682 Mdot
.63327 .43879 Mdot
.458 .31654 Mdot
.81309 .64891 Mdot
.18554 .5159 Mdot
.25012 .34141 Mdot
.46695 .62228 Mdot
.58228 .37871 Mdot
.63552 .43565 Mdot
.6411 .51878 Mdot
.45305 .35955 Mdot
.63457 .42552 Mdot
.58399 .74001 Mdot
.59546 .74301 Mdot
.5577 .59452 Mdot
.31435 .76043 Mdot
.67489 .43412 Mdot
.46301 .35512 Mdot
.72125 .41814 Mdot
.21117 .49993 Mdot
.36937 .61342 Mdot
.35043 .49751 Mdot
.83066 .5329 Mdot
.67431 .41847 Mdot
.2686 .47816 Mdot
.24226 .43491 Mdot
.43978 .32463 Mdot
.81472 .48567 Mdot
.31037 .4567 Mdot
.61926 .26912 Mdot
.50208 .26533 Mdot
.60387 .47994 Mdot
.35025 .4558 Mdot
.65977 .42408 Mdot
.20151 .43855 Mdot
.73653 .65589 Mdot
.5542 .82441 Mdot
.55606 .48051 Mdot
.22567 .56997 Mdot
.58922 .44306 Mdot
.50841 .50011 Mdot
.65701 .48106 Mdot
.47134 .3421 Mdot
.61081 .56244 Mdot
.42712 .46873 Mdot
.31378 .77678 Mdot
.234 .39903 Mdot
.54874 .71378 Mdot
.58421 .43818 Mdot
.60268 .47897 Mdot
.58051 .69817 Mdot
.48092 .33984 Mdot
.64967 .49399 Mdot
.6521 .59119 Mdot
.59696 .49021 Mdot
.31573 .44742 Mdot
.62312 .66781 Mdot
.40391 .3052 Mdot
.66081 .49117 Mdot
.41614 .34661 Mdot
.30659 .47616 Mdot
.34911 .44274 Mdot
.54087 .4763 Mdot
.36531 .47078 Mdot
.60407 .43218 Mdot
.67178 .73101 Mdot
.46374 .3677 Mdot
.70106 .42572 Mdot
.48229 .328 Mdot
.67857 .37332 Mdot
.34036 .48972 Mdot
.37179 .62794 Mdot
.45362 .26217 Mdot
.31238 .45722 Mdot
.2757 .31354 Mdot
.57947 .40317 Mdot
.67267 .45898 Mdot
.21526 .41162 Mdot
.46604 .61936 Mdot
.35645 .63213 Mdot
.35582 .48021 Mdot
.60366 .50154 Mdot
.65214 .4316 Mdot
.30119 .45768 Mdot
.58326 .28761 Mdot
.47848 .7602 Mdot
.62797 .43108 Mdot
.47519 .34288 Mdot
.45713 .32849 Mdot
.57452 .4954 Mdot
.62813 .48967 Mdot
.43124 .65038 Mdot
.33534 .62344 Mdot
.3579 .61213 Mdot
.35468 .63393 Mdot
.43067 .67041 Mdot
.37096 .36406 Mdot
.36165 .43845 Mdot
.34111 .31343 Mdot
.23658 .48012 Mdot
.67929 .50651 Mdot
.48619 .64254 Mdot
.60009 .4711 Mdot
.6052 .43718 Mdot
.36321 .45698 Mdot
.31082 .56868 Mdot
.56905 .53823 Mdot
.44821 .36503 Mdot
.35377 .48375 Mdot
.6467 .40816 Mdot
.37647 .29982 Mdot
.56133 .72279 Mdot
.24169 .34719 Mdot
.34614 .4471 Mdot
.44198 .31955 Mdot
.30393 .48668 Mdot
.59886 .48263 Mdot
.57215 .42639 Mdot
.44312 .3313 Mdot
.5523 .69146 Mdot
.54328 .43286 Mdot
.58518 .45739 Mdot
.14825 .57079 Mdot
.20283 .52816 Mdot
.31739 .41075 Mdot
.64849 .47608 Mdot
.6618 .4435 Mdot
.55814 .72998 Mdot
.59914 .48769 Mdot
.57746 .43859 Mdot
.22966 .65332 Mdot
.32317 .40527 Mdot
.54066 .69563 Mdot
.62806 .27356 Mdot
.45085 .30275 Mdot
.82421 .45982 Mdot
.35808 .61364 Mdot
.28455 .47021 Mdot
.34089 .72491 Mdot
.34333 .62591 Mdot
.24583 .53171 Mdot
.8209 .4753 Mdot
.35464 .6335 Mdot
.51803 .62579 Mdot
.56916 .54607 Mdot
.61464 .42572 Mdot
.58505 .44665 Mdot
.56934 .70866 Mdot
.44128 .34535 Mdot
.53034 .586 Mdot
.74254 .67914 Mdot
.5951 .44183 Mdot
.41408 .37264 Mdot
.81398 .56304 Mdot
.35139 .62203 Mdot
.58754 .73513 Mdot
.59335 .70164 Mdot
.58217 .44297 Mdot
.25261 .67034 Mdot
.46292 .35099 Mdot
.62483 .49617 Mdot
.61662 .5098 Mdot
.47151 .62393 Mdot
.43157 .32613 Mdot
.45988 .61191 Mdot
.35084 .63654 Mdot
.66081 .24071 Mdot
.13808 .53432 Mdot
.36151 .46621 Mdot
.78532 .41409 Mdot
.32068 .43695 Mdot
.57335 .80837 Mdot
.341 .62908 Mdot
.6304 .47424 Mdot
.48912 .32933 Mdot
.62505 .49938 Mdot
.61602 .47596 Mdot
.61268 .48299 Mdot
.60155 .4013 Mdot
.18088 .39572 Mdot
.5832 .72062 Mdot
.60781 .53791 Mdot
.44358 .66239 Mdot
.79489 .42506 Mdot
.7533 .70212 Mdot
.5929 .47388 Mdot
.57599 .44636 Mdot
.46042 .31395 Mdot
.60998 .42131 Mdot
.30649 .44599 Mdot
.4839 .31788 Mdot
.64658 .50616 Mdot
.80709 .48336 Mdot
.64458 .49863 Mdot
.75863 .32711 Mdot
.30265 .486 Mdot
.27288 .31839 Mdot
.59168 .53505 Mdot
.36357 .63184 Mdot
.35618 .63232 Mdot
.33395 .61319 Mdot
.30305 .49204 Mdot
.4821 .64713 Mdot
.69339 .74156 Mdot
.68321 .48578 Mdot
.64301 .46094 Mdot
.65309 .43132 Mdot
.48273 .67279 Mdot
.46443 .43949 Mdot
.25987 .60002 Mdot
.63338 .4022 Mdot
.43344 .64098 Mdot
.41554 .32569 Mdot
.41926 .6023 Mdot
.48571 .32559 Mdot
.54002 .702 Mdot
.34585 .45728 Mdot
.5687 .7311 Mdot
.3051 .27648 Mdot
.43802 .33651 Mdot
.41921 .29467 Mdot
.47955 .63623 Mdot
.47682 .49138 Mdot
.78381 .27334 Mdot
.49155 .62401 Mdot
.64512 .61811 Mdot
.46024 .36059 Mdot
.62531 .51156 Mdot
.58375 .64213 Mdot
.47335 .48153 Mdot
.47495 .64113 Mdot
.62569 .463 Mdot
.28942 .71364 Mdot
.43022 .64893 Mdot
.6289 .42015 Mdot
.43578 .62558 Mdot
.3323 .44648 Mdot
.44481 .62428 Mdot
.47804 .30222 Mdot
.56951 .47382 Mdot
.803 .29268 Mdot
.5511 .65063 Mdot
.65547 .47874 Mdot
.35158 .48509 Mdot
.65569 .57577 Mdot
.60936 .46757 Mdot
.59242 .73994 Mdot
.44138 .63933 Mdot
.48872 .74116 Mdot
.64206 .44011 Mdot
.4641 .62786 Mdot
.48392 .35439 Mdot
.29795 .48805 Mdot
.58123 .79457 Mdot
.37065 .62389 Mdot
.44771 .3584 Mdot
.35058 .63894 Mdot
.339 .49576 Mdot
.65706 .43897 Mdot
.60831 .50696 Mdot
.47042 .33156 Mdot
.36617 .76826 Mdot
.65164 .44514 Mdot
.6348 .47627 Mdot
.41666 .64801 Mdot
.48071 .67109 Mdot
.37806 .76733 Mdot
.45094 .61613 Mdot
.59646 .41143 Mdot
.47019 .33262 Mdot
.61541 .4423 Mdot
.45221 .31377 Mdot
.58027 .43069 Mdot
.50043 .38173 Mdot
.47328 .36397 Mdot
.28581 .6509 Mdot
.62173 .45297 Mdot
.64228 .39036 Mdot
.61367 .47935 Mdot
.60171 .49398 Mdot
.44034 .65578 Mdot
.58919 .72171 Mdot
.56498 .51109 Mdot
.59932 .69369 Mdot
.59318 .73354 Mdot
.57411 .2085 Mdot
.46638 .62104 Mdot
.56249 .7109 Mdot
.78733 .584 Mdot
.33106 .62124 Mdot
.57558 .71813 Mdot
.77203 .68404 Mdot
.36274 .46265 Mdot
.4335 .30439 Mdot
.63328 .43924 Mdot
.60494 .18786 Mdot
.6847 .70186 Mdot
.35261 .61704 Mdot
.65539 .48243 Mdot
.60245 .46902 Mdot
.44046 .36785 Mdot
.48193 .85822 Mdot
.43258 .66189 Mdot
.63283 .45529 Mdot
.43105 .31709 Mdot
.33774 .81601 Mdot
.45712 .66357 Mdot
.57385 .71424 Mdot
.29948 .46335 Mdot
.49644 .37496 Mdot
.37135 .62253 Mdot
.30449 .44523 Mdot
.3071 .65976 Mdot
.27725 .30652 Mdot
.63318 .50239 Mdot
.48755 .64515 Mdot
.29835 .27048 Mdot
.69034 .44896 Mdot
.30639 .41978 Mdot
.51908 .4308 Mdot
.44242 .32249 Mdot
.30319 .45579 Mdot
.56083 .72742 Mdot
.48079 .30886 Mdot
.47944 .34357 Mdot
.35465 .44282 Mdot
.48211 .59834 Mdot
.48902 .49497 Mdot
.32339 .44342 Mdot
.2228 .44576 Mdot
.50505 .18844 Mdot
.33631 .61858 Mdot
.59373 .72377 Mdot
.43409 .20981 Mdot
.4617 .34288 Mdot
.83095 .52943 Mdot
.24868 .32517 Mdot
.61539 .42854 Mdot
.55842 .70199 Mdot
.35775 .39416 Mdot
.71933 .71766 Mdot
.32454 .47524 Mdot
.42297 .4478 Mdot
.5747 .68341 Mdot
.63197 .43042 Mdot
.53108 .37541 Mdot
.63169 .46376 Mdot
.34258 .45987 Mdot
.68567 .38857 Mdot
.44276 .31857 Mdot
.3502 .48933 Mdot
.24288 .3444 Mdot
.59957 .43512 Mdot
.62553 .45975 Mdot
.64729 .671 Mdot
.42851 .33898 Mdot
.36472 .61451 Mdot
.63544 .49627 Mdot
.58779 .45253 Mdot
.66931 .4682 Mdot
.62246 .38883 Mdot
.23551 .64222 Mdot
.63103 .4548 Mdot
.39542 .65453 Mdot
.65141 .51233 Mdot
.6189 .45246 Mdot
.41695 .3467 Mdot
.14463 .51073 Mdot
.37288 .62971 Mdot
.58994 .44815 Mdot
.63672 .50212 Mdot
.35956 .44859 Mdot
.52346 .56508 Mdot
.46649 .47559 Mdot
.49379 .64398 Mdot
.731 .60664 Mdot
.60333 .40144 Mdot
.46093 .30763 Mdot
.57381 .68701 Mdot
.58541 .50151 Mdot
.45581 .30797 Mdot
.61313 .52493 Mdot
.43027 .64401 Mdot
.33617 .62021 Mdot
.25499 .35196 Mdot
.57004 .71892 Mdot
.66761 .70658 Mdot
.33362 .33151 Mdot
.41581 .63207 Mdot
.64134 .45515 Mdot
.29127 .45497 Mdot
.49196 .64528 Mdot
.35799 .62219 Mdot
.53556 .47334 Mdot
.45376 .35249 Mdot
.45656 .32002 Mdot
.57013 .61462 Mdot
.37283 .66185 Mdot
.19262 .63659 Mdot
.33483 .44718 Mdot
.63923 .51661 Mdot
.31762 .29783 Mdot
.45658 .31903 Mdot
.58287 .62606 Mdot
.56234 .71245 Mdot
.32399 .4767 Mdot
.35634 .60853 Mdot
.4594 .31083 Mdot
.42702 .34643 Mdot
.56132 .49148 Mdot
.58405 .46951 Mdot
.69177 .62654 Mdot
.56573 .60522 Mdot
.30233 .46964 Mdot
.58783 .7061 Mdot
.46623 .61051 Mdot
.63678 .46527 Mdot
.47873 .36063 Mdot
.47619 .19223 Mdot
.63338 .50524 Mdot
.43138 .65199 Mdot
.44461 .32412 Mdot
.57557 .69366 Mdot
.59186 .73841 Mdot
.60137 .49311 Mdot
.62505 .36863 Mdot
.31006 .4713 Mdot
.456 .31676 Mdot
.38593 .247 Mdot
.65441 .44851 Mdot
.58009 .47013 Mdot
.53136 .43214 Mdot
.33643 .43715 Mdot
.27678 .31805 Mdot
.55392 .68651 Mdot
.45235 .34288 Mdot
.64715 .49251 Mdot
.57033 .72468 Mdot
.29988 .3018 Mdot
.34142 .62181 Mdot
.43976 .62568 Mdot
.59151 .74066 Mdot
.56911 .6944 Mdot
.59558 .72022 Mdot
.83128 .545 Mdot
.48603 .30711 Mdot
.71915 .44871 Mdot
.65802 .46904 Mdot
.57083 .61691 Mdot
.54847 .4818 Mdot
.29867 .48249 Mdot
.46442 .61767 Mdot
.6123 .47606 Mdot
.5613 .49067 Mdot
.56047 .39219 Mdot
.68587 .41096 Mdot
.4054 .34684 Mdot
.43366 .33341 Mdot
.67577 .50625 Mdot
.47491 .62452 Mdot
.49028 .86798 Mdot
.78286 .30668 Mdot
.57364 .5316 Mdot
.50148 .52185 Mdot
.48254 .35167 Mdot
.35201 .43861 Mdot
.45417 .47307 Mdot
.31121 .48904 Mdot
.45359 .33747 Mdot
.63468 .46197 Mdot
.34525 .31677 Mdot
.57714 .7441 Mdot
.60005 .49952 Mdot
.33463 .46427 Mdot
.59926 .4982 Mdot
.30193 .4523 Mdot
.40741 .26831 Mdot
.21885 .46018 Mdot
.60841 .42938 Mdot
.6606 .45587 Mdot
.52827 .39523 Mdot
.59304 .47151 Mdot
.44929 .82422 Mdot
.48286 .34148 Mdot
.29925 .73532 Mdot
.57101 .4995 Mdot
.65556 .34544 Mdot
.65662 .45906 Mdot
.32173 .72615 Mdot
.58241 .47602 Mdot
.42944 .50551 Mdot
.62066 .42783 Mdot
.56888 .45515 Mdot
.32698 .48989 Mdot
.3592 .4484 Mdot
.47725 .36858 Mdot
.36874 .61678 Mdot
.78004 .36724 Mdot
.58253 .46141 Mdot
.41411 .66024 Mdot
.27934 .44095 Mdot
.57781 .69794 Mdot
.45598 .33812 Mdot
.35629 .83312 Mdot
.31244 .48438 Mdot
.45184 .60659 Mdot
.37731 .7811 Mdot
.39648 .64506 Mdot
.37563 .41856 Mdot
.53586 .5397 Mdot
.55624 .69076 Mdot
.63912 .4344 Mdot
.38075 .22011 Mdot
.20954 .52516 Mdot
.53818 .45441 Mdot
.33998 .49381 Mdot
.72604 .37857 Mdot
.43687 .2121 Mdot
.60126 .71916 Mdot
.55234 .7159 Mdot
.31436 .48321 Mdot
.41217 .64995 Mdot
.59543 .40554 Mdot
.56157 .71344 Mdot
.42029 .636 Mdot
.32849 .61838 Mdot
.39834 .51349 Mdot
.46081 .3485 Mdot
.24379 .34803 Mdot
.31382 .36738 Mdot
.30304 .47341 Mdot
.52997 .67094 Mdot
.49081 .38132 Mdot
.49861 .34955 Mdot
.3745 .62199 Mdot
.44096 .65718 Mdot
.48343 .30745 Mdot
.58549 .41306 Mdot
.69049 .41012 Mdot
.59245 .44355 Mdot
.5701 .70323 Mdot
.58784 .47789 Mdot
.4365 .65116 Mdot
.32408 .4704 Mdot
.45508 .65866 Mdot
.32162 .48702 Mdot
.3638 .35026 Mdot
.62022 .49282 Mdot
.57026 .45509 Mdot
.67827 .70896 Mdot
.46685 .37184 Mdot
.34982 .24788 Mdot
.43048 .67265 Mdot
.46795 .65136 Mdot
.58184 .4328 Mdot
.48722 .33632 Mdot
.58335 .75726 Mdot
.67423 .71538 Mdot
.5963 .50223 Mdot
.48337 .33993 Mdot
.63809 .45888 Mdot
.79502 .56096 Mdot
.19264 .53608 Mdot
.46592 .33556 Mdot
.33873 .79085 Mdot
.64406 .47974 Mdot
.6376 .55342 Mdot
.64813 .42671 Mdot
.66612 .59712 Mdot
.6516 .44376 Mdot
.45412 .30262 Mdot
.59446 .44709 Mdot
.47835 .30858 Mdot
.41029 .64244 Mdot
.35337 .43603 Mdot
.45451 .36286 Mdot
.60411 .50796 Mdot
.85117 .49782 Mdot
.34099 .4553 Mdot
.58661 .43738 Mdot
.34601 .47452 Mdot
.43632 .31017 Mdot
.43326 .35173 Mdot
.71708 .73021 Mdot
.30354 .41409 Mdot
.33 .4468 Mdot
.6302 .44914 Mdot
.28411 .36837 Mdot
.62176 .4477 Mdot
.67666 .63126 Mdot
.55964 .47593 Mdot
.65254 .44338 Mdot
.69433 .77499 Mdot
.31458 .43809 Mdot
.19939 .63863 Mdot
.7535 .66239 Mdot
.82827 .55824 Mdot
.50433 .35365 Mdot
.60096 .71847 Mdot
.81813 .49272 Mdot
.34591 .63625 Mdot
.44229 .63116 Mdot
.61152 .47697 Mdot
.42381 .27202 Mdot
.30645 .45405 Mdot
.58794 .71829 Mdot
.60679 .42931 Mdot
.43471 .65543 Mdot
.53361 .76734 Mdot
.37093 .44476 Mdot
.46032 .3424 Mdot
.45193 .36783 Mdot
.3097 .78744 Mdot
.64784 .49267 Mdot
.57588 .44336 Mdot
.34489 .45951 Mdot
.68712 .42215 Mdot
.57171 .6889 Mdot
.39418 .74406 Mdot
.33023 .44731 Mdot
.48345 .53484 Mdot
.43521 .33938 Mdot
.60176 .47035 Mdot
.47724 .44303 Mdot
.36276 .55185 Mdot
.62106 .24803 Mdot
.57252 .70898 Mdot
.67644 .6416 Mdot
.4535 .30259 Mdot
.32703 .46319 Mdot
.43311 .69491 Mdot
.6637 .50057 Mdot
.59983 .4645 Mdot
.67333 .64545 Mdot
.54122 .60145 Mdot
.61546 .75813 Mdot
.58511 .42147 Mdot
.54088 .59689 Mdot
.57332 .43669 Mdot
.66979 .47603 Mdot
.57839 .41857 Mdot
.5758 .47238 Mdot
.48337 .34349 Mdot
.58333 .39158 Mdot
.45407 .62587 Mdot
.55415 .26716 Mdot
.43419 .45101 Mdot
.65186 .45696 Mdot
.62945 .45732 Mdot
.67327 .28361 Mdot
.26115 .44883 Mdot
.47689 .35503 Mdot
.46144 .29082 Mdot
.36748 .46499 Mdot
.63865 .38871 Mdot
.43354 .66766 Mdot
.5508 .40487 Mdot
.45067 .65694 Mdot
.48456 .33331 Mdot
.47091 .6545 Mdot
.36941 .44798 Mdot
.4878 .6451 Mdot
.42988 .67066 Mdot
.30504 .45139 Mdot
.43562 .34797 Mdot
.58795 .49111 Mdot
.35519 .4822 Mdot
.64949 .66908 Mdot
.56943 .70388 Mdot
.7195 .72834 Mdot
.62646 .52045 Mdot
.41491 .42191 Mdot
.72296 .53946 Mdot
.45597 .65746 Mdot
.19856 .58523 Mdot
.47197 .36461 Mdot
.56938 .74374 Mdot
.4852 .33615 Mdot
.22361 .34804 Mdot
.59035 .71759 Mdot
.77733 .67854 Mdot
.33657 .64868 Mdot
.52373 .7478 Mdot
.57027 .4252 Mdot
.51855 .37123 Mdot
.48711 .62406 Mdot
.30576 .45541 Mdot
.32107 .6458 Mdot
.56665 .46386 Mdot
.2541 .62923 Mdot
.46621 .37388 Mdot
.33436 .61509 Mdot
.32116 .461 Mdot
.35602 .48396 Mdot
.62717 .50233 Mdot
.42994 .77684 Mdot
.56544 .47552 Mdot
.35691 .66007 Mdot
.70957 .62541 Mdot
.53658 .41288 Mdot
.5931 .42962 Mdot
.47227 .66244 Mdot
.63761 .45767 Mdot
.72988 .44738 Mdot
.35392 .22731 Mdot
.57179 .41069 Mdot
.30344 .60795 Mdot
.5337 .70575 Mdot
.44165 .33453 Mdot
.59024 .53341 Mdot
.36365 .62056 Mdot
.64657 .47854 Mdot
.34396 .19436 Mdot
.57527 .72079 Mdot
.5135 .6715 Mdot
.66033 .47176 Mdot
.63177 .49867 Mdot
.48063 .26013 Mdot
.43165 .26899 Mdot
.35513 .60795 Mdot
.59705 .45997 Mdot
.7284 .62602 Mdot
.35432 .46206 Mdot
.56961 .48379 Mdot
.58452 .4449 Mdot
.61056 .2199 Mdot
.34217 .4398 Mdot
.46174 .65835 Mdot
.33485 .6295 Mdot
.45551 .61055 Mdot
.5487 .67679 Mdot
.45122 .48887 Mdot
.58055 .61694 Mdot
.19507 .53076 Mdot
.59748 .71357 Mdot
.63811 .50613 Mdot
.5721 .54064 Mdot
.64075 .48802 Mdot
.55726 .72446 Mdot
.33184 .43824 Mdot
.47213 .36162 Mdot
.25989 .35527 Mdot
.35179 .6264 Mdot
.63316 .42191 Mdot
.5769 .73913 Mdot
.44816 .35337 Mdot
.54263 .66078 Mdot
.44664 .33916 Mdot
.32061 .45172 Mdot
.32686 .50245 Mdot
.58529 .73119 Mdot
.48492 .32623 Mdot
.38473 .6465 Mdot
.73675 .68468 Mdot
.55875 .46354 Mdot
.3709 .42649 Mdot
.48642 .35165 Mdot
.44041 .37702 Mdot
.48268 .37239 Mdot
.61029 .49468 Mdot
.50933 .53471 Mdot
.66389 .49005 Mdot
.31007 .47862 Mdot
.43009 .63096 Mdot
.5733 .60519 Mdot
.42926 .2347 Mdot
.52866 .61895 Mdot
.54642 .47597 Mdot
.5988 .43826 Mdot
.58245 .44276 Mdot
.55275 .46862 Mdot
.40108 .68537 Mdot
.6254 .49081 Mdot
.32643 .48928 Mdot
.44279 .64906 Mdot
.65611 .46515 Mdot
.36192 .61691 Mdot
.48718 .48223 Mdot
.57864 .68882 Mdot
.44036 .47633 Mdot
.82925 .44879 Mdot
.44924 .35549 Mdot
.46158 .61344 Mdot
.44524 .63007 Mdot
.59285 .70819 Mdot
.30713 .4558 Mdot
.44334 .34278 Mdot
.68583 .59011 Mdot
.59299 .71376 Mdot
.59181 .44893 Mdot
.3248 .69925 Mdot
.29408 .67843 Mdot
.63065 .42775 Mdot
.61855 .47032 Mdot
.33038 .62561 Mdot
.41818 .65542 Mdot
.52492 .15363 Mdot
.59652 .65213 Mdot
.58786 .72744 Mdot
.55084 .69817 Mdot
.49562 .35957 Mdot
.56294 .53015 Mdot
.31746 .48193 Mdot
.6314 .67751 Mdot
.62532 .5875 Mdot
.65528 .7091 Mdot
.56623 .80498 Mdot
.6128 .50446 Mdot
.52228 .31202 Mdot
.6027 .4335 Mdot
.4524 .37192 Mdot
.42585 .32498 Mdot
.46947 .3574 Mdot
.3063 .46883 Mdot
.68723 .37457 Mdot
.33815 .48821 Mdot
.8156 .40134 Mdot
.46328 .3017 Mdot
.43384 .71069 Mdot
.47727 .65018 Mdot
.61711 .53121 Mdot
.56916 .69003 Mdot
.38321 .4552 Mdot
.56387 .4237 Mdot
.24275 .65534 Mdot
.48623 .64394 Mdot
.43129 .34447 Mdot
.53926 .54134 Mdot
.72357 .27378 Mdot
.47411 .49533 Mdot
.68683 .50808 Mdot
.48797 .27472 Mdot
.58579 .7047 Mdot
.61794 .24859 Mdot
.54537 .69651 Mdot
.33197 .4716 Mdot
.56869 .46659 Mdot
.57634 .4805 Mdot
.57964 .43041 Mdot
.62326 .49062 Mdot
.36429 .4546 Mdot
.58052 .51497 Mdot
.20622 .3546 Mdot
.33291 .62174 Mdot
.80019 .54572 Mdot
.561 .7194 Mdot
.31736 .49585 Mdot
.44495 .65115 Mdot
.35583 .61096 Mdot
.60494 .63259 Mdot
.62258 .42916 Mdot
.61367 .47771 Mdot
.37709 .61793 Mdot
.59402 .41784 Mdot
.61816 .39958 Mdot
.45704 .62704 Mdot
.52975 .61778 Mdot
.59947 .7371 Mdot
.56703 .72968 Mdot
.32884 .4403 Mdot
.48538 .32948 Mdot
.56535 .70996 Mdot
.41708 .6495 Mdot
.59871 .52393 Mdot
.60623 .51055 Mdot
.48632 .3536 Mdot
.24682 .32687 Mdot
.59629 .70472 Mdot
.54348 .54527 Mdot
.46701 .30551 Mdot
.48784 .30845 Mdot
.60112 .46308 Mdot
.54264 .42165 Mdot
.44403 .3805 Mdot
.59726 .73328 Mdot
.32002 .49677 Mdot
.51762 .72507 Mdot
.33808 .46632 Mdot
.44365 .34737 Mdot
.57492 .49923 Mdot
.4346 .34393 Mdot
.64991 .47876 Mdot
.79215 .72804 Mdot
.57846 .47961 Mdot
.18887 .48785 Mdot
.66077 .60831 Mdot
.44827 .63187 Mdot
.38566 .64565 Mdot
.35078 .61408 Mdot
.46288 .30402 Mdot
.58725 .50436 Mdot
.54953 .69739 Mdot
.80829 .6141 Mdot
.48381 .38656 Mdot
.43095 .6377 Mdot
.42721 .66408 Mdot
.31225 .44085 Mdot
.6587 .48047 Mdot
.5984 .46914 Mdot
.48606 .64915 Mdot
.74299 .53348 Mdot
.46798 .3128 Mdot
.57865 .44121 Mdot
.60806 .44292 Mdot
.45302 .62992 Mdot
.73285 .68822 Mdot
.49141 .29609 Mdot
.57078 .46572 Mdot
.4947 .6887 Mdot
.29952 .48561 Mdot
.55591 .4536 Mdot
.57862 .51371 Mdot
.55903 .69595 Mdot
.7979 .49273 Mdot
.37515 .21248 Mdot
.29816 .47792 Mdot
.36538 .61519 Mdot
.64245 .50636 Mdot
.47759 .64878 Mdot
.60657 .50962 Mdot
.76396 .38276 Mdot
.33415 .61751 Mdot
.63212 .4835 Mdot
.55653 .52076 Mdot
.42497 .3309 Mdot
.62852 .49283 Mdot
.66077 .26045 Mdot
.48361 .61566 Mdot
.63094 .48821 Mdot
.59722 .36711 Mdot
.34863 .44422 Mdot
.57146 .53003 Mdot
.55723 .71864 Mdot
.66812 .59307 Mdot
.3339 .34365 Mdot
.49667 .66673 Mdot
.56738 .72858 Mdot
.59099 .49738 Mdot
.40817 .64714 Mdot
.30065 .46935 Mdot
.24412 .6241 Mdot
.59009 .42496 Mdot
.34201 .45886 Mdot
.32323 .46878 Mdot
.57532 .72713 Mdot
.22087 .68084 Mdot
.58885 .5254 Mdot
.59196 .47418 Mdot
.66656 .25834 Mdot
.4258 .35573 Mdot
.58797 .48216 Mdot
.6345 .50618 Mdot
.33384 .48654 Mdot
.45327 .26092 Mdot
.70567 .34302 Mdot
.40087 .75522 Mdot
.29786 .45815 Mdot
.50251 .61838 Mdot
.4064 .64567 Mdot
.56039 .71689 Mdot
.44621 .32981 Mdot
.56479 .67987 Mdot
.46414 .62282 Mdot
.64227 .49942 Mdot
.33059 .48385 Mdot
.52725 .21186 Mdot
.31758 .43343 Mdot
.49735 .64662 Mdot
.44249 .37282 Mdot
.30555 .31487 Mdot
.27616 .24187 Mdot
.3244 .36885 Mdot
.28871 .5001 Mdot
.57727 .69767 Mdot
.31398 .66501 Mdot
.60462 .4411 Mdot
.60817 .25277 Mdot
.59319 .49379 Mdot
.54507 .3617 Mdot
.44662 .61821 Mdot
.37478 .61993 Mdot
.56956 .46753 Mdot
.69716 .63568 Mdot
.35018 .42913 Mdot
.30897 .44241 Mdot
.62523 .48193 Mdot
.3126 .45659 Mdot
.5866 .46636 Mdot
.44268 .65532 Mdot
.1831 .60135 Mdot
.59321 .43737 Mdot
.67004 .45898 Mdot
.25757 .46729 Mdot
.73327 .7171 Mdot
.38684 .65667 Mdot
.51542 .30184 Mdot
.68986 .24214 Mdot
.31262 .45756 Mdot
.53796 .48991 Mdot
.48951 .63415 Mdot
.33008 .62573 Mdot
.38337 .6453 Mdot
.59417 .48751 Mdot
.60072 .48806 Mdot
.58293 .43241 Mdot
.62659 .46052 Mdot
.6149 .25473 Mdot
.65169 .40034 Mdot
.55093 .33292 Mdot
.61599 .47718 Mdot
.53114 .37191 Mdot
.35657 .47865 Mdot
.40917 .31807 Mdot
.57895 .68309 Mdot
.61513 .50454 Mdot
.39826 .31206 Mdot
.30529 .49065 Mdot
.8148 .39898 Mdot
.32446 .43745 Mdot
.45761 .64441 Mdot
.34373 .43506 Mdot
.65284 .4716 Mdot
.45762 .32798 Mdot
.49346 .63125 Mdot
.23717 .57216 Mdot
.44073 .63208 Mdot
.65553 .47893 Mdot
.51366 .69953 Mdot
.44465 .62866 Mdot
.47319 .46062 Mdot
.45354 .32535 Mdot
.7219 .63718 Mdot
.42582 .32394 Mdot
.63348 .48654 Mdot
.63484 .4821 Mdot
.32371 .63122 Mdot
.35692 .43427 Mdot
.43331 .31097 Mdot
.15095 .58229 Mdot
.54643 .68683 Mdot
.47062 .35324 Mdot
.66951 .50297 Mdot
.52858 .57798 Mdot
.46477 .32645 Mdot
.72512 .58662 Mdot
.30437 .45865 Mdot
.48697 .31261 Mdot
.66904 .50045 Mdot
.28634 .51929 Mdot
.58111 .74698 Mdot
.45344 .66721 Mdot
.43082 .53082 Mdot
.48395 .6199 Mdot
.3167 .49766 Mdot
.48893 .66264 Mdot
.356 .46333 Mdot
.3369 .2596 Mdot
.69882 .40742 Mdot
.29405 .44671 Mdot
.33056 .49939 Mdot
.47552 .6329 Mdot
.59508 .42664 Mdot
.41085 .46303 Mdot
.58195 .42115 Mdot
.55901 .43505 Mdot
.355 .45716 Mdot
.44259 .3052 Mdot
.43157 .30427 Mdot
.52195 .37321 Mdot
.45078 .36792 Mdot
.44804 .65762 Mdot
.19163 .53257 Mdot
.31049 .27184 Mdot
.34828 .45571 Mdot
.35622 .4873 Mdot
.62411 .45045 Mdot
.47937 .64438 Mdot
.41084 .63627 Mdot
.3187 .47964 Mdot
.55779 .23259 Mdot
.66162 .49427 Mdot
.43465 .37268 Mdot
.46795 .30179 Mdot
.46872 .3343 Mdot
.48919 .36862 Mdot
.68331 .33112 Mdot
.30415 .45751 Mdot
.46258 .30267 Mdot
.62846 .48123 Mdot
.5987 .48735 Mdot
.35992 .6302 Mdot
.56386 .72731 Mdot
.62018 .52461 Mdot
.61278 .41091 Mdot
.603 .46524 Mdot
.44003 .62636 Mdot
.62761 .54078 Mdot
.35155 .612 Mdot
.43906 .66442 Mdot
.43938 .67135 Mdot
.36949 .62911 Mdot
.5179 .37996 Mdot
.69397 .23724 Mdot
.63317 .45565 Mdot
.70791 .4465 Mdot
.47456 .6477 Mdot
.21293 .61799 Mdot
.2834 .31454 Mdot
.58495 .4291 Mdot
.38055 .53575 Mdot
.48843 .65536 Mdot
.43157 .35774 Mdot
.58952 .48696 Mdot
.34706 .6335 Mdot
.57836 .68924 Mdot
.67509 .49618 Mdot
.33598 .63131 Mdot
.48233 .31989 Mdot
.6019 .70551 Mdot
.49075 .32118 Mdot
.49187 .65162 Mdot
.55948 .52318 Mdot
.78313 .26914 Mdot
.44981 .6125 Mdot
.7876 .63296 Mdot
.4173 .26988 Mdot
.58095 .4376 Mdot
.46644 .61268 Mdot
.43058 .35995 Mdot
.30791 .49562 Mdot
.53567 .58369 Mdot
.46443 .36713 Mdot
.36665 .61466 Mdot
.34903 .63112 Mdot
.45369 .62721 Mdot
.43413 .3297 Mdot
.57041 .48913 Mdot
.43958 .31709 Mdot
.34074 .43464 Mdot
.61667 .43522 Mdot
.76871 .32705 Mdot
.69896 .43224 Mdot
.45707 .30431 Mdot
.43527 .65824 Mdot
.56137 .73418 Mdot
.61975 .4311 Mdot
.781 .62601 Mdot
.65127 .49527 Mdot
.35099 .46308 Mdot
.27955 .71319 Mdot
.55327 .21385 Mdot
.65531 .45727 Mdot
.62471 .45177 Mdot
.30257 .45497 Mdot
.62132 .42958 Mdot
.65134 .44622 Mdot
.2917 .42556 Mdot
.43081 .32379 Mdot
.59755 .44489 Mdot
.41598 .64051 Mdot
.37778 .22967 Mdot
.66323 .48803 Mdot
.35533 .59039 Mdot
.71125 .63995 Mdot
.26659 .71194 Mdot
.5854 .49218 Mdot
.61455 .65534 Mdot
.62481 .46409 Mdot
.6096 .49946 Mdot
.62573 .44659 Mdot
.5088 .28477 Mdot
.47566 .63058 Mdot
.43491 .64521 Mdot
.58425 .74715 Mdot
.7156 .63564 Mdot
.55767 .70078 Mdot
.31298 .4437 Mdot
.53945 .78467 Mdot
.33581 .61757 Mdot
.48457 .32289 Mdot
.57563 .48873 Mdot
.48868 .61755 Mdot
.60255 .47325 Mdot
.65129 .47222 Mdot
.46962 .66431 Mdot
.41407 .62796 Mdot
.48438 .68205 Mdot
.5543 .68972 Mdot
.46344 .36211 Mdot
.55927 .49007 Mdot
.59278 .73389 Mdot
.57439 .49284 Mdot
.55974 .62683 Mdot
.46902 .36041 Mdot
.43222 .32132 Mdot
.41879 .32919 Mdot
.64261 .49936 Mdot
.65124 .45819 Mdot
.34102 .48706 Mdot
.48792 .33183 Mdot
.33565 .44227 Mdot
.49165 .63604 Mdot
.43549 .6125 Mdot
.59442 .48753 Mdot
.59337 .56305 Mdot
.55622 .69441 Mdot
.45421 .64853 Mdot
.37481 .61493 Mdot
.56316 .73896 Mdot
.6522 .48872 Mdot
.47449 .66193 Mdot
.57187 .73383 Mdot
.52855 .23859 Mdot
.6518 .20471 Mdot
.55772 .72859 Mdot
.62622 .47983 Mdot
.46682 .25112 Mdot
.71738 .6981 Mdot
.54425 .68985 Mdot
.34193 .47381 Mdot
.64154 .50218 Mdot
.73028 .50444 Mdot
.5841 .68989 Mdot
.37269 .24137 Mdot
.44935 .63341 Mdot
.32116 .52814 Mdot
.68379 .45314 Mdot
.59202 .25665 Mdot
.55532 .67927 Mdot
.44788 .34309 Mdot
.41188 .32622 Mdot
.60932 .45889 Mdot
.55946 .67378 Mdot
.30251 .44606 Mdot
.44503 .63791 Mdot
.40189 .65303 Mdot
.43442 .32681 Mdot
.2654 .3919 Mdot
.4229 .6408 Mdot
.55951 .55493 Mdot
.35456 .7392 Mdot
.66349 .39542 Mdot
.55674 .37779 Mdot
.22039 .51461 Mdot
.62958 .5121 Mdot
.55055 .71784 Mdot
.31352 .49181 Mdot
.31795 .48519 Mdot
.32805 .44912 Mdot
.38734 .64572 Mdot
.45146 .47312 Mdot
.48525 .63442 Mdot
.24523 .60766 Mdot
.56966 .72392 Mdot
.74627 .61732 Mdot
.58206 .49805 Mdot
.59741 .43814 Mdot
.63741 .51805 Mdot
.56303 .46859 Mdot
.61868 .45846 Mdot
.30963 .45416 Mdot
.39149 .6492 Mdot
.48408 .74101 Mdot
.47555 .34009 Mdot
.521 .62165 Mdot
.47722 .65042 Mdot
.33036 .62443 Mdot
.58488 .71967 Mdot
.51114 .51115 Mdot
.49203 .66537 Mdot
.46944 .65427 Mdot
.61431 .5279 Mdot
.45562 .31079 Mdot
.5489 .4108 Mdot
.63423 .47494 Mdot
.45267 .65144 Mdot
.42133 .61052 Mdot
.70783 .3209 Mdot
.5256 .47282 Mdot
.59848 .75499 Mdot
.51707 .55304 Mdot
.54396 .69404 Mdot
.66203 .43522 Mdot
.21788 .62858 Mdot
.46497 .62357 Mdot
.46134 .63907 Mdot
.56754 .73384 Mdot
.61782 .55665 Mdot
.44121 .32622 Mdot
.37457 .61898 Mdot
.3481 .47598 Mdot
.63872 .48818 Mdot
.4251 .61839 Mdot
.68446 .51984 Mdot
.45842 .77596 Mdot
.33492 .44963 Mdot
.43629 .6624 Mdot
.65863 .47745 Mdot
.62476 .4779 Mdot
.58142 .69949 Mdot
.39322 .35747 Mdot
.67845 .498 Mdot
.82939 .55604 Mdot
.22128 .45743 Mdot
.22469 .42315 Mdot
.59963 .46455 Mdot
.4312 .32829 Mdot
.34155 .62886 Mdot
.59329 .71972 Mdot
.57543 .50644 Mdot
.66359 .2136 Mdot
.41302 .35477 Mdot
.33148 .46632 Mdot
.35016 .63366 Mdot
.45271 .47039 Mdot
.64719 .49897 Mdot
.59278 .49316 Mdot
.61579 .49284 Mdot
.58836 .16195 Mdot
.42801 .63826 Mdot
.46047 .37282 Mdot
.5746 .70836 Mdot
.45123 .36911 Mdot
.43745 .63836 Mdot
.26919 .35707 Mdot
.64699 .44559 Mdot
.43635 .37201 Mdot
.4497 .34067 Mdot
.31274 .44086 Mdot
.30815 .49667 Mdot
.52013 .67178 Mdot
.57826 .47819 Mdot
.34467 .6332 Mdot
.42411 .32698 Mdot
.39978 .64257 Mdot
.58994 .71515 Mdot
.34736 .4865 Mdot
.61631 .4784 Mdot
.45651 .62365 Mdot
.54007 .44063 Mdot
.46395 .32113 Mdot
.47013 .65379 Mdot
.37789 .62741 Mdot
.55131 .70443 Mdot
.60711 .4835 Mdot
.59381 .75811 Mdot
.37705 .62308 Mdot
.60791 .44172 Mdot
.51056 .47789 Mdot
.59574 .76318 Mdot
.2514 .58783 Mdot
.4794 .62309 Mdot
.36509 .62491 Mdot
.421 .33623 Mdot
.36918 .25709 Mdot
.45648 .63947 Mdot
.50861 .49055 Mdot
.38839 .37532 Mdot
.55779 .48846 Mdot
.46421 .34095 Mdot
.32189 .67808 Mdot
.83405 .50179 Mdot
.76369 .62174 Mdot
.58572 .43927 Mdot
.47184 .61459 Mdot
.58163 .73826 Mdot
.34875 .4556 Mdot
.35415 .59101 Mdot
.71733 .43008 Mdot
.47595 .66766 Mdot
.62755 .45044 Mdot
.42746 .32291 Mdot
.31726 .47627 Mdot
.3533 .3184 Mdot
.42472 .65472 Mdot
.45218 .61694 Mdot
.65665 .46486 Mdot
.56408 .71471 Mdot
.77451 .53837 Mdot
.43558 .65214 Mdot
.42977 .61661 Mdot
.30111 .65582 Mdot
.57537 .73905 Mdot
.62257 .46829 Mdot
.52315 .37191 Mdot
.55259 .46383 Mdot
.79213 .63067 Mdot
.35816 .61392 Mdot
.47651 .33733 Mdot
.59859 .49607 Mdot
.39173 .75729 Mdot
.44825 .64798 Mdot
.49781 .51562 Mdot
.47137 .60211 Mdot
.30406 .46036 Mdot
.4319 .61526 Mdot
.59289 .47953 Mdot
.34642 .42833 Mdot
.55613 .69498 Mdot
.57254 .46754 Mdot
.64989 .45624 Mdot
.43718 .36334 Mdot
.33225 .47276 Mdot
.46694 .21059 Mdot
.3503 .48977 Mdot
.30364 .48677 Mdot
.42715 .30215 Mdot
.59937 .45267 Mdot
.46064 .64697 Mdot
.48709 .66229 Mdot
.56947 .49965 Mdot
.18518 .5686 Mdot
.43958 .32485 Mdot
.53185 .66441 Mdot
.5416 .16004 Mdot
.52082 .45166 Mdot
.3814 .6193 Mdot
.40187 .37415 Mdot
.30018 .45296 Mdot
.62134 .47949 Mdot
.46518 .30746 Mdot
.40443 .63181 Mdot
.42172 .6405 Mdot
.57345 .49603 Mdot
.31989 .47215 Mdot
.59027 .70038 Mdot
.43968 .61783 Mdot
.43115 .77606 Mdot
.62167 .49594 Mdot
.25902 .62984 Mdot
.45015 .61509 Mdot
.82374 .60524 Mdot
.47434 .7536 Mdot
.46719 .34095 Mdot
.65056 .46788 Mdot
.45247 .36689 Mdot
.57469 .70416 Mdot
.51175 .63304 Mdot
.32248 .47152 Mdot
.52935 .49035 Mdot
.30559 .24079 Mdot
.47917 .63502 Mdot
.48297 .34451 Mdot
.65616 .45995 Mdot
.52723 .51095 Mdot
.58844 .4751 Mdot
.46215 .26302 Mdot
.53206 .6724 Mdot
.35375 .45349 Mdot
.34952 .46615 Mdot
.60715 .4383 Mdot
.583 .69686 Mdot
.45495 .66455 Mdot
.44675 .63777 Mdot
.56824 .87334 Mdot
.38179 .62376 Mdot
.68944 .62163 Mdot
.60324 .48657 Mdot
.40312 .64641 Mdot
.42593 .23289 Mdot
.34517 .45879 Mdot
.56272 .47259 Mdot
.41228 .65609 Mdot
.25697 .50055 Mdot
.55245 .61873 Mdot
.61843 .46112 Mdot
.64785 .41104 Mdot
.34753 .47464 Mdot
.67156 .69401 Mdot
.48692 .64033 Mdot
.56049 .47308 Mdot
.36578 .47484 Mdot
.36692 .75808 Mdot
.31408 .25803 Mdot
.46362 .36187 Mdot
.49262 .61793 Mdot
.30928 .45417 Mdot
.68818 .47905 Mdot
.56208 .72198 Mdot
.48633 .61914 Mdot
.43681 .63001 Mdot
.6318 .44603 Mdot
.61453 .52947 Mdot
.51985 .45838 Mdot
.48175 .33748 Mdot
.36119 .47052 Mdot
.56786 .46871 Mdot
.26395 .39655 Mdot
.5758 .43459 Mdot
.35288 .47994 Mdot
.88129 .39178 Mdot
.56306 .43415 Mdot
.58927 .4728 Mdot
.77553 .55762 Mdot
.46127 .36765 Mdot
.44566 .36589 Mdot
.20841 .48065 Mdot
.60359 .48624 Mdot
.50699 .75674 Mdot
.45904 .36276 Mdot
.44366 .32214 Mdot
.41461 .71288 Mdot
.60457 .43106 Mdot
.6706 .71487 Mdot
.32021 .48431 Mdot
.31673 .48887 Mdot
.43754 .31913 Mdot
.6836 .49031 Mdot
.29888 .46915 Mdot
.6517 .28357 Mdot
.48185 .64717 Mdot
.21965 .63532 Mdot
.46787 .3208 Mdot
.4092 .43732 Mdot
.34292 .45321 Mdot
.81729 .40576 Mdot
.37131 .54268 Mdot
.58653 .43101 Mdot
.61177 .48588 Mdot
.55427 .69852 Mdot
.54398 .46132 Mdot
.35805 .61211 Mdot
.31271 .45605 Mdot
.77317 .50111 Mdot
.46927 .35692 Mdot
.58079 .47486 Mdot
.51722 .52694 Mdot
.3553 .34106 Mdot
.29595 .61542 Mdot
.44253 .33476 Mdot
.46291 .34678 Mdot
.477 .62571 Mdot
.43989 .62139 Mdot
.60642 .45405 Mdot
.31159 .47881 Mdot
.48851 .32957 Mdot
.35561 .47374 Mdot
.46149 .62228 Mdot
.46584 .65203 Mdot
.33288 .61805 Mdot
.59691 .41455 Mdot
.45265 .66253 Mdot
.41243 .77717 Mdot
.26147 .39101 Mdot
.49824 .35313 Mdot
.35524 .2061 Mdot
.35374 .31612 Mdot
.7086 .55829 Mdot
.55108 .68959 Mdot
.38551 .63119 Mdot
.35873 .44357 Mdot
.62139 .44899 Mdot
.60826 .4756 Mdot
.35108 .62168 Mdot
.34187 .43062 Mdot
.58532 .71191 Mdot
.34773 .43101 Mdot
.57146 .72782 Mdot
.3956 .63577 Mdot
.65695 .49619 Mdot
.62414 .50892 Mdot
.31352 .4518 Mdot
.46636 .65867 Mdot
.43995 .64841 Mdot
.54423 .6964 Mdot
.55419 .60253 Mdot
.45295 .62624 Mdot
.4666 .32062 Mdot
.66712 .33238 Mdot
.34652 .62912 Mdot
.58895 .48521 Mdot
.57657 .62176 Mdot
.58872 .23598 Mdot
.5558 .47505 Mdot
.36114 .6326 Mdot
.45272 .85343 Mdot
.57919 .49024 Mdot
.37976 .83035 Mdot
.36557 .62591 Mdot
.46328 .36819 Mdot
.46896 .61475 Mdot
.35058 .61066 Mdot
.68526 .44661 Mdot
.5402 .71048 Mdot
.59867 .51793 Mdot
.45451 .3651 Mdot
.41624 .34164 Mdot
.21526 .41895 Mdot
.78821 .63408 Mdot
.54573 .70097 Mdot
.58394 .72754 Mdot
.45628 .63777 Mdot
.66117 .78401 Mdot
.6553 .51245 Mdot
.58811 .724 Mdot
.76045 .51328 Mdot
.63149 .4574 Mdot
.6659 .63624 Mdot
.38684 .53339 Mdot
.43265 .3269 Mdot
.51897 .38495 Mdot
.45082 .64282 Mdot
.48137 .34959 Mdot
.25127 .38208 Mdot
.63099 .51934 Mdot
.4707 .35865 Mdot
.34935 .48147 Mdot
.24974 .53762 Mdot
.43679 .35455 Mdot
.56752 .62784 Mdot
.31538 .47917 Mdot
.338 .66898 Mdot
.75862 .55458 Mdot
.25343 .23979 Mdot
.30856 .4604 Mdot
.4809 .65748 Mdot
.48816 .65627 Mdot
.4498 .63616 Mdot
.47036 .36642 Mdot
.41018 .64346 Mdot
.48072 .32906 Mdot
.71193 .71269 Mdot
.55649 .60221 Mdot
.58533 .73195 Mdot
.28708 .42422 Mdot
.45607 .34321 Mdot
.2111 .57655 Mdot
.28812 .23577 Mdot
.62521 .48385 Mdot
.35698 .48491 Mdot
.56455 .73117 Mdot
.80528 .66958 Mdot
.55689 .69681 Mdot
.48871 .63161 Mdot
.22312 .65083 Mdot
.58336 .46625 Mdot
.73936 .38588 Mdot
.54914 .70375 Mdot
.43871 .34099 Mdot
.60394 .4399 Mdot
.37767 .64441 Mdot
.56027 .71307 Mdot
.58416 .69377 Mdot
.60936 .4494 Mdot
.43009 .34311 Mdot
.46164 .6505 Mdot
.36312 .44495 Mdot
.54144 .68768 Mdot
.69461 .44554 Mdot
.55331 .48209 Mdot
.63374 .5145 Mdot
.47279 .48432 Mdot
.74724 .49158 Mdot
.31209 .45883 Mdot
.7313 .66145 Mdot
.43683 .62364 Mdot
.3509 .69589 Mdot
.21678 .48041 Mdot
.35901 .40749 Mdot
.36108 .615 Mdot
.34681 .61271 Mdot
.61529 .45752 Mdot
.74817 .49355 Mdot
.29769 .72447 Mdot
.25787 .45892 Mdot
.34416 .6276 Mdot
.44305 .64119 Mdot
.41094 .33125 Mdot
.21356 .39534 Mdot
.55053 .4817 Mdot
.29537 .45896 Mdot
.44938 .62463 Mdot
.76275 .37963 Mdot
.56886 .71734 Mdot
.21343 .60845 Mdot
.65401 .4581 Mdot
.57064 .45414 Mdot
.31911 .45886 Mdot
.33564 .48856 Mdot
.31045 .59378 Mdot
.21502 .43664 Mdot
.63662 .70022 Mdot
.38548 .26366 Mdot
.75388 .37004 Mdot
.40835 .32387 Mdot
.45424 .30435 Mdot
.35248 .63679 Mdot
.34141 .492 Mdot
.59365 .49675 Mdot
.48626 .32487 Mdot
.29336 .61919 Mdot
.50994 .36441 Mdot
.67863 .63539 Mdot
.48569 .76566 Mdot
.65151 .48314 Mdot
.44963 .31052 Mdot
.47759 .35646 Mdot
.49308 .34329 Mdot
.36557 .6309 Mdot
.59644 .4606 Mdot
.60277 .42724 Mdot
.56637 .45656 Mdot
.67838 .41738 Mdot
.62596 .49477 Mdot
.26199 .42078 Mdot
.48936 .53885 Mdot
.78358 .49495 Mdot
.55729 .46044 Mdot
.31212 .48557 Mdot
.62399 .51846 Mdot
.58519 .69846 Mdot
.62493 .4479 Mdot
.6794 .62821 Mdot
.33481 .45767 Mdot
.59355 .55494 Mdot
.38219 .26303 Mdot
.6506 .4512 Mdot
.59971 .72188 Mdot
.73404 .51847 Mdot
.46175 .21724 Mdot
.51734 .60873 Mdot
.46504 .31971 Mdot
.47776 .6715 Mdot
.33563 .43458 Mdot
.46303 .64563 Mdot
.56348 .4455 Mdot
.34935 .63534 Mdot
.33857 .3926 Mdot
.41054 .44144 Mdot
.6024 .5029 Mdot
.61243 .54034 Mdot
.45434 .31838 Mdot
.47561 .66124 Mdot
.42346 .28879 Mdot
.60766 .49421 Mdot
.57113 .70672 Mdot
.56317 .71871 Mdot
.23588 .42364 Mdot
.77278 .35828 Mdot
.35766 .25686 Mdot
.31743 .45842 Mdot
.4309 .64955 Mdot
.55799 .67818 Mdot
.71109 .46428 Mdot
.29235 .4731 Mdot
.30499 .44699 Mdot
.32702 .47666 Mdot
.64321 .48958 Mdot
.35738 .61264 Mdot
.76961 .46896 Mdot
.36327 .61325 Mdot
.64764 .44846 Mdot
.43063 .63328 Mdot
.33407 .61452 Mdot
.55419 .70456 Mdot
.3294 .43994 Mdot
.4603 .62031 Mdot
.63386 .48901 Mdot
.45271 .35805 Mdot
.54613 .59164 Mdot
.63879 .60025 Mdot
.79774 .59123 Mdot
.80479 .57283 Mdot
.42383 .31656 Mdot
.80451 .40586 Mdot
.37505 .43611 Mdot
.56032 .2338 Mdot
.5008 .69542 Mdot
.56799 .49506 Mdot
.17384 .50632 Mdot
.48738 .63874 Mdot
.47421 .66332 Mdot
.62521 .46828 Mdot
.40379 .63532 Mdot
.5833 .47491 Mdot
.45114 .61859 Mdot
.51941 .62203 Mdot
.54942 .48256 Mdot
.46001 .66287 Mdot
.68021 .46158 Mdot
.6201 .43212 Mdot
.43223 .32413 Mdot
.47291 .61277 Mdot
.57014 .43801 Mdot
.73295 .75103 Mdot
.34282 .48781 Mdot
.36303 .6314 Mdot
.58474 .66082 Mdot
.31031 .4518 Mdot
.4721 .34998 Mdot
.55517 .43788 Mdot
.5664 .69186 Mdot
.44853 .34671 Mdot
.52832 .66796 Mdot
.55017 .7096 Mdot
.19113 .53506 Mdot
.45979 .31632 Mdot
.34746 .62746 Mdot
.55309 .69578 Mdot
.59778 .53991 Mdot
.47451 .61051 Mdot
.61419 .58753 Mdot
.37102 .61905 Mdot
.59828 .47015 Mdot
.40149 .65691 Mdot
.34517 .48833 Mdot
.58258 .44432 Mdot
.44652 .61248 Mdot
.37161 .62847 Mdot
.64408 .48262 Mdot
.62189 .4538 Mdot
.23661 .35054 Mdot
.26964 .66133 Mdot
.58542 .70506 Mdot
.42579 .36125 Mdot
.62891 .48154 Mdot
.55618 .68835 Mdot
.47956 .80616 Mdot
.63226 .51209 Mdot
.47474 .36871 Mdot
.55077 .4009 Mdot
.42994 .62558 Mdot
.33379 .44168 Mdot
.49641 .62762 Mdot
.57533 .68781 Mdot
.17203 .63978 Mdot
.33007 .61897 Mdot
.66816 .44125 Mdot
.57333 .48913 Mdot
.3297 .64444 Mdot
.48037 .34956 Mdot
.63738 .69599 Mdot
.60757 .48367 Mdot
.69507 .4203 Mdot
.57412 .46455 Mdot
.48159 .74885 Mdot
.4412 .32492 Mdot
.5927 .47315 Mdot
.56738 .56119 Mdot
.66501 .46468 Mdot
.59324 .70335 Mdot
.76599 .59359 Mdot
.61626 .51518 Mdot
.6898 .17338 Mdot
.37808 .61844 Mdot
.45666 .66318 Mdot
.36753 .64696 Mdot
.57857 .82163 Mdot
.3485 .25338 Mdot
.48191 .33083 Mdot
.43833 .4076 Mdot
.46212 .6482 Mdot
.38736 .23633 Mdot
.81738 .43262 Mdot
.62426 .43376 Mdot
.64789 .49685 Mdot
.4887 .63157 Mdot
.39888 .64299 Mdot
.33909 .6325 Mdot
.56356 .44204 Mdot
.56648 .53546 Mdot
.4314 .65729 Mdot
.63196 .49829 Mdot
.54678 .40938 Mdot
.36398 .44861 Mdot
.42451 .33728 Mdot
.34803 .45212 Mdot
.32757 .43675 Mdot
.60406 .28538 Mdot
.22465 .45286 Mdot
.3532 .48019 Mdot
.34904 .42636 Mdot
.66699 .62856 Mdot
.52092 .40772 Mdot
.57424 .68427 Mdot
.80221 .46575 Mdot
.45522 .63351 Mdot
.5954 .45894 Mdot
.43683 .30429 Mdot
.58364 .26237 Mdot
.37762 .55755 Mdot
.25135 .69044 Mdot
.60408 .4964 Mdot
.44708 .64409 Mdot
.37379 .62545 Mdot
.55126 .48831 Mdot
.36557 .70084 Mdot
.57442 .44537 Mdot
.48849 .61742 Mdot
.68536 .35714 Mdot
.52496 .53057 Mdot
.31451 .67821 Mdot
.47247 .29147 Mdot
.57511 .48205 Mdot
.47348 .32541 Mdot
.33755 .44828 Mdot
.57315 .68992 Mdot
.58289 .70276 Mdot
.61034 .44487 Mdot
.71152 .4269 Mdot
.39206 .52624 Mdot
.62458 .43252 Mdot
.6254 .44144 Mdot
.36568 .62497 Mdot
.62329 .43977 Mdot
.57141 .48643 Mdot
.56384 .46407 Mdot
.66017 .44528 Mdot
.30457 .48687 Mdot
.52598 .53544 Mdot
.60128 .41302 Mdot
.54189 .42051 Mdot
.3689 .45183 Mdot
.41238 .39499 Mdot
.33992 .43852 Mdot
.76666 .32375 Mdot
.35231 .46207 Mdot
.58915 .71591 Mdot
.43381 .67493 Mdot
.57927 .38383 Mdot
.48568 .31515 Mdot
.30343 .49127 Mdot
.57943 .71643 Mdot
.32048 .45106 Mdot
.4255 .63807 Mdot
.47003 .17219 Mdot
.50966 .36369 Mdot
.6204 .66928 Mdot
.27825 .50296 Mdot
.26419 .62814 Mdot
.48171 .63466 Mdot
.43798 .32309 Mdot
.71604 .32683 Mdot
.56953 .44282 Mdot
.55178 .69899 Mdot
.61058 .45318 Mdot
.30155 .48543 Mdot
.44926 .63993 Mdot
.76289 .63684 Mdot
.57592 .69557 Mdot
.26596 .29593 Mdot
.44478 .63524 Mdot
.58768 .42457 Mdot
.29513 .46078 Mdot
.34656 .20856 Mdot
.35163 .45303 Mdot
.55978 .60576 Mdot
.46547 .37606 Mdot
.53627 .36348 Mdot
.46088 .34017 Mdot
.31647 .60236 Mdot
.59317 .15442 Mdot
.82485 .53062 Mdot
.44445 .35339 Mdot
.33198 .71121 Mdot
.64794 .49244 Mdot
.63028 .51648 Mdot
.54312 .54164 Mdot
.46043 .37355 Mdot
.6276 .48813 Mdot
.37061 .62276 Mdot
.27461 .36422 Mdot
.38363 .7312 Mdot
.47623 .67122 Mdot
.58811 .4797 Mdot
.36857 .45543 Mdot
.34419 .42979 Mdot
.34327 .61101 Mdot
.34763 .4403 Mdot
.59931 .42809 Mdot
.45777 .3417 Mdot
.40023 .44417 Mdot
.56538 .69861 Mdot
.75285 .70647 Mdot
.57381 .68022 Mdot
.38758 .63434 Mdot
.55911 .52329 Mdot
.46626 .65256 Mdot
.2973 .80152 Mdot
.58753 .43242 Mdot
.4627 .36393 Mdot
.63215 .46521 Mdot
.57113 .47364 Mdot
.63499 .5158 Mdot
.4222 .65072 Mdot
.61972 .74123 Mdot
.63304 .49635 Mdot
.32355 .47219 Mdot
.80157 .51909 Mdot
.62082 .5205 Mdot
.51595 .6188 Mdot
.72353 .61954 Mdot
.24129 .60089 Mdot
.49203 .32012 Mdot
.47245 .6612 Mdot
.46573 .35525 Mdot
.46186 .2926 Mdot
.47232 .34991 Mdot
.77463 .45924 Mdot
.71154 .33688 Mdot
.44594 .84752 Mdot
.57943 .3687 Mdot
.55046 .25234 Mdot
.42252 .36148 Mdot
.4699 .82001 Mdot
.46896 .30668 Mdot
.47969 .34057 Mdot
.87383 .62086 Mdot
.46886 .30403 Mdot
.59566 .48439 Mdot
.59318 .52385 Mdot
.33521 .35887 Mdot
.64769 .63824 Mdot
.61441 .43858 Mdot
.62845 .47566 Mdot
.56409 .68857 Mdot
.72922 .45631 Mdot
.3382 .63438 Mdot
.19064 .52937 Mdot
.3713 .32463 Mdot
.61129 .45143 Mdot
.63106 .48255 Mdot
.63294 .53062 Mdot
.52029 .12269 Mdot
.61657 .27318 Mdot
.41476 .35186 Mdot
.65012 .53104 Mdot
.79897 .64095 Mdot
.61471 .42566 Mdot
.63295 .50775 Mdot
.65 .47894 Mdot
.46098 .64747 Mdot
.41158 .35295 Mdot
.6475 .53196 Mdot
.22106 .56142 Mdot
.65702 .4727 Mdot
.33395 .40618 Mdot
.62939 .75506 Mdot
.59404 .47949 Mdot
.49337 .36077 Mdot
.63855 .46039 Mdot
.46158 .31499 Mdot
.42907 .32464 Mdot
.62864 .53151 Mdot
.77674 .42094 Mdot
.4771 .37028 Mdot
.65101 .45558 Mdot
.45952 .65783 Mdot
.83217 .51622 Mdot
.59944 .47242 Mdot
.59389 .7284 Mdot
.60932 .48527 Mdot
.59908 .72971 Mdot
.6313 .44074 Mdot
.36821 .61583 Mdot
.57606 .2194 Mdot
.46133 .63775 Mdot
.65039 .7532 Mdot
.41017 .65052 Mdot
.23523 .35294 Mdot
.47512 .367 Mdot
.37631 .63054 Mdot
.22339 .67702 Mdot
.36217 .62746 Mdot
.52234 .54731 Mdot
.50031 .56863 Mdot
.30851 .47672 Mdot
.43864 .36164 Mdot
.71572 .67436 Mdot
.31031 .63582 Mdot
.44771 .68621 Mdot
.44252 .67188 Mdot
.17185 .61665 Mdot
.19436 .62014 Mdot
.63698 .49081 Mdot
.74633 .40592 Mdot
.55609 .3311 Mdot
.63279 .51051 Mdot
.56631 .42575 Mdot
.46878 .60762 Mdot
.58048 .49574 Mdot
.46861 .46266 Mdot
.47631 .63373 Mdot
.57979 .72217 Mdot
.47697 .33475 Mdot
.59514 .7371 Mdot
.3764 .65586 Mdot
.51239 .57015 Mdot
.44901 .62124 Mdot
.66572 .45481 Mdot
.6326 .46935 Mdot
.44059 .31557 Mdot
.41752 .28527 Mdot
.42546 .33242 Mdot
.56024 .72833 Mdot
.46966 .63117 Mdot
.6053 .26161 Mdot
.62041 .47285 Mdot
.45086 .33845 Mdot
.34379 .515 Mdot
.62446 .47858 Mdot
.32331 .44681 Mdot
.65285 .4896 Mdot
.44425 .35563 Mdot
.62338 .4396 Mdot
.4588 .34336 Mdot
.4841 .65099 Mdot
.6242 .42723 Mdot
.62181 .46548 Mdot
.33838 .21959 Mdot
.58382 .70894 Mdot
.47326 .36754 Mdot
.43352 .51766 Mdot
.58215 .42619 Mdot
.32554 .65507 Mdot
.58568 .49142 Mdot
.49059 .40552 Mdot
.67626 .45477 Mdot
.36794 .62653 Mdot
.5435 .43204 Mdot
.59835 .4722 Mdot
.58385 .57181 Mdot
.60158 .35665 Mdot
.41614 .29356 Mdot
.29665 .46889 Mdot
.4893 .36773 Mdot
.44013 .61075 Mdot
.39344 .64135 Mdot
.41982 .62696 Mdot
.63384 .65245 Mdot
.62877 .53075 Mdot
.58485 .4653 Mdot
.32523 .50265 Mdot
.58013 .72807 Mdot
.44355 .33643 Mdot
.57521 .7272 Mdot
.19949 .50008 Mdot
.55708 .72344 Mdot
.35268 .61109 Mdot
.47253 .7551 Mdot
.62264 .25449 Mdot
.56219 .68889 Mdot
.42491 .33457 Mdot
.47626 .768 Mdot
.56548 .49056 Mdot
.53959 .66328 Mdot
.56976 .70723 Mdot
.15567 .59452 Mdot
.59313 .50097 Mdot
.51141 .53486 Mdot
.35995 .45921 Mdot
.55919 .71758 Mdot
.33602 .47028 Mdot
.61345 .44073 Mdot
.25848 .59718 Mdot
.48407 .34117 Mdot
.37255 .44565 Mdot
.58616 .41238 Mdot
.57462 .73478 Mdot
.44483 .62649 Mdot
.27066 .46232 Mdot
.31127 .48424 Mdot
.56201 .19994 Mdot
.76203 .62401 Mdot
.47183 .63214 Mdot
.3021 .71562 Mdot
.33461 .47874 Mdot
.62798 .51206 Mdot
.6527 .39591 Mdot
.58886 .4293 Mdot
.38597 .64861 Mdot
.47136 .66216 Mdot
.29624 .36643 Mdot
.63514 .47033 Mdot
.58949 .49725 Mdot
.46268 .38429 Mdot
.48069 .64269 Mdot
.46054 .32736 Mdot
.493 .33651 Mdot
.48549 .65288 Mdot
.46608 .33869 Mdot
.55031 .70465 Mdot
.28694 .34012 Mdot
.33538 .47938 Mdot
.32551 .4684 Mdot
.44406 .64025 Mdot
.44399 .66276 Mdot
.46914 .65289 Mdot
.65309 .48917 Mdot
.44051 .33124 Mdot
.64764 .46201 Mdot
.64158 .50885 Mdot
.47575 .28984 Mdot
.46597 .30114 Mdot
.64528 .46965 Mdot
.3196 .67368 Mdot
.53827 .71431 Mdot
.4515 .66033 Mdot
.35819 .47094 Mdot
.41428 .23728 Mdot
.34286 .50206 Mdot
.58633 .48096 Mdot
.27135 .51681 Mdot
.4389 .34946 Mdot
.55518 .69833 Mdot
.57896 .75867 Mdot
.56274 .69395 Mdot
.29316 .49002 Mdot
.4898 .34214 Mdot
.19242 .53205 Mdot
.58566 .47645 Mdot
.47047 .48125 Mdot
.72498 .66514 Mdot
.21034 .5068 Mdot
.35489 .47827 Mdot
.62732 .47905 Mdot
.3572 .6292 Mdot
.68962 .29834 Mdot
.57294 .44995 Mdot
.56208 .4573 Mdot
.47789 .71763 Mdot
.53753 .42394 Mdot
.46889 .37436 Mdot
.20972 .42701 Mdot
.5995 .5248 Mdot
.51016 .32928 Mdot
.61833 .83793 Mdot
.58183 .48307 Mdot
.61381 .49563 Mdot
.60765 .46859 Mdot
.63111 .45882 Mdot
.48747 .37292 Mdot
.67459 .68278 Mdot
.29456 .46297 Mdot
.47831 .50706 Mdot
.33119 .48284 Mdot
.48809 .6187 Mdot
.49932 .50482 Mdot
.42775 .35071 Mdot
.55474 .69693 Mdot
.62801 .22574 Mdot
.20653 .4606 Mdot
.47894 .62763 Mdot
.66248 .30631 Mdot
.56995 .70157 Mdot
.56815 .49723 Mdot
.59184 .74516 Mdot
.40012 .64522 Mdot
.3187 .47743 Mdot
.58147 .51733 Mdot
.43637 .30874 Mdot
.43886 .35697 Mdot
.62585 .48517 Mdot
.80602 .61724 Mdot
.32557 .44497 Mdot
.37476 .47954 Mdot
.64547 .48893 Mdot
.56218 .4558 Mdot
.46567 .32865 Mdot
.44827 .65446 Mdot
.38486 .77921 Mdot
.58386 .71552 Mdot
.61768 .42048 Mdot
.62978 .45503 Mdot
.22095 .45014 Mdot
.31604 .44261 Mdot
.33696 .62294 Mdot
.64263 .48714 Mdot
.23764 .43773 Mdot
.64296 .48535 Mdot
.54314 .47312 Mdot
.46108 .65437 Mdot
.67638 .48497 Mdot
.62868 .50547 Mdot
.6636 .5262 Mdot
.33585 .47548 Mdot
.47001 .36093 Mdot
.4781 .38168 Mdot
.34817 .63377 Mdot
.32463 .44708 Mdot
.64288 .46636 Mdot
.31539 .44465 Mdot
.6259 .51606 Mdot
.63046 .49544 Mdot
.35345 .47921 Mdot
.46096 .32785 Mdot
.38413 .39681 Mdot
.52007 .53134 Mdot
.63323 .46285 Mdot
.55547 .48936 Mdot
.64301 .65019 Mdot
.29916 .76804 Mdot
.60034 .49508 Mdot
.4426 .35675 Mdot
.62274 .4713 Mdot
.33935 .46218 Mdot
.55923 .72468 Mdot
.44918 .35748 Mdot
.437 .6487 Mdot
.48845 .644 Mdot
.38101 .26206 Mdot
.34056 .6122 Mdot
.55203 .47566 Mdot
.47871 .39742 Mdot
.44356 .30085 Mdot
.68467 .78636 Mdot
.48671 .65741 Mdot
.58809 .69487 Mdot
.61906 .44982 Mdot
.28196 .51591 Mdot
.32017 .50181 Mdot
.68207 .16548 Mdot
.19303 .5358 Mdot
.57776 .6809 Mdot
.24369 .68764 Mdot
.35134 .62613 Mdot
.6146 .50753 Mdot
.57688 .69152 Mdot
.47523 .62052 Mdot
.58787 .50771 Mdot
.64014 .40744 Mdot
.62647 .6855 Mdot
.50509 .62523 Mdot
.3221 .44228 Mdot
.42382 .62684 Mdot
.57191 .74651 Mdot
.35492 .61141 Mdot
.43065 .35042 Mdot
.5948 .4698 Mdot
.63875 .53088 Mdot
.44177 .65304 Mdot
.36812 .61534 Mdot
.65235 .48129 Mdot
.44724 .36477 Mdot
.4117 .62994 Mdot
.60641 .44589 Mdot
.56066 .23947 Mdot
.45928 .28821 Mdot
.45937 .62821 Mdot
.5719 .48495 Mdot
.52531 .39802 Mdot
.43976 .64315 Mdot
.44577 .65996 Mdot
.62809 .4878 Mdot
.55033 .69889 Mdot
.65887 .47963 Mdot
.35441 .46382 Mdot
.62137 .74131 Mdot
.33661 .46335 Mdot
.53431 .72421 Mdot
.5418 .49598 Mdot
.27488 .62658 Mdot
.42109 .33343 Mdot
.57096 .74778 Mdot
.43114 .21898 Mdot
.55954 .46173 Mdot
.79569 .40122 Mdot
.41619 .4388 Mdot
.78903 .67933 Mdot
.60529 .17968 Mdot
.56983 .71132 Mdot
.32692 .44897 Mdot
.61405 .49495 Mdot
.3544 .48917 Mdot
.58269 .69862 Mdot
.73159 .66929 Mdot
.56944 .48256 Mdot
.44332 .32314 Mdot
.65641 .47526 Mdot
.46542 .31957 Mdot
.62292 .47977 Mdot
.53799 .42473 Mdot
.48512 .68586 Mdot
.56475 .61242 Mdot
.56596 .4929 Mdot
.46729 .17062 Mdot
.39675 .54375 Mdot
.57581 .70756 Mdot
.64961 .45868 Mdot
.35097 .61693 Mdot
.33247 .43011 Mdot
.71625 .52359 Mdot
.46341 .65013 Mdot
.36293 .46956 Mdot
.47115 .33762 Mdot
.48445 .66285 Mdot
.37712 .62483 Mdot
.68229 .49789 Mdot
.59837 .7203 Mdot
.3062 .47214 Mdot
.59682 .47536 Mdot
.59327 .50035 Mdot
.35416 .73237 Mdot
.37167 .5748 Mdot
.41969 .3686 Mdot
.28856 .26181 Mdot
.49832 .3596 Mdot
.58752 .72089 Mdot
.46349 .65427 Mdot
.59701 .49372 Mdot
.58581 .44098 Mdot
.39047 .64158 Mdot
.47349 .36653 Mdot
.49856 .62304 Mdot
.62803 .29289 Mdot
.45684 .66922 Mdot
.69256 .65594 Mdot
.45731 .36412 Mdot
.68874 .65882 Mdot
.57384 .74781 Mdot
.76807 .37011 Mdot
.67933 .59454 Mdot
.35995 .45788 Mdot
.69701 .65428 Mdot
.43936 .34264 Mdot
.6368 .48144 Mdot
.34739 .62506 Mdot
.33576 .61566 Mdot
.47304 .3317 Mdot
.48777 .62772 Mdot
.56017 .71748 Mdot
.61704 .49755 Mdot
.23038 .6112 Mdot
.33896 .31999 Mdot
.43176 .6518 Mdot
.55842 .40804 Mdot
.33073 .47279 Mdot
.62176 .50492 Mdot
.59276 .73298 Mdot
.3087 .46847 Mdot
.35072 .60381 Mdot
.28383 .35896 Mdot
.61021 .44224 Mdot
.22285 .42774 Mdot
.31424 .45205 Mdot
.31124 .73881 Mdot
.60353 .45087 Mdot
.33464 .47855 Mdot
.5293 .45625 Mdot
.21886 .52211 Mdot
.42792 .48234 Mdot
.82248 .44849 Mdot
.50985 .63402 Mdot
.48798 .63436 Mdot
.25589 .55417 Mdot
.43788 .69254 Mdot
.36523 .46855 Mdot
.35689 .61174 Mdot
.74332 .56654 Mdot
.33498 .47243 Mdot
.64682 .50049 Mdot
.58469 .48887 Mdot
.5979 .27951 Mdot
.44391 .47904 Mdot
.36218 .61203 Mdot
.32692 .27428 Mdot
.57954 .42917 Mdot
.64351 .41891 Mdot
.58621 .44562 Mdot
.41589 .3433 Mdot
.30481 .45725 Mdot
.37729 .19812 Mdot
.33401 .44498 Mdot
.23119 .62962 Mdot
.45481 .63411 Mdot
.44256 .66397 Mdot
.59175 .48091 Mdot
.28308 .64626 Mdot
.74813 .48006 Mdot
.60749 .4274 Mdot
.33028 .6672 Mdot
.76712 .61477 Mdot
.59599 .40921 Mdot
.46206 .37736 Mdot
.58687 .52736 Mdot
.42466 .2971 Mdot
.31848 .48494 Mdot
.56572 .71405 Mdot
.53796 .69403 Mdot
.30814 .47351 Mdot
.58509 .46323 Mdot
.34895 .67078 Mdot
.57159 .46068 Mdot
.63943 .48864 Mdot
.20869 .60705 Mdot
.56127 .67766 Mdot
.47338 .65288 Mdot
.58015 .69949 Mdot
.48019 .34116 Mdot
.91499 .4521 Mdot
.57612 .72998 Mdot
.6425 .38412 Mdot
.67592 .72111 Mdot
.69459 .6576 Mdot
.43911 .3584 Mdot
.55239 .7243 Mdot
.3326 .44235 Mdot
.81501 .65387 Mdot
.32268 .78143 Mdot
.36421 .48609 Mdot
.59921 .44586 Mdot
.42314 .34584 Mdot
.42401 .31916 Mdot
.37443 .44378 Mdot
.43015 .33196 Mdot
.57341 .53858 Mdot
.63888 .47441 Mdot
.36421 .47032 Mdot
.33689 .3449 Mdot
.30896 .48278 Mdot
.27168 .34999 Mdot
.65306 .46604 Mdot
.45483 .36198 Mdot
.5895 .53223 Mdot
.50607 .37362 Mdot
.33298 .62454 Mdot
.59116 .5104 Mdot
.55582 .7088 Mdot
.45537 .46837 Mdot
.45995 .62994 Mdot
.27748 .5222 Mdot
.44337 .31536 Mdot
.38989 .44868 Mdot
.43133 .32479 Mdot
.42504 .35365 Mdot
.32851 .43624 Mdot
.48343 .32511 Mdot
.61418 .49654 Mdot
.32606 .69619 Mdot
.46327 .31287 Mdot
.32583 .45744 Mdot
.55999 .70509 Mdot
.46419 .33472 Mdot
.4754 .60748 Mdot
.62213 .45873 Mdot
.44353 .62049 Mdot
.49022 .68528 Mdot
.44381 .36533 Mdot
.55088 .72083 Mdot
.46662 .66418 Mdot
.5942 .70904 Mdot
.75395 .6608 Mdot
.33536 .49408 Mdot
.25687 .69395 Mdot
.52024 .42304 Mdot
.43701 .30759 Mdot
.49162 .68294 Mdot
.59782 .492 Mdot
.62278 .45739 Mdot
.55789 .73515 Mdot
.4245 .31763 Mdot
.82876 .5416 Mdot
.46727 .40534 Mdot
.29008 .34468 Mdot
.31796 .49518 Mdot
.30231 .26563 Mdot
.26606 .39299 Mdot
.65996 .77381 Mdot
.68501 .46739 Mdot
.35093 .62571 Mdot
.57881 .46996 Mdot
.44276 .21345 Mdot
.5682 .73327 Mdot
.40422 .80598 Mdot
.64889 .51665 Mdot
.4736 .64675 Mdot
.60908 .46091 Mdot
.65079 .56586 Mdot
.57435 .52227 Mdot
.55046 .69285 Mdot
.30268 .41336 Mdot
.48625 .31728 Mdot
.5671 .69929 Mdot
.4871 .64392 Mdot
.7464 .59279 Mdot
.58402 .50515 Mdot
.57058 .43102 Mdot
.449 .66898 Mdot
.43872 .32432 Mdot
.48159 .61408 Mdot
.33495 .47957 Mdot
.57032 .72244 Mdot
.62316 .45144 Mdot
.67121 .4551 Mdot
.3349 .65736 Mdot
.30336 .45857 Mdot
.45926 .66719 Mdot
.34747 .44989 Mdot
.34974 .62589 Mdot
.56862 .50325 Mdot
.43514 .66197 Mdot
.60005 .50649 Mdot
.3931 .21526 Mdot
.21524 .61805 Mdot
.62578 .35594 Mdot
.47745 .65118 Mdot
.69913 .6346 Mdot
.33736 .45697 Mdot
.35156 .4589 Mdot
.52604 .34248 Mdot
.73902 .50995 Mdot
.50048 .7599 Mdot
.57563 .19935 Mdot
.33528 .47999 Mdot
.33246 .46411 Mdot
.46562 .61535 Mdot
.48025 .32236 Mdot
.42041 .30617 Mdot
.49429 .65383 Mdot
.57772 .6248 Mdot
.44372 .33648 Mdot
.79848 .41587 Mdot
.44471 .60894 Mdot
.68577 .4594 Mdot
.34054 .63949 Mdot
.56394 .71772 Mdot
.57292 .6202 Mdot
.64917 .56456 Mdot
.59829 .49843 Mdot
.20941 .41355 Mdot
.45049 .65184 Mdot
.65535 .69195 Mdot
.76176 .31829 Mdot
.56644 .47827 Mdot
.59757 .4568 Mdot
.58292 .45852 Mdot
.55374 .67648 Mdot
.45687 .22708 Mdot
.60009 .50075 Mdot
.57602 .62883 Mdot
.58835 .42175 Mdot
.64775 .58823 Mdot
.58298 .70252 Mdot
.46917 .26917 Mdot
.50897 .64669 Mdot
.20843 .54178 Mdot
.5389 .53581 Mdot
.34322 .47067 Mdot
.48467 .68032 Mdot
.32296 .48347 Mdot
.76507 .44709 Mdot
.68093 .59634 Mdot
.43332 .37331 Mdot
.60532 .4979 Mdot
.43023 .6678 Mdot
.42331 .33113 Mdot
.30356 .63781 Mdot
.89543 .57893 Mdot
.30009 .46118 Mdot
.31908 .80867 Mdot
.35145 .45582 Mdot
.33238 .62116 Mdot
.46772 .32968 Mdot
.70497 .3409 Mdot
.47021 .47945 Mdot
.46398 .337 Mdot
.35395 .39257 Mdot
.50162 .35189 Mdot
.70177 .64114 Mdot
.48343 .30508 Mdot
.33015 .45595 Mdot
.28243 .48706 Mdot
.6662 .43178 Mdot
.60019 .48684 Mdot
.51771 .5722 Mdot
.55794 .38548 Mdot
.60069 .48971 Mdot
.47646 .63409 Mdot
.29599 .73444 Mdot
.48907 .67564 Mdot
.46183 .30728 Mdot
.2976 .45935 Mdot
.60003 .45735 Mdot
.63996 .47117 Mdot
.60744 .51153 Mdot
.32203 .22436 Mdot
.79819 .42776 Mdot
.6333 .4945 Mdot
.63153 .42552 Mdot
.48287 .65076 Mdot
.6035 .75595 Mdot
.50832 .18139 Mdot
.72863 .57269 Mdot
.57661 .4394 Mdot
.58057 .70283 Mdot
.57732 .68348 Mdot
.5784 .50298 Mdot
.23726 .60529 Mdot
.32244 .6983 Mdot
.59722 .47517 Mdot
.68256 .57947 Mdot
.39087 .66283 Mdot
.34365 .61069 Mdot
.44133 .65121 Mdot
.49438 .35449 Mdot
.36301 .61586 Mdot
.40605 .64549 Mdot
.69742 .32588 Mdot
.35146 .63461 Mdot
.25152 .44058 Mdot
.56038 .7285 Mdot
.58157 .44486 Mdot
.49718 .36831 Mdot
.38866 .64478 Mdot
.30924 .47661 Mdot
.45597 .35234 Mdot
.33452 .42929 Mdot
.60023 .70306 Mdot
.63148 .67296 Mdot
.33287 .61627 Mdot
.34231 .4755 Mdot
.28238 .35957 Mdot
.58131 .70275 Mdot
.34721 .44138 Mdot
.28733 .63652 Mdot
.62132 .52249 Mdot
.74388 .35738 Mdot
.62943 .43258 Mdot
.80901 .63453 Mdot
.34232 .44065 Mdot
.36588 .63295 Mdot
.58756 .4677 Mdot
.44427 .63608 Mdot
.53508 .47775 Mdot
.57571 .44296 Mdot
.4333 .64407 Mdot
.63699 .48916 Mdot
.59527 .72737 Mdot
.44673 .28764 Mdot
.39944 .42227 Mdot
.15625 .43748 Mdot
.59733 .7202 Mdot
.30156 .63797 Mdot
.60154 .49566 Mdot
.76337 .63304 Mdot
.46243 .33445 Mdot
.56237 .47202 Mdot
.49438 .28394 Mdot
.47547 .3214 Mdot
.46433 .35284 Mdot
.63404 .4483 Mdot
.35619 .45291 Mdot
.44808 .63157 Mdot
.57773 .69903 Mdot
.6939 .76549 Mdot
.59662 .43957 Mdot
.62223 .46809 Mdot
.56863 .70079 Mdot
.33472 .46395 Mdot
.63896 .4677 Mdot
.3238 .54862 Mdot
.75029 .73105 Mdot
.30902 .44184 Mdot
.63519 .51921 Mdot
.69121 .27454 Mdot
.50048 .3812 Mdot
.3098 .79023 Mdot
.54149 .72946 Mdot
.46993 .66074 Mdot
.53673 .42651 Mdot
.77157 .25431 Mdot
.56412 .7133 Mdot
.20102 .5377 Mdot
.6383 .4963 Mdot
.61534 .47184 Mdot
.4324 .34332 Mdot
.64611 .46472 Mdot
.47972 .35763 Mdot
.14694 .49423 Mdot
.22499 .32927 Mdot
.44676 .31751 Mdot
.4545 .30366 Mdot
.52683 .36909 Mdot
.49284 .18727 Mdot
.47514 .33798 Mdot
.64293 .51531 Mdot
.81114 .50479 Mdot
.68962 .48229 Mdot
.55509 .7324 Mdot
.49355 .68652 Mdot
.44894 .2637 Mdot
.41476 .60258 Mdot
.4214 .39543 Mdot
.55767 .5467 Mdot
.37477 .53509 Mdot
.35375 .46995 Mdot
.56759 .45002 Mdot
.3375 .61311 Mdot
.41134 .6341 Mdot
.56495 .51448 Mdot
.57635 .44879 Mdot
.46435 .31671 Mdot
.55044 .68112 Mdot
.33917 .43313 Mdot
.62831 .47494 Mdot
.49296 .61141 Mdot
.58257 .721 Mdot
.45914 .30859 Mdot
.53449 .36773 Mdot
.56736 .68346 Mdot
.54025 .43602 Mdot
.6108 .48282 Mdot
.65138 .48264 Mdot
.52081 .45495 Mdot
.33093 .49022 Mdot
.37872 .65081 Mdot
.65322 .50214 Mdot
.2015 .4958 Mdot
.54335 .60366 Mdot
.67493 .47524 Mdot
.43757 .33668 Mdot
.31464 .50014 Mdot
.33656 .6271 Mdot
.74739 .61639 Mdot
.60433 .43953 Mdot
.79697 .43119 Mdot
.61936 .27911 Mdot
.36283 .61698 Mdot
.42878 .36633 Mdot
.55631 .69636 Mdot
.59769 .42889 Mdot
.79282 .48461 Mdot
.5851 .48697 Mdot
.52555 .40734 Mdot
.45576 .65803 Mdot
.353 .47319 Mdot
.77896 .69768 Mdot
.41064 .63615 Mdot
.46531 .35461 Mdot
.82803 .4448 Mdot
.42066 .31404 Mdot
.48701 .32298 Mdot
.77456 .43051 Mdot
.33308 .48833 Mdot
.75263 .23376 Mdot
.31585 .78214 Mdot
.66481 .48169 Mdot
.3424 .45809 Mdot
.46388 .32272 Mdot
.62165 .50446 Mdot
.44984 .30124 Mdot
.48701 .34115 Mdot
.59891 .51441 Mdot
.61361 .47862 Mdot
.51791 .53123 Mdot
.78475 .36621 Mdot
.56181 .69274 Mdot
.46083 .36791 Mdot
.54842 .2607 Mdot
.60462 .50364 Mdot
.58617 .47625 Mdot
.32033 .64483 Mdot
.55177 .69198 Mdot
.61175 .56748 Mdot
.64156 .48771 Mdot
.22442 .35371 Mdot
.55783 .4939 Mdot
.47767 .37773 Mdot
.31004 .44127 Mdot
.22876 .59145 Mdot
.38417 .64755 Mdot
.46734 .3699 Mdot
.58453 .73924 Mdot
.46235 .38313 Mdot
.62434 .37835 Mdot
.32608 .48735 Mdot
.44422 .3556 Mdot
.49413 .62806 Mdot
.31458 .46885 Mdot
.34636 .4416 Mdot
.80218 .5179 Mdot
.47402 .66675 Mdot
.56658 .73574 Mdot
.322 .47868 Mdot
.55677 .23295 Mdot
.32626 .45314 Mdot
.56681 .2715 Mdot
.63323 .43127 Mdot
.59938 .64592 Mdot
.27687 .39652 Mdot
.52994 .43026 Mdot
.32976 .49248 Mdot
.57997 .69695 Mdot
.63176 .45147 Mdot
.43 .33405 Mdot
.57391 .72893 Mdot
.29812 .4253 Mdot
.44476 .66158 Mdot
.43297 .31843 Mdot
.29417 .4618 Mdot
.4612 .36642 Mdot
.70463 .67978 Mdot
.62465 .71633 Mdot
.32992 .53459 Mdot
.48218 .49601 Mdot
.6143 .51197 Mdot
.39694 .28701 Mdot
.55213 .48119 Mdot
.57378 .45076 Mdot
.45854 .62839 Mdot
.6338 .65381 Mdot
.46127 .32737 Mdot
.78011 .69999 Mdot
.34591 .47513 Mdot
.20799 .38976 Mdot
.51297 .39867 Mdot
.5656 .44715 Mdot
.46632 .3147 Mdot
.43076 .30172 Mdot
.60588 .35786 Mdot
.4131 .6251 Mdot
.61025 .40121 Mdot
.54195 .45542 Mdot
.67086 .44042 Mdot
.34215 .44108 Mdot
.27521 .53028 Mdot
.48655 .62168 Mdot
.461 .85783 Mdot
.44875 .65841 Mdot
.42573 .71942 Mdot
.48266 .32187 Mdot
.56025 .72411 Mdot
.58812 .47655 Mdot
.5086 .41682 Mdot
.4452 .37251 Mdot
.58446 .76216 Mdot
.55384 .7059 Mdot
.24322 .52758 Mdot
.35148 .4817 Mdot
.57162 .49589 Mdot
.57644 .48987 Mdot
.64629 .45687 Mdot
.64196 .43979 Mdot
.30081 .45596 Mdot
.64316 .503 Mdot
.36887 .46605 Mdot
.57383 .23992 Mdot
.21596 .36109 Mdot
.41634 .66144 Mdot
.72681 .51586 Mdot
.43881 .3096 Mdot
.53087 .22856 Mdot
.59149 .39563 Mdot
.22139 .63364 Mdot
.78278 .61246 Mdot
.5568 .44595 Mdot
.4757 .61778 Mdot
.73444 .48338 Mdot
.41866 .66048 Mdot
.15296 .65674 Mdot
.37308 .67009 Mdot
.81306 .42579 Mdot
.61458 .50278 Mdot
.32253 .64536 Mdot
.58999 .39243 Mdot
.58943 .51196 Mdot
.40065 .67815 Mdot
.30074 .2903 Mdot
.33005 .37264 Mdot
.57418 .68314 Mdot
.61666 .4538 Mdot
.479 .30156 Mdot
.61398 .49797 Mdot
.58213 .47611 Mdot
.63521 .50292 Mdot
.30014 .44716 Mdot
.58438 .52061 Mdot
.65218 .49407 Mdot
.3949 .57744 Mdot
.67078 .63615 Mdot
.42427 .62762 Mdot
.59945 .37026 Mdot
.5792 .72759 Mdot
.45587 .31299 Mdot
.47796 .44331 Mdot
.36077 .4596 Mdot
.56477 .35243 Mdot
.6555 .48438 Mdot
.28124 .38573 Mdot
.29396 .46276 Mdot
.56845 .72363 Mdot
.34498 .63186 Mdot
.82434 .49551 Mdot
.40908 .65513 Mdot
.34884 .6345 Mdot
.46044 .63115 Mdot
.47259 .23975 Mdot
.46642 .31797 Mdot
.61419 .51308 Mdot
.32664 .47564 Mdot
.44458 .63075 Mdot
.6384 .63861 Mdot
.58469 .44849 Mdot
.48143 .64717 Mdot
.62099 .51252 Mdot
.61788 .66603 Mdot
.35985 .74077 Mdot
.41495 .65515 Mdot
.28445 .47526 Mdot
.31822 .46609 Mdot
.55071 .70828 Mdot
.45039 .31141 Mdot
.43722 .34623 Mdot
.30939 .46739 Mdot
.26821 .74442 Mdot
.57389 .44404 Mdot
.61648 .50452 Mdot
.20321 .49227 Mdot
.61084 .49092 Mdot
.73694 .60955 Mdot
.32904 .63042 Mdot
.44801 .30893 Mdot
.62721 .5035 Mdot
.63551 .46402 Mdot
.61475 .44564 Mdot
.69951 .68428 Mdot
.44328 .65532 Mdot
.58365 .42857 Mdot
.5613 .68713 Mdot
.31751 .59313 Mdot
.61307 .50555 Mdot
.65634 .42855 Mdot
.44057 .34823 Mdot
.21319 .34728 Mdot
.35701 .46102 Mdot
.4774 .63044 Mdot
.45995 .66449 Mdot
.48567 .69294 Mdot
.46915 .28535 Mdot
.33599 .63299 Mdot
.57636 .81311 Mdot
.36511 .62975 Mdot
.57546 .70379 Mdot
.51239 .71846 Mdot
.46327 .59906 Mdot
.46959 .6208 Mdot
.35597 .43057 Mdot
.65739 .47194 Mdot
.5895 .42627 Mdot
.19963 .54771 Mdot
.57273 .43281 Mdot
.55683 .70452 Mdot
.36993 .45794 Mdot
.44214 .3433 Mdot
.56453 .72146 Mdot
.34827 .45395 Mdot
.4371 .32603 Mdot
.61476 .5226 Mdot
.62178 .52412 Mdot
.45936 .35098 Mdot
.42406 .33267 Mdot
.60019 .47875 Mdot
.34229 .566 Mdot
.49394 .33825 Mdot
.44926 .36003 Mdot
.3324 .61405 Mdot
.41464 .65942 Mdot
.65699 .52498 Mdot
.3429 .45511 Mdot
.64934 .48581 Mdot
.4184 .66143 Mdot
.54667 .69675 Mdot
.45761 .33033 Mdot
.63592 .4667 Mdot
.63289 .47542 Mdot
.57612 .6991 Mdot
.55805 .68042 Mdot
.56249 .72149 Mdot
.36664 .47675 Mdot
.63693 .44056 Mdot
.4741 .34118 Mdot
.34645 .48392 Mdot
.57774 .68378 Mdot
.59703 .74298 Mdot
.43813 .57697 Mdot
.59461 .49444 Mdot
.42334 .48844 Mdot
.90375 .43576 Mdot
.73969 .58477 Mdot
.33503 .62656 Mdot
.45857 .67007 Mdot
.66579 .66368 Mdot
.34751 .71675 Mdot
.31489 .44906 Mdot
.75197 .53681 Mdot
.56969 .74698 Mdot
.61613 .51503 Mdot
.55685 .49127 Mdot
.56696 .42388 Mdot
.57697 .72075 Mdot
.71978 .66117 Mdot
.42157 .31971 Mdot
.53149 .29418 Mdot
.57875 .72738 Mdot
.41348 .65385 Mdot
.43231 .66196 Mdot
.44952 .65869 Mdot
.58466 .51719 Mdot
.59265 .35292 Mdot
.54133 .24038 Mdot
.49347 .19946 Mdot
.35898 .47561 Mdot
.41234 .35822 Mdot
.75464 .65462 Mdot
.46355 .35066 Mdot
.40769 .63734 Mdot
.57951 .71825 Mdot
.43859 .35316 Mdot
.30276 .47132 Mdot
.33135 .46607 Mdot
.43898 .65559 Mdot
.44564 .63957 Mdot
.44005 .62348 Mdot
.4921 .34778 Mdot
.4832 .32413 Mdot
.60193 .4364 Mdot
.45578 .33827 Mdot
.19309 .44395 Mdot
.56636 .67555 Mdot
.42459 .65815 Mdot
.33039 .44788 Mdot
.462 .31789 Mdot
.58673 .44313 Mdot
.50436 .7392 Mdot
.37186 .27725 Mdot
.59415 .71139 Mdot
.3427 .732 Mdot
.18343 .69318 Mdot
.58147 .49973 Mdot
.32157 .44173 Mdot
.24506 .62861 Mdot
.58482 .45508 Mdot
.45858 .64896 Mdot
.41587 .2084 Mdot
.37358 .62266 Mdot
.64736 .49824 Mdot
.5699 .43698 Mdot
.34653 .43958 Mdot
.67756 .72422 Mdot
.60093 .43413 Mdot
.24755 .38886 Mdot
.30871 .43671 Mdot
.45535 .61193 Mdot
.75144 .73504 Mdot
.37178 .65263 Mdot
.57828 .61883 Mdot
.33744 .61703 Mdot
.57257 .47709 Mdot
.47231 .62944 Mdot
.5901 .70439 Mdot
.45503 .62346 Mdot
.43186 .37073 Mdot
.43126 .62484 Mdot
.6208 .46782 Mdot
.47624 .34105 Mdot
.31575 .45069 Mdot
.20806 .43018 Mdot
.38439 .58145 Mdot
.44382 .63678 Mdot
.32783 .61738 Mdot
.62439 .50773 Mdot
.56165 .56397 Mdot
.53934 .5004 Mdot
.60952 .50336 Mdot
.32548 .48503 Mdot
.4657 .31288 Mdot
.30961 .49144 Mdot
.65318 .43053 Mdot
.27931 .3002 Mdot
.3509 .45099 Mdot
.29196 .40423 Mdot
.57112 .70172 Mdot
.54461 .58218 Mdot
.58573 .43947 Mdot
.32583 .47892 Mdot
.63897 .44206 Mdot
.46397 .30008 Mdot
.45335 .51568 Mdot
.3048 .60617 Mdot
.3264 .47445 Mdot
.82614 .56582 Mdot
.43187 .52321 Mdot
.60341 .53318 Mdot
.33131 .48092 Mdot
.49627 .27379 Mdot
.33976 .61857 Mdot
.58302 .71256 Mdot
.57649 .68329 Mdot
.59299 .70539 Mdot
.55949 .45057 Mdot
.651 .41121 Mdot
.58072 .74233 Mdot
.3214 .43417 Mdot
.55007 .69228 Mdot
.50299 .44897 Mdot
.82921 .55549 Mdot
.57839 .73596 Mdot
.60454 .44853 Mdot
.64257 .4171 Mdot
.66652 .6366 Mdot
.40499 .63564 Mdot
.79441 .39669 Mdot
.7153 .45526 Mdot
.59695 .48704 Mdot
.6961 .46808 Mdot
.42136 .32926 Mdot
.26894 .6541 Mdot
.55426 .38784 Mdot
.34228 .71928 Mdot
.47182 .30555 Mdot
.38402 .63643 Mdot
.45008 .30996 Mdot
.58802 .50394 Mdot
.62915 .49648 Mdot
.42794 .29708 Mdot
.24794 .48854 Mdot
.25157 .58264 Mdot
.75717 .70045 Mdot
.44688 .36066 Mdot
.33547 .47561 Mdot
.29955 .46141 Mdot
.35922 .47359 Mdot
.4391 .61147 Mdot
.45075 .36888 Mdot
.625 .43608 Mdot
.48353 .65286 Mdot
.56944 .45009 Mdot
.31718 .47479 Mdot
.7853 .69091 Mdot
.44078 .3465 Mdot
.59782 .47283 Mdot
.3196 .77738 Mdot
.4523 .64113 Mdot
.58546 .70937 Mdot
.6322 .68066 Mdot
.45157 .60661 Mdot
.31584 .4894 Mdot
.42331 .30469 Mdot
.34787 .40646 Mdot
.44717 .43157 Mdot
.67947 .49901 Mdot
.6686 .49653 Mdot
.66499 .78172 Mdot
.33892 .5975 Mdot
.55806 .48735 Mdot
.487 .64235 Mdot
.39463 .64546 Mdot
.63169 .46408 Mdot
.43428 .35525 Mdot
.60185 .72201 Mdot
.56023 .68629 Mdot
.55637 .42146 Mdot
.4722 .48478 Mdot
.54377 .58441 Mdot
.64435 .47039 Mdot
.55542 .41161 Mdot
.45802 .66572 Mdot
.36367 .63214 Mdot
.21743 .46376 Mdot
.57988 .73875 Mdot
.64074 .49443 Mdot
.36442 .3756 Mdot
.48574 .33699 Mdot
.43677 .62283 Mdot
.31826 .48816 Mdot
.71496 .68173 Mdot
.48044 .61128 Mdot
.63351 .46616 Mdot
.63834 .46706 Mdot
.34798 .44145 Mdot
.47692 .37783 Mdot
.57742 .71828 Mdot
.47788 .6567 Mdot
.58002 .73954 Mdot
.48175 .33891 Mdot
.44402 .34611 Mdot
.68999 .48176 Mdot
.5545 .4137 Mdot
.43872 .64936 Mdot
.62905 .4201 Mdot
.40877 .64592 Mdot
.67102 .73592 Mdot
.3022 .49056 Mdot
.57834 .49673 Mdot
.40924 .33512 Mdot
.31653 .47733 Mdot
.61082 .47316 Mdot
.64797 .80552 Mdot
.56313 .45969 Mdot
.38318 .64327 Mdot
.25727 .32177 Mdot
.56566 .68956 Mdot
.66911 .38546 Mdot
.67151 .53488 Mdot
.6139 .49016 Mdot
.42176 .65227 Mdot
.5357 .4822 Mdot
.34861 .44484 Mdot
.47348 .31075 Mdot
.27521 .77288 Mdot
.32357 .45572 Mdot
.61877 .49972 Mdot
.56982 .72302 Mdot
.4249 .30596 Mdot
.36898 .62119 Mdot
.2005 .51317 Mdot
.55132 .50269 Mdot
.63799 .52129 Mdot
.64797 .49376 Mdot
.50818 .17543 Mdot
.47303 .62725 Mdot
.46332 .32042 Mdot
.33981 .44093 Mdot
.30755 .46359 Mdot
.44985 .65654 Mdot
.31457 .36778 Mdot
.51567 .57978 Mdot
.82663 .31268 Mdot
.43324 .63941 Mdot
.54561 .71194 Mdot
.49121 .4963 Mdot
.41239 .6414 Mdot
.47781 .64288 Mdot
.46613 .6651 Mdot
.25501 .42704 Mdot
.43832 .32958 Mdot
.63429 .4779 Mdot
.49262 .32235 Mdot
.5714 .47658 Mdot
.57644 .59513 Mdot
.31188 .47636 Mdot
.47553 .31113 Mdot
.66248 .7905 Mdot
.49413 .39745 Mdot
.59153 .4535 Mdot
.73778 .68661 Mdot
.55512 .52396 Mdot
.71196 .64819 Mdot
.59019 .53802 Mdot
.45257 .63346 Mdot
.62952 .39041 Mdot
.66172 .4339 Mdot
.20092 .43293 Mdot
.33287 .44772 Mdot
.33099 .62216 Mdot
.55151 .46463 Mdot
.54329 .4713 Mdot
.45814 .29657 Mdot
.43986 .3549 Mdot
.57615 .74059 Mdot
.54699 .62183 Mdot
.32045 .44812 Mdot
.62189 .69971 Mdot
.60265 .48512 Mdot
.25552 .48533 Mdot
.55638 .37108 Mdot
.60927 .47246 Mdot
.8077 .49254 Mdot
.57853 .35331 Mdot
.59171 .43204 Mdot
.49727 .26403 Mdot
.3341 .46142 Mdot
.25483 .32936 Mdot
.65187 .43993 Mdot
.46011 .64793 Mdot
.4788 .31828 Mdot
.41994 .33361 Mdot
.59207 .73711 Mdot
.18603 .59156 Mdot
.32769 .49367 Mdot
.48002 .31583 Mdot
.58014 .45501 Mdot
.324 .48982 Mdot
.34345 .61217 Mdot
.66832 .44538 Mdot
.75523 .52167 Mdot
.45287 .3395 Mdot
.63248 .42546 Mdot
.33419 .2815 Mdot
.56093 .62162 Mdot
.75441 .28633 Mdot
.3602 .46972 Mdot
.56785 .73051 Mdot
.61717 .53764 Mdot
.57437 .81142 Mdot
.57102 .42375 Mdot
.6057 .64663 Mdot
.49445 .30098 Mdot
.55896 .72404 Mdot
.59143 .46066 Mdot
.61636 .44223 Mdot
.47093 .47197 Mdot
.55457 .67968 Mdot
.56555 .47449 Mdot
.68436 .4156 Mdot
.43995 .32434 Mdot
.32833 .62723 Mdot
.4477 .33913 Mdot
.59942 .44635 Mdot
.6604 .41801 Mdot
.43007 .3419 Mdot
.61272 .77683 Mdot
.5407 .71143 Mdot
.35792 .46265 Mdot
.57671 .40386 Mdot
.64614 .44153 Mdot
.5189 .15611 Mdot
.33293 .62436 Mdot
.45509 .21346 Mdot
.48905 .6119 Mdot
.37301 .38841 Mdot
.34379 .64779 Mdot
.82862 .45812 Mdot
.21318 .43206 Mdot
.54654 .47231 Mdot
.69892 .56138 Mdot
.5029 .24948 Mdot
.31434 .49149 Mdot
.61971 .24573 Mdot
.59991 .48716 Mdot
.58011 .47408 Mdot
.4615 .61343 Mdot
.29572 .371 Mdot
.24245 .61343 Mdot
.47333 .49841 Mdot
.57514 .71367 Mdot
.47926 .35194 Mdot
.62496 .48033 Mdot
.51693 .59247 Mdot
.4232 .63154 Mdot
.27847 .51183 Mdot
.59444 .46848 Mdot
.23429 .64585 Mdot
.26229 .42432 Mdot
.33695 .48974 Mdot
.4376 .66229 Mdot
.46491 .60486 Mdot
.58088 .48959 Mdot
.31157 .48405 Mdot
.59747 .43439 Mdot
.42433 .5357 Mdot
.61134 .41586 Mdot
.58027 .73428 Mdot
.62523 .51026 Mdot
.44529 .46048 Mdot
.7916 .33762 Mdot
.67414 .3992 Mdot
.42783 .35311 Mdot
.44542 .6097 Mdot
.44444 .65465 Mdot
.43968 .35211 Mdot
.4449 .65262 Mdot
.54669 .31543 Mdot
.68571 .34966 Mdot
.57274 .70909 Mdot
.56931 .40316 Mdot
.58717 .73501 Mdot
.33066 .62402 Mdot
.59432 .49109 Mdot
.57252 .81753 Mdot
.4362 .63948 Mdot
.34933 .22896 Mdot
.3235 .45223 Mdot
.33167 .62334 Mdot
.59 .42139 Mdot
.50786 .71472 Mdot
.41425 .62964 Mdot
.38538 .63943 Mdot
.61216 .44338 Mdot
.43515 .34147 Mdot
.62162 .44664 Mdot
.56211 .52862 Mdot
.34386 .63296 Mdot
.65718 .4746 Mdot
.34817 .45394 Mdot
.48924 .36771 Mdot
.82875 .51149 Mdot
.38738 .64665 Mdot
.59232 .49805 Mdot
.58119 .45568 Mdot
.44173 .29945 Mdot
.61539 .42243 Mdot
.30189 .47252 Mdot
.57401 .10074 Mdot
.57193 .70159 Mdot
.37787 .62255 Mdot
.3765 .65307 Mdot
.5597 .44072 Mdot
.63969 .46418 Mdot
.69177 .76992 Mdot
.30131 .58207 Mdot
.34602 .46627 Mdot
.53756 .47046 Mdot
.48149 .65167 Mdot
.5682 .72203 Mdot
.3369 .43155 Mdot
.65111 .48094 Mdot
.58656 .4727 Mdot
.57556 .73199 Mdot
.80792 .52571 Mdot
.3415 .72157 Mdot
.36218 .47039 Mdot
.6176 .38808 Mdot
.49597 .74859 Mdot
.57466 .44352 Mdot
.5386 .76766 Mdot
.44706 .35756 Mdot
.33685 .48285 Mdot
.49911 .19319 Mdot
.62433 .51304 Mdot
.30222 .46188 Mdot
.32422 .44716 Mdot
.6672 .47399 Mdot
.48458 .30154 Mdot
.4894 .35762 Mdot
.46641 .36549 Mdot
.19356 .38117 Mdot
.61747 .60742 Mdot
.43915 .62409 Mdot
.33432 .46269 Mdot
.41995 .65999 Mdot
.55524 .67418 Mdot
.53926 .59699 Mdot
.40358 .64698 Mdot
.42271 .3268 Mdot
.43338 .66312 Mdot
.61797 .44553 Mdot
.31425 .45098 Mdot
.46666 .61941 Mdot
.55351 .46565 Mdot
.6303 .56052 Mdot
.41174 .51985 Mdot
.60144 .73423 Mdot
.56491 .75272 Mdot
.62891 .49086 Mdot
.33726 .62725 Mdot
.59781 .47868 Mdot
.3671 .46489 Mdot
.45827 .44723 Mdot
.55833 .44626 Mdot
.44056 .64222 Mdot
.70678 .46321 Mdot
.41804 .62332 Mdot
.53974 .48684 Mdot
.60311 .44922 Mdot
.56959 .4566 Mdot
.59878 .43339 Mdot
.32029 .3877 Mdot
.31932 .49573 Mdot
.65101 .5561 Mdot
.4975 .66634 Mdot
.46148 .34244 Mdot
.41463 .35468 Mdot
.48602 .76623 Mdot
.38014 .62192 Mdot
.34205 .45605 Mdot
.58059 .43896 Mdot
.37686 .6477 Mdot
.79247 .68236 Mdot
.61183 .78069 Mdot
.57528 .76292 Mdot
.48345 .63207 Mdot
.4237 .34954 Mdot
.41965 .629 Mdot
.57745 .48295 Mdot
.66461 .49121 Mdot
.83126 .47864 Mdot
.27934 .47199 Mdot
.57905 .71937 Mdot
.56861 .46177 Mdot
.57644 .61539 Mdot
.48279 .65087 Mdot
.46471 .66636 Mdot
.56438 .45885 Mdot
.47469 .37005 Mdot
.66617 .19711 Mdot
.33335 .4908 Mdot
.72447 .48863 Mdot
.39678 .31645 Mdot
.27051 .32466 Mdot
.30672 .47032 Mdot
.39095 .53101 Mdot
.49163 .64861 Mdot
.69697 .39524 Mdot
.45915 .34565 Mdot
.58035 .72295 Mdot
.6697 .48535 Mdot
.42544 .32329 Mdot
.49405 .65572 Mdot
.448 .30679 Mdot
.59842 .511 Mdot
.3149 .49317 Mdot
.46513 .662 Mdot
.29287 .48957 Mdot
.4221 .30108 Mdot
.59268 .71763 Mdot
.53186 .56076 Mdot
.66475 .27214 Mdot
.57362 .35299 Mdot
.58474 .42844 Mdot
.50257 .59228 Mdot
.63607 .44148 Mdot
.47361 .29814 Mdot
.58984 .43992 Mdot
.42355 .26145 Mdot
.43976 .6619 Mdot
.63511 .42696 Mdot
.64557 .50035 Mdot
.62258 .26252 Mdot
.60019 .46091 Mdot
.66038 .47307 Mdot
.59112 .43105 Mdot
.40906 .29463 Mdot
.57612 .51866 Mdot
.4361 .33412 Mdot
.20442 .52223 Mdot
.47655 .64115 Mdot
.60238 .73466 Mdot
.5714 .68586 Mdot
.5938 .64019 Mdot
.56162 .60705 Mdot
.30743 .37283 Mdot
.44681 .33229 Mdot
.34247 .44704 Mdot
.5954 .43398 Mdot
.54418 .19783 Mdot
.44155 .69058 Mdot
.48382 .65754 Mdot
.38556 .64478 Mdot
.52411 .44377 Mdot
.51121 .17373 Mdot
.60412 .41815 Mdot
.19063 .53924 Mdot
.57225 .41543 Mdot
.56289 .47294 Mdot
.46242 .60627 Mdot
.55644 .60864 Mdot
.58183 .42873 Mdot
.4568 .29677 Mdot
.58483 .7233 Mdot
.45137 .3998 Mdot
.35404 .69425 Mdot
.37129 .54443 Mdot
.67659 .30752 Mdot
.62829 .43469 Mdot
.46936 .65972 Mdot
.43351 .31829 Mdot
.21816 .45621 Mdot
.34596 .48372 Mdot
.26761 .40206 Mdot
.56907 .24889 Mdot
.70164 .73398 Mdot
.58228 .72135 Mdot
.80438 .5225 Mdot
.62207 .46914 Mdot
.43877 .61098 Mdot
.60504 .51593 Mdot
.79596 .6773 Mdot
.55011 .72057 Mdot
.45676 .37531 Mdot
.337 .47413 Mdot
.46833 .30083 Mdot
.63108 .35766 Mdot
.35902 .53406 Mdot
.47406 .55248 Mdot
.40547 .65198 Mdot
.60824 .56951 Mdot
.47454 .33155 Mdot
.64395 .48093 Mdot
.86049 .36058 Mdot
.44945 .35923 Mdot
.47039 .3676 Mdot
.65337 .74775 Mdot
.65266 .75617 Mdot
.53247 .44745 Mdot
.44476 .30524 Mdot
.45319 .67314 Mdot
.57198 .69397 Mdot
.62172 .44177 Mdot
.60628 .43553 Mdot
.4331 .34351 Mdot
.40614 .63748 Mdot
.72864 .4859 Mdot
.44907 .63644 Mdot
.43951 .3223 Mdot
.4608 .63811 Mdot
.4155 .66529 Mdot
.478 .62781 Mdot
.63915 .43398 Mdot
.59102 .43815 Mdot
.38503 .72114 Mdot
.44416 .34601 Mdot
.64059 .46057 Mdot
.63587 .49416 Mdot
.47389 .33732 Mdot
.49488 .61489 Mdot
.57115 .20688 Mdot
.60449 .49655 Mdot
.61912 .45785 Mdot
.56303 .72794 Mdot
.43477 .60557 Mdot
.35566 .75258 Mdot
.6317 .45108 Mdot
.54458 .69491 Mdot
.49221 .34288 Mdot
.6006 .47716 Mdot
.5017 .45513 Mdot
.40657 .65677 Mdot
.62932 .51052 Mdot
.36788 .61855 Mdot
.57076 .43 Mdot
.69358 .2288 Mdot
.59843 .50198 Mdot
.46465 .32495 Mdot
.47596 .3202 Mdot
.66166 .73333 Mdot
.46608 .35654 Mdot
.33706 .61574 Mdot
.31613 .47165 Mdot
.80868 .64573 Mdot
.3478 .61218 Mdot
.56062 .46945 Mdot
.31589 .7824 Mdot
.649 .43178 Mdot
.55273 .45966 Mdot
.46857 .18366 Mdot
.35139 .6126 Mdot
.47022 .31891 Mdot
.25305 .45794 Mdot
.56739 .4162 Mdot
.3191 .48916 Mdot
.67812 .46876 Mdot
.65477 .49713 Mdot
.23718 .37085 Mdot
.39411 .24002 Mdot
.36863 .45119 Mdot
.67604 .51063 Mdot
.63241 .45148 Mdot
.41001 .59697 Mdot
.58353 .44688 Mdot
.58439 .73785 Mdot
.47079 .36612 Mdot
.42061 .63785 Mdot
.56606 .69723 Mdot
.60754 .48768 Mdot
.57596 .72285 Mdot
.44087 .62224 Mdot
.32932 .48503 Mdot
.58739 .49154 Mdot
.54951 .72441 Mdot
.57541 .71535 Mdot
.6413 .44836 Mdot
.47748 .3141 Mdot
.61831 .38279 Mdot
.60325 .47594 Mdot
.64083 .47782 Mdot
.4372 .34604 Mdot
.49234 .85992 Mdot
.58071 .49539 Mdot
.42093 .4955 Mdot
.45216 .37316 Mdot
.33095 .63848 Mdot
.44781 .61777 Mdot
.65528 .49818 Mdot
.31854 .48573 Mdot
.31468 .47833 Mdot
.46796 .67132 Mdot
.46076 .29939 Mdot
.40887 .6324 Mdot
.70206 .45182 Mdot
.56612 .40977 Mdot
.66527 .45124 Mdot
.24604 .732 Mdot
.82309 .47138 Mdot
.43078 .35256 Mdot
.48832 .62382 Mdot
.47839 .50561 Mdot
.33697 .46509 Mdot
.44527 .66936 Mdot
.42649 .30294 Mdot
.42163 .34425 Mdot
.43904 .31012 Mdot
.55773 .71879 Mdot
.49086 .62233 Mdot
.47028 .37762 Mdot
.47811 .36821 Mdot
.61512 .44479 Mdot
.63453 .45324 Mdot
.51486 .34112 Mdot
.6943 .6299 Mdot
.59398 .72576 Mdot
.45557 .65624 Mdot
.4479 .1343 Mdot
.36819 .46223 Mdot
.62775 .26653 Mdot
.55672 .44894 Mdot
.91908 .53292 Mdot
.5999 .41718 Mdot
.57972 .45243 Mdot
.49398 .35059 Mdot
.56583 .74182 Mdot
.58945 .72754 Mdot
.47552 .33079 Mdot
.41966 .3069 Mdot
.58061 .7376 Mdot
.79118 .59721 Mdot
.83044 .5613 Mdot
.24246 .42903 Mdot
.46749 .33187 Mdot
.69086 .30006 Mdot
.3142 .4878 Mdot
.42749 .29403 Mdot
.36332 .4511 Mdot
.47702 .64479 Mdot
.4926 .65069 Mdot
.34941 .44251 Mdot
.60867 .44166 Mdot
.45007 .62007 Mdot
.60136 .5304 Mdot
.80559 .58268 Mdot
.7587 .40026 Mdot
.28078 .57014 Mdot
.55446 .48778 Mdot
.23471 .59923 Mdot
.25682 .621 Mdot
.62101 .49164 Mdot
.45605 .41599 Mdot
.57853 .72104 Mdot
.42732 .28902 Mdot
.30311 .47512 Mdot
.74381 .27536 Mdot
.57684 .4414 Mdot
.45996 .32508 Mdot
.33646 .44884 Mdot
.66192 .71465 Mdot
.25122 .38204 Mdot
.56887 .4719 Mdot
.78948 .27304 Mdot
.43424 .28101 Mdot
.42145 .63787 Mdot
.25328 .70697 Mdot
.49573 .33487 Mdot
.5472 .73664 Mdot
.4965 .64608 Mdot
.69538 .75433 Mdot
.45544 .31327 Mdot
.49393 .6604 Mdot
.4794 .347 Mdot
.58978 .73619 Mdot
.47116 .29112 Mdot
.47154 .66169 Mdot
.5957 .46128 Mdot
.44822 .65067 Mdot
.59442 .72226 Mdot
.42859 .61598 Mdot
.30721 .47987 Mdot
.33483 .62154 Mdot
.32512 .46551 Mdot
.55767 .62127 Mdot
.31551 .26564 Mdot
.35353 .47298 Mdot
.64518 .71 Mdot
.55704 .48639 Mdot
.48281 .378 Mdot
.43028 .64202 Mdot
.49421 .66885 Mdot
.51503 .5486 Mdot
.46578 .34334 Mdot
.4563 .65934 Mdot
.5614 .24257 Mdot
.39923 .83138 Mdot
.64721 .40907 Mdot
.64271 .5985 Mdot
.47209 .33744 Mdot
.46014 .66769 Mdot
.2038 .4914 Mdot
.42234 .32334 Mdot
.43326 .6382 Mdot
.33021 .47914 Mdot
.30667 .46595 Mdot
.56936 .44698 Mdot
.28799 .50334 Mdot
.42608 .65076 Mdot
.22441 .54491 Mdot
.48544 .34067 Mdot
.66219 .71021 Mdot
.59784 .72863 Mdot
.48035 .6419 Mdot
.66662 .43943 Mdot
.47735 .39209 Mdot
.42522 .66902 Mdot
.736 .51993 Mdot
.43578 .14525 Mdot
.45138 .65613 Mdot
.47369 .36467 Mdot
.45685 .32736 Mdot
.54448 .50965 Mdot
.47456 .48496 Mdot
.42382 .62222 Mdot
.55211 .82381 Mdot
.61802 .65154 Mdot
.34956 .62648 Mdot
.29328 .65115 Mdot
.57365 .43053 Mdot
.6431 .44455 Mdot
.33847 .46614 Mdot
.60094 .45564 Mdot
.48468 .36672 Mdot
.588 .42455 Mdot
.30484 .4557 Mdot
.48902 .65186 Mdot
.58938 .48976 Mdot
.57429 .69316 Mdot
.37028 .44263 Mdot
.34964 .44093 Mdot
.46855 .63318 Mdot
.44225 .30654 Mdot
.5399 .66352 Mdot
.44506 .64067 Mdot
.62411 .43327 Mdot
.36345 .61993 Mdot
.60819 .5116 Mdot
.78506 .53571 Mdot
.42675 .31234 Mdot
.4136 .63551 Mdot
.42708 .36467 Mdot
.32642 .46089 Mdot
.49792 .66301 Mdot
.59255 .44688 Mdot
.43624 .63547 Mdot
.34983 .70648 Mdot
.79752 .55531 Mdot
.4599 .29867 Mdot
.33252 .66367 Mdot
.47633 .3657 Mdot
.34944 .62786 Mdot
.76329 .56545 Mdot
.58024 .71083 Mdot
.47909 .65162 Mdot
.81429 .45596 Mdot
.43805 .64376 Mdot
.60349 .46266 Mdot
.61635 .47659 Mdot
.46503 .61449 Mdot
.5507 .69691 Mdot
.21945 .34252 Mdot
.40595 .50796 Mdot
.46431 .31486 Mdot
.71 .4113 Mdot
.49916 .13125 Mdot
.2982 .44376 Mdot
.34226 .46532 Mdot
.55055 .43104 Mdot
.56541 .44835 Mdot
.34329 .43548 Mdot
.29784 .45843 Mdot
.59144 .74187 Mdot
.47187 .66438 Mdot
.48356 .29549 Mdot
.31633 .43267 Mdot
.59658 .55078 Mdot
.5657 .60617 Mdot
.53708 .43927 Mdot
.69156 .45516 Mdot
.59991 .52498 Mdot
.60673 .65591 Mdot
.31608 .4427 Mdot
.63116 .48956 Mdot
.56258 .51074 Mdot
.33764 .4798 Mdot
.58867 .73604 Mdot
.38219 .24679 Mdot
.46166 .64311 Mdot
.63297 .83553 Mdot
.60665 .50845 Mdot
.6025 .46685 Mdot
.35787 .47695 Mdot
.4033 .60801 Mdot
.42642 .33063 Mdot
.43478 .3058 Mdot
.47044 .6253 Mdot
.52259 .56657 Mdot
.61248 .42383 Mdot
.62444 .49174 Mdot
.46919 .65398 Mdot
.33535 .62247 Mdot
.25669 .55752 Mdot
.63109 .47278 Mdot
.33451 .44999 Mdot
.48742 .67921 Mdot
.31077 .44513 Mdot
.58489 .50397 Mdot
.60669 .46406 Mdot
.63561 .43134 Mdot
.56456 .44977 Mdot
.35614 .44478 Mdot
.62979 .48517 Mdot
.63748 .41237 Mdot
.45926 .30577 Mdot
.64042 .43782 Mdot
.61525 .65618 Mdot
.61005 .45065 Mdot
.58665 .70545 Mdot
.51659 .60752 Mdot
.5688 .45776 Mdot
.64786 .44504 Mdot
.40841 .5076 Mdot
.58799 .46151 Mdot
.36726 .46346 Mdot
.45956 .33828 Mdot
.33403 .46338 Mdot
.33985 .44012 Mdot
.43682 .67037 Mdot
.58613 .74161 Mdot
.55143 .44906 Mdot
.589 .70025 Mdot
.68679 .47125 Mdot
.60174 .5127 Mdot
.50622 .67761 Mdot
.19042 .54179 Mdot
.35076 .72433 Mdot
.59343 .44542 Mdot
.47605 .63274 Mdot
.41854 .63649 Mdot
.71068 .54743 Mdot
.58882 .52822 Mdot
.34186 .43336 Mdot
.32591 .47859 Mdot
.73889 .60065 Mdot
.23556 .37788 Mdot
.59218 .7174 Mdot
.52619 .59581 Mdot
.57905 .51395 Mdot
.6377 .48338 Mdot
.66521 .44163 Mdot
.40651 .64969 Mdot
.35631 .63427 Mdot
.48403 .65787 Mdot
.36692 .63726 Mdot
.30589 .45042 Mdot
.5933 .42623 Mdot
.76315 .38034 Mdot
.43364 .35038 Mdot
.45903 .33875 Mdot
.32978 .43296 Mdot
.40571 .63299 Mdot
.57789 .54223 Mdot
.29088 .79406 Mdot
.4086 .3079 Mdot
.59502 .74483 Mdot
.6194 .49485 Mdot
.4707 .6318 Mdot
.44506 .36259 Mdot
.55231 .6873 Mdot
.63658 .50264 Mdot
.5059 .61674 Mdot
.59605 .4412 Mdot
.50021 .24959 Mdot
.46486 .30918 Mdot
.80803 .66709 Mdot
.42216 .31203 Mdot
.36911 .43825 Mdot
.34776 .47274 Mdot
.61103 .47155 Mdot
.24941 .72613 Mdot
.49056 .37201 Mdot
.29058 .50226 Mdot
.55826 .73301 Mdot
.37593 .62564 Mdot
.5538 .72146 Mdot
.41308 .6432 Mdot
.58412 .72157 Mdot
.45688 .66406 Mdot
.72772 .60448 Mdot
.40053 .32072 Mdot
.5697 .69936 Mdot
.42236 .58193 Mdot
.58101 .51882 Mdot
.58454 .68957 Mdot
.60677 .40756 Mdot
.69131 .39498 Mdot
.46709 .65221 Mdot
.55185 .69558 Mdot
.64328 .47784 Mdot
.74758 .2991 Mdot
.35156 .45889 Mdot
.34649 .43492 Mdot
.6196 .53095 Mdot
.47235 .66511 Mdot
.43981 .29454 Mdot
.45408 .43457 Mdot
.33072 .63588 Mdot
.6274 .48989 Mdot
.58443 .4265 Mdot
.41408 .35451 Mdot
.41352 .36438 Mdot
.61049 .46691 Mdot
.57289 .23163 Mdot
.62549 .47454 Mdot
.31221 .47977 Mdot
.42265 .33822 Mdot
.45767 .33142 Mdot
.42948 .65487 Mdot
.48206 .31039 Mdot
.69123 .44621 Mdot
.39143 .4146 Mdot
.58043 .41261 Mdot
.32226 .45776 Mdot
.44693 .45084 Mdot
.38616 .64498 Mdot
.78049 .36867 Mdot
.41334 .34449 Mdot
.65723 .4686 Mdot
.48343 .35234 Mdot
.56041 .7153 Mdot
.44634 .34482 Mdot
.44649 .36771 Mdot
.6071 .48175 Mdot
.57213 .47609 Mdot
.3518 .61359 Mdot
.47904 .49322 Mdot
.4826 .31692 Mdot
.62595 .48485 Mdot
.64633 .43161 Mdot
.66087 .48701 Mdot
.43771 .50037 Mdot
.43266 .35571 Mdot
.59873 .28194 Mdot
.75652 .50479 Mdot
.47966 .31315 Mdot
.67068 .21241 Mdot
.37093 .62361 Mdot
.37915 .62299 Mdot
.28299 .4644 Mdot
.63207 .473 Mdot
.47325 .61546 Mdot
.57849 .48404 Mdot
.69523 .46777 Mdot
.5845 .47445 Mdot
.54592 .69823 Mdot
.54736 .47407 Mdot
.34665 .62193 Mdot
.44345 .64436 Mdot
.6171 .50392 Mdot
.58776 .48744 Mdot
.38034 .61671 Mdot
.41581 .32664 Mdot
.42658 .32577 Mdot
.55554 .77108 Mdot
.56501 .70936 Mdot
.33061 .48649 Mdot
.58919 .43559 Mdot
.47534 .63024 Mdot
.4472 .64908 Mdot
.47691 .30335 Mdot
.45735 .64749 Mdot
.34833 .48564 Mdot
.5893 .44832 Mdot
.34706 .43581 Mdot
.55427 .69056 Mdot
.46474 .36709 Mdot
.58084 .43681 Mdot
.61591 .44562 Mdot
.47574 .32007 Mdot
.55766 .48779 Mdot
.56366 .72861 Mdot
.43955 .64824 Mdot
.44689 .31423 Mdot
.31504 .47257 Mdot
.4291 .65733 Mdot
.62979 .4579 Mdot
.42535 .15118 Mdot
.60784 .45926 Mdot
.63299 .46707 Mdot
.83973 .52098 Mdot
.5431 .44537 Mdot
.43099 .65079 Mdot
.41969 .36236 Mdot
.6262 .52595 Mdot
.60039 .62563 Mdot
.59669 .79935 Mdot
.45534 .67239 Mdot
.61361 .49876 Mdot
.79065 .37881 Mdot
.61421 .5016 Mdot
.61813 .69376 Mdot
.42222 .77296 Mdot
.62988 .57034 Mdot
.69036 .45846 Mdot
.35875 .45497 Mdot
.34624 .61364 Mdot
.4426 .66236 Mdot
.52238 .3122 Mdot
.61433 .48388 Mdot
.48096 .25782 Mdot
.64204 .5037 Mdot
.3058 .46741 Mdot
.69482 .40887 Mdot
.45387 .65422 Mdot
.18446 .51276 Mdot
.6262 .43602 Mdot
.42782 .35086 Mdot
.42628 .65983 Mdot
.37366 .62582 Mdot
.63709 .46842 Mdot
.57955 .69127 Mdot
.29619 .49911 Mdot
.57921 .40696 Mdot
.31756 .45983 Mdot
.63799 .49411 Mdot
.68641 .49692 Mdot
.21186 .65363 Mdot
.46044 .3078 Mdot
.33797 .47149 Mdot
.27561 .63901 Mdot
.56162 .49274 Mdot
.45279 .31272 Mdot
.46023 .34531 Mdot
.5965 .7272 Mdot
.47451 .53076 Mdot
.33316 .29167 Mdot
.73408 .33053 Mdot
.60427 .36901 Mdot
.45089 .66853 Mdot
.2625 .60157 Mdot
.62596 .44435 Mdot
.31018 .52811 Mdot
.36733 .45554 Mdot
.59965 .465 Mdot
.56576 .36794 Mdot
.46111 .36573 Mdot
.6213 .46243 Mdot
.58707 .73555 Mdot
.27003 .51241 Mdot
.30438 .53208 Mdot
.57049 .17445 Mdot
.45952 .67341 Mdot
.67401 .46737 Mdot
.68579 .4436 Mdot
.32815 .61874 Mdot
.62006 .51721 Mdot
.43306 .64946 Mdot
.77551 .6287 Mdot
.5478 .70227 Mdot
.45261 .36619 Mdot
.37119 .62405 Mdot
.60833 .52772 Mdot
.65875 .44978 Mdot
.60177 .7368 Mdot
.6534 .46966 Mdot
.18996 .59603 Mdot
.30308 .63024 Mdot
.4616 .61918 Mdot
.44385 .30849 Mdot
.58449 .51675 Mdot
.35085 .63459 Mdot
.61119 .48012 Mdot
.71874 .36959 Mdot
.65497 .4617 Mdot
.31379 .29919 Mdot
.47953 .31882 Mdot
.31928 .46168 Mdot
.67695 .4965 Mdot
.58022 .46903 Mdot
.50035 .74371 Mdot
.69342 .47395 Mdot
.59943 .5033 Mdot
.44853 .29695 Mdot
.43198 .35146 Mdot
.43725 .33453 Mdot
.42768 .6266 Mdot
.2356 .43997 Mdot
.33386 .45382 Mdot
.57758 .42389 Mdot
.31976 .43175 Mdot
.72407 .46057 Mdot
.60012 .74156 Mdot
.69582 .25463 Mdot
.65654 .48248 Mdot
.44226 .33108 Mdot
.36338 .35568 Mdot
.49193 .34613 Mdot
.512 .63502 Mdot
.31921 .44855 Mdot
.45576 .36324 Mdot
.57836 .46037 Mdot
.46549 .48437 Mdot
.60464 .19877 Mdot
.3312 .46855 Mdot
.64796 .42149 Mdot
.48933 .6697 Mdot
.38579 .65487 Mdot
.50348 .11655 Mdot
.34747 .46546 Mdot
.26165 .62042 Mdot
.62047 .4882 Mdot
.43176 .34692 Mdot
.3606 .46612 Mdot
.35483 .45894 Mdot
.46278 .65227 Mdot
.56972 .47093 Mdot
.57044 .4571 Mdot
.36935 .62035 Mdot
.32323 .47889 Mdot
.63321 .52896 Mdot
.64475 .42577 Mdot
.83239 .48126 Mdot
.51654 .3291 Mdot
.53324 .86164 Mdot
.70218 .44882 Mdot
.5909 .36401 Mdot
.49168 .48612 Mdot
.45899 .37172 Mdot
.56755 .4631 Mdot
.59141 .51799 Mdot
.42959 .65336 Mdot
.59782 .45239 Mdot
.45086 .61148 Mdot
.34542 .45804 Mdot
.65792 .20959 Mdot
.37819 .28161 Mdot
.77113 .62544 Mdot
.59551 .45528 Mdot
.25071 .35094 Mdot
.55758 .70054 Mdot
.37776 .45262 Mdot
.43559 .32284 Mdot
.57023 .49755 Mdot
.41099 .62389 Mdot
.48026 .65132 Mdot
.45684 .35353 Mdot
.22103 .56296 Mdot
.52691 .76089 Mdot
.58349 .5035 Mdot
.4432 .61769 Mdot
.37057 .39441 Mdot
.55724 .2261 Mdot
.33717 .42551 Mdot
.54726 .70967 Mdot
.48475 .65634 Mdot
.31975 .43761 Mdot
.51525 .38136 Mdot
.46004 .36101 Mdot
.42887 .37028 Mdot
.43974 .7563 Mdot
.42413 .62107 Mdot
.56624 .69527 Mdot
.22989 .4188 Mdot
.22499 .414 Mdot
.54606 .70387 Mdot
.49203 .64663 Mdot
.43852 .35806 Mdot
.4523 .3192 Mdot
.46004 .33732 Mdot
.18623 .49808 Mdot
.43969 .30199 Mdot
.65639 .30205 Mdot
.65319 .43653 Mdot
.52059 .5066 Mdot
.61187 .5 Mdot
.36052 .44603 Mdot
.46659 .31053 Mdot
.49866 .51066 Mdot
.55865 .46408 Mdot
.59087 .1852 Mdot
.62652 .49266 Mdot
.35164 .42642 Mdot
.62756 .46623 Mdot
.64635 .26679 Mdot
.45514 .37376 Mdot
.59688 .44766 Mdot
.33062 .49878 Mdot
.57248 .71584 Mdot
.49599 .31136 Mdot
.56904 .45859 Mdot
.28955 .36435 Mdot
.54951 .43578 Mdot
.78755 .61661 Mdot
.68109 .68993 Mdot
.59489 .74547 Mdot
.68747 .41699 Mdot
.46909 .66894 Mdot
.4828 .28766 Mdot
.61862 .39653 Mdot
.32955 .46895 Mdot
.3808 .2246 Mdot
.48265 .64689 Mdot
.6617 .39324 Mdot
.53737 .48053 Mdot
.58562 .74084 Mdot
.48505 .38672 Mdot
.36554 .46538 Mdot
.5524 .46978 Mdot
.6665 .47483 Mdot
.77732 .61025 Mdot
.60052 .39723 Mdot
.60973 .42116 Mdot
.59998 .71531 Mdot
.60897 .28906 Mdot
.61319 .4496 Mdot
.50185 .62481 Mdot
.42989 .37025 Mdot
.61547 .53118 Mdot
.59699 .27816 Mdot
.62472 .48451 Mdot
.44761 .35471 Mdot
.43215 .37566 Mdot
.34264 .34196 Mdot
.56671 .74006 Mdot
.6551 .46238 Mdot
.70554 .69771 Mdot
.63445 .43897 Mdot
.33029 .44996 Mdot
.58258 .49834 Mdot
.47631 .64932 Mdot
.19348 .5258 Mdot
.43325 .62954 Mdot
.57833 .48911 Mdot
.46226 .33391 Mdot
.36229 .45795 Mdot
.39524 .73665 Mdot
.4619 .77805 Mdot
.6489 .29875 Mdot
.65957 .79479 Mdot
.55155 .70655 Mdot
.55942 .67702 Mdot
.36138 .47757 Mdot
.59862 .44647 Mdot
.6746 .72064 Mdot
.56617 .41931 Mdot
.62075 .45867 Mdot
.5849 .47598 Mdot
.32522 .52339 Mdot
.33889 .46063 Mdot
.45474 .64194 Mdot
.60936 .46488 Mdot
.62715 .48378 Mdot
.48282 .34407 Mdot
.57321 .71424 Mdot
.42769 .63205 Mdot
.56987 .70526 Mdot
.45366 .62886 Mdot
.68815 .22275 Mdot
.61844 .41375 Mdot
.57033 .71601 Mdot
.3697 .46413 Mdot
.4368 .34622 Mdot
.34223 .63507 Mdot
.41524 .64622 Mdot
.45544 .65722 Mdot
.62598 .48992 Mdot
.44099 .35187 Mdot
.4812 .31118 Mdot
.5585 .71255 Mdot
.34614 .48149 Mdot
.57749 .4862 Mdot
.59008 .50934 Mdot
.69213 .5478 Mdot
.41373 .65364 Mdot
.54509 .23518 Mdot
.33471 .36567 Mdot
.59584 .4449 Mdot
.44899 .30424 Mdot
.59128 .48359 Mdot
.78318 .40188 Mdot
.42313 .32625 Mdot
.56316 .47219 Mdot
.22496 .38118 Mdot
.39877 .64727 Mdot
.30416 .33198 Mdot
.64391 .43512 Mdot
.70399 .76344 Mdot
.63343 .44698 Mdot
.82561 .42866 Mdot
.36081 .58813 Mdot
.5953 .42477 Mdot
.62226 .44554 Mdot
.72437 .31388 Mdot
.61158 .49031 Mdot
.34639 .62771 Mdot
.68743 .40566 Mdot
.42135 .34529 Mdot
.5088 .51992 Mdot
.48824 .60195 Mdot
.5586 .73502 Mdot
.46993 .62484 Mdot
.32573 .66741 Mdot
.58084 .73512 Mdot
.46852 .33104 Mdot
.59933 .43298 Mdot
.54077 .57526 Mdot
.46124 .67603 Mdot
.54602 .50781 Mdot
.32674 .44914 Mdot
.34077 .65615 Mdot
.4636 .60959 Mdot
.31692 .46882 Mdot
.65031 .49706 Mdot
.60255 .21581 Mdot
.39752 .76737 Mdot
.81301 .6494 Mdot
.36169 .47132 Mdot
.30536 .47103 Mdot
.20824 .47078 Mdot
.55141 .72488 Mdot
.77546 .54406 Mdot
.28035 .32586 Mdot
.32534 .49151 Mdot
.75285 .61117 Mdot
.48181 .66327 Mdot
.28017 .36332 Mdot
.42724 .28912 Mdot
.66604 .44984 Mdot
.57881 .46275 Mdot
.34408 .48126 Mdot
.50752 .44307 Mdot
.22746 .67246 Mdot
.32538 .46673 Mdot
.68045 .44613 Mdot
.44947 .53623 Mdot
.36463 .6238 Mdot
.3609 .61323 Mdot
.5764 .74449 Mdot
.57335 .77012 Mdot
.48077 .33814 Mdot
.59115 .74067 Mdot
.30021 .53437 Mdot
.65543 .47565 Mdot
.32476 .47455 Mdot
.35798 .63573 Mdot
.31036 .46902 Mdot
.58636 .732 Mdot
.59255 .74518 Mdot
.45801 .30558 Mdot
.42701 .32934 Mdot
.582 .36148 Mdot
.71646 .63527 Mdot
.61542 .5027 Mdot
.46991 .20854 Mdot
.48632 .33689 Mdot
.64085 .39839 Mdot
.54513 .69474 Mdot
.56918 .71283 Mdot
.51185 .26175 Mdot
.58649 .43338 Mdot
.6536 .73456 Mdot
.58455 .43712 Mdot
.75545 .55378 Mdot
.61392 .51874 Mdot
.46086 .65002 Mdot
.59499 .42758 Mdot
.54593 .66448 Mdot
.57257 .4322 Mdot
.59983 .5047 Mdot
.47797 .66269 Mdot
.57209 .41008 Mdot
.47636 .65044 Mdot
.57613 .48793 Mdot
.54675 .68031 Mdot
.47477 .62944 Mdot
.63214 .61207 Mdot
.42015 .49788 Mdot
.33928 .62501 Mdot
.58693 .70245 Mdot
.59744 .71885 Mdot
.57668 .62629 Mdot
.43675 .32133 Mdot
.50346 .39214 Mdot
.60122 .44814 Mdot
.46333 .66639 Mdot
.34041 .46389 Mdot
.62712 .48131 Mdot
.59354 .51388 Mdot
.62485 .4237 Mdot
.47436 .36229 Mdot
.40995 .62961 Mdot
.57239 .72133 Mdot
.43915 .6196 Mdot
.51934 .74086 Mdot
.4783 .61015 Mdot
.56838 .5147 Mdot
.66982 .49633 Mdot
.73645 .42281 Mdot
.43128 .2299 Mdot
.20809 .37973 Mdot
.46074 .35842 Mdot
.34714 .61612 Mdot
.59035 .74461 Mdot
.7118 .42805 Mdot
.43914 .32618 Mdot
.47367 .66074 Mdot
.59535 .44092 Mdot
.66436 .43195 Mdot
.28861 .43818 Mdot
.47138 .27611 Mdot
.63383 .65555 Mdot
.45743 .60843 Mdot
.35298 .62774 Mdot
.23283 .4413 Mdot
.56924 .3833 Mdot
.52076 .55928 Mdot
.59357 .47268 Mdot
.57607 .68923 Mdot
.44506 .36257 Mdot
.39458 .74778 Mdot
.33158 .48206 Mdot
.47567 .48747 Mdot
.59521 .45437 Mdot
.24524 .44893 Mdot
.46263 .3355 Mdot
.59125 .73206 Mdot
.34291 .48135 Mdot
.56372 .7407 Mdot
.36093 .61283 Mdot
.65082 .77168 Mdot
.64549 .45035 Mdot
.60004 .50208 Mdot
.35317 .42937 Mdot
.47895 .34441 Mdot
.5682 .75448 Mdot
.79247 .57979 Mdot
.45535 .61578 Mdot
.64752 .73791 Mdot
.4926 .36216 Mdot
.67997 .30587 Mdot
.43456 .62205 Mdot
.32869 .4331 Mdot
.56724 .62763 Mdot
.30537 .45399 Mdot
.56958 .45111 Mdot
.45006 .33114 Mdot
.34887 .45597 Mdot
.4882 .73809 Mdot
.78656 .34872 Mdot
.69098 .30555 Mdot
.6176 .42883 Mdot
.68241 .23856 Mdot
.81876 .56186 Mdot
.50028 .41716 Mdot
.30693 .48039 Mdot
.60564 .47657 Mdot
.63533 .5156 Mdot
.62023 .43359 Mdot
.33915 .44413 Mdot
.48916 .7083 Mdot
.46417 .65808 Mdot
.62276 .49713 Mdot
.59483 .73616 Mdot
.47252 .64565 Mdot
.47997 .68429 Mdot
.43738 .65526 Mdot
.42497 .35612 Mdot
.56247 .45917 Mdot
.27471 .40474 Mdot
.8049 .34775 Mdot
.33333 .46455 Mdot
.33956 .62478 Mdot
.62026 .50921 Mdot
.2809 .3028 Mdot
.43801 .33349 Mdot
.45827 .61538 Mdot
.60199 .46725 Mdot
.48989 .71779 Mdot
.39383 .62296 Mdot
.44339 .65695 Mdot
.44883 .31775 Mdot
.48573 .41962 Mdot
.60067 .45372 Mdot
.63745 .44917 Mdot
.47743 .33891 Mdot
.5911 .77963 Mdot
.19737 .51912 Mdot
.58881 .48593 Mdot
.31876 .46331 Mdot
.3709 .83569 Mdot
.65596 .45158 Mdot
.52483 .36464 Mdot
.37746 .62379 Mdot
.30692 .36287 Mdot
.53847 .23319 Mdot
.68823 .41515 Mdot
.7353 .31793 Mdot
.54728 .59395 Mdot
.66834 .21727 Mdot
.52545 .70047 Mdot
.39074 .55758 Mdot
.70111 .23389 Mdot
.33821 .49576 Mdot
.52722 .52537 Mdot
.72389 .50185 Mdot
.20783 .55197 Mdot
.49676 .45714 Mdot
.54114 .7998 Mdot
.48745 .75699 Mdot
.48114 .57269 Mdot
.43693 .63922 Mdot
.74577 .54424 Mdot
.5793 .48674 Mdot
.81724 .57031 Mdot
.58772 .23707 Mdot
.22422 .67753 Mdot
.69638 .24842 Mdot
.70899 .69353 Mdot
.62387 .21417 Mdot
.79394 .39731 Mdot
.74144 .43154 Mdot
.40403 .26339 Mdot
.51624 .84471 Mdot
.22306 .42446 Mdot
.72711 .68782 Mdot
.60212 .54097 Mdot
.51856 .59223 Mdot
.75201 .68025 Mdot
.66611 .32545 Mdot
.27049 .74457 Mdot
.42187 .64437 Mdot
.44035 .37362 Mdot
.71886 .51909 Mdot
.50161 .32809 Mdot
.38977 .45033 Mdot
.73296 .3126 Mdot
.8207 .43678 Mdot
.63894 .26358 Mdot
.70151 .76912 Mdot
.53699 .32 Mdot
.17771 .39607 Mdot
.41631 .52307 Mdot
.4541 .38025 Mdot
.44705 .82043 Mdot
.22615 .41179 Mdot
.36318 .28561 Mdot
.7098 .46255 Mdot
.46407 .69039 Mdot
.66028 .62717 Mdot
.46083 .32582 Mdot
.53687 .22548 Mdot
.35606 .60947 Mdot
.37814 .25821 Mdot
.53207 .66066 Mdot
.77144 .35021 Mdot
.48769 .5642 Mdot
.27653 .37552 Mdot
.25332 .58273 Mdot
.42836 .14958 Mdot
.72348 .65175 Mdot
.79193 .4647 Mdot
.317 .42285 Mdot
.49788 .44601 Mdot
.22694 .62007 Mdot
.6947 .64963 Mdot
.22579 .40368 Mdot
.42833 .1836 Mdot
.80555 .62164 Mdot
.48338 .15893 Mdot
.5095 .37386 Mdot
.62178 .42341 Mdot
.77555 .44258 Mdot
.61059 .37074 Mdot
.60637 .73808 Mdot
.53936 .16854 Mdot
.55905 .68625 Mdot
.5084 .35538 Mdot
.21718 .5611 Mdot
.6532 .28677 Mdot
.64558 .72524 Mdot
.55479 .74023 Mdot
.54611 .47485 Mdot
.11431 .52948 Mdot
.65795 .21551 Mdot
.33538 .3458 Mdot
.833 .47983 Mdot
.25638 .47552 Mdot
.66903 .70781 Mdot
.34502 .45175 Mdot
.75981 .28953 Mdot
.44875 .32279 Mdot
.74509 .24451 Mdot
.78046 .32633 Mdot
.2944 .72713 Mdot
.21827 .74841 Mdot
.29795 .55934 Mdot
.63867 .56293 Mdot
.55936 .59555 Mdot
.62311 .6317 Mdot
.22961 .65986 Mdot
.30662 .74571 Mdot
.25305 .47327 Mdot
.71792 .73127 Mdot
.72506 .26105 Mdot
.75764 .58743 Mdot
.6776 .74312 Mdot
.21708 .58075 Mdot
.42975 .49377 Mdot
.46342 .39155 Mdot
.40882 .47877 Mdot
.41411 .26055 Mdot
.52462 .16618 Mdot
.56989 .37791 Mdot
.30083 .7998 Mdot
.53478 .68597 Mdot
.37933 .60497 Mdot
.82179 .50535 Mdot
.64449 .60501 Mdot
.72536 .43077 Mdot
.22248 .46774 Mdot
.54716 .49029 Mdot
.22485 .45348 Mdot
.40445 .38623 Mdot
.32923 .66417 Mdot
.22834 .44296 Mdot
.34812 .39598 Mdot
.78172 .59952 Mdot
.7571 .4071 Mdot
.23631 .36373 Mdot
.41935 .34196 Mdot
.67136 .6645 Mdot
.73596 .63657 Mdot
.83089 .489 Mdot
.27497 .63813 Mdot
.82551 .63461 Mdot
.27812 .65618 Mdot
.57697 .41675 Mdot
.65421 .41154 Mdot
.60742 .54547 Mdot
.70313 .65635 Mdot
.63649 .42634 Mdot
.24357 .45243 Mdot
.83701 .5081 Mdot
.55335 .36958 Mdot
.36012 .67695 Mdot
.39435 .21486 Mdot
.81345 .63568 Mdot
.77034 .46433 Mdot
.33923 .58693 Mdot
.51813 .43516 Mdot
.22155 .31562 Mdot
.46768 .63824 Mdot
.75584 .60383 Mdot
.29404 .47828 Mdot
.42985 .75878 Mdot
.71414 .31312 Mdot
.28738 .71687 Mdot
.83907 .5116 Mdot
.20449 .51694 Mdot
.33843 .71938 Mdot
.56038 .64412 Mdot
.6383 .72753 Mdot
.41942 .21278 Mdot
.68157 .46304 Mdot
.68985 .51479 Mdot
.5898 .69725 Mdot
.64939 .36292 Mdot
.76183 .50745 Mdot
.46491 .79768 Mdot
.65754 .41817 Mdot
.37314 .77803 Mdot
.35415 .63011 Mdot
.47113 .48583 Mdot
.5479 .13356 Mdot
.55496 .51113 Mdot
.30483 .57058 Mdot
.79905 .63284 Mdot
.66543 .68458 Mdot
.80977 .48847 Mdot
.2965 .40108 Mdot
.4706 .16659 Mdot
.80183 .35901 Mdot
.45912 .78473 Mdot
.62635 .18722 Mdot
.85763 .5562 Mdot
.44004 .17083 Mdot
.47277 .23718 Mdot
.34685 .49604 Mdot
.68544 .16921 Mdot
.48739 .63261 Mdot
.35312 .23218 Mdot
.59577 .36946 Mdot
.44838 .7162 Mdot
.4562 .2922 Mdot
.53103 .49127 Mdot
.48743 .57197 Mdot
.44698 .27674 Mdot
.60508 .53051 Mdot
.47106 .14141 Mdot
.38663 .19727 Mdot
.48364 .14604 Mdot
.77574 .67986 Mdot
.63752 .19308 Mdot
.65243 .56716 Mdot
.66927 .31195 Mdot
.72756 .53229 Mdot
.58269 .50046 Mdot
.7293 .58364 Mdot
.29491 .56311 Mdot
.38276 .75797 Mdot
.35216 .28401 Mdot
.48305 .3021 Mdot
.53859 .18071 Mdot
.44552 .11214 Mdot
.54319 .31298 Mdot
.56457 .28112 Mdot
.30007 .52535 Mdot
.72037 .63812 Mdot
.39602 .36431 Mdot
.34679 .74855 Mdot
.82669 .49945 Mdot
.72789 .49648 Mdot
.76108 .61346 Mdot
.4878 .80856 Mdot
.61103 .69102 Mdot
.41542 .59822 Mdot
.77042 .33656 Mdot
.64712 .58166 Mdot
.2932 .70878 Mdot
.53424 .54761 Mdot
.26 .70719 Mdot
.51751 .77991 Mdot
.31368 .64671 Mdot
.73809 .65403 Mdot
.38653 .65091 Mdot
.75023 .5845 Mdot
.45413 .53086 Mdot
.74174 .49495 Mdot
.54733 .59314 Mdot
.75237 .57941 Mdot
.60864 .68864 Mdot
.55371 .16233 Mdot
.85934 .58935 Mdot
.33161 .21656 Mdot
.71603 .75252 Mdot
.4056 .39446 Mdot
.66301 .45568 Mdot
.83673 .5472 Mdot
.52236 .14781 Mdot
.8132 .37673 Mdot
.21926 .51963 Mdot
.48385 .73118 Mdot
.37457 .44812 Mdot
.33143 .22048 Mdot
.5571 .78811 Mdot
.80611 .43252 Mdot
.21146 .37722 Mdot
.28261 .4668 Mdot
.1935 .55181 Mdot
.35536 .2224 Mdot
.68926 .28775 Mdot
.52227 .24268 Mdot
.53925 .49676 Mdot
.61782 .24471 Mdot
.41698 .35433 Mdot
.24928 .58716 Mdot
.70148 .64991 Mdot
.46943 .63439 Mdot
.6285 .59448 Mdot
.70349 .49991 Mdot
.54582 .47085 Mdot
.48044 .59621 Mdot
.40641 .33313 Mdot
.42729 .23387 Mdot
.34018 .40323 Mdot
.66894 .19848 Mdot
.28491 .57774 Mdot
.68706 .50383 Mdot
.68392 .67748 Mdot
.36142 .72338 Mdot
.21589 .47096 Mdot
.31794 .49358 Mdot
.7285 .27931 Mdot
.40053 .46211 Mdot
.67602 .66625 Mdot
.59994 .23467 Mdot
.78486 .55514 Mdot
.66734 .49851 Mdot
.34984 .35906 Mdot
.7046 .37368 Mdot
.48266 .50125 Mdot
.5024 .36449 Mdot
.40918 .36231 Mdot
.76187 .74593 Mdot
.2802 .52617 Mdot
.29021 .63167 Mdot
.73819 .29112 Mdot
.3182 .44574 Mdot
.48983 .33035 Mdot
.74234 .56972 Mdot
.78403 .60581 Mdot
.68198 .35241 Mdot
.40258 .62801 Mdot
.43768 .68723 Mdot
.49339 .79495 Mdot
.68816 .24676 Mdot
.6455 .2218 Mdot
.21853 .67511 Mdot
.47595 .30044 Mdot
.7871 .5302 Mdot
.76746 .62353 Mdot
.48272 .35873 Mdot
.5058 .32872 Mdot
.36032 .26114 Mdot
.60974 .16921 Mdot
.25562 .42119 Mdot
.70245 .75629 Mdot
.59775 .64934 Mdot
.49621 .7122 Mdot
.37912 .73197 Mdot
.70444 .71256 Mdot
.74353 .29903 Mdot
.5268 .22012 Mdot
.66758 .26013 Mdot
.67083 .51702 Mdot
.47792 .26542 Mdot
.31428 .22773 Mdot
.42761 .51389 Mdot
.67411 .29772 Mdot
.37965 .40267 Mdot
.62793 .43387 Mdot
.43041 .1493 Mdot
.80466 .58704 Mdot
.20702 .45333 Mdot
.3216 .50593 Mdot
.64133 .46701 Mdot
.61797 .41602 Mdot
.51636 .4191 Mdot
.32439 .35827 Mdot
.39915 .20178 Mdot
.70726 .71163 Mdot
.43915 .41467 Mdot
.58101 .23214 Mdot
.3047 .57184 Mdot
.7714 .35786 Mdot
.8204 .53893 Mdot
.47478 .51875 Mdot
.28937 .56526 Mdot
.55581 .62926 Mdot
.73079 .73316 Mdot
.50768 .58354 Mdot
.67636 .55439 Mdot
.29615 .29828 Mdot
.3129 .38025 Mdot
.37234 .73469 Mdot
.62605 .51005 Mdot
.2202 .5611 Mdot
.79003 .39337 Mdot
.24968 .73688 Mdot
.23176 .64452 Mdot
.45449 .13614 Mdot
.72088 .3609 Mdot
.30188 .38655 Mdot
.63053 .22718 Mdot
.24175 .73833 Mdot
.50619 .59073 Mdot
.58188 .18911 Mdot
.55743 .63816 Mdot
.71459 .26794 Mdot
.31064 .49843 Mdot
.25174 .38428 Mdot
.38934 .21722 Mdot
.62298 .17801 Mdot
.7792 .47132 Mdot
.75291 .32136 Mdot
.53414 .55077 Mdot
.57791 .15497 Mdot
.30082 .28726 Mdot
.47942 .57458 Mdot
.48892 .66808 Mdot
.22671 .48931 Mdot
.53172 .19789 Mdot
.38475 .32293 Mdot
.75702 .61003 Mdot
.45163 .58275 Mdot
.71721 .42882 Mdot
.64053 .2442 Mdot
.67481 .59853 Mdot
.32748 .3839 Mdot
.68156 .67885 Mdot
.80307 .40358 Mdot
.46538 .58981 Mdot
.38728 .73046 Mdot
.29896 .59808 Mdot
.6633 .76679 Mdot
.32577 .35326 Mdot
.2753 .52788 Mdot
.79102 .46037 Mdot
.54593 .77534 Mdot
.71691 .68029 Mdot
.83698 .67955 Mdot
.7171 .71522 Mdot
.39799 .25395 Mdot
.51644 .16881 Mdot
.82417 .51649 Mdot
.41354 .24371 Mdot
.2157 .64331 Mdot
.50231 .29314 Mdot
.72526 .60458 Mdot
.58376 .47465 Mdot
.53352 .13628 Mdot
.67161 .62087 Mdot
.52486 .16389 Mdot
.83019 .58703 Mdot
.6167 .24055 Mdot
.54377 .46548 Mdot
.47927 .60604 Mdot
.36804 .54275 Mdot
.68461 .58976 Mdot
.67953 .26497 Mdot
.5101 .30457 Mdot
.33918 .6489 Mdot
.32483 .61419 Mdot
.43744 .60891 Mdot
.46964 .40437 Mdot
.27406 .56029 Mdot
.3292 .37061 Mdot
.60145 .76402 Mdot
.49802 .54986 Mdot
.73298 .62871 Mdot
.54369 .23298 Mdot
.69755 .29794 Mdot
.27736 .71032 Mdot
.39005 .4296 Mdot
.42882 .65012 Mdot
.73909 .34686 Mdot
.73431 .70332 Mdot
.35223 .38869 Mdot
.45368 .1775 Mdot
.21535 .4873 Mdot
.728 .5517 Mdot
.75315 .49469 Mdot
.24743 .68468 Mdot
.54957 .82868 Mdot
.49526 .188 Mdot
.43908 .24501 Mdot
.65432 .72742 Mdot
.70344 .5095 Mdot
.68883 .22419 Mdot
.73479 .6703 Mdot
.75548 .47687 Mdot
.41521 .50903 Mdot
.65063 .3335 Mdot
.60029 .22648 Mdot
.61862 .61118 Mdot
.51276 .54463 Mdot
.18265 .37271 Mdot
.44951 .28505 Mdot
.41312 .15001 Mdot
.32253 .48316 Mdot
.1767 .49046 Mdot
.61403 .70776 Mdot
.45185 .52293 Mdot
.51468 .54079 Mdot
.35029 .35058 Mdot
.31283 .29879 Mdot
.75185 .70195 Mdot
.28102 .73286 Mdot
.48772 .61565 Mdot
.67823 .72528 Mdot
.63649 .78179 Mdot
.73154 .32089 Mdot
.58707 .52159 Mdot
.70883 .72849 Mdot
.4284 .50909 Mdot
.37963 .75542 Mdot
.83009 .55816 Mdot
.3779 .36443 Mdot
.68836 .45983 Mdot
.71638 .64043 Mdot
.5794 .19036 Mdot
.79094 .34689 Mdot
.18671 .5799 Mdot
.4046 .38689 Mdot
.36136 .48218 Mdot
.59909 .58024 Mdot
.69827 .26446 Mdot
.65209 .69939 Mdot
.26511 .38782 Mdot
.73084 .64679 Mdot
.31455 .20223 Mdot
.41762 .19552 Mdot
.398 .20263 Mdot
.67693 .69483 Mdot
.49945 .33303 Mdot
.34404 .25329 Mdot
.75278 .48502 Mdot
.37079 .35249 Mdot
.7635 .67006 Mdot
.75033 .6113 Mdot
.18705 .64898 Mdot
.72406 .41794 Mdot
.52243 .74153 Mdot
.57225 .2144 Mdot
.62346 .36654 Mdot
.33149 .50321 Mdot
.71309 .60387 Mdot
.39569 .40633 Mdot
.36905 .43758 Mdot
.33103 .38039 Mdot
.29061 .35921 Mdot
.75618 .47342 Mdot
.68713 .34572 Mdot
.41691 .40634 Mdot
.75662 .37936 Mdot
.46237 .27969 Mdot
.39564 .74732 Mdot
.37165 .72041 Mdot
.46925 .4383 Mdot
.47209 .62081 Mdot
.6907 .41791 Mdot
.48809 .51728 Mdot
.5391 .61153 Mdot
.2943 .25712 Mdot
.56472 .68445 Mdot
.49052 .31644 Mdot
.19081 .45028 Mdot
.48354 .3617 Mdot
.49688 .13508 Mdot
.33819 .74084 Mdot
.60021 .23689 Mdot
.47626 .78088 Mdot
.45487 .81378 Mdot
.14006 .49068 Mdot
.4631 .22166 Mdot
.40772 .50104 Mdot
.42132 .26926 Mdot
.42812 .30703 Mdot
.36289 .65066 Mdot
.32788 .61431 Mdot
.53056 .251 Mdot
.32338 .56617 Mdot
.72719 .54123 Mdot
.46885 .38341 Mdot
.51981 .72646 Mdot
.66218 .39267 Mdot
.62646 .17583 Mdot
.43302 .64321 Mdot
.22552 .29752 Mdot
.62246 .41105 Mdot
.74404 .4103 Mdot
.84451 .52891 Mdot
.1869 .56202 Mdot
.32583 .69841 Mdot
.58057 .81319 Mdot
.56435 .43212 Mdot
.4187 .40433 Mdot
.46024 .32265 Mdot
.76877 .53253 Mdot
.58253 .71858 Mdot
.64767 .66026 Mdot
.32329 .43046 Mdot
.29907 .71131 Mdot
.27071 .56597 Mdot
.49877 .35835 Mdot
.38721 .36405 Mdot
.77208 .48819 Mdot
.2624 .35818 Mdot
.42985 .50638 Mdot
.72702 .319 Mdot
.67796 .34536 Mdot
.46334 .38362 Mdot
.44952 .18743 Mdot
.76047 .63039 Mdot
.76348 .28769 Mdot
.56683 .54418 Mdot
.40483 .53505 Mdot
.24992 .35935 Mdot
.34737 .37279 Mdot
.53403 .23679 Mdot
.82628 .4953 Mdot
.68329 .65852 Mdot
.23562 .39923 Mdot
.74998 .57812 Mdot
.53397 .43471 Mdot
.47953 .55176 Mdot
.23664 .55599 Mdot
.166 .59979 Mdot
.48655 .25328 Mdot
.2103 .59683 Mdot
.42097 .26236 Mdot
.30343 .56962 Mdot
.44841 .27956 Mdot
.4034 .71741 Mdot
.66748 .33112 Mdot
.30266 .66701 Mdot
.72049 .24655 Mdot
.829 .5007 Mdot
.28079 .45443 Mdot
.43088 .67842 Mdot
.50394 .49561 Mdot
.64446 .53669 Mdot
.47129 .46841 Mdot
.59044 .4239 Mdot
.50941 .40391 Mdot
.18555 .54001 Mdot
.36418 .35666 Mdot
.53182 .48703 Mdot
.67865 .22181 Mdot
.77025 .29769 Mdot
.56966 .15599 Mdot
.64516 .73602 Mdot
.45164 .37019 Mdot
.447 .16359 Mdot
.57053 .25821 Mdot
.80389 .39754 Mdot
.48673 .194 Mdot
.78353 .72295 Mdot
.67832 .26719 Mdot
.3725 .40181 Mdot
.30007 .73822 Mdot
.31596 .30994 Mdot
.81879 .58069 Mdot
.47813 .57691 Mdot
.36299 .66708 Mdot
.81954 .58819 Mdot
.1189 .51236 Mdot
.46335 .23493 Mdot
.28342 .36802 Mdot
.70704 .51471 Mdot
.4529 .42828 Mdot
.36216 .56952 Mdot
.58557 .50018 Mdot
.43643 .67316 Mdot
.34527 .72335 Mdot
.73846 .62568 Mdot
.73246 .45015 Mdot
.36264 .57142 Mdot
.69064 .58437 Mdot
.75605 .54269 Mdot
.72364 .69448 Mdot
.70064 .29229 Mdot
.53395 .24812 Mdot
.68772 .46946 Mdot
.48416 .29559 Mdot
.56414 .73655 Mdot
.33245 .67731 Mdot
.56643 .47398 Mdot
.3111 .67337 Mdot
.28618 .32479 Mdot
.45744 .13971 Mdot
.38076 .69962 Mdot
.79456 .59439 Mdot
.41986 .29744 Mdot
.33382 .35832 Mdot
.77146 .39732 Mdot
.2104 .55306 Mdot
.38203 .57898 Mdot
.57322 .37702 Mdot
.67005 .22482 Mdot
.23279 .45109 Mdot
.77945 .58463 Mdot
.25644 .30916 Mdot
.36467 .44108 Mdot
.46502 .25006 Mdot
.70282 .52787 Mdot
.21207 .51195 Mdot
.49172 .3821 Mdot
.33198 .39834 Mdot
.41995 .55317 Mdot
.23253 .45853 Mdot
.80023 .63358 Mdot
.77923 .51826 Mdot
.55273 .21009 Mdot
.65233 .22325 Mdot
.4385 .66954 Mdot
.76316 .60963 Mdot
.33124 .40069 Mdot
.39278 .56704 Mdot
.23744 .36997 Mdot
.67139 .20549 Mdot
.48119 .48329 Mdot
.6533 .62268 Mdot
.63865 .44594 Mdot
.60063 .28107 Mdot
.35925 .34822 Mdot
.57824 .6668 Mdot
.29007 .61825 Mdot
.42426 .32592 Mdot
.26765 .58702 Mdot
.41657 .61019 Mdot
.70951 .61566 Mdot
.40655 .29316 Mdot
.5303 .35764 Mdot
.6018 .70747 Mdot
.34502 .64152 Mdot
.6372 .52459 Mdot
.64456 .63289 Mdot
.6411 .71639 Mdot
.46639 .24649 Mdot
.44935 .22659 Mdot
.73124 .32596 Mdot
.78158 .62165 Mdot
.36427 .38255 Mdot
.48402 .1922 Mdot
.32176 .29227 Mdot
.68632 .32495 Mdot
.24362 .60937 Mdot
.63057 .42559 Mdot
.40716 .7177 Mdot
.49288 .33763 Mdot
.70648 .2801 Mdot
.71822 .36562 Mdot
.63388 .61112 Mdot
.45212 .49697 Mdot
.77795 .4131 Mdot
.43367 .47138 Mdot
.84107 .5367 Mdot
.31884 .30819 Mdot
.69985 .64988 Mdot
.28777 .46742 Mdot
.57068 .6465 Mdot
.23986 .66875 Mdot
.75848 .29611 Mdot
.28249 .71806 Mdot
.54315 .57335 Mdot
.20405 .58339 Mdot
.38725 .24093 Mdot
.82647 .58485 Mdot
.71042 .63325 Mdot
.46906 .46694 Mdot
.65154 .39009 Mdot
.29738 .42925 Mdot
.34165 .63457 Mdot
.42546 .7267 Mdot
.54906 .25646 Mdot
.44538 .70112 Mdot
.30892 .68513 Mdot
.64178 .52653 Mdot
.25806 .32505 Mdot
.65894 .22306 Mdot
.71061 .41236 Mdot
.43967 .52282 Mdot
.42365 .7669 Mdot
.69693 .62408 Mdot
.61632 .85129 Mdot
.42908 .14862 Mdot
.64118 .44808 Mdot
.54186 .59107 Mdot
.65613 .65277 Mdot
.46222 .61067 Mdot
.53611 .26746 Mdot
.7262 .31239 Mdot
.30536 .47372 Mdot
.47184 .73332 Mdot
.23611 .46796 Mdot
.35247 .34031 Mdot
.61571 .60242 Mdot
.30596 .51841 Mdot
.47754 .13423 Mdot
.73757 .70633 Mdot
.35748 .36819 Mdot
.67819 .81353 Mdot
.22458 .54675 Mdot
.39979 .34366 Mdot
.78205 .45393 Mdot
.55622 .16167 Mdot
.67042 .68648 Mdot
.43879 .7567 Mdot
.43007 .22061 Mdot
.69288 .65177 Mdot
.7621 .55911 Mdot
.2986 .59745 Mdot
.27335 .59393 Mdot
.46022 .55838 Mdot
.4574 .81386 Mdot
.31187 .25524 Mdot
.55063 .222 Mdot
.61968 .20332 Mdot
.3168 .7126 Mdot
.19527 .66384 Mdot
.75937 .2889 Mdot
.71569 .58759 Mdot
.35209 .57486 Mdot
.78809 .46956 Mdot
.61636 .6519 Mdot
.5605 .37868 Mdot
.33328 .73177 Mdot
.67031 .35359 Mdot
.42674 .80247 Mdot
.25152 .64071 Mdot
.75092 .5823 Mdot
.59842 .36602 Mdot
.48672 .49197 Mdot
.72719 .32965 Mdot
.30267 .62554 Mdot
.69327 .68103 Mdot
.47694 .74184 Mdot
.60144 .63317 Mdot
.74333 .34434 Mdot
.79118 .43417 Mdot
.4745 .46257 Mdot
.12324 .50169 Mdot
.5405 .17375 Mdot
.21928 .57577 Mdot
.65412 .43836 Mdot
.71156 .23457 Mdot
.45635 .4411 Mdot
.4719 .19541 Mdot
.79089 .63185 Mdot
.36893 .71052 Mdot
.25772 .34715 Mdot
.62021 .42244 Mdot
.46562 .21263 Mdot
.67281 .29338 Mdot
.61691 .36486 Mdot
.35217 .72847 Mdot
.68398 .67491 Mdot
.33931 .59842 Mdot
.6028 .61565 Mdot
.62825 .54779 Mdot
.49403 .35647 Mdot
.49841 .14351 Mdot
.56889 .57283 Mdot
.65312 .39758 Mdot
.51713 .4896 Mdot
.28265 .7268 Mdot
.62694 .82016 Mdot
.60722 .54888 Mdot
.23318 .44664 Mdot
.75383 .61364 Mdot
.73985 .51735 Mdot
.462 .228 Mdot
.26403 .8024 Mdot
.84648 .51516 Mdot
.43091 .29821 Mdot
.51501 .30452 Mdot
.68359 .70169 Mdot
.58108 .16335 Mdot
.49018 .80738 Mdot
.36056 .71835 Mdot
.29696 .76603 Mdot
.62931 .66662 Mdot
.59263 .51232 Mdot
.79683 .65276 Mdot
.76397 .30427 Mdot
.30346 .70964 Mdot
.69547 .23263 Mdot
.54139 .46937 Mdot
.64157 .42239 Mdot
.44068 .88667 Mdot
.7154 .27783 Mdot
.54498 .48687 Mdot
.26578 .71744 Mdot
.4762 .39154 Mdot
.57574 .47887 Mdot
.32076 .55406 Mdot
.73279 .66774 Mdot
.75823 .54974 Mdot
.62128 .17721 Mdot
.50089 .35983 Mdot
.31292 .67895 Mdot
.3095 .44121 Mdot
.5151 .54349 Mdot
.66986 .43831 Mdot
.3463 .4478 Mdot
.73448 .55201 Mdot
.46985 .44405 Mdot
.29493 .49686 Mdot
.68131 .73417 Mdot
.8202 .64982 Mdot
.7176 .34835 Mdot
.27466 .46252 Mdot
.52655 .42106 Mdot
.71187 .40768 Mdot
.68806 .58753 Mdot
.70299 .55531 Mdot
.81306 .61013 Mdot
.88315 .49971 Mdot
.38092 .67388 Mdot
.53524 .51693 Mdot
.40169 .30866 Mdot
.54267 .2455 Mdot
.67455 .27687 Mdot
.35108 .50256 Mdot
.34414 .61258 Mdot
.56196 .42385 Mdot
.62432 .54898 Mdot
.31463 .43296 Mdot
.36589 .17675 Mdot
.60326 .50988 Mdot
.50401 .22035 Mdot
.79615 .38418 Mdot
.39205 .7457 Mdot
.73698 .40987 Mdot
.55344 .45697 Mdot
.33003 .26422 Mdot
.4492 .43789 Mdot
.48497 .42467 Mdot
.37762 .72789 Mdot
.60995 .18499 Mdot
.72021 .36965 Mdot
.53912 .21097 Mdot
.62948 .48944 Mdot
.54274 .68962 Mdot
.2761 .36372 Mdot
.43796 .21067 Mdot
.68534 .51247 Mdot
.80359 .37871 Mdot
.37512 .71451 Mdot
.46015 .70029 Mdot
.7314 .47102 Mdot
.51227 .15764 Mdot
.2318 .63202 Mdot
.64913 .25939 Mdot
.20095 .47514 Mdot
.24963 .51685 Mdot
.67688 .59927 Mdot
.47681 .6057 Mdot
.53097 .4874 Mdot
.47837 .38923 Mdot
.51221 .12268 Mdot
.43167 .21203 Mdot
.29696 .41806 Mdot
.33491 .65412 Mdot
.63707 .28243 Mdot
.50269 .51354 Mdot
.73405 .77718 Mdot
.54529 .79876 Mdot
.47164 .13395 Mdot
.76784 .52307 Mdot
.4246 .39009 Mdot
.31074 .39235 Mdot
.66882 .42285 Mdot
.44553 .65587 Mdot
.59053 .17019 Mdot
.59915 .55294 Mdot
.25423 .63044 Mdot
.59515 .51193 Mdot
.20668 .43773 Mdot
.4086 .42279 Mdot
.41611 .67008 Mdot
.39735 .65571 Mdot
.21938 .64563 Mdot
.78637 .39903 Mdot
.44228 .43868 Mdot
.72177 .77247 Mdot
.64684 .2335 Mdot
.73052 .28084 Mdot
.40958 .6235 Mdot
.17228 .55974 Mdot
.39438 .28652 Mdot
.39966 .40203 Mdot
.34586 .40443 Mdot
.56707 .60018 Mdot
.21793 .49272 Mdot
.74084 .52568 Mdot
.2946 .33647 Mdot
.28706 .44486 Mdot
.92359 .50807 Mdot
.72816 .57649 Mdot
.70806 .46837 Mdot
.22616 .56819 Mdot
.70763 .25261 Mdot
.61204 .74679 Mdot
.80492 .65672 Mdot
.51937 .59149 Mdot
.66359 .43487 Mdot
.69587 .35652 Mdot
.74069 .44673 Mdot
.23077 .48495 Mdot
.1521 .43114 Mdot
.74549 .69049 Mdot
.41417 .68576 Mdot
.49329 .54389 Mdot
.48445 .3546 Mdot
.45495 .29255 Mdot
.46497 .79268 Mdot
.77141 .70793 Mdot
.43162 .4205 Mdot
.7009 .26638 Mdot
.14429 .51532 Mdot
.7764 .55055 Mdot
.59002 .16396 Mdot
.39043 .28056 Mdot
.49904 .30972 Mdot
.69669 .57934 Mdot
.53536 .7136 Mdot
.39372 .64484 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000;Sooooo0_l0002@ooooo`007?ooool00ol0003oooooooooo`2gooooo`;o0000
T?ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo08gooooo0_l0002jooooo`007?ooool00ol0003o
ooooooooo`2=ooooo`;o00004Oooool2o`000:Oooooo000Looooo`03o`000?oooooooooo0:3ooooo
0_l0002Wooooo`007?ooool00ol0003oooooooooo`2Sooooo`Co0000X_ooool001cooooo00?o0000
ooooooooool0Xoooool4o`000:;ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0W_ooool2o`000:Wooooo000Looooo`03o`000?oooooooooo08kooooo
0_l00005ooooo`Co00001Oooool2o`0000kooooo0_l0002Iooooo`007?ooool00ol0003ooooooooo
o`2>ooooo`Co00000oooool4o`0000Gooooo0_l0000:ooooo`;o00000_ooool2o`0009Wooooo000L
ooooo`03o`000?oooooooooo093ooooo0ol00002ooooo`;o00004oooool2o`0009gooooo000Loooo
o`03o`000?oooooooooo097ooooo0_l00002ooooo`;o00001oooool2o`000:Wooooo000Looooo`03
o`000?oooooooooo08[ooooo0_l0000=ooooo`;o00000oooool2o`000:Wooooo000Looooo`03o`00
0?oooooooooo08;ooooo0_l00003ooooo`Go00003Oooool2o`0000_ooooo0_l0002Qooooo`007?oo
ool2o`0008?ooooo0_l00002ooooo`Co00007?ooool3o`000:3ooooo000Looooo`03o`000?oooooo
oooo08Kooooo0_l0000Mooooo`Co00003?ooool2o`000003ooooool0003o000000?ooooo0_l0002:
ooooo`007?ooool00ol0003oooooooooo`2Iooooo`;o00002?ooool4o`0000kooooo0_l000000ooo
oooo0000o`000003ooooo`;o0000R_ooool001cooooo00?o0000ooooooooool0VOooool2o`0000So
oooo0_l00007ooooo`;o00000_ooool3o`0000Sooooo0_l0002<ooooo`007?ooool00ol0003ooooo
ooooo`2=ooooo`;o00006?ooool2o`0000?ooooo0_l00002ooooo`?o00001_ooool5o`0001cooooo
0_l0001]ooooo`007?ooool00ol0003oooooooooo`2=ooooo`;o00001_ooool2o`0000;ooooo0_l0
0009ooooo`;o000000?oooooo`000?l000000_ooool2o`0000cooooo0_l000000ooooooo0000o`00
0004ooooo`;o00005_ooool3o`0006cooooo000Looooo`03o`000?oooooooooo08_ooooo0_l00007
ooooo`?o00000_ooool2o`0000Wooooo0_l000000ooooooo0000o`000002ooooo`;o00003oooool2
o`0000Cooooo0_l0000Gooooo`;o0000K?ooool001cooooo00?o0000ooooooooool0Roooool2o`00
00Oooooo0ol0000;ooooo`;o00002?ooool2o`0000Sooooo0_l00004ooooo`;o00007_ooool2o`00
06_ooooo000Looooo`03o`000?oooooooooo07?ooooo0_l0000Kooooo`;o00003oooool3o`0000So
oooo0_l00008ooooo`;o00003_ooool4o`0001;ooooo0_l0001[ooooo`007?ooool00ol0003ooooo
ooooo`1cooooo`;o00006oooool2o`0000oooooo0_l00008ooooo`;o00005?ooool2o`0000?ooooo
1?l0001oooooo`007?ooool00ol0003oooooooooo`27ooooo`;o00002oooool2o`0000;ooooo0_l0
0007ooooo`;o00002?ooool2o`0001Cooooo0_l00026ooooo`007?ooool00ol0003oooooooooo`27
ooooo`;o00001Oooool2o`0000Cooooo0_l00002ooooo`;o00000_ooool2o`0001kooooo0_l00004
ooooo`;o00001?ooool2o`0007oooooo000Looooo`03o`000?oooooooooo08kooooo0_l0000<oooo
o`?o000000?oooooo`000?l000005_ooool3o`000003ooooool0003o000000?ooooo0ol00004oooo
o`;o0000Ooooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006
ooooo`03o`000?oooooooooo09Oooooo1?l00002ooooo`Go00003?ooool2o`0000Sooooo0ol00006
ooooo`;o00002?ooool2o`0007cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ
8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1/ooooo`;o0000
5_ooool2o`00013ooooo1_l00002ooooo`;o00003_ooool2o`0001Oooooo0_l00002ooooo`;o0000
O?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^
kP07ooooo`03o`000?oooooooooo06cooooo0_l00009ooooo`;o000000?oooooo`000?l000002?oo
ool2o`00013ooooo0_l00002ooooo`;o000000?oooooo`000?l000002_ooool2o`0000;ooooo0_l0
0004ooooo`;o00000_ooool2o`0000Sooooo0_l00004ooooo`;o00003?ooool2o`0007;ooooo0000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3
o`0006;ooooo0_l0000Cooooo`;o000000?oooooo`000?l000000_ooool2o`0001gooooo0_l0000:
ooooo`;o00000_ooool2o`0000Cooooo0_l00002ooooo`;o00002?ooool2o`0001;ooooo0_l0001b
ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo
00Gooooo00?o0000ooooooooool0H_ooool2o`0000cooooo0_l0000<ooooo`;o0000A_ooool2o`00
00Sooooo0_l00004ooooo`;o0000LOooool00003ooooool@413ooooo00;ooooo00?o410@oooooooo
ool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06gooooo0_l000000ooooooo
0000o`00000Aooooo`;o00004?ooool2o`0001oooooo0ol0000=ooooo`;o00002?ooool2o`0000Co
oooo0_l0001aooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001_ooool00ol0003oooooooooo`1]ooooo`;o00005?ooool2o`0000?ooooo1Ol00007
ooooo`?o00004Oooool2o`000003ooooool0003o000000?ooooo0_l00004ooooo`?o00006Oooool2
o`0007Gooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c006ooooo`03o`000?oooooooooo07Kooooo0_l00004ooooo`;o00001_ooool2o`0000;ooooo
1_l00002ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000oooooo0_l000000ooooooo
0000o`000003ooooo`;o00001?ooool2o`0000oooooo0_l00009ooooo`Ko0000LOooool001cooooo
00?o0000ooooooooool0J?ooool2o`0000cooooo0_l00003ooooo`?o00001_ooool2o`0000Kooooo
0_l00002ooooo`Go00000_ooool2o`0001Oooooo0_l00004ooooo`;o00002?ooool2o`0000Gooooo
0_l00009ooooo`Ko0000LOooool001cooooo00?o0000ooooooooool0J?ooool4o`0000Sooooo0_l0
0002ooooo`;o000000?oooooo`000?l000002oooool2o`0000Sooooo0_l0000<ooooo`;o00001Ooo
ool2o`0000kooooo0_l00007ooooo`;o000000?oooooo`000?l000003Oooool2o`000003ooooool0
003o000007;ooooo000Looooo`03o`000?oooooooooo06Gooooo0_l000000ooooooo0000o`000002
o`0000Cooooo0_l00002ooooo`;o00000_ooool2o`0000kooooo0_l00009ooooo`;o00002oooool2
o`0000Gooooo0_l00006ooooo`;o00001_ooool2o`0000[ooooo0_l00009ooooo`Ko00001Oooool2
o`000003ooooool0003o000006_ooooo000Looooo`03o`000?oooooooooo06;ooooo0_l000000ooo
oooo0000o`000008ooooo`?o00001_ooool2o`0001Cooooo0_l000000ooooooo0000o`000002o`00
01Kooooo0_l00002ooooo`Co00003?ooool2o`0000Oooooo0ol00003ooooo`Ko00000_ooool2o`00
0004ooooool0003o0000ooooo`;o0000Joooool001cooooo00?o0000ooooooooool0H_ooool2o`00
00[ooooo0ol00006ooooo`;o00003oooool2o`0000Cooooo0_l000001?oooooo0000o`000?l0000E
ooooo`Co00001?ooool2o`0000cooooo0_l00006ooooo`Co00002oooool2o`0000Gooooo0_l0001Z
ooooo`007?ooool00ol0003oooooooooo`1^ooooo`?o00001_ooool2o`0000kooooo0ol00008oooo
o`;o00005Oooool6o`0000;ooooo0ol00002ooooo`;o000000?oooooo`000?l000003?ooool2o`00
00Gooooo0_l0000=ooooo`Go00003oooool2o`0005Kooooo000Looooo`03o`000?oooooooooo05[o
oooo0_l0000Cooooo`;o00002Oooool2o`0000_ooooo0ol00009ooooo`;o00005Oooool5o`0000;o
oooo0ol00002ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00003Oooool2o`0000ko
oooo1?l000000ooooooo0000o`00000<ooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0
Coooool2o`0000Wooooo0_l0000Nooooo`Co00001Oooool2o`0000?ooooo0_l00009ooooo`;o0000
00?oooooo`000?l000004?ooool4o`000003ooooool0003o000000?ooooo0_l00003ooooo`;o0000
0_ooool2o`0000;ooooo0_l0000Iooooo`;o00000_ooool2o`0000?ooooo0_l0001Tooooo`007?oo
ool00ol0003oooooooooo`1?ooooo`;o00001Oooool2o`0000Sooooo0_l0000Cooooo`;o00000ooo
ool4o`0000Gooooo0_l0000Aooooo`;o00003_ooool4o`0000;ooooo0_l00004ooooo`?o00000_oo
ool2o`0000;ooooo0_l00008ooooo`;o00003?ooool2o`0000Gooooo1_l0001Yooooo`007?ooool0
0ol0003oooooooooo`1Fooooo`;o00002?ooool2o`0000_ooooo0_l00006ooooo`;o00000oooool2
o`0000Oooooo0_l00006ooooo`;o00006Oooool2o`0000Cooooo0ol00003ooooo`?o00004?ooool3
o`0000Cooooo0_l00005ooooo`;o00001oooool2o`00013ooooo0_l0001Iooooo`007?ooool00ol0
003oooooooooo`1]ooooo`?o00002?ooool4o`0000Oooooo0_l00006ooooo`;o00001oooool2o`00
01Cooooo0_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000003_ooool3o`00
00Cooooo0_l0000>ooooo`Co00001_ooool2o`0000Kooooo0_l0001Iooooo`007?ooool2o`0006oo
oooo0_l00008ooooo`Co00005oooool3o`0000Wooooo0ol00007ooooo`?o00000oooool2o`0000Co
oooo0_l0000>ooooo`?o00005?ooool4o`0000Kooooo0_l0001Qooooo`007?ooool00ol0003ooooo
ooooo`1Rooooo`;o00000_ooool2o`0000Cooooo0ol0000?ooooo`;o00004oooool3o`0000Cooooo
0_l00003ooooo`?o00001oooool2o`0000Cooooo0_l0000Aooooo`Ko00005_ooool2o`0000;ooooo
0_l0000Cooooo`;o0000D?ooool001cooooo00?o0000ooooooooool0G?ooool2o`0000Cooooo0_l0
0002ooooo`;o00001?ooool3o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`00
0005ooooo`;o00006?ooool4o`0001?ooooo0_l00005ooooo`;o00001Oooool2o`0000?ooooo1_l0
000=ooooo`;o00001oooool2o`0000;ooooo0_l0000Cooooo`;o0000D?ooool001cooooo00?o0000
ooooooooool0G?ooool2o`0000Cooooo0_l00006ooooo`;o00001?ooool3o`000004ooooool0003o
0000ooooo`;o00002_ooool2o`000003ooooool0003o000000Oooooo0_l00007ooooo`;o00005?oo
ool3o`0000Gooooo0_l00005ooooo`;o00000_ooool2o`0000cooooo0_l00002ooooo`Co00004Ooo
ool2o`0005oooooo000Looooo`03o`000?oooooooooo05[ooooo0_l0000;ooooo`;o000000?ooooo
o`000?l000001Oooool2o`0000Gooooo0ol00005ooooo`;o000000?oooooo`000?l000000ol00006
ooooo`Ko00001?ooool2o`0000Cooooo0_l00003ooooo`;o00002Oooool2o`0000[ooooo0_l00005
ooooo`;o00000oooool2o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`Co00002?ooool2
o`0000Oooooo0_l0001Oooooo`007?ooool00ol0003oooooooooo`1Jooooo`;o00000_ooool2o`00
00?ooooo0_l00002ooooo`;o00003oooool3o`0000Gooooo0_l00003ooooo`;o00001oooool6o`00
00?ooooo0_l00005ooooo`?o00000_ooool2o`0000Gooooo0_l00004ooooo`;o00002?ooool2o`00
00[ooooo1?l00002ooooo`Co00002Oooool2o`0000Cooooo0ol0001Wooooo`007?ooool00ol0003o
ooooooooo`1Mooooo`?o00000oooool2o`0001cooooo0_l000001Ooooooo0000o`000?l0003ooooo
00;o00002oooool4o`0000Kooooo0_l00009ooooo`;o00000oooool3o`0001?ooooo0_l000000ooo
oooo0000o`000004ooooo`;o00002Oooool2o`0000Gooooo0_l00002ooooo`;o00005Oooool2o`00
04cooooo000Looooo`03o`000?oooooooooo05gooooo0_l00002ooooo`;o00007_ooool2o`000003
ooooool0003o000000Co00002oooool2o`0000Kooooo0_l0000@ooooo`;o00000oooool2o`0000ko
oooo0ol000000ooooooo0000o`00000:ooooo`;o00003_ooool2o`000003ooooool0003o000001;o
oooo1?l0001:ooooo`007?ooool00ol0003oooooooooo`1Oooooo`Co00000oooool2o`0001kooooo
0_l00005ooooo`;o00001_ooool2o`0000Cooooo1?l0000Eooooo`;o00003_ooool2o`0000;ooooo
0_l0000:ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Sooooo0_l00005ooooo`;o0000
2oooool4o`000003ooooool0003o000004Oooooo000Looooo`03o`000?oooooooooo05oooooo0_l0
0005ooooo`;o00003Oooool2o`0001Kooooo0ol00002ooooo`;o000000?oooooo`000?l000001?oo
ool2o`00027ooooo0_l00005ooooo`;o00004?ooool2o`0000Cooooo0_l00003ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0000?ooooo0_l0000@ooooo`;o0000Aoooool001cooooo00?o0000
ooooooooool0JOooool2o`0000[ooooo1?l00002ooooo`;o00003?ooool2o`0000?ooooo0_l00002
ooooo`;o00008?ooool2o`0000Sooooo0ol00004ooooo`;o00001?ooool2o`0001Gooooo0_l00000
0ooooooo0000o`000002ooooo`;o0000G_ooool001cooooo00?o0000ooooooooool0JOooool2o`00
00Cooooo0_l000000ooooooo0000o`000003ooooo`;o00000_ooool2o`0000Oooooo0_l00003oooo
o`;o00000oooool2o`0000Gooooo0_l00006ooooo`;o00000oooool2o`00013ooooo0_l00009oooo
o`?o00002Oooool2o`0000?ooooo0_l00005ooooo`;o00004?ooool2o`0005kooooo000Looooo`03
o`000?oooooooooo05kooooo0_l0000?ooooo`;o000000?oooooo`000?l000002?ooool3o`0000Go
oooo1Ol00004ooooo`?o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00002ooooo`;o
00000oooool2o`0001Kooooo0_l00004ooooo`Co00003?ooool2o`0000Gooooo0_l00003ooooo`;o
00004oooool5o`0005?ooooo000Looooo`03o`000?oooooooooo05kooooo0_l00005ooooo`;o0000
00?oooooo`000?l000004_ooool3o`0000Oooooo0ol000001?oooooo0000o`000?ooool2o`000003
ooooool0003o000000;o000000?oooooo`000?l000001?l0000Oooooo`;o00001_ooool2o`0000co
oooo0_l0000:ooooo`;o00000_ooool2o`0000[ooooo0_l00003ooooo`Go0000Doooool001cooooo
00?o0000ooooooooool0G_ooool2o`0000?ooooo1?l000000ooooooo0000o`00000Fooooo`Ko0000
00Coooooo`000?l0003ooooo0ol00003ooooo`Co000000?oooooo`000?l000001?l00004ooooo`;o
00002?ooool2o`0001gooooo0_l0000=ooooo`;o00001oooool2o`0000[ooooo0_l00005ooooo`;o
00003?ooool2o`0004Kooooo000Looooo`03o`000?oooooooooo04Kooooo0_l0000;ooooo`;o0000
1oooool2o`0000Gooooo0_l00002ooooo`;o00005oooool:o`000004ooooool0003o0000ooooo`Ko
00000_ooool2o`000003ooooool0003o000000?o000000?oooooo`000?l000002?ooool2o`0001go
oooo0_l0000=ooooo`;o00000oooool2o`000003ooooool0003o000001;ooooo0_l000000ooooooo
0000o`000009ooooo`;o0000A_ooool001cooooo0_l00017ooooo`;o00002oooool2o`0000;ooooo
0_l00003ooooo`;o00001?ooool3o`0000;ooooo0_l0000>ooooo`;o00002oooool6o`0000;ooooo
1?l000000ooooooo0000o`00000<o`00033ooooo0_l00006ooooo`;o00000oooool5o`0000gooooo
0ol00002ooooo`;o000000?oooooo`000?l00000DOooool001cooooo00?o0000ooooooooool0Eooo
ool3o`0000Cooooo0_l00002ooooo`;o00004oooool2o`0000cooooo5ol000000ooooooo0000o`00
0003ooooo`Co0000:Oooool4o`0000[ooooo0_l0000?ooooo`?o00000oooool2o`0005?ooooo000L
ooooo`03o`000?oooooooooo05Kooooo1?l00004ooooo`;o00007oooool2o`0000Cooooo5ol00006
ooooo`Co0000:oooool4o`0000?ooooo0ol00002ooooo`;o00005Oooool2o`0000Cooooo0_l0001=
ooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00001?ooool2o`0000_ooooo0ol0000Ioooo
o`Co00000_oooolHo`000003ooooool0003o000003?ooooo0_l00003ooooo`?o00000_ooool2o`00
01_ooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00001?ooool2o`0000_o
oooo0ol00005ooooo`;o00004Oooool5o`0000;ooooo6ol00006ooooo`;o00001Oooool2o`0002Oo
oooo0_l0000<ooooo`;o000000?oooooo`000?l000000ol00006ooooo`;o00005Oooool2o`0003ko
oooo000Looooo`03o`000?oooooooooo04Cooooo0_l0000@ooooo`Co00001_ooool2o`0000Wooooo
0ol000000ooooooo0000o`00000<ooooo`?o00001OoooolAo`000003ooooool0003o000000Ko0000
1oooool2o`0000Gooooo0ol0000Vooooo`;o00003?ooool2o`000003ooooool0003o000000?o0000
1_ooool2o`0001Gooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00003ooo
ool5o`0000Kooooo0_l00008ooooo`Co000000?oooooo`000?l000003?ooool2o`0000;ooooo0_l0
0002oooooaWo00003Oooool2o`000003ooooool0003o000003Sooooo0_l000000ooooooo0000o`00
0007ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0D?ooool2o`0000?ooooo0ol0000B
ooooo`;o00000oooool2o`0000Sooooo0_l00003ooooo`;o000000?oooooo`000?l000000_oooolI
o`0000gooooo0_l0000eooooo`;o00001?ooool5o`0000Cooooo0_l000000ooooooo0000o`00001C
ooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o000000?oooooo`000?l000000_ooool2o`00
0003ooooool0003o000000;o00006_ooool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`00
0?l000006ol0000gooooo`;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000006oooo
o`;o00001Oooool2o`0000;ooooo0_l00003ooooo`;o0000COooool001cooooo00?o0000oooooooo
ool0AOooool2o`0000Gooooo1_l00002ooooo`;o000000?oooooo`000?l000000_l0000Jooooo`;o
00001Oooool2o`0000?ooooo3_l000000ooooooo0000o`00000;o`0000;ooooo1ol0000_ooooo`;o
00001?ooool2o`0000;ooooo0_l00004ooooo`;o00000oooool2o`0000Oooooo1_l000000ooooooo
0000o`00001=ooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00001Oooool2o`000003oooo
ool0003o000000kooooo0_l00008ooooo`;o00004Oooool2o`0000Cooooo6ol00002ooooo`Oo0000
2oooool2o`0002;ooooo0_l00003ooooo`;o00002Oooool2o`000004ooooool0003o0000ooooo`;o
00001_ooool2o`000004ooooool0003o0000o`00053ooooo000Looooo`03o`000?oooooooooo05oo
oooo0_l00008ooooo`;o00005Oooool@o`000003ooooool0003o000000go00003oooool4o`0001go
oooo0_l00003ooooo`;o00000oooool2o`0000cooooo0_l000000ooooooo0000o`00001Looooo`00
7?ooool00ol0003oooooooooo`1Looooo`;o00008_ooool>o`000003ooooool0003o000000oo0000
3oooool2o`0001oooooo0_l0000Aooooo`;o00004Oooool2o`0000Gooooo0_l0001:ooooo`007?oo
ool00ol0003oooooooooo`1>ooooo`;o00002Oooool2o`000003ooooool0003o0000017ooooo0ol0
000Aooooo`Ko000000?oooooo`000?l000004ol00004ooooo`;o0000??ooool4o`00017ooooo0ol0
0004ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0A?ooool2o`0000Gooooo0_l00000
0ooooooo0000o`000009ooooo`Co00003?ooool2o`000004ooooool0003o0000ooooo`?o00003?oo
ool2o`0000?ooooo6ol00005ooooo`;o00000_ooool2o`0003Sooooo0_l0000;ooooo`;o00001ooo
ool2o`00053ooooo000Looooo`03o`000?oooooooooo04;ooooo1?l00005ooooo`;o00000oooool2
o`0000Wooooo0_l0000<ooooo`Go00004?ooool4o`000003ooooool0003o000001Wo00002Oooool2
o`0002Sooooo0_l00005ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Wooooo1?l0000=
ooooo`;o00000oooool2o`0004Gooooo000Looooo`;o0000@oooool2o`000003ooooool0003o0000
00;ooooo1?l000000ooooooo0000o`000002o`0000?ooooo0_l0000Booooo`?o00000_ooool2o`00
0004ooooool0003o0000o`0000cooooo0_l000000ooooooo0000o`00000@o`000003ooooool0003o
000000?o000000?oooooo`000?l000000_l0000aooooo`;o00001Oooool2o`000003ooooool0003o
000000Sooooo0_l00005ooooo`;o00002Oooool2o`0000?ooooo0ol00003ooooo`;o0000AOooool0
01cooooo00?o0000ooooooooool0AOooool2o`0000;ooooo1?l000001?oooooo0000o`000?l00004
ooooo`;o00003oooool2o`0000Kooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00002ooo
ool3o`000003ooooool0003o000001Co000000?oooooo`000?l000000ol0000Booooo`;o000000Co
ooooo`000?l0003o00000oooool2o`0001Oooooo0_l00002ooooo`?o00002?ooool2o`00013ooooo
0ol00002ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0?oooool2o`0000Cooooo0_l0
0002ooooo`;o00001?ooool4o`000003ooooool0003o0000013ooooo0_l0000:ooooo`Go00002ooo
oolJo`000003ooooool0003o000000Co00004Oooool2o`000004ooooool0003o0000o`0000?ooooo
0_l000000ooooooo0000o`000005ooooo`Co00002oooool2o`0000;ooooo0ol000000ooooooo0000
o`00000Hooooo`;o0000Coooool001cooooo00?o0000ooooooooool0?oooool2o`0000cooooo0_l0
0002ooooo`Go00000_ooool2o`000003ooooool0003o000000Wooooo0_l000000ooooooo0000o`00
0003ooooo`;o00000_ooool3o`0000Oooooo0_l00004ooooo`oo000000?oooooo`000?l000003ol0
0005ooooo`;o00005_ooool3o`0000Cooooo1?l0000@ooooo`;o000000?oooooo`000?l000003_oo
ool2o`0000Oooooo0_l00008ooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0@_ooool2
o`0000Wooooo0_l00003ooooo`;o00001?ooool2o`000003ooooool0003o000000?ooooo0_l00004
ooooo`;o000000?oooooo`000?l000000oooool2o`0000cooooo0_l00003ooooo`?o000000?ooooo
o`000?l000000ol000000ooooooo0000o`00000Do`0000Oooooo0_l00003ooooo`;o00002_ooool2
o`0000Kooooo0_l00006ooooo`;o00001?ooool2o`0001Gooooo0_l00006ooooo`;o00001oooool2
o`0000Sooooo0_l0000Aooooo`;o0000<oooool001cooooo00?o0000ooooooooool0@_ooool2o`00
00Gooooo0_l0000:ooooo`Co000000?oooooo`000?l000001?ooool2o`0000Oooooo0_l0000:oooo
o`Co000000Coooooo`000?l0003ooooo0_l00002oooooa[o000000?oooooo`000?l000000ol00000
0ooooooo0000o`000003ooooo`;o000000Coooooo`000?l0003ooooo0_l0000:ooooo`;o000000Co
ooooo`000?l0003ooooo0_l00004ooooo`;o00002?ooool2o`0001Cooooo0ol0000Cooooo`;o0000
5oooool2o`0003?ooooo000Looooo`03o`000?oooooooooo04Wooooo0_l0000:ooooo`Oo000000?o
ooooo`000?l000000oooool2o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`;o00000ooo
ool4o`000004ooooool0003o0000ooooo`;o00001?oooolJo`000005ooooool0003o0000o`000?oo
ool00_l00003ooooo`;o000000?oooooo`000?l000002?ooool2o`0000;ooooo0_l00002ooooo`Oo
00000_ooool4o`0001cooooo0_l000000ooooooo0000o`00000@ooooo`?o0000C?ooool001cooooo
00?o0000ooooooooool0BOooool2o`0000gooooo0ol000001?oooooo0000o`000?l00003ooooo`;o
00000_ooool3o`0000Oooooo0_l0000<ooooo`;o00001Oooool2o`000003ooooool0003o000001Ko
00001Oooool7o`0000Cooooo0ol000000ooooooo0000o`000002ooooo`;o00001?ooool7o`0000;o
oooo0_l0000Mooooo`Co00001oooool2o`0000?ooooo0_l00002ooooo`;o0000COooool001cooooo
00?o0000ooooooooool0>?ooool2o`0000oooooo0_l0000;ooooo`;o00001?ooool2o`0000;ooooo
0_l00005ooooo`;o00001?ooool2o`0000Cooooo0_l00005ooooo`;o00000_ooool3o`0000;ooooo
0_l00003oooooaSo000000Goooooo`000?l0003o0000ooooo`03o`000003ooooool0003o000000Go
oooo0ol0000<ooooo`;o00000_ooool2o`0001Cooooo1?l00004ooooo`;o00000oooool2o`0000Wo
oooo0_l00003ooooo`;o0000DOooool001cooooo00?o0000ooooooooool0>?ooool2o`0000Oooooo
0_l00006ooooo`;o00002oooool2o`0000Sooooo0_l00005ooooo`;o00001?ooool2o`0000Cooooo
0_l00005ooooo`;o00000oooool2o`0000;ooooo0_l00004ooooo`Go000000?oooooo`000?l00000
3?l000001?oooooo0000o`000?ooool3o`0000;ooooo0_l000000ooooooo0000o`000006ooooo`?o
000000Goooooo`000?l0003o0000ooooo`02o`0000cooooo0_l0000@ooooo`Co00001?ooool2o`00
00Gooooo0_l0000Gooooo`;o000000?oooooo`000?l00000@oooool001cooooo00?o0000oooooooo
ool0>oooool2o`0000?ooooo0ol00002ooooo`;o00000_ooool2o`0001Oooooo0_l00003ooooo`?o
00007oooool5o`0000;ooooo2ol000001?oooooo0000o`000?ooool2o`0000?ooooo0_l0000;oooo
o`?o000000Goooooo`000?l0003o0000ooooo`02o`0000cooooo0_l0000Oooooo`;o00002?ooool4
o`0000Oooooo0_l00002ooooo`;o000000?oooooo`000?l00000@oooool001cooooo00?o0000oooo
ooooool0>oooool2o`0000?ooooo0_l00003ooooo`;o00001oooool2o`0001;ooooo0_l00003oooo
o`?o00002Oooool2o`0001Oooooo0_l00002ooooo`Oo000000?oooooo`000?l000000_ooool2o`00
0003ooooool0003o000000?ooooo0_l0000?ooooo`;o000000?oooooo`000?l000000oooool2o`00
00Kooooo0_l00006ooooo`;o00008oooool4o`0000Oooooo1?l00018ooooo`007?ooool00ol0003o
ooooooooo`1>ooooo`;o00000_ooool2o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`000003
ooooool0003o000000[ooooo0_l0000;ooooo`;o00004?ooool5o`0000;ooooo1Ol00007ooooo`;o
00002Oooool3o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o00001_ooool2o`0000Ko
oooo0_l00007ooooo`;o00005?ooool2o`0000Kooooo0_l00009ooooo`;o0000B?ooool001cooooo
00?o0000ooooooooool0@?ooool2o`0000_ooooo0_l00002ooooo`?o00001?ooool2o`0000Cooooo
0_l00004ooooo`;o00002Oooool2o`0000Cooooo0_l00009ooooo`;o00001?ooool2o`00013ooooo
1?l00009ooooo`;o00002Oooool3o`0001;ooooo0ol000001?oooooo0000o`000?ooool3o`000003
ooooool0003o000000Cooooo0_l00003ooooo`;o00003oooool2o`0005_ooooo00001_ooooook^k^
oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0
003oooooooooo`10ooooo`;o00002oooool2o`0000;ooooo1?l0000<ooooo`;o00001oooool2o`00
00?ooooo0_l00004ooooo`;o00003oooool2o`0000_ooooo0_l00002ooooo`?o00001_ooool2o`00
013ooooo0_l00006ooooo`Co00001oooool3o`000004ooooool0003o0000ooooo`?o000000Cooooo
o`000?l0003ooooo0_l00006ooooo`;o00008?ooool2o`0001_ooooo0_l0000]ooooo`0000Kooooo
ogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo03Kooooo0ol00009ooooo`;o00003_ooool3o`000003ooooool0003o000000Wooooo
0_l00007ooooo`;o000000?oooooo`000?l000000ol00003ooooo`;o00000_ooool2o`0000Gooooo
1?l000000ooooooo0000o`00000<ooooo`;o00000_ooool2o`0000Oooooo0_l00006ooooo`;o0000
2?ooool2o`0000Kooooo1?l00007ooooo`;o00000oooool2o`0000Cooooo0_l000001?oooooo0000
o`000?l00007ooooo`Go00002Oooool2o`00013ooooo0ol0000Jooooo`;o0000;Oooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo00?o0000ooooooooool0
=_ooool3o`0000Wooooo0_l00004ooooo`?o00001oooool2o`0000;ooooo0_l0000@ooooo`;o0000
0oooool2o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o00001Oooool4o`000003oooo
ool0003o000000Sooooo0_l00007ooooo`;o00000oooool2o`0000Cooooo0_l00002ooooo`?o0000
4_ooool2o`000003ooooool0003o000000Cooooo0_l00003ooooo`Co00000_ooool2o`000005oooo
ool0003o0000o`000?ooool00_l00004ooooo`Go00002Oooool2o`0000Kooooo0_l00002ooooo`;o
00000oooool4o`000003ooooool0003o000000;ooooo0_l00012ooooo`0000?oooooo`000?ooool0
0_ooool00ol0003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol00018ooooo`?o
00002?ooool2o`0000Sooooo0_l00009ooooo`;o000000?oooooo`000?l000002?ooool2o`000003
ooooool0003o000000Cooooo0_l0000?ooooo`;o00001oooool2o`0000?ooooo0_l00004ooooo`;o
00000_ooool2o`0000Kooooo0_l00004ooooo`;o000000?oooooo`000?l000001Oooool5o`000003
ooooool0003o000000?ooooo1?l00002ooooo`;o00001Oooool2o`0001[ooooo0_l00002ooooo`;o
00000_ooool8o`0000;ooooo0_l00012ooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooo
ooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0A_ooool2o`0000_o
oooo0_l000000ooooooo0000o`000003ooooo`Co00001_ooool2o`000003ooooool0003o000000Go
00001_ooool2o`000003ooooool0003o000000?ooooo0ol00004ooooo`;o00003_ooool3o`0000Go
oooo0_l00004ooooo`;o00002oooool2o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`Ko
00001_ooool2o`0000Cooooo0_l0000:ooooo`;o00004Oooool2o`0000[ooooo0_l00002ooooo`Go
000000Coooooo`000?l0003o0000@Oooool00003ooooool@413ooooo00;ooooo00?o410@oooooooo
ool02_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo03Gooooo0_l0000?ooooo`;o
00003_ooool2o`0000?ooooo0_l00008ooooo`;o00000_ooool2o`0000;ooooo0_l00002ooooo`;o
00002_ooool2o`0000Gooooo0_l00005ooooo`;o00001oooool3o`0000Gooooo0_l00004ooooo`;o
000000?oooooo`000?l000000_l00005ooooo`?o000000?oooooo`000?l000001?ooool2o`0000Co
oooo0_l000000ooooooo0000o`000009ooooo`Co00003?ooool5o`0000;ooooo0_l0000:ooooo`;o
000000?oooooo`000?l000000_l0000;ooooo`?o00000_ooool2o`00047ooooo00001_ooooooMgMg
oiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0eoooo
o`;o00002oooool2o`0000;ooooo1?l0000Iooooo`;o00002?ooool2o`0000;ooooo0_l0000Hoooo
o`;o00006?ooool4o`0000Gooooo3?l000001?oooooo0000o`000?ooool2o`000003ooooool0003o
000000;o000000?oooooo`000?l000000oooool8o`0000Sooooo1_l00002ooooo`;o00001oooool4
o`0000;ooooo1?l0001Cooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0
003ooooo00Kooooo00?o0000ooooooooool0@?ooool4o`000003ooooool0003o000000?o00005Ooo
ool2o`0000;ooooo0_l0000Fooooo`;o00003_ooool2o`0001kooooo0_l00002ooooo`Wo000000?o
ooooo`000?l000000_l000000ooooooo0000o`000002o`000003ooooool0003o000000?o00000ooo
ool2o`0000;ooooo1?l00008ooooo`?o00001Oooool2o`0000Oooooo1?l00009ooooo`Co0000C?oo
ool001cooooo00?o0000ooooooooool0@?ooool2o`0000?ooooo0_l00006ooooo`;o00003_ooool4
o`0001Gooooo0_l00003ooooo`;o00003_ooool2o`0000?ooooo0_l0000=ooooo`Co00002?ooool2
o`0000?ooooo0_l00003ooooo`Oo000000?oooooo`000?l000000ol000000ooooooo0000o`000002
o`0000Kooooo0ol00002ooooo`?o00000_ooool8o`0000Oooooo0ol0000@ooooo`Co00000oooool2
o`0004Oooooo000Looooo`03o`000?oooooooooo04;ooooo0_l00003ooooo`;o00001?ooool6o`00
00[ooooo0_l000000ooooooo0000o`00000Dooooo`;o00004?ooool2o`0000Kooooo0_l00008oooo
o`;o00000oooool4o`000004ooooool0003o0000ooooo`;o00000oooool2o`0000?ooooo0_l00000
1Ooooooo0000o`000?l0003ooooo00oo00000_ooool2o`0000;ooooo1?l000001?oooooo0000o`00
0?l00002ooooo`Co000000?oooooo`000?l000000_l00006ooooo`?o00003oooool2o`0000Kooooo
0_l00017ooooo`007?ooool00ol0003oooooooooo`12ooooo`;o000000?oooooo`000?l000001?l0
0004ooooo`Co00001oooool2o`0000Cooooo0_l000000ooooooo0000o`00000Iooooo`;o000000?o
ooooo`000?l000000_l00003ooooo`;o00004?ooool2o`0000Sooooo1Ol00002ooooo`?o00000ooo
ool?o`000003ooooool0003o000000Wo000000?oooooo`000?l000000_l00002ooooo`Co00001?oo
ool2o`000003ooooool0003o000000_ooooo0_l0000;ooooo`;o0000Coooool001cooooo00?o0000
ooooooooool0@?ooool2o`0000?ooooo0_l00002ooooo`;o00001?ooool4o`0000Oooooo1Ol00004
ooooo`;o00001Oooool2o`0000;ooooo0_l00005ooooo`;o00001oooool2o`000003ooooool0003o
000000;o00005Oooool2o`0000Wooooo0_l00004ooooo`;o00001_oooolNo`0000;ooooo1?l00004
ooooo`;o00000oooool2o`000003ooooool0003o000000Kooooo0_l0000Aooooo`Go000000?ooooo
o`000?l00000@oooool001cooooo00?o0000ooooooooool0@?ooool2o`0000?ooooo0_l00004oooo
o`;o00000_ooool2o`0000[ooooo1?l00006ooooo`;o000000?oooooo`000?l000002?l00003oooo
o`;o00001?ooool2o`0001;ooooo0_l0000Dooooo`;o000000Coooooo`000?l0003ooooo0_l00002
ooooo`;o00000_oooolJo`000003ooooool0003o000000?o00003Oooool2o`000003ooooool0003o
000000;o000000?oooooo`000?l000003_ooool2o`0000Cooooo1Ol000000ooooooo0000o`000002
ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0;_ooool2o`0000kooooo1_l00007oooo
o`;o00004?ooool2o`0000?ooooo4?l00009ooooo`;o00004Oooool3o`0001Cooooo0_l000000ooo
oooo0000o`000007o`0000;ooooo9_l00006ooooo`;o00000_ooool4o`000003ooooool0003o0000
00?ooooo0_l00009ooooo`;o00001Oooool2o`000003ooooool0003o000000;ooooo1?l0000ooooo
o`007?ooool00ol0003oooooooooo`0^ooooo`;o00003_ooool2o`0000;ooooo0_l00007ooooo`;o
00005?oooolAo`0000Cooooo0_l0000Fooooo`Co00004oooool2o`0000;ooooo2?l000000ooooooo
0000o`00000No`000003ooooool0003o000000Co00001_ooool2o`0000cooooo0_l0000>ooooo`Co
000000?oooooo`000?l000000_ooool3o`0001Wooooo0_l0000Uooooo`007?ooool00ol0003ooooo
ooooo`0_ooooo`;o00003Oooool3o`000003ooooool0003o000000Gooooo1?l0000=ooooo`;o0000
00Goooooo`000?l0003o0000ooooo`0Go`0000Wooooo1?l00007ooooo`Ko000000?oooooo`000?l0
00000_l0000>ooooo`;o00000oooool4o`000003ooooool0003o000000?o000000?oooooo`000?l0
00006?l000000ooooooo0000o`000006o`000003ooooool0003o000000;ooooo0_l000000ooooooo
0000o`00000Kooooo`;o00002?ooool2o`0001Wooooo0_l0000Uooooo`007?ooool00ol0003ooooo
ooooo`0_ooooo`;o00003Oooool3o`0000;ooooo0_l000000ooooooo0000o`000003o`0000?ooooo
0_l00007ooooo`;o000000Coooooo`000?l0003ooooo0ol000000ooooooo0000o`00000Do`0000[o
oooo1?l00007ooooo`Ko000000?oooooo`000?l000001Ol00007ooooo`;o00002?ooool3o`0000?o
oooo9ol000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000005_ooool2o`0004oo
oooo000Looooo`03o`000?oooooooooo03_ooooo0_l00006ooooo`Oo00001?ooool2o`0000Oooooo
0_l000001?oooooo0000o`000?oooolKo`0000Kooooo0_l00002ooooo`;o00003?ooool2o`000003
ooooool0003o000000Go00001?ooool2o`000003ooooool0003o000000?ooooo0_l00004ooooo`?o
00000_oooolQo`000003ooooool0003o000000?o000000?oooooo`000?l000001Ol0000Hooooo`;o
00003oooool2o`0003kooooo000Looooo`03o`000?oooooooooo03_ooooo0_l00008ooooo`;o0000
00?oooooo`000?l000000_ooool2o`0000?ooooo0_l00007oooooako00000oooool2o`000003oooo
ool0003o000000Kooooo0_l00009ooooo`Ko00001oooool4o`0000Cooooo0_l000000ooooooo0000
o`000002ooooob[o00000_ooool;o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o0000
1_ooool2o`00013ooooo1Ol0000mooooo`007?ooool2o`0003_ooooo0_l00008ooooo`;o00000_oo
ool2o`000004ooooool0003o0000o`0000?ooooo0_l00009oooooago00000_ooool2o`0000Wooooo
0_l000000ooooooo0000o`000002ooooo`;o00000_ooool2o`0000gooooo0_l00003ooooo`;o0000
0_ooool2o`0000Cooooo:?l00004ooooo`?o00000_ooool4o`0000;ooooo0_l000001Ooooooo0000
o`000?l0003ooooo00;o00001_ooool2o`00013ooooo0_l000000ooooooo0000o`00000Iooooo`;o
00008_ooool001cooooo00?o0000ooooooooool0>_ooool2o`0000Cooooo0_l00002ooooo`?o0000
00Coooooo`000?l0003ooooo0_l0000:ooooo`;o00000_ooool2o`000003ooooool0003o000001Ko
000000?oooooo`000?l000001?l0000<ooooo`;o00000_ooool2o`00013ooooo0_l00004ooooo`;o
00001?ooool3o`0000?ooooo6ol000000ooooooo0000o`00000=o`000004ooooool0003o0000oooo
o`;o00000oooool2o`0000?ooooo0_l0000>ooooo`;o0000:Oooool2o`0002;ooooo000Looooo`03
o`000?oooooooooo043ooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000Co
oooo0_l00007ooooo`;o00000_oooolKo`0000?ooooo0_l0000Sooooo`?o00001?ooool2o`000004
ooooool0003o0000ooooo`?o00000_ooool8o`000003ooooool0003o000002Co00001_ooool2o`00
00;ooooo0_l0000?ooooo`;o00002Oooool2o`0000;ooooo0_l0000nooooo`007?ooool00ol0003o
ooooooooo`0oooooo`;o00000_ooool3o`0000;ooooo0_l00004ooooo`Co00002_oooolJo`0001Oo
oooo0_l00007ooooo`;o00001_ooool2o`0000Gooooo0_l000000ooooooo0000o`000003ooooo`;o
000000?oooooo`000?l000003ol000000ooooooo0000o`00000Ao`000003ooooool0003o000000Ko
00002Oooool4o`0000gooooo0_l00003ooooo`;o00001_ooool2o`000004ooooool0003o0000o`00
03kooooo000Looooo`03o`000?oooooooooo03oooooo0_l00002ooooo`;o00002oooool2o`0000;o
oooo1_l00002oooooa[o00002?ooool2o`0000;ooooo0_l00009ooooo`;o00001Oooool4o`0001Go
oooo5ol000000ooooooo0000o`00000Go`0000Cooooo0ol00002ooooo`;o00003Oooool4o`0000?o
oooo0_l00009ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0@oooool4o`0000;ooooo
0_l00005ooooo`;o00000_ooool?o`000003ooooool0003o0000013o00002?ooool2o`0000;ooooo
0_l0000@ooooo`Co00005Oooool@o`0000;ooooo1_l000000ooooooo0000o`00000>o`000004oooo
ool0003o0000ooooo`?o000000?oooooo`000?l000000_ooool3o`00017ooooo0_l00005ooooo`;o
00000_ooool2o`0004Kooooo000Looooo`03o`000?oooooooooo043ooooo1?l000000ooooooo0000
o`000002ooooo`;o00001Oooool2o`0000Kooooo1?l000000ooooooo0000o`00000Go`00017ooooo
0_l00006ooooo`?o00000oooool2o`0001Cooooo:Ol00002ooooo`Co000000?oooooo`000?l00000
0ol00002ooooo`;o00001_ooool2o`0000[ooooo0_l00004ooooo`;o00000oooool2o`0004Kooooo
000Looooo`03o`000?oooooooooo043ooooo1?l0000:ooooo`;o00001ooooolNo`0001;ooooo1?l0
0004ooooo`?o00000oooool2o`00013ooooo0_l000000ooooooo0000o`00000^o`000003ooooool0
003o000000?o00000_ooool2o`0000Kooooo0_l00006ooooo`;o00000_ooool2o`000004ooooool0
003o0000ooooo`;o00002_ooool2o`0003oooooo000Looooo`03o`000?oooooooooo03kooooo0_l0
000>ooooo`Co00001Oooool6o`000003ooooool0003o000001Go00005?ooool4o`0000;ooooo0ol0
0002ooooo`?o00004?ooool2o`000003ooooool0003o000002;o000000?oooooo`000?l000002?l0
0002ooooo`Co00004oooool2o`0000Gooooo0_l0000<ooooo`?o0000?oooool001cooooo00?o0000
ooooooooool0?_ooool2o`0000Wooooo0_l00005ooooo`;o00000_ooool2o`0000?ooooo0_l00000
0ooooooo0000o`00000Go`000003ooooool0003o000000Wooooo0_l00008ooooo`?o00001_ooool3
o`0000_ooooo0_l00006ooooob[o000000?oooooo`000?l000000_l00003ooooo`;o00004Oooool2
o`000003ooooool0003o000001?ooooo0_l000001?oooooo0000o`000?l0000looooo`007?ooool0
0ol0003oooooooooo`10ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Wooooo0_l00006
ooooo`?o000000?oooooo`000?l000004_l00002ooooo`;o00002Oooool2o`0000Cooooo0_l00003
ooooo`;o00001oooool3o`000004ooooool0003o0000o`0000Kooooo0_l00006ooooo`?o000000?o
ooooo`000?l000000ol000000ooooooo0000o`00000Po`0000Kooooo0_l0000=ooooo`;o00000_oo
ool2o`00017ooooo0_l00006ooooo`?o0000??ooool001cooooo00?o0000ooooooooool0@?ooool2
o`000003ooooool0003o000000;ooooo0_l00006ooooo`;o00003?oooolHo`0001;ooooo0_l0000:
ooooo`Go000000?oooooo`000?l000000ol0000<ooooo`?o000000?oooooo`000?l000000ol00002
ooooobWo00002oooool4o`0000Cooooo0_l0000;ooooo`;o00000_ooool2o`000003ooooool0003o
000000Cooooo0_l0000looooo`007?ooool00ol0003oooooooooo`0jooooo`;o00001_ooool2o`00
00;ooooo0ol00004ooooo`Co00001oooool2o`000003ooooool0003o000001Go000000?oooooo`00
0?l000004Oooool2o`0000Oooooo0_l00002ooooo`Ko00000oooool2o`0000Kooooo0_l00003oooo
o`;o000000?oooooo`000?l000001_l000000ooooooo0000o`00000Uo`0000cooooo0ol00006oooo
o`;o00001?ooool2o`0000Gooooo0_l00003ooooo`Co00000oooool2o`0003gooooo000Looooo`03
o`000?oooooooooo02[ooooo0_l0000:ooooo`;o00000_ooool2o`0000;ooooo0ol000000ooooooo
0000o`000002ooooo`;o00001Oooool2o`0000Wooooo0_l000000ooooooo0000o`00000Eo`0001Co
oooo0_l00007ooooo`;o00001_ooool2o`000003ooooool0003o000000Gooooo0_l000000ooooooo
0000o`000002ooooob[o000000?oooooo`000?l000000_l00003ooooo`;o00003?ooool2o`0000Go
oooo0_l00006ooooo`;o00002_ooool2o`0000Gooooo0_l0000mooooo`007?ooool00ol0003ooooo
ooooo`0Zooooo`Co00002?ooool2o`0000Kooooo0ol00002ooooo`;o00005ooooolAo`000004oooo
ool0003o0000ooooo`;o00004_ooool2o`000003ooooool0003o000000cooooo1ol00003ooooo`?o
00001Oooool5o`000004ooooool0003o0000ooooob7o000000?oooooo`000?l000000_l00003oooo
o`;o00004Oooool6o`0000Sooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o0000
00?o0000?_ooool001cooooo00?o0000ooooooooool0;?ooool2o`0000_ooooo0_l00003ooooo`;o
00000oooool2o`0000oooooo0_l00004ooooo`Co00000_ooool6o`000003ooooool0003o000000Oo
000000?oooooo`000?l000004_ooool2o`000003ooooool0003o000000Gooooo0_l00005ooooo`So
00000_ooool2o`0000Wooooo0ol00003ooooo`[o000000?oooooo`000?l000007ol0000<ooooo`;o
00000_ooool6o`0000Sooooo0_l00002ooooo`;o00001Oooool5o`0000Kooooo0_l0000fooooo`00
7?ooool2o`0002Gooooo0_l0000Cooooo`;o00000_ooool3o`000003ooooool0003o000000gooooo
0_l00002ooooo`;o00001?ooool4o`0000;ooooo1_l00002ooooo`;o00000oooool3o`00017ooooo
0_l00002ooooo`;o00000oooool2o`0000?ooooo0_l00005ooooo`;o000000Coooooo`000?l0003o
oooo0_l000000ooooooo0000o`000002o`0000Sooooo0ol00004ooooo`;o000000?oooooo`000?l0
00009_l00004ooooo`;o00001?ooool4o`0000cooooo0_l0000@ooooo`Co00001?ooool2o`0000So
oooo0_l0000/ooooo`007?ooool00ol0003oooooooooo`0Tooooo`;o00005oooool2o`0000;ooooo
0_l0000=ooooo`;o00001Oooool2o`000003ooooool0003o000000;o00001?ooool8o`0000;ooooo
1?l0000Aooooo`;o00001oooool2o`0000gooooo0_l00003ooooo`Go00002?ooool2o`0000;ooooo
0_l00004oooooago00000_ooool4o`000003ooooool0003o000000;o00001?ooool2o`0000Cooooo
1?l00007ooooo`;o00000oooool2o`0000_ooooo0_l00003ooooo`Co00003_ooool2o`0002cooooo
000Looooo`03o`000?oooooooooo03Gooooo0_l0000:ooooo`;o00005?ooool2o`000004ooooool0
003o0000o`0000Sooooo1Ol00002ooooo`Co00004?ooool3o`0000Gooooo0_l0000>ooooo`;o0000
1?ooool2o`0000Gooooo0_l00007ooooo`?o00001?ooool8o`000003ooooool0003o000001;o0000
1?ooool7o`0000cooooo0_l00007ooooo`Co00003_ooool2o`000003ooooool0003o000001oooooo
0_l0000Oooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o00002?ooool2o`0000[ooooo0_l0
000Rooooo`;o00006Oooool5o`0000;ooooo0ol0000>ooooo`;o00001?ooool2o`0000;ooooo0_l0
00000ooooooo0000o`000002o`0000Cooooo1Ol000001Ooooooo0000o`000?l0003ooooo00;o0000
00?oooooo`000?l000000_l000000ooooooo0000o`00000?o`0000Sooooo1Ol00004ooooo`;o0000
2Oooool2o`0000Kooooo0_l0000Aooooo`;o00000oooool2o`0001[ooooo0_l0000Oooooo`007?oo
ool00ol0003oooooooooo`0Sooooo`;o00001_ooool2o`0000_ooooo0_l00003ooooo`;o00000_oo
ool2o`00017ooooo0_l000000ooooooo0000o`00000Uooooo`;o00000oooool2o`0000;ooooo0_l0
000Eooooo`Ko00000oooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool3o`0000;ooooo
0_l00002oooooa3o000000Coooooo`000?l0003ooooo0ol00005ooooo`;o000000?oooooo`000?l0
00001?ooool2o`0000Wooooo0_l00005ooooo`;o00005?ooool2o`000004ooooool0003o0000o`00
03[ooooo000Looooo`03o`000?oooooooooo02?ooooo0_l00006ooooo`;o00002oooool3o`0000;o
oooo1_l000000ooooooo0000o`000007ooooo`;o00001Oooool2o`000004ooooool0003o0000o`00
00kooooo0_l00002ooooo`;o00004?ooool2o`0000Oooooo0_l00007ooooo`;o00002Oooool2o`00
0003ooooool0003o000000;o00002?ooool2o`0000Sooooo0ol000000ooooooo0000o`00000Io`00
00?ooooo0_l00003ooooo`?o00001?ooool2o`0000Cooooo0_l00009ooooo`;o00004oooool9o`00
03Sooooo000Looooo`03o`000?oooooooooo02_ooooo0_l0000<ooooo`;o000000Coooooo`000?l0
003ooooo0_l00003ooooo`;o00001oooool2o`0000Gooooo0_l00002ooooo`?o00001Oooool2o`00
00;ooooo0_l00002ooooo`;o00000_ooool2o`0000Oooooo0_l0000;ooooo`;o00001Oooool2o`00
00Gooooo0_l00004ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo0_l00006oooo
o`;o00002?ooool?o`000003ooooool0003o000000_o00001Oooool2o`0000?ooooo0ol00004oooo
o`;o00000_ooool4o`000003ooooool0003o000000;o00002_ooool4o`0000Cooooo0_l00005oooo
o`Go00000_ooool2o`0003Sooooo000Looooo`03o`000?oooooooooo03cooooo0_l000000ooooooo
0000o`000002ooooo`?o00004?ooool2o`000003ooooool0003o000000Gooooo0_l00002ooooo`Co
00003Oooool2o`0000_ooooo0ol00004ooooo`Co00000_ooool2o`0000Gooooo0_l00007ooooo`;o
000000?oooooo`000?l000003Oooool3o`0000?ooooo1ol000000ooooooo0000o`000003ooooo`[o
00003Oooool2o`0000Wooooo0_l00003ooooo`Co00000oooool2o`0000;ooooo0_l000000ooooooo
0000o`000002o`0000Cooooo0_l0000:ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0
>oooool2o`0000;ooooo0ol000000ooooooo0000o`00000Aooooo`?o00001Oooool2o`0000Kooooo
0_l0000Dooooo`;o00001Oooool2o`0000Cooooo1?l00002ooooo`;o00003_ooool2o`0000Kooooo
0_l00008ooooo`?o00000oooool2o`000003ooooool0003o000000Go00000_ooool7o`000003oooo
ool0003o000000;o00000oooool4o`0000oooooo0_l00006ooooo`;o00000oooool2o`0000;ooooo
0_l00009ooooo`Co00002?ooool2o`0003[ooooo000Looooo`03o`000?oooooooooo027ooooo0_l0
000Gooooo`?o000000?oooooo`000?l000000_l00009ooooo`;o00002Oooool3o`0000Gooooo0_l0
00000ooooooo0000o`000002ooooo`;o00005Oooool2o`0002Kooooo0_l000000ooooooo0000o`00
0008ooooo`Co00001_ooool6o`000003ooooool0003o000000_o00000oooool4o`0000[ooooo0_l0
0003ooooo`;o00001_ooool2o`0001Cooooo0_l00005ooooo`;o00000_ooool2o`0003Wooooo000L
ooooo`03o`000?oooooooooo027ooooo0_l0000Gooooo`Ko00002oooool3o`0000Sooooo0_l00007
ooooo`Co00000_ooool2o`0001Cooooo0_l0000;ooooo`;o00001_ooool2o`0000Cooooo0_l0000<
ooooo`Go00002Oooool3o`000004ooooool0003o0000o`0000;ooooo0ol00002ooooo`Oo000000?o
ooooo`000?l000001?l000000ooooooo0000o`00000?ooooo`;o00001oooool2o`0000_ooooo0_l0
0004ooooo`;o00002_ooool4o`0000;ooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`0Y
ooooo`;o00003oooool4o`0000kooooo0_l00008ooooo`;o00001_ooool3o`0000Kooooo0_l00008
ooooo`;o00000oooool7o`0000?ooooo0_l00004ooooo`Co00001_ooool2o`0000Cooooo0_l00000
0ooooooo0000o`000007ooooo`Oo00000_ooool2o`0000Gooooo1ol00003ooooo`;o00000_ooool3
o`000005ooooool0003o0000o`000?ooool01_l000000ooooooo0000o`000005ooooo`;o00004Ooo
ool2o`0000?ooooo0_l00004ooooo`Co00000oooool3o`0000[ooooo1?l00003ooooo`;o00005_oo
ool2o`00023ooooo000Looooo`03o`000?oooooooooo02Wooooo0_l0000?ooooo`?o000000?ooooo
o`000?l000002oooool4o`0000oooooo0_l00007ooooo`;o00002?ooool4o`000003ooooool0003o
000000Co00001?ooool2o`0000Cooooo0_l00006ooooo`;o00002Oooool4o`0000Gooooo0_l00003
ooooo`;o00000_ooool2o`0000Oooooo1?l00004ooooo`;o00000_ooool4o`000003ooooool0003o
000000Oooooo0_l00006ooooo`;o00003oooool2o`0000Gooooo1?l00002ooooo`;o00000_ooool2
o`000003ooooool0003o000000gooooo0_l000000ooooooo0000o`000002o`0001Kooooo0_l0000P
ooooo`007?ooool00ol0003oooooooooo`0iooooo`Co000000?oooooo`000?l000000_l00009oooo
o`Co00009?ooool2o`0001Wooooo0_l0000;ooooo`;o00001_ooool2o`0000Gooooo1Ol00006oooo
o`?o000000Coooooo`000?l0003ooooo2ol000000ooooooo0000o`000004ooooo`;o00005oooool3
o`0000Kooooo0_l00006ooooo`;o00003Oooool4o`0000;ooooo0_l0000jooooo`007?ooool00ol0
003oooooooooo`0iooooo`?o00001?ooool2o`0000?ooooo0_l0000]ooooo`?o00001_ooool2o`00
01gooooo0_l00005ooooo`?o00001?ooool5o`0000Gooooo1ol00003ooooo`Co000000?oooooo`00
0?l000000oooool2o`0001gooooo0ol00004ooooo`;o00000_ooool2o`0000Cooooo0_l0000=oooo
o`Go0000?Oooool001cooooo00?o0000ooooooooool0?Oooool2o`0000Kooooo0_l0000@ooooo`;o
00006oooool3o`0000Kooooo0_l0000Mooooo`;o00001Oooool5o`0000;ooooo0_l000000ooooooo
0000o`000002ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000Sooooo0_l00004oooo
o`;o00004oooool2o`0000Cooooo0_l00009ooooo`;o00000_ooool2o`0000Cooooo0_l00006oooo
o`;o00002?ooool4o`0003_ooooo000Looooo`;o0000?_ooool2o`0000Kooooo0_l0000@ooooo`;o
00003?ooool2o`0003Oooooo0_l00004ooooo`Co00000_ooool2o`000003ooooool0003o000000;o
oooo0_l00002ooooo`;o00001oooool2o`000004ooooool0003o0000o`0000?ooooo0ol0000Coooo
o`;o00001?ooool2o`0000gooooo0_l00004ooooo`;o00001_ooool4o`0000Sooooo0_l0000koooo
o`007?ooool00ol0003oooooooooo`0kooooo`;o00000oooool3o`0000cooooo0_l0000Cooooo`?o
00002oooool2o`00017ooooo0_l0000?ooooo`Co00001?ooool2o`0000Cooooo0_l00004ooooo`;o
00004_ooool5o`0000Cooooo0_l00002ooooo`;o00007?ooool4o`0000Gooooo0_l00004ooooo`;o
00002?ooool2o`0004Gooooo000Looooo`03o`000?oooooooooo03_ooooo0_l00003ooooo`?o0000
1_ooool2o`0000Cooooo0_l0000Cooooo`;o00003?ooool2o`00017ooooo0_l0000?ooooo`Co0000
2_ooool2o`0000cooooo0_l00009ooooo`Co00001?ooool2o`0000Cooooo0_l00003ooooo`;o0000
1_ooool2o`0000Oooooo0_l00006ooooo`Co00001Oooool3o`0000Kooooo0_l00002ooooo`;o0000
2Oooool2o`0000Oooooo0_l0000dooooo`007?ooool00ol0003oooooooooo`0dooooo`;o00004ooo
ool2o`0000Gooooo0_l00003ooooo`;o00001_ooool2o`0001Sooooo0_l00002ooooo`;o00005Ooo
ool2o`00017ooooo0_l0000;ooooo`;o00002Oooool2o`0000Kooooo0_l00009ooooo`;o00001_oo
ool2o`0000Oooooo0ol0000?ooooo`?o00000_ooool5o`0000;ooooo0_l00008ooooo`?o00001ooo
ool2o`0003Cooooo000Looooo`03o`000?oooooooooo03Cooooo0_l00003ooooo`;o00002?ooool3
o`0000[ooooo0_l00003ooooo`;o00001Oooool3o`0001Sooooo0_l00002ooooo`;o00005Oooool2
o`00017ooooo0_l00002ooooo`;o00002_ooool2o`0000Kooooo0_l00004ooooo`;o00001?ooool2
o`000003ooooool0003o0000017ooooo0_l000000ooooooo0000o`00000@ooooo`;o00000_ooool4
o`0000;ooooo0_l00005ooooo`?o000000Coooooo`000?l0003o0000?Oooool001cooooo00?o0000
ooooooooool0>Oooool2o`0000Sooooo0ol0000>ooooo`;o00001?ooool4o`0000Oooooo0_l00004
ooooo`;o0000;_ooool2o`0000Wooooo0_l000000ooooooo0000o`000008ooooo`Co00001_ooool2
o`0000Cooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0ol0000=ooooo`;o00003Ooo
ool2o`0000Cooooo0_l00008ooooo`;o00001Oooool3o`000004ooooool0003o0000o`0003gooooo
000Looooo`03o`000?oooooooooo03Sooooo0_l0000<ooooo`;o00003?ooool2o`0000Cooooo0_l0
0003ooooo`Co00000_ooool2o`0000Cooooo0_l00005ooooo`;o00002?ooool2o`0001gooooo0_l0
0002ooooo`;o00001Oooool2o`0000_ooooo0_l000000ooooooo0000o`00000:ooooo`?o00002_oo
ool3o`0001cooooo0_l00004ooooo`;o00004oooool2o`0003kooooo000Looooo`03o`000?oooooo
oooo02cooooo0_l0000:ooooo`;o00003?ooool2o`000003ooooool0003o000000cooooo0_l00006
ooooo`Co00003oooool2o`0000Sooooo0_l0000Kooooo`Co00000_ooool2o`0000;ooooo0ol0000@
ooooo`;o00000_ooool2o`0000Kooooo0ol00004ooooo`;o00001Oooool2o`0001Oooooo0_l00002
ooooo`;o00005oooool2o`00047ooooo000Looooo`03o`000?oooooooooo02cooooo0_l0000Foooo
o`Co000000?oooooo`000?l000003?ooool2o`0000Kooooo0_l0000>ooooo`;o000000Coooooo`00
0?l0003ooooo0_l0000Qooooo`Go00001_ooool3o`0000Kooooo0ol00006ooooo`;o00000oooool2
o`0000gooooo0_l00006ooooo`;o00005_ooool2o`0000;ooooo0_l0000Cooooo`;o00000_ooool2
o`00047ooooo000Looooo`03o`000?oooooooooo047ooooo0_l000000ooooooo0000o`00000Coooo
o`;o00005?ooool2o`0000Cooooo0_l00006ooooo`;o00003?ooool2o`0000_ooooo0_l0000>oooo
o`;o00000_ooool3o`0000Kooooo0_l0000Jooooo`;o00005_ooool2o`0000Gooooo0_l0000@oooo
o`;o00006oooool2o`0002Sooooo000Looooo`03o`000?oooooooooo03Wooooo0_l00006ooooo`Co
00005?ooool2o`0001gooooo0ol00002ooooo`;o00001_ooool2o`0000Cooooo0_l0000;ooooo`;o
00002_ooool2o`0000;ooooo0_l0000Eooooo`;o00003Oooool2o`0000[ooooo0_l00003ooooo`;o
00002?ooool2o`0000Gooooo0ol0000;ooooo`;o00001_ooool2o`0001Oooooo0_l0000Xooooo`00
7?ooool00ol0003oooooooooo`0]ooooo`;o00002_ooool2o`0000Cooooo0_l00002ooooo`;o0000
2Oooool3o`0000gooooo0_l0000Hooooo`?o00002_ooool2o`0000Sooooo0_l0000@ooooo`;o0000
00?oooooo`000?l000001?ooool2o`000003ooooool0003o0000013ooooo0_l0000=ooooo`;o0000
2_ooool2o`000003ooooool0003o000000;o00002?ooool2o`000003ooooool0003o000000;ooooo
0ol00006ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00000_ooool2o`000003oooo
ool0003o000003kooooo000Looooo`03o`000?oooooooooo02gooooo0_l0000>ooooo`Co00002_oo
ool6o`0000;ooooo0_l00009ooooo`;o00002_ooool2o`0000Gooooo0_l0000Looooo`;o00004?oo
ool2o`0000Kooooo0ol000000ooooooo0000o`00000Eooooo`;o000000?oooooo`000?l000004ooo
ool3o`0000Kooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00000_ooool4o`0000Gooooo
0_l000000ooooooo0000o`000004ooooo`;o00001Oooool3o`0003gooooo000Looooo`03o`000?oo
oooooooo03gooooo0_l0000<ooooo`Go00000oooool2o`0001?ooooo1?l00003ooooo`Co00008?oo
ool2o`0000cooooo0_l00006ooooo`;o000000?oooooo`000?l000005_ooool2o`000003ooooool0
003o000000Kooooo0ol00009ooooo`?o00001oooool2o`000003ooooool0003o000000Sooooo0_l0
000;ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00007ooooo`;o0000=?oo
ool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o
410@olc<c006ooooo`03o`000?oooooooooo03Wooooo0_l0000<ooooo`;o00003?ooool3o`0000Wo
oooo1?l00003ooooo`;o00001Oooool3o`00027ooooo0_l0000:ooooo`Co000000Coooooo`000?l0
003o00001Oooool4o`0001oooooo0ol00003ooooo`;o00001?ooool2o`0001;ooooo0_l00004oooo
o`;o00002?ooool2o`0000Gooooo0_l0000;ooooo`;o0000=?ooool00006oooooomgMgOoV9RHoooo
oonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oo
oooooooo02oooooo0_l00008ooooo`?o00001Oooool2o`0000Cooooo0_l00007ooooo`;o00000ooo
ool3o`0000Wooooo1?l0000Looooo`;o00005Oooool2o`0000Gooooo0_l00003ooooo`Go00000_oo
ool5o`000004ooooool0003o0000o`0000?ooooo0_l0000?ooooo`;o00002oooool2o`0000;ooooo
0_l0000Dooooo`;o00001?ooool2o`0000;ooooo0_l00002ooooo`?o0000BOooool00003ooooool@
413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0;oooool2o`000003ooooool0003o000000Kooooo0_l00005ooooo`;o0000
1_ooool2o`0000Gooooo0ol0000:ooooo`;o000000?oooooo`000?l000002?ooool2o`0000Oooooo
0_l0000<ooooo`Co00003_ooool2o`0000?ooooo0ol0000<ooooo`;o00000_ooool3o`0000?ooooo
1Ol000000ooooooo0000o`00000?ooooo`;o00000_ooool3o`0000Kooooo1_l0000Nooooo`?o0000
00Coooooo`000?l0003o0000BOooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
2Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0000booooo`;o00001?ooool2o`0000oo
oooo1?l00004ooooo`?o00002Oooool2o`000004ooooool0003o0000ooooo`;o00001Oooool2o`00
00Oooooo0_l0000>ooooo`?o00003Oooool4o`0000;ooooo1?l0000?ooooo`;o00000_ooool3o`00
0003ooooool0003o000000kooooo0_l00006ooooo`?o00002?ooool3o`0001;ooooo0_l0000<oooo
o`;o0000COooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003o
EEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0>?ooool2o`0000oooooo1?l00005oooo
o`;o00002oooool2o`0000;ooooo0_l00009ooooo`;o00001oooool2o`0000[ooooo0ol00003oooo
o`;o00001?ooool2o`000003ooooool0003o000000Ko000000?oooooo`000?l000003oooool3o`00
0003ooooool0003o000000Ko00003?ooool2o`0000Sooooo0_l0000Dooooo`;o00000_ooool6o`00
00Cooooo0_l00007ooooo`;o00002oooool2o`0003oooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`10ooooo`Co
00001Oooool5o`00017ooooo0_l0000=ooooo`Co00001Oooool2o`0000Kooooo0_l00008ooooo`?o
000000?oooooo`000?l000002ol0000:ooooo`;o00001oooool2o`0000;ooooo1ol0000=ooooo`;o
00001oooool2o`0000?ooooo0_l0000?ooooo`;o00000_ooool6o`0000Cooooo1?l00005ooooo`;o
00002oooool2o`0003oooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@
4?nHV9P02?ooool00ol0003oooooooooo`10ooooo`Co00000oooool2o`0000;ooooo0ol0000Aoooo
o`;o00002_ooool9o`0000_ooooo0_l00003ooooo`?o00000oooool@o`000004ooooool0003o0000
o`0000Kooooo0_l00005ooooo`;o00001?ooool5o`0000;ooooo0_l0000;ooooo`;o00000oooool2
o`0000Oooooo0_l0000Gooooo`;o00000_ooool6o`0000?ooooo0ol00008ooooo`;o0000@oooool0
0006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`00
0?oooooooooo04Oooooo0_l00002ooooo`;o00003oooool2o`0000Sooooo4_l0000<ooooo`?o0000
0_oooolFo`0000cooooo0_l00007ooooo`Ko00001_ooool2o`0000?ooooo0_l00003ooooo`;o0000
5oooool2o`0000_ooooo1ol00002ooooo`?o00001oooool3o`0004?ooooo000Looooo`03o`000?oo
oooooooo03Cooooo0_l0000;ooooo`?o00001oooool2o`0000kooooo0ol00008oooooaCo00003?oo
oolMo`000003ooooool0003o000000;ooooo0_l00006ooooo`;o00000oooool6o`0000Gooooo0_l0
000<ooooo`;o00004oooool2o`0000[ooooo2?l00005ooooo`;o00001?ooool3o`0004Cooooo000L
ooooo`03o`000?oooooooooo03Cooooo0_l00005ooooo`;o00001?ooool3o`0000;ooooo0_l00008
ooooo`?o00002?ooool3o`0000Wooooo2_l000000ooooooo0000o`000006o`0000cooooo2ol00000
0ooooooo0000o`00000:o`000003ooooool0003o000000;o000000Goooooo`000?l0003o0000oooo
o`02o`0000Cooooo1_l00002ooooo`Go00004oooool2o`0000Kooooo0_l00004ooooo`;o00002Ooo
ool2o`0000Kooooo0_l00003ooooo`;o00001?ooool4o`0000Cooooo0_l0000Dooooo`;o0000;ooo
ool001cooooo00?o0000ooooooooool0>oooool2o`0000Wooooo0_l00004ooooo`?o000000Cooooo
o`000?l0003o00002Oooool2o`0000Wooooo4ol00002ooooo`;o00000ooooolPo`0000Cooooo0_l0
0007ooooo`;o000000Coooooo`000?l0003o00000_ooool4o`0001Kooooo0_l00004ooooo`;o0000
1?ooool2o`000003ooooool0003o000000Kooooo0_l0000;ooooo`?o00000oooool2o`0000Kooooo
0_l0000Dooooo`;o0000;oooool001cooooo00?o0000ooooooooool0C?ooool3o`0000?ooooo0_l0
0002ooooo`;o00001oooool2o`0000Kooooo4ol00002ooooo`;o000000?oooooo`000?l000008Ol0
0003ooooo`;o00002oooool5o`000003ooooool0003o000000;o00000oooool2o`0000oooooo0_l0
00000ooooooo0000o`000004ooooo`;o00000_ooool5o`000003ooooool0003o000000Cooooo0_l0
00000ooooooo0000o`000006ooooo`Go000000?oooooo`000?l00000COooool001cooooo00?o0000
ooooooooool0@oooool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000000ol00002
ooooo`;o00001oooool2o`0000Cooooo5_l00004oooooa_o000000?oooooo`000?l000000_l00000
0ooooooo0000o`000003ooooo`;o00002_ooool;o`0000?ooooo0_l0000Booooo`Co000000Cooooo
o`000?l0003o00000_ooool5o`000003ooooool0003o000000Cooooo1Ol00005ooooo`;o00000_oo
ool5o`000003ooooool0003o000004[ooooo000Looooo`03o`000?oooooooooo04?ooooo0ol00000
1?oooooo0000o`000?l00002ooooo`;o000000Coooooo`000?l0003o00002Oooool2o`0000;ooooo
0_l00004oooooaOo00000ooooolPo`0000?ooooo0_l0000=ooooo`;o00001?ooool2o`0000Oooooo
0ol00004ooooo`;o00001Oooool2o`0000Gooooo0_l000000ooooooo0000o`000004ooooo`;o0000
0oooool2o`0000Gooooo0_l00007ooooo`?o00000_ooool2o`0000;ooooo0ol000000ooooooo0000
o`000017ooooo`007?ooool00ol0003oooooooooo`0kooooo`;o00001oooool6o`00013ooooo0ol0
0004ooooo`;o00001Oooool=o`0000Cooooo0ol000000ooooooo0000o`00000Oo`0000Cooooo0ol0
000Kooooo`?o00001?ooool2o`0000Gooooo0_l00005ooooo`?o000000?oooooo`000?l000001?oo
ool2o`0000;ooooo1_l000001?oooooo0000o`000?l00007ooooo`;o00001_ooool3o`000004oooo
ool0003o0000ooooo`?o00000_ooool2o`0003oooooo000Looooo`03o`000?oooooooooo03Cooooo
0_l00005ooooo`Co00001Oooool4o`0000kooooo0_l00002ooooo`;o00000_ooool5o`0000Gooooo
0_l000000ooooooo0000o`000008o`0000Cooooo0_l00002oooooa[o000000?oooooo`000?l00000
1?l00005ooooo`;o00003?ooool2o`0000[ooooo0_l00005ooooo`;o00000_ooool2o`0000;ooooo
0_l000000ooooooo0000o`000004ooooo`?o000000?oooooo`000?l000001?ooool2o`0000;ooooo
1_l000001?oooooo0000o`000?l00007ooooo`;o00003Oooool3o`0000;ooooo0_l0000oooooo`00
7?ooool00ol0003oooooooooo`0dooooo`;o00001oooool2o`0000?ooooo0_l00005ooooo`;o0000
0oooool2o`0000Kooooo0_l00006ooooo`?o00001oooool2o`000003ooooool0003o000000?o0000
2OoooolMo`000003ooooool0003o000000Co00005?ooool2o`000003ooooool0003o000000Cooooo
0_l000000ooooooo0000o`000005ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000
o`000007ooooo`;o00001_ooool2o`000003ooooool0003o000000?o00006?ooool2o`0004Oooooo
000Looooo`03o`000?oooooooooo04;ooooo1?l00002ooooo`?o00000oooool2o`0000Sooooo0_l0
0008ooooo`Oo00000oooool2o`0000Wooooo7_l000000ooooooo0000o`000008o`0000;ooooo0_l0
000>ooooo`Ko00000_ooool2o`0000?ooooo1?l0000Dooooo`?o00001_ooool2o`0001kooooo0_l0
00000ooooooo0000o`000014ooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00002Oooool2
o`0000;ooooo0_l0000>ooooo`;o00002?ooool7o`000003ooooool0003o000000;o00001_ooool2
o`000003ooooool0003o000000ko000000?oooooo`000?l000002ol000000ooooooo0000o`000008
o`0000;ooooo0ol0000=ooooo`;o00000_ooool2o`0000Kooooo1Ol0000Dooooo`;o00001Oooool2
o`0000?ooooo0_l00005ooooo`;o00005oooool3o`0004?ooooo000Looooo`;o0000>_ooool2o`00
00[ooooo0_l0000Booooo`;o000000?oooooo`000?l000003?ooool4o`0000Cooooo2ol000000ooo
oooo0000o`00000No`0000Gooooo0_l0000:ooooo`;o00003Oooool2o`0000Cooooo0ol00003oooo
o`;o000000?oooooo`000?l000000_ooool2o`0000[ooooo1Ol000000ooooooo0000o`000002oooo
o`;o000000?oooooo`000?l000004oooool2o`0000?ooooo1Ol00010ooooo`007?ooool00ol0003o
ooooooooo`11ooooo`;o00000_ooool4o`0000;ooooo0_l00007ooooo`;o00000oooool2o`000003
ooooool0003o000000;o00001_ooool2o`000003ooooool0003o000000Oooooo0_l000000ooooooo
0000o`000002o`000004ooooool0003o0000ooooob;o00004?ooool2o`0000gooooo0_l000001?oo
oooo0000o`000?ooool3o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o00002_ooool5
o`0000Gooooo0_l00002ooooo`?o00000oooool2o`0000cooooo0_l00004ooooo`Co0000@?ooool0
01cooooo00?o0000ooooooooool0;_ooool2o`00017ooooo0_l00004ooooo`;o00000_ooool2o`00
00Oooooo0_l000000ooooooo0000o`000005ooooo`;o00001_ooool2o`000003ooooool0003o0000
00;o00002_ooool2o`000004ooooool0003o0000ooooob;o00008_ooool2o`000003ooooool0003o
000000Cooooo0_l0000>ooooo`Wo00002?ooool3o`0000?ooooo0_l0000?ooooo`;o000000?ooooo
o`000?l00000@_ooool001cooooo00?o0000ooooooooool0;_ooool2o`0001Oooooo0_l0000;oooo
o`;o000000?oooooo`000?l000001oooool2o`0000Oooooo1?l00003ooooo`;o00000oooool2o`00
00?ooooo0_l00003ooooob3o00002_ooool5o`0000cooooo0_l00008ooooo`;o00002Oooool2o`00
00Wooooo1_l000000ooooooo0000o`000003ooooo`;o00000_ooool2o`0000Gooooo0_l0000?oooo
o`;o0000AOooool001cooooo00?o0000ooooooooool0??ooool2o`0000Wooooo0_l0000;ooooo`;o
00002_ooool4o`0000?ooooo0ol00006ooooo`;o00000oooool2o`0000Cooooo0_l00006oooooago
00002Oooool7o`0000[ooooo0_l0000Cooooo`;o00000oooool4o`0000kooooo1_l00005ooooo`;o
0000E_ooool001cooooo00?o0000ooooooooool0??ooool2o`00027ooooo0_l000000ooooooo0000
o`000002ooooo`Co00002?ooool2o`0000Oooooo0_l00006ooooo`_o000000?oooooo`000?l00000
3ol00008ooooo`?o000000?oooooo`000?l000000_l00008ooooo`;o00002oooool6o`0000Wooooo
1_l0000>ooooo`Co00001Oooool2o`00013ooooo0_l00014ooooo`007?ooool00ol0003ooooooooo
o`1:ooooo`;o00000_ooool2o`0000oooooo0_l00005ooooo`Ko00000_ooool2o`0000;ooooo0_l0
00000ooooooo0000o`00000<oooooaOo000000?oooooo`000?l000000ol00008ooooo`;o00003_oo
ool2o`0000_ooooo1_l00003ooooo`?o00001oooool2o`00013ooooo0ol00007ooooo`;o00003?oo
ool3o`0004Cooooo000Looooo`03o`000?oooooooooo04Kooooo0_l00002ooooo`;o00000_ooool2
o`00017ooooo0_l000000ooooooo0000o`000004ooooo`;o00000_ooool2o`0000Gooooo0_l00000
0ooooooo0000o`000009ooooo`;o000000?oooooo`000?l000006?l00003ooooo`Co000000Cooooo
o`000?l0003o00001_ooool3o`0001;ooooo0_l000000ooooooo0000o`000003ooooo`?o00005?oo
ool2o`0000?ooooo0ol00007ooooo`;o00003?ooool2o`0004Gooooo000Looooo`03o`000?oooooo
oooo04?ooooo1Ol0000Iooooo`;o000000?oooooo`000?l000000_ooool2o`0000Oooooo0_l00005
ooooo`;o00003_ooool6o`000003ooooool0003o000000?o00000oooool6o`000003ooooool0003o
000000?ooooo1?l00002ooooo`;o00000oooool8o`0001?ooooo0_l0000?ooooo`;o00002Oooool2
o`0001Sooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`13ooooo`Co00005Oooool2o`00
00Cooooo0_l000001?oooooo0000o`000?ooool2o`0000Oooooo0_l0000;ooooo`;o00002?ooool3
o`0000Oooooo0_l00006ooooo`?o00001?ooool2o`0000_ooooo2?l000000ooooooo0000o`00000@
ooooo`;o00002_ooool2o`0000?ooooo0_l00005ooooo`;o00000_ooool2o`0000Kooooo0_l00000
0ooooooo0000o`000006ooooo`?o000000Coooooo`000?l0003ooooo0_l0000;ooooo`;o0000>ooo
ool001cooooo00?o0000ooooooooool0A?ooool3o`0001Gooooo0_l00004ooooo`;o000000?ooooo
o`000?l000005oooool2o`0000Sooooo0_l0000@ooooo`Co00000oooool2o`0000_ooooo3?l0000@
ooooo`;o00002Oooool4o`000004ooooool0003o0000ooooo`;o00000_ooool2o`000004ooooool0
003o0000o`0000Kooooo0_l000000ooooooo0000o`000006ooooo`?o000000?oooooo`000?l00000
0_l0000<ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0A?ooool2o`0000Oooooo0_l0
000Booooo`;o00007?ooool2o`0000;ooooo0_l00009ooooo`;o00002?ooool7o`0000_ooooo0_l0
0003ooooo`_o00003_ooool4o`0000Sooooo1Ol00004ooooo`Co00000oooool2o`0000Kooooo0_l0
0009ooooo`;o00000_ooool2o`000003ooooool0003o000004Wooooo000Looooo`03o`000?oooooo
oooo04_ooooo1?l0000Booooo`;o00007?ooool2o`0000;ooooo0_l00005ooooo`;o00000_ooool2
o`0000?ooooo0_l00003ooooo`Oo00002ooooolBo`0000Kooooo0_l00004ooooo`;o00002_ooool4
o`0000Oooooo0_l00007ooooo`Ko00002Oooool2o`0000;ooooo0_l0001<ooooo`007?ooool00ol0
003oooooooooo`1;ooooo`;o000000?oooooo`000?l00000=?ooool2o`0000Cooooo1?l00005oooo
o`;o00002?ooool2o`0000gooooo4?l00006ooooo`?o00003?ooool2o`0000Kooooo0_l0000=oooo
o`Co00000_ooool2o`0000_ooooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o
00005?ooool4o`0001cooooo0ol0000Cooooo`;o00000oooool5o`0000Gooooo0_l00005ooooo`;o
00000oooool2o`0000[ooooo4_l00002ooooo`;o00000_ooool4o`0000Cooooo0_l00004ooooo`;o
00000oooool5o`0000Sooooo0_l00002ooooo`;o00001Oooool2o`0000_ooooo0_l0001<ooooo`00
7?ooool00ol0003oooooooooo`0hooooo`;o00005_ooool2o`0001?ooooo0ol00006ooooo`?o0000
6?ooool2o`0000oooooo0_l00003ooooo`;o00002_oooolCo`000003ooooool0003o000000Cooooo
0_l00004ooooo`;o00002Oooool4o`0000Oooooo2?l0000@ooooo`;o0000C_ooool001cooooo0_l0
001Vooooo`?o00002oooool2o`0000?ooooo0_l0000Cooooo`;o00000oooool2o`0000oooooo0_l0
0002ooooo`;o00000ooooolCo`0000Oooooo0_l00003ooooo`;o00000oooool2o`0000Sooooo0ol0
0004ooooo`;o00000_ooool2o`0000Wooooo1?l00005ooooo`?o0000COooool001cooooo00?o0000
ooooooooool0I_ooool2o`0000_ooooo0_l00003ooooo`Co00004Oooool2o`0000?ooooo0_l0000?
ooooo`;o00000_ooool2o`0000?ooooo5Ol00005ooooo`;o00000oooool2o`0000?ooooo0_l00008
ooooo`?o00003_ooool2o`0000?ooooo1?l00006ooooo`;o0000COooool001cooooo00?o0000oooo
ooooool0Coooool4o`0001_ooooo0_l0000:ooooo`;o00007oooool2o`0000gooooo0_l00002oooo
o`Ko000000?oooooo`000?l000002ol00002ooooo`;o00003oooool3o`0001?ooooo0ol00003oooo
o`;o00001?ooool2o`00053ooooo000Looooo`03o`000?oooooooooo04oooooo1?l00003ooooo`;o
00001?ooool5o`0000Oooooo0_l00004ooooo`;o00001?ooool2o`0001?ooooo0_l0000@ooooo`;o
00003OoooolEo`000003ooooool0003o000000;ooooo0_l00008ooooo`;o000000?oooooo`000?l0
00001Ol000000ooooooo0000o`00000Aooooo`;o00000oooool2o`0000Cooooo0_l0001@ooooo`00
7?ooool00ol0003oooooooooo`1Cooooo`;o000000Goooooo`000?l0003o0000ooooo`07o`0000;o
oooo0_l00003ooooo`;o00002_ooool2o`0000gooooo0_l00004ooooo`;o00004_ooool2o`0000_o
oooo4_l000001?oooooo0000o`000?l0000>ooooo`;o000000?oooooo`000?l000000_l00004oooo
o`;o00001_ooool4o`0006Cooooo000Looooo`03o`000?oooooooooo05?ooooo0_l00002ooooo`;o
000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l00008ooooo`;o00001oooool2o`0000Oo
oooo0_l00002ooooo`;o00002Oooool2o`0000gooooo0_l00002ooooo`;o00001ooooolGo`0000Ko
oooo0_l00003ooooo`;o00001Oooool2o`000004ooooool0003o0000o`0000Sooooo1_l00003oooo
o`;o0000GOooool001cooooo00?o0000ooooooooool0Doooool2o`0000?ooooo1?l00002ooooo`;o
00002_ooool5o`0000;ooooo0_l00002ooooo`?o00001oooool4o`0000Cooooo0_l00005ooooo`;o
00001oooool2o`0000;ooooo0_l00004ooooo`Co00002_oooolCo`0000Gooooo0_l00003ooooo`;o
00001Oooool2o`000004ooooool0003o0000o`0000cooooo0ol00002ooooo`;o0000GOooool001co
oooo00?o0000ooooooooool0F?ooool2o`00013ooooo1?l00003ooooo`?o000000?oooooo`000?l0
00000_ooool2o`0000Kooooo0_l00004ooooo`;o00003_ooool2o`0000;ooooo0_l00006ooooo`;o
00002_oooolCo`0001Gooooo0ol0000<ooooo`;o00004oooool2o`0004cooooo000Looooo`03o`00
0?oooooooooo04gooooo0_l00009ooooo`;o00000oooool2o`0000Kooooo0_l00004ooooo`Go0000
0_ooool2o`0000Gooooo0_l0000;ooooo`;o00007?ooool3o`0000?ooooo0_l00003oooooa?o0000
3?ooool2o`0000Sooooo0ol0000Pooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0COoo
ool2o`0000Wooooo0_l00002ooooo`?o00001_ooool2o`0000Cooooo0_l000001?oooooo0000o`00
0?l00006ooooo`;o00003Oooool2o`0001cooooo0ol00003ooooo`Co000000?oooooo`000?l00000
4?l0000;ooooo`Co000000?oooooo`000?l000001Oooool3o`0000Oooooo0_l00002ooooo`;o0000
5Oooool2o`0004[ooooo000Looooo`03o`000?oooooooooo04cooooo0_l0000:ooooo`;o00000_oo
ool2o`0000_ooooo0_l000001?oooooo0000o`000?ooool2o`0000Kooooo1Ol0000Mooooo`;o0000
4Oooool2o`0000?ooooo4?l0000;ooooo`;o00000oooool2o`0000?ooooo0_l0000:ooooo`;o0000
00Coooooo`000?l0003o00002?ooool2o`0000_ooooo0_l0001:ooooo`007?ooool00ol0003ooooo
ooooo`1<ooooo`;o00002_ooool2o`0000;ooooo0ol0000:ooooo`;o000000Coooooo`000?l0003o
oooo0_l00004ooooo`Oo00006_ooool2o`000003ooooool0003o000001Kooooo4Ol0000<ooooo`;o
000000?oooooo`000?l000000_l000000ooooooo0000o`000002ooooo`;o00001?ooool2o`0000?o
oooo0_l00003ooooo`;o00001?ooool2o`0005Oooooo000Looooo`03o`000?oooooooooo04_ooooo
1?l0000=ooooo`Co000000?oooooo`000?l000004_ooool2o`0000Kooooo0_l0000Gooooo`;o0000
0oooool2o`00017ooooo0_l000000ooooooo0000o`00000@o`0000?ooooo0_l00006ooooo`Oo0000
00?oooooo`000?l000000_ooool2o`0000Cooooo0_l00008ooooo`;o00001?ooool2o`0005Oooooo
000Looooo`03o`000?oooooooooo04_ooooo1?l00006ooooo`;o00001oooool2o`000003ooooool0
003o000000Oooooo0_l00003ooooo`Co00002_ooool2o`0001Sooooo1_l00003ooooo`;o00000ooo
ool3o`0000Kooooo1?l000001Ooooooo0000o`000?l0003ooooo00co00000oooool2o`0000Oooooo
0_l0000<ooooo`;o0000J_ooool001cooooo00?o0000ooooooooool0Doooool4o`0001?ooooo0_l0
0003ooooo`Co00002Oooool2o`0001Wooooo1_l00002ooooo`?o00000oooool3o`0000Sooooo0_l0
00000ooooooo0000o`00000>o`0000?ooooo0_l0000@ooooo`;o00000oooool2o`0006[ooooo000L
ooooo`03o`000?oooooooooo05?ooooo0ol0000:ooooo`;o00003oooool2o`0000Wooooo0ol0000P
ooooo`;o00001Oooool2o`0000gooooo2ol000000ooooooo0000o`000002o`0000_ooooo0_l00006
ooooo`;o00006_ooool2o`0005?ooooo000Looooo`;o0000A?ooool2o`0001_ooooo0_l0000;oooo
o`;o00003Oooool3o`0001[ooooo0_l00002ooooo`;o00001oooool2o`0000gooooo1ol000001?oo
oooo0000o`000?l00003ooooo`;o00002oooool2o`0001Sooooo0_l00008ooooo`;o0000Doooool0
01cooooo00?o0000ooooooooool0@oooool2o`0002Sooooo0_l000000ooooooo0000o`00000Toooo
o`;o000000?oooooo`000?l000000_ooool2o`0001Gooooo0ol000000ooooooo0000o`000002o`00
01?ooooo0_l0000=ooooo`;o00001Oooool2o`0000?ooooo0_l0001Mooooo`007?ooool00ol0003o
ooooooooo`1`ooooo`;o00001_ooool2o`0000;ooooo1Ol0000:ooooo`;o00002Oooool2o`0000?o
oooo0_l00004ooooo`;o00004Oooool3o`000003ooooool0003o000000;o00000oooool3o`0000Oo
oooo0_l00004ooooo`?o00003?ooool4o`0000?ooooo0_l0001Rooooo`007?ooool00ol0003ooooo
ooooo`1Rooooo`;o00003oooool2o`0000?ooooo0ol000000ooooooo0000o`000003o`0000Oooooo
0_l000000ooooooo0000o`000009ooooo`Co000000?oooooo`000?l000000_ooool4o`0001Gooooo
1?l000000ooooooo0000o`000003o`0000;ooooo0_l00003ooooo`;o00001Oooool2o`0000kooooo
0_l0001Wooooo`007?ooool00ol0003oooooooooo`1Rooooo`;o00003oooool2o`0000Cooooo0_l0
000=ooooo`;o00003_ooool2o`0000Gooooo0_l00006ooooo`;o00003_ooool5o`000004ooooool0
003o0000o`0000Cooooo0_l0000Kooooo`;o0000I_ooool001cooooo00?o0000ooooooooool0GOoo
ool2o`0003_ooooo0_l0000;ooooo`;o00003_ooool2o`000003ooooool0003o000000;ooooo1?l0
000Booooo`;o00002?ooool5o`0006Kooooo000Looooo`03o`000?oooooooooo05gooooo0_l0000D
ooooo`;o00000_ooool2o`0000Cooooo0_l00007ooooo`;o00003oooool2o`000003ooooool0003o
000000kooooo0ol0000Cooooo`;o00004_ooool2o`0000Oooooo1Ol0001Wooooo`007?ooool00ol0
003oooooooooo`1Fooooo`;o00001Oooool2o`0001Cooooo0_l00002ooooo`;o00001?ooool2o`00
00Kooooo0ol0000?ooooo`;o00004Oooool3o`0000Cooooo0_l00003ooooo`;o00006?ooool2o`00
00_ooooo0_l000000ooooooo0000o`000005ooooo`;o0000H?ooool001cooooo00?o0000oooooooo
ool0E_ooool2o`0000Gooooo0_l0000Vooooo`;o000000?oooooo`000?l000001oooool2o`0001_o
oooo0_l000000ooooooo0000o`000003ooooo`;o00006?ooool2o`000003ooooool0003o000000Wo
oooo0_l00007ooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0GOooool2o`0000?ooooo
1?l0000?ooooo`;o00002oooool2o`0000Cooooo0_l00007ooooo`?o00006_ooool2o`0001?ooooo
0_l0000>ooooo`;o00002Oooool2o`0000_ooooo0_l0001Looooo`007?ooool00ol0003ooooooooo
o`1Rooooo`Go00003_ooool6o`0000Oooooo0_l00004ooooo`;o00002?ooool2o`0000?ooooo0_l0
000;ooooo`;o00005_ooool2o`0000Gooooo0_l00006ooooo`;o00001oooool2o`0001Gooooo0_l0
001Looooo`007?ooool00ol0003oooooooooo`1Sooooo`Co00004?ooool4o`0001Kooooo0_l00004
ooooo`;o00002oooool2o`0000Gooooo0_l0000?ooooo`;o00001Oooool2o`0000Kooooo0_l00006
ooooo`?o0000Loooool001cooooo00?o0000ooooooooool0HOooool4o`0002cooooo0_l0000Hoooo
o`;o00001?ooool2o`00023ooooo0_l00006ooooo`;o0000K?ooool001cooooo00?o0000oooooooo
ool0HOooool2o`0000Oooooo0_l00015ooooo`;o00008?ooool2o`0000Kooooo0_l0001/ooooo`00
00Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0Foooool2o`0000Cooooo0_l00007ooooo`;o00009oooool2
o`00017ooooo0_l0000Aooooo`;o00006?ooool2o`0007Cooooo00001_ooooooMgMgoiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`1Kooooo`;o0000=_ooool2o`0000Sooooo0_l00007ooooo`;o00004Oooool2o`0001Oooooo
0_l0001eooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`1Nooooo`;o0000<oooool2o`0000Sooooo
0_l0000=ooooo`?o00003oooool2o`0001;ooooo0_l0001eooooo`0000?oooooo`000?ooool00_oo
ool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`0005;ooooo
0_l00009ooooo`?o00009oooool2o`0000[ooooo0_l0000Gooooo`?o00003oooool2o`0008Wooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Goc<c<o`000?l0003o0000
olc<c006ooooo`03o`000?oooooooooo05;ooooo0_l00009ooooo`;o00008Oooool2o`0000Gooooo
0_l0000?ooooo`;o00006_ooool2o`0001Wooooo0_l0001hooooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooo
ooooo`1Tooooo`;o00006_ooool2o`0001Kooooo0_l000000ooooooo0000o`00000Gooooo`Co0000
5oooool2o`0007Sooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oo
oooo^[Zjo`000006ooooo`03o`000?oooooooooo06Cooooo0_l0000eooooo`;o00006Oooool3o`00
093ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o410@ojVY
Z@06ooooo`03o`000?oooooooooo06[ooooo0_l0000Tooooo`?o00009?ooool4o`0001kooooo0_l0
001^ooooo`007?ooool00ol0003oooooooooo`1Zooooo`;o00009?ooool3o`0002?ooooo1Ol0000N
ooooo`;o0000K_ooool001cooooo00?o0000ooooooooool0SOooool2o`0000Kooooo0_l0000Ooooo
o`Co00003_ooool2o`0007oooooo000Looooo`03o`000?oooooooooo08gooooo0ol00005ooooo`;o
00006Oooool2o`0000Kooooo0_l0000>ooooo`;o0000Ooooool001cooooo00?o0000ooooooooool0
S_ooool2o`00023ooooo0_l0002Gooooo`007?ooool00ol0003oooooooooo`1hooooo`;o00001?oo
ool4o`0002gooooo0_l0002Hooooo`007?ooool00ol0003oooooooooo`1`ooooo`;o00001_ooool2
o`0000Cooooo1?l0000]ooooo`;o0000V?ooool001cooooo00?o0000ooooooooool0L?ooool2o`00
00?ooooo0_l0001Cooooo`;o0000OOooool001cooooo00?o0000ooooooooool0MOooool2o`0004ko
oooo0_l00003ooooo`;o0000OOooool001cooooo00?o0000ooooooooool0aOooool2o`0008;ooooo
000Looooo`03o`000?oooooooooo0:Cooooo0_l0002Sooooo`007?ooool00ol0003oooooooooo`2=
ooooo`;o00005Oooool2o`000:?ooooo000Looooo`;o0000S_ooool2o`0003Gooooo0_l00023oooo
o`007?ooool00ol0003oooooooooo`2?ooooo`;o0000<oooool2o`0008?ooooo000Looooo`03o`00
0?oooooooooo08oooooo0_l000000ooooooo0000o`000005ooooo`;o0000[_ooool001cooooo00?o
0000ooooooooool0T_ooool2o`0000Gooooo0_l000000ooooooo0000o`000007ooooo`;o00000_oo
ool2o`0009kooooo000Looooo`03o`000?oooooooooo09cooooo0_l00007ooooo`;o00000_ooool2
o`0009kooooo000Looooo`03o`000?oooooooooo09cooooo0_l0002[ooooo`007?ooool00ol0003o
ooooooooo`2Looooo`;o0000Zoooool001cooooo00?o0000ooooooooool0]Oooool2o`0009;ooooo
000Looooo`03o`000?oooooooooo0;Gooooo0_l0002Booooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0Roooool2o`000;cooooo000Looooo`03o`000?oooooooooo08_ooooo0_l0002looooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001;ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oo
ooooB_ooool001Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood[ooooo
000Dooooo`03o`000?oooooooooo00Gooooo0ol0003ooooood[ooooo000Dooooo`03o`000?oooooo
oooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003o
ooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001;ooooo00?o
EEEEofIVI_l00000oooooomDooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
YOooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo01Gooooo00Co410@o`000?m4
A4Coc<c<1?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o410@olc<
c02@ooooo`00Y_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l0000;ooooo`03oiRHV?l@
413ogMgM00?ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B40T?ooool00:Kooooo00Go0000ooooooooooooooooo`00000Kooooo`03ohN7QomEEEGooooo00Ko
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo08kooooo002Vooooo`05
o`000?ooooooooooooooool000002Oooool6o`0000Wooooo00Goc<c<ob4Q8Ol0003oEEEEo`000006
ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oiRHV?ooooooV9RHob4Q8@2@ooooo`00Y_ooool0
1Ol0003oQhN7oooooonYZJWo000001Sooooo00Go8B4QohN7QoooooooV9RHo`000005ooooo`03oa0@
4?l0003o^[Zj00?ooooo00Go0000oeEEEOl0003o410@olc<c02@ooooo`00YOooool00ol@413o0000
ogMgM`02o`000003oiRHV?oooooooooo01Kooooo00Go0000ooooooooooooooooo`000006ooooo`03
okZj^_lQ8B7ooooo00;ooooo00?oEEEEohN7Qoooool0T_ooool00<?ooooo00Go8B4QoiRHV?oooooo
MgMgoeEEE@03ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool00ooMgMgo410@oiRHV02Boooo
o`00`oooool01Oo<c<co410@o`000?lb<S;ok^k^00?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@04
ooooo`04olc<c?m4A4Co0000oa0@493ooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(942) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.4862 .36543 Mdot
.47161 .31979 Mdot
.39964 .62707 Mdot
.64124 .47017 Mdot
.41966 .34006 Mdot
.44697 .62715 Mdot
.31364 .44491 Mdot
.3677 .4401 Mdot
.43063 .63361 Mdot
.55048 .57333 Mdot
.34977 .44791 Mdot
.67711 .46688 Mdot
.3396 .42648 Mdot
.62916 .4778 Mdot
.8011 .67833 Mdot
.60114 .55096 Mdot
.46217 .3013 Mdot
.51878 .69437 Mdot
.65625 .45047 Mdot
.38735 .61091 Mdot
.44864 .29012 Mdot
.62773 .4674 Mdot
.49507 .36116 Mdot
.6286 .47773 Mdot
.64857 .49419 Mdot
.47878 .34562 Mdot
.44623 .3546 Mdot
.65902 .48471 Mdot
.62217 .52645 Mdot
.35593 .41764 Mdot
.64225 .70553 Mdot
.84239 .56198 Mdot
.64472 .54573 Mdot
.39922 .20315 Mdot
.36318 .45133 Mdot
.77369 .44169 Mdot
.44946 .65849 Mdot
.33148 .41522 Mdot
.36457 .44508 Mdot
.37661 .43554 Mdot
.34433 .41957 Mdot
.48116 .3396 Mdot
.28266 .45135 Mdot
.3124 .48607 Mdot
.5707 .45476 Mdot
.35749 .35178 Mdot
.75587 .5683 Mdot
.58741 .50144 Mdot
.45679 .31635 Mdot
.39072 .60891 Mdot
.37673 .22648 Mdot
.34754 .40564 Mdot
.31857 .58772 Mdot
.81792 .29604 Mdot
.31959 .42184 Mdot
.58402 .44368 Mdot
.43881 .64987 Mdot
.61227 .46501 Mdot
.62347 .47525 Mdot
.63866 .38776 Mdot
.65123 .51472 Mdot
.53151 .72878 Mdot
.48979 .28529 Mdot
.47144 .60411 Mdot
.44328 .63389 Mdot
.36358 .44115 Mdot
.47329 .30186 Mdot
.3328 .42993 Mdot
.60124 .42757 Mdot
.47548 .63624 Mdot
.5871 .50011 Mdot
.35955 .43527 Mdot
.52042 .34628 Mdot
.58055 .48112 Mdot
.20395 .48636 Mdot
.67665 .78507 Mdot
.53149 .75901 Mdot
.66744 .38574 Mdot
.72323 .43508 Mdot
.48367 .78929 Mdot
.62314 .51394 Mdot
.37984 .81745 Mdot
.76587 .71052 Mdot
.48082 .36316 Mdot
.54115 .52266 Mdot
.4881 .66082 Mdot
.58173 .4719 Mdot
.4689 .43389 Mdot
.5659 .44688 Mdot
.23041 .40554 Mdot
.42527 .63539 Mdot
.49386 .32297 Mdot
.64108 .47197 Mdot
.62036 .53738 Mdot
.58184 .2873 Mdot
.66715 .49283 Mdot
.64927 .46757 Mdot
.47997 .37416 Mdot
.34196 .45713 Mdot
.69069 .49237 Mdot
.34272 .48095 Mdot
.35592 .59528 Mdot
.58645 .45058 Mdot
.42979 .6565 Mdot
.49217 .37704 Mdot
.57959 .46622 Mdot
.32838 .46533 Mdot
.60013 .51936 Mdot
.30145 .48543 Mdot
.46972 .31524 Mdot
.61754 .53771 Mdot
.55124 .70238 Mdot
.21391 .60363 Mdot
.49803 .32361 Mdot
.36857 .57935 Mdot
.60268 .5265 Mdot
.61991 .4546 Mdot
.47396 .32188 Mdot
.44256 .61041 Mdot
.49934 .48625 Mdot
.44837 .31998 Mdot
.37453 .44352 Mdot
.45696 .29783 Mdot
.55446 .53825 Mdot
.42893 .62563 Mdot
.34715 .59961 Mdot
.33623 .60109 Mdot
.6066 .66454 Mdot
.58501 .46708 Mdot
.35757 .27431 Mdot
.44643 .61911 Mdot
.4895 .32673 Mdot
.33614 .43195 Mdot
.55475 .47767 Mdot
.50676 .32133 Mdot
.33466 .44619 Mdot
.56187 .7386 Mdot
.37584 .66541 Mdot
.45245 .32329 Mdot
.26971 .45041 Mdot
.3775 .41813 Mdot
.37917 .43728 Mdot
.37831 .21138 Mdot
.46682 .32214 Mdot
.5468 .7113 Mdot
.32899 .44271 Mdot
.71197 .6637 Mdot
.58801 .43789 Mdot
.55857 .62843 Mdot
.27225 .75285 Mdot
.35459 .23308 Mdot
.26601 .55709 Mdot
.51928 .70303 Mdot
.3825 .43704 Mdot
.63913 .51404 Mdot
.46286 .33257 Mdot
.46973 .33508 Mdot
.6469 .45669 Mdot
.65015 .48221 Mdot
.58342 .49411 Mdot
.61789 .53601 Mdot
.77185 .58945 Mdot
.58603 .51428 Mdot
.58318 .76509 Mdot
.50052 .33273 Mdot
.65165 .50407 Mdot
.42245 .60653 Mdot
.56723 .50919 Mdot
.3537 .42545 Mdot
.6197 .46217 Mdot
.64461 .47121 Mdot
.62061 .54052 Mdot
.31089 .42817 Mdot
.82961 .54511 Mdot
.2494 .71461 Mdot
.7904 .38074 Mdot
.33002 .55686 Mdot
.45854 .64252 Mdot
.59231 .45719 Mdot
.54438 .7258 Mdot
.74525 .40083 Mdot
.62359 .50181 Mdot
.18689 .37768 Mdot
.64385 .46449 Mdot
.51051 .21435 Mdot
.69164 .43705 Mdot
.7903 .36642 Mdot
.54838 .65592 Mdot
.62467 .52875 Mdot
.59152 .26082 Mdot
.65073 .24547 Mdot
.36211 .50289 Mdot
.33979 .41906 Mdot
.41866 .60745 Mdot
.43012 .64918 Mdot
.33344 .40076 Mdot
.70103 .49242 Mdot
.67275 .4357 Mdot
.60327 .41743 Mdot
.33489 .59372 Mdot
.52508 .32126 Mdot
.53581 .75019 Mdot
.49474 .37447 Mdot
.49525 .86101 Mdot
.25009 .37645 Mdot
.28077 .45754 Mdot
.54641 .76274 Mdot
.4028 .621 Mdot
.33207 .59208 Mdot
.5493 .72721 Mdot
.60379 .50087 Mdot
.46554 .30973 Mdot
.51018 .18397 Mdot
.71117 .48971 Mdot
.51246 .16682 Mdot
.5045 .3084 Mdot
.4912 .48546 Mdot
.34423 .4416 Mdot
.37767 .61868 Mdot
.62649 .4546 Mdot
.59676 .48563 Mdot
.46834 .27785 Mdot
.58914 .49954 Mdot
.4303 .29336 Mdot
.63487 .45432 Mdot
.38329 .63643 Mdot
.52762 .75634 Mdot
.32946 .40101 Mdot
.59659 .66316 Mdot
.51111 .35506 Mdot
.51576 .6677 Mdot
.45096 .6061 Mdot
.75294 .42966 Mdot
.35874 .4402 Mdot
.55781 .71131 Mdot
.45229 .60884 Mdot
.5289 .74392 Mdot
.57249 .51195 Mdot
.45902 .65695 Mdot
.52644 .70631 Mdot
.79924 .57966 Mdot
.55956 .46762 Mdot
.76557 .62531 Mdot
.31557 .44835 Mdot
.45891 .2963 Mdot
.65388 .5097 Mdot
.36719 .60201 Mdot
.64428 .54181 Mdot
.23587 .50251 Mdot
.32163 .59655 Mdot
.31705 .58252 Mdot
.51484 .78809 Mdot
.54802 .70242 Mdot
.23276 .55509 Mdot
.34423 .26909 Mdot
.46294 .30217 Mdot
.61348 .43952 Mdot
.81677 .43356 Mdot
.32981 .4424 Mdot
.60776 .50398 Mdot
.45571 .67513 Mdot
.32696 .44085 Mdot
.60864 .46508 Mdot
.30807 .44519 Mdot
.46649 .3307 Mdot
.32612 .72177 Mdot
.46498 .29872 Mdot
.56078 .46256 Mdot
.31854 .45902 Mdot
.46788 .63524 Mdot
.47753 .34842 Mdot
.59993 .51576 Mdot
.61701 .44824 Mdot
.34346 .59289 Mdot
.64391 .51909 Mdot
.81186 .45851 Mdot
.63559 .53096 Mdot
.4039 .63739 Mdot
.66477 .49709 Mdot
.22525 .32587 Mdot
.35084 .67807 Mdot
.47184 .30251 Mdot
.31904 .5828 Mdot
.43395 .63815 Mdot
.43797 .75799 Mdot
.35931 .51755 Mdot
.61155 .52137 Mdot
.34056 .58286 Mdot
.53657 .62924 Mdot
.34127 .40866 Mdot
.66361 .4663 Mdot
.2679 .38134 Mdot
.41801 .60478 Mdot
.33512 .59153 Mdot
.56234 .42485 Mdot
.49786 .37797 Mdot
.64247 .47305 Mdot
.47122 .63679 Mdot
.45188 .30102 Mdot
.5639 .48038 Mdot
.70879 .57441 Mdot
.3248 .597 Mdot
.31551 .44409 Mdot
.63539 .4073 Mdot
.58376 .50427 Mdot
.44701 .65536 Mdot
.51689 .34115 Mdot
.36351 .45389 Mdot
.48763 .34359 Mdot
.57819 .20244 Mdot
.29877 .56066 Mdot
.78075 .55268 Mdot
.55988 .76535 Mdot
.26971 .50996 Mdot
.77648 .33915 Mdot
.23398 .5924 Mdot
.68271 .65301 Mdot
.65094 .2096 Mdot
.44835 .60954 Mdot
.41435 .67279 Mdot
.43661 .64294 Mdot
.63641 .50041 Mdot
.44478 .6298 Mdot
.78939 .35588 Mdot
.63905 .45723 Mdot
.45465 .64933 Mdot
.36868 .73997 Mdot
.6539 .48656 Mdot
.49959 .32294 Mdot
.79704 .67492 Mdot
.18561 .48362 Mdot
.27408 .31289 Mdot
.46072 .62724 Mdot
.62416 .39856 Mdot
.65785 .48491 Mdot
.6021 .54592 Mdot
.46319 .34208 Mdot
.66437 .47406 Mdot
.53531 .74881 Mdot
.54746 .76059 Mdot
.5411 .60577 Mdot
.28771 .73881 Mdot
.68916 .4888 Mdot
.47386 .34773 Mdot
.73562 .46039 Mdot
.21248 .46543 Mdot
.36452 .59264 Mdot
.3305 .47736 Mdot
.82544 .56151 Mdot
.69625 .46783 Mdot
.27392 .43083 Mdot
.25724 .39735 Mdot
.48141 .31254 Mdot
.81577 .51608 Mdot
.33201 .41899 Mdot
.64724 .28836 Mdot
.54295 .27938 Mdot
.60129 .4911 Mdot
.35503 .44739 Mdot
.68266 .47671 Mdot
.21243 .40339 Mdot
.71611 .6837 Mdot
.52051 .82638 Mdot
.56394 .46028 Mdot
.21806 .53767 Mdot
.62086 .45841 Mdot
.5066 .48552 Mdot
.63705 .53051 Mdot
.4895 .34782 Mdot
.57994 .57749 Mdot
.42928 .45889 Mdot
.28804 .75691 Mdot
.253 .36542 Mdot
.51854 .70573 Mdot
.62079 .45151 Mdot
.6014 .48973 Mdot
.55792 .72372 Mdot
.49929 .35402 Mdot
.62078 .53403 Mdot
.62826 .61729 Mdot
.588 .49027 Mdot
.34307 .41703 Mdot
.60171 .69462 Mdot
.44759 .27844 Mdot
.63455 .53845 Mdot
.44528 .31064 Mdot
.31246 .42974 Mdot
.36622 .4367 Mdot
.55028 .45512 Mdot
.35601 .46617 Mdot
.6392 .46344 Mdot
.64314 .7552 Mdot
.46675 .35641 Mdot
.7156 .47301 Mdot
.50878 .34777 Mdot
.70629 .40814 Mdot
.32271 .46387 Mdot
.35522 .60285 Mdot
.50124 .26215 Mdot
.33305 .42074 Mdot
.30208 .28734 Mdot
.62555 .42095 Mdot
.67052 .51576 Mdot
.23136 .37745 Mdot
.46247 .62429 Mdot
.33579 .59922 Mdot
.34069 .46719 Mdot
.58293 .5017 Mdot
.67241 .48558 Mdot
.32371 .41374 Mdot
.61408 .30652 Mdot
.4397 .74908 Mdot
.65627 .47695 Mdot
.49207 .35128 Mdot
.49003 .32917 Mdot
.56823 .4793 Mdot
.60781 .51541 Mdot
.40827 .62586 Mdot
.32425 .58412 Mdot
.35366 .58762 Mdot
.3328 .59973 Mdot
.39051 .6415 Mdot
.39622 .33633 Mdot
.37726 .43621 Mdot
.37156 .2879 Mdot
.23984 .4413 Mdot
.65455 .55257 Mdot
.45858 .65239 Mdot
.6063 .48353 Mdot
.63646 .46763 Mdot
.36318 .4549 Mdot
.30363 .53586 Mdot
.54596 .53226 Mdot
.45636 .34315 Mdot
.33696 .46851 Mdot
.67966 .45312 Mdot
.4114 .27383 Mdot
.52495 .71853 Mdot
.26461 .31804 Mdot
.36086 .43876 Mdot
.48629 .31148 Mdot
.30222 .43691 Mdot
.59582 .48832 Mdot
.6143 .43473 Mdot
.47879 .31877 Mdot
.53569 .69578 Mdot
.57246 .42605 Mdot
.60745 .46329 Mdot
.14256 .54599 Mdot
.20043 .49571 Mdot
.35095 .38377 Mdot
.63311 .52291 Mdot
.67148 .49988 Mdot
.51794 .72182 Mdot
.59156 .49079 Mdot
.61499 .44607 Mdot
.21289 .62379 Mdot
.35536 .37967 Mdot
.51819 .69133 Mdot
.65568 .29355 Mdot
.50277 .30658 Mdot
.82843 .48948 Mdot
.35268 .58873 Mdot
.29617 .41989 Mdot
.31062 .69978 Mdot
.32982 .58893 Mdot
.24098 .49647 Mdot
.82351 .50534 Mdot
.33311 .59939 Mdot
.5013 .64001 Mdot
.54565 .5436 Mdot
.65076 .46493 Mdot
.6152 .45698 Mdot
.5417 .71926 Mdot
.46589 .32432 Mdot
.51793 .5913 Mdot
.72101 .70577 Mdot
.62585 .46252 Mdot
.42907 .34113 Mdot
.80494 .59214 Mdot
.34 .59041 Mdot
.54073 .74883 Mdot
.56666 .73268 Mdot
.61587 .45251 Mdot
.23317 .64081 Mdot
.47679 .34546 Mdot
.60044 .51596 Mdot
.58559 .51809 Mdot
.46231 .63083 Mdot
.47378 .30655 Mdot
.462 .61303 Mdot
.32741 .60023 Mdot
.68622 .25998 Mdot
.13575 .51022 Mdot
.35444 .46161 Mdot
.79527 .44586 Mdot
.35233 .41244 Mdot
.53636 .81382 Mdot
.32509 .59031 Mdot
.62247 .50913 Mdot
.51452 .352 Mdot
.59808 .51786 Mdot
.61223 .49888 Mdot
.60402 .4995 Mdot
.64696 .4305 Mdot
.19472 .36652 Mdot
.54481 .73774 Mdot
.57266 .54504 Mdot
.40655 .63885 Mdot
.80294 .45651 Mdot
.73119 .72729 Mdot
.59945 .47916 Mdot
.6085 .44947 Mdot
.50298 .32294 Mdot
.64982 .45801 Mdot
.33582 .40953 Mdot
.51729 .34107 Mdot
.61132 .53989 Mdot
.80823 .51445 Mdot
.61293 .53337 Mdot
.77752 .35401 Mdot
.30188 .43571 Mdot
.29903 .29189 Mdot
.56127 .5339 Mdot
.3427 .60216 Mdot
.3354 .59923 Mdot
.32954 .57685 Mdot
.29759 .44322 Mdot
.45096 .65337 Mdot
.66645 .7647 Mdot
.66757 .53834 Mdot
.64197 .50906 Mdot
.6733 .48538 Mdot
.43697 .66868 Mdot
.46931 .42896 Mdot
.24924 .56628 Mdot
.67153 .44239 Mdot
.41997 .62094 Mdot
.45786 .29564 Mdot
.42629 .58622 Mdot
.51363 .34772 Mdot
.51488 .69457 Mdot
.35114 .4454 Mdot
.52622 .72971 Mdot
.33285 .25293 Mdot
.47104 .31702 Mdot
.46975 .27694 Mdot
.45776 .64513 Mdot
.47676 .47858 Mdot
.80224 .29483 Mdot
.47701 .63847 Mdot
.6233 .64285 Mdot
.46774 .34835 Mdot
.59087 .52672 Mdot
.56701 .66179 Mdot
.475 .46908 Mdot
.4501 .64576 Mdot
.62898 .49872 Mdot
.26536 .68631 Mdot
.40891 .62453 Mdot
.66376 .4656 Mdot
.43592 .61187 Mdot
.3536 .42871 Mdot
.44438 .61584 Mdot
.52182 .32336 Mdot
.58245 .46216 Mdot
.81958 .31465 Mdot
.53653 .66304 Mdot
.63726 .5283 Mdot
.33433 .46813 Mdot
.6302 .60345 Mdot
.61495 .48888 Mdot
.54458 .75607 Mdot
.42781 .62406 Mdot
.4486 .73017 Mdot
.65877 .49197 Mdot
.45409 .63018 Mdot
.49297 .36382 Mdot
.29646 .43798 Mdot
.54118 .80185 Mdot
.35744 .60029 Mdot
.46029 .33757 Mdot
.32537 .60222 Mdot
.31948 .4682 Mdot
.67089 .49468 Mdot
.58232 .5097 Mdot
.49656 .34156 Mdot
.33464 .74918 Mdot
.66153 .50023 Mdot
.62333 .51358 Mdot
.39627 .61994 Mdot
.4352 .66646 Mdot
.34552 .74907 Mdot
.45319 .61229 Mdot
.64235 .43953 Mdot
.49557 .34196 Mdot
.63931 .47826 Mdot
.49712 .31605 Mdot
.62144 .44359 Mdot
.50862 .38823 Mdot
.47723 .36163 Mdot
.26592 .61578 Mdot
.63472 .48938 Mdot
.67854 .428 Mdot
.60783 .49862 Mdot
.58765 .49561 Mdot
.41024 .63303 Mdot
.54964 .7434 Mdot
.55081 .49266 Mdot
.57593 .7268 Mdot
.54775 .75272 Mdot
.60364 .22148 Mdot
.46137 .62593 Mdot
.53435 .71377 Mdot
.77562 .61392 Mdot
.32159 .58088 Mdot
.54011 .72928 Mdot
.75203 .70959 Mdot
.35774 .45974 Mdot
.48644 .29416 Mdot
.65355 .48695 Mdot
.63119 .20155 Mdot
.6593 .7275 Mdot
.34509 .588 Mdot
.63438 .53067 Mdot
.60943 .48419 Mdot
.44926 .34053 Mdot
.45646 .85363 Mdot
.39798 .6339 Mdot
.63983 .49902 Mdot
.47883 .30084 Mdot
.31321 .8003 Mdot
.41597 .64666 Mdot
.54139 .72592 Mdot
.31779 .41679 Mdot
.50252 .38282 Mdot
.3595 .59959 Mdot
.33407 .40776 Mdot
.28359 .62367 Mdot
.30383 .28064 Mdot
.60169 .52652 Mdot
.45788 .65474 Mdot
.32548 .24705 Mdot
.69542 .50285 Mdot
.34067 .38866 Mdot
.53567 .42264 Mdot
.48475 .31364 Mdot
.3269 .41364 Mdot
.52176 .72138 Mdot
.52038 .33156 Mdot
.49537 .35486 Mdot
.36954 .43939 Mdot
.48236 .60414 Mdot
.48853 .48184 Mdot
.35072 .41984 Mdot
.23352 .40868 Mdot
.53566 .19298 Mdot
.32876 .58127 Mdot
.55324 .74782 Mdot
.46931 .20311 Mdot
.48177 .34025 Mdot
.82616 .55809 Mdot
.27321 .29772 Mdot
.64969 .46807 Mdot
.53715 .7066 Mdot
.38313 .37333 Mdot
.6947 .74228 Mdot
.32364 .44053 Mdot
.42808 .4385 Mdot
.56047 .70684 Mdot
.65938 .47822 Mdot
.55788 .38765 Mdot
.63201 .50371 Mdot
.34684 .44492 Mdot
.71144 .42754 Mdot
.48744 .31151 Mdot
.33163 .47053 Mdot
.26608 .31552 Mdot
.63398 .4621 Mdot
.63157 .49653 Mdot
.62426 .69742 Mdot
.46176 .31147 Mdot
.35858 .59253 Mdot
.60724 .52469 Mdot
.6128 .46251 Mdot
.66032 .52398 Mdot
.66302 .42211 Mdot
.21959 .61161 Mdot
.63912 .49742 Mdot
.36531 .62354 Mdot
.61465 .54734 Mdot
.63329 .487 Mdot
.44599 .31088 Mdot
.14501 .485 Mdot
.35505 .60411 Mdot
.61752 .46179 Mdot
.60454 .52931 Mdot
.36785 .44626 Mdot
.51219 .56378 Mdot
.46874 .46335 Mdot
.46544 .65606 Mdot
.71414 .63564 Mdot
.64846 .43144 Mdot
.50711 .31816 Mdot
.55848 .70984 Mdot
.57127 .48909 Mdot
.50323 .31449 Mdot
.57791 .53166 Mdot
.41421 .62138 Mdot
.32752 .58227 Mdot
.27876 .32262 Mdot
.53499 .724 Mdot
.6413 .7322 Mdot
.36319 .30481 Mdot
.41038 .60915 Mdot
.64573 .50371 Mdot
.31388 .40814 Mdot
.46248 .65643 Mdot
.34571 .59398 Mdot
.54551 .45264 Mdot
.46889 .33852 Mdot
.49626 .32423 Mdot
.55245 .63022 Mdot
.33799 .62957 Mdot
.17971 .60863 Mdot
.35446 .43107 Mdot
.60057 .5427 Mdot
.34612 .27351 Mdot
.49695 .32355 Mdot
.56477 .64475 Mdot
.53308 .71429 Mdot
.32199 .44096 Mdot
.35472 .58419 Mdot
.50411 .31961 Mdot
.45475 .31543 Mdot
.56031 .47039 Mdot
.5971 .4695 Mdot
.67197 .6538 Mdot
.54832 .61919 Mdot
.31505 .42275 Mdot
.55886 .7335 Mdot
.46697 .61427 Mdot
.63381 .50853 Mdot
.4839 .36367 Mdot
.50852 .19256 Mdot
.60035 .52869 Mdot
.40672 .62693 Mdot
.48522 .31648 Mdot
.55669 .71679 Mdot
.54442 .75463 Mdot
.5882 .49496 Mdot
.66292 .39838 Mdot
.31905 .42834 Mdot
.49804 .32142 Mdot
.42095 .23045 Mdot
.66086 .50425 Mdot
.59397 .46678 Mdot
.55403 .424 Mdot
.36271 .42337 Mdot
.30314 .29171 Mdot
.5393 .69401 Mdot
.47534 .33232 Mdot
.61921 .53152 Mdot
.53152 .72737 Mdot
.32733 .27665 Mdot
.33144 .58542 Mdot
.43964 .61389 Mdot
.54335 .75588 Mdot
.55118 .71237 Mdot
.55732 .74683 Mdot
.82461 .57341 Mdot
.52532 .33177 Mdot
.72479 .49555 Mdot
.64735 .52253 Mdot
.55312 .63277 Mdot
.55486 .46053 Mdot
.30146 .43143 Mdot
.46249 .62175 Mdot
.6098 .4959 Mdot
.56091 .46961 Mdot
.59986 .40352 Mdot
.70761 .45638 Mdot
.4343 .31041 Mdot
.47023 .31201 Mdot
.64944 .55189 Mdot
.46408 .63301 Mdot
.46623 .86453 Mdot
.80088 .33139 Mdot
.55013 .52325 Mdot
.49613 .5097 Mdot
.49294 .3614 Mdot
.37081 .43333 Mdot
.45626 .46103 Mdot
.3047 .44362 Mdot
.48054 .33069 Mdot
.63532 .50486 Mdot
.37596 .29079 Mdot
.52789 .74666 Mdot
.58189 .49709 Mdot
.33855 .44192 Mdot
.5825 .49574 Mdot
.32767 .41074 Mdot
.44961 .25187 Mdot
.22625 .42299 Mdot
.64418 .46443 Mdot
.6604 .51233 Mdot
.55268 .40041 Mdot
.60147 .47795 Mdot
.41956 .81481 Mdot
.50011 .35624 Mdot
.27325 .71061 Mdot
.56233 .48088 Mdot
.68621 .37336 Mdot
.65401 .51448 Mdot
.29344 .7005 Mdot
.59072 .47172 Mdot
.42765 .49408 Mdot
.65368 .47025 Mdot
.59591 .4502 Mdot
.31312 .4539 Mdot
.36775 .44598 Mdot
.47955 .3677 Mdot
.36123 .59512 Mdot
.79537 .39639 Mdot
.60263 .46367 Mdot
.38198 .62894 Mdot
.30275 .39732 Mdot
.55594 .72163 Mdot
.48158 .33304 Mdot
.33269 .81903 Mdot
.30901 .43992 Mdot
.45845 .60324 Mdot
.34599 .76405 Mdot
.37381 .61627 Mdot
.3948 .4083 Mdot
.52247 .53157 Mdot
.54045 .69855 Mdot
.66122 .48544 Mdot
.41313 .20558 Mdot
.20735 .49238 Mdot
.55814 .43887 Mdot
.32094 .46717 Mdot
.74532 .4125 Mdot
.47251 .20588 Mdot
.56445 .74903 Mdot
.52095 .70901 Mdot
.31106 .44004 Mdot
.38919 .62078 Mdot
.64169 .43226 Mdot
.5317 .71406 Mdot
.41244 .61272 Mdot
.32062 .57794 Mdot
.39373 .50097 Mdot
.477 .34238 Mdot
.26683 .31884 Mdot
.34244 .33951 Mdot
.31244 .42578 Mdot
.50828 .67456 Mdot
.49395 .38425 Mdot
.51459 .36875 Mdot
.36377 .59982 Mdot
.40934 .63418 Mdot
.52316 .33118 Mdot
.63222 .43412 Mdot
.71154 .45481 Mdot
.62271 .46131 Mdot
.54616 .71775 Mdot
.59281 .47709 Mdot
.41182 .62854 Mdot
.3279 .43724 Mdot
.41872 .64262 Mdot
.31207 .44775 Mdot
.39189 .32207 Mdot
.60024 .51035 Mdot
.59721 .45105 Mdot
.65207 .73442 Mdot
.46834 .36231 Mdot
.38019 .22816 Mdot
.38915 .6439 Mdot
.4355 .64679 Mdot
.62187 .44623 Mdot
.50794 .35589 Mdot
.53184 .76342 Mdot
.64721 .74061 Mdot
.57751 .49637 Mdot
.5016 .3558 Mdot
.6402 .50494 Mdot
.78559 .5913 Mdot
.18931 .5042 Mdot
.49028 .34003 Mdot
.31169 .77339 Mdot
.62639 .52234 Mdot
.60435 .57763 Mdot
.67273 .47888 Mdot
.64408 .62453 Mdot
.66266 .49886 Mdot
.50519 .30891 Mdot
.62138 .46485 Mdot
.51874 .33017 Mdot
.39438 .61518 Mdot
.37332 .43057 Mdot
.46197 .34542 Mdot
.57887 .50729 Mdot
.85111 .52499 Mdot
.35033 .44081 Mdot
.62312 .45308 Mdot
.33614 .45705 Mdot
.48748 .3007 Mdot
.45521 .32292 Mdot
.69199 .75412 Mdot
.33632 .38229 Mdot
.35203 .42724 Mdot
.64335 .49278 Mdot
.31019 .33866 Mdot
.63909 .48606 Mdot
.6558 .65753 Mdot
.57167 .4583 Mdot
.6637 .49872 Mdot
.66767 .79517 Mdot
.34689 .40921 Mdot
.18594 .61 Mdot
.73347 .68982 Mdot
.82 .58666 Mdot
.52159 .37265 Mdot
.56446 .74845 Mdot
.81824 .52272 Mdot
.32351 .59817 Mdot
.43697 .61918 Mdot
.60854 .49573 Mdot
.47145 .26018 Mdot
.331 .41462 Mdot
.55069 .74076 Mdot
.64301 .46325 Mdot
.40604 .63043 Mdot
.49129 .76039 Mdot
.38 .44517 Mdot
.48111 .33883 Mdot
.45745 .34807 Mdot
.28475 .76838 Mdot
.61979 .53207 Mdot
.61062 .44759 Mdot
.34847 .44626 Mdot
.70504 .4709 Mdot
.55607 .71026 Mdot
.3592 .72539 Mdot
.35176 .42779 Mdot
.47923 .52402 Mdot
.46666 .31624 Mdot
.60794 .48442 Mdot
.48294 .43308 Mdot
.358 .53039 Mdot
.649 .26624 Mdot
.54406 .72248 Mdot
.65511 .6675 Mdot
.50477 .30844 Mdot
.33599 .43536 Mdot
.38798 .672 Mdot
.63342 .54538 Mdot
.61132 .47934 Mdot
.65168 .67121 Mdot
.52631 .61111 Mdot
.57488 .77891 Mdot
.62988 .44121 Mdot
.52639 .60583 Mdot
.61167 .44171 Mdot
.65546 .53069 Mdot
.62421 .43405 Mdot
.58895 .46503 Mdot
.4993 .35763 Mdot
.62792 .41162 Mdot
.44936 .62265 Mdot
.58629 .28392 Mdot
.43858 .44039 Mdot
.65197 .51048 Mdot
.63603 .49789 Mdot
.69904 .30585 Mdot
.27621 .40621 Mdot
.48468 .35905 Mdot
.5135 .30079 Mdot
.36183 .46247 Mdot
.67577 .4253 Mdot
.39448 .63929 Mdot
.58686 .40993 Mdot
.41695 .63915 Mdot
.50726 .35248 Mdot
.43498 .65021 Mdot
.37649 .44785 Mdot
.45817 .65481 Mdot
.38972 .64158 Mdot
.33124 .41206 Mdot
.45986 .32177 Mdot
.58159 .48366 Mdot
.33901 .46823 Mdot
.62657 .69537 Mdot
.54516 .7174 Mdot
.69458 .75236 Mdot
.58873 .53633 Mdot
.42383 .40941 Mdot
.70821 .5757 Mdot
.42052 .64252 Mdot
.19004 .55468 Mdot
.47575 .36102 Mdot
.52102 .74046 Mdot
.50598 .35464 Mdot
.24473 .31895 Mdot
.55344 .74228 Mdot
.75793 .70416 Mdot
.30926 .61003 Mdot
.4824 .73759 Mdot
.61251 .43276 Mdot
.5396 .38454 Mdot
.47332 .63762 Mdot
.32942 .41503 Mdot
.29853 .6054 Mdot
.5879 .45447 Mdot
.23912 .5966 Mdot
.46703 .36343 Mdot
.32881 .57824 Mdot
.33515 .42959 Mdot
.33914 .47002 Mdot
.59732 .52134 Mdot
.3953 .76297 Mdot
.57731 .46106 Mdot
.32353 .62634 Mdot
.69082 .65345 Mdot
.56484 .41243 Mdot
.63275 .45341 Mdot
.42966 .65531 Mdot
.64093 .50373 Mdot
.73608 .49157 Mdot
.38403 .20967 Mdot
.61681 .42309 Mdot
.29394 .56868 Mdot
.50428 .69632 Mdot
.47516 .31908 Mdot
.5606 .53096 Mdot
.35248 .59594 Mdot
.6294 .52328 Mdot
.37055 .17878 Mdot
.53808 .73016 Mdot
.4824 .67571 Mdot
.64733 .52558 Mdot
.60296 .52302 Mdot
.5251 .26877 Mdot
.48003 .26056 Mdot
.3539 .58309 Mdot
.6131 .47434 Mdot
.71007 .65451 Mdot
.35152 .45447 Mdot
.5738 .46847 Mdot
.61612 .45557 Mdot
.63849 .2358 Mdot
.36429 .42964 Mdot
.42413 .64639 Mdot
.31924 .58842 Mdot
.45944 .60932 Mdot
.53635 .68437 Mdot
.45116 .4765 Mdot
.56222 .63474 Mdot
.19251 .49862 Mdot
.56332 .74348 Mdot
.60371 .53336 Mdot
.5476 .53641 Mdot
.61712 .52448 Mdot
.52017 .71699 Mdot
.35929 .42139 Mdot
.47691 .35908 Mdot
.28398 .32572 Mdot
.33654 .59325 Mdot
.66572 .46932 Mdot
.52856 .74159 Mdot
.46423 .33453 Mdot
.52734 .66972 Mdot
.47459 .32559 Mdot
.3428 .42357 Mdot
.30797 .46746 Mdot
.54014 .74447 Mdot
.51245 .34784 Mdot
.35695 .61652 Mdot
.71452 .71097 Mdot
.58008 .45009 Mdot
.38998 .42041 Mdot
.49736 .36414 Mdot
.44517 .35094 Mdot
.48472 .37371 Mdot
.59241 .50277 Mdot
.5018 .52447 Mdot
.63916 .53882 Mdot
.3125 .4336 Mdot
.42655 .61295 Mdot
.5552 .6206 Mdot
.46838 .22655 Mdot
.5131 .63118 Mdot
.55688 .45547 Mdot
.63117 .46345 Mdot
.61624 .45263 Mdot
.56954 .45114 Mdot
.36186 .6569 Mdot
.60517 .51374 Mdot
.31311 .45293 Mdot
.4188 .63045 Mdot
.6488 .51877 Mdot
.35369 .59287 Mdot
.48937 .46939 Mdot
.56136 .71441 Mdot
.44186 .4648 Mdot
.83454 .47781 Mdot
.46339 .33666 Mdot
.46246 .61555 Mdot
.43996 .62014 Mdot
.56212 .73746 Mdot
.33022 .41619 Mdot
.46939 .32462 Mdot
.66534 .61982 Mdot
.55864 .74134 Mdot
.61822 .46371 Mdot
.29649 .67029 Mdot
.27044 .64613 Mdot
.66032 .47486 Mdot
.6186 .49794 Mdot
.31792 .58374 Mdot
.39074 .62553 Mdot
.5511 .15888 Mdot
.57917 .67491 Mdot
.54483 .74502 Mdot
.53131 .69852 Mdot
.50598 .37362 Mdot
.54327 .51936 Mdot
.31388 .44077 Mdot
.60834 .70509 Mdot
.59992 .60893 Mdot
.62816 .73509 Mdot
.5283 .80871 Mdot
.58695 .51131 Mdot
.55636 .33667 Mdot
.63733 .46337 Mdot
.45592 .3523 Mdot
.46944 .30156 Mdot
.47709 .35432 Mdot
.31868 .42441 Mdot
.71324 .40961 Mdot
.32175 .46086 Mdot
.82614 .43053 Mdot
.51192 .31433 Mdot
.39074 .69121 Mdot
.44413 .65213 Mdot
.57973 .54202 Mdot
.55348 .70931 Mdot
.38505 .45547 Mdot
.605 .428 Mdot
.22496 .62534 Mdot
.45752 .65336 Mdot
.45958 .31662 Mdot
.52478 .5339 Mdot
.74626 .29694 Mdot
.47328 .48248 Mdot
.6651 .55391 Mdot
.53301 .28936 Mdot
.55799 .73135 Mdot
.64605 .26661 Mdot
.52455 .69414 Mdot
.33053 .44424 Mdot
.58783 .45734 Mdot
.58244 .46993 Mdot
.6209 .44289 Mdot
.60398 .51186 Mdot
.36648 .4529 Mdot
.55981 .50159 Mdot
.22524 .3259 Mdot
.32309 .58198 Mdot
.7927 .5762 Mdot
.52688 .71631 Mdot
.30414 .45462 Mdot
.41827 .63276 Mdot
.35254 .58566 Mdot
.58589 .65465 Mdot
.65404 .47243 Mdot
.60924 .49783 Mdot
.37003 .59759 Mdot
.63914 .44466 Mdot
.66037 .43467 Mdot
.45018 .62528 Mdot
.5143 .62981 Mdot
.55416 .75938 Mdot
.52572 .72752 Mdot
.35617 .4212 Mdot
.51067 .35035 Mdot
.53748 .71594 Mdot
.39525 .62104 Mdot
.56784 .52135 Mdot
.57854 .51103 Mdot
.49622 .36509 Mdot
.27115 .2993 Mdot
.5675 .73619 Mdot
.5276 .53948 Mdot
.51243 .32036 Mdot
.52607 .33358 Mdot
.61326 .47953 Mdot
.57393 .41911 Mdot
.44681 .35731 Mdot
.55274 .75566 Mdot
.30535 .45706 Mdot
.47904 .71404 Mdot
.33825 .44585 Mdot
.46584 .3274 Mdot
.56555 .48249 Mdot
.46243 .31849 Mdot
.63204 .52546 Mdot
.77285 .74971 Mdot
.58496 .47069 Mdot
.19273 .45452 Mdot
.63895 .63465 Mdot
.44011 .62317 Mdot
.35874 .61594 Mdot
.34564 .58513 Mdot
.51042 .31626 Mdot
.57034 .49266 Mdot
.52987 .69717 Mdot
.795 .64249 Mdot
.4844 .38478 Mdot
.42135 .61769 Mdot
.39154 .63402 Mdot
.3437 .40982 Mdot
.63922 .53085 Mdot
.60678 .48098 Mdot
.45308 .65678 Mdot
.73221 .56939 Mdot
.50888 .32767 Mdot
.6145 .44856 Mdot
.63383 .47315 Mdot
.44496 .62478 Mdot
.71019 .71428 Mdot
.53373 .31955 Mdot
.59036 .45808 Mdot
.45088 .68489 Mdot
.29968 .43496 Mdot
.58309 .44229 Mdot
.55913 .49924 Mdot
.54148 .70422 Mdot
.79737 .52445 Mdot
.40638 .19788 Mdot
.30474 .42704 Mdot
.35875 .59323 Mdot
.60727 .53701 Mdot
.44563 .65157 Mdot
.57938 .51051 Mdot
.77902 .41391 Mdot
.32713 .5797 Mdot
.61553 .5155 Mdot
.54111 .5057 Mdot
.46459 .30447 Mdot
.60542 .51729 Mdot
.68672 .28089 Mdot
.47659 .62818 Mdot
.61076 .51693 Mdot
.63749 .39073 Mdot
.36476 .43788 Mdot
.54897 .52046 Mdot
.52392 .71339 Mdot
.64597 .62098 Mdot
.36315 .31648 Mdot
.45769 .67134 Mdot
.52667 .72705 Mdot
.57814 .48931 Mdot
.38712 .61838 Mdot
.314 .42161 Mdot
.23031 .59192 Mdot
.63281 .44766 Mdot
.34749 .44385 Mdot
.32901 .43563 Mdot
.53395 .73313 Mdot
.20276 .65384 Mdot
.56107 .5188 Mdot
.59859 .47854 Mdot
.69216 .27884 Mdot
.44674 .32263 Mdot
.58936 .47934 Mdot
.60079 .53034 Mdot
.31951 .456 Mdot
.50052 .2606 Mdot
.72916 .37227 Mdot
.36601 .73804 Mdot
.32005 .41239 Mdot
.48949 .63337 Mdot
.38632 .6172 Mdot
.52814 .71469 Mdot
.48198 .32071 Mdot
.55317 .69758 Mdot
.45852 .62636 Mdot
.61046 .53208 Mdot
.31921 .45118 Mdot
.55995 .21995 Mdot
.35079 .40711 Mdot
.46774 .65901 Mdot
.44837 .34728 Mdot
.33322 .28931 Mdot
.29996 .22086 Mdot
.35305 .34173 Mdot
.28278 .45345 Mdot
.55569 .72104 Mdot
.28862 .62974 Mdot
.63296 .46951 Mdot
.63679 .27037 Mdot
.58256 .48907 Mdot
.57778 .37794 Mdot
.44889 .61171 Mdot
.3658 .59855 Mdot
.5879 .45841 Mdot
.67706 .66274 Mdot
.37573 .42061 Mdot
.33984 .4087 Mdot
.61277 .50935 Mdot
.3337 .42051 Mdot
.60135 .46973 Mdot
.41246 .63391 Mdot
.17358 .5729 Mdot
.6279 .4585 Mdot
.66777 .51565 Mdot
.26574 .42358 Mdot
.70939 .74178 Mdot
.35399 .62524 Mdot
.55186 .32638 Mdot
.71398 .26274 Mdot
.33294 .42112 Mdot
.53882 .46818 Mdot
.46797 .64748 Mdot
.31755 .58374 Mdot
.35589 .61545 Mdot
.58862 .48683 Mdot
.59221 .49218 Mdot
.62301 .44691 Mdot
.6316 .49782 Mdot
.64315 .27286 Mdot
.6846 .44268 Mdot
.58473 .35358 Mdot
.61116 .49946 Mdot
.55826 .38526 Mdot
.34245 .4666 Mdot
.45238 .28837 Mdot
.56388 .7089 Mdot
.58837 .51319 Mdot
.4384 .28252 Mdot
.30008 .44202 Mdot
.82563 .42812 Mdot
.35495 .41561 Mdot
.43407 .63701 Mdot
.36823 .42511 Mdot
.64072 .52196 Mdot
.49074 .32931 Mdot
.47367 .646 Mdot
.22941 .53941 Mdot
.43487 .61897 Mdot
.63717 .52845 Mdot
.47789 .69351 Mdot
.44092 .61885 Mdot
.47789 .44935 Mdot
.4902 .32464 Mdot
.70243 .66544 Mdot
.47003 .30094 Mdot
.61374 .51809 Mdot
.61837 .51683 Mdot
.30791 .58799 Mdot
.37666 .42949 Mdot
.48424 .29877 Mdot
.14418 .55749 Mdot
.52986 .6893 Mdot
.48092 .35306 Mdot
.641 .54852 Mdot
.51672 .58105 Mdot
.49666 .3342 Mdot
.70871 .61703 Mdot
.32573 .41623 Mdot
.52311 .33758 Mdot
.64106 .54681 Mdot
.27698 .47932 Mdot
.53093 .75241 Mdot
.41054 .64741 Mdot
.42849 .51867 Mdot
.47398 .63278 Mdot
.30282 .4564 Mdot
.44843 .66598 Mdot
.35158 .45646 Mdot
.36654 .23846 Mdot
.719 .45047 Mdot
.32142 .40349 Mdot
.31156 .46605 Mdot
.45755 .64047 Mdot
.63592 .45272 Mdot
.41305 .45638 Mdot
.62703 .43862 Mdot
.59503 .43226 Mdot
.35647 .45156 Mdot
.49537 .30216 Mdot
.48433 .29255 Mdot
.54453 .38595 Mdot
.45661 .34745 Mdot
.41432 .63802 Mdot
.1889 .50058 Mdot
.33858 .24886 Mdot
.354 .446 Mdot
.33837 .47264 Mdot
.63835 .48948 Mdot
.45089 .6502 Mdot
.40072 .6111 Mdot
.31653 .43958 Mdot
.5894 .24605 Mdot
.63378 .5407 Mdot
.4429 .34377 Mdot
.51497 .3173 Mdot
.49323 .34166 Mdot
.49442 .37538 Mdot
.70951 .35812 Mdot
.32642 .41536 Mdot
.51095 .31481 Mdot
.61533 .51152 Mdot
.59158 .4903 Mdot
.34048 .5996 Mdot
.52447 .72362 Mdot
.58313 .53634 Mdot
.65563 .44747 Mdot
.61276 .48238 Mdot
.43938 .61453 Mdot
.59016 .55967 Mdot
.34785 .58413 Mdot
.40133 .63846 Mdot
.39696 .64502 Mdot
.35145 .60281 Mdot
.5374 .38999 Mdot
.71789 .25781 Mdot
.63975 .4995 Mdot
.71431 .49591 Mdot
.4441 .6491 Mdot
.20116 .58712 Mdot
.31015 .28853 Mdot
.6265 .4465 Mdot
.3752 .51916 Mdot
.45083 .66172 Mdot
.44948 .32681 Mdot
.58617 .48288 Mdot
.32665 .59622 Mdot
.56096 .71463 Mdot
.6516 .54529 Mdot
.31885 .5903 Mdot
.51457 .34205 Mdot
.57252 .73856 Mdot
.52125 .34651 Mdot
.45754 .66087 Mdot
.5425 .50907 Mdot
.80164 .29026 Mdot
.45405 .60809 Mdot
.77096 .66056 Mdot
.46268 .25598 Mdot
.61857 .44839 Mdot
.46617 .61696 Mdot
.44715 .3283 Mdot
.29836 .44929 Mdot
.52236 .58915 Mdot
.46762 .35656 Mdot
.3606 .5931 Mdot
.33019 .59515 Mdot
.44789 .62335 Mdot
.47342 .31046 Mdot
.56998 .47254 Mdot
.48594 .30783 Mdot
.36683 .42318 Mdot
.64582 .47441 Mdot
.78703 .35378 Mdot
.71136 .48146 Mdot
.50629 .31245 Mdot
.40369 .63244 Mdot
.51847 .72696 Mdot
.65081 .47275 Mdot
.76466 .65425 Mdot
.62162 .5358 Mdot
.34862 .45285 Mdot
.25651 .68582 Mdot
.58475 .22508 Mdot
.65439 .51243 Mdot
.63765 .49077 Mdot
.3268 .41278 Mdot
.65292 .47223 Mdot
.66038 .50122 Mdot
.32235 .3882 Mdot
.47467 .30466 Mdot
.62514 .46613 Mdot
.40301 .61492 Mdot
.41055 .21402 Mdot
.63954 .53734 Mdot
.3583 .56681 Mdot
.69117 .66761 Mdot
.24465 .68469 Mdot
.57904 .48248 Mdot
.59486 .68024 Mdot
.62752 .49876 Mdot
.5883 .50507 Mdot
.64261 .48807 Mdot
.54858 .30528 Mdot
.45961 .63858 Mdot
.41674 .62421 Mdot
.534 .75504 Mdot
.6961 .66366 Mdot
.5373 .70546 Mdot
.34302 .41242 Mdot
.49853 .78117 Mdot
.32885 .58041 Mdot
.5144 .34524 Mdot
.57462 .47494 Mdot
.47916 .63107 Mdot
.6061 .48671 Mdot
.63884 .52167 Mdot
.42616 .65479 Mdot
.41143 .60589 Mdot
.43612 .67576 Mdot
.53864 .69629 Mdot
.46927 .35205 Mdot
.55946 .46889 Mdot
.54715 .7526 Mdot
.57018 .47724 Mdot
.54256 .64084 Mdot
.4747 .35564 Mdot
.47745 .30434 Mdot
.45951 .29955 Mdot
.61078 .53231 Mdot
.65051 .51112 Mdot
.32441 .46218 Mdot
.51167 .35319 Mdot
.35876 .4277 Mdot
.46867 .6496 Mdot
.44244 .60082 Mdot
.58876 .48704 Mdot
.56534 .57289 Mdot
.53921 .7008 Mdot
.42761 .63698 Mdot
.36952 .59493 Mdot
.51739 .73176 Mdot
.62677 .53252 Mdot
.43203 .65647 Mdot
.5271 .73396 Mdot
.56312 .24918 Mdot
.67703 .22155 Mdot
.5183 .72046 Mdot
.61522 .50907 Mdot
.51083 .25419 Mdot
.69355 .72355 Mdot
.52559 .68988 Mdot
.33381 .45358 Mdot
.60843 .53336 Mdot
.72227 .54536 Mdot
.56514 .71852 Mdot
.40551 .22399 Mdot
.43931 .62485 Mdot
.30598 .49629 Mdot
.68613 .50885 Mdot
.62149 .27367 Mdot
.54323 .69025 Mdot
.47218 .32861 Mdot
.45297 .2945 Mdot
.62181 .48366 Mdot
.54868 .68827 Mdot
.33168 .40707 Mdot
.43191 .62519 Mdot
.37428 .62251 Mdot
.47572 .30918 Mdot
.28843 .35879 Mdot
.41073 .61669 Mdot
.53906 .55467 Mdot
.32265 .71659 Mdot
.69376 .43669 Mdot
.59349 .39142 Mdot
.21906 .48077 Mdot
.594 .53082 Mdot
.51779 .70909 Mdot
.30415 .44794 Mdot
.31143 .44389 Mdot
.34908 .42747 Mdot
.36096 .61613 Mdot
.45351 .4612 Mdot
.46393 .64627 Mdot
.23384 .57489 Mdot
.53146 .72634 Mdot
.72908 .64596 Mdot
.5718 .48479 Mdot
.63028 .46229 Mdot
.59855 .54255 Mdot
.58086 .45548 Mdot
.62827 .49064 Mdot
.33347 .41689 Mdot
.364 .61905 Mdot
.44398 .72954 Mdot
.49432 .35013 Mdot
.50534 .63504 Mdot
.44387 .65221 Mdot
.31869 .58283 Mdot
.54691 .73887 Mdot
.50662 .49728 Mdot
.45153 .66901 Mdot
.43401 .64915 Mdot
.57815 .53615 Mdot
.5014 .31657 Mdot
.58396 .41343 Mdot
.62413 .5124 Mdot
.42366 .6375 Mdot
.42786 .59376 Mdot
.73144 .34722 Mdot
.53369 .45366 Mdot
.55039 .77112 Mdot
.50718 .54763 Mdot
.52355 .69202 Mdot
.67769 .49083 Mdot
.20475 .59784 Mdot
.45841 .62738 Mdot
.44184 .63623 Mdot
.52369 .73069 Mdot
.58482 .57325 Mdot
.48133 .31463 Mdot
.36629 .59786 Mdot
.33682 .45944 Mdot
.61564 .523 Mdot
.42922 .60144 Mdot
.65977 .56188 Mdot
.42228 .76405 Mdot
.3524 .43288 Mdot
.40066 .63572 Mdot
.64139 .52881 Mdot
.61603 .50693 Mdot
.55783 .72528 Mdot
.41792 .3242 Mdot
.65569 .54688 Mdot
.82139 .58442 Mdot
.22933 .42007 Mdot
.24011 .3877 Mdot
.61115 .47921 Mdot
.47198 .30744 Mdot
.32575 .59036 Mdot
.55512 .74523 Mdot
.56084 .48944 Mdot
.68843 .23154 Mdot
.43714 .31871 Mdot
.33517 .44066 Mdot
.32914 .59764 Mdot
.45516 .45853 Mdot
.61525 .53544 Mdot
.58285 .48845 Mdot
.59743 .50653 Mdot
.6134 .17315 Mdot
.41839 .61666 Mdot
.46169 .35783 Mdot
.54619 .72423 Mdot
.45634 .34885 Mdot
.42575 .6214 Mdot
.29415 .32769 Mdot
.65774 .49882 Mdot
.44435 .34339 Mdot
.47537 .32894 Mdot
.34415 .41017 Mdot
.29785 .45074 Mdot
.49272 .67528 Mdot
.58599 .46981 Mdot
.32487 .59499 Mdot
.46642 .30151 Mdot
.38054 .61469 Mdot
.5547 .74057 Mdot
.32991 .46639 Mdot
.61031 .50033 Mdot
.45289 .62258 Mdot
.56567 .43009 Mdot
.50022 .33062 Mdot
.43501 .64936 Mdot
.36345 .60374 Mdot
.52806 .7022 Mdot
.60015 .49523 Mdot
.54459 .77097 Mdot
.36603 .60098 Mdot
.63472 .47236 Mdot
.5149 .46162 Mdot
.54822 .77665 Mdot
.24224 .55444 Mdot
.46825 .63399 Mdot
.35015 .59892 Mdot
.45713 .30522 Mdot
.40218 .2376 Mdot
.4381 .63335 Mdot
.50943 .47508 Mdot
.40882 .34798 Mdot
.55926 .46734 Mdot
.48499 .34138 Mdot
.29419 .64553 Mdot
.83324 .53082 Mdot
.74682 .65029 Mdot
.6212 .45344 Mdot
.46916 .62197 Mdot
.53337 .74522 Mdot
.35437 .44624 Mdot
.35709 .56697 Mdot
.72884 .47511 Mdot
.43123 .66126 Mdot
.64058 .49197 Mdot
.47219 .30155 Mdot
.31884 .4362 Mdot
.38458 .29192 Mdot
.39797 .62633 Mdot
.45376 .61383 Mdot
.64947 .51881 Mdot
.53296 .7167 Mdot
.76644 .57154 Mdot
.41008 .62875 Mdot
.43467 .60193 Mdot
.27907 .61949 Mdot
.52717 .74021 Mdot
.62272 .4997 Mdot
.54653 .38514 Mdot
.57257 .44789 Mdot
.77612 .6584 Mdot
.35253 .58895 Mdot
.49708 .34942 Mdot
.58393 .49424 Mdot
.35759 .73942 Mdot
.42383 .63304 Mdot
.49354 .50301 Mdot
.47393 .60606 Mdot
.32414 .4172 Mdot
.43747 .60169 Mdot
.59479 .48215 Mdot
.3739 .41817 Mdot
.53891 .70106 Mdot
.59044 .46022 Mdot
.65103 .50893 Mdot
.44951 .33428 Mdot
.3296 .44517 Mdot
.50242 .21041 Mdot
.3316 .47094 Mdot
.30195 .43688 Mdot
.47946 .28768 Mdot
.62028 .47194 Mdot
.43392 .64013 Mdot
.44617 .66485 Mdot
.56101 .48027 Mdot
.17845 .53848 Mdot
.48109 .31249 Mdot
.51189 .67043 Mdot
.56806 .16738 Mdot
.53443 .43747 Mdot
.37419 .59933 Mdot
.41951 .34448 Mdot
.32562 .41007 Mdot
.61253 .50503 Mdot
.51013 .32096 Mdot
.39643 .60739 Mdot
.40975 .61618 Mdot
.56689 .47927 Mdot
.32429 .43497 Mdot
.5647 .73056 Mdot
.44376 .60742 Mdot
.39638 .76222 Mdot
.59863 .51316 Mdot
.24383 .59677 Mdot
.45308 .61081 Mdot
.81143 .63285 Mdot
.43536 .7416 Mdot
.48717 .34385 Mdot
.64192 .51807 Mdot
.45832 .34756 Mdot
.54922 .72241 Mdot
.49201 .64826 Mdot
.3261 .43663 Mdot
.53002 .47039 Mdot
.33225 .21998 Mdot
.45845 .64404 Mdot
.49823 .35789 Mdot
.65294 .51495 Mdot
.52098 .49524 Mdot
.59548 .4761 Mdot
.50965 .26641 Mdot
.51141 .67565 Mdot
.35919 .44818 Mdot
.34512 .45388 Mdot
.63691 .46978 Mdot
.56071 .72427 Mdot
.41354 .64609 Mdot
.43323 .62611 Mdot
.54516 .8778 Mdot
.37141 .60226 Mdot
.66969 .64905 Mdot
.59507 .49349 Mdot
.38145 .61756 Mdot
.46443 .22405 Mdot
.34931 .44596 Mdot
.57736 .45781 Mdot
.38367 .62551 Mdot
.25543 .45915 Mdot
.53558 .63126 Mdot
.62595 .49214 Mdot
.6797 .45736 Mdot
.33728 .45818 Mdot
.64665 .71984 Mdot
.46095 .65123 Mdot
.57483 .45695 Mdot
.35422 .46909 Mdot
.33467 .73805 Mdot
.34212 .23616 Mdot
.46955 .35204 Mdot
.48193 .63193 Mdot
.33319 .41665 Mdot
.67704 .53251 Mdot
.52612 .71861 Mdot
.47632 .63251 Mdot
.43341 .6156 Mdot
.647 .49143 Mdot
.57797 .53822 Mdot
.53122 .4427 Mdot
.50166 .35336 Mdot
.35166 .46418 Mdot
.58543 .45813 Mdot
.2866 .3628 Mdot
.61517 .44235 Mdot
.33814 .4652 Mdot
.88971 .40995 Mdot
.6005 .43378 Mdot
.59791 .47553 Mdot
.76522 .58946 Mdot
.46455 .35423 Mdot
.45408 .34222 Mdot
.21254 .44504 Mdot
.59558 .49362 Mdot
.46669 .74779 Mdot
.46537 .34871 Mdot
.48587 .31452 Mdot
.37478 .69154 Mdot
.64027 .46297 Mdot
.64345 .74014 Mdot
.31338 .44441 Mdot
.30802 .44674 Mdot
.48314 .30742 Mdot
.66612 .54166 Mdot
.31266 .42059 Mdot
.67857 .30489 Mdot
.4507 .65325 Mdot
.20558 .6049 Mdot
.50311 .33345 Mdot
.41698 .42907 Mdot
.35339 .44072 Mdot
.82727 .43499 Mdot
.36567 .5236 Mdot
.62685 .44909 Mdot
.60092 .50004 Mdot
.53542 .70148 Mdot
.56286 .44422 Mdot
.35382 .58769 Mdot
.3342 .42026 Mdot
.77032 .53639 Mdot
.47728 .3539 Mdot
.5906 .46984 Mdot
.50935 .51518 Mdot
.38478 .31353 Mdot
.28415 .57637 Mdot
.47554 .31995 Mdot
.47983 .34327 Mdot
.46455 .63508 Mdot
.44233 .61058 Mdot
.62377 .47838 Mdot
.31323 .43468 Mdot
.51375 .35188 Mdot
.34477 .46279 Mdot
.45728 .62458 Mdot
.43322 .64579 Mdot
.32547 .57952 Mdot
.64234 .44325 Mdot
.41336 .64348 Mdot
.37872 .76216 Mdot
.28398 .35791 Mdot
.51245 .37076 Mdot
.38412 .19032 Mdot
.38513 .28983 Mdot
.69035 .59216 Mdot
.5349 .6938 Mdot
.37045 .60701 Mdot
.3716 .44139 Mdot
.63778 .48661 Mdot
.60767 .49244 Mdot
.34003 .59005 Mdot
.37007 .41915 Mdot
.55269 .73552 Mdot
.37315 .42204 Mdot
.53046 .73013 Mdot
.38069 .6102 Mdot
.62729 .53955 Mdot
.59127 .52348 Mdot
.33815 .41821 Mdot
.42745 .64935 Mdot
.41738 .62852 Mdot
.52301 .69344 Mdot
.53782 .61407 Mdot
.44831 .62222 Mdot
.50239 .33239 Mdot
.69531 .35874 Mdot
.32976 .59257 Mdot
.58734 .48159 Mdot
.55862 .639 Mdot
.61818 .25186 Mdot
.56825 .45636 Mdot
.33967 .6016 Mdot
.42726 .84596 Mdot
.57622 .47774 Mdot
.3545 .81709 Mdot
.34979 .59965 Mdot
.46612 .3564 Mdot
.46705 .62068 Mdot
.34791 .58272 Mdot
.69162 .50137 Mdot
.51059 .70032 Mdot
.56949 .51348 Mdot
.46068 .34725 Mdot
.44871 .30665 Mdot
.23045 .38412 Mdot
.7715 .66158 Mdot
.5233 .69674 Mdot
.54091 .74145 Mdot
.43962 .63209 Mdot
.63155 .80241 Mdot
.61949 .54941 Mdot
.54717 .74358 Mdot
.75478 .54963 Mdot
.63722 .49946 Mdot
.64453 .66191 Mdot
.38196 .51789 Mdot
.47418 .30782 Mdot
.53874 .39318 Mdot
.43086 .6318 Mdot
.4931 .35946 Mdot
.27293 .3498 Mdot
.59261 .53871 Mdot
.47713 .356 Mdot
.33405 .46397 Mdot
.24402 .5026 Mdot
.45558 .3271 Mdot
.55008 .64342 Mdot
.31509 .43724 Mdot
.30754 .63551 Mdot
.74728 .58746 Mdot
.2749 .21957 Mdot
.32772 .42006 Mdot
.44078 .65834 Mdot
.44997 .66207 Mdot
.43691 .62693 Mdot
.47359 .36101 Mdot
.39325 .61588 Mdot
.50658 .34767 Mdot
.68714 .73756 Mdot
.53991 .61414 Mdot
.53981 .74491 Mdot
.31582 .38629 Mdot
.47757 .33564 Mdot
.203 .54491 Mdot
.31281 .21521 Mdot
.61107 .51027 Mdot
.33981 .47128 Mdot
.5228 .72682 Mdot
.78736 .69458 Mdot
.53894 .70281 Mdot
.46907 .64512 Mdot
.20703 .62139 Mdot
.59927 .46713 Mdot
.75642 .41967 Mdot
.52612 .70031 Mdot
.46777 .31987 Mdot
.63346 .46834 Mdot
.34929 .61397 Mdot
.53081 .71283 Mdot
.56332 .7222 Mdot
.62946 .47793 Mdot
.45975 .31501 Mdot
.4314 .64245 Mdot
.37378 .44357 Mdot
.52235 .6874 Mdot
.70145 .49817 Mdot
.55974 .46127 Mdot
.59647 .53639 Mdot
.47392 .47171 Mdot
.7442 .53118 Mdot
.33158 .42152 Mdot
.71024 .68887 Mdot
.43821 .61086 Mdot
.31945 .66776 Mdot
.22047 .44411 Mdot
.38437 .39112 Mdot
.3544 .59123 Mdot
.343 .58219 Mdot
.62684 .48748 Mdot
.74481 .53289 Mdot
.2722 .69851 Mdot
.26895 .41574 Mdot
.32908 .59049 Mdot
.42712 .62613 Mdot
.44912 .29758 Mdot
.23089 .36278 Mdot
.55711 .46065 Mdot
.3167 .41196 Mdot
.44744 .61894 Mdot
.77823 .41061 Mdot
.53508 .72212 Mdot
.20261 .57731 Mdot
.65272 .51243 Mdot
.59821 .45069 Mdot
.33597 .42676 Mdot
.31973 .45914 Mdot
.30443 .55753 Mdot
.22718 .4005 Mdot
.60999 .72858 Mdot
.42158 .24465 Mdot
.77092 .4007 Mdot
.44933 .29182 Mdot
.50426 .31041 Mdot
.32858 .60103 Mdot
.32277 .46664 Mdot
.58029 .49087 Mdot
.51462 .34743 Mdot
.28055 .58039 Mdot
.52746 .37981 Mdot
.65771 .66156 Mdot
.44682 .75575 Mdot
.63004 .52898 Mdot
.49722 .31156 Mdot
.48444 .36037 Mdot
.51024 .36305 Mdot
.34558 .6024 Mdot
.61222 .47422 Mdot
.64134 .45877 Mdot
.59253 .44963 Mdot
.69976 .46585 Mdot
.60224 .51615 Mdot
.2827 .38336 Mdot
.48439 .52865 Mdot
.78214 .5288 Mdot
.58045 .44741 Mdot
.30787 .44081 Mdot
.5874 .53231 Mdot
.56153 .72667 Mdot
.64102 .48843 Mdot
.65877 .65476 Mdot
.34485 .43804 Mdot
.56384 .56237 Mdot
.41757 .24379 Mdot
.65571 .50526 Mdot
.56122 .75011 Mdot
.72406 .55707 Mdot
.49846 .21645 Mdot
.50519 .62007 Mdot
.50204 .33066 Mdot
.43172 .66497 Mdot
.36396 .42032 Mdot
.43697 .64094 Mdot
.597 .44071 Mdot
.32711 .59868 Mdot
.36742 .36887 Mdot
.41745 .43377 Mdot
.58117 .50178 Mdot
.57669 .55067 Mdot
.49582 .32121 Mdot
.43347 .65681 Mdot
.47486 .27471 Mdot
.59108 .50034 Mdot
.54453 .72019 Mdot
.52928 .71763 Mdot
.25229 .38774 Mdot
.78918 .38698 Mdot
.38911 .23669 Mdot
.33541 .42522 Mdot
.40885 .62519 Mdot
.54646 .69126 Mdot
.71074 .51356 Mdot
.30279 .42224 Mdot
.33385 .40925 Mdot
.32353 .44339 Mdot
.61787 .52712 Mdot
.35281 .58769 Mdot
.77205 .50524 Mdot
.35802 .59111 Mdot
.65584 .50146 Mdot
.42513 .61476 Mdot
.32885 .57775 Mdot
.53105 .70439 Mdot
.35676 .42129 Mdot
.4582 .62244 Mdot
.61189 .51964 Mdot
.46406 .34091 Mdot
.53104 .60033 Mdot
.6154 .62428 Mdot
.78578 .62059 Mdot
.79457 .60217 Mdot
.4718 .29505 Mdot
.81489 .43595 Mdot
.38823 .43449 Mdot
.59171 .24764 Mdot
.45992 .69078 Mdot
.56325 .47576 Mdot
.17528 .47528 Mdot
.46261 .65027 Mdot
.43107 .65718 Mdot
.62434 .50167 Mdot
.3925 .60987 Mdot
.59222 .47185 Mdot
.45219 .61481 Mdot
.50374 .63566 Mdot
.55529 .46129 Mdot
.41878 .64788 Mdot
.6769 .51821 Mdot
.65033 .47385 Mdot
.47571 .30597 Mdot
.4707 .62027 Mdot
.60766 .4402 Mdot
.70915 .77337 Mdot
.3255 .46417 Mdot
.34253 .60168 Mdot
.57028 .68348 Mdot
.33572 .41588 Mdot
.48441 .35255 Mdot
.58906 .43225 Mdot
.55028 .70834 Mdot
.46968 .33105 Mdot
.50609 .67261 Mdot
.52303 .70417 Mdot
.18802 .50317 Mdot
.50097 .32424 Mdot
.33197 .59187 Mdot
.53506 .69891 Mdot
.56528 .54316 Mdot
.47276 .6182 Mdot
.58917 .60686 Mdot
.36208 .59725 Mdot
.60591 .48149 Mdot
.37084 .62564 Mdot
.32723 .4663 Mdot
.61516 .45363 Mdot
.45149 .60627 Mdot
.35454 .6031 Mdot
.62397 .52398 Mdot
.63414 .49003 Mdot
.25884 .32107 Mdot
.24952 .62929 Mdot
.55744 .73138 Mdot
.44289 .32813 Mdot
.61531 .51203 Mdot
.54118 .69696 Mdot
.44577 .79864 Mdot
.59621 .53312 Mdot
.47708 .36599 Mdot
.58683 .40728 Mdot
.43029 .60908 Mdot
.35809 .42586 Mdot
.47879 .64294 Mdot
.55929 .71146 Mdot
.15993 .61476 Mdot
.32199 .57896 Mdot
.6788 .4978 Mdot
.5724 .47404 Mdot
.3058 .60391 Mdot
.49208 .35873 Mdot
.61151 .72417 Mdot
.60028 .49567 Mdot
.71232 .46726 Mdot
.59408 .4595 Mdot
.44206 .73736 Mdot
.48223 .31393 Mdot
.59992 .47859 Mdot
.5452 .56458 Mdot
.65812 .52068 Mdot
.56552 .73399 Mdot
.75254 .62372 Mdot
.58258 .52261 Mdot
.71014 .18933 Mdot
.37083 .59812 Mdot
.41591 .64614 Mdot
.33637 .61409 Mdot
.5448 .82814 Mdot
.3789 .23314 Mdot
.50641 .34947 Mdot
.44259 .39207 Mdot
.4339 .64163 Mdot
.42174 .22112 Mdot
.82438 .46265 Mdot
.65189 .47753 Mdot
.61719 .53461 Mdot
.46909 .64509 Mdot
.37891 .61495 Mdot
.32065 .59227 Mdot
.59862 .43868 Mdot
.54473 .52771 Mdot
.40139 .6303 Mdot
.60336 .52296 Mdot
.58075 .41205 Mdot
.37149 .44719 Mdot
.45961 .30797 Mdot
.35725 .44341 Mdot
.35747 .41709 Mdot
.63339 .3048 Mdot
.23384 .41535 Mdot
.33827 .46557 Mdot
.37622 .41642 Mdot
.6458 .65449 Mdot
.54037 .40765 Mdot
.55983 .70745 Mdot
.80556 .49749 Mdot
.443 .62858 Mdot
.61284 .47238 Mdot
.48998 .29674 Mdot
.61363 .27958 Mdot
.37521 .53903 Mdot
.23111 .66244 Mdot
.58698 .49852 Mdot
.42696 .63021 Mdot
.35995 .60185 Mdot
.55298 .46671 Mdot
.33247 .67429 Mdot
.60787 .44768 Mdot
.4791 .63089 Mdot
.71166 .38841 Mdot
.51541 .51959 Mdot
.288 .64551 Mdot
.5216 .30767 Mdot
.58002 .47025 Mdot
.50352 .34051 Mdot
.35502 .4338 Mdot
.55676 .71213 Mdot
.55686 .7284 Mdot
.63379 .47603 Mdot
.72448 .47248 Mdot
.38706 .51188 Mdot
.65301 .47658 Mdot
.64662 .48428 Mdot
.35075 .59919 Mdot
.64658 .48182 Mdot
.57308 .47118 Mdot
.58505 .45299 Mdot
.66858 .50167 Mdot
.30246 .43747 Mdot
.51557 .52578 Mdot
.64632 .44437 Mdot
.57284 .41822 Mdot
.37307 .45136 Mdot
.42348 .3738 Mdot
.36386 .42699 Mdot
.78523 .35031 Mdot
.3503 .45309 Mdot
.55343 .74051 Mdot
.39083 .64732 Mdot
.62185 .40248 Mdot
.52052 .33946 Mdot
.29839 .44232 Mdot
.54443 .73238 Mdot
.34329 .42306 Mdot
.41615 .6156 Mdot
.49953 .1708 Mdot
.52717 .37935 Mdot
.59914 .69635 Mdot
.27367 .45811 Mdot
.24921 .59446 Mdot
.46075 .64498 Mdot
.48103 .31015 Mdot
.73871 .35395 Mdot
.6051 .4426 Mdot
.53219 .6997 Mdot
.62722 .48115 Mdot
.30151 .43481 Mdot
.43274 .62906 Mdot
.74432 .66474 Mdot
.5559 .71854 Mdot
.29168 .27056 Mdot
.43449 .62331 Mdot
.63101 .4455 Mdot
.31523 .41314 Mdot
.37483 .192 Mdot
.35842 .44644 Mdot
.54284 .61865 Mdot
.46557 .36466 Mdot
.56615 .37922 Mdot
.48321 .33819 Mdot
.31159 .56466 Mdot
.61731 .16568 Mdot
.81982 .55955 Mdot
.4617 .33179 Mdot
.3029 .68411 Mdot
.62003 .532 Mdot
.59294 .5354 Mdot
.52759 .53451 Mdot
.46141 .35845 Mdot
.6088 .51424 Mdot
.3584 .59961 Mdot
.29984 .33437 Mdot
.34915 .71031 Mdot
.4302 .66389 Mdot
.59153 .47825 Mdot
.36975 .45469 Mdot
.37187 .41912 Mdot
.341 .57935 Mdot
.36709 .43324 Mdot
.63829 .457 Mdot
.4799 .33633 Mdot
.40721 .4395 Mdot
.54557 .71145 Mdot
.73056 .73139 Mdot
.56081 .70319 Mdot
.37067 .60901 Mdot
.5422 .50923 Mdot
.43306 .64632 Mdot
.2742 .78332 Mdot
.62685 .45081 Mdot
.46764 .35267 Mdot
.63107 .50498 Mdot
.58403 .46292 Mdot
.59713 .5386 Mdot
.39948 .623 Mdot
.58167 .76713 Mdot
.60548 .52277 Mdot
.326 .43789 Mdot
.7974 .55001 Mdot
.58444 .53202 Mdot
.50148 .63259 Mdot
.70565 .64801 Mdot
.23083 .56812 Mdot
.5231 .34617 Mdot
.43055 .65466 Mdot
.4758 .35007 Mdot
.51385 .30331 Mdot
.48463 .3527 Mdot
.77873 .49449 Mdot
.73442 .36526 Mdot
.41979 .83918 Mdot
.61947 .38811 Mdot
.5827 .26709 Mdot
.44045 .32764 Mdot
.43853 .81244 Mdot
.51319 .32283 Mdot
.49764 .3535 Mdot
.86338 .64099 Mdot
.51447 .3201 Mdot
.59227 .48657 Mdot
.5642 .51855 Mdot
.36372 .33199 Mdot
.62632 .66337 Mdot
.64169 .47528 Mdot
.62012 .50847 Mdot
.54969 .70395 Mdot
.73298 .50108 Mdot
.31845 .59369 Mdot
.18846 .49729 Mdot
.40348 .29559 Mdot
.62911 .48064 Mdot
.61571 .51421 Mdot
.59398 .55174 Mdot
.54226 .12648 Mdot
.64473 .29251 Mdot
.44055 .31564 Mdot
.61354 .56201 Mdot
.78252 .6678 Mdot
.65084 .4649 Mdot
.59878 .5302 Mdot
.63196 .52562 Mdot
.43373 .64059 Mdot
.43694 .31664 Mdot
.61048 .56158 Mdot
.21431 .52922 Mdot
.64352 .52476 Mdot
.36533 .38405 Mdot
.59325 .77732 Mdot
.59556 .48307 Mdot
.50229 .37339 Mdot
.63919 .50637 Mdot
.50309 .32466 Mdot
.47259 .30379 Mdot
.58987 .54991 Mdot
.78617 .45388 Mdot
.47885 .36873 Mdot
.6524 .50899 Mdot
.42289 .64478 Mdot
.82915 .54507 Mdot
.60484 .48377 Mdot
.55095 .75045 Mdot
.59994 .49778 Mdot
.55659 .7546 Mdot
.65104 .48711 Mdot
.36138 .5943 Mdot
.60595 .23343 Mdot
.4431 .63534 Mdot
.61835 .77531 Mdot
.38632 .62104 Mdot
.25716 .32327 Mdot
.47801 .3651 Mdot
.3587 .60529 Mdot
.20528 .64956 Mdot
.34498 .59903 Mdot
.51152 .54067 Mdot
.49434 .56588 Mdot
.3132 .43127 Mdot
.4517 .33357 Mdot
.69306 .70076 Mdot
.29274 .59419 Mdot
.39942 .66485 Mdot
.39921 .64676 Mdot
.16148 .59034 Mdot
.18288 .59111 Mdot
.61236 .523 Mdot
.76008 .44176 Mdot
.59029 .35174 Mdot
.59734 .53224 Mdot
.60747 .43058 Mdot
.46995 .6119 Mdot
.57256 .48232 Mdot
.47281 .45118 Mdot
.45741 .64156 Mdot
.54087 .73522 Mdot
.49931 .34839 Mdot
.5487 .75645 Mdot
.34303 .62379 Mdot
.50377 .56913 Mdot
.44931 .61596 Mdot
.66642 .51146 Mdot
.62788 .50787 Mdot
.48762 .3077 Mdot
.46631 .26887 Mdot
.46395 .30569 Mdot
.52072 .72168 Mdot
.45494 .63585 Mdot
.63412 .27952 Mdot
.61766 .50081 Mdot
.47795 .32884 Mdot
.32518 .49046 Mdot
.61526 .50705 Mdot
.34818 .42231 Mdot
.62685 .5334 Mdot
.45992 .33318 Mdot
.64678 .48174 Mdot
.47931 .33803 Mdot
.44954 .65679 Mdot
.6564 .47132 Mdot
.62452 .4974 Mdot
.36657 .20155 Mdot
.55343 .73279 Mdot
.47604 .36408 Mdot
.43127 .50591 Mdot
.62514 .44221 Mdot
.29955 .61737 Mdot
.57989 .48215 Mdot
.49525 .40211 Mdot
.67705 .51192 Mdot
.3519 .60088 Mdot
.57299 .42561 Mdot
.60434 .48277 Mdot
.55954 .582 Mdot
.64029 .38057 Mdot
.46537 .27464 Mdot
.31069 .41958 Mdot
.49484 .37493 Mdot
.44732 .60139 Mdot
.37281 .61364 Mdot
.41927 .60588 Mdot
.61268 .67801 Mdot
.58994 .54917 Mdot
.60103 .46774 Mdot
.30672 .46683 Mdot
.53722 .73813 Mdot
.47481 .32162 Mdot
.53382 .73306 Mdot
.20164 .46627 Mdot
.5206 .71617 Mdot
.34954 .5841 Mdot
.43374 .74299 Mdot
.65048 .27313 Mdot
.54772 .7025 Mdot
.46193 .3066 Mdot
.4382 .75722 Mdot
.56467 .47104 Mdot
.52314 .67085 Mdot
.54306 .71908 Mdot
.1477 .56949 Mdot
.57651 .49309 Mdot
.50354 .52469 Mdot
.35764 .4562 Mdot
.52653 .71415 Mdot
.33367 .44665 Mdot
.63928 .47591 Mdot
.2482 .5635 Mdot
.50149 .35693 Mdot
.38069 .44635 Mdot
.63289 .4339 Mdot
.52862 .73666 Mdot
.44282 .61748 Mdot
.28333 .41495 Mdot
.30846 .4391 Mdot
.59178 .21105 Mdot
.74481 .65245 Mdot
.4556 .63784 Mdot
.2765 .6886 Mdot
.32562 .45088 Mdot
.59277 .52946 Mdot
.68584 .43674 Mdot
.62961 .4498 Mdot
.35724 .61826 Mdot
.42899 .65454 Mdot
.32363 .33763 Mdot
.62856 .51038 Mdot
.57733 .48828 Mdot
.46059 .37029 Mdot
.45342 .64995 Mdot
.49313 .33132 Mdot
.5143 .35863 Mdot
.4493 .6587 Mdot
.48798 .34178 Mdot
.52677 .70161 Mdot
.3139 .31287 Mdot
.3255 .45191 Mdot
.33043 .4372 Mdot
.42881 .62614 Mdot
.40655 .6393 Mdot
.43504 .64828 Mdot
.62738 .53329 Mdot
.47705 .31653 Mdot
.64458 .51223 Mdot
.60552 .53822 Mdot
.52415 .30699 Mdot
.51399 .31547 Mdot
.63607 .51677 Mdot
.29252 .64017 Mdot
.50607 .70307 Mdot
.41438 .64144 Mdot
.34873 .46262 Mdot
.45241 .22589 Mdot
.32197 .47681 Mdot
.5893 .47741 Mdot
.26502 .47675 Mdot
.46098 .32505 Mdot
.53648 .70216 Mdot
.5276 .76229 Mdot
.54601 .7064 Mdot
.29125 .44046 Mdot
.50699 .36086 Mdot
.18974 .50002 Mdot
.59254 .47455 Mdot
.47203 .46876 Mdot
.70333 .69221 Mdot
.21076 .47282 Mdot
.34116 .46531 Mdot
.61656 .50951 Mdot
.33889 .59767 Mdot
.71453 .32247 Mdot
.60325 .4495 Mdot
.58772 .4477 Mdot
.43461 .70583 Mdot
.56552 .41955 Mdot
.4695 .36584 Mdot
.22322 .39183 Mdot
.56822 .52296 Mdot
.5387 .35511 Mdot
.59127 .84858 Mdot
.58456 .4748 Mdot
.59393 .50629 Mdot
.61305 .48811 Mdot
.6358 .50011 Mdot
.49076 .37691 Mdot
.65064 .70864 Mdot
.31296 .41456 Mdot
.47552 .49419 Mdot
.32036 .45094 Mdot
.47796 .63231 Mdot
.49679 .49156 Mdot
.45195 .31913 Mdot
.53662 .70097 Mdot
.65521 .24283 Mdot
.21383 .42448 Mdot
.46434 .63774 Mdot
.68967 .32944 Mdot
.54721 .71692 Mdot
.56176 .47762 Mdot
.54273 .75941 Mdot
.37862 .61654 Mdot
.31856 .43793 Mdot
.55932 .50498 Mdot
.48822 .29977 Mdot
.45523 .33015 Mdot
.6103 .51142 Mdot
.79238 .64561 Mdot
.35092 .42264 Mdot
.36363 .47448 Mdot
.62026 .52837 Mdot
.58879 .44676 Mdot
.49555 .33612 Mdot
.41744 .63644 Mdot
.35281 .7625 Mdot
.54886 .73606 Mdot
.65576 .46109 Mdot
.63815 .49663 Mdot
.23059 .41297 Mdot
.3462 .41384 Mdot
.32621 .58443 Mdot
.61923 .52539 Mdot
.25136 .40035 Mdot
.62086 .52467 Mdot
.55494 .45284 Mdot
.42734 .64401 Mdot
.65875 .53771 Mdot
.59657 .52478 Mdot
.63062 .56307 Mdot
.32904 .44978 Mdot
.47526 .35682 Mdot
.4766 .37753 Mdot
.32737 .5969 Mdot
.34873 .42348 Mdot
.63709 .5131 Mdot
.34456 .41486 Mdot
.5896 .53141 Mdot
.60452 .52019 Mdot
.33921 .46505 Mdot
.49302 .33192 Mdot
.40281 .37723 Mdot
.51126 .52055 Mdot
.6337 .50431 Mdot
.55632 .46802 Mdot
.62145 .6758 Mdot
.27424 .74662 Mdot
.58585 .49508 Mdot
.45799 .33275 Mdot
.62037 .50165 Mdot
.34281 .44421 Mdot
.52188 .71829 Mdot
.46196 .33796 Mdot
.41478 .62728 Mdot
.4597 .6543 Mdot
.41611 .24286 Mdot
.33753 .57889 Mdot
.56351 .45585 Mdot
.47871 .39177 Mdot
.49722 .29914 Mdot
.65773 .80541 Mdot
.4476 .66193 Mdot
.56599 .72501 Mdot
.63556 .48547 Mdot
.2739 .47488 Mdot
.30349 .46323 Mdot
.70223 .18063 Mdot
.18973 .50389 Mdot
.56373 .70597 Mdot
.22394 .65988 Mdot
.33638 .59285 Mdot
.58594 .51492 Mdot
.55876 .71578 Mdot
.46745 .62971 Mdot
.56852 .49645 Mdot
.67546 .45116 Mdot
.60246 .71447 Mdot
.48837 .64097 Mdot
.35077 .41801 Mdot
.42357 .60719 Mdot
.52287 .74531 Mdot
.35139 .58549 Mdot
.45432 .32041 Mdot
.60397 .47843 Mdot
.60021 .55581 Mdot
.41402 .63211 Mdot
.36168 .5939 Mdot
.63225 .52836 Mdot
.45585 .34228 Mdot
.40697 .60697 Mdot
.63031 .4736 Mdot
.592 .25386 Mdot
.51172 .29624 Mdot
.45064 .62754 Mdot
.57476 .47044 Mdot
.54785 .40193 Mdot
.42264 .6255 Mdot
.41036 .6382 Mdot
.60938 .51447 Mdot
.53034 .69857 Mdot
.64001 .53038 Mdot
.35017 .4557 Mdot
.58385 .76714 Mdot
.34034 .44292 Mdot
.49719 .71125 Mdot
.53932 .47431 Mdot
.26015 .59133 Mdot
.45913 .30353 Mdot
.52188 .74607 Mdot
.46756 .21154 Mdot
.58216 .44928 Mdot
.80699 .43152 Mdot
.42293 .42943 Mdot
.77012 .70454 Mdot
.63102 .19297 Mdot
.54019 .72076 Mdot
.34857 .42653 Mdot
.59462 .50613 Mdot
.33598 .47302 Mdot
.55939 .72545 Mdot
.71004 .69629 Mdot
.57471 .46756 Mdot
.48497 .3148 Mdot
.64092 .5263 Mdot
.5024 .33087 Mdot
.61327 .50644 Mdot
.5661 .42012 Mdot
.43742 .67928 Mdot
.5474 .6268 Mdot
.56324 .47304 Mdot
.49654 .16879 Mdot
.39385 .52868 Mdot
.54773 .72501 Mdot
.64886 .51068 Mdot
.34371 .58706 Mdot
.36381 .41345 Mdot
.70192 .56311 Mdot
.4331 .64337 Mdot
.35402 .46442 Mdot
.49254 .34536 Mdot
.44274 .66366 Mdot
.36466 .60205 Mdot
.66128 .54699 Mdot
.56045 .74846 Mdot
.31572 .42671 Mdot
.60084 .48331 Mdot
.57706 .49266 Mdot
.32239 .70904 Mdot
.37216 .55476 Mdot
.43465 .33577 Mdot
.31454 .23886 Mdot
.51014 .37452 Mdot
.54854 .74165 Mdot
.42931 .64542 Mdot
.58499 .49195 Mdot
.62002 .45447 Mdot
.36849 .61358 Mdot
.4766 .36355 Mdot
.48357 .63819 Mdot
.65639 .31386 Mdot
.41203 .6508 Mdot
.67043 .68224 Mdot
.46323 .34832 Mdot
.66635 .68493 Mdot
.52432 .74797 Mdot
.78392 .39995 Mdot
.65836 .62338 Mdot
.35903 .45506 Mdot
.67508 .6808 Mdot
.46684 .32126 Mdot
.62012 .51795 Mdot
.33398 .59024 Mdot
.32997 .57918 Mdot
.4984 .34371 Mdot
.47112 .64136 Mdot
.52752 .71479 Mdot
.59449 .51013 Mdot
.21895 .57911 Mdot
.36914 .29393 Mdot
.40724 .62696 Mdot
.59801 .41453 Mdot
.32884 .44398 Mdot
.59215 .51865 Mdot
.5475 .75207 Mdot
.32072 .42552 Mdot
.352 .57762 Mdot
.31016 .33011 Mdot
.63584 .4744 Mdot
.23733 .39195 Mdot
.33847 .41891 Mdot
.28403 .71463 Mdot
.62438 .47421 Mdot
.32579 .45078 Mdot
.5447 .4401 Mdot
.21664 .48887 Mdot
.4284 .47177 Mdot
.82782 .47817 Mdot
.48941 .64937 Mdot
.46641 .64716 Mdot
.24877 .51985 Mdot
.39158 .66996 Mdot
.35719 .4646 Mdot
.35299 .58679 Mdot
.72969 .59884 Mdot
.33125 .44716 Mdot
.61409 .53618 Mdot
.58147 .47994 Mdot
.62746 .2982 Mdot
.4451 .46725 Mdot
.35785 .58982 Mdot
.35618 .25184 Mdot
.62132 .44203 Mdot
.67404 .46793 Mdot
.6168 .45735 Mdot
.44725 .3078 Mdot
.32717 .41561 Mdot
.40721 .18469 Mdot
.35576 .42879 Mdot
.21731 .59827 Mdot
.44215 .62872 Mdot
.40447 .6396 Mdot
.59286 .48184 Mdot
.26418 .61103 Mdot
.74758 .52013 Mdot
.64472 .46221 Mdot
.30151 .63284 Mdot
.75135 .64375 Mdot
.64213 .43677 Mdot
.46175 .36314 Mdot
.55943 .52081 Mdot
.47671 .28202 Mdot
.31192 .44396 Mdot
.53484 .71783 Mdot
.5148 .68963 Mdot
.31579 .42879 Mdot
.60286 .46672 Mdot
.31658 .63838 Mdot
.59462 .45548 Mdot
.6157 .52381 Mdot
.19806 .57621 Mdot
.55021 .69313 Mdot
.4385 .651 Mdot
.55683 .72448 Mdot
.4977 .35417 Mdot
.91861 .4666 Mdot
.53273 .73524 Mdot
.67852 .41999 Mdot
.64845 .746 Mdot
.67233 .68395 Mdot
.45434 .33133 Mdot
.51561 .71417 Mdot
.35691 .42559 Mdot
.79871 .67943 Mdot
.29636 .76251 Mdot
.34781 .47613 Mdot
.62549 .46798 Mdot
.45206 .31291 Mdot
.47095 .29676 Mdot
.38345 .44448 Mdot
.46846 .30857 Mdot
.54876 .53364 Mdot
.62736 .5156 Mdot
.35501 .46545 Mdot
.3661 .31773 Mdot
.3083 .43635 Mdot
.29715 .32142 Mdot
.64553 .51793 Mdot
.46276 .34499 Mdot
.56031 .52897 Mdot
.51888 .38456 Mdot
.32117 .58394 Mdot
.56913 .50133 Mdot
.52958 .70765 Mdot
.45813 .4565 Mdot
.44945 .62912 Mdot
.26951 .48305 Mdot
.48977 .30985 Mdot
.39569 .44673 Mdot
.47449 .30563 Mdot
.44771 .32044 Mdot
.35836 .41725 Mdot
.51183 .34639 Mdot
.59344 .5071 Mdot
.29757 .66683 Mdot
.50566 .32436 Mdot
.34065 .43107 Mdot
.5364 .7092 Mdot
.48978 .33816 Mdot
.47459 .61472 Mdot
.63025 .49335 Mdot
.44554 .61196 Mdot
.44426 .68082 Mdot
.4531 .34045 Mdot
.51617 .71099 Mdot
.42349 .65281 Mdot
.56287 .73872 Mdot
.73401 .6883 Mdot
.31715 .4639 Mdot
.23621 .66585 Mdot
.53852 .41736 Mdot
.4893 .29947 Mdot
.44602 .67952 Mdot
.58698 .49176 Mdot
.63176 .49297 Mdot
.51506 .72595 Mdot
.47212 .2962 Mdot
.82247 .57018 Mdot
.46794 .3956 Mdot
.31726 .31722 Mdot
.30485 .45416 Mdot
.32964 .24271 Mdot
.28915 .35975 Mdot
.62965 .79331 Mdot
.67916 .52268 Mdot
.3364 .59238 Mdot
.59323 .46573 Mdot
.47875 .2084 Mdot
.52454 .73078 Mdot
.37445 .79233 Mdot
.61108 .54923 Mdot
.44416 .64801 Mdot
.62005 .4847 Mdot
.62273 .59344 Mdot
.55273 .50971 Mdot
.53286 .69525 Mdot
.33517 .38135 Mdot
.51967 .34158 Mdot
.54652 .71333 Mdot
.45839 .65371 Mdot
.73149 .62296 Mdot
.56768 .49175 Mdot
.61068 .43645 Mdot
.40593 .64674 Mdot
.48078 .31147 Mdot
.47607 .6259 Mdot
.3251 .45169 Mdot
.53294 .72612 Mdot
.63692 .48944 Mdot
.67173 .512 Mdot
.30614 .6209 Mdot
.32494 .41555 Mdot
.41526 .65052 Mdot
.35902 .44153 Mdot
.33524 .59191 Mdot
.55789 .48365 Mdot
.40005 .63492 Mdot
.57715 .50292 Mdot
.42615 .20245 Mdot
.20342 .58703 Mdot
.66211 .38359 Mdot
.44338 .65277 Mdot
.6792 .6618 Mdot
.34679 .43943 Mdot
.35283 .4504 Mdot
.55508 .36406 Mdot
.73135 .54904 Mdot
.46054 .75086 Mdot
.6044 .21169 Mdot
.32492 .45223 Mdot
.33769 .44013 Mdot
.46442 .61969 Mdot
.511 .34283 Mdot
.47067 .28596 Mdot
.45922 .6631 Mdot
.55978 .64241 Mdot
.47488 .32179 Mdot
.80765 .44676 Mdot
.45172 .60198 Mdot
.68459 .51482 Mdot
.31665 .59948 Mdot
.53066 .71784 Mdot
.55513 .63664 Mdot
.62057 .59187 Mdot
.5817 .49514 Mdot
.22465 .37953 Mdot
.42164 .63638 Mdot
.6304 .71827 Mdot
.78085 .34456 Mdot
.57579 .4633 Mdot
.61591 .47287 Mdot
.60509 .46219 Mdot
.54207 .68707 Mdot
.49551 .22564 Mdot
.58102 .49807 Mdot
.55834 .64626 Mdot
.63269 .44387 Mdot
.62321 .61383 Mdot
.55709 .72831 Mdot
.51748 .27658 Mdot
.48291 .65983 Mdot
.2038 .50968 Mdot
.52531 .5264 Mdot
.33719 .45253 Mdot
.43662 .67451 Mdot
.31551 .44538 Mdot
.77122 .48363 Mdot
.66019 .62516 Mdot
.44176 .34436 Mdot
.5866 .5004 Mdot
.39164 .63858 Mdot
.46289 .30349 Mdot
.28564 .59789 Mdot
.88859 .59714 Mdot
.32004 .41558 Mdot
.29484 .79189 Mdot
.35569 .44822 Mdot
.32297 .58136 Mdot
.49615 .33833 Mdot
.72858 .36982 Mdot
.47205 .46705 Mdot
.48783 .33917 Mdot
.38011 .37096 Mdot
.51811 .37095 Mdot
.68129 .66824 Mdot
.52437 .32873 Mdot
.34416 .43346 Mdot
.28408 .43691 Mdot
.68328 .48663 Mdot
.59296 .49122 Mdot
.50797 .57233 Mdot
.59576 .39759 Mdot
.59075 .49289 Mdot
.45721 .64192 Mdot
.27031 .70958 Mdot
.44389 .6736 Mdot
.50792 .31848 Mdot
.319 .41308 Mdot
.61706 .47519 Mdot
.63075 .51452 Mdot
.57867 .51273 Mdot
.34903 .20515 Mdot
.80584 .45905 Mdot
.60703 .52198 Mdot
.66235 .47287 Mdot
.44857 .65594 Mdot
.55761 .77413 Mdot
.53797 .18591 Mdot
.713 .60444 Mdot
.61381 .44584 Mdot
.55492 .7269 Mdot
.56247 .70836 Mdot
.56531 .48717 Mdot
.22635 .57278 Mdot
.29442 .66912 Mdot
.60125 .48353 Mdot
.66125 .60992 Mdot
.35572 .63113 Mdot
.34155 .57931 Mdot
.41555 .63084 Mdot
.50613 .37025 Mdot
.35564 .59275 Mdot
.38605 .61704 Mdot
.722 .35264 Mdot
.32948 .59893 Mdot
.26664 .40118 Mdot
.52075 .7219 Mdot
.61402 .45309 Mdot
.50563 .37916 Mdot
.3634 .61553 Mdot
.31376 .43162 Mdot
.47063 .3403 Mdot
.3656 .41373 Mdot
.5722 .73612 Mdot
.6089 .70009 Mdot
.3265 .57838 Mdot
.33269 .45497 Mdot
.30855 .33059 Mdot
.55558 .72735 Mdot
.36608 .4342 Mdot
.27032 .59975 Mdot
.58441 .53472 Mdot
.7626 .38734 Mdot
.65614 .47908 Mdot
.79398 .66175 Mdot
.36379 .43061 Mdot
.34423 .60369 Mdot
.6009 .47127 Mdot
.43327 .62356 Mdot
.54251 .45643 Mdot
.61077 .44721 Mdot
.41666 .62275 Mdot
.61373 .52218 Mdot
.55308 .75084 Mdot
.50043 .28777 Mdot
.41155 .41141 Mdot
.16444 .41016 Mdot
.55929 .74788 Mdot
.28368 .59851 Mdot
.58609 .49626 Mdot
.74519 .66107 Mdot
.4888 .33658 Mdot
.57749 .45727 Mdot
.53782 .30341 Mdot
.50801 .33924 Mdot
.4765 .34763 Mdot
.64656 .49442 Mdot
.36123 .44912 Mdot
.44028 .62286 Mdot
.5552 .72233 Mdot
.66696 .78644 Mdot
.62865 .46249 Mdot
.62267 .49932 Mdot
.5467 .71537 Mdot
.33889 .44181 Mdot
.63305 .51166 Mdot
.3137 .51848 Mdot
.72753 .75445 Mdot
.34015 .40832 Mdot
.59622 .54185 Mdot
.7157 .29705 Mdot
.5087 .3879 Mdot
.28498 .77144 Mdot
.50275 .71626 Mdot
.42862 .65273 Mdot
.56369 .42103 Mdot
.79081 .27472 Mdot
.53402 .71615 Mdot
.19709 .50567 Mdot
.60924 .52703 Mdot
.61528 .49615 Mdot
.46135 .31658 Mdot
.64106 .5135 Mdot
.48626 .36262 Mdot
.14937 .46792 Mdot
.24706 .30189 Mdot
.49089 .31415 Mdot
.50485 .31003 Mdot
.55234 .3833 Mdot
.5239 .19007 Mdot
.49546 .34872 Mdot
.60459 .54431 Mdot
.80922 .5351 Mdot
.67745 .53492 Mdot
.51398 .7222 Mdot
.4491 .68291 Mdot
.49705 .2621 Mdot
.42111 .58561 Mdot
.42974 .37463 Mdot
.53773 .54284 Mdot
.36835 .51736 Mdot
.34556 .45919 Mdot
.59819 .44606 Mdot
.33349 .57825 Mdot
.40317 .60977 Mdot
.54934 .49722 Mdot
.60704 .45121 Mdot
.50379 .32813 Mdot
.53724 .68828 Mdot
.36694 .42071 Mdot
.62066 .50795 Mdot
.48551 .62396 Mdot
.54402 .73731 Mdot
.50526 .31758 Mdot
.56338 .38234 Mdot
.55448 .70249 Mdot
.567 .42735 Mdot
.60301 .49789 Mdot
.63029 .52862 Mdot
.53349 .43997 Mdot
.3156 .45702 Mdot
.34741 .61938 Mdot
.62016 .54126 Mdot
.20407 .4616 Mdot
.52799 .61382 Mdot
.66231 .53018 Mdot
.47057 .31674 Mdot
.30038 .45838 Mdot
.32268 .58717 Mdot
.73033 .64507 Mdot
.63402 .46841 Mdot
.80422 .46267 Mdot
.64749 .29899 Mdot
.35455 .59336 Mdot
.44193 .33468 Mdot
.53855 .70204 Mdot
.6366 .45636 Mdot
.7933 .51725 Mdot
.58337 .47932 Mdot
.54769 .4078 Mdot
.41983 .64269 Mdot
.34286 .46079 Mdot
.75866 .72233 Mdot
.40058 .61098 Mdot
.47595 .34938 Mdot
.83373 .47388 Mdot
.46901 .29123 Mdot
.51659 .34636 Mdot
.78281 .46436 Mdot
.31795 .45686 Mdot
.77252 .2534 Mdot
.29015 .76292 Mdot
.64542 .53381 Mdot
.34845 .44359 Mdot
.49895 .33144 Mdot
.5924 .51826 Mdot
.5028 .30457 Mdot
.50453 .35876 Mdot
.57164 .50992 Mdot
.60842 .49822 Mdot
.50941 .5204 Mdot
.79994 .39512 Mdot
.54573 .70479 Mdot
.46404 .35405 Mdot
.58103 .27637 Mdot
.58216 .50416 Mdot
.59304 .47486 Mdot
.2983 .60416 Mdot
.53485 .69569 Mdot
.58215 .58377 Mdot
.61797 .52492 Mdot
.24525 .32412 Mdot
.55529 .47256 Mdot
.47698 .37421 Mdot
.34142 .40859 Mdot
.21926 .55907 Mdot
.35556 .61729 Mdot
.46947 .36118 Mdot
.53611 .74875 Mdot
.46038 .3688 Mdot
.6634 .40975 Mdot
.31427 .45091 Mdot
.45992 .33314 Mdot
.47641 .64314 Mdot
.32427 .42936 Mdot
.36543 .43397 Mdot
.79819 .54877 Mdot
.42953 .65941 Mdot
.52185 .73141 Mdot
.31919 .44086 Mdot
.58846 .24632 Mdot
.34467 .42876 Mdot
.59806 .28902 Mdot
.6596 .47966 Mdot
.5814 .66831 Mdot
.30173 .3632 Mdot
.55222 .42268 Mdot
.31376 .45839 Mdot
.55822 .72243 Mdot
.6424 .49547 Mdot
.46681 .30957 Mdot
.53169 .73279 Mdot
.33096 .38994 Mdot
.40816 .63882 Mdot
.47979 .3032 Mdot
.31338 .41358 Mdot
.46509 .35321 Mdot
.68117 .70589 Mdot
.59334 .7466 Mdot
.31629 .5056 Mdot
.48129 .48309 Mdot
.5827 .51804 Mdot
.43771 .26444 Mdot
.55921 .46037 Mdot
.60342 .45061 Mdot
.44993 .62716 Mdot
.61258 .67946 Mdot
.4936 .33191 Mdot
.7598 .72447 Mdot
.33564 .45737 Mdot
.22508 .35808 Mdot
.52816 .40108 Mdot
.5982 .44297 Mdot
.50652 .3281 Mdot
.48372 .28994 Mdot
.6445 .38267 Mdot
.41212 .60363 Mdot
.6541 .43399 Mdot
.56301 .43995 Mdot
.68173 .49685 Mdot
.36339 .43095 Mdot
.2671 .49277 Mdot
.47462 .63513 Mdot
.43598 .85127 Mdot
.41412 .63887 Mdot
.38499 .70036 Mdot
.51341 .3437 Mdot
.52316 .71855 Mdot
.5941 .47661 Mdot
.52144 .4127 Mdot
.45048 .34864 Mdot
.53432 .76942 Mdot
.5297 .70476 Mdot
.23904 .4922 Mdot
.33579 .46555 Mdot
.56554 .47825 Mdot
.57431 .47615 Mdot
.64785 .50758 Mdot
.65897 .49164 Mdot
.32453 .41237 Mdot
.60948 .53519 Mdot
.36291 .46352 Mdot
.60415 .25538 Mdot
.23553 .33122 Mdot
.38338 .63016 Mdot
.71609 .55558 Mdot
.48984 .30229 Mdot
.56469 .23828 Mdot
.63703 .41936 Mdot
.20746 .60301 Mdot
.76821 .64158 Mdot
.58869 .43764 Mdot
.4698 .62737 Mdot
.73172 .52583 Mdot
.38654 .62949 Mdot
.14094 .63571 Mdot
.33766 .63879 Mdot
.82083 .45605 Mdot
.58922 .51151 Mdot
.29985 .60483 Mdot
.63493 .41528 Mdot
.56715 .50211 Mdot
.36194 .64813 Mdot
.32825 .26573 Mdot
.35854 .34609 Mdot
.56017 .7063 Mdot
.63073 .48619 Mdot
.52279 .32308 Mdot
.59225 .5078 Mdot
.59047 .47155 Mdot
.60293 .52858 Mdot
.32868 .40639 Mdot
.55964 .51028 Mdot
.6233 .53563 Mdot
.3964 .56072 Mdot
.64954 .66199 Mdot
.42354 .60795 Mdot
.6401 .39465 Mdot
.53678 .73704 Mdot
.50024 .31846 Mdot
.48373 .43335 Mdot
.35804 .45678 Mdot
.60129 .37117 Mdot
.63315 .53184 Mdot
.30665 .35414 Mdot
.31245 .41421 Mdot
.53064 .72507 Mdot
.32617 .59397 Mdot
.82421 .5251 Mdot
.38095 .62451 Mdot
.32736 .59779 Mdot
.44868 .63026 Mdot
.51354 .24296 Mdot
.50427 .33061 Mdot
.5819 .51884 Mdot
.32427 .44246 Mdot
.43889 .6202 Mdot
.61737 .66346 Mdot
.61357 .45773 Mdot
.45031 .65301 Mdot
.58716 .52392 Mdot
.59719 .6926 Mdot
.32752 .7187 Mdot
.38747 .62498 Mdot
.29283 .42456 Mdot
.32905 .43023 Mdot
.52456 .70382 Mdot
.49724 .31283 Mdot
.4624 .32175 Mdot
.32218 .42515 Mdot
.24513 .72056 Mdot
.60837 .44648 Mdot
.58922 .51425 Mdot
.20612 .45774 Mdot
.59591 .50146 Mdot
.72012 .63845 Mdot
.31338 .58771 Mdot
.49701 .30911 Mdot
.59661 .52213 Mdot
.63409 .5068 Mdot
.63613 .47978 Mdot
.67563 .71026 Mdot
.4129 .63421 Mdot
.62564 .44507 Mdot
.54733 .70043 Mdot
.31359 .55769 Mdot
.58635 .51231 Mdot
.67747 .48229 Mdot
.46309 .3255 Mdot
.2333 .31873 Mdot
.35403 .45562 Mdot
.46096 .63937 Mdot
.41758 .64894 Mdot
.4392 .6854 Mdot
.51941 .29775 Mdot
.31758 .59166 Mdot
.5406 .81926 Mdot
.34605 .60157 Mdot
.5501 .72295 Mdot
.47392 .70889 Mdot
.469 .59915 Mdot
.46358 .62724 Mdot
.3783 .42434 Mdot
.64445 .52438 Mdot
.63166 .44814 Mdot
.19434 .51595 Mdot
.61248 .439 Mdot
.53376 .7064 Mdot
.36889 .4574 Mdot
.46816 .3239 Mdot
.52864 .72025 Mdot
.35566 .4448 Mdot
.47834 .31101 Mdot
.57956 .52997 Mdot
.58442 .53695 Mdot
.47412 .34245 Mdot
.46249 .30492 Mdot
.60008 .48769 Mdot
.33893 .53906 Mdot
.51438 .36016 Mdot
.46022 .33978 Mdot
.3273 .57676 Mdot
.38323 .62832 Mdot
.62167 .5598 Mdot
.35157 .44196 Mdot
.62606 .52917 Mdot
.38551 .6303 Mdot
.52626 .69501 Mdot
.48888 .3305 Mdot
.63207 .50875 Mdot
.62292 .51167 Mdot
.55385 .72101 Mdot
.54588 .69302 Mdot
.5268 .71863 Mdot
.35415 .4707 Mdot
.65491 .4899 Mdot
.49236 .34954 Mdot
.33027 .46376 Mdot
.56269 .70891 Mdot
.54939 .76165 Mdot
.44314 .56617 Mdot
.58288 .49047 Mdot
.42302 .4779 Mdot
.90876 .45173 Mdot
.7247 .61548 Mdot
.32169 .58614 Mdot
.41299 .6524 Mdot
.64309 .68949 Mdot
.31677 .69116 Mdot
.3412 .41748 Mdot
.74191 .57176 Mdot
.52087 .74433 Mdot
.58254 .52235 Mdot
.55625 .46994 Mdot
.60896 .42984 Mdot
.53949 .73182 Mdot
.6981 .68832 Mdot
.46804 .29536 Mdot
.56697 .31555 Mdot
.53656 .73652 Mdot
.387 .62386 Mdot
.39769 .63385 Mdot
.41443 .63944 Mdot
.56141 .50609 Mdot
.63113 .37517 Mdot
.57451 .25266 Mdot
.52591 .20318 Mdot
.3466 .46608 Mdot
.43445 .32253 Mdot
.73497 .68237 Mdot
.47749 .34582 Mdot
.3959 .61141 Mdot
.54325 .73324 Mdot
.4579 .3273 Mdot
.314 .42418 Mdot
.33534 .44041 Mdot
.40935 .63232 Mdot
.43063 .62663 Mdot
.44133 .61234 Mdot
.50639 .36536 Mdot
.5123 .34557 Mdot
.63474 .46472 Mdot
.48133 .33295 Mdot
.20265 .40956 Mdot
.55542 .69437 Mdot
.39444 .62868 Mdot
.3514 .42834 Mdot
.50137 .32711 Mdot
.61904 .4564 Mdot
.46417 .72914 Mdot
.40582 .2551 Mdot
.56133 .74037 Mdot
.31204 .70777 Mdot
.16804 .67102 Mdot
.57002 .48575 Mdot
.35081 .41721 Mdot
.23051 .59662 Mdot
.6089 .46163 Mdot
.4305 .63985 Mdot
.44983 .19884 Mdot
.3621 .60009 Mdot
.61583 .5351 Mdot
.60775 .43944 Mdot
.36693 .4318 Mdot
.64993 .74888 Mdot
.63564 .46251 Mdot
.26844 .35589 Mdot
.34153 .40422 Mdot
.45864 .61067 Mdot
.72883 .7581 Mdot
.33911 .62017 Mdot
.56015 .63629 Mdot
.3309 .58074 Mdot
.58221 .46582 Mdot
.45827 .63589 Mdot
.56201 .7334 Mdot
.45213 .62155 Mdot
.44191 .34081 Mdot
.43204 .60914 Mdot
.62201 .49811 Mdot
.49424 .35116 Mdot
.34055 .41917 Mdot
.22089 .39492 Mdot
.38587 .56361 Mdot
.43222 .62376 Mdot
.32045 .57704 Mdot
.5921 .52276 Mdot
.54133 .5674 Mdot
.53484 .48015 Mdot
.5856 .50788 Mdot
.31558 .44837 Mdot
.50731 .32618 Mdot
.30212 .44526 Mdot
.67387 .48441 Mdot
.30602 .27462 Mdot
.35991 .44456 Mdot
.32074 .37112 Mdot
.54805 .71805 Mdot
.52968 .58853 Mdot
.62108 .45356 Mdot
.32087 .44383 Mdot
.65506 .49213 Mdot
.51322 .31321 Mdot
.45109 .50383 Mdot
.29589 .56709 Mdot
.32525 .44154 Mdot
.81698 .59426 Mdot
.42939 .51127 Mdot
.56942 .53647 Mdot
.32196 .44965 Mdot
.53912 .28963 Mdot
.33236 .58265 Mdot
.55021 .73393 Mdot
.56189 .7077 Mdot
.564 .73547 Mdot
.5894 .44182 Mdot
.68177 .45797 Mdot
.53154 .74789 Mdot
.3538 .41035 Mdot
.53258 .69465 Mdot
.51206 .43719 Mdot
.82127 .58389 Mdot
.53097 .74046 Mdot
.62692 .47364 Mdot
.67413 .46525 Mdot
.64514 .66229 Mdot
.39383 .61011 Mdot
.80635 .42682 Mdot
.71861 .50343 Mdot
.59077 .4888 Mdot
.69188 .52087 Mdot
.46221 .30106 Mdot
.24968 .62147 Mdot
.591 .39859 Mdot
.31204 .6936 Mdot
.51579 .32354 Mdot
.36391 .60987 Mdot
.49789 .31151 Mdot
.57113 .49265 Mdot
.6029 .51968 Mdot
.48057 .28415 Mdot
.24938 .44778 Mdot
.24289 .54922 Mdot
.73538 .72563 Mdot
.45816 .33862 Mdot
.32874 .44956 Mdot
.31935 .41546 Mdot
.34805 .46493 Mdot
.44616 .60152 Mdot
.4561 .34833 Mdot
.65058 .47986 Mdot
.44736 .65754 Mdot
.59992 .44729 Mdot
.3202 .43506 Mdot
.7657 .71569 Mdot
.46461 .32456 Mdot
.60351 .48271 Mdot
.29336 .75788 Mdot
.4336 .63172 Mdot
.55458 .7342 Mdot
.60869 .70847 Mdot
.45822 .60313 Mdot
.30714 .44677 Mdot
.47459 .28687 Mdot
.3763 .38775 Mdot
.45197 .42011 Mdot
.6568 .54764 Mdot
.64218 .54423 Mdot
.63571 .80054 Mdot
.34104 .5671 Mdot
.56039 .46632 Mdot
.45951 .6526 Mdot
.37096 .61646 Mdot
.63173 .50392 Mdot
.45328 .32615 Mdot
.56378 .75109 Mdot
.54643 .69891 Mdot
.5952 .42303 Mdot
.47322 .47215 Mdot
.529 .59113 Mdot
.6347 .51673 Mdot
.59372 .41589 Mdot
.41514 .64869 Mdot
.34256 .60238 Mdot
.22409 .42673 Mdot
.53145 .74393 Mdot
.61234 .52793 Mdot
.38915 .35061 Mdot
.50596 .35548 Mdot
.43868 .61019 Mdot
.30938 .44689 Mdot
.69188 .70782 Mdot
.47671 .62212 Mdot
.6311 .50662 Mdot
.63322 .51081 Mdot
.36649 .4347 Mdot
.47622 .37383 Mdot
.54151 .7312 Mdot
.43873 .65591 Mdot
.53138 .74471 Mdot
.50071 .35412 Mdot
.46711 .32699 Mdot
.67814 .53442 Mdot
.59237 .417 Mdot
.41545 .62848 Mdot
.66389 .4656 Mdot
.38905 .61753 Mdot
.64197 .75971 Mdot
.29805 .4412 Mdot
.57013 .48209 Mdot
.44489 .30018 Mdot
.31743 .43655 Mdot
.61133 .49321 Mdot
.61884 .82105 Mdot
.58727 .44981 Mdot
.35709 .61399 Mdot
.28249 .29459 Mdot
.55072 .70607 Mdot
.69876 .4237 Mdot
.64229 .57137 Mdot
.5985 .50369 Mdot
.3975 .62386 Mdot
.54069 .46059 Mdot
.36423 .43844 Mdot
.51397 .32949 Mdot
.25255 .75163 Mdot
.341 .4283 Mdot
.59393 .51286 Mdot
.53216 .72599 Mdot
.47625 .28887 Mdot
.35785 .59824 Mdot
.20067 .48001 Mdot
.54405 .48204 Mdot
.59874 .54596 Mdot
.61924 .5328 Mdot
.53717 .17959 Mdot
.46059 .63441 Mdot
.50035 .32974 Mdot
.36216 .42934 Mdot
.3242 .42144 Mdot
.41671 .63846 Mdot
.34323 .33994 Mdot
.50665 .58189 Mdot
.84123 .33374 Mdot
.42141 .61989 Mdot
.51625 .70288 Mdot
.49048 .4831 Mdot
.39795 .61472 Mdot
.45089 .64841 Mdot
.4225 .65314 Mdot
.27351 .38927 Mdot
.47672 .31387 Mdot
.62163 .51411 Mdot
.52234 .34812 Mdot
.58164 .46489 Mdot
.55733 .60975 Mdot
.31562 .433 Mdot
.5152 .33103 Mdot
.63343 .8083 Mdot
.49919 .39699 Mdot
.61456 .46606 Mdot
.71548 .71282 Mdot
.53924 .51011 Mdot
.69104 .6756 Mdot
.55979 .53761 Mdot
.44133 .62688 Mdot
.66874 .42571 Mdot
.67832 .48932 Mdot
.2127 .39814 Mdot
.35291 .43007 Mdot
.32087 .58149 Mdot
.5707 .44811 Mdot
.55626 .45144 Mdot
.5104 .30563 Mdot
.45748 .32942 Mdot
.52757 .74233 Mdot
.53026 .63389 Mdot
.34555 .42106 Mdot
.59496 .73086 Mdot
.59598 .49239 Mdot
.25778 .4425 Mdot
.59256 .38604 Mdot
.61092 .49158 Mdot
.80752 .52337 Mdot
.61659 .37342 Mdot
.63027 .45393 Mdot
.53906 .27711 Mdot
.34098 .43983 Mdot
.27969 .30171 Mdot
.66601 .49497 Mdot
.43263 .64027 Mdot
.51284 .33899 Mdot
.45786 .30296 Mdot
.54509 .75395 Mdot
.17729 .56237 Mdot
.31184 .45823 Mdot
.51546 .33773 Mdot
.60557 .4579 Mdot
.31141 .4519 Mdot
.34036 .58019 Mdot
.67599 .5021 Mdot
.74768 .55786 Mdot
.47842 .33108 Mdot
.66304 .47324 Mdot
.36401 .25874 Mdot
.5437 .63565 Mdot
.77524 .30996 Mdot
.35119 .46311 Mdot
.52589 .72868 Mdot
.58028 .54996 Mdot
.53814 .81712 Mdot
.61397 .43237 Mdot
.58705 .66984 Mdot
.53451 .32615 Mdot
.52201 .71767 Mdot
.60897 .47022 Mdot
.64001 .4789 Mdot
.47408 .46003 Mdot
.5423 .69004 Mdot
.57831 .46048 Mdot
.70504 .46267 Mdot
.48174 .31253 Mdot
.31489 .58457 Mdot
.47531 .32648 Mdot
.62524 .46842 Mdot
.68605 .46826 Mdot
.4607 .31423 Mdot
.57344 .79311 Mdot
.51066 .70112 Mdot
.35338 .45731 Mdot
.6223 .42005 Mdot
.66047 .49497 Mdot
.54553 .16069 Mdot
.32124 .5838 Mdot
.49125 .21102 Mdot
.48251 .62417 Mdot
.39506 .36637 Mdot
.31492 .60996 Mdot
.833 .48734 Mdot
.22609 .39631 Mdot
.55951 .45261 Mdot
.67906 .59479 Mdot
.54208 .25976 Mdot
.30484 .44807 Mdot
.64772 .26372 Mdot
.5925 .49114 Mdot
.59078 .46891 Mdot
.46241 .61549 Mdot
.32306 .34178 Mdot
.2303 .58095 Mdot
.47196 .48553 Mdot
.54285 .72699 Mdot
.48925 .35918 Mdot
.61402 .50835 Mdot
.50725 .59859 Mdot
.41974 .61015 Mdot
.27171 .46986 Mdot
.60478 .47735 Mdot
.218 .61558 Mdot
.28269 .38624 Mdot
.32017 .4612 Mdot
.40184 .63616 Mdot
.46847 .60693 Mdot
.57811 .47816 Mdot
.30879 .4391 Mdot
.63298 .46 Mdot
.42219 .52314 Mdot
.6532 .45286 Mdot
.5335 .74119 Mdot
.59142 .52554 Mdot
.44873 .44917 Mdot
.80809 .36428 Mdot
.70118 .44175 Mdot
.45021 .32115 Mdot
.45193 .60306 Mdot
.41443 .63441 Mdot
.45945 .32736 Mdot
.41678 .63351 Mdot
.58044 .33719 Mdot
.7119 .3796 Mdot
.54416 .72275 Mdot
.61287 .41565 Mdot
.54038 .74841 Mdot
.31926 .58265 Mdot
.5856 .48864 Mdot
.5376 .82287 Mdot
.42363 .62146 Mdot
.37907 .21085 Mdot
.34393 .4261 Mdot
.32072 .58258 Mdot
.63435 .44486 Mdot
.46883 .70601 Mdot
.41036 .60714 Mdot
.36323 .61179 Mdot
.63623 .47651 Mdot
.46488 .31739 Mdot
.63987 .48531 Mdot
.54298 .51702 Mdot
.32436 .59445 Mdot
.64217 .52618 Mdot
.35562 .44473 Mdot
.49478 .37488 Mdot
.82632 .54057 Mdot
.36038 .61685 Mdot
.57838 .4906 Mdot
.60586 .45913 Mdot
.4955 .29629 Mdot
.6531 .46202 Mdot
.31239 .42451 Mdot
.59069 .10783 Mdot
.54879 .71871 Mdot
.36745 .60079 Mdot
.34407 .62118 Mdot
.59439 .43587 Mdot
.63665 .5098 Mdot
.66472 .79046 Mdot
.29373 .54706 Mdot
.3428 .45154 Mdot
.54962 .45028 Mdot
.44646 .65562 Mdot
.53145 .72394 Mdot
.36648 .41774 Mdot
.63134 .52747 Mdot
.59618 .47327 Mdot
.53104 .73585 Mdot
.80308 .55599 Mdot
.31128 .69609 Mdot
.35275 .46461 Mdot
.65899 .41993 Mdot
.456 .73847 Mdot
.60945 .44675 Mdot
.49558 .76114 Mdot
.46044 .33652 Mdot
.32377 .45554 Mdot
.53054 .1973 Mdot
.58952 .52723 Mdot
.32132 .41726 Mdot
.34843 .42323 Mdot
.65362 .5288 Mdot
.5269 .32519 Mdot
.4982 .36931 Mdot
.4701 .35702 Mdot
.20973 .35152 Mdot
.59542 .62889 Mdot
.44016 .61234 Mdot
.33989 .44075 Mdot
.38826 .62921 Mdot
.54394 .68602 Mdot
.52502 .60579 Mdot
.38153 .61799 Mdot
.46517 .30046 Mdot
.39763 .63514 Mdot
.63837 .48204 Mdot
.33928 .41823 Mdot
.46283 .62463 Mdot
.5725 .44939 Mdot
.59843 .58217 Mdot
.40843 .50728 Mdot
.5578 .75861 Mdot
.51618 .74822 Mdot
.6073 .51663 Mdot
.32322 .58754 Mdot
.59864 .48575 Mdot
.36144 .46232 Mdot
.46289 .43611 Mdot
.5905 .43851 Mdot
.42421 .62538 Mdot
.7063 .51365 Mdot
.41937 .60283 Mdot
.5424 .46457 Mdot
.62541 .47292 Mdot
.59559 .45159 Mdot
.63458 .46035 Mdot
.34989 .36037 Mdot
.30543 .45551 Mdot
.62077 .58455 Mdot
.45903 .67137 Mdot
.48192 .33984 Mdot
.43864 .31869 Mdot
.44718 .75639 Mdot
.37069 .60084 Mdot
.3502 .44201 Mdot
.61751 .44889 Mdot
.34665 .61648 Mdot
.77357 .70731 Mdot
.57307 .79623 Mdot
.52527 .76532 Mdot
.46421 .64369 Mdot
.44973 .31621 Mdot
.4176 .60743 Mdot
.58119 .47207 Mdot
.63939 .53979 Mdot
.83353 .5079 Mdot
.28923 .42179 Mdot
.54211 .73327 Mdot
.5912 .45431 Mdot
.55835 .63229 Mdot
.44839 .65596 Mdot
.42049 .65315 Mdot
.58907 .44996 Mdot
.47659 .36688 Mdot
.69032 .21425 Mdot
.31702 .45935 Mdot
.71901 .53247 Mdot
.43556 .28557 Mdot
.29644 .29776 Mdot
.3177 .4257 Mdot
.38625 .51612 Mdot
.4596 .65867 Mdot
.71973 .43531 Mdot
.47787 .3395 Mdot
.54083 .73609 Mdot
.64959 .53729 Mdot
.47006 .30027 Mdot
.4579 .66418 Mdot
.49828 .30751 Mdot
.57334 .50618 Mdot
.30406 .45019 Mdot
.42365 .65046 Mdot
.2913 .43991 Mdot
.47343 .28345 Mdot
.55575 .74365 Mdot
.51856 .55922 Mdot
.69074 .29337 Mdot
.61127 .37249 Mdot
.62666 .44589 Mdot
.4965 .59789 Mdot
.65359 .49021 Mdot
.52052 .31657 Mdot
.62369 .45722 Mdot
.46839 .25053 Mdot
.40396 .63671 Mdot
.6638 .47591 Mdot
.61293 .53519 Mdot
.6504 .28158 Mdot
.61437 .47746 Mdot
.64639 .52653 Mdot
.63039 .4528 Mdot
.45524 .27265 Mdot
.55529 .50507 Mdot
.47156 .31428 Mdot
.20292 .48943 Mdot
.45135 .64668 Mdot
.55892 .75928 Mdot
.55711 .70743 Mdot
.57601 .66134 Mdot
.54453 .62041 Mdot
.33578 .34429 Mdot
.48034 .32241 Mdot
.35886 .43624 Mdot
.63176 .45813 Mdot
.57461 .20693 Mdot
.39442 .6684 Mdot
.44407 .66028 Mdot
.35919 .61525 Mdot
.54092 .43149 Mdot
.53988 .17819 Mdot
.64706 .4516 Mdot
.18689 .50753 Mdot
.61745 .42727 Mdot
.57723 .4581 Mdot
.46621 .60761 Mdot
.53966 .6212 Mdot
.62379 .44364 Mdot
.50934 .30496 Mdot
.54448 .74044 Mdot
.45239 .38495 Mdot
.32207 .66603 Mdot
.36598 .52522 Mdot
.7027 .33164 Mdot
.65381 .48044 Mdot
.42891 .65179 Mdot
.48032 .30356 Mdot
.22639 .41911 Mdot
.32996 .46327 Mdot
.29067 .36759 Mdot
.59972 .26469 Mdot
.67559 .75769 Mdot
.54355 .7372 Mdot
.79986 .55311 Mdot
.62172 .49986 Mdot
.44612 .60093 Mdot
.5744 .515 Mdot
.77738 .70235 Mdot
.51555 .71042 Mdot
.45799 .35813 Mdot
.3308 .44985 Mdot
.5157 .31654 Mdot
.66687 .38627 Mdot
.3494 .51299 Mdot
.47173 .54353 Mdot
.37945 .62185 Mdot
.57945 .58511 Mdot
.49966 .34482 Mdot
.62531 .52294 Mdot
.8715 .38033 Mdot
.46091 .33936 Mdot
.47323 .36189 Mdot
.6219 .77056 Mdot
.62088 .77785 Mdot
.55224 .43394 Mdot
.49692 .30389 Mdot
.4071 .65259 Mdot
.55372 .7144 Mdot
.64396 .48228 Mdot
.63845 .46737 Mdot
.46171 .31718 Mdot
.39375 .61143 Mdot
.72445 .52927 Mdot
.43615 .62666 Mdot
.48274 .311 Mdot
.44239 .63524 Mdot
.37971 .63362 Mdot
.46355 .63741 Mdot
.66155 .48505 Mdot
.62581 .45719 Mdot
.3501 .69909 Mdot
.46728 .32705 Mdot
.64048 .5076 Mdot
.60903 .52388 Mdot
.49493 .34738 Mdot
.48529 .62857 Mdot
.6008 .21944 Mdot
.5871 .4989 Mdot
.62905 .49058 Mdot
.52338 .72344 Mdot
.44375 .59436 Mdot
.32403 .73135 Mdot
.64269 .49514 Mdot
.52407 .69283 Mdot
.50938 .36247 Mdot
.60168 .48725 Mdot
.50959 .44262 Mdot
.37674 .62568 Mdot
.59446 .52923 Mdot
.35886 .5963 Mdot
.61128 .43597 Mdot
.71743 .24897 Mdot
.57906 .49777 Mdot
.49775 .33329 Mdot
.50928 .33877 Mdot
.63202 .75745 Mdot
.47515 .35106 Mdot
.33131 .57976 Mdot
.32256 .43216 Mdot
.79258 .67209 Mdot
.34428 .58234 Mdot
.57781 .45477 Mdot
.29021 .76321 Mdot
.66999 .48525 Mdot
.57533 .4452 Mdot
.49981 .1823 Mdot
.34727 .58445 Mdot
.50616 .33401 Mdot
.26359 .41606 Mdot
.61113 .4249 Mdot
.30915 .44836 Mdot
.67009 .52475 Mdot
.62436 .53894 Mdot
.25806 .33963 Mdot
.42976 .22529 Mdot
.37334 .45069 Mdot
.64889 .55478 Mdot
.64282 .49588 Mdot
.4152 .58027 Mdot
.61392 .45588 Mdot
.53636 .74759 Mdot
.47411 .36114 Mdot
.41106 .61409 Mdot
.54702 .71136 Mdot
.59673 .49739 Mdot
.53731 .73179 Mdot
.44264 .61185 Mdot
.31764 .45115 Mdot
.58087 .48343 Mdot
.51277 .71313 Mdot
.54189 .72794 Mdot
.65142 .49829 Mdot
.51472 .33481 Mdot
.65891 .41373 Mdot
.60431 .48868 Mdot
.62568 .51899 Mdot
.46255 .32162 Mdot
.46692 .85637 Mdot
.57302 .48218 Mdot
.41985 .48469 Mdot
.45527 .35344 Mdot
.30979 .59663 Mdot
.44999 .612 Mdot
.62439 .53986 Mdot
.3113 .44468 Mdot
.31546 .43619 Mdot
.42147 .659 Mdot
.51141 .31051 Mdot
.40159 .60822 Mdot
.7061 .5032 Mdot
.60911 .41923 Mdot
.66867 .50797 Mdot
.22521 .70753 Mdot
.82614 .50124 Mdot
.45278 .32219 Mdot
.47449 .63765 Mdot
.47578 .49269 Mdot
.33888 .44424 Mdot
.40279 .64546 Mdot
.47861 .2878 Mdot
.45196 .31096 Mdot
.48971 .30282 Mdot
.5243 .71376 Mdot
.47761 .63656 Mdot
.46979 .36938 Mdot
.48053 .36807 Mdot
.63708 .47955 Mdot
.64271 .49852 Mdot
.54092 .36436 Mdot
.67447 .65709 Mdot
.55242 .7491 Mdot
.42136 .64166 Mdot
.47133 .13002 Mdot
.36407 .4606 Mdot
.65533 .28612 Mdot
.58716 .43941 Mdot
.9163 .54761 Mdot
.64429 .44804 Mdot
.60709 .45603 Mdot
.50741 .36782 Mdot
.51833 .73592 Mdot
.5465 .74641 Mdot
.50099 .34514 Mdot
.46957 .28596 Mdot
.53249 .74369 Mdot
.77858 .62666 Mdot
.82188 .58953 Mdot
.25871 .39212 Mdot
.49427 .33934 Mdot
.71571 .32437 Mdot
.30731 .44414 Mdot
.4801 .28136 Mdot
.36879 .44937 Mdot
.44863 .64903 Mdot
.45911 .66049 Mdot
.36656 .43664 Mdot
.63528 .47291 Mdot
.45072 .61557 Mdot
.56851 .53166 Mdot
.79449 .61184 Mdot
.7721 .43365 Mdot
.27232 .53527 Mdot
.55651 .46645 Mdot
.22449 .5667 Mdot
.24315 .58778 Mdot
.60172 .51045 Mdot
.45878 .4043 Mdot
.54057 .73349 Mdot
.47978 .27716 Mdot
.31104 .427 Mdot
.76544 .29838 Mdot
.61288 .44718 Mdot
.49452 .32965 Mdot
.35393 .43344 Mdot
.63439 .74005 Mdot
.27288 .34977 Mdot
.58359 .46062 Mdot
.80743 .29422 Mdot
.48673 .27377 Mdot
.41198 .6143 Mdot
.23242 .67984 Mdot
.51851 .35851 Mdot
.5054 .72451 Mdot
.4671 .65835 Mdot
.66852 .77631 Mdot
.49976 .31832 Mdot
.4558 .66685 Mdot
.49293 .35665 Mdot
.54278 .75145 Mdot
.52072 .30656 Mdot
.42943 .65436 Mdot
.6112 .47404 Mdot
.42112 .63443 Mdot
.55486 .74734 Mdot
.43375 .60093 Mdot
.30969 .43282 Mdot
.32516 .58262 Mdot
.33295 .4352 Mdot
.54058 .63475 Mdot
.34386 .24332 Mdot
.34346 .46099 Mdot
.61733 .73681 Mdot
.56013 .46538 Mdot
.48285 .3774 Mdot
.41635 .6201 Mdot
.45338 .6718 Mdot
.50562 .54176 Mdot
.48442 .34391 Mdot
.41901 .64369 Mdot
.59267 .2573 Mdot
.37299 .81925 Mdot
.67977 .45447 Mdot
.61922 .62308 Mdot
.49341 .34602 Mdot
.41569 .65141 Mdot
.20678 .45677 Mdot
.46696 .29808 Mdot
.42264 .61916 Mdot
.32286 .44753 Mdot
.32144 .42259 Mdot
.60204 .44521 Mdot
.28126 .45791 Mdot
.40324 .62422 Mdot
.21938 .51242 Mdot
.50321 .35753 Mdot
.63525 .73579 Mdot
.55558 .75319 Mdot
.45378 .64929 Mdot
.67871 .49571 Mdot
.47674 .38649 Mdot
.38661 .63875 Mdot
.72609 .55814 Mdot
.46047 .13937 Mdot
.41826 .63913 Mdot
.4774 .36243 Mdot
.49074 .32837 Mdot
.5355 .49101 Mdot
.47565 .47236 Mdot
.42619 .60384 Mdot
.51831 .82537 Mdot
.59812 .67627 Mdot
.33458 .5922 Mdot
.27278 .61505 Mdot
.61442 .43829 Mdot
.65587 .49611 Mdot
.3386 .44605 Mdot
.61897 .47492 Mdot
.48926 .37146 Mdot
.6313 .44573 Mdot
.3284 .41463 Mdot
.45399 .65996 Mdot
.58366 .48412 Mdot
.556 .71555 Mdot
.38091 .44303 Mdot
.36784 .43501 Mdot
.45237 .63671 Mdot
.4943 .30286 Mdot
.52358 .67108 Mdot
.42908 .62698 Mdot
.65215 .47702 Mdot
.3528 .59548 Mdot
.5791 .51334 Mdot
.77812 .56811 Mdot
.47664 .29457 Mdot
.40469 .61113 Mdot
.44169 .33234 Mdot
.33783 .43356 Mdot
.4607 .66958 Mdot
.62026 .4632 Mdot
.42775 .61895 Mdot
.3189 .67978 Mdot
.7888 .58567 Mdot
.5111 .30918 Mdot
.30356 .62863 Mdot
.47961 .36513 Mdot
.33329 .59305 Mdot
.75142 .59742 Mdot
.54904 .73072 Mdot
.44437 .65406 Mdot
.81885 .48651 Mdot
.42069 .62495 Mdot
.6151 .48122 Mdot
.61189 .49947 Mdot
.46439 .61841 Mdot
.53162 .69771 Mdot
.24045 .31407 Mdot
.40239 .49619 Mdot
.50505 .32674 Mdot
.72746 .4539 Mdot
.52263 .13289 Mdot
.32785 .40317 Mdot
.34142 .44829 Mdot
.58408 .42667 Mdot
.59716 .44367 Mdot
.3677 .4254 Mdot
.31984 .41257 Mdot
.54303 .75671 Mdot
.4283 .65634 Mdot
.52831 .3173 Mdot
.34991 .4056 Mdot
.56559 .5577 Mdot
.54831 .62023 Mdot
.56136 .42894 Mdot
.69331 .50925 Mdot
.56846 .52341 Mdot
.58799 .68034 Mdot
.34618 .41394 Mdot
.60977 .51778 Mdot
.54919 .49203 Mdot
.32642 .45401 Mdot
.54161 .75039 Mdot
.41662 .22982 Mdot
.43825 .63886 Mdot
.60677 .84769 Mdot
.58022 .50962 Mdot
.61118 .48294 Mdot
.34475 .46626 Mdot
.40671 .58923 Mdot
.46614 .30524 Mdot
.48752 .29629 Mdot
.46048 .63146 Mdot
.51156 .5656 Mdot
.65029 .46197 Mdot
.6038 .51339 Mdot
.43407 .64884 Mdot
.32498 .58347 Mdot
.24941 .52329 Mdot
.62411 .5088 Mdot
.35186 .43283 Mdot
.44041 .67502 Mdot
.34031 .41185 Mdot
.56909 .49104 Mdot
.61604 .48466 Mdot
.66113 .48082 Mdot
.5953 .44412 Mdot
.3688 .44173 Mdot
.61269 .51454 Mdot
.6724 .45758 Mdot
.507 .31533 Mdot
.65946 .48923 Mdot
.59546 .68122 Mdot
.62891 .47921 Mdot
.55824 .73237 Mdot
.50482 .61851 Mdot
.59405 .45186 Mdot
.6588 .49881 Mdot
.40509 .4959 Mdot
.60611 .46798 Mdot
.36238 .46131 Mdot
.48383 .33614 Mdot
.33911 .44092 Mdot
.36277 .42862 Mdot
.39551 .64316 Mdot
.53727 .7521 Mdot
.57977 .43779 Mdot
.56368 .72989 Mdot
.67911 .52593 Mdot
.57436 .50991 Mdot
.46921 .67948 Mdot
.18632 .51017 Mdot
.31951 .69987 Mdot
.62196 .46311 Mdot
.45805 .64061 Mdot
.40988 .61274 Mdot
.69305 .58291 Mdot
.56056 .52288 Mdot
.3683 .42232 Mdot
.32121 .44369 Mdot
.72284 .63012 Mdot
.25589 .34606 Mdot
.5554 .74322 Mdot
.51422 .60317 Mdot
.55931 .49972 Mdot
.61903 .51966 Mdot
.67594 .49804 Mdot
.38269 .62015 Mdot
.33394 .60065 Mdot
.44415 .66059 Mdot
.34196 .60668 Mdot
.33265 .41201 Mdot
.63478 .45109 Mdot
.77852 .41135 Mdot
.45654 .32215 Mdot
.4831 .33592 Mdot
.36073 .41483 Mdot
.39713 .60826 Mdot
.55147 .53989 Mdot
.26792 .77492 Mdot
.45391 .28162 Mdot
.5465 .76152 Mdot
.59807 .51065 Mdot
.45511 .63693 Mdot
.45562 .33889 Mdot
.53722 .6933 Mdot
.60413 .52953 Mdot
.49319 .63135 Mdot
.627 .46292 Mdot
.53985 .25961 Mdot
.50896 .32234 Mdot
.79037 .6921 Mdot
.47139 .29101 Mdot
.38267 .43745 Mdot
.33879 .45708 Mdot
.61278 .49249 Mdot
.22839 .70086 Mdot
.4951 .37814 Mdot
.28337 .45654 Mdot
.51645 .72435 Mdot
.36248 .60233 Mdot
.51867 .71295 Mdot
.39702 .61606 Mdot
.54498 .73902 Mdot
.41542 .64686 Mdot
.71082 .63357 Mdot
.43971 .28866 Mdot
.54857 .71571 Mdot
.42739 .56831 Mdot
.55833 .50669 Mdot
.56563 .7184 Mdot
.65117 .44051 Mdot
.71524 .4354 Mdot
.43404 .64666 Mdot
.53358 .69784 Mdot
.62743 .52071 Mdot
.76854 .32371 Mdot
.35283 .4504 Mdot
.36992 .42626 Mdot
.58174 .54331 Mdot
.42839 .65714 Mdot
.49361 .29003 Mdot
.45862 .42346 Mdot
.31122 .59355 Mdot
.60718 .51493 Mdot
.62728 .44432 Mdot
.43827 .31844 Mdot
.43208 .32998 Mdot
.6162 .48941 Mdot
.60326 .2464 Mdot
.61935 .50562 Mdot
.31274 .43578 Mdot
.45724 .30747 Mdot
.48805 .3311 Mdot
.40215 .62807 Mdot
.52049 .33357 Mdot
.6978 .49964 Mdot
.40646 .4015 Mdot
.62718 .43029 Mdot
.33854 .42852 Mdot
.45127 .43967 Mdot
.35987 .61547 Mdot
.7957 .3979 Mdot
.44388 .30836 Mdot
.64701 .52183 Mdot
.49354 .36238 Mdot
.52931 .71397 Mdot
.46973 .3282 Mdot
.45369 .34451 Mdot
.60167 .49445 Mdot
.58272 .46497 Mdot
.34694 .58534 Mdot
.47866 .48041 Mdot
.51684 .33974 Mdot
.61065 .51135 Mdot
.66821 .48443 Mdot
.63725 .53587 Mdot
.43656 .48893 Mdot
.45178 .32565 Mdot
.62831 .30085 Mdot
.75186 .54221 Mdot
.51694 .33518 Mdot
.69514 .23074 Mdot
.35802 .60021 Mdot
.36866 .60133 Mdot
.29798 .41475 Mdot
.6245 .50966 Mdot
.46965 .62368 Mdot
.5811 .47331 Mdot
.691 .52077 Mdot
.5934 .47256 Mdot
.52464 .69538 Mdot
.5593 .45406 Mdot
.33599 .5879 Mdot
.42411 .62823 Mdot
.59 .51432 Mdot
.58465 .4817 Mdot
.37467 .59737 Mdot
.45773 .29637 Mdot
.46961 .30254 Mdot
.51013 .76804 Mdot
.53763 .71539 Mdot
.31734 .45338 Mdot
.62621 .45416 Mdot
.45968 .63812 Mdot
.42198 .633 Mdot
.52051 .32407 Mdot
.43094 .6384 Mdot
.33112 .46639 Mdot
.61695 .46136 Mdot
.36966 .4276 Mdot
.53833 .69678 Mdot
.46791 .3568 Mdot
.61892 .44782 Mdot
.63692 .48061 Mdot
.50922 .33854 Mdot
.55965 .46671 Mdot
.52353 .72437 Mdot
.41726 .62822 Mdot
.49299 .31199 Mdot
.32103 .43215 Mdot
.39934 .62951 Mdot
.63575 .49851 Mdot
.45049 .14394 Mdot
.62057 .48269 Mdot
.63002 .50677 Mdot
.83625 .5494 Mdot
.56898 .43355 Mdot
.40763 .62602 Mdot
.43791 .32796 Mdot
.58749 .54215 Mdot
.58126 .64682 Mdot
.55941 .81012 Mdot
.4092 .65289 Mdot
.59143 .50798 Mdot
.80467 .40824 Mdot
.58979 .51037 Mdot
.59293 .72516 Mdot
.38762 .75837 Mdot
.60071 .59221 Mdot
.69024 .51285 Mdot
.36105 .45198 Mdot
.34182 .58251 Mdot
.40581 .63838 Mdot
.55643 .33684 Mdot
.60426 .50125 Mdot
.52494 .26597 Mdot
.60815 .53481 Mdot
.31953 .42312 Mdot
.71537 .45274 Mdot
.42196 .63963 Mdot
.18502 .48048 Mdot
.65141 .48044 Mdot
.45189 .31929 Mdot
.3944 .6303 Mdot
.35946 .60205 Mdot
.63133 .51069 Mdot
.56095 .71732 Mdot
.28842 .45241 Mdot
.62572 .42428 Mdot
.33427 .42615 Mdot
.61057 .52556 Mdot
.66748 .54628 Mdot
.19625 .62503 Mdot
.50667 .31793 Mdot
.33358 .44896 Mdot
.25841 .6043 Mdot
.55962 .47163 Mdot
.49818 .31574 Mdot
.4789 .34024 Mdot
.55464 .75149 Mdot
.47098 .51944 Mdot
.36297 .26816 Mdot
.75475 .35807 Mdot
.64446 .39449 Mdot
.40771 .64724 Mdot
.25165 .56767 Mdot
.64459 .48665 Mdot
.29637 .49337 Mdot
.36847 .4545 Mdot
.61082 .4795 Mdot
.6038 .38478 Mdot
.46537 .35262 Mdot
.6267 .4951 Mdot
.54006 .74865 Mdot
.26458 .47142 Mdot
.29194 .49684 Mdot
.59737 .18472 Mdot
.41224 .65583 Mdot
.66628 .52339 Mdot
.69388 .49792 Mdot
.32007 .57803 Mdot
.58476 .52782 Mdot
.41079 .626 Mdot
.75848 .65678 Mdot
.52542 .69867 Mdot
.45879 .34702 Mdot
.35795 .60053 Mdot
.57384 .53198 Mdot
.66359 .50619 Mdot
.55737 .76038 Mdot
.64283 .52078 Mdot
.1807 .56664 Mdot
.28756 .58941 Mdot
.45975 .62197 Mdot
.4943 .30549 Mdot
.56152 .50548 Mdot
.329 .59867 Mdot
.60562 .49698 Mdot
.7396 .40257 Mdot
.65059 .51568 Mdot
.34202 .27465 Mdot
.51301 .33984 Mdot
.33359 .42853 Mdot
.65415 .54576 Mdot
.59494 .46628 Mdot
.46018 .73363 Mdot
.68586 .5269 Mdot
.57885 .49968 Mdot
.50195 .29896 Mdot
.4545 .32197 Mdot
.47208 .31541 Mdot
.42746 .60878 Mdot
.24855 .40257 Mdot
.34801 .43488 Mdot
.62135 .43713 Mdot
.35317 .40693 Mdot
.72625 .50669 Mdot
.55369 .76261 Mdot
.71973 .27619 Mdot
.63553 .53121 Mdot
.47838 .31794 Mdot
.39064 .32792 Mdot
.50711 .36429 Mdot
.49153 .65002 Mdot
.34447 .42043 Mdot
.46263 .34657 Mdot
.60042 .4599 Mdot
.46627 .47163 Mdot
.63161 .21308 Mdot
.33295 .44176 Mdot
.67569 .47209 Mdot
.44642 .67022 Mdot
.35365 .62356 Mdot
.52466 .11826 Mdot
.3444 .45201 Mdot
.248 .58678 Mdot
.60431 .50837 Mdot
.45793 .31858 Mdot
.35359 .46111 Mdot
.35468 .45268 Mdot
.43062 .64401 Mdot
.58519 .46051 Mdot
.59602 .45246 Mdot
.35903 .59782 Mdot
.31962 .44183 Mdot
.59416 .5502 Mdot
.671 .47707 Mdot
.83435 .51045 Mdot
.54631 .35427 Mdot
.5074 .86234 Mdot
.70755 .49989 Mdot
.63082 .38608 Mdot
.49326 .47293 Mdot
.46077 .35578 Mdot
.58931 .45451 Mdot
.56516 .51007 Mdot
.40378 .62712 Mdot
.6195 .47052 Mdot
.45535 .60767 Mdot
.35016 .44562 Mdot
.68301 .22699 Mdot
.41345 .25896 Mdot
.75423 .65377 Mdot
.61577 .47032 Mdot
.27415 .32161 Mdot
.53739 .70529 Mdot
.38064 .45391 Mdot
.47928 .308 Mdot
.56319 .47892 Mdot
.41029 .60248 Mdot
.44563 .65466 Mdot
.47039 .34167 Mdot
.21413 .53078 Mdot
.48503 .75267 Mdot
.5685 .4899 Mdot
.4465 .60925 Mdot
.39286 .37419 Mdot
.5888 .2389 Mdot
.36837 .41033 Mdot
.51965 .70251 Mdot
.44579 .66024 Mdot
.35138 .41239 Mdot
.53308 .39064 Mdot
.46728 .34842 Mdot
.44011 .33971 Mdot
.40265 .74182 Mdot
.42707 .60311 Mdot
.54833 .71042 Mdot
.24644 .38358 Mdot
.24169 .37935 Mdot
.5222 .69848 Mdot
.46156 .65741 Mdot
.45416 .3307 Mdot
.49387 .32008 Mdot
.48492 .33606 Mdot
.18881 .46536 Mdot
.49327 .29703 Mdot
.68378 .32451 Mdot
.66966 .49146 Mdot
.51636 .491 Mdot
.58939 .50731 Mdot
.37084 .4441 Mdot
.50936 .32473 Mdot
.49505 .49767 Mdot
.57959 .45039 Mdot
.61761 .1977 Mdot
.60433 .51558 Mdot
.37788 .41741 Mdot
.62744 .50215 Mdot
.67313 .28717 Mdot
.45719 .35568 Mdot
.62253 .46712 Mdot
.31184 .46544 Mdot
.53914 .72518 Mdot
.53143 .33819 Mdot
.59372 .45255 Mdot
.31629 .33533 Mdot
.58128 .42924 Mdot
.7728 .64546 Mdot
.65658 .71576 Mdot
.54621 .76187 Mdot
.70711 .46407 Mdot
.42349 .65781 Mdot
.52935 .30647 Mdot
.66063 .43083 Mdot
.3318 .4407 Mdot
.41353 .20973 Mdot
.45168 .65354 Mdot
.69271 .43373 Mdot
.54356 .45871 Mdot
.53687 .75101 Mdot
.48615 .38552 Mdot
.35935 .46238 Mdot
.56832 .45181 Mdot
.65222 .52932 Mdot
.76272 .63948 Mdot
.64578 .42517 Mdot
.64972 .45773 Mdot
.56504 .7459 Mdot
.63815 .309 Mdot
.63186 .48099 Mdot
.48544 .6405 Mdot
.44081 .33985 Mdot
.57843 .54093 Mdot
.62657 .29671 Mdot
.61018 .51018 Mdot
.46284 .33496 Mdot
.44014 .34734 Mdot
.37201 .31476 Mdot
.5196 .73467 Mdot
.65014 .51624 Mdot
.6812 .72325 Mdot
.65454 .48734 Mdot
.34958 .42971 Mdot
.57193 .48525 Mdot
.4441 .65105 Mdot
.19178 .4935 Mdot
.43058 .61352 Mdot
.5765 .47656 Mdot
.48911 .33615 Mdot
.36129 .45561 Mdot
.35981 .71737 Mdot
.42576 .76661 Mdot
.67656 .3207 Mdot
.63051 .81201 Mdot
.52675 .70348 Mdot
.54828 .69124 Mdot
.34765 .4688 Mdot
.62461 .46785 Mdot
.64707 .74558 Mdot
.60936 .42651 Mdot
.62943 .49231 Mdot
.59241 .47369 Mdot
.30851 .49211 Mdot
.34408 .44289 Mdot
.43447 .63378 Mdot
.6171 .4873 Mdot
.6123 .51178 Mdot
.49837 .35756 Mdot
.54087 .72527 Mdot
.42349 .61253 Mdot
.54454 .71839 Mdot
.44635 .62445 Mdot
.71211 .24245 Mdot
.65896 .45339 Mdot
.53725 .72307 Mdot
.36485 .46228 Mdot
.46212 .32144 Mdot
.32135 .59577 Mdot
.39646 .61849 Mdot
.42035 .64209 Mdot
.60627 .51378 Mdot
.46053 .32819 Mdot
.51935 .33398 Mdot
.52949 .71132 Mdot
.33136 .46176 Mdot
.57835 .4742 Mdot
.56903 .49951 Mdot
.67033 .5833 Mdot
.38748 .62372 Mdot
.57786 .2473 Mdot
.36301 .33911 Mdot
.62397 .46476 Mdot
.50052 .30633 Mdot
.59022 .4827 Mdot
.7949 .43298 Mdot
.46595 .30041 Mdot
.57811 .45778 Mdot
.2442 .34936 Mdot
.37504 .61799 Mdot
.33201 .30549 Mdot
.66397 .48781 Mdot
.67795 .78478 Mdot
.64727 .49306 Mdot
.83294 .45768 Mdot
.36375 .56621 Mdot
.63708 .45143 Mdot
.64122 .48507 Mdot
.7467 .33973 Mdot
.5969 .5018 Mdot
.33086 .59154 Mdot
.71023 .44937 Mdot
.45096 .31162 Mdot
.50299 .50735 Mdot
.48534 .60999 Mdot
.51572 .72619 Mdot
.46052 .63083 Mdot
.29791 .63283 Mdot
.53369 .74226 Mdot
.49564 .33974 Mdot
.63525 .4605 Mdot
.5264 .5793 Mdot
.41313 .65923 Mdot
.53742 .4885 Mdot
.34833 .42651 Mdot
.3107 .61988 Mdot
.46557 .61201 Mdot
.32573 .43091 Mdot
.61953 .53627 Mdot
.63071 .23106 Mdot
.36364 .7507 Mdot
.79691 .67537 Mdot
.35171 .46495 Mdot
.31614 .42543 Mdot
.21386 .43472 Mdot
.51435 .71416 Mdot
.76672 .57679 Mdot
.30683 .29927 Mdot
.31128 .45447 Mdot
.73663 .6402 Mdot
.43946 .66229 Mdot
.306 .33385 Mdot
.47969 .27719 Mdot
.6705 .50656 Mdot
.59905 .46166 Mdot
.32987 .4601 Mdot
.51837 .43199 Mdot
.20931 .64445 Mdot
.33193 .43612 Mdot
.68702 .50191 Mdot
.44753 .52483 Mdot
.35063 .59813 Mdot
.35563 .58999 Mdot
.52714 .74645 Mdot
.5254 .77295 Mdot
.5003 .35302 Mdot
.54295 .7556 Mdot
.28862 .49885 Mdot
.63969 .52612 Mdot
.32439 .44029 Mdot
.3342 .60237 Mdot
.32137 .42687 Mdot
.54086 .74593 Mdot
.54354 .75995 Mdot
.50622 .31421 Mdot
.46762 .30486 Mdot
.62127 .38175 Mdot
.69702 .66334 Mdot
.58981 .51212 Mdot
.50496 .2088 Mdot
.50663 .35575 Mdot
.67715 .43856 Mdot
.52491 .69304 Mdot
.53857 .7207 Mdot
.5504 .27571 Mdot
.62546 .45056 Mdot
.62305 .75889 Mdot
.62171 .45118 Mdot
.74389 .58686 Mdot
.57974 .52463 Mdot
.43125 .64174 Mdot
.63532 .45335 Mdot
.53193 .67342 Mdot
.61253 .43852 Mdot
.57818 .50119 Mdot
.43532 .65939 Mdot
.61714 .42276 Mdot
.44314 .65168 Mdot
.57573 .47465 Mdot
.53291 .68569 Mdot
.45995 .63715 Mdot
.61 .63551 Mdot
.41876 .48696 Mdot
.32689 .58668 Mdot
.56047 .73051 Mdot
.56019 .74705 Mdot
.55884 .64375 Mdot
.48116 .30809 Mdot
.51342 .39551 Mdot
.62502 .47084 Mdot
.41926 .65233 Mdot
.34175 .44606 Mdot
.61446 .51053 Mdot
.56869 .50649 Mdot
.65902 .46791 Mdot
.47883 .36135 Mdot
.40506 .60648 Mdot
.53537 .72751 Mdot
.44261 .60868 Mdot
.4788 .73032 Mdot
.47561 .61963 Mdot
.55169 .49796 Mdot
.64399 .54442 Mdot
.7482 .46305 Mdot
.46958 .22228 Mdot
.2258 .3489 Mdot
.46972 .34758 Mdot
.34094 .58457 Mdot
.54121 .75789 Mdot
.72438 .47378 Mdot
.47983 .31283 Mdot
.43189 .65517 Mdot
.62673 .46222 Mdot
.6817 .48694 Mdot
.31671 .39641 Mdot
.52076 .2863 Mdot
.61252 .68132 Mdot
.46187 .60802 Mdot
.33641 .59468 Mdot
.24519 .404 Mdot
.60999 .3988 Mdot
.50997 .55602 Mdot
.60088 .47906 Mdot
.55924 .71323 Mdot
.45564 .33887 Mdot
.35975 .72947 Mdot
.3212 .4507 Mdot
.47633 .47478 Mdot
.61628 .46954 Mdot
.25723 .40942 Mdot
.48811 .33728 Mdot
.54617 .75029 Mdot
.32892 .45928 Mdot
.517 .73354 Mdot
.35597 .58975 Mdot
.61909 .79115 Mdot
.65275 .50193 Mdot
.5801 .49915 Mdot
.37735 .42188 Mdot
.49435 .35494 Mdot
.51867 .75197 Mdot
.78123 .60959 Mdot
.45677 .61463 Mdot
.61592 .76218 Mdot
.5008 .37379 Mdot
.70576 .33006 Mdot
.43694 .60851 Mdot
.35983 .41424 Mdot
.5498 .64315 Mdot
.33006 .41388 Mdot
.59933 .44805 Mdot
.48338 .32462 Mdot
.35408 .44657 Mdot
.44789 .72707 Mdot
.80275 .37637 Mdot
.71589 .33027 Mdot
.65097 .46954 Mdot
.70681 .25859 Mdot
.80993 .59076 Mdot
.50961 .41241 Mdot
.30908 .43308 Mdot
.60524 .49086 Mdot
.59748 .5387 Mdot
.64937 .47521 Mdot
.35937 .43172 Mdot
.4457 .69914 Mdot
.42629 .64773 Mdot
.59839 .51473 Mdot
.54863 .75562 Mdot
.44427 .64677 Mdot
.4307 .67566 Mdot
.40839 .63141 Mdot
.44584 .32265 Mdot
.58694 .44911 Mdot
.29915 .37002 Mdot
.81998 .37411 Mdot
.33768 .44107 Mdot
.32734 .58663 Mdot
.58828 .52044 Mdot
.30768 .27714 Mdot
.47347 .31552 Mdot
.45924 .61604 Mdot
.61054 .48277 Mdot
.44786 .70772 Mdot
.38848 .60155 Mdot
.4114 .63521 Mdot
.49224 .31607 Mdot
.4912 .41276 Mdot
.62029 .47359 Mdot
.6481 .49698 Mdot
.49678 .35094 Mdot
.54708 .78991 Mdot
.19666 .48641 Mdot
.58662 .48182 Mdot
.33188 .42906 Mdot
.34679 .82237 Mdot
.65955 .50769 Mdot
.55007 .38029 Mdot
.36595 .60149 Mdot
.33515 .33483 Mdot
.57182 .24423 Mdot
.70828 .46157 Mdot
.75649 .34422 Mdot
.53203 .60328 Mdot
.69299 .2357 Mdot
.49439 .69269 Mdot
.38922 .54109 Mdot
.72465 .2546 Mdot
.31884 .46761 Mdot
.51802 .51304 Mdot
.71533 .54406 Mdot
.20196 .52002 Mdot
.50354 .44507 Mdot
.5028 .79823 Mdot
.44805 .74666 Mdot
.48 .56889 Mdot
.42446 .62168 Mdot
.73416 .57874 Mdot
.57938 .47546 Mdot
.80744 .59913 Mdot
.61724 .25297 Mdot
.20602 .65007 Mdot
.72023 .26967 Mdot
.68504 .71918 Mdot
.65082 .23032 Mdot
.80582 .42749 Mdot
.75105 .47183 Mdot
.44454 .24706 Mdot
.48765 .84286 Mdot
.23813 .38894 Mdot
.7042 .7138 Mdot
.56862 .54644 Mdot
.50848 .59832 Mdot
.73101 .7067 Mdot
.69401 .35082 Mdot
.24719 .72069 Mdot
.40576 .6188 Mdot
.44645 .34683 Mdot
.70583 .55919 Mdot
.529 .3544 Mdot
.39483 .44851 Mdot
.75459 .33838 Mdot
.82725 .46651 Mdot
.66602 .28358 Mdot
.67534 .78993 Mdot
.57024 .34257 Mdot
.19122 .36729 Mdot
.41325 .51049 Mdot
.45461 .36201 Mdot
.41692 .81055 Mdot
.24326 .3773 Mdot
.39601 .26224 Mdot
.70995 .51222 Mdot
.41436 .67515 Mdot
.6389 .6528 Mdot
.49452 .33074 Mdot
.57003 .23564 Mdot
.35382 .58473 Mdot
.41254 .2393 Mdot
.51258 .668 Mdot
.78841 .37834 Mdot
.4841 .55882 Mdot
.30152 .34469 Mdot
.24459 .54922 Mdot
.45339 .14273 Mdot
.70272 .6795 Mdot
.79528 .49764 Mdot
.3523 .39647 Mdot
.5061 .43522 Mdot
.21458 .5884 Mdot
.67317 .67614 Mdot
.2437 .36991 Mdot
.45896 .17624 Mdot
.79151 .64981 Mdot
.51092 .15913 Mdot
.52456 .38542 Mdot
.65706 .46619 Mdot
.78215 .47701 Mdot
.6505 .39792 Mdot
.5634 .76311 Mdot
.56674 .17602 Mdot
.54511 .69791 Mdot
.52735 .37424 Mdot
.21045 .52901 Mdot
.6801 .30829 Mdot
.61537 .75095 Mdot
.51019 .72967 Mdot
.5573 .45454 Mdot
.11259 .50943 Mdot
.68311 .23322 Mdot
.36455 .31863 Mdot
.83515 .50897 Mdot
.26163 .43202 Mdot
.64262 .73338 Mdot
.35593 .44116 Mdot
.78015 .31337 Mdot
.48907 .31933 Mdot
.76594 .26531 Mdot
.79814 .3527 Mdot
.26913 .70142 Mdot
.20005 .72757 Mdot
.28927 .52535 Mdot
.60823 .58741 Mdot
.54257 .60727 Mdot
.60275 .6553 Mdot
.2122 .63082 Mdot
.28002 .72224 Mdot
.25878 .43058 Mdot
.69285 .75511 Mdot
.74765 .28355 Mdot
.74397 .61802 Mdot
.64889 .76616 Mdot
.20854 .5489 Mdot
.42905 .48267 Mdot
.46161 .37895 Mdot
.40816 .47088 Mdot
.45661 .24696 Mdot
.5521 .17191 Mdot
.60993 .39431 Mdot
.27729 .78154 Mdot
.51278 .68441 Mdot
.37946 .58723 Mdot
.82008 .53485 Mdot
.62169 .62978 Mdot
.73615 .47428 Mdot
.22838 .43027 Mdot
.54766 .46833 Mdot
.23391 .41594 Mdot
.4188 .36154 Mdot
.30096 .62904 Mdot
.24 .40579 Mdot
.37561 .37439 Mdot
.76855 .62913 Mdot
.76965 .44151 Mdot
.25757 .33314 Mdot
.45156 .30817 Mdot
.64861 .69028 Mdot
.71687 .66508 Mdot
.83183 .5183 Mdot
.25797 .60346 Mdot
.81153 .66094 Mdot
.25798 .62261 Mdot
.62296 .43155 Mdot
.68385 .45878 Mdot
.57335 .55488 Mdot
.68113 .68308 Mdot
.66509 .47566 Mdot
.25437 .41284 Mdot
.83534 .53688 Mdot
.58861 .38451 Mdot
.32641 .64624 Mdot
.42746 .20222 Mdot
.79863 .66266 Mdot
.77359 .50042 Mdot
.3407 .55778 Mdot
.53362 .4257 Mdot
.24327 .2898 Mdot
.44709 .63982 Mdot
.74065 .63333 Mdot
.3004 .42718 Mdot
.39359 .74387 Mdot
.73734 .33883 Mdot
.26336 .68989 Mdot
.83695 .54023 Mdot
.20382 .48384 Mdot
.30857 .6935 Mdot
.54504 .65869 Mdot
.60675 .75397 Mdot
.45422 .20353 Mdot
.67763 .51932 Mdot
.66813 .55854 Mdot
.5661 .72777 Mdot
.68254 .39421 Mdot
.75725 .54403 Mdot
.43078 .78793 Mdot
.68395 .46846 Mdot
.34187 .76042 Mdot
.33541 .59678 Mdot
.47191 .47313 Mdot
.57089 .14037 Mdot
.54317 .49254 Mdot
.2972 .53681 Mdot
.7834 .66034 Mdot
.64132 .7105 Mdot
.81026 .51922 Mdot
.32596 .36906 Mdot
.49925 .16518 Mdot
.81654 .38645 Mdot
.42382 .77353 Mdot
.65164 .20227 Mdot
.85078 .58166 Mdot
.46879 .16514 Mdot
.51317 .24021 Mdot
.32677 .47394 Mdot
.70572 .18472 Mdot
.46716 .64556 Mdot
.38336 .21404 Mdot
.63641 .39287 Mdot
.4047 .69965 Mdot
.50911 .29919 Mdot
.53127 .47109 Mdot
.48473 .5687 Mdot
.49918 .27595 Mdot
.57104 .53376 Mdot
.49609 .13988 Mdot
.41718 .1848 Mdot
.50938 .14611 Mdot
.75619 .70548 Mdot
.66272 .2089 Mdot
.62489 .595 Mdot
.69616 .336 Mdot
.71446 .56936 Mdot
.57028 .48688 Mdot
.7134 .61431 Mdot
.28649 .52889 Mdot
.3493 .73932 Mdot
.38363 .26097 Mdot
.52552 .32537 Mdot
.56726 .18859 Mdot
.46518 .10787 Mdot
.577 .33499 Mdot
.59636 .29948 Mdot
.28761 .48827 Mdot
.70077 .6663 Mdot
.41795 .33204 Mdot
.31577 .72641 Mdot
.82602 .52885 Mdot
.72118 .53878 Mdot
.74511 .64244 Mdot
.45399 .80206 Mdot
.58713 .72313 Mdot
.42169 .5819 Mdot
.7882 .36381 Mdot
.62161 .60743 Mdot
.26894 .68085 Mdot
.52066 .54197 Mdot
.23871 .67978 Mdot
.478 .77346 Mdot
.29203 .6072 Mdot
.71785 .68194 Mdot
.35659 .62019 Mdot
.73617 .61535 Mdot
.4518 .51941 Mdot
.73749 .53511 Mdot
.53208 .60234 Mdot
.73877 .61064 Mdot
.58566 .72059 Mdot
.58003 .17077 Mdot
.84996 .61307 Mdot
.35895 .19841 Mdot
.69083 .77493 Mdot
.41866 .37323 Mdot
.66302 .51218 Mdot
.82985 .57528 Mdot
.54789 .15259 Mdot
.8262 .40442 Mdot
.21734 .48621 Mdot
.44296 .71972 Mdot
.38073 .44909 Mdot
.35901 .20199 Mdot
.51522 .78847 Mdot
.81315 .46339 Mdot
.22965 .34636 Mdot
.29606 .41687 Mdot
.18804 .52043 Mdot
.38537 .2053 Mdot
.71408 .31107 Mdot
.55784 .2534 Mdot
.53655 .47571 Mdot
.64593 .26252 Mdot
.4409 .31859 Mdot
.24022 .55387 Mdot
.68007 .67674 Mdot
.45189 .63815 Mdot
.60429 .61676 Mdot
.68991 .54634 Mdot
.55963 .45139 Mdot
.48149 .60095 Mdot
.44256 .29845 Mdot
.4661 .22528 Mdot
.37004 .38197 Mdot
.69298 .21584 Mdot
.27624 .54268 Mdot
.66637 .55105 Mdot
.6603 .70344 Mdot
.32908 .69975 Mdot
.22123 .43426 Mdot
.30559 .45231 Mdot
.75095 .30272 Mdot
.40203 .45798 Mdot
.65316 .69207 Mdot
.62883 .25093 Mdot
.77548 .58656 Mdot
.63947 .54515 Mdot
.37754 .33233 Mdot
.72747 .40801 Mdot
.48069 .48823 Mdot
.51524 .37836 Mdot
.42961 .32761 Mdot
.74042 .7677 Mdot
.27151 .48776 Mdot
.2743 .59391 Mdot
.76002 .31513 Mdot
.34598 .41774 Mdot
.5146 .35305 Mdot
.72842 .60174 Mdot
.77029 .63517 Mdot
.70876 .38274 Mdot
.39697 .60465 Mdot
.39117 .66326 Mdot
.4574 .78798 Mdot
.71239 .26751 Mdot
.67147 .23931 Mdot
.20089 .64781 Mdot
.52115 .32037 Mdot
.78097 .56259 Mdot
.75058 .65198 Mdot
.48951 .36536 Mdot
.53372 .35484 Mdot
.39222 .24064 Mdot
.63457 .18233 Mdot
.27503 .38423 Mdot
.67623 .77821 Mdot
.5801 .67191 Mdot
.45461 .70352 Mdot
.34506 .71077 Mdot
.67928 .73751 Mdot
.76479 .3236 Mdot
.56036 .2287 Mdot
.69318 .28078 Mdot
.64046 .55811 Mdot
.52392 .27477 Mdot
.34085 .20806 Mdot
.42534 .50213 Mdot
.70013 .32091 Mdot
.39911 .38532 Mdot
.6542 .47954 Mdot
.45548 .1427 Mdot
.79319 .61619 Mdot
.2156 .4172 Mdot
.30353 .46917 Mdot
.63534 .51268 Mdot
.65793 .45607 Mdot
.53286 .41461 Mdot
.35316 .33099 Mdot
.43113 .19042 Mdot
.68228 .73659 Mdot
.44373 .40065 Mdot
.61085 .24746 Mdot
.29713 .53796 Mdot
.78791 .38657 Mdot
.81432 .56801 Mdot
.47139 .5066 Mdot
.28095 .53062 Mdot
.53879 .64268 Mdot
.70658 .75684 Mdot
.50046 .58619 Mdot
.65131 .58768 Mdot
.32346 .27316 Mdot
.34174 .35192 Mdot
.33892 .71316 Mdot
.59215 .52606 Mdot
.21349 .52893 Mdot
.80255 .42355 Mdot
.22843 .71277 Mdot
.21579 .61425 Mdot
.47837 .13263 Mdot
.74191 .39249 Mdot
.33041 .35662 Mdot
.6576 .24449 Mdot
.22126 .71478 Mdot
.49917 .59591 Mdot
.60943 .20116 Mdot
.54113 .65205 Mdot
.73771 .29076 Mdot
.29853 .45414 Mdot
.27334 .35178 Mdot
.42226 .20384 Mdot
.64787 .19244 Mdot
.78132 .50602 Mdot
.77245 .34793 Mdot
.52051 .54618 Mdot
.60269 .16501 Mdot
.32834 .26285 Mdot
.47892 .57103 Mdot
.44646 .66909 Mdot
.2286 .4524 Mdot
.56257 .20572 Mdot
.41908 .29174 Mdot
.74121 .63917 Mdot
.45731 .57537 Mdot
.72909 .47367 Mdot
.66726 .26323 Mdot
.65359 .62668 Mdot
.35644 .35755 Mdot
.65786 .70477 Mdot
.81379 .43364 Mdot
.46972 .58767 Mdot
.35242 .7098 Mdot
.29032 .56091 Mdot
.63318 .7872 Mdot
.35467 .326 Mdot
.2673 .48994 Mdot
.79494 .4934 Mdot
.50279 .77137 Mdot
.69399 .70646 Mdot
.82155 .70134 Mdot
.69245 .73997 Mdot
.43582 .23808 Mdot
.5444 .17368 Mdot
.82088 .54567 Mdot
.45267 .23178 Mdot
.20087 .61367 Mdot
.5426 .31636 Mdot
.70823 .63366 Mdot
.59274 .47207 Mdot
.55736 .1419 Mdot
.65069 .64737 Mdot
.55211 .16955 Mdot
.81925 .61461 Mdot
.64486 .25807 Mdot
.5603 .44716 Mdot
.47786 .61461 Mdot
.36196 .52297 Mdot
.66398 .61941 Mdot
.70457 .2864 Mdot
.54652 .33015 Mdot
.31107 .6106 Mdot
.31878 .57394 Mdot
.4458 .5985 Mdot
.47021 .39532 Mdot
.26594 .52546 Mdot
.35771 .34391 Mdot
.55598 .77977 Mdot
.4918 .54206 Mdot
.7145 .65722 Mdot
.57655 .24468 Mdot
.7219 .32237 Mdot
.25465 .6827 Mdot
.40271 .42268 Mdot
.40644 .62475 Mdot
.75866 .37597 Mdot
.71094 .72863 Mdot
.37863 .36606 Mdot
.48389 .17368 Mdot
.21809 .45157 Mdot
.71317 .58598 Mdot
.75001 .53324 Mdot
.2276 .65655 Mdot
.51682 .83009 Mdot
.5263 .19123 Mdot
.48113 .23927 Mdot
.62465 .75233 Mdot
.68781 .55364 Mdot
.71279 .24397 Mdot
.71336 .69732 Mdot
.7561 .51565 Mdot
.41244 .4973 Mdot
.68103 .3591 Mdot
.62898 .2423 Mdot
.59693 .63306 Mdot
.50386 .53657 Mdot
.19834 .34502 Mdot
.50308 .28671 Mdot
.43756 .14151 Mdot
.31555 .44485 Mdot
.18024 .45871 Mdot
.58426 .74033 Mdot
.44941 .51129 Mdot
.5057 .53196 Mdot
.37879 .32342 Mdot
.341 .27424 Mdot
.72965 .72716 Mdot
.25683 .70759 Mdot
.4796 .62874 Mdot
.65056 .74987 Mdot
.60319 .7993 Mdot
.75293 .34745 Mdot
.56093 .51269 Mdot
.68331 .75252 Mdot
.42635 .49752 Mdot
.34627 .73627 Mdot
.82186 .58647 Mdot
.40229 .33578 Mdot
.68725 .51468 Mdot
.69641 .66835 Mdot
.60721 .2023 Mdot
.80699 .37423 Mdot
.17898 .55014 Mdot
.41881 .36248 Mdot
.34522 .4719 Mdot
.57384 .59559 Mdot
.72217 .28667 Mdot
.62617 .72591 Mdot
.28824 .35522 Mdot
.71083 .67494 Mdot
.33909 .18476 Mdot
.44973 .18658 Mdot
.43002 .19111 Mdot
.65199 .72063 Mdot
.52399 .35824 Mdot
.37406 .23287 Mdot
.75155 .52408 Mdot
.39822 .32349 Mdot
.74365 .69671 Mdot
.73394 .64028 Mdot
.17342 .6226 Mdot
.73816 .45965 Mdot
.48167 .73077 Mdot
.60227 .2277 Mdot
.66132 .39565 Mdot
.31143 .47091 Mdot
.69538 .63301 Mdot
.41046 .38987 Mdot
.38299 .43649 Mdot
.35962 .35432 Mdot
.31756 .3307 Mdot
.75754 .51209 Mdot
.71309 .37505 Mdot
.42617 .38939 Mdot
.77263 .41076 Mdot
.51417 .28719 Mdot
.36071 .72907 Mdot
.33821 .69729 Mdot
.47429 .42819 Mdot
.46518 .62843 Mdot
.70945 .46483 Mdot
.48405 .50486 Mdot
.5235 .62261 Mdot
.32065 .23465 Mdot
.55169 .70128 Mdot
.52392 .34243 Mdot
.19935 .41613 Mdot
.48952 .36768 Mdot
.52093 .13656 Mdot
.30791 .71743 Mdot
.6291 .25328 Mdot
.43943 .77119 Mdot
.42343 .80417 Mdot
.1428 .46563 Mdot
.50054 .22145 Mdot
.40466 .49016 Mdot
.46768 .2568 Mdot
.47977 .29201 Mdot
.33049 .61685 Mdot
.32216 .5751 Mdot
.56524 .26386 Mdot
.31714 .53543 Mdot
.71303 .577 Mdot
.46696 .37348 Mdot
.48124 .7151 Mdot
.69311 .43299 Mdot
.65102 .19034 Mdot
.41734 .62208 Mdot
.24728 .27338 Mdot
.66251 .45139 Mdot
.75738 .44719 Mdot
.84007 .55677 Mdot
.18067 .53145 Mdot
.2974 .66937 Mdot
.54506 .82025 Mdot
.60274 .43333 Mdot
.42756 .38675 Mdot
.49659 .32858 Mdot
.76103 .56657 Mdot
.54561 .73624 Mdot
.6254 .68632 Mdot
.35642 .40796 Mdot
.274 .6837 Mdot
.26263 .53133 Mdot
.51129 .37393 Mdot
.41046 .33357 Mdot
.77124 .52399 Mdot
.28661 .32842 Mdot
.42801 .49491 Mdot
.74893 .34535 Mdot
.70521 .37431 Mdot
.46133 .37002 Mdot
.48134 .18311 Mdot
.74244 .65858 Mdot
.78357 .31132 Mdot
.54399 .5405 Mdot
.40174 .52125 Mdot
.27278 .3292 Mdot
.37452 .34739 Mdot
.56791 .24771 Mdot
.82623 .52481 Mdot
.66092 .68444 Mdot
.25475 .36556 Mdot
.73628 .60946 Mdot
.55751 .42585 Mdot
.47649 .54312 Mdot
.23017 .52302 Mdot
.15726 .57346 Mdot
.52888 .26176 Mdot
.20055 .56568 Mdot
.4655 .25055 Mdot
.29565 .53579 Mdot
.50153 .27997 Mdot
.36574 .69605 Mdot
.69555 .35733 Mdot
.27877 .6324 Mdot
.74313 .26825 Mdot
.82821 .52997 Mdot
.30013 .40695 Mdot
.38713 .65079 Mdot
.50351 .48148 Mdot
.60767 .56444 Mdot
.47503 .45668 Mdot
.63363 .44714 Mdot
.52252 .4041 Mdot
.18191 .50846 Mdot
.39123 .32888 Mdot
.53404 .46629 Mdot
.70295 .24103 Mdot
.78953 .3221 Mdot
.59482 .1654 Mdot
.61345 .76067 Mdot
.45614 .35016 Mdot
.47471 .15888 Mdot
.60116 .2748 Mdot
.81533 .42725 Mdot
.51884 .19624 Mdot
.76335 .74551 Mdot
.70348 .28869 Mdot
.39398 .38413 Mdot
.27395 .71385 Mdot
.34421 .28477 Mdot
.80801 .60926 Mdot
.4782 .57375 Mdot
.32861 .63491 Mdot
.8082 .61656 Mdot
.11895 .49112 Mdot
.50358 .23546 Mdot
.30944 .3383 Mdot
.69163 .55716 Mdot
.45735 .41707 Mdot
.3614 .54747 Mdot
.57244 .48809 Mdot
.3937 .64595 Mdot
.31462 .69832 Mdot
.72032 .65418 Mdot
.73796 .4939 Mdot
.36234 .54946 Mdot
.67046 .61486 Mdot
.74574 .57678 Mdot
.70023 .72011 Mdot
.72472 .31639 Mdot
.56808 .26078 Mdot
.68123 .52403 Mdot
.5287 .31755 Mdot
.51945 .73044 Mdot
.30296 .64515 Mdot
.57955 .46063 Mdot
.28543 .63971 Mdot
.31299 .29843 Mdot
.48194 .13653 Mdot
.34546 .67363 Mdot
.78227 .6238 Mdot
.4707 .27937 Mdot
.3624 .33138 Mdot
.78434 .42896 Mdot
.20445 .52106 Mdot
.38308 .56093 Mdot
.61374 .39437 Mdot
.69471 .24367 Mdot
.24275 .4131 Mdot
.76732 .61486 Mdot
.28166 .28283 Mdot
.37784 .44029 Mdot
.50889 .25248 Mdot
.68441 .5675 Mdot
.21164 .47825 Mdot
.49527 .38527 Mdot
.36226 .37413 Mdot
.41961 .53994 Mdot
.24064 .4202 Mdot
.7846 .66101 Mdot
.7743 .552 Mdot
.58396 .22097 Mdot
.6779 .24115 Mdot
.39736 .64294 Mdot
.74781 .63885 Mdot
.36194 .37665 Mdot
.39275 .55046 Mdot
.2584 .33883 Mdot
.69562 .22346 Mdot
.4829 .47077 Mdot
.63175 .64798 Mdot
.65163 .49506 Mdot
.63005 .3 Mdot
.38779 .32049 Mdot
.56539 .68912 Mdot
.27727 .58021 Mdot
.46729 .30098 Mdot
.25832 .55276 Mdot
.42249 .59221 Mdot
.69137 .64404 Mdot
.45156 .27081 Mdot
.55862 .3752 Mdot
.57137 .74024 Mdot
.31904 .60303 Mdot
.598 .54861 Mdot
.62324 .65776 Mdot
.61181 .74344 Mdot
.50928 .24888 Mdot
.4878 .22329 Mdot
.7524 .35305 Mdot
.76581 .65022 Mdot
.38849 .35905 Mdot
.51604 .19387 Mdot
.35064 .26845 Mdot
.71203 .35128 Mdot
.23202 .57672 Mdot
.66167 .47251 Mdot
.36895 .69666 Mdot
.51347 .35933 Mdot
.7301 .30341 Mdot
.73935 .39802 Mdot
.61161 .63472 Mdot
.45117 .4847 Mdot
.78839 .44541 Mdot
.43564 .46066 Mdot
.83549 .56473 Mdot
.34731 .28317 Mdot
.6784 .67663 Mdot
.30181 .41716 Mdot
.55548 .66367 Mdot
.22122 .63989 Mdot
.77873 .32052 Mdot
.25889 .69117 Mdot
.52816 .57713 Mdot
.19553 .55234 Mdot
.42201 .22523 Mdot
.81553 .61284 Mdot
.691 .66108 Mdot
.47283 .45525 Mdot
.68543 .42883 Mdot
.32987 .39264 Mdot
.32126 .59509 Mdot
.38573 .70866 Mdot
.58149 .27161 Mdot
.39913 .68203 Mdot
.28296 .65354 Mdot
.60316 .55354 Mdot
.28327 .29769 Mdot
.68411 .24124 Mdot
.72774 .45511 Mdot
.4374 .51118 Mdot
.38845 .75206 Mdot
.67759 .65169 Mdot
.59137 .86102 Mdot
.454 .14187 Mdot
.65157 .49801 Mdot
.5274 .599 Mdot
.63407 .67848 Mdot
.46415 .61266 Mdot
.57054 .28366 Mdot
.74842 .33813 Mdot
.31376 .42732 Mdot
.43086 .72041 Mdot
.24206 .42902 Mdot
.38201 .31289 Mdot
.59314 .62327 Mdot
.29183 .48039 Mdot
.50155 .13338 Mdot
.71426 .7315 Mdot
.38378 .3423 Mdot
.6531 .82989 Mdot
.21935 .5143 Mdot
.43001 .30762 Mdot
.78691 .48798 Mdot
.58238 .17028 Mdot
.64617 .71235 Mdot
.40179 .74219 Mdot
.46667 .21292 Mdot
.67112 .67815 Mdot
.75064 .59152 Mdot
.28997 .56039 Mdot
.26344 .55912 Mdot
.46027 .549 Mdot
.42583 .80451 Mdot
.33965 .23348 Mdot
.58261 .23362 Mdot
.64621 .21873 Mdot
.28938 .68527 Mdot
.18003 .6377 Mdot
.77976 .31269 Mdot
.69831 .61804 Mdot
.35197 .5501 Mdot
.7907 .50304 Mdot
.59659 .67655 Mdot
.59842 .3928 Mdot
.30363 .7071 Mdot
.69902 .38375 Mdot
.39519 .78996 Mdot
.23482 .60902 Mdot
.73705 .61332 Mdot
.6385 .38986 Mdot
.48683 .47893 Mdot
.74858 .35715 Mdot
.28862 .58455 Mdot
.66945 .70705 Mdot
.43696 .72957 Mdot
.58267 .65488 Mdot
.76261 .37301 Mdot
.79828 .46632 Mdot
.47914 .45122 Mdot
.12451 .47957 Mdot
.56837 .18154 Mdot
.21115 .54375 Mdot
.66899 .49364 Mdot
.73449 .25552 Mdot
.46101 .43002 Mdot
.50482 .19514 Mdot
.77464 .6595 Mdot
.33569 .68574 Mdot
.28199 .31835 Mdot
.65654 .46447 Mdot
.50146 .21233 Mdot
.69881 .31619 Mdot
.65542 .39255 Mdot
.32067 .70456 Mdot
.66053 .70087 Mdot
.3415 .56804 Mdot
.58273 .63638 Mdot
.59251 .56779 Mdot
.50478 .37124 Mdot
.52365 .14537 Mdot
.54809 .58054 Mdot
.68595 .43905 Mdot
.51823 .47215 Mdot
.25856 .70087 Mdot
.59778 .8329 Mdot
.57365 .5593 Mdot
.24427 .40891 Mdot
.73738 .64253 Mdot
.73101 .5555 Mdot
.50079 .22784 Mdot
.24408 .78431 Mdot
.844 .54296 Mdot
.48404 .28711 Mdot
.55093 .32954 Mdot
.65818 .72734 Mdot
.60653 .17401 Mdot
.45608 .80103 Mdot
.32836 .69405 Mdot
.27211 .74436 Mdot
.60749 .69323 Mdot
.56899 .50428 Mdot
.77933 .67878 Mdot
.78353 .32935 Mdot
.27788 .68181 Mdot
.71928 .25306 Mdot
.55507 .44975 Mdot
.67088 .47219 Mdot
.42104 .8799 Mdot
.7385 .30116 Mdot
.54772 .46483 Mdot
.24366 .69067 Mdot
.47545 .38546 Mdot
.58336 .46864 Mdot
.31175 .52332 Mdot
.71141 .69485 Mdot
.74734 .58306 Mdot
.6462 .1915 Mdot
.51412 .37536 Mdot
.28661 .64634 Mdot
.34091 .4082 Mdot
.50583 .53531 Mdot
.68224 .49442 Mdot
.36031 .43936 Mdot
.72059 .58603 Mdot
.47513 .43364 Mdot
.28865 .44929 Mdot
.65332 .75802 Mdot
.80465 .67548 Mdot
.73947 .37831 Mdot
.28836 .41414 Mdot
.54847 .41648 Mdot
.72984 .44921 Mdot
.66771 .6176 Mdot
.68375 .58962 Mdot
.80019 .63835 Mdot
.88295 .52101 Mdot
.34467 .64329 Mdot
.52603 .5017 Mdot
.44382 .28046 Mdot
.57573 .25863 Mdot
.70013 .29877 Mdot
.33108 .48195 Mdot
.34068 .58079 Mdot
.6024 .42705 Mdot
.58889 .56729 Mdot
.3483 .40479 Mdot
.39193 .16379 Mdot
.57705 .50828 Mdot
.53903 .22673 Mdot
.80941 .41358 Mdot
.35732 .72698 Mdot
.75114 .44789 Mdot
.57782 .44367 Mdot
.35933 .24255 Mdot
.45394 .42665 Mdot
.49092 .41697 Mdot
.34364 .70614 Mdot
.63581 .19889 Mdot
.74086 .40257 Mdot
.57117 .22029 Mdot
.60884 .51639 Mdot
.5235 .68904 Mdot
.3015 .334 Mdot
.47342 .20467 Mdot
.66208 .55686 Mdot
.81699 .40731 Mdot
.34118 .69076 Mdot
.41247 .68458 Mdot
.73138 .51499 Mdot
.53923 .16144 Mdot
.21755 .60081 Mdot
.67565 .27948 Mdot
.20623 .43987 Mdot
.24606 .47935 Mdot
.65586 .62754 Mdot
.47626 .61303 Mdot
.53298 .46687 Mdot
.47755 .38441 Mdot
.53428 .12556 Mdot
.46711 .20485 Mdot
.32891 .38369 Mdot
.30673 .61678 Mdot
.66453 .30325 Mdot
.49852 .50069 Mdot
.71145 .79726 Mdot
.50652 .79779 Mdot
.49555 .13242 Mdot
.76136 .55786 Mdot
.43226 .36723 Mdot
.3407 .36339 Mdot
.69016 .47439 Mdot
.41403 .63567 Mdot
.61617 .18188 Mdot
.56782 .56153 Mdot
.23905 .59787 Mdot
.57078 .50525 Mdot
.21808 .40215 Mdot
.41875 .41113 Mdot
.3779 .63889 Mdot
.36685 .62457 Mdot
.20407 .61597 Mdot
.79834 .42974 Mdot
.44721 .42728 Mdot
.69769 .79322 Mdot
.67294 .25193 Mdot
.75287 .30432 Mdot
.40876 .60204 Mdot
.16687 .53078 Mdot
.43422 .26375 Mdot
.41374 .38386 Mdot
.37458 .3847 Mdot
.54949 .6139 Mdot
.21973 .45722 Mdot
.73084 .56271 Mdot
.32204 .30964 Mdot
.31258 .40059 Mdot
.92298 .52191 Mdot
.71236 .60783 Mdot
.70572 .51822 Mdot
.21873 .53587 Mdot
.73099 .2745 Mdot
.57037 .77033 Mdot
.78765 .68236 Mdot
.50911 .59739 Mdot
.67923 .49048 Mdot
.72052 .38783 Mdot
.74707 .4884 Mdot
.23325 .44716 Mdot
.16072 .40478 Mdot
.72344 .71647 Mdot
.37261 .6579 Mdot
.48772 .53457 Mdot
.4935 .3643 Mdot
.50802 .29877 Mdot
.43024 .7826 Mdot
.75034 .73218 Mdot
.43777 .40734 Mdot
.72468 .28879 Mdot
.1441 .48972 Mdot
.76692 .58279 Mdot
.61517 .17537 Mdot
.42876 .25883 Mdot
.53483 .33661 Mdot
.67704 .61052 Mdot
.50282 .70246 Mdot
.37023 .61596 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo09?ooooo0_l0000W
ooooo`;o0000Roooool001cooooo00?o0000ooooooooool0Toooool2o`0002Oooooo0_l0002;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0:Oooooo
0_l0002Pooooo`007?ooool00ol0003oooooooooo`2Wooooo`;o0000X?ooool001cooooo00?o0000
ooooooooool0Z_ooool2o`0009gooooo000Looooo`03o`000?oooooooooo0:[ooooo1?l0002Koooo
o`007?ooool00ol0003oooooooooo`2Eooooo`;o00005Oooool2o`0009_ooooo000Looooo`03o`00
0?oooooooooo09Gooooo0_l000000ooooooo0000o`000003ooooo`Co00001Oooool2o`000:7ooooo
000Looooo`03o`000?oooooooooo09Sooooo0ol00002ooooo`Co00001?ooool3o`000:7ooooo000L
ooooo`03o`000?oooooooooo08[ooooo0_l00006ooooo`;o00001Oooool2o`0000;ooooo0_l00006
ooooo`;o00003oooool2o`00097ooooo000Looooo`03o`000?oooooooooo08[ooooo0_l00003oooo
o`Go00002Oooool2o`0001;ooooo0_l00003ooooo`;o0000TOooool001cooooo00?o0000oooooooo
ool0Soooool3o`00013ooooo0_l00002ooooo`;o00002Oooool2o`0009Kooooo000Looooo`03o`00
0?oooooooooo0:;ooooo0_l00002ooooo`;o0000XOooool001cooooo0_l0002_ooooo`;o0000VOoo
ool001cooooo00?o0000ooooooooool0[_ooool2o`0009Wooooo000Looooo`03o`000?oooooooooo
09Kooooo0_l0000:ooooo`;o00002oooool2o`0009Sooooo000Looooo`03o`000?oooooooooo09Ko
oooo0_l0000:ooooo`;o00001oooool6o`0009Sooooo000Looooo`03o`000?oooooooooo07cooooo
0_l0000Gooooo`;o00001oooool2o`0000_ooooo1?l0000>ooooo`;o000000?oooooo`000?l00000
0oooool2o`0008;ooooo000Looooo`03o`000?oooooooooo07cooooo0_l0000Gooooo`;o00001ooo
ool2o`0000?ooooo0_l0000@ooooo`;o00001_ooool2o`000003ooooool0003o000000?ooooo0_l0
0022ooooo`007?ooool00ol0003oooooooooo`2Nooooo`?o00000_ooool2o`0000_ooooo0_l00003
ooooo`;o00000_ooool2o`0008kooooo000Looooo`03o`000?oooooooooo09Wooooo0_l00004oooo
o`;o00003?ooool2o`000003ooooool0003o000000Oooooo0_l00006ooooo`Go0000Poooool001co
oooo00?o0000ooooooooool0TOooool2o`0000Kooooo0_l0000Aooooo`?o00001Oooool2o`0000_o
oooo1Ol00023ooooo`007?ooool00ol0003oooooooooo`1eooooo`;o00006_ooool2o`0001Sooooo
0ol00006ooooo`?o0000:Oooool2o`0006Oooooo000Looooo`03o`000?oooooooooo07Gooooo0_l0
000Rooooo`;o00001?ooool2o`000003ooooool0003o000000Oooooo0_l00008ooooo`;o00003Ooo
ool2o`0000Cooooo0_l0000Dooooo`;o0000Ioooool001cooooo00?o0000ooooooooool0J_ooool2
o`0001Gooooo0_l000000ooooooo0000o`000008ooooo`;o00002Oooool2o`0000Cooooo0_l00000
0ooooooo0000o`000007ooooo`;o00004Oooool2o`0000Cooooo0_l00004ooooo`;o00005Oooool2
o`0006Kooooo000Looooo`03o`000?oooooooooo06[ooooo0_l0000=ooooo`;o00001_ooool2o`00
0003ooooool0003o000000;ooooo0_l00004ooooo`;o00005_ooool2o`0000?ooooo0_l00007oooo
o`;o00002?ooool2o`00013ooooo0_l0000?ooooo`Co0000I?ooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo07Kooooo0_l00000
0ooooooo0000o`00000=ooooo`;o00005oooool2o`000003ooooool0003o000000?o000000?ooooo
o`000?l000002?ooool2o`0001?ooooo0_l00003ooooo`Co00004Oooool2o`0006Cooooo00001_oo
ooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1_ooool00ol0003oooooooooo`1fooooo`;o00004?ooool2o`0001Kooooo0ol000000ooooooo0000
o`000003o`000003ooooool0003o000001gooooo0_l00003ooooo`?o0000N?ooool00003ooooool@
413ooooo00;ooooo00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oo
oooooooo077ooooo0_l0000=ooooo`;o00003?ooool2o`00013ooooo0_l00003ooooo`;o00000_oo
ool2o`0001[ooooo0_l00004ooooo`;o0000O?ooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool02oooool00onHV9So8B4Qonk^kP06ooooo`?o0000LOooool4o`0000_ooooo0_l00005
ooooo`;o00001Oooool2o`0000Gooooo0_l0000Booooo`;o00003Oooool2o`0000Oooooo0ol00000
0ooooooo0000o`000002ooooo`Co00000oooool2o`0007Oooooo00000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`1^oooo
o`;o000000?oooooo`000?l000000_l00004ooooo`;o00000oooool2o`0000;ooooo0_l000000ooo
oooo0000o`000002o`0000Oooooo0_l00002ooooo`Co00003oooool2o`0000[ooooo0_l00003oooo
o`;o00001oooool3o`0000Gooooo0_l00005ooooo`;o0000Moooool00003ooooool@413ooooo00;o
oooo00?o410@ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06_o
oooo0_l000000ooooooo0000o`000009ooooo`;o00000oooool2o`0000;ooooo0_l000000ooooooo
0000o`000009ooooo`;o00000_ooool6o`0000Kooooo0_l00005ooooo`;o00002_ooool2o`0000;o
oooo0_l0000Jooooo`;o0000M?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0
003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0Joooool2o`0000[ooooo1?l00008
ooooo`;o00003oooool2o`0000;ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00005Ooo
ool2o`0000?ooooo0_l00003ooooo`;o00003Oooool2o`000003ooooool0003o000007Cooooo0000
1_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03
o`000?oooooooooo06;ooooo0_l0000Cooooo`Co00001oooool3o`0000oooooo0_l00006ooooo`;o
000000Coooooo`000?l0003ooooo0_l0000Hooooo`;o00000oooool2o`0000Kooooo0_l00005oooo
o`;o00002_ooool2o`0006_ooooo000Looooo`03o`000?oooooooooo06;ooooo0_l0000Eooooo`;o
00001oooool2o`00013ooooo0_l00008ooooo`;o00000_ooool2o`0002Gooooo0_l0000Aooooo`?o
0000J_ooool001cooooo00?o0000ooooooooool0E_ooool2o`0000Kooooo0_l00008ooooo`;o0000
6oooool2o`0001Oooooo0ol0000Aooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`?o0000
3?ooool2o`0000Sooooo0_l00003ooooo`;o0000J_ooool001cooooo00?o0000ooooooooool0E_oo
ool2o`0000Kooooo0_l00008ooooo`;o00005_ooool2o`0000?ooooo0_l0000<ooooo`Co00001?oo
ool2o`0000;ooooo0_l0000Aooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`?o00003?oo
ool2o`0000Sooooo0_l00004ooooo`;o0000JOooool001cooooo00?o0000ooooooooool0Moooool2
o`0000Oooooo0_l00003ooooo`;o000000?oooooo`000?l000001Oooool2o`0000;ooooo1?l00004
ooooo`Co00003?ooool2o`0000gooooo0_l00004ooooo`;o00006?ooool2o`0000;ooooo0_l0001Y
ooooo`007?ooool00ol0003oooooooooo`1gooooo`?o00002_ooool3o`000003ooooool0003o0000
00Gooooo0_l00003ooooo`;o00001oooool4o`0000[ooooo0_l00005ooooo`;o00001_ooool2o`00
00Cooooo0_l0000>ooooo`;o00002?ooool2o`0000;ooooo0_l0001Yooooo`007?ooool00ol0003o
ooooooooo`1[ooooo`;o00000_ooool2o`0000Gooooo1?l0000:ooooo`?o00002?ooool2o`0000ko
oooo0_l0000Aooooo`;o00001Oooool2o`0000Kooooo0_l00006ooooo`;o00001Oooool2o`0000So
oooo1_l0001Yooooo`007?ooool00ol0003oooooooooo`1Tooooo`;o00001Oooool2o`0000;ooooo
0_l00005ooooo`?o00000_ooool2o`0001;ooooo0_l0000?ooooo`;o00004oooool2o`0000;ooooo
0_l00006ooooo`;o00001_ooool2o`000003ooooool0003o000000cooooo1Ol0001Zooooo`007?oo
ool00ol0003oooooooooo`1Rooooo`Co00001Oooool2o`0000Kooooo0_l00006ooooo`;o00000_oo
ool2o`000003ooooool0003o000000Kooooo0_l0000=ooooo`;o00001Oooool2o`0001;ooooo0ol0
0004ooooo`;o00003oooool2o`0000Sooooo0_l00005ooooo`;o0000J_ooool001cooooo00?o0000
ooooooooool0H_ooool2o`0000?ooooo0_l00008ooooo`Co00001oooool2o`000004ooooool0003o
0000ooooo`?o00001Oooool2o`0000gooooo0_l00008ooooo`;o00003oooool2o`0000Gooooo0_l0
000<ooooo`;o00001_ooool2o`0000?ooooo1_l00005ooooo`;o000000?oooooo`000?l00000Hooo
ool001cooooo00?o0000ooooooooool0Ioooool2o`0000?ooooo0_l00003ooooo`;o00002Oooool2
o`0000Gooooo1?l0000Looooo`;o00004Oooool4o`0000;ooooo0_l0000;ooooo`;o00001Oooool4
o`0000Cooooo1?l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l0001Sooooo`007?ooool0
0ol0003oooooooooo`1Vooooo`;o00000_ooool4o`0001Kooooo0ol00006ooooo`;o00000_ooool2
o`0000oooooo0_l0000?ooooo`Oo000000Coooooo`000?l0003o00000_ooool2o`000003ooooool0
003o000000_ooooo1?l0000:ooooo`;o00001?ooool3o`0006;ooooo000Looooo`;o0000Ioooool2
o`0000;ooooo0_l00004ooooo`;o00006oooool3o`000003ooooool0003o000000?o00003?ooool2
o`0000oooooo1?l000001?oooooo0000o`000?ooool3o`0000;ooooo0_l000000ooooooo0000o`00
0002o`000003ooooool0003o000000gooooo0_l0000<ooooo`;o0000H_ooool001cooooo00?o0000
ooooooooool0J?ooool2o`0000Kooooo0_l0000>ooooo`;o00003?ooool2o`0000?ooooo0ol0000<
ooooo`;o00003Oooool2o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l000000oooool2
o`000004ooooool0003o0000o`0000cooooo0_l0000=ooooo`Co00003Oooool2o`00053ooooo000L
ooooo`03o`000?oooooooooo06Sooooo0_l0000Fooooo`;o00004Oooool3o`0000cooooo0_l0000=
ooooo`;o00001?ooool2o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`;o00000_ooool2
o`0000?ooooo0_l0000Eooooo`Go000000?oooooo`000?l000002_ooool2o`00053ooooo000Loooo
o`03o`000?oooooooooo07?ooooo0_l00004ooooo`;o00002?ooool2o`0000?ooooo0_l00009oooo
o`Co000000?oooooo`000?l000001Oooool2o`0000_ooooo0_l00007ooooo`Co00000oooool3o`00
00oooooo0_l0000;ooooo`;o00001Oooool2o`000003ooooool0003o000000Cooooo0_l0001Loooo
o`007?ooool00ol0003oooooooooo`1Wooooo`;o00002_ooool2o`0000Cooooo0_l00002ooooo`;o
00001?ooool2o`0000?ooooo1?l00009ooooo`;o000000?oooooo`000?l000001?ooool3o`0000Oo
oooo0_l00002ooooo`;o00001_ooool5o`0000?ooooo0_l000000ooooooo0000o`00000=ooooo`?o
00001?ooool2o`0000Cooooo0_l00005ooooo`Co0000Hoooool001cooooo00?o0000ooooooooool0
Ioooool2o`0001Cooooo0_l0000:ooooo`?o00004_ooool3o`000003ooooool0003o000000?ooooo
0ol0000:ooooo`;o00001?ooool2o`0000?ooooo0_l0000=ooooo`?o00001?ooool2o`0000gooooo
0_l0000?ooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0Foooool2o`0000[ooooo0_l0
0003ooooo`Co00000_ooool2o`0001_ooooo0_l00003ooooo`;o00003?ooool2o`0000?ooooo0_l0
000Aooooo`;o00003oooool2o`000004ooooool0003o0000o`0001?ooooo1?l00006ooooo`;o0000
1Oooool2o`0005;ooooo000Looooo`03o`000?oooooooooo04gooooo0_l0000<ooooo`;o00002?oo
ool2o`0000Gooooo1?l00002ooooo`;o00003_ooool2o`0000_ooooo0ol00002ooooo`;o00001?oo
ool2o`0000_ooooo0_l0000@ooooo`;o00002oooool2o`0000?ooooo1?l000000ooooooo0000o`00
000Dooooo`;o00001_ooool2o`0005Wooooo000Looooo`03o`000?oooooooooo04gooooo0_l0000A
ooooo`;o00000oooool4o`0000;ooooo1?l000000ooooooo0000o`00000@ooooo`;o00003?ooool2
o`000003ooooool0003o000000?o00000_ooool2o`0000;ooooo0_l00004ooooo`Co00001oooool2
o`0000Sooooo0_l00004ooooo`;o00001Oooool2o`0000Gooooo0_l000000ooooooo0000o`00000D
ooooo`;o00000_ooool2o`00017ooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`1Poooo
o`;o00001Oooool2o`0000;ooooo0_l00003ooooo`;o00007?ooool2o`0000?ooooo1ol00004oooo
o`?o00000oooool4o`0000?ooooo1_l00008ooooo`;o00001?ooool2o`0000?ooooo0_l00004oooo
o`;o00003?ooool2o`0000?ooooo0_l00007ooooo`;o00000_ooool2o`00017ooooo0_l0001:oooo
o`007?ooool00ol0003oooooooooo`1Hooooo`;o00001Oooool3o`0000_ooooo0_l0000Looooo`Oo
00000_ooool6o`0000Gooooo0_l0000:ooooo`Co00005Oooool2o`0000Cooooo0_l00003ooooo`;o
00001oooool2o`000003ooooool0003o000000;o0000J_ooool001cooooo00?o0000ooooooooool0
F?ooool2o`0000Gooooo0_l0000;ooooo`?o00006oooool4o`0000;ooooo0_l00003ooooo`Go0000
00?oooooo`000?l000002?ooool2o`0000oooooo0_l00003ooooo`;o00004_ooool4o`0000;ooooo
0_l00004ooooo`Co00004?ooool2o`0005Sooooo000Looooo`03o`000?oooooooooo05kooooo0_l0
00000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l000001oooool2o`0001?ooooo0ol0
0002ooooo`;o00001?ooool8o`0000;ooooo0ol000000ooooooo0000o`000002o`0000;ooooo0_l0
000;ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`00000>ooooo`;o000000?o
ooooo`000?l000000_ooool4o`0000Sooooo0_l00004ooooo`?o00001Oooool2o`0005Sooooo000L
ooooo`03o`000?oooooooooo04_ooooo0_l0000@ooooo`Ko00001_ooool2o`0000[ooooo0ol00000
0ooooooo0000o`000009ooooo`;o00001Oooool2o`000004ooooool0003o0000o`0000Cooooo1_l0
0002ooooo`Go000000?oooooo`000?l000001?ooool4o`0000cooooo0_l00003ooooo`;o00003_oo
ool2o`0000Oooooo0_l00008ooooo`;o00001?ooool3o`0000;ooooo0_l0000Cooooo`;o0000A_oo
ool001cooooo00?o0000ooooooooool0Boooool2o`0000_ooooo0_l00003ooooo`Co00004oooool4
o`000003ooooool0003o000000Wooooo0_l00002ooooo`;o00001?ooool3o`0000?ooooo2?l00000
0ooooooo0000o`00000<ooooo`;o00008Oooool2o`000003ooooool0003o000000[ooooo0_l0000=
ooooo`;o00004oooool3o`0004Gooooo000Looooo`03o`000?oooooooooo05Gooooo0_l000000ooo
oooo0000o`000003ooooo`;o00000oooool2o`00013ooooo0_l00009ooooo`;o00001oooool2o`00
00;ooooo1ol000000ooooooo0000o`000003o`000003ooooool0003o000000?o00000oooool2o`00
0003ooooool0003o0000027ooooo0_l00004ooooo`;o000000?oooooo`000?l000002_ooool2o`00
00Kooooo0_l00008ooooo`;o00001?ooool2o`0000[ooooo0ol00002ooooo`;o0000@Oooool001co
oooo0_l0001Eooooo`?o000000?oooooo`000?l000000oooool2o`000003ooooool0003o000000;o
00006oooool2o`0000_ooooo6ol0000Gooooo`;o00002?ooool3o`0000Cooooo0_l0000?ooooo`;o
00000oooool2o`0000Gooooo0_l000000ooooooo0000o`000004ooooo`;o00003oooool2o`00047o
oooo000Looooo`03o`000?oooooooooo04gooooo0_l00005ooooo`;o000000?oooooo`000?l00000
1oooool2o`0002_ooooo6?l00006ooooo`;o00004Oooool2o`0000Sooooo0ol00004ooooo`;o0000
0oooool2o`0000[ooooo0_l00007ooooo`;o000000?oooooo`000?l000000_ooool3o`0005Kooooo
000Looooo`03o`000?oooooooooo04gooooo0_l00008ooooo`;o00003oooool2o`0000Sooooo0_l0
000Dooooo`;o00001?ooool2o`000003ooooool0003o000001Oo000000Coooooo`000?l0003ooooo
0_l0000Dooooo`;o00001?ooool2o`0000Sooooo0_l00003ooooo`;o00001?ooool2o`0000Sooooo
0_l00005ooooo`?o0000E_ooool001cooooo00?o0000ooooooooool0IOooool2o`000003ooooool0
003o000000Sooooo0_l0000Dooooo`?o000000?oooooo`000?l000005_l000000ooooooo0000o`00
0003o`0000Cooooo0_l0000Dooooo`;o00001?ooool4o`0000_ooooo0_l00004ooooo`;o00005ooo
ool2o`0004oooooo000Looooo`03o`000?oooooooooo05Gooooo0_l0000;ooooo`;o000000?ooooo
o`000?l000004Oooool3o`0000kooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o
0000017o00009oooool2o`0000?ooooo0_l00006ooooo`;o00002Oooool2o`0001;ooooo1Ol0001<
ooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o00001oooool4o`0000_ooooo0_l0000>oooo
o`;o000000Coooooo`000?l0003ooooo0ol0000?ooooo`?o000000?oooooo`000?l000005ol00005
ooooo`;o00001_ooool2o`0001_ooooo0_l0000<ooooo`;o00000oooool2o`0000;ooooo0_l00009
ooooo`;o00001?ooool4o`0000Wooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`18oooo
o`Ko00001?ooool3o`0000?ooooo0_l00009ooooo`;o00003Oooool5o`0001?ooooo0ol000000ooo
oooo0000o`00000Go`000003ooooool0003o000000Co00001_ooool2o`0002Wooooo0_l00007oooo
o`;o00002Oooool2o`00017ooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`18ooooo`;o
00000_ooool2o`0000;ooooo2_l00003ooooo`;o00001?ooool2o`0000kooooo0_l00005ooooo`Co
00002ooooolSo`0002cooooo0_l00006ooooo`;o00000_ooool2o`000003ooooool0003o0000013o
oooo0_l00002ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0AOooool2o`0000Gooooo
0_l00002ooooo`;o00000oooool6o`0000;ooooo0_l0000@ooooo`;o00001_ooool2o`000003oooo
ool0003o000000Co00001?ooool2o`0000?ooooo0_l00002oooooaco000000?oooooo`000?l00000
;?ooool4o`0000Cooooo0_l00002ooooo`Go00003?ooool3o`000003ooooool0003o000000;ooooo
0_l0001:ooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00001Oooool2o`0000;ooooo0_l0
0003ooooo`;o00000_ooool2o`000003ooooool0003o0000017ooooo0_l00006ooooo`;o00000_oo
ool2o`000003ooooool0003o000000Cooooo0_l00002ooooob7o000000?oooooo`000?l000000ooo
ool2o`0002Wooooo0_l00009ooooo`;o00003_ooool3o`0000?ooooo0_l0001<ooooo`007?ooool0
0ol0003oooooooooo`19ooooo`;o00002_ooool2o`0000;ooooo0_l000000ooooooo0000o`000003
ooooo`Co00002_ooool2o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o00001oooool2
o`0000;ooooo4_l000000ooooooo0000o`00000<o`0000Gooooo0ol0000[ooooo`;o00000_ooool3
o`0000;ooooo0_l0000Dooooo`;o00000oooool2o`0004Oooooo000Looooo`03o`000?oooooooooo
04Wooooo0_l00005ooooo`;o00003?ooool7o`0000Cooooo0_l00004ooooo`;o000000?oooooo`00
0?l000000oooool2o`0000Wooooo1?l00003ooooo`;o000000?oooooo`000?l000006ol00005oooo
o`?o00001oooool2o`0002;ooooo0_l00002ooooo`?o00000_ooool2o`0001Wooooo0_l0000;oooo
o`;o0000>_ooool001cooooo00?o0000ooooooooool0D?ooool2o`0000cooooo2Ol00002ooooo`;o
00004_ooool4o`000003ooooool0003o000000Gooooo0_l000000ooooooo0000o`00000No`0000Go
oooo0_l00005ooooo`?o00008oooool2o`0000oooooo1?l0000Jooooo`;o0000>_ooool001cooooo
00?o0000ooooooooool0D?ooool2o`0000oooooo0_l00002ooooo`;o00001Oooool2o`000004oooo
ool0003o0000ooooo`;o00002Oooool4o`0000Cooooo0_l000000ooooooo0000o`00000No`000004
ooooool0003o0000o`0000Gooooo0_l00006ooooo`;o00008oooool2o`0000cooooo0_l000000ooo
oooo0000o`000002o`0000Gooooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o
00003?ooool2o`0000Gooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo1Ol00005oooo
o`;o00002_ooool2o`000004ooooool0003o0000oooooago00003Oooool2o`0003Gooooo0_l00000
1?oooooo0000o`000?ooool2o`0000Cooooo1?l0001=ooooo`007?ooool00ol0003oooooooooo`0m
ooooo`;o00002?ooool2o`0000Kooooo0_l0000=ooooo`;o00001Oooool2o`0000;ooooo0_l00005
ooooo`?o00000oooool2o`000003ooooool0003o000000[ooooo0_l00004oooooago00003Oooool2
o`0003?ooooo0_l00003ooooo`Go00001_ooool2o`0004gooooo000Looooo`;o0000?_ooool2o`00
00Oooooo0ol00003ooooo`;o000000?oooooo`000?l000001?ooool2o`0001[ooooo0_l00003oooo
o`;o00000oooool2o`0000Cooooo0_l00008ooooo`oo000000?oooooo`000?l000002ol0000foooo
o`;o00002_ooool2o`0000?ooooo1?l00004ooooo`;o00000_ooool2o`0004cooooo000Looooo`03
o`000?oooooooooo043ooooo0_l00004ooooo`;o00001?ooool2o`0000Oooooo0_l0000Dooooo`;o
00000oooool2o`0000Wooooo0_l00004ooooo`;o00002_oooolHo`000003ooooool0003o000001;o
oooo1?l0000Pooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000oooool2o`0000Co
oooo1ol000000ooooooo0000o`000018ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o0000
4Oooool4o`0000?ooooo0_l00004ooooo`;o00001_ooool2o`000003ooooool0003o000000?ooooo
0ol0000Jooooo`;o000000?oooooo`000?l000004ol00003ooooo`Go000000?oooooo`000?l00000
2_ooool4o`0002Gooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000000;o0000
1_ooool2o`000003ooooool0003o000000?o0000B?ooool001cooooo00?o0000ooooooooool0AOoo
ool2o`0000cooooo0_l00004ooooo`?o00001?ooool2o`0000Kooooo0_l00006ooooo`?o00001ooo
ool2o`00017ooooo0_l00002ooooo`So000000?oooooo`000?l000004Ol000000ooooooo0000o`00
000Yooooo`;o00000oooool2o`0000?ooooo0_l0000:ooooo`Co00002_ooool2o`0004[ooooo000L
ooooo`03o`000?oooooooooo04Gooooo1?l0000@ooooo`?o00000_ooool2o`0000kooooo1?l00008
ooooo`;o00002?ooool2o`0000Oooooo0_l000000ooooooo0000o`00000Fo`00037ooooo0_l00003
ooooo`;o00000oooool2o`0000cooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`17oooo
o`;o00001Oooool3o`0000Sooooo0_l00003ooooo`;o00002oooool2o`000003ooooool0003o0000
00Oooooo0_l00004ooooo`;o00001Oooool2o`0000[ooooo4?l000001?oooooo0000o`000?l00008
ooooo`;o00000oooool2o`0003Sooooo0_l0000?ooooo`;o00001Oooool2o`0004Cooooo000Loooo
o`03o`000?oooooooooo03[ooooo1?l0000@ooooo`?o00002_ooool2o`0000Wooooo0_l00003oooo
o`;o00001oooool2o`000003ooooool0003o000000Cooooo0_l0000:ooooo`;o00001oooool>o`00
0003ooooool0003o000000;o00001oooool2o`0000?ooooo0_l0000hooooo`;o00003oooool3o`00
00Cooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0jooooo`Co00003Oooool2o`0000ko
oooo1?l00005ooooo`Co00003?ooool2o`0000;ooooo0_l0000?ooooo`;o00001oooool2o`000003
ooooool0003o000000?o000000Coooooo`000?l0003ooooo2Ol0000Iooooo`;o000000?oooooo`00
0?l000009?ooool2o`0001;ooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o
00004?ooool2o`0000Gooooo0_l0000<ooooo`;o00000_ooool5o`000003ooooool0003o000000Ko
oooo1_l00008ooooo`Co000000?oooooo`000?l000004Ol00008ooooo`;o00003?ooool2o`000003
ooooool0003o000000;o00000_ooool2o`00013ooooo0_l00004ooooo`;o000000?oooooo`000?l0
00000oooool2o`0000Wooooo0_l0000<ooooo`;o00000oooool2o`00043ooooo000Looooo`03o`00
0?oooooooooo03Wooooo0_l0000<ooooo`;o00000_ooool2o`000003ooooool0003o000002;ooooo
0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000003ooooo`Ko
00002_ooool2o`000003ooooool0003o0000017o00002?ooool2o`0000Cooooo0_l0000;ooooo`;o
00000_ooool2o`00013ooooo0_l00004ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Go
oooo0ol00006ooooo`;o00000oooool3o`0000?ooooo0_l00010ooooo`007?ooool00ol0003ooooo
ooooo`0iooooo`;o00002_ooool4o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o0000
5?ooool2o`0000Gooooo1?l0000;ooooo`;o00004Oooool2o`0000?ooooo1?l000000ooooooo0000
o`000004o`0000;ooooo0_l000001?oooooo0000o`000?l00005ooooo`;o00000oooool2o`0000;o
oooo0_l0000<ooooo`;o00001?ooool2o`0001Gooooo0_l00007ooooo`;o00001Oooool2o`0000Oo
oooo0ol00002ooooo`;o00005?ooool2o`00033ooooo000Looooo`03o`000?oooooooooo04Gooooo
1?l00002ooooo`?o00001Oooool2o`000003ooooool0003o000000;o00003Oooool5o`0000;ooooo
1?l000000ooooooo0000o`000003o`0000Cooooo0_l00005ooooo`;o00003Oooool2o`0000?ooooo
0_l000001?oooooo0000o`000?ooool5o`0000?ooooo1Ol00002ooooo`;o000000Goooooo`000?l0
003o0000ooooo`03o`0000Gooooo0_l00003ooooo`;o00001?ooool2o`0000Cooooo1?l00003oooo
o`;o00002_ooool2o`000004ooooool0003o0000o`0001Sooooo0_l0000Hooooo`;o0000<?ooool0
01cooooo00?o0000ooooooooool0Aoooool2o`000003ooooool0003o000000Co00001_ooool4o`00
00Wooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo1Ol00004oooo
o`Co00000oooool2o`0000;ooooo0_l00006ooooo`;o00001_ooool2o`000004ooooool0003o0000
ooooo`Ko00000_ooool4o`0000?ooooo2Ol00006ooooo`Co000000?oooooo`000?l000001oooool2
o`000003ooooool0003o000000;o00000oooool4o`0000Sooooo0_l000000ooooooo0000o`000002
ooooo`;o00003?ooool2o`0000Kooooo0ol00006ooooo`;o0000@_ooool001cooooo00?o0000oooo
ooooool0B_ooool2o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l000002Oooool4o`00
0004ooooool0003o0000ooooo`;o00002Oooool2o`0000Kooooo0_l00002ooooo`;o00000oooool2
o`0000Kooooo0_l00006ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00001?oo
ool9o`000004ooooool0003o0000o`0000Wooooo0_l00006ooooo`;o00000_ooool5o`0000Oooooo
0_l0000<ooooo`;o000000?oooooo`000?l000003?ooool2o`0000Kooooo0ol00006ooooo`;o0000
@_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413o
ooooooooo`04ooooo`03o`000?oooooooooo04Gooooo0_l00002ooooo`?o00001?ooool2o`0000?o
oooo0_l0000>ooooo`Go000000?oooooo`000?l000003?ooool2o`0000Oooooo0_l00003ooooo`;o
00000oooool2o`0000[ooooo0_l00007ooooo`;o00001_ooool4o`00013ooooo1?l00004ooooo`;o
00001?ooool3o`0000?ooooo0_l0000@ooooo`;o00002?ooool2o`0005[ooooo00001_ooooooMgMg
oiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0A?ooool4o`000003ooooool0003o000000Gooooo0_l0000Aooooo`;o00000_ooool2o`00
00Kooooo0_l00008ooooo`;o00004Oooool2o`0000Kooooo0ol000000ooooooo0000o`000004oooo
o`;o00000oooool2o`0000Kooooo0_l0000@ooooo`Co000000?oooooo`000?l000000_l00005oooo
o`Go000000?oooooo`000?l000000_l00005ooooo`;o00004Oooool2o`00013ooooo0ol00017oooo
o`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`Go00001_ooool00ol0003o
ooooooooo`11ooooo`;o000000?oooooo`000?l000000_l00008ooooo`;o00003Oooool2o`0000;o
oooo0_l0000:ooooo`;o00008oooool3o`0000Oooooo0_l00003ooooo`;o00005oooool4o`0000;o
oooo1?l000000ooooooo0000o`000003ooooo`Ko000000Coooooo`000?l0003o00001?ooool2o`00
013ooooo0_l0000=ooooo`;o00000_ooool3o`0004Oooooo00000ooooooo0000ooooo`02ooooo`03
o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`00047ooooo1?l000000ooo
oooo0000o`000005ooooo`Go000000?oooooo`000?l000002_ooool2o`000003ooooool0003o0000
00?ooooo1?l0000Eooooo`;o00002_ooool2o`0000oooooo0_l00009ooooo`;o00001?ooool4o`00
00[ooooo1?l00002ooooo`;o00000_ooool3o`0000Oooooo0_l00002ooooo`;o00005_ooool4o`00
00Oooooo0_l00002ooooo`;o00000_ooool2o`0004Sooooo00000ooooooo0000ooooo`02ooooo`03
o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`0aoooo
o`;o00003_ooool4o`000005ooooool0003o0000o`000?ooool01_l00003ooooo`;o000000?ooooo
o`000?l000002_ooool2o`000003ooooool0003o000000Wo00004?ooool2o`0000[ooooo0_l00003
ooooo`;o00002_ooool2o`0000Oooooo1?l00004ooooo`Co00003Oooool2o`0000Gooooo0_l0000T
ooooo`Co00001oooool2o`00013ooooo0_l0000nooooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0<Oooool2o`00
00kooooo0_l00004ooooo`Oo00000_ooool2o`0000Cooooo0_l00006ooooo`;o00000_ooool2o`00
0003ooooool0003o000000_o00002oooool2o`0000Oooooo0_l00002ooooo`;o00001Oooool2o`00
01?ooooo0_l00004ooooo`Co00002oooool2o`0000;ooooo0_l0000:ooooo`;o00005Oooool2o`00
00Cooooo0_l0000Hooooo`;o00000_ooool2o`000003ooooool0003o000003kooooo00001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0b
ooooo`;o00002_ooool2o`0000Sooooo0_l00002ooooo`;o00000_ooool2o`0000cooooo0_l00002
oooooa3o00000_ooool2o`0000Oooooo0_l00003ooooo`Ko00000_ooool2o`0001Kooooo0_l00008
ooooo`Co00001?ooool2o`0000?ooooo1?l0000;ooooo`;o000000?oooooo`000?l000001oooool2
o`0000cooooo1?l00002ooooo`;o00001?ooool2o`0000Oooooo1?l00007ooooo`;o00000_ooool2
o`0001Gooooo0_l0000Zooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0
003ooooo00Kooooo00?o0000ooooooooool0<_ooool2o`0000[ooooo0_l00007ooooo`?o000000?o
ooooo`000?l000000_ooool2o`0000Oooooo1?l000000ooooooo0000o`000003oooooaCo00003?oo
ool4o`0001Kooooo0_l00004ooooo`;o00000_ooool2o`000003ooooool0003o000000Wooooo0_l0
0003ooooo`Co000000?oooooo`000?l000000oooool2o`0000?ooooo1?l00006ooooo`Co00003_oo
ool2o`0000Sooooo0_l00007ooooo`Co00002?ooool2o`0001Sooooo0_l0000Zooooo`007?ooool0
0ol0003oooooooooo`0mooooo`;o00000oooool2o`0000?ooooo0ol000000ooooooo0000o`000002
ooooo`;o000000?oooooo`000?l000000_l00002ooooo`So00000_oooolCo`000004ooooool0003o
0000o`0001Sooooo0_l00009ooooo`;o00002?ooool2o`000003ooooool0003o000000;o000000?o
ooooo`000?l000001_ooool2o`0000;ooooo0_l000000ooooooo0000o`000003o`000003ooooool0
003o000000Gooooo0_l00006ooooo`;o00009Oooool2o`0000Sooooo0_l00014ooooo`007?ooool0
0ol0003oooooooooo`0mooooo`;o00000oooool2o`0000;ooooo1_l00006ooooo`Co00001?ooool6
o`000003ooooool0003o000001Ko00000_ooool2o`0001;ooooo1?l00009ooooo`;o00003Oooool2
o`000003ooooool0003o000000?ooooo1_l00004ooooo`;o000000?oooooo`000?l000000_l00002
ooooo`?o00000_ooool2o`0000Gooooo0_l00005ooooo`;o00005oooool2o`0005Gooooo000Loooo
o`03o`000?oooooooooo04;ooooo0_l00002ooooo`?o000000?oooooo`000?l000001oooool2o`00
00Gooooo1?l000000ooooooo0000o`00000Ho`0000;ooooo0_l00002ooooo`;o00003_ooool4o`00
01Oooooo0_l00004ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000Gooooo0_l00002
ooooo`Oo00000_ooool2o`0000Gooooo1?l00003ooooo`;o00001?ooool2o`00017ooooo0_l0000=
ooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0@_ooool2o`000004ooooool0003o0000
o`0000_ooooo0_l00006ooooo`;o000000?oooooo`000?l000001ol00002oooooa3o00001_ooool2
o`0000gooooo1Ol0000Gooooo`;o00001?ooool8o`0000;ooooo0_l00002ooooo`_o00001Oooool2
o`0000Cooooo0ol000001?oooooo0000o`000?l00004ooooo`;o00000_ooool2o`0001cooooo0ol0
00000ooooooo0000o`000012ooooo`007?ooool00ol0003oooooooooo`15ooooo`?o00000oooool2
o`0000?ooooo0_l00003ooooo`;o00001ooooolKo`0000_ooooo1?l00006ooooo`Ko000000Cooooo
o`000?l0003o00004_ooool2o`0000Gooooo1ol000001?oooooo0000o`000?l00004ooooo`Co0000
00Coooooo`000?l0003ooooo0_l00004ooooo`;o00000oooool4o`000003ooooool0003o000000?o
00001_ooool2o`0000cooooo0_l00008ooooo`;o00000oooool4o`000004ooooool0003o0000oooo
o`?o0000?_ooool001cooooo00?o0000ooooooooool0A_ooool2o`0000?ooooo0_l00003ooooo`?o
00000_ooool2o`0000Oooooo0_l000000ooooooo0000o`00000Fo`0000_ooooo1?l0000:ooooo`;o
000000?oooooo`000?l000001?l0000:ooooo`;o00001Oooool2o`0000;ooooo0_l000000ooooooo
0000o`000002o`0000;ooooo0_l000000ooooooo0000o`000008o`000003ooooool0003o000000?o
000000?oooooo`000?l000001_l00006ooooo`Co00004_ooool2o`0000Cooooo0_l00002ooooo`;o
000000?oooooo`000?l000001?l000001?oooooo0000o`000?ooool3o`0003kooooo000Looooo`03
o`000?oooooooooo04;ooooo1?l0000;ooooo`;o00001_ooool2o`0000?ooooo7_l00008ooooo`;o
00003Oooool8o`0000Kooooo1_l00005ooooo`;o00000_ooool2o`0000?ooooo0_l00005ooooo`Ko
000000?oooooo`000?l000001?l000001?oooooo0000o`000?ooool8o`0000;ooooo0_l00002oooo
o`Go00001Oooool4o`0000kooooo0_l00005ooooo`;o00000_ooool2o`000003ooooool0003o0000
00;ooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0oooooo`;o000000?oooooo`000?l0
00000_l0000CoooooaKo00000_ooool5o`000003ooooool0003o000000?o00001Oooool2o`0000Co
oooo0_l00006ooooo`;o00000_ooool2o`0000cooooo1?l00005ooooo`;o000000?oooooo`000?l0
00000oooool3o`0000Cooooo2?l000000ooooooo0000o`000006o`0000?ooooo0_l00004ooooo`;o
00000_ooool3o`000003ooooool0003o000000?o00001Oooool4o`0001cooooo0_l00002ooooo`;o
0000?_ooool001cooooo00?o0000ooooooooool0?oooool2o`0000Wooooo0_l00004ooooo`;o0000
2OoooolPo`0000Kooooo0_l00004ooooo`;o00000_ooool2o`0000;ooooo0_l0000Aooooo`;o0000
1Oooool3o`000003ooooool0003o000000?ooooo0ol00004oooooa;o00000_ooool2o`000003oooo
ool0003o000000Cooooo1?l000000ooooooo0000o`000003ooooo`;o00004Oooool2o`000003oooo
ool0003o000000;o0000Coooool001cooooo00?o0000ooooooooool0@Oooool2o`000003ooooool0
003o000000Cooooo0_l00004ooooo`;o00002OoooolPo`00013ooooo0_l0000Cooooo`Co00001Ooo
ool2o`0000Sooooo0_l00002oooooa_o00001?ooool2o`0000?ooooo0_l00003ooooo`;o00004Ooo
ool2o`000003ooooool0003o000000;o00000_ooool2o`000003ooooool0003o000004Sooooo000L
ooooo`03o`000?oooooooooo047ooooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool2
o`0000_ooooo0_l000000ooooooo0000o`00000Lo`0000;ooooo0_l0000?ooooo`;o00001oooool2
o`0000Oooooo0_l0000@ooooo`_o000000?oooooo`000?l000004?l000000ooooooo0000o`00000@
ooooo`;o00001?ooool2o`0000Gooooo1?l00008ooooo`;o000000?oooooo`000?l000000_ooool2
o`0004Cooooo000Looooo`;o0000A?ooool2o`0000;ooooo0ol00003ooooo`;o00001Oooool2o`00
00;ooooo1?l000000ooooooo0000o`00000Ko`0000?ooooo0_l0000?ooooo`;o00001_ooool4o`00
01?ooooo8ol000000ooooooo0000o`000002o`0000?ooooo0_l00009ooooo`;o000000Coooooo`00
0?l0003ooooo0_l00005ooooo`Co00003oooool2o`0001kooooo0_l0000Tooooo`007?ooool00ol0
003oooooooooo`0kooooo`;o00001_ooool2o`0000;ooooo0_l0000;ooooo`;o00000_ooool4o`00
0003ooooool0003o000001co00006oooool4o`00013ooooo0_l000000ooooooo0000o`000005o`00
0003ooooool0003o000000co000000?oooooo`000?l000001ol000000ooooooo0000o`000005o`00
00?ooooo0ol00008ooooo`So00004Oooool2o`0002Gooooo0_l0000Tooooo`007?ooool00ol0003o
ooooooooo`0gooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o00003oooool5o`0000?o
oooo6Ol00002ooooo`?o00001?ooool2o`000003ooooool0003o000000cooooo0ol00003ooooo`?o
00004OoooolEo`0000;ooooo0_l000000ooooooo0000o`00000>o`0000?ooooo1Ol00006ooooo`Go
000000Coooooo`000?l0003o00004Oooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool2
o`0000;ooooo0_l0000looooo`007?ooool00ol0003oooooooooo`0gooooo`;o00001_ooool2o`00
00?ooooo0_l00009ooooo`;o00001?ooool5o`0000Cooooo0ol000000ooooooo0000o`00000Bo`00
00Wooooo0_l000000ooooooo0000o`000004ooooo`Co00001?ooool3o`0000?ooooo0ol0000:oooo
o`;o00001oooool3o`000003ooooool0003o000002;o00000oooool5o`0000Kooooo0_l00007oooo
o`?o00004oooool5o`000003ooooool0003o000000;ooooo0_l0000looooo`007?ooool00ol0003o
ooooooooo`0oooooo`;o00003_ooool2o`0000kooooo0_l00002oooooa;o00004oooool6o`0000;o
oooo0_l00003ooooo`?o00002oooool2o`0000Oooooo2Ol00002oooooaco00003_ooool4o`0000Ko
oooo0ol000000ooooooo0000o`000009ooooo`;o00001Oooool5o`0000;ooooo0_l0000oooooo`00
7?ooool00ol0003oooooooooo`0[ooooo`Co00002oooool2o`0000;ooooo0_l000000ooooooo0000
o`00000LoooooaKo00005oooool3o`0000Kooooo0ol0000Aooooo`_o00000ooooolOo`000004oooo
ool0003o0000o`0000Cooooo2?l00009ooooo`;o00002Oooool2o`0000?ooooo1?l000000ooooooo
0000o`000002ooooo`?o00007?ooool2o`00023ooooo000Looooo`03o`000?oooooooooo02_ooooo
1?l0000;ooooo`;o00000_ooool2o`000003ooooool0003o000001;ooooo0_l00008oooooa?o0000
3oooool2o`0000[ooooo0_l00007ooooo`Oo00002oooool5o`000003ooooool0003o000000Ko0000
00?oooooo`000?l000007Ol000000ooooooo0000o`000004o`000003ooooool0003o000000?o0000
00?oooooo`000?l000006Oooool2o`0000Sooooo0_l0000Looooo`;o00008?ooool001cooooo00?o
0000ooooooooool0@Oooool2o`0000oooooo0_l000000ooooooo0000o`000008ooooo`Co000000?o
ooooo`000?l000002ol0000@ooooo`;o00001?ooool2o`0000_ooooo2_l00007ooooo`;o000000?o
ooooo`000?l000000ol000001?oooooo0000o`000?ooool/o`0000Cooooo0_l00002ooooo`Ko0000
1Oooool2o`0001Wooooo0_l0000looooo`007?ooool00ol0003oooooooooo`0eooooo`;o00002_oo
ool2o`0000oooooo0_l000000ooooooo0000o`00000>ooooo`?o000000?oooooo`000?l000001?l0
0003ooooo`;o00004oooool2o`0000Kooooo0_l00003ooooo`Go00000oooool2o`0000Cooooo0_l0
00000ooooooo0000o`000004ooooo`;o00001?ooool@o`0000;ooooo6ol00007ooooo`So00000ooo
ool2o`0000Sooooo0_l0000?ooooo`;o0000??ooool001cooooo00?o0000ooooooooool09Oooool2
o`0000kooooo0_l00006ooooo`;o00000_ooool2o`0000Wooooo0_l00004ooooo`;o000000Cooooo
o`000?l0003o00003Oooool2o`000003ooooool0003o000000?ooooo0_l00003ooooo`;o00004_oo
ool2o`0000Oooooo0_l00006ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Kooooo0ol0
0003ooooobWo000000?oooooo`000?l000000_l0000;ooooo`Co00003Oooool2o`0000gooooo1?l0
000looooo`007?ooool00ol0003oooooooooo`0Uooooo`;o00004Oooool2o`0000?ooooo0_l00002
ooooo`Co00001oooool2o`0000Kooooo1?l00003ooooo`;o00002oooool2o`0000;ooooo0_l0000H
ooooo`Co00003?ooool8o`0000;ooooo0_l00008ooooo`;o000000Coooooo`000?l0003ooooo9Ol0
0002ooooo`?o00002Oooool2o`0002Cooooo1?l0000looooo`007?ooool00ol0003oooooooooo`0[
ooooo`;o00002oooool3o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000oooooo0_l0
0005ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l00002ooooo`;o00005ooo
ool2o`000003ooooool0003o000000Gooooo0_l00005ooooo`go00002_ooool2o`0000;ooooo:Ol0
0009ooooo`;o00004_ooool2o`0000gooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0[
ooooo`;o00003?ooool2o`000003ooooool0003o000000?o00000_ooool2o`0000oooooo0_l00004
ooooo`;o00000_ooool2o`0000;ooooo0_l0000Pooooo`?o00000oooool2o`0000?ooooo0_l00005
ooooo`Co00000_ooool4o`000003ooooool0003o000000Sooooo0_l00004ooooobgo00004Oooool2
o`0000Kooooo0_l00003ooooo`;o00002?ooool2o`000003ooooool0003o000000;o0000??ooool0
01cooooo00?o0000ooooooooool08oooool2o`0000Kooooo0_l0000Aooooo`Co000000?oooooo`00
0?l000001Oooool2o`0000Oooooo0ol00004ooooo`;o00001?ooool2o`0000Cooooo0_l0000Hoooo
o`;o00000_ooool2o`0000Cooooo0_l0000;ooooo`?o00001?ooool2o`0000Cooooo0_l00004oooo
o`Oo000000?oooooo`000?l000004ol000000ooooooo0000o`00000Eo`000004ooooool0003o0000
ooooo`;o00001_ooool2o`0000;ooooo0_l0000;ooooo`;o00002oooool4o`0003cooooo000Loooo
o`03o`000?oooooooooo02?ooooo0_l00006ooooo`;o00003_ooool4o`000003ooooool0003o0000
00Sooooo0_l00007ooooo`;o00002?ooool2o`000003ooooool0003o000000Cooooo0_l0000Hoooo
o`;o00001Oooool2o`0000kooooo0_l00005ooooo`;o00001?ooool3o`0000?ooooo0_l000000ooo
oooo0000o`000002o`0000Cooooo4?l00003oooooaCo000000Coooooo`000?l0003ooooo0_l00000
0ooooooo0000o`000003ooooo`;o000000Coooooo`000?l0003o00002oooool2o`0000?ooooo0_l0
0019ooooo`007?ooool00ol0003oooooooooo`0jooooo`Go00003?ooool2o`0000Kooooo0_l00005
ooooo`Go000000?oooooo`000?l000007Oooool5o`0000?ooooo0_l0000>ooooo`;o00001?ooool2
o`0000;ooooo0_l00002ooooo`;o00002?ooool2o`0000Cooooo9ol00002ooooo`Co00000_ooool2
o`0000;ooooo0_l00002ooooo`;o00002oooool2o`0000?ooooo0ol000000ooooooo0000o`000015
ooooo`007?ooool2o`0003_ooooo0ol0000>ooooo`;o00003Oooool3o`0000?ooooo0_l0000Joooo
o`;o000000?oooooo`000?l000000ol00003ooooo`;o00005?ooool3o`000003ooooool0003o0000
00Cooooo0_l00006ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00000/
o`0000Cooooo0_l0000;ooooo`;o00001_ooool2o`000003ooooool0003o000000Gooooo0_l0000n
ooooo`007?ooool00ol0003oooooooooo`0iooooo`?o00003Oooool2o`000003ooooool0003o0000
02Cooooo0_l00008ooooo`;o00002?ooool2o`0000Oooooo0_l00008ooooo`;o00000_ooool3o`00
00Oooooo0_l00009ooooo`Go000000?oooooo`000?l000008?l000000ooooooo0000o`000004o`00
0003ooooool0003o000000;ooooo0_l00002ooooo`;o00002oooool2o`0000Cooooo0_l0000:oooo
o`;o0000?_ooool001cooooo00?o0000ooooooooool0>Oooool5o`0000_ooooo0_l000000ooooooo
0000o`00000Eooooo`;o00003Oooool2o`0000gooooo0_l00003ooooo`Co00001Oooool2o`0000Co
oooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000[ooooo0_l00003oooooa3o
000000?oooooo`000?l000005_l00004ooooo`;o00000_ooool2o`0000;ooooo1?l0000=ooooo`;o
000000Coooooo`000?l0003ooooo0_l00009ooooo`;o000000?oooooo`000?l00000??ooool001co
oooo00?o0000ooooooooool08Oooool2o`0000Gooooo0_l0000=ooooo`Co000000Coooooo`000?l0
003ooooo0_l0000Cooooo`;o00003Oooool2o`0001cooooo0ol00004ooooo`;o00002oooool2o`00
00Kooooo0_l000000ooooooo0000o`000009ooooo`?o00000_oooolXo`0000?ooooo1?l00009oooo
o`;o00003Oooool2o`000003ooooool0003o000000cooooo0_l000000ooooooo0000o`00000loooo
o`007?ooool00ol0003oooooooooo`0Qooooo`;o00001Oooool2o`0000gooooo1?l00004ooooo`;o
00000oooool2o`0000kooooo0_l0000Hooooo`;o00002_ooool2o`0000Kooooo0_l00004ooooo`Co
00000_ooool2o`0000gooooo0_l00006ooooo`;o00001?ooool3o`0000;ooooo:_l000000ooooooo
0000o`000002o`0000?ooooo0ol0000=ooooo`;o00005oooool2o`0003cooooo000Looooo`03o`00
0?oooooooooo03_ooooo0_l00007ooooo`;o0000:?ooool2o`0000[ooooo0_l0000<ooooo`Co0000
0_ooool2o`0001;ooooo0_l000000ooooooo0000o`000006ooooo`;o00000oooool2o`000003oooo
ool0003o000000?o000000?oooooo`000?l000007Ol000001?oooooo0000o`000?l00004ooooo`?o
00001Oooool2o`0000Kooooo0_l0000:ooooo`;o00000oooool4o`0004;ooooo000Looooo`03o`00
0?oooooooooo03_ooooo0_l000000ooooooo0000o`000004ooooo`;o00001oooool2o`0001?ooooo
0_l0000=ooooo`;o000000?oooooo`000?l000001_l0000;ooooo`;o00001_ooool2o`0000Cooooo
0_l0000;ooooo`Co00001oooool2o`0000?ooooo0ol00002oooooaco00000_ooool5o`000003oooo
ool0003o000000Cooooo0_l00007ooooo`;o00000oooool2o`000003ooooool0003o000000[ooooo
0_l00003ooooo`Co00000oooool2o`0003gooooo000Looooo`03o`000?oooooooooo03Wooooo0_l0
0003ooooo`?o00001_ooool2o`0000Cooooo0_l0000Cooooo`;o00003Oooool9o`0000Gooooo0_l0
0004ooooo`Co00001_ooool2o`0000Cooooo0_l0000;ooooo`Co00001_ooool5o`000003ooooool0
003o000000?o00000_oooolHo`000004ooooool0003o0000ooooo`;o000000Coooooo`000?l0003o
00000_ooool2o`0000;ooooo0_l0000<ooooo`;o00004Oooool3o`000003ooooool0003o000000;o
oooo0_l0000?ooooo`;o00002oooool2o`0001oooooo000Looooo`03o`000?oooooooooo03Wooooo
0_l00004ooooo`;o00001_ooool2o`0000Cooooo0_l00004ooooo`;o00001Oooool2o`0000Kooooo
0_l0000>ooooo`?o00002_ooool2o`0000Cooooo0_l00007ooooo`;o00002?ooool2o`0000Gooooo
1ol000000ooooooo0000o`000003ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo
0000o`000002oooooaOo00000_ooool6o`000003ooooool0003o000000;ooooo0_l0000;ooooo`;o
00001?ooool2o`0000Gooooo0_l00006ooooo`;o000000?oooooo`000?l000000_ooool5o`0000Ko
oooo0_l00008ooooo`;o00002oooool2o`0001oooooo000Looooo`03o`000?oooooooooo047ooooo
0ol0000?ooooo`;o00001?ooool3o`0001Oooooo0_l00007ooooo`;o00004?ooool2o`0000Sooooo
1?l00003ooooo`?o00000_ooool2o`000003ooooool0003o000000Cooooo0_l00003ooooo`;o0000
1OoooolLo`000004ooooool0003o0000ooooo`Co00002oooool4o`0000Cooooo0_l00005ooooo`;o
000000?oooooo`000?l000000oooool2o`0000Oooooo0ol00006ooooo`;o0000=_ooool001cooooo
00?o0000ooooooooool0<oooool2o`0000;ooooo0_l00008ooooo`?o00003_ooool2o`0000Cooooo
0ol0000Fooooo`;o00002Oooool2o`0001cooooo0_l00005ooooo`;o00000oooool2o`0000Gooooo
0ol00002ooooo`;o000000?oooooo`000?l000006?l000000ooooooo0000o`000003o`0000?ooooo
0_l000000ooooooo0000o`000009ooooo`Co00001?ooool2o`0000[ooooo0_l0000<ooooo`Go0000
??ooool001cooooo00?o0000ooooooooool0<oooool2o`0000;ooooo0_l00009ooooo`;o00003_oo
ool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000Gooooo0_l0000<ooooo`;o0000
:?ooool2o`0000Cooooo0_l00003ooooo`Co00001?ooool2o`0000;ooooo7_l000000ooooooo0000
o`000002o`0000?ooooo0_l0000<ooooo`;o00001?ooool6o`00017ooooo0_l00002ooooo`Ko0000
??ooool001cooooo00?o0000ooooooooool0=_ooool2o`0000_ooooo0_l0000@ooooo`;o00001Ooo
ool5o`0000;ooooo0_l0000fooooo`;o00000oooool3o`0000Cooooo0ol00004ooooob?o000000Co
ooooo`000?l0003ooooo0_l000000ooooooo0000o`00000<ooooo`;o00001?ooool6o`0000Cooooo
0_l0000;ooooo`;o00000_ooool2o`0000?ooooo0_l0000kooooo`007?ooool00ol0003ooooooooo
o`0fooooo`;o00002oooool2o`0000;ooooo0_l0000Dooooo`Co00002Oooool2o`0000[ooooo0_l0
0003ooooo`;o00002?ooool2o`0001Wooooo1?l000001?oooooo0000o`000?ooool2o`0000?ooooo
1ol000001?oooooo0000o`000?ooool8o`000003ooooool0003o000000ko000000Coooooo`000?l0
003ooooo0_l0000?ooooo`;o00003_ooool2o`00017ooooo0_l000000ooooooo0000o`00000koooo
o`007?ooool00ol0003oooooooooo`0nooooo`;o000000?oooooo`000?l000001?ooool2o`0000go
oooo0_l0000Booooo`;o00002_ooool2o`0000?ooooo0_l00008ooooo`;o00003_ooool4o`0000?o
oooo0_l00002ooooo`Co000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000004o`00
00?ooooo2Ol000000ooooooo0000o`000005o`000003ooooool0003o000000Oo00001_ooool2o`00
00kooooo0_l00009ooooo`Co00005Oooool2o`000003ooooool0003o000000;o0000>Oooool001co
oooo00?o0000ooooooooool0:oooool2o`00017ooooo0_l000000ooooooo0000o`00000Cooooo`;o
00001?ooool2o`0001Cooooo0_l0000Qooooo`Co00000oooool2o`0000?ooooo0_l00002ooooo`;o
00001?ooool4o`0000Gooooo1?l000000ooooooo0000o`000002o`0000;ooooo1?l000000ooooooo
0000o`000004ooooo`go00001Oooool2o`0000Oooooo1?l00007ooooo`Co00004oooool2o`000003
ooooool0003o000000;ooooo0_l0000Fooooo`;o00008Oooool001cooooo0_l0000/ooooo`;o0000
2Oooool2o`0000Sooooo0_l00009ooooo`?o00003_ooool2o`00017ooooo0_l000000ooooooo0000
o`000008ooooo`;o00005?ooool2o`0000gooooo0_l00002ooooo`;o00003_ooool2o`000005oooo
ool0003o0000o`000?ooool01_l000000ooooooo0000o`000002o`0000?ooooo3Ol00005ooooo`;o
00002Oooool2o`000003ooooool0003o000000Gooooo0_l0000<ooooo`;o00001_ooool2o`000003
ooooool0003o000000;o00006?ooool2o`00027ooooo000Looooo`03o`000?oooooooooo03Kooooo
0_l00004ooooo`;o00000_ooool2o`0000Sooooo1?l00002ooooo`;o00007Oooool2o`000003oooo
ool0003o000000Sooooo0_l0000Dooooo`;o00009?ooool3o`000003ooooool0003o000000Co0000
00?oooooo`000?l000000_l00005ooooo`;o000000?oooooo`000?l000000_l000001?oooooo0000
o`000?l00005ooooo`;o00003?ooool2o`0000Gooooo0_l00005ooooo`Co00000oooool3o`0000[o
oooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0jooooo`Co00002_ooool5o`0000?ooooo
0_l000000ooooooo0000o`00000Booooo`;o00003?ooool2o`0002_ooooo0_l00007ooooo`;o0000
2Oooool2o`0000Gooooo1Ol0000=ooooo`Oo00001_ooool3o`0000Kooooo1?l000000ooooooo0000
o`00000<ooooo`Co00001?ooool3o`0000[ooooo0_l0000jooooo`007?ooool00ol0003ooooooooo
o`0[ooooo`;o00003Oooool2o`0000Sooooo0_l00002ooooo`;o000000?oooooo`000?l000001Ooo
ool3o`0000Gooooo0_l00003ooooo`;o000000?oooooo`000?l000000oooool2o`0000;ooooo0_l0
0008ooooo`;o00008_ooool2o`0000Oooooo0_l000000ooooooo0000o`000004ooooo`;o00001ooo
ool5o`0000?ooooo0_l000000ooooooo0000o`000005ooooo`;o00001?ooool2o`000003ooooool0
003o000000;ooooo1?l00006ooooo`;o00000_ooool2o`0000;ooooo1ol00003ooooo`;o00000ooo
ool2o`0000_ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`0003[ooooo000L
ooooo`03o`000?oooooooooo02_ooooo0_l00009ooooo`;o00003?ooool2o`0000Oooooo0_l00003
ooooo`;o00001_ooool7o`000003ooooool0003o000000Oooooo0_l0000<ooooo`;o00000_ooool2
o`0001[ooooo0_l0000:ooooo`;o00003?ooool6o`0000?ooooo0_l00005ooooo`Go000000Cooooo
o`000?l0003ooooo0_l00005ooooo`Co00002Oooool3o`0000Gooooo1?l00003ooooo`;o00000ooo
ool2o`0000Cooooo0_l0000:ooooo`Go00000oooool2o`0003Wooooo000Looooo`03o`000?oooooo
oooo03Kooooo0_l00005ooooo`;o00003_ooool2o`0000cooooo1?l00002ooooo`;o00003oooool2
o`0000Gooooo0ol000000ooooooo0000o`00000=ooooo`;o00003oooool2o`0000?ooooo0ol00008
ooooo`;o00001?ooool4o`0000_ooooo1?l00003ooooo`;o00002?ooool2o`0000_ooooo0_l00008
ooooo`;o00001oooool2o`0000Gooooo0_l0000<ooooo`;o00000_ooool4o`0003Wooooo000Loooo
o`03o`000?oooooooooo02cooooo0_l00009ooooo`;o00001?ooool2o`0000Kooooo1?l00004oooo
o`?o00003?ooool2o`0000?ooooo0_l00008ooooo`;o00000oooool4o`0000Kooooo0_l0000;oooo
o`;o00000oooool2o`0000[ooooo1?l000001?oooooo0000o`000?ooool5o`0000Oooooo0ol0000=
ooooo`?o00000oooool2o`0001Oooooo0_l00007ooooo`;o00001?ooool2o`0000Kooooo0ol00004
ooooo`;o00002_ooool2o`0000Gooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0/oooo
o`;o00002Oooool2o`0000cooooo1?l00005ooooo`;o00003?ooool2o`0000gooooo0_l00003oooo
o`?o00005?ooool2o`0000oooooo1?l00004ooooo`?o00002Oooool2o`0000kooooo0ol0000>oooo
o`;o00003?ooool2o`0000Oooooo0_l00004ooooo`;o000000?oooooo`000?l000000oooool2o`00
0003ooooool0003o000000;ooooo0_l0000:ooooo`Co0000@?ooool001cooooo00?o0000oooooooo
ool0;oooool2o`0000Cooooo0_l0000?ooooo`Co00006_ooool3o`0002[ooooo0_l00005ooooo`;o
00001oooool2o`0000cooooo0_l00003ooooo`;o00001?ooool2o`00017ooooo0_l0000Cooooo`;o
00002Oooool2o`0000Kooooo0_l0000@ooooo`Go0000?Oooool001cooooo00?o0000ooooooooool0
;oooool2o`0000Cooooo0_l00006ooooo`?o00002?ooool2o`0000oooooo0_l00009ooooo`So0000
0oooool2o`00023ooooo0_l00005ooooo`;o00003_ooool2o`0000Gooooo0_l00003ooooo`;o0000
0oooool3o`0000Gooooo0_l0000Oooooo`Co00001Oooool2o`000003ooooool0003o000000Gooooo
0_l00007ooooo`;o00002?ooool4o`0003gooooo000Looooo`03o`000?oooooooooo03gooooo0ol0
0003ooooo`;o00000_ooool3o`0000cooooo1Ol00009ooooo`Wo00000_ooool2o`0000?ooooo0_l0
000=ooooo`Co00006_ooool2o`000004ooooool0003o0000ooooo`?o00001?ooool2o`0000;ooooo
0_l00005ooooo`;o00001_ooool2o`00027ooooo0_l00005ooooo`;o000000?oooooo`000?l00000
1Oooool2o`0000Oooooo1?l0000?ooooo`;o0000=_ooool001cooooo00?o0000ooooooooool0@ooo
ool2o`0000;ooooo0_l0000=ooooo`?o000000?oooooo`000?l000001oooool7o`000003ooooool0
003o000000Co00000oooool2o`0000gooooo1?l0000Jooooo`;o000000Coooooo`000?l0003ooooo
0_l00005ooooo`;o00000_ooool2o`0000Gooooo0_l00004ooooo`;o00001Oooool2o`0000kooooo
0_l00005ooooo`;o00004?ooool2o`0000Cooooo0_l00009ooooo`;o00001Oooool2o`0000Sooooo
0_l0000fooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00002oooool4o`0000_ooooo0_l0
0004oooooa7o00001oooool2o`0000_ooooo1?l0000<ooooo`;o00002?ooool2o`0001Oooooo0ol0
0004ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Sooooo0_l00004ooooo`;o00001Ooo
ool2o`0000Gooooo1?l00006ooooo`?o00001?ooool2o`000003ooooool0003o000000;ooooo0_l0
0009ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0<Oooool2o`0000Gooooo0_l00004
ooooo`;o00000_ooool2o`0000Oooooo1?l0000;ooooo`;o00001?oooolCo`0000Gooooo0_l00006
ooooo`;o00000oooool4o`0000cooooo0_l00008ooooo`;o00001Oooool4o`0000kooooo0_l00008
ooooo`;o00003?ooool2o`0000Sooooo0_l00008ooooo`Co00001_ooool3o`0000Cooooo1Ol00002
ooooo`;o00001Oooool2o`0000;ooooo0_l00010ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^
k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0
<Oooool2o`0000Gooooo0_l00008ooooo`;o00000oooool3o`0000Oooooo0_l00002ooooo`;o0000
0oooool3o`0000Cooooo5?l0000;ooooo`;o00000oooool4o`0001_ooooo1_l0000Eooooo`;o0000
1Oooool2o`0001;ooooo1?l0000Booooo`;o00000oooool4o`0000;ooooo0_l00005ooooo`?o0000
00Coooooo`000?l0003o0000@?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q
8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo04Oooooo2?l00002
ooooo`;o00000_ooool2o`0000Cooooo0_l00004oooooaOo00003Oooool4o`0000?ooooo0_l0000@
ooooo`;o00000_ooool4o`00017ooooo0_l00006ooooo`;o00001Oooool3o`00013ooooo0_l00000
0ooooooo0000o`00000Booooo`;o00002Oooool2o`0000Gooooo0_l00002ooooo`;o00005Oooool2
o`0002[ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo03oooooo0_l00002ooooo`;o00000_ooool2
o`000003ooooool0003o000000?o00001Oooool2o`0000;ooooo0ol00006oooooaOo00005?ooool3
o`0000Kooooo0_l00007ooooo`;o000000Coooooo`000?l0003o00001?ooool3o`0000cooooo0_l0
000>ooooo`;o00004?ooool2o`0000kooooo0_l00005ooooo`;o00004?ooool2o`0001Wooooo0_l0
000Zooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9So
oooooiRHV?lQ8B401_ooool3o`0003oooooo0ol000000ooooooo0000o`000005ooooo`;o00001?oo
ool2o`0000;ooooo0_l00002ooooo`?o00002?oooolEo`0000;ooooo0_l00005ooooo`Go000000?o
ooooo`000?l000002_l00002ooooo`;o00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`00
0002o`0000?ooooo0ol0000Nooooo`;o00007_ooool2o`0001?ooooo0_l00002ooooo`;o0000AOoo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oEEEEo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0?oooool6o`0000_ooooo0_l0000;ooooo`Go00000_oo
oolCo`0000?ooooo0_l000001?oooooo0000o`000?oooolCo`0000;ooooo0ol000000ooooooo0000
o`000008ooooo`;o00000_ooool4o`000003ooooool0003o000001_ooooo0_l0000Iooooo`;o0000
0oooool2o`0001?ooooo0_l00019ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0=oooool2o`0000Kooooo0_l0
00000ooooooo0000o`000005ooooo`;o00001Oooool2o`0000Wooooo1ol00009ooooo`?o00000_oo
ool4o`000003ooooool0003o000000Cooooo7Ol000000ooooooo0000o`00000<ooooo`;o00000ooo
ool2o`0000kooooo0_l000000ooooooo0000o`000005ooooo`;o00007?ooool2o`0000Gooooo0_l0
000=ooooo`;o00001oooool2o`0004Cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo
00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0gooooo`Co00002Oooool2o`0000?ooooo
0_l00007ooooo`;o00001oooool2o`0000Cooooo1?l00006ooooo`;o00001Oooool2o`000004oooo
ool0003o0000oooooaoo00000oooool2o`0000_ooooo0_l00003ooooo`;o00000oooool2o`0000Wo
oooo0_l000000ooooooo0000o`000005ooooo`;o00002oooool2o`0000?ooooo0_l0000:ooooo`;o
00001Oooool3o`0000cooooo0_l00002ooooo`;o00000oooool2o`0004Cooooo00001_ooooook^k^
oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`0`
ooooo`;o00001oooool2o`0000?ooooo0_l00002ooooo`Co00003?ooool5o`0000[ooooo1?l00005
ooooo`;o00000_ooool[o`000003ooooool0003o000000_ooooo0ol000001Ooooooo0000o`000?l0
003ooooo00Co00005?ooool2o`0000[ooooo0_l000000ooooooo0000o`000002o`0000[ooooo0_l0
0002ooooo`;o000000Coooooo`000?l0003o00001oooool2o`000003ooooool0003o000000Cooooo
0_l00005ooooo`?o00002?ooool2o`0003Oooooo000Looooo`03o`000?oooooooooo033ooooo0_l0
000<ooooo`?o000000Coooooo`000?l0003o00003_ooool4o`0000Oooooo1?l00006ooooo`Co0000
00?oooooo`000?l00000:_l00007ooooo`;o00001_ooool2o`000003ooooool0003o000000Co0000
4?ooool2o`0000Cooooo0ol0000;ooooo`?o00001oooool2o`000003ooooool0003o000000;o0000
0_ooool2o`000003ooooool0003o000000?o00001Oooool2o`000003ooooool0003o000000Cooooo
0_l00003ooooo`Go00002?ooool2o`0003Oooooo000Looooo`03o`000?oooooooooo03oooooo0ol0
000;ooooo`;o00002?ooool2o`0000Gooooo1Ol00005ooooo`Oo000000?oooooo`000?l000005ol0
00000ooooooo0000o`00000=o`0000Oooooo0_l0000:ooooo`Co000000?oooooo`000?l000003_oo
ool2o`0000Gooooo0_l00004ooooo`;o00001?ooool3o`0000Sooooo0_l000000ooooooo0000o`00
000:ooooo`;o00002oooool2o`000003ooooool0003o000000?ooooo0_l00014ooooo`007?ooool0
0ol0003oooooooooo`0eooooo`;o00001Oooool2o`0000;ooooo0ol0000:ooooo`;o000000?ooooo
o`000?l000001Oooool3o`0000Kooooo0ol00007ooooo`So000000Coooooo`000?l0003ooooo9_l0
0004ooooo`;o00001?ooool2o`0000Cooooo1?l000000ooooooo0000o`00000:ooooo`;o00001Ooo
ool3o`0000Kooooo0ol00002ooooo`Co00005?ooool2o`0000Gooooo0_l00007ooooo`?o0000C?oo
ool001cooooo00?o0000ooooooooool0=Oooool2o`0000Gooooo0_l00003ooooo`;o00000_ooool2
o`0000Wooooo0_l00006ooooo`;o00002oooool2o`0000Gooooo0_l000000ooooooo0000o`000002
ooooobWo00002_ooool2o`0000Kooooo0_l0000=ooooo`;o00001Oooool3o`0000Kooooo0_l00002
ooooo`Co00005Oooool2o`0000Gooooo0_l00002ooooo`;o00000_ooool3o`0004gooooo000Loooo
o`03o`000?oooooooooo047ooooo0_l00002ooooo`;o00001_ooool2o`0000_ooooo0_l00002oooo
o`?o00001?ooool2o`0000?ooooo0_l00003ooooo`?o00000ooooolWo`0000Oooooo0_l00005oooo
o`?o000000?oooooo`000?l000001?l0000:ooooo`;o00001_ooool2o`0000Wooooo1?l0000Boooo
o`;o00003?ooool3o`000003ooooool0003o000004kooooo000Looooo`03o`000?oooooooooo047o
oooo0_l0000:ooooo`;o00002?ooool2o`000004ooooool0003o0000ooooo`Co00002Oooool2o`00
00Cooooo0_l00006ooooobKo000000?oooooo`000?l000000_ooool2o`0000?ooooo1Ol00003oooo
o`Co00002_ooool2o`0000Kooooo0_l0000Fooooo`;o00000_ooool3o`0000;ooooo0_l00004oooo
o`;o00001oooool2o`0000cooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`0Zooooo`;o
0000:oooool2o`0000Cooooo1Ol00005ooooo`;o00003ooooolFo`000003ooooool0003o000000go
000000Coooooo`000?l0003o00001_ooool2o`0000;ooooo0ol000000ooooooo0000o`000003o`00
00Gooooo0_l00002ooooo`;o00000_ooool3o`0000Oooooo0_l0000@ooooo`;o00000_ooool4o`00
00Oooooo0_l00007ooooo`;o00003?ooool2o`0004?ooooo000Looooo`03o`000?oooooooooo02[o
oooo0_l0000;ooooo`;o00002oooool2o`0001?ooooo1?l00003ooooo`;o000000?oooooo`000?l0
00000_ooool2o`000003ooooool0003o000000_ooooo9Ol00003ooooo`?o00002_ooool3o`0000;o
oooo1?l00005ooooo`;o00001_ooool3o`0000Oooooo0_l0000Fooooo`Co00000oooool6o`0000?o
oooo1?l00008ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0=oooool2o`0000_ooooo
0_l00002ooooo`;o00003oooool4o`0000Kooooo0_l00005ooooo`Co00002Oooool2o`000003oooo
ool0003o0000027o00000_ooool2o`0000[ooooo0ol000001?oooooo0000o`000?ooool2o`0001?o
oooo0_l0000Mooooo`;o00000oooool6o`0000?ooooo1?l00006ooooo`Co00004oooool2o`0003;o
oooo000Looooo`03o`000?oooooooooo043ooooo0_l00006ooooo`;o00002_ooool2o`0000?ooooo
1Ol000000ooooooo0000o`000005ooooo`;o00001?ooool2o`0000gooooo1_l00002ooooo`Wo0000
0_ooool<o`000003ooooool0003o000000kooooo0ol000001?oooooo0000o`000?ooool4o`00017o
oooo0_l0000Dooooo`;o00002_ooool2o`000003ooooool0003o000000Co00001?ooool3o`0000Go
oooo0_l0000Eooooo`;o0000<_ooool001cooooo00?o0000ooooooooool0?_ooool4o`0001;ooooo
0_l00003ooooo`Go000000?oooooo`000?l000001Oooool2o`0000[ooooo0_l00007oooooa7o0000
00?oooooo`000?l000002Ol00003ooooo`?o00005?ooool4o`0000?ooooo0_l0000>ooooo`;o0000
1Oooool2o`0000Cooooo0_l00005ooooo`;o00000_ooool2o`0000Kooooo0_l00005ooooo`;o0000
1Oooool2o`0000Gooooo0_l00019ooooo`007?ooool2o`0003oooooo0ol0000aooooo`;o00001_oo
ool3o`000003ooooool0003o000001Ko00001Oooool3o`0000kooooo0_l0000;ooooo`;o00003_oo
ool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`Co00001oooool2o`0000_ooooo1?l0
0003ooooo`;o00001_ooool2o`0004[ooooo000Looooo`03o`000?oooooooooo03kooooo0ol0000G
ooooo`;o00008?ooool2o`0000Cooooo5Ol00007ooooo`;o00003_ooool4o`0000Wooooo1?l00003
ooooo`;o00002_ooool4o`0000;ooooo0_l00002ooooo`Ko000000?oooooo`000?l000001?ooool2
o`000003ooooool0003o000000Kooooo1Ol00002ooooo`;o00001_ooool2o`0004[ooooo000Loooo
o`03o`000?oooooooooo03kooooo0_l00006ooooo`;o00004?ooool2o`0001Sooooo0_l000000ooo
oooo0000o`00000:ooooo`?o000000?oooooo`000?l000003ol0000Gooooo`?o00002Oooool4o`00
00?ooooo0_l00005ooooo`;o00001Oooool2o`000004ooooool0003o0000o`0000;ooooo0ol00000
1?oooooo0000o`000?ooool2o`0000Cooooo1Ol00005ooooo`;o00000_ooool6o`000003ooooool0
003o000004oooooo000Looooo`03o`000?oooooooooo04Gooooo0ol0000Zooooo`;o000000?ooooo
o`000?l000002oooool2o`000003ooooool0003o000000oo00000oooool4o`00013ooooo0_l00005
ooooo`;o000000?oooooo`000?l000003_ooool2o`0000Gooooo1_l00003ooooo`Co00000_ooool2
o`0000Gooooo0_l00007ooooo`?o00000oooool2o`0000;ooooo0ol000001?oooooo0000o`000?oo
ool2o`0000Cooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`15ooooo`Co0000<_ooool2
o`000003ooooool0003o000000;ooooo0_l00004ooooo`_o00001_ooool4o`0000kooooo0_l00004
ooooo`;o000000Coooooo`000?l0003ooooo0_l00005ooooo`;o000000?oooooo`000?l000000_oo
ool2o`000003ooooool0003o000000Cooooo0ol000000ooooooo0000o`000004ooooo`?o00000_oo
ool4o`0000;ooooo1?l00007ooooo`;o00001oooool3o`000004ooooool0003o0000ooooo`Co0000
0_ooool2o`0004?ooooo000Looooo`03o`000?oooooooooo04Oooooo1?l0000Booooo`;o00001Ooo
ool3o`0000oooooo0_l00003ooooo`;o000000?oooooo`000?l000002?ooool;o`00013ooooo0ol0
0005ooooo`;o00001?ooool2o`0000_ooooo0_l000000ooooooo0000o`000002ooooo`;o000000?o
ooooo`000?l000001?ooool2o`000003ooooool0003o000000Gooooo1?l000000ooooooo0000o`00
0003o`000003ooooool0003o000000;o00001oooool2o`0000[ooooo0_l00004ooooo`;o0000Aooo
ool001cooooo00?o0000ooooooooool0<oooool2o`0001Cooooo0_l0000Aooooo`?o00001Oooool3
o`0000oooooo0_l00003ooooo`?o00003?ooool2o`000003ooooool0003o000000Go00003oooool7
o`0000oooooo1?l0000Cooooo`?o00001oooool2o`000003ooooool0003o000000?o00006?ooool2
o`0004gooooo000Looooo`03o`000?oooooooooo03?ooooo0_l0000Wooooo`?o00002Oooool2o`00
00;ooooo0_l0000<ooooo`Co00001Oooool2o`0000Gooooo2_l0000=ooooo`Co000000?oooooo`00
0?l000000ol0000>ooooo`Co00004oooool2o`0000cooooo0_l0000Nooooo`;o0000BOooool001co
oooo00?o0000ooooooooool0J?ooool2o`0000;ooooo0_l0000<ooooo`;o00001oooool2o`0000?o
oooo1_l00002ooooo`?o00001_ooool2o`000003ooooool0003o000000?ooooo0ol00005ooooo`;o
00003Oooool3o`0000?ooooo0ol00005ooooo`;o00003oooool4o`0000;ooooo0_l00004ooooo`;o
00006Oooool3o`000003ooooool0003o000004Gooooo000Looooo`03o`000?oooooooooo04Sooooo
1?l0000Hooooo`;o00002?ooool2o`0001?ooooo0_l00003ooooo`Oo000000?oooooo`000?l00000
0oooool2o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`?o00005?ooool2o`000003oooo
ool0003o000000Co00000_ooool2o`000003ooooool0003o000000;ooooo0_l0000:ooooo`Go0000
0_ooool2o`000004ooooool0003o0000ooooo`;o00005?ooool2o`0000Cooooo1Ol00015ooooo`00
7?ooool00ol0003oooooooooo`18ooooo`Co00000oooool2o`0000?ooooo0_l000000ooooooo0000
o`00000;ooooo`;o00002?ooool2o`0000kooooo0_l0000:ooooo`;o000000Coooooo`000?l0003o
00001Oooool2o`0001kooooo0_l00004ooooo`Go00000oooool2o`0000Gooooo0_l0000:ooooo`Go
00001Oooool2o`0000?ooooo0_l00004ooooo`;o00003?ooool2o`000003ooooool0003o000000;o
oooo0_l00017ooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o000000?oooooo`000?l00000
2?l000000ooooooo0000o`000003ooooo`;o00002?ooool2o`0001?ooooo0_l00002ooooo`;o0000
1oooool6o`0001;ooooo0_l00004ooooo`?o000000?oooooo`000?l000001_ooool2o`0000Oooooo
0_l00003ooooo`;o00000_ooool2o`0000[ooooo2?l0000:ooooo`;o00001?ooool2o`0000oooooo
0_l0001;ooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00000_ooool4o`000004ooooool0
003o0000o`0000;ooooo0_l00003ooooo`;o00002?ooool2o`0001Oooooo0_l00007ooooo`;o0000
0_ooool2o`0001;ooooo0_l000000ooooooo0000o`000008o`0000Cooooo0_l0000Aooooo`;o0000
1?ooool2o`0000Cooooo1_l00006ooooo`;o00000_ooool4o`0000?ooooo0ol0001Looooo`007?oo
ool00ol0003oooooooooo`1;ooooo`;o00000oooool4o`0000;ooooo0_l0000;ooooo`;o00001_oo
ool2o`0000Wooooo0_l00003ooooo`;o00005Oooool2o`0000Wooooo0_l00004ooooo`Oo000000?o
ooooo`000?l000000ol00004ooooo`;o00002?ooool2o`0000gooooo1Ol0000=ooooo`Ko00001Ooo
ool3o`00013ooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o00000oooool4
o`0000gooooo1?l00002ooooo`;o00000_ooool2o`0000Wooooo0_l00003ooooo`;o00005Oooool2
o`0000?ooooo0_l00004ooooo`;o00001?ooool@o`0000_ooooo1_l00004ooooo`;o00001Oooool3
o`0000oooooo1?l0000Gooooo`?o0000B_ooool001cooooo00?o0000ooooooooool0EOooool2o`00
00[ooooo0ol00003ooooo`;o000000?oooooo`000?l000001oooool3o`00027ooooo0_l00007oooo
o`;o000000?oooooo`000?l000003_l0000<ooooo`Go00000oooool3o`0001Wooooo0ol00008oooo
o`;o00003?ooool2o`0004_ooooo000Looooo`;o0000Aoooool2o`0000Sooooo0_l00002ooooo`?o
00001Oooool2o`0000?ooooo1Ol000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00003oooo
o`?o00000oooool2o`0000Gooooo0_l0000;ooooo`;o00004Oooool4o`0000;ooooo3?l0000=oooo
o`;o000000?oooooo`000?l000000oooool2o`0000[ooooo0_l00008ooooo`;o00001?ooool3o`00
00Sooooo0_l0000Gooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0A_ooool2o`0000So
oooo0_l00002ooooo`;o00001_ooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`00
00Gooooo0_l00009ooooo`;o00001Oooool2o`0000_ooooo0_l000000ooooooo0000o`00000>oooo
oaCo00003_ooool2o`0000kooooo0ol00008ooooo`;o00004oooool2o`0000;ooooo0_l000000ooo
oooo0000o`00000<ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0AOooool2o`0000Wo
oooo0_l0000=ooooo`;o000000?oooooo`000?l000000_l00006ooooo`;o00006oooool2o`0000?o
oooo1?l00003ooooo`;o00002Oooool3o`000003ooooool0003o000000oo00003Oooool2o`0000Wo
oooo0_l00003ooooo`?o000000Coooooo`000?l0003ooooo0_l00002ooooo`?o00001_ooool2o`00
00;ooooo0_l00006ooooo`;o00000_ooool5o`0004kooooo000Looooo`03o`000?oooooooooo04Go
oooo0_l00009ooooo`;o00000_ooool3o`0000Sooooo0_l000001?oooooo0000o`000?ooool2o`00
00Gooooo1Ol00009ooooo`;o00003Oooool2o`0000?ooooo0_l00005ooooo`?o00001_ooool2o`00
00Cooooo2Ol000000ooooooo0000o`000005o`0000gooooo0_l00009ooooo`;o000000?oooooo`00
0?l000001?ooool5o`0000;ooooo0ol00004ooooo`Co00000_ooool2o`0000Cooooo1?l000000ooo
oooo0000o`000002o`00053ooooo000Looooo`03o`000?oooooooooo04Kooooo0_l0000<ooooo`?o
00003_ooool2o`0000?ooooo1ol00009ooooo`;o00006_ooool4o`0000Cooooo0_l00003ooooo`Wo
000000?oooooo`000?l000001_l0000;ooooo`Co00002Oooool5o`0000Kooooo0_l00007ooooo`Ko
00002Oooool2o`0000?ooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`14ooooo`Co0000
1Oooool2o`0000Kooooo0_l00002ooooo`;o00001Oooool2o`0000?ooooo0_l00003ooooo`;o0000
1Oooool2o`0002Gooooo0ol00005ooooo`;o000000?oooooo`000?l000004?l0000;ooooo`;o0000
3?ooool2o`000003ooooool0003o000000kooooo2?l0000<ooooo`;o0000D_ooool001cooooo00?o
0000ooooooooool0A?ooool2o`0000Kooooo0ol0000:ooooo`;o00001Oooool2o`0000?ooooo1?l0
0008ooooo`;o00005Oooool2o`0000;ooooo0_l0000;ooooo`;o00001Oooool2o`0000?ooooo2ol0
00000ooooooo0000o`000003o`0000Cooooo0_l0000=ooooo`;o00000oooool5o`0000Sooooo0_l0
0003ooooo`;o00001Oooool2o`0000cooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`1<
ooooo`?o00002?ooool2o`0000gooooo0ol0000Oooooo`;o00000_ooool2o`0001Gooooo4ol00004
ooooo`?o00003?ooool2o`0000?ooooo1?l00007ooooo`Ko000000?oooooo`000?l000004Oooool2
o`0005Cooooo000Looooo`03o`000?oooooooooo04gooooo0_l00008ooooo`;o00002_ooool2o`00
0003ooooool0003o000000Wooooo0_l0000]ooooo`;o000000?oooooo`000?l000004Ol000000ooo
oooo0000o`000002ooooo`Co00001?ooool2o`0000?ooooo0_l0000?ooooo`;o00000_ooool2o`00
00cooooo0_l00006ooooo`;o0000E?ooool001cooooo00?o0000ooooooooool0?Oooool2o`0002Co
oooo0_l0000;ooooo`?o00005oooool6o`0000?ooooo0_l0000;oooooaKo000000?oooooo`000?l0
00001?ooool2o`0000?ooooo0ol00003ooooo`;o00002?ooool2o`0000oooooo0_l00004ooooo`Co
00001_ooool2o`0005Cooooo000Looooo`03o`000?oooooooooo03gooooo0_l0000Wooooo`;o0000
2?ooool3o`0001Oooooo1_l00003ooooo`;o00000oooool3o`0000Oooooo5?l00007ooooo`;o0000
0oooool2o`0000Wooooo0_l00003ooooo`;o00003oooool3o`0000?ooooo0ol00004ooooo`;o0000
Eoooool001cooooo00?o0000ooooooooool0I_ooool2o`0002Kooooo0_l00002ooooo`;o00001?oo
ool3o`0000Wooooo4_l00007ooooo`;o00002Oooool2o`000003ooooool0003o000000;o000000?o
ooooo`000?l000004_ooool2o`0000Cooooo0_l00004ooooo`;o0000Eoooool001cooooo00?o0000
ooooooooool0F_ooool2o`0000gooooo0_l00002ooooo`;o00001?ooool2o`0001Oooooo0_l00002
ooooo`Co00001Oooool2o`0000Wooooo5?l0000=ooooo`;o000000Coooooo`000?l0003ooooo1?l0
00000ooooooo0000o`000007ooooo`Co0000K?ooool001cooooo00?o0000ooooooooool0F_ooool2
o`0000gooooo0_l00002ooooo`Go000000Coooooo`000?l0003o00002Oooool2o`0000Wooooo1?l0
0002ooooo`;o00001oooool2o`0000[ooooo4ol00002ooooo`;o00002Oooool2o`0000?ooooo0_l0
00001?oooooo0000o`000?l00009ooooo`Ko00001?ooool2o`0006Cooooo000Looooo`03o`000?oo
oooooooo05Gooooo0_l0000Gooooo`Co00000_ooool2o`0000Kooooo0_l000000ooooooo0000o`00
0008ooooo`?o00006Oooool@o`000003ooooool0003o000000;ooooo0_l00007ooooo`;o00001Ooo
ool2o`000004ooooool0003o0000o`0000gooooo0ol00003ooooo`;o0000I?ooool001cooooo00?o
0000ooooooooool0EOooool2o`0002Gooooo0_l0000;ooooo`;o00000oooool2o`0000Cooooo0_l0
000>oooooa;o00001oooool2o`0000Cooooo0_l00009ooooo`?o00003Oooool2o`0001Cooooo0_l0
001Cooooo`007?ooool2o`0005Kooooo0_l0000Booooo`;o00000_ooool2o`0000?ooooo0_l0000G
ooooo`;o000000?oooooo`000?l000000_ooool4o`0000kooooo4_l00007ooooo`;o00001Oooool2
o`0000Sooooo1?l0000Rooooo`;o000000?oooooo`000?l00000D?ooool001cooooo00?o0000oooo
ooooool0C_ooool2o`0000Gooooo0_l0000Booooo`;o00000_ooool2o`0000?ooooo0_l00006oooo
o`;o00003oooool2o`0000Gooooo0_l00006ooooo`;o00002Oooool2o`0000;ooooo3Ol0000;oooo
o`;o000000Coooooo`000?l0003ooooo0_l00006ooooo`?o00002?ooool2o`000004ooooool0003o
0000o`0000Wooooo0_l0000<ooooo`;o0000D?ooool001cooooo00?o0000ooooooooool0C_ooool2
o`0000Gooooo0_l00003ooooo`;o00007_ooool2o`0000oooooo1Ol0000:ooooo`;o00002Oooool2
o`000003ooooool0003o000000Wo00003_ooool2o`0000Cooooo0_l000001?oooooo0000o`000?oo
ool2o`0000_ooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00001Oooool2o`0005kooooo
000Looooo`03o`000?oooooooooo05[ooooo1?l0000=ooooo`;o00003Oooool2o`0000oooooo1Ol0
000<ooooo`;o00002_ooool<o`0000oooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo
0_l000000ooooooo0000o`000006ooooo`;o00000oooool2o`0000?ooooo0_l00005ooooo`;o0000
G_ooool001cooooo00?o0000ooooooooool0Foooool4o`0000cooooo0_l00002ooooo`;o00001_oo
ool2o`000004ooooool0003o0000ooooo`;o00003?ooool2o`0000oooooo0ol00009ooooo`?o0000
00?oooooo`000?l000001ol0000>ooooo`?o000000?oooooo`000?l000001?ooool2o`000003oooo
ool0003o000000Kooooo0_l0000?ooooo`;o0000G_ooool001cooooo00?o0000ooooooooool0Fooo
ool4o`0000kooooo1?l00006ooooo`;o00001?ooool2o`0000Kooooo1?l0000Dooooo`;o00002?oo
ool4o`0000?ooooo1ol00005ooooo`;o00002?ooool2o`0000Wooooo0_l00004ooooo`;o0000L_oo
ool001cooooo00?o0000ooooooooool0FOooool2o`0001;ooooo0_l0000Fooooo`Co00006Oooool2
o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`;o00001Oooool3o`0001?ooooo0_l00004
ooooo`;o00005_ooool2o`0005[ooooo000Looooo`03o`000?oooooooooo05Wooooo0_l0000`oooo
o`;o00004oooool4o`0000?ooooo0_l000001?oooooo0000o`000?ooool4o`0000Gooooo0_l00000
1?oooooo0000o`000?l0000:ooooo`;o00009Oooool2o`0005[ooooo000Looooo`03o`000?oooooo
oooo05?ooooo0_l00004ooooo`;o00001oooool2o`0002;ooooo0_l00003ooooo`;o00002oooool2
o`0000Kooooo0_l00005ooooo`;o00001?ooool6o`0000?ooooo0_l0000=ooooo`?o00005Oooool2
o`0000Cooooo0_l0001Tooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00003Oooool2o`00
02;ooooo0_l0000@ooooo`;o00005?ooool2o`000003ooooool0003o000000Cooooo0_l00004oooo
o`;o00001_ooool3o`0000gooooo0_l000000ooooooo0000o`000003ooooo`;o00001?ooool2o`00
06Cooooo000Looooo`03o`000?oooooooooo05Kooooo0_l00016ooooo`;o00003_ooool2o`000003
ooooool0003o000000Cooooo0_l00004ooooo`;o00001oooool2o`0000gooooo0_l000000ooooooo
0000o`00001_ooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00001oooool3o`00033ooooo
0_l0000Dooooo`;o00004Oooool2o`0002Gooooo0_l0001_ooooo`007?ooool00ol0003ooooooooo
o`1<ooooo`;o00001oooool2o`00037ooooo0_l00007ooooo`;o00004?ooool2o`0002Gooooo0_l0
0009ooooo`;o000000?oooooo`000?l00000Koooool001cooooo00?o0000ooooooooool0OOooool2
o`0000Wooooo0_l00007ooooo`;o00001_ooool2o`0000Sooooo0ol00008ooooo`;o00005Oooool2
o`0000?ooooo0_l00008ooooo`?o000000?oooooo`000?l00000Koooool00006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`00
0?oooooooooo05cooooo0_l0000Hooooo`;o00001Oooool2o`0001[ooooo0_l00009ooooo`;o0000
2?ooool2o`0000Kooooo0_l0000=ooooo`;o00000_ooool2o`0000Wooooo0_l00002ooooo`;o0000
1Oooool2o`0006Sooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1Looooo`;o00006?ooool2o`00
03kooooo0_l0000Aooooo`;o00002_ooool2o`0000Sooooo0_l00002ooooo`;o0000I?ooool00003
ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool0H_ooool2o`0002Wooooo0_l0000Aooooo`?o00004oooool2o`00
00Sooooo0_l00009ooooo`;o00002?ooool2o`0000cooooo0_l0001Tooooo`0000?oooooo`000?oo
ool00_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`00
06;ooooo0_l0000Yooooo`;o000000?oooooo`000?l000003_ooool3o`0000Wooooo0_l0000Boooo
o`;o00001oooool4o`0007cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wo
oooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo08Kooooo0ol00007oooo
o`;o00006_ooool2o`0001_ooooo0_l00007ooooo`;o0000MOooool00003ooooool@413ooooo00;o
oooo00?o410@ooooooooool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000oooo
ooooool0Q_ooool3o`0001oooooo0_l0000Pooooo`;o00001_ooool2o`0007Gooooo00001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oo
oooooooo08Cooooo0_l00005ooooo`;o00006oooool2o`0000Sooooo0_l0000Eooooo`?o0000OOoo
ool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Ko
oooo00?o0000ooooooooool0Q?ooool3o`0000Cooooo0_l0000Mooooo`;o00001_ooool2o`0001Go
oooo0_l0001nooooo`007?ooool00ol0003oooooooooo`1Xooooo`;o00001Oooool2o`0000Oooooo
0_l0000;ooooo`;o00008oooool3o`0009cooooo000Looooo`03o`000?oooooooooo06Sooooo0_l0
0005ooooo`;o00001?ooool2o`000003ooooool0003o0000037ooooo1?l0000Fooooo`;o0000P_oo
ool001cooooo00?o0000ooooooooool0KOooool2o`0000Kooooo0_l0000^ooooo`;o00001?ooool4
o`0001Kooooo0_l00022ooooo`007?ooool00ol0003oooooooooo`1]ooooo`;o0000=_ooool2o`00
00Cooooo1?l0002Jooooo`007?ooool00ol0003oooooooooo`2Tooooo`?o00001_ooool2o`00027o
oooo0_l0001gooooo`007?ooool00ol0003oooooooooo`2Tooooo`;o00006?ooool2o`00013ooooo
0_l0001gooooo`007?ooool00ol0003oooooooooo`2nooooo`;o0000ROooool001cooooo00?o0000
ooooooooool0QOooool2o`000<;ooooo000Looooo`03o`000?oooooooooo08Gooooo0_l0000Doooo
o`;o0000[?ooool001cooooo00?o0000ooooooooool0Qoooool2o`0001;ooooo0_l0002/ooooo`00
7?ooool00ol0003oooooooooo`27ooooo`;o0000<oooool2o`0000?ooooo0_l00026ooooo`007?oo
ool2o`0008_ooooo0_l0000`ooooo`;o00000oooool2o`0008Kooooo000Looooo`03o`000?oooooo
oooo08[ooooo0_l00005ooooo`;o0000]_ooool001cooooo00?o0000ooooooooool0TOooool2o`00
0003ooooool0003o00000;?ooooo000Looooo`03o`000?oooooooooo09Cooooo0_l00007ooooo`;o
00000_ooool2o`0001Wooooo0_l0002;ooooo`007?ooool00ol0003oooooooooo`2Dooooo`;o0000
1oooool2o`0000;ooooo0_l0000Iooooo`;o0000Roooool001cooooo00?o0000ooooooooool0U?oo
ool2o`000;?ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo08Gooooo0_l0000Vooooo`;o0000V_ooool001cooooo00?o0000ooooooooool0QOoo
ool2o`0002Kooooo0_l0002Jooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Booooo`Co000000?o410@
ooooooooool00oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`?o
0000oooooom:ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oo
oooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0
003oooooooooo`3ooooooe;ooooo000Booooo`03oeEEEOmVIVKo00000?ooooooE?ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00:Gooooo00Co410@o`000?l0003ooooo0_l00000
0ol@413oooooooooo`0Eooooo`04oa0@4?l0003oA4A4olc<c0Kooooo0_l000001?l@413ooooooooo
ooooool5o`00093ooooo002Vooooo`05o`000?ooooooooooooooool000002Oooool6o`0000_ooooo
00?oV9RHoa0@4?oMgMd01_ooool00ol0003oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@0T?ooool00:Kooooo00Go0000ooooooooooooooooo`00000Kooooo`03ohN7QomEEEGooooo00;o
oooo1Ol00004ooooo`03oiRHV?lQ8B7ok^k^097ooooo002Vooooo`05o`000?ooooooooooooooool0
00002Oooool6o`0000Wooooo00Goc<c<ob4Q8Ol0003oEEEEo`000003ooooo`04odA4A?oMgMgooooo
o`0000Kooooo00?oV9RHob4Q8Oo^k^h0T?ooool00:Kooooo00Go0000ohN7QoooooooZJVYo`00000H
ooooo`05ob4Q8On7QhOooooooiRHV?l000000oooool01?oMgMgoEEEEooooool00007ooooo`03ogMg
MomVIVKooooo08oooooo002Uooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool05_oo
ool01Ol0003ooooooooooooooooo000000Cooooo00?oMgMgolc<c?l000002?ooool00ol0003ooooo
ooooo`2>ooooo`00`oooool01OlQ8B7oV9RHoooooomgMgOoEEEE00Cooooo00?ok^k^odA4A?l00000
1?ooool01Ol0003o^[ZjoooooonHV9So410@093ooooo0033ooooo`05olc<c?l@413o0000oc8b<_o^
k^h01Oooool00omgMgOo0000ooooo`03ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0T?ooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(948) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.49041 .35455 Mdot
.5104 .31509 Mdot
.38784 .59964 Mdot
.64611 .518 Mdot
.44887 .31096 Mdot
.43086 .62657 Mdot
.32747 .40092 Mdot
.36654 .4355 Mdot
.41224 .62006 Mdot
.52991 .57263 Mdot
.34658 .42852 Mdot
.68119 .52445 Mdot
.35992 .40942 Mdot
.63143 .5146 Mdot
.78269 .70357 Mdot
.56469 .55111 Mdot
.514 .29531 Mdot
.50212 .69265 Mdot
.67347 .50625 Mdot
.38343 .5879 Mdot
.50033 .27667 Mdot
.63919 .50748 Mdot
.49922 .35821 Mdot
.63115 .51415 Mdot
.63108 .53786 Mdot
.49687 .33476 Mdot
.46651 .32445 Mdot
.64828 .53746 Mdot
.58785 .53933 Mdot
.37729 .413 Mdot
.61528 .72771 Mdot
.83431 .58983 Mdot
.60326 .57177 Mdot
.43015 .19123 Mdot
.35478 .44058 Mdot
.7813 .47567 Mdot
.40775 .64554 Mdot
.36379 .39542 Mdot
.35979 .43732 Mdot
.37888 .43658 Mdot
.36845 .40796 Mdot
.5028 .33355 Mdot
.2923 .40259 Mdot
.30328 .44673 Mdot
.60491 .45708 Mdot
.38879 .33043 Mdot
.74231 .60218 Mdot
.587 .4943 Mdot
.50183 .30014 Mdot
.38977 .58781 Mdot
.40725 .21098 Mdot
.37982 .39658 Mdot
.31449 .54672 Mdot
.83345 .31665 Mdot
.3515 .39096 Mdot
.62341 .4587 Mdot
.40377 .63281 Mdot
.63183 .4943 Mdot
.63009 .50889 Mdot
.67236 .42114 Mdot
.6194 .55298 Mdot
.49832 .72283 Mdot
.54023 .30123 Mdot
.46614 .61278 Mdot
.42167 .62809 Mdot
.36184 .43416 Mdot
.52315 .30645 Mdot
.35298 .40612 Mdot
.64337 .45553 Mdot
.44829 .64543 Mdot
.58785 .49333 Mdot
.36418 .4282 Mdot
.53347 .36841 Mdot
.59866 .47829 Mdot
.20749 .45353 Mdot
.64976 .80346 Mdot
.48363 .74814 Mdot
.69554 .42102 Mdot
.73643 .47708 Mdot
.44559 .77752 Mdot
.59783 .53228 Mdot
.35318 .80236 Mdot
.7444 .73443 Mdot
.4873 .34802 Mdot
.5342 .50364 Mdot
.45603 .66392 Mdot
.60612 .47489 Mdot
.47561 .42421 Mdot
.60104 .44923 Mdot
.24669 .36967 Mdot
.40592 .61722 Mdot
.52457 .33657 Mdot
.64442 .51907 Mdot
.58113 .54682 Mdot
.61209 .31078 Mdot
.65053 .54562 Mdot
.65474 .52089 Mdot
.48227 .35811 Mdot
.33437 .42835 Mdot
.68056 .5465 Mdot
.3268 .45199 Mdot
.34859 .56997 Mdot
.62336 .46549 Mdot
.39103 .63052 Mdot
.49251 .37 Mdot
.60854 .47031 Mdot
.31977 .42503 Mdot
.58054 .51531 Mdot
.29539 .44395 Mdot
.51208 .31086 Mdot
.57892 .54492 Mdot
.52934 .7245 Mdot
.20303 .5722 Mdot
.52723 .34017 Mdot
.37262 .56351 Mdot
.57673 .52327 Mdot
.6451 .49339 Mdot
.51063 .31837 Mdot
.44125 .61144 Mdot
.50285 .47355 Mdot
.49154 .29637 Mdot
.37148 .441 Mdot
.5094 .28799 Mdot
.53833 .52243 Mdot
.41877 .61548 Mdot
.33466 .56752 Mdot
.3219 .56299 Mdot
.58277 .68608 Mdot
.61212 .47494 Mdot
.38901 .25486 Mdot
.43798 .62123 Mdot
.51847 .33468 Mdot
.35295 .40983 Mdot
.57235 .46126 Mdot
.53582 .34488 Mdot
.33895 .41625 Mdot
.51753 .75652 Mdot
.34165 .63045 Mdot
.49347 .30107 Mdot
.27878 .40483 Mdot
.3933 .41925 Mdot
.38 .43866 Mdot
.40822 .19697 Mdot
.50548 .31204 Mdot
.52087 .72806 Mdot
.33898 .41014 Mdot
.68923 .69001 Mdot
.62922 .45681 Mdot
.5384 .64222 Mdot
.24949 .73029 Mdot
.38425 .21569 Mdot
.26174 .52087 Mdot
.50137 .69855 Mdot
.3844 .43814 Mdot
.60868 .54476 Mdot
.49536 .31439 Mdot
.49823 .3214 Mdot
.66183 .51141 Mdot
.64271 .53097 Mdot
.59028 .4871 Mdot
.5797 .54347 Mdot
.75775 .62069 Mdot
.57613 .50154 Mdot
.5424 .78234 Mdot
.52232 .34701 Mdot
.62619 .54616 Mdot
.42811 .59891 Mdot
.5656 .48865 Mdot
.36944 .41852 Mdot
.63875 .49819 Mdot
.64789 .52059 Mdot
.58048 .55027 Mdot
.3398 .38918 Mdot
.82336 .57408 Mdot
.22814 .68886 Mdot
.80382 .40922 Mdot
.3364 .52855 Mdot
.42642 .64214 Mdot
.62478 .4745 Mdot
.50975 .73398 Mdot
.76021 .43432 Mdot
.60807 .52557 Mdot
.20215 .34861 Mdot
.6531 .51577 Mdot
.54621 .22127 Mdot
.70856 .48468 Mdot
.80477 .3941 Mdot
.53042 .66971 Mdot
.58815 .543 Mdot
.62151 .28121 Mdot
.67702 .26601 Mdot
.35467 .48292 Mdot
.36616 .4045 Mdot
.42424 .59793 Mdot
.39678 .6263 Mdot
.37113 .38243 Mdot
.69343 .54463 Mdot
.6936 .48572 Mdot
.64542 .44581 Mdot
.32654 .55837 Mdot
.55277 .35265 Mdot
.48982 .7418 Mdot
.49543 .36934 Mdot
.46874 .85762 Mdot
.27302 .34343 Mdot
.28734 .40964 Mdot
.49512 .76225 Mdot
.39795 .59825 Mdot
.32501 .55587 Mdot
.51242 .73937 Mdot
.59719 .50871 Mdot
.51283 .304 Mdot
.54177 .18807 Mdot
.70638 .53961 Mdot
.54147 .17046 Mdot
.54284 .33392 Mdot
.49399 .47292 Mdot
.34862 .42092 Mdot
.362 .58877 Mdot
.64914 .49805 Mdot
.60552 .49463 Mdot
.5224 .27846 Mdot
.58959 .49489 Mdot
.47441 .27222 Mdot
.65479 .50331 Mdot
.35758 .60017 Mdot
.4816 .74311 Mdot
.36797 .38026 Mdot
.5736 .68418 Mdot
.51818 .36788 Mdot
.49819 .67171 Mdot
.45013 .61048 Mdot
.76378 .46558 Mdot
.35856 .43102 Mdot
.5294 .73572 Mdot
.44936 .61392 Mdot
.48715 .73091 Mdot
.56796 .49337 Mdot
.41764 .65117 Mdot
.50723 .70625 Mdot
.78792 .60954 Mdot
.5849 .45721 Mdot
.74877 .65446 Mdot
.32561 .40421 Mdot
.51165 .28834 Mdot
.62487 .55107 Mdot
.35834 .57829 Mdot
.60271 .56818 Mdot
.23629 .46807 Mdot
.31127 .55392 Mdot
.31595 .54277 Mdot
.47196 .77979 Mdot
.52683 .7225 Mdot
.2282 .5213 Mdot
.37462 .24913 Mdot
.51452 .29673 Mdot
.65046 .47635 Mdot
.82413 .46338 Mdot
.33972 .41058 Mdot
.59695 .51366 Mdot
.40971 .66271 Mdot
.33962 .40762 Mdot
.62958 .49161 Mdot
.32265 .39863 Mdot
.49925 .31636 Mdot
.29712 .69613 Mdot
.51714 .29582 Mdot
.58894 .45519 Mdot
.31795 .41426 Mdot
.44043 .64221 Mdot
.49406 .33533 Mdot
.58321 .51315 Mdot
.64783 .4864 Mdot
.33608 .5627 Mdot
.60974 .55141 Mdot
.81597 .48936 Mdot
.59661 .5535 Mdot
.38277 .60597 Mdot
.64455 .54776 Mdot
.24733 .29807 Mdot
.32051 .64698 Mdot
.52177 .30556 Mdot
.31813 .54351 Mdot
.4103 .62406 Mdot
.40138 .74089 Mdot
.35601 .49637 Mdot
.58549 .52689 Mdot
.34084 .55663 Mdot
.51794 .63928 Mdot
.3742 .39638 Mdot
.6686 .52343 Mdot
.29309 .34772 Mdot
.42482 .59543 Mdot
.32858 .55745 Mdot
.59719 .43224 Mdot
.49725 .3743 Mdot
.64457 .52054 Mdot
.44304 .64446 Mdot
.50308 .28658 Mdot
.58219 .46662 Mdot
.68703 .6082 Mdot
.31388 .55514 Mdot
.32968 .40144 Mdot
.67074 .4451 Mdot
.58248 .49259 Mdot
.40751 .64196 Mdot
.53156 .36352 Mdot
.35373 .44239 Mdot
.50475 .34142 Mdot
.60801 .21574 Mdot
.29779 .5227 Mdot
.77155 .58562 Mdot
.51034 .77478 Mdot
.2677 .47331 Mdot
.79331 .36574 Mdot
.22404 .55901 Mdot
.65965 .67809 Mdot
.67626 .22785 Mdot
.44602 .61296 Mdot
.37184 .64094 Mdot
.40773 .62789 Mdot
.61731 .53406 Mdot
.42672 .62681 Mdot
.8046 .38308 Mdot
.65546 .50806 Mdot
.41852 .64371 Mdot
.3363 .71824 Mdot
.64216 .53586 Mdot
.52892 .34099 Mdot
.7785 .7005 Mdot
.18991 .45165 Mdot
.30146 .28668 Mdot
.44118 .63356 Mdot
.66119 .43115 Mdot
.64707 .53696 Mdot
.56637 .54452 Mdot
.48847 .32026 Mdot
.66304 .5307 Mdot
.48995 .74013 Mdot
.49594 .76073 Mdot
.52317 .61411 Mdot
.26321 .71498 Mdot
.68078 .54362 Mdot
.49189 .33188 Mdot
.74156 .50375 Mdot
.21857 .4312 Mdot
.36147 .57265 Mdot
.3171 .44057 Mdot
.81689 .59033 Mdot
.69989 .52075 Mdot
.29131 .38584 Mdot
.27856 .36147 Mdot
.5224 .32001 Mdot
.81344 .54656 Mdot
.36176 .39872 Mdot
.67285 .31161 Mdot
.57988 .30304 Mdot
.60376 .50132 Mdot
.35045 .43225 Mdot
.68066 .53374 Mdot
.22775 .36869 Mdot
.6925 .70935 Mdot
.48585 .82407 Mdot
.59416 .4559 Mdot
.21506 .5049 Mdot
.64263 .49671 Mdot
.51095 .47177 Mdot
.59814 .5543 Mdot
.50331 .34543 Mdot
.55099 .58223 Mdot
.43296 .44978 Mdot
.26399 .73503 Mdot
.27692 .33358 Mdot
.49917 .69944 Mdot
.64794 .49167 Mdot
.60495 .50063 Mdot
.52166 .74437 Mdot
.50671 .35727 Mdot
.58265 .54402 Mdot
.60088 .63833 Mdot
.59632 .48929 Mdot
.36955 .40495 Mdot
.5753 .71865 Mdot
.49731 .26666 Mdot
.5929 .55862 Mdot
.49207 .28876 Mdot
.34003 .39107 Mdot
.36852 .43236 Mdot
.57562 .44651 Mdot
.34112 .44584 Mdot
.65039 .51253 Mdot
.61265 .77492 Mdot
.48104 .33366 Mdot
.71746 .52149 Mdot
.51922 .3619 Mdot
.72586 .44663 Mdot
.31721 .4207 Mdot
.34171 .57303 Mdot
.54749 .27503 Mdot
.361 .40073 Mdot
.33115 .26418 Mdot
.66364 .46055 Mdot
.6416 .56192 Mdot
.25205 .34428 Mdot
.44527 .63224 Mdot
.32293 .56165 Mdot
.3276 .43584 Mdot
.58394 .4904 Mdot
.66259 .54113 Mdot
.35866 .38808 Mdot
.64191 .33063 Mdot
.40249 .7314 Mdot
.65247 .53113 Mdot
.50293 .34959 Mdot
.51704 .33631 Mdot
.58795 .46841 Mdot
.58785 .51963 Mdot
.39942 .60313 Mdot
.32293 .54675 Mdot
.35172 .56521 Mdot
.31939 .56033 Mdot
.3633 .60478 Mdot
.42623 .31226 Mdot
.3789 .43739 Mdot
.40469 .26767 Mdot
.24907 .40287 Mdot
.61559 .58242 Mdot
.42019 .64813 Mdot
.613 .50084 Mdot
.64473 .51355 Mdot
.35283 .44282 Mdot
.30212 .50163 Mdot
.53415 .515 Mdot
.48255 .31666 Mdot
.32427 .43452 Mdot
.69163 .50739 Mdot
.44892 .25564 Mdot
.49888 .7113 Mdot
.29105 .29097 Mdot
.36178 .43119 Mdot
.5269 .32368 Mdot
.32445 .39029 Mdot
.60275 .49528 Mdot
.653 .47186 Mdot
.51631 .32119 Mdot
.52034 .70747 Mdot
.61143 .43791 Mdot
.63032 .48962 Mdot
.13948 .52139 Mdot
.20259 .46341 Mdot
.3849 .36749 Mdot
.59831 .54586 Mdot
.65099 .5515 Mdot
.48973 .70851 Mdot
.59813 .49273 Mdot
.6478 .48314 Mdot
.19942 .59381 Mdot
.38794 .36297 Mdot
.50169 .69025 Mdot
.68069 .31738 Mdot
.54257 .33138 Mdot
.82935 .51909 Mdot
.34977 .56528 Mdot
.32697 .37723 Mdot
.28432 .67138 Mdot
.32519 .55287 Mdot
.24194 .46111 Mdot
.8228 .5354 Mdot
.31999 .5603 Mdot
.4798 .64974 Mdot
.52981 .53033 Mdot
.6582 .52001 Mdot
.64032 .49146 Mdot
.51213 .72815 Mdot
.50333 .31242 Mdot
.50468 .59491 Mdot
.69682 .73031 Mdot
.64221 .5031 Mdot
.45803 .3102 Mdot
.79257 .62126 Mdot
.33446 .55976 Mdot
.49419 .74464 Mdot
.52574 .75557 Mdot
.64421 .48888 Mdot
.21717 .61058 Mdot
.49555 .33295 Mdot
.58334 .51368 Mdot
.5729 .50443 Mdot
.43915 .6368 Mdot
.52057 .30962 Mdot
.45411 .62279 Mdot
.31385 .55845 Mdot
.70996 .28202 Mdot
.13588 .48629 Mdot
.34125 .44096 Mdot
.80146 .4775 Mdot
.37866 .40599 Mdot
.49838 .8143 Mdot
.31924 .55063 Mdot
.60132 .52891 Mdot
.52325 .36864 Mdot
.58052 .51281 Mdot
.60382 .51452 Mdot
.59844 .5082 Mdot
.67636 .47915 Mdot
.21162 .33743 Mdot
.5024 .74033 Mdot
.5483 .5325 Mdot
.38423 .60781 Mdot
.80743 .48795 Mdot
.70705 .75058 Mdot
.61246 .49314 Mdot
.64119 .48103 Mdot
.53157 .34339 Mdot
.66307 .51356 Mdot
.36991 .39358 Mdot
.53207 .36368 Mdot
.57374 .54242 Mdot
.80578 .54555 Mdot
.57752 .53696 Mdot
.79337 .38151 Mdot
.32496 .38936 Mdot
.32803 .26836 Mdot
.5454 .51615 Mdot
.3278 .56667 Mdot
.32252 .56145 Mdot
.33249 .54559 Mdot
.31454 .3936 Mdot
.41246 .64362 Mdot
.63824 .78428 Mdot
.63263 .57683 Mdot
.6144 .54356 Mdot
.66379 .54108 Mdot
.39153 .64491 Mdot
.47597 .4194 Mdot
.24348 .53129 Mdot
.68994 .49487 Mdot
.41526 .60759 Mdot
.51068 .28697 Mdot
.43525 .57946 Mdot
.52426 .3655 Mdot
.49671 .6903 Mdot
.34949 .42815 Mdot
.49347 .71872 Mdot
.36218 .23296 Mdot
.51182 .31304 Mdot
.52365 .27841 Mdot
.42407 .64322 Mdot
.47947 .46655 Mdot
.81898 .31649 Mdot
.44886 .64738 Mdot
.59816 .66399 Mdot
.48712 .32775 Mdot
.56985 .51541 Mdot
.5474 .68023 Mdot
.47944 .45787 Mdot
.41664 .63865 Mdot
.61399 .52778 Mdot
.24466 .65729 Mdot
.40124 .60292 Mdot
.6693 .52275 Mdot
.43508 .60953 Mdot
.3663 .4206 Mdot
.43881 .61727 Mdot
.54809 .35372 Mdot
.61378 .4703 Mdot
.83442 .33657 Mdot
.52098 .67413 Mdot
.59925 .55284 Mdot
.32243 .43224 Mdot
.6007 .62457 Mdot
.61378 .51081 Mdot
.49429 .75405 Mdot
.41928 .61397 Mdot
.41001 .71259 Mdot
.64207 .54189 Mdot
.43329 .63221 Mdot
.49662 .35872 Mdot
.31712 .38947 Mdot
.49993 .80298 Mdot
.34651 .57302 Mdot
.48982 .31523 Mdot
.31066 .55966 Mdot
.3125 .42452 Mdot
.65371 .5478 Mdot
.5772 .49581 Mdot
.51304 .34823 Mdot
.30545 .72666 Mdot
.63862 .54861 Mdot
.59824 .53223 Mdot
.38978 .5951 Mdot
.39062 .6417 Mdot
.31531 .7269 Mdot
.44781 .61792 Mdot
.66969 .49103 Mdot
.51199 .34757 Mdot
.63741 .52202 Mdot
.53214 .33504 Mdot
.65357 .48538 Mdot
.5113 .38983 Mdot
.48545 .34404 Mdot
.25114 .57959 Mdot
.62519 .52576 Mdot
.70043 .47481 Mdot
.60142 .5108 Mdot
.59178 .49162 Mdot
.39424 .60717 Mdot
.50397 .74911 Mdot
.55915 .47179 Mdot
.53964 .75371 Mdot
.49831 .75417 Mdot
.63283 .23858 Mdot
.44289 .63294 Mdot
.50981 .71781 Mdot
.76009 .64342 Mdot
.32223 .5433 Mdot
.5044 .73143 Mdot
.72974 .73372 Mdot
.34514 .44206 Mdot
.53593 .30986 Mdot
.64153 .53591 Mdot
.65728 .21841 Mdot
.63131 .7494 Mdot
.3418 .5613 Mdot
.5956 .55232 Mdot
.61435 .50363 Mdot
.47832 .31164 Mdot
.43034 .84587 Mdot
.37905 .60199 Mdot
.62062 .53547 Mdot
.52765 .31055 Mdot
.28947 .78255 Mdot
.38632 .61657 Mdot
.50752 .73109 Mdot
.3526 .38606 Mdot
.50224 .38158 Mdot
.34961 .57377 Mdot
.36942 .39056 Mdot
.26632 .58596 Mdot
.33285 .25782 Mdot
.57618 .52253 Mdot
.41801 .64908 Mdot
.35405 .22693 Mdot
.68139 .55433 Mdot
.37756 .37075 Mdot
.55566 .42239 Mdot
.52432 .3237 Mdot
.36119 .39049 Mdot
.49413 .71041 Mdot
.54136 .35932 Mdot
.503 .35438 Mdot
.36892 .43591 Mdot
.47413 .61357 Mdot
.49174 .46962 Mdot
.37224 .41227 Mdot
.24938 .37245 Mdot
.56667 .20178 Mdot
.32941 .54801 Mdot
.50522 .75555 Mdot
.50458 .20086 Mdot
.50275 .33442 Mdot
.81805 .58694 Mdot
.30071 .27252 Mdot
.65465 .52146 Mdot
.51611 .71649 Mdot
.40936 .35644 Mdot
.66818 .76409 Mdot
.33808 .40499 Mdot
.43489 .43048 Mdot
.53415 .7334 Mdot
.65422 .53339 Mdot
.58623 .4039 Mdot
.61181 .5331 Mdot
.34725 .42463 Mdot
.72765 .47 Mdot
.52776 .32459 Mdot
.31942 .43284 Mdot
.29272 .28871 Mdot
.64781 .50847 Mdot
.61741 .5282 Mdot
.59734 .72026 Mdot
.50904 .30152 Mdot
.35395 .57012 Mdot
.58065 .52565 Mdot
.63426 .49317 Mdot
.62548 .56402 Mdot
.6899 .46794 Mdot
.20727 .58041 Mdot
.62146 .53394 Mdot
.34065 .58833 Mdot
.57458 .55393 Mdot
.62631 .52323 Mdot
.49286 .2893 Mdot
.14807 .45921 Mdot
.34049 .5735 Mdot
.63776 .49629 Mdot
.57578 .52717 Mdot
.3627 .43967 Mdot
.50159 .55889 Mdot
.47363 .45226 Mdot
.42498 .65443 Mdot
.69289 .66264 Mdot
.67709 .48064 Mdot
.53841 .34303 Mdot
.53081 .73488 Mdot
.58421 .4755 Mdot
.53792 .338 Mdot
.55848 .51514 Mdot
.40914 .60442 Mdot
.32749 .54779 Mdot
.3063 .29592 Mdot
.50407 .72375 Mdot
.61231 .75349 Mdot
.39579 .28303 Mdot
.4145 .59529 Mdot
.62133 .54241 Mdot
.35204 .37686 Mdot
.42155 .65295 Mdot
.33768 .56432 Mdot
.56899 .44362 Mdot
.49512 .32252 Mdot
.52543 .33912 Mdot
.53281 .64305 Mdot
.31093 .5906 Mdot
.16968 .5805 Mdot
.36461 .42262 Mdot
.56606 .53906 Mdot
.37672 .25343 Mdot
.52646 .33929 Mdot
.54439 .66094 Mdot
.50848 .7168 Mdot
.33676 .40402 Mdot
.3552 .56371 Mdot
.53497 .34211 Mdot
.50057 .29798 Mdot
.58434 .45912 Mdot
.61886 .48562 Mdot
.64826 .67814 Mdot
.52937 .63043 Mdot
.34716 .38831 Mdot
.51686 .75111 Mdot
.45727 .62525 Mdot
.60912 .53739 Mdot
.48939 .35108 Mdot
.54134 .19694 Mdot
.57394 .52352 Mdot
.39671 .60278 Mdot
.52279 .32576 Mdot
.52509 .73898 Mdot
.49476 .75273 Mdot
.59265 .49179 Mdot
.69175 .4368 Mdot
.34654 .39465 Mdot
.52889 .33898 Mdot
.45616 .21913 Mdot
.63539 .551 Mdot
.61887 .48162 Mdot
.58471 .42834 Mdot
.37782 .42138 Mdot
.33234 .26845 Mdot
.52386 .70883 Mdot
.50405 .32478 Mdot
.58256 .54053 Mdot
.49925 .72205 Mdot
.35706 .25525 Mdot
.32951 .55211 Mdot
.43659 .61321 Mdot
.49339 .75287 Mdot
.52352 .7321 Mdot
.50937 .75851 Mdot
.81462 .60202 Mdot
.54696 .36098 Mdot
.71985 .54191 Mdot
.61155 .55601 Mdot
.53341 .64592 Mdot
.58098 .45124 Mdot
.32753 .38649 Mdot
.44752 .63042 Mdot
.60486 .51084 Mdot
.58563 .45899 Mdot
.63981 .42905 Mdot
.71595 .50494 Mdot
.47763 .28469 Mdot
.51457 .30954 Mdot
.60917 .57951 Mdot
.43865 .63911 Mdot
.4414 .8583 Mdot
.81656 .35631 Mdot
.54171 .50333 Mdot
.49475 .4959 Mdot
.4974 .35667 Mdot
.37565 .43217 Mdot
.46062 .44957 Mdot
.32115 .39618 Mdot
.5089 .32862 Mdot
.61307 .53617 Mdot
.40954 .27035 Mdot
.48512 .73285 Mdot
.58691 .48721 Mdot
.34498 .41683 Mdot
.58838 .48708 Mdot
.36318 .38862 Mdot
.49315 .24395 Mdot
.23875 .3864 Mdot
.6534 .51591 Mdot
.63042 .55613 Mdot
.58003 .41177 Mdot
.61466 .49395 Mdot
.3898 .80125 Mdot
.50589 .35918 Mdot
.24997 .68392 Mdot
.57999 .46617 Mdot
.71084 .40548 Mdot
.62242 .55434 Mdot
.26877 .67223 Mdot
.61287 .48193 Mdot
.42779 .48296 Mdot
.65603 .52529 Mdot
.63153 .47212 Mdot
.31854 .4078 Mdot
.36272 .43944 Mdot
.48414 .35105 Mdot
.35527 .57268 Mdot
.80732 .42564 Mdot
.62702 .48626 Mdot
.36094 .59506 Mdot
.33859 .36351 Mdot
.5213 .74164 Mdot
.50792 .33069 Mdot
.30945 .80274 Mdot
.32848 .39524 Mdot
.45731 .61028 Mdot
.31646 .74344 Mdot
.35755 .58668 Mdot
.41177 .40313 Mdot
.51481 .51727 Mdot
.52297 .71382 Mdot
.64991 .53881 Mdot
.44545 .19507 Mdot
.20983 .45968 Mdot
.59173 .44002 Mdot
.31398 .42373 Mdot
.75906 .44738 Mdot
.50826 .20427 Mdot
.51688 .76509 Mdot
.50008 .70305 Mdot
.33009 .3964 Mdot
.37878 .59281 Mdot
.67224 .48105 Mdot
.50744 .71531 Mdot
.41436 .59858 Mdot
.32272 .54095 Mdot
.39107 .48745 Mdot
.49788 .33139 Mdot
.29344 .2918 Mdot
.37453 .31647 Mdot
.34286 .3886 Mdot
.48787 .67482 Mdot
.49321 .3782 Mdot
.51875 .37905 Mdot
.35509 .57599 Mdot
.39208 .60719 Mdot
.54474 .36003 Mdot
.66535 .48083 Mdot
.72025 .50225 Mdot
.64133 .5 Mdot
.51633 .7315 Mdot
.6101 .48662 Mdot
.40032 .60624 Mdot
.34356 .40633 Mdot
.39263 .61585 Mdot
.32348 .40213 Mdot
.42448 .29862 Mdot
.58762 .51051 Mdot
.63206 .47371 Mdot
.62341 .75586 Mdot
.47876 .34003 Mdot
.41104 .21281 Mdot
.3601 .60649 Mdot
.40342 .62889 Mdot
.65227 .48805 Mdot
.51441 .36577 Mdot
.4829 .75342 Mdot
.61787 .76157 Mdot
.58405 .48375 Mdot
.50766 .36022 Mdot
.61625 .53964 Mdot
.77241 .6216 Mdot
.19026 .47245 Mdot
.50919 .34186 Mdot
.28605 .75355 Mdot
.59346 .5401 Mdot
.57016 .58872 Mdot
.66809 .53582 Mdot
.61789 .64761 Mdot
.64086 .54816 Mdot
.54306 .33474 Mdot
.63751 .50112 Mdot
.54052 .35757 Mdot
.39072 .59213 Mdot
.38021 .43132 Mdot
.48512 .32167 Mdot
.57643 .49229 Mdot
.84818 .55227 Mdot
.35297 .42507 Mdot
.64822 .49452 Mdot
.33081 .42412 Mdot
.53396 .31681 Mdot
.49624 .30274 Mdot
.66534 .77516 Mdot
.37323 .36142 Mdot
.36667 .41872 Mdot
.62809 .53373 Mdot
.34069 .31303 Mdot
.63059 .52669 Mdot
.63119 .68062 Mdot
.60502 .45994 Mdot
.64215 .54847 Mdot
.64055 .81235 Mdot
.37756 .40013 Mdot
.17551 .58114 Mdot
.71052 .71541 Mdot
.80846 .61521 Mdot
.5286 .38499 Mdot
.51703 .7647 Mdot
.81503 .55285 Mdot
.31182 .55569 Mdot
.43044 .61591 Mdot
.60425 .50973 Mdot
.52061 .26065 Mdot
.36375 .39454 Mdot
.50598 .74826 Mdot
.65349 .5145 Mdot
.39234 .60396 Mdot
.45136 .74389 Mdot
.37698 .44437 Mdot
.50332 .33312 Mdot
.47984 .32126 Mdot
.2612 .74755 Mdot
.58273 .54148 Mdot
.6439 .4812 Mdot
.34711 .4266 Mdot
.70749 .52194 Mdot
.52862 .73377 Mdot
.32736 .70183 Mdot
.36598 .41891 Mdot
.4768 .51158 Mdot
.5093 .30862 Mdot
.61326 .50262 Mdot
.48979 .42466 Mdot
.35791 .50911 Mdot
.6751 .28822 Mdot
.5117 .73204 Mdot
.63013 .69025 Mdot
.54302 .33411 Mdot
.34967 .41151 Mdot
.35116 .6383 Mdot
.59078 .56415 Mdot
.61944 .50225 Mdot
.62645 .69376 Mdot
.50975 .61892 Mdot
.53255 .79161 Mdot
.66053 .48814 Mdot
.51036 .61285 Mdot
.64797 .47703 Mdot
.61789 .56627 Mdot
.66014 .47685 Mdot
.6166 .47679 Mdot
.50435 .35931 Mdot
.66534 .44886 Mdot
.43686 .62506 Mdot
.61616 .30689 Mdot
.44521 .43077 Mdot
.62244 .55056 Mdot
.6191 .53215 Mdot
.72185 .33066 Mdot
.30108 .36721 Mdot
.49258 .34828 Mdot
.55366 .32965 Mdot
.34766 .44699 Mdot
.69896 .47151 Mdot
.36977 .60393 Mdot
.62705 .43054 Mdot
.39447 .61334 Mdot
.51518 .3632 Mdot
.40019 .63026 Mdot
.37178 .44455 Mdot
.41823 .64932 Mdot
.36229 .60475 Mdot
.36537 .3926 Mdot
.50078 .30576 Mdot
.59758 .48031 Mdot
.32594 .43569 Mdot
.59986 .71812 Mdot
.51583 .73045 Mdot
.66807 .77359 Mdot
.56248 .52523 Mdot
.43582 .39882 Mdot
.6863 .60927 Mdot
.3944 .61689 Mdot
.1854 .5238 Mdot
.48471 .3426 Mdot
.48255 .72366 Mdot
.51283 .36336 Mdot
.26909 .29135 Mdot
.50776 .75194 Mdot
.73618 .72849 Mdot
.29289 .56676 Mdot
.44473 .72046 Mdot
.65238 .46859 Mdot
.55872 .39806 Mdot
.44494 .64572 Mdot
.36239 .39362 Mdot
.285 .56255 Mdot
.62283 .46935 Mdot
.22831 .56293 Mdot
.47725 .34056 Mdot
.33107 .54609 Mdot
.35458 .40775 Mdot
.32554 .43769 Mdot
.57744 .51456 Mdot
.36217 .74391 Mdot
.61027 .46587 Mdot
.29939 .58664 Mdot
.66808 .679 Mdot
.59949 .42411 Mdot
.65408 .50124 Mdot
.3917 .62962 Mdot
.61771 .53932 Mdot
.7335 .53564 Mdot
.41429 .19589 Mdot
.65696 .45938 Mdot
.29141 .52917 Mdot
.4799 .68739 Mdot
.51339 .31797 Mdot
.54637 .51228 Mdot
.34393 .56852 Mdot
.59501 .54314 Mdot
.39685 .16588 Mdot
.50236 .72987 Mdot
.4468 .67243 Mdot
.61026 .55809 Mdot
.57943 .52064 Mdot
.56649 .28839 Mdot
.52933 .26491 Mdot
.35495 .56261 Mdot
.62459 .50059 Mdot
.68782 .68091 Mdot
.34299 .43387 Mdot
.60153 .46701 Mdot
.64204 .49123 Mdot
.66547 .25536 Mdot
.37349 .42647 Mdot
.39401 .62099 Mdot
.3147 .54737 Mdot
.45443 .61767 Mdot
.52268 .6968 Mdot
.45338 .46477 Mdot
.54177 .64973 Mdot
.19431 .46666 Mdot
.5172 .76068 Mdot
.57258 .53032 Mdot
.53384 .52041 Mdot
.58637 .53385 Mdot
.49487 .70683 Mdot
.37694 .4184 Mdot
.48676 .34189 Mdot
.31198 .29906 Mdot
.32862 .55908 Mdot
.66824 .5265 Mdot
.4881 .7287 Mdot
.49488 .3166 Mdot
.51326 .67761 Mdot
.50844 .32081 Mdot
.36435 .40998 Mdot
.3052 .42038 Mdot
.49554 .74046 Mdot
.52286 .36479 Mdot
.33434 .58134 Mdot
.6897 .735 Mdot
.61727 .46058 Mdot
.40312 .42085 Mdot
.50044 .36246 Mdot
.46776 .32038 Mdot
.48669 .36144 Mdot
.58907 .49951 Mdot
.49776 .51102 Mdot
.59727 .56229 Mdot
.33702 .3934 Mdot
.42676 .60561 Mdot
.53546 .63305 Mdot
.50764 .22433 Mdot
.49466 .64081 Mdot
.5856 .44915 Mdot
.64476 .50747 Mdot
.64434 .48923 Mdot
.60457 .45407 Mdot
.3302 .62113 Mdot
.58772 .5165 Mdot
.31945 .40696 Mdot
.40512 .61123 Mdot
.61467 .55434 Mdot
.34782 .56778 Mdot
.49509 .45846 Mdot
.53056 .7402 Mdot
.44538 .45402 Mdot
.83665 .50677 Mdot
.49274 .31713 Mdot
.45267 .62544 Mdot
.43216 .61846 Mdot
.51834 .75594 Mdot
.36237 .3952 Mdot
.50554 .31563 Mdot
.63996 .6456 Mdot
.51294 .75596 Mdot
.63654 .49801 Mdot
.27327 .6385 Mdot
.25135 .61228 Mdot
.65813 .53103 Mdot
.60836 .51921 Mdot
.31622 .54384 Mdot
.37701 .59541 Mdot
.57796 .16715 Mdot
.55753 .69685 Mdot
.49921 .74559 Mdot
.51583 .70609 Mdot
.50737 .37642 Mdot
.53769 .49934 Mdot
.33166 .39844 Mdot
.58034 .72902 Mdot
.57282 .62469 Mdot
.59808 .7561 Mdot
.48913 .80676 Mdot
.57906 .4998 Mdot
.58391 .36493 Mdot
.64909 .51136 Mdot
.47577 .32437 Mdot
.52048 .30269 Mdot
.48988 .33873 Mdot
.34912 .39197 Mdot
.73149 .44769 Mdot
.31863 .41711 Mdot
.83359 .45935 Mdot
.54496 .34285 Mdot
.35318 .6628 Mdot
.40694 .63797 Mdot
.55401 .5292 Mdot
.52716 .73143 Mdot
.37944 .45176 Mdot
.64683 .45848 Mdot
.21065 .59472 Mdot
.41856 .64801 Mdot
.50398 .30254 Mdot
.51616 .51996 Mdot
.76658 .32142 Mdot
.47516 .47008 Mdot
.62963 .58757 Mdot
.5712 .31657 Mdot
.51721 .7491 Mdot
.67232 .28851 Mdot
.50965 .69673 Mdot
.3384 .41212 Mdot
.62122 .47129 Mdot
.60808 .47446 Mdot
.65365 .48441 Mdot
.58853 .5145 Mdot
.35749 .44343 Mdot
.5639 .47944 Mdot
.24732 .2981 Mdot
.32308 .54483 Mdot
.78141 .6068 Mdot
.5019 .71191 Mdot
.31113 .40536 Mdot
.40228 .61177 Mdot
.35177 .56353 Mdot
.56387 .67423 Mdot
.65446 .52697 Mdot
.60292 .51149 Mdot
.36573 .57682 Mdot
.6645 .49638 Mdot
.68445 .48558 Mdot
.435 .62713 Mdot
.49613 .63927 Mdot
.5031 .76523 Mdot
.49441 .71692 Mdot
.37486 .41664 Mdot
.51972 .36486 Mdot
.51111 .72221 Mdot
.38735 .5952 Mdot
.55783 .50069 Mdot
.57335 .49518 Mdot
.49918 .36237 Mdot
.29849 .27392 Mdot
.5251 .7583 Mdot
.51696 .52674 Mdot
.54128 .34774 Mdot
.54681 .36254 Mdot
.62045 .50385 Mdot
.61285 .43312 Mdot
.46545 .32753 Mdot
.50172 .76077 Mdot
.31008 .40804 Mdot
.44262 .69954 Mdot
.34131 .41868 Mdot
.50114 .31404 Mdot
.58272 .46865 Mdot
.50484 .30612 Mdot
.59599 .54673 Mdot
.7523 .77051 Mdot
.60945 .47684 Mdot
.20084 .42148 Mdot
.61339 .65706 Mdot
.42962 .62049 Mdot
.33677 .58156 Mdot
.34455 .56006 Mdot
.54246 .34363 Mdot
.58051 .47742 Mdot
.51507 .70378 Mdot
.77865 .67041 Mdot
.48434 .37327 Mdot
.4191 .60639 Mdot
.37056 .6002 Mdot
.37521 .39905 Mdot
.60002 .55622 Mdot
.61536 .49974 Mdot
.41218 .64708 Mdot
.71515 .60403 Mdot
.53294 .35019 Mdot
.64594 .48482 Mdot
.63808 .51525 Mdot
.43164 .62409 Mdot
.68499 .73795 Mdot
.56267 .35219 Mdot
.62276 .47366 Mdot
.40425 .66881 Mdot
.32307 .38813 Mdot
.62295 .45704 Mdot
.56473 .47736 Mdot
.52079 .71874 Mdot
.79289 .55624 Mdot
.43738 .18701 Mdot
.33402 .3852 Mdot
.35364 .57053 Mdot
.57202 .53611 Mdot
.4087 .63877 Mdot
.57439 .49509 Mdot
.79014 .44529 Mdot
.32861 .54601 Mdot
.59212 .52658 Mdot
.54197 .4845 Mdot
.51529 .30005 Mdot
.58508 .5186 Mdot
.71043 .30421 Mdot
.45534 .63959 Mdot
.58834 .52319 Mdot
.67154 .42451 Mdot
.36609 .43248 Mdot
.54217 .50009 Mdot
.50072 .70779 Mdot
.61955 .64436 Mdot
.3956 .29409 Mdot
.41224 .66082 Mdot
.49555 .71734 Mdot
.59048 .48017 Mdot
.37761 .59114 Mdot
.34688 .38687 Mdot
.22055 .5588 Mdot
.65826 .49619 Mdot
.34857 .42455 Mdot
.34566 .40633 Mdot
.49738 .72753 Mdot
.1874 .62656 Mdot
.55394 .49736 Mdot
.61245 .4921 Mdot
.7156 .30206 Mdot
.48826 .2971 Mdot
.60617 .48494 Mdot
.57306 .52541 Mdot
.3212 .41173 Mdot
.54665 .27273 Mdot
.74792 .40332 Mdot
.33378 .71603 Mdot
.35634 .38427 Mdot
.46709 .64511 Mdot
.37725 .5904 Mdot
.50397 .71221 Mdot
.51734 .32513 Mdot
.53315 .72109 Mdot
.44026 .63188 Mdot
.57707 .53405 Mdot
.32553 .40802 Mdot
.59263 .23298 Mdot
.38139 .39997 Mdot
.42595 .65748 Mdot
.47285 .31734 Mdot
.36347 .26776 Mdot
.32451 .20201 Mdot
.3848 .31947 Mdot
.29132 .40478 Mdot
.52148 .74108 Mdot
.26973 .59243 Mdot
.64064 .51246 Mdot
.66353 .29216 Mdot
.5938 .48383 Mdot
.61069 .39957 Mdot
.44498 .61536 Mdot
.35896 .57624 Mdot
.62063 .47205 Mdot
.65322 .68701 Mdot
.39028 .42219 Mdot
.37317 .39548 Mdot
.59544 .52074 Mdot
.36156 .40108 Mdot
.62132 .48898 Mdot
.39559 .60873 Mdot
.16735 .54436 Mdot
.64686 .50186 Mdot
.638 .56111 Mdot
.28318 .38175 Mdot
.68366 .76403 Mdot
.32701 .58749 Mdot
.5805 .35638 Mdot
.73637 .28539 Mdot
.36063 .40089 Mdot
.55486 .45272 Mdot
.43315 .65023 Mdot
.31579 .54374 Mdot
.3338 .58034 Mdot
.59954 .48812 Mdot
.5974 .494 Mdot
.65255 .48938 Mdot
.61637 .52907 Mdot
.66945 .29501 Mdot
.70061 .49293 Mdot
.61585 .37884 Mdot
.6027 .51397 Mdot
.5865 .40222 Mdot
.32919 .43651 Mdot
.5054 .2775 Mdot
.53596 .73646 Mdot
.57846 .50217 Mdot
.48533 .26617 Mdot
.31822 .3933 Mdot
.83337 .45687 Mdot
.3781 .41048 Mdot
.41155 .62368 Mdot
.38064 .42503 Mdot
.60531 .55107 Mdot
.51747 .337 Mdot
.44093 .65128 Mdot
.22644 .506 Mdot
.4289 .61454 Mdot
.5991 .55288 Mdot
.44061 .68388 Mdot
.43388 .61799 Mdot
.48478 .43974 Mdot
.52057 .33425 Mdot
.6793 .69133 Mdot
.52118 .30275 Mdot
.58913 .52658 Mdot
.59271 .52988 Mdot
.30238 .54413 Mdot
.3842 .43093 Mdot
.53254 .31294 Mdot
.13994 .53289 Mdot
.51615 .69706 Mdot
.49359 .34121 Mdot
.59899 .57195 Mdot
.5045 .58159 Mdot
.51827 .34451 Mdot
.68734 .64529 Mdot
.35904 .39166 Mdot
.54093 .36445 Mdot
.59904 .57048 Mdot
.27689 .43722 Mdot
.48534 .74074 Mdot
.38039 .61433 Mdot
.42816 .50711 Mdot
.44888 .64257 Mdot
.30867 .40653 Mdot
.40318 .65019 Mdot
.34166 .4352 Mdot
.39711 .22159 Mdot
.72869 .49582 Mdot
.36056 .37752 Mdot
.30842 .41977 Mdot
.42676 .64031 Mdot
.65674 .50259 Mdot
.41554 .44987 Mdot
.65996 .48368 Mdot
.63702 .45624 Mdot
.34863 .43588 Mdot
.53929 .32326 Mdot
.5348 .30667 Mdot
.56643 .39999 Mdot
.47961 .32035 Mdot
.39311 .61142 Mdot
.19044 .46877 Mdot
.36812 .22956 Mdot
.35079 .43065 Mdot
.32431 .44004 Mdot
.62737 .52833 Mdot
.41447 .64175 Mdot
.40296 .59217 Mdot
.33471 .39938 Mdot
.62015 .26467 Mdot
.59159 .56002 Mdot
.47023 .31278 Mdot
.54558 .34668 Mdot
.51036 .34535 Mdot
.49491 .36994 Mdot
.73112 .38757 Mdot
.36 .39151 Mdot
.54386 .34278 Mdot
.59515 .52412 Mdot
.59854 .4925 Mdot
.32749 .56421 Mdot
.49558 .7136 Mdot
.55913 .52284 Mdot
.67474 .50253 Mdot
.61782 .50515 Mdot
.43589 .61359 Mdot
.55639 .55934 Mdot
.34765 .56049 Mdot
.37876 .60535 Mdot
.3682 .60838 Mdot
.3371 .57112 Mdot
.5556 .40108 Mdot
.74018 .28032 Mdot
.62018 .53574 Mdot
.70768 .54472 Mdot
.40897 .63626 Mdot
.19307 .55577 Mdot
.33962 .26581 Mdot
.65499 .49121 Mdot
.3735 .50187 Mdot
.40712 .64856 Mdot
.48829 .30139 Mdot
.60127 .48396 Mdot
.31619 .5552 Mdot
.53005 .74018 Mdot
.61155 .57524 Mdot
.31292 .54864 Mdot
.52845 .3627 Mdot
.53057 .76192 Mdot
.5345 .36892 Mdot
.41387 .65266 Mdot
.54183 .48783 Mdot
.81852 .31157 Mdot
.45114 .61388 Mdot
.75126 .68728 Mdot
.50965 .25247 Mdot
.64878 .48763 Mdot
.45463 .62776 Mdot
.48486 .3015 Mdot
.31048 .39885 Mdot
.50839 .59228 Mdot
.48156 .33425 Mdot
.356 .57145 Mdot
.32051 .55632 Mdot
.43514 .62476 Mdot
.51782 .31154 Mdot
.59457 .46621 Mdot
.5288 .32088 Mdot
.38116 .42301 Mdot
.64605 .52339 Mdot
.80247 .38096 Mdot
.70979 .53146 Mdot
.54168 .33829 Mdot
.38755 .60373 Mdot
.48759 .71218 Mdot
.65154 .52528 Mdot
.745 .68147 Mdot
.58264 .54631 Mdot
.34201 .43057 Mdot
.23659 .65698 Mdot
.61584 .24097 Mdot
.62387 .55316 Mdot
.62588 .52866 Mdot
.36152 .38969 Mdot
.65372 .52618 Mdot
.63671 .54877 Mdot
.36085 .36272 Mdot
.52239 .30932 Mdot
.63871 .50476 Mdot
.40299 .59528 Mdot
.44331 .20263 Mdot
.59803 .5614 Mdot
.36482 .5492 Mdot
.66745 .69269 Mdot
.22559 .65616 Mdot
.5965 .47765 Mdot
.57089 .70314 Mdot
.61306 .52674 Mdot
.58477 .49707 Mdot
.63141 .53025 Mdot
.58147 .335 Mdot
.42985 .64043 Mdot
.40912 .60732 Mdot
.48674 .74542 Mdot
.67288 .68923 Mdot
.51684 .71589 Mdot
.37295 .40096 Mdot
.45768 .76898 Mdot
.33001 .54756 Mdot
.52647 .36451 Mdot
.59774 .47073 Mdot
.45586 .64258 Mdot
.61027 .50253 Mdot
.60381 .54948 Mdot
.38908 .62718 Mdot
.41732 .59343 Mdot
.38951 .65193 Mdot
.52251 .71038 Mdot
.48564 .33149 Mdot
.58405 .45788 Mdot
.49787 .75354 Mdot
.59151 .46867 Mdot
.52374 .65226 Mdot
.48725 .33784 Mdot
.52456 .31154 Mdot
.51179 .29152 Mdot
.57709 .53448 Mdot
.62062 .55015 Mdot
.31944 .41965 Mdot
.5195 .36725 Mdot
.37088 .42267 Mdot
.43271 .65189 Mdot
.44748 .602 Mdot
.59945 .48835 Mdot
.54033 .57325 Mdot
.52083 .71442 Mdot
.40628 .61937 Mdot
.36672 .57517 Mdot
.48386 .71526 Mdot
.5881 .54769 Mdot
.39297 .63185 Mdot
.49153 .72228 Mdot
.5969 .26601 Mdot
.7015 .24099 Mdot
.49086 .70783 Mdot
.59706 .52269 Mdot
.55397 .2671 Mdot
.66734 .74618 Mdot
.51141 .69429 Mdot
.33216 .42011 Mdot
.57505 .53357 Mdot
.70591 .58426 Mdot
.53168 .74517 Mdot
.4385 .21127 Mdot
.42741 .62095 Mdot
.29896 .45865 Mdot
.66612 .55938 Mdot
.64902 .29543 Mdot
.52812 .708 Mdot
.50459 .32017 Mdot
.5054 .28251 Mdot
.62218 .51287 Mdot
.53277 .70883 Mdot
.36783 .38811 Mdot
.42147 .61692 Mdot
.3537 .58981 Mdot
.52028 .31289 Mdot
.31713 .32918 Mdot
.40947 .59997 Mdot
.52285 .54619 Mdot
.29414 .6903 Mdot
.71046 .48393 Mdot
.63095 .4148 Mdot
.22266 .447 Mdot
.56897 .52173 Mdot
.49645 .70078 Mdot
.3168 .39951 Mdot
.32672 .39913 Mdot
.36461 .41696 Mdot
.33944 .58247 Mdot
.45778 .44989 Mdot
.42944 .64747 Mdot
.22674 .54111 Mdot
.49987 .72143 Mdot
.70789 .673 Mdot
.588 .47343 Mdot
.64518 .50611 Mdot
.56481 .53767 Mdot
.61615 .46485 Mdot
.62028 .52204 Mdot
.36414 .39831 Mdot
.34152 .58514 Mdot
.40538 .71138 Mdot
.50541 .35088 Mdot
.48551 .64532 Mdot
.40663 .63783 Mdot
.3177 .54344 Mdot
.50358 .74324 Mdot
.50821 .48281 Mdot
.40559 .6549 Mdot
.40019 .62902 Mdot
.55611 .52104 Mdot
.53505 .33839 Mdot
.62428 .43262 Mdot
.59969 .5322 Mdot
.40231 .61694 Mdot
.4358 .58826 Mdot
.75123 .37519 Mdot
.55108 .44267 Mdot
.50012 .774 Mdot
.4989 .53807 Mdot
.50867 .69438 Mdot
.66497 .54584 Mdot
.19514 .56664 Mdot
.43923 .63253 Mdot
.41833 .62836 Mdot
.49063 .71764 Mdot
.55409 .57732 Mdot
.521 .32118 Mdot
.36016 .57599 Mdot
.32933 .42625 Mdot
.5866 .53156 Mdot
.43621 .59734 Mdot
.6237 .59225 Mdot
.38732 .74627 Mdot
.36156 .42242 Mdot
.38064 .60384 Mdot
.60297 .55632 Mdot
.5993 .52218 Mdot
.5206 .74528 Mdot
.45274 .29601 Mdot
.61684 .57844 Mdot
.81011 .61296 Mdot
.24249 .38338 Mdot
.2606 .3534 Mdot
.61945 .50204 Mdot
.51875 .30853 Mdot
.31986 .55102 Mdot
.50799 .75552 Mdot
.57282 .4708 Mdot
.71225 .25199 Mdot
.47862 .29108 Mdot
.34426 .41363 Mdot
.31742 .55722 Mdot
.45978 .44727 Mdot
.57796 .54072 Mdot
.5945 .48378 Mdot
.58902 .50606 Mdot
.63879 .18723 Mdot
.41705 .60405 Mdot
.47658 .33224 Mdot
.51209 .73495 Mdot
.47841 .32143 Mdot
.41985 .61121 Mdot
.32316 .30155 Mdot
.6357 .54594 Mdot
.47183 .31271 Mdot
.50652 .32313 Mdot
.37526 .39961 Mdot
.3088 .40013 Mdot
.46304 .67313 Mdot
.61086 .47717 Mdot
.31548 .55365 Mdot
.51786 .29964 Mdot
.36987 .58778 Mdot
.50955 .752 Mdot
.32027 .42725 Mdot
.60147 .51376 Mdot
.4395 .62664 Mdot
.60231 .43759 Mdot
.52365 .34567 Mdot
.40089 .62984 Mdot
.35163 .57747 Mdot
.51111 .70546 Mdot
.59968 .50269 Mdot
.49412 .7701 Mdot
.35741 .57742 Mdot
.63933 .51539 Mdot
.52498 .44939 Mdot
.49831 .77838 Mdot
.23788 .52013 Mdot
.44179 .6415 Mdot
.33868 .56868 Mdot
.50783 .29359 Mdot
.43574 .22327 Mdot
.41832 .62463 Mdot
.51631 .46186 Mdot
.43567 .32241 Mdot
.58461 .45692 Mdot
.50426 .33784 Mdot
.2725 .61039 Mdot
.82917 .55996 Mdot
.72625 .67752 Mdot
.64676 .49345 Mdot
.45313 .63268 Mdot
.48991 .73534 Mdot
.35086 .43107 Mdot
.36365 .54909 Mdot
.73044 .52078 Mdot
.38918 .63474 Mdot
.62675 .53141 Mdot
.52258 .3053 Mdot
.33938 .39907 Mdot
.41896 .27133 Mdot
.38627 .59865 Mdot
.44723 .61978 Mdot
.61536 .55477 Mdot
.50701 .71795 Mdot
.75366 .60453 Mdot
.39845 .60532 Mdot
.44118 .60047 Mdot
.26293 .58182 Mdot
.4878 .72671 Mdot
.60931 .52365 Mdot
.5694 .39985 Mdot
.60939 .454 Mdot
.75709 .68537 Mdot
.34944 .56532 Mdot
.50807 .35288 Mdot
.5905 .48762 Mdot
.32608 .71705 Mdot
.4071 .61541 Mdot
.49317 .4894 Mdot
.46707 .6156 Mdot
.35739 .39116 Mdot
.44351 .6013 Mdot
.60719 .49108 Mdot
.39032 .41919 Mdot
.52044 .71433 Mdot
.62133 .47509 Mdot
.62254 .54901 Mdot
.48306 .30694 Mdot
.33702 .41194 Mdot
.53812 .21527 Mdot
.3193 .43331 Mdot
.32418 .39018 Mdot
.53181 .29742 Mdot
.63087 .50452 Mdot
.40824 .62484 Mdot
.4014 .64767 Mdot
.57881 .46518 Mdot
.17552 .5083 Mdot
.52219 .31969 Mdot
.49304 .67274 Mdot
.59502 .17786 Mdot
.55398 .43199 Mdot
.37071 .57882 Mdot
.44705 .31574 Mdot
.36183 .3865 Mdot
.59885 .5182 Mdot
.53889 .34676 Mdot
.39925 .58851 Mdot
.40891 .5992 Mdot
.58645 .46759 Mdot
.34368 .40238 Mdot
.52453 .75313 Mdot
.44412 .60903 Mdot
.36312 .74315 Mdot
.58448 .51066 Mdot
.23288 .56267 Mdot
.44869 .61633 Mdot
.79624 .6603 Mdot
.39799 .72301 Mdot
.50422 .34116 Mdot
.60852 .54936 Mdot
.48087 .32127 Mdot
.51553 .73673 Mdot
.46526 .65577 Mdot
.34315 .40467 Mdot
.54236 .45479 Mdot
.35962 .20209 Mdot
.4254 .643 Mdot
.50319 .3585 Mdot
.62104 .55409 Mdot
.52419 .47857 Mdot
.61255 .48822 Mdot
.55468 .28276 Mdot
.49287 .67645 Mdot
.35286 .43591 Mdot
.33888 .42852 Mdot
.64317 .51519 Mdot
.52388 .74667 Mdot
.38445 .61498 Mdot
.42164 .61817 Mdot
.52216 .88044 Mdot
.36455 .57956 Mdot
.64587 .6735 Mdot
.59808 .49722 Mdot
.36911 .58927 Mdot
.50292 .22084 Mdot
.34789 .42707 Mdot
.61175 .4638 Mdot
.36629 .59353 Mdot
.26154 .41793 Mdot
.51688 .64125 Mdot
.61765 .52137 Mdot
.68943 .51263 Mdot
.33063 .42571 Mdot
.61885 .74171 Mdot
.42329 .64886 Mdot
.60926 .46137 Mdot
.3387 .44713 Mdot
.30511 .71431 Mdot
.37124 .21782 Mdot
.48585 .33167 Mdot
.45851 .64363 Mdot
.3641 .3979 Mdot
.64631 .57486 Mdot
.49992 .71239 Mdot
.45168 .643 Mdot
.43026 .61113 Mdot
.63204 .53513 Mdot
.55488 .52374 Mdot
.54922 .43512 Mdot
.50927 .35892 Mdot
.33769 .44093 Mdot
.61883 .47004 Mdot
.31515 .33256 Mdot
.65005 .48004 Mdot
.32655 .43207 Mdot
.89674 .42738 Mdot
.64198 .46145 Mdot
.61451 .4898 Mdot
.75053 .62102 Mdot
.48088 .33054 Mdot
.48136 .31487 Mdot
.22141 .40978 Mdot
.59828 .49774 Mdot
.42837 .73163 Mdot
.48517 .3264 Mdot
.52462 .32523 Mdot
.34025 .66295 Mdot
.65159 .51284 Mdot
.61392 .76102 Mdot
.32776 .40046 Mdot
.32114 .39988 Mdot
.52691 .31839 Mdot
.63059 .57877 Mdot
.34624 .38533 Mdot
.70244 .32942 Mdot
.41229 .64337 Mdot
.19494 .57404 Mdot
.52391 .34942 Mdot
.42579 .42279 Mdot
.35488 .4273 Mdot
.83418 .46391 Mdot
.36428 .50405 Mdot
.65344 .49373 Mdot
.59621 .50579 Mdot
.51752 .71162 Mdot
.59774 .44588 Mdot
.35184 .56532 Mdot
.36205 .40131 Mdot
.76251 .57167 Mdot
.49029 .33861 Mdot
.61418 .48079 Mdot
.50683 .50031 Mdot
.41809 .29104 Mdot
.27866 .53648 Mdot
.5131 .31882 Mdot
.49925 .33434 Mdot
.43717 .64074 Mdot
.44097 .6115 Mdot
.62769 .511 Mdot
.33681 .39446 Mdot
.52238 .36807 Mdot
.3325 .43465 Mdot
.44094 .63006 Mdot
.40235 .62683 Mdot
.32698 .54486 Mdot
.66756 .49557 Mdot
.38666 .61341 Mdot
.3467 .74248 Mdot
.31202 .328 Mdot
.51576 .37891 Mdot
.4128 .17781 Mdot
.41955 .26945 Mdot
.66549 .62249 Mdot
.52028 .70502 Mdot
.35946 .58153 Mdot
.36931 .4383 Mdot
.62934 .52613 Mdot
.60648 .50713 Mdot
.33478 .55962 Mdot
.38668 .41993 Mdot
.51016 .74695 Mdot
.38706 .42341 Mdot
.49662 .72261 Mdot
.37357 .58582 Mdot
.58616 .5543 Mdot
.57237 .51236 Mdot
.36584 .40268 Mdot
.39435 .62463 Mdot
.40564 .60959 Mdot
.50784 .69501 Mdot
.51999 .62334 Mdot
.43651 .62427 Mdot
.52408 .34829 Mdot
.71859 .38827 Mdot
.32224 .55469 Mdot
.6031 .48435 Mdot
.53856 .65366 Mdot
.64639 .27227 Mdot
.60115 .4564 Mdot
.32506 .56493 Mdot
.40133 .83537 Mdot
.5973 .47327 Mdot
.3296 .80116 Mdot
.33766 .56882 Mdot
.48062 .33332 Mdot
.45234 .63111 Mdot
.34862 .55961 Mdot
.67705 .55372 Mdot
.48946 .6918 Mdot
.56453 .4934 Mdot
.48286 .32235 Mdot
.4977 .28825 Mdot
.25036 .35024 Mdot
.75177 .68822 Mdot
.50778 .69762 Mdot
.49748 .73884 Mdot
.42067 .62493 Mdot
.6018 .81711 Mdot
.5777 .55942 Mdot
.50178 .74685 Mdot
.74342 .58555 Mdot
.61859 .53399 Mdot
.61952 .68432 Mdot
.38049 .50212 Mdot
.52005 .31071 Mdot
.55793 .40346 Mdot
.41428 .61947 Mdot
.49837 .35532 Mdot
.29939 .32007 Mdot
.56325 .52981 Mdot
.48886 .33991 Mdot
.32448 .42799 Mdot
.24412 .46734 Mdot
.49368 .30551 Mdot
.53089 .65659 Mdot
.33586 .39711 Mdot
.28509 .59822 Mdot
.73099 .61964 Mdot
.29708 .20093 Mdot
.35833 .39613 Mdot
.39982 .63915 Mdot
.40613 .6482 Mdot
.42361 .62068 Mdot
.48314 .34134 Mdot
.38852 .59208 Mdot
.51735 .35999 Mdot
.66031 .75938 Mdot
.5219 .62367 Mdot
.49508 .7405 Mdot
.35344 .3583 Mdot
.50317 .32841 Mdot
.19906 .51285 Mdot
.33811 .19701 Mdot
.59374 .51976 Mdot
.32576 .43952 Mdot
.49209 .71448 Mdot
.76715 .71891 Mdot
.51953 .71555 Mdot
.43581 .64912 Mdot
.19417 .5916 Mdot
.62214 .48586 Mdot
.76834 .45397 Mdot
.51046 .70269 Mdot
.50769 .31163 Mdot
.64201 .51207 Mdot
.3272 .57715 Mdot
.50737 .71379 Mdot
.52768 .7469 Mdot
.63151 .51489 Mdot
.50518 .30176 Mdot
.40387 .62406 Mdot
.37063 .44069 Mdot
.50774 .69015 Mdot
.69134 .54959 Mdot
.58793 .45387 Mdot
.56676 .52912 Mdot
.4778 .46021 Mdot
.7343 .5703 Mdot
.35954 .40009 Mdot
.68609 .71398 Mdot
.43768 .60991 Mdot
.29373 .63543 Mdot
.22928 .40803 Mdot
.40783 .38028 Mdot
.34991 .56737 Mdot
.34382 .55722 Mdot
.62205 .51896 Mdot
.73469 .57175 Mdot
.24976 .67057 Mdot
.28944 .3751 Mdot
.32321 .55319 Mdot
.41686 .61467 Mdot
.50019 .28235 Mdot
.25252 .33124 Mdot
.58433 .45221 Mdot
.35352 .38164 Mdot
.43884 .62156 Mdot
.78976 .44182 Mdot
.50538 .72288 Mdot
.19565 .54561 Mdot
.62211 .55228 Mdot
.63302 .47418 Mdot
.35759 .40678 Mdot
.31866 .41472 Mdot
.30508 .52107 Mdot
.24418 .36515 Mdot
.57882 .75141 Mdot
.45833 .23193 Mdot
.78394 .43176 Mdot
.50121 .27832 Mdot
.5414 .33543 Mdot
.31435 .5595 Mdot
.31546 .42373 Mdot
.59085 .48271 Mdot
.52556 .36597 Mdot
.27392 .54066 Mdot
.53845 .39188 Mdot
.63307 .68462 Mdot
.4095 .73918 Mdot
.5925 .54763 Mdot
.53526 .33199 Mdot
.49158 .34895 Mdot
.51503 .37223 Mdot
.33073 .56814 Mdot
.62417 .49986 Mdot
.65592 .51049 Mdot
.62911 .46921 Mdot
.7043 .51767 Mdot
.5842 .5153 Mdot
.31106 .34975 Mdot
.48127 .51638 Mdot
.77621 .56265 Mdot
.61853 .45896 Mdot
.32662 .3953 Mdot
.56413 .51985 Mdot
.52332 .74869 Mdot
.62996 .52946 Mdot
.6343 .67816 Mdot
.35226 .41954 Mdot
.53913 .55777 Mdot
.45357 .23059 Mdot
.62944 .54912 Mdot
.51241 .7638 Mdot
.70666 .59383 Mdot
.53529 .22105 Mdot
.48906 .63021 Mdot
.52508 .34709 Mdot
.38809 .6384 Mdot
.38126 .41946 Mdot
.4099 .62726 Mdot
.63692 .46537 Mdot
.31473 .55717 Mdot
.39715 .35056 Mdot
.42516 .42757 Mdot
.58258 .48922 Mdot
.54941 .54168 Mdot
.52737 .33715 Mdot
.39396 .63293 Mdot
.52824 .27914 Mdot
.59016 .49703 Mdot
.51355 .7314 Mdot
.50334 .71479 Mdot
.27431 .35339 Mdot
.80219 .41592 Mdot
.42124 .22137 Mdot
.35864 .40542 Mdot
.40058 .60317 Mdot
.53037 .71112 Mdot
.69749 .56052 Mdot
.33445 .38125 Mdot
.3686 .39187 Mdot
.33532 .4065 Mdot
.58483 .53629 Mdot
.35068 .56482 Mdot
.76933 .5415 Mdot
.35435 .56919 Mdot
.63195 .54672 Mdot
.42429 .60623 Mdot
.33133 .54578 Mdot
.51241 .70942 Mdot
.37521 .41702 Mdot
.44356 .629 Mdot
.58694 .52596 Mdot
.48997 .32012 Mdot
.51485 .60685 Mdot
.58913 .64384 Mdot
.77034 .64958 Mdot
.78084 .63148 Mdot
.52396 .29884 Mdot
.82198 .466 Mdot
.39328 .43515 Mdot
.62218 .26662 Mdot
.4158 .67792 Mdot
.58448 .46369 Mdot
.18059 .4443 Mdot
.4256 .64923 Mdot
.39168 .63177 Mdot
.60865 .52609 Mdot
.39177 .58882 Mdot
.61382 .48318 Mdot
.44538 .62 Mdot
.48353 .64604 Mdot
.58136 .45184 Mdot
.3879 .61874 Mdot
.6493 .56499 Mdot
.65019 .52571 Mdot
.52231 .31102 Mdot
.45595 .63162 Mdot
.64589 .47292 Mdot
.68435 .79348 Mdot
.31876 .42224 Mdot
.32801 .56632 Mdot
.54965 .70752 Mdot
.36616 .39915 Mdot
.49651 .34393 Mdot
.63107 .45248 Mdot
.52526 .72858 Mdot
.50115 .31925 Mdot
.48431 .673 Mdot
.50509 .70216 Mdot
.18916 .47143 Mdot
.52901 .34273 Mdot
.32508 .5557 Mdot
.5186 .70955 Mdot
.5441 .52908 Mdot
.45933 .62998 Mdot
.56306 .62081 Mdot
.35474 .574 Mdot
.61443 .49937 Mdot
.34689 .59091 Mdot
.31851 .42538 Mdot
.64293 .48914 Mdot
.4504 .61087 Mdot
.34065 .57279 Mdot
.59076 .53918 Mdot
.62431 .52577 Mdot
.28467 .29348 Mdot
.23345 .5963 Mdot
.51669 .74865 Mdot
.4805 .29973 Mdot
.59474 .52439 Mdot
.52425 .71308 Mdot
.41226 .78579 Mdot
.56872 .52542 Mdot
.48306 .34789 Mdot
.62653 .42798 Mdot
.43261 .60447 Mdot
.3721 .4211 Mdot
.44894 .6508 Mdot
.53052 .73672 Mdot
.15015 .58994 Mdot
.32371 .5424 Mdot
.6619 .5511 Mdot
.5961 .46868 Mdot
.29254 .55953 Mdot
.49811 .35406 Mdot
.58108 .74721 Mdot
.59939 .50303 Mdot
.71631 .5161 Mdot
.6245 .47734 Mdot
.40409 .71926 Mdot
.52216 .32158 Mdot
.61321 .49316 Mdot
.52624 .56003 Mdot
.6241 .56064 Mdot
.52377 .75583 Mdot
.7349 .65296 Mdot
.56755 .50701 Mdot
.7303 .20681 Mdot
.36653 .5773 Mdot
.38671 .61622 Mdot
.3136 .57346 Mdot
.51048 .83099 Mdot
.40991 .21738 Mdot
.51602 .36083 Mdot
.45283 .37509 Mdot
.40675 .62545 Mdot
.45615 .21071 Mdot
.82801 .49247 Mdot
.64826 .529 Mdot
.57971 .54155 Mdot
.43586 .64911 Mdot
.36697 .58745 Mdot
.31338 .55048 Mdot
.63912 .46479 Mdot
.53507 .50934 Mdot
.38689 .60179 Mdot
.57971 .52094 Mdot
.62025 .42995 Mdot
.36633 .44194 Mdot
.50929 .29755 Mdot
.35492 .43164 Mdot
.37876 .41318 Mdot
.65978 .32886 Mdot
.24827 .37864 Mdot
.32644 .43252 Mdot
.39319 .41698 Mdot
.6209 .67708 Mdot
.56175 .41346 Mdot
.53328 .73362 Mdot
.80534 .52927 Mdot
.42658 .62511 Mdot
.62605 .49921 Mdot
.53768 .31488 Mdot
.64152 .30177 Mdot
.377 .52213 Mdot
.21396 .63366 Mdot
.58904 .49245 Mdot
.4127 .61636 Mdot
.3484 .57499 Mdot
.5757 .45412 Mdot
.30492 .64281 Mdot
.64187 .4792 Mdot
.45592 .64242 Mdot
.73166 .42257 Mdot
.51158 .5043 Mdot
.26709 .61053 Mdot
.55676 .33899 Mdot
.606 .4727 Mdot
.5194 .3535 Mdot
.36234 .4247 Mdot
.52805 .73566 Mdot
.51787 .74639 Mdot
.6357 .51689 Mdot
.72678 .51896 Mdot
.38506 .49689 Mdot
.65002 .52904 Mdot
.63788 .53027 Mdot
.33917 .5691 Mdot
.64005 .52865 Mdot
.59884 .46778 Mdot
.62103 .4662 Mdot
.64617 .55196 Mdot
.32427 .39076 Mdot
.51013 .51113 Mdot
.66974 .49764 Mdot
.6113 .43191 Mdot
.36611 .44531 Mdot
.44147 .35222 Mdot
.37554 .4244 Mdot
.80096 .37736 Mdot
.34305 .43204 Mdot
.50847 .75073 Mdot
.36005 .60964 Mdot
.65977 .43535 Mdot
.53677 .36439 Mdot
.31618 .39305 Mdot
.50547 .73722 Mdot
.36507 .40997 Mdot
.41569 .60217 Mdot
.52933 .17267 Mdot
.53795 .39148 Mdot
.57259 .72081 Mdot
.28002 .41203 Mdot
.23867 .55966 Mdot
.427 .64495 Mdot
.52361 .31822 Mdot
.75749 .38246 Mdot
.64265 .47302 Mdot
.51598 .70769 Mdot
.62751 .51523 Mdot
.32521 .38862 Mdot
.41846 .61938 Mdot
.72245 .69121 Mdot
.52331 .7396 Mdot
.31957 .24779 Mdot
.42516 .61732 Mdot
.65853 .49304 Mdot
.3517 .38159 Mdot
.40299 .17861 Mdot
.35343 .43427 Mdot
.52439 .629 Mdot
.47565 .3412 Mdot
.59633 .39893 Mdot
.50529 .33465 Mdot
.31504 .52866 Mdot
.64182 .17956 Mdot
.8114 .58869 Mdot
.4951 .31298 Mdot
.27845 .654 Mdot
.58295 .54163 Mdot
.56545 .52622 Mdot
.51833 .52042 Mdot
.476 .33265 Mdot
.58932 .51987 Mdot
.34824 .5732 Mdot
.32942 .30809 Mdot
.31838 .6846 Mdot
.3871 .63645 Mdot
.60837 .4862 Mdot
.36039 .4461 Mdot
.38812 .42018 Mdot
.34343 .55446 Mdot
.37253 .43033 Mdot
.6551 .50744 Mdot
.5043 .3308 Mdot
.41257 .43649 Mdot
.51987 .72713 Mdot
.70632 .75442 Mdot
.53636 .72999 Mdot
.35824 .5825 Mdot
.54147 .48802 Mdot
.40176 .62696 Mdot
.25207 .76381 Mdot
.65221 .4952 Mdot
.48406 .33089 Mdot
.61019 .53318 Mdot
.61444 .4719 Mdot
.56573 .53187 Mdot
.39158 .59777 Mdot
.54045 .78369 Mdot
.58106 .52265 Mdot
.34189 .40528 Mdot
.78944 .58106 Mdot
.56249 .51809 Mdot
.48165 .64354 Mdot
.68361 .67437 Mdot
.22471 .53444 Mdot
.53717 .36956 Mdot
.39291 .62973 Mdot
.49169 .33491 Mdot
.55269 .33252 Mdot
.49658 .34421 Mdot
.77816 .52971 Mdot
.75298 .39523 Mdot
.39325 .82756 Mdot
.65597 .41789 Mdot
.61337 .28785 Mdot
.47814 .29853 Mdot
.40714 .80027 Mdot
.54018 .34978 Mdot
.5057 .35558 Mdot
.85125 .66169 Mdot
.54324 .34873 Mdot
.60204 .49126 Mdot
.55681 .49711 Mdot
.39538 .30967 Mdot
.60145 .68527 Mdot
.64196 .52152 Mdot
.60043 .52654 Mdot
.52729 .72485 Mdot
.72763 .54535 Mdot
.31019 .55103 Mdot
.19054 .46543 Mdot
.4401 .27383 Mdot
.62907 .51628 Mdot
.59324 .52597 Mdot
.56007 .54898 Mdot
.56477 .13238 Mdot
.6704 .31597 Mdot
.48423 .28982 Mdot
.57418 .5719 Mdot
.76331 .69394 Mdot
.65829 .52005 Mdot
.57205 .52398 Mdot
.59584 .54678 Mdot
.40763 .62489 Mdot
.47913 .28961 Mdot
.57157 .56999 Mdot
.2121 .49669 Mdot
.60674 .555 Mdot
.39517 .37002 Mdot
.55587 .79274 Mdot
.6069 .49222 Mdot
.50307 .37355 Mdot
.61444 .53989 Mdot
.53038 .34446 Mdot
.52148 .30697 Mdot
.55788 .54444 Mdot
.79147 .48704 Mdot
.48317 .35161 Mdot
.62385 .5498 Mdot
.39437 .61942 Mdot
.82289 .57406 Mdot
.61191 .49986 Mdot
.50206 .75535 Mdot
.59747 .50379 Mdot
.50609 .76332 Mdot
.63917 .53464 Mdot
.3561 .57239 Mdot
.63528 .25186 Mdot
.42014 .6287 Mdot
.58525 .79203 Mdot
.37415 .5921 Mdot
.28274 .29544 Mdot
.48418 .34756 Mdot
.3442 .57589 Mdot
.19002 .6218 Mdot
.33274 .56618 Mdot
.50341 .52924 Mdot
.48764 .56131 Mdot
.33948 .39244 Mdot
.48563 .30731 Mdot
.66744 .7244 Mdot
.28328 .55137 Mdot
.36121 .62926 Mdot
.36941 .61016 Mdot
.15378 .56409 Mdot
.17458 .56176 Mdot
.58477 .52878 Mdot
.76847 .47796 Mdot
.62175 .37735 Mdot
.56991 .52518 Mdot
.64861 .46289 Mdot
.46114 .62284 Mdot
.59055 .47272 Mdot
.47924 .44115 Mdot
.42597 .64086 Mdot
.5011 .7351 Mdot
.5106 .35423 Mdot
.49753 .75785 Mdot
.31646 .58444 Mdot
.49487 .56573 Mdot
.44241 .61972 Mdot
.63814 .55786 Mdot
.60577 .53253 Mdot
.53019 .32209 Mdot
.51766 .26744 Mdot
.51422 .30022 Mdot
.4929 .70989 Mdot
.42852 .63607 Mdot
.6608 .30179 Mdot
.60538 .5201 Mdot
.50841 .32541 Mdot
.31292 .4557 Mdot
.59875 .52159 Mdot
.36868 .41276 Mdot
.58782 .54848 Mdot
.49282 .31229 Mdot
.64028 .52872 Mdot
.50265 .33115 Mdot
.40893 .6446 Mdot
.65746 .52734 Mdot
.61235 .52366 Mdot
.39487 .18683 Mdot
.51227 .74612 Mdot
.48324 .34549 Mdot
.43089 .4945 Mdot
.65681 .48634 Mdot
.28199 .57689 Mdot
.59741 .47819 Mdot
.49742 .39673 Mdot
.65206 .56074 Mdot
.33919 .57045 Mdot
.61211 .43783 Mdot
.61243 .4989 Mdot
.53665 .58541 Mdot
.67337 .41282 Mdot
.51831 .27301 Mdot
.34471 .38344 Mdot
.4954 .36981 Mdot
.45049 .60417 Mdot
.358 .5852 Mdot
.42558 .59691 Mdot
.58771 .70063 Mdot
.55807 .54333 Mdot
.62274 .48756 Mdot
.30467 .41923 Mdot
.49659 .73321 Mdot
.51142 .31903 Mdot
.49732 .72736 Mdot
.20819 .43277 Mdot
.49579 .70663 Mdot
.34951 .56123 Mdot
.39656 .72433 Mdot
.67633 .29557 Mdot
.52655 .72234 Mdot
.51199 .29887 Mdot
.40154 .74007 Mdot
.58941 .462 Mdot
.50845 .67694 Mdot
.51322 .7294 Mdot
.14221 .54468 Mdot
.58593 .4811 Mdot
.49933 .51114 Mdot
.34705 .43969 Mdot
.50278 .71048 Mdot
.33797 .41579 Mdot
.63949 .52051 Mdot
.2428 .52864 Mdot
.507 .36082 Mdot
.37738 .44525 Mdot
.66588 .48083 Mdot
.49108 .72529 Mdot
.43642 .61792 Mdot
.30953 .37307 Mdot
.32874 .39443 Mdot
.62144 .2262 Mdot
.72389 .6795 Mdot
.42713 .6376 Mdot
.25448 .65955 Mdot
.32957 .41232 Mdot
.56914 .51951 Mdot
.70381 .48514 Mdot
.65469 .49616 Mdot
.33366 .58259 Mdot
.39169 .62873 Mdot
.3551 .3133 Mdot
.60417 .53456 Mdot
.59065 .47902 Mdot
.46978 .34562 Mdot
.41697 .64328 Mdot
.51774 .34005 Mdot
.52064 .37249 Mdot
.40747 .64555 Mdot
.50623 .34073 Mdot
.51029 .70399 Mdot
.34425 .28932 Mdot
.32856 .41284 Mdot
.34495 .40823 Mdot
.41822 .61568 Mdot
.38378 .60801 Mdot
.40178 .62931 Mdot
.58832 .54883 Mdot
.51649 .3183 Mdot
.61438 .54734 Mdot
.57041 .53621 Mdot
.55925 .3385 Mdot
.54593 .34478 Mdot
.60451 .54418 Mdot
.27164 .60425 Mdot
.4818 .69193 Mdot
.38966 .61293 Mdot
.33579 .43742 Mdot
.49055 .22001 Mdot
.31101 .43628 Mdot
.60762 .48388 Mdot
.26679 .43581 Mdot
.49936 .30856 Mdot
.51796 .71297 Mdot
.48 .74993 Mdot
.52313 .72406 Mdot
.30891 .39084 Mdot
.51183 .36818 Mdot
.19136 .46818 Mdot
.61193 .48496 Mdot
.47633 .45743 Mdot
.67862 .71679 Mdot
.21591 .43908 Mdot
.32865 .43434 Mdot
.59749 .52407 Mdot
.3274 .56246 Mdot
.73614 .34872 Mdot
.63743 .47708 Mdot
.62575 .46429 Mdot
.39228 .68522 Mdot
.60142 .42981 Mdot
.47784 .34432 Mdot
.24129 .35742 Mdot
.55703 .50263 Mdot
.55782 .37915 Mdot
.56479 .85673 Mdot
.60618 .47862 Mdot
.58717 .50282 Mdot
.61329 .50884 Mdot
.61716 .53345 Mdot
.4913 .36895 Mdot
.62358 .73087 Mdot
.34891 .38123 Mdot
.47572 .48137 Mdot
.32653 .40851 Mdot
.45368 .64327 Mdot
.49894 .47854 Mdot
.49576 .29811 Mdot
.5187 .71229 Mdot
.68119 .26323 Mdot
.2258 .38881 Mdot
.435 .6424 Mdot
.71308 .35557 Mdot
.51764 .7319 Mdot
.58141 .46404 Mdot
.4915 .75543 Mdot
.36525 .58808 Mdot
.33761 .39983 Mdot
.56114 .48262 Mdot
.53501 .31656 Mdot
.49122 .30715 Mdot
.59239 .51969 Mdot
.77571 .67346 Mdot
.37016 .41476 Mdot
.34874 .45786 Mdot
.58528 .5391 Mdot
.6271 .46435 Mdot
.51603 .34453 Mdot
.39779 .6126 Mdot
.32261 .74196 Mdot
.50662 .7435 Mdot
.6656 .51784 Mdot
.62147 .53277 Mdot
.24532 .37659 Mdot
.37381 .40404 Mdot
.32479 .54819 Mdot
.58689 .53623 Mdot
.27108 .36432 Mdot
.58837 .53709 Mdot
.58351 .44687 Mdot
.39897 .62197 Mdot
.621 .57297 Mdot
.57451 .51711 Mdot
.59012 .58124 Mdot
.33253 .4142 Mdot
.48695 .33911 Mdot
.47909 .3608 Mdot
.31634 .55598 Mdot
.36803 .41401 Mdot
.60778 .54265 Mdot
.37205 .404 Mdot
.56602 .51989 Mdot
.58239 .51975 Mdot
.32734 .43269 Mdot
.51721 .34025 Mdot
.42438 .35994 Mdot
.50739 .50581 Mdot
.61244 .53468 Mdot
.57999 .45607 Mdot
.59622 .69827 Mdot
.25115 .72351 Mdot
.59107 .48975 Mdot
.4916 .31067 Mdot
.60625 .52286 Mdot
.34544 .42123 Mdot
.49596 .70872 Mdot
.49074 .31674 Mdot
.40435 .60749 Mdot
.42002 .65 Mdot
.45181 .22957 Mdot
.34009 .55236 Mdot
.59489 .4531 Mdot
.47976 .37903 Mdot
.54224 .32162 Mdot
.6306 .82143 Mdot
.40398 .64642 Mdot
.52892 .75004 Mdot
.62895 .52387 Mdot
.27511 .43217 Mdot
.30441 .41388 Mdot
.72234 .19734 Mdot
.19072 .47213 Mdot
.53735 .73354 Mdot
.20719 .63146 Mdot
.32878 .55881 Mdot
.57557 .50201 Mdot
.52742 .73978 Mdot
.44483 .63809 Mdot
.57585 .4793 Mdot
.68896 .50574 Mdot
.57283 .73921 Mdot
.4626 .65069 Mdot
.37359 .41056 Mdot
.42865 .59993 Mdot
.48173 .72896 Mdot
.35058 .56288 Mdot
.49715 .30058 Mdot
.61576 .49612 Mdot
.56309 .55757 Mdot
.39894 .60892 Mdot
.35678 .57235 Mdot
.59472 .54895 Mdot
.48279 .31573 Mdot
.41191 .59224 Mdot
.63559 .51295 Mdot
.62222 .27353 Mdot
.55414 .32385 Mdot
.43321 .62878 Mdot
.60106 .4687 Mdot
.57283 .41154 Mdot
.41364 .6116 Mdot
.38894 .60938 Mdot
.58947 .52052 Mdot
.51502 .70528 Mdot
.60096 .55647 Mdot
.34114 .43361 Mdot
.54336 .78394 Mdot
.34511 .41869 Mdot
.46666 .69635 Mdot
.55335 .45728 Mdot
.25038 .55487 Mdot
.51046 .29419 Mdot
.4806 .72922 Mdot
.50408 .20897 Mdot
.61968 .46147 Mdot
.8149 .46179 Mdot
.43148 .42202 Mdot
.74897 .7287 Mdot
.65673 .20923 Mdot
.51005 .7274 Mdot
.36519 .416 Mdot
.5877 .50335 Mdot
.32235 .43886 Mdot
.52193 .74652 Mdot
.68555 .72095 Mdot
.6031 .46725 Mdot
.52373 .32458 Mdot
.60356 .55421 Mdot
.52522 .34747 Mdot
.5981 .5196 Mdot
.60229 .43047 Mdot
.39037 .65638 Mdot
.52825 .63844 Mdot
.58629 .4622 Mdot
.52604 .17014 Mdot
.3942 .51439 Mdot
.51272 .73679 Mdot
.61934 .54891 Mdot
.34102 .56021 Mdot
.38571 .41146 Mdot
.67885 .59896 Mdot
.40444 .62564 Mdot
.33974 .4429 Mdot
.50729 .34674 Mdot
.39864 .64421 Mdot
.35462 .5773 Mdot
.62421 .58096 Mdot
.51189 .76215 Mdot
.34525 .3913 Mdot
.60989 .49654 Mdot
.58677 .48122 Mdot
.29431 .68196 Mdot
.3766 .53829 Mdot
.46674 .30438 Mdot
.34178 .21876 Mdot
.51209 .37991 Mdot
.50376 .7468 Mdot
.39934 .62393 Mdot
.59303 .48743 Mdot
.64527 .49337 Mdot
.35147 .5838 Mdot
.48392 .3453 Mdot
.45725 .64853 Mdot
.68149 .3388 Mdot
.37925 .61747 Mdot
.6449 .70545 Mdot
.48392 .32476 Mdot
.64061 .7079 Mdot
.48179 .73233 Mdot
.7962 .43005 Mdot
.63277 .6482 Mdot
.34888 .44001 Mdot
.64973 .70432 Mdot
.50609 .31156 Mdot
.59286 .5321 Mdot
.32845 .55613 Mdot
.33184 .54747 Mdot
.51305 .35095 Mdot
.44035 .6474 Mdot
.50334 .71171 Mdot
.58447 .50545 Mdot
.21147 .54635 Mdot
.40214 .2731 Mdot
.39723 .60306 Mdot
.6398 .44006 Mdot
.33772 .41073 Mdot
.5765 .50881 Mdot
.49839 .75345 Mdot
.34982 .3942 Mdot
.35575 .55769 Mdot
.34054 .30516 Mdot
.63831 .5174 Mdot
.25682 .35721 Mdot
.36552 .40346 Mdot
.25965 .68815 Mdot
.63151 .50894 Mdot
.32976 .41239 Mdot
.57023 .43578 Mdot
.21926 .45567 Mdot
.43045 .46183 Mdot
.82984 .50774 Mdot
.46108 .65645 Mdot
.43159 .64928 Mdot
.24731 .48495 Mdot
.35416 .63568 Mdot
.34264 .44536 Mdot
.35152 .5644 Mdot
.71085 .62972 Mdot
.33613 .4143 Mdot
.57682 .54046 Mdot
.60019 .47853 Mdot
.65425 .32166 Mdot
.44839 .45617 Mdot
.35507 .56846 Mdot
.38686 .23368 Mdot
.65443 .48387 Mdot
.67748 .52587 Mdot
.64102 .49294 Mdot
.49552 .2881 Mdot
.36042 .3923 Mdot
.43687 .17458 Mdot
.36769 .42187 Mdot
.20706 .56634 Mdot
.42581 .6247 Mdot
.38121 .60719 Mdot
.60628 .48928 Mdot
.25036 .57477 Mdot
.74015 .55994 Mdot
.65571 .5147 Mdot
.28038 .59529 Mdot
.73184 .67156 Mdot
.67085 .48737 Mdot
.47363 .3376 Mdot
.55119 .4998 Mdot
.53048 .28901 Mdot
.32705 .39942 Mdot
.50793 .72047 Mdot
.49724 .68712 Mdot
.34365 .39263 Mdot
.62468 .4883 Mdot
.29232 .60137 Mdot
.62757 .47501 Mdot
.58606 .53218 Mdot
.19124 .54494 Mdot
.53261 .71505 Mdot
.40266 .6332 Mdot
.52021 .74404 Mdot
.50529 .356 Mdot
.92114 .48067 Mdot
.49511 .72758 Mdot
.7022 .4643 Mdot
.61884 .76663 Mdot
.64674 .70725 Mdot
.48958 .30732 Mdot
.49094 .7027 Mdot
.3715 .42035 Mdot
.78 .70461 Mdot
.27166 .74144 Mdot
.33172 .44979 Mdot
.63737 .50612 Mdot
.4991 .29447 Mdot
.52285 .29969 Mdot
.38175 .44397 Mdot
.51558 .30602 Mdot
.53581 .51653 Mdot
.59921 .53673 Mdot
.34034 .4445 Mdot
.39854 .29533 Mdot
.33099 .39265 Mdot
.3264 .29608 Mdot
.61193 .55172 Mdot
.486 .32191 Mdot
.54719 .50973 Mdot
.52502 .39193 Mdot
.31983 .54487 Mdot
.57274 .48317 Mdot
.50929 .70985 Mdot
.46308 .44529 Mdot
.43083 .62907 Mdot
.26966 .44265 Mdot
.5306 .32533 Mdot
.39705 .44504 Mdot
.52166 .30972 Mdot
.49059 .29624 Mdot
.37927 .41378 Mdot
.52301 .3635 Mdot
.58624 .50283 Mdot
.27435 .63456 Mdot
.53268 .34601 Mdot
.35631 .41278 Mdot
.51405 .71732 Mdot
.51013 .34045 Mdot
.46318 .62657 Mdot
.61922 .52521 Mdot
.44235 .61414 Mdot
.39702 .66144 Mdot
.48182 .31303 Mdot
.49338 .70098 Mdot
.38818 .62443 Mdot
.51862 .75723 Mdot
.71111 .71398 Mdot
.31352 .419 Mdot
.21868 .63688 Mdot
.55976 .41951 Mdot
.53597 .31702 Mdot
.39888 .66111 Mdot
.59447 .48911 Mdot
.62045 .52601 Mdot
.48431 .71012 Mdot
.52402 .30028 Mdot
.81283 .59896 Mdot
.47192 .38153 Mdot
.34793 .29366 Mdot
.31207 .4052 Mdot
.35828 .22313 Mdot
.31798 .33012 Mdot
.59893 .80869 Mdot
.65107 .56844 Mdot
.32919 .5586 Mdot
.61914 .48044 Mdot
.5149 .20811 Mdot
.49133 .71829 Mdot
.34553 .77494 Mdot
.57167 .55415 Mdot
.40983 .63572 Mdot
.62027 .51224 Mdot
.5911 .61236 Mdot
.55159 .4879 Mdot
.51821 .70472 Mdot
.3721 .35995 Mdot
.53468 .36523 Mdot
.51941 .72912 Mdot
.41915 .6488 Mdot
.71209 .65169 Mdot
.57854 .47554 Mdot
.64974 .47136 Mdot
.37632 .61182 Mdot
.5226 .3188 Mdot
.4566 .63745 Mdot
.32853 .41242 Mdot
.50114 .72281 Mdot
.62651 .52732 Mdot
.64485 .55967 Mdot
.28662 .58061 Mdot
.35881 .39052 Mdot
.38252 .6188 Mdot
.35755 .43193 Mdot
.32839 .5577 Mdot
.57288 .46589 Mdot
.3807 .60325 Mdot
.57839 .48817 Mdot
.45906 .1938 Mdot
.19531 .55548 Mdot
.6913 .41827 Mdot
.40582 .63779 Mdot
.65553 .68626 Mdot
.35212 .4217 Mdot
.34672 .43234 Mdot
.5808 .3862 Mdot
.71641 .5868 Mdot
.42243 .73474 Mdot
.63302 .22786 Mdot
.32794 .4126 Mdot
.34613 .41526 Mdot
.45092 .62959 Mdot
.52438 .3608 Mdot
.5247 .28881 Mdot
.41493 .65543 Mdot
.53974 .65753 Mdot
.51136 .31919 Mdot
.81341 .47759 Mdot
.45322 .60632 Mdot
.66134 .56354 Mdot
.30463 .55552 Mdot
.50441 .71624 Mdot
.5353 .65045 Mdot
.58863 .6101 Mdot
.58834 .48608 Mdot
.24437 .3463 Mdot
.40167 .61522 Mdot
.60202 .74029 Mdot
.79712 .37139 Mdot
.60733 .46592 Mdot
.62746 .50181 Mdot
.62974 .48718 Mdot
.52782 .70374 Mdot
.53433 .2304 Mdot
.58555 .48696 Mdot
.53854 .66137 Mdot
.66071 .49246 Mdot
.59536 .634 Mdot
.51813 .74653 Mdot
.56092 .29804 Mdot
.44794 .66271 Mdot
.20374 .47759 Mdot
.51877 .51079 Mdot
.33504 .42189 Mdot
.39007 .65081 Mdot
.32842 .40225 Mdot
.77223 .52033 Mdot
.63483 .65011 Mdot
.46881 .3131 Mdot
.58731 .49303 Mdot
.36684 .60293 Mdot
.51408 .29767 Mdot
.2747 .55689 Mdot
.88028 .6161 Mdot
.35501 .38676 Mdot
.27157 .77339 Mdot
.35028 .43324 Mdot
.32334 .54441 Mdot
.51491 .34617 Mdot
.74754 .40056 Mdot
.47664 .45586 Mdot
.50793 .33922 Mdot
.40722 .35356 Mdot
.52313 .38245 Mdot
.65715 .69258 Mdot
.54762 .35845 Mdot
.35611 .41667 Mdot
.30184 .38868 Mdot
.67491 .54271 Mdot
.59864 .49419 Mdot
.49803 .56995 Mdot
.63444 .42154 Mdot
.59591 .49305 Mdot
.42557 .64096 Mdot
.24732 .68283 Mdot
.39703 .65404 Mdot
.53883 .34377 Mdot
.35511 .38407 Mdot
.62623 .50407 Mdot
.60231 .53875 Mdot
.57218 .49664 Mdot
.37632 .189 Mdot
.80995 .49035 Mdot
.58252 .5234 Mdot
.66194 .5295 Mdot
.40858 .64341 Mdot
.50839 .78094 Mdot
.56815 .19435 Mdot
.69196 .63416 Mdot
.64715 .48211 Mdot
.5171 .74389 Mdot
.53502 .73553 Mdot
.57927 .47142 Mdot
.2196 .53943 Mdot
.27148 .63721 Mdot
.60995 .49698 Mdot
.63458 .63577 Mdot
.32712 .59333 Mdot
.34401 .55466 Mdot
.40163 .60937 Mdot
.50844 .37409 Mdot
.35024 .56871 Mdot
.37695 .59026 Mdot
.74243 .38131 Mdot
.31675 .55824 Mdot
.28945 .36401 Mdot
.49281 .71004 Mdot
.64262 .4879 Mdot
.50579 .38033 Mdot
.34304 .58302 Mdot
.33968 .39299 Mdot
.49497 .3249 Mdot
.38679 .41215 Mdot
.53108 .76014 Mdot
.5816 .72388 Mdot
.3286 .54475 Mdot
.33035 .42019 Mdot
.33881 .30544 Mdot
.51738 .7447 Mdot
.37078 .43053 Mdot
.25886 .56185 Mdot
.56087 .52136 Mdot
.77728 .41798 Mdot
.65053 .53241 Mdot
.77626 .68851 Mdot
.3722 .42692 Mdot
.32827 .56823 Mdot
.6198 .48956 Mdot
.42398 .61677 Mdot
.56341 .4453 Mdot
.64425 .48103 Mdot
.41037 .60656 Mdot
.58613 .52935 Mdot
.50375 .75752 Mdot
.548 .30985 Mdot
.42494 .40328 Mdot
.1753 .38276 Mdot
.5108 .76088 Mdot
.27254 .55795 Mdot
.59027 .49054 Mdot
.72355 .68766 Mdot
.51058 .33882 Mdot
.61211 .46355 Mdot
.5722 .33432 Mdot
.524 .35647 Mdot
.49386 .33399 Mdot
.62927 .5368 Mdot
.35402 .43797 Mdot
.43005 .62041 Mdot
.52024 .74146 Mdot
.63935 .80422 Mdot
.64397 .5051 Mdot
.6096 .52338 Mdot
.51826 .73054 Mdot
.34528 .41703 Mdot
.60614 .53876 Mdot
.30933 .48584 Mdot
.70335 .77594 Mdot
.37356 .39529 Mdot
.5637 .53555 Mdot
.73761 .32164 Mdot
.51135 .3896 Mdot
.26147 .75093 Mdot
.47287 .70002 Mdot
.39272 .62736 Mdot
.59894 .43011 Mdot
.80856 .29554 Mdot
.5082 .71874 Mdot
.19766 .47376 Mdot
.58005 .52913 Mdot
.60791 .51543 Mdot
.50531 .30407 Mdot
.61058 .54578 Mdot
.4917 .35218 Mdot
.15455 .44146 Mdot
.27193 .276 Mdot
.52872 .32912 Mdot
.54209 .33547 Mdot
.57788 .39969 Mdot
.55548 .19685 Mdot
.50727 .3511 Mdot
.56833 .54374 Mdot
.80373 .5654 Mdot
.64661 .57664 Mdot
.48489 .70712 Mdot
.40215 .66603 Mdot
.54415 .27356 Mdot
.43049 .57736 Mdot
.44618 .35226 Mdot
.52396 .53005 Mdot
.36575 .49847 Mdot
.33531 .43242 Mdot
.63547 .4706 Mdot
.33602 .54913 Mdot
.40635 .59244 Mdot
.55504 .47588 Mdot
.63903 .48122 Mdot
.52837 .34695 Mdot
.52326 .70144 Mdot
.38325 .42097 Mdot
.60118 .52669 Mdot
.46765 .6365 Mdot
.50199 .73925 Mdot
.53735 .34146 Mdot
.59309 .40091 Mdot
.53177 .7264 Mdot
.60405 .43622 Mdot
.59916 .50652 Mdot
.59289 .54757 Mdot
.55265 .43354 Mdot
.31755 .41141 Mdot
.32235 .58093 Mdot
.57999 .55075 Mdot
.2111 .42776 Mdot
.511 .62211 Mdot
.62668 .56916 Mdot
.51168 .31246 Mdot
.30528 .40773 Mdot
.31927 .54755 Mdot
.70927 .6722 Mdot
.64232 .51248 Mdot
.80792 .49416 Mdot
.67288 .32296 Mdot
.34847 .56843 Mdot
.47523 .30469 Mdot
.51963 .71468 Mdot
.6544 .50594 Mdot
.78966 .54987 Mdot
.60206 .47982 Mdot
.57322 .41546 Mdot
.39359 .61653 Mdot
.33236 .43166 Mdot
.73648 .74565 Mdot
.40289 .59205 Mdot
.49225 .33459 Mdot
.83624 .50289 Mdot
.52215 .29257 Mdot
.52848 .36647 Mdot
.78674 .49845 Mdot
.31933 .41202 Mdot
.79118 .27382 Mdot
.26603 .74171 Mdot
.60514 .56275 Mdot
.34937 .42513 Mdot
.52206 .34506 Mdot
.57694 .5087 Mdot
.54375 .32966 Mdot
.50965 .36469 Mdot
.56871 .49127 Mdot
.60211 .51105 Mdot
.50568 .50586 Mdot
.8118 .42407 Mdot
.52381 .72267 Mdot
.48064 .3301 Mdot
.61158 .29839 Mdot
.58142 .49143 Mdot
.61201 .48555 Mdot
.28525 .56114 Mdot
.5197 .7067 Mdot
.55357 .59091 Mdot
.58653 .53486 Mdot
.26953 .29604 Mdot
.57609 .45831 Mdot
.48 .35689 Mdot
.37434 .3964 Mdot
.21414 .52604 Mdot
.3323 .58143 Mdot
.48015 .33946 Mdot
.49059 .74066 Mdot
.47018 .34364 Mdot
.69161 .45141 Mdot
.32218 .40559 Mdot
.49285 .31226 Mdot
.44588 .65021 Mdot
.34877 .39921 Mdot
.37044 .43005 Mdot
.79042 .57976 Mdot
.38883 .63232 Mdot
.48847 .7171 Mdot
.33528 .40191 Mdot
.6193 .26489 Mdot
.36081 .41457 Mdot
.62685 .3122 Mdot
.65316 .53448 Mdot
.5598 .68917 Mdot
.33264 .33461 Mdot
.58177 .42686 Mdot
.3151 .41209 Mdot
.52273 .7438 Mdot
.62524 .53487 Mdot
.5138 .30508 Mdot
.49587 .72525 Mdot
.36951 .3684 Mdot
.38599 .60855 Mdot
.52695 .31288 Mdot
.3497 .38077 Mdot
.48192 .32995 Mdot
.65484 .72894 Mdot
.55667 .76865 Mdot
.30883 .4721 Mdot
.48345 .47071 Mdot
.57103 .50297 Mdot
.48129 .25167 Mdot
.5875 .45309 Mdot
.63687 .47804 Mdot
.43304 .62817 Mdot
.5875 .70217 Mdot
.51765 .34075 Mdot
.73767 .74764 Mdot
.33024 .42397 Mdot
.24618 .32723 Mdot
.54187 .40606 Mdot
.63695 .46811 Mdot
.53063 .34885 Mdot
.53493 .30322 Mdot
.67695 .41579 Mdot
.41897 .59192 Mdot
.68017 .48466 Mdot
.599 .4433 Mdot
.66634 .55068 Mdot
.37155 .42697 Mdot
.2663 .4542 Mdot
.448 .64441 Mdot
.41043 .8417 Mdot
.39203 .61165 Mdot
.34885 .6739 Mdot
.52625 .36296 Mdot
.49712 .70983 Mdot
.61128 .4874 Mdot
.53329 .41273 Mdot
.47375 .31917 Mdot
.48498 .76228 Mdot
.51106 .70838 Mdot
.2406 .45677 Mdot
.32478 .43073 Mdot
.58556 .46627 Mdot
.59658 .47108 Mdot
.62044 .54626 Mdot
.64252 .54178 Mdot
.35991 .38759 Mdot
.57436 .53594 Mdot
.34848 .44851 Mdot
.63326 .27574 Mdot
.25856 .30257 Mdot
.36215 .59609 Mdot
.69706 .59284 Mdot
.5349 .31968 Mdot
.59815 .25367 Mdot
.67183 .46185 Mdot
.19701 .57191 Mdot
.75021 .66984 Mdot
.62994 .45704 Mdot
.44916 .63712 Mdot
.7206 .56723 Mdot
.36736 .59638 Mdot
.13058 .6152 Mdot
.30986 .60132 Mdot
.82516 .48616 Mdot
.58029 .5016 Mdot
.28653 .56157 Mdot
.67052 .45573 Mdot
.57042 .48283 Mdot
.33075 .61109 Mdot
.35772 .2448 Mdot
.38984 .32439 Mdot
.5342 .73278 Mdot
.62545 .52092 Mdot
.54929 .35371 Mdot
.58499 .50215 Mdot
.61282 .48164 Mdot
.57542 .52533 Mdot
.36576 .38535 Mdot
.55808 .48801 Mdot
.58406 .54754 Mdot
.40138 .54766 Mdot
.62464 .68461 Mdot
.42807 .60049 Mdot
.67382 .42973 Mdot
.49697 .73224 Mdot
.53278 .33884 Mdot
.49063 .42498 Mdot
.34708 .44036 Mdot
.63592 .39678 Mdot
.59395 .55225 Mdot
.3375 .32699 Mdot
.34853 .38067 Mdot
.50006 .71996 Mdot
.31751 .55345 Mdot
.82081 .55481 Mdot
.36277 .5924 Mdot
.31564 .55661 Mdot
.42916 .62931 Mdot
.5543 .25417 Mdot
.52692 .34872 Mdot
.56988 .50331 Mdot
.33661 .40653 Mdot
.43124 .61786 Mdot
.59287 .68517 Mdot
.63869 .49071 Mdot
.41209 .64296 Mdot
.56956 .51049 Mdot
.57135 .71687 Mdot
.29848 .69281 Mdot
.3726 .59422 Mdot
.32015 .37983 Mdot
.35067 .40339 Mdot
.50685 .70326 Mdot
.53443 .33291 Mdot
.50266 .30793 Mdot
.35107 .39509 Mdot
.22411 .69561 Mdot
.64293 .47863 Mdot
.57815 .50356 Mdot
.21354 .42358 Mdot
.59217 .502 Mdot
.69903 .66551 Mdot
.30872 .54536 Mdot
.53662 .33 Mdot
.57645 .51471 Mdot
.6107 .53653 Mdot
.63403 .52077 Mdot
.64896 .73303 Mdot
.39573 .6091 Mdot
.65538 .48934 Mdot
.52735 .72046 Mdot
.31761 .52354 Mdot
.57789 .50018 Mdot
.67084 .53921 Mdot
.50057 .3106 Mdot
.25642 .29133 Mdot
.34424 .43657 Mdot
.43062 .64165 Mdot
.38589 .61876 Mdot
.39237 .66399 Mdot
.55926 .32718 Mdot
.31065 .54939 Mdot
.50414 .82107 Mdot
.33188 .56794 Mdot
.51583 .73779 Mdot
.43634 .69517 Mdot
.4667 .60603 Mdot
.44357 .6348 Mdot
.38983 .42589 Mdot
.60782 .55539 Mdot
.65719 .49593 Mdot
.19351 .48418 Mdot
.65002 .47517 Mdot
.5135 .71313 Mdot
.35782 .44758 Mdot
.50519 .31415 Mdot
.50129 .71553 Mdot
.35281 .43123 Mdot
.52103 .31634 Mdot
.56062 .51368 Mdot
.55957 .52408 Mdot
.49582 .32897 Mdot
.5132 .2983 Mdot
.60583 .49846 Mdot
.34106 .51297 Mdot
.52031 .37348 Mdot
.4881 .31651 Mdot
.33017 .54414 Mdot
.36334 .59496 Mdot
.58077 .57306 Mdot
.35267 .4266 Mdot
.58907 .5445 Mdot
.3652 .59662 Mdot
.51158 .69881 Mdot
.51518 .33594 Mdot
.60778 .53625 Mdot
.59952 .53077 Mdot
.52004 .73963 Mdot
.52937 .71264 Mdot
.50053 .71302 Mdot
.33841 .44857 Mdot
.64025 .53855 Mdot
.50432 .34886 Mdot
.32205 .42499 Mdot
.53491 .73613 Mdot
.49816 .76355 Mdot
.44702 .55909 Mdot
.59287 .48481 Mdot
.4242 .46785 Mdot
.91256 .46716 Mdot
.70499 .64454 Mdot
.31897 .54649 Mdot
.37905 .61918 Mdot
.61697 .71188 Mdot
.2905 .66193 Mdot
.36813 .40417 Mdot
.72619 .60581 Mdot
.48051 .72711 Mdot
.5677 .50674 Mdot
.57889 .45714 Mdot
.64996 .463 Mdot
.50231 .73207 Mdot
.67328 .71287 Mdot
.52046 .2956 Mdot
.59759 .34361 Mdot
.49714 .73176 Mdot
.37283 .59358 Mdot
.37872 .60186 Mdot
.39173 .61206 Mdot
.56254 .48371 Mdot
.66504 .40543 Mdot
.60669 .27083 Mdot
.55888 .2115 Mdot
.33271 .43896 Mdot
.47359 .29331 Mdot
.7122 .70836 Mdot
.49581 .33376 Mdot
.39585 .59071 Mdot
.50408 .73648 Mdot
.49542 .30737 Mdot
.34532 .38855 Mdot
.34459 .41363 Mdot
.39404 .6064 Mdot
.41917 .61696 Mdot
.43904 .61273 Mdot
.51004 .37082 Mdot
.52398 .36335 Mdot
.64606 .51063 Mdot
.50781 .33041 Mdot
.21625 .37572 Mdot
.53606 .71859 Mdot
.37926 .59822 Mdot
.36522 .41903 Mdot
.52718 .34465 Mdot
.64317 .49401 Mdot
.42587 .71291 Mdot
.44106 .23924 Mdot
.51612 .75735 Mdot
.28505 .68028 Mdot
.15442 .64916 Mdot
.5854 .47288 Mdot
.37419 .40982 Mdot
.21995 .56369 Mdot
.63259 .48968 Mdot
.4057 .62239 Mdot
.48356 .19339 Mdot
.35259 .57531 Mdot
.57852 .54088 Mdot
.64629 .47226 Mdot
.37371 .42923 Mdot
.62029 .76934 Mdot
.6486 .50979 Mdot
.29432 .32531 Mdot
.37609 .39147 Mdot
.45299 .61879 Mdot
.70489 .7793 Mdot
.31377 .58007 Mdot
.53991 .65104 Mdot
.33199 .54911 Mdot
.61091 .47212 Mdot
.43105 .63803 Mdot
.52019 .75325 Mdot
.43987 .62559 Mdot
.47122 .3098 Mdot
.43397 .60536 Mdot
.61023 .52212 Mdot
.50465 .35137 Mdot
.36651 .40512 Mdot
.23824 .36035 Mdot
.391 .54962 Mdot
.42298 .61628 Mdot
.32291 .54027 Mdot
.57339 .51218 Mdot
.52343 .56392 Mdot
.54519 .46218 Mdot
.5809 .49632 Mdot
.3256 .40423 Mdot
.53271 .34821 Mdot
.31738 .39658 Mdot
.66518 .54041 Mdot
.33494 .25216 Mdot
.35579 .43431 Mdot
.35567 .34508 Mdot
.51753 .73328 Mdot
.51429 .5919 Mdot
.6466 .49345 Mdot
.33342 .40479 Mdot
.63852 .5401 Mdot
.54671 .34241 Mdot
.4508 .49216 Mdot
.29393 .52783 Mdot
.33802 .40674 Mdot
.80463 .62276 Mdot
.42896 .49974 Mdot
.55007 .52008 Mdot
.32863 .40892 Mdot
.57593 .31666 Mdot
.33234 .55119 Mdot
.50893 .74365 Mdot
.53488 .73473 Mdot
.52135 .75582 Mdot
.62937 .46093 Mdot
.69104 .51284 Mdot
.48741 .73655 Mdot
.38107 .40462 Mdot
.51814 .70397 Mdot
.52277 .43004 Mdot
.81005 .61245 Mdot
.49057 .72963 Mdot
.63351 .5105 Mdot
.67943 .52303 Mdot
.62014 .68472 Mdot
.3936 .58934 Mdot
.81487 .45693 Mdot
.71032 .5505 Mdot
.59927 .49102 Mdot
.66951 .56795 Mdot
.5141 .29517 Mdot
.2345 .58789 Mdot
.62951 .42104 Mdot
.28606 .66456 Mdot
.54207 .35167 Mdot
.34768 .58036 Mdot
.53581 .33242 Mdot
.58129 .47779 Mdot
.58185 .51793 Mdot
.53324 .2941 Mdot
.25784 .40741 Mdot
.23914 .51492 Mdot
.71157 .749 Mdot
.48739 .31437 Mdot
.33254 .41384 Mdot
.35447 .38617 Mdot
.33433 .43895 Mdot
.4496 .60393 Mdot
.47858 .32088 Mdot
.64514 .52973 Mdot
.40643 .64349 Mdot
.63621 .47285 Mdot
.34128 .39941 Mdot
.7441 .73932 Mdot
.50227 .31144 Mdot
.61198 .49823 Mdot
.26884 .73624 Mdot
.41651 .62113 Mdot
.51249 .74795 Mdot
.58024 .73239 Mdot
.45721 .61006 Mdot
.32038 .39959 Mdot
.52795 .29286 Mdot
.40257 .37582 Mdot
.45953 .40894 Mdot
.61831 .57955 Mdot
.60023 .56889 Mdot
.60621 .81568 Mdot
.34775 .54346 Mdot
.58671 .45696 Mdot
.42095 .64884 Mdot
.35303 .58593 Mdot
.61147 .53302 Mdot
.49229 .3034 Mdot
.51552 .76611 Mdot
.5274 .71857 Mdot
.6376 .44726 Mdot
.47698 .46058 Mdot
.51364 .59524 Mdot
.60345 .54315 Mdot
.63553 .43944 Mdot
.38381 .61745 Mdot
.32748 .56672 Mdot
.23584 .3902 Mdot
.48908 .7328 Mdot
.58114 .53235 Mdot
.41716 .32874 Mdot
.51243 .36385 Mdot
.43856 .60959 Mdot
.32213 .40048 Mdot
.66601 .73109 Mdot
.46004 .63405 Mdot
.60888 .53421 Mdot
.60693 .53836 Mdot
.37066 .43108 Mdot
.47953 .35615 Mdot
.50416 .73376 Mdot
.39937 .63615 Mdot
.48866 .73344 Mdot
.50789 .35853 Mdot
.5023 .31491 Mdot
.64762 .57642 Mdot
.63426 .43991 Mdot
.40384 .60838 Mdot
.66943 .52276 Mdot
.38111 .59139 Mdot
.61124 .77899 Mdot
.3167 .3921 Mdot
.58815 .471 Mdot
.49446 .28165 Mdot
.33814 .39828 Mdot
.60802 .5105 Mdot
.59 .83332 Mdot
.62446 .46553 Mdot
.33611 .57984 Mdot
.31059 .26996 Mdot
.52692 .72721 Mdot
.71781 .467 Mdot
.6049 .59487 Mdot
.59189 .5055 Mdot
.38798 .59736 Mdot
.55976 .44769 Mdot
.36507 .4326 Mdot
.53624 .35451 Mdot
.23139 .72923 Mdot
.35909 .41153 Mdot
.582 .5065 Mdot
.50063 .72195 Mdot
.52899 .29633 Mdot
.34864 .5723 Mdot
.20534 .44706 Mdot
.55615 .46327 Mdot
.56421 .5427 Mdot
.58197 .54162 Mdot
.56682 .18735 Mdot
.4343 .63843 Mdot
.52441 .34529 Mdot
.37203 .4253 Mdot
.35499 .3943 Mdot
.39496 .61294 Mdot
.37531 .31696 Mdot
.49654 .58233 Mdot
.85417 .35442 Mdot
.41749 .60785 Mdot
.49738 .69625 Mdot
.49366 .47077 Mdot
.39638 .59317 Mdot
.41564 .64071 Mdot
.38708 .62413 Mdot
.29937 .35432 Mdot
.518 .3165 Mdot
.59676 .5311 Mdot
.53531 .37038 Mdot
.61116 .47118 Mdot
.53707 .62087 Mdot
.3401 .39502 Mdot
.53633 .35623 Mdot
.6044 .82264 Mdot
.50048 .39305 Mdot
.63234 .49667 Mdot
.69065 .73677 Mdot
.53809 .48951 Mdot
.66664 .70036 Mdot
.5426 .52128 Mdot
.42697 .62322 Mdot
.69341 .47256 Mdot
.66685 .54475 Mdot
.22881 .36383 Mdot
.36456 .42105 Mdot
.32111 .54322 Mdot
.60704 .45294 Mdot
.58601 .44658 Mdot
.54889 .33385 Mdot
.49361 .30828 Mdot
.48694 .72868 Mdot
.51164 .6434 Mdot
.36804 .40998 Mdot
.56136 .75572 Mdot
.59952 .49749 Mdot
.26816 .40039 Mdot
.62902 .40943 Mdot
.60913 .50921 Mdot
.8037 .55419 Mdot
.65144 .40138 Mdot
.65205 .50008 Mdot
.57696 .30014 Mdot
.3483 .41756 Mdot
.3077 .27651 Mdot
.64756 .54675 Mdot
.40704 .62402 Mdot
.52863 .35974 Mdot
.50932 .29265 Mdot
.49558 .75274 Mdot
.17206 .53306 Mdot
.31387 .41131 Mdot
.53213 .36057 Mdot
.63346 .48481 Mdot
.31911 .40546 Mdot
.34233 .55483 Mdot
.65556 .55388 Mdot
.73431 .59344 Mdot
.50711 .32691 Mdot
.66234 .52987 Mdot
.39543 .24062 Mdot
.52459 .64709 Mdot
.79369 .33431 Mdot
.33767 .43967 Mdot
.49385 .71779 Mdot
.55184 .54121 Mdot
.50107 .81824 Mdot
.65355 .46901 Mdot
.56469 .6912 Mdot
.56065 .35784 Mdot
.49645 .70845 Mdot
.62553 .49499 Mdot
.63737 .52286 Mdot
.47974 .44949 Mdot
.52743 .70715 Mdot
.61154 .46628 Mdot
.71095 .51275 Mdot
.52266 .3203 Mdot
.31219 .54357 Mdot
.50829 .32189 Mdot
.63685 .5062 Mdot
.68943 .52382 Mdot
.50642 .30215 Mdot
.53374 .80334 Mdot
.48942 .69231 Mdot
.34272 .43717 Mdot
.66133 .45802 Mdot
.64137 .54468 Mdot
.5728 .16839 Mdot
.32001 .54481 Mdot
.52758 .21357 Mdot
.46432 .63664 Mdot
.41995 .34689 Mdot
.2976 .56659 Mdot
.83414 .51653 Mdot
.24372 .36137 Mdot
.59035 .44888 Mdot
.65268 .62391 Mdot
.57959 .27789 Mdot
.31727 .39985 Mdot
.67396 .28551 Mdot
.59841 .49374 Mdot
.61501 .4804 Mdot
.45267 .62538 Mdot
.35463 .31717 Mdot
.22233 .5475 Mdot
.4733 .47296 Mdot
.50787 .73305 Mdot
.49581 .3521 Mdot
.59696 .52127 Mdot
.49523 .60406 Mdot
.42345 .60042 Mdot
.27441 .42646 Mdot
.61714 .49609 Mdot
.20523 .58474 Mdot
.31107 .35208 Mdot
.31735 .41691 Mdot
.3816 .60454 Mdot
.46261 .61626 Mdot
.59873 .47494 Mdot
.32904 .39459 Mdot
.64893 .50641 Mdot
.42205 .51134 Mdot
.66954 .5088 Mdot
.49202 .732 Mdot
.571 .51451 Mdot
.45437 .43881 Mdot
.82182 .39099 Mdot
.71532 .48894 Mdot
.49272 .29826 Mdot
.45271 .60758 Mdot
.39699 .61005 Mdot
.4966 .30862 Mdot
.40012 .61113 Mdot
.61046 .36375 Mdot
.73238 .41225 Mdot
.5116 .73227 Mdot
.65388 .44836 Mdot
.49408 .74395 Mdot
.31849 .54346 Mdot
.59613 .48633 Mdot
.5019 .82408 Mdot
.41809 .61007 Mdot
.40901 .19654 Mdot
.36281 .41247 Mdot
.32023 .54383 Mdot
.66116 .49441 Mdot
.42983 .69243 Mdot
.41555 .59387 Mdot
.3454 .58104 Mdot
.63678 .51891 Mdot
.5073 .30766 Mdot
.63171 .52675 Mdot
.53859 .49658 Mdot
.31543 .55306 Mdot
.60481 .55502 Mdot
.35284 .43115 Mdot
.49535 .36973 Mdot
.82063 .56978 Mdot
.33823 .58268 Mdot
.58961 .48104 Mdot
.63273 .48584 Mdot
.54208 .31776 Mdot
.66259 .51827 Mdot
.34357 .38775 Mdot
.60827 .11649 Mdot
.51765 .73429 Mdot
.35967 .5778 Mdot
.31826 .58193 Mdot
.63586 .45923 Mdot
.61007 .54025 Mdot
.63712 .80783 Mdot
.29216 .51107 Mdot
.33919 .4253 Mdot
.57609 .44348 Mdot
.40683 .64172 Mdot
.50143 .72015 Mdot
.38486 .4173 Mdot
.59436 .5476 Mdot
.61527 .48712 Mdot
.49345 .72659 Mdot
.79465 .58624 Mdot
.28518 .66731 Mdot
.3385 .44211 Mdot
.68723 .46501 Mdot
.41775 .72173 Mdot
.64357 .47967 Mdot
.45513 .74451 Mdot
.49072 .31472 Mdot
.32439 .41389 Mdot
.5624 .20576 Mdot
.5687 .51513 Mdot
.35529 .38902 Mdot
.36806 .41363 Mdot
.61611 .56399 Mdot
.55247 .35612 Mdot
.4998 .36728 Mdot
.48299 .33593 Mdot
.22921 .32233 Mdot
.57112 .64663 Mdot
.43815 .61219 Mdot
.34682 .41722 Mdot
.37011 .59663 Mdot
.52951 .70374 Mdot
.50917 .61273 Mdot
.36891 .58948 Mdot
.517 .29754 Mdot
.37742 .60241 Mdot
.6335 .52372 Mdot
.36647 .40348 Mdot
.44527 .63263 Mdot
.60883 .45492 Mdot
.56625 .59267 Mdot
.40735 .49467 Mdot
.50732 .76753 Mdot
.47506 .72958 Mdot
.58663 .51988 Mdot
.31952 .54802 Mdot
.60657 .49624 Mdot
.34734 .44662 Mdot
.46956 .42592 Mdot
.63153 .45898 Mdot
.41512 .61252 Mdot
.69167 .56129 Mdot
.42673 .59424 Mdot
.56111 .45047 Mdot
.6332 .50896 Mdot
.63053 .47292 Mdot
.64972 .50769 Mdot
.38211 .33903 Mdot
.31139 .40661 Mdot
.58691 .60206 Mdot
.41387 .66163 Mdot
.50316 .33434 Mdot
.48056 .29141 Mdot
.40987 .7399 Mdot
.36447 .57868 Mdot
.35181 .4256 Mdot
.64777 .4873 Mdot
.32296 .5783 Mdot
.75254 .73129 Mdot
.53396 .80603 Mdot
.47794 .75275 Mdot
.43128 .64603 Mdot
.49495 .29492 Mdot
.42321 .59745 Mdot
.60559 .47455 Mdot
.59731 .56323 Mdot
.83254 .53719 Mdot
.31609 .37772 Mdot
.50324 .73537 Mdot
.62561 .47168 Mdot
.53821 .64639 Mdot
.40841 .6433 Mdot
.38527 .62306 Mdot
.626 .46695 Mdot
.48229 .34852 Mdot
.71378 .23363 Mdot
.31662 .4141 Mdot
.70373 .5742 Mdot
.48162 .2677 Mdot
.32539 .27382 Mdot
.34748 .39207 Mdot
.38476 .50094 Mdot
.41706 .6526 Mdot
.73329 .47801 Mdot
.50057 .33063 Mdot
.5005 .73549 Mdot
.60941 .56788 Mdot
.52143 .30222 Mdot
.41326 .65537 Mdot
.53858 .32961 Mdot
.57278 .48895 Mdot
.31479 .40143 Mdot
.39016 .623 Mdot
.30933 .39041 Mdot
.52759 .28835 Mdot
.50928 .75502 Mdot
.50686 .55291 Mdot
.71411 .3174 Mdot
.64616 .39962 Mdot
.65549 .49074 Mdot
.48699 .60383 Mdot
.6388 .53805 Mdot
.55099 .34781 Mdot
.64531 .49797 Mdot
.51413 .24911 Mdot
.38354 .6057 Mdot
.66091 .53221 Mdot
.57633 .53847 Mdot
.67602 .30451 Mdot
.62279 .50344 Mdot
.6089 .55815 Mdot
.653 .49922 Mdot
.50583 .26521 Mdot
.55687 .48301 Mdot
.51401 .31201 Mdot
.20603 .45678 Mdot
.41719 .64001 Mdot
.50866 .76894 Mdot
.53111 .73204 Mdot
.55515 .68078 Mdot
.52587 .63114 Mdot
.36805 .32073 Mdot
.51488 .32447 Mdot
.36265 .42851 Mdot
.64967 .50424 Mdot
.60512 .22023 Mdot
.35657 .63366 Mdot
.40164 .64275 Mdot
.33781 .58135 Mdot
.56394 .42921 Mdot
.56922 .18618 Mdot
.66563 .50623 Mdot
.18738 .47589 Mdot
.6571 .46492 Mdot
.6115 .46391 Mdot
.46057 .61694 Mdot
.52132 .63125 Mdot
.65507 .48685 Mdot
.54844 .33275 Mdot
.50088 .74179 Mdot
.46076 .36503 Mdot
.29604 .63342 Mdot
.36496 .50576 Mdot
.72509 .35825 Mdot
.64738 .53195 Mdot
.39366 .62696 Mdot
.52712 .31355 Mdot
.23965 .38265 Mdot
.3222 .42435 Mdot
.32011 .33712 Mdot
.62883 .28576 Mdot
.648 .77806 Mdot
.50172 .73872 Mdot
.79163 .58378 Mdot
.60857 .52293 Mdot
.44993 .6033 Mdot
.56727 .49686 Mdot
.75657 .72651 Mdot
.49288 .70034 Mdot
.47367 .33066 Mdot
.3335 .41555 Mdot
.5467 .34633 Mdot
.69508 .42167 Mdot
.34379 .48892 Mdot
.46951 .53358 Mdot
.36244 .59073 Mdot
.5517 .59217 Mdot
.51332 .35261 Mdot
.59234 .53961 Mdot
.88095 .39935 Mdot
.48892 .31678 Mdot
.48238 .34193 Mdot
.58921 .78797 Mdot
.58822 .79439 Mdot
.58224 .43425 Mdot
.53962 .32575 Mdot
.37336 .61709 Mdot
.52422 .73532 Mdot
.63744 .52741 Mdot
.64642 .51459 Mdot
.50518 .30473 Mdot
.39262 .59004 Mdot
.71122 .57099 Mdot
.42331 .62011 Mdot
.52441 .32027 Mdot
.4197 .62821 Mdot
.35457 .59777 Mdot
.4344 .64184 Mdot
.6506 .53866 Mdot
.64663 .49945 Mdot
.31946 .67186 Mdot
.50239 .31509 Mdot
.6144 .54159 Mdot
.58225 .52656 Mdot
.50776 .34992 Mdot
.46458 .64091 Mdot
.63016 .23616 Mdot
.58881 .49275 Mdot
.6208 .52255 Mdot
.49461 .71274 Mdot
.4492 .59431 Mdot
.29524 .70661 Mdot
.62571 .53484 Mdot
.50922 .69538 Mdot
.51417 .37117 Mdot
.60716 .49943 Mdot
.52006 .43431 Mdot
.35524 .59208 Mdot
.57027 .52026 Mdot
.3514 .57195 Mdot
.65038 .47127 Mdot
.73986 .27108 Mdot
.58422 .48551 Mdot
.51978 .34497 Mdot
.52545 .35714 Mdot
.60057 .77656 Mdot
.49055 .33503 Mdot
.33298 .54876 Mdot
.34533 .39952 Mdot
.77389 .69794 Mdot
.34504 .55783 Mdot
.61331 .46214 Mdot
.26608 .74204 Mdot
.66003 .54057 Mdot
.61357 .45402 Mdot
.53141 .18463 Mdot
.3468 .56041 Mdot
.52603 .35205 Mdot
.28249 .37613 Mdot
.65228 .45858 Mdot
.32057 .40163 Mdot
.63811 .56795 Mdot
.58394 .55154 Mdot
.28305 .31035 Mdot
.46548 .21574 Mdot
.36676 .445 Mdot
.60871 .58169 Mdot
.62521 .5354 Mdot
.42418 .57035 Mdot
.64041 .48975 Mdot
.49123 .73977 Mdot
.48344 .34175 Mdot
.41189 .59869 Mdot
.521 .72829 Mdot
.59593 .50065 Mdot
.50072 .72998 Mdot
.44032 .61282 Mdot
.32445 .40722 Mdot
.59722 .4796 Mdot
.48781 .70072 Mdot
.50655 .73255 Mdot
.63026 .54221 Mdot
.53332 .35831 Mdot
.68787 .45662 Mdot
.60757 .50228 Mdot
.59547 .53742 Mdot
.50285 .30798 Mdot
.44075 .84972 Mdot
.59112 .47296 Mdot
.42029 .47415 Mdot
.47452 .32521 Mdot
.29983 .55154 Mdot
.4456 .61615 Mdot
.5837 .55245 Mdot
.32583 .39962 Mdot
.3371 .39675 Mdot
.38213 .62789 Mdot
.54692 .33909 Mdot
.40542 .59079 Mdot
.69515 .55295 Mdot
.65073 .45084 Mdot
.64287 .55617 Mdot
.20643 .6823 Mdot
.8259 .53111 Mdot
.49453 .30058 Mdot
.4463 .64609 Mdot
.47615 .47989 Mdot
.34307 .41828 Mdot
.37411 .60996 Mdot
.53109 .29691 Mdot
.4999 .29321 Mdot
.53452 .32002 Mdot
.50089 .7083 Mdot
.45062 .64625 Mdot
.47657 .34845 Mdot
.48477 .35221 Mdot
.63479 .52129 Mdot
.62301 .53706 Mdot
.56046 .38529 Mdot
.65083 .68144 Mdot
.50393 .75569 Mdot
.39599 .61702 Mdot
.49455 .12782 Mdot
.35064 .44707 Mdot
.68054 .30948 Mdot
.62801 .45754 Mdot
.91247 .56275 Mdot
.66592 .50151 Mdot
.63583 .48468 Mdot
.51058 .37333 Mdot
.48255 .71893 Mdot
.49999 .74826 Mdot
.51424 .3539 Mdot
.52369 .28793 Mdot
.48998 .73335 Mdot
.76241 .65557 Mdot
.81008 .61792 Mdot
.28113 .357 Mdot
.51275 .34505 Mdot
.73721 .35077 Mdot
.32301 .3975 Mdot
.53329 .29052 Mdot
.36212 .44214 Mdot
.41317 .63949 Mdot
.41558 .65345 Mdot
.36888 .43249 Mdot
.63924 .5161 Mdot
.44374 .62004 Mdot
.55197 .51347 Mdot
.77996 .64084 Mdot
.781 .46719 Mdot
.26973 .49931 Mdot
.58103 .45525 Mdot
.21855 .53337 Mdot
.23384 .55352 Mdot
.58838 .51182 Mdot
.46527 .39099 Mdot
.502 .73395 Mdot
.53313 .28509 Mdot
.34076 .38853 Mdot
.78486 .32235 Mdot
.6457 .48253 Mdot
.52004 .34044 Mdot
.36198 .42378 Mdot
.60429 .76072 Mdot
.29933 .32004 Mdot
.61582 .47029 Mdot
.82377 .31549 Mdot
.53817 .28446 Mdot
.41263 .59927 Mdot
.2143 .6517 Mdot
.52633 .37488 Mdot
.47347 .70625 Mdot
.42544 .65675 Mdot
.64072 .79498 Mdot
.53251 .33841 Mdot
.41047 .65605 Mdot
.50005 .35345 Mdot
.49477 .74869 Mdot
.55656 .33768 Mdot
.39219 .62888 Mdot
.62371 .49899 Mdot
.40322 .61419 Mdot
.50686 .75671 Mdot
.44057 .59895 Mdot
.33505 .39129 Mdot
.32481 .54648 Mdot
.34816 .4091 Mdot
.52161 .6456 Mdot
.37348 .22471 Mdot
.33264 .43225 Mdot
.58603 .75814 Mdot
.58682 .45631 Mdot
.48412 .36389 Mdot
.41235 .60498 Mdot
.40729 .65851 Mdot
.49835 .53087 Mdot
.50211 .33876 Mdot
.39186 .61653 Mdot
.62268 .27737 Mdot
.347 .80409 Mdot
.69104 .50908 Mdot
.59264 .64308 Mdot
.50752 .34785 Mdot
.38227 .61965 Mdot
.21429 .42252 Mdot
.519 .29711 Mdot
.41909 .60807 Mdot
.33108 .40834 Mdot
.35235 .39288 Mdot
.63894 .47282 Mdot
.28763 .40997 Mdot
.39535 .59994 Mdot
.21909 .47979 Mdot
.50864 .36274 Mdot
.60559 .75678 Mdot
.50521 .76139 Mdot
.41772 .64312 Mdot
.66308 .54957 Mdot
.478 .37201 Mdot
.36034 .60221 Mdot
.70899 .59467 Mdot
.4848 .13576 Mdot
.39572 .6141 Mdot
.48512 .34482 Mdot
.51817 .33654 Mdot
.54192 .47149 Mdot
.47951 .46087 Mdot
.43269 .59829 Mdot
.48354 .82257 Mdot
.57424 .69868 Mdot
.32747 .55745 Mdot
.25789 .57783 Mdot
.6517 .47572 Mdot
.63604 .54318 Mdot
.34133 .41905 Mdot
.6276 .50533 Mdot
.49134 .36272 Mdot
.65857 .49344 Mdot
.36185 .39248 Mdot
.41094 .64959 Mdot
.5986 .48235 Mdot
.52532 .73762 Mdot
.37903 .44306 Mdot
.37154 .43195 Mdot
.42575 .63507 Mdot
.5381 .32315 Mdot
.50905 .67732 Mdot
.41764 .61625 Mdot
.64892 .52882 Mdot
.34468 .56848 Mdot
.57205 .49732 Mdot
.76678 .60043 Mdot
.52834 .3029 Mdot
.40719 .59393 Mdot
.4765 .30271 Mdot
.35237 .41197 Mdot
.41605 .66122 Mdot
.63822 .49926 Mdot
.42327 .61059 Mdot
.29303 .64916 Mdot
.77634 .61609 Mdot
.54746 .33767 Mdot
.2828 .59018 Mdot
.48537 .34869 Mdot
.32545 .55709 Mdot
.7349 .62865 Mdot
.50991 .74086 Mdot
.4059 .63927 Mdot
.82002 .51695 Mdot
.41233 .6101 Mdot
.62017 .50629 Mdot
.60313 .51458 Mdot
.45197 .62856 Mdot
.51641 .70574 Mdot
.26444 .28698 Mdot
.40065 .48402 Mdot
.53042 .34705 Mdot
.73561 .49808 Mdot
.54651 .13683 Mdot
.36612 .38153 Mdot
.34105 .42239 Mdot
.62592 .44458 Mdot
.63576 .46791 Mdot
.37998 .425 Mdot
.35608 .38426 Mdot
.49279 .75331 Mdot
.38982 .62948 Mdot
.55815 .34965 Mdot
.38149 .39778 Mdot
.5409 .55096 Mdot
.52932 .63155 Mdot
.59598 .43468 Mdot
.67584 .5595 Mdot
.55692 .5032 Mdot
.56469 .70341 Mdot
.37372 .40412 Mdot
.58714 .52283 Mdot
.55759 .47133 Mdot
.32734 .41491 Mdot
.49426 .74675 Mdot
.45124 .21795 Mdot
.413 .62724 Mdot
.58119 .85744 Mdot
.57571 .49472 Mdot
.61642 .50425 Mdot
.33114 .43782 Mdot
.41578 .57727 Mdot
.51617 .30206 Mdot
.53601 .31281 Mdot
.43703 .63638 Mdot
.50104 .56126 Mdot
.66031 .51745 Mdot
.58723 .51514 Mdot
.40049 .62891 Mdot
.3241 .54685 Mdot
.24772 .48843 Mdot
.60261 .53007 Mdot
.36126 .42202 Mdot
.39344 .65334 Mdot
.37178 .39888 Mdot
.58049 .47572 Mdot
.61792 .50911 Mdot
.65374 .53573 Mdot
.63401 .46693 Mdot
.36629 .43716 Mdot
.59127 .5235 Mdot
.68276 .51428 Mdot
.54031 .34091 Mdot
.64496 .54049 Mdot
.57132 .70425 Mdot
.63013 .51527 Mdot
.51687 .74991 Mdot
.48909 .62861 Mdot
.62919 .47198 Mdot
.63674 .54644 Mdot
.40358 .4839 Mdot
.62564 .49149 Mdot
.3486 .44649 Mdot
.50726 .33419 Mdot
.3462 .41673 Mdot
.37319 .42506 Mdot
.36795 .60676 Mdot
.49021 .74472 Mdot
.62067 .45146 Mdot
.5238 .75207 Mdot
.65036 .57067 Mdot
.57089 .49248 Mdot
.42699 .67196 Mdot
.18644 .4786 Mdot
.29234 .67169 Mdot
.63935 .50053 Mdot
.42714 .6407 Mdot
.41167 .59733 Mdot
.6681 .61472 Mdot
.55088 .50221 Mdot
.383 .42276 Mdot
.33374 .40496 Mdot
.70234 .65787 Mdot
.2805 .31612 Mdot
.50912 .75442 Mdot
.50026 .6096 Mdot
.56461 .47777 Mdot
.59091 .5322 Mdot
.658 .55095 Mdot
.36911 .59073 Mdot
.31984 .56153 Mdot
.40152 .64301 Mdot
.32365 .5691 Mdot
.36643 .3936 Mdot
.65715 .50049 Mdot
.78995 .44259 Mdot
.49783 .30334 Mdot
.50689 .33344 Mdot
.38265 .41231 Mdot
.39975 .58924 Mdot
.53543 .52485 Mdot
.24606 .75447 Mdot
.50662 .27277 Mdot
.49508 .76096 Mdot
.58613 .50882 Mdot
.42763 .63679 Mdot
.48514 .31305 Mdot
.52233 .70642 Mdot
.57541 .52708 Mdot
.4725 .64325 Mdot
.64256 .5042 Mdot
.57781 .27763 Mdot
.53689 .34693 Mdot
.77042 .71651 Mdot
.52438 .29446 Mdot
.38427 .43853 Mdot
.33243 .42606 Mdot
.60948 .51124 Mdot
.20959 .67472 Mdot
.49481 .37283 Mdot
.29027 .40806 Mdot
.48674 .70947 Mdot
.35137 .57643 Mdot
.49536 .70358 Mdot
.39397 .59352 Mdot
.50192 .74132 Mdot
.38562 .61642 Mdot
.68947 .6606 Mdot
.48778 .27114 Mdot
.51942 .73233 Mdot
.43337 .55954 Mdot
.55902 .48442 Mdot
.53224 .74528 Mdot
.67534 .49337 Mdot
.72934 .47891 Mdot
.40229 .62781 Mdot
.51794 .7075 Mdot
.59531 .53989 Mdot
.78678 .34916 Mdot
.34673 .43234 Mdot
.38102 .42658 Mdot
.55466 .53156 Mdot
.38939 .6301 Mdot
.54246 .3095 Mdot
.46559 .41268 Mdot
.30294 .54933 Mdot
.58788 .51884 Mdot
.65691 .48968 Mdot
.48019 .29115 Mdot
.46697 .29924 Mdot
.61409 .51214 Mdot
.63271 .26595 Mdot
.60232 .52425 Mdot
.3354 .39481 Mdot
.50711 .29516 Mdot
.51412 .3355 Mdot
.39008 .60115 Mdot
.54023 .36067 Mdot
.68596 .55142 Mdot
.4229 .39149 Mdot
.66325 .47358 Mdot
.35746 .40977 Mdot
.45783 .42932 Mdot
.3385 .58171 Mdot
.8075 .42723 Mdot
.49111 .28651 Mdot
.6115 .55531 Mdot
.49753 .35797 Mdot
.50543 .71294 Mdot
.50324 .3178 Mdot
.47935 .31654 Mdot
.60122 .50354 Mdot
.61192 .47204 Mdot
.34579 .56074 Mdot
.4811 .46823 Mdot
.53231 .36263 Mdot
.59264 .51996 Mdot
.65862 .53972 Mdot
.59631 .55856 Mdot
.43732 .47792 Mdot
.49124 .30212 Mdot
.65503 .32452 Mdot
.74119 .57924 Mdot
.53536 .35981 Mdot
.71858 .25141 Mdot
.34731 .57328 Mdot
.36107 .57838 Mdot
.33102 .37447 Mdot
.60215 .5309 Mdot
.45217 .63418 Mdot
.60464 .47509 Mdot
.6683 .56789 Mdot
.61405 .48453 Mdot
.5096 .69773 Mdot
.58957 .4496 Mdot
.33237 .55626 Mdot
.41226 .61372 Mdot
.57857 .50415 Mdot
.60126 .48202 Mdot
.37258 .57785 Mdot
.5104 .28744 Mdot
.52018 .30357 Mdot
.46659 .75311 Mdot
.51156 .72208 Mdot
.32211 .40876 Mdot
.64932 .49752 Mdot
.43022 .6402 Mdot
.40548 .6142 Mdot
.54626 .35398 Mdot
.40759 .62214 Mdot
.32111 .42816 Mdot
.63777 .4956 Mdot
.37967 .42748 Mdot
.52205 .71054 Mdot
.48161 .33462 Mdot
.64936 .4874 Mdot
.63381 .52183 Mdot
.52555 .35696 Mdot
.5855 .45674 Mdot
.49422 .71343 Mdot
.40582 .60939 Mdot
.53174 .32935 Mdot
.34447 .39835 Mdot
.38504 .60057 Mdot
.61842 .53237 Mdot
.47518 .13899 Mdot
.62221 .51133 Mdot
.60804 .53351 Mdot
.82959 .57797 Mdot
.60729 .44189 Mdot
.39859 .60285 Mdot
.47501 .29814 Mdot
.55857 .53191 Mdot
.55946 .66532 Mdot
.52171 .81631 Mdot
.37513 .61801 Mdot
.58436 .50152 Mdot
.81528 .43762 Mdot
.58152 .50144 Mdot
.5603 .75111 Mdot
.35477 .73872 Mdot
.57041 .60549 Mdot
.67005 .56225 Mdot
.35231 .43959 Mdot
.34239 .55693 Mdot
.38391 .60726 Mdot
.58398 .36507 Mdot
.59716 .50929 Mdot
.5663 .28469 Mdot
.57393 .53468 Mdot
.35066 .39177 Mdot
.72457 .4991 Mdot
.39855 .61658 Mdot
.18978 .44853 Mdot
.64534 .53058 Mdot
.4956 .29817 Mdot
.37772 .59895 Mdot
.34764 .57482 Mdot
.60574 .53689 Mdot
.52836 .74224 Mdot
.29766 .40264 Mdot
.66345 .46505 Mdot
.35717 .40508 Mdot
.58187 .5291 Mdot
.63243 .58257 Mdot
.18364 .5963 Mdot
.53822 .34259 Mdot
.3359 .41707 Mdot
.24599 .56852 Mdot
.58263 .45951 Mdot
.53316 .3356 Mdot
.50075 .33191 Mdot
.50486 .75937 Mdot
.46934 .50724 Mdot
.39468 .24939 Mdot
.77181 .38659 Mdot
.67726 .43017 Mdot
.37769 .61293 Mdot
.24573 .53242 Mdot
.63416 .53059 Mdot
.29099 .45425 Mdot
.35895 .44543 Mdot
.619 .50196 Mdot
.64054 .41074 Mdot
.48251 .32959 Mdot
.6156 .52383 Mdot
.49371 .74384 Mdot
.2675 .42966 Mdot
.28744 .45832 Mdot
.62447 .19829 Mdot
.37608 .6217 Mdot
.6332 .56598 Mdot
.68172 .5506 Mdot
.32209 .54071 Mdot
.56537 .51336 Mdot
.4017 .6046 Mdot
.73806 .68371 Mdot
.51017 .70087 Mdot
.48161 .32107 Mdot
.34695 .57338 Mdot
.55555 .51469 Mdot
.63741 .55336 Mdot
.50687 .76872 Mdot
.60782 .55178 Mdot
.17496 .53699 Mdot
.27922 .54781 Mdot
.44515 .62942 Mdot
.53667 .32532 Mdot
.56306 .48316 Mdot
.3165 .55787 Mdot
.60147 .50811 Mdot
.75493 .43682 Mdot
.61822 .55327 Mdot
.37238 .25424 Mdot
.52823 .36037 Mdot
.35468 .40595 Mdot
.61481 .57684 Mdot
.61993 .48207 Mdot
.42186 .71715 Mdot
.65972 .57204 Mdot
.58244 .48654 Mdot
.54602 .32397 Mdot
.49627 .30162 Mdot
.51363 .31311 Mdot
.43057 .6029 Mdot
.26739 .36637 Mdot
.35707 .42026 Mdot
.65691 .47878 Mdot
.38299 .40084 Mdot
.7185 .55176 Mdot
.50293 .76799 Mdot
.7416 .29973 Mdot
.59645 .55363 Mdot
.51655 .32034 Mdot
.42222 .30445 Mdot
.51114 .37065 Mdot
.46397 .65696 Mdot
.36789 .40876 Mdot
.48475 .32298 Mdot
.62859 .48228 Mdot
.46972 .45982 Mdot
.65818 .2308 Mdot
.34204 .41255 Mdot
.67622 .53018 Mdot
.40012 .65252 Mdot
.32727 .58595 Mdot
.54628 .12188 Mdot
.33986 .4268 Mdot
.23889 .55197 Mdot
.59148 .51297 Mdot
.50133 .30236 Mdot
.34074 .43994 Mdot
.34655 .4352 Mdot
.40177 .62421 Mdot
.61715 .4714 Mdot
.63039 .47388 Mdot
.35042 .57272 Mdot
.3346 .40277 Mdot
.5605 .54677 Mdot
.66761 .53404 Mdot
.83308 .53969 Mdot
.56905 .37897 Mdot
.48084 .86045 Mdot
.69819 .54988 Mdot
.66567 .41788 Mdot
.49869 .46168 Mdot
.47722 .32986 Mdot
.62399 .47042 Mdot
.5633 .48847 Mdot
.39305 .60146 Mdot
.63158 .50309 Mdot
.45236 .61399 Mdot
.3487 .42753 Mdot
.70718 .24694 Mdot
.45017 .24324 Mdot
.73381 .68088 Mdot
.6295 .50015 Mdot
.3013 .29472 Mdot
.51701 .71586 Mdot
.37415 .45002 Mdot
.52364 .31537 Mdot
.58231 .46545 Mdot
.41732 .5902 Mdot
.40669 .64055 Mdot
.4938 .32547 Mdot
.21175 .49824 Mdot
.44607 .73569 Mdot
.58073 .47469 Mdot
.44486 .61191 Mdot
.41696 .35698 Mdot
.61974 .25668 Mdot
.39081 .40831 Mdot
.50205 .69854 Mdot
.40325 .64397 Mdot
.37809 .40548 Mdot
.54872 .40045 Mdot
.48674 .3275 Mdot
.47016 .30841 Mdot
.36771 .72132 Mdot
.43377 .59801 Mdot
.52255 .72866 Mdot
.26823 .34975 Mdot
.26339 .34597 Mdot
.50615 .69797 Mdot
.41992 .65302 Mdot
.48988 .30682 Mdot
.52676 .33505 Mdot
.50811 .33512 Mdot
.1956 .43296 Mdot
.54007 .31724 Mdot
.70752 .35015 Mdot
.6546 .54527 Mdot
.52029 .47536 Mdot
.58369 .4993 Mdot
.36711 .43968 Mdot
.53547 .3487 Mdot
.4958 .48429 Mdot
.61664 .46044 Mdot
.6443 .21343 Mdot
.58581 .51675 Mdot
.39402 .41825 Mdot
.61019 .52876 Mdot
.69744 .31081 Mdot
.47462 .32806 Mdot
.6363 .50336 Mdot
.30897 .41914 Mdot
.50638 .72847 Mdot
.55154 .36697 Mdot
.62856 .47224 Mdot
.34721 .31054 Mdot
.62275 .44523 Mdot
.75474 .67345 Mdot
.62917 .73797 Mdot
.49482 .7611 Mdot
.71241 .51384 Mdot
.38469 .62801 Mdot
.5639 .33833 Mdot
.68587 .48016 Mdot
.34241 .41111 Mdot
.44623 .19901 Mdot
.413 .64423 Mdot
.71042 .48036 Mdot
.56444 .44684 Mdot
.49032 .74339 Mdot
.48596 .37519 Mdot
.34535 .44518 Mdot
.60271 .4537 Mdot
.61429 .56364 Mdot
.74454 .66785 Mdot
.67697 .47145 Mdot
.66321 .51325 Mdot
.51848 .76332 Mdot
.66426 .33343 Mdot
.63044 .51847 Mdot
.45879 .65024 Mdot
.47075 .30869 Mdot
.55372 .52747 Mdot
.65345 .32005 Mdot
.59332 .51895 Mdot
.4936 .31573 Mdot
.46555 .31571 Mdot
.40467 .29254 Mdot
.48448 .71835 Mdot
.61745 .55339 Mdot
.65445 .7456 Mdot
.64209 .5367 Mdot
.36281 .41866 Mdot
.5878 .47376 Mdot
.40762 .63734 Mdot
.19444 .46143 Mdot
.42956 .60805 Mdot
.59838 .47294 Mdot
.51113 .33889 Mdot
.35059 .44202 Mdot
.32785 .69296 Mdot
.39072 .74929 Mdot
.70067 .346 Mdot
.60157 .82584 Mdot
.50918 .705 Mdot
.53174 .71203 Mdot
.33282 .44231 Mdot
.63695 .50538 Mdot
.6174 .76619 Mdot
.65067 .45942 Mdot
.61958 .52395 Mdot
.61251 .48437 Mdot
.30052 .45391 Mdot
.34736 .42148 Mdot
.41512 .62258 Mdot
.61637 .51157 Mdot
.59323 .52162 Mdot
.5035 .35842 Mdot
.50757 .73025 Mdot
.42465 .60383 Mdot
.51474 .7305 Mdot
.43298 .62464 Mdot
.73482 .26418 Mdot
.67386 .50987 Mdot
.50637 .72554 Mdot
.35085 .44876 Mdot
.50267 .30751 Mdot
.31158 .55322 Mdot
.3912 .59449 Mdot
.39466 .61658 Mdot
.58829 .51747 Mdot
.49683 .30997 Mdot
.53873 .36035 Mdot
.50709 .71173 Mdot
.32418 .42411 Mdot
.60171 .47329 Mdot
.574 .48176 Mdot
.64081 .61275 Mdot
.37368 .59364 Mdot
.60981 .26502 Mdot
.39428 .3171 Mdot
.63916 .50306 Mdot
.541 .32996 Mdot
.60397 .48745 Mdot
.80297 .46399 Mdot
.51772 .29827 Mdot
.61253 .46436 Mdot
.26763 .31899 Mdot
.3582 .58778 Mdot
.36288 .28316 Mdot
.65096 .54126 Mdot
.65115 .80326 Mdot
.63094 .53634 Mdot
.83718 .48664 Mdot
.36989 .54947 Mdot
.65849 .50209 Mdot
.63289 .52745 Mdot
.76572 .36682 Mdot
.59247 .50308 Mdot
.32422 .55485 Mdot
.72092 .49624 Mdot
.49848 .29291 Mdot
.50217 .49305 Mdot
.47442 .62145 Mdot
.48494 .71052 Mdot
.43766 .63596 Mdot
.27732 .59546 Mdot
.49159 .73299 Mdot
.51354 .34645 Mdot
.65005 .50824 Mdot
.51214 .5797 Mdot
.37481 .625 Mdot
.54517 .46896 Mdot
.36507 .41584 Mdot
.29061 .57906 Mdot
.45765 .6225 Mdot
.34823 .40122 Mdot
.58082 .54503 Mdot
.6581 .2501 Mdot
.33197 .72958 Mdot
.77832 .70092 Mdot
.33744 .44162 Mdot
.34648 .39078 Mdot
.22423 .39909 Mdot
.48935 .70209 Mdot
.75337 .60933 Mdot
.33639 .27594 Mdot
.31667 .40766 Mdot
.71637 .66781 Mdot
.39619 .64082 Mdot
.3361 .3082 Mdot
.53305 .28508 Mdot
.64597 .55572 Mdot
.62628 .48235 Mdot
.32442 .42163 Mdot
.53079 .42649 Mdot
.19417 .61608 Mdot
.34676 .40881 Mdot
.6706 .55443 Mdot
.44694 .51364 Mdot
.33991 .56857 Mdot
.35229 .56739 Mdot
.48462 .73224 Mdot
.47833 .76297 Mdot
.50828 .35758 Mdot
.49319 .7523 Mdot
.28467 .4606 Mdot
.60248 .55318 Mdot
.33873 .40541 Mdot
.31876 .56279 Mdot
.34928 .39554 Mdot
.49552 .74236 Mdot
.49208 .75664 Mdot
.54045 .3396 Mdot
.51739 .30317 Mdot
.65684 .41117 Mdot
.67386 .68898 Mdot
.58016 .50248 Mdot
.54026 .21399 Mdot
.51304 .36458 Mdot
.6961 .48895 Mdot
.51023 .69618 Mdot
.5089 .72573 Mdot
.58592 .29815 Mdot
.65152 .49407 Mdot
.5907 .77762 Mdot
.64875 .49205 Mdot
.72727 .61912 Mdot
.56421 .50786 Mdot
.40445 .62367 Mdot
.65585 .50278 Mdot
.51883 .68334 Mdot
.65026 .47473 Mdot
.58064 .48733 Mdot
.3939 .6358 Mdot
.65724 .45914 Mdot
.4063 .63698 Mdot
.59899 .47145 Mdot
.51941 .69588 Mdot
.43119 .63977 Mdot
.58501 .65521 Mdot
.41889 .4762 Mdot
.3239 .54983 Mdot
.52008 .75044 Mdot
.51208 .76102 Mdot
.53893 .65878 Mdot
.52499 .31708 Mdot
.5187 .39762 Mdot
.6347 .50744 Mdot
.3848 .62188 Mdot
.34317 .42141 Mdot
.59546 .52283 Mdot
.56867 .48705 Mdot
.66285 .52465 Mdot
.48681 .34494 Mdot
.41007 .5911 Mdot
.50206 .72592 Mdot
.44246 .60981 Mdot
.44151 .71374 Mdot
.46081 .63166 Mdot
.55726 .47641 Mdot
.60235 .57019 Mdot
.75308 .5039 Mdot
.50788 .22025 Mdot
.24727 .31895 Mdot
.48906 .32862 Mdot
.34 .55773 Mdot
.49094 .75295 Mdot
.72625 .52034 Mdot
.52099 .31875 Mdot
.39372 .6309 Mdot
.643 .50356 Mdot
.67272 .54306 Mdot
.35584 .36823 Mdot
.56261 .31199 Mdot
.58728 .70414 Mdot
.45708 .61693 Mdot
.3273 .55969 Mdot
.26326 .36777 Mdot
.6488 .42737 Mdot
.50043 .54883 Mdot
.6134 .49416 Mdot
.52941 .73812 Mdot
.48517 .31304 Mdot
.3279 .70633 Mdot
.32724 .40898 Mdot
.47976 .46309 Mdot
.63046 .50007 Mdot
.27616 .37159 Mdot
.50955 .33855 Mdot
.49804 .75087 Mdot
.32445 .42032 Mdot
.48252 .71651 Mdot
.35287 .56744 Mdot
.58696 .80603 Mdot
.62867 .54537 Mdot
.58393 .48693 Mdot
.39075 .42347 Mdot
.50217 .35357 Mdot
.47593 .73437 Mdot
.7663 .63913 Mdot
.44899 .62208 Mdot
.5825 .78048 Mdot
.50121 .37274 Mdot
.72792 .35663 Mdot
.43839 .60727 Mdot
.38242 .41133 Mdot
.53063 .65624 Mdot
.36349 .39318 Mdot
.63534 .473 Mdot
.51547 .32823 Mdot
.35042 .43104 Mdot
.40902 .70936 Mdot
.81592 .40402 Mdot
.73728 .35705 Mdot
.65443 .52321 Mdot
.72957 .28082 Mdot
.79781 .61967 Mdot
.51693 .40997 Mdot
.33425 .39112 Mdot
.60633 .50428 Mdot
.56586 .53214 Mdot
.64821 .52603 Mdot
.36752 .4257 Mdot
.40169 .68111 Mdot
.39471 .62301 Mdot
.58312 .51132 Mdot
.49782 .75716 Mdot
.41086 .63514 Mdot
.38485 .64941 Mdot
.39393 .60554 Mdot
.48725 .29677 Mdot
.62448 .46478 Mdot
.3304 .3402 Mdot
.8324 .40033 Mdot
.34526 .41574 Mdot
.32439 .55009 Mdot
.57282 .50779 Mdot
.33676 .25466 Mdot
.51454 .31444 Mdot
.44978 .62461 Mdot
.61617 .50366 Mdot
.40598 .69018 Mdot
.39054 .58306 Mdot
.39317 .60869 Mdot
.52843 .33141 Mdot
.49549 .40616 Mdot
.62951 .50552 Mdot
.62845 .5394 Mdot
.50678 .35345 Mdot
.50179 .79218 Mdot
.20046 .45388 Mdot
.60244 .48383 Mdot
.35326 .40492 Mdot
.32292 .80663 Mdot
.63193 .55265 Mdot
.57431 .39718 Mdot
.35691 .5776 Mdot
.36715 .31142 Mdot
.60449 .26102 Mdot
.71457 .51073 Mdot
.77442 .37152 Mdot
.51547 .61031 Mdot
.71652 .25655 Mdot
.46481 .68414 Mdot
.39127 .52648 Mdot
.74665 .27707 Mdot
.31239 .42365 Mdot
.51597 .49685 Mdot
.69734 .58368 Mdot
.20049 .48794 Mdot
.51292 .43641 Mdot
.46357 .78978 Mdot
.41027 .72958 Mdot
.47651 .56491 Mdot
.41861 .61068 Mdot
.71673 .61204 Mdot
.60169 .47471 Mdot
.79442 .62795 Mdot
.64549 .27344 Mdot
.19069 .62228 Mdot
.7422 .29285 Mdot
.65858 .74178 Mdot
.6769 .24973 Mdot
.81427 .45765 Mdot
.75393 .51255 Mdot
.48599 .23829 Mdot
.45819 .83741 Mdot
.25822 .35452 Mdot
.6787 .73726 Mdot
.54518 .53404 Mdot
.49627 .60371 Mdot
.70745 .73128 Mdot
.71737 .37927 Mdot
.22597 .69568 Mdot
.403 .5986 Mdot
.47147 .31641 Mdot
.68396 .59587 Mdot
.54302 .37706 Mdot
.39536 .4464 Mdot
.77307 .36524 Mdot
.83049 .49609 Mdot
.69075 .30697 Mdot
.64856 .80788 Mdot
.5994 .369 Mdot
.20769 .33856 Mdot
.41246 .49815 Mdot
.46892 .33384 Mdot
.38684 .79643 Mdot
.26531 .34415 Mdot
.43047 .24494 Mdot
.6969 .55959 Mdot
.37166 .64394 Mdot
.61391 .67501 Mdot
.51922 .34097 Mdot
.60287 .25118 Mdot
.35383 .5636 Mdot
.44745 .22593 Mdot
.4938 .6711 Mdot
.80212 .40676 Mdot
.47977 .55213 Mdot
.33139 .31769 Mdot
.24086 .51479 Mdot
.478 .13817 Mdot
.67862 .70484 Mdot
.79474 .53056 Mdot
.38516 .38595 Mdot
.51547 .42821 Mdot
.20592 .55617 Mdot
.64812 .69966 Mdot
.26639 .33755 Mdot
.4893 .17226 Mdot
.77451 .67744 Mdot
.53878 .16228 Mdot
.53438 .39453 Mdot
.66251 .52281 Mdot
.78434 .51168 Mdot
.68203 .43532 Mdot
.51475 .77493 Mdot
.59455 .18685 Mdot
.52687 .71686 Mdot
.53806 .38832 Mdot
.20817 .4966 Mdot
.70388 .33297 Mdot
.58245 .77071 Mdot
.47709 .71126 Mdot
.58652 .44883 Mdot
.11265 .48953 Mdot
.70723 .25356 Mdot
.39695 .29618 Mdot
.83405 .53815 Mdot
.27566 .38975 Mdot
.61361 .75463 Mdot
.35601 .42943 Mdot
.79811 .33784 Mdot
.52371 .33067 Mdot
.78528 .28702 Mdot
.81308 .37932 Mdot
.24673 .67382 Mdot
.18312 .70653 Mdot
.28653 .48984 Mdot
.57599 .6017 Mdot
.52443 .61603 Mdot
.57923 .67595 Mdot
.19808 .60136 Mdot
.2559 .69668 Mdot
.27264 .38921 Mdot
.66626 .77612 Mdot
.76819 .30736 Mdot
.72598 .64756 Mdot
.61881 .78507 Mdot
.20431 .51655 Mdot
.43003 .47203 Mdot
.46807 .35755 Mdot
.40776 .46253 Mdot
.4999 .2415 Mdot
.58016 .18099 Mdot
.64803 .42239 Mdot
.2548 .76188 Mdot
.49489 .68291 Mdot
.38351 .57231 Mdot
.81504 .56449 Mdot
.59567 .65037 Mdot
.73821 .5184 Mdot
.23948 .39334 Mdot
.56728 .45365 Mdot
.2482 .37918 Mdot
.44078 .33669 Mdot
.28054 .59081 Mdot
.25709 .36956 Mdot
.40336 .35791 Mdot
.75168 .65807 Mdot
.77753 .47613 Mdot
.28278 .30443 Mdot
.50059 .29118 Mdot
.62249 .7127 Mdot
.69418 .69147 Mdot
.82955 .5477 Mdot
.24571 .56771 Mdot
.7951 .68704 Mdot
.24229 .58799 Mdot
.66006 .47307 Mdot
.69257 .51328 Mdot
.54646 .54771 Mdot
.65579 .70689 Mdot
.66248 .53215 Mdot
.27194 .37479 Mdot
.83044 .56581 Mdot
.62438 .40718 Mdot
.30005 .61034 Mdot
.46043 .19375 Mdot
.78118 .68925 Mdot
.77179 .53651 Mdot
.34768 .53357 Mdot
.55257 .42402 Mdot
.26734 .26528 Mdot
.4188 .63345 Mdot
.72131 .66158 Mdot
.32894 .38333 Mdot
.35954 .72331 Mdot
.75708 .36599 Mdot
.24252 .66127 Mdot
.8316 .56901 Mdot
.20775 .4509 Mdot
.28293 .6644 Mdot
.52793 .67194 Mdot
.57225 .77363 Mdot
.48893 .19862 Mdot
.64988 .56587 Mdot
.63409 .59199 Mdot
.52757 .75199 Mdot
.7074 .43134 Mdot
.74702 .58029 Mdot
.39727 .77284 Mdot
.68717 .52458 Mdot
.31249 .73933 Mdot
.32454 .56017 Mdot
.47542 .46143 Mdot
.59451 .14961 Mdot
.5503 .47205 Mdot
.29538 .50179 Mdot
.76488 .6872 Mdot
.61401 .73258 Mdot
.80719 .55001 Mdot
.36072 .34418 Mdot
.52817 .16685 Mdot
.82832 .41384 Mdot
.38948 .75667 Mdot
.67663 .22016 Mdot
.84128 .60759 Mdot
.49734 .16241 Mdot
.55346 .25082 Mdot
.31504 .43432 Mdot
.72588 .20179 Mdot
.43337 .64864 Mdot
.41379 .1999 Mdot
.67077 .42691 Mdot
.36511 .67399 Mdot
.55115 .3266 Mdot
.54376 .45521 Mdot
.48015 .56478 Mdot
.5477 .29307 Mdot
.5526 .51655 Mdot
.52123 .14068 Mdot
.44752 .17572 Mdot
.53539 .14875 Mdot
.73429 .72977 Mdot
.68744 .22743 Mdot
.59357 .61457 Mdot
.7191 .36283 Mdot
.69408 .6041 Mdot
.58484 .47367 Mdot
.69249 .64299 Mdot
.28394 .49319 Mdot
.31851 .71641 Mdot
.41672 .24339 Mdot
.55084 .35605 Mdot
.59621 .20019 Mdot
.48443 .1051 Mdot
.60686 .36181 Mdot
.62525 .32357 Mdot
.2843 .44769 Mdot
.67751 .69207 Mdot
.45002 .30339 Mdot
.28778 .70104 Mdot
.82209 .55837 Mdot
.70548 .57901 Mdot
.72526 .67017 Mdot
.42021 .79016 Mdot
.55424 .75044 Mdot
.43067 .57356 Mdot
.80294 .39145 Mdot
.59285 .62704 Mdot
.24831 .65118 Mdot
.51071 .53034 Mdot
.22027 .65125 Mdot
.43945 .75913 Mdot
.27815 .56592 Mdot
.69441 .70776 Mdot
.33189 .58378 Mdot
.71761 .64491 Mdot
.45107 .508 Mdot
.72575 .57447 Mdot
.51559 .60923 Mdot
.7206 .64068 Mdot
.55331 .74846 Mdot
.60681 .18237 Mdot
.83825 .63731 Mdot
.38638 .18332 Mdot
.6646 .79462 Mdot
.43781 .35228 Mdot
.63352 .55721 Mdot
.81981 .60353 Mdot
.57412 .16019 Mdot
.83619 .43175 Mdot
.22028 .45286 Mdot
.40315 .70125 Mdot
.3763 .44701 Mdot
.38676 .18664 Mdot
.47236 .78031 Mdot
.81669 .49419 Mdot
.25162 .31651 Mdot
.32775 .37528 Mdot
.18673 .48897 Mdot
.41544 .19193 Mdot
.7359 .33653 Mdot
.59241 .27068 Mdot
.5491 .45845 Mdot
.67231 .28418 Mdot
.48349 .29195 Mdot
.2359 .51968 Mdot
.65514 .7007 Mdot
.42402 .63556 Mdot
.57787 .63411 Mdot
.66319 .58603 Mdot
.59092 .44825 Mdot
.47462 .60919 Mdot
.49155 .27927 Mdot
.50496 .22248 Mdot
.39862 .36758 Mdot
.71631 .23541 Mdot
.27347 .50646 Mdot
.63113 .58577 Mdot
.63355 .726 Mdot
.30089 .67195 Mdot
.23163 .39793 Mdot
.31425 .4038 Mdot
.77093 .32736 Mdot
.40209 .45297 Mdot
.62697 .71456 Mdot
.65643 .27144 Mdot
.76195 .6178 Mdot
.59716 .56797 Mdot
.40861 .30995 Mdot
.7437 .44427 Mdot
.48183 .4755 Mdot
.51867 .38577 Mdot
.46525 .2973 Mdot
.71793 .78796 Mdot
.27074 .44801 Mdot
.26423 .55501 Mdot
.77919 .34012 Mdot
.37078 .40741 Mdot
.52288 .36933 Mdot
.70937 .63229 Mdot
.75306 .66382 Mdot
.7295 .41604 Mdot
.40148 .58686 Mdot
.35472 .62724 Mdot
.42188 .77479 Mdot
.73478 .29038 Mdot
.69629 .25973 Mdot
.18605 .62028 Mdot
.54928 .35123 Mdot
.77055 .59498 Mdot
.73009 .67916 Mdot
.49315 .35723 Mdot
.55023 .37837 Mdot
.4249 .22519 Mdot
.6595 .19822 Mdot
.3015 .35019 Mdot
.64907 .79709 Mdot
.5585 .69331 Mdot
.4124 .68772 Mdot
.31471 .68495 Mdot
.65203 .75917 Mdot
.78329 .3491 Mdot
.59378 .2426 Mdot
.71655 .30412 Mdot
.59938 .58069 Mdot
.56562 .29629 Mdot
.36783 .1913 Mdot
.42496 .49068 Mdot
.72274 .34666 Mdot
.42003 .37099 Mdot
.64849 .5316 Mdot
.48014 .13841 Mdot
.7783 .6451 Mdot
.22885 .38153 Mdot
.30136 .42123 Mdot
.6069 .54109 Mdot
.67117 .51271 Mdot
.5507 .41642 Mdot
.38521 .30841 Mdot
.46282 .1828 Mdot
.65522 .75834 Mdot
.45319 .38626 Mdot
.63968 .26737 Mdot
.2954 .50289 Mdot
.80103 .41554 Mdot
.80478 .59726 Mdot
.47039 .49396 Mdot
.27841 .49454 Mdot
.52031 .65346 Mdot
.68091 .77809 Mdot
.49132 .58798 Mdot
.61947 .61327 Mdot
.35296 .25165 Mdot
.3742 .32902 Mdot
.30908 .68729 Mdot
.57106 .5155 Mdot
.21129 .49642 Mdot
.81158 .45371 Mdot
.20917 .68785 Mdot
.20333 .58344 Mdot
.50213 .13128 Mdot
.75795 .42532 Mdot
.36344 .33239 Mdot
.68341 .26507 Mdot
.20261 .69059 Mdot
.48935 .60102 Mdot
.63693 .21667 Mdot
.52322 .66364 Mdot
.75855 .3151 Mdot
.30681 .40332 Mdot
.29985 .32185 Mdot
.45508 .19461 Mdot
.67264 .20959 Mdot
.77889 .54062 Mdot
.78896 .37521 Mdot
.5098 .53569 Mdot
.62786 .17785 Mdot
.35773 .24206 Mdot
.47571 .56767 Mdot
.40041 .65152 Mdot
.23593 .41571 Mdot
.59359 .21795 Mdot
.45922 .27016 Mdot
.72139 .66701 Mdot
.45984 .57223 Mdot
.73114 .51923 Mdot
.69221 .28546 Mdot
.62801 .65082 Mdot
.38786 .33664 Mdot
.63103 .72724 Mdot
.82122 .46365 Mdot
.46878 .58984 Mdot
.32129 .68414 Mdot
.28801 .52294 Mdot
.60242 .8034 Mdot
.38684 .30339 Mdot
.26678 .45093 Mdot
.79498 .52641 Mdot
.46075 .75686 Mdot
.66825 .72987 Mdot
.80455 .72314 Mdot
.66584 .76182 Mdot
.47417 .22834 Mdot
.57304 .18191 Mdot
.81429 .57502 Mdot
.49204 .22574 Mdot
.1893 .58376 Mdot
.57307 .34836 Mdot
.68675 .6606 Mdot
.614 .48373 Mdot
.58179 .15002 Mdot
.62587 .67052 Mdot
.57995 .1785 Mdot
.80531 .64224 Mdot
.6714 .2794 Mdot
.59323 .44619 Mdot
.46595 .62679 Mdot
.36019 .50254 Mdot
.63846 .64507 Mdot
.72723 .31021 Mdot
.57349 .36054 Mdot
.29418 .5674 Mdot
.32231 .53751 Mdot
.45049 .60028 Mdot
.47365 .38165 Mdot
.26375 .4896 Mdot
.38913 .32202 Mdot
.50794 .78544 Mdot
.48672 .53155 Mdot
.69218 .68371 Mdot
.60869 .26194 Mdot
.74302 .34871 Mdot
.23511 .65366 Mdot
.41391 .42009 Mdot
.39857 .6017 Mdot
.77431 .40591 Mdot
.6854 .75157 Mdot
.40647 .34756 Mdot
.51423 .17321 Mdot
.22585 .41608 Mdot
.6921 .6181 Mdot
.74053 .57142 Mdot
.21091 .62773 Mdot
.48313 .82743 Mdot
.55783 .19847 Mdot
.52359 .2413 Mdot
.59282 .77174 Mdot
.66025 .59131 Mdot
.73546 .26578 Mdot
.68903 .72206 Mdot
.75046 .55436 Mdot
.41156 .48557 Mdot
.70628 .38865 Mdot
.65665 .26218 Mdot
.57281 .65138 Mdot
.49767 .52479 Mdot
.21682 .31755 Mdot
.55005 .30925 Mdot
.46144 .13512 Mdot
.32898 .40193 Mdot
.18762 .42723 Mdot
.54597 .76454 Mdot
.44889 .4998 Mdot
.5 .51921 Mdot
.41084 .30085 Mdot
.37129 .25378 Mdot
.70539 .75046 Mdot
.23515 .68087 Mdot
.45804 .6406 Mdot
.62093 .77027 Mdot
.56989 .81217 Mdot
.77091 .37508 Mdot
.55777 .49054 Mdot
.65616 .77339 Mdot
.42626 .48627 Mdot
.3157 .71289 Mdot
.81038 .61494 Mdot
.43244 .31056 Mdot
.66513 .56354 Mdot
.67283 .69378 Mdot
.63496 .21778 Mdot
.82011 .40156 Mdot
.17494 .52024 Mdot
.44053 .33794 Mdot
.32999 .44375 Mdot
.54884 .60507 Mdot
.7438 .3108 Mdot
.59682 .74762 Mdot
.31682 .32597 Mdot
.6874 .70086 Mdot
.36354 .16961 Mdot
.48158 .18137 Mdot
.46174 .18333 Mdot
.62423 .74259 Mdot
.5346 .37721 Mdot
.40472 .21679 Mdot
.74386 .56292 Mdot
.43093 .29916 Mdot
.72113 .72176 Mdot
.71349 .66779 Mdot
.1623 .5963 Mdot
.74421 .50241 Mdot
.44461 .71388 Mdot
.63183 .24535 Mdot
.69057 .4333 Mdot
.30595 .42575 Mdot
.67315 .65961 Mdot
.42815 .37558 Mdot
.38547 .43755 Mdot
.39069 .33335 Mdot
.34849 .30633 Mdot
.7527 .55074 Mdot
.73365 .40693 Mdot
.44059 .37296 Mdot
.78449 .44247 Mdot
.55781 .31232 Mdot
.32877 .70595 Mdot
.30911 .66952 Mdot
.48082 .41911 Mdot
.44388 .63631 Mdot
.71442 .51411 Mdot
.48297 .49157 Mdot
.506 .63136 Mdot
.34811 .21511 Mdot
.5303 .72386 Mdot
.53973 .36771 Mdot
.21188 .38246 Mdot
.49252 .35937 Mdot
.54539 .14044 Mdot
.28087 .69097 Mdot
.65665 .27394 Mdot
.40364 .75535 Mdot
.39215 .78994 Mdot
.14803 .44037 Mdot
.5382 .227 Mdot
.40301 .47864 Mdot
.51543 .2554 Mdot
.53139 .30264 Mdot
.30741 .57562 Mdot
.32544 .53996 Mdot
.59844 .28358 Mdot
.31692 .50384 Mdot
.69205 .61045 Mdot
.47319 .3523 Mdot
.44526 .70034 Mdot
.71097 .47938 Mdot
.67549 .20748 Mdot
.41162 .60662 Mdot
.27099 .2505 Mdot
.67804 .50747 Mdot
.76497 .48451 Mdot
.83254 .58495 Mdot
.17832 .50075 Mdot
.27412 .63744 Mdot
.50896 .82313 Mdot
.6441 .46262 Mdot
.44212 .36928 Mdot
.5224 .34164 Mdot
.7483 .60033 Mdot
.50386 .7403 Mdot
.59937 .70906 Mdot
.38436 .40317 Mdot
.25264 .6542 Mdot
.26024 .49561 Mdot
.51361 .38026 Mdot
.44147 .30656 Mdot
.76535 .55977 Mdot
.31487 .30166 Mdot
.42812 .48377 Mdot
.76739 .37287 Mdot
.72686 .40623 Mdot
.47041 .34561 Mdot
.51331 .18245 Mdot
.72082 .68528 Mdot
.80136 .33551 Mdot
.52954 .52629 Mdot
.4014 .50792 Mdot
.29961 .30153 Mdot
.40436 .3262 Mdot
.60106 .26466 Mdot
.82292 .55441 Mdot
.63514 .70713 Mdot
.27885 .33371 Mdot
.71789 .63953 Mdot
.59012 .43089 Mdot
.47365 .53304 Mdot
.22874 .48964 Mdot
.15126 .54728 Mdot
.56916 .27961 Mdot
.1948 .53403 Mdot
.511 .24804 Mdot
.29367 .50068 Mdot
.54943 .29945 Mdot
.33286 .66839 Mdot
.7188 .38666 Mdot
.26044 .59622 Mdot
.76402 .29133 Mdot
.82416 .55936 Mdot
.33512 .36985 Mdot
.35456 .61272 Mdot
.5084 .46855 Mdot
.56991 .57264 Mdot
.48107 .44641 Mdot
.65915 .49621 Mdot
.53358 .40672 Mdot
.18237 .47697 Mdot
.42266 .30534 Mdot
.54882 .45132 Mdot
.726 .26248 Mdot
.80642 .34696 Mdot
.62039 .17772 Mdot
.5797 .77919 Mdot
.47736 .32251 Mdot
.50233 .15693 Mdot
.6299 .29675 Mdot
.82354 .45689 Mdot
.55149 .20271 Mdot
.74175 .76698 Mdot
.72618 .31262 Mdot
.41623 .36989 Mdot
.25049 .68749 Mdot
.37491 .2639 Mdot
.79409 .63779 Mdot
.47521 .5712 Mdot
.30257 .59691 Mdot
.79372 .64487 Mdot
.12091 .46988 Mdot
.54384 .24317 Mdot
.33987 .31262 Mdot
.66543 .59412 Mdot
.46432 .40555 Mdot
.3652 .52818 Mdot
.58616 .47564 Mdot
.36395 .60873 Mdot
.28804 .66985 Mdot
.69828 .6808 Mdot
.735 .53747 Mdot
.36652 .53055 Mdot
.64507 .64147 Mdot
.7301 .61012 Mdot
.67437 .74311 Mdot
.74578 .34231 Mdot
.60091 .27997 Mdot
.6537 .56971 Mdot
.55843 .34991 Mdot
.4867 .71509 Mdot
.28013 .60973 Mdot
.61258 .4673 Mdot
.26546 .60402 Mdot
.34285 .27552 Mdot
.50635 .13563 Mdot
.31601 .64183 Mdot
.76648 .65276 Mdot
.52541 .2819 Mdot
.39415 .30902 Mdot
.79333 .46078 Mdot
.2029 .4889 Mdot
.38784 .54653 Mdot
.65162 .4235 Mdot
.71808 .26497 Mdot
.25856 .37598 Mdot
.75126 .64453 Mdot
.30942 .25889 Mdot
.3765 .44052 Mdot
.55209 .26451 Mdot
.65645 .6016 Mdot
.21598 .44473 Mdot
.49468 .37995 Mdot
.39303 .35667 Mdot
.4213 .52852 Mdot
.25458 .38259 Mdot
.76614 .68782 Mdot
.76468 .58571 Mdot
.6149 .23635 Mdot
.70225 .26185 Mdot
.37024 .60694 Mdot
.72855 .66693 Mdot
.39281 .35991 Mdot
.39616 .53667 Mdot
.28346 .30963 Mdot
.71899 .24367 Mdot
.4877 .45961 Mdot
.60669 .66977 Mdot
.63301 .5402 Mdot
.65664 .32363 Mdot
.42046 .29742 Mdot
.54494 .71453 Mdot
.27046 .54101 Mdot
.51877 .30005 Mdot
.25425 .51727 Mdot
.4311 .58466 Mdot
.66895 .66994 Mdot
.50061 .26182 Mdot
.58608 .39483 Mdot
.52843 .7626 Mdot
.3046 .5593 Mdot
.5632 .54618 Mdot
.59851 .67933 Mdot
.57906 .76436 Mdot
.55175 .26028 Mdot
.52644 .22593 Mdot
.77002 .38118 Mdot
.74667 .6778 Mdot
.41549 .33858 Mdot
.5486 .19965 Mdot
.38143 .24899 Mdot
.73345 .37989 Mdot
.22467 .54308 Mdot
.66154 .52914 Mdot
.33553 .66915 Mdot
.5195 .37229 Mdot
.75107 .32844 Mdot
.75515 .43171 Mdot
.58646 .65452 Mdot
.45236 .47281 Mdot
.79487 .47782 Mdot
.43946 .45063 Mdot
.82687 .59291 Mdot
.37819 .26255 Mdot
.65344 .70048 Mdot
.33523 .37746 Mdot
.53784 .68034 Mdot
.20586 .61052 Mdot
.79647 .34556 Mdot
.23831 .66277 Mdot
.51354 .57687 Mdot
.19104 .52096 Mdot
.45683 .21454 Mdot
.80158 .6408 Mdot
.66782 .68639 Mdot
.47887 .44494 Mdot
.70575 .47506 Mdot
.36876 .37099 Mdot
.31198 .55266 Mdot
.34994 .68377 Mdot
.61214 .29296 Mdot
.35957 .65144 Mdot
.26208 .61985 Mdot
.56546 .55573 Mdot
.31147 .27292 Mdot
.70806 .26211 Mdot
.73552 .4994 Mdot
.43706 .49991 Mdot
.35522 .73198 Mdot
.65428 .67651 Mdot
.56706 .86867 Mdot
.4785 .1374 Mdot
.63062 .54211 Mdot
.51188 .60505 Mdot
.60845 .70091 Mdot
.45608 .62295 Mdot
.60228 .30707 Mdot
.7674 .36506 Mdot
.34308 .39043 Mdot
.39145 .7001 Mdot
.25414 .39061 Mdot
.41522 .29058 Mdot
.56855 .64012 Mdot
.28861 .43745 Mdot
.52571 .13474 Mdot
.68888 .75438 Mdot
.41334 .32004 Mdot
.62835 .84384 Mdot
.21886 .48167 Mdot
.47244 .28218 Mdot
.78754 .52208 Mdot
.60901 .18202 Mdot
.61885 .73441 Mdot
.36695 .7217 Mdot
.50338 .21017 Mdot
.64588 .70149 Mdot
.73441 .62326 Mdot
.28766 .52252 Mdot
.2588 .52304 Mdot
.45987 .54002 Mdot
.3944 .79049 Mdot
.36846 .21514 Mdot
.61419 .25019 Mdot
.67215 .23732 Mdot
.26622 .65554 Mdot
.16729 .61158 Mdot
.79778 .33712 Mdot
.6759 .6459 Mdot
.35676 .52856 Mdot
.78917 .53645 Mdot
.57282 .69897 Mdot
.63637 .4175 Mdot
.27752 .67941 Mdot
.7212 .41766 Mdot
.36446 .77304 Mdot
.22209 .57638 Mdot
.71863 .64308 Mdot
.67233 .42361 Mdot
.49042 .46699 Mdot
.76622 .38577 Mdot
.2818 .543 Mdot
.64267 .72979 Mdot
.39854 .71053 Mdot
.56097 .67424 Mdot
.77816 .40243 Mdot
.80159 .49839 Mdot
.48594 .44153 Mdot
.12779 .45736 Mdot
.59663 .19283 Mdot
.20743 .51126 Mdot
.65214 .54664 Mdot
.75591 .27804 Mdot
.46782 .4197 Mdot
.53817 .19906 Mdot
.75538 .68635 Mdot
.30744 .65616 Mdot
.30989 .29221 Mdot
.6635 .52115 Mdot
.53751 .21718 Mdot
.72153 .3416 Mdot
.68594 .42908 Mdot
.29305 .67695 Mdot
.63391 .72349 Mdot
.34805 .54458 Mdot
.56032 .65404 Mdot
.55905 .57176 Mdot
.50661 .37381 Mdot
.54934 .14983 Mdot
.52824 .58256 Mdot
.70313 .48809 Mdot
.52715 .45793 Mdot
.23715 .6734 Mdot
.56913 .84253 Mdot
.54581 .55465 Mdot
.26118 .37215 Mdot
.71695 .67003 Mdot
.71516 .59228 Mdot
.53974 .23409 Mdot
.22485 .76542 Mdot
.8385 .57121 Mdot
.53556 .29999 Mdot
.57878 .35939 Mdot
.63016 .74923 Mdot
.63233 .18765 Mdot
.42202 .78917 Mdot
.3006 .6655 Mdot
.24913 .72103 Mdot
.58111 .7168 Mdot
.57049 .4854 Mdot
.75913 .70396 Mdot
.80049 .35498 Mdot
.25622 .65198 Mdot
.74158 .27538 Mdot
.58474 .44514 Mdot
.6712 .52977 Mdot
.40062 .87102 Mdot
.75907 .32597 Mdot
.56875 .45147 Mdot
.22425 .66268 Mdot
.47711 .37038 Mdot
.60973 .47451 Mdot
.30846 .49062 Mdot
.68707 .71965 Mdot
.73138 .61567 Mdot
.67102 .20851 Mdot
.51714 .38303 Mdot
.26579 .61154 Mdot
.37415 .39564 Mdot
.49956 .52318 Mdot
.66845 .5489 Mdot
.36067 .43134 Mdot
.70075 .61826 Mdot
.48185 .42448 Mdot
.29988 .39931 Mdot
.62373 .77782 Mdot
.78675 .70087 Mdot
.75676 .40968 Mdot
.31708 .37262 Mdot
.57538 .42158 Mdot
.73912 .49228 Mdot
.64234 .64377 Mdot
.65758 .61985 Mdot
.7843 .66625 Mdot
.88092 .54235 Mdot
.3156 .60635 Mdot
.52757 .48373 Mdot
.49261 .2666 Mdot
.60755 .27779 Mdot
.72295 .32321 Mdot
.317 .44682 Mdot
.34231 .55537 Mdot
.64448 .45574 Mdot
.55638 .56989 Mdot
.38067 .39596 Mdot
.41749 .15332 Mdot
.57424 .49233 Mdot
.57423 .23883 Mdot
.8194 .44295 Mdot
.32566 .70346 Mdot
.75907 .48651 Mdot
.61686 .45457 Mdot
.38977 .22505 Mdot
.46117 .41594 Mdot
.49605 .41024 Mdot
.31357 .67972 Mdot
.66153 .21583 Mdot
.75607 .4367 Mdot
.60309 .23436 Mdot
.58768 .52112 Mdot
.50899 .69214 Mdot
.33123 .3079 Mdot
.50899 .20322 Mdot
.62594 .58889 Mdot
.82726 .43581 Mdot
.31201 .66206 Mdot
.37005 .6559 Mdot
.7225 .55806 Mdot
.56683 .1684 Mdot
.2069 .569 Mdot
.69995 .30273 Mdot
.2159 .40512 Mdot
.24879 .4418 Mdot
.63045 .6519 Mdot
.46552 .62484 Mdot
.54722 .4518 Mdot
.47867 .36959 Mdot
.55682 .13056 Mdot
.50258 .2022 Mdot
.36676 .36053 Mdot
.28831 .57541 Mdot
.68904 .3277 Mdot
.49888 .48703 Mdot
.68844 .81544 Mdot
.46676 .7898 Mdot
.51952 .13306 Mdot
.74977 .59241 Mdot
.45007 .3415 Mdot
.37414 .34098 Mdot
.69026 .52961 Mdot
.39533 .61032 Mdot
.64202 .19659 Mdot
.54179 .55706 Mdot
.22802 .56425 Mdot
.57132 .48702 Mdot
.23407 .36711 Mdot
.43117 .40159 Mdot
.34946 .60154 Mdot
.34214 .58938 Mdot
.19204 .58599 Mdot
.80673 .46036 Mdot
.45482 .41688 Mdot
.67308 .81168 Mdot
.69756 .27337 Mdot
.77273 .32898 Mdot
.41574 .58921 Mdot
.16493 .50191 Mdot
.47664 .2503 Mdot
.43182 .36725 Mdot
.40167 .37149 Mdot
.53051 .62473 Mdot
.22663 .42188 Mdot
.71418 .59838 Mdot
.3527 .28671 Mdot
.35143 .37002 Mdot
.92137 .53587 Mdot
.69128 .63716 Mdot
.68944 .56489 Mdot
.21593 .50309 Mdot
.7524 .29807 Mdot
.52495 .78334 Mdot
.76788 .70736 Mdot
.49692 .60254 Mdot
.66712 .54577 Mdot
.73934 .42141 Mdot
.74611 .53012 Mdot
.24127 .40977 Mdot
.1718 .37824 Mdot
.699 .7404 Mdot
.33958 .62163 Mdot
.48383 .523 Mdot
.49697 .35957 Mdot
.55055 .32578 Mdot
.39624 .76701 Mdot
.72751 .75497 Mdot
.44781 .39472 Mdot
.74616 .31304 Mdot
.14658 .4641 Mdot
.75298 .61483 Mdot
.64064 .1897 Mdot
.46889 .24513 Mdot
.5567 .3662 Mdot
.65187 .63807 Mdot
.47686 .69072 Mdot
.35229 .58547 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`2Jooooo`;o0000[Oooool001cooooo00?o0000ooooooooool0V_ooool2
o`000:gooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0`_ooool2o`0008Gooooo000Looooo`03o`000?oooooooooo0<;ooooo0_l00025ooooo`007?oo
ool00ol0003oooooooooo`2^ooooo`;o0000VOooool001cooooo00?o0000ooooooooool0[_ooool2
o`0009Wooooo000Looooo`03o`000?oooooooooo09gooooo0_l0002Zooooo`007?ooool00ol0003o
ooooooooo`2Mooooo`Co00004?ooool2o`0009Kooooo000Looooo`03o`000?oooooooooo09;ooooo
0_l0000;ooooo`;o00001?ooool4o`0000Sooooo0_l000000ooooooo0000o`00002Cooooo`007?oo
ool00ol0003oooooooooo`2Booooo`;o00001?ooool4o`0000Gooooo0_l00002ooooo`Co00001Ooo
ool2o`0000Cooooo0_l0002Cooooo`007?ooool00ol0003oooooooooo`2Gooooo`Go00001Oooool2
o`0000?ooooo0_l00005ooooo`?o0000VOooool001cooooo00?o0000ooooooooool0Uoooool2o`00
00gooooo0_l00005ooooo`;o0000V_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`2Zooooo`;o00000oooool2o`0000Sooooo0_l00002ooooo`;o0000
R_ooool001cooooo0_l00025ooooo`;o00009?ooool2o`0000?ooooo0_l00008ooooo`;o00000_oo
ool2o`0008[ooooo000Looooo`03o`000?oooooooooo08Cooooo0_l00033ooooo`007?ooool00ol0
003oooooooooo`2Oooooo`;o0000Z?ooool001cooooo00?o0000ooooooooool0W_ooool3o`0000[o
oooo0_l0000:ooooo`;o0000T?ooool001cooooo00?o0000ooooooooool0OOooool2o`0001oooooo
0_l0000;ooooo`;o00002_ooool2o`00093ooooo000Looooo`03o`000?oooooooooo07gooooo0_l0
000Yooooo`;o00002_ooool6o`0008oooooo000Looooo`03o`000?oooooooooo07;ooooo0_l0000W
ooooo`;o00002_ooool3o`0000;ooooo0_l00006ooooo`Ko0000Soooool001cooooo00?o0000oooo
ooooool0L_ooool2o`0001Kooooo0_l0000?ooooo`;o00001_ooool2o`0000;ooooo0ol00002oooo
o`;o0000Voooool001cooooo00?o0000ooooooooool0P_ooool2o`0000Kooooo0_l00002ooooo`;o
00004oooool2o`0000?ooooo0_l0000Dooooo`;o00001_ooool4o`0007oooooo000Looooo`03o`00
0?oooooooooo07oooooo0_l000000ooooooo0000o`00000:ooooo`;o00002Oooool2o`0001kooooo
0_l00003ooooo`;o00001_ooool4o`0000?ooooo0_l0001jooooo`007?ooool00ol0003ooooooooo
o`1jooooo`;o00000oooool2o`00017ooooo0ol00004ooooo`;o00002?ooool2o`0000Cooooo0_l0
000;ooooo`;o000000?oooooo`000?l000001_ooool3o`0000Wooooo0_l0001jooooo`007?ooool0
0ol0003oooooooooo`1jooooo`;o000000?oooooo`000?l000002oooool2o`0000Kooooo0ol0000>
ooooo`;o00001?ooool2o`0000Wooooo1?l00005ooooo`;o00000_ooool3o`0000Kooooo1?l0001k
ooooo`007?ooool00ol0003oooooooooo`1gooooo`;o000000Coooooo`000?l0003ooooo0_l0000;
ooooo`;o00008?ooool2o`0000Kooooo0ol00006ooooo`;o00002oooool4o`0007_ooooo00001_oo
ooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003ooooooooo
o`1dooooo`;o000000?oooooo`000?l000002_ooool2o`0000?ooooo0_l00007ooooo`?o00001Ooo
ool2o`00017ooooo0_l0000@ooooo`;o00003?ooool2o`0007_ooooo00001_ooooooMgMgoiRHV?oo
ooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`1dooooo`;o00002oooool4o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l0
00000_l00005ooooo`;o00004Oooool2o`0000?ooooo0_l00002ooooo`;o00001oooool2o`0000go
oooo0_l0001jooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0J_ooool2o`0001Gooooo1?l00008ooooo`;o0000
00?oooooo`000?l000002Oooool2o`0000kooooo1Ol000000ooooooo0000o`000002ooooo`;o0000
4?ooool2o`0000Cooooo0_l00003ooooo`;o00004oooool2o`00063ooooo00000ooooooo0000oooo
o`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0005gooooo0_l0
0007ooooo`;o00000_ooool2o`0000Gooooo0_l0000>ooooo`Co00001oooool3o`0000cooooo0_l0
0002ooooo`?o00002Oooool2o`000003ooooool0003o000000?o000000?oooooo`000?l000002?oo
ool2o`0000Oooooo0_l00009ooooo`;o00004oooool3o`0005oooooo00000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`1M
ooooo`;o00001oooool2o`0000Wooooo0_l0000Iooooo`;o00004Oooool5o`0000_ooooo0_l00002
ooooo`?o00002?ooool2o`0002Sooooo0_l0001Oooooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0X?ooool5o`00
00kooooo0_l0000Mooooo`;o00000_ooool4o`0000oooooo0_l0001Nooooo`0000KoooooogMgMonH
V9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003ooooooooo
o`21ooooo`;o00002?ooool2o`0000?ooooo0_l0000>ooooo`;o000000?oooooo`000?l000003Ooo
ool2o`0001kooooo0_l00002ooooo`Co00003oooool2o`0005kooooo00001_ooooook^k^oc8b<_l0
003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo06go
oooo0_l00005ooooo`;o00002oooool3o`0000Oooooo0_l00003ooooo`?o00003Oooool2o`0000Ko
oooo0_l000001?oooooo0000o`000?l00004ooooo`;o00006_ooool2o`0000Oooooo0_l0001`oooo
o`007?ooool00ol0003oooooooooo`1]ooooo`;o00001Oooool3o`0000;ooooo0_l00005ooooo`Co
00002oooool6o`0001?ooooo0_l000001?oooooo0000o`000?l0000?ooooo`;o00000oooool2o`00
00Kooooo0ol000000ooooooo0000o`000002ooooo`?o0000M?ooool001cooooo00?o0000oooooooo
ool0Joooool2o`0000Sooooo0_l00002ooooo`;o00000_ooool2o`000004ooooool0003o0000o`00
00;ooooo0_l00008ooooo`?o000000?oooooo`000?l000001oooool2o`0000;ooooo0ol00007oooo
o`?o000000?oooooo`000?l000003Oooool2o`0000;ooooo0ol00006ooooo`?o00001Oooool3o`00
00?ooooo0_l0001_ooooo`007?ooool00ol0003oooooooooo`1[ooooo`;o00001?ooool2o`0000[o
oooo0_l00006ooooo`;o00000oooool2o`0000Cooooo0_l0000:ooooo`;o00000_ooool3o`0000Oo
oooo0_l00002ooooo`;o00004Oooool2o`0001Gooooo0_l0001_ooooo`007?ooool00ol0003ooooo
ooooo`1_ooooo`Co00000oooool2o`0000?ooooo0_l00009ooooo`;o00000_ooool2o`0000;ooooo
0_l0000<ooooo`;o00000_ooool3o`0000Cooooo0_l00002ooooo`;o00006Oooool2o`0001Cooooo
0_l0001[ooooo`007?ooool00ol0003oooooooooo`1_ooooo`;o00000oooool4o`0000?ooooo0_l0
0009ooooo`;o00001_ooool4o`0000Cooooo0_l00004ooooo`;o00002Oooool2o`000004ooooool0
003o0000o`0001Wooooo0_l00002ooooo`;o00001_ooool2o`0000Cooooo0_l00002ooooo`;o0000
Joooool001cooooo00?o0000ooooooooool0L_ooool4o`0000Cooooo0_l0000Cooooo`Co00000ooo
ool2o`0001;ooooo0_l0000Aooooo`;o00002oooool2o`0000Kooooo0_l00004ooooo`;o00002_oo
ool2o`0006?ooooo000Looooo`03o`000?oooooooooo07;ooooo0_l00006ooooo`;o00005Oooool2
o`0001Wooooo0_l0000?ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l0000I
ooooo`?o0000H_ooool001cooooo00?o0000ooooooooool0S?ooool2o`0000cooooo0_l0000@oooo
o`;o00002Oooool2o`0000Oooooo0_l00002ooooo`;o00000oooool3o`0000_ooooo0_l0000<oooo
o`;o0000H_ooool001cooooo00?o0000ooooooooool0L?ooool2o`0000_ooooo0_l0000=ooooo`;o
00003?ooool2o`0000?ooooo0_l00005ooooo`;o00001Oooool2o`0000Sooooo0_l00004ooooo`;o
00001Oooool2o`0000Cooooo0_l0000;ooooo`;o00001oooool2o`0006Oooooo000Looooo`03o`00
0?oooooooooo073ooooo0_l0000;ooooo`;o00001Oooool2o`0000;ooooo0_l00004ooooo`;o0000
1Oooool2o`0000Gooooo0_l000000ooooooo0000o`000005ooooo`;o00001Oooool2o`0000kooooo
0_l00005ooooo`;o00000oooool2o`0001Gooooo0_l00004ooooo`;o0000HOooool001cooooo00?o
0000ooooooooool0I?ooool2o`0000[ooooo0_l00004ooooo`Co00002_ooool2o`0000;ooooo0_l0
0004ooooo`;o00001Oooool2o`0000Gooooo0_l00004ooooo`?o00009?ooool2o`0001Oooooo0_l0
0002ooooo`;o0000HOooool001cooooo0_l0001Eooooo`;o00003_ooool2o`0000?ooooo0_l00004
ooooo`;o00001Oooool4o`0000;ooooo0_l0000Iooooo`Co00001oooool3o`0000_ooooo0_l0000>
ooooo`;o00000_ooool2o`0000Gooooo0_l00005ooooo`;o00001?ooool2o`0000Sooooo1_l0001Q
ooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o00004oooool3o`0000?ooooo0ol00003oooo
o`Co00000_ooool3o`0001Wooooo1?l00007ooooo`Co00002_ooool2o`0000gooooo0ol00002oooo
o`;o00001Oooool2o`0000Gooooo1?l00002ooooo`;o00002?ooool6o`00067ooooo000Looooo`03
o`000?oooooooooo06Sooooo1?l00004ooooo`;o00000oooool4o`0000;ooooo0_l0000Aooooo`;o
00004_ooool4o`0000[ooooo0_l0000=ooooo`;o00001Oooool2o`0000cooooo0_l0000<ooooo`;o
000000?oooooo`000?l00000H_ooool001cooooo00?o0000ooooooooool0HOooool2o`0000Gooooo
0_l0000Tooooo`;o00005Oooool2o`0000Sooooo0_l0000@ooooo`;o00000oooool2o`0001Kooooo
0_l00005ooooo`;o0000H_ooool001cooooo00?o0000ooooooooool0HOooool2o`0000Gooooo0_l0
000<ooooo`?o00009_ooool2o`0000Cooooo0_l00008ooooo`?o00003Oooool5o`0000;ooooo0_l0
000:ooooo`;o00001Oooool2o`0000?ooooo1_l00004ooooo`;o000000?oooooo`000?l00000G?oo
ool001cooooo00?o0000ooooooooool0Doooool2o`0001?ooooo0_l000000ooooooo0000o`000005
ooooo`;o00000_ooool3o`0000Oooooo0_l0000Gooooo`[o000000?oooooo`000?l000000_ooool2
o`0000Kooooo0_l0000<ooooo`?o000000Coooooo`000?l0003ooooo0ol00002ooooo`Co00001?oo
ool2o`0000Cooooo1?l00004ooooo`Co000000Coooooo`000?l0003ooooo0_l000000ooooooo0000
o`00001Looooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00003?ooool2o`0000Cooooo0ol0
00000ooooooo0000o`000005ooooo`;o00003?ooool3o`0000;ooooo0_l0000:ooooo`;o00001_oo
ool7o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000Kooooo0_l0000;ooooo`?o0000
00Goooooo`000?l0003o0000ooooo`03o`0000;ooooo1?l0000:ooooo`Co00002Oooool2o`0000Co
oooo0_l0001Looooo`007?ooool00ol0003oooooooooo`1Mooooo`?o000000?oooooo`000?l00000
0oooool4o`0001Gooooo1?l000001?oooooo0000o`000?l00004ooooo`;o00001?ooool2o`0000?o
oooo0_l00003ooooo`;o00001?ooool2o`0000;ooooo0_l00006ooooo`?o00003Oooool2o`0000;o
oooo0_l00003ooooo`;o00001_ooool2o`000004ooooool0003o0000o`0000_ooooo0_l0000<oooo
o`;o00003_ooool2o`0004[ooooo000Looooo`03o`000?oooooooooo05Gooooo0_l00006ooooo`Ko
00000oooool2o`0000;ooooo1?l0000Aooooo`;o00000oooool2o`0000Gooooo0_l00009ooooo`;o
00000oooool2o`0000;ooooo1?l00002ooooo`;o00001_ooool3o`0001Kooooo0_l00002ooooo`;o
00000_ooool2o`000004ooooool0003o0000o`0000_ooooo0_l0000<ooooo`;o00003_ooool2o`00
04[ooooo000Looooo`03o`000?oooooooooo05Gooooo0_l00009ooooo`;o00002?ooool4o`0002ko
oooo0_l000001?oooooo0000o`000?l00004ooooo`Co00001?ooool2o`0000Gooooo0_l000000ooo
oooo0000o`000005ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l0000:oooo
o`;o00005Oooool4o`000003ooooool0003o000005Gooooo000Looooo`03o`000?oooooooooo07;o
oooo0_l00009ooooo`;o00005oooool2o`0000Cooooo1_l00004ooooo`Co00001_ooool2o`0000?o
oooo0_l000000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l000000_ooool2o`0000ko
oooo0_l0000;ooooo`;o00001?ooool2o`0000;ooooo1?l000000ooooooo0000o`00001Eooooo`00
7?ooool00ol0003oooooooooo`1booooo`;o00002Oooool2o`0001Oooooo0ol00004ooooo`Go0000
1Oooool6o`0000?ooooo0_l00002ooooo`;o00002Oooool2o`0000Gooooo1?l0000=ooooo`;o0000
1?ooool2o`0000Cooooo0_l00004ooooo`Ko0000F_ooool001cooooo00?o0000ooooooooool0D_oo
ool2o`0000Oooooo0_l000000ooooooo0000o`00000<ooooo`;o000000?oooooo`000?l000009_oo
ool2o`0000?ooooo2?l00002ooooo`Oo00001oooool2o`0000Wooooo0_l00002ooooo`;o00000ooo
ool2o`0000gooooo0_l00004ooooo`;o00003?ooool2o`0000kooooo0_l0001<ooooo`007?ooool0
0ol0003oooooooooo`1@ooooo`Ko00001Oooool5o`000003ooooool0003o000000Wooooo0_l00000
0ooooooo0000o`00000Booooo`?o00004_ooool<o`0000;ooooo1Ol00009ooooo`;o00003Oooool2
o`0000oooooo0_l000000ooooooo0000o`00000Booooo`;o00001oooool2o`0000Gooooo0_l0001<
ooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00000_ooool2o`0000;ooooo2?l000000ooo
oooo0000o`00000:ooooo`;o00003_ooool5o`000004ooooool0003o0000o`00013ooooo1_l00000
0ooooooo0000o`000006o`000003ooooool0003o000000?o00000oooool2o`0001?ooooo0_l0000:
ooooo`;o00000oooool4o`0001?ooooo1?l00005ooooo`;o00003Oooool2o`0004Cooooo000Loooo
o`03o`000?oooooooooo04gooooo0_l00005ooooo`;o00000_ooool3o`0000?ooooo1?l00004oooo
o`;o00001Oooool2o`0000kooooo1Ol00003ooooo`?o00001oooool2o`0000;ooooo0_l000000ooo
oooo0000o`000002o`000003ooooool0003o000000ko00000oooool2o`0000;ooooo1?l00005oooo
o`;o00001_ooool2o`0000Cooooo0_l00004ooooo`;o00001Oooool4o`0001?ooooo0_l00002oooo
o`;o00004?ooool2o`0004Cooooo000Looooo`;o0000C_ooool2o`0000Gooooo0_l00008ooooo`[o
00005Oooool2o`0000?ooooo0_l000000ooooooo0000o`000003o`0000Gooooo0_l00002ooooo`?o
000000?oooooo`000?l000002?l000000ooooooo0000o`00000:o`000004ooooool0003o0000oooo
o`Co00000_ooool2o`000003ooooool0003o000000Kooooo0_l00004ooooo`;o00003Oooool2o`00
01?ooooo0_l00002ooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0D?ooool2o`0000Ko
oooo0_l00004ooooo`;o00000_ooool5o`0001?ooooo0_l00006ooooo`;o000000Coooooo`000?l0
003ooooo0_l00004ooooo`;o00001?ooool2o`000003ooooool0003o000001Go000000?oooooo`00
0?l000001oooool3o`0001;ooooo0_l00004ooooo`;o00000oooool2o`0000Kooooo0_l000000ooo
oooo0000o`000002o`0000Kooooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o
00001_ooool2o`00013ooooo1Ol0000;ooooo`;o00002Oooool3o`0000Cooooo1?l00004ooooo`;o
000000?oooooo`000?l000004ol0000=ooooo`;o00001Oooool2o`0000;ooooo0_l00007ooooo`;o
00001?ooool2o`0000?ooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo1?l0000?oooo
o`;o0000DOooool001cooooo00?o0000ooooooooool0F?ooool2o`0000gooooo2?l0000:ooooo`;o
000000Coooooo`000?l0003o00000_ooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool2
o`0000?ooooo0_l00002ooooo`;o00000_oooolHo`0000oooooo0_l000001?oooooo0000o`000?l0
000Cooooo`;o00000_ooool4o`0000Oooooo0_l00004ooooo`;o00001_ooool2o`00057ooooo000L
ooooo`03o`000?oooooooooo05Sooooo0_l0000=ooooo`So000000?oooooo`000?l000000_ooool2
o`0000?ooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00001?ooool4o`0000?ooooo0_l0
00000ooooooo0000o`000002ooooob3o00003_ooool2o`0000?ooooo0_l0000=ooooo`Co00001?oo
ool2o`0000Oooooo0_l00004ooooo`?o00005Oooool2o`00047ooooo000Looooo`03o`000?oooooo
oooo04kooooo0_l00007ooooo`;o00004_ooool2o`0000?ooooo0_l00002ooooo`Co00001?ooool2
o`0000Wooooo0_l00004ooooo`?o00000ooooolJo`0000Cooooo1?l000001?oooooo0000o`000?l0
000?ooooo`;o00003?ooool3o`0000oooooo0_l00005ooooo`;o00000_ooool2o`00017ooooo1?l0
00000ooooooo0000o`00000looooo`007?ooool00ol0003oooooooooo`13ooooo`;o00002?ooool3
o`0000?ooooo0_l00002ooooo`;o00001Oooool2o`0000Sooooo0_l00005ooooo`;o00001Oooool2
o`000004ooooool0003o0000ooooo`;o00001Oooool2o`0000Sooooo0_l00004oooooaKo000000?o
ooooo`000?l000000_l00008ooooo`?o00005oooool2o`0000Cooooo0_l000000ooooooo0000o`00
0009ooooo`;o00003Oooool2o`00017ooooo1?l000000ooooooo0000o`00000looooo`007?ooool0
0ol0003oooooooooo`13ooooo`;o00000_ooool2o`0000Cooooo0_l00004ooooo`;o00002Oooool2
o`0000Sooooo0_l00005ooooo`;o00000oooool2o`0000?ooooo1?l00006ooooo`;o00001Oooool2
o`0000Sooooo6_l0000Rooooo`?o00001?ooool4o`0000Wooooo0_l000000ooooooo0000o`000003
ooooo`;o00001oooool2o`0000Cooooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`17oooo
o`;o00004oooool4o`0000?ooooo0_l0000?ooooo`;o00001Oooool2o`0000?ooooo0_l00008oooo
o`;o00002?oooolNo`0001Gooooo0_l00008ooooo`?o00000oooool2o`0000kooooo0_l00003oooo
o`;o00001Oooool4o`0000Cooooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o
00003_ooool2o`0000Cooooo0ol00005ooooo`;o00002_ooool2o`0000?ooooo0_l00003ooooo`;o
00000_ooool2o`0000gooooo3?l000000ooooooo0000o`00000Bo`0001?ooooo0_l00008ooooo`Co
00001oooool2o`0000;ooooo0_l0000>ooooo`;o000000?oooooo`000?l000000_ooool2o`00053o
oooo000Looooo`03o`000?oooooooooo04cooooo1?l0000Booooo`Co00001?ooool2o`0000Kooooo
0_l00002ooooo`;o00000oooool2o`0000Oooooo0_l0000=ooooo`;o000000?oooooo`000?l00000
7?l0000Iooooo`;o00001?ooool2o`0000Oooooo0_l00002ooooo`;o00001Oooool2o`0000Oooooo
0_l00005ooooo`;o0000D?ooool001cooooo00?o0000ooooooooool0C_ooool2o`0000Kooooo0ol0
000:ooooo`?o00000_ooool2o`0000Sooooo0_l00007ooooo`;o00006?oooolMo`0000Cooooo0_l0
00000ooooooo0000o`00000Booooo`;o00001Oooool2o`0000_ooooo0_l00004ooooo`;o00005Ooo
ool4o`0004Oooooo000Looooo`03o`000?oooooooooo043ooooo0ol0000@ooooo`;o000000Cooooo
o`000?l0003o00002_ooool3o`0000;ooooo0_l0000@ooooo`?o00001_ooool2o`0000Kooooo0_l0
0008ooooob3o000000Coooooo`000?l0003ooooo0_l0000Iooooo`;o00002oooool2o`0000Sooooo
0_l0000Aooooo`Co00002Oooool2o`0003cooooo000Looooo`03o`000?oooooooooo043ooooo0ol0
000@ooooo`;o00003oooool2o`0000;ooooo0_l0000<ooooo`Ko00001oooool2o`0000Kooooo0_l0
00000ooooooo0000o`000006oooooa[o000000?oooooo`000?l000000_l0000Uooooo`;o00002ooo
ool2o`0000;ooooo0_l0000<ooooo`;o00001?ooool2o`0000[ooooo0_l0000looooo`007?ooool0
0ol0003oooooooooo`1>ooooo`;o00000_ooool2o`000003ooooool0003o0000017ooooo0_l00007
ooooo`;o00000oooool4o`0001Cooooo0_l00005oooooa_o000000?oooooo`000?l000002oooool2
o`0001[ooooo0_l0000;ooooo`;o00001Oooool2o`0000Wooooo0_l0001>ooooo`007?ooool00ol0
003oooooooooo`1<ooooo`Co00000_ooool2o`000003ooooool0003o000000Cooooo0_l0000Coooo
o`?o00003Oooool2o`0000?ooooo0_l0000>ooooo`Oo00000_oooolCo`0000gooooo0_l0000Poooo
o`;o00001Oooool2o`0000Gooooo0_l0000?ooooo`;o000000?oooooo`000?l00000AOooool001co
oooo0_l0000oooooo`;o00003?ooool4o`0000;ooooo0ol00006ooooo`;o000000Coooooo`000?l0
003ooooo0_l0000=ooooo`;o00002oooool2o`000003ooooool0003o000000?ooooo0_l0000>oooo
o`Wo00000_oooolAo`000003ooooool0003o000000;ooooo0_l0000Xooooo`Co00000oooool2o`00
00;ooooo1Ol0000;ooooo`?o000000Coooooo`000?l0003ooooo0_l00015ooooo`007?ooool00ol0
003oooooooooo`0nooooo`;o00003_ooool2o`000003ooooool0003o000000Co00001oooool2o`00
0003ooooool0003o000001[ooooo0_l00002ooooo`;o00001oooool5o`0000Oooooo7ol000000ooo
oooo0000o`00000Zooooo`;o00001oooool5o`0000_ooooo0ol0001;ooooo`007?ooool00ol0003o
ooooooooo`1@ooooo`?o00000_ooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo
0000o`00000Iooooo`;o00000oooool2o`000003ooooool0003o000000Cooooo1Ol00007oooooa?o
000000?oooooo`000?l000001_l000000ooooooo0000o`000004ooooo`;o0000:Oooool2o`0000?o
oooo0_l000000ooooooo0000o`00000Booooo`;o00000oooool2o`0000_ooooo0_l0000eooooo`00
7?ooool00ol0003oooooooooo`1;ooooo`;o00000oooool2o`0000Kooooo0_l00004ooooo`;o0000
3oooool2o`0000Cooooo0_l00005ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000
o`000002o`0000cooooo0_l00002ooooo`?o000000?oooooo`000?l000005_l00004ooooo`?o0000
:Oooool2o`0000;ooooo0ol000000ooooooo0000o`00000Booooo`;o00000oooool2o`0000_ooooo
0_l0000eooooo`007?ooool00ol0003oooooooooo`1:ooooo`?o00000oooool2o`0000Gooooo0_l0
000Fooooo`Wo00000_ooool4o`000003ooooool0003o000000Gooooo0_l0000<ooooo`;o00000_oo
oolHo`0000;ooooo0_l00003ooooo`?o00001oooool2o`0002?ooooo1?l0001Oooooo`007?ooool0
0ol0003oooooooooo`17ooooo`;o000000?oooooo`000?l000000_l00005ooooo`?o000000Cooooo
o`000?l0003ooooo0_l0000>ooooo`;o00001Oooool4o`000003ooooool0003o000000;ooooo0_l0
000Fooooo`;o00001?oooolHo`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`00
0005ooooo`Co00008Oooool2o`0000[ooooo0_l000000ooooooo0000o`000002o`0000Gooooo0_l0
0019ooooo`007?ooool00ol0003oooooooooo`16ooooo`Co00000_ooool2o`0000Cooooo1?l00004
ooooo`;o00000_ooool2o`0000[ooooo0_l00004ooooo`;o00000_ooool2o`0000?ooooo0_l00003
ooooo`;o00002Oooool2o`000003ooooool0003o000000Cooooo0_l00006ooooo`Oo000000?ooooo
o`000?l000002_l000000ooooooo0000o`000002o`0000Oooooo0_l00003ooooo`;o00000_ooool2
o`0002gooooo0_l000000ooooooo0000o`000002o`0000Gooooo0_l00019ooooo`007?ooool00ol0
003oooooooooo`16ooooo`Co00000_ooool3o`000003ooooool0003o000000;o00000_ooool2o`00
00Kooooo0_l00009ooooo`;o00000oooool4o`0000;ooooo0_l000000ooooooo0000o`000002o`00
00;ooooo1?l00002ooooo`Co00000_ooool2o`000003ooooool0003o000000Wooooo0ol00002oooo
o`Go000000?oooooo`000?l000002_l000000ooooooo0000o`00000>ooooo`;o0000=?ooool2o`00
0003ooooool0003o000000Gooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`1<ooooo`?o
000000Coooooo`000?l0003o00000_ooool3o`0000;ooooo0_l00005ooooo`Co00000_ooool4o`00
00?ooooo0_l00004ooooo`;o000000?oooooo`000?l000001?ooool4o`0000;ooooo1_l00002oooo
o`;o00000_ooool2o`0000Kooooo4_l000001?oooooo0000o`000?l00013ooooo`;o00000oooool5
o`0000;ooooo0_l000000ooooooo0000o`000018ooooo`007?ooool00ol0003oooooooooo`0doooo
o`;o00003Oooool2o`0000Oooooo0ol000000ooooooo0000o`000003ooooo`;o000000?oooooo`00
0?l000000_l00005ooooo`Co000000?oooooo`000?l000000ol00004ooooo`Co00003?ooool2o`00
00Kooooo0_l00002ooooo`;o00000_ooool2o`0000Wooooo2_l000000ooooooo0000o`000002o`00
0004ooooool0003o0000ooooo`Co00005Oooool2o`0002Sooooo0_l00003ooooo`Co00000oooool2
o`0000;ooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`0dooooo`;o00003Oooool2o`00
00;ooooo0_l00003ooooo`?o000000?oooooo`000?l000001_ooool2o`0000Wooooo1Ol000000ooo
oooo0000o`000002ooooo`Wo00002Oooool4o`0001?ooooo1?l00002ooooo`_o00000oooool2o`00
0003ooooool0003o000000Co00000_ooool2o`0000gooooo1?l0000Mooooo`;o00000oooool2o`00
0003ooooool0003o000000Oooooo0_l00006ooooo`Go000000?oooooo`000?l00000@oooool001co
oooo00?o0000ooooooooool0=Oooool2o`0000[ooooo0_l00004ooooo`;o000000?oooooo`000?l0
00001Ol00007ooooo`;o00002_ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l0
00001?l000000ooooooo0000o`000002o`0000[ooooo0_l0000Cooooo`Co00000oooool;o`0000Wo
oooo0_l00002ooooo`;o00003Oooool2o`0001oooooo0_l00003ooooo`;o000000?oooooo`000?l0
00000oooool2o`0000;ooooo0_l00006ooooo`;o000000?oooooo`000?l000000ol00013ooooo`00
7?ooool00ol0003oooooooooo`0eooooo`;o00002_ooool2o`0000Oooooo0ol00002ooooo`;o0000
2_ooool2o`0000[ooooo1?l000000ooooooo0000o`000009o`0000;ooooo0_l0000Dooooo`;o0000
4oooool6o`0000Sooooo0_l00005ooooo`;o0000:oooool2o`0000;ooooo0_l00006ooooo`;o0000
00?oooooo`000?l000000_l00009ooooo`;o0000AOooool001cooooo00?o0000ooooooooool0A_oo
ool2o`000004ooooool0003o0000o`0000?ooooo0_l00004ooooo`?o00000oooool2o`000004oooo
ool0003o0000oooooaGo00000oooool2o`0001Cooooo0_l00002ooooo`;o00003Oooool2o`000004
ooooool0003o0000ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Gooooo0_l0000Woooo
o`;o00000_ooool2o`0000;ooooo0_l00009ooooo`Co00003_ooool2o`00043ooooo00001_oooooo
k^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool0
0ol0003oooooooooo`16ooooo`;o000000Coooooo`000?l0003o00000oooool2o`0000Cooooo0ol0
0006ooooo`;o000000?oooooo`000?l000005Ol0000>ooooo`;o00002oooool2o`0000[ooooo0_l0
00000ooooooo0000o`000003ooooo`;o00000_ooool2o`0003Gooooo0_l00002ooooo`;o00006Ooo
ool3o`0000?ooooo0_l00010ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q
1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04[ooooo0_l0000FoooooaSo0000
3?ooool2o`0000Kooooo0_l0000>ooooo`?o00001_ooool2o`000004ooooool0003o0000o`0000[o
oooo0_l00002ooooo`;o00003_ooool2o`0002Cooooo0_l0000>ooooo`?o0000AOooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo00?o0000ooooooooool0
AOooool2o`000003ooooool0003o000001Cooooo0_l000000ooooooo0000o`00000Go`00013ooooo
0_l00002ooooo`;o00003_ooool2o`0000Gooooo0_l00003ooooo`;o00001_ooool8o`000004oooo
ool0003o0000ooooo`;o00000oooool2o`0000Kooooo0_l000000ooooooo0000o`00000Qooooo`;o
00009oooool2o`0002gooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo
00CoA4A4omgMgOoooooo00001oooool3o`0004Gooooo0_l000000ooooooo0000o`000003ooooo`;o
00001?ooool2o`0000Kooooo5Ol000000ooooooo0000o`000008o`0000Oooooo0_l00002ooooo`Ko
00006Oooool2o`0000Oooooo0_l000000ooooooo0000o`000004o`000004ooooool0003o0000oooo
o`Go00000oooool2o`0000Wooooo1?l0000Mooooo`;o00002?ooool2o`0000cooooo0_l00002oooo
o`;o00003Oooool2o`0002gooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wo
oooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`12ooooo`;o00002Oooool2o`00
00Cooooo0_l00002ooooo`;o00000_ooool4o`000003ooooool0003o000001Wo00001oooool2o`00
00;ooooo1?l00009ooooo`;o00002?ooool2o`0000gooooo1?l000000ooooooo0000o`000008oooo
o`Co00004Oooool2o`0000;ooooo0_l0000=ooooo`;o00000oooool2o`0000Gooooo0_l00007oooo
o`?o00002_ooool4o`0000;ooooo0_l0000looooo`0000?ooooooa0@4?ooool00_ooool00ol@413o
ooooooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0@_ooool2o`0000?o
oooo0_l00007ooooo`;o00001Oooool2o`0000;ooooo0_l00002oooooa_o000000?oooooo`000?l0
00005Oooool3o`0000Sooooo0_l0000;ooooo`Co00000oooool2o`0000Sooooo0_l0000:ooooo`Co
00002Oooool2o`0000gooooo0_l00003ooooo`;o000000?oooooo`000?l000002oooool2o`0000Oo
oooo0_l00002ooooo`;o0000@_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg3?ooool00oo^
k^koA4A4o`000007ooooo`03o`000?oooooooooo04Cooooo0_l000000ooooooo0000o`000002oooo
o`;o00000oooool2o`0000Gooooo0_l000001?oooooo0000o`000?l00002oooooako00005Oooool2
o`0000Wooooo0_l00005ooooo`;o00001?ooool2o`0000[ooooo0_l000000ooooooo0000o`00000<
ooooo`Co000000?oooooo`000?l000001?ooool2o`0001Kooooo0ol00005ooooo`;o00003Oooool2
o`0004Kooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_oo
ool00ol0003oooooooooo`14ooooo`;o00001Oooool2o`0000[ooooo0_l000000ooooooo0000o`00
0003ooooo`;o000000?oooooo`000?l000006?l0000Gooooo`;o00002?ooool2o`0000Gooooo0_l0
0003ooooo`;o00002?ooool2o`000004ooooool0003o0000ooooo`;o00003_ooool2o`000003oooo
ool0003o000000Cooooo0_l00003ooooo`;o00004Oooool2o`0000Kooooo0_l0000<ooooo`;o0000
1oooool2o`0003kooooo000Looooo`03o`000?oooooooooo04Kooooo0_l000000ooooooo0000o`00
0006ooooo`;o00003?ooool2o`0000;ooooo3?l000000ooooooo0000o`000009o`000003ooooool0
003o000001;ooooo1Ol0000Dooooo`;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`00
000Aooooo`Co00001?ooool2o`000004ooooool0003o0000ooooo`?o00000oooool2o`0000Oooooo
0_l000000ooooooo0000o`00000>ooooo`;o00001Oooool3o`0000Kooooo0_l0000nooooo`007?oo
ool00ol0003oooooooooo`0nooooo`;o00001_ooool2o`000003ooooool0003o000000Kooooo0_l0
000;ooooob3o000000?oooooo`000?l000000_ooool2o`0000_ooooo1_l000001?oooooo0000o`00
0?l0000Eooooo`;o000000?oooooo`000?l000000oooool2o`00013ooooo1?l00004ooooo`;o0000
00Coooooo`000?l0003ooooo0ol00003ooooo`?o00001_ooool2o`000004ooooool0003o0000oooo
o`;o00002oooool2o`0000Kooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`0nooooo`;o
00000_ooool2o`0000;ooooo0_l0000Fooooob3o000000?oooooo`000?l000000_ooool2o`0000;o
oooo0ol0000:ooooo`;o000000?oooooo`000?l000001?l0000Cooooo`Co00000oooool2o`0000Ko
oooo0_l00008ooooo`?o00000oooool3o`0000Cooooo0ol00005ooooo`;o00002_ooool4o`0001Ko
oooo0_l00013ooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00001_ooool3o`0000;ooooo
0_l0000=ooooo`;o00002OoooolMo`0000Wooooo1?l0000;ooooo`Wo00002oooool2o`0000Gooooo
0ol00006ooooo`;o00001?ooool2o`0000Oooooo0_l00005ooooo`?o00001?ooool3o`00017ooooo
0_l00006ooooo`;o00003_ooool4o`0001Wooooo0_l0000Xooooo`007?ooool00ol0003ooooooooo
o`0iooooo`;o00001_ooool2o`00013ooooo1?l00009ooooo`;o00000_oooolIo`0000Wooooo0_l0
0002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00005ooooo`;o00001_oo
ool4o`000003ooooool0003o000000Sooooo0_l00004ooooo`Go000000Coooooo`000?l0003o0000
1?ooool4o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`Co000000?oooooo`000?l00000
5Oooool2o`0000_ooooo0_l000000ooooooo0000o`00000Kooooo`;o0000:?ooool001cooooo00?o
0000ooooooooool0??ooool2o`0000;ooooo0_l000000ooooooo0000o`00000>ooooo`;o000000?o
ooooo`000?l000003?oooolGo`0000oooooo0_l000000ooooooo0000o`000002ooooo`;o00004Ooo
ool4o`0000Sooooo0_l000000ooooooo0000o`000005ooooo`So000000Coooooo`000?l0003ooooo
1?l00002ooooo`;o00001Oooool2o`0000;ooooo0ol000000ooooooo0000o`000002o`0000?ooooo
0_l0000=ooooo`;o00002?ooool2o`0000;ooooo0_l0000;ooooo`;o0000>oooool001cooooo00?o
0000ooooooooool0??ooool2o`0000;ooooo0_l000000ooooooo0000o`00000>ooooo`;o000000?o
ooooo`000?l000002OoooolIo`0000;ooooo0_l00004ooooo`;o00007oooool4o`0000Sooooo0ol0
0003ooooo`;o00000_ooool2o`0000?ooooo1?l000000ooooooo0000o`000002ooooo`;o00002_oo
ool2o`0000Gooooo0_l000000ooooooo0000o`000003ooooo`;o00003Oooool4o`0000Kooooo0_l0
000<ooooo`;o000000?oooooo`000?l00000>oooool001cooooo00?o0000ooooooooool0@_ooool2
o`0000oooooo0_l000000ooooooo0000o`000002ooooo`;o00001OoooolEo`000003ooooool0003o
000000;o000000?oooooo`000?l000001?ooool2o`0000cooooo0_l00008ooooo`;o00001oooool4
o`0000Sooooo0_l00004ooooo`;o00000_ooool2o`000003ooooool0003o000000Co000000?ooooo
o`000?l000001Oooool4o`0000Gooooo0_l00005ooooo`;o000000?oooooo`000?l000004_ooool4
o`00013ooooo0_l00002ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0;?ooool2o`00
0003ooooool0003o0000017ooooo0_l00009ooooo`;o00001Oooool2o`0000Cooooo0_l00007oooo
oaSo00005Oooool2o`0000Kooooo1?l0000Cooooo`;o00002oooool2o`000003ooooool0003o0000
00Co00001Oooool4o`0002gooooo1?l00006ooooo`?o0000@Oooool001cooooo00?o0000oooooooo
ool0;?ooool2o`000003ooooool0003o000000Kooooo0_l00009ooooo`;o00002Oooool2o`0000Go
oooo0_l00006ooooo`;o00001Oooool2o`0000;ooooo4ol00003ooooo`;o00005?ooool2o`0000?o
oooo1?l0000Cooooo`;o00000_ooool6o`000004ooooool0003o0000ooooo`Ko00001?ooool3o`00
00Cooooo0_l00006ooooo`;o00005_ooool2o`0000_ooooo1?l00007ooooo`;o0000@Oooool001co
oooo00?o0000ooooooooool0=oooool2o`000003ooooool0003o000000?ooooo0_l000001?oooooo
0000o`000?ooool2o`0000gooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l00002
ooooo`;o00000_ooool2o`000003ooooool0003o000000ko00000oooool2o`0001?ooooo0ol00003
ooooo`?o00003?ooool2o`0000Wooooo1ol000000ooooooo0000o`000005o`0000Kooooo0ol00000
1?oooooo0000o`000?ooool2o`000004ooooool0003o0000ooooo`Co00004?ooool4o`0000;ooooo
0_l00003ooooo`;o00002?ooool2o`0004[ooooo000Looooo`;o0000>oooool2o`0000?ooooo0ol0
0003ooooo`;o00003?ooool3o`0000?ooooo0_l00004ooooo`;o00000_ooool2o`000003ooooool0
003o000000Co000000?oooooo`000?l000000ol00004ooooo`Co00002Oooool2o`0000Cooooo1?l0
0004ooooo`?o00000_ooool4o`0000gooooo0_l00005ooooo`?o000000?oooooo`000?l000002_l0
00000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l000000_l00003ooooo`?o000000?o
ooooo`000?l000001oooool2o`0000Wooooo1?l00007ooooo`;o0000E?ooool001cooooo00?o0000
ooooooooool0>_ooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000gooooo0_l0
0006ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo1?l0000<ooooo`Co00001Ooo
ool2o`0000;ooooo0_l00004ooooo`Ko00000_ooool3o`0000;ooooo0_l0000Doooooa?o000000?o
ooooo`000?l000001_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000002ooo
ool2o`0001Oooooo0_l0000<ooooo`;o0000@oooool001cooooo00?o0000ooooooooool09_ooool2
o`0001Gooooo1Ol00002ooooo`;o00001?ooool2o`0000Oooooo0_l00005ooooo`Ko00000_ooool2
o`0000[ooooo0_l0000?ooooo`;o00003?ooool3o`0000Oooooo0ol00003ooooo`;o00002?ooool2
o`0000?ooooo1_l00002ooooo`;o000000?oooooo`000?l000006Ol000001?oooooo0000o`000?oo
ool2o`0000Cooooo0_l0000Hooooo`;o00003?ooool3o`000004ooooool0003o0000ooooo`;o0000
??ooool001cooooo00?o0000ooooooooool09_ooool2o`0000Cooooo0_l0000=ooooo`;o00000_oo
ool3o`0000Sooooo0ol0000<ooooo`?o000000?oooooo`000?l000003oooool2o`0001Sooooo0_l0
0004ooooo`;o00001Oooool5o`000003ooooool0003o000000?o00001?ooool2o`000003ooooool0
003o000000Kooooo0ol00004ooooo`ko000000?oooooo`000?l000004Ol00004ooooo`;o00008?oo
ool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000003cooooo
000Looooo`03o`000?oooooooooo02cooooo0_l0000=ooooo`;o000000?oooooo`000?l000000_l0
0009ooooo`;o00003?ooool2o`0002Kooooo0_l00005ooooo`;o00001_ooool2o`0000?ooooo1Ol0
00001?oooooo0000o`000?ooool2o`0000Cooooo0_l00007ooooo`;o00000_ooool2o`0000?ooooo
0_l000000ooooooo0000o`000003o`0000?ooooo5ol00008ooooo`;o00007?ooool2o`000005oooo
ool0003o0000o`000?ooool01Ol000000ooooooo0000o`00000looooo`007?ooool00ol0003ooooo
ooooo`0/ooooo`;o00003?ooool3o`000003ooooool0003o000000cooooo0_l0000cooooo`;o0000
0oooool2o`0000Sooooo0_l00006ooooo`;o00000_ooool2o`0000oooooo0_l00002ooooo`;o0000
0ooooolKo`000003ooooool0003o000000;o00001Oooool3o`0000;ooooo0_l00003ooooo`;o0000
3Oooool2o`0000Cooooo0_l00005ooooo`;o00001?ooool3o`000003ooooool0003o000001Sooooo
0_l0000Rooooo`007?ooool00ol0003oooooooooo`0Tooooo`;o00005?ooool3o`0000cooooo0_l0
00000ooooooo0000o`00000hooooo`;o00003oooool4o`000004ooooool0003o0000o`0000;ooooo
0_l0000:ooooo`;o00001ooooolGo`0000?ooooo0ol000000ooooooo0000o`000005ooooo`?o0000
1oooool2o`0000;ooooo0_l00009ooooo`;o00001?ooool2o`0000_ooooo0_l0000Looooo`;o0000
8_ooool001cooooo00?o0000ooooooooool09?ooool2o`0001Cooooo0_l000000ooooooo0000o`00
000:ooooo`;o00002?ooool2o`0000cooooo0_l0000Rooooo`;o000000?oooooo`000?l000001Ooo
ool2o`0000Gooooo1Ol000001Ooooooo0000o`000?l0003ooooo00Co00002?ooool8o`0000;ooooo
8?l00002ooooo`;o00000oooool4o`0000Sooooo0_l0001Nooooo`007?ooool00ol0003ooooooooo
o`0hooooo`Co000000?oooooo`000?l000005?ooool2o`0000cooooo0_l0000Qooooo`?o000000?o
ooooo`000?l000001Oooool2o`0000Gooooo0_l000000ooooooo0000o`000002ooooo`;o000000?o
ooooo`000?l000000_l000000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l000000ol0
0004oooooa[o000000Coooooo`000?l0003o00000_ooool2o`0000?ooooo1_l00008ooooo`;o0000
3?ooool3o`0004gooooo000Looooo`03o`000?oooooooooo03Sooooo0ol00003ooooo`;o00000ooo
ool2o`0003[ooooo0_l00003ooooo`;o00001?ooool2o`0000_ooooo1?l00003ooooo`;o00001Ooo
ool4o`0000Sooooo1Ol000000ooooooo0000o`00000Ao`000003ooooool0003o000000So00000ooo
ool2o`000003ooooool0003o000000?ooooo1Ol00004ooooo`Co00002Oooool2o`000004ooooool0
003o0000o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0004?ooooo000Looooo`03o`00
0?oooooooooo03Wooooo0_l00003ooooo`;o00000oooool2o`0002[ooooo0_l0000>ooooo`;o0000
1_ooool2o`000003ooooool0003o000000_ooooo0_l00005ooooo`;o000000?oooooo`000?l00000
1?ooool2o`0000Sooooo6Ol000000ooooooo0000o`000004o`000003ooooool0003o000000Ko0000
00?oooooo`000?l000001_ooool2o`0000Cooooo0ol0000:ooooo`;o00001_ooool2o`000004oooo
ool0003o0000ooooo`;o00008Oooool2o`00023ooooo000Looooo`03o`000?oooooooooo02Sooooo
0_l0000Aooooo`;o00001_ooool2o`0000Sooooo0_l0000Booooo`;o00003?ooool2o`0000gooooo
0ol000000ooooooo0000o`000003ooooo`;o00003_ooool2o`0000Cooooo0_l00002ooooo`;o0000
1Oooool2o`0000;ooooo0_l00003ooooo`Co000000Goooooo`000?l0003o0000ooooo`0So`000004
ooooool0003o0000ooooo`Co00003_ooool4o`00017ooooo0_l0000Mooooo`;o00008?ooool001co
oooo00?o0000ooooooooool08Oooool2o`0000Gooooo0_l0000?ooooo`Oo00003Oooool2o`0000?o
oooo0_l0000=ooooo`;o00002Oooool2o`0000gooooo0_l000001Ooooooo0000o`000?l0003ooooo
00;o00000oooool2o`0001?ooooo1?l00008ooooo`;o000000Goooooo`000?l0003o0000ooooo`02
o`000003ooooool0003o0000027o000000Coooooo`000?l0003ooooo1?l000001?oooooo0000o`00
0?ooool6o`0000cooooo1?l00006ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`;o
00000_ooool2o`0003_ooooo000Looooo`03o`000?oooooooooo027ooooo0_l0000Fooooo`;o0000
0_ooool3o`0000Oooooo0_l00004ooooo`;o00000oooool2o`0000Gooooo0_l00005ooooo`;o0000
2_ooool2o`0000gooooo0_l00009ooooo`;o00001oooool2o`0000Sooooo0_l000000ooooooo0000
o`000002o`0000_ooooo0ol000000ooooooo0000o`00000To`000003ooooool0003o000000Kooooo
0_l000000ooooooo0000o`000002ooooo`;o00001Oooool2o`0000oooooo0_l00003ooooo`Go0000
0_ooool2o`000003ooooool0003o000003_ooooo000Looooo`03o`000?oooooooooo04Oooooo0_l0
0008ooooo`;o00001?ooool4o`0000Gooooo0_l0000Oooooo`;o00000oooool4o`0000Gooooo0_l0
0004ooooo`;o00000_ooool2o`0000Cooooo0_l0000@ooooo`;o000000?oooooo`000?l000004?l0
00000ooooooo0000o`00000Ao`0000;ooooo0_l00002ooooo`;o00002_ooool2o`0001Gooooo1?l0
0002ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0@?ooool3o`0000kooooo0_l00004
ooooo`Co00005Oooool2o`000003ooooool0003o000000Cooooo0_l00006ooooo`?o00001?ooool2
o`0000_ooooo0_l00006ooooo`Co00000oooool2o`0000Gooooo0_l00003ooooo`?o000000?ooooo
o`000?l000009?l00002ooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`000002
o`0000oooooo0_l00003ooooo`Ko00000oooool2o`0003gooooo000Looooo`;o0000<oooool2o`00
00;ooooo0_l00008ooooo`?o00004Oooool2o`0000Kooooo1?l0000@ooooo`;o000000Coooooo`00
0?l0003ooooo0_l000000ooooooo0000o`000007ooooo`;o00001?ooool4o`0000;ooooo0_l0000=
ooooo`;o00000_ooool2o`000003ooooool0003o000000Gooooo0ol000000ooooooo0000o`000002
o`000003ooooool0003o000002;o00003_ooool7o`0000oooooo0_l00003ooooo`;o00001oooool2
o`0003gooooo000Looooo`03o`000?oooooooooo03;ooooo0_l00002ooooo`;o00002_ooool2o`00
013ooooo0_l00006ooooo`Co00000oooool2o`0000cooooo1?l000000ooooooo0000o`000003o`00
00gooooo1?l00002ooooo`;o00004Oooool3o`0000Kooooo1?l000000ooooooo0000o`000002o`00
00;ooooo7ol000000ooooooo0000o`000002o`0000cooooo1Ol000000ooooooo0000o`000003o`00
0003ooooool0003o000001Wooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`12ooooo`;o
00000_ooool2o`0000gooooo0_l00005ooooo`;o00001Oooool2o`0000cooooo1?l00003ooooo`;o
00001Oooool2o`0000Kooooo0_l00006ooooo`;o00001?ooool2o`0000Wooooo1?l00006ooooo`Co
000000?oooooo`000?l000000_l000000ooooooo0000o`00000Po`000004ooooool0003o0000o`00
00;ooooo0ol00006ooooo`?o00001Oooool3o`000003ooooool0003o000001Oooooo1?l0000koooo
o`007?ooool00ol0003oooooooooo`0eooooo`;o00003oooool2o`0000gooooo0_l00004ooooo`;o
00005?ooool4o`0000[ooooo0_l00006ooooo`;o00001_ooool2o`0000Cooooo0_l00007ooooo`Ko
000000?oooooo`000?l000000oooool2o`0000;ooooo0_l00004oooooaoo000000?oooooo`000?l0
00001?l00002ooooo`?o00001Oooool2o`0002Cooooo1?l0000kooooo`007?ooool00ol0003ooooo
ooooo`0eooooo`;o00001_ooool2o`000003ooooool0003o000001Wooooo0_l0000>ooooo`;o0000
1?ooool2o`0001;ooooo0_l00006ooooo`;o00002?ooool2o`0000Gooooo0_l00002ooooo`;o0000
00?oooooo`000?l000000oooool2o`0000;ooooo:ol00003ooooo`?o00001?ooool3o`0000_ooooo
0_l00008ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0?Oooool5o`0000Sooooo0ol0
0002ooooo`;o00006_ooool2o`0000oooooo0_l00007ooooo`;o00001_ooool2o`0000Sooooo1?l0
0008ooooo`;o00001Oooool2o`000003ooooool0003o000002Wo00000_ooool5o`0000Cooooo1?l0
000:ooooo`;o00002?ooool2o`0000[ooooo0_l00002ooooo`;o0000??ooool001cooooo00?o0000
ooooooooool0=Oooool2o`0000Sooooo0_l00008ooooo`Co00000_ooool2o`0002_ooooo0_l0000K
ooooo`;o00001?ooool2o`0000;ooooo0ol00004ooooo`;o000000?oooooo`000?l000005Ol00002
oooooa3o00001?ooool2o`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l000001?l00009
ooooo`;o00003_ooool2o`000004ooooool0003o0000o`0003cooooo000Looooo`03o`000?oooooo
oooo02[ooooo0_l00009ooooo`;o00000oooool2o`0000[ooooo0_l000001?oooooo0000o`000?l0
0004ooooo`?o00001oooool2o`000003ooooool0003o000000;o00005_ooool2o`00023ooooo0_l0
0004ooooo`;o00000oooool3o`0000?ooooo1?l000000ooooooo0000o`00000Co`000003ooooool0
003o0000017o000000?oooooo`000?l000001Oooool4o`000004ooooool0003o0000ooooo`Ko0000
2Oooool2o`0000?ooooo0_l0000<ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0:_oo
ool2o`0000gooooo0ol00006ooooo`;o00000_ooool2o`0000Sooooo0ol00007ooooo`;o000000?o
ooooo`000?l000000_l00002ooooo`;o00004_ooool2o`0000;ooooo0_l0000Looooo`;o00000ooo
ool3o`0000Cooooo0_l000000ooooooo0000o`000004o`0000;ooooo;_l00002ooooo`Co000000?o
ooooo`000?l000000_ooool2o`00017ooooo1?l00019ooooo`007?ooool00ol0003oooooooooo`0i
ooooo`;o00001oooool2o`0000Oooooo0_l0000>ooooo`?o00001Oooool2o`0000Gooooo0_l00004
ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Sooooo0_l0000Gooooo`Co00000_ooool2
o`0000;ooooo1?l000001?oooooo0000o`000?oooolNo`000003ooooool0003o000000Ko000000?o
ooooo`000?l000001?l0000Pooooo`;o00000_ooool2o`0004Gooooo000Looooo`03o`000?oooooo
oooo04_ooooo0ol0000=ooooo`?o00001Oooool2o`0000Gooooo0_l00004ooooo`;o000000?ooooo
o`000?l000004?ooool2o`0001?ooooo0_l00002ooooo`co00000ooooolJo`000003ooooool0003o
0000013o00000_ooool2o`0000Gooooo0_l0000:ooooo`;o00002?ooool2o`0000?ooooo0_l00002
ooooo`;o00001?ooool2o`0003oooooo000Looooo`03o`000?oooooooooo02[ooooo0_l00008oooo
o`;o00001_ooool2o`0000Gooooo1?l00004ooooo`?o00007oooool2o`0000Cooooo0_l0000Poooo
o`?o00000_ooool2o`0000;ooooo0_l00002ooooo`;o00000_ooool4o`0000?ooooo;_l00008oooo
o`;o00001Oooool2o`0000?ooooo0_l00008ooooo`;o00000oooool2o`0000Oooooo0ol0000ooooo
o`007?ooool00ol0003oooooooooo`0Zooooo`;o00002?ooool3o`0000Gooooo0_l00005ooooo`Co
00004?ooool2o`0000cooooo0_l00006ooooo`;o00002?ooool2o`0000Cooooo0_l0000Fooooo`?o
00001_ooool2o`0000;ooooo0_l00009ooooo`;o00001?ooool:o`000003ooooool0003o000001?o
00000_ooool2o`0000;ooooo0_l0000?ooooo`?o00002_ooool2o`0000Cooooo0_l00008ooooo`;o
00000_ooool2o`0001[ooooo0_l0000Pooooo`007?ooool00ol0003oooooooooo`0eooooo`;o0000
3Oooool4o`0000cooooo1Ol0000<ooooo`?o00003oooool2o`0000Cooooo0_l0000Cooooo`;o0000
2_ooool2o`0000oooooo0_l00003ooooobCo00002_ooool2o`0000;ooooo0_l00003ooooo`;o0000
2Oooool5o`0000;ooooo0_l0000<ooooo`;o00006_ooool2o`00023ooooo000Looooo`03o`000?oo
oooooooo02_ooooo0_l00006ooooo`;o00001Oooool2o`0000Sooooo1?l0000<ooooo`?o000000?o
ooooo`000?l000001Oooool2o`000003ooooool0003o000000Ko00000oooool2o`0002?ooooo0_l0
000Kooooobco00000_ooool2o`0000?ooooo0_l00002ooooo`;o00003_ooool2o`000003ooooool0
003o0000013ooooo0_l0000=ooooo`;o0000;Oooool001cooooo00?o0000ooooooooool0:oooool4
o`0000Cooooo0_l00005ooooo`Co00000oooool2o`0000;ooooo0_l0000@ooooo`?o00001Oooool;
o`0000?ooooo0_l0000;ooooo`;o00000oooool2o`0002Gooooo0_l00006ooooo`;o000000?ooooo
o`000?l000008?l000000ooooooo0000o`000005o`0000;ooooo0_l00003ooooo`;o00001Oooool2
o`0001Oooooo1?l00004ooooo`;o00003_ooool2o`0002gooooo000Looooo`;o0000;_ooool2o`00
00gooooo0_l00003ooooo`;o00000_ooool2o`00013ooooo0_l00006ooooo`co00001oooool4o`00
00Cooooo0ol00002ooooo`;o00007_ooool2o`0000Gooooo0_l00004ooooo`Co00000_ooool4o`00
00?ooooo7_l00002ooooo`?o000000?oooooo`000?l000000_l00002ooooo`;o00001?ooool2o`00
00Kooooo0_l0000:ooooo`;o00000oooool4o`0000Cooooo0_l0000mooooo`007?ooool00ol0003o
ooooooooo`18ooooo`Co00003?ooool2o`0000Cooooo3ol00005ooooo`Co00001Oooool2o`0001_o
oooo0_l00005ooooo`Co00002Oooool2o`0000Cooooo9Ol000000ooooooo0000o`000007o`0000;o
oooo0_l000000ooooooo0000o`000009ooooo`;o00002_ooool2o`0000;ooooo0ol000000ooooooo
0000o`000009ooooo`;o0000=oooool001cooooo00?o0000ooooooooool0>oooool3o`000003oooo
ool0003o000000Oooooo1?l00002ooooo`;o00000_ooool2o`0000;ooooo1?l00004ooooo`co0000
00Coooooo`000?l0003o0000:_ooool2o`0000Oooooo0_l00009ooooo`Co00001?ooool5o`000003
ooooool0003o000001Oo00000oooool7o`000003ooooool0003o000000Kooooo0_l00008ooooo`;o
00003?ooool2o`000003ooooool0003o000000;ooooo1?l00007ooooo`;o0000=oooool001cooooo
00?o0000ooooooooool0>oooool3o`000003ooooool0003o000000?ooooo0ol00003ooooo`;o0000
0_ooool2o`0000;ooooo0_l000001?oooooo0000o`000?l00003ooooo`;o00000_oooolCo`0001Oo
oooo0_l00002ooooo`;o00004?ooool2o`0000Kooooo0_l00002ooooo`Go000000?oooooo`000?l0
00000ol00002ooooo`;o000000?oooooo`000?l000002ol000000ooooooo0000o`000005o`0000Go
oooo1ol00003ooooo`;o00001_ooool2o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`;o
00001oooool2o`0000Oooooo1Ol0000mooooo`007?ooool00ol0003oooooooooo`0eooooo`;o0000
3Oooool8o`0000Cooooo0_l00003ooooo`;o00000_ooool4o`0000;ooooo4ol00003ooooo`;o0000
4_ooool2o`0000;ooooo0_l0000<ooooo`;o00000_ooool2o`0000Kooooo0_l00002ooooo`;o0000
1?ooool4o`0000?ooooo0_l00002ooooo`Co000000Coooooo`000?l0003o00000oooool2o`0000;o
oooo1ol00003ooooo`Go00000oooool4o`0000Kooooo0_l00004ooooo`?o00001Oooool2o`000003
ooooool0003o000000gooooo1Ol0000Iooooo`;o00008_ooool001cooooo00?o0000ooooooooool0
;_ooool2o`0000Gooooo0_l00009ooooo`;o00000_ooool6o`0000Kooooo0_l00005ooooo`Co0000
0_ooool2o`0000Gooooo3_l00003ooooo`;o00008?ooool3o`000003ooooool0003o000000Co0000
1Oooool2o`0001Cooooo1?l000001?oooooo0000o`000?ooool5o`000003ooooool0003o000000Ko
000000?oooooo`000?l000000ol00004ooooo`Go00003Oooool2o`0000Sooooo0_l00007ooooo`;o
00000_ooool2o`0000?ooooo0_l0000Iooooo`;o00008_ooool001cooooo00?o0000ooooooooool0
;_ooool2o`0000cooooo0_l00002ooooo`;o00000_ooool4o`0000Cooooo0_l00009ooooo`;o0000
0_ooool4o`0000Kooooo3Ol0000Uooooo`?o00000oooool2o`0000Oooooo0_l0000Doooooa7o0000
0_ooool3o`000003ooooool0003o000000?o00001?ooool2o`0000Sooooo0_l0000Iooooo`;o0000
0_ooool2o`0000?ooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0looooo`Ko00002_oo
ool2o`0000gooooo0ol00007ooooo`oo00001Oooool2o`0000_ooooo0_l0000:ooooo`;o00000ooo
ool2o`0000Gooooo0_l00008ooooo`;o00001oooool3o`000003ooooool0003o000000;o00001Ooo
ool6o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`Wo00002oooool2o`000003ooooool0
003o000000?ooooo1?l00005ooooo`;o00004Oooool2o`000004ooooool0003o0000ooooo`;o0000
>_ooool001cooooo00?o0000ooooooooool0??ooool4o`0000kooooo0_l0000:ooooo`;o00001?oo
ool4o`0000Kooooo2ol00004ooooo`;o00002oooool4o`0000Sooooo0_l00003ooooo`;o00001Ooo
ool2o`0000Sooooo0_l00002ooooo`;o00000oooool3o`000003ooooool0003o000000Co00001?oo
ool3o`000004ooooool0003o0000ooooo`;o00001_ooool7o`0000cooooo1?l00003ooooo`;o0000
00?oooooo`000?l000000_l00005ooooo`;o00003oooool5o`0000?ooooo0_l0000jooooo`007?oo
ool00ol0003oooooooooo`0looooo`;o00001_ooool2o`0000Sooooo1?l00006ooooo`Co00001?oo
ool4o`000003ooooool0003o000000;o00000_ooool<o`0000cooooo0_l00003ooooo`;o00006Ooo
ool2o`0000Oooooo0_l00002ooooo`;o00001oooool2o`0000Sooooo1Ol000001?oooooo0000o`00
0?l00002ooooo`?o00004?ooool2o`0000Gooooo0_l0000Kooooo`Oo0000?Oooool001cooooo00?o
0000ooooooooool0<oooool4o`0000Wooooo0_l00002ooooo`;o00002?ooool6o`0000Cooooo1Ol0
0005oooooaGo00003?ooool2o`0000?ooooo1?l0000Dooooo`;o000000?oooooo`000?l000002ooo
ool2o`0000[ooooo0_l000001?oooooo0000o`000?ooool:o`0000;ooooo0ol0000@ooooo`;o0000
2_ooool4o`0000cooooo0_l0000;ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0<ooo
ool4o`0000?ooooo0_l00002ooooo`Co00003?ooool2o`0000;ooooo0_l00005ooooo`Co00001Ooo
ool5o`000003ooooool0003o000000Ko000000?oooooo`000?l000000_l00006ooooo`;o00002ooo
ool4o`0001;ooooo1?l000000ooooooo0000o`000003ooooo`;o00001Oooool2o`0000_ooooo0_l0
00001?oooooo0000o`000?ooool7o`000003ooooool0003o000001?ooooo1Ol00009ooooo`Co0000
3?ooool2o`0000cooooo0_l0000looooo`007?ooool00ol0003oooooooooo`0jooooo`?o000000Co
ooooo`000?l0003o00001oooool2o`000003ooooool0003o000000Kooooo0_l00009ooooo`;o0000
0oooool2o`000003ooooool0003o0000013o000000?oooooo`000?l000000_l00002ooooo`;o0000
1oooool2o`0001;ooooo1?l00008ooooo`;o000000?oooooo`000?l000000_ooool2o`0001?ooooo
0_l00003ooooo`?o00002?ooool2o`0000Wooooo0_l000001?oooooo0000o`000?ooool2o`0000Oo
oooo0_l00005ooooo`Co00001?ooool3o`0000Kooooo0_l00003ooooo`;o0000??ooool001cooooo
00?o0000ooooooooool0;Oooool2o`0000cooooo0_l0000;ooooo`;o000000?oooooo`000?l00000
1_ooool2o`0000;ooooo0ol00004ooooo`;o000000?oooooo`000?l000000oooool3o`0000;ooooo
6ol00004ooooo`;o00002Oooool2o`0000Gooooo0_l0000=ooooo`;o00000oooool2o`0000?ooooo
0_l0000Aooooo`?o00002Oooool2o`0000oooooo0_l00007ooooo`;o00001Oooool4o`0000Gooooo
0_l00004ooooo`Co00000oooool2o`0003cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGo
oooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0]oooo
o`;o00003?ooool4o`0001Gooooo0_l000001?oooooo0000o`000?l00007ooooo`;o00001?ooool2
o`0000;ooooo6ol000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00005ooooo`;o00002_oo
ool4o`0000[ooooo0ol00002ooooo`?o00004?ooool5o`0000Oooooo0ol00009ooooo`;o000000Co
ooooo`000?l0003ooooo0_l00004ooooo`;o00000oooool2o`0001;ooooo1?l000000ooooooo0000
o`000002o`0003cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05
oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0aooooo`;o00001Oooool2o`00
0003ooooool0003o000000;o00000_ooool2o`0000Gooooo0_l00007ooooo`;o000000?oooooo`00
0?l000000ol00006ooooo`;o00001_ooool2o`0000Oooooo6Ol000000ooooooo0000o`000002oooo
o`;o00004?ooool5o`0000[ooooo0_l00003ooooo`;o00002oooool2o`0000Cooooo0_l000000ooo
oooo0000o`000007ooooo`?o00001?ooool2o`0000?ooooo0_l000000ooooooo0000o`000003o`00
00Cooooo0_l00003ooooo`;o00001?ooool2o`0000[ooooo0_l00005ooooo`;o0000?_ooool00003
ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool0<Oooool2o`0000Gooooo0_l00007ooooo`;o00001Oooool2o`00
00Oooooo0_l00003ooooo`Go00001?ooool2o`0000kooooo2_l000000ooooooo0000o`000009o`00
0003ooooool0003o000000Ko000000?oooooo`000?l000003oooool2o`000003ooooool0003o0000
01cooooo0_l0000Fooooo`?o00001oooool3o`0000Wooooo0_l00004ooooo`?o00002_ooool4o`00
04?ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oiRHV?oo
ooooV9RHob4Q8@06ooooo`?o0000?Oooool2o`0001[ooooo1?l00004ooooo`;o00002ooooolGo`00
0003ooooool0003o000000Wo00002_ooool2o`000003ooooool0003o000001Oooooo0_l00002oooo
o`;o00005?ooool2o`0000Kooooo0_l00009ooooo`;o00001oooool4o`0000Cooooo0_l0000=oooo
o`Co0000@Oooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003o
EEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0?Oooool2o`0001Cooooo1?l00004oooo
o`;o00001?ooool4o`0000Wooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o0000
01;o000000?oooooo`000?l000000ol00003ooooo`;o00001?ooool6o`0000?ooooo0_l0000:oooo
o`;o00001Oooool3o`0000;ooooo0_l0000Dooooo`;o00002oooool2o`0000Gooooo0_l000000ooo
oooo0000o`000003ooooo`;o00000_ooool2o`0001;ooooo0ol00011ooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000oooooooo
ool0Doooool6o`0000[ooooo0_l0000<ooooob3o00000oooool4o`0000;ooooo0_l000000ooooooo
0000o`000002o`0000;ooooo0ol00009ooooo`;o00001Oooool2o`0002?ooooo0_l000000ooooooo
0000o`000005ooooo`;o000000?oooooo`000?l000001oooool2o`0000Oooooo1?l0000?ooooo`;o
0000>_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008oooo
o`03o`000?oooooooooo03?ooooo0_l0000:ooooo`;o00000_ooool2o`0000Wooooo0_l00003oooo
o`Ko00001Oooool2o`0000Sooooo0_l00005ooooobCo000000?oooooo`000?l000000_l00007oooo
o`;o000000?oooooo`000?l000000_l0000Eooooo`?o00003_ooool2o`0000gooooo1?l00006oooo
o`;o00000_ooool2o`0000Kooooo0_l00007ooooo`Co00001Oooool2o`0000Sooooo0_l0000joooo
o`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o
0000ooooooooool09oooool2o`0000[ooooo0_l0000:ooooo`;o00000_ooool2o`0000Wooooo0_l0
0003ooooo`Co00001oooool2o`0000Sooooo0_l00005ooooo`;o00000ooooolOo`000003ooooool0
003o000000;o00002_ooool6o`0001?ooooo1?l00006ooooo`;o00001Oooool2o`0000Oooooo0_l0
0006ooooo`;o00001_ooool2o`0000;ooooo0ol00005ooooo`;o00004?ooool2o`0004Cooooo000L
ooooo`03o`000?oooooooooo02Oooooo0_l0000Booooo`;o0000>OoooolRo`0000[ooooo0_l00002
ooooo`?o00005?ooool2o`0000Kooooo0_l0000>ooooo`;o00001_ooool2o`000003ooooool0003o
000000Sooooo0_l00005ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Wooooo0_l0000E
ooooo`;o0000;Oooool001cooooo00?o0000ooooooooool0>Oooool4o`0001Cooooo0_l0000Eoooo
o`;o000000?oooooo`000?l000002OoooolOo`000003ooooool0003o000000[ooooo0_l00003oooo
o`;o00000_ooool2o`0000Kooooo0_l0000Mooooo`;o00002Oooool2o`000003ooooool0003o0000
00Kooooo1?l00004ooooo`Ko000000Coooooo`000?l0003o00001?ooool3o`0000;ooooo0_l0000E
ooooo`;o0000;Oooool001cooooo00?o0000ooooooooool0>Oooool3o`0001Gooooo0_l0000Eoooo
o`;o000000?oooooo`000?l000002OoooolOo`000003ooooool0003o000000[ooooo0_l000001Ooo
oooo0000o`000?l0003ooooo00Co00001_ooool2o`000003ooooool0003o000000Oooooo0_l0000?
ooooo`Ko00004_ooool5o`0000?ooooo1?l00003ooooo`;o00001Oooool3o`000003ooooool0003o
000004Gooooo000Looooo`03o`000?oooooooooo03Wooooo0ol00005ooooo`;o0000;?ooool2o`00
00Gooooo5ol000000ooooooo0000o`000006o`0000cooooo0_l000001Ooooooo0000o`000?l0003o
oooo00;o00002oooool2o`0000Gooooo1?l0000?ooooo`;o00000_ooool2o`0001Gooooo0_l0000A
ooooo`;o00000_ooool2o`0004Gooooo000Looooo`03o`000?oooooooooo03Wooooo0_l00006oooo
o`;o0000:?ooool2o`0000;ooooo0_l000000ooooooo0000o`000004oooooako00001Oooool2o`00
00Wooooo1?l0000Cooooo`;o00009?ooool2o`0000Kooooo0_l0000Aooooo`;o0000BOooool001co
oooo00?o0000ooooooooool0@?ooool4o`0001Sooooo0_l0000=ooooo`;o00000oooool4o`0000Oo
oooo1_l00003ooooo`?o000000?oooooo`000?l000002_l00007ooooo`;o00001?ooool2o`0000?o
oooo1_l0000<ooooo`;o00001?ooool2o`0001gooooo0_l00004ooooo`;o00001_ooool2o`0000go
oooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`10ooooo`Go00003oooool3o`0000Gooooo
0_l0000Aooooo`?o00002?oooolLo`0000_ooooo0_l00005ooooo`Co00003?ooool2o`0000Cooooo
0_l0000:ooooo`;o00004Oooool2o`0000Cooooo0_l0000Eooooo`;o00004?ooool2o`0003_ooooo
000Looooo`03o`000?oooooooooo04?ooooo0_l0000?ooooo`?o00001Oooool2o`00013ooooo0ol0
0009oooooaco00001oooool2o`0000Gooooo0_l00002ooooo`;o00002oooool2o`0000Sooooo0_l0
0009ooooo`;o00001?ooool2o`0000_ooooo0_l00006ooooo`;o00003_ooool2o`0000Oooooo0_l0
000<ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0EOooool2o`0000Sooooo0_l00002
ooooo`;o00002Oooool2o`0000Gooooo0_l00003oooooa_o000000Coooooo`000?l0003ooooo0_l0
0002ooooo`;o00000oooool4o`0000;ooooo1Ol00008ooooo`;o00001_ooool4o`0000gooooo1?l0
000;ooooo`;o00001_ooool3o`0000_ooooo1?l00003ooooo`;o00000_ooool2o`000004ooooool0
003o0000o`0004Gooooo000Looooo`03o`000?oooooooooo05oooooo0_l00002ooooo`;o00004?oo
ool2o`0000Cooooo7Ol000001Ooooooo0000o`000?l0003ooooo00;o00000oooool6o`000003oooo
ool0003o000000;o00002Oooool2o`0000Cooooo0ol00006ooooo`;o00001Oooool4o`0000Sooooo
0_l000000ooooooo0000o`000002o`0000;ooooo0_l00002ooooo`?o00002?ooool2o`000003oooo
ool0003o000000Cooooo0ol00002ooooo`;o000000Coooooo`000?l0003o0000AOooool001cooooo
00?o0000ooooooooool0;_ooool2o`0002_ooooo0_l00007ooooo`;o00003oooool2o`0000;ooooo
1?l000000ooooooo0000o`00000Co`000003ooooool0003o000000;ooooo1?l0000:ooooo`?o0000
00?oooooo`000?l000000_l00008ooooo`;o00001?ooool2o`0000Oooooo0_l00003ooooo`Go0000
2Oooool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o000000?oooooo`000?l00000
1_ooool2o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`;o0000BOooool001cooooo0_l0
000_ooooo`;o00004_ooool4o`0000Oooooo0_l000000ooooooo0000o`000009ooooo`;o00001ooo
ool2o`0000_ooooo0_l00006ooooo`Co000000?oooooo`000?l000004?l000000ooooooo0000o`00
0002o`0000?ooooo0_l0000<ooooo`?o000000?oooooo`000?l000000_l00008ooooo`;o00001_oo
ool2o`0000Gooooo0_l000000ooooooo0000o`000002o`0001Sooooo0_l00002ooooo`;o00002ooo
ool3o`00057ooooo000Looooo`03o`000?oooooooooo04;ooooo1?l00003ooooo`;o00000_ooool5
o`000003ooooool0003o000000;ooooo0_l0000Hooooo`;o000000?oooooo`000?l000001Oooool=
o`000003ooooool0003o000000Go000000?oooooo`000?l000000_l0000@ooooo`?o00000_ooool4
o`0000Cooooo0_l00002ooooo`;o00000_ooool3o`000003ooooool0003o000000Sooooo1?l0000H
ooooo`;o00001Oooool2o`0000;ooooo0_l00003ooooo`?o0000D_ooool001cooooo00?o0000oooo
ooooool0A_ooool2o`000004ooooool0003o0000ooooo`Co00000oooool2o`0000;ooooo0_l00007
ooooo`;o00004_ooool2o`0000Gooooo1?l000000ooooooo0000o`000007o`0000Wooooo0ol0000@
ooooo`;o00000_ooool5o`0000Cooooo0_l00006ooooo`?o00001_ooool2o`0001_ooooo0_l00009
ooooo`;o00000_ooool3o`0000;ooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`16oooo
o`;o000000?oooooo`000?l000000ol000000ooooooo0000o`00000:ooooo`;o00000oooool4o`00
01Oooooo1Ol000000ooooooo0000o`000002o`000004ooooool0003o0000o`0000Wooooo0ol0000D
ooooo`Ko00005?ooool2o`0001;ooooo0_l00002ooooo`?o00000_ooool2o`0000Cooooo0_l00008
ooooo`;o00003Oooool2o`00013ooooo0_l0000fooooo`007?ooool00ol0003oooooooooo`15oooo
o`;o00000oooool3o`0000;ooooo0_l00007ooooo`Go00001Oooool2o`0000Oooooo0_l00002oooo
o`;o00002oooool4o`000003ooooool0003o000000;o00002Oooool4o`0001Cooooo0_l00003oooo
o`Co00004?ooool2o`0001Kooooo0_l00002ooooo`Co00001oooool2o`0000Wooooo0_l0000<oooo
o`;o00004?ooool2o`0003Kooooo000Looooo`03o`000?oooooooooo04Gooooo0_l00003ooooo`;o
00003?ooool3o`0000?ooooo0_l0000;ooooo`;o00000_ooool2o`0000_ooooo0_l000000ooooooo
0000o`000002o`0000_ooooo1?l0000Dooooo`;o00002_ooool2o`0000_ooooo0_l0000Looooo`Co
00000oooool7o`0000?ooooo0_l000000ooooooo0000o`000008ooooo`;o0000C?ooool001cooooo
00?o0000ooooooooool0COooool2o`0000[ooooo0ol00002ooooo`;o000000?oooooo`000?l00000
1Oooool3o`0001Cooooo0ol0000Kooooo`;o00002_ooool2o`0000Oooooo0_l0000=ooooo`;o0000
1Oooool2o`0000cooooo0_l00007ooooo`;o00000oooool7o`0000?ooooo1?l00007ooooo`Co0000
C?ooool001cooooo00?o0000ooooooooool0BOooool2o`000004ooooool0003o0000o`0000Gooooo
0_l00003ooooo`Co000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000002ooooo`?o
00000oooool2o`0000?ooooo0_l0000;ooooo`;o00001Oooool2o`0000Cooooo0_l00004ooooo`;o
00001Oooool6o`0000Gooooo0_l000001?oooooo0000o`000?l00007ooooo`?o00003?ooool2o`00
00Gooooo0_l00004ooooo`;o00001_ooool2o`0000;ooooo0_l00006ooooo`Go000000?oooooo`00
0?l000000_l00004ooooo`?o00001Oooool3o`0004kooooo000Looooo`03o`000?oooooooooo043o
oooo0_l00007ooooo`;o000000?oooooo`000?l000001_ooool2o`0000?ooooo1?l000000ooooooo
0000o`000004ooooo`;o00002?ooool2o`0000?ooooo0_l0000Booooo`;o00001?ooool2o`0000Co
oooo0_l00005ooooo`Ko000000Goooooo`000?l0003o0000ooooo`02o`000003ooooool0003o0000
00Sooooo0ol00003ooooo`;o00002_ooool4o`0000Kooooo0_l000000ooooooo0000o`000007oooo
o`;o00001_ooool3o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0004oooooo000Looooo`03
o`000?oooooooooo043ooooo0_l0000Dooooo`;o000000?oooooo`000?l000000_l00005ooooo`;o
00007oooool2o`0001Kooooo0ol00003ooooo`Co00001_ooool2o`000003ooooool0003o000000So
oooo0_l00005ooooo`;o00000oooool4o`0000;ooooo0_l00003ooooo`Go000000?oooooo`000?l0
00004?ooool4o`0000Cooooo0_l00007ooooo`;o0000Coooool001cooooo00?o0000ooooooooool0
?oooool2o`0000Sooooo0_l00002ooooo`;o00001oooool2o`000004ooooool0003o0000ooooo`;o
00001?ooool2o`0001_ooooo0_l00002ooooo`;o00006?ooool2o`0000Cooooo1?l00004ooooo`;o
000000Coooooo`000?l0003ooooo0_l0000<ooooo`;o00002?ooool3o`0000?ooooo1Ol000000ooo
oooo0000o`000005ooooo`;o000000?oooooo`000?l000001_ooool6o`000004ooooool0003o0000
o`0005Sooooo000Looooo`03o`000?oooooooooo03oooooo0_l00008ooooo`;o00000_ooool2o`00
00gooooo0_l00005ooooo`Co00001oooool2o`0000cooooo0_l000000ooooooo0000o`00000:oooo
o`;o00001_ooool2o`0000Sooooo0_l00006ooooo`;o00002_ooool2o`0000Cooooo0_l000001?oo
oooo0000o`000?ooool2o`000003ooooool0003o000000?ooooo1ol00004ooooo`?o00000_ooool2
o`0000Gooooo1Ol00005ooooo`;o00000oooool5o`0000;ooooo0_l0001Eooooo`007?ooool00ol0
003oooooooooo`10ooooo`;o00001?ooool2o`0000Gooooo0ol000000ooooooo0000o`00000>oooo
o`Ko00001oooool2o`0000cooooo0_l00004ooooo`;o00001oooool2o`0000Kooooo0_l00003oooo
o`;o00001?ooool2o`0001;ooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l00000
0ooooooo0000o`000003ooooo`Co000000?oooooo`000?l000001?ooool3o`0000;ooooo1?l00004
ooooo`;o00001oooool3o`0000?ooooo0_l00002ooooo`Co000000Coooooo`000?l0003ooooo1?l0
0002ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0?_ooool4o`0000Cooooo0_l00006
ooooo`;o000000?oooooo`000?l000001Oooool2o`0000;ooooo0ol00002ooooo`;o00007Oooool4
o`0000Cooooo0_l0000=ooooo`Ko000000?oooooo`000?l000001?l0000>ooooo`Co00004oooool2
o`0000Gooooo1?l000000ooooooo0000o`000004o`000003ooooool0003o000000;o00001oooool2
o`0000Oooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o0000BOooool0
01cooooo00?o0000ooooooooool0?_ooool2o`0000Gooooo0ol0000@ooooo`;o00000_ooool3o`00
00Sooooo0_l0000Gooooo`;o00001_ooool4o`0000_ooooo1_l000000ooooooo0000o`000004o`00
0003ooooool0003o000000_ooooo1?l0000Booooo`?o00001oooool2o`000003ooooool0003o0000
00Co000000?oooooo`000?l000000_l00007ooooo`;o00002oooool2o`0005?ooooo000Looooo`03
o`000?oooooooooo04Gooooo0ol00007ooooo`;o00003?ooool2o`0000Sooooo0_l0000Qooooo`;o
00002?ooool2o`0000Sooooo2_l00009ooooo`?o00000_ooool3o`0000Gooooo0_l00008ooooo`;o
00003Oooool2o`0001_ooooo0_l00002ooooo`;o0000Coooool001cooooo0_l0001@ooooo`;o0000
2Oooool2o`000003ooooool0003o000000Sooooo0_l0000Booooo`;o00000_ooool2o`0000_ooooo
0ol00005ooooo`Co00000oooool=o`0000Wooooo0_l00003ooooo`?o00000_ooool2o`000003oooo
ool0003o000000;ooooo0_l0000:ooooo`Go00000_ooool2o`0000Cooooo0_l0000Kooooo`?o0000
00?oooooo`000?l00000Boooool001cooooo00?o0000ooooooooool0F_ooool2o`0000[ooooo0ol0
000Booooo`;o00000_ooool2o`0000_ooooo0ol00007ooooo`;o00000oooool?o`0000[ooooo1?l0
0003ooooo`;o00001Oooool2o`0000[ooooo1Ol00002ooooo`;o00000_ooool4o`0001Kooooo0_l0
0004ooooo`Go0000Boooool001cooooo00?o0000ooooooooool0>?ooool2o`0002;ooooo0_l00008
ooooo`?o0000;Oooool2o`0000;ooooo4?l00005ooooo`;o00000oooool4o`0000?ooooo0_l0000>
ooooo`So00001_ooool2o`0000?ooooo0_l0000Cooooo`;o000000?oooooo`000?l000000_ooool2
o`0004gooooo000Looooo`03o`000?oooooooooo03Sooooo0_l0000Rooooo`;o00002Oooool2o`00
01Gooooo1Ol0000Cooooo`?o000000?oooooo`000?l000003ol00004ooooo`;o00003_ooool2o`00
00[ooooo1Ol000000ooooooo0000o`00000:ooooo`?o00001?ooool2o`00013ooooo0_l0001Aoooo
o`007?ooool00ol0003oooooooooo`1Oooooo`;o00000_ooool2o`0001Wooooo1Ol00004ooooo`;o
00000oooool3o`0000Sooooo0_l000000ooooooo0000o`00000?o`0001Cooooo0_l00004ooooo`?o
00003oooool2o`0000;ooooo1?l00004ooooo`?o0000Hoooool001cooooo00?o0000ooooooooool0
D_ooool2o`0000_ooooo0_l00002ooooo`Go000000?oooooo`000?l000005_ooool2o`0000;ooooo
1?l00003ooooo`?o00002_oooolBo`0000;ooooo0_l00007ooooo`;o000000?oooooo`000?l00000
2_ooool5o`0000gooooo1_l00006ooooo`;o00004Oooool2o`00057ooooo000Looooo`03o`000?oo
oooooooo05;ooooo0_l0000@ooooo`Co000000Coooooo`000?l0003o00005?ooool2o`0000?ooooo
0_l00006ooooo`;o00002_oooolCo`000003ooooool0003o000000Oooooo1Ol00003ooooo`?o0000
1oooool2o`0000oooooo1?l00006ooooo`;o00004?ooool3o`00057ooooo000Looooo`03o`000?oo
oooooooo04gooooo0ol0000Jooooo`;o00001Oooool5o`0000Sooooo1?l00002ooooo`;o00001ooo
ool2o`0000[ooooo2ol000000ooooooo0000o`000005o`0000[ooooo0ol00005ooooo`?o00002Ooo
ool2o`0000oooooo0ol00008ooooo`;o00003Oooool2o`0000_ooooo0_l00015ooooo`007?ooool0
0ol0003oooooooooo`1=ooooo`?o00003oooool2o`00013ooooo1Ol00007ooooo`?o00001?ooool2
o`0001?ooooo2ol00002ooooo`Go00002oooool2o`000003ooooool0003o000000oooooo0_l00009
ooooo`;o00001?ooool3o`0000Sooooo0_l0000:ooooo`;o00003_ooool2o`0004Gooooo000Loooo
o`03o`000?oooooooooo04Oooooo0_l0000Fooooo`;o00000_ooool2o`0000?ooooo0_l0000Coooo
o`;o00000oooool2o`0001?ooooo5?l0000>ooooo`;o00002Oooool2o`0000?ooooo0ol000000ooo
oooo0000o`000002ooooo`;o00000_ooool2o`0001Cooooo0_l00002ooooo`;o000000?oooooo`00
0?l00000EOooool001cooooo00?o0000ooooooooool0Aoooool2o`0000Cooooo0_l0000Dooooo`;o
00000oooool2o`0000Kooooo0_l0000=ooooo`;o000000?oooooo`000?l000000oooool2o`0000ko
oooo5Ol0000=ooooo`;o00002Oooool2o`000003ooooool0003o000000;o00000_ooool2o`0000;o
oooo0_l00002ooooo`;o00002?ooool2o`000003ooooool0003o000000Oooooo0_l00002ooooo`Co
0000E_ooool001cooooo00?o0000ooooooooool0COooool2o`0000?ooooo0_l0000Looooo`;o0000
3Oooool2o`0000Cooooo1?l00004ooooo`;o00002?oooolFo`0000cooooo0_l00009ooooo`Go0000
1_ooool2o`0000Cooooo0_l00005ooooo`;o000000Coooooo`000?l0003ooooo0_l00005ooooo`;o
00000oooool2o`000003ooooool0003o000005Kooooo000Looooo`03o`000?oooooooooo05;ooooo
1?l0000Jooooo`;o00004oooool2o`0000Kooooo0_l00008ooooo`;o00000_ooool;o`000003oooo
ool0003o000000Co00006?ooool2o`0000;ooooo0_l00004ooooo`;o00002?ooool6o`0000[ooooo
0_l00003ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0Doooool4o`0000_ooooo0_l0
00000ooooooo0000o`000009ooooo`;o00003Oooool4o`0001Oooooo4_l0000:ooooo`;o00002?oo
ool2o`0000?ooooo0_l00002ooooo`;o00001oooool2o`0000Gooooo2?l0000=ooooo`;o0000FOoo
ool001cooooo00?o0000ooooooooool0Doooool4o`0000_ooooo1Ol00006ooooo`;o00000oooool2
o`0000_ooooo1?l0000<ooooo`?o00001ooooolBo`0000_ooooo0_l00008ooooo`;o00000oooool4
o`0000Wooooo0_l00003ooooo`;o00001_ooool2o`0000gooooo0_l0001Iooooo`007?ooool00ol0
003oooooooooo`1Aooooo`;o00004?ooool2o`0000Sooooo0_l00003ooooo`;o00001_ooool2o`00
01?ooooo0ol00007oooooa;o00003_ooool2o`0000?ooooo0_l00007ooooo`;o00002?ooool2o`00
00;ooooo1?l0000Booooo`?o0000Foooool001cooooo0_l0001Booooo`;o00009oooool3o`0001_o
oooo1?l000000ooooooo0000o`00000;o`0000Kooooo1?l00004ooooo`?o00000oooool2o`0000Wo
oooo0_l00006ooooo`;o00000_ooool2o`0000[ooooo1?l00006ooooo`?o0000Foooool001cooooo
00?o0000ooooooooool0C?ooool2o`0000?ooooo0_l00006ooooo`;o00008?ooool2o`0001Oooooo
0_l000000ooooooo0000o`000002o`000003ooooool0003o000000co00000_ooool2o`0000;ooooo
1?l00004ooooo`;o00002Oooool2o`0000Cooooo0_l0000@ooooo`?o00000oooool4o`0006Cooooo
000Looooo`03o`000?oooooooooo04cooooo0_l0000;ooooo`;o00008?ooool2o`0000;ooooo0_l0
000Aooooo`Co000000?oooooo`000?l000000_l000000ooooooo0000o`00000<o`0000;ooooo0_l0
0005ooooo`;o00002Oooool2o`000003ooooool0003o000000?o000000?oooooo`000?l000004_oo
ool3o`0000Cooooo0_l00005ooooo`;o0000G_ooool001cooooo00?o0000ooooooooool0Noooool2
o`0000;ooooo0_l0000:ooooo`;o00001Oooool2o`0000Sooooo3ol00008ooooo`;o00001_ooool2
o`000004ooooool0003o0000ooooo`;o000000Coooooo`000?l0003ooooo0_l00007ooooo`Go0000
5?ooool2o`0005kooooo000Looooo`03o`000?oooooooooo04oooooo0_l0000jooooo`;o00002ooo
ool4o`000003ooooool0003o000000co00004?ooool2o`0000Cooooo0_l000001?oooooo0000o`00
0?l00009ooooo`Ko0000Loooool001cooooo00?o0000ooooooooool0AOooool2o`0000Oooooo0ol0
0017ooooo`Co000000?oooooo`000?l000002?l000001?oooooo0000o`000?l00003ooooo`;o0000
2?ooool2o`0000Oooooo0_l000001?oooooo0000o`000?l0000=ooooo`?o00000oooool2o`0006go
oooo000Looooo`03o`000?oooooooooo04Gooooo0_l00007ooooo`;o0000;Oooool2o`0001;ooooo
0_l0000=ooooo`Ko00002?ooool2o`000003ooooool0003o000000Gooooo0_l0000;ooooo`?o0000
3Oooool2o`0000?ooooo0_l0000Aooooo`;o0000F_ooool001cooooo00?o0000ooooooooool0OOoo
ool2o`0001;ooooo0_l0000:ooooo`;o000000Coooooo`000?l0003o00003_ooool2o`0000Kooooo
0_l00002ooooo`;o00001oooool2o`0002Gooooo0_l00002ooooo`;o0000E_ooool001cooooo00?o
0000ooooooooool0EOooool2o`0001Kooooo0_l00004ooooo`;o00002?ooool2o`0000Kooooo0_l0
000Fooooo`Co000000Coooooo`000?l0003o00004Oooool2o`000003ooooool0003o000000;ooooo
0_l00004ooooo`;o000000?oooooo`000?l000002Oooool2o`000004ooooool0003o0000o`0000[o
oooo0_l0000>ooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0EOooool2o`0001Kooooo
0_l00004ooooo`;o00004?ooool2o`0000Kooooo0_l0000?ooooo`?o000000Coooooo`000?l0003o
00004Oooool2o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool2o`0000Ko
oooo1?l000001?oooooo0000o`000?l00002ooooo`;o00001_ooool2o`0006Kooooo000Looooo`03
o`000?oooooooooo08gooooo0_l00007ooooo`;o00001_ooool2o`000003ooooool0003o000001Ko
oooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00002ooooo`;o00001_ooool2o`00
00Cooooo0_l00002ooooo`;o00001_ooool2o`0006Kooooo000Looooo`03o`000?oooooooooo05[o
oooo0_l0000jooooo`;o00002Oooool2o`0000Cooooo0_l00003ooooo`?o00002_ooool2o`0000[o
oooo0_l00005ooooo`;o00004oooool2o`0006Kooooo000Looooo`03o`000?oooooooooo05[ooooo
0_l0000Vooooo`;o00007Oooool2o`0000Cooooo0_l00003ooooo`?o00003Oooool2o`0000Oooooo
0_l00005ooooo`;o00005oooool2o`0006;ooooo000Looooo`03o`000?oooooooooo07cooooo0_l0
0004ooooo`;o000000?oooooo`000?l000003?ooool3o`0000_ooooo0_l0000Iooooo`;o00009ooo
ool2o`0006;ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<
c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1looooo`;o00001oooool2o`0000co
oooo0ol00009ooooo`;o00002?ooool2o`0000Kooooo0_l00007ooooo`?o00007_ooool2o`0006co
oooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B401_ooool00ol0003oooooooooo`1jooooo`;o00008oooool2o`0000Sooooo0_l00006
ooooo`;o00001oooool3o`0000oooooo0_l000000ooooooo0000o`000003ooooo`;o00001Oooool2
o`0006cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo07[ooooo0_l00005ooooo`;o0000BOooool2
o`000003ooooool0003o000000?ooooo0_l0001cooooo`0000?oooooo`000?ooool00_ooool00ol0
003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`00067ooooo0_l00004
ooooo`;o00001_ooool2o`0000[ooooo0_l00004ooooo`;o00007?ooool2o`0000Wooooo0_l0000D
ooooo`;o00003Oooool3o`0007Oooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00Wooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo067ooooo0_l00002
ooooo`Co00001?ooool4o`0000[ooooo0_l0000Nooooo`;o00000_ooool2o`0000Wooooo0_l0000?
ooooo`;o00000oooool2o`0000[ooooo0_l000001?oooooo0000o`000?l0001gooooo`0000?ooooo
oa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_oo
ool00ol0003oooooooooo`1Uooooo`;o00001_ooool2o`0002cooooo0_l0000=ooooo`;o00003ooo
ool2o`0000;ooooo0_l0000:ooooo`?o000000?oooooo`000?l00000N?ooool00006oooooomgMgOo
V9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000oooooooo
ool0]Oooool2o`0000Sooooo0_l0000:ooooo`?o000000?oooooo`000?l000001_ooool2o`00073o
oooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06
ooooo`03o`000?oooooooooo09kooooo0_l0000Eooooo`;o00002_ooool2o`0000Wooooo0_l00009
ooooo`;o00000oooool2o`0006_ooooo000Looooo`03o`000?oooooooooo09kooooo0ol00005oooo
o`;o00006?ooool3o`0001Wooooo0_l0001[ooooo`007?ooool00ol0003oooooooooo`2Oooooo`?o
00001?ooool2o`0001Sooooo0_l00007ooooo`;o0000O_ooool001cooooo00?o0000ooooooooool0
VOooool3o`0000?ooooo1Ol0000Mooooo`;o00001_ooool2o`0007kooooo000Looooo`03o`000?oo
oooooooo07cooooo0_l0000Kooooo`?o00000oooool2o`000003ooooool0003o000001cooooo0ol0
0026ooooo`007?ooool00ol0003oooooooooo`1looooo`;o00006oooool2o`0000Oooooo0_l0000L
ooooo`;o0000Qoooool001cooooo00?o0000ooooooooool0X_ooool2o`0001Sooooo0_l0002;oooo
o`007?ooool00ol0003oooooooooo`1oooooo`;o00004?ooool2o`0002Wooooo0_l0002;ooooo`00
7?ooool00ol0003oooooooooo`1oooooo`;o00004?ooool2o`000;Kooooo000Looooo`03o`000?oo
oooooooo08;ooooo0_l0000aooooo`;o00004Oooool2o`0007oooooo000Looooo`03o`000?oooooo
oooo08;ooooo0_l00004ooooo`;o0000:oooool2o`00017ooooo0_l0001oooooo`007?ooool00ol0
003oooooooooo`28ooooo`;o000000?oooooo`000?l00000_?ooool001cooooo0_l0002<ooooo`;o
0000_?ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`2<ooooo`;o00001oooool2o`0001gooooo0_l00003ooooo`;o0000S_ooool001cooooo00?o0000
ooooooooool0S?ooool2o`0000Oooooo0_l000000ooooooo0000o`00000Jooooo`;o00000oooool2
o`0008kooooo000Looooo`03o`000?oooooooooo09Sooooo0_l0002_ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo07kooooo0_l0000dooooo`;o0000
Toooool001cooooo00?o0000ooooooooool0O_ooool2o`0003Cooooo0_l0002Cooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0:Kooooo0_l0002Qoooo
o`007?ooool00ol0003oooooooooo`2Vooooo`;o0000XOooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBooo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
4_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom:ooooo`005?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000
ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o0000ooooooooool0oooooomBoooo
o`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?oooooo
D_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`004_ooool00omEEEGoIVIVo`00003o
oooooeCooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Uooooo`04oa0@4?l0
003o0000ooooo`;o000000?o410@ooooooooool05Oooool01?l@413o0000odA4A?o<c<`6ooooo`;o
000000Wo410@ooooooooooooooooolc<c?lQ8B7o0000ob4Q8Oo<c<`0T?ooool00:Kooooo00Go0000
ooooooooooooooooo`000009ooooo`Ko00002oooool00onHV9So410@omgMg@06ooooo`03o`000?oo
oooooooo00;ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@2@ooooo`00Y_ooool01Ol0003ooooooooo
oooooooo000001_ooooo00?oQhN7oeEEEOooool00_ooool5o`0000?ooooo00Go0000oooooooooooo
ooooo`00002@ooooo`00Y_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l00009ooooo`05
olc<c?lQ8B7o0000oeEEEOl000000oooool01?m4A4CogMgMooooool00004ooooo`05oc8b<_nHV9So
oooooiRHV?lb<S80T?ooool00:Kooooo00Go0000ohN7QoooooooZJVYo`00000Hooooo`05ob4Q8On7
QhOooooooiRHV?l000000oooool01?oMgMgoEEEEooooool00004ooooo`05olc<c?l0003o0000o`00
0?o<c<`0T?ooool00:Gooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Fooooo`05
o`000?ooooooooooooooool000001?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?nj^[[ooooo
okZj^_l@4100T?ooool00<?ooooo00Go8B4QoiRHV?ooooooMgMgoeEEE@04ooooo`03onk^k_m4A4Co
000000Cooooo00Go0000okZj^_oooooo^[Zjo`00002@ooooo`00`oooool01Oo<c<co410@o`000?lb
<S;ok^k^00Gooooo00?oMgMgo`000?ooool00oooool01OnYZJWo410@o`000?l@413oZJVY093ooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(954) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.5076 .33434 Mdot
.5477 .32608 Mdot
.38769 .57968 Mdot
.62302 .55743 Mdot
.48719 .28956 Mdot
.40628 .62049 Mdot
.35995 .36852 Mdot
.359 .41762 Mdot
.39525 .60548 Mdot
.51292 .56545 Mdot
.34909 .39728 Mdot
.65958 .57638 Mdot
.37368 .39808 Mdot
.6152 .54449 Mdot
.76219 .72818 Mdot
.54436 .53207 Mdot
.56187 .31458 Mdot
.48796 .69681 Mdot
.6597 .56229 Mdot
.38835 .57162 Mdot
.55429 .28341 Mdot
.62672 .5465 Mdot
.5119 .34275 Mdot
.61538 .54402 Mdot
.59696 .55845 Mdot
.52568 .32437 Mdot
.5048 .30022 Mdot
.61197 .57041 Mdot
.56773 .52768 Mdot
.38358 .41178 Mdot
.58576 .74554 Mdot
.82337 .61766 Mdot
.56292 .57301 Mdot
.46069 .18322 Mdot
.34655 .41234 Mdot
.78445 .50948 Mdot
.37084 .61429 Mdot
.38816 .3914 Mdot
.35213 .41383 Mdot
.3713 .42701 Mdot
.38092 .40359 Mdot
.53047 .32904 Mdot
.31572 .35791 Mdot
.30695 .40154 Mdot
.64044 .48885 Mdot
.42189 .31421 Mdot
.72367 .63493 Mdot
.60468 .49787 Mdot
.55167 .3082 Mdot
.3965 .57516 Mdot
.438 .19977 Mdot
.39901 .3993 Mdot
.32044 .50925 Mdot
.84738 .33705 Mdot
.38445 .38055 Mdot
.65352 .50182 Mdot
.37684 .60372 Mdot
.63308 .53391 Mdot
.61914 .54037 Mdot
.69634 .46171 Mdot
.57919 .56155 Mdot
.47299 .71554 Mdot
.5769 .33518 Mdot
.4517 .62288 Mdot
.39612 .6153 Mdot
.35549 .41319 Mdot
.56168 .33134 Mdot
.3724 .39113 Mdot
.66906 .50591 Mdot
.41152 .64091 Mdot
.6059 .49802 Mdot
.36114 .41112 Mdot
.53613 .3785 Mdot
.62423 .49923 Mdot
.21542 .42111 Mdot
.62252 .81872 Mdot
.44618 .72421 Mdot
.71498 .4607 Mdot
.74117 .51978 Mdot
.40863 .75813 Mdot
.57922 .52969 Mdot
.32698 .78415 Mdot
.72111 .75684 Mdot
.50943 .32706 Mdot
.54182 .48488 Mdot
.41872 .65614 Mdot
.63155 .5034 Mdot
.48455 .41553 Mdot
.6388 .47835 Mdot
.26764 .33529 Mdot
.39235 .59988 Mdot
.54353 .3513 Mdot
.62083 .55679 Mdot
.55791 .53083 Mdot
.63821 .34002 Mdot
.61087 .57732 Mdot
.62834 .56512 Mdot
.49949 .33491 Mdot
.34134 .38847 Mdot
.65058 .59118 Mdot
.32254 .40984 Mdot
.34439 .54329 Mdot
.64981 .50861 Mdot
.36692 .59396 Mdot
.50103 .35153 Mdot
.63621 .50216 Mdot
.33348 .37817 Mdot
.5847 .50546 Mdot
.3013 .39887 Mdot
.55152 .325 Mdot
.55789 .52782 Mdot
.49346 .74401 Mdot
.19597 .54047 Mdot
.54335 .35563 Mdot
.37978 .55151 Mdot
.57471 .50912 Mdot
.64318 .54208 Mdot
.54567 .32829 Mdot
.42899 .61695 Mdot
.51043 .46316 Mdot
.54355 .29543 Mdot
.3615 .42488 Mdot
.56095 .30278 Mdot
.53779 .50086 Mdot
.40516 .60784 Mdot
.32863 .53324 Mdot
.31764 .52233 Mdot
.55589 .70427 Mdot
.6356 .50826 Mdot
.4218 .2404 Mdot
.41782 .62179 Mdot
.54016 .34463 Mdot
.36907 .39288 Mdot
.60637 .46573 Mdot
.54808 .36549 Mdot
.35511 .38471 Mdot
.46679 .75634 Mdot
.31683 .58957 Mdot
.54466 .30112 Mdot
.29746 .3622 Mdot
.39702 .42118 Mdot
.37156 .42901 Mdot
.43801 .18648 Mdot
.54653 .3194 Mdot
.48402 .74038 Mdot
.36071 .38193 Mdot
.66334 .71357 Mdot
.65853 .5025 Mdot
.51691 .65264 Mdot
.22869 .70646 Mdot
.41441 .20232 Mdot
.26321 .48397 Mdot
.48696 .70197 Mdot
.37702 .43104 Mdot
.57676 .54702 Mdot
.53814 .3112 Mdot
.5357 .31796 Mdot
.64209 .5633 Mdot
.61065 .56249 Mdot
.61197 .49658 Mdot
.55947 .52666 Mdot
.73957 .65116 Mdot
.59242 .49381 Mdot
.50018 .7909 Mdot
.53531 .35473 Mdot
.58798 .56087 Mdot
.42734 .60231 Mdot
.58938 .47923 Mdot
.37265 .4097 Mdot
.6346 .54122 Mdot
.62251 .56017 Mdot
.55529 .53456 Mdot
.37748 .37028 Mdot
.8138 .60317 Mdot
.20945 .66225 Mdot
.81389 .4377 Mdot
.34727 .50631 Mdot
.38912 .62543 Mdot
.64465 .5171 Mdot
.47298 .73313 Mdot
.77004 .46826 Mdot
.59057 .53363 Mdot
.22008 .31995 Mdot
.63068 .56101 Mdot
.58196 .23359 Mdot
.71138 .53439 Mdot
.81597 .42182 Mdot
.51063 .68236 Mdot
.56496 .53103 Mdot
.64902 .30691 Mdot
.70155 .28978 Mdot
.35153 .45932 Mdot
.3822 .40011 Mdot
.42449 .60006 Mdot
.37605 .59547 Mdot
.40218 .38098 Mdot
.66963 .59048 Mdot
.69531 .53935 Mdot
.67328 .49289 Mdot
.32591 .52302 Mdot
.56534 .38083 Mdot
.45466 .72114 Mdot
.50333 .35156 Mdot
.44133 .85148 Mdot
.30074 .31291 Mdot
.30632 .36435 Mdot
.44865 .7446 Mdot
.39993 .5865 Mdot
.32599 .52067 Mdot
.47106 .73893 Mdot
.59852 .51505 Mdot
.55628 .32087 Mdot
.57373 .19597 Mdot
.68825 .58552 Mdot
.57089 .17733 Mdot
.56199 .36437 Mdot
.50026 .46258 Mdot
.35659 .39468 Mdot
.35275 .55958 Mdot
.64203 .54763 Mdot
.61534 .51382 Mdot
.57198 .29914 Mdot
.60591 .50033 Mdot
.52246 .26433 Mdot
.642 .55436 Mdot
.34009 .56259 Mdot
.44688 .7186 Mdot
.4009 .37688 Mdot
.54746 .70227 Mdot
.52141 .36528 Mdot
.48217 .67402 Mdot
.43801 .61873 Mdot
.76906 .50158 Mdot
.35508 .40853 Mdot
.48747 .7515 Mdot
.43481 .62184 Mdot
.45867 .71147 Mdot
.58934 .48357 Mdot
.37647 .62594 Mdot
.48796 .71309 Mdot
.77318 .63922 Mdot
.62176 .47272 Mdot
.72847 .68241 Mdot
.35589 .36891 Mdot
.5627 .30506 Mdot
.58455 .5639 Mdot
.35325 .55327 Mdot
.56306 .568 Mdot
.24209 .43393 Mdot
.31264 .51267 Mdot
.32402 .50735 Mdot
.43021 .76151 Mdot
.49252 .74117 Mdot
.22841 .48701 Mdot
.40631 .23373 Mdot
.56154 .31642 Mdot
.66129 .53187 Mdot
.82809 .4928 Mdot
.36076 .38272 Mdot
.59419 .51792 Mdot
.36622 .63291 Mdot
.36336 .38124 Mdot
.63379 .53079 Mdot
.35704 .36383 Mdot
.53962 .31594 Mdot
.27185 .66758 Mdot
.56367 .31757 Mdot
.62641 .4745 Mdot
.34083 .3698 Mdot
.40287 .63438 Mdot
.5233 .32252 Mdot
.58795 .50623 Mdot
.65103 .53876 Mdot
.33375 .53213 Mdot
.5733 .55332 Mdot
.81664 .51997 Mdot
.56379 .54688 Mdot
.37716 .57847 Mdot
.60392 .57494 Mdot
.27212 .2717 Mdot
.29698 .61125 Mdot
.56125 .32961 Mdot
.32623 .50914 Mdot
.38996 .60541 Mdot
.36703 .71807 Mdot
.35731 .47457 Mdot
.57724 .51688 Mdot
.34332 .53251 Mdot
.49815 .64617 Mdot
.39467 .39724 Mdot
.64272 .57349 Mdot
.3242 .3177 Mdot
.426 .59747 Mdot
.32881 .52415 Mdot
.63508 .45805 Mdot
.50294 .35814 Mdot
.61982 .55773 Mdot
.405 .63738 Mdot
.55599 .29614 Mdot
.61596 .47697 Mdot
.65851 .63773 Mdot
.31477 .51449 Mdot
.3615 .37043 Mdot
.69138 .49323 Mdot
.60281 .49325 Mdot
.3729 .61148 Mdot
.53573 .37343 Mdot
.34484 .41305 Mdot
.52632 .33534 Mdot
.63761 .23304 Mdot
.30344 .48529 Mdot
.75806 .61826 Mdot
.46003 .76943 Mdot
.2722 .43622 Mdot
.80715 .39267 Mdot
.21834 .52513 Mdot
.63322 .69974 Mdot
.70082 .24891 Mdot
.43231 .62 Mdot
.34238 .59813 Mdot
.38438 .60478 Mdot
.58979 .54571 Mdot
.40199 .61802 Mdot
.81668 .41041 Mdot
.63883 .55771 Mdot
.38109 .6208 Mdot
.30712 .69234 Mdot
.60707 .5651 Mdot
.54419 .3576 Mdot
.75774 .72537 Mdot
.1983 .42002 Mdot
.33178 .26353 Mdot
.41036 .63011 Mdot
.68661 .47431 Mdot
.61104 .56926 Mdot
.54973 .52394 Mdot
.52928 .3088 Mdot
.63172 .57575 Mdot
.45578 .71986 Mdot
.44974 .74324 Mdot
.50438 .61943 Mdot
.24119 .68942 Mdot
.65158 .58938 Mdot
.52422 .3186 Mdot
.73919 .54695 Mdot
.22929 .39755 Mdot
.36131 .55298 Mdot
.32006 .39286 Mdot
.80517 .61918 Mdot
.68617 .57113 Mdot
.31963 .34631 Mdot
.30597 .32838 Mdot
.55257 .3402 Mdot
.80769 .57697 Mdot
.38416 .39312 Mdot
.69527 .33838 Mdot
.60994 .33532 Mdot
.60857 .51605 Mdot
.34885 .40285 Mdot
.65479 .5829 Mdot
.24704 .33513 Mdot
.66621 .73227 Mdot
.4504 .81735 Mdot
.63138 .47948 Mdot
.21662 .47189 Mdot
.6386 .5428 Mdot
.52016 .46152 Mdot
.56428 .54857 Mdot
.52268 .33666 Mdot
.52675 .57808 Mdot
.43779 .44152 Mdot
.24195 .71153 Mdot
.3053 .30434 Mdot
.48469 .7008 Mdot
.64662 .5426 Mdot
.60987 .51664 Mdot
.47595 .75134 Mdot
.51766 .34784 Mdot
.56086 .5288 Mdot
.5714 .65399 Mdot
.61432 .50302 Mdot
.38425 .40242 Mdot
.54448 .73833 Mdot
.54841 .2702 Mdot
.55864 .55024 Mdot
.54549 .28942 Mdot
.37651 .37189 Mdot
.36252 .41708 Mdot
.61053 .45712 Mdot
.33426 .40804 Mdot
.63096 .55732 Mdot
.5811 .78989 Mdot
.51435 .31248 Mdot
.70709 .56846 Mdot
.52435 .36106 Mdot
.73718 .48701 Mdot
.33476 .37378 Mdot
.33334 .54022 Mdot
.58922 .3009 Mdot
.38202 .3942 Mdot
.36231 .24464 Mdot
.68112 .51472 Mdot
.5973 .58452 Mdot
.27692 .31279 Mdot
.41582 .63162 Mdot
.31959 .5219 Mdot
.33093 .39139 Mdot
.60532 .49314 Mdot
.62651 .58172 Mdot
.39077 .38226 Mdot
.66571 .35915 Mdot
.36778 .70797 Mdot
.61964 .56943 Mdot
.51978 .33927 Mdot
.53809 .3441 Mdot
.6211 .48326 Mdot
.58469 .51404 Mdot
.39828 .59022 Mdot
.32975 .51451 Mdot
.35166 .54325 Mdot
.31704 .51973 Mdot
.34624 .56733 Mdot
.46069 .29387 Mdot
.37097 .42751 Mdot
.43954 .25321 Mdot
.26394 .36573 Mdot
.57345 .59233 Mdot
.38012 .62522 Mdot
.61444 .52325 Mdot
.62559 .55393 Mdot
.34395 .41273 Mdot
.30648 .46682 Mdot
.53686 .49475 Mdot
.52654 .30208 Mdot
.32953 .38848 Mdot
.68186 .56139 Mdot
.48747 .24516 Mdot
.47903 .70882 Mdot
.32055 .26664 Mdot
.35719 .41115 Mdot
.55366 .34618 Mdot
.36336 .35998 Mdot
.61321 .51182 Mdot
.66657 .52764 Mdot
.54751 .3353 Mdot
.49672 .7248 Mdot
.64872 .47196 Mdot
.63606 .53026 Mdot
.13894 .49686 Mdot
.2092 .43132 Mdot
.41579 .35945 Mdot
.56933 .5405 Mdot
.60942 .58176 Mdot
.47189 .69902 Mdot
.61269 .50646 Mdot
.6538 .53638 Mdot
.18952 .56374 Mdot
.41874 .35307 Mdot
.48752 .69407 Mdot
.70238 .34449 Mdot
.56323 .36248 Mdot
.82699 .54856 Mdot
.34901 .54202 Mdot
.36991 .35153 Mdot
.26241 .6405 Mdot
.32825 .51937 Mdot
.24844 .4261 Mdot
.81891 .56542 Mdot
.31765 .51988 Mdot
.45627 .65257 Mdot
.52489 .51092 Mdot
.6323 .56679 Mdot
.64151 .53803 Mdot
.47835 .73214 Mdot
.54488 .31752 Mdot
.49068 .59614 Mdot
.67045 .75229 Mdot
.63269 .54635 Mdot
.49941 .28865 Mdot
.77693 .65018 Mdot
.33391 .5297 Mdot
.45626 .72637 Mdot
.47536 .76236 Mdot
.64638 .53845 Mdot
.20488 .57995 Mdot
.52606 .32216 Mdot
.58756 .50667 Mdot
.58764 .49352 Mdot
.40551 .6306 Mdot
.55792 .33175 Mdot
.43318 .6296 Mdot
.31263 .5167 Mdot
.7316 .30647 Mdot
.13842 .46237 Mdot
.33684 .40289 Mdot
.8039 .50901 Mdot
.39097 .40697 Mdot
.45982 .80956 Mdot
.32358 .51396 Mdot
.58391 .53039 Mdot
.52601 .37036 Mdot
.58691 .50382 Mdot
.59698 .52406 Mdot
.59956 .51577 Mdot
.68118 .53691 Mdot
.23129 .30888 Mdot
.46441 .72987 Mdot
.54236 .50985 Mdot
.37771 .58005 Mdot
.80835 .51921 Mdot
.68126 .77162 Mdot
.62058 .51877 Mdot
.65094 .53129 Mdot
.54489 .3612 Mdot
.64194 .56523 Mdot
.39367 .39259 Mdot
.53618 .37396 Mdot
.55647 .52328 Mdot
.79983 .57641 Mdot
.56348 .51997 Mdot
.80599 .40932 Mdot
.36435 .35971 Mdot
.35925 .24843 Mdot
.54955 .49477 Mdot
.32119 .52785 Mdot
.31933 .52158 Mdot
.34041 .52092 Mdot
.35075 .35598 Mdot
.37583 .61612 Mdot
.60926 .80005 Mdot
.58879 .59425 Mdot
.58143 .55037 Mdot
.62806 .58232 Mdot
.35816 .60525 Mdot
.48485 .41037 Mdot
.24275 .4957 Mdot
.68642 .55017 Mdot
.40919 .60213 Mdot
.56217 .30267 Mdot
.43956 .58048 Mdot
.52802 .3687 Mdot
.48201 .69044 Mdot
.35122 .39942 Mdot
.47079 .70869 Mdot
.39257 .2169 Mdot
.54995 .32616 Mdot
.57283 .29955 Mdot
.38632 .62447 Mdot
.48477 .45584 Mdot
.83388 .33813 Mdot
.4118 .64243 Mdot
.57052 .68103 Mdot
.52333 .31253 Mdot
.57622 .49962 Mdot
.52431 .69775 Mdot
.48603 .44805 Mdot
.38298 .61645 Mdot
.59248 .53934 Mdot
.22763 .62701 Mdot
.40024 .59141 Mdot
.644 .5733 Mdot
.42498 .61273 Mdot
.36855 .4084 Mdot
.42189 .6199 Mdot
.55861 .37901 Mdot
.64002 .50629 Mdot
.84738 .35826 Mdot
.50366 .68523 Mdot
.56581 .54776 Mdot
.32993 .38556 Mdot
.56936 .63877 Mdot
.6065 .52938 Mdot
.45137 .73524 Mdot
.40699 .6075 Mdot
.37385 .68893 Mdot
.60383 .56903 Mdot
.40376 .62475 Mdot
.50969 .34141 Mdot
.35571 .35487 Mdot
.45823 .7975 Mdot
.33944 .54314 Mdot
.53343 .3069 Mdot
.30857 .51644 Mdot
.32695 .37573 Mdot
.61369 .58081 Mdot
.59683 .4911 Mdot
.52768 .34686 Mdot
.27899 .70124 Mdot
.59784 .57157 Mdot
.57947 .52998 Mdot
.39263 .57896 Mdot
.35908 .60199 Mdot
.2879 .70155 Mdot
.43024 .62439 Mdot
.66632 .54917 Mdot
.52736 .34556 Mdot
.61335 .55323 Mdot
.5508 .35714 Mdot
.65594 .54133 Mdot
.51272 .38412 Mdot
.51068 .32277 Mdot
.24165 .54298 Mdot
.60176 .54646 Mdot
.70718 .52545 Mdot
.5988 .51988 Mdot
.60965 .50034 Mdot
.3895 .58736 Mdot
.46046 .73807 Mdot
.58529 .46545 Mdot
.49427 .76887 Mdot
.45413 .73788 Mdot
.66113 .25976 Mdot
.41268 .63074 Mdot
.4838 .72391 Mdot
.741 .67207 Mdot
.3306 .51179 Mdot
.4715 .72639 Mdot
.70551 .75602 Mdot
.33873 .40606 Mdot
.56933 .34235 Mdot
.60648 .56468 Mdot
.6829 .23834 Mdot
.60146 .7671 Mdot
.34152 .53543 Mdot
.56383 .54509 Mdot
.6129 .52581 Mdot
.52519 .29596 Mdot
.40338 .83492 Mdot
.37419 .57471 Mdot
.59104 .54917 Mdot
.5625 .33789 Mdot
.26676 .76299 Mdot
.373 .58443 Mdot
.4736 .72926 Mdot
.38837 .37691 Mdot
.50489 .36946 Mdot
.34323 .54551 Mdot
.39558 .38927 Mdot
.25544 .54763 Mdot
.36377 .23858 Mdot
.57495 .50826 Mdot
.37774 .62444 Mdot
.38364 .21036 Mdot
.65012 .59642 Mdot
.40985 .36433 Mdot
.57709 .43006 Mdot
.55161 .34404 Mdot
.39041 .38566 Mdot
.47532 .70394 Mdot
.54777 .37791 Mdot
.51686 .34283 Mdot
.36124 .41967 Mdot
.45926 .62281 Mdot
.49822 .45961 Mdot
.38002 .40859 Mdot
.27006 .33776 Mdot
.59811 .21477 Mdot
.33577 .52001 Mdot
.45837 .74476 Mdot
.53953 .20298 Mdot
.52985 .32948 Mdot
.80673 .61585 Mdot
.33064 .25016 Mdot
.62784 .56538 Mdot
.48862 .72886 Mdot
.43685 .34338 Mdot
.64028 .78267 Mdot
.36477 .37877 Mdot
.44284 .42356 Mdot
.49372 .75252 Mdot
.62027 .57194 Mdot
.61578 .42673 Mdot
.58677 .54087 Mdot
.35259 .39553 Mdot
.73456 .51374 Mdot
.55377 .34746 Mdot
.32719 .38468 Mdot
.32236 .26469 Mdot
.63225 .55323 Mdot
.59438 .54213 Mdot
.56738 .73854 Mdot
.55535 .31568 Mdot
.35178 .54696 Mdot
.57536 .51295 Mdot
.63583 .53513 Mdot
.58183 .57689 Mdot
.69993 .51989 Mdot
.19868 .54891 Mdot
.59276 .54879 Mdot
.32339 .54853 Mdot
.54949 .53764 Mdot
.60457 .54575 Mdot
.54619 .29053 Mdot
.15376 .43326 Mdot
.33156 .53973 Mdot
.63557 .53945 Mdot
.57067 .51147 Mdot
.35337 .4177 Mdot
.49278 .55027 Mdot
.48062 .44256 Mdot
.38215 .63361 Mdot
.66773 .68706 Mdot
.68094 .53855 Mdot
.55195 .36644 Mdot
.48936 .75183 Mdot
.61479 .48455 Mdot
.55443 .36334 Mdot
.56583 .4944 Mdot
.40643 .59691 Mdot
.33387 .51844 Mdot
.33713 .27255 Mdot
.47644 .72165 Mdot
.58146 .76994 Mdot
.43051 .26688 Mdot
.4169 .59323 Mdot
.58688 .55462 Mdot
.39136 .36537 Mdot
.37927 .63008 Mdot
.3345 .53395 Mdot
.60069 .45129 Mdot
.53284 .31574 Mdot
.54259 .35343 Mdot
.51193 .65261 Mdot
.29485 .54741 Mdot
.1626 .55257 Mdot
.36563 .40819 Mdot
.55378 .5175 Mdot
.40869 .23804 Mdot
.54329 .35447 Mdot
.52204 .67463 Mdot
.48355 .72192 Mdot
.36479 .37723 Mdot
.35727 .54484 Mdot
.5489 .36334 Mdot
.5516 .30512 Mdot
.62076 .47375 Mdot
.63124 .51966 Mdot
.62128 .69888 Mdot
.50909 .63829 Mdot
.38333 .37524 Mdot
.46882 .75174 Mdot
.43492 .63219 Mdot
.58181 .54162 Mdot
.50902 .33078 Mdot
.5745 .20541 Mdot
.57246 .50776 Mdot
.39553 .58776 Mdot
.54912 .34386 Mdot
.4816 .75055 Mdot
.45233 .73412 Mdot
.61009 .50118 Mdot
.70952 .48064 Mdot
.37836 .3794 Mdot
.54545 .3565 Mdot
.49108 .21308 Mdot
.59396 .57122 Mdot
.63471 .51745 Mdot
.62009 .44757 Mdot
.37681 .41756 Mdot
.36375 .24891 Mdot
.49856 .72804 Mdot
.53725 .32538 Mdot
.56359 .52555 Mdot
.47416 .71596 Mdot
.38838 .23807 Mdot
.33338 .52226 Mdot
.42329 .616 Mdot
.45131 .73358 Mdot
.48366 .745 Mdot
.45997 .75087 Mdot
.80164 .63062 Mdot
.55482 .38263 Mdot
.70452 .58559 Mdot
.57187 .55862 Mdot
.51242 .65582 Mdot
.61786 .46453 Mdot
.36844 .35943 Mdot
.41984 .63168 Mdot
.6008 .52267 Mdot
.62214 .47477 Mdot
.67089 .46917 Mdot
.71128 .55324 Mdot
.52945 .27633 Mdot
.55398 .32639 Mdot
.56739 .5857 Mdot
.40301 .63148 Mdot
.4156 .84929 Mdot
.82975 .38124 Mdot
.55153 .48431 Mdot
.49749 .48256 Mdot
.51149 .34023 Mdot
.36988 .42218 Mdot
.46715 .43942 Mdot
.35691 .36137 Mdot
.53777 .33216 Mdot
.58537 .54385 Mdot
.44494 .25592 Mdot
.45571 .71144 Mdot
.6096 .49378 Mdot
.35812 .38978 Mdot
.61069 .49495 Mdot
.39305 .3848 Mdot
.53663 .24442 Mdot
.25596 .35103 Mdot
.63085 .56129 Mdot
.5878 .57229 Mdot
.60978 .43131 Mdot
.62122 .52093 Mdot
.36032 .78361 Mdot
.51594 .34864 Mdot
.2297 .65577 Mdot
.61382 .47478 Mdot
.72903 .44029 Mdot
.58127 .56507 Mdot
.24809 .642 Mdot
.63043 .51311 Mdot
.42966 .47258 Mdot
.62685 .56844 Mdot
.65105 .51905 Mdot
.34667 .36615 Mdot
.3535 .41755 Mdot
.50504 .32823 Mdot
.35211 .54894 Mdot
.81594 .45475 Mdot
.63657 .52599 Mdot
.34765 .56165 Mdot
.38091 .34333 Mdot
.47688 .74918 Mdot
.53575 .33233 Mdot
.28676 .78435 Mdot
.36449 .36592 Mdot
.44464 .61948 Mdot
.28918 .71984 Mdot
.34706 .55617 Mdot
.42586 .40208 Mdot
.51432 .50041 Mdot
.49506 .73221 Mdot
.61289 .57237 Mdot
.47725 .18867 Mdot
.21682 .42736 Mdot
.6302 .46265 Mdot
.32906 .37532 Mdot
.76718 .48259 Mdot
.54374 .20719 Mdot
.46567 .7639 Mdot
.48405 .70435 Mdot
.3653 .36785 Mdot
.37963 .57122 Mdot
.67615 .53926 Mdot
.48361 .71985 Mdot
.41507 .59605 Mdot
.33206 .5105 Mdot
.39099 .47348 Mdot
.52872 .32332 Mdot
.32316 .26759 Mdot
.409 .29892 Mdot
.38004 .37213 Mdot
.46982 .67283 Mdot
.49911 .36217 Mdot
.51843 .37607 Mdot
.34976 .55014 Mdot
.38714 .58564 Mdot
.55205 .38059 Mdot
.6701 .53858 Mdot
.71707 .5496 Mdot
.6348 .54401 Mdot
.47867 .73819 Mdot
.6247 .51346 Mdot
.39681 .59219 Mdot
.36679 .38376 Mdot
.38077 .5887 Mdot
.35545 .36636 Mdot
.46059 .28167 Mdot
.59235 .50823 Mdot
.65026 .52069 Mdot
.59302 .77286 Mdot
.50801 .31595 Mdot
.44211 .20189 Mdot
.34091 .56724 Mdot
.37982 .60175 Mdot
.65274 .54252 Mdot
.51905 .36068 Mdot
.44325 .7295 Mdot
.58698 .77787 Mdot
.61005 .48941 Mdot
.51651 .35074 Mdot
.58515 .54874 Mdot
.75553 .65146 Mdot
.19542 .44083 Mdot
.52904 .33967 Mdot
.26212 .73173 Mdot
.57029 .53188 Mdot
.54017 .5881 Mdot
.63597 .58104 Mdot
.58878 .66568 Mdot
.60014 .57276 Mdot
.56175 .36505 Mdot
.63112 .54186 Mdot
.54726 .37626 Mdot
.39555 .57814 Mdot
.37494 .4248 Mdot
.52563 .30722 Mdot
.59841 .4884 Mdot
.84243 .57976 Mdot
.35584 .40043 Mdot
.64438 .54471 Mdot
.34248 .38339 Mdot
.56382 .34734 Mdot
.5463 .30494 Mdot
.63756 .79302 Mdot
.40836 .35025 Mdot
.37046 .40771 Mdot
.59769 .55357 Mdot
.37459 .29259 Mdot
.60488 .55102 Mdot
.60349 .69989 Mdot
.63931 .49143 Mdot
.60129 .57386 Mdot
.61329 .8264 Mdot
.3946 .4022 Mdot
.16819 .55248 Mdot
.68508 .73874 Mdot
.79392 .64374 Mdot
.53024 .38885 Mdot
.4658 .76363 Mdot
.80841 .58296 Mdot
.3122 .51408 Mdot
.41545 .6148 Mdot
.60141 .52151 Mdot
.56825 .27431 Mdot
.38884 .39058 Mdot
.46228 .73925 Mdot
.63202 .56051 Mdot
.38985 .58472 Mdot
.4158 .71982 Mdot
.36669 .43104 Mdot
.53111 .3293 Mdot
.52133 .30328 Mdot
.23932 .72528 Mdot
.5629 .52646 Mdot
.65269 .53279 Mdot
.35095 .39658 Mdot
.69517 .5707 Mdot
.48762 .74974 Mdot
.29922 .67425 Mdot
.36979 .40728 Mdot
.47681 .49864 Mdot
.55114 .32083 Mdot
.61308 .52443 Mdot
.49781 .41753 Mdot
.36242 .48947 Mdot
.69876 .31365 Mdot
.47544 .73396 Mdot
.60223 .70918 Mdot
.56208 .3646 Mdot
.36567 .39104 Mdot
.32432 .59728 Mdot
.55523 .55634 Mdot
.61724 .52889 Mdot
.59835 .71242 Mdot
.49185 .62429 Mdot
.4899 .79644 Mdot
.6594 .54582 Mdot
.49315 .61744 Mdot
.65897 .53154 Mdot
.57498 .57455 Mdot
.66845 .53409 Mdot
.63717 .51289 Mdot
.51481 .34758 Mdot
.68647 .49863 Mdot
.41347 .62322 Mdot
.64221 .33544 Mdot
.45353 .42255 Mdot
.58271 .56168 Mdot
.59245 .54585 Mdot
.7413 .35753 Mdot
.33538 .33428 Mdot
.51322 .33038 Mdot
.57626 .3651 Mdot
.33825 .41285 Mdot
.70701 .52197 Mdot
.35663 .5696 Mdot
.6611 .46826 Mdot
.38473 .58945 Mdot
.52045 .3588 Mdot
.37586 .59983 Mdot
.36087 .42783 Mdot
.37782 .62478 Mdot
.34481 .56696 Mdot
.3914 .38958 Mdot
.54752 .31099 Mdot
.62201 .49939 Mdot
.32987 .39041 Mdot
.57017 .73641 Mdot
.47907 .73708 Mdot
.64039 .7917 Mdot
.56227 .50314 Mdot
.44992 .39048 Mdot
.65771 .63856 Mdot
.38169 .5904 Mdot
.18465 .49271 Mdot
.5111 .32122 Mdot
.45723 .70374 Mdot
.5186 .35724 Mdot
.2963 .26584 Mdot
.46182 .74392 Mdot
.7124 .75114 Mdot
.28654 .52245 Mdot
.4103 .69896 Mdot
.66823 .52371 Mdot
.57627 .41311 Mdot
.40706 .6393 Mdot
.38871 .38907 Mdot
.27993 .51944 Mdot
.64695 .51171 Mdot
.22189 .52874 Mdot
.50633 .31568 Mdot
.33861 .52015 Mdot
.37189 .39318 Mdot
.32819 .39206 Mdot
.58312 .50305 Mdot
.33117 .72026 Mdot
.64014 .50015 Mdot
.28568 .544 Mdot
.64196 .7013 Mdot
.63609 .45064 Mdot
.64311 .55264 Mdot
.3683 .59382 Mdot
.58637 .54964 Mdot
.7222 .57823 Mdot
.44433 .18605 Mdot
.67686 .51298 Mdot
.29569 .49022 Mdot
.45939 .67897 Mdot
.5477 .33072 Mdot
.55294 .49155 Mdot
.33918 .53969 Mdot
.56896 .53563 Mdot
.42275 .15575 Mdot
.47127 .72348 Mdot
.40705 .65947 Mdot
.57032 .55999 Mdot
.57904 .5086 Mdot
.60147 .31905 Mdot
.57602 .28286 Mdot
.3575 .54407 Mdot
.62237 .53184 Mdot
.66218 .70454 Mdot
.34279 .39785 Mdot
.63303 .49413 Mdot
.64289 .53884 Mdot
.69104 .27838 Mdot
.37024 .41724 Mdot
.37786 .5913 Mdot
.32031 .50976 Mdot
.43714 .6261 Mdot
.50304 .71475 Mdot
.45756 .45378 Mdot
.51976 .66145 Mdot
.20044 .43485 Mdot
.46566 .75973 Mdot
.56578 .51208 Mdot
.53384 .49985 Mdot
.5716 .52257 Mdot
.47773 .70226 Mdot
.37832 .41528 Mdot
.51319 .32193 Mdot
.34341 .276 Mdot
.3277 .52494 Mdot
.64068 .57527 Mdot
.46074 .7107 Mdot
.5364 .31207 Mdot
.49782 .68668 Mdot
.54266 .3275 Mdot
.37632 .40158 Mdot
.32223 .37153 Mdot
.45973 .72429 Mdot
.52689 .36687 Mdot
.31939 .54068 Mdot
.66276 .75629 Mdot
.6482 .5004 Mdot
.40866 .42197 Mdot
.51024 .34718 Mdot
.50855 .29719 Mdot
.50089 .33991 Mdot
.60236 .50257 Mdot
.49803 .49642 Mdot
.56003 .5571 Mdot
.37275 .37122 Mdot
.42102 .60682 Mdot
.51446 .64205 Mdot
.54664 .22801 Mdot
.47476 .646 Mdot
.62334 .46643 Mdot
.63079 .55056 Mdot
.64618 .53877 Mdot
.64105 .48572 Mdot
.30743 .58042 Mdot
.58729 .51201 Mdot
.34819 .36624 Mdot
.39706 .5975 Mdot
.57485 .55921 Mdot
.34481 .54187 Mdot
.50324 .45013 Mdot
.48669 .75517 Mdot
.45057 .44435 Mdot
.83559 .53565 Mdot
.5345 .31048 Mdot
.4296 .63084 Mdot
.41475 .61714 Mdot
.4677 .75661 Mdot
.38742 .39049 Mdot
.54425 .32163 Mdot
.61073 .66662 Mdot
.46368 .75184 Mdot
.63319 .53945 Mdot
.25544 .60474 Mdot
.23719 .57762 Mdot
.62579 .57306 Mdot
.5959 .53019 Mdot
.32391 .50822 Mdot
.37478 .57102 Mdot
.60542 .1784 Mdot
.53105 .71721 Mdot
.45914 .73096 Mdot
.49418 .72012 Mdot
.51034 .36681 Mdot
.54792 .48123 Mdot
.36528 .37026 Mdot
.54844 .74765 Mdot
.54536 .63508 Mdot
.56607 .77168 Mdot
.4493 .79876 Mdot
.59586 .49488 Mdot
.60732 .39403 Mdot
.63085 .55577 Mdot
.51538 .30309 Mdot
.56208 .32635 Mdot
.51782 .32169 Mdot
.38217 .37958 Mdot
.74198 .4872 Mdot
.33916 .3719 Mdot
.83786 .48799 Mdot
.55957 .37079 Mdot
.32289 .62701 Mdot
.37533 .60863 Mdot
.55032 .50668 Mdot
.48739 .74729 Mdot
.36973 .43852 Mdot
.67025 .51045 Mdot
.20008 .5638 Mdot
.37875 .62399 Mdot
.55157 .3118 Mdot
.51483 .50284 Mdot
.78427 .34688 Mdot
.47956 .45882 Mdot
.58775 .60457 Mdot
.59919 .35206 Mdot
.47003 .7506 Mdot
.69614 .31395 Mdot
.49404 .70702 Mdot
.35855 .38238 Mdot
.64449 .5123 Mdot
.63319 .5047 Mdot
.65683 .54065 Mdot
.58939 .51145 Mdot
.34756 .4169 Mdot
.59024 .47256 Mdot
.27211 .27173 Mdot
.33084 .51343 Mdot
.76652 .63708 Mdot
.48116 .71206 Mdot
.33972 .36166 Mdot
.39399 .59549 Mdot
.35272 .54249 Mdot
.53909 .69116 Mdot
.62425 .56837 Mdot
.59904 .52155 Mdot
.36544 .55679 Mdot
.65657 .55367 Mdot
.68565 .54195 Mdot
.40984 .62322 Mdot
.47634 .64466 Mdot
.45339 .75291 Mdot
.47247 .70838 Mdot
.37826 .4128 Mdot
.52382 .36401 Mdot
.48172 .72777 Mdot
.38972 .57741 Mdot
.57355 .48399 Mdot
.59378 .48804 Mdot
.50938 .34614 Mdot
.32831 .25134 Mdot
.47436 .76405 Mdot
.51338 .50967 Mdot
.55268 .37102 Mdot
.5544 .38354 Mdot
.61661 .53048 Mdot
.64982 .4668 Mdot
.50186 .30263 Mdot
.45362 .74684 Mdot
.33663 .36304 Mdot
.40676 .68097 Mdot
.3543 .38771 Mdot
.54239 .31637 Mdot
.61579 .47877 Mdot
.54988 .31497 Mdot
.56732 .53973 Mdot
.73076 .79019 Mdot
.63242 .50739 Mdot
.21288 .389 Mdot
.58504 .67495 Mdot
.41055 .61679 Mdot
.32218 .5421 Mdot
.34564 .5364 Mdot
.55625 .36955 Mdot
.61067 .48248 Mdot
.49473 .71743 Mdot
.75959 .69759 Mdot
.49418 .35376 Mdot
.41366 .60389 Mdot
.36034 .56859 Mdot
.39342 .40048 Mdot
.56434 .55152 Mdot
.6168 .5245 Mdot
.37365 .61858 Mdot
.69214 .63631 Mdot
.5421 .36603 Mdot
.65106 .53657 Mdot
.61932 .54989 Mdot
.40921 .61973 Mdot
.65772 .75879 Mdot
.5797 .38309 Mdot
.64386 .51517 Mdot
.3617 .63816 Mdot
.3631 .35764 Mdot
.65393 .49977 Mdot
.59178 .47169 Mdot
.4903 .7344 Mdot
.78453 .58791 Mdot
.46794 .17995 Mdot
.37486 .36276 Mdot
.35108 .54692 Mdot
.56061 .51631 Mdot
.37616 .6104 Mdot
.5948 .48868 Mdot
.79726 .47651 Mdot
.33606 .51826 Mdot
.581 .52172 Mdot
.55839 .47029 Mdot
.56024 .32003 Mdot
.58422 .51112 Mdot
.73144 .32997 Mdot
.42251 .64063 Mdot
.58194 .5166 Mdot
.69531 .46598 Mdot
.36011 .4153 Mdot
.55352 .48183 Mdot
.48225 .70818 Mdot
.59008 .66253 Mdot
.43035 .27732 Mdot
.36868 .6321 Mdot
.47329 .70966 Mdot
.61725 .49296 Mdot
.37852 .56981 Mdot
.38397 .37376 Mdot
.21496 .52519 Mdot
.6504 .55181 Mdot
.35349 .39656 Mdot
.36801 .38543 Mdot
.46944 .71745 Mdot
.17502 .59926 Mdot
.57018 .48071 Mdot
.62145 .51823 Mdot
.73642 .32757 Mdot
.54 .29334 Mdot
.62375 .50931 Mdot
.57023 .50866 Mdot
.34599 .36995 Mdot
.58874 .29759 Mdot
.7619 .43534 Mdot
.30483 .6899 Mdot
.39177 .37718 Mdot
.43832 .64778 Mdot
.37829 .56928 Mdot
.48261 .71427 Mdot
.54563 .33846 Mdot
.49926 .74269 Mdot
.41087 .62872 Mdot
.56567 .51737 Mdot
.35284 .37082 Mdot
.62479 .25109 Mdot
.39807 .40304 Mdot
.38234 .63684 Mdot
.51617 .29691 Mdot
.3956 .25082 Mdot
.34954 .18552 Mdot
.41871 .30248 Mdot
.31345 .35971 Mdot
.4773 .74897 Mdot
.25737 .55423 Mdot
.62344 .5503 Mdot
.68766 .31777 Mdot
.61678 .49789 Mdot
.64212 .42894 Mdot
.4294 .62152 Mdot
.35543 .55287 Mdot
.64353 .51252 Mdot
.62622 .70776 Mdot
.39197 .42227 Mdot
.39458 .39588 Mdot
.5875 .52094 Mdot
.38208 .39484 Mdot
.63007 .52329 Mdot
.38969 .58898 Mdot
.16438 .51584 Mdot
.63716 .54869 Mdot
.59365 .5816 Mdot
.30914 .34382 Mdot
.65653 .78351 Mdot
.30954 .54412 Mdot
.60305 .38723 Mdot
.75668 .30978 Mdot
.38163 .39404 Mdot
.57996 .45135 Mdot
.3919 .63535 Mdot
.32344 .50791 Mdot
.31924 .53965 Mdot
.61722 .50524 Mdot
.61124 .50651 Mdot
.6518 .54367 Mdot
.59298 .54187 Mdot
.69308 .32081 Mdot
.69937 .54498 Mdot
.64395 .40909 Mdot
.59679 .52285 Mdot
.61571 .42535 Mdot
.33157 .39282 Mdot
.55886 .28778 Mdot
.49447 .75545 Mdot
.59393 .49584 Mdot
.5346 .26351 Mdot
.35529 .35783 Mdot
.83794 .48544 Mdot
.38662 .41019 Mdot
.39136 .60621 Mdot
.37817 .42135 Mdot
.57067 .55002 Mdot
.53795 .34486 Mdot
.40073 .6408 Mdot
.22832 .47232 Mdot
.41527 .61324 Mdot
.56569 .5477 Mdot
.40165 .66716 Mdot
.41677 .6178 Mdot
.49338 .4319 Mdot
.54195 .34639 Mdot
.65304 .71422 Mdot
.56252 .32691 Mdot
.57947 .51932 Mdot
.57852 .52422 Mdot
.30629 .50249 Mdot
.38009 .42632 Mdot
.56489 .3433 Mdot
.13821 .50839 Mdot
.49842 .7114 Mdot
.5188 .32596 Mdot
.55986 .57121 Mdot
.4922 .579 Mdot
.5338 .3496 Mdot
.66136 .67051 Mdot
.38821 .38565 Mdot
.54587 .38105 Mdot
.5601 .56923 Mdot
.286 .39483 Mdot
.45158 .71781 Mdot
.36662 .5801 Mdot
.42945 .49647 Mdot
.41297 .63943 Mdot
.33582 .36167 Mdot
.365 .61585 Mdot
.34096 .39784 Mdot
.42821 .20914 Mdot
.72816 .54146 Mdot
.39688 .37026 Mdot
.32618 .37111 Mdot
.39074 .62461 Mdot
.64412 .55507 Mdot
.418 .4432 Mdot
.66279 .5413 Mdot
.66438 .50511 Mdot
.34518 .40392 Mdot
.56479 .35506 Mdot
.57009 .33878 Mdot
.58816 .41712 Mdot
.52167 .30254 Mdot
.38489 .58778 Mdot
.19618 .43715 Mdot
.39862 .21422 Mdot
.35023 .40209 Mdot
.32585 .3938 Mdot
.60127 .54965 Mdot
.37883 .61648 Mdot
.40804 .58481 Mdot
.36707 .3732 Mdot
.64918 .2884 Mdot
.55708 .55118 Mdot
.51489 .29288 Mdot
.55843 .37332 Mdot
.52763 .34279 Mdot
.50272 .35207 Mdot
.74783 .41853 Mdot
.38889 .38604 Mdot
.55832 .37001 Mdot
.5846 .52269 Mdot
.61312 .5067 Mdot
.32265 .52644 Mdot
.47508 .70731 Mdot
.56072 .50071 Mdot
.66373 .55939 Mdot
.61383 .52924 Mdot
.42234 .61593 Mdot
.53488 .54383 Mdot
.34917 .53838 Mdot
.37123 .57568 Mdot
.35169 .57111 Mdot
.32908 .53655 Mdot
.57221 .41425 Mdot
.76053 .30447 Mdot
.59053 .54901 Mdot
.68873 .58937 Mdot
.37841 .60938 Mdot
.18866 .52422 Mdot
.37115 .24698 Mdot
.65197 .5465 Mdot
.37571 .48515 Mdot
.36881 .61647 Mdot
.53934 .29676 Mdot
.62158 .50457 Mdot
.3172 .51539 Mdot
.48614 .75485 Mdot
.56885 .58148 Mdot
.31745 .50986 Mdot
.53296 .37019 Mdot
.48163 .77048 Mdot
.537 .37964 Mdot
.37259 .62471 Mdot
.55739 .47268 Mdot
.83362 .33287 Mdot
.43656 .62226 Mdot
.72882 .71268 Mdot
.55623 .25976 Mdot
.65063 .54019 Mdot
.43005 .63302 Mdot
.53577 .29392 Mdot
.34285 .3574 Mdot
.49405 .59262 Mdot
.51439 .31322 Mdot
.35394 .54895 Mdot
.32095 .5176 Mdot
.41205 .6221 Mdot
.55484 .33071 Mdot
.62797 .4877 Mdot
.55699 .34613 Mdot
.37976 .42023 Mdot
.61887 .56045 Mdot
.81479 .40831 Mdot
.69491 .57837 Mdot
.55828 .36613 Mdot
.38466 .58103 Mdot
.46779 .69977 Mdot
.62232 .56548 Mdot
.72237 .7073 Mdot
.5592 .53111 Mdot
.34455 .39479 Mdot
.2201 .62709 Mdot
.64606 .26151 Mdot
.58291 .56503 Mdot
.59994 .54875 Mdot
.39123 .38506 Mdot
.62396 .56744 Mdot
.59603 .57037 Mdot
.39962 .34968 Mdot
.55939 .33294 Mdot
.62875 .54469 Mdot
.4063 .58712 Mdot
.47572 .19567 Mdot
.56076 .55632 Mdot
.37269 .53669 Mdot
.64064 .7145 Mdot
.20975 .62682 Mdot
.6232 .49691 Mdot
.54255 .723 Mdot
.59274 .53804 Mdot
.60136 .49772 Mdot
.60272 .55382 Mdot
.60627 .36909 Mdot
.3935 .62673 Mdot
.40406 .59834 Mdot
.45018 .72266 Mdot
.64649 .71164 Mdot
.48948 .72913 Mdot
.39016 .40124 Mdot
.41902 .74726 Mdot
.33667 .52021 Mdot
.53048 .36986 Mdot
.62819 .49358 Mdot
.4226 .64266 Mdot
.61135 .52204 Mdot
.57067 .54757 Mdot
.36741 .59089 Mdot
.42049 .59308 Mdot
.35364 .61206 Mdot
.49673 .72881 Mdot
.51964 .31394 Mdot
.62074 .47252 Mdot
.45409 .73694 Mdot
.62424 .48668 Mdot
.50377 .6606 Mdot
.51647 .31929 Mdot
.55958 .33628 Mdot
.56188 .30875 Mdot
.56532 .51773 Mdot
.58141 .55999 Mdot
.33771 .37397 Mdot
.5228 .36584 Mdot
.37034 .41303 Mdot
.39092 .63633 Mdot
.44137 .60967 Mdot
.61699 .50529 Mdot
.52043 .56542 Mdot
.49313 .73126 Mdot
.39072 .6008 Mdot
.36773 .55643 Mdot
.46203 .69922 Mdot
.56168 .53566 Mdot
.36787 .59603 Mdot
.46732 .70927 Mdot
.62878 .28917 Mdot
.72488 .26282 Mdot
.4734 .69949 Mdot
.58674 .52338 Mdot
.59423 .29062 Mdot
.6393 .76549 Mdot
.49595 .70555 Mdot
.34707 .3816 Mdot
.56474 .51594 Mdot
.68149 .61971 Mdot
.48596 .75917 Mdot
.47129 .20319 Mdot
.40805 .61572 Mdot
.30117 .41738 Mdot
.62723 .59541 Mdot
.67374 .3215 Mdot
.50227 .72895 Mdot
.54068 .3234 Mdot
.5585 .29356 Mdot
.61033 .5367 Mdot
.50567 .73117 Mdot
.39631 .38609 Mdot
.40628 .61023 Mdot
.33936 .55525 Mdot
.55564 .33384 Mdot
.35079 .30441 Mdot
.40969 .59422 Mdot
.51281 .53103 Mdot
.26947 .66121 Mdot
.71365 .53312 Mdot
.66331 .44953 Mdot
.23113 .41352 Mdot
.57022 .50376 Mdot
.48161 .6995 Mdot
.35039 .36059 Mdot
.36053 .36698 Mdot
.37051 .40527 Mdot
.32478 .54395 Mdot
.4641 .43962 Mdot
.38917 .63101 Mdot
.22423 .50675 Mdot
.47499 .71618 Mdot
.68311 .69779 Mdot
.61901 .48659 Mdot
.63228 .55009 Mdot
.55397 .51576 Mdot
.64502 .50357 Mdot
.6014 .54062 Mdot
.38602 .39419 Mdot
.32577 .5466 Mdot
.36931 .68705 Mdot
.52069 .3422 Mdot
.46397 .64959 Mdot
.3752 .60834 Mdot
.32577 .50882 Mdot
.46333 .73299 Mdot
.51537 .47055 Mdot
.36515 .62213 Mdot
.37688 .59921 Mdot
.55871 .4991 Mdot
.55135 .36136 Mdot
.659 .47012 Mdot
.58028 .53108 Mdot
.38941 .59692 Mdot
.43774 .59191 Mdot
.76696 .40406 Mdot
.57383 .44332 Mdot
.45094 .76204 Mdot
.49368 .52522 Mdot
.49387 .7038 Mdot
.62811 .58588 Mdot
.18918 .53524 Mdot
.40928 .62847 Mdot
.39293 .61302 Mdot
.46854 .70562 Mdot
.5295 .57088 Mdot
.55078 .33962 Mdot
.35741 .55359 Mdot
.33957 .38418 Mdot
.57374 .52101 Mdot
.43513 .60329 Mdot
.58303 .60744 Mdot
.35438 .72321 Mdot
.36353 .40573 Mdot
.37555 .57636 Mdot
.56613 .55344 Mdot
.5883 .52487 Mdot
.47457 .75103 Mdot
.49481 .27813 Mdot
.57384 .58802 Mdot
.79586 .64147 Mdot
.2605 .34799 Mdot
.28562 .32104 Mdot
.61742 .52878 Mdot
.55737 .32945 Mdot
.32401 .51455 Mdot
.46034 .74713 Mdot
.60406 .47229 Mdot
.73472 .27467 Mdot
.53038 .28175 Mdot
.36063 .38772 Mdot
.31713 .51712 Mdot
.46657 .43725 Mdot
.56058 .5233 Mdot
.61729 .49848 Mdot
.59684 .50662 Mdot
.66432 .20411 Mdot
.41393 .60156 Mdot
.51119 .30912 Mdot
.47371 .73601 Mdot
.51978 .3026 Mdot
.40999 .60661 Mdot
.35558 .27953 Mdot
.5963 .56749 Mdot
.51696 .29342 Mdot
.53991 .3269 Mdot
.39305 .40105 Mdot
.33992 .35767 Mdot
.43068 .66489 Mdot
.63306 .50873 Mdot
.31749 .51414 Mdot
.56214 .32176 Mdot
.36658 .56366 Mdot
.46309 .74562 Mdot
.33208 .38017 Mdot
.5963 .52174 Mdot
.41467 .62556 Mdot
.64066 .46672 Mdot
.53717 .35523 Mdot
.37682 .60013 Mdot
.34367 .54837 Mdot
.49112 .71581 Mdot
.60502 .51343 Mdot
.44639 .75401 Mdot
.35237 .55231 Mdot
.62007 .55091 Mdot
.53821 .44343 Mdot
.44983 .76692 Mdot
.23852 .48528 Mdot
.40471 .63474 Mdot
.33266 .53646 Mdot
.55836 .30752 Mdot
.4693 .2141 Mdot
.39632 .6115 Mdot
.5275 .45333 Mdot
.46891 .3019 Mdot
.62151 .47223 Mdot
.52847 .33282 Mdot
.25695 .5738 Mdot
.82197 .5892 Mdot
.70233 .70294 Mdot
.64429 .54311 Mdot
.42443 .63552 Mdot
.4587 .71642 Mdot
.34997 .40241 Mdot
.37157 .53639 Mdot
.72224 .56546 Mdot
.36209 .59588 Mdot
.59844 .55111 Mdot
.56197 .33001 Mdot
.37055 .37669 Mdot
.45524 .25728 Mdot
.38649 .5782 Mdot
.4282 .62537 Mdot
.57524 .56015 Mdot
.48194 .7212 Mdot
.73631 .63671 Mdot
.3955 .59023 Mdot
.43732 .60772 Mdot
.25302 .54366 Mdot
.46147 .7092 Mdot
.5929 .53345 Mdot
.59238 .41798 Mdot
.6451 .48906 Mdot
.73533 .71109 Mdot
.34855 .54182 Mdot
.52127 .3457 Mdot
.61173 .49706 Mdot
.29777 .69089 Mdot
.39501 .60023 Mdot
.49676 .47673 Mdot
.45127 .62566 Mdot
.38765 .38426 Mdot
.43865 .60876 Mdot
.61927 .51338 Mdot
.39324 .42031 Mdot
.4929 .73092 Mdot
.64183 .51531 Mdot
.58354 .56047 Mdot
.53223 .29625 Mdot
.35785 .38122 Mdot
.57381 .2252 Mdot
.32674 .38509 Mdot
.36315 .35972 Mdot
.57253 .32807 Mdot
.62347 .53863 Mdot
.3875 .60408 Mdot
.36474 .61238 Mdot
.61285 .47317 Mdot
.17635 .47812 Mdot
.55262 .33982 Mdot
.47634 .673 Mdot
.62252 .19158 Mdot
.57639 .43653 Mdot
.37241 .56015 Mdot
.4838 .29373 Mdot
.39381 .38219 Mdot
.59128 .52222 Mdot
.55038 .36881 Mdot
.40691 .58063 Mdot
.40956 .59326 Mdot
.6199 .48137 Mdot
.3703 .38186 Mdot
.47451 .75969 Mdot
.43356 .61605 Mdot
.33202 .71944 Mdot
.5907 .50574 Mdot
.22655 .528 Mdot
.43234 .62356 Mdot
.77835 .68736 Mdot
.36328 .69865 Mdot
.52614 .3347 Mdot
.57377 .55073 Mdot
.52228 .30393 Mdot
.47471 .74044 Mdot
.43351 .654 Mdot
.36803 .38264 Mdot
.56177 .44957 Mdot
.38738 .18732 Mdot
.38763 .62525 Mdot
.5145 .34608 Mdot
.58015 .56382 Mdot
.5357 .46619 Mdot
.62482 .51628 Mdot
.59333 .31228 Mdot
.47695 .67619 Mdot
.34805 .40736 Mdot
.34423 .39118 Mdot
.62305 .5537 Mdot
.47697 .75472 Mdot
.37186 .58274 Mdot
.40529 .61089 Mdot
.49939 .88123 Mdot
.36221 .5575 Mdot
.61872 .69424 Mdot
.60894 .50889 Mdot
.3644 .56379 Mdot
.54109 .22315 Mdot
.35106 .39749 Mdot
.64237 .49959 Mdot
.35696 .56372 Mdot
.27467 .37804 Mdot
.4972 .64802 Mdot
.6002 .53829 Mdot
.67645 .56648 Mdot
.34095 .38446 Mdot
.58887 .75909 Mdot
.38265 .62795 Mdot
.64185 .49577 Mdot
.33217 .40855 Mdot
.2787 .68752 Mdot
.40102 .20325 Mdot
.51969 .3142 Mdot
.42612 .64439 Mdot
.38634 .39381 Mdot
.60316 .59908 Mdot
.47938 .7105 Mdot
.41668 .64106 Mdot
.41943 .6118 Mdot
.5996 .55735 Mdot
.55528 .50151 Mdot
.56997 .43727 Mdot
.51839 .35094 Mdot
.33454 .40125 Mdot
.64375 .50978 Mdot
.34894 .30719 Mdot
.658 .53522 Mdot
.33299 .38755 Mdot
.90235 .44409 Mdot
.66534 .51304 Mdot
.62469 .51863 Mdot
.73156 .65163 Mdot
.51629 .31022 Mdot
.52659 .30004 Mdot
.23474 .37535 Mdot
.6086 .50935 Mdot
.39282 .70962 Mdot
.52264 .31032 Mdot
.55085 .34517 Mdot
.3123 .62846 Mdot
.63171 .55829 Mdot
.58282 .77708 Mdot
.36055 .36849 Mdot
.35487 .3635 Mdot
.55707 .34296 Mdot
.58703 .59532 Mdot
.38424 .37176 Mdot
.72278 .35658 Mdot
.37583 .61582 Mdot
.18788 .54308 Mdot
.53501 .3575 Mdot
.43439 .41848 Mdot
.3553 .40326 Mdot
.8379 .49261 Mdot
.36728 .48529 Mdot
.64875 .54733 Mdot
.60054 .51241 Mdot
.4925 .72633 Mdot
.63605 .47254 Mdot
.35177 .54339 Mdot
.38222 .39535 Mdot
.74975 .60644 Mdot
.51821 .3219 Mdot
.63228 .51348 Mdot
.51026 .48557 Mdot
.45419 .27505 Mdot
.27982 .49644 Mdot
.54695 .33093 Mdot
.52757 .32624 Mdot
.40031 .63148 Mdot
.42869 .61688 Mdot
.61565 .53972 Mdot
.3719 .37178 Mdot
.52534 .36912 Mdot
.33517 .3928 Mdot
.41316 .62815 Mdot
.38067 .6001 Mdot
.335 .51638 Mdot
.66062 .5531 Mdot
.37615 .58357 Mdot
.31693 .7187 Mdot
.34497 .30254 Mdot
.51617 .37434 Mdot
.44106 .16866 Mdot
.45581 .25561 Mdot
.63483 .64771 Mdot
.49787 .72232 Mdot
.353 .55531 Mdot
.3605 .42153 Mdot
.60441 .54975 Mdot
.60507 .52171 Mdot
.33438 .52987 Mdot
.38825 .41978 Mdot
.46588 .74219 Mdot
.38727 .42216 Mdot
.4717 .71387 Mdot
.37411 .56506 Mdot
.55668 .54182 Mdot
.58106 .49862 Mdot
.38352 .39879 Mdot
.37508 .59298 Mdot
.39899 .59727 Mdot
.49311 .70387 Mdot
.50095 .62951 Mdot
.41381 .62261 Mdot
.53586 .35704 Mdot
.73662 .41983 Mdot
.32389 .51802 Mdot
.62238 .50637 Mdot
.51688 .6653 Mdot
.67265 .29695 Mdot
.63757 .48546 Mdot
.31939 .52499 Mdot
.3749 .82154 Mdot
.62647 .49489 Mdot
.30525 .78266 Mdot
.33133 .53586 Mdot
.51422 .31196 Mdot
.42477 .63423 Mdot
.35087 .53847 Mdot
.64378 .59504 Mdot
.47341 .68678 Mdot
.58541 .48177 Mdot
.52331 .30603 Mdot
.55096 .29343 Mdot
.27447 .31802 Mdot
.72931 .71353 Mdot
.49239 .70651 Mdot
.46215 .72472 Mdot
.39813 .61321 Mdot
.57223 .828 Mdot
.54883 .54567 Mdot
.46014 .73412 Mdot
.72654 .62035 Mdot
.59072 .54665 Mdot
.59156 .70282 Mdot
.38252 .48699 Mdot
.55686 .33215 Mdot
.57634 .41683 Mdot
.39756 .60668 Mdot
.51302 .33984 Mdot
.33012 .29385 Mdot
.55916 .50753 Mdot
.51622 .32176 Mdot
.33464 .383 Mdot
.24989 .4323 Mdot
.54263 .30435 Mdot
.51021 .667 Mdot
.36943 .37271 Mdot
.27024 .55922 Mdot
.70989 .65027 Mdot
.31973 .18402 Mdot
.38417 .38889 Mdot
.36868 .60464 Mdot
.3682 .61556 Mdot
.40479 .61328 Mdot
.51073 .31937 Mdot
.39286 .5767 Mdot
.52335 .35769 Mdot
.63198 .77772 Mdot
.50267 .63004 Mdot
.45939 .72396 Mdot
.39343 .34227 Mdot
.53423 .32655 Mdot
.1993 .48054 Mdot
.3637 .18133 Mdot
.58746 .51899 Mdot
.32719 .394 Mdot
.47146 .7048 Mdot
.74492 .74226 Mdot
.49149 .73113 Mdot
.39517 .63619 Mdot
.18481 .56177 Mdot
.63337 .52219 Mdot
.77517 .48836 Mdot
.492 .71299 Mdot
.5482 .32125 Mdot
.62476 .55111 Mdot
.31391 .53457 Mdot
.48432 .71872 Mdot
.48069 .75776 Mdot
.61501 .54471 Mdot
.5528 .31236 Mdot
.38443 .60034 Mdot
.36072 .42407 Mdot
.4933 .6984 Mdot
.66554 .59397 Mdot
.6256 .47252 Mdot
.56262 .50804 Mdot
.48392 .45001 Mdot
.71756 .60779 Mdot
.38161 .39272 Mdot
.65934 .73621 Mdot
.42698 .61415 Mdot
.27427 .60019 Mdot
.24274 .3729 Mdot
.42972 .3746 Mdot
.34789 .54306 Mdot
.34639 .53437 Mdot
.60515 .54011 Mdot
.71785 .60899 Mdot
.23085 .64115 Mdot
.31873 .33889 Mdot
.32596 .51805 Mdot
.40421 .60626 Mdot
.55422 .28963 Mdot
.27795 .30133 Mdot
.62176 .46804 Mdot
.39094 .3724 Mdot
.41836 .62243 Mdot
.79731 .47296 Mdot
.47781 .72248 Mdot
.19256 .51362 Mdot
.58172 .56294 Mdot
.65058 .52159 Mdot
.37456 .39501 Mdot
.34115 .37043 Mdot
.3127 .48589 Mdot
.26565 .33125 Mdot
.54473 .76764 Mdot
.49504 .22525 Mdot
.79285 .46298 Mdot
.55534 .28598 Mdot
.55959 .36435 Mdot
.31249 .51758 Mdot
.33055 .37562 Mdot
.6156 .49467 Mdot
.52913 .37021 Mdot
.27387 .50066 Mdot
.54378 .40023 Mdot
.6054 .7039 Mdot
.37454 .7167 Mdot
.56453 .53834 Mdot
.55563 .35789 Mdot
.51203 .33025 Mdot
.51759 .36734 Mdot
.32354 .53076 Mdot
.62269 .53113 Mdot
.6373 .55952 Mdot
.65138 .51516 Mdot
.69285 .56757 Mdot
.5866 .50838 Mdot
.34656 .32188 Mdot
.48061 .50317 Mdot
.7658 .59623 Mdot
.6499 .49949 Mdot
.36269 .36463 Mdot
.56788 .49987 Mdot
.47544 .75566 Mdot
.60226 .55225 Mdot
.60669 .69775 Mdot
.35997 .3969 Mdot
.52283 .5435 Mdot
.48953 .2233 Mdot
.58934 .56555 Mdot
.46126 .75884 Mdot
.68207 .62741 Mdot
.57216 .23114 Mdot
.4699 .63665 Mdot
.53738 .35731 Mdot
.35864 .59804 Mdot
.38183 .41788 Mdot
.38677 .60623 Mdot
.65943 .51546 Mdot
.31436 .51615 Mdot
.42764 .3371 Mdot
.43277 .4229 Mdot
.60518 .49134 Mdot
.53777 .52 Mdot
.54537 .35416 Mdot
.36803 .59735 Mdot
.57584 .30234 Mdot
.60477 .50201 Mdot
.47702 .73538 Mdot
.48086 .71538 Mdot
.30154 .32152 Mdot
.81182 .44483 Mdot
.45354 .21094 Mdot
.37643 .39512 Mdot
.39947 .59117 Mdot
.50252 .73276 Mdot
.67226 .60171 Mdot
.37672 .35956 Mdot
.39408 .39026 Mdot
.36166 .37732 Mdot
.56859 .52345 Mdot
.3505 .5424 Mdot
.76148 .57739 Mdot
.35292 .54684 Mdot
.59256 .5654 Mdot
.41844 .60638 Mdot
.33907 .52016 Mdot
.49011 .72016 Mdot
.37819 .41327 Mdot
.41677 .62897 Mdot
.57886 .51725 Mdot
.53051 .30997 Mdot
.49779 .61047 Mdot
.56108 .65874 Mdot
.75166 .67786 Mdot
.76373 .6604 Mdot
.56665 .32559 Mdot
.82563 .49566 Mdot
.39083 .43159 Mdot
.65086 .29065 Mdot
.37287 .65333 Mdot
.61933 .47702 Mdot
.18962 .41361 Mdot
.38466 .6298 Mdot
.36665 .59517 Mdot
.5905 .53437 Mdot
.3986 .57701 Mdot
.62996 .51452 Mdot
.42613 .62474 Mdot
.46145 .65009 Mdot
.6183 .46531 Mdot
.37303 .58626 Mdot
.60596 .59163 Mdot
.62075 .56478 Mdot
.55828 .33413 Mdot
.42865 .63596 Mdot
.66066 .52678 Mdot
.65888 .81113 Mdot
.33491 .37558 Mdot
.32167 .52783 Mdot
.52116 .73068 Mdot
.38669 .3961 Mdot
.51899 .33002 Mdot
.66152 .49808 Mdot
.48721 .74422 Mdot
.53906 .31945 Mdot
.46432 .67023 Mdot
.48843 .70816 Mdot
.19447 .43986 Mdot
.54317 .3586 Mdot
.32619 .52064 Mdot
.4944 .7255 Mdot
.54024 .50645 Mdot
.43394 .63609 Mdot
.53699 .62963 Mdot
.35051 .54911 Mdot
.61654 .52357 Mdot
.32961 .55268 Mdot
.33209 .37792 Mdot
.64527 .53791 Mdot
.43799 .61918 Mdot
.33222 .5395 Mdot
.56953 .52941 Mdot
.60113 .54582 Mdot
.31356 .26849 Mdot
.22176 .56291 Mdot
.46985 .7498 Mdot
.53136 .28931 Mdot
.58416 .52252 Mdot
.49648 .73223 Mdot
.37951 .76743 Mdot
.56703 .50632 Mdot
.50623 .32488 Mdot
.66056 .46484 Mdot
.42691 .60808 Mdot
.37244 .41307 Mdot
.41109 .64464 Mdot
.48818 .75286 Mdot
.1427 .56546 Mdot
.33252 .51222 Mdot
.62278 .58773 Mdot
.62805 .49076 Mdot
.28913 .51503 Mdot
.5136 .33867 Mdot
.54761 .76388 Mdot
.60456 .5134 Mdot
.70756 .56378 Mdot
.64225 .51892 Mdot
.36877 .69522 Mdot
.55137 .34089 Mdot
.62101 .51938 Mdot
.51233 .54867 Mdot
.58116 .57248 Mdot
.47297 .76105 Mdot
.71346 .68074 Mdot
.58055 .49249 Mdot
.75009 .2257 Mdot
.36644 .55738 Mdot
.37379 .58457 Mdot
.30356 .52886 Mdot
.4761 .83006 Mdot
.44123 .20617 Mdot
.52198 .3573 Mdot
.46962 .35791 Mdot
.38569 .60312 Mdot
.49021 .20512 Mdot
.82839 .52211 Mdot
.61684 .56532 Mdot
.561 .52487 Mdot
.39522 .63621 Mdot
.36176 .56188 Mdot
.31695 .51125 Mdot
.66139 .51589 Mdot
.54051 .48956 Mdot
.38522 .57986 Mdot
.57896 .50897 Mdot
.65574 .46554 Mdot
.35584 .42201 Mdot
.55772 .31268 Mdot
.35222 .40605 Mdot
.38487 .41243 Mdot
.68236 .35681 Mdot
.26764 .34338 Mdot
.33258 .38788 Mdot
.39825 .41944 Mdot
.593 .69571 Mdot
.58429 .42564 Mdot
.49261 .7524 Mdot
.80157 .56078 Mdot
.4034 .61713 Mdot
.62462 .5322 Mdot
.56812 .3477 Mdot
.66631 .32853 Mdot
.38221 .50835 Mdot
.20017 .60443 Mdot
.60728 .4985 Mdot
.39903 .60437 Mdot
.34069 .54518 Mdot
.61108 .46283 Mdot
.28375 .60774 Mdot
.65292 .53024 Mdot
.42271 .64258 Mdot
.74535 .45834 Mdot
.5147 .48859 Mdot
.25198 .57435 Mdot
.57594 .37295 Mdot
.63292 .50181 Mdot
.52892 .35562 Mdot
.36225 .4076 Mdot
.48608 .75061 Mdot
.4718 .7493 Mdot
.61627 .54899 Mdot
.71866 .56444 Mdot
.3862 .48219 Mdot
.61853 .56656 Mdot
.60747 .55854 Mdot
.33295 .53696 Mdot
.61024 .55914 Mdot
.63061 .49249 Mdot
.64773 .50789 Mdot
.60414 .57912 Mdot
.36294 .36016 Mdot
.51124 .49505 Mdot
.66143 .55504 Mdot
.64833 .46466 Mdot
.35477 .42471 Mdot
.46651 .33207 Mdot
.3732 .41757 Mdot
.8136 .40463 Mdot
.34416 .39665 Mdot
.46289 .74358 Mdot
.33967 .56941 Mdot
.68506 .47989 Mdot
.5406 .37818 Mdot
.35302 .35651 Mdot
.46831 .73078 Mdot
.37684 .40211 Mdot
.41436 .59984 Mdot
.55936 .17785 Mdot
.54296 .39966 Mdot
.54126 .74072 Mdot
.29673 .36825 Mdot
.23297 .52437 Mdot
.388 .62763 Mdot
.55464 .34012 Mdot
.77222 .41176 Mdot
.65826 .52541 Mdot
.49352 .72169 Mdot
.61196 .54194 Mdot
.36499 .35939 Mdot
.40133 .60936 Mdot
.69755 .71573 Mdot
.47966 .74949 Mdot
.34915 .22801 Mdot
.40929 .61264 Mdot
.65314 .54978 Mdot
.38969 .3712 Mdot
.43076 .16847 Mdot
.3495 .40666 Mdot
.50463 .63609 Mdot
.50442 .31589 Mdot
.62672 .42521 Mdot
.53135 .33201 Mdot
.32614 .4959 Mdot
.6666 .19604 Mdot
.7998 .61779 Mdot
.53885 .31013 Mdot
.25894 .62162 Mdot
.56291 .52672 Mdot
.56394 .50518 Mdot
.51691 .50298 Mdot
.51036 .30916 Mdot
.58521 .5154 Mdot
.3417 .54436 Mdot
.36256 .28641 Mdot
.29195 .65506 Mdot
.35889 .59607 Mdot
.62402 .51183 Mdot
.34932 .42153 Mdot
.38998 .42036 Mdot
.34751 .53261 Mdot
.36752 .41883 Mdot
.63901 .55711 Mdot
.53333 .32894 Mdot
.41614 .43269 Mdot
.48393 .73894 Mdot
.68053 .7752 Mdot
.49788 .75078 Mdot
.35054 .55489 Mdot
.55684 .4728 Mdot
.38003 .59968 Mdot
.23118 .74322 Mdot
.64665 .54758 Mdot
.51875 .31252 Mdot
.58562 .53968 Mdot
.6394 .50798 Mdot
.55957 .51001 Mdot
.39303 .58146 Mdot
.49795 .79165 Mdot
.57833 .511 Mdot
.36677 .38194 Mdot
.77776 .61203 Mdot
.56788 .49779 Mdot
.45914 .6482 Mdot
.65802 .69788 Mdot
.22315 .50022 Mdot
.5396 .38204 Mdot
.36944 .59465 Mdot
.52192 .32041 Mdot
.57382 .36715 Mdot
.51885 .33027 Mdot
.77291 .56472 Mdot
.76709 .42605 Mdot
.36638 .81264 Mdot
.68362 .45691 Mdot
.64113 .3145 Mdot
.52875 .28687 Mdot
.37601 .78338 Mdot
.55029 .37143 Mdot
.518 .34582 Mdot
.83749 .68288 Mdot
.55461 .37287 Mdot
.61615 .50907 Mdot
.57403 .48124 Mdot
.42945 .29269 Mdot
.57371 .7033 Mdot
.61704 .55634 Mdot
.58536 .52829 Mdot
.49137 .74307 Mdot
.7133 .58744 Mdot
.31291 .51034 Mdot
.19682 .43379 Mdot
.47905 .26022 Mdot
.61216 .54368 Mdot
.58208 .52225 Mdot
.54219 .52894 Mdot
.58789 .14041 Mdot
.69273 .34301 Mdot
.53702 .28444 Mdot
.54347 .56369 Mdot
.7416 .71897 Mdot
.63237 .56686 Mdot
.57069 .50706 Mdot
.56719 .53969 Mdot
.38694 .60363 Mdot
.53122 .28096 Mdot
.54201 .56036 Mdot
.21443 .46403 Mdot
.56923 .55447 Mdot
.42244 .36274 Mdot
.51825 .80164 Mdot
.61815 .51372 Mdot
.50772 .36075 Mdot
.58376 .54755 Mdot
.54319 .36074 Mdot
.5602 .33046 Mdot
.54316 .52322 Mdot
.79269 .51997 Mdot
.50396 .32844 Mdot
.58422 .56207 Mdot
.37955 .59108 Mdot
.81331 .60317 Mdot
.61463 .52185 Mdot
.45625 .74196 Mdot
.60289 .51224 Mdot
.45599 .75295 Mdot
.60528 .56218 Mdot
.35351 .54939 Mdot
.66332 .27463 Mdot
.3942 .61449 Mdot
.55172 .80337 Mdot
.37168 .56794 Mdot
.31145 .27015 Mdot
.50731 .32514 Mdot
.33448 .54293 Mdot
.17791 .59402 Mdot
.32731 .53126 Mdot
.4995 .51463 Mdot
.48109 .55435 Mdot
.37525 .37248 Mdot
.53473 .29857 Mdot
.63948 .74471 Mdot
.28162 .50894 Mdot
.33532 .58621 Mdot
.35253 .5725 Mdot
.14872 .53801 Mdot
.16959 .5325 Mdot
.57514 .51776 Mdot
.77161 .51409 Mdot
.64966 .40809 Mdot
.56811 .50679 Mdot
.66912 .51626 Mdot
.44081 .63121 Mdot
.62154 .48845 Mdot
.48773 .43272 Mdot
.38959 .62439 Mdot
.46701 .72544 Mdot
.52215 .34856 Mdot
.45201 .74106 Mdot
.30137 .5403 Mdot
.48643 .55939 Mdot
.42338 .62324 Mdot
.5945 .57882 Mdot
.58349 .53596 Mdot
.55738 .34795 Mdot
.56748 .28193 Mdot
.55943 .31923 Mdot
.47444 .70253 Mdot
.39585 .6237 Mdot
.68456 .32796 Mdot
.59334 .52844 Mdot
.5396 .32996 Mdot
.31181 .41345 Mdot
.58849 .52409 Mdot
.37703 .4062 Mdot
.56099 .53632 Mdot
.53764 .30767 Mdot
.61037 .55935 Mdot
.53203 .32757 Mdot
.37231 .61434 Mdot
.62712 .57051 Mdot
.59482 .53572 Mdot
.42303 .17552 Mdot
.46781 .74367 Mdot
.50796 .32288 Mdot
.4324 .48393 Mdot
.6576 .54356 Mdot
.27241 .53552 Mdot
.62345 .49806 Mdot
.50127 .38668 Mdot
.60913 .58947 Mdot
.33204 .53755 Mdot
.6493 .47218 Mdot
.61575 .52174 Mdot
.51635 .58272 Mdot
.69793 .45138 Mdot
.56893 .28969 Mdot
.38398 .36871 Mdot
.50312 .35209 Mdot
.44247 .61215 Mdot
.34857 .55583 Mdot
.42607 .59935 Mdot
.55939 .71948 Mdot
.54403 .52186 Mdot
.63234 .52356 Mdot
.32239 .37053 Mdot
.46517 .72031 Mdot
.54574 .32945 Mdot
.4695 .7173 Mdot
.21892 .39987 Mdot
.47859 .70295 Mdot
.35108 .53986 Mdot
.36202 .69995 Mdot
.69951 .32143 Mdot
.49238 .74089 Mdot
.55879 .31624 Mdot
.36715 .7172 Mdot
.62493 .48022 Mdot
.49382 .68386 Mdot
.47818 .73391 Mdot
.1392 .51998 Mdot
.61331 .4895 Mdot
.4996 .49642 Mdot
.34144 .40536 Mdot
.48256 .71195 Mdot
.35493 .38373 Mdot
.61598 .5539 Mdot
.24243 .49318 Mdot
.51571 .35073 Mdot
.36706 .43198 Mdot
.67057 .53862 Mdot
.46537 .71078 Mdot
.41914 .61906 Mdot
.34752 .34027 Mdot
.36522 .36561 Mdot
.65057 .24535 Mdot
.69965 .70467 Mdot
.39327 .62354 Mdot
.23643 .62893 Mdot
.35241 .37579 Mdot
.57219 .50224 Mdot
.70626 .53604 Mdot
.6477 .5497 Mdot
.31799 .54126 Mdot
.36898 .59332 Mdot
.38948 .29448 Mdot
.58086 .53595 Mdot
.61815 .49244 Mdot
.49617 .31941 Mdot
.38001 .61935 Mdot
.53623 .34669 Mdot
.52214 .37133 Mdot
.3706 .6141 Mdot
.52778 .33625 Mdot
.49125 .71392 Mdot
.37723 .27025 Mdot
.35119 .37534 Mdot
.36591 .38578 Mdot
.40449 .60757 Mdot
.3769 .57982 Mdot
.37804 .60061 Mdot
.5611 .53699 Mdot
.54953 .33385 Mdot
.57897 .5533 Mdot
.55943 .51565 Mdot
.57928 .37309 Mdot
.55975 .37251 Mdot
.57436 .54345 Mdot
.25702 .56708 Mdot
.46233 .6828 Mdot
.38005 .58552 Mdot
.33548 .39696 Mdot
.52828 .21958 Mdot
.31755 .38806 Mdot
.62551 .50995 Mdot
.27635 .39523 Mdot
.54474 .31138 Mdot
.49202 .72781 Mdot
.44232 .72486 Mdot
.48844 .73968 Mdot
.34409 .35203 Mdot
.51627 .36123 Mdot
.1972 .43651 Mdot
.62723 .51402 Mdot
.48273 .44738 Mdot
.65136 .73832 Mdot
.22561 .4059 Mdot
.33274 .39057 Mdot
.58584 .52452 Mdot
.32388 .52557 Mdot
.75411 .37649 Mdot
.65148 .52629 Mdot
.65222 .50877 Mdot
.35387 .65577 Mdot
.63893 .45763 Mdot
.50431 .31938 Mdot
.26352 .32437 Mdot
.57156 .48509 Mdot
.57128 .39953 Mdot
.53898 .86218 Mdot
.62893 .50581 Mdot
.59872 .50306 Mdot
.60785 .52789 Mdot
.59013 .54519 Mdot
.5006 .34996 Mdot
.59418 .74883 Mdot
.38787 .36906 Mdot
.47851 .46931 Mdot
.35326 .37175 Mdot
.41939 .64211 Mdot
.50508 .46743 Mdot
.54741 .30076 Mdot
.49292 .72788 Mdot
.70549 .28671 Mdot
.24204 .35423 Mdot
.39718 .63113 Mdot
.73222 .38383 Mdot
.4792 .73973 Mdot
.61605 .47459 Mdot
.44883 .73527 Mdot
.35844 .56114 Mdot
.36876 .37573 Mdot
.58571 .47321 Mdot
.56487 .34768 Mdot
.53969 .3032 Mdot
.58686 .51783 Mdot
.75634 .7005 Mdot
.3764 .40831 Mdot
.33807 .4266 Mdot
.56644 .52592 Mdot
.65312 .50954 Mdot
.53216 .34752 Mdot
.38876 .59198 Mdot
.29469 .71815 Mdot
.4651 .73604 Mdot
.64212 .56894 Mdot
.59362 .54804 Mdot
.26483 .34161 Mdot
.38833 .40382 Mdot
.33082 .51666 Mdot
.56984 .52471 Mdot
.29651 .33064 Mdot
.56996 .52628 Mdot
.62086 .46286 Mdot
.38184 .5956 Mdot
.57701 .58385 Mdot
.57848 .50336 Mdot
.55334 .58108 Mdot
.35279 .37887 Mdot
.51531 .32 Mdot
.49569 .3369 Mdot
.31684 .51594 Mdot
.3755 .40635 Mdot
.57751 .54464 Mdot
.38696 .40302 Mdot
.56939 .50087 Mdot
.58185 .5097 Mdot
.33308 .38849 Mdot
.53572 .34629 Mdot
.44899 .34538 Mdot
.50963 .49042 Mdot
.58601 .54236 Mdot
.61644 .46763 Mdot
.56796 .71683 Mdot
.23021 .69907 Mdot
.61055 .49871 Mdot
.53773 .30565 Mdot
.59165 .53069 Mdot
.35445 .39227 Mdot
.47777 .70449 Mdot
.53319 .30858 Mdot
.3996 .59556 Mdot
.37909 .62659 Mdot
.48745 .2221 Mdot
.34499 .5298 Mdot
.63256 .47749 Mdot
.48942 .36051 Mdot
.5686 .35505 Mdot
.6036 .8343 Mdot
.3674 .61272 Mdot
.48069 .76072 Mdot
.60592 .54809 Mdot
.28555 .38972 Mdot
.32561 .36614 Mdot
.74223 .21552 Mdot
.19593 .44049 Mdot
.49739 .75383 Mdot
.19371 .60274 Mdot
.32808 .52494 Mdot
.59165 .49372 Mdot
.48348 .75288 Mdot
.41026 .63455 Mdot
.60521 .47987 Mdot
.67944 .56062 Mdot
.53898 .75756 Mdot
.43055 .6501 Mdot
.38252 .40835 Mdot
.42714 .6034 Mdot
.45396 .70709 Mdot
.35153 .54139 Mdot
.54811 .30426 Mdot
.62005 .52291 Mdot
.54021 .54115 Mdot
.39309 .59186 Mdot
.35453 .54985 Mdot
.56521 .54114 Mdot
.52732 .30163 Mdot
.41602 .5891 Mdot
.6195 .54673 Mdot
.65034 .29835 Mdot
.57948 .36017 Mdot
.40665 .62299 Mdot
.63178 .49496 Mdot
.59978 .42836 Mdot
.40417 .60292 Mdot
.38208 .58391 Mdot
.58473 .51591 Mdot
.49398 .71876 Mdot
.5648 .55235 Mdot
.34176 .39624 Mdot
.50173 .79244 Mdot
.35652 .39075 Mdot
.43863 .68138 Mdot
.57795 .45398 Mdot
.24589 .51791 Mdot
.55996 .31043 Mdot
.45257 .70679 Mdot
.5403 .2112 Mdot
.64947 .50267 Mdot
.81926 .49179 Mdot
.4407 .41634 Mdot
.72589 .75146 Mdot
.68218 .22842 Mdot
.47758 .72969 Mdot
.37175 .40523 Mdot
.59852 .50383 Mdot
.32517 .39157 Mdot
.47518 .75303 Mdot
.65861 .74274 Mdot
.63406 .49559 Mdot
.55059 .34402 Mdot
.56773 .55179 Mdot
.53725 .35765 Mdot
.58977 .52242 Mdot
.63985 .45878 Mdot
.35312 .6179 Mdot
.50783 .64689 Mdot
.62172 .4776 Mdot
.55572 .17472 Mdot
.39739 .50205 Mdot
.47285 .73768 Mdot
.58126 .5581 Mdot
.34132 .5345 Mdot
.39384 .41296 Mdot
.64764 .62893 Mdot
.38354 .60136 Mdot
.33478 .40419 Mdot
.5246 .34093 Mdot
.36441 .60781 Mdot
.34822 .55035 Mdot
.58117 .59471 Mdot
.46084 .75659 Mdot
.38004 .37613 Mdot
.61624 .51844 Mdot
.61383 .49029 Mdot
.27031 .65205 Mdot
.38363 .52658 Mdot
.51287 .286 Mdot
.36988 .20176 Mdot
.51305 .37333 Mdot
.46147 .73596 Mdot
.38047 .59656 Mdot
.61356 .49915 Mdot
.64331 .54216 Mdot
.33934 .55095 Mdot
.50862 .32307 Mdot
.42321 .64686 Mdot
.70256 .36699 Mdot
.36246 .58072 Mdot
.61665 .72498 Mdot
.52267 .30837 Mdot
.61217 .7271 Mdot
.45247 .70961 Mdot
.80479 .46003 Mdot
.60369 .6682 Mdot
.34249 .40706 Mdot
.62166 .72423 Mdot
.54723 .31968 Mdot
.57671 .5258 Mdot
.32956 .52342 Mdot
.3387 .52155 Mdot
.52595 .34849 Mdot
.40092 .63777 Mdot
.48239 .71333 Mdot
.59515 .50248 Mdot
.2082 .51309 Mdot
.43702 .25804 Mdot
.39592 .58833 Mdot
.67034 .48399 Mdot
.35939 .38121 Mdot
.58757 .49851 Mdot
.4545 .73725 Mdot
.38069 .38154 Mdot
.36075 .54141 Mdot
.37409 .28505 Mdot
.61771 .55126 Mdot
.28087 .32428 Mdot
.38264 .39907 Mdot
.23837 .65995 Mdot
.62009 .54147 Mdot
.35249 .37596 Mdot
.60157 .44621 Mdot
.22659 .42283 Mdot
.43384 .45259 Mdot
.8286 .53718 Mdot
.42702 .65309 Mdot
.39061 .6337 Mdot
.2515 .4499 Mdot
.32744 .59387 Mdot
.33546 .4082 Mdot
.35187 .54274 Mdot
.68713 .65834 Mdot
.35512 .38163 Mdot
.56007 .52252 Mdot
.62507 .50069 Mdot
.67743 .34921 Mdot
.45345 .44611 Mdot
.35439 .54702 Mdot
.4184 .21997 Mdot
.65789 .54056 Mdot
.65369 .57713 Mdot
.64073 .53941 Mdot
.54902 .2916 Mdot
.38852 .38694 Mdot
.46586 .16786 Mdot
.36852 .41014 Mdot
.20077 .53394 Mdot
.40306 .61645 Mdot
.3737 .57789 Mdot
.62023 .51167 Mdot
.24183 .53815 Mdot
.7259 .59844 Mdot
.63383 .56206 Mdot
.26655 .55635 Mdot
.70887 .69772 Mdot
.67034 .54554 Mdot
.50482 .31229 Mdot
.5655 .48195 Mdot
.57495 .31693 Mdot
.36064 .36739 Mdot
.48095 .72368 Mdot
.48262 .68795 Mdot
.37804 .37588 Mdot
.63311 .5254 Mdot
.27617 .5621 Mdot
.64618 .51917 Mdot
.57288 .52112 Mdot
.1882 .51341 Mdot
.50232 .7372 Mdot
.3756 .6031 Mdot
.47482 .74985 Mdot
.51746 .34582 Mdot
.92263 .49441 Mdot
.46762 .71552 Mdot
.71259 .51275 Mdot
.58783 .78266 Mdot
.61844 .72688 Mdot
.53827 .30192 Mdot
.4751 .69615 Mdot
.37259 .41221 Mdot
.7592 .72913 Mdot
.24887 .71858 Mdot
.32657 .40897 Mdot
.62663 .54439 Mdot
.55117 .30049 Mdot
.56546 .32568 Mdot
.37219 .43365 Mdot
.55685 .3248 Mdot
.53804 .49583 Mdot
.57624 .53355 Mdot
.33432 .40616 Mdot
.43332 .27861 Mdot
.36824 .3661 Mdot
.35879 .27479 Mdot
.5745 .55504 Mdot
.52622 .30798 Mdot
.55536 .48947 Mdot
.52711 .39324 Mdot
.32742 .51113 Mdot
.60037 .48012 Mdot
.48766 .71768 Mdot
.47034 .4356 Mdot
.40407 .62169 Mdot
.27773 .40216 Mdot
.55567 .35023 Mdot
.39383 .4393 Mdot
.55862 .33267 Mdot
.54257 .29454 Mdot
.38485 .41304 Mdot
.52746 .36596 Mdot
.59825 .50231 Mdot
.25666 .60033 Mdot
.54427 .36356 Mdot
.3684 .39695 Mdot
.48678 .72758 Mdot
.53059 .33973 Mdot
.44088 .63436 Mdot
.59805 .5417 Mdot
.42784 .61949 Mdot
.35681 .62616 Mdot
.52817 .29913 Mdot
.47822 .69693 Mdot
.36859 .5889 Mdot
.46733 .75782 Mdot
.68569 .73739 Mdot
.33237 .37139 Mdot
.20457 .60734 Mdot
.58264 .42943 Mdot
.56543 .34855 Mdot
.35823 .62634 Mdot
.61324 .5013 Mdot
.59824 .5431 Mdot
.4645 .69625 Mdot
.56591 .32703 Mdot
.80014 .62773 Mdot
.48314 .36393 Mdot
.38126 .2748 Mdot
.34102 .36184 Mdot
.38781 .20712 Mdot
.35184 .30541 Mdot
.56826 .8199 Mdot
.60817 .59556 Mdot
.32868 .52515 Mdot
.6359 .517 Mdot
.55087 .21254 Mdot
.46895 .7066 Mdot
.31788 .75406 Mdot
.54748 .53734 Mdot
.37955 .60978 Mdot
.60957 .53495 Mdot
.55906 .62278 Mdot
.57079 .47374 Mdot
.49652 .72061 Mdot
.40758 .34815 Mdot
.53826 .37715 Mdot
.48227 .73973 Mdot
.37887 .62502 Mdot
.68854 .67833 Mdot
.60921 .47964 Mdot
.66451 .52633 Mdot
.36227 .57674 Mdot
.5535 .33965 Mdot
.42507 .63988 Mdot
.35155 .37509 Mdot
.47516 .71821 Mdot
.60145 .54838 Mdot
.60096 .58445 Mdot
.27567 .53899 Mdot
.38897 .38454 Mdot
.36601 .58306 Mdot
.35381 .40835 Mdot
.32842 .52412 Mdot
.60562 .46912 Mdot
.37611 .57619 Mdot
.60278 .48733 Mdot
.49145 .18927 Mdot
.19093 .52369 Mdot
.71186 .45759 Mdot
.37459 .60776 Mdot
.62865 .70725 Mdot
.35806 .3979 Mdot
.34635 .39989 Mdot
.60549 .41051 Mdot
.69442 .62204 Mdot
.38695 .71265 Mdot
.66102 .2478 Mdot
.35095 .37477 Mdot
.36023 .38996 Mdot
.42436 .63271 Mdot
.5296 .36505 Mdot
.57134 .31409 Mdot
.37245 .62804 Mdot
.51793 .66995 Mdot
.54559 .32947 Mdot
.81561 .50824 Mdot
.44344 .61469 Mdot
.62086 .59648 Mdot
.30427 .51118 Mdot
.48094 .71741 Mdot
.51402 .66108 Mdot
.55661 .61946 Mdot
.61139 .49436 Mdot
.26813 .31451 Mdot
.39034 .59593 Mdot
.57119 .75722 Mdot
.81036 .39852 Mdot
.6379 .4979 Mdot
.62339 .53462 Mdot
.63777 .52852 Mdot
.50404 .72441 Mdot
.57288 .24152 Mdot
.60884 .49248 Mdot
.51695 .67419 Mdot
.65572 .54992 Mdot
.56593 .64859 Mdot
.47193 .74965 Mdot
.59473 .33217 Mdot
.40731 .65214 Mdot
.20817 .44552 Mdot
.52077 .49365 Mdot
.34744 .3846 Mdot
.35449 .61092 Mdot
.3598 .36992 Mdot
.76818 .5568 Mdot
.60595 .67039 Mdot
.51293 .29262 Mdot
.60576 .4974 Mdot
.35253 .56782 Mdot
.56077 .31693 Mdot
.27086 .51565 Mdot
.87054 .63577 Mdot
.3896 .37917 Mdot
.2495 .75343 Mdot
.34803 .40337 Mdot
.3313 .51334 Mdot
.53031 .34739 Mdot
.76177 .43227 Mdot
.48329 .446 Mdot
.52995 .33699 Mdot
.43563 .34004 Mdot
.52321 .38255 Mdot
.62998 .71347 Mdot
.55641 .3815 Mdot
.36487 .39864 Mdot
.33439 .34895 Mdot
.64313 .58743 Mdot
.61178 .5077 Mdot
.48846 .56456 Mdot
.66657 .45853 Mdot
.61113 .50469 Mdot
.38916 .62416 Mdot
.22735 .65469 Mdot
.35887 .61722 Mdot
.55199 .36714 Mdot
.39104 .37629 Mdot
.62055 .5349 Mdot
.57635 .53719 Mdot
.59175 .4882 Mdot
.40367 .17601 Mdot
.81054 .52144 Mdot
.57859 .51242 Mdot
.63103 .57444 Mdot
.37275 .6132 Mdot
.45867 .7753 Mdot
.59878 .2067 Mdot
.66589 .66078 Mdot
.65421 .53524 Mdot
.47238 .74681 Mdot
.49375 .75442 Mdot
.61131 .47758 Mdot
.2173 .50559 Mdot
.25387 .60341 Mdot
.6159 .51872 Mdot
.60409 .65595 Mdot
.30813 .55029 Mdot
.34807 .53303 Mdot
.39547 .59427 Mdot
.51186 .36501 Mdot
.34747 .54385 Mdot
.37781 .56903 Mdot
.75843 .41109 Mdot
.31576 .51755 Mdot
.3197 .33074 Mdot
.47428 .70255 Mdot
.6461 .53688 Mdot
.508 .37014 Mdot
.32869 .54597 Mdot
.37502 .37302 Mdot
.53119 .31698 Mdot
.39449 .41379 Mdot
.4821 .76935 Mdot
.55038 .74274 Mdot
.33673 .5175 Mdot
.34569 .38048 Mdot
.3723 .28511 Mdot
.47222 .74766 Mdot
.36566 .41765 Mdot
.25324 .52351 Mdot
.56383 .49957 Mdot
.78783 .44889 Mdot
.6169 .56886 Mdot
.75605 .71441 Mdot
.36883 .41653 Mdot
.3206 .52902 Mdot
.62848 .52247 Mdot
.40871 .61169 Mdot
.59241 .44977 Mdot
.65307 .53285 Mdot
.40583 .59875 Mdot
.57542 .51907 Mdot
.45646 .74531 Mdot
.5797 .34571 Mdot
.43867 .39839 Mdot
.18869 .35551 Mdot
.46015 .75428 Mdot
.26831 .51709 Mdot
.60946 .49848 Mdot
.69885 .71237 Mdot
.53199 .33927 Mdot
.64278 .49966 Mdot
.59601 .3696 Mdot
.53087 .36157 Mdot
.52411 .3215 Mdot
.59635 .55643 Mdot
.34756 .40976 Mdot
.41102 .617 Mdot
.47604 .74813 Mdot
.61146 .81868 Mdot
.63224 .54869 Mdot
.5933 .53351 Mdot
.48052 .73952 Mdot
.35812 .39011 Mdot
.57885 .54025 Mdot
.311 .4512 Mdot
.67809 .79524 Mdot
.39501 .39582 Mdot
.5548 .51336 Mdot
.75656 .34786 Mdot
.51274 .38389 Mdot
.23956 .72901 Mdot
.44866 .68499 Mdot
.37115 .59321 Mdot
.63653 .45671 Mdot
.82466 .31659 Mdot
.48223 .72293 Mdot
.20263 .44184 Mdot
.57192 .51514 Mdot
.59876 .52768 Mdot
.55145 .31404 Mdot
.57739 .54927 Mdot
.51004 .333 Mdot
.16247 .41483 Mdot
.29909 .25211 Mdot
.55165 .35091 Mdot
.5603 .36483 Mdot
.60411 .42061 Mdot
.58755 .20769 Mdot
.52183 .34382 Mdot
.55174 .52331 Mdot
.79478 .5955 Mdot
.60372 .6009 Mdot
.46613 .69472 Mdot
.35996 .63376 Mdot
.58692 .29851 Mdot
.43577 .57707 Mdot
.47089 .33076 Mdot
.51911 .51199 Mdot
.36739 .47952 Mdot
.33868 .39223 Mdot
.65488 .51976 Mdot
.3424 .52564 Mdot
.41089 .58655 Mdot
.57846 .46675 Mdot
.64928 .5303 Mdot
.54002 .36024 Mdot
.50161 .72015 Mdot
.3834 .41948 Mdot
.58564 .52897 Mdot
.44095 .64239 Mdot
.46486 .72883 Mdot
.55175 .36482 Mdot
.62345 .42616 Mdot
.49477 .74643 Mdot
.64219 .46617 Mdot
.60135 .51533 Mdot
.56482 .53854 Mdot
.57471 .43721 Mdot
.34277 .36785 Mdot
.30765 .53695 Mdot
.55469 .53494 Mdot
.22244 .39456 Mdot
.49272 .62763 Mdot
.58228 .58292 Mdot
.55023 .32565 Mdot
.33069 .36175 Mdot
.32543 .51231 Mdot
.6846 .69711 Mdot
.62464 .55157 Mdot
.80803 .52545 Mdot
.69477 .35044 Mdot
.34524 .54257 Mdot
.52392 .28965 Mdot
.49211 .73056 Mdot
.6396 .55578 Mdot
.78201 .58224 Mdot
.62532 .50305 Mdot
.60126 .43165 Mdot
.38117 .58966 Mdot
.33732 .39015 Mdot
.7127 .76731 Mdot
.40804 .58469 Mdot
.52255 .32064 Mdot
.83559 .53183 Mdot
.56834 .31748 Mdot
.53183 .37309 Mdot
.78638 .53239 Mdot
.34403 .3691 Mdot
.80846 .2948 Mdot
.24375 .71887 Mdot
.56568 .56235 Mdot
.35354 .39755 Mdot
.53633 .35342 Mdot
.58802 .49872 Mdot
.56547 .36182 Mdot
.51572 .35619 Mdot
.59142 .48267 Mdot
.59896 .52061 Mdot
.50771 .49066 Mdot
.82039 .45285 Mdot
.48992 .73927 Mdot
.51637 .30976 Mdot
.63863 .32646 Mdot
.60285 .49172 Mdot
.62679 .51441 Mdot
.28068 .51793 Mdot
.49667 .72366 Mdot
.52841 .59016 Mdot
.57081 .52344 Mdot
.29683 .27008 Mdot
.61148 .4663 Mdot
.49852 .33284 Mdot
.39476 .39732 Mdot
.21346 .49259 Mdot
.31702 .53978 Mdot
.50962 .31618 Mdot
.45595 .72072 Mdot
.49771 .31742 Mdot
.7066 .49908 Mdot
.35179 .36726 Mdot
.53768 .30768 Mdot
.40718 .64275 Mdot
.37592 .384 Mdot
.36554 .4171 Mdot
.77894 .61069 Mdot
.36335 .59389 Mdot
.46657 .70357 Mdot
.36551 .37499 Mdot
.64841 .28862 Mdot
.36986 .40123 Mdot
.65195 .34041 Mdot
.6186 .57189 Mdot
.53431 .70816 Mdot
.36835 .31233 Mdot
.61594 .44479 Mdot
.33957 .3673 Mdot
.47721 .75184 Mdot
.59475 .5522 Mdot
.55625 .32251 Mdot
.46961 .71479 Mdot
.40525 .35942 Mdot
.37943 .58148 Mdot
.56055 .33917 Mdot
.38859 .36899 Mdot
.51757 .31049 Mdot
.62624 .7484 Mdot
.51728 .78178 Mdot
.30859 .43488 Mdot
.48862 .4599 Mdot
.58679 .49151 Mdot
.52568 .24815 Mdot
.62521 .47146 Mdot
.65034 .52675 Mdot
.40702 .62259 Mdot
.55902 .72108 Mdot
.53573 .34698 Mdot
.71399 .76918 Mdot
.34221 .38297 Mdot
.27086 .29778 Mdot
.55271 .41293 Mdot
.65765 .51816 Mdot
.54074 .36327 Mdot
.57193 .33535 Mdot
.70056 .45507 Mdot
.42253 .59206 Mdot
.68157 .54227 Mdot
.63742 .47078 Mdot
.62884 .58957 Mdot
.36822 .41607 Mdot
.27261 .41542 Mdot
.41137 .64011 Mdot
.38423 .82895 Mdot
.38356 .58699 Mdot
.31863 .64124 Mdot
.53076 .36847 Mdot
.47823 .70626 Mdot
.62475 .51483 Mdot
.54242 .41525 Mdot
.51631 .29851 Mdot
.4416 .74038 Mdot
.48966 .71814 Mdot
.24764 .42175 Mdot
.33274 .38546 Mdot
.6195 .47971 Mdot
.62713 .4928 Mdot
.58377 .55687 Mdot
.6043 .56926 Mdot
.39185 .38241 Mdot
.56229 .51748 Mdot
.33856 .41513 Mdot
.66022 .30086 Mdot
.2847 .27569 Mdot
.34893 .56266 Mdot
.67013 .62595 Mdot
.56294 .35002 Mdot
.63035 .2748 Mdot
.68682 .51591 Mdot
.1902 .54065 Mdot
.729 .69678 Mdot
.65896 .5031 Mdot
.416 .6363 Mdot
.70139 .60607 Mdot
.35707 .56535 Mdot
.12192 .59534 Mdot
.29168 .56011 Mdot
.82623 .516 Mdot
.59558 .4969 Mdot
.28189 .51814 Mdot
.68832 .50791 Mdot
.59768 .47841 Mdot
.30876 .56943 Mdot
.38852 .22791 Mdot
.42317 .30782 Mdot
.49406 .75208 Mdot
.60584 .54373 Mdot
.56016 .37978 Mdot
.59817 .50087 Mdot
.63066 .51291 Mdot
.57199 .50991 Mdot
.39698 .38244 Mdot
.57976 .47553 Mdot
.55923 .53315 Mdot
.40802 .53904 Mdot
.59672 .70335 Mdot
.42622 .60365 Mdot
.69638 .47268 Mdot
.46609 .71999 Mdot
.54892 .35978 Mdot
.49861 .41796 Mdot
.34103 .40592 Mdot
.66587 .42987 Mdot
.56283 .54403 Mdot
.37238 .30572 Mdot
.38781 .36818 Mdot
.47589 .71547 Mdot
.31982 .51478 Mdot
.81418 .58463 Mdot
.35192 .56144 Mdot
.31569 .5161 Mdot
.40222 .62078 Mdot
.59384 .27381 Mdot
.53779 .35987 Mdot
.58542 .49109 Mdot
.36248 .37835 Mdot
.41445 .61631 Mdot
.5655 .70323 Mdot
.64103 .53659 Mdot
.37593 .6154 Mdot
.58002 .49588 Mdot
.54064 .73702 Mdot
.27328 .66395 Mdot
.36762 .56776 Mdot
.36196 .34992 Mdot
.37347 .38792 Mdot
.48916 .71049 Mdot
.55429 .35775 Mdot
.54734 .31412 Mdot
.38067 .38301 Mdot
.20547 .66992 Mdot
.65412 .5303 Mdot
.59276 .49643 Mdot
.22535 .39011 Mdot
.60184 .50669 Mdot
.6741 .69017 Mdot
.31393 .50591 Mdot
.55818 .35769 Mdot
.5822 .50259 Mdot
.5835 .54226 Mdot
.61195 .54998 Mdot
.62004 .7521 Mdot
.38953 .5892 Mdot
.65383 .54534 Mdot
.49434 .73994 Mdot
.32874 .49235 Mdot
.59473 .49424 Mdot
.63844 .58405 Mdot
.54424 .31375 Mdot
.28218 .26561 Mdot
.34166 .40075 Mdot
.39334 .62791 Mdot
.37051 .58502 Mdot
.35305 .62831 Mdot
.5836 .36392 Mdot
.31433 .50942 Mdot
.46736 .81841 Mdot
.32504 .53148 Mdot
.47435 .74139 Mdot
.39885 .67619 Mdot
.45551 .61479 Mdot
.41178 .6321 Mdot
.38989 .42456 Mdot
.56969 .55553 Mdot
.64978 .55101 Mdot
.19688 .45238 Mdot
.66193 .53053 Mdot
.48893 .72409 Mdot
.34689 .42115 Mdot
.54497 .32039 Mdot
.47893 .71385 Mdot
.35111 .40408 Mdot
.55395 .33675 Mdot
.5692 .49388 Mdot
.56023 .50182 Mdot
.52903 .32006 Mdot
.55988 .31676 Mdot
.61226 .51614 Mdot
.34841 .48919 Mdot
.52149 .37191 Mdot
.53127 .30625 Mdot
.33865 .51824 Mdot
.35139 .56277 Mdot
.54756 .5665 Mdot
.35444 .40106 Mdot
.56442 .53303 Mdot
.3534 .56433 Mdot
.49464 .7104 Mdot
.53702 .34215 Mdot
.58171 .53976 Mdot
.58138 .5301 Mdot
.4767 .74673 Mdot
.50087 .73391 Mdot
.47957 .71149 Mdot
.33145 .41017 Mdot
.6038 .56547 Mdot
.52119 .33989 Mdot
.33528 .37937 Mdot
.49335 .75482 Mdot
.45029 .74769 Mdot
.44848 .55401 Mdot
.61542 .49758 Mdot
.42669 .45828 Mdot
.91516 .48212 Mdot
.68075 .67122 Mdot
.3257 .51152 Mdot
.36089 .58133 Mdot
.58811 .73017 Mdot
.26915 .62997 Mdot
.38386 .40112 Mdot
.70505 .63811 Mdot
.45339 .70522 Mdot
.5809 .49237 Mdot
.61501 .4676 Mdot
.67001 .51669 Mdot
.46979 .7247 Mdot
.64583 .73422 Mdot
.56596 .31991 Mdot
.62287 .37533 Mdot
.46652 .71984 Mdot
.36842 .56767 Mdot
.37369 .57444 Mdot
.38293 .58688 Mdot
.58726 .4746 Mdot
.69134 .44222 Mdot
.63684 .295 Mdot
.59201 .22466 Mdot
.33236 .3969 Mdot
.52367 .28086 Mdot
.68679 .73208 Mdot
.52567 .32285 Mdot
.40237 .58064 Mdot
.46796 .72904 Mdot
.54271 .30704 Mdot
.38184 .37399 Mdot
.36082 .38797 Mdot
.38986 .58693 Mdot
.40417 .60876 Mdot
.42591 .61684 Mdot
.51407 .36267 Mdot
.52845 .36673 Mdot
.62906 .55326 Mdot
.53586 .33208 Mdot
.23354 .34276 Mdot
.50355 .74134 Mdot
.37713 .57353 Mdot
.36914 .40677 Mdot
.54052 .35795 Mdot
.6413 .54135 Mdot
.38965 .6913 Mdot
.47661 .22954 Mdot
.46534 .75574 Mdot
.26204 .65028 Mdot
.14266 .62775 Mdot
.61699 .48391 Mdot
.38369 .40813 Mdot
.2135 .53027 Mdot
.63766 .53198 Mdot
.38751 .60127 Mdot
.51673 .19214 Mdot
.34651 .54815 Mdot
.56081 .52371 Mdot
.66141 .52629 Mdot
.3692 .41903 Mdot
.58931 .78528 Mdot
.63177 .55453 Mdot
.32464 .29808 Mdot
.3996 .39253 Mdot
.43489 .62661 Mdot
.67997 .79837 Mdot
.30057 .53539 Mdot
.51809 .66261 Mdot
.33797 .52263 Mdot
.63678 .50538 Mdot
.39662 .62628 Mdot
.47042 .75625 Mdot
.41594 .6252 Mdot
.51726 .29123 Mdot
.42736 .60925 Mdot
.59472 .53325 Mdot
.51987 .34194 Mdot
.38193 .4007 Mdot
.25978 .32706 Mdot
.39846 .54028 Mdot
.40824 .61086 Mdot
.33249 .51013 Mdot
.58209 .49901 Mdot
.50936 .55424 Mdot
.56613 .45529 Mdot
.59928 .49425 Mdot
.35587 .36892 Mdot
.543 .36475 Mdot
.35263 .35925 Mdot
.63012 .5826 Mdot
.36563 .23322 Mdot
.35107 .40855 Mdot
.39319 .32729 Mdot
.4782 .74041 Mdot
.49883 .59197 Mdot
.64417 .54301 Mdot
.36179 .375 Mdot
.60144 .56525 Mdot
.56185 .3717 Mdot
.45254 .48115 Mdot
.29876 .4892 Mdot
.36316 .37956 Mdot
.78925 .65117 Mdot
.43028 .48906 Mdot
.55252 .49816 Mdot
.35465 .37342 Mdot
.60374 .35142 Mdot
.33709 .52397 Mdot
.46655 .73844 Mdot
.49396 .75377 Mdot
.47026 .75907 Mdot
.65676 .50727 Mdot
.67837 .5663 Mdot
.45588 .71544 Mdot
.39434 .40655 Mdot
.4968 .7198 Mdot
.53324 .42727 Mdot
.79585 .64098 Mdot
.46256 .7131 Mdot
.62014 .54381 Mdot
.65775 .5753 Mdot
.59217 .70324 Mdot
.40064 .57851 Mdot
.81989 .48676 Mdot
.69097 .59363 Mdot
.61473 .50654 Mdot
.6319 .60293 Mdot
.562 .31453 Mdot
.22379 .55391 Mdot
.66253 .45684 Mdot
.26481 .63297 Mdot
.55171 .37376 Mdot
.33606 .54699 Mdot
.55588 .35854 Mdot
.61128 .4834 Mdot
.58316 .5081 Mdot
.57494 .32464 Mdot
.27268 .36871 Mdot
.24046 .48015 Mdot
.68609 .77022 Mdot
.53204 .30438 Mdot
.35313 .37871 Mdot
.38958 .37824 Mdot
.33345 .39766 Mdot
.44188 .61183 Mdot
.5203 .30232 Mdot
.61352 .56351 Mdot
.37104 .6118 Mdot
.65381 .52216 Mdot
.37146 .37837 Mdot
.7208 .76145 Mdot
.54482 .3159 Mdot
.61604 .52103 Mdot
.24633 .71285 Mdot
.39799 .60881 Mdot
.46711 .74524 Mdot
.54797 .75077 Mdot
.44468 .61922 Mdot
.35428 .36281 Mdot
.57194 .32076 Mdot
.42661 .36972 Mdot
.47006 .39887 Mdot
.57536 .59012 Mdot
.56115 .5676 Mdot
.57683 .82705 Mdot
.35657 .52641 Mdot
.62376 .47409 Mdot
.38044 .62628 Mdot
.34045 .55295 Mdot
.5866 .54056 Mdot
.54281 .30176 Mdot
.46439 .76384 Mdot
.49563 .73841 Mdot
.66754 .49339 Mdot
.48297 .45027 Mdot
.49798 .59634 Mdot
.57432 .54178 Mdot
.66729 .48224 Mdot
.36891 .58324 Mdot
.32077 .52764 Mdot
.25224 .35484 Mdot
.45943 .71411 Mdot
.56978 .51822 Mdot
.44863 .31122 Mdot
.51811 .35741 Mdot
.42802 .61432 Mdot
.35541 .36452 Mdot
.63794 .751 Mdot
.43184 .6391 Mdot
.58397 .53931 Mdot
.57966 .54059 Mdot
.36528 .4179 Mdot
.49858 .33193 Mdot
.4698 .7275 Mdot
.37051 .60254 Mdot
.45869 .71424 Mdot
.5177 .34965 Mdot
.5426 .31802 Mdot
.60484 .60115 Mdot
.66634 .48259 Mdot
.39839 .59561 Mdot
.64416 .57333 Mdot
.38395 .57206 Mdot
.57965 .79353 Mdot
.35408 .35622 Mdot
.62026 .48515 Mdot
.54917 .28492 Mdot
.37027 .37523 Mdot
.60307 .52489 Mdot
.56166 .84218 Mdot
.65055 .50926 Mdot
.32228 .54059 Mdot
.34105 .24843 Mdot
.48959 .74438 Mdot
.72615 .51244 Mdot
.56677 .60402 Mdot
.5987 .50865 Mdot
.38919 .57879 Mdot
.58703 .44973 Mdot
.35912 .41459 Mdot
.54336 .37126 Mdot
.21199 .70596 Mdot
.3713 .39848 Mdot
.59305 .50111 Mdot
.47529 .71722 Mdot
.57117 .32545 Mdot
.34287 .54426 Mdot
.21426 .41455 Mdot
.5824 .45888 Mdot
.54946 .52137 Mdot
.56232 .52616 Mdot
.59697 .19884 Mdot
.39944 .62848 Mdot
.53799 .35573 Mdot
.36957 .41544 Mdot
.3837 .38532 Mdot
.38557 .58973 Mdot
.40974 .29946 Mdot
.48569 .58048 Mdot
.86537 .37462 Mdot
.41093 .6036 Mdot
.48269 .69629 Mdot
.50021 .46074 Mdot
.4014 .58245 Mdot
.38057 .61676 Mdot
.36754 .58812 Mdot
.3323 .32382 Mdot
.55173 .33412 Mdot
.57963 .52814 Mdot
.53744 .38129 Mdot
.63756 .50489 Mdot
.51598 .62828 Mdot
.37393 .37471 Mdot
.54267 .37236 Mdot
.57567 .83347 Mdot
.5034 .38296 Mdot
.63137 .53557 Mdot
.66375 .75801 Mdot
.55183 .47379 Mdot
.63936 .7218 Mdot
.54323 .49913 Mdot
.40551 .61649 Mdot
.70131 .52453 Mdot
.63093 .58604 Mdot
.24883 .33066 Mdot
.36689 .4073 Mdot
.32948 .51096 Mdot
.64345 .4864 Mdot
.62391 .4645 Mdot
.56878 .36699 Mdot
.54079 .30597 Mdot
.45962 .70986 Mdot
.49226 .64942 Mdot
.37893 .40432 Mdot
.52364 .77197 Mdot
.6095 .51028 Mdot
.28591 .36049 Mdot
.66113 .44293 Mdot
.60489 .52499 Mdot
.79634 .58474 Mdot
.67982 .43665 Mdot
.64251 .5507 Mdot
.60794 .33235 Mdot
.35939 .39278 Mdot
.33822 .25446 Mdot
.60736 .57619 Mdot
.38722 .60287 Mdot
.53396 .36811 Mdot
.55973 .30784 Mdot
.45288 .73458 Mdot
.17032 .50372 Mdot
.33884 .36633 Mdot
.53706 .37174 Mdot
.64242 .52961 Mdot
.34889 .36523 Mdot
.34606 .53227 Mdot
.61417 .58615 Mdot
.71521 .62749 Mdot
.53776 .32951 Mdot
.63131 .57487 Mdot
.42773 .22739 Mdot
.50449 .65536 Mdot
.80959 .35913 Mdot
.33526 .39995 Mdot
.47154 .70843 Mdot
.5401 .51932 Mdot
.46352 .81457 Mdot
.66882 .5244 Mdot
.53851 .71024 Mdot
.57563 .3864 Mdot
.4783 .70475 Mdot
.62791 .52958 Mdot
.61268 .55371 Mdot
.48749 .44056 Mdot
.50215 .72787 Mdot
.64084 .50144 Mdot
.7026 .56177 Mdot
.55257 .3406 Mdot
.31905 .50613 Mdot
.54186 .32794 Mdot
.6262 .54404 Mdot
.67132 .57544 Mdot
.55332 .31375 Mdot
.49429 .80764 Mdot
.47336 .68714 Mdot
.34022 .40011 Mdot
.68058 .51142 Mdot
.60202 .57055 Mdot
.60069 .17911 Mdot
.32763 .5112 Mdot
.56384 .2211 Mdot
.43618 .642 Mdot
.44812 .33057 Mdot
.29148 .52141 Mdot
.83205 .54558 Mdot
.26571 .32786 Mdot
.62858 .46993 Mdot
.62109 .64713 Mdot
.61357 .30436 Mdot
.35075 .36106 Mdot
.69783 .31077 Mdot
.61202 .50726 Mdot
.63315 .51389 Mdot
.42966 .6308 Mdot
.38919 .29823 Mdot
.21875 .51354 Mdot
.47723 .46149 Mdot
.4725 .73073 Mdot
.51313 .33548 Mdot
.58785 .52247 Mdot
.48122 .60796 Mdot
.42248 .60224 Mdot
.28632 .38385 Mdot
.62094 .52395 Mdot
.19612 .55369 Mdot
.34697 .32387 Mdot
.33804 .37124 Mdot
.37656 .57722 Mdot
.44626 .62616 Mdot
.62647 .49721 Mdot
.3654 .36592 Mdot
.63487 .55276 Mdot
.42366 .5008 Mdot
.65298 .56392 Mdot
.46243 .71579 Mdot
.57796 .49954 Mdot
.46194 .42931 Mdot
.83263 .41742 Mdot
.71675 .53722 Mdot
.54441 .29808 Mdot
.44221 .61599 Mdot
.39009 .59055 Mdot
.54275 .30887 Mdot
.39243 .59352 Mdot
.63685 .39413 Mdot
.74713 .44648 Mdot
.47522 .73399 Mdot
.67853 .49763 Mdot
.45658 .72575 Mdot
.32665 .50934 Mdot
.61644 .50128 Mdot
.46583 .82103 Mdot
.40946 .60498 Mdot
.4388 .18615 Mdot
.37311 .40168 Mdot
.32831 .51074 Mdot
.6546 .55151 Mdot
.39098 .67231 Mdot
.41861 .59254 Mdot
.33273 .54606 Mdot
.61538 .55095 Mdot
.55045 .31829 Mdot
.60564 .55188 Mdot
.55014 .47914 Mdot
.31782 .51374 Mdot
.56803 .55332 Mdot
.35119 .40406 Mdot
.50312 .35198 Mdot
.81164 .59911 Mdot
.32328 .54354 Mdot
.61598 .49267 Mdot
.64105 .52982 Mdot
.57055 .35184 Mdot
.63822 .56804 Mdot
.38106 .37196 Mdot
.62683 .12669 Mdot
.47767 .74111 Mdot
.35556 .55397 Mdot
.30372 .53764 Mdot
.66236 .50844 Mdot
.58055 .54448 Mdot
.60928 .82191 Mdot
.29664 .47463 Mdot
.34715 .38939 Mdot
.61101 .45516 Mdot
.37254 .61084 Mdot
.47682 .71694 Mdot
.3881 .41726 Mdot
.56577 .53954 Mdot
.62751 .51779 Mdot
.46679 .71353 Mdot
.78269 .61652 Mdot
.26369 .63601 Mdot
.33442 .40285 Mdot
.69876 .51694 Mdot
.38204 .69921 Mdot
.65374 .53146 Mdot
.41961 .71985 Mdot
.53446 .30734 Mdot
.34695 .37309 Mdot
.59462 .21868 Mdot
.57551 .49882 Mdot
.38812 .3813 Mdot
.37585 .40617 Mdot
.57392 .57081 Mdot
.56374 .38287 Mdot
.50738 .3514 Mdot
.51442 .31534 Mdot
.25169 .29404 Mdot
.54529 .66055 Mdot
.42554 .61603 Mdot
.35883 .39142 Mdot
.36171 .56706 Mdot
.50533 .72492 Mdot
.49209 .61729 Mdot
.36391 .56375 Mdot
.56273 .31917 Mdot
.37101 .57381 Mdot
.60925 .55136 Mdot
.38326 .3997 Mdot
.41548 .63184 Mdot
.64434 .48959 Mdot
.53754 .59326 Mdot
.40856 .48281 Mdot
.45671 .75888 Mdot
.4457 .70586 Mdot
.58389 .51318 Mdot
.32543 .51273 Mdot
.61457 .51554 Mdot
.33817 .41223 Mdot
.4786 .41703 Mdot
.65932 .50617 Mdot
.40463 .60424 Mdot
.66402 .60208 Mdot
.4281 .5967 Mdot
.58926 .4522 Mdot
.62126 .54275 Mdot
.64978 .5192 Mdot
.63439 .55403 Mdot
.41569 .32344 Mdot
.3392 .36253 Mdot
.55389 .60885 Mdot
.36981 .63383 Mdot
.53017 .32982 Mdot
.53261 .28317 Mdot
.37492 .71748 Mdot
.36256 .55708 Mdot
.35469 .3998 Mdot
.65021 .53937 Mdot
.30938 .53455 Mdot
.72966 .75395 Mdot
.4952 .81026 Mdot
.43938 .72763 Mdot
.39162 .63118 Mdot
.54721 .2972 Mdot
.42379 .5992 Mdot
.63143 .50274 Mdot
.55989 .55841 Mdot
.82841 .56642 Mdot
.3567 .34628 Mdot
.46817 .72759 Mdot
.64724 .51531 Mdot
.51667 .65719 Mdot
.37269 .613 Mdot
.3662 .58658 Mdot
.65071 .5114 Mdot
.50522 .32506 Mdot
.73628 .25507 Mdot
.33957 .36917 Mdot
.67928 .61182 Mdot
.53055 .26322 Mdot
.35674 .25347 Mdot
.38103 .37842 Mdot
.38654 .48637 Mdot
.37537 .6268 Mdot
.73797 .52151 Mdot
.53104 .32529 Mdot
.46638 .72513 Mdot
.56806 .57133 Mdot
.563 .32667 Mdot
.37114 .62701 Mdot
.5603 .35887 Mdot
.59715 .48377 Mdot
.3469 .36057 Mdot
.37203 .58946 Mdot
.34486 .35188 Mdot
.57331 .31482 Mdot
.46149 .74786 Mdot
.49796 .54215 Mdot
.7344 .34375 Mdot
.67517 .43411 Mdot
.65272 .54646 Mdot
.47411 .60856 Mdot
.60288 .56411 Mdot
.56478 .37708 Mdot
.63939 .54524 Mdot
.5594 .25755 Mdot
.37852 .57889 Mdot
.62839 .57544 Mdot
.56144 .52063 Mdot
.69869 .33087 Mdot
.61861 .53201 Mdot
.56924 .55908 Mdot
.64394 .5507 Mdot
.55639 .27312 Mdot
.57962 .47188 Mdot
.55202 .32758 Mdot
.21354 .42447 Mdot
.38241 .61754 Mdot
.45803 .76157 Mdot
.49104 .75016 Mdot
.53098 .69851 Mdot
.50587 .63862 Mdot
.40267 .30284 Mdot
.5444 .33576 Mdot
.35967 .41011 Mdot
.63725 .5519 Mdot
.63528 .23777 Mdot
.33001 .59131 Mdot
.36774 .60832 Mdot
.32349 .54246 Mdot
.59075 .43836 Mdot
.59906 .19787 Mdot
.6502 .56122 Mdot
.19199 .44439 Mdot
.67401 .52 Mdot
.64213 .49949 Mdot
.44377 .62652 Mdot
.50164 .63815 Mdot
.65574 .54329 Mdot
.56883 .36602 Mdot
.46254 .72943 Mdot
.47921 .3432 Mdot
.27644 .59776 Mdot
.36832 .48737 Mdot
.74334 .38664 Mdot
.61412 .5664 Mdot
.37244 .59362 Mdot
.56026 .33979 Mdot
.25761 .34745 Mdot
.33593 .37896 Mdot
.35504 .3123 Mdot
.65537 .31182 Mdot
.61948 .79478 Mdot
.46504 .72825 Mdot
.77978 .61442 Mdot
.59301 .53249 Mdot
.44256 .61118 Mdot
.58648 .4855 Mdot
.73382 .74943 Mdot
.4777 .696 Mdot
.50923 .30679 Mdot
.35221 .38024 Mdot
.55997 .37389 Mdot
.71452 .46154 Mdot
.3431 .4625 Mdot
.4681 .52283 Mdot
.35232 .56059 Mdot
.52703 .59187 Mdot
.52508 .34973 Mdot
.57006 .53077 Mdot
.8888 .41764 Mdot
.53175 .30709 Mdot
.5097 .31945 Mdot
.55597 .80003 Mdot
.55517 .80576 Mdot
.61823 .45144 Mdot
.5636 .35702 Mdot
.35427 .57786 Mdot
.48257 .74753 Mdot
.60926 .55647 Mdot
.62606 .55574 Mdot
.55096 .31437 Mdot
.39904 .57826 Mdot
.68924 .60939 Mdot
.40505 .61284 Mdot
.55391 .34208 Mdot
.39426 .61397 Mdot
.33684 .55998 Mdot
.3969 .6304 Mdot
.6137 .57274 Mdot
.63903 .54702 Mdot
.29395 .6405 Mdot
.54254 .31821 Mdot
.58267 .54883 Mdot
.57558 .51456 Mdot
.52291 .34338 Mdot
.4354 .64475 Mdot
.6587 .25694 Mdot
.60693 .49848 Mdot
.60132 .5413 Mdot
.47465 .70588 Mdot
.44654 .60072 Mdot
.2698 .67912 Mdot
.59511 .55253 Mdot
.49408 .70528 Mdot
.51723 .36577 Mdot
.61219 .51778 Mdot
.53058 .43046 Mdot
.34059 .55731 Mdot
.57246 .50338 Mdot
.34699 .54598 Mdot
.66503 .52639 Mdot
.76056 .29483 Mdot
.60892 .49056 Mdot
.53463 .35125 Mdot
.53192 .36338 Mdot
.56815 .79049 Mdot
.52098 .31969 Mdot
.33926 .5232 Mdot
.37367 .38158 Mdot
.75286 .72294 Mdot
.34749 .5354 Mdot
.64446 .49933 Mdot
.2438 .71923 Mdot
.62354 .57995 Mdot
.64826 .49157 Mdot
.56324 .19072 Mdot
.34817 .53784 Mdot
.53502 .36086 Mdot
.30915 .33972 Mdot
.67395 .51147 Mdot
.35314 .36405 Mdot
.59367 .58818 Mdot
.55673 .53756 Mdot
.31184 .28373 Mdot
.50085 .21131 Mdot
.35546 .42485 Mdot
.56741 .58834 Mdot
.59433 .55253 Mdot
.43055 .56735 Mdot
.64302 .53694 Mdot
.45699 .72054 Mdot
.51069 .31986 Mdot
.41263 .59461 Mdot
.48396 .74063 Mdot
.60486 .50903 Mdot
.47018 .72196 Mdot
.42701 .61756 Mdot
.35261 .36967 Mdot
.62231 .49868 Mdot
.47117 .69237 Mdot
.47205 .72914 Mdot
.59343 .56083 Mdot
.53891 .3712 Mdot
.70218 .50637 Mdot
.60996 .51973 Mdot
.57364 .53133 Mdot
.54743 .31433 Mdot
.41366 .83997 Mdot
.62188 .48913 Mdot
.42224 .46423 Mdot
.51355 .3031 Mdot
.30036 .50696 Mdot
.42941 .62233 Mdot
.55609 .53857 Mdot
.35943 .36663 Mdot
.3706 .37347 Mdot
.35887 .58768 Mdot
.56373 .36981 Mdot
.41095 .58483 Mdot
.67024 .59633 Mdot
.67566 .5007 Mdot
.59959 .58037 Mdot
.18996 .65658 Mdot
.82242 .56088 Mdot
.54583 .30175 Mdot
.40873 .64029 Mdot
.47915 .46791 Mdot
.35569 .38893 Mdot
.35997 .57458 Mdot
.57229 .32718 Mdot
.55212 .30001 Mdot
.5624 .34999 Mdot
.48214 .70869 Mdot
.41442 .64259 Mdot
.50061 .32318 Mdot
.5048 .32961 Mdot
.61207 .55086 Mdot
.59162 .55202 Mdot
.57641 .40456 Mdot
.62394 .70224 Mdot
.4574 .74377 Mdot
.38319 .59173 Mdot
.51752 .12773 Mdot
.34076 .41523 Mdot
.70267 .33612 Mdot
.65735 .5028 Mdot
.90759 .57835 Mdot
.65397 .55799 Mdot
.64416 .53094 Mdot
.51377 .36561 Mdot
.45905 .70075 Mdot
.45818 .73378 Mdot
.5249 .35129 Mdot
.57097 .31248 Mdot
.4599 .71513 Mdot
.74301 .68357 Mdot
.79533 .64627 Mdot
.30949 .32478 Mdot
.52951 .34478 Mdot
.75502 .37864 Mdot
.35801 .36341 Mdot
.57628 .31999 Mdot
.35187 .41922 Mdot
.3793 .61417 Mdot
.37371 .62655 Mdot
.36282 .41744 Mdot
.61943 .55124 Mdot
.42445 .62403 Mdot
.5591 .4926 Mdot
.76218 .66934 Mdot
.78546 .50057 Mdot
.27318 .46273 Mdot
.61773 .46782 Mdot
.21705 .49958 Mdot
.22924 .51864 Mdot
.5916 .50967 Mdot
.4764 .37709 Mdot
.46834 .72557 Mdot
.57782 .31253 Mdot
.37858 .37051 Mdot
.80183 .34695 Mdot
.65284 .53476 Mdot
.53767 .34906 Mdot
.36272 .4068 Mdot
.57259 .77617 Mdot
.33005 .29381 Mdot
.64152 .50788 Mdot
.83838 .33665 Mdot
.58129 .31314 Mdot
.41306 .59557 Mdot
.19924 .62302 Mdot
.52703 .37798 Mdot
.44931 .68918 Mdot
.38195 .63589 Mdot
.61241 .81011 Mdot
.54896 .35932 Mdot
.36867 .62607 Mdot
.51537 .33972 Mdot
.45439 .73019 Mdot
.5762 .37197 Mdot
.36939 .5937 Mdot
.62311 .53034 Mdot
.39271 .5969 Mdot
.459 .74719 Mdot
.43788 .60618 Mdot
.37251 .36823 Mdot
.33188 .51576 Mdot
.36698 .38873 Mdot
.50174 .65324 Mdot
.40392 .21009 Mdot
.33704 .39078 Mdot
.55263 .77331 Mdot
.62399 .47364 Mdot
.49782 .34202 Mdot
.40896 .59921 Mdot
.36528 .62692 Mdot
.49449 .51702 Mdot
.5264 .3314 Mdot
.37942 .58827 Mdot
.65043 .30264 Mdot
.32145 .786 Mdot
.68027 .56302 Mdot
.56423 .65825 Mdot
.52405 .34183 Mdot
.36498 .58329 Mdot
.22622 .38896 Mdot
.56425 .32034 Mdot
.41214 .60468 Mdot
.35706 .37493 Mdot
.38333 .38246 Mdot
.65577 .52349 Mdot
.30654 .36458 Mdot
.39599 .58538 Mdot
.22352 .44731 Mdot
.51584 .35361 Mdot
.57417 .7726 Mdot
.45584 .75013 Mdot
.38076 .61981 Mdot
.62469 .58734 Mdot
.49015 .35076 Mdot
.34315 .56484 Mdot
.68491 .62822 Mdot
.50876 .13446 Mdot
.38538 .5907 Mdot
.50989 .32325 Mdot
.53875 .34529 Mdot
.56051 .46127 Mdot
.48569 .45076 Mdot
.4316 .60314 Mdot
.44792 .81521 Mdot
.54652 .71796 Mdot
.32759 .52331 Mdot
.24881 .54018 Mdot
.66271 .53154 Mdot
.59784 .56569 Mdot
.35398 .3879 Mdot
.62044 .5366 Mdot
.50351 .34267 Mdot
.65284 .55009 Mdot
.38927 .38778 Mdot
.3715 .62001 Mdot
.6211 .50137 Mdot
.48244 .74987 Mdot
.36917 .43134 Mdot
.36578 .41909 Mdot
.39402 .6214 Mdot
.56374 .35431 Mdot
.49437 .68458 Mdot
.40346 .60745 Mdot
.61759 .56567 Mdot
.34018 .54015 Mdot
.59121 .48855 Mdot
.75129 .63231 Mdot
.56735 .33171 Mdot
.41083 .58814 Mdot
.52601 .28892 Mdot
.3668 .39343 Mdot
.3717 .63451 Mdot
.63328 .5414 Mdot
.41365 .60829 Mdot
.27273 .61562 Mdot
.7602 .64612 Mdot
.56513 .36908 Mdot
.26982 .55034 Mdot
.5075 .32672 Mdot
.32562 .52158 Mdot
.71397 .65852 Mdot
.46866 .7374 Mdot
.37351 .60862 Mdot
.81781 .54722 Mdot
.40438 .60148 Mdot
.61442 .53158 Mdot
.59653 .52355 Mdot
.42638 .63253 Mdot
.49476 .72025 Mdot
.29105 .26182 Mdot
.40087 .4717 Mdot
.54161 .36214 Mdot
.73462 .54239 Mdot
.57083 .14303 Mdot
.39927 .378 Mdot
.35084 .38933 Mdot
.65958 .48601 Mdot
.65693 .51739 Mdot
.37738 .42104 Mdot
.39161 .37703 Mdot
.45069 .73373 Mdot
.36645 .59262 Mdot
.57397 .38048 Mdot
.39963 .40098 Mdot
.52637 .53348 Mdot
.50901 .63954 Mdot
.63418 .45994 Mdot
.64112 .59859 Mdot
.57113 .48545 Mdot
.53642 .72386 Mdot
.38819 .40385 Mdot
.58165 .5154 Mdot
.58311 .4646 Mdot
.34836 .37557 Mdot
.45511 .72816 Mdot
.48562 .21122 Mdot
.3894 .60859 Mdot
.55629 .86463 Mdot
.59624 .48936 Mdot
.61368 .52771 Mdot
.33205 .39506 Mdot
.42403 .57492 Mdot
.55961 .32233 Mdot
.5678 .34508 Mdot
.40381 .62911 Mdot
.49201 .55329 Mdot
.63622 .56643 Mdot
.58821 .51077 Mdot
.37724 .59939 Mdot
.33094 .51544 Mdot
.25165 .45335 Mdot
.58369 .53207 Mdot
.36365 .40528 Mdot
.35632 .615 Mdot
.39088 .39885 Mdot
.6112 .48138 Mdot
.61062 .53147 Mdot
.61859 .57302 Mdot
.65633 .51559 Mdot
.35796 .41856 Mdot
.58314 .51919 Mdot
.66677 .56872 Mdot
.55525 .36666 Mdot
.60717 .57007 Mdot
.54278 .72413 Mdot
.61373 .54389 Mdot
.46939 .75088 Mdot
.47029 .63513 Mdot
.64953 .51765 Mdot
.59705 .56862 Mdot
.40401 .47185 Mdot
.63103 .52781 Mdot
.33913 .41296 Mdot
.53295 .33359 Mdot
.35892 .39071 Mdot
.37074 .41618 Mdot
.35218 .57014 Mdot
.45326 .72395 Mdot
.65431 .49235 Mdot
.47429 .75839 Mdot
.6075 .59719 Mdot
.59301 .48476 Mdot
.38314 .65141 Mdot
.19065 .44713 Mdot
.26969 .64073 Mdot
.63293 .54294 Mdot
.39079 .62508 Mdot
.41314 .59332 Mdot
.63671 .64097 Mdot
.56394 .48365 Mdot
.38227 .42059 Mdot
.36189 .37534 Mdot
.67781 .68323 Mdot
.30909 .28878 Mdot
.46166 .74721 Mdot
.48459 .61399 Mdot
.59153 .47188 Mdot
.57558 .52445 Mdot
.61781 .58552 Mdot
.36352 .56433 Mdot
.31666 .52066 Mdot
.36748 .60846 Mdot
.31524 .5272 Mdot
.39132 .39103 Mdot
.64609 .554 Mdot
.79741 .47373 Mdot
.54705 .30677 Mdot
.53322 .33284 Mdot
.38984 .41278 Mdot
.40693 .58135 Mdot
.53335 .50389 Mdot
.22558 .73299 Mdot
.55921 .28269 Mdot
.44907 .7431 Mdot
.59307 .50595 Mdot
.39439 .62348 Mdot
.531 .30174 Mdot
.49867 .72488 Mdot
.57048 .5112 Mdot
.44654 .6474 Mdot
.63199 .5472 Mdot
.61216 .30415 Mdot
.54803 .36744 Mdot
.74844 .74002 Mdot
.56898 .32092 Mdot
.37668 .43122 Mdot
.34191 .38564 Mdot
.60337 .52642 Mdot
.19333 .64804 Mdot
.5016 .35556 Mdot
.3107 .36246 Mdot
.46787 .69744 Mdot
.34399 .54777 Mdot
.47965 .70052 Mdot
.39845 .581 Mdot
.46348 .73008 Mdot
.37219 .58396 Mdot
.66415 .68489 Mdot
.53885 .26959 Mdot
.48013 .74165 Mdot
.4375 .55456 Mdot
.58223 .47352 Mdot
.48656 .75957 Mdot
.6707 .55154 Mdot
.73394 .52338 Mdot
.37977 .60042 Mdot
.49504 .72314 Mdot
.5715 .53297 Mdot
.80215 .37514 Mdot
.34636 .39989 Mdot
.37794 .42245 Mdot
.54927 .50901 Mdot
.36553 .59275 Mdot
.57499 .34428 Mdot
.47531 .40284 Mdot
.30507 .50626 Mdot
.58539 .51358 Mdot
.65465 .54648 Mdot
.53222 .28274 Mdot
.51409 .28255 Mdot
.60559 .53035 Mdot
.66041 .29014 Mdot
.58825 .52845 Mdot
.37061 .3709 Mdot
.55728 .30846 Mdot
.53658 .34091 Mdot
.38923 .58189 Mdot
.54585 .37805 Mdot
.65737 .59504 Mdot
.43978 .38487 Mdot
.67343 .53057 Mdot
.3718 .39639 Mdot
.46661 .42007 Mdot
.32409 .54303 Mdot
.81598 .4564 Mdot
.54492 .28676 Mdot
.57211 .55788 Mdot
.51082 .34137 Mdot
.48332 .71619 Mdot
.54135 .32065 Mdot
.5237 .29982 Mdot
.60514 .51524 Mdot
.63754 .50611 Mdot
.34673 .53743 Mdot
.48634 .45749 Mdot
.5367 .37339 Mdot
.58675 .5182 Mdot
.62221 .57855 Mdot
.56076 .55195 Mdot
.43992 .46784 Mdot
.54219 .29987 Mdot
.67807 .35225 Mdot
.72462 .615 Mdot
.54035 .37388 Mdot
.74071 .27415 Mdot
.34035 .54377 Mdot
.35738 .55513 Mdot
.3742 .35113 Mdot
.58274 .53221 Mdot
.42207 .63598 Mdot
.63041 .50229 Mdot
.63025 .60248 Mdot
.62895 .51544 Mdot
.49369 .708 Mdot
.62773 .46999 Mdot
.33385 .52645 Mdot
.40104 .60299 Mdot
.59268 .49708 Mdot
.62307 .50356 Mdot
.37577 .56057 Mdot
.56187 .30299 Mdot
.56135 .32683 Mdot
.4292 .72751 Mdot
.48208 .72812 Mdot
.34926 .36894 Mdot
.64261 .54738 Mdot
.39401 .62684 Mdot
.3947 .59867 Mdot
.55613 .37794 Mdot
.38937 .60267 Mdot
.332 .38135 Mdot
.63619 .53908 Mdot
.37599 .42227 Mdot
.49631 .7287 Mdot
.51419 .31351 Mdot
.65124 .54035 Mdot
.61096 .55045 Mdot
.53209 .36336 Mdot
.62249 .47285 Mdot
.47397 .70596 Mdot
.39932 .59728 Mdot
.55411 .35353 Mdot
.37413 .38019 Mdot
.38393 .57814 Mdot
.59181 .54547 Mdot
.49941 .13647 Mdot
.61163 .53586 Mdot
.58404 .53827 Mdot
.81976 .60661 Mdot
.64501 .4745 Mdot
.39757 .58939 Mdot
.52487 .28495 Mdot
.55294 .50936 Mdot
.53532 .68103 Mdot
.48432 .8177 Mdot
.35614 .57901 Mdot
.59822 .50001 Mdot
.82262 .46678 Mdot
.59648 .49775 Mdot
.52272 .76843 Mdot
.32425 .71463 Mdot
.54153 .6109 Mdot
.63261 .59897 Mdot
.34529 .40958 Mdot
.34489 .53346 Mdot
.37773 .57966 Mdot
.6074 .39415 Mdot
.598 .51539 Mdot
.60198 .3142 Mdot
.56306 .5162 Mdot
.38326 .38051 Mdot
.72277 .54562 Mdot
.38611 .59373 Mdot
.19861 .41691 Mdot
.61312 .56415 Mdot
.54725 .30066 Mdot
.37393 .57278 Mdot
.33972 .5446 Mdot
.57988 .53859 Mdot
.48344 .75514 Mdot
.32315 .35749 Mdot
.67868 .52041 Mdot
.37581 .39383 Mdot
.5731 .5162 Mdot
.58952 .60034 Mdot
.17432 .5676 Mdot
.552 .36606 Mdot
.35243 .38273 Mdot
.23866 .53243 Mdot
.61889 .47256 Mdot
.55138 .35827 Mdot
.53027 .3262 Mdot
.45639 .74787 Mdot
.4699 .49491 Mdot
.42752 .23572 Mdot
.78511 .4156 Mdot
.69899 .47321 Mdot
.36359 .57802 Mdot
.24494 .49655 Mdot
.6045 .55603 Mdot
.29486 .4125 Mdot
.34828 .41987 Mdot
.61721 .52841 Mdot
.67117 .44634 Mdot
.51831 .31063 Mdot
.5968 .53823 Mdot
.45639 .72539 Mdot
.27841 .38864 Mdot
.2912 .41785 Mdot
.6516 .21511 Mdot
.35516 .58151 Mdot
.58869 .58341 Mdot
.65132 .59402 Mdot
.33148 .50988 Mdot
.57394 .4959 Mdot
.39946 .59258 Mdot
.71468 .70912 Mdot
.49268 .71124 Mdot
.52306 .30431 Mdot
.33979 .54357 Mdot
.56267 .49365 Mdot
.59505 .57453 Mdot
.45638 .75995 Mdot
.57184 .55235 Mdot
.17278 .50731 Mdot
.27812 .50627 Mdot
.41811 .62997 Mdot
.56109 .35483 Mdot
.58813 .4745 Mdot
.31575 .51722 Mdot
.6012 .51824 Mdot
.76475 .4716 Mdot
.57812 .56092 Mdot
.40417 .23842 Mdot
.53338 .36821 Mdot
.37355 .39236 Mdot
.57178 .58504 Mdot
.63505 .51849 Mdot
.38589 .69504 Mdot
.61908 .60257 Mdot
.60692 .48968 Mdot
.57102 .35816 Mdot
.54697 .30423 Mdot
.55106 .32795 Mdot
.42642 .60621 Mdot
.29178 .33234 Mdot
.36232 .40111 Mdot
.66428 .53586 Mdot
.39893 .40401 Mdot
.70099 .59382 Mdot
.45294 .75614 Mdot
.7611 .32487 Mdot
.56361 .54693 Mdot
.54823 .33506 Mdot
.45743 .28704 Mdot
.515 .36324 Mdot
.4313 .65433 Mdot
.37985 .40359 Mdot
.52449 .30781 Mdot
.64113 .52489 Mdot
.47537 .44924 Mdot
.68399 .25182 Mdot
.36032 .38546 Mdot
.64994 .57974 Mdot
.36173 .6167 Mdot
.3103 .54262 Mdot
.56831 .1274 Mdot
.34631 .39078 Mdot
.23462 .51663 Mdot
.59212 .51294 Mdot
.55001 .30928 Mdot
.3371 .40161 Mdot
.3442 .4017 Mdot
.38243 .59866 Mdot
.64162 .50963 Mdot
.64898 .51992 Mdot
.34509 .54563 Mdot
.36431 .3749 Mdot
.54381 .52613 Mdot
.6361 .57976 Mdot
.82866 .56887 Mdot
.58833 .40244 Mdot
.45355 .85603 Mdot
.67508 .59405 Mdot
.69132 .45745 Mdot
.50712 .4532 Mdot
.51335 .30768 Mdot
.64699 .51328 Mdot
.58653 .47795 Mdot
.39237 .58426 Mdot
.62522 .5384 Mdot
.43764 .62258 Mdot
.35121 .39841 Mdot
.73011 .26922 Mdot
.48721 .23435 Mdot
.71025 .70637 Mdot
.6263 .53528 Mdot
.3317 .27097 Mdot
.4896 .72926 Mdot
.3632 .43398 Mdot
.5565 .33826 Mdot
.61649 .4763 Mdot
.4219 .58975 Mdot
.37323 .60995 Mdot
.52997 .31631 Mdot
.21389 .46555 Mdot
.41108 .71263 Mdot
.61177 .48092 Mdot
.43203 .61874 Mdot
.44323 .34309 Mdot
.64929 .27942 Mdot
.4015 .41174 Mdot
.48758 .70258 Mdot
.36825 .61024 Mdot
.39086 .40641 Mdot
.56144 .41127 Mdot
.5232 .31211 Mdot
.51638 .28987 Mdot
.33578 .69562 Mdot
.43267 .60321 Mdot
.48492 .74216 Mdot
.2948 .31817 Mdot
.28963 .31466 Mdot
.49106 .70557 Mdot
.37775 .62909 Mdot
.53883 .30186 Mdot
.54622 .35249 Mdot
.53287 .33491 Mdot
.20644 .40085 Mdot
.56896 .35073 Mdot
.72711 .37816 Mdot
.61554 .57963 Mdot
.53111 .46399 Mdot
.59923 .49819 Mdot
.35753 .42086 Mdot
.54549 .36731 Mdot
.50053 .47228 Mdot
.64782 .49989 Mdot
.67075 .23236 Mdot
.58615 .51059 Mdot
.39842 .42068 Mdot
.58926 .53708 Mdot
.71876 .33726 Mdot
.51187 .30522 Mdot
.6283 .54212 Mdot
.32725 .37068 Mdot
.47467 .72663 Mdot
.56082 .38919 Mdot
.6489 .51751 Mdot
.38122 .29099 Mdot
.65715 .48562 Mdot
.73363 .7002 Mdot
.59961 .75597 Mdot
.44885 .74313 Mdot
.70388 .56248 Mdot
.36182 .58899 Mdot
.58523 .37341 Mdot
.69026 .53545 Mdot
.36183 .38509 Mdot
.47849 .19258 Mdot
.37595 .61698 Mdot
.71498 .52928 Mdot
.59408 .45131 Mdot
.45412 .72281 Mdot
.49471 .35664 Mdot
.33737 .40946 Mdot
.63954 .48402 Mdot
.57253 .56921 Mdot
.723 .69481 Mdot
.68628 .52748 Mdot
.6423 .56509 Mdot
.46722 .76345 Mdot
.68644 .36165 Mdot
.6113 .54597 Mdot
.42505 .6485 Mdot
.51704 .29029 Mdot
.55128 .50498 Mdot
.67673 .3475 Mdot
.58793 .51814 Mdot
.53604 .31039 Mdot
.50772 .29345 Mdot
.43979 .27614 Mdot
.46158 .70157 Mdot
.57746 .56046 Mdot
.62578 .76435 Mdot
.6065 .56557 Mdot
.36772 .40475 Mdot
.61869 .48662 Mdot
.3764 .60885 Mdot
.20144 .42955 Mdot
.42139 .60947 Mdot
.62744 .49561 Mdot
.53231 .33983 Mdot
.34271 .41026 Mdot
.29997 .66436 Mdot
.35761 .72665 Mdot
.72072 .37395 Mdot
.573 .83623 Mdot
.48998 .71385 Mdot
.5032 .73409 Mdot
.33053 .4005 Mdot
.62698 .54368 Mdot
.5863 .78215 Mdot
.67243 .51233 Mdot
.59934 .54123 Mdot
.6281 .51416 Mdot
.30313 .41102 Mdot
.35536 .39395 Mdot
.39543 .60842 Mdot
.60756 .53171 Mdot
.58567 .51967 Mdot
.51476 .34626 Mdot
.47419 .72883 Mdot
.42071 .60493 Mdot
.47838 .73602 Mdot
.41004 .62079 Mdot
.75594 .28768 Mdot
.65766 .56517 Mdot
.47662 .72496 Mdot
.34057 .41721 Mdot
.54761 .31386 Mdot
.31336 .51234 Mdot
.39464 .57961 Mdot
.38221 .59053 Mdot
.58675 .51307 Mdot
.54204 .30989 Mdot
.544 .37681 Mdot
.48514 .71699 Mdot
.33764 .37984 Mdot
.62957 .49866 Mdot
.60231 .48012 Mdot
.60601 .63401 Mdot
.36991 .56823 Mdot
.64003 .28839 Mdot
.42785 .30033 Mdot
.63056 .54414 Mdot
.56246 .36072 Mdot
.6204 .50874 Mdot
.80731 .49481 Mdot
.5628 .32041 Mdot
.64267 .50065 Mdot
.29491 .2908 Mdot
.34745 .55703 Mdot
.396 .2657 Mdot
.61294 .57466 Mdot
.62398 .81864 Mdot
.59792 .55735 Mdot
.83829 .51546 Mdot
.37767 .53778 Mdot
.64591 .55578 Mdot
.60594 .55317 Mdot
.78117 .39467 Mdot
.60105 .50762 Mdot
.32585 .51958 Mdot
.71996 .54345 Mdot
.55087 .29847 Mdot
.50638 .47966 Mdot
.45654 .63041 Mdot
.46519 .69692 Mdot
.40478 .62928 Mdot
.26373 .55685 Mdot
.4615 .71608 Mdot
.52917 .3463 Mdot
.63421 .55456 Mdot
.49842 .57616 Mdot
.3518 .58352 Mdot
.5655 .45994 Mdot
.37181 .40505 Mdot
.27984 .53658 Mdot
.43722 .63028 Mdot
.37392 .38479 Mdot
.55899 .5288 Mdot
.68422 .27275 Mdot
.3031 .70463 Mdot
.75753 .72575 Mdot
.33399 .40188 Mdot
.38127 .3767 Mdot
.23896 .36444 Mdot
.47315 .69446 Mdot
.73554 .64103 Mdot
.36832 .25658 Mdot
.34478 .36511 Mdot
.69242 .69344 Mdot
.36446 .60391 Mdot
.36959 .28739 Mdot
.57778 .31249 Mdot
.60283 .5819 Mdot
.63941 .52331 Mdot
.33997 .37812 Mdot
.54246 .42585 Mdot
.18238 .5877 Mdot
.36644 .38748 Mdot
.63414 .59375 Mdot
.44775 .50304 Mdot
.3342 .5372 Mdot
.35113 .54466 Mdot
.45551 .71077 Mdot
.43649 .73962 Mdot
.51853 .34923 Mdot
.45144 .73289 Mdot
.28854 .42078 Mdot
.56765 .55015 Mdot
.36481 .37949 Mdot
.31475 .52126 Mdot
.37923 .382 Mdot
.45854 .72564 Mdot
.44874 .73689 Mdot
.55616 .36604 Mdot
.55977 .32426 Mdot
.68457 .44874 Mdot
.64751 .71148 Mdot
.59493 .4973 Mdot
.57558 .2242 Mdot
.51832 .35855 Mdot
.69636 .54205 Mdot
.49462 .70683 Mdot
.47801 .7276 Mdot
.61603 .32872 Mdot
.6471 .5464 Mdot
.55734 .79076 Mdot
.64687 .54333 Mdot
.70574 .64972 Mdot
.57657 .49154 Mdot
.38528 .60067 Mdot
.64326 .55466 Mdot
.50219 .69609 Mdot
.66245 .53013 Mdot
.60511 .4886 Mdot
.36587 .59921 Mdot
.67717 .51268 Mdot
.37561 .60767 Mdot
.62875 .49517 Mdot
.50105 .71198 Mdot
.39529 .62724 Mdot
.55795 .67093 Mdot
.42066 .46611 Mdot
.32889 .51688 Mdot
.47162 .75416 Mdot
.46114 .75555 Mdot
.51723 .67124 Mdot
.55643 .34053 Mdot
.52059 .39555 Mdot
.62362 .54307 Mdot
.36654 .58575 Mdot
.35295 .39054 Mdot
.58581 .52217 Mdot
.59388 .47995 Mdot
.63471 .57208 Mdot
.51112 .32429 Mdot
.41493 .5872 Mdot
.47373 .7209 Mdot
.43142 .61616 Mdot
.40661 .69313 Mdot
.43458 .63772 Mdot
.58156 .46777 Mdot
.56249 .57045 Mdot
.75119 .54458 Mdot
.54595 .22372 Mdot
.27214 .29044 Mdot
.52432 .31444 Mdot
.34169 .53268 Mdot
.44954 .73237 Mdot
.71764 .56581 Mdot
.55235 .33819 Mdot
.36932 .59585 Mdot
.63287 .54715 Mdot
.63981 .58704 Mdot
.39603 .35546 Mdot
.59224 .34828 Mdot
.55859 .72311 Mdot
.44027 .62591 Mdot
.3258 .52422 Mdot
.28667 .33352 Mdot
.67769 .46821 Mdot
.49321 .53778 Mdot
.62028 .52004 Mdot
.48636 .75308 Mdot
.53103 .30176 Mdot
.2996 .67921 Mdot
.35344 .37248 Mdot
.48564 .45277 Mdot
.62706 .53595 Mdot
.30165 .33647 Mdot
.53149 .33813 Mdot
.4555 .73461 Mdot
.34114 .37718 Mdot
.45987 .69921 Mdot
.3519 .54507 Mdot
.55488 .81626 Mdot
.59044 .56204 Mdot
.60772 .49113 Mdot
.39208 .42324 Mdot
.51679 .34156 Mdot
.44493 .70984 Mdot
.74783 .66795 Mdot
.42821 .62742 Mdot
.54822 .79283 Mdot
.50644 .35848 Mdot
.74605 .3849 Mdot
.42972 .61248 Mdot
.39041 .41197 Mdot
.50996 .66654 Mdot
.38975 .3892 Mdot
.65308 .52187 Mdot
.54231 .33835 Mdot
.3497 .40204 Mdot
.37258 .68543 Mdot
.82594 .43155 Mdot
.75481 .38526 Mdot
.62646 .56623 Mdot
.75032 .30497 Mdot
.7825 .64847 Mdot
.52172 .40738 Mdot
.37197 .3675 Mdot
.60748 .51989 Mdot
.55944 .51031 Mdot
.61877 .56355 Mdot
.36556 .41221 Mdot
.36095 .65272 Mdot
.37682 .5926 Mdot
.58947 .50503 Mdot
.4525 .74051 Mdot
.38087 .61029 Mdot
.35086 .6082 Mdot
.3904 .58654 Mdot
.53901 .29223 Mdot
.65101 .50856 Mdot
.36692 .31733 Mdot
.84206 .42624 Mdot
.35929 .38949 Mdot
.32924 .51739 Mdot
.58517 .49566 Mdot
.36765 .2358 Mdot
.55078 .32966 Mdot
.42708 .62926 Mdot
.61402 .5272 Mdot
.36648 .66423 Mdot
.39899 .57233 Mdot
.38714 .58699 Mdot
.54994 .35196 Mdot
.50071 .39799 Mdot
.62164 .53814 Mdot
.59392 .55757 Mdot
.52004 .3451 Mdot
.45618 .78558 Mdot
.20857 .42166 Mdot
.62241 .50553 Mdot
.37364 .39074 Mdot
.2995 .78855 Mdot
.59024 .57025 Mdot
.59872 .41748 Mdot
.35148 .55204 Mdot
.40163 .29345 Mdot
.63566 .28355 Mdot
.70752 .55911 Mdot
.78893 .39937 Mdot
.49797 .61457 Mdot
.7386 .27958 Mdot
.43484 .67283 Mdot
.39608 .51491 Mdot
.76682 .30103 Mdot
.32751 .37494 Mdot
.52156 .48179 Mdot
.67049 .6188 Mdot
.20338 .4558 Mdot
.5226 .43136 Mdot
.42422 .77366 Mdot
.37505 .70663 Mdot
.47171 .55969 Mdot
.40937 .60558 Mdot
.69383 .64316 Mdot
.62868 .4996 Mdot
.77824 .65655 Mdot
.67173 .29822 Mdot
.17851 .59447 Mdot
.76194 .31763 Mdot
.63015 .76084 Mdot
.70169 .27218 Mdot
.8192 .48754 Mdot
.75015 .55297 Mdot
.52738 .2367 Mdot
.42771 .82818 Mdot
.28278 .32194 Mdot
.65113 .75772 Mdot
.53844 .51158 Mdot
.48219 .60746 Mdot
.68176 .75357 Mdot
.73574 .4097 Mdot
.20717 .66987 Mdot
.40445 .58953 Mdot
.51491 .2958 Mdot
.65378 .62711 Mdot
.54786 .3911 Mdot
.39138 .43986 Mdot
.7882 .39273 Mdot
.8305 .52553 Mdot
.71255 .33336 Mdot
.6215 .82279 Mdot
.62556 .39847 Mdot
.22681 .3103 Mdot
.41383 .48672 Mdot
.50226 .30833 Mdot
.35722 .77815 Mdot
.29194 .31316 Mdot
.4656 .23375 Mdot
.67155 .60104 Mdot
.34135 .60155 Mdot
.58605 .69323 Mdot
.53674 .34858 Mdot
.63454 .27221 Mdot
.35546 .54387 Mdot
.48226 .21813 Mdot
.47694 .67184 Mdot
.81244 .4352 Mdot
.47557 .54372 Mdot
.36514 .29579 Mdot
.24225 .4799 Mdot
.50216 .13599 Mdot
.65175 .72708 Mdot
.79033 .56323 Mdot
.40967 .38646 Mdot
.52426 .42437 Mdot
.20129 .52345 Mdot
.62025 .71956 Mdot
.29342 .30737 Mdot
.5192 .17174 Mdot
.75485 .70423 Mdot
.56699 .16841 Mdot
.53888 .40042 Mdot
.63534 .57081 Mdot
.78218 .54617 Mdot
.70191 .47959 Mdot
.46421 .77238 Mdot
.62275 .20118 Mdot
.49628 .73675 Mdot
.5425 .39721 Mdot
.21035 .46407 Mdot
.72404 .36024 Mdot
.54811 .78421 Mdot
.454 .69338 Mdot
.62443 .46689 Mdot
.11451 .46961 Mdot
.72997 .27627 Mdot
.43165 .27939 Mdot
.8298 .56725 Mdot
.29751 .35062 Mdot
.58277 .77109 Mdot
.35447 .40548 Mdot
.81352 .36266 Mdot
.54661 .3474 Mdot
.80288 .30943 Mdot
.82513 .40602 Mdot
.22769 .64485 Mdot
.16768 .68554 Mdot
.28999 .45335 Mdot
.54543 .60669 Mdot
.50537 .62181 Mdot
.55297 .69329 Mdot
.18744 .57185 Mdot
.23458 .66951 Mdot
.29385 .35057 Mdot
.63857 .79399 Mdot
.78639 .33217 Mdot
.70385 .67544 Mdot
.58797 .79962 Mdot
.20433 .48388 Mdot
.43266 .46216 Mdot
.48845 .33269 Mdot
.40778 .45326 Mdot
.54299 .24405 Mdot
.60875 .19349 Mdot
.67725 .46168 Mdot
.23361 .74107 Mdot
.48006 .68282 Mdot
.3917 .56096 Mdot
.80666 .59418 Mdot
.56758 .66643 Mdot
.73159 .56184 Mdot
.25551 .3576 Mdot
.59881 .4574 Mdot
.26747 .34388 Mdot
.47057 .31482 Mdot
.26761 .55131 Mdot
.27923 .3351 Mdot
.43153 .34583 Mdot
.73142 .68583 Mdot
.78069 .51048 Mdot
.31151 .27834 Mdot
.55308 .29865 Mdot
.5937 .73103 Mdot
.66836 .71523 Mdot
.82409 .57711 Mdot
.23854 .53165 Mdot
.77644 .71264 Mdot
.23141 .55289 Mdot
.67114 .52996 Mdot
.68009 .56633 Mdot
.53223 .52812 Mdot
.62777 .72719 Mdot
.63033 .57628 Mdot
.29585 .33913 Mdot
.82241 .59479 Mdot
.65667 .43956 Mdot
.28181 .57148 Mdot
.49286 .18942 Mdot
.76132 .71511 Mdot
.76494 .57228 Mdot
.3574 .51591 Mdot
.57283 .43018 Mdot
.29339 .24247 Mdot
.38896 .61561 Mdot
.6982 .68801 Mdot
.37101 .35788 Mdot
.32844 .69785 Mdot
.77309 .39411 Mdot
.22521 .63141 Mdot
.82315 .59781 Mdot
.21605 .41841 Mdot
.26196 .63287 Mdot
.50882 .6845 Mdot
.53625 .78639 Mdot
.52315 .19806 Mdot
.60669 .59272 Mdot
.59333 .61098 Mdot
.47839 .76113 Mdot
.72337 .47199 Mdot
.73126 .61555 Mdot
.365 .75256 Mdot
.6679 .57625 Mdot
.28547 .71533 Mdot
.32241 .52232 Mdot
.48117 .45093 Mdot
.61888 .16128 Mdot
.57233 .46302 Mdot
.29954 .46603 Mdot
.74375 .71295 Mdot
.58424 .75017 Mdot
.80064 .58058 Mdot
.39754 .32708 Mdot
.55729 .17163 Mdot
.83707 .4408 Mdot
.35683 .73464 Mdot
.70102 .24076 Mdot
.82929 .63379 Mdot
.52565 .16274 Mdot
.59281 .26955 Mdot
.32226 .38566 Mdot
.74575 .22032 Mdot
.39268 .63434 Mdot
.44411 .18982 Mdot
.69441 .46903 Mdot
.33183 .64028 Mdot
.57499 .36187 Mdot
.56379 .4501 Mdot
.47463 .55924 Mdot
.58569 .32645 Mdot
.55788 .49519 Mdot
.54641 .14382 Mdot
.47715 .17012 Mdot
.56167 .15393 Mdot
.71038 .75233 Mdot
.71136 .24851 Mdot
.56153 .62592 Mdot
.73767 .39161 Mdot
.66679 .63494 Mdot
.61615 .48392 Mdot
.66692 .66879 Mdot
.28753 .4566 Mdot
.29088 .69005 Mdot
.45062 .23139 Mdot
.56144 .38207 Mdot
.62534 .21563 Mdot
.5033 .10388 Mdot
.63294 .39223 Mdot
.65008 .35257 Mdot
.29028 .40544 Mdot
.65115 .71479 Mdot
.49029 .28364 Mdot
.26315 .67312 Mdot
.81494 .58804 Mdot
.68121 .61557 Mdot
.70185 .69612 Mdot
.38697 .77264 Mdot
.51503 .76824 Mdot
.43582 .57217 Mdot
.81441 .41917 Mdot
.5628 .64036 Mdot
.23166 .6202 Mdot
.50622 .51462 Mdot
.20505 .62207 Mdot
.40327 .73721 Mdot
.27184 .52425 Mdot
.66823 .73087 Mdot
.3156 .54162 Mdot
.69471 .67255 Mdot
.45192 .497 Mdot
.70685 .61174 Mdot
.49817 .6133 Mdot
.69806 .66889 Mdot
.51411 .76681 Mdot
.63394 .19716 Mdot
.82432 .66184 Mdot
.41368 .17143 Mdot
.63769 .81141 Mdot
.46311 .33311 Mdot
.59036 .57529 Mdot
.80675 .63186 Mdot
.60098 .17058 Mdot
.84325 .45881 Mdot
.22799 .41982 Mdot
.36599 .67591 Mdot
.36572 .43273 Mdot
.41444 .17462 Mdot
.43054 .76226 Mdot
.81678 .52477 Mdot
.27704 .28823 Mdot
.37074 .35017 Mdot
.18955 .4575 Mdot
.44525 .1824 Mdot
.7544 .3636 Mdot
.62464 .29478 Mdot
.57171 .4536 Mdot
.69636 .30935 Mdot
.53584 .28554 Mdot
.23654 .48496 Mdot
.62741 .72114 Mdot
.39203 .62042 Mdot
.55048 .64667 Mdot
.62572 .6153 Mdot
.62921 .46979 Mdot
.46143 .61737 Mdot
.54572 .28036 Mdot
.54352 .22537 Mdot
.42575 .35892 Mdot
.73867 .25699 Mdot
.27673 .46955 Mdot
.58887 .60325 Mdot
.6044 .74456 Mdot
.2774 .64097 Mdot
.24663 .36267 Mdot
.34465 .36178 Mdot
.78818 .35285 Mdot
.40089 .44596 Mdot
.59817 .733 Mdot
.6821 .29587 Mdot
.7444 .64839 Mdot
.55914 .5649 Mdot
.44254 .2929 Mdot
.75344 .48135 Mdot
.486 .46405 Mdot
.51881 .3831 Mdot
.51191 .28064 Mdot
.6947 .80649 Mdot
.27773 .4079 Mdot
.26027 .51569 Mdot
.79547 .36579 Mdot
.38308 .40471 Mdot
.52542 .3706 Mdot
.6855 .66052 Mdot
.73254 .69122 Mdot
.74419 .45107 Mdot
.40967 .58021 Mdot
.32939 .58467 Mdot
.38763 .75532 Mdot
.75496 .31503 Mdot
.71956 .2828 Mdot
.17425 .59277 Mdot
.56108 .37836 Mdot
.75598 .62701 Mdot
.70636 .70463 Mdot
.50803 .33819 Mdot
.55911 .396 Mdot
.45778 .21485 Mdot
.68438 .21677 Mdot
.33466 .3207 Mdot
.62141 .81269 Mdot
.53256 .713 Mdot
.37194 .66309 Mdot
.28861 .65545 Mdot
.62327 .77719 Mdot
.79886 .37519 Mdot
.62634 .262 Mdot
.73725 .32973 Mdot
.55986 .58327 Mdot
.59913 .32931 Mdot
.39493 .1776 Mdot
.42649 .48002 Mdot
.74156 .37436 Mdot
.44246 .35996 Mdot
.61539 .56699 Mdot
.50438 .1365 Mdot
.76023 .67346 Mdot
.24634 .34702 Mdot
.31753 .37246 Mdot
.57788 .54269 Mdot
.65231 .56703 Mdot
.56857 .42391 Mdot
.41956 .29117 Mdot
.49401 .17903 Mdot
.62662 .77652 Mdot
.46743 .37236 Mdot
.66669 .29174 Mdot
.29965 .46711 Mdot
.81074 .44449 Mdot
.79211 .62643 Mdot
.47195 .48171 Mdot
.28206 .45768 Mdot
.5007 .66111 Mdot
.65421 .79664 Mdot
.48063 .58813 Mdot
.58437 .62981 Mdot
.384 .23418 Mdot
.40863 .31189 Mdot
.28333 .65799 Mdot
.57714 .50032 Mdot
.21362 .46379 Mdot
.8171 .48363 Mdot
.19218 .66244 Mdot
.1945 .55245 Mdot
.52573 .13211 Mdot
.769 .45876 Mdot
.39879 .31449 Mdot
.70749 .28868 Mdot
.18603 .66605 Mdot
.4768 .60486 Mdot
.66411 .23558 Mdot
.50431 .67339 Mdot
.77681 .34061 Mdot
.33542 .35915 Mdot
.33071 .2955 Mdot
.48739 .18952 Mdot
.69704 .22935 Mdot
.7719 .57498 Mdot
.8023 .40288 Mdot
.50398 .5209 Mdot
.65339 .1935 Mdot
.38839 .22525 Mdot
.47078 .56331 Mdot
.3623 .61574 Mdot
.24829 .38 Mdot
.62444 .23461 Mdot
.50219 .25881 Mdot
.69789 .693 Mdot
.45791 .57065 Mdot
.72347 .5639 Mdot
.71487 .31063 Mdot
.59912 .67019 Mdot
.42078 .32102 Mdot
.60183 .74565 Mdot
.8252 .49329 Mdot
.46241 .59343 Mdot
.2946 .65453 Mdot
.29211 .48493 Mdot
.57157 .81535 Mdot
.42129 .28618 Mdot
.27352 .41172 Mdot
.79113 .55916 Mdot
.42311 .73234 Mdot
.64029 .74998 Mdot
.78619 .74476 Mdot
.6378 .78035 Mdot
.51233 .2246 Mdot
.60222 .19367 Mdot
.80436 .60438 Mdot
.53106 .22565 Mdot
.18113 .55378 Mdot
.59444 .381 Mdot
.66129 .68472 Mdot
.62961 .51495 Mdot
.60696 .1606 Mdot
.59795 .6896 Mdot
.60836 .19076 Mdot
.78854 .66974 Mdot
.69576 .30428 Mdot
.63169 .4696 Mdot
.44411 .63483 Mdot
.36295 .4826 Mdot
.60914 .66588 Mdot
.74713 .33599 Mdot
.5938 .39007 Mdot
.2876 .52289 Mdot
.33243 .50735 Mdot
.44487 .60795 Mdot
.48441 .36398 Mdot
.2676 .4533 Mdot
.42264 .30532 Mdot
.45962 .78037 Mdot
.4838 .51891 Mdot
.66655 .7075 Mdot
.63928 .28482 Mdot
.76061 .37636 Mdot
.21904 .62364 Mdot
.42201 .41892 Mdot
.39837 .58883 Mdot
.78592 .43623 Mdot
.65813 .77172 Mdot
.43606 .33286 Mdot
.5446 .1761 Mdot
.2383 .38137 Mdot
.66511 .64665 Mdot
.72479 .6083 Mdot
.19761 .5986 Mdot
.44859 .82055 Mdot
.58983 .20988 Mdot
.56574 .25143 Mdot
.55969 .78559 Mdot
.62309 .61892 Mdot
.75651 .28933 Mdot
.66228 .74403 Mdot
.73859 .59229 Mdot
.4126 .47418 Mdot
.72584 .42081 Mdot
.68271 .28587 Mdot
.54694 .66604 Mdot
.49505 .51043 Mdot
.23776 .29069 Mdot
.58177 .3454 Mdot
.48476 .1311 Mdot
.36052 .37017 Mdot
.1987 .39609 Mdot
.50322 .7778 Mdot
.45015 .48886 Mdot
.49847 .50446 Mdot
.44565 .2841 Mdot
.40302 .23789 Mdot
.67948 .77148 Mdot
.21633 .65309 Mdot
.42607 .64237 Mdot
.58999 .78618 Mdot
.53691 .82033 Mdot
.78533 .40327 Mdot
.57838 .47709 Mdot
.62788 .79082 Mdot
.42794 .47574 Mdot
.28837 .68614 Mdot
.79593 .64338 Mdot
.46783 .29161 Mdot
.62586 .59811 Mdot
.64619 .71603 Mdot
.66236 .23671 Mdot
.83016 .42863 Mdot
.17458 .49032 Mdot
.46996 .31618 Mdot
.32787 .40082 Mdot
.525 .60905 Mdot
.76281 .33644 Mdot
.56512 .76396 Mdot
.35014 .30138 Mdot
.66108 .72395 Mdot
.38772 .15692 Mdot
.51289 .18003 Mdot
.49298 .1794 Mdot
.59439 .7602 Mdot
.53623 .38596 Mdot
.43576 .20515 Mdot
.72983 .60065 Mdot
.46777 .28179 Mdot
.69629 .7448 Mdot
.68934 .69324 Mdot
.15382 .57025 Mdot
.74233 .54501 Mdot
.41015 .69332 Mdot
.6603 .26727 Mdot
.70913 .47638 Mdot
.31945 .37683 Mdot
.647 .6829 Mdot
.44833 .36403 Mdot
.37873 .43107 Mdot
.42346 .31745 Mdot
.38237 .2871 Mdot
.74165 .58867 Mdot
.74876 .44031 Mdot
.45972 .35799 Mdot
.79216 .47421 Mdot
.58767 .34908 Mdot
.3004 .6788 Mdot
.285 .63813 Mdot
.48923 .41053 Mdot
.4108 .63307 Mdot
.7061 .56232 Mdot
.48508 .47878 Mdot
.48699 .63697 Mdot
.37631 .19877 Mdot
.49477 .74394 Mdot
.54337 .38249 Mdot
.22811 .34962 Mdot
.50627 .33979 Mdot
.57027 .14663 Mdot
.2574 .66218 Mdot
.68217 .29854 Mdot
.36972 .73378 Mdot
.36154 .77117 Mdot
.15577 .41485 Mdot
.57575 .23851 Mdot
.40304 .46703 Mdot
.5624 .26554 Mdot
.56962 .33323 Mdot
.29688 .53025 Mdot
.33527 .51168 Mdot
.6285 .31011 Mdot
.32257 .47215 Mdot
.66465 .6401 Mdot
.4955 .32677 Mdot
.41 .68194 Mdot
.7159 .52808 Mdot
.69963 .22713 Mdot
.40689 .59953 Mdot
.29633 .22927 Mdot
.66461 .56342 Mdot
.76706 .52177 Mdot
.82203 .61312 Mdot
.1799 .47006 Mdot
.25628 .60352 Mdot
.47271 .82171 Mdot
.66613 .51492 Mdot
.46199 .35302 Mdot
.53872 .35192 Mdot
.73064 .63314 Mdot
.46532 .73119 Mdot
.57028 .72763 Mdot
.39859 .40611 Mdot
.23532 .62321 Mdot
.26374 .45942 Mdot
.51415 .37455 Mdot
.47908 .28698 Mdot
.75444 .59512 Mdot
.34665 .27869 Mdot
.42996 .47336 Mdot
.78223 .40103 Mdot
.7428 .43997 Mdot
.49676 .31946 Mdot
.54525 .18548 Mdot
.69608 .71003 Mdot
.81668 .36 Mdot
.52639 .50667 Mdot
.40355 .49588 Mdot
.32993 .27705 Mdot
.43668 .30957 Mdot
.63244 .28766 Mdot
.81642 .58416 Mdot
.60667 .72604 Mdot
.30747 .30456 Mdot
.69508 .66768 Mdot
.62729 .45286 Mdot
.47185 .52184 Mdot
.23233 .4562 Mdot
.14799 .52122 Mdot
.60503 .30726 Mdot
.193 .50209 Mdot
.55616 .25517 Mdot
.29769 .46481 Mdot
.58495 .33444 Mdot
.30567 .63565 Mdot
.73685 .41799 Mdot
.24786 .55932 Mdot
.78288 .31551 Mdot
.81692 .58891 Mdot
.37821 .34856 Mdot
.33213 .57102 Mdot
.51764 .45896 Mdot
.54064 .56428 Mdot
.48927 .43791 Mdot
.65112 .55227 Mdot
.54106 .41031 Mdot
.18682 .44568 Mdot
.45779 .28783 Mdot
.57094 .4486 Mdot
.7475 .28589 Mdot
.82073 .37198 Mdot
.64634 .19294 Mdot
.54499 .79153 Mdot
.51808 .30274 Mdot
.52982 .15787 Mdot
.65561 .32371 Mdot
.82835 .48615 Mdot
.58449 .21361 Mdot
.71902 .78705 Mdot
.74606 .33853 Mdot
.43953 .35928 Mdot
.22999 .65968 Mdot
.40724 .24787 Mdot
.7771 .66603 Mdot
.47002 .56791 Mdot
.28611 .55571 Mdot
.77634 .6728 Mdot
.12478 .4485 Mdot
.58362 .25867 Mdot
.37372 .2921 Mdot
.63003 .62254 Mdot
.47453 .39503 Mdot
.37251 .51342 Mdot
.61644 .48636 Mdot
.34539 .56989 Mdot
.266 .63875 Mdot
.67286 .70488 Mdot
.72357 .5796 Mdot
.37396 .51642 Mdot
.61554 .66324 Mdot
.7093 .64188 Mdot
.6466 .763 Mdot
.76349 .36953 Mdot
.631 .30574 Mdot
.61137 .59794 Mdot
.57428 .38071 Mdot
.46545 .70104 Mdot
.26397 .57254 Mdot
.64098 .50303 Mdot
.25135 .56731 Mdot
.37498 .25676 Mdot
.53067 .13697 Mdot
.29348 .60566 Mdot
.74744 .6809 Mdot
.57364 .30517 Mdot
.42828 .29201 Mdot
.79836 .49227 Mdot
.20576 .45668 Mdot
.39502 .53673 Mdot
.67999 .46355 Mdot
.7398 .28843 Mdot
.27968 .34065 Mdot
.73146 .67315 Mdot
.33918 .23788 Mdot
.36704 .4279 Mdot
.5928 .28701 Mdot
.62077 .62697 Mdot
.22488 .41173 Mdot
.49968 .36472 Mdot
.42339 .34494 Mdot
.42411 .51915 Mdot
.27386 .34664 Mdot
.74509 .71355 Mdot
.75053 .61902 Mdot
.64511 .25626 Mdot
.72501 .28508 Mdot
.35562 .57119 Mdot
.70568 .6933 Mdot
.42277 .34903 Mdot
.40183 .52666 Mdot
.31228 .2831 Mdot
.74123 .2659 Mdot
.49495 .45045 Mdot
.5789 .68749 Mdot
.59681 .56138 Mdot
.6796 .35127 Mdot
.45625 .28078 Mdot
.5142 .73881 Mdot
.26998 .50145 Mdot
.5625 .32287 Mdot
.25577 .48114 Mdot
.43499 .58638 Mdot
.64291 .69258 Mdot
.55037 .2665 Mdot
.6136 .41888 Mdot
.4789 .76983 Mdot
.30235 .51398 Mdot
.54623 .52557 Mdot
.571 .69707 Mdot
.54441 .77868 Mdot
.59234 .28135 Mdot
.56498 .23458 Mdot
.78394 .40984 Mdot
.72448 .70401 Mdot
.44551 .32196 Mdot
.58154 .20966 Mdot
.41347 .23422 Mdot
.75026 .40986 Mdot
.22184 .50889 Mdot
.63073 .574 Mdot
.30787 .63638 Mdot
.52109 .3702 Mdot
.76906 .35473 Mdot
.76563 .466 Mdot
.55926 .67026 Mdot
.45569 .46177 Mdot
.7974 .51001 Mdot
.44478 .44166 Mdot
.81509 .62123 Mdot
.41064 .24682 Mdot
.62568 .72079 Mdot
.37827 .35638 Mdot
.51647 .69716 Mdot
.19401 .58095 Mdot
.8115 .37095 Mdot
.22111 .6332 Mdot
.49986 .57239 Mdot
.19057 .48934 Mdot
.49134 .20885 Mdot
.7847 .66857 Mdot
.64138 .70845 Mdot
.48711 .43632 Mdot
.7123 .52446 Mdot
.40404 .36317 Mdot
.31411 .51213 Mdot
.31915 .6532 Mdot
.63958 .32033 Mdot
.32951 .61174 Mdot
.24646 .58497 Mdot
.54261 .53863 Mdot
.34209 .25133 Mdot
.73043 .28537 Mdot
.73412 .54376 Mdot
.43835 .48941 Mdot
.32458 .70731 Mdot
.62761 .6978 Mdot
.54345 .8741 Mdot
.50256 .13529 Mdot
.59376 .56101 Mdot
.49545 .60832 Mdot
.57993 .71931 Mdot
.43521 .63028 Mdot
.6295 .3369 Mdot
.7829 .39274 Mdot
.37911 .3738 Mdot
.35526 .67292 Mdot
.27177 .35386 Mdot
.45108 .27461 Mdot
.54281 .65294 Mdot
.29705 .39235 Mdot
.54999 .1383 Mdot
.66184 .77456 Mdot
.44605 .30277 Mdot
.6041 .85532 Mdot
.22308 .44919 Mdot
.52201 .27194 Mdot
.78399 .55594 Mdot
.63598 .1969 Mdot
.58919 .75207 Mdot
.33511 .69604 Mdot
.53979 .21229 Mdot
.61785 .72116 Mdot
.71358 .65363 Mdot
.29171 .48455 Mdot
.25984 .48626 Mdot
.4593 .53092 Mdot
.36363 .77187 Mdot
.39788 .20044 Mdot
.64457 .27179 Mdot
.69713 .25895 Mdot
.24754 .62391 Mdot
.15717 .58572 Mdot
.81326 .36191 Mdot
.64896 .67026 Mdot
.36508 .51246 Mdot
.78355 .56958 Mdot
.5451 .71835 Mdot
.66798 .45382 Mdot
.25529 .64953 Mdot
.7368 .45381 Mdot
.33499 .75204 Mdot
.2134 .54341 Mdot
.69585 .67096 Mdot
.69603 .46485 Mdot
.49712 .45724 Mdot
.78 .41498 Mdot
.28213 .50172 Mdot
.61355 .74871 Mdot
.36283 .68528 Mdot
.53648 .6911 Mdot
.78981 .43222 Mdot
.80118 .53026 Mdot
.49458 .43378 Mdot
.13307 .43492 Mdot
.62515 .20775 Mdot
.20806 .47847 Mdot
.61224 .57904 Mdot
.77554 .30183 Mdot
.47715 .41045 Mdot
.57181 .20719 Mdot
.73338 .71193 Mdot
.28485 .6229 Mdot
.34094 .26946 Mdot
.63751 .5702 Mdot
.57353 .22723 Mdot
.7406 .36903 Mdot
.70605 .47144 Mdot
.26972 .64652 Mdot
.60484 .74212 Mdot
.3566 .52754 Mdot
.53605 .66842 Mdot
.53364 .56234 Mdot
.51048 .36348 Mdot
.57543 .15685 Mdot
.51032 .57917 Mdot
.70426 .5393 Mdot
.54116 .45021 Mdot
.21889 .64481 Mdot
.54111 .84892 Mdot
.52891 .53787 Mdot
.28343 .33728 Mdot
.6929 .69553 Mdot
.69256 .6265 Mdot
.57832 .24699 Mdot
.20657 .74593 Mdot
.83004 .59951 Mdot
.574 .33231 Mdot
.60077 .3895 Mdot
.60027 .76688 Mdot
.65828 .2042 Mdot
.38853 .77158 Mdot
.27787 .63378 Mdot
.22833 .69642 Mdot
.5508 .73598 Mdot
.59679 .48005 Mdot
.73662 .72803 Mdot
.81469 .38083 Mdot
.2388 .62058 Mdot
.76205 .2993 Mdot
.62229 .46232 Mdot
.6431 .57826 Mdot
.37924 .86 Mdot
.77683 .3519 Mdot
.60085 .45665 Mdot
.2079 .63381 Mdot
.49007 .34854 Mdot
.6343 .50609 Mdot
.31101 .45637 Mdot
.66024 .74162 Mdot
.71048 .64676 Mdot
.6955 .22815 Mdot
.51704 .37942 Mdot
.25068 .57555 Mdot
.39519 .39643 Mdot
.49718 .50857 Mdot
.63219 .58936 Mdot
.35628 .4104 Mdot
.6752 .64752 Mdot
.49039 .41645 Mdot
.32784 .35527 Mdot
.59307 .79331 Mdot
.76677 .72569 Mdot
.76944 .44178 Mdot
.35768 .34269 Mdot
.60583 .43744 Mdot
.73987 .53567 Mdot
.61297 .66513 Mdot
.62572 .64403 Mdot
.76569 .69354 Mdot
.87709 .5638 Mdot
.29593 .56536 Mdot
.53927 .46986 Mdot
.54318 .26758 Mdot
.63696 .3031 Mdot
.74261 .3497 Mdot
.31719 .40114 Mdot
.34573 .53256 Mdot
.66976 .50642 Mdot
.53209 .5596 Mdot
.40015 .39878 Mdot
.44247 .14541 Mdot
.5964 .48687 Mdot
.60893 .25685 Mdot
.82603 .47201 Mdot
.29764 .67603 Mdot
.76089 .52512 Mdot
.65053 .49396 Mdot
.42087 .21187 Mdot
.47104 .40634 Mdot
.50173 .40259 Mdot
.288 .6496 Mdot
.68681 .23572 Mdot
.76583 .47133 Mdot
.63436 .25325 Mdot
.58335 .5148 Mdot
.49437 .70152 Mdot
.36446 .28647 Mdot
.54431 .20625 Mdot
.5844 .60454 Mdot
.83434 .4639 Mdot
.2883 .62949 Mdot
.33738 .61636 Mdot
.70496 .59855 Mdot
.59504 .17842 Mdot
.20018 .53677 Mdot
.72152 .32872 Mdot
.22984 .37116 Mdot
.25758 .40469 Mdot
.60167 .6716 Mdot
.44471 .63327 Mdot
.56864 .44852 Mdot
.49151 .34768 Mdot
.5799 .13766 Mdot
.53774 .20397 Mdot
.40373 .34803 Mdot
.27884 .53279 Mdot
.70998 .35516 Mdot
.50363 .47462 Mdot
.66527 .83157 Mdot
.42683 .77394 Mdot
.54354 .13586 Mdot
.73308 .62604 Mdot
.47858 .31721 Mdot
.40885 .3251 Mdot
.67012 .57972 Mdot
.38812 .58925 Mdot
.6679 .21422 Mdot
.52507 .54201 Mdot
.22134 .53013 Mdot
.59691 .48158 Mdot
.25423 .33331 Mdot
.44502 .39476 Mdot
.32907 .5611 Mdot
.32468 .54987 Mdot
.18346 .55596 Mdot
.81148 .49079 Mdot
.46497 .40752 Mdot
.64823 .82768 Mdot
.72025 .29753 Mdot
.78983 .35445 Mdot
.421 .58817 Mdot
.1664 .47312 Mdot
.51978 .24559 Mdot
.45359 .35285 Mdot
.42708 .36392 Mdot
.51031 .63206 Mdot
.23831 .38723 Mdot
.69111 .63154 Mdot
.38581 .2685 Mdot
.39263 .35622 Mdot
.91878 .55002 Mdot
.6653 .6634 Mdot
.6605 .60444 Mdot
.21771 .47011 Mdot
.77154 .323 Mdot
.47772 .78609 Mdot
.74592 .73143 Mdot
.48297 .60603 Mdot
.63107 .5868 Mdot
.75238 .45626 Mdot
.73782 .57116 Mdot
.25465 .37335 Mdot
.18524 .35179 Mdot
.67262 .76187 Mdot
.31585 .58006 Mdot
.48225 .50977 Mdot
.50941 .34231 Mdot
.57475 .36102 Mdot
.36364 .74617 Mdot
.70323 .77595 Mdot
.46144 .38359 Mdot
.76498 .33875 Mdot
.15168 .43835 Mdot
.73466 .64598 Mdot
.66621 .20684 Mdot
.50935 .23917 Mdot
.56897 .39069 Mdot
.62224 .66077 Mdot
.4547 .6801 Mdot
.33958 .55225 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0X?ooool2o`000:Oooooo
000Looooo`03o`000?oooooooooo0:3ooooo0_l0002Wooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`2Tooooo`;o00003oooool2o`00017ooooo0_l0001oooooo`007?ooool00ol0003o
ooooooooo`2Jooooo`;o00002?ooool2o`000003ooooool0003o000000cooooo0_l0000Aooooo`;o
0000Ooooool001cooooo00?o0000ooooooooool0V_ooool2o`0000?ooooo1?l00004ooooo`;o0000
X?ooool001cooooo00?o0000ooooooooool0W_ooool5o`0000Kooooo0_l00002ooooo`Co00002?oo
ool2o`0008kooooo000Looooo`03o`000?oooooooooo09kooooo1?l00007ooooo`;o00000_ooool4
o`0000Sooooo1?l0002<ooooo`007?ooool00ol0003oooooooooo`2^ooooo`;o00001_ooool2o`00
00?ooooo0_l0002<ooooo`007?ooool00ol0003oooooooooo`2<ooooo`;o00008?ooool2o`0000Go
oooo0ol0002Aooooo`007?ooool00ol0003oooooooooo`2<ooooo`;o00009oooool2o`0009;ooooo
000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`1jooooo`;o00002_ooool2
o`0002_ooooo0_l00002ooooo`;o0000T?ooool001cooooo00?o0000ooooooooool0N_ooool2o`00
00[ooooo0_l0000Pooooo`;o00002Oooool2o`0000;ooooo0_l0002@ooooo`007?ooool00ol0003o
ooooooooo`2Wooooo`?o00005oooool2o`0000;ooooo0_l00022ooooo`007?ooool00ol0003ooooo
ooooo`2Wooooo`;o00006?ooool2o`0000;ooooo0_l00022ooooo`007?ooool00ol0003ooooooooo
o`28ooooo`;o00000_ooool2o`0000Kooooo0_l0000Nooooo`;o0000Toooool001cooooo00?o0000
ooooooooool0Poooool2o`0000?ooooo0_l00002ooooo`;o00001_ooool2o`000003ooooool0003o
000000cooooo0_l0000:ooooo`;o000000?oooooo`000?l000002Oooool2o`0008Sooooo000Loooo
o`03o`000?oooooooooo08?ooooo0_l0000Booooo`;o00003?ooool2o`0000[ooooo0_l0000<oooo
o`;o0000R?ooool001cooooo00?o0000ooooooooool0OOooool4o`0000;ooooo0_l000000ooooooo
0000o`00000Uooooo`;o00000_ooool3o`0000;ooooo0_l00006ooooo`;o000000?oooooo`000?l0
0000Q_ooool001cooooo00?o0000ooooooooool0L_ooool2o`0000Wooooo1?l00005ooooo`;o0000
3?ooool2o`0000Kooooo0ol00004ooooo`;o00002?ooool2o`0000?ooooo0_l00002ooooo`;o0000
1_ooool5o`0008Kooooo000Looooo`03o`000?oooooooooo06Cooooo0_l0000<ooooo`;o00006Ooo
ool2o`0000?ooooo1?l00006ooooo`?o00001?ooool2o`0001[ooooo0_l00028ooooo`007?ooool0
0ol0003oooooooooo`1Tooooo`;o00002?ooool2o`0000[ooooo0_l0000?ooooo`Co00000oooool2
o`0001Wooooo0_l0002Jooooo`007?ooool00ol0003oooooooooo`1^ooooo`;o00002_ooool2o`00
00oooooo1?l00008ooooo`;o00000_ooool3o`0000oooooo0_l00004ooooo`;o00003Oooool2o`00
08Gooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool0
0ol0003oooooooooo`2=ooooo`;o00002?ooool3o`000004ooooool0003o0000o`0000Kooooo0_l0
000=ooooo`;o00002oooool4o`0000;ooooo0_l00006ooooo`Co0000Moooool00006oooooomgMgOo
V9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03
o`000?oooooooooo09Oooooo0ol0000:ooooo`;o00004Oooool2o`0000Oooooo1?l00002ooooo`;o
00000oooool2o`000003ooooool0003o000000;o00000oooool2o`0007;ooooo00000ooooooo410@
ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003ooooo
ooooo`1gooooo`;o00004_ooool2o`0000[ooooo0_l0000=ooooo`;o00003oooool2o`0000Gooooo
0ol00009ooooo`?o00002?ooool2o`0007;ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oo
oooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0007Cooooo0_l000000ooooooo0000o`00
0005ooooo`;o00000oooool2o`0000Kooooo0ol0000Hooooo`;o00000oooool2o`00017ooooo0ol0
0006ooooo`;o000000?oooooo`000?l00000OOooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo07Cooooo0_l00008
ooooo`?o00000_ooool2o`0000Gooooo1?l00007ooooo`;o00001?ooool2o`0000kooooo0_l0000:
ooooo`;o00003_ooool2o`0000Wooooo1?l0001cooooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0N_ooool2o`00
00?ooooo0_l00006ooooo`;o000000?oooooo`000?l000000_l00007ooooo`;o00001?ooool3o`00
00gooooo1?l00007ooooo`?o00000_ooool2o`0000;ooooo0_l00006ooooo`;o00002Oooool5o`00
07;ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@
4006ooooo`03o`000?oooooooooo07Wooooo0ol00003ooooo`;o00001?ooool4o`0000Oooooo0_l0
0008ooooo`Co000000?oooooo`000?l000002oooool3o`0000Oooooo0_l000000ooooooo0000o`00
0003o`000003ooooool0003o000000Kooooo0_l0000<ooooo`;o0000L_ooool00006ooooooo^k^ko
<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000oooooooo
ool0NOooool2o`0000?ooooo0ol00004ooooo`;o00002Oooool3o`0000;ooooo0_l00003ooooo`Co
000000?oooooo`000?l000002oooool2o`000003ooooool0003o000000Sooooo1Ol000000ooooooo
0000o`00000?ooooo`;o00000oooool2o`0007;ooooo000Looooo`03o`000?oooooooooo07cooooo
1?l0000Aooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000Aooooo`;o0000
2Oooool2o`0000?ooooo0_l00006ooooo`;o00001oooool2o`0000?ooooo0_l00004ooooo`;o0000
4?ooool2o`0005[ooooo000Looooo`03o`000?oooooooooo07cooooo0_l00006ooooo`;o00004ooo
ool2o`0000gooooo0_l00009ooooo`;o00002?ooool2o`0000Sooooo0_l0000Booooo`;o00004?oo
ool3o`0005Wooooo000Looooo`03o`000?oooooooooo08Cooooo0_l0000Eooooo`;o00001_ooool2
o`0000?ooooo0_l00002ooooo`Co00000oooool2o`0000;ooooo0_l00004ooooo`;o0000;oooool2
o`0005Wooooo000Looooo`03o`000?oooooooooo07[ooooo0_l0000;ooooo`;o00004_ooool4o`00
00Cooooo0_l00004ooooo`;o000000?oooooo`000?l000000_l00007ooooo`;o00001?ooool2o`00
023ooooo0_l0000?ooooo`;o0000Eoooool001cooooo00?o0000ooooooooool0GOooool2o`0000oo
oooo0_l0000:ooooo`;o00002oooool2o`0000kooooo0_l00004ooooo`;o00002_ooool2o`0000;o
oooo0ol00007ooooo`;o00008Oooool2o`0000;ooooo0ol0000?ooooo`;o0000Eoooool001cooooo
00?o0000ooooooooool0GOooool2o`0000oooooo0_l00003ooooo`;o00001Oooool2o`0000Cooooo
0_l0000=ooooo`;o00000_ooool2o`0000;ooooo0_l0000Eooooo`;o00001_ooool2o`000003oooo
ool0003o0000013ooooo0_l00009ooooo`;o00000_ooool2o`0000;ooooo0ol0001Xooooo`007?oo
ool00ol0003oooooooooo`1cooooo`?o00000oooool2o`0000Gooooo0_l000000ooooooo0000o`00
0002ooooo`;o00001_ooool2o`0000;ooooo0_l00006ooooo`;o00002oooool2o`0000[ooooo1?l0
00000ooooooo0000o`00000<ooooo`;o00000_ooool2o`0000Kooooo1Ol00003ooooo`;o0000K?oo
ool001cooooo00?o0000ooooooooool0J_ooool2o`0000Kooooo1?l00003ooooo`?o00000oooool6
o`0000;ooooo0_l0000Booooo`;o00001Oooool2o`0000Cooooo0_l0000:ooooo`;o000000?ooooo
o`000?l000003_ooool2o`0000;ooooo0_l00006ooooo`?o00001?ooool3o`0006cooooo000Loooo
o`03o`000?oooooooooo05cooooo0_l0000<ooooo`;o00001_ooool2o`0000Kooooo0_l00003oooo
o`Co00000_ooool2o`0001_ooooo0_l0000Booooo`?o00004_ooool2o`0000gooooo0_l00004oooo
o`;o0000Ioooool001cooooo00?o0000ooooooooool0G?ooool2o`0001Cooooo0_l0000Aooooo`;o
00005?ooool2o`0000Sooooo0_l00004ooooo`Co00001oooool2o`0001Sooooo0_l0000>ooooo`;o
0000Ioooool001cooooo00?o0000ooooooooool0Joooool2o`0000Cooooo0ol000000ooooooo0000
o`00000:ooooo`?o00005oooool2o`0000Sooooo1?l00002ooooo`Co00002Oooool2o`0001Kooooo
0_l000000ooooooo0000o`00000;ooooo`;o000000?oooooo`000?l00000I?ooool001cooooo0_l0
001Nooooo`;o00002?ooool3o`000003ooooool0003o000000Cooooo0ol000000ooooooo0000o`00
0006ooooo`;o00000_ooool3o`0002?ooooo0_l0000;ooooo`;o00000_ooool2o`0000gooooo0_l0
000:ooooo`;o00001Oooool2o`0000Cooooo0_l000000ooooooo0000o`00001Tooooo`007?ooool0
0ol0003oooooooooo`1Mooooo`;o00002?ooool6o`0000?ooooo0_l0000;ooooo`;o00003?ooool2
o`0002Cooooo0_l000000ooooooo0000o`00000Aooooo`;o000000?oooooo`000?l000003_ooool2
o`0000oooooo0_l0001Looooo`007?ooool00ol0003oooooooooo`1Zooooo`;o00001?ooool2o`00
00;ooooo1?l0000Booooo`Go000000?oooooo`000?l000007oooool3o`0000kooooo0_l00006oooo
o`;o00000_ooool2o`0000;ooooo0_l0000Gooooo`?o0000Foooool001cooooo00?o0000oooooooo
ool0M?ooool4o`0001;ooooo0_l000001?oooooo0000o`000?ooool2o`0000Kooooo0_l00005oooo
o`;o00004?ooool3o`0000Kooooo0_l00006ooooo`;o00002_ooool2o`0000;ooooo0ol0000:oooo
o`;o00002oooool2o`0005_ooooo000Looooo`03o`000?oooooooooo05_ooooo0_l00008ooooo`;o
000000?oooooo`000?l00000;_ooool2o`0000Gooooo0_l00005ooooo`;o000000Coooooo`000?l0
003o00001Oooool2o`0000Oooooo0_l0000<ooooo`;o00001?ooool2o`0000?ooooo0_l0000:oooo
o`;o00001oooool2o`0005oooooo000Looooo`03o`000?oooooooooo05Sooooo0_l000000ooooooo
0000o`000002o`0000Gooooo0ol000000ooooooo0000o`00000Cooooo`;o00002Oooool2o`0001co
oooo0_l000001Ooooooo0000o`000?l0003ooooo00Co00000_ooool2o`0001?ooooo0_l00009oooo
o`;o00004oooool2o`0000?ooooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o
00000oooool2o`0000;ooooo1_l00004ooooo`;o00002_ooool2o`000004ooooool0003o0000oooo
o`;o00002Oooool2o`00027ooooo1_l00002ooooo`;o00002?ooool2o`0001Cooooo0_l0000Doooo
o`;o00000_ooool2o`0005[ooooo000Looooo`03o`000?oooooooooo05Gooooo0_l00006ooooo`;o
00000_ooool3o`0000Cooooo1Ol0000:ooooo`;o000000?oooooo`000?l00000:_ooool2o`0000?o
oooo0_l000001?oooooo0000o`000?ooool2o`0000[ooooo0_l0000;ooooo`;o00000_ooool2o`00
00[ooooo0_l00004ooooo`;o00001oooool2o`0005kooooo000Looooo`03o`000?oooooooooo05Go
oooo0_l00002ooooo`;o00003?ooool7o`0000?ooooo0_l00005ooooo`;o00004Oooool2o`0000;o
oooo0ol0000Dooooo`Co00001oooool2o`0000;ooooo0_l00006ooooo`;o00002_ooool3o`0000;o
oooo0_l00004ooooo`;o00001?ooool2o`0000Cooooo0_l00007ooooo`Ko0000F_ooool001cooooo
00?o0000ooooooooool0FOooool2o`0000Kooooo0_l00004ooooo`;o00000oooool3o`000004oooo
ool0003o0000o`0000Gooooo0_l0000>ooooo`Go00000_ooool3o`0000_ooooo0_l00009ooooo`;o
00002oooool2o`0001;ooooo0_l00004ooooo`;o00000oooool2o`0000Oooooo0_l0000:ooooo`Ko
0000F_ooool001cooooo00?o0000ooooooooool0HOooool3o`0000Wooooo0_l000000ooooooo0000
o`00000Fooooo`?o00001Oooool6o`0000Oooooo0_l00004ooooo`;o000000Coooooo`000?l0003o
oooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000000;o00001?ooool2o`00013o
oooo0_l0000<ooooo`;o00001oooool2o`0000Cooooo0_l0001Kooooo`007?ooool00ol0003ooooo
ooooo`1Rooooo`;o00004Oooool3o`0000gooooo0_l00006ooooo`;o000000?oooooo`000?l00000
1?l00006ooooo`;o00001Oooool2o`000003ooooool0003o000000co000000?oooooo`000?l00000
0_l00004ooooo`;o00003?ooool3o`0000cooooo0_l0000:ooooo`Go00001?ooool2o`0005Sooooo
000Looooo`03o`000?oooooooooo05Kooooo0_l00009ooooo`?o00003_ooool8o`0000_ooooo0_l0
0006ooooo`;o00000_ooool2o`0000Gooooo0_l00002ooooo`Co00000oooool2o`0000;ooooo3Ol0
0009ooooo`;o00002Oooool6o`000003ooooool0003o000000Wooooo0_l00005ooooo`?o00001?oo
ool3o`0000;ooooo1?l000000ooooooo0000o`00001Eooooo`007?ooool00ol0003oooooooooo`1:
ooooo`;o00002Oooool3o`0000Cooooo0_l00003ooooo`;o00003oooool8o`0000_ooooo1?l00008
ooooo`;o000000?oooooo`000?l000000_ooool4o`0000;ooooo0_l00004oooooa3o000000?ooooo
o`000?l000001_ooool2o`0000Wooooo1_l000001Ooooooo0000o`000?l0003ooooo00Co00002Ooo
ool4o`0000Wooooo0_l00003ooooo`;o0000EOooool001cooooo00?o0000ooooooooool0B_ooool2
o`0000;ooooo0_l00005ooooo`;o00001Oooool2o`0000Wooooo0ol0000<ooooo`Co000000?ooooo
o`000?l000000_ooool2o`0000Cooooo1Ol00002ooooo`;o00001?ooool4o`0000?ooooo0ol00005
ooooo`Oo00000_ooool:o`000003ooooool0003o000000Kooooo0_l00008ooooo`;o00000_ooool2
o`0000?ooooo0_l000000ooooooo0000o`000002o`0000Wooooo0_l0000Aooooo`;o00003_ooool2
o`0004Cooooo000Looooo`03o`000?oooooooooo04kooooo0_l00004ooooo`;o00004?ooool4o`00
00Wooooo0_l000000ooooooo0000o`000003ooooo`;o00000_ooool2o`0000Oooooo0_l00002oooo
o`;o00001?ooool2o`0000Gooooo0_l00006ooooo`Go000000?oooooo`000?l000002ol00007oooo
o`;o00002_ooool2o`0000;ooooo0_l00002ooooo`;o00001Oooool3o`000003ooooool0003o0000
00[ooooo0_l0000;ooooo`;o00003_ooool2o`0004Cooooo000Looooo`;o0000EOooool2o`000003
ooooool0003o000000gooooo0_l00006ooooo`;o00000oooool2o`0000Kooooo0_l00004ooooo`;o
00001?ooool2o`0001Oooooo4ol00003ooooo`;o00000oooool3o`00017ooooo0_l00002ooooo`;o
000000Goooooo`000?l0003o0000ooooo`02o`0000[ooooo0_l0000<ooooo`?o0000D_ooool001co
oooo00?o0000ooooooooool0Eoooool2o`0000Kooooo0ol0000:ooooo`Co00003oooool4o`000004
ooooool0003o0000ooooo`;o00001?ooool2o`0000Kooooo0_l00008ooooo`?o000000?oooooo`00
0?l000004?l000001?oooooo0000o`000?l00003ooooo`;o00001Oooool3o`0000Gooooo0_l00002
ooooo`;o00000_ooool2o`0000Wooooo0_l0000Cooooo`Co000000?oooooo`000?l00000Coooool0
01cooooo00?o0000ooooooooool0G?ooool2o`000004ooooool0003o0000o`0000[ooooo1Ol00004
ooooo`;o00002?ooool2o`0000?ooooo1?l00005ooooo`;o00001_ooool2o`0000Sooooo0_l00000
0ooooooo0000o`00000=o`000004ooooool0003o0000o`0000;ooooo0_l00008ooooo`Go00000ooo
ool4o`0000;ooooo0_l0000=ooooo`;o00002_ooool2o`0000Cooooo0_l000000ooooooo0000o`00
0003ooooo`;o0000Coooool001cooooo00?o0000ooooooooool0A_ooool3o`0001?ooooo0_l0000@
ooooo`?o00001?ooool2o`0000oooooo0_l00002ooooo`;o00004oooool2o`000003ooooool0003o
0000017o00000_ooool2o`0000Sooooo0_l00005ooooo`?o00001?ooool2o`0000gooooo0ol00003
ooooo`;o00001?ooool2o`0000Cooooo1?l0000=ooooo`;o0000A_ooool001cooooo00?o0000oooo
ooooool0A_ooool3o`0000gooooo0_l00003ooooo`;o000000?oooooo`000?l000004?ooool2o`00
00;ooooo0_l0000;ooooo`;o00001oooool2o`0000;ooooo0_l0000?oooooaKo000000?oooooo`00
0?l000000ol00002ooooo`;o00002Oooool2o`0000Oooooo0_l0000;ooooo`?o00000oooool2o`00
00cooooo0_l0000=ooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0Doooool2o`000003
ooooool0003o000000;ooooo0ol000000ooooooo0000o`00000@ooooo`;o00000_ooool2o`0000So
oooo0_l000000ooooooo0000o`000002ooooo`;o00001oooool2o`0000Gooooo0_l00009oooooaGo
000000?oooooo`000?l000000ol00002ooooo`;o000000?oooooo`000?l000002_ooool2o`0000?o
oooo0_l0000;ooooo`?o00004?ooool2o`0000Oooooo0_l0000<ooooo`;o0000?oooool001cooooo
00?o0000ooooooooool0A?ooool2o`0000gooooo1?l00003ooooo`Co00002?ooool2o`0000_ooooo
0_l00009ooooo`;o00001Oooool3o`0000gooooo0_l000000ooooooo0000o`000003oooooaco0000
1oooool2o`0000[ooooo0_l0000>ooooo`;o00004oooool2o`000003ooooool0003o000000Cooooo
0_l0000<ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0A?ooool2o`0000oooooo0_l0
00001Ooooooo0000o`000?l0003ooooo00Co00001_ooool2o`000003ooooool0003o000000;ooooo
0_l00004ooooo`;o00004?ooool3o`0000Gooooo0_l00009ooooo`;o00000ooooolLo`0000Oooooo
0_l0000:ooooo`;o00002Oooool2o`0000?ooooo1Ol0000Cooooo`;o000000?oooooo`000?l00000
D?ooool001cooooo00?o0000ooooooooool0D_ooool2o`0000Cooooo0ol00003ooooo`;o000000?o
ooooo`000?l000001Oooool3o`0000;ooooo0_l0000Booooo`Ko00001_ooool2o`00013ooooo6_l0
000Cooooo`;o00000oooool2o`0000Cooooo0_l00004ooooo`Co00004_ooool2o`0000;ooooo0_l0
001@ooooo`007?ooool00ol0003oooooooooo`1Aooooo`Co00000oooool2o`0000Kooooo0ol00005
ooooo`;o00000oooool2o`0000gooooo0ol00002ooooo`Co00006?ooool2o`000003ooooool0003o
000000;o000000?oooooo`000?l000004_l000000ooooooo0000o`000003ooooo`;o00000oooool2
o`0000Kooooo0_l00003ooooo`;o00000_ooool2o`0000Cooooo0_l0000:ooooo`;o00000_ooool2
o`0000Kooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00000_ooool4o`00
00Kooooo1?l000000ooooooo0000o`000002ooooo`;o00005_ooool3o`0000oooooo0_l00004oooo
o`?o00001_oooolLo`000004ooooool0003o0000ooooo`Co000000?oooooo`000?l000000_l00006
ooooo`;o00001oooool2o`0000Cooooo0_l00002ooooo`;o00001_ooool2o`000003ooooool0003o
000000;o00003_ooool2o`0004_ooooo000Looooo`03o`000?oooooooooo04gooooo1?l00002oooo
o`;o00000_ooool8o`0000Gooooo0_l00003ooooo`;o00007oooool2o`0000;ooooo0_l00003oooo
o`Co00001?ooool2o`000003ooooool0003o000001co000000?oooooo`000?l000000oooool2o`00
00Wooooo0_l0000@ooooo`;o00000oooool2o`0000Cooooo1?l0000>ooooo`;o00003Oooool2o`00
03cooooo000Looooo`03o`000?oooooooooo04gooooo1?l00002ooooo`?o000000?oooooo`000?l0
00000_l00003ooooo`;o00002Oooool2o`0001cooooo0_l000000ooooooo0000o`000007ooooo`;o
00001_ooool5o`000003ooooool0003o000000;o000000?oooooo`000?l000000ol000000ooooooo
0000o`00000>o`0000Kooooo0_l00005ooooo`;o00000_ooool2o`0000oooooo1?l00002ooooo`Co
00001oooool2o`0000?ooooo0_l0000Eooooo`Ko0000>?ooool001cooooo00?o0000ooooooooool0
D_ooool4o`000004ooooool0003o0000o`0000;ooooo1?l000001?oooooo0000o`000?ooool2o`00
00Oooooo0_l0000Hooooo`;o000000?oooooo`000?l000004OoooolJo`0001;ooooo0_l000000ooo
oooo0000o`000002ooooo`;o00003?ooool4o`0000Cooooo0_l00007ooooo`;o00000oooool3o`00
00;ooooo0_l0000@ooooo`Ko0000>?ooool001cooooo00?o0000ooooooooool0B?ooool2o`0000So
oooo0ol00002ooooo`;o00000oooool2o`0000?ooooo0_l000000ooooooo0000o`000007ooooo`;o
000000?oooooo`000?l000001_ooool2o`0000;ooooo0_l0000<ooooo`Co00002_ooool2o`0000Co
oooo4?l000000ooooooo0000o`000008o`0001?ooooo0_l00002ooooo`;o00002oooool2o`000003
ooooool0003o000000Wooooo0_l00008ooooo`;o00000_ooool2o`0004kooooo000Looooo`03o`00
0?oooooooooo04Sooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000;o0000
2_ooool2o`000003ooooool0003o000000[ooooo0_l00006ooooo`;o00000_ooool2o`0000Sooooo
2_l00008ooooo`;o00000_oooolOo`0001gooooo0_l00003ooooo`;o000000?oooooo`000?l00000
2Oooool2o`0000Gooooo0_l00007ooooo`;o00001?ooool2o`0004Kooooo000Looooo`;o0000Aooo
ool2o`0000Cooooo0_l00002ooooo`?o00000_ooool2o`0000Gooooo0ol00005ooooo`;o00000ooo
ool2o`0000Gooooo1?l000000ooooooo0000o`000002o`0000Gooooo1Ol00003ooooo`Co00001?oo
ool2o`0000_ooooo0ol000001?oooooo0000o`000?oooolEo`0000;ooooo1_l0000Iooooo`;o0000
1?ooool2o`0000gooooo0_l00003ooooo`;o00001oooool2o`0000Cooooo0_l00016ooooo`007?oo
ool00ol0003oooooooooo`0hooooo`;o00003?ooool2o`0000Oooooo1?l00002ooooo`;o00001Ooo
ool3o`0000[ooooo0_l000000ooooooo0000o`000004ooooo`Oo00001Oooool5o`000003ooooool0
003o000000;o00002?ooool4o`0000Oooooo2?l000000ooooooo0000o`000003o`000003ooooool0
003o000000co00000oooool7o`0000gooooo0_l00007ooooo`?o00000oooool2o`0000gooooo0_l0
000:ooooo`;o000000?oooooo`000?l00000Boooool001cooooo00?o0000ooooooooool0>?ooool4
o`0000oooooo0_l000001?oooooo0000o`000?l00004ooooo`;o00004?ooool2o`0000?ooooo1_l0
0002ooooo`Go00000oooool3o`0000Gooooo0_l0000:ooooo`Co00002Oooool6o`000004ooooool0
003o0000oooooa7o00001oooool3o`0000gooooo0_l00007ooooo`Co00001oooool2o`0000;ooooo
0_l0000=ooooo`;o000000Coooooo`000?l0003ooooo0ol0001:ooooo`007?ooool00ol0003ooooo
ooooo`0jooooo`;o00003oooool2o`000004ooooool0003o0000o`00017ooooo5ol00003ooooo`?o
000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00000_ooool3o`0000Cooooo0_l000000ooo
oooo0000o`000006ooooo`Ko000000?oooooo`000?l000005?l0000Jooooo`;o00001?ooool2o`00
00Oooooo0_l00002ooooo`;o00001?ooool2o`0000Oooooo0_l00005ooooo`;o00001?ooool4o`00
00Sooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o000000?oooooo`000?l0
00002?ooool2o`0000;ooooo0_l00002ooooo`Ko000000?oooooo`000?l000003ol00007ooooo`;o
000000?oooooo`000?l000001?l00002ooooo`?o00001?ooool2o`000003ooooool0003o000000Co
oooo0_l000000ooooooo0000o`00000Jo`0001[ooooo0_l00005ooooo`;o00002_ooool2o`0000Co
oooo0_l0000Dooooo`Co00002?ooool2o`0003Sooooo000Looooo`03o`000?oooooooooo04[ooooo
1?l00004ooooo`;o00001Oooool2o`0000;ooooo0_l000001?oooooo0000o`000?l00003oooooa;o
00000oooool2o`0000?ooooo0ol00002ooooo`Co00001Oooool2o`0000Wooooo1?l000000ooooooo
0000o`00000Io`000003ooooool0003o000001oooooo0_l0000:ooooo`;o00002?ooool2o`0000co
oooo0_l00003ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0B_ooool2o`0000Kooooo
0_l000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo
3Ol00002ooooo`Co00001?ooool2o`0000Cooooo0_l00005ooooo`;o00002Oooool3o`0000?ooooo
6_l000000ooooooo0000o`000005ooooo`;o00007Oooool2o`0000_ooooo0_l00002ooooo`;o0000
3?ooool2o`0004Sooooo000Looooo`03o`000?oooooooooo04Oooooo0_l0000<ooooo`;o00001_oo
ool2o`0000Cooooo7?l00008ooooo`;o00002oooool2o`0000[ooooo6Ol00005ooooo`;o000000?o
ooooo`000?l000007Oooool2o`0000_ooooo0_l00005ooooo`;o00003_ooool2o`000003ooooool0
003o0000043ooooo000Looooo`03o`000?oooooooooo04Oooooo1_l00002ooooo`;o00004_oooolL
o`0000Sooooo0ol0000:ooooo`;o00002ooooolDo`0000;ooooo1Ol00002ooooo`;o00001oooool2
o`0001gooooo0_l00005ooooo`;o00001Oooool2o`0000[ooooo0ol000001?oooooo0000o`000?oo
ool2o`0000cooooo0_l0000booooo`007?ooool00ol0003oooooooooo`19ooooo`Co00000_ooool2
o`0000Gooooo0_l0000<oooooaco00002?ooool2o`0000gooooo0_l0000:oooooa?o000000?ooooo
o`000?l000000ol0000;ooooo`;o00007Oooool4o`0000?ooooo0_l00002ooooo`Co00002oooool3
o`0001;ooooo0_l0000booooo`007?ooool00ol0003oooooooooo`1:ooooo`;o000000?oooooo`00
0?l000001oooool2o`0000cooooo7Ol0000Fooooo`;o00002oooool5o`000003ooooool0003o0000
00[o000000?oooooo`000?l000001?ooool2o`0002Wooooo0_l00007ooooo`Co00004?ooool2o`00
00?ooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o000000?oooooo`000?l0
00002_ooool2o`0000cooooo6_l0000:ooooo`;o00001Oooool2o`0000cooooo0_l000000ooooooo
0000o`000003o`0000?ooooo2ol000000ooooooo0000o`000002o`0000;ooooo0_l0000[ooooo`;o
00006Oooool2o`0000?ooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o0000
3Oooool2o`0000[ooooo6_l00002ooooo`;o00002?ooool2o`0000Gooooo0_l0000;ooooo`?o0000
00?oooooo`000?l000000ol00002ooooo`Go000000Coooooo`000?l0003ooooo0_l00002ooooo`Co
00001Oooool2o`0002Sooooo0_l00002ooooo`Go0000E_ooool001cooooo00?o0000ooooooooool0
@Oooool2o`0000;ooooo0ol00002ooooo`;o00002oooool4o`0000Sooooo5Ol000000ooooooo0000
o`000004o`0000;ooooo0_l0000;ooooo`;o00003oooool2o`0000Oooooo1?l00006ooooo`;o0000
00?oooooo`000?l000000_l00004ooooo`Go0000;?ooool5o`0005Kooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003o
ooooooooo`11ooooo`;o00000_ooool3o`0000oooooo1?l00002ooooo`;o00001?oooolMo`0000ko
oooo0_l0000Gooooo`?o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000006ooooo`Ko
00001oooool2o`00023ooooo0_l00009ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o
0000AOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0mooooo`;o00001_ooool2o`0000oooooo0_l000000ooo
oooo0000o`000002ooooo`;o00001OoooolLo`0000gooooo0_l00007ooooo`;o00003Oooool4o`00
00Gooooo0_l00002ooooo`;o00003Oooool3o`0000Kooooo0ol0000Oooooo`;o00002Oooool2o`00
0003ooooool0003o000000;o00001?ooool2o`0004Gooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00Wooooo1Ol00006ooooo`03o`000?oooooooooo03gooooo0_l00004ooooo`Ko
00003Oooool2o`000003ooooool0003o000000?ooooo0_l00008oooooaSo00002oooool4o`0000Ko
oooo0ol00007ooooo`;o00001?ooool2o`0000Gooooo0ol00003ooooo`;o00000_ooool2o`0000[o
oooo0_l00003ooooo`;o00000_ooool2o`0002gooooo1?l00005ooooo`;o0000A?ooool00003oooo
ool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?m4A4CogMgMooooool00007ooooo`?o
0000?oooool2o`0000;ooooo0_l00002ooooo`;o00003_ooool2o`0000Gooooo1?l000000ooooooo
0000o`000002oooooaWo00001oooool2o`0000;ooooo0_l00008ooooo`Co00001_ooool2o`0000[o
oooo1?l00007ooooo`;o00000oooool2o`0000[ooooo0_l0000aooooo`Co00000oooool4o`0004Co
oooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`0oooooo`;o00001Oooool2o`0000Sooooo0_l00005ooooo`;o
00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000002oooooaWo00001oooool2o`0000co
oooo1?l00006ooooo`;o00002_ooool2o`0000[ooooo0_l00002ooooo`;o0000>?ooool2o`0000?o
oooo0ol00004ooooo`;o000000?oooooo`000?l000000_ooool2o`0003oooooo00000ooooooo410@
ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oMgMgolc<c?l000001oooool00ol0003ooooo
ooooo`16ooooo`;o00002?ooool2o`0000Gooooo0_l00002ooooo`;o00002OoooolJo`0001?ooooo
1?l0000?ooooo`;o00003oooool2o`0001Cooooo1?l0000Tooooo`;o00002oooool5o`000003oooo
ool0003o000003oooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l0
00001oooool00ol0003oooooooooo`15ooooo`;o00003_ooool4o`0000?ooooo0_l000000ooooooo
0000o`000004oooooaWo000000?oooooo`000?l000004_ooool2o`0000;ooooo0_l000001?oooooo
0000o`000?l00009ooooo`;o00001?ooool2o`0000Gooooo0_l0000<ooooo`;o00002_ooool4o`00
01[ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00005oooo
o`;o000000?oooooo`000?l00000@_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool0
0omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo02oooooo1?l00007ooooo`;o00001_ooool2
o`000003ooooool0003o000000;o00003?ooool2o`0000Gooooo0_l000001?oooooo0000o`000?oo
ool2o`000004ooooool0003o0000oooooaKo000000?oooooo`000?l000005_ooool2o`000004oooo
ool0003o0000o`0000oooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0ol00008oooo
o`;o0000:?ooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o000000Coooooo`00
0?l0003o00002?ooool2o`0004;ooooo000Looooo`03o`000?oooooooooo02oooooo1?l00007oooo
o`;o000000?oooooo`000?l000000oooool2o`0000?ooooo0_l0000<ooooo`;o00001?ooool2o`00
0003ooooool0003o000000;ooooo0_l00006oooooaCo00002oooool4o`0000_ooooo2?l0000<oooo
o`;o00000_ooool2o`0000Cooooo0ol00002ooooo`Ko0000:oooool2o`000003ooooool0003o0000
00Wooooo0ol0000>ooooo`;o00004?ooool2o`0002[ooooo000Looooo`03o`000?oooooooooo03go
oooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00005ooooo`;o00002oooool3o`000003
ooooool0003o000000_ooooo5Ol00005ooooo`;o00000_ooool4o`0000Oooooo0_l00002ooooo`;o
00000_ooool4o`0001Oooooo0_l00002ooooo`Oo00000_ooool2o`0002;ooooo0_l000001Ooooooo
0000o`000?l0003ooooo00;o00005?ooool2o`0000Cooooo0_l0000@ooooo`;o0000:_ooool001co
oooo00?o0000ooooooooool0?Oooool2o`000003ooooool0003o000000;o00000_ooool2o`0000Go
oooo0_l0000;ooooo`;o00004OoooolCo`000003ooooool0003o000000;ooooo0_l00002ooooo`;o
000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l0000Aooooo`;o00003?ooool2o`0000Wo
oooo0_l00002ooooo`;o00008_ooool2o`000003ooooool0003o000001Sooooo0_l00012ooooo`00
7?ooool00ol0003oooooooooo`12ooooo`?o000000?oooooo`000?l000001Oooool2o`0001_ooooo
0_l00004ooooo`ko00000oooool2o`0000Kooooo0_l000000ooooooo0000o`000002ooooo`;o0000
5Oooool4o`000003ooooool0003o000000Oooooo0_l00003ooooo`;o00002?ooool2o`000004oooo
ool0003o0000o`0002_ooooo0_l0000Gooooo`;o0000>Oooool001cooooo00?o0000ooooooooool0
?_ooool2o`0000?ooooo0_l00008ooooo`;o00006oooool2o`0000Gooooo2Ol0000Hooooo`;o0000
5Oooool2o`000003ooooool0003o000000Sooooo1_l00003ooooo`;o00000oooool2o`000004oooo
ool0003o0000o`0000?ooooo0_l00006ooooo`;o00007_ooool2o`0001?ooooo0_l00002ooooo`;o
0000>Oooool001cooooo00?o0000ooooooooool0;_ooool2o`0000cooooo1_l00009ooooo`Co0000
8oooool7o`0000;ooooo0_l00006ooooo`;o00003Oooool2o`0000Oooooo1?l00007ooooo`;o0000
00?oooooo`000?l000002oooool5o`0000Cooooo1Ol00009ooooo`;o00001_ooool2o`000003oooo
ool0003o000001[ooooo0_l00007ooooo`;o00002Oooool4o`0003gooooo000Looooo`03o`000?oo
oooooooo02Sooooo0_l00004ooooo`;o00003?ooool3o`000003ooooool0003o000000Wooooo1?l0
0006ooooo`;o00002_ooool2o`0000oooooo1ol00002ooooo`;o00001_ooool2o`00013ooooo0_l0
0003ooooo`Go00001oooool2o`0000oooooo0_l00007ooooo`Co00005?ooool3o`0001Wooooo0_l0
0005ooooo`Co00001Oooool2o`0000;ooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0X
ooooo`;o00001?ooool2o`0000_ooooo1?l0000Fooooo`;o00002_ooool2o`00017ooooo0_l00005
ooooo`?o00005Oooool4o`0000?ooooo0ol0000Hooooo`Co00000oooool2o`0000?ooooo0_l0000?
ooooo`;o00001Oooool2o`0000kooooo0_l00002ooooo`Co00000oooool2o`0000Gooooo0_l00007
ooooo`?o0000@_ooool001cooooo00?o0000ooooooooool0;_ooool2o`0000_ooooo1Ol0000doooo
o`;o00001Oooool3o`0000Kooooo0_l00004ooooo`;o000000?oooooo`000?l000001?ooool3o`00
00;ooooo0_l000000ooooooo0000o`00000Hooooo`Co00000oooool2o`0000?ooooo0_l0000?oooo
o`?o00002?ooool2o`0000[ooooo0_l00002ooooo`Co00001Oooool2o`0000gooooo0_l00005oooo
o`;o0000>oooool001cooooo00?o0000ooooooooool0>Oooool9o`0003cooooo0_l00004ooooo`;o
00001?ooool2o`000003ooooool0003o000000?o00001_ooool5o`0000kooooo0_l0000:ooooo`;o
00001oooool2o`0000;ooooo0_l0000=ooooo`;o000000?oooooo`000?l000001Oooool2o`00013o
oooo0_l00005ooooo`;o00003?ooool2o`0000Kooooo0_l0000Cooooo`;o00009_ooool001cooooo
00?o0000ooooooooool09Oooool2o`0001;ooooo1?l00003ooooo`;o00000oooool2o`0003Oooooo
0_l0000?ooooo`?o00001Oooool5o`0000oooooo0_l00008ooooo`?o00002?ooool2o`0000;ooooo
1?l0000<ooooo`Co00000oooool2o`0001;ooooo0_l0000;ooooo`;o00001_ooool2o`0001_ooooo
0_l0000Vooooo`007?ooool2o`0002Kooooo0_l0000Cooooo`Co00001oooool2o`0000Oooooo0_l0
000Aooooo`;o00009_ooool2o`0000cooooo1Ol000001?oooooo0000o`000?ooool2o`0000[ooooo
0_l00005ooooo`Go000000?oooooo`000?l000001_l00004ooooo`?o00000oooool2o`0000Oooooo
0_l00005ooooo`;o00000_ooool2o`0000gooooo0_l0000<ooooo`;o0000Boooool001cooooo00?o
0000ooooooooool0??ooool2o`00013ooooo0_l00003ooooo`;o00001Oooool2o`0000Gooooo0_l0
000Nooooo`;o00001_ooool2o`0000Kooooo0_l00006ooooo`?o000000Coooooo`000?l0003ooooo
0ol00005ooooo`;o00000_ooool2o`0000Gooooo3_l00002ooooo`Co000000Coooooo`000?l0003o
oooo0_l00008ooooo`;o00002?ooool3o`0000[ooooo1?l0000Eooooo`Co0000@?ooool001cooooo
00?o0000ooooooooool0>_ooool2o`0000;ooooo0ol00007ooooo`;o00001?ooool2o`0000?ooooo
0_l00003ooooo`Co00001Oooool2o`0001kooooo0_l00004ooooo`;o00002?ooool2o`0000Oooooo
0_l00002ooooo`;o000000?oooooo`000?l000001Oooool2o`0000[ooooo1_l00005ooooo`;o0000
0_ooool2o`0000?ooooo0_l000001?oooooo0000o`000?l00005ooooo`Co00000oooool2o`000004
ooooool0003o0000ooooo`;o000000?oooooo`000?l000001oooool4o`000003ooooool0003o0000
00?ooooo0_l0000=ooooo`Co0000@?ooool001cooooo00?o0000ooooooooool0>_ooool2o`0000;o
oooo0ol00007ooooo`;o00002?ooool2o`0000Cooooo1?l00005ooooo`;o00002oooool2o`0001Oo
oooo0_l00007ooooo`;o00001Oooool6o`000004ooooool0003o0000o`0000?ooooo0ol0000;oooo
o`Co00000oooool2o`0000Cooooo0_l00002ooooo`;o00001Oooool4o`0000Gooooo1?l000000ooo
oooo0000o`000002o`000004ooooool0003o0000o`0000?ooooo0ol00008ooooo`;o000000?ooooo
o`000?l000000oooool2o`0000[ooooo0_l000000ooooooo0000o`000007ooooo`;o0000>Oooool0
01cooooo00?o0000ooooooooool0:Oooool2o`0001Kooooo0ol0000>ooooo`;o000000?oooooo`00
0?l000001_ooool2o`0000gooooo1?l0000Eooooo`;o00000_ooool2o`0000Gooooo0_l00005oooo
o`Ko000000Goooooo`000?l0003o0000ooooo`05o`0000;ooooo0_l00007ooooo`Ko000000Cooooo
o`000?l0003o00001oooool9o`0000?ooooo0_l00002ooooo`;o00000oooool3o`0000?ooooo0_l0
0004ooooo`;o00006?ooool2o`0000;ooooo0_l00007ooooo`;o000000?oooooo`000?l00000>Ooo
ool001cooooo00?o0000ooooooooool0:Oooool2o`0001Kooooo0ol0000Aooooo`;o00001_ooool5
o`0000[ooooo0_l0000Aooooo`;o00001?ooool2o`0000;ooooo1?l0000;ooooo`Co00000oooool5
o`0000Gooooo0ol0000:ooooo`Ko00001Oooool:o`000003ooooool0003o000000Oo00001?ooool2
o`0000?ooooo0_l0000Eooooo`;o00001oooool2o`0000Oooooo0_l00002ooooo`;o0000??ooool0
01cooooo00?o0000ooooooooool08_ooool2o`0001?ooooo0_l00009ooooo`?o00004Oooool2o`00
00Kooooo1?l0000Mooooo`;o00001?ooool2o`0000Cooooo0_l0000;ooooo`;o00001_ooool2o`00
00;ooooo0_l00004ooooo`?o00001Oooool2o`0000Cooooo1?l00005oooooaCo000000?oooooo`00
0?l000000_l00004ooooo`;o00005Oooool3o`0000oooooo0_l00010ooooo`007?ooool00ol0003o
ooooooooo`0Rooooo`;o00003_ooool2o`0000?ooooo0_l0000:ooooo`;o000000?oooooo`000?l0
00003_ooool2o`0000gooooo0_l0000Dooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`00
00Cooooo0_l0000>ooooo`;o00001Oooool2o`0000?ooooo0_l00005ooooo`;o00000_ooool5o`00
00;ooooo0_l000000ooooooo0000o`000003o`0000;ooooo3Ol00002ooooo`;o000000Goooooo`00
0?l0003o0000ooooo`04o`0000Cooooo0ol000000ooooooo0000o`000003ooooo`;o00003?ooool3
o`0000Oooooo0_l00007ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0<_ooool2o`00
00oooooo0_l000000ooooooo0000o`00000Eooooo`;o00001_ooool2o`0000Wooooo0_l00009oooo
o`;o000000Goooooo`000?l0003o0000ooooo`02o`0000?ooooo0ol0000Dooooo`Co00003Oooool4
o`0000?ooooo2?l00002ooooo`;o000000?oooooo`000?l000001Ol000001?oooooo0000o`000?oo
ool3o`0000[ooooo0_l000001Ooooooo0000o`000?l0003ooooo00?o00000_ooool2o`0000cooooo
0_l00007ooooo`?o00001oooool2o`0003oooooo000Looooo`03o`000?oooooooooo03Kooooo0_l0
0008ooooo`;o00002?ooool3o`00013ooooo0_l0000Aooooo`;o00000_ooool2o`00017ooooo0_l0
000Aooooo`;o00000_ooool5o`0000cooooo0_l00007oooooaSo00002oooool2o`0000?ooooo0_l0
00000ooooooo0000o`00000Iooooo`?o0000B?ooool001cooooo00?o0000ooooooooool0=_ooool2
o`0000Gooooo0_l000000ooooooo0000o`000008ooooo`?o00000_ooool2o`00027ooooo1?l00004
ooooo`;o00001Oooool2o`0000Cooooo0_l00006ooooo`;o00001Oooool2o`0000;ooooo0_l00002
ooooo`;o000000?oooooo`000?l000000oooool2o`0000Kooooo1?l00002ooooo`Go000000?ooooo
o`000?l000004_l00007ooooo`;o00001?ooool2o`0000?ooooo0_l000000ooooooo0000o`00000<
ooooo`;o00000_ooool2o`0002kooooo0_l0000Rooooo`007?ooool00ol0003oooooooooo`0moooo
o`Co00002?ooool3o`0000?ooooo1Ol00007ooooo`;o00000_ooool2o`000003ooooool0003o0000
00kooooo1_l00002ooooo`;o00001Oooool2o`0000Kooooo0_l00004ooooo`;o00001Oooool2o`00
00Kooooo0_l00002ooooo`;o00000_ooool2o`0000Cooooo1_l000000ooooooo0000o`000004o`00
0003ooooool0003o000000Co00000oooool5o`0000?ooooo1?l00003ooooo`;o000000Coooooo`00
0?l0003o00002oooool2o`0000cooooo0_l00002ooooo`;o00003oooool2o`000004ooooool0003o
0000ooooo`;o00005oooool2o`0002;ooooo000Looooo`03o`000?oooooooooo03[ooooo0_l00003
ooooo`;o00001Oooool2o`000004ooooool0003o0000o`0000Gooooo0ol00007ooooo`Ko000000?o
ooooo`000?l000002Oooool2o`0000?ooooo1_l000001?oooooo0000o`000?l00007ooooo`;o0000
0oooool5o`000003ooooool0003o000001;ooooo0ol00007ooooo`;o000000?oooooo`000?l00000
1?l000001?oooooo0000o`000?l00002ooooo`oo000000?oooooo`000?l000000ol00002ooooo`;o
00000_ooool2o`0001Cooooo0ol00009ooooo`;o00003?ooool5o`000003ooooool0003o000003_o
oooo000Looooo`03o`000?oooooooooo03Gooooo0_l00003ooooo`;o00001_ooool2o`0000;ooooo
0_l0000Dooooo`?o00002?ooool2o`0000Cooooo0_l00003ooooo`Co00000oooool2o`0000Sooooo
0_l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Aooooo`Co00001oooool2o`0000;o
oooo1?l00004oooooa?o000000?oooooo`000?l000001Ol0000Iooooo`?o00002Oooool2o`0000Ko
oooo0_l00002ooooo`Go00000oooool2o`0003_ooooo000Looooo`03o`000?oooooooooo03Gooooo
0_l000000ooooooo0000o`000008ooooo`;o00001oooool2o`0000oooooo0_l00009ooooo`;o0000
;?ooool2o`0000[ooooo0ol000000ooooooo0000o`000004ooooo`;o00000_ooool8o`000003oooo
ool0003o000000go000000?oooooo`000?l000002Ol00002ooooo`Co00001?ooool2o`00027ooooo
2ol000000ooooooo0000o`00000Jooooo`;o00007oooool001cooooo00?o0000ooooooooool0:Ooo
ool2o`0000gooooo0_l0000Aooooo`?o00002Oooool2o`0000gooooo0_l0000Gooooo`;o00001ooo
ool2o`0000Gooooo0_l00004ooooo`Co00001Oooool3o`000004ooooool0003o0000ooooo`;o0000
1?ooool2o`0000;ooooo8?l000001?oooooo0000o`000?ooool<o`0002?ooooo0_l00004ooooo`?o
00007Oooool2o`0001oooooo000Looooo`;o0000:_ooool2o`0001Sooooo1?l00005ooooo`;o0000
1_ooool6o`0000cooooo0_l0000Gooooo`;o00001Oooool4o`0000Gooooo0_l00006ooooo`;o0000
1Oooool3o`0000;ooooo0_l00005ooooo`Go000000?oooooo`000?l000008ol00003ooooo`Go0000
1Oooool2o`0001;ooooo0_l00003ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0=?oo
ool2o`0000Gooooo0_l00006ooooo`Co00003Oooool3o`000003ooooool0003o000000Kooooo0_l0
000Kooooo`;o00001oooool2o`0000Kooooo0_l00008ooooo`;o00001?ooool2o`0000?ooooo0ol0
0003ooooob_o00001?ooool2o`0000Sooooo0_l0000Booooo`;o00000oooool2o`0004cooooo000L
ooooo`03o`000?oooooooooo03Cooooo0_l00005ooooo`;o00001_ooool4o`00013ooooo0_l00005
ooooo`co00000oooool2o`0000kooooo0_l0000?ooooo`;o00002?ooool2o`0000Cooooo0_l00003
ooooo`?o000000?oooooo`000?l000000_l000001?oooooo0000o`000?ooool2o`000003ooooool0
003o000001go000000?oooooo`000?l000001?l00004ooooo`;o00000_ooool2o`0006Oooooo000L
ooooo`03o`000?oooooooooo02Wooooo0_l00009ooooo`;o00003Oooool4o`00013ooooo0ol00004
ooooo`?o000000?oooooo`000?l000001_l00003ooooo`;o00002Oooool2o`0001oooooo0_l00002
ooooo`?o00000oooool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000009ol00004
ooooo`;o00000_ooool2o`0001Sooooo0ol00002ooooo`Co00000_ooool2o`0004;ooooo000Loooo
o`03o`000?oooooooooo02Wooooo0_l0000>ooooo`Co00000oooool2o`000004ooooool0003o0000
o`0001;ooooo0_l00004ooooo`?o000000?oooooo`000?l000001ol00008ooooo`Co000000?ooooo
o`000?l000007oooool2o`0000;ooooo0ol00003ooooo`Ko00000_ooool3o`000003ooooool0003o
0000027o000000?oooooo`000?l000001_l00009ooooo`;o00000_ooool2o`000003ooooool0003o
000000[ooooo0_l000001?oooooo0000o`000?l00002ooooo`Co00000_ooool2o`0004;ooooo000L
ooooo`03o`000?oooooooooo03;ooooo0_l00005ooooo`Co00000oooool2o`000003ooooool0003o
000000Cooooo0_l00006ooooo`Go00001?ooool2o`0000;ooooo3Ol00005ooooo`;o000000?ooooo
o`000?l000000ol00005ooooo`;o00007_ooool3o`000003ooooool0003o000000;ooooo0_l00004
ooooo`;o00000oooool]o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o
000000[ooooo0_l0000@ooooo`;o000000?oooooo`000?l00000>oooool001cooooo00?o0000oooo
ooooool0:_ooool2o`0000Kooooo0_l0000Cooooo`Co000000?oooooo`000?l000000oooool5o`00
0003ooooool0003o000000?o00001Oooool;o`0000Cooooo0_l00004ooooo`;o00001Oooool2o`00
00Oooooo0_l0000Aooooo`;o00000_ooool3o`000003ooooool0003o000000Sooooo0ol00002oooo
obgo00000_ooool3o`0000_ooooo0_l0000?ooooo`;o00000oooool4o`0000;ooooo0_l000000ooo
oooo0000o`00000kooooo`007?ooool00ol0003oooooooooo`0Zooooo`Co00004?ooool2o`0000Oo
oooo0_l00003ooooo`;o00002Oooool6o`0000Gooooo2ol0000Iooooo`;o00003?ooool4o`000003
ooooool0003o000000Gooooo0_l00009ooooobWo00000oooool4o`0000Gooooo1?l00007ooooo`Co
00001_ooool2o`0000Oooooo0_l00003ooooo`Co00000_ooool2o`0003kooooo000Looooo`03o`00
0?oooooooooo02cooooo0_l0000<ooooo`;o00000_ooool2o`0000;ooooo0ol00003ooooo`;o0000
1Oooool2o`0000Cooooo0_l00002ooooo`Co00001_ooool:o`0000?ooooo0_l0000Rooooo`Co0000
1Oooool2o`000003ooooool0003o000000_ooooo8Ol000000ooooooo0000o`000006o`0000Wooooo
1_l00005ooooo`?o00001Oooool4o`0000cooooo1?l00002ooooo`?o0000?Oooool001cooooo00?o
0000ooooooooool0>_ooool2o`0000Kooooo2?l00005ooooo`;o00001?ooool2o`0000Sooooo0_l0
0002ooooo`[o00000oooool2o`0000Oooooo0_l00004ooooo`;o00007?ooool2o`0000[ooooo0_l0
00000ooooooo0000o`00000Yo`0000Cooooo0_l00003ooooo`Oo00003?ooool2o`0000kooooo1?l0
0003ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0<oooool2o`0000gooooo1_l00002
ooooo`;o00004Oooool4o`0000;ooooo3?l000000ooooooo0000o`000007ooooo`;o00001?ooool2
o`00013ooooo0_l0000@ooooo`;o00001?ooool2o`000004ooooool0003o0000o`0000;ooooo:?l0
0002ooooo`;o00001oooool3o`0001Gooooo0_l00002ooooo`;o00002_ooool2o`0003_ooooo000L
ooooo`03o`000?oooooooooo03?ooooo0_l00005ooooo`;o00000_ooool2o`0000;ooooo1?l00004
ooooo`;o00002Oooool4o`0000Cooooo0ol000001Ooooooo0000o`000?l0003ooooo00[o00008_oo
ool2o`00013ooooo0_l00002ooooo`;o00001?ooool2o`000003ooooool0003o000000ko000000?o
ooooo`000?l000005_l00003ooooo`;o00001Oooool3o`0000Oooooo0_l0000=ooooo`;o00000_oo
ool2o`0000[ooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o00002oooool2
o`000004ooooool0003o0000o`0000_ooooo0_l00008ooooo`Co00001Oooool6o`0000?ooooo2Ol0
0005ooooo`Co00001?ooool2o`0001gooooo0_l00009ooooo`?o00000_oooolEo`000005ooooool0
003o0000o`000?ooool04_l000001?oooooo0000o`000?ooool2o`0000Cooooo1Ol00006ooooo`;o
00006_ooool2o`000003ooooool0003o000003_ooooo000Looooo`03o`000?oooooooooo02gooooo
0_l0000;ooooo`Go00003?ooool4o`0000Oooooo0ol00005ooooo`Co000000?oooooo`000?l00000
2ol000000ooooooo0000o`000002ooooo`Co00001?ooool3o`000003ooooool0003o000001Wooooo
0_l0000:ooooo`;o00000_oooolao`000004ooooool0003o0000ooooo`?o000000?oooooo`000?l0
00000_ooool2o`0001kooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0iooooo`Go0000
1?ooool2o`0000Oooooo1Ol00006ooooo`;o000000?oooooo`000?l000000oooool2o`000003oooo
ool0003o0000013o00002oooool2o`000003ooooool0003o000001Cooooo0_l00005ooooo`;o0000
1_ooool3o`000003ooooool0003o000000;o00000ooooolUo`0000;ooooo1Ol000000ooooooo0000
o`000003o`0000?ooooo0_l000000ooooooo0000o`000004o`000003ooooool0003o000005Oooooo
000Looooo`03o`000?oooooooooo03Wooooo0_l00007ooooo`;o00001oooool2o`000004ooooool0
003o0000o`0000Sooooo0_l000000ooooooo0000o`000003ooooo`;o00000_ooool=o`0002Gooooo
0_l00005ooooo`;o00001_ooool3o`000003ooooool0003o000000?ooooo0_l00002ooooob7o0000
0_ooool2o`0000;ooooo0_l00002ooooo`?o00001Oooool3o`0000;ooooo1?l000000ooooooo0000
o`000008ooooo`;o00002_ooool2o`0000;ooooo0_l0000mooooo`007?ooool2o`0003kooooo0_l0
000@ooooo`;o00000oooool2o`0000Kooooo0_l00002ooooo`;o00000oooool<o`0002_ooooo0_l0
0005ooooo`;o00002_oooolUo`000004ooooool0003o0000o`0000?ooooo0_l00008ooooo`Co0000
0oooool2o`0000cooooo0_l0000:ooooo`;o000000Coooooo`000?l0003o00006oooool2o`00023o
oooo000Looooo`03o`000?oooooooooo037ooooo1?l00002ooooo`;o00000_ooool4o`0000Kooooo
1?l00007ooooo`;o000000Coooooo`000?l0003o00002_ooool2o`0000?ooooo1?l00002ooooo`Wo
00001?ooool2o`0001Cooooo0_l0000<ooooo`;o00001?ooool3o`0000cooooo9ol00003ooooo`;o
00001_ooool4o`0000Wooooo0_l0000Gooooo`;o00007?ooool2o`00023ooooo000Looooo`03o`00
0?oooooooooo037ooooo1?l00002ooooo`?o000000Coooooo`000?l0003o00001oooool4o`0000Oo
oooo1Ol00004ooooo`;o00003?ooool2o`0000;ooooo2ol00002ooooo`;o00004?ooool2o`0000;o
oooo0_l00009ooooo`;o000000?oooooo`000?l000001?ooool2o`0000gooooo9?l000000ooooooo
0000o`00000;ooooo`;o00002oooool2o`0000Cooooo0_l00003ooooo`;o0000C?ooool001cooooo
00?o0000ooooooooool0>?ooool2o`0001?ooooo0_l00003ooooo`Co00000oooool4o`0000gooooo
3Ol0000Cooooo`;o00002Oooool3o`000004ooooool0003o0000o`0000gooooo0_l000000ooooooo
0000o`000003ooooo`?o000000?oooooo`000?l000003Ol000000ooooooo0000o`000009o`000003
ooooool0003o000000?o00003?ooool2o`0001;ooooo0_l00003ooooo`Co0000B_ooool001cooooo
00?o0000ooooooooool0>?ooool2o`0000[ooooo0_l00007ooooo`;o00001Oooool4o`0000?ooooo
0_l0000:ooooo`;o000000?oooooo`000?l000003?l00003ooooo`;o00006?ooool3o`0000;ooooo
0_l0000=ooooo`Go00001?ooool>o`000003ooooool0003o000001?o00000oooool3o`0000Cooooo
1?l00006ooooo`;o00004Oooool2o`0000;ooooo0_l00004ooooo`;o0000@?ooool001cooooo00?o
0000ooooooooool0:oooool2o`0000_ooooo1?l000000ooooooo0000o`000005ooooo`;o00004?oo
ool2o`0000Cooooo0_l00009ooooo`;o00000_ooool:o`000003ooooool0003o000000?ooooo0_l0
000Hooooo`;o00001?ooool2o`0000Kooooo1?l00003ooooo`Ko00000_ooool4o`0000;ooooo7_l0
0002ooooo`Co00001?ooool4o`000003ooooool0003o000000;o000000?oooooo`000?l000002ooo
ool2o`0000Cooooo0_l00002ooooo`;o00000oooool5o`0000kooooo0_l0000^ooooo`007?ooool0
0ol0003oooooooooo`0[ooooo`;o00002?ooool2o`0000?ooooo0_l000000ooooooo0000o`00000?
ooooo`Co00002_ooool2o`0000?ooooo0_l00008ooooo`ko00003oooool2o`0000_ooooo0_l00004
ooooo`;o00001_ooool4o`0000Gooooo1?l00002ooooo`?o000000Coooooo`000?l0003ooooo5_l0
00000ooooooo0000o`000002o`000004ooooool0003o0000ooooo`?o00000_ooool2o`0000?ooooo
0_l000000ooooooo0000o`000002o`0000kooooo0_l00002ooooo`;o00002Oooool2o`000004oooo
ool0003o0000o`0000gooooo0_l0000^ooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o0000
1Oooool2o`0000;ooooo0_l0000Cooooo`Ko00001?ooool2o`0000Oooooo0_l00005ooooo`;o0000
00?oooooo`000?l000003ol00002ooooo`;o00002?ooool4o`0000Gooooo0_l00002ooooo`;o0000
2?ooool2o`0000Oooooo0_l00008oooooago000000?oooooo`000?l000000oooool2o`0000Cooooo
1Ol00002ooooo`;o00002?ooool2o`0000Oooooo0_l00004ooooo`;o00003?ooool3o`0003gooooo
000Looooo`03o`000?oooooooooo02kooooo0_l00009ooooo`;o00004oooool6o`0000Cooooo0_l0
000>ooooo`;o00000_ooool2o`000003ooooool0003o000000;o00000_ooool7o`000004ooooool0
003o0000o`0000Kooooo0_l00002ooooo`;o00001Oooool2o`0000cooooo0_l00007ooooo`;o0000
2?oooolMo`0000?ooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000000cooooo
0_l00007ooooo`Co0000D?ooool001cooooo00?o0000ooooooooool0BOooool2o`0000?ooooo1?l0
000Mooooo`Go000000?oooooo`000?l000002Ol00006ooooo`;o00000_ooool2o`0001;ooooo0_l0
0007ooooo`;o00002_ooool2o`0000;ooooo1?l000000ooooooo0000o`00000=o`000004ooooool0
003o0000o`0000;ooooo0ol000001?oooooo0000o`000?l00006ooooo`;o00001oooool2o`0000_o
oooo0_l000000ooooooo0000o`000007ooooo`;o000000?oooooo`000?l000000oooool2o`0001Wo
oooo0_l0000Tooooo`007?ooool00ol0003oooooooooo`0kooooo`;o00000_ooool2o`0000Sooooo
0_l0000Eooooo`;o000000?oooooo`000?l000002_ooool6o`000003ooooool0003o000000_o0000
1oooool3o`0000gooooo1_l00002ooooo`;o00000oooool2o`0000Oooooo0_l00003ooooo`;o0000
0_ooool2o`0000;ooooo5ol000001?oooooo0000o`000?l00006ooooo`;o00001oooool2o`0000_o
oooo0_l0000:ooooo`;o000000?oooooo`000?l000000oooool2o`0000Cooooo0_l0000Cooooo`;o
00009?ooool001cooooo00?o0000ooooooooool0>oooool2o`0000;ooooo0_l0000;ooooo`;o0000
4_ooool2o`000003ooooool0003o000000;ooooo0_l00006oooooaGo00001oooool2o`0000gooooo
1?l00004ooooo`Co00002_ooool4o`000003ooooool0003o000000oo000000?oooooo`000?l00000
1Ol000000ooooooo0000o`000002o`0000?ooooo0_l0000?ooooo`;o00004Oooool2o`0000?ooooo
0ol000000ooooooo0000o`000002o`0000Oooooo0_l0000iooooo`007?ooool00ol0003ooooooooo
o`0_ooooo`;o00001oooool2o`0001;ooooo0_l0000Iooooo`Co00001?oooolHo`0000?ooooo0_l0
000<ooooo`;o00002_ooool2o`0000Kooooo0_l00004ooooo`;o000000?oooooo`000?l000002_l0
0003ooooo`Oo000000Coooooo`000?l0003o00000_ooool2o`0000Wooooo0_l00003ooooo`;o0000
00?oooooo`000?l000005?ooool3o`0000;ooooo0_l00002ooooo`Co0000@_ooool001cooooo00?o
0000ooooooooool0;oooool2o`0000Oooooo0_l0000Yooooo`;o00001?ooool2o`0000Kooooo1_l0
00000ooooooo0000o`00000=o`0000?ooooo0_l0000<ooooo`;o00003_ooool2o`0000;ooooo0_l0
0007ooooo`Co00001?ooool2o`0000?ooooo3Ol000000ooooooo0000o`000004ooooo`;o00001?oo
ool2o`0000?ooooo0_l000000ooooooo0000o`000007ooooo`;o00003?ooool2o`0000Sooooo1?l0
0010ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<00Kooooo00?o0000ooooooooool0=Oooool3o`0002_ooooo0_l00002ooooo`;o
00002OoooolFo`0000;ooooo0_l00006ooooo`;o00002Oooool3o`0000Oooooo0ol000000ooooooo
0000o`000008ooooo`Co00000_ooool2o`0000Cooooo0ol00004ooooo`Co00001?ooool2o`0000;o
oooo1Ol00003ooooo`?o000000?oooooo`000?l000002_ooool3o`0001?ooooo0_l00002ooooo`?o
0000@?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMg
MoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo02Cooooo0_l0000?ooooo`?o0000;_ooool3
o`0000Sooooo6?l000000ooooooo0000o`000006ooooo`;o00002?ooool4o`0000Oooooo0_l00002
ooooo`;o00002_ooool6o`0000Cooooo0ol00002ooooo`Ko000000?oooooo`000?l000002_l00004
ooooo`;o000000?oooooo`000?l000002_ooool2o`0000?ooooo0_l00002ooooo`;o00001oooool2
o`0000;ooooo0_l00003ooooo`;o0000@?ooool00003ooooool@413ooooo00;ooooo00?o410@oooo
ooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool09?ooool2
o`0000oooooo0ol00004ooooo`;o00004_ooool2o`0000?ooooo0ol0000>ooooo`;o00000oooool2
o`0000Cooooo5?l000001?oooooo0000o`000?l0000Cooooo`Co00006Oooool5o`0000;ooooo1Ol0
00000ooooooo0000o`000009o`000003ooooool0003o000000;ooooo0_l00009ooooo`;o00001Ooo
ool2o`0000Oooooo0_l00002ooooo`;o00001oooool2o`0000Cooooo0_l000000ooooooo0000o`00
0003o`0003gooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000
oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000=Oooool2o`0000Cooooo0ol0000Aooooo`?o00000ooo
ool3o`0001?ooooo0_l00004oooooa_o000000?oooooo`000?l00000;Oooool2o`0000;ooooo1ol0
00000ooooooo0000o`000004o`0000Kooooo1Ol00008ooooo`;o00001Oooool3o`0001Wooooo0ol0
00000ooooooo0000o`000002o`0003gooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo03_ooooo1?l0
000@ooooo`?o00002_ooool2o`0000gooooo0_l00004oooooa_o000000?oooooo`000?l000002?oo
ool4o`0001Wooooo0_l00004ooooo`Co00000_ooool3o`0000;ooooo0_l00002ooooo`;o00002?oo
ool6o`0000Oooooo0_l00007ooooo`;o00001Oooool2o`0000oooooo0_l000000ooooooo0000o`00
0002o`00047ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEE
ohN7Qoooool02?ooool00ol0003oooooooooo`0mooooo`Co00003_ooool2o`0000Oooooo0_l00002
ooooo`;o00004?ooool2o`000003ooooool0003o000001Ko000000?oooooo`000?l000000ol00007
ooooo`Go00000_ooool2o`0000Sooooo0_l00004ooooo`;o000000?oooooo`000?l000000_ooool2
o`0000Cooooo0ol0000Fooooo`;o00001oooool2o`0000;ooooo0_l00003ooooo`;o000000?ooooo
o`000?l000001_ooool2o`0000oooooo0_l00003ooooo`;o0000@Oooool00006oooooomgMgOoV9RH
oooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo03oooooo0_l0
000Gooooo`;o00000oooool2o`0000Sooooo0_l00005ooooo`?o00000_ooool7o`000003ooooool0
003o000001;o00001oooool2o`000003ooooool0003o000000;ooooo0ol00007ooooo`;o00000ooo
ool3o`000003ooooool0003o000000Sooooo0_l000000ooooooo0000o`00000Jooooo`;o000000?o
ooooo`000?l000001?ooool2o`000004ooooool0003o0000ooooo`;o00003oooool2o`0004kooooo
00001_ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0
003oooooooooo`1Eooooo`;o00001_ooool2o`0000Sooooo0_l00006ooooo`_o000000?oooooo`00
0?l000003Ol00002ooooo`;o00000_ooool2o`0000Sooooo0_l00002ooooo`;o00003?ooool2o`00
00oooooo0_l00008ooooo`;o00004?ooool2o`0000Oooooo0_l00004ooooo`Co00003Oooool2o`00
00Oooooo0_l00003ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0EOooool2o`0001?o
oooo0_l00003oooooaoo00000_ooool4o`0000Kooooo1_l0000Wooooo`;o00003Oooool2o`000003
ooooool0003o000000gooooo1?l00006ooooo`;o00001Oooool3o`0000Cooooo1?l00003ooooo`?o
0000?oooool001cooooo00?o0000ooooooooool0B?ooool4o`0000Cooooo0_l0000Hooooo`;o0000
0oooool<o`000004ooooool0003o0000oooooa3o00000oooool2o`0000Sooooo0_l00002ooooo`;o
00003oooool2o`0001Cooooo0_l0000=ooooo`;o00000_ooool2o`0000;ooooo0_l00008ooooo`;o
00001_ooool4o`0000Kooooo0_l00004ooooo`Co000000Coooooo`000?l0003ooooo0_l0000ooooo
o`007?ooool00ol0003oooooooooo`0mooooo`Co00000_ooool2o`0000?ooooo1?l000001?oooooo
0000o`000?ooool2o`0000Oooooo0_l0000Hooooob3o00002Oooool2o`0000;ooooo0_l0000?oooo
o`?o00005Oooool2o`0000oooooo0_l00002ooooo`;o00002?ooool2o`0000Kooooo0_l0000@oooo
o`;o000000?oooooo`000?l00000@_ooool001cooooo00?o0000ooooooooool0:oooool2o`00013o
oooo1Ol000000ooooooo0000o`000003o`000003ooooool0003o000000;ooooo0_l0000:ooooo`;o
00002_ooool2o`0000Wooooo8ol00009ooooo`;o00005?ooool3o`00017ooooo0_l000000ooooooo
0000o`000006ooooo`;o00000oooool2o`0000;ooooo1Ol00006ooooo`;o00000oooool2o`0000Ko
oooo0_l00009ooooo`;o000000?oooooo`000?l00000Aoooool001cooooo00?o0000ooooooooool0
:oooool2o`0001?ooooo0_l00002ooooo`Co000000?oooooo`000?l000002Oooool2o`0000Cooooo
0_l00006ooooo`;o000000?oooooo`000?l000002?oooolGo`000003ooooool0003o000000[o0000
2Oooool2o`000004ooooool0003o0000o`0000;ooooo0_l00005ooooo`;o00001_ooool2o`0000Go
oooo0_l0000:ooooo`;o00001oooool4o`0000?ooooo0_l00002ooooo`Go00001_ooool2o`0000?o
oooo0_l00006ooooo`;o00002Oooool2o`000004ooooool0003o0000o`0004Kooooo000Looooo`03
o`000?oooooooooo043ooooo0_l00002ooooo`?o00000_ooool2o`0000Kooooo1Ol000001?oooooo
0000o`000?ooool2o`0000Kooooo0_l0000;ooooo`Oo000000?oooooo`000?l000005_l00002oooo
o`;o00003?ooool7o`0000Gooooo0_l0000=ooooo`;o00001Oooool2o`0000cooooo0_l0000<oooo
o`;o00002oooool2o`0000Cooooo0_l0000?ooooo`?o00001_ooool2o`0003gooooo000Looooo`03
o`000?oooooooooo043ooooo0_l00002ooooo`?o00002_ooool3o`0000?ooooo0_l00007ooooo`;o
00003oooool6o`000004ooooool0003o0000oooooaCo00001_ooool2o`0000?ooooo0_l00004oooo
o`Co00002Oooool2o`0001;ooooo0_l0000Booooo`;o00001_ooool2o`0000Sooooo0_l000001?oo
oooo0000o`000?l00003ooooo`;o00000oooool2o`0000_ooooo0_l00006ooooo`;o00002oooool2
o`00033ooooo000Looooo`03o`000?oooooooooo05;ooooo0ol00004ooooo`;o000000?oooooo`00
0?l000000_ooool2o`0000Kooooo0_l00008ooooo`;o000000Coooooo`000?l0003ooooo0_l00000
0ooooooo0000o`00000>o`0000;ooooo0_l00006ooooo`;o00000oooool2o`0000?ooooo1Ol00009
ooooo`;o00001?ooool4o`0001_ooooo1Ol00006ooooo`;o00000_ooool2o`0000Cooooo0_l00002
ooooo`;o00002?ooool4o`0001kooooo0_l0000`ooooo`007?ooool00ol0003oooooooooo`17oooo
o`;o00001?ooool2o`0000?ooooo1_l000001?oooooo0000o`000?ooool2o`0000Kooooo0_l00002
ooooo`;o00002?ooool2o`0000[ooooo3ol0000Booooo`Ko00003_ooool4o`0001Cooooo0_l00005
ooooo`Co00002?ooool2o`000003ooooool0003o000000;o00001_ooool2o`0000[ooooo0_l00006
ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0@oooool2o`000004ooooool0003o0000
o`0000Cooooo0_l00005ooooo`Co00003?ooool2o`0001Sooooo0_l000000ooooooo0000o`000006
o`000004ooooool0003o0000o`0000Wooooo0ol00005ooooo`;o00000oooool2o`0000[ooooo0_l0
000Fooooo`;o00000_ooool2o`0000Oooooo0_l00008ooooo`;o00000oooool2o`0000Kooooo0_l0
0006ooooo`;o00002Oooool3o`0004Sooooo000Looooo`03o`000?oooooooooo03_ooooo0_l00006
ooooo`;o000000?oooooo`000?l000001oooool2o`0000?ooooo0_l00004ooooo`;o00009_ooool2
o`0000;ooooo0ol000000ooooooo0000o`000003o`0000;ooooo1?l000001?oooooo0000o`000?l0
0003ooooo`Co000000?oooooo`000?l000003?ooool2o`0000?ooooo0_l0000@ooooo`?o000000?o
ooooo`000?l000002?ooool2o`0000;ooooo0_l00007ooooo`Co00001_ooool2o`000003ooooool0
003o000000?ooooo0_l00005ooooo`;o00000_ooool3o`0004Sooooo000Looooo`;o0000??ooool2
o`0001;ooooo1?l000000ooooooo0000o`000004ooooo`;o00005_ooool2o`0000Gooooo0_l00006
ooooo`;o00000oooool4o`000003ooooool0003o000000;o000000?oooooo`000?l000000ol00007
ooooo`Co000000?oooooo`000?l000000ol0000>ooooo`;o00004?ooool2o`0000;ooooo0_l0000<
ooooo`;o00001oooool4o`0000Gooooo1_l00002ooooo`;o00001Oooool3o`000003ooooool0003o
000004[ooooo000Looooo`03o`000?oooooooooo04?ooooo0_l000001?oooooo0000o`000?l00008
ooooo`;o000000?oooooo`000?l000001?ooool4o`0000Kooooo0_l00009ooooo`;o000000Cooooo
o`000?l0003ooooo0_l00002ooooo`;o00001_ooool2o`0000Cooooo1?l00005ooooo`Co00002ooo
ool3o`000004ooooool0003o0000o`0000Oooooo0_l00007ooooo`;o00002?ooool2o`00027ooooo
0ol00004ooooo`Co00001?ooool2o`0000Gooooo0_l00002ooooo`;o0000B_ooool001cooooo00?o
0000ooooooooool0>_ooool2o`0000Oooooo0_l000001?oooooo0000o`000?l0000?ooooo`Ko0000
1_ooool2o`0000Wooooo0_l00004ooooo`;o00003Oooool2o`000003ooooool0003o000000;o0000
5?ooool3o`000004ooooool0003o0000o`0000Oooooo0_l00003ooooo`Ko00002?ooool2o`0001Wo
oooo0_l00007ooooo`;o00004oooool2o`0004kooooo000Looooo`03o`000?oooooooooo03[ooooo
0_l0000;ooooo`;o000000?oooooo`000?l000002?ooool2o`0000;ooooo0_l0000Vooooo`;o0000
0_ooool2o`0001Wooooo0ol000000ooooooo0000o`000002o`0000Kooooo0_l00003ooooo`Co0000
4?ooool2o`0000gooooo0_l00004ooooo`;o00001oooool2o`0000kooooo0_l00003ooooo`;o0000
3Oooool2o`0003oooooo000Looooo`03o`000?oooooooooo03_ooooo0_l00003ooooo`;o00001Ooo
ool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`?o00001oooool2o`0001?ooooo1?l0
0009ooooo`;o00001_ooool2o`0001Gooooo0ol000000ooooooo0000o`000002o`0000Kooooo0_l0
000=ooooo`;o00001Oooool5o`0000cooooo0ol00004ooooo`;o00005oooool2o`0001;ooooo0_l0
000oooooo`007?ooool00ol0003oooooooooo`0iooooo`Co00000oooool2o`0000kooooo0_l00003
ooooo`;o00001oooool2o`0001?ooooo1?l00008ooooo`;o00001oooool2o`0001Sooooo1Ol00007
ooooo`;o00001Oooool2o`0000Cooooo0ol00002ooooo`Ko00003_ooool2o`0000Sooooo0_l0000?
ooooo`;o00002?ooool2o`0004kooooo000Looooo`03o`000?oooooooooo03Wooooo0_l00004oooo
o`?o00001_ooool2o`0000_ooooo0_l0000Xooooo`;o00004_ooool2o`0000gooooo1?l00004oooo
o`;o00000_ooool2o`000005ooooool0003o0000o`000?ooool00_l00004ooooo`;o00000_ooool6
o`0000[ooooo0_l00002ooooo`Co00000_ooool2o`0000?ooooo0ol0000>ooooo`;o00000oooool2
o`0000?ooooo1Ol0001;ooooo`007?ooool00ol0003oooooooooo`0oooooo`?o00001_ooool2o`00
00Sooooo0_l00009ooooo`;o00004Oooool2o`0000Wooooo0_l0000=ooooo`;o00001oooool8o`00
00Gooooo0_l00002ooooo`;o00001?ooool2o`0000Gooooo0ol0000;ooooo`Co00003?ooool2o`00
00;ooooo1?l00002ooooo`;o00000oooool3o`0000Wooooo0_l000000ooooooo0000o`000004oooo
o`?o00000_ooool2o`000004ooooool0003o0000o`0004_ooooo000Looooo`03o`000?oooooooooo
05;ooooo0_l00009ooooo`;o00004Oooool2o`000003ooooool0003o000000Kooooo0_l000000ooo
oooo0000o`00000:ooooo`;o00002Oooool6o`0000Gooooo0_l00002ooooo`Co00004_ooool2o`00
00Cooooo0_l0000Looooo`;o000000?oooooo`000?l000001oooool2o`000003ooooool0003o0000
00Cooooo0_l00003ooooo`;o0000Coooool001cooooo00?o0000ooooooooool0E?ooool2o`0000Oo
oooo0ol0000Cooooo`;o00002Oooool2o`00013ooooo0ol00004ooooo`;o00003Oooool2o`0001;o
oooo0_l0000Pooooo`;o00000oooool2o`0000gooooo0_l0001Gooooo`007?ooool00ol0003ooooo
ooooo`1Dooooo`;o00002?ooool2o`00023ooooo0ol00008ooooo`;o00000oooool4o`0000Cooooo
0_l00008ooooo`;o00001_ooool2o`0000[ooooo0_l0000Fooooo`;o00002?ooool2o`0000;ooooo
0_l00006ooooo`;o00000oooool2o`0000?ooooo1?l0000Jooooo`;o0000>oooool001cooooo00?o
0000ooooooooool0<oooool2o`0002Gooooo0_l0000Fooooo`;o000000?oooooo`000?l000002Ooo
ool3o`0000Sooooo0_l000000ooooooo0000o`000002ooooo`;o00001?ooool2o`0000?ooooo1ol0
0006ooooo`;o00002_ooool2o`0001Kooooo0_l00003ooooo`?o00000_ooool2o`0000[ooooo0_l0
0003ooooo`?o00000_ooool3o`0001_ooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0c
ooooo`;o00005_ooool2o`0000[ooooo0_l000000ooooooo0000o`00000Fooooo`Ko00005_ooool2
o`0000Kooooo0_l000000ooooooo0000o`000002ooooo`Oo00005?ooool2o`0000Cooooo0_l0000C
ooooo`Co00002?ooool2o`0000Wooooo0_l0000=ooooo`;o0000C_ooool001cooooo00?o0000oooo
ooooool0Boooool2o`0000[ooooo0_l00002ooooo`Oo00004_ooool4o`0000?ooooo0_l0000Aoooo
o`;o00001Oooool3o`000003ooooool0003o000000oooooo0ol0000;ooooo`;o00001?ooool2o`00
00gooooo0_l00006ooooo`Co00001_ooool2o`0000Wooooo0_l0000=ooooo`;o0000C_ooool001co
oooo00?o0000ooooooooool0Foooool7o`0000Oooooo0_l00009ooooo`;o00001?ooool3o`0000?o
oooo0ol0000=ooooo`;o00000_ooool4o`000003ooooool0003o000000;o00003Oooool3o`0000?o
oooo0_l00009ooooo`Co00001_ooool2o`0000Kooooo0_l00008ooooo`;o00000oooool7o`0000Co
oooo0_l000000ooooooo0000o`000009ooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0
A_ooool3o`0001kooooo1?l00007ooooo`Co00001?ooool2o`0000Cooooo1?l0000<ooooo`;o0000
00?oooooo`000?l000002Ol000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l00000
0_l00005ooooo`;o00001?ooool2o`0000?ooooo1?l00002ooooo`;o00000_ooool5o`0000Sooooo
0_l00006ooooo`[o00000oooool4o`0000Sooooo1?l0001Booooo`007?ooool2o`0004Oooooo0ol0
000>ooooo`;o000000?oooooo`000?l000002oooool4o`0000Oooooo0_l00004ooooo`;o00002?oo
ool2o`0000gooooo4?l00003ooooo`;o000000?oooooo`000?l000000_l0000;ooooo`;o00002?oo
ool3o`0000?ooooo1_l000000ooooooo0000o`000003ooooo`;o00001_ooool3o`0000?ooooo1?l0
0005ooooo`?o00001_ooool3o`0005Cooooo000Looooo`03o`000?oooooooooo05Oooooo0_l00000
0ooooooo0000o`000003ooooo`;o00004Oooool2o`0000Cooooo0_l0000Fooooo`oo00003oooool2
o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000000oooool7o`0000Cooooo0_l0
00001?oooooo0000o`000?ooool2o`0000Cooooo0_l00002ooooo`;o00001_ooool5o`0000Cooooo
1?l00005ooooo`?o0000EOooool001cooooo00?o0000ooooooooool0@Oooool2o`0000Cooooo0_l0
000Fooooo`;o00001Oooool2o`0000cooooo1?l0000Eooooo`Ko000000?oooooo`000?l000002Ol0
000;ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l00000
0oooool4o`000003ooooool0003o000000Cooooo0ol00009ooooo`Ko00001_ooool6o`0000;ooooo
0ol00007ooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0@Oooool2o`0000Cooooo0_l0
000Mooooo`;o00003?ooool4o`0000Cooooo0_l0000?oooooa;o00002oooool3o`0001?ooooo0_l0
0006ooooo`;o00000oooool2o`0000Kooooo0_l00007ooooo`;o00000oooool3o`000003ooooool0
003o000000;ooooo0_l0001Looooo`007?ooool00ol0003oooooooooo`1;ooooo`?o0000;?ooool4
o`0000Cooooo0_l00009oooooaCo00002?ooool4o`0001;ooooo0ol00007ooooo`;o00000_ooool5
o`0000;ooooo0_l00008ooooo`?o00000oooool2o`0000?ooooo1?l000000ooooooo0000o`000002
ooooo`;o00001?ooool2o`0004oooooo000Looooo`03o`000?oooooooooo04_ooooo0ol0000;oooo
o`;o00002oooool2o`0000cooooo1?l00002ooooo`;o00001_ooool2o`0000cooooo4_l00007oooo
o`;o00002_ooool2o`0000Sooooo0_l00008ooooo`;o000000?oooooo`000?l000001?l00002oooo
o`?o00002?ooool2o`0000Sooooo0ol00002ooooo`;o00000_ooool3o`0000?ooooo0_l0001?oooo
o`007?ooool00ol0003oooooooooo`1;ooooo`Co00002_ooool5o`0000Gooooo0_l000000ooooooo
0000o`000002o`0000Wooooo1Ol0000;ooooo`Co00001_oooolEo`0000Oooooo0_l00002ooooo`?o
00000_ooool2o`000003ooooool0003o000000;ooooo0_l0000;ooooo`;o00001?ooool6o`0000?o
oooo0_l00008ooooo`;o00003?ooool2o`0000Cooooo0_l0001Dooooo`007?ooool00ol0003ooooo
ooooo`1;ooooo`Co00002oooool4o`0000Gooooo0_l00003ooooo`;o00001Oooool2o`0000;ooooo
0_l0000>ooooo`Co00001_oooolDo`0000_ooooo1?l00002ooooo`;o00001Oooool2o`0000[ooooo
1Ol00002ooooo`;o00007oooool2o`0000;ooooo0_l0001Fooooo`007?ooool00ol0003ooooooooo
o`1:ooooo`;o00008oooool3o`0001[ooooo5_l00008ooooo`Go00000oooool2o`0000gooooo0_l0
0002ooooo`Go00000_ooool2o`0000Gooooo0_l0000Looooo`?o000000?oooooo`000?l00000D_oo
ool001cooooo00?o0000ooooooooool0B_ooool2o`0002Cooooo0_l0000Fooooo`;o000000?ooooo
o`000?l000005Ol00008ooooo`;o000000?oooooo`000?l000001_ooool2o`0000[ooooo2Ol00006
ooooo`;o000000?oooooo`000?l000005_ooool2o`0000Gooooo1Ol0001Booooo`007?ooool00ol0
003oooooooooo`1:ooooo`;o00001Oooool2o`0003?ooooo1?l000000ooooooo0000o`00000Eo`00
00Cooooo0_l0000=ooooo`;o00001?ooool4o`0000Cooooo1?l000000ooooooo0000o`000006oooo
o`;o00000oooool2o`0000Cooooo0_l0000>ooooo`;o000000?oooooo`000?l000000oooool3o`00
05?ooooo000Looooo`03o`000?oooooooooo04Kooooo0_l00009ooooo`;o00007Oooool2o`0000;o
oooo0_l0000@ooooo`;o00001_ooool<o`0000;ooooo1_l00004ooooo`;o00001oooool2o`0000[o
oooo1_l0000=ooooo`;o00001Oooool2o`0000Cooooo0_l0000Aooooo`;o0000FOooool001cooooo
00?o0000ooooooooool0A_ooool2o`0002Sooooo0_l00002ooooo`;o00002Oooool2o`0000gooooo
3Ol000000ooooooo0000o`000004o`000003ooooool0003o000000Oooooo1Ol00004ooooo`;o0000
2?ooool2o`0000gooooo1_l00007ooooo`;o0000K?ooool001cooooo00?o0000ooooooooool0B?oo
ool2o`0003Gooooo0_l00009oooooaSo000000?oooooo`000?l000001oooool3o`0000Kooooo0_l0
000:ooooo`;o00003Oooool5o`0000Kooooo0_l0000Booooo`;o0000F?ooool001cooooo00?o0000
ooooooooool0Aoooool3o`00043ooooo6?l0000:ooooo`;o000000?oooooo`000?l000004?ooool2
o`0000Wooooo0_l00004ooooo`?o00002Oooool2o`0000kooooo0ol0000;ooooo`;o0000Boooool0
01cooooo00?o0000ooooooooool0?oooool2o`0000Kooooo0_l0000Yooooo`;o00004?ooool2o`00
00Sooooo4_l0000>ooooo`?o00002Oooool2o`0000Cooooo0ol00009ooooo`;o00001?ooool3o`00
00Wooooo0_l0000>ooooo`;o00003?ooool2o`0004_ooooo000Looooo`;o0000@?ooool2o`00037o
oooo0_l0000@ooooo`;o00002OoooolAo`0000kooooo0_l0000:ooooo`;o000000Coooooo`000?l0
003ooooo0_l00002ooooo`;o00000_ooool2o`000004ooooool0003o0000o`0001Kooooo0_l00005
ooooo`;o0000G?ooool001cooooo00?o0000ooooooooool0COooool2o`0001Gooooo0_l00003oooo
o`;o00002?ooool2o`0001Sooooo0_l000000ooooooo0000o`00000>o`0000kooooo0_l0000:oooo
o`Go00001Oooool6o`000004ooooool0003o0000o`0000Sooooo0_l00002ooooo`;o00001oooool3
o`0000;ooooo1Ol0001Looooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00005Oooool2o`00
00?ooooo0_l00008ooooo`;o00001Oooool2o`00017ooooo4ol0000;ooooo`;o00002Oooool2o`00
00Cooooo0_l000000ooooooo0000o`000005ooooo`;o00002oooool2o`000003ooooool0003o0000
00;ooooo0_l00005ooooo`Co000000?oooooo`000?l000000ol0001Nooooo`007?ooool00ol0003o
ooooooooo`1jooooo`;o00001Oooool2o`0000cooooo4?l0000<ooooo`;o00002Oooool2o`0000Co
oooo1Ol0000?ooooo`Ko00002oooool2o`0000?ooooo0_l0001Qooooo`007?ooool00ol0003ooooo
ooooo`1Cooooo`;o0000;?ooool2o`0000Gooooo0_l00005ooooo`go00008?ooool3o`0000[ooooo
0_l00003ooooo`So000000?oooooo`000?l000003Oooool2o`00067ooooo000Looooo`03o`000?oo
oooooooo05?ooooo0_l0000cooooo`;o00001Oooool;o`0000Wooooo0_l00009ooooo`;o00001?oo
ool2o`00017ooooo1?l000000ooooooo0000o`000002o`0000Oooooo0_l0000=ooooo`;o0000HOoo
ool001cooooo00?o0000ooooooooool0N?ooool2o`0001Cooooo0_l00002ooooo`Wo00000_ooool2
o`0000Cooooo1Ol00005ooooo`?o00001?ooool2o`0000Wooooo0ol00005ooooo`;o00000oooool2
o`0001Kooooo0_l0001Sooooo`007?ooool00ol0003oooooooooo`1booooo`;o00001?ooool4o`00
01;ooooo0_l00002ooooo`?o00000oooool3o`0000;ooooo0_l00005ooooo`Co00001Oooool2o`00
00Gooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000?o00004?ooool2o`00
00Gooooo1?l00007ooooo`;o0000Hoooool001cooooo00?o0000ooooooooool0L_ooool2o`0000Ko
oooo0_l0000:ooooo`?o00002?ooool4o`0000Cooooo0_l0000;ooooo`;o00002?ooool2o`0000;o
oooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000001?ooooo0ol00004ooooo`Co
00001?ooool2o`0006Kooooo000Looooo`03o`000?oooooooooo073ooooo0_l0000Dooooo`?o0000
2?ooool2o`0000gooooo0_l0000;ooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo
0ol0000:ooooo`Go00001oooool2o`0000Cooooo0_l00006ooooo`;o0000I_ooool001cooooo00?o
0000ooooooooool0L?ooool2o`00023ooooo0_l0000<ooooo`;o00000_ooool2o`0000Oooooo0_l0
0007ooooo`;o00000_ooool3o`0000[ooooo1_l0001looooo`007?ooool00ol0003oooooooooo`1I
ooooo`;o00001?ooool2o`0000Gooooo0_l00009ooooo`;o00000oooool2o`0001[ooooo0_l0000@
ooooo`;o00002?ooool2o`0000_ooooo0ol0000=ooooo`?o00000oooool2o`0007Kooooo000Loooo
o`03o`000?oooooooooo05Wooooo0_l00004ooooo`;o00001?ooool3o`0000Wooooo0_l00003oooo
o`;o00006?ooool2o`0000Gooooo0_l0000Aooooo`;o00000_ooool2o`0000;ooooo0_l00007oooo
o`?o00003_ooool2o`0000?ooooo0_l0000Cooooo`;o0000HOooool001cooooo00?o0000oooooooo
ool0G_ooool2o`0000Gooooo0_l0000Yooooo`;o00001Oooool2o`0000Kooooo0_l00009ooooo`;o
00001Oooool3o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`00000:ooooo`;o
00007?ooool2o`0000;ooooo0_l0001Mooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5oooo
o`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0G_ooool2
o`0003kooooo0ol0000<ooooo`?o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00002
ooooo`;o00002Oooool2o`000004ooooool0003o0000o`0001cooooo0_l0001Mooooo`0000Kooooo
ogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Ko
oooo00?o0000ooooooooool0TOooool2o`0000Sooooo0_l000001?oooooo0000o`000?l0000<oooo
o`?o00002Oooool2o`0000;ooooo0_l00006ooooo`;o00001?ooool3o`0000?ooooo0_l00005oooo
o`;o0000Koooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool0S_ooool2o`000003ooooool0003o0000
00Sooooo0_l0000Dooooo`;o00002?ooool2o`0000Gooooo0_l000000ooooooo0000o`00000:oooo
o`;o00001Oooool3o`0006kooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wo
oooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000S_ooool2o`0001Gooooo0_l00008oooo
o`Co00002?ooool2o`0000Gooooo0_l0000Eooooo`;o0000K_ooool00003ooooool0003ooooo00;o
oooo00?o0000ooooooooool02Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000oooo
ooooool0YOooool2o`0000Sooooo1?l0000[ooooo`;o0000JOooool00003ooooool@413ooooo00;o
oooo00?o410@ooooooooool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000oooo
ooooool0T_ooool2o`0000Wooooo0_l0000Booooo`;o0000:oooool2o`0006Wooooo00001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oo
oooooooo07?ooooo0_l0000Mooooo`;o00002Oooool2o`0002Cooooo0_l000000ooooooo0000o`00
0003ooooo`;o00001Oooool2o`0007Gooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo
00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo07?ooooo0_l0000Iooooo`;o
00000oooool2o`0000Sooooo0_l0000Gooooo`;o00002oooool2o`000003ooooool0003o000000?o
oooo0_l00005ooooo`;o0000MOooool001cooooo00?o0000ooooooooool0S_ooool3o`0000;ooooo
0ol00004ooooo`;o00005?ooool2o`0000Cooooo0_l0000;ooooo`;o000000Coooooo`000?l0003o
0000P?ooool001cooooo00?o0000ooooooooool0M_ooool2o`0001Kooooo0ol00003ooooo`Co0000
0_ooool2o`0000oooooo0_l00003ooooo`;o00000oooool2o`0000_ooooo0ol000001?oooooo0000
o`000?l00020ooooo`007?ooool00ol0003oooooooooo`1fooooo`;o00005_ooool2o`0000Cooooo
1?l0000Cooooo`;o00002?ooool2o`0000_ooooo0_l00002ooooo`;o0000POooool001cooooo00?o
0000ooooooooool0Qoooool2o`0002gooooo1?l00009ooooo`;o000000?oooooo`000?l000001ooo
ool2o`0007Sooooo000Looooo`03o`000?oooooooooo07Wooooo0_l0000<ooooo`;o00003_ooool2
o`0001gooooo1?l00009ooooo`;o00002_ooool2o`0007Sooooo000Looooo`03o`000?oooooooooo
07Wooooo0_l0000Looooo`;o00007_ooool2o`0000Oooooo0_l0000Booooo`;o0000Loooool001co
oooo00?o0000ooooooooool0Ooooool2o`0003Gooooo0ol00007ooooo`;o00004_ooool2o`0007?o
oooo000Looooo`03o`000?oooooooooo07oooooo0_l00002ooooo`;o0000<Oooool2o`00097ooooo
000Looooo`03o`000?oooooooooo08?ooooo0_l0000^ooooo`;o0000U?ooool001cooooo00?o0000
ooooooooool0/oooool2o`0009Cooooo000Looooo`03o`000?oooooooooo08?ooooo0_l0000Woooo
o`;o0000Voooool001cooooo0_l00024ooooo`;o00001oooool2o`0001kooooo0_l0002Kooooo`00
7?ooool00ol0003oooooooooo`2<ooooo`;o00000_ooool2o`0002kooooo0_l00027ooooo`007?oo
ool00ol0003oooooooooo`2@ooooo`;o0000;_ooool2o`0008Oooooo000Looooo`03o`000?oooooo
oooo07Oooooo0_l0000booooo`;o0000W?ooool001cooooo00?o0000ooooooooool0Moooool2o`00
03;ooooo0_l00004ooooo`;o0000U_ooool001cooooo00?o0000ooooooooool0/Oooool2o`0009Ko
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0[Ooo
ool2o`0009[ooooo000Looooo`03o`000?oooooooooo0:gooooo0_l0002Jooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo09kooooo0_l0002Yooooo`00
7?ooool00ol0003oooooooooo`2Nooooo`;o0000ZOooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?oooooo
Boooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001;ooooo1?l000000ol@413oooooooooo`03ooooo`03o`00
0?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo0ol0003ooooood[ooooo000Doooo
o`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`00
5?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_oo
ool001;ooooo00?oEEEEofIVI_l00000oooooomDooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00YOooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo01Gooooo
00Co410@o`000?m4A4Coc<c<1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo0_l000000ol@
413oooooooooo`2>ooooo`00Y_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l0000;oooo
o`03oiRHV?l@413ogMgM00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2?oooo
o`00Y_ooool01Ol0003ooooooooooooooooo000001_ooooo00?oQhN7oeEEEOooool01oooool00ol0
003oooooooooo`05o`00093ooooo002Vooooo`05o`000?ooooooooooooooool000002Oooool6o`00
00Wooooo00Goc<c<ob4Q8Ol0003oEEEEo`000007ooooo`08ogMgMolb<S;ooooooooooom4A4CogMgM
ooooool0002Aooooo`00Y_ooool01Ol0003oQhN7oooooonYZJWo000001Sooooo00Go8B4QohN7Qooo
ooooV9RHo`000004ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01?oMgMgoEEEEooooool0
002Aooooo`00YOooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo01Kooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Gooooo00?oMgMgolc<c?l00000TOoo
ool00<?ooooo00Go8B4QoiRHV?ooooooMgMgoeEEE@04ooooo`03o`000?oooooooooo00Gooooo00?o
k^k^odA4A?l00000TOooool00<?ooooo00Goc<c<oa0@4?l0003o<S8bonk^kP04ooooo`Co00001Ooo
ool00omgMgOo0000ooooo`2@ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(960) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.54383 .31859 Mdot
.57594 .34724 Mdot
.38999 .57108 Mdot
.5885 .57209 Mdot
.53134 .28001 Mdot
.37717 .60244 Mdot
.39753 .35599 Mdot
.35894 .38293 Mdot
.37779 .58814 Mdot
.50086 .55264 Mdot
.36723 .36206 Mdot
.61775 .6115 Mdot
.38193 .38296 Mdot
.59252 .55801 Mdot
.73991 .75176 Mdot
.54613 .50855 Mdot
.59275 .34979 Mdot
.46933 .70752 Mdot
.62011 .60197 Mdot
.39414 .56568 Mdot
.60118 .30991 Mdot
.59875 .56832 Mdot
.54177 .32727 Mdot
.593 .55788 Mdot
.56919 .55295 Mdot
.56392 .32534 Mdot
.5548 .29245 Mdot
.57279 .57347 Mdot
.57385 .51331 Mdot
.38071 .39921 Mdot
.55458 .75833 Mdot
.80959 .64559 Mdot
.53751 .55523 Mdot
.49087 .17922 Mdot
.35344 .37122 Mdot
.78316 .5428 Mdot
.34962 .57309 Mdot
.39826 .39045 Mdot
.35649 .37584 Mdot
.36464 .40147 Mdot
.38267 .39184 Mdot
.56378 .3327 Mdot
.35085 .32195 Mdot
.32376 .35583 Mdot
.65302 .54222 Mdot
.45634 .30366 Mdot
.70022 .66559 Mdot
.62416 .52469 Mdot
.59017 .33752 Mdot
.40096 .57446 Mdot
.46866 .19299 Mdot
.40211 .40174 Mdot
.33407 .47721 Mdot
.85965 .35712 Mdot
.40423 .38154 Mdot
.65488 .55903 Mdot
.36247 .57154 Mdot
.61256 .56655 Mdot
.5983 .55874 Mdot
.70905 .50669 Mdot
.55473 .54524 Mdot
.44972 .7125 Mdot
.59411 .37357 Mdot
.43068 .62713 Mdot
.37069 .59244 Mdot
.35923 .37721 Mdot
.58151 .36286 Mdot
.38683 .37848 Mdot
.66683 .56357 Mdot
.37244 .61831 Mdot
.62477 .52582 Mdot
.36443 .37931 Mdot
.53822 .37382 Mdot
.63427 .54112 Mdot
.22759 .38938 Mdot
.59508 .83076 Mdot
.42203 .69745 Mdot
.72539 .50277 Mdot
.73794 .56182 Mdot
.3744 .73127 Mdot
.58062 .52211 Mdot
.30161 .76297 Mdot
.69634 .77741 Mdot
.54987 .31419 Mdot
.5616 .47595 Mdot
.37947 .63634 Mdot
.63574 .54934 Mdot
.49527 .40779 Mdot
.65812 .53042 Mdot
.29258 .30328 Mdot
.37974 .58379 Mdot
.55704 .35939 Mdot
.58742 .56991 Mdot
.56254 .50987 Mdot
.65881 .37368 Mdot
.56848 .57902 Mdot
.58744 .58172 Mdot
.53561 .3157 Mdot
.3691 .35165 Mdot
.60624 .61859 Mdot
.33549 .36266 Mdot
.34352 .51541 Mdot
.64624 .56236 Mdot
.35857 .55852 Mdot
.5268 .33071 Mdot
.64003 .55184 Mdot
.36866 .34083 Mdot
.60484 .51307 Mdot
.31876 .35462 Mdot
.57894 .35005 Mdot
.56487 .50779 Mdot
.44712 .74936 Mdot
.19271 .50879 Mdot
.55418 .36198 Mdot
.38918 .54452 Mdot
.59452 .50769 Mdot
.61355 .57924 Mdot
.57326 .34672 Mdot
.40522 .61673 Mdot
.52096 .45611 Mdot
.5914 .31913 Mdot
.35712 .39141 Mdot
.59924 .33759 Mdot
.55227 .48573 Mdot
.38594 .59712 Mdot
.33029 .49817 Mdot
.32488 .48335 Mdot
.52622 .71837 Mdot
.63469 .5551 Mdot
.45532 .23124 Mdot
.38881 .61176 Mdot
.5593 .3518 Mdot
.38328 .37648 Mdot
.64023 .497 Mdot
.55332 .37351 Mdot
.38189 .36071 Mdot
.42096 .73702 Mdot
.30235 .54549 Mdot
.58984 .32581 Mdot
.32414 .32453 Mdot
.39192 .41445 Mdot
.36464 .40388 Mdot
.46774 .17991 Mdot
.57981 .34186 Mdot
.43971 .73867 Mdot
.38758 .36408 Mdot
.63482 .73378 Mdot
.65889 .56079 Mdot
.49436 .65942 Mdot
.21009 .68171 Mdot
.44484 .19301 Mdot
.27066 .44706 Mdot
.46622 .71239 Mdot
.36939 .41026 Mdot
.56381 .53169 Mdot
.58007 .3284 Mdot
.57439 .3307 Mdot
.59989 .59154 Mdot
.57663 .56604 Mdot
.62921 .52987 Mdot
.56751 .50766 Mdot
.71769 .68021 Mdot
.61899 .5117 Mdot
.45793 .79157 Mdot
.54952 .3536 Mdot
.56121 .5493 Mdot
.41448 .60741 Mdot
.62269 .49807 Mdot
.37305 .38862 Mdot
.608 .57178 Mdot
.58633 .57358 Mdot
.55667 .51243 Mdot
.40751 .36922 Mdot
.80134 .63205 Mdot
.19354 .63512 Mdot
.82052 .46597 Mdot
.35975 .49109 Mdot
.35701 .59218 Mdot
.63465 .56586 Mdot
.43831 .72352 Mdot
.77493 .50212 Mdot
.58432 .53283 Mdot
.24033 .29221 Mdot
.59139 .58057 Mdot
.6172 .2514 Mdot
.70107 .58241 Mdot
.8239 .44939 Mdot
.48776 .69464 Mdot
.56898 .51348 Mdot
.67282 .33747 Mdot
.72375 .31645 Mdot
.3536 .43285 Mdot
.3863 .39077 Mdot
.41314 .60515 Mdot
.36767 .56779 Mdot
.41924 .38694 Mdot
.63236 .62484 Mdot
.67902 .58982 Mdot
.67852 .54934 Mdot
.33335 .49059 Mdot
.56895 .39931 Mdot
.43263 .70009 Mdot
.52877 .33144 Mdot
.41309 .84273 Mdot
.33254 .28586 Mdot
.33589 .32563 Mdot
.41421 .7147 Mdot
.3979 .58494 Mdot
.33474 .48934 Mdot
.43319 .72533 Mdot
.60548 .52872 Mdot
.5847 .3513 Mdot
.60576 .20753 Mdot
.65835 .62413 Mdot
.60043 .18736 Mdot
.56661 .38503 Mdot
.50891 .45454 Mdot
.37433 .36667 Mdot
.34968 .53098 Mdot
.60868 .58151 Mdot
.61667 .54152 Mdot
.60867 .33662 Mdot
.62287 .52716 Mdot
.57102 .26928 Mdot
.6042 .58549 Mdot
.33033 .52312 Mdot
.42484 .69385 Mdot
.42057 .38313 Mdot
.51826 .71662 Mdot
.53368 .35176 Mdot
.46638 .6763 Mdot
.41495 .62194 Mdot
.76905 .53713 Mdot
.36203 .37317 Mdot
.43859 .75016 Mdot
.40943 .62237 Mdot
.44097 .69652 Mdot
.62111 .50148 Mdot
.34653 .58525 Mdot
.46069 .72372 Mdot
.75516 .66828 Mdot
.64988 .51519 Mdot
.70498 .70859 Mdot
.39423 .35281 Mdot
.59915 .34071 Mdot
.55682 .55016 Mdot
.35291 .52843 Mdot
.53994 .54855 Mdot
.25299 .40035 Mdot
.32411 .47467 Mdot
.33837 .47842 Mdot
.39254 .73271 Mdot
.44708 .74661 Mdot
.23335 .45269 Mdot
.43885 .22316 Mdot
.5913 .35118 Mdot
.63814 .58379 Mdot
.82877 .52192 Mdot
.38696 .36452 Mdot
.60033 .5269 Mdot
.33555 .58874 Mdot
.38973 .36596 Mdot
.6155 .56545 Mdot
.39797 .35002 Mdot
.57806 .33314 Mdot
.25059 .63693 Mdot
.59213 .35325 Mdot
.65193 .51996 Mdot
.38103 .34102 Mdot
.36604 .60799 Mdot
.5637 .32196 Mdot
.60638 .51591 Mdot
.6228 .58272 Mdot
.33674 .50189 Mdot
.55661 .53482 Mdot
.81386 .55031 Mdot
.55468 .52499 Mdot
.37989 .56247 Mdot
.5648 .57246 Mdot
.29913 .24724 Mdot
.28093 .57224 Mdot
.58227 .36134 Mdot
.34003 .48152 Mdot
.37285 .5836 Mdot
.33588 .69038 Mdot
.36333 .45357 Mdot
.59016 .51369 Mdot
.34766 .50939 Mdot
.47787 .64946 Mdot
.39866 .3985 Mdot
.59705 .59974 Mdot
.36057 .29299 Mdot
.41648 .60366 Mdot
.33588 .49379 Mdot
.66298 .50231 Mdot
.5243 .33776 Mdot
.5861 .56975 Mdot
.36696 .61151 Mdot
.5993 .32776 Mdot
.64443 .51637 Mdot
.62433 .66104 Mdot
.32571 .47692 Mdot
.39728 .35846 Mdot
.69519 .54566 Mdot
.62644 .51996 Mdot
.35329 .57241 Mdot
.54006 .36884 Mdot
.35175 .37081 Mdot
.55696 .33294 Mdot
.66648 .25426 Mdot
.31552 .44968 Mdot
.74042 .64996 Mdot
.41292 .7486 Mdot
.28312 .39952 Mdot
.81791 .41967 Mdot
.21715 .49102 Mdot
.60407 .71732 Mdot
.72419 .27252 Mdot
.40712 .62015 Mdot
.32672 .55178 Mdot
.36842 .57848 Mdot
.57361 .53953 Mdot
.37448 .59818 Mdot
.82563 .43762 Mdot
.59957 .58505 Mdot
.35326 .58362 Mdot
.28172 .66314 Mdot
.5725 .56555 Mdot
.55377 .36411 Mdot
.73512 .74912 Mdot
.21071 .38871 Mdot
.36443 .24408 Mdot
.37568 .61034 Mdot
.69715 .52356 Mdot
.57283 .57187 Mdot
.5578 .50324 Mdot
.57513 .31817 Mdot
.58615 .59338 Mdot
.43439 .69995 Mdot
.41585 .71385 Mdot
.48517 .62118 Mdot
.22189 .66257 Mdot
.60737 .61761 Mdot
.56643 .32018 Mdot
.72899 .58881 Mdot
.24425 .36488 Mdot
.36546 .53501 Mdot
.34314 .34627 Mdot
.79046 .64779 Mdot
.65697 .61366 Mdot
.35756 .31516 Mdot
.33886 .29944 Mdot
.56968 .36103 Mdot
.79881 .60711 Mdot
.39373 .38846 Mdot
.71383 .36809 Mdot
.6311 .37284 Mdot
.61068 .53728 Mdot
.36228 .36527 Mdot
.61108 .6141 Mdot
.26973 .30346 Mdot
.63772 .75195 Mdot
.41455 .80615 Mdot
.65253 .52863 Mdot
.22266 .43889 Mdot
.60962 .57596 Mdot
.53262 .45579 Mdot
.55373 .5268 Mdot
.55373 .33064 Mdot
.50894 .56636 Mdot
.44348 .43408 Mdot
.22217 .68679 Mdot
.33757 .27872 Mdot
.46537 .70989 Mdot
.61604 .58204 Mdot
.61097 .53861 Mdot
.42925 .73983 Mdot
.54276 .33463 Mdot
.56732 .50961 Mdot
.54108 .66431 Mdot
.6252 .53535 Mdot
.38625 .39366 Mdot
.5102 .75171 Mdot
.59652 .28889 Mdot
.54777 .52736 Mdot
.59427 .31316 Mdot
.40562 .37004 Mdot
.36165 .38464 Mdot
.6444 .49012 Mdot
.34688 .36159 Mdot
.59397 .57834 Mdot
.54901 .80001 Mdot
.56143 .30766 Mdot
.68556 .61119 Mdot
.53818 .34994 Mdot
.74044 .528 Mdot
.37263 .33909 Mdot
.33163 .50545 Mdot
.62144 .33853 Mdot
.39115 .3875 Mdot
.39503 .22926 Mdot
.67404 .5714 Mdot
.55695 .5801 Mdot
.30518 .28378 Mdot
.38103 .61535 Mdot
.32724 .48447 Mdot
.35662 .34783 Mdot
.62801 .52202 Mdot
.58017 .59522 Mdot
.40785 .38563 Mdot
.68452 .39117 Mdot
.3365 .67954 Mdot
.57861 .57825 Mdot
.55006 .32991 Mdot
.55838 .34946 Mdot
.64388 .52661 Mdot
.59763 .51769 Mdot
.39334 .58507 Mdot
.34162 .48849 Mdot
.35432 .52203 Mdot
.32575 .48149 Mdot
.33655 .52941 Mdot
.49826 .283 Mdot
.36429 .40175 Mdot
.47521 .24481 Mdot
.28387 .33079 Mdot
.53934 .58411 Mdot
.34971 .58641 Mdot
.60839 .54564 Mdot
.59263 .57186 Mdot
.35134 .37002 Mdot
.31648 .43191 Mdot
.55235 .48163 Mdot
.57649 .31076 Mdot
.35721 .34538 Mdot
.65256 .60677 Mdot
.52588 .24205 Mdot
.45738 .71296 Mdot
.35255 .24569 Mdot
.36169 .37647 Mdot
.56695 .366 Mdot
.4045 .35127 Mdot
.61708 .53885 Mdot
.64775 .58218 Mdot
.5697 .35297 Mdot
.45968 .73809 Mdot
.66804 .52402 Mdot
.61752 .56699 Mdot
.14087 .47229 Mdot
.22001 .39981 Mdot
.44263 .35823 Mdot
.56422 .52222 Mdot
.56645 .58326 Mdot
.45728 .69834 Mdot
.62138 .53581 Mdot
.62719 .58296 Mdot
.18331 .53374 Mdot
.44711 .3492 Mdot
.46989 .704 Mdot
.72015 .37426 Mdot
.56862 .38477 Mdot
.82144 .57782 Mdot
.35086 .51897 Mdot
.41197 .34473 Mdot
.24519 .60783 Mdot
.33784 .49056 Mdot
.26029 .39185 Mdot
.81166 .59525 Mdot
.32633 .48197 Mdot
.4327 .649 Mdot
.53142 .49326 Mdot
.58988 .58627 Mdot
.61532 .57562 Mdot
.44184 .72818 Mdot
.58012 .33908 Mdot
.47638 .5944 Mdot
.64233 .77125 Mdot
.60291 .57313 Mdot
.54797 .28154 Mdot
.75827 .67852 Mdot
.33834 .5009 Mdot
.43139 .70479 Mdot
.42495 .74989 Mdot
.61891 .57944 Mdot
.19661 .54932 Mdot
.56566 .32426 Mdot
.60574 .51586 Mdot
.61538 .50773 Mdot
.37036 .60718 Mdot
.57857 .3601 Mdot
.4036 .62593 Mdot
.32218 .47732 Mdot
.75076 .33298 Mdot
.14334 .43833 Mdot
.35319 .35813 Mdot
.80261 .54013 Mdot
.39051 .40153 Mdot
.42137 .79944 Mdot
.33527 .48285 Mdot
.58304 .52591 Mdot
.5344 .35998 Mdot
.60772 .51381 Mdot
.59675 .53237 Mdot
.60546 .5299 Mdot
.66098 .58989 Mdot
.2533 .28143 Mdot
.4357 .71334 Mdot
.55582 .49236 Mdot
.37978 .5638 Mdot
.80565 .55014 Mdot
.65425 .79007 Mdot
.6159 .54819 Mdot
.62846 .57813 Mdot
.55266 .36734 Mdot
.59903 .59285 Mdot
.40173 .39481 Mdot
.54015 .36958 Mdot
.56657 .50437 Mdot
.79058 .60707 Mdot
.57605 .50628 Mdot
.81533 .43705 Mdot
.40533 .3517 Mdot
.39216 .23267 Mdot
.57091 .48452 Mdot
.32536 .48895 Mdot
.32714 .48408 Mdot
.34981 .50083 Mdot
.39601 .3383 Mdot
.3524 .57735 Mdot
.57982 .81187 Mdot
.54956 .59021 Mdot
.56435 .53712 Mdot
.58139 .59694 Mdot
.34226 .56055 Mdot
.49576 .40226 Mdot
.2472 .45997 Mdot
.66272 .59903 Mdot
.39508 .59804 Mdot
.60012 .33795 Mdot
.43554 .58463 Mdot
.53655 .35963 Mdot
.46625 .69618 Mdot
.36683 .36477 Mdot
.45223 .70542 Mdot
.42359 .20499 Mdot
.5772 .34939 Mdot
.6091 .33732 Mdot
.35509 .5895 Mdot
.49225 .44692 Mdot
.84682 .35966 Mdot
.37233 .6197 Mdot
.54098 .69366 Mdot
.56884 .31522 Mdot
.60284 .50332 Mdot
.49684 .71379 Mdot
.4946 .44014 Mdot
.35793 .58235 Mdot
.58045 .53752 Mdot
.21452 .59587 Mdot
.3943 .58715 Mdot
.59845 .60049 Mdot
.40394 .61238 Mdot
.37114 .38417 Mdot
.39471 .61391 Mdot
.55969 .39286 Mdot
.63969 .55654 Mdot
.85843 .37964 Mdot
.48228 .69759 Mdot
.55557 .52647 Mdot
.35969 .34368 Mdot
.53817 .64636 Mdot
.59829 .54261 Mdot
.42181 .70831 Mdot
.38822 .59841 Mdot
.34141 .65943 Mdot
.56793 .56686 Mdot
.37171 .60253 Mdot
.54082 .32516 Mdot
.40045 .34054 Mdot
.41657 .78491 Mdot
.33722 .51139 Mdot
.57913 .32066 Mdot
.31751 .47588 Mdot
.36191 .3364 Mdot
.56991 .58498 Mdot
.62394 .51331 Mdot
.55005 .34176 Mdot
.2557 .67355 Mdot
.56232 .56569 Mdot
.58053 .52245 Mdot
.39539 .57457 Mdot
.34499 .55865 Mdot
.26374 .6736 Mdot
.40235 .62143 Mdot
.63418 .59659 Mdot
.55075 .34061 Mdot
.58467 .5616 Mdot
.55907 .37032 Mdot
.62579 .58721 Mdot
.5197 .37051 Mdot
.55323 .3121 Mdot
.23765 .50649 Mdot
.58155 .54878 Mdot
.69961 .57518 Mdot
.60143 .53145 Mdot
.62491 .53022 Mdot
.38719 .57679 Mdot
.42752 .71584 Mdot
.61849 .4828 Mdot
.44539 .76962 Mdot
.42264 .71188 Mdot
.68788 .2848 Mdot
.37793 .61245 Mdot
.45079 .72837 Mdot
.71874 .69931 Mdot
.34356 .48712 Mdot
.44227 .71803 Mdot
.67971 .77611 Mdot
.35228 .36143 Mdot
.58256 .37595 Mdot
.57232 .56477 Mdot
.70763 .26112 Mdot
.5703 .7803 Mdot
.34389 .5094 Mdot
.55619 .52331 Mdot
.60534 .54577 Mdot
.57738 .30412 Mdot
.37563 .82068 Mdot
.37799 .55766 Mdot
.5719 .54271 Mdot
.57842 .36784 Mdot
.24533 .74185 Mdot
.37147 .56069 Mdot
.44136 .72183 Mdot
.41007 .38008 Mdot
.51933 .35097 Mdot
.34076 .51537 Mdot
.40644 .39283 Mdot
.25074 .50944 Mdot
.39606 .2234 Mdot
.59543 .5074 Mdot
.34838 .5846 Mdot
.41386 .19755 Mdot
.60623 .62264 Mdot
.43566 .36587 Mdot
.59924 .44606 Mdot
.56675 .36268 Mdot
.40479 .38811 Mdot
.45782 .70566 Mdot
.54844 .3826 Mdot
.54558 .33018 Mdot
.35923 .38592 Mdot
.43986 .62696 Mdot
.50678 .45174 Mdot
.37881 .39433 Mdot
.29494 .3055 Mdot
.62948 .23202 Mdot
.34555 .49732 Mdot
.42158 .71993 Mdot
.57393 .20945 Mdot
.56311 .33239 Mdot
.79241 .64452 Mdot
.36253 .23118 Mdot
.58692 .58152 Mdot
.4505 .73549 Mdot
.46589 .33422 Mdot
.61144 .79779 Mdot
.39258 .36578 Mdot
.45119 .41794 Mdot
.44446 .75572 Mdot
.57774 .58079 Mdot
.64355 .45871 Mdot
.5754 .53419 Mdot
.3711 .36386 Mdot
.73254 .55707 Mdot
.56632 .36694 Mdot
.35699 .34209 Mdot
.35442 .24408 Mdot
.59767 .57683 Mdot
.57956 .54066 Mdot
.53519 .75152 Mdot
.58764 .34662 Mdot
.35303 .524 Mdot
.59188 .51024 Mdot
.61351 .56945 Mdot
.54875 .56443 Mdot
.69354 .57173 Mdot
.19405 .51744 Mdot
.57339 .54366 Mdot
.31638 .50414 Mdot
.54818 .51401 Mdot
.58411 .5505 Mdot
.59453 .31502 Mdot
.16203 .40723 Mdot
.32982 .50379 Mdot
.61 .5716 Mdot
.58911 .50614 Mdot
.35496 .37995 Mdot
.48689 .53828 Mdot
.48949 .43442 Mdot
.34739 .59529 Mdot
.63919 .70813 Mdot
.65981 .59115 Mdot
.55602 .3778 Mdot
.4403 .75192 Mdot
.63928 .52293 Mdot
.55931 .37794 Mdot
.59248 .49258 Mdot
.39628 .59373 Mdot
.34426 .49475 Mdot
.37055 .2533 Mdot
.4482 .72018 Mdot
.5495 .78127 Mdot
.46655 .2569 Mdot
.40954 .59659 Mdot
.56498 .54381 Mdot
.42069 .36836 Mdot
.34655 .59043 Mdot
.33653 .50333 Mdot
.63357 .47828 Mdot
.57397 .32646 Mdot
.55504 .35982 Mdot
.49003 .65863 Mdot
.28955 .50296 Mdot
.15855 .52478 Mdot
.36935 .38145 Mdot
.56727 .49983 Mdot
.44155 .22764 Mdot
.55483 .36118 Mdot
.49768 .68589 Mdot
.45201 .72695 Mdot
.39381 .36492 Mdot
.36234 .52802 Mdot
.55492 .37277 Mdot
.59192 .33462 Mdot
.64886 .51586 Mdot
.62261 .55746 Mdot
.59173 .71533 Mdot
.48799 .64242 Mdot
.40764 .37634 Mdot
.42429 .73396 Mdot
.40462 .6283 Mdot
.57157 .5312 Mdot
.54745 .31645 Mdot
.60763 .218 Mdot
.59372 .50535 Mdot
.39268 .58188 Mdot
.56531 .36012 Mdot
.43384 .74428 Mdot
.42331 .70803 Mdot
.62444 .53103 Mdot
.71565 .52695 Mdot
.40078 .37688 Mdot
.55529 .36464 Mdot
.52541 .21218 Mdot
.55972 .56316 Mdot
.6268 .55913 Mdot
.652 .48347 Mdot
.37219 .39777 Mdot
.3968 .23367 Mdot
.45913 .74164 Mdot
.57032 .33685 Mdot
.57205 .50946 Mdot
.45021 .71396 Mdot
.42087 .22552 Mdot
.34198 .4968 Mdot
.39943 .61303 Mdot
.42271 .707 Mdot
.43769 .74181 Mdot
.4191 .72657 Mdot
.78568 .65896 Mdot
.5559 .39314 Mdot
.67969 .62462 Mdot
.55183 .53958 Mdot
.49035 .6623 Mdot
.64975 .50288 Mdot
.40831 .35386 Mdot
.38575 .61848 Mdot
.60031 .53448 Mdot
.64923 .51791 Mdot
.68584 .51929 Mdot
.6946 .59861 Mdot
.58163 .28651 Mdot
.57949 .35316 Mdot
.5362 .57366 Mdot
.36744 .60605 Mdot
.38881 .83761 Mdot
.84029 .40605 Mdot
.57593 .47863 Mdot
.50353 .47103 Mdot
.54316 .32507 Mdot
.36454 .39538 Mdot
.47553 .43082 Mdot
.39897 .34776 Mdot
.56607 .34155 Mdot
.57203 .53515 Mdot
.48119 .2478 Mdot
.43778 .69417 Mdot
.63005 .52608 Mdot
.37942 .36564 Mdot
.62979 .52778 Mdot
.40775 .38846 Mdot
.57918 .25281 Mdot
.27739 .31768 Mdot
.59134 .5809 Mdot
.55479 .56109 Mdot
.63839 .46143 Mdot
.61462 .54983 Mdot
.33161 .76192 Mdot
.54094 .33423 Mdot
.21279 .62663 Mdot
.64408 .51242 Mdot
.74075 .47635 Mdot
.55392 .54989 Mdot
.23158 .61032 Mdot
.62727 .55343 Mdot
.43309 .46327 Mdot
.5846 .58316 Mdot
.63869 .57032 Mdot
.38834 .34339 Mdot
.35514 .37989 Mdot
.54494 .31279 Mdot
.35277 .52527 Mdot
.82104 .48358 Mdot
.62127 .56509 Mdot
.34047 .5272 Mdot
.42147 .33694 Mdot
.43075 .73878 Mdot
.56477 .33972 Mdot
.26486 .76403 Mdot
.40244 .35768 Mdot
.42294 .62402 Mdot
.26459 .6938 Mdot
.34175 .52391 Mdot
.43583 .40269 Mdot
.52068 .48573 Mdot
.45334 .74248 Mdot
.57228 .57575 Mdot
.5085 .18639 Mdot
.22814 .39567 Mdot
.65869 .50654 Mdot
.36492 .33695 Mdot
.77007 .51764 Mdot
.57864 .21458 Mdot
.41772 .7447 Mdot
.46305 .71283 Mdot
.40174 .35971 Mdot
.38605 .56032 Mdot
.65277 .59174 Mdot
.45349 .72576 Mdot
.40579 .59773 Mdot
.34543 .48719 Mdot
.39394 .46025 Mdot
.56654 .32743 Mdot
.35538 .24688 Mdot
.4449 .28742 Mdot
.40775 .37219 Mdot
.45398 .67016 Mdot
.5187 .34175 Mdot
.52655 .36149 Mdot
.34859 .52361 Mdot
.38604 .57403 Mdot
.5529 .38897 Mdot
.6448 .59063 Mdot
.70273 .59475 Mdot
.60608 .57353 Mdot
.43772 .7321 Mdot
.62303 .5489 Mdot
.39033 .58461 Mdot
.38969 .37014 Mdot
.3776 .57007 Mdot
.39538 .35065 Mdot
.49895 .27239 Mdot
.6076 .52034 Mdot
.63658 .5711 Mdot
.56151 .78513 Mdot
.55366 .30567 Mdot
.47304 .19551 Mdot
.33002 .52678 Mdot
.36679 .57339 Mdot
.62171 .58605 Mdot
.53498 .34594 Mdot
.41635 .70012 Mdot
.55517 .78932 Mdot
.63331 .52312 Mdot
.53996 .33624 Mdot
.56812 .53839 Mdot
.73525 .68032 Mdot
.20459 .40935 Mdot
.55577 .33818 Mdot
.2402 .70833 Mdot
.57237 .51743 Mdot
.51685 .57795 Mdot
.58869 .60135 Mdot
.55773 .67838 Mdot
.56332 .56811 Mdot
.56612 .38528 Mdot
.60515 .56929 Mdot
.54815 .38068 Mdot
.39884 .57644 Mdot
.36821 .40227 Mdot
.57323 .31362 Mdot
.62664 .5125 Mdot
.83402 .60731 Mdot
.36898 .36881 Mdot
.61259 .58166 Mdot
.37397 .34987 Mdot
.57516 .37512 Mdot
.5888 .33048 Mdot
.60908 .8075 Mdot
.43962 .34695 Mdot
.37284 .38543 Mdot
.5733 .55016 Mdot
.41093 .27825 Mdot
.58033 .55379 Mdot
.5733 .71465 Mdot
.65047 .54433 Mdot
.56355 .56987 Mdot
.58611 .83725 Mdot
.39607 .40126 Mdot
.16403 .52405 Mdot
.65762 .75936 Mdot
.77654 .67183 Mdot
.53256 .38298 Mdot
.41788 .74446 Mdot
.79869 .61282 Mdot
.32292 .4754 Mdot
.39167 .60726 Mdot
.60167 .53436 Mdot
.61111 .30114 Mdot
.39946 .39049 Mdot
.42788 .71811 Mdot
.59261 .58127 Mdot
.38941 .57587 Mdot
.38505 .69175 Mdot
.36012 .40219 Mdot
.56399 .33346 Mdot
.57199 .30695 Mdot
.21937 .70191 Mdot
.57079 .50954 Mdot
.62887 .58011 Mdot
.3691 .3631 Mdot
.66946 .6134 Mdot
.43938 .74895 Mdot
.27545 .64358 Mdot
.37268 .38457 Mdot
.47929 .48627 Mdot
.58155 .347 Mdot
.60656 .54518 Mdot
.50743 .4108 Mdot
.371 .47355 Mdot
.71934 .3421 Mdot
.43902 .72643 Mdot
.57201 .72358 Mdot
.56665 .38525 Mdot
.3828 .37269 Mdot
.30837 .55243 Mdot
.54088 .53349 Mdot
.60579 .55092 Mdot
.56801 .72656 Mdot
.47327 .6261 Mdot
.44767 .7939 Mdot
.62697 .59175 Mdot
.47524 .61888 Mdot
.63595 .58257 Mdot
.5451 .55963 Mdot
.64535 .58727 Mdot
.63215 .55877 Mdot
.5408 .33273 Mdot
.68839 .55314 Mdot
.38306 .60911 Mdot
.66309 .36857 Mdot
.46322 .41579 Mdot
.557 .54702 Mdot
.57537 .54153 Mdot
.757 .38601 Mdot
.37735 .31028 Mdot
.55128 .31893 Mdot
.58516 .39551 Mdot
.34698 .36716 Mdot
.70077 .57198 Mdot
.35304 .5394 Mdot
.67858 .519 Mdot
.38096 .57375 Mdot
.5372 .34535 Mdot
.36443 .56917 Mdot
.35589 .39453 Mdot
.34823 .58492 Mdot
.33474 .52835 Mdot
.40234 .39148 Mdot
.58596 .33665 Mdot
.63274 .53946 Mdot
.35623 .34677 Mdot
.53826 .74954 Mdot
.43872 .73182 Mdot
.61195 .80649 Mdot
.58581 .49591 Mdot
.46522 .38481 Mdot
.62354 .66164 Mdot
.37728 .57149 Mdot
.18776 .46156 Mdot
.55436 .3113 Mdot
.44131 .69002 Mdot
.53701 .34285 Mdot
.32582 .24296 Mdot
.42444 .72148 Mdot
.68695 .77171 Mdot
.28942 .47905 Mdot
.37818 .67395 Mdot
.65279 .57947 Mdot
.59277 .43111 Mdot
.36818 .61414 Mdot
.40058 .38956 Mdot
.2828 .47728 Mdot
.64121 .56333 Mdot
.21999 .49438 Mdot
.55207 .30443 Mdot
.34833 .49926 Mdot
.3848 .37905 Mdot
.35306 .34739 Mdot
.60579 .51057 Mdot
.3031 .69277 Mdot
.64476 .55216 Mdot
.28142 .50095 Mdot
.61304 .71972 Mdot
.66463 .49257 Mdot
.60614 .5853 Mdot
.36022 .5597 Mdot
.5683 .53985 Mdot
.70269 .61813 Mdot
.47424 .1802 Mdot
.67028 .57015 Mdot
.30619 .45233 Mdot
.44266 .67109 Mdot
.57282 .35018 Mdot
.57648 .48383 Mdot
.33865 .50954 Mdot
.56818 .51888 Mdot
.44815 .14846 Mdot
.44406 .7161 Mdot
.36721 .63408 Mdot
.5498 .54048 Mdot
.5983 .51057 Mdot
.6265 .35798 Mdot
.61592 .31451 Mdot
.36289 .52775 Mdot
.60693 .55663 Mdot
.63368 .72479 Mdot
.36219 .35808 Mdot
.64388 .54391 Mdot
.61574 .57714 Mdot
.71465 .3045 Mdot
.36717 .39176 Mdot
.37254 .56808 Mdot
.33374 .47747 Mdot
.41044 .62591 Mdot
.47148 .73275 Mdot
.46351 .44427 Mdot
.49643 .67008 Mdot
.21068 .40337 Mdot
.41893 .73981 Mdot
.5841 .50322 Mdot
.54686 .48468 Mdot
.58109 .51289 Mdot
.46019 .70609 Mdot
.37435 .3974 Mdot
.55597 .3132 Mdot
.37747 .25739 Mdot
.33421 .49323 Mdot
.59452 .59975 Mdot
.4434 .6977 Mdot
.57843 .32734 Mdot
.47794 .69814 Mdot
.57205 .34337 Mdot
.38077 .38697 Mdot
.3571 .3322 Mdot
.43567 .70584 Mdot
.53656 .35706 Mdot
.3159 .49675 Mdot
.63417 .77442 Mdot
.65137 .55558 Mdot
.40779 .41848 Mdot
.53743 .33011 Mdot
.55942 .29237 Mdot
.53396 .32023 Mdot
.61884 .52542 Mdot
.50219 .48307 Mdot
.54424 .53482 Mdot
.40376 .36727 Mdot
.40416 .60722 Mdot
.49261 .64721 Mdot
.58488 .23743 Mdot
.45506 .64638 Mdot
.65319 .50821 Mdot
.59856 .57402 Mdot
.6185 .57948 Mdot
.6555 .53927 Mdot
.29469 .53699 Mdot
.60105 .51855 Mdot
.38955 .34464 Mdot
.38624 .5868 Mdot
.55346 .54127 Mdot
.34482 .51513 Mdot
.51306 .44401 Mdot
.43649 .75239 Mdot
.45705 .43576 Mdot
.83137 .56428 Mdot
.57807 .32434 Mdot
.39834 .62465 Mdot
.38903 .60764 Mdot
.42149 .73798 Mdot
.39843 .38941 Mdot
.57696 .34117 Mdot
.57879 .68214 Mdot
.42098 .73012 Mdot
.60838 .56964 Mdot
.24317 .56962 Mdot
.22814 .54277 Mdot
.58187 .5863 Mdot
.59076 .53497 Mdot
.33795 .47901 Mdot
.38052 .55655 Mdot
.63342 .19263 Mdot
.49921 .7338 Mdot
.43118 .70989 Mdot
.46076 .73311 Mdot
.52482 .34857 Mdot
.57068 .47511 Mdot
.3998 .36118 Mdot
.51388 .75973 Mdot
.51836 .6404 Mdot
.53297 .78158 Mdot
.40934 .78415 Mdot
.62081 .51525 Mdot
.62792 .4247 Mdot
.59494 .57725 Mdot
.56696 .30185 Mdot
.58506 .35943 Mdot
.55998 .31667 Mdot
.40331 .37954 Mdot
.745 .52722 Mdot
.37822 .34105 Mdot
.83899 .51635 Mdot
.56189 .38747 Mdot
.30143 .58565 Mdot
.35739 .57242 Mdot
.56862 .4921 Mdot
.44008 .74691 Mdot
.36297 .41356 Mdot
.66488 .568 Mdot
.19344 .53295 Mdot
.34943 .58474 Mdot
.58786 .34056 Mdot
.52076 .48765 Mdot
.7991 .37304 Mdot
.48613 .44901 Mdot
.54856 .60436 Mdot
.61663 .38913 Mdot
.4256 .73388 Mdot
.71682 .34249 Mdot
.46843 .72138 Mdot
.38591 .36249 Mdot
.63856 .56263 Mdot
.63583 .55135 Mdot
.62713 .58732 Mdot
.60291 .51982 Mdot
.35132 .37595 Mdot
.62444 .49269 Mdot
.29912 .24726 Mdot
.34321 .48862 Mdot
.74816 .66664 Mdot
.45685 .71757 Mdot
.38346 .33492 Mdot
.38493 .58353 Mdot
.35623 .52262 Mdot
.51154 .70518 Mdot
.58259 .58099 Mdot
.60017 .53253 Mdot
.37023 .5398 Mdot
.61968 .59486 Mdot
.66481 .59325 Mdot
.3791 .60635 Mdot
.45665 .64532 Mdot
.41351 .72534 Mdot
.45351 .70676 Mdot
.37534 .39561 Mdot
.53601 .35222 Mdot
.44682 .72882 Mdot
.39298 .57098 Mdot
.60452 .49053 Mdot
.62328 .50845 Mdot
.53742 .32885 Mdot
.36012 .23209 Mdot
.42391 .75103 Mdot
.51742 .49347 Mdot
.55479 .38168 Mdot
.55549 .39364 Mdot
.60413 .55128 Mdot
.67072 .5171 Mdot
.55084 .29265 Mdot
.41689 .71917 Mdot
.37935 .33379 Mdot
.37152 .65657 Mdot
.37883 .36146 Mdot
.57942 .33599 Mdot
.64338 .5182 Mdot
.58478 .34179 Mdot
.5635 .52036 Mdot
.7085 .80853 Mdot
.63317 .55209 Mdot
.22864 .35743 Mdot
.55471 .68786 Mdot
.38471 .60438 Mdot
.3179 .49845 Mdot
.34868 .51317 Mdot
.55859 .3838 Mdot
.63799 .51764 Mdot
.46293 .73134 Mdot
.73813 .72363 Mdot
.51906 .33247 Mdot
.39847 .60153 Mdot
.35949 .54187 Mdot
.39547 .39942 Mdot
.55151 .52977 Mdot
.60894 .54818 Mdot
.34895 .57781 Mdot
.66365 .66487 Mdot
.54831 .36813 Mdot
.62449 .5814 Mdot
.59126 .56433 Mdot
.38092 .60442 Mdot
.62889 .77635 Mdot
.59025 .4091 Mdot
.63561 .56425 Mdot
.33049 .59487 Mdot
.40509 .34844 Mdot
.65675 .55751 Mdot
.62608 .49295 Mdot
.44783 .74035 Mdot
.77249 .61912 Mdot
.49801 .17678 Mdot
.41148 .36137 Mdot
.35195 .52331 Mdot
.57589 .5025 Mdot
.35684 .57398 Mdot
.62382 .50978 Mdot
.80048 .50737 Mdot
.34654 .49624 Mdot
.58893 .51899 Mdot
.58429 .47104 Mdot
.58793 .35347 Mdot
.59973 .51578 Mdot
.74932 .35777 Mdot
.38501 .62565 Mdot
.59368 .51701 Mdot
.70698 .51204 Mdot
.36104 .38148 Mdot
.57885 .47769 Mdot
.45976 .71503 Mdot
.5587 .67514 Mdot
.46651 .26685 Mdot
.33774 .58858 Mdot
.4533 .70848 Mdot
.63491 .53164 Mdot
.38561 .55882 Mdot
.40926 .37521 Mdot
.21382 .49134 Mdot
.61359 .59009 Mdot
.37079 .36507 Mdot
.389 .372 Mdot
.44637 .71032 Mdot
.16574 .5721 Mdot
.60146 .48602 Mdot
.61692 .54862 Mdot
.75425 .355 Mdot
.58963 .31416 Mdot
.62575 .54604 Mdot
.59099 .50429 Mdot
.38563 .3453 Mdot
.62213 .33431 Mdot
.77108 .4677 Mdot
.27971 .66055 Mdot
.41253 .38161 Mdot
.4052 .63993 Mdot
.38556 .55835 Mdot
.45649 .7207 Mdot
.56656 .35318 Mdot
.4537 .75239 Mdot
.37697 .60994 Mdot
.57991 .50619 Mdot
.39069 .35146 Mdot
.65571 .27428 Mdot
.39944 .40406 Mdot
.3464 .5987 Mdot
.56833 .29729 Mdot
.42906 .23893 Mdot
.37481 .1715 Mdot
.45415 .29139 Mdot
.34726 .32274 Mdot
.43114 .73897 Mdot
.25132 .51604 Mdot
.59376 .56788 Mdot
.70838 .34676 Mdot
.63081 .5345 Mdot
.66798 .4667 Mdot
.40269 .61939 Mdot
.35662 .5303 Mdot
.63755 .56236 Mdot
.59675 .72436 Mdot
.38576 .41223 Mdot
.39968 .39766 Mdot
.59365 .52348 Mdot
.39067 .38788 Mdot
.61889 .5584 Mdot
.38615 .57761 Mdot
.16464 .48731 Mdot
.60432 .57815 Mdot
.55491 .57448 Mdot
.34267 .31162 Mdot
.62843 .79988 Mdot
.30507 .49858 Mdot
.62202 .41814 Mdot
.77458 .33561 Mdot
.39097 .38714 Mdot
.60913 .46673 Mdot
.35505 .60187 Mdot
.33758 .47842 Mdot
.31628 .49589 Mdot
.62499 .53878 Mdot
.62051 .53467 Mdot
.62004 .58614 Mdot
.57876 .53942 Mdot
.71329 .34976 Mdot
.6822 .59357 Mdot
.66713 .44463 Mdot
.59767 .53156 Mdot
.64317 .45722 Mdot
.3562 .34902 Mdot
.60349 .318 Mdot
.44422 .75842 Mdot
.61879 .51435 Mdot
.58301 .27396 Mdot
.39905 .34316 Mdot
.83937 .51373 Mdot
.38462 .40043 Mdot
.37347 .58508 Mdot
.37184 .40179 Mdot
.55732 .53051 Mdot
.5578 .34981 Mdot
.36144 .61161 Mdot
.23499 .43873 Mdot
.39272 .60652 Mdot
.55552 .52638 Mdot
.36344 .64065 Mdot
.3907 .60937 Mdot
.50327 .42545 Mdot
.55926 .35467 Mdot
.6242 .73346 Mdot
.58502 .36013 Mdot
.58984 .51662 Mdot
.58511 .51848 Mdot
.31889 .46494 Mdot
.37239 .40782 Mdot
.57794 .37327 Mdot
.13892 .4839 Mdot
.46936 .72795 Mdot
.55842 .32024 Mdot
.53618 .5525 Mdot
.48051 .57313 Mdot
.55206 .34893 Mdot
.63148 .69172 Mdot
.403 .38703 Mdot
.54646 .38399 Mdot
.53728 .54977 Mdot
.30338 .3543 Mdot
.43082 .69575 Mdot
.36516 .55246 Mdot
.43212 .48732 Mdot
.37451 .61818 Mdot
.37877 .33237 Mdot
.34348 .57127 Mdot
.36083 .35691 Mdot
.45942 .2012 Mdot
.71812 .58575 Mdot
.42158 .37496 Mdot
.36292 .33329 Mdot
.35897 .59281 Mdot
.60563 .58758 Mdot
.4206 .43588 Mdot
.63342 .59071 Mdot
.66269 .56299 Mdot
.3588 .36377 Mdot
.57287 .3811 Mdot
.58499 .37371 Mdot
.60976 .4395 Mdot
.57263 .30671 Mdot
.38232 .57317 Mdot
.20598 .40569 Mdot
.4296 .20304 Mdot
.36388 .36563 Mdot
.34913 .34796 Mdot
.57878 .55028 Mdot
.35452 .5794 Mdot
.40635 .58654 Mdot
.39852 .36432 Mdot
.67543 .31693 Mdot
.54576 .52814 Mdot
.56711 .29288 Mdot
.55996 .38833 Mdot
.5528 .33898 Mdot
.52792 .33175 Mdot
.75957 .45025 Mdot
.40323 .38766 Mdot
.56051 .38589 Mdot
.59035 .52221 Mdot
.62142 .53627 Mdot
.32782 .48952 Mdot
.45578 .70827 Mdot
.58471 .49345 Mdot
.62645 .6019 Mdot
.60324 .54838 Mdot
.39841 .6124 Mdot
.52905 .52126 Mdot
.35264 .51724 Mdot
.37339 .55508 Mdot
.34431 .53609 Mdot
.3288 .50017 Mdot
.58745 .43031 Mdot
.77862 .32997 Mdot
.57166 .54226 Mdot
.65879 .62702 Mdot
.35953 .57524 Mdot
.188 .49263 Mdot
.40421 .23258 Mdot
.61854 .58788 Mdot
.38156 .47074 Mdot
.34641 .5736 Mdot
.58812 .31745 Mdot
.62823 .54188 Mdot
.32798 .47891 Mdot
.43611 .75168 Mdot
.53834 .5679 Mdot
.33073 .47555 Mdot
.53948 .3642 Mdot
.43093 .7635 Mdot
.53834 .37533 Mdot
.34434 .58247 Mdot
.58322 .47243 Mdot
.84686 .35407 Mdot
.41147 .6234 Mdot
.70399 .73626 Mdot
.60056 .27793 Mdot
.62137 .58331 Mdot
.39785 .62613 Mdot
.58641 .31144 Mdot
.38786 .33399 Mdot
.47979 .58971 Mdot
.5611 .30821 Mdot
.35567 .52702 Mdot
.33094 .48312 Mdot
.38227 .60753 Mdot
.57717 .35678 Mdot
.64507 .53527 Mdot
.56951 .36893 Mdot
.37352 .4022 Mdot
.58366 .57091 Mdot
.82398 .43558 Mdot
.66793 .6191 Mdot
.56164 .38324 Mdot
.38629 .5696 Mdot
.45348 .69553 Mdot
.58296 .57733 Mdot
.69718 .73116 Mdot
.56379 .51042 Mdot
.36621 .35739 Mdot
.20728 .59647 Mdot
.67454 .28651 Mdot
.55505 .55061 Mdot
.57851 .54876 Mdot
.40597 .38799 Mdot
.58287 .58003 Mdot
.56165 .56347 Mdot
.43313 .34709 Mdot
.57883 .36214 Mdot
.60145 .56895 Mdot
.40325 .58759 Mdot
.50754 .19304 Mdot
.54532 .53411 Mdot
.38189 .52876 Mdot
.61137 .73243 Mdot
.19724 .59687 Mdot
.63543 .53889 Mdot
.51031 .73774 Mdot
.58179 .53698 Mdot
.62231 .52179 Mdot
.57666 .55381 Mdot
.62444 .40332 Mdot
.36048 .59626 Mdot
.39264 .5928 Mdot
.42723 .69837 Mdot
.6175 .73029 Mdot
.45092 .73636 Mdot
.39204 .39744 Mdot
.38519 .71733 Mdot
.34636 .49806 Mdot
.53784 .36236 Mdot
.64107 .54059 Mdot
.38453 .62713 Mdot
.60738 .54255 Mdot
.55926 .52827 Mdot
.36091 .55762 Mdot
.41341 .59837 Mdot
.33435 .56478 Mdot
.45696 .7411 Mdot
.56529 .31291 Mdot
.64933 .51435 Mdot
.42319 .71116 Mdot
.64351 .53198 Mdot
.48288 .66627 Mdot
.56003 .31399 Mdot
.5769 .36456 Mdot
.59645 .34421 Mdot
.57933 .50617 Mdot
.55729 .54478 Mdot
.37561 .3412 Mdot
.53429 .35325 Mdot
.36951 .3888 Mdot
.35384 .60223 Mdot
.4244 .61564 Mdot
.62482 .53862 Mdot
.50728 .55085 Mdot
.45212 .74063 Mdot
.37743 .58275 Mdot
.37355 .54125 Mdot
.44738 .69008 Mdot
.56258 .51444 Mdot
.35845 .56027 Mdot
.44955 .70262 Mdot
.65732 .3185 Mdot
.74679 .28678 Mdot
.45854 .70007 Mdot
.59104 .52423 Mdot
.62819 .32451 Mdot
.60991 .78115 Mdot
.47054 .72076 Mdot
.37891 .35258 Mdot
.58011 .50481 Mdot
.64989 .64965 Mdot
.43426 .75503 Mdot
.50359 .19982 Mdot
.38282 .6021 Mdot
.31276 .37497 Mdot
.58006 .60976 Mdot
.69471 .35133 Mdot
.46254 .74402 Mdot
.57368 .33891 Mdot
.60183 .32568 Mdot
.59508 .54973 Mdot
.46539 .74703 Mdot
.40975 .39041 Mdot
.38524 .59881 Mdot
.332 .51804 Mdot
.57567 .35957 Mdot
.38827 .28574 Mdot
.40155 .59375 Mdot
.51078 .51317 Mdot
.24894 .6301 Mdot
.70417 .58082 Mdot
.68485 .49369 Mdot
.24417 .38091 Mdot
.59481 .50154 Mdot
.46413 .70658 Mdot
.39407 .34213 Mdot
.39891 .35538 Mdot
.3745 .384 Mdot
.31974 .5009 Mdot
.47223 .43101 Mdot
.35426 .5965 Mdot
.22639 .47223 Mdot
.4506 .71496 Mdot
.65522 .7197 Mdot
.64052 .52814 Mdot
.59992 .57497 Mdot
.56867 .49888 Mdot
.64619 .55666 Mdot
.58573 .54509 Mdot
.3943 .39042 Mdot
.3196 .50339 Mdot
.33722 .65682 Mdot
.54868 .33267 Mdot
.4428 .64814 Mdot
.35748 .57218 Mdot
.33966 .4809 Mdot
.43288 .71453 Mdot
.52636 .46247 Mdot
.33988 .5768 Mdot
.36588 .56988 Mdot
.58252 .49132 Mdot
.55766 .3737 Mdot
.67635 .52162 Mdot
.58006 .52367 Mdot
.3794 .58031 Mdot
.42997 .59833 Mdot
.77848 .4335 Mdot
.59885 .45622 Mdot
.40806 .73543 Mdot
.49253 .5108 Mdot
.46992 .71787 Mdot
.58075 .60057 Mdot
.18693 .50393 Mdot
.37536 .60859 Mdot
.36943 .58892 Mdot
.4525 .70113 Mdot
.51314 .55598 Mdot
.56892 .35894 Mdot
.35963 .5325 Mdot
.37093 .34808 Mdot
.58409 .51343 Mdot
.42172 .6093 Mdot
.54537 .60735 Mdot
.32435 .69569 Mdot
.36971 .37815 Mdot
.37893 .55981 Mdot
.55143 .53225 Mdot
.59067 .52623 Mdot
.42841 .73833 Mdot
.5406 .27218 Mdot
.54012 .57791 Mdot
.77873 .66959 Mdot
.28279 .31475 Mdot
.31473 .2916 Mdot
.60599 .551 Mdot
.57969 .35808 Mdot
.33546 .48361 Mdot
.42148 .72323 Mdot
.63745 .5023 Mdot
.75552 .2993 Mdot
.58285 .29344 Mdot
.38268 .36681 Mdot
.32709 .47995 Mdot
.47517 .42881 Mdot
.57105 .50632 Mdot
.63063 .53524 Mdot
.61191 .52301 Mdot
.68968 .22371 Mdot
.4006 .60056 Mdot
.56005 .30301 Mdot
.43666 .72598 Mdot
.57113 .30512 Mdot
.39228 .6003 Mdot
.39068 .26241 Mdot
.56333 .56073 Mdot
.56936 .29484 Mdot
.57087 .34035 Mdot
.39489 .39948 Mdot
.38445 .33211 Mdot
.39591 .64942 Mdot
.63256 .5533 Mdot
.32888 .47832 Mdot
.58818 .35589 Mdot
.37032 .54467 Mdot
.42414 .72388 Mdot
.36594 .3412 Mdot
.59832 .53058 Mdot
.38294 .61114 Mdot
.6643 .51585 Mdot
.55036 .35564 Mdot
.36517 .57015 Mdot
.34005 .51707 Mdot
.46124 .72795 Mdot
.61081 .53312 Mdot
.40785 .72427 Mdot
.35185 .52713 Mdot
.59104 .56555 Mdot
.55202 .44328 Mdot
.40631 .74167 Mdot
.24418 .45042 Mdot
.36767 .60937 Mdot
.33295 .50305 Mdot
.5948 .34116 Mdot
.50252 .21002 Mdot
.37385 .59114 Mdot
.54068 .44965 Mdot
.50718 .28932 Mdot
.64992 .51443 Mdot
.56 .33328 Mdot
.24761 .53668 Mdot
.81173 .61842 Mdot
.67552 .72599 Mdot
.6137 .58067 Mdot
.38958 .62396 Mdot
.43873 .69982 Mdot
.36342 .36566 Mdot
.38061 .52802 Mdot
.70491 .60759 Mdot
.35165 .55639 Mdot
.57567 .54912 Mdot
.58257 .36211 Mdot
.39785 .36916 Mdot
.49236 .24995 Mdot
.3894 .56911 Mdot
.39924 .62079 Mdot
.55305 .54235 Mdot
.45157 .72509 Mdot
.71461 .66732 Mdot
.39067 .5828 Mdot
.42121 .61327 Mdot
.2491 .5057 Mdot
.44475 .69732 Mdot
.58597 .53452 Mdot
.61525 .44193 Mdot
.65658 .54391 Mdot
.7112 .7351 Mdot
.35026 .51845 Mdot
.54671 .33563 Mdot
.6287 .52997 Mdot
.27318 .66176 Mdot
.38201 .58612 Mdot
.50331 .4661 Mdot
.42921 .62908 Mdot
.40369 .38577 Mdot
.42198 .61437 Mdot
.61943 .54441 Mdot
.38771 .41156 Mdot
.45218 .74023 Mdot
.63378 .56321 Mdot
.5584 .54636 Mdot
.58306 .31078 Mdot
.38645 .36133 Mdot
.60922 .24017 Mdot
.35614 .34222 Mdot
.40442 .35082 Mdot
.593 .36629 Mdot
.60249 .56125 Mdot
.37174 .58099 Mdot
.34531 .56856 Mdot
.64407 .50988 Mdot
.18091 .4479 Mdot
.56994 .36082 Mdot
.46065 .67288 Mdot
.65029 .20843 Mdot
.60029 .45149 Mdot
.37987 .54768 Mdot
.52661 .28272 Mdot
.4105 .38655 Mdot
.59482 .52704 Mdot
.55374 .37803 Mdot
.40801 .58309 Mdot
.4021 .59304 Mdot
.64436 .52393 Mdot
.39346 .37207 Mdot
.42511 .74642 Mdot
.41124 .61843 Mdot
.30389 .69185 Mdot
.60863 .51772 Mdot
.22496 .49318 Mdot
.40545 .62215 Mdot
.7581 .71369 Mdot
.33225 .66913 Mdot
.55728 .33238 Mdot
.55888 .53269 Mdot
.57239 .30824 Mdot
.43405 .72965 Mdot
.39865 .64218 Mdot
.3914 .37061 Mdot
.58452 .45584 Mdot
.41535 .17575 Mdot
.35576 .59097 Mdot
.54156 .33136 Mdot
.55393 .54803 Mdot
.55238 .46133 Mdot
.62082 .55042 Mdot
.62091 .35198 Mdot
.46189 .67653 Mdot
.35811 .36808 Mdot
.36912 .35518 Mdot
.59108 .56966 Mdot
.42871 .74378 Mdot
.37098 .55883 Mdot
.38361 .59826 Mdot
.47689 .88006 Mdot
.36552 .53798 Mdot
.58897 .7106 Mdot
.6171 .53401 Mdot
.36704 .54292 Mdot
.57865 .23089 Mdot
.36839 .36365 Mdot
.64705 .55255 Mdot
.35541 .53684 Mdot
.29412 .34075 Mdot
.47702 .65127 Mdot
.58667 .54282 Mdot
.64358 .60954 Mdot
.37196 .34922 Mdot
.5575 .77153 Mdot
.35024 .59015 Mdot
.64948 .54923 Mdot
.34468 .36171 Mdot
.25586 .65836 Mdot
.43119 .19254 Mdot
.5652 .31312 Mdot
.3884 .63067 Mdot
.39486 .39044 Mdot
.55945 .60191 Mdot
.45664 .71473 Mdot
.37817 .62198 Mdot
.39846 .60868 Mdot
.57186 .5539 Mdot
.57729 .49108 Mdot
.592 .44906 Mdot
.54117 .33758 Mdot
.3524 .35597 Mdot
.64002 .56052 Mdot
.38676 .2881 Mdot
.6322 .58457 Mdot
.36185 .34616 Mdot
.90654 .46019 Mdot
.65771 .57051 Mdot
.61883 .55151 Mdot
.70869 .68057 Mdot
.56429 .30759 Mdot
.57752 .30927 Mdot
.25211 .34229 Mdot
.61649 .53397 Mdot
.36041 .68275 Mdot
.56944 .31306 Mdot
.56559 .36268 Mdot
.29196 .58951 Mdot
.59384 .57956 Mdot
.5508 .78816 Mdot
.39799 .35648 Mdot
.39642 .34799 Mdot
.57125 .36689 Mdot
.54819 .59116 Mdot
.41099 .37342 Mdot
.7391 .38584 Mdot
.35263 .57715 Mdot
.18453 .51219 Mdot
.54742 .35512 Mdot
.4425 .41462 Mdot
.36632 .36996 Mdot
.83848 .52107 Mdot
.3744 .46923 Mdot
.61475 .58634 Mdot
.60904 .529 Mdot
.45518 .73661 Mdot
.65898 .52211 Mdot
.35442 .5222 Mdot
.39035 .38824 Mdot
.73217 .64008 Mdot
.56021 .31713 Mdot
.62826 .55512 Mdot
.51859 .47397 Mdot
.49181 .26618 Mdot
.28763 .45717 Mdot
.57224 .3496 Mdot
.56386 .32825 Mdot
.36472 .6042 Mdot
.40492 .61652 Mdot
.59644 .55562 Mdot
.40275 .36702 Mdot
.53442 .35826 Mdot
.35998 .35052 Mdot
.37982 .61137 Mdot
.36887 .57358 Mdot
.34619 .49405 Mdot
.6248 .59668 Mdot
.3758 .56359 Mdot
.29003 .69154 Mdot
.38181 .28274 Mdot
.52554 .35866 Mdot
.46902 .16294 Mdot
.49281 .24842 Mdot
.60009 .66641 Mdot
.46233 .7368 Mdot
.35175 .52916 Mdot
.35781 .38734 Mdot
.58096 .5527 Mdot
.60377 .53739 Mdot
.33877 .50137 Mdot
.38223 .408 Mdot
.42806 .72313 Mdot
.3803 .40915 Mdot
.44985 .71004 Mdot
.38154 .55258 Mdot
.55231 .51893 Mdot
.60747 .50631 Mdot
.38848 .39106 Mdot
.36835 .56596 Mdot
.38831 .58833 Mdot
.46936 .71757 Mdot
.48125 .63202 Mdot
.38383 .60908 Mdot
.54828 .35558 Mdot
.74924 .45241 Mdot
.3338 .48585 Mdot
.62728 .54343 Mdot
.49383 .6742 Mdot
.69611 .32555 Mdot
.65307 .53773 Mdot
.3252 .48597 Mdot
.34813 .80445 Mdot
.63902 .5402 Mdot
.28177 .76174 Mdot
.33179 .50169 Mdot
.56157 .30721 Mdot
.39059 .62347 Mdot
.35505 .51876 Mdot
.59813 .61854 Mdot
.45921 .6863 Mdot
.6178 .49722 Mdot
.57212 .31065 Mdot
.5969 .32156 Mdot
.30215 .28825 Mdot
.7045 .73704 Mdot
.46751 .72001 Mdot
.43729 .70815 Mdot
.37424 .59327 Mdot
.54295 .83511 Mdot
.54206 .5213 Mdot
.42995 .71279 Mdot
.70431 .65307 Mdot
.57355 .54081 Mdot
.56128 .7168 Mdot
.38795 .47396 Mdot
.5776 .35947 Mdot
.59406 .43428 Mdot
.37904 .59048 Mdot
.54465 .32563 Mdot
.36449 .27213 Mdot
.58003 .49665 Mdot
.55862 .31544 Mdot
.36691 .34421 Mdot
.26115 .3979 Mdot
.58688 .32715 Mdot
.48826 .6752 Mdot
.4004 .36583 Mdot
.26283 .51974 Mdot
.68444 .67853 Mdot
.34262 .16894 Mdot
.39724 .38618 Mdot
.354 .56544 Mdot
.3465 .57258 Mdot
.38117 .59869 Mdot
.55487 .30979 Mdot
.39655 .57293 Mdot
.53982 .34652 Mdot
.60262 .79232 Mdot
.48278 .63271 Mdot
.43556 .70536 Mdot
.43042 .3367 Mdot
.56774 .33467 Mdot
.20371 .44813 Mdot
.38943 .1683 Mdot
.59532 .52238 Mdot
.35049 .34842 Mdot
.45492 .70311 Mdot
.72102 .76426 Mdot
.45096 .73928 Mdot
.35789 .60462 Mdot
.17904 .53205 Mdot
.62207 .56051 Mdot
.7771 .52239 Mdot
.46361 .7261 Mdot
.57951 .34465 Mdot
.59406 .56942 Mdot
.31383 .49092 Mdot
.45469 .72564 Mdot
.43032 .74961 Mdot
.59222 .55799 Mdot
.58824 .34201 Mdot
.3721 .57704 Mdot
.3569 .39012 Mdot
.47216 .71171 Mdot
.62684 .6263 Mdot
.65234 .51707 Mdot
.58388 .49897 Mdot
.49208 .44162 Mdot
.69434 .64247 Mdot
.39206 .38643 Mdot
.6305 .75507 Mdot
.40509 .61418 Mdot
.26128 .56301 Mdot
.26054 .33925 Mdot
.44943 .37329 Mdot
.34874 .51846 Mdot
.35064 .51275 Mdot
.58881 .54765 Mdot
.69462 .64346 Mdot
.21555 .61066 Mdot
.35603 .30947 Mdot
.33597 .48763 Mdot
.38621 .59583 Mdot
.60002 .31839 Mdot
.30664 .27378 Mdot
.65168 .50939 Mdot
.41545 .37621 Mdot
.38899 .61247 Mdot
.80098 .50372 Mdot
.44836 .722 Mdot
.19333 .48156 Mdot
.55552 .54782 Mdot
.6361 .57186 Mdot
.38503 .38221 Mdot
.38099 .34164 Mdot
.32673 .45267 Mdot
.29093 .29966 Mdot
.50908 .77695 Mdot
.53117 .22448 Mdot
.79782 .49385 Mdot
.60148 .31398 Mdot
.56373 .38314 Mdot
.3216 .47791 Mdot
.36667 .33774 Mdot
.63267 .53154 Mdot
.53672 .36184 Mdot
.28035 .46121 Mdot
.5456 .40292 Mdot
.57525 .71867 Mdot
.34288 .68922 Mdot
.56274 .51761 Mdot
.56256 .37541 Mdot
.55036 .31805 Mdot
.52988 .35141 Mdot
.32608 .4925 Mdot
.60769 .55651 Mdot
.59729 .58496 Mdot
.64222 .56776 Mdot
.66693 .61114 Mdot
.60365 .51607 Mdot
.38727 .30215 Mdot
.48275 .49026 Mdot
.75106 .62911 Mdot
.65349 .55554 Mdot
.40184 .35519 Mdot
.59358 .49752 Mdot
.42727 .74335 Mdot
.57752 .55254 Mdot
.57657 .71284 Mdot
.37449 .37055 Mdot
.51691 .52393 Mdot
.52493 .22176 Mdot
.55923 .55457 Mdot
.4162 .73586 Mdot
.65111 .65617 Mdot
.6085 .24669 Mdot
.44945 .63797 Mdot
.54907 .35715 Mdot
.34626 .55594 Mdot
.3763 .40215 Mdot
.3693 .58109 Mdot
.64939 .57161 Mdot
.32445 .47774 Mdot
.45881 .32835 Mdot
.43968 .41858 Mdot
.62913 .52053 Mdot
.54462 .49872 Mdot
.5565 .36306 Mdot
.35788 .56101 Mdot
.61008 .34114 Mdot
.62072 .52711 Mdot
.43884 .72883 Mdot
.45473 .72012 Mdot
.33349 .29339 Mdot
.81792 .47352 Mdot
.48574 .20541 Mdot
.38619 .3838 Mdot
.39374 .58641 Mdot
.46102 .74688 Mdot
.63667 .63377 Mdot
.41411 .35819 Mdot
.40414 .39315 Mdot
.39186 .36243 Mdot
.57789 .51145 Mdot
.35291 .52052 Mdot
.74862 .61243 Mdot
.35485 .52501 Mdot
.56165 .55633 Mdot
.40167 .60546 Mdot
.34878 .49954 Mdot
.45762 .7307 Mdot
.37506 .39587 Mdot
.38343 .61457 Mdot
.59107 .51507 Mdot
.57545 .32016 Mdot
.4804 .61077 Mdot
.5321 .66899 Mdot
.73009 .70492 Mdot
.7436 .68845 Mdot
.58927 .36137 Mdot
.82599 .52499 Mdot
.38447 .4194 Mdot
.67667 .31941 Mdot
.33712 .61659 Mdot
.6464 .51879 Mdot
.20231 .38316 Mdot
.35084 .59281 Mdot
.35756 .5589 Mdot
.58361 .53319 Mdot
.40224 .57728 Mdot
.62582 .55376 Mdot
.3969 .61915 Mdot
.43961 .64814 Mdot
.64991 .50409 Mdot
.37039 .56143 Mdot
.56211 .59363 Mdot
.58232 .5756 Mdot
.57731 .362 Mdot
.3946 .62694 Mdot
.64152 .57996 Mdot
.63305 .82616 Mdot
.37176 .34021 Mdot
.32589 .48936 Mdot
.48454 .74757 Mdot
.39324 .39196 Mdot
.5558 .32309 Mdot
.66483 .55604 Mdot
.44103 .74448 Mdot
.5754 .33488 Mdot
.44671 .66547 Mdot
.46387 .71938 Mdot
.20377 .40843 Mdot
.55249 .36376 Mdot
.33496 .48949 Mdot
.45732 .73714 Mdot
.5541 .48975 Mdot
.40145 .62999 Mdot
.5116 .63345 Mdot
.35017 .52383 Mdot
.60949 .54747 Mdot
.32165 .51048 Mdot
.36723 .33986 Mdot
.6184 .57833 Mdot
.4147 .62219 Mdot
.33073 .5042 Mdot
.57387 .51547 Mdot
.58159 .54793 Mdot
.34505 .24668 Mdot
.21462 .52941 Mdot
.42587 .73295 Mdot
.58355 .30258 Mdot
.59024 .52178 Mdot
.45472 .74337 Mdot
.34834 .74375 Mdot
.58986 .50082 Mdot
.54792 .31076 Mdot
.67928 .51443 Mdot
.40971 .61081 Mdot
.37093 .39068 Mdot
.37123 .62121 Mdot
.43875 .75179 Mdot
.13764 .5413 Mdot
.34531 .48899 Mdot
.57579 .59886 Mdot
.643 .53809 Mdot
.29467 .47224 Mdot
.54592 .32506 Mdot
.51239 .77381 Mdot
.61056 .53274 Mdot
.68709 .60747 Mdot
.63114 .56556 Mdot
.3371 .66578 Mdot
.56851 .36034 Mdot
.6157 .54885 Mdot
.5051 .53234 Mdot
.55012 .55866 Mdot
.42356 .74662 Mdot
.68861 .70641 Mdot
.60943 .50156 Mdot
.76927 .24585 Mdot
.37152 .54088 Mdot
.37237 .56156 Mdot
.30607 .4838 Mdot
.44202 .82534 Mdot
.47247 .1996 Mdot
.53921 .34525 Mdot
.49297 .34266 Mdot
.37091 .57906 Mdot
.52364 .20436 Mdot
.82548 .55151 Mdot
.57928 .57302 Mdot
.5703 .50746 Mdot
.35793 .60467 Mdot
.36368 .5399 Mdot
.32962 .47614 Mdot
.65112 .57239 Mdot
.55896 .47886 Mdot
.38744 .56931 Mdot
.59794 .51071 Mdot
.67546 .51556 Mdot
.35445 .38552 Mdot
.59115 .34563 Mdot
.36199 .36961 Mdot
.38179 .40062 Mdot
.7003 .38798 Mdot
.29141 .31048 Mdot
.36115 .34619 Mdot
.39382 .414 Mdot
.56276 .70982 Mdot
.60728 .44546 Mdot
.44335 .75481 Mdot
.79445 .59192 Mdot
.37665 .59896 Mdot
.60816 .55867 Mdot
.57923 .3788 Mdot
.687 .35924 Mdot
.3895 .49887 Mdot
.19003 .57497 Mdot
.62515 .52724 Mdot
.38244 .59094 Mdot
.33765 .51323 Mdot
.64462 .49693 Mdot
.2693 .57021 Mdot
.63113 .57861 Mdot
.38468 .62715 Mdot
.75301 .49487 Mdot
.52353 .47648 Mdot
.24278 .53772 Mdot
.58412 .40069 Mdot
.63791 .54962 Mdot
.5448 .34889 Mdot
.36754 .3781 Mdot
.43768 .74831 Mdot
.42735 .73427 Mdot
.58984 .56142 Mdot
.70073 .60708 Mdot
.39068 .46903 Mdot
.57966 .57524 Mdot
.57669 .56042 Mdot
.33301 .50352 Mdot
.57837 .5631 Mdot
.64342 .54114 Mdot
.64501 .56092 Mdot
.56297 .57679 Mdot
.40411 .35114 Mdot
.51807 .48159 Mdot
.62498 .59824 Mdot
.67039 .51399 Mdot
.35261 .38793 Mdot
.49852 .31604 Mdot
.36919 .39461 Mdot
.82315 .43186 Mdot
.36428 .35818 Mdot
.42532 .72201 Mdot
.32823 .528 Mdot
.69407 .53078 Mdot
.54153 .37598 Mdot
.39773 .34032 Mdot
.43746 .71753 Mdot
.38071 .38771 Mdot
.4024 .59995 Mdot
.58935 .18628 Mdot
.54452 .40182 Mdot
.50634 .75397 Mdot
.32208 .32924 Mdot
.23229 .48895 Mdot
.35469 .59297 Mdot
.57107 .36288 Mdot
.78275 .44148 Mdot
.6402 .57799 Mdot
.4592 .73383 Mdot
.59222 .554 Mdot
.40592 .3518 Mdot
.3806 .59454 Mdot
.67007 .73774 Mdot
.43267 .7416 Mdot
.38001 .21167 Mdot
.38663 .60195 Mdot
.61779 .59054 Mdot
.41538 .37459 Mdot
.45828 .16167 Mdot
.35965 .36842 Mdot
.48407 .63949 Mdot
.54994 .30343 Mdot
.65372 .45982 Mdot
.56233 .33539 Mdot
.3418 .46871 Mdot
.69138 .21506 Mdot
.78511 .64664 Mdot
.58116 .32828 Mdot
.24465 .58766 Mdot
.57061 .5097 Mdot
.58694 .49816 Mdot
.52324 .48764 Mdot
.55921 .30246 Mdot
.59684 .5188 Mdot
.33926 .51355 Mdot
.39844 .27013 Mdot
.27042 .62266 Mdot
.34748 .55486 Mdot
.62389 .54753 Mdot
.35015 .3816 Mdot
.38396 .40953 Mdot
.35292 .51271 Mdot
.36425 .39045 Mdot
.60007 .58482 Mdot
.56558 .3353 Mdot
.41845 .42755 Mdot
.4403 .73755 Mdot
.65359 .79339 Mdot
.44958 .75729 Mdot
.3479 .52663 Mdot
.58245 .47228 Mdot
.3686 .57286 Mdot
.21177 .72181 Mdot
.61259 .58503 Mdot
.56526 .31118 Mdot
.57571 .53262 Mdot
.63779 .55742 Mdot
.57919 .49829 Mdot
.39473 .57685 Mdot
.45546 .79164 Mdot
.5958 .51134 Mdot
.39121 .36918 Mdot
.76249 .64248 Mdot
.59404 .49614 Mdot
.43642 .64636 Mdot
.62942 .71785 Mdot
.22621 .46587 Mdot
.53999 .37929 Mdot
.36103 .56114 Mdot
.56384 .31931 Mdot
.5815 .39579 Mdot
.55554 .32313 Mdot
.76318 .59911 Mdot
.77671 .45722 Mdot
.33942 .79434 Mdot
.6996 .50204 Mdot
.66448 .34641 Mdot
.58116 .29778 Mdot
.34563 .76182 Mdot
.55254 .37982 Mdot
.54436 .33327 Mdot
.82222 .70436 Mdot
.55622 .38474 Mdot
.62118 .53982 Mdot
.60591 .4889 Mdot
.46522 .28182 Mdot
.54363 .71695 Mdot
.5851 .56656 Mdot
.58582 .52587 Mdot
.44537 .74707 Mdot
.69052 .62597 Mdot
.32531 .4732 Mdot
.20719 .40235 Mdot
.51896 .25483 Mdot
.59104 .55516 Mdot
.58919 .52006 Mdot
.54542 .50571 Mdot
.61157 .15047 Mdot
.71105 .37305 Mdot
.58865 .30137 Mdot
.5273 .54337 Mdot
.71775 .74249 Mdot
.58991 .58639 Mdot
.59274 .50372 Mdot
.56344 .52025 Mdot
.37161 .58034 Mdot
.58365 .29316 Mdot
.52765 .53924 Mdot
.22121 .43151 Mdot
.55293 .53431 Mdot
.44715 .36093 Mdot
.481 .8046 Mdot
.61845 .54368 Mdot
.52645 .34153 Mdot
.56808 .53659 Mdot
.55153 .36531 Mdot
.58096 .36113 Mdot
.54992 .5016 Mdot
.78987 .55246 Mdot
.54374 .31244 Mdot
.55777 .54818 Mdot
.37455 .56965 Mdot
.80084 .63206 Mdot
.60961 .54506 Mdot
.4218 .71627 Mdot
.61059 .53081 Mdot
.41532 .72654 Mdot
.57291 .56176 Mdot
.3548 .52681 Mdot
.68938 .30141 Mdot
.36947 .59054 Mdot
.51831 .8095 Mdot
.37692 .55174 Mdot
.34279 .24801 Mdot
.54887 .31156 Mdot
.33155 .50775 Mdot
.16901 .56636 Mdot
.32998 .49606 Mdot
.50047 .49971 Mdot
.47568 .54511 Mdot
.40435 .36983 Mdot
.58412 .31528 Mdot
.60969 .76121 Mdot
.28748 .46782 Mdot
.32111 .54118 Mdot
.34536 .53757 Mdot
.14631 .51207 Mdot
.16789 .50338 Mdot
.5878 .51266 Mdot
.76962 .54963 Mdot
.67227 .44388 Mdot
.59056 .50181 Mdot
.65949 .57327 Mdot
.41295 .6305 Mdot
.64073 .53165 Mdot
.49754 .42569 Mdot
.35807 .59183 Mdot
.4402 .7131 Mdot
.54534 .33843 Mdot
.41896 .71317 Mdot
.29868 .49397 Mdot
.47941 .5502 Mdot
.39427 .61655 Mdot
.55645 .5715 Mdot
.57771 .52886 Mdot
.56888 .37045 Mdot
.61019 .31193 Mdot
.5879 .3523 Mdot
.45806 .70374 Mdot
.36442 .59607 Mdot
.70456 .35753 Mdot
.59066 .53205 Mdot
.56862 .34195 Mdot
.32397 .36791 Mdot
.59148 .52595 Mdot
.37809 .39023 Mdot
.56134 .51477 Mdot
.58175 .32527 Mdot
.57833 .56337 Mdot
.56571 .33321 Mdot
.35082 .57397 Mdot
.58394 .58513 Mdot
.5852 .53726 Mdot
.45102 .16765 Mdot
.42822 .72587 Mdot
.55059 .31041 Mdot
.43536 .47453 Mdot
.62624 .58943 Mdot
.27051 .4943 Mdot
.63469 .53979 Mdot
.51105 .37302 Mdot
.56484 .59257 Mdot
.33161 .50308 Mdot
.66838 .52437 Mdot
.61042 .54589 Mdot
.49951 .57432 Mdot
.71273 .4938 Mdot
.60978 .32335 Mdot
.41309 .37031 Mdot
.52825 .33188 Mdot
.42415 .61796 Mdot
.34434 .5252 Mdot
.4153 .60512 Mdot
.52827 .7336 Mdot
.55183 .50078 Mdot
.62026 .5604 Mdot
.35771 .33162 Mdot
.44196 .70813 Mdot
.57253 .34752 Mdot
.44649 .71028 Mdot
.23372 .36781 Mdot
.46036 .70741 Mdot
.35481 .51973 Mdot
.33115 .6705 Mdot
.71937 .35023 Mdot
.44704 .7463 Mdot
.58951 .3494 Mdot
.33599 .68944 Mdot
.64807 .52594 Mdot
.47533 .69303 Mdot
.44049 .72906 Mdot
.13865 .49537 Mdot
.63518 .52593 Mdot
.50399 .48303 Mdot
.35493 .36249 Mdot
.45781 .71863 Mdot
.38258 .36009 Mdot
.58606 .56411 Mdot
.24723 .4576 Mdot
.53937 .33578 Mdot
.36036 .40362 Mdot
.64542 .59072 Mdot
.44726 .70187 Mdot
.39232 .6116 Mdot
.3928 .32107 Mdot
.40317 .35802 Mdot
.67854 .26837 Mdot
.67257 .72742 Mdot
.36201 .59404 Mdot
.22252 .59724 Mdot
.38702 .35397 Mdot
.59766 .50203 Mdot
.69437 .58486 Mdot
.61225 .58701 Mdot
.31431 .4971 Mdot
.36132 .56017 Mdot
.42571 .28192 Mdot
.576 .52705 Mdot
.63581 .53197 Mdot
.53877 .3029 Mdot
.35338 .58191 Mdot
.55553 .34933 Mdot
.53116 .35841 Mdot
.34955 .57281 Mdot
.55727 .33486 Mdot
.46251 .72645 Mdot
.41222 .25638 Mdot
.38643 .3527 Mdot
.38744 .3704 Mdot
.38543 .59649 Mdot
.37891 .56285 Mdot
.36599 .57142 Mdot
.56086 .51535 Mdot
.57184 .35395 Mdot
.56048 .53785 Mdot
.57517 .50142 Mdot
.58895 .40199 Mdot
.56176 .38883 Mdot
.56512 .52757 Mdot
.24863 .52955 Mdot
.44754 .67596 Mdot
.37909 .56832 Mdot
.35692 .35325 Mdot
.56527 .2244 Mdot
.3428 .34234 Mdot
.62642 .5478 Mdot
.29292 .35645 Mdot
.58404 .3346 Mdot
.45372 .73741 Mdot
.41717 .6963 Mdot
.44372 .74226 Mdot
.38966 .33029 Mdot
.53265 .34493 Mdot
.20713 .40503 Mdot
.62432 .55127 Mdot
.49115 .43913 Mdot
.6221 .75626 Mdot
.23964 .3735 Mdot
.35925 .34801 Mdot
.58948 .52416 Mdot
.32966 .49015 Mdot
.76812 .40536 Mdot
.63298 .57534 Mdot
.64822 .56356 Mdot
.3227 .61839 Mdot
.66573 .50279 Mdot
.54842 .30581 Mdot
.28937 .29352 Mdot
.60188 .48998 Mdot
.58108 .41771 Mdot
.51375 .86491 Mdot
.63204 .54846 Mdot
.61615 .52262 Mdot
.60037 .54287 Mdot
.57423 .53944 Mdot
.52739 .3291 Mdot
.56309 .76203 Mdot
.4156 .37172 Mdot
.48366 .45854 Mdot
.39042 .35239 Mdot
.38089 .62457 Mdot
.51425 .45908 Mdot
.59172 .32744 Mdot
.45442 .73801 Mdot
.72758 .31293 Mdot
.26209 .32136 Mdot
.36188 .60191 Mdot
.74677 .41362 Mdot
.43691 .73353 Mdot
.64556 .51374 Mdot
.41938 .70705 Mdot
.35875 .53694 Mdot
.39751 .36717 Mdot
.61947 .49013 Mdot
.57602 .37619 Mdot
.58549 .3236 Mdot
.59592 .52131 Mdot
.73455 .72629 Mdot
.37643 .39102 Mdot
.34009 .38319 Mdot
.57419 .51148 Mdot
.6484 .56454 Mdot
.55244 .3461 Mdot
.38288 .578 Mdot
.26961 .69169 Mdot
.4319 .71806 Mdot
.59791 .59578 Mdot
.57456 .54378 Mdot
.28855 .30891 Mdot
.38907 .39766 Mdot
.34186 .49096 Mdot
.57793 .51296 Mdot
.32687 .30042 Mdot
.57676 .51394 Mdot
.65227 .50245 Mdot
.37341 .57322 Mdot
.54309 .57252 Mdot
.6023 .50729 Mdot
.52788 .56697 Mdot
.3851 .35593 Mdot
.55872 .31355 Mdot
.53038 .31642 Mdot
.32732 .47903 Mdot
.377 .389 Mdot
.56623 .53045 Mdot
.38822 .39611 Mdot
.59501 .49918 Mdot
.59931 .51326 Mdot
.36125 .34679 Mdot
.55548 .3486 Mdot
.47685 .33408 Mdot
.51703 .47787 Mdot
.57365 .53461 Mdot
.64812 .50579 Mdot
.53719 .73077 Mdot
.21165 .67367 Mdot
.62674 .53001 Mdot
.58288 .32377 Mdot
.58762 .53202 Mdot
.37506 .36376 Mdot
.459 .7081 Mdot
.57812 .32169 Mdot
.39031 .58821 Mdot
.34819 .58712 Mdot
.52253 .2203 Mdot
.35103 .50922 Mdot
.65436 .52682 Mdot
.5108 .34055 Mdot
.57698 .38416 Mdot
.57678 .84401 Mdot
.34757 .57012 Mdot
.42935 .75234 Mdot
.5833 .55288 Mdot
.30409 .34956 Mdot
.36398 .32999 Mdot
.7617 .23503 Mdot
.20517 .409 Mdot
.44803 .75917 Mdot
.18374 .57381 Mdot
.33463 .49356 Mdot
.61845 .51101 Mdot
.43452 .74785 Mdot
.37349 .613 Mdot
.63592 .51083 Mdot
.64917 .60607 Mdot
.50244 .76831 Mdot
.39396 .63769 Mdot
.38125 .39612 Mdot
.41346 .60804 Mdot
.43682 .68994 Mdot
.35486 .52093 Mdot
.59028 .3312 Mdot
.6123 .54993 Mdot
.53623 .51698 Mdot
.38705 .58145 Mdot
.35628 .52801 Mdot
.56075 .52013 Mdot
.57727 .31112 Mdot
.41118 .59289 Mdot
.59373 .56266 Mdot
.67521 .32799 Mdot
.59013 .39316 Mdot
.37581 .6038 Mdot
.6424 .54389 Mdot
.62676 .45466 Mdot
.38898 .59469 Mdot
.38214 .56922 Mdot
.5961 .51871 Mdot
.46149 .73196 Mdot
.55124 .53076 Mdot
.36284 .3564 Mdot
.46017 .79337 Mdot
.37762 .36475 Mdot
.41184 .66489 Mdot
.60724 .468 Mdot
.24691 .48103 Mdot
.59407 .34502 Mdot
.43512 .6888 Mdot
.57589 .21811 Mdot
.65072 .55791 Mdot
.82019 .52146 Mdot
.45012 .41173 Mdot
.70123 .77246 Mdot
.70696 .25031 Mdot
.44316 .72598 Mdot
.37531 .38505 Mdot
.61537 .52288 Mdot
.34995 .34619 Mdot
.42808 .7407 Mdot
.62973 .76119 Mdot
.64354 .54568 Mdot
.56612 .36167 Mdot
.55385 .53106 Mdot
.54876 .35723 Mdot
.59372 .52601 Mdot
.66616 .50464 Mdot
.33134 .57025 Mdot
.4866 .6517 Mdot
.64751 .52093 Mdot
.58538 .18246 Mdot
.40248 .49263 Mdot
.43502 .72616 Mdot
.55856 .54309 Mdot
.34416 .50883 Mdot
.39129 .40722 Mdot
.61016 .65078 Mdot
.37048 .57656 Mdot
.35028 .3584 Mdot
.55209 .33512 Mdot
.34776 .56507 Mdot
.34609 .52225 Mdot
.54425 .58888 Mdot
.41687 .73313 Mdot
.40458 .37557 Mdot
.61337 .54456 Mdot
.63496 .52702 Mdot
.25084 .62006 Mdot
.39177 .51977 Mdot
.56512 .28581 Mdot
.39854 .188 Mdot
.5236 .35665 Mdot
.42963 .7151 Mdot
.37137 .57226 Mdot
.62802 .53271 Mdot
.61359 .57939 Mdot
.3336 .51548 Mdot
.55114 .31096 Mdot
.38466 .6308 Mdot
.71905 .3977 Mdot
.35882 .54887 Mdot
.5863 .74022 Mdot
.57045 .31173 Mdot
.58168 .74193 Mdot
.43441 .69068 Mdot
.80978 .4898 Mdot
.57213 .6828 Mdot
.35434 .36441 Mdot
.59142 .73992 Mdot
.58002 .34271 Mdot
.5824 .51807 Mdot
.33712 .49406 Mdot
.34781 .50022 Mdot
.54783 .34145 Mdot
.36273 .60927 Mdot
.4569 .71969 Mdot
.61435 .51939 Mdot
.20914 .47967 Mdot
.4729 .24912 Mdot
.3926 .58242 Mdot
.67999 .53855 Mdot
.3874 .36261 Mdot
.61245 .51118 Mdot
.42335 .71161 Mdot
.40061 .37995 Mdot
.36756 .52774 Mdot
.40998 .27064 Mdot
.58916 .56388 Mdot
.30895 .29407 Mdot
.38754 .39054 Mdot
.22045 .63057 Mdot
.5981 .56013 Mdot
.38696 .35413 Mdot
.6333 .47344 Mdot
.23849 .39056 Mdot
.43836 .44435 Mdot
.82413 .56639 Mdot
.3895 .63817 Mdot
.35449 .59967 Mdot
.2612 .41512 Mdot
.31193 .54862 Mdot
.34783 .36207 Mdot
.35484 .52196 Mdot
.65904 .68368 Mdot
.38444 .35924 Mdot
.57112 .50557 Mdot
.63363 .54266 Mdot
.69612 .38016 Mdot
.45996 .43719 Mdot
.35709 .5265 Mdot
.45032 .21095 Mdot
.62833 .58782 Mdot
.60957 .60924 Mdot
.61367 .57578 Mdot
.59609 .31801 Mdot
.40219 .38808 Mdot
.49436 .16461 Mdot
.36998 .38524 Mdot
.19845 .50152 Mdot
.3768 .59844 Mdot
.37583 .55863 Mdot
.62148 .54435 Mdot
.23877 .50168 Mdot
.70503 .63461 Mdot
.59322 .58386 Mdot
.25992 .51718 Mdot
.68289 .72166 Mdot
.64149 .5952 Mdot
.55193 .30111 Mdot
.59544 .48408 Mdot
.60175 .3574 Mdot
.39874 .35576 Mdot
.44924 .7257 Mdot
.46691 .69346 Mdot
.40346 .37416 Mdot
.61933 .562 Mdot
.26794 .52205 Mdot
.63421 .56799 Mdot
.58331 .51291 Mdot
.18896 .48181 Mdot
.45905 .74997 Mdot
.36177 .5702 Mdot
.42903 .73748 Mdot
.54398 .3329 Mdot
.92304 .5079 Mdot
.44624 .70723 Mdot
.71009 .5614 Mdot
.55609 .79389 Mdot
.58805 .74224 Mdot
.58509 .32124 Mdot
.46012 .69774 Mdot
.37154 .39023 Mdot
.7366 .75258 Mdot
.22827 .69433 Mdot
.33949 .36183 Mdot
.60025 .56705 Mdot
.59421 .32982 Mdot
.58821 .36082 Mdot
.365 .4096 Mdot
.5824 .35454 Mdot
.5538 .4825 Mdot
.57506 .52249 Mdot
.34833 .35995 Mdot
.46959 .26823 Mdot
.40501 .36069 Mdot
.39362 .25835 Mdot
.55617 .53701 Mdot
.57328 .31471 Mdot
.58034 .48358 Mdot
.53012 .38712 Mdot
.34053 .484 Mdot
.63243 .50716 Mdot
.45758 .72723 Mdot
.47939 .42723 Mdot
.37396 .60125 Mdot
.293 .36305 Mdot
.56631 .37047 Mdot
.38929 .42739 Mdot
.57847 .36131 Mdot
.59104 .31745 Mdot
.3815 .40102 Mdot
.53739 .35656 Mdot
.61651 .52182 Mdot
.2447 .5648 Mdot
.55115 .36845 Mdot
.37956 .37786 Mdot
.45013 .73317 Mdot
.5567 .33962 Mdot
.41159 .6324 Mdot
.58252 .54318 Mdot
.40188 .61742 Mdot
.33099 .57954 Mdot
.57899 .30988 Mdot
.46267 .70113 Mdot
.36345 .55799 Mdot
.4208 .73898 Mdot
.65822 .7581 Mdot
.37098 .33629 Mdot
.19414 .5775 Mdot
.60628 .44812 Mdot
.5762 .37723 Mdot
.33209 .57978 Mdot
.62606 .53362 Mdot
.58159 .54415 Mdot
.45017 .68939 Mdot
.58771 .36215 Mdot
.78443 .65622 Mdot
.5034 .34591 Mdot
.41654 .26139 Mdot
.38484 .336 Mdot
.41788 .19485 Mdot
.38951 .28696 Mdot
.53775 .82694 Mdot
.56313 .59961 Mdot
.33518 .49422 Mdot
.62801 .55985 Mdot
.5863 .22161 Mdot
.45222 .70221 Mdot
.29197 .73009 Mdot
.54625 .51343 Mdot
.36022 .57636 Mdot
.59591 .54815 Mdot
.52871 .62536 Mdot
.60156 .48064 Mdot
.46233 .73477 Mdot
.43968 .34413 Mdot
.54025 .37361 Mdot
.43874 .73649 Mdot
.34887 .58562 Mdot
.66134 .70211 Mdot
.63876 .51387 Mdot
.64629 .5808 Mdot
.3599 .54697 Mdot
.57061 .36152 Mdot
.38832 .62687 Mdot
.38685 .35286 Mdot
.44953 .71658 Mdot
.57987 .54968 Mdot
.55964 .58181 Mdot
.27285 .49735 Mdot
.40453 .38661 Mdot
.36301 .55306 Mdot
.36132 .37229 Mdot
.33547 .49343 Mdot
.63923 .50011 Mdot
.37971 .5603 Mdot
.63018 .5153 Mdot
.5232 .18894 Mdot
.19033 .49186 Mdot
.72334 .49951 Mdot
.35737 .57141 Mdot
.59926 .72411 Mdot
.37249 .36939 Mdot
.36301 .36164 Mdot
.62888 .43939 Mdot
.66596 .65315 Mdot
.35463 .68555 Mdot
.68786 .27136 Mdot
.38663 .35218 Mdot
.38053 .36752 Mdot
.3908 .62233 Mdot
.53932 .35715 Mdot
.60034 .35342 Mdot
.34244 .5856 Mdot
.49452 .67986 Mdot
.57243 .3474 Mdot
.81434 .53853 Mdot
.42373 .62028 Mdot
.57402 .60726 Mdot
.31408 .47075 Mdot
.45355 .72175 Mdot
.49156 .66875 Mdot
.52666 .62103 Mdot
.63062 .52796 Mdot
.29519 .28497 Mdot
.38109 .58071 Mdot
.53877 .76869 Mdot
.82053 .42569 Mdot
.64471 .54942 Mdot
.60548 .55898 Mdot
.6201 .56739 Mdot
.46692 .74126 Mdot
.61066 .25923 Mdot
.63053 .52451 Mdot
.4935 .68481 Mdot
.62061 .59211 Mdot
.53593 .6576 Mdot
.42727 .73471 Mdot
.61547 .37213 Mdot
.36695 .62645 Mdot
.21694 .41391 Mdot
.53039 .48039 Mdot
.37687 .35433 Mdot
.3357 .56384 Mdot
.39647 .35675 Mdot
.75932 .59249 Mdot
.57449 .68538 Mdot
.56487 .29135 Mdot
.62517 .52532 Mdot
.34664 .53502 Mdot
.5904 .35119 Mdot
.27393 .47508 Mdot
.85943 .65606 Mdot
.40931 .38272 Mdot
.22886 .73227 Mdot
.36127 .36513 Mdot
.3437 .48892 Mdot
.55137 .34437 Mdot
.77125 .46437 Mdot
.49192 .43795 Mdot
.55814 .33728 Mdot
.46548 .33067 Mdot
.52762 .37154 Mdot
.6004 .73025 Mdot
.55747 .39331 Mdot
.37597 .37558 Mdot
.37792 .32219 Mdot
.59664 .61162 Mdot
.61979 .53569 Mdot
.48015 .55603 Mdot
.68559 .50553 Mdot
.62201 .53367 Mdot
.35783 .59137 Mdot
.2107 .62562 Mdot
.33702 .57017 Mdot
.55576 .37833 Mdot
.41261 .38048 Mdot
.60338 .55683 Mdot
.57188 .52484 Mdot
.62148 .50695 Mdot
.43099 .16628 Mdot
.80758 .55221 Mdot
.59481 .5123 Mdot
.58591 .59166 Mdot
.35199 .57342 Mdot
.41188 .75617 Mdot
.62955 .22297 Mdot
.63547 .6832 Mdot
.62842 .58251 Mdot
.42897 .73261 Mdot
.44382 .75715 Mdot
.64114 .51344 Mdot
.21948 .47158 Mdot
.2418 .56833 Mdot
.61292 .54443 Mdot
.57124 .66983 Mdot
.30152 .50463 Mdot
.35346 .51339 Mdot
.38735 .58429 Mdot
.527 .34697 Mdot
.34776 .51846 Mdot
.38514 .55789 Mdot
.76988 .44152 Mdot
.32537 .47939 Mdot
.35657 .3032 Mdot
.45795 .70363 Mdot
.61986 .57833 Mdot
.52134 .35211 Mdot
.3233 .50517 Mdot
.40377 .37012 Mdot
.57216 .32572 Mdot
.39168 .40816 Mdot
.43121 .7626 Mdot
.51643 .75539 Mdot
.34748 .4961 Mdot
.37867 .3509 Mdot
.40818 .27043 Mdot
.42841 .73318 Mdot
.36352 .38787 Mdot
.25357 .48538 Mdot
.58881 .49468 Mdot
.79441 .47966 Mdot
.5771 .57579 Mdot
.73368 .73909 Mdot
.36648 .38994 Mdot
.32399 .48904 Mdot
.61842 .55666 Mdot
.38675 .60117 Mdot
.62397 .47226 Mdot
.62919 .58036 Mdot
.39419 .59423 Mdot
.58698 .51356 Mdot
.41985 .71934 Mdot
.59357 .38254 Mdot
.45158 .39561 Mdot
.20451 .32871 Mdot
.41747 .73018 Mdot
.27084 .47679 Mdot
.62634 .52898 Mdot
.67149 .7346 Mdot
.55788 .34059 Mdot
.64735 .55276 Mdot
.61197 .40311 Mdot
.54203 .35486 Mdot
.56486 .32204 Mdot
.57025 .55118 Mdot
.356 .36971 Mdot
.38507 .60481 Mdot
.43055 .73707 Mdot
.58348 .82965 Mdot
.60089 .5741 Mdot
.58617 .53485 Mdot
.43779 .73467 Mdot
.37914 .3658 Mdot
.57083 .52837 Mdot
.31909 .41482 Mdot
.65213 .81208 Mdot
.4001 .39787 Mdot
.57125 .49779 Mdot
.77226 .37537 Mdot
.51976 .3702 Mdot
.21951 .70599 Mdot
.42835 .67102 Mdot
.36385 .56223 Mdot
.66421 .50088 Mdot
.83903 .3377 Mdot
.45053 .72639 Mdot
.2118 .41029 Mdot
.58724 .509 Mdot
.59475 .53573 Mdot
.58633 .3423 Mdot
.56246 .53375 Mdot
.54696 .31866 Mdot
.17307 .38808 Mdot
.32813 .23074 Mdot
.56288 .36716 Mdot
.56442 .38402 Mdot
.6296 .44862 Mdot
.61964 .22253 Mdot
.54834 .33476 Mdot
.56074 .50314 Mdot
.78247 .62544 Mdot
.56013 .60455 Mdot
.45195 .68927 Mdot
.33055 .58894 Mdot
.62038 .33568 Mdot
.43347 .58081 Mdot
.50376 .31375 Mdot
.5235 .49482 Mdot
.37336 .46223 Mdot
.36381 .35198 Mdot
.64164 .57258 Mdot
.34992 .50503 Mdot
.40785 .58882 Mdot
.61033 .47953 Mdot
.62778 .57652 Mdot
.54926 .36171 Mdot
.46706 .73701 Mdot
.37711 .40446 Mdot
.58538 .52646 Mdot
.40881 .63739 Mdot
.43668 .7131 Mdot
.55655 .37649 Mdot
.65085 .46012 Mdot
.44761 .7521 Mdot
.66555 .51536 Mdot
.60693 .53113 Mdot
.56278 .51792 Mdot
.59826 .45126 Mdot
.38387 .34136 Mdot
.30638 .49162 Mdot
.55573 .51263 Mdot
.23776 .3623 Mdot
.47375 .62957 Mdot
.54685 .5724 Mdot
.57771 .34931 Mdot
.37209 .32946 Mdot
.33793 .48322 Mdot
.65681 .71917 Mdot
.59365 .56961 Mdot
.80457 .55639 Mdot
.71241 .38081 Mdot
.3451 .51585 Mdot
.57657 .29676 Mdot
.4518 .73941 Mdot
.60134 .58446 Mdot
.77049 .61412 Mdot
.6319 .54409 Mdot
.62927 .4585 Mdot
.3773 .57076 Mdot
.36427 .34992 Mdot
.68765 .78699 Mdot
.40643 .58645 Mdot
.56419 .32004 Mdot
.83176 .56051 Mdot
.59584 .35535 Mdot
.53745 .3663 Mdot
.78186 .56585 Mdot
.38433 .34316 Mdot
.82421 .31618 Mdot
.22359 .69478 Mdot
.54499 .54196 Mdot
.36997 .36559 Mdot
.55105 .3537 Mdot
.61264 .51166 Mdot
.57149 .38611 Mdot
.53567 .34032 Mdot
.62347 .50236 Mdot
.60092 .53196 Mdot
.51468 .47805 Mdot
.82552 .48131 Mdot
.44523 .74321 Mdot
.56459 .30733 Mdot
.66062 .35954 Mdot
.62749 .51885 Mdot
.6237 .5511 Mdot
.28409 .4758 Mdot
.46041 .73718 Mdot
.50766 .5824 Mdot
.57974 .51287 Mdot
.32661 .24683 Mdot
.64459 .50112 Mdot
.53567 .31378 Mdot
.39866 .39861 Mdot
.21714 .45904 Mdot
.3141 .4957 Mdot
.5552 .30685 Mdot
.43413 .70066 Mdot
.54142 .30183 Mdot
.70807 .54849 Mdot
.39198 .34827 Mdot
.58178 .32531 Mdot
.36737 .61705 Mdot
.39521 .37776 Mdot
.36378 .38738 Mdot
.76389 .64112 Mdot
.35429 .556 Mdot
.45174 .69777 Mdot
.39608 .36418 Mdot
.67472 .31718 Mdot
.37705 .38122 Mdot
.67216 .37276 Mdot
.57645 .57942 Mdot
.50448 .72413 Mdot
.40689 .2976 Mdot
.64772 .47862 Mdot
.38112 .33855 Mdot
.42998 .74142 Mdot
.57226 .54729 Mdot
.58356 .35249 Mdot
.44797 .70865 Mdot
.43437 .36015 Mdot
.38093 .56606 Mdot
.57608 .36721 Mdot
.41617 .37187 Mdot
.56528 .30881 Mdot
.59589 .76379 Mdot
.47707 .78694 Mdot
.31669 .39498 Mdot
.49598 .45094 Mdot
.61561 .50559 Mdot
.56934 .25341 Mdot
.65252 .51553 Mdot
.63157 .57499 Mdot
.37648 .6039 Mdot
.52772 .73514 Mdot
.55502 .34904 Mdot
.68908 .78879 Mdot
.37404 .34944 Mdot
.29856 .2704 Mdot
.5601 .42032 Mdot
.64555 .57271 Mdot
.54847 .36472 Mdot
.58855 .37193 Mdot
.71421 .49799 Mdot
.41607 .59809 Mdot
.65892 .59383 Mdot
.6606 .52032 Mdot
.5813 .60472 Mdot
.36627 .38904 Mdot
.2856 .37756 Mdot
.3725 .61758 Mdot
.35746 .813 Mdot
.38159 .57177 Mdot
.2954 .60391 Mdot
.53864 .36119 Mdot
.45831 .71005 Mdot
.62195 .54963 Mdot
.54904 .41825 Mdot
.56843 .29879 Mdot
.40975 .70893 Mdot
.45866 .72892 Mdot
.25995 .38754 Mdot
.36304 .34477 Mdot
.64507 .5219 Mdot
.64098 .53921 Mdot
.56118 .54361 Mdot
.56814 .56736 Mdot
.40864 .38614 Mdot
.57669 .50417 Mdot
.34567 .36943 Mdot
.68399 .33034 Mdot
.31339 .25123 Mdot
.34222 .52895 Mdot
.6364 .65286 Mdot
.57308 .37623 Mdot
.66021 .30167 Mdot
.68008 .57127 Mdot
.18711 .50946 Mdot
.70499 .72192 Mdot
.65883 .56136 Mdot
.37927 .61838 Mdot
.67459 .6407 Mdot
.35506 .5377 Mdot
.11498 .57607 Mdot
.28312 .51763 Mdot
.82398 .54559 Mdot
.61922 .51642 Mdot
.28542 .47583 Mdot
.68591 .56276 Mdot
.63076 .50353 Mdot
.29757 .52514 Mdot
.42029 .21541 Mdot
.45809 .29697 Mdot
.44497 .75565 Mdot
.58655 .55029 Mdot
.56163 .39468 Mdot
.61768 .52095 Mdot
.62758 .55351 Mdot
.59155 .50619 Mdot
.41318 .38751 Mdot
.61284 .48802 Mdot
.56216 .51188 Mdot
.41383 .53474 Mdot
.56645 .71759 Mdot
.4123 .6079 Mdot
.70597 .52001 Mdot
.44276 .70879 Mdot
.55641 .37026 Mdot
.50815 .41136 Mdot
.35418 .36265 Mdot
.68798 .46919 Mdot
.55624 .52202 Mdot
.40979 .29131 Mdot
.41619 .37076 Mdot
.45156 .71533 Mdot
.33104 .4804 Mdot
.80437 .61424 Mdot
.34765 .53114 Mdot
.32598 .47843 Mdot
.3727 .59945 Mdot
.62997 .30231 Mdot
.54771 .35922 Mdot
.6146 .50424 Mdot
.39154 .36367 Mdot
.38936 .6071 Mdot
.53561 .71698 Mdot
.61609 .57444 Mdot
.35301 .57694 Mdot
.60783 .50358 Mdot
.50602 .75083 Mdot
.2522 .63294 Mdot
.37078 .54773 Mdot
.40702 .33916 Mdot
.39023 .37779 Mdot
.46308 .7221 Mdot
.56151 .37406 Mdot
.58384 .33894 Mdot
.39938 .38071 Mdot
.18942 .64381 Mdot
.63221 .57932 Mdot
.61757 .51381 Mdot
.24113 .35766 Mdot
.61489 .52714 Mdot
.64588 .71169 Mdot
.32799 .47068 Mdot
.56493 .37754 Mdot
.60556 .50964 Mdot
.57211 .53277 Mdot
.58611 .55861 Mdot
.58948 .76697 Mdot
.38582 .57757 Mdot
.62117 .58834 Mdot
.44922 .74719 Mdot
.34398 .46606 Mdot
.62045 .51389 Mdot
.59112 .60575 Mdot
.58222 .33586 Mdot
.31012 .24205 Mdot
.35885 .35927 Mdot
.3597 .59695 Mdot
.36807 .55838 Mdot
.32701 .58218 Mdot
.59548 .39672 Mdot
.32733 .47334 Mdot
.43064 .8111 Mdot
.3273 .49419 Mdot
.43323 .72998 Mdot
.36265 .64977 Mdot
.43789 .62055 Mdot
.37626 .61257 Mdot
.38298 .41279 Mdot
.55248 .53555 Mdot
.61343 .58921 Mdot
.20431 .42059 Mdot
.6399 .58306 Mdot
.45405 .73266 Mdot
.34856 .37983 Mdot
.57823 .34106 Mdot
.45441 .71706 Mdot
.36281 .36751 Mdot
.57273 .35998 Mdot
.59662 .49442 Mdot
.58374 .49386 Mdot
.56893 .3257 Mdot
.58988 .35054 Mdot
.61284 .54025 Mdot
.35961 .4696 Mdot
.53044 .3586 Mdot
.57788 .31816 Mdot
.34908 .49785 Mdot
.34631 .53133 Mdot
.52927 .54661 Mdot
.36756 .36809 Mdot
.56698 .51431 Mdot
.34917 .53398 Mdot
.46705 .72508 Mdot
.55902 .34719 Mdot
.57313 .52995 Mdot
.58171 .52384 Mdot
.43162 .73649 Mdot
.45856 .74704 Mdot
.45618 .71574 Mdot
.34297 .36325 Mdot
.56992 .56359 Mdot
.55059 .33149 Mdot
.37003 .34258 Mdot
.44325 .75716 Mdot
.41384 .71855 Mdot
.44745 .54947 Mdot
.63029 .53325 Mdot
.43037 .44951 Mdot
.91655 .49671 Mdot
.6526 .69471 Mdot
.33856 .48289 Mdot
.35616 .54806 Mdot
.55726 .74368 Mdot
.25305 .59602 Mdot
.38684 .3926 Mdot
.67886 .66753 Mdot
.4364 .68825 Mdot
.6098 .50174 Mdot
.64708 .50486 Mdot
.66018 .57363 Mdot
.44241 .71535 Mdot
.61629 .75181 Mdot
.5924 .35633 Mdot
.64308 .4093 Mdot
.44314 .70911 Mdot
.37204 .54844 Mdot
.37741 .55702 Mdot
.38105 .57124 Mdot
.62116 .49247 Mdot
.70858 .48326 Mdot
.66354 .32472 Mdot
.62492 .24256 Mdot
.35383 .35199 Mdot
.57671 .28788 Mdot
.6592 .75308 Mdot
.56494 .32435 Mdot
.40414 .58194 Mdot
.43844 .71616 Mdot
.58542 .32943 Mdot
.40756 .37458 Mdot
.38257 .36709 Mdot
.38786 .57691 Mdot
.38411 .59664 Mdot
.40174 .61496 Mdot
.5301 .34533 Mdot
.5377 .35797 Mdot
.59546 .57424 Mdot
.56501 .33966 Mdot
.25409 .31128 Mdot
.45934 .75336 Mdot
.38236 .55998 Mdot
.37259 .38369 Mdot
.55077 .36062 Mdot
.61267 .57733 Mdot
.35613 .664 Mdot
.5119 .22576 Mdot
.42017 .7353 Mdot
.24342 .61849 Mdot
.13283 .60682 Mdot
.64101 .52411 Mdot
.38247 .39687 Mdot
.2115 .49663 Mdot
.61727 .56919 Mdot
.37406 .58009 Mdot
.54921 .1951 Mdot
.34442 .51961 Mdot
.57097 .50669 Mdot
.64275 .57988 Mdot
.36541 .39213 Mdot
.55768 .79649 Mdot
.59641 .57722 Mdot
.35878 .27528 Mdot
.40801 .39639 Mdot
.40727 .62511 Mdot
.6544 .81508 Mdot
.29994 .48905 Mdot
.49496 .6712 Mdot
.34657 .50043 Mdot
.63784 .55437 Mdot
.36374 .59822 Mdot
.42354 .73977 Mdot
.38457 .61194 Mdot
.56977 .29312 Mdot
.40933 .61168 Mdot
.58732 .53579 Mdot
.54831 .33181 Mdot
.3856 .39089 Mdot
.28492 .29586 Mdot
.40582 .53604 Mdot
.38689 .60052 Mdot
.34595 .48719 Mdot
.60807 .50737 Mdot
.50081 .53973 Mdot
.592 .46279 Mdot
.62356 .51769 Mdot
.39421 .35279 Mdot
.5496 .36807 Mdot
.39647 .34262 Mdot
.58314 .59867 Mdot
.39755 .21827 Mdot
.35931 .37084 Mdot
.43064 .3175 Mdot
.43594 .73303 Mdot
.48388 .5884 Mdot
.61366 .58052 Mdot
.3938 .36125 Mdot
.56832 .56183 Mdot
.56472 .3899 Mdot
.45593 .47123 Mdot
.30988 .45199 Mdot
.39099 .3649 Mdot
.77109 .67911 Mdot
.43309 .47968 Mdot
.57432 .48778 Mdot
.39031 .35453 Mdot
.62206 .38835 Mdot
.34503 .50064 Mdot
.43108 .72094 Mdot
.44427 .75682 Mdot
.42241 .74253 Mdot
.65344 .5645 Mdot
.64649 .60972 Mdot
.43647 .69699 Mdot
.39423 .40364 Mdot
.46309 .7343 Mdot
.5423 .427 Mdot
.77876 .66912 Mdot
.44376 .70091 Mdot
.59637 .56152 Mdot
.61519 .6099 Mdot
.56189 .71725 Mdot
.40353 .57945 Mdot
.82145 .5163 Mdot
.66154 .63036 Mdot
.62248 .53746 Mdot
.58605 .62017 Mdot
.59289 .3498 Mdot
.21775 .51987 Mdot
.68288 .50348 Mdot
.24857 .59955 Mdot
.55313 .38282 Mdot
.3315 .51114 Mdot
.56248 .37606 Mdot
.63782 .51897 Mdot
.60155 .51337 Mdot
.59733 .36429 Mdot
.29327 .33267 Mdot
.24689 .44538 Mdot
.65937 .78893 Mdot
.57938 .31747 Mdot
.38545 .35613 Mdot
.40999 .38185 Mdot
.35432 .35292 Mdot
.42367 .61758 Mdot
.57168 .30536 Mdot
.57808 .56908 Mdot
.35144 .57147 Mdot
.63861 .57374 Mdot
.39706 .37092 Mdot
.69614 .78175 Mdot
.58116 .33791 Mdot
.61117 .54575 Mdot
.22613 .68811 Mdot
.37766 .59158 Mdot
.42682 .72661 Mdot
.51311 .76246 Mdot
.42309 .62386 Mdot
.39626 .34694 Mdot
.59685 .3598 Mdot
.44828 .36834 Mdot
.48341 .39027 Mdot
.54089 .58121 Mdot
.53881 .54775 Mdot
.54769 .83469 Mdot
.36617 .51484 Mdot
.65052 .51805 Mdot
.34939 .58751 Mdot
.33412 .51728 Mdot
.57555 .53386 Mdot
.58833 .325 Mdot
.41685 .74382 Mdot
.45106 .7471 Mdot
.67317 .55036 Mdot
.49103 .44174 Mdot
.48249 .59395 Mdot
.56649 .5264 Mdot
.67825 .5366 Mdot
.36695 .55601 Mdot
.32505 .48848 Mdot
.27284 .32139 Mdot
.44056 .69887 Mdot
.58296 .50926 Mdot
.48315 .29941 Mdot
.53657 .34267 Mdot
.40616 .6148 Mdot
.39634 .34924 Mdot
.60818 .76712 Mdot
.3972 .63056 Mdot
.57499 .53124 Mdot
.57107 .5291 Mdot
.3631 .3877 Mdot
.5362 .31308 Mdot
.44056 .71702 Mdot
.35718 .56552 Mdot
.4398 .69835 Mdot
.54157 .33608 Mdot
.57845 .33729 Mdot
.56106 .60534 Mdot
.67734 .53713 Mdot
.38908 .5872 Mdot
.59861 .60063 Mdot
.38969 .56328 Mdot
.54754 .80328 Mdot
.39866 .34075 Mdot
.6422 .52785 Mdot
.5975 .30935 Mdot
.39887 .36804 Mdot
.59987 .53748 Mdot
.53382 .84765 Mdot
.64636 .56317 Mdot
.31873 .49725 Mdot
.37336 .23056 Mdot
.44319 .7466 Mdot
.72429 .5577 Mdot
.53374 .60011 Mdot
.61129 .52559 Mdot
.39188 .5716 Mdot
.6175 .4692 Mdot
.36081 .38037 Mdot
.54696 .37326 Mdot
.19457 .68212 Mdot
.38013 .3811 Mdot
.61414 .51696 Mdot
.45018 .71601 Mdot
.59332 .36348 Mdot
.34088 .51449 Mdot
.2273 .38279 Mdot
.61399 .47511 Mdot
.55915 .50136 Mdot
.57051 .50902 Mdot
.6274 .21392 Mdot
.36534 .60162 Mdot
.55054 .35672 Mdot
.36759 .3898 Mdot
.3998 .38394 Mdot
.38155 .57453 Mdot
.4456 .28799 Mdot
.47476 .57585 Mdot
.87479 .39431 Mdot
.39576 .59978 Mdot
.46607 .70383 Mdot
.50901 .45295 Mdot
.40211 .58293 Mdot
.35569 .58072 Mdot
.3626 .55662 Mdot
.37133 .30004 Mdot
.573 .35622 Mdot
.58234 .52146 Mdot
.53833 .37734 Mdot
.63885 .55444 Mdot
.49455 .63154 Mdot
.40167 .37046 Mdot
.5459 .37344 Mdot
.54724 .8407 Mdot
.51339 .36826 Mdot
.61011 .56604 Mdot
.63523 .77614 Mdot
.5755 .47101 Mdot
.60979 .73933 Mdot
.56074 .48553 Mdot
.37945 .6004 Mdot
.69316 .57567 Mdot
.58342 .60259 Mdot
.27221 .29936 Mdot
.37076 .38202 Mdot
.34275 .48558 Mdot
.65693 .54067 Mdot
.65397 .50602 Mdot
.57472 .39206 Mdot
.58479 .32683 Mdot
.44262 .69621 Mdot
.47251 .65191 Mdot
.38054 .39075 Mdot
.48412 .77952 Mdot
.61622 .53514 Mdot
.31006 .32426 Mdot
.6839 .48514 Mdot
.60092 .53898 Mdot
.78561 .61521 Mdot
.69946 .47717 Mdot
.60688 .58369 Mdot
.62961 .37028 Mdot
.37763 .36813 Mdot
.37078 .23609 Mdot
.56645 .57558 Mdot
.37249 .58034 Mdot
.54108 .36287 Mdot
.5955 .34233 Mdot
.42352 .70871 Mdot
.17203 .47433 Mdot
.38085 .33744 Mdot
.54174 .36808 Mdot
.62262 .57158 Mdot
.39068 .34451 Mdot
.35121 .51137 Mdot
.5693 .59157 Mdot
.69073 .65895 Mdot
.56785 .3399 Mdot
.58602 .59226 Mdot
.46042 .21914 Mdot
.48346 .66035 Mdot
.82282 .38421 Mdot
.35414 .35527 Mdot
.45288 .70594 Mdot
.54812 .49833 Mdot
.42602 .80595 Mdot
.653 .58006 Mdot
.50834 .72573 Mdot
.58473 .40988 Mdot
.45918 .70877 Mdot
.61241 .55996 Mdot
.58385 .56136 Mdot
.49688 .43339 Mdot
.46297 .74317 Mdot
.64433 .55339 Mdot
.68119 .60628 Mdot
.56944 .3613 Mdot
.33372 .474 Mdot
.57129 .34287 Mdot
.60023 .56651 Mdot
.63486 .61466 Mdot
.58764 .34356 Mdot
.45551 .80621 Mdot
.45915 .68667 Mdot
.35832 .3579 Mdot
.67534 .56845 Mdot
.56583 .56715 Mdot
.6291 .19289 Mdot
.34072 .48424 Mdot
.59976 .23355 Mdot
.40203 .63472 Mdot
.47962 .31838 Mdot
.2954 .47737 Mdot
.82683 .5744 Mdot
.29143 .29665 Mdot
.65523 .51537 Mdot
.58609 .66335 Mdot
.64149 .33844 Mdot
.39417 .34279 Mdot
.7187 .33909 Mdot
.62031 .53567 Mdot
.62854 .55604 Mdot
.39843 .62466 Mdot
.42556 .28566 Mdot
.21963 .47939 Mdot
.48323 .45127 Mdot
.43975 .7216 Mdot
.54774 .32245 Mdot
.59251 .52457 Mdot
.46582 .60901 Mdot
.40931 .60561 Mdot
.30627 .34404 Mdot
.61209 .5512 Mdot
.19094 .52266 Mdot
.38821 .30427 Mdot
.37741 .33986 Mdot
.37977 .56126 Mdot
.42244 .62873 Mdot
.63725 .54168 Mdot
.40311 .35841 Mdot
.59982 .57868 Mdot
.42653 .49189 Mdot
.61118 .5995 Mdot
.44222 .70261 Mdot
.60447 .50459 Mdot
.47126 .42153 Mdot
.84053 .44374 Mdot
.70634 .58393 Mdot
.59101 .32262 Mdot
.42152 .62111 Mdot
.38529 .57855 Mdot
.58436 .33088 Mdot
.38506 .58153 Mdot
.65883 .42831 Mdot
.75627 .48138 Mdot
.43888 .72623 Mdot
.68097 .55401 Mdot
.43204 .70458 Mdot
.3404 .48202 Mdot
.62786 .53612 Mdot
.42981 .81362 Mdot
.39302 .59933 Mdot
.46854 .17967 Mdot
.37872 .38426 Mdot
.34162 .48445 Mdot
.61843 .59245 Mdot
.35464 .64358 Mdot
.41175 .59694 Mdot
.32798 .50823 Mdot
.58777 .56185 Mdot
.58288 .34467 Mdot
.58022 .55486 Mdot
.5737 .47436 Mdot
.32941 .4783 Mdot
.55292 .53269 Mdot
.36288 .36755 Mdot
.52832 .33178 Mdot
.79964 .62818 Mdot
.31837 .49994 Mdot
.6344 .53044 Mdot
.62141 .57068 Mdot
.58024 .38354 Mdot
.59449 .59206 Mdot
.40859 .37241 Mdot
.64634 .13842 Mdot
.43521 .733 Mdot
.35644 .53094 Mdot
.30215 .49146 Mdot
.65809 .56631 Mdot
.56837 .53229 Mdot
.58149 .83256 Mdot
.30701 .43824 Mdot
.37273 .35649 Mdot
.64477 .48815 Mdot
.3534 .57177 Mdot
.45129 .71735 Mdot
.38318 .40618 Mdot
.56258 .51919 Mdot
.62148 .55342 Mdot
.44676 .70508 Mdot
.76737 .64628 Mdot
.24706 .60291 Mdot
.35101 .35716 Mdot
.69343 .56922 Mdot
.34951 .6714 Mdot
.63092 .57984 Mdot
.38943 .69155 Mdot
.57967 .32198 Mdot
.38449 .34791 Mdot
.6267 .23607 Mdot
.60236 .50223 Mdot
.40646 .38384 Mdot
.37734 .38919 Mdot
.54598 .5545 Mdot
.56685 .39981 Mdot
.53231 .33259 Mdot
.56012 .30969 Mdot
.27664 .26721 Mdot
.51838 .67055 Mdot
.40196 .61435 Mdot
.37844 .36702 Mdot
.3621 .54228 Mdot
.468 .7421 Mdot
.47428 .61871 Mdot
.36633 .5425 Mdot
.59036 .35413 Mdot
.37383 .55399 Mdot
.58318 .55731 Mdot
.38749 .39135 Mdot
.38055 .61522 Mdot
.65565 .54421 Mdot
.51411 .58551 Mdot
.41187 .47229 Mdot
.41308 .73338 Mdot
.42557 .68457 Mdot
.5978 .51663 Mdot
.33775 .48352 Mdot
.61475 .54178 Mdot
.34734 .36655 Mdot
.48961 .40911 Mdot
.65677 .56423 Mdot
.38837 .5955 Mdot
.62561 .63205 Mdot
.41896 .6032 Mdot
.62086 .47286 Mdot
.59791 .56181 Mdot
.63739 .56984 Mdot
.59859 .57906 Mdot
.44993 .31356 Mdot
.38258 .33516 Mdot
.52463 .60636 Mdot
.33788 .59092 Mdot
.56307 .33291 Mdot
.58484 .29666 Mdot
.34323 .69006 Mdot
.36611 .53798 Mdot
.36878 .36759 Mdot
.6216 .58255 Mdot
.3093 .48995 Mdot
.70527 .77495 Mdot
.45712 .80901 Mdot
.41249 .69781 Mdot
.3565 .59822 Mdot
.59321 .32365 Mdot
.41303 .6044 Mdot
.63617 .5489 Mdot
.54327 .53627 Mdot
.82118 .59549 Mdot
.40267 .33222 Mdot
.43954 .71551 Mdot
.63842 .56596 Mdot
.49396 .66458 Mdot
.35208 .57324 Mdot
.3617 .55466 Mdot
.64477 .56482 Mdot
.54676 .31048 Mdot
.75754 .2783 Mdot
.38011 .3397 Mdot
.64666 .64294 Mdot
.57895 .27173 Mdot
.38994 .23735 Mdot
.40343 .37796 Mdot
.39154 .47379 Mdot
.34527 .58562 Mdot
.73423 .56433 Mdot
.56664 .33086 Mdot
.43999 .7123 Mdot
.54177 .55381 Mdot
.58556 .36024 Mdot
.34195 .58399 Mdot
.56655 .38006 Mdot
.62811 .5077 Mdot
.39107 .33949 Mdot
.36725 .56165 Mdot
.39052 .33065 Mdot
.60153 .35488 Mdot
.42181 .72469 Mdot
.49325 .52814 Mdot
.75123 .37197 Mdot
.69574 .47421 Mdot
.61934 .58833 Mdot
.459 .61068 Mdot
.57002 .56175 Mdot
.56815 .39606 Mdot
.60837 .57801 Mdot
.60261 .27605 Mdot
.3813 .56399 Mdot
.58328 .59052 Mdot
.57371 .50538 Mdot
.71775 .3601 Mdot
.60429 .55371 Mdot
.54968 .53917 Mdot
.60812 .5848 Mdot
.60276 .29625 Mdot
.61249 .48474 Mdot
.5775 .35217 Mdot
.22528 .39284 Mdot
.3566 .58245 Mdot
.41307 .73726 Mdot
.44255 .75198 Mdot
.50299 .71395 Mdot
.48506 .64241 Mdot
.43875 .2911 Mdot
.56758 .35022 Mdot
.36411 .37739 Mdot
.6021 .58013 Mdot
.6646 .25943 Mdot
.31487 .54587 Mdot
.35074 .56718 Mdot
.31906 .49916 Mdot
.6189 .46029 Mdot
.62922 .2131 Mdot
.60896 .59591 Mdot
.20052 .41302 Mdot
.6624 .57649 Mdot
.64693 .55238 Mdot
.41898 .62847 Mdot
.48117 .6414 Mdot
.6244 .58823 Mdot
.57493 .39146 Mdot
.43469 .71151 Mdot
.50854 .32381 Mdot
.26355 .56014 Mdot
.37565 .472 Mdot
.75719 .4162 Mdot
.57671 .57178 Mdot
.36502 .56365 Mdot
.5755 .3674 Mdot
.27972 .31433 Mdot
.37094 .34278 Mdot
.39393 .29464 Mdot
.67809 .34242 Mdot
.59036 .80762 Mdot
.43718 .71291 Mdot
.76444 .64454 Mdot
.58689 .53406 Mdot
.42483 .61712 Mdot
.61757 .50084 Mdot
.70948 .77078 Mdot
.46229 .69962 Mdot
.55909 .30003 Mdot
.38368 .35613 Mdot
.56182 .39001 Mdot
.72481 .50385 Mdot
.34785 .43438 Mdot
.46809 .51165 Mdot
.34862 .53108 Mdot
.50635 .58489 Mdot
.54641 .34163 Mdot
.57315 .51661 Mdot
.89507 .43525 Mdot
.57781 .31923 Mdot
.55383 .30918 Mdot
.52262 .80683 Mdot
.52229 .81212 Mdot
.65093 .48725 Mdot
.57086 .38146 Mdot
.34683 .5418 Mdot
.4358 .74276 Mdot
.57941 .5604 Mdot
.5917 .57339 Mdot
.58582 .34216 Mdot
.40221 .57874 Mdot
.6593 .64241 Mdot
.3818 .59874 Mdot
.56943 .36353 Mdot
.36994 .59039 Mdot
.32746 .51981 Mdot
.36196 .6012 Mdot
.57258 .57658 Mdot
.60683 .57874 Mdot
.27403 .60611 Mdot
.57829 .33736 Mdot
.56636 .5368 Mdot
.59074 .51126 Mdot
.54935 .33536 Mdot
.40075 .63624 Mdot
.68576 .28162 Mdot
.62497 .52693 Mdot
.58517 .54543 Mdot
.45633 .70674 Mdot
.43465 .60741 Mdot
.24803 .64952 Mdot
.57227 .54774 Mdot
.46934 .71956 Mdot
.53053 .34967 Mdot
.61143 .54103 Mdot
.54026 .4295 Mdot
.33262 .51992 Mdot
.59729 .50292 Mdot
.34611 .51903 Mdot
.64686 .58098 Mdot
.77922 .31993 Mdot
.63188 .52308 Mdot
.55146 .35075 Mdot
.54174 .35719 Mdot
.53534 .79921 Mdot
.5635 .31799 Mdot
.34767 .50163 Mdot
.39585 .37465 Mdot
.72987 .74671 Mdot
.35163 .51419 Mdot
.64901 .55314 Mdot
.22362 .69518 Mdot
.57797 .59113 Mdot
.65764 .54774 Mdot
.59498 .20042 Mdot
.35145 .51607 Mdot
.54524 .35749 Mdot
.34287 .30859 Mdot
.66812 .56886 Mdot
.39482 .34707 Mdot
.55379 .58343 Mdot
.55583 .51516 Mdot
.34373 .26054 Mdot
.5355 .21195 Mdot
.35303 .38843 Mdot
.53572 .57746 Mdot
.57172 .54722 Mdot
.43113 .5685 Mdot
.61732 .57614 Mdot
.43519 .70129 Mdot
.55461 .3101 Mdot
.40424 .59543 Mdot
.43957 .73879 Mdot
.61459 .53079 Mdot
.44434 .71406 Mdot
.40245 .61598 Mdot
.39124 .35055 Mdot
.63349 .53927 Mdot
.45697 .6908 Mdot
.44064 .72021 Mdot
.56507 .55261 Mdot
.54338 .36899 Mdot
.70124 .55749 Mdot
.60842 .54026 Mdot
.57526 .51933 Mdot
.58375 .33917 Mdot
.38564 .82712 Mdot
.64044 .53243 Mdot
.42557 .45487 Mdot
.56495 .30042 Mdot
.31025 .46644 Mdot
.4023 .61984 Mdot
.55436 .5159 Mdot
.39832 .35423 Mdot
.40053 .36716 Mdot
.35084 .55006 Mdot
.56757 .39008 Mdot
.40899 .58753 Mdot
.6335 .62929 Mdot
.67658 .558 Mdot
.55937 .57576 Mdot
.17598 .63069 Mdot
.8157 .59051 Mdot
.5902 .3272 Mdot
.36963 .616 Mdot
.48451 .45728 Mdot
.37866 .3632 Mdot
.35695 .54431 Mdot
.59329 .36543 Mdot
.59506 .32992 Mdot
.57256 .3758 Mdot
.4594 .71539 Mdot
.37518 .62156 Mdot
.54269 .30695 Mdot
.54398 .31372 Mdot
.58552 .5592 Mdot
.57019 .54505 Mdot
.59026 .42412 Mdot
.59447 .71882 Mdot
.42148 .71849 Mdot
.37771 .57329 Mdot
.54032 .12982 Mdot
.34734 .3703 Mdot
.7211 .36546 Mdot
.65754 .56105 Mdot
.90167 .59443 Mdot
.61454 .5961 Mdot
.62294 .57357 Mdot
.52808 .34819 Mdot
.4438 .68906 Mdot
.42858 .71126 Mdot
.54522 .34261 Mdot
.60099 .35166 Mdot
.44047 .69995 Mdot
.72068 .71009 Mdot
.77781 .6742 Mdot
.34325 .29693 Mdot
.55264 .34192 Mdot
.76885 .40756 Mdot
.39893 .35047 Mdot
.60122 .36068 Mdot
.35307 .38058 Mdot
.35662 .57837 Mdot
.34415 .58467 Mdot
.36164 .38517 Mdot
.59036 .56523 Mdot
.39512 .6177 Mdot
.5846 .48736 Mdot
.74156 .69692 Mdot
.78551 .53353 Mdot
.2827 .42603 Mdot
.64903 .50682 Mdot
.22002 .46567 Mdot
.22949 .4836 Mdot
.60587 .52054 Mdot
.4933 .36376 Mdot
.44096 .71446 Mdot
.60662 .35345 Mdot
.40805 .37002 Mdot
.81617 .37194 Mdot
.62748 .58139 Mdot
.55484 .35221 Mdot
.36842 .37805 Mdot
.53995 .78628 Mdot
.36441 .27208 Mdot
.63967 .55824 Mdot
.85115 .35763 Mdot
.60939 .35428 Mdot
.40402 .59632 Mdot
.18737 .59387 Mdot
.53203 .36852 Mdot
.43009 .67436 Mdot
.34643 .59756 Mdot
.58381 .82158 Mdot
.55665 .36999 Mdot
.34054 .58209 Mdot
.54659 .3269 Mdot
.42747 .70633 Mdot
.58455 .40015 Mdot
.36154 .56072 Mdot
.60858 .55643 Mdot
.38253 .58299 Mdot
.42053 .72249 Mdot
.42275 .61207 Mdot
.40596 .36485 Mdot
.3433 .49117 Mdot
.38554 .37271 Mdot
.48108 .65757 Mdot
.43475 .19956 Mdot
.36349 .35016 Mdot
.51803 .78222 Mdot
.65087 .51763 Mdot
.52957 .32125 Mdot
.39716 .5965 Mdot
.33745 .58164 Mdot
.4949 .50256 Mdot
.55965 .3305 Mdot
.37646 .56862 Mdot
.6747 .33271 Mdot
.29668 .76514 Mdot
.64988 .60774 Mdot
.53487 .66859 Mdot
.55113 .33524 Mdot
.36147 .55216 Mdot
.24212 .35644 Mdot
.59075 .35592 Mdot
.39622 .60101 Mdot
.39088 .3574 Mdot
.40184 .38216 Mdot
.63934 .57555 Mdot
.33616 .32578 Mdot
.39502 .58133 Mdot
.23255 .4151 Mdot
.53752 .33822 Mdot
.54167 .78311 Mdot
.41667 .72359 Mdot
.35366 .58272 Mdot
.5775 .59975 Mdot
.51661 .32968 Mdot
.33324 .52608 Mdot
.6546 .65727 Mdot
.53245 .13554 Mdot
.38063 .57476 Mdot
.55225 .31191 Mdot
.558 .35086 Mdot
.58589 .46505 Mdot
.4939 .4425 Mdot
.41827 .60881 Mdot
.41188 .80322 Mdot
.5153 .73262 Mdot
.33501 .49224 Mdot
.24552 .50276 Mdot
.64002 .58403 Mdot
.56541 .55989 Mdot
.37847 .36128 Mdot
.60201 .55768 Mdot
.53457 .32363 Mdot
.61728 .59054 Mdot
.40209 .38907 Mdot
.34628 .57775 Mdot
.63056 .53984 Mdot
.4348 .7445 Mdot
.36229 .40457 Mdot
.36279 .38905 Mdot
.36418 .59346 Mdot
.57208 .37974 Mdot
.47566 .6942 Mdot
.38442 .59563 Mdot
.57958 .57386 Mdot
.33957 .51047 Mdot
.62085 .50679 Mdot
.73179 .66312 Mdot
.58603 .36674 Mdot
.40678 .58998 Mdot
.57855 .29772 Mdot
.38147 .37479 Mdot
.33904 .59231 Mdot
.60696 .5708 Mdot
.39495 .60345 Mdot
.25824 .58 Mdot
.74066 .67529 Mdot
.56955 .39067 Mdot
.26437 .51033 Mdot
.54826 .31277 Mdot
.33384 .48953 Mdot
.68903 .68617 Mdot
.43297 .72214 Mdot
.35579 .57106 Mdot
.81226 .57727 Mdot
.39042 .59433 Mdot
.60181 .55013 Mdot
.59691 .53175 Mdot
.39339 .6236 Mdot
.46112 .73355 Mdot
.31978 .23906 Mdot
.40341 .46006 Mdot
.54968 .36475 Mdot
.72504 .58543 Mdot
.59553 .15141 Mdot
.41837 .38406 Mdot
.37525 .3594 Mdot
.67009 .54212 Mdot
.64549 .57185 Mdot
.37128 .40089 Mdot
.4125 .38141 Mdot
.42203 .70678 Mdot
.35881 .5575 Mdot
.58131 .40483 Mdot
.40227 .40298 Mdot
.52458 .51262 Mdot
.48787 .64379 Mdot
.66206 .50456 Mdot
.59543 .62043 Mdot
.60129 .48995 Mdot
.50353 .7393 Mdot
.38893 .39757 Mdot
.59448 .51615 Mdot
.61574 .48063 Mdot
.3841 .35047 Mdot
.42932 .7053 Mdot
.51943 .20953 Mdot
.36972 .58424 Mdot
.53197 .86922 Mdot
.62455 .51149 Mdot
.60435 .54742 Mdot
.35497 .35064 Mdot
.42461 .57932 Mdot
.58592 .35482 Mdot
.57995 .37678 Mdot
.36936 .60505 Mdot
.48555 .542 Mdot
.59337 .58919 Mdot
.60271 .51857 Mdot
.36611 .57027 Mdot
.34246 .49015 Mdot
.26109 .41847 Mdot
.58137 .52667 Mdot
.3701 .378 Mdot
.33565 .56776 Mdot
.3943 .39659 Mdot
.63901 .51708 Mdot
.59934 .54704 Mdot
.57595 .58043 Mdot
.64639 .57032 Mdot
.35769 .38324 Mdot
.59238 .51926 Mdot
.6289 .60893 Mdot
.55859 .38096 Mdot
.56969 .56991 Mdot
.51036 .7388 Mdot
.59197 .55651 Mdot
.42507 .73361 Mdot
.45015 .63665 Mdot
.63847 .56863 Mdot
.56328 .56229 Mdot
.40668 .46058 Mdot
.61596 .5616 Mdot
.34763 .36754 Mdot
.56224 .33789 Mdot
.37911 .36676 Mdot
.36808 .39141 Mdot
.3454 .53598 Mdot
.42987 .70111 Mdot
.6622 .54995 Mdot
.42544 .74499 Mdot
.56269 .60135 Mdot
.62424 .50526 Mdot
.34496 .61625 Mdot
.19874 .41582 Mdot
.25191 .60774 Mdot
.60557 .57137 Mdot
.35874 .59316 Mdot
.40562 .59477 Mdot
.60075 .66002 Mdot
.59304 .48434 Mdot
.37558 .40444 Mdot
.39359 .36152 Mdot
.64974 .7055 Mdot
.34095 .26491 Mdot
.42229 .72422 Mdot
.46783 .61535 Mdot
.62582 .49296 Mdot
.5827 .51656 Mdot
.57221 .59313 Mdot
.36558 .54246 Mdot
.32479 .48183 Mdot
.3504 .56713 Mdot
.31942 .48559 Mdot
.40104 .39245 Mdot
.60809 .58838 Mdot
.80098 .50451 Mdot
.58821 .33265 Mdot
.56291 .33767 Mdot
.38699 .40441 Mdot
.40759 .58364 Mdot
.54508 .48738 Mdot
.2067 .71075 Mdot
.60455 .31097 Mdot
.41537 .71342 Mdot
.61002 .51967 Mdot
.36314 .59485 Mdot
.57992 .31453 Mdot
.46135 .73923 Mdot
.58916 .50586 Mdot
.41768 .6429 Mdot
.60181 .57304 Mdot
.64029 .33845 Mdot
.55243 .37487 Mdot
.72476 .76225 Mdot
.59418 .35871 Mdot
.36908 .41021 Mdot
.37185 .35056 Mdot
.59876 .53855 Mdot
.17976 .6211 Mdot
.52482 .33482 Mdot
.3426 .32435 Mdot
.45361 .69331 Mdot
.34082 .5171 Mdot
.46234 .70608 Mdot
.40064 .58117 Mdot
.43492 .7127 Mdot
.37073 .55968 Mdot
.63537 .70571 Mdot
.58876 .28358 Mdot
.43633 .73583 Mdot
.43822 .5516 Mdot
.61563 .48799 Mdot
.43477 .75588 Mdot
.63933 .59904 Mdot
.72956 .56715 Mdot
.36777 .57287 Mdot
.45943 .73578 Mdot
.57229 .5189 Mdot
.81445 .40134 Mdot
.36301 .36165 Mdot
.37131 .40254 Mdot
.56609 .49318 Mdot
.35764 .55684 Mdot
.58826 .38004 Mdot
.48774 .39417 Mdot
.31663 .46743 Mdot
.59847 .51796 Mdot
.6214 .58948 Mdot
.5845 .29588 Mdot
.56673 .28356 Mdot
.59688 .54244 Mdot
.6854 .31865 Mdot
.58747 .52817 Mdot
.40265 .3655 Mdot
.59354 .3414 Mdot
.55957 .34597 Mdot
.39049 .57379 Mdot
.54642 .38089 Mdot
.61566 .62442 Mdot
.45623 .38171 Mdot
.65427 .58524 Mdot
.38213 .38053 Mdot
.4773 .41254 Mdot
.31944 .49986 Mdot
.82093 .4853 Mdot
.59438 .30942 Mdot
.55252 .5389 Mdot
.5418 .32566 Mdot
.45576 .7229 Mdot
.57594 .33784 Mdot
.57538 .30642 Mdot
.6093 .53413 Mdot
.63783 .55526 Mdot
.34966 .51461 Mdot
.49377 .44856 Mdot
.54076 .36934 Mdot
.59554 .52143 Mdot
.57721 .58871 Mdot
.54834 .52945 Mdot
.44396 .45882 Mdot
.5888 .32281 Mdot
.69651 .38333 Mdot
.70238 .64851 Mdot
.54331 .37239 Mdot
.76121 .2987 Mdot
.33795 .51231 Mdot
.35904 .53318 Mdot
.41504 .34591 Mdot
.58064 .52606 Mdot
.38653 .62259 Mdot
.63585 .54785 Mdot
.58423 .6189 Mdot
.62437 .5534 Mdot
.46767 .72224 Mdot
.65466 .51497 Mdot
.34016 .49931 Mdot
.38563 .59217 Mdot
.61708 .5142 Mdot
.63003 .54254 Mdot
.38452 .55063 Mdot
.59975 .33818 Mdot
.58419 .35932 Mdot
.39994 .6974 Mdot
.44679 .72937 Mdot
.38898 .3473 Mdot
.60931 .58183 Mdot
.36092 .59672 Mdot
.383 .58528 Mdot
.55717 .39002 Mdot
.3746 .58218 Mdot
.36509 .34189 Mdot
.61072 .57189 Mdot
.3697 .40077 Mdot
.45668 .74074 Mdot
.56079 .30825 Mdot
.6218 .58381 Mdot
.58506 .5581 Mdot
.54186 .35728 Mdot
.65028 .51578 Mdot
.45585 .70621 Mdot
.38861 .58862 Mdot
.56338 .37118 Mdot
.3973 .3742 Mdot
.3869 .56725 Mdot
.5752 .54083 Mdot
.5233 .1364 Mdot
.59663 .55028 Mdot
.57598 .53065 Mdot
.80708 .63521 Mdot
.66432 .52702 Mdot
.39333 .58417 Mdot
.57766 .29281 Mdot
.571 .49469 Mdot
.50884 .6938 Mdot
.44743 .81427 Mdot
.34953 .54375 Mdot
.61846 .52053 Mdot
.82642 .49561 Mdot
.61917 .51771 Mdot
.4829 .7767 Mdot
.29684 .68688 Mdot
.51547 .60922 Mdot
.58609 .61642 Mdot
.35453 .36819 Mdot
.34915 .51107 Mdot
.38 .56363 Mdot
.62802 .42481 Mdot
.60487 .52848 Mdot
.62842 .35254 Mdot
.57833 .50393 Mdot
.40336 .38089 Mdot
.71075 .59039 Mdot
.37893 .5765 Mdot
.21137 .38566 Mdot
.5774 .56926 Mdot
.59167 .32723 Mdot
.3785 .55649 Mdot
.33682 .51229 Mdot
.573 .52801 Mdot
.43361 .74967 Mdot
.36201 .3236 Mdot
.6676 .57673 Mdot
.38685 .38266 Mdot
.58739 .51039 Mdot
.54948 .59898 Mdot
.16823 .53919 Mdot
.55622 .37758 Mdot
.38183 .35752 Mdot
.23663 .49639 Mdot
.64816 .51326 Mdot
.55901 .37163 Mdot
.56556 .3307 Mdot
.4183 .72169 Mdot
.4726 .48336 Mdot
.46093 .2272 Mdot
.7946 .44476 Mdot
.70812 .52022 Mdot
.36145 .54867 Mdot
.2494 .46053 Mdot
.57626 .55641 Mdot
.308 .37079 Mdot
.35013 .37919 Mdot
.60614 .55063 Mdot
.69153 .48941 Mdot
.56583 .30951 Mdot
.58431 .54019 Mdot
.43206 .7042 Mdot
.29645 .34982 Mdot
.30327 .37745 Mdot
.67835 .2351 Mdot
.34725 .54441 Mdot
.55108 .57502 Mdot
.60747 .62119 Mdot
.34508 .48625 Mdot
.60145 .49907 Mdot
.39259 .58694 Mdot
.6887 .73241 Mdot
.46513 .72489 Mdot
.5728 .3092 Mdot
.33741 .51184 Mdot
.58882 .49014 Mdot
.55888 .56722 Mdot
.4124 .73449 Mdot
.55634 .53323 Mdot
.17411 .47758 Mdot
.28406 .46575 Mdot
.38446 .61615 Mdot
.5691 .378 Mdot
.62211 .49299 Mdot
.32551 .47918 Mdot
.6043 .53249 Mdot
.76932 .50639 Mdot
.55446 .54421 Mdot
.43694 .22754 Mdot
.54063 .36261 Mdot
.38657 .38005 Mdot
.53931 .57332 Mdot
.62622 .55995 Mdot
.35285 .66743 Mdot
.57337 .61346 Mdot
.63129 .52071 Mdot
.5791 .38803 Mdot
.58959 .33032 Mdot
.57666 .35155 Mdot
.41059 .60954 Mdot
.32094 .30151 Mdot
.37241 .37459 Mdot
.63881 .58755 Mdot
.40017 .40493 Mdot
.67452 .63101 Mdot
.4117 .7289 Mdot
.77795 .35129 Mdot
.5545 .52498 Mdot
.57028 .35351 Mdot
.49516 .27706 Mdot
.53043 .34625 Mdot
.39547 .64138 Mdot
.38176 .39104 Mdot
.57211 .31298 Mdot
.62542 .56807 Mdot
.48304 .44002 Mdot
.70856 .27587 Mdot
.38441 .36548 Mdot
.60464 .60918 Mdot
.33997 .57066 Mdot
.30638 .49723 Mdot
.59073 .1348 Mdot
.37097 .35654 Mdot
.2354 .48115 Mdot
.60342 .52269 Mdot
.5885 .33715 Mdot
.35447 .35728 Mdot
.35993 .36156 Mdot
.3716 .5747 Mdot
.63831 .5595 Mdot
.63606 .56997 Mdot
.34344 .51712 Mdot
.39542 .3632 Mdot
.54903 .50386 Mdot
.58906 .60027 Mdot
.82117 .59791 Mdot
.60616 .42695 Mdot
.42572 .84915 Mdot
.64008 .62858 Mdot
.70586 .50199 Mdot
.51728 .44712 Mdot
.56287 .30356 Mdot
.63994 .56444 Mdot
.62003 .49493 Mdot
.39232 .57785 Mdot
.60382 .56255 Mdot
.41272 .62405 Mdot
.36769 .36423 Mdot
.75146 .29353 Mdot
.52396 .23187 Mdot
.68398 .72965 Mdot
.60691 .56171 Mdot
.36467 .25111 Mdot
.45091 .73654 Mdot
.3571 .40352 Mdot
.57348 .36329 Mdot
.64509 .516 Mdot
.41669 .59579 Mdot
.35461 .57168 Mdot
.57173 .32408 Mdot
.22047 .43296 Mdot
.37977 .68585 Mdot
.63964 .51713 Mdot
.40744 .6193 Mdot
.47193 .33272 Mdot
.67651 .30686 Mdot
.40071 .41051 Mdot
.4663 .71335 Mdot
.34996 .56879 Mdot
.39062 .40111 Mdot
.57105 .42281 Mdot
.56895 .3148 Mdot
.56892 .29131 Mdot
.3077 .66558 Mdot
.4193 .60897 Mdot
.43982 .74085 Mdot
.32555 .28988 Mdot
.31966 .28637 Mdot
.46707 .71836 Mdot
.3459 .58883 Mdot
.58552 .3217 Mdot
.55809 .36283 Mdot
.56132 .33866 Mdot
.221 .36953 Mdot
.57894 .38153 Mdot
.74214 .40787 Mdot
.57153 .58484 Mdot
.54631 .45901 Mdot
.6206 .52028 Mdot
.35614 .38519 Mdot
.55045 .37236 Mdot
.50827 .46265 Mdot
.65143 .555 Mdot
.69648 .25435 Mdot
.60148 .51693 Mdot
.39366 .41491 Mdot
.58038 .53377 Mdot
.73657 .366 Mdot
.56258 .30073 Mdot
.60306 .56713 Mdot
.3646 .33341 Mdot
.44378 .72133 Mdot
.56306 .40291 Mdot
.63802 .56825 Mdot
.4174 .27752 Mdot
.66828 .54177 Mdot
.70988 .72523 Mdot
.56848 .76936 Mdot
.41515 .71337 Mdot
.68267 .60672 Mdot
.3545 .55245 Mdot
.59738 .4039 Mdot
.67409 .5876 Mdot
.38561 .36659 Mdot
.51014 .19038 Mdot
.35189 .57799 Mdot
.70708 .57699 Mdot
.6263 .47472 Mdot
.43126 .70089 Mdot
.51797 .33554 Mdot
.34859 .36373 Mdot
.65543 .53701 Mdot
.54582 .55209 Mdot
.69853 .71988 Mdot
.67304 .5817 Mdot
.59944 .59302 Mdot
.41891 .74521 Mdot
.70394 .39292 Mdot
.58871 .5558 Mdot
.38675 .63324 Mdot
.5696 .29214 Mdot
.57061 .49144 Mdot
.69558 .3784 Mdot
.59633 .52229 Mdot
.57915 .32576 Mdot
.55854 .28895 Mdot
.47633 .26628 Mdot
.44675 .69171 Mdot
.55433 .5435 Mdot
.59576 .77908 Mdot
.57181 .56555 Mdot
.37309 .38127 Mdot
.6403 .5279 Mdot
.35818 .57334 Mdot
.21252 .39809 Mdot
.40248 .60874 Mdot
.63908 .54144 Mdot
.5577 .34124 Mdot
.35218 .36718 Mdot
.27683 .63264 Mdot
.32733 .69944 Mdot
.73619 .40382 Mdot
.54479 .84307 Mdot
.46165 .72562 Mdot
.46127 .74811 Mdot
.34911 .35411 Mdot
.60101 .56694 Mdot
.55447 .79327 Mdot
.6659 .56969 Mdot
.5838 .54388 Mdot
.62481 .55205 Mdot
.31645 .36719 Mdot
.37419 .36532 Mdot
.37549 .58931 Mdot
.59709 .54475 Mdot
.59363 .5214 Mdot
.54164 .33165 Mdot
.44198 .72215 Mdot
.40529 .60609 Mdot
.4391 .73052 Mdot
.38102 .60545 Mdot
.77516 .31264 Mdot
.61661 .60288 Mdot
.44599 .72228 Mdot
.34593 .37204 Mdot
.58418 .33899 Mdot
.3251 .47478 Mdot
.39731 .57692 Mdot
.3777 .57201 Mdot
.59979 .51871 Mdot
.58329 .33101 Mdot
.54498 .37806 Mdot
.45639 .72491 Mdot
.3722 .34442 Mdot
.63812 .54512 Mdot
.63381 .50872 Mdot
.56897 .64598 Mdot
.37413 .55015 Mdot
.66727 .31703 Mdot
.46314 .28943 Mdot
.60308 .57011 Mdot
.56819 .383 Mdot
.62404 .54304 Mdot
.80797 .52532 Mdot
.5896 .35519 Mdot
.64649 .55349 Mdot
.32541 .26551 Mdot
.34202 .5247 Mdot
.43064 .25375 Mdot
.571 .57775 Mdot
.59661 .83083 Mdot
.57068 .55282 Mdot
.83621 .54405 Mdot
.38701 .53112 Mdot
.607 .58938 Mdot
.57945 .55584 Mdot
.79291 .42292 Mdot
.61361 .52698 Mdot
.33514 .48855 Mdot
.7081 .58892 Mdot
.59501 .32747 Mdot
.5146 .46906 Mdot
.43457 .63285 Mdot
.45089 .69056 Mdot
.37025 .60583 Mdot
.25708 .51805 Mdot
.44131 .70198 Mdot
.55139 .34266 Mdot
.59811 .57925 Mdot
.48629 .56873 Mdot
.34141 .54329 Mdot
.59234 .46646 Mdot
.37547 .385 Mdot
.27767 .4941 Mdot
.40858 .62835 Mdot
.39323 .37656 Mdot
.56535 .50882 Mdot
.70853 .29868 Mdot
.27749 .6766 Mdot
.73487 .74945 Mdot
.35139 .35625 Mdot
.40499 .37667 Mdot
.25766 .33131 Mdot
.45858 .69445 Mdot
.71354 .67115 Mdot
.40206 .24177 Mdot
.3872 .34121 Mdot
.66525 .71642 Mdot
.35005 .56253 Mdot
.40561 .27227 Mdot
.60661 .3534 Mdot
.56145 .57951 Mdot
.6254 .56593 Mdot
.37547 .34514 Mdot
.55236 .42852 Mdot
.17393 .55936 Mdot
.38629 .37166 Mdot
.58703 .61207 Mdot
.44971 .49322 Mdot
.33432 .50463 Mdot
.35294 .52224 Mdot
.43776 .69357 Mdot
.40469 .7079 Mdot
.54243 .33631 Mdot
.42321 .70656 Mdot
.3002 .38108 Mdot
.55506 .52941 Mdot
.39203 .36622 Mdot
.32231 .48125 Mdot
.39918 .37916 Mdot
.43387 .70585 Mdot
.41842 .70825 Mdot
.55958 .38134 Mdot
.58472 .35637 Mdot
.70203 .49176 Mdot
.61856 .73024 Mdot
.61846 .51615 Mdot
.61066 .23936 Mdot
.53593 .34373 Mdot
.67932 .59178 Mdot
.46894 .72149 Mdot
.44487 .72518 Mdot
.63849 .36516 Mdot
.61374 .58466 Mdot
.52364 .79839 Mdot
.6157 .58266 Mdot
.67978 .67777 Mdot
.60563 .49795 Mdot
.37257 .5779 Mdot
.60511 .58666 Mdot
.47912 .71171 Mdot
.64082 .58294 Mdot
.63092 .51835 Mdot
.35442 .56046 Mdot
.6708 .56988 Mdot
.35834 .57216 Mdot
.64025 .54215 Mdot
.4712 .72954 Mdot
.36195 .59789 Mdot
.52939 .6825 Mdot
.4239 .45661 Mdot
.33965 .4894 Mdot
.42515 .73865 Mdot
.41753 .73219 Mdot
.4939 .68128 Mdot
.5721 .36474 Mdot
.52482 .3873 Mdot
.59923 .56387 Mdot
.36258 .55466 Mdot
.37558 .36171 Mdot
.59154 .52286 Mdot
.62686 .50201 Mdot
.58993 .59255 Mdot
.55287 .31342 Mdot
.41127 .59089 Mdot
.44714 .71699 Mdot
.40866 .6175 Mdot
.37334 .6682 Mdot
.4015 .63125 Mdot
.61431 .48242 Mdot
.53836 .5517 Mdot
.74285 .58428 Mdot
.58343 .2326 Mdot
.29983 .26394 Mdot
.56861 .31743 Mdot
.34559 .50826 Mdot
.42163 .70518 Mdot
.69921 .6083 Mdot
.57079 .35949 Mdot
.36017 .56149 Mdot
.60244 .57373 Mdot
.59272 .6093 Mdot
.42874 .35557 Mdot
.60875 .38618 Mdot
.52706 .7371 Mdot
.41463 .62715 Mdot
.33254 .49114 Mdot
.31468 .30226 Mdot
.69162 .51722 Mdot
.48971 .5242 Mdot
.61468 .54859 Mdot
.43699 .75047 Mdot
.57994 .31457 Mdot
.27548 .64901 Mdot
.39009 .35298 Mdot
.49359 .44428 Mdot
.60691 .56271 Mdot
.33298 .30543 Mdot
.55833 .33941 Mdot
.42581 .71021 Mdot
.37705 .34553 Mdot
.44485 .6884 Mdot
.35396 .52317 Mdot
.52296 .82194 Mdot
.56215 .55183 Mdot
.63079 .52252 Mdot
.38574 .41305 Mdot
.54639 .3292 Mdot
.42404 .68698 Mdot
.72623 .69559 Mdot
.39824 .62192 Mdot
.51367 .79943 Mdot
.52692 .33893 Mdot
.75985 .41431 Mdot
.40951 .61457 Mdot
.38793 .40428 Mdot
.48807 .67461 Mdot
.40129 .39031 Mdot
.63819 .5732 Mdot
.56465 .34986 Mdot
.36355 .36523 Mdot
.34003 .6554 Mdot
.83275 .4588 Mdot
.7682 .41441 Mdot
.5854 .58107 Mdot
.76874 .33072 Mdot
.76426 .67672 Mdot
.5268 .40266 Mdot
.40619 .36396 Mdot
.60676 .53837 Mdot
.57887 .49839 Mdot
.5817 .57314 Mdot
.36668 .38395 Mdot
.32806 .61447 Mdot
.37051 .56752 Mdot
.60841 .5164 Mdot
.4197 .71296 Mdot
.36095 .57768 Mdot
.33297 .56092 Mdot
.38869 .57719 Mdot
.58921 .31212 Mdot
.64733 .56286 Mdot
.40654 .30274 Mdot
.84889 .45178 Mdot
.38036 .3665 Mdot
.33981 .49007 Mdot
.61226 .50738 Mdot
.3998 .22105 Mdot
.57535 .35242 Mdot
.39587 .62223 Mdot
.60498 .54742 Mdot
.33292 .62973 Mdot
.40411 .57251 Mdot
.38511 .57466 Mdot
.56105 .36614 Mdot
.50973 .38793 Mdot
.60165 .5595 Mdot
.56772 .55043 Mdot
.5463 .33417 Mdot
.41167 .76936 Mdot
.22073 .3901 Mdot
.62799 .54303 Mdot
.38797 .37932 Mdot
.27677 .76829 Mdot
.55748 .56007 Mdot
.62273 .44383 Mdot
.35055 .52616 Mdot
.43772 .28161 Mdot
.66401 .31161 Mdot
.6882 .60378 Mdot
.79987 .42746 Mdot
.48002 .61553 Mdot
.75893 .30448 Mdot
.40387 .65726 Mdot
.40215 .50718 Mdot
.78488 .32621 Mdot
.36308 .33613 Mdot
.53347 .47149 Mdot
.63601 .64688 Mdot
.2106 .42381 Mdot
.53216 .42886 Mdot
.38666 .74889 Mdot
.34322 .67862 Mdot
.46654 .55279 Mdot
.39243 .59948 Mdot
.66593 .67096 Mdot
.63682 .54496 Mdot
.75917 .68453 Mdot
.69511 .32696 Mdot
.16955 .56676 Mdot
.77918 .34369 Mdot
.60026 .77601 Mdot
.7247 .29734 Mdot
.82068 .51714 Mdot
.73995 .5923 Mdot
.56774 .2419 Mdot
.39645 .81517 Mdot
.31136 .29217 Mdot
.62202 .77473 Mdot
.54946 .49292 Mdot
.46682 .60833 Mdot
.65441 .77317 Mdot
.74897 .44128 Mdot
.19099 .64363 Mdot
.39988 .58853 Mdot
.56699 .29538 Mdot
.61694 .65048 Mdot
.54888 .39608 Mdot
.38629 .42678 Mdot
.79977 .42056 Mdot
.82726 .55471 Mdot
.73087 .36222 Mdot
.59439 .83455 Mdot
.64817 .43168 Mdot
.24819 .28303 Mdot
.41705 .47674 Mdot
.55036 .29687 Mdot
.32858 .75579 Mdot
.32236 .28525 Mdot
.50079 .22853 Mdot
.63564 .63311 Mdot
.32485 .5548 Mdot
.5559 .7069 Mdot
.55458 .35101 Mdot
.66401 .29858 Mdot
.35995 .52592 Mdot
.51656 .21566 Mdot
.46097 .67187 Mdot
.81932 .46346 Mdot
.47256 .53352 Mdot
.40181 .27991 Mdot
.2488 .44499 Mdot
.526 .13626 Mdot
.6226 .74565 Mdot
.78219 .59546 Mdot
.42365 .392 Mdot
.5326 .42227 Mdot
.2007 .49058 Mdot
.59016 .7352 Mdot
.32417 .28029 Mdot
.54864 .1747 Mdot
.73282 .72971 Mdot
.59538 .17745 Mdot
.54035 .40029 Mdot
.59091 .59198 Mdot
.77584 .58006 Mdot
.70894 .52726 Mdot
.41586 .75487 Mdot
.65104 .21891 Mdot
.45237 .74642 Mdot
.54357 .39887 Mdot
.21691 .43164 Mdot
.74012 .38955 Mdot
.51323 .79168 Mdot
.43734 .67978 Mdot
.65373 .50932 Mdot
.11815 .44948 Mdot
.75096 .30103 Mdot
.46789 .26888 Mdot
.82249 .59619 Mdot
.32601 .31598 Mdot
.55085 .78249 Mdot
.36396 .37069 Mdot
.82629 .38768 Mdot
.56153 .35994 Mdot
.81862 .33234 Mdot
.83419 .43247 Mdot
.21209 .61486 Mdot
.15385 .66477 Mdot
.29985 .41647 Mdot
.51851 .60343 Mdot
.48585 .62382 Mdot
.52429 .70691 Mdot
.18044 .54239 Mdot
.21633 .64128 Mdot
.32133 .31602 Mdot
.61017 .80853 Mdot
.80206 .35772 Mdot
.67813 .70094 Mdot
.55673 .80979 Mdot
.20862 .45111 Mdot
.43666 .45326 Mdot
.52396 .3126 Mdot
.40873 .44331 Mdot
.58516 .25435 Mdot
.63773 .20933 Mdot
.69322 .50882 Mdot
.21396 .71938 Mdot
.46517 .68567 Mdot
.40102 .55851 Mdot
.79519 .62358 Mdot
.53805 .6778 Mdot
.71685 .60341 Mdot
.27592 .32381 Mdot
.63282 .48354 Mdot
.29113 .31093 Mdot
.50714 .2999 Mdot
.26203 .51168 Mdot
.3057 .30333 Mdot
.46051 .3379 Mdot
.70809 .71186 Mdot
.77926 .54428 Mdot
.34315 .25555 Mdot
.59631 .32898 Mdot
.56292 .7447 Mdot
.63995 .73575 Mdot
.81558 .6065 Mdot
.23665 .49563 Mdot
.75586 .73742 Mdot
.22553 .51783 Mdot
.65173 .58458 Mdot
.64904 .60996 Mdot
.53375 .5063 Mdot
.5976 .74338 Mdot
.58476 .59278 Mdot
.32525 .30715 Mdot
.81139 .62381 Mdot
.68053 .4807 Mdot
.2717 .53134 Mdot
.52466 .18928 Mdot
.73938 .73987 Mdot
.75325 .60722 Mdot
.36803 .50482 Mdot
.59359 .44419 Mdot
.32102 .22181 Mdot
.36382 .58676 Mdot
.6717 .71195 Mdot
.4106 .35336 Mdot
.30108 .66839 Mdot
.78522 .42273 Mdot
.21161 .60069 Mdot
.81174 .62669 Mdot
.22857 .38662 Mdot
.24592 .59962 Mdot
.48619 .6973 Mdot
.4999 .79274 Mdot
.55665 .20189 Mdot
.56245 .59535 Mdot
.55335 .61463 Mdot
.42744 .75094 Mdot
.73046 .51435 Mdot
.71015 .64894 Mdot
.33482 .72746 Mdot
.62979 .61432 Mdot
.26128 .68896 Mdot
.32998 .48711 Mdot
.489 .44211 Mdot
.64385 .1753 Mdot
.60183 .47265 Mdot
.30955 .43012 Mdot
.72036 .73719 Mdot
.55291 .76266 Mdot
.79084 .61096 Mdot
.43425 .31747 Mdot
.58645 .17946 Mdot
.84277 .46758 Mdot
.32677 .70808 Mdot
.72442 .26383 Mdot
.81484 .66013 Mdot
.55367 .16619 Mdot
.62924 .29679 Mdot
.35016 .34133 Mdot
.76511 .24014 Mdot
.35615 .60145 Mdot
.47427 .18387 Mdot
.70533 .5159 Mdot
.30662 .60051 Mdot
.58371 .39283 Mdot
.58741 .45723 Mdot
.46916 .55183 Mdot
.60758 .36752 Mdot
.58231 .4884 Mdot
.57163 .14934 Mdot
.50619 .16802 Mdot
.58818 .16161 Mdot
.68483 .77277 Mdot
.73411 .27189 Mdot
.53082 .62953 Mdot
.75156 .42164 Mdot
.63352 .66004 Mdot
.6405 .52345 Mdot
.63732 .69077 Mdot
.29741 .41985 Mdot
.26691 .66092 Mdot
.48476 .2249 Mdot
.56356 .39753 Mdot
.65422 .23484 Mdot
.5219 .10426 Mdot
.65481 .42611 Mdot
.66968 .38532 Mdot
.30518 .36415 Mdot
.62224 .73383 Mdot
.53539 .27589 Mdot
.24226 .64333 Mdot
.80465 .61749 Mdot
.64932 .64625 Mdot
.67531 .71968 Mdot
.35503 .74955 Mdot
.47298 .77586 Mdot
.43441 .57432 Mdot
.82263 .44675 Mdot
.53283 .64767 Mdot
.2192 .58836 Mdot
.50799 .49876 Mdot
.19315 .59233 Mdot
.37077 .70925 Mdot
.27286 .4831 Mdot
.63984 .75079 Mdot
.31187 .49707 Mdot
.66804 .69746 Mdot
.45425 .4869 Mdot
.68116 .64545 Mdot
.48037 .61405 Mdot
.67166 .69445 Mdot
.47166 .77464 Mdot
.66119 .21506 Mdot
.80829 .68648 Mdot
.44082 .16277 Mdot
.61041 .82517 Mdot
.49452 .3179 Mdot
.55522 .56569 Mdot
.79086 .65996 Mdot
.6284 .18375 Mdot
.84727 .48541 Mdot
.24025 .38746 Mdot
.33349 .64367 Mdot
.35914 .4035 Mdot
.44198 .16593 Mdot
.39267 .73363 Mdot
.81347 .55507 Mdot
.3053 .26211 Mdot
.413 .34339 Mdot
.19625 .42611 Mdot
.47488 .17673 Mdot
.76923 .39188 Mdot
.65295 .32548 Mdot
.59894 .46418 Mdot
.71742 .33765 Mdot
.58763 .30184 Mdot
.24214 .45026 Mdot
.59745 .73744 Mdot
.363 .59141 Mdot
.52278 .65448 Mdot
.58263 .63065 Mdot
.65568 .51549 Mdot
.44358 .62223 Mdot
.59542 .30147 Mdot
.5814 .23383 Mdot
.45139 .35524 Mdot
.75976 .28032 Mdot
.28608 .43253 Mdot
.54927 .60284 Mdot
.5735 .75857 Mdot
.25896 .60768 Mdot
.26584 .32909 Mdot
.38858 .33871 Mdot
.80251 .37892 Mdot
.39909 .4357 Mdot
.56742 .74683 Mdot
.70513 .32395 Mdot
.72319 .67771 Mdot
.5388 .54404 Mdot
.47855 .28225 Mdot
.75689 .51866 Mdot
.49259 .45437 Mdot
.52427 .37003 Mdot
.56392 .28071 Mdot
.67103 .82308 Mdot
.2919 .3689 Mdot
.26248 .47662 Mdot
.8087 .39187 Mdot
.38381 .39419 Mdot
.53387 .35983 Mdot
.65732 .68548 Mdot
.70911 .71692 Mdot
.753 .48689 Mdot
.41066 .58351 Mdot
.31516 .53943 Mdot
.35564 .72992 Mdot
.77262 .34115 Mdot
.74085 .30819 Mdot
.16559 .56545 Mdot
.56296 .39425 Mdot
.7374 .65808 Mdot
.67981 .72781 Mdot
.54157 .32184 Mdot
.56186 .40762 Mdot
.49055 .20956 Mdot
.70882 .23777 Mdot
.37348 .29776 Mdot
.59344 .82489 Mdot
.50172 .72939 Mdot
.33719 .62901 Mdot
.26732 .62323 Mdot
.5935 .79117 Mdot
.81131 .40153 Mdot
.65718 .28687 Mdot
.7549 .35722 Mdot
.53173 .5698 Mdot
.62107 .36886 Mdot
.42207 .16704 Mdot
.42957 .47049 Mdot
.7562 .40344 Mdot
.46624 .35257 Mdot
.57723 .5732 Mdot
.52832 .13704 Mdot
.73935 .70083 Mdot
.26761 .31431 Mdot
.34992 .33157 Mdot
.56809 .52934 Mdot
.60947 .60126 Mdot
.58568 .43691 Mdot
.45553 .27998 Mdot
.52462 .17908 Mdot
.59699 .79076 Mdot
.48635 .36034 Mdot
.69105 .32018 Mdot
.30972 .43123 Mdot
.8169 .47324 Mdot
.7763 .65524 Mdot
.47577 .47053 Mdot
.29191 .42091 Mdot
.4803 .66624 Mdot
.6268 .81223 Mdot
.46903 .58594 Mdot
.54928 .63712 Mdot
.41619 .22116 Mdot
.44417 .30092 Mdot
.26216 .6262 Mdot
.60339 .50449 Mdot
.22038 .4313 Mdot
.8191 .51329 Mdot
.1776 .63683 Mdot
.18955 .52149 Mdot
.54924 .13518 Mdot
.7752 .49223 Mdot
.43517 .30335 Mdot
.72931 .31499 Mdot
.17169 .6414 Mdot
.46234 .60624 Mdot
.69051 .25775 Mdot
.48363 .68183 Mdot
.79222 .36702 Mdot
.37871 .33037 Mdot
.36531 .27373 Mdot
.51905 .18861 Mdot
.72074 .25151 Mdot
.76048 .60872 Mdot
.81236 .43055 Mdot
.50395 .505 Mdot
.67901 .21189 Mdot
.41997 .21275 Mdot
.46513 .55727 Mdot
.34103 .57011 Mdot
.26536 .34569 Mdot
.65465 .25567 Mdot
.54593 .25725 Mdot
.67117 .71649 Mdot
.45282 .56852 Mdot
.70673 .60616 Mdot
.73475 .33834 Mdot
.56791 .68432 Mdot
.45475 .31086 Mdot
.57089 .75945 Mdot
.82586 .52261 Mdot
.45175 .59573 Mdot
.27288 .62192 Mdot
.30226 .44743 Mdot
.54074 .82298 Mdot
.45741 .27504 Mdot
.28704 .37351 Mdot
.78359 .59151 Mdot
.39189 .702 Mdot
.61062 .76633 Mdot
.76672 .7659 Mdot
.60877 .79535 Mdot
.54971 .22661 Mdot
.63179 .20882 Mdot
.79139 .63348 Mdot
.56925 .23127 Mdot
.17654 .52399 Mdot
.61056 .41169 Mdot
.6324 .70526 Mdot
.62522 .55369 Mdot
.63266 .17359 Mdot
.56758 .7041 Mdot
.63719 .2063 Mdot
.76928 .6967 Mdot
.71729 .3323 Mdot
.65735 .5164 Mdot
.41587 .63389 Mdot
.37017 .46497 Mdot
.57716 .68112 Mdot
.76394 .36338 Mdot
.61095 .4186 Mdot
.29046 .4793 Mdot
.34668 .48464 Mdot
.42926 .61442 Mdot
.50454 .34565 Mdot
.27745 .41715 Mdot
.45776 .29438 Mdot
.41333 .7635 Mdot
.48382 .50568 Mdot
.63813 .72803 Mdot
.66704 .31298 Mdot
.77441 .40499 Mdot
.20668 .59293 Mdot
.42711 .41681 Mdot
.39454 .5846 Mdot
.79363 .46652 Mdot
.62959 .78871 Mdot
.4673 .32271 Mdot
.57471 .18229 Mdot
.25504 .34794 Mdot
.63305 .67023 Mdot
.70301 .64287 Mdot
.18797 .56925 Mdot
.4136 .80944 Mdot
.62183 .22534 Mdot
.60646 .26989 Mdot
.52612 .79385 Mdot
.58103 .63366 Mdot
.77563 .31434 Mdot
.63361 .76277 Mdot
.72065 .62862 Mdot
.41558 .46387 Mdot
.73951 .4544 Mdot
.70648 .31306 Mdot
.51971 .67684 Mdot
.49674 .49609 Mdot
.26073 .26495 Mdot
.5963 .38271 Mdot
.50765 .12946 Mdot
.39681 .35751 Mdot
.21331 .36552 Mdot
.45839 .78038 Mdot
.45298 .47896 Mdot
.50139 .49021 Mdot
.48244 .27401 Mdot
.43572 .22689 Mdot
.65234 .78984 Mdot
.20065 .62461 Mdot
.3887 .62916 Mdot
.55841 .7974 Mdot
.50432 .82388 Mdot
.79605 .43173 Mdot
.61125 .48844 Mdot
.59891 .80451 Mdot
.4312 .46632 Mdot
.26479 .65668 Mdot
.77865 .67141 Mdot
.50682 .28095 Mdot
.57908 .61191 Mdot
.61706 .73451 Mdot
.68896 .25897 Mdot
.83712 .4555 Mdot
.17782 .46032 Mdot
.50611 .30113 Mdot
.34619 .35382 Mdot
.50286 .60775 Mdot
.77892 .3633 Mdot
.53203 .77454 Mdot
.38719 .28262 Mdot
.63241 .74361 Mdot
.41153 .14667 Mdot
.54363 .18249 Mdot
.52363 .17932 Mdot
.56311 .77305 Mdot
.53737 .38227 Mdot
.46676 .19804 Mdot
.70957 .63632 Mdot
.50726 .27272 Mdot
.66958 .76536 Mdot
.66195 .71596 Mdot
.14803 .54458 Mdot
.73295 .58646 Mdot
.37729 .66887 Mdot
.68695 .29323 Mdot
.71639 .52212 Mdot
.3511 .33468 Mdot
.61756 .70212 Mdot
.47055 .35583 Mdot
.3709 .4115 Mdot
.45755 .30704 Mdot
.41834 .27377 Mdot
.72462 .6252 Mdot
.75848 .47431 Mdot
.48333 .34576 Mdot
.79578 .5056 Mdot
.60292 .38663 Mdot
.27624 .64854 Mdot
.26632 .60412 Mdot
.49975 .40253 Mdot
.37472 .61244 Mdot
.68556 .60643 Mdot
.49007 .46752 Mdot
.46727 .6387 Mdot
.40498 .18568 Mdot
.44844 .75032 Mdot
.54389 .38323 Mdot
.24758 .31818 Mdot
.53897 .32227 Mdot
.59549 .15509 Mdot
.23776 .63174 Mdot
.70496 .3268 Mdot
.33864 .70721 Mdot
.33223 .74797 Mdot
.16595 .38917 Mdot
.6126 .25615 Mdot
.40521 .45552 Mdot
.60628 .28766 Mdot
.58734 .36914 Mdot
.29812 .48467 Mdot
.34812 .49048 Mdot
.65366 .34292 Mdot
.33306 .44079 Mdot
.63172 .66425 Mdot
.53507 .30823 Mdot
.37516 .65824 Mdot
.70855 .57568 Mdot
.72311 .2491 Mdot
.3947 .59533 Mdot
.32293 .21001 Mdot
.62651 .60477 Mdot
.76381 .55841 Mdot
.80865 .64135 Mdot
.1853 .43943 Mdot
.24407 .56825 Mdot
.43674 .8159 Mdot
.65715 .57216 Mdot
.48716 .33935 Mdot
.55357 .35503 Mdot
.70831 .66415 Mdot
.43542 .71496 Mdot
.53883 .74122 Mdot
.39894 .40621 Mdot
.22224 .59126 Mdot
.27313 .42342 Mdot
.52397 .35839 Mdot
.52086 .27748 Mdot
.73855 .62948 Mdot
.38116 .26035 Mdot
.43336 .46404 Mdot
.79333 .42952 Mdot
.7531 .4745 Mdot
.5395 .30309 Mdot
.57681 .19216 Mdot
.66863 .73225 Mdot
.82947 .38466 Mdot
.5348 .4898 Mdot
.40775 .48609 Mdot
.36305 .25657 Mdot
.47111 .29864 Mdot
.6607 .3165 Mdot
.80674 .61371 Mdot
.57615 .74044 Mdot
.34001 .27914 Mdot
.66833 .69304 Mdot
.65801 .49254 Mdot
.4718 .51015 Mdot
.24088 .42308 Mdot
.1474 .49523 Mdot
.63318 .34366 Mdot
.19521 .47001 Mdot
.5995 .27192 Mdot
.30767 .42867 Mdot
.60374 .37458 Mdot
.28505 .59908 Mdot
.74956 .45035 Mdot
.24095 .52235 Mdot
.79946 .34053 Mdot
.80657 .61828 Mdot
.41856 .34365 Mdot
.31983 .52691 Mdot
.52945 .45332 Mdot
.52468 .54469 Mdot
.49886 .43098 Mdot
.61414 .59083 Mdot
.54585 .41235 Mdot
.19507 .41465 Mdot
.49552 .27776 Mdot
.59652 .45939 Mdot
.76711 .31096 Mdot
.83238 .39699 Mdot
.67245 .21102 Mdot
.51003 .79798 Mdot
.56962 .30381 Mdot
.55708 .16169 Mdot
.67708 .35505 Mdot
.82985 .51511 Mdot
.61744 .22874 Mdot
.69543 .80547 Mdot
.76276 .36606 Mdot
.46369 .3525 Mdot
.21267 .63088 Mdot
.4407 .23711 Mdot
.75742 .69356 Mdot
.46362 .56303 Mdot
.27878 .51374 Mdot
.7563 .70002 Mdot
.13057 .42688 Mdot
.62162 .28225 Mdot
.41004 .27762 Mdot
.58915 .6398 Mdot
.48816 .38539 Mdot
.38129 .50403 Mdot
.6391 .52583 Mdot
.33483 .53066 Mdot
.24879 .60575 Mdot
.64458 .72585 Mdot
.70416 .61917 Mdot
.38269 .50763 Mdot
.58308 .67932 Mdot
.68373 .67107 Mdot
.61742 .77938 Mdot
.77761 .39771 Mdot
.65665 .33758 Mdot
.56597 .6041 Mdot
.58181 .40517 Mdot
.45105 .6946 Mdot
.2545 .53467 Mdot
.64318 .55463 Mdot
.24311 .53034 Mdot
.40887 .24272 Mdot
.55492 .14065 Mdot
.27847 .56659 Mdot
.7255 .70771 Mdot
.60697 .34439 Mdot
.46411 .28111 Mdot
.79946 .52335 Mdot
.21298 .42463 Mdot
.4026 .53187 Mdot
.69491 .51093 Mdot
.75954 .31373 Mdot
.30546 .30811 Mdot
.70836 .70011 Mdot
.37056 .22025 Mdot
.36074 .39877 Mdot
.6277 .31985 Mdot
.58103 .6418 Mdot
.23818 .37944 Mdot
.51775 .34474 Mdot
.45363 .338 Mdot
.42726 .51185 Mdot
.2979 .31331 Mdot
.7218 .73779 Mdot
.73197 .65123 Mdot
.67376 .28054 Mdot
.74578 .31049 Mdot
.35088 .53938 Mdot
.67962 .71739 Mdot
.45186 .34326 Mdot
.40791 .52059 Mdot
.34419 .26001 Mdot
.76201 .28986 Mdot
.50394 .44334 Mdot
.54897 .70069 Mdot
.56714 .55519 Mdot
.69802 .38224 Mdot
.49407 .27143 Mdot
.47387 .75415 Mdot
.27588 .4623 Mdot
.58771 .35697 Mdot
.2629 .44499 Mdot
.42965 .59195 Mdot
.61391 .71123 Mdot
.5974 .28474 Mdot
.63948 .44983 Mdot
.42811 .761 Mdot
.31084 .47213 Mdot
.55237 .50386 Mdot
.54125 .71054 Mdot
.50882 .78649 Mdot
.6282 .31231 Mdot
.60278 .24915 Mdot
.79405 .43874 Mdot
.69966 .72829 Mdot
.47854 .31003 Mdot
.61447 .22382 Mdot
.44623 .22442 Mdot
.76235 .44062 Mdot
.2236 .47453 Mdot
.5858 .59105 Mdot
.28685 .59965 Mdot
.5309 .3565 Mdot
.78382 .38195 Mdot
.77098 .50033 Mdot
.53056 .68178 Mdot
.46068 .452 Mdot
.796 .54176 Mdot
.45108 .43373 Mdot
.80055 .64937 Mdot
.44412 .2364 Mdot
.59567 .73692 Mdot
.41614 .35444 Mdot
.49014 .71359 Mdot
.18592 .55134 Mdot
.82371 .39652 Mdot
.20745 .60286 Mdot
.48829 .56383 Mdot
.19409 .45763 Mdot
.52523 .20814 Mdot
.76527 .69576 Mdot
.61232 .72664 Mdot
.49671 .42917 Mdot
.70578 .57309 Mdot
.43159 .36536 Mdot
.32606 .47505 Mdot
.29448 .61818 Mdot
.66228 .35289 Mdot
.31055 .56654 Mdot
.23633 .54947 Mdot
.54026 .514 Mdot
.37464 .2335 Mdot
.75084 .31068 Mdot
.72412 .58679 Mdot
.44102 .48014 Mdot
.29732 .67891 Mdot
.59828 .71489 Mdot
.5204 .87721 Mdot
.52631 .13561 Mdot
.56519 .55297 Mdot
.47866 .60836 Mdot
.54919 .73299 Mdot
.40593 .62735 Mdot
.6506 .37152 Mdot
.79472 .42083 Mdot
.40583 .37309 Mdot
.32426 .63951 Mdot
.29443 .31966 Mdot
.48842 .26559 Mdot
.51637 .66166 Mdot
.31624 .34949 Mdot
.57439 .14411 Mdot
.63358 .79169 Mdot
.48141 .29154 Mdot
.58027 .86424 Mdot
.23191 .41694 Mdot
.57297 .27715 Mdot
.77646 .58926 Mdot
.66306 .21487 Mdot
.55798 .7648 Mdot
.3071 .66608 Mdot
.57555 .21914 Mdot
.58766 .73656 Mdot
.68857 .68174 Mdot
.30182 .44706 Mdot
.26672 .44946 Mdot
.45905 .52157 Mdot
.33413 .74876 Mdot
.42768 .18946 Mdot
.67286 .29817 Mdot
.72068 .28332 Mdot
.2336 .59102 Mdot
.14977 .56024 Mdot
.82609 .38691 Mdot
.61832 .69011 Mdot
.37484 .5021 Mdot
.77399 .60215 Mdot
.51377 .73308 Mdot
.6877 .49919 Mdot
.23727 .61804 Mdot
.74585 .49095 Mdot
.30743 .72734 Mdot
.20914 .5102 Mdot
.66927 .69612 Mdot
.70793 .51057 Mdot
.50571 .44954 Mdot
.78978 .44445 Mdot
.28952 .46166 Mdot
.58277 .76326 Mdot
.33139 .65424 Mdot
.50914 .70526 Mdot
.79768 .46193 Mdot
.79707 .56176 Mdot
.50442 .42747 Mdot
.14038 .41217 Mdot
.6536 .22621 Mdot
.21301 .44561 Mdot
.56915 .58194 Mdot
.79313 .32665 Mdot
.48872 .4022 Mdot
.60534 .21953 Mdot
.70902 .73578 Mdot
.26837 .58696 Mdot
.37443 .25089 Mdot
.59306 .5932 Mdot
.60921 .24244 Mdot
.75561 .39794 Mdot
.71493 .51689 Mdot
.25105 .61405 Mdot
.57398 .7562 Mdot
.36597 .51577 Mdot
.51017 .67932 Mdot
.51951 .54377 Mdot
.52688 .34503 Mdot
.60189 .16641 Mdot
.49547 .57072 Mdot
.69059 .58805 Mdot
.5571 .44961 Mdot
.20385 .61541 Mdot
.51364 .85202 Mdot
.52555 .5164 Mdot
.31037 .30531 Mdot
.66569 .7184 Mdot
.66382 .65669 Mdot
.61595 .26689 Mdot
.18942 .72606 Mdot
.81877 .62783 Mdot
.59229 .3703 Mdot
.61956 .41961 Mdot
.56906 .78 Mdot
.68408 .22362 Mdot
.35639 .74827 Mdot
.26047 .59969 Mdot
.20994 .67088 Mdot
.51741 .74938 Mdot
.62946 .50432 Mdot
.71213 .75056 Mdot
.826 .40675 Mdot
.22583 .58817 Mdot
.7804 .32455 Mdot
.65337 .50248 Mdot
.59654 .60386 Mdot
.35691 .84685 Mdot
.79149 .37862 Mdot
.63485 .48395 Mdot
.19471 .60439 Mdot
.5177 .32742 Mdot
.63549 .55295 Mdot
.31963 .42083 Mdot
.63146 .76029 Mdot
.68509 .67545 Mdot
.7193 .2502 Mdot
.52424 .36504 Mdot
.24139 .53911 Mdot
.39973 .39841 Mdot
.49928 .49413 Mdot
.58469 .60662 Mdot
.36154 .37531 Mdot
.64464 .6725 Mdot
.50072 .40906 Mdot
.36897 .32376 Mdot
.56186 .80433 Mdot
.74502 .74954 Mdot
.77748 .47401 Mdot
.40329 .32863 Mdot
.6357 .46623 Mdot
.7326 .57805 Mdot
.58081 .68091 Mdot
.59001 .66099 Mdot
.74467 .7198 Mdot
.87146 .58539 Mdot
.28615 .52263 Mdot
.55739 .46463 Mdot
.59191 .28307 Mdot
.6624 .33398 Mdot
.75875 .37782 Mdot
.33513 .35355 Mdot
.35065 .51127 Mdot
.66718 .56405 Mdot
.51928 .54062 Mdot
.40382 .40155 Mdot
.46699 .14018 Mdot
.62599 .50964 Mdot
.64218 .28092 Mdot
.82923 .50076 Mdot
.27389 .64556 Mdot
.75696 .56303 Mdot
.65796 .55093 Mdot
.45221 .20316 Mdot
.48328 .39822 Mdot
.51029 .39405 Mdot
.26744 .61678 Mdot
.71125 .25832 Mdot
.77042 .50595 Mdot
.66422 .27685 Mdot
.5961 .5171 Mdot
.4714 .71563 Mdot
.40037 .27051 Mdot
.57905 .21371 Mdot
.54614 .60357 Mdot
.83813 .49175 Mdot
.27055 .59406 Mdot
.31686 .56985 Mdot
.67927 .63481 Mdot
.62374 .19151 Mdot
.1974 .50454 Mdot
.73987 .35698 Mdot
.24754 .33857 Mdot
.27197 .36878 Mdot
.57046 .68609 Mdot
.41739 .63304 Mdot
.59345 .45817 Mdot
.51969 .32637 Mdot
.60353 .1468 Mdot
.57231 .21015 Mdot
.43675 .34436 Mdot
.27776 .4904 Mdot
.72671 .38507 Mdot
.51177 .46481 Mdot
.64215 .84555 Mdot
.38874 .74918 Mdot
.56762 .14091 Mdot
.71157 .65799 Mdot
.51657 .30081 Mdot
.44381 .31539 Mdot
.63283 .61735 Mdot
.3844 .57642 Mdot
.69342 .23466 Mdot
.51969 .52175 Mdot
.21919 .49585 Mdot
.62895 .50569 Mdot
.27795 .30157 Mdot
.45921 .39041 Mdot
.31836 .51681 Mdot
.31719 .50565 Mdot
.1785 .52606 Mdot
.81263 .52094 Mdot
.47713 .40002 Mdot
.62338 .84112 Mdot
.74055 .32404 Mdot
.80401 .38047 Mdot
.41665 .59413 Mdot
.17119 .44438 Mdot
.56234 .24901 Mdot
.47904 .34148 Mdot
.45089 .36118 Mdot
.48947 .63554 Mdot
.2544 .35376 Mdot
.66224 .66074 Mdot
.42069 .2556 Mdot
.42609 .35668 Mdot
.9152 .5644 Mdot
.63507 .68556 Mdot
.62129 .63292 Mdot
.22401 .43716 Mdot
.78814 .34899 Mdot
.4306 .77855 Mdot
.72209 .75415 Mdot
.46782 .60665 Mdot
.58354 .60342 Mdot
.7598 .4916 Mdot
.72243 .61056 Mdot
.27282 .33871 Mdot
.20093 .32569 Mdot
.64476 .78041 Mdot
.30272 .53572 Mdot
.48362 .4966 Mdot
.53998 .32576 Mdot
.58349 .39215 Mdot
.33334 .72053 Mdot
.67787 .79482 Mdot
.47789 .37496 Mdot
.78087 .36562 Mdot
.15934 .41252 Mdot
.71236 .67556 Mdot
.69156 .2267 Mdot
.5492 .24025 Mdot
.57544 .40932 Mdot
.58935 .67779 Mdot
.43644 .66986 Mdot
.33336 .51637 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0Y_ooool2o`000:7ooooo
000Looooo`03o`000?oooooooooo0:Kooooo0_l0002Qooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0:7ooooo0_l00009ooooo`;o
0000Voooool001cooooo00?o0000ooooooooool0XOooool2o`0000Wooooo0_l000000ooooooo0000
o`00000;ooooo`;o0000Roooool001cooooo00?o0000ooooooooool0Y_ooool5o`0000Cooooo0_l0
000;ooooo`;o00004?ooool2o`0007Wooooo000Looooo`03o`000?oooooooooo09Cooooo0_l0000@
ooooo`Go00001Oooool2o`0000?ooooo0_l0000Gooooo`;o0000NOooool001cooooo00?o0000oooo
ooooool0U?ooool2o`0001[ooooo0_l00003ooooo`Co0000T?ooool001cooooo00?o0000oooooooo
ool0P_ooool2o`0003?ooooo0_l00007ooooo`;o0000Qoooool001cooooo00?o0000ooooooooool0
P_ooool2o`0000[ooooo0_l0000Vooooo`;o00002?ooool2o`000003ooooool0003o000008Cooooo
000Looooo`;o0000Soooool2o`0002Kooooo0_l00006ooooo`;o00000oooool2o`0008Cooooo000L
ooooo`03o`000?oooooooooo0;kooooo0_l00029ooooo`007?ooool00ol0003oooooooooo`2noooo
o`;o0000ROooool001cooooo00?o0000ooooooooool0Roooool2o`0000Cooooo0_l00002ooooo`;o
00006_ooool2o`0000Sooooo0_l0002<ooooo`007?ooool00ol0003oooooooooo`2;ooooo`?o0000
0oooool2o`0000;ooooo0_l00006ooooo`;o00004_ooool2o`0000Sooooo0_l0002<ooooo`007?oo
ool00ol0003oooooooooo`1/ooooo`;o00003Oooool2o`0000Sooooo0_l000000ooooooo0000o`00
0002ooooo`;o000000?oooooo`000?l000003?ooool2o`0000;ooooo0_l0000=ooooo`;o00003_oo
ool2o`0008Oooooo000Looooo`03o`000?oooooooooo06cooooo0_l00008ooooo`;o00000oooool2
o`0000Sooooo0_l000000ooooooo0000o`000005ooooo`;o00004?ooool2o`0000gooooo0_l0000>
ooooo`;o0000Qoooool001cooooo00?o0000ooooooooool0M_ooool2o`0003Kooooo0_l0000Joooo
o`;o000000?oooooo`000?l00000N_ooool001cooooo00?o0000ooooooooool0Poooool2o`0001;o
oooo0_l00005ooooo`;o00003_ooool2o`0000kooooo0_l0000:ooooo`;o000000?oooooo`000?l0
0000N_ooool001cooooo00?o0000ooooooooool0Poooool2o`0000oooooo1Ol00003ooooo`Co0000
1_ooool3o`0001;ooooo0_l000000ooooooo0000o`000029ooooo`007?ooool00ol0003ooooooooo
o`2Dooooo`Co00001?ooool2o`0000Sooooo0ol00004ooooo`;o00002?ooool2o`000004ooooool0
003o0000o`0000_ooooo0_l0001oooooo`007?ooool00ol0003oooooooooo`20ooooo`;o00005?oo
ool2o`0000Wooooo0_l0000:ooooo`;o00002?ooool2o`000003ooooool0003o000000;o000000?o
ooooo`000?l000001oooool2o`0007oooooo000Looooo`03o`000?oooooooooo07kooooo1?l00005
ooooo`;o00006?ooool3o`000003ooooool0003o000000;o00004oooool2o`000003ooooool0003o
000008Sooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_oo
ool00ol0003oooooooooo`1nooooo`;o00001oooool3o`0000?ooooo0_l00005ooooo`;o00002ooo
ool3o`000003ooooool0003o000000;o00003oooool2o`0000gooooo1Ol0001mooooo`0000Kooooo
ogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Ko
oooo00?o0000ooooooooool0Q?ooool2o`0000;ooooo0_l00003ooooo`;o00001Oooool4o`0000Wo
oooo0_l0000<ooooo`;o00001oooool2o`0000gooooo1Ol0001mooooo`0000?ooooooa0@4?ooool0
0_ooool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0
Poooool3o`0000?ooooo0_l00009ooooo`Co00002?ooool2o`0000gooooo0_l0002Hooooo`0000?o
ooooo`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0
0023ooooo`;o00000oooool3o`0000Kooooo0_l000000ooooooo0000o`000002o`0000Sooooo0_l0
000?ooooo`;o00002_ooool2o`0008[ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`26ooooo`Co00001Oooool4
o`0000Oooooo0_l0000:ooooo`;o00002Oooool2o`0000[ooooo0_l0002:ooooo`0000?ooooooa0@
4?ooool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0Q_ooool2o`0000Oooooo0_l00009ooooo`;o00002_ooool3o`0001Sooooo0_l00006oooo
o`Co00000_ooool2o`0007Sooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000
okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo06Gooooo0_l0000Aooooo`;o00005Ooo
ool2o`0000_ooooo0_l000000ooooooo0000o`000004ooooo`Co000000?oooooo`000?l000002_oo
ool3o`0000Sooooo0_l00006ooooo`Co00000_ooool2o`0000Kooooo1?l0001^ooooo`0000Kooooo
onk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003o
ooooooooo`1Uooooo`;o00004Oooool2o`0000_ooooo0_l00008ooooo`;o00002oooool2o`000003
ooooool0003o000000Cooooo1?l000000ooooooo0000o`00000:ooooo`Co00003_ooool5o`0000Ko
oooo0ol000000ooooooo0000o`000002o`0000;ooooo0_l0001Zooooo`007?ooool00ol0003ooooo
ooooo`1mooooo`;o00001_ooool2o`0001gooooo0_l0000Aooooo`?o00002?ooool2o`0000Cooooo
0ol00008ooooo`?o00001oooool2o`0006[ooooo000Looooo`03o`000?oooooooooo07Gooooo0_l0
0006ooooo`?o00000oooool2o`0000gooooo0_l0000@ooooo`Co00003oooool2o`0000;ooooo0_l0
0004ooooo`?o00003?ooool2o`0007Oooooo000Looooo`03o`000?oooooooooo06Gooooo0_l0000>
ooooo`;o00001_ooool3o`0000?ooooo0_l00006ooooo`Co00000oooool2o`0001;ooooo1Ol00009
ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l000001?oooooo0000o`000?l0
0002ooooo`;o00001Oooool2o`0000Sooooo1?l0001[ooooo`007?ooool00ol0003oooooooooo`1U
ooooo`;o00005_ooool2o`0000Kooooo0_l00003ooooo`Go00000oooool2o`0000Kooooo0_l00007
ooooo`;o00000_ooool4o`0000Cooooo0_l00003ooooo`;o00003_ooool4o`000003ooooool0003o
000000Kooooo0_l00007ooooo`Go0000J_ooool001cooooo00?o0000ooooooooool0Ioooool2o`00
00gooooo0_l00005ooooo`;o00001_ooool2o`0000?ooooo1?l00004ooooo`;o00001_ooool2o`00
00?ooooo0_l00002ooooo`;o00002_ooool2o`0001Cooooo0ol00009ooooo`;o00002_ooool2o`00
06[ooooo000Looooo`03o`000?oooooooooo06Oooooo0_l00008ooooo`?o00000_ooool2o`0000Co
oooo0ol000000ooooooo0000o`00000>ooooo`;o00003Oooool2o`0000Gooooo0_l0000=ooooo`;o
000000?oooooo`000?l000000_l00003ooooo`;o00001?ooool2o`0000;ooooo0_l0001nooooo`00
7?ooool00ol0003oooooooooo`1aooooo`?o000000Coooooo`000?l0003o00001?ooool3o`000003
ooooool0003o000000_ooooo0_l000000ooooooo0000o`00000Dooooo`;o00003Oooool2o`000003
ooooool0003o000000;o00000oooool2o`0000Oooooo0ol00006ooooo`;o00001_ooool2o`0000;o
oooo0_l0000Eooooo`;o0000Doooool001cooooo00?o0000ooooooooool0I?ooool2o`0000oooooo
0_l00004ooooo`;o00002oooool2o`000003ooooool0003o000000;o0000:oooool2o`0000Oooooo
0_l00003ooooo`;o00001oooool2o`0000Kooooo0_l00002ooooo`;o00000oooool2o`00013ooooo
0_l0001Cooooo`007?ooool00ol0003oooooooooo`1Qooooo`;o000000?oooooo`000?l000000_l0
000Cooooo`;o00000_ooool4o`0000Gooooo0_l000000ooooooo0000o`00000Jooooo`;o00001_oo
ool2o`0000Cooooo0_l00003ooooo`;o00001_ooool3o`0000;ooooo0_l0000Iooooo`;o00004Ooo
ool2o`0005;ooooo000Looooo`03o`000?oooooooooo067ooooo0_l00003ooooo`;o00001oooool2
o`0000;ooooo0_l0000:ooooo`Co00005?ooool2o`0000kooooo0_l00006ooooo`;o00001?ooool2
o`0000_ooooo0_l00003ooooo`;o0000;?ooool3o`00057ooooo000Looooo`03o`000?oooooooooo
05gooooo0_l00007ooooo`;o00001?ooool2o`000005ooooool0003o0000o`000?ooool00_l0000Q
ooooo`Go000000?oooooo`000?l000005Oooool2o`0000_ooooo1?l0000Sooooo`;o00003Oooool2
o`00057ooooo000Looooo`;o0000G_ooool2o`0000?ooooo0_l00002ooooo`;o00001?ooool2o`00
00;ooooo0_l000001?oooooo0000o`000?ooool2o`0001kooooo0_l000001?oooooo0000o`000?oo
ool2o`0001Gooooo0_l0000;ooooo`Co000000?oooooo`000?l000006oooool2o`0000;ooooo0ol0
001Pooooo`007?ooool00ol0003oooooooooo`1Rooooo`;o00003oooool5o`00013ooooo0_l0000B
ooooo`;o00001oooool2o`0000kooooo0_l000000ooooooo0000o`000002o`0000Wooooo0_l0000>
ooooo`;o00001oooool2o`0000;ooooo0_l00002ooooo`;o0000HOooool001cooooo00?o0000oooo
ooooool0K?ooool2o`0000Cooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l00004oooo
o`;o000000Coooooo`000?l0003ooooo0_l0000:ooooo`;o00003oooool2o`0000Oooooo0_l00005
ooooo`;o000000?oooooo`000?l000000_l00007ooooo`;o00003?ooool2o`0000;ooooo0_l00006
ooooo`?o00000oooool2o`0006Cooooo000Looooo`03o`000?oooooooooo06cooooo0_l00004oooo
o`;o00000oooool3o`0000;ooooo0_l00004ooooo`Go00003Oooool2o`0001Sooooo0_l0000Coooo
o`;o00003?ooool2o`000003ooooool0003o000000Kooooo0ol00003ooooo`?o0000I?ooool001co
oooo00?o0000ooooooooool0G_ooool3o`0000_ooooo0_l0000:ooooo`;o000000?oooooo`000?l0
00001oooool2o`0003gooooo0_l0000?ooooo`;o00001_ooool2o`0000Cooooo0_l00004ooooo`;o
0000Goooool001cooooo00?o0000ooooooooool0DOooool2o`0000?ooooo0_l00006ooooo`?o0000
1Oooool2o`0000?ooooo0_l0000>ooooo`;o00005oooool2o`000003ooooool0003o000000;ooooo
0ol0000Vooooo`;o00008_ooool2o`0005oooooo000Looooo`03o`000?oooooooooo057ooooo0_l0
0003ooooo`;o00001Oooool2o`0000Oooooo0_l00003ooooo`;o00004Oooool2o`000003ooooool0
003o0000017ooooo1Ol00002ooooo`?o00006?ooool2o`0000Wooooo0_l000000ooooooo0000o`00
000Cooooo`;o0000K_ooool001cooooo00?o0000ooooooooool0GOooool2o`000003ooooool0003o
0000017ooooo0_l00009ooooo`Go000000?oooooo`000?l000003_ooool3o`0000Kooooo0ol00000
0ooooooo0000o`000009ooooo`;o00002?ooool6o`0000?ooooo1?l0000Fooooo`;o000000?ooooo
o`000?l000002Oooool2o`0000;ooooo0_l0001Looooo`007?ooool00ol0003oooooooooo`1Poooo
o`;o00003oooool4o`0000_ooooo0_l00002ooooo`;o00002oooool2o`0000Kooooo0_l00002oooo
o`?o000000?oooooo`000?l000001oooool4o`0000[ooooo1?l00003ooooo`?o00003oooool2o`00
0003ooooool0003o000000Kooooo0_l00004ooooo`;o00000oooool2o`0000;ooooo0_l0001Loooo
o`007?ooool00ol0003oooooooooo`1Zooooo`?o00001?ooool2o`0000cooooo1ol0000:ooooo`?o
00001_ooool2o`0000;ooooo0_l00006ooooo`;o00000_ooool3o`0000[ooooo0_l00007ooooo`?o
00003oooool2o`000003ooooool0003o000000cooooo0_l0000>ooooo`;o0000EOooool001cooooo
00?o0000ooooooooool0COooool4o`0001Gooooo0_l00002ooooo`?o00002oooool4o`0000?ooooo
1ol000001?oooooo0000o`000?ooool2o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`;o
00000oooool3o`000003ooooool0003o000000;ooooo1_l00003ooooo`;o00000oooool2o`000003
ooooool0003o000000Cooooo0_l000000ooooooo0000o`000005ooooo`;o00001Oooool2o`0000So
oooo0_l00002ooooo`;o00005Oooool3o`0005Cooooo000Looooo`03o`000?oooooooooo04gooooo
1?l0000;ooooo`;o000000?oooooo`000?l000001?ooool5o`0000kooooo1?l0000:ooooo`?o0000
00?oooooo`000?l000001oooool2o`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l00000
1?ooool2o`0000Gooooo0_l00003ooooo`?o00001Oooool5o`0000Kooooo0_l00005ooooo`;o0000
2?ooool2o`0000;ooooo0ol00008ooooo`;o00002oooool2o`0005Cooooo000Looooo`03o`000?oo
oooooooo05cooooo1Ol00003ooooo`?o000000?oooooo`000?l000004?ooool3o`0000Wooooo0_l0
0005ooooo`;o00004_ooool2o`0000oooooo1?l00002ooooo`Go000000Coooooo`000?l0003ooooo
0_l0000?ooooo`;o00000oooool2o`0000?ooooo0_l00008ooooo`;o00001oooool2o`0005Sooooo
000Looooo`03o`000?oooooooooo04[ooooo0_l0000Booooo`;o000000?oooooo`000?l000001Ol0
000Booooo`?o00001?ooool2o`0000Sooooo1?l000001?oooooo0000o`000?ooool2o`0000Cooooo
0_l00006ooooo`;o00003Oooool7o`000004ooooool0003o0000o`0000?ooooo0_l000000ooooooo
0000o`00000?ooooo`;o00000oooool2o`0001Kooooo0_l00003ooooo`;o0000Doooool001cooooo
00?o0000ooooooooool0B_ooool2o`0000kooooo0_l00005ooooo`Co000000Coooooo`000?l0003o
oooo0_l00006ooooo`;o00002Oooool2o`0000?ooooo0_l00008ooooo`;o00000oooool5o`0000Co
oooo0_l0000Dooooo`So000000?oooooo`000?l000000_l0000Oooooo`;o00004oooool2o`0000;o
oooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`1Iooooo`Co00001?ooool2o`0000Kooooo
0_l000000ooooooo0000o`000003ooooo`;o00000oooool2o`0000Cooooo0_l00002ooooo`;o0000
3oooool2o`0001cooooo0_l00003ooooo`?o000000?oooooo`000?l000000_l00004ooooo`;o0000
1oooool2o`0000Wooooo0_l000000ooooooo0000o`000002ooooo`;o00002oooool2o`0000Kooooo
0_l0001Gooooo`007?ooool2o`0005Kooooo2?l00008ooooo`?o00000_ooool4o`0000Oooooo0ol0
0008ooooo`;o00002oooool2o`0000;ooooo0_l00002ooooo`;o00000_ooool2o`0000Kooooo0_l0
00000ooooooo0000o`000009ooooo`So000000?oooooo`000?l000000ol000000ooooooo0000o`00
0002o`000003ooooool0003o000000Cooooo0_l00008ooooo`?o000000?oooooo`000?l000000ooo
ool2o`0000Cooooo0_l00004ooooo`;o00001_ooool5o`0005Cooooo000Looooo`03o`000?oooooo
oooo05Cooooo1Ol00002ooooo`;o00000oooool4o`000004ooooool0003o0000o`0000;ooooo0_l0
0004ooooo`;o00000oooool2o`0000?ooooo0_l00004ooooo`;o00002?ooool2o`000004ooooool0
003o0000ooooo`;o00000oooool2o`0000;ooooo0_l00006ooooo`;o000000?oooooo`000?l00000
1Oooool3o`000003ooooool0003o000000Ko000000?oooooo`000?l000000ol000000ooooooo0000
o`000003ooooo`;o00001?ooool2o`0000Sooooo0_l00007ooooo`;o00001?ooool4o`0000[ooooo
1Ol0001Dooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o00001Oooool3o`0000;ooooo1?l0
0002ooooo`Co00001_ooool2o`0000Sooooo0_l00004ooooo`;o00002?ooool2o`0000Cooooo0ol0
000Hoooooa;o00003?ooool2o`0000gooooo0_l0000:ooooo`;o00003Oooool2o`0005Cooooo000L
ooooo`03o`000?oooooooooo05[ooooo1?l00002ooooo`?o00000oooool4o`0000;ooooo0_l00002
ooooo`;o00001Oooool2o`0001Oooooo0ol00005ooooo`;o00004?ooool2o`000003ooooool0003o
000000go000000?oooooo`000?l000000ol0000Fooooo`;o00004oooool5o`0005Oooooo000Loooo
o`03o`000?oooooooooo04oooooo0_l00009ooooo`Go000000?oooooo`000?l000002_ooool2o`00
00;ooooo0_l00005ooooo`;o00005Oooool4o`0000Kooooo0_l00006ooooo`;o00001?ooool2o`00
00;ooooo0_l000000ooooooo0000o`00000Eo`0000Cooooo0_l0000:ooooo`?o00002oooool2o`00
00Gooooo0_l00002ooooo`Go000000?oooooo`000?l000000_l000000ooooooo0000o`00001?oooo
o`007?ooool00ol0003oooooooooo`1?ooooo`;o00000_ooool2o`0000;ooooo0ol00003ooooo`;o
00001_ooool3o`0000Cooooo0_l00002ooooo`;o00006_ooool4o`0000kooooo1?l00004ooooo`;o
000000Goooooo`000?l0003o0000ooooo`0Bo`000003ooooool0003o000000Co00000_ooool2o`00
00Wooooo1?l000000ooooooo0000o`000008ooooo`;o00000oooool4o`0000Sooooo1?l000000ooo
oooo0000o`00000>ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0COooool2o`0000Co
oooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00007ooooo`?o00002?ooool2o`0001Ko
oooo0ol000000ooooooo0000o`00000:ooooo`;o00000oooool3o`0000Wooooo0ol000000ooooooo
0000o`000002o`000003ooooool0003o000000ko00000_ooool2o`0000;ooooo0_l00008ooooo`So
000000?oooooo`000?l000000_l00008ooooo`Co00003Oooool3o`0000gooooo0_l0000oooooo`00
7?ooool00ol0003oooooooooo`1=ooooo`;o00000_ooool2o`0000;ooooo0ol00004ooooo`;o0000
3oooool3o`0000Oooooo0_l00003ooooo`;o00002_ooool3o`0000Wooooo0_l00002ooooo`;o0000
0oooool2o`0000Wooooo6_l00006ooooo`;o00002?ooool2o`0000?ooooo0ol000000ooooooo0000
o`000002o`0001[ooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00004Ooo
ool2o`0000;ooooo0ol00009ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`Co0000
0_ooool4o`000003ooooool0003o000000?ooooo0_l0000Fooooo`;o00002oooool2o`0000Gooooo
2?l000000ooooooo0000o`00000Ao`0000Cooooo0_l00006ooooo`;o00000_ooool2o`0000Sooooo
0_l000000ooooooo0000o`00000:ooooo`;o00002oooool3o`0004cooooo000Looooo`03o`000?oo
oooooooo03kooooo0ol0000Booooo`;o000000?oooooo`000?l000002Oooool2o`0000;ooooo0ol0
00001?oooooo0000o`000?ooool2o`0000Cooooo1?l00009ooooo`;o00004?ooool2o`0000kooooo
0_l000001Ooooooo0000o`000?l0003ooooo00So00000ooooolAo`0000Cooooo0_l00006ooooo`;o
00000_ooool2o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l000002_ooool2o`0000_o
oooo0ol000000ooooooo0000o`000019ooooo`007?ooool00ol0003oooooooooo`0oooooo`;o0000
3oooool2o`000003ooooool0003o000000?ooooo0_l0000;ooooo`;o00001oooool6o`000003oooo
ool0003o000000Ko00000_ooool2o`00013ooooo1?l0000?ooooo`Ko000000?oooooo`000?l00000
2Ol000000ooooooo0000o`000008o`0001Oooooo1?l00002ooooo`;o000000?oooooo`000?l00000
0_ooool2o`0000oooooo0_l000000ooooooo0000o`000003ooooo`;o00001_ooool2o`00047ooooo
000Looooo`03o`000?oooooooooo053ooooo0_l00006ooooo`;o00000_ooool2o`00013ooooo3ol0
0002ooooo`;o00004_ooool6o`0000_ooooo7?l00006ooooo`;o00002oooool2o`0000;ooooo0_l0
00000ooooooo0000o`000009ooooo`;o00002Oooool2o`0000Cooooo0_l000000ooooooo0000o`00
000;ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0COooool2o`0000gooooo0_l0000@
ooooo`;o00000_ooool:o`000003ooooool0003o000000Kooooo0_l000000ooooooo0000o`000006
ooooo`Wo00002oooool2o`000003ooooool0003o000001Go000000Coooooo`000?l0003ooooo0_l0
0002ooooo`;o00001?ooool3o`0000?ooooo0ol00002ooooo`;o00003?ooool2o`0000Cooooo0_l0
0003ooooo`;o00001_ooool2o`0001?ooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`1=
ooooo`;o00000_ooool2o`0000;ooooo0_l00005ooooo`;o00004?ooool2o`0000;ooooo4?l00003
ooooo`;o000000?oooooo`000?l000001_ooool4o`0000Cooooo1?l00006ooooo`;o00000oooool2
o`000003ooooool0003o000001Go000000?oooooo`000?l000000_ooool2o`0000Cooooo0ol00003
ooooo`;o00000oooool2o`0000cooooo0ol00003ooooo`;o00002_ooool3o`0000Kooooo0_l0000;
ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0C_ooool2o`000003ooooool0003o0000
00;ooooo0_l00005ooooo`;o00000_ooool2o`0000[ooooo6_l00004ooooo`?o00000_ooool2o`00
00Oooooo1_l00004ooooo`Oo000000?oooooo`000?l000006?l00006ooooo`;o00001Oooool2o`00
00Gooooo0_l0000;ooooo`?o00003oooool4o`0000Gooooo0_l00017ooooo`007?ooool00ol0003o
ooooooooo`1>ooooo`;o00000_ooool2o`0000cooooo0_l0000:oooooaCo00000_ooool4o`0000?o
oooo1?l00002ooooo`;o00002?ooool2o`000003ooooool0003o000000;ooooo0_l00002oooooa3o
000000?oooooo`000?l000002Ol000000ooooooo0000o`000007ooooo`;o00001Oooool2o`000003
ooooool0003o000000;ooooo0_l00008ooooo`;o000000Coooooo`000?l0003o00004Oooool2o`00
04kooooo000Looooo`;o0000D?ooool2o`000003ooooool0003o000000Wooooo1?l00002ooooo`;o
00001ooooolFo`000003ooooool0003o000000Cooooo1_l0000:ooooo`;o00001Oooool2o`0000?o
oooo6_l0000Eooooo`;o00003?ooool6o`0001Cooooo0_l0001;ooooo`007?ooool00ol0003ooooo
ooooo`1?ooooo`;o00003?ooool4o`0000;ooooo0_l00004ooooo`;o00000_oooolGo`0000Wooooo
0_l00004ooooo`?o00003ooooolNo`0000?ooooo1?l00009ooooo`;o00002Oooool2o`0000Cooooo
1?l0000Aooooo`;o000000?oooooo`000?l000004Oooool2o`0003Sooooo000Looooo`03o`000?oo
oooooooo04_ooooo0_l00002ooooo`;o00002_ooool2o`0000;ooooo0_l00003ooooo`?o00000_oo
ool2o`0000;ooooo6?l00002ooooo`?o00001Oooool2o`0000;ooooo1?l0000?oooooako00000_oo
ool4o`0000Wooooo0_l00003ooooo`;o00001?ooool2o`0000gooooo0_l00002ooooo`;o00001_oo
ool2o`0001Cooooo0_l00002ooooo`;o0000=?ooool001cooooo00?o0000ooooooooool0Aoooool2
o`0000;ooooo0_l0000>ooooo`;o00000_ooool2o`0000?ooooo0ol00006oooooaCo00000_ooool2
o`0000;ooooo1?l000001?oooooo0000o`000?ooool2o`0000Cooooo0_l0000?oooooako00001?oo
ool2o`0000Wooooo0_l00003ooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo0_l0
0006ooooo`;o000000Coooooo`000?l0003o00003_ooool2o`0000cooooo1_l0000dooooo`007?oo
ool00ol0003oooooooooo`17ooooo`;o000000Coooooo`000?l0003o00003_ooool2o`0000cooooo
7?l00004ooooo`;o000000?oooooo`000?l000000ol00009ooooo`;o00002_oooolLo`0000Kooooo
0_l00009ooooo`;o00001_ooool2o`0000Cooooo0_l00002ooooo`;o00000oooool2o`0000Cooooo
0ol00006ooooo`;o00001_ooool2o`0000cooooo1?l0000fooooo`007?ooool00ol0003ooooooooo
o`12ooooo`;o00001_ooool4o`0000gooooo0_l00002ooooo`;o00002?oooolKo`0000Cooooo1?l0
00000ooooooo0000o`000002o`0000Wooooo1?l00009ooooo`;o00000_oooolGo`0000[ooooo0_l0
000Hooooo`;o00000_ooool3o`0000Oooooo0_l00003ooooo`?o0000COooool001cooooo00?o0000
ooooooooool0@_ooool2o`0000Cooooo0_l00002ooooo`;o00001oooool2o`0000Cooooo0_l00002
ooooo`;o00000_ooool2o`000003ooooool0003o000000Gooooo5_l00002ooooo`;o000000?ooooo
o`000?l000000_l00002ooooo`;o00003?ooool2o`0000Gooooo0_l00002oooooa?o000000?ooooo
o`000?l000000ol00002ooooo`;o00000_ooool2o`0000Cooooo0_l00006ooooo`;o00003_ooool4
o`0000?ooooo0_l00007ooooo`;o00001?ooool2o`0000;ooooo0_l00019ooooo`007?ooool00ol0
003oooooooooo`14ooooo`;o00000_ooool2o`0000_ooooo0_l00004ooooo`;o00000oooool2o`00
0004ooooool0003o0000ooooo`;o00001OoooolJo`0000Oooooo0_l0000Cooooo`So000000?ooooo
o`000?l000003?l000000ooooooo0000o`000002o`0000?ooooo1_l000000ooooooo0000o`000005
ooooo`;o00000_ooool2o`0000kooooo0_l0000:ooooo`;o00003?ooool2o`0000Gooooo0_l00012
ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00001?ooool2o`0000kooooo0_l00004oooo
o`Co00002OoooolJo`0000Oooooo0_l00007ooooo`;o00002Oooool2o`000003ooooool0003o0000
00?o000000?oooooo`000?l000004_l000000ooooooo0000o`000002ooooo`;o00000oooool2o`00
00Gooooo1?l00003ooooo`;o00002_ooool2o`000003ooooool0003o000000Sooooo0_l00005oooo
o`;o00001oooool2o`0000?ooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o
00003Oooool3o`0000?ooooo0_l000000ooooooo0000o`00000:oooooaWo00001oooool2o`0000Oo
oooo0_l00009ooooo`;o00001ooooolAo`000004ooooool0003o0000ooooo`;o00001oooool2o`00
00Oooooo0_l00003ooooo`;o00001Oooool2o`0000?ooooo0_l000000ooooooo0000o`00000;oooo
o`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`000017ooooo`007?ooool00ol0003o
ooooooooo`1:ooooo`Co00002oooool2o`0000?ooooo0ol0000<oooooaSo00002oooool2o`0001Wo
oooo4_l0000Qooooo`;o00001?ooool2o`0000gooooo0_l00008ooooo`;o00000_ooool2o`00013o
oooo0_l0000dooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00001_ooool2o`0000;ooooo
1?l0000@ooooo`;o00002ooooolAo`0000;ooooo2Ol00009ooooo`;o000000?oooooo`000?l00000
5?oooolGo`0001kooooo0ol00003ooooo`;o00005Oooool2o`0000Cooooo0_l00004ooooo`;o0000
00?oooooo`000?l000001oooool2o`0003Cooooo000Looooo`03o`000?oooooooooo03kooooo0_l0
00000ooooooo0000o`000003ooooo`?o000000?oooooo`000?l000001Oooool2o`0001Sooooo0_l0
0002oooooaSo00003?ooool2o`0000Kooooo0_l00005ooooo`;o00000ooooolDo`0000;ooooo1ol0
000Booooo`;o00001_ooool3o`0000Oooooo0_l00002ooooo`;o00001?ooool2o`0000Oooooo0_l0
000:ooooo`Go0000?Oooool001cooooo00?o0000ooooooooool0<_ooool2o`000003ooooool0003o
000000[ooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000Gooooo0_l0000L
oooooaOo00002oooool2o`0000Kooooo1?l00005ooooo`;o00000oooool3o`0000Kooooo2_l00006
ooooo`Co000000Coooooo`000?l0003o00003_ooool2o`0000Sooooo0_l00006ooooo`;o00000_oo
ool3o`0000?ooooo0_l0000Eooooo`;o0000?_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^
1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo03;ooooo
0_l000000ooooooo0000o`00000:ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o0000
1Oooool2o`0001cooooo5?l00003ooooo`;o00002Oooool2o`0000Kooooo0_l00007ooooo`;o0000
3?ooool>o`0000Oooooo0ol0000Cooooo`;o00000oooool3o`0000[ooooo0_l00007ooooo`;o0000
2oooool2o`0004Cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0AOooool3o`0000Wooooo0_l0000@ooooo`;o
00002oooool2o`000003ooooool0003o000000Wo000000?oooooo`000?l000000_l00003ooooo`;o
00001oooool2o`0000[ooooo0_l00005ooooo`;o00002ooooolAo`0001_ooooo0_l00004ooooo`;o
00004oooool2o`0000_ooooo0_l00003ooooo`;o000000?oooooo`000?l000002oooool2o`0002oo
oooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006ooooo`03o`00
0?oooooooooo047ooooo0_l000000ooooooo0000o`000002o`0000Wooooo0_l00005ooooo`;o0000
2Oooool2o`0000_ooooo4ol0000<ooooo`;o00001_ooool6o`00013ooooo1?l00002ooooo`Co0000
0_ooool3o`0000;ooooo0_l0000Vooooo`;o00002_ooool2o`0000Gooooo0_l0000=ooooo`;o0000
00?oooooo`000?l000002oooool2o`0002oooooo00000ooooooo0000ooooo`02ooooo`03o`000?oo
oooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`00043ooooo0ol000000ooooooo0000
o`000008ooooo`;o000000?oooooo`000?l000001Oooool2o`0001Oooooo4?l00009ooooo`;o0000
2oooool:o`0000Kooooo0_l00003ooooo`?o00001?ooool4o`0000?ooooo1?l00005ooooo`;o0000
0_ooool2o`0001gooooo0_l0000:ooooo`;o00001Oooool2o`0000Wooooo0ol00012ooooo`0000?o
ooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo
00?o0000ooooooooool0?oooool4o`0000_ooooo0_l0000Poooooa7o00002Oooool2o`0000oooooo
1_l00006ooooo`;o00000oooool3o`0000Cooooo0_l00004ooooo`Oo00000oooool2o`0000;ooooo
0_l0000Rooooo`;o00001Oooool2o`0000;ooooo1?l0000:ooooo`?o00001_ooool2o`0003[ooooo
00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oMgMgolc<c?l000001ooo
ool00ol0003oooooooooo`0aooooo`;o00002oooool5o`0002gooooo4?l0000Kooooo`Ko00004_oo
ool2o`0000;ooooo1?l000000ooooooo0000o`000002o`0000gooooo0_l0000Looooo`Co00000ooo
ool2o`0000;ooooo1?l0000>ooooo`;o00000oooool2o`0003[ooooo00001_ooooooMgMgoiRHV?oo
ooooV9RHogMgM`cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0Zooooo`;o0000
1?ooool3o`0000_ooooo1Ol0000`ooooo`Co000000?oooooo`000?l000000ol000000ooooooo0000
o`00000>ooooo`;o00001oooool2o`0000;ooooo2?l0000;ooooo`;o00000oooool2o`0000;ooooo
0_l000000ooooooo0000o`000002o`0000Gooooo0_l00008ooooo`;o00007_ooool2o`0000Oooooo
0_l0000@ooooo`;o0000?oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo
0000ooooo`06ooooo`03o`000?oooooooooo02[ooooo0_l00004ooooo`;o00002_ooool3o`0000;o
oooo1?l00003ooooo`;o00001oooool2o`00017ooooo0_l0000<ooooo`Go00000_ooool7o`0000co
oooo1?l00007ooooo`;o00002?ooool2o`0000_ooooo0_l0000:ooooo`;o00001oooool2o`0002[o
oooo0_l00002ooooo`;o000000?oooooo`000?l00000DOooool001cooooo00?o0000ooooooooool0
??ooool3o`0000Cooooo0_l00003ooooo`;o00001oooool2o`0000?ooooo0_l00006ooooo`;o0000
1?ooool2o`0000cooooo0_l00005ooooo`Go00000oooool2o`0000Cooooo0_l00002ooooo`?o0000
00?oooooo`000?l000000_ooool2o`0001[ooooo0_l00008ooooo`;o00002?ooool2o`000003oooo
ool0003o000002Oooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o0000DOooool001cooooo
00?o0000ooooooooool0?Oooool4o`0000Oooooo0_l00007ooooo`;o00000oooool2o`0000?ooooo
1Ol00004ooooo`;o00004oooool2o`0000Kooooo0_l00004ooooo`;o00000_ooool2o`0000;ooooo
0_l00002ooooo`Co00006?ooool2o`000003ooooool0003o000000Gooooo0_l00008ooooo`Go0000
:?ooool4o`0000[ooooo1?l00004ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0?ooo
ool4o`0000Sooooo0_l00008ooooo`;o00001?ooool4o`0000Gooooo0_l0000Cooooo`;o00006_oo
ool2o`0001;ooooo0_l00007ooooo`;o00000_ooool2o`0000Cooooo0_l00007ooooo`;o000000?o
ooooo`000?l000009_ooool2o`0000Wooooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l0
0011ooooo`007?ooool00ol0003oooooooooo`0Wooooo`;o00004oooool2o`0000?ooooo0_l00008
ooooo`;o00002?ooool2o`000003ooooool0003o0000023ooooo0ol00007ooooo`;o00004_ooool2
o`0000Cooooo1?l00007ooooo`;o000000?oooooo`000?l000002?ooool2o`0000Cooooo0_l00003
ooooo`;o00001Oooool2o`0000Oooooo0_l0000Xooooo`;o000000?oooooo`000?l000000_l00005
ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool09oooool2o`0001?ooooo0_l0000Joooo
o`;o00001_ooool3o`0001Oooooo0ol00007ooooo`;o00004?ooool4o`0000Cooooo1?l00007oooo
o`;o000000?oooooo`000?l000000_ooool2o`0000Wooooo0_l00004ooooo`;o00003_ooool3o`00
02[ooooo1?l00002ooooo`;o000000?oooooo`000?l00000@?ooool001cooooo00?o0000oooooooo
ool0@oooool3o`0001?ooooo0_l00005ooooo`Go00002_ooool2o`0001_ooooo0_l000000ooooooo
0000o`000005ooooo`?o00001Oooool2o`0000Wooooo0_l000000ooooooo0000o`000002ooooo`;o
00002Oooool4o`00013ooooo0_l000000ooooooo0000o`00000Uooooo`;o00000oooool3o`0000?o
oooo0_l00002ooooo`;o000000?oooooo`000?l00000??ooool001cooooo00?o0000ooooooooool0
@oooool4o`0001;ooooo0_l00006ooooo`Co00002?ooool4o`0000gooooo0_l00005ooooo`;o0000
1Oooool2o`000003ooooool0003o000000?o00001oooool2o`000003ooooool0003o000001[ooooo
0_l000000ooooooo0000o`00000@ooooo`;o0000:?ooool2o`0000Cooooo0_l00004ooooo`;o0000
00Coooooo`000?l0003ooooo0_l0000Booooo`;o0000:?ooool001cooooo00?o0000ooooooooool0
:oooool2o`0000_ooooo0_l0000;ooooo`;o00000_ooool2o`0001Gooooo0_l0000;ooooo`;o0000
3oooool2o`0000Gooooo0_l0000:ooooo`?o00001Oooool6o`0001_ooooo0_l000000ooooooo0000
o`000003ooooo`;o00001?ooool2o`0003Cooooo0_l00005ooooo`;o000000?oooooo`000?l00000
5Oooool2o`0002Sooooo000Looooo`03o`000?oooooooooo02_ooooo0_l0000;ooooo`;o00002ooo
ool2o`0000;ooooo0_l0000Eooooo`;o00001_ooool2o`0001Oooooo0_l0000Fooooo`Ko000000?o
ooooo`000?l000003_ooool2o`00013ooooo1?l00002ooooo`;o00009Oooool2o`0000?ooooo1?l0
0002ooooo`;o00000_ooool2o`0000Sooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0d
ooooo`;o00002oooool2o`0000Wooooo0ol00003ooooo`;o00005?ooool2o`0001Oooooo0_l00008
ooooo`;o00001_ooool2o`0000Kooooo1?l000001?oooooo0000o`000?ooool2o`0000_ooooo0_l0
000;ooooo`Ko000000?oooooo`000?l000000_l0000=ooooo`Co00005_ooool2o`0000?ooooo1?l0
0002ooooo`;o000000Coooooo`000?l0003o00003Oooool2o`0003[ooooo000Looooo`03o`000?oo
oooooooo02?ooooo0_l0000?ooooo`;o000000?oooooo`000?l000001Oooool2o`000003ooooool0
003o000000Wooooo0ol00003ooooo`Co00002?ooool2o`0002Sooooo0_l000000ooooooo0000o`00
0006ooooo`;o00001Oooool5o`0000;ooooo1Ol0000Gooooo`Ko00000oooool2o`000003ooooool0
003o000000[ooooo1?l0000Tooooo`?o00001oooool3o`0000?ooooo0_l0000jooooo`007?ooool2
o`0002Cooooo0_l0000Booooo`;o00001Oooool4o`0000Wooooo0ol00005ooooo`?o00002?ooool7
o`0002?ooooo0_l00008ooooo`;o00001Oooool6o`0000;ooooo0_l000000ooooooo0000o`000006
ooooo`;o00000oooool2o`0000[ooooo1_l00006ooooo`;o000000?oooooo`000?l000008_ooool2
o`000003ooooool0003o000001;ooooo0ol00006ooooo`;o0000=oooool001cooooo00?o0000oooo
ooooool0@?ooool2o`0000Kooooo0_l000001?oooooo0000o`000?l0000Booooo`Go000000?ooooo
o`000?l000002_ooool2o`0000cooooo0_l00004ooooo`;o00000_ooool2o`0000Kooooo0_l00005
ooooo`;o000000Coooooo`000?l0003o00000_ooool3o`0000Cooooo0_l00002ooooo`;o00000ooo
ool2o`0000cooooo0_l00007ooooo`;o00000_ooool2o`0001kooooo0_l00002ooooo`;o000000?o
ooooo`000?l000005oooool2o`0000;ooooo0_l0000gooooo`007?ooool00ol0003oooooooooo`0k
ooooo`;o00002oooool2o`0000?ooooo0_l0000;ooooo`;o00002_ooool2o`0000[ooooo0_l0000<
ooooo`;o00001?ooool2o`0000;ooooo0_l0000=ooooo`Go00001?ooool2o`000004ooooool0003o
0000ooooo`?o00003oooool7o`0000Oooooo0ol00002ooooo`;o00007Oooool2o`0000[ooooo0_l0
000Aooooo`?o0000>oooool001cooooo00?o0000ooooooooool0=_ooool2o`000003ooooool0003o
000000;o00001_ooool2o`0000Sooooo0_l00008ooooo`;o000000?oooooo`000?l000008?ooool2
o`000004ooooool0003o0000o`0000Cooooo0_l00004ooooo`;o00002oooool3o`0000Oooooo1?l0
0002ooooo`;o00000oooool4o`0000Sooooo1ol00004ooooo`;o00000_ooool2o`000005ooooool0
003o0000o`000?ooool00ol0000Uooooo`;o00004Oooool2o`0001Kooooo0_l0000Tooooo`007?oo
ool00ol0003oooooooooo`0fooooo`;o000000?oooooo`000?l000002?ooool2o`0000Sooooo0_l0
0007ooooo`?o000000?oooooo`000?l000002?ooool2o`00013ooooo0_l00004ooooo`;o000000Go
ooooo`000?l0003o0000ooooo`02o`0000Cooooo0_l000000ooooooo0000o`00000Cooooo`Co0000
0_ooool2o`0000Gooooo1Ol0000:ooooo`Co00001?ooool2o`0000Gooooo0_l00002ooooo`?o0000
9?ooool2o`0000Kooooo0_l00005ooooo`;o00006oooool2o`0002Cooooo000Looooo`03o`000?oo
oooooooo04Cooooo1?l0000>ooooo`;o000000Coooooo`000?l0003o00001Oooool5o`0000Kooooo
0_l00007ooooo`?o00002oooool2o`0000?ooooo0ol0000@ooooo`;o00000oooool4o`0000?ooooo
0_l00008ooooo`;o00002?ooool9o`0000Oooooo0_l00008ooooo`;o00008?ooool2o`0000Gooooo
0ol00005ooooo`?o00001Oooool2o`0003Wooooo000Looooo`03o`000?oooooooooo03cooooo0_l0
0006ooooo`Co00004Oooool3o`0000Gooooo1?l00002ooooo`;o00000_ooool3o`0000?ooooo0_l0
0002ooooo`Go000000?oooooo`000?l000002oooool2o`0000gooooo0_l00002ooooo`;o00000ooo
ool2o`000003ooooool0003o000001;ooooo0_l000000ooooooo0000o`000003o`0000;ooooo0ol0
00000ooooooo0000o`000004ooooo`;o00002?ooool2o`0000Gooooo0_l0000Iooooo`;o00001Ooo
ool2o`0000Oooooo0_l00005ooooo`;o0000>Oooool001cooooo00?o0000ooooooooool0:_ooool2
o`00013ooooo0_l00006ooooo`Co00005?ooool2o`0000?ooooo0ol00002ooooo`Oo00001?ooool2
o`0000;ooooo2?l00005ooooo`;o00001?ooool2o`0000Kooooo0_l00005ooooo`;o00001oooool2
o`000003ooooool0003o000000;o00000oooool2o`0000_ooooo1Ol00004ooooo`;o00000oooool4
o`000003ooooool0003o0000013ooooo0_l0000Kooooo`;o00002oooool2o`00047ooooo000Loooo
o`03o`000?oooooooooo02[ooooo0_l00008ooooo`;o00003_ooool4o`0000[ooooo1Ol000001Ooo
oooo0000o`000?l0003ooooo00;o00000oooool:o`0000[ooooo0ol00002ooooo`?o00001Oooool4
o`0000Cooooo0_l00004ooooo`;o00004oooool3o`0000;ooooo0_l00007ooooo`;o000000?ooooo
o`000?l000001?l00004ooooo`;o00000_ooool8o`0001;ooooo0ol0000<ooooo`;o00000_ooool4
o`0000Cooooo0_l0000;ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0=?ooool3o`00
00Wooooo0_l00002ooooo`?o00002oooool5o`000003ooooool0003o000000Co00001Oooool9o`00
01Sooooo0_l00003ooooo`Go000000?oooooo`000?l000004_ooool5o`0000[ooooo0ol000000ooo
oooo0000o`000002o`0000Sooooo1?l00002ooooo`Co00000oooool2o`0000gooooo0ol0000<oooo
o`;o00000_ooool4o`0000Wooooo0_l00019ooooo`007?ooool00ol0003oooooooooo`0eooooo`;o
00000oooool3o`0000?ooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000000Oo
oooo0_l00003ooooo`Co00001oooool8o`0001cooooo0_l000001?oooooo0000o`000?ooool2o`00
00Gooooo0_l00007ooooo`?o000000?oooooo`000?l000000_l00002ooooo`;o00001Oooool4o`00
00?ooooo0ol00006ooooo`Oo00000oooool2o`0000?ooooo0_l00008ooooo`;o00001oooool2o`00
00kooooo0_l0000:ooooo`;o00002?ooool2o`0003oooooo000Looooo`03o`000?oooooooooo02Wo
oooo0_l0000?ooooo`?o00002_ooool4o`000004ooooool0003o0000ooooo`;o00001?ooool2o`00
00Kooooo0_l000000ooooooo0000o`000002ooooo`_o00004_ooool2o`0001?ooooo1?l00005oooo
o`?o00000oooool2o`0000;ooooo0_l00003ooooo`Ko00000_ooool5o`0000;ooooo1Ol000000ooo
oooo0000o`000002o`0000?ooooo0_l00004ooooo`;o00001oooool3o`0000Kooooo0_l0000>oooo
o`;o00004oooool3o`0000Gooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0Yooooo`;o
00001oooool2o`0001?ooooo0ol00005ooooo`;o00003?ooool5o`0000;ooooo2ol0000Booooo`;o
00001_ooool2o`0000Gooooo0_l00006ooooo`;o00002oooool3o`0000Gooooo1ol00002ooooo`Ko
000000?oooooo`000?l000001ol00004ooooo`;o00000_ooool4o`0000Sooooo0_l000000ooooooo
0000o`00000Booooo`;o00005?ooool2o`0000Kooooo0_l0000hooooo`007?ooool00ol0003ooooo
ooooo`0booooo`;o00001Oooool3o`000003ooooool0003o000000?ooooo0ol00003ooooo`;o0000
3Oooool2o`0000Gooooo1_l00002ooooo`Wo00000_ooool2o`0000cooooo0_l00006ooooo`Co0000
1Oooool2o`0000Oooooo0_l00004ooooo`;o00001?ooool3o`0000;ooooo0_l000001?oooooo0000
o`000?ooool3o`0000;ooooo2_l000000ooooooo0000o`000007o`0000Gooooo2?l00007ooooo`;o
000000?oooooo`000?l000003?ooool2o`000003ooooool0003o000000;o00000oooool2o`0000Wo
oooo0_l00007ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0:Oooool2o`000003oooo
ool0003o000000_ooooo0ol000000ooooooo0000o`000003ooooo`Go00000_ooool2o`0000Wooooo
1Ol00004ooooo`Oo00000_ooool9o`0000;ooooo0_l0000<ooooo`;o00001_ooool2o`0000Gooooo
0_l00009ooooo`;o00000oooool3o`0000?ooooo1?l000001?oooooo0000o`000?l00003ooooo`Co
000000?oooooo`000?l000003Ol00002ooooo`Go00001?ooool2o`0000;ooooo1?l00005ooooo`;o
00000oooool2o`0000;ooooo0_l00008ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o
00001Oooool2o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l00000>oooool001cooooo
00?o0000ooooooooool0:Oooool2o`000003ooooool0003o000001?ooooo1_l00002ooooo`;o0000
2Oooool4o`0000Gooooo2Ol000000ooooooo0000o`000007o`0001kooooo0_l00009ooooo`;o0000
0oooool2o`000004ooooool0003o0000ooooo`Co000000?oooooo`000?l000000_ooool4o`0000?o
oooo3?l000000ooooooo0000o`000002ooooo`Go00000_ooool4o`0000_ooooo0_l00007ooooo`;o
00002oooool2o`0000cooooo0_l00008ooooo`;o00006oooool2o`00027ooooo000Looooo`;o0000
?_ooool2o`0000;ooooo1?l00004ooooo`?o00002Oooool2o`000003ooooool0003o000000Gooooo
1ol000000ooooooo0000o`000007o`0000_ooooo0_l0000Looooo`;o00000oooool5o`0000[ooooo
1?l000000ooooooo0000o`00000;o`000003ooooool0003o000000;o000000Coooooo`000?l0003o
00001?ooool4o`0000Cooooo0_l00006ooooo`;o00001_ooool2o`000003ooooool0003o000000ko
oooo0_l0000Aooooo`;o00006_ooool2o`00027ooooo000Looooo`03o`000?oooooooooo03?ooooo
0_l00004ooooo`;o000000Coooooo`000?l0003o00002oooool4o`0000[ooooo1?l00002ooooo`;o
00000oooool3o`000003ooooool0003o000000Oo00001?ooool6o`000003ooooool0003o0000023o
oooo1Ol0000=ooooob?o000000?oooooo`000?l000000_l00003ooooo`Co000000?oooooo`000?l0
00000_l00004ooooo`?o00003Oooool3o`0000Kooooo0_l00008ooooo`;o0000?Oooool001cooooo
00?o0000ooooooooool0<oooool2o`0000Cooooo0_l000000ooooooo0000o`00000;ooooo`;o0000
00Coooooo`000?l0003o00002oooool2o`0000;ooooo0_l00003ooooo`Wo00000_ooool2o`0000Co
oooo1ol00004ooooo`;o00006?ooool2o`0000;ooooo0_l000000ooooooo0000o`000008ooooo`;o
000000?oooooo`000?l000007_l000000ooooooo0000o`000007o`0000?ooooo0ol00002ooooo`Ko
00000oooool2o`0000cooooo1?l00005ooooo`?o00009_ooool2o`0001oooooo000Looooo`03o`00
0?oooooooooo03Wooooo1?l00003ooooo`;o00001oooool2o`0000;ooooo0ol00002ooooo`;o0000
3oooool=o`0000Wooooo0_l00004ooooo`;o00005Oooool2o`000004ooooool0003o0000ooooo`;o
00003?ooool2o`000004ooooool0003o0000o`0000?ooooo8Ol00007ooooo`Go00000_ooool3o`00
017ooooo0_l00007ooooo`?o00009_ooool2o`0001oooooo000Looooo`03o`000?oooooooooo02co
oooo0_l0000:ooooo`Go00000oooool2o`0000cooooo0_l000001?oooooo0000o`000?l00003oooo
o`;o00003?ooool<o`0001Kooooo0_l0000;ooooo`Co00001?ooool2o`0000Cooooo0_l00003oooo
o`;o00000oooool4o`000003ooooool0003o0000023o00000oooool2o`0000Gooooo0ol00002oooo
o`;o00008_ooool2o`0000Gooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o
00002_ooool2o`0001Cooooo0_l000000ooooooo0000o`000004ooooo`;o00002oooool2o`0000?o
oooo2?l00002ooooo`;o00004_ooool2o`0000_ooooo0_l0000<ooooo`;o00000oooool2o`000003
ooooool0003o000001oo000000?oooooo`000?l000003Ol00002ooooo`;o00000_ooool5o`0000?o
oooo0_l0000Kooooo`?o000000Coooooo`000?l0003ooooo0_l0000jooooo`007?ooool00ol0003o
ooooooooo`0kooooo`;o00001_ooool2o`000003ooooool0003o000000Kooooo1_l00004ooooo`;o
00002_ooool2o`000003ooooool0003o000000Wo000000?oooooo`000?l000001oooool2o`0002Wo
oooo0_l000000ooooooo0000o`000004oooooboo00000_ooool5o`0000?ooooo0_l00007ooooo`;o
00000_ooool2o`0000oooooo0_l000001?oooooo0000o`000?ooool2o`0003[ooooo000Looooo`03
o`000?oooooooooo03[ooooo0ol00006ooooo`;o000000?oooooo`000?l000000oooool2o`0000?o
oooo1Ol00003ooooo`?o00003?ooool3o`0000;ooooo1_l0000:ooooo`;o00000oooool2o`0000ko
oooo0_l0000Booooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo9Ol00003ooooo`Go
00001Oooool2o`000003ooooool0003o000000_ooooo0_l00002ooooo`;o000000?oooooo`000?l0
00001Oooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l0000jooooo`00
7?ooool00ol0003oooooooooo`0`ooooo`Co00000_ooool2o`0000;ooooo0_l0000?ooooo`;o0000
1_ooool2o`0000Cooooo0_l00002ooooo`;o00002Oooool;o`0000kooooo0_l0000>ooooo`;o0000
2?ooool2o`0000Oooooo0ol000000ooooooo0000o`000002ooooo`;o00000_ooool3o`000003oooo
ool0003o000001_o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000005ooooo`;o
00001?ooool2o`0001;ooooo0_l00005ooooo`;o000000Goooooo`000?l0003o0000ooooo`04o`00
00;ooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`0`ooooo`Co00000_ooool2o`0000[o
oooo0_l00009ooooo`;o00003_ooool2o`0000Gooooo0_l000000ooooooo0000o`00000=o`0000;o
oooo0_l0000Qooooo`?o00001_ooool2o`0000Sooooo9Ol000001?oooooo0000o`000?l00008oooo
o`;o000000Coooooo`000?l0003ooooo0_l00006ooooo`?o00004oooool2o`0000?ooooo0_l0000o
ooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00002_ooool2o`0000Oooooo1?l00006oooo
o`;o00003Oooool2o`000003ooooool0003o000000go00000_ooool4o`0000?ooooo0_l0000Koooo
o`;o00000_ooool2o`0000cooooo8Ol000000ooooooo0000o`000004o`0000Sooooo0_l00002oooo
o`;o000000?oooooo`000?l000001_ooool3o`0005Wooooo000Looooo`03o`000?oooooooooo03Ko
oooo1?l000000ooooooo0000o`00000>ooooo`;o00000_ooool2o`0000Cooooo0_l00008ooooo`;o
00002?ooool2o`0000;ooooo2?l00005ooooo`;o00000oooool2o`0000;ooooo0_l0000Aooooo`;o
00002?ooool2o`0000[ooooo9?l00002ooooo`;o00002_ooool2o`0001_ooooo0_l0001<ooooo`00
7?ooool00ol0003oooooooooo`0hooooo`;o000000?oooooo`000?l000003_ooool6o`0000_ooooo
0_l000000ooooooo0000o`00000;ooooo`Wo00002oooool2o`000003ooooool0003o0000017ooooo
0_l00002ooooo`;o00004?ooool3o`000003ooooool0003o0000027o00001Oooool3o`0001_ooooo
0_l00003ooooo`;o00002?ooool2o`0004;ooooo000Looooo`03o`000?oooooooooo02Wooooo0_l0
0008ooooo`;o00005_ooool4o`0000gooooo0_l00005ooooo`Co00001Oooool<o`0000Sooooo0_l0
000Hooooo`;o00000oooool2o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`oo00000ooo
ool@o`000003ooooool0003o000000;o000000Coooooo`000?l0003ooooo0ol0000Kooooo`;o0000
1oooool4o`0000;ooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`0Yooooo`;o000000?o
ooooo`000?l000001Oooool2o`0000;ooooo0_l0000=ooooo`;o00000oooool2o`0001Kooooo1?l0
0004ooooo`go00000oooool2o`0001gooooo0_l00003ooooo`;o00001?ooool5o`000003ooooool0
003o0000013o000000Goooooo`000?l0003o0000ooooo`0=o`000003ooooool0003o000000;o0000
00Coooooo`000?l0003o00008Oooool4o`0000;ooooo1?l00009ooooo`;o0000>oooool001cooooo
00?o0000ooooooooool0;?ooool2o`0000Wooooo0_l0000=ooooo`;o00005_ooool2o`0000?ooooo
0_l00006ooooo`co000000Coooooo`000?l0003ooooo0_l0000Jooooo`;o000000?oooooo`000?l0
00002Oooool5o`000003ooooool0003o000000?ooooo3Ol000000ooooooo0000o`00000?o`000003
ooooool0003o000000;o00000_ooool2o`0000Kooooo0_l0000Iooooo`Co00002oooool2o`0000;o
oooo0_l0000kooooo`007?ooool2o`0003gooooo0_l0000;ooooo`;o00004oooool2o`0000;ooooo
0ol00009ooooo`Ko000000?oooooo`000?l000001?l0000Cooooo`;o00001oooool3o`0000Oooooo
0_l00005ooooo`;o000000Coooooo`000?l0003o00000_ooool=o`000003ooooool0003o0000017o
000000Coooooo`000?l0003o00000_ooool4o`0000?ooooo0_l00002ooooo`;o00004_ooool2o`00
00[ooooo0_l000001?oooooo0000o`000?ooool2o`0003oooooo000Looooo`03o`000?oooooooooo
03Wooooo0_l000000ooooooo0000o`00000;ooooo`;o00005Oooool4o`0000;ooooo0_l00006oooo
o`go00004?ooool2o`000003ooooool0003o000000Cooooo0ol000000ooooooo0000o`000005oooo
o`Co00001ooooolWo`000004ooooool0003o0000o`0000;ooooo1?l000000ooooooo0000o`000004
ooooo`;o00004_ooool2o`0000Gooooo0_l00003ooooo`Go000000?oooooo`000?l00000?oooool0
01cooooo00?o0000ooooooooool0>Oooool2o`0002Gooooo0_l00004ooooo`;o00001Oooool8o`00
0003ooooool0003o000000;o00004Oooool2o`0000Kooooo1?l000000ooooooo0000o`000005oooo
o`;o00000_ooool2o`0000Gooooo1_l00002oooooa;o000000?oooooo`000?l000002ol00002oooo
o`;o00000oooool2o`000003ooooool0003o000000cooooo0_l0000Aooooo`;o00000oooool4o`00
00;ooooo0ol0000nooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o00001_ooool2o`0001_o
oooo0_l0000Booooo`;o00001?ooool@o`0000?ooooo0_l0000Booooo`;o00000oooool2o`0000Wo
oooo0_l00006ooooo`_o000000?oooooo`000?l000007Ol00002ooooo`;o00001_ooool2o`0000Go
oooo0_l000000ooooooo0000o`000008ooooo`;o00003?ooool4o`0000?ooooo0_l0000nooooo`00
7?ooool00ol0003oooooooooo`0]ooooo`;o00001_ooool2o`0001[ooooo0ol0000Dooooo`;o0000
00?oooooo`000?l000004?l00002ooooo`;o00004_ooool2o`0001Sooooo:?l00003ooooo`;o0000
00?oooooo`000?l000000oooool2o`000003ooooool0003o000000;ooooo0_l00003ooooo`;o0000
1?ooool4o`0000Wooooo0_l00009ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0<_oo
ool3o`0001Oooooo0_l00003ooooo`;o00001?ooool2o`0000Sooooo0_l00005oooooa;o000000Co
ooooo`000?l0003o00005Oooool2o`0000Kooooo0_l00005ooooo`;o00002_oooolYo`0000Cooooo
0_l00006ooooo`;o00001_ooool3o`0000Cooooo0_l00006ooooo`;o00000oooool2o`0000Oooooo
1?l0000Iooooo`;o00008_ooool001cooooo00?o0000ooooooooool0<_ooool3o`0000Cooooo0_l0
000@ooooo`?o00002Oooool2o`0000Sooooo0_l00006ooooo`;o000000?oooooo`000?l000001?l0
00000ooooooo0000o`000009o`0000[ooooo0_l00005ooooo`;o00002Oooool3o`0000Gooooo0_l0
0004ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00000To`000003oooo
ool0003o000000?ooooo0_l0000:ooooo`Co00003Oooool2o`0000cooooo1?l0000Iooooo`;o0000
8_ooool001cooooo00?o0000ooooooooool0<_ooool3o`0000Cooooo0_l0000@ooooo`?o00001_oo
ool2o`0000;ooooo0_l00009ooooo`;o00000ooooolFo`0000;ooooo0_l00006ooooo`;o00001Ooo
ool2o`0000Wooooo0_l000000ooooooo0000o`000009ooooo`So000000?oooooo`000?l000005_l0
00000ooooooo0000o`00000?o`0000;ooooo0_l000000ooooooo0000o`000007ooooo`;o0000G_oo
ool001cooooo00?o0000ooooooooool0<_ooool2o`0000Cooooo1?l0000Hooooo`;o00000_ooool2
o`0000Wooooo0_l00003oooooa[o00001oooool2o`0000_ooooo1?l00003ooooo`?o00002Oooool/
o`000003ooooool0003o000000?o00000_ooool7o`0002Gooooo0_l0000nooooo`007?ooool00ol0
003oooooooooo`0Rooooo`;o00005?ooool5o`0002kooooo5_l00008ooooo`;o00002oooool4o`00
00Cooooo0_l00004ooooo`;o00001?ooool4o`000003ooooool0003o000001go00001?ooool5o`00
00Kooooo1ol00006ooooo`;o00006?ooool2o`000003ooooool0003o000000;o0000?_ooool001co
oooo00?o0000ooooooooool08_ooool2o`0001Oooooo0_l0000Cooooo`;o00005_oooolJo`0000Co
oooo0_l000000ooooooo0000o`00000Iooooo`;o00001?ooool4o`0000?ooooo8Ol000000ooooooo
0000o`000004o`0000Sooooo0ol00006ooooo`;o00003?ooool2o`0000[ooooo0_l000000ooooooo
0000o`000010ooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00005?ooool=o`000003oooo
ool0003o000000ko00000_ooool2o`000004ooooool0003o0000o`0001Gooooo0_l00008ooooo`?o
00000_oooolRo`0000Gooooo0_l00005ooooo`Ko00002Oooool2o`0000Wooooo0_l0001?ooooo`00
7?ooool00ol0003oooooooooo`16ooooo`;o00001?ooool2o`0000Gooooo0_l00009ooooo`;o0000
1_ooool2o`0000?ooooo6Ol00006ooooo`;o00002Oooool2o`0000[ooooo1?l00006ooooo`;o0000
0oooool2o`0000;ooooo1?l000000ooooooo0000o`00000Ho`0000Cooooo0_l00004ooooo`Oo0000
00?oooooo`000?l000001Ol000000ooooooo0000o`00000Xooooo`;o0000<?ooool001cooooo00?o
0000ooooooooool0@oooool7o`0000;ooooo0_l00005ooooo`;o00001_ooool2o`000003ooooool0
003o000000Sooooo7?l0000Aooooo`;o000000Coooooo`000?l0003o00002?ooool2o`0000Sooooo
1?l00007ooooo`Oo000000?oooooo`000?l000003_l000000ooooooo0000o`000002o`0000;ooooo
1?l00002ooooo`;o00000oooool:o`0000cooooo0_l0000;ooooo`;o00004?ooool2o`00033ooooo
00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@
4?o<c<`01_ooool00ol0003oooooooooo`0iooooo`Co00000_ooool2o`0000;ooooo0ol00002oooo
o`;o00002_ooool2o`0000Gooooo0_l0000;ooooo`Co000000?oooooo`000?l000005ol00002oooo
o`;o00003_ooool3o`0001;ooooo1?l00002oooooaWo00000_ooool8o`0000?ooooo0ol00006oooo
o`?o00001?ooool2o`0000;ooooo0_l00004ooooo`;o00000oooool2o`000004ooooool0003o0000
ooooo`;o00001Oooool2o`0004;ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ
8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0iooooo`Go0000
00?oooooo`000?l000000ol000000ooooooo0000o`000007ooooo`;o00001?ooool2o`0001;ooooo
1?l000000ooooooo0000o`00000Go`0000;ooooo0_l00005ooooo`;o00001_ooool4o`0001Sooooo
1Ol000000ooooooo0000o`000006o`000003ooooool0003o000000So000000Coooooo`000?l0003o
oooo1_l00003ooooo`?o00001?ooool2o`0000_ooooo0_l00004ooooo`;o00001Oooool3o`000003
ooooool0003o000000Cooooo0_l000000ooooooo0000o`00000Hooooo`;o00009_ooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool0??ooool2o`0000;ooooo1?l000000ooooooo0000o`000005ooooo`Co
000000?oooooo`000?l000001_ooool2o`0000gooooo0_l00003oooooaWo00000_ooool2o`0000Go
oooo0_l00006ooooo`;o00004Oooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool:o`000003
ooooool0003o000000Go000000?oooooo`000?l000000ol00004ooooo`;o00002Oooool4o`0001;o
oooo0_l00004ooooo`;o00002?ooool2o`000003ooooool0003o000001Sooooo0_l0000Vooooo`00
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ
8B401_ooool3o`00043ooooo0ol00009ooooo`?o00000_ooool2o`0000Kooooo0_l00005ooooo`;o
00002ooooolEo`000004ooooool0003o0000o`0000;ooooo0_l0000Kooooo`;o00000oooool2o`00
00;ooooo0ol000001?oooooo0000o`000?l00002ooooo`[o000000?oooooo`000?l000001_l00002
ooooo`;o00001Oooool2o`0000Wooooo0_l00005ooooo`;o00003Oooool2o`0000;ooooo0_l0000=
ooooo`;o0000@?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0
003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0??ooool2o`0000;ooooo0ol0000:
ooooo`;o00001?ooool4o`0000Gooooo0_l00002ooooo`;o00003OoooolGo`0000cooooo1?l0000?
ooooo`Co00001Oooool3o`000003ooooool0003o000000;o00000oooool8o`000004ooooool0003o
0000ooooo`Go00001Oooool2o`0000Sooooo1Ol00004ooooo`;o000000?oooooo`000?l000004Ooo
ool2o`0000_ooooo0_l00012ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09
ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool09oooool2o`0001?ooooo0_l0000>
ooooo`Ko000000?oooooo`000?l000000_l00005ooooo`;o00004ooooolFo`0000;ooooo0_l00007
ooooo`Co00000_ooool2o`0000Kooooo0_l00002ooooo`;o000000?oooooo`000?l000001?ooool3
o`0000;ooooo1?l000000ooooooo0000o`000007o`000004ooooool0003o0000o`0000Cooooo0ol0
0002ooooo`Go00001oooool5o`000003ooooool0003o000000?o00003Oooool4o`0000Sooooo0_l0
00000ooooooo0000o`000003ooooo`;o00001?ooool2o`0003cooooo00001_ooooooMgMgoiRHV?oo
ooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0Wooooo`;o0000
6Oooool2o`0000Cooooo0_l00002ooooo`Ko00008?oooolFo`000003ooooool0003o000000Kooooo
0_l000000ooooooo0000o`000002ooooo`;o00001_ooool2o`0000;ooooo0_l00007ooooo`;o0000
2?ooool9o`000003ooooool0003o000000Co00000_ooool2o`0000;ooooo1Ol00003ooooo`;o0000
0oooool3o`0000;ooooo1?l00004ooooo`;o00001_ooool6o`0000Sooooo0_l000000ooooooo0000
o`000009ooooo`;o0000??ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<co
A4A4o`000?l@4106ooooo`03o`000?oooooooooo03oooooo1Ol00004ooooo`;o00001?ooool2o`00
01Oooooo0_l00009oooooa7o00000_ooool5o`0000Oooooo0_l000000ooooooo0000o`000002oooo
o`;o00005_ooool2o`0000Cooooo1ol000000ooooooo0000o`000003ooooo`Co00000_ooool3o`00
00?ooooo0_l000001?oooooo0000o`000?ooool3o`0000?ooooo0_l0000:ooooo`;o00001_ooool2
o`0000Gooooo0_l00003ooooo`Co000000?oooooo`000?l000000_l00015ooooo`007?ooool00ol0
003oooooooooo`0oooooo`Co00001_ooool4o`000003ooooool0003o000000?ooooo0_l00007oooo
o`;o00001oooool4o`000003ooooool0003o000000;o00001_ooool@o`000003ooooool0003o0000
00?o00002_ooool6o`0001Kooooo0_l00004ooooo`;o00000_ooool3o`0000;ooooo1_l00004oooo
o`?o00001_ooool2o`0000;ooooo0_l00008ooooo`;o00005?ooool2o`0000?ooooo0_l00004oooo
o`Go0000@oooool001cooooo00?o0000ooooooooool0=oooool2o`00013ooooo1?l000000ooooooo
0000o`000003ooooo`Co00001Oooool2o`0000Oooooo0_l00003ooooo`Co00001_oooolDo`0000;o
oooo0_l0000:ooooo`?o000000?oooooo`000?l000002oooool2o`00017ooooo0ol000000ooooooo
0000o`000004o`0000Kooooo0_l00009ooooo`;o00002Oooool3o`0001Cooooo0_l00009ooooo`Co
0000@oooool001cooooo00?o0000ooooooooool0=oooool2o`0000Cooooo0_l0000?ooooo`;o0000
0oooool4o`0001kooooo4ol00002ooooo`Co00003?ooool2o`0000_ooooo0_l0000Booooo`;o0000
00Coooooo`000?l0003ooooo1Ol00004ooooo`;o00001_ooool2o`000003ooooool0003o000000;o
oooo0_l00006ooooo`;o00005?ooool2o`0000Gooooo0_l00004ooooo`;o0000@oooool001cooooo
00?o0000ooooooooool0?Oooool2o`0000;ooooo0_l0000>ooooo`Go00007Oooool2o`0000?ooooo
3Ol000000ooooooo0000o`000002o`000004ooooool0003o0000o`0000Sooooo0_l00002ooooo`;o
00003?ooool2o`0001Oooooo0_l000000ooooooo0000o`000002ooooo`Co00001_ooool2o`0000Go
oooo0_l00002ooooo`;o00002Oooool2o`00013ooooo0_l00002ooooo`Co00000_ooool4o`00047o
oooo000Looooo`03o`000?oooooooooo03Gooooo0_l0000:ooooo`;o000000?oooooo`000?l00000
1oooool2o`0000;ooooo0_l0000Eooooo`Co00001oooool2o`0000Cooooo3_l000001?oooooo0000
o`000?ooool2o`0000Wooooo0_l0000@ooooo`?o00003_ooool2o`0000gooooo1_l00004ooooo`?o
00000_ooool2o`0000Cooooo0_l00007ooooo`Co00000_ooool2o`0000;ooooo0_l00008ooooo`;o
00001?ooool2o`0000;ooooo1?l00011ooooo`007?ooool00ol0003oooooooooo`0eooooo`;o0000
2_ooool2o`000003ooooool0003o000000Cooooo0_l000001?oooooo0000o`000?l00006ooooo`;o
00004?ooool4o`0000Sooooo0_l00003ooooo`ko000000Coooooo`000?l0003o00002oooool2o`00
0003ooooool0003o000000;ooooo0_l00003ooooo`;o00001Oooool2o`0000kooooo0_l0000;oooo
o`?o000000?oooooo`000?l000000_l00005ooooo`;o00000_ooool2o`0000gooooo0_l00004oooo
o`;o00000_ooool2o`0000_ooooo0_l000000ooooooo0000o`000017ooooo`007?ooool00ol0003o
ooooooooo`0fooooo`;o00000oooool2o`0000gooooo0_l00002ooooo`;o00001_ooool2o`0001co
oooo0_l00002ooooo`Co00000_ooool8o`0000?ooooo0_l00003ooooo`;o00002Oooool6o`0000?o
oooo0_l0000;ooooo`;o00002?ooool2o`0000_ooooo0ol00002ooooo`;o00003?ooool2o`0000Ko
oooo1?l0000Hooooo`;o000000?oooooo`000?l000000_l00015ooooo`007?ooool00ol0003ooooo
ooooo`0fooooo`;o00000oooool2o`00017ooooo0_l0000Fooooo`;o00004?ooool2o`000003oooo
ool0003o000000Ko00002oooool2o`0000Cooooo0_l00003ooooo`Co00002?ooool2o`0000Sooooo
0_l0000;ooooo`;o00006oooool2o`0000Kooooo1?l00005ooooo`;o00005_ooool2o`0004Gooooo
000Looooo`03o`000?oooooooooo03Cooooo0_l00004ooooo`;o00001oooool2o`0000Kooooo0_l0
0009ooooo`;o00003_ooool2o`0000Oooooo0_l000000ooooooo0000o`000007ooooo`Oo00000_oo
ool2o`0000Sooooo0_l00004ooooo`;o00000oooool4o`0000Sooooo0_l0000Booooo`;o000000?o
ooooo`000?l000004?ooool2o`0000;ooooo0_l00003ooooo`;o00001Oooool2o`000003ooooool0
003o000000Oooooo0_l00008ooooo`;o00003Oooool2o`0004Cooooo000Looooo`03o`000?oooooo
oooo03Cooooo0_l00004ooooo`;o00001oooool2o`0000Kooooo0_l00008ooooo`?o00004Oooool2
o`0000Cooooo0_l000000ooooooo0000o`000009ooooo`?o00001?ooool2o`0000Cooooo0_l00004
ooooo`?o00001_ooool4o`0000kooooo0_l00008ooooo`;o00000_ooool2o`0001?ooooo0ol00000
0ooooooo0000o`000003ooooo`Co00000oooool2o`000003ooooool0003o0000017ooooo0ol00004
ooooo`;o000000?oooooo`000?l000000oooool2o`0004Cooooo000Looooo`03o`000?oooooooooo
03[ooooo0_l0000Aooooo`;o00001_ooool3o`00017ooooo0_l00007ooooo`;o00002Oooool2o`00
00[ooooo1Ol00002ooooo`?o00001?ooool2o`0000;ooooo0ol0000;ooooo`Co00002?ooool2o`00
01Cooooo0_l00002ooooo`;o00002?ooool2o`0000Gooooo0_l000000ooooooo0000o`00000@oooo
o`;o00001?ooool7o`000003ooooool0003o000004Cooooo000Looooo`;o0000C_ooool2o`0000Oo
oooo0_l0000Jooooo`;o00002Oooool2o`0000[ooooo1Ol00008ooooo`?o000000?oooooo`000?l0
00000_l0000;ooooo`;o00005oooool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o
00003oooool2o`000003ooooool0003o000000Gooooo0_l000000ooooooo0000o`00000>ooooo`;o
000000?oooooo`000?l00000Aoooool001cooooo00?o0000ooooooooool0J?ooool2o`000003oooo
ool0003o000002Wooooo0ol000000ooooooo0000o`00000:ooooo`;o00006_ooool2o`000003oooo
ool0003o000000Cooooo0_l00008ooooo`;o00002_ooool2o`0000Oooooo0_l000000ooooooo0000
o`000009ooooo`;o0000Coooool001cooooo00?o0000ooooooooool0Coooool2o`000003ooooool0
003o000001Cooooo1Ol00008ooooo`?o00001oooool2o`0001Sooooo1?l00009ooooo`;o00000_oo
ool2o`0002Cooooo0ol000001?oooooo0000o`000?l00006ooooo`;o00000_ooool4o`0000Oooooo
0_l0000:ooooo`;o000000?oooooo`000?l000005_ooool2o`0003Cooooo000Looooo`03o`000?oo
oooooooo04oooooo0_l000000ooooooo0000o`000005o`00017ooooo0ol00008ooooo`?o00001ooo
ool2o`0001Sooooo1_l00005ooooo`;o00001?ooool2o`00013ooooo0_l000000ooooooo0000o`00
0006ooooo`;o000000?oooooo`000?l000001?ooool6o`0000Oooooo0_l00004ooooo`;o00001ooo
ool2o`0000gooooo1?l00006ooooo`;o00003?ooool2o`0003Cooooo000Looooo`03o`000?oooooo
oooo02kooooo0_l0000Dooooo`;o00003Oooool7o`00017ooooo0_l00003ooooo`;o00004?ooool2
o`0001Gooooo0_l000001?oooooo0000o`000?l00005ooooo`;o00001_ooool2o`0000gooooo0ol0
00000ooooooo0000o`000006ooooo`Go00001oooool3o`0000cooooo0_l00006ooooo`;o00004Ooo
ool2o`0000Kooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00005?ooool2
o`0001;ooooo0_l00006ooooo`;o00002?ooool2o`0000?ooooo0ol00004ooooo`;o00002_ooool2
o`0000Wooooo0_l00009ooooo`?o000000Coooooo`000?l0003o00003Oooool2o`0000gooooo0_l0
0002ooooo`;o00002?ooool2o`0000Wooooo0_l00003ooooo`;o00001Oooool6o`0000Cooooo0_l0
0003ooooo`;o0000F?ooool001cooooo00?o0000ooooooooool0@?ooool2o`0001cooooo1?l00006
ooooo`Co00000oooool2o`0000Gooooo0ol0000>ooooo`;o000000?oooooo`000?l000000ol00000
0ooooooo0000o`000006ooooo`?o000000Coooooo`000?l0003o00001_ooool2o`0000;ooooo0ol0
000:ooooo`;o00001oooool2o`0000Wooooo0_l00009ooooo`;o00000_ooool3o`0000Cooooo0_l0
0002ooooo`;o00002Oooool4o`0000Kooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`10
ooooo`?o00003?ooool2o`000003ooooool0003o000000[ooooo0_l00008ooooo`;o00001?ooool2
o`0000Oooooo0_l0000>ooooo`Oo00000_ooool4o`0000Sooooo0ol00006ooooo`;o00000_ooool3
o`0000[ooooo0_l0000Booooo`;o00000_ooool2o`0000Gooooo0_l00003ooooo`;o00002?ooool2
o`0000_ooooo0_l00005ooooo`?o0000C_ooool001cooooo00?o0000ooooooooool0@Oooool2o`00
00cooooo0_l000000ooooooo0000o`000002ooooo`;o00005_ooool2o`0000Oooooo0_l0000?oooo
o`;o00001?ooool2o`0000;ooooo1?l00005ooooo`Co00001_ooool2o`0000_ooooo0_l0000Joooo
o`;o00002oooool2o`0000Oooooo0_l00007ooooo`;o00001Oooool2o`0000;ooooo0ol0001>oooo
o`007?ooool00ol0003oooooooooo`1Fooooo`;o00001Oooool2o`0000_ooooo1?l0000Looooo`;o
00000_ooool2o`0000;ooooo1?l00005ooooo`Co00000oooool2o`000003ooooool0003o000000Co
oooo0_l00004ooooo`?o00001_ooool4o`0001_ooooo1?l00005ooooo`Oo00000_ooool4o`0000?o
oooo1?l000000ooooooo0000o`00001@ooooo`007?ooool00ol0003oooooooooo`0looooo`;o0000
0oooool2o`0001[ooooo0_l0000;ooooo`Co00000oooool2o`0001Oooooo0_l0000=ooooo`;o0000
0_ooool2o`0000?ooooo0_l00004ooooo`Go00001?ooool2o`0000?ooooo2?l0000=ooooo`;o0000
3?ooool5o`0000Cooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00005ooooo`;o0000
0oooool2o`00053ooooo000Looooo`03o`000?oooooooooo03cooooo0_l00003ooooo`;o0000;?oo
ool4o`0000Gooooo0_l0000<ooooo`;o00002Oooool4o`0000Cooooo0_l00002ooooo`?o00002?oo
ool3o`0000[ooooo1_l0000@ooooo`;o00001Oooool2o`0000Sooooo0_l0000Eooooo`;o00003_oo
ool2o`0004Cooooo000Looooo`03o`000?oooooooooo04Cooooo1?l00009ooooo`;o00002_ooool2
o`0000[ooooo0_l000001?oooooo0000o`000?ooool2o`0000Oooooo0_l0000<ooooo`;o00000_oo
ool;o`0000Sooooo0ol0000@ooooo`;o00000oooool4o`0001;ooooo0_l00005ooooo`;o00002?oo
ool2o`00013ooooo0_l00003ooooo`;o00003_ooool2o`0004Cooooo000Looooo`03o`000?oooooo
oooo04Cooooo1?l00009ooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o
000000;o00002?ooool2o`000003ooooool0003o000000_ooooo1?l00009ooooo`;o000000?ooooo
o`000?l000002?l0000Mooooo`;o00004oooool2o`0000;ooooo1?l0000Qooooo`;o0000FOooool0
01cooooo00?o0000ooooooooool0AOooool3o`0000[ooooo1?l00004ooooo`;o00000oooool2o`00
00Gooooo0_l000001?oooooo0000o`000?ooool2o`0000_ooooo1?l00009ooooo`go000000Cooooo
o`000?l0003ooooo0_l00002ooooo`;o00001Oooool2o`0000Sooooo0_l0000Gooooo`;o00000_oo
ool4o`0000?ooooo0_l00003ooooo`?o00004?ooool2o`0000Sooooo0_l000000ooooooo0000o`00
001Booooo`007?ooool00ol0003oooooooooo`15ooooo`?o00002_ooool2o`0001;ooooo0_l0000F
ooooo`;o00000_oooolDo`000003ooooool0003o000000Co00001Oooool2o`0000Sooooo0_l0000R
ooooo`;o00000oooool3o`00013ooooo0_l00003ooooo`;o00000oooool2o`000004ooooool0003o
0000o`00057ooooo000Looooo`;o0000AOooool2o`00027ooooo0_l0000Cooooo`Co00000_oooolD
o`000003ooooool0003o000000?o00004oooool2o`0001Cooooo0_l0000<ooooo`Oo00002?ooool2
o`0000;ooooo0_l00004ooooo`?o00000oooool2o`0000;ooooo0_l0001Aooooo`007?ooool00ol0
003oooooooooo`14ooooo`;o00008Oooool2o`0001?ooooo0_l00006ooooo`?o000000?oooooo`00
0?l000003Ol0000;ooooo`;o00002oooool2o`0000Cooooo0_l0000>ooooo`;o00003?ooool2o`00
00?ooooo0_l00008ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o00001?ooool2
o`0001?ooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00008?ooool2o`00
00;ooooo0_l0000Dooooo`;o00000_oooolCo`0000_ooooo0_l00003ooooo`;o00002?ooool2o`00
00;ooooo0_l0000Cooooo`Co000000?oooooo`000?l000002oooool2o`0000[ooooo0ol0000Loooo
o`;o0000@?ooool001cooooo00?o0000ooooooooool0?oooool2o`0000?ooooo0_l00004ooooo`;o
00006_ooool2o`0000;ooooo0_l00009ooooo`;o00002Oooool3o`000003ooooool0003o0000017o
00002oooool2o`0000?ooooo0_l00003ooooo`;o00000oooool4o`0000Oooooo0_l00006ooooo`;o
00001?ooool4o`000003ooooool0003o000000_ooooo0_l00003ooooo`;o00000oooool4o`0005oo
oooo000Looooo`03o`000?oooooooooo03oooooo0_l00009ooooo`;o0000:Oooool2o`0000[ooooo
6Ol000001?oooooo0000o`000?ooool4o`0000[ooooo0_l00005ooooo`;o00000oooool2o`0000;o
oooo0_l00006ooooo`;o00002?ooool2o`0000Kooooo0_l00009ooooo`?o00000_ooool2o`0000[o
oooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`1iooooo`;o00002?oooolGo`000004oooo
ool0003o0000ooooo`Co00000oooool2o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`;o
000000?oooooo`000?l000000_l00002ooooo`;o000000Coooooo`000?l0003o00003?ooool2o`00
00?ooooo1Ol000000ooooooo0000o`000007ooooo`?o00003Oooool2o`0005Gooooo000Looooo`03
o`000?oooooooooo04;ooooo0_l0000Uooooo`;o00003_ooool2o`0000Sooooo5?l0000>ooooo`Co
000000Coooooo`000?l0003ooooo0_l00004ooooo`Ko00000oooool6o`000003ooooool0003o0000
00Cooooo0_l00006ooooo`[o00001?ooool2o`0000;ooooo0_l00009ooooo`;o0000FOooool001co
oooo00?o0000ooooooooool0@Oooool3o`0002Gooooo0_l0000HoooooaCo00004?ooool2o`0000_o
oooo1Ol00004ooooo`;o00001?ooool2o`0000Cooooo0_l00006ooooo`Go00000_ooool4o`0000?o
oooo1?l00009ooooo`Co0000FOooool001cooooo00?o0000ooooooooool0>_ooool2o`0000Gooooo
0_l0000noooooaKo00002Oooool3o`0001;ooooo0ol00006ooooo`?o00000_ooool2o`0000Gooooo
0_l00002ooooo`;o00002?ooool4o`0000Gooooo1?l00006ooooo`?o0000Foooool001cooooo00?o
0000ooooooooool0>_ooool2o`0002Cooooo0_l00007ooooo`;o00005_oooolFo`0000Sooooo1?l0
000Booooo`;o00001oooool3o`0000;ooooo0_l00005ooooo`?o000000?oooooo`000?l000001ooo
ool5o`0000?ooooo0_l00002ooooo`;o00001Oooool3o`0005cooooo000Looooo`03o`000?oooooo
oooo04Oooooo0_l0000Booooo`;o00000oooool2o`0000Oooooo0_l00005ooooo`;o00001?ooool2
o`0000Cooooo0_l00004oooooaGo00002?ooool2o`0000?ooooo0_l00005ooooo`;o00004_ooool2
o`0000;ooooo1?l00004ooooo`;o00002?ooool9o`000003ooooool0003o000000Wooooo0_l0001M
ooooo`007?ooool00ol0003oooooooooo`17ooooo`;o00004_ooool2o`0001?ooooo0_l00004oooo
o`;o00001?ooool2o`0000?ooooo3?l000000ooooooo0000o`000007o`0000Oooooo0_l00003oooo
o`?o00000_ooool2o`000003ooooool0003o000000;ooooo0_l0000;ooooo`;o000000?oooooo`00
0?l000000_ooool6o`000003ooooool0003o000000;o00001oooool3o`0000Cooooo0_l000000ooo
oooo0000o`000002ooooo`;o0000I?ooool001cooooo00?o0000ooooooooool0O?ooool2o`0000?o
oooo3?l000000ooooooo0000o`000006o`0000Sooooo0_l00002ooooo`?o00000_ooool3o`0000Go
oooo0_l0000:ooooo`Go00001Oooool4o`000003ooooool0003o000000;o00002?ooool2o`0000Wo
oooo1?l000001?oooooo0000o`000?l00002ooooo`;o00001Oooool2o`0005Gooooo000Looooo`03
o`000?oooooooooo04cooooo0_l0000booooo`go000000?oooooo`000?l000001_l0000:ooooo`Co
00000oooool2o`0000;ooooo0_l0000:ooooo`Wo00000_ooool2o`0001;ooooo0_l00009ooooo`;o
00000oooool3o`0000;ooooo0ol00004ooooo`;o0000EOooool001cooooo00?o0000ooooooooool0
C?ooool2o`0001oooooo0_l0000Aooooo`;o00000_oooolBo`0000[ooooo0_l00009ooooo`;o0000
1?ooool4o`0000;ooooo2Ol00002ooooo`;o00001_ooool2o`0001Wooooo0_l00005ooooo`;o0000
Foooool001cooooo00?o0000ooooooooool0J?ooool2o`0000?ooooo0_l000000ooooooo0000o`00
000Boooooa7o00001Oooool2o`0001Gooooo1_l00004ooooo`;o000000?oooooo`000?l000001_oo
ool2o`0000;ooooo0_l0000Iooooo`;o00000_ooool2o`0005kooooo000Looooo`;o0000JOooool3
o`0000Gooooo0_l00008ooooo`?o00001Oooool2o`0000;ooooo3ol00005ooooo`;o00001Oooool2
o`000003ooooool0003o000000Gooooo0_l00008ooooo`;o00003oooool2o`0000Cooooo0_l0000F
ooooo`;o00000oooool4o`000003ooooool0003o000005Wooooo000Looooo`03o`000?oooooooooo
06Wooooo0_l00005ooooo`;o00002?ooool3o`0000Gooooo0_l00002ooooo`go00000oooool2o`00
00Wooooo1Ol00004ooooo`?o00005oooool2o`0000Gooooo0ol00004ooooo`;o00004?ooool2o`00
0003ooooool0003o000000;ooooo1Ol0001Iooooo`007?ooool00ol0003oooooooooo`1Wooooo`;o
00006Oooool3o`0000?ooooo2ol00003ooooo`;o00002Oooool5o`0000Cooooo0_l0000;ooooo`;o
00002oooool4o`000003ooooool0003o000000;o00001Oooool2o`0001?ooooo0_l00002ooooo`Co
0000F_ooool001cooooo00?o0000ooooooooool0Ioooool2o`0001Wooooo0ol00004ooooo`;o0000
00?oooooo`000?l000000_l0000Cooooo`?o00002_ooool2o`0000Cooooo0ol0000=ooooo`;o0000
00?oooooo`000?l000001oooool2o`0007Gooooo000Looooo`03o`000?oooooooooo05Sooooo0_l0
0004ooooo`;o00002?ooool2o`0000?ooooo0_l0000Dooooo`;o00000_ooool3o`0000?ooooo0ol0
000Cooooo`;o00002oooool2o`000004ooooool0003o0000ooooo`?o000000?oooooo`000?l00000
1_ooool2o`0000Gooooo0ol00006ooooo`;o00005?ooool2o`0005oooooo000Looooo`03o`000?oo
oooooooo05;ooooo0_l00004ooooo`;o00000oooool3o`0000Sooooo0_l00003ooooo`;o00005?oo
ool2o`0000;ooooo0ol0000Iooooo`;o00002oooool5o`0000Gooooo0_l00002ooooo`;o00000_oo
ool3o`0000Cooooo0ol0000:ooooo`;o00003_ooool4o`0000_ooooo0_l0001Booooo`007?ooool0
0ol0003oooooooooo`1Booooo`;o00000_ooool2o`0000Gooooo0_l0000Sooooo`;o00002Oooool2
o`00013ooooo0_l0000:ooooo`;o00001?ooool2o`0000;ooooo0_l00005ooooo`Co00000_ooool3
o`00017ooooo0_l0000>ooooo`;o00003Oooool2o`0005;ooooo000Looooo`03o`000?oooooooooo
05Kooooo0_l0000Zooooo`;o00002Oooool2o`00013ooooo0_l0000:ooooo`;o00001?ooool2o`00
00;ooooo0_l00005ooooo`;o00001?ooool2o`0000Wooooo0_l0000<ooooo`;o00000oooool2o`00
0003ooooool0003o000006Cooooo000Looooo`03o`000?oooooooooo09Gooooo0ol0000;ooooo`;o
00001?ooool2o`0000Kooooo1?l0000:ooooo`;o00001Oooool2o`0000;ooooo0_l000000ooooooo
0000o`000002ooooo`;o00002?ooool2o`0000?ooooo1Ol0001Tooooo`007?ooool00ol0003ooooo
ooooo`28ooooo`;o00002oooool3o`000003ooooool0003o000000Oooooo0ol00004ooooo`;o0000
2?ooool2o`0000Wooooo0ol00005ooooo`Oo00001?ooool2o`0000Kooooo0_l00003ooooo`;o0000
00?oooooo`000?l00000I_ooool001cooooo00?o0000ooooooooool0R?ooool2o`0000Oooooo0_l0
0006ooooo`?o00001_ooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o00001?oo
ool2o`0000Oooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l000001?oooooo0000
o`000?ooool2o`0000Wooooo0_l00003ooooo`;o0000JOooool001cooooo00?o0000ooooooooool0
POooool2o`000003ooooool0003o000000_ooooo0_l00007ooooo`;o00002Oooool2o`0000;ooooo
0_l000001?oooooo0000o`000?ooool2o`0000;ooooo1?l0000;ooooo`;o000000?oooooo`000?l0
00001oooool2o`0000kooooo0_l0001Yooooo`007?ooool00ol0003oooooooooo`21ooooo`;o0000
00?oooooo`000?l000004Oooool2o`0000Wooooo0_l00008ooooo`;o000000?oooooo`000?l00000
0_ooool2o`0002Oooooo0_l0001[ooooo`007?ooool00ol0003oooooooooo`2Gooooo`;o00002Ooo
ool2o`0000Sooooo0_l000000ooooooo0000o`000002o`0000[ooooo0ol00009ooooo`;o00001Ooo
ool4o`0000Sooooo0_l0001[ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q
1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0Joooool2o`00027o
oooo1_l0000;ooooo`;o00000_ooool2o`0000;ooooo0_l00007ooooo`?o00002_ooool5o`0000Oo
oooo0ol00004ooooo`Co00002?ooool2o`0006_ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMg
M`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1[
ooooo`;o00008Oooool6o`0000_ooooo0_l00002ooooo`;o00000_ooool2o`0000Oooooo1?l0000<
ooooo`Co00001_ooool2o`0000Gooooo0_l00005ooooo`;o0000Koooool00003ooooool@413ooooo
00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool0QOooool2o`0001_ooooo0ol000000ooooooo0000o`000002ooooo`;o00000oooool5
o`0000kooooo0ol00003ooooo`;o00003_ooool2o`0006oooooo00000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000P_ooool2
o`000003ooooool0003o000001_ooooo0ol000000ooooooo0000o`000002ooooo`;o00000_ooool3
o`0001;ooooo0_l00003ooooo`;o0000Ooooool00003ooooool0003ooooo00;ooooo00?o0000oooo
ooooool02Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0KOooool2
o`0001?ooooo0ol00002ooooo`;o00001oooool2o`0000Kooooo0_l0000<ooooo`;o00001_ooool2
o`0000?ooooo0_l0000:ooooo`;o00000_ooool2o`0001Wooooo0_l0001Yooooo`0000?ooooooa0@
4?ooool00_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool0
0ol0003oooooooooo`1]ooooo`;o00005?ooool2o`0000;ooooo0_l00007ooooo`?o00001Oooool2
o`0000_ooooo0ol00009ooooo`Co00001oooool2o`000004ooooool0003o0000ooooo`?o00006Ooo
ool2o`0000;ooooo0_l0001Uooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`00
0?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`1`ooooo`;o00004Oooool2o`0000?o
oooo0_l00007ooooo`;o00004_ooool3o`0000Wooooo0_l00006ooooo`;o000000?oooooo`000?l0
00001?ooool2o`0000Cooooo0_l00006ooooo`;o00004?ooool2o`0006Gooooo00001_ooooook^k^
oc8b<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooo
oooo073ooooo0_l0000;ooooo`;o00002Oooool4o`0000;ooooo0_l0000Fooooo`;o00004Oooool2
o`0000gooooo0_l00006ooooo`?o0000M_ooool001cooooo00?o0000ooooooooool0OOooool2o`00
00Wooooo1?l00002ooooo`;o0000@Oooool2o`0007Kooooo000Looooo`03o`000?oooooooooo07Ko
oooo0_l0000^ooooo`;o00004_ooool2o`0008gooooo000Looooo`03o`000?oooooooooo07Kooooo
0_l0000Dooooo`;o00004_ooool2o`0000Cooooo0_l00004ooooo`;o00003?ooool2o`000003oooo
ool0003o000000?ooooo0_l0000Booooo`;o0000LOooool001cooooo00?o0000ooooooooool0N_oo
ool2o`00013ooooo0_l0000Booooo`;o00002Oooool3o`0000oooooo0_l00003ooooo`;o00001_oo
ool2o`0000[ooooo0_l0001aooooo`007?ooool00ol0003oooooooooo`1jooooo`;o0000;oooool2
o`0000gooooo0_l00002ooooo`;o00002_ooool2o`0007gooooo000Looooo`03o`000?oooooooooo
0;Wooooo0ol000001?oooooo0000o`000?l00029ooooo`007?ooool00ol0003oooooooooo`1koooo
o`;o0000<?ooool3o`0000Wooooo1_l0002:ooooo`007?ooool00ol0003oooooooooo`1kooooo`;o
0000<?ooool3o`0000_ooooo0_l0002<ooooo`007?ooool00ol0003oooooooooo`22ooooo`;o0000
:Oooool3o`0001Oooooo0_l00020ooooo`007?ooool00ol0003oooooooooo`1`ooooo`;o00004?oo
ool2o`0002Wooooo0_l00009ooooo`;o00003Oooool2o`0000Cooooo0_l0001jooooo`007?ooool0
0ol0003oooooooooo`1`ooooo`;o00005Oooool2o`00027ooooo0_l0000<ooooo`;o00004oooool2
o`0007[ooooo000Looooo`;o0000R?ooool2o`0001[ooooo0_l00005ooooo`;o0000WOooool001co
oooo00?o0000ooooooooool0Xoooool2o`000:Cooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2S
ooooo`;o00005?ooool2o`0008kooooo000Looooo`03o`000?oooooooooo0:?ooooo0_l0000Doooo
o`;o0000S_ooool001cooooo00?o0000ooooooooool0ZOooool2o`0009kooooo000Looooo`03o`00
0?oooooooooo0:Wooooo0_l0002Nooooo`007?ooool00ol0003oooooooooo`2Uooooo`;o0000X_oo
ool001cooooo00?o0000ooooooooool0Uoooool2o`0000cooooo0_l0002Rooooo`007?ooool00ol0
003oooooooooo`2Gooooo`;o0000/?ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`004_ooool4o`000003
oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Ooo
ool3o`000?ooooooB_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0
003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo
00?o0000ooooooooool0oooooomBooooo`004_ooool00omEEEGoIVIVo`00003ooooooeCooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo002Uooooo`04oa0@4?l0003o0000ooooo`;o
000000?o410@ooooooooool05Oooool01?l@413o0000odA4A?o<c<`4ooooo`05onk^k_lb<S;o0000
oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^093ooooo002Vooooo`05o`000?oooooo
ooooooooool000002Oooool6o`0000_ooooo00?oV9RHoa0@4?oMgMd00oooool01OmEEEGoMgMgoooo
oonHV9So8B4Q00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`2@ooooo`00Y_ooool01Ol0003ooooo
oooooooooooo000001_ooooo00?oQhN7oeEEEOooool00_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go410@oooooooooooooooooa0@402@ooooo`00Y_ooool01Ol0003ooooooooooooooooo
000000Wooooo1_l00009ooooo`05olc<c?lQ8B7o0000oeEEEOl000000oooool01Ol0003oV9RHoooo
oonHV9So8B4Q00?ooooo00Go0000ooooooooooooooooo`00002@ooooo`00Y_ooool01Ol0003oQhN7
oooooonYZJWo000001Sooooo00Go8B4QohN7QoooooooV9RHo`000003ooooo`05o`000?mEEEGo0000
oa0@4?o<c<`00oooool01Ol0003ooooooooooooooooo0000093ooooo002Uooooo`03oa0@4?l0003o
MgMg00;o000000?oV9RHooooooooool05_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o
EEEEohN7Qoooool01Oooool01Ol@413ooooooooooooooooo410@093ooooo0033ooooo`05ob4Q8OnH
V9SoooooogMgMomEEED00oooool00ooMgMgo410@oiRHV005ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0T?ooool00<?ooooo00Goc<c<oa0@4?l0003o<S8bonk^kP04ooooo`04olc<c?m4A4Co0000oa0@
40?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP2@ooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(966) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.59212 .32075 Mdot
.59328 .37001 Mdot
.38519 .56872 Mdot
.56404 .56448 Mdot
.57765 .28277 Mdot
.35275 .57111 Mdot
.42435 .35799 Mdot
.3784 .34185 Mdot
.36234 .56562 Mdot
.49533 .53661 Mdot
.4007 .33625 Mdot
.56772 .62254 Mdot
.39377 .35947 Mdot
.57747 .55845 Mdot
.71621 .77397 Mdot
.56614 .49728 Mdot
.60285 .38601 Mdot
.43906 .71921 Mdot
.57037 .61392 Mdot
.39213 .56761 Mdot
.6339 .35172 Mdot
.57328 .56996 Mdot
.58617 .32586 Mdot
.57787 .55875 Mdot
.56455 .53769 Mdot
.60153 .34381 Mdot
.60713 .30477 Mdot
.55237 .55568 Mdot
.59605 .51882 Mdot
.38231 .36961 Mdot
.52223 .76588 Mdot
.79329 .67314 Mdot
.53295 .53086 Mdot
.52065 .17922 Mdot
.38205 .33102 Mdot
.77763 .57546 Mdot
.34443 .53305 Mdot
.39902 .3796 Mdot
.38161 .33553 Mdot
.37115 .36247 Mdot
.38802 .36589 Mdot
.59671 .34898 Mdot
.39543 .29773 Mdot
.35208 .31607 Mdot
.6325 .59535 Mdot
.49157 .29908 Mdot
.6725 .69331 Mdot
.62458 .56626 Mdot
.609 .37477 Mdot
.39437 .5787 Mdot
.49933 .19052 Mdot
.39751 .39101 Mdot
.35244 .45233 Mdot
.87023 .37685 Mdot
.40889 .37802 Mdot
.62386 .6068 Mdot
.35769 .54358 Mdot
.58301 .58015 Mdot
.58052 .56368 Mdot
.71058 .55309 Mdot
.5572 .5251 Mdot
.42225 .71142 Mdot
.59607 .40373 Mdot
.4072 .62359 Mdot
.35292 .56049 Mdot
.38292 .33798 Mdot
.58722 .38567 Mdot
.39999 .36171 Mdot
.63792 .61325 Mdot
.34132 .57968 Mdot
.62399 .56734 Mdot
.38522 .34276 Mdot
.55295 .36022 Mdot
.61686 .58366 Mdot
.2437 .35852 Mdot
.56763 .83957 Mdot
.40754 .67668 Mdot
.72725 .54528 Mdot
.72723 .60224 Mdot
.34483 .69836 Mdot
.59664 .52953 Mdot
.2775 .73904 Mdot
.67042 .79579 Mdot
.59851 .32203 Mdot
.58734 .48163 Mdot
.34405 .60248 Mdot
.61142 .58927 Mdot
.50822 .40121 Mdot
.64565 .5873 Mdot
.32083 .27448 Mdot
.3671 .56612 Mdot
.57481 .36057 Mdot
.56501 .56218 Mdot
.58627 .50776 Mdot
.67298 .41019 Mdot
.54546 .55922 Mdot
.55625 .57075 Mdot
.58419 .3131 Mdot
.40904 .33241 Mdot
.55821 .62454 Mdot
.36533 .31989 Mdot
.34749 .48679 Mdot
.61145 .6041 Mdot
.35968 .53316 Mdot
.56937 .3201 Mdot
.61283 .59394 Mdot
.41389 .32458 Mdot
.62109 .54565 Mdot
.34592 .31589 Mdot
.59315 .37454 Mdot
.58972 .5083 Mdot
.39812 .73569 Mdot
.19339 .47728 Mdot
.57141 .36004 Mdot
.39472 .54456 Mdot
.61663 .53366 Mdot
.57456 .58914 Mdot
.59217 .36721 Mdot
.37496 .60426 Mdot
.53258 .45238 Mdot
.62189 .35935 Mdot
.37135 .34814 Mdot
.61655 .37961 Mdot
.57597 .48464 Mdot
.36424 .57724 Mdot
.34004 .4646 Mdot
.34144 .45043 Mdot
.49437 .72745 Mdot
.60631 .59152 Mdot
.48911 .22751 Mdot
.35888 .58707 Mdot
.58127 .35756 Mdot
.39961 .3574 Mdot
.65639 .54875 Mdot
.56351 .36873 Mdot
.4113 .34847 Mdot
.38759 .70491 Mdot
.2986 .50021 Mdot
.61656 .36462 Mdot
.35737 .2933 Mdot
.38772 .39598 Mdot
.37008 .36527 Mdot
.49734 .17726 Mdot
.59924 .37 Mdot
.39846 .71976 Mdot
.41195 .35527 Mdot
.6042 .74998 Mdot
.62812 .60956 Mdot
.47111 .66271 Mdot
.19385 .65635 Mdot
.47546 .18788 Mdot
.28395 .4108 Mdot
.43333 .72304 Mdot
.37119 .37622 Mdot
.57579 .52125 Mdot
.60857 .3604 Mdot
.6038 .3575 Mdot
.55819 .58906 Mdot
.56045 .55171 Mdot
.62325 .57303 Mdot
.5925 .5103 Mdot
.6925 .70714 Mdot
.6318 .55449 Mdot
.41658 .78506 Mdot
.57428 .35052 Mdot
.56069 .53027 Mdot
.39152 .60518 Mdot
.64301 .54444 Mdot
.3841 .3554 Mdot
.57616 .5796 Mdot
.56154 .56392 Mdot
.57854 .50516 Mdot
.42105 .3731 Mdot
.78601 .66054 Mdot
.18059 .60775 Mdot
.82372 .49402 Mdot
.37141 .48162 Mdot
.34019 .54977 Mdot
.59868 .59757 Mdot
.40813 .70844 Mdot
.77514 .53553 Mdot
.59093 .53781 Mdot
.26243 .26591 Mdot
.5595 .57259 Mdot
.65122 .27465 Mdot
.67926 .62567 Mdot
.8285 .47682 Mdot
.46045 .70658 Mdot
.59119 .51485 Mdot
.69148 .37211 Mdot
.74307 .34559 Mdot
.36159 .40351 Mdot
.39091 .36861 Mdot
.39088 .6032 Mdot
.36535 .54738 Mdot
.42307 .39034 Mdot
.58664 .64345 Mdot
.64773 .63129 Mdot
.66022 .6025 Mdot
.34683 .46217 Mdot
.56871 .40812 Mdot
.41778 .68717 Mdot
.57118 .32145 Mdot
.38449 .83145 Mdot
.36769 .26324 Mdot
.37386 .29544 Mdot
.39351 .68431 Mdot
.38475 .58274 Mdot
.34872 .46254 Mdot
.40388 .70499 Mdot
.6089 .55358 Mdot
.59615 .3804 Mdot
.63742 .22273 Mdot
.61885 .65236 Mdot
.62983 .20046 Mdot
.56791 .39118 Mdot
.51897 .44896 Mdot
.40207 .34466 Mdot
.3531 .50443 Mdot
.56996 .58698 Mdot
.60535 .56928 Mdot
.62659 .38123 Mdot
.62166 .56682 Mdot
.61706 .28577 Mdot
.56461 .58678 Mdot
.33095 .48255 Mdot
.41122 .67574 Mdot
.42632 .38773 Mdot
.48642 .72623 Mdot
.56399 .33875 Mdot
.44842 .67959 Mdot
.38532 .61371 Mdot
.764 .57203 Mdot
.3883 .33755 Mdot
.3917 .72925 Mdot
.37786 .61037 Mdot
.42549 .69094 Mdot
.64015 .54719 Mdot
.33471 .53865 Mdot
.42194 .72805 Mdot
.73423 .69622 Mdot
.65067 .5711 Mdot
.67878 .73241 Mdot
.42481 .35337 Mdot
.61458 .38213 Mdot
.55581 .52962 Mdot
.35785 .50626 Mdot
.53958 .52393 Mdot
.26869 .36789 Mdot
.34291 .44289 Mdot
.35588 .45661 Mdot
.36272 .69675 Mdot
.3989 .73299 Mdot
.24289 .41886 Mdot
.47187 .21765 Mdot
.60083 .38602 Mdot
.59256 .61166 Mdot
.82618 .55069 Mdot
.41125 .35496 Mdot
.60681 .5484 Mdot
.32215 .53883 Mdot
.41164 .35807 Mdot
.58564 .58189 Mdot
.42936 .35305 Mdot
.60424 .36244 Mdot
.23372 .60482 Mdot
.60045 .38805 Mdot
.64841 .57631 Mdot
.42422 .33455 Mdot
.33975 .56662 Mdot
.60349 .34105 Mdot
.62014 .54852 Mdot
.57888 .5991 Mdot
.34467 .47207 Mdot
.56684 .51832 Mdot
.80779 .58024 Mdot
.57062 .51137 Mdot
.38138 .55787 Mdot
.54704 .55138 Mdot
.32779 .22518 Mdot
.27277 .53141 Mdot
.58858 .3852 Mdot
.35637 .46069 Mdot
.36065 .5589 Mdot
.3087 .6587 Mdot
.37434 .43508 Mdot
.60953 .53354 Mdot
.35449 .48745 Mdot
.45742 .64942 Mdot
.3959 .38574 Mdot
.55211 .59571 Mdot
.4011 .27505 Mdot
.39589 .60381 Mdot
.3477 .46637 Mdot
.6708 .55679 Mdot
.5625 .32484 Mdot
.56428 .56108 Mdot
.33902 .57021 Mdot
.62248 .37122 Mdot
.64557 .57074 Mdot
.5861 .67654 Mdot
.34427 .44591 Mdot
.42219 .35975 Mdot
.68245 .59623 Mdot
.6301 .56493 Mdot
.34836 .53598 Mdot
.55726 .35628 Mdot
.38054 .33002 Mdot
.59277 .34277 Mdot
.694 .27924 Mdot
.33273 .41572 Mdot
.71902 .68015 Mdot
.37523 .7142 Mdot
.30011 .36412 Mdot
.82547 .44679 Mdot
.22053 .45704 Mdot
.57293 .73022 Mdot
.74593 .29839 Mdot
.37574 .60742 Mdot
.32357 .50603 Mdot
.35959 .55244 Mdot
.57781 .5329 Mdot
.35287 .5666 Mdot
.83135 .46475 Mdot
.56186 .58283 Mdot
.34195 .54196 Mdot
.26061 .63136 Mdot
.55776 .54865 Mdot
.56979 .36135 Mdot
.71098 .77133 Mdot
.22672 .35815 Mdot
.39883 .22888 Mdot
.34737 .57512 Mdot
.69246 .57453 Mdot
.55352 .55423 Mdot
.58363 .50026 Mdot
.6123 .34796 Mdot
.5486 .5827 Mdot
.41925 .68856 Mdot
.39574 .68451 Mdot
.466 .61875 Mdot
.20556 .63483 Mdot
.55902 .62392 Mdot
.60616 .34229 Mdot
.71165 .62827 Mdot
.26317 .3337 Mdot
.37255 .52242 Mdot
.38262 .31106 Mdot
.77306 .67581 Mdot
.61551 .64353 Mdot
.40287 .29481 Mdot
.37622 .27607 Mdot
.58076 .37349 Mdot
.78684 .63683 Mdot
.39682 .37402 Mdot
.72782 .40021 Mdot
.64351 .4113 Mdot
.60509 .56197 Mdot
.39447 .33366 Mdot
.56184 .62174 Mdot
.29528 .27424 Mdot
.60752 .76788 Mdot
.37895 .79045 Mdot
.64202 .58424 Mdot
.23301 .40623 Mdot
.57414 .58364 Mdot
.54571 .45428 Mdot
.56854 .51195 Mdot
.59227 .33816 Mdot
.49879 .54961 Mdot
.44969 .42765 Mdot
.20485 .66118 Mdot
.37289 .25758 Mdot
.43427 .72034 Mdot
.5745 .59323 Mdot
.60415 .56285 Mdot
.39138 .71225 Mdot
.58232 .33208 Mdot
.59136 .51128 Mdot
.51063 .6692 Mdot
.61599 .5733 Mdot
.38912 .37066 Mdot
.47385 .75781 Mdot
.63718 .32225 Mdot
.56088 .50989 Mdot
.6273 .35415 Mdot
.41898 .37223 Mdot
.3792 .34487 Mdot
.66186 .54073 Mdot
.38082 .32208 Mdot
.56269 .57281 Mdot
.51674 .80531 Mdot
.60947 .32616 Mdot
.65433 .64726 Mdot
.56914 .33973 Mdot
.73623 .56869 Mdot
.41791 .32618 Mdot
.33796 .47044 Mdot
.63973 .38232 Mdot
.39584 .37094 Mdot
.42889 .21838 Mdot
.64529 .61879 Mdot
.53602 .55741 Mdot
.33623 .25818 Mdot
.34999 .58282 Mdot
.34358 .453 Mdot
.39943 .31978 Mdot
.62931 .56729 Mdot
.54388 .58219 Mdot
.41078 .3833 Mdot
.69752 .42585 Mdot
.30947 .64689 Mdot
.55311 .56275 Mdot
.59034 .33447 Mdot
.58238 .35518 Mdot
.6363 .58009 Mdot
.61226 .54196 Mdot
.3797 .57932 Mdot
.3553 .46754 Mdot
.36063 .50339 Mdot
.34311 .44966 Mdot
.33625 .491 Mdot
.53775 .28038 Mdot
.37079 .36257 Mdot
.51115 .24248 Mdot
.30807 .29886 Mdot
.51954 .56342 Mdot
.33695 .5411 Mdot
.59674 .56429 Mdot
.56679 .56745 Mdot
.38065 .32933 Mdot
.33185 .39689 Mdot
.57605 .4818 Mdot
.6172 .34177 Mdot
.40123 .31872 Mdot
.60874 .63666 Mdot
.56355 .24577 Mdot
.42648 .71786 Mdot
.38646 .22868 Mdot
.38543 .3391 Mdot
.57621 .37472 Mdot
.43294 .35683 Mdot
.60787 .56827 Mdot
.60403 .61681 Mdot
.58597 .36791 Mdot
.41166 .73711 Mdot
.66098 .58128 Mdot
.58572 .58447 Mdot
.14521 .44765 Mdot
.23483 .36897 Mdot
.46487 .36225 Mdot
.58227 .51618 Mdot
.54129 .56298 Mdot
.43638 .70501 Mdot
.6132 .57048 Mdot
.58227 .60274 Mdot
.18087 .50393 Mdot
.47323 .3504 Mdot
.44165 .71564 Mdot
.73332 .40621 Mdot
.5696 .39281 Mdot
.81273 .60678 Mdot
.35633 .49733 Mdot
.44325 .35174 Mdot
.23287 .57398 Mdot
.35104 .46596 Mdot
.27713 .359 Mdot
.80145 .62462 Mdot
.34357 .45046 Mdot
.41064 .64011 Mdot
.54591 .48327 Mdot
.55482 .57688 Mdot
.57812 .58811 Mdot
.40675 .71463 Mdot
.60133 .36844 Mdot
.46231 .58921 Mdot
.61294 .78685 Mdot
.57203 .57631 Mdot
.59769 .28985 Mdot
.73696 .70572 Mdot
.34676 .47292 Mdot
.41516 .68983 Mdot
.38316 .72023 Mdot
.57805 .59367 Mdot
.19235 .51864 Mdot
.60319 .34468 Mdot
.61971 .54795 Mdot
.63214 .54929 Mdot
.34409 .56892 Mdot
.58641 .3811 Mdot
.36971 .60853 Mdot
.34019 .4439 Mdot
.76707 .36122 Mdot
.1506 .41411 Mdot
.39031 .3232 Mdot
.79774 .57081 Mdot
.38846 .38107 Mdot
.38346 .7839 Mdot
.35187 .45822 Mdot
.59538 .53342 Mdot
.55858 .34582 Mdot
.62265 .5484 Mdot
.59978 .54783 Mdot
.60787 .5541 Mdot
.62089 .62788 Mdot
.27717 .25564 Mdot
.41372 .69963 Mdot
.58095 .49118 Mdot
.38062 .55867 Mdot
.7995 .58053 Mdot
.62636 .80555 Mdot
.59938 .57218 Mdot
.58586 .6004 Mdot
.567 .36308 Mdot
.55689 .58973 Mdot
.40014 .38546 Mdot
.55687 .35705 Mdot
.59312 .50762 Mdot
.77809 .63711 Mdot
.60163 .51664 Mdot
.82128 .46482 Mdot
.43324 .35751 Mdot
.42629 .22146 Mdot
.59993 .49521 Mdot
.33961 .45474 Mdot
.34363 .45265 Mdot
.35965 .4839 Mdot
.43605 .34035 Mdot
.34481 .53781 Mdot
.55022 .81963 Mdot
.52499 .57028 Mdot
.57222 .52477 Mdot
.54378 .58489 Mdot
.34068 .51838 Mdot
.50929 .39528 Mdot
.2568 .4246 Mdot
.62272 .63455 Mdot
.37305 .58649 Mdot
.61715 .3803 Mdot
.42498 .58708 Mdot
.56066 .34645 Mdot
.44323 .70635 Mdot
.3984 .33719 Mdot
.4287 .70805 Mdot
.45524 .19733 Mdot
.59255 .37255 Mdot
.62667 .38193 Mdot
.34006 .54681 Mdot
.50111 .43972 Mdot
.85782 .38099 Mdot
.34075 .58088 Mdot
.51005 .7016 Mdot
.61035 .34004 Mdot
.62556 .53734 Mdot
.4642 .72601 Mdot
.50438 .43376 Mdot
.34713 .54501 Mdot
.58461 .53692 Mdot
.20536 .56404 Mdot
.37937 .58104 Mdot
.55288 .59742 Mdot
.37541 .60104 Mdot
.38611 .35082 Mdot
.36401 .59375 Mdot
.56035 .39326 Mdot
.6092 .5962 Mdot
.86747 .4007 Mdot
.4548 .71038 Mdot
.57087 .51274 Mdot
.40455 .31946 Mdot
.50811 .64766 Mdot
.59274 .55432 Mdot
.40454 .6845 Mdot
.36569 .58004 Mdot
.31414 .62428 Mdot
.55333 .54744 Mdot
.34775 .56674 Mdot
.5868 .32355 Mdot
.43802 .34476 Mdot
.37622 .76505 Mdot
.34131 .47824 Mdot
.61309 .35326 Mdot
.33499 .43989 Mdot
.40891 .31583 Mdot
.54268 .56605 Mdot
.6339 .55867 Mdot
.58292 .34292 Mdot
.23589 .64416 Mdot
.54963 .54423 Mdot
.59631 .52962 Mdot
.38843 .57471 Mdot
.3442 .51973 Mdot
.24324 .64368 Mdot
.36948 .60452 Mdot
.58531 .61858 Mdot
.58413 .34271 Mdot
.5695 .5545 Mdot
.56911 .37066 Mdot
.57931 .6048 Mdot
.53912 .35403 Mdot
.60192 .32305 Mdot
.23914 .4704 Mdot
.57685 .54423 Mdot
.67931 .6201 Mdot
.60377 .55133 Mdot
.62028 .5701 Mdot
.37898 .57031 Mdot
.40642 .69393 Mdot
.64401 .52437 Mdot
.39615 .75665 Mdot
.40393 .68752 Mdot
.71227 .31334 Mdot
.34848 .57843 Mdot
.41196 .72305 Mdot
.69368 .7245 Mdot
.35757 .46805 Mdot
.41419 .70867 Mdot
.65273 .79364 Mdot
.38741 .32441 Mdot
.58332 .39693 Mdot
.55819 .54791 Mdot
.73096 .2865 Mdot
.53838 .78872 Mdot
.34981 .48347 Mdot
.57325 .51125 Mdot
.59475 .5618 Mdot
.62078 .33507 Mdot
.34732 .80324 Mdot
.3814 .55276 Mdot
.57411 .53348 Mdot
.58225 .38682 Mdot
.22546 .71938 Mdot
.37311 .54785 Mdot
.41103 .71021 Mdot
.41521 .38135 Mdot
.54975 .33445 Mdot
.34398 .48376 Mdot
.40619 .38719 Mdot
.2522 .47189 Mdot
.4294 .21257 Mdot
.61752 .53425 Mdot
.33683 .53904 Mdot
.44458 .18872 Mdot
.55909 .62942 Mdot
.45384 .37191 Mdot
.62089 .47155 Mdot
.57817 .37203 Mdot
.40654 .38282 Mdot
.43188 .71207 Mdot
.55519 .37485 Mdot
.58714 .33096 Mdot
.37652 .34431 Mdot
.41938 .6247 Mdot
.51668 .44616 Mdot
.38406 .36415 Mdot
.32327 .27654 Mdot
.66033 .25322 Mdot
.35588 .47727 Mdot
.3991 .69197 Mdot
.60746 .22005 Mdot
.59655 .34812 Mdot
.77538 .67261 Mdot
.39588 .21602 Mdot
.55608 .57022 Mdot
.40713 .72736 Mdot
.49603 .32954 Mdot
.58191 .8092 Mdot
.4134 .36039 Mdot
.45957 .41324 Mdot
.39488 .73999 Mdot
.55076 .56462 Mdot
.66358 .50028 Mdot
.58332 .53122 Mdot
.40213 .34047 Mdot
.72221 .59882 Mdot
.57528 .37484 Mdot
.40218 .31639 Mdot
.38834 .2274 Mdot
.56603 .57454 Mdot
.58152 .53786 Mdot
.50161 .75861 Mdot
.60104 .37987 Mdot
.35855 .50328 Mdot
.61302 .533 Mdot
.58136 .58271 Mdot
.53862 .5395 Mdot
.67241 .61807 Mdot
.19341 .48613 Mdot
.57456 .53511 Mdot
.32287 .45957 Mdot
.56709 .50155 Mdot
.57738 .54722 Mdot
.62647 .35636 Mdot
.17284 .3811 Mdot
.33689 .46802 Mdot
.57754 .58114 Mdot
.61323 .52805 Mdot
.3771 .33762 Mdot
.48493 .5246 Mdot
.49967 .42779 Mdot
.32968 .54741 Mdot
.60796 .72507 Mdot
.61896 .6283 Mdot
.56254 .3742 Mdot
.39221 .73242 Mdot
.63588 .57543 Mdot
.56449 .37667 Mdot
.62152 .51996 Mdot
.3772 .5857 Mdot
.35545 .47428 Mdot
.40595 .2388 Mdot
.4159 .71549 Mdot
.51703 .78738 Mdot
.50308 .25334 Mdot
.39091 .59643 Mdot
.56784 .52909 Mdot
.43511 .37607 Mdot
.33172 .54293 Mdot
.34379 .47275 Mdot
.65587 .52334 Mdot
.60636 .35387 Mdot
.57335 .35911 Mdot
.46751 .66132 Mdot
.29398 .45968 Mdot
.15755 .49718 Mdot
.38701 .34774 Mdot
.59567 .50527 Mdot
.4749 .22247 Mdot
.57234 .35996 Mdot
.47084 .695 Mdot
.41365 .72325 Mdot
.41484 .36091 Mdot
.36962 .51436 Mdot
.56501 .3692 Mdot
.61227 .37349 Mdot
.64935 .57147 Mdot
.59608 .58299 Mdot
.56038 .72698 Mdot
.46659 .64258 Mdot
.41549 .37739 Mdot
.39209 .7041 Mdot
.3705 .61103 Mdot
.58258 .52668 Mdot
.59583 .32195 Mdot
.64022 .23447 Mdot
.61741 .5315 Mdot
.38112 .57722 Mdot
.57893 .36876 Mdot
.39153 .7197 Mdot
.40626 .68537 Mdot
.61929 .57024 Mdot
.71067 .57346 Mdot
.40964 .37273 Mdot
.57041 .36304 Mdot
.55897 .21628 Mdot
.5492 .54112 Mdot
.59758 .5874 Mdot
.66919 .53259 Mdot
.37789 .36312 Mdot
.43103 .22309 Mdot
.4104 .73941 Mdot
.59743 .35801 Mdot
.59617 .51506 Mdot
.42149 .71288 Mdot
.45414 .21784 Mdot
.35229 .4736 Mdot
.36964 .59756 Mdot
.40597 .68422 Mdot
.39522 .7204 Mdot
.393 .69509 Mdot
.76713 .68664 Mdot
.55769 .39172 Mdot
.64657 .65698 Mdot
.55815 .51984 Mdot
.46747 .66582 Mdot
.65987 .55773 Mdot
.43386 .36073 Mdot
.3529 .5886 Mdot
.60044 .55172 Mdot
.64798 .57356 Mdot
.68261 .57315 Mdot
.66747 .63832 Mdot
.62764 .31386 Mdot
.59144 .37711 Mdot
.52167 .55116 Mdot
.34194 .56601 Mdot
.36133 .82332 Mdot
.84815 .4307 Mdot
.60542 .49345 Mdot
.51183 .46241 Mdot
.58863 .32524 Mdot
.37431 .3561 Mdot
.48527 .42357 Mdot
.43176 .35136 Mdot
.59193 .35711 Mdot
.57991 .52927 Mdot
.51759 .24597 Mdot
.42343 .6859 Mdot
.62709 .57127 Mdot
.40603 .34876 Mdot
.62543 .57214 Mdot
.40951 .3851 Mdot
.61965 .26844 Mdot
.30233 .28709 Mdot
.55925 .57284 Mdot
.54625 .53798 Mdot
.65957 .5028 Mdot
.59726 .57197 Mdot
.30433 .73642 Mdot
.58122 .33041 Mdot
.19932 .59685 Mdot
.64854 .56672 Mdot
.74616 .51255 Mdot
.55314 .52848 Mdot
.21944 .57771 Mdot
.60224 .58463 Mdot
.43787 .45542 Mdot
.55356 .57044 Mdot
.59908 .60337 Mdot
.4286 .34193 Mdot
.3773 .33764 Mdot
.59445 .31685 Mdot
.35803 .50387 Mdot
.82273 .51212 Mdot
.58951 .58638 Mdot
.3406 .49118 Mdot
.4551 .34182 Mdot
.393 .71247 Mdot
.5925 .3547 Mdot
.24404 .74197 Mdot
.42635 .36217 Mdot
.39629 .61937 Mdot
.24311 .66588 Mdot
.34289 .49022 Mdot
.44223 .4022 Mdot
.53191 .47655 Mdot
.40505 .73495 Mdot
.55043 .55757 Mdot
.53921 .18829 Mdot
.24352 .36478 Mdot
.66423 .56269 Mdot
.41183 .31849 Mdot
.76796 .55223 Mdot
.61268 .22623 Mdot
.38056 .71111 Mdot
.43048 .72171 Mdot
.42423 .36346 Mdot
.38775 .55938 Mdot
.60868 .62574 Mdot
.41546 .72367 Mdot
.38562 .59493 Mdot
.35928 .46963 Mdot
.39995 .44924 Mdot
.60164 .34785 Mdot
.38954 .23023 Mdot
.48159 .28243 Mdot
.4189 .37502 Mdot
.43825 .66813 Mdot
.55386 .32674 Mdot
.55036 .34506 Mdot
.35238 .49791 Mdot
.37969 .568 Mdot
.55659 .3851 Mdot
.59851 .62078 Mdot
.67863 .63534 Mdot
.57362 .57911 Mdot
.40171 .71342 Mdot
.60316 .57864 Mdot
.37684 .57674 Mdot
.40823 .36018 Mdot
.37439 .55907 Mdot
.42723 .3522 Mdot
.53817 .27095 Mdot
.61746 .55172 Mdot
.5968 .60223 Mdot
.52941 .79252 Mdot
.60406 .31753 Mdot
.5039 .19354 Mdot
.32985 .48539 Mdot
.36107 .54879 Mdot
.57617 .60064 Mdot
.56914 .33496 Mdot
.40017 .67529 Mdot
.52289 .79581 Mdot
.63172 .57174 Mdot
.57922 .3312 Mdot
.57433 .52825 Mdot
.71199 .70759 Mdot
.21767 .37841 Mdot
.58869 .34536 Mdot
.22055 .68372 Mdot
.59261 .5199 Mdot
.50225 .56107 Mdot
.54634 .59356 Mdot
.52572 .6856 Mdot
.54878 .54679 Mdot
.56746 .39098 Mdot
.57641 .57574 Mdot
.55589 .3726 Mdot
.391 .57868 Mdot
.37306 .3655 Mdot
.61377 .34219 Mdot
.63633 .55971 Mdot
.82305 .63454 Mdot
.3968 .34096 Mdot
.57244 .59019 Mdot
.41414 .33557 Mdot
.57702 .38974 Mdot
.61279 .36808 Mdot
.58012 .8184 Mdot
.46683 .34986 Mdot
.38628 .35291 Mdot
.5697 .53898 Mdot
.44864 .27065 Mdot
.57222 .5464 Mdot
.54153 .72452 Mdot
.62833 .59573 Mdot
.54777 .5485 Mdot
.559 .84485 Mdot
.39282 .38573 Mdot
.16308 .49578 Mdot
.62852 .77672 Mdot
.75659 .69913 Mdot
.54381 .36887 Mdot
.38081 .71092 Mdot
.78592 .64229 Mdot
.3414 .44277 Mdot
.36403 .58738 Mdot
.60148 .55284 Mdot
.64472 .34048 Mdot
.39991 .38069 Mdot
.40538 .69567 Mdot
.55979 .57409 Mdot
.3817 .57128 Mdot
.35779 .66171 Mdot
.36783 .36054 Mdot
.59633 .34971 Mdot
.61628 .3343 Mdot
.20153 .67774 Mdot
.59489 .51406 Mdot
.58503 .60203 Mdot
.4013 .33836 Mdot
.63257 .64659 Mdot
.39266 .72852 Mdot
.25648 .61064 Mdot
.38682 .35223 Mdot
.48412 .47551 Mdot
.59685 .37482 Mdot
.59595 .56249 Mdot
.51893 .40442 Mdot
.38169 .46339 Mdot
.73616 .37309 Mdot
.40645 .7109 Mdot
.54015 .73311 Mdot
.56789 .39145 Mdot
.40238 .35513 Mdot
.30375 .50642 Mdot
.5491 .51205 Mdot
.5911 .56511 Mdot
.53605 .7357 Mdot
.45457 .62396 Mdot
.40645 .78457 Mdot
.57895 .6094 Mdot
.45722 .61635 Mdot
.59068 .60918 Mdot
.53826 .53439 Mdot
.5999 .61878 Mdot
.60171 .59152 Mdot
.58204 .32919 Mdot
.67166 .60409 Mdot
.35461 .58019 Mdot
.6777 .4048 Mdot
.47356 .41048 Mdot
.55824 .52721 Mdot
.57766 .53532 Mdot
.7687 .4157 Mdot
.42284 .29826 Mdot
.59783 .32733 Mdot
.58652 .41587 Mdot
.37758 .32569 Mdot
.68168 .61741 Mdot
.35691 .51426 Mdot
.67519 .57468 Mdot
.37507 .56387 Mdot
.57145 .33585 Mdot
.36109 .54456 Mdot
.36854 .35075 Mdot
.3365 .53918 Mdot
.33451 .48922 Mdot
.40242 .38345 Mdot
.60666 .37118 Mdot
.61723 .58151 Mdot
.39954 .31885 Mdot
.50499 .75686 Mdot
.40248 .71411 Mdot
.58302 .81773 Mdot
.6148 .51772 Mdot
.48093 .38207 Mdot
.5854 .67699 Mdot
.37311 .55923 Mdot
.19468 .43046 Mdot
.60307 .32334 Mdot
.42757 .68452 Mdot
.57286 .33396 Mdot
.35712 .22327 Mdot
.40069 .69504 Mdot
.66022 .78984 Mdot
.30025 .43801 Mdot
.3481 .64465 Mdot
.61128 .61787 Mdot
.60852 .45319 Mdot
.33909 .57337 Mdot
.4015 .38083 Mdot
.2931 .43699 Mdot
.60585 .60114 Mdot
.22282 .46016 Mdot
.60304 .31508 Mdot
.35838 .48131 Mdot
.39842 .36009 Mdot
.39576 .31694 Mdot
.62347 .54483 Mdot
.27863 .66216 Mdot
.61697 .59731 Mdot
.28575 .45909 Mdot
.58197 .73362 Mdot
.67653 .54392 Mdot
.56598 .58809 Mdot
.36112 .53546 Mdot
.57338 .52921 Mdot
.67582 .65389 Mdot
.50397 .1783 Mdot
.64025 .61774 Mdot
.32272 .41649 Mdot
.42808 .66462 Mdot
.58954 .36903 Mdot
.60633 .49875 Mdot
.3435 .47825 Mdot
.58785 .51729 Mdot
.47337 .144 Mdot
.41654 .70904 Mdot
.33413 .59525 Mdot
.55531 .51985 Mdot
.61775 .53863 Mdot
.63997 .39903 Mdot
.64402 .35729 Mdot
.37026 .51454 Mdot
.5874 .5695 Mdot
.6029 .74097 Mdot
.39923 .32999 Mdot
.62211 .59209 Mdot
.5774 .5895 Mdot
.73558 .33333 Mdot
.37819 .35428 Mdot
.37044 .55283 Mdot
.35209 .45234 Mdot
.37834 .61343 Mdot
.42727 .74052 Mdot
.47065 .43627 Mdot
.47189 .67571 Mdot
.22484 .37251 Mdot
.38425 .70648 Mdot
.61042 .5218 Mdot
.56842 .48168 Mdot
.60294 .52511 Mdot
.43308 .71406 Mdot
.37945 .36405 Mdot
.60356 .32654 Mdot
.41357 .24385 Mdot
.34638 .46457 Mdot
.5505 .59442 Mdot
.42709 .69429 Mdot
.60832 .35826 Mdot
.45107 .71066 Mdot
.59385 .36392 Mdot
.39017 .36078 Mdot
.40369 .30914 Mdot
.41818 .69454 Mdot
.56258 .34436 Mdot
.3256 .4537 Mdot
.60443 .78903 Mdot
.62177 .60305 Mdot
.40518 .4088 Mdot
.58072 .32506 Mdot
.61125 .30783 Mdot
.58153 .31571 Mdot
.62065 .5631 Mdot
.50967 .47261 Mdot
.55249 .51401 Mdot
.41977 .36932 Mdot
.37821 .59855 Mdot
.47035 .64844 Mdot
.62167 .25212 Mdot
.43633 .6428 Mdot
.65848 .56466 Mdot
.56873 .57343 Mdot
.57774 .59336 Mdot
.63714 .59392 Mdot
.29214 .49302 Mdot
.61417 .54528 Mdot
.42836 .34367 Mdot
.37124 .57373 Mdot
.5587 .52163 Mdot
.34926 .48805 Mdot
.52384 .44043 Mdot
.38954 .73019 Mdot
.46453 .42877 Mdot
.82419 .59265 Mdot
.61007 .3555 Mdot
.364 .60348 Mdot
.36114 .58502 Mdot
.38735 .70605 Mdot
.39959 .37904 Mdot
.59808 .36699 Mdot
.54521 .6917 Mdot
.39223 .69895 Mdot
.57806 .57861 Mdot
.23646 .53365 Mdot
.22424 .50784 Mdot
.54985 .57229 Mdot
.59373 .54415 Mdot
.3554 .45691 Mdot
.38401 .55315 Mdot
.66152 .20959 Mdot
.46258 .74305 Mdot
.41266 .69323 Mdot
.41592 .73451 Mdot
.55711 .33346 Mdot
.59855 .48633 Mdot
.42168 .36333 Mdot
.47772 .76495 Mdot
.49223 .64076 Mdot
.49945 .786 Mdot
.37045 .76262 Mdot
.63031 .55817 Mdot
.64528 .45911 Mdot
.56408 .5728 Mdot
.61516 .3247 Mdot
.59177 .38624 Mdot
.6045 .33332 Mdot
.40943 .37606 Mdot
.74104 .56691 Mdot
.42194 .3324 Mdot
.83697 .54442 Mdot
.56351 .38923 Mdot
.28989 .54108 Mdot
.3523 .5396 Mdot
.59738 .49995 Mdot
.39397 .72704 Mdot
.36651 .37746 Mdot
.63319 .61578 Mdot
.19085 .50219 Mdot
.3377 .53973 Mdot
.60525 .3756 Mdot
.53188 .47804 Mdot
.8109 .39977 Mdot
.49436 .44106 Mdot
.51887 .59008 Mdot
.62689 .42394 Mdot
.39308 .70485 Mdot
.73369 .37365 Mdot
.43034 .7309 Mdot
.41226 .35298 Mdot
.60407 .59872 Mdot
.60993 .59041 Mdot
.58054 .60596 Mdot
.61451 .54747 Mdot
.37652 .33326 Mdot
.64637 .5389 Mdot
.32778 .2252 Mdot
.35671 .46891 Mdot
.72673 .69492 Mdot
.42291 .72101 Mdot
.42795 .3298 Mdot
.37221 .57128 Mdot
.3631 .50577 Mdot
.48096 .71527 Mdot
.55377 .56721 Mdot
.60198 .55073 Mdot
.37793 .53096 Mdot
.57112 .60649 Mdot
.6261 .63127 Mdot
.35235 .57501 Mdot
.43778 .64196 Mdot
.38801 .6919 Mdot
.42852 .71002 Mdot
.38111 .36294 Mdot
.56575 .34011 Mdot
.40918 .71971 Mdot
.38811 .57059 Mdot
.63202 .52623 Mdot
.63706 .55444 Mdot
.5815 .3241 Mdot
.39343 .2166 Mdot
.382 .72108 Mdot
.52688 .48209 Mdot
.55978 .37737 Mdot
.55729 .39212 Mdot
.58982 .56395 Mdot
.66837 .57368 Mdot
.6031 .3024 Mdot
.39474 .68865 Mdot
.42509 .32595 Mdot
.3392 .6246 Mdot
.4089 .34619 Mdot
.60307 .36572 Mdot
.64323 .57221 Mdot
.60239 .37411 Mdot
.58246 .51459 Mdot
.68579 .82532 Mdot
.60741 .58872 Mdot
.24779 .32719 Mdot
.52305 .69568 Mdot
.35863 .5791 Mdot
.32707 .45575 Mdot
.35477 .49104 Mdot
.56191 .38216 Mdot
.63965 .5702 Mdot
.41909 .73476 Mdot
.71463 .74805 Mdot
.55885 .31961 Mdot
.37451 .5911 Mdot
.36471 .52265 Mdot
.39311 .38371 Mdot
.56421 .51276 Mdot
.59509 .56616 Mdot
.3413 .53503 Mdot
.63055 .68836 Mdot
.56356 .36064 Mdot
.58089 .5995 Mdot
.57177 .56143 Mdot
.35501 .57546 Mdot
.59896 .79031 Mdot
.59717 .43127 Mdot
.60056 .59736 Mdot
.31469 .54468 Mdot
.43552 .35408 Mdot
.6271 .60674 Mdot
.64748 .5398 Mdot
.40224 .72826 Mdot
.75697 .64955 Mdot
.52759 .17752 Mdot
.43086 .36863 Mdot
.35715 .50157 Mdot
.60334 .51424 Mdot
.35089 .5399 Mdot
.63647 .55583 Mdot
.7999 .53779 Mdot
.35733 .47743 Mdot
.60495 .53526 Mdot
.61258 .49083 Mdot
.59702 .38471 Mdot
.61524 .54277 Mdot
.76369 .38722 Mdot
.34992 .59395 Mdot
.60984 .53828 Mdot
.70672 .55959 Mdot
.38107 .34208 Mdot
.6084 .49448 Mdot
.42653 .72141 Mdot
.5265 .6821 Mdot
.50346 .26297 Mdot
.32438 .53905 Mdot
.42718 .71123 Mdot
.62533 .57839 Mdot
.38777 .55768 Mdot
.41767 .3779 Mdot
.21715 .45761 Mdot
.56798 .59756 Mdot
.40098 .34077 Mdot
.40636 .36049 Mdot
.42191 .70708 Mdot
.15952 .54493 Mdot
.63002 .51907 Mdot
.59966 .57329 Mdot
.76873 .38399 Mdot
.62362 .35333 Mdot
.60723 .57944 Mdot
.61579 .52846 Mdot
.42558 .34188 Mdot
.64214 .37808 Mdot
.77557 .49988 Mdot
.25894 .62868 Mdot
.41716 .38398 Mdot
.37037 .62066 Mdot
.38787 .5572 Mdot
.42069 .72287 Mdot
.58415 .3651 Mdot
.40383 .74407 Mdot
.34871 .57581 Mdot
.60529 .52003 Mdot
.42376 .34982 Mdot
.68437 .30234 Mdot
.39476 .39105 Mdot
.32702 .55028 Mdot
.61728 .32039 Mdot
.46335 .23246 Mdot
.4002 .15997 Mdot
.49038 .2867 Mdot
.39056 .29684 Mdot
.3931 .7129 Mdot
.25152 .47837 Mdot
.57056 .56571 Mdot
.72499 .37857 Mdot
.62025 .57707 Mdot
.68338 .51106 Mdot
.37074 .60365 Mdot
.3627 .51161 Mdot
.60344 .59777 Mdot
.56536 .73628 Mdot
.38239 .3885 Mdot
.39702 .38597 Mdot
.60478 .54127 Mdot
.39531 .37074 Mdot
.5931 .58044 Mdot
.37743 .56996 Mdot
.16809 .45881 Mdot
.5692 .58079 Mdot
.53773 .55095 Mdot
.38258 .28668 Mdot
.59966 .81295 Mdot
.31247 .45423 Mdot
.6379 .45104 Mdot
.7898 .3626 Mdot
.39595 .37053 Mdot
.63553 .49988 Mdot
.33288 .55598 Mdot
.35522 .45606 Mdot
.32644 .4532 Mdot
.61286 .57498 Mdot
.61365 .5692 Mdot
.57479 .5994 Mdot
.58186 .5366 Mdot
.7294 .38134 Mdot
.65161 .63413 Mdot
.68293 .48495 Mdot
.60104 .5482 Mdot
.6632 .49842 Mdot
.39839 .32017 Mdot
.63174 .3616 Mdot
.39434 .74273 Mdot
.62972 .55633 Mdot
.62781 .29647 Mdot
.43524 .34695 Mdot
.83765 .54172 Mdot
.3843 .37443 Mdot
.36026 .56008 Mdot
.37553 .36704 Mdot
.57046 .51611 Mdot
.58182 .35491 Mdot
.33418 .56752 Mdot
.24624 .4057 Mdot
.3655 .58801 Mdot
.57087 .51266 Mdot
.33122 .60299 Mdot
.36194 .58753 Mdot
.51432 .42031 Mdot
.57927 .35942 Mdot
.59336 .74853 Mdot
.59138 .38669 Mdot
.60731 .53484 Mdot
.60258 .53174 Mdot
.33815 .43168 Mdot
.37365 .37461 Mdot
.57974 .39077 Mdot
.14205 .45937 Mdot
.42762 .73605 Mdot
.60154 .33479 Mdot
.533 .52835 Mdot
.47046 .56405 Mdot
.57912 .34942 Mdot
.59857 .708 Mdot
.40518 .38081 Mdot
.55333 .37533 Mdot
.53576 .52556 Mdot
.32754 .31781 Mdot
.41712 .68179 Mdot
.36917 .53577 Mdot
.43559 .47977 Mdot
.34319 .58084 Mdot
.42507 .32412 Mdot
.33878 .52682 Mdot
.39878 .32825 Mdot
.4908 .1978 Mdot
.6994 .62696 Mdot
.43128 .38176 Mdot
.41029 .31398 Mdot
.34164 .55146 Mdot
.56426 .58965 Mdot
.42372 .42814 Mdot
.5858 .61332 Mdot
.63227 .61221 Mdot
.39257 .33014 Mdot
.57374 .39308 Mdot
.58645 .397 Mdot
.63005 .4691 Mdot
.61677 .33452 Mdot
.37678 .56491 Mdot
.21964 .37485 Mdot
.46115 .19615 Mdot
.3955 .33516 Mdot
.39051 .31484 Mdot
.5737 .5431 Mdot
.34569 .54072 Mdot
.39332 .58888 Mdot
.41833 .36414 Mdot
.69767 .34974 Mdot
.5579 .50983 Mdot
.61708 .31388 Mdot
.56173 .38829 Mdot
.58644 .34329 Mdot
.57007 .3213 Mdot
.76626 .48215 Mdot
.40513 .3814 Mdot
.56282 .38614 Mdot
.60344 .53794 Mdot
.61282 .57074 Mdot
.34191 .45698 Mdot
.42882 .71286 Mdot
.61431 .51455 Mdot
.57651 .61815 Mdot
.59147 .56155 Mdot
.36873 .59631 Mdot
.53814 .50269 Mdot
.35915 .49819 Mdot
.37743 .54608 Mdot
.34513 .5021 Mdot
.33756 .46482 Mdot
.6016 .4499 Mdot
.79419 .35658 Mdot
.57426 .53304 Mdot
.61986 .65486 Mdot
.35278 .54275 Mdot
.19111 .4612 Mdot
.43831 .22294 Mdot
.57262 .5995 Mdot
.39024 .46071 Mdot
.3409 .5304 Mdot
.62072 .35584 Mdot
.61227 .5793 Mdot
.34619 .44929 Mdot
.38956 .72913 Mdot
.52662 .54415 Mdot
.34963 .44829 Mdot
.55979 .35174 Mdot
.38372 .74087 Mdot
.55221 .3618 Mdot
.33424 .53555 Mdot
.61182 .49168 Mdot
.85821 .3751 Mdot
.38027 .61241 Mdot
.67719 .75753 Mdot
.64059 .30699 Mdot
.57747 .59839 Mdot
.36311 .6042 Mdot
.62302 .34872 Mdot
.43141 .33108 Mdot
.46627 .58326 Mdot
.60905 .32642 Mdot
.36181 .50834 Mdot
.3478 .45497 Mdot
.35465 .57852 Mdot
.58765 .37748 Mdot
.62986 .58729 Mdot
.57583 .3793 Mdot
.37641 .36848 Mdot
.56179 .56012 Mdot
.82992 .46277 Mdot
.63087 .65065 Mdot
.56441 .38441 Mdot
.3827 .56554 Mdot
.43504 .69942 Mdot
.55659 .56438 Mdot
.66984 .75251 Mdot
.58733 .50902 Mdot
.40304 .33308 Mdot
.19827 .56532 Mdot
.70034 .31574 Mdot
.55376 .52942 Mdot
.57464 .54196 Mdot
.40783 .38356 Mdot
.55462 .56653 Mdot
.55062 .54201 Mdot
.46056 .35178 Mdot
.58541 .38285 Mdot
.57444 .57253 Mdot
.38912 .58797 Mdot
.53883 .19479 Mdot
.55417 .51384 Mdot
.38992 .52602 Mdot
.58016 .74592 Mdot
.18829 .56664 Mdot
.61951 .58322 Mdot
.47507 .74586 Mdot
.58595 .53775 Mdot
.62591 .56332 Mdot
.56949 .54377 Mdot
.63785 .43754 Mdot
.34093 .55456 Mdot
.37385 .58213 Mdot
.41313 .68116 Mdot
.58648 .7446 Mdot
.40683 .7283 Mdot
.39135 .37911 Mdot
.35759 .68332 Mdot
.35654 .47856 Mdot
.55978 .34929 Mdot
.62215 .58843 Mdot
.34923 .59507 Mdot
.59856 .5618 Mdot
.57392 .51605 Mdot
.36256 .53485 Mdot
.39456 .59931 Mdot
.33043 .51901 Mdot
.40842 .73709 Mdot
.60951 .33474 Mdot
.65091 .57014 Mdot
.40482 .68743 Mdot
.63127 .58419 Mdot
.46102 .66987 Mdot
.6059 .33099 Mdot
.58277 .38291 Mdot
.60976 .38371 Mdot
.60476 .5195 Mdot
.56016 .52556 Mdot
.41969 .33042 Mdot
.56342 .34025 Mdot
.38166 .35317 Mdot
.33166 .55586 Mdot
.40084 .61419 Mdot
.6129 .57476 Mdot
.50243 .533 Mdot
.40491 .73227 Mdot
.36562 .56337 Mdot
.38193 .53551 Mdot
.43224 .68898 Mdot
.58419 .51046 Mdot
.35901 .53411 Mdot
.4291 .70398 Mdot
.68074 .35317 Mdot
.76685 .31252 Mdot
.43607 .7075 Mdot
.60233 .53943 Mdot
.65179 .36627 Mdot
.57959 .79283 Mdot
.43274 .73144 Mdot
.41571 .3413 Mdot
.60613 .51933 Mdot
.61246 .67204 Mdot
.38731 .73188 Mdot
.5354 .20104 Mdot
.35812 .57612 Mdot
.33371 .33495 Mdot
.539 .60172 Mdot
.71105 .38428 Mdot
.41399 .74374 Mdot
.59783 .3625 Mdot
.62592 .36976 Mdot
.58525 .55573 Mdot
.4172 .74771 Mdot
.41084 .38771 Mdot
.36247 .57717 Mdot
.33393 .4796 Mdot
.58498 .37806 Mdot
.42805 .27428 Mdot
.38318 .58994 Mdot
.51627 .49779 Mdot
.2329 .5976 Mdot
.68358 .62416 Mdot
.69287 .54247 Mdot
.26145 .34954 Mdot
.62038 .52978 Mdot
.43553 .71656 Mdot
.43292 .34387 Mdot
.42573 .35832 Mdot
.38845 .35333 Mdot
.32795 .45849 Mdot
.48166 .42376 Mdot
.33507 .55112 Mdot
.23316 .438 Mdot
.421 .71392 Mdot
.62484 .7381 Mdot
.63218 .57994 Mdot
.56881 .57509 Mdot
.5973 .50565 Mdot
.61528 .60078 Mdot
.58254 .54537 Mdot
.39613 .37592 Mdot
.3267 .46019 Mdot
.3106 .62107 Mdot
.58774 .33529 Mdot
.4234 .64214 Mdot
.35253 .53957 Mdot
.35625 .45987 Mdot
.4112 .69777 Mdot
.53923 .45906 Mdot
.33254 .52964 Mdot
.3622 .54637 Mdot
.61252 .51068 Mdot
.56615 .37204 Mdot
.67139 .57773 Mdot
.59502 .52979 Mdot
.36913 .56457 Mdot
.4145 .60182 Mdot
.78568 .46305 Mdot
.62339 .48258 Mdot
.37731 .69916 Mdot
.4957 .49732 Mdot
.43365 .72899 Mdot
.54162 .5893 Mdot
.18845 .47278 Mdot
.34788 .57359 Mdot
.35392 .55769 Mdot
.43181 .7048 Mdot
.50675 .53685 Mdot
.58164 .37125 Mdot
.36615 .51579 Mdot
.41264 .3318 Mdot
.60504 .52813 Mdot
.40007 .60913 Mdot
.51586 .59442 Mdot
.2981 .66446 Mdot
.38988 .34617 Mdot
.38158 .55526 Mdot
.56261 .51439 Mdot
.6005 .54003 Mdot
.39187 .71041 Mdot
.58675 .27784 Mdot
.52318 .5555 Mdot
.75905 .69695 Mdot
.30864 .28444 Mdot
.34693 .26595 Mdot
.59115 .56532 Mdot
.58842 .38066 Mdot
.35176 .45898 Mdot
.39716 .69399 Mdot
.65126 .5542 Mdot
.77433 .32553 Mdot
.6277 .32453 Mdot
.40701 .35225 Mdot
.34501 .44949 Mdot
.48514 .42173 Mdot
.59671 .51239 Mdot
.6195 .57738 Mdot
.6182 .55656 Mdot
.71449 .24584 Mdot
.37755 .59248 Mdot
.60995 .32022 Mdot
.40545 .70847 Mdot
.61655 .33164 Mdot
.36862 .58477 Mdot
.42767 .25096 Mdot
.55405 .54021 Mdot
.61843 .31802 Mdot
.59531 .36085 Mdot
.39263 .38325 Mdot
.42952 .32724 Mdot
.36103 .62478 Mdot
.60604 .58887 Mdot
.34723 .44944 Mdot
.59602 .3865 Mdot
.37749 .53526 Mdot
.39893 .69639 Mdot
.41135 .32269 Mdot
.60231 .5483 Mdot
.35354 .5814 Mdot
.6628 .57313 Mdot
.57338 .35255 Mdot
.36129 .54574 Mdot
.34251 .48399 Mdot
.41974 .7313 Mdot
.60873 .56013 Mdot
.3823 .68924 Mdot
.35653 .50414 Mdot
.57068 .56204 Mdot
.56464 .44773 Mdot
.37287 .70516 Mdot
.25478 .41595 Mdot
.34062 .56888 Mdot
.34034 .46978 Mdot
.61025 .38043 Mdot
.53531 .21094 Mdot
.35667 .5628 Mdot
.55367 .45053 Mdot
.54846 .2862 Mdot
.65129 .57038 Mdot
.59429 .34581 Mdot
.24443 .49956 Mdot
.79873 .64729 Mdot
.64631 .74606 Mdot
.57375 .59029 Mdot
.3547 .59572 Mdot
.42284 .69228 Mdot
.39511 .3348 Mdot
.38888 .52512 Mdot
.67943 .64552 Mdot
.3524 .52484 Mdot
.57225 .54008 Mdot
.58846 .38603 Mdot
.41395 .36631 Mdot
.52946 .24926 Mdot
.38581 .56709 Mdot
.36619 .60163 Mdot
.5575 .52233 Mdot
.41458 .72165 Mdot
.68909 .69562 Mdot
.37842 .57614 Mdot
.39761 .61168 Mdot
.25123 .46839 Mdot
.42823 .69504 Mdot
.59078 .53999 Mdot
.63617 .47383 Mdot
.6353 .5977 Mdot
.68511 .75697 Mdot
.3556 .4963 Mdot
.58453 .33588 Mdot
.62284 .57272 Mdot
.25276 .63031 Mdot
.36765 .56924 Mdot
.51181 .45815 Mdot
.40499 .62459 Mdot
.40645 .38045 Mdot
.39814 .61264 Mdot
.60465 .5732 Mdot
.38411 .38933 Mdot
.40515 .73201 Mdot
.59982 .59533 Mdot
.56014 .52711 Mdot
.62126 .34613 Mdot
.41347 .35279 Mdot
.64356 .26001 Mdot
.40113 .31587 Mdot
.43323 .35635 Mdot
.59664 .39759 Mdot
.58112 .56868 Mdot
.3613 .55681 Mdot
.3419 .52647 Mdot
.6505 .56403 Mdot
.18899 .41784 Mdot
.58103 .37358 Mdot
.44397 .67368 Mdot
.678 .22822 Mdot
.62354 .47804 Mdot
.38631 .54484 Mdot
.57222 .28388 Mdot
.41319 .38569 Mdot
.60278 .54383 Mdot
.56097 .37308 Mdot
.39719 .58713 Mdot
.38427 .59001 Mdot
.63901 .57784 Mdot
.40879 .36443 Mdot
.38487 .7163 Mdot
.38192 .60933 Mdot
.27939 .66112 Mdot
.62033 .55134 Mdot
.22825 .45857 Mdot
.37291 .60738 Mdot
.73581 .73887 Mdot
.306 .63522 Mdot
.59331 .34266 Mdot
.5707 .51831 Mdot
.61595 .33601 Mdot
.40131 .70858 Mdot
.36278 .61886 Mdot
.40881 .36192 Mdot
.60808 .4744 Mdot
.44342 .16743 Mdot
.33978 .54818 Mdot
.58345 .32876 Mdot
.55444 .52702 Mdot
.57094 .46488 Mdot
.60058 .57758 Mdot
.63466 .39446 Mdot
.44518 .67866 Mdot
.38887 .33187 Mdot
.40686 .33442 Mdot
.56751 .56479 Mdot
.38861 .71549 Mdot
.37329 .54607 Mdot
.36123 .57529 Mdot
.45459 .87684 Mdot
.37234 .52495 Mdot
.55738 .72204 Mdot
.61206 .56593 Mdot
.37367 .53051 Mdot
.61485 .24364 Mdot
.40037 .33801 Mdot
.61905 .5989 Mdot
.36035 .51499 Mdot
.31872 .30705 Mdot
.45664 .65131 Mdot
.58489 .54487 Mdot
.59719 .63487 Mdot
.41285 .33341 Mdot
.52527 .7789 Mdot
.33522 .54423 Mdot
.62395 .59824 Mdot
.37797 .32134 Mdot
.23693 .62749 Mdot
.46162 .18588 Mdot
.60935 .33487 Mdot
.35249 .60115 Mdot
.39648 .37646 Mdot
.52726 .58645 Mdot
.42476 .71866 Mdot
.34497 .58629 Mdot
.37059 .59446 Mdot
.56584 .54028 Mdot
.60738 .50617 Mdot
.61401 .4711 Mdot
.57936 .33304 Mdot
.39056 .3215 Mdot
.60668 .59865 Mdot
.42698 .27645 Mdot
.58636 .60778 Mdot
.40557 .32287 Mdot
.90934 .47584 Mdot
.62179 .61472 Mdot
.59849 .57649 Mdot
.68234 .70708 Mdot
.61132 .32859 Mdot
.61855 .34097 Mdot
.27304 .31113 Mdot
.61171 .56539 Mdot
.33148 .65161 Mdot
.61184 .33853 Mdot
.57753 .37096 Mdot
.28002 .54776 Mdot
.5617 .57356 Mdot
.51838 .79416 Mdot
.42425 .35869 Mdot
.42995 .35041 Mdot
.57805 .37938 Mdot
.52351 .57165 Mdot
.42045 .37807 Mdot
.75103 .4167 Mdot
.34514 .5379 Mdot
.18493 .4815 Mdot
.57184 .34998 Mdot
.4496 .41105 Mdot
.394 .33928 Mdot
.83591 .54921 Mdot
.38439 .45823 Mdot
.57103 .59548 Mdot
.6111 .55676 Mdot
.40943 .73227 Mdot
.65253 .58015 Mdot
.36075 .50362 Mdot
.3949 .37068 Mdot
.71013 .67184 Mdot
.6044 .33392 Mdot
.60163 .58638 Mdot
.5297 .46687 Mdot
.53008 .26464 Mdot
.30178 .4194 Mdot
.58962 .36812 Mdot
.59965 .34588 Mdot
.3404 .5628 Mdot
.37468 .60394 Mdot
.58175 .56023 Mdot
.41922 .36852 Mdot
.55986 .34445 Mdot
.40161 .32397 Mdot
.35062 .57899 Mdot
.36313 .55104 Mdot
.35772 .47554 Mdot
.57562 .61206 Mdot
.37657 .5545 Mdot
.26659 .66166 Mdot
.4213 .26972 Mdot
.55126 .34233 Mdot
.49682 .16068 Mdot
.52978 .24783 Mdot
.56306 .6776 Mdot
.41488 .7382 Mdot
.35616 .50547 Mdot
.37443 .34474 Mdot
.57348 .54619 Mdot
.60039 .55607 Mdot
.347 .4736 Mdot
.38009 .38028 Mdot
.4022 .69908 Mdot
.37858 .38057 Mdot
.42407 .70975 Mdot
.38613 .54992 Mdot
.57051 .5065 Mdot
.62728 .54294 Mdot
.39206 .37089 Mdot
.36708 .54725 Mdot
.37226 .57633 Mdot
.43326 .72857 Mdot
.46142 .63057 Mdot
.35532 .58083 Mdot
.57207 .35094 Mdot
.75643 .48537 Mdot
.34938 .45932 Mdot
.61037 .57933 Mdot
.46936 .68055 Mdot
.71581 .35749 Mdot
.63571 .5921 Mdot
.34075 .45256 Mdot
.32131 .78409 Mdot
.62086 .58676 Mdot
.25949 .73864 Mdot
.33982 .46803 Mdot
.60974 .32582 Mdot
.35588 .59615 Mdot
.36216 .50187 Mdot
.55127 .62072 Mdot
.44151 .69056 Mdot
.63974 .54108 Mdot
.61463 .33833 Mdot
.62437 .36425 Mdot
.33264 .26185 Mdot
.67774 .75827 Mdot
.43018 .72951 Mdot
.41816 .69767 Mdot
.35569 .56407 Mdot
.51396 .83847 Mdot
.55601 .5042 Mdot
.41009 .69403 Mdot
.6772 .68275 Mdot
.5768 .53358 Mdot
.52941 .72577 Mdot
.39562 .46495 Mdot
.58619 .37977 Mdot
.61124 .4569 Mdot
.36196 .56773 Mdot
.58934 .32686 Mdot
.4016 .25587 Mdot
.60937 .51351 Mdot
.6043 .33099 Mdot
.41101 .32573 Mdot
.2775 .36477 Mdot
.61371 .36391 Mdot
.46472 .68147 Mdot
.41842 .36631 Mdot
.26255 .48082 Mdot
.65518 .70339 Mdot
.36555 .15574 Mdot
.40029 .37574 Mdot
.35232 .53282 Mdot
.3414 .5299 Mdot
.35865 .573 Mdot
.60391 .32239 Mdot
.39055 .57441 Mdot
.57288 .33832 Mdot
.57253 .80291 Mdot
.46275 .63141 Mdot
.41831 .69408 Mdot
.46265 .33967 Mdot
.59752 .3541 Mdot
.21231 .41595 Mdot
.4152 .15795 Mdot
.60686 .54218 Mdot
.39208 .31594 Mdot
.43187 .70799 Mdot
.6958 .78456 Mdot
.40493 .73027 Mdot
.33404 .55946 Mdot
.17689 .50258 Mdot
.59342 .58431 Mdot
.77439 .55592 Mdot
.42301 .7316 Mdot
.59715 .37153 Mdot
.56955 .56695 Mdot
.32569 .44887 Mdot
.41636 .72457 Mdot
.38676 .72292 Mdot
.57729 .55819 Mdot
.6045 .37697 Mdot
.36424 .55573 Mdot
.37195 .34686 Mdot
.43913 .72408 Mdot
.5807 .64252 Mdot
.65106 .57361 Mdot
.61215 .5187 Mdot
.50154 .43485 Mdot
.66522 .67304 Mdot
.39703 .37108 Mdot
.60004 .77004 Mdot
.37603 .60283 Mdot
.25487 .52495 Mdot
.28205 .30775 Mdot
.46646 .37509 Mdot
.35355 .49458 Mdot
.35743 .49292 Mdot
.58269 .54939 Mdot
.66558 .67389 Mdot
.2041 .57946 Mdot
.39969 .28911 Mdot
.35059 .46238 Mdot
.36531 .57702 Mdot
.62865 .36169 Mdot
.33774 .24946 Mdot
.65649 .56557 Mdot
.42273 .38208 Mdot
.35873 .58765 Mdot
.80087 .5341 Mdot
.41468 .71683 Mdot
.19804 .44954 Mdot
.55618 .52736 Mdot
.59592 .60232 Mdot
.39608 .36197 Mdot
.42396 .33512 Mdot
.34505 .42216 Mdot
.31931 .2712 Mdot
.47273 .77967 Mdot
.56645 .22931 Mdot
.79894 .52437 Mdot
.6322 .35673 Mdot
.56609 .3864 Mdot
.3394 .44397 Mdot
.41311 .32046 Mdot
.62398 .57665 Mdot
.55922 .34837 Mdot
.29319 .42312 Mdot
.54898 .39914 Mdot
.54352 .72862 Mdot
.31511 .65757 Mdot
.58289 .51244 Mdot
.56792 .37775 Mdot
.59757 .32579 Mdot
.56057 .33713 Mdot
.33864 .45767 Mdot
.58794 .57005 Mdot
.56045 .58106 Mdot
.60399 .60444 Mdot
.62903 .64435 Mdot
.61803 .54628 Mdot
.43005 .29223 Mdot
.48751 .4791 Mdot
.73227 .66074 Mdot
.62434 .60403 Mdot
.42791 .35963 Mdot
.62135 .52568 Mdot
.38794 .71411 Mdot
.57107 .5436 Mdot
.54482 .72304 Mdot
.39912 .34659 Mdot
.52136 .50573 Mdot
.55957 .2257 Mdot
.55498 .5338 Mdot
.38442 .70198 Mdot
.61488 .67817 Mdot
.6436 .26764 Mdot
.42995 .63423 Mdot
.57148 .35261 Mdot
.34608 .51907 Mdot
.37815 .37002 Mdot
.3588 .55431 Mdot
.61003 .61127 Mdot
.34269 .44573 Mdot
.49035 .3245 Mdot
.44596 .41437 Mdot
.63131 .56712 Mdot
.56508 .49027 Mdot
.57216 .36286 Mdot
.35811 .53398 Mdot
.62588 .38551 Mdot
.62038 .56533 Mdot
.40465 .71227 Mdot
.41988 .72102 Mdot
.36919 .26995 Mdot
.82054 .50198 Mdot
.51769 .20469 Mdot
.39555 .36396 Mdot
.37924 .58026 Mdot
.41193 .74499 Mdot
.59379 .65359 Mdot
.43567 .36648 Mdot
.40356 .38589 Mdot
.4157 .35801 Mdot
.60082 .52134 Mdot
.35892 .50073 Mdot
.73108 .64611 Mdot
.36095 .50607 Mdot
.5559 .53599 Mdot
.37598 .59571 Mdot
.35881 .48195 Mdot
.41511 .73039 Mdot
.38079 .36302 Mdot
.35248 .58414 Mdot
.60927 .53505 Mdot
.61126 .34999 Mdot
.46324 .60721 Mdot
.50273 .67459 Mdot
.70602 .73023 Mdot
.7208 .71513 Mdot
.59458 .39113 Mdot
.82303 .55398 Mdot
.38121 .39645 Mdot
.69839 .35237 Mdot
.31347 .57046 Mdot
.64506 .57362 Mdot
.21838 .35333 Mdot
.3342 .54664 Mdot
.35848 .53241 Mdot
.59015 .5374 Mdot
.39428 .58149 Mdot
.60101 .58361 Mdot
.36421 .59867 Mdot
.41953 .64136 Mdot
.65916 .5592 Mdot
.37158 .54708 Mdot
.53261 .57496 Mdot
.55742 .5626 Mdot
.58447 .38137 Mdot
.35946 .6023 Mdot
.5973 .61139 Mdot
.60707 .83843 Mdot
.41683 .32653 Mdot
.33997 .45542 Mdot
.4428 .7539 Mdot
.39462 .37604 Mdot
.5982 .33453 Mdot
.63866 .60801 Mdot
.39576 .7256 Mdot
.60155 .36136 Mdot
.43095 .66003 Mdot
.42718 .7272 Mdot
.21695 .37754 Mdot
.56918 .36005 Mdot
.34886 .46283 Mdot
.41058 .73447 Mdot
.57854 .48839 Mdot
.36652 .61002 Mdot
.48717 .63242 Mdot
.35457 .49988 Mdot
.59598 .56625 Mdot
.32594 .46691 Mdot
.41298 .32269 Mdot
.57841 .59249 Mdot
.38491 .61372 Mdot
.33761 .46895 Mdot
.59502 .52007 Mdot
.57752 .54373 Mdot
.37851 .22866 Mdot
.21218 .49599 Mdot
.39391 .70427 Mdot
.62525 .33699 Mdot
.60369 .53765 Mdot
.40593 .73701 Mdot
.31971 .71504 Mdot
.61667 .52514 Mdot
.59763 .3175 Mdot
.67836 .56965 Mdot
.38365 .60428 Mdot
.38133 .35569 Mdot
.33936 .58181 Mdot
.39121 .73114 Mdot
.135 .51742 Mdot
.35858 .47097 Mdot
.5393 .58545 Mdot
.62578 .5881 Mdot
.30781 .43234 Mdot
.5906 .32747 Mdot
.4764 .7772 Mdot
.6089 .55974 Mdot
.65661 .64457 Mdot
.59614 .59464 Mdot
.31035 .63152 Mdot
.58054 .3719 Mdot
.59872 .57236 Mdot
.5055 .51518 Mdot
.54363 .53448 Mdot
.38374 .71571 Mdot
.66075 .72931 Mdot
.63141 .54038 Mdot
.78764 .26707 Mdot
.37947 .53322 Mdot
.37372 .54938 Mdot
.31891 .44228 Mdot
.40837 .8169 Mdot
.50362 .1976 Mdot
.57321 .33704 Mdot
.52269 .33151 Mdot
.36174 .55524 Mdot
.55636 .20826 Mdot
.81944 .58068 Mdot
.55727 .55868 Mdot
.59541 .51244 Mdot
.33406 .55952 Mdot
.36997 .5249 Mdot
.34842 .44803 Mdot
.61186 .61275 Mdot
.58466 .48274 Mdot
.38391 .56605 Mdot
.61738 .53841 Mdot
.67401 .57142 Mdot
.37278 .34191 Mdot
.60422 .38177 Mdot
.39107 .33558 Mdot
.38227 .37188 Mdot
.71288 .42156 Mdot
.31877 .28081 Mdot
.4049 .32231 Mdot
.38947 .39684 Mdot
.5309 .71887 Mdot
.62903 .47458 Mdot
.39403 .73811 Mdot
.78402 .62252 Mdot
.35434 .56884 Mdot
.58654 .57175 Mdot
.57927 .39672 Mdot
.70256 .39308 Mdot
.39688 .49387 Mdot
.1835 .54531 Mdot
.62302 .56847 Mdot
.36485 .57136 Mdot
.34118 .47975 Mdot
.65967 .54945 Mdot
.26177 .53126 Mdot
.58779 .6028 Mdot
.34937 .59519 Mdot
.75486 .5311 Mdot
.53591 .46968 Mdot
.23948 .5011 Mdot
.58641 .41999 Mdot
.61284 .5911 Mdot
.57454 .34373 Mdot
.38841 .34442 Mdot
.39185 .72657 Mdot
.39398 .70636 Mdot
.57314 .5584 Mdot
.67426 .64508 Mdot
.39788 .45926 Mdot
.55594 .56071 Mdot
.56461 .54796 Mdot
.34018 .47013 Mdot
.56388 .55089 Mdot
.62378 .5902 Mdot
.61115 .60246 Mdot
.54278 .55513 Mdot
.43274 .35659 Mdot
.52876 .47292 Mdot
.57552 .61364 Mdot
.67003 .57034 Mdot
.36963 .34349 Mdot
.5359 .30748 Mdot
.37784 .35829 Mdot
.82946 .45901 Mdot
.40093 .33182 Mdot
.40107 .69606 Mdot
.32779 .48545 Mdot
.68636 .58264 Mdot
.55415 .36421 Mdot
.43645 .34357 Mdot
.41183 .70391 Mdot
.38961 .36118 Mdot
.38008 .59361 Mdot
.6191 .19791 Mdot
.54818 .39721 Mdot
.46922 .75955 Mdot
.35426 .29668 Mdot
.2367 .45388 Mdot
.33757 .54876 Mdot
.58041 .37619 Mdot
.78906 .47116 Mdot
.5967 .60923 Mdot
.41418 .7338 Mdot
.58022 .55585 Mdot
.4336 .35778 Mdot
.36078 .57081 Mdot
.64053 .75669 Mdot
.39234 .7163 Mdot
.4118 .199 Mdot
.36192 .5799 Mdot
.57082 .60109 Mdot
.42378 .38079 Mdot
.48563 .15828 Mdot
.39002 .33316 Mdot
.46326 .63892 Mdot
.60136 .31255 Mdot
.67195 .50267 Mdot
.59415 .34948 Mdot
.35998 .44799 Mdot
.71579 .23643 Mdot
.76762 .67483 Mdot
.60932 .36107 Mdot
.23571 .55261 Mdot
.59464 .514 Mdot
.61517 .52063 Mdot
.53521 .47834 Mdot
.60946 .31897 Mdot
.61083 .54183 Mdot
.34281 .4812 Mdot
.43619 .26012 Mdot
.25416 .58836 Mdot
.3477 .51953 Mdot
.60482 .57865 Mdot
.37139 .33725 Mdot
.38119 .38363 Mdot
.36044 .49543 Mdot
.37708 .35132 Mdot
.56232 .58299 Mdot
.59594 .3525 Mdot
.42 .42033 Mdot
.39956 .71949 Mdot
.62585 .80865 Mdot
.39934 .74555 Mdot
.35103 .49924 Mdot
.611 .49102 Mdot
.3633 .55048 Mdot
.19403 .69983 Mdot
.57043 .59282 Mdot
.61033 .33304 Mdot
.58479 .53063 Mdot
.60704 .59519 Mdot
.60817 .51418 Mdot
.38642 .57575 Mdot
.41392 .78444 Mdot
.61533 .53699 Mdot
.40986 .36101 Mdot
.74389 .67198 Mdot
.62214 .52476 Mdot
.41497 .63895 Mdot
.59845 .73362 Mdot
.23384 .43185 Mdot
.55124 .36656 Mdot
.36146 .5371 Mdot
.60521 .33916 Mdot
.5818 .41374 Mdot
.59801 .33432 Mdot
.74928 .63234 Mdot
.78185 .4883 Mdot
.31277 .77272 Mdot
.70326 .5496 Mdot
.68197 .3824 Mdot
.62558 .32971 Mdot
.31677 .73571 Mdot
.55915 .37413 Mdot
.58431 .33233 Mdot
.80561 .7259 Mdot
.55996 .38182 Mdot
.60957 .57231 Mdot
.63332 .52512 Mdot
.50206 .27758 Mdot
.51185 .72548 Mdot
.56605 .55812 Mdot
.59738 .53577 Mdot
.39751 .73188 Mdot
.66033 .65927 Mdot
.34453 .4424 Mdot
.22136 .37158 Mdot
.55846 .2572 Mdot
.57859 .55555 Mdot
.60432 .53598 Mdot
.56572 .49517 Mdot
.6356 .16253 Mdot
.72458 .40551 Mdot
.62895 .33745 Mdot
.52736 .52095 Mdot
.69218 .7641 Mdot
.55477 .57703 Mdot
.61751 .52954 Mdot
.58246 .51449 Mdot
.36161 .55644 Mdot
.62826 .32449 Mdot
.52968 .51719 Mdot
.23224 .39933 Mdot
.56306 .51632 Mdot
.46858 .36365 Mdot
.44446 .80208 Mdot
.60466 .57197 Mdot
.56297 .3283 Mdot
.57564 .5272 Mdot
.56755 .36055 Mdot
.5876 .38394 Mdot
.57274 .49449 Mdot
.78313 .58433 Mdot
.59341 .31564 Mdot
.55817 .52834 Mdot
.37159 .55565 Mdot
.78548 .66056 Mdot
.59797 .56503 Mdot
.40106 .6898 Mdot
.61058 .5589 Mdot
.38926 .69351 Mdot
.56081 .5461 Mdot
.36066 .50727 Mdot
.7125 .33176 Mdot
.35293 .55848 Mdot
.48513 .81067 Mdot
.38246 .54701 Mdot
.37617 .22963 Mdot
.59828 .31893 Mdot
.33694 .47197 Mdot
.16338 .53876 Mdot
.3408 .46296 Mdot
.50596 .48691 Mdot
.47248 .53387 Mdot
.41819 .37119 Mdot
.61945 .35142 Mdot
.57858 .7735 Mdot
.30029 .4287 Mdot
.31858 .49484 Mdot
.34652 .50441 Mdot
.14657 .48625 Mdot
.16951 .47441 Mdot
.60837 .53091 Mdot
.76273 .58434 Mdot
.68738 .48402 Mdot
.6168 .52643 Mdot
.62313 .61713 Mdot
.3813 .61829 Mdot
.62925 .58259 Mdot
.50886 .42007 Mdot
.34141 .55028 Mdot
.41656 .70358 Mdot
.58185 .33686 Mdot
.39954 .68583 Mdot
.30669 .45004 Mdot
.47494 .5387 Mdot
.36238 .59486 Mdot
.54083 .54814 Mdot
.58924 .53031 Mdot
.57454 .37987 Mdot
.64022 .35442 Mdot
.59769 .38391 Mdot
.43334 .71054 Mdot
.34479 .55729 Mdot
.72 .3899 Mdot
.59596 .54268 Mdot
.59301 .35977 Mdot
.34854 .32584 Mdot
.60128 .54057 Mdot
.38629 .3605 Mdot
.58272 .50976 Mdot
.61167 .35899 Mdot
.56366 .55104 Mdot
.59741 .35117 Mdot
.34518 .53461 Mdot
.55188 .57207 Mdot
.58814 .54069 Mdot
.4789 .16334 Mdot
.40039 .70104 Mdot
.60011 .31931 Mdot
.43945 .46675 Mdot
.57896 .60693 Mdot
.27585 .45425 Mdot
.61825 .5832 Mdot
.53009 .3583 Mdot
.53501 .57396 Mdot
.33899 .46884 Mdot
.66113 .58157 Mdot
.59781 .56617 Mdot
.48756 .56128 Mdot
.71774 .53753 Mdot
.63445 .36784 Mdot
.4251 .3765 Mdot
.57036 .32154 Mdot
.39947 .61572 Mdot
.34615 .49408 Mdot
.39368 .60418 Mdot
.495 .74209 Mdot
.57549 .49495 Mdot
.59238 .58275 Mdot
.40449 .30908 Mdot
.421 .70177 Mdot
.59122 .36704 Mdot
.422 .70716 Mdot
.25224 .33705 Mdot
.4323 .71533 Mdot
.36166 .50231 Mdot
.30498 .63675 Mdot
.73525 .38146 Mdot
.39898 .73267 Mdot
.60054 .38336 Mdot
.30882 .6577 Mdot
.64038 .58065 Mdot
.45098 .70425 Mdot
.40539 .71393 Mdot
.14052 .47079 Mdot
.63045 .57491 Mdot
.51178 .47272 Mdot
.38956 .32671 Mdot
.4229 .7225 Mdot
.41218 .34874 Mdot
.56855 .5572 Mdot
.25715 .42239 Mdot
.57899 .33048 Mdot
.3674 .36242 Mdot
.59925 .62121 Mdot
.42833 .70172 Mdot
.36254 .59027 Mdot
.43777 .31732 Mdot
.42664 .36276 Mdot
.70464 .29503 Mdot
.64313 .74712 Mdot
.34377 .55438 Mdot
.21289 .56472 Mdot
.41954 .34868 Mdot
.6224 .53249 Mdot
.66995 .62792 Mdot
.56899 .59412 Mdot
.32361 .45348 Mdot
.36222 .53687 Mdot
.46291 .27593 Mdot
.58935 .528 Mdot
.62562 .57929 Mdot
.59039 .30463 Mdot
.34311 .54112 Mdot
.58087 .35261 Mdot
.55679 .34347 Mdot
.34447 .53282 Mdot
.59172 .34439 Mdot
.42182 .73111 Mdot
.44848 .24831 Mdot
.42019 .34739 Mdot
.40679 .35829 Mdot
.36414 .57648 Mdot
.38033 .55754 Mdot
.3614 .54713 Mdot
.58194 .50976 Mdot
.58646 .37058 Mdot
.56848 .52235 Mdot
.60318 .51296 Mdot
.59316 .42408 Mdot
.56305 .39058 Mdot
.58 .51986 Mdot
.24644 .49222 Mdot
.43365 .67253 Mdot
.37705 .56006 Mdot
.39697 .32316 Mdot
.60106 .23422 Mdot
.38302 .30842 Mdot
.6062 .58092 Mdot
.31531 .32092 Mdot
.60685 .36821 Mdot
.40796 .73149 Mdot
.40125 .67297 Mdot
.39862 .72603 Mdot
.4338 .32765 Mdot
.56758 .33301 Mdot
.22093 .37419 Mdot
.60206 .581 Mdot
.50085 .4324 Mdot
.5913 .77017 Mdot
.25763 .34243 Mdot
.40213 .32189 Mdot
.60128 .53809 Mdot
.34348 .45883 Mdot
.77799 .43494 Mdot
.59113 .60213 Mdot
.61286 .60603 Mdot
.30146 .57491 Mdot
.67282 .55713 Mdot
.59932 .31356 Mdot
.31796 .26572 Mdot
.62994 .5239 Mdot
.58822 .43445 Mdot
.48888 .8649 Mdot
.60941 .58591 Mdot
.62135 .55971 Mdot
.59388 .55615 Mdot
.57837 .53329 Mdot
.57093 .31913 Mdot
.53098 .77017 Mdot
.42653 .37837 Mdot
.49077 .44971 Mdot
.42285 .35028 Mdot
.34657 .59035 Mdot
.525 .45382 Mdot
.61683 .36721 Mdot
.40801 .73252 Mdot
.74694 .34149 Mdot
.28539 .29079 Mdot
.33895 .55926 Mdot
.75645 .44446 Mdot
.40025 .7137 Mdot
.64857 .56849 Mdot
.40224 .68197 Mdot
.36458 .51834 Mdot
.41535 .36497 Mdot
.64344 .5339 Mdot
.57735 .39148 Mdot
.61514 .35996 Mdot
.60816 .5422 Mdot
.71076 .7504 Mdot
.38469 .35974 Mdot
.36056 .3374 Mdot
.59728 .51807 Mdot
.61255 .6067 Mdot
.5813 .34784 Mdot
.374 .56725 Mdot
.24775 .66318 Mdot
.40815 .69915 Mdot
.55451 .59187 Mdot
.57538 .53604 Mdot
.31574 .27933 Mdot
.38899 .37649 Mdot
.35456 .46953 Mdot
.6001 .52226 Mdot
.36135 .27495 Mdot
.59853 .52175 Mdot
.66203 .55748 Mdot
.36808 .55573 Mdot
.52864 .54872 Mdot
.62293 .5399 Mdot
.51692 .54503 Mdot
.41686 .34836 Mdot
.60525 .32938 Mdot
.57783 .31123 Mdot
.34547 .44888 Mdot
.38642 .35868 Mdot
.57876 .52233 Mdot
.3891 .37444 Mdot
.62184 .52823 Mdot
.61673 .54106 Mdot
.40469 .32276 Mdot
.58135 .35207 Mdot
.50735 .32732 Mdot
.52761 .46977 Mdot
.58162 .53014 Mdot
.65658 .56064 Mdot
.50453 .73926 Mdot
.19564 .64762 Mdot
.6216 .5713 Mdot
.61336 .35849 Mdot
.59387 .54016 Mdot
.40482 .34396 Mdot
.43093 .71503 Mdot
.61183 .35334 Mdot
.37438 .57819 Mdot
.33514 .54086 Mdot
.55688 .22389 Mdot
.3588 .49098 Mdot
.64507 .58311 Mdot
.54459 .32577 Mdot
.57652 .39971 Mdot
.55021 .8505 Mdot
.34359 .52947 Mdot
.38502 .72556 Mdot
.57502 .54806 Mdot
.32921 .31367 Mdot
.41167 .31189 Mdot
.78052 .25567 Mdot
.21832 .37806 Mdot
.39765 .7463 Mdot
.17723 .5448 Mdot
.34662 .46514 Mdot
.63193 .55363 Mdot
.39015 .72385 Mdot
.34433 .57582 Mdot
.64389 .56281 Mdot
.60407 .63467 Mdot
.46486 .77164 Mdot
.35771 .61174 Mdot
.38452 .36773 Mdot
.38988 .60499 Mdot
.42372 .681 Mdot
.36154 .50321 Mdot
.61335 .36963 Mdot
.59577 .57003 Mdot
.54927 .49998 Mdot
.37572 .57251 Mdot
.36251 .50966 Mdot
.57975 .51249 Mdot
.6175 .34277 Mdot
.39511 .59478 Mdot
.57464 .56234 Mdot
.69546 .36175 Mdot
.59255 .41697 Mdot
.35077 .5708 Mdot
.62079 .59115 Mdot
.6492 .49187 Mdot
.36882 .57937 Mdot
.37929 .56298 Mdot
.61034 .54116 Mdot
.41733 .73424 Mdot
.56331 .51328 Mdot
.40084 .32965 Mdot
.41946 .78751 Mdot
.40564 .34672 Mdot
.38592 .64558 Mdot
.63404 .50051 Mdot
.25341 .44464 Mdot
.60706 .38308 Mdot
.42252 .67864 Mdot
.6105 .22948 Mdot
.61951 .60408 Mdot
.81771 .55079 Mdot
.45897 .40811 Mdot
.67532 .79135 Mdot
.73062 .27466 Mdot
.40903 .71449 Mdot
.38817 .35462 Mdot
.62064 .55929 Mdot
.39224 .31429 Mdot
.3901 .71218 Mdot
.59939 .77583 Mdot
.62049 .59289 Mdot
.57844 .37069 Mdot
.56621 .51461 Mdot
.57122 .35243 Mdot
.60282 .54246 Mdot
.67208 .55943 Mdot
.32534 .52237 Mdot
.46494 .653 Mdot
.64411 .57599 Mdot
.61475 .19335 Mdot
.40826 .4865 Mdot
.40437 .70714 Mdot
.56272 .52469 Mdot
.35032 .48339 Mdot
.38761 .38746 Mdot
.56964 .66258 Mdot
.3629 .55386 Mdot
.38683 .32153 Mdot
.58842 .33996 Mdot
.34572 .52665 Mdot
.34913 .49409 Mdot
.52145 .56893 Mdot
.38671 .69973 Mdot
.41372 .37469 Mdot
.60077 .56803 Mdot
.62935 .57545 Mdot
.23609 .58671 Mdot
.39851 .51731 Mdot
.61558 .30358 Mdot
.42761 .17764 Mdot
.55071 .34019 Mdot
.40849 .69525 Mdot
.36658 .5532 Mdot
.62004 .57389 Mdot
.57449 .58928 Mdot
.33636 .47876 Mdot
.60045 .32024 Mdot
.34891 .59891 Mdot
.73032 .43031 Mdot
.36252 .52701 Mdot
.55439 .75063 Mdot
.6131 .33807 Mdot
.5497 .7519 Mdot
.42147 .67991 Mdot
.81113 .51931 Mdot
.5391 .69162 Mdot
.3877 .32735 Mdot
.5596 .75087 Mdot
.59878 .37074 Mdot
.60085 .52914 Mdot
.34876 .46762 Mdot
.35748 .48148 Mdot
.58173 .34095 Mdot
.33617 .56579 Mdot
.4216 .72253 Mdot
.62283 .55664 Mdot
.21431 .4464 Mdot
.50907 .2464 Mdot
.38068 .57743 Mdot
.66677 .59313 Mdot
.41301 .35432 Mdot
.62774 .55001 Mdot
.40478 .68786 Mdot
.40691 .37434 Mdot
.37553 .51793 Mdot
.44735 .26264 Mdot
.57079 .55946 Mdot
.34014 .26754 Mdot
.39181 .36963 Mdot
.20616 .60041 Mdot
.57932 .56437 Mdot
.41938 .34874 Mdot
.65585 .51695 Mdot
.25459 .35935 Mdot
.44391 .43703 Mdot
.81656 .59539 Mdot
.35307 .60948 Mdot
.33351 .55381 Mdot
.27619 .38126 Mdot
.30812 .50255 Mdot
.38169 .32277 Mdot
.36137 .50393 Mdot
.62729 .70465 Mdot
.41392 .34986 Mdot
.59715 .51201 Mdot
.61517 .58407 Mdot
.70949 .41374 Mdot
.46755 .42993 Mdot
.36373 .50936 Mdot
.48251 .20666 Mdot
.58154 .60728 Mdot
.56076 .61528 Mdot
.57692 .58687 Mdot
.62588 .36017 Mdot
.40386 .38095 Mdot
.52248 .16488 Mdot
.38452 .35068 Mdot
.20014 .46926 Mdot
.35481 .56875 Mdot
.3788 .5514 Mdot
.60595 .57493 Mdot
.24119 .46564 Mdot
.67817 .66729 Mdot
.55847 .5769 Mdot
.26011 .47864 Mdot
.65435 .74277 Mdot
.59362 .62216 Mdot
.60385 .31188 Mdot
.625 .51298 Mdot
.60935 .39567 Mdot
.42531 .35854 Mdot
.41273 .71997 Mdot
.44483 .70319 Mdot
.41401 .37306 Mdot
.59059 .58293 Mdot
.26729 .48241 Mdot
.59692 .5985 Mdot
.60472 .52712 Mdot
.19355 .45025 Mdot
.40949 .74606 Mdot
.35776 .54231 Mdot
.39284 .71016 Mdot
.58426 .33176 Mdot
.92236 .52126 Mdot
.42401 .70481 Mdot
.6959 .60711 Mdot
.52385 .80034 Mdot
.55614 .75283 Mdot
.61642 .35763 Mdot
.43842 .70588 Mdot
.38202 .35567 Mdot
.71257 .77455 Mdot
.21008 .66908 Mdot
.37113 .31983 Mdot
.5752 .57038 Mdot
.61715 .37067 Mdot
.59384 .38987 Mdot
.36839 .37287 Mdot
.59254 .38056 Mdot
.57807 .48308 Mdot
.59217 .52493 Mdot
.38357 .32165 Mdot
.50659 .26455 Mdot
.42595 .36565 Mdot
.4302 .24742 Mdot
.56474 .51953 Mdot
.61321 .3433 Mdot
.61047 .5014 Mdot
.54047 .37406 Mdot
.35598 .4632 Mdot
.64429 .55783 Mdot
.41734 .72803 Mdot
.48987 .42041 Mdot
.35054 .56776 Mdot
.31442 .32691 Mdot
.57309 .3775 Mdot
.38765 .40942 Mdot
.58562 .38191 Mdot
.62265 .35747 Mdot
.38187 .37197 Mdot
.56365 .34434 Mdot
.62224 .55951 Mdot
.23843 .52848 Mdot
.56529 .36289 Mdot
.39638 .3546 Mdot
.40841 .72551 Mdot
.58824 .34717 Mdot
.37926 .61882 Mdot
.58177 .54159 Mdot
.37067 .60196 Mdot
.32164 .52958 Mdot
.61916 .34264 Mdot
.43802 .71048 Mdot
.36535 .53767 Mdot
.3862 .70657 Mdot
.62908 .77557 Mdot
.41729 .32239 Mdot
.18742 .54742 Mdot
.6287 .47708 Mdot
.57724 .39258 Mdot
.32274 .53005 Mdot
.61803 .57298 Mdot
.58038 .54141 Mdot
.43444 .68992 Mdot
.5929 .3904 Mdot
.76606 .68404 Mdot
.53355 .33189 Mdot
.45316 .25405 Mdot
.42864 .33181 Mdot
.44836 .18655 Mdot
.42939 .27584 Mdot
.50752 .82992 Mdot
.53068 .58351 Mdot
.34682 .46603 Mdot
.59788 .58879 Mdot
.62084 .23509 Mdot
.43091 .70548 Mdot
.26832 .70341 Mdot
.5647 .50038 Mdot
.35282 .54385 Mdot
.58698 .55551 Mdot
.50115 .62102 Mdot
.63039 .51283 Mdot
.41623 .73677 Mdot
.4681 .34652 Mdot
.55459 .36107 Mdot
.39932 .71737 Mdot
.33666 .54006 Mdot
.63106 .72224 Mdot
.64345 .56678 Mdot
.60257 .61504 Mdot
.36425 .52671 Mdot
.58098 .37473 Mdot
.3529 .59741 Mdot
.42032 .34784 Mdot
.41921 .7142 Mdot
.57496 .54352 Mdot
.53712 .55965 Mdot
.2776 .4569 Mdot
.40694 .38162 Mdot
.36641 .53399 Mdot
.38846 .3365 Mdot
.34748 .46578 Mdot
.65397 .55218 Mdot
.3821 .55611 Mdot
.6364 .56408 Mdot
.55432 .19271 Mdot
.19356 .4602 Mdot
.72613 .54203 Mdot
.35284 .53908 Mdot
.56792 .73632 Mdot
.39876 .34427 Mdot
.39763 .3325 Mdot
.64874 .475 Mdot
.63197 .67851 Mdot
.32612 .65419 Mdot
.71282 .29823 Mdot
.42073 .34721 Mdot
.40521 .35064 Mdot
.35643 .59548 Mdot
.56474 .34581 Mdot
.60905 .39233 Mdot
.33061 .53747 Mdot
.46917 .68751 Mdot
.59125 .36687 Mdot
.80968 .56849 Mdot
.39796 .61716 Mdot
.53531 .59645 Mdot
.33189 .43452 Mdot
.41807 .7211 Mdot
.46794 .67379 Mdot
.49991 .61551 Mdot
.6258 .57286 Mdot
.32492 .25844 Mdot
.37046 .56646 Mdot
.50554 .77453 Mdot
.82747 .45284 Mdot
.6189 .59571 Mdot
.5847 .56975 Mdot
.58705 .58683 Mdot
.41954 .7443 Mdot
.64667 .28342 Mdot
.62876 .57064 Mdot
.46743 .6938 Mdot
.5727 .60468 Mdot
.50635 .66147 Mdot
.39363 .70665 Mdot
.62471 .41028 Mdot
.33459 .58565 Mdot
.22986 .3827 Mdot
.54494 .4739 Mdot
.41306 .3406 Mdot
.33225 .5187 Mdot
.42306 .35793 Mdot
.74588 .6269 Mdot
.54145 .69466 Mdot
.61555 .3104 Mdot
.62468 .56732 Mdot
.34851 .50396 Mdot
.6001 .38534 Mdot
.28359 .43572 Mdot
.84701 .67679 Mdot
.41344 .38246 Mdot
.20989 .71017 Mdot
.39375 .33276 Mdot
.35707 .46956 Mdot
.58188 .34578 Mdot
.77604 .49632 Mdot
.50181 .43135 Mdot
.59061 .34687 Mdot
.49648 .3259 Mdot
.54542 .35531 Mdot
.56895 .74242 Mdot
.55872 .3927 Mdot
.39605 .35027 Mdot
.42545 .31261 Mdot
.55046 .61106 Mdot
.6123 .56908 Mdot
.47421 .54497 Mdot
.68896 .55711 Mdot
.61547 .56991 Mdot
.34147 .54986 Mdot
.19746 .59594 Mdot
.3319 .52395 Mdot
.56204 .37449 Mdot
.41764 .38335 Mdot
.58513 .56671 Mdot
.5878 .52353 Mdot
.63689 .55221 Mdot
.45828 .15975 Mdot
.8012 .58247 Mdot
.61394 .53669 Mdot
.54936 .58054 Mdot
.34658 .53537 Mdot
.37203 .72408 Mdot
.65998 .24285 Mdot
.60163 .70036 Mdot
.58356 .60337 Mdot
.39616 .70628 Mdot
.39415 .74104 Mdot
.64553 .56703 Mdot
.22604 .43779 Mdot
.23526 .53245 Mdot
.60059 .56758 Mdot
.53735 .67719 Mdot
.30649 .45971 Mdot
.36102 .4965 Mdot
.37405 .57388 Mdot
.56041 .33271 Mdot
.35223 .49347 Mdot
.38763 .55655 Mdot
.77673 .47206 Mdot
.34332 .44773 Mdot
.39887 .28359 Mdot
.43335 .71037 Mdot
.5794 .59368 Mdot
.55126 .3357 Mdot
.32973 .46419 Mdot
.41752 .37095 Mdot
.60584 .35172 Mdot
.38779 .3888 Mdot
.38392 .73978 Mdot
.48065 .7613 Mdot
.35841 .4782 Mdot
.41686 .34012 Mdot
.44562 .26214 Mdot
.39541 .70623 Mdot
.37829 .34865 Mdot
.25975 .448 Mdot
.61782 .51907 Mdot
.79704 .51005 Mdot
.5538 .55985 Mdot
.70959 .76212 Mdot
.37891 .35226 Mdot
.33808 .45377 Mdot
.59417 .57904 Mdot
.36251 .57968 Mdot
.64855 .51274 Mdot
.5852 .60245 Mdot
.37459 .58411 Mdot
.60718 .53071 Mdot
.39783 .69036 Mdot
.59543 .41032 Mdot
.46314 .39436 Mdot
.22256 .30268 Mdot
.3891 .6974 Mdot
.27985 .43762 Mdot
.62224 .57039 Mdot
.64198 .7538 Mdot
.58822 .34887 Mdot
.61922 .59919 Mdot
.62346 .43476 Mdot
.56836 .34594 Mdot
.6041 .34223 Mdot
.56664 .53737 Mdot
.38573 .33134 Mdot
.35874 .57968 Mdot
.39407 .71093 Mdot
.55557 .83715 Mdot
.57007 .5753 Mdot
.59066 .54032 Mdot
.39996 .71524 Mdot
.40574 .34858 Mdot
.58419 .52457 Mdot
.33395 .37716 Mdot
.62574 .82625 Mdot
.39724 .38649 Mdot
.60028 .50693 Mdot
.78442 .40387 Mdot
.53933 .35368 Mdot
.2015 .6822 Mdot
.41153 .65758 Mdot
.36402 .54053 Mdot
.67262 .5548 Mdot
.85161 .35881 Mdot
.41308 .72158 Mdot
.22503 .37922 Mdot
.61012 .52825 Mdot
.59578 .54779 Mdot
.60303 .37572 Mdot
.57313 .52145 Mdot
.59476 .32341 Mdot
.18622 .36132 Mdot
.35858 .21234 Mdot
.57323 .37181 Mdot
.56641 .38801 Mdot
.65089 .48557 Mdot
.65133 .24118 Mdot
.58623 .3365 Mdot
.58744 .50236 Mdot
.76704 .65472 Mdot
.52683 .59025 Mdot
.43572 .69078 Mdot
.31721 .53825 Mdot
.63968 .3797 Mdot
.42412 .58369 Mdot
.54288 .30533 Mdot
.53495 .48359 Mdot
.38305 .44882 Mdot
.40424 .32805 Mdot
.60073 .60683 Mdot
.35855 .48694 Mdot
.39366 .59091 Mdot
.6377 .51628 Mdot
.58633 .59881 Mdot
.5684 .35593 Mdot
.42027 .74135 Mdot
.37762 .37302 Mdot
.59661 .53568 Mdot
.37519 .62085 Mdot
.41447 .70038 Mdot
.5637 .37342 Mdot
.66961 .50282 Mdot
.39814 .73884 Mdot
.6644 .57243 Mdot
.60783 .5559 Mdot
.5828 .51265 Mdot
.62138 .47674 Mdot
.42637 .33711 Mdot
.31657 .44848 Mdot
.57732 .5047 Mdot
.25683 .33147 Mdot
.45472 .6276 Mdot
.53208 .54828 Mdot
.59291 .37297 Mdot
.42 .31687 Mdot
.35404 .4606 Mdot
.62649 .73777 Mdot
.56915 .56676 Mdot
.79763 .58677 Mdot
.72514 .41346 Mdot
.34941 .48881 Mdot
.62301 .32558 Mdot
.40541 .73111 Mdot
.56338 .58366 Mdot
.75537 .64514 Mdot
.61283 .58346 Mdot
.6518 .49712 Mdot
.37363 .559 Mdot
.40587 .32727 Mdot
.66166 .80438 Mdot
.39347 .58886 Mdot
.60498 .34007 Mdot
.82496 .58895 Mdot
.60305 .39185 Mdot
.55683 .35262 Mdot
.77339 .59851 Mdot
.42599 .33917 Mdot
.83838 .33778 Mdot
.20575 .6698 Mdot
.5491 .51944 Mdot
.4 .34029 Mdot
.57516 .35182 Mdot
.62753 .55048 Mdot
.57163 .39678 Mdot
.57318 .33135 Mdot
.6414 .54928 Mdot
.60298 .55112 Mdot
.52472 .4696 Mdot
.82731 .50947 Mdot
.39907 .72822 Mdot
.61161 .32857 Mdot
.67622 .39617 Mdot
.63171 .56486 Mdot
.60181 .58038 Mdot
.2949 .43564 Mdot
.41289 .73704 Mdot
.49258 .56891 Mdot
.60184 .52387 Mdot
.35832 .22687 Mdot
.65721 .55444 Mdot
.58462 .31164 Mdot
.39586 .38582 Mdot
.22513 .42573 Mdot
.32399 .45237 Mdot
.60501 .31993 Mdot
.41883 .68894 Mdot
.5935 .30525 Mdot
.69673 .5959 Mdot
.42702 .34818 Mdot
.61165 .35905 Mdot
.33731 .57561 Mdot
.40513 .36892 Mdot
.37879 .34839 Mdot
.74552 .67062 Mdot
.35551 .52723 Mdot
.43318 .70099 Mdot
.41684 .36229 Mdot
.69697 .35007 Mdot
.39223 .35398 Mdot
.68646 .40809 Mdot
.55084 .56278 Mdot
.4706 .73418 Mdot
.44631 .29116 Mdot
.66663 .52602 Mdot
.42506 .33212 Mdot
.3908 .71419 Mdot
.57103 .53645 Mdot
.59464 .38019 Mdot
.42398 .70724 Mdot
.4552 .36665 Mdot
.38024 .56056 Mdot
.58081 .38413 Mdot
.42703 .37862 Mdot
.61141 .33068 Mdot
.56436 .77473 Mdot
.43714 .78501 Mdot
.33368 .35463 Mdot
.50471 .44374 Mdot
.63364 .54766 Mdot
.61076 .2665 Mdot
.65242 .57215 Mdot
.59021 .6008 Mdot
.35131 .5714 Mdot
.4943 .74355 Mdot
.58078 .35199 Mdot
.66327 .80615 Mdot
.41444 .33535 Mdot
.32852 .24583 Mdot
.56484 .42636 Mdot
.60487 .60956 Mdot
.56586 .35782 Mdot
.5906 .39836 Mdot
.71803 .54213 Mdot
.39795 .59997 Mdot
.61732 .62974 Mdot
.6555 .57852 Mdot
.54062 .59508 Mdot
.37937 .35137 Mdot
.3046 .34184 Mdot
.34163 .57906 Mdot
.33039 .79385 Mdot
.37704 .56373 Mdot
.28014 .56345 Mdot
.56123 .34873 Mdot
.42911 .71623 Mdot
.6019 .57811 Mdot
.55391 .41993 Mdot
.617 .3223 Mdot
.38969 .67839 Mdot
.41703 .73005 Mdot
.27716 .35484 Mdot
.40733 .32294 Mdot
.64135 .5762 Mdot
.62315 .58757 Mdot
.5649 .52625 Mdot
.55314 .54798 Mdot
.41139 .38418 Mdot
.60328 .51595 Mdot
.37465 .32686 Mdot
.70341 .36352 Mdot
.34399 .22974 Mdot
.34268 .49434 Mdot
.59759 .67149 Mdot
.57508 .38873 Mdot
.68622 .3338 Mdot
.65414 .61881 Mdot
.18784 .47846 Mdot
.67865 .74469 Mdot
.62774 .60989 Mdot
.34721 .5839 Mdot
.64114 .66924 Mdot
.35979 .51523 Mdot
.10972 .55732 Mdot
.28368 .47571 Mdot
.81855 .57492 Mdot
.62834 .55797 Mdot
.29641 .43559 Mdot
.66503 .61216 Mdot
.64568 .55344 Mdot
.29727 .48065 Mdot
.45276 .20749 Mdot
.49386 .29236 Mdot
.39532 .7403 Mdot
.57921 .54904 Mdot
.56141 .39687 Mdot
.6237 .55982 Mdot
.6024 .58494 Mdot
.61519 .5302 Mdot
.41569 .38804 Mdot
.63899 .52806 Mdot
.58494 .50865 Mdot
.41639 .53373 Mdot
.53459 .72685 Mdot
.38845 .60427 Mdot
.70283 .56861 Mdot
.42098 .70293 Mdot
.56754 .36834 Mdot
.51955 .40507 Mdot
.38866 .3263 Mdot
.70018 .51228 Mdot
.57391 .51054 Mdot
.44839 .28452 Mdot
.42799 .37767 Mdot
.42129 .71499 Mdot
.34884 .45292 Mdot
.7917 .64351 Mdot
.35023 .50223 Mdot
.34419 .44737 Mdot
.35044 .56569 Mdot
.6597 .33916 Mdot
.56913 .353 Mdot
.63367 .54587 Mdot
.41451 .35843 Mdot
.36174 .58506 Mdot
.50389 .72571 Mdot
.57944 .58798 Mdot
.34561 .53811 Mdot
.62909 .54103 Mdot
.4691 .75691 Mdot
.23566 .60046 Mdot
.37735 .53818 Mdot
.44322 .34459 Mdot
.40239 .36451 Mdot
.42492 .72854 Mdot
.56817 .37576 Mdot
.60373 .37134 Mdot
.40535 .3739 Mdot
.17603 .61755 Mdot
.58838 .60409 Mdot
.62933 .55519 Mdot
.26061 .32675 Mdot
.61664 .56093 Mdot
.61499 .72932 Mdot
.34779 .44188 Mdot
.56845 .38186 Mdot
.62387 .544 Mdot
.5818 .52797 Mdot
.57272 .55373 Mdot
.55781 .77732 Mdot
.37714 .56968 Mdot
.57463 .60197 Mdot
.40041 .73548 Mdot
.36168 .44581 Mdot
.63116 .55702 Mdot
.54716 .60059 Mdot
.60483 .36784 Mdot
.33964 .22121 Mdot
.39551 .3279 Mdot
.33976 .55443 Mdot
.37025 .54264 Mdot
.31646 .53142 Mdot
.60033 .42326 Mdot
.34665 .44387 Mdot
.39449 .79926 Mdot
.33903 .45971 Mdot
.4006 .70808 Mdot
.33106 .61459 Mdot
.41728 .6198 Mdot
.34695 .5773 Mdot
.37998 .38685 Mdot
.5617 .51707 Mdot
.56841 .59674 Mdot
.21582 .38924 Mdot
.59459 .61241 Mdot
.41127 .72869 Mdot
.37099 .33533 Mdot
.59888 .36806 Mdot
.42171 .71864 Mdot
.39328 .33519 Mdot
.58306 .37557 Mdot
.62483 .52511 Mdot
.61334 .51411 Mdot
.60408 .3488 Mdot
.60011 .38446 Mdot
.60398 .56529 Mdot
.37335 .45646 Mdot
.55599 .3434 Mdot
.61391 .35006 Mdot
.35966 .48098 Mdot
.34831 .50083 Mdot
.52815 .5237 Mdot
.39636 .33938 Mdot
.58879 .51373 Mdot
.35213 .50604 Mdot
.42686 .73291 Mdot
.58431 .35422 Mdot
.58481 .5272 Mdot
.59605 .5313 Mdot
.39511 .71128 Mdot
.40929 .74331 Mdot
.42374 .71909 Mdot
.37489 .32185 Mdot
.55723 .54559 Mdot
.5897 .33606 Mdot
.41441 .32707 Mdot
.39366 .74062 Mdot
.39155 .68688 Mdot
.44465 .54429 Mdot
.621 .57592 Mdot
.43531 .44163 Mdot
.91672 .51107 Mdot
.62122 .71401 Mdot
.35468 .46079 Mdot
.35947 .52376 Mdot
.52498 .75192 Mdot
.24236 .56076 Mdot
.39013 .37044 Mdot
.64828 .69291 Mdot
.42379 .67903 Mdot
.63159 .54078 Mdot
.65652 .55935 Mdot
.62398 .61763 Mdot
.41618 .70705 Mdot
.58517 .7652 Mdot
.59925 .39028 Mdot
.65821 .44543 Mdot
.42097 .70348 Mdot
.37858 .53999 Mdot
.38108 .55179 Mdot
.3769 .56305 Mdot
.64407 .53743 Mdot
.7163 .52593 Mdot
.68519 .3593 Mdot
.65703 .26496 Mdot
.39436 .32017 Mdot
.62423 .31327 Mdot
.62983 .77082 Mdot
.60272 .34405 Mdot
.39362 .58521 Mdot
.41336 .70393 Mdot
.61124 .36497 Mdot
.41684 .37629 Mdot
.40672 .35229 Mdot
.37954 .57083 Mdot
.36275 .57518 Mdot
.37157 .60055 Mdot
.56477 .33229 Mdot
.56285 .34564 Mdot
.56669 .57119 Mdot
.59266 .35488 Mdot
.27732 .28195 Mdot
.40946 .74905 Mdot
.38455 .55713 Mdot
.38745 .35162 Mdot
.57013 .35628 Mdot
.57521 .58709 Mdot
.32671 .63093 Mdot
.54661 .22772 Mdot
.38814 .70298 Mdot
.22936 .5855 Mdot
.12487 .58632 Mdot
.63615 .57704 Mdot
.38486 .36948 Mdot
.21393 .4631 Mdot
.58394 .58563 Mdot
.36417 .55892 Mdot
.58094 .20212 Mdot
.34741 .49039 Mdot
.59646 .51254 Mdot
.59872 .61216 Mdot
.37677 .35349 Mdot
.52556 .80302 Mdot
.56498 .57387 Mdot
.39592 .25786 Mdot
.40634 .39068 Mdot
.37431 .61065 Mdot
.62846 .82922 Mdot
.30982 .44594 Mdot
.47056 .67697 Mdot
.35599 .48042 Mdot
.6093 .59357 Mdot
.34281 .55806 Mdot
.38763 .70868 Mdot
.35464 .58325 Mdot
.61893 .31605 Mdot
.38272 .60449 Mdot
.59074 .54171 Mdot
.58802 .33435 Mdot
.39041 .36803 Mdot
.31282 .26762 Mdot
.40958 .53601 Mdot
.36303 .57954 Mdot
.35977 .47006 Mdot
.62708 .54418 Mdot
.49878 .52328 Mdot
.61829 .4862 Mdot
.63013 .5615 Mdot
.42481 .35334 Mdot
.56448 .36149 Mdot
.43403 .34532 Mdot
.544 .58783 Mdot
.43038 .20757 Mdot
.38797 .33417 Mdot
.46672 .31529 Mdot
.40004 .7125 Mdot
.47017 .58102 Mdot
.57382 .59016 Mdot
.4178 .35893 Mdot
.55728 .54334 Mdot
.56519 .39452 Mdot
.46069 .46284 Mdot
.32682 .41678 Mdot
.41319 .35861 Mdot
.7504 .70614 Mdot
.43692 .47191 Mdot
.60409 .50074 Mdot
.42107 .35166 Mdot
.63321 .42395 Mdot
.35415 .47906 Mdot
.40567 .70027 Mdot
.39458 .74103 Mdot
.38518 .7108 Mdot
.61898 .6093 Mdot
.601 .63639 Mdot
.42159 .68752 Mdot
.3907 .38634 Mdot
.41729 .73694 Mdot
.55005 .42759 Mdot
.75911 .6965 Mdot
.4265 .69796 Mdot
.57717 .56378 Mdot
.56531 .61935 Mdot
.53001 .72625 Mdot
.39447 .58347 Mdot
.81963 .54547 Mdot
.62385 .65828 Mdot
.61243 .57223 Mdot
.54211 .61831 Mdot
.60297 .38609 Mdot
.21651 .48592 Mdot
.68739 .55525 Mdot
.23754 .56492 Mdot
.55827 .37774 Mdot
.33558 .4743 Mdot
.56747 .37817 Mdot
.63836 .57142 Mdot
.61836 .54302 Mdot
.6017 .39909 Mdot
.31854 .30019 Mdot
.2583 .41107 Mdot
.63175 .80478 Mdot
.61521 .35059 Mdot
.41691 .34876 Mdot
.41447 .38239 Mdot
.39446 .32105 Mdot
.39897 .61534 Mdot
.61678 .33233 Mdot
.55929 .55488 Mdot
.34702 .5338 Mdot
.59709 .60538 Mdot
.41196 .3667 Mdot
.67042 .7999 Mdot
.60278 .3685 Mdot
.5984 .56676 Mdot
.20843 .66241 Mdot
.35996 .56675 Mdot
.39895 .70037 Mdot
.47693 .7673 Mdot
.39653 .61931 Mdot
.43066 .34935 Mdot
.60236 .39559 Mdot
.46705 .37058 Mdot
.49925 .38396 Mdot
.52221 .55951 Mdot
.5387 .52339 Mdot
.5188 .83859 Mdot
.37483 .50581 Mdot
.64887 .57405 Mdot
.336 .54174 Mdot
.33631 .48035 Mdot
.58369 .53117 Mdot
.61605 .36299 Mdot
.38037 .70992 Mdot
.40196 .73702 Mdot
.65271 .60396 Mdot
.50041 .43485 Mdot
.46791 .58776 Mdot
.58207 .5202 Mdot
.66554 .59166 Mdot
.36989 .53992 Mdot
.33949 .45419 Mdot
.29696 .29054 Mdot
.42456 .69298 Mdot
.60651 .52466 Mdot
.51987 .29437 Mdot
.57257 .33357 Mdot
.37711 .60392 Mdot
.42893 .35152 Mdot
.57726 .77905 Mdot
.36168 .60736 Mdot
.58529 .52933 Mdot
.58381 .52515 Mdot
.37811 .34823 Mdot
.58539 .31136 Mdot
.41397 .70644 Mdot
.35565 .53588 Mdot
.42407 .69178 Mdot
.58057 .33223 Mdot
.60162 .36575 Mdot
.52722 .59148 Mdot
.66418 .59228 Mdot
.37379 .57664 Mdot
.55298 .5977 Mdot
.38941 .56339 Mdot
.51546 .80828 Mdot
.43674 .3444 Mdot
.63381 .58042 Mdot
.63149 .35036 Mdot
.41557 .36644 Mdot
.59773 .55281 Mdot
.50639 .84981 Mdot
.61105 .60464 Mdot
.32856 .45537 Mdot
.40705 .21676 Mdot
.39617 .72947 Mdot
.71299 .60106 Mdot
.5092 .58583 Mdot
.61557 .55716 Mdot
.38668 .57028 Mdot
.64321 .50656 Mdot
.38173 .34109 Mdot
.55945 .36472 Mdot
.17928 .65797 Mdot
.39416 .35675 Mdot
.62463 .55503 Mdot
.42 .71433 Mdot
.59767 .39585 Mdot
.34444 .48338 Mdot
.24416 .35198 Mdot
.64068 .51248 Mdot
.58563 .4999 Mdot
.59487 .51353 Mdot
.65766 .23238 Mdot
.34236 .56139 Mdot
.57274 .35342 Mdot
.37973 .35282 Mdot
.40355 .37634 Mdot
.37511 .56473 Mdot
.48225 .28303 Mdot
.46456 .5683 Mdot
.88245 .41356 Mdot
.37264 .58783 Mdot
.43877 .7144 Mdot
.51914 .44759 Mdot
.39074 .5848 Mdot
.34601 .54239 Mdot
.36481 .53592 Mdot
.41442 .2851 Mdot
.5856 .3732 Mdot
.59836 .53073 Mdot
.55109 .36386 Mdot
.61004 .5944 Mdot
.47319 .6305 Mdot
.41563 .36974 Mdot
.55862 .36427 Mdot
.51915 .84443 Mdot
.53426 .35229 Mdot
.58193 .57783 Mdot
.6056 .79079 Mdot
.60309 .48516 Mdot
.57845 .75241 Mdot
.58742 .48906 Mdot
.35598 .57203 Mdot
.67076 .62111 Mdot
.54258 .59303 Mdot
.29833 .27056 Mdot
.38753 .34915 Mdot
.35734 .46611 Mdot
.63771 .59537 Mdot
.66075 .56207 Mdot
.57383 .40527 Mdot
.61255 .36232 Mdot
.4269 .69205 Mdot
.45274 .65134 Mdot
.38745 .36309 Mdot
.44423 .77929 Mdot
.61051 .5657 Mdot
.33933 .29279 Mdot
.69432 .53198 Mdot
.59723 .55444 Mdot
.77166 .64494 Mdot
.70921 .5202 Mdot
.56745 .58731 Mdot
.64199 .40915 Mdot
.403 .3483 Mdot
.40482 .22191 Mdot
.54623 .55504 Mdot
.36247 .55736 Mdot
.56188 .35153 Mdot
.61011 .38173 Mdot
.40624 .68601 Mdot
.17709 .44488 Mdot
.42516 .33075 Mdot
.55893 .35664 Mdot
.5858 .59148 Mdot
.42912 .34423 Mdot
.35851 .49263 Mdot
.53855 .5738 Mdot
.66148 .68666 Mdot
.59401 .35771 Mdot
.54911 .58131 Mdot
.49322 .21608 Mdot
.46185 .66258 Mdot
.8332 .40944 Mdot
.39293 .32224 Mdot
.42872 .70892 Mdot
.57016 .49144 Mdot
.38911 .79248 Mdot
.61136 .61833 Mdot
.47462 .73526 Mdot
.59012 .42895 Mdot
.43058 .71574 Mdot
.58804 .57602 Mdot
.56911 .55372 Mdot
.50747 .42752 Mdot
.41457 .74338 Mdot
.61567 .59774 Mdot
.64879 .64314 Mdot
.58047 .37348 Mdot
.35273 .44892 Mdot
.59379 .36288 Mdot
.57561 .57003 Mdot
.58724 .63498 Mdot
.60305 .37768 Mdot
.41774 .7995 Mdot
.44137 .69103 Mdot
.39584 .32677 Mdot
.64831 .61687 Mdot
.55146 .54684 Mdot
.65757 .20945 Mdot
.35606 .46352 Mdot
.63464 .25068 Mdot
.36671 .61433 Mdot
.51376 .31179 Mdot
.30761 .43645 Mdot
.81855 .60298 Mdot
.32007 .26857 Mdot
.65463 .57274 Mdot
.54975 .67183 Mdot
.66094 .37795 Mdot
.4325 .34453 Mdot
.7359 .37002 Mdot
.61264 .56952 Mdot
.60111 .58711 Mdot
.3641 .60356 Mdot
.46284 .2798 Mdot
.22503 .44541 Mdot
.49103 .4429 Mdot
.41031 .70857 Mdot
.59344 .32707 Mdot
.6031 .54081 Mdot
.44987 .60638 Mdot
.3857 .60127 Mdot
.33266 .30886 Mdot
.59464 .57058 Mdot
.18966 .4918 Mdot
.43128 .2949 Mdot
.4217 .33068 Mdot
.3818 .55692 Mdot
.39521 .62232 Mdot
.61844 .58627 Mdot
.42628 .36308 Mdot
.56595 .57747 Mdot
.43012 .48484 Mdot
.56305 .60496 Mdot
.42468 .69807 Mdot
.62605 .53948 Mdot
.4818 .41518 Mdot
.84541 .46978 Mdot
.68551 .62648 Mdot
.61946 .36242 Mdot
.39466 .61688 Mdot
.37596 .56968 Mdot
.60957 .36547 Mdot
.37372 .57071 Mdot
.67491 .46636 Mdot
.75996 .516 Mdot
.40651 .71066 Mdot
.66156 .60599 Mdot
.41579 .69025 Mdot
.35651 .46138 Mdot
.61698 .57581 Mdot
.39422 .80186 Mdot
.37002 .58508 Mdot
.49813 .17712 Mdot
.39092 .35717 Mdot
.35675 .46434 Mdot
.5707 .60329 Mdot
.32456 .60577 Mdot
.39338 .59769 Mdot
.3332 .4698 Mdot
.57144 .55704 Mdot
.59925 .37444 Mdot
.57134 .54699 Mdot
.60193 .48752 Mdot
.34777 .44983 Mdot
.5641 .51524 Mdot
.39332 .33527 Mdot
.57049 .3215 Mdot
.78477 .65688 Mdot
.32687 .45703 Mdot
.62604 .57724 Mdot
.58557 .58992 Mdot
.57938 .40185 Mdot
.55447 .58589 Mdot
.41937 .37575 Mdot
.66658 .15157 Mdot
.39963 .71184 Mdot
.3624 .5119 Mdot
.31163 .4481 Mdot
.62429 .61244 Mdot
.57913 .52495 Mdot
.55376 .83977 Mdot
.32296 .40276 Mdot
.40871 .33823 Mdot
.66269 .53822 Mdot
.3488 .53575 Mdot
.41967 .71621 Mdot
.38126 .37895 Mdot
.58204 .51326 Mdot
.59858 .57977 Mdot
.42581 .7037 Mdot
.74891 .6752 Mdot
.23552 .56861 Mdot
.38834 .32126 Mdot
.67303 .61613 Mdot
.32116 .63856 Mdot
.58697 .60344 Mdot
.36298 .66195 Mdot
.61254 .35477 Mdot
.42281 .34276 Mdot
.65815 .25758 Mdot
.62583 .53618 Mdot
.41009 .38116 Mdot
.38651 .3591 Mdot
.54236 .52976 Mdot
.56659 .40703 Mdot
.57433 .32393 Mdot
.60784 .32702 Mdot
.3035 .24244 Mdot
.49067 .67659 Mdot
.37212 .60042 Mdot
.40438 .34853 Mdot
.36774 .52531 Mdot
.42086 .74548 Mdot
.45635 .61619 Mdot
.37284 .52946 Mdot
.59859 .38717 Mdot
.37836 .54579 Mdot
.57164 .5507 Mdot
.39129 .37016 Mdot
.34961 .58237 Mdot
.63407 .59766 Mdot
.49736 .57108 Mdot
.41691 .46396 Mdot
.38308 .69876 Mdot
.41173 .66851 Mdot
.61316 .54157 Mdot
.35379 .46071 Mdot
.60393 .56775 Mdot
.37837 .32542 Mdot
.50261 .40275 Mdot
.62355 .61065 Mdot
.36769 .57907 Mdot
.58083 .64776 Mdot
.39922 .60421 Mdot
.64613 .51249 Mdot
.57789 .56523 Mdot
.59829 .6021 Mdot
.56493 .57677 Mdot
.48427 .3096 Mdot
.42723 .32955 Mdot
.50063 .59569 Mdot
.32335 .54127 Mdot
.5962 .34845 Mdot
.6282 .32985 Mdot
.31544 .65848 Mdot
.37305 .52548 Mdot
.3976 .34021 Mdot
.57809 .59802 Mdot
.32068 .44731 Mdot
.6797 .79396 Mdot
.41998 .8027 Mdot
.3949 .67161 Mdot
.33607 .55349 Mdot
.62031 .36462 Mdot
.39111 .60272 Mdot
.61209 .58938 Mdot
.55053 .51473 Mdot
.81093 .62427 Mdot
.44242 .33453 Mdot
.41446 .70453 Mdot
.60169 .60055 Mdot
.47031 .66891 Mdot
.34676 .53535 Mdot
.36437 .53373 Mdot
.60833 .60452 Mdot
.59668 .31632 Mdot
.77725 .30305 Mdot
.42395 .33258 Mdot
.60751 .66518 Mdot
.62428 .29195 Mdot
.42443 .22589 Mdot
.41085 .37523 Mdot
.39864 .46489 Mdot
.3333 .53845 Mdot
.72265 .60533 Mdot
.59946 .35039 Mdot
.417 .70287 Mdot
.53847 .52881 Mdot
.59177 .38722 Mdot
.33103 .53598 Mdot
.56896 .38595 Mdot
.64092 .55655 Mdot
.43224 .33953 Mdot
.36801 .54379 Mdot
.43432 .32847 Mdot
.60999 .39377 Mdot
.39658 .69522 Mdot
.49361 .51333 Mdot
.76423 .40169 Mdot
.70634 .51725 Mdot
.57303 .60048 Mdot
.44275 .60885 Mdot
.55866 .54419 Mdot
.56736 .40396 Mdot
.57195 .58405 Mdot
.64201 .30461 Mdot
.38181 .55954 Mdot
.54829 .57787 Mdot
.59979 .51408 Mdot
.73252 .39171 Mdot
.58807 .56554 Mdot
.55607 .51883 Mdot
.56758 .58918 Mdot
.64004 .33365 Mdot
.63905 .52382 Mdot
.59085 .37466 Mdot
.24097 .36199 Mdot
.34582 .54405 Mdot
.38086 .70228 Mdot
.39388 .73439 Mdot
.47082 .7252 Mdot
.464 .6423 Mdot
.47541 .28607 Mdot
.58673 .36412 Mdot
.3865 .34143 Mdot
.56651 .58052 Mdot
.6924 .28506 Mdot
.31157 .49974 Mdot
.34818 .53075 Mdot
.32801 .45687 Mdot
.64319 .49624 Mdot
.65922 .23167 Mdot
.56187 .59941 Mdot
.21293 .38201 Mdot
.62612 .62011 Mdot
.61904 .59873 Mdot
.39016 .62049 Mdot
.46055 .64078 Mdot
.57763 .60449 Mdot
.57402 .40486 Mdot
.41433 .69752 Mdot
.54764 .31258 Mdot
.25744 .52172 Mdot
.38535 .46189 Mdot
.7664 .4465 Mdot
.55637 .55618 Mdot
.36465 .54253 Mdot
.58032 .38373 Mdot
.30527 .28402 Mdot
.41513 .32797 Mdot
.43474 .28542 Mdot
.69581 .37674 Mdot
.56089 .81655 Mdot
.41491 .70071 Mdot
.74587 .67375 Mdot
.59178 .54053 Mdot
.40078 .61532 Mdot
.6379 .54464 Mdot
.6839 .79018 Mdot
.43872 .70882 Mdot
.61008 .31639 Mdot
.41586 .34734 Mdot
.56279 .39192 Mdot
.72642 .54663 Mdot
.35777 .40453 Mdot
.46991 .50089 Mdot
.35159 .50329 Mdot
.49072 .57223 Mdot
.58066 .33996 Mdot
.59376 .5201 Mdot
.89976 .45232 Mdot
.61322 .35098 Mdot
.60322 .32093 Mdot
.48949 .8086 Mdot
.48958 .81364 Mdot
.66753 .53754 Mdot
.57208 .39156 Mdot
.3483 .50925 Mdot
.39352 .71959 Mdot
.56664 .54985 Mdot
.56505 .56776 Mdot
.6028 .37522 Mdot
.39344 .58248 Mdot
.62269 .66791 Mdot
.35922 .57366 Mdot
.57912 .37516 Mdot
.35348 .55883 Mdot
.32876 .47809 Mdot
.3394 .55879 Mdot
.55008 .5585 Mdot
.57046 .58331 Mdot
.26019 .56969 Mdot
.60148 .36565 Mdot
.57409 .52606 Mdot
.6115 .53262 Mdot
.58652 .33776 Mdot
.36514 .61478 Mdot
.71054 .30984 Mdot
.62317 .56816 Mdot
.5819 .54509 Mdot
.43021 .71201 Mdot
.41705 .60901 Mdot
.23023 .61846 Mdot
.5707 .53673 Mdot
.43219 .73004 Mdot
.56241 .3359 Mdot
.60243 .56447 Mdot
.54871 .42972 Mdot
.33401 .48135 Mdot
.62163 .53283 Mdot
.34985 .49195 Mdot
.60321 .6155 Mdot
.7956 .34616 Mdot
.63085 .57069 Mdot
.57747 .35016 Mdot
.56647 .34742 Mdot
.50238 .80281 Mdot
.60581 .33776 Mdot
.35687 .48231 Mdot
.4081 .36777 Mdot
.7053 .76882 Mdot
.35841 .495 Mdot
.62074 .60034 Mdot
.20576 .67022 Mdot
.54452 .57619 Mdot
.63417 .60072 Mdot
.62635 .21371 Mdot
.35775 .49606 Mdot
.56869 .35004 Mdot
.38248 .28435 Mdot
.63759 .61674 Mdot
.42965 .34879 Mdot
.53165 .56138 Mdot
.57634 .50627 Mdot
.37809 .24149 Mdot
.56929 .21751 Mdot
.3697 .34407 Mdot
.51945 .55576 Mdot
.57067 .53602 Mdot
.4254 .57021 Mdot
.5791 .59012 Mdot
.41952 .69043 Mdot
.60361 .32245 Mdot
.38524 .59269 Mdot
.3983 .71973 Mdot
.61326 .56231 Mdot
.41814 .70791 Mdot
.37197 .60167 Mdot
.42482 .34959 Mdot
.61789 .58197 Mdot
.43875 .69535 Mdot
.41178 .70852 Mdot
.56162 .5345 Mdot
.55955 .35848 Mdot
.68639 .6053 Mdot
.60111 .56149 Mdot
.59437 .52345 Mdot
.60352 .37144 Mdot
.35698 .81126 Mdot
.62836 .58296 Mdot
.43028 .44666 Mdot
.6142 .32149 Mdot
.32766 .42985 Mdot
.37006 .60356 Mdot
.57425 .50583 Mdot
.42626 .35697 Mdot
.41744 .36714 Mdot
.35258 .51958 Mdot
.5675 .39729 Mdot
.39572 .59044 Mdot
.58905 .64817 Mdot
.65405 .60958 Mdot
.5406 .55308 Mdot
.16455 .60483 Mdot
.80588 .61969 Mdot
.61591 .36611 Mdot
.33971 .57596 Mdot
.49179 .44859 Mdot
.40747 .34691 Mdot
.36117 .52199 Mdot
.59715 .39721 Mdot
.61774 .37121 Mdot
.57482 .38785 Mdot
.42605 .7214 Mdot
.34262 .58432 Mdot
.59363 .31035 Mdot
.59335 .31688 Mdot
.57188 .55365 Mdot
.57106 .53361 Mdot
.60269 .44526 Mdot
.56317 .73066 Mdot
.39975 .69099 Mdot
.37228 .56031 Mdot
.56306 .13416 Mdot
.37602 .32798 Mdot
.73521 .39705 Mdot
.62619 .60916 Mdot
.89467 .61094 Mdot
.56643 .6038 Mdot
.58467 .59301 Mdot
.56082 .33399 Mdot
.42983 .68535 Mdot
.40981 .69184 Mdot
.57923 .3397 Mdot
.61066 .39123 Mdot
.42425 .694 Mdot
.69586 .73466 Mdot
.75775 .70137 Mdot
.38141 .27477 Mdot
.58433 .34518 Mdot
.77853 .43715 Mdot
.42963 .35393 Mdot
.60752 .3979 Mdot
.37488 .33735 Mdot
.34826 .54195 Mdot
.3328 .53726 Mdot
.37883 .34526 Mdot
.5705 .5613 Mdot
.36284 .59628 Mdot
.61478 .50844 Mdot
.71839 .72302 Mdot
.78134 .56598 Mdot
.29811 .39021 Mdot
.65645 .56201 Mdot
.2274 .432 Mdot
.23468 .44886 Mdot
.61605 .55032 Mdot
.51576 .35296 Mdot
.41602 .70517 Mdot
.61681 .39443 Mdot
.42084 .37395 Mdot
.82783 .39732 Mdot
.58324 .60185 Mdot
.57847 .35395 Mdot
.38907 .34507 Mdot
.507 .7911 Mdot
.4015 .25581 Mdot
.60797 .5971 Mdot
.86207 .37837 Mdot
.62 .39599 Mdot
.38441 .59299 Mdot
.17879 .56451 Mdot
.55092 .3529 Mdot
.41475 .66159 Mdot
.32764 .54923 Mdot
.55523 .82935 Mdot
.56786 .36833 Mdot
.33064 .53401 Mdot
.5899 .32938 Mdot
.41103 .68748 Mdot
.58681 .41974 Mdot
.36222 .53738 Mdot
.58853 .57073 Mdot
.37028 .56871 Mdot
.39672 .69288 Mdot
.4002 .61131 Mdot
.42336 .36915 Mdot
.35586 .4709 Mdot
.40389 .35766 Mdot
.45999 .65893 Mdot
.466 .19332 Mdot
.40504 .32674 Mdot
.48308 .78523 Mdot
.64947 .57374 Mdot
.57613 .31441 Mdot
.37633 .58771 Mdot
.32763 .53294 Mdot
.49934 .48963 Mdot
.59588 .34352 Mdot
.37424 .55734 Mdot
.69411 .36687 Mdot
.27308 .74169 Mdot
.60522 .63628 Mdot
.50516 .67411 Mdot
.58774 .33921 Mdot
.36485 .53183 Mdot
.26171 .32551 Mdot
.59808 .38866 Mdot
.37236 .58877 Mdot
.41912 .35403 Mdot
.40642 .37663 Mdot
.59687 .60705 Mdot
.37427 .29561 Mdot
.38395 .57876 Mdot
.24597 .3836 Mdot
.57597 .33103 Mdot
.50881 .78827 Mdot
.39224 .6918 Mdot
.34288 .54179 Mdot
.53995 .58716 Mdot
.55683 .31721 Mdot
.33329 .48657 Mdot
.61912 .67989 Mdot
.556 .13906 Mdot
.37406 .56389 Mdot
.60116 .32202 Mdot
.58121 .35579 Mdot
.61263 .48513 Mdot
.50336 .43589 Mdot
.3958 .60777 Mdot
.37607 .78649 Mdot
.48117 .74126 Mdot
.34762 .46463 Mdot
.24805 .46592 Mdot
.59446 .61317 Mdot
.55641 .54036 Mdot
.40882 .34577 Mdot
.58363 .56611 Mdot
.58139 .31854 Mdot
.5704 .60069 Mdot
.4033 .38157 Mdot
.33882 .53292 Mdot
.61547 .58006 Mdot
.39198 .72057 Mdot
.36827 .36471 Mdot
.377 .34919 Mdot
.34617 .55564 Mdot
.57337 .39101 Mdot
.45083 .70575 Mdot
.3637 .57512 Mdot
.55687 .55953 Mdot
.3442 .47964 Mdot
.63655 .55172 Mdot
.70872 .69217 Mdot
.58971 .3924 Mdot
.39171 .59116 Mdot
.62398 .32808 Mdot
.39993 .3549 Mdot
.32377 .54272 Mdot
.5763 .57814 Mdot
.36953 .58867 Mdot
.24975 .54304 Mdot
.7181 .70299 Mdot
.569 .39965 Mdot
.26607 .47115 Mdot
.59745 .31948 Mdot
.34779 .4619 Mdot
.66059 .7108 Mdot
.406 .70272 Mdot
.35148 .5375 Mdot
.80346 .60684 Mdot
.37053 .58064 Mdot
.58925 .56139 Mdot
.60038 .54767 Mdot
.3589 .59863 Mdot
.41595 .73508 Mdot
.35009 .21922 Mdot
.40864 .45009 Mdot
.56666 .3587 Mdot
.70767 .62589 Mdot
.62043 .16194 Mdot
.423 .38823 Mdot
.40824 .34196 Mdot
.65262 .5976 Mdot
.6052 .609 Mdot
.37563 .36575 Mdot
.41721 .38384 Mdot
.40531 .68359 Mdot
.36023 .53274 Mdot
.58395 .42224 Mdot
.39741 .3922 Mdot
.53412 .49665 Mdot
.46642 .64413 Mdot
.66858 .5598 Mdot
.54943 .62203 Mdot
.62946 .52349 Mdot
.46707 .74737 Mdot
.38892 .37628 Mdot
.61104 .53851 Mdot
.64202 .52036 Mdot
.42055 .34413 Mdot
.41313 .68834 Mdot
.55257 .21276 Mdot
.35719 .55594 Mdot
.50805 .8712 Mdot
.63571 .55763 Mdot
.59288 .5619 Mdot
.39628 .32019 Mdot
.41589 .58435 Mdot
.59479 .38386 Mdot
.5804 .39557 Mdot
.34421 .56661 Mdot
.48282 .52867 Mdot
.5554 .58226 Mdot
.61537 .5467 Mdot
.36222 .54678 Mdot
.35544 .46944 Mdot
.27583 .38447 Mdot
.59361 .53235 Mdot
.39027 .34641 Mdot
.33115 .52169 Mdot
.39343 .3805 Mdot
.64088 .56998 Mdot
.59003 .55766 Mdot
.5498 .56349 Mdot
.60713 .60868 Mdot
.37715 .34142 Mdot
.60721 .53829 Mdot
.57931 .62638 Mdot
.56265 .37895 Mdot
.55254 .551 Mdot
.47503 .74678 Mdot
.57821 .55711 Mdot
.39289 .7043 Mdot
.4308 .63317 Mdot
.6 .60219 Mdot
.55286 .54153 Mdot
.41182 .45096 Mdot
.58888 .57992 Mdot
.37812 .32617 Mdot
.59242 .3511 Mdot
.40498 .34901 Mdot
.379 .35453 Mdot
.34669 .50326 Mdot
.41503 .6856 Mdot
.6384 .60333 Mdot
.38581 .71487 Mdot
.52966 .58594 Mdot
.63993 .55227 Mdot
.31964 .56975 Mdot
.2107 .38474 Mdot
.23926 .57343 Mdot
.57501 .57736 Mdot
.3412 .5515 Mdot
.38733 .59322 Mdot
.5626 .67065 Mdot
.62281 .51157 Mdot
.3767 .37217 Mdot
.41746 .3589 Mdot
.6188 .72385 Mdot
.37543 .2452 Mdot
.39727 .69521 Mdot
.45073 .61284 Mdot
.64729 .53972 Mdot
.60204 .52861 Mdot
.5397 .57673 Mdot
.37193 .52872 Mdot
.34189 .44922 Mdot
.34785 .53041 Mdot
.33446 .44807 Mdot
.40057 .38324 Mdot
.56537 .59212 Mdot
.80077 .5349 Mdot
.61093 .36951 Mdot
.59292 .35158 Mdot
.38479 .38064 Mdot
.39641 .5874 Mdot
.56585 .48285 Mdot
.18961 .68802 Mdot
.63609 .35313 Mdot
.39533 .68397 Mdot
.61975 .55348 Mdot
.34434 .55568 Mdot
.61727 .34815 Mdot
.41304 .73924 Mdot
.61343 .52792 Mdot
.38763 .62975 Mdot
.57144 .57537 Mdot
.65972 .37821 Mdot
.56208 .36937 Mdot
.69976 .78286 Mdot
.59996 .39328 Mdot
.37099 .37597 Mdot
.41197 .33415 Mdot
.59618 .55246 Mdot
.16898 .59403 Mdot
.56469 .32272 Mdot
.38386 .29635 Mdot
.43575 .69676 Mdot
.34349 .48485 Mdot
.43458 .71529 Mdot
.39019 .58296 Mdot
.41371 .6985 Mdot
.37272 .54639 Mdot
.60391 .72225 Mdot
.63246 .31218 Mdot
.39833 .71479 Mdot
.43566 .54874 Mdot
.64113 .52951 Mdot
.38742 .73322 Mdot
.59074 .62384 Mdot
.71688 .60883 Mdot
.36242 .54962 Mdot
.41304 .73532 Mdot
.59183 .52066 Mdot
.82361 .42775 Mdot
.39763 .33251 Mdot
.37488 .3676 Mdot
.59431 .49888 Mdot
.35908 .53114 Mdot
.58879 .40462 Mdot
.50297 .38737 Mdot
.33533 .43285 Mdot
.61268 .5428 Mdot
.57437 .60308 Mdot
.62823 .32867 Mdot
.61654 .30173 Mdot
.59195 .55309 Mdot
.70666 .35095 Mdot
.59675 .53823 Mdot
.42033 .36759 Mdot
.60901 .37992 Mdot
.58545 .35393 Mdot
.38403 .57075 Mdot
.55466 .37185 Mdot
.56836 .63561 Mdot
.47146 .38126 Mdot
.61181 .62218 Mdot
.39575 .35833 Mdot
.4895 .40647 Mdot
.32808 .45757 Mdot
.82248 .51389 Mdot
.62926 .34974 Mdot
.55938 .51955 Mdot
.58724 .32466 Mdot
.41883 .72367 Mdot
.59982 .36387 Mdot
.61858 .33625 Mdot
.60686 .5593 Mdot
.60865 .59405 Mdot
.35568 .49307 Mdot
.50256 .44136 Mdot
.55746 .35721 Mdot
.60779 .54194 Mdot
.5454 .57298 Mdot
.56046 .5115 Mdot
.44916 .45109 Mdot
.61782 .36132 Mdot
.70961 .41699 Mdot
.67492 .67878 Mdot
.55745 .36174 Mdot
.77979 .32473 Mdot
.3418 .47938 Mdot
.36539 .51583 Mdot
.44488 .35345 Mdot
.59357 .53144 Mdot
.35214 .59231 Mdot
.61266 .58857 Mdot
.54078 .61597 Mdot
.60039 .5822 Mdot
.42911 .73114 Mdot
.6545 .57221 Mdot
.34935 .47362 Mdot
.36709 .57507 Mdot
.62872 .55517 Mdot
.61289 .58111 Mdot
.38923 .54922 Mdot
.61666 .38033 Mdot
.59112 .38542 Mdot
.3768 .66758 Mdot
.4088 .72002 Mdot
.42601 .34554 Mdot
.57018 .58773 Mdot
.34108 .55516 Mdot
.36916 .56996 Mdot
.55932 .38864 Mdot
.36329 .56022 Mdot
.41034 .32252 Mdot
.57777 .58193 Mdot
.37471 .36469 Mdot
.40825 .73654 Mdot
.60883 .32619 Mdot
.57749 .59909 Mdot
.57237 .55262 Mdot
.56649 .34758 Mdot
.6505 .57179 Mdot
.43029 .71125 Mdot
.37238 .57673 Mdot
.57101 .37531 Mdot
.40938 .36869 Mdot
.38466 .56445 Mdot
.57806 .53479 Mdot
.547 .13884 Mdot
.58584 .5573 Mdot
.58652 .52981 Mdot
.79162 .66344 Mdot
.65474 .58467 Mdot
.38027 .57888 Mdot
.62441 .32081 Mdot
.60031 .5041 Mdot
.47982 .70357 Mdot
.41132 .80623 Mdot
.35178 .51363 Mdot
.62455 .5601 Mdot
.82697 .52408 Mdot
.62727 .55877 Mdot
.44245 .77677 Mdot
.27308 .65617 Mdot
.49293 .60112 Mdot
.54238 .61316 Mdot
.38534 .32965 Mdot
.35591 .49017 Mdot
.3809 .55869 Mdot
.64541 .45924 Mdot
.60867 .55296 Mdot
.64342 .39413 Mdot
.60493 .51724 Mdot
.40851 .37694 Mdot
.68949 .63145 Mdot
.37125 .56271 Mdot
.22775 .35515 Mdot
.55867 .55456 Mdot
.61693 .367 Mdot
.38227 .55209 Mdot
.34062 .47858 Mdot
.58623 .52607 Mdot
.38877 .7252 Mdot
.40941 .30488 Mdot
.63382 .62163 Mdot
.39675 .36391 Mdot
.60945 .52924 Mdot
.52135 .58244 Mdot
.16549 .51099 Mdot
.56281 .37414 Mdot
.41368 .34659 Mdot
.2399 .46073 Mdot
.6509 .56874 Mdot
.56825 .3716 Mdot
.59898 .34926 Mdot
.39498 .69113 Mdot
.47729 .47323 Mdot
.49449 .22408 Mdot
.80013 .47382 Mdot
.70496 .56833 Mdot
.36573 .5294 Mdot
.25909 .42491 Mdot
.56725 .54513 Mdot
.32944 .33192 Mdot
.37301 .33528 Mdot
.59152 .56523 Mdot
.69983 .53595 Mdot
.61142 .33187 Mdot
.58527 .54144 Mdot
.41595 .68999 Mdot
.32028 .31468 Mdot
.323 .3392 Mdot
.70429 .25808 Mdot
.34868 .51166 Mdot
.53422 .55126 Mdot
.55987 .62824 Mdot
.35925 .46855 Mdot
.62686 .533 Mdot
.37764 .57964 Mdot
.66053 .75305 Mdot
.42507 .73178 Mdot
.61575 .33733 Mdot
.34137 .47867 Mdot
.61854 .51457 Mdot
.54567 .5446 Mdot
.38184 .69953 Mdot
.56762 .5172 Mdot
.17887 .4478 Mdot
.29675 .42702 Mdot
.35275 .58606 Mdot
.57149 .38649 Mdot
.64459 .53842 Mdot
.34353 .44765 Mdot
.60487 .55426 Mdot
.76893 .54074 Mdot
.55765 .52421 Mdot
.47028 .22183 Mdot
.56173 .35102 Mdot
.3986 .36224 Mdot
.52474 .55018 Mdot
.59657 .58738 Mdot
.32401 .63449 Mdot
.53404 .60524 Mdot
.63253 .56872 Mdot
.57811 .40501 Mdot
.61344 .36847 Mdot
.59076 .37349 Mdot
.38543 .60416 Mdot
.35403 .27511 Mdot
.39456 .34665 Mdot
.59224 .6148 Mdot
.39524 .39245 Mdot
.64031 .66129 Mdot
.38432 .69419 Mdot
.79186 .37878 Mdot
.57041 .51126 Mdot
.58592 .36881 Mdot
.53404 .27483 Mdot
.56453 .33312 Mdot
.35927 .61627 Mdot
.38799 .36446 Mdot
.61346 .3407 Mdot
.59016 .59157 Mdot
.4921 .43245 Mdot
.73131 .30263 Mdot
.40905 .35315 Mdot
.55678 .61226 Mdot
.33513 .52506 Mdot
.31448 .45309 Mdot
.61351 .1441 Mdot
.40738 .33673 Mdot
.24125 .44609 Mdot
.6125 .54917 Mdot
.60805 .37338 Mdot
.39221 .32358 Mdot
.39507 .3299 Mdot
.36526 .55435 Mdot
.60599 .59674 Mdot
.59713 .60114 Mdot
.34687 .48776 Mdot
.41719 .36127 Mdot
.57124 .49556 Mdot
.5469 .59233 Mdot
.81068 .62668 Mdot
.62276 .45485 Mdot
.39769 .83988 Mdot
.59668 .65012 Mdot
.70915 .54833 Mdot
.5283 .4438 Mdot
.61183 .32317 Mdot
.60396 .60082 Mdot
.64237 .53981 Mdot
.38334 .57457 Mdot
.58091 .57056 Mdot
.3818 .61365 Mdot
.39943 .33768 Mdot
.77089 .31953 Mdot
.55994 .23551 Mdot
.65541 .75017 Mdot
.58342 .57258 Mdot
.39959 .23574 Mdot
.40671 .72842 Mdot
.36517 .36134 Mdot
.58148 .37874 Mdot
.64637 .57057 Mdot
.3999 .5983 Mdot
.35002 .53678 Mdot
.60666 .35006 Mdot
.2313 .40072 Mdot
.35138 .65613 Mdot
.6413 .57023 Mdot
.37658 .60721 Mdot
.50255 .3269 Mdot
.70015 .33854 Mdot
.39565 .39816 Mdot
.43283 .72387 Mdot
.34665 .53093 Mdot
.3887 .38079 Mdot
.57818 .43455 Mdot
.61064 .33975 Mdot
.61851 .31307 Mdot
.28439 .6321 Mdot
.39707 .60823 Mdot
.39709 .72146 Mdot
.35966 .26579 Mdot
.35277 .26196 Mdot
.43068 .7281 Mdot
.33203 .54133 Mdot
.61639 .35831 Mdot
.57325 .3641 Mdot
.59141 .35075 Mdot
.23902 .33921 Mdot
.57854 .39894 Mdot
.75233 .43887 Mdot
.54391 .56642 Mdot
.56281 .46097 Mdot
.62613 .56134 Mdot
.37448 .34227 Mdot
.56234 .36588 Mdot
.51787 .45594 Mdot
.62222 .60273 Mdot
.72095 .27911 Mdot
.61574 .54487 Mdot
.38945 .39771 Mdot
.58743 .53498 Mdot
.75038 .39662 Mdot
.61244 .31993 Mdot
.57684 .57272 Mdot
.41204 .31528 Mdot
.41267 .71217 Mdot
.56334 .40773 Mdot
.59987 .60161 Mdot
.45476 .27072 Mdot
.65051 .59742 Mdot
.6839 .74799 Mdot
.53642 .77788 Mdot
.3951 .68383 Mdot
.65076 .64362 Mdot
.35652 .52504 Mdot
.60502 .43028 Mdot
.64087 .62932 Mdot
.40884 .35477 Mdot
.54125 .19246 Mdot
.34397 .53771 Mdot
.68818 .62078 Mdot
.6504 .51665 Mdot
.41633 .68663 Mdot
.55591 .32187 Mdot
.38157 .32415 Mdot
.63862 .59207 Mdot
.54369 .52771 Mdot
.6716 .74241 Mdot
.64051 .62537 Mdot
.55705 .59016 Mdot
.38119 .71203 Mdot
.71601 .42646 Mdot
.57657 .55407 Mdot
.35064 .60271 Mdot
.61891 .31463 Mdot
.5998 .50098 Mdot
.70912 .41196 Mdot
.60768 .54299 Mdot
.60977 .35753 Mdot
.61029 .30326 Mdot
.51358 .26324 Mdot
.43132 .6904 Mdot
.55803 .52362 Mdot
.56485 .78951 Mdot
.55724 .54827 Mdot
.38967 .35059 Mdot
.63221 .57967 Mdot
.35253 .54073 Mdot
.22744 .36732 Mdot
.3753 .59801 Mdot
.61996 .58749 Mdot
.58767 .34914 Mdot
.38358 .32782 Mdot
.25888 .59866 Mdot
.30076 .66848 Mdot
.74676 .43512 Mdot
.51696 .84653 Mdot
.42158 .72998 Mdot
.4121 .74612 Mdot
.38771 .31837 Mdot
.57575 .57093 Mdot
.52218 .79953 Mdot
.63397 .61698 Mdot
.58213 .54307 Mdot
.60174 .58184 Mdot
.33988 .32684 Mdot
.40304 .34391 Mdot
.3594 .5637 Mdot
.59033 .55455 Mdot
.60642 .54032 Mdot
.58333 .32904 Mdot
.41113 .71099 Mdot
.38024 .59881 Mdot
.4036 .71359 Mdot
.35457 .57616 Mdot
.79222 .33879 Mdot
.56726 .61255 Mdot
.41318 .71483 Mdot
.37329 .32882 Mdot
.60391 .37163 Mdot
.34401 .44363 Mdot
.38909 .5778 Mdot
.37315 .55986 Mdot
.6131 .54429 Mdot
.60882 .36482 Mdot
.5553 .36824 Mdot
.41799 .72551 Mdot
.41554 .33029 Mdot
.61643 .58883 Mdot
.64406 .55991 Mdot
.53261 .64873 Mdot
.38023 .54336 Mdot
.69015 .35046 Mdot
.49949 .28496 Mdot
.57451 .57456 Mdot
.56966 .3906 Mdot
.60863 .57642 Mdot
.80503 .55546 Mdot
.59748 .38723 Mdot
.61778 .59913 Mdot
.35839 .24387 Mdot
.34309 .49106 Mdot
.4662 .24776 Mdot
.54815 .55892 Mdot
.56921 .83981 Mdot
.56576 .53872 Mdot
.83109 .57228 Mdot
.39414 .52935 Mdot
.56405 .59217 Mdot
.57005 .54704 Mdot
.80091 .45138 Mdot
.61593 .55976 Mdot
.34944 .46233 Mdot
.68656 .63041 Mdot
.61924 .36904 Mdot
.52507 .46225 Mdot
.41215 .62838 Mdot
.43462 .69175 Mdot
.34464 .56782 Mdot
.25703 .47979 Mdot
.42424 .69667 Mdot
.58308 .34464 Mdot
.56451 .57655 Mdot
.47682 .55783 Mdot
.34072 .50443 Mdot
.6196 .49061 Mdot
.38831 .35472 Mdot
.2834 .45296 Mdot
.37544 .61386 Mdot
.405 .36659 Mdot
.58973 .50927 Mdot
.73033 .32748 Mdot
.2557 .64617 Mdot
.71071 .77162 Mdot
.38924 .321 Mdot
.41314 .37564 Mdot
.27976 .30034 Mdot
.43887 .70104 Mdot
.68782 .69894 Mdot
.43699 .23202 Mdot
.42885 .33906 Mdot
.63537 .73611 Mdot
.34904 .52728 Mdot
.44326 .2636 Mdot
.61681 .39439 Mdot
.53989 .5575 Mdot
.59167 .59026 Mdot
.41791 .33354 Mdot
.56001 .43237 Mdot
.16897 .53119 Mdot
.40514 .35784 Mdot
.54354 .60748 Mdot
.45275 .48467 Mdot
.34097 .47179 Mdot
.35869 .50196 Mdot
.42357 .68529 Mdot
.38306 .67618 Mdot
.58107 .33305 Mdot
.40667 .68426 Mdot
.3192 .34328 Mdot
.5686 .51421 Mdot
.41272 .36018 Mdot
.33925 .44703 Mdot
.4065 .37285 Mdot
.41678 .6929 Mdot
.40074 .68219 Mdot
.5633 .38023 Mdot
.59304 .38387 Mdot
.70856 .53698 Mdot
.58757 .74469 Mdot
.62806 .55732 Mdot
.6447 .2593 Mdot
.57137 .33394 Mdot
.64777 .63266 Mdot
.43078 .73121 Mdot
.41052 .71559 Mdot
.65245 .40401 Mdot
.57141 .59341 Mdot
.4899 .80063 Mdot
.5739 .59341 Mdot
.64995 .70216 Mdot
.63047 .53474 Mdot
.36416 .55654 Mdot
.56448 .58847 Mdot
.44581 .72535 Mdot
.59563 .61296 Mdot
.63432 .56681 Mdot
.35456 .53029 Mdot
.64114 .61761 Mdot
.35337 .54029 Mdot
.62029 .58875 Mdot
.42874 .73805 Mdot
.34132 .55661 Mdot
.49969 .68982 Mdot
.42858 .44831 Mdot
.35318 .46665 Mdot
.38951 .70854 Mdot
.38788 .69917 Mdot
.46839 .68932 Mdot
.57984 .37855 Mdot
.53637 .37444 Mdot
.57708 .56758 Mdot
.36541 .53463 Mdot
.40671 .34342 Mdot
.60377 .53923 Mdot
.64396 .55039 Mdot
.55141 .58383 Mdot
.60121 .32392 Mdot
.39637 .59345 Mdot
.41759 .71236 Mdot
.37902 .60712 Mdot
.34255 .63803 Mdot
.3664 .61107 Mdot
.64076 .52192 Mdot
.53591 .52723 Mdot
.72855 .62212 Mdot
.61958 .24646 Mdot
.32966 .24018 Mdot
.609 .34185 Mdot
.35225 .48453 Mdot
.40542 .68218 Mdot
.67219 .64597 Mdot
.5823 .37339 Mdot
.36038 .53644 Mdot
.57128 .57631 Mdot
.54791 .60616 Mdot
.45171 .36321 Mdot
.61632 .41954 Mdot
.49346 .74536 Mdot
.38392 .61699 Mdot
.34579 .46184 Mdot
.34641 .27508 Mdot
.68944 .56931 Mdot
.49062 .51012 Mdot
.59829 .57135 Mdot
.39057 .72842 Mdot
.61726 .3482 Mdot
.256 .61649 Mdot
.42218 .35043 Mdot
.50283 .43749 Mdot
.58263 .57318 Mdot
.36913 .27982 Mdot
.58929 .3485 Mdot
.40779 .68882 Mdot
.41904 .33521 Mdot
.43083 .68536 Mdot
.35997 .50377 Mdot
.49131 .82319 Mdot
.55968 .53258 Mdot
.63065 .56955 Mdot
.3823 .38949 Mdot
.58832 .33089 Mdot
.41007 .66964 Mdot
.70185 .72138 Mdot
.36466 .60148 Mdot
.47916 .80048 Mdot
.56493 .32643 Mdot
.76915 .44443 Mdot
.38155 .60615 Mdot
.38557 .38138 Mdot
.46463 .68072 Mdot
.40188 .38187 Mdot
.59697 .60473 Mdot
.58544 .36116 Mdot
.39552 .3347 Mdot
.31299 .61941 Mdot
.83629 .48583 Mdot
.77732 .44413 Mdot
.55547 .56891 Mdot
.78453 .35779 Mdot
.74338 .70396 Mdot
.53506 .39495 Mdot
.42425 .36864 Mdot
.60158 .55913 Mdot
.60784 .51398 Mdot
.55882 .56035 Mdot
.38326 .34749 Mdot
.30667 .56903 Mdot
.36856 .55035 Mdot
.62121 .55047 Mdot
.40044 .68616 Mdot
.35276 .5451 Mdot
.32971 .5156 Mdot
.38016 .57157 Mdot
.62444 .35089 Mdot
.61227 .60511 Mdot
.44645 .29689 Mdot
.85287 .47692 Mdot
.40592 .35002 Mdot
.35305 .46725 Mdot
.63015 .54703 Mdot
.43291 .21065 Mdot
.58943 .37285 Mdot
.36198 .59972 Mdot
.59326 .56241 Mdot
.30825 .58783 Mdot
.39857 .57779 Mdot
.37843 .56776 Mdot
.57285 .36934 Mdot
.52412 .37676 Mdot
.58199 .56693 Mdot
.56525 .53505 Mdot
.58514 .3345 Mdot
.3704 .74277 Mdot
.23675 .35931 Mdot
.61116 .57971 Mdot
.39995 .36318 Mdot
.25504 .74605 Mdot
.5494 .53783 Mdot
.64375 .4784 Mdot
.35481 .50196 Mdot
.47469 .27626 Mdot
.68815 .34472 Mdot
.65844 .64192 Mdot
.80719 .45567 Mdot
.46217 .61254 Mdot
.77716 .33088 Mdot
.37224 .63584 Mdot
.40781 .50302 Mdot
.80055 .35236 Mdot
.41012 .31645 Mdot
.54835 .46759 Mdot
.59596 .66573 Mdot
.22191 .3922 Mdot
.5412 .42717 Mdot
.35347 .71578 Mdot
.31552 .64608 Mdot
.462 .54402 Mdot
.36931 .58458 Mdot
.63378 .69414 Mdot
.61556 .58779 Mdot
.73759 .7114 Mdot
.71465 .35905 Mdot
.16386 .53912 Mdot
.79364 .3708 Mdot
.56942 .78689 Mdot
.74544 .32484 Mdot
.81875 .54638 Mdot
.72382 .62969 Mdot
.60654 .25334 Mdot
.36477 .79846 Mdot
.34301 .26611 Mdot
.59177 .78798 Mdot
.57206 .48834 Mdot
.45096 .60559 Mdot
.62578 .78961 Mdot
.7569 .4734 Mdot
.17751 .61721 Mdot
.38464 .58609 Mdot
.6167 .317 Mdot
.57628 .66398 Mdot
.55219 .39188 Mdot
.38462 .40711 Mdot
.80786 .44862 Mdot
.82092 .58369 Mdot
.74515 .39311 Mdot
.56728 .84318 Mdot
.66552 .46947 Mdot
.27137 .2573 Mdot
.42157 .46885 Mdot
.60292 .30649 Mdot
.30165 .72963 Mdot
.35589 .26132 Mdot
.53562 .22906 Mdot
.59242 .6526 Mdot
.32112 .50797 Mdot
.52417 .71556 Mdot
.57915 .35293 Mdot
.69003 .33001 Mdot
.36717 .51118 Mdot
.5502 .21838 Mdot
.44415 .67252 Mdot
.82276 .49151 Mdot
.47151 .52232 Mdot
.44018 .27086 Mdot
.2604 .41056 Mdot
.54967 .13902 Mdot
.59171 .76006 Mdot
.77058 .62688 Mdot
.42737 .39408 Mdot
.54059 .41998 Mdot
.20416 .45788 Mdot
.5584 .74606 Mdot
.35786 .25717 Mdot
.57768 .18111 Mdot
.70884 .75348 Mdot
.62364 .18937 Mdot
.54545 .39321 Mdot
.55232 .58377 Mdot
.76549 .61312 Mdot
.70355 .57535 Mdot
.37518 .72297 Mdot
.67905 .23984 Mdot
.40324 .73755 Mdot
.54795 .39287 Mdot
.22763 .39953 Mdot
.75173 .42039 Mdot
.47823 .79337 Mdot
.42435 .67114 Mdot
.65806 .56606 Mdot
.12355 .42906 Mdot
.76987 .3275 Mdot
.50484 .26506 Mdot
.81219 .62487 Mdot
.36012 .28702 Mdot
.51843 .78871 Mdot
.39171 .33771 Mdot
.83622 .41278 Mdot
.57699 .36511 Mdot
.83237 .35559 Mdot
.84023 .45886 Mdot
.20018 .58425 Mdot
.14167 .64437 Mdot
.31594 .37996 Mdot
.49641 .59294 Mdot
.46635 .62169 Mdot
.49336 .716 Mdot
.17706 .51312 Mdot
.20132 .61238 Mdot
.35399 .28664 Mdot
.58132 .81952 Mdot
.81503 .38383 Mdot
.64923 .72331 Mdot
.52548 .81555 Mdot
.21708 .41855 Mdot
.44181 .44571 Mdot
.57018 .30622 Mdot
.41196 .43296 Mdot
.62526 .27183 Mdot
.66663 .22833 Mdot
.69466 .55909 Mdot
.19606 .69708 Mdot
.44576 .69201 Mdot
.40173 .56393 Mdot
.78073 .65255 Mdot
.50776 .6845 Mdot
.69468 .64181 Mdot
.30003 .29273 Mdot
.65474 .53 Mdot
.31841 .28119 Mdot
.54858 .29469 Mdot
.2634 .47284 Mdot
.33581 .27531 Mdot
.48976 .33453 Mdot
.68218 .73561 Mdot
.77342 .57749 Mdot
.3771 .23672 Mdot
.61934 .37096 Mdot
.53078 .75319 Mdot
.60946 .75242 Mdot
.80414 .63546 Mdot
.24007 .46 Mdot
.7337 .76099 Mdot
.2247 .48294 Mdot
.60857 .62052 Mdot
.60438 .6377 Mdot
.54817 .49247 Mdot
.56586 .75495 Mdot
.54804 .58133 Mdot
.35929 .28013 Mdot
.79766 .65247 Mdot
.69237 .52699 Mdot
.26944 .49117 Mdot
.55583 .19325 Mdot
.71576 .76315 Mdot
.73702 .64092 Mdot
.37743 .49763 Mdot
.61416 .46675 Mdot
.34976 .20367 Mdot
.34996 .55184 Mdot
.64235 .7327 Mdot
.43608 .36092 Mdot
.27823 .63573 Mdot
.79334 .45163 Mdot
.20183 .56929 Mdot
.79766 .65519 Mdot
.245 .35575 Mdot
.235 .5652 Mdot
.4583 .70982 Mdot
.46363 .793 Mdot
.58929 .20984 Mdot
.53206 .57739 Mdot
.5202 .60492 Mdot
.38434 .72275 Mdot
.72918 .55687 Mdot
.68414 .67953 Mdot
.30763 .69818 Mdot
.58121 .63202 Mdot
.24025 .6608 Mdot
.34523 .45706 Mdot
.4982 .43499 Mdot
.66919 .19146 Mdot
.62999 .50338 Mdot
.32521 .39449 Mdot
.69513 .7595 Mdot
.52051 .76991 Mdot
.77785 .64074 Mdot
.46979 .31501 Mdot
.61535 .19033 Mdot
.84537 .49392 Mdot
.30014 .67778 Mdot
.7464 .28909 Mdot
.79814 .68626 Mdot
.58139 .17275 Mdot
.66018 .33233 Mdot
.39385 .31137 Mdot
.78374 .26107 Mdot
.33403 .55597 Mdot
.5043 .18198 Mdot
.70367 .56427 Mdot
.29115 .55683 Mdot
.58415 .41252 Mdot
.61174 .47746 Mdot
.46471 .54246 Mdot
.61453 .40486 Mdot
.61252 .50765 Mdot
.59678 .15723 Mdot
.53472 .16952 Mdot
.61464 .17179 Mdot
.65802 .79074 Mdot
.7553 .29728 Mdot
.50259 .62632 Mdot
.76056 .45246 Mdot
.59576 .67763 Mdot
.63634 .57633 Mdot
.60457 .70796 Mdot
.31341 .38355 Mdot
.24701 .6297 Mdot
.51878 .22387 Mdot
.56276 .40171 Mdot
.68237 .25765 Mdot
.54041 .10628 Mdot
.6711 .46384 Mdot
.68336 .42085 Mdot
.3277 .32623 Mdot
.59134 .74865 Mdot
.58156 .27998 Mdot
.22532 .61226 Mdot
.79153 .64662 Mdot
.61123 .66886 Mdot
.64617 .74021 Mdot
.32546 .72107 Mdot
.43017 .77415 Mdot
.42689 .57614 Mdot
.82751 .47422 Mdot
.5038 .6493 Mdot
.21104 .55581 Mdot
.51496 .48604 Mdot
.18475 .56241 Mdot
.34271 .67729 Mdot
.28076 .44319 Mdot
.60969 .767 Mdot
.32082 .45316 Mdot
.63814 .71881 Mdot
.45785 .47808 Mdot
.64948 .67417 Mdot
.46272 .61087 Mdot
.64194 .71648 Mdot
.42827 .77277 Mdot
.68818 .23595 Mdot
.79037 .7109 Mdot
.46789 .15737 Mdot
.58305 .83573 Mdot
.53075 .30939 Mdot
.54351 .54228 Mdot
.77244 .68746 Mdot
.6559 .19948 Mdot
.84833 .51157 Mdot
.25673 .3562 Mdot
.30781 .60526 Mdot
.36662 .36181 Mdot
.46947 .16063 Mdot
.3626 .69768 Mdot
.80684 .58496 Mdot
.3357 .23894 Mdot
.4449 .35036 Mdot
.20681 .39481 Mdot
.50426 .17494 Mdot
.78018 .42108 Mdot
.67515 .36167 Mdot
.62553 .49179 Mdot
.73484 .3686 Mdot
.62812 .33767 Mdot
.2526 .41597 Mdot
.56578 .7491 Mdot
.34629 .55359 Mdot
.49539 .65769 Mdot
.54106 .63136 Mdot
.65489 .57298 Mdot
.42413 .62103 Mdot
.63335 .33972 Mdot
.61787 .2474 Mdot
.47516 .35612 Mdot
.77928 .30512 Mdot
.30136 .39636 Mdot
.51983 .5879 Mdot
.54142 .76774 Mdot
.24591 .5729 Mdot
.28865 .29789 Mdot
.43059 .33704 Mdot
.81379 .40553 Mdot
.3994 .42296 Mdot
.53533 .75557 Mdot
.7247 .35509 Mdot
.6987 .70507 Mdot
.54083 .51996 Mdot
.51581 .2786 Mdot
.75453 .55559 Mdot
.50069 .44645 Mdot
.54332 .35347 Mdot
.61366 .29675 Mdot
.64713 .83757 Mdot
.31235 .33256 Mdot
.27077 .43848 Mdot
.81879 .41834 Mdot
.3873 .36874 Mdot
.55822 .34551 Mdot
.62557 .70605 Mdot
.68325 .74035 Mdot
.75611 .52244 Mdot
.39971 .58771 Mdot
.31272 .49347 Mdot
.32707 .69938 Mdot
.78748 .36846 Mdot
.75974 .33554 Mdot
.16009 .53817 Mdot
.56264 .3976 Mdot
.71523 .68753 Mdot
.6509 .74813 Mdot
.58929 .32157 Mdot
.56317 .41253 Mdot
.52304 .20923 Mdot
.73242 .26101 Mdot
.41607 .28335 Mdot
.56544 .83364 Mdot
.46642 .73906 Mdot
.31171 .58653 Mdot
.25117 .58922 Mdot
.56303 .80098 Mdot
.82055 .42816 Mdot
.68501 .31694 Mdot
.76917 .38625 Mdot
.51929 .54746 Mdot
.63185 .40795 Mdot
.44921 .15954 Mdot
.43402 .46258 Mdot
.76648 .43352 Mdot
.49119 .34906 Mdot
.55572 .55765 Mdot
.5521 .14009 Mdot
.71599 .72666 Mdot
.29198 .28414 Mdot
.39436 .30449 Mdot
.58117 .52306 Mdot
.56146 .60581 Mdot
.60212 .45557 Mdot
.49238 .27531 Mdot
.55469 .18292 Mdot
.56663 .80088 Mdot
.50961 .35157 Mdot
.71177 .35219 Mdot
.3254 .39567 Mdot
.81957 .50175 Mdot
.75767 .68329 Mdot
.48147 .46086 Mdot
.30785 .38479 Mdot
.45894 .66949 Mdot
.59895 .8247 Mdot
.45725 .58084 Mdot
.51658 .63611 Mdot
.44914 .21282 Mdot
.48009 .29626 Mdot
.24589 .59273 Mdot
.62532 .53865 Mdot
.23137 .39916 Mdot
.81767 .54258 Mdot
.16555 .61125 Mdot
.18848 .49071 Mdot
.57271 .1406 Mdot
.77675 .52529 Mdot
.47154 .29884 Mdot
.74838 .3436 Mdot
.15965 .61686 Mdot
.44692 .60392 Mdot
.71552 .28291 Mdot
.4599 .68983 Mdot
.80461 .39412 Mdot
.42566 .32206 Mdot
.40271 .25755 Mdot
.55012 .19183 Mdot
.74329 .27584 Mdot
.74497 .64134 Mdot
.81903 .45831 Mdot
.50943 .49137 Mdot
.70436 .23284 Mdot
.45222 .20474 Mdot
.45969 .54924 Mdot
.33654 .52499 Mdot
.2865 .31357 Mdot
.68349 .28097 Mdot
.58839 .26447 Mdot
.64175 .73684 Mdot
.44573 .56466 Mdot
.68185 .64438 Mdot
.75134 .36819 Mdot
.53528 .69278 Mdot
.48917 .30653 Mdot
.53881 .76837 Mdot
.8232 .55158 Mdot
.43839 .59492 Mdot
.25656 .58734 Mdot
.31823 .4114 Mdot
.51013 .82646 Mdot
.49422 .27051 Mdot
.30659 .33768 Mdot
.77255 .62303 Mdot
.36664 .67037 Mdot
.57974 .77854 Mdot
.74642 .78624 Mdot
.57902 .80652 Mdot
.58592 .23398 Mdot
.66127 .22718 Mdot
.77549 .66202 Mdot
.60594 .24217 Mdot
.17545 .49448 Mdot
.62372 .44192 Mdot
.60083 .72145 Mdot
.60069 .58307 Mdot
.65865 .18884 Mdot
.53559 .71343 Mdot
.66599 .22493 Mdot
.74778 .72274 Mdot
.73533 .36302 Mdot
.65551 .5743 Mdot
.38531 .62244 Mdot
.38094 .45194 Mdot
.54364 .69042 Mdot
.77736 .39206 Mdot
.62588 .44843 Mdot
.30139 .43814 Mdot
.36119 .46843 Mdot
.40789 .6143 Mdot
.53499 .33139 Mdot
.29316 .38186 Mdot
.49373 .28978 Mdot
.3715 .73454 Mdot
.48702 .49331 Mdot
.60747 .74463 Mdot
.69067 .346 Mdot
.78419 .43427 Mdot
.19819 .56174 Mdot
.42996 .41248 Mdot
.3813 .58 Mdot
.79734 .49653 Mdot
.60018 .80229 Mdot
.50019 .31743 Mdot
.60442 .19177 Mdot
.27557 .31643 Mdot
.59708 .68739 Mdot
.67567 .67408 Mdot
.18197 .53981 Mdot
.37874 .79412 Mdot
.6534 .24466 Mdot
.64435 .29677 Mdot
.4924 .79671 Mdot
.54023 .63501 Mdot
.79255 .34054 Mdot
.60351 .77779 Mdot
.69717 .66252 Mdot
.42042 .45517 Mdot
.7472 .48848 Mdot
.72723 .3433 Mdot
.49138 .68384 Mdot
.50207 .48377 Mdot
.28526 .24084 Mdot
.59885 .41226 Mdot
.5303 .13023 Mdot
.42267 .35871 Mdot
.23121 .33581 Mdot
.41385 .77382 Mdot
.45711 .47044 Mdot
.50809 .47873 Mdot
.52001 .27106 Mdot
.46901 .22103 Mdot
.62431 .80522 Mdot
.18816 .59571 Mdot
.35293 .59984 Mdot
.52636 .80398 Mdot
.47216 .82301 Mdot
.80298 .46023 Mdot
.63767 .52769 Mdot
.56946 .81439 Mdot
.43586 .4584 Mdot
.24537 .62524 Mdot
.75884 .69869 Mdot
.54786 .27938 Mdot
.53807 .6045 Mdot
.586 .74867 Mdot
.71412 .28428 Mdot
.84088 .48216 Mdot
.18457 .43032 Mdot
.54724 .29561 Mdot
.38398 .31701 Mdot
.48287 .60126 Mdot
.79187 .39112 Mdot
.4983 .77941 Mdot
.42658 .27078 Mdot
.60184 .75924 Mdot
.4351 .13887 Mdot
.57381 .18862 Mdot
.55375 .18305 Mdot
.53099 .78097 Mdot
.54779 .36874 Mdot
.49782 .19541 Mdot
.68362 .66887 Mdot
.54768 .27209 Mdot
.6414 .78305 Mdot
.63187 .73529 Mdot
.14497 .51915 Mdot
.71671 .62568 Mdot
.34642 .6394 Mdot
.71097 .32279 Mdot
.7128 .56839 Mdot
.39584 .30733 Mdot
.58551 .71651 Mdot
.49459 .35142 Mdot
.37206 .37879 Mdot
.49237 .30251 Mdot
.45552 .26697 Mdot
.70208 .65948 Mdot
.76295 .50812 Mdot
.51113 .33729 Mdot
.79544 .53653 Mdot
.60846 .41799 Mdot
.25675 .61595 Mdot
.25343 .56843 Mdot
.51283 .39536 Mdot
.34565 .57617 Mdot
.65468 .64369 Mdot
.49683 .45823 Mdot
.44786 .63646 Mdot
.43397 .17605 Mdot
.39911 .7378 Mdot
.5519 .37301 Mdot
.26982 .28869 Mdot
.58661 .32009 Mdot
.62087 .1658 Mdot
.22226 .6002 Mdot
.72417 .35811 Mdot
.31113 .67661 Mdot
.30501 .72068 Mdot
.17851 .36337 Mdot
.64791 .27985 Mdot
.40992 .44538 Mdot
.64392 .32171 Mdot
.59015 .39527 Mdot
.30896 .44231 Mdot
.36087 .47461 Mdot
.67204 .38031 Mdot
.34803 .40992 Mdot
.59458 .68131 Mdot
.58498 .30704 Mdot
.34267 .62741 Mdot
.69032 .61954 Mdot
.74551 .27313 Mdot
.37442 .58503 Mdot
.35035 .19301 Mdot
.57635 .62099 Mdot
.75547 .59397 Mdot
.79264 .6692 Mdot
.19427 .40906 Mdot
.23747 .53212 Mdot
.40128 .80579 Mdot
.62028 .61545 Mdot
.5172 .32995 Mdot
.57579 .35474 Mdot
.68183 .69256 Mdot
.41241 .70041 Mdot
.5058 .74918 Mdot
.39408 .39268 Mdot
.21356 .55852 Mdot
.28825 .3882 Mdot
.54991 .34183 Mdot
.56428 .27822 Mdot
.71807 .66217 Mdot
.41769 .24734 Mdot
.43812 .4562 Mdot
.80058 .45811 Mdot
.75789 .50894 Mdot
.59115 .30517 Mdot
.60791 .20238 Mdot
.63893 .75133 Mdot
.83956 .40938 Mdot
.55087 .48159 Mdot
.41301 .47899 Mdot
.39837 .24072 Mdot
.50695 .29396 Mdot
.68424 .35049 Mdot
.79423 .64293 Mdot
.54413 .74991 Mdot
.37567 .25833 Mdot
.63824 .71473 Mdot
.67141 .54448 Mdot
.47389 .49892 Mdot
.25408 .39065 Mdot
.14953 .46928 Mdot
.65093 .38494 Mdot
.2014 .43797 Mdot
.6395 .29836 Mdot
.32337 .39286 Mdot
.60854 .40887 Mdot
.27162 .56006 Mdot
.75687 .48312 Mdot
.23983 .4857 Mdot
.81359 .36625 Mdot
.79341 .64734 Mdot
.44919 .35061 Mdot
.31937 .48063 Mdot
.54183 .45134 Mdot
.52366 .52255 Mdot
.50968 .42538 Mdot
.56789 .59854 Mdot
.55039 .41131 Mdot
.20703 .38379 Mdot
.53447 .2755 Mdot
.62193 .4849 Mdot
.78454 .33739 Mdot
.84125 .42206 Mdot
.69832 .23176 Mdot
.4751 .79875 Mdot
.61612 .32896 Mdot
.58411 .16842 Mdot
.69313 .38983 Mdot
.82808 .54374 Mdot
.64978 .24798 Mdot
.67131 .82204 Mdot
.77599 .39489 Mdot
.4886 .34966 Mdot
.19879 .60147 Mdot
.47475 .23185 Mdot
.73531 .71995 Mdot
.45705 .55596 Mdot
.28 .47253 Mdot
.73394 .72604 Mdot
.13825 .40498 Mdot
.65574 .31428 Mdot
.44776 .26987 Mdot
.54796 .64476 Mdot
.50497 .37799 Mdot
.38969 .4997 Mdot
.63313 .57757 Mdot
.33429 .49117 Mdot
.23666 .57151 Mdot
.61398 .74307 Mdot
.67758 .65475 Mdot
.39087 .50358 Mdot
.54897 .68925 Mdot
.65401 .69663 Mdot
.58722 .79196 Mdot
.78791 .42662 Mdot
.67601 .37425 Mdot
.53088 .59027 Mdot
.58472 .42286 Mdot
.43359 .69672 Mdot
.25158 .49683 Mdot
.61362 .59773 Mdot
.24078 .49356 Mdot
.44388 .23389 Mdot
.57915 .14675 Mdot
.27126 .52591 Mdot
.70107 .73266 Mdot
.62086 .38786 Mdot
.50096 .27682 Mdot
.7968 .55405 Mdot
.22429 .39296 Mdot
.40716 .53141 Mdot
.69538 .56114 Mdot
.77697 .34054 Mdot
.33514 .27935 Mdot
.68238 .72474 Mdot
.40308 .20633 Mdot
.36984 .35703 Mdot
.65291 .36108 Mdot
.54161 .64544 Mdot
.25551 .34836 Mdot
.55123 .32907 Mdot
.48315 .33606 Mdot
.43003 .50634 Mdot
.32584 .28346 Mdot
.69669 .76016 Mdot
.70939 .68164 Mdot
.69999 .30897 Mdot
.76415 .33775 Mdot
.35402 .5119 Mdot
.65087 .73856 Mdot
.48003 .34242 Mdot
.41242 .51781 Mdot
.37853 .24106 Mdot
.78103 .31527 Mdot
.51402 .4383 Mdot
.51754 .70897 Mdot
.56135 .5376 Mdot
.71116 .41576 Mdot
.53266 .26964 Mdot
.42784 .75649 Mdot
.288 .42424 Mdot
.59512 .38682 Mdot
.27569 .40948 Mdot
.41647 .59581 Mdot
.58264 .72528 Mdot
.63814 .31632 Mdot
.65965 .489 Mdot
.38178 .73592 Mdot
.32768 .4345 Mdot
.57599 .4973 Mdot
.50976 .71901 Mdot
.47303 .78824 Mdot
.6557 .35197 Mdot
.63917 .26953 Mdot
.80023 .46758 Mdot
.67262 .7501 Mdot
.51368 .30428 Mdot
.64687 .24197 Mdot
.47935 .2198 Mdot
.7696 .47162 Mdot
.22991 .44042 Mdot
.54961 .57976 Mdot
.27316 .56036 Mdot
.55792 .34177 Mdot
.79516 .40989 Mdot
.77149 .53423 Mdot
.50079 .689 Mdot
.46701 .44389 Mdot
.79082 .57307 Mdot
.45812 .42714 Mdot
.78338 .67708 Mdot
.47815 .23149 Mdot
.56398 .74838 Mdot
.4401 .36321 Mdot
.45689 .72689 Mdot
.18158 .5218 Mdot
.83294 .42214 Mdot
.1975 .57193 Mdot
.47994 .55184 Mdot
.20157 .42595 Mdot
.55836 .21223 Mdot
.74353 .72195 Mdot
.5812 .74036 Mdot
.50771 .42339 Mdot
.68762 .61771 Mdot
.44955 .37246 Mdot
.34499 .44452 Mdot
.27675 .58013 Mdot
.67878 .38932 Mdot
.30345 .51944 Mdot
.23172 .51374 Mdot
.55598 .49897 Mdot
.4086 .21986 Mdot
.7689 .3377 Mdot
.70631 .62717 Mdot
.44472 .4722 Mdot
.274 .64748 Mdot
.56705 .72723 Mdot
.4977 .878 Mdot
.54989 .1384 Mdot
.56145 .53482 Mdot
.46201 .60466 Mdot
.5168 .74143 Mdot
.37225 .61129 Mdot
.66474 .40885 Mdot
.80292 .44915 Mdot
.4167 .37415 Mdot
.30035 .60068 Mdot
.32121 .28894 Mdot
.5264 .26377 Mdot
.4896 .66623 Mdot
.34387 .31221 Mdot
.59881 .15215 Mdot
.60451 .80551 Mdot
.51837 .28723 Mdot
.5568 .87066 Mdot
.24512 .38539 Mdot
.6206 .29664 Mdot
.7651 .6217 Mdot
.68988 .23578 Mdot
.52575 .77242 Mdot
.28382 .63269 Mdot
.61031 .23051 Mdot
.55583 .74714 Mdot
.6599 .70671 Mdot
.31774 .411 Mdot
.27941 .41331 Mdot
.45975 .51214 Mdot
.30672 .72147 Mdot
.45773 .1824 Mdot
.69796 .32901 Mdot
.74229 .3101 Mdot
.22456 .5572 Mdot
.14505 .53496 Mdot
.83611 .412 Mdot
.58488 .70457 Mdot
.38404 .49721 Mdot
.76076 .63389 Mdot
.47944 .74171 Mdot
.69357 .54875 Mdot
.22361 .58551 Mdot
.74877 .52801 Mdot
.28241 .69945 Mdot
.20936 .47711 Mdot
.63943 .71772 Mdot
.70816 .55773 Mdot
.5156 .44406 Mdot
.79553 .47382 Mdot
.30347 .42334 Mdot
.5508 .77317 Mdot
.30568 .61798 Mdot
.47857 .71558 Mdot
.80159 .49142 Mdot
.78939 .59278 Mdot
.51532 .42246 Mdot
.14967 .38918 Mdot
.68156 .24803 Mdot
.22212 .41296 Mdot
.54403 .56244 Mdot
.80846 .3523 Mdot
.50253 .3957 Mdot
.63826 .23585 Mdot
.68271 .75743 Mdot
.25831 .54927 Mdot
.40976 .23707 Mdot
.55298 .58634 Mdot
.64376 .26269 Mdot
.76637 .42795 Mdot
.71293 .56318 Mdot
.23733 .58025 Mdot
.54189 .76544 Mdot
.37454 .50651 Mdot
.48275 .68684 Mdot
.51812 .52263 Mdot
.56144 .33114 Mdot
.62845 .17846 Mdot
.48482 .55799 Mdot
.66423 .63037 Mdot
.57268 .45562 Mdot
.19228 .58555 Mdot
.48655 .85189 Mdot
.53459 .49939 Mdot
.34112 .27731 Mdot
.63584 .73801 Mdot
.62984 .68119 Mdot
.65136 .29395 Mdot
.17357 .706 Mdot
.80493 .65588 Mdot
.59486 .39996 Mdot
.63561 .45191 Mdot
.53711 .78832 Mdot
.70933 .24568 Mdot
.32675 .71949 Mdot
.24874 .5641 Mdot
.19413 .64474 Mdot
.48216 .75609 Mdot
.64423 .55378 Mdot
.68604 .7711 Mdot
.83432 .43266 Mdot
.2175 .55494 Mdot
.79636 .35088 Mdot
.66285 .55759 Mdot
.55121 .60079 Mdot
.33374 .83167 Mdot
.80291 .40597 Mdot
.65618 .53106 Mdot
.18488 .57465 Mdot
.5591 .31562 Mdot
.60846 .591 Mdot
.33427 .38435 Mdot
.60118 .77516 Mdot
.65575 .70068 Mdot
.742 .27443 Mdot
.54602 .3482 Mdot
.23791 .50266 Mdot
.39674 .38657 Mdot
.50517 .48205 Mdot
.54256 .59902 Mdot
.38623 .33834 Mdot
.61 .69183 Mdot
.51307 .40249 Mdot
.4168 .30919 Mdot
.53045 .81093 Mdot
.72186 .77206 Mdot
.78103 .50599 Mdot
.44381 .32983 Mdot
.65768 .50829 Mdot
.71799 .61827 Mdot
.54699 .69065 Mdot
.55295 .66979 Mdot
.72161 .74461 Mdot
.86405 .60714 Mdot
.28583 .48018 Mdot
.5782 .46956 Mdot
.63459 .3125 Mdot
.68221 .36958 Mdot
.77108 .40719 Mdot
.36837 .31362 Mdot
.3578 .49194 Mdot
.63822 .61359 Mdot
.51902 .51974 Mdot
.39932 .39199 Mdot
.4913 .13761 Mdot
.63808 .55701 Mdot
.67253 .31111 Mdot
.82919 .52915 Mdot
.25483 .61288 Mdot
.74755 .59975 Mdot
.63258 .60296 Mdot
.48384 .19897 Mdot
.49767 .39207 Mdot
.52347 .38433 Mdot
.25229 .5822 Mdot
.73439 .2834 Mdot
.77009 .54012 Mdot
.69175 .30501 Mdot
.61155 .54037 Mdot
.4363 .72746 Mdot
.4381 .26087 Mdot
.61296 .22537 Mdot
.51739 .58905 Mdot
.8388 .51926 Mdot
.25913 .55675 Mdot
.30945 .52152 Mdot
.64646 .66505 Mdot
.65246 .20742 Mdot
.19862 .47247 Mdot
.75452 .38712 Mdot
.26858 .30783 Mdot
.29132 .33498 Mdot
.53773 .69496 Mdot
.38757 .62269 Mdot
.61843 .48182 Mdot
.56214 .31505 Mdot
.62747 .15789 Mdot
.60598 .22053 Mdot
.46525 .34756 Mdot
.28438 .44942 Mdot
.73882 .41682 Mdot
.52192 .4583 Mdot
.61924 .85735 Mdot
.35521 .71578 Mdot
.59173 .14823 Mdot
.68568 .68734 Mdot
.56113 .29623 Mdot
.47847 .31197 Mdot
.5854 .63647 Mdot
.37655 .56801 Mdot
.71815 .25768 Mdot
.52538 .50372 Mdot
.22174 .46167 Mdot
.64294 .55497 Mdot
.30464 .27247 Mdot
.47309 .38835 Mdot
.32029 .47094 Mdot
.32313 .46099 Mdot
.17711 .49643 Mdot
.81025 .55071 Mdot
.49103 .39444 Mdot
.59866 .852 Mdot
.75808 .35254 Mdot
.81514 .407 Mdot
.40072 .59697 Mdot
.17923 .41567 Mdot
.60296 .25979 Mdot
.50776 .33414 Mdot
.47242 .3628 Mdot
.46842 .63491 Mdot
.27442 .32216 Mdot
.62846 .68446 Mdot
.45667 .2486 Mdot
.44844 .365 Mdot
.91058 .57907 Mdot
.60154 .70257 Mdot
.57635 .64697 Mdot
.23463 .40457 Mdot
.80199 .37585 Mdot
.38578 .76091 Mdot
.69678 .77512 Mdot
.45222 .60373 Mdot
.54242 .59419 Mdot
.76182 .52651 Mdot
.70056 .64736 Mdot
.29512 .30655 Mdot
.2187 .30027 Mdot
.61582 .79577 Mdot
.30067 .49048 Mdot
.48779 .4849 Mdot
.58576 .32339 Mdot
.58375 .41176 Mdot
.30625 .69084 Mdot
.65172 .81127 Mdot
.49696 .36938 Mdot
.79359 .39337 Mdot
.16954 .38663 Mdot
.68645 .70279 Mdot
.71629 .24909 Mdot
.5878 .24771 Mdot
.57819 .42313 Mdot
.55467 .68845 Mdot
.42094 .66028 Mdot
.33584 .47924 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`2/ooooo`;o0000Voooool001cooooo00?o0000ooooooooool0[?ooool2
o`0009_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0:Sooooo0_l0002Oooooo`00
7?ooool00ol0003oooooooooo`2Xooooo`;o00002Oooool2o`0009Cooooo000Looooo`03o`000?oo
oooooooo09cooooo0_l0000Aooooo`;o00000_ooool2o`0009Cooooo000Looooo`03o`000?oooooo
oooo08[ooooo0_l0000@ooooo`;o00004?ooool5o`0000?ooooo0_l0002Aooooo`007?ooool00ol0
003oooooooooo`2:ooooo`;o00002_ooool2o`0001Kooooo1Ol00003ooooo`;o00003?ooool2o`00
08?ooooo000Looooo`03o`000?oooooooooo09Kooooo0_l0000Pooooo`;o00002_ooool2o`0008?o
oooo000Looooo`03o`000?oooooooooo0;Sooooo0_l00002ooooo`;o0000Roooool001cooooo0_l0
002mooooo`;o000000?oooooo`000?l000005?ooool2o`0007;ooooo000Looooo`03o`000?oooooo
oooo07?ooooo0_l0001:ooooo`;o00005?ooool2o`0007;ooooo000Looooo`03o`000?oooooooooo
07?ooooo0_l00009ooooo`;o00000oooool2o`0000Wooooo0_l000001?oooooo0000o`000?ooool2
o`0000Cooooo0_l0000Rooooo`;o00002?ooool2o`0007oooooo000Looooo`03o`000?oooooooooo
07kooooo0_l00003ooooo`;o00002Oooool2o`000004ooooool0003o0000ooooo`?o00000oooool2
o`0000;ooooo0_l0000Nooooo`;o00001_ooool4o`000003ooooool0003o000007cooooo000Loooo
o`03o`000?oooooooooo09Gooooo0_l000000ooooooo0000o`000004ooooo`;o00001_ooool2o`00
01kooooo0_l00003ooooo`;o0000O?ooool001cooooo00?o0000ooooooooool0S?ooool2o`0000[o
oooo0_l0000<ooooo`;o00004_ooool2o`0000[ooooo0_l00021ooooo`007?ooool00ol0003ooooo
ooooo`2<ooooo`;o00007?ooool2o`0000kooooo0_l00008ooooo`;o0000Poooool001cooooo00?o
0000ooooooooool0X?ooool2o`0000Sooooo0_l0000=ooooo`;o00002Oooool2o`0008?ooooo000L
ooooo`03o`000?oooooooooo08Oooooo1?l0000Cooooo`Co00001_ooool2o`0000oooooo0_l0000=
ooooo`;o0000Ooooool001cooooo00?o0000ooooooooool0Qoooool4o`0001?ooooo1?l00003oooo
o`;o000000?oooooo`000?l000003_ooool2o`0000kooooo0_l0001oooooo`007?ooool00ol0003o
ooooooooo`2Aooooo`;o00003Oooool2o`0000?ooooo0_l00009ooooo`;o00001_ooool2o`0008oo
oooo000Looooo`03o`000?oooooooooo08kooooo0_l000001?oooooo0000o`000?l0000<ooooo`;o
00003_ooool2o`0009Oooooo000Looooo`03o`000?oooooooooo08gooooo0ol00002ooooo`;o0000
0oooool2o`0000Gooooo0_l0000;ooooo`;o00002_ooool2o`0000_ooooo0_l000000ooooooo0000
o`000009ooooo`;o0000MOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Co
oooo1Ol00006ooooo`03o`000?oooooooooo06kooooo0_l0000Mooooo`;o00001Oooool2o`000003
ooooool0003o000000Gooooo1?l00009ooooo`?o000000?oooooo`000?l000000_l00004ooooo`;o
00002?ooool2o`000004ooooool0003o0000ooooo`;o00002Oooool2o`0000;ooooo0_l0001aoooo
o`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Kooooo00?o0000ooooooooool0K_ooool2o`0002;ooooo1?l00008ooooo`Co00002Ooo
ool3o`000003ooooool0003o000000;o00003_ooool2o`000003ooooool0003o0000013ooooo0_l0
001aooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7o
k^k^00Oooooo00?o0000ooooooooool0P_ooool2o`0000cooooo1?l00005ooooo`;o000000?ooooo
o`000?l000001?l00009ooooo`;o00006?ooool2o`0000[ooooo0_l0001fooooo`0000?oooooo`00
0?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol00022oooo
o`;o00003?ooool2o`0000Oooooo0_l000000ooooooo0000o`000002ooooo`;o00002?ooool2o`00
00gooooo0_l00007ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Kooooo0_l0001foooo
o`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0K_ooool2o`0001oooooo0_l0000Cooooo`;o00001?ooool2o`0000go
oooo0_l00007ooooo`;o00001Oooool2o`0007kooooo00000ooooooo410@ooooo`02ooooo`03oa0@
4?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1^ooooo`;o0000
3oooool2o`0000Oooooo0_l00005ooooo`;o00002?ooool2o`0000Wooooo1?l00009ooooo`;o0000
7Oooool2o`0007Oooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oo
ooooV9RHoa0@4006ooooo`03o`000?oooooooooo077ooooo0_l0000<ooooo`;o00001oooool3o`00
00Cooooo0_l00008ooooo`;o00002oooool2o`0000;ooooo0_l00005ooooo`?o00002?ooool2o`00
01;ooooo1Ol0001dooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1aooooo`;o00005Oooool3o`0000?ooooo0_l0
000Jooooo`;o00001?ooool4o`0000Sooooo0_l0000:ooooo`;o00002?ooool3o`0007Cooooo000L
ooooo`03o`000?oooooooooo07cooooo0ol000000ooooooo0000o`000006ooooo`;o00001?ooool4
o`0000Cooooo0_l00004ooooo`;o00004Oooool5o`000003ooooool0003o0000017ooooo0_l0001o
ooooo`007?ooool00ol0003oooooooooo`1[ooooo`;o000000?oooooo`000?l000003?ooool3o`00
0004ooooool0003o0000o`0000Cooooo0ol00006ooooo`;o00000oooool5o`0000;ooooo0_l0000A
ooooo`;o000000Coooooo`000?l0003ooooo0_l0000:ooooo`?o0000QOooool001cooooo00?o0000
ooooooooool0Joooool2o`000003ooooool0003o000000;o00003_ooool3o`0000Cooooo0ol00000
0ooooooo0000o`000008ooooo`Go00000oooool2o`0000Kooooo0_l0000:ooooo`;o00003_ooool3
o`0000Oooooo0_l0001looooo`007?ooool00ol0003oooooooooo`1Wooooo`;o00001oooool3o`00
00Oooooo0_l00004ooooo`;o00001?ooool4o`000003ooooool0003o000000Sooooo1?l00002oooo
o`Co00001_ooool2o`0000Oooooo0_l000001?oooooo0000o`000?l0000?ooooo`;o00001_ooool2
o`0000Kooooo1?l0001booooo`007?ooool00ol0003oooooooooo`1Wooooo`;o00000oooool2o`00
00?ooooo0_l00003ooooo`?o000000Goooooo`000?l0003o0000ooooo`02o`0000Kooooo0_l0000C
ooooo`;o00003Oooool2o`0000;ooooo0_l00002ooooo`Co00003?ooool3o`0000kooooo1?l00000
0ooooooo0000o`00001_ooooo`007?ooool00ol0003oooooooooo`1/ooooo`;o00002?ooool3o`00
0005ooooool0003o0000o`000?ooool00_l0000:ooooo`Co00001Oooool2o`000003ooooool0003o
000000;o00004?ooool2o`0000Sooooo0_l0000<ooooo`?o00003Oooool2o`000004ooooool0003o
0000ooooo`;o00001Oooool4o`0006Kooooo000Looooo`03o`000?oooooooooo07Oooooo0_l00005
ooooo`;o00002_ooool4o`0000Gooooo0_l000000ooooooo0000o`000002o`0001Sooooo0_l00007
ooooo`;o00000_ooool2o`0000Gooooo0_l00004ooooo`;o00001?ooool2o`0000Sooooo0_l00000
0ooooooo0000o`000002o`0000;ooooo0_l0001Rooooo`007?ooool00ol0003oooooooooo`1Yoooo
o`;o00003?ooool2o`0000Gooooo1Ol0000_ooooo`;o00001oooool2o`0000;ooooo0_l00005oooo
o`;o00001?ooool2o`0000_ooooo0_l000000ooooooo0000o`000007ooooo`;o0000H_ooool001co
oooo00?o0000ooooooooool0FOooool2o`0000Cooooo0_l00006ooooo`Co00003?ooool2o`0000Go
oooo1Ol0000Oooooo`;o00007Oooool2o`0000_ooooo1?l000000ooooooo0000o`000004ooooo`;o
0000K_ooool001cooooo00?o0000ooooooooool0FOooool2o`0000Cooooo0_l00006ooooo`;o0000
2?ooool2o`0000?ooooo0ol00005ooooo`;o00000oooool2o`0001gooooo1?l0000=ooooo`;o0000
3?ooool2o`000003ooooool0003o000000Sooooo1?l000000ooooooo0000o`00000>ooooo`?o0000
Hoooool001cooooo00?o0000ooooooooool0Ioooool2o`0000Sooooo0_l00003ooooo`;o00002ooo
ool3o`0000;ooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l0000<ooooo`Co0000
0_ooool2o`0000Wooooo0_l00006ooooo`;o00001oooool3o`0000Sooooo0ol00008ooooo`;o0000
1oooool4o`0006;ooooo000Looooo`;o0000Joooool2o`0001Sooooo0_l000001?oooooo0000o`00
0?l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l0000<ooooo`;o00001?ooool2o`00017o
oooo0_l00008ooooo`?o00000_ooool2o`0000?ooooo0_l00009ooooo`;o00002Oooool2o`0006;o
oooo000Looooo`03o`000?oooooooooo06[ooooo0_l0000Kooooo`;o00001_ooool2o`0000oooooo
0_l0000Oooooo`;o00000oooool2o`0000;ooooo0_l00007ooooo`;o0000M?ooool001cooooo00?o
0000ooooooooool0E?ooool4o`0000kooooo0_l000000ooooooo0000o`000006ooooo`;o00000_oo
ool3o`0000Gooooo1?l0000>ooooo`;o00003oooool2o`00013ooooo0_l0000=ooooo`;o00003ooo
ool3o`0000Gooooo0_l00005ooooo`;o00000_ooool2o`0001?ooooo0_l0001=ooooo`007?ooool0
0ol0003oooooooooo`1Dooooo`Co00003_ooool2o`000003ooooool0003o000000Gooooo0ol00002
ooooo`?o00001Oooool4o`0000Wooooo0ol0000Uooooo`;o00003?ooool2o`0000_ooooo0ol00002
ooooo`;o00001_ooool2o`0000Gooooo0_l00002ooooo`;o00000oooool2o`0000kooooo0ol0001<
ooooo`007?ooool00ol0003oooooooooo`1Xooooo`;o00001Oooool3o`0000;ooooo0_l0000Doooo
o`Ko00004?ooool5o`0000;ooooo0ol0000Aooooo`;o00000oooool2o`0000_ooooo0ol0000Joooo
o`;o00003oooool2o`0004cooooo000Looooo`03o`000?oooooooooo05;ooooo0_l0000>ooooo`Co
00000_ooool2o`000003ooooool0003o000000Ko000000?oooooo`000?l000005_ooool6o`0000ko
oooo1Ol00002ooooo`?o00004Oooool2o`0000Kooooo0_l00008ooooo`;o00000oooool2o`0002So
oooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`1Booooo`;o00002Oooool2o`0000?ooooo
1?l00005ooooo`Co00000_ooool2o`000003ooooool0003o000000oooooo1?l00002ooooo`;o0000
00?oooooo`000?l000000_l0000;ooooo`;o000000?oooooo`000?l000001oooool2o`0001Sooooo
1?l00005ooooo`?o00000oooool2o`0002Sooooo0_l0001;ooooo`007?ooool00ol0003ooooooooo
o`1Mooooo`Co00000oooool2o`0000kooooo0_l0000?ooooo`Co00000_ooool2o`000003ooooool0
003o000000;o00002oooool2o`0000Kooooo0_l00002ooooo`Co000000?oooooo`000?l000005Ooo
ool4o`0000?ooooo0_l0000Pooooo`;o0000FOooool001cooooo00?o0000ooooooooool0G?ooool2
o`000003ooooool0003o000000?ooooo0ol00002ooooo`;o00000_ooool4o`000003ooooool0003o
000000;ooooo1?l00005ooooo`;o00001_ooool3o`0000Wooooo0_l000000ooooooo0000o`000004
ooooo`;o000000?oooooo`000?l000001?ooool2o`0000?ooooo0ol000000ooooooo0000o`00000G
ooooo`;o00001oooool2o`0001Sooooo0_l000001?oooooo0000o`000?l0001Iooooo`007?ooool0
0ol0003oooooooooo`1Looooo`;o00001Oooool4o`0000;ooooo4Ol00005ooooo`;o00001_ooool3
o`0000Wooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000000oooool2
o`0000Cooooo0_l00002ooooo`;o00001?ooool2o`0000?ooooo1?l0000Booooo`?o00003?ooool2
o`0000Kooooo0_l00002ooooo`;o000000Coooooo`000?l0003o0000FOooool001cooooo00?o0000
ooooooooool0E_ooool2o`0000_ooooo0ol00003ooooo`Co00001?ooool2o`000003ooooool0003o
000001gooooo0_l00004ooooo`;o00001?ooool2o`0000?ooooo0_l00005ooooo`;o000000?ooooo
o`000?l000001?ooool2o`0000;ooooo1Ol0000Booooo`;o00002Oooool2o`0000;ooooo0_l00005
ooooo`?o0000HOooool001cooooo00?o0000ooooooooool0E_ooool2o`0000?ooooo0_l00002oooo
o`Co000000?oooooo`000?l000000_l0000Aooooo`;o00000oooool2o`0000?ooooo0_l00004oooo
o`;o00000oooool2o`0000Oooooo1?l00003ooooo`;o00002oooool2o`000003ooooool0003o0000
00Kooooo1?l0000;ooooo`;o00001oooool2o`0000[ooooo0_l000000ooooooo0000o`000005oooo
o`?o00001?ooool2o`0005cooooo000Looooo`03o`000?oooooooooo05Cooooo0_l00005ooooo`;o
000000?oooooo`000?l000000ol00002ooooo`?o00001oooool4o`0000Kooooo0_l00003ooooo`;o
00000oooool2o`0000Cooooo0_l00003ooooo`;o00001oooool2o`0000?ooooo1?l00005ooooo`;o
00001oooool2o`0000Kooooo0_l0000=ooooo`;o00001oooool2o`0000gooooo0_l00005ooooo`;o
00001?ooool3o`0000;ooooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o0000
0oooool2o`0000;ooooo0ol00005ooooo`;o00002?ooool4o`0000Kooooo0_l00003ooooo`;o0000
2?ooool2o`0000?ooooo0_l0000=ooooo`?o00001_ooool2o`0001Oooooo0_l00007ooooo`;o0000
8Oooool2o`0000?ooooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o00000_oo
ool3o`0000[ooooo0_l00004ooooo`;o00001?ooool2o`0000Oooooo0_l00007ooooo`;o00000ooo
ool2o`0000kooooo0_l00002ooooo`;o00000_ooool2o`0000Oooooo0_l0000>ooooo`;o00001ooo
ool2o`0000Oooooo0_l0000?ooooo`;o0000I_ooool001cooooo00?o0000ooooooooool0F_ooool2
o`0000;ooooo0_l0000:ooooo`;o00000oooool3o`0000Cooooo0_l000000ooooooo0000o`000006
o`0000Gooooo1?l00003ooooo`;o00002Oooool2o`0000Oooooo0_l00002ooooo`;o00001oooool2
o`0000?ooooo0_l0000?ooooo`Ko00000_ooool6o`0000oooooo0_l000000ooooooo0000o`000008
ooooo`;o00000_ooool2o`0005Gooooo000Looooo`;o0000A?ooool2o`0001;ooooo0_l000000ooo
oooo0000o`000004ooooo`;o00000_ooool2o`0000Wooooo0_l00005ooooo`;o000000?oooooo`00
0?l000001?l00007ooooo`;o00001Oooool2o`0000Kooooo0_l000000ooooooo0000o`000002oooo
o`;o00004?ooool2o`0000?ooooo0_l0000?ooooo`Ko00000_ooool4o`0001Cooooo0_l00008oooo
o`;o00000_ooool2o`0005Gooooo000Looooo`03o`000?oooooooooo04?ooooo1?l0000@ooooo`;o
00001oooool2o`0000;ooooo0_l0000Fooooo`;o00005oooool2o`0000Gooooo0_l00005ooooo`;o
00005oooool2o`0000;ooooo1_l00007ooooo`;o00003?ooool2o`0000gooooo0_l0000=ooooo`;o
0000C_ooool001cooooo00?o0000ooooooooool0AOooool2o`0000gooooo0_l00002ooooo`;o0000
0_ooool2o`0000Kooooo0_l0000Fooooo`?o00000_ooool2o`0001Sooooo0ol00005ooooo`;o0000
1Oooool2o`000003ooooool0003o000000Kooooo0_l00003ooooo`Go000000?oooooo`000?l00000
1?l00006ooooo`?o00003?ooool4o`0000_ooooo0_l0000=ooooo`;o0000C_ooool001cooooo00?o
0000ooooooooool0E?ooool2o`0000;ooooo0_l00002ooooo`;o00001_ooool2o`0000;ooooo0_l0
000?ooooo`;o00000_ooool6o`000003ooooool0003o000001Cooooo0ol0000<ooooo`?o000000?o
ooooo`000?l000001_ooool2o`0000?ooooo1Ol000001?oooooo0000o`000?ooool3o`0000Kooooo
0_l0000?ooooo`;o000000Coooooo`000?l0003ooooo0_l00008ooooo`;o00002_ooool2o`0004ko
oooo000Looooo`03o`000?oooooooooo05Gooooo0_l00002ooooo`;o00003?ooool3o`0000;ooooo
0_l00006ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`Wo00004?ooool4o`0000Oo
oooo0_l00004ooooo`;o00000oooool2o`0000Sooooo1?l000000ooooooo0000o`000003o`0000;o
oooo2?l0000;ooooo`;o00001oooool2o`000004ooooool0003o0000o`0000Oooooo0_l00006oooo
o`;o0000D_ooool001cooooo00?o0000ooooooooool0EOooool3o`000003ooooool0003o000000Wo
oooo0_l000000ooooooo0000o`000003ooooo`Go00000oooool2o`0000?ooooo2ol000001?oooooo
0000o`000?l0000<ooooo`?o000000?oooooo`000?l000002Oooool2o`0000Wooooo0_l00002oooo
o`?o00000_ooool5o`000003ooooool0003o000000Go000000?oooooo`000?l000001ol00003oooo
o`;o00001?ooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000oooooo0_l00003oooo
o`;o0000COooool001cooooo00?o0000ooooooooool0E_ooool2o`0000cooooo0_l000000ooooooo
0000o`000004ooooo`Co00000_ooool4o`0000;ooooo2ol000000ooooooo0000o`000003ooooo`;o
00002?ooool3o`0000Sooooo0_l0000@oooooaKo00001Oooool2o`0000?ooooo0_l00008ooooo`;o
00000oooool2o`0001Gooooo0_l000000ooooooo0000o`00001=ooooo`007?ooool00ol0003ooooo
ooooo`1Eooooo`;o00003?ooool2o`0000;ooooo0_l0000:oooooa?o000000Coooooo`000?l0003o
oooo0_l0000Cooooo`;o00004?ooool7o`000003ooooool0003o000000ko00000_ooool4o`0001Co
oooo0_l0000Booooo`;o0000D?ooool001cooooo00?o0000ooooooooool0DOooool2o`0000;ooooo
0_l0000<ooooo`;o00000_ooool2o`0000Cooooo0_l00007oooooa?o00004oooool4o`0000gooooo
0_l00002oooooaWo000000?oooooo`000?l000000_l0000Dooooo`;o00002Oooool2o`0000Sooooo
0ol0001>ooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00000_ooool2o`0000oooooo0_l0
0003ooooo`;o00000_ooool4o`0000Oooooo5Ol0000Aooooo`Oo00002_ooool5o`000005ooooool0
003o0000o`000?ooool03ol000001?oooooo0000o`000?l0000Eooooo`;o00002?ooool2o`0000?o
oooo0_l00006ooooo`Go0000C_ooool001cooooo00?o0000ooooooooool0COooool2o`000004oooo
ool0003o0000o`0000oooooo0_l00003ooooo`;o00000_ooool2o`0000Wooooo5Ol000000ooooooo
0000o`00000?ooooo`Ko000000?oooooo`000?l000000_l00002ooooo`;o00000oooool3o`000003
ooooool0003o000001Go00002Oooool2o`0000Oooooo0_l000000ooooooo0000o`000003ooooo`;o
00000oooool2o`0000_ooooo0_l000000ooooooo0000o`00001>ooooo`007?ooool00ol0003ooooo
ooooo`1@ooooo`Co00001oooool2o`0000Gooooo0_l00003ooooo`Co00002_oooolEo`0000;ooooo
0_l0000=ooooo`Co00000_ooool2o`000003ooooool0003o000000;o00000_ooool2o`0000?ooooo
6ol00002ooooo`;o00001Oooool2o`0000Kooooo0ol00006ooooo`;o00001Oooool2o`0000Kooooo
0_l00004ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0Aoooool2o`0000Gooooo0_l0
0002ooooo`;o00001oooool2o`0000?ooooo1?l00005ooooo`;o00001_ooool2o`0000;ooooo5Ol0
0002ooooo`;o00002oooool4o`0000Cooooo0ol0000;oooooaco000000?oooooo`000?l000003Ooo
ool2o`0000?ooooo0_l00009ooooo`;o00001_ooool5o`0000?ooooo0_l0000@ooooo`;o0000>_oo
ool001cooooo00?o0000ooooooooool0Aoooool2o`000003ooooool0003o000000;ooooo0_l0000@
ooooo`;o00000oooool2o`0000[ooooo0_l00002oooooa7o000000?oooooo`000?l000000ol00007
ooooo`;o00001?ooool2o`0000Oooooo0_l0000;ooooo`;o000000?oooooo`000?l000002ol00000
0ooooooo0000o`00000:o`0000;ooooo0_l00002ooooo`;o00003?ooool2o`0000gooooo0_l00003
ooooo`Co000000?oooooo`000?l000000_l000000ooooooo0000o`00000=ooooo`;o0000>_ooool0
01cooooo00?o0000ooooooooool0B_ooool2o`0000Cooooo0_l0000=ooooo`;o00000oooool3o`00
00gooooo6_l00002ooooo`;o000000?oooooo`000?l000000oooool2o`0001Gooooo6?l00003oooo
o`;o00000_ooool2o`0000;ooooo0_l00008ooooo`;o00002_ooool2o`0000Gooooo0_l00008oooo
o`;o00000oooool2o`0004Wooooo000Looooo`03o`000?oooooooooo053ooooo0_l0000=ooooo`;o
00000oooool2o`0000kooooo6_l00002ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`00
01Gooooo6Ol0000Dooooo`?o00002Oooool2o`0000Cooooo0ol0000>ooooo`;o0000B?ooool001co
oooo0_l0001@ooooo`Co00008OoooolHo`000004ooooool0003o0000o`0000?ooooo1Ol00003oooo
o`?o00004?ooool3o`000003ooooool0003o000001Oo00003oooool7o`000003ooooool0003o0000
00[ooooo0_l0000?ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0@oooool2o`0000Oo
oooo0_l000000ooooooo0000o`000002o`00027ooooo5ol000000ooooooo0000o`000002o`0000;o
oooo1_l00003ooooo`Co00000oooool4o`0000Cooooo8ol00004ooooo`;o00001_ooool5o`000004
ooooool0003o0000ooooo`?o00003Oooool2o`0000_ooooo0ol000000ooooooo0000o`000014oooo
o`007?ooool00ol0003oooooooooo`13ooooo`;o000000?oooooo`000?l000001?ooool2o`0000;o
oooo0_l00004ooooo`;o00004Oooool2o`0000Wooooo6ol00003ooooo`;o00000oooool2o`0000Co
oooo0_l00003ooooo`Co00001?oooolFo`000003ooooool0003o000000_o00000oooool2o`0000Ko
oooo0_l00004ooooo`;o00000_ooool2o`0000?ooooo0_l00008ooooo`;o00002_ooool4o`000003
ooooool0003o000000Kooooo0_l0000looooo`007?ooool00ol0003oooooooooo`16ooooo`;o0000
00?oooooo`000?l000000ol000001?oooooo0000o`000?l00004ooooo`;o00004Oooool2o`0000Wo
oooo6?l0000;ooooo`;o00003oooool2o`0000?ooooo0_l000000ooooooo0000o`00000Mo`0000co
oooo0_l00007ooooo`Ko00004Oooool2o`000003ooooool0003o000000_ooooo0_l00004ooooo`;o
0000=_ooool001cooooo00?o0000ooooooooool0>Oooool2o`0000_ooooo0_l000000ooooooo0000
o`000002o`0000;ooooo0_l00005ooooo`;o00006ooooolJo`0000;ooooo0_l00002ooooo`;o0000
00?oooooo`000?l000004?ooool2o`0000Kooooo3?l000000ooooooo0000o`00000<o`0000;ooooo
0_l000000ooooooo0000o`000006ooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`Go
00000_ooool2o`0000Sooooo0_l00004ooooo`Co00004_ooool2o`0003Kooooo000Looooo`03o`00
0?oooooooooo03Kooooo0_l000000ooooooo0000o`00000@ooooo`;o00002Oooool2o`0000Kooooo
0_l0000Coooooa[o000000Coooooo`000?l0003o00000_ooool5o`0001Oooooo7?l00005ooooo`;o
00001_ooool2o`0000Cooooo0_l000000ooooooo0000o`000008ooooo`;o00002?ooool2o`0000Ko
oooo0_l00005ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0=_ooool2o`0000kooooo
0_l000000ooooooo0000o`000002o`0000Oooooo1?l00006ooooo`;o00005?oooolHo`0000;ooooo
1?l00002ooooo`;o00002?ooool2o`0000gooooo7?l000000ooooooo0000o`000004ooooo`;o0000
3?ooool2o`000003ooooool0003o000000Sooooo0_l00003ooooo`;o00002_ooool2o`0000Kooooo
0_l00013ooooo`007?ooool00ol0003oooooooooo`14ooooo`Co000000?oooooo`000?l000002Ooo
ool2o`00023ooooo2Ol000000ooooooo0000o`00000:o`0000;ooooo1?l00002ooooo`;o00002?oo
ool2o`0000gooooo7ol0000>ooooo`;o000000Coooooo`000?l0003o00002oooool2o`0000?ooooo
0_l0000:ooooo`Co0000BOooool001cooooo00?o0000ooooooooool0A?ooool3o`0002gooooo2ol0
00000ooooooo0000o`000005o`0000Oooooo1?l00002ooooo`;o00005?ooool4o`0000;ooooo6_l0
000>ooooo`Co000000?oooooo`000?l000003?ooool2o`00017ooooo0_l0000Cooooo`;o0000=?oo
ool001cooooo00?o0000ooooooooool0@oooool3o`0002?ooooo0_l00008oooooaKo000000?ooooo
o`000?l000002?ooool2o`0000[ooooo0_l00004ooooo`;o00000_ooool4o`0000;ooooo5Ol00008
ooooo`;o00001?ooool2o`0000?ooooo0_l00004ooooo`;o00002?ooool2o`000003ooooool0003o
000001Cooooo0_l0000@ooooo`?o000000?oooooo`000?l00000<?ooool001cooooo00?o0000oooo
ooooool0=?ooool2o`0000gooooo1?l0000?ooooo`;o00002oooool2o`0000Cooooo0_l00008oooo
oaWo00002Oooool2o`0000Wooooo0_l00004ooooo`;o00002_oooolEo`000003ooooool0003o0000
00;ooooo0ol00004ooooo`;o00000_ooool2o`0000Gooooo0_l00008ooooo`Go00004?ooool2o`00
00;ooooo0_l0000@ooooo`?o000000?oooooo`000?l00000<?ooool001cooooo00?o0000oooooooo
ool0=?ooool2o`0000[ooooo0ol00002ooooo`Co00000oooool2o`0000Sooooo0_l00004ooooo`;o
00000_ooool5o`0000Cooooo0_l0000:oooooaGo00002oooool2o`000003ooooool0003o000000Co
oooo0_l00006ooooo`;o00002_oooolEo`000003ooooool0003o000000;ooooo0_l00009ooooo`;o
000000?oooooo`000?l000001oooool2o`0000Cooooo1?l00009ooooo`;o00001Oooool2o`0000Ko
oooo0_l0000<ooooo`;o0000=?ooool001cooooo00?o0000ooooooooool0<oooool2o`0000_ooooo
0ol00004ooooo`;o00000oooool2o`0000Sooooo0_l00004ooooo`;o00000_ooool4o`0000Gooooo
0_l0000=oooooa7o00003oooool2o`0000Cooooo1?l00004ooooo`;o00002OoooolIo`0000;ooooo
0_l00002ooooo`;o00002?ooool2o`0000Oooooo0_l0000<ooooo`;o000000?oooooo`000?l00000
0_l0000=ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0;Oooool2o`0000Cooooo0_l0
000=ooooo`;o00002?ooool2o`000003ooooool0003o000000Wooooo0_l000000ooooooo0000o`00
000Iooooo`go000000Coooooo`000?l0003o00003Oooool2o`0000Sooooo0_l0000?oooooa7o0000
1?ooool4o`0000Kooooo0_l00007ooooo`;o00000_ooool2o`0000Oooooo0_l00009ooooo`;o0000
00?oooooo`000?l000000_l0001Aooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o
8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0;Oooool2o`0001?o
oooo1Ol00008ooooo`;o00002Oooool2o`000003ooooool0003o000000Kooooo0_l0000Aooooo`[o
000000Coooooo`000?l0003ooooo0ol0000=ooooo`;o00001_ooool2o`0000gooooo3_l000000ooo
oooo0000o`000007o`0001Cooooo0_l00002ooooo`;o000000?oooooo`000?l000001?ooool2o`00
00;ooooo0_l00002ooooo`;o00002Oooool2o`0000;ooooo0ol00019ooooo`0000KoooooogMgMonH
V9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo03oooooo0_l00003ooooo`?o00005oooool2o`0000Gooooo1Ol0000>ooooo`So00001oooool2
o`0000[ooooo0_l00007ooooo`Go000000Coooooo`000?l0003o00001Oooool2o`000003ooooool0
003o000001Wo00000_ooool2o`000003ooooool0003o000000Wooooo0_l00006ooooo`;o00002?oo
ool3o`000003ooooool0003o000000;o00001_ooool3o`0000;ooooo0ol00002ooooo`;o0000AOoo
ool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo00?o0000
ooooooooool0?oooool2o`0000Gooooo1?l0000Dooooo`;o00001_ooool4o`0000kooooo1ol0000D
ooooo`;o00001oooool2o`000004ooooool0003o0000ooooo`?o00001Oooool2o`0000;ooooo0ol0
0002oooooa7o000000Coooooo`000?l0003o00000_ooool5o`0000Wooooo0_l0000?ooooo`Co0000
0oooool2o`0000Kooooo0_l00008ooooo`Co00000oooool2o`0003kooooo00000ooooooo0000oooo
o`02ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`0004Kooooo
1?l0000Kooooo`;o00005?ooool4o`0000gooooo0_l0000Booooo`Go00002Oooool3o`0000;ooooo
1ol00002ooooo`So00002?ooool2o`0001_ooooo0_l00009ooooo`;o00003_ooool2o`0000?ooooo
0_l0000;ooooo`;o0000<Oooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Ooo
ool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo02Wooooo0_l0000Looooo`Co0000
00?oooooo`000?l000005oooool2o`0000Wooooo1?l0000Hooooo`;o00004_ooool7o`0000cooooo
1ol000001?oooooo0000o`000?ooool2o`0000Cooooo0_l0000:ooooo`;o00001_ooool2o`0000ko
oooo1?l00008ooooo`;o00001Oooool2o`0000Cooooo0_l00002ooooo`;o00003oooool2o`00037o
oooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oMgMgolc<c?l00000
1oooool00ol0003oooooooooo`0Yooooo`;o00004?ooool2o`0000_ooooo0ol000000ooooooo0000
o`000008ooooo`;o00006?ooool4o`0000Gooooo0ol00004ooooo`;o00003oooool2o`0000Sooooo
0_l00008ooooo`;o00003?ooool7o`000004ooooool0003o0000ooooo`;o00000_ooool4o`0000?o
oooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l000000ooooooo
0000o`00000;ooooo`Co00002oooool2o`0000;ooooo0_l00004ooooo`;o00000_ooool2o`0000Co
oooo1?l0000jooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co0000
00Oooooo00?o0000ooooooooool0>oooool2o`0001?ooooo0ol00003ooooo`;o000000?oooooo`00
0?l000002?ooool3o`0000Oooooo0_l0000:ooooo`?o00001?ooool2o`0000Kooooo0_l00004oooo
o`;o000000?oooooo`000?l000000oooool2o`0000?ooooo0_l0000Booooo`;o00000_ooool4o`00
00?ooooo0_l00002ooooo`?o000000?oooooo`000?l000000oooool4o`0000;ooooo0_l00005oooo
o`;o000000?oooooo`000?l000000_ooool2o`0000Kooooo0_l0000Booooo`;o00001Oooool2o`00
00Gooooo0_l00004ooooo`Co0000>_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool0
0omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo02gooooo0_l00008ooooo`;o00002oooool2
o`0000[ooooo0ol00004ooooo`Co00002?ooool3o`0000Oooooo0_l0000Iooooo`;o00000oooool3
o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000005?ooool2o`0000;ooooo0_l00004
ooooo`?o00000_ooool3o`0000Kooooo0_l00004ooooo`;o00002?ooool2o`0000[ooooo0_l00003
ooooo`;o00005?ooool2o`0000cooooo0_l0000=ooooo`;o0000;?ooool001cooooo00?o0000oooo
ooooool0;Oooool2o`0000Sooooo0_l000000ooooooo0000o`000005ooooo`Go00002?ooool3o`00
00Kooooo0_l0000<ooooo`Go00008oooool2o`0000?ooooo0_l00005ooooo`;o00007_ooool6o`00
00?ooooo0_l0000Oooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`;o00001?ooool2o`00
00kooooo0_l00004ooooo`;o00003Oooool2o`0002cooooo000Looooo`03o`000?oooooooooo03[o
oooo0_l00005ooooo`Co00001_ooool2o`000004ooooool0003o0000o`0000gooooo0_l00005oooo
o`Go00006oooool2o`0001?ooooo0ol00005ooooo`?o00001oooool2o`0000;ooooo0_l00009oooo
o`Co00000oooool4o`0001Cooooo0_l00007ooooo`?o00001_ooool2o`0000;ooooo0_l00004oooo
o`;o00000_ooool2o`0000[ooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o
00000oooool2o`0000Sooooo1ol0000;ooooo`;o00004?ooool2o`0000Gooooo0_l0000Booooo`Co
00001?ooool5o`0000Kooooo0_l00002ooooo`;o00001_ooool9o`0000?ooooo0_l00002ooooo`Co
00003_ooool2o`0000Sooooo0_l0000:ooooo`;o00002?ooool2o`0000oooooo1?l0000jooooo`00
7?ooool00ol0003oooooooooo`0nooooo`;o00001Oooool2o`0000Wooooo0_l00008ooooo`Oo0000
2oooool2o`00013ooooo0_l0000>ooooo`;o000000?oooooo`000?l000001_ooool3o`0000?ooooo
1ol00006ooooo`;o000000?oooooo`000?l000000oooool2o`0000;ooooo1?l000000ooooooo0000
o`000002o`0000Oooooo1?l0000Cooooo`;o00001?ooool2o`0000kooooo0_l00005ooooo`;o0000
2_ooool2o`000003ooooool0003o000000;o0000>_ooool001cooooo00?o0000ooooooooool09?oo
ool2o`0001;ooooo0_l00002ooooo`Co00001Oooool2o`0001Kooooo0ol00007ooooo`;o00007Ooo
ool2o`0000Kooooo0_l000000ooooooo0000o`000003o`0000Wooooo1Ol00008ooooo`Go00000ooo
ool2o`0000Kooooo0_l00003ooooo`;o00007?ooool2o`0000Cooooo0_l00002ooooo`;o00002_oo
ool2o`0000Gooooo0_l00009ooooo`?o00001_ooool2o`0003Oooooo000Looooo`03o`000?oooooo
oooo02Cooooo0_l0000Booooo`;o00000_ooool2o`0000Sooooo1?l0000Dooooo`Co00001Oooool5
o`0001Kooooo0_l00002ooooo`;o00002oooool3o`0000Kooooo0_l000001?oooooo0000o`000?l0
000<ooooo`;o00000_ooool2o`0000Sooooo1?l000000ooooooo0000o`00000Vooooo`;o00002_oo
ool2o`00013ooooo0_l00002ooooo`;o00000oooool2o`0003Oooooo000Looooo`03o`000?oooooo
oooo04Kooooo1?l0000>ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000005
ooooo`Go00002_ooool2o`0000[ooooo0_l00008ooooo`;o00001oooool2o`0000Gooooo1_l0000@
ooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`;o00001oooool2o`0002Kooooo0_l0
0004ooooo`;o00000_ooool4o`0000kooooo0_l0000looooo`007?ooool00ol0003oooooooooo`0n
ooooo`;o00001_ooool4o`0000[ooooo0_l000001Ooooooo0000o`000?l0003ooooo00Oo00001Ooo
ool4o`0000_ooooo0_l0000Dooooo`;o00001oooool2o`0000Oooooo1?l000000ooooooo0000o`00
000Cooooo`;o000000?oooooo`000?l000002_ooool2o`0000;ooooo0_l0000Rooooo`Co00001_oo
ool4o`0004cooooo000Looooo`03o`000?oooooooooo03kooooo0_l00006ooooo`Co00002_ooool2
o`000003ooooool0003o000000Gooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo1_l0
000Kooooo`;o00004?ooool6o`000004ooooool0003o0000ooooo`;o00007oooool2o`0000;ooooo
0_l0000Tooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0=_ooool2o`0000[ooooo0_l0
00000ooooooo0000o`000002o`0000;ooooo0_l00002ooooo`;o00001_ooool2o`0000Sooooo0_l0
00000ooooooo0000o`000005ooooo`Co00000oooool2o`0000gooooo0_l00007ooooo`Co00001_oo
ool2o`0000Kooooo1_l00002ooooo`Ko00005_ooool2o`0000Gooooo0_l00009ooooo`;o00007_oo
ool2o`0000;ooooo0_l000000ooooooo0000o`00001>ooooo`007?ooool00ol0003oooooooooo`0[
ooooo`;o00002Oooool2o`0000Gooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool4
o`0000;ooooo1?l00006ooooo`;o00001_ooool7o`000003ooooool0003o000000Wo00001Oooool2
o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`?o00000_ooool2o`0000Kooooo0_l00006
ooooo`;o000000Coooooo`000?l0003o00000_ooool3o`000003ooooool0003o000000[ooooo0_l0
000:ooooo`;o00001_ooool2o`0000Sooooo0_l0000Nooooo`;o000000Goooooo`000?l0003o0000
ooooo`02o`0000Kooooo1?l00003ooooo`;o0000?oooool001cooooo0_l0000/ooooo`;o00002Ooo
ool2o`0000?ooooo1?l0000:ooooo`;o00001_ooool2o`0000Kooooo0_l00005ooooo`So000000?o
ooooo`000?l000002?l00005ooooo`?o00000oooool2o`000004ooooool0003o0000o`0000?ooooo
0ol00004ooooo`;o00003?ooool2o`0000Oooooo0_l00002ooooo`;o000000?oooooo`000?l00000
0_ooool2o`0000;ooooo0_l0000:ooooo`;o00001_ooool2o`000003ooooool0003o000002Kooooo
1?l00007ooooo`Oo00000oooool2o`0001Kooooo0_l0000Wooooo`007?ooool00ol0003ooooooooo
o`0kooooo`;o00003?ooool2o`0000_ooooo1?l00006ooooo`Wo000000?oooooo`000?l000001Ol0
0007ooooo`;o00001oooool3o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o00003?oo
ool2o`0000Wooooo1?l000001Ooooooo0000o`000?l0003ooooo00;o00001?ooool2o`0000Sooooo
1?l00003ooooo`;o00000_ooool2o`0002Kooooo0_l00009ooooo`Ko00001Oooool2o`0001Gooooo
0_l0000Wooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00000_ooool5o`000003ooooool0
003o000000_ooooo1?l00008ooooo`Oo000000?oooooo`000?l000001_l00004ooooo`;o000000?o
ooooo`000?l000002_ooool2o`0000?ooooo0ol0000Aooooo`;o00000_ooool7o`0000Cooooo0_l0
0007ooooo`;o00002?ooool5o`0000;ooooo0_l0000gooooo`Co00000_ooool2o`000003ooooool0
003o000003kooooo000Looooo`03o`000?oooooooooo02[ooooo0_l00007ooooo`;o00001Oooool3
o`0000;ooooo0_l00002ooooo`Go00000_ooool2o`0000[ooooo0_l000001?oooooo0000o`000?oo
ool2o`0000;ooooo0_l00003ooooo`Co000000?oooooo`000?l000001_l00004ooooo`;o000000?o
ooooo`000?l000000_l000000ooooooo0000o`00000:ooooo`?o00003?ooool2o`0000?ooooo0_l0
0002ooooo`Ko00000oooool2o`0000Kooooo0_l0000>ooooo`;o00002Oooool2o`00033ooooo0ol0
0003ooooo`;o00000_ooool2o`000003ooooool0003o000003[ooooo000Looooo`03o`000?oooooo
oooo02[ooooo0_l00007ooooo`;o00001Oooool3o`0000Gooooo1Ol00003ooooo`;o00003Oooool2
o`000003ooooool0003o000000;ooooo0_l00003ooooo`Co000000?oooooo`000?l000001_l00006
ooooo`So00001?ooool2o`0000?ooooo0_l00007ooooo`;o00001Oooool2o`0000Oooooo0_l00003
ooooo`;o00000_ooool2o`0000Kooooo0_l000000ooooooo0000o`00000Fooooo`;o00001_ooool2
o`0002?ooooo0_l00004ooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`;o0000>_oo
ool001cooooo00?o0000ooooooooool0@_ooool2o`0000Oooooo1?l0000Gooooo`?o000000?ooooo
o`000?l000001_l00006ooooo`?o00000_ooool3o`0000Cooooo0_l00003ooooo`Co00001Oooool2
o`0000kooooo0_l00003ooooo`?o00001?ooool2o`0000Kooooo0_l0000<ooooo`;o00004?ooool3
o`0002;ooooo0_l00003ooooo`;o00001Oooool2o`000003ooooool0003o000003gooooo000Loooo
o`03o`000?oooooooooo02[ooooo0_l000000ooooooo0000o`00000>ooooo`;o00002oooool6o`00
01Cooooo1?l000000ooooooo0000o`000009o`00017ooooo0_l00004ooooo`;o00001?ooool2o`00
01Cooooo1Ol00002ooooo`;o00002?ooool2o`0000[ooooo0_l00003ooooo`;o00002Oooool2o`00
0003ooooool0003o000002Oooooo0_l0000=ooooo`;o0000>?ooool001cooooo00?o0000oooooooo
ool0:_ooool2o`000003ooooool0003o000000_ooooo0_l000000ooooooo0000o`00000;ooooo`;o
00000_ooool2o`0000;ooooo0ol00002ooooo`;o00002oooool2o`0000?ooooo2ol0000Aooooo`;o
00000oooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o00002Oooool2o`0000?o
oooo1Ol000000ooooooo0000o`000009ooooo`;o00002_ooool4o`000003ooooool0003o000000;o
00001oooool2o`0001cooooo0_l00002ooooo`Co00000_ooool2o`000004ooooool0003o0000o`00
00gooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00001Oooool5o`000003
ooooool0003o000000cooooo0_l00002ooooo`?o00000_ooool3o`0000oooooo2_l0000Gooooo`;o
000000?oooooo`000?l000002?ooool2o`000003ooooool0003o000000Kooooo0_l00004ooooo`?o
00000_ooool2o`0001?ooooo0_l00002ooooo`Oo00000_ooool2o`00027ooooo0_l00002ooooo`Co
00000_ooool2o`000004ooooool0003o0000o`0000Oooooo0_l00006ooooo`;o00004Oooool2o`00
02?ooooo000Looooo`03o`000?oooooooooo03?ooooo0_l00004ooooo`Co00000oooool2o`0000co
oooo1Ol00005ooooo`?o00003?ooool7o`000003ooooool0003o000000;o00003oooool2o`0000Ko
oooo0_l00005ooooo`;o00001oooool3o`0000Cooooo0_l00006ooooo`?o00005_ooool3o`000003
ooooool0003o000000?o00000_ooool4o`0003Sooooo0_l00006ooooo`;o00004Oooool2o`0002?o
oooo000Looooo`03o`000?oooooooooo03Sooooo0ol0000:ooooo`;o00001oooool7o`0000Cooooo
0_l00002ooooo`;o00001Oooool2o`000003ooooool0003o000000[o00000_ooool2o`0000_ooooo
0_l00006ooooo`;o00001Oooool2o`0000Sooooo0_l00003ooooo`?o00001?ooool5o`0000;ooooo
0ol00003ooooo`Wo00001_ooool6o`0000Cooooo0_l0000Sooooo`;o000000?oooooo`000?l00000
5_ooool2o`0003[ooooo000Looooo`03o`000?oooooooooo02cooooo0_l0000:ooooo`;o000000?o
ooooo`000?l000001_ooool4o`0000?ooooo0_l00006ooooo`?o00002?ooool2o`0000Gooooo0_l0
00000ooooooo0000o`000002o`000003ooooool0003o000000Go00000_ooool2o`0000[ooooo0_l0
0005ooooo`;o00001Oooool2o`0000[ooooo0_l00002ooooo`?o00000_ooool2o`000004ooooool0
003o0000ooooo`;o00000_ooool3o`0000?ooooo2Ol00002ooooo`?o000000?oooooo`000?l00000
1?l00007ooooo`;o00002?ooool3o`0001Gooooo0_l000000ooooooo0000o`00000Eooooo`?o0000
>_ooool001cooooo00?o0000ooooooooool0;?ooool2o`0000gooooo0_l00006ooooo`;o00001Ooo
ool2o`0001_ooooo1?l000000ooooooo0000o`000005o`0000kooooo0_l00005ooooo`;o00001Ooo
ool2o`0000[ooooo0_l00002ooooo`Co000000?oooooo`000?l000001?ooool2o`0000[ooooo1?l0
00000ooooooo0000o`000002ooooo`?o000000?oooooo`000?l000000ol00008ooooo`Co00001_oo
ool3o`0001;ooooo0_l000000ooooooo0000o`000006ooooo`;o00004?ooool2o`0003_ooooo000L
ooooo`03o`000?oooooooooo03[ooooo0_l0000@ooooo`;o00001_ooool2o`0000Sooooo0_l00009
ooooo`[o0000:oooool2o`000004ooooool0003o0000o`0000[ooooo0_l00004ooooo`Wo00000ooo
ool2o`000003ooooool0003o000000Co00001_ooool2o`000003ooooool0003o000001_ooooo0_l0
0009ooooo`;o00001Oooool2o`0000Cooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0e
ooooo`;o00000oooool2o`0000oooooo0ol00006ooooo`;o00001Oooool2o`000003ooooool0003o
000000;ooooo1?l00003ooooo`[o00002_ooool2o`0001_ooooo0_l00002ooooo`;o00000_ooool2
o`0000[ooooo0_l00004ooooo`Oo00001?ooool:o`0000Kooooo0_l0000`ooooo`;o00001?ooool3
o`0000Gooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0_ooooo`Co00000_ooool3o`00
00Wooooo0_l00008ooooo`;o000000?oooooo`000?l000002oooool2o`0000Gooooo1?l00006oooo
o`So00000oooool4o`0000;ooooo0_l0000Kooooo`;o000000?oooooo`000?l000001Oooool2o`00
00Cooooo0_l00008ooooo`Go00001_ooool5o`0000Wooooo0_l000000ooooooo0000o`000002oooo
o`;o00008_ooool2o`0000Gooooo0_l00007ooooo`;o00001Oooool2o`0003Sooooo000Looooo`;o
0000<?ooool4o`0000?ooooo0_l00009ooooo`;o00001oooool6o`0000gooooo0_l00002ooooo`;o
00002_ooool7o`0000?ooooo1_l0000Hooooo`?o00001Oooool2o`0000Gooooo0_l00004ooooo`;o
00000oooool4o`000004ooooool0003o0000ooooo`;o000000Coooooo`000?l0003ooooo2?l00005
ooooo`Go000000?oooooo`000?l000000_ooool2o`0002;ooooo0_l00005ooooo`;o00001Oooool2
o`00047ooooo000Looooo`03o`000?oooooooooo03Kooooo0ol000000ooooooo0000o`00000>oooo
o`Co00003oooool2o`000004ooooool0003o0000o`0000Sooooo2Ol00007ooooo`;o00001?ooool2
o`0001;ooooo0ol0000?ooooo`;o000000Coooooo`000?l0003o00000_ooool4o`000003ooooool0
003o000000;ooooo2_l000000ooooooo0000o`000004ooooo`Co00001Oooool6o`00023ooooo0_l0
000<ooooo`?o0000@?ooool001cooooo00?o0000ooooooooool0=_ooool3o`000003ooooool0003o
000000Wooooo0_l00003ooooo`;o00004oooool3o`0000?ooooo0_l00004ooooo`Wo00000_ooool2
o`0000?ooooo0_l00004ooooo`;o00001Oooool2o`0001cooooo0ol00002ooooo`;o00001?ooool2
o`0000?ooooo1?l000000ooooooo0000o`000004o`000004ooooool0003o0000o`0000Cooooo0_l0
0002ooooo`;o00000oooool2o`0000;ooooo0_l0000Rooooo`;o00002oooool2o`00043ooooo000L
ooooo`03o`000?oooooooooo03;ooooo0_l0000Aooooo`;o00006?ooool2o`0000Cooooo0_l00006
ooooo`Oo00000_ooool2o`00013ooooo0_l0000Booooo`;o00002?ooool2o`0000Wooooo0ol00002
ooooo`_o000000?oooooo`000?l000000_l00007ooooo`;o00000oooool2o`0000Kooooo0_l0000F
ooooo`Co00001?ooool2o`0000?ooooo0_l00008ooooo`;o00006oooool2o`00027ooooo000Loooo
o`03o`000?oooooooooo03;ooooo0_l00002ooooo`;o00004?ooool2o`0002?ooooo1?l000000ooo
oooo0000o`000002o`0001cooooo0_l00008ooooo`?o00004?oooolGo`000003ooooool0003o0000
00;o000000?oooooo`000?l000000ol000000ooooooo0000o`000006ooooo`;o00001?ooool2o`00
00gooooo0_l000000ooooooo0000o`000002o`0000Wooooo0_l00006ooooo`Co00001Oooool2o`00
01Cooooo0_l0000Qooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00004?ooool2o`0001go
oooo0_l00005ooooo`Wo00001oooool2o`0001;ooooo0_l00009ooooo`;o000000?oooooo`000?l0
00001_ooool2o`0000Gooooo9?l0000=ooooo`Co00002oooool2o`0000;ooooo0_l0000Booooo`;o
00001oooool2o`0003Oooooo000Looooo`03o`000?oooooooooo02Sooooo0_l000000ooooooo0000
o`00000>ooooo`;o00008_ooool2o`0000Kooooo0ol000000ooooooo0000o`00000;o`0000Kooooo
0_l00002ooooo`;o00007?ooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o0000
00?oooooo`000?l000005ol000000ooooooo0000o`000008o`0000oooooo0ol0000>ooooo`;o0000
3oooool2o`0000Oooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`0Xooooo`;o000000?o
ooooo`000?l000002_ooool2o`0000;ooooo0_l0000Cooooo`;o00003Oooool4o`0000?ooooo1?l0
00000ooooooo0000o`000004o`000003ooooool0003o000000Co00002_ooool2o`00017ooooo0_l0
0007ooooo`;o00001Oooool5o`000005ooooool0003o0000o`000?ooool03?l000000ooooooo0000
o`00000:o`000004ooooool0003o0000ooooo`?o00000_ooool2o`00013ooooo0_l0000=ooooo`;o
00004?ooool2o`0000Oooooo0_l0000Iooooo`;o00007oooool001cooooo00?o0000ooooooooool0
=oooool2o`0001Kooooo0ol00002ooooo`;o00002oooool2o`0000?ooooo1ol00002ooooo`So0000
1?ooool2o`0001Sooooo0_l00003ooooo`;o00000_ooool2o`0000Gooooo2Ol00003oooooako0000
0_ooool2o`0000;ooooo0_l0000>ooooo`;o00002oooool4o`0000;ooooo0_l00006ooooo`;o0000
1oooool2o`0001gooooo0_l0000Oooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o00000ooo
ool2o`0000?ooooo0_l0000?ooooo`;o000000?oooooo`000?l000003Ol00004ooooo`?o00006ooo
ool3o`0000cooooo1ol000000ooooooo0000o`00000Mo`0000Kooooo0_l00006ooooo`;o00001_oo
ool2o`0000Sooooo0_l00003ooooo`;o00000_ooool2o`0000Kooooo0_l00007ooooo`?o0000?Ooo
ool001cooooo00?o0000ooooooooool0<oooool2o`0001Cooooo0ol00005ooooo`;o00000_ooool2
o`0000cooooo1?l000000ooooooo0000o`00000?o`0000?ooooo0_l00003ooooo`;o00005_ooool2
o`0000kooooo1_l000000ooooooo0000o`000002o`000003ooooool0003o0000017o00000oooool3
o`0000?ooooo0_l00003ooooo`;o00001Oooool3o`0000oooooo1?l0000Gooooo`;o0000?Oooool0
01cooooo00?o0000ooooooooool0:oooool2o`0000Kooooo0_l0000Dooooo`;o00001_ooool2o`00
00;ooooo0_l0000<oooooaOo00001oooool2o`000003ooooool0003o0000013ooooo0_l00007oooo
o`;o00002?ooool6o`0000;ooooo6_l00002ooooo`;o00000_ooool2o`0000?ooooo0_l00006oooo
o`;o00004Oooool2o`0000Cooooo0ol00006ooooo`;o0000Aoooool001cooooo00?o0000oooooooo
ool0:oooool2o`0000?ooooo0ol0000Fooooo`;o00006?oooolCo`000004ooooool0003o0000o`00
00Oooooo0_l000000ooooooo0000o`00000@ooooo`?o00001?ooool6o`0000Sooooo8?l00002oooo
o`?o00000oooool4o`0000Wooooo1?l000000ooooooo0000o`00000@ooooo`?o00001Oooool3o`00
04Oooooo000Looooo`03o`000?oooooooooo033ooooo1?l00003ooooo`;o00008Oooool2o`0000Oo
oooo4ol000000ooooooo0000o`000008ooooo`;o00005?ooool2o`0000Cooooo0_l00002ooooo`;o
00002?ooool2o`000003ooooool0003o000001_o000000?oooooo`000?l000000ol00002ooooo`Co
00002Oooool4o`000003ooooool0003o000000oooooo0_l00007ooooo`?o00002_ooool2o`0003_o
oooo000Looooo`03o`000?oooooooooo033ooooo1?l00002ooooo`?o00005?ooool2o`0000_ooooo
0_l00006ooooo`;o000000?oooooo`000?l000005ol0000?ooooo`;o00000oooool3o`000003oooo
ool0003o000000cooooo0_l000000ooooooo0000o`000002ooooobKo00000_ooool2o`000003oooo
ool0003o000000;o00000oooool2o`0000Kooooo0_l000000ooooooo0000o`00000<ooooo`;o0000
3_ooool2o`000004ooooool0003o0000ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0
<?ooool2o`0000Cooooo1Ol0000Booooo`;o00002?ooool2o`0000Wooooo0_l000000ooooooo0000
o`00000Go`0000oooooo0_l00003ooooo`?o000000?oooooo`000?l000003?ooool5o`0000Cooooo
3ol000000ooooooo0000o`00000@o`0000Oooooo1?l00003ooooo`;o00001_ooool2o`000003oooo
ool0003o000001cooooo0_l000001?oooooo0000o`000?ooool2o`0003_ooooo000Looooo`;o0000
>Oooool3o`0001Gooooo0_l00005ooooo`;o00003_ooool6o`0000;ooooo0_l000000ooooooo0000
o`000009o`0000gooooo0_l00006ooooo`;o00002_ooool2o`0000Gooooo5_l00003oooooa7o0000
0_ooool3o`0000Wooooo0_l00002ooooo`Co00000oooool2o`0001Wooooo0_l000001?oooooo0000
o`000?ooool2o`000003ooooool0003o000003_ooooo000Looooo`03o`000?oooooooooo04Wooooo
0_l00005ooooo`;o00005Oooool9o`000003ooooool0003o000000[o00003Oooool2o`0000Kooooo
0_l00004ooooo`;o00001?ooool2o`0000Kooooo5Ol00002oooooaOo00002Oooool2o`0000;ooooo
1?l0000Aooooo`;o00001oooool2o`0000;ooooo0_l000000ooooooo0000o`000003o`000003oooo
ool0003o000003_ooooo000Looooo`03o`000?oooooooooo023ooooo0_l0000Oooooo`Ko00000_oo
ool2o`0000Gooooo0_l00009ooooo`;o00002ooooolDo`0001Gooooo0_l00005ooooo`;o00002ooo
ool3o`0000;ooooo2_l000000ooooooo0000o`00000Mo`0000;ooooo0ol00002ooooo`?o00001Ooo
ool2o`0000Cooooo0_l00006ooooo`;o00000oooool4o`0000Gooooo0_l000000ooooooo0000o`00
0004ooooo`;o0000?oooool001cooooo00?o0000ooooooooool08?ooool2o`0001oooooo1_l00009
ooooo`;o00000oooool2o`0000Cooooo0_l0000;oooooaCo00005Oooool2o`0000Cooooo0_l00000
0ooooooo0000o`000009ooooo`?o00000_oooolUo`0000;ooooo2?l00002ooooo`Go00000_ooool2
o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Sooooo0_l00015ooooo`007?ooool00ol0
003oooooooooo`0hooooo`;o00000oooool2o`0000?ooooo0_l00007ooooo`;o00002?ooool4o`00
013ooooo1Ol000000ooooooo0000o`00000<o`0001[ooooo0_l000001?oooooo0000o`000?l00002
ooooo`;o00001?ooool3o`000003ooooool0003o0000013o000000?oooooo`000?l000004Ol00002
ooooo`So00001Oooool2o`0000;ooooo1?l0001Sooooo`007?ooool00ol0003oooooooooo`0foooo
o`Co00000oooool6o`0000Kooooo1_l00008ooooo`;o00004?oooolDo`0000;ooooo0_l0000<oooo
o`;o00001_ooool2o`0000Cooooo0_l00002ooooo`;o00001?ooool2o`0000;ooooo0_l000000ooo
oooo0000o`00000Qo`000003ooooool0003o000000Co00002?ooool2o`000004ooooool0003o0000
ooooo`;o00005?ooool2o`0004gooooo000Looooo`03o`000?oooooooooo03Kooooo0_l000000ooo
oooo0000o`000002ooooo`Ko00001_ooool2o`0000;ooooo1_l0000=ooooo`;o00001ooooolEo`00
0003ooooool0003o000000cooooo0_l00004ooooo`Co00001Oooool2o`0000Sooooo0_l00005oooo
obOo00001Oooool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000005oooo
o`Co00002oooool2o`0000Oooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0iooooo`;o
000000?oooooo`000?l000000_l00009ooooo`;o00001?ooool4o`0000gooooo1_l00003oooooaGo
00002?ooool2o`0000_ooooo0_l00007ooooo`Co00001_ooool3o`0000Kooooo9?l000000ooooooo
0000o`000005o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000005ooooo`Co
00001Oooool2o`0000Wooooo0_l00002ooooo`;o00001Oooool2o`0003gooooo000Looooo`03o`00
0?oooooooooo03Sooooo0_l00002ooooo`;o00002_ooool6o`00013ooooo0_l00002ooooo`Co0000
1?oooolCo`0000Wooooo0_l0000Dooooo`Co00001_ooool]o`000003ooooool0003o000000Ko0000
00?oooooo`000?l000000_ooool4o`0000oooooo0_l00003ooooo`;o00000_ooool4o`0000Gooooo
0_l00002ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0>?ooool2o`0000[ooooo0_l0
0002ooooo`Ko00004?ooool2o`0000[ooooo5_l00007ooooo`;o00008?oooolDo`0000;ooooo5?l0
00000ooooooo0000o`000006o`000003ooooool0003o000000;ooooo1?l0000Booooo`Co00000_oo
ool2o`0000Oooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00000oooool2
o`0000?ooooo0_l0000;ooooo`;o00004ooooolEo`0000Oooooo0_l00008ooooo`;o00000_ooool2
o`0001;ooooo0_l000000ooooooo0000o`00000Wo`000003ooooool0003o000001oooooo0_l00007
ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Looooo`;o00008oooool001cooooo00?o0000
ooooooooool0?Oooool4o`0000Sooooo0_l00003ooooo`;o00001_ooool2o`0001?ooooo4ol00005
ooooo`;o000000?oooooo`000?l000002Oooool2o`000004ooooool0003o0000o`0000oooooo0_l0
00000ooooooo0000o`000002ooooobSo00001_ooool2o`0001Oooooo0_l00005ooooo`;o00000ooo
ool5o`000004ooooool0003o0000o`0001_ooooo0_l0000Sooooo`007?ooool00ol0003ooooooooo
o`0Uooooo`;o00005?ooool4o`0000Kooooo1_l00003ooooo`Co00003_ooool4o`0000Gooooo0_l0
00000ooooooo0000o`00000Bo`0000?ooooo0_l000000ooooooo0000o`00000<ooooo`;o00003?oo
ool2o`000003ooooool0003o000002Co00000_ooool3o`000003ooooool0003o000000Sooooo0_l0
000Gooooo`;o00001Oooool2o`0000;ooooo1Ol00003ooooo`;o0000@?ooool001cooooo00?o0000
ooooooooool09Oooool2o`0001Cooooo0_l00008ooooo`Ko00000oooool4o`0000kooooo1?l00005
ooooo`;o000000?oooooo`000?l000004_l00006ooooo`;o00002_ooool4o`0000cooooo3Ol00000
0ooooooo0000o`00000Io`0000?ooooo0_l0000_ooooo`;o00001oooool2o`0003oooooo00001_oo
ooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0
1_ooool00ol0003oooooooooo`0cooooo`;o00005oooool5o`0001cooooo1?l000000ooooooo0000
o`00000;o`0001?ooooo0_l00009ooooo`;o00001Oooool7o`000003ooooool0003o000001_o0000
0_ooool3o`0000Kooooo0ol0000Kooooo`;o00002Oooool2o`0000Wooooo0_l0000oooooo`0000Ko
ooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q
00Kooooo00?o0000ooooooooool0<oooool2o`0000Cooooo0_l000001?oooooo0000o`000?l0000=
ooooo`;o00006oooool2o`0000?ooooo4_l00004ooooo`;o00001Oooool2o`00013ooooo1?l00003
ooooo`;o000000Coooooo`000?l0003ooooo2?l000000ooooooo0000o`00000Io`0000;ooooo0_l0
0002ooooo`?o00000oooool2o`0000?ooooo0_l0000Aooooo`;o00002Oooool2o`0000Kooooo0_l0
00000ooooooo0000o`00000oooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0iooooo`;o000000?o
ooooo`000?l000000ol00003ooooo`;o00000_ooool3o`0000Gooooo0_l0000Gooooo`;o00000ooo
oolBo`0000Cooooo0_l00005ooooo`;o00004_ooool2o`0000?ooooo0_l00004ooooo`Co000000Go
ooooo`000?l0003o0000ooooo`0:o`000003ooooool0003o000000go00000oooool2o`0000Sooooo
0_l00003ooooo`;o00001_ooool2o`0000Kooooo0_l00006ooooo`;o00003?ooool2o`0004;ooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oiRHV?ooooooV9RH
ob4Q8@06ooooo`?o0000?Oooool4o`0000?ooooo0_l00002ooooo`?o00001Oooool2o`0000cooooo
0_l00008ooooo`;o00000_oooolDo`0000?ooooo0_l0000Dooooo`;o000000?oooooo`000?l00000
3Oooool7o`000003ooooool0003o000001Co000000?oooooo`000?l000000_l00002ooooo`;o0000
00?oooooo`000?l000003oooool2o`000004ooooool0003o0000o`0000Gooooo0_l00006ooooo`;o
00003Oooool2o`00047ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo
00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo03;ooooo0_l00009ooooo`;o
00002Oooool2o`0001Cooooo1?l00004ooooo`Co00000_oooolDo`0000?ooooo0_l00008ooooo`Co
000000?oooooo`000?l000001Oooool2o`000003ooooool0003o000000Oooooo0_l00003ooooo`?o
000000Coooooo`000?l0003o00000_oooolFo`000003ooooool0003o000000;o00000_ooool2o`00
0004ooooool0003o0000ooooo`;o00000oooool2o`0000Oooooo0_l000001?oooooo0000o`000?l0
000Looooo`;o0000@Oooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool0
0omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo03;ooooo0_l00003ooooo`;o00003oooool2
o`0001Kooooo0_l00004ooooo`;o00001oooool2o`000003ooooool0003o000000co00001?ooool2
o`0000Kooooo1Ol000001?oooooo0000o`000?l0000@ooooo`;o00000oooool6o`0000?ooooo5ol0
0002ooooo`;o00000_ooool5o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`00
0005ooooo`Co00006?ooool2o`000003ooooool0003o000000oooooo0_l0000booooo`0000Kooooo
ogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0
<_ooool2o`0000?ooooo0_l00005ooooo`;o00001Oooool2o`0000Wooooo0_l0000Mooooo`_o0000
0oooool3o`0000Cooooo0_l00006ooooo`;o00001?ooool3o`0001Sooooo1_l000001?oooooo0000
o`000?oooolGo`0000?ooooo0_l000000ooooooo0000o`000008ooooo`;o00001Oooool2o`0001[o
oooo0_l000000ooooooo0000o`00000?ooooo`;o00002?ooool2o`0002Sooooo00001_ooooook^k^
oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`0b
ooooo`;o00002_ooool2o`0000Gooooo0_l00008ooooo`?o00005_ooool2o`0000Kooooo0_l00000
0ooooooo0000o`000006o`0000;ooooo0ol000000ooooooo0000o`00000<ooooo`;o000000Cooooo
o`000?l0003o00002_ooool2o`0000_ooooo0_l000000ooooooo0000o`000008o`0000;ooooo2_l0
00000ooooooo0000o`000006o`0000Kooooo0_l0000Oooooo`;o0000:?ooool2o`0002Sooooo000L
ooooo`03o`000?oooooooooo033ooooo0_l00003ooooo`?o00003oooool2o`0000Kooooo0ol0000>
ooooo`;o00001_ooool2o`0000Oooooo1?l000000ooooooo0000o`000003o`000003ooooool0003o
000000;o000000?oooooo`000?l000003?ooool4o`000003ooooool0003o000000Wooooo0_l0000;
ooooo`;o00001?ooool2o`0000;ooooo0ol000000ooooooo0000o`000006o`000004ooooool0003o
0000ooooo`?o000000?oooooo`000?l000001ol00004ooooo`;o000000?oooooo`000?l000000_l0
0007ooooo`;o00003_ooool2o`0005;ooooo000Looooo`03o`000?oooooooooo033ooooo0_l00003
ooooo`?o00003oooool2o`0000Kooooo0ol0000>ooooo`Co00003Oooool3o`000003ooooool0003o
000000Wo00001?ooool4o`0000Sooooo0ol000000ooooooo0000o`000009ooooo`;o00002oooool2
o`000003ooooool0003o000000;ooooo0ol000001?oooooo0000o`000?ooool2o`0000?ooooo1_l0
0002ooooo`co00000oooool8o`0000Oooooo0_l0000>ooooo`;o00002oooool2o`0004Gooooo000L
ooooo`03o`000?oooooooooo067ooooo0ol00006ooooo`;o00001_ooool2o`000005ooooool0003o
0000o`000?ooool01_l000001Ooooooo0000o`000?l0003ooooo00Co00002?ooool2o`0000;ooooo
0_l00009ooooo`;o00003_ooool2o`000003ooooool0003o000000Go00000oooool5o`000004oooo
ool0003o0000o`0000?ooooo1?l0000:ooooo`;o000000?oooooo`000?l000000ol0000;ooooo`;o
00002_ooool4o`0000;ooooo0_l00004ooooo`Go0000@oooool001cooooo00?o0000ooooooooool0
BOooool2o`000003ooooool0003o000001Cooooo0_l00006ooooo`Co00001?ooool2o`0000Gooooo
0ol000001?oooooo0000o`000?ooool3o`000003ooooool0003o000000[ooooo0_l0000=ooooo`;o
00004Oooool2o`000004ooooool0003o0000ooooo`;o00000_ooool3o`0000?ooooo0ol000000ooo
oooo0000o`000004ooooo`;o00002?ooool2o`000003ooooool0003o000000;o00000_ooool2o`00
0004ooooool0003o0000ooooo`;o00000_ooool2o`0000?ooooo0_l00006ooooo`?o00000_ooool2
o`0000Cooooo0_l000000ooooooo0000o`000013ooooo`007?ooool00ol0003oooooooooo`19oooo
o`;o000000?oooooo`000?l000001?l0000Dooooo`;o00001?ooool2o`0000cooooo0_l00006oooo
o`;o00003?ooool4o`0000;ooooo0_l00007ooooo`;o00004Oooool2o`0000Cooooo0_l00008oooo
o`;o000000?oooooo`000?l000000ol00002ooooo`;o000000?oooooo`000?l000000oooool4o`00
0003ooooool0003o000000;o00000_ooool2o`000003ooooool0003o000000Go00001Oooool2o`00
00Kooooo0_l0000<ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0COooool6o`0000Go
oooo0ol00006ooooo`;o00000oooool2o`0001;ooooo0_l00006ooooo`;o00001?ooool2o`0000So
oooo0ol000000ooooooo0000o`000002ooooo`;o00004?ooool2o`0000Cooooo0_l00005ooooo`;o
00002_ooool2o`000003ooooool0003o000000;ooooo0_l000001?oooooo0000o`000?l00002oooo
o`;o00001Oooool3o`0000Gooooo0_l00002ooooo`;o00001oooool2o`000003ooooool0003o0000
05Cooooo000Looooo`03o`000?oooooooooo03oooooo0_l0000@ooooo`;o00001?ooool4o`0000Co
oooo1?l00003ooooo`;o00003Oooool2o`00017ooooo0_l00004ooooo`;o00000oooool3o`0000Co
oooo0_l00008ooooo`;o00001_ooool2o`0000Oooooo0_l00002ooooo`Co000000?oooooo`000?l0
00001?l00002ooooo`;o00001oooool3o`0000Oooooo0_l000000ooooooo0000o`00000Booooo`;o
000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000?ooooo0_l00005ooooo`;o
0000?oooool001cooooo00?o0000ooooooooool0?oooool2o`0001Kooooo0_l00006ooooo`?o0000
0oooool3o`0000Cooooo0ol00006ooooo`;o00002oooool3o`0000Wooooo0_l00003ooooo`?o0000
3_ooool2o`0000Kooooo0_l00007ooooo`;o00000oooool3o`000003ooooool0003o000000Co0000
0_ooool2o`0000gooooo0_l00002ooooo`;o00007_ooool2o`000003ooooool0003o000000?ooooo
0_l00005ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0IOooool2o`0000Gooooo0ol0
000Cooooo`Ko00000_ooool2o`0000Kooooo1?l00006ooooo`;o00006oooool4o`0000Cooooo0_l0
00000ooooooo0000o`000009ooooo`Go000000?oooooo`000?l000001oooool2o`0000cooooo1?l0
0009ooooo`Oo0000BOooool001cooooo00?o0000ooooooooool0:_ooool2o`0000oooooo0_l0000<
ooooo`Co00000_ooool2o`0001;ooooo0_l00008ooooo`;o00002oooool2o`0000Wooooo0ol00002
ooooo`;o00001_ooool4o`0000Kooooo0_l0000>ooooo`Co00002Oooool4o`0000Oooooo0_l00003
ooooo`?o00000oooool5o`0000?ooooo1Ol00002ooooo`;o00002_ooool6o`0000;ooooo0_l00003
ooooo`Wo0000BOooool001cooooo00?o0000ooooooooool0:_ooool2o`0000oooooo0ol0000;oooo
o`Co00000_ooool2o`0000Cooooo0_l0000:ooooo`Co00002?ooool2o`0000_ooooo0_l0000Eoooo
o`;o000000Coooooo`000?l0003o00002Oooool3o`0000Kooooo0_l000000ooooooo0000o`000002
o`0000Oooooo1?l000000ooooooo0000o`00000;ooooo`?o00001Oooool2o`0000Cooooo1Ol00004
ooooo`;o00002?ooool2o`0000Kooooo0_l00003ooooo`;o00001?ooool5o`0004Oooooo000Loooo
o`;o0000?Oooool2o`0001Oooooo0_l0000:ooooo`;o00001Oooool2o`0002Gooooo1?l00002oooo
o`;o00002Oooool3o`0000Kooooo0_l0000<ooooo`Co000000?oooooo`000?l000000_l00005oooo
o`;o00000_ooool2o`0000Kooooo0_l0000=ooooo`;o00004?ooool2o`0000Kooooo0_l00002oooo
o`Co0000Aoooool001cooooo00?o0000ooooooooool0I_ooool4o`0002Gooooo1_l0000Xooooo`?o
00001Oooool3o`000003ooooool0003o000000gooooo0_l0000Kooooo`;o00000oooool2o`0000?o
oooo0_l000000ooooooo0000o`000015ooooo`007?ooool00ol0003oooooooooo`0gooooo`;o0000
0_ooool2o`0001Sooooo0_l0000:ooooo`Co000000?oooooo`000?l000001_ooool2o`0001;ooooo
0_l0000>ooooo`?o00002?ooool2o`0001kooooo0_l00007ooooo`?o00001Oooool2o`0000Sooooo
0_l0000Kooooo`;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000015ooooo`007?oo
ool00ol0003oooooooooo`0gooooo`;o00000_ooool2o`0000;ooooo0_l00009ooooo`;o00001ooo
ool6o`0000Sooooo1?l00009ooooo`Ko00003_ooool5o`000003ooooool0003o000000Sooooo1?l0
0007ooooo`;o00000_ooool2o`0002Cooooo0_l00003ooooo`Co00000oooool2o`0000_ooooo0_l0
0008ooooo`;o00003?ooool2o`000004ooooool0003o0000o`0004_ooooo000Looooo`03o`000?oo
oooooooo03oooooo0ol00008ooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo0_l0
0004ooooo`;o00004Oooool4o`0000oooooo1ol00008ooooo`Go00002_ooool2o`0001;ooooo1?l0
0009ooooo`;o00002?ooool4o`0000?ooooo0_l0000:ooooo`?o00000oooool2o`0000?ooooo0_l0
000<ooooo`;o000000?oooooo`000?l000000_l0001:ooooo`007?ooool00ol0003oooooooooo`10
ooooo`;o00002Oooool4o`0000Sooooo0_l00004ooooo`;o00006?ooool2o`0000kooooo0_l00002
ooooo`;o00001Oooool5o`0000Cooooo0_l0000Hooooo`Co00001Oooool2o`0000;ooooo0_l00002
ooooo`;o00001_ooool2o`0000Sooooo0_l00005ooooo`;o00001?ooool2o`0001Kooooo0_l0001:
ooooo`007?ooool00ol0003oooooooooo`0oooooo`Co00002?ooool2o`00017ooooo0_l0000Coooo
o`;o00000_ooool2o`0000Sooooo0ol00002ooooo`;o00000oooool2o`0000Cooooo1_l00004oooo
o`;o00001Oooool2o`0000cooooo0_l000000ooooooo0000o`000009ooooo`;o00000oooool2o`00
0003ooooool0003o000000Cooooo0_l0000:ooooo`Co00004_ooool2o`0000kooooo0_l00019oooo
o`007?ooool00ol0003oooooooooo`0oooooo`Co00006oooool2o`0001?ooooo0_l00008ooooo`Oo
00000_ooool2o`000004ooooool0003o0000ooooo`?o00000_ooool6o`0000Wooooo1?l0000;oooo
o`?o000000?oooooo`000?l000002Oooool2o`0000?ooooo0_l00007ooooo`;o000000?oooooo`00
0?l000000oooool2o`0000;ooooo1?l00007ooooo`;o00002Oooool2o`0000Sooooo0_l00004oooo
o`;o0000BOooool001cooooo00?o0000ooooooooool0HOooool2o`0000Wooooo0_l0000;ooooo`;o
00000_ooool7o`0000Gooooo0_l000001?oooooo0000o`000?l00005ooooo`Co00001?ooool2o`00
00;ooooo0_l00009ooooo`;o00000_ooool2o`0000Wooooo0ol000000ooooooo0000o`000003oooo
o`;o00002_ooool2o`0000?ooooo0_l00002ooooo`;o00002Oooool2o`0000Wooooo0ol00005oooo
o`Co000000Coooooo`000?l0003ooooo0_l0000?ooooo`;o0000>?ooool001cooooo00?o0000oooo
ooooool0?_ooool2o`0001kooooo0_l000000ooooooo0000o`000009ooooo`;o00002oooool4o`00
0004ooooool0003o0000ooooo`?o000000Coooooo`000?l0003o00001Oooool3o`0000Gooooo0ol0
0004ooooo`;o00000_ooool2o`0000Wooooo0_l00006ooooo`;o00001Oooool3o`000003ooooool0
003o000000Cooooo0ol00002ooooo`;o00003?ooool2o`000003ooooool0003o000000[ooooo0_l0
0007ooooo`;o00001Oooool3o`0000;ooooo0_l0000Booooo`;o0000>?ooool001cooooo00?o0000
ooooooooool0?_ooool2o`0001kooooo0_l0000@ooooo`;o00002Oooool2o`000003ooooool0003o
000000So00001Oooool3o`0000?ooooo1?l0000@ooooo`;o00002_ooool2o`0000Sooooo0ol00004
ooooo`?o00000_ooool2o`0000cooooo1Ol00007ooooo`;o000000?oooooo`000?l000002_ooool2
o`0005Gooooo000Looooo`03o`000?oooooooooo03kooooo0_l00004ooooo`;o0000:_ooool2o`00
00[ooooo3_l00009ooooo`;o00001oooool2o`0000?ooooo0_l00004ooooo`;o00005?ooool2o`00
00Wooooo0ol00008ooooo`;o00000oooool2o`0000Wooooo0_l0000=ooooo`;o000000?oooooo`00
0?l000002?ooool2o`0004Sooooo000Looooo`03o`000?oooooooooo03[ooooo0_l00008ooooo`;o
0000<_ooool2o`000003ooooool0003o000000ko00001oooool5o`0000;ooooo0_l000001?oooooo
0000o`000?ooool4o`0000Cooooo0_l00006ooooo`?o00003?ooool2o`0000Sooooo0ol00008oooo
o`;o00001_ooool2o`0000Sooooo0_l0000>ooooo`Co00001_ooool2o`0004Sooooo000Looooo`03
o`000?oooooooooo03[ooooo0_l0000Tooooo`;o00005_oooolGo`0000?ooooo1Ol00002ooooo`;o
00001?ooool2o`0000Wooooo2?l0000<ooooo`;o00000_ooool2o`0000Gooooo0_l00004ooooo`;o
00002Oooool3o`0000Gooooo0_l000000ooooooo0000o`00000@ooooo`;o0000D?ooool001cooooo
00?o0000ooooooooool0H?ooool2o`0001Oooooo5_l00005ooooo`?o00003oooool2o`0000;ooooo
1_l0000Booooo`;o00001_ooool2o`0000?ooooo0_l00006ooooo`;o000000?oooooo`000?l00000
0_l00004ooooo`;o00001?ooool2o`0005oooooo000Looooo`03o`000?oooooooooo03cooooo0_l0
000Rooooo`;o00002_ooool2o`0000Cooooo0_l00005oooooaCo00001oooool3o`0000oooooo0_l0
0003ooooo`?o00007?ooool2o`0000Gooooo0_l00004ooooo`;o00000oooool2o`0000[ooooo0_l0
00000ooooooo0000o`000006ooooo`;o0000E?ooool001cooooo0_l0000looooo`?o00006_ooool2
o`0000Kooooo0_l00005ooooo`;o00000oooool2o`0000Cooooo0_l00003oooooaKo00005Oooool2
o`0001cooooo0_l0000?ooooo`;o00002Oooool2o`0000gooooo0_l00005ooooo`?o0000E?ooool0
01cooooo00?o0000ooooooooool0>oooool2o`0001Kooooo0_l00003ooooo`;o00003Oooool2o`00
00cooooo7?l00007ooooo`;o00002?ooool2o`0001Kooooo0_l00004ooooo`;o00001_ooool2o`00
00Gooooo1?l00008ooooo`;o00000_ooool2o`0000Cooooo0_l00007ooooo`;o00000_ooool2o`00
05Gooooo000Looooo`03o`000?oooooooooo03Gooooo0_l0000Looooo`;o00008?ooool2o`000003
ooooool0003o000001Oo000000?oooooo`000?l000001?ooool2o`00023ooooo0_l00003ooooo`Co
00001?ooool3o`0000Gooooo1_l00005ooooo`Oo00000_ooool4o`0000Gooooo1_l0001Gooooo`00
7?ooool00ol0003oooooooooo`0eooooo`;o00002Oooool2o`0003Kooooo5_l000000ooooooo0000
o`000003o`00013ooooo0_l0000Iooooo`Co00001?ooool2o`0000[ooooo0_l00005ooooo`;o0000
00?oooooo`000?l000001?ooool2o`0000Oooooo0_l00002ooooo`;o00002oooool2o`0004[ooooo
000Looooo`03o`000?oooooooooo043ooooo0_l0000doooooaOo00000_ooool4o`00017ooooo0_l0
0004ooooo`;o00006_ooool2o`0000_ooooo0_l0000Gooooo`;o00003oooool2o`0004[ooooo000L
ooooo`03o`000?oooooooooo06Cooooo0_l00009ooooo`?o00001?oooolAo`000003ooooool0003o
000000Co00002_ooool2o`0000?ooooo0_l00008ooooo`;o000000?oooooo`000?l000003_ooool2
o`0000[ooooo0_l00004ooooo`?o00005oooool2o`0000Cooooo0_l0001Kooooo`007?ooool00ol0
003oooooooooo`16ooooo`;o00007?ooool4o`0000Oooooo0ol00007oooooaGo00002_ooool2o`00
00?ooooo0_l00003ooooo`;o00000oooool4o`0000oooooo0_l0000@ooooo`?o00005oooool2o`00
00?ooooo0_l0001Looooo`007?ooool00ol0003oooooooooo`16ooooo`;o00005oooool3o`0000Co
oooo0_l0000>ooooo`[o000000?oooooo`000?l000002_l0000Eooooo`;o00001Oooool2o`0000;o
oooo0_l00002ooooo`;o00003?ooool3o`0000Oooooo0_l000001?oooooo0000o`000?ooool2o`00
00oooooo0_l00004ooooo`;o00000oooool2o`000004ooooool0003o0000o`0005Sooooo000Loooo
o`03o`000?oooooooooo05oooooo0ol00004ooooo`;o00003Oooool;o`000003ooooool0003o0000
00co00001?ooool4o`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l000000oooool2o`00
00;ooooo0ol00002ooooo`;o00001_ooool2o`0000Cooooo1Ol000000ooooooo0000o`000002oooo
o`;o00001?ooool2o`0000Wooooo0_l00002ooooo`Co00000oooool3o`0000?ooooo0_l000001?oo
oooo0000o`000?l0000Aooooo`;o0000AOooool001cooooo00?o0000ooooooooool0G_ooool2o`00
01Gooooo0_l00002oooooaKo00000_ooool6o`0000?ooooo0_l000001?oooooo0000o`000?ooool2
o`000003ooooool0003o000000?ooooo1ol00003ooooo`Co00000oooool2o`0000Oooooo1Ol0000<
ooooo`;o00001Oooool2o`0000;ooooo0_l00005ooooo`;o00001?ooool2o`0001Gooooo0_l00015
ooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o00006_oooolBo`0000Gooooo0_l0000:oooo
o`;o00002oooool2o`000003ooooool0003o000000?ooooo1_l0000<ooooo`;o00001oooool2o`00
00Cooooo0_l00004ooooo`;o00001Oooool4o`0006Gooooo000Looooo`03o`000?oooooooooo06?o
oooo0_l0000@ooooo`;o000000?oooooo`000?l000004Ol0000:ooooo`?o00004_ooool4o`0000Go
oooo0_l000001?oooooo0000o`000?ooool2o`0000Cooooo0_l00008ooooo`;o00000_ooool2o`00
00[ooooo0ol00002ooooo`Ko0000IOooool001cooooo00?o0000ooooooooool0DOooool2o`0000?o
oooo0_l00007ooooo`;o00000_ooool2o`00013ooooo0_l000000ooooooo0000o`00000<o`000004
ooooool0003o0000o`0000[ooooo1?l0000Booooo`Co00001_ooool3o`0000;ooooo0_l00004oooo
o`;o00001_ooool8o`000003ooooool0003o000000Sooooo0_l00002ooooo`;o00002oooool2o`00
05cooooo000Looooo`03o`000?oooooooooo04cooooo0_l00003ooooo`;o00000_ooool3o`0000Oo
oooo0_l0000Hooooo`;o000000?oooooo`000?l000003?l0000:ooooo`;o00000_ooool3o`0000;o
oooo0_l000000ooooooo0000o`000002ooooo`;o00003_ooool3o`0000;ooooo0_l00005ooooo`;o
00001Oooool3o`000003ooooool0003o000000Go00002?ooool2o`0000oooooo0_l0001Looooo`00
7?ooool00ol0003oooooooooo`1<ooooo`;o00001oooool2o`0001kooooo0_l00002ooooo`;o0000
00?oooooo`000?l000002ol0000:ooooo`;o00000oooool3o`0000;ooooo0_l000000ooooooo0000
o`000002ooooo`;o00003oooool2o`0000;ooooo1?l00003ooooo`Ko00002?ooool2o`000003oooo
ool0003o000000?ooooo0_l000001?oooooo0000o`000?l0000;ooooo`;o0000H?ooool001cooooo
00?o0000ooooooooool0Coooool2o`0002Cooooo0_l00005ooooo`_o00003?ooool3o`000003oooo
ool0003o000000Cooooo0_l0000Booooo`?o000000?oooooo`000?l000000_ooool4o`0000Gooooo
1?l00007ooooo`Ko00000oooool2o`000004ooooool0003o0000o`0000Sooooo0_l000000ooooooo
0000o`00001Pooooo`007?ooool2o`00053ooooo0_l0000/ooooo`?o000000?oooooo`000?l00000
1?l0000=ooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo0_l0000:ooooo`;o0000
00?oooooo`000?l000001?l00003ooooo`Ko000000?oooooo`000?l000002_ooool7o`0000Cooooo
0_l000000ooooooo0000o`000007ooooo`?o0000Hoooool001cooooo00?o0000ooooooooool0POoo
ool2o`0000Wooooo0_l0000Cooooo`;o00001?ooool4o`0000;ooooo2Ol00002ooooo`;o000000?o
ooooo`000?l000000_l000000ooooooo0000o`000002o`0000Sooooo0ol00002ooooo`Co000000Co
ooooo`000?l0003o00002Oooool3o`0006Cooooo000Looooo`03o`000?oooooooooo07gooooo0_l0
0008ooooo`;o00000oooool2o`0000Oooooo0_l00002ooooo`;o00001Oooool2o`0000Gooooo1Ol0
0003ooooo`Co000000?oooooo`000?l000000_ooool2o`0000Sooooo0_l00008ooooo`?o00001?oo
ool2o`000003ooooool0003o000000Go00001Oooool2o`0006Gooooo000Looooo`03o`000?oooooo
oooo07gooooo0_l00008ooooo`;o00003?ooool3o`000003ooooool0003o000000Cooooo0ol00008
ooooo`;o00002?ooool2o`0000Kooooo0_l00002ooooo`;o00002_ooool2o`0000[ooooo1Ol00000
1?oooooo0000o`000?l0001Xooooo`007?ooool00ol0003oooooooooo`1eooooo`;o00000oooool2
o`0001Wooooo1Ol00005ooooo`;o00006oooool2o`0000;ooooo0_l0000Fooooo`;o00001?ooool3
o`0000;ooooo1?l00004ooooo`;o0000G?ooool001cooooo00?o0000ooooooooool0MOooool3o`00
00;ooooo0_l0000Kooooo`?o00003?ooool2o`0000Cooooo0_l0000<ooooo`;o00008Oooool2o`00
00Cooooo1?l00004ooooo`;o0000G?ooool001cooooo00?o0000ooooooooool0M_ooool2o`0001oo
oooo0_l0000<ooooo`?o00000oooool3o`0000cooooo0_l00006ooooo`;o00006Oooool2o`0000;o
oooo0_l0001Vooooo`007?ooool00ol0003oooooooooo`1Rooooo`;o00008oooool2o`0000[ooooo
0_l00002ooooo`;o00003?ooool9o`0000kooooo0_l000001?oooooo0000o`000?ooool2o`0000Go
oooo0_l0000@ooooo`;o00001?ooool4o`0000;ooooo0_l0001Pooooo`007?ooool00ol0003ooooo
ooooo`1Rooooo`;o00007oooool2o`0000;ooooo0ol00009ooooo`;o00002oooool2o`0000Gooooo
1?l00004ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o
00001oooool2o`00013ooooo0_l00002ooooo`;o00000_ooool6o`00063ooooo000Looooo`03o`00
0?oooooooooo08?ooooo0_l00003ooooo`;o00000_ooool2o`0000Wooooo0_l00007ooooo`;o0000
1Oooool2o`000003ooooool0003o000000?ooooo1?l000000ooooooo0000o`000002ooooo`?o0000
1?ooool3o`0000Kooooo0ol0000Dooooo`;o00000oooool3o`0006;ooooo000Looooo`03o`000?oo
oooooooo08cooooo0ol00007ooooo`?o00001Oooool2o`0000Oooooo1Ol00005ooooo`;o00001Ooo
ool3o`0000Gooooo0_l00006ooooo`;o0000Ooooool001cooooo00?o0000ooooooooool0IOooool2
o`0001;ooooo0_l00005ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`000003ooooool0
003o000000Oooooo0_l000000ooooooo0000o`000003ooooo`;o00002Oooool2o`0002;ooooo0_l0
000?ooooo`Co0000Ioooool001cooooo00?o0000ooooooooool0IOooool2o`0000oooooo0_l00000
0ooooooo0000o`000005ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o00002_ooool2
o`000003ooooool0003o000000?ooooo0_l00002ooooo`Co00001Oooool2o`0000Sooooo0_l00005
ooooo`;o00001Oooool2o`0000Sooooo0_l0000?ooooo`Co00003Oooool2o`0005Sooooo000Loooo
o`03o`000?oooooooooo07Kooooo0ol0000<ooooo`;o00003oooool2o`0000Kooooo0_l000000ooo
oooo0000o`000004o`0000Cooooo0_l00007ooooo`?o00001Oooool2o`000003ooooool0003o0000
00Co00000_ooool2o`0000Wooooo0ol00003ooooo`Co00004oooool2o`0005Sooooo00001_oooooo
k^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_oo
ool00ol0003oooooooooo`1Xooooo`;o00003Oooool2o`0000;ooooo0_l0000Fooooo`;o00000ooo
ool2o`0000Oooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l00007ooooo`;o0000
0_ooool2o`000003ooooool0003o000000;ooooo1?l00004ooooo`;o00001oooool5o`0000?ooooo
1?l0001]ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7o
V9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0J?ooool2o`0000gooooo0_l00002oooo
o`;o00005_ooool2o`0000?ooooo0_l00002ooooo`;o00001oooool5o`0000kooooo0_l000000ooo
oooo0000o`000007ooooo`;o00002_ooool2o`0000Cooooo0_l000000ooooooo0000o`00001^oooo
o`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooooooo`1cooooo`;o00001oooool2o`0000Kooooo0_l0000Aoooo
o`?o000000Coooooo`000?l0003o00002?ooool2o`0001cooooo0_l0000@ooooo`;o0000LOooool0
0003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Olb<S;oV9RHoooooonHV9So
<S8b00Kooooo0ol0001]ooooo`;o00001?ooool2o`0000Oooooo0_l00006ooooo`?o00001_ooool2
o`0000Sooooo0ol000000ooooooo0000o`000002ooooo`;o00001Oooool3o`0000[ooooo1Ol00007
ooooo`;o00005Oooool2o`00077ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00Wooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo06gooooo0_l0000=
ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000006ooooo`;o00004?oo
ool2o`0000?ooooo0_l000000ooooooo0000o`00000:ooooo`Oo00001Oooool4o`0000Cooooo1?l0
0008ooooo`?o0000Loooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool0
1Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0Ooooool2o`000003ooooool0
003o000001Oooooo0_l00007ooooo`;o000000?oooooo`000?l000003oooool3o`0000Kooooo0_l0
0004ooooo`Co00002?ooool3o`0007?ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo
00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo073ooooo0_l0000Xooooo`?o
00001oooool2o`0000?ooooo0_l0000>ooooo`;o00001?ooool2o`0000Oooooo0_l00006ooooo`;o
0000Moooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413o
ZJVY00Kooooo00?o0000ooooooooool0L?ooool2o`0002Sooooo0ol0000:ooooo`Co00002_ooool2
o`0000Sooooo0_l0000?ooooo`;o0000Moooool001cooooo00?o0000ooooooooool0POooool2o`00
01Sooooo0_l0000:ooooo`;o00002Oooool2o`000003ooooool0003o000000;ooooo0ol0002=oooo
o`007?ooool00ol0003oooooooooo`21ooooo`;o0000;?ooool2o`000003ooooool0003o000000Go
oooo0ol0000Jooooo`;o0000LOooool001cooooo00?o0000ooooooooool0L_ooool2o`0002;ooooo
0_l00004ooooo`;o00004Oooool2o`0000Sooooo0_l00004ooooo`;o00005Oooool2o`0000?ooooo
0_l0001/ooooo`007?ooool00ol0003oooooooooo`1booooo`;o00008_ooool2o`0000Cooooo0_l0
0004ooooo`;o00006oooool2o`0000Kooooo0_l0000Booooo`;o0000K?ooool001cooooo00?o0000
ooooooooool0NOooool2o`0002Kooooo0ol0000=ooooo`;o00005?ooool3o`0007oooooo000Loooo
o`03o`000?oooooooooo06Wooooo0_l0000>ooooo`;o00009_ooool2o`0000kooooo0_l000000ooo
oooo0000o`00000Booooo`;o0000Ooooool001cooooo00?o0000ooooooooool0JOooool2o`0004Ko
oooo0_l000000ooooooo0000o`000004ooooo`;o00004_ooool2o`0007Wooooo000Looooo`03o`00
0?oooooooooo07gooooo0_l0000Tooooo`Co00002Oooool3o`0000;ooooo0_l00003ooooo`;o0000
1Oooool2o`0000_ooooo0_l0001iooooo`007?ooool00ol0003oooooooooo`1mooooo`;o00009?oo
ool4o`0000Wooooo0_l00002ooooo`?o00002_ooool2o`0008Kooooo000Looooo`03o`000?oooooo
oooo0:Cooooo0ol0000;ooooo`Co0000Toooool001cooooo00?o0000ooooooooool0XOooool2o`00
0004ooooool0003o0000o`0000_ooooo0_l0002Eooooo`007?ooool2o`0009_ooooo0_l00005oooo
o`;o00003?ooool2o`0000kooooo0_l00028ooooo`007?ooool00ol0003oooooooooo`2Jooooo`;o
00004oooool2o`0000kooooo0_l00028ooooo`007?ooool00ol0003oooooooooo`35ooooo`;o0000
P_ooool001cooooo00?o0000ooooooooool0aOooool2o`0008;ooooo000Looooo`03o`000?oooooo
oooo09_ooooo0_l0002/ooooo`007?ooool00ol0003oooooooooo`2Kooooo`;o0000[?ooool001co
oooo00?o0000ooooooooool0XOooool2o`0000kooooo0_l0002Fooooo`007?ooool00ol0003ooooo
ooooo`2Qooooo`;o00003_ooool2o`0009Kooooo000Looooo`03o`000?oooooooooo093ooooo0_l0
002gooooo`007?ooool00ol0003oooooooooo`2@ooooo`;o00003?ooool2o`000:Wooooo000Loooo
o`03o`000?oooooooooo09kooooo0_l0002Yooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Booooo`Co
000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003ooooooooo
o`05ooooo`?o0000oooooom:ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Doooo
o`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`00
5?ooool00ol0003oooooooooo`3ooooooe;ooooo000Booooo`03oeEEEOmVIVKo00000?ooooooE?oo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Gooooo00Co410@o`000?l0003o
oooo0_l000000ol@413oooooooooo`0Eooooo`04oa0@4?l0003oA4A4olc<c0Cooooo00Gok^k^oc8b
<_l0003o410@olc<c003ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0T?ooool00:Kooooo00Go0000
ooooooooooooooooo`000009ooooo`Ko00002oooool00onHV9So410@omgMg@03ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B400oooool01OmEEEGoMgMgoooooonHV9So8B4Q093ooooo002Vooooo`05o`00
0?ooooooooooooooool000006oooool00on7QhOoEEEEooooo`02ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo0000093ooooo002Vooooo`05o`000?oooooooooo
ooooool000002Oooool6o`0000Wooooo00Goc<c<ob4Q8Ol0003oEEEEo`000003ooooo`05o`000?nH
V9SooooooiRHV?lQ8B400oooool01Ol0003oV9RHoooooonHV9So8B4Q093ooooo002Vooooo`05o`00
0?n7QhOoooooojVYZOl000006?ooool01OlQ8B7oQhN7oooooonHV9So000000?ooooo00Go0000oeEE
EOl0003o410@olc<c003ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0T?ooool00:Gooooo00?o410@
o`000?mgMgL00_l000000onHV9Soooooooooo`0Fooooo`05o`000?ooooooooooooooool000000ooo
ool00omEEEGoQhN7ooooo`05ooooo`03oeEEEOn7QhOooooo09;ooooo0033ooooo`05ob4Q8OnHV9So
ooooogMgMomEEED00oooool00ooMgMgo410@oiRHV005ooooo`03omgMgOl@413oV9RH09;ooooo0033
ooooo`05olc<c?l@413o0000oc8b<_o^k^h01?ooool01?o<c<coA4A4o`000?l@4104ooooo`04olc<
c?m4A4Co0000oa0@493ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(972) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.63776 .34654 Mdot
.60477 .38735 Mdot
.37049 .5649 Mdot
.56166 .55222 Mdot
.62264 .29661 Mdot
.34068 .53258 Mdot
.43569 .35985 Mdot
.41817 .31101 Mdot
.35175 .53984 Mdot
.49675 .52033 Mdot
.43779 .3275 Mdot
.52577 .60975 Mdot
.41732 .33416 Mdot
.57462 .55938 Mdot
.69149 .79438 Mdot
.59312 .50698 Mdot
.60155 .40792 Mdot
.39679 .72224 Mdot
.53031 .59895 Mdot
.37853 .56793 Mdot
.64683 .3991 Mdot
.56329 .56294 Mdot
.6314 .34696 Mdot
.57467 .5599 Mdot
.57923 .5357 Mdot
.6277 .37525 Mdot
.65195 .33559 Mdot
.55811 .53899 Mdot
.61398 .55195 Mdot
.40269 .33276 Mdot
.48946 .768 Mdot
.77472 .69999 Mdot
.54662 .51374 Mdot
.5502 .18321 Mdot
.42685 .3072 Mdot
.76813 .60737 Mdot
.34992 .50026 Mdot
.40576 .3524 Mdot
.42443 .30966 Mdot
.3982 .32164 Mdot
.40912 .33352 Mdot
.62165 .37541 Mdot
.44426 .28781 Mdot
.3884 .28524 Mdot
.58661 .62595 Mdot
.52691 .30087 Mdot
.64116 .71703 Mdot
.59842 .60287 Mdot
.61127 .40454 Mdot
.37567 .5767 Mdot
.52997 .19239 Mdot
.39967 .36459 Mdot
.3719 .43443 Mdot
.87916 .3963 Mdot
.41268 .36067 Mdot
.57413 .62788 Mdot
.35778 .52292 Mdot
.5615 .57661 Mdot
.57271 .56494 Mdot
.70175 .59796 Mdot
.57955 .52174 Mdot
.38768 .7058 Mdot
.59271 .41983 Mdot
.38415 .61262 Mdot
.34606 .52673 Mdot
.42435 .31228 Mdot
.59148 .39404 Mdot
.41907 .34111 Mdot
.59054 .64214 Mdot
.3269 .53147 Mdot
.59709 .60298 Mdot
.42347 .31711 Mdot
.5851 .35024 Mdot
.5798 .606 Mdot
.26347 .329 Mdot
.5401 .84506 Mdot
.3964 .6646 Mdot
.72105 .58659 Mdot
.70992 .64022 Mdot
.32091 .66198 Mdot
.60784 .55946 Mdot
.25515 .71267 Mdot
.64368 .81168 Mdot
.64079 .35262 Mdot
.61184 .50452 Mdot
.32036 .55632 Mdot
.57221 .60479 Mdot
.52324 .39637 Mdot
.60558 .62819 Mdot
.35148 .24962 Mdot
.35547 .54533 Mdot
.60213 .36451 Mdot
.56392 .55157 Mdot
.61107 .53368 Mdot
.6803 .44814 Mdot
.54923 .53788 Mdot
.5507 .55212 Mdot
.63425 .33259 Mdot
.44561 .33228 Mdot
.51907 .61068 Mdot
.40818 .29002 Mdot
.35749 .45996 Mdot
.56402 .61563 Mdot
.36294 .51732 Mdot
.61966 .32988 Mdot
.5702 .60917 Mdot
.45381 .32916 Mdot
.61298 .59005 Mdot
.38008 .285 Mdot
.60156 .39037 Mdot
.61364 .5371 Mdot
.35768 .70408 Mdot
.19795 .44606 Mdot
.60049 .36136 Mdot
.39075 .5481 Mdot
.61891 .57956 Mdot
.54881 .57653 Mdot
.60622 .38445 Mdot
.34459 .57696 Mdot
.54416 .45143 Mdot
.63075 .40143 Mdot
.40736 .31057 Mdot
.61587 .41412 Mdot
.60113 .50078 Mdot
.34723 .54809 Mdot
.35734 .43434 Mdot
.36326 .42416 Mdot
.46084 .73066 Mdot
.56719 .60185 Mdot
.52292 .22931 Mdot
.33784 .54889 Mdot
.60787 .36799 Mdot
.42207 .33837 Mdot
.64447 .60455 Mdot
.58874 .36214 Mdot
.4352 .34429 Mdot
.36921 .67217 Mdot
.30525 .45614 Mdot
.62246 .4032 Mdot
.39511 .26916 Mdot
.39279 .36661 Mdot
.39544 .32375 Mdot
.52695 .17857 Mdot
.60796 .39272 Mdot
.36807 .69008 Mdot
.43007 .34857 Mdot
.57205 .76172 Mdot
.57857 .63315 Mdot
.4473 .66289 Mdot
.1801 .6306 Mdot
.50627 .18695 Mdot
.30271 .37607 Mdot
.38932 .72175 Mdot
.39004 .33463 Mdot
.59747 .53524 Mdot
.6198 .39398 Mdot
.61915 .38783 Mdot
.53782 .56702 Mdot
.56805 .54115 Mdot
.59192 .60532 Mdot
.61513 .5414 Mdot
.66454 .73127 Mdot
.61445 .60185 Mdot
.37707 .77224 Mdot
.6087 .35697 Mdot
.57998 .52785 Mdot
.3631 .59142 Mdot
.6335 .60006 Mdot
.41394 .32381 Mdot
.55743 .57099 Mdot
.56023 .55013 Mdot
.60521 .52452 Mdot
.4237 .36748 Mdot
.76818 .68819 Mdot
.17062 .58032 Mdot
.82347 .52183 Mdot
.38048 .47586 Mdot
.3401 .5071 Mdot
.55792 .59963 Mdot
.38194 .69128 Mdot
.7709 .56811 Mdot
.59845 .55913 Mdot
.286 .24156 Mdot
.5519 .55515 Mdot
.68291 .3028 Mdot
.64775 .66196 Mdot
.82966 .50407 Mdot
.42724 .71399 Mdot
.61243 .54456 Mdot
.70374 .40969 Mdot
.75893 .37679 Mdot
.37562 .37138 Mdot
.40893 .33766 Mdot
.36263 .58958 Mdot
.36326 .53307 Mdot
.42056 .38312 Mdot
.54027 .64417 Mdot
.60513 .65976 Mdot
.62252 .64282 Mdot
.36429 .43878 Mdot
.57139 .40724 Mdot
.40125 .68294 Mdot
.62098 .33212 Mdot
.35587 .8177 Mdot
.40518 .2459 Mdot
.41801 .2752 Mdot
.3819 .66128 Mdot
.36246 .57221 Mdot
.36573 .44084 Mdot
.38179 .68522 Mdot
.59897 .5835 Mdot
.59948 .39754 Mdot
.66814 .24128 Mdot
.57343 .66736 Mdot
.65868 .21645 Mdot
.57663 .38581 Mdot
.52951 .44565 Mdot
.43288 .3338 Mdot
.36128 .48279 Mdot
.54751 .57194 Mdot
.58445 .58849 Mdot
.62742 .41999 Mdot
.59593 .60089 Mdot
.65809 .31225 Mdot
.54409 .56854 Mdot
.34247 .44211 Mdot
.39946 .66588 Mdot
.42458 .38253 Mdot
.45253 .72971 Mdot
.60831 .34057 Mdot
.42594 .68417 Mdot
.35414 .59311 Mdot
.75435 .60585 Mdot
.42898 .31675 Mdot
.35709 .69369 Mdot
.34632 .58459 Mdot
.40382 .6916 Mdot
.62828 .6014 Mdot
.33932 .49584 Mdot
.37666 .71671 Mdot
.71075 .72242 Mdot
.62128 .62026 Mdot
.65036 .75325 Mdot
.43981 .35748 Mdot
.61342 .41445 Mdot
.5758 .52364 Mdot
.36569 .48946 Mdot
.55727 .51093 Mdot
.28884 .33707 Mdot
.36608 .41801 Mdot
.37321 .44108 Mdot
.34121 .65912 Mdot
.35962 .70177 Mdot
.25688 .38584 Mdot
.50527 .21726 Mdot
.59976 .40619 Mdot
.5468 .60796 Mdot
.82043 .5791 Mdot
.42995 .34779 Mdot
.60151 .57897 Mdot
.32531 .4893 Mdot
.42765 .34985 Mdot
.56184 .57972 Mdot
.44341 .36027 Mdot
.61601 .39169 Mdot
.22146 .57186 Mdot
.59864 .4076 Mdot
.61476 .62268 Mdot
.45475 .34327 Mdot
.33138 .51973 Mdot
.63067 .37445 Mdot
.60994 .59082 Mdot
.54404 .58674 Mdot
.3588 .44463 Mdot
.59116 .52508 Mdot
.79857 .60957 Mdot
.59635 .52282 Mdot
.37243 .55565 Mdot
.55539 .53321 Mdot
.35746 .20599 Mdot
.27267 .49005 Mdot
.59254 .39485 Mdot
.37237 .44555 Mdot
.35368 .53456 Mdot
.28629 .62389 Mdot
.38858 .42157 Mdot
.61412 .57337 Mdot
.36399 .4679 Mdot
.43704 .64637 Mdot
.40062 .35683 Mdot
.52834 .572 Mdot
.44431 .26535 Mdot
.36922 .59347 Mdot
.36351 .44305 Mdot
.65608 .61082 Mdot
.6111 .32944 Mdot
.56421 .55027 Mdot
.32909 .52246 Mdot
.62534 .41095 Mdot
.61508 .61825 Mdot
.54611 .68318 Mdot
.36672 .42198 Mdot
.43279 .3593 Mdot
.65586 .6405 Mdot
.60388 .60622 Mdot
.35229 .50686 Mdot
.59172 .34923 Mdot
.4258 .3053 Mdot
.62418 .36712 Mdot
.71947 .30753 Mdot
.35422 .3836 Mdot
.69435 .70811 Mdot
.35141 .6742 Mdot
.32269 .33098 Mdot
.82972 .47387 Mdot
.22857 .42351 Mdot
.54017 .73785 Mdot
.76558 .32615 Mdot
.34467 .58028 Mdot
.33218 .46238 Mdot
.35575 .53004 Mdot
.5924 .54418 Mdot
.34302 .53007 Mdot
.83377 .49176 Mdot
.54532 .5639 Mdot
.34501 .50375 Mdot
.24421 .59768 Mdot
.56783 .53723 Mdot
.59849 .36105 Mdot
.68573 .79165 Mdot
.24609 .32871 Mdot
.4345 .21832 Mdot
.33414 .53071 Mdot
.67429 .62221 Mdot
.56023 .53852 Mdot
.61049 .52392 Mdot
.63054 .3868 Mdot
.53542 .55772 Mdot
.40131 .68533 Mdot
.38416 .66318 Mdot
.44763 .61215 Mdot
.19234 .60655 Mdot
.51973 .60991 Mdot
.63118 .37749 Mdot
.68796 .66422 Mdot
.28554 .30456 Mdot
.37753 .51876 Mdot
.43189 .29277 Mdot
.75319 .70285 Mdot
.5675 .65699 Mdot
.45062 .28812 Mdot
.41693 .2593 Mdot
.59577 .37842 Mdot
.77216 .66574 Mdot
.40842 .34625 Mdot
.73665 .43413 Mdot
.64893 .44827 Mdot
.59012 .58444 Mdot
.43569 .32016 Mdot
.52209 .60726 Mdot
.3229 .24814 Mdot
.5761 .77973 Mdot
.34425 .77028 Mdot
.60216 .62447 Mdot
.24742 .37435 Mdot
.55289 .57227 Mdot
.5578 .45657 Mdot
.59412 .52145 Mdot
.62718 .36294 Mdot
.49738 .53126 Mdot
.45618 .42214 Mdot
.19014 .63497 Mdot
.41036 .24159 Mdot
.39103 .72052 Mdot
.54565 .57962 Mdot
.58885 .5841 Mdot
.3681 .67993 Mdot
.62575 .34946 Mdot
.61393 .54142 Mdot
.48077 .66898 Mdot
.58723 .59947 Mdot
.40634 .33794 Mdot
.43661 .75674 Mdot
.66511 .36777 Mdot
.58623 .51342 Mdot
.6389 .39961 Mdot
.42233 .36541 Mdot
.41725 .3134 Mdot
.6553 .59654 Mdot
.4288 .30005 Mdot
.55412 .55716 Mdot
.48456 .80588 Mdot
.64405 .36449 Mdot
.61538 .67428 Mdot
.61241 .34509 Mdot
.72531 .60799 Mdot
.45549 .33271 Mdot
.35325 .43683 Mdot
.64422 .42422 Mdot
.41008 .3432 Mdot
.46349 .21233 Mdot
.60084 .64957 Mdot
.53985 .53376 Mdot
.36907 .23661 Mdot
.33271 .53877 Mdot
.36445 .42809 Mdot
.44616 .31436 Mdot
.60131 .60686 Mdot
.5317 .55626 Mdot
.41109 .36697 Mdot
.70423 .46237 Mdot
.28762 .61078 Mdot
.55385 .54457 Mdot
.6287 .35819 Mdot
.61015 .3673 Mdot
.59834 .61852 Mdot
.60988 .58061 Mdot
.35918 .56553 Mdot
.36936 .45104 Mdot
.36854 .48895 Mdot
.36493 .42474 Mdot
.3461 .45267 Mdot
.5775 .2858 Mdot
.3978 .32163 Mdot
.54679 .24613 Mdot
.33553 .27065 Mdot
.51702 .53903 Mdot
.34075 .49896 Mdot
.58295 .57867 Mdot
.56123 .55629 Mdot
.42617 .30493 Mdot
.35246 .36212 Mdot
.60034 .49774 Mdot
.63806 .38439 Mdot
.44781 .31475 Mdot
.5587 .64613 Mdot
.60006 .25575 Mdot
.38561 .71328 Mdot
.42173 .21607 Mdot
.42585 .31516 Mdot
.59239 .37537 Mdot
.44392 .36466 Mdot
.58672 .59007 Mdot
.55338 .6208 Mdot
.6026 .37928 Mdot
.36555 .71556 Mdot
.62924 .62935 Mdot
.5598 .58134 Mdot
.15197 .42288 Mdot
.25336 .33923 Mdot
.48245 .36876 Mdot
.60508 .53772 Mdot
.5428 .53862 Mdot
.40316 .70969 Mdot
.58795 .59568 Mdot
.54373 .59201 Mdot
.18217 .4743 Mdot
.49669 .35565 Mdot
.40122 .72061 Mdot
.74138 .4398 Mdot
.57677 .3885 Mdot
.80114 .63518 Mdot
.36479 .47908 Mdot
.45976 .36299 Mdot
.22562 .5395 Mdot
.36642 .44587 Mdot
.29854 .32814 Mdot
.7883 .65337 Mdot
.36511 .42581 Mdot
.39193 .62768 Mdot
.56403 .48355 Mdot
.5449 .55575 Mdot
.55193 .57813 Mdot
.37671 .69364 Mdot
.61027 .39342 Mdot
.4493 .58048 Mdot
.58259 .79876 Mdot
.55744 .56584 Mdot
.64374 .31156 Mdot
.71336 .73129 Mdot
.36035 .44741 Mdot
.39814 .68362 Mdot
.35601 .68127 Mdot
.54761 .58209 Mdot
.19218 .48798 Mdot
.62793 .37726 Mdot
.61011 .59021 Mdot
.61922 .59867 Mdot
.33421 .52375 Mdot
.59375 .38934 Mdot
.33876 .57632 Mdot
.3636 .4173 Mdot
.78011 .39087 Mdot
.16016 .38973 Mdot
.4374 .30907 Mdot
.78942 .6009 Mdot
.39886 .34722 Mdot
.34692 .76311 Mdot
.36969 .43968 Mdot
.60445 .56065 Mdot
.59961 .34236 Mdot
.61192 .59255 Mdot
.59734 .57229 Mdot
.59792 .58285 Mdot
.57003 .64414 Mdot
.30236 .23202 Mdot
.39113 .69071 Mdot
.60771 .51164 Mdot
.3713 .55549 Mdot
.79008 .61035 Mdot
.59791 .81795 Mdot
.57854 .5851 Mdot
.54753 .59215 Mdot
.59537 .3602 Mdot
.53635 .56714 Mdot
.40325 .35918 Mdot
.59089 .34958 Mdot
.61649 .53923 Mdot
.76274 .66627 Mdot
.61913 .55482 Mdot
.82375 .49249 Mdot
.44382 .36525 Mdot
.46124 .21514 Mdot
.62431 .52984 Mdot
.36026 .42633 Mdot
.36459 .42781 Mdot
.36938 .46934 Mdot
.46057 .35232 Mdot
.3488 .50421 Mdot
.52047 .82335 Mdot
.51977 .54446 Mdot
.59259 .53416 Mdot
.52952 .559 Mdot
.34963 .48373 Mdot
.52553 .39023 Mdot
.27129 .39044 Mdot
.57334 .65149 Mdot
.34974 .56273 Mdot
.61622 .41508 Mdot
.41074 .58499 Mdot
.60118 .34403 Mdot
.40872 .71335 Mdot
.43575 .32593 Mdot
.39471 .70825 Mdot
.48724 .19416 Mdot
.6026 .38841 Mdot
.62742 .42053 Mdot
.3414 .50489 Mdot
.51096 .43429 Mdot
.8668 .4022 Mdot
.3259 .53235 Mdot
.47814 .70445 Mdot
.63505 .37857 Mdot
.62319 .58695 Mdot
.42727 .73026 Mdot
.51514 .42907 Mdot
.3481 .51151 Mdot
.59469 .5529 Mdot
.2004 .5319 Mdot
.35792 .56613 Mdot
.5277 .57404 Mdot
.34582 .57482 Mdot
.41857 .32263 Mdot
.33896 .5587 Mdot
.57073 .38434 Mdot
.56627 .60762 Mdot
.87462 .4215 Mdot
.41955 .71786 Mdot
.59639 .5242 Mdot
.45015 .31816 Mdot
.48005 .64322 Mdot
.58783 .56982 Mdot
.39285 .67046 Mdot
.34692 .55117 Mdot
.29358 .58422 Mdot
.56428 .53362 Mdot
.33846 .52465 Mdot
.63298 .34527 Mdot
.45908 .3564 Mdot
.33825 .73779 Mdot
.35366 .44612 Mdot
.62736 .39176 Mdot
.35853 .41026 Mdot
.45418 .3169 Mdot
.54221 .54143 Mdot
.6127 .60547 Mdot
.61899 .35872 Mdot
.21983 .61352 Mdot
.56207 .52942 Mdot
.60756 .55922 Mdot
.37077 .57064 Mdot
.3526 .48884 Mdot
.22666 .61231 Mdot
.33942 .57237 Mdot
.53873 .61118 Mdot
.61978 .35961 Mdot
.57212 .55036 Mdot
.59107 .36729 Mdot
.54055 .59231 Mdot
.57214 .34324 Mdot
.64199 .35608 Mdot
.24589 .43503 Mdot
.58417 .55 Mdot
.64831 .65778 Mdot
.59737 .57774 Mdot
.59233 .60144 Mdot
.36354 .56006 Mdot
.39026 .67987 Mdot
.64683 .57973 Mdot
.35152 .73058 Mdot
.39146 .67264 Mdot
.73353 .34503 Mdot
.33352 .5341 Mdot
.3734 .70375 Mdot
.6664 .74713 Mdot
.37104 .45329 Mdot
.3851 .69704 Mdot
.62488 .80833 Mdot
.4344 .30742 Mdot
.58292 .40083 Mdot
.56866 .53706 Mdot
.75237 .31409 Mdot
.506 .79235 Mdot
.36022 .45943 Mdot
.59899 .52513 Mdot
.58353 .57564 Mdot
.645 .37978 Mdot
.31896 .78272 Mdot
.37505 .5521 Mdot
.58914 .54115 Mdot
.58794 .39053 Mdot
.20734 .69586 Mdot
.37008 .54081 Mdot
.38226 .695 Mdot
.41473 .36906 Mdot
.59301 .33057 Mdot
.35465 .45352 Mdot
.40662 .36686 Mdot
.25956 .43548 Mdot
.46345 .20638 Mdot
.61912 .58054 Mdot
.34146 .4973 Mdot
.47571 .1839 Mdot
.51907 .61773 Mdot
.46448 .37777 Mdot
.6385 .50758 Mdot
.59548 .37517 Mdot
.40859 .36259 Mdot
.39426 .71309 Mdot
.57788 .36341 Mdot
.62917 .35245 Mdot
.41504 .31111 Mdot
.40004 .61655 Mdot
.52712 .44273 Mdot
.40772 .32951 Mdot
.35413 .25166 Mdot
.68979 .27798 Mdot
.36728 .46014 Mdot
.38541 .67195 Mdot
.63968 .23463 Mdot
.62219 .37462 Mdot
.75587 .69977 Mdot
.4302 .20509 Mdot
.55095 .55165 Mdot
.36794 .70279 Mdot
.52688 .32975 Mdot
.55202 .81677 Mdot
.42672 .35267 Mdot
.46741 .40964 Mdot
.35336 .70686 Mdot
.55046 .54462 Mdot
.671 .54876 Mdot
.59747 .54843 Mdot
.43584 .33144 Mdot
.70456 .63794 Mdot
.59176 .37473 Mdot
.44904 .31284 Mdot
.42356 .21512 Mdot
.55501 .56049 Mdot
.59192 .55058 Mdot
.46743 .75978 Mdot
.60274 .40145 Mdot
.36653 .48705 Mdot
.61688 .57624 Mdot
.55833 .57688 Mdot
.55137 .52116 Mdot
.63897 .65555 Mdot
.19674 .45505 Mdot
.58856 .54254 Mdot
.34053 .42023 Mdot
.59407 .51162 Mdot
.5824 .55227 Mdot
.63693 .40102 Mdot
.1861 .35509 Mdot
.35308 .43413 Mdot
.55708 .573 Mdot
.62039 .57291 Mdot
.41891 .30753 Mdot
.48744 .51115 Mdot
.51104 .42285 Mdot
.33031 .49986 Mdot
.5746 .7373 Mdot
.56795 .64338 Mdot
.58404 .36602 Mdot
.35562 .69724 Mdot
.60113 .61553 Mdot
.58358 .36916 Mdot
.63141 .56984 Mdot
.35369 .56656 Mdot
.36756 .45711 Mdot
.4427 .2295 Mdot
.381 .70263 Mdot
.48434 .78837 Mdot
.53949 .25616 Mdot
.3648 .58537 Mdot
.58658 .533 Mdot
.43641 .37832 Mdot
.33438 .49751 Mdot
.35778 .4443 Mdot
.65751 .57818 Mdot
.62301 .38731 Mdot
.60232 .36228 Mdot
.44449 .66112 Mdot
.30672 .41914 Mdot
.15961 .46974 Mdot
.4213 .3216 Mdot
.61909 .53877 Mdot
.50855 .22263 Mdot
.60112 .36205 Mdot
.44071 .70136 Mdot
.37416 .70542 Mdot
.42707 .35423 Mdot
.3759 .50789 Mdot
.58944 .36344 Mdot
.61442 .40636 Mdot
.61931 .62005 Mdot
.56771 .58859 Mdot
.52757 .73312 Mdot
.44545 .63886 Mdot
.41706 .36618 Mdot
.37385 .67469 Mdot
.33913 .57941 Mdot
.59971 .54502 Mdot
.63929 .35054 Mdot
.6716 .25448 Mdot
.62101 .57828 Mdot
.36173 .56583 Mdot
.59832 .37363 Mdot
.36319 .6854 Mdot
.39414 .67277 Mdot
.59163 .60068 Mdot
.69589 .61763 Mdot
.41616 .35731 Mdot
.5976 .36273 Mdot
.59161 .22516 Mdot
.56317 .527 Mdot
.56504 .59236 Mdot
.6665 .58603 Mdot
.40388 .32476 Mdot
.46603 .21752 Mdot
.36383 .71684 Mdot
.61548 .38278 Mdot
.61601 .54899 Mdot
.38613 .70604 Mdot
.48798 .21519 Mdot
.36497 .45354 Mdot
.34204 .56687 Mdot
.39417 .67142 Mdot
.36538 .68837 Mdot
.37856 .66911 Mdot
.74627 .71324 Mdot
.56968 .3814 Mdot
.60696 .68057 Mdot
.58184 .51882 Mdot
.44373 .66668 Mdot
.6423 .61256 Mdot
.4427 .36773 Mdot
.33243 .54576 Mdot
.59491 .57497 Mdot
.61602 .62085 Mdot
.6626 .62293 Mdot
.63176 .66991 Mdot
.66206 .35564 Mdot
.59894 .39073 Mdot
.5248 .52828 Mdot
.33366 .52026 Mdot
.33355 .80658 Mdot
.85328 .45523 Mdot
.62828 .53046 Mdot
.52135 .4566 Mdot
.63322 .34833 Mdot
.40551 .31763 Mdot
.49602 .41831 Mdot
.44704 .36007 Mdot
.61346 .37723 Mdot
.59617 .54401 Mdot
.55359 .25027 Mdot
.40545 .68535 Mdot
.59624 .60732 Mdot
.43206 .33972 Mdot
.59424 .60655 Mdot
.40959 .36764 Mdot
.65699 .29055 Mdot
.33002 .25987 Mdot
.5515 .5552 Mdot
.56121 .52343 Mdot
.66706 .55234 Mdot
.5774 .58327 Mdot
.27931 .70743 Mdot
.62596 .34711 Mdot
.18947 .56666 Mdot
.62195 .61691 Mdot
.74547 .54815 Mdot
.57362 .52101 Mdot
.21184 .54457 Mdot
.57015 .59442 Mdot
.44347 .44932 Mdot
.54873 .55038 Mdot
.55535 .60489 Mdot
.45255 .35121 Mdot
.41911 .30769 Mdot
.6409 .34398 Mdot
.36599 .48718 Mdot
.821 .54027 Mdot
.56074 .58545 Mdot
.35029 .45667 Mdot
.48 .35231 Mdot
.36924 .6812 Mdot
.61549 .37599 Mdot
.22455 .71842 Mdot
.43505 .36384 Mdot
.36876 .60466 Mdot
.225 .63658 Mdot
.35262 .45821 Mdot
.44563 .39917 Mdot
.54538 .47331 Mdot
.36234 .70818 Mdot
.55497 .53933 Mdot
.56944 .19417 Mdot
.26269 .33512 Mdot
.6444 .61663 Mdot
.45575 .32213 Mdot
.76122 .58584 Mdot
.64536 .24191 Mdot
.35879 .67289 Mdot
.38676 .71888 Mdot
.43249 .36314 Mdot
.37792 .56062 Mdot
.55763 .63417 Mdot
.37485 .70739 Mdot
.3587 .58023 Mdot
.372 .45593 Mdot
.40859 .44194 Mdot
.62488 .37867 Mdot
.42507 .21808 Mdot
.51827 .28413 Mdot
.42046 .36739 Mdot
.42055 .66749 Mdot
.60031 .32667 Mdot
.59084 .33806 Mdot
.36096 .47551 Mdot
.36544 .55962 Mdot
.57243 .37347 Mdot
.54848 .62151 Mdot
.64625 .66929 Mdot
.5562 .56882 Mdot
.37467 .68847 Mdot
.57558 .59169 Mdot
.35806 .56121 Mdot
.42428 .34791 Mdot
.36551 .54908 Mdot
.44249 .35843 Mdot
.57714 .27711 Mdot
.60576 .59008 Mdot
.55422 .602 Mdot
.49699 .79506 Mdot
.64638 .35138 Mdot
.53469 .19598 Mdot
.34073 .44446 Mdot
.35871 .5298 Mdot
.54117 .58652 Mdot
.61437 .34141 Mdot
.38951 .65775 Mdot
.49039 .79745 Mdot
.59984 .6108 Mdot
.62418 .34615 Mdot
.59232 .53818 Mdot
.68622 .73268 Mdot
.23437 .34819 Mdot
.62031 .36558 Mdot
.20335 .65823 Mdot
.61094 .54981 Mdot
.49761 .54112 Mdot
.52534 .56857 Mdot
.49356 .68712 Mdot
.55978 .53082 Mdot
.57646 .38535 Mdot
.56068 .56884 Mdot
.58005 .36159 Mdot
.37161 .57473 Mdot
.39806 .32483 Mdot
.63555 .38272 Mdot
.61404 .60755 Mdot
.80974 .66143 Mdot
.43225 .32671 Mdot
.54661 .57598 Mdot
.44677 .33852 Mdot
.58307 .38894 Mdot
.61762 .40302 Mdot
.55089 .82568 Mdot
.48965 .357 Mdot
.41721 .32403 Mdot
.58257 .54071 Mdot
.48676 .27039 Mdot
.57951 .54747 Mdot
.50852 .72889 Mdot
.58196 .62328 Mdot
.55774 .53154 Mdot
.53196 .84922 Mdot
.39883 .35506 Mdot
.16535 .46771 Mdot
.59824 .79062 Mdot
.73439 .72517 Mdot
.57039 .35591 Mdot
.35914 .67286 Mdot
.77049 .67094 Mdot
.36487 .41695 Mdot
.34188 .55406 Mdot
.59477 .57647 Mdot
.66382 .38762 Mdot
.40554 .35408 Mdot
.3885 .6802 Mdot
.55094 .55636 Mdot
.36556 .5633 Mdot
.33365 .62933 Mdot
.39607 .31908 Mdot
.62094 .37564 Mdot
.64251 .37699 Mdot
.18594 .65307 Mdot
.61556 .54703 Mdot
.54602 .59314 Mdot
.43674 .32936 Mdot
.58797 .66704 Mdot
.35821 .69354 Mdot
.24264 .57603 Mdot
.41805 .32407 Mdot
.49075 .46682 Mdot
.60337 .394 Mdot
.58381 .57703 Mdot
.5329 .39872 Mdot
.39186 .45896 Mdot
.74867 .40619 Mdot
.37923 .69117 Mdot
.50727 .73718 Mdot
.57647 .3861 Mdot
.42519 .33973 Mdot
.31017 .4615 Mdot
.57143 .50718 Mdot
.57858 .57439 Mdot
.50315 .73945 Mdot
.43631 .6178 Mdot
.36716 .76907 Mdot
.53795 .59718 Mdot
.43981 .60983 Mdot
.54656 .60419 Mdot
.55282 .51753 Mdot
.54965 .62004 Mdot
.56421 .59805 Mdot
.62713 .34672 Mdot
.63913 .6456 Mdot
.33771 .54018 Mdot
.68547 .44273 Mdot
.48396 .40689 Mdot
.57941 .52392 Mdot
.5908 .54549 Mdot
.77616 .44645 Mdot
.46692 .29974 Mdot
.6372 .35753 Mdot
.58532 .42703 Mdot
.4241 .30023 Mdot
.65178 .65598 Mdot
.36415 .49693 Mdot
.65225 .62525 Mdot
.36359 .55259 Mdot
.61609 .3438 Mdot
.36046 .52727 Mdot
.40255 .31164 Mdot
.34105 .49723 Mdot
.34468 .44994 Mdot
.40564 .35923 Mdot
.61181 .39996 Mdot
.58154 .60502 Mdot
.44646 .31347 Mdot
.47111 .75831 Mdot
.37464 .68956 Mdot
.55378 .82539 Mdot
.62771 .56455 Mdot
.49638 .38199 Mdot
.54554 .68353 Mdot
.3643 .54784 Mdot
.20533 .39965 Mdot
.64243 .35718 Mdot
.4089 .6859 Mdot
.61808 .34337 Mdot
.3896 .20717 Mdot
.38546 .67557 Mdot
.63256 .80521 Mdot
.31784 .40009 Mdot
.3215 .61037 Mdot
.56007 .62757 Mdot
.62244 .48075 Mdot
.32775 .52518 Mdot
.40641 .35578 Mdot
.30982 .39916 Mdot
.56129 .6086 Mdot
.23046 .4264 Mdot
.64702 .34771 Mdot
.36869 .46598 Mdot
.41946 .33873 Mdot
.44376 .30822 Mdot
.61554 .59112 Mdot
.25831 .62921 Mdot
.57132 .61513 Mdot
.29779 .41956 Mdot
.5493 .7425 Mdot
.66914 .59646 Mdot
.54398 .57037 Mdot
.36351 .52037 Mdot
.591 .53791 Mdot
.64271 .68373 Mdot
.53363 .18039 Mdot
.59376 .64666 Mdot
.34427 .38284 Mdot
.41357 .6603 Mdot
.60357 .38327 Mdot
.62828 .53799 Mdot
.35567 .44838 Mdot
.60884 .54368 Mdot
.49863 .14232 Mdot
.38612 .69937 Mdot
.31498 .54621 Mdot
.57849 .51671 Mdot
.61602 .58379 Mdot
.64394 .43744 Mdot
.65608 .40371 Mdot
.37647 .50862 Mdot
.57274 .57385 Mdot
.57042 .75258 Mdot
.44117 .32232 Mdot
.57826 .61587 Mdot
.55039 .57863 Mdot
.75328 .36439 Mdot
.41026 .31861 Mdot
.36522 .54127 Mdot
.37162 .43417 Mdot
.34649 .58767 Mdot
.37765 .73075 Mdot
.47861 .43001 Mdot
.44592 .67875 Mdot
.24263 .34257 Mdot
.36498 .67136 Mdot
.62241 .56586 Mdot
.59176 .493 Mdot
.61504 .56205 Mdot
.39381 .71525 Mdot
.40449 .32633 Mdot
.64068 .36086 Mdot
.45092 .236 Mdot
.36305 .44033 Mdot
.52804 .57021 Mdot
.40287 .69589 Mdot
.62106 .39225 Mdot
.41505 .71831 Mdot
.60943 .38374 Mdot
.41418 .33186 Mdot
.45192 .30563 Mdot
.39701 .69018 Mdot
.60419 .34377 Mdot
.34535 .41675 Mdot
.57378 .79985 Mdot
.57274 .62336 Mdot
.40565 .39302 Mdot
.62801 .34199 Mdot
.65401 .34194 Mdot
.63167 .33359 Mdot
.59842 .59823 Mdot
.51893 .46543 Mdot
.57561 .51057 Mdot
.42492 .36391 Mdot
.34932 .57572 Mdot
.44814 .64592 Mdot
.65636 .27164 Mdot
.41879 .63607 Mdot
.63594 .61783 Mdot
.55768 .56157 Mdot
.54764 .58166 Mdot
.59241 .62801 Mdot
.29917 .45038 Mdot
.60863 .58401 Mdot
.45088 .35249 Mdot
.35483 .55373 Mdot
.58218 .52055 Mdot
.35899 .46297 Mdot
.53457 .43848 Mdot
.35502 .69341 Mdot
.4724 .42326 Mdot
.81404 .62074 Mdot
.62393 .39148 Mdot
.33511 .56689 Mdot
.34069 .54963 Mdot
.3684 .67283 Mdot
.40647 .35245 Mdot
.6094 .38961 Mdot
.51108 .69498 Mdot
.37649 .67124 Mdot
.55947 .57184 Mdot
.23536 .49735 Mdot
.22553 .47312 Mdot
.54431 .54964 Mdot
.5959 .56506 Mdot
.37276 .44106 Mdot
.37733 .55382 Mdot
.68918 .22908 Mdot
.42337 .74342 Mdot
.39454 .68467 Mdot
.36956 .71681 Mdot
.60242 .33287 Mdot
.62269 .51722 Mdot
.43031 .3612 Mdot
.44122 .76353 Mdot
.46751 .63627 Mdot
.46588 .78501 Mdot
.33392 .73384 Mdot
.60991 .60292 Mdot
.65746 .49827 Mdot
.55513 .55803 Mdot
.64819 .36599 Mdot
.59371 .39855 Mdot
.63664 .36823 Mdot
.41413 .35964 Mdot
.73087 .60522 Mdot
.45441 .3404 Mdot
.83195 .57197 Mdot
.57489 .38128 Mdot
.28885 .49569 Mdot
.35453 .51404 Mdot
.62179 .53413 Mdot
.36003 .69302 Mdot
.38551 .33542 Mdot
.58432 .64122 Mdot
.19224 .47159 Mdot
.34211 .49839 Mdot
.60817 .40193 Mdot
.54547 .4746 Mdot
.8196 .42698 Mdot
.50362 .43472 Mdot
.50266 .56689 Mdot
.63254 .45638 Mdot
.37433 .67595 Mdot
.74614 .40695 Mdot
.38384 .72538 Mdot
.43208 .34759 Mdot
.56122 .60516 Mdot
.57042 .60426 Mdot
.54073 .59423 Mdot
.60721 .58543 Mdot
.42002 .30444 Mdot
.64084 .59521 Mdot
.35746 .206 Mdot
.37009 .45338 Mdot
.70261 .72129 Mdot
.381 .71227 Mdot
.46071 .34012 Mdot
.35699 .55353 Mdot
.37078 .49346 Mdot
.44775 .72001 Mdot
.55124 .54816 Mdot
.59665 .57581 Mdot
.3804 .53129 Mdot
.53419 .58997 Mdot
.57681 .65024 Mdot
.33839 .53459 Mdot
.42008 .63537 Mdot
.37439 .66313 Mdot
.39311 .70957 Mdot
.4065 .32653 Mdot
.60947 .34283 Mdot
.37429 .69896 Mdot
.37261 .56798 Mdot
.63571 .58035 Mdot
.61937 .60463 Mdot
.62895 .3417 Mdot
.42774 .20531 Mdot
.35448 .68168 Mdot
.53965 .47693 Mdot
.57986 .36741 Mdot
.56918 .38177 Mdot
.5786 .57268 Mdot
.64344 .62484 Mdot
.64962 .33045 Mdot
.38226 .66576 Mdot
.46082 .33529 Mdot
.31346 .58442 Mdot
.4357 .34093 Mdot
.61312 .39298 Mdot
.61117 .61807 Mdot
.60722 .39836 Mdot
.60583 .53656 Mdot
.6629 .84042 Mdot
.56993 .60099 Mdot
.26994 .29869 Mdot
.4908 .69805 Mdot
.34163 .54345 Mdot
.34651 .41892 Mdot
.36382 .4715 Mdot
.57802 .3728 Mdot
.60874 .61501 Mdot
.37194 .71973 Mdot
.68958 .77044 Mdot
.60835 .32352 Mdot
.34894 .56716 Mdot
.37009 .51221 Mdot
.39995 .35275 Mdot
.58942 .51839 Mdot
.58044 .5783 Mdot
.34684 .49833 Mdot
.59383 .7055 Mdot
.59436 .35618 Mdot
.54501 .58822 Mdot
.56884 .5566 Mdot
.34044 .53763 Mdot
.56819 .80039 Mdot
.60133 .45126 Mdot
.5594 .60107 Mdot
.31499 .4941 Mdot
.44865 .36347 Mdot
.57781 .63029 Mdot
.64138 .5961 Mdot
.36453 .69968 Mdot
.73834 .67876 Mdot
.55692 .18216 Mdot
.43584 .37097 Mdot
.36528 .48402 Mdot
.62152 .55402 Mdot
.35323 .51263 Mdot
.61761 .6052 Mdot
.79569 .56768 Mdot
.36856 .46155 Mdot
.6098 .57023 Mdot
.63347 .5303 Mdot
.59757 .40183 Mdot
.61123 .58373 Mdot
.77419 .41805 Mdot
.32783 .5492 Mdot
.61096 .5764 Mdot
.69555 .6053 Mdot
.42056 .31318 Mdot
.63031 .53338 Mdot
.3833 .71567 Mdot
.49436 .68331 Mdot
.54037 .26575 Mdot
.32776 .49062 Mdot
.39123 .70942 Mdot
.58952 .60987 Mdot
.37874 .55909 Mdot
.41807 .36844 Mdot
.22497 .42429 Mdot
.53812 .5794 Mdot
.43494 .33053 Mdot
.42312 .34635 Mdot
.39072 .70278 Mdot
.15636 .51769 Mdot
.63817 .57229 Mdot
.57782 .58592 Mdot
.77955 .41427 Mdot
.63594 .39725 Mdot
.57728 .59549 Mdot
.6219 .57481 Mdot
.45013 .34991 Mdot
.64779 .42091 Mdot
.77535 .5316 Mdot
.24292 .59495 Mdot
.41517 .37318 Mdot
.33809 .58921 Mdot
.37906 .55868 Mdot
.37836 .71166 Mdot
.60377 .37573 Mdot
.35781 .7173 Mdot
.33495 .53216 Mdot
.61985 .56056 Mdot
.44197 .35465 Mdot
.70972 .33497 Mdot
.3981 .36322 Mdot
.32629 .50072 Mdot
.65219 .36166 Mdot
.49819 .23161 Mdot
.42562 .15094 Mdot
.52668 .28859 Mdot
.43889 .28416 Mdot
.36901 .68158 Mdot
.2577 .4417 Mdot
.56494 .55826 Mdot
.73668 .41263 Mdot
.58678 .60507 Mdot
.68617 .55858 Mdot
.34077 .57267 Mdot
.36985 .49922 Mdot
.56128 .60388 Mdot
.53281 .74296 Mdot
.3916 .35279 Mdot
.40117 .35776 Mdot
.60542 .5734 Mdot
.40994 .34263 Mdot
.56789 .58474 Mdot
.36233 .55827 Mdot
.1747 .43034 Mdot
.55198 .56692 Mdot
.54522 .52897 Mdot
.42722 .27079 Mdot
.57041 .8226 Mdot
.32927 .41378 Mdot
.64993 .48783 Mdot
.80212 .39054 Mdot
.41044 .34301 Mdot
.64883 .54881 Mdot
.32976 .50818 Mdot
.37289 .44009 Mdot
.34648 .41675 Mdot
.5841 .59774 Mdot
.58925 .59541 Mdot
.5412 .58471 Mdot
.59299 .55017 Mdot
.74072 .41503 Mdot
.61055 .66303 Mdot
.68959 .52857 Mdot
.5979 .57363 Mdot
.671 .54652 Mdot
.4452 .31381 Mdot
.63976 .4075 Mdot
.35197 .71019 Mdot
.61101 .60154 Mdot
.66626 .32981 Mdot
.45436 .35761 Mdot
.83293 .56921 Mdot
.40072 .33836 Mdot
.35278 .53473 Mdot
.39925 .327 Mdot
.59515 .5266 Mdot
.61006 .36659 Mdot
.32581 .51829 Mdot
.26183 .37365 Mdot
.34279 .556 Mdot
.59641 .52413 Mdot
.31053 .55582 Mdot
.34011 .55214 Mdot
.52659 .41654 Mdot
.60547 .36751 Mdot
.56101 .75884 Mdot
.59322 .3986 Mdot
.61171 .57214 Mdot
.61057 .56599 Mdot
.36142 .40313 Mdot
.393 .33346 Mdot
.5841 .39182 Mdot
.14759 .43477 Mdot
.37941 .72743 Mdot
.6341 .36749 Mdot
.54728 .51201 Mdot
.46292 .5521 Mdot
.61241 .36025 Mdot
.56342 .71857 Mdot
.40875 .3594 Mdot
.57589 .36335 Mdot
.55166 .51075 Mdot
.35686 .28679 Mdot
.40337 .67703 Mdot
.37081 .52777 Mdot
.43935 .47397 Mdot
.32798 .53329 Mdot
.46189 .33347 Mdot
.34692 .4895 Mdot
.44207 .32083 Mdot
.52223 .19893 Mdot
.67325 .66378 Mdot
.43063 .38031 Mdot
.45562 .31545 Mdot
.34064 .50918 Mdot
.54159 .57064 Mdot
.42866 .42021 Mdot
.54125 .60558 Mdot
.58339 .63793 Mdot
.43643 .31621 Mdot
.57913 .39083 Mdot
.58541 .40388 Mdot
.64561 .50743 Mdot
.64267 .37747 Mdot
.36453 .55495 Mdot
.23689 .3448 Mdot
.49297 .19371 Mdot
.43531 .32201 Mdot
.43968 .30188 Mdot
.58279 .54663 Mdot
.34854 .50719 Mdot
.37052 .58249 Mdot
.42699 .35925 Mdot
.71455 .38603 Mdot
.58282 .51114 Mdot
.65547 .35296 Mdot
.57424 .37924 Mdot
.62059 .36204 Mdot
.61993 .3313 Mdot
.76791 .51394 Mdot
.4084 .35989 Mdot
.57616 .37739 Mdot
.60689 .57036 Mdot
.58752 .59549 Mdot
.3617 .43006 Mdot
.39124 .71166 Mdot
.62887 .56097 Mdot
.53285 .60661 Mdot
.58153 .57274 Mdot
.34182 .56513 Mdot
.55648 .49584 Mdot
.36747 .48255 Mdot
.37479 .54389 Mdot
.35398 .47183 Mdot
.3549 .43232 Mdot
.61406 .47397 Mdot
.80702 .38406 Mdot
.58951 .54102 Mdot
.57519 .67022 Mdot
.35383 .51665 Mdot
.19797 .43004 Mdot
.4731 .21839 Mdot
.53973 .58361 Mdot
.39948 .45577 Mdot
.34788 .49446 Mdot
.63174 .39806 Mdot
.58026 .5996 Mdot
.36766 .42672 Mdot
.35567 .69236 Mdot
.53384 .523 Mdot
.37068 .42827 Mdot
.5969 .34737 Mdot
.34579 .70419 Mdot
.58339 .35127 Mdot
.33996 .49316 Mdot
.63289 .53115 Mdot
.86765 .39599 Mdot
.34855 .58821 Mdot
.64888 .77606 Mdot
.67325 .34657 Mdot
.54367 .5854 Mdot
.3342 .56699 Mdot
.63808 .39318 Mdot
.46277 .34255 Mdot
.45429 .57332 Mdot
.64365 .36448 Mdot
.36935 .49505 Mdot
.36746 .43333 Mdot
.33858 .53907 Mdot
.59664 .38752 Mdot
.58786 .61875 Mdot
.58878 .37822 Mdot
.39905 .32867 Mdot
.56324 .54765 Mdot
.83256 .48987 Mdot
.58683 .67013 Mdot
.57823 .37635 Mdot
.36965 .56122 Mdot
.40566 .70462 Mdot
.55571 .5477 Mdot
.64082 .7709 Mdot
.61155 .5358 Mdot
.44141 .32758 Mdot
.19307 .53387 Mdot
.72253 .34871 Mdot
.5738 .52205 Mdot
.58425 .54674 Mdot
.40909 .36453 Mdot
.55246 .54815 Mdot
.5643 .52838 Mdot
.48132 .3607 Mdot
.59216 .38995 Mdot
.56198 .56538 Mdot
.36544 .57896 Mdot
.56964 .20071 Mdot
.57773 .51154 Mdot
.39173 .52778 Mdot
.54759 .75447 Mdot
.18279 .53611 Mdot
.58187 .60799 Mdot
.43836 .74665 Mdot
.59506 .5546 Mdot
.60191 .6024 Mdot
.57949 .54355 Mdot
.64731 .47314 Mdot
.33841 .51101 Mdot
.35255 .56099 Mdot
.40045 .67351 Mdot
.55397 .75403 Mdot
.36718 .70337 Mdot
.40175 .34681 Mdot
.3357 .64821 Mdot
.36758 .46189 Mdot
.59848 .34559 Mdot
.58048 .61347 Mdot
.32684 .54996 Mdot
.58606 .57883 Mdot
.59824 .52973 Mdot
.365 .52112 Mdot
.36859 .58969 Mdot
.33911 .47697 Mdot
.36341 .71293 Mdot
.63829 .37314 Mdot
.62232 .61975 Mdot
.39226 .67336 Mdot
.59092 .61782 Mdot
.43769 .67174 Mdot
.63895 .36702 Mdot
.59062 .38756 Mdot
.60855 .41183 Mdot
.61977 .55969 Mdot
.58208 .52438 Mdot
.45403 .33752 Mdot
.60731 .34128 Mdot
.41378 .32045 Mdot
.32859 .50748 Mdot
.37546 .60357 Mdot
.5843 .59765 Mdot
.50597 .51612 Mdot
.3637 .70547 Mdot
.35568 .54232 Mdot
.38276 .53682 Mdot
.4096 .69259 Mdot
.60861 .53444 Mdot
.36207 .51749 Mdot
.39795 .70546 Mdot
.69718 .39197 Mdot
.78479 .33972 Mdot
.4012 .71161 Mdot
.6051 .57018 Mdot
.66254 .41065 Mdot
.54856 .80028 Mdot
.38631 .72727 Mdot
.44366 .34395 Mdot
.62084 .56069 Mdot
.57133 .68515 Mdot
.35254 .69428 Mdot
.56674 .20661 Mdot
.34275 .5412 Mdot
.36226 .30053 Mdot
.51416 .57777 Mdot
.72186 .41958 Mdot
.36538 .72434 Mdot
.61245 .38629 Mdot
.63005 .41118 Mdot
.58173 .56421 Mdot
.36769 .73118 Mdot
.40976 .37158 Mdot
.34582 .54622 Mdot
.34616 .44097 Mdot
.59479 .38548 Mdot
.46877 .2711 Mdot
.35763 .57505 Mdot
.52675 .48749 Mdot
.22164 .56433 Mdot
.65357 .66122 Mdot
.6869 .59086 Mdot
.28258 .31995 Mdot
.62439 .5783 Mdot
.39416 .71852 Mdot
.45475 .35433 Mdot
.43659 .36105 Mdot
.41835 .32611 Mdot
.34678 .42134 Mdot
.49196 .41844 Mdot
.33426 .50556 Mdot
.24453 .40447 Mdot
.38505 .70625 Mdot
.59247 .75234 Mdot
.59438 .61576 Mdot
.55639 .56274 Mdot
.62024 .54047 Mdot
.56829 .61624 Mdot
.5873 .55578 Mdot
.40671 .34718 Mdot
.34484 .42202 Mdot
.29097 .58057 Mdot
.62682 .35675 Mdot
.40647 .63306 Mdot
.35475 .51428 Mdot
.37253 .44466 Mdot
.39076 .68699 Mdot
.55178 .45975 Mdot
.3397 .4874 Mdot
.36078 .52949 Mdot
.62925 .55579 Mdot
.5881 .36638 Mdot
.64563 .62773 Mdot
.60657 .55821 Mdot
.35802 .54676 Mdot
.39519 .59832 Mdot
.78851 .49273 Mdot
.6412 .52299 Mdot
.35947 .66309 Mdot
.50232 .48619 Mdot
.38799 .72611 Mdot
.52434 .56343 Mdot
.19369 .44194 Mdot
.3353 .52987 Mdot
.34827 .52637 Mdot
.39952 .70741 Mdot
.51047 .51873 Mdot
.59788 .3777 Mdot
.37246 .50643 Mdot
.4483 .33445 Mdot
.61465 .56589 Mdot
.37465 .59971 Mdot
.49776 .5729 Mdot
.2763 .63046 Mdot
.42433 .32318 Mdot
.37395 .55401 Mdot
.58747 .51833 Mdot
.60343 .56884 Mdot
.36977 .67893 Mdot
.6302 .2939 Mdot
.52495 .5318 Mdot
.7371 .7231 Mdot
.33723 .25774 Mdot
.38142 .24488 Mdot
.57846 .57455 Mdot
.59512 .39082 Mdot
.36936 .44032 Mdot
.38275 .67182 Mdot
.63498 .60916 Mdot
.79082 .35302 Mdot
.65672 .36952 Mdot
.42983 .3425 Mdot
.36661 .42603 Mdot
.49609 .41664 Mdot
.61761 .54701 Mdot
.58607 .60461 Mdot
.60233 .59303 Mdot
.73831 .27017 Mdot
.351 .5711 Mdot
.64807 .35794 Mdot
.38038 .68881 Mdot
.64449 .37434 Mdot
.3469 .55707 Mdot
.46578 .24583 Mdot
.5688 .52928 Mdot
.65417 .35904 Mdot
.61238 .38292 Mdot
.39995 .35198 Mdot
.46348 .33797 Mdot
.33 .58943 Mdot
.56895 .59993 Mdot
.36847 .42764 Mdot
.59607 .40246 Mdot
.37895 .53526 Mdot
.38333 .67502 Mdot
.45337 .32612 Mdot
.59865 .57484 Mdot
.33626 .54017 Mdot
.63608 .62432 Mdot
.60674 .35767 Mdot
.36019 .52823 Mdot
.35323 .45218 Mdot
.37365 .71738 Mdot
.59376 .58665 Mdot
.36789 .65807 Mdot
.36453 .48602 Mdot
.56769 .55609 Mdot
.57498 .45539 Mdot
.35217 .66637 Mdot
.27007 .38265 Mdot
.33113 .52197 Mdot
.3557 .43855 Mdot
.60996 .40969 Mdot
.56751 .21656 Mdot
.34826 .53221 Mdot
.56502 .45469 Mdot
.59066 .29256 Mdot
.62263 .62001 Mdot
.62276 .37085 Mdot
.24723 .46292 Mdot
.78315 .67549 Mdot
.61514 .76262 Mdot
.54739 .57689 Mdot
.33082 .55358 Mdot
.40128 .69138 Mdot
.43531 .32143 Mdot
.39106 .52669 Mdot
.6471 .6775 Mdot
.35863 .5025 Mdot
.58386 .54355 Mdot
.59197 .39546 Mdot
.42262 .35689 Mdot
.56598 .25493 Mdot
.372 .56445 Mdot
.3375 .56691 Mdot
.58068 .5201 Mdot
.37576 .70518 Mdot
.66027 .7208 Mdot
.35982 .56253 Mdot
.37095 .60005 Mdot
.25914 .43224 Mdot
.40321 .69725 Mdot
.59683 .56019 Mdot
.65089 .51486 Mdot
.58918 .6294 Mdot
.65749 .77624 Mdot
.36416 .47735 Mdot
.62472 .35456 Mdot
.59188 .60484 Mdot
.23686 .59719 Mdot
.35427 .54752 Mdot
.52147 .45277 Mdot
.38118 .6126 Mdot
.40974 .3603 Mdot
.37167 .60103 Mdot
.58088 .58997 Mdot
.39232 .35491 Mdot
.36398 .70541 Mdot
.5601 .59891 Mdot
.58121 .52536 Mdot
.63818 .39026 Mdot
.43293 .34852 Mdot
.67588 .28418 Mdot
.44839 .3115 Mdot
.44455 .36442 Mdot
.59351 .41351 Mdot
.56926 .56834 Mdot
.35524 .53421 Mdot
.34963 .49244 Mdot
.62642 .61583 Mdot
.20052 .38808 Mdot
.59584 .37872 Mdot
.42392 .67607 Mdot
.70511 .25069 Mdot
.64112 .51695 Mdot
.38322 .54675 Mdot
.61725 .29617 Mdot
.41193 .37149 Mdot
.60221 .57292 Mdot
.58376 .3642 Mdot
.3762 .5836 Mdot
.35881 .5761 Mdot
.60262 .61888 Mdot
.42134 .35088 Mdot
.35994 .67896 Mdot
.35067 .58695 Mdot
.2591 .62802 Mdot
.60785 .59234 Mdot
.23637 .42451 Mdot
.34199 .57791 Mdot
.71191 .76242 Mdot
.28551 .59756 Mdot
.62453 .3675 Mdot
.59465 .52855 Mdot
.64117 .37841 Mdot
.3778 .68513 Mdot
.33155 .58303 Mdot
.42323 .3494 Mdot
.62849 .50621 Mdot
.47167 .16233 Mdot
.34048 .50573 Mdot
.62824 .34746 Mdot
.57576 .52094 Mdot
.58825 .47667 Mdot
.57491 .58901 Mdot
.63709 .43269 Mdot
.42385 .68285 Mdot
.43251 .31386 Mdot
.44286 .33183 Mdot
.56367 .55523 Mdot
.36367 .68052 Mdot
.37113 .53985 Mdot
.34579 .54388 Mdot
.43232 .87145 Mdot
.37674 .52097 Mdot
.52441 .72793 Mdot
.591 .59244 Mdot
.3765 .52722 Mdot
.64922 .26105 Mdot
.43641 .32827 Mdot
.57204 .61805 Mdot
.36718 .50074 Mdot
.34714 .27787 Mdot
.43627 .64854 Mdot
.58928 .55762 Mdot
.54763 .63804 Mdot
.44736 .33588 Mdot
.49274 .78107 Mdot
.33753 .5004 Mdot
.57654 .62161 Mdot
.42578 .29749 Mdot
.22215 .59542 Mdot
.49233 .18325 Mdot
.63812 .37315 Mdot
.32711 .558 Mdot
.40653 .34788 Mdot
.51279 .56084 Mdot
.38388 .71233 Mdot
.32708 .53922 Mdot
.34415 .56557 Mdot
.57891 .53836 Mdot
.62731 .54782 Mdot
.63277 .50449 Mdot
.62334 .34783 Mdot
.43814 .3079 Mdot
.56313 .60733 Mdot
.46807 .27336 Mdot
.54404 .59991 Mdot
.44974 .32249 Mdot
.91071 .49123 Mdot
.57073 .63266 Mdot
.57452 .58674 Mdot
.65307 .73042 Mdot
.64347 .36832 Mdot
.6395 .38445 Mdot
.29694 .28252 Mdot
.59124 .59187 Mdot
.30705 .61647 Mdot
.63697 .37817 Mdot
.59593 .3739 Mdot
.27699 .50497 Mdot
.55279 .5571 Mdot
.48577 .79519 Mdot
.43515 .36018 Mdot
.44629 .35854 Mdot
.59002 .38002 Mdot
.5174 .54602 Mdot
.41975 .37084 Mdot
.75823 .44883 Mdot
.34903 .50463 Mdot
.18904 .45107 Mdot
.60742 .35462 Mdot
.45552 .40741 Mdot
.43166 .32307 Mdot
.83038 .57684 Mdot
.39486 .45282 Mdot
.54168 .57935 Mdot
.59785 .58704 Mdot
.3664 .70908 Mdot
.61782 .62636 Mdot
.36864 .48928 Mdot
.40975 .34225 Mdot
.68422 .70096 Mdot
.63617 .36872 Mdot
.56835 .59495 Mdot
.54198 .46428 Mdot
.56795 .27012 Mdot
.32178 .38379 Mdot
.60429 .38274 Mdot
.62529 .37546 Mdot
.3338 .51696 Mdot
.34439 .57645 Mdot
.57607 .5639 Mdot
.42496 .36293 Mdot
.60182 .34204 Mdot
.44651 .32034 Mdot
.33502 .53601 Mdot
.3596 .53319 Mdot
.36933 .46018 Mdot
.5345 .59858 Mdot
.36978 .5485 Mdot
.24707 .62975 Mdot
.46227 .26453 Mdot
.59296 .3365 Mdot
.52466 .16186 Mdot
.56615 .25352 Mdot
.52577 .6808 Mdot
.36758 .71936 Mdot
.36411 .48702 Mdot
.41261 .31009 Mdot
.58049 .54839 Mdot
.59162 .57726 Mdot
.36034 .4482 Mdot
.39431 .34158 Mdot
.3844 .67979 Mdot
.39314 .34121 Mdot
.39013 .70617 Mdot
.38081 .55148 Mdot
.59693 .51858 Mdot
.62027 .59191 Mdot
.40795 .34021 Mdot
.36492 .53463 Mdot
.35428 .55618 Mdot
.3877 .72555 Mdot
.44206 .6252 Mdot
.33798 .54128 Mdot
.60694 .35548 Mdot
.75814 .51817 Mdot
.36737 .43861 Mdot
.57916 .59803 Mdot
.44277 .68465 Mdot
.73086 .39225 Mdot
.59139 .6259 Mdot
.36199 .42544 Mdot
.29496 .7606 Mdot
.58056 .61134 Mdot
.23879 .71363 Mdot
.35586 .43672 Mdot
.64441 .3643 Mdot
.33155 .55469 Mdot
.3701 .48867 Mdot
.51534 .60436 Mdot
.41565 .69747 Mdot
.63271 .59682 Mdot
.63873 .37982 Mdot
.63061 .40641 Mdot
.36506 .23948 Mdot
.64949 .77678 Mdot
.3841 .72427 Mdot
.39501 .69295 Mdot
.34677 .53181 Mdot
.48516 .83815 Mdot
.58128 .50563 Mdot
.39247 .68316 Mdot
.64599 .70833 Mdot
.59121 .54367 Mdot
.49646 .72929 Mdot
.40366 .46044 Mdot
.59441 .388 Mdot
.62644 .48611 Mdot
.35033 .54053 Mdot
.63281 .35044 Mdot
.44072 .24581 Mdot
.62597 .55725 Mdot
.63813 .36587 Mdot
.45123 .32844 Mdot
.29855 .33354 Mdot
.62072 .40077 Mdot
.43848 .68607 Mdot
.4257 .36079 Mdot
.26897 .44299 Mdot
.62275 .72391 Mdot
.38837 .14443 Mdot
.40908 .35056 Mdot
.35658 .50901 Mdot
.34842 .49461 Mdot
.3448 .53995 Mdot
.64348 .35678 Mdot
.37334 .57185 Mdot
.616 .34687 Mdot
.54204 .80936 Mdot
.44317 .62617 Mdot
.39737 .68985 Mdot
.4893 .34817 Mdot
.61836 .37999 Mdot
.22481 .38423 Mdot
.44097 .15024 Mdot
.60614 .57578 Mdot
.44084 .30416 Mdot
.3973 .70991 Mdot
.66968 .80284 Mdot
.36487 .70363 Mdot
.3293 .51147 Mdot
.17837 .47329 Mdot
.56494 .58728 Mdot
.76736 .58865 Mdot
.37644 .72042 Mdot
.60574 .39194 Mdot
.56335 .55819 Mdot
.34662 .41313 Mdot
.37479 .7089 Mdot
.35739 .68522 Mdot
.57468 .55907 Mdot
.60687 .40229 Mdot
.35837 .53689 Mdot
.40873 .31007 Mdot
.39563 .72561 Mdot
.53526 .6409 Mdot
.62001 .62191 Mdot
.62536 .56412 Mdot
.51205 .42974 Mdot
.63126 .69819 Mdot
.41064 .34429 Mdot
.56847 .78085 Mdot
.34593 .57675 Mdot
.25505 .48655 Mdot
.30662 .27905 Mdot
.48012 .37857 Mdot
.36232 .47357 Mdot
.3662 .47589 Mdot
.58453 .55824 Mdot
.63176 .69898 Mdot
.19652 .54786 Mdot
.44651 .28002 Mdot
.3673 .44237 Mdot
.34822 .54911 Mdot
.63644 .40624 Mdot
.37046 .22895 Mdot
.63284 .61817 Mdot
.4202 .37565 Mdot
.33744 .54917 Mdot
.79711 .5639 Mdot
.37936 .7023 Mdot
.20662 .41788 Mdot
.57734 .52245 Mdot
.55354 .60137 Mdot
.41682 .33767 Mdot
.45416 .34369 Mdot
.36629 .39428 Mdot
.34995 .24656 Mdot
.43638 .77628 Mdot
.60057 .23936 Mdot
.79626 .55428 Mdot
.64248 .4035 Mdot
.57814 .37941 Mdot
.36281 .41686 Mdot
.45587 .3251 Mdot
.58971 .60784 Mdot
.59855 .3446 Mdot
.31188 .387 Mdot
.55952 .38989 Mdot
.5106 .73306 Mdot
.29215 .62259 Mdot
.60697 .53513 Mdot
.58506 .37195 Mdot
.63799 .35576 Mdot
.60529 .33727 Mdot
.3584 .42788 Mdot
.57268 .57461 Mdot
.54576 .56177 Mdot
.55843 .60981 Mdot
.58318 .66364 Mdot
.61036 .58796 Mdot
.47184 .29327 Mdot
.49429 .47007 Mdot
.70985 .69048 Mdot
.57519 .62613 Mdot
.43771 .3634 Mdot
.62781 .5751 Mdot
.364 .6791 Mdot
.58067 .54475 Mdot
.51178 .72771 Mdot
.42973 .33208 Mdot
.53345 .49447 Mdot
.59324 .2348 Mdot
.57285 .52576 Mdot
.36712 .66829 Mdot
.57511 .69192 Mdot
.67643 .29342 Mdot
.41243 .62677 Mdot
.60542 .3562 Mdot
.35427 .49019 Mdot
.39944 .33079 Mdot
.35418 .53013 Mdot
.55976 .6203 Mdot
.36543 .42072 Mdot
.52197 .32573 Mdot
.45141 .40999 Mdot
.6032 .60815 Mdot
.5903 .49934 Mdot
.59884 .36395 Mdot
.36132 .51652 Mdot
.62587 .42292 Mdot
.59637 .59912 Mdot
.37724 .69032 Mdot
.37905 .70965 Mdot
.40763 .25225 Mdot
.8197 .53012 Mdot
.54936 .20865 Mdot
.41505 .33837 Mdot
.35824 .56557 Mdot
.36362 .72424 Mdot
.54862 .65925 Mdot
.44179 .37235 Mdot
.40529 .36291 Mdot
.42993 .3533 Mdot
.61586 .55774 Mdot
.36705 .48483 Mdot
.70937 .67777 Mdot
.36869 .49196 Mdot
.57267 .52783 Mdot
.34837 .5717 Mdot
.36895 .46689 Mdot
.3708 .71245 Mdot
.40623 .32634 Mdot
.33411 .5416 Mdot
.6129 .57405 Mdot
.62851 .38779 Mdot
.44685 .59978 Mdot
.47338 .67564 Mdot
.68001 .75333 Mdot
.69579 .73983 Mdot
.59323 .40531 Mdot
.81687 .58262 Mdot
.38877 .36394 Mdot
.7147 .38869 Mdot
.30486 .52034 Mdot
.61231 .61974 Mdot
.23759 .32441 Mdot
.3354 .50168 Mdot
.36209 .51565 Mdot
.5982 .55821 Mdot
.37428 .57846 Mdot
.57025 .59284 Mdot
.33701 .5627 Mdot
.40229 .63136 Mdot
.64047 .61372 Mdot
.36912 .53886 Mdot
.52527 .54892 Mdot
.55773 .54687 Mdot
.59251 .38779 Mdot
.33199 .56269 Mdot
.55026 .61087 Mdot
.58103 .8479 Mdot
.45454 .33244 Mdot
.36042 .42718 Mdot
.39878 .74936 Mdot
.40578 .34615 Mdot
.63262 .36462 Mdot
.5919 .63876 Mdot
.36217 .69287 Mdot
.61523 .38868 Mdot
.41566 .65521 Mdot
.38178 .72042 Mdot
.23372 .34736 Mdot
.59892 .35969 Mdot
.36574 .44121 Mdot
.36602 .71213 Mdot
.60486 .50672 Mdot
.33557 .57524 Mdot
.46427 .62664 Mdot
.36289 .47976 Mdot
.58097 .5791 Mdot
.34185 .42692 Mdot
.45441 .32703 Mdot
.54875 .58146 Mdot
.35366 .59283 Mdot
.35345 .43542 Mdot
.61256 .55201 Mdot
.585 .55029 Mdot
.41341 .21481 Mdot
.21444 .46288 Mdot
.37533 .67618 Mdot
.64723 .38301 Mdot
.60727 .57043 Mdot
.36187 .71093 Mdot
.29473 .68227 Mdot
.62471 .57247 Mdot
.64274 .34699 Mdot
.65873 .62069 Mdot
.35345 .58454 Mdot
.41178 .32177 Mdot
.32433 .53276 Mdot
.35564 .69531 Mdot
.13478 .49363 Mdot
.37109 .45666 Mdot
.52495 .55922 Mdot
.58366 .61622 Mdot
.32745 .39572 Mdot
.63318 .35202 Mdot
.44033 .77446 Mdot
.59417 .58661 Mdot
.61805 .6726 Mdot
.5583 .59557 Mdot
.2896 .59307 Mdot
.59684 .37715 Mdot
.57799 .58466 Mdot
.51256 .50117 Mdot
.55962 .51981 Mdot
.35925 .67796 Mdot
.63046 .74882 Mdot
.62581 .59223 Mdot
.80499 .28911 Mdot
.38121 .53411 Mdot
.36985 .54238 Mdot
.33944 .40562 Mdot
.37551 .8049 Mdot
.53471 .20011 Mdot
.61691 .34612 Mdot
.55755 .32743 Mdot
.35637 .53391 Mdot
.58831 .21665 Mdot
.81031 .60943 Mdot
.56045 .5439 Mdot
.61661 .54598 Mdot
.32929 .51153 Mdot
.37459 .51892 Mdot
.36976 .42712 Mdot
.56114 .62311 Mdot
.60952 .50421 Mdot
.3706 .56246 Mdot
.61592 .58338 Mdot
.65222 .62282 Mdot
.4121 .30743 Mdot
.60429 .40567 Mdot
.43214 .31814 Mdot
.40112 .33475 Mdot
.71952 .45685 Mdot
.34882 .2551 Mdot
.44959 .32151 Mdot
.39363 .36876 Mdot
.49795 .72259 Mdot
.6452 .51412 Mdot
.35378 .70435 Mdot
.77061 .65219 Mdot
.3432 .53299 Mdot
.57043 .57446 Mdot
.58031 .39741 Mdot
.71208 .42921 Mdot
.40233 .49261 Mdot
.18072 .51559 Mdot
.59544 .60282 Mdot
.35082 .54556 Mdot
.35306 .44718 Mdot
.64753 .60532 Mdot
.26125 .49193 Mdot
.54746 .5957 Mdot
.3269 .55015 Mdot
.75123 .56633 Mdot
.5494 .46836 Mdot
.24194 .4649 Mdot
.58638 .43199 Mdot
.57193 .60721 Mdot
.61353 .35228 Mdot
.42458 .32087 Mdot
.35887 .69132 Mdot
.37404 .67769 Mdot
.57182 .55581 Mdot
.64059 .6764 Mdot
.40612 .45376 Mdot
.55781 .54466 Mdot
.57336 .54218 Mdot
.35543 .43866 Mdot
.57088 .54345 Mdot
.58077 .61598 Mdot
.56453 .61407 Mdot
.54887 .53372 Mdot
.44388 .36441 Mdot
.54131 .46936 Mdot
.53384 .60051 Mdot
.64748 .62228 Mdot
.40764 .30674 Mdot
.5767 .30831 Mdot
.40721 .32102 Mdot
.83249 .48611 Mdot
.44097 .32495 Mdot
.38526 .67663 Mdot
.33865 .44391 Mdot
.66413 .62996 Mdot
.58397 .35376 Mdot
.4584 .35507 Mdot
.38721 .69198 Mdot
.41353 .33167 Mdot
.35295 .57435 Mdot
.64821 .21257 Mdot
.55973 .3874 Mdot
.43125 .75769 Mdot
.39119 .27128 Mdot
.24599 .41952 Mdot
.33793 .50508 Mdot
.5936 .3799 Mdot
.79107 .50086 Mdot
.55084 .60841 Mdot
.36864 .71465 Mdot
.57825 .55999 Mdot
.44404 .36558 Mdot
.34773 .54092 Mdot
.60932 .77208 Mdot
.36612 .68349 Mdot
.44427 .19024 Mdot
.34393 .5472 Mdot
.53739 .58405 Mdot
.42169 .37517 Mdot
.51302 .15817 Mdot
.43275 .31572 Mdot
.44289 .63455 Mdot
.6468 .3434 Mdot
.67756 .55075 Mdot
.62005 .37355 Mdot
.37839 .4344 Mdot
.73947 .25985 Mdot
.74763 .70198 Mdot
.61979 .3951 Mdot
.23221 .5169 Mdot
.61539 .54676 Mdot
.62644 .56763 Mdot
.54956 .4758 Mdot
.64853 .35613 Mdot
.60904 .57924 Mdot
.35415 .45008 Mdot
.47494 .25686 Mdot
.24348 .55266 Mdot
.35564 .49243 Mdot
.57655 .59306 Mdot
.41239 .30379 Mdot
.39316 .34601 Mdot
.36893 .48094 Mdot
.41133 .31591 Mdot
.54552 .56429 Mdot
.61874 .37742 Mdot
.42303 .41144 Mdot
.36899 .69069 Mdot
.59759 .82087 Mdot
.35439 .71635 Mdot
.35961 .47533 Mdot
.63235 .52987 Mdot
.36001 .53302 Mdot
.17811 .6775 Mdot
.54327 .57681 Mdot
.63992 .37203 Mdot
.59889 .54945 Mdot
.56532 .60504 Mdot
.62487 .55725 Mdot
.36799 .56974 Mdot
.37427 .77087 Mdot
.61557 .58071 Mdot
.42444 .34985 Mdot
.72236 .69996 Mdot
.629 .57461 Mdot
.39686 .62802 Mdot
.56568 .74467 Mdot
.24593 .39853 Mdot
.57959 .35495 Mdot
.3633 .52198 Mdot
.63291 .37407 Mdot
.58052 .42109 Mdot
.63267 .36428 Mdot
.73151 .66396 Mdot
.78249 .5191 Mdot
.28697 .74792 Mdot
.69525 .59582 Mdot
.69235 .42094 Mdot
.65209 .37507 Mdot
.29049 .70545 Mdot
.58165 .36424 Mdot
.62681 .35135 Mdot
.78784 .74719 Mdot
.57696 .37144 Mdot
.58443 .59359 Mdot
.63741 .57992 Mdot
.53895 .28013 Mdot
.47891 .72853 Mdot
.56738 .54984 Mdot
.60425 .56373 Mdot
.3594 .69983 Mdot
.62404 .68556 Mdot
.36751 .41852 Mdot
.23911 .34166 Mdot
.59683 .26669 Mdot
.57737 .55847 Mdot
.60886 .57006 Mdot
.59231 .50459 Mdot
.65973 .17653 Mdot
.73282 .43973 Mdot
.65002 .38433 Mdot
.54063 .50606 Mdot
.66527 .78337 Mdot
.54476 .55583 Mdot
.62242 .5767 Mdot
.60587 .53647 Mdot
.35568 .53437 Mdot
.65714 .3696 Mdot
.54409 .50375 Mdot
.24728 .36797 Mdot
.58768 .52021 Mdot
.48658 .36903 Mdot
.40888 .79452 Mdot
.58187 .58933 Mdot
.61049 .33229 Mdot
.59397 .53874 Mdot
.59745 .35883 Mdot
.59274 .39289 Mdot
.59989 .50913 Mdot
.77278 .61535 Mdot
.64053 .34181 Mdot
.57875 .52459 Mdot
.36479 .54411 Mdot
.76763 .68821 Mdot
.5832 .58009 Mdot
.38808 .67196 Mdot
.59584 .58766 Mdot
.3753 .66515 Mdot
.57184 .53792 Mdot
.36833 .49298 Mdot
.73175 .36519 Mdot
.34703 .52567 Mdot
.4523 .80711 Mdot
.37886 .54803 Mdot
.41103 .21538 Mdot
.64238 .34908 Mdot
.35171 .43712 Mdot
.16097 .51104 Mdot
.35863 .43382 Mdot
.51465 .47772 Mdot
.47212 .52184 Mdot
.42239 .36404 Mdot
.63334 .39384 Mdot
.54649 .78124 Mdot
.31924 .39211 Mdot
.32797 .45031 Mdot
.35523 .47561 Mdot
.14953 .46052 Mdot
.17441 .44561 Mdot
.61512 .57066 Mdot
.75146 .61793 Mdot
.69365 .52693 Mdot
.62396 .57365 Mdot
.5721 .63573 Mdot
.34924 .59401 Mdot
.59007 .61535 Mdot
.5213 .41603 Mdot
.34101 .5082 Mdot
.39013 .69609 Mdot
.6226 .35309 Mdot
.38778 .66736 Mdot
.32319 .41014 Mdot
.47375 .52605 Mdot
.33714 .55806 Mdot
.55028 .528 Mdot
.60225 .55339 Mdot
.5876 .37772 Mdot
.65272 .40153 Mdot
.59837 .40175 Mdot
.39669 .71262 Mdot
.34054 .5157 Mdot
.73018 .42435 Mdot
.59846 .56621 Mdot
.61205 .38009 Mdot
.38276 .29212 Mdot
.60358 .56984 Mdot
.41184 .32864 Mdot
.60765 .5325 Mdot
.62255 .39543 Mdot
.57063 .54336 Mdot
.62041 .3777 Mdot
.35005 .50224 Mdot
.54614 .55062 Mdot
.59451 .55821 Mdot
.50688 .1625 Mdot
.38202 .67951 Mdot
.64324 .35082 Mdot
.44428 .46073 Mdot
.53914 .5944 Mdot
.28786 .41617 Mdot
.58104 .60691 Mdot
.55904 .34801 Mdot
.52848 .5481 Mdot
.3548 .43657 Mdot
.62932 .62956 Mdot
.58223 .58058 Mdot
.48138 .54531 Mdot
.71342 .58037 Mdot
.64078 .4129 Mdot
.42556 .37268 Mdot
.62013 .33168 Mdot
.37342 .60392 Mdot
.35543 .46527 Mdot
.36614 .59229 Mdot
.46063 .74433 Mdot
.60284 .51178 Mdot
.56555 .58554 Mdot
.4525 .306 Mdot
.39404 .69872 Mdot
.60587 .38347 Mdot
.39072 .70291 Mdot
.27405 .30806 Mdot
.39212 .71579 Mdot
.3696 .48869 Mdot
.28448 .59937 Mdot
.74655 .41469 Mdot
.35987 .70151 Mdot
.60062 .40375 Mdot
.28644 .62279 Mdot
.60229 .62136 Mdot
.41796 .71232 Mdot
.37648 .69197 Mdot
.14485 .44619 Mdot
.59637 .61168 Mdot
.52131 .46575 Mdot
.43546 .31105 Mdot
.38009 .71332 Mdot
.4355 .34518 Mdot
.56964 .55131 Mdot
.27194 .38837 Mdot
.62437 .34535 Mdot
.3945 .32065 Mdot
.54912 .62252 Mdot
.39898 .70334 Mdot
.3393 .55467 Mdot
.47495 .32719 Mdot
.43499 .36441 Mdot
.72822 .32489 Mdot
.61178 .76325 Mdot
.34111 .51296 Mdot
.20773 .5318 Mdot
.44 .35105 Mdot
.62413 .5815 Mdot
.63516 .66243 Mdot
.54134 .57704 Mdot
.34305 .41583 Mdot
.36405 .52244 Mdot
.50013 .27705 Mdot
.60377 .55211 Mdot
.58911 .61061 Mdot
.63977 .32658 Mdot
.34627 .50453 Mdot
.61119 .36409 Mdot
.59909 .3397 Mdot
.35002 .50015 Mdot
.6225 .36747 Mdot
.37554 .71903 Mdot
.48547 .24643 Mdot
.44148 .3508 Mdot
.42502 .34556 Mdot
.34754 .54757 Mdot
.37162 .55446 Mdot
.35973 .52922 Mdot
.60704 .53181 Mdot
.60085 .38155 Mdot
.5909 .52936 Mdot
.62195 .55262 Mdot
.59442 .44101 Mdot
.57387 .38261 Mdot
.60158 .53831 Mdot
.25023 .45555 Mdot
.41659 .67262 Mdot
.36737 .55252 Mdot
.4431 .31528 Mdot
.63522 .24865 Mdot
.43226 .29082 Mdot
.57549 .59546 Mdot
.34231 .28976 Mdot
.61377 .398 Mdot
.36595 .70715 Mdot
.39059 .65621 Mdot
.36379 .69504 Mdot
.46668 .33933 Mdot
.61353 .33886 Mdot
.23833 .34417 Mdot
.573 .59216 Mdot
.51165 .42733 Mdot
.55946 .77971 Mdot
.27921 .31318 Mdot
.44768 .31886 Mdot
.60532 .56849 Mdot
.36255 .43299 Mdot
.78357 .46518 Mdot
.55015 .59753 Mdot
.56416 .61832 Mdot
.29191 .528 Mdot
.65826 .6107 Mdot
.64516 .34335 Mdot
.34866 .24156 Mdot
.63549 .57721 Mdot
.59339 .45032 Mdot
.46414 .86216 Mdot
.57334 .60095 Mdot
.60172 .59715 Mdot
.58724 .57181 Mdot
.59257 .54495 Mdot
.62145 .32998 Mdot
.49834 .77309 Mdot
.42589 .37494 Mdot
.49907 .44267 Mdot
.44096 .35429 Mdot
.32668 .54399 Mdot
.53602 .45127 Mdot
.62106 .40547 Mdot
.36541 .70815 Mdot
.76308 .37196 Mdot
.31119 .26317 Mdot
.33416 .51356 Mdot
.76113 .47594 Mdot
.37359 .68741 Mdot
.62062 .61798 Mdot
.3912 .66608 Mdot
.37063 .50772 Mdot
.42436 .35727 Mdot
.64113 .59025 Mdot
.58222 .3909 Mdot
.62427 .39856 Mdot
.60699 .57698 Mdot
.68544 .77241 Mdot
.41129 .3269 Mdot
.39759 .30044 Mdot
.61526 .55238 Mdot
.5636 .61859 Mdot
.61471 .36099 Mdot
.36078 .55327 Mdot
.22943 .63314 Mdot
.38811 .68528 Mdot
.53294 .56855 Mdot
.58863 .54384 Mdot
.34551 .25356 Mdot
.40217 .34295 Mdot
.36813 .45214 Mdot
.61479 .55776 Mdot
.39875 .25498 Mdot
.61399 .55609 Mdot
.64506 .61238 Mdot
.36169 .54067 Mdot
.53467 .52661 Mdot
.61911 .5876 Mdot
.52095 .52374 Mdot
.43858 .3488 Mdot
.63969 .36496 Mdot
.62881 .32656 Mdot
.36716 .42581 Mdot
.41321 .32762 Mdot
.59921 .53868 Mdot
.40365 .34109 Mdot
.62653 .57757 Mdot
.6135 .58424 Mdot
.44924 .32179 Mdot
.61181 .36412 Mdot
.54004 .32607 Mdot
.53973 .46634 Mdot
.59689 .54617 Mdot
.63639 .6147 Mdot
.47084 .74189 Mdot
.18231 .62117 Mdot
.59217 .60312 Mdot
.624 .3962 Mdot
.59884 .56302 Mdot
.43504 .336 Mdot
.39125 .71462 Mdot
.62652 .39095 Mdot
.3551 .55942 Mdot
.33891 .49778 Mdot
.59033 .2326 Mdot
.3677 .47527 Mdot
.6064 .62531 Mdot
.58818 .32309 Mdot
.57749 .39967 Mdot
.52375 .85388 Mdot
.35029 .49663 Mdot
.3544 .68686 Mdot
.58023 .55083 Mdot
.35915 .28339 Mdot
.45709 .31361 Mdot
.7985 .27718 Mdot
.2351 .34786 Mdot
.35311 .71641 Mdot
.17437 .51571 Mdot
.36305 .44102 Mdot
.61531 .60142 Mdot
.35939 .68795 Mdot
.33121 .5295 Mdot
.61943 .61294 Mdot
.55371 .64135 Mdot
.42712 .76808 Mdot
.3283 .57233 Mdot
.4055 .33247 Mdot
.36098 .59008 Mdot
.40841 .68049 Mdot
.36943 .48951 Mdot
.61712 .4046 Mdot
.57796 .58098 Mdot
.57213 .49846 Mdot
.35939 .55782 Mdot
.36991 .49703 Mdot
.60442 .53226 Mdot
.63757 .38544 Mdot
.37086 .58727 Mdot
.57003 .55949 Mdot
.70983 .39868 Mdot
.59143 .43229 Mdot
.33909 .53024 Mdot
.57773 .61415 Mdot
.66052 .53894 Mdot
.34981 .55411 Mdot
.36781 .5566 Mdot
.6092 .57845 Mdot
.37075 .71779 Mdot
.58838 .51805 Mdot
.44239 .32349 Mdot
.3805 .77558 Mdot
.43344 .33828 Mdot
.36141 .62245 Mdot
.64756 .54953 Mdot
.26517 .40951 Mdot
.60631 .40912 Mdot
.40789 .67679 Mdot
.64364 .24505 Mdot
.57026 .6223 Mdot
.81194 .57969 Mdot
.46684 .4053 Mdot
.6485 .80782 Mdot
.75268 .30112 Mdot
.37804 .69566 Mdot
.41726 .32663 Mdot
.60161 .59637 Mdot
.4414 .30275 Mdot
.36713 .679 Mdot
.568 .78639 Mdot
.57644 .61506 Mdot
.59662 .3745 Mdot
.59127 .52157 Mdot
.60536 .35587 Mdot
.60324 .57224 Mdot
.65613 .61303 Mdot
.33288 .47784 Mdot
.44314 .65111 Mdot
.60958 .62063 Mdot
.64353 .20725 Mdot
.41318 .48329 Mdot
.38067 .68701 Mdot
.58475 .52595 Mdot
.36073 .45991 Mdot
.39509 .35435 Mdot
.52947 .66369 Mdot
.35807 .53448 Mdot
.43475 .30467 Mdot
.62398 .36118 Mdot
.35275 .49668 Mdot
.35823 .46843 Mdot
.51652 .54379 Mdot
.37056 .66798 Mdot
.41753 .36259 Mdot
.58268 .58403 Mdot
.59497 .61123 Mdot
.22635 .5526 Mdot
.40084 .51902 Mdot
.65755 .33734 Mdot
.457 .1707 Mdot
.59289 .33483 Mdot
.39072 .68269 Mdot
.36169 .53776 Mdot
.58906 .60317 Mdot
.54865 .57659 Mdot
.34881 .44194 Mdot
.64293 .35211 Mdot
.32514 .5539 Mdot
.736 .4642 Mdot
.36716 .51449 Mdot
.52157 .75595 Mdot
.63802 .37858 Mdot
.51687 .7567 Mdot
.40702 .67785 Mdot
.80891 .54832 Mdot
.50557 .69441 Mdot
.43354 .30978 Mdot
.52677 .75678 Mdot
.6072 .39283 Mdot
.61103 .56287 Mdot
.36395 .44509 Mdot
.36782 .46535 Mdot
.61974 .35621 Mdot
.32845 .51769 Mdot
.37918 .71222 Mdot
.60527 .59683 Mdot
.22376 .41352 Mdot
.545 .24983 Mdot
.36118 .5655 Mdot
.63393 .63787 Mdot
.43141 .34898 Mdot
.61475 .59676 Mdot
.39208 .67369 Mdot
.41357 .35589 Mdot
.38099 .51661 Mdot
.48547 .26153 Mdot
.56956 .55456 Mdot
.37355 .2454 Mdot
.40871 .33907 Mdot
.19553 .56977 Mdot
.57142 .56439 Mdot
.43985 .35095 Mdot
.65989 .57056 Mdot
.27458 .32962 Mdot
.45016 .43102 Mdot
.80597 .62386 Mdot
.32539 .56788 Mdot
.3314 .50681 Mdot
.29603 .34898 Mdot
.31562 .45769 Mdot
.42946 .30125 Mdot
.36922 .4901 Mdot
.59261 .72039 Mdot
.43558 .34726 Mdot
.61809 .54701 Mdot
.57841 .60478 Mdot
.71688 .44917 Mdot
.47566 .42426 Mdot
.3711 .49775 Mdot
.51489 .20717 Mdot
.54072 .59625 Mdot
.52341 .59785 Mdot
.55212 .57645 Mdot
.63433 .40383 Mdot
.40785 .35824 Mdot
.55036 .16864 Mdot
.41756 .32125 Mdot
.20591 .4373 Mdot
.34367 .53346 Mdot
.37336 .54881 Mdot
.58023 .59197 Mdot
.24886 .43037 Mdot
.64627 .69522 Mdot
.54768 .55769 Mdot
.26676 .44119 Mdot
.6238 .76049 Mdot
.54452 .62021 Mdot
.64853 .34393 Mdot
.63716 .56344 Mdot
.60579 .42152 Mdot
.43611 .36087 Mdot
.37598 .70238 Mdot
.4121 .711 Mdot
.41864 .36166 Mdot
.56424 .58424 Mdot
.27375 .44394 Mdot
.55612 .59887 Mdot
.61505 .56493 Mdot
.20191 .41899 Mdot
.36163 .72379 Mdot
.35831 .52218 Mdot
.37071 .67943 Mdot
.6271 .35081 Mdot
.92054 .53464 Mdot
.39373 .70299 Mdot
.67149 .64792 Mdot
.49148 .80203 Mdot
.52328 .75834 Mdot
.62685 .39737 Mdot
.40437 .7113 Mdot
.41229 .32228 Mdot
.68752 .7947 Mdot
.19445 .64314 Mdot
.41674 .29244 Mdot
.56416 .5647 Mdot
.61963 .40832 Mdot
.59314 .40349 Mdot
.38954 .33066 Mdot
.59744 .39446 Mdot
.60292 .50045 Mdot
.60763 .55271 Mdot
.43164 .30195 Mdot
.54354 .26756 Mdot
.43281 .36577 Mdot
.46781 .2426 Mdot
.58889 .52418 Mdot
.63443 .38331 Mdot
.63066 .54356 Mdot
.56404 .36088 Mdot
.37128 .44764 Mdot
.62405 .61001 Mdot
.37337 .71249 Mdot
.50158 .41545 Mdot
.34039 .52815 Mdot
.34081 .29505 Mdot
.58848 .37502 Mdot
.39287 .38702 Mdot
.59284 .38932 Mdot
.63261 .40022 Mdot
.40079 .33459 Mdot
.60506 .3445 Mdot
.60248 .59775 Mdot
.23788 .49192 Mdot
.59425 .35891 Mdot
.42235 .33384 Mdot
.36985 .70245 Mdot
.61879 .36657 Mdot
.34703 .59312 Mdot
.58948 .55292 Mdot
.34126 .57121 Mdot
.32717 .48207 Mdot
.63879 .38626 Mdot
.40091 .71493 Mdot
.36668 .52589 Mdot
.36694 .67254 Mdot
.59873 .78955 Mdot
.45742 .32894 Mdot
.18449 .51722 Mdot
.64504 .51729 Mdot
.5815 .39195 Mdot
.32832 .48295 Mdot
.58865 .60101 Mdot
.58866 .55153 Mdot
.41065 .6945 Mdot
.59226 .40315 Mdot
.74533 .71077 Mdot
.57159 .3266 Mdot
.49034 .25321 Mdot
.46005 .34239 Mdot
.47922 .1822 Mdot
.47008 .27313 Mdot
.47752 .82886 Mdot
.51792 .55709 Mdot
.3629 .44193 Mdot
.56409 .59342 Mdot
.65389 .25261 Mdot
.39831 .7075 Mdot
.24745 .6745 Mdot
.59169 .50884 Mdot
.35344 .51739 Mdot
.58307 .56556 Mdot
.47758 .61063 Mdot
.64116 .56509 Mdot
.36905 .71914 Mdot
.49245 .35331 Mdot
.58631 .35138 Mdot
.37036 .68909 Mdot
.34089 .49801 Mdot
.59827 .73798 Mdot
.61566 .61509 Mdot
.55234 .61783 Mdot
.36885 .5157 Mdot
.59496 .37944 Mdot
.32876 .55426 Mdot
.4412 .35114 Mdot
.38377 .70486 Mdot
.58337 .54795 Mdot
.53996 .53559 Mdot
.28929 .41848 Mdot
.40943 .36181 Mdot
.36877 .52376 Mdot
.42969 .31628 Mdot
.36354 .44236 Mdot
.63948 .60759 Mdot
.37402 .555 Mdot
.61047 .60983 Mdot
.58496 .20055 Mdot
.2006 .42879 Mdot
.7207 .58342 Mdot
.35517 .51429 Mdot
.53537 .74333 Mdot
.43116 .33045 Mdot
.43845 .32238 Mdot
.66112 .51795 Mdot
.59375 .69656 Mdot
.30221 .61903 Mdot
.73525 .32803 Mdot
.44199 .35107 Mdot
.43014 .33996 Mdot
.33225 .55437 Mdot
.60492 .34636 Mdot
.60596 .41838 Mdot
.33526 .49271 Mdot
.44093 .69282 Mdot
.60601 .38338 Mdot
.8018 .59781 Mdot
.3712 .60409 Mdot
.51414 .57158 Mdot
.35498 .40338 Mdot
.37801 .70804 Mdot
.44282 .67656 Mdot
.47766 .60388 Mdot
.59396 .6072 Mdot
.35648 .23568 Mdot
.35814 .54916 Mdot
.47206 .77478 Mdot
.83112 .47995 Mdot
.57362 .61564 Mdot
.57077 .57182 Mdot
.55877 .5838 Mdot
.3698 .72909 Mdot
.67966 .31364 Mdot
.59814 .60818 Mdot
.4377 .70048 Mdot
.53625 .58864 Mdot
.47765 .66025 Mdot
.37357 .67762 Mdot
.62653 .44289 Mdot
.31876 .53529 Mdot
.24661 .35245 Mdot
.56082 .47497 Mdot
.44262 .34144 Mdot
.34122 .47744 Mdot
.43485 .35885 Mdot
.72828 .65951 Mdot
.50774 .69799 Mdot
.65604 .34746 Mdot
.59759 .6035 Mdot
.35708 .47731 Mdot
.5994 .405 Mdot
.2994 .39845 Mdot
.83337 .69771 Mdot
.41314 .36853 Mdot
.19273 .68738 Mdot
.43583 .31896 Mdot
.3702 .45425 Mdot
.61645 .35997 Mdot
.77612 .52788 Mdot
.51278 .42645 Mdot
.62019 .36844 Mdot
.52817 .32623 Mdot
.57925 .34489 Mdot
.53632 .74952 Mdot
.56992 .38294 Mdot
.42528 .33115 Mdot
.46697 .32011 Mdot
.51808 .59047 Mdot
.58858 .59422 Mdot
.47163 .53227 Mdot
.67691 .60691 Mdot
.58969 .59731 Mdot
.34128 .50797 Mdot
.18781 .56587 Mdot
.34015 .48212 Mdot
.58348 .36603 Mdot
.41564 .37298 Mdot
.57336 .57039 Mdot
.60537 .54792 Mdot
.62113 .60312 Mdot
.48575 .1564 Mdot
.79161 .61212 Mdot
.61485 .57926 Mdot
.53782 .55584 Mdot
.35098 .50437 Mdot
.34348 .68338 Mdot
.68935 .26599 Mdot
.56533 .71129 Mdot
.54423 .59347 Mdot
.37572 .67938 Mdot
.35249 .70793 Mdot
.61797 .61606 Mdot
.23709 .40461 Mdot
.23429 .49628 Mdot
.58292 .58364 Mdot
.50389 .67811 Mdot
.32099 .41818 Mdot
.3694 .48244 Mdot
.35713 .55682 Mdot
.60645 .334 Mdot
.36118 .47114 Mdot
.37914 .55801 Mdot
.7789 .50264 Mdot
.36554 .42308 Mdot
.44426 .27367 Mdot
.39683 .71249 Mdot
.54849 .58296 Mdot
.59467 .33193 Mdot
.34697 .42646 Mdot
.42206 .36331 Mdot
.62422 .38521 Mdot
.39471 .35628 Mdot
.34634 .70282 Mdot
.44436 .76056 Mdot
.36937 .46315 Mdot
.44537 .34395 Mdot
.48387 .26069 Mdot
.37519 .67875 Mdot
.41418 .31497 Mdot
.2715 .41206 Mdot
.62918 .56738 Mdot
.7957 .53995 Mdot
.5565 .54283 Mdot
.68419 .78313 Mdot
.41229 .31776 Mdot
.35902 .42435 Mdot
.56972 .58477 Mdot
.34452 .54767 Mdot
.65539 .56558 Mdot
.54588 .59366 Mdot
.35219 .56291 Mdot
.61444 .56947 Mdot
.38475 .66964 Mdot
.59258 .42664 Mdot
.47279 .39398 Mdot
.24263 .27774 Mdot
.37392 .66784 Mdot
.29498 .40038 Mdot
.59332 .60319 Mdot
.61074 .76945 Mdot
.61757 .36785 Mdot
.57202 .6184 Mdot
.63182 .46612 Mdot
.60771 .349 Mdot
.63015 .3759 Mdot
.58106 .5372 Mdot
.43005 .31062 Mdot
.34143 .5439 Mdot
.37109 .68091 Mdot
.52755 .84115 Mdot
.55701 .56377 Mdot
.59651 .56027 Mdot
.37232 .68816 Mdot
.43204 .33936 Mdot
.60218 .54527 Mdot
.35611 .3398 Mdot
.59921 .83767 Mdot
.40108 .35852 Mdot
.62211 .54419 Mdot
.79291 .43321 Mdot
.57257 .34295 Mdot
.18567 .6579 Mdot
.39808 .64562 Mdot
.3646 .52708 Mdot
.65927 .60853 Mdot
.86246 .37987 Mdot
.37502 .70374 Mdot
.24199 .34906 Mdot
.61812 .57054 Mdot
.59468 .56883 Mdot
.60662 .40009 Mdot
.59521 .53292 Mdot
.63787 .35122 Mdot
.20188 .33479 Mdot
.38992 .19725 Mdot
.59279 .37108 Mdot
.57744 .38142 Mdot
.6625 .53118 Mdot
.68177 .26325 Mdot
.62522 .35652 Mdot
.61332 .52912 Mdot
.74878 .68292 Mdot
.51016 .56533 Mdot
.41112 .69592 Mdot
.31984 .48807 Mdot
.64447 .42225 Mdot
.41045 .58214 Mdot
.58577 .3075 Mdot
.54981 .48021 Mdot
.39501 .44129 Mdot
.44557 .32537 Mdot
.55486 .60922 Mdot
.36791 .47126 Mdot
.37027 .58395 Mdot
.64538 .5703 Mdot
.54895 .59118 Mdot
.601 .35626 Mdot
.37081 .72658 Mdot
.39711 .33326 Mdot
.60379 .563 Mdot
.34283 .59244 Mdot
.3911 .69197 Mdot
.58541 .36598 Mdot
.67555 .5512 Mdot
.35599 .7074 Mdot
.63865 .62389 Mdot
.59653 .58374 Mdot
.60682 .53522 Mdot
.63942 .51449 Mdot
.45463 .34636 Mdot
.33552 .40995 Mdot
.60409 .52302 Mdot
.27915 .30257 Mdot
.43616 .62174 Mdot
.53928 .5264 Mdot
.6025 .38903 Mdot
.46206 .32421 Mdot
.37062 .44371 Mdot
.59416 .75223 Mdot
.56325 .55776 Mdot
.78748 .61658 Mdot
.73245 .44772 Mdot
.35903 .46382 Mdot
.65271 .36983 Mdot
.36463 .70476 Mdot
.54572 .56542 Mdot
.73701 .67489 Mdot
.57734 .60241 Mdot
.66185 .5456 Mdot
.36488 .54824 Mdot
.44707 .32609 Mdot
.63503 .81919 Mdot
.37072 .58258 Mdot
.63214 .37471 Mdot
.81517 .6171 Mdot
.59994 .41315 Mdot
.59358 .34632 Mdot
.76116 .63024 Mdot
.45276 .34797 Mdot
.85092 .35948 Mdot
.19038 .64421 Mdot
.57077 .51237 Mdot
.43466 .32933 Mdot
.60839 .35861 Mdot
.61417 .59689 Mdot
.57583 .39397 Mdot
.61929 .34155 Mdot
.62791 .60325 Mdot
.59701 .57691 Mdot
.5363 .46554 Mdot
.82573 .53727 Mdot
.36263 .69728 Mdot
.64364 .36849 Mdot
.68465 .43462 Mdot
.6054 .60726 Mdot
.57335 .5916 Mdot
.31206 .39799 Mdot
.36648 .71656 Mdot
.48441 .55156 Mdot
.61503 .56029 Mdot
.39131 .21062 Mdot
.64149 .60966 Mdot
.63472 .33125 Mdot
.40056 .35692 Mdot
.23739 .39307 Mdot
.34379 .41508 Mdot
.64562 .35487 Mdot
.40082 .68539 Mdot
.64232 .32912 Mdot
.67434 .63895 Mdot
.44585 .35535 Mdot
.6225 .39546 Mdot
.32518 .52652 Mdot
.41632 .35033 Mdot
.41479 .31518 Mdot
.72422 .69866 Mdot
.36078 .50818 Mdot
.40315 .70514 Mdot
.42718 .35678 Mdot
.71381 .38644 Mdot
.42031 .32974 Mdot
.69416 .44528 Mdot
.55181 .54333 Mdot
.43389 .73665 Mdot
.48477 .2934 Mdot
.66648 .57916 Mdot
.45701 .34132 Mdot
.36634 .68094 Mdot
.58501 .54027 Mdot
.59878 .39603 Mdot
.39193 .70451 Mdot
.46834 .37381 Mdot
.36998 .55632 Mdot
.58875 .3868 Mdot
.42626 .37542 Mdot
.64212 .37043 Mdot
.53192 .78093 Mdot
.39837 .77675 Mdot
.35921 .31739 Mdot
.51437 .43865 Mdot
.62191 .59837 Mdot
.64903 .28644 Mdot
.62282 .62143 Mdot
.55019 .59558 Mdot
.33927 .53118 Mdot
.45984 .74564 Mdot
.61158 .36355 Mdot
.63685 .82101 Mdot
.44712 .33855 Mdot
.36001 .22472 Mdot
.56932 .42977 Mdot
.55655 .61478 Mdot
.59792 .35574 Mdot
.58857 .40921 Mdot
.71253 .58518 Mdot
.37296 .59227 Mdot
.56635 .64379 Mdot
.62289 .62623 Mdot
.51957 .56967 Mdot
.41331 .31748 Mdot
.3288 .30934 Mdot
.32744 .53105 Mdot
.30346 .77165 Mdot
.3654 .5546 Mdot
.27356 .52131 Mdot
.60012 .34609 Mdot
.38892 .71412 Mdot
.57527 .59038 Mdot
.55966 .41833 Mdot
.65085 .36389 Mdot
.37781 .65364 Mdot
.3722 .71388 Mdot
.29883 .3242 Mdot
.45075 .3237 Mdot
.60623 .61931 Mdot
.58182 .61374 Mdot
.58573 .52875 Mdot
.56378 .53386 Mdot
.41117 .36839 Mdot
.62067 .55556 Mdot
.42013 .29909 Mdot
.7174 .39961 Mdot
.37585 .21168 Mdot
.35209 .46185 Mdot
.55613 .68037 Mdot
.58246 .38675 Mdot
.70693 .37055 Mdot
.61318 .65254 Mdot
.1923 .44774 Mdot
.65039 .76454 Mdot
.57809 .63314 Mdot
.32995 .53808 Mdot
.60257 .69018 Mdot
.36662 .50052 Mdot
.10608 .53892 Mdot
.29261 .43553 Mdot
.80999 .6038 Mdot
.60843 .60146 Mdot
.31379 .39795 Mdot
.62886 .65032 Mdot
.62923 .60751 Mdot
.3068 .43819 Mdot
.48576 .2043 Mdot
.52976 .29425 Mdot
.35351 .70742 Mdot
.58236 .55492 Mdot
.56957 .38917 Mdot
.60324 .59904 Mdot
.57 .59472 Mdot
.62031 .57592 Mdot
.41337 .37595 Mdot
.6404 .58406 Mdot
.60974 .53338 Mdot
.41443 .53377 Mdot
.50163 .73068 Mdot
.35927 .58847 Mdot
.68835 .6147 Mdot
.39319 .69945 Mdot
.59177 .3645 Mdot
.53337 .39937 Mdot
.43481 .30992 Mdot
.70178 .55656 Mdot
.59978 .52512 Mdot
.48659 .2857 Mdot
.42788 .37531 Mdot
.38443 .70714 Mdot
.3689 .43225 Mdot
.77637 .67202 Mdot
.35873 .47742 Mdot
.36636 .42337 Mdot
.34132 .52683 Mdot
.67967 .38236 Mdot
.60348 .3547 Mdot
.62341 .59721 Mdot
.4289 .35254 Mdot
.34116 .55025 Mdot
.47083 .72879 Mdot
.5529 .57892 Mdot
.34935 .50531 Mdot
.62333 .5915 Mdot
.43116 .75547 Mdot
.22389 .56713 Mdot
.37806 .53786 Mdot
.46496 .35673 Mdot
.41819 .34499 Mdot
.37924 .7196 Mdot
.58668 .37053 Mdot
.60984 .39753 Mdot
.41303 .35407 Mdot
.16541 .59134 Mdot
.54718 .59739 Mdot
.61166 .60066 Mdot
.28334 .29789 Mdot
.5978 .59383 Mdot
.58204 .74248 Mdot
.37019 .41996 Mdot
.58245 .37579 Mdot
.61655 .59088 Mdot
.59836 .54504 Mdot
.57477 .55252 Mdot
.52529 .78291 Mdot
.36222 .55782 Mdot
.53925 .58688 Mdot
.35923 .70527 Mdot
.37988 .43247 Mdot
.61168 .60284 Mdot
.52124 .57662 Mdot
.61279 .39599 Mdot
.37019 .2034 Mdot
.43988 .31752 Mdot
.33735 .51031 Mdot
.36978 .53458 Mdot
.32073 .48251 Mdot
.60149 .44407 Mdot
.36904 .42147 Mdot
.35934 .78314 Mdot
.35813 .4298 Mdot
.3777 .68419 Mdot
.30823 .57096 Mdot
.39739 .61231 Mdot
.33276 .53217 Mdot
.39089 .34927 Mdot
.58613 .51963 Mdot
.53901 .57894 Mdot
.23105 .35846 Mdot
.5479 .61005 Mdot
.36946 .70757 Mdot
.41258 .30239 Mdot
.6091 .39105 Mdot
.38195 .70973 Mdot
.43389 .31998 Mdot
.59543 .38188 Mdot
.63081 .57604 Mdot
.62841 .56003 Mdot
.62542 .3814 Mdot
.59976 .40427 Mdot
.58682 .58525 Mdot
.38619 .44979 Mdot
.59824 .33925 Mdot
.63016 .38956 Mdot
.36991 .46667 Mdot
.357 .47396 Mdot
.54141 .50806 Mdot
.43305 .32537 Mdot
.61106 .54148 Mdot
.36034 .4834 Mdot
.37968 .72444 Mdot
.61179 .36834 Mdot
.60103 .54744 Mdot
.6063 .56 Mdot
.37162 .68194 Mdot
.36194 .72032 Mdot
.38291 .71174 Mdot
.42163 .2959 Mdot
.56909 .53491 Mdot
.62731 .35903 Mdot
.45257 .33163 Mdot
.35234 .70721 Mdot
.3794 .66184 Mdot
.44099 .53775 Mdot
.58817 .60505 Mdot
.4415 .43523 Mdot
.91562 .52536 Mdot
.5873 .7284 Mdot
.37105 .44438 Mdot
.36499 .50882 Mdot
.49209 .75463 Mdot
.23737 .52475 Mdot
.40712 .33846 Mdot
.61411 .71314 Mdot
.40877 .67799 Mdot
.62566 .59261 Mdot
.63726 .61367 Mdot
.57304 .63676 Mdot
.38739 .69785 Mdot
.55301 .77401 Mdot
.59703 .40861 Mdot
.66777 .48431 Mdot
.39278 .69979 Mdot
.37881 .54077 Mdot
.37524 .55117 Mdot
.36565 .55409 Mdot
.63953 .59377 Mdot
.71468 .56824 Mdot
.70017 .39756 Mdot
.68729 .29154 Mdot
.44184 .31016 Mdot
.66012 .35412 Mdot
.59917 .785 Mdot
.62814 .37637 Mdot
.37215 .58045 Mdot
.38807 .6934 Mdot
.61851 .39949 Mdot
.41849 .36654 Mdot
.42966 .34225 Mdot
.36377 .56093 Mdot
.34709 .5454 Mdot
.34255 .57092 Mdot
.61106 .33639 Mdot
.60353 .34492 Mdot
.55822 .55864 Mdot
.61543 .37627 Mdot
.30271 .25522 Mdot
.36136 .72749 Mdot
.37586 .55732 Mdot
.41889 .32426 Mdot
.60205 .35777 Mdot
.55084 .57545 Mdot
.3033 .5921 Mdot
.58051 .2351 Mdot
.37069 .67119 Mdot
.22007 .55184 Mdot
.11872 .56619 Mdot
.60024 .61661 Mdot
.4045 .33409 Mdot
.22082 .42995 Mdot
.55768 .58067 Mdot
.35672 .53848 Mdot
.61183 .21316 Mdot
.35696 .46316 Mdot
.61735 .54694 Mdot
.55089 .61255 Mdot
.40961 .31714 Mdot
.49342 .80486 Mdot
.55485 .55935 Mdot
.43522 .24662 Mdot
.40574 .37102 Mdot
.34284 .58207 Mdot
.60241 .8407 Mdot
.32777 .40701 Mdot
.44457 .68037 Mdot
.36666 .46305 Mdot
.56793 .60586 Mdot
.3384 .51467 Mdot
.36723 .67487 Mdot
.33627 .54253 Mdot
.6555 .35664 Mdot
.3524 .5839 Mdot
.59557 .56109 Mdot
.62757 .35617 Mdot
.40905 .33686 Mdot
.34285 .24291 Mdot
.40736 .53785 Mdot
.34503 .54812 Mdot
.37231 .45668 Mdot
.6191 .59267 Mdot
.50327 .50825 Mdot
.6376 .52621 Mdot
.60688 .6045 Mdot
.43983 .35747 Mdot
.59454 .35738 Mdot
.45457 .35588 Mdot
.52751 .56208 Mdot
.46395 .20132 Mdot
.43054 .31443 Mdot
.50045 .3199 Mdot
.37431 .68647 Mdot
.45853 .5701 Mdot
.54753 .57683 Mdot
.43042 .35551 Mdot
.57035 .53351 Mdot
.57313 .38828 Mdot
.46651 .45618 Mdot
.34849 .38379 Mdot
.42805 .3515 Mdot
.72759 .73178 Mdot
.44129 .46597 Mdot
.62635 .53927 Mdot
.43859 .35384 Mdot
.63961 .45835 Mdot
.36525 .46008 Mdot
.38592 .6838 Mdot
.35276 .70808 Mdot
.36364 .67498 Mdot
.56856 .62599 Mdot
.55115 .64171 Mdot
.40335 .68589 Mdot
.39735 .35464 Mdot
.36982 .72018 Mdot
.55752 .42732 Mdot
.7372 .72267 Mdot
.40019 .69919 Mdot
.57051 .56235 Mdot
.52509 .60474 Mdot
.49706 .7298 Mdot
.37384 .57981 Mdot
.8145 .57429 Mdot
.58052 .67497 Mdot
.5861 .59594 Mdot
.50966 .60056 Mdot
.60163 .4081 Mdot
.22006 .45238 Mdot
.67594 .60543 Mdot
.2319 .5296 Mdot
.57846 .36707 Mdot
.34959 .43787 Mdot
.58446 .372 Mdot
.60646 .61489 Mdot
.61308 .58668 Mdot
.59751 .41906 Mdot
.34734 .27202 Mdot
.27447 .37796 Mdot
.60353 .81759 Mdot
.63068 .39081 Mdot
.43828 .34906 Mdot
.41383 .36937 Mdot
.44166 .31103 Mdot
.37274 .60338 Mdot
.64416 .3752 Mdot
.56496 .5424 Mdot
.35179 .50367 Mdot
.55293 .6051 Mdot
.42128 .35528 Mdot
.64396 .81561 Mdot
.61111 .39468 Mdot
.58218 .58139 Mdot
.19339 .63603 Mdot
.34915 .53785 Mdot
.3814 .67782 Mdot
.44043 .76556 Mdot
.3691 .60476 Mdot
.44788 .35799 Mdot
.59851 .41608 Mdot
.48242 .37495 Mdot
.51717 .38057 Mdot
.52205 .53499 Mdot
.55614 .51024 Mdot
.49007 .83886 Mdot
.38191 .50319 Mdot
.61684 .62145 Mdot
.33947 .49893 Mdot
.3483 .44322 Mdot
.59777 .54874 Mdot
.62309 .40157 Mdot
.35912 .67194 Mdot
.35937 .70793 Mdot
.61145 .64189 Mdot
.51087 .42959 Mdot
.4549 .57786 Mdot
.60299 .54051 Mdot
.63246 .63675 Mdot
.37034 .53211 Mdot
.3603 .42579 Mdot
.32383 .2629 Mdot
.40197 .69309 Mdot
.61785 .56483 Mdot
.55748 .29665 Mdot
.61799 .34285 Mdot
.34673 .57858 Mdot
.44444 .35888 Mdot
.54539 .78651 Mdot
.33226 .56935 Mdot
.60008 .54918 Mdot
.60154 .54526 Mdot
.41426 .31458 Mdot
.63537 .33144 Mdot
.38662 .6955 Mdot
.35858 .51515 Mdot
.40238 .69161 Mdot
.62458 .34814 Mdot
.61225 .39178 Mdot
.50982 .5667 Mdot
.6303 .63692 Mdot
.35542 .55798 Mdot
.52758 .57436 Mdot
.37766 .56404 Mdot
.48345 .80859 Mdot
.45803 .35583 Mdot
.59569 .61713 Mdot
.64499 .39753 Mdot
.42353 .35846 Mdot
.59231 .57325 Mdot
.47919 .8487 Mdot
.56348 .61573 Mdot
.34833 .41938 Mdot
.44164 .20747 Mdot
.35995 .69662 Mdot
.69327 .64116 Mdot
.49518 .56463 Mdot
.60024 .5911 Mdot
.37123 .56688 Mdot
.65303 .55775 Mdot
.42174 .31311 Mdot
.58858 .35647 Mdot
.1662 .63369 Mdot
.4195 .33302 Mdot
.60795 .59738 Mdot
.38412 .70564 Mdot
.59454 .41255 Mdot
.35516 .45368 Mdot
.26455 .32262 Mdot
.6492 .56548 Mdot
.61234 .52517 Mdot
.61576 .54652 Mdot
.68705 .25394 Mdot
.33631 .51685 Mdot
.60574 .35776 Mdot
.4126 .31869 Mdot
.41045 .3542 Mdot
.36315 .55309 Mdot
.51888 .28476 Mdot
.45596 .55784 Mdot
.88836 .43247 Mdot
.34878 .56316 Mdot
.39883 .71853 Mdot
.5297 .44443 Mdot
.36857 .57829 Mdot
.34818 .50861 Mdot
.36672 .52395 Mdot
.4587 .28037 Mdot
.59848 .38256 Mdot
.60827 .56169 Mdot
.58102 .35267 Mdot
.56794 .60709 Mdot
.4525 .62517 Mdot
.42156 .36079 Mdot
.58814 .3557 Mdot
.49125 .84477 Mdot
.56665 .3421 Mdot
.56264 .57439 Mdot
.57507 .80169 Mdot
.62614 .51808 Mdot
.54584 .76065 Mdot
.6134 .51362 Mdot
.34301 .53662 Mdot
.63652 .65754 Mdot
.52259 .56755 Mdot
.32644 .24493 Mdot
.42068 .32288 Mdot
.37144 .45136 Mdot
.59272 .62935 Mdot
.64043 .61611 Mdot
.57524 .40582 Mdot
.62094 .39868 Mdot
.4041 .6935 Mdot
.43302 .64822 Mdot
.41076 .33122 Mdot
.40505 .77242 Mdot
.5903 .591 Mdot
.37229 .26677 Mdot
.69167 .57924 Mdot
.59076 .57371 Mdot
.75484 .67371 Mdot
.709 .5634 Mdot
.54557 .57067 Mdot
.64702 .44618 Mdot
.43073 .33666 Mdot
.43992 .21231 Mdot
.55247 .53537 Mdot
.35601 .5358 Mdot
.59881 .34857 Mdot
.60945 .41058 Mdot
.39394 .67336 Mdot
.1855 .41546 Mdot
.45795 .34002 Mdot
.59308 .35034 Mdot
.55427 .58578 Mdot
.45104 .35325 Mdot
.36728 .4766 Mdot
.53243 .54803 Mdot
.62821 .70955 Mdot
.61404 .37952 Mdot
.53698 .55651 Mdot
.52597 .21816 Mdot
.4396 .66248 Mdot
.84078 .43497 Mdot
.44 .31066 Mdot
.39408 .70891 Mdot
.59656 .50398 Mdot
.35332 .77434 Mdot
.56013 .62811 Mdot
.43842 .73762 Mdot
.59316 .44497 Mdot
.39044 .71484 Mdot
.56812 .57815 Mdot
.5724 .54955 Mdot
.51905 .42335 Mdot
.36589 .72439 Mdot
.57013 .61433 Mdot
.60779 .66943 Mdot
.59563 .37814 Mdot
.37295 .43111 Mdot
.61016 .38297 Mdot
.5647 .56482 Mdot
.53971 .63355 Mdot
.60546 .40156 Mdot
.38121 .78794 Mdot
.41531 .69804 Mdot
.44068 .31702 Mdot
.60498 .64933 Mdot
.56268 .53216 Mdot
.68556 .22863 Mdot
.37123 .44799 Mdot
.66769 .27205 Mdot
.33523 .58002 Mdot
.54956 .3119 Mdot
.32666 .39911 Mdot
.80738 .63112 Mdot
.35092 .24427 Mdot
.62535 .62239 Mdot
.51411 .6724 Mdot
.67042 .41945 Mdot
.4538 .35474 Mdot
.74885 .40309 Mdot
.58842 .59473 Mdot
.56744 .59497 Mdot
.33516 .56704 Mdot
.50007 .28105 Mdot
.23506 .41199 Mdot
.49986 .43626 Mdot
.38306 .69338 Mdot
.63499 .35383 Mdot
.60463 .57162 Mdot
.43414 .59989 Mdot
.35659 .58419 Mdot
.36363 .27951 Mdot
.5768 .58036 Mdot
.19234 .46115 Mdot
.47294 .29686 Mdot
.45534 .33868 Mdot
.37332 .55534 Mdot
.36728 .60622 Mdot
.5791 .60898 Mdot
.4345 .36437 Mdot
.55254 .56249 Mdot
.43373 .47958 Mdot
.52985 .58507 Mdot
.39889 .69814 Mdot
.622 .58886 Mdot
.49302 .41076 Mdot
.84722 .49555 Mdot
.65583 .66311 Mdot
.62651 .40287 Mdot
.3666 .60193 Mdot
.36116 .55659 Mdot
.61718 .3984 Mdot
.35862 .5548 Mdot
.68343 .5079 Mdot
.75843 .54987 Mdot
.37944 .69108 Mdot
.62413 .64542 Mdot
.39824 .68445 Mdot
.37226 .44631 Mdot
.58577 .60163 Mdot
.35956 .78604 Mdot
.34791 .55874 Mdot
.52772 .17852 Mdot
.41721 .33043 Mdot
.37151 .44928 Mdot
.53581 .58615 Mdot
.30474 .55989 Mdot
.36758 .58792 Mdot
.34873 .43271 Mdot
.57164 .55356 Mdot
.60499 .39589 Mdot
.57851 .54711 Mdot
.62551 .52065 Mdot
.36881 .42842 Mdot
.58896 .52026 Mdot
.43386 .32006 Mdot
.62028 .33172 Mdot
.76731 .68472 Mdot
.34593 .41977 Mdot
.59092 .60978 Mdot
.55533 .58459 Mdot
.57939 .40392 Mdot
.53752 .5627 Mdot
.42031 .36832 Mdot
.68727 .16613 Mdot
.37448 .68573 Mdot
.36953 .49926 Mdot
.32954 .40889 Mdot
.57377 .63266 Mdot
.59802 .54064 Mdot
.52601 .84354 Mdot
.34398 .36843 Mdot
.44144 .336 Mdot
.65744 .59372 Mdot
.35272 .50717 Mdot
.38252 .70649 Mdot
.39583 .3409 Mdot
.60601 .53504 Mdot
.5719 .58868 Mdot
.39578 .70334 Mdot
.72769 .70274 Mdot
.22925 .53366 Mdot
.43623 .30578 Mdot
.63997 .65422 Mdot
.2983 .60118 Mdot
.54654 .59579 Mdot
.33937 .63051 Mdot
.62598 .39262 Mdot
.44726 .34925 Mdot
.68802 .28289 Mdot
.62427 .58617 Mdot
.41163 .36433 Mdot
.41297 .32795 Mdot
.55974 .51602 Mdot
.56998 .40474 Mdot
.62298 .3363 Mdot
.64261 .36431 Mdot
.33163 .22033 Mdot
.4624 .67878 Mdot
.34309 .57133 Mdot
.43133 .33806 Mdot
.37242 .5174 Mdot
.37093 .73126 Mdot
.43901 .60969 Mdot
.376 .52552 Mdot
.59757 .40527 Mdot
.37577 .54462 Mdot
.57616 .54971 Mdot
.40802 .33907 Mdot
.33261 .53813 Mdot
.58772 .62857 Mdot
.48878 .55238 Mdot
.4228 .45833 Mdot
.36672 .66531 Mdot
.40044 .65774 Mdot
.61077 .58124 Mdot
.37038 .4436 Mdot
.58482 .5865 Mdot
.4251 .3006 Mdot
.51724 .39827 Mdot
.57314 .63065 Mdot
.34905 .55274 Mdot
.53627 .64765 Mdot
.37386 .59584 Mdot
.65354 .56532 Mdot
.56986 .56378 Mdot
.55536 .60312 Mdot
.55241 .56135 Mdot
.5182 .31157 Mdot
.46028 .33962 Mdot
.48339 .57889 Mdot
.32589 .49176 Mdot
.62178 .37456 Mdot
.654 .37579 Mdot
.29242 .62358 Mdot
.37724 .52206 Mdot
.43326 .32703 Mdot
.54434 .58546 Mdot
.34083 .4101 Mdot
.65327 .81068 Mdot
.38403 .79173 Mdot
.38289 .65089 Mdot
.33413 .50787 Mdot
.62602 .40506 Mdot
.36305 .58944 Mdot
.57259 .60542 Mdot
.57302 .50989 Mdot
.79797 .65247 Mdot
.4707 .34703 Mdot
.38828 .69477 Mdot
.55856 .6046 Mdot
.44564 .67047 Mdot
.35113 .50457 Mdot
.36699 .52176 Mdot
.56154 .61342 Mdot
.64257 .34493 Mdot
.79509 .32901 Mdot
.45585 .34134 Mdot
.56461 .67657 Mdot
.66392 .32253 Mdot
.45983 .21944 Mdot
.41547 .36034 Mdot
.40632 .4602 Mdot
.33786 .49492 Mdot
.70413 .64355 Mdot
.62197 .3789 Mdot
.3909 .69601 Mdot
.55474 .5138 Mdot
.59313 .39938 Mdot
.3362 .49176 Mdot
.58025 .38046 Mdot
.62133 .60794 Mdot
.4577 .35058 Mdot
.36722 .53324 Mdot
.46667 .3403 Mdot
.6067 .42032 Mdot
.38174 .67222 Mdot
.49859 .50028 Mdot
.77313 .43265 Mdot
.70679 .56076 Mdot
.53926 .58466 Mdot
.42656 .60276 Mdot
.57113 .53505 Mdot
.57079 .4009 Mdot
.55114 .57108 Mdot
.67475 .34298 Mdot
.37198 .55717 Mdot
.53897 .55314 Mdot
.61905 .55106 Mdot
.74239 .4252 Mdot
.57622 .57213 Mdot
.5795 .51651 Mdot
.54419 .57221 Mdot
.66222 .38101 Mdot
.64285 .57933 Mdot
.60024 .38836 Mdot
.26036 .33241 Mdot
.34739 .50943 Mdot
.36286 .66675 Mdot
.35565 .70015 Mdot
.43527 .72938 Mdot
.44323 .63841 Mdot
.51185 .28779 Mdot
.60578 .37739 Mdot
.42528 .31744 Mdot
.55041 .56499 Mdot
.71787 .31427 Mdot
.31984 .45484 Mdot
.35367 .50269 Mdot
.3473 .42017 Mdot
.65528 .54428 Mdot
.68841 .25328 Mdot
.53273 .57847 Mdot
.22891 .35164 Mdot
.57546 .64032 Mdot
.57212 .61791 Mdot
.36032 .60178 Mdot
.44034 .63646 Mdot
.53961 .59106 Mdot
.5754 .40536 Mdot
.3928 .68955 Mdot
.59264 .31407 Mdot
.25808 .48311 Mdot
.39519 .45722 Mdot
.77087 .47734 Mdot
.56145 .54154 Mdot
.36453 .52917 Mdot
.58871 .38598 Mdot
.33352 .25721 Mdot
.45247 .33281 Mdot
.4752 .2854 Mdot
.70731 .41381 Mdot
.53125 .82137 Mdot
.39114 .69261 Mdot
.72444 .70151 Mdot
.59713 .56137 Mdot
.3753 .60432 Mdot
.62821 .59857 Mdot
.65741 .80736 Mdot
.40271 .71386 Mdot
.65025 .35322 Mdot
.4388 .34745 Mdot
.57299 .38404 Mdot
.71987 .58817 Mdot
.37313 .37243 Mdot
.47369 .49117 Mdot
.35995 .47999 Mdot
.48134 .55556 Mdot
.61986 .35456 Mdot
.61164 .55094 Mdot
.90286 .46903 Mdot
.62906 .38991 Mdot
.64403 .35475 Mdot
.45666 .80559 Mdot
.45719 .81055 Mdot
.66274 .59183 Mdot
.57899 .38832 Mdot
.35675 .48253 Mdot
.36471 .68668 Mdot
.57342 .54506 Mdot
.55985 .55516 Mdot
.60677 .39951 Mdot
.37283 .57863 Mdot
.58145 .68402 Mdot
.34494 .5409 Mdot
.59368 .37808 Mdot
.34735 .52647 Mdot
.3414 .43735 Mdot
.33482 .51339 Mdot
.55402 .53982 Mdot
.55077 .56956 Mdot
.25279 .53205 Mdot
.61224 .39159 Mdot
.59338 .53663 Mdot
.61611 .57461 Mdot
.62453 .35781 Mdot
.33386 .5796 Mdot
.73228 .34124 Mdot
.59581 .60277 Mdot
.58706 .55503 Mdot
.39292 .71209 Mdot
.39784 .60394 Mdot
.21662 .58643 Mdot
.58459 .54017 Mdot
.38611 .72592 Mdot
.60758 .33749 Mdot
.58651 .58351 Mdot
.55668 .42972 Mdot
.3458 .44255 Mdot
.62329 .58143 Mdot
.3591 .4672 Mdot
.5528 .61879 Mdot
.80949 .37327 Mdot
.5999 .60966 Mdot
.61092 .35939 Mdot
.60521 .34876 Mdot
.4696 .80143 Mdot
.63421 .37325 Mdot
.36709 .46557 Mdot
.41861 .35236 Mdot
.67954 .78892 Mdot
.367 .4788 Mdot
.57266 .6205 Mdot
.19036 .64467 Mdot
.53681 .55076 Mdot
.58705 .63075 Mdot
.65689 .23024 Mdot
.36628 .47922 Mdot
.60516 .35223 Mdot
.42647 .26863 Mdot
.5901 .64454 Mdot
.44749 .35711 Mdot
.53243 .53685 Mdot
.60291 .52357 Mdot
.41416 .22709 Mdot
.60206 .22779 Mdot
.40747 .30714 Mdot
.52025 .53225 Mdot
.58496 .5397 Mdot
.41508 .56908 Mdot
.55103 .5802 Mdot
.40034 .68732 Mdot
.64328 .35663 Mdot
.35901 .57856 Mdot
.36798 .68994 Mdot
.59464 .59166 Mdot
.38785 .70013 Mdot
.34254 .57219 Mdot
.44295 .35511 Mdot
.58166 .60585 Mdot
.41092 .70226 Mdot
.3839 .69472 Mdot
.57851 .53132 Mdot
.59251 .352 Mdot
.65956 .64697 Mdot
.58797 .58079 Mdot
.61005 .55367 Mdot
.60965 .39741 Mdot
.32817 .79252 Mdot
.58906 .61491 Mdot
.43652 .44011 Mdot
.64969 .36176 Mdot
.35028 .39738 Mdot
.34022 .57202 Mdot
.60084 .52127 Mdot
.43791 .36068 Mdot
.42443 .36056 Mdot
.35977 .49783 Mdot
.57309 .39261 Mdot
.37314 .5849 Mdot
.54323 .65093 Mdot
.61305 .64608 Mdot
.54762 .53126 Mdot
.15575 .57906 Mdot
.79321 .64828 Mdot
.62094 .40404 Mdot
.32715 .52757 Mdot
.50023 .44163 Mdot
.43432 .34003 Mdot
.36689 .50852 Mdot
.59396 .41353 Mdot
.61994 .40906 Mdot
.58283 .38569 Mdot
.38295 .71526 Mdot
.326 .53637 Mdot
.6419 .33557 Mdot
.64013 .34321 Mdot
.57427 .55177 Mdot
.58663 .53856 Mdot
.61332 .46924 Mdot
.53048 .73709 Mdot
.38644 .67176 Mdot
.36304 .54763 Mdot
.58589 .14083 Mdot
.4214 .30071 Mdot
.74438 .43039 Mdot
.57634 .63144 Mdot
.88653 .62787 Mdot
.53277 .58487 Mdot
.55236 .58602 Mdot
.60649 .33516 Mdot
.40995 .68767 Mdot
.39369 .68123 Mdot
.61921 .35316 Mdot
.6078 .41866 Mdot
.40114 .69391 Mdot
.66906 .75676 Mdot
.73552 .72728 Mdot
.42284 .25951 Mdot
.61817 .36164 Mdot
.78389 .46733 Mdot
.44287 .36107 Mdot
.60366 .42224 Mdot
.4166 .30581 Mdot
.35025 .51092 Mdot
.33775 .49372 Mdot
.41667 .31336 Mdot
.5681 .55548 Mdot
.33688 .55958 Mdot
.6316 .55424 Mdot
.6932 .74711 Mdot
.77323 .59762 Mdot
.31909 .35599 Mdot
.63527 .61573 Mdot
.23914 .39898 Mdot
.24466 .41483 Mdot
.60597 .58818 Mdot
.54355 .34707 Mdot
.38869 .69657 Mdot
.61404 .42572 Mdot
.42292 .36797 Mdot
.8367 .42298 Mdot
.54491 .59178 Mdot
.60894 .36294 Mdot
.42457 .32183 Mdot
.47398 .7907 Mdot
.44062 .24573 Mdot
.56489 .60725 Mdot
.87113 .39892 Mdot
.61784 .42908 Mdot
.35788 .57802 Mdot
.1735 .53495 Mdot
.58716 .34396 Mdot
.40214 .65131 Mdot
.3274 .50021 Mdot
.52652 .83341 Mdot
.59199 .3647 Mdot
.33631 .48998 Mdot
.63165 .35324 Mdot
.39708 .67862 Mdot
.58669 .43193 Mdot
.3639 .52287 Mdot
.57255 .57548 Mdot
.35676 .55013 Mdot
.3828 .67064 Mdot
.37472 .60127 Mdot
.42839 .3663 Mdot
.36881 .45447 Mdot
.42404 .34252 Mdot
.43855 .65785 Mdot
.49747 .19141 Mdot
.44692 .3251 Mdot
.4482 .78261 Mdot
.61784 .62146 Mdot
.62707 .32876 Mdot
.35199 .56686 Mdot
.33317 .48759 Mdot
.50691 .47958 Mdot
.62516 .37037 Mdot
.36625 .54785 Mdot
.7074 .40406 Mdot
.25109 .71596 Mdot
.55511 .6438 Mdot
.47559 .67493 Mdot
.62415 .36 Mdot
.36801 .52061 Mdot
.28454 .29666 Mdot
.59664 .40613 Mdot
.34811 .56347 Mdot
.43533 .35375 Mdot
.41194 .3572 Mdot
.55198 .60649 Mdot
.41861 .27549 Mdot
.36369 .56929 Mdot
.26349 .35321 Mdot
.62181 .34342 Mdot
.47581 .7882 Mdot
.37889 .66611 Mdot
.34583 .50469 Mdot
.52436 .56101 Mdot
.60552 .32069 Mdot
.34386 .44682 Mdot
.57993 .69472 Mdot
.57959 .1451 Mdot
.36269 .55153 Mdot
.64223 .35448 Mdot
.60912 .36668 Mdot
.63341 .52252 Mdot
.51382 .43098 Mdot
.3686 .59613 Mdot
.34126 .76516 Mdot
.44551 .74302 Mdot
.36406 .44154 Mdot
.25617 .43014 Mdot
.54747 .61072 Mdot
.57104 .53099 Mdot
.43598 .34063 Mdot
.57285 .56884 Mdot
.63093 .3364 Mdot
.5374 .58347 Mdot
.40716 .35826 Mdot
.34545 .49428 Mdot
.58151 .60268 Mdot
.36294 .68638 Mdot
.39401 .32289 Mdot
.41262 .31448 Mdot
.34252 .51639 Mdot
.58009 .38836 Mdot
.41713 .71372 Mdot
.34791 .54636 Mdot
.55948 .54431 Mdot
.35586 .45022 Mdot
.62123 .60262 Mdot
.68258 .71879 Mdot
.58919 .40214 Mdot
.36764 .5828 Mdot
.65188 .37291 Mdot
.4241 .33731 Mdot
.32582 .49309 Mdot
.55869 .5702 Mdot
.3458 .56053 Mdot
.24744 .50529 Mdot
.69297 .72861 Mdot
.57276 .39603 Mdot
.27444 .43342 Mdot
.64161 .34911 Mdot
.36519 .43944 Mdot
.6292 .73158 Mdot
.38457 .68575 Mdot
.35448 .51155 Mdot
.79168 .63581 Mdot
.35054 .55663 Mdot
.58017 .57079 Mdot
.59785 .57275 Mdot
.33283 .55872 Mdot
.3694 .71735 Mdot
.38142 .2027 Mdot
.41612 .44304 Mdot
.59796 .35693 Mdot
.68347 .66253 Mdot
.64533 .17466 Mdot
.42038 .38124 Mdot
.43859 .338 Mdot
.61209 .63761 Mdot
.55707 .61458 Mdot
.40018 .32596 Mdot
.41523 .37308 Mdot
.39374 .67026 Mdot
.36356 .51745 Mdot
.58475 .43324 Mdot
.3993 .36616 Mdot
.55018 .48998 Mdot
.44516 .64069 Mdot
.65163 .61391 Mdot
.51374 .60615 Mdot
.63536 .57659 Mdot
.42891 .74732 Mdot
.40227 .3427 Mdot
.61159 .57763 Mdot
.6471 .57514 Mdot
.44445 .34898 Mdot
.39787 .68088 Mdot
.58488 .22069 Mdot
.35198 .52916 Mdot
.48432 .87064 Mdot
.61529 .60593 Mdot
.5822 .57413 Mdot
.44346 .31195 Mdot
.40078 .58405 Mdot
.5968 .3992 Mdot
.58163 .39684 Mdot
.33542 .52199 Mdot
.48436 .5152 Mdot
.54109 .56004 Mdot
.60835 .58582 Mdot
.36063 .52976 Mdot
.3689 .45284 Mdot
.29545 .352 Mdot
.60393 .55847 Mdot
.42441 .32368 Mdot
.33968 .47976 Mdot
.40201 .34938 Mdot
.61023 .61558 Mdot
.58352 .56937 Mdot
.5504 .54327 Mdot
.55863 .61584 Mdot
.41714 .30986 Mdot
.60919 .574 Mdot
.53333 .61857 Mdot
.58071 .37025 Mdot
.56136 .53568 Mdot
.43828 .74743 Mdot
.57604 .55913 Mdot
.37447 .67542 Mdot
.41322 .62587 Mdot
.55656 .60461 Mdot
.56693 .52939 Mdot
.41884 .44404 Mdot
.56557 .58109 Mdot
.42458 .30092 Mdot
.61804 .37325 Mdot
.4313 .33888 Mdot
.41077 .31933 Mdot
.35542 .47465 Mdot
.40057 .67958 Mdot
.59201 .63529 Mdot
.36168 .67842 Mdot
.51541 .5599 Mdot
.62395 .60476 Mdot
.31115 .51824 Mdot
.22622 .35428 Mdot
.23193 .53839 Mdot
.55848 .56872 Mdot
.34021 .50894 Mdot
.36137 .58065 Mdot
.52461 .67236 Mdot
.63611 .56099 Mdot
.39693 .33213 Mdot
.43022 .35524 Mdot
.58555 .73764 Mdot
.41172 .23023 Mdot
.38237 .6728 Mdot
.43408 .6064 Mdot
.64124 .59602 Mdot
.61221 .56356 Mdot
.53163 .55073 Mdot
.37536 .52404 Mdot
.36402 .42344 Mdot
.3535 .50206 Mdot
.35682 .41723 Mdot
.40454 .35715 Mdot
.54044 .57328 Mdot
.79692 .56471 Mdot
.61558 .40243 Mdot
.61794 .37405 Mdot
.39699 .34471 Mdot
.37508 .58336 Mdot
.5891 .49266 Mdot
.17445 .665 Mdot
.64855 .40051 Mdot
.38383 .6624 Mdot
.60578 .59289 Mdot
.34096 .51431 Mdot
.63383 .38991 Mdot
.36584 .71881 Mdot
.62062 .57292 Mdot
.35838 .60834 Mdot
.55782 .5648 Mdot
.66902 .41983 Mdot
.58727 .36175 Mdot
.67385 .80153 Mdot
.59685 .41197 Mdot
.39002 .33432 Mdot
.44631 .3358 Mdot
.59152 .57173 Mdot
.16102 .56704 Mdot
.61408 .3291 Mdot
.43121 .28022 Mdot
.40779 .7025 Mdot
.35394 .45395 Mdot
.39426 .71697 Mdot
.36859 .57679 Mdot
.39181 .68981 Mdot
.37047 .5395 Mdot
.57031 .73389 Mdot
.66587 .35396 Mdot
.37153 .68664 Mdot
.43075 .54459 Mdot
.64151 .58563 Mdot
.35193 .6959 Mdot
.54224 .62078 Mdot
.69677 .6473 Mdot
.35961 .53168 Mdot
.36721 .71506 Mdot
.60994 .54965 Mdot
.8295 .45437 Mdot
.43844 .32238 Mdot
.39835 .32723 Mdot
.61956 .53056 Mdot
.36296 .51516 Mdot
.58675 .41514 Mdot
.52051 .38323 Mdot
.3586 .40316 Mdot
.60952 .58142 Mdot
.53835 .58782 Mdot
.65473 .37443 Mdot
.65847 .3349 Mdot
.58822 .56846 Mdot
.72304 .38638 Mdot
.60215 .56452 Mdot
.42652 .3631 Mdot
.60902 .40828 Mdot
.61258 .36914 Mdot
.36819 .5651 Mdot
.57948 .3605 Mdot
.52555 .62823 Mdot
.48494 .3828 Mdot
.56056 .63248 Mdot
.41928 .33531 Mdot
.50282 .40253 Mdot
.34719 .42072 Mdot
.82061 .54209 Mdot
.64308 .39653 Mdot
.58329 .51957 Mdot
.63267 .34667 Mdot
.37676 .71054 Mdot
.61254 .38896 Mdot
.64268 .38007 Mdot
.5933 .5846 Mdot
.56717 .60562 Mdot
.36448 .47433 Mdot
.5123 .43607 Mdot
.59134 .35 Mdot
.60693 .5765 Mdot
.54002 .54802 Mdot
.58555 .51432 Mdot
.45521 .44495 Mdot
.62565 .40118 Mdot
.7167 .45244 Mdot
.64311 .70455 Mdot
.58863 .35322 Mdot
.79615 .3519 Mdot
.35374 .44752 Mdot
.37174 .50582 Mdot
.46069 .3645 Mdot
.6045 .5579 Mdot
.33023 .5488 Mdot
.57353 .60538 Mdot
.50936 .59719 Mdot
.57103 .59152 Mdot
.38251 .72472 Mdot
.62554 .62203 Mdot
.36243 .45062 Mdot
.3507 .54995 Mdot
.61116 .60026 Mdot
.57916 .60111 Mdot
.38394 .55151 Mdot
.61576 .41472 Mdot
.59383 .39729 Mdot
.35777 .63904 Mdot
.37386 .69883 Mdot
.44735 .35284 Mdot
.54706 .57265 Mdot
.33825 .51153 Mdot
.35514 .54954 Mdot
.57244 .37834 Mdot
.35532 .53816 Mdot
.45285 .32539 Mdot
.5566 .57368 Mdot
.40008 .3247 Mdot
.36356 .71223 Mdot
.64368 .36409 Mdot
.54317 .58597 Mdot
.57531 .55153 Mdot
.60512 .34889 Mdot
.62057 .62062 Mdot
.39356 .71159 Mdot
.35416 .55651 Mdot
.58882 .37201 Mdot
.41861 .35418 Mdot
.37221 .56216 Mdot
.59142 .54555 Mdot
.5707 .14382 Mdot
.58096 .56561 Mdot
.60065 .5506 Mdot
.7738 .69091 Mdot
.61903 .62986 Mdot
.35997 .56587 Mdot
.65654 .36427 Mdot
.6229 .541 Mdot
.44821 .70876 Mdot
.37628 .79392 Mdot
.35964 .49087 Mdot
.60365 .59981 Mdot
.82413 .55215 Mdot
.60687 .60113 Mdot
.4026 .76976 Mdot
.25357 .62325 Mdot
.47483 .58772 Mdot
.51147 .59308 Mdot
.43051 .30917 Mdot
.365 .47183 Mdot
.37155 .55577 Mdot
.65758 .49845 Mdot
.5993 .58298 Mdot
.64791 .43358 Mdot
.62113 .55794 Mdot
.41306 .35945 Mdot
.66038 .66718 Mdot
.36087 .54793 Mdot
.24738 .32583 Mdot
.56466 .54178 Mdot
.62128 .40535 Mdot
.3762 .55213 Mdot
.35291 .44566 Mdot
.60274 .54808 Mdot
.35749 .68831 Mdot
.45693 .30352 Mdot
.58534 .64621 Mdot
.41575 .33941 Mdot
.617 .57057 Mdot
.50918 .55757 Mdot
.16612 .48287 Mdot
.58426 .3661 Mdot
.43811 .34525 Mdot
.24829 .42582 Mdot
.62339 .61887 Mdot
.58982 .3674 Mdot
.62255 .3776 Mdot
.38174 .66785 Mdot
.48351 .46485 Mdot
.52796 .22639 Mdot
.80167 .50285 Mdot
.69085 .614 Mdot
.36952 .51931 Mdot
.27376 .39054 Mdot
.57706 .54256 Mdot
.35762 .29842 Mdot
.41517 .30339 Mdot
.57878 .57481 Mdot
.69608 .58216 Mdot
.64132 .37161 Mdot
.592 .55603 Mdot
.3985 .68432 Mdot
.34847 .28431 Mdot
.3492 .30525 Mdot
.7289 .28367 Mdot
.35699 .48543 Mdot
.54066 .52881 Mdot
.51967 .61614 Mdot
.37226 .45492 Mdot
.62732 .58406 Mdot
.35715 .56359 Mdot
.63069 .77056 Mdot
.37834 .7222 Mdot
.64014 .37953 Mdot
.35358 .44652 Mdot
.63183 .56288 Mdot
.55743 .52781 Mdot
.36499 .66527 Mdot
.59219 .52489 Mdot
.18703 .4181 Mdot
.31544 .39051 Mdot
.33344 .54339 Mdot
.58155 .38239 Mdot
.6394 .59475 Mdot
.36573 .42315 Mdot
.59588 .58024 Mdot
.76386 .57414 Mdot
.58037 .5215 Mdot
.50401 .22139 Mdot
.59902 .3481 Mdot
.41796 .34013 Mdot
.52908 .52762 Mdot
.56443 .59157 Mdot
.30091 .59636 Mdot
.50833 .58317 Mdot
.60301 .60977 Mdot
.57827 .4075 Mdot
.61783 .40384 Mdot
.60101 .38743 Mdot
.35549 .58594 Mdot
.38995 .25382 Mdot
.42694 .32777 Mdot
.54519 .61095 Mdot
.39797 .36538 Mdot
.60023 .68277 Mdot
.36936 .66268 Mdot
.80263 .40709 Mdot
.59615 .52254 Mdot
.6019 .37985 Mdot
.57289 .28024 Mdot
.61056 .33685 Mdot
.329 .57841 Mdot
.41012 .33253 Mdot
.63639 .38122 Mdot
.55698 .58909 Mdot
.50241 .42663 Mdot
.7517 .33173 Mdot
.4302 .34485 Mdot
.5219 .59299 Mdot
.34358 .48493 Mdot
.33197 .41315 Mdot
.63639 .15528 Mdot
.44162 .33383 Mdot
.25206 .41177 Mdot
.60463 .58449 Mdot
.61137 .40273 Mdot
.43898 .31112 Mdot
.43847 .31842 Mdot
.35995 .53715 Mdot
.56366 .60529 Mdot
.55496 .6013 Mdot
.35677 .46017 Mdot
.42815 .35643 Mdot
.59845 .50911 Mdot
.52666 .56732 Mdot
.79751 .65485 Mdot
.63677 .48787 Mdot
.36981 .82824 Mdot
.55042 .65614 Mdot
.70175 .59332 Mdot
.5392 .44239 Mdot
.64728 .3625 Mdot
.56008 .60674 Mdot
.6363 .5961 Mdot
.36539 .56651 Mdot
.56768 .56928 Mdot
.35008 .59041 Mdot
.43605 .3272 Mdot
.78812 .34688 Mdot
.59475 .24481 Mdot
.62505 .76741 Mdot
.56774 .57245 Mdot
.43594 .22529 Mdot
.36704 .70338 Mdot
.3928 .31927 Mdot
.59242 .3827 Mdot
.61621 .61847 Mdot
.37623 .59234 Mdot
.35344 .50932 Mdot
.62585 .38447 Mdot
.24612 .36925 Mdot
.32613 .62296 Mdot
.61049 .61595 Mdot
.34552 .5808 Mdot
.53468 .32634 Mdot
.71914 .37386 Mdot
.39711 .37363 Mdot
.38857 .72199 Mdot
.35237 .50114 Mdot
.39917 .34705 Mdot
.58324 .44529 Mdot
.63542 .3785 Mdot
.65665 .35239 Mdot
.26648 .5959 Mdot
.37033 .59729 Mdot
.36594 .69038 Mdot
.39617 .24671 Mdot
.38804 .24217 Mdot
.38506 .72356 Mdot
.33537 .49646 Mdot
.62638 .39792 Mdot
.59857 .3657 Mdot
.61781 .37209 Mdot
.26021 .31036 Mdot
.57897 .39967 Mdot
.75746 .47068 Mdot
.54315 .54219 Mdot
.57766 .46917 Mdot
.60378 .60158 Mdot
.41391 .30857 Mdot
.59005 .35914 Mdot
.52822 .4518 Mdot
.57327 .62347 Mdot
.74361 .30626 Mdot
.60997 .58522 Mdot
.39344 .37004 Mdot
.59794 .5544 Mdot
.75978 .42873 Mdot
.64962 .35903 Mdot
.56337 .56738 Mdot
.45665 .31818 Mdot
.3817 .69767 Mdot
.56763 .40414 Mdot
.55673 .60401 Mdot
.49239 .27111 Mdot
.60919 .63674 Mdot
.65614 .76799 Mdot
.50379 .78138 Mdot
.38361 .66209 Mdot
.61039 .67037 Mdot
.36211 .50726 Mdot
.60983 .454 Mdot
.59564 .65577 Mdot
.42881 .34554 Mdot
.57185 .19864 Mdot
.34814 .50318 Mdot
.65985 .65881 Mdot
.65553 .57041 Mdot
.40073 .68144 Mdot
.60433 .324 Mdot
.42896 .30214 Mdot
.5948 .62766 Mdot
.56211 .51517 Mdot
.64265 .76185 Mdot
.59477 .65259 Mdot
.53613 .56761 Mdot
.359 .67386 Mdot
.72217 .4616 Mdot
.57708 .55589 Mdot
.32526 .5589 Mdot
.65622 .35475 Mdot
.62331 .53701 Mdot
.7167 .4474 Mdot
.60609 .57695 Mdot
.62238 .39286 Mdot
.65421 .33484 Mdot
.55064 .26693 Mdot
.40814 .69381 Mdot
.58097 .5214 Mdot
.53327 .7954 Mdot
.5676 .53663 Mdot
.42108 .32557 Mdot
.5946 .61562 Mdot
.35436 .51507 Mdot
.24595 .33755 Mdot
.34686 .57259 Mdot
.57936 .61105 Mdot
.61711 .36756 Mdot
.4296 .30638 Mdot
.24651 .56307 Mdot
.27856 .63469 Mdot
.75214 .46746 Mdot
.48935 .84663 Mdot
.37571 .71792 Mdot
.36364 .72572 Mdot
.43636 .30281 Mdot
.56408 .56547 Mdot
.48972 .80101 Mdot
.58529 .64264 Mdot
.58867 .55409 Mdot
.57213 .59239 Mdot
.37111 .2935 Mdot
.43399 .3343 Mdot
.35024 .53567 Mdot
.58604 .56789 Mdot
.6072 .5744 Mdot
.62803 .34762 Mdot
.38174 .69555 Mdot
.35128 .57777 Mdot
.37568 .69018 Mdot
.3397 .53758 Mdot
.80694 .36592 Mdot
.52868 .5959 Mdot
.38002 .69971 Mdot
.41781 .29949 Mdot
.60977 .39789 Mdot
.3669 .41949 Mdot
.36985 .57292 Mdot
.36403 .54827 Mdot
.60867 .58254 Mdot
.61712 .3973 Mdot
.58258 .35748 Mdot
.37518 .71113 Mdot
.45124 .33506 Mdot
.57598 .60885 Mdot
.62205 .61126 Mdot
.49939 .64318 Mdot
.37864 .54428 Mdot
.70711 .38767 Mdot
.53601 .28718 Mdot
.5604 .56665 Mdot
.57804 .38603 Mdot
.58055 .59499 Mdot
.79869 .58494 Mdot
.59676 .40436 Mdot
.57096 .61714 Mdot
.3931 .2264 Mdot
.35271 .45919 Mdot
.50219 .24795 Mdot
.55195 .53909 Mdot
.54174 .8455 Mdot
.57966 .53733 Mdot
.82307 .60014 Mdot
.39455 .53193 Mdot
.53951 .57261 Mdot
.57762 .54609 Mdot
.80504 .48006 Mdot
.59834 .59266 Mdot
.36639 .44131 Mdot
.65677 .66621 Mdot
.62261 .40805 Mdot
.53632 .45917 Mdot
.39147 .61803 Mdot
.40977 .69661 Mdot
.33522 .52319 Mdot
.26327 .44261 Mdot
.39947 .69652 Mdot
.61789 .36015 Mdot
.55231 .56093 Mdot
.47104 .54446 Mdot
.34977 .46948 Mdot
.63838 .53274 Mdot
.41729 .32681 Mdot
.29632 .41412 Mdot
.34355 .58592 Mdot
.41793 .3487 Mdot
.61336 .53808 Mdot
.74891 .35869 Mdot
.23807 .61395 Mdot
.68544 .79189 Mdot
.43712 .30635 Mdot
.41663 .36277 Mdot
.30461 .27211 Mdot
.40775 .70754 Mdot
.65892 .72362 Mdot
.47278 .22766 Mdot
.45514 .34907 Mdot
.60343 .75188 Mdot
.35527 .50082 Mdot
.48174 .26189 Mdot
.61403 .42568 Mdot
.5445 .53415 Mdot
.559 .58946 Mdot
.45073 .33926 Mdot
.56651 .43553 Mdot
.16749 .50296 Mdot
.42454 .34379 Mdot
.51472 .58522 Mdot
.45663 .47751 Mdot
.35556 .44073 Mdot
.36675 .48586 Mdot
.40589 .68481 Mdot
.36837 .64837 Mdot
.62443 .34925 Mdot
.39475 .67205 Mdot
.34449 .30931 Mdot
.59385 .52336 Mdot
.42653 .35196 Mdot
.36199 .41955 Mdot
.41433 .3544 Mdot
.3972 .68761 Mdot
.38968 .66505 Mdot
.58025 .37168 Mdot
.59583 .39768 Mdot
.70448 .58153 Mdot
.55507 .75426 Mdot
.60876 .60094 Mdot
.6768 .28347 Mdot
.61677 .34224 Mdot
.60529 .6608 Mdot
.38423 .7259 Mdot
.37803 .6977 Mdot
.65854 .4426 Mdot
.54348 .57787 Mdot
.4564 .79781 Mdot
.54512 .5794 Mdot
.61696 .722 Mdot
.62909 .58733 Mdot
.35789 .53723 Mdot
.54266 .56981 Mdot
.40378 .72864 Mdot
.54838 .61127 Mdot
.60622 .60995 Mdot
.3592 .5096 Mdot
.59498 .64697 Mdot
.35524 .51576 Mdot
.57878 .61213 Mdot
.37994 .72972 Mdot
.33776 .51272 Mdot
.46916 .69257 Mdot
.43477 .44174 Mdot
.36792 .44842 Mdot
.36899 .67597 Mdot
.372 .66833 Mdot
.43977 .69503 Mdot
.59161 .38099 Mdot
.55951 .36187 Mdot
.56753 .56453 Mdot
.36767 .52342 Mdot
.43659 .33743 Mdot
.60621 .57138 Mdot
.62982 .60484 Mdot
.5368 .55963 Mdot
.64108 .3565 Mdot
.37301 .58717 Mdot
.38424 .7023 Mdot
.34798 .58279 Mdot
.31621 .60177 Mdot
.33534 .57627 Mdot
.64529 .57707 Mdot
.55156 .51193 Mdot
.70878 .6574 Mdot
.65385 .26493 Mdot
.36092 .21973 Mdot
.63301 .37922 Mdot
.36234 .46296 Mdot
.39409 .66895 Mdot
.63801 .67681 Mdot
.59663 .37974 Mdot
.36253 .52051 Mdot
.55696 .5653 Mdot
.5186 .58367 Mdot
.465 .3717 Mdot
.61893 .44841 Mdot
.45889 .74726 Mdot
.35234 .59477 Mdot
.36354 .43755 Mdot
.38089 .25274 Mdot
.67259 .61819 Mdot
.49562 .49776 Mdot
.57853 .58377 Mdot
.35681 .69228 Mdot
.63378 .38995 Mdot
.24149 .58226 Mdot
.44037 .35391 Mdot
.51306 .43243 Mdot
.56676 .57219 Mdot
.40889 .26078 Mdot
.61837 .36851 Mdot
.39412 .67716 Mdot
.45042 .3414 Mdot
.41062 .68804 Mdot
.36788 .48881 Mdot
.45994 .82019 Mdot
.57789 .5285 Mdot
.60064 .60893 Mdot
.39117 .35408 Mdot
.62988 .35335 Mdot
.39908 .65819 Mdot
.67527 .74483 Mdot
.33627 .56546 Mdot
.44503 .79645 Mdot
.61312 .33209 Mdot
.77379 .4751 Mdot
.35078 .58414 Mdot
.39702 .34595 Mdot
.4386 .68519 Mdot
.4061 .35714 Mdot
.55315 .6044 Mdot
.60733 .37422 Mdot
.43563 .32175 Mdot
.29318 .57836 Mdot
.83653 .51268 Mdot
.78197 .47431 Mdot
.55143 .55035 Mdot
.79742 .38591 Mdot
.72027 .72967 Mdot
.54992 .38521 Mdot
.42954 .36657 Mdot
.59008 .57992 Mdot
.62473 .55682 Mdot
.56061 .54597 Mdot
.41887 .31825 Mdot
.29868 .52021 Mdot
.36484 .53797 Mdot
.60916 .59259 Mdot
.3886 .6684 Mdot
.35289 .5181 Mdot
.33851 .47345 Mdot
.36393 .56194 Mdot
.63806 .39561 Mdot
.56416 .6171 Mdot
.48484 .30017 Mdot
.85398 .50188 Mdot
.43101 .34029 Mdot
.36762 .44883 Mdot
.61934 .59615 Mdot
.46672 .20486 Mdot
.60074 .38577 Mdot
.33481 .56188 Mdot
.58207 .57473 Mdot
.29494 .54089 Mdot
.38127 .57759 Mdot
.36443 .55816 Mdot
.59439 .36906 Mdot
.54536 .36744 Mdot
.57116 .568 Mdot
.58119 .5346 Mdot
.62595 .35391 Mdot
.33555 .70569 Mdot
.25631 .32979 Mdot
.5793 .59889 Mdot
.41796 .34191 Mdot
.23463 .72208 Mdot
.56494 .52488 Mdot
.65708 .52162 Mdot
.36301 .48209 Mdot
.51161 .27773 Mdot
.70644 .38192 Mdot
.6202 .67088 Mdot
.81078 .48402 Mdot
.44505 .6056 Mdot
.793 .3585 Mdot
.34238 .60699 Mdot
.41141 .50169 Mdot
.81367 .37928 Mdot
.45495 .31845 Mdot
.56349 .47026 Mdot
.55326 .67357 Mdot
.23712 .36128 Mdot
.55028 .42563 Mdot
.32732 .67711 Mdot
.293 .60982 Mdot
.459 .53367 Mdot
.34756 .55768 Mdot
.59826 .71159 Mdot
.57609 .60743 Mdot
.71385 .73665 Mdot
.72944 .39394 Mdot
.16143 .51135 Mdot
.8051 .39875 Mdot
.53781 .79331 Mdot
.76336 .3543 Mdot
.81351 .57523 Mdot
.70228 .66435 Mdot
.64287 .27038 Mdot
.33338 .77813 Mdot
.37687 .2445 Mdot
.56073 .79715 Mdot
.59787 .50207 Mdot
.43534 .59901 Mdot
.59623 .80273 Mdot
.75951 .50559 Mdot
.16685 .59081 Mdot
.36083 .57408 Mdot
.65371 .357 Mdot
.5352 .66663 Mdot
.56536 .38056 Mdot
.39052 .38235 Mdot
.81219 .47689 Mdot
.81153 .61228 Mdot
.75491 .42562 Mdot
.54019 .84857 Mdot
.67529 .51166 Mdot
.29586 .23363 Mdot
.42683 .46339 Mdot
.64902 .33601 Mdot
.27721 .70001 Mdot
.39159 .24208 Mdot
.56977 .23507 Mdot
.54717 .65758 Mdot
.32947 .46342 Mdot
.49138 .71885 Mdot
.61004 .36281 Mdot
.71119 .36584 Mdot
.37406 .50251 Mdot
.58303 .22605 Mdot
.42423 .67449 Mdot
.82273 .51934 Mdot
.47311 .51095 Mdot
.47919 .26943 Mdot
.27682 .37736 Mdot
.57336 .14432 Mdot
.55959 .76994 Mdot
.75569 .65713 Mdot
.42618 .38833 Mdot
.54956 .41694 Mdot
.2117 .42559 Mdot
.52566 .75185 Mdot
.39354 .23863 Mdot
.60625 .19095 Mdot
.68338 .77515 Mdot
.65151 .20401 Mdot
.55924 .3823 Mdot
.53757 .5599 Mdot
.7515 .64486 Mdot
.68714 .6207 Mdot
.347 .6824 Mdot
.70617 .26367 Mdot
.35989 .7094 Mdot
.56144 .38176 Mdot
.24234 .36815 Mdot
.75858 .45241 Mdot
.4435 .78968 Mdot
.41009 .66776 Mdot
.6345 .61881 Mdot
.13076 .40834 Mdot
.78634 .35533 Mdot
.54177 .26792 Mdot
.79922 .65296 Mdot
.39822 .2647 Mdot
.48579 .78985 Mdot
.43121 .32 Mdot
.84338 .43814 Mdot
.59998 .36947 Mdot
.84408 .37907 Mdot
.84318 .48515 Mdot
.19195 .55322 Mdot
.13118 .62435 Mdot
.33812 .34495 Mdot
.4803 .57682 Mdot
.44751 .61534 Mdot
.46064 .71985 Mdot
.1774 .48397 Mdot
.18976 .58303 Mdot
.39036 .26332 Mdot
.5522 .82694 Mdot
.82519 .41047 Mdot
.61779 .74183 Mdot
.49418 .81698 Mdot
.22955 .38651 Mdot
.44804 .43955 Mdot
.62005 .31747 Mdot
.41794 .4238 Mdot
.66212 .29578 Mdot
.69491 .25013 Mdot
.68244 .60754 Mdot
.18007 .67438 Mdot
.41849 .69972 Mdot
.39055 .56777 Mdot
.76361 .68064 Mdot
.47712 .68635 Mdot
.66612 .6757 Mdot
.32703 .26495 Mdot
.65362 .58573 Mdot
.3484 .25542 Mdot
.59209 .30008 Mdot
.27131 .43531 Mdot
.36843 .25172 Mdot
.5191 .33573 Mdot
.65417 .75648 Mdot
.76349 .60987 Mdot
.41267 .22233 Mdot
.62177 .40959 Mdot
.49797 .75626 Mdot
.57746 .76475 Mdot
.79004 .6639 Mdot
.24859 .42512 Mdot
.71037 .78299 Mdot
.22891 .44857 Mdot
.55739 .62828 Mdot
.55462 .64497 Mdot
.56888 .4918 Mdot
.533 .76155 Mdot
.53606 .55624 Mdot
.39661 .25895 Mdot
.78142 .68044 Mdot
.69107 .57431 Mdot
.27465 .45196 Mdot
.58649 .20129 Mdot
.69089 .78448 Mdot
.71666 .67275 Mdot
.38503 .49566 Mdot
.6319 .49917 Mdot
.37915 .18833 Mdot
.34755 .51867 Mdot
.61075 .74967 Mdot
.44515 .36857 Mdot
.26038 .6006 Mdot
.79742 .48076 Mdot
.196 .5376 Mdot
.7811 .68302 Mdot
.26506 .32629 Mdot
.22938 .53013 Mdot
.42376 .71718 Mdot
.42781 .78773 Mdot
.62088 .22191 Mdot
.52319 .55111 Mdot
.49722 .58523 Mdot
.35551 .68401 Mdot
.72025 .59802 Mdot
.65397 .70637 Mdot
.28425 .66552 Mdot
.53495 .62706 Mdot
.22267 .63131 Mdot
.36466 .433 Mdot
.50854 .42946 Mdot
.69442 .20963 Mdot
.64381 .55277 Mdot
.34636 .35959 Mdot
.66847 .77949 Mdot
.48774 .77176 Mdot
.76203 .66966 Mdot
.50333 .31901 Mdot
.64374 .20413 Mdot
.84487 .51995 Mdot
.27765 .64457 Mdot
.76654 .31618 Mdot
.77947 .71184 Mdot
.60882 .18247 Mdot
.68225 .37479 Mdot
.44356 .30123 Mdot
.80145 .28285 Mdot
.33091 .50874 Mdot
.53426 .18419 Mdot
.69068 .61046 Mdot
.28632 .51144 Mdot
.58252 .42127 Mdot
.63199 .51179 Mdot
.46218 .53159 Mdot
.61283 .43346 Mdot
.63034 .55229 Mdot
.62184 .16754 Mdot
.56294 .17457 Mdot
.64092 .18449 Mdot
.63029 .80592 Mdot
.77454 .32437 Mdot
.47789 .61704 Mdot
.76457 .48373 Mdot
.55559 .68648 Mdot
.60095 .61633 Mdot
.56942 .71954 Mdot
.33531 .34872 Mdot
.23148 .59698 Mdot
.55244 .22815 Mdot
.56815 .39565 Mdot
.70913 .2837 Mdot
.55904 .11 Mdot
.6801 .50511 Mdot
.69048 .45812 Mdot
.35627 .29376 Mdot
.55896 .75869 Mdot
.62579 .2948 Mdot
.21257 .58038 Mdot
.77578 .67499 Mdot
.56937 .68156 Mdot
.61493 .75718 Mdot
.29955 .68804 Mdot
.38821 .7645 Mdot
.41528 .57449 Mdot
.82894 .50152 Mdot
.47641 .64561 Mdot
.20732 .52296 Mdot
.52508 .47783 Mdot
.17977 .53217 Mdot
.31911 .6427 Mdot
.29509 .40537 Mdot
.57829 .77913 Mdot
.33975 .41469 Mdot
.60567 .73587 Mdot
.46245 .47083 Mdot
.61297 .69638 Mdot
.44581 .60378 Mdot
.6096 .73428 Mdot
.38571 .76258 Mdot
.71438 .25944 Mdot
.77081 .73471 Mdot
.49505 .15517 Mdot
.55546 .84321 Mdot
.57015 .30948 Mdot
.55604 .5252 Mdot
.75179 .71396 Mdot
.68307 .21763 Mdot
.84642 .53742 Mdot
.27709 .32652 Mdot
.29089 .56174 Mdot
.39406 .31995 Mdot
.49711 .15864 Mdot
.34096 .65983 Mdot
.79711 .61423 Mdot
.36752 .21919 Mdot
.46276 .36199 Mdot
.22101 .36414 Mdot
.53356 .17702 Mdot
.78711 .45104 Mdot
.68948 .4016 Mdot
.64245 .53615 Mdot
.74802 .40174 Mdot
.64918 .3844 Mdot
.26769 .38279 Mdot
.53302 .75574 Mdot
.34361 .51543 Mdot
.46865 .65639 Mdot
.50644 .61933 Mdot
.62552 .62262 Mdot
.4055 .61405 Mdot
.65266 .38733 Mdot
.6524 .26569 Mdot
.49679 .36077 Mdot
.7969 .33108 Mdot
.32227 .36182 Mdot
.50471 .56409 Mdot
.50865 .77174 Mdot
.23848 .53722 Mdot
.31428 .26972 Mdot
.45815 .34791 Mdot
.8219 .43252 Mdot
.4048 .40924 Mdot
.50254 .75898 Mdot
.74005 .38888 Mdot
.67147 .72986 Mdot
.55953 .50876 Mdot
.55319 .28203 Mdot
.74694 .59148 Mdot
.50988 .4405 Mdot
.57764 .34317 Mdot
.65704 .32656 Mdot
.6232 .84989 Mdot
.33799 .30024 Mdot
.28483 .40193 Mdot
.82558 .44504 Mdot
.4066 .33517 Mdot
.59947 .34193 Mdot
.59096 .72143 Mdot
.65541 .76095 Mdot
.75377 .55712 Mdot
.37941 .58502 Mdot
.3219 .44872 Mdot
.30293 .66503 Mdot
.79931 .39675 Mdot
.77585 .36446 Mdot
.15773 .51082 Mdot
.56997 .39064 Mdot
.68994 .71471 Mdot
.62013 .76505 Mdot
.63551 .34525 Mdot
.56708 .41073 Mdot
.55515 .2137 Mdot
.75476 .28619 Mdot
.45979 .2787 Mdot
.53727 .83888 Mdot
.42821 .74038 Mdot
.29842 .53856 Mdot
.24046 .55391 Mdot
.53216 .80643 Mdot
.82648 .455 Mdot
.70862 .35186 Mdot
.77974 .41653 Mdot
.52314 .52539 Mdot
.6349 .44305 Mdot
.47645 .15515 Mdot
.43927 .45661 Mdot
.77216 .4644 Mdot
.51689 .34963 Mdot
.55979 .54228 Mdot
.57589 .1457 Mdot
.69067 .75044 Mdot
.31881 .25701 Mdot
.44445 .29468 Mdot
.60068 .54143 Mdot
.52831 .58562 Mdot
.61686 .48065 Mdot
.52923 .27735 Mdot
.5843 .19045 Mdot
.53586 .80668 Mdot
.53685 .3474 Mdot
.7278 .38717 Mdot
.34649 .36086 Mdot
.81876 .52995 Mdot
.73658 .71014 Mdot
.48859 .45322 Mdot
.32952 .35028 Mdot
.43607 .67121 Mdot
.57089 .83397 Mdot
.44598 .57257 Mdot
.48784 .62768 Mdot
.4827 .20934 Mdot
.51563 .29821 Mdot
.23484 .55816 Mdot
.62203 .58785 Mdot
.24637 .36781 Mdot
.81289 .57149 Mdot
.15606 .58578 Mdot
.19131 .46014 Mdot
.59625 .14843 Mdot
.77381 .55759 Mdot
.50714 .30118 Mdot
.76418 .37409 Mdot
.14993 .59256 Mdot
.4315 .59762 Mdot
.73854 .3107 Mdot
.43182 .69658 Mdot
.81383 .42178 Mdot
.4635 .3316 Mdot
.44215 .24773 Mdot
.58068 .1991 Mdot
.76432 .30198 Mdot
.72573 .67237 Mdot
.82222 .48608 Mdot
.51858 .48169 Mdot
.72902 .25601 Mdot
.48501 .20138 Mdot
.45545 .53943 Mdot
.34504 .48592 Mdot
.31101 .28439 Mdot
.71015 .31011 Mdot
.6284 .27937 Mdot
.61018 .75346 Mdot
.43766 .55834 Mdot
.65013 .67687 Mdot
.76416 .39985 Mdot
.50211 .69545 Mdot
.52353 .3082 Mdot
.50608 .7721 Mdot
.81733 .58021 Mdot
.42402 .58994 Mdot
.24596 .5513 Mdot
.33937 .37707 Mdot
.47971 .82577 Mdot
.53107 .27262 Mdot
.33126 .30532 Mdot
.75822 .65343 Mdot
.34529 .63867 Mdot
.54791 .7863 Mdot
.72561 .80549 Mdot
.5489 .81374 Mdot
.62054 .2464 Mdot
.69007 .24844 Mdot
.75698 .68962 Mdot
.6408 .25798 Mdot
.17794 .46518 Mdot
.63415 .47382 Mdot
.56718 .73264 Mdot
.5705 .59227 Mdot
.6845 .20623 Mdot
.50251 .71734 Mdot
.69421 .2463 Mdot
.72445 .74737 Mdot
.7493 .39599 Mdot
.62553 .6236 Mdot
.35407 .60026 Mdot
.3929 .44512 Mdot
.50964 .69341 Mdot
.78719 .42174 Mdot
.63807 .48166 Mdot
.31916 .40024 Mdot
.37386 .45601 Mdot
.38544 .60618 Mdot
.57364 .3262 Mdot
.31427 .34834 Mdot
.52981 .2917 Mdot
.33892 .69512 Mdot
.49298 .48298 Mdot
.57515 .75678 Mdot
.7086 .38291 Mdot
.78991 .46409 Mdot
.19354 .53028 Mdot
.43231 .40586 Mdot
.36033 .56746 Mdot
.79701 .52619 Mdot
.57016 .81223 Mdot
.53378 .31791 Mdot
.6334 .20443 Mdot
.2993 .28751 Mdot
.55862 .69703 Mdot
.64369 .70063 Mdot
.17975 .51035 Mdot
.34464 .7746 Mdot
.68367 .26745 Mdot
.6777 .33162 Mdot
.45883 .7944 Mdot
.50559 .62448 Mdot
.80709 .36771 Mdot
.57235 .78886 Mdot
.66887 .69285 Mdot
.42653 .44878 Mdot
.749 .52254 Mdot
.74421 .37605 Mdot
.46213 .68675 Mdot
.51027 .47467 Mdot
.31082 .21886 Mdot
.59628 .43103 Mdot
.55293 .13338 Mdot
.43392 .35902 Mdot
.25202 .30744 Mdot
.37097 .75906 Mdot
.46223 .46362 Mdot
.51717 .47072 Mdot
.55749 .27514 Mdot
.50271 .2204 Mdot
.59572 .81749 Mdot
.179 .56657 Mdot
.32785 .55676 Mdot
.4943 .80589 Mdot
.44039 .81791 Mdot
.80608 .48882 Mdot
.63947 .58362 Mdot
.53979 .82028 Mdot
.44129 .45234 Mdot
.23037 .59235 Mdot
.73678 .72475 Mdot
.589 .28645 Mdot
.51194 .58158 Mdot
.55354 .75798 Mdot
.73722 .31229 Mdot
.84142 .50857 Mdot
.19476 .40058 Mdot
.59054 .3006 Mdot
.43313 .29861 Mdot
.46576 .59021 Mdot
.80144 .41972 Mdot
.46442 .77867 Mdot
.46712 .26685 Mdot
.56997 .77055 Mdot
.4585 .13344 Mdot
.6034 .19847 Mdot
.58338 .19048 Mdot
.49846 .7838 Mdot
.57471 .3562 Mdot
.52886 .19725 Mdot
.65287 .69723 Mdot
.58777 .2796 Mdot
.61202 .79757 Mdot
.59971 .75061 Mdot
.14466 .49381 Mdot
.69432 .66162 Mdot
.31953 .604 Mdot
.73138 .35555 Mdot
.69964 .61251 Mdot
.44607 .29866 Mdot
.55172 .72539 Mdot
.51999 .35107 Mdot
.38929 .33755 Mdot
.52732 .30417 Mdot
.49309 .26722 Mdot
.67471 .69046 Mdot
.76229 .54133 Mdot
.54227 .3342 Mdot
.79132 .56688 Mdot
.60912 .44276 Mdot
.24227 .58162 Mdot
.24657 .53153 Mdot
.52904 .38978 Mdot
.33218 .53052 Mdot
.61546 .67143 Mdot
.505 .45093 Mdot
.42935 .63079 Mdot
.46327 .16982 Mdot
.35717 .70688 Mdot
.57611 .36087 Mdot
.29429 .26165 Mdot
.63425 .34176 Mdot
.6462 .17877 Mdot
.21104 .56799 Mdot
.73906 .39206 Mdot
.28801 .6429 Mdot
.28075 .68977 Mdot
.19339 .33769 Mdot
.68052 .30907 Mdot
.4174 .43773 Mdot
.67098 .36621 Mdot
.5887 .40542 Mdot
.32738 .40403 Mdot
.37228 .46159 Mdot
.68232 .42015 Mdot
.36661 .3789 Mdot
.55508 .69009 Mdot
.63521 .32629 Mdot
.31602 .58843 Mdot
.66272 .65787 Mdot
.76646 .29891 Mdot
.3516 .56328 Mdot
.3782 .17849 Mdot
.53183 .61022 Mdot
.74249 .62826 Mdot
.77434 .69631 Mdot
.20679 .37901 Mdot
.23654 .49569 Mdot
.36673 .79166 Mdot
.56906 .63219 Mdot
.55104 .32695 Mdot
.60683 .36119 Mdot
.6518 .71747 Mdot
.38987 .69011 Mdot
.47207 .75118 Mdot
.39724 .36511 Mdot
.20942 .52541 Mdot
.30867 .35464 Mdot
.59142 .33568 Mdot
.60723 .28858 Mdot
.69354 .69244 Mdot
.4555 .2403 Mdot
.44366 .45011 Mdot
.80394 .48681 Mdot
.75728 .54275 Mdot
.64041 .32768 Mdot
.63805 .21602 Mdot
.60748 .76677 Mdot
.84698 .43428 Mdot
.57006 .48411 Mdot
.41808 .47467 Mdot
.43515 .23004 Mdot
.54333 .296 Mdot
.7013 .38859 Mdot
.77906 .67141 Mdot
.51132 .75415 Mdot
.41352 .24285 Mdot
.60549 .73198 Mdot
.66341 .59828 Mdot
.47814 .48891 Mdot
.27164 .3594 Mdot
.15437 .44334 Mdot
.65765 .42621 Mdot
.2115 .40634 Mdot
.67401 .33391 Mdot
.34466 .35789 Mdot
.60657 .43361 Mdot
.26588 .51952 Mdot
.75875 .51576 Mdot
.24425 .44973 Mdot
.82517 .39256 Mdot
.77764 .67564 Mdot
.46785 .36196 Mdot
.331 .43691 Mdot
.5534 .45251 Mdot
.53535 .5069 Mdot
.52152 .42145 Mdot
.53735 .5802 Mdot
.55789 .40615 Mdot
.22245 .35356 Mdot
.57342 .28093 Mdot
.64019 .52568 Mdot
.79956 .36492 Mdot
.84731 .44715 Mdot
.72352 .25486 Mdot
.44058 .79436 Mdot
.64601 .37123 Mdot
.61091 .17815 Mdot
.70277 .42699 Mdot
.82315 .57198 Mdot
.68064 .27089 Mdot
.64691 .8366 Mdot
.78555 .42473 Mdot
.5139 .35085 Mdot
.18842 .57164 Mdot
.50911 .23227 Mdot
.71123 .74468 Mdot
.45117 .54685 Mdot
.28912 .43306 Mdot
.70977 .75037 Mdot
.14784 .38279 Mdot
.68328 .35432 Mdot
.48595 .26944 Mdot
.51079 .63819 Mdot
.52476 .37374 Mdot
.39563 .49885 Mdot
.59692 .61499 Mdot
.34419 .45167 Mdot
.22979 .53659 Mdot
.58165 .75596 Mdot
.6449 .68468 Mdot
.39619 .50322 Mdot
.51436 .69255 Mdot
.62083 .71746 Mdot
.55628 .80042 Mdot
.79431 .45609 Mdot
.68761 .41382 Mdot
.51391 .56471 Mdot
.5857 .4345 Mdot
.40614 .70159 Mdot
.25497 .45959 Mdot
.56866 .61256 Mdot
.2442 .45737 Mdot
.47966 .23058 Mdot
.60338 .15525 Mdot
.27196 .48494 Mdot
.6747 .7553 Mdot
.61904 .42302 Mdot
.53783 .27932 Mdot
.79053 .58424 Mdot
.23954 .362 Mdot
.40602 .53329 Mdot
.68248 .60935 Mdot
.79179 .36857 Mdot
.36755 .25517 Mdot
.65402 .74645 Mdot
.43649 .19645 Mdot
.40031 .3168 Mdot
.6653 .40588 Mdot
.5061 .63886 Mdot
.27652 .31896 Mdot
.59632 .3273 Mdot
.51183 .33869 Mdot
.43192 .50205 Mdot
.35672 .25796 Mdot
.67017 .78023 Mdot
.68334 .7095 Mdot
.7229 .34109 Mdot
.77979 .36648 Mdot
.36176 .49154 Mdot
.61998 .75622 Mdot
.50678 .34586 Mdot
.4137 .5173 Mdot
.41459 .22675 Mdot
.79807 .34181 Mdot
.52474 .43484 Mdot
.4851 .71191 Mdot
.57669 .53306 Mdot
.71834 .45109 Mdot
.57103 .27516 Mdot
.38069 .74627 Mdot
.30597 .38806 Mdot
.59533 .40195 Mdot
.29369 .37534 Mdot
.39887 .59349 Mdot
.54949 .73403 Mdot
.66835 .35984 Mdot
.66933 .5353 Mdot
.34653 .69754 Mdot
.3503 .40173 Mdot
.60349 .51472 Mdot
.47705 .72219 Mdot
.43743 .78429 Mdot
.67127 .39662 Mdot
.67301 .29522 Mdot
.80248 .49646 Mdot
.64382 .76895 Mdot
.55009 .3054 Mdot
.6779 .26364 Mdot
.51269 .22043 Mdot
.772 .50273 Mdot
.24082 .40694 Mdot
.53863 .55523 Mdot
.26735 .51951 Mdot
.60101 .33911 Mdot
.80288 .43848 Mdot
.76738 .56724 Mdot
.47027 .69161 Mdot
.47419 .43731 Mdot
.78206 .60369 Mdot
.46537 .4219 Mdot
.76385 .70394 Mdot
.51241 .23225 Mdot
.53122 .75481 Mdot
.44914 .37092 Mdot
.41791 .73096 Mdot
.18105 .49232 Mdot
.83916 .44798 Mdot
.19124 .5407 Mdot
.47593 .5379 Mdot
.21293 .39472 Mdot
.59064 .22096 Mdot
.71995 .74665 Mdot
.54863 .74912 Mdot
.51974 .41933 Mdot
.65951 .65643 Mdot
.45817 .37811 Mdot
.36761 .4211 Mdot
.26665 .54003 Mdot
.6881 .42787 Mdot
.30794 .47322 Mdot
.23258 .47813 Mdot
.58117 .50139 Mdot
.44353 .21083 Mdot
.78431 .3661 Mdot
.68167 .66367 Mdot
.44926 .4659 Mdot
.2552 .61379 Mdot
.53424 .7341 Mdot
.47511 .87646 Mdot
.57349 .1437 Mdot
.5782 .53139 Mdot
.4461 .59714 Mdot
.48356 .74417 Mdot
.34076 .58104 Mdot
.67175 .44704 Mdot
.80726 .47773 Mdot
.41963 .36486 Mdot
.28505 .55771 Mdot
.3511 .2624 Mdot
.56402 .26886 Mdot
.46272 .66674 Mdot
.37755 .28226 Mdot
.6232 .16245 Mdot
.57488 .81586 Mdot
.55587 .29011 Mdot
.53361 .87463 Mdot
.26244 .35493 Mdot
.6616 .32851 Mdot
.75023 .65282 Mdot
.71591 .25928 Mdot
.49314 .77475 Mdot
.26589 .59663 Mdot
.64357 .24612 Mdot
.52306 .75263 Mdot
.62813 .72767 Mdot
.33887 .37662 Mdot
.29747 .37859 Mdot
.46163 .50301 Mdot
.28226 .69048 Mdot
.48808 .17921 Mdot
.71866 .36373 Mdot
.76149 .33891 Mdot
.22054 .52283 Mdot
.14301 .5097 Mdot
.84335 .43734 Mdot
.54947 .71288 Mdot
.39086 .49581 Mdot
.74413 .66429 Mdot
.44353 .74332 Mdot
.68528 .59726 Mdot
.21452 .55233 Mdot
.74574 .56409 Mdot
.26057 .66891 Mdot
.21403 .44435 Mdot
.60699 .73505 Mdot
.69772 .60314 Mdot
.52603 .44066 Mdot
.79715 .50316 Mdot
.32338 .38749 Mdot
.51806 .77816 Mdot
.28714 .57732 Mdot
.4451 .72054 Mdot
.8016 .52066 Mdot
.77834 .62305 Mdot
.5273 .41886 Mdot
.16095 .36599 Mdot
.7084 .27288 Mdot
.23528 .38094 Mdot
.54582 .53942 Mdot
.82136 .37858 Mdot
.51844 .39143 Mdot
.66993 .25578 Mdot
.65487 .77643 Mdot
.25484 .51061 Mdot
.44639 .22844 Mdot
.53603 .56259 Mdot
.67623 .28743 Mdot
.77261 .45886 Mdot
.70119 .60758 Mdot
.22871 .54571 Mdot
.50911 .76948 Mdot
.38155 .50374 Mdot
.4537 .69071 Mdot
.52776 .50655 Mdot
.60804 .33344 Mdot
.65484 .1929 Mdot
.47937 .54283 Mdot
.62745 .66323 Mdot
.58624 .46745 Mdot
.18413 .55534 Mdot
.45964 .84859 Mdot
.55115 .49222 Mdot
.3746 .25402 Mdot
.60396 .75375 Mdot
.59185 .69858 Mdot
.68309 .32772 Mdot
.15908 .68595 Mdot
.78872 .68347 Mdot
.59183 .41459 Mdot
.64798 .48834 Mdot
.5047 .7918 Mdot
.73358 .27007 Mdot
.30089 .68614 Mdot
.24291 .52751 Mdot
.18104 .61824 Mdot
.44611 .75611 Mdot
.62732 .60737 Mdot
.65874 .78925 Mdot
.83955 .45869 Mdot
.21389 .52131 Mdot
.80974 .37806 Mdot
.64597 .61246 Mdot
.52417 .57746 Mdot
.31003 .81462 Mdot
.81097 .43387 Mdot
.65447 .58688 Mdot
.17833 .54466 Mdot
.60831 .32034 Mdot
.56901 .60337 Mdot
.35551 .3477 Mdot
.56982 .786 Mdot
.62312 .72147 Mdot
.76318 .3005 Mdot
.58391 .33932 Mdot
.24014 .46659 Mdot
.40076 .35835 Mdot
.51385 .47341 Mdot
.51861 .57432 Mdot
.42693 .31538 Mdot
.57248 .70434 Mdot
.52777 .39725 Mdot
.46134 .31258 Mdot
.49901 .81307 Mdot
.69767 .79292 Mdot
.78009 .53742 Mdot
.47451 .34163 Mdot
.66406 .55949 Mdot
.69677 .65525 Mdot
.51264 .69395 Mdot
.51659 .67024 Mdot
.69697 .76754 Mdot
.85489 .629 Mdot
.29422 .43941 Mdot
.59817 .48534 Mdot
.66723 .35456 Mdot
.69488 .40839 Mdot
.77941 .43764 Mdot
.4125 .28694 Mdot
.36665 .47529 Mdot
.59091 .64256 Mdot
.52927 .50448 Mdot
.40046 .36684 Mdot
.51557 .1377 Mdot
.61811 .60678 Mdot
.69838 .34707 Mdot
.82584 .55713 Mdot
.24079 .57855 Mdot
.7332 .63483 Mdot
.5848 .63131 Mdot
.51562 .19935 Mdot
.514 .38853 Mdot
.54219 .37541 Mdot
.24278 .54634 Mdot
.75571 .31058 Mdot
.76513 .57337 Mdot
.71597 .33731 Mdot
.6106 .57914 Mdot
.39136 .72664 Mdot
.4768 .25799 Mdot
.64552 .24103 Mdot
.50172 .56609 Mdot
.83627 .54639 Mdot
.25428 .51836 Mdot
.31463 .47468 Mdot
.6081 .68766 Mdot
.68066 .22599 Mdot
.20388 .4407 Mdot
.76509 .41882 Mdot
.29242 .27952 Mdot
.31497 .30412 Mdot
.50434 .69804 Mdot
.35702 .60192 Mdot
.63754 .52028 Mdot
.61194 .32134 Mdot
.65153 .17097 Mdot
.63832 .23493 Mdot
.48882 .3552 Mdot
.298 .41076 Mdot
.74573 .45005 Mdot
.53269 .45481 Mdot
.59654 .86697 Mdot
.32912 .67672 Mdot
.61584 .1578 Mdot
.65606 .71329 Mdot
.60802 .30478 Mdot
.51208 .31453 Mdot
.53832 .63473 Mdot
.36261 .55634 Mdot
.74162 .28295 Mdot
.53892 .49354 Mdot
.22909 .42795 Mdot
.62486 .60773 Mdot
.33346 .24683 Mdot
.48599 .38839 Mdot
.3344 .42865 Mdot
.34043 .42141 Mdot
.17936 .46701 Mdot
.80448 .57996 Mdot
.50628 .3915 Mdot
.57408 .86022 Mdot
.77236 .38268 Mdot
.82311 .43388 Mdot
.37781 .59174 Mdot
.19038 .38714 Mdot
.64079 .27702 Mdot
.53904 .33205 Mdot
.49148 .3674 Mdot
.44783 .63021 Mdot
.29779 .29304 Mdot
.5909 .70137 Mdot
.49323 .24784 Mdot
.45981 .37295 Mdot
.90486 .59404 Mdot
.56557 .71353 Mdot
.53256 .64534 Mdot
.24933 .3728 Mdot
.8129 .40336 Mdot
.34456 .73362 Mdot
.67041 .794 Mdot
.43686 .59702 Mdot
.52167 .56882 Mdot
.75877 .56051 Mdot
.67314 .68039 Mdot
.32069 .27763 Mdot
.23837 .27584 Mdot
.58611 .80765 Mdot
.30902 .44693 Mdot
.49436 .47537 Mdot
.63232 .34431 Mdot
.58218 .42002 Mdot
.2831 .65796 Mdot
.62508 .82511 Mdot
.51804 .36748 Mdot
.80291 .42188 Mdot
.18219 .3608 Mdot
.65752 .72693 Mdot
.73995 .27367 Mdot
.62453 .26106 Mdot
.57962 .431 Mdot
.51938 .6922 Mdot
.40754 .65245 Mdot
.34815 .44194 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0;;ooooo0_l0002E
ooooo`007?ooool00ol0003oooooooooo`2booooo`;o0000UOooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0TOooool2o`0001gooooo0_l0002Gooooo`007?ooool00ol0003ooooooooo
o`2Aooooo`;o00004Oooool2o`0000[ooooo0_l0002Gooooo`007?ooool00ol0003oooooooooo`2T
ooooo`;o00005Oooool2o`0008cooooo000Looooo`03o`000?oooooooooo07[ooooo0_l0000Roooo
o`;o00005_ooool3o`0000;ooooo0_l0002<ooooo`007?ooool00ol0003oooooooooo`1jooooo`;o
00008_ooool2o`0001Kooooo1?l0002?ooooo`007?ooool00ol0003oooooooooo`2;ooooo`;o0000
:_ooool3o`0000Cooooo0_l00029ooooo`007?ooool2o`0008Sooooo0_l00002ooooo`;o0000<Ooo
ool2o`0008Wooooo000Looooo`03o`000?oooooooooo08Oooooo0_l0000>ooooo`;o000000Cooooo
o`000?l0003ooooo0_l0000Qooooo`;o00002Oooool2o`0007cooooo000Looooo`03o`000?oooooo
oooo09Oooooo0_l000001?oooooo0000o`000?ooool3o`0000?ooooo0_l0000Kooooo`;o00000_oo
ool2o`0000Gooooo0_l0001looooo`007?ooool00ol0003oooooooooo`2Eooooo`;o00001oooool2
o`000003ooooool0003o000000;o00000_ooool2o`0001_ooooo0_l000000ooooooo0000o`000020
ooooo`007?ooool00ol0003oooooooooo`2Eooooo`;o00002_ooool2o`0000Cooooo0_l0000Noooo
o`;o00004_ooool2o`0006cooooo000Looooo`03o`000?oooooooooo0:oooooo0_l0000Eooooo`;o
00004oooool2o`0006cooooo000Looooo`03o`000?oooooooooo097ooooo1?l0000Jooooo`;o0000
5Oooool2o`0000Sooooo0_l0001gooooo`007?ooool00ol0003oooooooooo`2Aooooo`Co00007_oo
ool2o`0001Wooooo1?l0001gooooo`007?ooool00ol0003oooooooooo`2Zooooo`;o00001oooool2
o`0000kooooo0_l00009ooooo`;o00000oooool2o`0007Cooooo000Looooo`03o`000?oooooooooo
07Oooooo0_l0000Rooooo`;o00002_ooool5o`0001Oooooo0_l00009ooooo`;o00000oooool2o`00
07Cooooo000Looooo`03o`000?oooooooooo07Oooooo0_l0000Nooooo`?o000000Coooooo`000?l0
003o00002Oooool5o`0000?ooooo1?l0000?ooooo`;o00002?ooool4o`0007Wooooo000Looooo`03
o`000?oooooooooo09Oooooo0ol00002ooooo`;o00000oooool2o`0000Oooooo0_l00003ooooo`Co
00003oooool2o`0000Sooooo0_l0001kooooo`007?ooool00ol0003oooooooooo`1gooooo`;o0000
5?ooool2o`0001;ooooo0_l0000Gooooo`;o0000SOooool00006ooooooo^k^ko<S8bo`000?lb<S;o
k^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo07Oooooo0_l0000Dooooo`;o
00003Oooool4o`0000Sooooo0_l0000@ooooo`;o00001Oooool2o`0000kooooo0_l0001fooooo`00
00KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400Kooooo00?o0000ooooooooool0R_ooool2o`0000oooooo1Ol00008ooooo`Co00002Oooool2
o`0000[ooooo0_l0000>ooooo`;o0000M_ooool00003ooooool@413ooooo00;ooooo00?o410@oooo
ooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo07_ooooo0_l0000=oooo
o`;o00003oooool2o`0000Oooooo2?l00009ooooo`?o000000?oooooo`000?l000001Oooool2o`00
08Oooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^
k^h01_ooool3o`0007Sooooo0_l000000ooooooo0000o`00000Fooooo`;o00001Oooool2o`0000So
oooo2?l00009ooooo`?o000000?oooooo`000?l000000_l00003ooooo`;o0000Qoooool00003oooo
ool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`00
0?oooooooooo073ooooo0_l00003ooooo`;o000000?oooooo`000?l000003Oooool3o`0000Wooooo
0ol00004ooooo`;o00003_ooool2o`0000Wooooo0_l00003ooooo`?o00003Oooool2o`000004oooo
ool0003o0000ooooo`;o0000Moooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool0
3Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo073ooooo0_l00003ooooo`;o0000
1?ooool2o`0000[ooooo0ol00002ooooo`;o00001Oooool3o`0000Cooooo0_l00007ooooo`;o0000
2_ooool2o`0000?ooooo0_l0000Dooooo`;o000000Coooooo`000?l0003ooooo0_l00009ooooo`;o
0000K?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So
410@00Kooooo00?o0000ooooooooool0M_ooool2o`0000?ooooo0_l0000>ooooo`?o00001Oooool2
o`0000Cooooo0_l00008ooooo`;o00002_ooool2o`0000?ooooo0_l0000Gooooo`;o00003?ooool2
o`000003ooooool0003o000006Wooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo07Kooooo0_l00003ooooo`;o0000
1Oooool3o`000003ooooool0003o000000?ooooo0ol00004ooooo`?o00001?ooool4o`0001Cooooo
0_l0000@ooooo`;o00002_ooool2o`0000gooooo0_l0001Yooooo`007?ooool00ol0003ooooooooo
o`22ooooo`Ko000000?oooooo`000?l000001oooool6o`0000?ooooo0_l00003ooooo`;o00001Ooo
ool2o`0000Sooooo0_l00002ooooo`;o00001?ooool2o`0000Kooooo0_l00006ooooo`;o00000_oo
ool2o`000003ooooool0003o000000Kooooo0_l0001]ooooo`007?ooool00ol0003oooooooooo`1Q
ooooo`;o00001Oooool2o`0000Sooooo1?l0000?ooooo`?o000000?oooooo`000?l000001oooool6
o`0000Sooooo0_l000000ooooooo0000o`000002ooooo`;o00003?ooool2o`0000?ooooo1?l0000=
ooooo`;o00001Oooool2o`0000Kooooo0_l0001]ooooo`007?ooool00ol0003oooooooooo`1Qoooo
o`;o00001Oooool2o`0000Sooooo1?l0000<ooooo`;o00003_ooool2o`0000cooooo1Ol0000Eoooo
o`Co00002?ooool2o`00087ooooo000Looooo`03o`000?oooooooooo077ooooo0_l00009ooooo`;o
00001?ooool3o`0000Gooooo0_l0000:ooooo`;o00002Oooool2o`0000Gooooo0_l0000@ooooo`Co
00002?ooool2o`00017ooooo0_l0001^ooooo`007?ooool00ol0003oooooooooo`1aooooo`;o0000
0_ooool2o`0000Gooooo0_l00004ooooo`?o00001Oooool5o`0000Oooooo1?l0000<ooooo`Co0000
1_ooool2o`0000Sooooo1?l00002ooooo`;o00004?ooool2o`0000Gooooo1Ol0001[ooooo`007?oo
ool00ol0003oooooooooo`1Looooo`Co00005Oooool2o`0000_ooooo0_l00006ooooo`Go00002Ooo
ool2o`0000Cooooo0_l00002ooooo`?o000000?oooooo`000?l000002?ooool2o`0000[ooooo0_l0
0002ooooo`;o00004?ooool2o`0000Oooooo0ol0001[ooooo`007?ooool00ol0003oooooooooo`1L
ooooo`Co00004?ooool2o`0000;ooooo0_l0000Iooooo`;o00003Oooool2o`0000;ooooo0ol0000@
ooooo`;o00000_ooool2o`000004ooooool0003o0000o`0000gooooo0_l0001kooooo`007?ooool0
0ol0003oooooooooo`1`ooooo`;o000000Coooooo`000?l0003o00001_ooool2o`00017ooooo0_l0
000Tooooo`;o00000_ooool2o`0000;ooooo1?l0000;ooooo`;o0000Noooool001cooooo00?o0000
ooooooooool0FOooool2o`00017ooooo1?l00003ooooo`;o00001Oooool4o`0000Cooooo0ol0000;
ooooo`;o00000_ooool2o`0002Wooooo0_l0000=ooooo`;o00001Oooool2o`0007;ooooo000Loooo
o`03o`000?oooooooooo05Wooooo0_l0000;ooooo`;o00001?ooool4o`0000Kooooo1ol00003oooo
o`Go00001_ooool2o`0000?ooooo0_l00002ooooo`;o00006?ooool2o`0000gooooo0_l0000>oooo
o`?o00001Oooool2o`0007;ooooo000Looooo`03o`000?oooooooooo06Gooooo0ol000000ooooooo
0000o`000003ooooo`;o00001_ooool4o`0000?ooooo0_l000000ooooooo0000o`000008ooooo`Co
00001_ooool2o`0000Cooooo1?l000000ooooooo0000o`00000=ooooo`;o00003Oooool2o`0000Oo
oooo0_l00003ooooo`Co00003Oooool4o`0006Wooooo000Looooo`;o0000I_ooool2o`0000;ooooo
0_l00003ooooo`?o00000oooool2o`0000Oooooo0_l00002ooooo`;o00001oooool4o`0000cooooo
1?l000000ooooooo0000o`00000<ooooo`;o000000?oooooo`000?l000005?ooool2o`0000?ooooo
0_l0000?ooooo`Co000000?oooooo`000?l00000I_ooool001cooooo00?o0000ooooooooool0Gooo
ool2o`0000cooooo1?l00003ooooo`Ko000000Coooooo`000?l0003ooooo0_l000000ooooooo0000
o`00000Iooooo`;o00003oooool2o`000003ooooool0003o000000;ooooo0_l0000Kooooo`;o0000
0oooool2o`0000?ooooo1Ol000000ooooooo0000o`000004ooooo`;o0000H?ooool001cooooo00?o
0000ooooooooool0Goooool2o`0000?ooooo0_l00003ooooo`?o000000?oooooo`000?l000000ol0
0002ooooo`Ko000000Coooooo`000?l0003ooooo0_l0000Gooooo`;o00000oooool2o`0000gooooo
0_l00007ooooo`;o00002Oooool2o`0000_ooooo0_l00003ooooo`;o00000oooool2o`0000?ooooo
0ol00009ooooo`Co0000G_ooool001cooooo00?o0000ooooooooool0G?ooool2o`0000Kooooo0_l0
00000ooooooo0000o`000003o`0000Cooooo0_l0000;ooooo`;o00000_ooool2o`000003ooooool0
003o000000;o00003oooool5o`0000oooooo0_l0000Booooo`;o00001_ooool2o`0000?ooooo0_l0
00000ooooooo0000o`000005ooooo`;o00003?ooool3o`0000;ooooo0_l000000ooooooo0000o`00
001Kooooo`007?ooool00ol0003oooooooooo`1Looooo`;o00000oooool2o`0000;ooooo1?l00005
ooooo`;o00002oooool5o`000004ooooool0003o0000ooooo`Co00002_ooool2o`0000Gooooo0ol0
000[ooooo`;o00001_ooool2o`0000Oooooo1?l00006ooooo`Go00001Oooool2o`0005_ooooo000L
ooooo`03o`000?oooooooooo067ooooo0_l00002ooooo`Co00001Oooool2o`0000Gooooo0_l00004
ooooo`;o000000?oooooo`000?l000003Oooool2o`0000?ooooo1?l00003ooooo`;o000000?ooooo
o`000?l000003_ooool5o`0000gooooo0_l0000@ooooo`?o00001Oooool6o`0000Cooooo0_l0001U
ooooo`007?ooool00ol0003oooooooooo`1Rooooo`;o00000oooool4o`0000[ooooo0_l00006oooo
o`;o00002?ooool2o`0000Cooooo0_l00005ooooo`;o00000_ooool6o`0000kooooo1Ol00002oooo
o`Co00001oooool2o`0000gooooo0_l000001?oooooo0000o`000?l00006ooooo`Go00003?ooool4
o`0005_ooooo000Looooo`03o`000?oooooooooo05oooooo0_l000000ooooooo0000o`000005oooo
o`;o00000_ooool2o`0000cooooo1?l00008ooooo`;o00001?ooool2o`0000Gooooo0ol000000ooo
oooo0000o`000004o`0000_ooooo0_l000000ooooooo0000o`000005ooooo`Co00005_ooool2o`00
00;ooooo0_l00002ooooo`;o00000_ooool2o`0000Oooooo0_l00006ooooo`Go0000F_ooool001co
oooo00?o0000ooooooooool0B_ooool2o`0001?ooooo0_l0000<ooooo`;o00003?ooool2o`0000Oo
oooo0_l00007ooooo`;o00001Oooool3o`0000Gooooo0_l000000ooooooo0000o`000008ooooo`;o
00001_ooool2o`0000?ooooo0_l0000Dooooo`;o00000oooool2o`0000;ooooo0_l0000;ooooo`;o
00002Oooool2o`0005[ooooo000Looooo`03o`000?oooooooooo04[ooooo0ol0000>ooooo`;o0000
0oooool2o`0000;ooooo0_l00007ooooo`;o00000oooool2o`00013ooooo0_l00007ooooo`;o0000
0oooool2o`0000_ooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l00000
1?ooool2o`0000?ooooo1?l000000ooooooo0000o`00000;ooooo`;o00000_ooool2o`0000kooooo
0_l0000Rooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0Boooool2o`0000kooooo1?l0
00000ooooooo0000o`000002ooooo`;o00001oooool2o`0000?ooooo0_l00003ooooo`;o00003ooo
ool2o`0000?ooooo0_l00002ooooo`?o00002oooool2o`000003ooooool0003o000000Cooooo0_l0
00000ooooooo0000o`000003ooooo`;o00001?ooool4o`000003ooooool0003o000000_ooooo0_l0
000Booooo`;o00003oooool2o`00017ooooo0ol00016ooooo`007?ooool00ol0003oooooooooo`1M
ooooo`;o00000_ooool2o`0000[ooooo0_l00002ooooo`;o00001?ooool5o`0000cooooo0_l00000
0ooooooo0000o`000004ooooo`;o00001?ooool2o`000003ooooool0003o000000?ooooo0_l00004
ooooo`;o00002Oooool2o`0000Cooooo1?l0000Nooooo`;o00000_ooool2o`0000Gooooo0_l00004
ooooo`;o00000_ooool2o`0000;ooooo0_l0000>ooooo`;o0000A_ooool001cooooo00?o0000oooo
ooooool0G_ooool2o`000003ooooool0003o000000[ooooo0_l000001?oooooo0000o`000?l00005
ooooo`Co00001_ooool2o`0000Oooooo1_l00006ooooo`;o000000?oooooo`000?l000001oooool6
o`000003ooooool0003o000000cooooo0_l00002ooooo`;o00000oooool2o`0000cooooo0_l00007
ooooo`;o00002Oooool2o`0000Cooooo0_l00006ooooo`;o00003oooool2o`0004Gooooo000Loooo
o`03o`000?oooooooooo05kooooo0_l0000;ooooo`;o00000oooool2o`0000Oooooo0_l00006oooo
o`Go00000oooool2o`0000;ooooo1?l0000Booooo`;o00000_ooool5o`0000Gooooo0_l00009oooo
o`;o00000oooool2o`0000cooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`00
0?l000009Oooool2o`0004Gooooo000Looooo`03o`000?oooooooooo05gooooo0_l0000<ooooo`;o
00000oooool2o`0000?ooooo0_l00002ooooo`;o00001_ooool2o`000003ooooool0003o000000?o
oooo0_l00002ooooo`;o00001oooool2o`0000;ooooo0_l0000<ooooo`;o00001oooool2o`0000Wo
oooo0_l00009ooooo`Co00001oooool2o`0000?ooooo0ol000000ooooooo0000o`00001/ooooo`00
7?ooool00ol0003oooooooooo`1Hooooo`?o00000_ooool2o`0000cooooo0_l00003ooooo`;o0000
0oooool2o`0000kooooo1_l00002ooooo`;o00001oooool2o`0000;ooooo0_l00008ooooo`;o0000
0_ooool2o`0000?ooooo0_l00002ooooo`;o00002Oooool2o`0000Oooooo1_l00008ooooo`;o0000
0_ooool3o`0006oooooo000Looooo`;o0000EOooool2o`0000;ooooo0ol0000?ooooo`;o00001?oo
ool4o`0000Wooooo0_l00005ooooo`Oo000000Coooooo`000?l0003o00001Oooool4o`0000;ooooo
0_l00005ooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o00000_ooool2o`0000Wo
oooo0ol00006ooooo`?o00002oooool2o`0001cooooo0_l000001?oooooo0000o`000?l0001Boooo
o`007?ooool00ol0003oooooooooo`1Dooooo`;o000000?oooooo`000?l000000_l00008ooooo`;o
00001Oooool2o`0000Kooooo0_l00009ooooo`;o00000oooool=o`0000;ooooo0_l000000ooooooo
0000o`000004ooooo`;o00001Oooool2o`0000Cooooo0ol0000Booooo`?o00000oooool2o`0001Ko
oooo0_l0000Eooooo`;o000000Coooooo`000?l0003o0000D_ooool001cooooo00?o0000oooooooo
ool0C_ooool2o`0000Oooooo1?l00008ooooo`;o00000oooool2o`0000Cooooo0_l0000Aooooo`go
000000?oooooo`000?l000000_l0000Eooooo`;o00001Oooool2o`0000Wooooo0_l00006ooooo`;o
00005_ooool2o`0000[ooooo0_l00006ooooo`;o00001?ooool2o`0005?ooooo000Looooo`03o`00
0?oooooooooo04kooooo0_l000000ooooooo0000o`000002ooooo`;o00004?ooool3o`0000;ooooo
1?l0000Aooooo`go000000?oooooo`000?l000005Oooool2o`0000Oooooo0_l00004ooooo`;o0000
00?oooooo`000?l000000_l0000Mooooo`;o00002?ooool2o`000003ooooool0003o000000Cooooo
1?l00002ooooo`;o0000EOooool001cooooo00?o0000ooooooooool0DOooool2o`0000;ooooo1?l0
000>ooooo`;o00000oooool2o`00017ooooo4Ol000001?oooooo0000o`000?l0000Aooooo`?o0000
1oooool2o`0000Cooooo0_l000000ooooooo0000o`00000Cooooo`;o00000oooool2o`0000Gooooo
0_l00008ooooo`;o00001oooool2o`0000Cooooo0_l0001Eooooo`007?ooool00ol0003ooooooooo
o`1Gooooo`;o00009Oooool3o`000003ooooool0003o0000013o00003oooool4o`0000Sooooo0_l0
000<ooooo`;o00003_ooool2o`0000?ooooo0_l00005ooooo`;o00002_ooool2o`0000Gooooo0_l0
0003ooooo`;o00000_ooool2o`0005;ooooo000Looooo`03o`000?oooooooooo05Kooooo1?l0000G
ooooo`;o00002OoooolGo`000003ooooool0003o000000Wooooo0ol000000ooooooo0000o`000005
ooooo`;o00004Oooool2o`0000Oooooo0_l0000Mooooo`;o00002_ooool2o`0000;ooooo0_l0001B
ooooo`007?ooool00ol0003oooooooooo`1Booooo`;o00000_ooool4o`0001Oooooo0_l00009oooo
oaOo000000?oooooo`000?l000002Oooool3o`0000Sooooo0_l0000?ooooo`;o00001?ooool4o`00
0003ooooool0003o000000cooooo0_l0001cooooo`007?ooool00ol0003oooooooooo`19ooooo`;o
00000_ooool2o`0000?ooooo0_l00009ooooo`;o00007OoooolHo`0001;ooooo2?l00009ooooo`;o
00000_ooool2o`0000Cooooo1?l00006ooooo`;o00001oooool2o`0001?ooooo0_l0000:ooooo`;o
000000?oooooo`000?l00000Coooool001cooooo00?o0000ooooooooool0BOooool2o`000004oooo
ool0003o0000o`0000?ooooo0_l00002ooooo`;o00001Oooool2o`0001kooooo5ol00003ooooo`;o
00003Oooool8o`000003ooooool0003o000000;o00000oooool3o`0000Gooooo2?l00002ooooo`;o
000000?oooooo`000?l000000_l00003ooooo`?o00001Oooool2o`0000gooooo1?l00008ooooo`;o
000000?oooooo`000?l000001?ooool2o`0004Wooooo000Looooo`03o`000?oooooooooo04cooooo
0_l00002ooooo`Co000000Coooooo`000?l0003o00001Oooool2o`0000Kooooo0_l0000Doooooa[o
00000_ooool2o`0000kooooo0_l00002ooooo`;o00000_ooool4o`0000?ooooo0_l00005ooooo`Co
00000_ooool>o`000003ooooool0003o000000?o000000?oooooo`000?l000000_l0000?ooooo`;o
00000oooool2o`0000cooooo0ol00018ooooo`007?ooool00ol0003oooooooooo`0nooooo`;o0000
4?ooool4o`000003ooooool0003o000000Kooooo0_l00006ooooo`;o00004_oooolLo`0001;ooooo
0_l00002ooooo`?o00003oooool2o`000003ooooool0003o000000?o000000Coooooo`000?l0003o
oooo2ol000000ooooooo0000o`000003o`0000Wooooo0_l0000;ooooo`;o00003Oooool2o`0004So
oooo000Looooo`03o`000?oooooooooo03_ooooo0_l000000ooooooo0000o`00000<ooooo`;o0000
1?ooool2o`0000Kooooo0_l000000ooooooo0000o`00000Joooooaco00004?ooool2o`0000Gooooo
0_l0000>ooooo`?o000000?oooooo`000?l000000ol00002ooooo`Go000000?oooooo`000?l00000
1Ol00003ooooo`;o00002_ooool4o`0006;ooooo000Looooo`03o`000?oooooooooo03_ooooo0_l0
000=ooooo`Co000000?oooooo`000?l000002Oooool2o`0001Cooooo0_l00009oooooago00002_oo
ool2o`000003ooooool0003o000001?ooooo4Ol00004ooooo`Go00004Oooool4o`000003ooooool0
003o000000Sooooo0_l00005ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0BOooool4
o`0000;ooooo0_l0000Oooooo`;o00002_oooolLo`0000[ooooo0_l0000@ooooo`Wo00000_oooolD
o`0000Cooooo0_l0000>ooooo`;o000000?oooooo`000?l000002?ooool2o`0000Gooooo0_l00002
ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0B?ooool5o`0001gooooo0_l00004oooo
o`;o00002_oooolCo`000003ooooool0003o000000Go00002_ooool2o`0000Sooooo1?l00005oooo
o`Ko000000?oooooo`000?l000005_l00004ooooo`;o00001_ooool2o`0000Wooooo0_l0000@oooo
o`;o000000?oooooo`000?l00000B?ooool001cooooo0_l00019ooooo`Go00003oooool2o`0000Co
oooo0_l00003ooooo`Go00001?ooool2o`0000Wooooo6?l00002ooooo`;o00001?ooool2o`0000Co
oooo1Ol00005ooooo`Co00000oooool2o`0000Cooooo6?l000000ooooooo0000o`000004ooooo`;o
00001_ooool2o`0000Kooooo0_l000000ooooooo0000o`00000@ooooo`;o0000Boooool001cooooo
00?o0000ooooooooool0AOooool5o`000004ooooool0003o0000o`0000Cooooo0_l00008ooooo`;o
00001?ooool2o`0000?ooooo1?l0000@ooooo`;o000000?oooooo`000?l000005?l00004ooooo`;o
000000Coooooo`000?l0003o00001Oooool4o`0000_ooooo0_l00005oooooa_o000000?oooooo`00
0?l000002oooool2o`0000?ooooo0_l0000Dooooo`Co0000B?ooool001cooooo00?o0000oooooooo
ool0>Oooool2o`0000[ooooo1?l00003ooooo`;o00001?ooool2o`0000Sooooo0_l00003ooooo`;o
000000?oooooo`000?l000005OoooolJo`0000?ooooo0_l000000ooooooo0000o`000003o`0000Go
oooo0_l0000?ooooob7o00000oooool2o`0000Kooooo0_l00006ooooo`;o00002?ooool2o`0000Ko
oooo1Ol00018ooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00002oooool3o`0000Wooooo
0_l000000ooooooo0000o`00000:ooooo`;o000000?oooooo`000?l000001_ooool3o`0000cooooo
6_l00006ooooo`;o000000?oooooo`000?l000005_oooolDo`000003ooooool0003o000000[o0000
0oooool2o`0000kooooo0_l00003ooooo`;o00000oooool2o`0000Kooooo1?l0000Aooooo`;o0000
=_ooool001cooooo00?o0000ooooooooool0=oooool2o`0000kooooo1Ol00009ooooo`;o00003_oo
ool2o`0000Gooooo1Ol0000=oooooaSo00000oooool2o`0000?ooooo0_l0000Booooo`?o00000_oo
oolCo`000003ooooool0003o000000Ko00000_ooool2o`0001Sooooo0_l0000=ooooo`;o00004Ooo
ool2o`0003Kooooo000Looooo`03o`000?oooooooooo037ooooo0_l00004ooooo`;o00002oooool2
o`0000?ooooo0ol0000Iooooo`;o00001_ooool4o`0000[ooooo5Ol00002ooooo`Co00000oooool2
o`0000?ooooo0_l0000Booooo`?o00000_oooolLo`0000?ooooo0_l0000;ooooo`;o000000?ooooo
o`000?l000000_ooool2o`0000Gooooo0_l00005ooooo`;o000000?oooooo`000?l000000oooool4
o`0004Gooooo000Looooo`03o`000?oooooooooo037ooooo0_l0000Aooooo`;o00001Oooool4o`00
01gooooo0_l0000=oooooaGo00000_ooool2o`0000Gooooo1Ol00007ooooo`;o00001_ooool2o`00
00Sooooo4_l000000ooooooo0000o`000007o`000003ooooool0003o000000;o00002oooool2o`00
0003ooooool0003o000000;ooooo0_l00005ooooo`;o00001Oooool7o`000003ooooool0003o0000
00;o0000AOooool001cooooo00?o0000ooooooooool0Boooool4o`0001gooooo0_l00007ooooo`?o
00001?oooolDo`0000?ooooo0_l00004ooooo`Go00001oooool2o`0000Kooooo0_l00009oooooa7o
000000?oooooo`000?l000002_l0000<ooooo`;o00004?ooool2o`0000?ooooo0_l00002ooooo`;o
00000oooool2o`0004Gooooo000Looooo`03o`000?oooooooooo04gooooo0_l00002ooooo`;o0000
2Oooool2o`0001Oooooo0ol00004ooooo`?o000000?oooooo`000?l000001ol000000ooooooo0000
o`000004o`0000;ooooo1?l00003ooooo`;o00003?ooool2o`0000?ooooo0_l00008ooooo`go0000
0_ooool?o`0000Kooooo0_l00006ooooo`;o00000_ooool2o`0000cooooo0_l0000=ooooo`;o0000
A?ooool001cooooo00?o0000ooooooooool0COooool2o`0000;ooooo0_l00002ooooo`?o00001?oo
ool5o`0000Wooooo0ol0000@ooooo`;o00001?ooool6o`000003ooooool0003o000000Gooooo1Ol0
0002ooooo`?o00003?ooool2o`0000?ooooo0_l00008oooooago00001oooool2o`0000[ooooo0_l0
0006ooooo`;o00000oooool3o`0000gooooo0_l00002ooooo`;o0000@?ooool001cooooo00?o0000
ooooooooool0?oooool2o`0000Sooooo0_l0000:ooooo`?o00001Oooool4o`0000Wooooo0ol00006
ooooo`;o00003_ooool4o`000003ooooool0003o000000;o00001Oooool4o`0000?ooooo0_l0000:
ooooo`;o00003OoooolMo`000003ooooool0003o000000;o00006Oooool2o`0000?ooooo0_l0000>
ooooo`?o000000?oooooo`000?l000001Oooool2o`0000Cooooo0_l0000cooooo`007?ooool00ol0
003oooooooooo`0/ooooo`;o00004Oooool2o`0000Cooooo0_l00002ooooo`;o00002?ooool3o`00
00oooooo0_l00005ooooo`Go00000_ooool2o`0000Kooooo0_l00008ooooo`Go00004?ooool2o`00
0003ooooool0003o000000Gooooo0ol0000;ooooo`Wo000000?oooooo`000?l000004ol00002oooo
o`;o00001?ooool2o`0000Oooooo0_l0000Cooooo`;o00002Oooool4o`0000Sooooo0_l00004oooo
o`;o0000<oooool001cooooo00?o0000ooooooooool0;?ooool2o`0000cooooo0_l00009ooooo`Co
00001oooool2o`000004ooooool0003o0000o`0000cooooo0_l000000ooooooo0000o`000005oooo
o`Go00002_ooool3o`0000Oooooo0ol0000Booooo`;o000000?oooooo`000?l000001_ooool2o`00
00Sooooo0_l000001?oooooo0000o`000?oooolMo`0000;ooooo0_l00003ooooo`;o00001oooool4
o`000003ooooool0003o000000;o00003?ooool2o`0000Kooooo0_l000000ooooooo0000o`000015
ooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00002?ooool2o`000003ooooool0003o0000
00Sooooo0_l00007ooooo`;o00000_ooool3o`0000Wooooo1ol0000Eooooo`;o00002Oooool2o`00
017ooooo0_l00007ooooo`;o00000_ooool3o`0000Gooooo0_l000001?oooooo0000o`000?oooolI
o`0000;ooooo0_l00002ooooo`;o00002_ooool6o`000003ooooool0003o000000;o00000_ooool2
o`0000_ooooo0_l00003ooooo`Co0000A_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Ooo
ool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo033ooooo0_l0
000;ooooo`;o00002_ooool2o`0000Wooooo0ol00009ooooo`;o000000Coooooo`000?l0003o0000
6_ooool2o`0000Gooooo0_l0000=ooooo`;o00000_ooool2o`0000Gooooo2Ol00008ooooo`;o0000
00?oooooo`000?l000005ol0000Aooooo`?o00000_ooool2o`0000?ooooo1_l0000;ooooo`;o0000
1Oooool2o`0000Gooooo0_l0000oooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o
8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo047ooooo0_l00006ooooo`;o
00006Oooool2o`000003ooooool0003o000000[ooooo0_l0000;ooooo`;o00005?ooool2o`0000Wo
oooo0_l00002ooooo`?o00003OoooolJo`0000Oooooo0_l00007ooooo`;o00002?ooool5o`0000;o
oooo0_l0000>ooooo`;o00001_ooool2o`0000cooooo0_l00002ooooo`;o0000;Oooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo00?o0000ooooooooool0
?oooool4o`0000Oooooo1?l0000@ooooo`;o000000?oooooo`000?l000001_l00005ooooo`;o0000
0oooool2o`0001Sooooo0_l0000Eooooo`Oo00002_ooool6o`0000;ooooo4ol00006ooooo`;o0000
2?ooool2o`000003ooooool0003o000000;o00002Oooool2o`0000;ooooo0_l0000:ooooo`Co0000
4_ooool3o`000003ooooool0003o000002gooooo00000ooooooo0000ooooo`02ooooo`03o`000?oo
oooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`0003cooooo0_l000000ooooooo0000
o`000009ooooo`Co00002oooool2o`000003ooooool0003o000000;o000000?oooooo`000?l00000
1Ol00006ooooo`;o000000Coooooo`000?l0003o00006Oooool2o`00017ooooo0_l00002ooooo`;o
00000_ooool3o`0000_ooooo7?l0000:ooooo`;o00000_ooool2o`000003ooooool0003o000000;o
00002?ooool2o`0000?ooooo0_l0000<ooooo`;o00004_ooool3o`00033ooooo00000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003o
ooooooooo`0looooo`;o00000oooool2o`0000Kooooo0_l000000ooooooo0000o`00000;ooooo`;o
000000?oooooo`000?l000002Oooool2o`0000;ooooo0_l000000ooooooo0000o`000004o`0001Go
oooo0_l00009ooooo`;o00002_ooool2o`0000oooooo0_l00002oooooako000000?oooooo`000?l0
00001_ooool2o`0000Cooooo0_l0000;ooooo`;o00004oooool2o`00013ooooo0_l0000aooooo`00
00?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo
00?o0000ooooooooool09oooool2o`0001Sooooo0_l00006ooooo`Go00001?ooool2o`0000Sooooo
0_l00009ooooo`;o00000_ooool2o`0000?ooooo0_l0000>ooooo`;o00001oooool2o`0000Gooooo
0_l00002ooooo`;o00000oooool2o`0001Kooooo0_l00002oooooa[o00000_ooool2o`000003oooo
ool0003o000000Sooooo0_l00002ooooo`;o00002oooool2o`00013ooooo0_l000000ooooooo0000
o`000013ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co000000Oo
oooo00?o0000ooooooooool09oooool2o`00023ooooo1?l000000ooooooo0000o`000002ooooo`Co
00001oooool2o`0000Kooooo2?l00004ooooo`;o00003Oooool2o`0000Cooooo0_l00007ooooo`?o
00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`00000Fooooo`Ko000000?oooooo`000?l0
00001ol000000ooooooo0000o`000004o`000003ooooool0003o000000Gooooo0_l00009ooooo`;o
000000?oooooo`000?l000003?ooool2o`00013ooooo0_l00005ooooo`;o0000?oooool00006oooo
ooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo
03Wooooo0_l0000:ooooo`;o00000_ooool2o`000003ooooool0003o000000;o00001?ooool2o`00
00Oooooo0_l00006ooooo`[o00000_ooool2o`0001?ooooo0_l00007ooooo`;o00000oooool2o`00
00Kooooo0_l000000ooooooo0000o`00000Cooooo`;o00001Oooool6o`000003ooooool0003o0000
00Oo000000?oooooo`000?l000001Oooool2o`0000Oooooo0_l00003ooooo`?o00001oooool6o`00
00Sooooo0_l0000=ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0>Oooool2o`0000Co
oooo0_l00004ooooo`;o00001Oooool2o`0000cooooo0_l000000ooooooo0000o`000006ooooo`Go
000000?oooooo`000?l000000_l000000ooooooo0000o`000004o`0002Kooooo1Ol00005ooooo`?o
00001_ooool2o`000003ooooool0003o000000Oooooo2ol00006ooooo`;o00003_ooool2o`0000Co
oooo0_l00007ooooo`Ko00001oooool3o`0004kooooo000Looooo`03o`000?oooooooooo03Wooooo
0_l00003ooooo`?o00002oooool2o`0000cooooo0_l000001?oooooo0000o`000?ooool2o`0000?o
oooo0_l00004ooooo`Co000000?oooooo`000?l000001Ol00003ooooo`;o00002oooool2o`0001?o
oooo0ol00006ooooo`Go00001Oooool2o`000003ooooool0003o000000Gooooo0_l00002ooooo`Oo
00001?ooool2o`0000Gooooo0_l00005ooooo`;o00000_ooool2o`000003ooooool0003o000000So
oooo0_l0000<ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000?ooooo0_l00002oooo
o`;o00004Oooool2o`0002oooooo000Looooo`03o`000?oooooooooo02kooooo0_l0000>ooooo`;o
00001Oooool6o`000003ooooool0003o000000oooooo0_l000000ooooooo0000o`000009ooooo`Co
00000_ooool6o`0000?ooooo0_l00008ooooo`;o000000?oooooo`000?l000001oooool2o`000004
ooooool0003o0000ooooo`?o00002Oooool2o`000003ooooool0003o000000?o00003oooool2o`00
00;ooooo1_l00002ooooo`;o000000?oooooo`000?l000000oooool4o`0000Gooooo0_l00002oooo
o`;o000000?oooooo`000?l000002?ooool4o`0000[ooooo0_l00004ooooo`?o00000oooool2o`00
00;ooooo0_l00005ooooo`;o00002_ooool2o`0002oooooo000Looooo`03o`000?oooooooooo02ko
oooo0_l0000Aooooo`;o00000_ooool6o`0000;ooooo0_l0000Looooo`Co00000_ooool5o`0000ko
oooo0_l0000:ooooo`;o000000Coooooo`000?l0003ooooo0ol00006ooooo`;o000000?oooooo`00
0?l000000ol00008ooooo`Co00001oooool2o`000004ooooool0003o0000ooooo`;o00000_ooool3
o`000003ooooool0003o000000?ooooo0ol00002ooooo`;o00002?ooool2o`0000;ooooo0_l00007
ooooo`;o00000_ooool2o`0000;ooooo0_l00008ooooo`;o00001?ooool2o`0000?ooooo0_l00004
ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0=Oooool2o`0000Kooooo0_l00002oooo
o`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o000000?oooooo`000?l000005oooool6
o`0000;ooooo1_l0000Gooooo`;o00002?ooool2o`0000Gooooo1ol00009ooooo`Co00000_ooool2
o`0000;ooooo0ol000001?oooooo0000o`000?l00004ooooo`?o00002oooool2o`0000Sooooo0_l0
0002ooooo`;o00000_ooool2o`0000Oooooo0ol000000ooooooo0000o`000002o`00017ooooo0_l0
0011ooooo`007?ooool00ol0003oooooooooo`0eooooo`;o00001_ooool2o`0000Gooooo0_l00007
ooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo0_l0000=ooooo`;o00000oooool9
o`000003ooooool0003o000001Cooooo0_l00008ooooo`;o00001oooool5o`0000_ooooo0_l00002
ooooo`;o00000_ooool7o`000003ooooool0003o000000Co00001?ooool2o`0000;ooooo0_l0000C
ooooo`;o00001Oooool2o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o00001Oooool2
o`0000Cooooo0_l000001?oooooo0000o`000?l0000Cooooo`;o0000:_ooool001cooooo00?o0000
ooooooooool0;?ooool2o`0001kooooo0_l00002ooooo`?o000000Coooooo`000?l0003o00000ooo
ool3o`0000_ooooo0_l00004ooooo`co00004_ooool2o`00017ooooo1_l00002ooooo`;o00002ooo
ool2o`0000Cooooo1?l00003ooooo`Co00001_ooool2o`0000;ooooo0_l0000:ooooo`;o00003_oo
ool2o`0000[ooooo0_l00005ooooo`;o00001?ooool2o`000004ooooool0003o0000o`0000?ooooo
1?l0000<ooooo`;o0000:_ooool001cooooo00?o0000ooooooooool0;?ooool2o`00017ooooo0_l0
000;ooooo`;o00000oooool2o`000003ooooool0003o000000Gooooo0ol00002ooooo`;o00001_oo
ool2o`000004ooooool0003o0000ooooo`_o00002oooool2o`0000Cooooo1_l00006ooooo`;o0000
1oooool6o`0000;ooooo0_l000000ooooooo0000o`000008ooooo`;o00001?ooool2o`00017ooooo
0_l0000<ooooo`;o00003Oooool2o`000003ooooool0003o000000[ooooo0_l00006ooooo`;o0000
2_ooool4o`0003Sooooo000Looooo`03o`000?oooooooooo02kooooo0_l0000;ooooo`;o00000_oo
ool2o`0000oooooo1_l00006ooooo`;o00000_ooool2o`0000Wooooo3?l00006ooooo`;o00000_oo
ool5o`0000?ooooo0ol00002ooooo`;o00001_ooool2o`0000Kooooo0ol000001?oooooo0000o`00
0?l00002ooooo`;o000000Coooooo`000?l0003o00004?ooool2o`0000?ooooo0_l00004ooooo`Co
000000?oooooo`000?l000000oooool2o`0000Oooooo0_l0000=ooooo`;o000000?oooooo`000?l0
00002_ooool2o`0000Kooooo0_l0000;ooooo`;o0000>Oooool001cooooo00?o0000ooooooooool0
:oooool2o`000003ooooool0003o000000Gooooo0_l00004ooooo`Ko000000?oooooo`000?l00000
3?ooool7o`0001?ooooo3Ol00005ooooo`?o00000_ooool5o`0000?ooooo0_l00005ooooo`;o0000
3?ooool3o`000003ooooool0003o000000?ooooo0ol000000ooooooo0000o`00000=ooooo`;o0000
00Coooooo`000?l0003ooooo1?l00004ooooo`Co00000_ooool2o`0000;ooooo0_l00007ooooo`;o
000000?oooooo`000?l000006?ooool2o`0000kooooo0_l0000oooooo`007?ooool00ol0003ooooo
ooooo`0[ooooo`;o00002?ooool2o`0000Cooooo1?l00003ooooo`;o00000oooool2o`0000cooooo
0_l0000:ooooo`;o00000_ooool2o`0000?ooooo1?l000000ooooooo0000o`000006o`0000Gooooo
0_l00006ooooo`;o000000?oooooo`000?l000000oooool2o`0000;ooooo0_l0000Fooooo`;o0000
4?ooool2o`000004ooooool0003o0000ooooo`;o00000oooool2o`0000Oooooo0ol00005ooooo`;o
000000?oooooo`000?l000000oooool2o`0000Gooooo0_l00003ooooo`;o00001_ooool2o`0000Co
oooo0_l0000>ooooo`;o00000oooool4o`0003Sooooo000Looooo`;o0000>oooool3o`0000Oooooo
0_l000000ooooooo0000o`000003ooooo`;o00002?ooool2o`0000Gooooo0_l00002ooooo`;o0000
0_ooool4o`0000?ooooo0_l000000ooooooo0000o`000006o`0000?ooooo0_l0000;ooooo`;o0000
0oooool2o`0001;ooooo0_l00006ooooo`Co000000Coooooo`000?l0003ooooo0_l0000;ooooo`;o
000000?oooooo`000?l000000oooool2o`0000Sooooo0_l00005ooooo`;o000000?oooooo`000?l0
00002_ooool3o`0000;ooooo0_l00002ooooo`;o00000_ooool3o`0000Oooooo0_l0000?ooooo`Co
0000>?ooool001cooooo00?o0000ooooooooool0>_ooool4o`0000Kooooo0_l00006ooooo`Co0000
1_ooool2o`0000Gooooo0_l00005ooooo`;o000000?oooooo`000?l000000oooool;o`0000?ooooo
0_l000001?oooooo0000o`000?ooool2o`0000[ooooo0_l0000=ooooo`;o00000oooool2o`0000Co
oooo1_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l000000ooooooo0000o`000004oooo
o`;o000000?oooooo`000?l000000_l0000Qooooo`?o00001_ooool2o`0000?ooooo0_l00007oooo
o`;o00002oooool3o`0000Gooooo0_l0000fooooo`007?ooool00ol0003oooooooooo`0looooo`;o
00003_ooool4o`0000oooooo0_l00002ooooo`?o00001oooool5o`000003ooooool0003o000000?o
00001Oooool5o`0000Cooooo0_l00003ooooo`;o00001oooool2o`0000Gooooo0_l00009ooooo`;o
000000?oooooo`000?l000001_ooool2o`000004ooooool0003o0000ooooo`;o00002Oooool2o`00
00Kooooo1?l0000>ooooo`;o00002?ooool2o`0001Kooooo0_l00009ooooo`?o000000?oooooo`00
0?l000000_ooool2o`0003Kooooo000Looooo`03o`000?oooooooooo02gooooo0_l0000;ooooo`?o
00003oooool2o`000003ooooool0003o000000kooooo1_l00009ooooo`[o00001?ooool6o`0000Co
oooo0_l00003ooooo`Co00001Oooool2o`00013ooooo0_l00002ooooo`;o00000oooool4o`0001Oo
oooo1?l0000>ooooo`;o00002?ooool3o`0000kooooo0_l00005ooooo`;o00003Oooool2o`0003[o
oooo000Looooo`03o`000?oooooooooo02gooooo0_l0000;ooooo`?o00001Oooool2o`0000Oooooo
1_l0000@ooooo`;o00001?ooool3o`0000Gooooo2?l00005ooooo`;o000000Coooooo`000?l0003o
00001Oooool2o`0000Cooooo0_l00003ooooo`;o00001Oooool2o`0000oooooo1?l000000ooooooo
0000o`00000`ooooo`;o00001?ooool2o`0000;ooooo0_l0000:ooooo`;o00001?ooool2o`0004[o
oooo000Looooo`03o`000?oooooooooo03;ooooo0_l00002ooooo`?o00002Oooool2o`0000Kooooo
1Ol0000Hooooo`?o00001_ooool6o`00017ooooo0_l00003ooooo`Co00000_ooool2o`0000Gooooo
0_l000000ooooooo0000o`000007ooooo`?o00000_ooool4o`0000gooooo0_l0000<ooooo`;o0000
5_ooool2o`0000Sooooo0_l00004ooooo`;o00001?ooool2o`0000;ooooo1?l0001:ooooo`007?oo
ool00ol0003oooooooooo`0`ooooo`Co00000_ooool3o`00017ooooo0_l0000Rooooo`So00005_oo
ool4o`0000;ooooo0_l00008ooooo`?o00001Oooool4o`0000;ooooo1?l000000ooooooo0000o`00
0002ooooo`;o00000oooool2o`000003ooooool0003o000000Kooooo0_l00004ooooo`;o00009_oo
ool3o`0000Oooooo0_l0000Tooooo`;o00009_ooool001cooooo00?o0000ooooooooool0<?ooool2
o`0000Cooooo0_l00003ooooo`;o00002Oooool2o`0001Sooooo0_l00008ooooo`;o00000_ooool8
o`0001Gooooo0_l00005ooooo`;o00002Oooool2o`0000Cooooo0ol00006ooooo`Go00000_ooool2
o`0000?ooooo0_l00009ooooo`?o00001?ooool2o`0000;ooooo0_l0000Rooooo`;o00005_ooool2
o`0001Gooooo0_l0000Vooooo`007?ooool00ol0003oooooooooo`0fooooo`?o00000_ooool2o`00
00Wooooo0_l0000Hooooo`Co00001_ooool2o`0000?ooooo1ol00002ooooo`;o00002_ooool2o`00
00Gooooo0_l0000@ooooo`;o00000oooool3o`0000Oooooo1Ol000000ooooooo0000o`000007oooo
o`;o00001oooool2o`0000Cooooo0_l00002ooooo`;o00008oooool2o`0000?ooooo1?l00008oooo
o`;o00001?ooool2o`0003gooooo000Looooo`03o`000?oooooooooo03Oooooo0_l0000?ooooo`;o
00006?ooool2o`0000Cooooo1Ol00003ooooo`Ko00000_ooool2o`0000[ooooo0_l00003ooooo`;o
00001_ooool2o`0000[ooooo0_l00002ooooo`Co00000_ooool2o`0000?ooooo1Ol000000ooooooo
0000o`000007ooooo`;o0000=_ooool2o`0000;ooooo1Ol00006ooooo`Co00001?ooool2o`0003go
oooo000Looooo`03o`000?oooooooooo03;ooooo0_l0000Dooooo`;o00001_ooool2o`0001;ooooo
0_l000001Ooooooo0000o`000?l0003ooooo00;o00000oooool6o`0000cooooo0_l00005ooooo`;o
00001_ooool2o`0000Wooooo0_l00003ooooo`So00001_ooool2o`0001Cooooo0ol00003ooooo`;o
0000:_ooool2o`0000Kooooo0_l000000ooooooo0000o`000006ooooo`;o0000?Oooool001cooooo
00?o0000ooooooooool0<_ooool2o`0000;ooooo0_l0000Hooooo`;o00000oooool2o`0000gooooo
0_l000000ooooooo0000o`000002ooooo`_o00003?ooool2o`0001Sooooo0_l000000ooooooo0000
o`000004ooooo`;o00003?ooool4o`0000Sooooo0_l00004ooooo`Go000000?oooooo`000?l00000
2?ooool2o`0001kooooo0_l00008ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo
0_l000000ooooooo0000o`00000iooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00000ooo
ool2o`0001;ooooo0_l00004ooooo`;o00003Oooool6o`000003ooooool0003o000000Go000000Co
ooooo`000?l0003o00008_ooool2o`0000Gooooo0_l00006ooooo`;o00002_ooool4o`0000Sooooo
0_l00007ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l0000Nooooo`;o0000
2_ooool5o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`00000iooooo`007?oo
ool00ol0003oooooooooo`0gooooo`;o00000_ooool2o`0000gooooo0_l00003ooooo`Co00000_oo
ool2o`0000gooooo4_l00009ooooo`;o00005Oooool4o`0000gooooo0_l00006ooooo`;o00001?oo
ool2o`0000Gooooo0_l0000=ooooo`;o00000_ooool2o`00033ooooo0ol00004ooooo`;o000000?o
ooooo`000?l000005oooool2o`0002?ooooo000Looooo`03o`000?oooooooooo02Sooooo0_l00000
0ooooooo0000o`00000:ooooo`;o00004?ooool3o`0000Gooooo0_l00002ooooo`;o00000oooool2
o`0000Oooooo0_l000000ooooooo0000o`00000?o`0000;ooooo0_l00004ooooo`;o00005Oooool2
o`0001;ooooo0ol00002ooooo`;o00001?ooool2o`0000Gooooo0_l0000nooooo`;o00002_ooool2
o`000003ooooool0003o000000;ooooo0_l0000Cooooo`;o00008oooool001cooooo00?o0000oooo
ooooool0:?ooool2o`000003ooooool0003o000001_ooooo0ol0000?ooooo`;o00001oooool2o`00
0004ooooool0003o0000ooooo`ko00000_ooool6o`0001kooooo0_l0000;ooooo`?o00001?ooool2
o`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l000004Oooool2o`0002Sooooo0_l00003
ooooo`;o00003?ooool2o`0003Sooooo000Looooo`;o0000BOooool3o`0001_ooooo4Ol00004oooo
o`Co00000oooool2o`0001Wooooo0ol00003ooooo`;o00003?ooool2o`0000?ooooo0_l000001?oo
oooo0000o`000?ooool2o`000004ooooool0003o0000o`0000Oooooo0_l00007ooooo`;o0000:Ooo
ool2o`0000;ooooo0_l00006ooooo`;o00001oooool2o`0003Gooooo000Looooo`03o`000?oooooo
oooo03?ooooo0_l0000Qooooo`;o00003_oooolDo`0000?ooooo0_l00003ooooo`;o00001Oooool2
o`0000Oooooo0_l0000:ooooo`;o00000oooool2o`0000?ooooo0_l00003ooooo`;o00002_ooool2
o`000003ooooool0003o000000Oo00001?ooool3o`0002_ooooo1?l00002ooooo`Ko00001_ooool3
o`0000Kooooo0_l0000eooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00006?ooool2o`00
00Oooooo0_l0000?ooooo`go000000?oooooo`000?l000000ol00003ooooo`;o00002_ooool2o`00
00Oooooo0_l0000Dooooo`Oo00001oooool2o`000003ooooool0003o000000;ooooo0ol000000ooo
oooo0000o`000002o`0000?ooooo2?l00009ooooo`?o00005oooool2o`0000;ooooo1?l00004oooo
o`Co00001oooool2o`0003gooooo000Looooo`03o`000?oooooooooo02_ooooo0_l00003ooooo`?o
00001?ooool2o`0001Cooooo1?l0000Foooooa;o00007Oooool2o`0000?ooooo0_l00003ooooo`;o
00001_ooool6o`000003ooooool0003o000000?o00000_ooool=o`0000Gooooo0_l00002ooooo`Co
00002Oooool3o`0001Oooooo0_l0000Hooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0
:oooool2o`0000?ooooo0ol00004ooooo`;o00005_ooool2o`0000Sooooo0_l0000<ooooo`oo0000
00?oooooo`000?l000007Oooool2o`0000?ooooo0_l00003ooooo`;o00003?ooool6o`0000;ooooo
3ol00005ooooo`;o00000_ooool2o`0000Sooooo0_l0000Looooo`;o00005?ooool3o`0003[ooooo
000Looooo`03o`000?oooooooooo037ooooo0_l00002ooooo`Go00003_ooool2o`0000oooooo0_l0
000<ooooo`oo00000_ooool2o`0000Wooooo0_l0000Eooooo`;o00001Oooool2o`0000_ooooo1ol0
00000ooooooo0000o`000007o`000003ooooool0003o000000?o000000?oooooo`000?l000000_oo
ool8o`0000Kooooo0_l0000Iooooo`;o000000?oooooo`000?l000005?ooool2o`0003_ooooo000L
ooooo`03o`000?oooooooooo02oooooo0_l00004ooooo`Go00003_ooool2o`0000Gooooo0_l00002
ooooo`;o00002?ooool6o`0000?ooooo5?l00004ooooo`;o00000oooool2o`0001Gooooo0_l00002
ooooo`;o000000Coooooo`000?l0003o00003?ooool5o`0000?ooooo2_l00004ooooo`Co000000?o
ooooo`000?l000001Ol000000ooooooo0000o`00000Mooooo`?o00001Oooool2o`0000_ooooo0_l0
0006ooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0;oooool2o`0000oooooo1_l00009
ooooo`;o00000_ooool4o`0000Kooooo1_l00003ooooo`Go00000_ooool<o`0000Gooooo0_l0000F
ooooo`;o00001_ooool2o`0000;ooooo0_l00006ooooo`;o00000oooool6o`0000;ooooo2ol00005
ooooo`Oo00001?ooool3o`0001[ooooo0_l000000ooooooo0000o`000006ooooo`;o00001Oooool2
o`0000Cooooo0ol00005ooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0@?ooool6o`00
00?ooooo0_l0000:ooooo`;o00003oooool6o`000004ooooool0003o0000ooooo`Wo00007Oooool2
o`0000gooooo0ol00002ooooo`?o00000_oooolFo`0000;ooooo0_l000000ooooooo0000o`000002
o`0000Cooooo0_l0000Kooooo`;o00003_ooool4o`0000Gooooo0_l0000Looooo`;o00008Oooool0
01cooooo00?o0000ooooooooool0@?ooool2o`0000Kooooo1Ol0000>ooooo`;o00002OoooolCo`00
00;ooooo0ol0000Hooooo`;o00003OoooolPo`0000Kooooo0ol0000>ooooo`Co00006?ooool2o`00
00Gooooo0_l0000Uooooo`;o00008Oooool001cooooo00?o0000ooooooooool0=oooool2o`0000;o
oooo1?l000000ooooooo0000o`000005ooooo`?o000000?oooooo`000?l000000ol0000;ooooo`;o
00002OoooolDo`000004ooooool0003o0000o`0001Cooooo0_l000000ooooooo0000o`000007oooo
o`;o00001OoooolWo`0000Oooooo0_l00007ooooo`Co00006?ooool2o`0000cooooo0_l00011oooo
o`007?ooool00ol0003oooooooooo`0eooooo`Co00000_ooool4o`000003ooooool0003o000000Go
oooo0_l00003ooooo`Co00005?oooolFo`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l0
00003?ooool3o`000003ooooool0003o000000Oooooo0_l00005ooooo`Co00000ooooolRo`0000Go
oooo0_l000000ooooooo0000o`00000Pooooo`;o00003?ooool2o`0001oooooo0_l0000Pooooo`00
7?ooool00ol0003oooooooooo`0eooooo`;o000000Coooooo`000?l0003ooooo0ol00009ooooo`Go
00004Oooool2o`0000Gooooo4_l000000ooooooo0000o`000002o`0000Gooooo1Ol00006ooooo`;o
00001?ooool2o`0000Cooooo0_l0000=ooooo`;o000000Coooooo`000?l0003ooooo7ol000001?oo
oooo0000o`000?l00007ooooo`;o00008_ooool2o`0000cooooo0_l00005ooooo`;o00005_ooool2
o`00023ooooo000Looooo`03o`000?oooooooooo01oooooo0_l0000Gooooo`Ko00002?ooool6o`00
00Oooooo0_l00007ooooo`?o00001ooooolEo`0000Kooooo0_l00008ooooo`;o00000oooool2o`00
00Gooooo0_l00005ooooo`;o00001?ooool2o`0000?ooooo0_l000000ooooooo0000o`00000Lo`00
00?ooooo0_l00004ooooo`;o00007oooool2o`0000Cooooo0_l00003ooooo`;o00001_ooool3o`00
00Gooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0Oooooo`;o00005Oooool2o`0000;o
oooo0_l00005ooooo`;o00000oooool2o`0000_ooooo0_l00007ooooo`;o00002?oooolCo`0000oo
oooo0_l00006ooooo`;o00000oooool2o`000003ooooool0003o000000Cooooo0_l00004ooooo`?o
00001OoooolOo`0000Kooooo1?l0000Mooooo`Co00002Oooool2o`0000Kooooo0_l00010ooooo`00
7?ooool00ol0003oooooooooo`0fooooo`;o00001?ooool2o`0000?ooooo0_l00004ooooo`;o0000
0_ooool2o`0001Kooooo0_l000000ooooooo0000o`00000Eo`0000_ooooo0_l00005ooooo`;o0000
1?ooool2o`000004ooooool0003o0000o`0000Wooooo0ol000001Ooooooo0000o`000?l0003ooooo
01oo00001_ooool4o`000003ooooool0003o000001[ooooo0_l0000Cooooo`;o00000oooool2o`00
03_ooooo000Looooo`;o0000?Oooool2o`0000Wooooo0_l00002ooooo`;o00005_ooool2o`000003
ooooool0003o000001Go00004_ooool2o`0000Sooooo0_l00009ooooob?o000000?oooooo`000?l0
00001Oooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0001Cooooo0_l00003ooooo`;o
00003_ooool2o`0000Oooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0kooooo`;o0000
1Oooool6o`0000;ooooo1?l0000HoooooaGo00006?ooool2o`0000Gooooo0ol00009ooooob;o0000
00?oooooo`000?l000000_ooool4o`0000Cooooo1Ol0000Dooooo`;o00000oooool2o`0000[ooooo
0_l00002ooooo`;o00000oooool2o`0003oooooo000Looooo`03o`000?oooooooooo03Sooooo0_l0
00000ooooooo0000o`000005ooooo`Ko00000_ooool4o`0001?ooooo0_l000000ooooooo0000o`00
000Eo`0001Sooooo0_l00004ooooo`Co00001oooool2o`0000?ooooo8_l00002ooooo`;o00001_oo
ool2o`0000Wooooo0_l0000?ooooo`;o00003?ooool2o`0000Oooooo0_l0000oooooo`007?ooool0
0ol0003oooooooooo`0hooooo`;o00003oooool2o`0000kooooo0_l00004ooooo`Co000000?ooooo
o`000?l000004ol0000Aooooo`;o00001?ooool2o`0000Oooooo0_l00007ooooo`Co000000?ooooo
o`000?l000008_l00005ooooo`;o00000_ooool2o`0000Gooooo0_l00003ooooo`;o00003oooool2
o`0000Gooooo0_l0000>ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0BOooool2o`00
0003ooooool0003o000000_ooooo1?l00002ooooo`;o00001Oooool6o`000003ooooool0003o0000
00[o00004Oooool2o`0000Cooooo0_l0000@ooooo`Co000000?oooooo`000?l000009?l00003oooo
o`;o00000_ooool2o`0000Gooooo0_l00005ooooo`?o00003_ooool2o`0000?ooooo0_l0001?oooo
o`007?ooool00ol0003oooooooooo`0Sooooo`;o00004Oooool2o`000003ooooool0003o000000Wo
oooo0_l00006ooooo`;o00003Oooool2o`0000_ooooo4Ol0000Tooooo`So00000_oooolEo`0000;o
oooo4?l000000ooooooo0000o`000002o`0000oooooo0ol00009ooooo`Co000000?oooooo`000?l0
00002_ooool2o`0004Sooooo000Looooo`03o`000?oooooooooo02?ooooo0_l0000<ooooo`;o0000
0oooool2o`000004ooooool0003o0000o`0000Gooooo0_l000001?oooooo0000o`000?l0000Ooooo
oa?o00000_ooool2o`0000Kooooo0_l0000Hooooobko000000Coooooo`000?l0003ooooo1?l0000A
ooooo`;o00002?ooool4o`0000?ooooo1?l00004ooooo`Co00002_ooool2o`0003cooooo000Loooo
o`03o`000?oooooooooo037ooooo0_l00007ooooo`Co00000oooool2o`000004ooooool0003o0000
o`0001Wooooo0_l00004oooooa?o00000_ooool2o`0000Kooooo0_l00008ooooo`;o00000_ooool2
o`0000gooooo:ol000000ooooooo0000o`000002o`000003ooooool0003o000000;o00003oooool2
o`0000oooooo1?l00004ooooo`Co00000oooool2o`0000;ooooo1Ol0000looooo`007?ooool00ol0
003oooooooooo`0jooooo`Co00001_ooool2o`0001[ooooo0_l00005oooooa7o00002oooool2o`00
00Sooooo0_l000001?oooooo0000o`000?l0000;ooooo`;o00000oooool4o`000004ooooool0003o
0000ooooob3o000000?oooooo`000?l000000_l000000ooooooo0000o`000002o`0000Sooooo0_l0
000Eooooo`?o00003Oooool3o`000003ooooool0003o000000;o0000?Oooool001cooooo00?o0000
ooooooooool0Boooool2o`0000gooooo1?l00009ooooo`co000000?oooooo`000?l000001?l00009
ooooo`;o00002oooool2o`0000Kooooo0ol00003ooooo`;o00000ooooolZo`000003ooooool0003o
000000;ooooo0_l00009ooooo`;o00005Oooool3o`0000gooooo0ol00003ooooo`;o0000?Oooool0
01cooooo00?o0000ooooooooool0;oooool2o`0000?ooooo0_l0000;ooooo`;o00002?ooool2o`00
00gooooo1?l00009ooooo`Wo000000?oooooo`000?l000001ol0000Dooooo`Co00001_ooool3o`00
00Sooooo0_l000000ooooooo0000o`00000?o`000003ooooool0003o000001Ko00000_ooool2o`00
0003ooooool0003o000000Kooooo0_l00002ooooo`;o000000?oooooo`000?l000006oooool2o`00
0003ooooool0003o000000?o000000?oooooo`000?l00000?Oooool001cooooo00?o0000oooooooo
ool0;oooool2o`0000?ooooo0_l00004ooooo`;o00001Oooool2o`0000Sooooo0_l0000>ooooo`?o
00001?ooool2o`0000Cooooo4_l00004ooooo`;o00000_ooool2o`0000[ooooo0_l0000Aooooo`Ko
000000?oooooo`000?l000003Ol000000ooooooo0000o`00000@o`000003ooooool0003o000000?o
00001Oooool2o`0000Kooooo0ol000001?oooooo0000o`000?ooool4o`0001Gooooo0_l000001Ooo
oooo0000o`000?l0003ooooo00Go0000@?ooool001cooooo00?o0000ooooooooool0;oooool2o`00
00Wooooo0_l00007ooooo`;o00001_ooool2o`0000oooooo0_l00004ooooo`;o00001?ooool2o`00
00;ooooo1_l000000ooooooo0000o`000005o`0000Cooooo0_l00002ooooo`;o00004_ooool2o`00
00Kooooo0_l000000ooooooo0000o`000004o`000003ooooool0003o0000027o000000Coooooo`00
0?l0003o00000_ooool2o`0000;ooooo0_l00007ooooo`;o00001?ooool4o`0000_ooooo0_l00008
ooooo`;o000000?oooooo`000?l000001?ooool2o`00047ooooo000Looooo`03o`000?oooooooooo
02oooooo0_l00002ooooo`;o00003_ooool2o`0001kooooo0_l00002ooooo`;o000000?oooooo`00
0?l000002ol0000?ooooo`;o00003?ooool4o`0000Kooooo0_l00003ooooo`Co000000?oooooo`00
0?l000008Ol000001?oooooo0000o`000?l00002ooooo`;o00000_ooool2o`0000Cooooo0_l00007
ooooo`Co00002oooool4o`0005;ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ
8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0]ooooo`;o0000
0oooool3o`0001;ooooo0_l0000Aooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`;o0000
00?oooooo`000?l000003Ol00005ooooo`;o00001_ooool2o`0000cooooo0_l0000<ooooo`;o0000
00Coooooo`000?l0003o00000_oooolOo`0000?ooooo0_l00004ooooo`?o00001_ooool2o`0000?o
oooo0_l0000=ooooo`;o00001?ooool2o`0002_ooooo0_l0000Uooooo`0000KoooooogMgMonHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000
ooooooooool0;Oooool2o`0000?ooooo0_l0000@ooooo`;o000000?oooooo`000?l000001?l00006
ooooo`;o00001Oooool2o`0000;ooooo0ol0000;ooooo`Go000000?oooooo`000?l000001Ol00005
ooooo`;o00002_ooool2o`000003ooooool0003o000001?ooooo0_l00002ooooo`Co000000?ooooo
o`000?l000001?l000000ooooooo0000o`00000Eo`000003ooooool0003o000000?o00000_ooool4
o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000002o`0000gooooo0_l0000a
ooooo`;o00009Oooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0A?ooool2o`000003ooooool0003o
000000Go00001Oooool2o`0000Cooooo0_l00003ooooo`;o00003oooool2o`0000?ooooo1?l00005
ooooo`;o00002Oooool4o`000003ooooool0003o000001?ooooo0_l00002ooooobWo00000_ooool2
o`000003ooooool0003o000000;o00000oooool2o`000003ooooool0003o000000;o00001?ooool2
o`0000oooooo0_l00008ooooo`;o00001Oooool2o`0003oooooo00000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000C?ooool2
o`0000?ooooo0_l00006ooooo`;o00000_ooool2o`0000Cooooo0_l0000:ooooo`Wo00001Oooool2
o`0000Sooooo1Ol000000ooooooo0000o`00000Cooooo`;o00000_ooool6o`000003ooooool0003o
000001go00002?ooool2o`0000Wooooo0ol00004ooooo`;o00003oooool2o`0000Cooooo0_l00002
ooooo`;o00001Oooool2o`0003oooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo03_ooooo0_l0000D
ooooo`;o00002_ooool2o`0000Cooooo0ol0000:ooooo`So000000?oooooo`000?l000000_ooool2
o`0000Sooooo1?l00002ooooo`;o00002?ooool2o`0000Wooooo1?l000000ooooooo0000o`00000R
o`0000?ooooo0ol00007ooooo`;o00001?ooool3o`0000Wooooo0_l00005ooooo`;o00001oooool2
o`000003ooooool0003o000000Cooooo0_l00014ooooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0>oooool2o`00
02Oooooo0_l00005ooooo`;o00001?ooool2o`000003ooooool0003o000000;o000000?oooooo`00
0?l000000_ooool2o`0000[ooooo1_l00008ooooo`;o00002_ooool8o`000003ooooool0003o0000
02?o000000?oooooo`000?l000001?ooool4o`0000;ooooo1?l00006ooooo`Co00001Oooool2o`00
00?ooooo0_l00002ooooo`;o00001?ooool2o`000003ooooool0003o000004Cooooo00001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`16
ooooo`;o00004_ooool3o`0000Sooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo0ol00002
ooooo`;o00003?ooool2o`000003ooooool0003o000000Oooooo0_l0000<oooooaKo000000?ooooo
o`000?l000004_l000001?oooooo0000o`000?l00004ooooo`Co000000?oooooo`000?l000000ol0
0006ooooo`;o00002_ooool4o`0000Gooooo0_l000001?oooooo0000o`000?ooool3o`0004?ooooo
00001_ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0
003oooooooooo`14ooooo`Co00000_ooool2o`0000?ooooo0_l00009ooooo`?o00002?ooool2o`00
017ooooo0ol00002ooooo`;o000000?oooooo`000?l000002Oooool2o`000003ooooool0003o0000
00Oooooo0_l0000<oooooaKo000000?oooooo`000?l000003?l000000ooooooo0000o`000007o`00
00Sooooo1Ol0000Cooooo`;o000000?oooooo`000?l000001?ooool4o`0000?ooooo0_l00013oooo
o`007?ooool00ol0003oooooooooo`0gooooo`;o00002oooool2o`0000Cooooo0_l00003ooooo`;o
00003oooool2o`0001Wooooo0_l000000ooooooo0000o`000002o`0000Sooooo0_l00002ooooo`;o
00001oooool2o`0000cooooo0_l00002ooooo`;o00001OoooolSo`0000Cooooo0_l00003ooooo`Co
00004?ooool2o`0000Gooooo0_l00003ooooo`;o000000?oooooo`000?l000001?ooool2o`0004;o
oooo000Looooo`03o`000?oooooooooo03Oooooo0ol0000Tooooo`Co00006Oooool2o`000003oooo
ool0003o000000[ooooo0_l0000;ooooo`;o00002?ooool2o`0000;ooooo0_l00002ooooo`;o0000
00?oooooo`000?l000006ol000000ooooooo0000o`000004o`0000;ooooo0_l00003ooooo`;o0000
0_ooool2o`000003ooooool0003o0000013ooooo0_l0000:ooooo`;o00001oooool2o`0004;ooooo
000Looooo`03o`000?oooooooooo02Oooooo0_l0000?ooooo`;o00005Oooool2o`0000Sooooo1?l0
00000ooooooo0000o`000006ooooo`;o00002_ooool2o`0001Kooooo0_l0000Dooooo`?o00002Ooo
ool?o`0000Gooooo2Ol00002ooooo`[o00000_ooool2o`0000;ooooo0_l0000Looooo`;o00001ooo
ool2o`000003ooooool0003o000004;ooooo000Looooo`03o`000?oooooooooo02Oooooo0_l0000V
ooooo`?o00001oooool4o`0000Wooooo0_l0000:ooooo`;o00002?ooool3o`0000?ooooo0_l00008
ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Kooooo0_l00003ooooo`;o00002?ooool2
o`0000?ooooo0_l000000ooooooo0000o`00000;o`000005ooooool0003o0000o`000?ooool01Ol0
0002ooooo`Oo000000?oooooo`000?l000000_ooool2o`00023ooooo0_l00007ooooo`;o00006?oo
ool2o`0002_ooooo000Looooo`03o`000?oooooooooo03Oooooo0_l0000Dooooo`;o000000?ooooo
o`000?l000001?ooool2o`00017ooooo1?l0000?ooooo`?o00000oooool2o`0000Cooooo0_l00002
ooooo`Go00000_ooool2o`0000Kooooo0_l0000:ooooo`;o000000?oooooo`000?l000001Oooool3
o`000003ooooool0003o000000?o000000?oooooo`000?l000000_l00002ooooo`;o00000_ooool6
o`0000?ooooo1?l00002ooooo`;o00005oooool2o`0000Cooooo0_l0000=ooooo`;o00003_ooool2
o`0000Sooooo0_l0000[ooooo`007?ooool00ol0003oooooooooo`0booooo`;o00000oooool2o`00
00cooooo1?l00004ooooo`;o000000?oooooo`000?l000001?ooool2o`00017ooooo1?l0000Boooo
o`?o00001_ooool2o`0000Cooooo0_l0000Gooooo`;o00000oooool2o`0000?ooooo0ol000000ooo
oooo0000o`000008o`0000Kooooo0_l00002ooooo`;o00002Oooool2o`0001Oooooo0_l00004oooo
o`;o00003Oooool2o`0000kooooo0_l0000eooooo`007?ooool00ol0003oooooooooo`0booooo`;o
00001_ooool3o`0000Sooooo1?l0000>ooooo`;o00009_ooool3o`0000;ooooo0ol00004ooooo`?o
00001_ooool2o`0001Gooooo0ol00003ooooo`?o000000?oooooo`000?l000001Ol000000ooooooo
0000o`000003ooooo`;o00001Oooool3o`0001kooooo0_l0000Aooooo`;o000000?oooooo`000?l0
0000Aoooool001cooooo00?o0000ooooooooool0>_ooool3o`0000Sooooo0_l0000@ooooo`;o0000
4oooool2o`0000;ooooo0_l0000Booooo`?o00001?ooool4o`0000Gooooo0_l0000;ooooo`?o0000
1oooool2o`000003ooooool0003o000000Kooooo0ol000000ooooooo0000o`000003o`0000?ooooo
0ol00004ooooo`?o00001Oooool2o`0000Cooooo0_l00008ooooo`Co00001Oooool2o`00017ooooo
0_l000000ooooooo0000o`000017ooooo`007?ooool00ol0003oooooooooo`0kooooo`;o00007Ooo
ool2o`0000Sooooo0_l00006ooooo`;o00000_ooool2o`0001[ooooo0ol00009ooooo`;o00001?oo
ool2o`000004ooooool0003o0000o`0000Kooooo0_l00002ooooo`Co00000oooool4o`000003oooo
ool0003o000000;o00001Oooool2o`000003ooooool0003o000000;ooooo0_l00005ooooo`;o0000
1?ooool2o`0000Cooooo0_l00002ooooo`Co0000I?ooool001cooooo00?o0000ooooooooool0>_oo
ool3o`0001Wooooo0_l00002ooooo`;o00002?ooool2o`0001Sooooo0_l0000:ooooo`;o000000Co
ooooo`000?l0003o00001oooool3o`0000Cooooo0_l00009ooooo`Go000000?oooooo`000?l00000
1_l00003ooooo`Go00001?ooool2o`000004ooooool0003o0000o`0000?ooooo0_l0000?ooooo`;o
00000_ooool2o`0000gooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`0jooooo`;o0000
6_ooool2o`00017ooooo0_l00009ooooo`;o00002?ooool2o`0000Wooooo0ol00002ooooo`;o0000
1oooool2o`00013ooooo1Ol00002ooooo`Oo00000oooool;o`0000;ooooo0_l00003ooooo`;o0000
1?ooool2o`0000;ooooo0_l00007ooooo`;o00003oooool2o`0000cooooo0_l00019ooooo`007?oo
ool2o`0006[ooooo0_l00009ooooo`;o00000oooool2o`0000Cooooo1?l00006ooooo`Go00007?oo
ool2o`000003ooooool0003o000000Oooooo1?l00003ooooo`So00000oooool2o`0000Sooooo0_l0
0002ooooo`;o00001oooool2o`0000oooooo0_l00005ooooo`;o00001Oooool3o`0004Sooooo000L
ooooo`03o`000?oooooooooo03Wooooo0_l0000looooo`Co00001?ooool6o`0000Oooooo0_l0000O
ooooo`;o00001oooool4o`0000?ooooo0ol00003ooooo`;o00000oooool2o`0000;ooooo0_l0000A
ooooo`;o00003oooool4o`0000?ooooo0_l00003ooooo`;o000000Coooooo`000?l0003o0000Aooo
ool001cooooo00?o0000ooooooooool0>Oooool2o`0000?ooooo0_l0000Hooooo`;o00006_ooool2
o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000003ooooo`;o00001_ooool2
o`0000Oooooo0_l0000Hooooo`?o00001?ooool2o`0000Oooooo0_l0000;ooooo`?o000000?ooooo
o`000?l000001?l0000:ooooo`;o000000?oooooo`000?l000003_ooool2o`0000Sooooo0_l00000
1?oooooo0000o`000?l00017ooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00000oooool2
o`0001Sooooo0_l0000;ooooo`;o00001?ooool2o`0000Oooooo0_l00002ooooo`Go000000?ooooo
o`000?l000000oooool2o`0000Kooooo1?l00005ooooo`;o000000?oooooo`000?l000005Oooool3
o`0000Cooooo0_l0000:ooooo`;o00002?ooool2o`0000;ooooo1_l00009ooooo`;o00000_ooool2
o`0000Gooooo0_l00007ooooo`;o00003oooool2o`0004Cooooo000Looooo`03o`000?oooooooooo
03Gooooo0_l0000Xooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`;o000000?oooooo`00
0?l000002Ol00004ooooo`;o00001_ooool5o`0000Oooooo0_l0000?ooooo`;o00001?ooool2o`00
00[ooooo0_l00005ooooo`Co00000oooool2o`000003ooooool0003o000000;ooooo1?l00004oooo
o`;o000000?oooooo`000?l000001_l00007ooooo`?o00000_ooool2o`0000gooooo0_l00004oooo
o`;o0000A?ooool001cooooo00?o0000ooooooooool0=Oooool2o`0002;ooooo0_l00004ooooo`;o
00003_oooolAo`000003ooooool0003o000000;ooooo0_l00004ooooo`Go00000oooool2o`0001?o
oooo1?l0000:ooooo`;o00000_ooool3o`0000Kooooo0_l00003ooooo`;o000000?oooooo`000?l0
00001?ooool4o`0000;ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00008ooooo`;o
00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`;o0000B_ooool001cooooo
00?o0000ooooooooool0DOooool2o`0000Kooooo0_l0000Dooooo`;o000000?oooooo`000?l00000
3?l000000ooooooo0000o`000002ooooo`;o00000oooool5o`0000Cooooo0_l00003ooooo`;o0000
2_ooool2o`0000Cooooo0_l0000:ooooo`?o00000_ooool2o`0000Gooooo0_l00002ooooo`;o0000
00?oooooo`000?l000000oooool2o`0000;ooooo0ol0000Oooooo`Go0000D?ooool001cooooo00?o
0000ooooooooool0=oooool2o`0001Sooooo0_l0000Kooooo`;o000000?oooooo`000?l000003Ol0
0004ooooo`;o00001?ooool2o`000003ooooool0003o000000Wooooo0_l00009ooooo`?o000000?o
ooooo`000?l000001oooool2o`0000Gooooo0_l00002ooooo`;o00001Oooool6o`000003ooooool0
003o000000?ooooo0_l0000Eooooo`;o000000?oooooo`000?l000001oooool2o`000003ooooool0
003o000000Go0000C_ooool001cooooo00?o0000ooooooooool0=_ooool3o`0001Cooooo0_l0000H
ooooo`;o00001Oooool2o`000003ooooool0003o0000013o000000?oooooo`000?l000000_l00002
ooooo`Co00002?ooool3o`0000[ooooo0_l00002ooooo`;o00001oooool2o`0000;ooooo0_l00003
ooooo`;o00002Oooool3o`0000Cooooo1_l00004ooooo`;o00003_ooool2o`000003ooooool0003o
000000;ooooo0_l00003ooooo`;o00001Oooool5o`0004cooooo000Looooo`03o`000?oooooooooo
03Kooooo0_l0000Eooooo`;o00006?ooool2o`0000Sooooo4_l00003ooooo`;o00001?ooool3o`00
00?ooooo0_l00002ooooo`?o00001oooool2o`0000oooooo0_l000000ooooooo0000o`000003oooo
o`;o00001_ooool2o`0000Sooooo1_l00004ooooo`Co00002_ooool2o`0000Oooooo0_l0000:oooo
o`Go0000C?ooool001cooooo00?o0000ooooooooool0G?ooool2o`0000kooooo5ol00003ooooo`;o
00001Oooool2o`0000?ooooo0_l00009ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Co
oooo0ol000000ooooooo0000o`000002ooooo`;o00002?ooool4o`0001Cooooo0_l0000:ooooo`;o
00001oooool2o`000003ooooool0003o000000?ooooo0_l00004ooooo`Co0000Boooool001cooooo
00?o0000ooooooooool0<?ooool2o`0002[ooooo1?l0000<oooooaOo00000oooool3o`0000;ooooo
0ol00004ooooo`;o00000oooool2o`0000Cooooo0_l00008ooooo`;o00001?ooool3o`000003oooo
ool0003o000000;ooooo0ol000000ooooooo0000o`000004ooooo`;o00001_ooool2o`0000Cooooo
0ol0000Oooooo`;o00000oooool3o`0000?ooooo1?l0001;ooooo`007?ooool00ol0003ooooooooo
o`0`ooooo`;o00002Oooool2o`0001[ooooo0_l00005ooooo`;o00003ooooolEo`0000?ooooo0_l0
0002ooooo`?o00001?ooool2o`0000?ooooo0_l00004ooooo`;o00004_ooool2o`0000?ooooo0_l0
00000ooooooo0000o`000007ooooo`;o00000oooool2o`0000Cooooo0ol0000Rooooo`;o000000Co
ooooo`000?l0003o0000DOooool001cooooo00?o0000ooooooooool0>oooool2o`0001[ooooo0ol0
0004ooooo`;o00003ooooolEo`0000Oooooo0_l00003ooooo`;o00000oooool2o`0000Kooooo0_l0
0004ooooo`Co00002_ooool2o`0000Cooooo0_l00007ooooo`Co00004Oooool4o`0000Cooooo0_l0
0004ooooo`;o00003Oooool2o`0000;ooooo1?l0001?ooooo`007?ooool00ol0003oooooooooo`10
ooooo`;o00005_ooool2o`00013ooooo0_l00003oooooaGo00001oooool2o`0000?ooooo0_l00003
ooooo`;o00002?ooool8o`0000[ooooo0_l00004ooooo`Co00001Oooool2o`0000cooooo0_l00005
ooooo`Co00001?ooool2o`0000Cooooo0_l0000Cooooo`;o0000Coooool001cooooo00?o0000oooo
ooooool0@?ooool2o`0002Sooooo0_l000000ooooooo0000o`000005o`0000;ooooo3ol00004oooo
o`Co00003oooool2o`000003ooooool0003o000000Co00003Oooool2o`0000Gooooo0_l000001?oo
oooo0000o`000?l00004ooooo`;o00001?ooool2o`0000?ooooo1?l0000Eooooo`;o00003oooool2
o`00017ooooo0_l0000looooo`007?ooool2o`0005Oooooo0_l0000Eooooo`;o000000?oooooo`00
0?l000000ol000000ooooooo0000o`00000>o`0000?ooooo1?l0000?ooooo`;o00000_ooool3o`00
00oooooo0_l00008ooooo`?o00001?ooool2o`0000Cooooo0_l00002ooooo`;o000000?oooooo`00
0?l000002?ooool2o`0000_ooooo0ol00005ooooo`;o000000?oooooo`000?l000001?ooool2o`00
017ooooo0_l0000looooo`007?ooool00ol0003oooooooooo`1Fooooo`;o00005OoooolIo`0000Co
oooo0ol0000;ooooo`;o00007?ooool2o`0000Cooooo0_l0000?ooooo`;o00002oooool2o`0000_o
oooo1?l00004ooooo`Oo00000_ooool2o`0004oooooo000Looooo`03o`000?oooooooooo05Oooooo
0_l00002ooooo`;o00003?ooool2o`0000;ooooo5ol0000Dooooo`;o00007?ooool2o`0000Gooooo
0_l0000>ooooo`;o00000_ooool2o`0000_ooooo0_l00009ooooo`;o00001_ooool2o`000003oooo
ool0003o000005?ooooo000Looooo`03o`000?oooooooooo05Oooooo0_l00002ooooo`;o00003?oo
ool2o`0000Cooooo5Ol0000:ooooo`;o00009?ooool2o`0000Oooooo0_l00009ooooo`;o00001?oo
ool2o`000003ooooool0003o000000Oooooo0_l00002ooooo`;o00002oooool2o`000003ooooool0
003o000005Wooooo000Looooo`03o`000?oooooooooo04[ooooo0_l00003ooooo`;o00007_oooolG
o`000003ooooool0003o000000Gooooo0_l0000:ooooo`;o00004oooool2o`0000?ooooo0_l00009
ooooo`;o00000oooool2o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l000001oooool2
o`0000oooooo0_l000000ooooooo0000o`000002o`0000Oooooo0_l0001>ooooo`007?ooool00ol0
003oooooooooo`1:ooooo`;o00000_ooool3o`0001kooooo5?l000000ooooooo0000o`000003o`00
017ooooo0_l00003ooooo`;o00003_ooool2o`0000?ooooo0_l00009ooooo`;o00000oooool4o`00
00Cooooo0_l00002ooooo`?o00002Oooool2o`00017ooooo0ol00007ooooo`;o0000C_ooool001co
oooo00?o0000ooooooooool0AOooool2o`0000Oooooo0_l0000Ooooooa;o00000_ooool5o`0000Go
oooo0ol00002ooooo`;o00002?ooool2o`000003ooooool0003o000001;ooooo1?l00006ooooo`;o
00001oooool2o`0000Cooooo0_l00002ooooo`;o00002?ooool4o`0006_ooooo000Looooo`03o`00
0?oooooooooo04Gooooo0_l00002ooooo`;o00009oooool?o`0000;ooooo1?l00006ooooo`?o0000
0_ooool2o`0000?ooooo0_l00003ooooo`Co00004oooool4o`0000Gooooo0ol00006ooooo`Co0000
2Oooool3o`0000Gooooo0_l00004ooooo`;o000000?oooooo`000?l000001oooool2o`0005_ooooo
000Looooo`03o`000?oooooooooo04Wooooo0_l0000Wooooo`go00006?ooool2o`0000Gooooo0_l0
000?ooooo`;o00002oooool2o`0000Oooooo1?l00009ooooo`?o00002oooool2o`000003ooooool0
003o000000Kooooo0ol0001Kooooo`007?ooool00ol0003oooooooooo`1booooo`Go000000?ooooo
o`000?l000001ol00009ooooo`;o00000oooool2o`0000Cooooo0_l000000ooooooo0000o`000004
ooooo`;o000000Coooooo`000?l0003o00000oooool2o`0000Kooooo0_l0000:ooooo`;o00002_oo
ool3o`0000Sooooo0_l00002ooooo`;o00001Oooool2o`0000Oooooo0_l00003ooooo`?o0000Fooo
ool001cooooo00?o0000ooooooooool0K_ooool2o`0000;ooooo2_l00003ooooo`;o00000oooool2
o`000004ooooool0003o0000ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`;o0000
00?oooooo`000?l000001?ooool6o`0000?ooooo0_l0000;ooooo`;o00001Oooool2o`0000Cooooo
0_l00005ooooo`?o00001Oooool8o`0000?ooooo1?l00005ooooo`Co000000?oooooo`000?l00000
0_l0001Looooo`007?ooool00ol0003oooooooooo`1Yooooo`;o000000?oooooo`000?l000000_l0
0004ooooo`Go00002oooool2o`000003ooooool0003o000000Wooooo0_l0000;ooooo`;o000000?o
ooooo`000?l000001?ooool4o`0000?ooooo0_l00003ooooo`?o00002_ooool3o`0000Gooooo0_l0
0005ooooo`;o00000_ooool2o`0000Gooooo0_l00007ooooo`;o00000oooool2o`0000cooooo0_l0
001@ooooo`007?ooool00ol0003oooooooooo`1Yooooo`Go00006oooool4o`0001Cooooo0ol00004
ooooo`Ko000000?oooooo`000?l000001?ooool4o`000003ooooool0003o000000?ooooo1Ol0000P
ooooo`;o00004Oooool2o`00053ooooo000Looooo`03o`000?oooooooooo06[ooooo0_l0000Koooo
o`Ko00002?ooool2o`0000Wooooo0ol00006ooooo`;o000000?oooooo`000?l000002Oooool2o`00
0003ooooool0003o000000?ooooo0_l00004ooooo`;o00005oooool2o`0000Cooooo0_l0001Soooo
o`007?ooool00ol0003oooooooooo`26ooooo`?o00000oooool3o`0000?ooooo0_l000000ooooooo
0000o`000002ooooo`;o00001Oooool2o`0000Oooooo0ol00003ooooo`;o00000oooool2o`0000?o
oooo0_l0000:ooooo`;o00004Oooool2o`0000Cooooo0_l00003ooooo`;o0000I?ooool001cooooo
00?o0000ooooooooool0FOooool2o`0001gooooo0_l0000<ooooo`Co000000?oooooo`000?l00000
0_l00002ooooo`?o00001Oooool2o`0000kooooo0ol00003ooooo`;o00000oooool2o`0000?ooooo
0_l0000Fooooo`;o00000_ooool2o`000003ooooool0003o000000?ooooo0_l00004ooooo`;o0000
00?oooooo`000?l000000_l0000Booooo`;o0000Boooool001cooooo0_l0001Jooooo`;o00007Ooo
ool2o`0000Cooooo0_l00008ooooo`;o000000?oooooo`000?l000001?ooool3o`0000;ooooo0_l0
000Booooo`;o00000_ooool2o`0000oooooo0_l00002ooooo`;o00001?ooool2o`0000Kooooo0_l0
0002ooooo`;o00001_ooool2o`0000Cooooo0_l000000ooooooo0000o`000002o`0001;ooooo0_l0
001;ooooo`007?ooool00ol0003oooooooooo`1nooooo`;o00005_ooool2o`0000[ooooo0_l00002
ooooo`?o000000?oooooo`000?l000000_ooool5o`0000?ooooo0_l00005ooooo`So00001?ooool2
o`0000Cooooo0_l00008ooooo`;o00000_ooool2o`0000Cooooo0_l0001Tooooo`007?ooool00ol0
003oooooooooo`28ooooo`Co000000?oooooo`000?l000003Oooool4o`0000;ooooo2Ol00003oooo
o`Go00000oooool5o`0000;ooooo0_l000000ooooooo0000o`000006o`0000Oooooo1?l00003oooo
o`Go0000K_ooool001cooooo00?o0000ooooooooool0G?ooool2o`0001Oooooo0_l0000Aooooo`Co
000000?oooooo`000?l000001Oooool3o`0000Gooooo1Ol00003ooooo`Oo00000oooool6o`0000?o
oooo1?l00009ooooo`Go00002?ooool2o`0000?ooooo0ol0001`ooooo`007?ooool00ol0003ooooo
ooooo`1Looooo`;o00003oooool2o`0000Kooooo0_l00003ooooo`;o00003?ooool2o`0000;ooooo
0ol00005ooooo`?o00002?ooool2o`0000Gooooo0_l000000ooooooo0000o`000003ooooo`Ko0000
0_ooool2o`0000_ooooo0ol000000ooooooo0000o`000004ooooo`;o00000_ooool2o`00013ooooo
0_l0001Tooooo`007?ooool00ol0003oooooooooo`1[ooooo`Co00002oooool2o`0000oooooo0ol0
000Kooooo`;o00002oooool4o`0000Sooooo1_l00005ooooo`Ko00004?ooool2o`0006Cooooo000L
ooooo`03o`000?oooooooooo06_ooooo0_l00007ooooo`;o00001?ooool2o`0000?ooooo0_l00006
ooooo`;o00000_ooool2o`0000kooooo0_l00005ooooo`;o00005?ooool2o`0000Sooooo0ol00000
1?oooooo0000o`000?l00004ooooo`Ko00003?ooool2o`0006Sooooo000Looooo`03o`000?oooooo
oooo05oooooo0_l0000;ooooo`;o00001_ooool5o`0000Kooooo0ol00005ooooo`;o00004_ooool2
o`0000Cooooo0ol0000>ooooo`;o000000?oooooo`000?l000002oooool3o`0000;ooooo1?l00000
1?oooooo0000o`000?l00002ooooo`;o00002?ooool3o`000003ooooool0003o000006Sooooo000L
ooooo`03o`000?oooooooooo05oooooo0_l0000;ooooo`;o000000?oooooo`000?l000001Oooool4
o`0000Kooooo0_l00009ooooo`;o00002Oooool2o`0000?ooooo1Ol000000ooooooo0000o`00000=
ooooo`Co000000?oooooo`000?l000002oooool2o`0000Gooooo0_l000001?oooooo0000o`000?oo
ool2o`0000Wooooo1?l0001[ooooo`007?ooool00ol0003oooooooooo`1Yooooo`;o000000Cooooo
o`000?l0003ooooo0_l00007ooooo`;o00001?ooool2o`0000[ooooo0ol00006ooooo`;o000000?o
ooooo`000?l000001?ooool4o`0000Gooooo0_l00009ooooo`;o00001_ooool2o`0001Gooooo1Ol0
0006ooooo`;o0000KOooool001cooooo00?o0000ooooooooool0JOooool2o`0001?ooooo0_l0000:
ooooo`;o00001oooool2o`0000Oooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003
ooooo`;o00000_ooool2o`000003ooooool0003o000000?o00005Oooool5o`000004ooooool0003o
0000o`00077ooooo000Looooo`03o`000?oooooooooo06Cooooo0_l0000;ooooo`;o00005oooool2
o`0000;ooooo0_l00004ooooo`;o00001_ooool6o`0000Gooooo1?l00003ooooo`;o00000_ooool2
o`000003ooooool0003o000000;o00001_ooool2o`0001?ooooo1?l00002ooooo`;o000000?ooooo
o`000?l000001?ooool2o`0006Cooooo000Looooo`03o`000?oooooooooo06Cooooo0_l0000;oooo
o`;o00001Oooool2o`0000gooooo0_l000000ooooooo0000o`000002ooooo`;o00001?ooool2o`00
0004ooooool0003o0000ooooo`;o00000_ooool2o`0000Oooooo0_l00004ooooo`?o00001Oooool2
o`0000Sooooo0_l0000Cooooo`;o00001?ooool2o`000003ooooool0003o000000Cooooo0_l0001T
ooooo`007?ooool00ol0003oooooooooo`1aooooo`;o00001Oooool2o`0000gooooo0_l00003oooo
o`;o00002?ooool3o`000003ooooool0003o0000017ooooo0ol00005ooooo`?o00001oooool2o`00
017ooooo0_l00005ooooo`;o0000K_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2
ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo06Oooooo0_l0
000:ooooo`;o000000Coooooo`000?l0003ooooo0_l00006ooooo`;o00002?ooool3o`0000?ooooo
0_l00003ooooo`;o00000_ooool2o`0000Cooooo0ol00008ooooo`;o00002Oooool2o`0000Oooooo
0_l0000Aooooo`;o00000_ooool2o`000003ooooool0003o000000Ko0000J?ooool00006oooooomg
MgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06oooo
o`03o`000?oooooooooo06Oooooo0_l0000:ooooo`;o000000Coooooo`000?l0003ooooo0_l00006
ooooo`;o00002?ooool4o`0000;ooooo0_l00007ooooo`Wo00001_ooool4o`0000Gooooo0_l0000?
ooooo`;o00004Oooool2o`0000?ooooo1_l0001Xooooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`2=
ooooo`;o00000_ooool2o`0000Oooooo1_l00009ooooo`;o00000oooool2o`000005ooooool0003o
0000o`000?ooool01_l00008ooooo`;o00005oooool2o`0006_ooooo00000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000TOoo
ool2o`0000;ooooo0_l00004ooooo`?o00004?ooool2o`000003ooooool0003o000000;ooooo1_l0
0003ooooo`;o00005_ooool3o`00073ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo00Wooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo06Wooooo0_l0
000;ooooo`;o00006Oooool2o`0000;ooooo0_l00003ooooo`Go00002_ooool3o`0000_ooooo0_l0
0005ooooo`;o00002Oooool3o`0000[ooooo0ol0000?ooooo`;o0000Goooool00003ooooool@413o
oooo00;ooooo00?o410@ooooooooool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o
0000ooooooooool0JOooool2o`0000_ooooo0_l0000Gooooo`Co00001_ooool3o`000003ooooool0
003o000000[ooooo1Ol0000=ooooo`;o00002_ooool5o`0000?ooooo0_l000000ooooooo0000o`00
000Dooooo`;o0000Goooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zj
oooooonj^[[o000000Kooooo00?o0000ooooooooool0Soooool4o`0000Kooooo0_l0000Aooooo`;o
00001oooool2o`0000Cooooo0_l0000:ooooo`;o00001?ooool7o`0007Gooooo00001_ooooook^k^
oc8b<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooo
oooo067ooooo0_l0000^ooooo`;o00002oooool2o`0000oooooo0_l00004ooooo`Co00005?ooool2
o`000003ooooool0003o000007Oooooo000Looooo`03o`000?oooooooooo067ooooo0_l0000=oooo
o`;o00006Oooool2o`00013ooooo0ol0000?ooooo`?o00001Oooool2o`0000Gooooo1?l00008oooo
o`;o000000?oooooo`000?l00000N_ooool001cooooo00?o0000ooooooooool0L?ooool2o`0001Wo
oooo0_l00005ooooo`;o00002Oooool2o`0000[ooooo0_l000000ooooooo0000o`000002ooooo`;o
00003?ooool4o`0000Sooooo0ol0001looooo`007?ooool00ol0003oooooooooo`2Booooo`;o0000
4Oooool2o`0000;ooooo0_l000000ooooooo0000o`000008ooooo`;o00001_ooool2o`0000Oooooo
0_l00002ooooo`;o0000O?ooool001cooooo00?o0000ooooooooool0M?ooool2o`0002;ooooo0_l0
000;ooooo`;o00002?ooool3o`0000Cooooo0_l0000?ooooo`;o0000P?ooool001cooooo00?o0000
ooooooooool0M?ooool2o`00027ooooo0ol0000Eooooo`?o0000Uoooool001cooooo00?o0000oooo
ooooool0Uoooool2o`0000kooooo0_l0000=ooooo`;o0000TOooool001cooooo00?o0000oooooooo
ool0Yoooool2o`0000gooooo0_l00007ooooo`;o00003Oooool2o`0007Wooooo000Looooo`03o`00
0?oooooooooo09[ooooo0ol0000>ooooo`;o00004_ooool3o`0000cooooo0_l00004ooooo`;o0000
Loooool001cooooo00?o0000ooooooooool0V_ooool3o`0000[ooooo0ol000000ooooooo0000o`00
0004ooooo`;o00003Oooool2o`0001;ooooo0_l0001cooooo`007?ooool00ol0003oooooooooo`2K
ooooo`?o00002Oooool3o`0000;ooooo0_l00003ooooo`;o0000U_ooool001cooooo00?o0000oooo
ooooool0T_ooool2o`0000Cooooo0_l000001?oooooo0000o`000?l0000;ooooo`;o000000?ooooo
o`000?l000002oooool2o`0000cooooo0_l00020ooooo`007?ooool2o`0009?ooooo0_l00004oooo
o`;o00003oooool2o`000003ooooool0003o000000_ooooo0_l0000<ooooo`;o0000P?ooool001co
oooo00?o0000ooooooooool0Y_ooool2o`000:7ooooo000Looooo`03o`000?oooooooooo0:Kooooo
0_l0002Qooooo`007?ooool00ol0003oooooooooo`2Cooooo`;o00008_ooool2o`00093ooooo000L
ooooo`03o`000?oooooooooo09?ooooo0_l0000Rooooo`;o0000T?ooool001cooooo00?o0000oooo
ooooool0__ooool2o`0008Wooooo000Looooo`03o`000?oooooooooo08Wooooo0_l0000?ooooo`;o
00008_ooool2o`0008Wooooo000Looooo`03o`000?oooooooooo08Wooooo0_l0000?ooooo`;o0000
3_ooool2o`0009gooooo000Looooo`03o`000?oooooooooo09Oooooo0_l0000Aooooo`;o0000WOoo
ool001cooooo00?o0000ooooooooool0Uoooool2o`000;3ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o
0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?o
oooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool3o`000?ooooooB_oo
ool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooo
oe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0
oooooomBooooo`004_ooool00omEEEGoIVIVo`00003ooooooeCooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo002Uooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@oooooooo
ool05Oooool01?l@413o0000odA4A?o<c<`6ooooo`03o`000?o^k^kooooo00?ooooo1Ol0002@oooo
o`00Y_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l0000;ooooo`03oiRHV?l@413ogMgM
00Gooooo00?oEEEEojVYZOooool00oooool01OnHV9So8B4Qonk^k_ooooooA4A4093ooooo002Voooo
o`05o`000?ooooooooooooooool000006oooool00on7QhOoEEEEooooo`04ooooo`03ojVYZOmEEEGo
oooo00Cooooo00?oV9RHob4Q8Oo^k^h0TOooool00:Kooooo00Go0000ooooooooooooooooo`000009
ooooo`Ko00002Oooool01Oo<c<co8B4Qo`000?mEEEGo000000Kooooo00?o8B4Qooooooooool01?oo
ool00onHV9So8B4Qonk^kP2@ooooo`00Y_ooool01Ol0003oQhN7oooooonYZJWo000001Sooooo00Go
8B4QohN7QoooooooV9RHo`000006ooooo`03oeEEEOo<c<cooooo00Gooooo00?oMgMgofIVI_ooool0
Soooool00:Gooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Fooooo`05o`000?oo
ooooooooooooool000001_ooool00onYZJWoMgMgooooo`06ooooo`03o`000?oooooooooo08kooooo
0033ooooo`05ob4Q8OnHV9SoooooogMgMomEEED00oooool01Ol@413ooooooooooooooooo<S8b00?o
oooo00Go0000okZj^_ooooooV9RHoa0@402@ooooo`00`oooool01Oo<c<co410@o`000?lb<S;ok^k^
00?ooooo1Ol00003ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0T?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(978) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.66726 .39043 Mdot
.61769 .39895 Mdot
.34866 .55065 Mdot
.57325 .55568 Mdot
.66343 .32004 Mdot
.34279 .49401 Mdot
.44085 .34999 Mdot
.46665 .30222 Mdot
.34664 .5129 Mdot
.50439 .50686 Mdot
.467 .33183 Mdot
.50292 .582 Mdot
.45205 .31741 Mdot
.57683 .57155 Mdot
.66617 .81277 Mdot
.61379 .53892 Mdot
.60223 .4131 Mdot
.34942 .70789 Mdot
.51361 .56988 Mdot
.35656 .55919 Mdot
.64216 .43922 Mdot
.56705 .56408 Mdot
.66325 .38754 Mdot
.5765 .5719 Mdot
.5951 .55898 Mdot
.63839 .40862 Mdot
.68322 .3807 Mdot
.57895 .54319 Mdot
.60726 .59913 Mdot
.44281 .30468 Mdot
.45657 .76466 Mdot
.75418 .72574 Mdot
.5688 .51401 Mdot
.5795 .19108 Mdot
.47414 .30644 Mdot
.75493 .63799 Mdot
.36024 .47661 Mdot
.43128 .32077 Mdot
.47132 .30653 Mdot
.44394 .29402 Mdot
.44743 .30993 Mdot
.63516 .40405 Mdot
.49058 .29351 Mdot
.43015 .26449 Mdot
.53781 .62368 Mdot
.56155 .30892 Mdot
.60685 .73612 Mdot
.5588 .61568 Mdot
.60975 .41847 Mdot
.35141 .5633 Mdot
.5606 .19858 Mdot
.41835 .32879 Mdot
.38985 .42209 Mdot
.88652 .4155 Mdot
.42865 .33176 Mdot
.52802 .61737 Mdot
.35738 .50684 Mdot
.55574 .57056 Mdot
.57167 .57317 Mdot
.68388 .63923 Mdot
.60161 .54643 Mdot
.34971 .68806 Mdot
.59192 .42278 Mdot
.36447 .59648 Mdot
.34844 .49577 Mdot
.46976 .30864 Mdot
.60538 .39344 Mdot
.4475 .32342 Mdot
.5387 .64446 Mdot
.33166 .48408 Mdot
.55787 .6146 Mdot
.46644 .31177 Mdot
.62921 .35666 Mdot
.54482 .60203 Mdot
.28642 .30136 Mdot
.51252 .8473 Mdot
.38274 .6599 Mdot
.70767 .62546 Mdot
.68705 .67481 Mdot
.30282 .62421 Mdot
.59789 .60005 Mdot
.23506 .6842 Mdot
.61642 .82492 Mdot
.6644 .39801 Mdot
.62702 .5451 Mdot
.31523 .5041 Mdot
.54099 .59506 Mdot
.54022 .39436 Mdot
.55275 .63944 Mdot
.38372 .22914 Mdot
.3463 .5213 Mdot
.63407 .38015 Mdot
.57518 .55719 Mdot
.61708 .58144 Mdot
.68072 .48649 Mdot
.5704 .53544 Mdot
.56532 .54676 Mdot
.67333 .37203 Mdot
.46815 .34083 Mdot
.49657 .58394 Mdot
.45805 .27593 Mdot
.37258 .43564 Mdot
.52806 .59809 Mdot
.36301 .50642 Mdot
.66435 .36149 Mdot
.53641 .59653 Mdot
.47713 .34325 Mdot
.5787 .62207 Mdot
.41878 .26272 Mdot
.61377 .3983 Mdot
.61687 .58661 Mdot
.33293 .66334 Mdot
.20647 .41523 Mdot
.63551 .37647 Mdot
.37704 .54863 Mdot
.59081 .62121 Mdot
.54699 .56058 Mdot
.62068 .39814 Mdot
.32389 .53589 Mdot
.55482 .45238 Mdot
.62523 .43157 Mdot
.45689 .29271 Mdot
.6096 .43193 Mdot
.61953 .5349 Mdot
.34003 .51337 Mdot
.37951 .41041 Mdot
.38691 .40488 Mdot
.42666 .72771 Mdot
.54007 .58917 Mdot
.55649 .2366 Mdot
.33309 .50613 Mdot
.63444 .38741 Mdot
.451 .32446 Mdot
.60842 .64873 Mdot
.6275 .36804 Mdot
.45244 .34012 Mdot
.35974 .64802 Mdot
.32117 .41533 Mdot
.61748 .42673 Mdot
.43584 .2529 Mdot
.41235 .32938 Mdot
.4398 .29401 Mdot
.55672 .18379 Mdot
.61514 .40547 Mdot
.35007 .66038 Mdot
.44649 .33821 Mdot
.53871 .76858 Mdot
.52982 .62662 Mdot
.42303 .6602 Mdot
.16893 .60475 Mdot
.53731 .19024 Mdot
.32646 .34373 Mdot
.34299 .70192 Mdot
.42859 .29933 Mdot
.60703 .57377 Mdot
.62056 .41696 Mdot
.62451 .41163 Mdot
.54493 .54752 Mdot
.58476 .55343 Mdot
.55282 .61147 Mdot
.61516 .59156 Mdot
.63448 .75203 Mdot
.57233 .62925 Mdot
.3398 .754 Mdot
.6432 .37975 Mdot
.59946 .5527 Mdot
.33531 .56481 Mdot
.59486 .64187 Mdot
.45671 .30772 Mdot
.55721 .56407 Mdot
.57372 .55301 Mdot
.61765 .56791 Mdot
.42998 .34663 Mdot
.7482 .71461 Mdot
.16364 .55292 Mdot
.81974 .54944 Mdot
.38634 .4736 Mdot
.35181 .47215 Mdot
.5356 .58111 Mdot
.35719 .67366 Mdot
.76237 .5996 Mdot
.59221 .59211 Mdot
.31059 .21953 Mdot
.56428 .54974 Mdot
.71098 .33527 Mdot
.60878 .68949 Mdot
.82743 .53131 Mdot
.3894 .71288 Mdot
.61128 .59216 Mdot
.70852 .44884 Mdot
.77089 .40964 Mdot
.39759 .33583 Mdot
.44449 .31258 Mdot
.33497 .56273 Mdot
.35695 .52109 Mdot
.42265 .36342 Mdot
.50167 .62844 Mdot
.55633 .67155 Mdot
.57231 .664 Mdot
.38319 .42051 Mdot
.58262 .3988 Mdot
.37535 .682 Mdot
.6649 .36508 Mdot
.32772 .80163 Mdot
.444 .2344 Mdot
.46561 .26641 Mdot
.37307 .64816 Mdot
.33881 .54801 Mdot
.38343 .42377 Mdot
.36147 .66949 Mdot
.57432 .60652 Mdot
.60723 .40134 Mdot
.69734 .26282 Mdot
.52764 .66746 Mdot
.68657 .23516 Mdot
.60158 .37871 Mdot
.5403 .44422 Mdot
.45951 .33163 Mdot
.37171 .46758 Mdot
.54957 .55695 Mdot
.5615 .59622 Mdot
.61935 .44642 Mdot
.55869 .61251 Mdot
.69232 .34709 Mdot
.54942 .55249 Mdot
.36364 .40647 Mdot
.38396 .66272 Mdot
.4259 .36525 Mdot
.41767 .72665 Mdot
.6528 .36563 Mdot
.39722 .68704 Mdot
.32701 .55987 Mdot
.7406 .63818 Mdot
.46985 .31644 Mdot
.33915 .65483 Mdot
.32223 .54518 Mdot
.37134 .69016 Mdot
.58751 .63968 Mdot
.35452 .46086 Mdot
.3365 .68707 Mdot
.6853 .74643 Mdot
.57137 .64533 Mdot
.62022 .7707 Mdot
.44518 .35176 Mdot
.60762 .43023 Mdot
.59811 .54495 Mdot
.37313 .47947 Mdot
.58105 .51794 Mdot
.31279 .30856 Mdot
.38997 .39943 Mdot
.38835 .43008 Mdot
.32643 .62313 Mdot
.33608 .66225 Mdot
.27501 .3544 Mdot
.53878 .22207 Mdot
.6022 .40988 Mdot
.52113 .58242 Mdot
.81149 .60703 Mdot
.44703 .33763 Mdot
.57935 .60644 Mdot
.34233 .44598 Mdot
.44435 .33683 Mdot
.55359 .57265 Mdot
.44622 .35637 Mdot
.62006 .41189 Mdot
.21389 .53816 Mdot
.60071 .41076 Mdot
.56347 .64202 Mdot
.46822 .35354 Mdot
.34023 .4761 Mdot
.64053 .41032 Mdot
.57585 .61989 Mdot
.53516 .56402 Mdot
.37734 .42122 Mdot
.60797 .55934 Mdot
.78635 .63818 Mdot
.61234 .56066 Mdot
.35428 .54582 Mdot
.57766 .5363 Mdot
.38764 .18994 Mdot
.28061 .44965 Mdot
.60537 .39469 Mdot
.38621 .43406 Mdot
.35012 .51118 Mdot
.26927 .5868 Mdot
.40454 .41403 Mdot
.59172 .61388 Mdot
.37577 .45126 Mdot
.41693 .64059 Mdot
.42452 .32137 Mdot
.53057 .54728 Mdot
.48809 .26483 Mdot
.34214 .5716 Mdot
.38114 .42392 Mdot
.62301 .65437 Mdot
.65785 .35561 Mdot
.57623 .55655 Mdot
.33706 .47733 Mdot
.61793 .43608 Mdot
.56515 .63916 Mdot
.50673 .68053 Mdot
.38977 .40468 Mdot
.43986 .34731 Mdot
.61866 .67495 Mdot
.56033 .62221 Mdot
.35954 .48581 Mdot
.63592 .36032 Mdot
.47461 .30393 Mdot
.64313 .3996 Mdot
.74214 .33851 Mdot
.3791 .35288 Mdot
.66704 .73325 Mdot
.33987 .63771 Mdot
.34998 .30122 Mdot
.83064 .50115 Mdot
.24105 .39076 Mdot
.50671 .73995 Mdot
.78281 .35537 Mdot
.32256 .53932 Mdot
.3511 .42224 Mdot
.35331 .51018 Mdot
.59832 .57698 Mdot
.34523 .49481 Mdot
.83285 .51882 Mdot
.55347 .55067 Mdot
.35602 .47451 Mdot
.23263 .56277 Mdot
.58685 .55018 Mdot
.63458 .37465 Mdot
.65978 .80981 Mdot
.26846 .30083 Mdot
.47089 .21277 Mdot
.33821 .48785 Mdot
.64522 .66256 Mdot
.58083 .54462 Mdot
.62154 .57033 Mdot
.63209 .41981 Mdot
.54806 .54033 Mdot
.37375 .68394 Mdot
.3746 .65206 Mdot
.43086 .60182 Mdot
.18226 .57795 Mdot
.49753 .58282 Mdot
.63864 .41307 Mdot
.65916 .69569 Mdot
.31086 .27802 Mdot
.37366 .51885 Mdot
.48118 .29393 Mdot
.73128 .72842 Mdot
.5211 .65255 Mdot
.495 .29593 Mdot
.45958 .25018 Mdot
.62031 .38538 Mdot
.75493 .69346 Mdot
.43781 .31806 Mdot
.7397 .46933 Mdot
.6492 .48367 Mdot
.56826 .59908 Mdot
.47159 .32518 Mdot
.501 .57938 Mdot
.35196 .22563 Mdot
.54367 .78712 Mdot
.3113 .74595 Mdot
.55088 .63374 Mdot
.26567 .34384 Mdot
.55309 .56129 Mdot
.56797 .46125 Mdot
.61142 .55764 Mdot
.64813 .39846 Mdot
.50415 .51554 Mdot
.46285 .41773 Mdot
.17812 .60845 Mdot
.44903 .23136 Mdot
.34486 .70211 Mdot
.5424 .55986 Mdot
.56775 .59777 Mdot
.35615 .65327 Mdot
.65814 .38618 Mdot
.61434 .59069 Mdot
.45208 .66376 Mdot
.55433 .60428 Mdot
.44243 .31088 Mdot
.39966 .74916 Mdot
.67535 .41725 Mdot
.60828 .54247 Mdot
.63309 .43598 Mdot
.43046 .34341 Mdot
.46464 .3032 Mdot
.6266 .6442 Mdot
.47857 .30093 Mdot
.56466 .5528 Mdot
.45249 .80179 Mdot
.65716 .40991 Mdot
.57101 .68998 Mdot
.65303 .37281 Mdot
.7085 .64472 Mdot
.47612 .34665 Mdot
.37527 .40925 Mdot
.63933 .45924 Mdot
.4412 .3172 Mdot
.49857 .2113 Mdot
.54953 .6587 Mdot
.56051 .52624 Mdot
.40299 .21961 Mdot
.33365 .49403 Mdot
.38678 .40996 Mdot
.48215 .32706 Mdot
.55779 .62022 Mdot
.54441 .53769 Mdot
.42329 .33707 Mdot
.70417 .49972 Mdot
.27175 .57205 Mdot
.57285 .54394 Mdot
.65289 .39566 Mdot
.63611 .38874 Mdot
.54936 .62543 Mdot
.58342 .61456 Mdot
.33888 .53951 Mdot
.38251 .43727 Mdot
.37511 .48123 Mdot
.38796 .40669 Mdot
.36511 .41879 Mdot
.61611 .29868 Mdot
.44344 .2938 Mdot
.58161 .25558 Mdot
.36534 .24658 Mdot
.52967 .52169 Mdot
.35469 .46538 Mdot
.56849 .58977 Mdot
.57026 .55805 Mdot
.47504 .30391 Mdot
.37883 .32841 Mdot
.6188 .5302 Mdot
.63834 .42382 Mdot
.48308 .32829 Mdot
.51396 .63478 Mdot
.63479 .27128 Mdot
.34392 .69182 Mdot
.45781 .20815 Mdot
.46896 .31234 Mdot
.62059 .38058 Mdot
.44555 .36028 Mdot
.56164 .59901 Mdot
.5178 .59856 Mdot
.62304 .39146 Mdot
.3308 .67806 Mdot
.58098 .65728 Mdot
.55095 .57196 Mdot
.16122 .39803 Mdot
.27516 .31118 Mdot
.49529 .37548 Mdot
.61066 .58105 Mdot
.56325 .53169 Mdot
.36062 .70275 Mdot
.55779 .60294 Mdot
.53064 .56789 Mdot
.18722 .44478 Mdot
.51733 .36363 Mdot
.35427 .70943 Mdot
.74387 .47452 Mdot
.59959 .38115 Mdot
.78684 .66286 Mdot
.37458 .46607 Mdot
.46429 .36878 Mdot
.22357 .50453 Mdot
.38214 .42932 Mdot
.32378 .3 Mdot
.77261 .68113 Mdot
.38784 .408 Mdot
.37713 .61308 Mdot
.58088 .49345 Mdot
.55812 .54509 Mdot
.54792 .56394 Mdot
.35261 .67044 Mdot
.61586 .40807 Mdot
.43806 .56871 Mdot
.55163 .80681 Mdot
.56115 .56102 Mdot
.68226 .34439 Mdot
.68802 .75475 Mdot
.3776 .42531 Mdot
.37265 .68073 Mdot
.34365 .64559 Mdot
.54184 .56282 Mdot
.19605 .4574 Mdot
.637 .41034 Mdot
.57643 .61971 Mdot
.57868 .63162 Mdot
.34115 .48152 Mdot
.6105 .39152 Mdot
.32011 .53151 Mdot
.38839 .39717 Mdot
.78974 .42172 Mdot
.17204 .36531 Mdot
.47948 .31628 Mdot
.7779 .63016 Mdot
.43043 .31248 Mdot
.31265 .73749 Mdot
.38647 .42591 Mdot
.59486 .59819 Mdot
.64534 .36059 Mdot
.57606 .62246 Mdot
.58192 .59894 Mdot
.57422 .60525 Mdot
.52203 .6365 Mdot
.32841 .21096 Mdot
.36291 .68089 Mdot
.62337 .55341 Mdot
.35327 .54481 Mdot
.77757 .63929 Mdot
.56905 .82702 Mdot
.56048 .58944 Mdot
.53367 .56984 Mdot
.63335 .37157 Mdot
.54321 .54689 Mdot
.42437 .32487 Mdot
.63503 .36001 Mdot
.61751 .59046 Mdot
.74481 .69403 Mdot
.60867 .60517 Mdot
.8227 .52019 Mdot
.44532 .36069 Mdot
.49668 .21393 Mdot
.62837 .5812 Mdot
.38427 .40509 Mdot
.38695 .40977 Mdot
.37898 .45807 Mdot
.46898 .36193 Mdot
.35825 .47923 Mdot
.49061 .823 Mdot
.53245 .52603 Mdot
.60448 .56925 Mdot
.54016 .53882 Mdot
.36441 .45769 Mdot
.54399 .38832 Mdot
.29036 .35815 Mdot
.52521 .64753 Mdot
.33395 .52726 Mdot
.60972 .43325 Mdot
.39553 .57745 Mdot
.64595 .36323 Mdot
.36563 .70821 Mdot
.46713 .32913 Mdot
.35302 .69578 Mdot
.51958 .19547 Mdot
.61581 .39785 Mdot
.61943 .44699 Mdot
.35334 .47162 Mdot
.52179 .43085 Mdot
.87389 .4233 Mdot
.33046 .48424 Mdot
.44582 .70191 Mdot
.64007 .41692 Mdot
.58971 .62848 Mdot
.38803 .72537 Mdot
.52692 .42631 Mdot
.3553 .48517 Mdot
.59418 .58482 Mdot
.19953 .49954 Mdot
.33772 .53857 Mdot
.5285 .54844 Mdot
.32569 .53475 Mdot
.46038 .3112 Mdot
.32901 .51508 Mdot
.59662 .37585 Mdot
.53508 .59244 Mdot
.87982 .44214 Mdot
.37827 .71478 Mdot
.61178 .56216 Mdot
.48247 .33262 Mdot
.45471 .63352 Mdot
.57804 .58899 Mdot
.37733 .66479 Mdot
.3383 .51532 Mdot
.28137 .5402 Mdot
.58571 .54399 Mdot
.34429 .48544 Mdot
.66532 .38672 Mdot
.46496 .36426 Mdot
.30477 .70283 Mdot
.37297 .41809 Mdot
.62692 .42119 Mdot
.38477 .38632 Mdot
.48637 .33314 Mdot
.5621 .5334 Mdot
.56872 .62965 Mdot
.6474 .38914 Mdot
.20763 .58202 Mdot
.58485 .53851 Mdot
.59788 .59966 Mdot
.34717 .55499 Mdot
.36508 .46676 Mdot
.21417 .57994 Mdot
.32245 .52793 Mdot
.51282 .58373 Mdot
.64711 .39044 Mdot
.58138 .56357 Mdot
.62539 .37361 Mdot
.52765 .56679 Mdot
.61559 .34585 Mdot
.66235 .40181 Mdot
.25782 .40087 Mdot
.58929 .57376 Mdot
.60914 .68629 Mdot
.57787 .60205 Mdot
.556 .60969 Mdot
.34458 .5404 Mdot
.37002 .67228 Mdot
.62264 .63189 Mdot
.31484 .69246 Mdot
.37516 .66622 Mdot
.75091 .37924 Mdot
.33628 .49047 Mdot
.3434 .67405 Mdot
.63743 .7667 Mdot
.38317 .44122 Mdot
.35457 .68011 Mdot
.59642 .82001 Mdot
.47856 .31244 Mdot
.59479 .3948 Mdot
.58749 .55076 Mdot
.77143 .34343 Mdot
.47337 .79118 Mdot
.37456 .43764 Mdot
.61311 .56481 Mdot
.57117 .58856 Mdot
.64763 .423 Mdot
.29119 .7594 Mdot
.35833 .54512 Mdot
.59816 .57204 Mdot
.60599 .38864 Mdot
.19115 .67153 Mdot
.35867 .53303 Mdot
.35457 .67632 Mdot
.42405 .34156 Mdot
.64145 .34522 Mdot
.37192 .42628 Mdot
.42087 .33477 Mdot
.27252 .40062 Mdot
.49798 .20501 Mdot
.59029 .62194 Mdot
.35559 .46446 Mdot
.50724 .18312 Mdot
.49341 .59294 Mdot
.46805 .37959 Mdot
.64571 .55408 Mdot
.62262 .38276 Mdot
.42492 .33102 Mdot
.35055 .69894 Mdot
.61744 .36223 Mdot
.65777 .3911 Mdot
.46431 .29952 Mdot
.38386 .60437 Mdot
.53781 .44101 Mdot
.44889 .30619 Mdot
.38665 .23127 Mdot
.71697 .30571 Mdot
.37916 .44517 Mdot
.3718 .66165 Mdot
.67033 .25282 Mdot
.63607 .40385 Mdot
.73426 .72549 Mdot
.46524 .19854 Mdot
.56584 .54662 Mdot
.341 .66887 Mdot
.55809 .3352 Mdot
.52176 .82043 Mdot
.44176 .33781 Mdot
.47435 .40684 Mdot
.3275 .66441 Mdot
.57001 .54137 Mdot
.66301 .59886 Mdot
.59893 .58424 Mdot
.46284 .33283 Mdot
.68082 .67331 Mdot
.62062 .37965 Mdot
.48514 .32702 Mdot
.45956 .20753 Mdot
.56315 .55575 Mdot
.5939 .58088 Mdot
.43334 .75519 Mdot
.60671 .40792 Mdot
.37423 .47744 Mdot
.59164 .61771 Mdot
.55333 .56823 Mdot
.57593 .52365 Mdot
.59646 .68176 Mdot
.20405 .42433 Mdot
.5969 .5725 Mdot
.36558 .38691 Mdot
.61419 .54575 Mdot
.58666 .57371 Mdot
.63098 .43572 Mdot
.20174 .32943 Mdot
.37591 .40672 Mdot
.55544 .56499 Mdot
.59673 .61824 Mdot
.46904 .30012 Mdot
.49389 .49971 Mdot
.52344 .42011 Mdot
.34582 .45762 Mdot
.53996 .74419 Mdot
.52051 .63453 Mdot
.62103 .3679 Mdot
.3356 .65675 Mdot
.55285 .62539 Mdot
.61847 .36997 Mdot
.60968 .62168 Mdot
.33459 .5344 Mdot
.37999 .44215 Mdot
.48035 .22582 Mdot
.34824 .67997 Mdot
.45178 .78429 Mdot
.57526 .26519 Mdot
.33755 .5608 Mdot
.6013 .56338 Mdot
.43586 .36766 Mdot
.35019 .45825 Mdot
.3767 .41997 Mdot
.6369 .6299 Mdot
.62717 .41425 Mdot
.63583 .37864 Mdot
.42096 .65835 Mdot
.32645 .38236 Mdot
.16472 .44238 Mdot
.46264 .31307 Mdot
.61969 .59076 Mdot
.54227 .22816 Mdot
.63534 .3775 Mdot
.40724 .70217 Mdot
.34262 .67592 Mdot
.44079 .33913 Mdot
.37562 .50686 Mdot
.62706 .36952 Mdot
.61066 .42284 Mdot
.56909 .64368 Mdot
.55073 .58231 Mdot
.4942 .73353 Mdot
.42508 .63167 Mdot
.42712 .33981 Mdot
.36255 .6541 Mdot
.31903 .53496 Mdot
.60254 .58329 Mdot
.6651 .39527 Mdot
.70107 .27761 Mdot
.5934 .62209 Mdot
.34067 .54247 Mdot
.62534 .38384 Mdot
.34934 .65319 Mdot
.3768 .66788 Mdot
.55613 .60868 Mdot
.67295 .6572 Mdot
.43316 .33171 Mdot
.63283 .37521 Mdot
.62328 .23849 Mdot
.58642 .53735 Mdot
.54605 .58223 Mdot
.64516 .63488 Mdot
.44842 .29993 Mdot
.50147 .21716 Mdot
.32888 .6785 Mdot
.62639 .40477 Mdot
.61064 .59832 Mdot
.34862 .68687 Mdot
.52213 .21772 Mdot
.37902 .4358 Mdot
.32691 .52438 Mdot
.3776 .66643 Mdot
.34933 .65696 Mdot
.36841 .65346 Mdot
.72348 .73831 Mdot
.59724 .37324 Mdot
.56322 .69343 Mdot
.60417 .54538 Mdot
.41899 .66491 Mdot
.60265 .65304 Mdot
.44356 .36194 Mdot
.3303 .49988 Mdot
.57851 .59828 Mdot
.56521 .64166 Mdot
.62961 .66329 Mdot
.58946 .69144 Mdot
.67916 .40594 Mdot
.61222 .39636 Mdot
.54161 .51597 Mdot
.3421 .47792 Mdot
.30607 .78763 Mdot
.85567 .4799 Mdot
.63095 .58265 Mdot
.53144 .45337 Mdot
.66327 .38999 Mdot
.45308 .29631 Mdot
.50727 .41509 Mdot
.4499 .35905 Mdot
.62978 .39895 Mdot
.60088 .57996 Mdot
.5887 .26046 Mdot
.37715 .68563 Mdot
.55403 .61613 Mdot
.45442 .33457 Mdot
.55333 .61404 Mdot
.42206 .33717 Mdot
.69014 .31825 Mdot
.35961 .23655 Mdot
.56393 .54946 Mdot
.58556 .53266 Mdot
.65771 .60347 Mdot
.5612 .58752 Mdot
.25738 .67537 Mdot
.65986 .38413 Mdot
.18322 .53627 Mdot
.57317 .64374 Mdot
.739 .58252 Mdot
.59701 .54052 Mdot
.20877 .51109 Mdot
.54774 .58742 Mdot
.44973 .44508 Mdot
.56485 .5441 Mdot
.52968 .58364 Mdot
.46043 .35769 Mdot
.46915 .30043 Mdot
.67109 .38883 Mdot
.37385 .47713 Mdot
.81581 .5681 Mdot
.54849 .57503 Mdot
.36791 .42594 Mdot
.49636 .36395 Mdot
.35638 .65518 Mdot
.63173 .39966 Mdot
.20664 .69368 Mdot
.43822 .35266 Mdot
.34265 .5813 Mdot
.21052 .60636 Mdot
.36943 .42944 Mdot
.44869 .3936 Mdot
.55852 .47536 Mdot
.33363 .6692 Mdot
.57598 .5409 Mdot
.59922 .20401 Mdot
.28514 .3073 Mdot
.60471 .65631 Mdot
.48402 .33841 Mdot
.75015 .61804 Mdot
.67627 .26124 Mdot
.34891 .64105 Mdot
.34202 .69738 Mdot
.4372 .35 Mdot
.35778 .55343 Mdot
.51526 .61756 Mdot
.34159 .67795 Mdot
.3329 .55079 Mdot
.38324 .44494 Mdot
.41779 .43899 Mdot
.63435 .40904 Mdot
.46139 .21078 Mdot
.55401 .29248 Mdot
.42823 .34369 Mdot
.39889 .66793 Mdot
.64887 .34576 Mdot
.63872 .35078 Mdot
.3728 .45806 Mdot
.34632 .5421 Mdot
.60504 .36765 Mdot
.5141 .59783 Mdot
.60752 .69512 Mdot
.55802 .56183 Mdot
.35517 .66524 Mdot
.55331 .59042 Mdot
.34002 .53518 Mdot
.44438 .33253 Mdot
.35108 .53522 Mdot
.44668 .35442 Mdot
.61476 .29033 Mdot
.57345 .61586 Mdot
.53105 .58073 Mdot
.46448 .79275 Mdot
.66919 .39862 Mdot
.56535 .20284 Mdot
.36146 .40773 Mdot
.35532 .51362 Mdot
.53279 .56257 Mdot
.6564 .37081 Mdot
.3791 .64813 Mdot
.45794 .79422 Mdot
.55405 .62109 Mdot
.65947 .38203 Mdot
.60201 .57249 Mdot
.65855 .75503 Mdot
.2544 .31915 Mdot
.64247 .39551 Mdot
.1888 .63215 Mdot
.60675 .5952 Mdot
.50278 .52305 Mdot
.52928 .54391 Mdot
.46191 .68312 Mdot
.58246 .5378 Mdot
.60175 .37826 Mdot
.5611 .56531 Mdot
.62078 .36196 Mdot
.34711 .55866 Mdot
.44259 .29611 Mdot
.63775 .42056 Mdot
.56894 .63189 Mdot
.79428 .68763 Mdot
.46474 .32673 Mdot
.5459 .55855 Mdot
.46434 .34585 Mdot
.60404 .38455 Mdot
.61416 .42255 Mdot
.52141 .82926 Mdot
.50796 .36614 Mdot
.4587 .31089 Mdot
.59427 .56592 Mdot
.52434 .27771 Mdot
.58799 .56797 Mdot
.47515 .7275 Mdot
.53491 .61715 Mdot
.58034 .53677 Mdot
.50488 .8504 Mdot
.42462 .31897 Mdot
.17081 .43981 Mdot
.56707 .80064 Mdot
.71047 .74945 Mdot
.61054 .35419 Mdot
.34933 .64122 Mdot
.75258 .69837 Mdot
.38929 .39743 Mdot
.33354 .51314 Mdot
.57731 .599 Mdot
.66552 .434 Mdot
.4298 .32196 Mdot
.36872 .67129 Mdot
.56273 .54983 Mdot
.34484 .54472 Mdot
.31299 .59392 Mdot
.44193 .29121 Mdot
.63463 .40368 Mdot
.64714 .41949 Mdot
.1727 .62812 Mdot
.61167 .59644 Mdot
.53164 .56985 Mdot
.46496 .33223 Mdot
.54078 .67227 Mdot
.34022 .65543 Mdot
.23409 .54044 Mdot
.4592 .3117 Mdot
.49871 .46025 Mdot
.61182 .4023 Mdot
.57029 .58959 Mdot
.54981 .39521 Mdot
.39934 .45733 Mdot
.75623 .44092 Mdot
.35581 .67118 Mdot
.47406 .7356 Mdot
.60122 .3789 Mdot
.45132 .32825 Mdot
.32646 .41975 Mdot
.59568 .5238 Mdot
.56885 .58363 Mdot
.46993 .73753 Mdot
.4194 .60809 Mdot
.33028 .74821 Mdot
.52168 .56977 Mdot
.4238 .59962 Mdot
.52359 .57887 Mdot
.57714 .52125 Mdot
.51565 .59629 Mdot
.5411 .58471 Mdot
.66082 .38455 Mdot
.59546 .67413 Mdot
.33708 .49856 Mdot
.68604 .48102 Mdot
.49381 .40514 Mdot
.60067 .54843 Mdot
.59646 .57648 Mdot
.77917 .47804 Mdot
.50444 .31368 Mdot
.65818 .40051 Mdot
.5868 .42967 Mdot
.47474 .29736 Mdot
.61358 .68576 Mdot
.37022 .48649 Mdot
.61466 .66376 Mdot
.34799 .53556 Mdot
.65607 .37427 Mdot
.3575 .51375 Mdot
.45133 .28989 Mdot
.35534 .46396 Mdot
.36428 .41506 Mdot
.42578 .32621 Mdot
.61255 .41477 Mdot
.54665 .60285 Mdot
.48293 .32636 Mdot
.43724 .75401 Mdot
.35438 .66592 Mdot
.52429 .82937 Mdot
.60938 .61646 Mdot
.51112 .38453 Mdot
.50629 .68088 Mdot
.35075 .53315 Mdot
.21953 .36943 Mdot
.66173 .40304 Mdot
.37988 .6871 Mdot
.65756 .37531 Mdot
.42275 .19506 Mdot
.36962 .66484 Mdot
.60422 .81766 Mdot
.34109 .36567 Mdot
.30063 .57073 Mdot
.51897 .60953 Mdot
.63242 .51501 Mdot
.33481 .47902 Mdot
.42899 .32383 Mdot
.33221 .36454 Mdot
.53113 .59003 Mdot
.24263 .39342 Mdot
.67241 .39475 Mdot
.37905 .45329 Mdot
.44954 .32226 Mdot
.48411 .31934 Mdot
.58001 .62476 Mdot
.2426 .59471 Mdot
.53296 .60225 Mdot
.31646 .38321 Mdot
.51558 .7459 Mdot
.64502 .64292 Mdot
.54808 .55345 Mdot
.36238 .50988 Mdot
.60133 .57123 Mdot
.60475 .70649 Mdot
.56334 .18643 Mdot
.54231 .65157 Mdot
.36995 .35141 Mdot
.39617 .65873 Mdot
.62034 .3951 Mdot
.62715 .59145 Mdot
.37394 .42204 Mdot
.60949 .58879 Mdot
.52409 .14337 Mdot
.35338 .68245 Mdot
.31419 .49425 Mdot
.60195 .54018 Mdot
.58556 .62128 Mdot
.64167 .47155 Mdot
.65303 .44555 Mdot
.37584 .50801 Mdot
.56531 .57837 Mdot
.53668 .75917 Mdot
.47307 .33069 Mdot
.53664 .60766 Mdot
.54646 .56302 Mdot
.76713 .3973 Mdot
.45679 .3009 Mdot
.35459 .52939 Mdot
.38975 .42163 Mdot
.32155 .54873 Mdot
.33204 .70338 Mdot
.48684 .42567 Mdot
.41803 .67875 Mdot
.26373 .31405 Mdot
.35618 .64393 Mdot
.60343 .61489 Mdot
.61119 .51925 Mdot
.60069 .60731 Mdot
.34934 .70018 Mdot
.44807 .30151 Mdot
.65757 .40531 Mdot
.48911 .23419 Mdot
.38177 .42088 Mdot
.53141 .54596 Mdot
.36732 .69294 Mdot
.62255 .41658 Mdot
.37202 .71404 Mdot
.62278 .40036 Mdot
.45186 .31317 Mdot
.49097 .31973 Mdot
.36715 .6848 Mdot
.64838 .36536 Mdot
.37126 .38624 Mdot
.54261 .8067 Mdot
.52883 .61106 Mdot
.41399 .37366 Mdot
.66459 .38047 Mdot
.68128 .38962 Mdot
.67134 .37237 Mdot
.56229 .61332 Mdot
.52892 .46126 Mdot
.5999 .53076 Mdot
.43279 .34432 Mdot
.32773 .53843 Mdot
.42646 .63986 Mdot
.68823 .29544 Mdot
.40247 .62755 Mdot
.59195 .65363 Mdot
.56434 .55858 Mdot
.5422 .5626 Mdot
.54185 .63008 Mdot
.31463 .41075 Mdot
.58002 .61525 Mdot
.45816 .35719 Mdot
.34169 .52631 Mdot
.60388 .54751 Mdot
.37314 .44056 Mdot
.54569 .4377 Mdot
.33745 .65347 Mdot
.48028 .41931 Mdot
.80127 .6482 Mdot
.62488 .41825 Mdot
.32206 .52017 Mdot
.3349 .50856 Mdot
.35888 .64789 Mdot
.43167 .32128 Mdot
.61817 .4045 Mdot
.47726 .69195 Mdot
.36593 .65349 Mdot
.55798 .56615 Mdot
.23996 .4611 Mdot
.23201 .43891 Mdot
.56148 .54051 Mdot
.58636 .5934 Mdot
.38805 .42973 Mdot
.35994 .54784 Mdot
.7158 .2508 Mdot
.38335 .7351 Mdot
.36949 .67922 Mdot
.33237 .68191 Mdot
.65033 .35357 Mdot
.63237 .56497 Mdot
.43729 .34664 Mdot
.405 .756 Mdot
.44487 .62716 Mdot
.43264 .77889 Mdot
.30192 .69753 Mdot
.56758 .62588 Mdot
.66154 .54246 Mdot
.56484 .55417 Mdot
.65918 .41323 Mdot
.6031 .39818 Mdot
.649 .40911 Mdot
.43024 .33187 Mdot
.71519 .64122 Mdot
.46983 .35146 Mdot
.82396 .59909 Mdot
.60286 .37446 Mdot
.29817 .45194 Mdot
.35845 .49508 Mdot
.62439 .58595 Mdot
.34215 .65623 Mdot
.42248 .29919 Mdot
.53303 .63979 Mdot
.1976 .44123 Mdot
.35571 .46622 Mdot
.60947 .41333 Mdot
.55882 .47671 Mdot
.82505 .45463 Mdot
.51388 .43059 Mdot
.50114 .54246 Mdot
.63503 .48828 Mdot
.36232 .65554 Mdot
.75351 .44192 Mdot
.33759 .70135 Mdot
.44825 .33939 Mdot
.53363 .58713 Mdot
.54026 .59329 Mdot
.52633 .56839 Mdot
.57797 .61477 Mdot
.4708 .29826 Mdot
.60715 .64179 Mdot
.38763 .18996 Mdot
.38248 .44048 Mdot
.67643 .74527 Mdot
.34172 .68696 Mdot
.47697 .35369 Mdot
.34314 .52869 Mdot
.37558 .48796 Mdot
.4128 .718 Mdot
.56838 .54443 Mdot
.57891 .60033 Mdot
.37146 .53177 Mdot
.52358 .56264 Mdot
.52784 .64738 Mdot
.34012 .49406 Mdot
.40358 .62687 Mdot
.36622 .644 Mdot
.35113 .69542 Mdot
.44961 .30324 Mdot
.65236 .36854 Mdot
.3474 .67164 Mdot
.34984 .55467 Mdot
.60817 .63053 Mdot
.5757 .63485 Mdot
.66534 .38068 Mdot
.46278 .19838 Mdot
.34182 .64491 Mdot
.55281 .47712 Mdot
.6166 .36633 Mdot
.59649 .37343 Mdot
.5701 .58265 Mdot
.6019 .66117 Mdot
.68379 .37298 Mdot
.37252 .65347 Mdot
.48005 .35045 Mdot
.29823 .53719 Mdot
.45524 .33858 Mdot
.61765 .41029 Mdot
.56136 .63585 Mdot
.611 .40924 Mdot
.61185 .58052 Mdot
.64004 .85375 Mdot
.54249 .59082 Mdot
.2947 .27242 Mdot
.45852 .69492 Mdot
.33861 .504 Mdot
.37239 .38879 Mdot
.37517 .45561 Mdot
.61126 .3694 Mdot
.56017 .6317 Mdot
.33191 .68645 Mdot
.66345 .79048 Mdot
.65592 .3471 Mdot
.33126 .53028 Mdot
.36999 .5068 Mdot
.42724 .31745 Mdot
.60945 .55087 Mdot
.56718 .58743 Mdot
.35883 .47115 Mdot
.55468 .7152 Mdot
.63518 .36769 Mdot
.53476 .56562 Mdot
.57503 .5649 Mdot
.34042 .49805 Mdot
.53691 .80645 Mdot
.60374 .4697 Mdot
.53553 .583 Mdot
.32926 .44742 Mdot
.45109 .36278 Mdot
.53 .62264 Mdot
.6075 .64251 Mdot
.34104 .66402 Mdot
.71705 .70619 Mdot
.58592 .19062 Mdot
.43664 .35996 Mdot
.37402 .47269 Mdot
.61113 .6058 Mdot
.35813 .49225 Mdot
.57364 .63367 Mdot
.78784 .59693 Mdot
.37973 .44797 Mdot
.5911 .60858 Mdot
.6348 .58336 Mdot
.60347 .40393 Mdot
.58205 .61732 Mdot
.78058 .45002 Mdot
.32508 .49982 Mdot
.5873 .6131 Mdot
.67507 .64669 Mdot
.46698 .30603 Mdot
.63106 .58655 Mdot
.34113 .69176 Mdot
.46291 .67896 Mdot
.57641 .27496 Mdot
.34492 .44807 Mdot
.34986 .69371 Mdot
.54791 .61218 Mdot
.35927 .55281 Mdot
.42628 .34288 Mdot
.23721 .39173 Mdot
.53572 .55604 Mdot
.46307 .33148 Mdot
.44512 .33047 Mdot
.35353 .68862 Mdot
.15622 .49037 Mdot
.61579 .6254 Mdot
.55936 .58926 Mdot
.78646 .44569 Mdot
.63114 .43204 Mdot
.55137 .5938 Mdot
.59664 .62047 Mdot
.45929 .35512 Mdot
.64306 .45719 Mdot
.77055 .56275 Mdot
.23173 .56004 Mdot
.4221 .34691 Mdot
.31511 .54619 Mdot
.35979 .55271 Mdot
.3406 .68422 Mdot
.62639 .38984 Mdot
.3246 .67646 Mdot
.33829 .48966 Mdot
.60513 .6098 Mdot
.44925 .35166 Mdot
.73067 .37142 Mdot
.41823 .32668 Mdot
.34132 .45639 Mdot
.66561 .41077 Mdot
.53323 .23651 Mdot
.45098 .1444 Mdot
.56222 .29703 Mdot
.48683 .28627 Mdot
.35601 .65525 Mdot
.26958 .40647 Mdot
.57139 .56261 Mdot
.74281 .44836 Mdot
.54982 .60713 Mdot
.67639 .60523 Mdot
.32322 .52906 Mdot
.3736 .49354 Mdot
.53464 .58621 Mdot
.49952 .74419 Mdot
.42012 .31471 Mdot
.42417 .3225 Mdot
.58594 .60678 Mdot
.44157 .31669 Mdot
.55386 .5804 Mdot
.34445 .53793 Mdot
.18452 .40201 Mdot
.55647 .55745 Mdot
.56762 .52591 Mdot
.47372 .26547 Mdot
.5409 .82869 Mdot
.35286 .37863 Mdot
.65558 .52918 Mdot
.81137 .41929 Mdot
.44157 .31734 Mdot
.64013 .60368 Mdot
.34283 .46462 Mdot
.38849 .4288 Mdot
.3725 .3868 Mdot
.55378 .60069 Mdot
.55881 .60392 Mdot
.53431 .5612 Mdot
.59487 .58155 Mdot
.74661 .45031 Mdot
.56303 .67725 Mdot
.68618 .57336 Mdot
.58126 .60022 Mdot
.66369 .59656 Mdot
.48186 .32597 Mdot
.63291 .44285 Mdot
.32434 .66733 Mdot
.56934 .62614 Mdot
.69548 .37235 Mdot
.45866 .36276 Mdot
.82523 .59625 Mdot
.4378 .30722 Mdot
.34947 .51022 Mdot
.4429 .2983 Mdot
.6099 .56378 Mdot
.63663 .38813 Mdot
.33551 .47173 Mdot
.28142 .34323 Mdot
.33312 .51543 Mdot
.61182 .5621 Mdot
.30567 .5044 Mdot
.33323 .51026 Mdot
.54018 .41443 Mdot
.6336 .3851 Mdot
.52757 .76415 Mdot
.60278 .39793 Mdot
.59095 .61126 Mdot
.59474 .60661 Mdot
.38674 .37876 Mdot
.43267 .29964 Mdot
.60241 .38757 Mdot
.15559 .41008 Mdot
.33379 .70039 Mdot
.64799 .40693 Mdot
.5693 .51286 Mdot
.45843 .53848 Mdot
.6428 .38521 Mdot
.52705 .72273 Mdot
.42746 .32818 Mdot
.61547 .36117 Mdot
.57437 .51425 Mdot
.38965 .26187 Mdot
.38064 .67698 Mdot
.36506 .5221 Mdot
.443 .4697 Mdot
.33189 .48631 Mdot
.48237 .34946 Mdot
.36129 .46172 Mdot
.47481 .33019 Mdot
.55371 .2046 Mdot
.64116 .69497 Mdot
.43095 .36628 Mdot
.48846 .33208 Mdot
.35147 .47458 Mdot
.54608 .55187 Mdot
.43618 .41385 Mdot
.51841 .57813 Mdot
.53214 .6352 Mdot
.47468 .32232 Mdot
.59969 .38419 Mdot
.59452 .3994 Mdot
.65129 .55387 Mdot
.64695 .41997 Mdot
.34765 .5381 Mdot
.25746 .316 Mdot
.52506 .19576 Mdot
.46994 .32618 Mdot
.48487 .31028 Mdot
.59061 .57028 Mdot
.35708 .48172 Mdot
.34424 .5634 Mdot
.43705 .34244 Mdot
.72491 .42486 Mdot
.60588 .53706 Mdot
.67494 .40257 Mdot
.60344 .37267 Mdot
.64553 .39295 Mdot
.66433 .36344 Mdot
.76462 .54548 Mdot
.42687 .32837 Mdot
.6066 .37185 Mdot
.58914 .60627 Mdot
.55769 .60247 Mdot
.38428 .4099 Mdot
.34871 .69538 Mdot
.61306 .61413 Mdot
.51079 .57826 Mdot
.57201 .58517 Mdot
.32765 .52266 Mdot
.57665 .50276 Mdot
.37571 .47283 Mdot
.36136 .53875 Mdot
.36872 .4469 Mdot
.37803 .40656 Mdot
.62365 .5035 Mdot
.81696 .41228 Mdot
.59848 .57228 Mdot
.52974 .67147 Mdot
.35707 .49656 Mdot
.20862 .39933 Mdot
.50826 .21911 Mdot
.53385 .55976 Mdot
.40693 .45484 Mdot
.36059 .46813 Mdot
.62717 .42956 Mdot
.54998 .59845 Mdot
.3894 .41081 Mdot
.33862 .65301 Mdot
.55367 .51518 Mdot
.39106 .41466 Mdot
.64112 .36268 Mdot
.3221 .65999 Mdot
.62716 .35639 Mdot
.35566 .4588 Mdot
.634 .58431 Mdot
.87528 .41677 Mdot
.32297 .5507 Mdot
.61947 .79152 Mdot
.69453 .3939 Mdot
.53595 .56284 Mdot
.32136 .51969 Mdot
.63424 .43049 Mdot
.47803 .35586 Mdot
.44451 .56065 Mdot
.65687 .40971 Mdot
.37423 .48856 Mdot
.38729 .4177 Mdot
.33827 .49814 Mdot
.61355 .39239 Mdot
.54083 .61697 Mdot
.61624 .38007 Mdot
.44175 .29937 Mdot
.57733 .5539 Mdot
.83184 .51702 Mdot
.54043 .67539 Mdot
.60916 .37214 Mdot
.34928 .5473 Mdot
.36511 .70082 Mdot
.57216 .54758 Mdot
.61053 .78592 Mdot
.61619 .58384 Mdot
.4691 .33459 Mdot
.1917 .50224 Mdot
.74017 .38483 Mdot
.59688 .54167 Mdot
.59147 .57162 Mdot
.42375 .33317 Mdot
.56937 .54535 Mdot
.58708 .53948 Mdot
.49562 .36993 Mdot
.60908 .39088 Mdot
.56446 .56439 Mdot
.33941 .55615 Mdot
.59991 .21076 Mdot
.60176 .53357 Mdot
.38446 .52999 Mdot
.51401 .75779 Mdot
.18091 .50549 Mdot
.54462 .60499 Mdot
.40138 .74032 Mdot
.59327 .58623 Mdot
.5615 .6185 Mdot
.59052 .56521 Mdot
.65197 .51113 Mdot
.34935 .47375 Mdot
.33657 .52881 Mdot
.3805 .6718 Mdot
.52038 .75827 Mdot
.34013 .66868 Mdot
.43299 .31386 Mdot
.31837 .61286 Mdot
.37903 .44744 Mdot
.64314 .36243 Mdot
.53971 .60757 Mdot
.32396 .49983 Mdot
.57027 .59254 Mdot
.61051 .5691 Mdot
.36323 .51174 Mdot
.34143 .5678 Mdot
.35714 .44097 Mdot
.33116 .67416 Mdot
.64631 .41417 Mdot
.57281 .64579 Mdot
.37524 .66739 Mdot
.54354 .61861 Mdot
.41233 .67153 Mdot
.65152 .4094 Mdot
.61008 .38812 Mdot
.60444 .42305 Mdot
.60569 .60915 Mdot
.60236 .55131 Mdot
.47141 .34933 Mdot
.65173 .36551 Mdot
.45846 .30527 Mdot
.34183 .46343 Mdot
.35091 .58443 Mdot
.55398 .60081 Mdot
.51632 .50381 Mdot
.33644 .6676 Mdot
.34788 .51943 Mdot
.3716 .53779 Mdot
.3761 .69332 Mdot
.61496 .58046 Mdot
.36231 .50592 Mdot
.35708 .69634 Mdot
.70511 .43306 Mdot
.80031 .36801 Mdot
.35774 .70293 Mdot
.58815 .60464 Mdot
.66085 .45206 Mdot
.51712 .80338 Mdot
.33929 .70529 Mdot
.4584 .34667 Mdot
.60583 .61047 Mdot
.52912 .68771 Mdot
.33448 .65304 Mdot
.59747 .21656 Mdot
.34046 .50307 Mdot
.39619 .27331 Mdot
.51007 .55038 Mdot
.72625 .45648 Mdot
.32572 .688 Mdot
.62223 .40479 Mdot
.62258 .43962 Mdot
.57813 .58037 Mdot
.32521 .69838 Mdot
.41998 .34238 Mdot
.34008 .51037 Mdot
.36753 .40761 Mdot
.61418 .38958 Mdot
.50898 .27667 Mdot
.33394 .54543 Mdot
.53973 .4833 Mdot
.21516 .53037 Mdot
.61621 .69025 Mdot
.66869 .63518 Mdot
.30694 .29274 Mdot
.59659 .62417 Mdot
.34834 .70294 Mdot
.46043 .36108 Mdot
.4405 .35158 Mdot
.45813 .31333 Mdot
.37245 .39111 Mdot
.50258 .41512 Mdot
.34783 .46536 Mdot
.26033 .3722 Mdot
.34788 .68605 Mdot
.55862 .76197 Mdot
.54716 .61981 Mdot
.56263 .55829 Mdot
.61949 .59285 Mdot
.53036 .60119 Mdot
.58746 .5802 Mdot
.43601 .31751 Mdot
.37022 .39064 Mdot
.27986 .53637 Mdot
.65308 .39316 Mdot
.39183 .62265 Mdot
.3585 .49555 Mdot
.38661 .43329 Mdot
.36542 .67816 Mdot
.56291 .46322 Mdot
.35671 .45274 Mdot
.35681 .51587 Mdot
.61688 .60982 Mdot
.62391 .37085 Mdot
.60483 .6638 Mdot
.59798 .59817 Mdot
.34715 .52531 Mdot
.37657 .58784 Mdot
.78692 .52252 Mdot
.64394 .57431 Mdot
.35095 .63357 Mdot
.51149 .47846 Mdot
.34087 .70527 Mdot
.5311 .54013 Mdot
.2027 .41148 Mdot
.33955 .48782 Mdot
.34997 .49812 Mdot
.35764 .69889 Mdot
.5222 .50603 Mdot
.62198 .38651 Mdot
.37351 .50288 Mdot
.46848 .34412 Mdot
.5976 .60957 Mdot
.34934 .58065 Mdot
.49257 .54896 Mdot
.25952 .59454 Mdot
.46341 .31711 Mdot
.35643 .54587 Mdot
.60817 .54933 Mdot
.58813 .6024 Mdot
.35783 .65395 Mdot
.66915 .31841 Mdot
.54155 .51856 Mdot
.71339 .74755 Mdot
.36767 .23509 Mdot
.41733 .22889 Mdot
.56865 .58362 Mdot
.6101 .39352 Mdot
.38602 .42632 Mdot
.37024 .65949 Mdot
.59314 .64789 Mdot
.80475 .3815 Mdot
.66467 .41883 Mdot
.45118 .33426 Mdot
.38884 .40929 Mdot
.50749 .41365 Mdot
.61305 .59795 Mdot
.54973 .60627 Mdot
.56887 .61425 Mdot
.76061 .29627 Mdot
.33079 .53565 Mdot
.66511 .40598 Mdot
.35816 .67066 Mdot
.65063 .41818 Mdot
.33517 .51993 Mdot
.50441 .24743 Mdot
.59076 .54408 Mdot
.66927 .40866 Mdot
.6248 .40227 Mdot
.42784 .31681 Mdot
.48156 .35305 Mdot
.30933 .54437 Mdot
.54269 .58944 Mdot
.38972 .41242 Mdot
.60214 .40365 Mdot
.36865 .53424 Mdot
.36866 .66267 Mdot
.47906 .34065 Mdot
.58081 .60159 Mdot
.33591 .49759 Mdot
.59114 .6578 Mdot
.64163 .37873 Mdot
.35692 .5142 Mdot
.37114 .42371 Mdot
.33433 .68523 Mdot
.5687 .60348 Mdot
.36037 .63421 Mdot
.37315 .47448 Mdot
.57464 .56358 Mdot
.58255 .4647 Mdot
.34156 .63234 Mdot
.28976 .35114 Mdot
.33912 .47805 Mdot
.37685 .41283 Mdot
.60621 .42212 Mdot
.59896 .22688 Mdot
.34765 .50277 Mdot
.57384 .46098 Mdot
.6315 .30769 Mdot
.57313 .64619 Mdot
.63938 .4014 Mdot
.25591 .42721 Mdot
.76534 .70274 Mdot
.58253 .77527 Mdot
.54573 .55968 Mdot
.32541 .50553 Mdot
.36937 .68856 Mdot
.47039 .32579 Mdot
.3841 .52896 Mdot
.60933 .70216 Mdot
.36495 .48827 Mdot
.59327 .56906 Mdot
.60454 .39481 Mdot
.43663 .33701 Mdot
.60133 .26663 Mdot
.35031 .55164 Mdot
.32375 .5216 Mdot
.60302 .54581 Mdot
.34365 .67711 Mdot
.62893 .7422 Mdot
.34065 .53805 Mdot
.34464 .57852 Mdot
.27255 .39766 Mdot
.36657 .69418 Mdot
.59046 .59132 Mdot
.65413 .56332 Mdot
.53888 .62928 Mdot
.6288 .79262 Mdot
.37447 .46332 Mdot
.65371 .38988 Mdot
.55316 .61117 Mdot
.22558 .56295 Mdot
.34449 .52139 Mdot
.53165 .44973 Mdot
.3606 .59525 Mdot
.42732 .32953 Mdot
.34568 .57987 Mdot
.55807 .59394 Mdot
.41931 .3169 Mdot
.33667 .66774 Mdot
.53769 .58209 Mdot
.60138 .55148 Mdot
.63559 .42836 Mdot
.448 .34066 Mdot
.70524 .31228 Mdot
.48548 .32528 Mdot
.4463 .36056 Mdot
.59457 .41514 Mdot
.56699 .57224 Mdot
.35126 .51281 Mdot
.36232 .46777 Mdot
.57925 .64641 Mdot
.21533 .35886 Mdot
.62011 .38565 Mdot
.39846 .67855 Mdot
.73092 .27529 Mdot
.64583 .56643 Mdot
.36874 .54587 Mdot
.65869 .31818 Mdot
.42119 .34323 Mdot
.58434 .6037 Mdot
.6221 .36632 Mdot
.35088 .56871 Mdot
.33444 .54745 Mdot
.55294 .62926 Mdot
.4407 .33181 Mdot
.3488 .64631 Mdot
.32488 .55081 Mdot
.24345 .59336 Mdot
.57321 .61883 Mdot
.24909 .39135 Mdot
.32168 .53515 Mdot
.68689 .78401 Mdot
.27174 .55711 Mdot
.64298 .40016 Mdot
.60869 .56544 Mdot
.64494 .42012 Mdot
.35921 .66582 Mdot
.31238 .53643 Mdot
.44273 .33254 Mdot
.63861 .55115 Mdot
.50017 .16046 Mdot
.35249 .47135 Mdot
.66099 .38597 Mdot
.59881 .54228 Mdot
.60198 .49641 Mdot
.55501 .58845 Mdot
.63311 .46445 Mdot
.39571 .68592 Mdot
.47366 .31706 Mdot
.46662 .33863 Mdot
.57258 .55947 Mdot
.35205 .65009 Mdot
.36 .53293 Mdot
.34115 .50865 Mdot
.40991 .86383 Mdot
.37232 .52035 Mdot
.49086 .72792 Mdot
.56231 .60397 Mdot
.36978 .52557 Mdot
.68121 .28253 Mdot
.46564 .33124 Mdot
.53144 .60526 Mdot
.37133 .49313 Mdot
.37836 .25367 Mdot
.41596 .64328 Mdot
.58749 .58306 Mdot
.50782 .62054 Mdot
.46668 .34451 Mdot
.46008 .77809 Mdot
.35204 .46357 Mdot
.53199 .61146 Mdot
.47609 .29542 Mdot
.21162 .56251 Mdot
.52335 .18472 Mdot
.64617 .41409 Mdot
.3205 .50691 Mdot
.43534 .3179 Mdot
.51731 .53696 Mdot
.34339 .68956 Mdot
.32879 .49081 Mdot
.32898 .52474 Mdot
.59337 .56082 Mdot
.62042 .60157 Mdot
.64187 .5495 Mdot
.65784 .38303 Mdot
.48062 .31559 Mdot
.53327 .5901 Mdot
.50847 .27928 Mdot
.52475 .5742 Mdot
.47895 .33586 Mdot
.91066 .50658 Mdot
.52448 .62156 Mdot
.55657 .58693 Mdot
.62153 .74998 Mdot
.65396 .4127 Mdot
.63953 .42465 Mdot
.3232 .2569 Mdot
.56293 .60389 Mdot
.28832 .5778 Mdot
.64165 .41779 Mdot
.62383 .38215 Mdot
.283 .46264 Mdot
.56368 .55174 Mdot
.45331 .79129 Mdot
.44036 .34979 Mdot
.44983 .35739 Mdot
.61579 .38225 Mdot
.52877 .52659 Mdot
.42584 .34674 Mdot
.76044 .4818 Mdot
.35826 .47991 Mdot
.19683 .421 Mdot
.64411 .3769 Mdot
.46061 .40365 Mdot
.46727 .32382 Mdot
.82185 .60408 Mdot
.40333 .45162 Mdot
.5393 .5574 Mdot
.57083 .60731 Mdot
.33563 .67235 Mdot
.5665 .64725 Mdot
.3751 .48167 Mdot
.44174 .31629 Mdot
.65526 .72669 Mdot
.64831 .40924 Mdot
.54618 .58626 Mdot
.5536 .46526 Mdot
.60453 .28223 Mdot
.3469 .351 Mdot
.62111 .39532 Mdot
.63699 .40689 Mdot
.34352 .475 Mdot
.32398 .53523 Mdot
.57461 .5754 Mdot
.43345 .34351 Mdot
.64726 .36202 Mdot
.47823 .33241 Mdot
.33674 .49313 Mdot
.35446 .51731 Mdot
.38049 .44715 Mdot
.51762 .57001 Mdot
.35485 .53872 Mdot
.23184 .59648 Mdot
.50329 .26772 Mdot
.64109 .35073 Mdot
.55256 .16636 Mdot
.60136 .26519 Mdot
.48978 .67607 Mdot
.32964 .68314 Mdot
.37267 .47531 Mdot
.46246 .29661 Mdot
.58802 .56947 Mdot
.57484 .59661 Mdot
.37736 .42607 Mdot
.42976 .30606 Mdot
.36649 .66765 Mdot
.42874 .3053 Mdot
.35097 .69044 Mdot
.36445 .54828 Mdot
.61437 .55629 Mdot
.58366 .62898 Mdot
.44205 .31359 Mdot
.35744 .5238 Mdot
.34011 .52734 Mdot
.3407 .70447 Mdot
.42375 .61608 Mdot
.3368 .49969 Mdot
.64324 .37719 Mdot
.75457 .55061 Mdot
.38531 .42294 Mdot
.55052 .59667 Mdot
.41359 .68531 Mdot
.74047 .42916 Mdot
.54166 .62717 Mdot
.3857 .40537 Mdot
.26963 .73428 Mdot
.54132 .60615 Mdot
.22001 .68705 Mdot
.37754 .41134 Mdot
.65757 .40994 Mdot
.32545 .50695 Mdot
.3762 .48218 Mdot
.49622 .57708 Mdot
.3794 .69909 Mdot
.59542 .63957 Mdot
.64184 .42021 Mdot
.62403 .43574 Mdot
.39867 .22168 Mdot
.62016 .79224 Mdot
.33807 .70036 Mdot
.36372 .68533 Mdot
.34687 .50065 Mdot
.45648 .83429 Mdot
.60461 .52909 Mdot
.36927 .67664 Mdot
.61136 .72904 Mdot
.59789 .57559 Mdot
.46316 .72712 Mdot
.40995 .45942 Mdot
.61194 .39106 Mdot
.63658 .52323 Mdot
.34546 .51169 Mdot
.66138 .39165 Mdot
.4808 .24249 Mdot
.61282 .61016 Mdot
.65184 .408 Mdot
.47549 .34137 Mdot
.32358 .30492 Mdot
.61708 .42323 Mdot
.409 .68735 Mdot
.43529 .34244 Mdot
.28171 .40696 Mdot
.58783 .73945 Mdot
.41087 .13498 Mdot
.43474 .32163 Mdot
.3615 .49286 Mdot
.36091 .46887 Mdot
.34229 .50458 Mdot
.66279 .40309 Mdot
.34968 .55803 Mdot
.65416 .377 Mdot
.51124 .81158 Mdot
.42464 .61717 Mdot
.36764 .68483 Mdot
.51038 .35897 Mdot
.62994 .40499 Mdot
.2411 .35347 Mdot
.46675 .14517 Mdot
.5846 .60874 Mdot
.48438 .31335 Mdot
.35459 .69898 Mdot
.64307 .81881 Mdot
.33852 .66707 Mdot
.34122 .4674 Mdot
.18352 .44411 Mdot
.54993 .57939 Mdot
.75622 .62005 Mdot
.33415 .69024 Mdot
.61457 .40294 Mdot
.5704 .56118 Mdot
.37284 .38349 Mdot
.34051 .67904 Mdot
.34372 .64922 Mdot
.57708 .57142 Mdot
.60855 .41249 Mdot
.35202 .5186 Mdot
.45845 .29341 Mdot
.34781 .71015 Mdot
.49873 .62365 Mdot
.56959 .64555 Mdot
.6074 .61517 Mdot
.52357 .42668 Mdot
.5935 .71675 Mdot
.44066 .31838 Mdot
.53598 .78714 Mdot
.32492 .53672 Mdot
.26177 .44872 Mdot
.33354 .25368 Mdot
.49005 .38241 Mdot
.37394 .45684 Mdot
.37599 .46335 Mdot
.584 .57932 Mdot
.59419 .71759 Mdot
.19287 .51603 Mdot
.49249 .28313 Mdot
.38392 .42663 Mdot
.34012 .51527 Mdot
.62972 .43964 Mdot
.40413 .21279 Mdot
.58744 .65205 Mdot
.42392 .35293 Mdot
.33264 .50613 Mdot
.78971 .59308 Mdot
.34763 .67829 Mdot
.21898 .38677 Mdot
.59967 .54516 Mdot
.53103 .57989 Mdot
.44912 .31918 Mdot
.46731 .35356 Mdot
.38947 .3681 Mdot
.38204 .22621 Mdot
.40062 .76732 Mdot
.63331 .25423 Mdot
.7898 .58364 Mdot
.6363 .44114 Mdot
.60718 .3743 Mdot
.38784 .39619 Mdot
.48197 .34097 Mdot
.54956 .61114 Mdot
.64358 .36166 Mdot
.33582 .35366 Mdot
.58134 .38028 Mdot
.47731 .73181 Mdot
.27471 .5851 Mdot
.61346 .57998 Mdot
.61772 .37301 Mdot
.66011 .39945 Mdot
.65167 .36014 Mdot
.38231 .40519 Mdot
.56472 .57875 Mdot
.55517 .54965 Mdot
.52832 .58945 Mdot
.53549 .66644 Mdot
.57827 .61877 Mdot
.5098 .30515 Mdot
.50252 .46319 Mdot
.68444 .71767 Mdot
.52925 .61585 Mdot
.43996 .35437 Mdot
.60229 .62386 Mdot
.35288 .64927 Mdot
.59049 .56709 Mdot
.47836 .7266 Mdot
.45936 .32772 Mdot
.54888 .49124 Mdot
.6257 .2487 Mdot
.5951 .54437 Mdot
.35894 .64307 Mdot
.53379 .69615 Mdot
.7058 .32351 Mdot
.39678 .6163 Mdot
.6419 .37652 Mdot
.36576 .47008 Mdot
.44102 .3011 Mdot
.35226 .50833 Mdot
.52236 .60058 Mdot
.3891 .40237 Mdot
.55316 .33208 Mdot
.45666 .40553 Mdot
.55854 .62262 Mdot
.61144 .52691 Mdot
.63267 .37709 Mdot
.3621 .5044 Mdot
.6182 .44863 Mdot
.56031 .61198 Mdot
.35532 .66881 Mdot
.34232 .68323 Mdot
.44773 .24091 Mdot
.81531 .55799 Mdot
.58061 .21722 Mdot
.44773 .31803 Mdot
.33819 .53849 Mdot
.32468 .68706 Mdot
.50696 .65076 Mdot
.44157 .36531 Mdot
.42281 .32966 Mdot
.44286 .34098 Mdot
.60439 .60485 Mdot
.37502 .47526 Mdot
.6841 .70662 Mdot
.37451 .48465 Mdot
.59426 .54613 Mdot
.32874 .53381 Mdot
.37908 .45464 Mdot
.33589 .67865 Mdot
.44949 .3029 Mdot
.33354 .4974 Mdot
.59036 .61333 Mdot
.63017 .41898 Mdot
.4322 .58882 Mdot
.44444 .6721 Mdot
.65258 .77375 Mdot
.66913 .76207 Mdot
.59876 .40538 Mdot
.80755 .61064 Mdot
.41072 .32583 Mdot
.72444 .42744 Mdot
.31177 .47092 Mdot
.56184 .6379 Mdot
.25972 .2968 Mdot
.34996 .46287 Mdot
.36297 .50413 Mdot
.59272 .59131 Mdot
.34942 .56347 Mdot
.54904 .58665 Mdot
.32553 .51746 Mdot
.38794 .61982 Mdot
.59967 .65311 Mdot
.35878 .53063 Mdot
.5388 .53061 Mdot
.57419 .54866 Mdot
.61103 .38954 Mdot
.32191 .51424 Mdot
.52173 .58671 Mdot
.55503 .85448 Mdot
.47542 .34602 Mdot
.38417 .40607 Mdot
.3552 .73482 Mdot
.43625 .31611 Mdot
.64957 .40359 Mdot
.53948 .64128 Mdot
.34392 .65767 Mdot
.62182 .40896 Mdot
.39842 .65181 Mdot
.33753 .69456 Mdot
.2538 .31836 Mdot
.63585 .37398 Mdot
.3833 .42415 Mdot
.33332 .67493 Mdot
.62203 .54528 Mdot
.31839 .52871 Mdot
.44354 .61634 Mdot
.37327 .46519 Mdot
.56689 .58831 Mdot
.36613 .39318 Mdot
.47923 .34191 Mdot
.54312 .56336 Mdot
.32661 .55925 Mdot
.37586 .40817 Mdot
.60629 .59811 Mdot
.58963 .57466 Mdot
.44915 .2055 Mdot
.22132 .43027 Mdot
.36294 .65662 Mdot
.64797 .42668 Mdot
.58933 .60662 Mdot
.33146 .67142 Mdot
.27446 .64633 Mdot
.60092 .62056 Mdot
.67005 .39276 Mdot
.62455 .66146 Mdot
.32759 .5504 Mdot
.4563 .30441 Mdot
.32893 .48365 Mdot
.33681 .65525 Mdot
.13697 .46976 Mdot
.38243 .44495 Mdot
.53422 .53751 Mdot
.53968 .61182 Mdot
.35229 .3626 Mdot
.66036 .39331 Mdot
.40474 .76612 Mdot
.56898 .60382 Mdot
.57367 .68931 Mdot
.539 .57885 Mdot
.27614 .55134 Mdot
.62188 .38528 Mdot
.56047 .58874 Mdot
.52417 .49234 Mdot
.58486 .52824 Mdot
.34833 .64515 Mdot
.59823 .76444 Mdot
.58937 .6331 Mdot
.82116 .31166 Mdot
.37113 .53469 Mdot
.35772 .53421 Mdot
.36536 .37392 Mdot
.34379 .78963 Mdot
.56564 .20716 Mdot
.65517 .37698 Mdot
.59589 .3321 Mdot
.35211 .51396 Mdot
.61934 .22929 Mdot
.79835 .63749 Mdot
.57803 .54888 Mdot
.61309 .59641 Mdot
.34119 .46745 Mdot
.3713 .5168 Mdot
.39076 .41275 Mdot
.52168 .60445 Mdot
.62539 .54376 Mdot
.34967 .54901 Mdot
.58578 .62098 Mdot
.61496 .66215 Mdot
.46262 .29404 Mdot
.60513 .41338 Mdot
.47088 .32052 Mdot
.44029 .30498 Mdot
.71971 .49308 Mdot
.38068 .23379 Mdot
.47957 .33501 Mdot
.4118 .33224 Mdot
.46462 .72059 Mdot
.64975 .56254 Mdot
.32942 .6622 Mdot
.75447 .68064 Mdot
.34418 .49731 Mdot
.56333 .57677 Mdot
.59556 .39051 Mdot
.71489 .46654 Mdot
.40383 .49393 Mdot
.1816 .48564 Mdot
.55695 .6131 Mdot
.34342 .51591 Mdot
.3722 .41861 Mdot
.61257 .64989 Mdot
.26783 .45301 Mdot
.5308 .5725 Mdot
.32392 .50004 Mdot
.74243 .60007 Mdot
.56201 .47152 Mdot
.25014 .42948 Mdot
.58733 .43737 Mdot
.53898 .5965 Mdot
.64916 .3798 Mdot
.46495 .31573 Mdot
.34217 .65428 Mdot
.36138 .65672 Mdot
.57749 .56694 Mdot
.60129 .69961 Mdot
.4135 .45196 Mdot
.57573 .54718 Mdot
.58749 .55878 Mdot
.37659 .4127 Mdot
.58509 .55753 Mdot
.53809 .60956 Mdot
.52941 .59688 Mdot
.57079 .53197 Mdot
.44556 .36005 Mdot
.55359 .47012 Mdot
.51567 .57181 Mdot
.60816 .66078 Mdot
.45789 .28998 Mdot
.61856 .31918 Mdot
.45312 .30008 Mdot
.83218 .51326 Mdot
.4709 .33241 Mdot
.36885 .66561 Mdot
.35944 .40634 Mdot
.63083 .66839 Mdot
.62704 .35857 Mdot
.4646 .36316 Mdot
.3596 .67862 Mdot
.45158 .31249 Mdot
.33082 .54037 Mdot
.67635 .23014 Mdot
.58298 .37764 Mdot
.39367 .74924 Mdot
.43131 .25375 Mdot
.26008 .38637 Mdot
.35094 .46813 Mdot
.61796 .38478 Mdot
.78873 .5305 Mdot
.52384 .5846 Mdot
.33321 .67916 Mdot
.57877 .57497 Mdot
.4455 .36112 Mdot
.34368 .50883 Mdot
.57687 .78354 Mdot
.35278 .65415 Mdot
.47716 .18551 Mdot
.3384 .50917 Mdot
.53119 .55923 Mdot
.42512 .35355 Mdot
.5406 .16137 Mdot
.47269 .31895 Mdot
.42338 .62676 Mdot
.67537 .38975 Mdot
.66926 .59939 Mdot
.63587 .40141 Mdot
.39436 .42589 Mdot
.76192 .28494 Mdot
.72551 .7276 Mdot
.61977 .41784 Mdot
.2343 .4809 Mdot
.61175 .5961 Mdot
.606 .6181 Mdot
.56346 .47934 Mdot
.66694 .40429 Mdot
.58389 .6131 Mdot
.37235 .42237 Mdot
.51392 .26094 Mdot
.2387 .51635 Mdot
.36601 .47406 Mdot
.55284 .59193 Mdot
.46347 .29119 Mdot
.42598 .30903 Mdot
.37693 .47213 Mdot
.45894 .29984 Mdot
.55337 .55105 Mdot
.63214 .40334 Mdot
.42992 .40289 Mdot
.35024 .66158 Mdot
.56901 .82981 Mdot
.32267 .67455 Mdot
.37198 .45658 Mdot
.63417 .58264 Mdot
.35478 .51769 Mdot
.16408 .65499 Mdot
.54288 .55649 Mdot
.64834 .41411 Mdot
.5992 .58606 Mdot
.5364 .58981 Mdot
.61179 .6098 Mdot
.34464 .55175 Mdot
.33697 .75184 Mdot
.58742 .61926 Mdot
.44289 .33393 Mdot
.69836 .72588 Mdot
.60388 .62409 Mdot
.38215 .61469 Mdot
.53161 .75043 Mdot
.26232 .36654 Mdot
.62207 .35699 Mdot
.36165 .51128 Mdot
.64204 .41165 Mdot
.58388 .41869 Mdot
.64989 .40334 Mdot
.71046 .69343 Mdot
.77868 .5496 Mdot
.26262 .72023 Mdot
.67705 .63827 Mdot
.69467 .46029 Mdot
.65679 .42235 Mdot
.26784 .67155 Mdot
.62039 .36497 Mdot
.65732 .38854 Mdot
.76915 .76793 Mdot
.61111 .36786 Mdot
.55736 .59883 Mdot
.61052 .63074 Mdot
.57507 .28927 Mdot
.44553 .72576 Mdot
.5786 .55901 Mdot
.59244 .59998 Mdot
.33723 .66055 Mdot
.5832 .70331 Mdot
.39088 .40092 Mdot
.26011 .31309 Mdot
.6333 .28247 Mdot
.57925 .57334 Mdot
.59062 .60772 Mdot
.6132 .53519 Mdot
.6837 .19248 Mdot
.73509 .47513 Mdot
.65031 .42882 Mdot
.55991 .50433 Mdot
.63746 .8 Mdot
.55795 .54504 Mdot
.5958 .622 Mdot
.61192 .58046 Mdot
.35147 .51347 Mdot
.66507 .41894 Mdot
.56389 .504 Mdot
.26603 .33797 Mdot
.60769 .55163 Mdot
.50089 .37547 Mdot
.37451 .78236 Mdot
.55921 .59445 Mdot
.65689 .35847 Mdot
.60272 .57422 Mdot
.63556 .37217 Mdot
.60707 .39337 Mdot
.6185 .54602 Mdot
.75899 .64526 Mdot
.67234 .38618 Mdot
.59993 .54849 Mdot
.35291 .53107 Mdot
.74761 .71461 Mdot
.56752 .59076 Mdot
.37343 .6635 Mdot
.56914 .60583 Mdot
.36667 .64678 Mdot
.58914 .55425 Mdot
.37403 .48547 Mdot
.74626 .40116 Mdot
.34946 .49607 Mdot
.41984 .79898 Mdot
.36372 .54442 Mdot
.44674 .20569 Mdot
.66823 .39489 Mdot
.37379 .40829 Mdot
.16177 .48319 Mdot
.38071 .41101 Mdot
.52494 .47205 Mdot
.47504 .51001 Mdot
.43139 .34224 Mdot
.63014 .42745 Mdot
.51369 .7842 Mdot
.34347 .35855 Mdot
.34742 .40979 Mdot
.36917 .45287 Mdot
.15519 .43473 Mdot
.18269 .41695 Mdot
.59438 .61305 Mdot
.73625 .64992 Mdot
.69035 .57076 Mdot
.59938 .62093 Mdot
.52469 .62631 Mdot
.32277 .55763 Mdot
.54424 .61598 Mdot
.53497 .41392 Mdot
.35202 .47414 Mdot
.35822 .68369 Mdot
.65369 .38719 Mdot
.37597 .65899 Mdot
.34611 .37484 Mdot
.47633 .51351 Mdot
.32801 .51346 Mdot
.57344 .52844 Mdot
.59868 .59143 Mdot
.61575 .37889 Mdot
.64907 .44292 Mdot
.60401 .40441 Mdot
.35291 .70048 Mdot
.34908 .48009 Mdot
.73432 .46034 Mdot
.58707 .59639 Mdot
.62685 .39992 Mdot
.42322 .26859 Mdot
.58747 .60311 Mdot
.45236 .3091 Mdot
.6154 .57791 Mdot
.62139 .42029 Mdot
.58498 .55725 Mdot
.63275 .40485 Mdot
.35967 .47872 Mdot
.56248 .54243 Mdot
.5904 .58802 Mdot
.5351 .1651 Mdot
.36523 .66537 Mdot
.66746 .39703 Mdot
.44946 .45645 Mdot
.5248 .56794 Mdot
.30589 .38071 Mdot
.54491 .60363 Mdot
.59638 .34732 Mdot
.54349 .53095 Mdot
.37668 .41031 Mdot
.58108 .65748 Mdot
.56651 .59018 Mdot
.48132 .52889 Mdot
.70075 .6208 Mdot
.63384 .44791 Mdot
.42866 .35378 Mdot
.66441 .36404 Mdot
.34833 .58353 Mdot
.37038 .44001 Mdot
.33862 .56811 Mdot
.42599 .74041 Mdot
.62006 .55114 Mdot
.5517 .57893 Mdot
.4912 .32043 Mdot
.35872 .68849 Mdot
.62129 .39715 Mdot
.35344 .68871 Mdot
.29871 .28133 Mdot
.34771 .69921 Mdot
.37586 .4818 Mdot
.27052 .55932 Mdot
.75269 .44944 Mdot
.33645 .66215 Mdot
.60415 .4082 Mdot
.2695 .58557 Mdot
.55183 .63104 Mdot
.37774 .71044 Mdot
.3537 .66917 Mdot
.15167 .4215 Mdot
.55082 .61862 Mdot
.53155 .46203 Mdot
.47713 .3167 Mdot
.34054 .68702 Mdot
.45195 .34088 Mdot
.57912 .56203 Mdot
.29128 .35624 Mdot
.66012 .38142 Mdot
.43957 .29148 Mdot
.51403 .59931 Mdot
.35894 .69567 Mdot
.33135 .51188 Mdot
.50088 .34399 Mdot
.43794 .35311 Mdot
.74852 .35739 Mdot
.57903 .7754 Mdot
.35042 .47839 Mdot
.20702 .49863 Mdot
.45041 .34798 Mdot
.59407 .62607 Mdot
.59246 .68613 Mdot
.54093 .55561 Mdot
.36879 .3843 Mdot
.36204 .5123 Mdot
.53652 .28537 Mdot
.60053 .59161 Mdot
.54711 .61228 Mdot
.67865 .36548 Mdot
.35657 .47666 Mdot
.63915 .38714 Mdot
.64596 .35792 Mdot
.36034 .47661 Mdot
.642 .39863 Mdot
.33437 .68816 Mdot
.52265 .25104 Mdot
.45179 .34897 Mdot
.44659 .33173 Mdot
.34048 .51338 Mdot
.35402 .54434 Mdot
.35622 .51442 Mdot
.61536 .57681 Mdot
.62041 .39164 Mdot
.60585 .56346 Mdot
.61251 .6048 Mdot
.59462 .45327 Mdot
.60099 .37519 Mdot
.60795 .57919 Mdot
.25984 .41999 Mdot
.39361 .67419 Mdot
.35106 .53933 Mdot
.47951 .3261 Mdot
.66737 .26731 Mdot
.48152 .29164 Mdot
.55027 .59232 Mdot
.37262 .26367 Mdot
.61479 .41487 Mdot
.33671 .67047 Mdot
.38001 .64655 Mdot
.34368 .66034 Mdot
.48471 .35454 Mdot
.65721 .36771 Mdot
.25905 .31545 Mdot
.55131 .58853 Mdot
.52348 .42438 Mdot
.52675 .78461 Mdot
.3038 .28627 Mdot
.48016 .33192 Mdot
.58955 .60383 Mdot
.38398 .41344 Mdot
.78478 .49588 Mdot
.53149 .57523 Mdot
.52642 .60083 Mdot
.29474 .48058 Mdot
.62612 .65441 Mdot
.67432 .38928 Mdot
.38061 .22154 Mdot
.60971 .62829 Mdot
.59647 .46518 Mdot
.43931 .8567 Mdot
.54464 .59356 Mdot
.56528 .61572 Mdot
.57625 .58961 Mdot
.59795 .57766 Mdot
.66566 .36268 Mdot
.46549 .77072 Mdot
.42816 .35666 Mdot
.5082 .43752 Mdot
.44869 .35067 Mdot
.32646 .49461 Mdot
.54697 .4508 Mdot
.61566 .42768 Mdot
.33567 .67094 Mdot
.77555 .40403 Mdot
.33887 .23894 Mdot
.34509 .47223 Mdot
.76062 .50788 Mdot
.35526 .66352 Mdot
.57121 .64338 Mdot
.37878 .65934 Mdot
.37178 .50279 Mdot
.43723 .33881 Mdot
.60993 .63863 Mdot
.60185 .38583 Mdot
.62082 .4242 Mdot
.58424 .61012 Mdot
.65907 .79201 Mdot
.453 .30748 Mdot
.44572 .2789 Mdot
.60781 .60043 Mdot
.5259 .60078 Mdot
.64339 .38762 Mdot
.34568 .5329 Mdot
.21493 .60208 Mdot
.36509 .67491 Mdot
.53827 .54658 Mdot
.59612 .57345 Mdot
.37701 .23207 Mdot
.43598 .31142 Mdot
.38141 .4373 Mdot
.60366 .60407 Mdot
.43807 .24126 Mdot
.60434 .60224 Mdot
.60674 .65383 Mdot
.35237 .52535 Mdot
.5549 .51833 Mdot
.58539 .62581 Mdot
.53632 .51163 Mdot
.45116 .34552 Mdot
.6536 .40814 Mdot
.67128 .36161 Mdot
.38927 .40943 Mdot
.45395 .3096 Mdot
.60616 .57792 Mdot
.43836 .31114 Mdot
.59928 .62486 Mdot
.58333 .61946 Mdot
.47909 .33504 Mdot
.63944 .38767 Mdot
.57397 .33115 Mdot
.55154 .46668 Mdot
.59998 .58211 Mdot
.59341 .65191 Mdot
.43684 .73855 Mdot
.17179 .59456 Mdot
.55464 .61046 Mdot
.6219 .42207 Mdot
.58963 .59482 Mdot
.45883 .33493 Mdot
.34744 .69762 Mdot
.62688 .41989 Mdot
.33897 .53052 Mdot
.35374 .46238 Mdot
.62266 .24605 Mdot
.37703 .46393 Mdot
.55447 .63769 Mdot
.63514 .33597 Mdot
.59186 .39134 Mdot
.49724 .85412 Mdot
.36155 .47311 Mdot
.33994 .64847 Mdot
.58623 .57087 Mdot
.3924 .25921 Mdot
.49075 .33039 Mdot
.81544 .29923 Mdot
.25521 .31886 Mdot
.32169 .67429 Mdot
.17502 .4864 Mdot
.38152 .42154 Mdot
.57339 .62976 Mdot
.34444 .65233 Mdot
.33619 .48495 Mdot
.57177 .63939 Mdot
.51115 .62673 Mdot
.38991 .75826 Mdot
.31449 .52274 Mdot
.44524 .30657 Mdot
.33333 .56188 Mdot
.38279 .68209 Mdot
.37556 .48255 Mdot
.6132 .42354 Mdot
.5634 .58679 Mdot
.59449 .51459 Mdot
.34254 .53437 Mdot
.37415 .49116 Mdot
.61332 .5755 Mdot
.63738 .42428 Mdot
.34419 .56757 Mdot
.57379 .56775 Mdot
.71707 .43774 Mdot
.59072 .44011 Mdot
.34254 .49073 Mdot
.53755 .60602 Mdot
.65558 .59081 Mdot
.33847 .52069 Mdot
.34967 .54243 Mdot
.58459 .61281 Mdot
.33244 .68371 Mdot
.60887 .54971 Mdot
.47295 .33234 Mdot
.34357 .75842 Mdot
.45624 .33491 Mdot
.33918 .59537 Mdot
.63849 .60471 Mdot
.28187 .37613 Mdot
.60428 .41842 Mdot
.38437 .67803 Mdot
.67492 .26443 Mdot
.52782 .60833 Mdot
.80294 .6079 Mdot
.47348 .40289 Mdot
.62113 .82164 Mdot
.77269 .3292 Mdot
.35184 .67291 Mdot
.45715 .31265 Mdot
.5658 .61524 Mdot
.48548 .31215 Mdot
.35574 .65171 Mdot
.53585 .79256 Mdot
.53611 .60572 Mdot
.62376 .38314 Mdot
.60951 .55575 Mdot
.6421 .37621 Mdot
.58547 .60423 Mdot
.62252 .65592 Mdot
.35144 .43827 Mdot
.42137 .64628 Mdot
.55888 .6364 Mdot
.67141 .22405 Mdot
.41587 .48237 Mdot
.35959 .66971 Mdot
.60343 .55512 Mdot
.37482 .43865 Mdot
.42213 .31705 Mdot
.49268 .65474 Mdot
.35293 .51644 Mdot
.48032 .31001 Mdot
.64797 .39474 Mdot
.36306 .47586 Mdot
.37192 .44652 Mdot
.52812 .52491 Mdot
.36199 .64553 Mdot
.42981 .3368 Mdot
.564 .59237 Mdot
.55028 .61725 Mdot
.22178 .51784 Mdot
.39653 .52138 Mdot
.68628 .38366 Mdot
.4867 .16719 Mdot
.6412 .34914 Mdot
.3685 .67501 Mdot
.3537 .52313 Mdot
.55268 .60793 Mdot
.54683 .56049 Mdot
.36981 .41033 Mdot
.66624 .39828 Mdot
.32086 .50213 Mdot
.73577 .49891 Mdot
.36708 .50684 Mdot
.48819 .75586 Mdot
.64211 .41876 Mdot
.48357 .75606 Mdot
.38307 .67908 Mdot
.80309 .5768 Mdot
.4724 .6911 Mdot
.47668 .31405 Mdot
.49329 .75732 Mdot
.61465 .40487 Mdot
.59741 .60485 Mdot
.38077 .4263 Mdot
.3786 .45172 Mdot
.64977 .3877 Mdot
.33827 .47258 Mdot
.3407 .68535 Mdot
.56796 .61873 Mdot
.23735 .38146 Mdot
.58019 .25922 Mdot
.34039 .54165 Mdot
.5873 .66597 Mdot
.44686 .33962 Mdot
.57564 .62693 Mdot
.37493 .66761 Mdot
.43295 .32878 Mdot
.37715 .51886 Mdot
.52338 .2677 Mdot
.57688 .56417 Mdot
.4084 .22819 Mdot
.44338 .31337 Mdot
.18873 .53887 Mdot
.57122 .57177 Mdot
.45039 .34781 Mdot
.64287 .6228 Mdot
.29792 .30196 Mdot
.45696 .42646 Mdot
.79266 .65171 Mdot
.31426 .51702 Mdot
.34484 .46443 Mdot
.32019 .31912 Mdot
.33311 .41621 Mdot
.47887 .30286 Mdot
.37529 .48304 Mdot
.5559 .73007 Mdot
.45044 .34216 Mdot
.61338 .59829 Mdot
.54488 .60011 Mdot
.71781 .4856 Mdot
.48381 .42029 Mdot
.37482 .49288 Mdot
.54728 .21251 Mdot
.52479 .57 Mdot
.50784 .56877 Mdot
.54935 .56312 Mdot
.62806 .43619 Mdot
.42786 .3267 Mdot
.57821 .17583 Mdot
.46052 .30929 Mdot
.21576 .40591 Mdot
.34427 .49822 Mdot
.35803 .54156 Mdot
.55605 .59442 Mdot
.26166 .3964 Mdot
.61024 .71738 Mdot
.55923 .54837 Mdot
.27954 .40545 Mdot
.59164 .77444 Mdot
.51197 .59525 Mdot
.67616 .39086 Mdot
.62003 .61797 Mdot
.60101 .43267 Mdot
.44037 .35107 Mdot
.3458 .67534 Mdot
.3706 .70795 Mdot
.43108 .33691 Mdot
.55182 .57716 Mdot
.28682 .40747 Mdot
.53489 .57955 Mdot
.59858 .60923 Mdot
.21398 .38822 Mdot
.32366 .68559 Mdot
.358 .50684 Mdot
.35831 .65518 Mdot
.6579 .38828 Mdot
.91751 .54822 Mdot
.35536 .69119 Mdot
.63924 .68224 Mdot
.45915 .79896 Mdot
.48982 .75846 Mdot
.62343 .42526 Mdot
.36135 .70456 Mdot
.4564 .30521 Mdot
.66183 .81277 Mdot
.18149 .61678 Mdot
.46801 .28329 Mdot
.56634 .56583 Mdot
.61373 .42914 Mdot
.59972 .40322 Mdot
.42977 .29631 Mdot
.60849 .39767 Mdot
.62077 .53531 Mdot
.6026 .59495 Mdot
.47995 .30522 Mdot
.57961 .27708 Mdot
.43605 .35259 Mdot
.50592 .24427 Mdot
.60686 .55668 Mdot
.6367 .42015 Mdot
.62587 .59788 Mdot
.60102 .35657 Mdot
.38479 .43535 Mdot
.57846 .64134 Mdot
.33732 .68073 Mdot
.51384 .41281 Mdot
.34433 .49015 Mdot
.37078 .26821 Mdot
.61815 .37756 Mdot
.40609 .36052 Mdot
.60999 .39087 Mdot
.62722 .43194 Mdot
.44009 .30465 Mdot
.64859 .36666 Mdot
.56535 .61669 Mdot
.24312 .45555 Mdot
.63355 .36971 Mdot
.45466 .3219 Mdot
.34237 .67016 Mdot
.64093 .39508 Mdot
.32101 .5553 Mdot
.59078 .58028 Mdot
.32426 .52798 Mdot
.34521 .44008 Mdot
.6378 .42583 Mdot
.35614 .70509 Mdot
.3627 .51752 Mdot
.35768 .64644 Mdot
.56748 .79963 Mdot
.48066 .34461 Mdot
.18532 .48681 Mdot
.6489 .56669 Mdot
.60051 .38639 Mdot
.34642 .44131 Mdot
.55403 .60634 Mdot
.59117 .57866 Mdot
.37586 .69531 Mdot
.59936 .40234 Mdot
.72262 .73596 Mdot
.61454 .33317 Mdot
.52757 .25913 Mdot
.47475 .355 Mdot
.51047 .18182 Mdot
.51011 .27925 Mdot
.44762 .82395 Mdot
.52578 .53423 Mdot
.3811 .42229 Mdot
.54461 .58206 Mdot
.68492 .2738 Mdot
.35648 .69804 Mdot
.22982 .64387 Mdot
.61266 .54048 Mdot
.35657 .49675 Mdot
.57805 .58231 Mdot
.45891 .59524 Mdot
.62347 .61993 Mdot
.33063 .68392 Mdot
.51268 .36256 Mdot
.63008 .35829 Mdot
.3522 .6617 Mdot
.35504 .46458 Mdot
.56377 .74871 Mdot
.56699 .63761 Mdot
.51879 .59479 Mdot
.36794 .50929 Mdot
.61907 .3855 Mdot
.32351 .50476 Mdot
.45131 .34896 Mdot
.34812 .68395 Mdot
.59012 .57167 Mdot
.56037 .52767 Mdot
.30719 .38276 Mdot
.42598 .33077 Mdot
.36514 .51711 Mdot
.47054 .31668 Mdot
.3814 .42328 Mdot
.60016 .64896 Mdot
.35608 .54662 Mdot
.56426 .63004 Mdot
.61486 .21223 Mdot
.21147 .39789 Mdot
.70795 .62246 Mdot
.35876 .49607 Mdot
.50201 .74489 Mdot
.46131 .32802 Mdot
.4714 .3288 Mdot
.66196 .56644 Mdot
.55294 .70598 Mdot
.28392 .58084 Mdot
.75453 .36022 Mdot
.452 .34952 Mdot
.45335 .33297 Mdot
.32614 .50714 Mdot
.64754 .36817 Mdot
.60122 .42853 Mdot
.35213 .45439 Mdot
.40955 .69388 Mdot
.62143 .39721 Mdot
.79081 .62649 Mdot
.34557 .58232 Mdot
.51353 .54525 Mdot
.3813 .37688 Mdot
.34285 .68112 Mdot
.41568 .67659 Mdot
.46064 .58748 Mdot
.55267 .61417 Mdot
.38909 .21709 Mdot
.34603 .52707 Mdot
.43874 .7697 Mdot
.83146 .5072 Mdot
.53399 .60419 Mdot
.56547 .57552 Mdot
.54836 .57257 Mdot
.32692 .69654 Mdot
.70795 .34919 Mdot
.5546 .61819 Mdot
.40405 .70174 Mdot
.52651 .56235 Mdot
.45038 .65415 Mdot
.36108 .65625 Mdot
.62482 .47084 Mdot
.32279 .48336 Mdot
.26685 .32355 Mdot
.57478 .48273 Mdot
.45935 .34445 Mdot
.35883 .44308 Mdot
.44117 .34865 Mdot
.7071 .68978 Mdot
.47419 .69521 Mdot
.67921 .39647 Mdot
.55781 .6153 Mdot
.37012 .45677 Mdot
.60269 .40843 Mdot
.32076 .36395 Mdot
.8186 .71856 Mdot
.42348 .34003 Mdot
.17748 .66411 Mdot
.47251 .32429 Mdot
.38236 .44152 Mdot
.64511 .38818 Mdot
.77163 .55893 Mdot
.5248 .42364 Mdot
.64008 .3976 Mdot
.56008 .33199 Mdot
.62432 .34955 Mdot
.50286 .75124 Mdot
.59661 .37452 Mdot
.45806 .323 Mdot
.49609 .33758 Mdot
.50692 .56175 Mdot
.55938 .60275 Mdot
.47274 .51921 Mdot
.65199 .65028 Mdot
.55755 .60526 Mdot
.35227 .47423 Mdot
.1817 .53563 Mdot
.35769 .44747 Mdot
.62059 .36752 Mdot
.42245 .34687 Mdot
.56822 .57689 Mdot
.60441 .5896 Mdot
.57836 .63543 Mdot
.51338 .15622 Mdot
.77896 .64093 Mdot
.58792 .61789 Mdot
.55173 .54041 Mdot
.35956 .48191 Mdot
.3281 .64203 Mdot
.71678 .29191 Mdot
.52777 .71517 Mdot
.52991 .56924 Mdot
.36152 .6596 Mdot
.32612 .6652 Mdot
.56898 .6401 Mdot
.25241 .37248 Mdot
.23896 .46018 Mdot
.56447 .59237 Mdot
.47175 .6726 Mdot
.3427 .38142 Mdot
.37699 .47441 Mdot
.34158 .5311 Mdot
.65338 .35758 Mdot
.37353 .45271 Mdot
.36014 .55225 Mdot
.77639 .53314 Mdot
.38874 .40521 Mdot
.48974 .27479 Mdot
.3531 .70049 Mdot
.54178 .56401 Mdot
.64321 .34753 Mdot
.37183 .3957 Mdot
.4317 .3413 Mdot
.62934 .41358 Mdot
.42042 .31875 Mdot
.32338 .6588 Mdot
.40835 .7537 Mdot
.37995 .45056 Mdot
.45965 .34802 Mdot
.52197 .26656 Mdot
.36155 .65862 Mdot
.46157 .30162 Mdot
.28843 .37808 Mdot
.60898 .61905 Mdot
.79039 .56935 Mdot
.57601 .54485 Mdot
.65793 .80182 Mdot
.45876 .302 Mdot
.38377 .40217 Mdot
.55504 .58192 Mdot
.33855 .5101 Mdot
.63978 .61906 Mdot
.53112 .57018 Mdot
.33539 .5299 Mdot
.59478 .61178 Mdot
.37278 .65915 Mdot
.59167 .43253 Mdot
.48018 .39408 Mdot
.26443 .25421 Mdot
.36491 .64821 Mdot
.31565 .36585 Mdot
.55532 .61148 Mdot
.5782 .78117 Mdot
.63929 .3951 Mdot
.5312 .60555 Mdot
.6369 .49957 Mdot
.6478 .37258 Mdot
.63918 .41103 Mdot
.59542 .56184 Mdot
.47408 .31211 Mdot
.33825 .50422 Mdot
.35788 .65662 Mdot
.49949 .84166 Mdot
.56236 .55943 Mdot
.59021 .59108 Mdot
.35401 .66286 Mdot
.4547 .33433 Mdot
.60401 .5852 Mdot
.38575 .30593 Mdot
.5725 .8462 Mdot
.42353 .32319 Mdot
.61851 .59699 Mdot
.7975 .46334 Mdot
.61623 .34576 Mdot
.17212 .63332 Mdot
.38613 .63537 Mdot
.36064 .51706 Mdot
.62816 .6529 Mdot
.87157 .40081 Mdot
.34428 .67544 Mdot
.26235 .32018 Mdot
.59669 .61511 Mdot
.58289 .59453 Mdot
.60963 .41019 Mdot
.60683 .57004 Mdot
.66372 .39525 Mdot
.2198 .30883 Mdot
.42168 .18573 Mdot
.62383 .37771 Mdot
.6053 .37544 Mdot
.65987 .58171 Mdot
.71023 .28831 Mdot
.65242 .39186 Mdot
.62104 .57776 Mdot
.72811 .70962 Mdot
.51165 .54059 Mdot
.37537 .6967 Mdot
.33589 .44331 Mdot
.63925 .45751 Mdot
.39541 .57509 Mdot
.62927 .32075 Mdot
.56468 .48395 Mdot
.40588 .43928 Mdot
.47368 .33563 Mdot
.52619 .5872 Mdot
.37778 .45911 Mdot
.34378 .56436 Mdot
.62561 .6244 Mdot
.53557 .56991 Mdot
.63938 .373 Mdot
.32816 .69383 Mdot
.43728 .3015 Mdot
.5927 .59913 Mdot
.31773 .55213 Mdot
.36195 .6817 Mdot
.62211 .36879 Mdot
.66703 .60032 Mdot
.32939 .66569 Mdot
.59498 .65874 Mdot
.57269 .60446 Mdot
.6133 .57997 Mdot
.64506 .56324 Mdot
.46591 .35561 Mdot
.36057 .37669 Mdot
.61751 .56558 Mdot
.3043 .2761 Mdot
.41878 .61226 Mdot
.56096 .52048 Mdot
.61527 .39819 Mdot
.48853 .34154 Mdot
.38565 .43077 Mdot
.56033 .76212 Mdot
.57062 .5608 Mdot
.77425 .64544 Mdot
.73378 .48303 Mdot
.37303 .4416 Mdot
.66039 .41838 Mdot
.33756 .66772 Mdot
.55278 .55186 Mdot
.71584 .70276 Mdot
.54601 .59774 Mdot
.6546 .59766 Mdot
.35099 .53401 Mdot
.47419 .33709 Mdot
.60804 .83135 Mdot
.34447 .56364 Mdot
.64112 .41164 Mdot
.80272 .64461 Mdot
.59836 .41766 Mdot
.63861 .35937 Mdot
.74565 .66052 Mdot
.46289 .35572 Mdot
.86186 .38111 Mdot
.17756 .61828 Mdot
.5955 .52906 Mdot
.46387 .3305 Mdot
.64184 .38076 Mdot
.57504 .62652 Mdot
.5946 .38572 Mdot
.65948 .37443 Mdot
.58618 .64044 Mdot
.57829 .60127 Mdot
.54784 .46499 Mdot
.82077 .56479 Mdot
.34132 .66103 Mdot
.65397 .41292 Mdot
.68544 .4733 Mdot
.56099 .62413 Mdot
.55197 .58853 Mdot
.33485 .36354 Mdot
.33071 .67957 Mdot
.48348 .53362 Mdot
.60198 .60608 Mdot
.42506 .1985 Mdot
.60236 .65095 Mdot
.67414 .37039 Mdot
.42442 .32142 Mdot
.25368 .36151 Mdot
.36964 .38399 Mdot
.66587 .40198 Mdot
.37333 .68373 Mdot
.67965 .36966 Mdot
.64334 .67533 Mdot
.45189 .3551 Mdot
.62135 .42028 Mdot
.33198 .47874 Mdot
.43879 .32707 Mdot
.46188 .30232 Mdot
.70045 .72468 Mdot
.36459 .49582 Mdot
.36228 .69964 Mdot
.43896 .34093 Mdot
.72404 .42536 Mdot
.45685 .31744 Mdot
.69485 .48316 Mdot
.57183 .54146 Mdot
.39609 .73123 Mdot
.52069 .3042 Mdot
.64756 .62913 Mdot
.47197 .3532 Mdot
.35424 .65251 Mdot
.59609 .56776 Mdot
.60797 .39973 Mdot
.35312 .69083 Mdot
.47435 .37782 Mdot
.35172 .54422 Mdot
.60954 .38632 Mdot
.42837 .35754 Mdot
.6513 .41381 Mdot
.49881 .7823 Mdot
.36117 .76294 Mdot
.39158 .28656 Mdot
.5248 .43531 Mdot
.58164 .63356 Mdot
.68329 .31219 Mdot
.57317 .64732 Mdot
.53304 .57382 Mdot
.3423 .49166 Mdot
.42514 .74158 Mdot
.63977 .38705 Mdot
.61011 .83326 Mdot
.46459 .3461 Mdot
.39238 .2075 Mdot
.57536 .42949 Mdot
.52363 .59337 Mdot
.63779 .37015 Mdot
.59382 .40756 Mdot
.69871 .62555 Mdot
.34665 .57336 Mdot
.51937 .63441 Mdot
.57272 .65085 Mdot
.52162 .54316 Mdot
.45964 .30269 Mdot
.35709 .28109 Mdot
.3323 .48404 Mdot
.27729 .74665 Mdot
.34851 .53877 Mdot
.27603 .47871 Mdot
.64432 .36412 Mdot
.34572 .6953 Mdot
.55415 .58946 Mdot
.56967 .4137 Mdot
.66278 .41251 Mdot
.36966 .63602 Mdot
.33574 .68099 Mdot
.32424 .29637 Mdot
.47881 .33734 Mdot
.55612 .63263 Mdot
.54035 .60875 Mdot
.60284 .5587 Mdot
.58523 .54376 Mdot
.42247 .33883 Mdot
.60932 .60663 Mdot
.4713 .29281 Mdot
.72487 .43774 Mdot
.40837 .19748 Mdot
.36844 .43302 Mdot
.51499 .67889 Mdot
.60542 .38238 Mdot
.72076 .41085 Mdot
.56336 .6681 Mdot
.20054 .41739 Mdot
.6207 .78112 Mdot
.52948 .62632 Mdot
.33166 .49166 Mdot
.56069 .70186 Mdot
.371 .49245 Mdot
.10401 .52077 Mdot
.30877 .39813 Mdot
.79852 .63198 Mdot
.56713 .62382 Mdot
.33678 .36357 Mdot
.58206 .67356 Mdot
.58595 .64362 Mdot
.32463 .39936 Mdot
.51913 .20593 Mdot
.56503 .30265 Mdot
.32728 .66501 Mdot
.58486 .5754 Mdot
.59221 .3799 Mdot
.56489 .618 Mdot
.54741 .58745 Mdot
.59447 .62014 Mdot
.41991 .34994 Mdot
.61205 .6344 Mdot
.61635 .58023 Mdot
.40803 .53225 Mdot
.46832 .72878 Mdot
.33182 .55892 Mdot
.66439 .65546 Mdot
.35758 .68832 Mdot
.62787 .37204 Mdot
.55012 .39577 Mdot
.47738 .31513 Mdot
.69343 .59977 Mdot
.61364 .56531 Mdot
.52313 .29507 Mdot
.42966 .35865 Mdot
.34695 .68614 Mdot
.38862 .41766 Mdot
.75864 .69942 Mdot
.3711 .45844 Mdot
.38927 .4061 Mdot
.34542 .4902 Mdot
.68698 .4281 Mdot
.64179 .37379 Mdot
.5839 .63411 Mdot
.44292 .33961 Mdot
.33493 .50943 Mdot
.43725 .72601 Mdot
.54798 .56516 Mdot
.35822 .48091 Mdot
.58702 .63103 Mdot
.39345 .74722 Mdot
.21696 .53303 Mdot
.36682 .53592 Mdot
.47324 .366 Mdot
.444 .32511 Mdot
.33632 .69173 Mdot
.6199 .37304 Mdot
.61294 .41093 Mdot
.4341 .32706 Mdot
.15758 .56518 Mdot
.52926 .57366 Mdot
.57043 .62628 Mdot
.30878 .27163 Mdot
.56535 .61062 Mdot
.54759 .75054 Mdot
.3925 .40433 Mdot
.61311 .37418 Mdot
.58105 .62543 Mdot
.60164 .58234 Mdot
.58163 .56732 Mdot
.49221 .78362 Mdot
.34458 .53751 Mdot
.53072 .56207 Mdot
.33342 .66495 Mdot
.39603 .42442 Mdot
.56919 .62738 Mdot
.51946 .54863 Mdot
.61548 .41234 Mdot
.4012 .18902 Mdot
.47587 .3262 Mdot
.3488 .47212 Mdot
.36128 .52733 Mdot
.3375 .43881 Mdot
.6013 .46043 Mdot
.39147 .40557 Mdot
.32569 .76314 Mdot
.38153 .40682 Mdot
.35977 .66506 Mdot
.29807 .52121 Mdot
.38038 .59993 Mdot
.33643 .48828 Mdot
.42157 .3114 Mdot
.60685 .54975 Mdot
.53701 .55603 Mdot
.24973 .32875 Mdot
.52054 .58491 Mdot
.33847 .67356 Mdot
.46375 .29007 Mdot
.61694 .40527 Mdot
.34386 .68584 Mdot
.47073 .32366 Mdot
.61738 .38757 Mdot
.60497 .62581 Mdot
.61326 .61324 Mdot
.63269 .41158 Mdot
.60334 .40795 Mdot
.56558 .59658 Mdot
.39643 .44568 Mdot
.64536 .35689 Mdot
.63012 .42168 Mdot
.37971 .45527 Mdot
.37049 .45241 Mdot
.56124 .50638 Mdot
.46617 .32653 Mdot
.6124 .58864 Mdot
.37099 .46751 Mdot
.33468 .69712 Mdot
.63609 .39086 Mdot
.60188 .58608 Mdot
.5965 .59927 Mdot
.35759 .65786 Mdot
.32562 .68148 Mdot
.34318 .68824 Mdot
.47257 .29039 Mdot
.58879 .54932 Mdot
.65146 .39538 Mdot
.47421 .34446 Mdot
.32642 .66444 Mdot
.37084 .64677 Mdot
.43713 .52966 Mdot
.5507 .60827 Mdot
.44846 .43061 Mdot
.91319 .53978 Mdot
.55155 .73716 Mdot
.3857 .43181 Mdot
.36736 .49966 Mdot
.45897 .7517 Mdot
.23818 .48835 Mdot
.44266 .31179 Mdot
.57728 .72723 Mdot
.38447 .67964 Mdot
.58899 .6332 Mdot
.59496 .6517 Mdot
.52508 .62812 Mdot
.35526 .68257 Mdot
.51996 .77798 Mdot
.59921 .41111 Mdot
.6706 .5255 Mdot
.35705 .68823 Mdot
.3663 .5389 Mdot
.3589 .54453 Mdot
.34894 .53867 Mdot
.60603 .64047 Mdot
.70461 .60871 Mdot
.70708 .43786 Mdot
.71475 .32161 Mdot
.48175 .32024 Mdot
.67825 .4043 Mdot
.56752 .79517 Mdot
.63778 .40983 Mdot
.34647 .56321 Mdot
.35904 .68024 Mdot
.61646 .42027 Mdot
.42767 .34118 Mdot
.4513 .33395 Mdot
.34437 .54123 Mdot
.34125 .51132 Mdot
.32527 .52857 Mdot
.65637 .36339 Mdot
.64736 .36585 Mdot
.56666 .55706 Mdot
.63148 .39982 Mdot
.3296 .23161 Mdot
.32204 .69041 Mdot
.35697 .54961 Mdot
.45961 .31261 Mdot
.63897 .37501 Mdot
.54923 .56154 Mdot
.28811 .54826 Mdot
.61332 .24744 Mdot
.36125 .64842 Mdot
.21569 .51766 Mdot
.11431 .54637 Mdot
.55161 .62542 Mdot
.44345 .30695 Mdot
.23212 .39751 Mdot
.54997 .56993 Mdot
.3503 .51784 Mdot
.64173 .22786 Mdot
.37172 .43889 Mdot
.61293 .59771 Mdot
.52109 .58866 Mdot
.45699 .29928 Mdot
.46131 .80204 Mdot
.56378 .55486 Mdot
.47559 .2421 Mdot
.41807 .33978 Mdot
.32065 .54015 Mdot
.57626 .84942 Mdot
.35177 .37273 Mdot
.41636 .6807 Mdot
.37822 .44791 Mdot
.53745 .59237 Mdot
.34804 .47687 Mdot
.35725 .64855 Mdot
.33484 .49963 Mdot
.67224 .40647 Mdot
.32696 .54894 Mdot
.58903 .59074 Mdot
.65395 .3932 Mdot
.44511 .31214 Mdot
.3742 .22217 Mdot
.39901 .53782 Mdot
.33865 .51096 Mdot
.38329 .44602 Mdot
.58212 .62844 Mdot
.51297 .49747 Mdot
.63962 .57879 Mdot
.56394 .62399 Mdot
.44521 .35177 Mdot
.63465 .36877 Mdot
.45952 .36187 Mdot
.53583 .54027 Mdot
.49799 .19975 Mdot
.47214 .31587 Mdot
.53096 .32996 Mdot
.35631 .66355 Mdot
.44959 .5566 Mdot
.54588 .55976 Mdot
.44146 .34282 Mdot
.5903 .5492 Mdot
.59641 .3798 Mdot
.473 .45103 Mdot
.37393 .35274 Mdot
.44328 .33822 Mdot
.70311 .75558 Mdot
.44585 .46174 Mdot
.62494 .59253 Mdot
.44723 .34855 Mdot
.64216 .49275 Mdot
.37784 .44318 Mdot
.36483 .67208 Mdot
.32627 .66542 Mdot
.35379 .6458 Mdot
.52504 .61173 Mdot
.50941 .62669 Mdot
.37498 .68542 Mdot
.42381 .31799 Mdot
.33044 .68552 Mdot
.56674 .42519 Mdot
.71351 .74714 Mdot
.36256 .69358 Mdot
.57208 .56982 Mdot
.50515 .57614 Mdot
.46376 .72765 Mdot
.34858 .56409 Mdot
.80609 .60245 Mdot
.53559 .67885 Mdot
.55645 .60146 Mdot
.49269 .57401 Mdot
.60217 .41334 Mdot
.22837 .41952 Mdot
.65113 .64921 Mdot
.23183 .49386 Mdot
.6155 .36532 Mdot
.37162 .40729 Mdot
.6172 .37269 Mdot
.55806 .62966 Mdot
.5812 .62042 Mdot
.59512 .42402 Mdot
.37867 .24862 Mdot
.29503 .34673 Mdot
.5749 .82718 Mdot
.6297 .42307 Mdot
.45075 .34543 Mdot
.42338 .34142 Mdot
.48114 .32104 Mdot
.34735 .58263 Mdot
.64978 .41875 Mdot
.58194 .55167 Mdot
.36029 .48216 Mdot
.52775 .58262 Mdot
.43723 .33471 Mdot
.61706 .82874 Mdot
.61545 .4098 Mdot
.56582 .59056 Mdot
.18108 .60927 Mdot
.34587 .50823 Mdot
.36583 .66338 Mdot
.40424 .75778 Mdot
.34308 .58161 Mdot
.45164 .35825 Mdot
.59617 .42046 Mdot
.49382 .37978 Mdot
.53656 .38073 Mdot
.53713 .52008 Mdot
.5796 .51653 Mdot
.4615 .83557 Mdot
.38204 .50462 Mdot
.56602 .64275 Mdot
.35385 .46404 Mdot
.36902 .41113 Mdot
.59892 .5847 Mdot
.61854 .42578 Mdot
.34955 .64051 Mdot
.33172 .66744 Mdot
.55949 .65672 Mdot
.52233 .42644 Mdot
.44423 .56504 Mdot
.60758 .58204 Mdot
.58519 .66439 Mdot
.36283 .52554 Mdot
.38443 .40457 Mdot
.35269 .23904 Mdot
.36868 .69027 Mdot
.60064 .61118 Mdot
.59483 .30636 Mdot
.65783 .37476 Mdot
.32468 .53913 Mdot
.44797 .3562 Mdot
.51295 .78926 Mdot
.31885 .52084 Mdot
.60015 .58672 Mdot
.6036 .58475 Mdot
.46184 .30142 Mdot
.67447 .37087 Mdot
.35661 .6804 Mdot
.36065 .50082 Mdot
.37012 .68936 Mdot
.65836 .38415 Mdot
.61806 .40861 Mdot
.51052 .5417 Mdot
.58214 .66339 Mdot
.3399 .52991 Mdot
.52815 .54862 Mdot
.35641 .55581 Mdot
.45158 .80435 Mdot
.46375 .36355 Mdot
.54765 .62202 Mdot
.64033 .43739 Mdot
.43593 .33889 Mdot
.57825 .59496 Mdot
.45206 .84439 Mdot
.52764 .59788 Mdot
.37434 .39022 Mdot
.47689 .20282 Mdot
.33973 .65865 Mdot
.66681 .67662 Mdot
.49274 .54226 Mdot
.56902 .61145 Mdot
.34874 .5527 Mdot
.64061 .61204 Mdot
.46774 .30704 Mdot
.63054 .36362 Mdot
.15537 .60936 Mdot
.45403 .31869 Mdot
.56953 .6214 Mdot
.34777 .68479 Mdot
.59565 .41449 Mdot
.37226 .42689 Mdot
.288 .29519 Mdot
.63271 .61998 Mdot
.62223 .57263 Mdot
.61216 .5962 Mdot
.71481 .27815 Mdot
.34564 .47686 Mdot
.64101 .37799 Mdot
.45854 .30295 Mdot
.4326 .32528 Mdot
.34743 .53542 Mdot
.55457 .2931 Mdot
.44952 .54536 Mdot
.8926 .4512 Mdot
.33315 .52668 Mdot
.35255 .70635 Mdot
.54052 .44306 Mdot
.34293 .55856 Mdot
.35637 .48263 Mdot
.36349 .51575 Mdot
.50128 .28673 Mdot
.61843 .39043 Mdot
.5965 .60193 Mdot
.62422 .3561 Mdot
.53652 .59322 Mdot
.43316 .61575 Mdot
.43321 .3388 Mdot
.6305 .36271 Mdot
.4635 .84171 Mdot
.60827 .34385 Mdot
.55821 .57017 Mdot
.54406 .80868 Mdot
.63452 .56666 Mdot
.51235 .76373 Mdot
.62689 .55825 Mdot
.34257 .49987 Mdot
.59345 .68252 Mdot
.52657 .54229 Mdot
.35592 .2229 Mdot
.46153 .31337 Mdot
.3839 .43947 Mdot
.54172 .63167 Mdot
.59901 .65458 Mdot
.58636 .39733 Mdot
.61831 .42166 Mdot
.37019 .69178 Mdot
.41329 .64291 Mdot
.44997 .30984 Mdot
.36724 .75952 Mdot
.56307 .60263 Mdot
.40772 .24663 Mdot
.67725 .62369 Mdot
.57699 .59384 Mdot
.73547 .70099 Mdot
.69963 .60507 Mdot
.54906 .55479 Mdot
.64686 .48115 Mdot
.45623 .33145 Mdot
.47569 .20754 Mdot
.57425 .53582 Mdot
.35106 .51495 Mdot
.64219 .36513 Mdot
.60553 .42256 Mdot
.37633 .66838 Mdot
.19719 .38643 Mdot
.47386 .35268 Mdot
.63679 .36215 Mdot
.54367 .57021 Mdot
.45776 .35776 Mdot
.37656 .46523 Mdot
.54868 .5325 Mdot
.59183 .72668 Mdot
.62823 .40114 Mdot
.55045 .54037 Mdot
.55854 .22527 Mdot
.41645 .66033 Mdot
.84549 .46076 Mdot
.48024 .31967 Mdot
.35219 .69575 Mdot
.61629 .53692 Mdot
.31933 .75202 Mdot
.51879 .61026 Mdot
.40146 .73254 Mdot
.59471 .45803 Mdot
.34666 .69714 Mdot
.55907 .57695 Mdot
.58209 .56324 Mdot
.53167 .42109 Mdot
.32601 .68829 Mdot
.53278 .60076 Mdot
.56162 .68255 Mdot
.62045 .38507 Mdot
.39169 .41926 Mdot
.62372 .40042 Mdot
.56659 .56635 Mdot
.50347 .61312 Mdot
.60817 .41053 Mdot
.34636 .77203 Mdot
.37866 .69951 Mdot
.47673 .32626 Mdot
.5537 .66065 Mdot
.58472 .54137 Mdot
.71246 .25013 Mdot
.38465 .43568 Mdot
.69809 .29716 Mdot
.31606 .53396 Mdot
.58614 .31926 Mdot
.35118 .36564 Mdot
.79356 .65862 Mdot
.38312 .22424 Mdot
.57637 .64982 Mdot
.48048 .66553 Mdot
.67013 .45948 Mdot
.45925 .36066 Mdot
.75693 .43788 Mdot
.55886 .60286 Mdot
.54558 .58555 Mdot
.32202 .52033 Mdot
.53614 .28959 Mdot
.24939 .37953 Mdot
.50967 .43166 Mdot
.35622 .676 Mdot
.65995 .39606 Mdot
.58678 .60509 Mdot
.41955 .58972 Mdot
.33014 .55264 Mdot
.39777 .2564 Mdot
.56314 .58549 Mdot
.19886 .43081 Mdot
.50995 .30966 Mdot
.47193 .35074 Mdot
.35526 .54631 Mdot
.34121 .58188 Mdot
.54217 .60343 Mdot
.43767 .35268 Mdot
.55996 .55515 Mdot
.43675 .47586 Mdot
.52304 .55703 Mdot
.36242 .69187 Mdot
.58732 .62864 Mdot
.50438 .40852 Mdot
.84602 .52135 Mdot
.6192 .69223 Mdot
.62105 .42959 Mdot
.3396 .57728 Mdot
.34435 .53555 Mdot
.61639 .41822 Mdot
.34352 .53144 Mdot
.68321 .55151 Mdot
.75189 .58275 Mdot
.35599 .67131 Mdot
.57492 .66714 Mdot
.37213 .68143 Mdot
.38589 .43477 Mdot
.5518 .60428 Mdot
.32628 .7665 Mdot
.33491 .52221 Mdot
.55747 .18382 Mdot
.45463 .315 Mdot
.38448 .43727 Mdot
.528 .56027 Mdot
.29858 .50919 Mdot
.3404 .56544 Mdot
.37216 .40224 Mdot
.57891 .56531 Mdot
.61135 .40515 Mdot
.5876 .56685 Mdot
.63324 .56991 Mdot
.38975 .41354 Mdot
.60854 .55266 Mdot
.47066 .3237 Mdot
.6645 .36418 Mdot
.74765 .71131 Mdot
.37169 .38926 Mdot
.54886 .61323 Mdot
.54533 .57036 Mdot
.59053 .39621 Mdot
.54745 .54465 Mdot
.4276 .34452 Mdot
.70809 .18207 Mdot
.35691 .66321 Mdot
.37336 .49334 Mdot
.35365 .37461 Mdot
.52658 .62324 Mdot
.60419 .57871 Mdot
.49823 .84389 Mdot
.37005 .33575 Mdot
.46237 .34044 Mdot
.63057 .64206 Mdot
.3597 .48662 Mdot
.34633 .68398 Mdot
.43174 .30621 Mdot
.61285 .57924 Mdot
.55336 .58578 Mdot
.35656 .6931 Mdot
.70414 .72837 Mdot
.22836 .49825 Mdot
.48061 .31217 Mdot
.59765 .68106 Mdot
.28229 .56009 Mdot
.52999 .57213 Mdot
.31875 .59624 Mdot
.62546 .42078 Mdot
.45745 .35254 Mdot
.71542 .31139 Mdot
.5913 .6288 Mdot
.4253 .33444 Mdot
.45358 .30961 Mdot
.58483 .52463 Mdot
.58258 .39569 Mdot
.66471 .37128 Mdot
.65623 .40907 Mdot
.36046 .2012 Mdot
.43364 .67688 Mdot
.32543 .52933 Mdot
.4554 .33288 Mdot
.3701 .51367 Mdot
.3274 .70022 Mdot
.42304 .59948 Mdot
.37004 .52376 Mdot
.60142 .40759 Mdot
.36201 .53991 Mdot
.5844 .5666 Mdot
.44291 .31286 Mdot
.33385 .49341 Mdot
.53795 .62735 Mdot
.48878 .53345 Mdot
.4285 .45529 Mdot
.35913 .64018 Mdot
.38696 .65283 Mdot
.58356 .61564 Mdot
.38553 .43048 Mdot
.56334 .59551 Mdot
.47555 .29861 Mdot
.53355 .39671 Mdot
.52664 .62029 Mdot
.33874 .51883 Mdot
.49845 .63314 Mdot
.34799 .57697 Mdot
.6378 .61918 Mdot
.57065 .5701 Mdot
.53103 .58219 Mdot
.56063 .55432 Mdot
.55111 .31933 Mdot
.47676 .35324 Mdot
.47372 .55892 Mdot
.34262 .44833 Mdot
.63591 .4035 Mdot
.65813 .42379 Mdot
.27488 .58619 Mdot
.37231 .52164 Mdot
.46498 .3278 Mdot
.53647 .56321 Mdot
.36666 .37835 Mdot
.62635 .82488 Mdot
.34965 .77656 Mdot
.37436 .63608 Mdot
.347 .46728 Mdot
.61996 .43113 Mdot
.33539 .56294 Mdot
.54075 .5958 Mdot
.59749 .528 Mdot
.78254 .6798 Mdot
.48579 .36054 Mdot
.35812 .6813 Mdot
.53221 .58512 Mdot
.41979 .66913 Mdot
.35959 .48227 Mdot
.36451 .51387 Mdot
.5279 .59451 Mdot
.67147 .39043 Mdot
.81089 .35586 Mdot
.47068 .35274 Mdot
.52172 .67619 Mdot
.69543 .36201 Mdot
.49575 .21824 Mdot
.43039 .33341 Mdot
.41251 .45887 Mdot
.3537 .45863 Mdot
.67983 .67803 Mdot
.63265 .40695 Mdot
.35876 .68423 Mdot
.57867 .51901 Mdot
.60211 .39855 Mdot
.3531 .45421 Mdot
.60837 .37619 Mdot
.57623 .63814 Mdot
.46638 .35983 Mdot
.35986 .52435 Mdot
.48415 .35528 Mdot
.60172 .43175 Mdot
.36938 .659 Mdot
.50731 .49042 Mdot
.7776 .46463 Mdot
.69785 .6029 Mdot
.53253 .56038 Mdot
.41147 .5927 Mdot
.59014 .55123 Mdot
.58537 .39145 Mdot
.5528 .55924 Mdot
.69743 .38914 Mdot
.3532 .54655 Mdot
.55447 .53933 Mdot
.61126 .60222 Mdot
.74685 .46009 Mdot
.56889 .58031 Mdot
.60281 .54083 Mdot
.54694 .55463 Mdot
.66539 .42883 Mdot
.61769 .63143 Mdot
.61473 .39583 Mdot
.28294 .30465 Mdot
.35559 .48247 Mdot
.35489 .63862 Mdot
.3338 .65912 Mdot
.39792 .72547 Mdot
.42321 .63118 Mdot
.54724 .29621 Mdot
.62604 .39272 Mdot
.4673 .31371 Mdot
.55666 .55509 Mdot
.7403 .34633 Mdot
.33809 .41361 Mdot
.36178 .48333 Mdot
.37317 .39036 Mdot
.64855 .59757 Mdot
.71602 .2775 Mdot
.53083 .55334 Mdot
.24818 .32236 Mdot
.52603 .63397 Mdot
.53158 .60519 Mdot
.33265 .57288 Mdot
.42093 .62894 Mdot
.52778 .56545 Mdot
.58672 .39679 Mdot
.36481 .6814 Mdot
.63882 .32944 Mdot
.26541 .44518 Mdot
.40269 .45636 Mdot
.77044 .50857 Mdot
.58025 .54808 Mdot
.35967 .51888 Mdot
.61017 .38569 Mdot
.36356 .23433 Mdot
.47326 .34527 Mdot
.51341 .29498 Mdot
.71164 .45237 Mdot
.50136 .82222 Mdot
.3615 .68216 Mdot
.70062 .72727 Mdot
.58978 .5923 Mdot
.35085 .585 Mdot
.58881 .63811 Mdot
.63041 .82206 Mdot
.35853 .7054 Mdot
.67058 .40174 Mdot
.45232 .3449 Mdot
.5992 .37609 Mdot
.70606 .62717 Mdot
.39542 .33763 Mdot
.47922 .48275 Mdot
.37138 .46283 Mdot
.4785 .53771 Mdot
.6511 .38644 Mdot
.60643 .59659 Mdot
.90441 .48564 Mdot
.62919 .42108 Mdot
.66485 .40132 Mdot
.42415 .79791 Mdot
.42519 .803 Mdot
.63827 .64016 Mdot
.60158 .38191 Mdot
.36896 .46309 Mdot
.34996 .65524 Mdot
.58568 .56092 Mdot
.5701 .55609 Mdot
.61005 .40982 Mdot
.34766 .56246 Mdot
.53827 .68917 Mdot
.34196 .50545 Mdot
.61942 .38353 Mdot
.34934 .49709 Mdot
.36353 .40172 Mdot
.3457 .47261 Mdot
.57497 .54054 Mdot
.55367 .55806 Mdot
.25218 .49364 Mdot
.61818 .40847 Mdot
.60359 .57201 Mdot
.59225 .61615 Mdot
.65101 .39244 Mdot
.31527 .53292 Mdot
.75026 .37526 Mdot
.55722 .61339 Mdot
.5878 .57952 Mdot
.34984 .6971 Mdot
.38001 .59271 Mdot
.20727 .55373 Mdot
.59589 .56732 Mdot
.33933 .70368 Mdot
.65337 .36206 Mdot
.5668 .5954 Mdot
.56594 .42826 Mdot
.36681 .40881 Mdot
.59327 .62554 Mdot
.37264 .4458 Mdot
.51855 .59605 Mdot
.82069 .40105 Mdot
.5548 .62049 Mdot
.64265 .38337 Mdot
.64643 .37044 Mdot
.43705 .79527 Mdot
.64345 .41183 Mdot
.3781 .45131 Mdot
.43827 .33037 Mdot
.65301 .8067 Mdot
.37603 .46772 Mdot
.53025 .60788 Mdot
.17751 .61877 Mdot
.55314 .53651 Mdot
.53682 .62928 Mdot
.68612 .24985 Mdot
.3755 .4676 Mdot
.64434 .37321 Mdot
.47231 .26284 Mdot
.53863 .64706 Mdot
.45196 .35742 Mdot
.55086 .52471 Mdot
.61646 .56549 Mdot
.45129 .21772 Mdot
.63365 .24236 Mdot
.45765 .29016 Mdot
.535 .51769 Mdot
.59642 .5673 Mdot
.40235 .56352 Mdot
.54568 .56442 Mdot
.37158 .68493 Mdot
.66277 .40286 Mdot
.33371 .54967 Mdot
.35011 .6602 Mdot
.56518 .60677 Mdot
.35379 .68442 Mdot
.32465 .52978 Mdot
.44969 .35271 Mdot
.54609 .60347 Mdot
.37196 .70158 Mdot
.35567 .6776 Mdot
.59689 .55456 Mdot
.63571 .36301 Mdot
.62374 .6804 Mdot
.56987 .59527 Mdot
.6035 .59748 Mdot
.6129 .41066 Mdot
.29985 .77116 Mdot
.54393 .61495 Mdot
.44363 .43573 Mdot
.6634 .41018 Mdot
.37639 .36852 Mdot
.32316 .52806 Mdot
.61601 .56179 Mdot
.44142 .35234 Mdot
.43482 .34117 Mdot
.36704 .48402 Mdot
.59313 .3838 Mdot
.34702 .56745 Mdot
.50311 .63831 Mdot
.56184 .66179 Mdot
.56989 .52922 Mdot
.14951 .55351 Mdot
.77792 .67595 Mdot
.61602 .42628 Mdot
.33336 .4808 Mdot
.5095 .43665 Mdot
.45528 .3368 Mdot
.36882 .50079 Mdot
.59482 .41538 Mdot
.61376 .43011 Mdot
.60652 .38178 Mdot
.34113 .6911 Mdot
.32901 .48773 Mdot
.67677 .37854 Mdot
.67114 .3877 Mdot
.58181 .56638 Mdot
.59817 .56793 Mdot
.62142 .49725 Mdot
.49724 .73795 Mdot
.37254 .66224 Mdot
.34995 .53166 Mdot
.60895 .14981 Mdot
.47239 .29562 Mdot
.7482 .465 Mdot
.52867 .62318 Mdot
.8772 .64515 Mdot
.52604 .55804 Mdot
.54214 .56885 Mdot
.65316 .35884 Mdot
.37975 .68894 Mdot
.37137 .67596 Mdot
.65175 .3848 Mdot
.60268 .4305 Mdot
.36736 .6904 Mdot
.64079 .77593 Mdot
.7116 .75147 Mdot
.46603 .25216 Mdot
.64464 .39079 Mdot
.78488 .49796 Mdot
.44538 .35656 Mdot
.59933 .43194 Mdot
.46741 .29659 Mdot
.35686 .48716 Mdot
.35392 .45738 Mdot
.46427 .30265 Mdot
.57532 .56352 Mdot
.32703 .5146 Mdot
.62011 .6088 Mdot
.66654 .76876 Mdot
.76136 .6282 Mdot
.34517 .32449 Mdot
.5915 .652 Mdot
.25509 .36709 Mdot
.25926 .38199 Mdot
.57504 .61509 Mdot
.57561 .3477 Mdot
.357 .68281 Mdot
.6078 .44435 Mdot
.42926 .34644 Mdot
.84281 .44904 Mdot
.53182 .56827 Mdot
.63889 .38446 Mdot
.46438 .31641 Mdot
.44122 .78532 Mdot
.48069 .24238 Mdot
.53447 .59122 Mdot
.87843 .41932 Mdot
.6118 .45074 Mdot
.33301 .54815 Mdot
.17163 .5054 Mdot
.63321 .35327 Mdot
.38886 .64452 Mdot
.34269 .45638 Mdot
.49769 .83373 Mdot
.62787 .37236 Mdot
.35349 .45258 Mdot
.65854 .39341 Mdot
.37523 .67559 Mdot
.58754 .43743 Mdot
.36176 .51259 Mdot
.564 .57915 Mdot
.3447 .52611 Mdot
.37098 .65853 Mdot
.34961 .58201 Mdot
.43324 .34945 Mdot
.38136 .44048 Mdot
.44861 .3289 Mdot
.41644 .65473 Mdot
.52921 .1939 Mdot
.47486 .33624 Mdot
.41375 .77473 Mdot
.56714 .64353 Mdot
.66977 .36383 Mdot
.33335 .53295 Mdot
.35102 .44814 Mdot
.51646 .47293 Mdot
.64094 .40289 Mdot
.35221 .53513 Mdot
.71342 .44313 Mdot
.23119 .68831 Mdot
.51173 .63053 Mdot
.44659 .67105 Mdot
.64904 .39393 Mdot
.36569 .51351 Mdot
.31004 .27045 Mdot
.60037 .40809 Mdot
.33257 .52632 Mdot
.4453 .34583 Mdot
.43101 .32855 Mdot
.52603 .58333 Mdot
.46638 .26697 Mdot
.34089 .5471 Mdot
.28472 .32452 Mdot
.65982 .37789 Mdot
.44304 .78307 Mdot
.36961 .65089 Mdot
.35624 .47632 Mdot
.53249 .53852 Mdot
.65331 .34239 Mdot
.36407 .41154 Mdot
.53891 .70044 Mdot
.60335 .15364 Mdot
.34783 .53388 Mdot
.66384 .40038 Mdot
.63609 .38743 Mdot
.63801 .57359 Mdot
.52528 .42801 Mdot
.34153 .57349 Mdot
.30834 .73944 Mdot
.40945 .73797 Mdot
.38204 .42297 Mdot
.26962 .39588 Mdot
.51978 .58537 Mdot
.59184 .54759 Mdot
.45562 .33865 Mdot
.56899 .57555 Mdot
.66962 .37555 Mdot
.53168 .55879 Mdot
.42744 .32631 Mdot
.35902 .46539 Mdot
.5484 .60138 Mdot
.34861 .65369 Mdot
.43832 .29271 Mdot
.4607 .29989 Mdot
.35006 .48295 Mdot
.60242 .38245 Mdot
.37623 .71126 Mdot
.34128 .51297 Mdot
.57712 .54834 Mdot
.37361 .42402 Mdot
.57872 .63525 Mdot
.65408 .74233 Mdot
.59794 .39946 Mdot
.34098 .56117 Mdot
.65783 .42053 Mdot
.45272 .3257 Mdot
.34233 .44949 Mdot
.55869 .56457 Mdot
.33266 .52171 Mdot
.25147 .46744 Mdot
.66587 .75163 Mdot
.5904 .38693 Mdot
.28904 .39776 Mdot
.6677 .39467 Mdot
.38356 .42193 Mdot
.59548 .74793 Mdot
.36269 .67229 Mdot
.3593 .49277 Mdot
.77709 .66387 Mdot
.3376 .52335 Mdot
.57251 .58287 Mdot
.58189 .59967 Mdot
.32449 .51122 Mdot
.33193 .68234 Mdot
.41328 .18981 Mdot
.42436 .43948 Mdot
.63709 .3711 Mdot
.65378 .69431 Mdot
.66995 .18953 Mdot
.42269 .36058 Mdot
.45914 .33927 Mdot
.55972 .65292 Mdot
.52411 .5934 Mdot
.44443 .29811 Mdot
.42217 .34681 Mdot
.378 .66497 Mdot
.36342 .50701 Mdot
.58618 .43844 Mdot
.4171 .33045 Mdot
.56771 .4937 Mdot
.4246 .63376 Mdot
.6159 .65612 Mdot
.49387 .57962 Mdot
.60991 .62782 Mdot
.39036 .73949 Mdot
.43623 .31132 Mdot
.58683 .61431 Mdot
.62523 .62832 Mdot
.45545 .3502 Mdot
.37438 .67837 Mdot
.61631 .23305 Mdot
.35124 .50487 Mdot
.46055 .86752 Mdot
.57099 .6321 Mdot
.57144 .58655 Mdot
.48184 .32309 Mdot
.38355 .57694 Mdot
.60452 .40069 Mdot
.59687 .39069 Mdot
.34292 .48071 Mdot
.48996 .50324 Mdot
.55243 .54527 Mdot
.57845 .61594 Mdot
.35659 .5159 Mdot
.38176 .43878 Mdot
.31945 .32192 Mdot
.59612 .59632 Mdot
.46315 .31753 Mdot
.35751 .44452 Mdot
.43125 .31603 Mdot
.5614 .63337 Mdot
.57568 .58492 Mdot
.57043 .54036 Mdot
.52434 .59533 Mdot
.46659 .30043 Mdot
.5879 .6103 Mdot
.50448 .59266 Mdot
.61539 .36898 Mdot
.58271 .5432 Mdot
.40131 .74101 Mdot
.57792 .5726 Mdot
.36266 .65523 Mdot
.39747 .61541 Mdot
.53077 .58401 Mdot
.58912 .54256 Mdot
.42672 .44039 Mdot
.55512 .5765 Mdot
.47509 .29852 Mdot
.63515 .3996 Mdot
.45473 .33335 Mdot
.45683 .30185 Mdot
.36939 .45182 Mdot
.37707 .67864 Mdot
.5395 .63742 Mdot
.3508 .64706 Mdot
.52126 .53609 Mdot
.58071 .63843 Mdot
.31977 .46813 Mdot
.24504 .32487 Mdot
.23007 .50283 Mdot
.55967 .56354 Mdot
.35128 .47386 Mdot
.335 .55362 Mdot
.48887 .66548 Mdot
.62042 .61572 Mdot
.43771 .3006 Mdot
.44157 .34248 Mdot
.55079 .7462 Mdot
.44913 .22037 Mdot
.36942 .66002 Mdot
.41866 .59616 Mdot
.60733 .64242 Mdot
.59766 .60622 Mdot
.54676 .53397 Mdot
.3701 .52203 Mdot
.3876 .40461 Mdot
.36187 .48249 Mdot
.38301 .39316 Mdot
.42674 .32383 Mdot
.54309 .55271 Mdot
.78942 .5939 Mdot
.61328 .42029 Mdot
.63445 .40013 Mdot
.4305 .30962 Mdot
.34953 .56769 Mdot
.6088 .51737 Mdot
.16126 .64193 Mdot
.64404 .44086 Mdot
.37448 .6509 Mdot
.57131 .61726 Mdot
.34984 .47938 Mdot
.63235 .42484 Mdot
.32892 .68162 Mdot
.59691 .6184 Mdot
.33181 .57875 Mdot
.56219 .5607 Mdot
.66846 .45977 Mdot
.62669 .36671 Mdot
.64743 .81794 Mdot
.59727 .4149 Mdot
.42871 .29911 Mdot
.46593 .34375 Mdot
.57889 .59339 Mdot
.15594 .54002 Mdot
.66024 .3571 Mdot
.48026 .27773 Mdot
.36829 .70037 Mdot
.37129 .42612 Mdot
.34904 .70184 Mdot
.3433 .55749 Mdot
.364 .68082 Mdot
.3596 .53215 Mdot
.53544 .74002 Mdot
.68388 .404 Mdot
.35454 .6611 Mdot
.42435 .53839 Mdot
.61272 .63571 Mdot
.33292 .6541 Mdot
.51007 .59569 Mdot
.67062 .68152 Mdot
.35511 .51617 Mdot
.33214 .67857 Mdot
.60621 .59432 Mdot
.8321 .48132 Mdot
.4714 .3288 Mdot
.44179 .29795 Mdot
.62462 .58136 Mdot
.36377 .50431 Mdot
.58986 .41393 Mdot
.53989 .3826 Mdot
.38457 .37789 Mdot
.58257 .61468 Mdot
.52913 .56247 Mdot
.65952 .423 Mdot
.68799 .38021 Mdot
.57924 .58854 Mdot
.73358 .42419 Mdot
.59054 .59867 Mdot
.43413 .34501 Mdot
.60632 .41996 Mdot
.63584 .39211 Mdot
.34644 .54861 Mdot
.62054 .3609 Mdot
.49475 .60619 Mdot
.4962 .38568 Mdot
.51758 .61631 Mdot
.45213 .31993 Mdot
.51669 .40122 Mdot
.37299 .39079 Mdot
.81528 .56994 Mdot
.63834 .43593 Mdot
.60498 .54742 Mdot
.66421 .38805 Mdot
.34048 .68201 Mdot
.62025 .40679 Mdot
.64529 .42219 Mdot
.57007 .60201 Mdot
.53715 .5916 Mdot
.37517 .4598 Mdot
.52296 .43265 Mdot
.63532 .36064 Mdot
.58456 .60982 Mdot
.55782 .5366 Mdot
.60766 .54306 Mdot
.46179 .44063 Mdot
.62082 .42746 Mdot
.71729 .48886 Mdot
.60766 .7251 Mdot
.63173 .36122 Mdot
.81003 .37996 Mdot
.37267 .41952 Mdot
.37317 .50175 Mdot
.46532 .36999 Mdot
.59689 .59639 Mdot
.32717 .50105 Mdot
.54137 .59655 Mdot
.49407 .57031 Mdot
.55056 .58658 Mdot
.33675 .69963 Mdot
.57667 .6497 Mdot
.37808 .43039 Mdot
.34114 .51883 Mdot
.57021 .62563 Mdot
.54814 .59845 Mdot
.36792 .54983 Mdot
.60941 .43249 Mdot
.60418 .3973 Mdot
.34192 .61083 Mdot
.34726 .67117 Mdot
.45497 .35474 Mdot
.54872 .55702 Mdot
.34906 .47403 Mdot
.344 .5238 Mdot
.60208 .37146 Mdot
.3496 .51593 Mdot
.4792 .33979 Mdot
.55458 .56501 Mdot
.44494 .29716 Mdot
.3317 .67355 Mdot
.65718 .40941 Mdot
.53504 .56302 Mdot
.58264 .56711 Mdot
.6463 .37047 Mdot
.57044 .64504 Mdot
.35055 .69726 Mdot
.33986 .52743 Mdot
.62045 .37559 Mdot
.43682 .3316 Mdot
.35134 .55021 Mdot
.59683 .57707 Mdot
.59457 .15146 Mdot
.57667 .58053 Mdot
.59956 .58818 Mdot
.7539 .71724 Mdot
.56757 .65086 Mdot
.3393 .54061 Mdot
.66785 .41401 Mdot
.62122 .59378 Mdot
.41456 .70801 Mdot
.34271 .77777 Mdot
.36889 .47601 Mdot
.56459 .61874 Mdot
.81798 .57985 Mdot
.56603 .62227 Mdot
.36429 .75644 Mdot
.23862 .58884 Mdot
.46219 .57047 Mdot
.49831 .56538 Mdot
.47518 .31114 Mdot
.37587 .45712 Mdot
.35339 .54521 Mdot
.66163 .54268 Mdot
.57493 .60655 Mdot
.64531 .46874 Mdot
.608 .60866 Mdot
.42982 .331 Mdot
.62514 .69637 Mdot
.34834 .52945 Mdot
.27 .29809 Mdot
.58216 .55098 Mdot
.61587 .42775 Mdot
.35947 .54586 Mdot
.37247 .417 Mdot
.6026 .5878 Mdot
.34235 .6514 Mdot
.49552 .3181 Mdot
.53456 .64646 Mdot
.44728 .31932 Mdot
.59582 .61434 Mdot
.51374 .53478 Mdot
.17006 .45481 Mdot
.62114 .36811 Mdot
.4535 .34307 Mdot
.2617 .3922 Mdot
.57441 .64603 Mdot
.62446 .37279 Mdot
.63395 .40641 Mdot
.37144 .65512 Mdot
.49093 .45856 Mdot
.56116 .23399 Mdot
.7992 .53182 Mdot
.66758 .65465 Mdot
.36727 .51337 Mdot
.29308 .35812 Mdot
.58959 .56231 Mdot
.39043 .2715 Mdot
.46638 .29315 Mdot
.56868 .58404 Mdot
.68139 .62557 Mdot
.64981 .41442 Mdot
.59033 .58446 Mdot
.3724 .6815 Mdot
.37981 .25927 Mdot
.38022 .27707 Mdot
.75155 .31136 Mdot
.36851 .46696 Mdot
.56228 .52304 Mdot
.4946 .59072 Mdot
.38366 .44405 Mdot
.59594 .62934 Mdot
.33829 .53584 Mdot
.59952 .78454 Mdot
.33441 .69358 Mdot
.64324 .42064 Mdot
.3728 .4184 Mdot
.61475 .61657 Mdot
.5809 .53343 Mdot
.35745 .63888 Mdot
.60872 .55992 Mdot
.19857 .38878 Mdot
.33942 .35694 Mdot
.33218 .4985 Mdot
.60815 .37842 Mdot
.60538 .64103 Mdot
.38886 .40542 Mdot
.57509 .60208 Mdot
.75435 .60625 Mdot
.60228 .54691 Mdot
.53789 .2263 Mdot
.64258 .36492 Mdot
.44776 .32179 Mdot
.54745 .5168 Mdot
.54627 .5813 Mdot
.28526 .55389 Mdot
.50015 .5559 Mdot
.55743 .62336 Mdot
.58792 .40013 Mdot
.61396 .42347 Mdot
.61582 .39585 Mdot
.32889 .55349 Mdot
.4278 .23835 Mdot
.46143 .32249 Mdot
.51792 .58474 Mdot
.41674 .32902 Mdot
.55664 .69354 Mdot
.36179 .63969 Mdot
.81016 .43615 Mdot
.61233 .56023 Mdot
.62225 .3913 Mdot
.61058 .29273 Mdot
.65586 .36354 Mdot
.31227 .53007 Mdot
.44873 .31014 Mdot
.63917 .42005 Mdot
.54306 .57421 Mdot
.51351 .42299 Mdot
.76925 .36267 Mdot
.44945 .33606 Mdot
.50945 .56384 Mdot
.35995 .45353 Mdot
.35611 .37859 Mdot
.65939 .16846 Mdot
.46423 .3391 Mdot
.26758 .37891 Mdot
.577 .61204 Mdot
.6108 .4169 Mdot
.47931 .31943 Mdot
.47442 .32588 Mdot
.35286 .52069 Mdot
.53513 .58888 Mdot
.53214 .58056 Mdot
.37204 .43522 Mdot
.4397 .34151 Mdot
.61748 .54511 Mdot
.53161 .54353 Mdot
.78192 .68214 Mdot
.6449 .52784 Mdot
.3424 .8143 Mdot
.50826 .64678 Mdot
.68498 .63495 Mdot
.54995 .44222 Mdot
.66095 .40994 Mdot
.53168 .58772 Mdot
.60056 .64065 Mdot
.34343 .54682 Mdot
.56528 .57145 Mdot
.32371 .55413 Mdot
.4663 .33022 Mdot
.80281 .37527 Mdot
.62825 .25929 Mdot
.59327 .781 Mdot
.56301 .57333 Mdot
.4731 .22019 Mdot
.34004 .66857 Mdot
.43761 .28978 Mdot
.61504 .3859 Mdot
.56621 .64021 Mdot
.35081 .57569 Mdot
.35942 .48948 Mdot
.63079 .41429 Mdot
.26467 .33912 Mdot
.30521 .58595 Mdot
.56152 .63384 Mdot
.32298 .54051 Mdot
.56754 .33163 Mdot
.73234 .41208 Mdot
.41185 .33978 Mdot
.34227 .70157 Mdot
.36148 .48027 Mdot
.43081 .31252 Mdot
.58696 .45436 Mdot
.64036 .41712 Mdot
.67638 .40208 Mdot
.25444 .55792 Mdot
.34365 .57575 Mdot
.34841 .65882 Mdot
.43417 .23322 Mdot
.42468 .2275 Mdot
.33902 .70038 Mdot
.35131 .45803 Mdot
.62279 .42533 Mdot
.63123 .37817 Mdot
.63597 .39853 Mdot
.28411 .28344 Mdot
.593 .39184 Mdot
.75733 .50305 Mdot
.56301 .53455 Mdot
.58921 .48263 Mdot
.5634 .61975 Mdot
.46413 .29653 Mdot
.63044 .36675 Mdot
.53886 .44998 Mdot
.52911 .61153 Mdot
.76397 .33534 Mdot
.58004 .61701 Mdot
.41101 .33382 Mdot
.59523 .58867 Mdot
.76437 .46201 Mdot
.66542 .40757 Mdot
.56389 .56671 Mdot
.48757 .33505 Mdot
.35228 .67746 Mdot
.58088 .39512 Mdot
.53136 .58363 Mdot
.52942 .27886 Mdot
.55641 .65013 Mdot
.62707 .78494 Mdot
.4709 .77985 Mdot
.37434 .65037 Mdot
.56466 .68444 Mdot
.36584 .49592 Mdot
.61268 .4769 Mdot
.54559 .66285 Mdot
.44827 .33522 Mdot
.60193 .20885 Mdot
.35818 .47748 Mdot
.62421 .68955 Mdot
.63782 .62347 Mdot
.37597 .68049 Mdot
.65248 .34529 Mdot
.47821 .30342 Mdot
.54383 .63139 Mdot
.58719 .52555 Mdot
.61218 .77782 Mdot
.5441 .65888 Mdot
.54265 .54708 Mdot
.34892 .6419 Mdot
.72197 .4976 Mdot
.58083 .57147 Mdot
.31852 .5072 Mdot
.67429 .40458 Mdot
.62393 .5895 Mdot
.71781 .48387 Mdot
.58368 .60935 Mdot
.62298 .41812 Mdot
.68508 .37994 Mdot
.5867 .27709 Mdot
.37379 .69395 Mdot
.60273 .54735 Mdot
.50124 .79671 Mdot
.58697 .54947 Mdot
.46009 .31555 Mdot
.54739 .61988 Mdot
.35797 .49578 Mdot
.26763 .30934 Mdot
.32733 .5334 Mdot
.5408 .60505 Mdot
.6393 .39452 Mdot
.47624 .30787 Mdot
.2399 .52657 Mdot
.26135 .59889 Mdot
.75214 .50046 Mdot
.46185 .84341 Mdot
.33516 .68732 Mdot
.32409 .68901 Mdot
.48233 .30922 Mdot
.56573 .56621 Mdot
.45734 .79769 Mdot
.53407 .64208 Mdot
.58947 .58032 Mdot
.55057 .58794 Mdot
.40746 .26822 Mdot
.45966 .33295 Mdot
.34747 .50785 Mdot
.57831 .58628 Mdot
.58632 .60888 Mdot
.66075 .38599 Mdot
.35389 .67618 Mdot
.32826 .54202 Mdot
.35453 .66729 Mdot
.33985 .4975 Mdot
.81903 .3937 Mdot
.51423 .56672 Mdot
.34987 .67721 Mdot
.46915 .29144 Mdot
.61268 .41118 Mdot
.39032 .40178 Mdot
.34557 .5558 Mdot
.35034 .53316 Mdot
.58115 .61454 Mdot
.61702 .41727 Mdot
.62455 .36048 Mdot
.33922 .68115 Mdot
.4705 .34625 Mdot
.54033 .60091 Mdot
.57551 .64052 Mdot
.47094 .63029 Mdot
.36488 .54144 Mdot
.71667 .42756 Mdot
.57183 .29598 Mdot
.56253 .5638 Mdot
.60268 .37946 Mdot
.55382 .59626 Mdot
.78903 .61381 Mdot
.60146 .40614 Mdot
.5314 .60377 Mdot
.42887 .21352 Mdot
.36931 .43055 Mdot
.53814 .25459 Mdot
.57301 .53838 Mdot
.51424 .84796 Mdot
.59445 .56067 Mdot
.81209 .62756 Mdot
.38619 .53383 Mdot
.54266 .55184 Mdot
.58771 .56536 Mdot
.80523 .50901 Mdot
.56661 .61053 Mdot
.3837 .4248 Mdot
.62055 .69493 Mdot
.61618 .43129 Mdot
.54729 .45879 Mdot
.3746 .60383 Mdot
.37343 .69695 Mdot
.34227 .48161 Mdot
.27554 .40697 Mdot
.3641 .69113 Mdot
.6457 .38942 Mdot
.56083 .55396 Mdot
.46952 .52995 Mdot
.36594 .4402 Mdot
.63743 .58712 Mdot
.45706 .3128 Mdot
.31548 .3783 Mdot
.31981 .54484 Mdot
.44088 .32735 Mdot
.61608 .58732 Mdot
.76371 .39188 Mdot
.22482 .58056 Mdot
.65947 .81001 Mdot
.48084 .31333 Mdot
.4292 .33628 Mdot
.33156 .24716 Mdot
.36651 .70379 Mdot
.62761 .74455 Mdot
.50895 .22897 Mdot
.46451 .35772 Mdot
.56981 .76322 Mdot
.36335 .48312 Mdot
.52005 .26764 Mdot
.60779 .4443 Mdot
.56588 .5294 Mdot
.54421 .57595 Mdot
.46711 .3488 Mdot
.57297 .43701 Mdot
.16944 .47464 Mdot
.4478 .33016 Mdot
.50634 .55703 Mdot
.46104 .47166 Mdot
.37606 .41469 Mdot
.37462 .47623 Mdot
.3779 .68529 Mdot
.35868 .62491 Mdot
.65751 .38507 Mdot
.3776 .66737 Mdot
.37466 .28057 Mdot
.61044 .55949 Mdot
.4422 .33717 Mdot
.38692 .3989 Mdot
.43453 .32828 Mdot
.36915 .68312 Mdot
.37815 .65746 Mdot
.61405 .36975 Mdot
.60503 .3988 Mdot
.6908 .62344 Mdot
.52148 .75867 Mdot
.56774 .62385 Mdot
.706 .31149 Mdot
.65747 .37333 Mdot
.55676 .67271 Mdot
.33777 .7022 Mdot
.35032 .67418 Mdot
.65815 .47993 Mdot
.54222 .55724 Mdot
.42336 .79027 Mdot
.5422 .55932 Mdot
.58152 .73648 Mdot
.59604 .63217 Mdot
.35157 .51829 Mdot
.54746 .55218 Mdot
.35696 .71757 Mdot
.52009 .58632 Mdot
.56022 .62638 Mdot
.36301 .49601 Mdot
.54348 .65258 Mdot
.35829 .49746 Mdot
.53965 .60536 Mdot
.33383 .70355 Mdot
.34829 .47456 Mdot
.43816 .69051 Mdot
.44192 .43748 Mdot
.38231 .43325 Mdot
.35832 .65093 Mdot
.36316 .64704 Mdot
.40767 .69627 Mdot
.61595 .3841 Mdot
.59452 .357 Mdot
.56862 .56857 Mdot
.36442 .51596 Mdot
.4585 .33718 Mdot
.58795 .6063 Mdot
.58782 .64254 Mdot
.54854 .5423 Mdot
.6614 .4018 Mdot
.34672 .56917 Mdot
.35019 .68266 Mdot
.32404 .54442 Mdot
.29697 .5598 Mdot
.31775 .52975 Mdot
.62197 .62982 Mdot
.57449 .51527 Mdot
.68439 .68938 Mdot
.68561 .28745 Mdot
.39293 .20301 Mdot
.63845 .41584 Mdot
.37541 .44373 Mdot
.37896 .6637 Mdot
.5982 .69927 Mdot
.61973 .38699 Mdot
.3616 .50926 Mdot
.56123 .56033 Mdot
.51185 .55499 Mdot
.47002 .37571 Mdot
.61905 .47412 Mdot
.42412 .74301 Mdot
.32536 .56048 Mdot
.38311 .41867 Mdot
.41717 .2358 Mdot
.64371 .6596 Mdot
.50385 .48807 Mdot
.56154 .58873 Mdot
.33976 .65365 Mdot
.6323 .42483 Mdot
.23207 .54699 Mdot
.4485 .34999 Mdot
.52427 .42931 Mdot
.56257 .57235 Mdot
.4508 .24924 Mdot
.63915 .39623 Mdot
.37415 .67227 Mdot
.46534 .35002 Mdot
.38016 .68941 Mdot
.37471 .48054 Mdot
.42891 .81304 Mdot
.59776 .55143 Mdot
.55587 .62074 Mdot
.41882 .31589 Mdot
.65746 .39236 Mdot
.38593 .65284 Mdot
.64703 .76541 Mdot
.3236 .51957 Mdot
.41145 .78771 Mdot
.65898 .36 Mdot
.77365 .50618 Mdot
.32566 .54791 Mdot
.4297 .31056 Mdot
.40936 .68644 Mdot
.4277 .32477 Mdot
.52843 .58215 Mdot
.62928 .39165 Mdot
.47031 .32625 Mdot
.28235 .53328 Mdot
.83348 .53943 Mdot
.78214 .50487 Mdot
.56708 .54609 Mdot
.80722 .4149 Mdot
.69541 .75341 Mdot
.57273 .37734 Mdot
.43376 .35066 Mdot
.57185 .59669 Mdot
.61195 .60941 Mdot
.57675 .55047 Mdot
.46303 .30831 Mdot
.30454 .47173 Mdot
.35583 .52643 Mdot
.57396 .62011 Mdot
.3759 .66047 Mdot
.35597 .49672 Mdot
.35672 .4366 Mdot
.34406 .54209 Mdot
.63351 .43232 Mdot
.5272 .59962 Mdot
.51956 .31203 Mdot
.85223 .52685 Mdot
.45349 .33397 Mdot
.38199 .43339 Mdot
.58029 .63042 Mdot
.50098 .20388 Mdot
.61701 .39449 Mdot
.32436 .51534 Mdot
.57092 .58679 Mdot
.29448 .49212 Mdot
.35829 .56764 Mdot
.34616 .54008 Mdot
.62631 .3774 Mdot
.57334 .3634 Mdot
.56849 .57364 Mdot
.59696 .55984 Mdot
.65487 .39016 Mdot
.31111 .6616 Mdot
.27896 .30204 Mdot
.54992 .59724 Mdot
.44635 .32291 Mdot
.21582 .69668 Mdot
.58853 .53692 Mdot
.6576 .57138 Mdot
.37293 .46825 Mdot
.54781 .28603 Mdot
.7174 .42216 Mdot
.57578 .68845 Mdot
.81057 .51257 Mdot
.4295 .59498 Mdot
.80623 .38705 Mdot
.31705 .56977 Mdot
.41143 .50174 Mdot
.82412 .40687 Mdot
.48598 .33485 Mdot
.57616 .47844 Mdot
.51175 .66993 Mdot
.25582 .3315 Mdot
.56083 .42329 Mdot
.30918 .63691 Mdot
.27663 .57061 Mdot
.45791 .52234 Mdot
.33525 .52103 Mdot
.56035 .72237 Mdot
.54145 .60002 Mdot
.68849 .7598 Mdot
.73865 .43099 Mdot
.1622 .48345 Mdot
.81347 .42745 Mdot
.50573 .79511 Mdot
.77813 .38535 Mdot
.805 .60342 Mdot
.67625 .69552 Mdot
.67636 .29229 Mdot
.30301 .75456 Mdot
.41213 .22786 Mdot
.52911 .80211 Mdot
.61723 .535 Mdot
.42088 .58881 Mdot
.56602 .8122 Mdot
.75685 .53769 Mdot
.159 .56445 Mdot
.33675 .54777 Mdot
.67044 .40648 Mdot
.49701 .65888 Mdot
.59283 .37197 Mdot
.40502 .3525 Mdot
.81282 .50543 Mdot
.79936 .64019 Mdot
.75977 .4594 Mdot
.51306 .85083 Mdot
.67546 .55695 Mdot
.32121 .21236 Mdot
.43176 .46025 Mdot
.68109 .3807 Mdot
.25608 .66747 Mdot
.42865 .22804 Mdot
.60292 .2462 Mdot
.50588 .64816 Mdot
.34826 .42266 Mdot
.45822 .7165 Mdot
.63956 .38524 Mdot
.72617 .40514 Mdot
.37582 .50021 Mdot
.61495 .23837 Mdot
.39935 .67653 Mdot
.8192 .547 Mdot
.4773 .50039 Mdot
.51773 .27597 Mdot
.29769 .34608 Mdot
.59721 .15223 Mdot
.5265 .77495 Mdot
.73797 .68583 Mdot
.42751 .37418 Mdot
.56158 .4129 Mdot
.22328 .39387 Mdot
.49232 .75224 Mdot
.43052 .22514 Mdot
.63435 .20411 Mdot
.65691 .79438 Mdot
.67864 .22129 Mdot
.58495 .37299 Mdot
.5492 .54292 Mdot
.73426 .67486 Mdot
.66173 .6605 Mdot
.3328 .642 Mdot
.73166 .28978 Mdot
.33112 .66904 Mdot
.58774 .37262 Mdot
.26072 .33803 Mdot
.76041 .48524 Mdot
.40928 .78098 Mdot
.39057 .66769 Mdot
.58963 .65339 Mdot
.1398 .38725 Mdot
.80015 .38423 Mdot
.57785 .27728 Mdot
.78378 .68022 Mdot
.43888 .24981 Mdot
.45328 .78596 Mdot
.46926 .32126 Mdot
.84769 .46369 Mdot
.62931 .38209 Mdot
.85376 .40274 Mdot
.84299 .5114 Mdot
.18752 .52202 Mdot
.12233 .60474 Mdot
.36603 .31296 Mdot
.47106 .55775 Mdot
.43022 .60527 Mdot
.42694 .71762 Mdot
.18139 .45485 Mdot
.18161 .55352 Mdot
.42923 .24675 Mdot
.52285 .83072 Mdot
.83241 .43749 Mdot
.58428 .75594 Mdot
.46303 .81412 Mdot
.24589 .35545 Mdot
.45489 .43521 Mdot
.66552 .34574 Mdot
.42703 .41758 Mdot
.69458 .3253 Mdot
.72177 .27435 Mdot
.65881 .65013 Mdot
.16604 .65147 Mdot
.38187 .70143 Mdot
.37213 .56398 Mdot
.74417 .70741 Mdot
.4466 .6833 Mdot
.63248 .70411 Mdot
.35614 .24105 Mdot
.62875 .63624 Mdot
.3802 .23404 Mdot
.63475 .31542 Mdot
.28535 .39975 Mdot
.40277 .23311 Mdot
.54824 .34147 Mdot
.62453 .7741 Mdot
.74978 .64086 Mdot
.44923 .21274 Mdot
.61507 .4321 Mdot
.4649 .75373 Mdot
.54424 .77234 Mdot
.77357 .69135 Mdot
.26212 .39154 Mdot
.68628 .80315 Mdot
.23809 .41497 Mdot
.51696 .60944 Mdot
.51128 .63209 Mdot
.58897 .50509 Mdot
.49947 .76293 Mdot
.54961 .53969 Mdot
.43612 .24432 Mdot
.76303 .70743 Mdot
.67781 .6192 Mdot
.28679 .41472 Mdot
.6164 .21317 Mdot
.66519 .80363 Mdot
.69284 .70201 Mdot
.38684 .49662 Mdot
.64153 .54207 Mdot
.40881 .176 Mdot
.3524 .49083 Mdot
.57733 .7623 Mdot
.44615 .36434 Mdot
.24792 .56383 Mdot
.79739 .51017 Mdot
.19406 .50568 Mdot
.76244 .70985 Mdot
.28827 .29874 Mdot
.22921 .49465 Mdot
.38411 .7149 Mdot
.39269 .77731 Mdot
.65123 .23775 Mdot
.53521 .53152 Mdot
.48662 .56108 Mdot
.34217 .6472 Mdot
.70453 .6364 Mdot
.62042 .72858 Mdot
.26545 .63042 Mdot
.50211 .6041 Mdot
.20876 .6009 Mdot
.38546 .41513 Mdot
.51983 .42612 Mdot
.71907 .2296 Mdot
.63297 .6087 Mdot
.37313 .32645 Mdot
.64082 .79681 Mdot
.45493 .76822 Mdot
.74368 .69718 Mdot
.53422 .32855 Mdot
.67131 .22075 Mdot
.84124 .54595 Mdot
.25991 .60935 Mdot
.78449 .34472 Mdot
.75911 .73647 Mdot
.6359 .19521 Mdot
.69247 .42088 Mdot
.48761 .31143 Mdot
.81805 .30517 Mdot
.34377 .46579 Mdot
.56419 .19047 Mdot
.66814 .65168 Mdot
.29234 .46662 Mdot
.58516 .41992 Mdot
.64012 .55923 Mdot
.46194 .51993 Mdot
.60835 .45302 Mdot
.62021 .60666 Mdot
.64676 .18032 Mdot
.59103 .18327 Mdot
.66674 .19965 Mdot
.6019 .81814 Mdot
.79152 .35273 Mdot
.45774 .6027 Mdot
.76348 .51532 Mdot
.51529 .68579 Mdot
.55234 .6258 Mdot
.53289 .7248 Mdot
.36278 .31676 Mdot
.22042 .56321 Mdot
.58542 .23751 Mdot
.58636 .38608 Mdot
.73375 .31231 Mdot
.57799 .11546 Mdot
.68045 .54885 Mdot
.69082 .49613 Mdot
.38886 .26763 Mdot
.52551 .7637 Mdot
.6657 .3186 Mdot
.20405 .54794 Mdot
.75769 .70225 Mdot
.52674 .68321 Mdot
.58207 .7701 Mdot
.27854 .65157 Mdot
.34856 .74797 Mdot
.40192 .56813 Mdot
.82696 .52883 Mdot
.45121 .63691 Mdot
.20813 .48985 Mdot
.53667 .4742 Mdot
.17841 .5019 Mdot
.30025 .60609 Mdot
.31518 .37036 Mdot
.54587 .78682 Mdot
.36514 .38188 Mdot
.57129 .74797 Mdot
.46783 .46506 Mdot
.57295 .71073 Mdot
.43053 .59304 Mdot
.57524 .74714 Mdot
.34562 .74522 Mdot
.73916 .28507 Mdot
.74989 .75755 Mdot
.52245 .15614 Mdot
.52791 .84742 Mdot
.61083 .319 Mdot
.58012 .53021 Mdot
.72927 .739 Mdot
.70936 .23796 Mdot
.84147 .56321 Mdot
.30074 .299 Mdot
.28442 .51502 Mdot
.43916 .2908 Mdot
.52499 .15996 Mdot
.32621 .62367 Mdot
.78439 .64277 Mdot
.40008 .20336 Mdot
.46879 .36884 Mdot
.23861 .33437 Mdot
.56301 .1829 Mdot
.78985 .4817 Mdot
.69424 .44302 Mdot
.63962 .59071 Mdot
.75629 .43663 Mdot
.6494 .42854 Mdot
.28711 .35136 Mdot
.4995 .75708 Mdot
.35109 .48339 Mdot
.44295 .65069 Mdot
.48223 .59806 Mdot
.57656 .65009 Mdot
.38946 .6029 Mdot
.65219 .43209 Mdot
.68437 .28814 Mdot
.51616 .36777 Mdot
.81248 .35789 Mdot
.3483 .32985 Mdot
.50507 .54004 Mdot
.47556 .77052 Mdot
.23682 .50104 Mdot
.34204 .24506 Mdot
.46883 .35812 Mdot
.82675 .45995 Mdot
.41588 .39792 Mdot
.46948 .75679 Mdot
.75043 .42472 Mdot
.64214 .75141 Mdot
.58321 .51731 Mdot
.58974 .2922 Mdot
.73454 .62555 Mdot
.51981 .43657 Mdot
.62278 .34764 Mdot
.68991 .36805 Mdot
.59934 .85997 Mdot
.36748 .27272 Mdot
.3042 .36779 Mdot
.8291 .4722 Mdot
.44444 .3092 Mdot
.64539 .36011 Mdot
.55434 .7308 Mdot
.62604 .77837 Mdot
.74629 .59057 Mdot
.3549 .57208 Mdot
.34084 .40808 Mdot
.284 .62827 Mdot
.80794 .42586 Mdot
.78887 .39462 Mdot
.15847 .48339 Mdot
.59156 .38136 Mdot
.66222 .739 Mdot
.5879 .77821 Mdot
.66687 .38798 Mdot
.57782 .40373 Mdot
.58669 .22284 Mdot
.77536 .31285 Mdot
.50218 .28466 Mdot
.50893 .8407 Mdot
.38915 .7334 Mdot
.29894 .48885 Mdot
.23548 .51797 Mdot
.501 .8075 Mdot
.82904 .48219 Mdot
.7266 .39074 Mdot
.78636 .44793 Mdot
.53938 .51341 Mdot
.63359 .47437 Mdot
.50387 .15381 Mdot
.44473 .4525 Mdot
.77312 .4959 Mdot
.54291 .35417 Mdot
.57869 .54718 Mdot
.59983 .15392 Mdot
.66393 .77175 Mdot
.34732 .23347 Mdot
.49035 .30332 Mdot
.60546 .5812 Mdot
.52113 .55685 Mdot
.62787 .51323 Mdot
.56542 .28598 Mdot
.61338 .20161 Mdot
.50478 .80815 Mdot
.56698 .34889 Mdot
.73831 .42445 Mdot
.37313 .32773 Mdot
.81437 .55788 Mdot
.7134 .73529 Mdot
.4967 .44742 Mdot
.35653 .31861 Mdot
.41104 .67109 Mdot
.54259 .83998 Mdot
.43604 .56154 Mdot
.46416 .6131 Mdot
.51662 .21084 Mdot
.55011 .30654 Mdot
.22918 .52281 Mdot
.58799 .62812 Mdot
.26506 .3378 Mdot
.80479 .59973 Mdot
.14912 .56055 Mdot
.19796 .42989 Mdot
.61992 .15856 Mdot
.76657 .58895 Mdot
.54105 .31008 Mdot
.77633 .40614 Mdot
.14257 .56851 Mdot
.4172 .58769 Mdot
.75906 .34058 Mdot
.39851 .69885 Mdot
.8198 .44999 Mdot
.48537 .34819 Mdot
.48256 .24486 Mdot
.6106 .21025 Mdot
.78342 .32948 Mdot
.70334 .70119 Mdot
.8219 .51392 Mdot
.52956 .47643 Mdot
.75247 .28103 Mdot
.51817 .20275 Mdot
.45286 .52828 Mdot
.36087 .45594 Mdot
.33808 .25871 Mdot
.73374 .34233 Mdot
.66499 .30069 Mdot
.57691 .76584 Mdot
.42952 .54959 Mdot
.61296 .70233 Mdot
.77286 .4329 Mdot
.46922 .69218 Mdot
.55722 .31586 Mdot
.47305 .7706 Mdot
.80827 .60823 Mdot
.41018 .58091 Mdot
.24143 .51453 Mdot
.36532 .345 Mdot
.44939 .82111 Mdot
.5673 .28132 Mdot
.35986 .27736 Mdot
.74104 .68232 Mdot
.32702 .60601 Mdot
.51549 .7894 Mdot
.70462 .82344 Mdot
.51843 .81693 Mdot
.65333 .26339 Mdot
.71744 .27222 Mdot
.73624 .71584 Mdot
.67334 .27811 Mdot
.18402 .43604 Mdot
.64061 .5096 Mdot
.53224 .73823 Mdot
.54964 .58655 Mdot
.70969 .22558 Mdot
.46912 .71549 Mdot
.7211 .27007 Mdot
.6998 .77018 Mdot
.75853 .4308 Mdot
.57647 .65079 Mdot
.3267 .56744 Mdot
.40324 .44316 Mdot
.47604 .69011 Mdot
.79313 .45241 Mdot
.64522 .52017 Mdot
.34255 .36588 Mdot
.38458 .44652 Mdot
.36475 .59142 Mdot
.61719 .33334 Mdot
.34023 .31762 Mdot
.56524 .30016 Mdot
.31882 .65109 Mdot
.50104 .47499 Mdot
.54156 .76405 Mdot
.71944 .42274 Mdot
.79143 .49438 Mdot
.19279 .49861 Mdot
.43713 .3979 Mdot
.3389 .54216 Mdot
.79267 .5555 Mdot
.53972 .81841 Mdot
.56754 .3245 Mdot
.66151 .22021 Mdot
.32559 .26166 Mdot
.51939 .69836 Mdot
.60789 .72167 Mdot
.18121 .48068 Mdot
.31206 .75118 Mdot
.71185 .29323 Mdot
.7036 .37355 Mdot
.42571 .78723 Mdot
.47996 .60499 Mdot
.81896 .39552 Mdot
.54043 .79563 Mdot
.63681 .71876 Mdot
.43336 .44507 Mdot
.74512 .55611 Mdot
.75667 .41086 Mdot
.43211 .68524 Mdot
.51998 .4687 Mdot
.33694 .19935 Mdot
.59403 .44053 Mdot
.57577 .13897 Mdot
.4406 .34802 Mdot
.27543 .2808 Mdot
.3313 .73716 Mdot
.46803 .45841 Mdot
.52732 .46591 Mdot
.59401 .286 Mdot
.53659 .22508 Mdot
.56671 .82636 Mdot
.17314 .53736 Mdot
.32165 .50631 Mdot
.46227 .80318 Mdot
.40913 .80881 Mdot
.80523 .51759 Mdot
.61109 .63383 Mdot
.50984 .82222 Mdot
.44724 .44814 Mdot
.21991 .55847 Mdot
.71301 .7491 Mdot
.62861 .30134 Mdot
.50523 .55399 Mdot
.52003 .7622 Mdot
.75775 .34245 Mdot
.83877 .53499 Mdot
.20828 .37123 Mdot
.63314 .31551 Mdot
.48197 .30239 Mdot
.45245 .57556 Mdot
.80759 .44905 Mdot
.43084 .77272 Mdot
.50746 .27135 Mdot
.537 .77712 Mdot
.4818 .1303 Mdot
.63238 .21186 Mdot
.61249 .20155 Mdot
.46575 .78161 Mdot
.61598 .35575 Mdot
.55987 .20355 Mdot
.61822 .72036 Mdot
.62624 .2944 Mdot
.58193 .8087 Mdot
.56592 .76138 Mdot
.14706 .4684 Mdot
.66685 .69345 Mdot
.29936 .56265 Mdot
.74741 .39095 Mdot
.67835 .65246 Mdot
.49034 .3091 Mdot
.51673 .72823 Mdot
.54623 .35484 Mdot
.42628 .30132 Mdot
.56167 .312 Mdot
.53015 .27469 Mdot
.64361 .71716 Mdot
.75666 .57368 Mdot
.57588 .33771 Mdot
.78345 .59652 Mdot
.60785 .46266 Mdot
.23292 .54625 Mdot
.24608 .49407 Mdot
.54793 .38725 Mdot
.33662 .48645 Mdot
.57048 .68729 Mdot
.51421 .44595 Mdot
.41184 .62219 Mdot
.49286 .16705 Mdot
.33068 .66563 Mdot
.61659 .35958 Mdot
.32045 .23744 Mdot
.66851 .38354 Mdot
.67119 .19397 Mdot
.20415 .5353 Mdot
.74888 .42804 Mdot
.26985 .60699 Mdot
.26035 .65595 Mdot
.21043 .31242 Mdot
.70888 .34323 Mdot
.42591 .43344 Mdot
.68279 .41569 Mdot
.59586 .40308 Mdot
.35159 .3701 Mdot
.38213 .45139 Mdot
.6838 .46013 Mdot
.38932 .34708 Mdot
.5153 .68984 Mdot
.67568 .36362 Mdot
.29917 .54229 Mdot
.62787 .68927 Mdot
.78559 .32598 Mdot
.33484 .5296 Mdot
.40615 .16659 Mdot
.50778 .58241 Mdot
.72555 .66055 Mdot
.75401 .72231 Mdot
.2226 .34967 Mdot
.24134 .45935 Mdot
.33352 .77385 Mdot
.52344 .62001 Mdot
.58751 .33156 Mdot
.63908 .38146 Mdot
.61892 .73815 Mdot
.36258 .67954 Mdot
.43819 .74734 Mdot
.4164 .32851 Mdot
.20988 .49204 Mdot
.33389 .3237 Mdot
.63962 .349 Mdot
.64762 .30725 Mdot
.66574 .71948 Mdot
.49398 .23961 Mdot
.44985 .44587 Mdot
.8033 .51572 Mdot
.7515 .57569 Mdot
.67891 .36722 Mdot
.66708 .23288 Mdot
.57468 .77819 Mdot
.85166 .45934 Mdot
.58736 .49692 Mdot
.42175 .47267 Mdot
.47296 .22492 Mdot
.57931 .30488 Mdot
.71031 .4293 Mdot
.7615 .69885 Mdot
.47814 .75288 Mdot
.45255 .23328 Mdot
.57075 .7441 Mdot
.63692 .6451 Mdot
.48429 .48046 Mdot
.29319 .32999 Mdot
.16194 .41735 Mdot
.65554 .46438 Mdot
.22538 .3753 Mdot
.70008 .3772 Mdot
.37161 .3249 Mdot
.60271 .44948 Mdot
.26819 .47859 Mdot
.75537 .54809 Mdot
.25414 .41485 Mdot
.83402 .41922 Mdot
.75956 .70287 Mdot
.47611 .37008 Mdot
.35213 .39819 Mdot
.56369 .45539 Mdot
.55339 .50276 Mdot
.53437 .41932 Mdot
.53428 .55632 Mdot
.57191 .39821 Mdot
.24107 .32432 Mdot
.61121 .29344 Mdot
.64202 .57794 Mdot
.81186 .39322 Mdot
.85057 .47238 Mdot
.7475 .27987 Mdot
.40664 .7852 Mdot
.65393 .41636 Mdot
.63743 .19073 Mdot
.70524 .46521 Mdot
.81499 .59983 Mdot
.70922 .29699 Mdot
.62234 .84901 Mdot
.79113 .45556 Mdot
.53916 .35586 Mdot
.1816 .54164 Mdot
.54346 .23842 Mdot
.68572 .76728 Mdot
.44667 .536 Mdot
.30519 .39619 Mdot
.68425 .7726 Mdot
.15937 .36041 Mdot
.70106 .40029 Mdot
.52365 .27658 Mdot
.48096 .62197 Mdot
.54685 .37348 Mdot
.39628 .50087 Mdot
.54954 .62139 Mdot
.36355 .4165 Mdot
.22831 .50119 Mdot
.54795 .76408 Mdot
.60747 .70784 Mdot
.39578 .50535 Mdot
.48018 .68932 Mdot
.58502 .7328 Mdot
.52487 .80469 Mdot
.79672 .48617 Mdot
.69025 .45411 Mdot
.51691 .53981 Mdot
.58678 .44069 Mdot
.3667 .69902 Mdot
.26442 .4235 Mdot
.53307 .59822 Mdot
.25327 .42215 Mdot
.51579 .23306 Mdot
.62768 .16615 Mdot
.28045 .44508 Mdot
.64688 .77511 Mdot
.61173 .44447 Mdot
.57397 .2884 Mdot
.78081 .61368 Mdot
.25831 .33224 Mdot
.39863 .53384 Mdot
.6584 .65162 Mdot
.80377 .39753 Mdot
.40185 .23603 Mdot
.62381 .76479 Mdot
.47034 .19076 Mdot
.44776 .29194 Mdot
.66447 .44824 Mdot
.47714 .62362 Mdot
.30063 .2918 Mdot
.64489 .34402 Mdot
.53944 .34545 Mdot
.43261 .49822 Mdot
.38952 .2372 Mdot
.64269 .79768 Mdot
.65459 .73415 Mdot
.74168 .37632 Mdot
.79241 .39637 Mdot
.37008 .47855 Mdot
.58736 .76995 Mdot
.53203 .35291 Mdot
.41078 .5168 Mdot
.45169 .21745 Mdot
.81286 .36918 Mdot
.53605 .43285 Mdot
.45234 .70923 Mdot
.59485 .55446 Mdot
.7191 .48741 Mdot
.60815 .2876 Mdot
.33597 .72451 Mdot
.32917 .35458 Mdot
.60198 .40264 Mdot
.31651 .34341 Mdot
.3811 .58442 Mdot
.51539 .73715 Mdot
.68307 .41003 Mdot
.66529 .58494 Mdot
.32636 .65406 Mdot
.37669 .37342 Mdot
.61992 .55539 Mdot
.4438 .7196 Mdot
.40238 .77505 Mdot
.67323 .44077 Mdot
.70309 .32548 Mdot
.80067 .52537 Mdot
.61371 .78445 Mdot
.58673 .31358 Mdot
.70685 .28847 Mdot
.54603 .22631 Mdot
.7695 .53378 Mdot
.25614 .37462 Mdot
.5529 .5405 Mdot
.26975 .47828 Mdot
.64777 .35881 Mdot
.80695 .46768 Mdot
.75885 .59908 Mdot
.43937 .68941 Mdot
.48177 .43263 Mdot
.76998 .63332 Mdot
.47269 .41783 Mdot
.74242 .72948 Mdot
.54657 .23874 Mdot
.49773 .75591 Mdot
.45021 .36871 Mdot
.37573 .72429 Mdot
.18432 .46279 Mdot
.84239 .47408 Mdot
.18874 .50926 Mdot
.47655 .52344 Mdot
.22793 .36413 Mdot
.62198 .23403 Mdot
.69499 .76941 Mdot
.515 .75252 Mdot
.53291 .41718 Mdot
.62372 .68762 Mdot
.45921 .37833 Mdot
.39055 .4042 Mdot
.2646 .49907 Mdot
.68949 .46685 Mdot
.32287 .43002 Mdot
.23896 .44291 Mdot
.60403 .52383 Mdot
.47909 .20661 Mdot
.79684 .3956 Mdot
.65156 .69521 Mdot
.45417 .46124 Mdot
.24124 .57857 Mdot
.50072 .73529 Mdot
.45244 .8726 Mdot
.59726 .1516 Mdot
.59665 .55434 Mdot
.43193 .58618 Mdot
.45009 .7411 Mdot
.31954 .53769 Mdot
.67207 .48511 Mdot
.80774 .50657 Mdot
.42939 .34053 Mdot
.2797 .51234 Mdot
.3831 .24052 Mdot
.60039 .2805 Mdot
.43608 .66326 Mdot
.41522 .2602 Mdot
.64754 .17509 Mdot
.54484 .82255 Mdot
.59281 .30014 Mdot
.51049 .87622 Mdot
.28348 .32614 Mdot
.69249 .37087 Mdot
.73229 .68217 Mdot
.74055 .28488 Mdot
.46038 .7718 Mdot
.25378 .55879 Mdot
.67494 .26557 Mdot
.48974 .75271 Mdot
.59394 .74402 Mdot
.36483 .34452 Mdot
.3205 .3462 Mdot
.46498 .49449 Mdot
.26171 .65653 Mdot
.51877 .17993 Mdot
.7339 .4016 Mdot
.77788 .36931 Mdot
.22169 .48813 Mdot
.1436 .48439 Mdot
.84776 .46288 Mdot
.51325 .71441 Mdot
.39231 .49727 Mdot
.72457 .69286 Mdot
.40722 .738 Mdot
.66499 .64108 Mdot
.21007 .51876 Mdot
.73712 .59853 Mdot
.24253 .63637 Mdot
.2231 .41225 Mdot
.57259 .74741 Mdot
.67809 .64448 Mdot
.53673 .43883 Mdot
.79462 .53243 Mdot
.3484 .35459 Mdot
.48479 .77817 Mdot
.27713 .53341 Mdot
.40977 .71845 Mdot
.79765 .54964 Mdot
.76417 .65227 Mdot
.5405 .41684 Mdot
.17424 .34275 Mdot
.73335 .3001 Mdot
.25227 .35 Mdot
.56651 .53427 Mdot
.83173 .40533 Mdot
.53602 .39041 Mdot
.69961 .27891 Mdot
.62597 .79251 Mdot
.25823 .47175 Mdot
.48382 .2254 Mdot
.54587 .5438 Mdot
.70557 .31622 Mdot
.77418 .49049 Mdot
.68114 .64794 Mdot
.2254 .51059 Mdot
.476 .76824 Mdot
.38153 .50519 Mdot
.42308 .69019 Mdot
.54381 .49994 Mdot
.65475 .35811 Mdot
.6807 .20969 Mdot
.47949 .52711 Mdot
.58288 .68412 Mdot
.59637 .48401 Mdot
.17952 .525 Mdot
.4328 .8421 Mdot
.56946 .49638 Mdot
.40993 .23597 Mdot
.57044 .76511 Mdot
.55142 .70759 Mdot
.70889 .36746 Mdot
.146 .666 Mdot
.7705 .71012 Mdot
.59307 .41564 Mdot
.65402 .52962 Mdot
.47207 .79048 Mdot
.75627 .29633 Mdot
.28011 .6494 Mdot
.2432 .4905 Mdot
.17076 .59161 Mdot
.41023 .74989 Mdot
.58356 .64228 Mdot
.63064 .80471 Mdot
.84167 .48487 Mdot
.21512 .48742 Mdot
.82037 .40594 Mdot
.60806 .6541 Mdot
.52233 .54946 Mdot
.2862 .79592 Mdot
.81556 .46228 Mdot
.6294 .63706 Mdot
.17524 .5146 Mdot
.65582 .3435 Mdot
.54005 .59158 Mdot
.38404 .31341 Mdot
.53768 .79244 Mdot
.58793 .73714 Mdot
.78246 .32794 Mdot
.63117 .3477 Mdot
.24808 .43123 Mdot
.42346 .32285 Mdot
.52383 .46793 Mdot
.51763 .54701 Mdot
.46945 .31347 Mdot
.53344 .70906 Mdot
.54482 .39462 Mdot
.49482 .32985 Mdot
.4676 .81087 Mdot
.67288 .81183 Mdot
.77479 .56822 Mdot
.49361 .35627 Mdot
.65194 .61141 Mdot
.67009 .6881 Mdot
.47866 .69084 Mdot
.48254 .66282 Mdot
.67124 .78823 Mdot
.84395 .6509 Mdot
.31012 .40148 Mdot
.61413 .51206 Mdot
.68484 .4045 Mdot
.69921 .44854 Mdot
.78343 .46901 Mdot
.46276 .27541 Mdot
.37637 .463 Mdot
.5391 .64517 Mdot
.54548 .49871 Mdot
.41738 .33181 Mdot
.54006 .14042 Mdot
.57334 .63491 Mdot
.71793 .38779 Mdot
.81925 .58475 Mdot
.23192 .54323 Mdot
.71454 .66758 Mdot
.53494 .62839 Mdot
.54749 .2043 Mdot
.53155 .38835 Mdot
.56682 .3708 Mdot
.23921 .50995 Mdot
.77479 .33939 Mdot
.75576 .60536 Mdot
.73595 .37308 Mdot
.58501 .61435 Mdot
.34376 .70817 Mdot
.51565 .26249 Mdot
.67636 .26032 Mdot
.50029 .54195 Mdot
.83058 .57316 Mdot
.25631 .47951 Mdot
.33072 .43123 Mdot
.56596 .70089 Mdot
.7078 .24697 Mdot
.21323 .40944 Mdot
.77116 .45171 Mdot
.31848 .25407 Mdot
.34201 .27686 Mdot
.47111 .69513 Mdot
.32952 .57104 Mdot
.64192 .57097 Mdot
.659 .34655 Mdot
.67544 .18601 Mdot
.66906 .25301 Mdot
.50741 .36485 Mdot
.31773 .37514 Mdot
.74722 .48418 Mdot
.54356 .45371 Mdot
.57413 .8744 Mdot
.31132 .63643 Mdot
.64001 .16971 Mdot
.62347 .73501 Mdot
.65242 .32536 Mdot
.54424 .32279 Mdot
.50216 .61482 Mdot
.34553 .53698 Mdot
.76327 .31001 Mdot
.55525 .49237 Mdot
.24099 .39499 Mdot
.58044 .64071 Mdot
.36374 .22493 Mdot
.49724 .39009 Mdot
.35723 .39192 Mdot
.36532 .38785 Mdot
.18524 .43774 Mdot
.79544 .60845 Mdot
.52216 .39167 Mdot
.54966 .86587 Mdot
.78313 .41411 Mdot
.82781 .46121 Mdot
.35286 .57627 Mdot
.20455 .359 Mdot
.6753 .29973 Mdot
.5721 .33616 Mdot
.50781 .37376 Mdot
.42828 .62169 Mdot
.32389 .26695 Mdot
.55096 .71023 Mdot
.52986 .25358 Mdot
.46237 .37539 Mdot
.89796 .6094 Mdot
.52835 .71766 Mdot
.49613 .62982 Mdot
.26785 .34244 Mdot
.82076 .43151 Mdot
.30971 .69643 Mdot
.64334 .81043 Mdot
.4227 .58677 Mdot
.52473 .54282 Mdot
.75092 .59336 Mdot
.64122 .70857 Mdot
.34873 .25251 Mdot
.25967 .2527 Mdot
.55589 .81587 Mdot
.32637 .40691 Mdot
.50259 .46804 Mdot
.6656 .38532 Mdot
.5851 .41798 Mdot
.26462 .62278 Mdot
.5982 .83621 Mdot
.54041 .36948 Mdot
.80882 .45108 Mdot
.19725 .33525 Mdot
.62627 .74735 Mdot
.76201 .30002 Mdot
.65882 .27957 Mdot
.58282 .4328 Mdot
.48453 .68911 Mdot
.39264 .64729 Mdot
.3692 .40985 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2hooooo`;o
0000Soooool001cooooo00?o0000ooooooooool0^?ooool2o`0008oooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo09Wooooo0_l0002^ooooo`00
7?ooool00ol0003oooooooooo`22ooooo`;o00005Oooool2o`000:kooooo000Looooo`03o`000?oo
oooooooo08;ooooo0_l00035ooooo`007?ooool00ol0003oooooooooo`2/ooooo`;o00002Oooool2
o`00093ooooo000Looooo`03o`000?oooooooooo08oooooo0_l0000Eooooo`;o00001?ooool2o`00
00Wooooo0_l0002@ooooo`007?ooool00ol0003oooooooooo`2?ooooo`;o00000oooool2o`00013o
oooo0_l0002Qooooo`007?ooool00ol0003oooooooooo`2Dooooo`;o0000;?ooool2o`0008Gooooo
000Looooo`;o0000XOooool2o`0001_ooooo1ol00025ooooo`007?ooool00ol0003oooooooooo`2P
ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Eooooo`Go0000Qoooool001cooooo00?o0000
ooooooooool0Xoooool2o`000004ooooool0003o0000o`0001Kooooo0_l00005ooooo`;o0000POoo
ool001cooooo00?o0000ooooooooool0Woooool2o`0000Kooooo0_l00003ooooo`;o00006?ooool2
o`00087ooooo000Looooo`03o`000?oooooooooo09oooooo0_l00009ooooo`Co00006_ooool2o`00
07oooooo000Looooo`03o`000?oooooooooo083ooooo0_l0000Hooooo`Co00003?ooool2o`0000Co
oooo0_l0000Fooooo`;o00002?ooool2o`0007Gooooo000Looooo`03o`000?oooooooooo083ooooo
0_l0000Hooooo`Co00004_ooool2o`0001[ooooo0_l00004ooooo`;o0000MOooool001cooooo00?o
0000ooooooooool0c?ooool2o`000003ooooool0003o000007Sooooo000Looooo`03o`000?oooooo
oooo087ooooo0_l0000eooooo`;o00005Oooool2o`0007Sooooo000Looooo`03o`000?oooooooooo
087ooooo0_l0000Rooooo`;o00004Oooool2o`0001Cooooo0_l0001iooooo`007?ooool00ol0003o
ooooooooo`2Qooooo`?o000000?oooooo`000?l000002_ooool4o`0000Oooooo0_l0000@ooooo`;o
00004_ooool2o`0006Gooooo000Looooo`03o`000?oooooooooo08Gooooo0_l0000@ooooo`;o0000
2?ooool3o`0000;ooooo0_l00009ooooo`Co00001oooool2o`0001[ooooo0_l00008ooooo`;o0000
IOooool001cooooo00?o0000ooooooooool0N_ooool2o`0000?ooooo0_l00002ooooo`Co00003_oo
ool4o`0000gooooo0_l00003ooooo`;o00001_ooool2o`0000Kooooo0_l0000>ooooo`;o00002Ooo
ool4o`0006oooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go0000
1_ooool00ol0003oooooooooo`1jooooo`;o00000oooool2o`0000;ooooo0_l0000@ooooo`;o0000
5?ooool2o`0000Kooooo0_l00003ooooo`;o000000?oooooo`000?l000003_ooool2o`0000Wooooo
0_l00002ooooo`;o0000KOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo08Kooooo0_l0000Moooo
o`Go00003_ooool2o`00017ooooo0_l00009ooooo`;o00000_ooool2o`0006gooooo00000ooooooo
410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003o
ooooooooo`1Zooooo`;o00005Oooool2o`0000?ooooo0_l0000;ooooo`;o00002Oooool2o`0000Go
oooo1Ol00008ooooo`;o00005oooool2o`0000Sooooo0ol0001aooooo`0000?oooooo`000?ooool0
0_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0001Zooooo`;o0000
1Oooool2o`0000Wooooo0_l00003ooooo`;o00000oooool2o`0000_ooooo0_l00002ooooo`;o0000
1Oooool2o`0000Gooooo0_l0000;ooooo`Co00003Oooool2o`00013ooooo0_l0001booooo`0000?o
ooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00Gooooo00?o
0000ooooooooool0LOooool2o`0000Wooooo1?l0000=ooooo`?o00001oooool2o`0000Gooooo0ol0
0004ooooo`;o00001oooool8o`0000Wooooo0_l00002ooooo`;o00001Oooool2o`0007gooooo0000
0ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1looooo`Co00003Oooool3o`000004ooooool0003o0000o`0000?ooooo0ol0
0004ooooo`?o00001?ooool2o`0000Oooooo2?l00009ooooo`?o00002?ooool2o`0007gooooo0000
1_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03
o`000?oooooooooo06Gooooo1?l0000Cooooo`;o00004oooool3o`0000?ooooo0ol00004ooooo`;o
00001?ooool2o`0000kooooo0_l00009ooooo`?o000000Coooooo`000?l0003o00001?ooool2o`00
00gooooo0_l0001^ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Uooooo`Co00005oooool2o`0000Kooooo0_l0
0004ooooo`;o00000_ooool2o`000003ooooool0003o000000Oooooo0_l00004ooooo`;o00002?oo
ool2o`0000oooooo0_l00002ooooo`?o00001?ooool2o`0000gooooo0_l0001^ooooo`007?ooool0
0ol0003oooooooooo`1kooooo`;o00000oooool2o`0000Kooooo0_l00004ooooo`?o00001?ooool2
o`0000Kooooo1?l00005ooooo`;o00001_ooool2o`0000Wooooo0_l00003ooooo`;o00001?ooool2
o`0008?ooooo000Looooo`03o`000?oooooooooo067ooooo0_l0000Eooooo`;o000000?oooooo`00
0?l000000_ooool2o`0000gooooo0ol00005ooooo`;o00001Oooool6o`0000?ooooo0_l0000Aoooo
o`;o00000oooool2o`0001?ooooo0_l000001?oooooo0000o`000?ooool2o`0006kooooo000Loooo
o`03o`000?oooooooooo067ooooo0_l0000=ooooo`;o00001?ooool5o`0000?ooooo0ol0000=oooo
o`;o00001_ooool2o`0000Wooooo0_l00008ooooo`;o00003_ooool2o`0001Kooooo0_l000001?oo
oooo0000o`000?ooool2o`0006kooooo000Looooo`03o`000?oooooooooo06oooooo1Ol00002oooo
o`Go00000oooool2o`0000Kooooo1?l0000<ooooo`Go00004?ooool2o`000003ooooool0003o0000
00;ooooo0_l00007ooooo`;o00000_ooool2o`0001Gooooo0_l0000;ooooo`;o0000I?ooool001co
oooo00?o0000ooooooooool0Koooool2o`000003ooooool0003o000000Cooooo0ol00006ooooo`Wo
00003?ooool5o`0000Oooooo0_l00007ooooo`Go00000_ooool2o`0000_ooooo0_l00004ooooo`;o
00001_ooool2o`0000Wooooo0_l00009ooooo`;o000000?oooooo`000?l00000HOooool001cooooo
00?o0000ooooooooool0Ioooool2o`0000Cooooo0_l00008ooooo`Go00000oooool7o`000003oooo
ool0003o000000;o00000oooool3o`00017ooooo1?l00006ooooo`;o00005_ooool3o`0000Kooooo
0_l00006ooooo`;o000000?oooooo`000?l000003?ooool2o`00067ooooo000Looooo`03o`000?oo
oooooooo06Oooooo0_l00004ooooo`;o00000_ooool5o`000003ooooool0003o000000?o00000ooo
ool4o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000003o`0000[ooooo0_l0
0007ooooo`;o00000oooool2o`0000Kooooo1?l0000?ooooo`Co00003Oooool2o`0000Cooooo0_l0
001/ooooo`007?ooool00ol0003oooooooooo`1Tooooo`;o00001?ooool2o`0000?ooooo1ol00002
ooooo`;o000000?oooooo`000?l000000_ooool4o`000004ooooool0003o0000ooooo`;o00000ooo
ool2o`0000gooooo1?l0000:ooooo`;o00000_ooool3o`000003ooooool0003o000000;o00001Ooo
ool2o`0000Sooooo1Ol00007ooooo`;o00002Oooool2o`0000Kooooo0_l0001Tooooo`007?ooool0
0ol0003oooooooooo`1Tooooo`;o00001?ooool2o`0000?ooooo0ol00007ooooo`Co00002_ooool2
o`0000;ooooo0_l000000ooooooo0000o`000007ooooo`?o00000oooool2o`0000kooooo0ol0000:
ooooo`;o00002?ooool2o`000004ooooool0003o0000ooooo`;o00001?ooool2o`00017ooooo0_l0
001Tooooo`007?ooool00ol0003oooooooooo`1[ooooo`;o00000oooool2o`0000Oooooo0_l0000?
ooooo`?o000000?oooooo`000?l000001oooool4o`0000Kooooo0_l0000Mooooo`;o00001?ooool2
o`0000;ooooo0_l0001mooooo`007?ooool00ol0003oooooooooo`1Xooooo`;o000000?oooooo`00
0?l000001_ooool2o`0000;ooooo0_l00008ooooo`;o00001Oooool4o`0000?ooooo0_l00008oooo
o`;o00001Oooool3o`0001gooooo0_l000001?oooooo0000o`000?ooool3o`0001Wooooo0_l0001U
ooooo`007?ooool2o`0006Wooooo0_l00009ooooo`;o00000_ooool2o`0000Sooooo0_l00005oooo
o`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000;o00002_ooool2o`00
00Cooooo0_l0000Kooooo`;o00000_ooool2o`0001;ooooo0_l00005ooooo`Go0000H_ooool001co
oooo00?o0000ooooooooool0DOooool3o`00013ooooo0_l00003ooooo`;o00000oooool2o`0000Oo
oooo0_l0000?ooooo`Go00001Oooool4o`00013ooooo1?l000000ooooooo0000o`00000Mooooo`;o
00002_ooool2o`0000?ooooo0_l00007ooooo`?o0000H_ooool001cooooo00?o0000ooooooooool0
DOooool3o`00013ooooo0ol00002ooooo`;o00000oooool2o`0000Oooooo0_l00004ooooo`;o0000
2Oooool4o`0001cooooo0_l000000ooooooo0000o`00000<ooooo`;o00003oooool2o`0000[ooooo
0_l0001aooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o00000oooool2o`0000cooooo0_l0
0002ooooo`?o00001?ooool2o`0001kooooo0_l00003ooooo`;o00003oooool4o`0000_ooooo0_l0
000>ooooo`;o0000Koooool001cooooo00?o0000ooooooooool0I_ooool2o`0000;ooooo0_l00009
ooooo`;o000000Coooooo`000?l0003ooooo0ol00005ooooo`?o00000_ooool2o`0000cooooo0_l0
000;ooooo`?o00000_ooool2o`0000oooooo1?l0000;ooooo`;o00001_ooool2o`0000Gooooo0ol0
0005ooooo`;o0000J?ooool001cooooo00?o0000ooooooooool0IOooool3o`0000gooooo0_l00004
ooooo`;o00001oooool2o`0000;ooooo0_l00009ooooo`Go00000oooool2o`0000?ooooo0_l00002
ooooo`Co00003oooool2o`0000Oooooo0_l0000>ooooo`;o00000oooool4o`0000Kooooo0_l0001X
ooooo`007?ooool00ol0003oooooooooo`1Qooooo`;o00000_ooool2o`0000kooooo0_l00004oooo
o`;o00001?ooool2o`0000?ooooo0_l0000;ooooo`Go00000oooool2o`0000?ooooo0_l00003oooo
o`?o00003oooool2o`0000Oooooo0_l0000Cooooo`Co00003Oooool2o`00067ooooo000Looooo`03
o`000?oooooooooo05cooooo0_l00003ooooo`;o00004Oooool3o`0000Cooooo1?l00002ooooo`;o
00000oooool2o`0001Wooooo0_l0000Wooooo`;o00003oooool2o`0000Sooooo0ol0001Qooooo`00
7?ooool00ol0003oooooooooo`1Looooo`;o000000?oooooo`000?l000000_l00008ooooo`;o0000
1oooool2o`0000Gooooo1?l0000Booooo`Co00001_ooool2o`0000Cooooo2Ol0000=ooooo`;o0000
4Oooool2o`0000oooooo0_l00008ooooo`Co000000?oooooo`000?l00000GOooool001cooooo00?o
0000ooooooooool0Goooool4o`0000Sooooo0_l00004ooooo`;o00001Oooool2o`0001?ooooo0_l0
0002ooooo`Co00000oooool2o`000003ooooool0003o000000Cooooo2Ol0000=ooooo`?o000000?o
ooooo`000?l000005Oooool2o`0000?ooooo0_l00006ooooo`?o00000_ooool5o`000003ooooool0
003o000000?ooooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`1Fooooo`;o00001Oooool2
o`0000;ooooo0_l0000=ooooo`?o00000oooool4o`0001?ooooo0_l00009ooooo`;o00000_ooool2
o`0000?ooooo0ol00003ooooo`?o00002oooool2o`000004ooooool0003o0000ooooo`;o00000_oo
ool4o`0000Oooooo0_l00006ooooo`;o00000oooool4o`0000Cooooo0ol00002ooooo`?o00002?oo
ool4o`0005Kooooo000Looooo`03o`000?oooooooooo05Kooooo0_l000000ooooooo0000o`000002
ooooo`Co00003oooool2o`0000Cooooo0_l0000Looooo`;o00001?ooool4o`000003ooooool0003o
000000[ooooo0_l000000ooooooo0000o`000004ooooo`?o00001_ooool6o`0000Oooooo0_l0000=
ooooo`;o00004Oooool3o`0000;ooooo0_l000000ooooooo0000o`00001Cooooo`007?ooool00ol0
003oooooooooo`1Iooooo`;o00001?ooool2o`0001[ooooo0_l0000Gooooo`;o00001?ooool2o`00
00?ooooo0_l0000:ooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o0000
00Cooooo0_l00003ooooo`;o00005oooool2o`0000Gooooo0ol00007ooooo`?o00001Oooool2o`00
05?ooooo000Looooo`03o`000?oooooooooo05kooooo0_l0000Kooooo`;o00003Oooool>o`000003
ooooool0003o000000Cooooo0_l00009ooooo`;o00002oooool2o`0000?ooooo0_l00004ooooo`Co
00004_ooool2o`000003ooooool0003o000000Gooooo1Ol00003ooooo`;o0000GOooool001cooooo
00?o0000ooooooooool0F_ooool2o`0000;ooooo1?l0000Xoooooa7o000000?oooooo`000?l00000
1Oooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o00002_ooool2o`0000Gooooo
0ol00002ooooo`;o00003_ooool2o`0000;ooooo0_l00005ooooo`Co00000oooool2o`0005gooooo
000Looooo`03o`000?oooooooooo057ooooo0_l000000ooooooo0000o`000004ooooo`;o00001?oo
ool2o`0000Cooooo0_l0000Pooooo`;o000000?oooooo`000?l000003_l000001?oooooo0000o`00
0?l00004ooooo`;o000000?oooooo`000?l000001_ooool4o`000004ooooool0003o0000ooooo`;o
00002oooool2o`0000?ooooo0_l0000Booooo`;o000000?oooooo`000?l000000_ooool2o`0000go
oooo0ol0001Dooooo`007?ooool2o`0005;ooooo1Ol00003ooooo`?o00000_ooool2o`0000Gooooo
0ol00006ooooo`;o00005OoooolEo`0000?ooooo0_l0000?ooooo`;o00000oooool5o`0000Gooooo
0_l00005ooooo`;o00000_ooool2o`0000[ooooo0_l00002ooooo`;o00001Oooool2o`0000;ooooo
0_l00005ooooo`;o00001_ooool4o`0000oooooo0_l00012ooooo`007?ooool00ol0003ooooooooo
o`1Cooooo`;o00000_ooool5o`000004ooooool0003o0000o`0000Gooooo0_l00007ooooo`;o0000
5OoooolFo`000003ooooool0003o000000Oooooo0_l0000=ooooo`;o00001oooool2o`0000Gooooo
0_l00002ooooo`;o00002_ooool2o`0000;ooooo0_l0000@ooooo`;o00002?ooool2o`0000oooooo
0_l00012ooooo`007?ooool00ol0003oooooooooo`1Gooooo`Co00000_ooool2o`0000Kooooo0_l0
000Cooooo`;o00003?oooolCo`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`00
0008ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00002_ooool2o`0000Cooooo0_l0
000Dooooo`;o00007oooool2o`00047ooooo000Looooo`03o`000?oooooooooo04Cooooo0_l0000=
ooooo`;o00001?ooool2o`0000Oooooo0_l000000ooooooo0000o`00000Cooooo`;o00002ooooolG
o`0000Cooooo0_l00008ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l00003
ooooo`;o00002_ooool2o`0000Cooooo0_l0000Dooooo`;o00003Oooool2o`00013ooooo0_l00011
ooooo`007?ooool00ol0003oooooooooo`11ooooo`;o000000?oooooo`000?l000002oooool4o`00
0003ooooool0003o000000[ooooo0_l0000?ooooo`;o00001?ooool2o`0000[ooooo6Ol00002oooo
o`Co000000?oooooo`000?l000001Oooool2o`0000Gooooo0_l00006ooooo`;o00007Oooool2o`00
00Gooooo0ol000000ooooooo0000o`000004ooooo`;o00000oooool2o`0000;ooooo0_l00002oooo
o`;o00003Oooool2o`00043ooooo000Looooo`03o`000?oooooooooo047ooooo0_l0000=ooooo`Co
00000_ooool2o`0001[ooooo0ol00004ooooo`;o00002OoooolIo`0000?ooooo0_l00003ooooo`;o
00002_ooool4o`0000Kooooo0_l0000=ooooo`;o00003_ooool2o`0000Gooooo0ol000000ooooooo
0000o`000004ooooo`;o00000oooool2o`0000Kooooo0_l0000=ooooo`;o0000@?ooool001cooooo
00?o0000ooooooooool0Coooool5o`00013ooooo0_l00005ooooo`;o00000oooool4o`00013ooooo
5ol000001?oooooo0000o`000?l0000@ooooo`Co00002?ooool2o`0000Kooooo1?l00003ooooo`;o
00001_ooool6o`0000Cooooo0_l00003ooooo`;o0000I_ooool001cooooo00?o0000ooooooooool0
COooool4o`000003ooooool0003o0000013ooooo0_l00005ooooo`;o00000oooool2o`0001?ooooo
5_l000001?oooooo0000o`000?l0000>ooooo`Co00002_ooool2o`0000Kooooo1?l00002ooooo`;o
00001oooool6o`0000Cooooo0_l00006ooooo`;o0000Hoooool001cooooo00?o0000ooooooooool0
Boooool4o`0000Cooooo0_l00003ooooo`?o00002Oooool2o`0000?ooooo0_l000000ooooooo0000
o`000007ooooo`;o00002oooool2o`0000;ooooo1Ol000000ooooooo0000o`00000@o`0000oooooo
0_l00006ooooo`;o00004_ooool2o`0000Gooooo0_l0000<ooooo`;o000000Coooooo`000?l0003o
oooo0_l0000Eooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0Boooool4o`0000Cooooo
0_l00003ooooo`?o00003_ooool2o`000003ooooool0003o000000Oooooo1?l00009oooooa[o0000
3_ooool2o`0000Wooooo0_l0000Iooooo`;o00003?ooool2o`000003ooooool0003o000001Cooooo
0_l000001?oooooo0000o`000?l0001<ooooo`007?ooool00ol0003oooooooooo`0nooooo`;o0000
3Oooool5o`0000[ooooo0_l0000?ooooo`;o00001_ooool4o`0000Wooooo7Ol0000:ooooo`?o0000
1?ooool4o`000003ooooool0003o000000;o00000_ooool2o`000003ooooool0003o000000cooooo
0_l0000Yooooo`;o000000Coooooo`000?l0003o0000C?ooool001cooooo00?o0000ooooooooool0
??ooool4o`0000[ooooo0_l00003ooooo`?o00002_ooool2o`0000oooooo0_l0000Coooooago0000
2_ooool2o`0000Gooooo1?l000000ooooooo0000o`000002o`0000;ooooo0_l000000ooooooo0000
o`000004ooooo`?o00001Oooool2o`0001Gooooo0_l0000?ooooo`;o00001Oooool2o`0004cooooo
000Looooo`03o`000?oooooooooo03cooooo0_l0000<ooooo`;o00001Oooool4o`0001oooooo0_l0
0007ooooo`;o00000oooool2o`000003ooooool0003o000001So00004oooool2o`0000;ooooo0ol0
000;ooooo`?o00001?ooool2o`0001Kooooo0_l00008ooooo`;o00001Oooool2o`0005?ooooo000L
ooooo`03o`000?oooooooooo057ooooo1?l0000Oooooo`;o00001oooool2o`0000?ooooo7Ol0000?
ooooo`;o00001_ooool3o`0001;ooooo0_l0000Pooooo`;o00001?ooool2o`0000?ooooo0_l0001?
ooooo`007?ooool00ol0003oooooooooo`0eooooo`;o00006oooool3o`0000?ooooo0_l00009oooo
o`;o000000?oooooo`000?l000002oooool2o`0000gooooo6ol00002ooooo`;o00003Oooool2o`00
01;ooooo0_l0000:ooooo`Go00001oooool2o`0000Kooooo0_l00007ooooo`;o00001Oooool3o`00
00;ooooo0ol000000ooooooo0000o`00001<ooooo`007?ooool00ol0003oooooooooo`0eooooo`;o
00007?ooool2o`0000?ooooo0_l00002ooooo`?o00001?ooool5o`0000_ooooo0_l00006ooooo`;o
00002?oooolEo`0000Gooooo0_l0000:ooooo`;o00002_ooool2o`0000Gooooo0_l00002ooooo`Co
000000?oooooo`000?l000000_l00002ooooo`Wo00001?ooool2o`000003ooooool0003o000000?o
oooo0_l00007ooooo`Co00000oooool2o`0000?ooooo0_l00002ooooo`;o0000C?ooool001cooooo
0_l00016ooooo`;o00001oooool2o`0000cooooo0ol00005ooooo`;o00003Oooool2o`0000Kooooo
0_l00008oooooaOo00003oooool2o`0000Oooooo0_l000000ooooooo0000o`000005ooooo`;o0000
1?ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000002?l00007ooooo`;o0000
0oooool2o`0000Wooooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00001?oo
ool2o`000003ooooool0003o000000[ooooo0_l0000=ooooo`;o00000_ooool2o`0000Gooooo1Ol0
0007ooooo`;o00000ooooolGo`0000gooooo0_l00009ooooo`;o00004Oooool2o`000003ooooool0
003o000000;o000000?oooooo`000?l000004Oooool2o`0001Wooooo0_l0001:ooooo`007?ooool0
0ol0003oooooooooo`1;ooooo`?o00002?ooool2o`0000;ooooo0ol0000:ooooo`So00001Oooool5
o`0000Oooooo0_l00004ooooo`?o000000?oooooo`000?l000004?l000000ooooooo0000o`00000:
ooooo`Oo00003Oooool4o`0000;ooooo2Ol00002ooooo`?o000000Coooooo`000?l0003o00009Ooo
ool2o`000003ooooool0003o000000Gooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`0o
ooooo`;o000000?oooooo`000?l000002?ooool2o`0000Sooooo0_l00003ooooo`;o00002_ooool2
o`0000;ooooo1?l0000HoooooaGo000000?oooooo`000?l000000oooool2o`0000Oooooo1Ol0000=
ooooo`Co00000_oooolBo`0001[ooooo1?l00007ooooo`;o00002?ooool2o`0004?ooooo000Loooo
o`03o`000?oooooooooo033ooooo0_l0000=ooooo`;o000000?oooooo`000?l000002oooool2o`00
00[ooooo0_l0000?ooooo`;o000000?oooooo`000?l000003oooool2o`0000Cooooo4Ol00003oooo
o`;o00001_ooool3o`0001oooooo5?l00006ooooo`;o00003oooool4o`0000?ooooo0_l0000<oooo
o`;o0000@oooool001cooooo00?o0000ooooooooool0<?ooool2o`0000;ooooo0_l0000@ooooo`;o
00001oooool2o`0001;ooooo0ol00002ooooo`Wo00003oooool2o`0000Cooooo1?l00002ooooo`co
00000_ooool2o`000003ooooool0003o000000;ooooo1Ol0000@ooooo`;o00003?ooool?o`000003
ooooool0003o000000Go00000oooool2o`0001Kooooo0_l0001Aooooo`007?ooool00ol0003ooooo
ooooo`0dooooo`;o00003_ooool4o`0000Oooooo1?l0000<ooooo`;o00000_ooool3o`0000;ooooo
2?l00007ooooo`;o00000_ooool2o`0000Wooooo2_l00003ooooo`Go00001Oooool2o`0000;ooooo
0_l000000ooooooo0000o`00000@ooooo`;o00002OoooolJo`000003ooooool0003o000000Cooooo
0_l0000Eooooo`;o00001Oooool2o`0000;ooooo0_l00013ooooo`007?ooool00ol0003ooooooooo
o`10ooooo`;o00000_ooool2o`0000Sooooo1Ol0000<ooooo`;o00000_ooool2o`0000Wooooo0_l0
0007ooooo`;o00000_ooool2o`0000gooooo0_l00002ooooo`;o00000oooool6o`0000Cooooo0_l0
0005ooooo`;o00001_ooool2o`0000Kooooo0_l00007ooooo`;o000000?oooooo`000?l000002ol0
00000ooooooo0000o`00000;o`000003ooooool0003o000000;o00000_ooool2o`0000Kooooo0_l0
000=ooooo`;o00001Oooool2o`0000;ooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`10
ooooo`;o00001?ooool2o`0000Kooooo1Ol0000@ooooo`;o00002?ooool4o`0000;ooooo0_l00002
ooooo`;o00002_ooool2o`0000;ooooo0_l00009ooooo`?o00000_ooool2o`0000Cooooo1_l00009
ooooo`Co00001?ooool2o`0000Cooooo8_l000001Ooooooo0000o`000?l0003ooooo00;o00001ooo
ool3o`0000?ooooo0_l0000?ooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0A_ooool2
o`0000Oooooo0_l00007ooooo`Co00001oooool2o`0000Sooooo2?l00002ooooo`Co00002?ooool2
o`0000;ooooo0_l00008ooooo`?o000000Coooooo`000?l0003o00001Oooool6o`0000_ooooo0_l0
0006ooooo`;o00000_ooool3o`000003ooooool0003o000001Go000000?oooooo`000?l000001?l0
0004ooooo`?o00002?ooool4o`000003ooooool0003o000000oooooo0_l00016ooooo`007?ooool0
0ol0003oooooooooo`19ooooo`;o00000_ooool2o`0000Cooooo0_l00003ooooo`Co00001?ooool2
o`000003ooooool0003o000000Oooooo0_l000000ooooooo0000o`000004o`0000?ooooo1?l0000E
ooooo`;o000000?oooooo`000?l000000_l00005ooooo`;o00003?ooool2o`0000Wooooo0_l00000
0ooooooo0000o`00000Ko`0000;ooooo1_l00002ooooo`;o00002oooool2o`000003ooooool0003o
0000013ooooo0ol0000?ooooo`;o0000<oooool001cooooo00?o0000ooooooooool0BOooool2o`00
00;ooooo0_l00002ooooo`Co00002oooool2o`000004ooooool0003o0000ooooo`;o00001?ooool2
o`0000Gooooo1?l00003ooooo`;o00006?ooool2o`0000Gooooo1?l00003ooooo`;o00001oooool3
o`0000_ooooo0_l000000ooooooo0000o`000005o`000003ooooool0003o0000017o00000_ooool5
o`0000oooooo0_l000000ooooooo0000o`00000>ooooo`Go00003oooool2o`0003?ooooo000Loooo
o`03o`000?oooooooooo02[ooooo0_l0000@ooooo`;o00001Oooool2o`0000cooooo0_l0000=oooo
o`;o000000Coooooo`000?l0003ooooo0_l0000;ooooo`Co00000_ooool2o`00023ooooo1?l00003
ooooo`;o00002?ooool4o`0000_ooooo7_l00002ooooo`;o00002?ooool2o`0000Kooooo0_l0000:
ooooo`;o00001Oooool4o`0004Gooooo000Looooo`03o`000?oooooooooo02[ooooo0_l0000@oooo
o`?o00000oooool3o`0000Kooooo0_l00004ooooo`;o00008?ooool5o`000003ooooool0003o0000
02;ooooo0ol00009ooooo`?o000000Coooooo`000?l0003o00002ooooolQo`0000?ooooo0_l00004
ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Sooooo0_l00007ooooo`;o0000AOooool0
0006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413ooooooooo
o`04ooooo`03o`000?oooooooooo03gooooo0_l00003ooooo`;o000000?oooooo`000?l000000_oo
ool6o`0000;ooooo0_l0000Mooooo`;o000000?oooooo`000?l000000ol000000ooooooo0000o`00
000Cooooo`;o00002?ooool2o`0000Cooooo0_l00006ooooo`;o000000Goooooo`000?l0003o0000
ooooo`02o`0000_ooooo1_l000000ooooooo0000o`00000:o`000003ooooool0003o000000co0000
0_ooool3o`0000Oooooo0_l00005ooooo`;o00000oooool2o`0000kooooo1?l00011ooooo`0000Ko
ooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo04Gooooo0_l00002ooooo`Ko00000_ooool2o`000003ooooool0003o000000Wo
oooo0_l0000?ooooo`;o000000?oooooo`000?l000000_l00002ooooo`?o00004_ooool2o`0000So
oooo0_l0000<ooooo`;o00000_ooool7o`0000Sooooo1_l00002oooooa[o00000oooool2o`0001Co
oooo0_l00006ooooo`Go00000oooool4o`00047ooooo00000ooooooo410@ooooo`02ooooo`03oa0@
4?oooooooooo00Wooooo1Ol00006ooooo`03o`000?oooooooooo037ooooo0_l0000=ooooo`?o0000
1Oooool2o`000003ooooool0003o000000Cooooo0_l000001?oooooo0000o`000?l00002ooooo`?o
00000oooool4o`0000?ooooo0_l00007ooooo`;o00001?ooool2o`0000?ooooo0ol00006ooooo`;o
00001Oooool2o`0001kooooo1ol00005ooooo`;o000000?oooooo`000?l000005ol000000ooooooo
0000o`000006o`0001[ooooo0_l00005ooooo`Oo00000oooool2o`00047ooooo00000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`00037o
oooo0_l00005ooooo`;o00001_ooool3o`0000Gooooo0_l00006ooooo`;o00000oooool2o`0000;o
oooo0ol00005ooooo`;o00000oooool2o`0000Oooooo0_l000001?oooooo0000o`000?ooool2o`00
00;ooooo1?l00006ooooo`;o00000oooool4o`0000[ooooo0_l0000<ooooo`;o00004?ooool2o`00
0003ooooool0003o000001Ko000000?oooooo`000?l000001_l00006ooooo`;o00002Oooool2o`00
00;ooooo0_l00004ooooo`;o00002_ooool2o`0000Cooooo0_l00008ooooo`;o00001?ooool2o`00
033ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoo
oooo00001oooool00ol0003oooooooooo`0hooooo`;o00002?ooool2o`0000cooooo0_l00003oooo
o`Co00002?ooool2o`0000kooooo0ol000001?oooooo0000o`000?ooool6o`0000[ooooo0_l00007
ooooo`?o00000_ooool2o`0000Gooooo0_l00005ooooo`;o00004_ooool2o`0000Cooooo4?l00000
1?oooooo0000o`000?ooool;o`0000?ooooo0_l00006ooooo`;o000000?oooooo`000?l000000_oo
ool2o`0000Oooooo0_l0000=ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Cooooo0_l0
000`ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co
000000Oooooo00?o0000ooooooooool0@_ooool2o`00013ooooo1ol0000;ooooo`;o00000oooool2
o`0000Cooooo3Ol0000Cooooo`?o00000_ooool2o`0000Gooooo0_l000000ooooooo0000o`00000F
ooooo`;o00000ooooolAo`000003ooooool0003o000000co00002oooool2o`0000kooooo0_l0000=
ooooo`Go0000?Oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`00
0007ooooo`03o`000?oooooooooo02oooooo0_l0000=ooooo`;o00000_ooool2o`000003ooooool0
003o000000gooooo1ol00007ooooo`;o00000_ooool2o`0000?ooooo1?l00003ooooo`_o00006Ooo
ool2o`0000Sooooo0_l0000Kooooo`co000000?oooooo`000?l000003Ol000000ooooooo0000o`00
000:ooooo`;o00000_ooool2o`0000Kooooo0_l00003ooooo`;o00003Oooool4o`0003oooooo0000
1_ooooook^k^oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooo
ooooo`0_ooooo`;o00003Oooool3o`0000Cooooo0_l00003ooooo`;o00000oooool2o`0000Sooooo
0_l00007ooooo`;o000000?oooooo`000?l000000oooool2o`000003ooooool0003o000000Cooooo
2_l00003ooooo`;o00002?ooool2o`0001?ooooo1_l00005ooooo`Co00001Oooool4o`0000Gooooo
6ol00003ooooo`;o00002_ooool2o`0000;ooooo0_l00006ooooo`;o00000oooool2o`0000;ooooo
0_l00005ooooo`;o00000_ooool2o`0001Cooooo0_l0000[ooooo`007?ooool00ol0003ooooooooo
o`0aooooo`;o00001Oooool2o`0000?ooooo1?l00009ooooo`;o00000oooool2o`0000Sooooo0_l0
000:ooooo`;o000000?oooooo`000?l000000_l00006ooooo`_o00000oooool2o`0000Gooooo0_l0
00000ooooooo0000o`000007ooooo`;o000000?oooooo`000?l000001oooool6o`0000Cooooo1Ol0
0005ooooo`Co00000ooooolAo`000003ooooool0003o000000Wo000000?oooooo`000?l000000_l0
000Oooooo`;o00001Oooool2o`0001Cooooo0_l00002ooooo`;o0000:oooool001cooooo00?o0000
ooooooooool0;_ooool2o`000003ooooool0003o000000Gooooo0_l00002ooooo`?o00001oooool2
o`0000Wooooo0_l0000Cooooo`Co00002?ooool;o`0000[ooooo0_l0000:ooooo`;o000000?ooooo
o`000?l000000ol0000;ooooo`;o000000?oooooo`000?l000000ol0000<ooooo`;o00000_oooolH
o`0000;ooooo1?l000000ooooooo0000o`00000Nooooo`;o00001Oooool2o`0000Gooooo0_l0000;
ooooo`Co0000;Oooool001cooooo00?o0000ooooooooool0;_ooool2o`0000cooooo0_l000000ooo
oooo0000o`000005ooooo`;o00001oooool5o`0001;ooooo0_l00005ooooo`?o00000oooool<o`00
01Wooooo0ol00008ooooo`;o000000?oooooo`000?l000001?l00006ooooo`;o00001_ooool6o`00
0003ooooool0003o000000ko000000?oooooo`000?l000000_l00007ooooo`;o00001_ooool9o`00
00;ooooo0_l0000;ooooo`;o00001Oooool2o`0000Gooooo0_l0000;ooooo`Co0000;Oooool001co
oooo00?o0000ooooooooool0?oooool2o`0000kooooo0_l000000ooooooo0000o`00000Iooooo`?o
00001?ooool;o`0001;ooooo0_l00007ooooo`;o00001oooool6o`0000Wooooo1?l00006ooooo`Co
000000?oooooo`000?l000003_l000000ooooooo0000o`00000Aooooo`Wo00000_ooool2o`00017o
oooo0ol0000Booooo`;o0000;oooool001cooooo00?o0000ooooooooool0?Oooool2o`0000Gooooo
0_l00008ooooo`?o00005?ooool2o`0000gooooo2_l0000@ooooo`;o000000?oooooo`000?l00000
1oooool2o`0000Oooooo1_l0000;ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo
3Ol00002ooooo`;o00000oooool2o`0000Gooooo0_l00006ooooo`Oo00000_ooool5o`0000;ooooo
0_l0000>ooooo`?o0000@oooool001cooooo00?o0000ooooooooool0?Oooool2o`0000Gooooo0_l0
0007ooooo`?o00005Oooool2o`000003ooooool0003o000000[ooooo0_l000000ooooooo0000o`00
0003o`0000_ooooo0_l00005ooooo`;o00002Oooool2o`0000Oooooo0ol000001Ooooooo0000o`00
0?l0003ooooo00;o00002?ooool2o`000004ooooool0003o0000ooooo`Co000000?oooooo`000?l0
00003?l00002ooooo`?o00000_ooool2o`0000Gooooo0_l00004ooooo`Co00001oooool5o`0000;o
oooo0_l00002ooooo`;o00003_ooool2o`00043ooooo000Looooo`03o`000?oooooooooo02oooooo
0_l00007ooooo`;o00004oooool2o`0001Wooooo0_l00006ooooo`;o00000_ooool8o`0000_ooooo
0_l00003ooooo`;o00000_ooool2o`0000Oooooo0_l00007ooooo`;o000000?oooooo`000?l00000
0_l000000ooooooo0000o`00000:ooooo`;o00000_ooool4o`000003ooooool0003o000000go0000
0_ooool2o`0000;ooooo0_l0000;ooooo`;o00003oooool2o`0000?ooooo0_l0000:ooooo`;o0000
0_ooool2o`00043ooooo000Looooo`03o`000?oooooooooo02oooooo0_l00003ooooo`;o00000_oo
ool2o`0000kooooo0_l0000Pooooo`So000000?oooooo`000?l000001ol00004ooooo`;o00000_oo
ool4o`0000Cooooo0_l00002ooooo`;o00003oooool3o`000003ooooool0003o000000;o00000_oo
ool4o`0000Oooooo0_l00003ooooo`?o00001oooool:o`0001?ooooo0_l000001?oooooo0000o`00
0?ooool2o`0000Sooooo0_l0000?ooooo`;o00001_ooool2o`0003cooooo000Looooo`03o`000?oo
oooooooo03;ooooo1?l00002ooooo`;o00000_ooool2o`0000[ooooo1?l0000Moooooa;o00001?oo
ool3o`0000;ooooo1Ol00003ooooo`;o00001?ooool2o`0000gooooo0_l00008ooooo`Ko00002_oo
ool4o`0000Oooooo0_l000000ooooooo0000o`000006o`0000Kooooo0_l00005ooooo`;o00000_oo
ool5o`000003ooooool0003o000000Oooooo0ol0000Gooooo`;o00003Oooool2o`0002gooooo000L
ooooo`03o`000?oooooooooo03;ooooo0_l00004ooooo`?o000000?oooooo`000?l000003?ooool2
o`0000Oooooo0_l00002ooooo`;o00004?ooool6o`000004ooooool0003o0000o`0000;ooooo1_l0
0002ooooo`Co00001_ooool4o`0000?ooooo0_l00002ooooo`;o00003oooool2o`0000Kooooo0ol0
00000ooooooo0000o`00000:ooooo`Co00000oooool5o`0000?ooooo2?l00005ooooo`;o00001Ooo
ool2o`0000Cooooo0_l0000;ooooo`?o00002?ooool2o`0001cooooo0_l0000]ooooo`007?ooool0
0ol0003oooooooooo`0hooooo`?o00005_ooool4o`0000;ooooo0_l0000>ooooo`;o00000_ooool7
o`0000;ooooo1ol00002ooooo`;o00002_ooool2o`0000?ooooo0_l0000>ooooo`;o00000oooool2
o`0000Oooooo0_l0000Booooo`Oo00000oooool2o`0000Cooooo0_l00002ooooo`;o00002Oooool2
o`000003ooooool0003o000000Wooooo0_l00002ooooo`;o00002Oooool2o`0000Gooooo0_l00009
ooooo`;o0000>Oooool001cooooo0_l0001Booooo`;o00001?ooool2o`0000Cooooo0_l00008oooo
o`;o00000_ooool7o`0000;ooooo1ol00004ooooo`;o00000_ooool2o`0000Sooooo0ol00006oooo
o`;o00001_ooool2o`0000Wooooo1?l000000ooooooo0000o`000002o`0000kooooo0_l000000ooo
oooo0000o`000002o`0000?ooooo0_l00007ooooo`?o00002Oooool2o`000004ooooool0003o0000
o`0000Sooooo1_l00004ooooo`;o000000?oooooo`000?l000001?l00003ooooo`;o000000?ooooo
o`000?l000001_ooool2o`0000kooooo0_l0000Yooooo`007?ooool00ol0003oooooooooo`0doooo
o`;o000000?oooooo`000?l000004_ooool2o`0000Kooooo0_l00002ooooo`;o00001?ooool2o`00
013ooooo1?l000000ooooooo0000o`000004o`0000Gooooo0ol000000ooooooo0000o`000002oooo
o`;o00001?ooool2o`0000Oooooo0_l0000Aooooo`Wo000000?oooooo`000?l000001_ooool4o`00
00?ooooo0ol0000>ooooo`;o00001oooool2o`0000Gooooo0_l0000:ooooo`;o00001_ooool2o`00
0004ooooool0003o0000ooooo`?o00000oooool2o`000003ooooool0003o000000;o00005?ooool2
o`0002Wooooo000Looooo`03o`000?oooooooooo03Cooooo0_l000000ooooooo0000o`000003oooo
o`;o00003Oooool2o`0000Kooooo0_l0000Fooooo`oo00001?ooool4o`0000Gooooo0_l00005oooo
o`;o00001?ooool2o`0000Kooooo0_l0000;ooooo`;o00000_ooool3o`0000?ooooo0_l00006oooo
o`Co00000oooool2o`0000Sooooo0ol0000=ooooo`;o00002_ooool2o`0001?ooooo0_l00009oooo
o`;o0000?oooool001cooooo00?o0000ooooooooool0??ooool2o`0000cooooo0ol0000Nooooo`ko
00001Oooool6o`0000Gooooo0_l00002ooooo`Go00000_ooool2o`0000Kooooo1?l00008ooooo`;o
00001?ooool2o`0000Gooooo1?l00004ooooo`;o000000?oooooo`000?l000002_ooool3o`0000Ko
oooo0ol00002ooooo`;o00000_ooool2o`0000Sooooo0_l000000ooooooo0000o`000002ooooo`;o
00000_ooool2o`0001Cooooo0_l00004ooooo`Co0000=_ooool001cooooo00?o0000ooooooooool0
>?ooool2o`00013ooooo0ol0000;ooooo`;o00004Oooool>o`0000Sooooo0ol00005ooooo`;o0000
0_ooool2o`000003ooooool0003o000000cooooo0ol00007ooooo`?o00002?ooool8o`0000Gooooo
1?l00006ooooo`Co00000oooool2o`0000;ooooo0ol00002ooooo`;o00000_ooool2o`0000_ooooo
0_l00002ooooo`;o00000_ooool3o`0000?ooooo0_l00004ooooo`;o00001?ooool2o`0000;ooooo
0_l00004ooooo`Co0000=_ooool001cooooo00?o0000ooooooooool0>?ooool2o`0001Cooooo0_l0
0008ooooo`;o000000?oooooo`000?l000003_ooool>o`0001_ooooo0_l00009ooooo`;o00001Ooo
ool5o`0000?ooooo1?l000000ooooooo0000o`000004ooooo`;o00000oooool2o`0000;ooooo0_l0
0006ooooo`;o00001Oooool2o`0000Wooooo0_l00003ooooo`;o000000?oooooo`000?l000002Ooo
ool2o`0000?ooooo0_l00003ooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`;o0000
2Oooool2o`0003Oooooo000Looooo`03o`000?oooooooooo02Wooooo0_l000000ooooooo0000o`00
000Pooooo`;o00002oooool2o`0000Gooooo1?l00005ooooo`ko00004oooool2o`0000Kooooo0_l0
0009ooooo`;o00001?ooool5o`0000Cooooo1?l0000<ooooo`Co00001Oooool2o`0000Gooooo0_l0
000<ooooo`;o00000oooool2o`000003ooooool0003o000000Kooooo0_l000000ooooooo0000o`00
000:ooooo`;o00001Oooool2o`0004Gooooo000Looooo`03o`000?oooooooooo02Wooooo0_l00000
0ooooooo0000o`00000Rooooo`;o00003Oooool2o`000003ooooool0003o000000;o00000oooool@
o`000003ooooool0003o000000Wooooo0_l00005ooooo`;o00001?ooool2o`00013ooooo1Ol00002
ooooo`;o00000oooool2o`000003ooooool0003o000000_ooooo0_l00003ooooo`Co00001?ooool3
o`0000_ooooo0_l0000?ooooo`;o00003Oooool2o`0000cooooo0_l00003ooooo`Co0000=oooool0
01cooooo00?o0000ooooooooool0<oooool2o`0001_ooooo0_l0000=ooooo`;o00002?ooool@o`00
0003ooooool0003o000000Wooooo0_l00003ooooo`;o00001_ooool2o`0000_ooooo0_l00003oooo
o`;o000000Goooooo`000?l0003o0000ooooo`02o`0000?ooooo1Ol0000>ooooo`Co00000oooool2
o`000003ooooool0003o000000cooooo0_l0000>ooooo`;o000000?oooooo`000?l000006Oooool2
o`0000?ooooo1?l0000gooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00006oooool2o`00
0003ooooool0003o000000?o00004?oooolAo`00017ooooo0_l0000Cooooo`;o000000?oooooo`00
0?l000001?ooool2o`0000Kooooo1Ol00002ooooo`;o00002_ooool2o`0000Gooooo0_l00006oooo
o`;o00005oooool2o`000003ooooool0003o000000Wooooo0_l0000Gooooo`;o0000=Oooool001co
oooo00?o0000ooooooooool0<?ooool3o`0000Cooooo0_l0000?ooooo`;o00001_ooool2o`000003
ooooool0003o000000?o00001?ooool2o`0000Oooooo0_l000000ooooooo0000o`00000>o`0000_o
oooo0_l0000Cooooo`Co00001_ooool2o`0000Sooooo0_l00005ooooo`;o00000_ooool2o`0000?o
oooo0_l0000@ooooo`;o00000_ooool2o`0000Oooooo0_l000000ooooooo0000o`00000;ooooo`;o
00001_ooool2o`0000Cooooo0_l00002ooooo`;o00002_ooool3o`0000Kooooo0_l0000eooooo`00
7?ooool00ol0003oooooooooo`0[ooooo`;o00000oooool3o`0000;ooooo1?l0000?ooooo`;o0000
4_ooool2o`0000Oooooo4ol0000;ooooo`;o00004oooool4o`00013ooooo0_l00006ooooo`;o0000
00?oooooo`000?l000000oooool4o`0000kooooo0ol00006ooooo`Ko000000?oooooo`000?l00000
1Oooool2o`0000Cooooo0_l00002ooooo`;o00000_ooool2o`0000Sooooo1?l00008ooooo`?o0000
0_ooool2o`0001;ooooo0_l0000Uooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o00001?oo
ool2o`0000;ooooo1_l00007ooooo`Co00001?ooool2o`00017ooooo0_l00008ooooo`Oo00000_oo
ool8o`0002Sooooo0_l0000Booooo`;o00002?ooool2o`0000[ooooo0_l00003ooooo`;o00001_oo
ool4o`0000[ooooo0ol00007ooooo`;o00000_ooool2o`0000[ooooo0_l0000=ooooo`;o00004_oo
ool2o`0002Gooooo000Looooo`03o`000?oooooooooo02oooooo0_l00008ooooo`;o00001Oooool6
o`0000Cooooo0ol0000?ooooo`?o00002?ooool7o`000003ooooool0003o000000Oo0000:?ooool3
o`0000Cooooo0_l00006ooooo`Co00005oooool2o`0001Wooooo0ol0000@ooooo`;o0000Coooool0
01cooooo00?o0000ooooooooool0;oooool2o`0000oooooo0_l00005ooooo`?o000000?oooooo`00
0?l000000ol0000<ooooo`;o00001?ooool2o`0000;ooooo3_l000001?oooooo0000o`000?l00007
ooooo`;o00004_ooool2o`0000cooooo0_l00004ooooo`;o00001_ooool4o`0000;ooooo0_l00002
ooooo`;o00004_ooool2o`0001Oooooo0_l0000@ooooo`;o00000oooool2o`0004[ooooo000Loooo
o`03o`000?oooooooooo03_ooooo0_l00003ooooo`;o00001?ooool4o`0000;ooooo1?l0000Boooo
o`;o00000_oooolBo`0000;ooooo1?l000000ooooooo0000o`000008ooooo`;o00002?ooool2o`00
00kooooo0_l00008ooooo`;o00001_ooool2o`0000;ooooo1?l00003ooooo`;o00001?ooool2o`00
00Gooooo0_l0000>ooooo`;o00001oooool3o`0000kooooo0_l00002ooooo`Co0000B_ooool001co
oooo0_l0000gooooo`;o00000oooool4o`000003ooooool0003o000000Cooooo0_l000000ooooooo
0000o`000007ooooo`;o00004OoooolCo`0000;ooooo1Ol00003ooooo`;o00001Oooool2o`0000co
oooo0_l00004ooooo`;o00001?ooool2o`0000Sooooo0_l00006ooooo`;o00001?ooool2o`0000?o
oooo0_l00004ooooo`;o00000oooool2o`00013ooooo0_l00002ooooo`;o00001?ooool2o`0000;o
oooo0_l00004ooooo`;o00001?ooool2o`0000;ooooo0_l0000=ooooo`;o0000?Oooool001cooooo
00?o0000ooooooooool0=_ooool2o`0000?ooooo1?l00006ooooo`Ko00001oooool2o`0000cooooo
0_l000000ooooooo0000o`00000;o`000003ooooool0003o000000Oo00000oooool2o`0000?ooooo
0_l0000Cooooo`;o00000_ooool4o`0000Gooooo0_l00007ooooo`;o000000?oooooo`000?l00000
0ol00003ooooo`;o00003Oooool2o`0000;ooooo0_l0000Dooooo`;o00002?ooool2o`0000Cooooo
0ol00006ooooo`;o00003_ooool2o`0003gooooo000Looooo`03o`000?oooooooooo03Cooooo0_l0
00000ooooooo0000o`000002ooooo`;o00002?ooool4o`0001Oooooo0_l000000ooooooo0000o`00
000Eo`0000?ooooo0_l0000Looooo`;o00000oooool2o`0000;ooooo1?l00008ooooo`Go00000ooo
ool2o`0000;ooooo0_l00009ooooo`;o0000:Oooool3o`0000;ooooo0_l000000ooooooo0000o`00
0007ooooo`?o00001?ooool2o`0001Sooooo0_l0000Sooooo`007?ooool00ol0003oooooooooo`0d
ooooo`;o000000Coooooo`000?l0003ooooo0ol00003ooooo`;o00001?ooool2o`0000;ooooo0_l0
000Aooooo`;o00001OoooolFo`0000?ooooo0_l0000Hooooo`;o00001oooool2o`0000Cooooo0_l0
000;ooooo`;o00001oooool2o`0000kooooo0_l00002ooooo`;o00008Oooool2o`000004ooooool0
003o0000o`0000Kooooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l0000Hooooo`;o0000
8oooool001cooooo00?o0000ooooooooool0>_ooool2o`0000Cooooo0_l00004ooooo`;o00000_oo
ool2o`0000_ooooo0_l00004ooooo`;o00001_oooolAo`00027ooooo0_l0000Aooooo`?o00002?oo
ool4o`0000_ooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo0_l0000Tooooo`;o00001ooo
ool2o`000004ooooool0003o0000o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o0000
>Oooool001cooooo00?o0000ooooooooool0=Oooool2o`0000Cooooo0_l0000=ooooo`?o00002_oo
ool4o`0000Oooooo0_l000000ooooooo0000o`00000@o`0000_ooooo0_l0000Cooooo`;o00001ooo
ool2o`0000Sooooo2?l00003ooooo`Oo000000?oooooo`000?l000001Oooool2o`0000;ooooo1?l0
000Xooooo`;o00002oooool4o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o0000>Ooo
ool001cooooo00?o0000ooooooooool0=Oooool2o`0000Cooooo0_l00004ooooo`Go00000oooool4
o`0000cooooo0_l00007ooooo`;o000000?oooooo`000?l000004_l00009ooooo`;o00003_ooool2
o`0000;ooooo0_l00008ooooo`;o00002?ooool8o`0000Gooooo1Ol000000ooooooo0000o`000003
ooooo`?o00001Oooool2o`0000;ooooo0_l0000Tooooo`;o00002oooool3o`0000?ooooo0_l00000
1?oooooo0000o`000?l0000looooo`007?ooool00ol0003oooooooooo`0Nooooo`;o00006Oooool2
o`0000Kooooo1Ol000000ooooooo0000o`000002o`0001;ooooo0_l00003oooooaOo00001?ooool2
o`0001;ooooo0ol00002ooooo`?o00001oooool2o`0000Kooooo1_l00002ooooo`Go00000oooool3
o`0000Oooooo0ol00006ooooo`;o000000?oooooo`000?l00000;?ooool2o`0000Cooooo0_l00003
ooooo`;o00000_ooool2o`0000;ooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0Noooo
o`;o00005oooool4o`0000cooooo0_l000000ooooooo0000o`00000Aooooo`;o00000ooooolEo`00
00Kooooo0_l0000Booooo`;o00001?ooool2o`0000Oooooo0_l00006ooooo`?o00001?ooool2o`00
0003ooooool0003o000000Wo000000?oooooo`000?l000000_l00009ooooo`;o00002Oooool2o`00
02Cooooo0_l00002ooooo`;o00003Oooool2o`0003Sooooo000Looooo`03o`000?oooooooooo03Oo
oooo0_l0000Aooooo`;o00006?oooolBo`0000?ooooo0_l0000Dooooo`;o00001oooool3o`0000go
oooo0ol00004ooooo`;o000000?oooooo`000?l000001Ol000001Ooooooo0000o`000?l0003ooooo
00Oo00002Oooool2o`000003ooooool0003o000000?ooooo0_l0000Xooooo`;o00001oooool2o`00
00Kooooo0_l0000fooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00007_oooolBo`000003
ooooool0003o000000;ooooo0_l00006ooooo`;o00001oooool2o`0000?ooooo0_l00004ooooo`;o
000000Coooooo`000?l0003o00003Oooool8o`0000;ooooo1_l000001?oooooo0000o`000?l00002
ooooo`Wo00001oooool2o`000003ooooool0003o000002Wooooo1_l00007ooooo`;o00001_ooool2
o`0003Kooooo000Looooo`03o`000?oooooooooo03Oooooo0_l00006ooooo`;o000000Coooooo`00
0?l0003o00004Oooool4o`0000Sooooo4Ol000001?oooooo0000o`000?l00002ooooo`?o00000_oo
ool2o`000003ooooool0003o000000Oooooo0_l00009ooooo`;o00000_ooool4o`0000Kooooo0_l0
0002ooooo`;o000000?oooooo`000?l000001?l00003ooooo`Go000000Coooooo`000?l0003o0000
0oooool3o`000003ooooool0003o000000?o0000;_ooool4o`0000;ooooo1_l00007ooooo`;o0000
0_ooool2o`0003[ooooo000Looooo`03o`000?oooooooooo03Gooooo1ol00003ooooo`;o000000Co
ooooo`000?l0003o00004Oooool4o`0000?ooooo0_l00003oooooaGo00000oooool2o`0000;ooooo
0_l00006ooooo`;o00001Oooool2o`0000;ooooo0_l00005ooooo`Go00001_oooolJo`0000?ooooo
2?l0000Zooooo`;o00000_ooool4o`0001?ooooo0_l0000jooooo`007?ooool00ol0003ooooooooo
o`0_ooooo`;o00001?ooool7o`0000Kooooo0_l00004ooooo`;o00003Oooool3o`0000?ooooo0_l0
0003oooooaGo00001oooool2o`0000Kooooo0_l00005ooooo`;o00000_ooool2o`0000Gooooo0_l0
0005ooooo`Wo000000?oooooo`000?l000004_l000000ooooooo0000o`000006o`0002cooooo0_l0
000Gooooo`;o00006?ooool2o`0002;ooooo000Looooo`03o`000?oooooooooo02oooooo0_l00006
ooooo`;o00003oooool2o`0000kooooo0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o
000000oo00009oooool2o`000003ooooool0003o000000_o00000_oooolHo`000003ooooool0003o
000000Cooooo0_l00004ooooo`;o0000=_ooool2o`0001Sooooo0_l0000Rooooo`007?ooool00ol0
003oooooooooo`0Qooooo`;o00007?ooool2o`0000Oooooo0_l0000Cooooo`;o00000_oooolEo`00
01Sooooo0_l0000<ooooo`;o000000?oooooo`000?l000000_oooolWo`0000?ooooo0_l00004oooo
o`;o00007Oooool2o`000003ooooool0003o000000oooooo0_l00005ooooo`;o0000>_ooool001co
oooo0_l0000Rooooo`;o00007?ooool2o`0000Oooooo0_l0000@ooooo`;o00001ooooolCo`000003
ooooool0003o000000oooooo0_l00004ooooo`;o00003?ooool2o`0000Cooooo3Ol000000ooooooo
0000o`00000Ho`0000;ooooo0ol0000:ooooo`;o00005_ooool3o`000003ooooool0003o000000;o
oooo0_l00004ooooo`;o00001Oooool2o`0000Gooooo0_l0000Gooooo`;o00008Oooool001cooooo
00?o0000ooooooooool0;Oooool2o`0000;ooooo0_l00004ooooo`;o00001oooool2o`0001Cooooo
0_l000001?oooooo0000o`000?l00007ooooo`So000000?oooooo`000?l000002?l000000ooooooo
0000o`00000?ooooo`;o00004_ooool2o`0000;ooooo1?l000000ooooooo0000o`000004o`0000;o
oooo2Ol000000ooooooo0000o`00000;o`0000;ooooo0ol00003ooooo`Ko00001oooool3o`0001Go
oooo0_l00006ooooo`;o00001?ooool2o`0000Gooooo0_l0000Nooooo`;o00008Oooool001cooooo
00?o0000ooooooooool0;Oooool2o`0000;ooooo0_l00004ooooo`;o00001oooool2o`0001?ooooo
0ol000000ooooooo0000o`000008oooooa3o00006oooool2o`0000oooooo1_l000001?oooooo0000
o`000?oooolPo`0000Gooooo1?l00006ooooo`Co00004_ooool2o`0000kooooo0_l00019ooooo`00
7?ooool00ol0003oooooooooo`14ooooo`;o00000_ooool2o`0000Gooooo0_l00003ooooo`?o0000
00?oooooo`000?l000000oooool2o`0000Kooooo1Ol000000ooooooo0000o`000005o`0001cooooo
0_l00005ooooo`?o00001oooool6o`000003ooooool0003o000002;o00000_ooool2o`0000[ooooo
0_l0000Dooooo`;o00001oooool2o`0000Gooooo0_l00005ooooo`;o0000@_ooool001cooooo00?o
0000ooooooooool0;Oooool2o`0001;ooooo0_l000000ooooooo0000o`000004o`0000Gooooo0_l0
0003ooooo`;o00000_ooool2o`0000?ooooo0ol00005ooooo`go00003Oooool2o`0000Wooooo0_l0
00000ooooooo0000o`000006ooooo`?o00000_ooool2o`0000Gooooo0_l00003ooooob3o00000_oo
ool2o`0000;ooooo1ol0000Sooooo`?o00003?ooool2o`0000Oooooo0_l0000iooooo`007?ooool0
0ol0003oooooooooo`0]ooooo`Go00003oooool2o`000003ooooool0003o000000Co00000oooool2
o`0000oooooo0_l00006ooooo`;o000000?oooooo`000?l000001Ol00005ooooo`;o00002?ooool2
o`0000Wooooo0_l000000ooooooo0000o`00000;ooooo`;o00000_ooool2o`000004ooooool0003o
0000o`0000;ooooo8Ol00003ooooo`;o00000_ooool7o`00027ooooo0_l0000?ooooo`;o00001Ooo
ool2o`0003Wooooo000Looooo`03o`000?oooooooooo02_ooooo0_l00002ooooo`?o00006oooool2
o`0001Oooooo0_l000000ooooooo0000o`000005o`000003ooooool0003o000000;ooooo0_l00008
ooooo`;o00002_ooool4o`0000oooooo0_l000000ooooooo0000o`000002o`0000;ooooo8?l00003
ooooo`;o00000_ooool3o`0000;ooooo0_l0000Sooooo`;o00000oooool2o`0000Kooooo1?l00010
ooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o0000:?ooool3o`0000Kooooo0_l00003oooo
o`;o000000Goooooo`000?l0003o0000ooooo`09o`0000cooooo0_l0000:ooooo`;o00001Oooool2
o`0000Wooooo0_l00002ooooobOo00000_ooool2o`000003ooooool0003o000000;o000000?ooooo
o`000?l000002?ooool2o`0001[ooooo0_l00003ooooo`;o00001_ooool2o`0004;ooooo000Loooo
o`03o`000?oooooooooo05Gooooo0ol00006ooooo`;o00000oooool2o`0000;ooooo0ol000000ooo
oooo0000o`000005o`0000_ooooo0_l0000@ooooo`;o000000?oooooo`000?l000002?ooool3o`00
00Cooooo2Ol000000ooooooo0000o`00000Fo`000003ooooool0003o000000;ooooo1Ol00003oooo
o`;o00001oooool3o`0001;ooooo1?l0000Aooooo`;o00000oooool2o`0003gooooo000Looooo`03
o`000?oooooooooo03Sooooo0_l0000Aooooo`;o00003Oooool2o`0000cooooo0_l000000ooooooo
0000o`000004o`0000Sooooo0_l00002ooooo`;o00004?ooool2o`0000_ooooo0ol000000ooooooo
0000o`000002o`000003ooooool0003o0000027o00000oooool4o`0000cooooo0_l0000Cooooo`Co
00003Oooool2o`0000Oooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0hooooo`;o0000
1_ooool4o`000003ooooool0003o000000Cooooo0_l0000<ooooo`?o00003?ooool2o`000003oooo
ool0003o000000Co00002?ooool2o`0000;ooooo0_l00002ooooo`;o00006_ooool7o`000005oooo
ool0003o0000o`000?ooool03_l000000ooooooo0000o`00000@o`0000;ooooo0ol00004ooooo`;o
0000;?ooool2o`0000?ooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`10ooooo`Co0000
00?oooooo`000?l000003oooool2o`000003ooooool0003o0000013ooooo1Ol00008ooooo`;o0000
1oooool2o`0001[ooooo;ol00007ooooo`?o00005_ooool2o`0000;ooooo0_l0000;ooooo`;o0000
1oooool2o`00047ooooo000Looooo`03o`000?oooooooooo05Cooooo1?l00007ooooo`;o00003?oo
ool3o`0000Oooooo0ol0000:ooooo`Co000000?oooooo`000?l000001oooool2o`0000[ooooo0_l0
00000ooooooo0000o`00000Go`000003ooooool0003o0000013o00001oooool2o`0001Kooooo0_l0
0002ooooo`;o00002oooool2o`0000Oooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`1:
ooooo`;o00002?ooool4o`0000Oooooo0_l0000Fooooo`;o00002oooool4o`000003ooooool0003o
000000Oooooo0_l00009ooooo`;o00001_oooolEo`0000;ooooo4_l00003ooooo`;o00007?ooool2
o`0000Cooooo0_l0001Booooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?oo
ool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0=?ooool2o`0001Cooooo
0ol0000Eooooo`;o00003oooool2o`0000?ooooo0_l00008ooooo`;o000000Coooooo`000?l0003o
oooo0ol0000Booooo`;o000000?oooooo`000?l000001?oooolDo`000003ooooool0003o000000go
00000_ooool2o`0000?ooooo0_l0000Looooo`?o00000oooool2o`0000Kooooo0_l0001:ooooo`00
00KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So
8B4Q00Kooooo00?o0000ooooooooool0=?ooool2o`0001;ooooo0_l000000ooooooo0000o`000004
ooooo`;o00003oooool4o`0000Cooooo0_l00005ooooo`Co00000oooool2o`0000Sooooo1?l00002
ooooo`;o00001oooool2o`0000[ooooo0_l000000ooooooo0000o`00000Xo`0000[ooooo0_l0000J
ooooo`;o00002Oooool4o`0000Wooooo0_l0000oooooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0d
ooooo`;o00004_ooool2o`000003ooooool0003o000000Cooooo0_l0000Aooooo`;o00001?ooool2
o`0000Gooooo1?l00003ooooo`;o00002_ooool6o`0000Oooooo0_l00006ooooo`;o00001ooooolU
o`000003ooooool0003o000000Gooooo1?l000000ooooooo0000o`000002o`0000Gooooo0_l0000=
ooooo`?o00001?ooool3o`0000Gooooo0ol00004ooooo`;o000000Coooooo`000?l0003ooooo0_l0
000oooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9So
oooooiRHV?lQ8B401_ooool3o`00043ooooo1?l0000=ooooo`;o00009Oooool2o`000003ooooool0
003o000000Wooooo1?l00007ooooo`;o00001_ooool2o`0000Sooooo2?l000000ooooooo0000o`00
000Go`000003ooooool0003o000000;o00001Oooool9o`0000Gooooo1?l0000;ooooo`?o00001?oo
ool3o`0000cooooo0_l000001?oooooo0000o`000?ooool2o`0003oooooo00000ooooooo0000oooo
o`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`00
0?oooooooooo02Cooooo0_l0000=ooooo`;o00002oooool4o`0001[ooooo0_l00007ooooo`;o0000
3Oooool2o`000003ooooool0003o000000;o00002oooool2o`0000Oooooo0_l00005ooooo`;o0000
0oooool4o`0000Gooooo7ol000000ooooooo0000o`000004ooooo`;o00001?ooool2o`0000Cooooo
0_l00005ooooo`;o00004?ooool3o`0000kooooo0_l00003ooooo`;o0000@?ooool00003ooooool@
413ooooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo02Cooooo0_l00009ooooo`;o00000_ooool2o`000004ooooool0003o0000o`0000Sooooo
0_l0000>ooooo`;o000000?oooooo`000?l000002?ooool2o`0000Oooooo0_l0000=ooooo`;o0000
00?oooooo`000?l000002Oooool2o`0000;ooooo0_l0000>ooooo`;o00000oooool4o`0000?ooooo
8Ol000000ooooooo0000o`000002ooooo`Co00002_ooool2o`0000Gooooo1?l0000>ooooo`?o0000
2oooool7o`000003ooooool0003o000001Oooooo0_l0000Wooooo`0000KoooooogMgMonHV9Sooooo
oiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0;oooool2o`0000Go
oooo0ol0000Hooooo`;o000000?oooooo`000?l000005Oooool2o`0001Oooooo0_l0000NooooobCo
00000_ooool4o`0000;ooooo0_l0000?ooooo`;o00007?ooool7o`0001[ooooo0_l0000Wooooo`00
00Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000
ooooooooool0I?ooool2o`0000Gooooo0_l0000:ooooo`?o00000oooool2o`0000Gooooo0_l00003
ooooo`;o00002?ooool2o`0000[ooooo0ol00003ooooo`Ko000000?oooooo`000?l000006_l00004
ooooo`;o00000_ooool2o`0002Sooooo1?l00004ooooo`;o0000AOooool001cooooo00?o0000oooo
ooooool0=_ooool3o`0002_ooooo0_l0000Aooooo`?o00000oooool2o`0000Oooooo0_l000001?oo
oooo0000o`000?ooool2o`0000Gooooo0_l0000:ooooo`?o00000_ooool2o`0000;ooooo8?l0000X
ooooo`;o00002?ooool4o`0004_ooooo000Looooo`03o`000?oooooooooo03Kooooo0ol00011oooo
o`;o000000?oooooo`000?l000001oooool3o`0000?ooooo0_l0000:ooooo`;o00001oooool2o`00
0003ooooool0003o000002?o000000?oooooo`000?l000000_l0000:ooooo`;o00001_ooool2o`00
00kooooo1?l0001Eooooo`007?ooool00ol0003oooooooooo`1Booooo`;o00002oooool2o`0000Go
oooo0_l00009ooooo`;o00001oooool4o`0000Cooooo0_l00003ooooo`;o00003_ooool3o`0000Co
oooo0_l000000ooooooo0000o`000003ooooo`Co000000Coooooo`000?l0003ooooo5_l00003oooo
o`;o000000?oooooo`000?l000000ol00009ooooo`;o00000oooool2o`000003ooooool0003o0000
00;o00003_ooool2o`0005Gooooo000Looooo`03o`000?oooooooooo03Cooooo0_l0000Looooo`;o
00002oooool2o`0000Gooooo0_l00009ooooo`;o00002Oooool2o`000004ooooool0003o0000oooo
o`;o00000_ooool2o`0000Gooooo0_l00008ooooo`;o00001Oooool2o`0000;ooooo0_l00003oooo
o`?o000000Goooooo`000?l0003o0000ooooo`0Go`000003ooooool0003o000000;ooooo1?l00009
ooooo`Co000000?oooooo`000?l000000_l000000ooooooo0000o`000007ooooo`;o00001oooool2
o`0000Oooooo0_l00005ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0=?ooool2o`00
01gooooo0_l00004ooooo`;o00009?ooool2o`0000Cooooo0ol00005ooooo`;o00001_ooool2o`00
00Kooooo1?l000000ooooooo0000o`000003ooooo`Oo000000?oooooo`000?l000003ol000000ooo
oooo0000o`000006o`0000;ooooo0_l00002ooooo`;o00002Oooool2o`0000?ooooo0_l000000ooo
oooo0000o`000007ooooo`;o00001oooool2o`0000?ooooo0_l00002ooooo`;o00001Oooool2o`00
04?ooooo000Looooo`03o`000?oooooooooo03Cooooo0_l00004ooooo`;o00005oooool2o`0000Co
oooo0_l0000@ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Booooo`?o00002?ooool2o`00
00?ooooo0_l00006ooooo`Co000000?oooooo`000?l000000oooool2o`000003ooooool0003o0000
01Co00000_ooool7o`0000;ooooo0_l00002ooooo`;o00009Oooool2o`000003ooooool0003o0000
00Gooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`0dooooo`;o00001?ooool2o`0000oo
oooo0_l0000Dooooo`;o00002?ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`00
0?l000000_l00002ooooo`;o00002_ooool2o`0000Oooooo0ol0000<ooooo`;o00000_oooolNo`00
00?ooooo2?l00003ooooo`;o00001Oooool2o`0000Cooooo0_l00004ooooo`;o00004oooool2o`00
00Sooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o00005?ooool2o`0000So
oooo0_l000000ooooooo0000o`000008o`0000;ooooo0_l0000;ooooo`;o00001_ooool2o`0000oo
oooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000;o00000oooool=o`000004
ooooool0003o0000ooooo`Co00000oooool3o`000003ooooool0003o000000;o00001Oooool2o`00
0003ooooool0003o000000?o00001?ooool2o`0000[ooooo0_l00002ooooo`;o00001_ooool2o`00
0003ooooool0003o000000;ooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`0aooooo`;o
0000=?ooool3o`000004ooooool0003o0000ooooo`Ko00003oooool3o`000003ooooool0003o0000
01Oooooo0_l00007ooooo`Co00000oooool2o`000003ooooool0003o000000oo00001Oooool2o`00
0003ooooool0003o000000;o00001?ooool2o`0000;ooooo1?l00009ooooo`;o00001_ooool2o`00
0004ooooool0003o0000o`0000Kooooo1Ol00002ooooo`;o0000Aoooool001cooooo00?o0000oooo
ooooool0<Oooool2o`0001Cooooo0_l0000<ooooo`;o00004?ooool3o`000003ooooool0003o0000
00So00000oooool2o`000003ooooool0003o000000Kooooo1?l0000Sooooo`?o00001_oooolAo`00
00Cooooo1Ol000000ooooooo0000o`000004ooooo`;o000000Coooooo`000?l0003o00002?ooool2
o`000003ooooool0003o000000Wooooo0_l000000ooooooo0000o`000003ooooo`Go00001?ooool2
o`0001Kooooo0_l0000^ooooo`007?ooool00ol0003oooooooooo`17ooooo`;o00003?ooool4o`00
01;ooooo3ol000001?oooooo0000o`000?l00007ooooo`;o00006_ooool2o`0000Cooooo1_l00007
ooooo`Ko00000oooool4o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000003
ooooo`;o00001Oooool4o`0000Oooooo0_l0000?ooooo`;o00000oooool2o`0000Kooooo0ol0000F
ooooo`;o0000;_ooool001cooooo0_l0000cooooo`;o00008oooool2o`0000_ooooo0_l00005oooo
o`ko000000?oooooo`000?l000001?l0000<ooooo`;o00004oooool2o`0000?ooooo1?l000000ooo
oooo0000o`000002o`0000;ooooo0_l000000ooooooo0000o`000004o`000003ooooool0003o0000
00So00002oooool4o`000003ooooool0003o000000;ooooo0_l0000@ooooo`;o00001oooool2o`00
00Sooooo1?l0000<ooooo`;o0000>Oooool001cooooo00?o0000ooooooooool0<_ooool2o`0001go
oooo0_l00004ooooo`;o00002ooooolDo`0000;ooooo0_l00002ooooo`;o00001?ooool2o`0000Ko
oooo0_l000000ooooooo0000o`00000;ooooo`;o00000oooool2o`0000?ooooo0_l00004ooooo`?o
00000_ooool3o`000003ooooool0003o000000?o000000?oooooo`000?l000002?l000000ooooooo
0000o`000002o`0000Kooooo1ol00002ooooo`;o00004?ooool2o`0000Oooooo0_l00008ooooo`;o
00003_ooool2o`0003Wooooo000Looooo`03o`000?oooooooooo03;ooooo0_l0000Mooooo`;o0000
4_oooolDo`0000Cooooo0_l00005ooooo`?o00002?ooool2o`0000_ooooo1?l0000=ooooo`Co0000
00?oooooo`000?l000001Oooool2o`000003ooooool0003o000000co00002_ooool5o`0002Gooooo
0_l00019ooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o00003_ooool2o`0000;ooooo0_l0
0002oooooa;o00000_ooool2o`0000Gooooo1?l0000Fooooo`;o00003Oooool8o`0000Cooooo0_l0
00001Ooooooo0000o`000?l0003ooooo00Ko000000?oooooo`000?l000001?ooool2o`0000Cooooo
0_l00002ooooo`;o00003oooool2o`0000Cooooo0_l0000>ooooo`;o0000BOooool001cooooo00?o
0000ooooooooool0=_ooool2o`0002Wooooo0_l00002oooooaKo00002Oooool4o`0000;ooooo0_l0
0003ooooo`;o00002?ooool2o`0001;ooooo0_l000001?oooooo0000o`000?ooool2o`000004oooo
ool0003o0000ooooo`?o00001?ooool6o`000003ooooool0003o000000;o00000_ooool3o`0000?o
oooo0_l0000Cooooo`;o00001?ooool2o`0000Wooooo0_l000000ooooooo0000o`00001;ooooo`00
7?ooool00ol0003oooooooooo`0/ooooo`;o00002?ooool2o`0001Oooooo0_l0000Eooooo`Oo0000
0_ooool>o`000003ooooool0003o000000Cooooo0_l00004ooooo`;o00000oooool2o`0000Oooooo
1Ol0000;ooooo`Co000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000Go0000
1?ooool2o`000003ooooool0003o000000?ooooo0_l00003ooooo`;o00005?ooool2o`0001?ooooo
0_l000000ooooooo0000o`00001;ooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00008Ooo
ool2o`0001Gooooo4ol00002ooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0
003o000000Kooooo0_l00009ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Cooooo1?l0
0007ooooo`;o00000_ooool2o`0000;ooooo0_l0000<ooooo`;o00006Oooool2o`0006?ooooo000L
ooooo`03o`000?oooooooooo03[ooooo0_l0000Gooooo`;o00004?ooool2o`000003ooooool0003o
0000013o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`000006ooooo`;o00001_ooool2
o`0000_ooooo0_l00004ooooo`;o00000_ooool2o`0000?ooooo0_l00006ooooo`;o00000oooool2
o`0000Wooooo0_l0000>ooooo`;o0000K_ooool001cooooo00?o0000ooooooooool0>_ooool2o`00
01Cooooo0_l000000ooooooo0000o`00000@oooooaGo00000_ooool4o`0000;ooooo0ol00004oooo
o`;o00000_ooool2o`0000Kooooo0_l00004ooooo`;o00002Oooool4o`0000;ooooo0_l00003oooo
o`Co00001?ooool2o`0000?ooooo0_l00005ooooo`;o00001_ooool2o`0000Kooooo0_l00002oooo
o`Co00003_ooool2o`0000cooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o
00004ooooolFo`0000?ooooo0_l00003ooooo`?o00000oooool2o`0000Sooooo0_l00006ooooo`;o
00001?ooool2o`000003ooooool0003o000000;o00000_ooool4o`0000Gooooo0_l0000@ooooo`Co
00001?ooool2o`0000Kooooo0_l00002ooooo`Co00003_ooool2o`0000cooooo1?l0001<ooooo`00
7?ooool00ol0003oooooooooo`1VoooooaGo00000oooool2o`0000Cooooo0_l00007ooooo`;o0000
0oooool3o`0000cooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000Oo
oooo0_l00008ooooo`?o00001oooool2o`0000?ooooo0_l00008ooooo`;o000000?oooooo`000?l0
00003oooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o000000Coooooo`000?l0
003o0000C?ooool001cooooo00?o0000ooooooooool0BOooool2o`0001[ooooo5_l00002ooooo`;o
00000_ooool5o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000gooooo0_l000001?oooooo
0000o`000?ooool2o`0000[ooooo0ol00004ooooo`;o000000Coooooo`000?l0003o00000_ooool4
o`0000Kooooo0_l00008ooooo`;o00004_ooool5o`0000;ooooo0_l00004ooooo`;o000000?ooooo
o`000?l00000COooool001cooooo00?o0000ooooooooool0A?ooool2o`000003ooooool0003o0000
00;o00006_oooolEo`0000?ooooo0_l00002ooooo`Co00001?ooool4o`0000_ooooo1?l00008oooo
o`;o00000_ooool2o`000003ooooool0003o000000Oooooo1Ol000001?oooooo0000o`000?ooool2
o`0000?ooooo1?l000001?oooooo0000o`000?l0000<ooooo`;o00000oooool2o`0000Gooooo0_l0
0008ooooo`;o00004?ooool2o`0004Wooooo000Looooo`03o`000?oooooooooo04Cooooo0_l00000
0ooooooo0000o`00000Jooooo`Go000000?oooooo`000?l000003?l000000ooooooo0000o`000003
ooooo`;o00000_ooool2o`0000?ooooo0_l00003ooooo`;o00002?ooool7o`0000Sooooo0_l00002
ooooo`;o000000?oooooo`000?l000002Oooool3o`0000?ooooo0_l00004ooooo`So00003?ooool2
o`0000?ooooo0_l00005ooooo`;o00001?ooool2o`0000gooooo0_l00005ooooo`;o0000BOooool0
01cooooo00?o0000ooooooooool0?oooool2o`0002;ooooo5Ol00009ooooo`;o00000oooool2o`00
00?ooooo0_l00004ooooo`;o00000_ooool5o`0000[ooooo0_l0000;ooooo`Co000000?oooooo`00
0?l000001?ooool2o`0000Cooooo1_l00004ooooo`;o00000_ooool4o`000004ooooool0003o0000
ooooo`;o00002Oooool2o`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l000001?ooool2
o`00053ooooo000Looooo`03o`000?oooooooooo03oooooo0_l000000ooooooo0000o`00000Joooo
o`;o000000?oooooo`000?l000000ooooolBo`0000Kooooo0_l000000ooooooo0000o`00000>oooo
o`;o00000_ooool3o`0000gooooo0_l00003ooooo`;o00001Oooool4o`0000gooooo0_l00002oooo
o`?o00000oooool2o`0000;ooooo1?l000001?oooooo0000o`000?ooool2o`0000Wooooo0_l00009
ooooo`;o000000Coooooo`000?l0003ooooo0_l0001Cooooo`007?ooool2o`0004?ooooo0_l0000J
ooooo`;o000000?oooooo`000?l000000ooooolDo`0000Cooooo1Ol0000:ooooo`;o00005_ooool2
o`0000?ooooo0ol00005ooooo`Co00002Oooool3o`0000Gooooo0_l0000Dooooo`;o00000_ooool2
o`0000Sooooo0_l000001?oooooo0000o`000?ooool5o`0005?ooooo000Looooo`03o`000?oooooo
oooo05oooooo0_l00006oooooa?o00001_ooool3o`0000[ooooo0_l0000Looooo`;o00001Oooool4
o`0000Cooooo0_l00003ooooo`Ko00001Oooool2o`00017ooooo0_l00002ooooo`;o00000_ooool2
o`0000Cooooo0_l00005ooooo`Go0000D_ooool001cooooo00?o0000ooooooooool0Goooool2o`00
00Oooooo3ol0000:ooooo`Co0000:_ooool3o`0000Sooooo0_l00005ooooo`Co00001Oooool2o`00
00kooooo0_l00009ooooo`;o00001oooool2o`0000;ooooo1Ol0001Booooo`007?ooool00ol0003o
ooooooooo`1Zooooo`oo00002_ooool2o`0000[ooooo0_l0000Iooooo`;o00000oooool3o`0000Co
oooo0_l00009ooooo`?o00002Oooool2o`0000_ooooo0_l00009ooooo`;o00000_ooool2o`0000?o
oooo0ol00003ooooo`Co0000DOooool001cooooo00?o0000ooooooooool0KOooool4o`0000Cooooo
1?l00002ooooo`;o00004_ooool2o`0001;ooooo0_l00005ooooo`;o00000oooool2o`0000Gooooo
0_l0000Eooooo`;o00006_ooool2o`0000Cooooo0_l00003ooooo`Co0000DOooool001cooooo00?o
0000ooooooooool0MOooool8o`0001Cooooo0_l00002ooooo`;o00003?ooool2o`0000?ooooo0_l0
0006ooooo`;o00002oooool2o`0000?ooooo0_l00009ooooo`;o00007?ooool2o`0000;ooooo1?l0
001Fooooo`007?ooool00ol0003oooooooooo`1Booooo`;o00007?ooool2o`0000Gooooo1?l00006
ooooo`?o00000oooool2o`0000?ooooo0_l00003ooooo`Ko00004Oooool2o`0000Kooooo0_l0000;
ooooo`;o00000oooool2o`000003ooooool0003o000000Cooooo1?l00005ooooo`;o00001Oooool2
o`0000kooooo0_l00002ooooo`Co00004oooool2o`00047ooooo000Looooo`03o`000?oooooooooo
05;ooooo0_l0000Looooo`;o00003oooool3o`0000?ooooo0_l00003ooooo`;o00001Oooool2o`00
01;ooooo0ol00008ooooo`;o00002Oooool2o`0000?ooooo0_l000000ooooooo0000o`000004oooo
o`;o00001oooool2o`0000Gooooo0_l0000Dooooo`;o00004oooool2o`00047ooooo000Looooo`03
o`000?oooooooooo06Wooooo0_l0000;ooooo`;o00000_ooool2o`0000;ooooo0_l00004ooooo`;o
00001?ooool2o`000003ooooool0003o000000Wooooo0_l0000=ooooo`Co00001oooool2o`0000So
oooo0_l00004ooooo`;o00003Oooool2o`0000cooooo0ol00009ooooo`;o00001?ooool2o`0005Ko
oooo000Looooo`03o`000?oooooooooo06Wooooo0_l0000;ooooo`;o00000_ooool2o`0000;ooooo
0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000004ooooo`?o
000000Coooooo`000?l0003o00000_ooool2o`0000Kooooo0_l00003ooooo`;o00003Oooool2o`00
00;ooooo0_l00004ooooo`?o000000?oooooo`000?l000002Oooool2o`0000cooooo1?l00005oooo
o`Oo00000_ooool2o`0005Kooooo000Looooo`03o`000?oooooooooo07gooooo1?l00006ooooo`;o
00002_ooool3o`000003ooooool0003o000000?ooooo0_l00006ooooo`;o00002_ooool3o`0000Go
oooo1?l00007ooooo`;o000000?oooooo`000?l000006?ooool3o`0000Gooooo1?l000000ooooooo
0000o`00001Jooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o00006_ooool2o`0000Oooooo
2?l0000Eooooo`?o00001?ooool4o`0000oooooo0ol00007ooooo`;o00002oooool2o`0000Sooooo
0_l00002ooooo`;o00003Oooool2o`000003ooooool0003o0000063ooooo000Looooo`03o`000?oo
oooooooo05Cooooo0_l0000<ooooo`;o00001?ooool2o`0000Kooooo0_l00007ooooo`Co00001?oo
ool2o`0000Oooooo0_l00009ooooo`?o00001Oooool4o`0000?ooooo0_l00003ooooo`;o00001?oo
ool2o`0000Sooooo1?l00004ooooo`;o00000_ooool4o`0000Sooooo1_l0000=ooooo`;o000000?o
ooooo`000?l000000_l00008ooooo`;o0000E?ooool001cooooo00?o0000ooooooooool0H?ooool4
o`0000Cooooo0_l0000Aooooo`;o00000_ooool4o`0000?ooooo0ol000000ooooooo0000o`000002
ooooo`;o00001Oooool2o`0000Oooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0ol0
0003ooooo`;o00002?ooool4o`0000Cooooo0_l00002ooooo`;o00000_ooool2o`0000Sooooo0_l0
000Booooo`Co00002?ooool2o`0005Cooooo000Looooo`03o`000?oooooooooo063ooooo0_l0000;
ooooo`;o00003?ooool2o`0000;ooooo0_l00005ooooo`?o00001Oooool2o`0000oooooo1?l00007
ooooo`Co00002?ooool2o`0000?ooooo1?l00009ooooo`?o00001_ooool2o`0000Gooooo0_l0001_
ooooo`007?ooool00ol0003oooooooooo`1Fooooo`;o00002Oooool2o`0000Gooooo0_l00003oooo
o`;o00003Oooool2o`0000Sooooo0_l00003ooooo`;o00004_ooool2o`0000?ooooo0_l00006oooo
o`;o000000?oooooo`000?l000001Oooool3o`0000Cooooo0ol00008ooooo`;o00001oooool2o`00
00Gooooo0_l000000ooooooo0000o`000007ooooo`;o0000Hoooool001cooooo0_l0001Gooooo`;o
00002Oooool3o`0000Cooooo0_l00003ooooo`;o00003Oooool4o`0000;ooooo0_l00007ooooo`;o
00004oooool2o`0000;ooooo0_l00003ooooo`;o00000oooool3o`0000;ooooo0_l000001?oooooo
0000o`000?l00005ooooo`;o00001_ooool4o`0000?ooooo0_l0000<ooooo`;o00001_ooool3o`00
06?ooooo000Looooo`03o`000?oooooooooo06;ooooo1?l00004ooooo`?o00003oooool4o`000004
ooooool0003o0000o`0000Kooooo0_l00005ooooo`Co00000oooool2o`000004ooooool0003o0000
o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0000?ooooo0_l00003ooooo`;o00004Oooool2
o`0000;ooooo0_l000000ooooooo0000o`000006ooooo`;o00001oooool2o`0000?ooooo0ol0001S
ooooo`007?ooool00ol0003oooooooooo`1Oooooo`;o00000oooool2o`0000Cooooo0ol00006oooo
o`;o00002oooool3o`0000Kooooo0ol00005ooooo`Ko000000?oooooo`000?l000001_l00004oooo
o`;o00005?ooool2o`0000kooooo0_l00006ooooo`;o000000?oooooo`000?l000001Oooool4o`00
0003ooooool0003o000000;o00002oooool2o`0005Oooooo000Looooo`03o`000?oooooooooo05_o
oooo0_l00002ooooo`;o00002oooool2o`0000Gooooo0ol00005ooooo`;o00000oooool2o`0000Oo
oooo0_l0000:ooooo`;o00000_ooool7o`0000?ooooo1Ol00003ooooo`;o00003Oooool2o`0001Ko
oooo0_l00008ooooo`;o00000oooool2o`0000gooooo0_l0001Gooooo`007?ooool00ol0003ooooo
ooooo`1Kooooo`;o00002Oooool2o`0000Cooooo0_l00004ooooo`Co00001Oooool2o`0000?ooooo
0_l0000Iooooo`;o000000?oooooo`000?l000000oooool6o`0000;ooooo0_l00005ooooo`Go0000
00?oooooo`000?l000007?ooool2o`0000Cooooo0_l0001[ooooo`007?ooool00ol0003ooooooooo
o`1Vooooo`;o00002_ooool2o`0000cooooo0_l0000?ooooo`;o00002oooool2o`0000?ooooo1ol0
0002ooooo`Co00000_ooool8o`0000Gooooo0_l00006ooooo`;o00000_ooool2o`000003ooooool0
003o000000Kooooo0_l0001aooooo`007?ooool00ol0003oooooooooo`1Vooooo`;o00005_ooool4
o`0000Wooooo0_l00003ooooo`?o00001?ooool2o`0000oooooo0_l000000ooooooo0000o`000003
o`0000Kooooo1?l00005ooooo`;o00001_ooool2o`0000;ooooo0_l000000ooooooo0000o`000005
ooooo`;o00001?ooool2o`000003ooooool0003o000001Kooooo0_l0001Aooooo`007?ooool00ol0
003oooooooooo`1Nooooo`;o00003Oooool2o`0000oooooo0_l00008ooooo`;o000000?oooooo`00
0?l000000oooool5o`000004ooooool0003o0000o`0001;ooooo1?l0000:ooooo`Co00002Oooool2
o`0000cooooo0ol00003ooooo`?o000000?oooooo`000?l000000_l0000Dooooo`;o0000DOooool0
01cooooo00?o0000ooooooooool0G_ooool2o`0000Wooooo0_l00002ooooo`;o00004?ooool2o`00
00;ooooo0_l00003ooooo`;o00002?ooool3o`000004ooooool0003o0000o`0000kooooo0_l00004
ooooo`;o00002Oooool6o`0000Sooooo0ol00003ooooo`Ko00000_ooool2o`0000Cooooo0_l00004
ooooo`;o0000Ioooool001cooooo00?o0000ooooooooool0JOooool2o`000003ooooool0003o0000
00;o00003?ooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o00001oooool2o`00
00Kooooo0_l00009ooooo`Co00000_ooool2o`0000[ooooo1ol00005ooooo`;o00000_ooool3o`00
00;ooooo1_l0001gooooo`007?ooool00ol0003oooooooooo`1/ooooo`Co00003?ooool2o`0000?o
oooo0_l00006ooooo`;o00001oooool5o`0000?ooooo0_l00009ooooo`;o00001?ooool2o`0000[o
oooo0ol000000ooooooo0000o`000002o`0000Cooooo0_l000000ooooooo0000o`000002o`0007oo
oooo000Looooo`03o`000?oooooooooo07Kooooo0_l00008ooooo`?o00002Oooool2o`000003oooo
ool0003o000000?ooooo0ol00005ooooo`Co00000oooool2o`0000;ooooo0_l0000?ooooo`;o0000
0oooool4o`0000?ooooo1_l0000Aooooo`;o0000K?ooool001cooooo00?o0000ooooooooool0H?oo
ool2o`0001Cooooo0_l00008ooooo`Co00000oooool2o`0000?ooooo0_l000000ooooooo0000o`00
000;ooooo`Co00000oooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool3o`0000Sooooo
0_l00005ooooo`;o00000_ooool3o`0000;ooooo0_l0000<ooooo`;o00000oooool2o`0006cooooo
000Looooo`03o`000?oooooooooo063ooooo0_l0000:ooooo`;o00005?ooool2o`0000;ooooo0ol0
0006ooooo`;o00001Oooool2o`0000_ooooo0ol00004ooooo`;o000000Coooooo`000?l0003o0000
4oooool2o`0000oooooo1?l0001aooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o
8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0K?ooool2o`00
01Sooooo0_l00007ooooo`Ko000000?oooooo`000?l000002oooool3o`0000Cooooo0ol0000Hoooo
o`Go00002?ooool4o`0007?ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44
ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1Iooooo`;o0000;ooo
ool2o`0000Gooooo1?l0000:ooooo`Co00001oooool4o`0000Oooooo0_l0000>ooooo`Go00000_oo
ool2o`0000Cooooo0_l0001eooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`1Iooooo`;o0000:_oo
ool3o`0000;ooooo0_l00005ooooo`;o00003?ooool4o`0000Wooooo0_l00006ooooo`?o00005?oo
ool4o`0007[ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8b
oiRHV?ooooooV9RHoc8b<P06ooooo`?o0000Ioooool2o`0001cooooo0ol00007ooooo`Go00004?oo
ool2o`0000;ooooo0_l0000:ooooo`?o00005?ooool4o`0000?ooooo1?l00005ooooo`;o0000K?oo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Oo<c<co0000o`000?l0
003oc<c<00Kooooo00?o0000ooooooooool0Ioooool2o`0001gooooo0_l00007ooooo`;o000000?o
ooooo`000?l000004?ooool2o`000005ooooool0003o0000o`000?ooool00ol000000ooooooo0000
o`00000Hooooo`;o00001Oooool6o`0000Gooooo0_l0001/ooooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooo
ooooo`21ooooo`;o00003?ooool2o`0000kooooo0ol00005ooooo`;o00000_ooool6o`0000Sooooo
0_l0000>ooooo`;o00001Oooool2o`000003ooooool0003o000007Cooooo00001_ooooooMgMgoiRH
V?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo
087ooooo0_l00005ooooo`;o00002_ooool2o`0000Wooooo1Ol00009ooooo`;o00001Oooool2o`00
00?ooooo0_l0000Booooo`;o00000oooool7o`00073ooooo00001_ooooook^k^oc8b<_l0003o<S8b
onk^kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo06_ooooo0_l0
000Kooooo`;o00002Oooool3o`0000cooooo0_l0000=ooooo`;o000000?oooooo`000?l000005ooo
ool2o`0000?ooooo1ol0001`ooooo`007?ooool00ol0003oooooooooo`1[ooooo`;o00009_ooool2
o`00013ooooo0_l00005ooooo`;o00000oooool2o`0000gooooo0_l0000;ooooo`Co0000N?ooool0
01cooooo00?o0000ooooooooool0S_ooool2o`0000oooooo0_l000001?oooooo0000o`000?ooool3
o`0000Cooooo0_l0000@ooooo`Co00001?ooool2o`000003ooooool0003o000000;ooooo1?l0001h
ooooo`007?ooool00ol0003oooooooooo`2>ooooo`;o00003?ooool2o`000004ooooool0003o0000
ooooo`;o00000_ooool2o`0000Gooooo0_l0000?ooooo`;o00001?ooool7o`0001Kooooo0_l0001V
ooooo`007?ooool00ol0003oooooooooo`2>ooooo`;o00003?ooool2o`0000oooooo0_l00005oooo
o`Go00002oooool2o`0000;ooooo0_l0000Gooooo`;o0000I_ooool001cooooo00?o0000oooooooo
ool0Y_ooool3o`0000?ooooo0_l00006ooooo`Go00002Oooool2o`000003ooooool0003o000008;o
oooo000Looooo`03o`000?oooooooooo097ooooo0_l0000;ooooo`;o00001_ooool3o`0000?ooooo
0_l00007ooooo`;o00002oooool2o`000003ooooool0003o000008;ooooo000Looooo`03o`000?oo
oooooooo097ooooo0ol0000:ooooo`;o00007oooool2o`000003ooooool0003o000008Gooooo000L
ooooo`03o`000?oooooooooo09;ooooo0_l0000>ooooo`;o00002?ooool2o`00017ooooo0_l00028
ooooo`007?ooool00ol0003oooooooooo`29ooooo`;o00001oooool3o`0000Wooooo0_l00002oooo
o`;o00002?ooool2o`0009_ooooo000Looooo`03o`000?oooooooooo08Wooooo0_l00004ooooo`;o
000000Coooooo`000?l0003o00002Oooool2o`0001Kooooo0_l0002Aooooo`007?ooool00ol0003o
ooooooooo`2?ooooo`;o00003Oooool2o`0000?ooooo0_l00003ooooo`;o00003?ooool3o`0000go
oooo0_l00021ooooo`007?ooool2o`000:7ooooo0_l000000ooooooo0000o`000003ooooo`;o0000
3Oooool2o`0000gooooo0_l00021ooooo`007?ooool00ol0003oooooooooo`2Nooooo`Co000000?o
ooooo`000?l000003?ooool2o`0001Wooooo0_l0001kooooo`007?ooool00ol0003oooooooooo`2;
ooooo`;o00004Oooool2o`00017ooooo0_l0000Iooooo`;o0000Noooool001cooooo00?o0000oooo
ooooool0Roooool2o`0003;ooooo0_l00028ooooo`007?ooool00ol0003oooooooooo`21ooooo`;o
0000??ooool2o`0008Sooooo000Looooo`03o`000?oooooooooo087ooooo0_l0000?ooooo`;o0000
6oooool2o`0009Sooooo000Looooo`03o`000?oooooooooo09;ooooo0_l0000Kooooo`;o0000V?oo
ool001cooooo00?o0000ooooooooool0Soooool2o`0002Kooooo0_l0002@ooooo`007?ooool00ol0
003oooooooooo`2?ooooo`;o00004Oooool2o`0001?ooooo0_l0002@ooooo`007?ooool00ol0003o
ooooooooo`2Rooooo`;o0000YOooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Booooo`Co000000?o410@ooooooooool00oooool00ol0003ooooooooo
o`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom:
ooooo`005?ooool00ol0003oooooooooo`05ooooo`?o0000oooooom:ooooo`005?ooool00ol0003o
ooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o
0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Boooo
o`03oeEEEOmVIVKo00000?ooooooE?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00:Gooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0Eooooo`04oa0@4?l0
003oA4A4olc<c0Kooooo00?o0000onk^k_ooool00oooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<093o
oooo002Vooooo`05o`000?ooooooooooooooool000002Oooool6o`0000_ooooo00?oV9RHoa0@4?oM
gMd01Oooool00omEEEGoZJVYooooo`03ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40T?ooool00:Ko
oooo00Go0000ooooooooooooooooo`00000Kooooo`03ohN7QomEEEGooooo00Cooooo00?oZJVYoeEE
EOooool00oooool01Ol0003ooooooooooooooooo0000093ooooo002Vooooo`05o`000?oooooooooo
ooooool000002Oooool6o`0000Wooooo00Goc<c<ob4Q8Ol0003oEEEEo`000006ooooo`03ob4Q8Ooo
oooooooo00;ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P2@ooooo`00Y_ooool01Ol0003oQhN7oooo
oonYZJWo000001Sooooo00Go8B4QohN7QoooooooV9RHo`000006ooooo`03oeEEEOo<c<cooooo00;o
oooo00Goc<c<o`000?l0003o0000olc<c02@ooooo`00YOooool00ol@413o0000ogMgM`02o`000003
oiRHV?oooooooooo01Kooooo00Go0000ooooooooooooooooo`000006ooooo`03ojVYZOmgMgOooooo
00;ooooo00Go410@okZj^_oooooo^[Zjoa0@402@ooooo`00`oooool01OlQ8B7oV9RHoooooomgMgOo
EEEE00?ooooo00Go410@oooooooooooooooooc8b<P03ooooo`05o`000?nj^[[ooooookZj^_l00000
T?ooool00<?ooooo00Goc<c<oa0@4?l0003o<S8bonk^kP03ooooo`Go00000oooool01OnYZJWo410@
o`000?l@413oZJVY093ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(984) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.67375 .43865 Mdot
.6371 .41049 Mdot
.3284 .52246 Mdot
.58048 .58124 Mdot
.69805 .35074 Mdot
.35441 .4626 Mdot
.45646 .32753 Mdot
.50803 .31531 Mdot
.34637 .48603 Mdot
.51647 .49844 Mdot
.48477 .33731 Mdot
.50179 .55244 Mdot
.48863 .31586 Mdot
.57125 .5945 Mdot
.64062 .82894 Mdot
.61664 .58818 Mdot
.61621 .41127 Mdot
.30704 .67602 Mdot
.52203 .54555 Mdot
.33311 .53754 Mdot
.6295 .46543 Mdot
.57071 .58146 Mdot
.67261 .4345 Mdot
.5708 .59444 Mdot
.5916 .60035 Mdot
.63943 .43369 Mdot
.69595 .43244 Mdot
.59171 .57496 Mdot
.57154 .6371 Mdot
.49244 .29859 Mdot
.42403 .75595 Mdot
.73215 .74993 Mdot
.58863 .53344 Mdot
.60859 .20286 Mdot
.50949 .32382 Mdot
.73839 .66698 Mdot
.37028 .45968 Mdot
.47434 .30067 Mdot
.50766 .32223 Mdot
.49561 .28962 Mdot
.49179 .30656 Mdot
.64137 .42783 Mdot
.52875 .3134 Mdot
.47478 .25391 Mdot
.50782 .59689 Mdot
.5949 .32288 Mdot
.57041 .74997 Mdot
.52789 .60382 Mdot
.61663 .42 Mdot
.3279 .53728 Mdot
.59119 .20907 Mdot
.45735 .29812 Mdot
.40537 .41379 Mdot
.89239 .4345 Mdot
.46405 .30603 Mdot
.50494 .58757 Mdot
.35364 .49145 Mdot
.55913 .57584 Mdot
.56695 .59112 Mdot
.65873 .6755 Mdot
.60442 .59217 Mdot
.31761 .65667 Mdot
.60205 .41735 Mdot
.34942 .57677 Mdot
.35581 .47034 Mdot
.50518 .32322 Mdot
.63366 .39782 Mdot
.48177 .316 Mdot
.49828 .62248 Mdot
.35195 .44292 Mdot
.52807 .60246 Mdot
.50082 .32336 Mdot
.67265 .38548 Mdot
.52908 .58449 Mdot
.31206 .27617 Mdot
.48477 .84625 Mdot
.35965 .65798 Mdot
.68822 .66108 Mdot
.65976 .70519 Mdot
.29028 .58592 Mdot
.5637 .63034 Mdot
.21771 .65403 Mdot
.58889 .83533 Mdot
.66542 .44314 Mdot
.62374 .5969 Mdot
.32987 .45458 Mdot
.53193 .57759 Mdot
.55876 .39618 Mdot
.50965 .62092 Mdot
.41682 .21332 Mdot
.34163 .49365 Mdot
.66091 .41046 Mdot
.58061 .58386 Mdot
.59223 .63027 Mdot
.67439 .52432 Mdot
.58933 .56102 Mdot
.58096 .56786 Mdot
.69254 .42292 Mdot
.47919 .34375 Mdot
.49289 .55518 Mdot
.50883 .27874 Mdot
.39162 .41677 Mdot
.5196 .5703 Mdot
.35648 .49656 Mdot
.69261 .40917 Mdot
.5273 .57518 Mdot
.48557 .35197 Mdot
.53627 .62586 Mdot
.46024 .24892 Mdot
.63557 .40699 Mdot
.58866 .6339 Mdot
.32375 .6263 Mdot
.21889 .38494 Mdot
.66465 .40875 Mdot
.35773 .54005 Mdot
.54503 .63689 Mdot
.56058 .56198 Mdot
.63926 .4123 Mdot
.32144 .48656 Mdot
.56498 .45429 Mdot
.6177 .44403 Mdot
.50651 .29844 Mdot
.60881 .43585 Mdot
.6223 .58386 Mdot
.3437 .47956 Mdot
.40369 .39262 Mdot
.41001 .39118 Mdot
.39268 .71866 Mdot
.53576 .57351 Mdot
.58942 .24937 Mdot
.34373 .4664 Mdot
.65498 .41582 Mdot
.48267 .31965 Mdot
.55795 .67133 Mdot
.66588 .39549 Mdot
.46997 .32973 Mdot
.35101 .63467 Mdot
.34454 .3792 Mdot
.61601 .43392 Mdot
.47845 .24477 Mdot
.45025 .2965 Mdot
.49193 .28641 Mdot
.58651 .19296 Mdot
.63026 .413 Mdot
.33839 .63796 Mdot
.46881 .32355 Mdot
.50457 .77028 Mdot
.5003 .59818 Mdot
.39806 .65442 Mdot
.16037 .57882 Mdot
.56854 .19779 Mdot
.35449 .31483 Mdot
.30509 .66502 Mdot
.47975 .28324 Mdot
.5891 .61926 Mdot
.62384 .42531 Mdot
.62992 .42454 Mdot
.56494 .55116 Mdot
.58913 .58807 Mdot
.52704 .59657 Mdot
.58388 .63653 Mdot
.603 .76894 Mdot
.52793 .62511 Mdot
.30536 .73115 Mdot
.66604 .41684 Mdot
.59889 .59788 Mdot
.31504 .52613 Mdot
.54188 .65593 Mdot
.49846 .31262 Mdot
.56476 .57317 Mdot
.58255 .57961 Mdot
.60187 .61911 Mdot
.45276 .31767 Mdot
.72642 .73933 Mdot
.15974 .52554 Mdot
.81241 .57699 Mdot
.38674 .47385 Mdot
.36884 .44631 Mdot
.53804 .56525 Mdot
.33222 .65363 Mdot
.7498 .62973 Mdot
.56579 .6208 Mdot
.33577 .20002 Mdot
.57862 .56934 Mdot
.73426 .37117 Mdot
.5651 .70659 Mdot
.82173 .55866 Mdot
.34924 .70163 Mdot
.57978 .63486 Mdot
.70494 .48813 Mdot
.77847 .44381 Mdot
.43005 .30228 Mdot
.48828 .30596 Mdot
.31533 .52341 Mdot
.34643 .50425 Mdot
.43782 .33586 Mdot
.4769 .60125 Mdot
.50849 .66504 Mdot
.52036 .66267 Mdot
.40229 .40687 Mdot
.6074 .39318 Mdot
.33873 .67271 Mdot
.69073 .41353 Mdot
.30045 .78344 Mdot
.48363 .22895 Mdot
.51271 .27004 Mdot
.35966 .64149 Mdot
.32303 .51079 Mdot
.40121 .41085 Mdot
.33768 .65439 Mdot
.54425 .61302 Mdot
.62914 .40435 Mdot
.7245 .28695 Mdot
.48708 .65299 Mdot
.71309 .25627 Mdot
.64107 .38535 Mdot
.55114 .44414 Mdot
.48079 .33095 Mdot
.37915 .45935 Mdot
.56434 .56181 Mdot
.54405 .59612 Mdot
.61165 .46087 Mdot
.53016 .60196 Mdot
.71815 .38881 Mdot
.56631 .55851 Mdot
.39121 .37794 Mdot
.3591 .66085 Mdot
.43917 .33948 Mdot
.3829 .71713 Mdot
.68235 .40996 Mdot
.36245 .68293 Mdot
.31061 .51522 Mdot
.72317 .66848 Mdot
.49917 .32935 Mdot
.33282 .62439 Mdot
.31438 .49597 Mdot
.33103 .67622 Mdot
.5349 .64752 Mdot
.37497 .43501 Mdot
.31086 .64633 Mdot
.65847 .76775 Mdot
.5206 .63968 Mdot
.58887 .78439 Mdot
.45752 .33253 Mdot
.60863 .43274 Mdot
.60309 .58924 Mdot
.37478 .47419 Mdot
.59909 .54578 Mdot
.33992 .28314 Mdot
.41323 .38603 Mdot
.40172 .4223 Mdot
.31657 .58918 Mdot
.32707 .6279 Mdot
.29688 .32527 Mdot
.5722 .23211 Mdot
.61868 .40844 Mdot
.52453 .55624 Mdot
.79958 .63433 Mdot
.46958 .32368 Mdot
.54734 .61761 Mdot
.36839 .40985 Mdot
.46901 .32097 Mdot
.5563 .5752 Mdot
.45544 .33778 Mdot
.62746 .42109 Mdot
.21102 .50422 Mdot
.61702 .40837 Mdot
.51563 .62978 Mdot
.47277 .35238 Mdot
.36089 .44059 Mdot
.63934 .43661 Mdot
.53566 .62144 Mdot
.5489 .55396 Mdot
.39871 .40308 Mdot
.60015 .60767 Mdot
.77129 .66575 Mdot
.60253 .6106 Mdot
.33391 .5232 Mdot
.59431 .56716 Mdot
.41785 .17731 Mdot
.29641 .41143 Mdot
.63278 .39862 Mdot
.39939 .42549 Mdot
.3486 .48803 Mdot
.25822 .54829 Mdot
.41901 .41036 Mdot
.55014 .63318 Mdot
.38809 .44068 Mdot
.3971 .63262 Mdot
.46846 .29622 Mdot
.55139 .53987 Mdot
.53053 .27408 Mdot
.31956 .53895 Mdot
.39993 .40924 Mdot
.57817 .68268 Mdot
.69128 .39988 Mdot
.5817 .5842 Mdot
.35835 .43949 Mdot
.61187 .44548 Mdot
.51788 .62786 Mdot
.47038 .66889 Mdot
.4119 .39274 Mdot
.45797 .32446 Mdot
.57472 .69749 Mdot
.52418 .60904 Mdot
.36528 .47017 Mdot
.67552 .39396 Mdot
.51158 .3215 Mdot
.64943 .43064 Mdot
.7613 .37148 Mdot
.40833 .32371 Mdot
.63787 .75495 Mdot
.33625 .60944 Mdot
.38095 .27587 Mdot
.82823 .52871 Mdot
.25788 .35929 Mdot
.47278 .73615 Mdot
.79731 .38559 Mdot
.31823 .48952 Mdot
.37752 .388 Mdot
.35035 .49042 Mdot
.58065 .61568 Mdot
.35502 .46596 Mdot
.82863 .54608 Mdot
.5704 .56067 Mdot
.36959 .45319 Mdot
.22609 .52711 Mdot
.59265 .58694 Mdot
.66558 .40658 Mdot
.63354 .82561 Mdot
.29342 .27503 Mdot
.50762 .21241 Mdot
.35516 .45149 Mdot
.60818 .69363 Mdot
.59211 .5776 Mdot
.60372 .62261 Mdot
.62826 .43759 Mdot
.57079 .54827 Mdot
.33619 .6732 Mdot
.35832 .64636 Mdot
.41639 .58807 Mdot
.1754 .54925 Mdot
.49459 .55404 Mdot
.63631 .43727 Mdot
.6265 .72173 Mdot
.33843 .2546 Mdot
.35975 .51448 Mdot
.52197 .31258 Mdot
.70779 .75209 Mdot
.48392 .63196 Mdot
.53108 .3167 Mdot
.50295 .24945 Mdot
.64949 .40343 Mdot
.73554 .71962 Mdot
.48051 .30408 Mdot
.73651 .50513 Mdot
.6452 .51849 Mdot
.5461 .60396 Mdot
.49314 .33649 Mdot
.50057 .55053 Mdot
.38179 .20685 Mdot
.51063 .78983 Mdot
.2809 .71814 Mdot
.51102 .61362 Mdot
.2873 .31528 Mdot
.56424 .56788 Mdot
.57602 .46648 Mdot
.60385 .60739 Mdot
.65326 .43351 Mdot
.51687 .50537 Mdot
.46984 .41471 Mdot
.16887 .58177 Mdot
.48836 .2271 Mdot
.30608 .66632 Mdot
.55719 .55744 Mdot
.54676 .60285 Mdot
.34597 .63664 Mdot
.66972 .43105 Mdot
.58365 .6355 Mdot
.42511 .65392 Mdot
.53355 .59377 Mdot
.48843 .30298 Mdot
.36373 .73561 Mdot
.6675 .46166 Mdot
.61116 .59028 Mdot
.62253 .45547 Mdot
.4557 .31515 Mdot
.5062 .31506 Mdot
.58304 .67655 Mdot
.51622 .32012 Mdot
.57703 .57196 Mdot
.42054 .79315 Mdot
.65106 .44807 Mdot
.52456 .693 Mdot
.67732 .41709 Mdot
.68672 .67806 Mdot
.48282 .35364 Mdot
.40093 .38823 Mdot
.6308 .48709 Mdot
.4831 .30635 Mdot
.53387 .21544 Mdot
.50316 .6452 Mdot
.5828 .54301 Mdot
.43741 .20742 Mdot
.34981 .45425 Mdot
.40841 .39715 Mdot
.50008 .34436 Mdot
.52388 .60577 Mdot
.5678 .54279 Mdot
.45564 .30668 Mdot
.69716 .53704 Mdot
.26248 .53165 Mdot
.5874 .57133 Mdot
.65825 .43504 Mdot
.65471 .41801 Mdot
.51462 .60408 Mdot
.54408 .62575 Mdot
.32743 .50292 Mdot
.39641 .4267 Mdot
.37502 .47783 Mdot
.41019 .39407 Mdot
.39067 .391 Mdot
.65236 .31844 Mdot
.49523 .28901 Mdot
.61517 .27047 Mdot
.39662 .22704 Mdot
.55073 .51841 Mdot
.37323 .4408 Mdot
.55313 .59893 Mdot
.577 .58035 Mdot
.51188 .32167 Mdot
.41145 .29865 Mdot
.62332 .57716 Mdot
.62996 .44638 Mdot
.50017 .34563 Mdot
.48417 .60804 Mdot
.6672 .29166 Mdot
.31184 .65521 Mdot
.4943 .20516 Mdot
.50186 .32565 Mdot
.65334 .40031 Mdot
.45302 .34131 Mdot
.54205 .59779 Mdot
.50916 .56788 Mdot
.64595 .40972 Mdot
.31349 .63545 Mdot
.52692 .65987 Mdot
.55516 .57244 Mdot
.17299 .37314 Mdot
.29978 .28529 Mdot
.50329 .3813 Mdot
.58676 .62676 Mdot
.58475 .55141 Mdot
.31666 .67818 Mdot
.53675 .59616 Mdot
.5424 .55314 Mdot
.19597 .41544 Mdot
.53504 .37343 Mdot
.3105 .68098 Mdot
.74033 .50976 Mdot
.63782 .38589 Mdot
.77008 .68949 Mdot
.38099 .4601 Mdot
.46532 .36312 Mdot
.22679 .46941 Mdot
.39862 .41647 Mdot
.35212 .27529 Mdot
.75464 .70757 Mdot
.40971 .39555 Mdot
.36598 .59756 Mdot
.59323 .51191 Mdot
.57658 .56029 Mdot
.55903 .56491 Mdot
.33245 .64745 Mdot
.62846 .41533 Mdot
.42916 .55462 Mdot
.52012 .81082 Mdot
.56936 .57461 Mdot
.71124 .38608 Mdot
.66151 .77564 Mdot
.39749 .40805 Mdot
.33718 .67016 Mdot
.33988 .61962 Mdot
.55533 .55882 Mdot
.20397 .42692 Mdot
.6374 .43384 Mdot
.53615 .62193 Mdot
.53063 .63265 Mdot
.35931 .44732 Mdot
.63875 .40011 Mdot
.32132 .48075 Mdot
.41266 .3822 Mdot
.79552 .45353 Mdot
.1862 .34097 Mdot
.50588 .33517 Mdot
.76324 .65826 Mdot
.47831 .29434 Mdot
.28151 .7077 Mdot
.40202 .41582 Mdot
.56301 .62669 Mdot
.68104 .40024 Mdot
.53429 .62347 Mdot
.55456 .61608 Mdot
.54514 .61232 Mdot
.48955 .60994 Mdot
.35486 .19271 Mdot
.32995 .6632 Mdot
.61602 .60668 Mdot
.33353 .52136 Mdot
.7621 .66707 Mdot
.53993 .83278 Mdot
.54841 .59133 Mdot
.54427 .55644 Mdot
.66708 .40302 Mdot
.56379 .54932 Mdot
.46591 .29863 Mdot
.67515 .39304 Mdot
.58688 .63696 Mdot
.72468 .71999 Mdot
.5691 .64189 Mdot
.81814 .5481 Mdot
.45269 .3416 Mdot
.53234 .21797 Mdot
.60439 .63312 Mdot
.40825 .38973 Mdot
.40858 .39704 Mdot
.38689 .45234 Mdot
.47019 .35959 Mdot
.36813 .46104 Mdot
.46058 .81865 Mdot
.5543 .52366 Mdot
.59042 .61439 Mdot
.5634 .54044 Mdot
.38059 .43976 Mdot
.56415 .39063 Mdot
.31351 .32855 Mdot
.48799 .62516 Mdot
.33203 .48769 Mdot
.60816 .43752 Mdot
.38158 .56507 Mdot
.6798 .40342 Mdot
.32057 .68706 Mdot
.48712 .3357 Mdot
.31448 .66572 Mdot
.55223 .20131 Mdot
.63703 .40828 Mdot
.61165 .46173 Mdot
.36978 .44713 Mdot
.53323 .42952 Mdot
.87913 .44439 Mdot
.35086 .44241 Mdot
.41369 .69396 Mdot
.63448 .44154 Mdot
.54025 .6407 Mdot
.34847 .71161 Mdot
.53935 .42581 Mdot
.36386 .46532 Mdot
.57235 .61776 Mdot
.20287 .4671 Mdot
.32733 .50107 Mdot
.54862 .53925 Mdot
.3231 .48712 Mdot
.4978 .31827 Mdot
.33627 .47234 Mdot
.63647 .38058 Mdot
.52933 .57186 Mdot
.88312 .46275 Mdot
.33508 .69965 Mdot
.60107 .61173 Mdot
.4969 .34805 Mdot
.43284 .61919 Mdot
.55957 .60688 Mdot
.3521 .66049 Mdot
.34172 .47989 Mdot
.27907 .49382 Mdot
.59564 .58047 Mdot
.35916 .45456 Mdot
.67496 .43483 Mdot
.46593 .35889 Mdot
.27807 .66078 Mdot
.39689 .39597 Mdot
.62457 .43465 Mdot
.41149 .36644 Mdot
.50085 .35044 Mdot
.58364 .55249 Mdot
.52533 .62223 Mdot
.66041 .42668 Mdot
.19941 .5501 Mdot
.5981 .57446 Mdot
.56397 .6301 Mdot
.32605 .52531 Mdot
.37688 .45221 Mdot
.20589 .54712 Mdot
.32516 .47878 Mdot
.51341 .55546 Mdot
.65918 .42734 Mdot
.5798 .59302 Mdot
.66108 .39866 Mdot
.53985 .55056 Mdot
.66113 .36571 Mdot
.66058 .44513 Mdot
.27464 .36834 Mdot
.57733 .60634 Mdot
.56491 .70384 Mdot
.54976 .61409 Mdot
.5305 .59816 Mdot
.32997 .50904 Mdot
.3413 .66232 Mdot
.578 .66658 Mdot
.29048 .64598 Mdot
.34943 .66063 Mdot
.76381 .41538 Mdot
.35292 .45263 Mdot
.32492 .64175 Mdot
.60738 .78289 Mdot
.39555 .43219 Mdot
.32592 .65543 Mdot
.56765 .82851 Mdot
.50809 .33145 Mdot
.62346 .39281 Mdot
.59266 .5879 Mdot
.78768 .37395 Mdot
.44078 .78514 Mdot
.39203 .42104 Mdot
.60027 .61462 Mdot
.55569 .60061 Mdot
.63727 .4524 Mdot
.26466 .73375 Mdot
.33723 .52629 Mdot
.58409 .61211 Mdot
.63756 .39509 Mdot
.17701 .64661 Mdot
.34176 .51629 Mdot
.32887 .653 Mdot
.45275 .31038 Mdot
.6835 .37875 Mdot
.39383 .40459 Mdot
.45542 .3037 Mdot
.2907 .36801 Mdot
.5328 .20859 Mdot
.54424 .63688 Mdot
.37405 .4405 Mdot
.53907 .1865 Mdot
.48488 .5641 Mdot
.46955 .37608 Mdot
.63673 .60576 Mdot
.65277 .40341 Mdot
.46171 .30329 Mdot
.31117 .66679 Mdot
.66138 .38275 Mdot
.66527 .43467 Mdot
.50863 .31143 Mdot
.37102 .58949 Mdot
.54877 .44072 Mdot
.49538 .30506 Mdot
.42007 .2157 Mdot
.74107 .3359 Mdot
.39204 .4347 Mdot
.35008 .65516 Mdot
.699 .27422 Mdot
.64199 .4284 Mdot
.71104 .74933 Mdot
.50052 .19661 Mdot
.58139 .5682 Mdot
.32728 .63628 Mdot
.58898 .34596 Mdot
.49124 .82013 Mdot
.46691 .31936 Mdot
.48056 .40487 Mdot
.31827 .62324 Mdot
.58687 .56689 Mdot
.64044 .64454 Mdot
.57575 .62116 Mdot
.48162 .33444 Mdot
.65229 .704 Mdot
.65408 .39967 Mdot
.50312 .34569 Mdot
.49597 .20484 Mdot
.5742 .57279 Mdot
.57506 .61494 Mdot
.39987 .74511 Mdot
.62322 .40921 Mdot
.37619 .47273 Mdot
.54771 .63543 Mdot
.55933 .57231 Mdot
.59519 .55035 Mdot
.54881 .69451 Mdot
.21541 .39399 Mdot
.58297 .61145 Mdot
.39465 .35966 Mdot
.61322 .59621 Mdot
.57574 .60419 Mdot
.62092 .45355 Mdot
.21963 .30439 Mdot
.40207 .38598 Mdot
.563 .57219 Mdot
.55109 .64039 Mdot
.51086 .31472 Mdot
.50343 .49116 Mdot
.53638 .41971 Mdot
.37007 .42437 Mdot
.5043 .74528 Mdot
.48933 .6073 Mdot
.66183 .39041 Mdot
.32877 .62335 Mdot
.51702 .60626 Mdot
.65893 .39028 Mdot
.56289 .65285 Mdot
.32811 .49458 Mdot
.39344 .43117 Mdot
.51826 .22798 Mdot
.32293 .64973 Mdot
.41947 .77533 Mdot
.60957 .28005 Mdot
.31759 .52295 Mdot
.59238 .6081 Mdot
.44424 .34543 Mdot
.37307 .42822 Mdot
.39874 .40111 Mdot
.59882 .66891 Mdot
.62934 .42874 Mdot
.66307 .41068 Mdot
.39655 .65264 Mdot
.35176 .34991 Mdot
.17291 .41513 Mdot
.49766 .32144 Mdot
.58894 .63822 Mdot
.57576 .23903 Mdot
.66374 .40944 Mdot
.37159 .69537 Mdot
.32307 .64233 Mdot
.46527 .3193 Mdot
.3662 .50401 Mdot
.66473 .39648 Mdot
.61453 .42558 Mdot
.51909 .63584 Mdot
.54772 .57851 Mdot
.46069 .72797 Mdot
.40592 .62134 Mdot
.45639 .31059 Mdot
.34914 .64244 Mdot
.31802 .48428 Mdot
.57886 .62321 Mdot
.66815 .44136 Mdot
.72809 .30328 Mdot
.54644 .63984 Mdot
.32677 .50723 Mdot
.65334 .40629 Mdot
.34155 .63103 Mdot
.34967 .66271 Mdot
.53134 .59771 Mdot
.64358 .69078 Mdot
.46729 .30899 Mdot
.66421 .40573 Mdot
.65353 .25593 Mdot
.59968 .57428 Mdot
.54491 .57434 Mdot
.60979 .67319 Mdot
.49831 .29932 Mdot
.53704 .22219 Mdot
.31157 .63487 Mdot
.63644 .42132 Mdot
.57519 .6387 Mdot
.31788 .65485 Mdot
.5563 .22558 Mdot
.39492 .42221 Mdot
.32977 .47925 Mdot
.35128 .66192 Mdot
.33981 .63441 Mdot
.35323 .64533 Mdot
.69926 .7614 Mdot
.63777 .3791 Mdot
.51814 .69434 Mdot
.60675 .59196 Mdot
.39297 .66015 Mdot
.55074 .67123 Mdot
.45099 .34178 Mdot
.34482 .45799 Mdot
.55299 .61272 Mdot
.51692 .63057 Mdot
.58771 .69147 Mdot
.54352 .70137 Mdot
.6761 .45502 Mdot
.63625 .40452 Mdot
.56299 .51914 Mdot
.36128 .44421 Mdot
.27946 .76671 Mdot
.85527 .50487 Mdot
.60664 .63448 Mdot
.5418 .45225 Mdot
.67069 .43641 Mdot
.50274 .29947 Mdot
.51837 .41432 Mdot
.45643 .34316 Mdot
.64295 .42005 Mdot
.58015 .61972 Mdot
.62229 .27613 Mdot
.33869 .67648 Mdot
.52437 .60039 Mdot
.47572 .3283 Mdot
.52545 .59854 Mdot
.4546 .30606 Mdot
.71842 .35042 Mdot
.39029 .21733 Mdot
.57853 .56882 Mdot
.60091 .56818 Mdot
.63252 .64908 Mdot
.55025 .59088 Mdot
.23942 .64081 Mdot
.67267 .43036 Mdot
.18058 .50571 Mdot
.52222 .63927 Mdot
.7273 .6154 Mdot
.60495 .58385 Mdot
.21031 .47751 Mdot
.5423 .57881 Mdot
.45605 .44268 Mdot
.58205 .56529 Mdot
.53126 .56266 Mdot
.46403 .34923 Mdot
.5107 .31508 Mdot
.67821 .43921 Mdot
.37614 .47205 Mdot
.8072 .59561 Mdot
.55144 .57213 Mdot
.3913 .40103 Mdot
.50559 .37369 Mdot
.34497 .63853 Mdot
.64329 .42208 Mdot
.19054 .66807 Mdot
.45311 .32798 Mdot
.32051 .55035 Mdot
.19984 .57565 Mdot
.39146 .40641 Mdot
.45431 .38672 Mdot
.56947 .48105 Mdot
.3214 .63085 Mdot
.59104 .57075 Mdot
.62845 .21766 Mdot
.31043 .28186 Mdot
.5537 .6753 Mdot
.49563 .35249 Mdot
.73511 .64847 Mdot
.70502 .28373 Mdot
.34483 .61868 Mdot
.30708 .65943 Mdot
.45446 .32485 Mdot
.33496 .53334 Mdot
.49427 .58621 Mdot
.32095 .64282 Mdot
.31831 .50831 Mdot
.39446 .43713 Mdot
.42525 .4392 Mdot
.63702 .43072 Mdot
.4981 .20855 Mdot
.58824 .30702 Mdot
.45398 .31421 Mdot
.37172 .66613 Mdot
.68857 .38284 Mdot
.6809 .38452 Mdot
.38383 .44782 Mdot
.33011 .51227 Mdot
.64794 .37925 Mdot
.50567 .5667 Mdot
.56471 .71131 Mdot
.5669 .57248 Mdot
.33764 .64604 Mdot
.54337 .58536 Mdot
.33055 .50011 Mdot
.47274 .31857 Mdot
.33621 .51088 Mdot
.4567 .33618 Mdot
.65001 .30979 Mdot
.53678 .61663 Mdot
.53446 .56177 Mdot
.43213 .78566 Mdot
.66949 .44582 Mdot
.59589 .21402 Mdot
.38893 .37791 Mdot
.34941 .49581 Mdot
.54728 .5513 Mdot
.68092 .41702 Mdot
.36365 .64331 Mdot
.42574 .78625 Mdot
.52073 .60357 Mdot
.67409 .42851 Mdot
.5863 .61529 Mdot
.62967 .77417 Mdot
.27734 .29186 Mdot
.65242 .42736 Mdot
.17698 .60569 Mdot
.57373 .63417 Mdot
.5156 .51117 Mdot
.5505 .53656 Mdot
.43141 .67375 Mdot
.59681 .57202 Mdot
.64141 .38513 Mdot
.56621 .57723 Mdot
.66437 .38485 Mdot
.32499 .5289 Mdot
.49407 .29054 Mdot
.63095 .44282 Mdot
.52423 .62433 Mdot
.77687 .71287 Mdot
.4878 .33226 Mdot
.56062 .55964 Mdot
.47369 .34387 Mdot
.63904 .39106 Mdot
.6167 .42727 Mdot
.49169 .82913 Mdot
.52199 .37587 Mdot
.49713 .31665 Mdot
.58605 .60473 Mdot
.5602 .29258 Mdot
.58069 .60124 Mdot
.44207 .72034 Mdot
.51029 .58947 Mdot
.59588 .56949 Mdot
.47757 .84836 Mdot
.46982 .29471 Mdot
.17955 .41199 Mdot
.5352 .80674 Mdot
.68529 .77157 Mdot
.65629 .37119 Mdot
.34512 .61916 Mdot
.73263 .72421 Mdot
.41318 .38299 Mdot
.34025 .47385 Mdot
.55171 .61203 Mdot
.65335 .47196 Mdot
.47238 .30036 Mdot
.34102 .66082 Mdot
.57752 .56807 Mdot
.328 .51324 Mdot
.29716 .55496 Mdot
.49436 .28538 Mdot
.64139 .42714 Mdot
.63815 .44887 Mdot
.16194 .60305 Mdot
.57737 .63802 Mdot
.54231 .55505 Mdot
.4833 .33587 Mdot
.49679 .66154 Mdot
.33368 .62567 Mdot
.23096 .50414 Mdot
.49678 .31768 Mdot
.50751 .45572 Mdot
.6311 .40832 Mdot
.5544 .60046 Mdot
.56953 .39565 Mdot
.40208 .45965 Mdot
.7584 .47689 Mdot
.33347 .65076 Mdot
.44102 .72834 Mdot
.64064 .38526 Mdot
.47963 .32206 Mdot
.35061 .38313 Mdot
.6093 .56133 Mdot
.55777 .59544 Mdot
.43693 .72995 Mdot
.40446 .59513 Mdot
.29655 .72285 Mdot
.53201 .5488 Mdot
.40988 .58622 Mdot
.52905 .55557 Mdot
.59617 .54796 Mdot
.50837 .56576 Mdot
.5399 .57159 Mdot
.67307 .43112 Mdot
.54582 .68657 Mdot
.34976 .46189 Mdot
.67953 .51871 Mdot
.50239 .40512 Mdot
.60253 .59394 Mdot
.57984 .61389 Mdot
.77755 .51028 Mdot
.53219 .33557 Mdot
.65779 .44209 Mdot
.59489 .42644 Mdot
.51603 .31454 Mdot
.57019 .70498 Mdot
.37036 .47966 Mdot
.56784 .68667 Mdot
.33441 .50812 Mdot
.67808 .42006 Mdot
.3503 .49813 Mdot
.50263 .29104 Mdot
.37414 .43964 Mdot
.39058 .38674 Mdot
.46611 .30044 Mdot
.62106 .41833 Mdot
.52967 .58644 Mdot
.5013 .34431 Mdot
.40392 .7442 Mdot
.33675 .64589 Mdot
.49455 .82968 Mdot
.56436 .64935 Mdot
.52458 .38953 Mdot
.47 .66932 Mdot
.33711 .50875 Mdot
.23712 .34014 Mdot
.65903 .44582 Mdot
.34116 .67899 Mdot
.67823 .42175 Mdot
.45611 .18706 Mdot
.34624 .65664 Mdot
.57555 .82695 Mdot
.36907 .33528 Mdot
.28806 .52627 Mdot
.50277 .57771 Mdot
.63479 .55647 Mdot
.3561 .43974 Mdot
.47047 .30098 Mdot
.3594 .33379 Mdot
.52792 .56759 Mdot
.25926 .36176 Mdot
.67518 .44439 Mdot
.38896 .44571 Mdot
.4837 .31705 Mdot
.50768 .33934 Mdot
.53555 .629 Mdot
.23184 .55928 Mdot
.52032 .57598 Mdot
.34069 .35071 Mdot
.48123 .74355 Mdot
.60876 .67894 Mdot
.56478 .55803 Mdot
.35451 .49931 Mdot
.58673 .61392 Mdot
.56363 .7211 Mdot
.59296 .19641 Mdot
.49901 .63294 Mdot
.39988 .32254 Mdot
.37295 .65716 Mdot
.64163 .41001 Mdot
.59723 .64098 Mdot
.39635 .40124 Mdot
.58043 .63148 Mdot
.54981 .14713 Mdot
.32359 .65592 Mdot
.33154 .44588 Mdot
.60828 .58532 Mdot
.54132 .63201 Mdot
.63603 .50261 Mdot
.64124 .47762 Mdot
.36599 .50516 Mdot
.55931 .58898 Mdot
.50211 .76042 Mdot
.48948 .34123 Mdot
.51878 .58204 Mdot
.55876 .56306 Mdot
.77672 .43163 Mdot
.50362 .30737 Mdot
.34106 .50923 Mdot
.40551 .41316 Mdot
.31187 .49995 Mdot
.29774 .66195 Mdot
.49499 .4231 Mdot
.3881 .67423 Mdot
.28765 .28747 Mdot
.3498 .62732 Mdot
.55875 .64396 Mdot
.61998 .55958 Mdot
.56089 .63705 Mdot
.30972 .66708 Mdot
.49766 .30054 Mdot
.65399 .44504 Mdot
.52734 .23872 Mdot
.40136 .40621 Mdot
.55271 .53954 Mdot
.32612 .67537 Mdot
.62519 .42672 Mdot
.3275 .69617 Mdot
.6384 .41546 Mdot
.49174 .31267 Mdot
.51428 .34146 Mdot
.33021 .66927 Mdot
.67988 .40711 Mdot
.4004 .36122 Mdot
.51097 .80943 Mdot
.51015 .58156 Mdot
.43051 .35159 Mdot
.67924 .42954 Mdot
.68803 .44127 Mdot
.69066 .42309 Mdot
.53187 .60542 Mdot
.539 .45962 Mdot
.61075 .57259 Mdot
.45639 .31726 Mdot
.32206 .49192 Mdot
.40564 .63074 Mdot
.71676 .32265 Mdot
.38717 .6175 Mdot
.53817 .66407 Mdot
.57303 .57574 Mdot
.55573 .559 Mdot
.50683 .60547 Mdot
.3371 .37536 Mdot
.54137 .62281 Mdot
.46257 .34704 Mdot
.3367 .49366 Mdot
.60523 .59413 Mdot
.39042 .42371 Mdot
.55704 .43774 Mdot
.33156 .62205 Mdot
.48773 .41704 Mdot
.78592 .6749 Mdot
.62532 .43019 Mdot
.32914 .47185 Mdot
.3436 .47027 Mdot
.35045 .6338 Mdot
.47425 .30131 Mdot
.63268 .41463 Mdot
.44464 .68272 Mdot
.35161 .64404 Mdot
.56373 .57511 Mdot
.25027 .42537 Mdot
.2436 .40535 Mdot
.58116 .55928 Mdot
.56134 .61668 Mdot
.40166 .42165 Mdot
.33792 .53014 Mdot
.74088 .27442 Mdot
.34428 .71942 Mdot
.33576 .66705 Mdot
.31187 .63954 Mdot
.68751 .39427 Mdot
.61817 .61844 Mdot
.45712 .32205 Mdot
.36982 .74298 Mdot
.42491 .61388 Mdot
.39999 .7679 Mdot
.27719 .65446 Mdot
.52669 .61806 Mdot
.65468 .58932 Mdot
.57628 .57311 Mdot
.65089 .45186 Mdot
.62869 .39942 Mdot
.64573 .44181 Mdot
.46518 .30707 Mdot
.69478 .67423 Mdot
.47516 .35218 Mdot
.81297 .62595 Mdot
.64387 .38303 Mdot
.31702 .41183 Mdot
.35997 .48015 Mdot
.59703 .63622 Mdot
.3351 .62784 Mdot
.47257 .27947 Mdot
.49595 .61524 Mdot
.20696 .41113 Mdot
.37332 .4428 Mdot
.62046 .41542 Mdot
.56993 .48269 Mdot
.8272 .48282 Mdot
.52467 .42853 Mdot
.51226 .52485 Mdot
.63403 .52142 Mdot
.34804 .64359 Mdot
.7553 .47809 Mdot
.30215 .66159 Mdot
.46861 .32572 Mdot
.53205 .56764 Mdot
.53276 .57603 Mdot
.53764 .55077 Mdot
.54037 .62047 Mdot
.51308 .31378 Mdot
.55604 .66512 Mdot
.41785 .17732 Mdot
.39539 .43072 Mdot
.6488 .7663 Mdot
.31414 .64946 Mdot
.47999 .35896 Mdot
.33595 .49723 Mdot
.373 .48504 Mdot
.37756 .70908 Mdot
.58421 .56838 Mdot
.55169 .61416 Mdot
.35362 .52455 Mdot
.53733 .54546 Mdot
.4899 .62507 Mdot
.35331 .45995 Mdot
.3882 .61663 Mdot
.35709 .63422 Mdot
.3136 .66394 Mdot
.49798 .30342 Mdot
.68006 .41261 Mdot
.32893 .6436 Mdot
.32813 .52744 Mdot
.55893 .65767 Mdot
.52692 .6325 Mdot
.67965 .43007 Mdot
.49807 .19602 Mdot
.33847 .61763 Mdot
.56446 .48137 Mdot
.65921 .38576 Mdot
.63682 .37886 Mdot
.55923 .59589 Mdot
.55087 .6779 Mdot
.70116 .42411 Mdot
.356 .6472 Mdot
.48519 .35841 Mdot
.29708 .48582 Mdot
.47266 .33129 Mdot
.62757 .41817 Mdot
.51706 .62202 Mdot
.62473 .41291 Mdot
.58812 .62705 Mdot
.61745 .86525 Mdot
.53631 .57631 Mdot
.32148 .24881 Mdot
.42699 .68638 Mdot
.34794 .46892 Mdot
.4014 .3645 Mdot
.38597 .44629 Mdot
.65354 .3846 Mdot
.51837 .61715 Mdot
.30814 .6434 Mdot
.63676 .80789 Mdot
.69316 .38737 Mdot
.32876 .48805 Mdot
.36152 .50114 Mdot
.47304 .29548 Mdot
.60689 .59981 Mdot
.55399 .5963 Mdot
.37237 .45182 Mdot
.51438 .71676 Mdot
.67065 .40079 Mdot
.5477 .55464 Mdot
.57497 .5887 Mdot
.35155 .46456 Mdot
.50523 .80832 Mdot
.60446 .48734 Mdot
.53661 .56644 Mdot
.35423 .40784 Mdot
.45551 .34796 Mdot
.50285 .59362 Mdot
.55651 .66591 Mdot
.3304 .63295 Mdot
.69359 .73135 Mdot
.6147 .20284 Mdot
.44746 .33481 Mdot
.37808 .46712 Mdot
.57113 .64401 Mdot
.36129 .47661 Mdot
.52628 .62979 Mdot
.77646 .62528 Mdot
.39141 .43892 Mdot
.55325 .62952 Mdot
.6109 .63521 Mdot
.62447 .4039 Mdot
.54137 .62605 Mdot
.78254 .48299 Mdot
.34065 .45489 Mdot
.54763 .62862 Mdot
.64724 .68217 Mdot
.50547 .31905 Mdot
.60474 .63758 Mdot
.31027 .65323 Mdot
.43295 .66914 Mdot
.61103 .29022 Mdot
.37063 .4132 Mdot
.31389 .6614 Mdot
.52317 .59309 Mdot
.3364 .53408 Mdot
.45328 .31258 Mdot
.2537 .36034 Mdot
.55296 .54935 Mdot
.48288 .33386 Mdot
.47485 .31805 Mdot
.31932 .66042 Mdot
.15909 .46287 Mdot
.56961 .65905 Mdot
.54786 .59019 Mdot
.78914 .47803 Mdot
.62187 .4493 Mdot
.53972 .58545 Mdot
.54978 .64171 Mdot
.46456 .34632 Mdot
.63367 .48621 Mdot
.76128 .5931 Mdot
.22559 .5244 Mdot
.44727 .31428 Mdot
.30803 .49612 Mdot
.33693 .53441 Mdot
.31561 .64642 Mdot
.64894 .41126 Mdot
.30896 .63145 Mdot
.35444 .45346 Mdot
.56307 .64221 Mdot
.45983 .33559 Mdot
.74603 .41068 Mdot
.45873 .29653 Mdot
.3666 .42024 Mdot
.65847 .4534 Mdot
.56796 .24715 Mdot
.47623 .14031 Mdot
.59638 .3116 Mdot
.52849 .30306 Mdot
.34472 .6383 Mdot
.28684 .37337 Mdot
.57443 .58418 Mdot
.74272 .48509 Mdot
.52841 .5915 Mdot
.65555 .64765 Mdot
.32498 .48034 Mdot
.36969 .48947 Mdot
.53354 .5678 Mdot
.46594 .73966 Mdot
.4666 .28913 Mdot
.46743 .29679 Mdot
.55115 .6238 Mdot
.48366 .30632 Mdot
.55096 .58013 Mdot
.33127 .50673 Mdot
.19745 .37403 Mdot
.56894 .56828 Mdot
.58866 .54771 Mdot
.51924 .27154 Mdot
.51114 .83125 Mdot
.38125 .34828 Mdot
.65181 .57443 Mdot
.81737 .4487 Mdot
.4832 .30677 Mdot
.60925 .65088 Mdot
.36634 .43006 Mdot
.40217 .42087 Mdot
.40157 .36234 Mdot
.53597 .59134 Mdot
.53664 .59758 Mdot
.54941 .55156 Mdot
.57517 .61617 Mdot
.74647 .48659 Mdot
.51479 .67503 Mdot
.67289 .61667 Mdot
.55319 .61618 Mdot
.64191 .64251 Mdot
.50054 .34351 Mdot
.62185 .46393 Mdot
.31357 .62414 Mdot
.52773 .61987 Mdot
.71228 .42124 Mdot
.46037 .35255 Mdot
.81451 .62305 Mdot
.48727 .29634 Mdot
.34886 .4864 Mdot
.49401 .29289 Mdot
.59848 .61246 Mdot
.65549 .41798 Mdot
.35874 .43275 Mdot
.30454 .31521 Mdot
.33862 .47581 Mdot
.60114 .61169 Mdot
.3183 .4545 Mdot
.34163 .47069 Mdot
.55517 .41476 Mdot
.6565 .41357 Mdot
.49341 .76408 Mdot
.6286 .39906 Mdot
.55133 .63093 Mdot
.55713 .63153 Mdot
.41298 .35686 Mdot
.48419 .2862 Mdot
.63549 .39203 Mdot
.16613 .38529 Mdot
.30026 .65881 Mdot
.64668 .43946 Mdot
.58883 .53221 Mdot
.45725 .52456 Mdot
.66122 .42057 Mdot
.49025 .71994 Mdot
.46598 .30283 Mdot
.6599 .38049 Mdot
.5933 .53697 Mdot
.42463 .2432 Mdot
.34696 .67177 Mdot
.35063 .51261 Mdot
.44611 .46654 Mdot
.35141 .44527 Mdot
.4887 .35881 Mdot
.37764 .44226 Mdot
.49123 .34206 Mdot
.58505 .21484 Mdot
.60491 .71948 Mdot
.44177 .34214 Mdot
.50383 .35055 Mdot
.36754 .44887 Mdot
.56388 .5552 Mdot
.44522 .40999 Mdot
.52395 .55249 Mdot
.49743 .60919 Mdot
.49757 .33672 Mdot
.63567 .38803 Mdot
.62025 .396 Mdot
.64217 .60435 Mdot
.63779 .44916 Mdot
.33286 .51001 Mdot
.28086 .28902 Mdot
.55745 .20227 Mdot
.49128 .33594 Mdot
.51483 .33142 Mdot
.58064 .60495 Mdot
.36637 .46292 Mdot
.32181 .5314 Mdot
.46048 .31868 Mdot
.72764 .46524 Mdot
.61224 .58281 Mdot
.673 .45113 Mdot
.64495 .38208 Mdot
.65624 .42786 Mdot
.69136 .41149 Mdot
.75641 .57646 Mdot
.46534 .30262 Mdot
.64846 .38342 Mdot
.55358 .62642 Mdot
.53703 .59583 Mdot
.40687 .39534 Mdot
.31223 .66205 Mdot
.56948 .6503 Mdot
.51394 .5511 Mdot
.55863 .59919 Mdot
.3312 .47831 Mdot
.59252 .52262 Mdot
.3788 .46869 Mdot
.34179 .5234 Mdot
.38637 .42875 Mdot
.40371 .3873 Mdot
.62778 .53935 Mdot
.82382 .44108 Mdot
.58412 .61254 Mdot
.48855 .65865 Mdot
.3587 .48031 Mdot
.22289 .3693 Mdot
.54349 .22531 Mdot
.54961 .5503 Mdot
.41063 .45603 Mdot
.3745 .44977 Mdot
.6198 .44322 Mdot
.53531 .58675 Mdot
.40966 .39995 Mdot
.33288 .62252 Mdot
.57514 .52544 Mdot
.40914 .40565 Mdot
.67725 .39986 Mdot
.31367 .61781 Mdot
.67108 .38376 Mdot
.37625 .4334 Mdot
.60945 .63599 Mdot
.88118 .43748 Mdot
.31191 .50259 Mdot
.58932 .80359 Mdot
.70095 .44436 Mdot
.55023 .55385 Mdot
.3289 .47095 Mdot
.62468 .45004 Mdot
.48022 .36113 Mdot
.4375 .54632 Mdot
.65095 .44773 Mdot
.37195 .48471 Mdot
.40567 .40669 Mdot
.35056 .46254 Mdot
.64013 .40291 Mdot
.51466 .59172 Mdot
.65116 .39664 Mdot
.49288 .29296 Mdot
.58417 .58299 Mdot
.8278 .54438 Mdot
.49671 .66566 Mdot
.65059 .38537 Mdot
.3299 .51988 Mdot
.3213 .67981 Mdot
.58491 .57401 Mdot
.57943 .79731 Mdot
.58984 .63158 Mdot
.48368 .34073 Mdot
.1943 .47052 Mdot
.75241 .42326 Mdot
.60421 .58508 Mdot
.58021 .60656 Mdot
.45905 .30416 Mdot
.58438 .56996 Mdot
.59908 .57703 Mdot
.5041 .3776 Mdot
.63821 .39868 Mdot
.56892 .57948 Mdot
.32029 .51951 Mdot
.62951 .22473 Mdot
.61105 .57695 Mdot
.36941 .52682 Mdot
.47985 .75561 Mdot
.18264 .47473 Mdot
.5266 .58606 Mdot
.36517 .72762 Mdot
.57074 .61794 Mdot
.52756 .60761 Mdot
.58425 .60126 Mdot
.65 .55225 Mdot
.3669 .4459 Mdot
.33249 .49138 Mdot
.35031 .66756 Mdot
.48612 .75704 Mdot
.32686 .63544 Mdot
.48002 .29723 Mdot
.30498 .57698 Mdot
.39122 .43773 Mdot
.67862 .40085 Mdot
.52111 .58402 Mdot
.33968 .45431 Mdot
.55223 .60223 Mdot
.59515 .61737 Mdot
.3542 .50168 Mdot
.31904 .53407 Mdot
.38132 .41158 Mdot
.31653 .63258 Mdot
.64029 .44381 Mdot
.52164 .64133 Mdot
.34874 .66155 Mdot
.51529 .59461 Mdot
.38438 .66789 Mdot
.64721 .44381 Mdot
.64096 .39758 Mdot
.61075 .42213 Mdot
.56396 .64224 Mdot
.60178 .59753 Mdot
.47751 .35196 Mdot
.68179 .40922 Mdot
.50125 .31213 Mdot
.36587 .42806 Mdot
.32956 .55866 Mdot
.536 .59158 Mdot
.53056 .49788 Mdot
.32458 .63195 Mdot
.34329 .49357 Mdot
.35224 .52947 Mdot
.33501 .68142 Mdot
.59093 .62855 Mdot
.3563 .4955 Mdot
.3167 .66965 Mdot
.70315 .47461 Mdot
.81311 .397 Mdot
.3142 .67613 Mdot
.5541 .62462 Mdot
.6507 .4871 Mdot
.48531 .80208 Mdot
.30129 .66718 Mdot
.46863 .3393 Mdot
.5633 .64317 Mdot
.48851 .67948 Mdot
.32875 .6196 Mdot
.62747 .2306 Mdot
.34917 .46984 Mdot
.43333 .25368 Mdot
.52381 .53165 Mdot
.72357 .49405 Mdot
.30236 .64227 Mdot
.63442 .41803 Mdot
.61425 .45286 Mdot
.5658 .60137 Mdot
.29569 .65332 Mdot
.44905 .30915 Mdot
.34535 .4767 Mdot
.39473 .38129 Mdot
.64263 .40155 Mdot
.54702 .291 Mdot
.32152 .50391 Mdot
.55255 .48415 Mdot
.21348 .49619 Mdot
.57411 .70984 Mdot
.64086 .67301 Mdot
.33397 .26848 Mdot
.54819 .6441 Mdot
.30786 .66939 Mdot
.46223 .35204 Mdot
.45514 .32868 Mdot
.49496 .31801 Mdot
.40133 .36705 Mdot
.51283 .41413 Mdot
.36956 .43469 Mdot
.28015 .34179 Mdot
.31807 .6536 Mdot
.52374 .76659 Mdot
.51688 .59764 Mdot
.57218 .5741 Mdot
.58747 .63963 Mdot
.51911 .57371 Mdot
.57159 .6092 Mdot
.47976 .30221 Mdot
.3992 .3655 Mdot
.27866 .49014 Mdot
.66032 .43348 Mdot
.37875 .61117 Mdot
.35975 .48072 Mdot
.39984 .42485 Mdot
.3336 .66342 Mdot
.57201 .46793 Mdot
.37855 .42643 Mdot
.34896 .49935 Mdot
.57584 .64967 Mdot
.66199 .39519 Mdot
.55502 .68189 Mdot
.56507 .62929 Mdot
.33972 .49817 Mdot
.36109 .5719 Mdot
.78091 .55237 Mdot
.62592 .62658 Mdot
.34646 .61167 Mdot
.522 .47381 Mdot
.30226 .66784 Mdot
.55298 .53484 Mdot
.21547 .38153 Mdot
.35588 .45265 Mdot
.35523 .47452 Mdot
.31574 .67229 Mdot
.53803 .50136 Mdot
.64947 .40551 Mdot
.36583 .4993 Mdot
.4778 .34617 Mdot
.55714 .63581 Mdot
.327 .55381 Mdot
.49913 .52903 Mdot
.24822 .55746 Mdot
.49492 .32504 Mdot
.33554 .5252 Mdot
.60698 .59772 Mdot
.55571 .62336 Mdot
.34656 .63862 Mdot
.70219 .34931 Mdot
.56366 .52189 Mdot
.68841 .76987 Mdot
.39921 .21677 Mdot
.45404 .21822 Mdot
.55764 .59525 Mdot
.63703 .4011 Mdot
.40165 .41594 Mdot
.35046 .65225 Mdot
.53941 .65978 Mdot
.81594 .41063 Mdot
.65417 .4592 Mdot
.47444 .32534 Mdot
.4099 .39777 Mdot
.5187 .41311 Mdot
.57779 .63984 Mdot
.52902 .59093 Mdot
.53521 .61166 Mdot
.78092 .32366 Mdot
.32534 .49226 Mdot
.66069 .44953 Mdot
.33504 .65249 Mdot
.64167 .45015 Mdot
.33714 .48189 Mdot
.54276 .25603 Mdot
.5989 .58423 Mdot
.66376 .45321 Mdot
.63778 .41836 Mdot
.47389 .29547 Mdot
.48591 .36086 Mdot
.30414 .49321 Mdot
.53751 .57567 Mdot
.40922 .40208 Mdot
.62379 .40291 Mdot
.35 .52502 Mdot
.34719 .65428 Mdot
.48885 .35137 Mdot
.55188 .61649 Mdot
.34954 .45986 Mdot
.53777 .66759 Mdot
.66604 .41495 Mdot
.34982 .49796 Mdot
.39404 .40092 Mdot
.31076 .64354 Mdot
.5431 .60644 Mdot
.35479 .61849 Mdot
.37693 .46841 Mdot
.5757 .58753 Mdot
.58789 .47412 Mdot
.33711 .60501 Mdot
.31329 .32227 Mdot
.35948 .44181 Mdot
.40111 .39326 Mdot
.61234 .42207 Mdot
.62948 .2415 Mdot
.35204 .477 Mdot
.58088 .4672 Mdot
.66899 .33042 Mdot
.52184 .64204 Mdot
.64579 .42917 Mdot
.2702 .39297 Mdot
.74563 .72858 Mdot
.54881 .78363 Mdot
.55999 .56025 Mdot
.33835 .46074 Mdot
.32998 .67364 Mdot
.49188 .33602 Mdot
.36913 .52596 Mdot
.56805 .71845 Mdot
.36674 .47755 Mdot
.58316 .60618 Mdot
.63207 .39815 Mdot
.46496 .31477 Mdot
.63483 .28382 Mdot
.32925 .52493 Mdot
.32944 .47434 Mdot
.60573 .59199 Mdot
.32276 .64396 Mdot
.59585 .75929 Mdot
.32921 .50323 Mdot
.32205 .54848 Mdot
.29105 .36532 Mdot
.32493 .67574 Mdot
.56531 .61885 Mdot
.64173 .61382 Mdot
.50524 .60354 Mdot
.59942 .80582 Mdot
.38215 .45657 Mdot
.6635 .43142 Mdot
.52749 .59667 Mdot
.21908 .52812 Mdot
.34087 .49185 Mdot
.54212 .44871 Mdot
.34454 .57409 Mdot
.46482 .30369 Mdot
.32319 .55064 Mdot
.54363 .59164 Mdot
.46485 .29024 Mdot
.32469 .63221 Mdot
.53907 .56742 Mdot
.60101 .59735 Mdot
.62636 .44881 Mdot
.46739 .32625 Mdot
.73087 .34348 Mdot
.50465 .34451 Mdot
.45338 .34217 Mdot
.60909 .40987 Mdot
.56475 .58652 Mdot
.34818 .4908 Mdot
.37533 .45089 Mdot
.52667 .64711 Mdot
.2333 .33053 Mdot
.64917 .40346 Mdot
.36641 .67602 Mdot
.75488 .30162 Mdot
.63168 .61859 Mdot
.3474 .53458 Mdot
.69424 .34772 Mdot
.44932 .31047 Mdot
.55242 .62072 Mdot
.66335 .38982 Mdot
.32741 .54241 Mdot
.32079 .50632 Mdot
.51476 .60996 Mdot
.47159 .31504 Mdot
.34356 .62406 Mdot
.31318 .50345 Mdot
.23281 .55776 Mdot
.53456 .61802 Mdot
.26633 .35964 Mdot
.32028 .48486 Mdot
.66122 .80333 Mdot
.2653 .51487 Mdot
.64889 .43093 Mdot
.59635 .61345 Mdot
.63612 .44788 Mdot
.33927 .64986 Mdot
.31093 .48513 Mdot
.47194 .31717 Mdot
.63109 .60346 Mdot
.5289 .16181 Mdot
.36951 .446 Mdot
.67205 .43229 Mdot
.6051 .58657 Mdot
.61046 .52376 Mdot
.54583 .58579 Mdot
.62672 .49103 Mdot
.36083 .68195 Mdot
.50108 .33246 Mdot
.4792 .34108 Mdot
.57741 .58322 Mdot
.34471 .63031 Mdot
.34272 .51745 Mdot
.34665 .47614 Mdot
.38721 .85395 Mdot
.35774 .51544 Mdot
.4574 .7219 Mdot
.53879 .6008 Mdot
.35341 .51872 Mdot
.71029 .30737 Mdot
.48451 .33582 Mdot
.51676 .5774 Mdot
.36839 .4875 Mdot
.41121 .23464 Mdot
.3957 .636 Mdot
.56954 .61109 Mdot
.486 .59047 Mdot
.47621 .34493 Mdot
.42763 .7701 Mdot
.37268 .43614 Mdot
.51232 .5831 Mdot
.51794 .3128 Mdot
.20539 .52925 Mdot
.55467 .19032 Mdot
.64025 .44364 Mdot
.33387 .45917 Mdot
.47907 .30193 Mdot
.53517 .52478 Mdot
.31311 .65284 Mdot
.34727 .44792 Mdot
.33075 .48124 Mdot
.58919 .60039 Mdot
.58365 .64609 Mdot
.63473 .60124 Mdot
.67212 .42846 Mdot
.50733 .33506 Mdot
.52961 .56916 Mdot
.5462 .29425 Mdot
.53286 .55344 Mdot
.49125 .34823 Mdot
.90919 .52214 Mdot
.49937 .59121 Mdot
.54787 .58633 Mdot
.58842 .76531 Mdot
.64699 .44799 Mdot
.63047 .44816 Mdot
.35116 .23469 Mdot
.53923 .60134 Mdot
.27645 .53636 Mdot
.6349 .44349 Mdot
.65391 .40393 Mdot
.29803 .42235 Mdot
.57704 .57033 Mdot
.42112 .78263 Mdot
.45635 .32696 Mdot
.45722 .34148 Mdot
.64918 .39781 Mdot
.55002 .52216 Mdot
.44997 .31571 Mdot
.75726 .5153 Mdot
.36779 .46187 Mdot
.20841 .39127 Mdot
.66889 .41514 Mdot
.46648 .39999 Mdot
.49165 .33239 Mdot
.81039 .63095 Mdot
.40771 .45275 Mdot
.55566 .55315 Mdot
.54156 .61019 Mdot
.3211 .6345 Mdot
.51653 .63819 Mdot
.37483 .4783 Mdot
.48404 .30618 Mdot
.62411 .74831 Mdot
.64519 .44141 Mdot
.54218 .5768 Mdot
.56412 .46843 Mdot
.63907 .30033 Mdot
.37642 .32183 Mdot
.64182 .41076 Mdot
.64003 .43129 Mdot
.36323 .44215 Mdot
.32188 .48608 Mdot
.56716 .59508 Mdot
.45748 .31703 Mdot
.68135 .40295 Mdot
.49265 .34562 Mdot
.35208 .4558 Mdot
.34718 .49831 Mdot
.39213 .4383 Mdot
.52722 .54687 Mdot
.33691 .51753 Mdot
.22119 .56241 Mdot
.54291 .27969 Mdot
.6826 .38581 Mdot
.58066 .17417 Mdot
.63475 .28229 Mdot
.45686 .66385 Mdot
.30887 .63928 Mdot
.37636 .46896 Mdot
.50921 .30707 Mdot
.57962 .60232 Mdot
.552 .60859 Mdot
.3971 .40875 Mdot
.47982 .28921 Mdot
.34208 .65675 Mdot
.47894 .28793 Mdot
.31668 .65959 Mdot
.34238 .53394 Mdot
.60692 .60723 Mdot
.53548 .63537 Mdot
.48621 .30457 Mdot
.34531 .50714 Mdot
.33527 .49314 Mdot
.30249 .66674 Mdot
.4073 .60379 Mdot
.34908 .46283 Mdot
.66818 .4148 Mdot
.74587 .58238 Mdot
.40251 .4114 Mdot
.53702 .58625 Mdot
.38183 .68081 Mdot
.74375 .46743 Mdot
.50836 .60213 Mdot
.40911 .39099 Mdot
.24603 .70556 Mdot
.52337 .58431 Mdot
.20348 .65922 Mdot
.40203 .39216 Mdot
.65136 .44837 Mdot
.33773 .46215 Mdot
.37525 .47969 Mdot
.49534 .54965 Mdot
.33696 .68735 Mdot
.54275 .65445 Mdot
.63377 .44572 Mdot
.61581 .44849 Mdot
.43281 .20868 Mdot
.5901 .80434 Mdot
.30295 .66057 Mdot
.32744 .66691 Mdot
.3528 .47399 Mdot
.42786 .82693 Mdot
.61423 .57175 Mdot
.33753 .66504 Mdot
.57436 .74421 Mdot
.58138 .61437 Mdot
.43021 .71921 Mdot
.41267 .46063 Mdot
.64008 .40085 Mdot
.63724 .56809 Mdot
.34658 .4836 Mdot
.66776 .43685 Mdot
.52097 .24629 Mdot
.57089 .64772 Mdot
.6484 .44299 Mdot
.48488 .34971 Mdot
.35186 .27974 Mdot
.61791 .42971 Mdot
.3764 .68298 Mdot
.45948 .31746 Mdot
.30024 .37356 Mdot
.55111 .74938 Mdot
.43297 .12737 Mdot
.47612 .30395 Mdot
.36268 .48009 Mdot
.37427 .45096 Mdot
.34913 .47327 Mdot
.66002 .44633 Mdot
.32719 .53057 Mdot
.67466 .42145 Mdot
.48014 .80953 Mdot
.40793 .60495 Mdot
.33056 .66967 Mdot
.5263 .37065 Mdot
.638 .42431 Mdot
.26092 .32404 Mdot
.49252 .14271 Mdot
.54888 .62363 Mdot
.51228 .33421 Mdot
.3136 .6698 Mdot
.61625 .83225 Mdot
.32661 .63314 Mdot
.36453 .43181 Mdot
.19226 .41506 Mdot
.54928 .57605 Mdot
.74135 .6499 Mdot
.30698 .64818 Mdot
.63208 .41082 Mdot
.57484 .58246 Mdot
.40196 .35878 Mdot
.3195 .64266 Mdot
.33892 .62304 Mdot
.5715 .59463 Mdot
.62058 .4142 Mdot
.34544 .49705 Mdot
.50759 .3005 Mdot
.30558 .67798 Mdot
.47632 .59589 Mdot
.51915 .63849 Mdot
.56263 .64718 Mdot
.53568 .42583 Mdot
.55333 .72785 Mdot
.48198 .30671 Mdot
.50295 .78867 Mdot
.32153 .4881 Mdot
.27505 .41216 Mdot
.36208 .23201 Mdot
.49639 .38553 Mdot
.38486 .44704 Mdot
.38283 .45781 Mdot
.57012 .60572 Mdot
.55419 .72888 Mdot
.19322 .4841 Mdot
.5331 .29914 Mdot
.40045 .41463 Mdot
.34268 .48148 Mdot
.6194 .45757 Mdot
.43816 .2012 Mdot
.53307 .65911 Mdot
.44427 .32176 Mdot
.34344 .46605 Mdot
.77873 .62146 Mdot
.32392 .64812 Mdot
.23503 .35655 Mdot
.60395 .5901 Mdot
.53503 .56122 Mdot
.48582 .31463 Mdot
.47201 .35168 Mdot
.41523 .34237 Mdot
.41491 .21039 Mdot
.36588 .75332 Mdot
.6642 .27343 Mdot
.77966 .61226 Mdot
.62459 .46397 Mdot
.64804 .3857 Mdot
.41251 .38065 Mdot
.49208 .35307 Mdot
.52509 .59372 Mdot
.67934 .4003 Mdot
.36422 .32397 Mdot
.61487 .37906 Mdot
.44422 .7248 Mdot
.26338 .54595 Mdot
.5899 .62747 Mdot
.65676 .39227 Mdot
.66024 .44229 Mdot
.68517 .40332 Mdot
.40696 .38859 Mdot
.55868 .58871 Mdot
.5722 .56137 Mdot
.52604 .56525 Mdot
.49282 .6526 Mdot
.53796 .6232 Mdot
.54088 .32545 Mdot
.51156 .45872 Mdot
.65672 .74168 Mdot
.50698 .58639 Mdot
.45292 .33087 Mdot
.55387 .64878 Mdot
.34561 .63019 Mdot
.58287 .60258 Mdot
.44523 .71966 Mdot
.48401 .32856 Mdot
.56385 .49568 Mdot
.65651 .26694 Mdot
.60152 .5872 Mdot
.35214 .6286 Mdot
.49315 .69022 Mdot
.73083 .35706 Mdot
.38314 .60398 Mdot
.66799 .41336 Mdot
.37563 .4569 Mdot
.49191 .29392 Mdot
.3509 .48749 Mdot
.51243 .57034 Mdot
.41205 .38942 Mdot
.58348 .34347 Mdot
.46281 .4015 Mdot
.5227 .60805 Mdot
.61922 .57091 Mdot
.66266 .40708 Mdot
.35694 .49375 Mdot
.6109 .46348 Mdot
.5316 .60301 Mdot
.33504 .64873 Mdot
.31732 .64696 Mdot
.48843 .23643 Mdot
.80732 .58566 Mdot
.61127 .23021 Mdot
.48593 .31262 Mdot
.32763 .50142 Mdot
.30212 .64098 Mdot
.47385 .63007 Mdot
.44844 .34473 Mdot
.46098 .30105 Mdot
.46464 .32218 Mdot
.56543 .63857 Mdot
.37748 .47087 Mdot
.65608 .73206 Mdot
.37347 .48092 Mdot
.59995 .58863 Mdot
.32531 .48893 Mdot
.38841 .44761 Mdot
.31679 .63906 Mdot
.49814 .30305 Mdot
.34817 .45775 Mdot
.54957 .63159 Mdot
.62774 .43529 Mdot
.41998 .57476 Mdot
.41637 .66392 Mdot
.62427 .79111 Mdot
.64146 .78146 Mdot
.6199 .40251 Mdot
.79521 .63805 Mdot
.4502 .29348 Mdot
.72654 .46763 Mdot
.33248 .42647 Mdot
.51634 .62435 Mdot
.28426 .27103 Mdot
.37168 .43353 Mdot
.3576 .49417 Mdot
.56669 .62072 Mdot
.32606 .53583 Mdot
.54362 .57952 Mdot
.33276 .47199 Mdot
.37553 .60755 Mdot
.54712 .66929 Mdot
.34285 .51435 Mdot
.56154 .53172 Mdot
.58557 .57644 Mdot
.64059 .3992 Mdot
.33178 .46662 Mdot
.52215 .55941 Mdot
.52899 .85826 Mdot
.48248 .35276 Mdot
.40793 .39083 Mdot
.31501 .71196 Mdot
.48087 .30142 Mdot
.65018 .43816 Mdot
.49991 .61843 Mdot
.33586 .6305 Mdot
.63075 .42052 Mdot
.37777 .64864 Mdot
.30623 .65399 Mdot
.27676 .29109 Mdot
.66676 .40694 Mdot
.40101 .41119 Mdot
.31769 .63452 Mdot
.61946 .59728 Mdot
.3214 .47776 Mdot
.42583 .60215 Mdot
.38079 .45795 Mdot
.55318 .59658 Mdot
.39492 .36621 Mdot
.48846 .35227 Mdot
.55609 .56028 Mdot
.31056 .51431 Mdot
.40167 .3875 Mdot
.57137 .63575 Mdot
.57689 .60724 Mdot
.48536 .20089 Mdot
.23282 .39828 Mdot
.34768 .64499 Mdot
.63661 .45611 Mdot
.55344 .62679 Mdot
.31839 .63075 Mdot
.25978 .60845 Mdot
.55362 .64549 Mdot
.67446 .44177 Mdot
.58082 .68859 Mdot
.31522 .50425 Mdot
.50073 .30977 Mdot
.34969 .44105 Mdot
.3304 .62305 Mdot
.14156 .44562 Mdot
.394 .43659 Mdot
.55654 .53471 Mdot
.51774 .58689 Mdot
.38155 .33331 Mdot
.66552 .43766 Mdot
.37009 .75267 Mdot
.54302 .60686 Mdot
.52691 .69321 Mdot
.54254 .56626 Mdot
.2708 .50749 Mdot
.65041 .40458 Mdot
.54892 .59092 Mdot
.53773 .48912 Mdot
.60123 .562 Mdot
.34353 .62254 Mdot
.56453 .77565 Mdot
.53823 .64377 Mdot
.83597 .33439 Mdot
.35252 .52673 Mdot
.34068 .51636 Mdot
.39468 .34623 Mdot
.31349 .77139 Mdot
.5964 .21862 Mdot
.67531 .42202 Mdot
.63557 .34662 Mdot
.34792 .49279 Mdot
.64922 .2459 Mdot
.78364 .66474 Mdot
.58782 .57941 Mdot
.57875 .63882 Mdot
.36449 .43183 Mdot
.35837 .5115 Mdot
.40971 .40316 Mdot
.50891 .57347 Mdot
.62306 .59533 Mdot
.32962 .52185 Mdot
.54164 .63202 Mdot
.56799 .68548 Mdot
.51034 .30413 Mdot
.61781 .4131 Mdot
.49654 .3329 Mdot
.49026 .29664 Mdot
.71323 .52936 Mdot
.41356 .21714 Mdot
.49237 .34805 Mdot
.44789 .29855 Mdot
.43173 .71276 Mdot
.63752 .61395 Mdot
.32101 .62295 Mdot
.73597 .70745 Mdot
.35338 .46761 Mdot
.55924 .58625 Mdot
.62717 .39005 Mdot
.71034 .50409 Mdot
.39988 .49508 Mdot
.18629 .45554 Mdot
.52858 .60085 Mdot
.34354 .48554 Mdot
.39621 .39593 Mdot
.56355 .67459 Mdot
.28146 .41549 Mdot
.53985 .55622 Mdot
.33956 .4545 Mdot
.7289 .63197 Mdot
.57209 .47753 Mdot
.26381 .39534 Mdot
.59218 .43674 Mdot
.52931 .57694 Mdot
.66934 .42084 Mdot
.49689 .32519 Mdot
.33581 .62621 Mdot
.34671 .64393 Mdot
.57497 .5921 Mdot
.55844 .71344 Mdot
.4181 .45251 Mdot
.5874 .57629 Mdot
.58703 .59429 Mdot
.40097 .39292 Mdot
.58644 .59153 Mdot
.51834 .5843 Mdot
.5216 .57035 Mdot
.59039 .55727 Mdot
.45313 .34105 Mdot
.56455 .47381 Mdot
.52382 .54738 Mdot
.5588 .68101 Mdot
.50785 .29596 Mdot
.65844 .33963 Mdot
.5019 .30362 Mdot
.82855 .54065 Mdot
.48658 .34076 Mdot
.34516 .65674 Mdot
.38704 .37559 Mdot
.58971 .69579 Mdot
.67044 .38601 Mdot
.46561 .35747 Mdot
.32967 .65893 Mdot
.49211 .31193 Mdot
.32259 .4964 Mdot
.70318 .25034 Mdot
.6177 .37756 Mdot
.35725 .73468 Mdot
.47346 .2442 Mdot
.27869 .35503 Mdot
.37019 .44069 Mdot
.64857 .4012 Mdot
.78209 .56012 Mdot
.52562 .55923 Mdot
.31453 .63774 Mdot
.57 .59839 Mdot
.45261 .34224 Mdot
.34746 .47895 Mdot
.54361 .7909 Mdot
.3434 .6347 Mdot
.51037 .18491 Mdot
.34524 .4739 Mdot
.54713 .54805 Mdot
.44461 .32285 Mdot
.56843 .16783 Mdot
.49897 .3331 Mdot
.40528 .61577 Mdot
.6815 .44135 Mdot
.6481 .64393 Mdot
.64389 .42653 Mdot
.40695 .42119 Mdot
.78264 .31118 Mdot
.70177 .75123 Mdot
.62279 .42545 Mdot
.24206 .44499 Mdot
.57766 .63783 Mdot
.55993 .64795 Mdot
.57458 .48727 Mdot
.66357 .44904 Mdot
.54535 .62536 Mdot
.39522 .40033 Mdot
.5519 .27268 Mdot
.2398 .47962 Mdot
.37393 .46178 Mdot
.54197 .58576 Mdot
.51163 .30105 Mdot
.47504 .28879 Mdot
.37965 .46892 Mdot
.50551 .30811 Mdot
.57014 .56087 Mdot
.64044 .42492 Mdot
.44053 .39755 Mdot
.33766 .63904 Mdot
.54019 .83548 Mdot
.30799 .62937 Mdot
.38413 .44506 Mdot
.61051 .63461 Mdot
.34713 .49898 Mdot
.15197 .63243 Mdot
.55906 .55562 Mdot
.64188 .4452 Mdot
.57457 .62264 Mdot
.53233 .57128 Mdot
.5699 .64686 Mdot
.32528 .51978 Mdot
.30264 .7282 Mdot
.54377 .63247 Mdot
.47084 .31808 Mdot
.67253 .74924 Mdot
.55557 .65018 Mdot
.37049 .60072 Mdot
.49671 .75054 Mdot
.28265 .33648 Mdot
.66691 .38096 Mdot
.35344 .49994 Mdot
.63932 .43876 Mdot
.59758 .4128 Mdot
.65056 .43821 Mdot
.6867 .72018 Mdot
.77047 .57962 Mdot
.24037 .69011 Mdot
.65069 .67511 Mdot
.68877 .49878 Mdot
.64564 .4577 Mdot
.24994 .63484 Mdot
.66277 .38731 Mdot
.66711 .43246 Mdot
.74979 .78782 Mdot
.65391 .38325 Mdot
.53956 .59364 Mdot
.56177 .65938 Mdot
.60967 .30463 Mdot
.41244 .71719 Mdot
.58139 .58776 Mdot
.56017 .62571 Mdot
.3289 .62755 Mdot
.53973 .71141 Mdot
.4135 .3885 Mdot
.28392 .28637 Mdot
.66707 .30363 Mdot
.57145 .59773 Mdot
.55353 .62858 Mdot
.61779 .58305 Mdot
.70723 .21028 Mdot
.73098 .51096 Mdot
.63813 .45961 Mdot
.57804 .51593 Mdot
.60917 .8138 Mdot
.57648 .5601 Mdot
.54838 .64195 Mdot
.58822 .62705 Mdot
.34792 .49166 Mdot
.65458 .45947 Mdot
.58165 .51772 Mdot
.28809 .30991 Mdot
.6052 .59992 Mdot
.51112 .38191 Mdot
.34156 .76604 Mdot
.54395 .59298 Mdot
.68928 .40338 Mdot
.58556 .61699 Mdot
.6679 .40517 Mdot
.63499 .39888 Mdot
.61608 .59809 Mdot
.74216 .67364 Mdot
.68121 .4375 Mdot
.60201 .59374 Mdot
.33932 .50905 Mdot
.72579 .73932 Mdot
.5518 .59863 Mdot
.34991 .65765 Mdot
.54162 .60795 Mdot
.35631 .63775 Mdot
.59128 .59205 Mdot
.37291 .48141 Mdot
.75528 .43906 Mdot
.35605 .47175 Mdot
.388 .78666 Mdot
.34224 .53011 Mdot
.48291 .20069 Mdot
.67125 .44255 Mdot
.39999 .38614 Mdot
.16582 .4552 Mdot
.4043 .39414 Mdot
.53577 .46966 Mdot
.48079 .49946 Mdot
.45726 .31484 Mdot
.62277 .44342 Mdot
.48045 .78225 Mdot
.37223 .32886 Mdot
.37411 .37565 Mdot
.38458 .43747 Mdot
.16357 .40886 Mdot
.19421 .38863 Mdot
.55257 .63507 Mdot
.71765 .67982 Mdot
.67775 .6132 Mdot
.55196 .64442 Mdot
.49669 .59678 Mdot
.30847 .51094 Mdot
.51772 .59292 Mdot
.54978 .41453 Mdot
.36801 .44888 Mdot
.32523 .66105 Mdot
.66577 .42938 Mdot
.35488 .65453 Mdot
.37395 .34401 Mdot
.48204 .50228 Mdot
.33641 .47008 Mdot
.5929 .55482 Mdot
.57032 .62569 Mdot
.65174 .39542 Mdot
.63653 .47309 Mdot
.62443 .40462 Mdot
.31184 .67005 Mdot
.36388 .45304 Mdot
.73183 .49702 Mdot
.55953 .61906 Mdot
.64073 .41839 Mdot
.46724 .25524 Mdot
.55478 .62318 Mdot
.49509 .3101 Mdot
.59302 .62683 Mdot
.62206 .42908 Mdot
.58657 .59123 Mdot
.63951 .42645 Mdot
.36899 .46172 Mdot
.58103 .56178 Mdot
.5677 .61672 Mdot
.56359 .17113 Mdot
.343 .65417 Mdot
.66899 .44382 Mdot
.45443 .45366 Mdot
.53625 .54955 Mdot
.32916 .34862 Mdot
.52788 .58549 Mdot
.63873 .35934 Mdot
.56654 .53545 Mdot
.40171 .39039 Mdot
.52705 .66017 Mdot
.55159 .59735 Mdot
.48687 .51465 Mdot
.68108 .65779 Mdot
.62334 .47079 Mdot
.44664 .32441 Mdot
.69103 .41221 Mdot
.3265 .55623 Mdot
.38921 .42068 Mdot
.31685 .53228 Mdot
.39181 .73065 Mdot
.61437 .60401 Mdot
.55068 .57733 Mdot
.51406 .3421 Mdot
.32229 .66489 Mdot
.64037 .41213 Mdot
.31922 .6604 Mdot
.3257 .25738 Mdot
.30932 .66492 Mdot
.37519 .47904 Mdot
.2637 .51758 Mdot
.75311 .48523 Mdot
.32745 .62812 Mdot
.62133 .40804 Mdot
.25857 .54692 Mdot
.51304 .61123 Mdot
.33394 .69568 Mdot
.33396 .64757 Mdot
.16102 .39669 Mdot
.52034 .59958 Mdot
.54178 .46078 Mdot
.5038 .33431 Mdot
.31344 .64865 Mdot
.46908 .32975 Mdot
.57954 .59024 Mdot
.31465 .32681 Mdot
.67506 .42835 Mdot
.49214 .28392 Mdot
.50464 .56786 Mdot
.3183 .67067 Mdot
.33948 .47095 Mdot
.51603 .36038 Mdot
.45263 .32824 Mdot
.76492 .39182 Mdot
.5452 .78318 Mdot
.36529 .45235 Mdot
.21081 .46536 Mdot
.46282 .33331 Mdot
.54516 .6431 Mdot
.54545 .69717 Mdot
.55783 .55336 Mdot
.39799 .35817 Mdot
.35321 .50121 Mdot
.5709 .3005 Mdot
.57143 .62729 Mdot
.52254 .59252 Mdot
.70095 .41556 Mdot
.36875 .45632 Mdot
.65763 .4192 Mdot
.68284 .39755 Mdot
.37032 .45977 Mdot
.64957 .42914 Mdot
.30864 .64625 Mdot
.55939 .26227 Mdot
.46294 .33523 Mdot
.47447 .31999 Mdot
.34385 .48003 Mdot
.33423 .52163 Mdot
.3494 .49746 Mdot
.59375 .62594 Mdot
.64451 .40776 Mdot
.59563 .61051 Mdot
.57314 .64415 Mdot
.59513 .46104 Mdot
.64174 .38241 Mdot
.58591 .62384 Mdot
.27502 .38612 Mdot
.36296 .67196 Mdot
.33416 .51444 Mdot
.49826 .34232 Mdot
.69708 .28959 Mdot
.52318 .30966 Mdot
.54017 .58367 Mdot
.40501 .24286 Mdot
.62221 .41964 Mdot
.32312 .63405 Mdot
.36509 .64181 Mdot
.33447 .63244 Mdot
.48979 .36331 Mdot
.68365 .41424 Mdot
.2826 .28857 Mdot
.54357 .58253 Mdot
.53587 .42367 Mdot
.49352 .78461 Mdot
.33087 .26226 Mdot
.49485 .34642 Mdot
.55558 .62541 Mdot
.40544 .3992 Mdot
.78148 .52698 Mdot
.53874 .55845 Mdot
.51603 .57174 Mdot
.3098 .43586 Mdot
.58245 .68373 Mdot
.68081 .44073 Mdot
.41321 .20588 Mdot
.56131 .65719 Mdot
.59809 .47854 Mdot
.41428 .84849 Mdot
.53566 .57957 Mdot
.53198 .60926 Mdot
.55804 .60572 Mdot
.57993 .61586 Mdot
.69279 .41078 Mdot
.43287 .76311 Mdot
.4445 .32768 Mdot
.5179 .43462 Mdot
.46014 .33428 Mdot
.34396 .45034 Mdot
.55746 .45163 Mdot
.61447 .43404 Mdot
.32202 .63357 Mdot
.78398 .43731 Mdot
.36773 .21838 Mdot
.36526 .44034 Mdot
.75488 .54 Mdot
.33893 .64478 Mdot
.52074 .63725 Mdot
.35676 .65608 Mdot
.36453 .49825 Mdot
.46372 .31633 Mdot
.55981 .66453 Mdot
.63631 .3905 Mdot
.61933 .43287 Mdot
.54765 .62404 Mdot
.63213 .8089 Mdot
.49665 .3094 Mdot
.49771 .27539 Mdot
.57121 .6383 Mdot
.5156 .57153 Mdot
.65952 .42266 Mdot
.33471 .5035 Mdot
.20444 .57049 Mdot
.33582 .66094 Mdot
.55958 .54511 Mdot
.5818 .61151 Mdot
.40951 .21509 Mdot
.48377 .29792 Mdot
.39578 .42594 Mdot
.56534 .63751 Mdot
.47831 .23421 Mdot
.56706 .6369 Mdot
.55611 .67444 Mdot
.34204 .50348 Mdot
.57695 .52996 Mdot
.53859 .63487 Mdot
.55591 .51182 Mdot
.46501 .33209 Mdot
.64947 .44434 Mdot
.69748 .41033 Mdot
.41012 .39823 Mdot
.49556 .31176 Mdot
.58543 .62183 Mdot
.48582 .2997 Mdot
.55043 .64693 Mdot
.54089 .62865 Mdot
.49187 .3478 Mdot
.65734 .41977 Mdot
.60842 .343 Mdot
.5623 .46955 Mdot
.57798 .62052 Mdot
.53971 .66359 Mdot
.40328 .72939 Mdot
.16397 .56788 Mdot
.52901 .59746 Mdot
.62124 .43133 Mdot
.56223 .6203 Mdot
.47762 .33228 Mdot
.31013 .66319 Mdot
.62534 .43336 Mdot
.33273 .49504 Mdot
.37404 .43619 Mdot
.65342 .26386 Mdot
.38312 .45926 Mdot
.51156 .61978 Mdot
.67833 .36395 Mdot
.62249 .38933 Mdot
.47052 .85128 Mdot
.37251 .45669 Mdot
.33568 .61951 Mdot
.57751 .6019 Mdot
.42769 .24127 Mdot
.50753 .34991 Mdot
.83116 .32151 Mdot
.27823 .29162 Mdot
.30704 .62892 Mdot
.17929 .45695 Mdot
.40099 .40678 Mdot
.52832 .62648 Mdot
.3384 .62639 Mdot
.35503 .44684 Mdot
.52212 .63321 Mdot
.48568 .59776 Mdot
.35403 .74296 Mdot
.32096 .4714 Mdot
.49316 .30223 Mdot
.31443 .52129 Mdot
.3461 .67665 Mdot
.37477 .47959 Mdot
.61557 .42787 Mdot
.55213 .59246 Mdot
.60863 .54757 Mdot
.33232 .50174 Mdot
.37095 .48735 Mdot
.59293 .6239 Mdot
.62913 .44607 Mdot
.32133 .53595 Mdot
.57215 .58947 Mdot
.71618 .47766 Mdot
.59365 .44085 Mdot
.35588 .45875 Mdot
.52074 .58157 Mdot
.63354 .63912 Mdot
.33851 .48544 Mdot
.33195 .51582 Mdot
.54601 .62587 Mdot
.31055 .6412 Mdot
.60722 .59838 Mdot
.48811 .3422 Mdot
.30932 .73678 Mdot
.47632 .33005 Mdot
.32063 .56456 Mdot
.60671 .65158 Mdot
.30314 .34532 Mdot
.61354 .41703 Mdot
.35014 .67404 Mdot
.70392 .28707 Mdot
.5114 .57867 Mdot
.79081 .63551 Mdot
.47941 .40095 Mdot
.59345 .83265 Mdot
.7902 .35843 Mdot
.33018 .64838 Mdot
.49495 .31668 Mdot
.53265 .60946 Mdot
.51411 .33331 Mdot
.34653 .63487 Mdot
.50318 .79413 Mdot
.51992 .5804 Mdot
.65311 .40457 Mdot
.60374 .60479 Mdot
.66835 .41324 Mdot
.55272 .622 Mdot
.57759 .68367 Mdot
.37703 .40529 Mdot
.3998 .63885 Mdot
.5151 .62082 Mdot
.69809 .24353 Mdot
.41503 .48216 Mdot
.33649 .65306 Mdot
.5999 .60176 Mdot
.39184 .42256 Mdot
.46804 .29183 Mdot
.46194 .63699 Mdot
.34695 .49598 Mdot
.51122 .32993 Mdot
.65613 .43085 Mdot
.37183 .46127 Mdot
.388 .43093 Mdot
.54924 .52046 Mdot
.35363 .6338 Mdot
.46075 .31013 Mdot
.54843 .59629 Mdot
.52097 .59825 Mdot
.22235 .48285 Mdot
.38573 .51961 Mdot
.69726 .43527 Mdot
.51665 .16711 Mdot
.68288 .38379 Mdot
.33816 .66334 Mdot
.34384 .50284 Mdot
.52966 .59437 Mdot
.5605 .56178 Mdot
.39623 .38551 Mdot
.66694 .4442 Mdot
.33607 .45495 Mdot
.72939 .53373 Mdot
.35918 .49966 Mdot
.45475 .75031 Mdot
.6347 .44466 Mdot
.45028 .74998 Mdot
.34804 .67445 Mdot
.79383 .6048 Mdot
.4403 .68189 Mdot
.50552 .33189 Mdot
.45965 .75241 Mdot
.6305 .41222 Mdot
.56014 .6328 Mdot
.39889 .41176 Mdot
.38933 .44328 Mdot
.66294 .42731 Mdot
.36078 .4353 Mdot
.31479 .64739 Mdot
.53141 .61314 Mdot
.25496 .35059 Mdot
.61404 .27417 Mdot
.32706 .50621 Mdot
.5351 .67374 Mdot
.46774 .32467 Mdot
.5314 .62635 Mdot
.34835 .66156 Mdot
.46952 .30708 Mdot
.36328 .51583 Mdot
.56006 .2813 Mdot
.57662 .58981 Mdot
.44401 .21616 Mdot
.48709 .30558 Mdot
.18572 .50777 Mdot
.56767 .58984 Mdot
.46293 .33315 Mdot
.60841 .66455 Mdot
.32403 .27702 Mdot
.46419 .42349 Mdot
.77677 .67859 Mdot
.32359 .46594 Mdot
.36783 .4313 Mdot
.34795 .29254 Mdot
.3583 .3802 Mdot
.51514 .32228 Mdot
.37446 .47987 Mdot
.5179 .73305 Mdot
.46728 .32924 Mdot
.5779 .64025 Mdot
.53064 .58344 Mdot
.7119 .52217 Mdot
.49167 .418 Mdot
.37074 .4896 Mdot
.57953 .22268 Mdot
.53517 .55084 Mdot
.51456 .54387 Mdot
.56054 .56569 Mdot
.61857 .45187 Mdot
.46749 .30203 Mdot
.60608 .18648 Mdot
.49935 .31688 Mdot
.22956 .37523 Mdot
.35298 .46869 Mdot
.33813 .52285 Mdot
.54205 .59004 Mdot
.2793 .36422 Mdot
.57143 .73294 Mdot
.57592 .56391 Mdot
.29797 .37226 Mdot
.55832 .78422 Mdot
.50502 .56426 Mdot
.68148 .4425 Mdot
.57699 .65645 Mdot
.60365 .43218 Mdot
.45543 .32809 Mdot
.32527 .64464 Mdot
.32569 .68978 Mdot
.46154 .31097 Mdot
.552 .57636 Mdot
.3059 .37383 Mdot
.53857 .56372 Mdot
.55807 .63646 Mdot
.22963 .35825 Mdot
.30218 .63932 Mdot
.35388 .4921 Mdot
.34601 .6401 Mdot
.66777 .43255 Mdot
.91321 .56222 Mdot
.31865 .664 Mdot
.60147 .70859 Mdot
.42703 .79123 Mdot
.45627 .75317 Mdot
.62006 .4358 Mdot
.31697 .68053 Mdot
.50018 .31046 Mdot
.6359 .82857 Mdot
.1713 .59026 Mdot
.51625 .29283 Mdot
.56901 .58195 Mdot
.61258 .43471 Mdot
.62245 .40108 Mdot
.48126 .28155 Mdot
.63294 .40264 Mdot
.62308 .58443 Mdot
.57057 .631 Mdot
.5143 .32518 Mdot
.61419 .29263 Mdot
.4519 .32654 Mdot
.54377 .25267 Mdot
.60121 .60466 Mdot
.63057 .44161 Mdot
.59229 .64553 Mdot
.64568 .36854 Mdot
.39823 .42601 Mdot
.52671 .64102 Mdot
.3162 .64156 Mdot
.52627 .41271 Mdot
.35691 .45989 Mdot
.4031 .24674 Mdot
.65414 .39622 Mdot
.42822 .33059 Mdot
.63886 .39932 Mdot
.61897 .44597 Mdot
.4902 .2962 Mdot
.67917 .40859 Mdot
.53131 .60982 Mdot
.25414 .41992 Mdot
.6684 .40148 Mdot
.48654 .32121 Mdot
.32723 .63829 Mdot
.65189 .42593 Mdot
.30822 .50766 Mdot
.57357 .61199 Mdot
.32619 .48025 Mdot
.37125 .4048 Mdot
.62886 .44794 Mdot
.31248 .67721 Mdot
.35119 .50652 Mdot
.35015 .63129 Mdot
.53552 .80579 Mdot
.48886 .35479 Mdot
.19003 .45626 Mdot
.63491 .61829 Mdot
.63479 .39001 Mdot
.37235 .40656 Mdot
.53177 .59462 Mdot
.57497 .61122 Mdot
.33409 .68275 Mdot
.62291 .40011 Mdot
.69842 .75915 Mdot
.65759 .35272 Mdot
.56393 .2719 Mdot
.47749 .35826 Mdot
.54202 .18556 Mdot
.54757 .29425 Mdot
.41781 .81518 Mdot
.54636 .52674 Mdot
.40049 .40731 Mdot
.54413 .57298 Mdot
.71341 .29801 Mdot
.31541 .6706 Mdot
.21589 .61194 Mdot
.61513 .58966 Mdot
.35841 .47998 Mdot
.56437 .60258 Mdot
.44596 .57646 Mdot
.58125 .65908 Mdot
.30904 .64048 Mdot
.52898 .37307 Mdot
.67266 .38783 Mdot
.33859 .64077 Mdot
.37374 .44014 Mdot
.52782 .75396 Mdot
.51988 .62779 Mdot
.5129 .56509 Mdot
.35878 .50252 Mdot
.64868 .40254 Mdot
.3372 .45888 Mdot
.46266 .33482 Mdot
.31979 .65232 Mdot
.57933 .60553 Mdot
.58277 .54456 Mdot
.33044 .35047 Mdot
.46275 .30375 Mdot
.35303 .5081 Mdot
.49941 .33001 Mdot
.40029 .40869 Mdot
.54744 .66608 Mdot
.33507 .52556 Mdot
.52209 .61885 Mdot
.644 .22763 Mdot
.226 .36772 Mdot
.68899 .65834 Mdot
.35959 .48156 Mdot
.46832 .74069 Mdot
.4848 .33032 Mdot
.48999 .33875 Mdot
.64883 .6153 Mdot
.5112 .70589 Mdot
.27218 .54029 Mdot
.77007 .39412 Mdot
.46269 .33584 Mdot
.47658 .32647 Mdot
.33818 .46276 Mdot
.67751 .40947 Mdot
.60587 .42705 Mdot
.37524 .42497 Mdot
.37578 .68848 Mdot
.64039 .41227 Mdot
.77684 .6542 Mdot
.32346 .55329 Mdot
.52955 .52921 Mdot
.40907 .35324 Mdot
.31922 .64595 Mdot
.38629 .67241 Mdot
.44973 .56824 Mdot
.52491 .59809 Mdot
.42215 .20294 Mdot
.33823 .49862 Mdot
.40596 .7594 Mdot
.82845 .53468 Mdot
.51956 .57796 Mdot
.56145 .5873 Mdot
.55311 .57052 Mdot
.29792 .65162 Mdot
.73009 .38906 Mdot
.52324 .60211 Mdot
.36782 .69489 Mdot
.54073 .54702 Mdot
.42511 .64346 Mdot
.34685 .64328 Mdot
.6213 .49608 Mdot
.34377 .43828 Mdot
.29015 .29667 Mdot
.58541 .49551 Mdot
.47057 .33858 Mdot
.38215 .41538 Mdot
.45763 .32666 Mdot
.683 .71716 Mdot
.44165 .68636 Mdot
.68107 .4477 Mdot
.52752 .6028 Mdot
.38329 .44369 Mdot
.62017 .40743 Mdot
.34691 .33305 Mdot
.80279 .73906 Mdot
.45349 .30888 Mdot
.16425 .64054 Mdot
.49451 .33654 Mdot
.395 .432 Mdot
.65997 .42433 Mdot
.76265 .58928 Mdot
.53741 .42311 Mdot
.64932 .42704 Mdot
.5916 .34324 Mdot
.66963 .37439 Mdot
.46903 .74733 Mdot
.63673 .37967 Mdot
.4873 .32464 Mdot
.5113 .3559 Mdot
.51608 .53886 Mdot
.53788 .59752 Mdot
.47723 .50717 Mdot
.6175 .68473 Mdot
.53484 .59712 Mdot
.36808 .44922 Mdot
.17915 .50521 Mdot
.38043 .42032 Mdot
.66173 .38975 Mdot
.44754 .3144 Mdot
.56217 .59053 Mdot
.5757 .62881 Mdot
.52826 .63525 Mdot
.54129 .15918 Mdot
.76342 .66861 Mdot
.54496 .63209 Mdot
.57377 .55124 Mdot
.36731 .46547 Mdot
.32268 .60669 Mdot
.74155 .32005 Mdot
.49006 .71143 Mdot
.54089 .55355 Mdot
.34492 .64668 Mdot
.31645 .62318 Mdot
.51997 .63163 Mdot
.2717 .34199 Mdot
.24929 .42459 Mdot
.54872 .59673 Mdot
.44185 .6612 Mdot
.36973 .34961 Mdot
.37877 .47155 Mdot
.33374 .49792 Mdot
.68751 .40088 Mdot
.38648 .44095 Mdot
.33735 .53427 Mdot
.76926 .5635 Mdot
.41111 .39279 Mdot
.53239 .28699 Mdot
.31195 .67019 Mdot
.55467 .5595 Mdot
.68449 .38273 Mdot
.4004 .37165 Mdot
.45825 .31434 Mdot
.63099 .43003 Mdot
.46547 .29206 Mdot
.31555 .61729 Mdot
.3733 .74125 Mdot
.39055 .44255 Mdot
.46882 .34137 Mdot
.55882 .2799 Mdot
.34557 .6458 Mdot
.50567 .31154 Mdot
.31011 .34686 Mdot
.56289 .65069 Mdot
.78126 .59823 Mdot
.58891 .57441 Mdot
.63125 .81795 Mdot
.50386 .30976 Mdot
.40864 .38593 Mdot
.55058 .58206 Mdot
.34483 .47496 Mdot
.60479 .66179 Mdot
.54159 .55493 Mdot
.3312 .49132 Mdot
.5537 .63465 Mdot
.35245 .65323 Mdot
.59724 .43059 Mdot
.48541 .39377 Mdot
.28764 .2324 Mdot
.3544 .63842 Mdot
.34114 .3348 Mdot
.52871 .5986 Mdot
.54479 .78874 Mdot
.65096 .42475 Mdot
.51634 .57753 Mdot
.63716 .5364 Mdot
.67439 .41375 Mdot
.63804 .43613 Mdot
.58972 .60272 Mdot
.5052 .32889 Mdot
.34766 .4688 Mdot
.34482 .64102 Mdot
.47117 .83867 Mdot
.57122 .57463 Mdot
.56534 .6185 Mdot
.33874 .6432 Mdot
.47606 .3284 Mdot
.57851 .62557 Mdot
.42167 .27896 Mdot
.54587 .85185 Mdot
.46636 .29688 Mdot
.58405 .64202 Mdot
.79816 .49417 Mdot
.66179 .36594 Mdot
.16101 .60862 Mdot
.37272 .62802 Mdot
.3502 .50424 Mdot
.5852 .68323 Mdot
.87911 .42161 Mdot
.32439 .64339 Mdot
.28571 .29323 Mdot
.55294 .63839 Mdot
.55844 .61441 Mdot
.62313 .4128 Mdot
.5916 .61631 Mdot
.66694 .44068 Mdot
.2398 .2838 Mdot
.45359 .178 Mdot
.65731 .40071 Mdot
.64583 .38535 Mdot
.64169 .63044 Mdot
.73598 .31575 Mdot
.66101 .43209 Mdot
.59838 .62889 Mdot
.70545 .73431 Mdot
.5274 .5254 Mdot
.33306 .68351 Mdot
.36175 .40523 Mdot
.63028 .48502 Mdot
.38139 .56302 Mdot
.66949 .34412 Mdot
.57683 .49325 Mdot
.41336 .43927 Mdot
.48642 .3448 Mdot
.52582 .56242 Mdot
.38573 .4531 Mdot
.32128 .53206 Mdot
.58338 .66278 Mdot
.546 .55788 Mdot
.66937 .40863 Mdot
.30044 .64917 Mdot
.48844 .29125 Mdot
.56094 .62544 Mdot
.30723 .50338 Mdot
.32877 .66294 Mdot
.66203 .39201 Mdot
.64511 .64508 Mdot
.31959 .62533 Mdot
.54226 .67121 Mdot
.54481 .61054 Mdot
.58976 .62738 Mdot
.63229 .61553 Mdot
.46976 .35207 Mdot
.38973 .3479 Mdot
.60329 .61702 Mdot
.33159 .25256 Mdot
.40331 .59969 Mdot
.58277 .53659 Mdot
.63646 .40809 Mdot
.49967 .35676 Mdot
.40005 .42103 Mdot
.52545 .76701 Mdot
.57525 .58241 Mdot
.75817 .67308 Mdot
.72878 .51862 Mdot
.39005 .42504 Mdot
.64995 .45663 Mdot
.32544 .63286 Mdot
.56929 .56097 Mdot
.69239 .72827 Mdot
.53327 .58302 Mdot
.63013 .64489 Mdot
.33678 .50974 Mdot
.48596 .34608 Mdot
.58082 .84069 Mdot
.32194 .53185 Mdot
.63874 .43808 Mdot
.78765 .67141 Mdot
.61035 .41335 Mdot
.67768 .39475 Mdot
.72723 .68894 Mdot
.4672 .34974 Mdot
.8712 .40256 Mdot
.1674 .59221 Mdot
.60849 .56865 Mdot
.48415 .33391 Mdot
.66446 .41666 Mdot
.53126 .62548 Mdot
.6294 .38636 Mdot
.68019 .42195 Mdot
.53352 .64699 Mdot
.5506 .61408 Mdot
.55847 .46692 Mdot
.81242 .59211 Mdot
.33232 .631 Mdot
.64686 .44816 Mdot
.67888 .51104 Mdot
.52335 .61107 Mdot
.54396 .58312 Mdot
.36238 .33298 Mdot
.31232 .63666 Mdot
.48912 .51823 Mdot
.56272 .63737 Mdot
.4591 .19064 Mdot
.5502 .66926 Mdot
.69427 .4211 Mdot
.46833 .29619 Mdot
.27377 .33165 Mdot
.39885 .35815 Mdot
.66387 .44687 Mdot
.3359 .6728 Mdot
.69935 .42051 Mdot
.60614 .7035 Mdot
.45964 .34076 Mdot
.62204 .42903 Mdot
.35383 .43781 Mdot
.47444 .31071 Mdot
.50533 .31234 Mdot
.67486 .74817 Mdot
.36299 .48576 Mdot
.31906 .67664 Mdot
.46279 .31907 Mdot
.72656 .46579 Mdot
.49112 .31997 Mdot
.68844 .52073 Mdot
.588 .56828 Mdot
.35868 .71846 Mdot
.55205 .32205 Mdot
.61391 .66918 Mdot
.47605 .35499 Mdot
.34515 .63438 Mdot
.58585 .60748 Mdot
.63096 .40368 Mdot
.31763 .66176 Mdot
.47612 .37701 Mdot
.33266 .51937 Mdot
.64192 .39599 Mdot
.44406 .3288 Mdot
.64432 .44703 Mdot
.4654 .77865 Mdot
.32619 .74429 Mdot
.42856 .26385 Mdot
.53589 .43399 Mdot
.53141 .63672 Mdot
.71292 .34254 Mdot
.52171 .64337 Mdot
.54112 .55856 Mdot
.35533 .45954 Mdot
.39091 .73169 Mdot
.65804 .41959 Mdot
.58316 .84278 Mdot
.47376 .34426 Mdot
.4251 .19443 Mdot
.58605 .42606 Mdot
.51908 .56508 Mdot
.67057 .40496 Mdot
.61393 .40254 Mdot
.67796 .66226 Mdot
.32359 .54422 Mdot
.48852 .60717 Mdot
.52087 .64713 Mdot
.5408 .53145 Mdot
.50383 .31099 Mdot
.38827 .25765 Mdot
.35246 .44328 Mdot
.25255 .7193 Mdot
.33299 .51144 Mdot
.28755 .43724 Mdot
.67824 .40331 Mdot
.31058 .65974 Mdot
.54457 .58558 Mdot
.5862 .4091 Mdot
.65456 .45342 Mdot
.36106 .62474 Mdot
.31496 .64074 Mdot
.35262 .27195 Mdot
.49025 .3491 Mdot
.51504 .61518 Mdot
.52063 .58523 Mdot
.59691 .60502 Mdot
.59544 .5799 Mdot
.45363 .30748 Mdot
.56891 .64326 Mdot
.51618 .30743 Mdot
.72492 .47695 Mdot
.44109 .18736 Mdot
.38998 .41009 Mdot
.4771 .66709 Mdot
.64171 .39053 Mdot
.7264 .45313 Mdot
.51353 .6633 Mdot
.2126 .38746 Mdot
.59005 .79412 Mdot
.50023 .59775 Mdot
.34925 .4505 Mdot
.5175 .70326 Mdot
.36845 .48654 Mdot
.10347 .50276 Mdot
.33109 .36441 Mdot
.78422 .65936 Mdot
.52762 .61601 Mdot
.3645 .33309 Mdot
.5312 .67915 Mdot
.53293 .64987 Mdot
.34897 .3652 Mdot
.55263 .21251 Mdot
.59899 .31708 Mdot
.31778 .62358 Mdot
.57343 .60384 Mdot
.63014 .38133 Mdot
.53007 .61011 Mdot
.54208 .57853 Mdot
.54828 .63954 Mdot
.44362 .31685 Mdot
.56298 .66284 Mdot
.59234 .62904 Mdot
.39861 .52708 Mdot
.43533 .72115 Mdot
.31425 .51676 Mdot
.63317 .68922 Mdot
.32176 .66378 Mdot
.66357 .39926 Mdot
.56976 .39607 Mdot
.5052 .33316 Mdot
.67637 .63999 Mdot
.60035 .61527 Mdot
.55646 .31186 Mdot
.44416 .33064 Mdot
.31753 .65286 Mdot
.40646 .40759 Mdot
.73891 .72534 Mdot
.38296 .44687 Mdot
.41119 .3942 Mdot
.35734 .46105 Mdot
.68074 .47144 Mdot
.67008 .41096 Mdot
.53291 .63926 Mdot
.46586 .32139 Mdot
.34316 .47117 Mdot
.40388 .71729 Mdot
.55819 .5657 Mdot
.36726 .46304 Mdot
.53679 .63996 Mdot
.35685 .7327 Mdot
.21489 .49868 Mdot
.34769 .5252 Mdot
.47479 .36619 Mdot
.47869 .314 Mdot
.30736 .65057 Mdot
.65819 .39394 Mdot
.62444 .41545 Mdot
.47162 .3069 Mdot
.15252 .53924 Mdot
.53764 .55597 Mdot
.52838 .621 Mdot
.33626 .2484 Mdot
.53575 .60672 Mdot
.51207 .7531 Mdot
.41372 .39391 Mdot
.65288 .38978 Mdot
.53584 .63046 Mdot
.57892 .62192 Mdot
.57723 .59579 Mdot
.45889 .7794 Mdot
.33157 .50648 Mdot
.54539 .54953 Mdot
.3235 .62781 Mdot
.40867 .42031 Mdot
.52692 .62075 Mdot
.53705 .53408 Mdot
.62469 .41813 Mdot
.43233 .17822 Mdot
.49528 .34011 Mdot
.36734 .44348 Mdot
.34578 .51392 Mdot
.36347 .40128 Mdot
.60073 .47323 Mdot
.41273 .39486 Mdot
.29415 .73976 Mdot
.40603 .38996 Mdot
.34013 .64976 Mdot
.30335 .46975 Mdot
.36707 .58432 Mdot
.3539 .45048 Mdot
.46935 .28764 Mdot
.60582 .59764 Mdot
.55418 .55037 Mdot
.27154 .30065 Mdot
.52216 .55773 Mdot
.3222 .63748 Mdot
.51204 .29975 Mdot
.63139 .41421 Mdot
.31614 .65008 Mdot
.49384 .33488 Mdot
.64611 .40264 Mdot
.55632 .65215 Mdot
.57003 .64987 Mdot
.63423 .43125 Mdot
.621 .40737 Mdot
.54631 .60021 Mdot
.40249 .4457 Mdot
.68302 .396 Mdot
.62604 .43776 Mdot
.38854 .44884 Mdot
.38533 .43799 Mdot
.5799 .51921 Mdot
.48875 .33328 Mdot
.58312 .63304 Mdot
.37888 .45863 Mdot
.30275 .6555 Mdot
.6529 .41945 Mdot
.57633 .62468 Mdot
.56333 .6287 Mdot
.34389 .64189 Mdot
.30666 .63613 Mdot
.31397 .65158 Mdot
.51787 .30481 Mdot
.59446 .58765 Mdot
.65763 .43382 Mdot
.48219 .35088 Mdot
.31711 .62272 Mdot
.35906 .63926 Mdot
.43364 .52022 Mdot
.5281 .59291 Mdot
.45589 .42795 Mdot
.90939 .55457 Mdot
.51477 .73981 Mdot
.39978 .42234 Mdot
.36285 .49206 Mdot
.42612 .7433 Mdot
.24491 .45192 Mdot
.48788 .30384 Mdot
.53858 .7346 Mdot
.34918 .6754 Mdot
.53783 .64349 Mdot
.54143 .66457 Mdot
.49596 .5991 Mdot
.32448 .65767 Mdot
.48634 .77686 Mdot
.61572 .40786 Mdot
.66528 .56836 Mdot
.32152 .66325 Mdot
.34623 .52731 Mdot
.33785 .52626 Mdot
.33328 .51178 Mdot
.55461 .66335 Mdot
.68744 .64627 Mdot
.7047 .47856 Mdot
.73838 .35457 Mdot
.50478 .33929 Mdot
.67578 .45361 Mdot
.53514 .80134 Mdot
.6382 .43408 Mdot
.3236 .5331 Mdot
.32816 .65948 Mdot
.61935 .42596 Mdot
.45564 .31194 Mdot
.47476 .32526 Mdot
.32945 .5096 Mdot
.34526 .47884 Mdot
.32643 .48157 Mdot
.68608 .40916 Mdot
.67894 .40701 Mdot
.57549 .57666 Mdot
.64303 .42199 Mdot
.35744 .21132 Mdot
.29786 .64364 Mdot
.335 .52909 Mdot
.49631 .31871 Mdot
.66761 .41009 Mdot
.56162 .56463 Mdot
.28302 .50119 Mdot
.64461 .26444 Mdot
.35186 .63628 Mdot
.21618 .48332 Mdot
.11159 .52678 Mdot
.51615 .60544 Mdot
.49191 .30099 Mdot
.24767 .36612 Mdot
.55601 .57035 Mdot
.34513 .49458 Mdot
.67041 .24606 Mdot
.39022 .42031 Mdot
.57781 .6396 Mdot
.51995 .56076 Mdot
.50466 .30599 Mdot
.42924 .79467 Mdot
.57517 .5727 Mdot
.51613 .24468 Mdot
.44925 .30626 Mdot
.31615 .48996 Mdot
.55022 .85537 Mdot
.38036 .34271 Mdot
.38576 .67637 Mdot
.39061 .43783 Mdot
.53126 .57352 Mdot
.36485 .44832 Mdot
.34902 .63309 Mdot
.34799 .4611 Mdot
.66818 .45278 Mdot
.31557 .50225 Mdot
.56489 .61729 Mdot
.66083 .43408 Mdot
.48894 .30617 Mdot
.40623 .20564 Mdot
.38674 .53256 Mdot
.34441 .4759 Mdot
.39415 .43859 Mdot
.53476 .63354 Mdot
.52573 .49145 Mdot
.61881 .63114 Mdot
.52539 .61345 Mdot
.45753 .33255 Mdot
.66965 .40141 Mdot
.46122 .35215 Mdot
.55856 .53837 Mdot
.53235 .20294 Mdot
.50105 .33055 Mdot
.55809 .34419 Mdot
.33944 .64566 Mdot
.44397 .54182 Mdot
.56007 .56044 Mdot
.46241 .32234 Mdot
.59548 .58866 Mdot
.63526 .38317 Mdot
.47984 .44748 Mdot
.40361 .32389 Mdot
.46727 .32088 Mdot
.67748 .77712 Mdot
.44994 .45899 Mdot
.59392 .6414 Mdot
.4608 .33133 Mdot
.64048 .52848 Mdot
.39196 .43099 Mdot
.33774 .65876 Mdot
.31652 .62341 Mdot
.34745 .62741 Mdot
.50657 .58108 Mdot
.48425 .5979 Mdot
.33662 .67501 Mdot
.46946 .29352 Mdot
.30775 .64183 Mdot
.5794 .4221 Mdot
.68853 .76949 Mdot
.32203 .67203 Mdot
.56961 .58933 Mdot
.5075 .54865 Mdot
.4308 .71977 Mdot
.32526 .53576 Mdot
.79456 .63006 Mdot
.4932 .66933 Mdot
.53703 .59418 Mdot
.49193 .54785 Mdot
.61599 .41146 Mdot
.24137 .38742 Mdot
.61646 .6839 Mdot
.23735 .45805 Mdot
.65868 .38411 Mdot
.39843 .3836 Mdot
.65657 .39161 Mdot
.51803 .61374 Mdot
.53888 .62719 Mdot
.60394 .41923 Mdot
.41147 .23021 Mdot
.31943 .31822 Mdot
.54602 .8335 Mdot
.62498 .43875 Mdot
.46485 .33168 Mdot
.45236 .30992 Mdot
.50361 .33964 Mdot
.32527 .5547 Mdot
.64071 .45005 Mdot
.58853 .58458 Mdot
.3675 .46642 Mdot
.53031 .56067 Mdot
.46727 .31387 Mdot
.58992 .83914 Mdot
.62679 .41626 Mdot
.55089 .59693 Mdot
.17164 .58235 Mdot
.34857 .48065 Mdot
.34483 .65306 Mdot
.3691 .74458 Mdot
.32095 .55097 Mdot
.45792 .34358 Mdot
.60677 .41532 Mdot
.50119 .38424 Mdot
.5567 .38509 Mdot
.5591 .52087 Mdot
.5978 .54303 Mdot
.43297 .82881 Mdot
.37255 .50493 Mdot
.51715 .63239 Mdot
.37341 .43836 Mdot
.39539 .38579 Mdot
.57541 .62148 Mdot
.61714 .43341 Mdot
.34543 .61856 Mdot
.32084 .62824 Mdot
.51026 .64634 Mdot
.53436 .42548 Mdot
.43643 .55036 Mdot
.58355 .62568 Mdot
.53253 .67068 Mdot
.34756 .51377 Mdot
.40848 .38921 Mdot
.38271 .21917 Mdot
.32859 .67437 Mdot
.55842 .6394 Mdot
.63089 .32296 Mdot
.67884 .4214 Mdot
.31989 .4902 Mdot
.45663 .33894 Mdot
.48009 .78724 Mdot
.32638 .47051 Mdot
.57468 .62384 Mdot
.57854 .62496 Mdot
.50597 .31158 Mdot
.69423 .4217 Mdot
.32676 .65744 Mdot
.35797 .48865 Mdot
.33029 .67477 Mdot
.67156 .4296 Mdot
.62917 .41733 Mdot
.52575 .52585 Mdot
.52925 .66767 Mdot
.3336 .49529 Mdot
.54815 .53913 Mdot
.33336 .53433 Mdot
.41979 .79563 Mdot
.46472 .35722 Mdot
.51567 .59983 Mdot
.628 .46226 Mdot
.4629 .31547 Mdot
.55533 .61067 Mdot
.42488 .83686 Mdot
.51939 .56998 Mdot
.40319 .36698 Mdot
.51245 .20306 Mdot
.33202 .62792 Mdot
.63517 .70627 Mdot
.50054 .52418 Mdot
.53738 .61048 Mdot
.32781 .5245 Mdot
.60758 .65689 Mdot
.50516 .32044 Mdot
.67025 .39354 Mdot
.14684 .58529 Mdot
.48868 .31847 Mdot
.53065 .61637 Mdot
.31896 .6526 Mdot
.61045 .40955 Mdot
.39387 .40558 Mdot
.31398 .27029 Mdot
.59444 .66167 Mdot
.60289 .62483 Mdot
.57799 .63814 Mdot
.74037 .30449 Mdot
.36367 .44608 Mdot
.66631 .41393 Mdot
.50303 .31035 Mdot
.47198 .30464 Mdot
.3342 .50744 Mdot
.58877 .30764 Mdot
.44584 .5319 Mdot
.89523 .4699 Mdot
.33194 .48647 Mdot
.30963 .67626 Mdot
.55141 .44297 Mdot
.32197 .52511 Mdot
.36561 .46333 Mdot
.35253 .50556 Mdot
.53904 .30433 Mdot
.64446 .40539 Mdot
.56148 .63029 Mdot
.66884 .38146 Mdot
.52988 .57337 Mdot
.41606 .60278 Mdot
.46134 .31355 Mdot
.67074 .39264 Mdot
.43573 .83532 Mdot
.65275 .36059 Mdot
.56092 .57778 Mdot
.51258 .81163 Mdot
.61948 .61996 Mdot
.47832 .76143 Mdot
.61653 .61185 Mdot
.35152 .46871 Mdot
.54563 .69397 Mdot
.54732 .53358 Mdot
.38608 .20461 Mdot
.49679 .32083 Mdot
.39649 .43048 Mdot
.5059 .60726 Mdot
.54647 .67013 Mdot
.6125 .39251 Mdot
.61954 .42861 Mdot
.3293 .67658 Mdot
.39346 .63588 Mdot
.49324 .30865 Mdot
.33148 .7414 Mdot
.54025 .60088 Mdot
.44461 .23256 Mdot
.65318 .66289 Mdot
.55539 .60893 Mdot
.71398 .72631 Mdot
.68245 .64373 Mdot
.56495 .55984 Mdot
.64269 .51509 Mdot
.47926 .32807 Mdot
.51176 .2078 Mdot
.592 .56421 Mdot
.34697 .49264 Mdot
.67635 .40302 Mdot
.61168 .4222 Mdot
.34897 .66285 Mdot
.21209 .35783 Mdot
.47788 .35605 Mdot
.67494 .39641 Mdot
.55181 .56493 Mdot
.46199 .34722 Mdot
.38232 .46053 Mdot
.57191 .54087 Mdot
.55326 .73741 Mdot
.64037 .42031 Mdot
.57275 .5502 Mdot
.5907 .23742 Mdot
.39179 .65573 Mdot
.84729 .48689 Mdot
.50388 .33823 Mdot
.31402 .66504 Mdot
.61919 .58643 Mdot
.28783 .72603 Mdot
.50211 .5784 Mdot
.36495 .7206 Mdot
.5956 .46798 Mdot
.30997 .66215 Mdot
.55654 .58263 Mdot
.58048 .59334 Mdot
.5452 .42123 Mdot
.30241 .64268 Mdot
.52133 .57496 Mdot
.51455 .68102 Mdot
.64981 .40333 Mdot
.40765 .41164 Mdot
.63881 .41624 Mdot
.56879 .5825 Mdot
.48593 .58251 Mdot
.62196 .41229 Mdot
.31358 .75231 Mdot
.33595 .68728 Mdot
.49591 .34069 Mdot
.50586 .64939 Mdot
.59648 .57724 Mdot
.7378 .2736 Mdot
.39806 .42632 Mdot
.72522 .32531 Mdot
.31583 .48299 Mdot
.62241 .33391 Mdot
.38016 .3361 Mdot
.77726 .68518 Mdot
.41602 .20873 Mdot
.52383 .64852 Mdot
.45041 .65194 Mdot
.6619 .49619 Mdot
.46148 .35075 Mdot
.7597 .47393 Mdot
.53747 .5971 Mdot
.54231 .57587 Mdot
.32904 .47197 Mdot
.57009 .30485 Mdot
.26789 .3486 Mdot
.51995 .42927 Mdot
.32993 .65427 Mdot
.66289 .43959 Mdot
.55291 .62363 Mdot
.40697 .57639 Mdot
.31575 .50836 Mdot
.43381 .23958 Mdot
.5529 .59144 Mdot
.20939 .40077 Mdot
.53952 .33022 Mdot
.47725 .3533 Mdot
.33452 .52454 Mdot
.31926 .55015 Mdot
.52612 .58329 Mdot
.45278 .32765 Mdot
.5726 .56967 Mdot
.43863 .47291 Mdot
.53893 .54157 Mdot
.32277 .67059 Mdot
.53823 .63859 Mdot
.51518 .4086 Mdot
.84178 .54743 Mdot
.57803 .71251 Mdot
.61616 .43905 Mdot
.3175 .54375 Mdot
.33256 .50454 Mdot
.62062 .42369 Mdot
.3345 .50008 Mdot
.67367 .5951 Mdot
.74062 .61423 Mdot
.33345 .65101 Mdot
.52321 .6679 Mdot
.33625 .67038 Mdot
.39901 .42612 Mdot
.53193 .59156 Mdot
.29499 .74368 Mdot
.33559 .48385 Mdot
.58722 .19306 Mdot
.49182 .31634 Mdot
.39749 .42816 Mdot
.54332 .54656 Mdot
.30797 .45912 Mdot
.31855 .53049 Mdot
.39988 .37872 Mdot
.57702 .59226 Mdot
.62839 .41006 Mdot
.58126 .60014 Mdot
.6163 .62326 Mdot
.40879 .40344 Mdot
.60512 .60133 Mdot
.49377 .33485 Mdot
.69101 .4124 Mdot
.72613 .73621 Mdot
.40071 .36469 Mdot
.52301 .59451 Mdot
.55276 .5665 Mdot
.61791 .39255 Mdot
.56836 .55111 Mdot
.45289 .31455 Mdot
.72879 .19933 Mdot
.33999 .64589 Mdot
.36961 .4891 Mdot
.38234 .34469 Mdot
.49993 .59345 Mdot
.58339 .62114 Mdot
.47021 .84083 Mdot
.40127 .30651 Mdot
.47509 .33851 Mdot
.58866 .67612 Mdot
.36494 .47129 Mdot
.31887 .6508 Mdot
.48184 .29072 Mdot
.58988 .6266 Mdot
.54679 .58281 Mdot
.31822 .66656 Mdot
.67887 .75159 Mdot
.23295 .46273 Mdot
.50989 .33201 Mdot
.54999 .69434 Mdot
.27439 .5163 Mdot
.53928 .55547 Mdot
.30231 .55874 Mdot
.62401 .43303 Mdot
.46465 .3428 Mdot
.73948 .34253 Mdot
.54153 .6424 Mdot
.45935 .30586 Mdot
.49536 .31148 Mdot
.6016 .55712 Mdot
.60889 .39079 Mdot
.6863 .42047 Mdot
.65083 .44683 Mdot
.3895 .18533 Mdot
.40466 .6703 Mdot
.32609 .48235 Mdot
.47764 .32817 Mdot
.35867 .50787 Mdot
.2962 .65615 Mdot
.40915 .58611 Mdot
.35419 .51735 Mdot
.62 .40598 Mdot
.3419 .5249 Mdot
.57946 .59747 Mdot
.48722 .30481 Mdot
.35017 .45377 Mdot
.50568 .60105 Mdot
.49625 .51801 Mdot
.43282 .45429 Mdot
.35291 .62527 Mdot
.36724 .65025 Mdot
.54345 .62652 Mdot
.40008 .42058 Mdot
.54571 .59747 Mdot
.51579 .31631 Mdot
.5509 .39871 Mdot
.50186 .59022 Mdot
.33981 .48383 Mdot
.47227 .60791 Mdot
.32515 .54904 Mdot
.60193 .66169 Mdot
.56854 .58828 Mdot
.53341 .56269 Mdot
.57353 .56963 Mdot
.58252 .33243 Mdot
.48003 .35851 Mdot
.47196 .53918 Mdot
.36853 .41241 Mdot
.6422 .42803 Mdot
.64656 .45974 Mdot
.26341 .54715 Mdot
.35718 .51666 Mdot
.48703 .33314 Mdot
.55055 .55449 Mdot
.39592 .35117 Mdot
.59923 .83638 Mdot
.31721 .75765 Mdot
.36428 .62622 Mdot
.36838 .43622 Mdot
.61469 .44022 Mdot
.31557 .52397 Mdot
.53117 .57782 Mdot
.61003 .56799 Mdot
.76486 .706 Mdot
.49054 .36799 Mdot
.3269 .65936 Mdot
.53232 .56537 Mdot
.39262 .6643 Mdot
.36713 .46593 Mdot
.35409 .50463 Mdot
.52211 .56793 Mdot
.67739 .44064 Mdot
.82441 .38324 Mdot
.47522 .35371 Mdot
.48244 .664 Mdot
.71655 .4085 Mdot
.53184 .22246 Mdot
.46402 .3082 Mdot
.41547 .45973 Mdot
.37521 .4315 Mdot
.65096 .70788 Mdot
.63778 .42785 Mdot
.32515 .6619 Mdot
.59737 .5459 Mdot
.62767 .39903 Mdot
.37595 .42547 Mdot
.64817 .38799 Mdot
.52561 .6357 Mdot
.46791 .35558 Mdot
.34626 .51005 Mdot
.48883 .36356 Mdot
.60452 .4314 Mdot
.35019 .65128 Mdot
.51837 .48433 Mdot
.77748 .49747 Mdot
.68081 .64205 Mdot
.54801 .54973 Mdot
.39831 .57946 Mdot
.59399 .59027 Mdot
.61455 .38798 Mdot
.56543 .56629 Mdot
.70644 .43901 Mdot
.3329 .52285 Mdot
.5763 .55245 Mdot
.5734 .6417 Mdot
.7453 .4958 Mdot
.56015 .59332 Mdot
.60849 .58636 Mdot
.5633 .55787 Mdot
.65334 .46759 Mdot
.57095 .66412 Mdot
.6381 .4061 Mdot
.30827 .27924 Mdot
.36538 .46236 Mdot
.34983 .62014 Mdot
.32633 .62389 Mdot
.36047 .7137 Mdot
.40435 .62092 Mdot
.58089 .31085 Mdot
.64637 .41293 Mdot
.49981 .3255 Mdot
.57049 .56678 Mdot
.7588 .38055 Mdot
.36395 .37809 Mdot
.36759 .46909 Mdot
.40207 .36658 Mdot
.62237 .64561 Mdot
.74145 .30382 Mdot
.54917 .54402 Mdot
.27041 .29464 Mdot
.49366 .60676 Mdot
.51692 .57742 Mdot
.31199 .53447 Mdot
.40276 .61845 Mdot
.54066 .54978 Mdot
.6132 .39217 Mdot
.33078 .66509 Mdot
.68022 .35726 Mdot
.2794 .4087 Mdot
.40583 .45813 Mdot
.76509 .53998 Mdot
.58971 .5803 Mdot
.34883 .50495 Mdot
.64286 .39602 Mdot
.39466 .21566 Mdot
.48099 .35072 Mdot
.54727 .31319 Mdot
.70802 .49117 Mdot
.47123 .81897 Mdot
.32817 .66286 Mdot
.67503 .75053 Mdot
.56419 .61888 Mdot
.32965 .55921 Mdot
.53645 .64735 Mdot
.60321 .83406 Mdot
.31437 .67931 Mdot
.66888 .44873 Mdot
.46608 .33265 Mdot
.63949 .38206 Mdot
.68611 .66283 Mdot
.42709 .30428 Mdot
.48624 .47605 Mdot
.38111 .45315 Mdot
.48186 .52148 Mdot
.66478 .42724 Mdot
.57251 .63489 Mdot
.90443 .50236 Mdot
.62589 .43642 Mdot
.66336 .4459 Mdot
.39225 .78598 Mdot
.39357 .79121 Mdot
.59958 .67622 Mdot
.63902 .38764 Mdot
.38005 .45119 Mdot
.34101 .63338 Mdot
.58436 .59447 Mdot
.57827 .5789 Mdot
.62369 .41277 Mdot
.32468 .53331 Mdot
.49612 .68273 Mdot
.34858 .47381 Mdot
.65039 .40147 Mdot
.3555 .47275 Mdot
.39161 .3733 Mdot
.36545 .4413 Mdot
.59057 .56968 Mdot
.56671 .56626 Mdot
.25847 .45518 Mdot
.62936 .41733 Mdot
.58778 .61594 Mdot
.54909 .63503 Mdot
.65972 .43152 Mdot
.31568 .48186 Mdot
.76386 .41122 Mdot
.52854 .60124 Mdot
.57228 .60903 Mdot
.31187 .66453 Mdot
.36574 .57719 Mdot
.20223 .52078 Mdot
.58604 .60701 Mdot
.30204 .66514 Mdot
.68503 .4064 Mdot
.54795 .60069 Mdot
.57786 .42593 Mdot
.39389 .38202 Mdot
.54466 .64199 Mdot
.38857 .43052 Mdot
.51174 .56602 Mdot
.82905 .42931 Mdot
.52168 .60372 Mdot
.6627 .41917 Mdot
.67522 .41088 Mdot
.40503 .78461 Mdot
.6401 .43992 Mdot
.38922 .4424 Mdot
.47148 .31221 Mdot
.62614 .82193 Mdot
.381 .46312 Mdot
.51372 .57916 Mdot
.1673 .59274 Mdot
.57583 .54856 Mdot
.5038 .60301 Mdot
.71356 .27209 Mdot
.3808 .46259 Mdot
.67194 .41214 Mdot
.51753 .26778 Mdot
.4975 .62596 Mdot
.45853 .343 Mdot
.5736 .53427 Mdot
.60249 .61653 Mdot
.48882 .21372 Mdot
.6637 .26094 Mdot
.50762 .296 Mdot
.55599 .51724 Mdot
.58638 .60742 Mdot
.38951 .55316 Mdot
.55725 .56321 Mdot
.33365 .67267 Mdot
.66018 .44615 Mdot
.31932 .50786 Mdot
.33852 .63785 Mdot
.53849 .60475 Mdot
.32238 .65763 Mdot
.32539 .4821 Mdot
.45947 .33688 Mdot
.5288 .58634 Mdot
.32791 .68503 Mdot
.32842 .6548 Mdot
.5959 .59824 Mdot
.67377 .39654 Mdot
.58192 .70364 Mdot
.54996 .60345 Mdot
.56952 .63328 Mdot
.62465 .41521 Mdot
.27267 .74753 Mdot
.51829 .59198 Mdot
.45086 .43344 Mdot
.65641 .45197 Mdot
.4052 .34216 Mdot
.32551 .47945 Mdot
.60462 .61305 Mdot
.45512 .33012 Mdot
.4603 .31622 Mdot
.36976 .47438 Mdot
.62904 .38439 Mdot
.32381 .53808 Mdot
.47426 .61378 Mdot
.51156 .65427 Mdot
.59013 .55334 Mdot
.14587 .52819 Mdot
.76031 .7024 Mdot
.61549 .43261 Mdot
.35441 .44065 Mdot
.51936 .43387 Mdot
.47422 .33031 Mdot
.3633 .49429 Mdot
.60914 .41014 Mdot
.61205 .43587 Mdot
.64305 .39084 Mdot
.31073 .65263 Mdot
.34853 .44501 Mdot
.69098 .43039 Mdot
.67906 .43837 Mdot
.57803 .5953 Mdot
.58704 .60922 Mdot
.62511 .53025 Mdot
.46371 .73289 Mdot
.35018 .6561 Mdot
.33748 .50665 Mdot
.63229 .16116 Mdot
.51554 .31148 Mdot
.74611 .50035 Mdot
.50151 .59389 Mdot
.86656 .66276 Mdot
.542 .54396 Mdot
.55179 .56274 Mdot
.68675 .40241 Mdot
.34046 .68023 Mdot
.33968 .66583 Mdot
.66659 .42638 Mdot
.6057 .43036 Mdot
.32735 .6735 Mdot
.61162 .79193 Mdot
.68647 .77353 Mdot
.50956 .25349 Mdot
.65752 .42577 Mdot
.78135 .52895 Mdot
.4548 .33733 Mdot
.60298 .43055 Mdot
.51207 .30997 Mdot
.36343 .46928 Mdot
.37566 .43011 Mdot
.5064 .31432 Mdot
.57615 .58807 Mdot
.33518 .47046 Mdot
.58025 .65057 Mdot
.63899 .78757 Mdot
.74605 .65723 Mdot
.37548 .2969 Mdot
.53757 .66219 Mdot
.27494 .33694 Mdot
.27823 .35096 Mdot
.53829 .61776 Mdot
.61056 .35604 Mdot
.3252 .65937 Mdot
.60459 .45223 Mdot
.45245 .31714 Mdot
.84596 .47542 Mdot
.54338 .55416 Mdot
.65976 .41715 Mdot
.49603 .32526 Mdot
.4089 .77506 Mdot
.52085 .24614 Mdot
.52975 .5707 Mdot
.88403 .43963 Mdot
.6067 .46363 Mdot
.31963 .50569 Mdot
.17307 .4757 Mdot
.67638 .38416 Mdot
.37266 .64046 Mdot
.36773 .42105 Mdot
.46865 .83035 Mdot
.66336 .39954 Mdot
.37657 .42373 Mdot
.66396 .43684 Mdot
.34312 .66781 Mdot
.5923 .43684 Mdot
.35291 .50123 Mdot
.55795 .58834 Mdot
.3382 .49641 Mdot
.35159 .65168 Mdot
.32753 .55541 Mdot
.45256 .32196 Mdot
.39476 .42993 Mdot
.47781 .32013 Mdot
.39326 .64924 Mdot
.56119 .20077 Mdot
.48706 .34599 Mdot
.38018 .76206 Mdot
.51772 .63416 Mdot
.69504 .41289 Mdot
.32829 .4922 Mdot
.37571 .41657 Mdot
.52695 .46913 Mdot
.64549 .43138 Mdot
.33689 .51191 Mdot
.71115 .48274 Mdot
.21378 .65909 Mdot
.48433 .60263 Mdot
.41863 .66253 Mdot
.65739 .43108 Mdot
.35511 .50514 Mdot
.33757 .2473 Mdot
.61891 .40579 Mdot
.33184 .48565 Mdot
.46184 .32761 Mdot
.46838 .30548 Mdot
.52836 .55994 Mdot
.51349 .27101 Mdot
.32465 .51179 Mdot
.30912 .29821 Mdot
.67771 .42521 Mdot
.41069 .77302 Mdot
.3557 .64328 Mdot
.36879 .45558 Mdot
.55456 .5344 Mdot
.69201 .37971 Mdot
.39092 .38314 Mdot
.49797 .69631 Mdot
.62736 .16472 Mdot
.33523 .50649 Mdot
.66308 .44471 Mdot
.6558 .4171 Mdot
.61954 .62649 Mdot
.53735 .42723 Mdot
.31907 .54068 Mdot
.27824 .70996 Mdot
.37398 .7267 Mdot
.40076 .40883 Mdot
.28804 .36372 Mdot
.52091 .55793 Mdot
.59751 .58835 Mdot
.47279 .33166 Mdot
.56359 .59034 Mdot
.68694 .4263 Mdot
.5478 .54812 Mdot
.46745 .30151 Mdot
.37512 .44487 Mdot
.53199 .58704 Mdot
.34083 .6309 Mdot
.49074 .28418 Mdot
.50646 .30949 Mdot
.36291 .45734 Mdot
.63932 .38854 Mdot
.33211 .69572 Mdot
.34437 .48047 Mdot
.58759 .5783 Mdot
.39554 .40326 Mdot
.52859 .63543 Mdot
.62397 .76222 Mdot
.62357 .39735 Mdot
.31985 .52619 Mdot
.64699 .45679 Mdot
.48244 .32181 Mdot
.3682 .41347 Mdot
.5653 .57474 Mdot
.33464 .4815 Mdot
.26181 .43024 Mdot
.63749 .77156 Mdot
.62364 .38566 Mdot
.3092 .36495 Mdot
.67095 .44213 Mdot
.40196 .40881 Mdot
.55999 .7593 Mdot
.33623 .65735 Mdot
.36154 .4783 Mdot
.75999 .69074 Mdot
.33638 .48725 Mdot
.56056 .59812 Mdot
.55399 .61644 Mdot
.33505 .46558 Mdot
.31121 .63971 Mdot
.44528 .18076 Mdot
.43163 .43899 Mdot
.66952 .40535 Mdot
.62001 .72017 Mdot
.69413 .20652 Mdot
.43905 .33163 Mdot
.47404 .33504 Mdot
.51084 .64131 Mdot
.51954 .56526 Mdot
.49533 .29402 Mdot
.44739 .31422 Mdot
.35253 .66095 Mdot
.35646 .49747 Mdot
.59099 .43805 Mdot
.45492 .29875 Mdot
.58215 .50661 Mdot
.40511 .62382 Mdot
.56853 .68113 Mdot
.4913 .55213 Mdot
.56165 .65701 Mdot
.35274 .72491 Mdot
.48403 .29804 Mdot
.54649 .62889 Mdot
.58224 .66519 Mdot
.46455 .3393 Mdot
.34041 .6694 Mdot
.64651 .24955 Mdot
.35229 .48292 Mdot
.43653 .86182 Mdot
.52546 .62624 Mdot
.5573 .59959 Mdot
.50265 .34148 Mdot
.36786 .56374 Mdot
.62792 .40201 Mdot
.62833 .39085 Mdot
.36056 .44803 Mdot
.49891 .49406 Mdot
.57209 .55563 Mdot
.53989 .62164 Mdot
.34884 .49917 Mdot
.39552 .42806 Mdot
.3471 .29509 Mdot
.56517 .62661 Mdot
.49444 .32513 Mdot
.38101 .41631 Mdot
.47732 .29738 Mdot
.51836 .61967 Mdot
.56106 .60223 Mdot
.5877 .56627 Mdot
.51831 .56683 Mdot
.50926 .31359 Mdot
.54993 .62756 Mdot
.49809 .56136 Mdot
.65709 .38716 Mdot
.5941 .57757 Mdot
.36512 .72824 Mdot
.57116 .59611 Mdot
.34845 .64354 Mdot
.38378 .60299 Mdot
.53192 .56366 Mdot
.59873 .58158 Mdot
.43381 .43968 Mdot
.55448 .57888 Mdot
.51555 .31602 Mdot
.64503 .42471 Mdot
.47692 .32787 Mdot
.50294 .30816 Mdot
.38507 .43621 Mdot
.34251 .67119 Mdot
.50154 .61351 Mdot
.34485 .62634 Mdot
.54047 .52591 Mdot
.52906 .6401 Mdot
.34255 .4244 Mdot
.26683 .29692 Mdot
.23377 .46711 Mdot
.56664 .57494 Mdot
.36779 .44785 Mdot
.31834 .51307 Mdot
.45735 .65104 Mdot
.57824 .65515 Mdot
.48904 .29082 Mdot
.46275 .32218 Mdot
.51483 .7491 Mdot
.48695 .216 Mdot
.34956 .65232 Mdot
.40525 .58285 Mdot
.55629 .66573 Mdot
.5594 .63384 Mdot
.57003 .54089 Mdot
.3549 .51588 Mdot
.41053 .3913 Mdot
.36805 .46817 Mdot
.40983 .37445 Mdot
.46873 .29936 Mdot
.56097 .55325 Mdot
.77837 .62226 Mdot
.61754 .42411 Mdot
.64422 .42454 Mdot
.4795 .29236 Mdot
.32609 .5403 Mdot
.61841 .5561 Mdot
.15012 .6189 Mdot
.63132 .46831 Mdot
.35894 .64501 Mdot
.53446 .61533 Mdot
.36456 .45295 Mdot
.62553 .44258 Mdot
.30941 .63756 Mdot
.55112 .64065 Mdot
.31125 .54132 Mdot
.57021 .57528 Mdot
.6601 .49624 Mdot
.66613 .39367 Mdot
.62081 .83189 Mdot
.61148 .41043 Mdot
.4799 .28314 Mdot
.47602 .3438 Mdot
.55688 .61031 Mdot
.15366 .51314 Mdot
.6921 .40264 Mdot
.5255 .28935 Mdot
.32444 .6817 Mdot
.39348 .40389 Mdot
.30879 .66867 Mdot
.32256 .52432 Mdot
.33069 .66404 Mdot
.34271 .51644 Mdot
.49977 .74025 Mdot
.68307 .45351 Mdot
.3402 .64221 Mdot
.41747 .52978 Mdot
.56376 .66417 Mdot
.32688 .61937 Mdot
.50265 .56424 Mdot
.63979 .71048 Mdot
.34804 .49793 Mdot
.31415 .63663 Mdot
.57387 .63321 Mdot
.83135 .50867 Mdot
.48998 .33875 Mdot
.49309 .29164 Mdot
.59999 .63269 Mdot
.35802 .49497 Mdot
.60576 .40788 Mdot
.56038 .3863 Mdot
.4114 .35518 Mdot
.54344 .62499 Mdot
.54355 .54869 Mdot
.648 .4599 Mdot
.70102 .43174 Mdot
.56063 .60763 Mdot
.73732 .46358 Mdot
.55992 .62333 Mdot
.45664 .31864 Mdot
.61364 .41952 Mdot
.65172 .4201 Mdot
.32752 .51841 Mdot
.66454 .38369 Mdot
.48033 .57702 Mdot
.50471 .3894 Mdot
.49709 .58468 Mdot
.4868 .31774 Mdot
.53071 .40284 Mdot
.40187 .36696 Mdot
.80654 .59746 Mdot
.62666 .45922 Mdot
.60602 .59445 Mdot
.67299 .43533 Mdot
.31723 .64464 Mdot
.63179 .41781 Mdot
.63567 .45006 Mdot
.54504 .60699 Mdot
.53159 .57286 Mdot
.38408 .45223 Mdot
.53427 .43132 Mdot
.67496 .39388 Mdot
.54807 .62417 Mdot
.57967 .55245 Mdot
.61041 .59071 Mdot
.46863 .43798 Mdot
.61732 .43652 Mdot
.71109 .52537 Mdot
.56972 .73966 Mdot
.67238 .39205 Mdot
.82132 .4086 Mdot
.39629 .39731 Mdot
.366 .498 Mdot
.46646 .36506 Mdot
.56562 .62729 Mdot
.34185 .45726 Mdot
.53101 .57872 Mdot
.4951 .54469 Mdot
.54456 .5808 Mdot
.30252 .65916 Mdot
.52409 .64862 Mdot
.3961 .41459 Mdot
.34107 .48595 Mdot
.52861 .62029 Mdot
.53412 .58519 Mdot
.3462 .5374 Mdot
.60841 .43644 Mdot
.63012 .3995 Mdot
.32936 .58256 Mdot
.32921 .64317 Mdot
.46174 .34261 Mdot
.56363 .5611 Mdot
.36663 .44596 Mdot
.33928 .49357 Mdot
.64378 .38038 Mdot
.34587 .49204 Mdot
.4894 .35089 Mdot
.56245 .57146 Mdot
.49589 .29351 Mdot
.31737 .63243 Mdot
.65136 .44773 Mdot
.54929 .55325 Mdot
.57801 .59646 Mdot
.67511 .41083 Mdot
.5199 .63858 Mdot
.31219 .66522 Mdot
.33508 .49301 Mdot
.65691 .39644 Mdot
.46964 .31176 Mdot
.33044 .52453 Mdot
.57965 .61458 Mdot
.61876 .16162 Mdot
.56479 .60021 Mdot
.57323 .62434 Mdot
.73225 .74199 Mdot
.51689 .64345 Mdot
.32704 .50429 Mdot
.65965 .45673 Mdot
.58884 .64103 Mdot
.37974 .70047 Mdot
.31095 .75822 Mdot
.37431 .46654 Mdot
.52934 .61028 Mdot
.80857 .60716 Mdot
.52787 .61386 Mdot
.32817 .73773 Mdot
.22858 .55357 Mdot
.45552 .55187 Mdot
.5026 .54038 Mdot
.50669 .32862 Mdot
.38563 .44895 Mdot
.33348 .52184 Mdot
.65472 .58956 Mdot
.54459 .61359 Mdot
.63869 .50032 Mdot
.5665 .64359 Mdot
.46558 .30622 Mdot
.58572 .71773 Mdot
.33793 .50307 Mdot
.29511 .27249 Mdot
.58913 .58417 Mdot
.61454 .43422 Mdot
.33798 .52796 Mdot
.39682 .39441 Mdot
.57559 .62637 Mdot
.33707 .62389 Mdot
.52021 .34065 Mdot
.49487 .62442 Mdot
.48476 .31312 Mdot
.55276 .63714 Mdot
.53041 .5219 Mdot
.1774 .42672 Mdot
.66178 .39068 Mdot
.46808 .33246 Mdot
.27981 .36038 Mdot
.52285 .64284 Mdot
.66106 .39724 Mdot
.63887 .42851 Mdot
.35418 .64845 Mdot
.49914 .45407 Mdot
.59372 .24691 Mdot
.7927 .56078 Mdot
.6372 .68864 Mdot
.3564 .50605 Mdot
.31653 .32845 Mdot
.58577 .59849 Mdot
.42615 .25149 Mdot
.513 .30521 Mdot
.55736 .59554 Mdot
.65786 .66402 Mdot
.64285 .44648 Mdot
.57025 .61437 Mdot
.33644 .67059 Mdot
.41304 .23973 Mdot
.41428 .25521 Mdot
.77173 .34064 Mdot
.37813 .45568 Mdot
.58411 .54052 Mdot
.4873 .56173 Mdot
.39497 .43624 Mdot
.5457 .64709 Mdot
.32923 .49917 Mdot
.56752 .79478 Mdot
.30485 .6516 Mdot
.63461 .44715 Mdot
.39669 .39617 Mdot
.57067 .65282 Mdot
.59742 .56601 Mdot
.35179 .62232 Mdot
.6003 .60852 Mdot
.21336 .35995 Mdot
.36792 .32713 Mdot
.34678 .45788 Mdot
.64682 .38953 Mdot
.55377 .66335 Mdot
.41113 .39312 Mdot
.54804 .61157 Mdot
.74074 .6368 Mdot
.60455 .59291 Mdot
.57161 .23658 Mdot
.67671 .40305 Mdot
.48317 .31519 Mdot
.56937 .52353 Mdot
.54569 .57399 Mdot
.27872 .50844 Mdot
.50815 .53393 Mdot
.52145 .60781 Mdot
.61276 .39482 Mdot
.61604 .42822 Mdot
.63869 .40696 Mdot
.31455 .50856 Mdot
.46674 .2289 Mdot
.48946 .32702 Mdot
.51906 .55716 Mdot
.4555 .29756 Mdot
.51231 .69244 Mdot
.35501 .62655 Mdot
.81431 .46582 Mdot
.60281 .6102 Mdot
.6457 .40898 Mdot
.64606 .31168 Mdot
.68567 .40912 Mdot
.31439 .47867 Mdot
.49234 .30781 Mdot
.63209 .44349 Mdot
.5486 .56682 Mdot
.52504 .42151 Mdot
.78353 .39487 Mdot
.47208 .32486 Mdot
.51887 .54067 Mdot
.38009 .43018 Mdot
.38487 .34876 Mdot
.68232 .1836 Mdot
.47716 .33928 Mdot
.2875 .34814 Mdot
.54173 .61814 Mdot
.6184 .41921 Mdot
.50331 .33759 Mdot
.4945 .33892 Mdot
.34473 .49981 Mdot
.532 .56979 Mdot
.53551 .56243 Mdot
.39145 .41578 Mdot
.46266 .32003 Mdot
.61585 .59679 Mdot
.55336 .5379 Mdot
.76412 .70829 Mdot
.64312 .57385 Mdot
.31571 .79814 Mdot
.47574 .62461 Mdot
.66061 .67173 Mdot
.56082 .44269 Mdot
.65411 .45053 Mdot
.53004 .56659 Mdot
.54808 .65955 Mdot
.32624 .51388 Mdot
.56429 .58457 Mdot
.31074 .50695 Mdot
.48573 .33573 Mdot
.8148 .40434 Mdot
.65981 .27837 Mdot
.56055 .79068 Mdot
.56153 .58382 Mdot
.51052 .22057 Mdot
.32688 .63529 Mdot
.49052 .28106 Mdot
.64596 .39973 Mdot
.51808 .62963 Mdot
.32789 .54962 Mdot
.36331 .47449 Mdot
.63126 .43182 Mdot
.28655 .3109 Mdot
.29035 .54499 Mdot
.51819 .62021 Mdot
.31779 .49094 Mdot
.60062 .3431 Mdot
.73867 .45232 Mdot
.44327 .30506 Mdot
.30486 .66419 Mdot
.36898 .46517 Mdot
.47865 .29464 Mdot
.58986 .46096 Mdot
.63451 .44193 Mdot
.67478 .45137 Mdot
.24847 .5189 Mdot
.321 .54473 Mdot
.33832 .63527 Mdot
.47312 .22549 Mdot
.46206 .21822 Mdot
.30352 .66099 Mdot
.37386 .42883 Mdot
.61967 .4354 Mdot
.66104 .40679 Mdot
.64633 .42461 Mdot
.31029 .25897 Mdot
.62344 .39007 Mdot
.75182 .53569 Mdot
.58411 .55447 Mdot
.59674 .50035 Mdot
.52785 .60988 Mdot
.51022 .30804 Mdot
.66841 .39645 Mdot
.54946 .44983 Mdot
.51003 .58209 Mdot
.78158 .36578 Mdot
.54023 .62388 Mdot
.44601 .29979 Mdot
.57017 .62112 Mdot
.76372 .49616 Mdot
.66013 .45086 Mdot
.56689 .58044 Mdot
.50124 .35227 Mdot
.32686 .6517 Mdot
.60714 .39018 Mdot
.53267 .56384 Mdot
.56472 .29384 Mdot
.50883 .63595 Mdot
.59715 .79848 Mdot
.4381 .77327 Mdot
.35917 .64437 Mdot
.51757 .68431 Mdot
.3637 .48675 Mdot
.61331 .50014 Mdot
.50008 .64985 Mdot
.47225 .32338 Mdot
.63136 .22291 Mdot
.36899 .45885 Mdot
.58372 .7116 Mdot
.60113 .66462 Mdot
.34022 .67197 Mdot
.69108 .38367 Mdot
.51433 .32258 Mdot
.50748 .60778 Mdot
.60324 .55975 Mdot
.58066 .79002 Mdot
.49936 .64379 Mdot
.56322 .54901 Mdot
.34467 .6196 Mdot
.71519 .53366 Mdot
.57374 .59787 Mdot
.33205 .45841 Mdot
.67133 .45225 Mdot
.59443 .63885 Mdot
.71204 .52048 Mdot
.54785 .6231 Mdot
.62437 .42843 Mdot
.69828 .43159 Mdot
.62117 .29331 Mdot
.33224 .68057 Mdot
.60458 .59353 Mdot
.46892 .79329 Mdot
.59318 .58641 Mdot
.49431 .32129 Mdot
.51699 .59786 Mdot
.35943 .48041 Mdot
.29208 .28316 Mdot
.32479 .48738 Mdot
.52388 .58325 Mdot
.65147 .42436 Mdot
.50985 .32616 Mdot
.23909 .48958 Mdot
.24958 .56192 Mdot
.74652 .5337 Mdot
.43434 .83692 Mdot
.3098 .64582 Mdot
.30039 .64278 Mdot
.5134 .32981 Mdot
.56837 .58168 Mdot
.42522 .78968 Mdot
.49586 .61844 Mdot
.57274 .61094 Mdot
.54358 .58156 Mdot
.44695 .25115 Mdot
.47974 .33184 Mdot
.34935 .48196 Mdot
.56169 .60538 Mdot
.54988 .62529 Mdot
.67185 .43219 Mdot
.32864 .65231 Mdot
.32028 .49558 Mdot
.33581 .64699 Mdot
.35158 .4634 Mdot
.82839 .42196 Mdot
.5243 .54355 Mdot
.32588 .64939 Mdot
.51533 .30452 Mdot
.62408 .41548 Mdot
.41296 .38933 Mdot
.32469 .52466 Mdot
.33689 .50835 Mdot
.5426 .62352 Mdot
.62163 .42311 Mdot
.66794 .3862 Mdot
.31712 .64311 Mdot
.47832 .3492 Mdot
.52683 .58042 Mdot
.52443 .6375 Mdot
.44853 .61144 Mdot
.34407 .52838 Mdot
.7178 .46863 Mdot
.60628 .31103 Mdot
.56818 .5775 Mdot
.64165 .38663 Mdot
.53934 .58898 Mdot
.77613 .64176 Mdot
.62122 .40471 Mdot
.51793 .57618 Mdot
.46513 .20556 Mdot
.39111 .40769 Mdot
.57337 .26763 Mdot
.59032 .56617 Mdot
.48656 .84717 Mdot
.58997 .60113 Mdot
.79846 .65434 Mdot
.371 .52999 Mdot
.561 .55229 Mdot
.5824 .59917 Mdot
.80143 .5382 Mdot
.53659 .60783 Mdot
.40098 .41227 Mdot
.58003 .71527 Mdot
.61266 .43849 Mdot
.55743 .46017 Mdot
.36189 .58691 Mdot
.3309 .68249 Mdot
.35984 .44846 Mdot
.29336 .37374 Mdot
.32439 .67143 Mdot
.65924 .42562 Mdot
.57388 .56954 Mdot
.47204 .5162 Mdot
.38688 .41722 Mdot
.61235 .6382 Mdot
.49479 .31672 Mdot
.33997 .34622 Mdot
.31267 .49505 Mdot
.47534 .31264 Mdot
.58741 .63406 Mdot
.77421 .42655 Mdot
.21606 .54651 Mdot
.63321 .82576 Mdot
.50923 .33314 Mdot
.46075 .30942 Mdot
.35992 .22577 Mdot
.32191 .68344 Mdot
.59462 .76123 Mdot
.54502 .23616 Mdot
.46745 .35253 Mdot
.53505 .76971 Mdot
.36842 .4702 Mdot
.5571 .28101 Mdot
.60459 .45214 Mdot
.58706 .5507 Mdot
.54812 .5689 Mdot
.47433 .3482 Mdot
.58176 .43577 Mdot
.17484 .44616 Mdot
.47637 .32015 Mdot
.51676 .53559 Mdot
.46579 .46695 Mdot
.40003 .39469 Mdot
.37689 .47167 Mdot
.33958 .67667 Mdot
.3523 .60588 Mdot
.67018 .42989 Mdot
.35067 .66268 Mdot
.40798 .25783 Mdot
.60188 .60878 Mdot
.46768 .31937 Mdot
.41137 .38368 Mdot
.47097 .30798 Mdot
.33274 .66961 Mdot
.35749 .65368 Mdot
.65572 .38684 Mdot
.62976 .40099 Mdot
.66923 .66124 Mdot
.48722 .75761 Mdot
.528 .61656 Mdot
.73153 .34256 Mdot
.67972 .41993 Mdot
.50899 .66673 Mdot
.30184 .66271 Mdot
.32845 .64785 Mdot
.65264 .51569 Mdot
.55816 .55555 Mdot
.39104 .77822 Mdot
.55726 .55691 Mdot
.54438 .74504 Mdot
.54496 .64924 Mdot
.34541 .49632 Mdot
.56488 .5566 Mdot
.31261 .69211 Mdot
.52057 .55871 Mdot
.52144 .61236 Mdot
.36194 .48485 Mdot
.49963 .63464 Mdot
.3587 .48256 Mdot
.52282 .5826 Mdot
.29878 .66282 Mdot
.36601 .44586 Mdot
.40708 .68332 Mdot
.44905 .43533 Mdot
.39751 .42148 Mdot
.34862 .63628 Mdot
.35382 .63618 Mdot
.37315 .69053 Mdot
.64787 .3992 Mdot
.63738 .36645 Mdot
.56841 .58559 Mdot
.35306 .50648 Mdot
.47552 .33329 Mdot
.55278 .62536 Mdot
.53483 .65049 Mdot
.57034 .5502 Mdot
.65966 .44469 Mdot
.32352 .5397 Mdot
.32182 .65323 Mdot
.31615 .49573 Mdot
.28737 .51315 Mdot
.32008 .47881 Mdot
.57731 .66495 Mdot
.59356 .53842 Mdot
.65633 .7174 Mdot
.71434 .31326 Mdot
.42526 .19028 Mdot
.6343 .43935 Mdot
.39056 .42987 Mdot
.35408 .66038 Mdot
.55491 .71208 Mdot
.64791 .40408 Mdot
.35432 .49809 Mdot
.5699 .57425 Mdot
.5252 .53519 Mdot
.47154 .37325 Mdot
.61745 .49844 Mdot
.38982 .73296 Mdot
.30925 .51535 Mdot
.40292 .40468 Mdot
.45449 .22445 Mdot
.60616 .69115 Mdot
.5142 .48185 Mdot
.54958 .5919 Mdot
.3338 .62385 Mdot
.6255 .44253 Mdot
.22791 .51101 Mdot
.46047 .33352 Mdot
.5361 .42834 Mdot
.56197 .58284 Mdot
.49377 .2458 Mdot
.64994 .42541 Mdot
.34455 .66471 Mdot
.47228 .34761 Mdot
.3408 .68076 Mdot
.3751 .47673 Mdot
.39822 .80192 Mdot
.59866 .59585 Mdot
.52221 .6047 Mdot
.46462 .28935 Mdot
.66398 .43548 Mdot
.36635 .6502 Mdot
.61776 .78278 Mdot
.33046 .47245 Mdot
.3787 .77448 Mdot
.68984 .40607 Mdot
.76867 .53749 Mdot
.31527 .50038 Mdot
.47834 .29245 Mdot
.37698 .68217 Mdot
.46886 .30064 Mdot
.53122 .56085 Mdot
.64884 .41475 Mdot
.49145 .33627 Mdot
.28214 .48628 Mdot
.82711 .5662 Mdot
.7777 .53569 Mdot
.58249 .56877 Mdot
.81376 .44465 Mdot
.66933 .7747 Mdot
.60318 .37695 Mdot
.45197 .32341 Mdot
.55011 .60598 Mdot
.57028 .64673 Mdot
.58602 .57981 Mdot
.5015 .318 Mdot
.32335 .42754 Mdot
.34319 .50786 Mdot
.53427 .61964 Mdot
.35388 .65605 Mdot
.3582 .47932 Mdot
.38154 .40603 Mdot
.32885 .51008 Mdot
.62363 .45151 Mdot
.51767 .57107 Mdot
.54897 .33031 Mdot
.84761 .55202 Mdot
.47578 .32716 Mdot
.39729 .42142 Mdot
.53233 .63319 Mdot
.53551 .20781 Mdot
.64043 .40698 Mdot
.333 .46925 Mdot
.5568 .59927 Mdot
.30728 .4454 Mdot
.33502 .54682 Mdot
.33101 .51028 Mdot
.65893 .4024 Mdot
.60642 .36732 Mdot
.56465 .58868 Mdot
.59213 .60249 Mdot
.66401 .43234 Mdot
.29901 .61713 Mdot
.30428 .27659 Mdot
.5362 .58604 Mdot
.48158 .31468 Mdot
.19891 .67019 Mdot
.60127 .5752 Mdot
.64258 .62116 Mdot
.3794 .46116 Mdot
.5823 .30074 Mdot
.71993 .46377 Mdot
.5287 .69302 Mdot
.80651 .54132 Mdot
.41624 .58125 Mdot
.81665 .41625 Mdot
.301 .52533 Mdot
.40719 .50075 Mdot
.83169 .43486 Mdot
.49955 .3513 Mdot
.58546 .49049 Mdot
.475 .6555 Mdot
.27778 .30344 Mdot
.57424 .42104 Mdot
.29828 .59759 Mdot
.26713 .52938 Mdot
.45902 .51084 Mdot
.33651 .48302 Mdot
.52093 .72578 Mdot
.52833 .58075 Mdot
.66207 .78044 Mdot
.74144 .46934 Mdot
.16623 .45541 Mdot
.81857 .45674 Mdot
.47332 .79216 Mdot
.78932 .41754 Mdot
.79335 .63104 Mdot
.64665 .72239 Mdot
.70643 .31812 Mdot
.27446 .72804 Mdot
.44815 .21644 Mdot
.49713 .8027 Mdot
.6206 .58383 Mdot
.40848 .57546 Mdot
.53524 .81802 Mdot
.74901 .5694 Mdot
.15398 .53829 Mdot
.32196 .50875 Mdot
.66619 .45207 Mdot
.46477 .64185 Mdot
.63252 .37629 Mdot
.43042 .3197 Mdot
.80967 .53425 Mdot
.78447 .66731 Mdot
.75916 .49409 Mdot
.48577 .84993 Mdot
.66503 .60246 Mdot
.34699 .19374 Mdot
.43527 .45882 Mdot
.69375 .43261 Mdot
.23913 .63258 Mdot
.46652 .21945 Mdot
.63469 .26216 Mdot
.47361 .62666 Mdot
.37463 .38777 Mdot
.42548 .70837 Mdot
.65945 .4182 Mdot
.73362 .44681 Mdot
.3686 .49797 Mdot
.64554 .255 Mdot
.36841 .67416 Mdot
.81202 .57461 Mdot
.48396 .49129 Mdot
.55449 .2905 Mdot
.32243 .31757 Mdot
.62136 .16268 Mdot
.49275 .77481 Mdot
.71779 .71249 Mdot
.43832 .35417 Mdot
.57794 .4101 Mdot
.23878 .36313 Mdot
.45882 .74707 Mdot
.46821 .21707 Mdot
.66174 .22042 Mdot
.6299 .81089 Mdot
.70468 .24101 Mdot
.62141 .37485 Mdot
.57059 .5512 Mdot
.71428 .70267 Mdot
.62945 .6931 Mdot
.32833 .60934 Mdot
.75486 .3177 Mdot
.31946 .62885 Mdot
.6255 .3751 Mdot
.28241 .30971 Mdot
.75687 .51854 Mdot
.37595 .76763 Mdot
.36303 .66594 Mdot
.53553 .6621 Mdot
.15076 .36583 Mdot
.81104 .41382 Mdot
.61247 .2927 Mdot
.76613 .70636 Mdot
.48107 .24272 Mdot
.42097 .77723 Mdot
.49491 .33222 Mdot
.84913 .48957 Mdot
.65683 .40815 Mdot
.86136 .42639 Mdot
.83968 .53794 Mdot
.18689 .49066 Mdot
.11508 .58556 Mdot
.39864 .28587 Mdot
.46895 .53877 Mdot
.41516 .59171 Mdot
.39321 .70932 Mdot
.1891 .42569 Mdot
.1769 .52387 Mdot
.46947 .2371 Mdot
.49324 .83085 Mdot
.8367 .46501 Mdot
.54933 .76527 Mdot
.43199 .8071 Mdot
.26587 .32587 Mdot
.46186 .43255 Mdot
.69963 .38737 Mdot
.43718 .41518 Mdot
.72175 .35948 Mdot
.74667 .30048 Mdot
.62649 .68486 Mdot
.15404 .6285 Mdot
.3394 .69014 Mdot
.35175 .55066 Mdot
.72279 .73243 Mdot
.41651 .67534 Mdot
.59543 .72596 Mdot
.38647 .22123 Mdot
.58643 .6716 Mdot
.41304 .2173 Mdot
.67352 .33958 Mdot
.30495 .36691 Mdot
.43802 .21974 Mdot
.57669 .35173 Mdot
.59379 .78811 Mdot
.73274 .6701 Mdot
.48623 .20826 Mdot
.61163 .43888 Mdot
.43209 .74576 Mdot
.51023 .77493 Mdot
.755 .71752 Mdot
.28034 .35977 Mdot
.66186 .82123 Mdot
.25217 .38241 Mdot
.50095 .57737 Mdot
.48326 .60468 Mdot
.60274 .53152 Mdot
.46558 .75891 Mdot
.57226 .54891 Mdot
.47668 .23664 Mdot
.74281 .73298 Mdot
.65464 .65909 Mdot
.30534 .3803 Mdot
.64553 .22876 Mdot
.63912 .82037 Mdot
.66627 .72808 Mdot
.3799 .49827 Mdot
.63707 .59256 Mdot
.43837 .16683 Mdot
.3598 .46896 Mdot
.54266 .77018 Mdot
.45177 .34659 Mdot
.24105 .52624 Mdot
.79313 .53978 Mdot
.19615 .47367 Mdot
.74198 .73524 Mdot
.3141 .27371 Mdot
.2345 .45909 Mdot
.34257 .70179 Mdot
.35875 .76233 Mdot
.68003 .25705 Mdot
.55753 .53011 Mdot
.48801 .53867 Mdot
.33818 .61999 Mdot
.68303 .67122 Mdot
.58455 .74558 Mdot
.25179 .59376 Mdot
.48933 .57283 Mdot
.19866 .57006 Mdot
.40563 .4023 Mdot
.5317 .42493 Mdot
.74269 .25113 Mdot
.59779 .65401 Mdot
.40553 .2975 Mdot
.61264 .81125 Mdot
.42242 .75939 Mdot
.72319 .72288 Mdot
.56218 .34232 Mdot
.69775 .23999 Mdot
.83448 .57204 Mdot
.2474 .57293 Mdot
.79993 .37417 Mdot
.73739 .75976 Mdot
.66249 .21091 Mdot
.6891 .46575 Mdot
.51648 .33315 Mdot
.83335 .32769 Mdot
.3667 .43203 Mdot
.59406 .20079 Mdot
.63818 .68627 Mdot
.30877 .42463 Mdot
.598 .41407 Mdot
.62898 .61211 Mdot
.4641 .50844 Mdot
.60454 .46541 Mdot
.58127 .64925 Mdot
.67146 .19553 Mdot
.61885 .19538 Mdot
.6919 .21719 Mdot
.57317 .82721 Mdot
.80597 .38194 Mdot
.44287 .58444 Mdot
.75725 .54693 Mdot
.47718 .67576 Mdot
.51641 .60629 Mdot
.49575 .72314 Mdot
.39491 .28936 Mdot
.21395 .52898 Mdot
.61734 .2518 Mdot
.61898 .38412 Mdot
.75552 .34295 Mdot
.59748 .1227 Mdot
.6714 .59281 Mdot
.68425 .53408 Mdot
.42404 .24804 Mdot
.49136 .76332 Mdot
.6996 .34915 Mdot
.19977 .51525 Mdot
.73765 .72799 Mdot
.48637 .67364 Mdot
.548 .77856 Mdot
.26346 .61298 Mdot
.3121 .72573 Mdot
.38892 .55707 Mdot
.82152 .55627 Mdot
.42894 .62379 Mdot
.21349 .45664 Mdot
.54814 .47401 Mdot
.18059 .47148 Mdot
.28644 .56776 Mdot
.34026 .33894 Mdot
.5128 .78986 Mdot
.39432 .35437 Mdot
.53531 .75465 Mdot
.47369 .46072 Mdot
.53102 .71631 Mdot
.4176 .57919 Mdot
.53923 .75461 Mdot
.30898 .72198 Mdot
.76189 .31238 Mdot
.72797 .77904 Mdot
.55015 .16025 Mdot
.50022 .84843 Mdot
.65019 .33765 Mdot
.59751 .56148 Mdot
.70533 .76216 Mdot
.73432 .26015 Mdot
.83351 .58896 Mdot
.32714 .27427 Mdot
.2898 .46774 Mdot
.49187 .28302 Mdot
.55316 .16455 Mdot
.31647 .58962 Mdot
.76891 .67022 Mdot
.43297 .19168 Mdot
.47012 .36607 Mdot
.25929 .30593 Mdot
.59239 .19263 Mdot
.78826 .51294 Mdot
.68895 .48339 Mdot
.61346 .64108 Mdot
.75925 .47281 Mdot
.63734 .45878 Mdot
.31034 .32251 Mdot
.46566 .75291 Mdot
.36311 .4589 Mdot
.41878 .64084 Mdot
.47021 .57232 Mdot
.52395 .64897 Mdot
.37623 .58872 Mdot
.63926 .46383 Mdot
.71326 .31396 Mdot
.53291 .37663 Mdot
.82578 .38522 Mdot
.37873 .30177 Mdot
.51815 .52373 Mdot
.44253 .76407 Mdot
.24104 .46468 Mdot
.37118 .22425 Mdot
.4709 .35613 Mdot
.8283 .48793 Mdot
.43032 .39083 Mdot
.43663 .74924 Mdot
.75521 .46198 Mdot
.61142 .76933 Mdot
.60065 .5461 Mdot
.62467 .30878 Mdot
.71786 .6574 Mdot
.53042 .43458 Mdot
.66829 .37141 Mdot
.7092 .41726 Mdot
.57557 .86781 Mdot
.39955 .25055 Mdot
.32826 .33685 Mdot
.82924 .49985 Mdot
.49077 .30347 Mdot
.68135 .39975 Mdot
.51651 .73353 Mdot
.59569 .79227 Mdot
.73401 .62234 Mdot
.33178 .54874 Mdot
.367 .37334 Mdot
.2707 .59015 Mdot
.81322 .45567 Mdot
.79849 .42576 Mdot
.16234 .45574 Mdot
.6288 .38204 Mdot
.63283 .75984 Mdot
.55462 .7873 Mdot
.67524 .43656 Mdot
.59972 .39733 Mdot
.61748 .23647 Mdot
.79382 .34052 Mdot
.54018 .30147 Mdot
.48038 .83899 Mdot
.35076 .71908 Mdot
.31357 .44206 Mdot
.23621 .48154 Mdot
.46958 .80409 Mdot
.82818 .50981 Mdot
.73758 .43246 Mdot
.78873 .48025 Mdot
.5598 .51519 Mdot
.62983 .5035 Mdot
.5315 .15549 Mdot
.45001 .4501 Mdot
.76918 .52775 Mdot
.56864 .36282 Mdot
.58929 .57843 Mdot
.62404 .1647 Mdot
.63636 .7902 Mdot
.37685 .21375 Mdot
.52369 .32543 Mdot
.58254 .62373 Mdot
.53677 .54038 Mdot
.63163 .55349 Mdot
.60007 .30083 Mdot
.6419 .21624 Mdot
.47343 .80517 Mdot
.59911 .3568 Mdot
.74242 .46323 Mdot
.40538 .29869 Mdot
.80638 .58559 Mdot
.68868 .75827 Mdot
.50541 .44348 Mdot
.38799 .29124 Mdot
.3832 .66765 Mdot
.51409 .84271 Mdot
.42799 .54831 Mdot
.44662 .59382 Mdot
.55062 .2175 Mdot
.5828 .32067 Mdot
.22893 .48701 Mdot
.53903 .63886 Mdot
.28707 .3097 Mdot
.79352 .62742 Mdot
.14472 .53556 Mdot
.20857 .39993 Mdot
.64375 .17121 Mdot
.75514 .61907 Mdot
.57259 .32467 Mdot
.78441 .43937 Mdot
.13754 .54471 Mdot
.40472 .57444 Mdot
.77654 .37196 Mdot
.36145 .6922 Mdot
.82238 .47869 Mdot
.49308 .35943 Mdot
.52297 .24935 Mdot
.63979 .22516 Mdot
.80022 .35791 Mdot
.67841 .72722 Mdot
.81805 .542 Mdot
.54101 .4748 Mdot
.77422 .30741 Mdot
.55149 .20897 Mdot
.45231 .51663 Mdot
.37976 .43423 Mdot
.36694 .23691 Mdot
.75332 .37689 Mdot
.69742 .32703 Mdot
.54244 .77354 Mdot
.42218 .53864 Mdot
.57222 .71971 Mdot
.777 .46719 Mdot
.43733 .68314 Mdot
.58964 .32919 Mdot
.44014 .76386 Mdot
.79619 .63566 Mdot
.39773 .56829 Mdot
.243 .47741 Mdot
.39569 .31589 Mdot
.41922 .81247 Mdot
.60204 .29619 Mdot
.39122 .25436 Mdot
.72138 .70925 Mdot
.31189 .57189 Mdot
.48263 .78773 Mdot
.68378 .83991 Mdot
.48768 .81605 Mdot
.68381 .28432 Mdot
.7428 .29802 Mdot
.71367 .74018 Mdot
.70305 .30184 Mdot
.19361 .40713 Mdot
.6407 .55005 Mdot
.4966 .73783 Mdot
.54405 .57998 Mdot
.73387 .24666 Mdot
.43622 .70773 Mdot
.74611 .29573 Mdot
.67424 .7908 Mdot
.76264 .46694 Mdot
.52377 .64967 Mdot
.30837 .5247 Mdot
.40974 .44341 Mdot
.44365 .68072 Mdot
.79505 .48385 Mdot
.64427 .56381 Mdot
.37066 .33558 Mdot
.39473 .44006 Mdot
.34826 .57201 Mdot
.6605 .35383 Mdot
.37016 .29081 Mdot
.59934 .31473 Mdot
.31082 .61051 Mdot
.51039 .4696 Mdot
.50713 .76611 Mdot
.7221 .464 Mdot
.78864 .52511 Mdot
.19602 .46688 Mdot
.44564 .39063 Mdot
.32598 .50535 Mdot
.78439 .5845 Mdot
.50892 .82077 Mdot
.60087 .33697 Mdot
.68849 .23883 Mdot
.35373 .23931 Mdot
.4811 .69091 Mdot
.56946 .73644 Mdot
.18648 .45081 Mdot
.2818 .72448 Mdot
.7372 .3214 Mdot
.71964 .42035 Mdot
.39328 .77542 Mdot
.46524 .58027 Mdot
.82809 .42385 Mdot
.50799 .79797 Mdot
.60216 .73941 Mdot
.43958 .44359 Mdot
.73592 .58866 Mdot
.76413 .44721 Mdot
.40146 .67886 Mdot
.53032 .46555 Mdot
.36317 .18251 Mdot
.59589 .44186 Mdot
.59902 .14704 Mdot
.45781 .32566 Mdot
.30105 .25636 Mdot
.29584 .7093 Mdot
.4742 .4546 Mdot
.53774 .46399 Mdot
.62875 .30304 Mdot
.57034 .23513 Mdot
.53744 .83191 Mdot
.17064 .50804 Mdot
.33504 .45928 Mdot
.43025 .79595 Mdot
.37835 .79586 Mdot
.80041 .54646 Mdot
.56183 .66185 Mdot
.47964 .82013 Mdot
.45316 .44575 Mdot
.2141 .52417 Mdot
.68798 .77133 Mdot
.66516 .32317 Mdot
.51595 .53336 Mdot
.48589 .76099 Mdot
.77514 .37414 Mdot
.83291 .56149 Mdot
.22497 .34262 Mdot
.67206 .33932 Mdot
.51769 .32271 Mdot
.44352 .55864 Mdot
.81015 .47896 Mdot
.39791 .76176 Mdot
.54625 .28442 Mdot
.50331 .77868 Mdot
.50509 .12939 Mdot
.66049 .2286 Mdot
.64104 .2161 Mdot
.43316 .77446 Mdot
.66162 .37576 Mdot
.59076 .2143 Mdot
.58089 .7376 Mdot
.66183 .31553 Mdot
.55123 .81623 Mdot
.531 .76721 Mdot
.15222 .44282 Mdot
.6355 .7203 Mdot
.28872 .51625 Mdot
.75831 .42833 Mdot
.65057 .68691 Mdot
.52038 .33142 Mdot
.48139 .72464 Mdot
.57256 .36302 Mdot
.47692 .2833 Mdot
.59484 .32575 Mdot
.56577 .28936 Mdot
.60985 .73885 Mdot
.74633 .60497 Mdot
.61092 .34849 Mdot
.77198 .62513 Mdot
.60593 .47897 Mdot
.22888 .51015 Mdot
.25204 .45647 Mdot
.56902 .38916 Mdot
.35477 .44871 Mdot
.52345 .68973 Mdot
.52391 .44287 Mdot
.39583 .61091 Mdot
.52271 .16774 Mdot
.32077 .62623 Mdot
.66146 .37979 Mdot
.3477 .21638 Mdot
.67995 .4339 Mdot
.69566 .21133 Mdot
.20163 .50243 Mdot
.75293 .4654 Mdot
.2572 .56974 Mdot
.24458 .62001 Mdot
.22946 .28791 Mdot
.73168 .38134 Mdot
.43407 .43246 Mdot
.67723 .46233 Mdot
.61923 .3992 Mdot
.38032 .34028 Mdot
.39161 .44488 Mdot
.67688 .4984 Mdot
.4184 .31538 Mdot
.47729 .68057 Mdot
.69964 .41322 Mdot
.29592 .49119 Mdot
.58814 .71229 Mdot
.8025 .35393 Mdot
.33109 .49056 Mdot
.43395 .15744 Mdot
.50778 .55357 Mdot
.70516 .69033 Mdot
.73208 .74674 Mdot
.2415 .3214 Mdot
.2519 .4236 Mdot
.30218 .75285 Mdot
.49953 .5893 Mdot
.62522 .34476 Mdot
.66241 .41518 Mdot
.58409 .75406 Mdot
.33076 .66202 Mdot
.40471 .73789 Mdot
.4555 .29703 Mdot
.21496 .45856 Mdot
.36313 .29643 Mdot
.68176 .38274 Mdot
.68356 .33273 Mdot
.63553 .74264 Mdot
.5324 .24561 Mdot
.45608 .44344 Mdot
.79863 .54475 Mdot
.7409 .60737 Mdot
.70014 .41765 Mdot
.69464 .25272 Mdot
.54096 .78523 Mdot
.85365 .48473 Mdot
.59935 .51928 Mdot
.4229 .47191 Mdot
.51107 .22558 Mdot
.6141 .32006 Mdot
.70991 .47091 Mdot
.74196 .72485 Mdot
.44504 .74614 Mdot
.49222 .22988 Mdot
.53439 .75057 Mdot
.59743 .67953 Mdot
.49193 .47407 Mdot
.3181 .30311 Mdot
.17229 .39141 Mdot
.64769 .49818 Mdot
.24286 .34531 Mdot
.71462 .42565 Mdot
.40407 .29617 Mdot
.60087 .4575 Mdot
.27866 .43835 Mdot
.74685 .57981 Mdot
.26933 .38148 Mdot
.84012 .44641 Mdot
.73956 .72863 Mdot
.47788 .37128 Mdot
.37961 .36593 Mdot
.57227 .4587 Mdot
.57132 .51067 Mdot
.54831 .41961 Mdot
.55142 .54844 Mdot
.59491 .39358 Mdot
.26259 .29642 Mdot
.64677 .31248 Mdot
.622 .63016 Mdot
.82137 .42214 Mdot
.85096 .49793 Mdot
.76975 .30637 Mdot
.37355 .77151 Mdot
.64522 .45087 Mdot
.66356 .20615 Mdot
.70001 .50334 Mdot
.80382 .62712 Mdot
.73479 .32561 Mdot
.59793 .85925 Mdot
.79259 .48719 Mdot
.56382 .36465 Mdot
.17827 .51146 Mdot
.57741 .25026 Mdot
.6593 .7874 Mdot
.44394 .52422 Mdot
.32721 .36278 Mdot
.6579 .79238 Mdot
.17286 .3379 Mdot
.70614 .44856 Mdot
.55969 .29132 Mdot
.4603 .59884 Mdot
.57038 .37788 Mdot
.38976 .50197 Mdot
.51741 .60059 Mdot
.38973 .3877 Mdot
.2323 .46565 Mdot
.51337 .76709 Mdot
.56688 .72318 Mdot
.38821 .50587 Mdot
.44739 .67972 Mdot
.54737 .74204 Mdot
.4931 .80463 Mdot
.79499 .51675 Mdot
.68396 .49305 Mdot
.53465 .52672 Mdot
.5909 .44122 Mdot
.32339 .67953 Mdot
.27975 .38922 Mdot
.52346 .57372 Mdot
.26775 .38837 Mdot
.55171 .24145 Mdot
.652 .17952 Mdot
.29654 .40747 Mdot
.61818 .79184 Mdot
.60706 .45438 Mdot
.60856 .30369 Mdot
.76772 .64206 Mdot
.28035 .30425 Mdot
.38677 .5294 Mdot
.62582 .686 Mdot
.81275 .42723 Mdot
.43716 .22221 Mdot
.59232 .77934 Mdot
.50443 .1894 Mdot
.49921 .29051 Mdot
.65392 .48451 Mdot
.45613 .60191 Mdot
.32733 .26743 Mdot
.68606 .37886 Mdot
.56573 .35594 Mdot
.43188 .49385 Mdot
.4234 .22144 Mdot
.6147 .81229 Mdot
.62394 .7549 Mdot
.75552 .41389 Mdot
.8017 .42711 Mdot
.37372 .47054 Mdot
.55349 .77929 Mdot
.55548 .36316 Mdot
.40399 .51378 Mdot
.48919 .21353 Mdot
.8252 .39706 Mdot
.54809 .4327 Mdot
.41985 .70105 Mdot
.5947 .5966 Mdot
.71308 .52385 Mdot
.64311 .3062 Mdot
.2972 .6934 Mdot
.35683 .32467 Mdot
.62455 .40191 Mdot
.34347 .31469 Mdot
.36581 .56976 Mdot
.48075 .73425 Mdot
.67958 .45814 Mdot
.6471 .63219 Mdot
.32022 .61499 Mdot
.40542 .34807 Mdot
.61167 .60845 Mdot
.41083 .71118 Mdot
.36834 .76111 Mdot
.66324 .47963 Mdot
.72851 .35957 Mdot
.79484 .55433 Mdot
.58274 .79634 Mdot
.62262 .32886 Mdot
.73301 .31579 Mdot
.57913 .23741 Mdot
.76217 .56456 Mdot
.27549 .34403 Mdot
.57465 .55224 Mdot
.28046 .43782 Mdot
.68348 .39959 Mdot
.80725 .4975 Mdot
.74618 .62951 Mdot
.40846 .68214 Mdot
.48942 .42977 Mdot
.75469 .66161 Mdot
.47966 .41533 Mdot
.71946 .75327 Mdot
.58029 .25087 Mdot
.46397 .75149 Mdot
.45351 .35479 Mdot
.33329 .70716 Mdot
.19143 .43316 Mdot
.84251 .50051 Mdot
.1901 .47773 Mdot
.48143 .51042 Mdot
.24645 .33466 Mdot
.65201 .25111 Mdot
.66914 .78987 Mdot
.48076 .75031 Mdot
.5471 .4176 Mdot
.58287 .7098 Mdot
.46042 .37073 Mdot
.41252 .39258 Mdot
.27092 .45799 Mdot
.68314 .50486 Mdot
.34638 .39202 Mdot
.25076 .40849 Mdot
.61482 .56409 Mdot
.51496 .20739 Mdot
.80617 .42583 Mdot
.61741 .72076 Mdot
.45888 .45796 Mdot
.23239 .54253 Mdot
.46695 .73045 Mdot
.42947 .86636 Mdot
.62134 .16202 Mdot
.59591 .59789 Mdot
.42012 .57217 Mdot
.41693 .73241 Mdot
.31675 .48717 Mdot
.66618 .52255 Mdot
.8043 .5357 Mdot
.45738 .31239 Mdot
.2851 .46658 Mdot
.41633 .22356 Mdot
.63485 .29814 Mdot
.40993 .65581 Mdot
.45535 .24588 Mdot
.67176 .19003 Mdot
.51452 .82561 Mdot
.62828 .3168 Mdot
.48727 .87543 Mdot
.30769 .2997 Mdot
.71017 .42016 Mdot
.71172 .70931 Mdot
.76316 .31213 Mdot
.42788 .76365 Mdot
.24765 .51994 Mdot
.70398 .28831 Mdot
.45631 .74725 Mdot
.55791 .75516 Mdot
.39523 .3154 Mdot
.34777 .31712 Mdot
.46952 .48677 Mdot
.24586 .6204 Mdot
.54978 .18465 Mdot
.74266 .44173 Mdot
.79109 .40081 Mdot
.22797 .4534 Mdot
.14681 .4589 Mdot
.8493 .48875 Mdot
.47715 .70883 Mdot
.38598 .49881 Mdot
.70253 .71912 Mdot
.37155 .72642 Mdot
.63546 .67787 Mdot
.21024 .48504 Mdot
.72352 .63117 Mdot
.22877 .60239 Mdot
.23654 .38087 Mdot
.53657 .75434 Mdot
.65117 .68026 Mdot
.54792 .43852 Mdot
.78796 .56166 Mdot
.37783 .32533 Mdot
.45142 .7731 Mdot
.27666 .48781 Mdot
.37414 .70929 Mdot
.78984 .57841 Mdot
.74715 .68005 Mdot
.55507 .41703 Mdot
.1895 .31962 Mdot
.75578 .32918 Mdot
.27279 .3207 Mdot
.58676 .55683 Mdot
.83947 .4325 Mdot
.55459 .39326 Mdot
.72678 .30462 Mdot
.59635 .80535 Mdot
.26856 .43352 Mdot
.52147 .22817 Mdot
.56745 .54922 Mdot
.73098 .34822 Mdot
.77088 .52254 Mdot
.65442 .68307 Mdot
.22743 .47525 Mdot
.44295 .76174 Mdot
.3719 .50525 Mdot
.3913 .68437 Mdot
.56083 .50322 Mdot
.6881 .40212 Mdot
.70577 .22868 Mdot
.48469 .51327 Mdot
.53465 .69109 Mdot
.60272 .50474 Mdot
.17845 .49452 Mdot
.4059 .83252 Mdot
.5845 .51086 Mdot
.44631 .22338 Mdot
.5358 .77168 Mdot
.5101 .70737 Mdot
.72661 .41167 Mdot
.13435 .64627 Mdot
.75057 .73546 Mdot
.60747 .41004 Mdot
.65046 .57514 Mdot
.43948 .78428 Mdot
.7769 .32397 Mdot
.2653 .61069 Mdot
.24973 .45337 Mdot
.1632 .56492 Mdot
.37515 .73788 Mdot
.53094 .64648 Mdot
.60212 .8174 Mdot
.84068 .51138 Mdot
.22125 .4534 Mdot
.82808 .43431 Mdot
.55786 .67542 Mdot
.54064 .53622 Mdot
.26276 .77584 Mdot
.81659 .49127 Mdot
.58728 .67234 Mdot
.17556 .4845 Mdot
.69356 .38203 Mdot
.53391 .57489 Mdot
.41909 .2851 Mdot
.50501 .79429 Mdot
.55091 .74707 Mdot
.79944 .35631 Mdot
.67542 .37628 Mdot
.26147 .39706 Mdot
.46652 .2966 Mdot
.53428 .46543 Mdot
.53492 .53209 Mdot
.50127 .32687 Mdot
.49433 .70528 Mdot
.5639 .39589 Mdot
.51296 .35013 Mdot
.43624 .80437 Mdot
.64789 .82859 Mdot
.76527 .59819 Mdot
.50209 .36809 Mdot
.6231 .65588 Mdot
.63924 .71595 Mdot
.44595 .68146 Mdot
.45252 .64844 Mdot
.64491 .8064 Mdot
.83125 .67275 Mdot
.33241 .36736 Mdot
.62188 .54978 Mdot
.68411 .45384 Mdot
.69451 .48822 Mdot
.78301 .50116 Mdot
.51269 .28021 Mdot
.38318 .45761 Mdot
.49834 .6235 Mdot
.56224 .50255 Mdot
.45431 .29986 Mdot
.5649 .14575 Mdot
.52539 .63052 Mdot
.72943 .43161 Mdot
.80945 .61197 Mdot
.22834 .50722 Mdot
.69229 .69737 Mdot
.50297 .60147 Mdot
.57922 .21389 Mdot
.54966 .39189 Mdot
.59623 .37301 Mdot
.24162 .47325 Mdot
.79126 .36932 Mdot
.74231 .63582 Mdot
.75069 .41143 Mdot
.54526 .62717 Mdot
.30307 .67323 Mdot
.55338 .27466 Mdot
.70506 .28274 Mdot
.5111 .52437 Mdot
.82179 .59967 Mdot
.26528 .44103 Mdot
.35557 .39346 Mdot
.52221 .70369 Mdot
.73337 .27 Mdot
.22652 .37883 Mdot
.77238 .48561 Mdot
.34613 .23185 Mdot
.37154 .25377 Mdot
.43885 .6863 Mdot
.30985 .53056 Mdot
.62522 .62365 Mdot
.69527 .38747 Mdot
.69902 .203 Mdot
.69783 .27433 Mdot
.52137 .37494 Mdot
.3427 .34329 Mdot
.74285 .51868 Mdot
.55396 .45424 Mdot
.55193 .87972 Mdot
.3009 .59755 Mdot
.66415 .18392 Mdot
.58885 .75196 Mdot
.69042 .35588 Mdot
.57445 .33596 Mdot
.48377 .58474 Mdot
.33237 .50695 Mdot
.78269 .33834 Mdot
.57027 .49945 Mdot
.25734 .36331 Mdot
.52844 .64213 Mdot
.39477 .20709 Mdot
.50623 .39304 Mdot
.38553 .36139 Mdot
.39435 .36051 Mdot
.19467 .40871 Mdot
.78314 .63628 Mdot
.53803 .39502 Mdot
.52532 .86899 Mdot
.78993 .44667 Mdot
.82923 .48909 Mdot
.33012 .55158 Mdot
.22165 .33152 Mdot
.70591 .32678 Mdot
.60613 .34698 Mdot
.52084 .3812 Mdot
.41051 .60971 Mdot
.352 .2443 Mdot
.51012 .71027 Mdot
.56588 .26586 Mdot
.46347 .36902 Mdot
.88974 .6252 Mdot
.49087 .71438 Mdot
.47146 .60427 Mdot
.28975 .31408 Mdot
.82546 .46013 Mdot
.28429 .6514 Mdot
.61596 .82426 Mdot
.41064 .57343 Mdot
.54495 .53288 Mdot
.73852 .62462 Mdot
.60623 .73109 Mdot
.3784 .23146 Mdot
.28229 .23113 Mdot
.5252 .8204 Mdot
.35072 .37188 Mdot
.51181 .46326 Mdot
.67627 .43388 Mdot
.59903 .41202 Mdot
.25135 .58616 Mdot
.57115 .84443 Mdot
.56318 .37551 Mdot
.81114 .48085 Mdot
.21458 .31022 Mdot
.59343 .76358 Mdot
.78203 .32763 Mdot
.69012 .30233 Mdot
.59073 .43036 Mdot
.45123 .67938 Mdot
.37458 .64367 Mdot
.3958 .3846 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0__oo
ool2o`0008Wooooo000Looooo`03o`000?oooooooooo0;kooooo0_l00029ooooo`007?ooool00ol0
003oooooooooo`29ooooo`;o0000__ooool001cooooo00?o0000ooooooooool0ROooool2o`0001Go
oooo0_l0002Wooooo`007?ooool00ol0003oooooooooo`2Pooooo`;o0000Yoooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Gooooo`;o0000/?ooool0
01cooooo00?o0000ooooooooool0Uoooool2o`0000?ooooo0_l0002[ooooo`007?ooool00ol0003o
ooooooooo`2Looooo`;o00004Oooool2o`0000?ooooo0_l00009ooooo`;o0000R?ooool001cooooo
00?o0000ooooooooool0[oooool2o`0000?ooooo0_l00009ooooo`;o0000R?ooool001cooooo0_l0
003ooooood_ooooo000Looooo`03o`000?oooooooooo0:Wooooo0_l0002Nooooo`007?ooool00ol0
003oooooooooo`29ooooo`;o00007_ooool2o`000003ooooool0003o000009_ooooo000Looooo`03
o`000?oooooooooo08Wooooo0_l0000Mooooo`;o00000_ooool2o`000003ooooool0003o000001Co
oooo0ol00002ooooo`;o0000OOooool001cooooo00?o0000ooooooooool0Z?ooool2o`0000Gooooo
0ol0000Cooooo`Oo0000OOooool001cooooo00?o0000ooooooooool0Roooool2o`0001Oooooo1?l0
0008ooooo`;o00000oooool2o`00013ooooo0ol0001oooooo`007?ooool00ol0003oooooooooo`2;
ooooo`;o00005oooool4o`0000_ooooo1?l0000Fooooo`;o0000N_ooool001cooooo00?o0000oooo
ooooool0/oooool2o`0000Cooooo0_l0000Booooo`;o0000N_ooool001cooooo00?o0000oooooooo
ool0Q?ooool2o`0000?ooooo0_l00005ooooo`;o00009oooool2o`0008kooooo000Looooo`03o`00
0?oooooooooo08Cooooo0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o000003kooooo
0_l0001gooooo`007?ooool00ol0003oooooooooo`1booooo`;o00006Oooool2o`00047ooooo0_l0
0002ooooo`;o00001?ooool2o`0006gooooo000Looooo`03o`000?oooooooooo07;ooooo0_l00007
ooooo`;o00003oooool2o`0000;ooooo0_l0000@ooooo`;o00001oooool3o`000003ooooool0003o
0000013ooooo0_l0000Aooooo`;o00001?ooool2o`0006gooooo000Looooo`03o`000?oooooooooo
07_ooooo0_l00009ooooo`;o00001?ooool2o`0000;ooooo0ol0000=ooooo`Co00001oooool3o`00
0004ooooool0003o0000o`0000oooooo0_l0000Cooooo`;o0000LOooool00006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo06gooooo0_l0
00000ooooooo0000o`00000Dooooo`;o000000?oooooo`000?l000001_ooool2o`0000gooooo0_l0
000>ooooo`;o00002Oooool4o`0001Oooooo0_l0001aooooo`0000KoooooogMgMonHV9SooooooiRH
V?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000oooooooo
ool0KOooool2o`000003ooooool0003o000001Cooooo0_l000000ooooooo0000o`00000Cooooo`?o
00006_ooool4o`0000Kooooo0_l0000?ooooo`;o0000LOooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo06Wooooo
0_l0000Kooooo`;o00005_ooool3o`0001Cooooo0_l00006ooooo`;o00001_ooool2o`0000oooooo
0_l0000Aooooo`;o0000G_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02ooo
ool00onHV9So8B4Qonk^kP06ooooo`?o0000JOooool2o`0001[ooooo0_l00004ooooo`;o00003?oo
ool3o`0000Oooooo0_l00004ooooo`;o00001Oooool7o`0000Kooooo0_l00003ooooo`Co00006Ooo
ool2o`0000Sooooo0_l0001Nooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<
ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0N_ooool2o`0000Cooooo1?l00000
0ooooooo0000o`000004ooooo`;o00001_ooool2o`0000Cooooo0ol000000ooooooo0000o`000004
ooooo`;o00001?ooool2o`0000Gooooo1Ol00008ooooo`;o00000oooool4o`0000kooooo0_l00009
ooooo`;o0000J?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool03Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo07Sooooo1_l00002ooooo`Go00001?ooool3o`00
00Oooooo0_l00005ooooo`;o000000Coooooo`000?l0003o00000_ooool4o`0000?ooooo0ol00003
ooooo`;o00002oooool2o`0001Kooooo0_l00008ooooo`;o0000JOooool00006oooooomgMgOoV9RH
oooooonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
L?ooool2o`0000Kooooo0_l00002ooooo`;o00001Oooool2o`0000Cooooo0ol0000>ooooo`;o0000
0_ooool2o`0000;ooooo1?l00003ooooo`?o00000oooool2o`0000_ooooo0_l0000Eooooo`;o0000
2Oooool2o`0000;ooooo0_l0001Uooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1`ooooo`;o00001Oooool2o`00
00Sooooo1Ol0000Eooooo`;o00001?ooool2o`0000Oooooo0_l00004ooooo`;o00001_ooool8o`00
01?ooooo0_l00009ooooo`;o00000_ooool2o`0006Gooooo000Looooo`03o`000?oooooooooo06go
oooo0_l00005ooooo`;o000000?oooooo`000?l000000_ooool5o`000003ooooool0003o000000Co
00001Oooool:o`0000Cooooo0ol00004ooooo`;o00001_ooool3o`0000?ooooo0ol00006ooooo`So
00002?ooool2o`0000;ooooo0ol0000>ooooo`;o0000J_ooool001cooooo00?o0000ooooooooool0
KOooool2o`0000Gooooo0_l00003ooooo`Oo00000_ooool6o`0000?ooooo2ol00004ooooo`;o0000
1_ooool2o`0000Gooooo0_l00004ooooo`;o00003Oooool2o`0000Sooooo0_l00002ooooo`?o0000
1?ooool2o`0000Sooooo0_l0001Zooooo`007?ooool00ol0003oooooooooo`1eooooo`;o00000_oo
ool3o`0000Oooooo0_l000000ooooooo0000o`000002ooooo`Go000000?oooooo`000?l000000_oo
ool2o`0000cooooo0_l00005ooooo`Co00002oooool2o`0000Cooooo0_l00009ooooo`;o00002?oo
ool2o`0007Cooooo000Looooo`03o`000?oooooooooo077ooooo0_l00002ooooo`;o00001_ooool2
o`0000Cooooo0_l00005ooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o00000ooo
ool2o`0000Gooooo0_l00005ooooo`Ko00000_ooool2o`0000Gooooo0_l0000?ooooo`;o000000Co
ooooo`000?l0003o0000N_ooool001cooooo00?o0000ooooooooool0LOooool2o`0000[ooooo0_l0
0003ooooo`;o00004?ooool4o`000003ooooool0003o000000?o00001?ooool2o`000004ooooool0
003o0000o`0000Gooooo0_l00002ooooo`;o00004?ooool2o`0000?ooooo0ol000000ooooooo0000
o`000002o`0000?ooooo0_l0000<ooooo`;o0000I_ooool001cooooo00?o0000ooooooooool0F?oo
ool4o`00017ooooo0_l00003ooooo`;o00000oooool2o`0000Wooooo0_l00009ooooo`;o00001Ooo
ool2o`0000?ooooo0_l000000ooooooo0000o`000007ooooo`?o00003_ooool2o`0000_ooooo0_l0
0003ooooo`;o00001?ooool2o`0000?ooooo0_l0000<ooooo`;o0000I_ooool001cooooo00?o0000
ooooooooool0F?ooool4o`00017ooooo0ol00002ooooo`?o00000_ooool2o`0000Wooooo0_l00009
ooooo`;o00002?ooool3o`000003ooooool0003o0000013ooooo0_l00006ooooo`?o00003Oooool2
o`0008;ooooo000Looooo`03o`000?oooooooooo06kooooo0ol00002ooooo`;o00003Oooool2o`00
00Gooooo0_l0000:ooooo`Go000000?oooooo`000?l000002oooool2o`0000?ooooo0_l00006oooo
o`Go00000_ooool2o`0000Oooooo0_l0000Eooooo`;o000000?oooooo`000?l00000J?ooool001co
oooo00?o0000ooooooooool0Koooool2o`0000oooooo1?l00003ooooo`Co00002_ooool2o`0000;o
oooo0_l0000=ooooo`;o00001Oooool2o`0000Kooooo0ol00002ooooo`;o00002oooool2o`00017o
oooo0_l000000ooooooo0000o`000002o`0006Kooooo000Looooo`03o`000?oooooooooo06oooooo
0_l0000?ooooo`;o00001?ooool3o`0000Oooooo0_l00004ooooo`Go00000_ooool2o`0000Gooooo
0ol00002ooooo`;o00001?ooool2o`0001Sooooo0_l00004ooooo`;o00001Oooool2o`0000Oooooo
1?l0001Vooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o00000oooool2o`0000?ooooo0_l0
000>ooooo`;o00001Oooool2o`0000Sooooo1?l00002ooooo`Co00000oooool2o`0000Gooooo0ol0
0002ooooo`;o00002_ooool2o`0000Kooooo0_l0000@ooooo`;o00001Oooool2o`0000Oooooo0_l0
000:ooooo`;o0000G?ooool001cooooo0_l0001Vooooo`;o00000oooool2o`0001;ooooo0ol00005
ooooo`?o00001?ooool2o`0000?ooooo0_l0000<ooooo`;o00000oooool3o`0000gooooo0_l00000
1Ooooooo0000o`000?l0003ooooo00?o00001_ooool2o`0000Oooooo1?l0000?ooooo`;o00002?oo
ool4o`0005[ooooo000Looooo`03o`000?oooooooooo06Sooooo1?l00009ooooo`;o00001?ooool2
o`000003ooooool0003o000000?ooooo0_l00002ooooo`Co00000_ooool2o`0000Gooooo1?l00008
ooooo`Co00000_ooool2o`0000Gooooo0_l00009ooooo`?o000000?oooooo`000?l000001oooool2
o`0000Oooooo1?l0000<ooooo`;o000000?oooooo`000?l000002_ooool2o`0005[ooooo000Loooo
o`03o`000?oooooooooo05kooooo0_l00006ooooo`Ko00002Oooool2o`0000?ooooo0ol00004oooo
o`Co00001?ooool2o`0000Wooooo1?l0000:ooooo`;o00002Oooool2o`0001oooooo1?l00007oooo
o`;o00000oooool2o`0000Cooooo0_l0001Sooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o
000000?oooooo`000?l000000oooool2o`0001;ooooo0_l00005ooooo`;o0000:_ooool2o`00027o
oooo0_l00002ooooo`;o00000oooool2o`0000Wooooo0_l00005ooooo`;o0000G?ooool001cooooo
00?o0000ooooooooool0HOooool2o`0000Gooooo0_l0000Mooooo`;o0000:Oooool2o`0001Kooooo
0_l00002ooooo`Co00000_ooool2o`0001Gooooo0_l0001Looooo`007?ooool00ol0003ooooooooo
o`1Wooooo`?o00007Oooool2o`0001_ooooo0_l0000<ooooo`Ko00004_ooool2o`0000;ooooo1Ol0
001fooooo`007?ooool00ol0003oooooooooo`1Rooooo`;o00000oooool4o`0003Sooooo0ol0000>
ooooo`Co00003?ooool2o`0000_ooooo0_l0000Gooooo`;o0000GOooool001cooooo00?o0000oooo
ooooool0FOooool2o`000003ooooool0003o000000Cooooo0_l00005ooooo`;o00001?ooool2o`00
03;ooooo1?l00009ooooo`;o000000?oooooo`000?l000003oooool2o`0000kooooo0_l0000>oooo
o`;o00001?ooool4o`0005_ooooo000Looooo`03o`000?oooooooooo05Wooooo0_l000001?oooooo
0000o`000?ooool2o`000003ooooool0003o000000;ooooo0ol00006ooooo`;o00001oooool2o`00
02Cooooo0_l00003ooooo`Co00000_ooool2o`0000Gooooo0_l000000ooooooo0000o`00000?oooo
o`Co00003?ooool2o`0000Wooooo0_l00003ooooo`;o00001_ooool3o`0005[ooooo000Looooo`03
o`000?oooooooooo05cooooo0_l000000ooooooo0000o`000003o`0000;ooooo0ol00006ooooo`;o
00001oooool2o`0000_ooooo0_l0000?ooooo`;o00001_ooool2o`0000;ooooo0_l00005ooooo`;o
00000_ooool2o`000003ooooool0003o000000;o00003_ooool6o`0000_ooooo0_l0000:ooooo`;o
00003?ooool2o`0005[ooooo000Looooo`03o`000?oooooooooo05_ooooo0_l00003ooooo`?o0000
2?ooool2o`0000;ooooo0_l0000Dooooo`;o00003oooool5o`000003ooooool0003o000000Cooooo
0ol00008ooooo`;o00000_ooool3o`0000kooooo0_l00006ooooo`;o00001oooool2o`0000cooooo
0_l0001Vooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o00003oooool2o`000004ooooool0
003o0000ooooo`;o00002?ooool2o`00017ooooo0_l00004ooooo`;o00004Oooool8o`0000Cooooo
0_l00009ooooo`;o000000Coooooo`000?l0003o00005_ooool2o`0000kooooo0_l00005ooooo`;o
0000I_ooool001cooooo00?o0000ooooooooool0Aoooool2o`000003ooooool0003o000000cooooo
1?l00002ooooo`;o00007Oooool3o`0000Cooooo0_l0000=ooooo`co00002?ooool4o`0000?ooooo
0_l00004ooooo`;o00005?ooool2o`0000kooooo0_l00005ooooo`;o00001Oooool2o`0005oooooo
000Looooo`03o`000?oooooooooo04Oooooo0_l0000=ooooo`Ko00006Oooool2o`0000?ooooo0_l0
00000ooooooo0000o`00000Dooooo`oo00001Oooool4o`0000?ooooo2?l0000=ooooo`;o00004?oo
ool2o`0000Sooooo1?l00005ooooo`;o0000Goooool001cooooo00?o0000ooooooooool0E?ooool7
o`0001;ooooo0_l00006ooooo`;o00000oooool2o`0001;ooooo0_l00003ooooo`oo00000_ooool2
o`0000Sooooo2?l0000=ooooo`Go00003Oooool2o`0000Sooooo0_l0001Xooooo`007?ooool00ol0
003oooooooooo`1Booooo`Co00000oooool4o`0000Cooooo0_l0000:ooooo`;o00000oooool2o`00
00;ooooo0_l00008ooooo`;o00003?ooool5o`000003ooooool0003o000000Wo00000_ooool2o`00
0003ooooool0003o000000Sooooo0_l00002ooooo`Co00002_ooool2o`000003ooooool0003o0000
00?o00000_ooool2o`0001Sooooo0_l00007ooooo`Co0000F?ooool001cooooo0_l0001Cooooo`Co
00001Oooool2o`0000?ooooo0ol0000?ooooo`;o00000_ooool2o`0000Sooooo1?l00009oooooaSo
00001?ooool2o`000003ooooool0003o000000Sooooo0_l000000ooooooo0000o`000004ooooo`?o
00002?ooool4o`0001Kooooo0_l00007ooooo`Ko0000E_ooool001cooooo00?o0000ooooooooool0
A?ooool2o`0000kooooo0_l000000ooooooo0000o`000007ooooo`;o00000_ooool2o`00017ooooo
0_l00007ooooo`Co00000oooool3o`0000?ooooo0_l000000ooooooo0000o`00000Do`0000;ooooo
1_l00008ooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000Cooooo
0_l00002ooooo`;o00001oooool2o`0000Gooooo0_l00003ooooo`;o00001Oooool3o`0000;ooooo
1_l0001Fooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00002oooool2o`0000Cooooo0_l0
000;ooooo`;o00004Oooool2o`0000Kooooo0_l00006ooooo`?o00000_oooolJo`0000;ooooo0_l0
00000ooooooo0000o`000008ooooo`;o00001?ooool2o`0000Gooooo0_l00004ooooo`;o00000ooo
ool2o`0000Kooooo0_l00005ooooo`;o00000oooool4o`0000?ooooo0ol00002ooooo`;o00001ooo
ool4o`0004oooooo000Looooo`03o`000?oooooooooo04;ooooo0_l0000=ooooo`;o00001Oooool4
o`0002?ooooo0_l0000;ooooo`co000000?oooooo`000?l000003Ol0000=ooooo`;o00000_ooool4
o`0000[ooooo0_l00004ooooo`Co00004_ooool2o`00017ooooo1?l0001?ooooo`007?ooool00ol0
003oooooooooo`12ooooo`;o00005?ooool4o`0003;ooooo7?l00004ooooo`;o000000?oooooo`00
0?l000001_ooool2o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`;o00001Oooool3o`00
01?ooooo0_l0000>ooooo`;o00001?ooool2o`0004gooooo000Looooo`03o`000?oooooooooo05[o
oooo0_l00003ooooo`;o00002oooool2o`000003ooooool0003o000000cooooo0_l00005ooooo`;o
00001_oooolOo`0000?ooooo0_l000000ooooooo0000o`00000;ooooo`Go00001Oooool2o`0000Co
oooo0_l00003ooooo`;o00003oooool2o`0000Cooooo0ol00007ooooo`;o00001?ooool2o`0004go
oooo000Looooo`03o`000?oooooooooo03[ooooo0_l0000Nooooo`;o00000oooool2o`0000?ooooo
0ol00005ooooo`Go00003?ooool2o`0000Gooooo0_l00002ooooo`;o00000_oooolJo`0000?ooooo
0_l0000Dooooo`;o00000oooool2o`0000;ooooo0_l00006ooooo`;o000000?oooooo`000?l00000
3Oooool2o`0000Kooooo1Ol00002ooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0>_oo
ool2o`0000oooooo0_l00008ooooo`;o00002_ooool6o`0000Kooooo0_l00008ooooo`;o00001Ooo
ool2o`0000Sooooo0_l00003oooooaWo00002_ooool2o`0000Sooooo0_l000000ooooooo0000o`00
0005ooooo`;o00000oooool2o`0000Gooooo0_l00002ooooo`;o00003?ooool2o`000003ooooool0
003o000000Gooooo0ol00002ooooo`;o00005oooool2o`0003gooooo000Looooo`03o`000?oooooo
oooo04_ooooo0_l00004ooooo`Ko00001_ooool2o`0000;ooooo0ol0000<ooooo`;o000000?ooooo
o`000?l000000_ooool2o`0000Gooooo1Ol0000:oooooa_o00001?ooool2o`0000;ooooo0_l00004
ooooo`;o00000_ooool2o`000003ooooool0003o000000[ooooo0_l00009ooooo`;o00003oooool2
o`000004ooooool0003o0000ooooo`?o00002oooool3o`0000kooooo0_l0000mooooo`007?ooool0
0ol0003oooooooooo`1Aooooo`Co00002?ooool2o`0000?ooooo0ol0000;ooooo`;o000000?ooooo
o`000?l000001?l00006ooooo`Co00002OoooolIo`000003ooooool0003o000000Cooooo0_l00008
ooooo`;o00001?ooool3o`0000Oooooo0_l0000Gooooo`;o000000?oooooo`000?l000001?ooool2
o`000003ooooool0003o000000Gooooo0_l00005ooooo`?o00003oooool2o`0003cooooo000Loooo
o`03o`000?oooooooooo04Cooooo0_l00002ooooo`;o00002oooool2o`0000_ooooo0ol0000?oooo
o`?o00004?ooool2o`0000;ooooo7?l00004ooooo`;o00000_ooool2o`0000Sooooo0_l000000ooo
oooo0000o`000008ooooo`;o00003_ooool2o`0000Oooooo0_l000000ooooooo0000o`00000>oooo
o`;o00001_ooool2o`0000oooooo0_l0000looooo`007?ooool00ol0003oooooooooo`14ooooo`;o
00000_ooool2o`0000;ooooo0_l00007ooooo`;o00005?ooool4o`0000;ooooo1_l000000ooooooo
0000o`00000=ooooo`;o00000_oooolLo`0000;ooooo1?l00002ooooo`;o00002?ooool2o`0000_o
oooo0_l0000>ooooo`;o00000_ooool2o`00033ooooo0_l0000kooooo`007?ooool00ol0003ooooo
ooooo`0dooooo`;o00005_ooool2o`0000Sooooo1?l0000=ooooo`;o00000_ooool4o`0000;ooooo
1_l000000ooooooo0000o`00000@ooooo`;o00000_oooolHo`0000?ooooo0_l0000<ooooo`;o0000
1_ooool2o`0000Gooooo0_l00007ooooo`;o00002Oooool2o`00017ooooo0_l0000;ooooo`;o0000
4?ooool2o`0003_ooooo000Looooo`03o`000?oooooooooo03Cooooo0_l00003ooooo`;o00003_oo
ool2o`0000_ooooo1?l0000=ooooo`;o00000_ooool2o`0000_ooooo0_l0000@ooooo`?o00000_oo
oolHo`00013ooooo0_l00006ooooo`;o00003_ooool2o`000003ooooool0003o000000?ooooo0_l0
000Dooooo`;o00002?ooool2o`000003ooooool0003o000000;ooooo0_l00019ooooo`007?ooool0
0ol0003oooooooooo`0iooooo`;o00002_ooool2o`0000;ooooo0_l0000:ooooo`Co00004_ooool3
o`0000Sooooo1?l00006ooooo`;o000000?oooooo`000?l000001_oooolLo`0000_ooooo0ol00005
ooooo`Co000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00002Oooool2o`0000;ooooo0ol0
000;ooooo`;o00001?ooool4o`0000Cooooo0_l00003ooooo`;o00001Oooool2o`0004Wooooo000L
ooooo`03o`000?oooooooooo04Gooooo0_l00004ooooo`;o00002?ooool4o`0000Kooooo1?l00008
ooooo`?o00002?ooool4o`000004ooooool0003o0000o`0000;ooooo0_l000000ooooooo0000o`00
0007ooooo`Wo000000?oooooo`000?l000002_l000000ooooooo0000o`00000=ooooo`?o00001Ooo
ool4o`000003ooooool0003o000000?o00000oooool2o`0000;ooooo0_l00009ooooo`;o00001_oo
ool2o`0000Cooooo0_l00004ooooo`Co00001?ooool2o`0005Gooooo000Looooo`;o0000C?ooool2
o`0000;ooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000?ooooo1?l00004
ooooo`?o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l00002ooooo`Ko00000_ooool2
o`0000_ooooo6?l0000Gooooo`;o00000oooool4o`0000Kooooo0_l0000Aooooo`Co00001?ooool2
o`0000;ooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1?ooooo`;o00000_ooool2o`00
00;ooooo0_l000000ooooooo0000o`00000;ooooo`?o000000?oooooo`000?l000000_ooool2o`00
00?ooooo0_l00002ooooo`?o00000_ooool2o`000004ooooool0003o0000o`0000Gooooo0_l00006
oooooaGo00004oooool2o`0000Wooooo0_l0000=ooooo`?o00002_ooool3o`0000Cooooo0_l00002
ooooo`;o00005Oooool2o`0004Kooooo000Looooo`03o`000?oooooooooo04Wooooo0_l0000<oooo
o`;o00008oooool3o`0000;ooooo0ol00004ooooo`;o000000?oooooo`000?l000000ooooolAo`00
0003ooooool0003o0000013ooooo0_l00002ooooo`;o00001Oooool2o`0000;ooooo0_l0000=oooo
o`?o00001oooool2o`0000cooooo1?l0000Booooo`?o0000A_ooool001cooooo00?o0000oooooooo
ool0@Oooool3o`0000?ooooo1?l00005ooooo`;o000000?oooooo`000?l000000_ooool2o`0002?o
oooo1Ol000000ooooooo0000o`000007ooooo`;o00000oooool2o`000003ooooool0003o000000Wo
000000Coooooo`000?l0003ooooo0_l0000@ooooo`;o00002Oooool2o`0000;ooooo0_l00007oooo
o`;o00002oooool2o`000003ooooool0003o000000Wooooo1ol0000?ooooo`;o000000?oooooo`00
0?l00000Aoooool001cooooo00?o0000ooooooooool0@Oooool3o`0000?ooooo0_l000000ooooooo
0000o`000003ooooo`Ko00000_ooool2o`0000kooooo0_l0000@ooooo`;o000000?oooooo`000?l0
00000ol0000Booooo`_o00001_ooool2o`0000_ooooo0_l00002ooooo`?o00005?ooool2o`0000;o
oooo0_l00007ooooo`;o00003?ooool4o`0001;ooooo0_l000000ooooooo0000o`000017ooooo`00
7?ooool00ol0003oooooooooo`0]ooooo`;o00006oooool2o`000003ooooool0003o000000Co0000
1?ooool2o`000004ooooool0003o0000o`0000Cooooo0_l00004ooooo`?o00001?ooool2o`0000So
oooo0ol000000ooooooo0000o`000003o`0001;ooooo2_l00007ooooo`;o00002oooool7o`0001So
oooo0_l000000ooooooo0000o`000004ooooo`;o00007oooool2o`0004gooooo000Looooo`03o`00
0?oooooooooo02gooooo0_l0000Fooooo`?o00001Oooool2o`0000Kooooo1?l000001?oooooo0000
o`000?l00002ooooo`Co00001Oooool2o`0000Cooooo0_l00008ooooo`;o00000oooool4o`000003
ooooool0003o000000oooooo1Ol00003ooooo`?o000000?oooooo`000?l000004_ooool2o`0000co
oooo0_l00008ooooo`;o000000?oooooo`000?l000000oooool2o`0000Cooooo0_l0000Oooooo`;o
000000?oooooo`000?l00000B_ooool001cooooo00?o0000ooooooooool0AOooool3o`0000gooooo
0_l00004ooooo`Ko00001oooool2o`0000Cooooo0_l0000>ooooo`?o000000?oooooo`000?l00000
3_ooool3o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000001_ooool2o`0001Sooooo
0_l00008ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00005?ooool2o`0000Ko
oooo0_l00003ooooo`;o00000oooool2o`0004[ooooo000Looooo`03o`000?oooooooooo03Cooooo
0_l00006ooooo`;o00002Oooool2o`00013ooooo0_l000000ooooooo0000o`000004o`0000Sooooo
0_l00002ooooo`;o00000oooool2o`0000Gooooo0ol000001?oooooo0000o`000?ooool2o`0000oo
oooo0_l000000ooooooo0000o`000002o`0000Oooooo0_l00004ooooo`Ko00001oooool2o`0000Wo
oooo0_l00006ooooo`?o00002?ooool2o`0000;ooooo0ol0000Cooooo`;o00001_ooool2o`0000?o
oooo0_l00002ooooo`;o00000_ooool2o`0004Oooooo000Looooo`03o`000?oooooooooo03Cooooo
0_l00006ooooo`;o00002Oooool2o`00013ooooo0_l000000ooooooo0000o`000004o`0000Sooooo
0_l00006ooooo`?o000000?oooooo`000?l000000_ooool3o`0000Cooooo0_l0000Booooo`Co0000
1oooool2o`0000Cooooo1_l00007ooooo`;o000000?oooooo`000?l000001_ooool4o`0000?ooooo
1?l000000ooooooo0000o`000007ooooo`;o000000?oooooo`000?l000000_l0000Gooooo`;o0000
1Oooool2o`0000;ooooo0_l00002ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0@_oo
ool2o`0000;ooooo0_l000000ooooooo0000o`000009ooooo`;o00002Oooool2o`0000_ooooo0_l0
0003ooooo`?o00000_ooool2o`0000?ooooo1Ol00002ooooo`;o00004Oooool4o`0000Oooooo0_l0
0003ooooo`?o000000?oooooo`000?l000002oooool2o`0000Sooooo0_l00002ooooo`?o00000_oo
ool8o`0000;ooooo1?l000000ooooooo0000o`000005o`0000_ooooo0_l00005ooooo`Co0000E?oo
ool001cooooo00?o0000ooooooooool0@_ooool2o`0000;ooooo0_l000000ooooooo0000o`000003
ooooo`;o00001?ooool2o`0000Wooooo0_l0000;ooooo`Co000000?oooooo`000?l000002?ooool5
o`0000;ooooo0_l0000Kooooo`Go000000?oooooo`000?l000007Oooool3o`000003ooooool0003o
000001Go00002oooool2o`0000Oooooo0_l0000=ooooo`;o00001?ooool2o`0003oooooo000Loooo
o`03o`000?oooooooooo03;ooooo0_l0000=ooooo`Co00001_ooool2o`000003ooooool0003o0000
00Kooooo0_l0000Fooooo`;o00001_ooool2o`0000?ooooo2Ol0000<ooooo`;o00002oooool4o`00
0003ooooool0003o000000gooooo0ol0000Aoooooaco00000_ooool2o`0001[ooooo0_l000000ooo
oooo0000o`000004ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0<_ooool2o`0000Oo
oooo0_l00004ooooo`Co00001_ooool2o`0000Kooooo0_l000001?oooooo0000o`000?l0000Moooo
o`?o00000_ooool:o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000002oooool2o`00
0003ooooool0003o000000Gooooo0_l00008ooooo`Ko00002_oooolHo`000004ooooool0003o0000
ooooo`Co00000_ooool4o`0000;ooooo0_l0000Dooooo`;o00001oooool2o`0003oooooo00001_oo
ooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?oo
ool00ol0003oooooooooo`0dooooo`;o00001Oooool2o`0000?ooooo1?l0000?ooooo`?o000000?o
ooooo`000?l000005?ooool2o`000003ooooool0003o000000Gooooo0_l00002ooooo`;o000000?o
ooooo`000?l000001Ol00003ooooo`;o00000oooool2o`0000_ooooo0_l00004ooooo`?o00001?oo
ool2o`0000Kooooo0ol000000ooooooo0000o`000002o`0000Kooooo0_l00002oooooaWo00002ooo
ool2o`0000;ooooo0_l0000:ooooo`;o0000D_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0aooooo`;o0000
00?oooooo`000?l000002_ooool4o`0000gooooo1Ol0000Gooooo`;o000000?oooooo`000?l00000
2oooool8o`0001Gooooo0_l00005ooooo`;o00002?ooool2o`0000;ooooo2?l00006ooooo`;o0000
0oooool7o`0000;ooooo1?l000000ooooooo0000o`00000<o`0001Oooooo0ol00003ooooo`;o0000
1oooool2o`0000;ooooo0_l0000oooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`09ooooo`Go00001_ooool00ol0003oooooooooo`0aooooo`;o00003Oooool2o`0000Kooooo0_l0
0007ooooo`?o0000:Oooool7o`0000Oooooo0_l00007ooooo`;o00005Oooool2o`0000;ooooo0_l0
00000ooooooo0000o`000003o`0000Sooooo0_l00002oooooaco00005oooool2o`0000?ooooo0_l0
0007ooooo`;o00000_ooool2o`0003oooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`00043ooooo0_l00006ooooo`;o0000:?oo
ool2o`0000Oooooo2?l00008ooooo`;o00001_ooool3o`0000;ooooo0_l0000?ooooo`;o00001?oo
ool2o`0000kooooo0_l00003oooooa_o00007_ooool2o`0001Sooooo0_l0000`ooooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o
0000ooooooooool0@?ooool2o`0000Wooooo0_l0000Uooooo`;o000000?oooooo`000?l000000ol0
00000ooooooo0000o`000006o`00013ooooo0_l00003ooooo`;o00001Oooool2o`0000Sooooo0_l0
000Ioooooa_o00007_ooool2o`0000Kooooo0_l0000@ooooo`;o0000<?ooool00003ooooool@413o
oooo00;ooooo00?o410@ooooooooool02_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooo
oooo037ooooo0_l00008ooooo`?o00003Oooool2o`000003ooooool0003o000000Oooooo0_l00004
ooooo`;o00004?ooool2o`000004ooooool0003o0000ooooo`Go000000?oooooo`000?l000001_l0
000Eooooo`;o00001Oooool2o`0000?ooooo0_l0000Eooooo`;o00001?ooool2o`000003ooooool0
003o000001Wo00001_ooool2o`0001kooooo1?l00010ooooo`0000KoooooogMgMonHV9SooooooiRH
V?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0<Oooool2o`0000Cooooo
0_l00002ooooo`?o00000_ooool2o`0000cooooo0_l00006ooooo`?o00001?ooool2o`0000Cooooo
0_l0000:ooooo`;o00000oooool3o`000004ooooool0003o0000ooooo`So000000?oooooo`000?l0
00001oooool2o`0001Gooooo0_l0000Booooo`;o000000?oooooo`000?l000000_oooolBo`000003
ooooool0003o000000go00001?ooool2o`000003ooooool0003o000000Gooooo0ol00002ooooo`;o
00003oooool4o`00043ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`00
0?ooool01_ooool00ol0003oooooooooo`0dooooo`;o000000?oooooo`000?l000000_ooool3o`00
00;ooooo0_l0000Dooooo`Co00000oooool2o`0000Cooooo0_l0000?ooooo`?o000000Coooooo`00
0?l0003ooooo2?l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000001_ooool2
o`000003ooooool0003o000000Wooooo1_l00006ooooo`Co00001Oooool2o`0000Cooooo7_l00000
0ooooooo0000o`000003o`0000Kooooo0_l00005ooooo`Oo00003_ooool3o`0004;ooooo000Loooo
o`03o`000?oooooooooo03Cooooo0_l00005ooooo`?o00006_ooool2o`0001[ooooo3_l00008oooo
o`;o00002Oooool2o`000004ooooool0003o0000ooooo`?o00001Oooool6o`0000Gooooo1Ol0000;
oooooako000000?oooooo`000?l000000ol000000ooooooo0000o`00000=ooooo`Co00001oooool2
o`0000Gooooo0ol00012ooooo`007?ooool00ol0003oooooooooo`1?ooooo`;o00008_ooool@o`00
01Sooooo0ol00009ooooo`;o000000Coooooo`000?l0003ooooo0ol000000ooooooo0000o`000004
ooooo`;o00001oooool2o`0000;ooooo2ol000000ooooooo0000o`00000;o`000003ooooool0003o
000000;o000000?oooooo`000?l000000ol0000Eooooo`;o00001_ooool2o`0001?ooooo0_l0000]
ooooo`007?ooool00ol0003oooooooooo`1=ooooo`Co00003?ooool2o`0000;ooooo0_l00009oooo
o`;o00001Oooool3o`000005ooooool0003o0000o`000?ooool02?l0000@ooooo`;o00002?ooool2
o`0000Sooooo0_l000000ooooooo0000o`000004o`0000Oooooo0ol00006ooooo`;o000000?ooooo
o`000?l000004?l000000ooooooo0000o`00000:o`000003ooooool0003o000000?o00002Oooool2
o`0001Cooooo1?l0000?ooooo`;o0000;Oooool001cooooo00?o0000ooooooooool0=_ooool2o`00
00;ooooo0_l00003ooooo`;o00003?ooool3o`0000gooooo0_l00002ooooo`;o00000_ooool2o`00
0003ooooool0003o000000;ooooo0_l00006ooooo`Go00000_ooool6o`0000oooooo0_l000000ooo
oooo0000o`000008ooooo`;o00002_ooool4o`0000_ooooo0_l000000ooooooo0000o`000002o`00
00;ooooo5_l000000ooooooo0000o`000005o`000003ooooool0003o000000;ooooo0_l0000;oooo
o`;o00001Oooool2o`0000Kooooo1_l000000ooooooo0000o`000002o`0000Wooooo0_l0000coooo
o`007?ooool00ol0003oooooooooo`0fooooo`;o00000_ooool2o`0000?ooooo0_l0000=ooooo`;o
000000?oooooo`000?l000004_ooool2o`000003ooooool0003o000000Wooooo3Ol0000@ooooo`;o
00002Oooool2o`0000Sooooo2?l0000;ooooo`;o000000?oooooo`000?l000001_l000000ooooooo
0000o`00000Io`0000Gooooo0_l0000=ooooo`;o00000oooool2o`0000Kooooo1_l00003ooooo`;o
00002Oooool2o`0003?ooooo000Looooo`03o`000?oooooooooo03[ooooo0_l0000Eooooo`;o0000
00?oooooo`000?l000006oooool>o`0000[ooooo0_l00004ooooo`;o000000?oooooo`000?l00000
1oooool2o`0000Sooooo1ol00002ooooo`;o00003?oooolOo`0000;ooooo1Ol00007ooooo`;o0000
00?oooooo`000?l000001Oooool2o`0000?ooooo0_l0000?ooooo`;o00000_ooool2o`0003[ooooo
000Looooo`03o`000?oooooooooo03[ooooo0_l0000Hooooo`;o00001?ooool2o`0000Gooooo0_l0
000>ooooo`[o000000Coooooo`000?l0003o00002_ooool2o`0000?ooooo0ol000000ooooooo0000
o`00000@ooooo`?o00000_ooool3o`0000;ooooo0_l00009ooooo`;o00000_ooool2o`000003oooo
ool0003o000001Wo00000oooool4o`0000Oooooo0_l000000ooooooo0000o`00000:ooooo`;o0000
3oooool3o`000003ooooool0003o000000oooooo0_l0000Yooooo`007?ooool00ol0003ooooooooo
o`1Gooooo`;o000000?oooooo`000?l000001Oooool2o`0000Wooooo0_l000000ooooooo0000o`00
0002o`000003ooooool0003o000000Wo00001?ooool2o`000003ooooool0003o000000?o00000ooo
ool2o`0000Cooooo0_l0000>ooooo`;o00000oooool2o`0000?ooooo0_l000000ooooooo0000o`00
0006ooooo`;o000000Coooooo`000?l0003o00000ooooolIo`0000Cooooo0_l000000ooooooo0000
o`00000>ooooo`;o00001oooool2o`0000cooooo0ol0000>ooooo`?o000000?oooooo`000?l00000
:Oooool001cooooo00?o0000ooooooooool0;_ooool2o`0002;ooooo0_l00003ooooo`;o00002Ooo
ool2o`0000Sooooo4_l00005ooooo`;o000000?oooooo`000?l000000ol00005ooooo`;o00000_oo
ool2o`00013ooooo0_l00006ooooo`Ko00002?ooool4o`0000;ooooo7?l00004ooooo`;o00002Ooo
ool2o`0000?ooooo0_l00007ooooo`;o00002oooool2o`00013ooooo0ol0000/ooooo`007?ooool0
0ol0003oooooooooo`0Zooooo`;o00000_ooool2o`0000Gooooo0_l0000Dooooo`;o00001Oooool2
o`0000cooooo1?l00004ooooo`;o00000oooool@o`0000;ooooo1?l00008ooooo`;o00000_ooool3
o`0000kooooo0_l00004ooooo`;o00001_ooool3o`000003ooooool0003o000000Sooooo1?l00003
oooooa_o00000_ooool2o`0000_ooooo0_l0000:ooooo`;o00002_ooool2o`000003ooooool0003o
000000?ooooo0_l0000;ooooo`;o0000;Oooool001cooooo00?o0000ooooooooool0:_ooool2o`00
00Wooooo0_l0000Dooooo`;o00004oooool2o`0000Kooooo0_l00003ooooo`_o000000?oooooo`00
0?l000000_l00002ooooo`Co00002?ooool2o`0000;ooooo0ol00006ooooo`;o00001_ooool2o`00
00[ooooo0_l000000ooooooo0000o`00000BoooooaSo00001Oooool4o`0000Kooooo0_l00008oooo
o`;o00000oooool2o`0000;ooooo0_l00006ooooo`?o00001Oooool2o`0000_ooooo0_l0000]oooo
o`007?ooool2o`0003[ooooo0_l0000Aooooo`;o00007_ooool@o`0000Sooooo0_l00008ooooo`;o
00002?ooool2o`0001;ooooo0_l000000ooooooo0000o`000002o`0000kooooo0_l000000ooooooo
0000o`00000Eo`0000Oooooo0_l00006ooooo`Co00001_ooool2o`0000Oooooo0_l00007ooooo`;o
0000@Oooool001cooooo00?o0000ooooooooool0<_ooool2o`0000Gooooo0_l00009ooooo`Co0000
1?ooool3o`000003ooooool0003o000001;ooooo0_l000000ooooooo0000o`00000Co`0000Gooooo
0_l000000ooooooo0000o`000003ooooo`;o00000oooool4o`0000Cooooo0_l00006ooooo`;o0000
00?oooooo`000?l000002Oooool2o`000003ooooool0003o000000;o000000?oooooo`000?l00000
2oooool2o`000003ooooool0003o000000?o00000_oooolAo`0000cooooo0_l00002ooooo`;o0000
4Oooool2o`0000?ooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`0aooooo`?o00000ooo
ool5o`0000Kooooo1_l000000ooooooo0000o`000002ooooo`Go00000_ooool2o`0000kooooo0_l0
00000ooooooo0000o`00000Co`0000Cooooo1?l00005ooooo`;o00001Oooool3o`0000?ooooo0_l0
0006ooooo`;o000000Coooooo`000?l0003o00003?ooool2o`0000;ooooo1?l00007ooooo`Co0000
00?oooooo`000?l000000_l00003ooooo`;o000000?oooooo`000?l000001ol000000ooooooo0000
o`000002o`0000cooooo0_l0000Eooooo`;o00000oooool4o`00047ooooo000Looooo`03o`000?oo
oooooooo02cooooo0_l00003ooooo`;o00001?ooool2o`000003ooooool0003o000000Kooooo0_l0
0004ooooo`?o00000oooool2o`0000Cooooo0_l0000:ooooo`;o00001_oooolCo`0000Cooooo1_l0
0005ooooo`;o00000_ooool2o`000003ooooool0003o000000?ooooo0_l0000:ooooo`;o00001ooo
ool3o`0000?ooooo0_l00003ooooo`;o00001?ooool5o`0000;ooooo1?l000001?oooooo0000o`00
0?ooool2o`000003ooooool0003o000000Co000000?oooooo`000?l000000_ooool2o`0002_ooooo
1?l0000oooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00000_ooool2o`0001Kooooo0_l0
00000ooooooo0000o`00000Cooooo`;o00001oooool3o`000003ooooool0003o000000co00001?oo
ool2o`000004ooooool0003o0000o`0000Gooooo0_l00002ooooo`;o00001_ooool2o`0000[ooooo
0_l00007ooooo`?o00000oooool2o`0000Wooooo1?l000000ooooooo0000o`000002o`000003oooo
ool0003o000000;o000000?oooooo`000?l000001_l00002ooooo`;o000000?oooooo`000?l00000
3?ooool3o`0000?ooooo0ol00003ooooo`;o00005?ooool2o`00017ooooo0_l0000/ooooo`007?oo
ool00ol0003oooooooooo`0`ooooo`;o00002_ooool4o`000003ooooool0003o000000Gooooo0_l0
00000ooooooo0000o`00000<ooooo`?o00002Oooool2o`000003ooooool0003o0000013o00004ooo
ool2o`0000Gooooo0_l0000<ooooo`;o00001?ooool5o`0000Gooooo0_l00002ooooo`Go00000ooo
ool2o`000003ooooool0003o000000;o000000?oooooo`000?l000000ol000000ooooooo0000o`00
0002ooooo`;o00001_ooool2o`0000;ooooo0_l00008ooooo`Go000000?oooooo`000?l000000_l0
00000ooooooo0000o`000003o`0000?ooooo0_l0000:ooooo`;o00001Oooool2o`0000gooooo0_l0
000/ooooo`007?ooool00ol0003oooooooooo`0kooooo`Go000000?oooooo`000?l000000oooool4
o`0000oooooo0ol00003ooooo`;o00001?oooolEo`0001?ooooo0_l00005ooooo`;o00003?ooool2
o`0000?ooooo1Ol00006ooooo`?o000000?oooooo`000?l000000ol00003ooooo`;o000000?ooooo
o`000?l000001?ooool4o`0000Gooooo0_l0000:ooooo`;o00001Oooool4o`000004ooooool0003o
0000o`0000;ooooo0ol000001?oooooo0000o`000?ooool2o`0000?ooooo0_l0000:ooooo`;o0000
1Oooool2o`00017ooooo0_l0000Xooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00000_oo
ool3o`0000Sooooo0_l00003ooooo`;o00004_ooool2o`0000Cooooo5ol0000:ooooo`;o00000ooo
ool2o`0000oooooo0_l00004ooooo`;o00000_ooool3o`000003ooooool0003o000000;ooooo0_l0
0003ooooo`?o00001Oooool2o`0000;ooooo0_l00006ooooo`Ko00000oooool2o`0000Oooooo0_l0
0008ooooo`Co00001_ooool2o`0000Cooooo0_l0000Zooooo`;o0000:?ooool001cooooo00?o0000
ooooooooool0=Oooool5o`0000;ooooo0_l00008ooooo`;o00000oooool2o`0001Sooooo5?l00000
0ooooooo0000o`00000:ooooo`;o00000oooool2o`0000gooooo1?l00008ooooo`;o00001?ooool4
o`0000Cooooo0_l00005ooooo`;o00000_ooool2o`0000[ooooo0_l00003ooooo`;o00001oooool2
o`0000Kooooo0_l00005ooooo`;o00002Oooool2o`0001[ooooo0_l0000hooooo`007?ooool00ol0
003oooooooooo`0eooooo`;o000000?oooooo`000?l000000_l00005ooooo`;o00000oooool2o`00
00;ooooo0ol0000EoooooaKo00008_ooool2o`00013ooooo0_l00008ooooo`;o00001_ooool2o`00
0003ooooool0003o000000[ooooo0_l00005ooooo`;o00002oooool2o`0000;ooooo0_l000000ooo
oooo0000o`000008ooooo`?o00001oooool3o`0000Cooooo0_l00002ooooo`;o00001_ooool2o`00
03Sooooo000Looooo`03o`000?oooooooooo03[ooooo0_l00005ooooo`Ko00000_ooool4o`0001Go
oooo5_l0000;ooooo`;o00007_ooool2o`0000oooooo1?l00006ooooo`;o000000?oooooo`000?l0
00002_ooool2o`0000Gooooo0_l00006ooooo`;o00000oooool6o`0000_ooooo0_l00006ooooo`Go
00001?ooool3o`000003ooooool0003o000000;o0000?_ooool001cooooo00?o0000ooooooooool0
=Oooool2o`0000Cooooo0_l00004ooooo`Ko00000_ooool2o`0000gooooo0_l00003ooooo`;o0000
0_oooolCo`000004ooooool0003o0000o`0000_ooooo0_l0000Nooooo`Co00002Oooool2o`0000;o
oooo0ol0000Booooo`?o00001Oooool2o`0000Wooooo0_l00005ooooo`;o00002?ooool2o`0000;o
oooo0_l00004ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l00003ooooo`;o
00001_ooool2o`0003Kooooo000Looooo`03o`000?oooooooooo03Gooooo0_l00004ooooo`;o0000
1?ooool2o`0000Cooooo0_l000000ooooooo0000o`00000:ooooo`Co00000oooool2o`0000;ooooo
3ol000000ooooooo0000o`000004o`0001kooooo0_l0000>ooooo`;o00001?ooool2o`0000?ooooo
0_l00005ooooo`;o00002?ooool2o`0000Kooooo0ol00004ooooo`?o00002oooool2o`000003oooo
ool0003o000000[ooooo1_l00004ooooo`;o00001Oooool2o`0000Wooooo0ol00003ooooo`Co0000
=_ooool001cooooo00?o0000ooooooooool0>Oooool2o`0000cooooo0_l000000ooooooo0000o`00
000:ooooo`?o00000oooool2o`0000Gooooo5?l0000Nooooo`;o00000_ooool2o`0000Gooooo0_l0
0005ooooo`;o00000_ooool2o`0000[ooooo0_l000000ooooooo0000o`000005ooooo`;o00001Ooo
ool3o`0000Gooooo0_l0000<ooooo`;o000000Coooooo`000?l0003o00002oooool2o`0000gooooo
0_l00005ooooo`;o00000_ooool3o`0000?ooooo0ol0000gooooo`007?ooool00ol0003ooooooooo
o`0fooooo`;o000000?oooooo`000?l000007?ooool2o`0000?ooooo0_l000001?oooooo0000o`00
0?oooolBo`0000[ooooo0_l00009ooooo`;o00003_ooool2o`0000?ooooo1?l00005ooooo`;o0000
2_ooool2o`0000?ooooo1?l0000<ooooo`;o00004?ooool2o`0000Kooooo0_l00003ooooo`;o0000
2_ooool2o`0000[ooooo0_l00004ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0=_oo
ool2o`0000[ooooo0_l0000Cooooo`;o00001_oooolGo`0000;ooooo1?l00002ooooo`;o00002Ooo
ool2o`0001?ooooo0_l00004ooooo`;o00000oooool2o`0000Sooooo0_l00003ooooo`Co00002Ooo
ool3o`0000Oooooo0_l00002ooooo`;o00000oooool6o`0000Wooooo0_l000000ooooooo0000o`00
0002ooooo`;o00000oooool3o`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l000003Ooo
ool2o`0003Kooooo000Looooo`;o0000@oooool2o`0001Cooooo0_l00006oooooaKo00000_ooool4
o`0000Gooooo0_l0000Eooooo`;o00002_ooool2o`0000?ooooo1?l00008ooooo`;o00001oooool2
o`0000?ooooo1Ol00004ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l00002
ooooo`;o00003?ooool2o`0000;ooooo0ol00003ooooo`;o00000oooool4o`0000Gooooo0_l00006
ooooo`;o00000_ooool2o`000003ooooool0003o000003Kooooo000Looooo`03o`000?oooooooooo
01kooooo0_l0000Nooooo`;o000000?oooooo`000?l000001?ooool2o`0000oooooo0_l00006oooo
oaOo00001?ooool2o`0000Cooooo0_l0000Eooooo`?o00004?ooool2o`0000Gooooo1Ol00007oooo
o`Co000000?oooooo`000?l000001?ooool5o`0000cooooo0_l00004ooooo`;o000000?oooooo`00
0?l000002_ooool2o`0000[ooooo0_l0000=ooooo`;o00000_ooool2o`0000;ooooo0_l0000>oooo
o`;o00009Oooool001cooooo00?o0000ooooooooool07_ooool2o`0001Cooooo1ol00003ooooo`;o
000000?oooooo`000?l000000oooool3o`0000_ooooo0_l0000:oooooaOo00000oooool3o`0001[o
oooo1?l00009ooooo`;o00003?ooool3o`0000Cooooo0_l00005ooooo`;o00001oooool4o`0000go
oooo0_l00004ooooo`;o000000?oooooo`000?l000001_ooool2o`0002Gooooo0_l0000>ooooo`;o
00009Oooool001cooooo00?o0000ooooooooool0=?ooool7o`0000_ooooo0ol0000;ooooo`;o0000
00?oooooo`000?l000001ooooolGo`0000?ooooo0_l0000Eooooo`Co00000_ooool4o`0000Wooooo
0_l0000@ooooo`;o000000Coooooo`000?l0003o00007Oooool2o`0000oooooo1Ol0000:ooooo`;o
00003_ooool3o`0003gooooo000Looooo`03o`000?oooooooooo02kooooo0_l00006ooooo`;o0000
3_ooool3o`0000kooooo0_l000000ooooooo0000o`000004oooooa?o00003?ooool2o`00013ooooo
1?l00004ooooo`?o00002?ooool2o`0000_ooooo0_l00003ooooo`;o00000_ooool2o`000003oooo
ool0003o000001[ooooo0_l0000?ooooo`;o000000?oooooo`000?l000002_ooool2o`000003oooo
ool0003o000000_ooooo0ol000000ooooooo0000o`00000jooooo`007?ooool00ol0003ooooooooo
o`0^ooooo`;o00001_ooool2o`0000Gooooo0_l0000Cooooo`;o000000?oooooo`000?l000000ooo
ool2o`0000Gooooo4ol0000;ooooo`;o00003_ooool2o`0000Gooooo0_l00002ooooo`;o00005Ooo
ool3o`0000Cooooo0_l00003ooooo`;o00003_ooool2o`000003ooooool0003o0000023ooooo0_l0
0008ooooo`Co00003Oooool2o`0003[ooooo000Looooo`03o`000?oooooooooo03gooooo0_l0000>
ooooo`;o00000oooool2o`000003ooooool0003o000000?ooooo0_l00005ooooo`go000000?ooooo
o`000?l000000ol00006ooooo`;o00003Oooool2o`0000Cooooo0_l00005ooooo`;o00000_ooool5
o`00013ooooo1_l00003ooooo`?o00001?ooool2o`0000cooooo1Ol00007ooooo`;o00003_ooool2
o`0000;ooooo0_l00003ooooo`;o00002_ooool2o`0004Wooooo000Looooo`03o`000?oooooooooo
03kooooo0_l0000=ooooo`;o00000oooool2o`0000kooooo3?l000000ooooooo0000o`000009oooo
o`;o00003Oooool2o`0000kooooo1_l0000:ooooo`;o00001?ooool2o`000004ooooool0003o0000
o`0000Cooooo0_l00002ooooo`Co00002Oooool2o`0000;ooooo0_l00005ooooo`;o00000_ooool2
o`000003ooooool0003o000000Gooooo0_l00004ooooo`;o00000_ooool2o`0000?ooooo0_l00003
ooooo`;o0000:_ooool2o`0002Cooooo000Looooo`03o`000?oooooooooo033ooooo0_l00004oooo
o`;o00001_ooool2o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0000gooooo0_l00002oooo
oa?o00000oooool2o`0001Kooooo0_l00003ooooo`;o00001_ooool2o`0000Cooooo0_l000000ooo
oooo0000o`00000:o`000003ooooool0003o000000So00001?ooool2o`0000Cooooo0_l00005oooo
o`;o00002Oooool4o`0000?ooooo0_l00005ooooo`?o00004Oooool2o`0000?ooooo0_l0000Uoooo
o`;o00009?ooool001cooooo00?o0000ooooooooool08Oooool2o`0000Wooooo0_l00002ooooo`;o
00001?ooool2o`0000Oooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00000oooool2o`00
00Kooooo0_l00005ooooo`;o00000_ooool4o`000003ooooool0003o000000co00000oooool2o`00
00Cooooo0_l00002ooooo`;o00003?ooool2o`0000?ooooo0_l0000;ooooo`?o000000?oooooo`00
0?l000003_l00003ooooo`Co00002_ooool2o`0000Oooooo0_l00009ooooo`;o00002_ooool3o`00
013ooooo0_l00002ooooo`Co00002oooool2o`0003kooooo000Looooo`03o`000?oooooooooo027o
oooo0_l00009ooooo`;o00004Oooool2o`000005ooooool0003o0000o`000?ooool00_l0000:oooo
o`?o00003?ooool@o`0000?ooooo0ol00003ooooo`;o00000_ooool2o`0000Cooooo0_l00007oooo
o`;o00003oooool2o`0000Kooooo2_l000000ooooooo0000o`000002o`0000?ooooo0_l000000ooo
oooo0000o`000003ooooo`;o00001Oooool2o`0000?ooooo0_l0000Fooooo`;o00004?ooool2o`00
00;ooooo0_l0000=ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0:oooool2o`0002Go
oooo0_l0000=ooooo`ko00001_ooool2o`0000?ooooo0_l00008ooooo`;o00001oooool2o`0001;o
oooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000[o000000Goooooo`000?l0
003o0000ooooo`02o`0000?ooooo0_l00005ooooo`;o00004Oooool2o`0000Wooooo0_l00002oooo
o`;o00001?ooool3o`0000Oooooo0_l00006ooooo`Co00001?ooool2o`0003kooooo000Looooo`03
o`000?oooooooooo02_ooooo0_l000000ooooooo0000o`00000Vooooo`;o00002_ooool=o`0001Ko
oooo0_l0000>ooooo`;o00001?ooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`00
00;ooooo2ol000001?oooooo0000o`000?ooool5o`0000cooooo0_l0000=ooooo`;o00000oooool2
o`0000Cooooo0_l00002ooooo`;o00001?ooool3o`0000Cooooo0_l000000ooooooo0000o`000006
ooooo`Co00001?ooool2o`0000;ooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`0^oooo
o`;o00009Oooool3o`0000Wooooo0_l000000ooooooo0000o`000004o`0000?ooooo0_l000000ooo
oooo0000o`00000Cooooo`;o00001Oooool2o`0000Oooooo0ol00003ooooo`;o00000_ooool2o`00
00?ooooo0ol00004ooooo`go00000_ooool2o`000003ooooool0003o000000Wooooo0_l000000ooo
oooo0000o`00000Booooo`;o00004?ooool2o`0000;ooooo0ol00006ooooo`;o000000Coooooo`00
0?l0003o00001Oooool2o`0000;ooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`0Yoooo
o`;o00000oooool2o`0001Sooooo0_l0000;ooooo`;o00001?ooool2o`0000Cooooo2?l00007oooo
o`;o00006_ooool2o`0000Sooooo0_l00005ooooo`Co00000_ooool6o`0000;ooooo1ol000000ooo
oooo0000o`000003o`0000;ooooo0_l00002ooooo`;o00002?ooool2o`0002Oooooo0_l00002oooo
o`;o00001oooool6o`0000;ooooo0_l000000ooooooo0000o`00000nooooo`007?ooool00ol0003o
ooooooooo`0Yooooo`;o00005?ooool2o`000003ooooool0003o000000Cooooo0_l00006ooooo`Co
00001oooool2o`0000Kooooo2?l0000Oooooo`;o00004?ooool3o`0000Cooooo0_l000001?oooooo
0000o`000?l00002ooooo`Ko000000Coooooo`000?l0003ooooo0_l00003ooooo`?o000000Gooooo
o`000?l0003o0000ooooo`02o`0002kooooo0_l0000<ooooo`;o00001?ooool2o`000003ooooool0
003o000000?ooooo0_l0000iooooo`007?ooool2o`0003Kooooo0_l00006ooooo`Co000000?ooooo
o`000?l000003?ooool4o`00013ooooo1ol00004ooooo`;o00005_ooool2o`000003ooooool0003o
0000013ooooo2Ol000000ooooooo0000o`00000Ao`0000;ooooo0_l000001Ooooooo0000o`000?l0
003ooooo00;o00000_ooool2o`0000Cooooo0_l0000Tooooo`;o00003?ooool2o`0000Cooooo0_l0
00000ooooooo0000o`000003ooooo`;o0000>Oooool001cooooo00?o0000ooooooooool0=Oooool2
o`0000Kooooo0_l00008ooooo`;o00001oooool2o`0001;ooooo1_l00005ooooo`;o00002_ooool2
o`0000[ooooo0_l000000ooooooo0000o`000004ooooo`;o00002_ooool9o`000004ooooool0003o
0000oooooaOo00001_ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l00000
:Oooool2o`0001Cooooo0_l0000gooooo`007?ooool00ol0003oooooooooo`17ooooo`;o00005?oo
ool2o`0000Kooooo1Ol0000Aooooo`;o00002oooool2o`0000Kooooo0_l0000:ooooob?o000000?o
ooooo`000?l000000oooool2o`0000;ooooo0ol00003ooooo`;o0000:Oooool2o`0000;ooooo0_l0
0007ooooo`;o00001oooool2o`0001;ooooo0_l0000Sooooo`007?ooool00ol0003oooooooooo`18
ooooo`;o00000oooool2o`0000kooooo0ol00006ooooo`?o00004_ooool2o`0000_ooooo0_l00002
ooooo`;o00003_ooool2o`0000Gooooo1ol000000ooooooo0000o`00000Bo`000003ooooool0003o
000000?ooooo0ol00002ooooo`;o0000;_ooool2o`0000;ooooo0_l00007ooooo`;o00006oooool2
o`0002?ooooo000Looooo`03o`000?oooooooooo04Cooooo0_l00002ooooo`;o00000oooool2o`00
00oooooo0_l00007ooooo`;o00003oooool2o`0001;ooooo0_l0000=ooooo`;o000000?oooooo`00
0?l000001OoooolFo`000003ooooool0003o000000Ko00000_ooool2o`0002kooooo0_l00002oooo
o`Ko00001oooool2o`0000;ooooo0_l0000Hooooo`;o00008_ooool001cooooo00?o0000oooooooo
ool0<Oooool2o`00017ooooo0_l00007ooooo`;o00005Oooool2o`0000kooooo0_l00002ooooo`;o
00008?ooool3o`000003ooooool0003o000000ko000000?oooooo`000?l000005Ol00007ooooo`;o
00009Oooool4o`0000Cooooo1?l00009ooooo`Co00006?ooool2o`0002;ooooo000Looooo`03o`00
0?oooooooooo037ooooo0ol0000Uooooo`;o00002Oooool2o`0000kooooo0_l00002ooooo`;o0000
0oooool2o`0000oooooo0_l0000:ooooo`;o00001?oooolQo`000003ooooool0003o000000;o0000
1Oooool4o`0000Gooooo0_l0000Iooooo`;o00000oooool2o`0001?ooooo0_l0000nooooo`007?oo
ool00ol0003oooooooooo`0booooo`;o00002Oooool4o`0000oooooo0_l00007ooooo`;o00001ooo
ool2o`0000Wooooo0_l00003ooooo`?o00002?ooool2o`0000Kooooo0_l00007ooooo`;o00001Ooo
ool2o`0000Wooooo8Ol000000ooooooo0000o`000003o`0000Cooooo0_l00007ooooo`;o00006Ooo
ool2o`0001[ooooo0_l0000looooo`007?ooool00ol0003oooooooooo`0mooooo`Co00003?ooool2
o`000003ooooool0003o0000013ooooo0_l00008ooooo`?o00000oooool3o`0000_ooooo1?l00000
0ooooooo0000o`00000>ooooo`;o00001?ooool2o`0000Gooooo8?l000000ooooooo0000o`000002
o`0000Kooooo1Ol0000booooo`;o00001Oooool2o`0003cooooo000Looooo`03o`000?oooooooooo
033ooooo0_l0000;ooooo`;o00003_ooool2o`00013ooooo0_l0000;ooooo`Co00000oooool2o`00
00_ooooo1?l000000ooooooo0000o`000006ooooo`;o00002Oooool2o`000003ooooool0003o0000
00;ooooo8ol000000ooooooo0000o`000002ooooo`;o00001?ooool5o`00023ooooo0_l00009oooo
o`;o00001Oooool2o`0004?ooooo000Looooo`03o`000?oooooooooo033ooooo0_l000000ooooooo
0000o`00000Zooooo`;o00003Oooool2o`0000?ooooo0_l00009ooooo`Co000000Coooooo`000?l0
003o00001oooool2o`0000Cooooo0_l00003ooooo`;o00001OoooolRo`0000;ooooo0_l00002oooo
o`;o00009_ooool2o`000003ooooool0003o000000;ooooo0_l00005ooooo`;o00001Oooool2o`00
04?ooooo000Looooo`03o`000?oooooooooo03?ooooo0ol0000aooooo`;o00002oooool2o`0000So
oooo1?l000001?oooooo0000o`000?l00006ooooo`;o00001Oooool2o`0000Cooooo0ol00002oooo
o`;o000000?oooooo`000?l000009_l0000Uooooo`?o00001Oooool2o`0000?ooooo0_l0001<oooo
o`007?ooool00ol0003oooooooooo`0Rooooo`;o00002?ooool2o`0000Kooooo0_l0000Hooooo`;o
00002oooool2o`0000[ooooo0_l00009ooooo`Co00002_ooool3o`000003ooooool0003o000000Ko
oooo0_l0000;ooooo`?o000000?oooooo`000?l00000:_l0000Uooooo`;o00002oooool2o`0000Go
oooo0_l00015ooooo`007?ooool00ol0003oooooooooo`0Rooooo`;o00002?ooool2o`0000Kooooo
0_l0000Hooooo`;o00001?ooool2o`0000Gooooo0_l00006ooooo`;o00003Oooool2o`000004oooo
ool0003o0000o`0000Wooooo0_l000000ooooooo0000o`00000Dooooo`;o000000?oooooo`000?l0
0000:?l0000:ooooo`;o00006?ooool2o`0000Oooooo0_l0000<ooooo`;o00001oooool2o`0003co
oooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000
oa0@4?o<c<`01_ooool00ol0003oooooooooo`0cooooo`?o00006?ooool2o`0000Cooooo0_l0000=
ooooo`;o00004?ooool3o`0000_ooooo0_l00008ooooo`;o00002oooool2o`0000;ooooo:?l00005
ooooo`;o00001?ooool2o`0000?ooooo0_l0000Cooooo`;o00001_ooool3o`0000kooooo0_l00005
ooooo`;o0000??ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go
EEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo03?ooooo0_l0000Iooooo`;o0000
<?ooool2o`000003ooooool0003o000000Sooooo0_l00008ooooo`;o00001Oooool[o`0000;ooooo
0_l00009ooooo`?o00006_ooool2o`0000gooooo1?l00013ooooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`1Mooooo`?o00004oooool2o`0000[ooooo0ol0000@ooooo`;o00000oooool2o`000004oooo
ool0003o0000ooooo`Ko000000?oooooo`000?l000008ol0000>ooooo`;o00007?ooool2o`0000?o
oooo0_l00006ooooo`;o00000oooool2o`00043ooooo00000ooooooo0000ooooo`02ooooo`03o`00
0?oooooooooo00Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000<Oooool2o`0001Co
oooo0_l0000Dooooo`?o00004oooool4o`0000;ooooo0_l00004ooooo`;o00000_ooool2o`0000;o
oooo0_l00007ooooo`Co00000oooool2o`000004ooooool0003o0000ooooo`Ko000000?oooooo`00
0?l000007Ol000000ooooooo0000o`000003ooooo`?o00002?ooool2o`0001oooooo0_l00003oooo
o`;o00001_ooool2o`0000?ooooo0_l00010ooooo`0000?oooooo`000?ooool00_ooool00ol0003o
ooooooooo`09ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0aoooo
o`;o00000oooool2o`0000oooooo0_l0000Qooooo`;o00000oooool2o`0000Cooooo0_l00002oooo
o`;o00001_ooool4o`0000;ooooo0_l00007ooooo`;o00000oooool7o`0000Cooooo8ol000000ooo
oooo0000o`000003ooooo`Ko00001Oooool2o`0001Wooooo0_l0000=ooooo`;o0000BOooool00003
ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03
o`000?oooooooooo037ooooo0_l00003ooooo`;o00006Oooool2o`0001;ooooo1ol00003ooooo`;o
00001Oooool2o`000003ooooool0003o000000Kooooo0ol0000Aooooo`?o000000?oooooo`000?l0
00001Ol000000ooooooo0000o`00000So`0000Gooooo1?l0000Nooooo`Co00003Oooool2o`0000?o
oooo0_l00014ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH
00Sooooo00?o0000ooooooooool0<Oooool2o`0000oooooo0_l0000=ooooo`?o00003Oooool2o`00
00;ooooo1_l00002ooooo`;o00001oooool3o`0000Cooooo0_l00003ooooo`;o00002_ooool2o`00
00Kooooo0_l00002ooooo`Ko000000?oooooo`000?l000000_l000000ooooooo0000o`00000<o`00
0003ooooool0003o000000oo00000oooool2o`0002;ooooo0_l0000:ooooo`;o00002?ooool2o`00
04Cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_oo
ool00ol0003oooooooooo`12ooooo`;o00003_ooool2o`0000gooooo0_l000000ooooooo0000o`00
0007ooooo`;o00002?ooool2o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`;o00001_oo
ool2o`0000Kooooo0_l00003ooooo`Ko000000?oooooo`000?l000004?l000000ooooooo0000o`00
000<o`000003ooooool0003o000000?ooooo2?l00007ooooo`;o00003_ooool2o`0000?ooooo0_l0
000:ooooo`;o00002?ooool2o`0004Cooooo000Looooo`03o`000?oooooooooo02gooooo0_l0000S
ooooo`;o00002Oooool2o`0000?ooooo1?l00004ooooo`Co00000_ooool2o`0000Sooooo0_l00003
ooooo`?o00001?ooool2o`0000kooooo0_l00005ooooo`Co000000?oooooo`000?l000007ol00002
ooooo`;o00000_ooool8o`0000Kooooo0ol0000>ooooo`;o00000oooool2o`0005[ooooo000Loooo
o`03o`000?oooooooooo02gooooo0_l0000Mooooo`;o00003oooool2o`0000?ooooo0ol000000ooo
oooo0000o`00000:o`0000Sooooo0_l00003ooooo`?o00001oooool2o`0001;ooooo1?l000000ooo
oooo0000o`00000No`0000?ooooo0_l00002ooooo`?o000000?oooooo`000?l000002?ooool2o`00
01Sooooo0_l00006ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0C?ooool2o`0001Co
oooo3ol000000ooooooo0000o`00000<ooooo`;o00001_ooool3o`0000cooooo0_l00002ooooo`Go
00000_oooolMo`000003ooooool0003o000000;ooooo1Ol00004ooooo`;o00007?ooool3o`0000?o
oooo0_l00004ooooo`Co00002_ooool2o`0004;ooooo000Looooo`03o`000?oooooooooo06;ooooo
5Ol00009ooooo`;o00001_ooool2o`0000cooooo0ol00002ooooo`Go00001?oooolKo`000003oooo
ool0003o000000;ooooo1_l0000Qooooo`?o00002Oooool4o`0000?ooooo0_l000001?oooooo0000
o`000?ooool3o`0001Kooooo0_l0000Zooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o0000
<?ooool2o`0000;ooooo3_l000000ooooooo0000o`000002o`0000Wooooo0_l0000Dooooo`;o0000
0oooool2o`000003ooooool0003o000000Cooooo7Ol00004ooooo`Go00000oooool2o`0001Sooooo
0_l00006ooooo`?o00001_ooool2o`0000Cooooo0_l000000ooooooo0000o`000003o`0001Oooooo
0_l0000Zooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00006_ooool2o`0001Cooooo4_l0
000;ooooo`;o000000?oooooo`000?l000005?ooool2o`000003ooooool0003o000000?ooooo0_l0
0004oooooaoo00000_ooool3o`0000Gooooo0ol0000Gooooo`Co00001?ooool3o`0000cooooo1?l0
00000ooooooo0000o`000014ooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00006_ooool2
o`000003ooooool0003o0000017ooooo4_l0000:ooooo`?o00004oooool2o`0000Gooooo0_l00003
ooooo`?o000000?oooooo`000?l000008Ol00009ooooo`;o00006Oooool2o`0000;ooooo0_l0000<
ooooo`Oo0000Aoooool001cooooo00?o0000ooooooooool0<_ooool2o`0001Wooooo0_l0000?oooo
o`_o000000?oooooo`000?l000001ol00002ooooo`;o00001Oooool4o`0001;ooooo0_l0000;oooo
o`;o000000?oooooo`000?l000007?l000000ooooooo0000o`000002o`0000Gooooo0_l0000<oooo
o`;o00004oooool2o`0000cooooo1_l00018ooooo`007?ooool00ol0003oooooooooo`0booooo`;o
00005_ooool2o`0001;ooooo2ol000000ooooooo0000o`00000;o`0000Oooooo0_l00004ooooo`Co
00002oooool2o`0000gooooo7_l000000ooooooo0000o`000002o`0000Gooooo0_l000000ooooooo
0000o`000009ooooo`?o00006oooool4o`0000Cooooo0_l00019ooooo`007?ooool00ol0003ooooo
ooooo`0Xooooo`;o00003?ooool2o`0001;ooooo0_l0000?ooooo`ko000000?oooooo`000?l00000
2Ol000000ooooooo0000o`00000<ooooo`Co00002oooool2o`0000Wooooo6_l00002ooooo`Ko0000
0oooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000000ol00008ooooo`Go
00006?ooool4o`0004oooooo000Looooo`03o`000?oooooooooo02Sooooo0_l0000<ooooo`;o0000
8ooooolHo`0000?ooooo0ol00003ooooo`;o00004Oooool2o`0000gooooo1_l000000ooooooo0000
o`00000Eo`000003ooooool0003o000000Oooooo0_l000000ooooooo0000o`000008o`0000Oooooo
1?l0000=ooooo`;o0000G?ooool001cooooo0_l0001Jooooo`;o00000_ooool@o`000003ooooool0
003o000000;o000000Goooooo`000?l0003o0000ooooo`02o`0000?ooooo0ol0000@ooooo`Co0000
2Oooool2o`000003ooooool0003o000000;o00000_ooool7o`000003ooooool0003o000000co0000
1_ooool3o`0000Kooooo0_l00005ooooo`;o00006?ooool4o`0005[ooooo000Looooo`03o`000?oo
oooooooo04?ooooo0_l0000Aooooo`;o000000Coooooo`000?l0003ooooo5_l000001?oooooo0000
o`000?l00006ooooo`Co000000?oooooo`000?l000000oooool2o`0000Oooooo1?l00004ooooo`;o
000000?oooooo`000?l000000_l000001?oooooo0000o`000?ooool2o`0000Gooooo1_l00002oooo
o`[o00000oooool2o`000004ooooool0003o0000o`0000?ooooo0_l0000Tooooo`;o00002_ooool2
o`0000Gooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00004Oooool2o`00
00Cooooo5ol00002ooooo`;o00001Oooool4o`000003ooooool0003o000000?ooooo0_l0000?oooo
o`;o000000Coooooo`000?l0003o00001Oooool2o`0000Sooooo0ol00003ooooo`?o00000oooool2
o`0000Cooooo0_l00002ooooo`;o00000oooool2o`00013ooooo0_l000000ooooooo0000o`000007
ooooo`;o00002?ooool2o`0000?ooooo0_l00003ooooo`;o00001Oooool2o`0004Oooooo000Loooo
o`03o`000?oooooooooo03kooooo0_l00002ooooo`;o00004oooool2o`0000?ooooo5ol00002oooo
o`;o00001Oooool2o`0000kooooo0_l0000=ooooo`;o000000?oooooo`000?l000001oooool6o`00
0003ooooool0003o000000;ooooo1Ol000001?oooooo0000o`000?l00002ooooo`;o000000?ooooo
o`000?l000000_l0000=ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`;o00001ooo
ool2o`0000Sooooo1?l000000ooooooo0000o`000005ooooo`;o0000C?ooool001cooooo00?o0000
ooooooooool0?_ooool2o`0000;ooooo0_l0000Cooooo`;o00001?oooolFo`0000Wooooo0_l00006
ooooo`;o00001_ooool2o`0000?ooooo0_l00006ooooo`;o00000oooool2o`000003ooooool0003o
000001Wo000000?oooooo`000?l000001Ol0000<ooooo`Co00000_ooool4o`000004ooooool0003o
0000o`0001?ooooo0_l00008ooooo`;o00006Oooool2o`00037ooooo000Looooo`03o`000?oooooo
oooo03[ooooo0_l0000Qoooooa?o00000_ooool2o`000003ooooool0003o000000;ooooo0_l00000
0ooooooo0000o`000006ooooo`;o00002oooool2o`0000Cooooo1?l00003ooooo`;o000000?ooooo
o`000?l000001ol000000ooooooo0000o`000008o`000003ooooool0003o000000Co00000oooool2
o`000003ooooool0003o000000cooooo1?l00004ooooo`;o000000?oooooo`000?l000003oooool2
o`0000Kooooo0_l000000ooooooo0000o`000002ooooo`;o00006Oooool2o`00037ooooo000Loooo
o`03o`000?oooooooooo03[ooooo0_l000000ooooooo0000o`00000Ooooooa;o00000_ooool2o`00
0003ooooool0003o000000;ooooo0_l00005ooooo`;o00001oooool2o`0000[ooooo1?l00003oooo
o`Co00000_ooool2o`0000;ooooo3Ol00005ooooo`;o00001Oooool2o`0000?ooooo0_l0000Doooo
o`;o00002oooool2o`000003ooooool0003o000000;o00001_ooool5o`0000;ooooo0_l0001<oooo
o`007?ooool00ol0003oooooooooo`0mooooo`;o00008?oooolAo`0000;ooooo1?l00004ooooo`;o
00001?ooool2o`0000Kooooo0ol0000:ooooo`;o00000oooool4o`0000_ooooo2_l00008ooooo`;o
00000_ooool2o`000003ooooool0003o000000;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o
00000_ooool2o`0000Oooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo1_l00004oooo
o`;o00003?ooool2o`0003gooooo000Looooo`03o`000?oooooooooo05oooooo4Ol00002ooooo`Co
00001?ooool2o`0000Sooooo0_l00002ooooo`;o00003Oooool2o`000003ooooool0003o000000Oo
oooo0_l00005ooooo`;o00001?ooool5o`0000Gooooo0ol00002ooooo`;o000000?oooooo`000?l0
00002?ooool2o`0000;ooooo1Ol00009ooooo`;o00003Oooool2o`0000?ooooo0_l00007ooooo`?o
00003?ooool2o`0003gooooo000Looooo`03o`000?oooooooooo063ooooo4?l00003ooooo`;o0000
1Oooool2o`0000?ooooo0_l00003ooooo`;o00002?ooool3o`0000Kooooo0_l00002ooooo`;o0000
1_ooool2o`0000Cooooo0_l00004ooooo`Ko00001Oooool3o`000005ooooool0003o0000o`000?oo
ool00_l00007ooooo`;o00000oooool4o`0000Oooooo0_l00008ooooo`;o00002?ooool2o`0000So
oooo1?l0001<ooooo`007?ooool00ol0003oooooooooo`1Pooooo`go00001?ooool3o`0000?ooooo
0ol00005ooooo`Co00001oooool7o`0000Kooooo0_l00002ooooo`Co00001?ooool2o`0000Cooooo
0_l00004ooooo`Go000000Coooooo`000?l0003ooooo1?l00002ooooo`;o00000_ooool2o`0000Oo
oooo0_l000000ooooooo0000o`000003o`0000Sooooo0_l00008ooooo`;o00002?ooool2o`0000So
oooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`1Qooooo`;o00000_ooool8o`0000Cooooo
0ol00003ooooo`?o000000?oooooo`000?l000000oooool3o`0000Cooooo0_l000000ooooooo0000
o`000003o`0000kooooo0_l00004ooooo`?o00002?ooool2o`000005ooooool0003o0000o`000?oo
ool00_l000000ooooooo0000o`000002o`0000Sooooo0ol000000ooooooo0000o`000002ooooo`Co
000000?oooooo`000?l000009_ooool2o`0004kooooo000Looooo`03o`000?oooooooooo06Cooooo
2?l0000:ooooo`;o00000oooool2o`0000[ooooo0_l00002ooooo`?o00005_ooool4o`0000Kooooo
0_l00005ooooo`;o00000_ooool2o`0000Wooooo0ol000000ooooooo0000o`000004o`0000;ooooo
0_l0000Fooooo`;o00003?ooool2o`000003ooooool0003o000004kooooo000Looooo`03o`000?oo
oooooooo04[ooooo0_l0000Fooooo`Ko000000?oooooo`000?l000000_l00005ooooo`;o000000Co
ooooo`000?l0003o00008Oooool2o`000003ooooool0003o000000Gooooo0_l000000ooooooo0000
o`000002ooooo`;o00003Oooool4o`0000Cooooo0_l00007ooooo`Go000000?oooooo`000?l00000
3oooool2o`0000Gooooo0_l00009ooooo`;o000000?oooooo`000?l00000DOooool001cooooo00?o
0000ooooooooool0B_ooool2o`00017ooooo0_l00003ooooo`;o00001?ooool5o`0000Gooooo1Ol0
000<ooooo`;o00005?ooool2o`000003ooooool0003o000000Gooooo2Ol000000ooooooo0000o`00
0002o`0000[ooooo0ol00003ooooo`?o00001Oooool2o`0000;ooooo0_l0000Booooo`;o00004?oo
ool2o`0005Cooooo000Looooo`03o`000?oooooooooo05gooooo0_l00008ooooo`Co00002Oooool3
o`0000cooooo0_l0000Iooooo`;o00001Oooool5o`0000?ooooo1?l00006ooooo`;o00000oooool2
o`0000Cooooo0_l00005ooooo`;o00004_ooool2o`0006[ooooo000Looooo`;o0000J?ooool4o`00
0003ooooool0003o000000;o00002?ooool2o`0000_ooooo0_l0000Gooooo`;o00003Oooool2o`00
00Sooooo0_l0000Tooooo`;o0000J_ooool001cooooo00?o0000ooooooooool0JOooool2o`000003
ooooool0003o000000;o00002?ooool2o`0000_ooooo0_l0000Mooooo`Co00001Oooool2o`0000Go
oooo0ol00002ooooo`;o00001_ooool2o`0000gooooo0_l000000ooooooo0000o`00000?ooooo`;o
00003Oooool2o`0005Cooooo000Looooo`03o`000?oooooooooo04cooooo0_l0000:ooooo`;o0000
3oooool2o`0001oooooo0_l0000Aooooo`;o00000oooool6o`0000cooooo0ol00002ooooo`;o0000
1_ooool2o`0000Sooooo0_l00003ooooo`;o000000?oooooo`000?l000003oooool2o`0000Gooooo
0_l00004ooooo`Ko0000D_ooool001cooooo00?o0000ooooooooool0C?ooool2o`0000Wooooo0ol0
0002ooooo`;o00002oooool2o`0000_ooooo0ol00003ooooo`;o00001?ooool2o`0000;ooooo0_l0
0002ooooo`;o00002oooool2o`0000Cooooo0_l00003ooooo`;o00004?ooool2o`000004ooooool0
003o0000ooooo`;o00001?ooool2o`0000Wooooo0ol00002ooooo`;o00004Oooool2o`0000;ooooo
0_l00002ooooo`;o00001?ooool2o`000004ooooool0003o0000o`0005;ooooo000Looooo`03o`00
0?oooooooooo05Oooooo0_l00003ooooo`;o00001Oooool2o`0000Sooooo0_l00002ooooo`;o0000
0oooool3o`0000?ooooo0_l00004ooooo`;o00000_ooool4o`0000gooooo0_l00002ooooo`?o0000
1?ooool2o`0000Sooooo0_l00002ooooo`Ko000000?oooooo`000?l000001?l00003ooooo`;o0000
2_ooool2o`0001Gooooo1_l0000@ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0Hooo
ool2o`0000Sooooo0_l00002ooooo`;o00001_ooool2o`0000Cooooo0_l000000ooooooo0000o`00
0004ooooo`;o00004Oooool3o`0000Gooooo0_l00004ooooo`;o000000?oooooo`000?l000000_oo
ool4o`0000Cooooo1Ol0000?ooooo`;o00000oooool2o`0000Oooooo0_l00009ooooo`;o00002_oo
ool2o`0000Kooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o00002?ooool2
o`0001;ooooo1?l000000ooooooo0000o`000002o`0000Cooooo0_l000001?oooooo0000o`000?oo
ool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`?o00003?ooool2o`0000Kooooo0_l0
0004ooooo`;o00002_ooool3o`000004ooooool0003o0000o`0000Gooooo0_l00003ooooo`;o0000
0oooool3o`0000?ooooo0_l00007ooooo`?o00000oooool2o`0000Kooooo0_l000000ooooooo0000
o`000004ooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0C_ooool2o`0000Sooooo0_l0
0003ooooo`;o00000_ooool2o`0000Wooooo1?l000000ooooooo0000o`000002o`0000Oooooo0_l0
000:ooooo`Oo00000_ooool2o`0000Sooooo1?l0000Dooooo`Go00000_ooool2o`0000Gooooo0_l0
0002ooooo`Go000000Coooooo`000?l0003ooooo0_l0000;ooooo`;o00000oooool2o`0000Gooooo
0ol000000ooooooo0000o`00001Looooo`007?ooool00ol0003oooooooooo`1Hooooo`Co000000?o
ooooo`000?l000000_ooool3o`0000_ooooo0_l00004ooooo`?o00004_ooool2o`000003ooooool0
003o000000;ooooo0_l00006ooooo`;o00000_ooool2o`0000Kooooo0_l0000<ooooo`?o00002?oo
ool2o`0000Gooooo0_l000000ooooooo0000o`000004ooooo`;o00005?ooool2o`000004ooooool0
003o0000ooooo`Go0000F_ooool001cooooo00?o0000ooooooooool0EOooool2o`000003ooooool0
003o000000;o00000oooool2o`000003ooooool0003o000000_ooooo0_l00002ooooo`Go00001ooo
ool2o`0000_ooooo0ol00003ooooo`;o00001Oooool2o`0000[ooooo0_l00009ooooo`;o00003?oo
ool2o`0001Gooooo0_l00002ooooo`;o00000_ooool2o`0000Gooooo0_l00004ooooo`Ko0000FOoo
ool001cooooo00?o0000ooooooooool0EOooool2o`0000Sooooo0_l0000?ooooo`;o000000?ooooo
o`000?l000001_ooool3o`000003ooooool0003o000000?ooooo0_l00004ooooo`Co00001?ooool4
o`0001[ooooo0_l00004ooooo`;o00002Oooool2o`0000kooooo0_l00002ooooo`;o00000_ooool2
o`0000;ooooo0ol00007ooooo`;o00000oooool4o`0005Wooooo000Looooo`03o`000?oooooooooo
05;ooooo0_l0000;ooooo`;o00003oooool4o`0000Oooooo0ol00006ooooo`;o00001?ooool2o`00
00Oooooo0ol00002ooooo`;o00002_ooool2o`0000Gooooo0_l00009ooooo`;o00002Oooool2o`00
00kooooo0_l0000;ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Cooooo0_l000000ooo
oooo0000o`00001Gooooo`007?ooool00ol0003oooooooooo`1Booooo`;o00003Oooool2o`0000Co
oooo0_l00007ooooo`Co00000_ooool2o`0000Sooooo0_l0000Dooooo`Co00001?ooool2o`0000Co
oooo0_l00005ooooo`;o00000oooool2o`0000?ooooo0_l00002ooooo`;o00001oooool2o`0001go
oooo0_l00005ooooo`;o00000oooool2o`000003ooooool0003o000000oooooo0_l00016ooooo`00
7?ooool00ol0003oooooooooo`1Looooo`;o00000oooool2o`0000Cooooo0ol0000<ooooo`;o0000
2?ooool2o`0001;ooooo1?l00006ooooo`?o00000_ooool2o`0000Wooooo1?l00003ooooo`;o0000
0_ooool2o`0000Gooooo1?l0000>ooooo`;o00004?ooool2o`0000;ooooo1?l0000Eooooo`;o0000
A_ooool001cooooo00?o0000ooooooooool0G?ooool2o`0000Sooooo1?l00005ooooo`;o00000ooo
ool4o`0000Kooooo0ol00006ooooo`;o00002oooool2o`0000?ooooo0_l00004ooooo`?o000000?o
ooooo`000?l000002?ooool3o`0000Gooooo1?l00007ooooo`;o00002Oooool2o`0000Gooooo0_l0
000@ooooo`;o00000_ooool4o`0005gooooo000Looooo`03o`000?oooooooooo05Gooooo0_l00005
ooooo`;o00002?ooool2o`0000Oooooo0_l00003ooooo`;o00002?ooool3o`0000Kooooo1?l00002
ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0000;ooooo0_l00005ooooo`;o00002ooo
ool4o`0000Kooooo0_l000000ooooooo0000o`00000;ooooo`;o00000_ooool2o`0000[ooooo0_l0
000Aooooo`;o0000GOooool001cooooo0_l0001Fooooo`;o0000<_ooool3o`000003ooooool0003o
000000Co00000_ooool2o`000003ooooool0003o000000Cooooo0_l00003ooooo`;o00001Oooool2
o`0000?ooooo0_l00005ooooo`;o00000_ooool2o`0000_ooooo0_l0000>ooooo`;o00001oooool2
o`000003ooooool0003o000000Gooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1Noooo
o`;o00000_ooool2o`0000oooooo0ol0000Dooooo`;o00000oooool7o`0000;ooooo0_l00004oooo
o`;o00000oooool2o`0000?ooooo1Ol00002ooooo`;o00001Oooool2o`0000;ooooo0ol0000Joooo
o`Co00001Oooool5o`000003ooooool0003o000000;ooooo0_l0001Mooooo`007?ooool00ol0003o
ooooooooo`1Nooooo`;o00000_ooool2o`0000oooooo0ol0000@ooooo`;o00002?ooool6o`0000;o
oooo1?l00007ooooo`;o00000oooool5o`0000Cooooo0_l00007ooooo`?o00002_ooool2o`0000;o
oooo0_l0000<ooooo`;o00001oooool2o`0000;ooooo0_l0001Qooooo`007?ooool00ol0003ooooo
ooooo`1Qooooo`Co00006oooool2o`0000?ooooo0ol0000;ooooo`;o00000oooool5o`0000;ooooo
0_l00009ooooo`?o00001?ooool3o`0000[ooooo0_l00007ooooo`;o000000Coooooo`000?l0003o
00003oooool2o`000003ooooool0003o000000_ooooo0_l0001Kooooo`007?ooool00ol0003ooooo
ooooo`1Qooooo`Co00003?ooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`Co0000
0oooool6o`000003ooooool0003o000000Gooooo0_l00003ooooo`Ko000000?oooooo`000?l00000
4Oooool2o`0000Wooooo0ol00007ooooo`;o000000?oooooo`000?l000004?ooool2o`000003oooo
ool0003o000000;o00002Oooool2o`0005_ooooo000Looooo`03o`000?oooooooooo05Oooooo0_l0
000Booooo`;o00001?ooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o00001ooo
ool7o`0000[ooooo1ol00002ooooo`;o00000oooool2o`0000Oooooo0_l0000:ooooo`Co00002?oo
ool2o`0000Kooooo0_l0000>ooooo`Co0000I_ooool001cooooo00?o0000ooooooooool0Eoooool2
o`0001;ooooo0_l00009ooooo`;o00001_ooool2o`0000_ooooo0ol0000?ooooo`;o00000_ooool4
o`000003ooooool0003o000000Co00000oooool2o`0000[ooooo0_l00003ooooo`;o000000?ooooo
o`000?l000002_ooool2o`000003ooooool0003o000000Sooooo0_l0001[ooooo`007?ooool00ol0
003oooooooooo`1Rooooo`;o00004_ooool2o`0000Kooooo0_l00007ooooo`;o00005oooool2o`00
0003ooooool0003o000000;ooooo1Ol000000ooooooo0000o`00000Aooooo`;o000000?oooooo`00
0?l000001_ooool2o`0000Gooooo0_l00007ooooo`?o0000Joooool001cooooo00?o0000oooooooo
ool0D_ooool2o`0000kooooo0_l0000Booooo`?o00000oooool2o`0000?ooooo0ol000000ooooooo
0000o`000006o`0000;ooooo0_l0000;ooooo`;o00000_ooool4o`0000Kooooo1Ol00005ooooo`;o
00004oooool4o`0000Kooooo0_l000000ooooooo0000o`000003ooooo`?o0000Joooool001cooooo
00?o0000ooooooooool0D_ooool2o`0002?ooooo0_l00002ooooo`?o00000oooool3o`000003oooo
ool0003o000000;ooooo1?l00002ooooo`;o00000_ooool2o`0000Gooooo1?l00002ooooo`Co0000
2?ooool4o`0000Cooooo0_l0000Cooooo`;o00002?ooool2o`000003ooooool0003o000000;o0000
00?oooooo`000?l000003?ooool2o`0005kooooo000Looooo`03o`000?oooooooooo07_ooooo0_l0
0008ooooo`;o00002_ooool4o`0000Gooooo0_l00004ooooo`;o00003?ooool4o`0000_ooooo0_l0
000>ooooo`;o00001?ooool2o`0000?ooooo0_l0000?ooooo`;o0000G_ooool001cooooo00?o0000
ooooooooool0G_ooool2o`00023ooooo0_l00003ooooo`;o00001?ooool2o`0000Cooooo0_l00005
ooooo`;o00000oooool2o`0000gooooo2?l00008ooooo`?o00000oooool2o`000003ooooool0003o
000000Kooooo0_l00004ooooo`;o0000M?ooool001cooooo00?o0000ooooooooool0G_ooool2o`00
01[ooooo1?l00002ooooo`;o00000oooool8o`0000_ooooo0ol00002ooooo`;o00003Oooool8o`00
00Sooooo0ol00003ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Cooooo0_l0000Loooo
o`;o0000Eoooool001cooooo00?o0000ooooooooool0N_ooool4o`0000Sooooo1Ol0000=ooooo`?o
00001Oooool5o`0000Sooooo0_l000000ooooooo0000o`000002o`0000Gooooo0_l00002ooooo`;o
00002?ooool2o`0000;ooooo0ol00004ooooo`;o00000_ooool3o`0001Oooooo0_l0001Gooooo`00
00Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0O?ooool2o`0000Oooooo1?l0000<ooooo`?o00002?ooool5
o`0000Sooooo0_l00003ooooo`;o00001Oooool2o`000003ooooool0003o000000;o00000oooool6
o`0000;ooooo0_l00005ooooo`;o00000_ooool3o`00073ooooo00001_ooooooMgMgoiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`1gooooo`;o00003?ooool2o`000003ooooool0003o000000_ooooo0ol00008ooooo`;o0000
4oooool2o`000003ooooool0003o000000Ko00000oooool4o`0000_ooooo0_l0001eooooo`0000?o
oooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`1Sooooo`;o00004_ooool2o`0000cooooo0_l000000ooooooo0000
o`00000Gooooo`;o00004_ooool2o`000003ooooool0003o000000;o00000_ooool2o`0008Wooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RH
oc8b<P06ooooo`?o0000Hoooool2o`0001Wooooo0_l0000Jooooo`;o00000_ooool2o`000003oooo
ool0003o000000Oooooo0_l0000@ooooo`Co00004oooool2o`0007Cooooo00000ooooooo0000oooo
o`02ooooo`03o`000?oooooooooo00Wooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`00
0?oooooooooo07kooooo0_l0000:ooooo`;o00002Oooool3o`0000;ooooo1_l0000:ooooo`;o0000
4?ooool5o`0000gooooo0_l00003ooooo`;o0000M?ooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0
ROooool3o`0000Wooooo1Ol00002ooooo`;o00000_ooool4o`0000Kooooo0_l0000@ooooo`Go0000
2Oooool3o`000003ooooool0003o000007Wooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_o
oooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo08Cooooo0_l00003oooo
o`;o00003Oooool2o`0000Kooooo1ol0000Looooo`?o00000oooool4o`0007cooooo00001_oooooo
k^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oo
oooooooo08Cooooo0_l0000Eooooo`;o00001_ooool4o`0001_ooooo1?l00003ooooo`;o0000O_oo
ool001cooooo00?o0000ooooooooool0Q?ooool2o`0000cooooo0_l000000ooooooo0000o`000004
ooooo`;o00003Oooool2o`0000?ooooo0_l0000?ooooo`Co00001Oooool2o`0007kooooo000Loooo
o`03o`000?oooooooooo09;ooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00004
ooooo`;o00000oooool2o`000003ooooool0003o000000?ooooo0_l0000?ooooo`;o00001_ooool3
o`000003ooooool0003o000000Gooooo0_l0001dooooo`007?ooool00ol0003oooooooooo`2Hoooo
o`;o00000_ooool2o`0000Cooooo0_l00003ooooo`;o00006oooool2o`0000;ooooo0_l00002oooo
o`;o00001Oooool2o`0007Cooooo000Looooo`03o`000?oooooooooo08Oooooo0_l0000Jooooo`;o
00004Oooool3o`0000_ooooo0_l00004ooooo`;o0000OOooool001cooooo00?o0000ooooooooool0
Qoooool4o`0000Wooooo0_l00006ooooo`?o00000oooool3o`00013ooooo1?l0000Aooooo`Co0000
00?oooooo`000?l00000N?ooool001cooooo00?o0000ooooooooool0P?ooool2o`0000Oooooo0_l0
0009ooooo`;o00001_ooool3o`0000?ooooo0_l00007ooooo`Go00001Oooool2o`0000Kooooo0_l0
00000ooooooo0000o`000002ooooo`Co00000oooool3o`000003ooooool0003o000007Sooooo000L
ooooo`03o`000?oooooooooo083ooooo0_l00004ooooo`;o000000Coooooo`000?l0003o00007ooo
ool5o`0000cooooo1_l00002ooooo`Co0000POooool001cooooo00?o0000ooooooooool0Q_ooool2
o`000004ooooool0003o0000o`0000Wooooo0_l000000ooooooo0000o`00000Booooo`;o00002ooo
ool2o`000004ooooool0003o0000ooooo`;o00006Oooool2o`0006gooooo000Looooo`03o`000?oo
oooooooo09Gooooo0_l000000ooooooo0000o`000009ooooo`;o00005?ooool5o`0001cooooo0_l0
001]ooooo`007?ooool00ol0003oooooooooo`2Eooooo`;o00000oooool2o`0000Oooooo0_l0000A
ooooo`;o00000_ooool2o`0008gooooo000Looooo`03o`000?oooooooooo08?ooooo0_l0000Boooo
o`;o000000?oooooo`000?l000000oooool2o`0001Gooooo0_l0002Aooooo`007?ooool2o`0008Co
oooo0_l0000@ooooo`Co000000?oooooo`000?l000000oooool2o`0000gooooo0_l0002Iooooo`00
7?ooool00ol0003oooooooooo`1jooooo`;o00006Oooool2o`0001Oooooo0ol0002Hooooo`007?oo
ool00ol0003oooooooooo`1jooooo`;o0000;?ooool2o`0000Gooooo0_l0000=ooooo`;o0000ROoo
ool001cooooo00?o0000ooooooooool0R_ooool2o`0001cooooo0_l0000Dooooo`;o0000ROooool0
01cooooo00?o0000ooooooooool0R_ooool2o`0003Wooooo0_l00022ooooo`007?ooool00ol0003o
ooooooooo`28ooooo`;o0000;Oooool2o`0000cooooo0_l00022ooooo`007?ooool00ol0003ooooo
ooooo`28ooooo`;o00007Oooool2o`0000kooooo0_l0002@ooooo`007?ooool00ol0003ooooooooo
o`2Wooooo`;o0000X?ooool001cooooo00?o0000ooooooooool0Voooool2o`000:cooooo000Loooo
o`03o`000?oooooooooo09_ooooo0_l0000Cooooo`;o0000Uoooool001cooooo00?o0000oooooooo
ool0/?ooool2o`0009Oooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001;ooooo1?l000000ol@413ooooo
ooooo`03ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo0ol0003o
oooood[ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000oooooooo
ool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oo
oooooooo0?ooooooD_ooool001;ooooo00?oEEEEofIVI_l00000oooooomDooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00YOooool01?l@413o0000o`000?ooool2o`000003oa0@
4?oooooooooo01Gooooo00Co410@o`000?m4A4Coc<c<1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<
00Gooooo0_l000000ol@413oooooooooo`2>ooooo`00Y_ooool01Ol0003ooooooooooooooooo0000
00Wooooo1_l0000;ooooo`03oiRHV?l@413ogMgM00?ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06
ooooo`03o`000?oooooooooo08oooooo002Vooooo`05o`000?ooooooooooooooool000006oooool0
0on7QhOoEEEEooooo`02ooooo`05o`000?ooooooooooooooool000000oooool5o`00093ooooo002V
ooooo`05o`000?ooooooooooooooool000002Oooool6o`0000Wooooo00Goc<c<ob4Q8Ol0003oEEEE
o`000003ooooo`05oc8b<_nHV9SooooooiRHV?lb<S800oooool01?m4A4CogMgMooooool0002Aoooo
o`00Y_ooool01Ol0003oQhN7oooooonYZJWo000001Sooooo00Go8B4QohN7QoooooooV9RHo`000003
ooooo`05olc<c?l0003o0000o`000?o<c<`00oooool01?oMgMgoEEEEooooool0002Aooooo`00YOoo
ool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo01Kooooo00Go0000oooooooooooooooo
o`000003ooooo`05oa0@4?nj^[[ooooookZj^_l@41001?ooool00omgMgOoc<c<o`00002Aooooo`00
`oooool01OlQ8B7oV9RHoooooomgMgOoEEEE00?ooooo00Go0000okZj^_oooooo^[Zjo`000004oooo
o`03onk^k_m4A4Co0000097ooooo0033ooooo`05olc<c?l@413o0000oc8b<_o^k^h00oooool01OnY
ZJWo410@o`000?l@413oZJVY00Gooooo00?oMgMgo`000?ooool0T?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(990) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.66113 .47747 Mdot
.66046 .43065 Mdot
.31841 .4819 Mdot
.56652 .61717 Mdot
.72539 .38664 Mdot
.37009 .43851 Mdot
.49062 .30513 Mdot
.53221 .33779 Mdot
.34999 .45989 Mdot
.53042 .49522 Mdot
.49883 .33394 Mdot
.51745 .53524 Mdot
.51858 .32525 Mdot
.55068 .61781 Mdot
.61521 .84271 Mdot
.59368 .63905 Mdot
.6453 .41638 Mdot
.27804 .63111 Mdot
.54484 .54083 Mdot
.31551 .50413 Mdot
.61952 .47805 Mdot
.55999 .60938 Mdot
.66256 .47364 Mdot
.55043 .61741 Mdot
.56052 .63694 Mdot
.64196 .44782 Mdot
.68832 .4814 Mdot
.57947 .61974 Mdot
.52255 .64566 Mdot
.53444 .31611 Mdot
.39219 .74223 Mdot
.70896 .77224 Mdot
.59649 .56988 Mdot
.63733 .21838 Mdot
.52651 .34474 Mdot
.71894 .69394 Mdot
.37694 .44766 Mdot
.52257 .30445 Mdot
.52606 .34271 Mdot
.54153 .30817 Mdot
.52798 .32183 Mdot
.64787 .44536 Mdot
.5543 .34053 Mdot
.52058 .25351 Mdot
.50729 .5677 Mdot
.62637 .34209 Mdot
.53266 .75815 Mdot
.51936 .58452 Mdot
.64019 .42275 Mdot
.31199 .50027 Mdot
.62144 .22376 Mdot
.50927 .28722 Mdot
.41995 .40877 Mdot
.89684 .45335 Mdot
.51241 .29861 Mdot
.50985 .55987 Mdot
.34826 .47196 Mdot
.55673 .59616 Mdot
.55042 .61219 Mdot
.62808 .70593 Mdot
.57778 .63899 Mdot
.29861 .61804 Mdot
.62672 .41585 Mdot
.33954 .55481 Mdot
.36451 .44958 Mdot
.52326 .3419 Mdot
.66809 .41945 Mdot
.51452 .3195 Mdot
.48077 .58812 Mdot
.38063 .41264 Mdot
.52045 .5838 Mdot
.51992 .33903 Mdot
.70043 .4328 Mdot
.5334 .5743 Mdot
.33981 .25402 Mdot
.45669 .84198 Mdot
.32696 .64881 Mdot
.66404 .69269 Mdot
.62924 .73084 Mdot
.28304 .54794 Mdot
.52067 .63384 Mdot
.20354 .62254 Mdot
.56128 .84279 Mdot
.65185 .47544 Mdot
.59702 .64685 Mdot
.35906 .4147 Mdot
.53966 .57258 Mdot
.57802 .40219 Mdot
.49291 .58771 Mdot
.45015 .20214 Mdot
.34286 .46368 Mdot
.67318 .44853 Mdot
.56466 .61883 Mdot
.54388 .65754 Mdot
.66177 .5612 Mdot
.58683 .60586 Mdot
.57651 .60829 Mdot
.6892 .4734 Mdot
.49107 .33363 Mdot
.50441 .53458 Mdot
.55322 .29756 Mdot
.41185 .40413 Mdot
.53522 .55703 Mdot
.34641 .47935 Mdot
.69841 .46251 Mdot
.53815 .56683 Mdot
.49146 .34698 Mdot
.50759 .60694 Mdot
.50308 .24338 Mdot
.66245 .42717 Mdot
.53872 .65758 Mdot
.32258 .59983 Mdot
.23511 .35539 Mdot
.67676 .44984 Mdot
.33903 .52126 Mdot
.50498 .62253 Mdot
.56714 .58771 Mdot
.66009 .43353 Mdot
.33813 .44173 Mdot
.5746 .45631 Mdot
.62164 .44463 Mdot
.54394 .32269 Mdot
.62059 .43388 Mdot
.60225 .63545 Mdot
.35399 .45051 Mdot
.42786 .37998 Mdot
.43207 .38172 Mdot
.35962 .70405 Mdot
.54482 .57347 Mdot
.62121 .26735 Mdot
.3635 .43489 Mdot
.66536 .44806 Mdot
.51204 .32228 Mdot
.505 .66966 Mdot
.68881 .44024 Mdot
.49686 .3169 Mdot
.33455 .6262 Mdot
.37338 .3488 Mdot
.62791 .43396 Mdot
.52141 .24501 Mdot
.50152 .28137 Mdot
.54008 .302 Mdot
.61632 .20596 Mdot
.65451 .42704 Mdot
.32391 .62147 Mdot
.50127 .31235 Mdot
.47 .76663 Mdot
.49849 .5661 Mdot
.37261 .64486 Mdot
.15451 .55303 Mdot
.59982 .20957 Mdot
.38589 .29027 Mdot
.28393 .61834 Mdot
.53216 .29044 Mdot
.54599 .64779 Mdot
.64023 .43145 Mdot
.64446 .43477 Mdot
.57605 .58145 Mdot
.56764 .62751 Mdot
.52402 .57942 Mdot
.53309 .65592 Mdot
.57066 .78165 Mdot
.50345 .6 Mdot
.27437 .70457 Mdot
.67089 .45647 Mdot
.56837 .64009 Mdot
.30829 .4798 Mdot
.49404 .64001 Mdot
.52725 .33065 Mdot
.56219 .59909 Mdot
.56917 .61768 Mdot
.55867 .65591 Mdot
.49539 .29634 Mdot
.70328 .762 Mdot
.15888 .49831 Mdot
.80157 .60447 Mdot
.37893 .47268 Mdot
.38633 .4294 Mdot
.55164 .57009 Mdot
.30839 .62784 Mdot
.73353 .65821 Mdot
.52846 .6298 Mdot
.36115 .18318 Mdot
.57384 .60795 Mdot
.75191 .40964 Mdot
.51952 .71223 Mdot
.81248 .58622 Mdot
.30982 .68065 Mdot
.5301 .6513 Mdot
.69289 .526 Mdot
.78129 .47898 Mdot
.4726 .27878 Mdot
.52636 .31888 Mdot
.30992 .47654 Mdot
.33669 .47868 Mdot
.46872 .30658 Mdot
.46863 .57071 Mdot
.4695 .64202 Mdot
.47799 .64026 Mdot
.42123 .39757 Mdot
.6436 .40012 Mdot
.30044 .64769 Mdot
.69343 .46551 Mdot
.27441 .7634 Mdot
.52342 .22988 Mdot
.55644 .2862 Mdot
.33654 .63606 Mdot
.32357 .46492 Mdot
.41902 .40224 Mdot
.31057 .63295 Mdot
.52138 .60537 Mdot
.6602 .42052 Mdot
.74911 .31298 Mdot
.4569 .62653 Mdot
.73781 .27943 Mdot
.67992 .41456 Mdot
.56231 .44584 Mdot
.50173 .32685 Mdot
.37994 .45419 Mdot
.56967 .59058 Mdot
.53345 .59502 Mdot
.60909 .46588 Mdot
.52192 .58548 Mdot
.73403 .43544 Mdot
.57307 .58954 Mdot
.422 .35585 Mdot
.32466 .65073 Mdot
.46783 .31044 Mdot
.3491 .70188 Mdot
.68832 .4599 Mdot
.32413 .66837 Mdot
.31118 .46564 Mdot
.70271 .69625 Mdot
.51376 .34121 Mdot
.32931 .60495 Mdot
.32704 .44668 Mdot
.29342 .64492 Mdot
.49275 .62569 Mdot
.396 .41843 Mdot
.30212 .60592 Mdot
.63083 .78599 Mdot
.48847 .6098 Mdot
.55678 .79406 Mdot
.48732 .30938 Mdot
.62278 .43077 Mdot
.57859 .6363 Mdot
.36994 .46763 Mdot
.60048 .59087 Mdot
.36936 .26148 Mdot
.43597 .37655 Mdot
.41427 .41844 Mdot
.31081 .55723 Mdot
.32394 .60386 Mdot
.32203 .29905 Mdot
.60494 .24732 Mdot
.64932 .41597 Mdot
.54454 .5511 Mdot
.78474 .66096 Mdot
.50157 .31306 Mdot
.51964 .61113 Mdot
.39925 .38145 Mdot
.5035 .31107 Mdot
.55555 .59327 Mdot
.48172 .31284 Mdot
.64609 .43056 Mdot
.21277 .47021 Mdot
.64786 .41493 Mdot
.4917 .5979 Mdot
.48226 .33752 Mdot
.38701 .41547 Mdot
.63966 .45009 Mdot
.51057 .60314 Mdot
.56436 .5714 Mdot
.421 .39028 Mdot
.56296 .64736 Mdot
.75364 .69202 Mdot
.56364 .65064 Mdot
.32045 .48755 Mdot
.58664 .61413 Mdot
.44785 .16808 Mdot
.31946 .37676 Mdot
.66693 .41936 Mdot
.41139 .42151 Mdot
.34913 .46397 Mdot
.25324 .50905 Mdot
.43053 .41021 Mdot
.51041 .62397 Mdot
.39716 .4356 Mdot
.37748 .62227 Mdot
.51937 .29489 Mdot
.57083 .5586 Mdot
.56961 .29326 Mdot
.30613 .49789 Mdot
.41906 .39924 Mdot
.52798 .6937 Mdot
.70395 .45363 Mdot
.56515 .61986 Mdot
.38613 .41237 Mdot
.61656 .44533 Mdot
.49482 .59667 Mdot
.4391 .64923 Mdot
.43252 .38478 Mdot
.49421 .3041 Mdot
.52777 .70682 Mdot
.51301 .58546 Mdot
.36778 .45675 Mdot
.6962 .44334 Mdot
.53024 .34415 Mdot
.65003 .45371 Mdot
.77643 .40581 Mdot
.44286 .29831 Mdot
.60746 .77281 Mdot
.33523 .58966 Mdot
.41437 .25576 Mdot
.82239 .55663 Mdot
.27877 .32955 Mdot
.43898 .72636 Mdot
.80871 .41638 Mdot
.33413 .44258 Mdot
.40863 .36095 Mdot
.34789 .46803 Mdot
.54166 .63892 Mdot
.3677 .4433 Mdot
.82103 .57362 Mdot
.57436 .59465 Mdot
.38156 .43901 Mdot
.22459 .49131 Mdot
.57126 .62907 Mdot
.67911 .44897 Mdot
.60742 .83881 Mdot
.32039 .2519 Mdot
.54427 .21739 Mdot
.37781 .42524 Mdot
.56596 .71452 Mdot
.57789 .62213 Mdot
.55948 .6592 Mdot
.63263 .44396 Mdot
.58124 .58278 Mdot
.29838 .64611 Mdot
.3323 .63957 Mdot
.40503 .57152 Mdot
.17181 .52059 Mdot
.50695 .5341 Mdot
.63747 .44879 Mdot
.59118 .74179 Mdot
.36754 .2347 Mdot
.34101 .49888 Mdot
.5474 .33994 Mdot
.68315 .77349 Mdot
.46186 .6009 Mdot
.55517 .34346 Mdot
.54568 .25748 Mdot
.67302 .43553 Mdot
.71446 .74386 Mdot
.52341 .31164 Mdot
.72666 .54075 Mdot
.63637 .55402 Mdot
.52892 .60158 Mdot
.50407 .3405 Mdot
.51589 .53347 Mdot
.41187 .19199 Mdot
.47715 .78783 Mdot
.25383 .68734 Mdot
.49933 .58148 Mdot
.312 .28934 Mdot
.56554 .59498 Mdot
.58335 .47099 Mdot
.56696 .64919 Mdot
.64996 .45877 Mdot
.53212 .50187 Mdot
.47715 .41329 Mdot
.16251 .55512 Mdot
.52774 .22909 Mdot
.28366 .62006 Mdot
.56778 .58141 Mdot
.53006 .60152 Mdot
.32941 .62558 Mdot
.66247 .46922 Mdot
.53327 .65496 Mdot
.40034 .63968 Mdot
.52955 .58389 Mdot
.52876 .31686 Mdot
.32958 .71687 Mdot
.64848 .49342 Mdot
.58629 .63968 Mdot
.61733 .46012 Mdot
.49972 .29694 Mdot
.53094 .33669 Mdot
.53208 .69018 Mdot
.53601 .34492 Mdot
.57096 .60842 Mdot
.38902 .78015 Mdot
.63914 .46864 Mdot
.48014 .68262 Mdot
.67763 .4642 Mdot
.66101 .70743 Mdot
.48868 .34632 Mdot
.42767 .37287 Mdot
.6218 .51039 Mdot
.52306 .31508 Mdot
.56905 .2248 Mdot
.4726 .61377 Mdot
.59069 .58163 Mdot
.47197 .20017 Mdot
.37354 .42483 Mdot
.42858 .38868 Mdot
.50615 .3519 Mdot
.51524 .5829 Mdot
.5812 .57416 Mdot
.5046 .2919 Mdot
.68332 .57342 Mdot
.26027 .49042 Mdot
.57876 .61449 Mdot
.65163 .46383 Mdot
.66336 .44936 Mdot
.50892 .57632 Mdot
.5119 .61354 Mdot
.33051 .46107 Mdot
.40918 .42159 Mdot
.36799 .47188 Mdot
.43094 .38564 Mdot
.41973 .37026 Mdot
.6849 .34405 Mdot
.5415 .30718 Mdot
.6468 .29032 Mdot
.42861 .21202 Mdot
.56974 .53023 Mdot
.3916 .42533 Mdot
.53635 .60495 Mdot
.56489 .61382 Mdot
.53042 .34438 Mdot
.44923 .27625 Mdot
.60673 .62877 Mdot
.62754 .45385 Mdot
.50568 .35293 Mdot
.47388 .57546 Mdot
.69657 .31605 Mdot
.29649 .61292 Mdot
.53088 .20724 Mdot
.51879 .34108 Mdot
.67778 .4362 Mdot
.47735 .31533 Mdot
.53121 .59416 Mdot
.52424 .54856 Mdot
.66582 .43708 Mdot
.31002 .59992 Mdot
.483 .63825 Mdot
.55682 .59054 Mdot
.18728 .34826 Mdot
.3267 .26218 Mdot
.50741 .38464 Mdot
.5401 .65113 Mdot
.58878 .59313 Mdot
.28311 .638 Mdot
.52956 .58827 Mdot
.56048 .56463 Mdot
.2085 .3863 Mdot
.54947 .38457 Mdot
.27799 .63881 Mdot
.7304 .54483 Mdot
.67728 .41273 Mdot
.75116 .71481 Mdot
.3805 .45603 Mdot
.47366 .34818 Mdot
.23531 .43441 Mdot
.41521 .40846 Mdot
.38263 .25461 Mdot
.7347 .73241 Mdot
.43001 .38735 Mdot
.35718 .58238 Mdot
.59905 .53827 Mdot
.57864 .59929 Mdot
.56423 .58866 Mdot
.31347 .62392 Mdot
.65158 .42726 Mdot
.42305 .53906 Mdot
.48823 .81074 Mdot
.56411 .60386 Mdot
.72896 .43382 Mdot
.63434 .79361 Mdot
.4184 .39597 Mdot
.30043 .64426 Mdot
.33591 .60523 Mdot
.5658 .58107 Mdot
.21601 .39658 Mdot
.64071 .44662 Mdot
.51047 .6039 Mdot
.49952 .60819 Mdot
.38227 .42306 Mdot
.66984 .42504 Mdot
.34142 .43613 Mdot
.43664 .37108 Mdot
.7973 .48602 Mdot
.20263 .31688 Mdot
.51597 .34953 Mdot
.74577 .68492 Mdot
.52796 .30193 Mdot
.25451 .67437 Mdot
.41732 .40954 Mdot
.52271 .63099 Mdot
.6952 .45138 Mdot
.50829 .60357 Mdot
.52478 .61693 Mdot
.52236 .60579 Mdot
.47887 .57642 Mdot
.38131 .17737 Mdot
.29985 .63259 Mdot
.58221 .6528 Mdot
.32123 .48513 Mdot
.74401 .69336 Mdot
.51059 .83513 Mdot
.53927 .59608 Mdot
.56033 .5694 Mdot
.68303 .44735 Mdot
.57608 .57862 Mdot
.51673 .2948 Mdot
.69667 .44227 Mdot
.53582 .65854 Mdot
.70285 .74381 Mdot
.51879 .64751 Mdot
.80994 .57621 Mdot
.4769 .31553 Mdot
.56783 .22737 Mdot
.55717 .66663 Mdot
.43166 .37888 Mdot
.42872 .38864 Mdot
.38999 .44872 Mdot
.47781 .34546 Mdot
.37529 .44764 Mdot
.43035 .81034 Mdot
.5733 .53919 Mdot
.54995 .64553 Mdot
.57902 .56819 Mdot
.3949 .4293 Mdot
.58522 .39759 Mdot
.34013 .30242 Mdot
.46891 .59228 Mdot
.34384 .44974 Mdot
.61888 .43541 Mdot
.3703 .54901 Mdot
.69152 .45371 Mdot
.28261 .65107 Mdot
.50133 .33496 Mdot
.28958 .6236 Mdot
.58489 .21174 Mdot
.66225 .42916 Mdot
.60896 .46719 Mdot
.38606 .43127 Mdot
.54482 .43061 Mdot
.88255 .46548 Mdot
.38008 .41144 Mdot
.3825 .68076 Mdot
.63345 .45166 Mdot
.49972 .62198 Mdot
.31084 .69029 Mdot
.55203 .42784 Mdot
.37083 .44961 Mdot
.53476 .63346 Mdot
.21049 .43461 Mdot
.33177 .45921 Mdot
.56899 .55571 Mdot
.33893 .44324 Mdot
.52212 .33391 Mdot
.35623 .43637 Mdot
.67822 .40692 Mdot
.54172 .56647 Mdot
.88464 .48345 Mdot
.29459 .67342 Mdot
.56145 .65057 Mdot
.50149 .35247 Mdot
.41519 .60115 Mdot
.5344 .61574 Mdot
.31761 .64713 Mdot
.35315 .44925 Mdot
.28764 .44738 Mdot
.57859 .62626 Mdot
.37737 .43222 Mdot
.66434 .47539 Mdot
.47551 .34257 Mdot
.26108 .61392 Mdot
.42265 .38007 Mdot
.63282 .43923 Mdot
.43886 .3488 Mdot
.50424 .3571 Mdot
.58756 .59399 Mdot
.50407 .59587 Mdot
.65944 .45971 Mdot
.19522 .51802 Mdot
.58486 .62264 Mdot
.521 .63392 Mdot
.3156 .48374 Mdot
.38474 .44325 Mdot
.20188 .5141 Mdot
.34546 .43621 Mdot
.53265 .54265 Mdot
.65815 .45929 Mdot
.55731 .6237 Mdot
.6834 .44026 Mdot
.55936 .55969 Mdot
.69892 .40197 Mdot
.64727 .47351 Mdot
.29602 .33816 Mdot
.54601 .63015 Mdot
.51869 .70929 Mdot
.52356 .61121 Mdot
.52478 .58358 Mdot
.32732 .46907 Mdot
.3074 .64134 Mdot
.52437 .67787 Mdot
.28126 .59834 Mdot
.31497 .64579 Mdot
.77163 .45288 Mdot
.37608 .42503 Mdot
.3143 .61368 Mdot
.57668 .79536 Mdot
.4056 .42855 Mdot
.30389 .62376 Mdot
.53867 .83377 Mdot
.52006 .34885 Mdot
.66256 .40823 Mdot
.57055 .62969 Mdot
.80083 .40522 Mdot
.40828 .77449 Mdot
.41007 .41066 Mdot
.55913 .65204 Mdot
.53662 .6083 Mdot
.62808 .46427 Mdot
.24012 .70623 Mdot
.32077 .49404 Mdot
.54653 .63929 Mdot
.67242 .42035 Mdot
.16504 .62131 Mdot
.32764 .48698 Mdot
.30728 .6246 Mdot
.49977 .29207 Mdot
.71117 .42625 Mdot
.41788 .38892 Mdot
.50567 .2898 Mdot
.31364 .3384 Mdot
.56754 .21719 Mdot
.50452 .62189 Mdot
.39208 .42554 Mdot
.57113 .19406 Mdot
.49172 .54035 Mdot
.47523 .36815 Mdot
.61008 .65279 Mdot
.67481 .43794 Mdot
.51178 .29468 Mdot
.28674 .62284 Mdot
.69485 .42463 Mdot
.65663 .4689 Mdot
.53584 .33503 Mdot
.36146 .57302 Mdot
.56014 .44223 Mdot
.53139 .32309 Mdot
.45377 .20487 Mdot
.76155 .36774 Mdot
.40244 .43 Mdot
.31922 .64216 Mdot
.72529 .29827 Mdot
.64773 .44624 Mdot
.68664 .77093 Mdot
.53592 .19939 Mdot
.57658 .60879 Mdot
.31927 .61143 Mdot
.61908 .36204 Mdot
.46045 .81585 Mdot
.50365 .30842 Mdot
.48699 .40356 Mdot
.31926 .59307 Mdot
.58136 .61028 Mdot
.60659 .68135 Mdot
.53469 .63844 Mdot
.49942 .32958 Mdot
.62026 .72938 Mdot
.67872 .43627 Mdot
.50879 .35495 Mdot
.53245 .20723 Mdot
.56854 .60666 Mdot
.53847 .63388 Mdot
.36749 .7299 Mdot
.65243 .41949 Mdot
.37149 .46689 Mdot
.50748 .62353 Mdot
.55935 .59409 Mdot
.59614 .5961 Mdot
.5006 .69271 Mdot
.23063 .36429 Mdot
.5462 .63798 Mdot
.42629 .33647 Mdot
.58469 .64473 Mdot
.54652 .62749 Mdot
.61757 .45726 Mdot
.23961 .28026 Mdot
.42896 .37071 Mdot
.56176 .59698 Mdot
.50631 .62999 Mdot
.53509 .33865 Mdot
.51474 .48611 Mdot
.54951 .42209 Mdot
.39824 .40014 Mdot
.46838 .74034 Mdot
.48013 .57396 Mdot
.69034 .43316 Mdot
.32708 .6007 Mdot
.5094 .57924 Mdot
.68874 .43144 Mdot
.51003 .65234 Mdot
.33682 .45367 Mdot
.40523 .42596 Mdot
.55589 .2362 Mdot
.30708 .61749 Mdot
.38775 .76166 Mdot
.64185 .30021 Mdot
.31174 .47679 Mdot
.55574 .64265 Mdot
.46824 .31831 Mdot
.39848 .40739 Mdot
.42178 .38778 Mdot
.55027 .69097 Mdot
.64048 .43759 Mdot
.67424 .45011 Mdot
.3715 .64341 Mdot
.38143 .32226 Mdot
.18424 .38777 Mdot
.51938 .33559 Mdot
.53745 .66096 Mdot
.60838 .25521 Mdot
.67567 .4497 Mdot
.33571 .68069 Mdot
.31286 .61255 Mdot
.50278 .30702 Mdot
.34935 .49326 Mdot
.68731 .44049 Mdot
.63366 .42633 Mdot
.49006 .60522 Mdot
.54836 .58769 Mdot
.42796 .7165 Mdot
.38845 .60821 Mdot
.50331 .29485 Mdot
.32714 .63232 Mdot
.33691 .43773 Mdot
.53547 .64238 Mdot
.6549 .47594 Mdot
.75212 .33083 Mdot
.50389 .6259 Mdot
.32733 .46459 Mdot
.67263 .44033 Mdot
.33089 .61828 Mdot
.31395 .6475 Mdot
.52556 .58412 Mdot
.60952 .7176 Mdot
.51228 .30315 Mdot
.67905 .44745 Mdot
.68202 .27708 Mdot
.58625 .62332 Mdot
.54967 .5825 Mdot
.56528 .69812 Mdot
.53763 .32006 Mdot
.57238 .23273 Mdot
.30874 .59805 Mdot
.65082 .43724 Mdot
.52481 .65026 Mdot
.30023 .61702 Mdot
.59005 .23873 Mdot
.41075 .41441 Mdot
.34826 .43952 Mdot
.3159 .64781 Mdot
.32737 .61974 Mdot
.32827 .63664 Mdot
.67405 .78216 Mdot
.67981 .40636 Mdot
.47528 .6828 Mdot
.58036 .63968 Mdot
.36557 .65116 Mdot
.49903 .66507 Mdot
.47557 .31522 Mdot
.36892 .42584 Mdot
.52636 .61337 Mdot
.49213 .5991 Mdot
.5411 .7063 Mdot
.49716 .69891 Mdot
.65798 .49183 Mdot
.66482 .42608 Mdot
.57916 .53771 Mdot
.38507 .42051 Mdot
.25425 .74417 Mdot
.85211 .53026 Mdot
.55992 .66853 Mdot
.55208 .45292 Mdot
.65985 .47384 Mdot
.54057 .3222 Mdot
.52862 .41565 Mdot
.47833 .31852 Mdot
.65534 .44147 Mdot
.53854 .64117 Mdot
.65378 .29673 Mdot
.29901 .65101 Mdot
.5197 .57937 Mdot
.50113 .32095 Mdot
.52176 .57906 Mdot
.50378 .29074 Mdot
.7413 .38586 Mdot
.42146 .20239 Mdot
.57415 .60753 Mdot
.59115 .61811 Mdot
.59535 .68419 Mdot
.54065 .59743 Mdot
.22614 .60425 Mdot
.66516 .47065 Mdot
.18154 .47503 Mdot
.4898 .61002 Mdot
.71092 .64604 Mdot
.58437 .633 Mdot
.21647 .44392 Mdot
.54513 .58303 Mdot
.46182 .44175 Mdot
.579 .60653 Mdot
.5489 .56206 Mdot
.47889 .32923 Mdot
.53465 .33887 Mdot
.66495 .48064 Mdot
.37181 .46612 Mdot
.79519 .62284 Mdot
.5549 .587 Mdot
.41762 .3827 Mdot
.50938 .3788 Mdot
.32725 .62665 Mdot
.65379 .44307 Mdot
.1764 .64187 Mdot
.48773 .30342 Mdot
.30505 .5132 Mdot
.19314 .54462 Mdot
.41599 .38966 Mdot
.46417 .38096 Mdot
.57776 .48834 Mdot
.3189 .60217 Mdot
.58187 .61581 Mdot
.65692 .23498 Mdot
.33796 .25943 Mdot
.50165 .67192 Mdot
.49861 .3552 Mdot
.71658 .67669 Mdot
.73111 .30877 Mdot
.33952 .60615 Mdot
.28972 .61388 Mdot
.49131 .30203 Mdot
.31763 .50039 Mdot
.4975 .55654 Mdot
.31126 .61119 Mdot
.32231 .45985 Mdot
.40192 .43489 Mdot
.42918 .44141 Mdot
.64304 .44404 Mdot
.53485 .21153 Mdot
.62015 .32702 Mdot
.49882 .29514 Mdot
.33859 .65739 Mdot
.71272 .43223 Mdot
.70646 .434 Mdot
.39107 .44179 Mdot
.32525 .47234 Mdot
.68745 .4131 Mdot
.51993 .54625 Mdot
.52017 .71698 Mdot
.56404 .60038 Mdot
.31715 .62716 Mdot
.54093 .58798 Mdot
.33375 .46088 Mdot
.50746 .31299 Mdot
.32844 .47635 Mdot
.48389 .31196 Mdot
.68189 .33461 Mdot
.51482 .60081 Mdot
.55164 .56442 Mdot
.39997 .77393 Mdot
.65401 .4804 Mdot
.62595 .22947 Mdot
.4199 .35487 Mdot
.34373 .4727 Mdot
.56445 .56745 Mdot
.681 .46545 Mdot
.33934 .63846 Mdot
.39384 .7737 Mdot
.51448 .57931 Mdot
.66748 .47023 Mdot
.546 .64309 Mdot
.60006 .78975 Mdot
.30276 .26678 Mdot
.65437 .45387 Mdot
.16805 .57895 Mdot
.52561 .64541 Mdot
.53186 .50681 Mdot
.57077 .55381 Mdot
.40292 .65938 Mdot
.58548 .61986 Mdot
.68026 .4146 Mdot
.5602 .60299 Mdot
.69563 .42844 Mdot
.3132 .48766 Mdot
.5401 .30842 Mdot
.63057 .45082 Mdot
.50178 .59684 Mdot
.7578 .73688 Mdot
.50447 .33358 Mdot
.56872 .58599 Mdot
.48784 .32938 Mdot
.67571 .41816 Mdot
.63393 .42875 Mdot
.46171 .82526 Mdot
.53141 .38488 Mdot
.52303 .33246 Mdot
.55314 .63591 Mdot
.59276 .31408 Mdot
.55189 .62954 Mdot
.41002 .70741 Mdot
.51446 .56386 Mdot
.58638 .61708 Mdot
.44992 .84319 Mdot
.52095 .29468 Mdot
.19153 .38419 Mdot
.50289 .80868 Mdot
.65932 .7912 Mdot
.69533 .40748 Mdot
.33956 .60687 Mdot
.71103 .74808 Mdot
.43678 .37238 Mdot
.35691 .4411 Mdot
.52614 .61176 Mdot
.6366 .49791 Mdot
.52145 .30237 Mdot
.30814 .64005 Mdot
.574 .60614 Mdot
.32386 .47149 Mdot
.28734 .51332 Mdot
.54205 .30198 Mdot
.64847 .44492 Mdot
.63049 .46095 Mdot
.1536 .578 Mdot
.52686 .65165 Mdot
.55967 .56628 Mdot
.4992 .33185 Mdot
.46187 .63711 Mdot
.32926 .60693 Mdot
.23324 .46767 Mdot
.52195 .3328 Mdot
.51666 .45316 Mdot
.65868 .42458 Mdot
.53598 .60704 Mdot
.59135 .4012 Mdot
.39782 .46224 Mdot
.75459 .51353 Mdot
.31129 .62698 Mdot
.40891 .71545 Mdot
.67966 .41418 Mdot
.50832 .32093 Mdot
.38029 .35267 Mdot
.60198 .61116 Mdot
.54164 .60691 Mdot
.40483 .71683 Mdot
.39203 .5796 Mdot
.26657 .69394 Mdot
.55341 .55107 Mdot
.39872 .5701 Mdot
.54893 .55432 Mdot
.5977 .5934 Mdot
.5239 .54678 Mdot
.54858 .57605 Mdot
.66495 .47147 Mdot
.49635 .68181 Mdot
.36892 .43398 Mdot
.66658 .55509 Mdot
.50974 .40615 Mdot
.57456 .63951 Mdot
.54233 .6371 Mdot
.77101 .5429 Mdot
.54914 .35807 Mdot
.64693 .46879 Mdot
.61365 .42307 Mdot
.53998 .34052 Mdot
.52451 .71257 Mdot
.36404 .47134 Mdot
.51754 .69252 Mdot
.32953 .47199 Mdot
.67584 .46688 Mdot
.34243 .47583 Mdot
.5455 .313 Mdot
.39269 .4244 Mdot
.42037 .36538 Mdot
.51641 .29654 Mdot
.64467 .42409 Mdot
.53248 .576 Mdot
.50748 .35268 Mdot
.37164 .72924 Mdot
.31683 .62635 Mdot
.46455 .82628 Mdot
.51235 .65014 Mdot
.53582 .39594 Mdot
.4387 .6498 Mdot
.3301 .47499 Mdot
.25793 .31218 Mdot
.64589 .47291 Mdot
.30026 .655 Mdot
.67484 .46815 Mdot
.48944 .18335 Mdot
.31488 .64096 Mdot
.54665 .83305 Mdot
.40093 .30949 Mdot
.28579 .47893 Mdot
.51217 .55225 Mdot
.62491 .60289 Mdot
.3847 .41125 Mdot
.51973 .30106 Mdot
.39047 .30762 Mdot
.54359 .56238 Mdot
.28004 .33185 Mdot
.6599 .48277 Mdot
.39476 .44219 Mdot
.51476 .32176 Mdot
.51587 .3535 Mdot
.5049 .60884 Mdot
.22618 .5236 Mdot
.53272 .56121 Mdot
.36936 .32277 Mdot
.44686 .73544 Mdot
.56465 .70241 Mdot
.57237 .58791 Mdot
.34378 .48043 Mdot
.54722 .6425 Mdot
.52104 .72681 Mdot
.62255 .21023 Mdot
.47551 .59916 Mdot
.43442 .29803 Mdot
.34344 .6503 Mdot
.66331 .43391 Mdot
.54674 .6684 Mdot
.42045 .38634 Mdot
.53222 .64939 Mdot
.57589 .15361 Mdot
.30234 .62218 Mdot
.36221 .40721 Mdot
.58665 .6351 Mdot
.50601 .61576 Mdot
.62806 .53268 Mdot
.62783 .50052 Mdot
.34883 .49418 Mdot
.54729 .60431 Mdot
.46711 .756 Mdot
.49904 .34073 Mdot
.52789 .56373 Mdot
.56528 .58707 Mdot
.7816 .46708 Mdot
.5352 .32938 Mdot
.33131 .47899 Mdot
.42028 .40802 Mdot
.32215 .44975 Mdot
.27994 .61318 Mdot
.50259 .42212 Mdot
.35706 .66403 Mdot
.31392 .26339 Mdot
.339 .61842 Mdot
.50997 .64003 Mdot
.61132 .60901 Mdot
.5143 .63562 Mdot
.2856 .6224 Mdot
.5363 .32077 Mdot
.6428 .46828 Mdot
.56502 .2498 Mdot
.42105 .39611 Mdot
.57184 .55923 Mdot
.29048 .64049 Mdot
.63981 .43341 Mdot
.28769 .66615 Mdot
.65692 .43491 Mdot
.52304 .32589 Mdot
.52225 .35895 Mdot
.29622 .63775 Mdot
.68843 .45679 Mdot
.43115 .33963 Mdot
.47899 .808 Mdot
.51925 .55822 Mdot
.45519 .3274 Mdot
.67086 .47425 Mdot
.67482 .48662 Mdot
.687 .47306 Mdot
.52042 .58913 Mdot
.54891 .45983 Mdot
.59729 .62393 Mdot
.49881 .29863 Mdot
.33528 .44704 Mdot
.38606 .61869 Mdot
.74133 .35238 Mdot
.37225 .60635 Mdot
.48963 .64843 Mdot
.56567 .60764 Mdot
.56595 .58153 Mdot
.50104 .57307 Mdot
.365 .34509 Mdot
.51258 .609 Mdot
.47942 .32594 Mdot
.34122 .45948 Mdot
.57718 .64074 Mdot
.40811 .41349 Mdot
.5692 .43948 Mdot
.32943 .60146 Mdot
.49484 .41613 Mdot
.76822 .70061 Mdot
.63694 .43622 Mdot
.35192 .4315 Mdot
.36063 .43952 Mdot
.3348 .62515 Mdot
.52215 .30486 Mdot
.65455 .42995 Mdot
.41417 .66784 Mdot
.32783 .63488 Mdot
.56014 .59954 Mdot
.2662 .39068 Mdot
.26016 .37295 Mdot
.58225 .60046 Mdot
.52846 .62342 Mdot
.41452 .41751 Mdot
.32027 .49902 Mdot
.76397 .29948 Mdot
.3078 .69723 Mdot
.30104 .64048 Mdot
.30683 .60186 Mdot
.70487 .44701 Mdot
.57997 .66127 Mdot
.49556 .30201 Mdot
.33621 .72499 Mdot
.4084 .59721 Mdot
.36824 .75227 Mdot
.26249 .60779 Mdot
.50801 .59375 Mdot
.63566 .63442 Mdot
.56966 .60858 Mdot
.63727 .47226 Mdot
.66347 .41686 Mdot
.63954 .45898 Mdot
.51266 .30025 Mdot
.67064 .70365 Mdot
.4839 .33874 Mdot
.79917 .65224 Mdot
.68293 .41432 Mdot
.3441 .37712 Mdot
.35822 .46529 Mdot
.54723 .6649 Mdot
.32906 .61024 Mdot
.52684 .28141 Mdot
.48278 .5813 Mdot
.22034 .38136 Mdot
.39028 .42821 Mdot
.64635 .42164 Mdot
.57834 .49054 Mdot
.82597 .51151 Mdot
.53541 .42883 Mdot
.53046 .51798 Mdot
.62793 .55729 Mdot
.32544 .6326 Mdot
.75094 .51489 Mdot
.28411 .614 Mdot
.49937 .31341 Mdot
.54634 .56617 Mdot
.54123 .57234 Mdot
.55755 .5578 Mdot
.51381 .60648 Mdot
.53782 .33881 Mdot
.50304 .66088 Mdot
.44785 .16809 Mdot
.4064 .42645 Mdot
.62029 .78406 Mdot
.30212 .61055 Mdot
.48416 .34948 Mdot
.33801 .46251 Mdot
.36282 .47872 Mdot
.34298 .69372 Mdot
.57846 .61035 Mdot
.52458 .61306 Mdot
.33346 .50453 Mdot
.55882 .55257 Mdot
.47086 .5918 Mdot
.37162 .43432 Mdot
.37336 .60514 Mdot
.33957 .62755 Mdot
.29045 .62147 Mdot
.53433 .32332 Mdot
.6839 .46147 Mdot
.3149 .61835 Mdot
.31559 .4879 Mdot
.5055 .65412 Mdot
.49747 .60541 Mdot
.67091 .47488 Mdot
.53347 .19834 Mdot
.33559 .60158 Mdot
.57357 .48771 Mdot
.69182 .42689 Mdot
.67901 .40549 Mdot
.54217 .60849 Mdot
.49944 .67358 Mdot
.69861 .47575 Mdot
.32962 .63927 Mdot
.48832 .35298 Mdot
.31209 .43631 Mdot
.49708 .32008 Mdot
.6487 .42854 Mdot
.49842 .59098 Mdot
.65108 .42293 Mdot
.54123 .65235 Mdot
.59529 .87488 Mdot
.54328 .57582 Mdot
.34972 .22823 Mdot
.39675 .67262 Mdot
.36319 .44128 Mdot
.43166 .34382 Mdot
.39299 .4412 Mdot
.68879 .42233 Mdot
.50284 .58794 Mdot
.30185 .60185 Mdot
.60987 .82241 Mdot
.71361 .43842 Mdot
.34185 .44777 Mdot
.3467 .48772 Mdot
.52338 .29828 Mdot
.57494 .64549 Mdot
.53877 .60409 Mdot
.38344 .43948 Mdot
.4744 .70968 Mdot
.68722 .44751 Mdot
.56331 .57098 Mdot
.55736 .61725 Mdot
.36769 .43869 Mdot
.4732 .806 Mdot
.60365 .50428 Mdot
.55001 .56956 Mdot
.38571 .37597 Mdot
.47453 .32367 Mdot
.50415 .56296 Mdot
.50348 .66217 Mdot
.32319 .61106 Mdot
.66853 .75378 Mdot
.64305 .21874 Mdot
.47787 .30734 Mdot
.37516 .46214 Mdot
.51974 .65117 Mdot
.36158 .46179 Mdot
.49904 .60267 Mdot
.76173 .65265 Mdot
.39955 .43539 Mdot
.51469 .62415 Mdot
.5657 .67057 Mdot
.65704 .41686 Mdot
.51021 .61137 Mdot
.77978 .51668 Mdot
.36795 .41971 Mdot
.51195 .61869 Mdot
.61395 .71088 Mdot
.527 .33923 Mdot
.55698 .66984 Mdot
.29692 .61043 Mdot
.4052 .6544 Mdot
.64342 .3109 Mdot
.40085 .38619 Mdot
.29263 .61936 Mdot
.5241 .57391 Mdot
.31845 .50241 Mdot
.49913 .29373 Mdot
.27422 .33058 Mdot
.56897 .57032 Mdot
.50056 .33031 Mdot
.50902 .31456 Mdot
.2965 .62199 Mdot
.16493 .43516 Mdot
.5149 .66401 Mdot
.53981 .59489 Mdot
.78735 .51109 Mdot
.62088 .45221 Mdot
.53889 .58475 Mdot
.50483 .63019 Mdot
.48102 .32622 Mdot
.62376 .51 Mdot
.74771 .62243 Mdot
.2245 .48863 Mdot
.49168 .29115 Mdot
.32031 .4457 Mdot
.31876 .50321 Mdot
.30525 .60962 Mdot
.66607 .44041 Mdot
.30776 .59353 Mdot
.37626 .42717 Mdot
.51389 .64224 Mdot
.48639 .31318 Mdot
.7548 .45193 Mdot
.51093 .28702 Mdot
.39688 .39303 Mdot
.64215 .47945 Mdot
.60163 .26361 Mdot
.50136 .13868 Mdot
.62842 .33158 Mdot
.55951 .32994 Mdot
.32727 .62629 Mdot
.30906 .34312 Mdot
.56037 .61406 Mdot
.73586 .52217 Mdot
.52832 .57777 Mdot
.62617 .68345 Mdot
.34447 .43766 Mdot
.35851 .48145 Mdot
.5472 .56764 Mdot
.43258 .72937 Mdot
.51993 .28688 Mdot
.51838 .29448 Mdot
.51731 .61867 Mdot
.52341 .31551 Mdot
.549 .59155 Mdot
.32934 .46789 Mdot
.21348 .34647 Mdot
.56828 .59911 Mdot
.59291 .5901 Mdot
.56113 .28925 Mdot
.48115 .83022 Mdot
.41325 .32252 Mdot
.63628 .61994 Mdot
.82007 .47865 Mdot
.52279 .3154 Mdot
.56272 .68096 Mdot
.394 .40557 Mdot
.41518 .41667 Mdot
.43196 .34123 Mdot
.53259 .58472 Mdot
.52849 .58901 Mdot
.56574 .56956 Mdot
.5377 .63476 Mdot
.7398 .52326 Mdot
.47261 .65647 Mdot
.65103 .65589 Mdot
.52393 .61572 Mdot
.60878 .67992 Mdot
.50701 .35156 Mdot
.61492 .4727 Mdot
.31421 .5907 Mdot
.50731 .59578 Mdot
.71425 .47181 Mdot
.47489 .33132 Mdot
.80097 .6493 Mdot
.5328 .31067 Mdot
.35041 .46246 Mdot
.53892 .31113 Mdot
.55843 .64953 Mdot
.66381 .44992 Mdot
.38842 .40451 Mdot
.33067 .29018 Mdot
.35495 .44209 Mdot
.56155 .65058 Mdot
.3464 .41196 Mdot
.35961 .43847 Mdot
.57101 .41836 Mdot
.66809 .44762 Mdot
.45889 .75847 Mdot
.66365 .41655 Mdot
.51261 .62345 Mdot
.5157 .62883 Mdot
.44119 .336 Mdot
.53458 .2969 Mdot
.6727 .41632 Mdot
.17921 .36039 Mdot
.28446 .61086 Mdot
.64175 .45784 Mdot
.59678 .56811 Mdot
.45924 .51157 Mdot
.66493 .45584 Mdot
.45407 .70996 Mdot
.51546 .29828 Mdot
.695 .42124 Mdot
.59887 .57674 Mdot
.46066 .23074 Mdot
.30781 .65279 Mdot
.33427 .49073 Mdot
.44816 .46394 Mdot
.37941 .415 Mdot
.49077 .35595 Mdot
.39214 .43076 Mdot
.49992 .34297 Mdot
.61604 .22951 Mdot
.56599 .73661 Mdot
.46835 .31387 Mdot
.5075 .35906 Mdot
.3841 .43175 Mdot
.57338 .58464 Mdot
.45478 .40958 Mdot
.54495 .5477 Mdot
.48827 .57565 Mdot
.50734 .34441 Mdot
.67471 .41306 Mdot
.65842 .40841 Mdot
.61734 .65086 Mdot
.63009 .46103 Mdot
.32772 .47251 Mdot
.30669 .26434 Mdot
.58978 .21337 Mdot
.50335 .33858 Mdot
.52723 .35234 Mdot
.54919 .63189 Mdot
.37337 .44859 Mdot
.3102 .48913 Mdot
.50053 .30263 Mdot
.72167 .50568 Mdot
.59242 .63389 Mdot
.65539 .48692 Mdot
.68416 .41416 Mdot
.65609 .45728 Mdot
.69554 .46404 Mdot
.7435 .60661 Mdot
.51505 .29752 Mdot
.68594 .41786 Mdot
.51701 .62247 Mdot
.52995 .58835 Mdot
.4285 .3854 Mdot
.2911 .61894 Mdot
.5161 .65539 Mdot
.53428 .53988 Mdot
.5394 .61003 Mdot
.34967 .43948 Mdot
.5993 .55454 Mdot
.37483 .46423 Mdot
.32432 .49465 Mdot
.40393 .41794 Mdot
.42967 .37321 Mdot
.62251 .58166 Mdot
.82756 .47034 Mdot
.54625 .63959 Mdot
.4564 .6339 Mdot
.35773 .46435 Mdot
.24074 .34022 Mdot
.57838 .23701 Mdot
.56638 .56849 Mdot
.40895 .45798 Mdot
.38567 .43848 Mdot
.62367 .44431 Mdot
.53555 .58142 Mdot
.42807 .39312 Mdot
.33012 .603 Mdot
.58815 .55321 Mdot
.42527 .40029 Mdot
.69259 .44969 Mdot
.31477 .58505 Mdot
.70051 .43009 Mdot
.39747 .4171 Mdot
.56359 .67062 Mdot
.88538 .45811 Mdot
.3205 .45243 Mdot
.55885 .81221 Mdot
.69093 .49091 Mdot
.56526 .57246 Mdot
.35216 .43047 Mdot
.62204 .45464 Mdot
.48343 .3521 Mdot
.43354 .53118 Mdot
.63923 .46822 Mdot
.36215 .47792 Mdot
.42295 .39956 Mdot
.36881 .43539 Mdot
.66835 .42802 Mdot
.51742 .56774 Mdot
.67958 .43184 Mdot
.53815 .31056 Mdot
.56779 .62094 Mdot
.82037 .57203 Mdot
.46087 .64277 Mdot
.68647 .42126 Mdot
.32052 .48017 Mdot
.28533 .64231 Mdot
.57502 .61537 Mdot
.54777 .80487 Mdot
.5409 .65678 Mdot
.49564 .33517 Mdot
.20085 .43881 Mdot
.75836 .46326 Mdot
.58274 .63369 Mdot
.54774 .63261 Mdot
.50909 .29297 Mdot
.57749 .6118 Mdot
.58387 .62531 Mdot
.50785 .38156 Mdot
.6705 .42358 Mdot
.5603 .60666 Mdot
.31582 .47329 Mdot
.65815 .24251 Mdot
.59496 .62847 Mdot
.35104 .51363 Mdot
.4456 .7478 Mdot
.18805 .44398 Mdot
.53082 .57296 Mdot
.33063 .70928 Mdot
.53359 .63225 Mdot
.51633 .58688 Mdot
.55432 .63229 Mdot
.63883 .59544 Mdot
.38596 .42727 Mdot
.34132 .45378 Mdot
.31249 .65153 Mdot
.45167 .75011 Mdot
.31956 .61039 Mdot
.52794 .3063 Mdot
.2959 .54033 Mdot
.40021 .43364 Mdot
.69279 .45106 Mdot
.52851 .56683 Mdot
.36757 .41852 Mdot
.53348 .60617 Mdot
.55261 .65072 Mdot
.3422 .48253 Mdot
.30733 .49134 Mdot
.40873 .38962 Mdot
.31396 .5999 Mdot
.63517 .45726 Mdot
.48808 .61209 Mdot
.31376 .64606 Mdot
.51607 .57011 Mdot
.35399 .65885 Mdot
.639 .46177 Mdot
.67303 .42489 Mdot
.63335 .42178 Mdot
.51458 .6431 Mdot
.57126 .64156 Mdot
.48558 .34014 Mdot
.68841 .45912 Mdot
.5296 .33193 Mdot
.39438 .40268 Mdot
.31354 .52749 Mdot
.53243 .58489 Mdot
.54538 .49824 Mdot
.32028 .6056 Mdot
.3434 .46506 Mdot
.33187 .50857 Mdot
.29436 .65298 Mdot
.54326 .65544 Mdot
.3469 .4782 Mdot
.2881 .62868 Mdot
.69114 .51405 Mdot
.82314 .42646 Mdot
.28265 .63448 Mdot
.51856 .62182 Mdot
.63711 .51607 Mdot
.45317 .79626 Mdot
.27948 .61927 Mdot
.48848 .32218 Mdot
.51375 .64337 Mdot
.45246 .66103 Mdot
.32843 .59672 Mdot
.65639 .24862 Mdot
.3629 .44343 Mdot
.47221 .24147 Mdot
.54536 .52929 Mdot
.71331 .53119 Mdot
.29736 .59769 Mdot
.6526 .43352 Mdot
.61381 .45521 Mdot
.5422 .61763 Mdot
.28326 .60538 Mdot
.49628 .28898 Mdot
.35653 .44859 Mdot
.42465 .3613 Mdot
.67088 .42901 Mdot
.58075 .31341 Mdot
.32738 .45732 Mdot
.56374 .48857 Mdot
.21658 .46197 Mdot
.52973 .719 Mdot
.60605 .70289 Mdot
.36288 .24771 Mdot
.50264 .63124 Mdot
.28274 .62399 Mdot
.47626 .33168 Mdot
.48875 .30509 Mdot
.52053 .33161 Mdot
.4314 .34692 Mdot
.52211 .41498 Mdot
.39383 .41399 Mdot
.30375 .31387 Mdot
.30135 .61633 Mdot
.48821 .76579 Mdot
.51547 .57307 Mdot
.5663 .60587 Mdot
.53541 .66096 Mdot
.5331 .55874 Mdot
.54024 .62738 Mdot
.52448 .30994 Mdot
.42986 .34446 Mdot
.28827 .44412 Mdot
.65398 .46438 Mdot
.36654 .5994 Mdot
.35774 .46575 Mdot
.41196 .42091 Mdot
.3018 .6358 Mdot
.57985 .47248 Mdot
.40192 .40867 Mdot
.34102 .47592 Mdot
.52158 .66009 Mdot
.6868 .43784 Mdot
.50355 .6806 Mdot
.52226 .63439 Mdot
.33863 .46666 Mdot
.35009 .55267 Mdot
.77042 .58217 Mdot
.5888 .66794 Mdot
.34276 .59706 Mdot
.53274 .47199 Mdot
.27978 .62027 Mdot
.57274 .55343 Mdot
.23186 .3523 Mdot
.3774 .42725 Mdot
.36106 .4544 Mdot
.28574 .63089 Mdot
.55363 .50416 Mdot
.67125 .43693 Mdot
.35094 .48869 Mdot
.48873 .33455 Mdot
.5128 .63158 Mdot
.31045 .52049 Mdot
.51369 .51733 Mdot
.24256 .51994 Mdot
.51462 .33548 Mdot
.32033 .49129 Mdot
.57651 .64401 Mdot
.52041 .62248 Mdot
.32828 .62763 Mdot
.72859 .3848 Mdot
.57997 .54204 Mdot
.6626 .78974 Mdot
.43116 .20279 Mdot
.49107 .21288 Mdot
.5417 .60668 Mdot
.66796 .42437 Mdot
.41706 .4095 Mdot
.32146 .64026 Mdot
.49129 .64334 Mdot
.82413 .44017 Mdot
.63705 .48257 Mdot
.50282 .31815 Mdot
.42915 .39037 Mdot
.529 .41466 Mdot
.52647 .65343 Mdot
.52906 .57801 Mdot
.5177 .59611 Mdot
.79887 .35182 Mdot
.33694 .44954 Mdot
.64532 .47743 Mdot
.3107 .62944 Mdot
.63191 .46427 Mdot
.35024 .44766 Mdot
.5798 .27189 Mdot
.5785 .63074 Mdot
.64618 .48294 Mdot
.65408 .43631 Mdot
.52408 .29907 Mdot
.48795 .35609 Mdot
.31744 .44278 Mdot
.54445 .57653 Mdot
.42687 .39566 Mdot
.65724 .41571 Mdot
.33016 .50264 Mdot
.31727 .63984 Mdot
.49414 .34908 Mdot
.52297 .61469 Mdot
.37018 .43134 Mdot
.48901 .653 Mdot
.67243 .45512 Mdot
.34236 .47525 Mdot
.41926 .3844 Mdot
.30367 .6039 Mdot
.52557 .60027 Mdot
.34623 .60843 Mdot
.374 .46275 Mdot
.5587 .61712 Mdot
.59134 .48209 Mdot
.33566 .58447 Mdot
.34011 .29676 Mdot
.38576 .41599 Mdot
.42615 .37926 Mdot
.63482 .42241 Mdot
.65868 .26027 Mdot
.35826 .45463 Mdot
.58697 .47216 Mdot
.70135 .35916 Mdot
.48775 .61298 Mdot
.64918 .44979 Mdot
.28987 .36073 Mdot
.7244 .75268 Mdot
.51437 .78752 Mdot
.56792 .58597 Mdot
.36389 .42479 Mdot
.29382 .64159 Mdot
.50361 .33913 Mdot
.35061 .51284 Mdot
.52506 .72554 Mdot
.36354 .46654 Mdot
.55005 .63466 Mdot
.66676 .41849 Mdot
.50629 .30424 Mdot
.66592 .30587 Mdot
.31737 .48559 Mdot
.35098 .43413 Mdot
.57925 .63937 Mdot
.3115 .61343 Mdot
.56163 .77159 Mdot
.33099 .46281 Mdot
.30626 .51148 Mdot
.31419 .33599 Mdot
.28955 .64006 Mdot
.52948 .62819 Mdot
.61409 .65858 Mdot
.50068 .57109 Mdot
.5698 .81574 Mdot
.38419 .45176 Mdot
.65767 .46532 Mdot
.5242 .5799 Mdot
.21738 .49323 Mdot
.34406 .46119 Mdot
.55262 .44948 Mdot
.33383 .55053 Mdot
.51416 .29778 Mdot
.30702 .51475 Mdot
.53646 .59198 Mdot
.51818 .28654 Mdot
.32019 .60591 Mdot
.55083 .57248 Mdot
.57066 .64101 Mdot
.62383 .45428 Mdot
.49827 .31271 Mdot
.7522 .37698 Mdot
.51089 .3551 Mdot
.47699 .31636 Mdot
.63858 .41249 Mdot
.55242 .60755 Mdot
.34695 .46651 Mdot
.38514 .4405 Mdot
.48796 .62111 Mdot
.25416 .30345 Mdot
.67283 .43531 Mdot
.33008 .66417 Mdot
.77647 .32914 Mdot
.59904 .66269 Mdot
.32722 .51089 Mdot
.72257 .38264 Mdot
.49593 .28995 Mdot
.5202 .61787 Mdot
.69167 .43338 Mdot
.31062 .50651 Mdot
.3255 .45897 Mdot
.50492 .58072 Mdot
.50972 .31011 Mdot
.33656 .61261 Mdot
.32115 .45353 Mdot
.22731 .52192 Mdot
.51257 .59988 Mdot
.28777 .32992 Mdot
.33836 .43943 Mdot
.6353 .82014 Mdot
.26686 .47181 Mdot
.6495 .45347 Mdot
.55585 .64886 Mdot
.63003 .45887 Mdot
.31491 .63119 Mdot
.3293 .43626 Mdot
.50817 .31155 Mdot
.60358 .6516 Mdot
.55787 .16644 Mdot
.38678 .42953 Mdot
.66337 .47165 Mdot
.58252 .63511 Mdot
.6112 .559 Mdot
.54197 .59042 Mdot
.61942 .51476 Mdot
.32211 .66715 Mdot
.51306 .34439 Mdot
.49292 .33157 Mdot
.56303 .61589 Mdot
.3334 .61952 Mdot
.32745 .48904 Mdot
.35734 .449 Mdot
.36417 .84178 Mdot
.33897 .49848 Mdot
.42487 .70982 Mdot
.52735 .59291 Mdot
.33433 .49875 Mdot
.73596 .33476 Mdot
.49987 .33284 Mdot
.52886 .55926 Mdot
.35821 .47905 Mdot
.4449 .22082 Mdot
.37521 .6263 Mdot
.53757 .62694 Mdot
.48477 .55995 Mdot
.48856 .33215 Mdot
.39573 .75721 Mdot
.39442 .41831 Mdot
.52071 .56039 Mdot
.54312 .33968 Mdot
.20351 .49589 Mdot
.58623 .20009 Mdot
.63526 .45707 Mdot
.36121 .42083 Mdot
.52432 .30921 Mdot
.55652 .52886 Mdot
.29909 .61202 Mdot
.37548 .41566 Mdot
.34758 .44224 Mdot
.55862 .63529 Mdot
.53011 .66324 Mdot
.60913 .64946 Mdot
.66604 .46891 Mdot
.51742 .35049 Mdot
.5437 .56494 Mdot
.57925 .31724 Mdot
.55287 .55586 Mdot
.49725 .34822 Mdot
.90629 .53811 Mdot
.50143 .56045 Mdot
.5427 .59256 Mdot
.55425 .77606 Mdot
.63644 .46547 Mdot
.62664 .45598 Mdot
.38018 .21617 Mdot
.52721 .59363 Mdot
.2723 .49292 Mdot
.63237 .45385 Mdot
.67497 .43913 Mdot
.3214 .38589 Mdot
.57212 .60733 Mdot
.38932 .76937 Mdot
.49101 .30467 Mdot
.48009 .31709 Mdot
.67755 .4313 Mdot
.56969 .53469 Mdot
.49381 .29354 Mdot
.74843 .5489 Mdot
.37457 .44841 Mdot
.22362 .36212 Mdot
.67397 .4572 Mdot
.47405 .39766 Mdot
.5065 .33692 Mdot
.79613 .65728 Mdot
.40676 .45481 Mdot
.56902 .57624 Mdot
.52206 .60109 Mdot
.31655 .60493 Mdot
.48659 .60712 Mdot
.3676 .47232 Mdot
.52373 .31575 Mdot
.59153 .76539 Mdot
.6395 .45822 Mdot
.54644 .58161 Mdot
.57291 .47231 Mdot
.67078 .32371 Mdot
.40986 .29739 Mdot
.66277 .43455 Mdot
.64423 .44661 Mdot
.38707 .41932 Mdot
.33872 .44153 Mdot
.54764 .61481 Mdot
.49977 .29934 Mdot
.69323 .4538 Mdot
.49939 .34713 Mdot
.37375 .4283 Mdot
.34108 .47331 Mdot
.40022 .43503 Mdot
.54959 .54562 Mdot
.32483 .48396 Mdot
.21526 .52804 Mdot
.57922 .30026 Mdot
.70685 .43584 Mdot
.60904 .18532 Mdot
.66577 .30422 Mdot
.42837 .64509 Mdot
.30456 .59943 Mdot
.37345 .46295 Mdot
.5397 .33161 Mdot
.55039 .62939 Mdot
.5288 .60989 Mdot
.41792 .39665 Mdot
.53056 .29736 Mdot
.31164 .63806 Mdot
.53025 .29526 Mdot
.2957 .61956 Mdot
.32292 .50678 Mdot
.57052 .65049 Mdot
.5004 .61396 Mdot
.52625 .31646 Mdot
.33439 .48063 Mdot
.34107 .45779 Mdot
.2807 .61921 Mdot
.39326 .58868 Mdot
.36802 .43462 Mdot
.67382 .45648 Mdot
.73228 .61289 Mdot
.41947 .40379 Mdot
.53684 .58272 Mdot
.34854 .66953 Mdot
.73998 .50631 Mdot
.50455 .57154 Mdot
.43162 .381 Mdot
.22484 .67502 Mdot
.52984 .56901 Mdot
.18947 .6305 Mdot
.42712 .37839 Mdot
.63921 .46916 Mdot
.36276 .42601 Mdot
.367 .47415 Mdot
.50846 .53126 Mdot
.29547 .66061 Mdot
.49507 .63881 Mdot
.63017 .4554 Mdot
.61743 .44993 Mdot
.46711 .20059 Mdot
.55973 .81303 Mdot
.28555 .61328 Mdot
.29588 .63342 Mdot
.36079 .45164 Mdot
.39922 .81608 Mdot
.60089 .62307 Mdot
.30331 .64037 Mdot
.53593 .75331 Mdot
.54305 .63864 Mdot
.39828 .70574 Mdot
.41015 .46216 Mdot
.67003 .42658 Mdot
.62381 .61613 Mdot
.35185 .45745 Mdot
.65718 .47224 Mdot
.56047 .25757 Mdot
.51821 .65425 Mdot
.64027 .46204 Mdot
.49196 .34426 Mdot
.38248 .25864 Mdot
.63277 .43135 Mdot
.34165 .67085 Mdot
.50086 .30113 Mdot
.32401 .34363 Mdot
.51323 .75328 Mdot
.45453 .12159 Mdot
.5211 .30796 Mdot
.3595 .4672 Mdot
.38471 .43983 Mdot
.36026 .44763 Mdot
.64633 .47413 Mdot
.31364 .49126 Mdot
.67261 .46559 Mdot
.44872 .80319 Mdot
.39365 .58988 Mdot
.29624 .63839 Mdot
.53727 .38173 Mdot
.64908 .44041 Mdot
.28388 .29649 Mdot
.51827 .14288 Mdot
.51609 .61647 Mdot
.52279 .35315 Mdot
.28614 .62727 Mdot
.5895 .84312 Mdot
.32084 .60823 Mdot
.39226 .4068 Mdot
.20465 .3862 Mdot
.55097 .58755 Mdot
.72311 .67771 Mdot
.29815 .60451 Mdot
.65736 .42698 Mdot
.56192 .61335 Mdot
.43254 .33695 Mdot
.31046 .60995 Mdot
.33393 .6085 Mdot
.55075 .61809 Mdot
.6472 .42094 Mdot
.34139 .4705 Mdot
.54335 .32514 Mdot
.27608 .63298 Mdot
.47022 .56609 Mdot
.4883 .60802 Mdot
.51177 .64656 Mdot
.54797 .42753 Mdot
.51202 .73087 Mdot
.52215 .31438 Mdot
.46953 .78543 Mdot
.33731 .4432 Mdot
.2946 .3778 Mdot
.39158 .21425 Mdot
.49994 .38669 Mdot
.39203 .44146 Mdot
.38366 .45371 Mdot
.54178 .62398 Mdot
.51304 .73221 Mdot
.19753 .45213 Mdot
.56561 .32509 Mdot
.41698 .40699 Mdot
.35231 .45179 Mdot
.61462 .46236 Mdot
.47221 .1944 Mdot
.4873 .63959 Mdot
.4841 .295 Mdot
.36359 .43426 Mdot
.76438 .64888 Mdot
.30888 .61721 Mdot
.25459 .3276 Mdot
.57881 .63728 Mdot
.5523 .56454 Mdot
.51797 .32216 Mdot
.4821 .33626 Mdot
.44586 .31732 Mdot
.44799 .19913 Mdot
.33271 .73483 Mdot
.69272 .29633 Mdot
.76597 .63997 Mdot
.61666 .47366 Mdot
.68463 .41992 Mdot
.43689 .36887 Mdot
.49576 .3531 Mdot
.52486 .576 Mdot
.69379 .45087 Mdot
.39636 .29888 Mdot
.65519 .39312 Mdot
.41211 .71206 Mdot
.2585 .50588 Mdot
.54271 .65395 Mdot
.68606 .43201 Mdot
.64843 .47088 Mdot
.69617 .45531 Mdot
.43131 .37666 Mdot
.54711 .60358 Mdot
.57506 .59667 Mdot
.54337 .55914 Mdot
.46155 .62518 Mdot
.51048 .60634 Mdot
.56379 .3494 Mdot
.52104 .45617 Mdot
.62745 .76208 Mdot
.5128 .56005 Mdot
.48528 .30568 Mdot
.50475 .64077 Mdot
.3341 .61982 Mdot
.5524 .63209 Mdot
.41311 .70686 Mdot
.50543 .32826 Mdot
.57521 .50558 Mdot
.68523 .28906 Mdot
.57858 .63417 Mdot
.33975 .62036 Mdot
.45549 .67445 Mdot
.75088 .39319 Mdot
.37139 .59023 Mdot
.67487 .45534 Mdot
.38063 .44843 Mdot
.53705 .31111 Mdot
.35019 .46542 Mdot
.52738 .55197 Mdot
.434 .38048 Mdot
.61261 .35975 Mdot
.47091 .39929 Mdot
.51267 .58378 Mdot
.60579 .62218 Mdot
.67703 .44736 Mdot
.34815 .47709 Mdot
.60819 .46974 Mdot
.52197 .58745 Mdot
.31369 .62692 Mdot
.30594 .6113 Mdot
.52921 .239 Mdot
.79589 .61314 Mdot
.64102 .24751 Mdot
.51967 .32109 Mdot
.33164 .45979 Mdot
.29777 .59655 Mdot
.45294 .60141 Mdot
.47172 .31807 Mdot
.51191 .2924 Mdot
.5001 .3081 Mdot
.51707 .64117 Mdot
.37312 .46569 Mdot
.62612 .75356 Mdot
.36513 .4746 Mdot
.57607 .63444 Mdot
.33921 .44634 Mdot
.39352 .44401 Mdot
.31077 .60524 Mdot
.53471 .32311 Mdot
.37075 .42785 Mdot
.51112 .6224 Mdot
.63412 .44169 Mdot
.41071 .55844 Mdot
.38948 .65136 Mdot
.59554 .80518 Mdot
.61328 .79767 Mdot
.65442 .41277 Mdot
.77998 .66464 Mdot
.50208 .27921 Mdot
.72 .50779 Mdot
.36347 .39048 Mdot
.49618 .59279 Mdot
.31069 .24769 Mdot
.3954 .4139 Mdot
.34826 .478 Mdot
.5291 .63052 Mdot
.31124 .49722 Mdot
.54537 .58467 Mdot
.35442 .43367 Mdot
.36459 .5949 Mdot
.496 .66031 Mdot
.32917 .4859 Mdot
.57892 .55504 Mdot
.57372 .61753 Mdot
.67165 .4258 Mdot
.35646 .42753 Mdot
.54145 .55169 Mdot
.50284 .85918 Mdot
.48883 .34515 Mdot
.43102 .38013 Mdot
.28007 .68269 Mdot
.52571 .31036 Mdot
.64471 .45966 Mdot
.48502 .58422 Mdot
.32795 .6133 Mdot
.64845 .43248 Mdot
.35266 .64288 Mdot
.29328 .60889 Mdot
.30218 .26603 Mdot
.67947 .45001 Mdot
.41877 .40259 Mdot
.31385 .60235 Mdot
.59149 .64686 Mdot
.34312 .43323 Mdot
.4118 .58479 Mdot
.3822 .453 Mdot
.53808 .60353 Mdot
.42619 .34401 Mdot
.49345 .34961 Mdot
.56539 .58285 Mdot
.3117 .46464 Mdot
.42833 .37237 Mdot
.523 .64444 Mdot
.54508 .63038 Mdot
.52168 .20112 Mdot
.24877 .3672 Mdot
.32408 .63347 Mdot
.62625 .46849 Mdot
.51668 .62258 Mdot
.31644 .59978 Mdot
.25126 .56979 Mdot
.50565 .63708 Mdot
.66034 .48031 Mdot
.53251 .70072 Mdot
.32254 .45471 Mdot
.53116 .32987 Mdot
.37958 .40935 Mdot
.32827 .60163 Mdot
.14858 .4212 Mdot
.40206 .43386 Mdot
.57528 .55583 Mdot
.52383 .56608 Mdot
.41462 .30842 Mdot
.65493 .47128 Mdot
.33698 .73464 Mdot
.52523 .60045 Mdot
.482 .68352 Mdot
.55356 .57491 Mdot
.27446 .46281 Mdot
.67253 .437 Mdot
.53986 .59627 Mdot
.55072 .49068 Mdot
.59508 .61176 Mdot
.33725 .61076 Mdot
.52991 .78239 Mdot
.49671 .62354 Mdot
.84928 .35699 Mdot
.33227 .50601 Mdot
.3271 .48609 Mdot
.42731 .32215 Mdot
.28499 .75058 Mdot
.62658 .23445 Mdot
.67261 .46644 Mdot
.67342 .3707 Mdot
.3454 .46832 Mdot
.67756 .26614 Mdot
.76637 .69092 Mdot
.57322 .62107 Mdot
.52768 .65346 Mdot
.39223 .40681 Mdot
.34044 .49526 Mdot
.42666 .39736 Mdot
.52174 .55215 Mdot
.59698 .64557 Mdot
.31929 .48218 Mdot
.50618 .61604 Mdot
.51738 .69133 Mdot
.54277 .32949 Mdot
.6456 .4185 Mdot
.50905 .3412 Mdot
.53442 .31292 Mdot
.69999 .5648 Mdot
.44677 .20515 Mdot
.49814 .34895 Mdot
.49824 .28146 Mdot
.39989 .69934 Mdot
.60848 .65905 Mdot
.32185 .59465 Mdot
.71545 .73231 Mdot
.36593 .44407 Mdot
.54924 .60258 Mdot
.66702 .40868 Mdot
.69823 .54074 Mdot
.39052 .49198 Mdot
.19461 .42523 Mdot
.52185 .58334 Mdot
.34959 .45692 Mdot
.42226 .37958 Mdot
.51026 .67696 Mdot
.30185 .38051 Mdot
.55758 .56492 Mdot
.36741 .41866 Mdot
.71124 .66154 Mdot
.5796 .48433 Mdot
.28279 .36295 Mdot
.60504 .43333 Mdot
.53836 .56978 Mdot
.6697 .46157 Mdot
.51575 .33711 Mdot
.33038 .60924 Mdot
.3242 .6321 Mdot
.55484 .61932 Mdot
.51426 .71695 Mdot
.41838 .45432 Mdot
.57521 .61854 Mdot
.56145 .62989 Mdot
.42621 .37874 Mdot
.56306 .62776 Mdot
.52611 .56482 Mdot
.53698 .55874 Mdot
.58965 .6023 Mdot
.47761 .3151 Mdot
.57315 .47861 Mdot
.54615 .54355 Mdot
.50683 .68153 Mdot
.54644 .32029 Mdot
.69338 .36813 Mdot
.53685 .3255 Mdot
.82156 .56835 Mdot
.49729 .33772 Mdot
.31391 .64033 Mdot
.41819 .35164 Mdot
.54425 .71107 Mdot
.69867 .43249 Mdot
.47587 .34052 Mdot
.30289 .62924 Mdot
.52386 .32574 Mdot
.33279 .45136 Mdot
.7283 .27283 Mdot
.6588 .39325 Mdot
.32285 .71496 Mdot
.51605 .24278 Mdot
.30136 .32608 Mdot
.3906 .42278 Mdot
.67444 .43331 Mdot
.77106 .58955 Mdot
.54488 .55436 Mdot
.30975 .60249 Mdot
.54703 .61923 Mdot
.47639 .3162 Mdot
.35551 .45299 Mdot
.50974 .7939 Mdot
.32923 .62245 Mdot
.54369 .18852 Mdot
.35854 .44519 Mdot
.56554 .56406 Mdot
.48379 .29594 Mdot
.59664 .1775 Mdot
.51081 .34321 Mdot
.38904 .60208 Mdot
.66727 .48413 Mdot
.61693 .68092 Mdot
.65034 .44649 Mdot
.41775 .41966 Mdot
.80128 .33811 Mdot
.67688 .77249 Mdot
.63948 .43089 Mdot
.25559 .40956 Mdot
.52718 .65176 Mdot
.50948 .64504 Mdot
.58262 .49762 Mdot
.64772 .47907 Mdot
.51287 .61442 Mdot
.42015 .38444 Mdot
.58768 .29195 Mdot
.2469 .44281 Mdot
.37648 .45318 Mdot
.53987 .58699 Mdot
.54597 .32696 Mdot
.527 .29324 Mdot
.37517 .46499 Mdot
.53604 .33084 Mdot
.57406 .59459 Mdot
.64984 .4427 Mdot
.45239 .39606 Mdot
.32273 .6218 Mdot
.51117 .83781 Mdot
.3073 .59128 Mdot
.39283 .43873 Mdot
.56523 .67003 Mdot
.34056 .47396 Mdot
.14181 .60993 Mdot
.56997 .58126 Mdot
.63508 .45949 Mdot
.53295 .63839 Mdot
.54412 .56882 Mdot
.51771 .65265 Mdot
.31857 .47623 Mdot
.27188 .70086 Mdot
.50713 .61817 Mdot
.50683 .31107 Mdot
.64547 .76959 Mdot
.50554 .64366 Mdot
.36095 .58635 Mdot
.46154 .74482 Mdot
.30656 .30898 Mdot
.69934 .42492 Mdot
.34283 .4802 Mdot
.63809 .45195 Mdot
.62334 .41191 Mdot
.6449 .46001 Mdot
.66092 .74379 Mdot
.75793 .60898 Mdot
.22092 .65813 Mdot
.61828 .70528 Mdot
.67532 .53509 Mdot
.63164 .47556 Mdot
.2377 .59615 Mdot
.69309 .43046 Mdot
.65953 .46852 Mdot
.73006 .80662 Mdot
.68973 .42113 Mdot
.53288 .58942 Mdot
.5076 .65827 Mdot
.64203 .32556 Mdot
.38033 .70324 Mdot
.56228 .62176 Mdot
.52157 .6279 Mdot
.32529 .60496 Mdot
.49578 .70908 Mdot
.43525 .37996 Mdot
.31006 .26206 Mdot
.69727 .32917 Mdot
.54844 .61999 Mdot
.5155 .62379 Mdot
.59797 .63461 Mdot
.73005 .22982 Mdot
.72013 .54642 Mdot
.62625 .47398 Mdot
.58937 .53976 Mdot
.58075 .8245 Mdot
.57869 .59906 Mdot
.50384 .62929 Mdot
.54133 .65243 Mdot
.34623 .46717 Mdot
.63735 .48315 Mdot
.59199 .54363 Mdot
.31306 .28443 Mdot
.57302 .64491 Mdot
.5174 .38742 Mdot
.31037 .74609 Mdot
.53566 .59307 Mdot
.69962 .45676 Mdot
.54434 .64367 Mdot
.68165 .44949 Mdot
.66826 .42123 Mdot
.5869 .64684 Mdot
.72261 .70007 Mdot
.6686 .48115 Mdot
.5742 .63912 Mdot
.33075 .47726 Mdot
.70262 .76195 Mdot
.53581 .60356 Mdot
.31741 .64388 Mdot
.52372 .59978 Mdot
.33643 .63114 Mdot
.56636 .63143 Mdot
.36448 .47485 Mdot
.75805 .47827 Mdot
.36347 .45159 Mdot
.35696 .77028 Mdot
.32326 .5024 Mdot
.51923 .20047 Mdot
.65703 .47895 Mdot
.42756 .36981 Mdot
.17303 .42702 Mdot
.42756 .38231 Mdot
.5463 .46978 Mdot
.48881 .49119 Mdot
.50126 .29794 Mdot
.62536 .4463 Mdot
.44701 .77527 Mdot
.40486 .30375 Mdot
.40525 .34784 Mdot
.39787 .42874 Mdot
.17478 .38289 Mdot
.20905 .36063 Mdot
.5106 .62731 Mdot
.69628 .70709 Mdot
.65706 .65196 Mdot
.50495 .63461 Mdot
.49486 .56504 Mdot
.31196 .46058 Mdot
.51962 .57022 Mdot
.56506 .41832 Mdot
.38424 .43216 Mdot
.29901 .62704 Mdot
.66077 .46538 Mdot
.32419 .64412 Mdot
.40564 .31782 Mdot
.49042 .4937 Mdot
.35771 .43393 Mdot
.59261 .6006 Mdot
.52813 .6367 Mdot
.68087 .43132 Mdot
.624 .49236 Mdot
.6565 .41732 Mdot
.28489 .62657 Mdot
.37995 .43415 Mdot
.72222 .53353 Mdot
.5257 .62325 Mdot
.65561 .43864 Mdot
.51299 .25209 Mdot
.51997 .62154 Mdot
.52718 .32662 Mdot
.54609 .65571 Mdot
.63594 .43332 Mdot
.56338 .62768 Mdot
.64803 .44298 Mdot
.37504 .44918 Mdot
.58061 .60285 Mdot
.53247 .62891 Mdot
.59247 .18052 Mdot
.314 .63703 Mdot
.65448 .47847 Mdot
.45878 .4519 Mdot
.55679 .55541 Mdot
.35672 .32071 Mdot
.532 .57379 Mdot
.67977 .38522 Mdot
.58211 .5637 Mdot
.42754 .37598 Mdot
.48301 .6387 Mdot
.5366 .60258 Mdot
.49681 .50413 Mdot
.65602 .69035 Mdot
.6148 .48379 Mdot
.48474 .29787 Mdot
.6947 .46453 Mdot
.31034 .52317 Mdot
.40905 .40809 Mdot
.30668 .48824 Mdot
.35884 .71546 Mdot
.58148 .65061 Mdot
.55086 .58959 Mdot
.52179 .35928 Mdot
.29457 .62779 Mdot
.66083 .43429 Mdot
.29645 .62191 Mdot
.35429 .23665 Mdot
.28697 .6201 Mdot
.36737 .47337 Mdot
.26461 .47507 Mdot
.74736 .52156 Mdot
.32409 .60437 Mdot
.6518 .4174 Mdot
.25375 .50754 Mdot
.50263 .58069 Mdot
.29311 .66843 Mdot
.3141 .62525 Mdot
.17292 .37169 Mdot
.51718 .5762 Mdot
.55168 .46136 Mdot
.51444 .34748 Mdot
.30226 .60947 Mdot
.49635 .31619 Mdot
.5592 .62181 Mdot
.34145 .30087 Mdot
.66832 .47074 Mdot
.54081 .29881 Mdot
.51817 .54658 Mdot
.28832 .6306 Mdot
.35863 .43711 Mdot
.52189 .37261 Mdot
.48715 .30333 Mdot
.77685 .42762 Mdot
.51068 .78646 Mdot
.38088 .43443 Mdot
.2192 .43207 Mdot
.48996 .3137 Mdot
.50126 .62792 Mdot
.49808 .6946 Mdot
.57032 .57817 Mdot
.42932 .33551 Mdot
.34195 .48126 Mdot
.60248 .32138 Mdot
.52777 .63863 Mdot
.52408 .57301 Mdot
.7031 .46848 Mdot
.379 .44223 Mdot
.66397 .45237 Mdot
.69878 .44948 Mdot
.37688 .44781 Mdot
.65133 .4528 Mdot
.30058 .60419 Mdot
.59446 .28022 Mdot
.48849 .3152 Mdot
.50722 .31526 Mdot
.35369 .45118 Mdot
.32139 .48605 Mdot
.34256 .47437 Mdot
.54721 .65559 Mdot
.66672 .43467 Mdot
.557 .64642 Mdot
.52129 .65305 Mdot
.59815 .46383 Mdot
.68171 .41226 Mdot
.54075 .64848 Mdot
.29538 .35452 Mdot
.32629 .66029 Mdot
.32552 .47823 Mdot
.50532 .34902 Mdot
.72385 .31478 Mdot
.55054 .33712 Mdot
.54044 .58412 Mdot
.43852 .22747 Mdot
.64428 .42588 Mdot
.31817 .60622 Mdot
.34171 .63726 Mdot
.32588 .61388 Mdot
.49134 .3615 Mdot
.68602 .46389 Mdot
.30855 .26404 Mdot
.54314 .58646 Mdot
.54845 .42561 Mdot
.45999 .77968 Mdot
.35967 .24163 Mdot
.50063 .34955 Mdot
.51893 .62364 Mdot
.42607 .38959 Mdot
.77352 .55824 Mdot
.55596 .56579 Mdot
.53093 .55521 Mdot
.336 .39681 Mdot
.5332 .69679 Mdot
.6668 .4833 Mdot
.44596 .19464 Mdot
.50743 .65547 Mdot
.59869 .49001 Mdot
.38895 .83762 Mdot
.54071 .57736 Mdot
.51774 .59164 Mdot
.53433 .61362 Mdot
.54103 .63847 Mdot
.69742 .4639 Mdot
.40074 .7505 Mdot
.48028 .29997 Mdot
.52762 .4337 Mdot
.48762 .31242 Mdot
.37207 .4166 Mdot
.56787 .45363 Mdot
.62662 .43352 Mdot
.31773 .60492 Mdot
.78797 .47161 Mdot
.39715 .20173 Mdot
.389 .41846 Mdot
.7437 .57192 Mdot
.31882 .62725 Mdot
.49022 .60728 Mdot
.32513 .64611 Mdot
.3504 .48694 Mdot
.5043 .30405 Mdot
.50621 .66286 Mdot
.67409 .41566 Mdot
.63115 .43463 Mdot
.51509 .61561 Mdot
.605 .82285 Mdot
.52873 .32718 Mdot
.54602 .28965 Mdot
.52181 .64634 Mdot
.53055 .55477 Mdot
.66217 .45618 Mdot
.33283 .46766 Mdot
.19809 .53856 Mdot
.30474 .63586 Mdot
.57496 .5709 Mdot
.54534 .6371 Mdot
.44232 .20265 Mdot
.52974 .30977 Mdot
.40928 .42025 Mdot
.51743 .64019 Mdot
.51896 .23393 Mdot
.51905 .64133 Mdot
.50361 .67226 Mdot
.33538 .47406 Mdot
.58934 .56085 Mdot
.50251 .61586 Mdot
.57263 .52401 Mdot
.49219 .31448 Mdot
.64014 .46403 Mdot
.70252 .46403 Mdot
.42907 .3911 Mdot
.52611 .3281 Mdot
.54143 .64675 Mdot
.52975 .3127 Mdot
.50287 .63598 Mdot
.50809 .61288 Mdot
.49789 .34834 Mdot
.66332 .45256 Mdot
.64234 .3616 Mdot
.57128 .47342 Mdot
.53656 .63989 Mdot
.49075 .64853 Mdot
.37082 .71483 Mdot
.1591 .54131 Mdot
.52447 .58179 Mdot
.63358 .43458 Mdot
.52655 .62638 Mdot
.49898 .32491 Mdot
.28885 .61887 Mdot
.63432 .4387 Mdot
.33848 .4577 Mdot
.39489 .41941 Mdot
.68221 .28557 Mdot
.3827 .45576 Mdot
.49544 .5871 Mdot
.711 .40386 Mdot
.66269 .40489 Mdot
.44348 .84537 Mdot
.37985 .44569 Mdot
.33312 .60176 Mdot
.54931 .62744 Mdot
.464 .22952 Mdot
.51187 .36084 Mdot
.84548 .34367 Mdot
.30373 .2666 Mdot
.30645 .59033 Mdot
.18704 .42723 Mdot
.42062 .39662 Mdot
.50267 .60138 Mdot
.33194 .61158 Mdot
.3806 .4193 Mdot
.49395 .60361 Mdot
.48084 .56584 Mdot
.32022 .72293 Mdot
.34529 .42722 Mdot
.53214 .31952 Mdot
.31047 .47364 Mdot
.30567 .65625 Mdot
.36676 .47377 Mdot
.63255 .42871 Mdot
.54052 .60006 Mdot
.60672 .59341 Mdot
.33323 .46394 Mdot
.36037 .47998 Mdot
.54729 .65366 Mdot
.62727 .45304 Mdot
.30817 .4948 Mdot
.55497 .61546 Mdot
.70637 .51675 Mdot
.6045 .43722 Mdot
.37336 .43486 Mdot
.52973 .56504 Mdot
.59748 .6772 Mdot
.34823 .45254 Mdot
.3238 .4777 Mdot
.51289 .61536 Mdot
.30492 .60208 Mdot
.57632 .64457 Mdot
.49764 .34034 Mdot
.2782 .71148 Mdot
.50005 .32248 Mdot
.30685 .53078 Mdot
.55923 .68058 Mdot
.32836 .31781 Mdot
.63922 .41918 Mdot
.31044 .65649 Mdot
.73013 .31234 Mdot
.52236 .55679 Mdot
.77569 .66224 Mdot
.48567 .39944 Mdot
.56573 .84074 Mdot
.80493 .3883 Mdot
.31164 .62264 Mdot
.52163 .33083 Mdot
.51795 .59237 Mdot
.52535 .35338 Mdot
.33115 .6244 Mdot
.47014 .7911 Mdot
.52986 .56361 Mdot
.67398 .43898 Mdot
.56835 .64744 Mdot
.67518 .45549 Mdot
.5195 .61895 Mdot
.52758 .69441 Mdot
.40699 .37929 Mdot
.3784 .62861 Mdot
.49773 .58917 Mdot
.72323 .26539 Mdot
.40996 .48031 Mdot
.31098 .63104 Mdot
.56649 .64334 Mdot
.40926 .4128 Mdot
.52032 .2905 Mdot
.43949 .61269 Mdot
.34271 .47073 Mdot
.524 .34979 Mdot
.65364 .45923 Mdot
.37621 .45089 Mdot
.40322 .42211 Mdot
.56882 .53207 Mdot
.33719 .62625 Mdot
.50742 .29807 Mdot
.53562 .59908 Mdot
.51871 .57566 Mdot
.22805 .44787 Mdot
.37147 .51084 Mdot
.68876 .48377 Mdot
.54685 .17047 Mdot
.70825 .43318 Mdot
.30469 .63959 Mdot
.33648 .47501 Mdot
.527 .5806 Mdot
.56722 .5875 Mdot
.42507 .367 Mdot
.6526 .47737 Mdot
.36463 .41735 Mdot
.71669 .56794 Mdot
.34607 .4845 Mdot
.42164 .73929 Mdot
.63144 .45489 Mdot
.4174 .73843 Mdot
.30812 .65561 Mdot
.78101 .63224 Mdot
.41023 .66724 Mdot
.51745 .34727 Mdot
.42624 .74204 Mdot
.65529 .42671 Mdot
.5167 .63226 Mdot
.41747 .40201 Mdot
.3961 .43974 Mdot
.66054 .4619 Mdot
.38897 .40881 Mdot
.30402 .60966 Mdot
.51453 .59381 Mdot
.27633 .32143 Mdot
.6459 .29418 Mdot
.32812 .46387 Mdot
.48706 .66031 Mdot
.49975 .31209 Mdot
.50454 .60349 Mdot
.31342 .64581 Mdot
.51503 .30407 Mdot
.34436 .50199 Mdot
.59418 .30186 Mdot
.55761 .61924 Mdot
.4799 .20931 Mdot
.52597 .31777 Mdot
.18648 .47656 Mdot
.55183 .61201 Mdot
.49015 .31366 Mdot
.56245 .69095 Mdot
.35232 .25535 Mdot
.47164 .42246 Mdot
.75854 .7043 Mdot
.34959 .42334 Mdot
.39439 .40819 Mdot
.37846 .27009 Mdot
.38866 .35051 Mdot
.53337 .34607 Mdot
.36639 .47393 Mdot
.47957 .72893 Mdot
.49577 .3144 Mdot
.52642 .65387 Mdot
.53506 .5751 Mdot
.699 .55789 Mdot
.49893 .4172 Mdot
.35937 .48199 Mdot
.61129 .23761 Mdot
.55553 .55562 Mdot
.53555 .53478 Mdot
.56467 .59044 Mdot
.61715 .45472 Mdot
.51697 .29912 Mdot
.63392 .20048 Mdot
.52428 .33414 Mdot
.24721 .34559 Mdot
.36497 .44511 Mdot
.32264 .49089 Mdot
.53679 .5896 Mdot
.30134 .33454 Mdot
.53102 .74144 Mdot
.57578 .60169 Mdot
.32152 .34242 Mdot
.52424 .78965 Mdot
.51979 .54437 Mdot
.66684 .48497 Mdot
.5223 .66719 Mdot
.61873 .42949 Mdot
.48943 .30485 Mdot
.31236 .61599 Mdot
.28604 .65722 Mdot
.50742 .2992 Mdot
.55229 .59016 Mdot
.33033 .34386 Mdot
.55294 .56955 Mdot
.51291 .63278 Mdot
.24874 .32942 Mdot
.29864 .59522 Mdot
.3479 .47284 Mdot
.32676 .62861 Mdot
.65995 .46903 Mdot
.90759 .57684 Mdot
.29332 .62449 Mdot
.5603 .72622 Mdot
.39523 .77901 Mdot
.42301 .74248 Mdot
.62927 .43737 Mdot
.28229 .64101 Mdot
.5302 .3301 Mdot
.61012 .84186 Mdot
.16398 .56365 Mdot
.5542 .31797 Mdot
.55853 .60829 Mdot
.62458 .43354 Mdot
.6575 .41353 Mdot
.53372 .28943 Mdot
.6641 .42225 Mdot
.60281 .63594 Mdot
.52479 .64025 Mdot
.53048 .34777 Mdot
.64648 .31359 Mdot
.48789 .30169 Mdot
.58051 .26803 Mdot
.5658 .64603 Mdot
.63117 .44934 Mdot
.5403 .66869 Mdot
.68707 .3991 Mdot
.41048 .42163 Mdot
.49147 .61378 Mdot
.3088 .60664 Mdot
.53806 .41513 Mdot
.37292 .4371 Mdot
.43666 .23075 Mdot
.68159 .43372 Mdot
.46169 .30182 Mdot
.67047 .42456 Mdot
.62122 .44733 Mdot
.53465 .31243 Mdot
.68659 .45776 Mdot
.51694 .59145 Mdot
.27085 .38552 Mdot
.6852 .44689 Mdot
.51294 .32646 Mdot
.31796 .61305 Mdot
.65524 .45249 Mdot
.31369 .45708 Mdot
.53956 .63078 Mdot
.34534 .4383 Mdot
.40216 .3765 Mdot
.62585 .45483 Mdot
.28101 .6349 Mdot
.33769 .485 Mdot
.33645 .62263 Mdot
.50311 .80777 Mdot
.49265 .35225 Mdot
.19846 .42557 Mdot
.60361 .6624 Mdot
.67319 .41412 Mdot
.40297 .37892 Mdot
.52798 .58272 Mdot
.54101 .63142 Mdot
.29324 .65372 Mdot
.65856 .41319 Mdot
.6732 .77997 Mdot
.69503 .38362 Mdot
.59839 .29136 Mdot
.48279 .34715 Mdot
.57379 .19342 Mdot
.5805 .31705 Mdot
.38811 .80276 Mdot
.56724 .53826 Mdot
.42016 .397 Mdot
.55011 .58087 Mdot
.73892 .32455 Mdot
.28668 .62898 Mdot
.20601 .57914 Mdot
.59108 .64002 Mdot
.35789 .46371 Mdot
.54043 .61718 Mdot
.43895 .55621 Mdot
.52713 .67277 Mdot
.30416 .60044 Mdot
.54109 .38389 Mdot
.69885 .4355 Mdot
.32186 .62393 Mdot
.39222 .4248 Mdot
.49117 .7533 Mdot
.49637 .5973 Mdot
.52981 .54888 Mdot
.34432 .48695 Mdot
.67335 .43431 Mdot
.36394 .42211 Mdot
.48866 .3147 Mdot
.30335 .61674 Mdot
.54789 .63124 Mdot
.59015 .58368 Mdot
.35807 .32242 Mdot
.51246 .29593 Mdot
.33793 .48807 Mdot
.51342 .34176 Mdot
.41947 .39873 Mdot
.49614 .65632 Mdot
.31994 .49131 Mdot
.50436 .59131 Mdot
.67197 .24649 Mdot
.24414 .33856 Mdot
.66518 .69025 Mdot
.35707 .46659 Mdot
.43478 .73074 Mdot
.50442 .32993 Mdot
.50051 .33919 Mdot
.62263 .65877 Mdot
.47056 .69604 Mdot
.26756 .49823 Mdot
.78137 .42919 Mdot
.48787 .31548 Mdot
.50305 .32065 Mdot
.36274 .42695 Mdot
.68444 .45788 Mdot
.62464 .42475 Mdot
.40096 .40421 Mdot
.34062 .6753 Mdot
.66072 .4344 Mdot
.76006 .6808 Mdot
.30749 .51815 Mdot
.55135 .53019 Mdot
.43876 .33103 Mdot
.30793 .61203 Mdot
.35535 .66258 Mdot
.44512 .54827 Mdot
.52178 .57829 Mdot
.45531 .19333 Mdot
.33774 .46583 Mdot
.37408 .74427 Mdot
.82207 .56251 Mdot
.53099 .56181 Mdot
.54979 .60517 Mdot
.55695 .58747 Mdot
.28677 .60443 Mdot
.74471 .43219 Mdot
.51755 .57983 Mdot
.3312 .67961 Mdot
.56105 .55712 Mdot
.40241 .62866 Mdot
.32482 .63168 Mdot
.61623 .52063 Mdot
.37513 .40393 Mdot
.31598 .27232 Mdot
.59141 .51159 Mdot
.49014 .32312 Mdot
.40809 .39526 Mdot
.49215 .30533 Mdot
.65671 .74118 Mdot
.41092 .67193 Mdot
.66507 .48861 Mdot
.51989 .58353 Mdot
.39335 .43645 Mdot
.65131 .4162 Mdot
.37692 .30665 Mdot
.78609 .75901 Mdot
.50134 .29169 Mdot
.15304 .61682 Mdot
.50503 .34172 Mdot
.40545 .428 Mdot
.6611 .45771 Mdot
.74932 .61867 Mdot
.55023 .42524 Mdot
.6529 .45118 Mdot
.62224 .35986 Mdot
.70358 .4171 Mdot
.43528 .73786 Mdot
.67877 .40624 Mdot
.51051 .32897 Mdot
.51554 .3672 Mdot
.53703 .53142 Mdot
.5292 .59013 Mdot
.48454 .49733 Mdot
.57661 .70903 Mdot
.52786 .58705 Mdot
.38403 .43266 Mdot
.18018 .47469 Mdot
.40547 .40102 Mdot
.69076 .43244 Mdot
.49192 .29137 Mdot
.54785 .60776 Mdot
.52987 .64338 Mdot
.49631 .6088 Mdot
.5695 .16527 Mdot
.74529 .69482 Mdot
.50808 .61887 Mdot
.58196 .58813 Mdot
.37178 .45253 Mdot
.32323 .57875 Mdot
.76313 .34972 Mdot
.45341 .6998 Mdot
.55929 .56353 Mdot
.32086 .63298 Mdot
.3174 .59178 Mdot
.49363 .60112 Mdot
.29473 .3137 Mdot
.26519 .39004 Mdot
.53545 .59961 Mdot
.41532 .64454 Mdot
.40078 .32271 Mdot
.3735 .46719 Mdot
.33664 .46137 Mdot
.70002 .454 Mdot
.39636 .43489 Mdot
.31909 .50338 Mdot
.75748 .59341 Mdot
.43203 .38443 Mdot
.56896 .30998 Mdot
.28487 .62678 Mdot
.56499 .58108 Mdot
.70994 .43188 Mdot
.43028 .35225 Mdot
.50245 .29839 Mdot
.64031 .43963 Mdot
.51817 .28863 Mdot
.31685 .58568 Mdot
.33976 .72375 Mdot
.39702 .43962 Mdot
.48696 .32395 Mdot
.59321 .30029 Mdot
.32197 .63276 Mdot
.53342 .33368 Mdot
.33583 .31915 Mdot
.51076 .65022 Mdot
.76836 .62633 Mdot
.57772 .61786 Mdot
.60453 .83131 Mdot
.53346 .33144 Mdot
.43315 .37412 Mdot
.54737 .59238 Mdot
.35764 .44611 Mdot
.55721 .68754 Mdot
.55924 .56546 Mdot
.34072 .45277 Mdot
.51154 .62796 Mdot
.32266 .64199 Mdot
.61368 .42714 Mdot
.49046 .39263 Mdot
.31187 .21257 Mdot
.33437 .63111 Mdot
.37056 .3082 Mdot
.5235 .58216 Mdot
.51073 .79193 Mdot
.65572 .45095 Mdot
.52837 .55903 Mdot
.62994 .57711 Mdot
.67838 .45992 Mdot
.63931 .44889 Mdot
.55738 .6372 Mdot
.51907 .34529 Mdot
.36318 .44091 Mdot
.32524 .62863 Mdot
.4426 .83224 Mdot
.56531 .60543 Mdot
.52974 .628 Mdot
.32 .62592 Mdot
.50123 .32131 Mdot
.53385 .64365 Mdot
.46136 .2609 Mdot
.51918 .85461 Mdot
.51751 .29364 Mdot
.53128 .66029 Mdot
.79459 .52563 Mdot
.6994 .40251 Mdot
.15224 .58393 Mdot
.35649 .62183 Mdot
.33852 .48187 Mdot
.53633 .69757 Mdot
.88504 .44216 Mdot
.31282 .61438 Mdot
.31153 .26871 Mdot
.50863 .62994 Mdot
.52826 .61948 Mdot
.65001 .42174 Mdot
.54982 .64765 Mdot
.65424 .47456 Mdot
.26161 .2601 Mdot
.48543 .1741 Mdot
.67959 .43931 Mdot
.68326 .41798 Mdot
.61017 .67109 Mdot
.7585 .34488 Mdot
.65548 .46397 Mdot
.55097 .66068 Mdot
.68133 .75658 Mdot
.54846 .52524 Mdot
.29229 .6539 Mdot
.39316 .3747 Mdot
.62108 .5073 Mdot
.36993 .54707 Mdot
.70332 .37555 Mdot
.58499 .50624 Mdot
.41664 .44199 Mdot
.49528 .3411 Mdot
.54419 .55695 Mdot
.38882 .44907 Mdot
.30958 .48973 Mdot
.52996 .67762 Mdot
.5607 .57224 Mdot
.67956 .45295 Mdot
.29112 .60288 Mdot
.53608 .30588 Mdot
.52225 .62841 Mdot
.31535 .45255 Mdot
.29941 .63142 Mdot
.68931 .43487 Mdot
.61287 .68183 Mdot
.32013 .59593 Mdot
.49229 .66005 Mdot
.52349 .60438 Mdot
.54262 .6538 Mdot
.60084 .66048 Mdot
.48062 .3356 Mdot
.42221 .32329 Mdot
.56128 .65525 Mdot
.36037 .23234 Mdot
.39023 .58453 Mdot
.59231 .57263 Mdot
.6621 .42859 Mdot
.50042 .36147 Mdot
.41384 .41582 Mdot
.48989 .76651 Mdot
.56223 .61365 Mdot
.73952 .69916 Mdot
.71714 .55371 Mdot
.40731 .41518 Mdot
.63489 .47691 Mdot
.32028 .60706 Mdot
.57344 .59398 Mdot
.66724 .751 Mdot
.53696 .57729 Mdot
.59227 .68105 Mdot
.32936 .4757 Mdot
.49437 .34184 Mdot
.55359 .84709 Mdot
.31007 .48977 Mdot
.63826 .451 Mdot
.77019 .69723 Mdot
.638 .41539 Mdot
.69709 .44496 Mdot
.70645 .71507 Mdot
.48041 .33151 Mdot
.87897 .42371 Mdot
.15997 .56611 Mdot
.59745 .61956 Mdot
.50119 .33142 Mdot
.67009 .45526 Mdot
.50511 .6027 Mdot
.67014 .40721 Mdot
.67638 .46929 Mdot
.4922 .62437 Mdot
.52403 .61199 Mdot
.56795 .47009 Mdot
.80072 .6192 Mdot
.32555 .6109 Mdot
.63627 .46555 Mdot
.66589 .54701 Mdot
.51092 .5864 Mdot
.54292 .58716 Mdot
.39377 .30703 Mdot
.3085 .59999 Mdot
.49991 .50717 Mdot
.51542 .63754 Mdot
.49307 .18722 Mdot
.49849 .66222 Mdot
.69218 .47244 Mdot
.51928 .29474 Mdot
.29725 .30403 Mdot
.43008 .33567 Mdot
.64893 .47742 Mdot
.29834 .64552 Mdot
.69823 .473 Mdot
.56499 .72267 Mdot
.48216 .31759 Mdot
.63597 .43327 Mdot
.38362 .40781 Mdot
.51478 .31027 Mdot
.53249 .33416 Mdot
.648 .76871 Mdot
.35556 .47403 Mdot
.2854 .63739 Mdot
.50159 .30476 Mdot
.72032 .50622 Mdot
.5166 .32963 Mdot
.67512 .5571 Mdot
.58125 .61208 Mdot
.32297 .69928 Mdot
.57813 .3443 Mdot
.57031 .69607 Mdot
.48326 .34254 Mdot
.33061 .62321 Mdot
.55106 .63756 Mdot
.66197 .42144 Mdot
.29452 .62197 Mdot
.47989 .37088 Mdot
.32197 .48212 Mdot
.6747 .42441 Mdot
.47906 .30089 Mdot
.63528 .46271 Mdot
.43204 .76992 Mdot
.29394 .72159 Mdot
.46806 .24942 Mdot
.54722 .43491 Mdot
.49714 .61229 Mdot
.73737 .37621 Mdot
.48684 .61446 Mdot
.5574 .56817 Mdot
.37263 .4354 Mdot
.3579 .7164 Mdot
.66387 .45294 Mdot
.55623 .84944 Mdot
.48761 .32977 Mdot
.45766 .18562 Mdot
.60343 .42373 Mdot
.53674 .55324 Mdot
.68347 .45089 Mdot
.64857 .40928 Mdot
.65192 .69436 Mdot
.30769 .50671 Mdot
.47929 .57389 Mdot
.48425 .61893 Mdot
.56302 .54011 Mdot
.53244 .33241 Mdot
.42118 .23946 Mdot
.38084 .41334 Mdot
.22992 .69016 Mdot
.32685 .47405 Mdot
.30806 .3986 Mdot
.6904 .45303 Mdot
.2919 .61594 Mdot
.54143 .58919 Mdot
.60977 .40975 Mdot
.6393 .47662 Mdot
.34828 .61828 Mdot
.30843 .60508 Mdot
.38308 .25159 Mdot
.49615 .34817 Mdot
.50159 .58475 Mdot
.52744 .56712 Mdot
.56168 .64355 Mdot
.57885 .62572 Mdot
.50215 .29093 Mdot
.51818 .64856 Mdot
.54528 .33433 Mdot
.71669 .51596 Mdot
.47375 .18138 Mdot
.41391 .3935 Mdot
.44514 .6462 Mdot
.67781 .4197 Mdot
.72247 .49571 Mdot
.47331 .64006 Mdot
.22832 .35816 Mdot
.55886 .80338 Mdot
.49866 .56574 Mdot
.37534 .41995 Mdot
.47546 .69404 Mdot
.35867 .47816 Mdot
.10449 .48476 Mdot
.35831 .33522 Mdot
.76726 .68572 Mdot
.51012 .59294 Mdot
.39609 .30724 Mdot
.48431 .66632 Mdot
.49046 .62759 Mdot
.3781 .33632 Mdot
.58596 .22407 Mdot
.63095 .33695 Mdot
.31868 .59305 Mdot
.54526 .62544 Mdot
.67218 .40345 Mdot
.51602 .5906 Mdot
.5452 .58265 Mdot
.50514 .62708 Mdot
.4861 .29124 Mdot
.50896 .66321 Mdot
.54449 .65676 Mdot
.38782 .51718 Mdot
.40334 .70791 Mdot
.31309 .46834 Mdot
.5967 .71506 Mdot
.29512 .62647 Mdot
.6843 .44229 Mdot
.59159 .40151 Mdot
.51642 .34779 Mdot
.65239 .67553 Mdot
.55888 .65252 Mdot
.58529 .33405 Mdot
.47788 .30261 Mdot
.30165 .61542 Mdot
.42301 .40123 Mdot
.71758 .74942 Mdot
.39122 .44019 Mdot
.43147 .38634 Mdot
.37218 .43891 Mdot
.66376 .50806 Mdot
.67804 .45506 Mdot
.49628 .61556 Mdot
.50142 .30868 Mdot
.35983 .44025 Mdot
.3715 .70316 Mdot
.56318 .58857 Mdot
.37355 .44946 Mdot
.49814 .61884 Mdot
.3223 .71291 Mdot
.21763 .46428 Mdot
.32821 .50118 Mdot
.47885 .35621 Mdot
.51443 .31574 Mdot
.29678 .60663 Mdot
.68565 .43448 Mdot
.64903 .42443 Mdot
.51633 .30577 Mdot
.15027 .5135 Mdot
.55609 .56255 Mdot
.50682 .59712 Mdot
.36516 .22858 Mdot
.52155 .59356 Mdot
.47612 .74977 Mdot
.43313 .38726 Mdot
.68562 .42726 Mdot
.50402 .61024 Mdot
.53629 .64159 Mdot
.55358 .62337 Mdot
.42568 .77016 Mdot
.32962 .4679 Mdot
.56384 .564 Mdot
.32172 .60104 Mdot
.41908 .41939 Mdot
.50615 .59586 Mdot
.55978 .54034 Mdot
.64704 .42649 Mdot
.46329 .17106 Mdot
.50373 .34489 Mdot
.38775 .42436 Mdot
.33085 .48801 Mdot
.39472 .37107 Mdot
.60042 .48252 Mdot
.43211 .38803 Mdot
.26528 .71368 Mdot
.43028 .37789 Mdot
.31544 .63183 Mdot
.32486 .42315 Mdot
.35748 .56695 Mdot
.37787 .42307 Mdot
.52265 .28761 Mdot
.57532 .6435 Mdot
.56931 .57232 Mdot
.29602 .27466 Mdot
.54183 .5504 Mdot
.31557 .60822 Mdot
.54717 .32573 Mdot
.65419 .4287 Mdot
.30292 .61251 Mdot
.50569 .34014 Mdot
.67188 .43245 Mdot
.50543 .64634 Mdot
.51671 .65546 Mdot
.64106 .44261 Mdot
.65199 .41673 Mdot
.53169 .5995 Mdot
.40381 .4474 Mdot
.70011 .44803 Mdot
.63122 .44265 Mdot
.39293 .44546 Mdot
.39782 .42999 Mdot
.59101 .5454 Mdot
.50416 .33496 Mdot
.53386 .65273 Mdot
.38044 .45303 Mdot
.28909 .60881 Mdot
.66118 .44894 Mdot
.53279 .64119 Mdot
.52155 .6325 Mdot
.32396 .62871 Mdot
.30408 .59548 Mdot
.3005 .61185 Mdot
.54852 .332 Mdot
.5722 .63064 Mdot
.65218 .46248 Mdot
.48946 .34305 Mdot
.31818 .59181 Mdot
.33761 .63355 Mdot
.43094 .50968 Mdot
.52717 .5783 Mdot
.46318 .42719 Mdot
.90416 .56994 Mdot
.47762 .73599 Mdot
.41309 .41753 Mdot
.3522 .48006 Mdot
.39413 .72956 Mdot
.25764 .41584 Mdot
.52778 .31709 Mdot
.49913 .73462 Mdot
.30917 .65702 Mdot
.49663 .62298 Mdot
.49184 .65074 Mdot
.49261 .56695 Mdot
.30136 .62408 Mdot
.45254 .77055 Mdot
.64699 .41382 Mdot
.65068 .61085 Mdot
.29541 .62586 Mdot
.3267 .50234 Mdot
.32115 .49454 Mdot
.32676 .47467 Mdot
.50179 .65774 Mdot
.66462 .6798 Mdot
.69285 .5175 Mdot
.75763 .38962 Mdot
.51297 .35145 Mdot
.65777 .49047 Mdot
.50228 .80323 Mdot
.64096 .44731 Mdot
.3105 .49227 Mdot
.30169 .62836 Mdot
.63693 .42913 Mdot
.50176 .29508 Mdot
.50306 .31839 Mdot
.32676 .46917 Mdot
.35496 .451 Mdot
.34473 .43976 Mdot
.69239 .46041 Mdot
.68775 .45636 Mdot
.5666 .61026 Mdot
.65373 .4428 Mdot
.38574 .19451 Mdot
.29131 .59788 Mdot
.31864 .4954 Mdot
.5208 .33302 Mdot
.67733 .45278 Mdot
.56607 .59052 Mdot
.28977 .45324 Mdot
.67399 .28558 Mdot
.33398 .62806 Mdot
.22157 .44898 Mdot
.11057 .50738 Mdot
.50925 .57818 Mdot
.53231 .31779 Mdot
.26728 .3362 Mdot
.55873 .58997 Mdot
.34319 .4677 Mdot
.6975 .2673 Mdot
.40964 .40829 Mdot
.52659 .65327 Mdot
.53893 .55093 Mdot
.53705 .32872 Mdot
.39754 .78283 Mdot
.56923 .60739 Mdot
.55612 .2548 Mdot
.4977 .28728 Mdot
.33209 .44205 Mdot
.52412 .85856 Mdot
.41267 .31717 Mdot
.354 .66594 Mdot
.39992 .43336 Mdot
.54192 .56931 Mdot
.38361 .42882 Mdot
.33428 .62394 Mdot
.3687 .4317 Mdot
.65018 .48541 Mdot
.32424 .45281 Mdot
.53028 .62687 Mdot
.6539 .46519 Mdot
.52659 .31949 Mdot
.4384 .19341 Mdot
.37347 .52126 Mdot
.35682 .44687 Mdot
.40084 .43674 Mdot
.50125 .61191 Mdot
.53905 .49041 Mdot
.57756 .66995 Mdot
.51058 .58949 Mdot
.48731 .3094 Mdot
.68603 .44751 Mdot
.47562 .33128 Mdot
.5762 .56214 Mdot
.56668 .21099 Mdot
.51435 .34326 Mdot
.58202 .3614 Mdot
.31836 .62832 Mdot
.44169 .52684 Mdot
.56785 .58618 Mdot
.4987 .30634 Mdot
.57227 .63193 Mdot
.67626 .40846 Mdot
.48681 .44547 Mdot
.43805 .299 Mdot
.50262 .30957 Mdot
.65117 .79606 Mdot
.4531 .45707 Mdot
.54257 .66664 Mdot
.49039 .31076 Mdot
.63283 .56676 Mdot
.40471 .4248 Mdot
.30739 .63595 Mdot
.31742 .59204 Mdot
.33734 .6179 Mdot
.51535 .55619 Mdot
.47906 .56612 Mdot
.29794 .64809 Mdot
.52101 .29325 Mdot
.30246 .60045 Mdot
.59725 .42124 Mdot
.66273 .78938 Mdot
.28967 .63427 Mdot
.55344 .6133 Mdot
.52599 .53483 Mdot
.39886 .70632 Mdot
.31075 .49667 Mdot
.77996 .65687 Mdot
.45752 .64782 Mdot
.53112 .58738 Mdot
.5038 .52938 Mdot
.64497 .4164 Mdot
.25883 .35656 Mdot
.57518 .70816 Mdot
.24866 .42247 Mdot
.69235 .42474 Mdot
.427 .36588 Mdot
.68642 .43128 Mdot
.50497 .58525 Mdot
.50803 .61007 Mdot
.62799 .41761 Mdot
.44495 .21684 Mdot
.34702 .29321 Mdot
.51694 .83649 Mdot
.62986 .44286 Mdot
.49243 .31409 Mdot
.49959 .29154 Mdot
.51165 .35087 Mdot
.30912 .52073 Mdot
.63136 .4636 Mdot
.56982 .62493 Mdot
.37116 .45387 Mdot
.54874 .55964 Mdot
.50834 .30572 Mdot
.56277 .84667 Mdot
.64984 .42667 Mdot
.5365 .60168 Mdot
.16515 .5554 Mdot
.35457 .45589 Mdot
.31612 .63753 Mdot
.33554 .72648 Mdot
.30537 .51418 Mdot
.479 .31956 Mdot
.63303 .41559 Mdot
.50528 .38678 Mdot
.57667 .3935 Mdot
.57658 .5381 Mdot
.60045 .58682 Mdot
.40444 .81855 Mdot
.35572 .49674 Mdot
.49102 .60103 Mdot
.39327 .42201 Mdot
.42439 .36688 Mdot
.53426 .63835 Mdot
.62917 .434 Mdot
.33996 .60613 Mdot
.31979 .59943 Mdot
.47733 .61578 Mdot
.54654 .42709 Mdot
.43188 .53471 Mdot
.53783 .64787 Mdot
.48522 .65513 Mdot
.33189 .48937 Mdot
.43201 .37833 Mdot
.41329 .20351 Mdot
.29256 .64129 Mdot
.5114 .63529 Mdot
.66436 .34594 Mdot
.67553 .46828 Mdot
.335 .44408 Mdot
.48163 .31439 Mdot
.44698 .78033 Mdot
.35037 .42879 Mdot
.53224 .63925 Mdot
.53421 .64327 Mdot
.53363 .33385 Mdot
.69179 .47288 Mdot
.30267 .62582 Mdot
.35166 .47286 Mdot
.29353 .64294 Mdot
.66485 .46938 Mdot
.65032 .42914 Mdot
.54671 .52484 Mdot
.48317 .64983 Mdot
.33863 .45865 Mdot
.56868 .5552 Mdot
.31634 .5004 Mdot
.38841 .78261 Mdot
.47542 .33974 Mdot
.51279 .57391 Mdot
.61917 .47253 Mdot
.50454 .30286 Mdot
.52918 .61424 Mdot
.39757 .82624 Mdot
.53517 .55666 Mdot
.43277 .34732 Mdot
.54799 .20829 Mdot
.32711 .60783 Mdot
.59996 .72951 Mdot
.51524 .51394 Mdot
.5197 .59734 Mdot
.31694 .48397 Mdot
.5606 .6848 Mdot
.52558 .34003 Mdot
.69309 .44059 Mdot
.14062 .56131 Mdot
.51645 .32677 Mdot
.51167 .5955 Mdot
.30266 .61631 Mdot
.64031 .41274 Mdot
.41756 .39023 Mdot
.34195 .24844 Mdot
.54343 .68282 Mdot
.55766 .66029 Mdot
.52732 .65227 Mdot
.76312 .33241 Mdot
.38469 .4249 Mdot
.67341 .4546 Mdot
.53235 .33154 Mdot
.51833 .30483 Mdot
.32991 .47113 Mdot
.62067 .3276 Mdot
.4449 .51843 Mdot
.89629 .48866 Mdot
.3447 .44844 Mdot
.27962 .63249 Mdot
.5627 .44468 Mdot
.31345 .48112 Mdot
.37284 .4485 Mdot
.339 .48509 Mdot
.56922 .32988 Mdot
.66868 .43304 Mdot
.51928 .63186 Mdot
.70033 .42634 Mdot
.5411 .56796 Mdot
.40195 .58668 Mdot
.50523 .30046 Mdot
.69412 .43989 Mdot
.40793 .82561 Mdot
.69227 .39213 Mdot
.55642 .59891 Mdot
.48077 .81047 Mdot
.58127 .66257 Mdot
.44413 .75362 Mdot
.5804 .65644 Mdot
.36451 .44394 Mdot
.49761 .69079 Mdot
.56861 .54759 Mdot
.41641 .19026 Mdot
.51934 .33459 Mdot
.40709 .42672 Mdot
.49891 .57438 Mdot
.49552 .661 Mdot
.65049 .40158 Mdot
.63481 .43137 Mdot
.2921 .64406 Mdot
.37308 .62665 Mdot
.52718 .32436 Mdot
.29851 .71889 Mdot
.52807 .59431 Mdot
.48231 .22455 Mdot
.62195 .69548 Mdot
.53048 .61321 Mdot
.69087 .74934 Mdot
.65913 .67809 Mdot
.57136 .58957 Mdot
.63423 .54959 Mdot
.50321 .3239 Mdot
.54777 .21321 Mdot
.5868 .61024 Mdot
.34521 .46734 Mdot
.68919 .45205 Mdot
.63413 .42223 Mdot
.31326 .64715 Mdot
.23011 .33 Mdot
.48401 .34487 Mdot
.69382 .44555 Mdot
.55985 .58258 Mdot
.47897 .32582 Mdot
.38108 .45716 Mdot
.58448 .57424 Mdot
.51365 .74116 Mdot
.65376 .43961 Mdot
.58179 .58635 Mdot
.62197 .25447 Mdot
.36559 .64718 Mdot
.84613 .51346 Mdot
.51255 .35009 Mdot
.28983 .62273 Mdot
.59748 .63772 Mdot
.25951 .69716 Mdot
.51108 .5524 Mdot
.32992 .70251 Mdot
.59753 .47407 Mdot
.28957 .6178 Mdot
.55034 .598 Mdot
.55752 .62442 Mdot
.5591 .42407 Mdot
.29719 .59803 Mdot
.53406 .56143 Mdot
.47224 .66468 Mdot
.67328 .43569 Mdot
.42199 .40731 Mdot
.65645 .43574 Mdot
.55799 .60845 Mdot
.48808 .55376 Mdot
.64947 .42061 Mdot
.28327 .7294 Mdot
.29454 .65991 Mdot
.50399 .34587 Mdot
.47278 .61958 Mdot
.58161 .62412 Mdot
.76113 .2986 Mdot
.41021 .42195 Mdot
.74854 .35564 Mdot
.33549 .43571 Mdot
.6569 .35553 Mdot
.41293 .31095 Mdot
.75878 .71057 Mdot
.44912 .19776 Mdot
.48545 .62186 Mdot
.42507 .63258 Mdot
.64861 .52936 Mdot
.47654 .3297 Mdot
.75654 .51071 Mdot
.52928 .5895 Mdot
.54713 .58111 Mdot
.35178 .43156 Mdot
.60106 .32567 Mdot
.29027 .31972 Mdot
.5301 .42901 Mdot
.30677 .62634 Mdot
.65176 .47078 Mdot
.5185 .62014 Mdot
.39699 .56062 Mdot
.32003 .45933 Mdot
.47083 .22905 Mdot
.54173 .60013 Mdot
.22374 .37124 Mdot
.5606 .35335 Mdot
.48479 .3414 Mdot
.32011 .48963 Mdot
.3042 .51242 Mdot
.53229 .57087 Mdot
.48773 .30299 Mdot
.56969 .60316 Mdot
.43907 .46997 Mdot
.56122 .55021 Mdot
.29089 .63327 Mdot
.4999 .61871 Mdot
.52469 .41053 Mdot
.83441 .5739 Mdot
.53448 .72308 Mdot
.62398 .43846 Mdot
.30376 .50338 Mdot
.33132 .46684 Mdot
.63971 .4281 Mdot
.33527 .46413 Mdot
.65516 .636 Mdot
.72507 .64394 Mdot
.31108 .62713 Mdot
.47903 .6483 Mdot
.29969 .64369 Mdot
.41087 .42213 Mdot
.53024 .58109 Mdot
.26621 .71825 Mdot
.34825 .4485 Mdot
.61699 .20613 Mdot
.52005 .32812 Mdot
.40894 .42409 Mdot
.56314 .55909 Mdot
.33277 .41496 Mdot
.30855 .48658 Mdot
.42891 .36069 Mdot
.55604 .62104 Mdot
.65562 .42369 Mdot
.55306 .62927 Mdot
.57574 .66409 Mdot
.42601 .3972 Mdot
.57196 .64585 Mdot
.50566 .34006 Mdot
.69454 .46467 Mdot
.70319 .75903 Mdot
.43113 .3439 Mdot
.52308 .57456 Mdot
.55942 .58452 Mdot
.65699 .40445 Mdot
.57844 .58413 Mdot
.49755 .2946 Mdot
.74912 .21781 Mdot
.31846 .62892 Mdot
.35859 .48107 Mdot
.41464 .31925 Mdot
.50083 .56225 Mdot
.54014 .64468 Mdot
.44187 .83435 Mdot
.43715 .28318 Mdot
.49269 .32654 Mdot
.53883 .69253 Mdot
.36687 .45787 Mdot
.30405 .61502 Mdot
.53164 .30063 Mdot
.54311 .65335 Mdot
.54471 .58948 Mdot
.29112 .62655 Mdot
.65245 .77201 Mdot
.24312 .42741 Mdot
.52144 .3504 Mdot
.50166 .69298 Mdot
.27559 .47105 Mdot
.55748 .56369 Mdot
.29156 .51816 Mdot
.63382 .43762 Mdot
.48351 .32257 Mdot
.75965 .37549 Mdot
.49946 .62453 Mdot
.50863 .29433 Mdot
.52622 .32777 Mdot
.59787 .60605 Mdot
.64595 .39889 Mdot
.68396 .46984 Mdot
.63964 .46731 Mdot
.41838 .1728 Mdot
.376 .65908 Mdot
.34403 .44031 Mdot
.50226 .32255 Mdot
.3419 .49202 Mdot
.28209 .6078 Mdot
.39801 .57003 Mdot
.33534 .498 Mdot
.65215 .41513 Mdot
.32403 .49638 Mdot
.5538 .62619 Mdot
.52664 .31732 Mdot
.374 .42451 Mdot
.50268 .56938 Mdot
.50908 .50798 Mdot
.43468 .45422 Mdot
.34234 .61681 Mdot
.33989 .64444 Mdot
.511 .61352 Mdot
.41406 .41518 Mdot
.53334 .59732 Mdot
.5384 .34188 Mdot
.56841 .40442 Mdot
.505 .56017 Mdot
.3498 .45191 Mdot
.46027 .5782 Mdot
.30844 .51374 Mdot
.5533 .68639 Mdot
.55353 .61179 Mdot
.55044 .56412 Mdot
.57032 .60391 Mdot
.61201 .3503 Mdot
.48439 .34904 Mdot
.47688 .52236 Mdot
.39917 .3845 Mdot
.64816 .44615 Mdot
.63166 .47863 Mdot
.25835 .50719 Mdot
.33821 .49925 Mdot
.50333 .33341 Mdot
.56515 .57333 Mdot
.42803 .32747 Mdot
.57209 .84513 Mdot
.28701 .73562 Mdot
.35001 .62029 Mdot
.39255 .41522 Mdot
.62203 .43922 Mdot
.30979 .47733 Mdot
.53902 .57204 Mdot
.59915 .61883 Mdot
.74526 .73076 Mdot
.49235 .36691 Mdot
.30117 .62724 Mdot
.54801 .56491 Mdot
.36408 .65496 Mdot
.37139 .45297 Mdot
.34045 .48537 Mdot
.53857 .55762 Mdot
.66356 .48121 Mdot
.83541 .41082 Mdot
.48328 .34056 Mdot
.45022 .64164 Mdot
.72484 .45876 Mdot
.5677 .23227 Mdot
.51109 .29986 Mdot
.4136 .46113 Mdot
.39801 .41361 Mdot
.61882 .73254 Mdot
.6459 .4426 Mdot
.2983 .6276 Mdot
.59925 .59087 Mdot
.66295 .41586 Mdot
.40111 .40541 Mdot
.68348 .42218 Mdot
.4944 .60782 Mdot
.47801 .33914 Mdot
.33315 .48443 Mdot
.49046 .36116 Mdot
.62007 .42884 Mdot
.32182 .63943 Mdot
.53009 .4818 Mdot
.77236 .53087 Mdot
.6574 .67681 Mdot
.56554 .56653 Mdot
.38781 .56358 Mdot
.56984 .63206 Mdot
.65368 .39933 Mdot
.56738 .59479 Mdot
.69951 .48688 Mdot
.32014 .48625 Mdot
.5829 .59086 Mdot
.5223 .65115 Mdot
.73728 .53172 Mdot
.54459 .60771 Mdot
.58613 .63596 Mdot
.57152 .58661 Mdot
.63626 .49242 Mdot
.51678 .67049 Mdot
.66464 .42857 Mdot
.33578 .2568 Mdot
.3735 .44709 Mdot
.34241 .6094 Mdot
.32527 .59942 Mdot
.32445 .69511 Mdot
.38709 .60796 Mdot
.61201 .33071 Mdot
.6633 .43952 Mdot
.51742 .33951 Mdot
.57031 .5993 Mdot
.77284 .41625 Mdot
.39463 .34904 Mdot
.36938 .45716 Mdot
.43198 .34653 Mdot
.5813 .68051 Mdot
.76415 .33167 Mdot
.56814 .56148 Mdot
.29513 .26902 Mdot
.48542 .57349 Mdot
.52899 .55939 Mdot
.30268 .48896 Mdot
.38615 .60539 Mdot
.5602 .55972 Mdot
.65144 .40166 Mdot
.29902 .63474 Mdot
.71243 .39445 Mdot
.2997 .37467 Mdot
.40258 .46053 Mdot
.75469 .57126 Mdot
.57401 .62285 Mdot
.33739 .48144 Mdot
.67527 .42515 Mdot
.42617 .20124 Mdot
.48865 .34182 Mdot
.575 .3372 Mdot
.6962 .52881 Mdot
.44081 .8118 Mdot
.29916 .63085 Mdot
.64823 .77087 Mdot
.52874 .62723 Mdot
.31373 .52817 Mdot
.49375 .62628 Mdot
.57598 .84334 Mdot
.28113 .6383 Mdot
.65227 .4824 Mdot
.49235 .31568 Mdot
.68012 .41038 Mdot
.66142 .69435 Mdot
.46819 .28003 Mdot
.49428 .47119 Mdot
.38612 .44686 Mdot
.49043 .50907 Mdot
.66178 .46312 Mdot
.52431 .64483 Mdot
.90296 .51939 Mdot
.63216 .44143 Mdot
.64898 .47624 Mdot
.36107 .76988 Mdot
.36264 .77539 Mdot
.55244 .69737 Mdot
.6774 .41517 Mdot
.38693 .44388 Mdot
.32881 .61979 Mdot
.55939 .62806 Mdot
.56678 .61394 Mdot
.65044 .4221 Mdot
.31109 .49317 Mdot
.45817 .66526 Mdot
.35968 .44783 Mdot
.6752 .43486 Mdot
.36252 .45241 Mdot
.42268 .35085 Mdot
.38846 .41991 Mdot
.58223 .61461 Mdot
.56823 .59582 Mdot
.2718 .41732 Mdot
.65043 .42927 Mdot
.54683 .64462 Mdot
.50856 .62437 Mdot
.65516 .46257 Mdot
.3359 .43464 Mdot
.77248 .44854 Mdot
.52156 .58352 Mdot
.54081 .62784 Mdot
.2889 .62108 Mdot
.35548 .55917 Mdot
.20144 .48771 Mdot
.55153 .6374 Mdot
.28146 .61745 Mdot
.69362 .4578 Mdot
.53222 .60129 Mdot
.59406 .42533 Mdot
.42382 .36172 Mdot
.50156 .62645 Mdot
.40368 .42194 Mdot
.52809 .54879 Mdot
.83448 .45792 Mdot
.51512 .58 Mdot
.66698 .45585 Mdot
.68141 .45809 Mdot
.37356 .76951 Mdot
.6377 .45345 Mdot
.39655 .43861 Mdot
.51196 .30851 Mdot
.59932 .83445 Mdot
.37849 .45977 Mdot
.52473 .55839 Mdot
.15982 .56667 Mdot
.58438 .58604 Mdot
.49947 .57041 Mdot
.73878 .29651 Mdot
.37858 .45912 Mdot
.6782 .45714 Mdot
.55988 .28397 Mdot
.47792 .59163 Mdot
.4798 .31927 Mdot
.58696 .5659 Mdot
.56062 .65451 Mdot
.52645 .21512 Mdot
.69176 .28299 Mdot
.54626 .3203 Mdot
.57374 .53142 Mdot
.55149 .63792 Mdot
.37821 .53885 Mdot
.56425 .58599 Mdot
.29678 .64355 Mdot
.64652 .47409 Mdot
.32347 .45969 Mdot
.32406 .62149 Mdot
.5244 .59493 Mdot
.30033 .62237 Mdot
.3437 .43964 Mdot
.48513 .31401 Mdot
.532 .57514 Mdot
.28811 .65244 Mdot
.30562 .62541 Mdot
.56556 .63843 Mdot
.69293 .44513 Mdot
.53696 .71578 Mdot
.53135 .60484 Mdot
.52274 .64088 Mdot
.64936 .4244 Mdot
.24723 .72214 Mdot
.52085 .56985 Mdot
.45747 .43308 Mdot
.64124 .47656 Mdot
.43721 .31783 Mdot
.34533 .43709 Mdot
.56465 .65333 Mdot
.48757 .30613 Mdot
.50242 .30107 Mdot
.36717 .4647 Mdot
.67046 .40532 Mdot
.30912 .49884 Mdot
.45993 .58363 Mdot
.47479 .62693 Mdot
.59146 .59769 Mdot
.14487 .50306 Mdot
.74066 .72733 Mdot
.62858 .43264 Mdot
.38322 .41135 Mdot
.52925 .43315 Mdot
.49871 .32084 Mdot
.35144 .48243 Mdot
.63848 .4127 Mdot
.62325 .43445 Mdot
.67852 .42097 Mdot
.2977 .61023 Mdot
.37744 .41314 Mdot
.68332 .47883 Mdot
.66614 .48052 Mdot
.55444 .62369 Mdot
.55073 .63961 Mdot
.62125 .56923 Mdot
.43066 .72195 Mdot
.31869 .6429 Mdot
.33159 .4732 Mdot
.65593 .17486 Mdot
.54178 .33787 Mdot
.73766 .53585 Mdot
.50249 .56274 Mdot
.85458 .68068 Mdot
.56292 .55529 Mdot
.56122 .58106 Mdot
.69822 .45507 Mdot
.29931 .65565 Mdot
.30428 .64274 Mdot
.66362 .46373 Mdot
.62193 .42798 Mdot
.29221 .63952 Mdot
.58198 .80445 Mdot
.66058 .79314 Mdot
.55202 .26376 Mdot
.65851 .4569 Mdot
.77318 .56008 Mdot
.48163 .31217 Mdot
.61925 .42778 Mdot
.53987 .33526 Mdot
.36775 .45426 Mdot
.39891 .41193 Mdot
.53171 .33621 Mdot
.55859 .61781 Mdot
.35677 .43355 Mdot
.52596 .66441 Mdot
.61103 .80324 Mdot
.72762 .68441 Mdot
.40913 .27446 Mdot
.48951 .64562 Mdot
.29836 .30907 Mdot
.30115 .32231 Mdot
.51476 .60288 Mdot
.6468 .37322 Mdot
.30033 .62583 Mdot
.60787 .45264 Mdot
.49545 .29584 Mdot
.84618 .50221 Mdot
.56074 .56652 Mdot
.66689 .45242 Mdot
.51511 .33649 Mdot
.37726 .76023 Mdot
.56034 .25739 Mdot
.54279 .56608 Mdot
.88798 .45987 Mdot
.60554 .46912 Mdot
.32522 .4577 Mdot
.17795 .44595 Mdot
.70369 .43252 Mdot
.35052 .63589 Mdot
.39757 .39456 Mdot
.43936 .82328 Mdot
.68395 .44239 Mdot
.40216 .40331 Mdot
.65423 .46954 Mdot
.30596 .64692 Mdot
.60511 .43341 Mdot
.34179 .48104 Mdot
.54696 .60271 Mdot
.3395 .46357 Mdot
.32284 .64044 Mdot
.31112 .52268 Mdot
.49204 .29893 Mdot
.40657 .42502 Mdot
.50891 .31828 Mdot
.369 .64077 Mdot
.59316 .2121 Mdot
.4952 .34273 Mdot
.34789 .74496 Mdot
.49021 .60302 Mdot
.69811 .4663 Mdot
.33858 .45154 Mdot
.4041 .39274 Mdot
.53742 .46799 Mdot
.64723 .45105 Mdot
.3281 .47804 Mdot
.70014 .52126 Mdot
.19925 .62868 Mdot
.47684 .57032 Mdot
.39209 .64963 Mdot
.65418 .46041 Mdot
.34078 .48668 Mdot
.3665 .22759 Mdot
.6513 .41432 Mdot
.34522 .44753 Mdot
.49403 .30908 Mdot
.51569 .30223 Mdot
.54724 .5573 Mdot
.55701 .28765 Mdot
.32354 .46724 Mdot
.33615 .27486 Mdot
.67227 .47022 Mdot
.37903 .75833 Mdot
.33183 .63611 Mdot
.37955 .44134 Mdot
.5739 .55398 Mdot
.71661 .42794 Mdot
.42116 .36152 Mdot
.45942 .68226 Mdot
.65163 .17832 Mdot
.33092 .47108 Mdot
.64931 .47503 Mdot
.66472 .44955 Mdot
.57958 .66695 Mdot
.54964 .42895 Mdot
.30538 .49995 Mdot
.25185 .67732 Mdot
.3399 .70974 Mdot
.41965 .39921 Mdot
.31096 .33443 Mdot
.54054 .54957 Mdot
.57417 .63296 Mdot
.49686 .32041 Mdot
.54888 .60888 Mdot
.68088 .47469 Mdot
.56601 .56472 Mdot
.51711 .29865 Mdot
.38944 .43247 Mdot
.53347 .57851 Mdot
.33056 .61765 Mdot
.53975 .29835 Mdot
.53569 .3324 Mdot
.37653 .43878 Mdot
.67722 .41621 Mdot
.29158 .66767 Mdot
.35352 .4521 Mdot
.57386 .62012 Mdot
.41929 .38837 Mdot
.49637 .60917 Mdot
.59282 .77812 Mdot
.66071 .4117 Mdot
.31151 .48156 Mdot
.63282 .47524 Mdot
.51011 .32324 Mdot
.3988 .38563 Mdot
.56141 .60059 Mdot
.34941 .44531 Mdot
.27858 .39438 Mdot
.60835 .78804 Mdot
.66468 .40281 Mdot
.33422 .33587 Mdot
.65694 .47842 Mdot
.42026 .39995 Mdot
.52336 .76541 Mdot
.3076 .6337 Mdot
.36038 .46412 Mdot
.74067 .71608 Mdot
.34613 .45265 Mdot
.54133 .61107 Mdot
.52419 .61662 Mdot
.3593 .42819 Mdot
.30624 .6015 Mdot
.47724 .17559 Mdot
.43626 .4403 Mdot
.68248 .45059 Mdot
.58352 .73955 Mdot
.71767 .22551 Mdot
.47242 .30237 Mdot
.49485 .32352 Mdot
.48045 .60958 Mdot
.53714 .55373 Mdot
.53915 .3131 Mdot
.49186 .29118 Mdot
.31776 .64768 Mdot
.34588 .4802 Mdot
.60321 .43475 Mdot
.5066 .28594 Mdot
.59089 .52693 Mdot
.38715 .61111 Mdot
.51679 .68695 Mdot
.50253 .53227 Mdot
.50774 .65554 Mdot
.31731 .70439 Mdot
.52982 .31006 Mdot
.5111 .61787 Mdot
.52897 .67917 Mdot
.48616 .31939 Mdot
.30308 .64619 Mdot
.67513 .26982 Mdot
.35394 .46167 Mdot
.4122 .85352 Mdot
.50114 .59918 Mdot
.53833 .60909 Mdot
.50999 .35151 Mdot
.3556 .54594 Mdot
.66098 .41808 Mdot
.66766 .41012 Mdot
.38231 .42496 Mdot
.50995 .48812 Mdot
.5786 .5917 Mdot
.51269 .60685 Mdot
.34109 .47564 Mdot
.408 .42292 Mdot
.37757 .27238 Mdot
.52415 .63283 Mdot
.51425 .33515 Mdot
.40722 .39574 Mdot
.52607 .30411 Mdot
.50108 .58976 Mdot
.53866 .6141 Mdot
.58235 .61011 Mdot
.53535 .55378 Mdot
.53462 .33707 Mdot
.51403 .61999 Mdot
.51082 .53979 Mdot
.68973 .42721 Mdot
.57948 .62315 Mdot
.33061 .70988 Mdot
.54944 .61874 Mdot
.32578 .6328 Mdot
.37205 .58904 Mdot
.54887 .56341 Mdot
.58032 .62871 Mdot
.43854 .44065 Mdot
.55189 .59391 Mdot
.53838 .34158 Mdot
.65249 .44619 Mdot
.50212 .32175 Mdot
.53406 .32972 Mdot
.39886 .42733 Mdot
.3041 .64923 Mdot
.49 .57969 Mdot
.33623 .61577 Mdot
.56187 .5334 Mdot
.49345 .61406 Mdot
.37456 .39014 Mdot
.29115 .27101 Mdot
.24312 .43154 Mdot
.56213 .60183 Mdot
.38491 .4306 Mdot
.31886 .46525 Mdot
.43162 .6301 Mdot
.52362 .66695 Mdot
.53665 .30573 Mdot
.49902 .30653 Mdot
.47843 .74595 Mdot
.52487 .21711 Mdot
.32058 .63984 Mdot
.39452 .56691 Mdot
.50329 .66181 Mdot
.51553 .63227 Mdot
.58328 .57323 Mdot
.33625 .49712 Mdot
.43233 .38215 Mdot
.37015 .45641 Mdot
.4364 .35918 Mdot
.51881 .29802 Mdot
.57244 .58052 Mdot
.76394 .64967 Mdot
.63728 .4266 Mdot
.65221 .44544 Mdot
.52943 .30068 Mdot
.3101 .503 Mdot
.6113 .60464 Mdot
.14105 .596 Mdot
.62024 .48318 Mdot
.33362 .63881 Mdot
.51456 .59793 Mdot
.38023 .43459 Mdot
.62756 .44719 Mdot
.30574 .59853 Mdot
.5062 .63026 Mdot
.30014 .49744 Mdot
.56419 .60503 Mdot
.64704 .5291 Mdot
.69046 .43866 Mdot
.59427 .8433 Mdot
.64094 .41372 Mdot
.5323 .29042 Mdot
.48922 .33106 Mdot
.53033 .61545 Mdot
.1542 .48637 Mdot
.70265 .45656 Mdot
.56275 .31346 Mdot
.28663 .64643 Mdot
.41794 .38779 Mdot
.28385 .62365 Mdot
.31427 .4804 Mdot
.29961 .63383 Mdot
.328 .48798 Mdot
.46388 .73427 Mdot
.6663 .49389 Mdot
.32154 .62633 Mdot
.41088 .51872 Mdot
.50975 .66529 Mdot
.32703 .59513 Mdot
.51652 .54339 Mdot
.60569 .73365 Mdot
.34169 .47367 Mdot
.30998 .60134 Mdot
.52617 .64484 Mdot
.82725 .53653 Mdot
.50051 .33918 Mdot
.53894 .30917 Mdot
.55152 .66426 Mdot
.34806 .47908 Mdot
.63578 .41001 Mdot
.58106 .39435 Mdot
.44028 .33368 Mdot
.5121 .61242 Mdot
.5627 .56146 Mdot
.63258 .47964 Mdot
.69489 .48167 Mdot
.53449 .61716 Mdot
.73334 .50348 Mdot
.52305 .62622 Mdot
.49791 .29963 Mdot
.63794 .42092 Mdot
.65998 .44844 Mdot
.32045 .47644 Mdot
.69637 .42716 Mdot
.48232 .54975 Mdot
.51054 .39239 Mdot
.50195 .55533 Mdot
.51599 .32476 Mdot
.54384 .40726 Mdot
.4318 .34695 Mdot
.79442 .62468 Mdot
.61885 .46727 Mdot
.57777 .64128 Mdot
.6624 .47451 Mdot
.30752 .60964 Mdot
.65137 .43139 Mdot
.6283 .46079 Mdot
.52618 .60242 Mdot
.54258 .56918 Mdot
.38844 .44721 Mdot
.54576 .43234 Mdot
.69587 .44305 Mdot
.51524 .61608 Mdot
.58501 .59242 Mdot
.58518 .63983 Mdot
.4753 .43685 Mdot
.62681 .43666 Mdot
.69797 .56104 Mdot
.53033 .74772 Mdot
.69562 .44 Mdot
.82972 .43753 Mdot
.42181 .38136 Mdot
.35173 .48755 Mdot
.47384 .35145 Mdot
.52397 .63364 Mdot
.36761 .42309 Mdot
.53834 .57248 Mdot
.50844 .52775 Mdot
.54496 .58629 Mdot
.28624 .61185 Mdot
.48556 .62209 Mdot
.41486 .40414 Mdot
.34863 .45523 Mdot
.50751 .59674 Mdot
.536 .5794 Mdot
.32618 .51311 Mdot
.61984 .43439 Mdot
.66445 .41799 Mdot
.32141 .55439 Mdot
.31537 .61829 Mdot
.48201 .32073 Mdot
.56968 .58947 Mdot
.38583 .42713 Mdot
.34223 .46156 Mdot
.68406 .41167 Mdot
.34533 .46576 Mdot
.49475 .34908 Mdot
.56192 .59604 Mdot
.5398 .31287 Mdot
.31473 .60042 Mdot
.63953 .46855 Mdot
.56492 .57107 Mdot
.55359 .6244 Mdot
.68138 .45799 Mdot
.48875 .60835 Mdot
.28856 .62191 Mdot
.3411 .45751 Mdot
.68295 .43582 Mdot
.51133 .30667 Mdot
.31814 .48608 Mdot
.54172 .6374 Mdot
.64326 .17439 Mdot
.54241 .61604 Mdot
.53094 .63834 Mdot
.70934 .76481 Mdot
.48353 .61327 Mdot
.32941 .46205 Mdot
.64191 .48364 Mdot
.53662 .66298 Mdot
.34521 .68623 Mdot
.28141 .73581 Mdot
.37362 .45906 Mdot
.51545 .59014 Mdot
.7959 .63409 Mdot
.51188 .59155 Mdot
.29504 .71455 Mdot
.22356 .51808 Mdot
.45465 .5339 Mdot
.51907 .52688 Mdot
.52054 .34621 Mdot
.39132 .44409 Mdot
.32095 .48562 Mdot
.63564 .63464 Mdot
.52114 .60605 Mdot
.62982 .53017 Mdot
.51614 .64668 Mdot
.51348 .30013 Mdot
.54388 .73059 Mdot
.33427 .47003 Mdot
.32219 .24956 Mdot
.57058 .62507 Mdot
.62653 .4337 Mdot
.32079 .49657 Mdot
.4232 .37803 Mdot
.53122 .64165 Mdot
.33232 .60787 Mdot
.53055 .36014 Mdot
.47615 .59032 Mdot
.51858 .3204 Mdot
.50935 .62892 Mdot
.55118 .52331 Mdot
.18806 .39846 Mdot
.69012 .43341 Mdot
.49362 .31709 Mdot
.30217 .33105 Mdot
.48788 .61428 Mdot
.68456 .43907 Mdot
.64593 .44385 Mdot
.3272 .63937 Mdot
.5077 .45133 Mdot
.62511 .26489 Mdot
.78213 .58968 Mdot
.60168 .7151 Mdot
.34115 .48856 Mdot
.34347 .30236 Mdot
.55745 .63163 Mdot
.46337 .23836 Mdot
.5441 .33148 Mdot
.54133 .60661 Mdot
.62772 .69644 Mdot
.63473 .46125 Mdot
.53573 .6296 Mdot
.29971 .64402 Mdot
.44723 .2257 Mdot
.44997 .23977 Mdot
.78897 .3709 Mdot
.38256 .44859 Mdot
.59224 .57866 Mdot
.49557 .53874 Mdot
.40275 .43392 Mdot
.49967 .63244 Mdot
.33391 .45893 Mdot
.53488 .80095 Mdot
.29387 .60633 Mdot
.62968 .4573 Mdot
.42245 .38019 Mdot
.51619 .65865 Mdot
.58973 .6146 Mdot
.34294 .61281 Mdot
.5626 .64801 Mdot
.23136 .33189 Mdot
.40025 .30195 Mdot
.36998 .42704 Mdot
.68173 .42262 Mdot
.50112 .65716 Mdot
.4319 .38487 Mdot
.52446 .60805 Mdot
.72341 .66539 Mdot
.57738 .63958 Mdot
.60455 .25217 Mdot
.68945 .45221 Mdot
.51598 .32026 Mdot
.58416 .54761 Mdot
.55035 .58298 Mdot
.2825 .46175 Mdot
.52618 .52379 Mdot
.5119 .58285 Mdot
.65048 .4033 Mdot
.63263 .42921 Mdot
.66427 .4296 Mdot
.31883 .45929 Mdot
.5062 .22564 Mdot
.50975 .33212 Mdot
.53878 .5476 Mdot
.50746 .28545 Mdot
.47064 .67931 Mdot
.34307 .61883 Mdot
.81486 .49603 Mdot
.56416 .65053 Mdot
.66631 .4364 Mdot
.67823 .33619 Mdot
.69205 .46024 Mdot
.33596 .43147 Mdot
.52732 .32312 Mdot
.63076 .45218 Mdot
.55673 .58088 Mdot
.53632 .42251 Mdot
.7942 .42789 Mdot
.50195 .31584 Mdot
.54081 .5346 Mdot
.40076 .41534 Mdot
.41705 .32348 Mdot
.70506 .20062 Mdot
.49321 .32872 Mdot
.31135 .32009 Mdot
.51628 .60621 Mdot
.64213 .42314 Mdot
.51227 .34924 Mdot
.5037 .34334 Mdot
.33904 .4727 Mdot
.54489 .56753 Mdot
.55193 .56587 Mdot
.41222 .40258 Mdot
.50075 .30519 Mdot
.58743 .6458 Mdot
.57262 .55769 Mdot
.74443 .73299 Mdot
.62773 .62126 Mdot
.29004 .77997 Mdot
.45683 .59466 Mdot
.63057 .70283 Mdot
.57229 .44419 Mdot
.64014 .47338 Mdot
.5457 .56363 Mdot
.49732 .64841 Mdot
.3228 .47061 Mdot
.55357 .60596 Mdot
.31647 .45681 Mdot
.50058 .33381 Mdot
.82386 .43382 Mdot
.68886 .30146 Mdot
.52715 .79617 Mdot
.55239 .60314 Mdot
.54787 .22666 Mdot
.31967 .61028 Mdot
.54033 .29412 Mdot
.67423 .4303 Mdot
.49368 .59849 Mdot
.31066 .51588 Mdot
.36404 .46055 Mdot
.63894 .44118 Mdot
.31138 .28524 Mdot
.28296 .50121 Mdot
.50057 .59007 Mdot
.33296 .44363 Mdot
.63301 .36057 Mdot
.73724 .49341 Mdot
.49059 .28333 Mdot
.28438 .61741 Mdot
.37253 .45347 Mdot
.52813 .30253 Mdot
.59422 .4638 Mdot
.63321 .45207 Mdot
.65721 .48812 Mdot
.24872 .47956 Mdot
.30587 .50612 Mdot
.32593 .61925 Mdot
.51237 .22377 Mdot
.49973 .21431 Mdot
.28571 .61387 Mdot
.39861 .4088 Mdot
.62934 .43682 Mdot
.67636 .44608 Mdot
.65329 .44716 Mdot
.33817 .2374 Mdot
.66341 .40611 Mdot
.74069 .5681 Mdot
.5869 .5965 Mdot
.60004 .5217 Mdot
.51483 .58871 Mdot
.53979 .33287 Mdot
.68956 .44244 Mdot
.56005 .45137 Mdot
.51878 .55854 Mdot
.79602 .39706 Mdot
.51118 .60876 Mdot
.49557 .28129 Mdot
.53108 .63374 Mdot
.7575 .53083 Mdot
.64436 .47824 Mdot
.55829 .60561 Mdot
.50385 .35877 Mdot
.30739 .62205 Mdot
.64356 .398 Mdot
.54924 .56421 Mdot
.59706 .31513 Mdot
.48216 .60316 Mdot
.56684 .80856 Mdot
.40563 .76177 Mdot
.33422 .6384 Mdot
.47441 .66964 Mdot
.35534 .47559 Mdot
.61131 .52486 Mdot
.46827 .62039 Mdot
.50325 .31517 Mdot
.65985 .24068 Mdot
.37718 .44558 Mdot
.54056 .7241 Mdot
.55266 .68844 Mdot
.30188 .64821 Mdot
.71408 .43347 Mdot
.5323 .34596 Mdot
.50015 .57521 Mdot
.59792 .60934 Mdot
.54844 .79817 Mdot
.47027 .6122 Mdot
.57584 .57786 Mdot
.33913 .60735 Mdot
.70178 .56885 Mdot
.5498 .62191 Mdot
.35993 .41927 Mdot
.65339 .48688 Mdot
.54353 .66511 Mdot
.69924 .55625 Mdot
.51587 .61515 Mdot
.63787 .43424 Mdot
.69153 .48121 Mdot
.65322 .31484 Mdot
.29253 .65016 Mdot
.57695 .64004 Mdot
.43643 .7852 Mdot
.57209 .62906 Mdot
.51739 .33291 Mdot
.51541 .57328 Mdot
.35787 .46512 Mdot
.31876 .25959 Mdot
.33988 .44453 Mdot
.53084 .56883 Mdot
.65632 .45109 Mdot
.5251 .34655 Mdot
.24418 .45249 Mdot
.24343 .52447 Mdot
.73509 .5666 Mdot
.40677 .82716 Mdot
.30166 .60476 Mdot
.29483 .59758 Mdot
.52648 .35069 Mdot
.55833 .6076 Mdot
.39341 .77718 Mdot
.48067 .58429 Mdot
.53975 .62943 Mdot
.54386 .58588 Mdot
.48809 .24201 Mdot
.50047 .32647 Mdot
.35383 .45803 Mdot
.53676 .61666 Mdot
.51553 .61847 Mdot
.66327 .47145 Mdot
.30773 .62395 Mdot
.33202 .44907 Mdot
.31547 .62636 Mdot
.36857 .43725 Mdot
.83488 .45052 Mdot
.54749 .54075 Mdot
.3088 .61969 Mdot
.54653 .33127 Mdot
.64878 .4242 Mdot
.43458 .38082 Mdot
.31527 .48204 Mdot
.33027 .47439 Mdot
.51271 .61062 Mdot
.64082 .4283 Mdot
.69695 .43163 Mdot
.30846 .60847 Mdot
.4874 .33791 Mdot
.53455 .56975 Mdot
.49245 .60903 Mdot
.43316 .58882 Mdot
.32488 .5019 Mdot
.70935 .50902 Mdot
.63859 .33167 Mdot
.56128 .60479 Mdot
.67975 .41616 Mdot
.53612 .58648 Mdot
.76021 .66863 Mdot
.65396 .41513 Mdot
.53066 .55935 Mdot
.50151 .20251 Mdot
.41535 .3911 Mdot
.60689 .28686 Mdot
.58433 .61127 Mdot
.45858 .84318 Mdot
.5587 .63632 Mdot
.78223 .68031 Mdot
.35339 .51667 Mdot
.5729 .57958 Mdot
.55454 .62954 Mdot
.7936 .5676 Mdot
.5212 .595 Mdot
.4183 .40404 Mdot
.53716 .72647 Mdot
.62174 .43711 Mdot
.56698 .46252 Mdot
.35316 .56902 Mdot
.291 .65141 Mdot
.38176 .42495 Mdot
.3163 .34365 Mdot
.29143 .6353 Mdot
.6596 .45813 Mdot
.57061 .60414 Mdot
.47797 .50444 Mdot
.40956 .40134 Mdot
.56739 .67308 Mdot
.52151 .33073 Mdot
.36876 .31862 Mdot
.32589 .44541 Mdot
.5137 .31209 Mdot
.53739 .65678 Mdot
.77998 .46236 Mdot
.21196 .5123 Mdot
.60708 .83892 Mdot
.52018 .35064 Mdot
.50788 .29766 Mdot
.38909 .20818 Mdot
.28439 .64711 Mdot
.56053 .77322 Mdot
.58043 .24921 Mdot
.47904 .335 Mdot
.49947 .771 Mdot
.36904 .45903 Mdot
.59151 .30156 Mdot
.60791 .45253 Mdot
.5906 .5932 Mdot
.55511 .58183 Mdot
.48541 .33385 Mdot
.59484 .43421 Mdot
.18364 .4174 Mdot
.50812 .31702 Mdot
.5374 .52893 Mdot
.47068 .46332 Mdot
.42497 .38045 Mdot
.37241 .46617 Mdot
.29966 .65185 Mdot
.3472 .59048 Mdot
.66362 .46868 Mdot
.31491 .64805 Mdot
.44307 .24131 Mdot
.56405 .64908 Mdot
.50408 .30907 Mdot
.43547 .37251 Mdot
.5151 .30581 Mdot
.29772 .64013 Mdot
.32732 .64466 Mdot
.68902 .42605 Mdot
.66308 .41874 Mdot
.6417 .6939 Mdot
.45273 .75086 Mdot
.50994 .59361 Mdot
.75283 .37585 Mdot
.67734 .46757 Mdot
.46953 .64443 Mdot
.28304 .61497 Mdot
.31126 .62082 Mdot
.64248 .55096 Mdot
.56942 .58049 Mdot
.35959 .76192 Mdot
.56811 .581 Mdot
.50616 .74717 Mdot
.49829 .63424 Mdot
.34195 .46972 Mdot
.57332 .58677 Mdot
.27679 .65509 Mdot
.54004 .5499 Mdot
.50858 .58616 Mdot
.35564 .47225 Mdot
.47516 .60103 Mdot
.35607 .46695 Mdot
.53052 .56749 Mdot
.28032 .61423 Mdot
.38568 .4265 Mdot
.37646 .67106 Mdot
.45536 .43509 Mdot
.4123 .415 Mdot
.33156 .62665 Mdot
.33559 .62872 Mdot
.33744 .6767 Mdot
.67572 .43135 Mdot
.67946 .39246 Mdot
.55544 .61004 Mdot
.33883 .48644 Mdot
.49704 .32371 Mdot
.51725 .6211 Mdot
.49134 .62928 Mdot
.5802 .58472 Mdot
.64683 .47243 Mdot
.30851 .50077 Mdot
.30366 .61897 Mdot
.32881 .44707 Mdot
.28994 .46438 Mdot
.34153 .43358 Mdot
.52345 .67582 Mdot
.59874 .57897 Mdot
.62563 .74095 Mdot
.73947 .3415 Mdot
.45743 .18163 Mdot
.63485 .44942 Mdot
.40482 .42237 Mdot
.31969 .64802 Mdot
.51043 .71434 Mdot
.67162 .43478 Mdot
.34442 .47908 Mdot
.56472 .60407 Mdot
.54748 .53346 Mdot
.4766 .36475 Mdot
.61391 .52323 Mdot
.35678 .71754 Mdot
.31 .46543 Mdot
.42245 .39513 Mdot
.49225 .21884 Mdot
.56313 .71193 Mdot
.52534 .47877 Mdot
.5395 .59745 Mdot
.33021 .60518 Mdot
.62758 .44712 Mdot
.22898 .47487 Mdot
.48842 .31211 Mdot
.54813 .42984 Mdot
.55339 .60292 Mdot
.5366 .25084 Mdot
.6546 .45058 Mdot
.30851 .64557 Mdot
.48458 .33195 Mdot
.29957 .65637 Mdot
.36869 .47067 Mdot
.36794 .78694 Mdot
.56965 .6386 Mdot
.5148 .58105 Mdot
.51824 .28558 Mdot
.65514 .46857 Mdot
.33889 .64432 Mdot
.58788 .79657 Mdot
.35263 .43279 Mdot
.3471 .75721 Mdot
.69812 .45913 Mdot
.75875 .56874 Mdot
.32519 .45092 Mdot
.52853 .29987 Mdot
.34246 .67027 Mdot
.51854 .29926 Mdot
.54949 .56063 Mdot
.66302 .44264 Mdot
.50317 .3389 Mdot
.29354 .43977 Mdot
.81738 .59319 Mdot
.76857 .56657 Mdot
.57696 .60985 Mdot
.81696 .47498 Mdot
.64257 .79321 Mdot
.63905 .38787 Mdot
.4904 .29955 Mdot
.52963 .60653 Mdot
.51807 .65285 Mdot
.57156 .62021 Mdot
.52484 .33625 Mdot
.35262 .39065 Mdot
.33303 .47949 Mdot
.51118 .60073 Mdot
.32226 .64474 Mdot
.35832 .46274 Mdot
.41011 .38268 Mdot
.32623 .46913 Mdot
.62046 .45565 Mdot
.53297 .556 Mdot
.57265 .35179 Mdot
.84005 .57763 Mdot
.50208 .32035 Mdot
.41223 .41477 Mdot
.50011 .60986 Mdot
.56997 .21671 Mdot
.6652 .43097 Mdot
.35602 .43095 Mdot
.53827 .60845 Mdot
.33267 .4043 Mdot
.31648 .51659 Mdot
.32688 .47117 Mdot
.67901 .44162 Mdot
.64282 .38133 Mdot
.55076 .60877 Mdot
.55946 .63872 Mdot
.65736 .46633 Mdot
.29763 .57736 Mdot
.33169 .25402 Mdot
.53655 .58184 Mdot
.51548 .31861 Mdot
.18413 .64295 Mdot
.58701 .62477 Mdot
.6133 .66415 Mdot
.37862 .45671 Mdot
.61439 .32105 Mdot
.71271 .50492 Mdot
.48339 .68378 Mdot
.79861 .57029 Mdot
.40593 .56482 Mdot
.82403 .44585 Mdot
.29845 .47483 Mdot
.39925 .49621 Mdot
.83634 .46329 Mdot
.50241 .35696 Mdot
.59077 .50447 Mdot
.4461 .63194 Mdot
.30248 .27766 Mdot
.59142 .42131 Mdot
.29345 .56036 Mdot
.26515 .48699 Mdot
.4621 .50016 Mdot
.34921 .44835 Mdot
.48129 .72131 Mdot
.53532 .57131 Mdot
.63509 .79824 Mdot
.73704 .50821 Mdot
.17344 .42717 Mdot
.82029 .48657 Mdot
.44067 .78454 Mdot
.79666 .45051 Mdot
.77866 .65785 Mdot
.61452 .74456 Mdot
.7325 .34682 Mdot
.2484 .6993 Mdot
.48446 .21023 Mdot
.4648 .79891 Mdot
.60043 .63545 Mdot
.39866 .55968 Mdot
.50412 .82007 Mdot
.7361 .60021 Mdot
.15182 .51233 Mdot
.32444 .46213 Mdot
.64861 .48353 Mdot
.44074 .61761 Mdot
.67525 .40027 Mdot
.46858 .29144 Mdot
.80269 .56336 Mdot
.76709 .69339 Mdot
.75274 .52925 Mdot
.45816 .84591 Mdot
.64428 .64462 Mdot
.3728 .1779 Mdot
.43662 .45808 Mdot
.68556 .48111 Mdot
.22703 .59598 Mdot
.50461 .21637 Mdot
.66461 .28244 Mdot
.45395 .59759 Mdot
.40586 .35983 Mdot
.39379 .69481 Mdot
.66584 .45295 Mdot
.73244 .48932 Mdot
.354 .48889 Mdot
.67444 .27554 Mdot
.33293 .66317 Mdot
.80131 .60217 Mdot
.49229 .48441 Mdot
.58768 .31219 Mdot
.35038 .29265 Mdot
.64581 .17571 Mdot
.45872 .76944 Mdot
.69569 .73678 Mdot
.45982 .33041 Mdot
.59878 .4117 Mdot
.25806 .33367 Mdot
.42559 .73634 Mdot
.50614 .21434 Mdot
.68821 .23969 Mdot
.60273 .82446 Mdot
.72928 .26288 Mdot
.66325 .39277 Mdot
.57996 .58604 Mdot
.69209 .72792 Mdot
.59229 .71775 Mdot
.32845 .58475 Mdot
.77527 .34686 Mdot
.31831 .59894 Mdot
.66802 .39516 Mdot
.30705 .28385 Mdot
.74769 .55192 Mdot
.34389 .75011 Mdot
.32746 .65588 Mdot
.48819 .64463 Mdot
.16368 .34405 Mdot
.81881 .44395 Mdot
.64482 .31356 Mdot
.74656 .73109 Mdot
.52341 .24362 Mdot
.38921 .76378 Mdot
.50854 .33952 Mdot
.84766 .51589 Mdot
.67289 .44413 Mdot
.86693 .45008 Mdot
.83319 .56482 Mdot
.19008 .45924 Mdot
.10938 .56678 Mdot
.43456 .26525 Mdot
.47302 .52225 Mdot
.40315 .57528 Mdot
.36013 .69523 Mdot
.20041 .39659 Mdot
.17567 .49415 Mdot
.51031 .23441 Mdot
.46339 .82729 Mdot
.83787 .49304 Mdot
.51328 .76927 Mdot
.40102 .79594 Mdot
.28906 .2983 Mdot
.46873 .43159 Mdot
.71873 .43796 Mdot
.44649 .41606 Mdot
.74305 .39692 Mdot
.76907 .32797 Mdot
.58812 .71063 Mdot
.14408 .60556 Mdot
.29784 .66504 Mdot
.33456 .52917 Mdot
.69991 .75531 Mdot
.38764 .66253 Mdot
.55622 .74064 Mdot
.41742 .20573 Mdot
.5351 .68734 Mdot
.44621 .20522 Mdot
.70611 .37057 Mdot
.32949 .33766 Mdot
.47365 .21165 Mdot
.60409 .36654 Mdot
.5624 .7983 Mdot
.7128 .69716 Mdot
.52334 .20892 Mdot
.62065 .43731 Mdot
.39997 .73242 Mdot
.47573 .77233 Mdot
.7347 .74211 Mdot
.30279 .33052 Mdot
.63748 .83703 Mdot
.27083 .35138 Mdot
.50998 .55123 Mdot
.47456 .57242 Mdot
.60587 .56991 Mdot
.43175 .7495 Mdot
.58195 .58449 Mdot
.51768 .23596 Mdot
.72114 .75678 Mdot
.62405 .69246 Mdot
.32953 .34965 Mdot
.67345 .2478 Mdot
.61306 .83451 Mdot
.63775 .75055 Mdot
.36543 .49308 Mdot
.61524 .6415 Mdot
.46778 .16086 Mdot
.36679 .45106 Mdot
.50705 .77291 Mdot
.4729 .32103 Mdot
.23985 .4884 Mdot
.78461 .56956 Mdot
.20226 .44169 Mdot
.72011 .75888 Mdot
.342 .25175 Mdot
.24545 .42375 Mdot
.30254 .67857 Mdot
.32635 .7433 Mdot
.7069 .27942 Mdot
.57618 .55013 Mdot
.49867 .52247 Mdot
.33465 .60433 Mdot
.6571 .70177 Mdot
.54718 .75678 Mdot
.24379 .55637 Mdot
.49573 .54666 Mdot
.19252 .53893 Mdot
.42486 .39374 Mdot
.54361 .42632 Mdot
.76489 .2739 Mdot
.5472 .67846 Mdot
.44243 .27533 Mdot
.58431 .82258 Mdot
.39065 .74561 Mdot
.70104 .74644 Mdot
.5873 .35956 Mdot
.72276 .26158 Mdot
.82463 .59822 Mdot
.24044 .53596 Mdot
.81256 .40418 Mdot
.71466 .78139 Mdot
.6884 .22937 Mdot
.67344 .50522 Mdot
.52838 .3541 Mdot
.84719 .35009 Mdot
.39349 .40843 Mdot
.62376 .21506 Mdot
.60284 .71329 Mdot
.33461 .38773 Mdot
.62333 .41288 Mdot
.59745 .65812 Mdot
.46844 .49819 Mdot
.6039 .4714 Mdot
.52717 .66404 Mdot
.69579 .21304 Mdot
.64644 .211 Mdot
.71618 .23695 Mdot
.54423 .83305 Mdot
.81766 .41165 Mdot
.43376 .56407 Mdot
.7458 .57828 Mdot
.44366 .65695 Mdot
.50887 .57894 Mdot
.45899 .71443 Mdot
.43043 .26817 Mdot
.21211 .49466 Mdot
.64776 .27065 Mdot
.65962 .39886 Mdot
.77387 .37491 Mdot
.61759 .13175 Mdot
.65307 .63428 Mdot
.67079 .57121 Mdot
.46048 .23496 Mdot
.45688 .75737 Mdot
.72661 .3846 Mdot
.1997 .48248 Mdot
.71605 .75188 Mdot
.4515 .65365 Mdot
.51312 .78236 Mdot
.25483 .57364 Mdot
.27959 .69905 Mdot
.37775 .54233 Mdot
.8125 .58392 Mdot
.41027 .60691 Mdot
.22342 .42343 Mdot
.55841 .47635 Mdot
.1864 .44102 Mdot
.27818 .52815 Mdot
.36942 .31194 Mdot
.47927 .78818 Mdot
.42632 .33068 Mdot
.4985 .7555 Mdot
.47981 .45771 Mdot
.48886 .71254 Mdot
.40761 .56277 Mdot
.50231 .75626 Mdot
.27662 .69418 Mdot
.78212 .34076 Mdot
.70539 .7989 Mdot
.57819 .16752 Mdot
.47231 .84633 Mdot
.68556 .36434 Mdot
.59247 .61017 Mdot
.68043 .78308 Mdot
.75756 .28387 Mdot
.8226 .61467 Mdot
.35562 .25287 Mdot
.30746 .42284 Mdot
.54082 .29746 Mdot
.58166 .17243 Mdot
.31087 .55766 Mdot
.75089 .69633 Mdot
.46567 .18426 Mdot
.47592 .35432 Mdot
.2827 .2793 Mdot
.62179 .2061 Mdot
.78221 .54461 Mdot
.67454 .52047 Mdot
.56871 .6754 Mdot
.75624 .50972 Mdot
.62596 .47246 Mdot
.33684 .29692 Mdot
.43196 .74325 Mdot
.37543 .4409 Mdot
.39664 .62717 Mdot
.47014 .54788 Mdot
.4853 .62249 Mdot
.36619 .57248 Mdot
.62607 .48038 Mdot
.7385 .34225 Mdot
.54655 .38686 Mdot
.83655 .41271 Mdot
.41275 .2789 Mdot
.53749 .51934 Mdot
.40985 .75257 Mdot
.25135 .42839 Mdot
.40104 .20748 Mdot
.47962 .34133 Mdot
.82644 .51643 Mdot
.44589 .38743 Mdot
.40436 .73634 Mdot
.75372 .50014 Mdot
.57986 .78316 Mdot
.60148 .59136 Mdot
.65708 .33103 Mdot
.69758 .68648 Mdot
.54122 .43488 Mdot
.70336 .41241 Mdot
.71229 .46877 Mdot
.55202 .87341 Mdot
.43302 .23381 Mdot
.35622 .30997 Mdot
.82595 .52802 Mdot
.52976 .31887 Mdot
.69585 .45104 Mdot
.47838 .72924 Mdot
.56479 .8025 Mdot
.71748 .65207 Mdot
.31385 .51697 Mdot
.39773 .34483 Mdot
.26333 .55172 Mdot
.815 .48609 Mdot
.80448 .45754 Mdot
.16928 .42793 Mdot
.67068 .40319 Mdot
.60234 .77681 Mdot
.52069 .79204 Mdot
.66363 .47685 Mdot
.63235 .40101 Mdot
.64715 .2544 Mdot
.80983 .36879 Mdot
.57138 .32653 Mdot
.45156 .8338 Mdot
.31449 .69821 Mdot
.34084 .40178 Mdot
.24268 .44517 Mdot
.43787 .79626 Mdot
.82393 .53793 Mdot
.74058 .47561 Mdot
.78662 .51329 Mdot
.57625 .53047 Mdot
.62347 .53278 Mdot
.55942 .16015 Mdot
.4544 .44892 Mdot
.76021 .55966 Mdot
.59355 .37562 Mdot
.57508 .62127 Mdot
.64851 .17806 Mdot
.60841 .80549 Mdot
.40681 .19801 Mdot
.54177 .35048 Mdot
.53804 .64574 Mdot
.55978 .54723 Mdot
.62296 .59968 Mdot
.63258 .32119 Mdot
.66958 .23417 Mdot
.44174 .79783 Mdot
.63203 .37178 Mdot
.7393 .5027 Mdot
.44224 .27633 Mdot
.79492 .61311 Mdot
.66295 .77869 Mdot
.51413 .4415 Mdot
.42276 .26963 Mdot
.35261 .65869 Mdot
.48544 .84213 Mdot
.4223 .53361 Mdot
.43576 .57191 Mdot
.58441 .2293 Mdot
.61321 .33978 Mdot
.23409 .45122 Mdot
.50019 .61952 Mdot
.31198 .28417 Mdot
.77913 .65431 Mdot
.14293 .51078 Mdot
.22296 .37049 Mdot
.66768 .1862 Mdot
.73987 .64775 Mdot
.60139 .34377 Mdot
.78807 .47362 Mdot
.13483 .52119 Mdot
.39486 .55879 Mdot
.79057 .40429 Mdot
.32324 .67582 Mdot
.8215 .50789 Mdot
.49413 .35961 Mdot
.56253 .26149 Mdot
.66792 .24358 Mdot
.81448 .38681 Mdot
.65164 .75002 Mdot
.81056 .57034 Mdot
.55166 .47597 Mdot
.79377 .33463 Mdot
.5847 .22004 Mdot
.45371 .50536 Mdot
.39823 .42086 Mdot
.3969 .2192 Mdot
.76827 .41306 Mdot
.72498 .35716 Mdot
.5071 .77627 Mdot
.41615 .52581 Mdot
.52962 .72826 Mdot
.77618 .50225 Mdot
.4072 .66875 Mdot
.62025 .34759 Mdot
.4076 .75209 Mdot
.78117 .6623 Mdot
.3878 .55282 Mdot
.25086 .44018 Mdot
.43055 .29195 Mdot
.38914 .80007 Mdot
.63464 .31661 Mdot
.42415 .23661 Mdot
.69974 .73387 Mdot
.30102 .53653 Mdot
.44951 .78117 Mdot
.66336 .85478 Mdot
.45665 .81107 Mdot
.71151 .30858 Mdot
.76568 .32528 Mdot
.68977 .76226 Mdot
.72944 .32838 Mdot
.2068 .37847 Mdot
.63108 .59417 Mdot
.46078 .73112 Mdot
.54528 .58534 Mdot
.75665 .26919 Mdot
.40439 .69438 Mdot
.76876 .32276 Mdot
.64826 .80893 Mdot
.76095 .50389 Mdot
.48484 .62334 Mdot
.3044 .47564 Mdot
.41194 .44557 Mdot
.41355 .66573 Mdot
.79272 .51597 Mdot
.63148 .60988 Mdot
.40266 .30986 Mdot
.40016 .43914 Mdot
.33698 .54945 Mdot
.69758 .38579 Mdot
.4031 .26891 Mdot
.63138 .33474 Mdot
.31081 .57666 Mdot
.5204 .46653 Mdot
.47224 .7627 Mdot
.71534 .50502 Mdot
.78138 .55605 Mdot
.20327 .43513 Mdot
.45749 .38654 Mdot
.32827 .4622 Mdot
.77216 .61295 Mdot
.47784 .81924 Mdot
.63301 .35531 Mdot
.71405 .26004 Mdot
.38303 .22078 Mdot
.44554 .6751 Mdot
.52955 .74443 Mdot
.19538 .42073 Mdot
.25451 .69506 Mdot
.75921 .35127 Mdot
.72349 .46956 Mdot
.36172 .75928 Mdot
.46169 .5552 Mdot
.83431 .45246 Mdot
.47514 .79584 Mdot
.56584 .75425 Mdot
.44414 .44361 Mdot
.72161 .61975 Mdot
.76586 .48471 Mdot
.37107 .66733 Mdot
.54058 .46482 Mdot
.38923 .16848 Mdot
.60615 .43817 Mdot
.62273 .15753 Mdot
.4931 .30479 Mdot
.32827 .23461 Mdot
.26536 .67676 Mdot
.48057 .45211 Mdot
.54788 .46417 Mdot
.66088 .32557 Mdot
.60335 .25047 Mdot
.50794 .834 Mdot
.17147 .47867 Mdot
.36213 .42147 Mdot
.39859 .78427 Mdot
.34835 .77935 Mdot
.79159 .57553 Mdot
.50784 .6612 Mdot
.44915 .81408 Mdot
.45837 .44473 Mdot
.21294 .48979 Mdot
.66216 .79111 Mdot
.69721 .35055 Mdot
.53611 .52664 Mdot
.45151 .75417 Mdot
.78899 .40682 Mdot
.82382 .58816 Mdot
.24473 .31503 Mdot
.70488 .37006 Mdot
.53594 .34717 Mdot
.43905 .54111 Mdot
.80893 .50944 Mdot
.36597 .74604 Mdot
.58137 .30583 Mdot
.46923 .77516 Mdot
.52845 .13069 Mdot
.68747 .24843 Mdot
.66878 .23397 Mdot
.40094 .76241 Mdot
.69791 .41593 Mdot
.62124 .22938 Mdot
.54189 .74837 Mdot
.69345 .34186 Mdot
.52025 .82016 Mdot
.49531 .76769 Mdot
.16013 .41688 Mdot
.60143 .7416 Mdot
.2901 .46737 Mdot
.76336 .46706 Mdot
.61798 .71503 Mdot
.53432 .35394 Mdot
.44659 .71455 Mdot
.5984 .37567 Mdot
.53002 .28863 Mdot
.62619 .34472 Mdot
.59868 .31042 Mdot
.57437 .75493 Mdot
.73158 .63466 Mdot
.64605 .36683 Mdot
.75707 .65268 Mdot
.60392 .49228 Mdot
.23011 .47388 Mdot
.26449 .41936 Mdot
.59151 .39619 Mdot
.37934 .42148 Mdot
.47897 .67812 Mdot
.53378 .44191 Mdot
.3815 .59752 Mdot
.55281 .17191 Mdot
.32071 .59759 Mdot
.69632 .4211 Mdot
.37554 .1987 Mdot
.66914 .47781 Mdot
.71938 .23073 Mdot
.2034 .46949 Mdot
.75056 .50354 Mdot
.25025 .53192 Mdot
.23421 .58263 Mdot
.2503 .2645 Mdot
.74786 .42248 Mdot
.4402 .43357 Mdot
.65894 .49867 Mdot
.656 .41007 Mdot
.4128 .31489 Mdot
.39649 .4427 Mdot
.66325 .53368 Mdot
.4553 .28949 Mdot
.44313 .66289 Mdot
.70301 .46655 Mdot
.30856 .44103 Mdot
.54561 .72615 Mdot
.81697 .38231 Mdot
.34123 .45194 Mdot
.46143 .15107 Mdot
.52581 .5384 Mdot
.68209 .71714 Mdot
.70897 .76925 Mdot
.26328 .29457 Mdot
.26813 .38898 Mdot
.27313 .72915 Mdot
.50268 .55897 Mdot
.66188 .36644 Mdot
.67009 .45282 Mdot
.54799 .76474 Mdot
.30114 .63238 Mdot
.37239 .72315 Mdot
.50757 .28505 Mdot
.22471 .42511 Mdot
.39546 .27383 Mdot
.70808 .43168 Mdot
.71381 .36329 Mdot
.60367 .76142 Mdot
.5701 .25856 Mdot
.46177 .44245 Mdot
.7899 .57399 Mdot
.7258 .63734 Mdot
.70089 .47045 Mdot
.7204 .27513 Mdot
.50659 .7878 Mdot
.85287 .51052 Mdot
.60373 .55103 Mdot
.42072 .47074 Mdot
.549 .23228 Mdot
.64684 .34114 Mdot
.69946 .51109 Mdot
.72081 .74904 Mdot
.41247 .73385 Mdot
.53186 .23297 Mdot
.49718 .75097 Mdot
.55034 .69934 Mdot
.50064 .46956 Mdot
.3458 .27954 Mdot
.18542 .36544 Mdot
.63663 .52913 Mdot
.26378 .31679 Mdot
.71541 .47516 Mdot
.4408 .27423 Mdot
.60311 .45885 Mdot
.29726 .40023 Mdot
.73342 .61035 Mdot
.28941 .35022 Mdot
.84334 .47401 Mdot
.71802 .75256 Mdot
.48095 .36388 Mdot
.41088 .3393 Mdot
.58065 .4612 Mdot
.58393 .52927 Mdot
.56277 .42279 Mdot
.56829 .5681 Mdot
.62588 .3979 Mdot
.28659 .27046 Mdot
.67899 .33711 Mdot
.58241 .66983 Mdot
.82786 .45138 Mdot
.84847 .52395 Mdot
.78974 .33377 Mdot
.34174 .75382 Mdot
.63387 .46726 Mdot
.68911 .22423 Mdot
.68724 .54 Mdot
.78963 .65385 Mdot
.75682 .35606 Mdot
.57366 .86727 Mdot
.7897 .51949 Mdot
.58741 .37722 Mdot
.17851 .48119 Mdot
.61018 .26771 Mdot
.63242 .80471 Mdot
.44321 .51218 Mdot
.35407 .33373 Mdot
.63118 .8094 Mdot
.18833 .3154 Mdot
.6971 .49398 Mdot
.59247 .31277 Mdot
.45001 .57276 Mdot
.59461 .3874 Mdot
.37689 .49759 Mdot
.51383 .57537 Mdot
.41952 .36602 Mdot
.24186 .43029 Mdot
.47828 .76467 Mdot
.52467 .73006 Mdot
.37481 .50051 Mdot
.41714 .66433 Mdot
.50865 .74466 Mdot
.46101 .8002 Mdot
.78898 .54771 Mdot
.66999 .52908 Mdot
.55628 .53064 Mdot
.60169 .43798 Mdot
.28682 .64326 Mdot
.30051 .35736 Mdot
.53637 .56249 Mdot
.28736 .35656 Mdot
.58679 .25588 Mdot
.67627 .1953 Mdot
.3196 .37341 Mdot
.58905 .80518 Mdot
.60842 .45587 Mdot
.64094 .32454 Mdot
.75154 .66917 Mdot
.30516 .2786 Mdot
.37325 .51868 Mdot
.58734 .71145 Mdot
.81848 .45743 Mdot
.47291 .21379 Mdot
.56009 .78982 Mdot
.53864 .19239 Mdot
.54345 .31094 Mdot
.63935 .51381 Mdot
.44426 .57689 Mdot
.35591 .24638 Mdot
.71284 .42649 Mdot
.59042 .37027 Mdot
.42982 .48822 Mdot
.45769 .21074 Mdot
.58658 .82382 Mdot
.59205 .77138 Mdot
.76364 .45296 Mdot
.80747 .45856 Mdot
.37135 .46295 Mdot
.51881 .78406 Mdot
.57694 .3764 Mdot
.39475 .50667 Mdot
.52679 .215 Mdot
.83488 .42515 Mdot
.56053 .43475 Mdot
.38842 .68753 Mdot
.56577 .63659 Mdot
.70014 .55947 Mdot
.67501 .33016 Mdot
.26639 .65451 Mdot
.38818 .29922 Mdot
.65851 .4156 Mdot
.37372 .29008 Mdot
.3545 .5515 Mdot
.44624 .72517 Mdot
.66172 .49608 Mdot
.61708 .67216 Mdot
.32175 .58615 Mdot
.43654 .32463 Mdot
.57565 .65293 Mdot
.37876 .69738 Mdot
.33571 .7429 Mdot
.64654 .511 Mdot
.74863 .39641 Mdot
.78491 .58336 Mdot
.55121 .8044 Mdot
.65648 .35068 Mdot
.75588 .34487 Mdot
.61139 .25369 Mdot
.75003 .59479 Mdot
.29868 .31576 Mdot
.58199 .58976 Mdot
.29945 .39964 Mdot
.69772 .45153 Mdot
.80362 .5279 Mdot
.72974 .6582 Mdot
.3781 .66983 Mdot
.49689 .42844 Mdot
.73654 .68829 Mdot
.48652 .41408 Mdot
.69537 .77498 Mdot
.61282 .26855 Mdot
.43038 .74157 Mdot
.46951 .33214 Mdot
.29436 .68131 Mdot
.20226 .40353 Mdot
.8395 .52749 Mdot
.19531 .4462 Mdot
.48977 .50026 Mdot
.26817 .30675 Mdot
.6804 .27184 Mdot
.64285 .80775 Mdot
.44645 .74243 Mdot
.56171 .42094 Mdot
.53927 .72209 Mdot
.46907 .3576 Mdot
.43296 .3849 Mdot
.28579 .41792 Mdot
.6698 .54086 Mdot
.37601 .36049 Mdot
.26785 .37536 Mdot
.60521 .6144 Mdot
.55077 .21329 Mdot
.81212 .45675 Mdot
.58059 .73971 Mdot
.4632 .45558 Mdot
.22873 .50623 Mdot
.43374 .71965 Mdot
.40607 .85773 Mdot
.64573 .175 Mdot
.56582 .6382 Mdot
.41121 .55597 Mdot
.3848 .7183 Mdot
.33418 .43982 Mdot
.65422 .55938 Mdot
.79693 .56505 Mdot
.50307 .29663 Mdot
.30173 .42269 Mdot
.45002 .21151 Mdot
.66662 .32107 Mdot
.38454 .64422 Mdot
.49649 .23917 Mdot
.6957 .20717 Mdot
.48398 .82493 Mdot
.66115 .33946 Mdot
.46379 .87232 Mdot
.33457 .27622 Mdot
.71209 .47119 Mdot
.68907 .7339 Mdot
.7833 .34044 Mdot
.39599 .75053 Mdot
.24768 .48077 Mdot
.7302 .31368 Mdot
.4232 .73624 Mdot
.52077 .76082 Mdot
.4301 .29151 Mdot
.37845 .29227 Mdot
.47505 .48021 Mdot
.23547 .58282 Mdot
.58099 .19341 Mdot
.74397 .48318 Mdot
.80076 .43293 Mdot
.23941 .41893 Mdot
.15261 .43322 Mdot
.84794 .51506 Mdot
.44228 .69596 Mdot
.37246 .49477 Mdot
.67862 .7427 Mdot
.3373 .70913 Mdot
.59919 .70617 Mdot
.21505 .45131 Mdot
.70556 .66128 Mdot
.21979 .56753 Mdot
.25412 .35065 Mdot
.49969 .75543 Mdot
.61874 .70955 Mdot
.55949 .44004 Mdot
.77711 .59076 Mdot
.41117 .30072 Mdot
.41829 .76298 Mdot
.28657 .44251 Mdot
.33921 .69341 Mdot
.77809 .60682 Mdot
.72761 .70602 Mdot
.57058 .42036 Mdot
.20669 .29678 Mdot
.77516 .35953 Mdot
.29647 .29362 Mdot
.5874 .60021 Mdot
.84447 .46001 Mdot
.57333 .39998 Mdot
.75089 .33228 Mdot
.56649 .81487 Mdot
.28589 .39684 Mdot
.55882 .23696 Mdot
.5786 .58133 Mdot
.7519 .38262 Mdot
.76256 .55474 Mdot
.62266 .71207 Mdot
.23481 .43999 Mdot
.41026 .75014 Mdot
.35494 .49679 Mdot
.35897 .67268 Mdot
.5745 .51457 Mdot
.69958 .45527 Mdot
.7297 .24963 Mdot
.49396 .50283 Mdot
.48787 .68317 Mdot
.60467 .52959 Mdot
.18094 .46397 Mdot
.37893 .81994 Mdot
.59306 .53402 Mdot
.48312 .21639 Mdot
.50036 .77315 Mdot
.46978 .69764 Mdot
.73443 .45869 Mdot
.12404 .62691 Mdot
.72927 .75919 Mdot
.63663 .41205 Mdot
.63475 .62099 Mdot
.407 .77344 Mdot
.79509 .35247 Mdot
.257 .57133 Mdot
.26249 .41671 Mdot
.15863 .53835 Mdot
.34156 .7207 Mdot
.49092 .62241 Mdot
.57349 .82699 Mdot
.83648 .53838 Mdot
.2322 .41959 Mdot
.83278 .46308 Mdot
.50515 .67448 Mdot
.56332 .54567 Mdot
.2402 .7547 Mdot
.81395 .52081 Mdot
.53632 .68845 Mdot
.17936 .45429 Mdot
.71667 .43116 Mdot
.54273 .57266 Mdot
.45858 .2656 Mdot
.47195 .79157 Mdot
.51273 .7508 Mdot
.81388 .38517 Mdot
.70671 .42143 Mdot
.28016 .36458 Mdot
.51771 .29353 Mdot
.54454 .4652 Mdot
.55735 .53662 Mdot
.51736 .34134 Mdot
.45668 .69287 Mdot
.58428 .40173 Mdot
.51834 .36407 Mdot
.40496 .79361 Mdot
.62305 .843 Mdot
.75161 .62713 Mdot
.50437 .37268 Mdot
.58215 .68795 Mdot
.60541 .73826 Mdot
.41557 .66637 Mdot
.42778 .62817 Mdot
.61839 .82182 Mdot
.81679 .69444 Mdot
.35975 .33789 Mdot
.61585 .59627 Mdot
.66754 .49456 Mdot
.68118 .5254 Mdot
.77791 .53388 Mdot
.55565 .30044 Mdot
.38405 .4536 Mdot
.48021 .58913 Mdot
.57544 .5142 Mdot
.50568 .28635 Mdot
.59015 .15368 Mdot
.49796 .60274 Mdot
.73127 .47692 Mdot
.79649 .63878 Mdot
.23004 .47105 Mdot
.66721 .72373 Mdot
.49954 .569 Mdot
.61067 .22801 Mdot
.56751 .39895 Mdot
.62907 .38382 Mdot
.25023 .43645 Mdot
.80475 .39989 Mdot
.72515 .66439 Mdot
.75932 .45153 Mdot
.51156 .6156 Mdot
.27703 .62652 Mdot
.58884 .29428 Mdot
.73113 .3077 Mdot
.52895 .51716 Mdot
.80986 .62612 Mdot
.28143 .40372 Mdot
.38624 .36253 Mdot
.47934 .69563 Mdot
.75697 .29464 Mdot
.24366 .34917 Mdot
.76843 .52022 Mdot
.37479 .21315 Mdot
.40263 .23518 Mdot
.40827 .67201 Mdot
.30283 .48321 Mdot
.58838 .66589 Mdot
.71518 .4385 Mdot
.72202 .22182 Mdot
.72419 .29835 Mdot
.53051 .3841 Mdot
.37186 .31596 Mdot
.73232 .55294 Mdot
.56415 .45618 Mdot
.52986 .88293 Mdot
.29638 .56067 Mdot
.68811 .20038 Mdot
.55291 .76361 Mdot
.71966 .39324 Mdot
.60248 .35347 Mdot
.48443 .55546 Mdot
.32959 .46905 Mdot
.79946 .36747 Mdot
.58106 .51283 Mdot
.27786 .33332 Mdot
.49183 .61591 Mdot
.426 .19329 Mdot
.51295 .39595 Mdot
.41707 .33613 Mdot
.42597 .33736 Mdot
.20775 .37992 Mdot
.76779 .66309 Mdot
.55323 .40119 Mdot
.50094 .86957 Mdot
.79256 .48004 Mdot
.82726 .51748 Mdot
.3128 .51942 Mdot
.24146 .30501 Mdot
.73206 .35704 Mdot
.63998 .36474 Mdot
.53022 .38888 Mdot
.39517 .5948 Mdot
.38141 .2255 Mdot
.47009 .70114 Mdot
.60021 .28462 Mdot
.47125 .35611 Mdot
.88012 .64157 Mdot
.45427 .7034 Mdot
.46091 .57481 Mdot
.31465 .28839 Mdot
.82692 .48927 Mdot
.27172 .6032 Mdot
.58866 .83541 Mdot
.40115 .55761 Mdot
.56674 .54493 Mdot
.72205 .65397 Mdot
.56923 .7473 Mdot
.40896 .21474 Mdot
.30587 .21139 Mdot
.4942 .82114 Mdot
.38013 .34246 Mdot
.52149 .46052 Mdot
.66597 .47552 Mdot
.62551 .41141 Mdot
.24369 .54894 Mdot
.54414 .84977 Mdot
.58575 .38578 Mdot
.8097 .5112 Mdot
.23405 .28598 Mdot
.55952 .77522 Mdot
.79961 .35601 Mdot
.71787 .32852 Mdot
.60669 .42725 Mdot
.42065 .66363 Mdot
.35109 .63886 Mdot
.42493 .36571 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0T?oo
ool2o`000;Oooooo000Looooo`03o`000?oooooooooo093ooooo0_l0002gooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0:Sooooo0_l0000Kooooo`;o
0000P_ooool001cooooo00?o0000ooooooooool0Z?ooool2o`0001_ooooo0_l00022ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo09oooooo0_l0002X
ooooo`007?ooool00ol0003oooooooooo`2Oooooo`;o00001?ooool2o`000:;ooooo000Looooo`03
o`000?oooooooooo0:Gooooo0_l0002Rooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`;o0000Toooool2o`0002?ooooo0_l00003ooooo`;o0000Roooool001cooooo00?o0000
ooooooooool0T_ooool2o`0002?ooooo0_l00003ooooo`;o0000Roooool001cooooo00?o0000oooo
ooooool0a_ooool2o`00087ooooo000Looooo`03o`000?oooooooooo09Cooooo0_l0000Looooo`;o
00004_ooool2o`00087ooooo000Looooo`03o`000?oooooooooo09Cooooo0_l0000Looooo`;o0000
00?oooooo`000?l00000T_ooool001cooooo00?o0000ooooooooool0Noooool2o`00017ooooo0_l0
000Qooooo`;o00000_ooool2o`000003ooooool0003o000008oooooo000Looooo`03o`000?oooooo
oooo07_ooooo0_l0000Aooooo`;o00000oooool2o`0001Wooooo1Ol00005ooooo`;o0000Soooool0
01cooooo00?o0000ooooooooool0Q?ooool2o`0000gooooo0_l00005ooooo`;o00004_ooool4o`00
00Oooooo0_l0000Booooo`?o000000?oooooo`000?l00000M_ooool001cooooo00?o0000oooooooo
ool0MOooool2o`000003ooooool0003o000000[ooooo0_l0000Aooooo`;o000000?oooooo`000?l0
00007Oooool2o`0000?ooooo0_l0000=ooooo`Ko0000M_ooool001cooooo00?o0000ooooooooool0
MOooool2o`000003ooooool0003o000001cooooo0ol0000Tooooo`?o00003_ooool4o`0007Oooooo
000Looooo`03o`000?oooooooooo07;ooooo0_l0000Mooooo`;o000000?oooooo`000?l000000_l0
0003ooooo`;o00008?ooool2o`0008[ooooo000Looooo`03o`000?oooooooooo07;ooooo0_l0000M
ooooo`;o000000?oooooo`000?l000001Oooool3o`0002Cooooo0_l0000Aooooo`;o0000L_ooool0
01cooooo00?o0000ooooooooool0Q?ooool2o`0000_ooooo0_l00009ooooo`;o00003oooool2o`00
01?ooooo0_l0000Aooooo`;o0000L_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2
ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo08;ooooo1?l000000ooooooo0000o`000002
ooooo`;o00000oooool2o`0001Wooooo1?l00008ooooo`Co0000S_ooool00006oooooomgMgOoV9RH
oooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`00
0?oooooooooo07[ooooo0_l00006ooooo`;o00000oooool2o`0000;ooooo1?l000000ooooooo0000
o`000004ooooo`;o00004oooool2o`0000Wooooo1Ol0000Mooooo`;o0000Koooool00003ooooool@
413ooooo00;ooooo00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oo
oooooooo07Kooooo0_l00002ooooo`;o00001?ooool2o`0000_ooooo0ol00006ooooo`;o00004_oo
ool2o`0000[ooooo0_l0000Pooooo`;o0000Koooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool02oooool00onHV9So8B4Qonk^kP06ooooo`?o0000M_ooool2o`0000Gooooo0_l00000
0ooooooo0000o`000003ooooo`Go00000_ooool4o`0000Cooooo1?l00007ooooo`;o00001?ooool3
o`0000;ooooo0_l0000?ooooo`;o00003Oooool2o`00013ooooo0_l00003ooooo`;o0000I_ooool0
0003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`05oooo
o`03o`000?oooooooooo07gooooo0_l00004ooooo`Oo00000_ooool6o`0000;ooooo1?l00007oooo
o`;o00001?ooool3o`0001?ooooo0_l00007ooooo`Co00000_ooool2o`00013ooooo0_l00003oooo
o`;o0000I_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool03Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo07_ooooo0_l00002ooooo`;o00000_ooool3o`0000Oo
oooo0_l000000ooooooo0000o`00000Dooooo`;o000000?oooooo`000?l000000oooool2o`0001Co
oooo1?l0000Fooooo`;o0000JOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0
003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0H?ooool2o`0001Wooooo0_l00002
ooooo`;o00001_ooool2o`0000Gooooo0_l000000ooooooo0000o`000003ooooo`Ko00002_ooool2
o`000004ooooool0003o0000o`0000;ooooo0_l00004ooooo`;o00001?ooool2o`000003ooooool0
003o000000;o00001Oooool2o`0000Kooooo0_l0000>ooooo`;o0000JOooool00006ooooooo^k^ko
<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000oooooooo
ool0H?ooool4o`0001;ooooo0_l00003ooooo`;o00001?ooool2o`0000Cooooo0_l00005ooooo`;o
000000?oooooo`000?l000000oooool8o`000003ooooool0003o000000;o00001?ooool2o`000003
ooooool0003o000000;ooooo0ol00003ooooo`;o00001?ooool7o`0000Gooooo0ol00005ooooo`;o
00003_ooool2o`0006Wooooo000Looooo`03o`000?oooooooooo06;ooooo0_l0000Booooo`Co0000
00?oooooo`000?l000001?ooool2o`0000[ooooo0_l00007ooooo`;o000000Coooooo`000?l0003o
oooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l00004ooooo`Co00001?ooool2o`0000Go
oooo0_l00009ooooo`;o00000_ooool2o`00017ooooo0_l0000@ooooo`;o0000Eoooool001cooooo
00?o0000ooooooooool0N?ooool3o`0000;ooooo0_l0000>ooooo`;o00002_ooool2o`000003oooo
ool0003o000000;ooooo0_l00005ooooo`;o00001?ooool2o`0000Kooooo0_l00003ooooo`;o0000
3oooool4o`00027ooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`1iooooo`;o00000_oo
ool2o`0000kooooo0_l0000:ooooo`;o000000?oooooo`000?l000001Oooool2o`0001Gooooo0ol0
0009ooooo`;o00001Oooool2o`0000gooooo0_l00009ooooo`;o0000H?ooool001cooooo00?o0000
ooooooooool0Loooool2o`0000?ooooo0_l0000Aooooo`;o000000?oooooo`000?l000002Oooool2
o`0000Kooooo1?l00009ooooo`;o00001Oooool2o`0000Cooooo0_l00009ooooo`;o00005?ooool2
o`0000Oooooo1?l0001Pooooo`007?ooool00ol0003oooooooooo`1^ooooo`;o00000oooool2o`00
00?ooooo0_l0000@ooooo`?o000000?oooooo`000?l000000_ooool5o`0000[ooooo0_l00003oooo
o`Co00001?ooool2o`0000Gooooo0_l00003ooooo`;o00001oooool7o`0001;ooooo0_l00007oooo
o`?o000000?oooooo`000?l00000G_ooool001cooooo00?o0000ooooooooool0K_ooool2o`000003
ooooool0003o000000;o00005?ooool3o`0000Kooooo1Ol0000>ooooo`Ko00001?ooool2o`0000Co
oooo0ol00002ooooo`;o00001oooool7o`0001;ooooo0_l00008ooooo`;o000000?oooooo`000?l0
0000G_ooool001cooooo00?o0000ooooooooool0Ioooool2o`0000Kooooo1?l000000ooooooo0000
o`000009ooooo`;o00001Oooool2o`000003ooooool0003o000000Oooooo0_l0000>ooooo`Go0000
0_ooool2o`0000Cooooo1Ol000000ooooooo0000o`000003o`0000kooooo0_l00008ooooo`;o0000
00Coooooo`000?l0003o00003Oooool2o`0006;ooooo000Looooo`03o`000?oooooooooo06Oooooo
0_l000000ooooooo0000o`000003ooooo`;o00000oooool2o`0000Wooooo0_l00004ooooo`?o0000
1_ooool2o`0000;ooooo0ol00009ooooo`;o00000_ooool4o`0000;ooooo0_l00007ooooo`?o0000
1?ooool2o`0000;ooooo0_l00005ooooo`;o00000oooool2o`0000Sooooo0_l000001?oooooo0000
o`000?l00004ooooo`;o00001oooool2o`0006;ooooo000Looooo`03o`000?oooooooooo06[ooooo
0_l00005ooooo`;o00004_ooool2o`0000Gooooo1?l00003ooooo`;o000000?oooooo`000?l00000
0oooool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o00004_ooool2o`0000Gooooo
0_l0000=ooooo`?o00001oooool2o`0006_ooooo000Looooo`03o`000?oooooooooo077ooooo0_l0
000Iooooo`;o00002?ooool2o`0000?ooooo0_l00003ooooo`;o00000_ooool4o`0002[ooooo1Ol0
001booooo`007?ooool00ol0003oooooooooo`1Qooooo`;o00002?ooool2o`0000?ooooo1?l0000/
ooooo`;o00001?ooool2o`00017ooooo0_l00006ooooo`;o00002Oooool2o`0000?ooooo0_l00002
ooooo`Co00000oooool2o`0006_ooooo000Looooo`;o0000H_ooool2o`000004ooooool0003o0000
o`0000Cooooo0_l00003ooooo`Co00001Oooool2o`0001Wooooo0_l0000=ooooo`;o00001_ooool2
o`0000Oooooo0_l00003ooooo`;o00001Oooool3o`0000Wooooo0_l00003ooooo`;o00000oooool3
o`0000?ooooo0_l0000;ooooo`;o0000G_ooool001cooooo00?o0000ooooooooool0I?ooool3o`00
0004ooooool0003o0000ooooo`;o00000_ooool3o`0000Oooooo0_l0000Iooooo`;o00003Oooool4
o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l000002_ooool5o`000003ooooool0003o
000000Kooooo0_l0000Iooooo`;o0000G_ooool001cooooo00?o0000ooooooooool0J?ooool5o`00
00;ooooo0ol00007ooooo`;o00002?ooool2o`00023ooooo0_l00006ooooo`;o00000_ooool3o`00
0003ooooool0003o000000Cooooo0_l00005ooooo`?o000000?oooooo`000?l000001_ooool2o`00
07Wooooo000Looooo`03o`000?oooooooooo057ooooo0_l0000Aooooo`;o00000oooool3o`0000So
oooo0_l00003ooooo`;o00002?ooool2o`0000gooooo0_l0000Iooooo`;o00000oooool5o`0000Co
oooo0_l0000Eooooo`;o00004?ooool2o`000003ooooool0003o0000063ooooo000Looooo`03o`00
0?oooooooooo04kooooo0_l000000ooooooo0000o`00000=ooooo`So00000_ooool2o`0000Sooooo
0_l00003ooooo`;o00005oooool2o`0001cooooo0_l000000ooooooo0000o`00000;ooooo`;o0000
4?ooool2o`00013ooooo0_l000000ooooooo0000o`000002o`0005kooooo000Looooo`03o`000?oo
oooooooo04kooooo0_l0000>ooooo`Ko00000_ooool2o`00027ooooo0_l00006ooooo`;o00007Ooo
ool2o`0000kooooo1?l00002ooooo`?o00003oooool2o`0000Gooooo0_l00006ooooo`Co0000G_oo
ool001cooooo00?o0000ooooooooool0FOooool2o`000003ooooool0003o000000Go00005?ooool2
o`0000Kooooo0_l00005ooooo`Go00001_ooool2o`0002Kooooo0_l00007ooooo`?o000000Cooooo
o`000?l0003o00001_ooool2o`0000Oooooo0_l00005ooooo`;o00001_ooool2o`0000Wooooo0_l0
001Eooooo`007?ooool00ol0003oooooooooo`1Iooooo`Go00000oooool4o`0001;ooooo0_l00004
ooooo`Co00001Oooool4o`0002oooooo0_l00008ooooo`;o00002_ooool2o`0000Oooooo0ol0000>
ooooo`;o00001oooool2o`000003ooooool0003o000005;ooooo000Looooo`03o`000?oooooooooo
05_ooooo0ol00005ooooo`;o00001?ooool2o`0000cooooo0_l00004ooooo`;o00000_ooool2o`00
00Sooooo1Ol0000Yooooo`;o00007?ooool4o`0000_ooooo0_l000000ooooooo0000o`00000:oooo
o`;o0000D_ooool001cooooo00?o0000ooooooooool0F?ooool2o`0000;ooooo0_l000000ooooooo
0000o`000008ooooo`;o00000_ooool2o`0001;ooooo0ol00007ooooo`Go00001?ooool4o`0000Oo
oooo0_l0000fooooo`;o000000?oooooo`000?l000001_ooool2o`0000;ooooo0_l00004ooooo`;o
0000Foooool001cooooo00?o0000ooooooooool0B_ooool2o`0000cooooo0_l00005ooooo`;o0000
3?ooool2o`0001?ooooo0_l00006ooooo`;o00002?ooool4o`0000Gooooo1?l00006ooooo`;o0000
5?ooool2o`0001Gooooo0_l00004ooooo`;o000000?oooooo`000?l000000oooool2o`0000Sooooo
0_l0001Kooooo`007?ooool00ol0003oooooooooo`18ooooo`Co00005?ooool4o`0002Kooooo0_l0
000@ooooo`Oo00000_ooool4o`0000Sooooo0ol00009ooooo`Co00004oooool2o`000004ooooool0
003o0000ooooo`;o000000?oooooo`000?l000004oooool2o`0005Gooooo000Looooo`03o`000?oo
oooooooo04Sooooo0_l0000Fooooo`Co0000>?ooool8o`000003ooooool0003o000000?o00001ooo
ool4o`0000[ooooo1?l0000Dooooo`;o000000Coooooo`000?l0003o00005Oooool2o`0005Gooooo
000Looooo`03o`000?oooooooooo06;ooooo0_l00004ooooo`;o00003?ooool3o`000003ooooool0
003o000000cooooo0_l00006ooooo`;o00000_ooool2o`0000Cooooo4_l00002ooooo`;o000000?o
ooooo`000?l000000_l00006ooooo`;o00000_ooool4o`0000_ooooo0_l0000;ooooo`;o0000K?oo
ool001cooooo00?o0000ooooooooool0D_ooool2o`0000Wooooo0_l00009ooooo`;o00000oooool3
o`0000Kooooo0ol000000ooooooo0000o`00000<ooooo`;o00001_ooool2o`0000;ooooo0_l00003
oooooaOo00001Oooool2o`0000Cooooo0_l00002ooooo`;o00003Oooool2o`0002;ooooo0_l0001E
ooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00004Oooool2o`0000Cooooo1?l000000ooo
oooo0000o`00000;ooooo`Ko00004Oooool2o`0000Kooooo0_l000000ooooooo0000o`00000;oooo
o`?o000000?oooooo`000?l000003ol00002ooooo`;o00000oooool2o`0000Cooooo0_l0000Aoooo
o`;o000000?oooooo`000?l000002_ooool2o`0000Sooooo0ol00002ooooo`;o00001?ooool3o`00
05Cooooo000Looooo`;o0000@?ooool2o`0001Oooooo1?l00009ooooo`;o00000oooool3o`0000go
oooo0_l000000ooooooo0000o`000002ooooo`?o00001Oooool5o`0000[ooooo5_l00002ooooo`?o
00001Oooool2o`0000;ooooo0ol0000>ooooo`;o00000_ooool2o`0000Wooooo0ol00008ooooo`?o
00000_ooool2o`0000Gooooo0ol0001Cooooo`007?ooool00ol0003oooooooooo`1?ooooo`;o0000
3?ooool2o`0000Kooooo0_l00004ooooo`?o00003?ooool2o`000003ooooool0003o000000Go0000
1oooool2o`0000Gooooo0_l00002oooooaGo000000?oooooo`000?l000000oooool2o`0000Gooooo
0_l00002ooooo`?o00003_ooool2o`0000Gooooo0_l00006ooooo`;o00005_ooool2o`0005?ooooo
000Looooo`03o`000?oooooooooo04_ooooo0_l00002ooooo`;o00000_ooool2o`0000Sooooo0_l0
000<ooooo`?o00002Oooool2o`0000;ooooo1ol0000@ooooo`;o000000?oooooo`000?l000000_l0
00000ooooooo0000o`00000Bo`0000_ooooo0_l00002ooooo`;o00005Oooool3o`0001?ooooo0_l0
001Mooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o00001_ooool2o`0000Sooooo0_l00000
0ooooooo0000o`00000>ooooo`;o00000oooool4o`0000;ooooo1_l00002ooooo`;o00003oooool5
o`000003ooooool0003o000001?o00001_ooool2o`0000;ooooo0_l00004ooooo`;o00003?ooool2
o`0000Kooooo0_l0000<ooooo`;o00001Oooool2o`0005gooooo000Looooo`03o`000?oooooooooo
053ooooo0_l0000:ooooo`Ko00003_ooool2o`0000;ooooo0ol00007ooooo`?o000000Coooooo`00
0?l0003o00003oooool2o`0000?ooooo3?l000000ooooooo0000o`000007o`0000Cooooo1?l00002
ooooo`So00003?ooool3o`0001?ooooo0_l00004ooooo`?o00001?ooool2o`0005Oooooo000Loooo
o`03o`000?oooooooooo03Wooooo0_l00003ooooo`;o00003?ooool2o`0000;ooooo1?l00008oooo
o`Go00004oooool3o`0000_ooooo0_l0000@ooooo`;o000000?oooooo`000?l000003?l000000ooo
oooo0000o`000007o`0000Cooooo0_l00004ooooo`Oo00002_ooool2o`0000;ooooo1?l0000<oooo
o`;o00001oooool4o`0000Gooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`0iooooo`;o
00000oooool2o`0000cooooo0_l00004ooooo`;o00001oooool4o`0000;ooooo0_l00004ooooo`Co
00002Oooool3o`0000Wooooo1Ol00005ooooo`;o000000?oooooo`000?l000001OoooolIo`0000?o
oooo0_l00006ooooo`?o00000_ooool3o`0000[ooooo0_l00004ooooo`;o00003?ooool2o`0000Oo
oooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`1Fooooo`;o00000oooool2o`000004oooo
ool0003o0000ooooo`;o00001?ooool4o`0000Gooooo0ol000000ooooooo0000o`000002ooooo`;o
00001?ooool7o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000Gooooo2Ol000000ooo
oooo0000o`00000Bo`0000Kooooo0_l00006ooooo`;o00000_ooool2o`0000Cooooo0_l00009oooo
o`;o00007oooool2o`00057ooooo000Looooo`03o`000?oooooooooo05Kooooo0_l00006ooooo`;o
00004?ooool3o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o00000_ooool7o`000003
ooooool0003o000000[ooooo6_l00004ooooo`;o00002Oooool3o`0000;ooooo0_l00004ooooo`Go
00001?ooool5o`0001Cooooo0_l00007ooooo`?o0000DOooool001cooooo00?o0000ooooooooool0
COooool4o`0000gooooo0_l0000Tooooo`Go000000?oooooo`000?l000001?ooool2o`0000Cooooo
6_l00004ooooo`Co00001oooool2o`0000Gooooo0_l00004ooooo`?o00001?ooool2o`000003oooo
ool0003o000000Oooooo0_l00004ooooo`;o00000_ooool2o`000003ooooool0003o000000Oooooo
1Ol0001?ooooo`007?ooool00ol0003oooooooooo`17ooooo`;o00001?ooool4o`0000Cooooo1?l0
00000ooooooo0000o`000002ooooo`?o00009_ooool2o`0000;ooooo0_l00003ooooo`Co000000?o
ooooo`000?l000006Ol00002ooooo`;o000000Coooooo`000?l0003o00002oooool2o`000003oooo
ool0003o000000;o00000_ooool2o`0000Cooooo0_l00003ooooo`;o00001_ooool2o`0000Cooooo
0_l00002ooooo`;o00001Oooool3o`000003ooooool0003o000000Co0000Coooool001cooooo00?o
0000ooooooooool0Aoooool2o`0000Oooooo0_l00003ooooo`Co000000?oooooo`000?l000000_oo
ool5o`0000cooooo1?l0000Dooooo`?o000000?oooooo`000?l000001Oooool2o`000003ooooool0
003o000001Wo00000_ooool2o`000003ooooool0003o000000?ooooo0_l00007ooooo`;o00000ooo
ool3o`000003ooooool0003o000000Cooooo0_l00003ooooo`;o000000?oooooo`000?l000003ooo
ool2o`0000?ooooo0ol000000ooooooo0000o`000007ooooo`?o0000BOooool001cooooo00?o0000
ooooooooool0C?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool4
o`000004ooooool0003o0000o`0000?ooooo1?l00004ooooo`Co00001?ooool2o`0000_ooooo0_l0
00000ooooooo0000o`000005o`0000[ooooo6Ol00006ooooo`;o000000?oooooo`000?l000003Ooo
ool2o`0000kooooo0ol0000?ooooo`;o00004?ooool5o`0004Oooooo000Looooo`03o`000?oooooo
oooo04[ooooo1?l00005ooooo`;o00001oooool2o`0000Cooooo0_l00003ooooo`Co00001_ooool2
o`0000Cooooo0_l00009ooooo`Co000000?oooooo`000?l000000_l000000ooooooo0000o`000009
oooooa_o00001Oooool2o`0000[ooooo0_l00004ooooo`;o00000oooool2o`0000?ooooo0_l00004
ooooo`;o00004Oooool2o`0000cooooo0ol00003ooooo`;o0000Aoooool001cooooo00?o0000oooo
ooooool0<Oooool2o`0001Oooooo0_l0000Eooooo`Wo00003_ooool2o`0000Sooooo0_l00003oooo
o`Co00003?oooolLo`0000Gooooo0_l00006ooooo`;o000000?oooooo`000?l000000oooool2o`00
00Cooooo0_l00003ooooo`;o00001_ooool4o`0000gooooo0_l0000<ooooo`?o00004_ooool2o`00
03Sooooo000Looooo`03o`000?oooooooooo037ooooo0_l0000?ooooo`;o00002Oooool2o`0001;o
oooo2Ol00009ooooo`;o00000oooool2o`0000?ooooo0_l000000ooooooo0000o`000005ooooo`Co
00003?oooolFo`0000Cooooo0_l00005ooooo`;o00001_ooool2o`0000Cooooo1?l0000:ooooo`;o
00001Oooool4o`0000_ooooo1?l00004ooooo`?o00000oooool2o`0001Gooooo0_l0000hooooo`00
7?ooool2o`0003[ooooo0_l00007ooooo`;o00001oooool6o`0000Wooooo0_l0000;ooooo`;o0000
2_ooool2o`000003ooooool0003o000000?ooooo1?l000000ooooooo0000o`000004ooooo`Oo0000
2OoooolHo`0000Gooooo0_l0000>ooooo`;o000000?oooooo`000?l000002Oooool2o`000003oooo
ool0003o000000Wooooo0_l00009ooooo`;o00001_ooool4o`0000;ooooo0_l0000Eooooo`;o0000
>?ooool001cooooo00?o0000ooooooooool0>Oooool2o`0000gooooo0_l000000ooooooo0000o`00
0002ooooo`;o00000oooool2o`0000Cooooo0_l0000;ooooo`;o00003Oooool4o`000004ooooool0
003o0000o`0000Kooooo1_l000000ooooooo0000o`000009ooooo`;o000000?oooooo`000?l00000
3_l000000ooooooo0000o`000002o`0000Cooooo0ol000000ooooooo0000o`000008ooooo`;o0000
00?oooooo`000?l000003?ooool2o`0000cooooo0_l0000<ooooo`;o00001?ooool3o`0000Sooooo
1?l0000=ooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0B?ooool3o`0000Gooooo0_l0
0002ooooo`;o00001?ooool4o`0001[ooooo0_l0000:ooooo`?o000000?oooooo`000?l000002ooo
oolGo`0000Kooooo0_l00002ooooo`;o00002?ooool2o`0000Sooooo0_l00006ooooo`;o00005_oo
ool2o`000003ooooool0003o000000;o000000Coooooo`000?l0003o00002Oooool4o`0000kooooo
0_l0000gooooo`007?ooool00ol0003oooooooooo`16ooooo`;o000000?oooooo`000?l000001Ooo
ool2o`0000Sooooo1_l0000Pooooo`;o00000oooool2o`0000?ooooo0_l00009ooooo`Go000000?o
ooooo`000?l000001ol00002ooooo`Go00001?ooool2o`0000[ooooo0_l00006ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0000Kooooo0_l0000<ooooo`;o00001_ooool4o`0000?ooooo0_l0
00000ooooooo0000o`000004ooooo`;o00001_ooool2o`0000kooooo0_l0000gooooo`007?ooool0
0ol0003oooooooooo`0gooooo`;o00001oooool2o`0000?ooooo0ol0000@ooooo`Co00000_ooool2
o`0001Kooooo0_l00002ooooo`;o00001?ooool3o`0000;ooooo1ol00009ooooo`;o00001Oooool9
o`000004ooooool0003o0000ooooo`;o00001?ooool2o`0000Sooooo1?l00006ooooo`Go00000_oo
ool2o`000003ooooool0003o0000017ooooo0_l00002ooooo`;o00000_ooool2o`0000kooooo0_l0
001?ooooo`007?ooool00ol0003oooooooooo`0gooooo`Co00001Oooool2o`0000?ooooo1?l0000>
ooooo`Go00006_ooool2o`0000;ooooo0_l00005ooooo`;o00000_ooool5o`0000gooooo0ol00002
ooooo`;o000000?oooooo`000?l000000_ooool4o`0001;ooooo0_l0000:ooooo`;o00000oooool5
o`0000cooooo0_l00007ooooo`;o0000Hoooool001cooooo00?o0000ooooooooool0>Oooool2o`00
00cooooo0_l00004ooooo`;o00002?ooool2o`0002cooooo1?l000000ooooooo0000o`00000;oooo
o`?o00000_ooool2o`0000Kooooo0ol0000Iooooo`;o00002_ooool4o`0000?ooooo0_l00006oooo
o`Co00005Oooool2o`0000[ooooo0_l000000ooooooo0000o`000014ooooo`007?ooool00ol0003o
ooooooooo`0dooooo`;o00003oooool2o`0000Kooooo0_l0000]ooooo`;o00001oooool7o`0000_o
oooo0ol00002ooooo`;o00001_ooool2o`0001Kooooo0_l00002ooooo`;o00002?ooool2o`0000;o
oooo0_l00003ooooo`;o00000_ooool2o`0000Cooooo0_l00002ooooo`?o00004?ooool2o`0000Ko
oooo0_l00002ooooo`;o000000?oooooo`000?l00000A?ooool001cooooo00?o0000ooooooooool0
=?ooool2o`0000oooooo0_l0000:ooooo`Co00002Oooool2o`0000Cooooo0_l0000Fooooo`;o0000
1oooool7o`0000cooooo0_l00006ooooo`;o00001?ooool2o`0001Cooooo0ol0000;ooooo`;o0000
0_ooool2o`0000Oooooo0_l00008ooooo`?o00003oooool2o`0000?ooooo0_l00002ooooo`;o0000
Boooool001cooooo00?o0000ooooooooool0?oooool2o`00013ooooo1?l00007ooooo`Co00001?oo
ool2o`0000Kooooo0_l0000<ooooo`Co000000?oooooo`000?l000001Oooool6o`0001Cooooo0_l0
0004ooooo`;o00004?ooool2o`000003ooooool0003o000000Co00003Oooool2o`00017ooooo0_l0
0009ooooo`;o00000oooool4o`0000?ooooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`0o
ooooo`?o00000_ooool2o`0001Kooooo1?l00004ooooo`;o00001_ooool2o`0000cooooo0_l00002
ooooo`Co00000oooool7o`0000Oooooo0_l0000<ooooo`?o00001oooool2o`0000_ooooo0_l00000
0ooooooo0000o`000002ooooo`;o00003?ooool2o`0001gooooo0_l00003ooooo`;o0000E_ooool0
01cooooo00?o0000ooooooooool0=Oooool2o`0000Cooooo0_l00003ooooo`;o00000_ooool2o`00
01Sooooo0_l0000Nooooo`Go000000?oooooo`000?l000001_l00007ooooo`;o00003?ooool3o`00
00Gooooo1Ol000000ooooooo0000o`00000Hooooo`;o00000_ooool2o`0000oooooo0_l00007oooo
o`Co00001Oooool2o`0001Cooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0eooooo`;o
000000Coooooo`000?l0003ooooo0_l00002ooooo`?o00004_ooool2o`0000oooooo0_l00002oooo
o`;o00004oooool2o`000004ooooool0003o0000ooooo`Oo00000_ooool2o`0000;ooooo0_l0000<
ooooo`Co000000?oooooo`000?l000000oooool2o`000003ooooool0003o000000?o00002Oooool2
o`000003ooooool0003o000000[ooooo0_l000000ooooooo0000o`00000;ooooo`;o00000oooool3
o`0000Kooooo1?l00002ooooo`;o000000?oooooo`000?l000004oooool3o`00047ooooo000Loooo
o`03o`000?oooooooooo03Sooooo0_l00005ooooo`?o00004?ooool4o`0000oooooo0_l00002oooo
o`;o00001?ooool2o`000003ooooool0003o000000;ooooo0_l00006ooooo`;o000000?oooooo`00
0?l000002?l00002ooooo`;o00000_ooool2o`0000cooooo0ol00002ooooo`;o00000_ooool3o`00
00?ooooo0_l0000:ooooo`;o000000?oooooo`000?l000003Oooool2o`0000_ooooo0_l00004oooo
o`;o00001oooool2o`0000?ooooo0_l00003ooooo`;o00003_ooool2o`000003ooooool0003o0000
04;ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool01?ooool00ol0003oooooooooo`1Booooo`?o00006_ooool2o`000003ooooool0003o
000000;ooooo0_l00005ooooo`;o000000?oooooo`000?l000002Ol0000Aooooo`;o00001?ooool2
o`0000Cooooo0_l0000>ooooo`;o00005oooool5o`0000?ooooo0_l00002ooooo`;o00001oooool2
o`0000Sooooo1?l0000>ooooo`;o0000AOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Ooo
ool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0mooooo`;o00000ooo
ool2o`0001?ooooo1?l0000>ooooo`;o00004_ooool2o`000003ooooool0003o000000So00001Ooo
ool2o`0000_ooooo0_l00004ooooo`?o00001Oooool2o`0000cooooo0ol000000ooooooo0000o`00
000Cooooo`Ko00000_ooool2o`0000;ooooo0_l00005ooooo`Co00001_ooool4o`0000gooooo0_l0
0018ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`Go00001_ooool0
0ol0003oooooooooo`0iooooo`;o00000_ooool2o`0000?ooooo0_l0000Cooooo`Co00000_ooool5
o`0000Oooooo0_l0000Booooo`?o000000Coooooo`000?l0003ooooo1Ol00006ooooo`;o00001?oo
ool3o`0000;ooooo0_l00007ooooo`;o00001Oooool2o`0000Wooooo0ol000000ooooooo0000o`00
0003o`0000[ooooo0_l00003ooooo`?o000000Goooooo`000?l0003o0000ooooo`02o`000004oooo
ool0003o0000ooooo`;o00001oooool2o`0000Sooooo0ol0000>ooooo`;o000000?oooooo`000?l0
0000AOooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?m4A4CogMgM
ooooool00007ooooo`?o0000>Oooool2o`0002;ooooo1Ol00009ooooo`;o00003oooool=o`0000co
oooo0ol00002ooooo`;o00005?ooool2o`0000?ooooo2Ol0000:ooooo`Co000000?oooooo`000?l0
00002ol000000ooooooo0000o`000002ooooo`;o00008Oooool2o`0004Gooooo00000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003o
ooooooooo`0nooooo`;o00006?ooool2o`0000kooooo0_l000000ooooooo0000o`000009ooooo`;o
00000_ooool4o`000003ooooool0003o000000Oo00004_ooool2o`0000Kooooo0_l0000<ooooo`;o
00000oooool2o`000003ooooool0003o000000Co00003?ooool2o`0000Cooooo2ol00004ooooo`;o
00000_ooool2o`0001?ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`0004?o
oooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oMgMgolc<c?l00000
1oooool00ol0003oooooooooo`0nooooo`;o00006?ooool2o`0000kooooo0_l00008ooooo`;o0000
0_oooolAo`0001?ooooo0_l00006ooooo`;o00002Oooool2o`0000Kooooo0_l0000Hooooo`;o0000
00?oooooo`000?l000001ol00003ooooo`;o00000oooool2o`0001?ooooo0_l00002ooooo`?o0000
00?oooooo`000?l000000_ooool2o`0004?ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`co
oooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`1?ooooo`;o00007?ooool2o`0000?o
oooo0_l00004ooooo`oo000000?oooooo`000?l000001_ooool2o`0001Gooooo0_l00004ooooo`;o
00004?ooool2o`000003ooooool0003o000000?ooooo0_l00002ooooo`?o000000?oooooo`000?l0
00002ol00002ooooo`;o000000?oooooo`000?l000003Oooool2o`0000[ooooo0_l00008ooooo`;o
00001?ooool2o`0003_ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`00
0?ooool01_ooool00ol0003oooooooooo`1?ooooo`;o00005oooool2o`0000?ooooo0_l00002oooo
o`;o00000oooool:o`000003ooooool0003o000000?o00000_ooool2o`0000Kooooo0_l00005oooo
o`;o000000?oooooo`000?l000002_ooool4o`000003ooooool0003o000001;ooooo0_l000000ooo
oooo0000o`000003ooooo`;o000000?oooooo`000?l000004_l00003ooooo`;o00003Oooool2o`00
00Cooooo0_l0000>ooooo`;o00001?ooool2o`0003_ooooo000Looooo`03o`000?oooooooooo033o
oooo0_l00006ooooo`;o00005_ooool4o`000003ooooool0003o000000;ooooo0_l0000=ooooo`;o
00001ooooolDo`0000Sooooo0_l00008ooooo`;o000000Coooooo`000?l0003ooooo0ol00006oooo
o`Co000000?oooooo`000?l000001oooool4o`0000oooooo5ol000000ooooooo0000o`000002o`00
01?ooooo0ol0000:ooooo`;o00001oooool2o`0003_ooooo000Looooo`03o`000?oooooooooo02go
oooo0_l000000ooooooo0000o`000006ooooo`;o00000_ooool2o`0000[ooooo1?l00004ooooo`Co
000000?oooooo`000?l000000_ooool2o`0001Kooooo5Ol00007ooooo`;o00003_ooool3o`0001?o
oooo1Ol00004ooooo`Co00002?oooolLo`0001?ooooo0_l0000:ooooo`;o0000A?ooool001cooooo
00?o0000ooooooooool0;Oooool2o`0000gooooo0_l00007ooooo`;o000000?oooooo`000?l00000
1Ol00003ooooo`;o00002_ooool4o`0000Cooooo0_l00006ooooo`;o000000?oooooo`000?l00000
4ol0000?ooooo`;o00002?ooool2o`0000Wooooo0_l00003ooooo`;o000000Goooooo`000?l0003o
0000ooooo`02o`0000Cooooo1_l00002ooooo`;o000000Coooooo`000?l0003ooooo5ol000000ooo
oooo0000o`00000;ooooo`;o0000:Oooool2o`0002gooooo000Looooo`03o`000?oooooooooo03?o
oooo1?l00002ooooo`;o000000Coooooo`000?l0003o00001_ooool2o`0000Cooooo1?l0000?oooo
o`Co00001?ooool2o`0000Cooooo6?l0000?ooooo`Co00002?ooool2o`0000Wooooo0_l000000ooo
oooo0000o`000006o`0000Sooooo0_l000001Ooooooo0000o`000?l0003ooooo00Go000000?ooooo
o`000?l000005_l000000ooooooo0000o`000002o`0000Sooooo0_l00008ooooo`;o00000oooool2
o`0000Sooooo0_l000000ooooooo0000o`00000=ooooo`;o0000;Oooool001cooooo00?o0000oooo
ooooool0<oooool4o`0000;ooooo0_l000001?oooooo0000o`000?l00006ooooo`;o00001?ooool2
o`000003ooooool0003o000001cooooo5_l0000Aooooo`;o00002Oooool2o`0000Sooooo1?l00000
0ooooooo0000o`000003o`0000_ooooo0_l00002ooooo`;o000000?oooooo`000?l000000ol00000
0ooooooo0000o`00000>o`000003ooooool0003o000000Go000000?oooooo`000?l000000_l0000B
ooooo`?o00000_ooool2o`0000Sooooo0_l000000ooooooo0000o`00000looooo`007?ooool00ol0
003oooooooooo`0^ooooo`;o00004oooool2o`0000Kooooo0_l000000ooooooo0000o`00000Ioooo
o`[o000000?oooooo`000?l000003?l00009ooooo`;o00001?ooool2o`0000;ooooo0_l00007oooo
o`;o00002?ooool4o`000003ooooool0003o000000;o00004?ooool2o`0000;ooooo8_l00002oooo
o`;o00000oooool2o`0000[ooooo0_l00004ooooo`;o00001_ooool2o`0003oooooo000Looooo`03
o`000?oooooooooo02kooooo0_l00002ooooo`;o00002_ooool2o`000003ooooool0003o000000;o
00001?ooool4o`000003ooooool0003o000001;ooooo0_l00003oooooa[o00002_ooool2o`0000?o
oooo0ol00002ooooo`Co00003oooool2o`0000;ooooo1?l00002ooooo`;o00002Oooool2o`000004
ooooool0003o0000o`0000;ooooo8_l00002ooooo`Co000000?oooooo`000?l000004?ooool2o`00
00Kooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0booooo`;o00002_ooool2o`000003
ooooool0003o000000Kooooo0_l00003ooooo`;o00003?ooool2o`0000Cooooo0_l00003oooooa[o
00002Oooool2o`0000Cooooo0_l00005ooooo`;o00004oooool4o`0000;ooooo0_l000000ooooooo
0000o`000006ooooo`;o000000Coooooo`000?l0003o00000_oooolLo`000003ooooool0003o0000
00Co00000oooool2o`0001_ooooo1?l0000mooooo`007?ooool00ol0003oooooooooo`0iooooo`;o
00000oooool2o`0000Wooooo0_l000000ooooooo0000o`000002o`0000Wooooo0_l000000ooooooo
0000o`000003ooooo`Co00000ooooolHo`0000Cooooo0_l00002ooooo`Go00001Oooool2o`0000oo
oooo0_l00005ooooo`;o00001_ooool2o`000003ooooool0003o000000Wooooo0ol00003ooooo`go
000000?oooooo`000?l000002ol00003ooooo`Co00008?ooool4o`00013ooooo0_l0000[ooooo`00
7?ooool00ol0003oooooooooo`0fooooo`;o000000Coooooo`000?l0003ooooo1?l00003ooooo`;o
00001_ooool3o`0000_ooooo0ol00005oooooako00000oooool4o`0000;ooooo0_l000000ooooooo
0000o`000002o`0000;ooooo0ol00006ooooo`;o00001oooool2o`0000Gooooo0_l00006ooooo`?o
000000?oooooo`000?l000003?ooool?o`000003ooooool0003o000000_o00009Oooool4o`0001;o
oooo0_l0000[ooooo`007?ooool00ol0003oooooooooo`0fooooo`;o000000Coooooo`000?l0003o
oooo0_l00005ooooo`Go00000oooool2o`0000gooooo0_l00008oooooa[o000000Coooooo`000?l0
003ooooo0_l00009ooooo`;o000000Coooooo`000?l0003o00001oooool2o`0001Cooooo0_l00000
1?oooooo0000o`000?ooool2o`0000cooooo3_l000000ooooooo0000o`00000>o`0001Cooooo0_l0
000=ooooo`Co0000?oooool001cooooo0_l0000mooooo`;o00001?ooool8o`0000;ooooo0_l0000<
ooooo`;o00001ooooolJo`0000;ooooo0_l0000?ooooo`?o00001Oooool2o`0000Oooooo0_l0000=
ooooo`Co00003_ooool2o`000003ooooool0003o000001co00003_ooool4o`0000;ooooo0_l00006
ooooo`;o00002?ooool4o`0000Wooooo0_l0000aooooo`007?ooool00ol0003oooooooooo`0goooo
o`;o00000oooool2o`0000Cooooo0_l00004ooooo`;o00000_ooool2o`0000cooooo0_l00007oooo
oaSo00001Oooool2o`0000;ooooo0_l00003ooooo`;o00001_ooool4o`0000?ooooo0_l00007oooo
o`;o000000?oooooo`000?l000002_ooool4o`000003ooooool0003o000000_ooooo4Ol000000ooo
oooo0000o`00000=o`0000kooooo1Ol000000ooooooo0000o`000006ooooo`;o00002?ooool4o`00
00Wooooo0_l00007ooooo`;o0000:?ooool001cooooo00?o0000ooooooooool0=oooool2o`00027o
oooo0_l00006ooooo`Oo000000?oooooo`000?l000003ol00005ooooo`?o000000?oooooo`000?l0
00000oooool3o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000[ooooo0ol00009ooooo`;o
000000?oooooo`000?l000001?l00009ooooob7o00001Oooool2o`000003ooooool0003o000000Oo
oooo0_l000000ooooooo0000o`000008ooooo`Oo00000oooool2o`0000oooooo0_l000000ooooooo
0000o`00000Xooooo`007?ooool00ol0003oooooooooo`0jooooo`;o00007?ooool2o`0000Sooooo
3ol000000ooooooo0000o`000007o`0000Cooooo1_l00005ooooo`;o00000oooool2o`0000Oooooo
0_l0000;ooooo`?o00001oooool2o`0000;ooooo0_l00002ooooo`Co00001Oooool4o`000004oooo
ool0003o0000oooooa[o00001_ooool2o`000003ooooool0003o000001Cooooo1ol00003ooooo`;o
000000?oooooo`000?l000003?ooool3o`0002[ooooo000Looooo`03o`000?oooooooooo03Oooooo
0_l000000ooooooo0000o`000007ooooo`;o00004?ooool2o`000003ooooool0003o000000;o0000
1_oooolGo`0000Cooooo2?l00009ooooo`;o00001Oooool2o`0000oooooo0_l00004ooooo`Go0000
0oooool2o`0000?ooooo0_l00002ooooo`Go00000_ooool3o`000003ooooool0003o000001So0000
4Oooool2o`0000Gooooo0_l0000?ooooo`Go00003Oooool2o`0002[ooooo000Looooo`03o`000?oo
oooooooo03Oooooo0_l0000:ooooo`;o00000oooool2o`0000_ooooo0_l00003ooooo`?o00001?oo
oolGo`0000Gooooo0_l00002ooooo`;o00002oooool2o`0000Gooooo0_l0000>ooooo`;o00001?oo
ool5o`0000Cooooo0_l00007ooooo`Co000000?oooooo`000?l000000ol000000ooooooo0000o`00
0004o`0000;ooooo1_l000000ooooooo0000o`00000:o`00013ooooo0ol00004ooooo`;o00003ooo
ool3o`0000gooooo0_l0000/ooooo`007?ooool00ol0003oooooooooo`0nooooo`;o000000?ooooo
o`000?l000001?ooool3o`0000cooooo0_l00003ooooo`;o00001?oooolGo`0000gooooo0_l00004
ooooo`;o00004_ooool2o`0000Cooooo0_l00004ooooo`Go00001Oooool2o`0000?ooooo0_l00005
ooooo`?o000000Coooooo`000?l0003ooooo5?l000000ooooooo0000o`000004o`000004ooooool0
003o0000ooooo`;o00002oooool2o`0000Cooooo0_l0000=ooooo`;o00004?ooool2o`0002cooooo
000Looooo`03o`000?oooooooooo03kooooo0_l000000ooooooo0000o`000004ooooo`;o00002_oo
ool2o`000003ooooool0003o000000Wooooo4Ol000001Ooooooo0000o`000?l0003ooooo00;o0000
3?ooool2o`0000Cooooo0_l0000@ooooo`Co00002?ooool2o`0000?ooooo0_l00005ooooo`?o0000
00?oooooo`000?l000000_l000000ooooooo0000o`000007o`000004ooooool0003o0000oooooaSo
000000Coooooo`000?l0003ooooo0_l0000Cooooo`;o00002oooool2o`0000?ooooo0_l0000ioooo
o`007?ooool00ol0003oooooooooo`0gooooo`Co00003?ooool2o`0000Wooooo0ol00008oooooaGo
000000Goooooo`000?l0003o0000ooooo`02o`0002Cooooo0_l0000:ooooo`;o00001?ooool2o`00
0003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o0000
00;o00000_ooool3o`000003ooooool0003o000000ko000000?oooooo`000?l000001_l00003oooo
o`?o00000oooool2o`000003ooooool0003o000000gooooo0_l00008ooooo`;o00001_ooool2o`00
03Wooooo000Looooo`03o`000?oooooooooo03Cooooo0_l000000ooooooo0000o`000002o`0000co
oooo0_l00004ooooo`;o00000oooool2o`0000Gooooo0_l00002oooooaSo00003?ooool2o`0001Co
oooo0_l0000>ooooo`;o00001_ooool2o`000003ooooool0003o000000;ooooo0_l0000=ooooo`;o
00000_ooool?o`000004ooooool0003o0000o`0000?ooooo0_l00004ooooo`;o00000oooool2o`00
0003ooooool0003o000000?ooooo0_l00006ooooo`;o00000_ooool2o`0000Kooooo0ol00010oooo
o`007?ooool00ol0003oooooooooo`0dooooo`Co00001Oooool2o`0000kooooo0_l0000:ooooo`;o
00001?oooolEo`0000gooooo0_l0000Dooooo`;o00003_ooool3o`0000cooooo0_l00004ooooo`;o
000000?oooooo`000?l000001?oooolCo`0000;ooooo1_l0000>ooooo`;o00000_ooool2o`0000Ko
oooo0_l00002ooooo`;o00001oooool2o`00043ooooo000Looooo`03o`000?oooooooooo01kooooo
0_l0000>ooooo`;o00001_ooool2o`0000Gooooo0_l0000>ooooo`;o00004?oooolAo`000003oooo
ool0003o000002Wooooo0_l00005ooooo`;o00000oooool2o`0000kooooo0_l00002ooooo`;o0000
00?oooooo`000?l000000oooool6o`000003ooooool0003o000000[o00001?ooool5o`0000kooooo
0_l00005ooooo`;o00002?ooool2o`0000Cooooo0_l0000Eooooo`;o0000:oooool001cooooo00?o
0000ooooooooool07_ooool2o`0000kooooo0_l0000>ooooo`;o00001Oooool2o`0000?ooooo0_l0
0006ooooo`;o00002ooooolBo`0001Oooooo0_l0000Booooo`;o00001?ooool3o`0000kooooo0_l0
0002ooooo`?o00002_ooool2o`0000Oooooo3?l00003ooooo`;o000000?oooooo`000?l000002Ooo
ool2o`0000Wooooo0_l00008ooooo`;o00001?ooool6o`00017ooooo0_l000000ooooooo0000o`00
000Xooooo`007?ooool00ol0003oooooooooo`0nooooo`;o000000?oooooo`000?l000000_ooool2
o`0000?ooooo0_l00005ooooo`?o00002ooooolBo`0000[ooooo0_l0000;ooooo`;o00004Oooool2
o`0000Gooooo0_l00007ooooo`;o00000_ooool2o`0000;ooooo0_l00002ooooo`?o00001Oooool3
o`0000Gooooo0_l00002ooooo`;o00000oooool6o`000003ooooool0003o000000Cooooo1?l00009
ooooo`;o00006oooool4o`0001Cooooo0_l0000Xooooo`007?ooool00ol0003oooooooooo`0eoooo
o`;o00002_ooool6o`0000[ooooo0_l00002ooooo`;o00002Oooool8o`000003ooooool0003o0000
00;o000000?oooooo`000?l000000oooool4o`0000Cooooo0_l0000Nooooo`?o00002oooool4o`00
00;ooooo0_l00007ooooo`;o00001Oooool3o`0000Gooooo0_l00002ooooo`;o00000_ooool2o`00
0004ooooool0003o0000ooooo`;o00001_ooool4o`0000Kooooo0_l00003ooooo`;o00007_ooool2
o`0003_ooooo000Looooo`03o`000?oooooooooo033ooooo0_l00003ooooo`;o00001oooool2o`00
0003ooooool0003o000000;o00003_ooool4o`0000Oooooo1Ol000000ooooooo0000o`000002o`00
0003ooooool0003o000000;o000000?oooooo`000?l000000_l000000ooooooo0000o`000004o`00
00Gooooo0_l0000Dooooo`;o00001?ooool4o`0000_ooooo0_l00002ooooo`;o00002_ooool2o`00
013ooooo0_l00002ooooo`;o000000?oooooo`000?l000000ol00008ooooo`;o00001_ooool2o`00
00?ooooo0_l0000Gooooo`;o00001Oooool2o`0003_ooooo000Looooo`;o0000<Oooool2o`0000co
oooo0_l0000Cooooo`;o00000oooool2o`0000Cooooo3ol00003ooooo`;o00001?ooool3o`0000Go
oooo0_l0000Booooo`Co00001?ooool3o`0000cooooo0_l00002ooooo`;o00002_ooool2o`0000go
oooo0_l000000ooooooo0000o`000005ooooo`?o00007?ooool2o`0001;ooooo0_l00012ooooo`00
7?ooool00ol0003oooooooooo`0[ooooo`;o0000:oooool2o`0000Gooooo3ol00008ooooo`;o0000
6_ooool2o`0000Cooooo0_l000000ooooooo0000o`000003o`0000Wooooo0_l00005ooooo`;o0000
2_ooool2o`0000;ooooo0_l00006ooooo`;o00006_ooool2o`0000Cooooo1?l00002ooooo`Go0000
0oooool2o`0001Gooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0Pooooo`;o00002Ooo
ool2o`0001[ooooo0_l00006ooooo`?o00003Oooool<o`000003ooooool0003o000000kooooo0_l0
000Booooo`;o00001_ooool2o`0000?ooooo1?l000000ooooooo0000o`000005ooooo`;o00001Ooo
ool2o`0000Gooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00004ooooo`;o00003?oo
ool2o`000003ooooool0003o000000_ooooo1Ol000000ooooooo0000o`000003o`000004ooooool0
003o0000ooooo`;o00000oooool2o`0000gooooo0_l00006ooooo`;o0000>?ooool001cooooo00?o
0000ooooooooool08?ooool2o`0000Wooooo0_l0000Jooooo`;o00001_ooool3o`0000kooooo0ol0
0002ooooo`Go00002oooool2o`0000Gooooo0_l0000:ooooo`;o00001_ooool2o`0000[ooooo0_l0
00001?oooooo0000o`000?ooool2o`0000Gooooo0_l0000<ooooo`;o000000?oooooo`000?l00000
2_ooool3o`0000Gooooo0_l00004ooooo`;o000000?oooooo`000?l000001_ooool2o`0000;ooooo
1_l00003ooooo`?o00000oooool2o`0000Sooooo0_l00005ooooo`;o00000_ooool2o`0000Sooooo
0_l0000fooooo`007?ooool00ol0003oooooooooo`0[ooooo`Go00003_ooool2o`000003ooooool0
003o000000cooooo0_l00009ooooo`;o00000oooool3o`0000Cooooo1?l00004ooooo`;o00001Ooo
ool2o`00017ooooo0_l00002ooooo`;o00000oooool2o`0000Wooooo0_l00006ooooo`;o00004Ooo
ool4o`000003ooooool0003o000000Sooooo0ol00003ooooo`Co00003Oooool4o`0000;ooooo0_l0
0007ooooo`;o00000oooool3o`0000Sooooo0_l00005ooooo`;o00000oooool2o`0000Gooooo1?l0
000fooooo`007?ooool00ol0003oooooooooo`0]ooooo`?o00003_ooool2o`000003ooooool0003o
000001Oooooo0_l00003ooooo`Ko000000?oooooo`000?l000001_ooool3o`0000Wooooo0_l0000@
ooooo`;o00000oooool2o`00013ooooo0ol00002ooooo`;o00003Oooool4o`000003ooooool0003o
000000Oooooo0_l00004ooooo`?o00003oooool2o`0000?ooooo0_l000000ooooooo0000o`000009
ooooo`?o00001_ooool2o`000003ooooool0003o000000;o00000oooool2o`0000?ooooo0ol00004
ooooo`?o0000=oooool001cooooo00?o0000ooooooooool0??ooool2o`0000Oooooo0_l00004oooo
o`;o00003_ooool2o`0000?ooooo1Ol0000:ooooo`;o00001Oooool2o`0000;ooooo0_l00006oooo
o`;o00002Oooool2o`0001Cooooo0_l00003ooooo`Go00002_ooool2o`0000cooooo0_l00004oooo
o`;o00004?ooool2o`0000?ooooo0_l000000ooooooo0000o`000009ooooo`;o00001?ooool2o`00
0003ooooool0003o000000;ooooo0ol00009ooooo`;o00001Oooool2o`0000oooooo0_l0000Voooo
o`007?ooool00ol0003oooooooooo`0Xooooo`;o00002_ooool2o`0000Kooooo0_l00007ooooo`?o
00000oooool2o`0000kooooo0_l00003ooooo`Co00001_ooool2o`0000[ooooo0_l0000:ooooo`;o
00002Oooool2o`0000Oooooo0ol00005ooooo`;o00002Oooool4o`0000;ooooo0_l0000>ooooo`;o
00000oooool2o`00017ooooo0_l00004ooooo`;o000000?oooooo`000?l000002Oooool6o`0000Go
oooo0_l00005ooooo`;o00001_ooool2o`0000;ooooo0_l0000Fooooo`;o00009_ooool001cooooo
00?o0000ooooooooool0:?ooool2o`0000[ooooo0_l0000@ooooo`;o00000oooool2o`0001Cooooo
0_l00007ooooo`;o00002_ooool2o`0000_ooooo0_l0000Aooooo`?o00001Oooool2o`0000Oooooo
0_l00005ooooo`?o00001Oooool2o`0000Oooooo0_l00002ooooo`?o00004Oooool4o`0000;ooooo
0_l000000ooooooo0000o`000009ooooo`Ko00003Oooool2o`0000Gooooo0_l00009ooooo`;o0000
=oooool001cooooo00?o0000ooooooooool0@_ooool2o`0000;ooooo0_l00003ooooo`;o00002_oo
ool2o`0000Wooooo0_l00005ooooo`;o00006?ooool2o`0000Oooooo0_l0000Booooo`?o00000_oo
ool4o`000003ooooool0003o000000Co000000?oooooo`000?l000000oooool2o`0000;ooooo1?l0
0003ooooo`Co00001_ooool2o`000004ooooool0003o0000o`0000Gooooo0_l000000ooooooo0000
o`000002ooooo`?o00004Oooool2o`0000_ooooo0_l000000ooooooo0000o`000005ooooo`;o0000
0oooool2o`000003ooooool0003o000003Oooooo000Looooo`03o`000?oooooooooo04;ooooo0_l0
000:ooooo`;o00001oooool2o`0000Oooooo1?l00005ooooo`;o00007_ooool2o`000003ooooool0
003o0000017ooooo1?l00002ooooo`;o00000oooool9o`0000;ooooo1?l000000ooooooo0000o`00
0002o`0000?ooooo0_l00005ooooo`Go000000Coooooo`000?l0003o00001Oooool2o`0000Kooooo
0_l00004ooooo`;o00001_ooool2o`0000?ooooo0ol00003ooooo`;o00002?ooool2o`0000Gooooo
0_l00003ooooo`;o00000_ooool2o`0003Kooooo000Looooo`03o`000?oooooooooo04kooooo0_l0
000@ooooo`;o00008oooool2o`0000;ooooo0_l00005ooooo`;o00003Oooool4o`000004ooooool0
003o0000ooooo`;o000000?oooooo`000?l000003Ol00004ooooo`;o00002?ooool4o`0000Wooooo
0_l00002ooooo`;o00002_ooool2o`000003ooooool0003o000000?ooooo0_l00004ooooo`;o0000
0oooool4o`0001Kooooo0_l0000fooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00002ooo
ool2o`0000_ooooo0_l0000Booooo`;o00005oooool2o`0000cooooo0_l00002ooooo`;o00001Ooo
ool2o`0000_ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o000000Coooooo`000?l0003o
oooo1_l000000ooooooo0000o`000004o`000003ooooool0003o000000?ooooo1?l00006ooooo`;o
00002oooool2o`0000;ooooo0_l0000=ooooo`;o00000oooool2o`0000_ooooo0_l0000=ooooo`?o
000000?oooooo`000?l000005Oooool2o`0002Cooooo000Looooo`03o`000?oooooooooo033ooooo
0_l00009ooooo`Co00002oooool2o`00013ooooo1?l0000Gooooo`;o00003Oooool2o`0000?ooooo
0_l0000?ooooo`?o00000oooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool3o`000003
ooooool0003o000000Oo00000_ooool2o`000003ooooool0003o000001Gooooo0_l00003ooooo`;o
00000_ooool2o`0000Oooooo0_l00002ooooo`;o00006_ooool3o`000003ooooool0003o000001Go
oooo0_l0000Tooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00002Oooool2o`0001oooooo
0_l0000Iooooo`;o00003Oooool2o`0000?ooooo0_l0000?ooooo`;o00001?ooool5o`0000;ooooo
0ol000001?oooooo0000o`000?l00002ooooo`Ko000000Coooooo`000?l0003ooooo0ol0000Goooo
o`;o00000oooool2o`0000;ooooo0_l00007ooooo`?o00003?ooool2o`000003ooooool0003o0000
04gooooo000Looooo`03o`000?oooooooooo03_ooooo0_l0000Kooooo`;o00005_ooool2o`0000;o
oooo0_l000000ooooooo0000o`00000Looooo`;o00001_ooool2o`0000Gooooo1?l000000ooooooo
0000o`000006o`000003ooooool0003o000000?o00000_ooool6o`0001Kooooo0_l0000?ooooo`;o
000000?oooooo`000?l000003?ooool2o`000003ooooool0003o000000;o0000Boooool001cooooo
0_l0001<ooooo`;o00002oooool2o`0000oooooo0ol00004ooooo`;o00000_ooool3o`0001Kooooo
0_l00006ooooo`;o00000_ooool2o`0000;ooooo0_l00006ooooo`Go000000?oooooo`000?l00000
3?l000000ooooooo0000o`000002o`0000;ooooo0_l00008ooooo`;o000000?oooooo`000?l00000
1_ooool2o`0000oooooo0_l00007ooooo`;o00002oooool2o`0004_ooooo000Looooo`03o`000?oo
oooooooo02kooooo0_l0000Kooooo`;o00001Oooool2o`0001Gooooo0ol00002ooooo`?o00001?oo
ool2o`0000?ooooo0_l0000Aooooo`;o00002_ooool4o`0000Gooooo0ol000000ooooooo0000o`00
0007o`000003ooooool0003o000000?o000000Coooooo`000?l0003o00000_ooool2o`0000?ooooo
0_l00008ooooo`Go00005_ooool2o`0000?ooooo0_l00003ooooo`;o0000F?ooool001cooooo00?o
0000ooooooooool0;_ooool2o`000004ooooool0003o0000o`0001Oooooo0_l00005ooooo`;o0000
3Oooool2o`0000;ooooo0_l00004ooooo`;o000000Coooooo`000?l0003o00002Oooool2o`0000Ko
oooo0_l00007ooooo`;o00001Oooool2o`0000Kooooo0ol000001Ooooooo0000o`000?l0003ooooo
01So000000?oooooo`000?l000000_ooool2o`0000Oooooo0_l000000ooooooo0000o`000008oooo
o`;o000000?oooooo`000?l000001Oooool2o`0000Cooooo0_l00003ooooo`;o00000oooool2o`00
00?ooooo0_l00004ooooo`;o00002oooool2o`00043ooooo000Looooo`03o`000?oooooooooo037o
oooo0ol0000Gooooo`;o00003oooool2o`0000?ooooo0_l00002ooooo`;o00001?ooool2o`0000?o
oooo0_l0000;ooooo`Co000000?oooooo`000?l000001oooool2o`0000Gooooo0_l00006ooooo`;o
00000_oooolLo`0000Gooooo0_l00002ooooo`;o00000oooool2o`0000Oooooo0_l00002ooooo`;o
000000?oooooo`000?l000001Oooool3o`00017ooooo0ol000001?oooooo0000o`000?ooool2o`00
00_ooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0Zooooo`;o0000<?ooool3o`0000;o
oooo0_l0000=ooooo`;o00002oooool7o`0001Kooooo0_l00003oooooa[o00000oooool2o`0000Go
oooo0_l0000<ooooo`Co00002_ooool3o`00017ooooo0_l00002ooooo`;o00002?ooool2o`0000Co
oooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0Zooooo`;o00001?ooool4o`0002Wooooo
0_l0000Kooooo`;o000000Coooooo`000?l0003ooooo0ol00006ooooo`;o00002_ooool2o`000003
ooooool0003o000000?ooooo1Ol000001?oooooo0000o`000?oooolHo`0001Gooooo0_l0000:oooo
o`?o00002Oooool2o`0000Wooooo0_l00007ooooo`Co00001?ooool2o`0000;ooooo0_l0000loooo
o`007?ooool00ol0003oooooooooo`0Pooooo`;o00003_ooool4o`00013ooooo0_l0000Yooooo`?o
00002?ooool4o`0000;ooooo0_l00007ooooo`;o00002_ooool2o`000003ooooool0003o000000;o
oooo6ol000000ooooooo0000o`000003o`000003ooooool0003o000000Kooooo0_l00002ooooo`;o
00005?ooool2o`0000?ooooo0_l00004ooooo`Co00001?ooool2o`000003ooooool0003o000000?o
oooo0_l000001?oooooo0000o`000?l00006ooooo`;o00000_ooool2o`0003cooooo000Looooo`03
o`000?oooooooooo023ooooo0_l0000>ooooo`;o00004_ooool2o`0000Sooooo1?l0000Mooooo`?o
000000?oooooo`000?l000001oooool6o`0000Sooooo0_l00002ooooo`;o00001?ooool5o`0000?o
oooo1ol000001Ooooooo0000o`000?l0003ooooo01;o00000oooool3o`000003ooooool0003o0000
00?ooooo0_l00002ooooo`;o00002_ooool2o`0000Sooooo0_l00003ooooo`;o00001_ooool3o`00
0003ooooool0003o000000;o00001_ooool2o`000003ooooool0003o000000;o000000?oooooo`00
0?l000000_ooool2o`0001Wooooo0_l0000Uooooo`007?ooool00ol0003oooooooooo`1>ooooo`Co
00008?ooool3o`0000Wooooo1?l00008ooooo`;o00000_ooool2o`0000;ooooo2ol000000ooooooo
0000o`000002o`000003ooooool0003o000000?o000000?oooooo`000?l000004Ol000001Ooooooo
0000o`000?l0003ooooo00;o00004oooool2o`0000;ooooo0_l0000Booooo`;o000000?oooooo`00
0?l000002_ooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000;ooooo0_l0000E
ooooo`;o00009Oooool001cooooo00?o0000ooooooooool0;_ooool2o`0001oooooo0_l0000<oooo
o`;o00000_ooool2o`0000;ooooo0_l0000;ooooo`;o00002oooool2o`0000cooooo0_l00003oooo
o`;o00000_ooool7o`000005ooooool0003o0000o`000?ooool04?l00002ooooo`So000000?ooooo
o`000?l000000_l00008ooooo`;o00003oooool2o`0001;ooooo0_l0000=ooooo`;o00001?ooool2
o`0000;ooooo0_l00002ooooo`Co00005?ooool2o`0002Cooooo000Looooo`03o`000?oooooooooo
02kooooo0_l00003ooooo`;o00002_ooool2o`0001cooooo0_l00002ooooo`;o00000_ooool2o`00
01Gooooo0_l0000?ooooo`;o00000oooool2o`0000Cooooo1Ol000000ooooooo0000o`00000Jo`00
00;ooooo1Ol00005ooooo`;o000000?oooooo`000?l000008oooool2o`0001?ooooo0_l00008oooo
o`;o00005?ooool2o`0002Cooooo000Looooo`03o`000?oooooooooo02kooooo0_l00003ooooo`;o
00002_ooool2o`0000Oooooo0ol0000Hooooo`;o00000_ooool4o`0000Gooooo0_l00009ooooo`?o
00001?ooool2o`0000kooooo0_l00004ooooo`Go000000?oooooo`000?l000006ol000001?oooooo
0000o`000?ooool2o`0000Gooooo0_l0000^ooooo`;o00000oooool2o`0000Oooooo0_l00013oooo
o`007?ooool00ol0003oooooooooo`0^ooooo`;o00006?ooool3o`0001Sooooo2?l00005ooooo`Co
00001oooool2o`0000;ooooo0_l000000ooooooo0000o`00000>ooooo`;o00001?oooolVo`000003
ooooool0003o000003Gooooo0_l00003ooooo`;o00001oooool2o`0000;ooooo0_l0000oooooo`00
7?ooool00ol0003oooooooooo`1Pooooo`Oo00000_ooool2o`0000;ooooo0_l00003ooooo`;o0000
00?oooooo`000?l000001Oooool2o`000003ooooool0003o000000Sooooo0_l0000<ooooo`?o0000
0_oooolLo`000005ooooool0003o0000o`000?ooool01?l0000fooooo`Go00002?ooool2o`0000;o
oooo0_l0000oooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^
k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0H?ooool6o`0000?ooooo0_l00002
ooooo`;o00001_ooool2o`0000Gooooo0_l0000;ooooo`;o00002_ooool5o`0000?ooooo9_l00006
ooooo`;o00009oooool2o`0000?ooooo1Ol0000:ooooo`;o0000@Oooool00006oooooomgMgOoV9RH
oooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`00
0?oooooooooo02[ooooo0_l0000Jooooo`;o00000_ooool2o`00017ooooo1Ol000000ooooooo0000
o`000004o`0000?ooooo0_l00005ooooo`;o00002?ooool2o`0000;ooooo0_l0000>ooooo`;o0000
0_ooool4o`0000Cooooo9_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l00000
8_ooool4o`0001;ooooo0_l00011ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Zooooo`;o0000
6_ooool2o`0000;ooooo0_l0000<ooooo`;o000000?oooooo`000?l000003?l00003ooooo`;o0000
1Oooool2o`0000?ooooo0_l00003ooooo`;o00000_ooool2o`0000gooooo0ol00004ooooo`;o0000
0ooooolBo`000003ooooool0003o000000oo00001?ooool2o`000003ooooool0003o000000?ooooo
0_l0000Mooooo`;o00000oooool2o`0001Kooooo0_l0000oooooo`0000?oooooo`000?ooool00_oo
ool00ol0003oooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0005Gooooo
0_l000001?oooooo0000o`000?ooool@o`0000Sooooo0_l00003ooooo`;o000000?oooooo`000?l0
00001_ooool2o`0000[ooooo1Ol00003ooooo`ko000000?oooooo`000?l000005ol00008ooooo`;o
00008_ooool2o`0001?ooooo0_l00006ooooo`;o0000?oooool00003ooooool0003ooooo00;ooooo
00?o0000ooooooooool02Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000oooooooo
ool0:oooool2o`0001Wooooo0_l0000=ooooo`;o000000?oooooo`000?l000004ol00008ooooo`?o
00000_ooool3o`0000Kooooo0_l0000:ooooo`;o000000?oooooo`000?l000000ooooolYo`0000?o
oooo0_l00002ooooo`;o00009Oooool2o`00013ooooo0ol00016ooooo`0000?ooooooa0@4?ooool0
0_ooool00ol@413oooooooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0
:oooool2o`0001Wooooo0_l0000:ooooo`;o00001?oooolGo`0000Kooooo0ol00002ooooo`;o0000
1_ooool2o`0001Cooooo8_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l0000Yooooo`;o
00000_ooool2o`0000Gooooo0_l00006ooooo`;o0000A_ooool00006oooooomgMgOoV9RHoooooonH
V9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo02[ooooo0_l0000Voooo
o`;o00001?oooolGo`0000_ooooo0_l00006ooooo`;o00001oooool2o`0000Sooooo0_l000000ooo
oooo0000o`00000Xo`000003ooooool0003o000000Cooooo0_l00005ooooo`;o00006?ooool2o`00
00Kooooo0_l00005ooooo`;o0000C_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool0
1?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo02[ooooo0_l0000Uooooo`;o00001?oo
ool5o`000003ooooool0003o000000oo00003?ooool2o`0000oooooo0_l00008ooooob7o000000?o
ooooo`000?l000002_l00006ooooo`;o00001Oooool2o`0001Sooooo0_l0000;ooooo`;o00001Ooo
ool3o`0000Kooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00008Oooool2
o`0000Cooooo6?l0000;ooooo`;o00003oooool2o`0000Wooooo:?l000000ooooooo0000o`000002
o`0000Cooooo0_l0000Qooooo`;o00001?ooool2o`0000Gooooo0_l00005ooooo`?o00001_ooool2
o`00043ooooo000Looooo`03o`000?oooooooooo02kooooo0_l00002ooooo`;o00008ooooolKo`00
00Sooooo0_l0000?ooooo`;o00001oooool4o`0000;ooooo9ol00006ooooo`Ko00006_ooool2o`00
00Oooooo0_l0000>ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0<_ooool2o`0000[o
oooo0_l0000Gooooo`go000000?oooooo`000?l000001_l000000ooooooo0000o`000002o`0000Go
oooo0_l0000Kooooo`Co00000_ooool@o`0000;ooooo4Ol000000ooooooo0000o`000003o`0000Go
oooo1Ol0000Jooooo`;o00001_ooool2o`0000gooooo1?l00017ooooo`007?ooool00ol0003ooooo
ooooo`0Uooooo`;o00005oooool2o`0001Kooooo5ol00008ooooo`Co00001?ooool2o`0000Sooooo
0_l00008ooooo`?o00000_ooool2o`0000;ooooo4?l000000ooooooo0000o`00000@o`000003oooo
ool0003o000000?o0000;?ooool3o`0000Cooooo0_l00006ooooo`;o00000oooool2o`0004Cooooo
000Looooo`03o`000?oooooooooo02Gooooo0_l0000Cooooo`;o000000?oooooo`000?l000005ooo
oolGo`0000Sooooo1?l00004ooooo`Co00001_ooool3o`0000Oooooo0ol00002ooooo`;o00001?oo
oolPo`000003ooooool0003o000000;ooooo0_l0000]ooooo`;o00001?ooool2o`0000_ooooo0_l0
0014ooooo`007?ooool00ol0003oooooooooo`0jooooo`;o000000?oooooo`000?l000005ooooolF
o`0000_ooooo0_l00006ooooo`;o00001Oooool4o`0000?ooooo0_l00002ooooo`;o00002OoooolP
o`000003ooooool0003o000000;ooooo0_l0000=ooooo`;o0000:?ooool2o`0000?ooooo0_l00018
ooooo`007?ooool00ol0003oooooooooo`1FoooooaOo000000?oooooo`000?l000005_ooool2o`00
00Gooooo0_l00002ooooo`?o00002_oooolTo`0000Wooooo0_l00003ooooo`?o00005Oooool4o`00
00kooooo0_l00003ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0EooooolFo`000003
ooooool0003o000000kooooo0_l0000Booooo`;o00000_ooool9o`000003ooooool0003o0000023o
00002Oooool2o`0000Cooooo0_l0000Eooooo`Co00002Oooool2o`0000Sooooo0_l00018ooooo`00
7?ooool00ol0003oooooooooo`0fooooo`Co00007OoooolFo`000004ooooool0003o0000o`0000?o
oooo0ol00007ooooo`;o00003_ooool2o`0000;ooooo0_l000000ooooooo0000o`000008o`000003
ooooool0003o000001ko00001?ooool2o`0002oooooo0_l00008ooooo`;o00006Oooool2o`0002go
oooo000Looooo`03o`000?oooooooooo03Kooooo1?l0000Noooooa7o000000Coooooo`000?l0003o
00000_ooool2o`0000?ooooo0ol00002ooooo`;o00002?ooool2o`0000;ooooo0_l00004ooooo`?o
00000_ooool2o`000003ooooool0003o000000Cooooo0ol00002oooooago000000?oooooo`000?l0
00001?ooool2o`0000Oooooo0_l0000Dooooo`;o00000oooool2o`00033ooooo0_l0000]ooooo`00
7?ooool00ol0003oooooooooo`1Ioooooa3o000000Coooooo`000?l0003o00001_ooool4o`0000;o
oooo0_l000000ooooooo0000o`000005ooooo`;o00000_ooool2o`0000;ooooo1?l00002ooooo`;o
00000_ooool2o`000004ooooool0003o0000oooooako000000?oooooo`000?l000001?l00002oooo
o`;o00002Oooool2o`0001Cooooo0_l00003ooooo`;o00000oooool2o`0000Gooooo0_l0000:oooo
o`;o0000Aoooool001cooooo0_l0001Ioooooa3o00001?ooool2o`0000Gooooo0_l00006ooooo`?o
00003Oooool2o`0000Cooooo0_l00005ooooo`So00000_oooolFo`000003ooooool0003o000000Wo
000000?oooooo`000?l000002oooool2o`00017ooooo0_l00006ooooo`;o00000oooool4o`0000[o
oooo0_l00017ooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o000000?oooooo`000?l00000
3?l00002ooooo`?o00000oooool2o`0000Gooooo0_l00006ooooo`;o00000oooool2o`0000Wooooo
0_l00002ooooo`;o00002?ooool5o`0000;ooooo6ol00005ooooo`Co000000?oooooo`000?l00000
2Oooool4o`00017ooooo1?l00009ooooo`Co00000oooool2o`0000;ooooo0_l000000ooooooo0000
o`000017ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00003Oooool2o`000004ooooool0
003o0000ooooo`[o00001?ooool2o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o0000
2oooool2o`0000[ooooo0_l000000ooooooo0000o`000005ooooo`;o00000_ooool9o`000003oooo
ool0003o000000[o00000_ooool4o`000003ooooool0003o000000;o00000oooool2o`0000Cooooo
1?l00008ooooo`;o00005Oooool5o`0000gooooo0ol000000ooooooo0000o`000002o`0004Sooooo
000Looooo`03o`000?oooooooooo04Cooooo0_l0000Cooooo`;o000000?oooooo`000?l000001Ol0
0003ooooo`;o00000_ooool2o`0000?ooooo0_l00005ooooo`;o00001oooool2o`0000_ooooo0_l0
00000ooooooo0000o`000005ooooo`;o00000_ooool9o`000003ooooool0003o000000;o000000?o
ooooo`000?l000002Ol00005ooooo`;o00000oooool3o`000003ooooool0003o000000Co00006Ooo
ool4o`0000Cooooo0ol0000=ooooo`Co00000_ooool2o`0004Sooooo000Looooo`03o`000?oooooo
oooo05cooooo0ol00007ooooo`Co00001_ooool2o`0000Cooooo0_l00002ooooo`;o00000oooool2
o`0000?ooooo0ol00005ooooo`;o000000?oooooo`000?l000001Oooool2o`0000;ooooo2ol00000
0ooooooo0000o`00000<o`0000?ooooo1?l00004ooooo`Ko00007?ooool4o`0000?ooooo0_l0000<
ooooo`Oo0000C?ooool001cooooo00?o0000ooooooooool0F_ooool5o`0000Kooooo1Ol00005oooo
o`?o00000oooool2o`0000?ooooo0_l00006ooooo`Go00001Oooool2o`0000?ooooo0_l00003oooo
o`;o00000_ooool2o`0000;ooooo1ol000000ooooooo0000o`000002o`000003ooooool0003o0000
00Ko00001?ooool6o`0000;ooooo0ol000000ooooooo0000o`00000Rooooo`?o00003?ooool6o`00
04gooooo000Looooo`03o`000?oooooooooo05[ooooo0ol00008ooooo`?o00000oooool6o`0000Co
oooo1?l00008ooooo`Co00003?ooool2o`0000?ooooo0_l00002ooooo`;o00001?ooool8o`0000Co
oooo1?l000000ooooooo0000o`000003o`0000;ooooo1Ol00005ooooo`;o00008oooool2o`0000Oo
oooo0_l000000ooooooo0000o`00001Dooooo`007?ooool00ol0003oooooooooo`1?ooooo`;o0000
2_ooool3o`0000Sooooo0_l00003ooooo`Co00000_ooool2o`0000Cooooo0_l00004ooooo`;o0000
0_ooool3o`0001;ooooo0_l00006ooooo`Co00000_ooool2o`000003ooooool0003o000000?ooooo
1?l000000ooooooo0000o`000004o`000004ooooool0003o0000o`0000Oooooo0_l000000ooooooo
0000o`00000Yooooo`;o000000?oooooo`000?l00000E?ooool001cooooo00?o0000ooooooooool0
AOooool2o`0000Oooooo0ol000000ooooooo0000o`000008ooooo`;o00001oooool2o`0000?ooooo
0ol00004ooooo`;o00002_ooool2o`0000;ooooo0ol00009ooooo`;o000000?oooooo`000?l00000
3?ooool6o`0000;ooooo0ol0000<ooooo`;o00001oooool2o`0000Gooooo0_l00009ooooo`Co0000
4Oooool2o`0006;ooooo000Looooo`03o`000?oooooooooo04Gooooo0_l00007ooooo`;o00000_oo
ool2o`0000_ooooo0_l00004ooooo`;o000000?oooooo`000?l000000ol0000Pooooo`;o000000?o
ooooo`000?l000000oooool2o`000003ooooool0003o000000Kooooo1?l00002ooooo`Co00001?oo
ool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool2o`0000;ooooo0_l0
000<ooooo`Ko00003oooool4o`00017ooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`1G
ooooo`;o00000oooool2o`000003ooooool0003o000000;o00001Oooool3o`0000kooooo0_l0000F
ooooo`;o00000_ooool:o`000004ooooool0003o0000o`0000Cooooo0ol00003ooooo`?o00000_oo
ool3o`0000Cooooo0_l00002ooooo`;o00000_ooool6o`000003ooooool0003o000000Sooooo1?l0
000Aooooo`;o00002_ooool2o`0000Gooooo0_l0000Fooooo`;o0000=Oooool001cooooo00?o0000
ooooooooool0Eoooool2o`0000?ooooo0_l00003ooooo`;o00001_ooool2o`000003ooooool0003o
000000_ooooo0_l0000Fooooo`;o00001?ooool8o`000004ooooool0003o0000o`0000[ooooo0_l0
00000ooooooo0000o`000003o`0000Sooooo0ol000000ooooooo0000o`000004o`000003ooooool0
003o000001Gooooo0_l00008ooooo`;o00000oooool2o`0000?ooooo1?l0000Kooooo`;o0000=Ooo
ool001cooooo00?o0000ooooooooool0Coooool2o`0001_ooooo0_l0000<ooooo`;o00007Oooool2
o`0000Wooooo0_l00004ooooo`;o00001?ooool4o`0000Gooooo0_l00003ooooo`;o00007oooool2
o`0000Sooooo1?l000000ooooooo0000o`000005ooooo`;o0000D_ooool001cooooo00?o0000oooo
ooooool0Aoooool2o`0000Kooooo0_l0000@ooooo`;o00005oooool2o`0001Gooooo0_l0000;oooo
o`?o00000oooool2o`0000?ooooo1?l00002ooooo`Ko00001?ooool2o`0000cooooo0_l00008oooo
o`;o000000?oooooo`000?l000005Oooool2o`0000Cooooo0_l00002ooooo`;o0000D_ooool001co
oooo00?o0000ooooooooool0Aoooool2o`0000Kooooo0_l00002ooooo`;o000000?oooooo`000?l0
00002Oooool2o`0000?ooooo0_l00002ooooo`Co00000oooool2o`0000Wooooo0_l00002ooooo`;o
00002_ooool2o`0000?ooooo0_l00004ooooo`?o00001?ooool3o`0000?ooooo0_l00002ooooo`Go
00000_ooool2o`0000;ooooo0_l0000Aooooo`?o00001?ooool2o`000003ooooool0003o000000Co
00004?ooool2o`0000Kooooo0_l000000ooooooo0000o`000002ooooo`;o00003_ooool2o`0004;o
oooo000Looooo`03o`000?oooooooooo04oooooo1_l000001?oooooo0000o`000?l00007ooooo`Co
00000_ooool2o`0000;ooooo1?l00003ooooo`;o00001?ooool2o`0000?ooooo0_l00002ooooo`;o
00002_ooool2o`0000Oooooo1Ol00004ooooo`?o00001oooool4o`0000Cooooo0_l00002ooooo`?o
00003oooool4o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0000_ooooo0_l00002oooo
o`Co00001_ooool4o`0000?ooooo0ol0000=ooooo`;o0000@_ooool001cooooo0_l0001>ooooo`;o
00000_ooool2o`0000;ooooo1?l00007ooooo`Co000000?oooooo`000?l000001oooool2o`0000Oo
oooo0_l00005ooooo`;o00004?ooool2o`0000?ooooo0_l00007ooooo`;o00002Oooool3o`0000?o
oooo0ol00002ooooo`?o00004Oooool2o`0000Sooooo0_l0000<ooooo`;o00000_ooool2o`000003
ooooool0003o000000?ooooo0_l00002ooooo`;o00001?ooool2o`00057ooooo000Looooo`03o`00
0?oooooooooo04gooooo0_l00006ooooo`;o00003?ooool6o`0000Gooooo0_l000000ooooooo0000
o`000002ooooo`;o000000?oooooo`000?l000001?ooool2o`00013ooooo0_l00003ooooo`;o0000
4_ooool2o`0000Cooooo0_l00003ooooo`;o00002oooool2o`0000Kooooo0_l00007ooooo`;o0000
0_ooool2o`0000oooooo0_l00003ooooo`;o00001Oooool2o`000003ooooool0003o0000057ooooo
000Looooo`03o`000?oooooooooo04[ooooo0_l00009ooooo`;o00003?ooool2o`0000;ooooo0_l0
0008ooooo`;o00000_ooool2o`000003ooooool0003o000000Cooooo1_l0000<ooooo`;o00005_oo
ool2o`0000;ooooo0_l00006ooooo`;o000000?oooooo`000?l000001_ooool4o`0000;ooooo0_l0
00001?oooooo0000o`000?l00008ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Wooooo
0_l00008ooooo`;o0000E?ooool001cooooo00?o0000ooooooooool0B_ooool2o`0001cooooo1Ol0
000Aooooo`Ko00000_ooool2o`0000Sooooo0_l00004ooooo`;o00001Oooool2o`0000Kooooo0_l0
00000ooooooo0000o`000002ooooo`?o00002?ooool3o`000003ooooool0003o000000;ooooo0_l0
0003ooooo`?o000000?oooooo`000?l000002Oooool2o`0000Wooooo0_l00009ooooo`;o00002?oo
ool2o`0005Cooooo000Looooo`03o`000?oooooooooo05;ooooo0_l00003ooooo`;o00003?ooool2
o`000003ooooool0003o000000?o00005Oooool2o`0000;ooooo0_l00008ooooo`?o00000oooool2
o`0000?ooooo1?l00003ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o00001?ooool2
o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`;o00000_ooool4o`0002_ooooo0_l0001D
ooooo`007?ooool00ol0003oooooooooo`1Booooo`;o00000oooool2o`0000?ooooo0_l00007oooo
o`Co00001oooool3o`0000;ooooo0_l00009ooooo`Co00000oooool2o`0000Cooooo0_l00002oooo
o`;o00002?ooool2o`0000Gooooo1ol00002ooooo`;o00001_ooool3o`0000Gooooo0_l000000ooo
oooo0000o`000002o`0000?ooooo0ol0000Booooo`;o00001_ooool2o`0000Wooooo0_l000000ooo
oooo0000o`00001Gooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00001oooool3o`0000Ko
oooo1?l00007ooooo`?o00000_ooool2o`0000;ooooo0_l00005ooooo`?o00001?ooool4o`0000;o
oooo0_l0000Dooooo`Co000000Coooooo`000?l0003ooooo0_l00007ooooo`;o00001oooool7o`00
0003ooooool0003o000001?ooooo0_l00006ooooo`;o00002Oooool2o`000003ooooool0003o0000
05Oooooo000Looooo`03o`000?oooooooooo04gooooo0_l00004ooooo`;o00001oooool3o`0000Go
oooo0_l00005ooooo`;o00002?ooool2o`0000;ooooo0_l0000=ooooo`?o00003_ooool2o`0000go
oooo1Ol00007ooooo`;o00001oooool2o`0000?ooooo0_l00025ooooo`007?ooool00ol0003ooooo
ooooo`1=ooooo`;o00003Oooool2o`0000Kooooo0_l00003ooooo`Co00002?ooool2o`00017ooooo
0_l000000ooooooo0000o`000002o`0000[ooooo0_l0000<ooooo`;o000000?oooooo`000?l00000
0ol00003ooooo`Co00007oooool2o`0007;ooooo000Looooo`03o`000?oooooooooo05Gooooo0_l0
00000ooooooo0000o`00000?ooooo`Co00002?ooool2o`0000Gooooo0_l0000;ooooo`Ko00002Ooo
ool2o`0000_ooooo1Ol000000ooooooo0000o`000002o`0000?ooooo0_l0000;ooooo`;o00001Ooo
ool2o`0000gooooo0_l00006ooooo`;o00003_ooool2o`0005[ooooo000Looooo`03o`000?oooooo
oooo05Gooooo0_l000000ooooooo0000o`00000Jooooo`?o00001Oooool4o`0000Wooooo0_l00007
ooooo`;o00001?ooool2o`0000Wooooo1ol00003ooooo`;o00004?ooool2o`0000Cooooo0ol00000
0ooooooo0000o`00000Booooo`;o00001_ooool2o`0000Cooooo1_l0001Hooooo`007?ooool00ol0
003oooooooooo`1Hooooo`Co00003?ooool4o`0000Sooooo0_l00008ooooo`;o00000_ooool2o`00
00Gooooo0_l00002ooooo`;o00000oooool3o`0000;ooooo0_l00005ooooo`;o00000oooool2o`00
00;ooooo0_l00004ooooo`;o00004_ooool2o`0000;ooooo0_l00002ooooo`;o00004Oooool2o`00
0003ooooool0003o000000Cooooo0_l00004ooooo`;o000000Coooooo`000?l0003o0000F?ooool0
01cooooo00?o0000ooooooooool0F?ooool4o`0000cooooo1?l0000Dooooo`Wo000000Coooooo`00
0?l0003ooooo0_l00004ooooo`;o00000_ooool2o`0000Gooooo0_l0000Dooooo`;o00002oooool2
o`0001Wooooo1Ol0000=ooooo`;o00000_ooool2o`0005Gooooo000Looooo`03o`000?oooooooooo
083ooooo0_l00002ooooo`So00002?ooool2o`0000gooooo0_l00004ooooo`;o00001_ooool2o`00
0003ooooool0003o000000?ooooo1Ol00002ooooo`?o00001?ooool2o`0000Wooooo0_l0000:oooo
o`;o00002oooool2o`0000Gooooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`1?ooooo`;o
00005Oooool2o`000003ooooool0003o000000;ooooo0_l00007ooooo`;o00001?ooool2o`0000Oo
oooo1_l00002ooooo`;o00000oooool4o`0000_ooooo1?l00003ooooo`?o00001_ooool2o`0000Ko
oooo1Ol00002ooooo`;o00000_ooool2o`000003ooooool0003o000000Wooooo0ol00004ooooo`;o
00001_ooool2o`000003ooooool0003o000000Gooooo0_l0001Looooo`007?ooool00ol0003ooooo
ooooo`1?ooooo`;o00004?ooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o0000
1?ooool2o`000003ooooool0003o000000?ooooo0ol00008ooooo`;o000000?oooooo`000?l00000
0_ooool2o`0000?ooooo0_l00004ooooo`;o00001oooool2o`0000Gooooo0ol0000:ooooo`;o0000
3Oooool2o`0000gooooo0_l00004ooooo`;o00001Oooool6o`0006?ooooo000Looooo`;o0000F_oo
ool2o`0000Kooooo0_l00009ooooo`;o00001Oooool2o`0000Kooooo1Ol00002ooooo`;o00001?oo
ool2o`0000?ooooo1?l00006ooooo`?o00001?ooool2o`000003ooooool0003o000000;o00001?oo
ool2o`000003ooooool0003o000000Oooooo0_l0000Dooooo`;o00000oooool2o`0000?ooooo0_l0
0006ooooo`;o000000Coooooo`000?l0003ooooo1Ol0001Qooooo`007?ooool00ol0003ooooooooo
o`1Iooooo`;o00004?ooool3o`0000Kooooo0_l00007ooooo`?o000000Coooooo`000?l0003o0000
1?ooool2o`0000?ooooo1?l00006ooooo`;o00000oooool4o`0000?ooooo0_l00005ooooo`Co0000
1_ooool2o`0001;ooooo0_l000000ooooooo0000o`000003ooooo`;o00000oooool2o`0000Kooooo
0_l00006ooooo`Go0000Goooool001cooooo00?o0000ooooooooool0B_ooool2o`0001oooooo1?l0
0005ooooo`;o00001oooool2o`0000;ooooo0_l0000:ooooo`Ko000000?oooooo`000?l000001_oo
ool5o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`00
000?ooooo`;o00002oooool2o`0000?ooooo0_l00004ooooo`;o00000oooool5o`0005oooooo000L
ooooo`03o`000?oooooooooo04[ooooo0_l0000Qooooo`;o00000oooool2o`0000?ooooo0_l00004
ooooo`;o00004_ooool2o`000003ooooool0003o000000Sooooo0ol00008ooooo`;o00000oooool2
o`0000Oooooo0_l0000Qooooo`;o00001?ooool3o`0000?ooooo0_l000000ooooooo0000o`00000A
ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0EOooool2o`0001[ooooo0ol00003oooo
o`;o000000?oooooo`000?l000000_ooool4o`0000;ooooo0_l0000;ooooo`;o00000oooool2o`00
00gooooo0_l00002ooooo`;o00001Oooool2o`0000kooooo0_l00006ooooo`;o00004_ooool2o`00
00;ooooo0ol00003ooooo`;o000000?oooooo`000?l000004Oooool2o`0004_ooooo000Looooo`03
o`000?oooooooooo05Gooooo0_l0000Jooooo`;o00001oooool3o`000003ooooool0003o000000;o
00000_ooool2o`0000oooooo1Ol000000ooooooo0000o`000008ooooo`?o00001_ooool4o`0000[o
oooo0_l00002ooooo`;o00001_ooool2o`0001;ooooo0_l00002ooooo`Go0000I?ooool001cooooo
00?o0000ooooooooool0L_ooool2o`0000;ooooo0_l00003ooooo`;o00003?ooool2o`0000Kooooo
0_l00002ooooo`;o000000Coooooo`000?l0003ooooo1?l00004ooooo`;o000000?oooooo`000?l0
00001_ooool2o`0000cooooo0_l0000@ooooo`?o00004Oooool3o`0006Cooooo000Looooo`03o`00
0?oooooooooo073ooooo1?l00002ooooo`;o00000oooool2o`0000[ooooo1?l00004ooooo`Co0000
1?ooool2o`0000Cooooo0ol000000ooooooo0000o`000002o`0000kooooo0_l00008ooooo`;o0000
0oooool2o`0000[ooooo1?l00006ooooo`;o000000?oooooo`000?l000001Oooool2o`0006Gooooo
000Looooo`03o`000?oooooooooo073ooooo1?l00008ooooo`Oo00001?ooool2o`0000Cooooo1?l0
0004ooooo`Co00001Oooool5o`0000gooooo1Ol00008ooooo`;o00000oooool2o`0000_ooooo0ol0
0006ooooo`Go000000?oooooo`000?l000000_ooool2o`0006Gooooo000Looooo`03o`000?oooooo
oooo07;ooooo0_l00008ooooo`Oo00002_ooool2o`0000Kooooo0_l00008ooooo`Co00003Oooool4
o`0000Wooooo0_l000000ooooooo0000o`00000Booooo`;o00001?ooool2o`0000;ooooo0_l0001Y
ooooo`007?ooool00ol0003oooooooooo`1Jooooo`;o00004Oooool2o`0000cooooo1?l0000>oooo
o`?o00000_ooool2o`0000gooooo0_l0000Cooooo`;o00001Oooool2o`000003ooooool0003o0000
01;ooooo0_l000000ooooooo0000o`00000;ooooo`;o0000Hoooool001cooooo00?o0000oooooooo
ool0F_ooool2o`00017ooooo0_l0000;ooooo`Ko00002_ooool6o`0000;ooooo0_l0000?ooooo`Co
000000?oooooo`000?l000003?ooool2o`000003ooooool0003o000000_ooooo0_l0000?ooooo`Co
00002Oooool2o`0006?ooooo000Looooo`03o`000?oooooooooo07Cooooo0_l00004ooooo`;o0000
00Coooooo`000?l0003o00002_ooool3o`0000Sooooo1Ol00007ooooo`Ko000000?oooooo`000?l0
00003oooool2o`0000Oooooo0_l00002ooooo`;o000000?oooooo`000?l000003_ooool2o`0006ko
oooo000Looooo`03o`000?oooooooooo07Cooooo0_l0000Oooooo`Go00001oooool4o`0000;ooooo
0_l00009ooooo`;o00002oooool2o`000003ooooool0003o000000Gooooo0_l00007ooooo`?o0000
M?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0
003o8B4Qolc<c006ooooo`03o`000?oooooooooo083ooooo0_l0000Cooooo`?o00002_ooool2o`00
0003ooooool0003o000000;o00002?ooool3o`0000_ooooo0_l00009ooooo`;o000000?oooooo`00
0?l000000oooool3o`0007Cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44
ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1oooooo`?o00002?oo
ool2o`0000?ooooo0_l00005ooooo`?o00002Oooool2o`000003ooooool0003o000000;o00002?oo
ool2o`0000Gooooo0_l000000ooooooo0000o`00000=ooooo`;o000000Coooooo`000?l0003ooooo
0_l000000ooooooo0000o`00001dooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`1kooooo`;o0000
0_ooool2o`0000Wooooo1?l000001?oooooo0000o`000?ooool3o`0000;ooooo0_l0000>ooooo`;o
00001Oooool2o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Ko
oooo0_l00003ooooo`;o00003oooool2o`0006Kooooo00000ooooooo0000ooooo`02ooooo`03o`00
0?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000N_ooool3o`0000oo
oooo1?l00002ooooo`?o00002_ooool2o`0000Wooooo0_l00002ooooo`;o00000_ooool4o`0000go
oooo0_l00006ooooo`;o00005?ooool2o`0006Kooooo00000ooooooo0000ooooo`02ooooo`03o`00
0?oooooooooo00Wooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo07[o
oooo0_l0000Booooo`;o00001_ooool2o`0000Oooooo0_l00009ooooo`;o00000_ooool3o`000003
ooooool0003o000000;o00000oooool2o`000003ooooool0003o000000;o00000_ooool3o`0000Go
oooo0_l0000Mooooo`;o0000G_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool0
2Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0U_ooool4o`0000Ko
oooo0_l0000<ooooo`?o00000oooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`0000;o
oooo0_l00005ooooo`?o000000?oooooo`000?l000000_l0000Hooooo`;o0000G_ooool00006oooo
oomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000
ooooooooool0R?ooool2o`000003ooooool0003o000000Cooooo0_l00005ooooo`;o000000?ooooo
o`000?l000000oooool2o`00013ooooo1?l0000Cooooo`;o00000_ooool4o`0007Sooooo00001_oo
ooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`00
0?oooooooooo07kooooo0_l00008ooooo`;o000000Coooooo`000?l0003ooooo0_l000001?oooooo
0000o`000?l00004ooooo`;o000000?oooooo`000?l000005Oooool5o`0009;ooooo000Looooo`03
o`000?oooooooooo07kooooo1?l0000<ooooo`;o00000_ooool2o`00023ooooo0ol0002Booooo`00
7?ooool00ol0003oooooooooo`1gooooo`;o00001oooool2o`0001Gooooo0_l00004ooooo`;o0000
00?oooooo`000?l000000oooool2o`0001kooooo0_l00004ooooo`;o0000O?ooool001cooooo00?o
0000ooooooooool0Moooool2o`0001;ooooo0_l00005ooooo`;o00000oooool4o`0000;ooooo0_l0
00000ooooooo0000o`000003ooooo`;o00004_ooool4o`0000?ooooo1?l000000ooooooo0000o`00
0004ooooo`;o0000O?ooool001cooooo00?o0000ooooooooool0OOooool2o`000004ooooool0003o
0000o`0000Sooooo0_l00005ooooo`?o00001?ooool2o`0001cooooo1_l00003ooooo`Co0000QOoo
ool001cooooo00?o0000ooooooooool0OOooool2o`000004ooooool0003o0000o`00013ooooo0_l0
0004ooooo`;o00007?ooool2o`0000Sooooo0_l00026ooooo`007?ooool00ol0003oooooooooo`2<
ooooo`;o000000?oooooo`000?l000002?ooool2o`0000Kooooo0_l00008ooooo`Go00003oooool6
o`0008Cooooo000Looooo`03o`000?oooooooooo07_ooooo0_l0000?ooooo`;o000000?oooooo`00
0?l000004?ooool5o`0000Gooooo1Ol0000;ooooo`;o00000_ooool2o`0000;ooooo0_l00006oooo
o`;o0000O?ooool001cooooo00?o0000ooooooooool0Noooool2o`0002Gooooo1?l0000>ooooo`;o
00001Oooool2o`0000Cooooo0ol00007ooooo`;o0000O?ooool001cooooo00?o0000ooooooooool0
Loooool2o`0001Wooooo0_l000000ooooooo0000o`000007ooooo`;o00001_ooool2o`0000oooooo
0ol000000ooooooo0000o`000003ooooo`?o00000_ooool5o`000003ooooool0003o0000083ooooo
000Looooo`03o`000?oooooooooo07?ooooo0_l0000Gooooo`Co000000?oooooo`000?l000000ooo
ool2o`0000;ooooo0_l0000Gooooo`;o000000Coooooo`000?l0003o00000oooool3o`0000?ooooo
1?l000000ooooooo0000o`000020ooooo`007?ooool00ol0003oooooooooo`2<ooooo`;o00000ooo
ool2o`0000?ooooo0_l0000Eooooo`;o000000?oooooo`000?l000000ol000000ooooooo0000o`00
002Aooooo`007?ooool2o`000:kooooo0_l000001?oooooo0000o`000?l0002Fooooo`007?ooool0
0ol0003oooooooooo`22ooooo`;o00008Oooool2o`0002gooooo0_l0001cooooo`007?ooool00ol0
003oooooooooo`20ooooo`Co00007?ooool2o`0000?ooooo0ol0000/ooooo`;o0000Loooool001co
oooo00?o0000ooooooooool0P?ooool2o`0001kooooo0_l00004ooooo`;o0000XOooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2gooooo`;o0000T?oo
ool001cooooo00?o0000ooooooooool0Woooool2o`0001Kooooo0_l0002@ooooo`007?ooool00ol0
003oooooooooo`2Cooooo`;o00002_ooool2o`0000oooooo0_l0002Gooooo`007?ooool00ol0003o
ooooooooo`2Cooooo`;o00006oooool2o`0000cooooo0_l00029ooooo`007?ooool00ol0003ooooo
ooooo`2nooooo`;o0000ROooool001cooooo00?o0000ooooooooool0Z?ooool2o`0009oooooo000L
ooooo`03o`000?oooooooooo0:Sooooo0_l0002Oooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo
00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000D
ooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBoooo
o`004_ooool00omEEEGoIVIVo`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo002Uooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05Oooool0
1?l@413o0000odA4A?o<c<`4ooooo`04oa0@4?l0003oA4A4olc<c0Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP2@ooooo`00Y_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l0000;ooooo`03
oiRHV?l@413ogMgM00Gooooo00?oV9RHoa0@4?oMgMd00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
093ooooo002Vooooo`05o`000?ooooooooooooooool000006oooool00on7QhOoEEEEooooo`05oooo
o`03ohN7QomEEEGooooo00;ooooo00Go410@oooooooooooooooooa0@402@ooooo`00Y_ooool01Ol0
003ooooooooooooooooo000000Wooooo1_l00009ooooo`05olc<c?lQ8B7o0000oeEEEOl000000ooo
ool01Oo<c<co8B4Qo`000?mEEEGo000000?ooooo00Go0000ooooooooooooooooo`00002@ooooo`00
Y_ooool01Ol0003oQhN7oooooonYZJWo000001Sooooo00Go8B4QohN7QoooooooV9RHo`000003oooo
o`05ob4Q8On7QhOooooooiRHV?l000000oooool01Ol0003ooooooooooooooooo0000093ooooo002U
ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool05_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05oa0@4?ooooooooooooooool@
4100T?ooool00<?ooooo00Go8B4QoiRHV?ooooooMgMgoeEEE@03ooooo`05ob4Q8OnHV9SoooooogMg
MomEEED00oooool01OmgMgOoV9RHoooooonHV9SoMgMg093ooooo0033ooooo`05olc<c?l@413o0000
oc8b<_o^k^h00oooool01Oo<c<co410@o`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP2@ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(996) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.64288 .499 Mdot
.67919 .46271 Mdot
.32507 .43519 Mdot
.53031 .64233 Mdot
.74505 .42591 Mdot
.38578 .42164 Mdot
.53931 .29978 Mdot
.54057 .35481 Mdot
.35709 .4338 Mdot
.54366 .49679 Mdot
.52198 .32471 Mdot
.53873 .5345 Mdot
.53924 .33636 Mdot
.51938 .62865 Mdot
.59026 .85395 Mdot
.54833 .67429 Mdot
.67972 .44104 Mdot
.2669 .58161 Mdot
.56286 .55886 Mdot
.30807 .46297 Mdot
.61668 .48002 Mdot
.53106 .63163 Mdot
.64587 .4962 Mdot
.51951 .62818 Mdot
.51353 .64939 Mdot
.65434 .46041 Mdot
.66524 .51861 Mdot
.53953 .65415 Mdot
.48335 .62497 Mdot
.55785 .34282 Mdot
.36155 .7237 Mdot
.68501 .79236 Mdot
.58404 .61664 Mdot
.66546 .23758 Mdot
.53257 .35511 Mdot
.69702 .71838 Mdot
.37887 .43671 Mdot
.55826 .3268 Mdot
.53321 .3533 Mdot
.57 .33917 Mdot
.54815 .34218 Mdot
.65974 .4629 Mdot
.56712 .36641 Mdot
.5652 .26319 Mdot
.52688 .55702 Mdot
.65516 .36616 Mdot
.49435 .76038 Mdot
.5277 .57886 Mdot
.67216 .44201 Mdot
.3076 .45633 Mdot
.65099 .24256 Mdot
.56001 .30127 Mdot
.43274 .40803 Mdot
.89993 .47202 Mdot
.55649 .3151 Mdot
.53095 .55255 Mdot
.3453 .44533 Mdot
.53793 .62044 Mdot
.52309 .62478 Mdot
.59398 .73015 Mdot
.52795 .66473 Mdot
.29287 .58191 Mdot
.66174 .42922 Mdot
.33465 .53194 Mdot
.37243 .43149 Mdot
.53131 .35044 Mdot
.69257 .46027 Mdot
.54147 .32959 Mdot
.48797 .55858 Mdot
.41154 .39413 Mdot
.52875 .5794 Mdot
.53005 .34554 Mdot
.70431 .48697 Mdot
.54137 .58479 Mdot
.36912 .23541 Mdot
.42821 .83454 Mdot
.29063 .62612 Mdot
.63648 .7196 Mdot
.59663 .75147 Mdot
.28112 .51042 Mdot
.49026 .61378 Mdot
.19296 .59014 Mdot
.53371 .84733 Mdot
.63844 .49005 Mdot
.55164 .68055 Mdot
.39527 .38787 Mdot
.54551 .58919 Mdot
.59672 .41257 Mdot
.5035 .56254 Mdot
.48331 .19566 Mdot
.35129 .43275 Mdot
.67047 .48384 Mdot
.52785 .64174 Mdot
.49054 .65222 Mdot
.64278 .59699 Mdot
.55477 .64926 Mdot
.54376 .64465 Mdot
.66778 .51245 Mdot
.51795 .3192 Mdot
.5236 .52739 Mdot
.58666 .32907 Mdot
.43142 .39815 Mdot
.55267 .57107 Mdot
.33806 .45183 Mdot
.68221 .50864 Mdot
.54865 .58298 Mdot
.50775 .33139 Mdot
.50376 .58479 Mdot
.54588 .24592 Mdot
.68319 .46193 Mdot
.48702 .64863 Mdot
.31949 .58506 Mdot
.25496 .3269 Mdot
.67142 .4873 Mdot
.32547 .49451 Mdot
.48932 .59373 Mdot
.55035 .62367 Mdot
.67653 .46426 Mdot
.36777 .40723 Mdot
.58517 .45928 Mdot
.641 .44708 Mdot
.56249 .35172 Mdot
.64666 .43864 Mdot
.56166 .67461 Mdot
.36782 .42605 Mdot
.45184 .37151 Mdot
.45358 .37583 Mdot
.32837 .68446 Mdot
.54735 .59453 Mdot
.65102 .29025 Mdot
.38669 .41339 Mdot
.6667 .47774 Mdot
.53795 .32885 Mdot
.46135 .64571 Mdot
.6883 .48821 Mdot
.53431 .31211 Mdot
.3084 .61346 Mdot
.40595 .32451 Mdot
.65454 .44205 Mdot
.56382 .25349 Mdot
.55592 .28912 Mdot
.5729 .33306 Mdot
.64585 .22278 Mdot
.67882 .45579 Mdot
.30352 .60368 Mdot
.54024 .31344 Mdot
.43536 .7574 Mdot
.51701 .55034 Mdot
.34677 .63105 Mdot
.15142 .52727 Mdot
.63082 .22556 Mdot
.41983 .27101 Mdot
.28204 .5718 Mdot
.57376 .31821 Mdot
.49717 .6456 Mdot
.66661 .448 Mdot
.66669 .45335 Mdot
.56091 .62422 Mdot
.52466 .64951 Mdot
.53329 .57968 Mdot
.48423 .64309 Mdot
.53774 .78993 Mdot
.50673 .5769 Mdot
.24731 .67536 Mdot
.66273 .48769 Mdot
.51835 .65795 Mdot
.31864 .43043 Mdot
.4686 .60529 Mdot
.54093 .34669 Mdot
.53941 .62723 Mdot
.53196 .64491 Mdot
.5037 .66225 Mdot
.54655 .2977 Mdot
.67925 .78231 Mdot
.16105 .47121 Mdot
.78722 .6318 Mdot
.36558 .46295 Mdot
.40089 .41972 Mdot
.55315 .59798 Mdot
.29009 .59593 Mdot
.71391 .68463 Mdot
.49752 .61729 Mdot
.38643 .1691 Mdot
.54187 .64243 Mdot
.76331 .44964 Mdot
.47462 .70585 Mdot
.79982 .61389 Mdot
.27488 .6515 Mdot
.48456 .6362 Mdot
.67316 .56053 Mdot
.77895 .51489 Mdot
.52101 .26948 Mdot
.54942 .33913 Mdot
.32247 .42735 Mdot
.33491 .44415 Mdot
.51406 .2881 Mdot
.47568 .54546 Mdot
.44634 .60814 Mdot
.45505 .60463 Mdot
.43941 .39293 Mdot
.68249 .42531 Mdot
.27119 .60715 Mdot
.67529 .50857 Mdot
.24997 .74185 Mdot
.56276 .23704 Mdot
.59315 .3144 Mdot
.30553 .62141 Mdot
.34153 .42188 Mdot
.43577 .39888 Mdot
.28715 .60127 Mdot
.51171 .59516 Mdot
.6873 .45556 Mdot
.77078 .3404 Mdot
.44085 .59374 Mdot
.76038 .30422 Mdot
.70324 .46289 Mdot
.57371 .44953 Mdot
.52914 .32228 Mdot
.37549 .44521 Mdot
.5502 .62758 Mdot
.52554 .59896 Mdot
.61507 .46571 Mdot
.52827 .58189 Mdot
.73872 .48443 Mdot
.55337 .62913 Mdot
.45387 .33808 Mdot
.28796 .62646 Mdot
.51163 .29063 Mdot
.31719 .68142 Mdot
.67293 .50183 Mdot
.28674 .64289 Mdot
.33108 .41764 Mdot
.67981 .72098 Mdot
.52448 .34181 Mdot
.32051 .59324 Mdot
.35632 .40676 Mdot
.26876 .60062 Mdot
.47748 .58991 Mdot
.4141 .41072 Mdot
.30421 .57542 Mdot
.6028 .80103 Mdot
.48521 .57595 Mdot
.52424 .79953 Mdot
.534 .2996 Mdot
.65052 .43757 Mdot
.52988 .66371 Mdot
.35954 .45485 Mdot
.57756 .63946 Mdot
.40046 .24412 Mdot
.45803 .37019 Mdot
.42237 .42019 Mdot
.30953 .52682 Mdot
.31764 .5901 Mdot
.34986 .27641 Mdot
.63633 .26763 Mdot
.68318 .4437 Mdot
.5603 .57219 Mdot
.76712 .68671 Mdot
.53984 .31412 Mdot
.50652 .59748 Mdot
.43245 .36052 Mdot
.54238 .31481 Mdot
.53917 .61756 Mdot
.52685 .29769 Mdot
.67098 .45175 Mdot
.21901 .43632 Mdot
.68249 .44172 Mdot
.49641 .56924 Mdot
.50923 .3179 Mdot
.41275 .40139 Mdot
.65116 .46031 Mdot
.50819 .58468 Mdot
.5595 .60855 Mdot
.4433 .38216 Mdot
.51029 .65865 Mdot
.73366 .71668 Mdot
.50971 .66169 Mdot
.32148 .44253 Mdot
.55002 .65498 Mdot
.47735 .16234 Mdot
.34891 .34712 Mdot
.69197 .45939 Mdot
.41904 .42251 Mdot
.35294 .43752 Mdot
.25429 .46988 Mdot
.4394 .41264 Mdot
.49163 .59861 Mdot
.39979 .43311 Mdot
.35814 .60942 Mdot
.56304 .31715 Mdot
.57106 .59797 Mdot
.6028 .32143 Mdot
.30529 .45101 Mdot
.43739 .39441 Mdot
.47869 .68683 Mdot
.69324 .50465 Mdot
.52751 .6428 Mdot
.41462 .39653 Mdot
.63527 .44594 Mdot
.50076 .56968 Mdot
.41488 .62347 Mdot
.45246 .38013 Mdot
.54279 .3024 Mdot
.48105 .70252 Mdot
.5228 .57416 Mdot
.36712 .44157 Mdot
.69204 .49448 Mdot
.53601 .35751 Mdot
.65385 .47035 Mdot
.78715 .44089 Mdot
.48248 .28074 Mdot
.57637 .78668 Mdot
.33277 .57628 Mdot
.44917 .24126 Mdot
.81305 .58495 Mdot
.30333 .30213 Mdot
.40631 .71074 Mdot
.81695 .44744 Mdot
.36432 .40615 Mdot
.44215 .34064 Mdot
.34876 .4409 Mdot
.49897 .63488 Mdot
.37998 .42601 Mdot
.80997 .60145 Mdot
.55098 .63379 Mdot
.38953 .42885 Mdot
.22807 .45575 Mdot
.52678 .65343 Mdot
.67349 .4884 Mdot
.58158 .84936 Mdot
.34897 .23181 Mdot
.58066 .22771 Mdot
.40127 .4094 Mdot
.52097 .72477 Mdot
.5367 .65446 Mdot
.50421 .66606 Mdot
.65126 .45173 Mdot
.564 .62823 Mdot
.27086 .60425 Mdot
.2993 .62177 Mdot
.39716 .55312 Mdot
.17168 .49206 Mdot
.52658 .52807 Mdot
.6508 .45801 Mdot
.55414 .75563 Mdot
.39759 .21868 Mdot
.32576 .47007 Mdot
.55751 .36414 Mdot
.65786 .79234 Mdot
.45709 .56795 Mdot
.56775 .36836 Mdot
.58617 .27449 Mdot
.68168 .47524 Mdot
.69208 .76586 Mdot
.55324 .33233 Mdot
.70983 .57517 Mdot
.62127 .59123 Mdot
.51811 .59929 Mdot
.51942 .33353 Mdot
.53668 .53184 Mdot
.44181 .18112 Mdot
.44338 .78096 Mdot
.23067 .65459 Mdot
.51348 .56167 Mdot
.33917 .26656 Mdot
.54442 .62744 Mdot
.59046 .47419 Mdot
.51345 .66326 Mdot
.64965 .47412 Mdot
.54648 .50448 Mdot
.48466 .41343 Mdot
.15915 .52848 Mdot
.56665 .23724 Mdot
.28086 .57276 Mdot
.55505 .6194 Mdot
.51873 .60027 Mdot
.30433 .61014 Mdot
.64856 .49203 Mdot
.48481 .64223 Mdot
.37828 .62174 Mdot
.53266 .58795 Mdot
.55282 .33958 Mdot
.29794 .69367 Mdot
.6298 .51152 Mdot
.53801 .67088 Mdot
.62609 .4587 Mdot
.55004 .30231 Mdot
.54009 .35313 Mdot
.48156 .68436 Mdot
.54071 .36209 Mdot
.53937 .64047 Mdot
.35811 .76298 Mdot
.63579 .47577 Mdot
.4418 .65971 Mdot
.66179 .49832 Mdot
.63269 .73226 Mdot
.50655 .32951 Mdot
.45442 .36181 Mdot
.61272 .5311 Mdot
.55024 .33425 Mdot
.60365 .2395 Mdot
.46437 .57776 Mdot
.57307 .6297 Mdot
.50632 .19778 Mdot
.39968 .40643 Mdot
.44818 .38363 Mdot
.51396 .34626 Mdot
.52598 .57418 Mdot
.56925 .62004 Mdot
.55527 .30224 Mdot
.66289 .60791 Mdot
.26495 .44905 Mdot
.54192 .6503 Mdot
.6465 .47943 Mdot
.66452 .47713 Mdot
.52454 .56453 Mdot
.50087 .59252 Mdot
.3488 .42198 Mdot
.41776 .4217 Mdot
.35607 .45813 Mdot
.45111 .38057 Mdot
.45029 .35522 Mdot
.71255 .37412 Mdot
.57065 .33824 Mdot
.67572 .31454 Mdot
.46078 .20161 Mdot
.57926 .55475 Mdot
.40653 .41772 Mdot
.5198 .60794 Mdot
.53138 .6388 Mdot
.53605 .3578 Mdot
.48999 .263 Mdot
.56972 .67059 Mdot
.63903 .45702 Mdot
.51311 .34702 Mdot
.48224 .54893 Mdot
.72234 .3436 Mdot
.2953 .57674 Mdot
.56727 .21432 Mdot
.52811 .34607 Mdot
.68388 .47885 Mdot
.52082 .29723 Mdot
.52522 .59634 Mdot
.54597 .55286 Mdot
.6765 .47087 Mdot
.31219 .57616 Mdot
.46065 .60208 Mdot
.5418 .61697 Mdot
.20406 .32351 Mdot
.35541 .24233 Mdot
.51106 .38517 Mdot
.49121 .64373 Mdot
.56446 .63974 Mdot
.26655 .58915 Mdot
.52921 .59087 Mdot
.5615 .59967 Mdot
.22466 .3575 Mdot
.56007 .39639 Mdot
.26171 .58912 Mdot
.71379 .57882 Mdot
.70286 .45965 Mdot
.73037 .73847 Mdot
.37441 .44745 Mdot
.49544 .32801 Mdot
.24901 .39977 Mdot
.43026 .40587 Mdot
.41457 .2385 Mdot
.71322 .75532 Mdot
.44967 .38248 Mdot
.35065 .56733 Mdot
.59589 .57275 Mdot
.55126 .64006 Mdot
.54775 .62214 Mdot
.29585 .59737 Mdot
.67689 .45368 Mdot
.41974 .52272 Mdot
.45607 .80654 Mdot
.53752 .63186 Mdot
.7339 .48439 Mdot
.60694 .8085 Mdot
.43885 .38919 Mdot
.27326 .60333 Mdot
.32501 .59576 Mdot
.55394 .61783 Mdot
.23205 .36659 Mdot
.6546 .45872 Mdot
.50756 .58511 Mdot
.49712 .58026 Mdot
.40491 .40912 Mdot
.68902 .46573 Mdot
.37304 .40328 Mdot
.46062 .36254 Mdot
.79478 .51917 Mdot
.22123 .29322 Mdot
.5215 .3506 Mdot
.72579 .7098 Mdot
.56385 .32835 Mdot
.23226 .63841 Mdot
.43068 .40823 Mdot
.49342 .61328 Mdot
.6854 .4994 Mdot
.5067 .58313 Mdot
.50489 .60566 Mdot
.51185 .59628 Mdot
.48901 .5503 Mdot
.40751 .16501 Mdot
.28174 .59271 Mdot
.5299 .67711 Mdot
.32394 .44016 Mdot
.7236 .71782 Mdot
.48108 .83412 Mdot
.52759 .60482 Mdot
.55834 .60454 Mdot
.67773 .48987 Mdot
.56275 .62172 Mdot
.56147 .31517 Mdot
.69322 .49402 Mdot
.48467 .64756 Mdot
.67976 .76517 Mdot
.48001 .62426 Mdot
.79813 .60448 Mdot
.52022 .29718 Mdot
.60269 .2422 Mdot
.50188 .67186 Mdot
.45447 .37174 Mdot
.44828 .38364 Mdot
.38646 .44356 Mdot
.50025 .32498 Mdot
.37823 .43573 Mdot
.40003 .79816 Mdot
.58008 .57067 Mdot
.50129 .64701 Mdot
.57101 .61302 Mdot
.40451 .42425 Mdot
.60623 .4093 Mdot
.36953 .28047 Mdot
.46986 .56095 Mdot
.3648 .41868 Mdot
.64398 .43903 Mdot
.3627 .53038 Mdot
.68026 .49912 Mdot
.25841 .6046 Mdot
.52243 .32737 Mdot
.28261 .57923 Mdot
.61733 .22667 Mdot
.68142 .46311 Mdot
.61426 .46733 Mdot
.39907 .42182 Mdot
.5559 .43417 Mdot
.88423 .48663 Mdot
.41179 .39227 Mdot
.35288 .66277 Mdot
.64555 .45777 Mdot
.48593 .59022 Mdot
.27741 .66262 Mdot
.56428 .43276 Mdot
.37472 .43531 Mdot
.49868 .62522 Mdot
.22229 .40236 Mdot
.35107 .42089 Mdot
.57149 .59344 Mdot
.36741 .4091 Mdot
.53491 .34419 Mdot
.38206 .41105 Mdot
.70678 .45302 Mdot
.55068 .58591 Mdot
.88437 .50436 Mdot
.26165 .6389 Mdot
.5076 .65988 Mdot
.51065 .3435 Mdot
.40251 .58028 Mdot
.51105 .61323 Mdot
.28288 .61849 Mdot
.36884 .42404 Mdot
.30806 .40341 Mdot
.53505 .6575 Mdot
.39486 .41807 Mdot
.646 .49912 Mdot
.50048 .32124 Mdot
.25574 .56632 Mdot
.44885 .36913 Mdot
.6554 .44848 Mdot
.46802 .33187 Mdot
.50998 .35055 Mdot
.56275 .64008 Mdot
.50978 .57463 Mdot
.65374 .48183 Mdot
.19518 .48606 Mdot
.54353 .65956 Mdot
.49039 .6141 Mdot
.32145 .43641 Mdot
.38666 .43574 Mdot
.20223 .48118 Mdot
.37573 .4053 Mdot
.55373 .55258 Mdot
.65344 .48056 Mdot
.51956 .63829 Mdot
.68418 .48505 Mdot
.56393 .59371 Mdot
.72242 .44998 Mdot
.63695 .48476 Mdot
.32147 .31091 Mdot
.50782 .63271 Mdot
.47339 .7021 Mdot
.50846 .60088 Mdot
.53094 .58331 Mdot
.34009 .42801 Mdot
.27912 .60534 Mdot
.47369 .66497 Mdot
.28638 .5567 Mdot
.28141 .61527 Mdot
.7738 .49129 Mdot
.4007 .40811 Mdot
.30474 .59092 Mdot
.54567 .80396 Mdot
.41146 .42761 Mdot
.29127 .58968 Mdot
.5096 .8357 Mdot
.52494 .35317 Mdot
.69616 .44571 Mdot
.52582 .65322 Mdot
.81065 .43676 Mdot
.37635 .75921 Mdot
.4263 .40668 Mdot
.50493 .65921 Mdot
.5176 .61033 Mdot
.63161 .46701 Mdot
.2181 .67747 Mdot
.31647 .45123 Mdot
.50205 .63938 Mdot
.69441 .46393 Mdot
.15532 .59583 Mdot
.32485 .44675 Mdot
.29224 .59288 Mdot
.55149 .29797 Mdot
.71962 .48071 Mdot
.4425 .37851 Mdot
.55667 .30107 Mdot
.34075 .31248 Mdot
.60193 .23084 Mdot
.48953 .59297 Mdot
.40653 .41828 Mdot
.6033 .20582 Mdot
.50843 .5275 Mdot
.48761 .35789 Mdot
.57005 .68744 Mdot
.6805 .47812 Mdot
.5586 .31122 Mdot
.28125 .5767 Mdot
.70604 .47817 Mdot
.64538 .48737 Mdot
.5456 .3555 Mdot
.35493 .55591 Mdot
.57181 .44615 Mdot
.54982 .34535 Mdot
.4873 .1989 Mdot
.77805 .40057 Mdot
.40831 .42814 Mdot
.28606 .61527 Mdot
.74879 .32438 Mdot
.65891 .4634 Mdot
.66152 .79 Mdot
.57125 .20683 Mdot
.54351 .64502 Mdot
.30903 .59327 Mdot
.64764 .38342 Mdot
.42949 .80766 Mdot
.54451 .31349 Mdot
.49421 .40348 Mdot
.32123 .57563 Mdot
.54677 .64938 Mdot
.56524 .70719 Mdot
.49511 .62851 Mdot
.52579 .32205 Mdot
.58595 .74925 Mdot
.68443 .47946 Mdot
.51407 .35121 Mdot
.56875 .2146 Mdot
.53876 .63737 Mdot
.50059 .62872 Mdot
.33678 .71017 Mdot
.68333 .44891 Mdot
.36106 .45478 Mdot
.49014 .59617 Mdot
.54096 .62152 Mdot
.57031 .64385 Mdot
.45624 .67653 Mdot
.24961 .33549 Mdot
.50254 .63814 Mdot
.46006 .31675 Mdot
.53473 .67316 Mdot
.51002 .63139 Mdot
.6281 .4563 Mdot
.26146 .25735 Mdot
.45603 .35936 Mdot
.54054 .62551 Mdot
.48441 .60056 Mdot
.54277 .35735 Mdot
.52651 .48446 Mdot
.56189 .42741 Mdot
.42705 .38459 Mdot
.43292 .72911 Mdot
.49127 .54895 Mdot
.69542 .48397 Mdot
.32184 .58761 Mdot
.52349 .567 Mdot
.69572 .48177 Mdot
.47201 .62472 Mdot
.35828 .4184 Mdot
.41297 .42465 Mdot
.59267 .25058 Mdot
.29814 .58796 Mdot
.35695 .74354 Mdot
.67127 .32495 Mdot
.32395 .42791 Mdot
.50702 .64951 Mdot
.50886 .29654 Mdot
.42372 .39573 Mdot
.4451 .37897 Mdot
.49874 .69431 Mdot
.66204 .45238 Mdot
.66973 .48568 Mdot
.34583 .62994 Mdot
.41434 .30007 Mdot
.19859 .36048 Mdot
.53173 .34283 Mdot
.48481 .65123 Mdot
.63942 .27658 Mdot
.67089 .48643 Mdot
.30124 .65858 Mdot
.30496 .58898 Mdot
.54517 .31191 Mdot
.33344 .46873 Mdot
.68691 .48753 Mdot
.66425 .44017 Mdot
.48997 .57355 Mdot
.53873 .6076 Mdot
.39664 .69927 Mdot
.37327 .59259 Mdot
.55334 .30386 Mdot
.29808 .61355 Mdot
.36893 .40278 Mdot
.49295 .63224 Mdot
.63996 .49288 Mdot
.7728 .35959 Mdot
.48588 .59566 Mdot
.34403 .42358 Mdot
.67724 .47806 Mdot
.31119 .60558 Mdot
.28 .61615 Mdot
.53083 .58439 Mdot
.57235 .73736 Mdot
.55302 .31807 Mdot
.67465 .48737 Mdot
.7082 .3014 Mdot
.54479 .66076 Mdot
.54321 .60538 Mdot
.51626 .70866 Mdot
.55773 .34719 Mdot
.60694 .24879 Mdot
.31207 .57326 Mdot
.6683 .45964 Mdot
.4819 .63123 Mdot
.29478 .58234 Mdot
.62283 .25715 Mdot
.42379 .41256 Mdot
.37542 .41022 Mdot
.28134 .61789 Mdot
.30731 .6047 Mdot
.29667 .6174 Mdot
.64836 .8003 Mdot
.70805 .45291 Mdot
.43814 .65976 Mdot
.53051 .66711 Mdot
.33728 .63702 Mdot
.45896 .6375 Mdot
.51894 .29636 Mdot
.39658 .40522 Mdot
.50835 .60471 Mdot
.49619 .57025 Mdot
.49328 .70733 Mdot
.45404 .68373 Mdot
.63653 .51388 Mdot
.68538 .46291 Mdot
.58387 .56975 Mdot
.40805 .40731 Mdot
.23088 .72046 Mdot
.84608 .55622 Mdot
.50449 .6757 Mdot
.56211 .45552 Mdot
.64412 .49443 Mdot
.55913 .35002 Mdot
.53758 .41876 Mdot
.51975 .30007 Mdot
.66715 .46577 Mdot
.4956 .63392 Mdot
.68241 .32157 Mdot
.2686 .61043 Mdot
.53091 .5756 Mdot
.5335 .31819 Mdot
.53223 .5773 Mdot
.55498 .30032 Mdot
.75828 .42336 Mdot
.45262 .19178 Mdot
.54238 .64239 Mdot
.55316 .65975 Mdot
.55038 .70659 Mdot
.52738 .60685 Mdot
.21823 .56647 Mdot
.64931 .49524 Mdot
.18616 .44443 Mdot
.48635 .57675 Mdot
.69037 .67391 Mdot
.53796 .66558 Mdot
.2272 .41064 Mdot
.54043 .60165 Mdot
.46657 .44176 Mdot
.54687 .64535 Mdot
.55709 .58838 Mdot
.51281 .30889 Mdot
.5422 .35722 Mdot
.64399 .50482 Mdot
.36174 .45413 Mdot
.77985 .64962 Mdot
.54305 .61298 Mdot
.44501 .37002 Mdot
.51203 .37942 Mdot
.30185 .60956 Mdot
.66493 .46567 Mdot
.16436 .61541 Mdot
.53739 .29621 Mdot
.29884 .47099 Mdot
.19059 .51352 Mdot
.44115 .37853 Mdot
.47702 .37886 Mdot
.58364 .49567 Mdot
.31573 .58535 Mdot
.5441 .65331 Mdot
.68425 .25568 Mdot
.36718 .24054 Mdot
.45861 .64793 Mdot
.50732 .34461 Mdot
.69503 .70228 Mdot
.75414 .33572 Mdot
.32706 .5979 Mdot
.28932 .57271 Mdot
.54127 .29835 Mdot
.31086 .45874 Mdot
.51651 .54253 Mdot
.30521 .58668 Mdot
.34474 .41636 Mdot
.40376 .43387 Mdot
.42829 .44337 Mdot
.65809 .45861 Mdot
.57139 .21966 Mdot
.64913 .35159 Mdot
.54982 .29988 Mdot
.30287 .63849 Mdot
.71726 .48686 Mdot
.70963 .48828 Mdot
.39111 .43732 Mdot
.33622 .42998 Mdot
.70916 .46364 Mdot
.54226 .54729 Mdot
.47603 .71166 Mdot
.53979 .62964 Mdot
.2951 .60247 Mdot
.53452 .6011 Mdot
.35058 .42377 Mdot
.54289 .31953 Mdot
.33406 .43598 Mdot
.52939 .29854 Mdot
.70939 .36364 Mdot
.51215 .58654 Mdot
.55697 .59308 Mdot
.36846 .75775 Mdot
.63709 .49722 Mdot
.65519 .249 Mdot
.45233 .3364 Mdot
.34297 .44282 Mdot
.5621 .60459 Mdot
.6634 .50157 Mdot
.30754 .62442 Mdot
.36261 .7568 Mdot
.52744 .57101 Mdot
.65107 .49647 Mdot
.4997 .64188 Mdot
.57007 .80171 Mdot
.33017 .24442 Mdot
.65598 .47368 Mdot
.162 .55202 Mdot
.48527 .62704 Mdot
.54736 .50999 Mdot
.5734 .59177 Mdot
.37695 .64078 Mdot
.54567 .65814 Mdot
.70343 .46307 Mdot
.53551 .62785 Mdot
.7035 .48206 Mdot
.31646 .44064 Mdot
.5685 .33914 Mdot
.64395 .45575 Mdot
.5076 .57359 Mdot
.73734 .75946 Mdot
.52509 .32891 Mdot
.5526 .6235 Mdot
.51925 .31391 Mdot
.69805 .46409 Mdot
.66318 .44197 Mdot
.4315 .8177 Mdot
.53665 .39243 Mdot
.5366 .34413 Mdot
.5087 .64257 Mdot
.62095 .34053 Mdot
.51198 .63734 Mdot
.3797 .68916 Mdot
.53525 .5594 Mdot
.54815 .65679 Mdot
.42182 .83487 Mdot
.56416 .318 Mdot
.20669 .35653 Mdot
.47023 .80653 Mdot
.63303 .80811 Mdot
.71765 .45769 Mdot
.32662 .59862 Mdot
.68825 .76967 Mdot
.4602 .36446 Mdot
.37844 .41687 Mdot
.5094 .60347 Mdot
.62212 .51448 Mdot
.55909 .3246 Mdot
.28044 .60479 Mdot
.54318 .64135 Mdot
.33628 .42833 Mdot
.28499 .47002 Mdot
.57461 .33331 Mdot
.66044 .46302 Mdot
.63586 .46456 Mdot
.14789 .55295 Mdot
.48236 .63417 Mdot
.55999 .60098 Mdot
.52384 .32345 Mdot
.44133 .60413 Mdot
.31897 .59531 Mdot
.24081 .43155 Mdot
.53556 .34342 Mdot
.52574 .45244 Mdot
.68321 .45734 Mdot
.51812 .60896 Mdot
.61397 .41237 Mdot
.38659 .45874 Mdot
.74425 .55015 Mdot
.29226 .59767 Mdot
.37834 .6973 Mdot
.70334 .46235 Mdot
.53711 .32471 Mdot
.41347 .32856 Mdot
.56967 .65705 Mdot
.52142 .61374 Mdot
.3743 .69851 Mdot
.38279 .56184 Mdot
.24085 .66238 Mdot
.56518 .57898 Mdot
.39089 .55199 Mdot
.56143 .58002 Mdot
.57342 .64168 Mdot
.54585 .55077 Mdot
.54736 .5999 Mdot
.64869 .49584 Mdot
.45342 .66086 Mdot
.38984 .41539 Mdot
.6476 .59001 Mdot
.5161 .40768 Mdot
.52437 .66254 Mdot
.50065 .6342 Mdot
.75935 .57555 Mdot
.5568 .37651 Mdot
.64012 .48001 Mdot
.64245 .42954 Mdot
.54741 .36122 Mdot
.47915 .70801 Mdot
.35331 .45562 Mdot
.46962 .68123 Mdot
.33846 .43228 Mdot
.65886 .49927 Mdot
.33954 .4452 Mdot
.57051 .34431 Mdot
.40777 .41715 Mdot
.45159 .3494 Mdot
.56018 .31654 Mdot
.67472 .44628 Mdot
.53978 .58521 Mdot
.51441 .348 Mdot
.34098 .70968 Mdot
.2956 .60166 Mdot
.43434 .8192 Mdot
.47464 .62327 Mdot
.54438 .40308 Mdot
.41432 .6242 Mdot
.33594 .43571 Mdot
.28157 .286 Mdot
.63654 .48322 Mdot
.26788 .61606 Mdot
.65735 .49964 Mdot
.52257 .18387 Mdot
.28389 .61087 Mdot
.51765 .83587 Mdot
.43594 .2893 Mdot
.29571 .43068 Mdot
.53382 .54745 Mdot
.59993 .64741 Mdot
.41445 .39426 Mdot
.55895 .32252 Mdot
.42452 .28694 Mdot
.55419 .58385 Mdot
.3046 .30429 Mdot
.63973 .50393 Mdot
.39296 .43949 Mdot
.53983 .33104 Mdot
.5194 .3542 Mdot
.5009 .58389 Mdot
.22564 .48806 Mdot
.54917 .5731 Mdot
.40135 .30012 Mdot
.41323 .72137 Mdot
.51659 .71265 Mdot
.55391 .62745 Mdot
.336 .45113 Mdot
.50088 .64244 Mdot
.47838 .72331 Mdot
.65172 .22786 Mdot
.47587 .56588 Mdot
.47301 .28061 Mdot
.30942 .63449 Mdot
.67794 .46694 Mdot
.49204 .66635 Mdot
.4451 .3763 Mdot
.48689 .63594 Mdot
.60242 .16271 Mdot
.29178 .58744 Mdot
.39916 .38094 Mdot
.53998 .66828 Mdot
.49571 .58959 Mdot
.61658 .5641 Mdot
.61667 .51647 Mdot
.33278 .46942 Mdot
.52657 .61702 Mdot
.43226 .74574 Mdot
.51669 .3299 Mdot
.54494 .57107 Mdot
.54952 .62183 Mdot
.7814 .50331 Mdot
.54866 .35159 Mdot
.33275 .44066 Mdot
.43339 .4071 Mdot
.35045 .40743 Mdot
.28044 .56667 Mdot
.50973 .42256 Mdot
.32528 .64751 Mdot
.34206 .24231 Mdot
.31804 .6091 Mdot
.47961 .61152 Mdot
.58202 .65494 Mdot
.4853 .61065 Mdot
.28074 .57561 Mdot
.55595 .34692 Mdot
.6383 .47697 Mdot
.60135 .26761 Mdot
.44011 .39068 Mdot
.57133 .59927 Mdot
.26996 .59427 Mdot
.66491 .44902 Mdot
.25705 .62727 Mdot
.67363 .46273 Mdot
.54153 .34057 Mdot
.52289 .36344 Mdot
.27555 .59447 Mdot
.67508 .49967 Mdot
.46386 .32067 Mdot
.44682 .80234 Mdot
.54058 .55837 Mdot
.48984 .30533 Mdot
.65097 .50235 Mdot
.65128 .51686 Mdot
.66551 .51109 Mdot
.5247 .58293 Mdot
.55845 .46174 Mdot
.55832 .6657 Mdot
.54876 .30292 Mdot
.36259 .41093 Mdot
.36809 .60386 Mdot
.76157 .38373 Mdot
.35776 .59405 Mdot
.46031 .6145 Mdot
.53607 .63559 Mdot
.55372 .61828 Mdot
.51844 .55693 Mdot
.3968 .32066 Mdot
.50467 .5902 Mdot
.51558 .30642 Mdot
.35475 .42726 Mdot
.52669 .66538 Mdot
.42331 .40987 Mdot
.58217 .44391 Mdot
.32294 .5893 Mdot
.50164 .41635 Mdot
.74846 .72502 Mdot
.66081 .449 Mdot
.38291 .4033 Mdot
.38142 .41721 Mdot
.30928 .61282 Mdot
.55767 .32681 Mdot
.67647 .45773 Mdot
.38667 .64809 Mdot
.29713 .61586 Mdot
.53778 .62567 Mdot
.28766 .35779 Mdot
.28147 .34214 Mdot
.55354 .64323 Mdot
.50211 .61307 Mdot
.42327 .41888 Mdot
.31313 .45786 Mdot
.78465 .32554 Mdot
.2755 .66977 Mdot
.27619 .5999 Mdot
.30918 .57549 Mdot
.69874 .49965 Mdot
.52638 .68203 Mdot
.54498 .30233 Mdot
.30488 .70275 Mdot
.39594 .57787 Mdot
.33787 .73247 Mdot
.25912 .5612 Mdot
.51382 .57615 Mdot
.60582 .67275 Mdot
.5383 .63953 Mdot
.63188 .47876 Mdot
.69185 .4549 Mdot
.64384 .46665 Mdot
.55542 .31647 Mdot
.64391 .72894 Mdot
.50934 .31976 Mdot
.78262 .67796 Mdot
.70535 .46374 Mdot
.3773 .34935 Mdot
.35476 .44552 Mdot
.4925 .66273 Mdot
.31618 .59837 Mdot
.57373 .30438 Mdot
.4931 .5547 Mdot
.23759 .35219 Mdot
.40349 .42049 Mdot
.6776 .44583 Mdot
.58395 .49852 Mdot
.82126 .54066 Mdot
.54533 .43126 Mdot
.54854 .52224 Mdot
.6138 .59635 Mdot
.29647 .61263 Mdot
.73989 .55159 Mdot
.28431 .56918 Mdot
.53841 .31233 Mdot
.55316 .58983 Mdot
.54643 .59041 Mdot
.56406 .59046 Mdot
.50721 .58957 Mdot
.54563 .35904 Mdot
.46323 .63281 Mdot
.47734 .16235 Mdot
.41336 .42563 Mdot
.59133 .79844 Mdot
.30105 .57904 Mdot
.50163 .33178 Mdot
.35086 .42817 Mdot
.349 .46191 Mdot
.31029 .67273 Mdot
.54414 .64742 Mdot
.50764 .60296 Mdot
.31916 .47236 Mdot
.56743 .58433 Mdot
.47277 .56058 Mdot
.39061 .41735 Mdot
.35923 .59245 Mdot
.31256 .61685 Mdot
.28478 .57839 Mdot
.55221 .34734 Mdot
.66806 .50036 Mdot
.30119 .59468 Mdot
.31792 .4416 Mdot
.46825 .625 Mdot
.49747 .57723 Mdot
.65069 .50297 Mdot
.56885 .20529 Mdot
.32711 .59159 Mdot
.58031 .49457 Mdot
.70173 .47962 Mdot
.70798 .45146 Mdot
.52063 .61522 Mdot
.45675 .64973 Mdot
.67826 .51809 Mdot
.29665 .62009 Mdot
.50206 .33763 Mdot
.3428 .39441 Mdot
.532 .31416 Mdot
.67414 .45235 Mdot
.50798 .56754 Mdot
.67988 .45033 Mdot
.49136 .64566 Mdot
.57366 .88262 Mdot
.54489 .59497 Mdot
.37892 .21105 Mdot
.36854 .65434 Mdot
.38051 .42086 Mdot
.46343 .32545 Mdot
.39256 .43764 Mdot
.70333 .47427 Mdot
.51343 .56844 Mdot
.30592 .57171 Mdot
.58309 .83397 Mdot
.71438 .4926 Mdot
.36579 .4153 Mdot
.33336 .46108 Mdot
.56337 .32279 Mdot
.52292 .66688 Mdot
.52174 .60946 Mdot
.38984 .43046 Mdot
.43643 .69405 Mdot
.6811 .49238 Mdot
.55912 .6076 Mdot
.52402 .63421 Mdot
.38475 .42043 Mdot
.44102 .79938 Mdot
.60119 .52005 Mdot
.55269 .59608 Mdot
.42025 .35195 Mdot
.51257 .30256 Mdot
.52425 .5513 Mdot
.46291 .63468 Mdot
.3115 .5959 Mdot
.64247 .7732 Mdot
.67079 .23816 Mdot
.5255 .29182 Mdot
.36643 .45149 Mdot
.47839 .62871 Mdot
.35919 .44407 Mdot
.50129 .5759 Mdot
.74382 .67864 Mdot
.40138 .43387 Mdot
.494 .60201 Mdot
.51033 .68132 Mdot
.68801 .45024 Mdot
.5017 .58975 Mdot
.77193 .55074 Mdot
.40034 .39704 Mdot
.49682 .59594 Mdot
.57711 .73238 Mdot
.53562 .3516 Mdot
.50162 .67501 Mdot
.29745 .57518 Mdot
.38026 .63548 Mdot
.67274 .33624 Mdot
.43295 .36669 Mdot
.28779 .57851 Mdot
.53653 .57566 Mdot
.31052 .4618 Mdot
.55048 .2989 Mdot
.29838 .30304 Mdot
.56313 .60988 Mdot
.52577 .32347 Mdot
.54247 .32184 Mdot
.28832 .58312 Mdot
.17376 .40736 Mdot
.46933 .64168 Mdot
.52874 .60454 Mdot
.78081 .54462 Mdot
.63455 .45313 Mdot
.53606 .59713 Mdot
.48329 .59978 Mdot
.51667 .3075 Mdot
.61399 .53076 Mdot
.73 .65032 Mdot
.22837 .4531 Mdot
.54463 .29031 Mdot
.35036 .40337 Mdot
.31037 .46301 Mdot
.30333 .58075 Mdot
.67373 .47318 Mdot
.31257 .56769 Mdot
.399 .411 Mdot
.4805 .61595 Mdot
.53043 .30127 Mdot
.75617 .49419 Mdot
.56134 .30245 Mdot
.42872 .37381 Mdot
.63065 .4891 Mdot
.63338 .28573 Mdot
.52645 .13952 Mdot
.65751 .35633 Mdot
.57816 .35904 Mdot
.30212 .60933 Mdot
.33562 .31641 Mdot
.52814 .6349 Mdot
.72163 .55849 Mdot
.53658 .58256 Mdot
.59123 .71164 Mdot
.37427 .40631 Mdot
.34447 .462 Mdot
.55259 .59188 Mdot
.4003 .71346 Mdot
.56753 .30882 Mdot
.56267 .31604 Mdot
.49968 .60035 Mdot
.55013 .33478 Mdot
.53637 .61061 Mdot
.34216 .42803 Mdot
.2325 .31955 Mdot
.54357 .63235 Mdot
.57034 .63798 Mdot
.59623 .31785 Mdot
.45095 .82565 Mdot
.44855 .30203 Mdot
.60907 .66051 Mdot
.81929 .50912 Mdot
.5498 .33424 Mdot
.50908 .69001 Mdot
.42238 .39063 Mdot
.4243 .41788 Mdot
.46422 .32254 Mdot
.53331 .59132 Mdot
.52817 .59037 Mdot
.56157 .60747 Mdot
.49951 .62864 Mdot
.72606 .55938 Mdot
.4428 .62529 Mdot
.62257 .68894 Mdot
.50534 .60413 Mdot
.56807 .70654 Mdot
.51469 .34652 Mdot
.61618 .47371 Mdot
.31825 .56916 Mdot
.51196 .577 Mdot
.70024 .51859 Mdot
.50783 .30937 Mdot
.78464 .67505 Mdot
.56081 .3379 Mdot
.35477 .43684 Mdot
.5655 .34121 Mdot
.50555 .65674 Mdot
.66426 .47785 Mdot
.41957 .38655 Mdot
.35922 .26885 Mdot
.37668 .41686 Mdot
.50769 .65998 Mdot
.38358 .38162 Mdot
.38195 .41539 Mdot
.58696 .42567 Mdot
.66853 .47947 Mdot
.42455 .74722 Mdot
.69218 .45476 Mdot
.49336 .59986 Mdot
.49102 .60625 Mdot
.47357 .31646 Mdot
.57199 .32646 Mdot
.69757 .46049 Mdot
.19485 .33547 Mdot
.28609 .56734 Mdot
.64602 .46729 Mdot
.58504 .61448 Mdot
.46401 .50027 Mdot
.65978 .48288 Mdot
.41969 .6929 Mdot
.55846 .31726 Mdot
.70889 .47469 Mdot
.58294 .62478 Mdot
.49707 .22421 Mdot
.27367 .61752 Mdot
.32515 .45591 Mdot
.44891 .46107 Mdot
.40961 .39665 Mdot
.50205 .34249 Mdot
.40197 .42458 Mdot
.51544 .33244 Mdot
.64616 .24854 Mdot
.52554 .74602 Mdot
.51096 .29326 Mdot
.51108 .35476 Mdot
.39784 .4213 Mdot
.55684 .62541 Mdot
.46321 .41166 Mdot
.56167 .56816 Mdot
.50203 .55255 Mdot
.51868 .33962 Mdot
.70106 .45861 Mdot
.69314 .4431 Mdot
.58041 .68666 Mdot
.63551 .46449 Mdot
.3372 .43165 Mdot
.33441 .2425 Mdot
.62183 .22892 Mdot
.52057 .33157 Mdot
.52945 .36122 Mdot
.50861 .63658 Mdot
.37663 .43566 Mdot
.31332 .4416 Mdot
.54749 .3074 Mdot
.70632 .54445 Mdot
.54812 .67053 Mdot
.63554 .50614 Mdot
.70627 .46394 Mdot
.65403 .4775 Mdot
.67827 .50846 Mdot
.72594 .63543 Mdot
.55873 .31631 Mdot
.7049 .46875 Mdot
.49657 .60264 Mdot
.52932 .59128 Mdot
.44988 .37911 Mdot
.28701 .57714 Mdot
.4739 .63121 Mdot
.55534 .55046 Mdot
.51795 .61383 Mdot
.37625 .41094 Mdot
.592 .59683 Mdot
.36487 .45355 Mdot
.318 .45381 Mdot
.41797 .41417 Mdot
.4555 .36308 Mdot
.60354 .6265 Mdot
.82803 .50007 Mdot
.50169 .63937 Mdot
.43721 .60196 Mdot
.35543 .44415 Mdot
.26194 .31242 Mdot
.61238 .25427 Mdot
.56264 .60672 Mdot
.40062 .4565 Mdot
.39185 .43042 Mdot
.64321 .44757 Mdot
.53713 .59189 Mdot
.44542 .38964 Mdot
.32242 .59134 Mdot
.58476 .59476 Mdot
.44 .39872 Mdot
.68419 .49684 Mdot
.31965 .56252 Mdot
.70661 .48428 Mdot
.41582 .40956 Mdot
.50811 .68007 Mdot
.88793 .47871 Mdot
.34762 .40903 Mdot
.52814 .81717 Mdot
.66785 .52769 Mdot
.55938 .61003 Mdot
.38374 .40226 Mdot
.63384 .45557 Mdot
.49959 .33504 Mdot
.43261 .51597 Mdot
.63617 .47539 Mdot
.34885 .46077 Mdot
.43924 .39661 Mdot
.38848 .41704 Mdot
.68572 .46685 Mdot
.53603 .56494 Mdot
.68897 .47685 Mdot
.56526 .34043 Mdot
.52882 .64571 Mdot
.80945 .59996 Mdot
.4379 .61082 Mdot
.70259 .47239 Mdot
.32774 .43443 Mdot
.26524 .5944 Mdot
.53814 .64808 Mdot
.5158 .80851 Mdot
.48889 .64944 Mdot
.51931 .32335 Mdot
.21129 .40723 Mdot
.75734 .50403 Mdot
.53571 .66497 Mdot
.50718 .63582 Mdot
.55784 .30727 Mdot
.54244 .64763 Mdot
.54108 .66054 Mdot
.51102 .38197 Mdot
.69062 .46512 Mdot
.5331 .63021 Mdot
.33005 .42583 Mdot
.68545 .26374 Mdot
.55355 .66802 Mdot
.33565 .4907 Mdot
.41182 .73447 Mdot
.19697 .41328 Mdot
.54092 .58129 Mdot
.29861 .68609 Mdot
.49883 .62339 Mdot
.5242 .57782 Mdot
.51171 .64119 Mdot
.61677 .63729 Mdot
.40267 .41687 Mdot
.36003 .42139 Mdot
.27753 .61921 Mdot
.41758 .7376 Mdot
.31001 .59275 Mdot
.56055 .33163 Mdot
.29145 .50396 Mdot
.40358 .43184 Mdot
.68335 .49791 Mdot
.5434 .5742 Mdot
.40057 .39548 Mdot
.51733 .60623 Mdot
.50055 .65313 Mdot
.33371 .45231 Mdot
.30991 .44342 Mdot
.43714 .37466 Mdot
.31449 .57921 Mdot
.64227 .46294 Mdot
.48322 .57735 Mdot
.2804 .6146 Mdot
.53368 .56558 Mdot
.32198 .64295 Mdot
.6412 .46892 Mdot
.69101 .46779 Mdot
.66648 .43686 Mdot
.48034 .61719 Mdot
.52033 .66127 Mdot
.50931 .32179 Mdot
.67352 .50132 Mdot
.54188 .3493 Mdot
.42388 .3865 Mdot
.30427 .49279 Mdot
.53311 .59128 Mdot
.55757 .50324 Mdot
.31408 .58961 Mdot
.35014 .43455 Mdot
.3176 .47652 Mdot
.26489 .61095 Mdot
.49118 .64989 Mdot
.33926 .45094 Mdot
.27774 .58202 Mdot
.67047 .54873 Mdot
.83001 .45602 Mdot
.26879 .58554 Mdot
.49791 .60345 Mdot
.62309 .54185 Mdot
.42092 .78602 Mdot
.27667 .57125 Mdot
.52513 .30891 Mdot
.47967 .61694 Mdot
.42378 .63434 Mdot
.32497 .58314 Mdot
.68379 .27023 Mdot
.37821 .42325 Mdot
.51157 .23646 Mdot
.56335 .54309 Mdot
.69537 .56646 Mdot
.30362 .5648 Mdot
.67242 .45856 Mdot
.62566 .454 Mdot
.51425 .62119 Mdot
.28693 .56286 Mdot
.54948 .29225 Mdot
.3707 .42543 Mdot
.45523 .34562 Mdot
.68624 .4693 Mdot
.6085 .34114 Mdot
.34997 .41658 Mdot
.5722 .4946 Mdot
.22428 .42794 Mdot
.48512 .71737 Mdot
.56673 .7242 Mdot
.39305 .23091 Mdot
.48102 .59938 Mdot
.27698 .57583 Mdot
.50884 .31009 Mdot
.53765 .29814 Mdot
.5354 .34156 Mdot
.4626 .32904 Mdot
.53013 .41733 Mdot
.41686 .40299 Mdot
.33048 .28906 Mdot
.29604 .58267 Mdot
.45245 .7594 Mdot
.53157 .56727 Mdot
.53769 .63501 Mdot
.48346 .64989 Mdot
.55071 .57106 Mdot
.50623 .62593 Mdot
.55534 .3319 Mdot
.46181 .32601 Mdot
.30952 .4008 Mdot
.64726 .48159 Mdot
.35437 .5873 Mdot
.35418 .44566 Mdot
.41963 .42215 Mdot
.28024 .59661 Mdot
.58711 .47617 Mdot
.4244 .39955 Mdot
.33893 .4443 Mdot
.47495 .64001 Mdot
.68884 .48531 Mdot
.4585 .66091 Mdot
.49077 .61544 Mdot
.34714 .43283 Mdot
.34379 .53152 Mdot
.75544 .6116 Mdot
.53904 .69165 Mdot
.33454 .58791 Mdot
.54309 .47255 Mdot
.27647 .57205 Mdot
.5747 .59222 Mdot
.25173 .32408 Mdot
.39941 .41176 Mdot
.36627 .43508 Mdot
.27419 .58302 Mdot
.56574 .51259 Mdot
.67949 .47487 Mdot
.33596 .4648 Mdot
.51581 .31851 Mdot
.48727 .60632 Mdot
.30161 .48275 Mdot
.53112 .51495 Mdot
.24257 .48269 Mdot
.52879 .33859 Mdot
.31832 .44742 Mdot
.52504 .66707 Mdot
.4984 .60547 Mdot
.30198 .61092 Mdot
.74788 .42328 Mdot
.5832 .57697 Mdot
.63644 .80693 Mdot
.46309 .19326 Mdot
.528 .21285 Mdot
.52161 .61366 Mdot
.68852 .46395 Mdot
.43056 .40808 Mdot
.2887 .61541 Mdot
.46443 .60865 Mdot
.82921 .46991 Mdot
.62628 .49166 Mdot
.53652 .31813 Mdot
.44757 .38624 Mdot
.53793 .41795 Mdot
.48118 .63575 Mdot
.53678 .58345 Mdot
.51743 .58559 Mdot
.8141 .38028 Mdot
.36183 .41424 Mdot
.63353 .48807 Mdot
.28995 .59886 Mdot
.63431 .46856 Mdot
.36934 .42038 Mdot
.61412 .295 Mdot
.53254 .66019 Mdot
.63145 .49582 Mdot
.67089 .46148 Mdot
.56328 .32389 Mdot
.50027 .34196 Mdot
.34821 .40021 Mdot
.54493 .59654 Mdot
.44334 .39275 Mdot
.68889 .44941 Mdot
.31741 .46797 Mdot
.28606 .61184 Mdot
.50794 .33503 Mdot
.5056 .60263 Mdot
.39275 .41282 Mdot
.4575 .62005 Mdot
.66469 .48783 Mdot
.34005 .44452 Mdot
.44529 .37308 Mdot
.30616 .57487 Mdot
.51768 .59532 Mdot
.3316 .60112 Mdot
.36528 .4516 Mdot
.52498 .63533 Mdot
.59476 .48727 Mdot
.33416 .56914 Mdot
.36952 .27534 Mdot
.41178 .40144 Mdot
.45113 .36973 Mdot
.66757 .43818 Mdot
.68598 .28272 Mdot
.36496 .43366 Mdot
.59333 .47517 Mdot
.72753 .39207 Mdot
.48227 .57782 Mdot
.6567 .46692 Mdot
.31451 .33135 Mdot
.70205 .77476 Mdot
.47955 .78674 Mdot
.55206 .62294 Mdot
.39463 .40131 Mdot
.27124 .59702 Mdot
.52027 .33217 Mdot
.33504 .48974 Mdot
.48188 .72315 Mdot
.35608 .45045 Mdot
.50725 .63914 Mdot
.69251 .45852 Mdot
.54908 .31347 Mdot
.69382 .33197 Mdot
.3211 .4392 Mdot
.38057 .40579 Mdot
.52938 .66608 Mdot
.30358 .58854 Mdot
.52677 .77886 Mdot
.34749 .424 Mdot
.30011 .4691 Mdot
.3414 .31033 Mdot
.26968 .59337 Mdot
.49926 .6171 Mdot
.57529 .69197 Mdot
.51863 .55528 Mdot
.54006 .82222 Mdot
.38022 .44443 Mdot
.64853 .48507 Mdot
.53312 .58021 Mdot
.22042 .45856 Mdot
.35405 .43099 Mdot
.56296 .45236 Mdot
.3286 .52556 Mdot
.55804 .31582 Mdot
.29981 .47382 Mdot
.52934 .59967 Mdot
.56652 .30725 Mdot
.31381 .58981 Mdot
.55106 .59921 Mdot
.52 .66042 Mdot
.63561 .45596 Mdot
.53834 .31095 Mdot
.76883 .41187 Mdot
.51535 .35271 Mdot
.51983 .29781 Mdot
.67533 .4331 Mdot
.5275 .6236 Mdot
.34989 .43863 Mdot
.38952 .43265 Mdot
.47657 .58451 Mdot
.27765 .27804 Mdot
.68177 .47496 Mdot
.29268 .64107 Mdot
.79526 .35729 Mdot
.55347 .6917 Mdot
.31399 .4771 Mdot
.74336 .42102 Mdot
.54891 .29282 Mdot
.50179 .6023 Mdot
.6962 .4849 Mdot
.30423 .46418 Mdot
.34751 .41716 Mdot
.51887 .56492 Mdot
.54631 .32 Mdot
.32032 .60293 Mdot
.34765 .41022 Mdot
.22696 .48626 Mdot
.51175 .58406 Mdot
.31296 .30286 Mdot
.36929 .40506 Mdot
.60951 .83422 Mdot
.2766 .42889 Mdot
.65377 .46979 Mdot
.50393 .65422 Mdot
.63714 .46226 Mdot
.29081 .60348 Mdot
.36261 .39848 Mdot
.54438 .3194 Mdot
.56072 .68541 Mdot
.58708 .17427 Mdot
.40094 .42013 Mdot
.64758 .4949 Mdot
.53487 .6657 Mdot
.59996 .60134 Mdot
.53319 .60362 Mdot
.61118 .53759 Mdot
.2845 .64086 Mdot
.5223 .34394 Mdot
.52071 .31874 Mdot
.5287 .63843 Mdot
.31223 .60785 Mdot
.32326 .44903 Mdot
.37054 .42644 Mdot
.34081 .8274 Mdot
.32449 .46833 Mdot
.39401 .69203 Mdot
.52453 .59194 Mdot
.32152 .46566 Mdot
.75781 .36386 Mdot
.52339 .32468 Mdot
.54795 .5679 Mdot
.34548 .45942 Mdot
.47867 .21222 Mdot
.35454 .61386 Mdot
.50494 .62332 Mdot
.4997 .54042 Mdot
.51759 .31649 Mdot
.36468 .73967 Mdot
.41356 .40964 Mdot
.54179 .56175 Mdot
.55193 .36204 Mdot
.20594 .46272 Mdot
.61776 .21399 Mdot
.6425 .46282 Mdot
.39528 .39531 Mdot
.55579 .33129 Mdot
.57119 .54768 Mdot
.29792 .57793 Mdot
.407 .39559 Mdot
.37302 .41278 Mdot
.513 .64671 Mdot
.47926 .64915 Mdot
.56908 .68503 Mdot
.65097 .49429 Mdot
.52199 .35247 Mdot
.55265 .58633 Mdot
.60592 .34509 Mdot
.56275 .58505 Mdot
.51035 .33577 Mdot
.90197 .5547 Mdot
.52122 .54773 Mdot
.532 .60563 Mdot
.51952 .7819 Mdot
.63648 .47159 Mdot
.63669 .45844 Mdot
.40973 .20153 Mdot
.52388 .59229 Mdot
.27648 .44858 Mdot
.64296 .45891 Mdot
.67952 .47903 Mdot
.35205 .35514 Mdot
.54094 .6407 Mdot
.35833 .75176 Mdot
.53989 .29984 Mdot
.52247 .29981 Mdot
.68814 .47524 Mdot
.57884 .56187 Mdot
.54595 .294 Mdot
.73367 .58197 Mdot
.37728 .43616 Mdot
.24238 .33373 Mdot
.66405 .49043 Mdot
.48292 .39714 Mdot
.52342 .33275 Mdot
.77918 .68293 Mdot
.399 .45366 Mdot
.55936 .6156 Mdot
.51544 .59278 Mdot
.31258 .58595 Mdot
.48508 .57325 Mdot
.35558 .45836 Mdot
.55016 .33517 Mdot
.55805 .7777 Mdot
.64444 .466 Mdot
.54216 .60188 Mdot
.58088 .47619 Mdot
.6988 .35133 Mdot
.44631 .27897 Mdot
.6771 .46694 Mdot
.65664 .46118 Mdot
.40979 .40683 Mdot
.3683 .40732 Mdot
.51956 .62403 Mdot
.54914 .30442 Mdot
.68185 .50007 Mdot
.5123 .33608 Mdot
.39694 .41101 Mdot
.34146 .44154 Mdot
.40225 .4336 Mdot
.56501 .56873 Mdot
.32623 .44144 Mdot
.21422 .49372 Mdot
.61021 .32793 Mdot
.70875 .49 Mdot
.63749 .19971 Mdot
.69364 .33017 Mdot
.40556 .62133 Mdot
.30871 .5715 Mdot
.3648 .45155 Mdot
.55201 .35543 Mdot
.51113 .63596 Mdot
.51214 .60456 Mdot
.43825 .38997 Mdot
.56885 .32552 Mdot
.28391 .60597 Mdot
.5699 .32313 Mdot
.28975 .58087 Mdot
.31163 .46966 Mdot
.51694 .66708 Mdot
.49303 .5849 Mdot
.55134 .33749 Mdot
.33241 .4446 Mdot
.35628 .4254 Mdot
.27817 .57135 Mdot
.38245 .57122 Mdot
.38888 .41565 Mdot
.66448 .4898 Mdot
.71399 .6417 Mdot
.43519 .40117 Mdot
.5367 .59392 Mdot
.315 .6512 Mdot
.7284 .54473 Mdot
.52278 .55802 Mdot
.45362 .37464 Mdot
.20665 .64325 Mdot
.54281 .5772 Mdot
.17827 .60122 Mdot
.452 .36904 Mdot
.63544 .47632 Mdot
.39313 .40223 Mdot
.35439 .45976 Mdot
.52784 .52612 Mdot
.26317 .62168 Mdot
.4702 .60413 Mdot
.63997 .45933 Mdot
.63288 .45007 Mdot
.50118 .19731 Mdot
.52915 .81808 Mdot
.28593 .56961 Mdot
.27877 .59062 Mdot
.36898 .43167 Mdot
.3707 .80189 Mdot
.56347 .6659 Mdot
.27751 .60138 Mdot
.49688 .75607 Mdot
.50005 .63588 Mdot
.36808 .68719 Mdot
.4014 .45997 Mdot
.68786 .46699 Mdot
.59503 .6593 Mdot
.36006 .43247 Mdot
.64352 .49088 Mdot
.59796 .27656 Mdot
.47576 .63115 Mdot
.64184 .46974 Mdot
.51001 .32881 Mdot
.41465 .24217 Mdot
.66069 .44301 Mdot
.30698 .6509 Mdot
.54879 .3068 Mdot
.35221 .3179 Mdot
.47488 .75083 Mdot
.47552 .11765 Mdot
.55458 .32824 Mdot
.35366 .44846 Mdot
.39002 .43159 Mdot
.37297 .42663 Mdot
.63601 .48481 Mdot
.31412 .44525 Mdot
.65742 .49602 Mdot
.41712 .79259 Mdot
.38261 .57243 Mdot
.27506 .59506 Mdot
.54314 .39146 Mdot
.66462 .46043 Mdot
.30961 .27134 Mdot
.54404 .14567 Mdot
.50072 .5979 Mdot
.52498 .35866 Mdot
.27739 .57989 Mdot
.56311 .85121 Mdot
.3124 .59216 Mdot
.42085 .3916 Mdot
.22057 .35762 Mdot
.54035 .60982 Mdot
.70194 .7031 Mdot
.30201 .57137 Mdot
.68052 .45793 Mdot
.52967 .63585 Mdot
.46568 .31783 Mdot
.30577 .58511 Mdot
.3212 .59837 Mdot
.51923 .6289 Mdot
.67873 .44597 Mdot
.34428 .4388 Mdot
.56028 .35306 Mdot
.2637 .58318 Mdot
.47875 .5422 Mdot
.48627 .57463 Mdot
.47644 .619 Mdot
.55969 .43193 Mdot
.4709 .72544 Mdot
.55019 .33312 Mdot
.43591 .77729 Mdot
.36633 .40825 Mdot
.32009 .3467 Mdot
.42154 .20057 Mdot
.5045 .38547 Mdot
.39187 .43744 Mdot
.37838 .44631 Mdot
.50956 .62501 Mdot
.472 .72723 Mdot
.20569 .42029 Mdot
.5879 .35453 Mdot
.43209 .40453 Mdot
.36594 .42642 Mdot
.62214 .46094 Mdot
.50598 .19213 Mdot
.46348 .60386 Mdot
.53584 .28744 Mdot
.38726 .4127 Mdot
.74679 .67502 Mdot
.29923 .58918 Mdot
.27741 .30035 Mdot
.52973 .66448 Mdot
.55722 .59379 Mdot
.54133 .33413 Mdot
.51012 .31664 Mdot
.48318 .29684 Mdot
.48083 .19239 Mdot
.3018 .71244 Mdot
.71836 .3223 Mdot
.74891 .66652 Mdot
.617 .47478 Mdot
.70244 .47041 Mdot
.46164 .35939 Mdot
.50664 .34063 Mdot
.53572 .57794 Mdot
.68444 .4983 Mdot
.43133 .27941 Mdot
.69342 .42411 Mdot
.3816 .69398 Mdot
.25997 .46572 Mdot
.49155 .64818 Mdot
.69335 .48064 Mdot
.63936 .4829 Mdot
.68375 .50263 Mdot
.45513 .36852 Mdot
.52696 .61641 Mdot
.55019 .63572 Mdot
.55598 .58048 Mdot
.44646 .59092 Mdot
.50567 .58674 Mdot
.57912 .37261 Mdot
.53036 .45565 Mdot
.59727 .77874 Mdot
.53408 .55485 Mdot
.53412 .29566 Mdot
.47581 .60931 Mdot
.3126 .6084 Mdot
.51052 .63945 Mdot
.38274 .68867 Mdot
.52983 .32637 Mdot
.58207 .51879 Mdot
.71128 .31437 Mdot
.53076 .66241 Mdot
.31723 .6112 Mdot
.42356 .64999 Mdot
.76539 .43091 Mdot
.36143 .57558 Mdot
.66598 .48972 Mdot
.38015 .43946 Mdot
.56391 .34047 Mdot
.35194 .43982 Mdot
.54832 .55889 Mdot
.45526 .37495 Mdot
.64001 .38082 Mdot
.47988 .39939 Mdot
.52357 .57273 Mdot
.57036 .66581 Mdot
.67354 .48586 Mdot
.34082 .45064 Mdot
.6123 .47051 Mdot
.52669 .58325 Mdot
.29352 .59956 Mdot
.30246 .58258 Mdot
.56938 .24862 Mdot
.78094 .64027 Mdot
.66934 .26883 Mdot
.54315 .33507 Mdot
.35054 .42138 Mdot
.30416 .56396 Mdot
.44585 .57064 Mdot
.51303 .2972 Mdot
.55986 .30909 Mdot
.54297 .31001 Mdot
.4831 .61709 Mdot
.3629 .45427 Mdot
.59496 .77098 Mdot
.35267 .45926 Mdot
.52823 .66057 Mdot
.36554 .41234 Mdot
.39134 .44058 Mdot
.30931 .58156 Mdot
.55271 .34745 Mdot
.39596 .40875 Mdot
.49332 .59796 Mdot
.65431 .45102 Mdot
.40494 .54045 Mdot
.36418 .63472 Mdot
.56663 .81581 Mdot
.58491 .81058 Mdot
.68855 .44465 Mdot
.762 .69024 Mdot
.55668 .28709 Mdot
.70412 .54612 Mdot
.3998 .36409 Mdot
.50458 .56758 Mdot
.33865 .22713 Mdot
.41759 .40372 Mdot
.34012 .45169 Mdot
.49739 .61833 Mdot
.30873 .452 Mdot
.53931 .60296 Mdot
.38301 .40701 Mdot
.35389 .58226 Mdot
.45888 .6304 Mdot
.32622 .44662 Mdot
.57766 .59713 Mdot
.53574 .64842 Mdot
.68942 .46754 Mdot
.38838 .40093 Mdot
.55831 .57028 Mdot
.47653 .8573 Mdot
.50748 .32828 Mdot
.45362 .37316 Mdot
.25136 .6489 Mdot
.55586 .33302 Mdot
.64615 .47092 Mdot
.49507 .55738 Mdot
.31295 .60026 Mdot
.67089 .45477 Mdot
.32276 .63041 Mdot
.29519 .57156 Mdot
.32958 .24366 Mdot
.67288 .48934 Mdot
.43546 .39926 Mdot
.31286 .58142 Mdot
.54363 .67815 Mdot
.37566 .40115 Mdot
.40212 .56507 Mdot
.37783 .44498 Mdot
.52175 .60851 Mdot
.45874 .32498 Mdot
.5072 .33531 Mdot
.55244 .6189 Mdot
.33229 .41684 Mdot
.45501 .36139 Mdot
.48438 .62415 Mdot
.50709 .63207 Mdot
.55784 .20615 Mdot
.26901 .33739 Mdot
.29483 .61233 Mdot
.62733 .47073 Mdot
.49631 .60244 Mdot
.31593 .58104 Mdot
.24933 .5313 Mdot
.47893 .60627 Mdot
.64091 .50143 Mdot
.48423 .69733 Mdot
.34821 .41184 Mdot
.54456 .34926 Mdot
.41229 .38933 Mdot
.32205 .58911 Mdot
.15797 .39634 Mdot
.4048 .43263 Mdot
.57505 .59671 Mdot
.54108 .56936 Mdot
.45114 .28932 Mdot
.64283 .48828 Mdot
.306 .71263 Mdot
.51738 .59514 Mdot
.44304 .66112 Mdot
.55076 .60355 Mdot
.28772 .41885 Mdot
.68011 .47588 Mdot
.52777 .60544 Mdot
.56136 .49545 Mdot
.56102 .65619 Mdot
.3222 .60144 Mdot
.4947 .78427 Mdot
.48228 .58989 Mdot
.86097 .37919 Mdot
.31802 .47355 Mdot
.32531 .44534 Mdot
.46331 .30259 Mdot
.25857 .72768 Mdot
.65582 .25442 Mdot
.65687 .49671 Mdot
.70536 .40304 Mdot
.34767 .43942 Mdot
.70392 .2896 Mdot
.74681 .71576 Mdot
.53317 .65022 Mdot
.48194 .63665 Mdot
.42083 .39159 Mdot
.32659 .4655 Mdot
.44226 .39511 Mdot
.54342 .55453 Mdot
.55181 .67974 Mdot
.32542 .43585 Mdot
.49558 .5899 Mdot
.4693 .67968 Mdot
.55698 .35551 Mdot
.67891 .44294 Mdot
.5215 .33794 Mdot
.56034 .34054 Mdot
.68022 .59841 Mdot
.47989 .19793 Mdot
.51041 .33714 Mdot
.55322 .28682 Mdot
.36993 .68085 Mdot
.56731 .69148 Mdot
.32211 .57853 Mdot
.69344 .75488 Mdot
.37858 .42585 Mdot
.52893 .61767 Mdot
.69894 .44913 Mdot
.67907 .57508 Mdot
.37793 .48184 Mdot
.20662 .39494 Mdot
.52979 .58039 Mdot
.35988 .4303 Mdot
.44879 .36831 Mdot
.46349 .6579 Mdot
.32858 .34934 Mdot
.55971 .59839 Mdot
.4004 .39557 Mdot
.69 .68829 Mdot
.58535 .49054 Mdot
.30671 .3331 Mdot
.62674 .43542 Mdot
.54684 .58571 Mdot
.65818 .4907 Mdot
.52817 .34052 Mdot
.31795 .59797 Mdot
.29578 .61142 Mdot
.52098 .63329 Mdot
.4708 .70983 Mdot
.41323 .45397 Mdot
.53642 .65017 Mdot
.51835 .64573 Mdot
.45135 .36907 Mdot
.52089 .64581 Mdot
.54323 .57039 Mdot
.55288 .57442 Mdot
.55983 .6475 Mdot
.52125 .29717 Mdot
.58027 .48312 Mdot
.56338 .56346 Mdot
.46075 .66321 Mdot
.5668 .3506 Mdot
.72129 .40244 Mdot
.55306 .35013 Mdot
.81107 .59636 Mdot
.51816 .3264 Mdot
.28367 .60956 Mdot
.45116 .33229 Mdot
.49737 .71391 Mdot
.70284 .48654 Mdot
.50222 .31891 Mdot
.28613 .59262 Mdot
.54217 .34118 Mdot
.35792 .41374 Mdot
.75137 .29721 Mdot
.6966 .42597 Mdot
.29123 .69082 Mdot
.55833 .24929 Mdot
.32765 .30025 Mdot
.40835 .41375 Mdot
.68447 .4747 Mdot
.75572 .61854 Mdot
.55917 .57648 Mdot
.31054 .57832 Mdot
.51611 .62641 Mdot
.51928 .29743 Mdot
.36577 .42992 Mdot
.47552 .79244 Mdot
.30653 .6078 Mdot
.57706 .19626 Mdot
.37491 .42269 Mdot
.56484 .60152 Mdot
.53528 .28788 Mdot
.62509 .19038 Mdot
.52149 .34116 Mdot
.37539 .58598 Mdot
.64499 .51005 Mdot
.57912 .70868 Mdot
.66011 .46546 Mdot
.42388 .42273 Mdot
.81757 .36528 Mdot
.65132 .7911 Mdot
.66648 .44709 Mdot
.27479 .37526 Mdot
.4825 .63451 Mdot
.47602 .6161 Mdot
.58684 .50829 Mdot
.63411 .49157 Mdot
.50068 .59389 Mdot
.44577 .37359 Mdot
.61964 .31808 Mdot
.26006 .40637 Mdot
.37445 .44232 Mdot
.53479 .59948 Mdot
.56221 .35531 Mdot
.56891 .31952 Mdot
.36471 .45448 Mdot
.54849 .353 Mdot
.55079 .63354 Mdot
.66309 .4625 Mdot
.46345 .39767 Mdot
.3025 .60308 Mdot
.48202 .83683 Mdot
.31269 .5649 Mdot
.39482 .43458 Mdot
.50978 .68052 Mdot
.34064 .44186 Mdot
.13356 .58755 Mdot
.55667 .6206 Mdot
.64033 .465 Mdot
.49412 .62701 Mdot
.55027 .5901 Mdot
.47635 .62904 Mdot
.32981 .42963 Mdot
.24518 .67089 Mdot
.49439 .59202 Mdot
.54406 .3179 Mdot
.61781 .78671 Mdot
.47443 .61269 Mdot
.35299 .57219 Mdot
.4268 .7332 Mdot
.33348 .28465 Mdot
.70963 .47902 Mdot
.33576 .4502 Mdot
.64867 .46055 Mdot
.65812 .42488 Mdot
.64598 .47133 Mdot
.63383 .76397 Mdot
.74115 .63731 Mdot
.20484 .62488 Mdot
.58203 .72838 Mdot
.6561 .56847 Mdot
.62608 .48016 Mdot
.23191 .55648 Mdot
.69967 .48339 Mdot
.6473 .48924 Mdot
.71023 .8241 Mdot
.70499 .47338 Mdot
.52975 .59469 Mdot
.46738 .63096 Mdot
.67128 .35125 Mdot
.34988 .68432 Mdot
.52422 .64146 Mdot
.49502 .61014 Mdot
.31774 .59184 Mdot
.45379 .69615 Mdot
.45623 .37474 Mdot
.33804 .24066 Mdot
.72324 .35812 Mdot
.51646 .62812 Mdot
.49473 .60238 Mdot
.55573 .67305 Mdot
.75188 .25091 Mdot
.70237 .58047 Mdot
.62369 .47657 Mdot
.58963 .57412 Mdot
.55237 .83218 Mdot
.55145 .63993 Mdot
.48327 .59841 Mdot
.49139 .64581 Mdot
.34904 .4388 Mdot
.6262 .49259 Mdot
.59028 .58045 Mdot
.34036 .26208 Mdot
.52105 .66497 Mdot
.52083 .3905 Mdot
.28137 .72315 Mdot
.52812 .59966 Mdot
.68648 .50529 Mdot
.49819 .64094 Mdot
.67483 .49046 Mdot
.69129 .46184 Mdot
.53725 .6758 Mdot
.70078 .72413 Mdot
.64668 .50765 Mdot
.52418 .66201 Mdot
.3341 .43848 Mdot
.67855 .78222 Mdot
.52046 .60657 Mdot
.28393 .61536 Mdot
.51726 .59332 Mdot
.3076 .61792 Mdot
.52127 .65081 Mdot
.35204 .45916 Mdot
.75386 .51813 Mdot
.37002 .43322 Mdot
.32708 .75022 Mdot
.31334 .46386 Mdot
.55536 .20505 Mdot
.63964 .49768 Mdot
.45549 .35759 Mdot
.18341 .39858 Mdot
.45075 .37448 Mdot
.556 .47178 Mdot
.49847 .48558 Mdot
.55068 .30464 Mdot
.64314 .44989 Mdot
.41373 .76322 Mdot
.44057 .2844 Mdot
.43903 .32598 Mdot
.40648 .42498 Mdot
.18869 .35675 Mdot
.22708 .33315 Mdot
.48914 .60132 Mdot
.67284 .73125 Mdot
.63003 .68515 Mdot
.48018 .60367 Mdot
.51265 .54772 Mdot
.33499 .41337 Mdot
.53605 .56876 Mdot
.58013 .42546 Mdot
.39752 .42187 Mdot
.28581 .58829 Mdot
.65022 .48745 Mdot
.28942 .62044 Mdot
.44063 .29717 Mdot
.5006 .48799 Mdot
.38475 .40902 Mdot
.56398 .64697 Mdot
.49254 .62183 Mdot
.69031 .4772 Mdot
.61495 .50252 Mdot
.68737 .45022 Mdot
.27693 .57877 Mdot
.3939 .42191 Mdot
.70526 .56866 Mdot
.50069 .61056 Mdot
.66974 .46412 Mdot
.55817 .25896 Mdot
.49887 .60447 Mdot
.54379 .34439 Mdot
.49304 .65219 Mdot
.66215 .44634 Mdot
.52118 .64603 Mdot
.66184 .4614 Mdot
.37681 .43729 Mdot
.55059 .64391 Mdot
.50052 .62019 Mdot
.62155 .19328 Mdot
.28603 .60705 Mdot
.63836 .49534 Mdot
.46232 .45059 Mdot
.565 .58707 Mdot
.38765 .29772 Mdot
.54104 .58308 Mdot
.71207 .42285 Mdot
.57574 .60871 Mdot
.45315 .36599 Mdot
.46038 .6026 Mdot
.52159 .60662 Mdot
.50916 .49834 Mdot
.62715 .71766 Mdot
.61144 .489 Mdot
.53589 .28996 Mdot
.67712 .50844 Mdot
.30151 .4862 Mdot
.42769 .40244 Mdot
.31143 .43959 Mdot
.32773 .69551 Mdot
.52937 .67512 Mdot
.53885 .61104 Mdot
.52238 .36344 Mdot
.28254 .58566 Mdot
.67628 .46531 Mdot
.28836 .58303 Mdot
.38393 .21955 Mdot
.28329 .57502 Mdot
.355 .45921 Mdot
.27329 .43253 Mdot
.73492 .55765 Mdot
.31737 .59068 Mdot
.68435 .4468 Mdot
.25501 .46819 Mdot
.51686 .56333 Mdot
.2605 .63186 Mdot
.29509 .59876 Mdot
.18736 .34653 Mdot
.53103 .57105 Mdot
.56118 .46362 Mdot
.52156 .34769 Mdot
.30188 .57832 Mdot
.53458 .31125 Mdot
.5221 .63875 Mdot
.371 .27911 Mdot
.65131 .4975 Mdot
.57555 .32997 Mdot
.54047 .54636 Mdot
.27638 .5838 Mdot
.38269 .41325 Mdot
.52334 .37729 Mdot
.53686 .29569 Mdot
.78394 .4641 Mdot
.47575 .78501 Mdot
.39398 .42278 Mdot
.23207 .39909 Mdot
.53253 .30445 Mdot
.48251 .59572 Mdot
.45446 .6784 Mdot
.55898 .61806 Mdot
.46306 .31605 Mdot
.33458 .45073 Mdot
.63037 .34673 Mdot
.49101 .62294 Mdot
.53704 .57496 Mdot
.6859 .51449 Mdot
.38501 .43148 Mdot
.66225 .47968 Mdot
.69018 .49993 Mdot
.37872 .43684 Mdot
.65529 .47065 Mdot
.30401 .5728 Mdot
.62675 .30454 Mdot
.5304 .3042 Mdot
.541 .32057 Mdot
.36703 .42663 Mdot
.32324 .44127 Mdot
.34093 .44373 Mdot
.49391 .65291 Mdot
.67909 .47003 Mdot
.50606 .6533 Mdot
.47825 .63178 Mdot
.6063 .46408 Mdot
.70591 .46095 Mdot
.49302 .6419 Mdot
.32056 .32592 Mdot
.28828 .6359 Mdot
.3313 .4359 Mdot
.51495 .34268 Mdot
.74729 .34214 Mdot
.56287 .36356 Mdot
.53725 .59813 Mdot
.47228 .2174 Mdot
.67321 .44723 Mdot
.31252 .58838 Mdot
.31086 .62447 Mdot
.31101 .59956 Mdot
.49965 .35051 Mdot
.66851 .50346 Mdot
.33639 .2424 Mdot
.5368 .60212 Mdot
.56038 .43032 Mdot
.42644 .76972 Mdot
.38957 .22482 Mdot
.51166 .33962 Mdot
.49673 .605 Mdot
.44631 .38372 Mdot
.76074 .5894 Mdot
.5583 .59822 Mdot
.55059 .56537 Mdot
.37077 .36606 Mdot
.484 .69289 Mdot
.64478 .50886 Mdot
.47838 .18773 Mdot
.46873 .62735 Mdot
.59898 .49837 Mdot
.36338 .8241 Mdot
.54251 .5938 Mdot
.52123 .58234 Mdot
.51253 .61179 Mdot
.49888 .63402 Mdot
.68051 .50917 Mdot
.36963 .73301 Mdot
.53065 .2883 Mdot
.53678 .43486 Mdot
.53191 .30174 Mdot
.40443 .39518 Mdot
.57856 .45687 Mdot
.65339 .44114 Mdot
.31321 .58689 Mdot
.7872 .50668 Mdot
.42675 .18899 Mdot
.41124 .40673 Mdot
.7271 .60299 Mdot
.2959 .60388 Mdot
.48876 .57503 Mdot
.28957 .62272 Mdot
.33618 .46261 Mdot
.54824 .3116 Mdot
.46437 .63657 Mdot
.69887 .46076 Mdot
.65722 .4443 Mdot
.50087 .5965 Mdot
.57799 .83381 Mdot
.54455 .3459 Mdot
.58404 .31939 Mdot
.48249 .62511 Mdot
.55044 .56457 Mdot
.65803 .48112 Mdot
.34393 .42999 Mdot
.19607 .50662 Mdot
.28179 .59884 Mdot
.56672 .61366 Mdot
.50252 .63677 Mdot
.47503 .19479 Mdot
.55921 .33531 Mdot
.41855 .42035 Mdot
.48398 .61646 Mdot
.55914 .24027 Mdot
.48416 .61853 Mdot
.45981 .64896 Mdot
.33877 .43835 Mdot
.58252 .60528 Mdot
.4931 .58747 Mdot
.58129 .54591 Mdot
.5334 .30673 Mdot
.64011 .47158 Mdot
.68658 .51131 Mdot
.44712 .38723 Mdot
.5419 .34437 Mdot
.49444 .64103 Mdot
.55691 .33744 Mdot
.47785 .60371 Mdot
.49945 .58902 Mdot
.51065 .33632 Mdot
.66173 .47934 Mdot
.67379 .38691 Mdot
.57922 .47731 Mdot
.49519 .63114 Mdot
.46109 .61476 Mdot
.34006 .69546 Mdot
.15724 .51479 Mdot
.53214 .58181 Mdot
.65938 .44571 Mdot
.49888 .61333 Mdot
.52931 .3187 Mdot
.28547 .5755 Mdot
.65697 .44903 Mdot
.35547 .42357 Mdot
.41286 .41151 Mdot
.70844 .31053 Mdot
.37611 .44813 Mdot
.50675 .56331 Mdot
.73042 .45161 Mdot
.69741 .44202 Mdot
.4159 .83636 Mdot
.38192 .43608 Mdot
.32528 .59095 Mdot
.51182 .63375 Mdot
.50063 .2237 Mdot
.5137 .35935 Mdot
.85827 .36545 Mdot
.3312 .24435 Mdot
.31223 .56329 Mdot
.19828 .39748 Mdot
.43961 .39125 Mdot
.50533 .5772 Mdot
.31734 .6006 Mdot
.40718 .40307 Mdot
.49518 .57423 Mdot
.49365 .54354 Mdot
.28911 .69886 Mdot
.38031 .39583 Mdot
.55324 .34365 Mdot
.32505 .4247 Mdot
.27112 .62037 Mdot
.35434 .4593 Mdot
.66187 .44114 Mdot
.52549 .60838 Mdot
.58304 .6415 Mdot
.34756 .4265 Mdot
.34646 .46173 Mdot
.49499 .65137 Mdot
.63944 .45625 Mdot
.3083 .4479 Mdot
.52372 .63093 Mdot
.68767 .55305 Mdot
.6248 .43812 Mdot
.39072 .41902 Mdot
.54518 .5738 Mdot
.55227 .70176 Mdot
.36377 .42457 Mdot
.33109 .4342 Mdot
.49996 .59449 Mdot
.30783 .57421 Mdot
.52466 .6673 Mdot
.51626 .3286 Mdot
.25074 .68347 Mdot
.53176 .3181 Mdot
.29924 .49465 Mdot
.50523 .68764 Mdot
.35687 .29427 Mdot
.67339 .43881 Mdot
.27462 .62333 Mdot
.75316 .33955 Mdot
.54354 .55969 Mdot
.75773 .68789 Mdot
.49308 .39913 Mdot
.53806 .84586 Mdot
.81658 .41844 Mdot
.29601 .59506 Mdot
.53676 .34207 Mdot
.52071 .58306 Mdot
.52721 .36069 Mdot
.30658 .61035 Mdot
.43691 .78333 Mdot
.54612 .5727 Mdot
.67913 .47821 Mdot
.51541 .66308 Mdot
.66605 .49005 Mdot
.50059 .6024 Mdot
.47848 .68753 Mdot
.43879 .36098 Mdot
.35734 .61534 Mdot
.50823 .56592 Mdot
.74651 .28923 Mdot
.40124 .4741 Mdot
.28885 .60023 Mdot
.51523 .65866 Mdot
.42434 .40944 Mdot
.56611 .3133 Mdot
.42666 .58501 Mdot
.3445 .44 Mdot
.52784 .35694 Mdot
.65118 .4772 Mdot
.37604 .43975 Mdot
.41433 .41971 Mdot
.57858 .55733 Mdot
.31087 .6148 Mdot
.55412 .31047 Mdot
.52347 .60354 Mdot
.53235 .572 Mdot
.23879 .41325 Mdot
.35779 .4942 Mdot
.66556 .52081 Mdot
.57724 .17722 Mdot
.71207 .48758 Mdot
.27886 .60173 Mdot
.33825 .44012 Mdot
.53412 .58339 Mdot
.55054 .62357 Mdot
.45458 .35302 Mdot
.63781 .49275 Mdot
.39896 .39287 Mdot
.6978 .60063 Mdot
.33448 .45716 Mdot
.38955 .72301 Mdot
.64138 .45939 Mdot
.38562 .72171 Mdot
.27308 .62099 Mdot
.76489 .65893 Mdot
.3829 .64787 Mdot
.52376 .34982 Mdot
.3937 .72638 Mdot
.67954 .45616 Mdot
.4891 .60961 Mdot
.43513 .39782 Mdot
.39539 .43756 Mdot
.65261 .48439 Mdot
.41807 .39291 Mdot
.30266 .57982 Mdot
.51766 .58132 Mdot
.30108 .29451 Mdot
.67498 .31864 Mdot
.34506 .42334 Mdot
.45263 .62926 Mdot
.53966 .31192 Mdot
.50478 .58009 Mdot
.28024 .6141 Mdot
.55389 .32087 Mdot
.32776 .47552 Mdot
.62443 .32826 Mdot
.52282 .6357 Mdot
.51569 .20765 Mdot
.55006 .33814 Mdot
.19101 .44542 Mdot
.52409 .62591 Mdot
.53268 .30458 Mdot
.51129 .70033 Mdot
.38207 .2375 Mdot
.47858 .42307 Mdot
.73828 .72851 Mdot
.38527 .39348 Mdot
.42127 .39474 Mdot
.41088 .25237 Mdot
.42219 .32705 Mdot
.53777 .36107 Mdot
.35396 .45927 Mdot
.44211 .71748 Mdot
.53564 .30971 Mdot
.48094 .63619 Mdot
.54159 .58696 Mdot
.67947 .59172 Mdot
.50575 .41758 Mdot
.34482 .46309 Mdot
.64198 .2572 Mdot
.56425 .58658 Mdot
.55623 .5448 Mdot
.54685 .62369 Mdot
.62934 .45405 Mdot
.55873 .31908 Mdot
.66151 .21781 Mdot
.53641 .34616 Mdot
.26852 .31736 Mdot
.37718 .42651 Mdot
.3199 .4479 Mdot
.53137 .59839 Mdot
.32735 .30797 Mdot
.49011 .7425 Mdot
.54743 .63976 Mdot
.34944 .31668 Mdot
.48968 .79053 Mdot
.54229 .54535 Mdot
.64447 .51071 Mdot
.47304 .64949 Mdot
.64638 .4351 Mdot
.53839 .29857 Mdot
.3019 .59103 Mdot
.25805 .61384 Mdot
.55339 .31135 Mdot
.53931 .61267 Mdot
.35918 .31844 Mdot
.55419 .59872 Mdot
.48648 .60738 Mdot
.27105 .30213 Mdot
.30514 .5632 Mdot
.34437 .44599 Mdot
.30015 .61062 Mdot
.6472 .49 Mdot
.90058 .59224 Mdot
.28433 .58251 Mdot
.51725 .73467 Mdot
.36401 .76251 Mdot
.39066 .72653 Mdot
.65384 .44508 Mdot
.26384 .59214 Mdot
.5436 .3487 Mdot
.58474 .85257 Mdot
.15961 .53703 Mdot
.57705 .34946 Mdot
.53087 .62961 Mdot
.6512 .44019 Mdot
.69035 .44762 Mdot
.5753 .31731 Mdot
.68811 .45965 Mdot
.56234 .67505 Mdot
.48819 .62185 Mdot
.53447 .3602 Mdot
.67564 .33922 Mdot
.53812 .29519 Mdot
.61481 .29041 Mdot
.51337 .65997 Mdot
.64564 .45491 Mdot
.48642 .66242 Mdot
.71555 .44428 Mdot
.41846 .42227 Mdot
.48514 .58026 Mdot
.30729 .58115 Mdot
.54853 .41963 Mdot
.38823 .42156 Mdot
.47063 .2202 Mdot
.68871 .47932 Mdot
.50566 .28357 Mdot
.68979 .46582 Mdot
.63848 .44918 Mdot
.56091 .3403 Mdot
.67274 .49928 Mdot
.52096 .58155 Mdot
.29307 .35315 Mdot
.67991 .49079 Mdot
.53511 .33197 Mdot
.30708 .59337 Mdot
.65758 .4733 Mdot
.33862 .41083 Mdot
.50343 .62759 Mdot
.37443 .40742 Mdot
.4354 .35596 Mdot
.6369 .45718 Mdot
.26704 .58561 Mdot
.33015 .45179 Mdot
.31254 .61169 Mdot
.47035 .80563 Mdot
.50513 .33817 Mdot
.21069 .39492 Mdot
.56018 .69273 Mdot
.69943 .45875 Mdot
.43577 .35895 Mdot
.53292 .58572 Mdot
.50385 .62927 Mdot
.2639 .61149 Mdot
.69121 .44804 Mdot
.64745 .79814 Mdot
.72273 .42277 Mdot
.6296 .31687 Mdot
.50234 .32843 Mdot
.6057 .20541 Mdot
.60732 .34473 Mdot
.35872 .78677 Mdot
.57692 .56653 Mdot
.43915 .3916 Mdot
.54462 .60471 Mdot
.76096 .35278 Mdot
.27644 .58165 Mdot
.20053 .5457 Mdot
.54439 .67367 Mdot
.35605 .44358 Mdot
.51349 .61937 Mdot
.43768 .53621 Mdot
.47586 .6596 Mdot
.3081 .57218 Mdot
.54875 .39413 Mdot
.7005 .4894 Mdot
.30027 .6039 Mdot
.40724 .4174 Mdot
.45444 .7464 Mdot
.50213 .5708 Mdot
.55069 .55749 Mdot
.33225 .45866 Mdot
.68296 .47465 Mdot
.39637 .39808 Mdot
.53089 .30403 Mdot
.29688 .5845 Mdot
.50824 .63504 Mdot
.57138 .63159 Mdot
.3891 .29936 Mdot
.55825 .31288 Mdot
.32836 .45544 Mdot
.52396 .34198 Mdot
.43787 .39385 Mdot
.46094 .62529 Mdot
.31808 .4473 Mdot
.51274 .5718 Mdot
.69844 .26853 Mdot
.26566 .3108 Mdot
.63791 .71748 Mdot
.35324 .44606 Mdot
.40227 .71514 Mdot
.528 .32652 Mdot
.51867 .32983 Mdot
.58697 .69268 Mdot
.4334 .67659 Mdot
.27033 .45548 Mdot
.78813 .46493 Mdot
.52977 .30388 Mdot
.53471 .31976 Mdot
.39246 .40336 Mdot
.67077 .49806 Mdot
.65549 .43447 Mdot
.42656 .3922 Mdot
.3062 .65474 Mdot
.67613 .46529 Mdot
.74075 .70592 Mdot
.29968 .47854 Mdot
.56776 .54733 Mdot
.47271 .31128 Mdot
.30288 .58468 Mdot
.32329 .64612 Mdot
.44625 .5295 Mdot
.53266 .57676 Mdot
.48814 .18803 Mdot
.34763 .43137 Mdot
.34363 .72474 Mdot
.81218 .59068 Mdot
.54785 .57213 Mdot
.5275 .61977 Mdot
.54396 .6151 Mdot
.29082 .56416 Mdot
.75099 .4774 Mdot
.52931 .57399 Mdot
.29613 .65635 Mdot
.56631 .5914 Mdot
.38281 .6104 Mdot
.29654 .61153 Mdot
.60901 .54625 Mdot
.41069 .38089 Mdot
.34386 .25103 Mdot
.59313 .52978 Mdot
.52555 .31066 Mdot
.43419 .38258 Mdot
.54054 .30125 Mdot
.629 .76156 Mdot
.38287 .65262 Mdot
.6425 .51383 Mdot
.52861 .57868 Mdot
.39725 .4321 Mdot
.68465 .44544 Mdot
.40984 .28544 Mdot
.76863 .77817 Mdot
.55284 .29904 Mdot
.14392 .59305 Mdot
.51902 .3353 Mdot
.41174 .42695 Mdot
.65622 .4815 Mdot
.7318 .64673 Mdot
.56246 .43026 Mdot
.65748 .47063 Mdot
.65113 .38192 Mdot
.71881 .47048 Mdot
.40239 .72282 Mdot
.70747 .45237 Mdot
.53184 .33123 Mdot
.51697 .36852 Mdot
.55701 .54142 Mdot
.52757 .59177 Mdot
.49393 .49043 Mdot
.53187 .72261 Mdot
.52945 .58848 Mdot
.39695 .42236 Mdot
.18481 .44424 Mdot
.43017 .38987 Mdot
.69633 .48368 Mdot
.54479 .29067 Mdot
.52454 .6197 Mdot
.48903 .62847 Mdot
.49351 .57917 Mdot
.59798 .17444 Mdot
.72488 .71922 Mdot
.49439 .59318 Mdot
.56123 .63307 Mdot
.37264 .43909 Mdot
.32613 .55755 Mdot
.78115 .38028 Mdot
.41937 .68066 Mdot
.56151 .59786 Mdot
.29292 .60953 Mdot
.32039 .57288 Mdot
.4966 .57233 Mdot
.3209 .2882 Mdot
.28656 .35725 Mdot
.52301 .60373 Mdot
.3927 .62362 Mdot
.43505 .30129 Mdot
.36243 .45594 Mdot
.35138 .42611 Mdot
.68846 .50363 Mdot
.40007 .43184 Mdot
.31049 .46337 Mdot
.74111 .62256 Mdot
.45235 .37945 Mdot
.59706 .33984 Mdot
.27674 .57895 Mdot
.55337 .61731 Mdot
.7147 .48638 Mdot
.46076 .33538 Mdot
.55118 .30616 Mdot
.66023 .45367 Mdot
.56565 .30973 Mdot
.32124 .56467 Mdot
.30839 .7019 Mdot
.39596 .43789 Mdot
.52272 .30928 Mdot
.62374 .32673 Mdot
.29381 .61023 Mdot
.54404 .35314 Mdot
.36485 .29572 Mdot
.47365 .62259 Mdot
.75183 .6535 Mdot
.53904 .65165 Mdot
.57797 .84185 Mdot
.54554 .35178 Mdot
.45726 .3657 Mdot
.53482 .60967 Mdot
.37364 .42322 Mdot
.50489 .69412 Mdot
.56027 .5999 Mdot
.36077 .41993 Mdot
.48921 .60252 Mdot
.28893 .61765 Mdot
.64076 .43229 Mdot
.49706 .39142 Mdot
.33677 .19498 Mdot
.30544 .61691 Mdot
.40293 .28667 Mdot
.5314 .58114 Mdot
.47632 .79059 Mdot
.65913 .47254 Mdot
.54771 .56724 Mdot
.61174 .61972 Mdot
.66491 .49548 Mdot
.65191 .45927 Mdot
.51103 .64696 Mdot
.52609 .34957 Mdot
.38089 .42041 Mdot
.29898 .60961 Mdot
.41376 .82237 Mdot
.5373 .63387 Mdot
.49955 .6172 Mdot
.29757 .60389 Mdot
.53327 .31849 Mdot
.49122 .63201 Mdot
.5028 .25199 Mdot
.49244 .85449 Mdot
.56262 .31458 Mdot
.48101 .64643 Mdot
.78667 .55756 Mdot
.72253 .45079 Mdot
.14602 .55923 Mdot
.33519 .61358 Mdot
.33282 .44892 Mdot
.48702 .69524 Mdot
.88939 .46244 Mdot
.30344 .59025 Mdot
.33935 .24714 Mdot
.48593 .60209 Mdot
.50489 .61035 Mdot
.68005 .44867 Mdot
.50007 .64856 Mdot
.64039 .49097 Mdot
.28495 .23808 Mdot
.51703 .17399 Mdot
.68224 .48214 Mdot
.703 .46792 Mdot
.56965 .70033 Mdot
.77745 .37501 Mdot
.64836 .48234 Mdot
.49598 .66088 Mdot
.65625 .77611 Mdot
.56513 .53906 Mdot
.26324 .61134 Mdot
.42739 .3517 Mdot
.61225 .52622 Mdot
.36214 .52841 Mdot
.72911 .41227 Mdot
.58878 .52097 Mdot
.41345 .44397 Mdot
.51436 .32771 Mdot
.55758 .57886 Mdot
.38541 .44346 Mdot
.31248 .44215 Mdot
.47807 .66752 Mdot
.55664 .60739 Mdot
.6706 .49135 Mdot
.29578 .56554 Mdot
.56696 .33553 Mdot
.49502 .61106 Mdot
.34231 .40757 Mdot
.28244 .5916 Mdot
.69322 .48462 Mdot
.57373 .70879 Mdot
.32028 .57954 Mdot
.45644 .62948 Mdot
.51345 .59631 Mdot
.49157 .64797 Mdot
.55609 .6907 Mdot
.50957 .31533 Mdot
.45796 .30341 Mdot
.50641 .66376 Mdot
.39013 .21581 Mdot
.38023 .56713 Mdot
.57932 .61988 Mdot
.68181 .46262 Mdot
.50525 .35321 Mdot
.42423 .41606 Mdot
.45408 .76045 Mdot
.52967 .63631 Mdot
.71868 .72329 Mdot
.69881 .5873 Mdot
.42163 .41197 Mdot
.62739 .48302 Mdot
.31299 .5908 Mdot
.55073 .63269 Mdot
.64102 .77062 Mdot
.54084 .59038 Mdot
.54571 .70312 Mdot
.33501 .43594 Mdot
.51326 .32782 Mdot
.52637 .85066 Mdot
.31279 .44234 Mdot
.64954 .46 Mdot
.7506 .72178 Mdot
.67387 .43507 Mdot
.69164 .49606 Mdot
.68383 .7385 Mdot
.51245 .31151 Mdot
.88514 .44444 Mdot
.15536 .54002 Mdot
.5604 .66258 Mdot
.52519 .32474 Mdot
.6632 .48624 Mdot
.50567 .58 Mdot
.70164 .44935 Mdot
.65782 .50164 Mdot
.47799 .58852 Mdot
.50813 .60179 Mdot
.57653 .47362 Mdot
.78571 .64598 Mdot
.31317 .59719 Mdot
.6363 .4716 Mdot
.64727 .58122 Mdot
.52067 .57324 Mdot
.53614 .60238 Mdot
.42817 .28659 Mdot
.31116 .57505 Mdot
.51325 .50165 Mdot
.48463 .61299 Mdot
.52681 .18816 Mdot
.45967 .63342 Mdot
.67133 .51307 Mdot
.56307 .31694 Mdot
.32367 .27923 Mdot
.46372 .31626 Mdot
.63565 .4903 Mdot
.27123 .60359 Mdot
.67844 .51593 Mdot
.52163 .73239 Mdot
.52383 .30147 Mdot
.66222 .44632 Mdot
.41539 .38904 Mdot
.54895 .32458 Mdot
.5429 .35278 Mdot
.62053 .78606 Mdot
.34683 .45268 Mdot
.26878 .58917 Mdot
.54634 .30955 Mdot
.70461 .54484 Mdot
.53459 .33701 Mdot
.6556 .59168 Mdot
.54557 .65053 Mdot
.29023 .67455 Mdot
.59918 .36821 Mdot
.52151 .70859 Mdot
.50595 .32324 Mdot
.30702 .60917 Mdot
.50626 .64195 Mdot
.68756 .45751 Mdot
.28708 .58166 Mdot
.49022 .36208 Mdot
.32669 .43742 Mdot
.69239 .4685 Mdot
.529 .28813 Mdot
.63787 .46835 Mdot
.39893 .75633 Mdot
.26499 .69565 Mdot
.50846 .24293 Mdot
.5583 .43827 Mdot
.49148 .58209 Mdot
.75626 .412 Mdot
.48033 .57855 Mdot
.55747 .60153 Mdot
.38989 .41928 Mdot
.32678 .69636 Mdot
.6617 .48001 Mdot
.52935 .85332 Mdot
.5188 .31407 Mdot
.49002 .18093 Mdot
.62767 .42872 Mdot
.555 .56813 Mdot
.67509 .49257 Mdot
.68525 .4372 Mdot
.62218 .72108 Mdot
.30242 .46325 Mdot
.49012 .54868 Mdot
.47447 .58202 Mdot
.57413 .56764 Mdot
.54393 .35168 Mdot
.45491 .22663 Mdot
.41133 .39516 Mdot
.20999 .65987 Mdot
.3355 .43258 Mdot
.33692 .36492 Mdot
.67968 .49803 Mdot
.28971 .57563 Mdot
.53383 .60235 Mdot
.63929 .41984 Mdot
.63033 .48428 Mdot
.32777 .61058 Mdot
.30819 .57959 Mdot
.41486 .23574 Mdot
.50972 .33508 Mdot
.51403 .56541 Mdot
.54261 .57346 Mdot
.51112 .6549 Mdot
.5356 .65737 Mdot
.55369 .29905 Mdot
.47901 .62495 Mdot
.55733 .35968 Mdot
.69971 .55297 Mdot
.50624 .17958 Mdot
.43801 .38311 Mdot
.42162 .61861 Mdot
.69818 .46671 Mdot
.70816 .53645 Mdot
.45082 .60516 Mdot
.24759 .32977 Mdot
.52735 .80875 Mdot
.51728 .55018 Mdot
.4043 .40105 Mdot
.43729 .67442 Mdot
.34626 .45884 Mdot
.10711 .46664 Mdot
.38933 .31125 Mdot
.74792 .71073 Mdot
.51577 .57719 Mdot
.43071 .28693 Mdot
.4484 .6374 Mdot
.47417 .59119 Mdot
.41069 .31309 Mdot
.61876 .24045 Mdot
.66002 .36169 Mdot
.32086 .57529 Mdot
.51068 .62896 Mdot
.7045 .44587 Mdot
.52118 .58016 Mdot
.54075 .60145 Mdot
.48585 .59738 Mdot
.5389 .28617 Mdot
.46598 .63805 Mdot
.49135 .65194 Mdot
.37796 .50272 Mdot
.37309 .68949 Mdot
.33122 .42047 Mdot
.5568 .73262 Mdot
.28392 .58514 Mdot
.68303 .48704 Mdot
.61427 .41261 Mdot
.52274 .34944 Mdot
.6234 .70519 Mdot
.50457 .65941 Mdot
.60934 .3593 Mdot
.52707 .2887 Mdot
.29695 .58224 Mdot
.43838 .39908 Mdot
.69507 .77134 Mdot
.3926 .43553 Mdot
.45106 .38175 Mdot
.38608 .42337 Mdot
.64232 .53675 Mdot
.66816 .49176 Mdot
.4881 .58398 Mdot
.54319 .31156 Mdot
.38041 .41761 Mdot
.34075 .68408 Mdot
.54712 .62123 Mdot
.37595 .43673 Mdot
.48709 .58718 Mdot
.29057 .68861 Mdot
.22502 .43005 Mdot
.31676 .46489 Mdot
.49462 .33971 Mdot
.54439 .32748 Mdot
.29971 .5722 Mdot
.69093 .4822 Mdot
.67745 .44981 Mdot
.55336 .32303 Mdot
.15087 .48789 Mdot
.56042 .59494 Mdot
.51075 .57753 Mdot
.39492 .21251 Mdot
.52151 .587 Mdot
.44038 .74033 Mdot
.45157 .38368 Mdot
.69703 .47681 Mdot
.49908 .58434 Mdot
.49393 .63227 Mdot
.51738 .63481 Mdot
.39279 .75613 Mdot
.34228 .42821 Mdot
.56387 .6006 Mdot
.31814 .58609 Mdot
.42509 .42266 Mdot
.51116 .57618 Mdot
.5723 .56667 Mdot
.67467 .44972 Mdot
.49391 .16756 Mdot
.51622 .33726 Mdot
.40591 .41415 Mdot
.32535 .45029 Mdot
.42886 .34821 Mdot
.60173 .4876 Mdot
.45056 .38429 Mdot
.23961 .68555 Mdot
.45404 .36976 Mdot
.29061 .60435 Mdot
.3596 .38642 Mdot
.35169 .54854 Mdot
.40308 .40656 Mdot
.56892 .31102 Mdot
.52387 .66581 Mdot
.56209 .61204 Mdot
.32275 .25123 Mdot
.55899 .56903 Mdot
.30968 .58787 Mdot
.56433 .35481 Mdot
.67729 .45664 Mdot
.30001 .58114 Mdot
.52051 .33447 Mdot
.68378 .47236 Mdot
.47271 .61561 Mdot
.47422 .63162 Mdot
.65814 .45625 Mdot
.68492 .44643 Mdot
.52109 .60039 Mdot
.39829 .44695 Mdot
.69248 .49959 Mdot
.65123 .45 Mdot
.39026 .44166 Mdot
.40537 .42645 Mdot
.58917 .58314 Mdot
.52382 .32956 Mdot
.48629 .64046 Mdot
.37664 .44423 Mdot
.29142 .5688 Mdot
.66372 .47521 Mdot
.49214 .62901 Mdot
.49169 .61345 Mdot
.29795 .60879 Mdot
.30937 .56715 Mdot
.29912 .57881 Mdot
.56259 .35958 Mdot
.52674 .65514 Mdot
.64784 .47874 Mdot
.50945 .32639 Mdot
.32093 .57341 Mdot
.3078 .62018 Mdot
.42925 .49821 Mdot
.53566 .58185 Mdot
.46952 .42812 Mdot
.8975 .58605 Mdot
.44092 .72528 Mdot
.42248 .41831 Mdot
.34078 .45657 Mdot
.3635 .7109 Mdot
.27637 .38082 Mdot
.55192 .33902 Mdot
.45994 .72691 Mdot
.27354 .62324 Mdot
.48265 .58943 Mdot
.46073 .61764 Mdot
.5095 .54809 Mdot
.28964 .58798 Mdot
.41882 .75902 Mdot
.68227 .44014 Mdot
.62689 .64988 Mdot
.28457 .58494 Mdot
.31539 .46558 Mdot
.31632 .45205 Mdot
.33493 .43312 Mdot
.46401 .6283 Mdot
.63772 .70846 Mdot
.6726 .55226 Mdot
.77199 .42593 Mdot
.51858 .35044 Mdot
.63654 .51202 Mdot
.46906 .80085 Mdot
.65418 .45936 Mdot
.31141 .44554 Mdot
.28622 .59113 Mdot
.6657 .4441 Mdot
.55218 .30259 Mdot
.53646 .31848 Mdot
.33972 .42778 Mdot
.36765 .42725 Mdot
.37315 .40862 Mdot
.67665 .50439 Mdot
.67477 .49897 Mdot
.53497 .63805 Mdot
.66513 .46544 Mdot
.4141 .18133 Mdot
.29734 .56149 Mdot
.31426 .45229 Mdot
.53454 .34257 Mdot
.66941 .48967 Mdot
.54773 .62486 Mdot
.30945 .4077 Mdot
.70081 .31025 Mdot
.30672 .61451 Mdot
.23174 .41497 Mdot
.11129 .48806 Mdot
.52389 .56612 Mdot
.5548 .34259 Mdot
.29062 .3083 Mdot
.54335 .61832 Mdot
.34756 .43717 Mdot
.72259 .29123 Mdot
.4278 .40303 Mdot
.48133 .63567 Mdot
.55705 .56722 Mdot
.55101 .35224 Mdot
.3663 .76677 Mdot
.53878 .63841 Mdot
.59427 .27261 Mdot
.55113 .29185 Mdot
.36293 .40474 Mdot
.49799 .85896 Mdot
.44839 .2971 Mdot
.3215 .64879 Mdot
.40361 .43141 Mdot
.54888 .58855 Mdot
.40039 .41744 Mdot
.30965 .61166 Mdot
.39179 .41244 Mdot
.63261 .50122 Mdot
.35059 .41095 Mdot
.50067 .61692 Mdot
.64658 .48218 Mdot
.54908 .33969 Mdot
.47029 .18537 Mdot
.36212 .50406 Mdot
.37257 .42361 Mdot
.4011 .43594 Mdot
.49546 .58391 Mdot
.551 .49314 Mdot
.52424 .68783 Mdot
.51844 .57515 Mdot
.53397 .29961 Mdot
.68009 .4917 Mdot
.50853 .30952 Mdot
.57246 .60493 Mdot
.60076 .2239 Mdot
.52377 .34401 Mdot
.60301 .38108 Mdot
.29484 .60425 Mdot
.44261 .51245 Mdot
.55187 .62305 Mdot
.54359 .30775 Mdot
.5261 .65598 Mdot
.70474 .45409 Mdot
.49365 .44469 Mdot
.477 .28141 Mdot
.5431 .31317 Mdot
.62465 .81217 Mdot
.45516 .45521 Mdot
.48839 .66152 Mdot
.53512 .30296 Mdot
.61634 .60716 Mdot
.41342 .42321 Mdot
.28312 .60098 Mdot
.32032 .57322 Mdot
.31697 .60805 Mdot
.53686 .55329 Mdot
.49113 .54326 Mdot
.26951 .60639 Mdot
.56503 .31659 Mdot
.30688 .57091 Mdot
.61968 .42691 Mdot
.63658 .8066 Mdot
.27429 .58779 Mdot
.52422 .62817 Mdot
.54757 .53915 Mdot
.36865 .68778 Mdot
.30877 .45113 Mdot
.76246 .68275 Mdot
.43277 .61752 Mdot
.53059 .59172 Mdot
.52191 .52253 Mdot
.67944 .44081 Mdot
.28055 .3273 Mdot
.53002 .72142 Mdot
.26564 .38759 Mdot
.70397 .47772 Mdot
.45612 .35221 Mdot
.69423 .4803 Mdot
.5166 .56811 Mdot
.50161 .58715 Mdot
.66277 .43107 Mdot
.47854 .20851 Mdot
.37712 .27239 Mdot
.48774 .83614 Mdot
.64993 .44942 Mdot
.53386 .30668 Mdot
.5515 .29733 Mdot
.51803 .34901 Mdot
.30064 .48257 Mdot
.63443 .46766 Mdot
.528 .64978 Mdot
.37125 .4402 Mdot
.55858 .58599 Mdot
.54899 .31617 Mdot
.5357 .85137 Mdot
.67628 .45196 Mdot
.52216 .60596 Mdot
.16173 .52843 Mdot
.36246 .43265 Mdot
.28688 .60912 Mdot
.30426 .70418 Mdot
.29879 .47244 Mdot
.51968 .30118 Mdot
.66888 .43217 Mdot
.50942 .38694 Mdot
.59557 .40561 Mdot
.58224 .56989 Mdot
.57951 .63549 Mdot
.37596 .80493 Mdot
.33852 .47566 Mdot
.49377 .57111 Mdot
.41004 .41428 Mdot
.45413 .35262 Mdot
.49491 .62808 Mdot
.65577 .44275 Mdot
.3274 .59805 Mdot
.31798 .58335 Mdot
.46877 .57932 Mdot
.55809 .43133 Mdot
.43052 .51889 Mdot
.49137 .63904 Mdot
.45362 .62249 Mdot
.32479 .45262 Mdot
.45489 .37114 Mdot
.44392 .19205 Mdot
.27068 .59607 Mdot
.48379 .60841 Mdot
.69376 .37432 Mdot
.65779 .50022 Mdot
.36417 .40796 Mdot
.52576 .29873 Mdot
.41397 .7685 Mdot
.38343 .39959 Mdot
.49313 .62705 Mdot
.49166 .63197 Mdot
.54413 .35337 Mdot
.67078 .51324 Mdot
.28888 .59012 Mdot
.34592 .44871 Mdot
.27015 .59839 Mdot
.64991 .49387 Mdot
.67467 .45398 Mdot
.56372 .53772 Mdot
.45454 .6158 Mdot
.35466 .42465 Mdot
.57157 .59263 Mdot
.31009 .45824 Mdot
.35758 .7655 Mdot
.50242 .31799 Mdot
.52904 .5657 Mdot
.61966 .47322 Mdot
.54927 .31112 Mdot
.50923 .60773 Mdot
.37021 .81253 Mdot
.55281 .57064 Mdot
.46362 .3297 Mdot
.58331 .21843 Mdot
.31674 .5954 Mdot
.56239 .74598 Mdot
.53208 .51214 Mdot
.51743 .58812 Mdot
.32225 .43703 Mdot
.50778 .69296 Mdot
.53406 .35098 Mdot
.6915 .49088 Mdot
.13682 .53737 Mdot
.53679 .33529 Mdot
.51472 .58022 Mdot
.29683 .58365 Mdot
.67688 .43442 Mdot
.44161 .38024 Mdot
.37133 .23012 Mdot
.49007 .68113 Mdot
.50236 .6657 Mdot
.4823 .63514 Mdot
.78274 .36122 Mdot
.40428 .41304 Mdot
.66568 .48815 Mdot
.54445 .3511 Mdot
.55527 .32404 Mdot
.33939 .43167 Mdot
.64965 .35216 Mdot
.44653 .50559 Mdot
.89578 .50762 Mdot
.36635 .4178 Mdot
.26755 .58304 Mdot
.57428 .44848 Mdot
.32203 .43278 Mdot
.37653 .43524 Mdot
.33057 .45285 Mdot
.59082 .35798 Mdot
.68154 .47046 Mdot
.49086 .61122 Mdot
.70942 .4805 Mdot
.54939 .58664 Mdot
.39133 .56829 Mdot
.55142 .31027 Mdot
.69289 .49098 Mdot
.38004 .81266 Mdot
.72023 .43464 Mdot
.53587 .62188 Mdot
.44876 .80517 Mdot
.52811 .6838 Mdot
.41041 .74038 Mdot
.52723 .67861 Mdot
.37824 .42483 Mdot
.45396 .67335 Mdot
.57479 .58169 Mdot
.44655 .1799 Mdot
.53238 .3422 Mdot
.41362 .42616 Mdot
.51572 .55652 Mdot
.45824 .63122 Mdot
.68876 .43087 Mdot
.66247 .44428 Mdot
.26852 .59903 Mdot
.35212 .61466 Mdot
.54555 .34308 Mdot
.26891 .69287 Mdot
.5237 .59355 Mdot
.52007 .22246 Mdot
.58613 .72078 Mdot
.51068 .60818 Mdot
.66664 .76972 Mdot
.63136 .70717 Mdot
.5521 .62799 Mdot
.62001 .58598 Mdot
.53223 .3218 Mdot
.58356 .22375 Mdot
.55222 .65247 Mdot
.34855 .43824 Mdot
.67924 .49668 Mdot
.66699 .43764 Mdot
.27961 .61529 Mdot
.25104 .30326 Mdot
.5047 .32603 Mdot
.68833 .49467 Mdot
.549 .61451 Mdot
.51527 .30611 Mdot
.3739 .44894 Mdot
.57188 .62097 Mdot
.47381 .73764 Mdot
.6679 .46336 Mdot
.56222 .63149 Mdot
.65171 .27618 Mdot
.33808 .63373 Mdot
.84192 .54064 Mdot
.51901 .34886 Mdot
.28344 .57881 Mdot
.55416 .67491 Mdot
.23494 .66616 Mdot
.53265 .54688 Mdot
.29747 .6791 Mdot
.60184 .47651 Mdot
.28671 .57527 Mdot
.53273 .61581 Mdot
.5192 .63895 Mdot
.57271 .43013 Mdot
.30341 .56502 Mdot
.54977 .57447 Mdot
.43961 .63581 Mdot
.68168 .47554 Mdot
.43491 .40663 Mdot
.67267 .4629 Mdot
.53041 .62921 Mdot
.50439 .53679 Mdot
.68054 .44745 Mdot
.25584 .70398 Mdot
.26271 .6204 Mdot
.51578 .33843 Mdot
.46137 .5829 Mdot
.53932 .65831 Mdot
.78204 .32467 Mdot
.41815 .42248 Mdot
.76765 .38733 Mdot
.36861 .40026 Mdot
.68767 .38348 Mdot
.44912 .2915 Mdot
.73838 .73449 Mdot
.48192 .19126 Mdot
.4736 .58487 Mdot
.40557 .60896 Mdot
.63228 .56041 Mdot
.51041 .30845 Mdot
.74689 .54751 Mdot
.52811 .59143 Mdot
.54289 .60217 Mdot
.38278 .4033 Mdot
.62834 .35066 Mdot
.31601 .29355 Mdot
.53946 .43085 Mdot
.29053 .59362 Mdot
.64132 .48536 Mdot
.49916 .60231 Mdot
.39013 .54282 Mdot
.34351 .41476 Mdot
.50817 .22455 Mdot
.52613 .60948 Mdot
.24188 .34239 Mdot
.57405 .37519 Mdot
.50781 .32272 Mdot
.31953 .44511 Mdot
.2985 .46967 Mdot
.543 .581 Mdot
.53755 .29593 Mdot
.5419 .63608 Mdot
.43803 .46614 Mdot
.56972 .58214 Mdot
.27591 .58751 Mdot
.48868 .58796 Mdot
.53267 .41372 Mdot
.82396 .60063 Mdot
.49028 .72358 Mdot
.64812 .44315 Mdot
.30138 .45723 Mdot
.34407 .42818 Mdot
.66853 .44535 Mdot
.3483 .42798 Mdot
.62898 .67172 Mdot
.70558 .67136 Mdot
.29203 .5976 Mdot
.45187 .61415 Mdot
.27323 .6023 Mdot
.41843 .42291 Mdot
.53513 .58676 Mdot
.24046 .69083 Mdot
.36774 .42009 Mdot
.64647 .22302 Mdot
.53784 .33923 Mdot
.4163 .42412 Mdot
.56638 .59477 Mdot
.36886 .38114 Mdot
.31392 .43814 Mdot
.45838 .34601 Mdot
.52057 .63546 Mdot
.68211 .45436 Mdot
.51291 .63817 Mdot
.5214 .6818 Mdot
.44203 .39459 Mdot
.5197 .66479 Mdot
.52055 .33439 Mdot
.67688 .50847 Mdot
.6793 .77948 Mdot
.46297 .32549 Mdot
.53555 .5752 Mdot
.54743 .6154 Mdot
.69334 .43792 Mdot
.56095 .62789 Mdot
.54893 .29824 Mdot
.76883 .23736 Mdot
.29443 .60475 Mdot
.3447 .46167 Mdot
.45035 .29914 Mdot
.52033 .54878 Mdot
.49463 .63822 Mdot
.41326 .82452 Mdot
.47628 .26778 Mdot
.52452 .31489 Mdot
.48812 .69036 Mdot
.36566 .44234 Mdot
.2986 .58382 Mdot
.56737 .32911 Mdot
.49213 .64793 Mdot
.53537 .60548 Mdot
.28136 .58234 Mdot
.62544 .78936 Mdot
.25881 .39257 Mdot
.5253 .35547 Mdot
.45708 .67714 Mdot
.28666 .42598 Mdot
.56042 .59702 Mdot
.28749 .47632 Mdot
.65744 .44796 Mdot
.52126 .30606 Mdot
.77557 .40955 Mdot
.48373 .592 Mdot
.55687 .30817 Mdot
.54223 .34427 Mdot
.56708 .65239 Mdot
.68497 .42551 Mdot
.66378 .50689 Mdot
.63715 .47462 Mdot
.44672 .16363 Mdot
.34796 .64318 Mdot
.37237 .40883 Mdot
.53284 .32015 Mdot
.32865 .46273 Mdot
.28503 .56388 Mdot
.39018 .55192 Mdot
.32248 .46539 Mdot
.68578 .44513 Mdot
.31682 .456 Mdot
.51556 .63682 Mdot
.55091 .33834 Mdot
.40015 .40627 Mdot
.52132 .55528 Mdot
.52409 .50462 Mdot
.43345 .45345 Mdot
.32241 .60852 Mdot
.30605 .62896 Mdot
.50044 .59176 Mdot
.42485 .4152 Mdot
.52363 .60041 Mdot
.54486 .36134 Mdot
.58484 .41404 Mdot
.52549 .54962 Mdot
.36495 .42492 Mdot
.46219 .55071 Mdot
.30089 .47304 Mdot
.50064 .69075 Mdot
.52532 .62729 Mdot
.55656 .59172 Mdot
.54187 .63707 Mdot
.63924 .37252 Mdot
.50206 .33128 Mdot
.48689 .51022 Mdot
.43198 .36402 Mdot
.65923 .46365 Mdot
.62452 .48406 Mdot
.25959 .46714 Mdot
.32374 .46876 Mdot
.52466 .32785 Mdot
.55873 .61081 Mdot
.46323 .30775 Mdot
.54516 .85101 Mdot
.25948 .71107 Mdot
.32847 .61259 Mdot
.41532 .40407 Mdot
.6457 .44278 Mdot
.32175 .42814 Mdot
.54559 .58818 Mdot
.56287 .66245 Mdot
.72409 .75379 Mdot
.49875 .35838 Mdot
.28687 .58998 Mdot
.55481 .59022 Mdot
.33493 .64032 Mdot
.37209 .43935 Mdot
.33096 .45421 Mdot
.55429 .57464 Mdot
.64279 .50455 Mdot
.84386 .43842 Mdot
.50748 .32124 Mdot
.42808 .61219 Mdot
.71834 .50858 Mdot
.60281 .24769 Mdot
.55486 .31493 Mdot
.40589 .45926 Mdot
.41892 .40471 Mdot
.58453 .75178 Mdot
.66096 .45965 Mdot
.28492 .58819 Mdot
.5763 .63942 Mdot
.69223 .45365 Mdot
.42601 .39415 Mdot
.69984 .47179 Mdot
.49248 .57748 Mdot
.50495 .31774 Mdot
.32886 .44786 Mdot
.49927 .34983 Mdot
.64831 .43517 Mdot
.28942 .61505 Mdot
.54126 .48234 Mdot
.76202 .56448 Mdot
.62936 .70613 Mdot
.56333 .60417 Mdot
.38036 .54564 Mdot
.52387 .65408 Mdot
.69199 .43043 Mdot
.5458 .62879 Mdot
.67815 .52685 Mdot
.32243 .44084 Mdot
.56034 .63577 Mdot
.47989 .63039 Mdot
.72238 .5669 Mdot
.52261 .61682 Mdot
.53903 .6685 Mdot
.55416 .62588 Mdot
.62237 .50578 Mdot
.4687 .65134 Mdot
.68322 .46451 Mdot
.36493 .23784 Mdot
.37809 .43402 Mdot
.32743 .60164 Mdot
.32144 .58545 Mdot
.29123 .67053 Mdot
.37198 .59259 Mdot
.64008 .35495 Mdot
.67305 .47051 Mdot
.52791 .34367 Mdot
.5449 .63407 Mdot
.78202 .45276 Mdot
.42835 .32603 Mdot
.36756 .44289 Mdot
.46315 .32865 Mdot
.53099 .69881 Mdot
.78373 .3604 Mdot
.56791 .60002 Mdot
.32194 .24591 Mdot
.49865 .55019 Mdot
.54798 .56816 Mdot
.30808 .4394 Mdot
.37171 .59004 Mdot
.56437 .59418 Mdot
.68959 .43153 Mdot
.27955 .59377 Mdot
.73382 .43782 Mdot
.32583 .34416 Mdot
.39201 .45818 Mdot
.73912 .602 Mdot
.53279 .65191 Mdot
.33275 .44763 Mdot
.69209 .46942 Mdot
.45763 .19121 Mdot
.50991 .32482 Mdot
.59625 .36308 Mdot
.6768 .5635 Mdot
.4102 .80064 Mdot
.28276 .59103 Mdot
.62086 .78806 Mdot
.49952 .61582 Mdot
.30451 .49372 Mdot
.47789 .59078 Mdot
.54901 .84973 Mdot
.26473 .58903 Mdot
.63517 .49858 Mdot
.53257 .3076 Mdot
.70606 .45815 Mdot
.63334 .72106 Mdot
.51525 .26927 Mdot
.50314 .46817 Mdot
.38485 .44019 Mdot
.50224 .50135 Mdot
.65238 .48628 Mdot
.48489 .62552 Mdot
.90002 .53688 Mdot
.65301 .44966 Mdot
.63632 .48893 Mdot
.33103 .75002 Mdot
.33269 .75586 Mdot
.50249 .70246 Mdot
.70125 .46221 Mdot
.38728 .43755 Mdot
.30833 .60562 Mdot
.51798 .64285 Mdot
.53265 .64054 Mdot
.68007 .44925 Mdot
.31119 .44685 Mdot
.42778 .63843 Mdot
.37256 .42651 Mdot
.68352 .47627 Mdot
.36883 .43361 Mdot
.45494 .33226 Mdot
.40989 .40847 Mdot
.54512 .65278 Mdot
.54572 .63014 Mdot
.29235 .381 Mdot
.67464 .45415 Mdot
.49948 .64376 Mdot
.49016 .59757 Mdot
.6493 .48097 Mdot
.36939 .39943 Mdot
.7756 .48677 Mdot
.52952 .58024 Mdot
.50625 .62672 Mdot
.28398 .57704 Mdot
.3495 .53951 Mdot
.20485 .45481 Mdot
.50668 .64223 Mdot
.2801 .57011 Mdot
.67958 .50311 Mdot
.52006 .60201 Mdot
.61428 .43005 Mdot
.45457 .34591 Mdot
.48382 .59467 Mdot
.41468 .41972 Mdot
.54927 .55605 Mdot
.83683 .4869 Mdot
.52754 .57203 Mdot
.66091 .48439 Mdot
.66823 .49624 Mdot
.34311 .75045 Mdot
.64721 .46134 Mdot
.3967 .43641 Mdot
.54875 .32105 Mdot
.57266 .84415 Mdot
.37025 .45052 Mdot
.54534 .56337 Mdot
.15514 .54061 Mdot
.56468 .63223 Mdot
.5174 .55405 Mdot
.76139 .32255 Mdot
.37087 .44983 Mdot
.66678 .49335 Mdot
.59637 .31118 Mdot
.48268 .56043 Mdot
.52064 .30134 Mdot
.57833 .61168 Mdot
.50587 .66257 Mdot
.56387 .22181 Mdot
.71735 .30802 Mdot
.56659 .35056 Mdot
.58157 .55813 Mdot
.50637 .64257 Mdot
.3699 .52129 Mdot
.54955 .6203 Mdot
.27166 .60069 Mdot
.63615 .48489 Mdot
.34564 .41679 Mdot
.30361 .60379 Mdot
.52159 .59059 Mdot
.29046 .58609 Mdot
.3726 .40797 Mdot
.52884 .30086 Mdot
.54013 .58411 Mdot
.26133 .60794 Mdot
.29073 .5921 Mdot
.51682 .65457 Mdot
.68788 .4939 Mdot
.49128 .71637 Mdot
.5171 .60353 Mdot
.48659 .62082 Mdot
.67769 .45004 Mdot
.22407 .69551 Mdot
.53701 .56959 Mdot
.46282 .43393 Mdot
.63156 .48497 Mdot
.47408 .29833 Mdot
.37519 .40613 Mdot
.51013 .66472 Mdot
.53604 .29781 Mdot
.54959 .30816 Mdot
.35967 .45041 Mdot
.70262 .44723 Mdot
.30661 .45333 Mdot
.46038 .55479 Mdot
.45942 .58997 Mdot
.56447 .64427 Mdot
.14654 .47807 Mdot
.71937 .75044 Mdot
.65586 .44155 Mdot
.41359 .39367 Mdot
.53853 .4345 Mdot
.53232 .31599 Mdot
.33898 .45852 Mdot
.67517 .43321 Mdot
.64934 .44018 Mdot
.69761 .46818 Mdot
.29821 .57559 Mdot
.40939 .39329 Mdot
.66031 .51404 Mdot
.6449 .50545 Mdot
.51771 .63578 Mdot
.5049 .64313 Mdot
.60565 .61234 Mdot
.39891 .7053 Mdot
.28532 .61549 Mdot
.33819 .43485 Mdot
.67978 .19085 Mdot
.55109 .36031 Mdot
.72249 .57057 Mdot
.52228 .55014 Mdot
.84117 .69888 Mdot
.56832 .58993 Mdot
.5509 .61459 Mdot
.68599 .50346 Mdot
.26705 .61647 Mdot
.27638 .60425 Mdot
.65302 .48813 Mdot
.65087 .43537 Mdot
.27178 .59402 Mdot
.55211 .81336 Mdot
.63439 .81007 Mdot
.59169 .28363 Mdot
.65558 .47899 Mdot
.7602 .5911 Mdot
.5272 .29716 Mdot
.64778 .43418 Mdot
.55 .3578 Mdot
.36929 .43876 Mdot
.42064 .40273 Mdot
.54098 .35345 Mdot
.52444 .63566 Mdot
.3845 .40808 Mdot
.47616 .64801 Mdot
.58297 .81568 Mdot
.70651 .70932 Mdot
.44496 .258 Mdot
.46173 .61113 Mdot
.3248 .28409 Mdot
.32755 .29677 Mdot
.51049 .58793 Mdot
.68087 .3995 Mdot
.2876 .58839 Mdot
.62093 .45168 Mdot
.54674 .29734 Mdot
.84339 .52953 Mdot
.56046 .60175 Mdot
.66376 .48188 Mdot
.52824 .3396 Mdot
.34676 .74116 Mdot
.59785 .27632 Mdot
.55145 .58652 Mdot
.89035 .48008 Mdot
.61039 .46993 Mdot
.34825 .41581 Mdot
.18615 .41611 Mdot
.7079 .48673 Mdot
.32246 .62501 Mdot
.42875 .37615 Mdot
.40981 .81259 Mdot
.68268 .4869 Mdot
.42755 .39151 Mdot
.64358 .48614 Mdot
.27482 .60969 Mdot
.62681 .43548 Mdot
.33468 .45038 Mdot
.52746 .61573 Mdot
.35038 .43027 Mdot
.28978 .61655 Mdot
.30209 .48584 Mdot
.54286 .29673 Mdot
.41436 .42417 Mdot
.53949 .32379 Mdot
.34362 .628 Mdot
.62485 .22782 Mdot
.51305 .3291 Mdot
.31733 .72389 Mdot
.49158 .57212 Mdot
.68048 .51113 Mdot
.36098 .41728 Mdot
.43326 .37669 Mdot
.54745 .46897 Mdot
.65459 .46639 Mdot
.33243 .43746 Mdot
.6808 .55662 Mdot
.18796 .59746 Mdot
.4874 .54572 Mdot
.36734 .63275 Mdot
.65051 .47852 Mdot
.33046 .45591 Mdot
.39625 .21165 Mdot
.68551 .44379 Mdot
.36744 .41712 Mdot
.53877 .30509 Mdot
.55566 .32018 Mdot
.55905 .58204 Mdot
.59325 .31627 Mdot
.33967 .42407 Mdot
.36518 .25515 Mdot
.65431 .4997 Mdot
.34852 .73934 Mdot
.30051 .61905 Mdot
.38618 .43068 Mdot
.57512 .59357 Mdot
.72378 .48179 Mdot
.45265 .34488 Mdot
.42571 .65913 Mdot
.67606 .19435 Mdot
.33988 .43225 Mdot
.6372 .48779 Mdot
.66507 .47827 Mdot
.52639 .68642 Mdot
.56147 .43342 Mdot
.30381 .45335 Mdot
.22981 .6424 Mdot
.30803 .68795 Mdot
.4377 .39465 Mdot
.33787 .30866 Mdot
.55843 .5669 Mdot
.52724 .65814 Mdot
.53162 .31417 Mdot
.52439 .6213 Mdot
.659 .50907 Mdot
.56471 .60246 Mdot
.55915 .31883 Mdot
.3993 .42515 Mdot
.53843 .588 Mdot
.31144 .60492 Mdot
.57497 .32933 Mdot
.5471 .35376 Mdot
.38777 .42577 Mdot
.7004 .46312 Mdot
.25951 .63036 Mdot
.36603 .42758 Mdot
.5343 .65013 Mdot
.4435 .37849 Mdot
.49328 .57947 Mdot
.56111 .78983 Mdot
.69341 .44812 Mdot
.32006 .43293 Mdot
.62703 .48024 Mdot
.53619 .32763 Mdot
.43152 .36525 Mdot
.5379 .62746 Mdot
.37134 .4172 Mdot
.30157 .36084 Mdot
.57883 .80101 Mdot
.6995 .44078 Mdot
.36327 .31124 Mdot
.63987 .49705 Mdot
.4376 .39604 Mdot
.48608 .76591 Mdot
.285 .59947 Mdot
.35655 .44583 Mdot
.71949 .73955 Mdot
.36291 .42332 Mdot
.51834 .61617 Mdot
.50481 .60495 Mdot
.38971 .40308 Mdot
.30897 .5747 Mdot
.50894 .17432 Mdot
.43722 .44184 Mdot
.67456 .49173 Mdot
.54527 .75218 Mdot
.74027 .24631 Mdot
.52012 .28629 Mdot
.52812 .31444 Mdot
.47653 .57382 Mdot
.55506 .56903 Mdot
.56422 .34297 Mdot
.54479 .29047 Mdot
.28278 .61911 Mdot
.33713 .45238 Mdot
.62387 .43637 Mdot
.55838 .29768 Mdot
.59241 .55379 Mdot
.37122 .59588 Mdot
.46824 .67391 Mdot
.52082 .52458 Mdot
.46889 .62754 Mdot
.28522 .67897 Mdot
.55904 .33558 Mdot
.49701 .59472 Mdot
.47726 .669 Mdot
.52555 .30541 Mdot
.27355 .60706 Mdot
.70167 .29341 Mdot
.35664 .43854 Mdot
.38745 .84259 Mdot
.50576 .57466 Mdot
.518 .6123 Mdot
.51663 .34852 Mdot
.3479 .52517 Mdot
.68956 .45416 Mdot
.6985 .45108 Mdot
.40333 .41168 Mdot
.52176 .48573 Mdot
.55618 .63425 Mdot
.50637 .58889 Mdot
.33922 .44404 Mdot
.4164 .42256 Mdot
.41001 .25441 Mdot
.49292 .61579 Mdot
.52886 .33808 Mdot
.43352 .38283 Mdot
.56088 .32888 Mdot
.51106 .56842 Mdot
.51465 .61583 Mdot
.54782 .64988 Mdot
.55396 .56757 Mdot
.54316 .35604 Mdot
.49691 .59849 Mdot
.53219 .53537 Mdot
.6999 .47911 Mdot
.53766 .65625 Mdot
.29863 .68669 Mdot
.51796 .62817 Mdot
.29664 .613 Mdot
.36231 .57409 Mdot
.55622 .58962 Mdot
.53545 .66028 Mdot
.44 .44193 Mdot
.53649 .61467 Mdot
.54497 .36114 Mdot
.66152 .4668 Mdot
.53338 .31955 Mdot
.5473 .35112 Mdot
.4082 .42373 Mdot
.27252 .6111 Mdot
.50331 .55588 Mdot
.31765 .60574 Mdot
.57436 .55669 Mdot
.48673 .58148 Mdot
.41062 .36528 Mdot
.31759 .24756 Mdot
.25806 .39639 Mdot
.53755 .62887 Mdot
.39924 .42036 Mdot
.33831 .41976 Mdot
.41306 .60471 Mdot
.47398 .64994 Mdot
.56752 .33562 Mdot
.54362 .30816 Mdot
.44232 .73653 Mdot
.56258 .22359 Mdot
.28824 .61443 Mdot
.387 .5489 Mdot
.46294 .63411 Mdot
.4884 .6088 Mdot
.57148 .61964 Mdot
.32341 .46491 Mdot
.45355 .37653 Mdot
.3686 .44247 Mdot
.46388 .34572 Mdot
.56062 .31953 Mdot
.55892 .62136 Mdot
.74629 .67577 Mdot
.66745 .44264 Mdot
.66201 .46608 Mdot
.5658 .32811 Mdot
.30532 .45924 Mdot
.58363 .65122 Mdot
.13408 .57323 Mdot
.61542 .48785 Mdot
.30112 .6219 Mdot
.51431 .58431 Mdot
.39356 .42261 Mdot
.64438 .45154 Mdot
.3098 .57147 Mdot
.48415 .60071 Mdot
.30166 .44865 Mdot
.53679 .63266 Mdot
.631 .56 Mdot
.69088 .48805 Mdot
.56813 .85199 Mdot
.67713 .43567 Mdot
.57386 .31822 Mdot
.51886 .31604 Mdot
.50898 .60952 Mdot
.15763 .45966 Mdot
.69004 .50635 Mdot
.58896 .34464 Mdot
.26352 .59976 Mdot
.44308 .37695 Mdot
.27831 .57587 Mdot
.32332 .43211 Mdot
.28062 .59349 Mdot
.32426 .44818 Mdot
.42863 .72181 Mdot
.64304 .52062 Mdot
.29819 .60532 Mdot
.4053 .50537 Mdot
.46572 .64125 Mdot
.325 .58073 Mdot
.53905 .5422 Mdot
.56943 .75069 Mdot
.34131 .44236 Mdot
.3114 .57745 Mdot
.48596 .62692 Mdot
.81964 .56489 Mdot
.51868 .32983 Mdot
.56694 .33951 Mdot
.49658 .66525 Mdot
.33911 .4527 Mdot
.67305 .42931 Mdot
.60109 .40655 Mdot
.47341 .31401 Mdot
.50182 .59198 Mdot
.56475 .59725 Mdot
.62467 .48581 Mdot
.67273 .52133 Mdot
.51007 .61423 Mdot
.72077 .54258 Mdot
.49705 .61019 Mdot
.54775 .30289 Mdot
.67126 .43919 Mdot
.66353 .47396 Mdot
.33069 .43085 Mdot
.70521 .48093 Mdot
.49649 .53238 Mdot
.51522 .39411 Mdot
.52202 .54391 Mdot
.53812 .33378 Mdot
.55513 .41394 Mdot
.46292 .32913 Mdot
.77898 .6514 Mdot
.62273 .46687 Mdot
.52719 .66619 Mdot
.64526 .49691 Mdot
.3045 .58256 Mdot
.67346 .45625 Mdot
.63438 .46347 Mdot
.51619 .59737 Mdot
.54928 .58904 Mdot
.38622 .44149 Mdot
.55685 .43582 Mdot
.69196 .49411 Mdot
.50058 .59693 Mdot
.56129 .63792 Mdot
.53652 .6703 Mdot
.48153 .43688 Mdot
.65196 .44331 Mdot
.67829 .59482 Mdot
.49041 .74895 Mdot
.69404 .4919 Mdot
.83514 .46664 Mdot
.4479 .37039 Mdot
.33695 .46407 Mdot
.49369 .33239 Mdot
.49226 .61623 Mdot
.39785 .4011 Mdot
.54496 .58792 Mdot
.52719 .52287 Mdot
.53787 .60367 Mdot
.28723 .5691 Mdot
.47355 .5851 Mdot
.43275 .39968 Mdot
.36125 .4278 Mdot
.51143 .5778 Mdot
.53886 .59098 Mdot
.31323 .47941 Mdot
.64559 .43865 Mdot
.69157 .45653 Mdot
.31858 .5268 Mdot
.30147 .59501 Mdot
.52145 .30372 Mdot
.55094 .62678 Mdot
.40275 .41662 Mdot
.35313 .4301 Mdot
.70779 .46091 Mdot
.35008 .43667 Mdot
.5083 .33532 Mdot
.54128 .62507 Mdot
.56497 .34302 Mdot
.31459 .58031 Mdot
.63611 .47582 Mdot
.56007 .60852 Mdot
.51667 .63549 Mdot
.66827 .49616 Mdot
.48653 .57506 Mdot
.28317 .57735 Mdot
.35656 .42513 Mdot
.68783 .48157 Mdot
.54983 .31939 Mdot
.32121 .44002 Mdot
.50006 .63387 Mdot
.66801 .1896 Mdot
.51549 .62032 Mdot
.49301 .62533 Mdot
.68558 .78538 Mdot
.47767 .57705 Mdot
.34737 .4223 Mdot
.62869 .49481 Mdot
.48378 .65305 Mdot
.31212 .6659 Mdot
.25447 .71112 Mdot
.36811 .44727 Mdot
.52123 .57937 Mdot
.78014 .66047 Mdot
.51791 .57758 Mdot
.26558 .68783 Mdot
.22356 .48275 Mdot
.45883 .51813 Mdot
.53886 .52679 Mdot
.52679 .35148 Mdot
.38982 .43974 Mdot
.32342 .44051 Mdot
.60577 .67293 Mdot
.51107 .59542 Mdot
.61797 .56068 Mdot
.47897 .62172 Mdot
.55598 .31704 Mdot
.50096 .73459 Mdot
.34227 .43333 Mdot
.35082 .22971 Mdot
.52855 .65049 Mdot
.6532 .44122 Mdot
.31486 .45471 Mdot
.44986 .36674 Mdot
.49093 .62809 Mdot
.32046 .59725 Mdot
.53218 .36999 Mdot
.48077 .55947 Mdot
.54307 .33374 Mdot
.48715 .60173 Mdot
.56691 .53753 Mdot
.20203 .37022 Mdot
.69505 .48402 Mdot
.53229 .30949 Mdot
.32837 .30486 Mdot
.48147 .5788 Mdot
.6861 .48488 Mdot
.65991 .46051 Mdot
.29419 .61872 Mdot
.5162 .45034 Mdot
.65466 .28759 Mdot
.7675 .61832 Mdot
.56277 .73368 Mdot
.32968 .45828 Mdot
.37322 .28054 Mdot
.51434 .64341 Mdot
.50118 .2318 Mdot
.5574 .35734 Mdot
.52144 .61328 Mdot
.5933 .72216 Mdot
.63866 .46665 Mdot
.50198 .62348 Mdot
.27302 .60265 Mdot
.48155 .21716 Mdot
.48634 .23067 Mdot
.803 .40162 Mdot
.38132 .44045 Mdot
.57611 .62683 Mdot
.51314 .52745 Mdot
.40527 .4329 Mdot
.4781 .59876 Mdot
.35238 .42191 Mdot
.50191 .80306 Mdot
.29718 .57003 Mdot
.63813 .4607 Mdot
.44869 .36919 Mdot
.47231 .63525 Mdot
.55322 .65675 Mdot
.32573 .60489 Mdot
.50967 .65884 Mdot
.25232 .30495 Mdot
.43553 .28245 Mdot
.39621 .4073 Mdot
.69831 .47122 Mdot
.46388 .62735 Mdot
.45206 .37998 Mdot
.5112 .5996 Mdot
.70282 .69156 Mdot
.52728 .66478 Mdot
.636 .27302 Mdot
.67937 .49694 Mdot
.54169 .33132 Mdot
.58412 .58623 Mdot
.54325 .6063 Mdot
.29787 .41604 Mdot
.54558 .52696 Mdot
.52352 .57146 Mdot
.68837 .4326 Mdot
.66167 .44152 Mdot
.68216 .46494 Mdot
.34252 .41425 Mdot
.54554 .22836 Mdot
.52893 .33241 Mdot
.55772 .56304 Mdot
.55914 .29782 Mdot
.43513 .65506 Mdot
.3217 .61056 Mdot
.81173 .52674 Mdot
.51025 .66202 Mdot
.67736 .47081 Mdot
.70609 .36513 Mdot
.67639 .5041 Mdot
.37065 .39645 Mdot
.54664 .34245 Mdot
.64302 .45688 Mdot
.54832 .61063 Mdot
.54653 .42577 Mdot
.80097 .46131 Mdot
.53786 .31603 Mdot
.56034 .54776 Mdot
.41867 .40874 Mdot
.45254 .30321 Mdot
.72743 .21941 Mdot
.52314 .31683 Mdot
.3386 .29553 Mdot
.50861 .59144 Mdot
.67347 .44371 Mdot
.51927 .34787 Mdot
.51721 .33574 Mdot
.34137 .43944 Mdot
.55153 .58972 Mdot
.55615 .59463 Mdot
.43244 .39599 Mdot
.54559 .30901 Mdot
.53818 .67542 Mdot
.57258 .59774 Mdot
.72321 .75594 Mdot
.59853 .66299 Mdot
.26559 .76002 Mdot
.45292 .56409 Mdot
.59688 .72769 Mdot
.5848 .44817 Mdot
.63285 .48085 Mdot
.55449 .58694 Mdot
.46598 .61563 Mdot
.33649 .42687 Mdot
.5293 .62364 Mdot
.34171 .4113 Mdot
.52297 .32594 Mdot
.82981 .46348 Mdot
.71486 .32778 Mdot
.49334 .79739 Mdot
.53049 .62083 Mdot
.58473 .23859 Mdot
.31016 .59275 Mdot
.5778 .32464 Mdot
.68702 .47244 Mdot
.49832 .5705 Mdot
.30215 .47676 Mdot
.36164 .44396 Mdot
.65807 .4538 Mdot
.33858 .26267 Mdot
.28439 .45552 Mdot
.51048 .56827 Mdot
.3628 .4066 Mdot
.66344 .38419 Mdot
.72697 .53404 Mdot
.54578 .28318 Mdot
.2829 .57151 Mdot
.37225 .44051 Mdot
.56351 .3289 Mdot
.60258 .46457 Mdot
.64503 .45796 Mdot
.63652 .50869 Mdot
.25516 .44046 Mdot
.30156 .46174 Mdot
.30668 .60346 Mdot
.55142 .22785 Mdot
.53727 .21571 Mdot
.2858 .5701 Mdot
.42291 .39794 Mdot
.65427 .44474 Mdot
.67426 .48453 Mdot
.66111 .46806 Mdot
.36725 .21912 Mdot
.69748 .44384 Mdot
.72398 .59962 Mdot
.56055 .64195 Mdot
.59841 .54677 Mdot
.52192 .57785 Mdot
.55136 .35626 Mdot
.68715 .49016 Mdot
.57061 .4546 Mdot
.54011 .55827 Mdot
.80704 .42868 Mdot
.50417 .58889 Mdot
.55101 .28481 Mdot
.49629 .62221 Mdot
.74539 .56538 Mdot
.63255 .48861 Mdot
.53253 .62771 Mdot
.50884 .35216 Mdot
.29447 .59128 Mdot
.68237 .42326 Mdot
.55589 .59071 Mdot
.62532 .3412 Mdot
.48253 .56888 Mdot
.53629 .81493 Mdot
.3739 .74555 Mdot
.30195 .62191 Mdot
.44 .64223 Mdot
.34565 .45411 Mdot
.60556 .55234 Mdot
.45601 .58424 Mdot
.53905 .31685 Mdot
.68704 .26184 Mdot
.38084 .43451 Mdot
.49637 .72672 Mdot
.5005 .69269 Mdot
.27176 .60859 Mdot
.71786 .48813 Mdot
.5369 .36024 Mdot
.51681 .55785 Mdot
.56556 .65496 Mdot
.51581 .80216 Mdot
.46246 .57643 Mdot
.56306 .62087 Mdot
.32599 .59891 Mdot
.68193 .60226 Mdot
.51598 .63056 Mdot
.39498 .39301 Mdot
.63418 .50492 Mdot
.48921 .66038 Mdot
.67978 .59013 Mdot
.5016 .59688 Mdot
.66293 .44826 Mdot
.66885 .51973 Mdot
.68206 .34094 Mdot
.26519 .6066 Mdot
.52665 .66474 Mdot
.40402 .77248 Mdot
.5275 .6541 Mdot
.53241 .33956 Mdot
.53141 .56737 Mdot
.35479 .44508 Mdot
.34722 .2391 Mdot
.36718 .41089 Mdot
.54348 .57798 Mdot
.65932 .47308 Mdot
.53046 .35534 Mdot
.2553 .41562 Mdot
.24298 .48728 Mdot
.71788 .5985 Mdot
.37909 .81421 Mdot
.30445 .57409 Mdot
.30116 .56321 Mdot
.52952 .35944 Mdot
.5312 .62899 Mdot
.36226 .76039 Mdot
.48935 .55603 Mdot
.50449 .62687 Mdot
.53761 .6024 Mdot
.52932 .24048 Mdot
.52882 .32094 Mdot
.36009 .43452 Mdot
.51173 .61587 Mdot
.49891 .5987 Mdot
.64764 .49464 Mdot
.29301 .5928 Mdot
.3589 .41122 Mdot
.29488 .6006 Mdot
.38653 .41919 Mdot
.83836 .47936 Mdot
.56467 .5605 Mdot
.29715 .59084 Mdot
.56046 .35838 Mdot
.67744 .44946 Mdot
.45547 .37566 Mdot
.32269 .43426 Mdot
.33655 .43521 Mdot
.5035 .59135 Mdot
.66919 .44629 Mdot
.70196 .48549 Mdot
.30581 .58237 Mdot
.51225 .32071 Mdot
.54491 .58218 Mdot
.48964 .57737 Mdot
.42547 .56463 Mdot
.3145 .46398 Mdot
.69108 .54653 Mdot
.66786 .35714 Mdot
.535 .62993 Mdot
.70202 .46455 Mdot
.53349 .59572 Mdot
.74147 .69407 Mdot
.68713 .44649 Mdot
.549 .56956 Mdot
.53769 .20436 Mdot
.44003 .38031 Mdot
.6377 .31169 Mdot
.54909 .65185 Mdot
.43017 .83607 Mdot
.51247 .64745 Mdot
.76353 .7053 Mdot
.3389 .49457 Mdot
.55987 .6208 Mdot
.51369 .63963 Mdot
.78164 .59712 Mdot
.52015 .5877 Mdot
.43445 .40104 Mdot
.49347 .72815 Mdot
.64651 .44122 Mdot
.57645 .46556 Mdot
.34812 .55064 Mdot
.26363 .60756 Mdot
.40313 .41133 Mdot
.34367 .31745 Mdot
.2746 .5896 Mdot
.65511 .48074 Mdot
.54193 .63744 Mdot
.4866 .49563 Mdot
.4319 .39262 Mdot
.51256 .68475 Mdot
.53675 .34191 Mdot
.40078 .29623 Mdot
.3558 .40521 Mdot
.5469 .32472 Mdot
.48656 .64694 Mdot
.78064 .49897 Mdot
.21253 .47822 Mdot
.58123 .84942 Mdot
.52406 .3547 Mdot
.55461 .31054 Mdot
.41862 .19447 Mdot
.26163 .59989 Mdot
.52584 .78022 Mdot
.61452 .26835 Mdot
.50882 .31412 Mdot
.46348 .76691 Mdot
.36567 .44485 Mdot
.62188 .32816 Mdot
.62103 .45157 Mdot
.56625 .64023 Mdot
.54673 .6098 Mdot
.51419 .31619 Mdot
.61318 .43664 Mdot
.19577 .3885 Mdot
.54009 .32237 Mdot
.55687 .53849 Mdot
.47554 .46052 Mdot
.45002 .37073 Mdot
.36213 .45444 Mdot
.26854 .61173 Mdot
.341 .57899 Mdot
.64963 .49238 Mdot
.2805 .61739 Mdot
.47892 .23102 Mdot
.51056 .66078 Mdot
.54422 .31424 Mdot
.45932 .36424 Mdot
.55261 .32207 Mdot
.27456 .59749 Mdot
.29213 .62287 Mdot
.70038 .47781 Mdot
.69025 .45619 Mdot
.61012 .72063 Mdot
.41859 .73851 Mdot
.51517 .57752 Mdot
.76951 .41051 Mdot
.65955 .50084 Mdot
.44523 .61099 Mdot
.28292 .56912 Mdot
.29737 .59356 Mdot
.6266 .58689 Mdot
.55681 .61963 Mdot
.32945 .74173 Mdot
.55555 .61929 Mdot
.46768 .74253 Mdot
.47582 .60005 Mdot
.34522 .43839 Mdot
.55535 .62716 Mdot
.25259 .60977 Mdot
.55803 .5669 Mdot
.51899 .57134 Mdot
.34815 .45091 Mdot
.47448 .56729 Mdot
.35257 .44571 Mdot
.54412 .57657 Mdot
.2804 .5675 Mdot
.40326 .41572 Mdot
.34699 .65391 Mdot
.4602 .43594 Mdot
.42409 .41414 Mdot
.30538 .6122 Mdot
.30793 .6158 Mdot
.30273 .65524 Mdot
.68697 .47414 Mdot
.71178 .43297 Mdot
.52772 .6279 Mdot
.32963 .45425 Mdot
.5292 .31635 Mdot
.49776 .60189 Mdot
.47373 .59306 Mdot
.56193 .62938 Mdot
.6374 .48333 Mdot
.30531 .45564 Mdot
.29519 .58628 Mdot
.35767 .40786 Mdot
.3063 .41663 Mdot
.37435 .40078 Mdot
.47302 .66175 Mdot
.58177 .62731 Mdot
.59324 .75988 Mdot
.76061 .37135 Mdot
.4894 .17698 Mdot
.64843 .45688 Mdot
.41499 .4207 Mdot
.28424 .62082 Mdot
.46702 .7057 Mdot
.68159 .47376 Mdot
.33737 .45013 Mdot
.53779 .63252 Mdot
.56514 .55005 Mdot
.48946 .35262 Mdot
.60737 .55002 Mdot
.32564 .69739 Mdot
.32998 .41721 Mdot
.44138 .3899 Mdot
.52995 .2188 Mdot
.51723 .72146 Mdot
.53617 .47854 Mdot
.52673 .60586 Mdot
.32097 .59379 Mdot
.64445 .45149 Mdot
.23516 .439 Mdot
.5327 .3022 Mdot
.55969 .43397 Mdot
.53125 .62159 Mdot
.57797 .2643 Mdot
.65887 .47145 Mdot
.27714 .61015 Mdot
.51507 .31417 Mdot
.26698 .61751 Mdot
.35708 .45734 Mdot
.3383 .7684 Mdot
.52026 .65803 Mdot
.52671 .5725 Mdot
.56695 .30613 Mdot
.64478 .48596 Mdot
.30488 .62845 Mdot
.55771 .80668 Mdot
.38249 .40511 Mdot
.31702 .73622 Mdot
.6835 .50621 Mdot
.74372 .59955 Mdot
.35239 .40974 Mdot
.56577 .32698 Mdot
.30788 .65058 Mdot
.55957 .32033 Mdot
.55833 .5876 Mdot
.67018 .47235 Mdot
.52023 .33168 Mdot
.31722 .39692 Mdot
.80434 .62028 Mdot
.75461 .59722 Mdot
.54319 .64598 Mdot
.8166 .50586 Mdot
.61557 .80873 Mdot
.67574 .41123 Mdot
.54115 .29578 Mdot
.51497 .60312 Mdot
.47644 .62948 Mdot
.53227 .64841 Mdot
.53555 .3479 Mdot
.38852 .3628 Mdot
.33292 .4424 Mdot
.51036 .58353 Mdot
.28753 .61966 Mdot
.35707 .44286 Mdot
.44026 .36635 Mdot
.33951 .42742 Mdot
.6318 .45581 Mdot
.55171 .568 Mdot
.59116 .37413 Mdot
.82957 .60367 Mdot
.53444 .31871 Mdot
.42423 .41378 Mdot
.49627 .58178 Mdot
.6041 .2306 Mdot
.68149 .46652 Mdot
.38591 .40467 Mdot
.51841 .61183 Mdot
.36784 .37206 Mdot
.30615 .47996 Mdot
.33798 .42984 Mdot
.67971 .48343 Mdot
.67847 .4063 Mdot
.52563 .62289 Mdot
.51175 .64968 Mdot
.64763 .4857 Mdot
.30331 .54461 Mdot
.3607 .2348 Mdot
.53724 .59308 Mdot
.54271 .32999 Mdot
.17168 .6153 Mdot
.54493 .66209 Mdot
.57404 .69588 Mdot
.37283 .44722 Mdot
.64338 .346 Mdot
.69516 .5434 Mdot
.44402 .66163 Mdot
.78673 .59938 Mdot
.39907 .54668 Mdot
.82824 .47567 Mdot
.31212 .42465 Mdot
.38922 .48618 Mdot
.83789 .49214 Mdot
.50885 .34917 Mdot
.59263 .51902 Mdot
.42749 .60268 Mdot
.32949 .25463 Mdot
.6117 .42718 Mdot
.29359 .52562 Mdot
.27077 .44424 Mdot
.46702 .49104 Mdot
.36826 .42052 Mdot
.44296 .70879 Mdot
.54432 .5842 Mdot
.60795 .813 Mdot
.72461 .54642 Mdot
.18383 .39868 Mdot
.81854 .51689 Mdot
.4081 .77217 Mdot
.79987 .48398 Mdot
.76105 .68368 Mdot
.58082 .76171 Mdot
.75416 .37749 Mdot
.22546 .66898 Mdot
.52066 .20925 Mdot
.43234 .79066 Mdot
.55904 .67425 Mdot
.39195 .54194 Mdot
.47266 .81838 Mdot
.71824 .62962 Mdot
.15254 .4865 Mdot
.34445 .41958 Mdot
.63258 .49789 Mdot
.42658 .58944 Mdot
.70762 .4429 Mdot
.51654 .27791 Mdot
.79183 .59266 Mdot
.74748 .71813 Mdot
.74017 .56421 Mdot
.43011 .83887 Mdot
.61523 .68016 Mdot
.39838 .1649 Mdot
.43536 .45653 Mdot
.66229 .51713 Mdot
.22042 .55832 Mdot
.54255 .21865 Mdot
.69207 .30647 Mdot
.44833 .56716 Mdot
.43955 .33877 Mdot
.36391 .67628 Mdot
.66275 .48148 Mdot
.72163 .53109 Mdot
.33827 .46681 Mdot
.70109 .29946 Mdot
.29589 .64122 Mdot
.78706 .6296 Mdot
.50193 .47995 Mdot
.61602 .33918 Mdot
.38081 .27201 Mdot
.67048 .19119 Mdot
.42472 .75871 Mdot
.67223 .75839 Mdot
.49334 .30797 Mdot
.6233 .42019 Mdot
.28082 .306 Mdot
.39341 .72025 Mdot
.54387 .21689 Mdot
.71338 .26161 Mdot
.57568 .83508 Mdot
.75212 .28654 Mdot
.70012 .42739 Mdot
.56089 .63035 Mdot
.66835 .75025 Mdot
.55193 .73406 Mdot
.32929 .56733 Mdot
.79249 .37664 Mdot
.31745 .58163 Mdot
.70358 .43276 Mdot
.33407 .26092 Mdot
.73264 .58469 Mdot
.31353 .72882 Mdot
.28999 .63254 Mdot
.46124 .60981 Mdot
.17856 .32201 Mdot
.82332 .47426 Mdot
.67406 .33909 Mdot
.72544 .7541 Mdot
.56525 .25246 Mdot
.35831 .74591 Mdot
.52239 .33614 Mdot
.84319 .54282 Mdot
.6741 .48071 Mdot
.87043 .47376 Mdot
.82349 .59196 Mdot
.19696 .42791 Mdot
.10526 .54836 Mdot
.47232 .25181 Mdot
.48201 .50974 Mdot
.39458 .5569 Mdot
.32871 .67604 Mdot
.21534 .3676 Mdot
.178 .46455 Mdot
.55094 .23845 Mdot
.43331 .82008 Mdot
.83586 .52156 Mdot
.47667 .76782 Mdot
.37047 .78087 Mdot
.31508 .27328 Mdot
.47491 .43203 Mdot
.72029 .49198 Mdot
.45321 .41925 Mdot
.75793 .43645 Mdot
.78852 .35627 Mdot
.54585 .7269 Mdot
.13617 .5827 Mdot
.26393 .6285 Mdot
.32332 .50177 Mdot
.67602 .77574 Mdot
.36025 .64536 Mdot
.5158 .74785 Mdot
.44843 .19452 Mdot
.48357 .68229 Mdot
.4793 .19789 Mdot
.73144 .40604 Mdot
.35815 .31272 Mdot
.50923 .20881 Mdot
.63021 .38601 Mdot
.53067 .80447 Mdot
.69049 .72153 Mdot
.56026 .21463 Mdot
.64525 .44085 Mdot
.3692 .71407 Mdot
.44107 .76433 Mdot
.71306 .76478 Mdot
.32906 .30442 Mdot
.61342 .85047 Mdot
.29385 .32237 Mdot
.53153 .54514 Mdot
.48382 .54687 Mdot
.592 .61611 Mdot
.39859 .73485 Mdot
.56353 .63 Mdot
.55822 .2421 Mdot
.69844 .77853 Mdot
.58868 .7186 Mdot
.35851 .32364 Mdot
.69984 .26999 Mdot
.58723 .84598 Mdot
.60807 .76911 Mdot
.34847 .47658 Mdot
.57866 .6799 Mdot
.49697 .15815 Mdot
.3718 .43457 Mdot
.47094 .77035 Mdot
.51255 .29991 Mdot
.24422 .45081 Mdot
.77175 .59934 Mdot
.21235 .40983 Mdot
.69726 .78047 Mdot
.37138 .23335 Mdot
.26194 .38902 Mdot
.26823 .64723 Mdot
.29603 .72074 Mdot
.73145 .30432 Mdot
.57808 .58924 Mdot
.51433 .51472 Mdot
.32471 .59439 Mdot
.62812 .72741 Mdot
.50909 .76191 Mdot
.24163 .51894 Mdot
.5143 .53403 Mdot
.1905 .50781 Mdot
.44336 .38906 Mdot
.55478 .43022 Mdot
.78535 .2976 Mdot
.49258 .67807 Mdot
.48195 .2615 Mdot
.55601 .83085 Mdot
.36003 .72708 Mdot
.6777 .76751 Mdot
.60975 .3797 Mdot
.746 .28514 Mdot
.81156 .62464 Mdot
.23914 .49915 Mdot
.82216 .43432 Mdot
.69135 .80105 Mdot
.71327 .25035 Mdot
.65086 .53613 Mdot
.53018 .36341 Mdot
.85948 .3721 Mdot
.42068 .39462 Mdot
.65297 .23322 Mdot
.56395 .73235 Mdot
.36795 .35794 Mdot
.65802 .42559 Mdot
.55106 .68802 Mdot
.47461 .48971 Mdot
.60801 .47283 Mdot
.47706 .64828 Mdot
.71947 .23268 Mdot
.67359 .22988 Mdot
.73925 .25868 Mdot
.51517 .83558 Mdot
.82633 .44146 Mdot
.43055 .54325 Mdot
.72912 .60876 Mdot
.41695 .6313 Mdot
.5232 .56638 Mdot
.42384 .69847 Mdot
.46795 .254 Mdot
.21486 .46057 Mdot
.67601 .29365 Mdot
.6969 .43325 Mdot
.7885 .40758 Mdot
.63845 .14256 Mdot
.6267 .67049 Mdot
.65065 .60678 Mdot
.49746 .2281 Mdot
.42262 .7458 Mdot
.74631 .4232 Mdot
.20375 .44983 Mdot
.69332 .77359 Mdot
.42517 .62578 Mdot
.47781 .7813 Mdot
.25324 .53461 Mdot
.25154 .6691 Mdot
.36976 .52454 Mdot
.80005 .61169 Mdot
.3959 .58708 Mdot
.23792 .39056 Mdot
.56721 .47978 Mdot
.19566 .4106 Mdot
.27572 .48798 Mdot
.40163 .29008 Mdot
.44545 .78165 Mdot
.46102 .3108 Mdot
.46137 .75017 Mdot
.48608 .45572 Mdot
.44847 .69925 Mdot
.40115 .54464 Mdot
.46499 .75175 Mdot
.24896 .66308 Mdot
.79949 .36965 Mdot
.68249 .81688 Mdot
.60653 .17785 Mdot
.44407 .84111 Mdot
.71461 .39714 Mdot
.55872 .65431 Mdot
.65503 .80151 Mdot
.77872 .30873 Mdot
.80866 .64048 Mdot
.38547 .23535 Mdot
.33718 .38407 Mdot
.57636 .3285 Mdot
.61045 .18347 Mdot
.30973 .52734 Mdot
.73064 .72076 Mdot
.4982 .18101 Mdot
.49358 .33651 Mdot
.30838 .25502 Mdot
.65085 .22328 Mdot
.77149 .57648 Mdot
.65426 .55273 Mdot
.51455 .68777 Mdot
.74669 .54666 Mdot
.62449 .47484 Mdot
.36594 .27533 Mdot
.39901 .72824 Mdot
.3851 .42777 Mdot
.37707 .61015 Mdot
.47983 .52918 Mdot
.47301 .58545 Mdot
.35911 .55525 Mdot
.62025 .48442 Mdot
.7597 .37221 Mdot
.55657 .39764 Mdot
.84478 .44023 Mdot
.44916 .26226 Mdot
.55519 .52662 Mdot
.37807 .73609 Mdot
.26765 .39279 Mdot
.43115 .19478 Mdot
.50448 .32054 Mdot
.82111 .54541 Mdot
.46084 .38691 Mdot
.37336 .71839 Mdot
.74529 .53842 Mdot
.54774 .79282 Mdot
.57835 .63993 Mdot
.68599 .35806 Mdot
.67445 .71223 Mdot
.55163 .43741 Mdot
.72118 .46458 Mdot
.69828 .51638 Mdot
.52863 .87677 Mdot
.46706 .22259 Mdot
.38724 .28787 Mdot
.8192 .55673 Mdot
.55191 .34161 Mdot
.68627 .4995 Mdot
.4411 .7177 Mdot
.53359 .80886 Mdot
.69714 .67922 Mdot
.30426 .47944 Mdot
.43144 .32214 Mdot
.26199 .51373 Mdot
.81313 .51704 Mdot
.80665 .48994 Mdot
.17929 .3999 Mdot
.70356 .4447 Mdot
.57125 .78982 Mdot
.48631 .79235 Mdot
.64477 .50008 Mdot
.66965 .42019 Mdot
.67514 .27631 Mdot
.8231 .39725 Mdot
.59445 .35479 Mdot
.42251 .82519 Mdot
.28194 .67196 Mdot
.37701 .3712 Mdot
.255 .40904 Mdot
.40616 .78409 Mdot
.8161 .56655 Mdot
.73441 .5189 Mdot
.77974 .54679 Mdot
.58318 .5573 Mdot
.61325 .56423 Mdot
.58763 .16774 Mdot
.45752 .44817 Mdot
.746 .5912 Mdot
.61744 .39274 Mdot
.53467 .65175 Mdot
.67316 .1939 Mdot
.58037 .81757 Mdot
.43675 .18633 Mdot
.54676 .36855 Mdot
.4926 .63732 Mdot
.57013 .57712 Mdot
.5987 .6448 Mdot
.66204 .34634 Mdot
.69608 .25519 Mdot
.41001 .7861 Mdot
.66414 .39427 Mdot
.7281 .54171 Mdot
.48178 .26232 Mdot
.77993 .64027 Mdot
.63672 .79632 Mdot
.5226 .44116 Mdot
.45957 .25461 Mdot
.3203 .64269 Mdot
.45651 .83835 Mdot
.41901 .51804 Mdot
.43181 .54951 Mdot
.61752 .24615 Mdot
.64087 .36319 Mdot
.24458 .41581 Mdot
.48826 .58868 Mdot
.33923 .26173 Mdot
.76177 .68027 Mdot
.14378 .48613 Mdot
.24111 .34172 Mdot
.69156 .20348 Mdot
.72099 .67454 Mdot
.62725 .36656 Mdot
.78696 .50862 Mdot
.13454 .49786 Mdot
.38802 .54105 Mdot
.80088 .43709 Mdot
.28707 .65026 Mdot
.81708 .53755 Mdot
.50221 .34843 Mdot
.59982 .28165 Mdot
.69462 .26525 Mdot
.8259 .41586 Mdot
.62374 .76928 Mdot
.79939 .59886 Mdot
.56103 .47881 Mdot
.81088 .36222 Mdot
.61749 .23587 Mdot
.45701 .49503 Mdot
.41303 .4155 Mdot
.42734 .20578 Mdot
.77819 .45019 Mdot
.74731 .38969 Mdot
.47128 .77385 Mdot
.41187 .51137 Mdot
.48657 .72767 Mdot
.76995 .53773 Mdot
.37966 .64971 Mdot
.64853 .37064 Mdot
.37601 .73535 Mdot
.76336 .68799 Mdot
.38075 .53523 Mdot
.26492 .40351 Mdot
.46895 .27513 Mdot
.35945 .78402 Mdot
.66421 .34178 Mdot
.4578 .22424 Mdot
.6767 .75585 Mdot
.29526 .5002 Mdot
.41645 .76972 Mdot
.64357 .86795 Mdot
.42543 .80208 Mdot
.73595 .3354 Mdot
.78557 .35345 Mdot
.66501 .78181 Mdot
.75211 .35693 Mdot
.22342 .35022 Mdot
.60897 .63765 Mdot
.42578 .71799 Mdot
.53875 .60333 Mdot
.77772 .29285 Mdot
.37463 .6759 Mdot
.78857 .35064 Mdot
.62221 .82437 Mdot
.75296 .54107 Mdot
.47198 .5862 Mdot
.31771 .42587 Mdot
.40771 .44631 Mdot
.38641 .64596 Mdot
.78586 .54859 Mdot
.60562 .65246 Mdot
.43782 .28976 Mdot
.39805 .4389 Mdot
.33115 .52514 Mdot
.72443 .42596 Mdot
.438 .25262 Mdot
.6605 .35959 Mdot
.3155 .54968 Mdot
.53031 .46574 Mdot
.4373 .75356 Mdot
.69843 .54364 Mdot
.76955 .58707 Mdot
.21445 .40351 Mdot
.47056 .38623 Mdot
.3466 .42179 Mdot
.75608 .64067 Mdot
.44664 .81385 Mdot
.66293 .3793 Mdot
.73785 .28347 Mdot
.41295 .20627 Mdot
.41482 .65196 Mdot
.48914 .74528 Mdot
.20796 .39063 Mdot
.23083 .66377 Mdot
.77748 .38213 Mdot
.71374 .51695 Mdot
.3315 .73917 Mdot
.46776 .53419 Mdot
.83749 .48139 Mdot
.44209 .78906 Mdot
.5286 .76301 Mdot
.44615 .44411 Mdot
.70258 .64869 Mdot
.76136 .52283 Mdot
.34129 .65074 Mdot
.55038 .46603 Mdot
.41486 .15728 Mdot
.62664 .43881 Mdot
.64695 .17044 Mdot
.54158 .30178 Mdot
.35669 .21589 Mdot
.24056 .64071 Mdot
.48694 .45071 Mdot
.55746 .46614 Mdot
.68951 .35269 Mdot
.63492 .27107 Mdot
.47824 .83269 Mdot
.1756 .44935 Mdot
.39564 .39645 Mdot
.36735 .7684 Mdot
.31935 .7595 Mdot
.77867 .60459 Mdot
.46606 .63486 Mdot
.41844 .8041 Mdot
.46251 .4444 Mdot
.21635 .45563 Mdot
.636 .80823 Mdot
.72376 .38199 Mdot
.55535 .535 Mdot
.41747 .7418 Mdot
.79902 .44003 Mdot
.8115 .61514 Mdot
.26723 .28889 Mdot
.73047 .40536 Mdot
.53981 .36355 Mdot
.43892 .524 Mdot
.80379 .54041 Mdot
.33553 .7261 Mdot
.61099 .33347 Mdot
.43506 .76636 Mdot
.55192 .1342 Mdot
.7129 .271 Mdot
.69533 .25495 Mdot
.36949 .74573 Mdot
.71496 .469 Mdot
.65088 .24867 Mdot
.50213 .75233 Mdot
.72014 .37213 Mdot
.48904 .82039 Mdot
.45928 .76268 Mdot
.17071 .39058 Mdot
.5656 .75714 Mdot
.30537 .41914 Mdot
.76191 .50662 Mdot
.58225 .73661 Mdot
.53661 .36723 Mdot
.41333 .69789 Mdot
.62352 .39311 Mdot
.57319 .3152 Mdot
.65498 .36859 Mdot
.6277 .33655 Mdot
.5379 .76515 Mdot
.71276 .66237 Mdot
.67868 .39287 Mdot
.73894 .67874 Mdot
.60206 .50174 Mdot
.23651 .4379 Mdot
.28367 .3834 Mdot
.61455 .40867 Mdot
.40497 .40529 Mdot
.44161 .65354 Mdot
.54334 .4429 Mdot
.36916 .5823 Mdot
.58311 .17947 Mdot
.31965 .58173 Mdot
.71006 .47473 Mdot
.40358 .18447 Mdot
.64816 .50463 Mdot
.74203 .25195 Mdot
.20934 .43661 Mdot
.74116 .54169 Mdot
.2491 .49433 Mdot
.22984 .54465 Mdot
.27271 .24252 Mdot
.7568 .46551 Mdot
.44312 .43578 Mdot
.63689 .52333 Mdot
.69078 .44317 Mdot
.4487 .29505 Mdot
.39391 .44065 Mdot
.64494 .56635 Mdot
.49824 .27427 Mdot
.41494 .6383 Mdot
.68636 .51316 Mdot
.3373 .3977 Mdot
.50185 .73047 Mdot
.82873 .4108 Mdot
.36175 .41937 Mdot
.48851 .14748 Mdot
.54802 .54308 Mdot
.65713 .74056 Mdot
.68506 .78956 Mdot
.28754 .26965 Mdot
.28989 .35625 Mdot
.24684 .7034 Mdot
.5228 .54726 Mdot
.69432 .39598 Mdot
.66515 .48451 Mdot
.51114 .76984 Mdot
.28261 .59351 Mdot
.34167 .70369 Mdot
.55932 .29746 Mdot
.2391 .39199 Mdot
.42992 .25666 Mdot
.71297 .4861 Mdot
.73782 .39722 Mdot
.57078 .77565 Mdot
.60589 .27861 Mdot
.46646 .44236 Mdot
.77702 .60323 Mdot
.70661 .6651 Mdot
.68247 .5151 Mdot
.74399 .29968 Mdot
.47183 .78566 Mdot
.84925 .53682 Mdot
.59622 .59161 Mdot
.41507 .467 Mdot
.58621 .24504 Mdot
.67633 .36738 Mdot
.67952 .54719 Mdot
.69847 .77114 Mdot
.38116 .71644 Mdot
.57084 .24244 Mdot
.4598 .74494 Mdot
.50084 .70364 Mdot
.50988 .4671 Mdot
.37559 .25989 Mdot
.20132 .33957 Mdot
.62307 .55954 Mdot
.28774 .2902 Mdot
.70117 .52098 Mdot
.48 .26038 Mdot
.6131 .45801 Mdot
.32369 .3659 Mdot
.71523 .63927 Mdot
.31407 .32168 Mdot
.84351 .50199 Mdot
.69535 .77436 Mdot
.49247 .35182 Mdot
.4449 .31785 Mdot
.59026 .46355 Mdot
.58795 .5566 Mdot
.57702 .42918 Mdot
.56408 .60732 Mdot
.66136 .41527 Mdot
.31263 .24691 Mdot
.70682 .36618 Mdot
.53039 .69027 Mdot
.83121 .4809 Mdot
.84302 .55059 Mdot
.80721 .3616 Mdot
.31158 .73247 Mdot
.63338 .4724 Mdot
.71376 .24474 Mdot
.66779 .57409 Mdot
.77261 .67982 Mdot
.77492 .38759 Mdot
.54984 .87302 Mdot
.78221 .55229 Mdot
.60964 .39359 Mdot
.18229 .45096 Mdot
.64096 .29052 Mdot
.60551 .81906 Mdot
.44435 .50042 Mdot
.38472 .30973 Mdot
.60448 .82349 Mdot
.2057 .29307 Mdot
.67523 .53192 Mdot
.62088 .33929 Mdot
.4497 .548 Mdot
.6188 .40217 Mdot
.36214 .48383 Mdot
.52905 .56762 Mdot
.45089 .3499 Mdot
.25693 .39534 Mdot
.44307 .75658 Mdot
.48223 .72813 Mdot
.35996 .48583 Mdot
.39018 .64407 Mdot
.46969 .74034 Mdot
.42876 .79139 Mdot
.77855 .57891 Mdot
.65076 .56165 Mdot
.57104 .55024 Mdot
.62099 .43881 Mdot
.26562 .59601 Mdot
.32623 .32882 Mdot
.55037 .57747 Mdot
.31177 .32742 Mdot
.62024 .27639 Mdot
.70027 .21335 Mdot
.34878 .34421 Mdot
.5597 .81499 Mdot
.61977 .45474 Mdot
.67022 .35014 Mdot
.73249 .69468 Mdot
.33226 .2558 Mdot
.3614 .50167 Mdot
.54507 .72744 Mdot
.82087 .48791 Mdot
.50864 .21067 Mdot
.52732 .79601 Mdot
.57292 .19972 Mdot
.5699 .34211 Mdot
.62444 .53895 Mdot
.4413 .55213 Mdot
.38572 .22914 Mdot
.72102 .48088 Mdot
.61352 .38826 Mdot
.42674 .48088 Mdot
.49188 .20509 Mdot
.5585 .83233 Mdot
.55946 .78339 Mdot
.7654 .49305 Mdot
.80952 .49057 Mdot
.36352 .45052 Mdot
.48365 .78406 Mdot
.59615 .39235 Mdot
.38492 .49435 Mdot
.56418 .22175 Mdot
.84181 .45334 Mdot
.57315 .43945 Mdot
.35872 .66916 Mdot
.51796 .65355 Mdot
.6806 .59323 Mdot
.70291 .35846 Mdot
.24506 .60983 Mdot
.42228 .27921 Mdot
.68974 .45024 Mdot
.4064 .27031 Mdot
.34772 .53094 Mdot
.41289 .71001 Mdot
.63914 .52119 Mdot
.57918 .70213 Mdot
.32463 .56721 Mdot
.47207 .30491 Mdot
.52211 .6728 Mdot
.34835 .67861 Mdot
.30512 .72096 Mdot
.62917 .53631 Mdot
.76285 .43496 Mdot
.77088 .61224 Mdot
.51937 .80856 Mdot
.68671 .37835 Mdot
.77509 .37505 Mdot
.64211 .27501 Mdot
.73315 .62406 Mdot
.32504 .29043 Mdot
.56022 .63446 Mdot
.32636 .36545 Mdot
.68773 .5008 Mdot
.79597 .55878 Mdot
.70988 .68469 Mdot
.34892 .65273 Mdot
.50395 .42842 Mdot
.71589 .71295 Mdot
.4936 .41423 Mdot
.67061 .79429 Mdot
.64332 .29149 Mdot
.3976 .7263 Mdot
.50214 .30957 Mdot
.26212 .64904 Mdot
.21682 .37396 Mdot
.83325 .55506 Mdot
.20424 .41476 Mdot
.50044 .49373 Mdot
.29276 .28086 Mdot
.70665 .29575 Mdot
.61651 .82283 Mdot
.4127 .7289 Mdot
.57602 .42754 Mdot
.49472 .72414 Mdot
.48736 .34183 Mdot
.45265 .38048 Mdot
.30928 .38051 Mdot
.65099 .57448 Mdot
.40937 .33572 Mdot
.28999 .34414 Mdot
.57244 .65984 Mdot
.58634 .22432 Mdot
.81454 .48809 Mdot
.54207 .7518 Mdot
.46708 .45378 Mdot
.23024 .47019 Mdot
.40179 .70298 Mdot
.3822 .8467 Mdot
.67034 .19042 Mdot
.51716 .65464 Mdot
.40572 .53816 Mdot
.35427 .69928 Mdot
.3659 .40353 Mdot
.63608 .59562 Mdot
.78547 .59457 Mdot
.55241 .30523 Mdot
.32952 .38379 Mdot
.48369 .20441 Mdot
.69482 .34831 Mdot
.36026 .6288 Mdot
.53772 .23969 Mdot
.71912 .22637 Mdot
.45319 .82061 Mdot
.69024 .36716 Mdot
.4399 .86691 Mdot
.36349 .25631 Mdot
.69733 .5181 Mdot
.66499 .75559 Mdot
.80063 .36923 Mdot
.3651 .73263 Mdot
.25382 .44184 Mdot
.75321 .341 Mdot
.39118 .71992 Mdot
.48302 .76065 Mdot
.46845 .27472 Mdot
.41161 .27246 Mdot
.48148 .47488 Mdot
.23117 .54465 Mdot
.61236 .20616 Mdot
.73701 .52482 Mdot
.80678 .46549 Mdot
.25603 .38503 Mdot
.16095 .40723 Mdot
.84358 .54197 Mdot
.41008 .6762 Mdot
.35652 .48036 Mdot
.65344 .76331 Mdot
.30537 .68696 Mdot
.55864 .72553 Mdot
.22444 .41785 Mdot
.68389 .68833 Mdot
.21596 .5322 Mdot
.27568 .32195 Mdot
.46248 .75031 Mdot
.58284 .73206 Mdot
.57136 .4441 Mdot
.7621 .61949 Mdot
.44767 .28209 Mdot
.38567 .74802 Mdot
.30762 .39978 Mdot
.30629 .67177 Mdot
.76249 .63469 Mdot
.70602 .72978 Mdot
.58621 .42737 Mdot
.22566 .27446 Mdot
.79111 .39051 Mdot
.32288 .26924 Mdot
.55873 .64514 Mdot
.84656 .48771 Mdot
.59111 .41059 Mdot
.77157 .36116 Mdot
.53646 .82086 Mdot
.31008 .36295 Mdot
.59529 .25186 Mdot
.56287 .62558 Mdot
.76786 .41849 Mdot
.74898 .58665 Mdot
.58769 .73476 Mdot
.24742 .40508 Mdot
.37853 .73351 Mdot
.33775 .47534 Mdot
.32722 .65518 Mdot
.58218 .53177 Mdot
.68728 .50426 Mdot
.75219 .2723 Mdot
.50567 .49666 Mdot
.44732 .66133 Mdot
.60078 .55938 Mdot
.18695 .43348 Mdot
.35196 .8044 Mdot
.593 .56543 Mdot
.5199 .21486 Mdot
.46449 .76932 Mdot
.43275 .67857 Mdot
.73068 .50596 Mdot
.11511 .60797 Mdot
.707 .78102 Mdot
.67348 .43151 Mdot
.60704 .66165 Mdot
.37511 .758 Mdot
.81045 .38135 Mdot
.25566 .53242 Mdot
.28171 .3812 Mdot
.15703 .51185 Mdot
.31012 .69906 Mdot
.47832 .58639 Mdot
.5449 .83355 Mdot
.82895 .56589 Mdot
.24802 .38621 Mdot
.83435 .49226 Mdot
.46034 .65264 Mdot
.57256 .5763 Mdot
.21893 .73281 Mdot
.80756 .5509 Mdot
.48489 .68422 Mdot
.18655 .4241 Mdot
.72192 .48545 Mdot
.54692 .59202 Mdot
.50018 .25559 Mdot
.43868 .78409 Mdot
.47411 .748 Mdot
.8255 .41419 Mdot
.71874 .47547 Mdot
.3038 .3345 Mdot
.56281 .31461 Mdot
.55424 .46685 Mdot
.57143 .55982 Mdot
.52691 .34503 Mdot
.42241 .67221 Mdot
.60466 .41242 Mdot
.51922 .36642 Mdot
.37406 .77881 Mdot
.59867 .855 Mdot
.73402 .65469 Mdot
.50763 .36992 Mdot
.53385 .7056 Mdot
.56966 .75477 Mdot
.38827 .64639 Mdot
.40957 .60374 Mdot
.592 .83436 Mdot
.80063 .71582 Mdot
.3909 .31377 Mdot
.59199 .64289 Mdot
.64404 .52196 Mdot
.66121 .55881 Mdot
.76779 .56684 Mdot
.58757 .33209 Mdot
.37875 .44634 Mdot
.48683 .55907 Mdot
.58279 .53142 Mdot
.55761 .29741 Mdot
.61593 .16417 Mdot
.50006 .57548 Mdot
.72226 .52146 Mdot
.78053 .66499 Mdot
.2369 .43517 Mdot
.64017 .74631 Mdot
.51778 .55308 Mdot
.64127 .24658 Mdot
.58404 .40945 Mdot
.66292 .40426 Mdot
.26493 .40021 Mdot
.81512 .43071 Mdot
.70473 .69059 Mdot
.76121 .49255 Mdot
.49911 .59355 Mdot
.26893 .57727 Mdot
.62041 .32057 Mdot
.75417 .33457 Mdot
.5469 .52071 Mdot
.7949 .65228 Mdot
.30464 .36884 Mdot
.42011 .33855 Mdot
.44022 .67681 Mdot
.7782 .32045 Mdot
.26449 .32079 Mdot
.75897 .55511 Mdot
.40395 .19814 Mdot
.43453 .22136 Mdot
.38026 .65293 Mdot
.31167 .43311 Mdot
.53823 .68991 Mdot
.71605 .49274 Mdot
.74419 .24229 Mdot
.74777 .32446 Mdot
.5354 .39145 Mdot
.40419 .29387 Mdot
.71546 .58614 Mdot
.57431 .45913 Mdot
.50785 .88404 Mdot
.29666 .52657 Mdot
.71167 .21897 Mdot
.51622 .76964 Mdot
.73946 .4353 Mdot
.62822 .3749 Mdot
.49935 .53709 Mdot
.34118 .42937 Mdot
.81327 .3969 Mdot
.58643 .53029 Mdot
.30218 .30563 Mdot
.48389 .58193 Mdot
.457 .18373 Mdot
.51818 .39821 Mdot
.45135 .31539 Mdot
.45961 .31766 Mdot
.22433 .35153 Mdot
.74956 .68867 Mdot
.56653 .41022 Mdot
.47638 .86766 Mdot
.79064 .51414 Mdot
.82183 .54636 Mdot
.30335 .48224 Mdot
.26376 .2798 Mdot
.75329 .38936 Mdot
.67182 .38942 Mdot
.53612 .39564 Mdot
.3831 .57741 Mdot
.41152 .21078 Mdot
.43291 .68303 Mdot
.63167 .30937 Mdot
.48952 .33932 Mdot
.86903 .65857 Mdot
.41997 .68504 Mdot
.46382 .54826 Mdot
.34198 .26592 Mdot
.82502 .5189 Mdot
.27297 .55853 Mdot
.56148 .84361 Mdot
.39474 .54003 Mdot
.57469 .57676 Mdot
.70192 .68087 Mdot
.53101 .75695 Mdot
.43986 .20236 Mdot
.33007 .19373 Mdot
.46291 .81813 Mdot
.41295 .31893 Mdot
.53095 .45988 Mdot
.64699 .50034 Mdot
.6609 .42541 Mdot
.24177 .51175 Mdot
.51711 .85224 Mdot
.60735 .40019 Mdot
.80435 .54203 Mdot
.25545 .26281 Mdot
.52505 .78197 Mdot
.81442 .38469 Mdot
.74165 .35718 Mdot
.63104 .43137 Mdot
.39373 .64286 Mdot
.32207 .62729 Mdot
.45474 .35131 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo09Oooooo0_l0002`ooooo`007?ooool00ol0003ooooooooo
o`2Gooooo`;o0000/?ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0/?ooool2o`0009Oooooo000Looooo`03o`000?oooooooooo0;3ooooo0_l0
002Gooooo`007?ooool00ol0003oooooooooo`2Wooooo`;o0000X?ooool001cooooo00?o0000oooo
ooooool0Yoooool2o`0002?ooooo0_l0001kooooo`007?ooool00ol0003oooooooooo`2Kooooo`;o
00004?ooool2o`0001gooooo0_l0001kooooo`007?ooool00ol0003oooooooooo`2Kooooo`;o0000
4?ooool2o`0009[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo08?ooooo0_l0000Iooooo`;o0000ZOooool001co
oooo00?o0000ooooooooool0Poooool2o`0001;ooooo0_l00005ooooo`;o00008?ooool2o`0008Oo
oooo000Looooo`03o`000?oooooooooo07kooooo0_l000000ooooooo0000o`00000:ooooo`;o0000
2?ooool2o`0002Oooooo0_l00002ooooo`;o0000Poooool001cooooo00?o0000ooooooooool0N_oo
ool2o`0000;ooooo0_l000000ooooooo0000o`00000:ooooo`;o00003_ooool2o`0001cooooo0_l0
0007ooooo`;o0000Poooool001cooooo00?o0000ooooooooool0N_ooool2o`00027ooooo0_l0000L
ooooo`;o00004Oooool2o`0007Wooooo000Looooo`03o`000?oooooooooo0:;ooooo1?l0000Eoooo
o`;o000000?oooooo`000?l000003_ooool2o`0007Wooooo000Looooo`03o`000?oooooooooo09_o
oooo0_l00005ooooo`Co00004_ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`00
0?l00000Q_ooool001cooooo00?o0000ooooooooool0Poooool2o`0000Oooooo0ol0000<ooooo`;o
000000Coooooo`000?l0003ooooo0_l0000Eooooo`Co00001Oooool2o`0008Kooooo000Looooo`03
o`000?oooooooooo07oooooo0_l00002ooooo`;o00001oooool3o`0000;ooooo0_l00008ooooo`;o
000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00004_ooool2o`0000Oooooo0_l00024oooo
o`007?ooool00ol0003oooooooooo`1oooooo`;o00002Oooool2o`0000Gooooo0_l00002ooooo`;o
00003oooool2o`0001_ooooo0_l00024ooooo`007?ooool00ol0003oooooooooo`27ooooo`;o0000
00?oooooo`000?l000002Oooool2o`000004ooooool0003o0000ooooo`;o00002_ooool2o`0001ko
oooo0_l0000<ooooo`?o0000LOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q
8@Cooooo1Ol00006ooooo`03o`000?oooooooooo06Oooooo0_l0000Nooooo`;o00000oooool2o`00
0003ooooool0003o000000Co00000oooool5o`0000Cooooo0_l00004ooooo`;o00007Oooool3o`00
00cooooo0ol000000ooooooo0000o`00001^ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5
ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0Iooo
ool2o`000003ooooool0003o000001Sooooo0_l00002ooooo`;o00000_ooool9o`0000;ooooo1?l0
0006ooooo`;o00005Oooool2o`0000cooooo0_l0000>ooooo`Go0000K_ooool00003ooooool@413o
oooo00;ooooo00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooo
oooo06[ooooo0_l0000Cooooo`;o00000oooool2o`0000;ooooo0_l00004ooooo`;o00001oooool6
o`0000;ooooo1?l0000Cooooo`Co00004Oooool2o`0000[ooooo0ol0001_ooooo`0000?oooooo`00
0?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0001ooooo
o`Co00000_ooool2o`0000Cooooo0_l00005ooooo`;o00001?ooool2o`000003ooooool0003o0000
00;ooooo1?l0000Cooooo`;o00004oooool2o`0007cooooo00000ooooooo0000ooooo`02ooooo`03
o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`21ooooo`;o
00000_ooool4o`0000;ooooo0_l00005ooooo`;o00001Oooool2o`000003ooooool0003o000000go
oooo0_l00004ooooo`;o00000_ooool2o`0000Wooooo1Ol0000Hooooo`;o0000J_ooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo08;ooooo0_l00003ooooo`;o00003oooool3o`000003ooooool0003o000000Cooooo
1Ol00004ooooo`;o00001?ooool2o`0000;ooooo0ol00008ooooo`Go00006?ooool2o`0006[ooooo
00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4006oooo
o`03o`000?oooooooooo07Oooooo0_l00004ooooo`;o00000oooool2o`0001Cooooo0_l00007oooo
o`Ko00003oooool2o`00097ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo07Oooooo0_l00004ooooo`;o00000ooo
ool2o`0001Cooooo0_l00007ooooo`;o00000_ooool2o`000003ooooool0003o000000Sooooo1Ol0
000>ooooo`;o00006Oooool2o`0006Oooooo000Looooo`03o`000?oooooooooo073ooooo0_l00009
ooooo`Co00005oooool2o`000003ooooool0003o000000[ooooo0_l000001?oooooo0000o`000?oo
ool4o`0000?ooooo1Ol00003ooooo`;o00002Oooool2o`0000cooooo0_l0000;ooooo`;o0000Iooo
ool001cooooo00?o0000ooooooooool0L?ooool2o`0000;ooooo0_l00003ooooo`Ko00002_ooool2
o`0000[ooooo0ol000000ooooooo0000o`00000=ooooo`;o000000?oooooo`000?l000000_l00007
ooooo`;o00000_ooool2o`0001Oooooo0_l0000>ooooo`;o00000oooool2o`0005oooooo000Loooo
o`03o`000?oooooooooo07Cooooo0_l00003ooooo`;o00000_ooool2o`0000[ooooo0_l00006oooo
o`;o000000Coooooo`000?l0003o00001oooool5o`0000;ooooo0_l000000ooooooo0000o`000002
ooooo`;o00001Oooool2o`000003ooooool0003o000000;ooooo0ol00002ooooo`;o00003Oooool4
o`00017ooooo0_l00003ooooo`;o0000Goooool001cooooo00?o0000ooooooooool0J_ooool2o`00
00oooooo0_l0000Cooooo`?o000000?oooooo`000?l000002?ooool5o`0000;ooooo0_l0000<oooo
o`;o00001?ooool4o`0000;ooooo0_l00004ooooo`;o00000_ooool2o`0000?ooooo1?l0000Doooo
o`;o0000HOooool001cooooo00?o0000ooooooooool0J_ooool2o`0000;ooooo0_l00005ooooo`;o
00000oooool3o`0001?ooooo0_l00008ooooo`;o00000_ooool2o`0000gooooo1?l00008ooooo`;o
00001Oooool2o`0000?ooooo1_l00005ooooo`;o00001Oooool2o`0000gooooo0_l0001Qooooo`00
7?ooool00ol0003oooooooooo`1^ooooo`;o00001Oooool2o`0000?ooooo1?l0000Jooooo`Co0000
0_ooool3o`0000cooooo1?l0000?ooooo`;o00001?ooool3o`0000Oooooo0_l00005ooooo`;o0000
3Oooool2o`00067ooooo000Looooo`03o`000?oooooooooo06kooooo0_l000001?oooooo0000o`00
0?ooool3o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`;o00004oooool2o`0000Gooooo
0_l000000ooooooo0000o`00000Qooooo`;o00002Oooool2o`0001Cooooo0_l0001Qooooo`007?oo
ool00ol0003oooooooooo`1Iooooo`;o00004_ooool2o`0000;ooooo1Ol00002ooooo`?o00002?oo
ool2o`0001gooooo0_l00007ooooo`;o00000_ooool2o`0000;ooooo0ol00004ooooo`;o00001?oo
ool2o`0000?ooooo0_l0000=ooooo`Co00007_ooool2o`00057ooooo000Looooo`03o`000?oooooo
oooo05Gooooo0_l00002ooooo`;o00003_ooool6o`000004ooooool0003o0000ooooo`?o00000_oo
ool2o`0000Wooooo0_l00009ooooo`;o00004Oooool2o`0000Gooooo0_l000000ooooooo0000o`00
0002ooooo`;o000000?oooooo`000?l000001?l00002ooooo`;o00001?ooool2o`0000?ooooo0_l0
0009ooooo`;o00000_ooool4o`0001Kooooo0_l00006ooooo`;o0000DOooool001cooooo00?o0000
ooooooooool0EOooool2o`0000kooooo2?l00003ooooo`;o00000_ooool2o`0000Sooooo0_l00003
ooooo`;o00002Oooool2o`00017ooooo0_l00005ooooo`;o00001?ooool2o`0000;ooooo0_l00002
ooooo`;o00000oooool2o`0000?ooooo0_l00003ooooo`;o00002Oooool2o`0001;ooooo0_l00008
ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0H_ooool8o`000003ooooool0003o0000
017ooooo0_l0000^ooooo`;o00000_ooool2o`000003ooooool0003o000000Cooooo0_l00003oooo
o`?o00000_ooool2o`0000Kooooo1_l0000Aooooo`;o00001oooool2o`0005[ooooo000Looooo`;o
0000Hoooool5o`0000Cooooo0ol0000Dooooo`;o00004_ooool2o`0000Sooooo0_l0000@ooooo`;o
000000?oooooo`000?l000001_ooool6o`0000[ooooo1_l0000Aooooo`;o00001oooool2o`000003
ooooool0003o000005Oooooo000Looooo`03o`000?oooooooooo063ooooo0_l00003ooooo`Co0000
0oooool2o`0000Gooooo0_l0000<ooooo`?o00001oooool2o`0000Gooooo1_l00008ooooo`;o0000
4Oooool3o`0000Oooooo0ol00003ooooo`;o00003?ooool2o`0000_ooooo0_l00004ooooo`;o0000
1oooool2o`000003ooooool0003o000005Oooooo000Looooo`03o`000?oooooooooo057ooooo0_l0
000=ooooo`;o00001Oooool3o`0000Sooooo0ol0000<ooooo`;o00001Oooool2o`000003ooooool0
003o000000;o00000oooool4o`0000Wooooo0_l0000Booooo`?o00003Oooool2o`0000;ooooo0_l0
0004ooooo`;o00000_ooool2o`0000Oooooo0_l00002ooooo`;o0000JOooool001cooooo00?o0000
ooooooooool0DOooool2o`0001Gooooo0ol00007ooooo`;o00000_ooool2o`00013ooooo0_l00003
ooooo`;o00002Oooool3o`0000Cooooo0_l0000Aooooo`;o00004oooool2o`0000Cooooo0_l0000;
ooooo`;o00002?ooool2o`0000Kooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`1?oooo
o`;o00006?ooool4o`0000Wooooo0_l0000Fooooo`;o00002?ooool5o`0001Gooooo1?l00002oooo
o`;o00008Oooool2o`0000Oooooo0_l00006ooooo`;o0000Foooool001cooooo00?o0000oooooooo
ool0Coooool2o`0001Wooooo0ol0000Qooooo`;o00001oooool6o`0001Oooooo0_l00002ooooo`;o
00001_ooool2o`0000Wooooo0_l0000>ooooo`;o000000?oooooo`000?l00000JOooool001cooooo
00?o0000ooooooooool0F_ooool2o`0000Wooooo0_l00003ooooo`?o00001?ooool2o`0000gooooo
0_l0000Eooooo`;o00002oooool3o`0001Wooooo0_l00002ooooo`;o00001Oooool2o`0000Wooooo
0_l00002ooooo`;o00000_ooool4o`0006Oooooo000Looooo`03o`000?oooooooooo05[ooooo0_l0
0005ooooo`Ko00002_ooool2o`0000Cooooo0ol00006ooooo`Co000000?oooooo`000?l000007Ooo
ool3o`0001Kooooo0_l00005ooooo`;o00001?ooool3o`0000Wooooo0_l00002ooooo`;o00000ooo
ool3o`0000;ooooo0_l0000;ooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0A_ooool2
o`0001Wooooo1?l00009ooooo`;o00000oooool3o`000004ooooool0003o0000o`0000Sooooo0_l0
00000ooooooo0000o`00000=ooooo`?o00001oooool2o`0001_ooooo1Ol00006ooooo`;o00000_oo
ool5o`000003ooooool0003o000000Kooooo0_l0000:ooooo`;o00002oooool2o`0005Kooooo000L
ooooo`03o`000?oooooooooo04Kooooo0_l0000:ooooo`;o00000_ooool2o`0000gooooo0_l00007
ooooo`;o00000oooool4o`0000kooooo0_l000000ooooooo0000o`000003ooooo`;o00001Oooool3
o`0000Oooooo0_l00004ooooo`;o00005Oooool2o`000004ooooool0003o0000ooooo`;o00000ooo
ool2o`0000Cooooo0ol000000ooooooo0000o`000006ooooo`;o0000Koooool001cooooo00?o0000
ooooooooool0D_ooool2o`0000;ooooo0_l00003ooooo`;o00002?ooool2o`0000gooooo0ol0000>
ooooo`;o000000?oooooo`000?l000000_l000001?oooooo0000o`000?l00006ooooo`Go00002Ooo
ool2o`0000Sooooo0_l0000?ooooo`Co00006?ooool2o`0006cooooo000Looooo`03o`000?oooooo
oooo05Sooooo0_l000000ooooooo0000o`000009ooooo`;o000000?oooooo`000?l000002Oooool3
o`0000[ooooo0_l00007ooooo`?o000000?oooooo`000?l000001_ooool5o`0000Gooooo0_l00003
ooooo`;o00001?ooool2o`000004ooooool0003o0000o`0000_ooooo0_l000000ooooooo0000o`00
0009ooooo`;o00003oooool2o`0000oooooo0_l000000ooooooo0000o`00001Hooooo`007?ooool0
0ol0003oooooooooo`1Cooooo`;o00000oooool2o`0000_ooooo1_l0000?ooooo`;o00000oooool4
o`0000?ooooo1ol00002ooooo`;o00003oooool2o`000003ooooool0003o000000So00000_ooool4
o`0000Wooooo0_l0000<ooooo`;o00001Oooool2o`0001Wooooo0_l000000ooooooo0000o`000002
o`0005Kooooo000Looooo`03o`000?oooooooooo05?ooooo0_l00005ooooo`;o00002Oooool5o`00
013ooooo0_l00003ooooo`;o00001Oooool6o`0000;ooooo0ol0000Aooooo`?o00000_ooool5o`00
0003ooooool0003o000000Co00004Oooool2o`0000Kooooo0ol000001?oooooo0000o`000?l0000>
ooooo`;o00001?ooool2o`0000Kooooo1?l0001Fooooo`007?ooool00ol0003oooooooooo`0ooooo
o`;o00000oooool2o`0001Cooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o0000
00;ooooo0_l00004ooooo`;o00003Oooool3o`0000Sooooo0_l00002ooooo`;o00004_ooool2o`00
00?ooooo0_l000000ooooooo0000o`000005o`0001?ooooo0_l00006ooooo`?o000000?oooooo`00
0?l000001_ooool2o`0000Kooooo0ol00004ooooo`;o00004?ooool2o`0004kooooo000Looooo`03
o`000?oooooooooo03oooooo0_l00003ooooo`;o00006?ooool2o`0000?ooooo0_l00002ooooo`;o
000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000Gooooo0_l00002ooooo`Co
00002Oooool2o`000003ooooool0003o000000Kooooo0_l000000ooooooo0000o`000007oooooa;o
00004?ooool2o`0001;ooooo0_l00006ooooo`Co00003?ooool2o`0000Oooooo1?l0001<ooooo`00
7?ooool2o`0005Oooooo0_l0000?ooooo`;o00002_ooool2o`0000Gooooo0ol000001?oooooo0000
o`000?l00002ooooo`;o00001Oooool3o`000004ooooool0003o0000o`0000Gooooo0_l000000ooo
oooo0000o`000007oooooa;o0000;?ooool4o`0000[ooooo1?l00009ooooo`;o0000C?ooool001co
oooo00?o0000ooooooooool0C_ooool2o`0000Cooooo1?l00005ooooo`Co000000?oooooo`000?l0
00000oooool2o`0001;ooooo0_l00002ooooo`;o00000_ooool2o`0000Gooooo0_l00002ooooo`Oo
00003_oooolBo`0000;ooooo0_l0000?ooooo`;o00005_ooool4o`0000Kooooo0_l00002ooooo`;o
00000oooool2o`0005Cooooo000Looooo`03o`000?oooooooooo04kooooo0_l00004ooooo`;o0000
0_ooool2o`0000?ooooo1?l000000ooooooo0000o`000003ooooo`;o00009Oooool7o`000003oooo
ool0003o000000?ooooo0_l00006oooooa?o000000?oooooo`000?l000003oooool2o`0001?ooooo
0_l0000;ooooo`;o00001oooool2o`0005Cooooo000Looooo`03o`000?oooooooooo04kooooo0_l0
0003ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`;o00001Oooool4o`000004oooo
ool0003o0000o`0000cooooo0_l0000Gooooo`?o000000?oooooo`000?l000000oooool3o`000003
ooooool0003o000001Ko00004_ooool2o`0001;ooooo0_l000000ooooooo0000o`000002o`000003
ooooool0003o000001;ooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`1Aooooo`Co0000
1_ooool2o`0000Sooooo1?l000001?oooooo0000o`000?l00004ooooo`?o00001Oooool4o`0000Go
oooo0_l0000>ooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`00000Fo`0000Oo
oooo0_l00009ooooo`Co00004oooool4o`000003ooooool0003o000001;ooooo0_l0001>ooooo`00
7?ooool00ol0003oooooooooo`1Aooooo`;o00005_ooool4o`000004ooooool0003o0000ooooo`?o
00001oooool2o`0000Gooooo0_l0000;ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`00
00[ooooo5_l00005ooooo`?o00002Oooool4o`0000_ooooo0_l00009ooooo`;o0000I?ooool001co
oooo00?o0000ooooooooool0B?ooool2o`0000[ooooo0_l0000Cooooo`;o000000?oooooo`000?l0
00001Ol0000?ooooo`;o00002Oooool4o`000003ooooool0003o000000Co00001ooooolJo`000004
ooooool0003o0000ooooo`?o00001Oooool2o`0000;ooooo0_l0000<ooooo`?o00002Oooool2o`00
06Cooooo000Looooo`03o`000?oooooooooo03Kooooo0_l0000@ooooo`;o00002?ooool6o`0000Co
oooo0_l00004ooooo`;o00002?ooool2o`000003ooooool0003o000000;o00002_ooool2o`0000?o
oooo0_l00004ooooo`;o00000oooool2o`0000?ooooo1?l00009oooooa[o000000?oooooo`000?l0
00000_ooool4o`0000?ooooo0ol0000?ooooo`;o000000?oooooo`000?l000002_ooool2o`0000co
oooo0_l00003ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0=_ooool2o`0000Oooooo
0_l0000=ooooo`;o00000_ooool2o`0000;ooooo0_l00004ooooo`;o00001?ooool4o`0000_ooooo
0_l0000:ooooo`;o000000?oooooo`000?l000001Oooool3o`000003ooooool0003o000000Cooooo
1?l0000:oooooaSo000000?oooooo`000?l000001_ooool2o`0000Cooooo0_l0000>ooooo`;o0000
0_ooool2o`0000[ooooo0_l00007ooooo`;o00000oooool2o`0000?ooooo1?l0001<ooooo`007?oo
ool00ol0003oooooooooo`0oooooo`;o00003Oooool3o`0000Kooooo0_l00009ooooo`Ko00002Ooo
ool2o`0000gooooo0_l000000ooooooo0000o`000004o`0000;ooooo0_l00004ooooo`Co00002?oo
oolMo`000003ooooool0003o000000Gooooo0_l00002ooooo`?o00003Oooool2o`0000cooooo0_l0
0009ooooo`;o00002Oooool3o`0004cooooo000Looooo`03o`000?oooooooooo04gooooo1?l00006
ooooo`;o00002Oooool2o`0000;ooooo0_l0000Kooooo`Co00002?ooool3o`000004ooooool0003o
0000o`0000Oooooo4_l000000ooooooo0000o`000007o`0000;ooooo0_l00005ooooo`;o00000_oo
ool3o`0001Gooooo0_l00004ooooo`;o0000Hoooool001cooooo00?o0000ooooooooool0??ooool2
o`0000Sooooo0_l00003ooooo`Co00004?ooool5o`0002_ooooo1ol00007oooooaco00000_ooool2
o`0000Kooooo0_l0000Iooooo`;o00002oooool2o`0000Cooooo0_l0001Fooooo`007?ooool00ol0
003oooooooooo`0looooo`;o00002?ooool2o`0000?ooooo1?l00005ooooo`;o00002Oooool3o`00
01oooooo0_l00002ooooo`;o00002?ooool5o`0000Wooooo7?l0000:ooooo`;o00000oooool2o`00
00gooooo0_l0000Booooo`;o00001?ooool2o`0005Kooooo000Looooo`03o`000?oooooooooo03ko
oooo0_l0000;ooooo`;o00001oooool2o`0002_ooooo0_l00002ooooo`;o00001?ooool3o`000004
ooooool0003o0000o`0000Wooooo4ol000000ooooooo0000o`000007o`0000Kooooo0_l00002oooo
o`So00003Oooool5o`0001Gooooo0_l00004ooooo`;o0000D?ooool001cooooo00?o0000oooooooo
ool0?_ooool2o`0000_ooooo0_l0000;ooooo`Co00002_ooool2o`0000Kooooo0_l0000Kooooo`?o
00003OoooolMo`0000Cooooo1?l000000ooooooo0000o`000006o`0000_ooooo0_l000000ooooooo
0000o`000003o`0000_ooooo0_l00006ooooo`Co00001?ooool2o`00053ooooo000Looooo`03o`00
0?oooooooooo03Wooooo0_l0000@ooooo`;o00002oooool4o`0000Sooooo1?l00006ooooo`;o0000
7oooool6o`0000Kooooo0_l00002oooooaCo000000?oooooo`000?l000000_l00004ooooo`;o0000
0oooool2o`0000Kooooo0_l00002ooooo`;o00001?ooool3o`00017ooooo0_l00006ooooo`;o0000
F?ooool001cooooo0_l0000jooooo`;o00002_ooool2o`0001gooooo0_l000000ooooooo0000o`00
0005ooooo`;o00001oooool2o`0000oooooo0_l00005ooooo`Ko00002Oooool3o`000003ooooool0
003o000001;o00000_ooool2o`0000Oooooo0_l00005ooooo`?o00000_ooool2o`0000Cooooo0_l0
00000ooooooo0000o`000006ooooo`;o00007?ooool2o`0004_ooooo000Looooo`03o`000?oooooo
oooo04Gooooo0_l00002ooooo`;o00004?ooool2o`0000[ooooo0_l0000>ooooo`;o00003?ooool5
o`0000Gooooo0ol00009oooooa_o00000_ooool2o`0000kooooo0_l00005ooooo`;o00001Oooool2
o`0000Cooooo1Ol0000Booooo`;o00001_ooool3o`0004_ooooo000Looooo`03o`000?oooooooooo
03[ooooo0_l00003ooooo`;o00001?ooool2o`0000;ooooo0_l0000?ooooo`?o00004_ooool2o`00
01Cooooo1?l000000ooooooo0000o`000003ooooo`?o00002Oooool3o`0000;ooooo5_l00005oooo
o`Co00003Oooool2o`000004ooooool0003o0000ooooo`;o000000Coooooo`000?l0003o00001?oo
ool2o`000003ooooool0003o000000oooooo0_l000000ooooooo0000o`000006ooooo`?o0000Booo
ool001cooooo00?o0000ooooooooool0>_ooool2o`0000?ooooo0_l00003ooooo`?o00004_ooool3
o`0001?ooooo0_l00003ooooo`;o00005?ooool2o`0000?ooooo1Ol00007ooooo`;o000000?ooooo
o`000?l000000_oooolDo`0000;ooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l00008
ooooo`;o00001?ooool5o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`0000Cooooo0_l00000
0ooooooo0000o`000005ooooo`;o00000oooool2o`000003ooooool0003o000004Sooooo000Loooo
o`03o`000?oooooooooo03gooooo0_l00005ooooo`?o00004_ooool3o`0000;ooooo0_l000000ooo
oooo0000o`00000Aooooo`;o00001?ooool2o`0000gooooo1?l00003ooooo`Co00001oooool2o`00
0003ooooool0003o000000?ooooo0_l00002ooooo`ko00000oooool2o`0000;ooooo1?l00002oooo
o`;o00002?ooool2o`0000Gooooo0_l00006ooooo`;o00001?ooool2o`0000Cooooo0_l00004oooo
o`;o00002?ooool2o`000004ooooool0003o0000o`0000;ooooo0_l000000ooooooo0000o`000002
o`0004?ooooo000Looooo`03o`000?oooooooooo03gooooo0_l0000Oooooo`;o000000?oooooo`00
0?l000000_ooool3o`0000;ooooo0_l00009ooooo`;o00000oooool2o`0000;ooooo0_l00002oooo
o`;o00001?ooool5o`0000;ooooo1Ol00007ooooo`;o00002Oooool4o`000003ooooool0003o0000
00So00002Oooool2o`0000cooooo0_l00003ooooo`Co00003Oooool3o`0000gooooo0_l00003oooo
o`;o000000Coooooo`000?l0003o00001Oooool6o`0000_ooooo0_l0000dooooo`007?ooool00ol0
003oooooooooo`12ooooo`;o00001?ooool2o`0001Gooooo0_l00004ooooo`?o00000_ooool2o`00
00Wooooo0_l00007ooooo`;o00000_ooool2o`0000Cooooo1Ol000000ooooooo0000o`000004o`00
013ooooo1_l000000ooooooo0000o`000003o`000003ooooool0003o000000Co00002?ooool2o`00
00Oooooo0_l00007ooooo`;o00001Oooool2o`0000;ooooo0_l00004ooooo`?o00003Oooool2o`00
00cooooo0_l00004ooooo`;o00002oooool2o`0003Cooooo000Looooo`03o`000?oooooooooo03ko
oooo0_l00002ooooo`;o00001?ooool2o`0001Gooooo0_l0000Cooooo`;o000000?oooooo`000?l0
00004?ooool2o`0000;ooooo1_l0000>ooooo`;o000000Coooooo`000?l0003o00000_ooool4o`00
0003ooooool0003o000000Cooooo0ol00008ooooo`;o00001oooool2o`0000;ooooo0_l000000ooo
oooo0000o`000002o`0000Gooooo0_l00002ooooo`;o00002?ooool2o`0000_ooooo0_l0000;oooo
o`;o00004Oooool2o`0003Cooooo000Looooo`03o`000?oooooooooo03kooooo0_l00003ooooo`;o
00004Oooool2o`0001cooooo0_l000000ooooooo0000o`00000?ooooo`Co000000?oooooo`000?l0
00001?l0000>ooooo`;o00001_ooool2o`0000cooooo0ol00002ooooo`;o00002_ooool2o`0000;o
oooo0_l000000ooooooo0000o`00000=ooooo`;o00001?ooool4o`0000_ooooo0_l00003ooooo`?o
00001Oooool2o`00017ooooo0_l0000dooooo`007?ooool00ol0003oooooooooo`13ooooo`;o0000
4Oooool2o`00033ooooo2_l0000Dooooo`;o00002Oooool2o`0000Cooooo0ol00002ooooo`;o0000
2_ooool2o`00017ooooo0_l000000ooooooo0000o`000004ooooo`;o00002oooool2o`0000Gooooo
0ol00003ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0E_ooool4o`000003ooooool0
003o000000Cooooo0_l0000Aooooo`;o00000oooool2o`0000?ooooo0_l00002ooooo`;o00001?oo
ool:o`0000Gooooo0_l0000:ooooo`;o000000?oooooo`000?l000002Oooool2o`0000gooooo1?l0
0008ooooo`;o00001_ooool2o`0000Gooooo0_l0000Dooooo`;o00001oooool2o`0000;ooooo0_l0
0003ooooo`Co00003Oooool2o`0003?ooooo000Looooo`03o`000?oooooooooo05Kooooo1?l00000
0ooooooo0000o`000004ooooo`;o00001?ooool2o`000003ooooool0003o000000Sooooo0_l00003
ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`[o00001_ooool2o`0000Wooooo0ol0000K
ooooo`Co00002?ooool2o`000004ooooool0003o0000o`0000;ooooo0_l00006ooooo`;o00002Ooo
ool2o`0000_ooooo0_l00003ooooo`?o00001oooool4o`0000gooooo0_l0000cooooo`007?ooool0
0ol0003oooooooooo`1=ooooo`Co00000_ooool2o`0000?ooooo0_l0000=ooooo`;o000000?ooooo
o`000?l000001Oooool2o`0000[ooooo0_l00006ooooo`co000000Coooooo`000?l0003ooooo0_l0
0009ooooo`Co00009Oooool2o`0000Cooooo0ol00002ooooo`;o000000?oooooo`000?l000000ooo
ool2o`0000Wooooo0_l0000;ooooo`Oo00002_ooool2o`0004;ooooo000Looooo`03o`000?oooooo
oooo03Cooooo0_l00006ooooo`;o00000_ooool2o`0000Sooooo0_l000000ooooooo0000o`000006
o`0001cooooo0_l0000:ooooo`;o00000oooool8o`000003ooooool0003o000000?o00000_ooool2
o`000003ooooool0003o000000Wooooo1?l000000ooooooo0000o`00000Mooooo`;o00000oooool2
o`0000_ooooo0ol0000Fooooo`Co00000oooool4o`0000?ooooo0_l0001:ooooo`0000Koooooonk^
k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool0=?ooool2o`0000Kooooo0_l00002ooooo`;o00002?ooool2o`0000Cooooo1Ol0
000Tooooo`;o00000_ooool3o`000003ooooool0003o000000co00003oooool2o`0000Cooooo0ol0
0003ooooo`Go00003oooool2o`0000;ooooo1ol0000=ooooo`;o000000?oooooo`000?l000003_oo
ool2o`0000Cooooo1?l0000:ooooo`;o0000B_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0`ooooo`;o0000
3Oooool4o`0000Oooooo0_l00004ooooo`;o000000?oooooo`000?l000003_ooool2o`0000Oooooo
0_l00007ooooo`;o000000Coooooo`000?l0003o00000_oooolAo`0000_ooooo0_l00003ooooo`;o
00001?ooool2o`0000Cooooo1_l00002ooooo`;o00002_ooool2o`0000;ooooo0_l000000ooooooo
0000o`000002o`0000_ooooo0_l00003ooooo`;o00000oooool2o`0000Cooooo0_l00003ooooo`;o
00006Oooool2o`0004?ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo
1Ol00006ooooo`03o`000?oooooooooo033ooooo0_l00005ooooo`?o00000oooool6o`0000Gooooo
0_l00003ooooo`;o000000?oooooo`000?l000000_l0000<ooooo`;o000000?oooooo`000?l00000
1Oooool5o`0000?ooooo1Ol000001?oooooo0000o`000?l00002oooooa7o00001Oooool2o`0000?o
oooo0ol000000ooooooo0000o`000007ooooo`;o00000oooool2o`0000;ooooo0_l000001?oooooo
0000o`000?l0000>ooooo`;o00004?ooool2o`0000?ooooo0_l00003ooooo`;o00001?ooool2o`00
00Kooooo0_l0000Fooooo`;o00000_ooool2o`0003oooooo00000ooooooo0000ooooo`02ooooo`03
o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`0003Oooooo0ol00003oooo
o`;o00001_ooool2o`000003ooooool0003o000000?ooooo0_l00003ooooo`;o00003?ooool3o`00
00Oooooo0_l000000ooooooo0000o`000003ooooo`Ko000000?oooooo`000?l000001?l000000ooo
oooo0000o`00000;o`0000Kooooo0_l00003ooooo`;o00000_ooool2o`0000Oooooo0_l00006oooo
o`;o00000_ooool2o`0000oooooo0_l000000ooooooo0000o`00000Booooo`;o00001_ooool2o`00
00?ooooo0_l00004ooooo`;o00002oooool2o`0000Kooooo0_l00005ooooo`;o0000?oooool00003
ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?oMgMgoEEEEooooool00007oooo
o`03o`000?oooooooooo04;ooooo0_l000000ooooooo0000o`000006ooooo`;o00000_ooool3o`00
00cooooo0ol0000;oooooako00004Oooool2o`0000kooooo0_l0000?ooooo`;o00001Oooool2o`00
00gooooo0_l00003ooooo`;o00001_ooool2o`0000?ooooo0_l000001?oooooo0000o`000?l0000=
ooooo`;o00001_ooool2o`0004Kooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo
00[ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0aooooo`;o00000_ooool2o`00
00[ooooo0ol00009ooooo`Oo00003?ooool3o`0000Sooooo8Ol0000Aooooo`;o00001Oooool2o`00
01Cooooo0_l00002ooooo`Go000000?oooooo`000?l000003_ooool2o`0000?ooooo0_l0000>oooo
o`?o00004?ooool2o`0004_ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^
odA4A?l000001oooool00ol0003oooooooooo`0aooooo`;o00000_ooool2o`0000Gooooo0_l00003
ooooo`;o00000oooool2o`0000Oooooo0_l0000@ooooo`;o00001ooooolAo`000003ooooool0003o
000000ko00001oooool2o`0000oooooo0_l0000>ooooo`;o00001?ooool9o`000003ooooool0003o
000001;ooooo0_l0000?ooooo`;o00001oooool2o`0000;ooooo1?l00002ooooo`;o00002oooool2
o`0003kooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_oo
ool00ol0003oooooooooo`0looooo`;o000000?oooooo`000?l000000_l00003ooooo`Ko00000ooo
ool2o`0001Sooooo7ol00003ooooo`;o00001_ooool2o`0000Gooooo0_l000000ooooooo0000o`00
000:ooooo`;o00001_ooool2o`000003ooooool0003o000000Cooooo1_l000001?oooooo0000o`00
0?ooool2o`0000gooooo0_l00003ooooo`;o00003oooool2o`0000Oooooo0_l00002ooooo`Co0000
3_ooool3o`0003kooooo000Looooo`03o`000?oooooooooo03Wooooo0_l000001?oooooo0000o`00
0?ooool2o`0000Cooooo0_l000000ooooooo0000o`000004o`000003ooooool0003o000000cooooo
0_l000000ooooooo0000o`000005ooooo`Co000000?oooooo`000?l000000_l000000ooooooo0000
o`00000Eo`0000?ooooo0_l0000=ooooo`;o000000?oooooo`000?l000001?l00005ooooo`Go0000
1?ooool2o`0000Oooooo0_l00008ooooo`;o00003Oooool2o`00027ooooo0_l0000=ooooo`;o0000
00?oooooo`000?l00000?oooool001cooooo00?o0000ooooooooool0>Oooool2o`0000Cooooo0_l0
0004ooooo`;o00001Oooool2o`0000cooooo0_l000000ooooooo0000o`000003o`0000Gooooo2Ol0
00000ooooooo0000o`00000Eo`0000Oooooo0_l0000>ooooo`Co00001Oooool2o`000004ooooool0
003o0000ooooo`;o00005oooool2o`0000?ooooo0_l00008ooooo`;o00005_ooool2o`0000Kooooo
0_l0000=ooooo`;o000000?oooooo`000?l00000?oooool001cooooo00?o0000ooooooooool0>Ooo
ool2o`0000Cooooo0_l0000Iooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo8_l0
0007ooooo`;o00001oooool2o`0000Sooooo0_l00007ooooo`;o000000?oooooo`000?l000005ooo
ool2o`0000?ooooo0_l00004ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`00
0005ooooo`;o000000?oooooo`000?l000001Oooool3o`0000;ooooo0_l0001Dooooo`007?ooool0
0ol0003oooooooooo`0iooooo`;o000000?oooooo`000?l000001oooool2o`0001;ooooo0_l00007
ooooo`Oo000000?oooooo`000?l000007?l0000@ooooo`;o00002?ooool2o`0000[ooooo0_l00003
ooooo`;o00000_ooool6o`0000Kooooo0_l000000ooooooo0000o`00000:ooooo`?o00001Oooool8
o`0000;ooooo0_l000001?oooooo0000o`000?l00004ooooo`?o00000_ooool2o`0000;ooooo0_l0
001@ooooo`007?ooool00ol0003oooooooooo`0looooo`;o00001oooool2o`0000oooooo0_l00000
1?oooooo0000o`000?ooool2o`0000Gooooo8_l0000@ooooo`;o00002Oooool2o`0000Wooooo0_l0
00000ooooooo0000o`000005o`000003ooooool0003o000000Go00001_ooool7o`0000?ooooo0_l0
0003ooooo`?o00000_ooool2o`000003ooooool0003o000000Ko00001_ooool2o`0000Cooooo0_l0
0005ooooo`Co00002Oooool2o`000003ooooool0003o000004;ooooo000Looooo`03o`000?oooooo
oooo03Wooooo0_l0000:ooooo`;o00001?ooool2o`0000Sooooo0ol00004ooooo`;o00001?oooolQ
o`00013ooooo1_l00007ooooo`;o00002Oooool4o`000003ooooool0003o000000So00002_ooool2
o`0000;ooooo0ol000001?oooooo0000o`000?l00004ooooo`Oo00000_ooool9o`00013ooooo0_l0
000;ooooo`;o000000?oooooo`000?l00000@_ooool001cooooo00?o0000ooooooooool0>Oooool2
o`0000Gooooo0_l000000ooooooo0000o`000004ooooo`Co00002?ooool2o`0000_ooooo8?l0000:
ooooo`;o00001?ooool3o`0000;ooooo1?l0000@ooooo`Co00000_ooool5o`0000gooooo0_l00002
ooooo`Co000000?oooooo`000?l000001Ol00002ooooo`Go000000Goooooo`000?l0003o0000oooo
o`06o`000003ooooool0003o000000Cooooo0_l00004ooooo`Co00002_ooool2o`0000;ooooo0_l0
00000ooooooo0000o`000010ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o000000?ooooo
o`000?l000001?ooool2o`0001Gooooo1?l000000ooooooo0000o`00000Jo`0000_ooooo0_l00004
ooooo`;o00001Oooool2o`00013ooooo0_l00002ooooo`Go00000_ooool2o`0000_ooooo0_l00000
0ooooooo0000o`000002o`0000?ooooo1_l000000ooooooo0000o`000009o`0000Oooooo0_l00003
ooooo`?o00001?ooool4o`0000[ooooo0_l00002ooooo`;o000000?oooooo`000?l000001Oooool3
o`0003Sooooo000Looooo`03o`000?oooooooooo04Wooooo0_l00004ooooo`;o00003ooooolBo`00
0003ooooool0003o000000_o00001oooool2o`000004ooooool0003o0000o`0000Oooooo0_l0000@
ooooo`;o00001Oooool4o`000003ooooool0003o000000;ooooo0_l0000>ooooo`Co00000oooool?
o`000003ooooool0003o000000;o000000?oooooo`000?l000001oooool2o`0000oooooo0_l00002
ooooo`;o00001oooool2o`0000?ooooo0ol0000hooooo`007?ooool00ol0003oooooooooo`0hoooo
o`Co00004oooool2o`0000?ooooo0_l0000;oooooago00000oooool4o`0000;ooooo0_l000000ooo
oooo0000o`000003o`0000?ooooo1?l00007ooooo`;o00001oooool2o`0000Gooooo0_l00007oooo
o`;o000000?oooooo`000?l000004?ooool2o`000003ooooool0003o000001Co000000?oooooo`00
0?l000005Oooool2o`0000_ooooo0_l0000Aooooo`;o0000:oooool001cooooo00?o0000oooooooo
ool0=Oooool2o`000003ooooool0003o000000;o00005_ooool6o`0000Kooooo7_l00002ooooo`;o
000000?oooooo`000?l000000_l00008ooooo`;o00000_ooool3o`0000Wooooo0_l0000Gooooo`Ko
00003ooooolHo`0000;ooooo0_l0000Oooooo`;o00005?ooool2o`0002_ooooo000Looooo`;o0000
=_ooool2o`000003ooooool0003o000000Cooooo0_l0000<ooooo`;o00001?ooool2o`0000;ooooo
0_l00006oooooa[o00001_ooool2o`00017ooooo0ol00006ooooo`;o00002?ooool2o`000003oooo
ool0003o000000[ooooo0_l00002ooooo`;o000000?oooooo`000?l000002_ooool2o`0000;ooooo
6_l00003ooooo`Co00002Oooool2o`0000?ooooo0_l0000;ooooo`;o0000@Oooool001cooooo00?o
0000ooooooooool0>?ooool2o`0000Cooooo0ol00002ooooo`;o000000?oooooo`000?l000001?oo
ool2o`0000Kooooo0_l00003ooooo`;o00001?oooolHo`0000Oooooo0_l00002ooooo`;o00001Ooo
ool2o`0000Gooooo1_l00004ooooo`;o00002?ooool2o`000003ooooool0003o000000;o00002?oo
ool2o`000003ooooool0003o000000kooooo1_l000000ooooooo0000o`00000Eo`0000?ooooo1?l0
0009ooooo`;o00000oooool3o`0001;ooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`0o
ooooo`;o00000_ooool5o`0000cooooo0_l00003ooooo`;o00000ooooolGo`0000Gooooo1_l00002
ooooo`;o00001Oooool3o`0000Cooooo0_l00002ooooo`;o00001?ooool2o`0000gooooo0_l00008
ooooo`;o000000?oooooo`000?l000000_l00009ooooo`;o000000?oooooo`000?l000007?l00000
0ooooooo0000o`00000Cooooo`;o00003_ooool2o`0000;ooooo0_l0000iooooo`007?ooool00ol0
003oooooooooo`0`ooooo`;o00004?ooool6o`0001Kooooo1ol000000ooooooo0000o`00000<o`00
00Kooooo2?l00008ooooo`;o00000_ooool2o`0000Oooooo0_l0000@ooooo`;o00001oooool2o`00
00?ooooo1Ol00007ooooo`;o000000?oooooo`000?l000007?l000000ooooooo0000o`00000Ioooo
o`;o00002?ooool2o`0003gooooo000Looooo`03o`000?oooooooooo033ooooo0_l00004ooooo`;o
00001oooool2o`000003ooooool0003o000001[ooooo5?l000000ooooooo0000o`00000:ooooo`?o
00003?ooool2o`0000Oooooo0_l0000@ooooo`;o00001oooool3o`0000;ooooo0_l000000ooooooo
0000o`000002o`0000;ooooo0ol00003ooooo`;o00000_oooolKo`000003ooooool0003o000001?o
oooo0ol00002ooooo`;o00002?ooool2o`00017ooooo0_l0000Zooooo`007?ooool00ol0003ooooo
ooooo`0Oooooo`;o00005Oooool2o`0000Oooooo0_l0000@ooooo`;o00003?oooolAo`0000?ooooo
0_l0000>ooooo`;o00001_ooool2o`0001Gooooo0_l00004ooooo`;o00001Oooool6o`0000;ooooo
0_l00003ooooo`;o00000_ooool3o`000003ooooool0003o000000;o000000?oooooo`000?l00000
1Ol000000ooooooo0000o`00000Bo`000003ooooool0003o000000[ooooo0_l00007ooooo`?o0000
1?ooool2o`0000Kooooo0ol0000@ooooo`;o0000:_ooool001cooooo00?o0000ooooooooool07ooo
ool2o`0002Kooooo0_l00006ooooo`Co00001_ooool2o`0000;ooooo0ol00002ooooo`[o00005ooo
ool2o`0000Kooooo0_l0000Cooooo`Co00001?ooool2o`0000Cooooo1Ol00004ooooo`;o00002Ooo
ool>o`000003ooooool0003o0000013o000000?oooooo`000?l000000_l0000:ooooo`;o00003_oo
ool2o`0000Kooooo0ol0000looooo`007?ooool00ol0003oooooooooo`0aooooo`;o00005?ooool2
o`0000Kooooo0_l00008ooooo`;o00000_ooool3o`0000;ooooo2Ol0000Dooooo`;o00007oooool2
o`0000_ooooo0ol000000ooooooo0000o`000004ooooo`;o00000oooool2o`0000Cooooo8Ol00000
0ooooooo0000o`000002o`0002;ooooo0_l0000;ooooo`;o00001oooool2o`0002Oooooo000Loooo
o`03o`000?oooooooooo037ooooo0_l0000Wooooo`;o000000Coooooo`000?l0003o00000_ooool4
o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000004?ooool2o`0001Sooooo0_l0
000Booooo`;o00000_ooool2o`0000Cooooo2?l000000ooooooo0000o`000007o`000003ooooool0
003o000001;o000000?oooooo`000?l000001?l000000ooooooo0000o`00000Pooooo`?o00003?oo
ool2o`0000Oooooo0_l0000Wooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00004oooool2
o`0001Oooooo0_l00002ooooo`Oo00000_ooool2o`000004ooooool0003o0000ooooo`;o000000?o
ooooo`000?l000009oooool2o`0000Cooooo0_l00009ooooo`;o00001_ooool4o`0000;ooooo1ol0
00000ooooooo0000o`000003oooooa;o000000?oooooo`000?l000002ol000000ooooooo0000o`00
0008ooooo`;o00005_ooool3o`000003ooooool0003o000000oooooo0_l0000Zooooo`007?ooool0
0ol0003oooooooooo`0/ooooo`;o00004?ooool2o`000003ooooool0003o000000;ooooo0_l00004
ooooo`;o00004Oooool6o`0000cooooo0_l00005ooooo`;o00003_ooool2o`0001Kooooo0_l00009
ooooo`Co00001?ooool4o`0000;ooooo0ol0000:ooooo`;o000000?oooooo`000?l000006ol00000
1?oooooo0000o`000?l00007ooooo`;o00006?ooool4o`0000oooooo0_l0000Zooooo`007?ooool0
0ol0003oooooooooo`0[ooooo`;o000000?oooooo`000?l000003?ooool4o`0000Gooooo0ol00003
ooooo`;o00004Oooool3o`00013ooooo0ol00003ooooo`;o00000_ooool2o`0000[ooooo0_l0000E
ooooo`;o00001_ooool3o`0000?ooooo0_l0000;ooooo`;o00002ooooolSo`0000;ooooo0ol0000B
ooooo`;o00002?ooool4o`0003_ooooo000Looooo`03o`000?oooooooooo023ooooo0_l00009oooo
o`Go00003?ooool2o`0000Sooooo0_l00003ooooo`;o00002Oooool2o`0000Kooooo0_l0000Aoooo
o`?o00001oooool2o`00027ooooo0ol00005ooooo`?o00005?ooool2o`000004ooooool0003o0000
ooooo`oo000000?oooooo`000?l000001?l000000ooooooo0000o`00000=o`0000;ooooo0ol0000:
ooooo`;o00001_ooool2o`0000?ooooo1?l00003ooooo`;o000000?oooooo`000?l000002_ooool2
o`0002cooooo000Looooo`03o`000?oooooooooo023ooooo0_l0000;ooooo`;o00001Oooool2o`00
013ooooo0_l00003ooooo`;o00002Oooool2o`00017ooooo0_l0000Yooooo`Co00001Oooool4o`00
01Wooooo0_l000001?oooooo0000o`000?ooool2o`000004ooooool0003o0000o`0000;ooooo8?l0
000;ooooo`;o00000oooool2o`0000Sooooo1ol00002ooooo`?o000000?oooooo`000?l000002_oo
ool2o`0002cooooo000Looooo`03o`000?oooooooooo03Cooooo0_l0000<ooooo`;o00002Oooool2
o`0000kooooo1?l00005ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`0000Oooooo0_l0
000Fooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o000000?oooooo`000?l000000_l0
000>ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`?o00003?oooolHo`0000;ooooo
1_l0000:ooooo`Go000000?oooooo`000?l000002?ooool3o`0000Kooooo0ol0000kooooo`007?oo
ool00ol0003oooooooooo`0Xooooo`;o00006?ooool2o`0000Wooooo0_l0000>ooooo`Co00001Ooo
ool2o`0000;ooooo0_l00004ooooo`;o00001oooool2o`0000gooooo0_l00007ooooo`;o00001ooo
ool2o`0000?ooooo1Ol00009ooooo`Co00000_ooool2o`000004ooooool0003o0000ooooo`?o0000
0oooool2o`0000Oooooo4?l000000ooooooo0000o`000004o`0000Kooooo0_l0000;ooooo`;o0000
00?oooooo`000?l00000D_ooool001cooooo0_l0000Yooooo`;o00008?ooool2o`00013ooooo0_l0
0007ooooo`;o00002oooool2o`0001Cooooo0_l00003ooooo`;o00001?ooool2o`0000[ooooo1_l0
0008ooooo`;o00002oooool2o`0000?ooooo0ol00007oooooaSo00006Oooool2o`0000gooooo0_l0
000nooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o00003oooool3o`0000Oooooo0_l0000;
ooooo`;o00000oooool2o`0001Cooooo0_l00004ooooo`;o00002_ooool2o`0000;ooooo0_l00000
0ooooooo0000o`000006ooooo`;o000000?oooooo`000?l000003Oooool2o`0000;ooooo0_l00004
oooooaOo00004Oooool2o`0000Kooooo0_l0000=ooooo`;o00000oooool2o`0000_ooooo0_l0000/
ooooo`007?ooool00ol0003oooooooooo`0jooooo`Co00007Oooool2o`0001Gooooo0_l00003oooo
o`;o00001oooool2o`0000_ooooo0_l0000Gooooo`;o00001_ooool2o`000003ooooool0003o0000
017ooooo1?l00002ooooo`So00000_ooool3o`000003ooooool0003o000000Go00002oooool2o`00
00Kooooo1?l00004ooooo`Co00001oooool2o`0000Oooooo0_l0000;ooooo`;o00000_ooool2o`00
02Sooooo000Looooo`03o`000?oooooooooo03[ooooo1?l0000Jooooo`;o00009_ooool2o`0000_o
oooo0_l0000:ooooo`?o00004_ooool2o`0000_ooooo0_l00009ooooo`;o00000oooool2o`000003
ooooool0003o000000;ooooo1?l00002ooooo`Ko00002?ooool2o`0000;ooooo0_l00008ooooo`;o
00001_ooool2o`0000Oooooo0ol0000Gooooo`;o0000:?ooool001cooooo00?o0000ooooooooool0
;oooool2o`0000Wooooo0_l0000?ooooo`;o00001?ooool2o`0000Gooooo0_l0000Xooooo`;o0000
2?ooool2o`0000_ooooo0ol0000=ooooo`;o00000oooool2o`0000Cooooo0_l00005ooooo`;o0000
3?ooool7o`0000;ooooo2ol00009ooooo`;o00005?ooool3o`0000Oooooo0_l00011ooooo`007?oo
ool00ol0003oooooooooo`0_ooooo`;o00002Oooool2o`0000oooooo0_l00004ooooo`;o0000;ooo
ool2o`0000Gooooo0_l000000ooooooo0000o`00000Eooooo`;o00001?ooool2o`0000Wooooo0_l0
000?ooooo`?o000000?oooooo`000?l000001?l000001?oooooo0000o`000?ooool5o`000003oooo
ool0003o000000;o00000_ooool2o`0000?ooooo0_l0000Cooooo`;o00000_ooool2o`0000Gooooo
1?l00011ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00006_ooool2o`0003Oooooo0_l0
0002ooooo`?o00001_ooool2o`00013ooooo0_l00004ooooo`;o00003_ooool2o`0000;ooooo0_l0
00000ooooooo0000o`000003ooooo`?o00002?ooool2o`000003ooooool0003o000000;o00000_oo
ool4o`0000;ooooo0ol00002ooooo`;o00001Oooool2o`0000Cooooo0_l00006ooooo`;o00000ooo
ool2o`0000Cooooo1_l0000oooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o00009oooool2
o`0000kooooo0ol000000ooooooo0000o`000007ooooo`;o00004oooool3o`0000Gooooo0_l00009
ooooo`Ko000000?oooooo`000?l000002Oooool4o`0000Gooooo1ol00004ooooo`?o00001Oooool2
o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l000002?ooool2o`0000Sooooo0_l00002
ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0G?ooool3o`0000Sooooo0ol00003oooo
o`;o00001Oooool2o`0000oooooo0_l00004ooooo`;o00006?ooool5o`0000Cooooo0_l0000;oooo
o`;o00001_ooool2o`0000Kooooo1?l00005ooooo`;o000000?oooooo`000?l000001oooool2o`00
00Gooooo0_l00003ooooo`;o00001_ooool2o`0001Kooooo0_l0000kooooo`007?ooool00ol0003o
ooooooooo`0]ooooo`;o000000Coooooo`000?l0003o0000:Oooool3o`0000;ooooo0_l000001?oo
oooo0000o`000?ooool3o`0000?ooooo0_l00003ooooo`Co00005Oooool4o`0000Wooooo0_l00007
ooooo`Wo000000?oooooo`000?l000000_l00002ooooo`;o00004?ooool2o`00013ooooo0_l00000
0ooooooo0000o`00000Booooo`;o00005_ooool2o`0000Sooooo0_l0000iooooo`007?ooool00ol0
003oooooooooo`0]ooooo`;o000000Coooooo`000?l0003o00003oooool2o`0000Wooooo1?l0000@
ooooo`;o000000?oooooo`000?l000000oooool2o`000004ooooool0003o0000o`0000?ooooo0_l0
000Iooooo`;o00002Oooool2o`0000Cooooo0_l000000ooooooo0000o`000002o`000004ooooool0
003o0000o`0000;ooooo1?l00002ooooo`;o00001_ooool6o`0000Cooooo0ol0000?ooooo`;o0000
00?oooooo`000?l000003Oooool2o`0001_ooooo0_l00008ooooo`;o0000>Oooool001cooooo00?o
0000ooooooooool0@_ooool2o`0000Wooooo1?l0000Hooooo`;o000000Coooooo`000?l0003o0000
0oooool2o`0000Cooooo0_l0000Jooooo`;o00002?ooool2o`0000?ooooo0_l00004ooooo`Co0000
1?ooool2o`0000Kooooo1_l00004ooooo`?o00004_ooool2o`0000gooooo0ol0001Oooooo`007?oo
ool00ol0003oooooooooo`0Yooooo`;o00001Oooool2o`0001gooooo0_l0000Wooooo`;o00001_oo
ool2o`0000Sooooo0_l00008ooooo`;o00002?ooool4o`000003ooooool0003o000000Cooooo1?l0
0004ooooo`Go00003Oooool2o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l000004?oo
ool2o`0000Cooooo0_l00004ooooo`;o00001_ooool2o`0000kooooo0_l00008ooooo`;o00003ooo
ool2o`0002Kooooo000Looooo`03o`000?oooooooooo02Wooooo0_l00004ooooo`?o0000??ooool2
o`0000[ooooo1?l00002ooooo`;o00002?ooool2o`0001;ooooo1?l0000<ooooo`;o000000?ooooo
o`000?l000000ol0000=ooooo`;o00000_ooool4o`0000;ooooo0_l000000ooooooo0000o`00000@
ooooo`;o00001Oooool2o`0000;ooooo0ol000000ooooooo0000o`000003ooooo`;o00002Oooool2
o`0000?ooooo0ol00005ooooo`Co00003oooool2o`0002Kooooo000Looooo`03o`000?oooooooooo
02oooooo0_l0000Fooooo`;o00005_ooool2o`0000gooooo0_l0000:ooooo`Co000000Coooooo`00
0?l0003o00001_ooool2o`0000kooooo0_l00002ooooo`Go00000oooool4o`0000?ooooo0_l00000
1?oooooo0000o`000?ooool5o`00017ooooo0_l0000Eooooo`Ko00000_ooool2o`000003ooooool0
003o000000;ooooo0_l00002ooooo`;o00001oooool2o`0000Gooooo0_l00004ooooo`;o00001Ooo
ool2o`0003Wooooo000Looooo`03o`000?oooooooooo03gooooo0_l00008ooooo`;o00005_ooool2
o`0001Oooooo0_l000001?oooooo0000o`000?ooool3o`0000Oooooo0_l00004ooooo`;o00001ooo
ool8o`0000?ooooo1_l000000ooooooo0000o`000005o`000003ooooool0003o000000Go000000?o
ooooo`000?l000001?ooool2o`000003ooooool0003o000001Gooooo0_l00002ooooo`Oo00000_oo
ool5o`0000Cooooo0_l00008ooooo`?o00001Oooool2o`0000Cooooo0_l00005ooooo`;o0000>Ooo
ool001cooooo0_l0000Pooooo`;o00007?ooool2o`0002Cooooo0_l00008ooooo`Co00001oooool4
o`0000;ooooo0_l00009ooooo`;o00000oooool2o`0000;ooooo0ol00002ooooo`Wo00000_ooool>
o`000003ooooool0003o000000Go000000?oooooo`000?l000001?ooool2o`000003ooooool0003o
000001;ooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool2o`0000Gooooo0_l00004
ooooo`?o00001_ooool6o`0000Gooooo0_l00003ooooo`;o00001Oooool2o`0003Wooooo000Loooo
o`03o`000?oooooooooo01oooooo0_l0000;ooooo`;o00000oooool2o`00033ooooo0_l00008oooo
o`Co00002Oooool5o`0000[ooooo0_l000000ooooooo0000o`000004ooooo`?o00001?ooool8o`00
00?ooooo2Ol000000ooooooo0000o`000003o`000003ooooool0003o000000;o00001Oooool2o`00
00;ooooo0ol0000=ooooo`;o00000oooool3o`0000?ooooo0_l000000ooooooo0000o`00000<oooo
o`?o00001oooool2o`000004ooooool0003o0000o`0000Gooooo0_l0000:ooooo`;o0000>Oooool0
01cooooo00?o0000ooooooooool0;?ooool2o`0000?ooooo0_l0000Eooooo`;o00003oooool2o`00
01Gooooo0ol00008ooooo`Co00003Oooool2o`0000Cooooo0_l00007ooooo`?o000000Coooooo`00
0?l0003o00000_ooool>o`0000Gooooo2?l00002ooooo`;o00003_ooool2o`0000Cooooo1?l00000
1?oooooo0000o`000?ooool2o`0000cooooo0_l00004ooooo`;o00001Oooool2o`0000[ooooo0_l0
0003ooooo`;o00000_ooool2o`00013ooooo0_l0000Vooooo`007?ooool00ol0003oooooooooo`0/
ooooo`;o00005_ooool2o`0000;ooooo0_l0000;ooooo`;o00000_ooool2o`0000_ooooo0_l00008
ooooo`?o00002Oooool2o`0001Cooooo0_l00004ooooo`Oo000000?oooooo`000?l000000_ooool5
o`000003ooooool0003o000000Go00000_ooool2o`000003ooooool0003o000000Go00000_ooool2
o`0000Kooooo1Ol00007ooooo`;o00001?ooool2o`0000cooooo0ol000000ooooooo0000o`000006
ooooo`;o00001oooool2o`000003ooooool0003o000000Gooooo0_l00003ooooo`;o00000_ooool2
o`00013ooooo0_l0000Vooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00005_ooool2o`00
00[ooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo1?l000000ooooooo0000o`000004o`00
017ooooo0_l0000Jooooo`[o000000?oooooo`000?l000001_l00002oooooa7o00001?ooool2o`00
00Cooooo1ol00004ooooo`;o000000?oooooo`000?l000000_ooool3o`0000gooooo0ol000000ooo
oooo0000o`00000?ooooo`;o000000?oooooo`000?l00000B?ooool001cooooo00?o0000oooooooo
ool0@oooool2o`0000[ooooo0ol00007ooooo`So000000?oooooo`000?l000000ol0000Booooo`;o
00001?ooool2o`0000Gooooo0_l00007ooooo`;o00001?ooool4o`0000Oooooo5_l00002ooooo`;o
00000oooool2o`0000Cooooo1?l00007ooooo`Co00001Oooool3o`0000Cooooo0_l0000=ooooo`?o
00001?ooool2o`0000oooooo0ol000000ooooooo0000o`00000nooooo`007?ooool00ol0003ooooo
ooooo`13ooooo`;o00002_ooool2o`0000Kooooo1ol000000ooooooo0000o`00000:o`0000?ooooo
0_l00008ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Gooooo0_l00006ooooo`Go0000
0oooool5o`0000;ooooo7Ol00003ooooo`;o00001?ooool4o`0000Oooooo0_l000000ooooooo0000
o`00000;ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Cooooo0ol00004ooooo`Co0000
3Oooool3o`000003ooooool0003o000003kooooo000Looooo`03o`000?oooooooooo05Kooooo5Ol0
0003ooooo`?o00001oooool5o`00013ooooo0ol000000ooooooo0000o`000003ooooo`;o000000Co
ooooo`000?l0003ooooo8?l00002ooooo`;o00004Oooool2o`0000kooooo0_l00004ooooo`;o0000
3Oooool2o`00057ooooo000Looooo`03o`000?oooooooooo02Sooooo0_l0000/oooooa7o00002?oo
ool2o`000003ooooool0003o000000Cooooo0ol0000Booooo`;o00002?ooool2o`000003ooooool0
003o000001So00001Oooool7o`00013ooooo0_l00003ooooo`;o00000_ooool2o`0000Sooooo0_l0
0002ooooo`;o00002_ooool2o`0005Cooooo000Looooo`03o`000?oooooooooo02Sooooo0_l0000Z
oooooa?o000000?oooooo`000?l000002?ooool2o`0000Gooooo0_l00002ooooo`;o00004oooool3
o`0000;ooooo7Ol000000ooooooo0000o`000002o`000003ooooool0003o000000;o00004_ooool2
o`0000?ooooo0_l00002ooooo`;o00002?ooool3o`0000gooooo0_l00002ooooo`Co0000C_ooool0
01cooooo00?o0000ooooooooool0DooooolGo`000003ooooool0003o000000cooooo0_l00002oooo
o`Co00004OoooolWo`000003ooooool0003o000000;o00004?ooool2o`00013ooooo0_l00002oooo
o`;o00001Oooool2o`0000[ooooo1?l0001>ooooo`007?ooool00ol0003oooooooooo`0Yooooo`;o
00009ooooolFo`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000Wooooo0_l00006ooooo`;o
00001oooool4o`000003ooooool0003o000002;o00000oooool2o`00013ooooo0_l0000@ooooo`;o
00002?ooool3o`0001Oooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`0Xooooo`?o0000
9ooooolFo`000003ooooool0003o000000Cooooo0_l00003ooooo`Co00001Oooool2o`0000Sooooo
0_l00007ooooo`Co00000_oooolQo`0000?ooooo1?l00008ooooo`Co00005Oooool2o`0000Cooooo
0_l00003ooooo`;o00000oooool2o`0000Gooooo0_l0000<ooooo`;o00006_ooool2o`0002Oooooo
000Looooo`03o`000?oooooooooo02Sooooo0_l0000Aooooo`;o00005?oooolGo`000003ooooool0
003o000000Cooooo0_l00004ooooo`?o00001Oooool2o`0000Sooooo0_l00004ooooo`;o00000_oo
ool2o`0000?ooooo8Ol000000ooooooo0000o`000002o`0000[ooooo1?l00005ooooo`;o00002?oo
ool2o`0000Cooooo0_l00004ooooo`;o00002?ooool2o`0000;ooooo0_l000000ooooooo0000o`00
000<ooooo`;o00006_ooool2o`0002Oooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo
0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0[ooooo`;o
00003_ooool2o`0001Cooooo6?l00007ooooo`?o00000_ooool3o`0000oooooo0_l00002ooooo`Co
00000_ooool2o`0000?ooooo3Ol000000ooooooo0000o`00000Do`0000Cooooo0_l00006ooooo`;o
00001oooool4o`0000Kooooo0_l0000Dooooo`;o00000_ooool2o`0000Sooooo0_l00005ooooo`;o
00000_ooool2o`0001Oooooo0_l0000Vooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5oooo
o`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0:oooool2
o`0000;ooooo0_l0000QoooooaOo00001oooool3o`0000;ooooo0ol0000Cooooo`;o00002Oooool2
o`000003ooooool0003o0000027o000000Coooooo`000?l0003o00001?ooool2o`0000Gooooo1?l0
0002ooooo`;o00001_ooool2o`0001Kooooo0_l00007ooooo`Go00001Oooool2o`0000;ooooo0_l0
000Gooooo`;o00009_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0;oooool2o`0000Sooooo0_l0
000Fooooo`oo000000?oooooo`000?l000001_l0000<ooooo`;o00008?oooolUo`000003ooooool0
003o000000Gooooo0_l00005ooooo`Co00002_ooool2o`0000[ooooo1?l00005ooooo`;o000000?o
ooooo`000?l000001?ooool2o`000003ooooool0003o000000;o00000_ooool2o`000004ooooool0
003o0000o`0004?ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go
0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000=_ooool2o`000003ooooool0003o000001Kooooo
3Ol000000ooooooo0000o`000009o`0001gooooo0_l000000ooooooo0000o`000006ooooo`;o0000
0ooooolQo`0000Oooooo0_l0000Hooooo`?o00000oooool2o`0000Cooooo1Ol00002ooooo`Co0000
1oooool4o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000003ooooo`;o0000
?oooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oEEEEo`00
0?l@413oc<c<00Kooooo00?o0000ooooooooool0=_ooool2o`0001Sooooo6_l0000:ooooo`;o0000
2oooool3o`0000?ooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000002Oo0000
00?oooooo`000?l000001?ooool2o`0001Wooooo0_l00003ooooo`;o00001oooool2o`0000;ooooo
0_l0000;ooooo`;o00001?ooool2o`0000;ooooo0_l00003ooooo`Co0000?Oooool00003ooooool@
413ooooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo02;ooooo0_l0000/oooooaSo00002Oooool2o`000003ooooool0003o000000[ooooo1?l0
0008ooooo`Ko000000?oooooo`000?l000006_l00002ooooo`Co000000?oooooo`000?l000000ol0
0009ooooo`;o00002_ooool2o`0000;ooooo0_l0000Cooooo`;o00003_ooool2o`0000Cooooo0_l0
0009ooooo`;o0000?Oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@
oiRHV008ooooo`03o`000?oooooooooo02;ooooo0_l0000Xooooo`Co000000?oooooo`000?l00000
5_l00008ooooo`;o00001?ooool4o`0000Gooooo0_l00005ooooo`;o000000Coooooo`000?l0003o
oooo0_l00003ooooo`?o000000?oooooo`000?l000006?l000000ooooooo0000o`000002o`0000;o
oooo0ol00007ooooo`;o000000?oooooo`000?l000002_ooool2o`0000;ooooo0_l0000Cooooo`;o
00001oooool2o`0000?ooooo0_l00007ooooo`;o0000Aoooool00006ooooooo^k^ko<S8bo`000?lb
<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo03;ooooo1?l0000F
oooooaoo00001?ooool3o`0000Gooooo1?l0000<ooooo`;o000000Coooooo`000?l0003ooooo9?l0
00000ooooooo0000o`000008o`0000Gooooo0_l0000_ooooo`;o00000oooool2o`0000Oooooo0_l0
0002ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0<_ooool4o`0001[ooooo0_l00000
0ooooooo0000o`00000?o`0000Gooooo0_l00004ooooo`?o00004oooool2o`0000;ooooo0_l00004
oooooa;o000000?oooooo`000?l000005?l00002ooooo`;o000000?oooooo`000?l00000<oooool2
o`000003ooooool0003o000000Wooooo0_l00002ooooo`;o0000@oooool001cooooo00?o0000oooo
ooooool0D_oooolBo`0001?ooooo0_l00007ooooo`;o00000oooool2o`0000;ooooo0_l00006oooo
o`?o00000oooool:o`0000;ooooo6Ol000000ooooooo0000o`000004ooooo`;o0000;Oooool5o`00
00[ooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00004OoooolAo`0000;o
oooo0_l0000@ooooo`;o00000oooool2o`0000;ooooo0_l000000ooooooo0000o`00000;ooooo`?o
000000?oooooo`000?l000009_l00007ooooo`;o00009Oooool2o`000003ooooool0003o000000Go
oooo0_l0000;ooooo`;o000000?oooooo`000?l00000@oooool001cooooo00?o0000ooooooooool0
?oooool2o`0000oooooo0_l00003ooooo`;o00000oooool3o`0000?ooooo0ol00002ooooo`;o0000
1Oooool2o`0000kooooo0_l00005ooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo
9Ol00002ooooo`Go00001?ooool2o`0002Sooooo0_l000000ooooooo0000o`00000Eooooo`;o0000
@oooool001cooooo00?o0000ooooooooool0D?ooool4o`0000Kooooo0ol00002ooooo`?o00000ooo
ool2o`0000Gooooo0ol00002ooooo`;o00004Oooool4o`0000Cooooo0_l000000ooooooo0000o`00
000To`000003ooooool0003o000000?o00001Oooool2o`0002Cooooo0_l0000Dooooo`;o0000Booo
ool001cooooo00?o0000ooooooooool0DOooool3o`0000Kooooo0_l00003ooooo`?o00000oooool2
o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000003_ooool4
o`0000Oooooo6Ol000000ooooooo0000o`00000=o`0002kooooo0_l0000Dooooo`;o0000Boooool0
01cooooo00?o0000ooooooooool0DOooool2o`0000Oooooo0_l00005ooooo`;o00001oooool2o`00
00Oooooo0ol00002ooooo`;o00003?ooool2o`0000?ooooo0_l000000ooooooo0000o`000002oooo
obSo00002oooool2o`00027ooooo0_l00003ooooo`;o00001Oooool2o`0000Kooooo0_l0001;oooo
o`007?ooool00ol0003oooooooooo`18ooooo`;o00001oooool2o`0000Oooooo0_l00003ooooo`Co
00001_ooool3o`0000Oooooo0_l00003ooooo`;o00002Oooool2o`0000;ooooo0_l00002ooooo`;o
000000Coooooo`000?l0003ooooo8?l000000ooooooo0000o`000006o`0000Sooooo0_l000000ooo
oooo0000o`00000Nooooo`;o000000?oooooo`000?l000000oooool2o`0000Gooooo0_l00004oooo
o`;o00001oooool2o`0004Cooooo000Looooo`03o`000?oooooooooo03oooooo0_l00006ooooo`Go
00001Oooool2o`0000Kooooo1Ol000000ooooooo0000o`000003ooooo`?o00000_ooool2o`0000;o
oooo0_l00008ooooo`;o00000oooool2o`0000Gooooo0_l00002ooooo`;o00000_ooool2o`0000Co
oooo0_l000000ooooooo0000o`000003o`000003ooooool0003o0000023o000000?oooooo`000?l0
00000oooool2o`00023ooooo0ol0000;ooooo`;o00001_ooool2o`0000Oooooo0_l00014ooooo`00
7?ooool00ol0003oooooooooo`0oooooo`;o00001_ooool2o`000003ooooool0003o000000gooooo
1Ol00006ooooo`?o00001_ooool2o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l00000
0_l0000=ooooo`;o00001Oooool5o`000003ooooool0003o0000017o000000?oooooo`000?l00000
2_l00002ooooo`;o000000?oooooo`000?l000000_l0000Sooooo`;o00003?ooool2o`0000Oooooo
0_l0001<ooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o000000?oooooo`000?l000000_l0
000@ooooo`?o00002Oooool2o`0000Gooooo1Ol0000Dooooo`?o00000_oooolQo`0000Sooooo0_l0
000Oooooo`;o00002?ooool2o`0000kooooo0ol0001<ooooo`007?ooool2o`0004oooooo0_l00000
0ooooooo0000o`000002o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o000000?ooooo
o`000?l000000ol00003ooooo`;o000000?oooooo`000?l000002?ooool4o`0000Oooooo0_l00000
0ooooooo0000o`000009oooooaCo000000?oooooo`000?l000003_l00004ooooo`;o00000oooool4
o`0000Gooooo0_l0000Fooooo`;o00001oooool3o`0000gooooo0ol00002ooooo`;o0000BOooool0
01cooooo00?o0000ooooooooool0Aoooool2o`0000gooooo0_l00002ooooo`;o00000oooool3o`00
0003ooooool0003o000000;ooooo0_l00002ooooo`Go00001?ooool2o`0000;ooooo0ol00008oooo
o`;o000000?oooooo`000?l000000_ooool4o`0000Cooooo1_l000000ooooooo0000o`00000Ko`00
00?ooooo0ol00005ooooo`;o00001Oooool2o`0001oooooo1?l00003ooooo`;o00001oooool2o`00
00?ooooo0_l00019ooooo`007?ooool00ol0003oooooooooo`17ooooo`;o00004oooool6o`0000Go
oooo0_l00004ooooo`;o00001Oooool2o`0000;ooooo0_l0000@ooooo`Co00001Oooool2o`0000Co
oooo0_l00002oooooa[o00000_ooool2o`00033ooooo0_l00003ooooo`;o00000oooool2o`0001oo
oooo0_l0000aooooo`007?ooool00ol0003oooooooooo`11ooooo`;o00006Oooool4o`0002Oooooo
0_l00002ooooo`[o000000Coooooo`000?l0003o00000_ooool4o`000003ooooool0003o000001;o
000000Coooooo`000?l0003o00001_ooool2o`000004ooooool0003o0000o`00037ooooo0_l00003
ooooo`;o00006_ooool2o`00037ooooo000Looooo`03o`000?oooooooooo047ooooo0_l00004oooo
o`;o00000_ooool4o`0000Oooooo0_l0000Gooooo`;o00005_ooool2o`0000;ooooo2Ol00002oooo
o`?o000000?oooooo`000?l000000ol000000ooooooo0000o`00000=o`000003ooooool0003o0000
00?o000000?oooooo`000?l000001_ooool6o`0001kooooo1?l0000Dooooo`;o0000COooool001co
oooo00?o0000ooooooooool0Aoooool8o`0000Oooooo0_l0000:ooooo`;o00002oooool2o`00027o
oooo0_l00002oooooaOo00000oooool7o`0000Sooooo0_l0000Qooooo`Co00002Oooool2o`0000Wo
oooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`16ooooo`;o000000Coooooo`000?l0003o
oooo1?l00006ooooo`;o00000oooool2o`0000Gooooo0_l0000=ooooo`;o00009?ooool3o`0000;o
oooo1_l00002oooooa?o00004Oooool2o`0002Gooooo0_l0001Hooooo`007?ooool00ol0003ooooo
ooooo`16ooooo`;o00001?ooool4o`0000Kooooo1?l000000ooooooo0000o`000003ooooo`?o0000
3_ooool2o`0001;ooooo0_l00003ooooo`;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000
o`000006ooooo`;o00001Oooool2o`0000;ooooo1_l000001Ooooooo0000o`000?l0003ooooo00;o
00002_ooool2o`0000Gooooo0ol0000Aooooo`;o00000oooool2o`0006Kooooo000Looooo`03o`00
0?oooooooooo04?ooooo0_l00008ooooo`;o00002Oooool2o`000003ooooool0003o000000?ooooo
0ol00004ooooo`;o00002Oooool2o`0000;ooooo0_l00009ooooo`;o00000_ooool2o`0000;ooooo
1?l00003ooooo`?o000000?oooooo`000?l000002Oooool3o`0000Cooooo3ol0000<ooooo`;o0000
1_ooool2o`00017ooooo0_l00003ooooo`;o00000oooool2o`0000Oooooo0_l0000:ooooo`;o0000
C?ooool001cooooo00?o0000ooooooooool0@oooool2o`0000Sooooo0_l0000:ooooo`Ko00002?oo
ool2o`0000Cooooo0_l00003ooooo`;o00000_ooool2o`0000Wooooo0_l00006ooooo`Co00000ooo
ool3o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l000000ol00003ooooo`?o000000?o
ooooo`000?l000001Ol000000ooooooo0000o`000003ooooo`;o00002_ooool2o`0001Wooooo0_l0
0005ooooo`;o00001?ooool5o`0000?ooooo0_l000001?oooooo0000o`000?ooool3o`0004cooooo
000Looooo`03o`000?oooooooooo04kooooo0_l00009ooooo`;o00000_ooool2o`0000Cooooo0_l0
0008ooooo`;o00001Oooool2o`0000kooooo0_l00003ooooo`;o00001Oooool2o`0000?ooooo0_l0
0002ooooo`Go00000oooool3o`0000;ooooo0ol00004ooooo`Co00001oooool2o`0000[ooooo0_l0
000Iooooo`?o00002_ooool4o`0000Cooooo0_l000000ooooooo0000o`000003o`0004gooooo000L
ooooo`03o`000?oooooooooo04[ooooo0_l00002ooooo`;o00003Oooool2o`0000Cooooo0_l00002
ooooo`;o00000_ooool2o`000003ooooool0003o000000Cooooo0_l0000>ooooo`?o00000_ooool2
o`0000Gooooo0_l00003ooooo`;o00000_ooool4o`0000Gooooo0ol000000ooooooo0000o`000002
o`0000Sooooo0_l000000ooooooo0000o`000002ooooo`;o00003_ooool2o`0001Gooooo0_l00000
1?oooooo0000o`000?l0000=ooooo`Co00000_ooool2o`0004kooooo000Looooo`03o`000?oooooo
oooo04[ooooo0_l00007ooooo`;o00001_ooool7o`0000Gooooo0_l00002ooooo`;o000000?ooooo
o`000?l000001?ooool3o`000004ooooool0003o0000o`0000[ooooo0_l00009ooooo`;o00001_oo
ool4o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`?o00001Oooool2o`000004ooooool0
003o0000ooooo`;o00000_ooool2o`0000_ooooo0_l000000ooooooo0000o`00000?ooooo`Co0000
1Oooool3o`0000[ooooo1ol0001Booooo`007?ooool00ol0003oooooooooo`1:ooooo`;o00001ooo
ool3o`0000Gooooo0_l00002ooooo`?o00004_ooool3o`000005ooooool0003o0000o`000?ooool0
0_l00007ooooo`;o00004Oooool5o`0000;ooooo1_l00002ooooo`Ko00000_ooool5o`000003oooo
ool0003o000000;o00000_ooool2o`0000Wooooo0_l0000Booooo`Co00000_ooool3o`0000gooooo
1_l0001Cooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00000oooool2o`0000Kooooo1?l0
0005ooooo`Co00002?ooool2o`0000;ooooo0_l0000;ooooo`;o00000_ooool2o`0000Oooooo0_l0
0003ooooo`;o00003Oooool4o`000003ooooool0003o000000Co00001Oooool4o`0000?ooooo1?l0
00000ooooooo0000o`000002o`0000;ooooo0_l0000Sooooo`?o00001oooool2o`000003ooooool0
003o000000Gooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00002oooool2
o`0000Kooooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool3o`0000;ooooo0_l00009
ooooo`Co00002Oooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o00002?ooool2
o`0000;ooooo1Ol00006ooooo`;o00003?ooool2o`00037ooooo0_l000000ooooooo0000o`00000N
ooooo`;o0000>_ooool001cooooo0_l0001Kooooo`;o00001?ooool3o`0000?ooooo0_l00007oooo
o`;o00001Oooool3o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l000001_ooool4o`00
00Cooooo0_l00002ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00000oooool2o`00
0003ooooool0003o000005?ooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o
000000?oooooo`000?l000003_ooool3o`0000Wooooo0_l00002ooooo`;o00003?ooool4o`0000go
oooo0_l00006ooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000Wo
oooo0_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000003Oooool2o`0001Go
oooo1?l0001Wooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o000000?oooooo`000?l00000
3_ooool2o`0000[ooooo0_l0000Aooooo`?o00004oooool7o`000004ooooool0003o0000ooooo`;o
00002Oooool2o`000003ooooool0003o000000;o00000oooool3o`00013ooooo1?l0000Cooooo`Co
00002oooool2o`0000Gooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`1?ooooo`Co0000
5oooool3o`0000Gooooo0_l0000:ooooo`Ko00002?ooool2o`0000Kooooo1_l00002ooooo`;o0000
1_ooool4o`0000;ooooo0_l00003ooooo`;o00000oooool6o`0000oooooo1?l0000Eooooo`;o0000
1?ooool2o`0000?ooooo1?l00003ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0Cooo
ool4o`0000_ooooo1?l00008ooooo`?o00001Oooool4o`0000Sooooo1_l00008ooooo`;o00001ooo
ool4o`0000Gooooo0_l00004ooooo`Co00003oooool3o`0000;ooooo0_l0000=ooooo`;o00002_oo
ool2o`0000Wooooo0_l000001?oooooo0000o`000?ooool2o`0000Gooooo0_l0001Hooooo`007?oo
ool00ol0003oooooooooo`1Nooooo`Co00004_ooool2o`0000;ooooo0_l00004ooooo`?o00002ooo
ool2o`0000Wooooo0_l000000ooooooo0000o`000004o`0000Cooooo0_l0000Fooooo`;o00003Ooo
ool2o`0000[ooooo0_l0000<ooooo`;o00001?ooool2o`0000;ooooo0_l0000?ooooo`;o0000Aooo
ool001cooooo00?o0000ooooooooool0Aoooool2o`0002gooooo1?l000001Ooooooo0000o`000?l0
003ooooo00;o00001_ooool2o`0000?ooooo0_l0000<ooooo`Co00007Oooool2o`0000Gooooo0_l0
0004ooooo`;o000000?oooooo`000?l000004_ooool2o`0000Kooooo0ol000000ooooooo0000o`00
0002ooooo`;o00003oooool2o`0004Oooooo000Looooo`03o`000?oooooooooo04Oooooo0_l0000?
ooooo`;o00000_ooool2o`000003ooooool0003o0000017ooooo0_l00002ooooo`;o00000_ooool4
o`000004ooooool0003o0000ooooo`;o00000oooool2o`0000?ooooo0_l0000:ooooo`?o000000?o
ooooo`000?l000001_ooool2o`0000;ooooo0ol0000@ooooo`Co00000oooool2o`0000;ooooo1ol0
000<ooooo`;o000000Coooooo`000?l0003ooooo0_l00005ooooo`Ko00000oooool3o`0005Oooooo
000Looooo`03o`000?oooooooooo05Sooooo0_l00002ooooo`;o000000?oooooo`000?l000000_oo
ool2o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`;o00001_ooool7o`000003ooooool0
003o000000?ooooo0_l00002ooooo`;o00002?ooool2o`000005ooooool0003o0000o`000?ooool0
0ol00005ooooo`?o000000Coooooo`000?l0003o00001oooool4o`0000Gooooo1?l00007ooooo`;o
00000_ooool2o`0000gooooo0_l000000ooooooo0000o`000002ooooo`;o00001?ooool2o`0000;o
oooo0_l00003ooooo`?o0000Eoooool001cooooo00?o0000ooooooooool0D?ooool2o`00013ooooo
0ol00004ooooo`;o000000?oooooo`000?l000000oooool2o`0000Sooooo1Ol00002ooooo`;o0000
1Oooool4o`0000Gooooo0_l000001Ooooooo0000o`000?l0003ooooo00?o000000?oooooo`000?l0
00001_ooool2o`0000Kooooo0ol00002ooooo`Co00000oooool2o`0000?ooooo0_l00008ooooo`;o
00000oooool2o`00017ooooo1?l00008ooooo`;o000000?oooooo`000?l00000F?ooool001cooooo
00?o0000ooooooooool0@oooool2o`0000_ooooo0_l0000?ooooo`?o00001_ooool2o`0000Gooooo
1?l00009ooooo`;o00000_ooool2o`0000Gooooo0_l00007ooooo`;o00000_ooool2o`000005oooo
ool0003o0000o`000?ooool01?l00005ooooo`;o00001Oooool3o`000003ooooool0003o000000;o
00000oooool4o`000004ooooool0003o0000o`0000Sooooo1?l000000ooooooo0000o`000008oooo
o`;o00002Oooool2o`0000Sooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`13ooooo`;o
00007?ooool2o`0000Oooooo0_l00007ooooo`Ko00001Oooool2o`0000;ooooo0_l00003ooooo`;o
00005_ooool2o`0000?ooooo1?l00008ooooo`Go00000oooool7o`0000_ooooo0_l0000;ooooo`;o
00004oooool2o`0005_ooooo000Looooo`03o`000?oooooooooo06?ooooo0_l0000?ooooo`Go0000
1Oooool2o`0000;ooooo1?l000000ooooooo0000o`000003ooooo`;o00002?ooool2o`0000Oooooo
0_l00003ooooo`;o00002_ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l0
00000_l0000Mooooo`;o00003Oooool2o`000003ooooool0003o000005_ooooo000Looooo`03o`00
0?oooooooooo04gooooo0_l0000Dooooo`;o00000_ooool3o`0000?ooooo0_l00004ooooo`;o0000
0_ooool2o`0000Wooooo1?l00005ooooo`?o00001oooool3o`0001kooooo0_l000000ooooooo0000
o`00000Gooooo`;o00001_ooool2o`0000[ooooo0_l000000ooooooo0000o`00001Nooooo`007?oo
ool00ol0003oooooooooo`1=ooooo`;o00006?ooool3o`0000?ooooo0_l000001?oooooo0000o`00
0?ooool2o`0000gooooo1?l00005ooooo`;o00001Oooool5o`0000Cooooo0_l0000eooooo`;o0000
4_ooool2o`00067ooooo000Looooo`03o`000?oooooooooo073ooooo0ol000000ooooooo0000o`00
0002o`0000;ooooo0_l0000:ooooo`;o000000?oooooo`000?l000001Oooool8o`0000?ooooo0_l0
0007ooooo`;o000000?oooooo`000?l000002_ooool2o`0001Oooooo0_l0001kooooo`007?ooool2
o`0006Sooooo0ol00002ooooo`;o00000oooool2o`000003ooooool0003o000000;o00000_ooool2
o`0000[ooooo0_l000000ooooooo0000o`000005ooooo`Co00000_ooool3o`0000?ooooo0_l00006
ooooo`;o000000?oooooo`000?l000002_ooool4o`0000Cooooo0_l0000?ooooo`;o00001oooool2
o`0000oooooo0_l0001Qooooo`007?ooool00ol0003oooooooooo`1Wooooo`?o00000_ooool2o`00
00?ooooo0_l0000Gooooo`;o00001_ooool3o`0000;ooooo0_l00003ooooo`;o000000?oooooo`00
0?l000002oooool3o`0000Kooooo0_l00003ooooo`?o000000?oooooo`000?l000005Oooool2o`00
00oooooo1?l0001Oooooo`007?ooool00ol0003oooooooooo`1Xooooo`;o00001oooool3o`0000So
oooo1?l0000:ooooo`Co00001Oooool2o`0000Wooooo0ol00008ooooo`;o000000Goooooo`000?l0
003o0000ooooo`02o`0000;ooooo0ol00003ooooo`;o00000_ooool2o`0001Cooooo0_l00002oooo
o`;o00000oooool2o`0000Gooooo0_l000001?oooooo0000o`000?l0001Oooooo`007?ooool00ol0
003oooooooooo`1Cooooo`;o00003oooool2o`0000;ooooo0_l00008ooooo`Oo00000oooool4o`00
00Cooooo1?l00002ooooo`Co000000Coooooo`000?l0003o00001oooool2o`0000;ooooo0ol00009
ooooo`;o00001Oooool2o`0000;ooooo0ol00006ooooo`;o00005Oooool2o`000004ooooool0003o
0000o`0000?ooooo0_l00005ooooo`;o000000?oooooo`000?l000000oooool2o`0005_ooooo000L
ooooo`03o`000?oooooooooo05?ooooo0_l0000?ooooo`;o00002oooool8o`0000[ooooo1Ol00007
ooooo`Co00001_ooool2o`0000;ooooo0_l00003ooooo`;o00001?ooool2o`0000oooooo0_l00002
ooooo`;o00002_ooool2o`0000Gooooo0_l00005ooooo`;o00004oooool2o`0005_ooooo000Loooo
o`03o`000?oooooooooo073ooooo1Ol0000>ooooo`;o00001Oooool4o`0000?ooooo0_l00007oooo
o`;o00001_ooool2o`0000Cooooo0_l000000ooooooo0000o`00000<ooooo`;o00003_ooool3o`00
00Cooooo0_l00007ooooo`;o00000_ooool2o`0000Gooooo0_l0001Sooooo`007?ooool00ol0003o
ooooooooo`1Zooooo`;o00001?ooool2o`000004ooooool0003o0000o`0000gooooo0ol000001?oo
oooo0000o`000?ooool4o`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l000001_ooool4
o`0000Gooooo0_l0000Eooooo`;o00000oooool2o`000003ooooool0003o000000Wooooo0_l00000
1Ooooooo0000o`000?l0003ooooo00?o00001Oooool2o`0006?ooooo000Looooo`03o`000?oooooo
oooo06[ooooo0_l00008ooooo`;o00002Oooool7o`000003ooooool0003o000000[ooooo1_l00009
ooooo`Co00005oooool2o`0000?ooooo0_l00003ooooo`;o00000oooool2o`0000Oooooo0_l00000
0ooooooo0000o`000002ooooo`Go0000J?ooool001cooooo00?o0000ooooooooool0Ooooool4o`00
01;ooooo0_l0000Oooooo`;o00001Oooool2o`0000gooooo0ol00009ooooo`;o00000oooool5o`00
06Oooooo000Looooo`03o`000?oooooooooo07Kooooo0_l0000Booooo`;o00002Oooool2o`00013o
oooo0_l00009ooooo`;o00000_ooool2o`0000Kooooo0_l0000=ooooo`;o00000_ooool2o`0000Go
oooo0_l00003ooooo`Go00005?ooool2o`00057ooooo000Looooo`03o`000?oooooooooo07Gooooo
0ol0000Booooo`Go00002?ooool2o`0000cooooo1?l00009ooooo`;o00002_ooool2o`00017ooooo
0_l000000ooooooo0000o`000003ooooo`;o00001?ooool2o`000003ooooool0003o000001;ooooo
0_l0001Aooooo`007?ooool00ol0003oooooooooo`1aooooo`;o00000_ooool2o`0000Wooooo0_l0
0008ooooo`Go00002?ooool4o`0000;ooooo0_l00006ooooo`Co00002Oooool2o`00023ooooo0_l0
0003ooooo`;o00001?ooool2o`000003ooooool0003o000006Gooooo000Looooo`03o`000?oooooo
oooo077ooooo0_l0000=ooooo`?o00000_ooool2o`0000?ooooo0ol00009ooooo`Go00000_ooool2
o`0001?ooooo0_l00003ooooo`;o00003?ooool3o`00017ooooo1?l0001/ooooo`007?ooool00ol0
003oooooooooo`1aooooo`;o00003_ooool2o`0000;ooooo0_l000001Ooooooo0000o`000?l0003o
oooo00;o00002?ooool4o`000003ooooool0003o000000kooooo0_l00005ooooo`;o00000_ooool3
o`0000cooooo1?l00007ooooo`;o000000?oooooo`000?l000001_ooool2o`0006cooooo00001_oo
ooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0
1_ooool00ol0003oooooooooo`24ooooo`;o00000_ooool3o`000003ooooool0003o000000Wooooo
0_l000001?oooooo0000o`000?l0000>ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;o
oooo0_l0000?ooooo`;o00001oooool5o`000003ooooool0003o000000?ooooo0_l0001/ooooo`00
00KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q00Kooooo00?o0000ooooooooool0Q?ooool2o`00017ooooo0_l000000ooooooo0000o`000002
o`0000[ooooo0_l00004ooooo`;o00006oooool2o`0000Gooooo0_l00002ooooo`;o00000oooool2
o`0006cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo07kooooo0_l00002ooooo`;o00002?ooool2
o`0000kooooo0_l00009ooooo`?o00004_ooool2o`0000gooooo0_l00002ooooo`;o0000N?ooool0
0003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Olb<S;oV9RHoooooonHV9So
<S8b00Kooooo0ol0001eooooo`;o00001oooool2o`0000;ooooo0_l00002ooooo`;o00001?ooool3
o`0000Kooooo0_l00008ooooo`;o00000oooool2o`000003ooooool0003o000000cooooo0_l00000
0ooooooo0000o`000002ooooo`;o00000_ooool2o`0000gooooo1?l0000:ooooo`;o0000J_ooool0
0003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Oo<c<co0000o`000?l0003o
c<c<00Kooooo00?o0000ooooooooool0Koooool2o`0000Cooooo0ol0000<ooooo`Co00001Oooool5
o`0000?ooooo0_l00008ooooo`;o00000oooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool2
o`0000;ooooo0_l000000ooooooo0000o`000006ooooo`;o00002Oooool2o`0000Cooooo0_l0000:
ooooo`;o0000J_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol@
413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0Koooool2o`0000Gooooo0_l0000<
ooooo`;o00000_ooool2o`0000Cooooo1?l00003ooooo`;o00003Oooool3o`000003ooooool0003o
000000;o000000?oooooo`000?l000000_ooool2o`0000kooooo0_l000000ooooooo0000o`000004
ooooo`?o0000O?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooo
oonj^[[o000000Kooooo00?o0000ooooooooool0MOooool2o`000003ooooool0003o000000Oooooo
0_l00005ooooo`;o00006_ooool3o`000003ooooool0003o000000;o00003_ooool2o`0000Gooooo
1Ol000001?oooooo0000o`000?ooool3o`0007cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^
kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo07Gooooo1Ol00007
ooooo`;o00002_ooool2o`0001_ooooo0_l00004ooooo`Ko00001?ooool2o`0000Kooooo0_l00003
ooooo`;o000000?oooooo`000?l00000OOooool001cooooo00?o0000ooooooooool0Moooool2o`00
00oooooo0ol00002ooooo`;o00001?ooool2o`000003ooooool0003o0000013ooooo1?l00004oooo
o`Ko00000oooool3o`0000Gooooo0_l0000Gooooo`;o0000KOooool001cooooo00?o0000oooooooo
ool0R?ooool3o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l000000oooool2o`0000_o
oooo1_l0000;ooooo`;o00001_ooool2o`0001Oooooo0_l0001]ooooo`007?ooool00ol0003ooooo
ooooo`1booooo`;o00003_ooool3o`000004ooooool0003o0000ooooo`;o00001?ooool2o`0000[o
oooo0_l0000=ooooo`Co00004oooool2o`000003ooooool0003o000000;o00006oooool2o`0006Co
oooo000Looooo`03o`000?oooooooooo06_ooooo0_l00005ooooo`;o00003_ooool3o`000003oooo
ool0003o000000Oooooo0_l0000`ooooo`;o000000?oooooo`000?l000000_l0000Kooooo`;o0000
I?ooool001cooooo00?o0000ooooooooool0Joooool2o`0002;ooooo0_l0000Pooooo`;o0000U_oo
ool001cooooo00?o0000ooooooooool0Qoooool2o`0000oooooo0ol0000Booooo`;o000000?ooooo
o`000?l000000_l00004ooooo`Co000000?oooooo`000?l000000oooool2o`0008Gooooo000Loooo
o`03o`000?oooooooooo08?ooooo1ol0000>ooooo`Go00001Oooool4o`0000Oooooo0_l000000ooo
oooo0000o`000002o`0000?ooooo1Ol000000ooooooo0000o`000003ooooo`;o0000QOooool001co
oooo00?o0000ooooooooool0Poooool4o`000003ooooool0003o000000Oooooo0_l00006ooooo`Co
00001Oooool4o`00017ooooo0_l0002@ooooo`007?ooool00ol0003oooooooooo`1jooooo`;o0000
3?ooool2o`0000;ooooo0_l00003ooooo`;o00008?ooool2o`0000?ooooo0_l0002?ooooo`007?oo
ool00ol0003oooooooooo`1hooooo`Co00004?ooool2o`0001gooooo0_l00006ooooo`;o000000?o
ooooo`000?l000000_l000000ooooooo0000o`00002<ooooo`007?ooool00ol0003oooooooooo`1h
ooooo`;o0000<?ooool3o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l000000_l0002<
ooooo`007?ooool2o`000:Gooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o
000000;o00000_ooool4o`0000;ooooo0ol00007ooooo`;o0000Q?ooool001cooooo00?o0000oooo
ooooool0W?ooool2o`0000Kooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o0000
00Cooooo1?l00003ooooo`Co000000?oooooo`000?l000000_ooool2o`0008Cooooo000Looooo`03
o`000?oooooooooo09Oooooo0_l00003ooooo`Co00002?ooool2o`0001;ooooo0_l000000ooooooo
0000o`000028ooooo`007?ooool00ol0003oooooooooo`2Gooooo`;o00001Oooool2o`000:Wooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0Roooool2
o`0000[ooooo0_l0000dooooo`;o0000N_ooool001cooooo00?o0000ooooooooool0Roooool2o`00
00[ooooo0_l0000dooooo`;o0000N_ooool001cooooo00?o0000ooooooooool0[oooool2o`0009So
oooo000Looooo`03o`000?oooooooooo0:Sooooo0_l00005ooooo`;o0000V?ooool001cooooo00?o
0000ooooooooool0Z?ooool2o`0009oooooo000Looooo`03o`000?oooooooooo0;Oooooo0_l0002@
ooooo`007?ooool00ol0003oooooooooo`2Qooooo`;o00005?ooool2o`00093ooooo000Looooo`03
o`000?oooooooooo0:7ooooo0_l0002Vooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001;ooooo1?l000000ol@
413oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo
0ol0003ooooood[ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000
ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03
o`000?oooooooooo0?ooooooD_ooool001;ooooo00?oEEEEofIVI_l00000oooooomDooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00YOooool01?l@413o0000o`000?ooool2o`00
0003oa0@4?oooooooooo01Gooooo00Co410@o`000?m4A4Coc<c<1?ooool01?l@413o0000odA4A?o<
c<`4ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0T?ooool00:Kooooo00Go0000oooooooooooooooo
o`000009ooooo`Ko00002oooool00onHV9So410@omgMg@05ooooo`03oiRHV?l@413ogMgM00?ooooo
00GoEEEEogMgMoooooooV9RHob4Q8@2@ooooo`00Y_ooool01Ol0003ooooooooooooooooo000001_o
oooo00?oQhN7oeEEEOooool01Oooool00on7QhOoEEEEooooo`02ooooo`05o`000?oooooooooooooo
ool00000T?ooool00:Kooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00002Oooool01Oo<
c<co8B4Qo`000?mEEEGo000000?ooooo00Goc<c<ob4Q8Ol0003oEEEEo`000003ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40T?ooool00:Kooooo00Go0000ohN7QoooooooZJVYo`00000Hooooo`05ob4Q
8On7QhOooooooiRHV?l000000oooool01OlQ8B7oQhN7oooooonHV9So000000?ooooo00Go0000oeEE
EOl0003o410@olc<c02@ooooo`00YOooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo
01Kooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool00omEEEGoQhN7ooooo`2Booooo`00`oooool01OlQ8B7oV9RHoooooomgMgOoEEEE00?ooooo00Go
8B4QoiRHV?ooooooMgMgoeEEE@03ooooo`03omgMgOl@413oV9RH09;ooooo0033ooooo`05olc<c?l@
413o0000oc8b<_o^k^h00oooool01Oo<c<co410@o`000?lb<S;ok^k^00Cooooo00Coc<c<odA4A?l0
003o410@T?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1002) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.63302 .50529 Mdot
.68479 .50212 Mdot
.34924 .39296 Mdot
.48693 .64204 Mdot
.75714 .46708 Mdot
.3985 .40931 Mdot
.58596 .31959 Mdot
.54505 .3572 Mdot
.36902 .40776 Mdot
.55439 .50138 Mdot
.55848 .32136 Mdot
.55429 .54848 Mdot
.55713 .34301 Mdot
.48934 .6228 Mdot
.56572 .86266 Mdot
.49195 .68435 Mdot
.70294 .48598 Mdot
.27313 .53676 Mdot
.56309 .59357 Mdot
.31308 .41748 Mdot
.62578 .47966 Mdot
.49405 .63512 Mdot
.63684 .50333 Mdot
.48974 .62258 Mdot
.47195 .63266 Mdot
.67252 .4822 Mdot
.63859 .54 Mdot
.48611 .65959 Mdot
.47053 .59335 Mdot
.56467 .36288 Mdot
.33285 .70081 Mdot
.66066 .81004 Mdot
.54744 .65874 Mdot
.69254 .2601 Mdot
.54006 .35231 Mdot
.67308 .73993 Mdot
.37832 .42061 Mdot
.57584 .35271 Mdot
.54164 .35098 Mdot
.57944 .36812 Mdot
.55839 .35459 Mdot
.67384 .48777 Mdot
.57028 .38489 Mdot
.60707 .28269 Mdot
.54377 .57317 Mdot
.68038 .39456 Mdot
.456 .75643 Mdot
.5316 .59598 Mdot
.69733 .48186 Mdot
.31701 .40922 Mdot
.67932 .26524 Mdot
.59676 .3349 Mdot
.44154 .41115 Mdot
.90165 .49051 Mdot
.58355 .34444 Mdot
.54751 .56985 Mdot
.35053 .41188 Mdot
.50514 .63358 Mdot
.49412 .62332 Mdot
.55811 .74778 Mdot
.47429 .65852 Mdot
.29416 .55374 Mdot
.69476 .46208 Mdot
.33453 .50892 Mdot
.37985 .41284 Mdot
.54252 .34728 Mdot
.69481 .50974 Mdot
.56378 .3406 Mdot
.50962 .54766 Mdot
.43948 .38619 Mdot
.53166 .59724 Mdot
.54529 .34231 Mdot
.6844 .534 Mdot
.53302 .61161 Mdot
.39947 .22068 Mdot
.39951 .82397 Mdot
.26072 .58893 Mdot
.60676 .7414 Mdot
.56311 .7669 Mdot
.2844 .47416 Mdot
.48398 .58862 Mdot
.18632 .55695 Mdot
.50628 .84896 Mdot
.63713 .49479 Mdot
.49713 .69213 Mdot
.43242 .3735 Mdot
.53142 .61789 Mdot
.61417 .42705 Mdot
.52555 .56222 Mdot
.51602 .19363 Mdot
.3674 .40386 Mdot
.66145 .50983 Mdot
.48576 .63929 Mdot
.45476 .62091 Mdot
.61701 .63086 Mdot
.50219 .6691 Mdot
.4941 .65637 Mdot
.64195 .53379 Mdot
.55943 .31475 Mdot
.54157 .53327 Mdot
.60638 .36399 Mdot
.44722 .3988 Mdot
.54954 .60624 Mdot
.34045 .41442 Mdot
.65434 .53843 Mdot
.53818 .61531 Mdot
.5425 .31777 Mdot
.5147 .58021 Mdot
.58745 .25617 Mdot
.68782 .50435 Mdot
.45458 .61546 Mdot
.30737 .57314 Mdot
.27817 .29986 Mdot
.65915 .51298 Mdot
.31946 .46283 Mdot
.49791 .57402 Mdot
.5104 .64711 Mdot
.6819 .50123 Mdot
.40215 .38709 Mdot
.59685 .46448 Mdot
.67005 .46397 Mdot
.56616 .37188 Mdot
.67877 .46153 Mdot
.50928 .69305 Mdot
.38376 .40568 Mdot
.47565 .36654 Mdot
.47442 .37316 Mdot
.29969 .66051 Mdot
.52808 .62309 Mdot
.678 .31761 Mdot
.40841 .40138 Mdot
.66458 .50281 Mdot
.56273 .33714 Mdot
.43666 .60741 Mdot
.66909 .52565 Mdot
.5746 .32368 Mdot
.27937 .5877 Mdot
.44088 .30656 Mdot
.68471 .46949 Mdot
.6043 .26976 Mdot
.60057 .31816 Mdot
.58601 .36524 Mdot
.67464 .2432 Mdot
.69074 .4972 Mdot
.28138 .57662 Mdot
.57652 .3299 Mdot
.40121 .7426 Mdot
.53757 .55798 Mdot
.32087 .61257 Mdot
.15123 .50142 Mdot
.66112 .24559 Mdot
.45529 .25755 Mdot
.29242 .53744 Mdot
.59676 .35434 Mdot
.46357 .61814 Mdot
.68963 .48279 Mdot
.68587 .48675 Mdot
.51826 .65563 Mdot
.47918 .64227 Mdot
.53356 .60128 Mdot
.45658 .60877 Mdot
.50444 .79378 Mdot
.52104 .577 Mdot
.2246 .64431 Mdot
.65373 .50711 Mdot
.47037 .64369 Mdot
.34686 .38697 Mdot
.47123 .57146 Mdot
.55096 .35165 Mdot
.50148 .63984 Mdot
.48644 .64551 Mdot
.45841 .63805 Mdot
.59128 .32324 Mdot
.65473 .80001 Mdot
.1663 .44418 Mdot
.76949 .65877 Mdot
.35229 .44018 Mdot
.40913 .41385 Mdot
.52878 .6301 Mdot
.28093 .56069 Mdot
.6913 .70855 Mdot
.48536 .59673 Mdot
.41146 .15783 Mdot
.49403 .65299 Mdot
.76815 .49057 Mdot
.43301 .68765 Mdot
.78366 .64153 Mdot
.24719 .61666 Mdot
.46225 .6031 Mdot
.64807 .59096 Mdot
.77105 .55118 Mdot
.57051 .27427 Mdot
.56108 .35355 Mdot
.35261 .38596 Mdot
.3466 .40536 Mdot
.56612 .28866 Mdot
.49334 .53095 Mdot
.44228 .57269 Mdot
.4553 .56925 Mdot
.45592 .39289 Mdot
.71135 .4676 Mdot
.25981 .55875 Mdot
.64896 .53401 Mdot
.22742 .71911 Mdot
.60101 .25018 Mdot
.61995 .35009 Mdot
.27349 .59274 Mdot
.37286 .3893 Mdot
.44915 .40116 Mdot
.27471 .56239 Mdot
.5103 .59307 Mdot
.69583 .50279 Mdot
.78928 .36869 Mdot
.44011 .56192 Mdot
.78045 .33022 Mdot
.70101 .51627 Mdot
.5849 .45617 Mdot
.56413 .32558 Mdot
.36849 .42698 Mdot
.5081 .64977 Mdot
.51416 .60719 Mdot
.63094 .46806 Mdot
.52938 .59854 Mdot
.73103 .5329 Mdot
.50955 .65353 Mdot
.48735 .32384 Mdot
.25872 .58792 Mdot
.56314 .28941 Mdot
.28825 .65654 Mdot
.64988 .52573 Mdot
.25598 .60808 Mdot
.36652 .38139 Mdot
.65506 .74226 Mdot
.54481 .33525 Mdot
.30212 .57984 Mdot
.39398 .38176 Mdot
.26321 .55177 Mdot
.48931 .56343 Mdot
.42691 .40911 Mdot
.30547 .55616 Mdot
.57491 .81277 Mdot
.5036 .55935 Mdot
.49144 .80077 Mdot
.58286 .31476 Mdot
.68302 .46315 Mdot
.47607 .65926 Mdot
.35093 .42902 Mdot
.53242 .67434 Mdot
.43247 .23138 Mdot
.48028 .36632 Mdot
.4237 .4223 Mdot
.31269 .49792 Mdot
.30206 .57606 Mdot
.3799 .25794 Mdot
.66563 .29281 Mdot
.70317 .4904 Mdot
.55274 .61202 Mdot
.74693 .71129 Mdot
.57578 .32996 Mdot
.50571 .59005 Mdot
.4665 .34625 Mdot
.57642 .33261 Mdot
.50771 .63262 Mdot
.57877 .30666 Mdot
.68964 .48877 Mdot
.22953 .40295 Mdot
.70421 .48812 Mdot
.51702 .56248 Mdot
.55263 .30849 Mdot
.43486 .39724 Mdot
.67041 .47991 Mdot
.51734 .58393 Mdot
.52573 .64299 Mdot
.4651 .37859 Mdot
.46467 .63852 Mdot
.71166 .73941 Mdot
.4628 .64113 Mdot
.33986 .39792 Mdot
.4958 .66955 Mdot
.50649 .16002 Mdot
.38334 .32399 Mdot
.6952 .50875 Mdot
.41943 .42358 Mdot
.36265 .40897 Mdot
.26106 .4316 Mdot
.44399 .41743 Mdot
.49617 .57885 Mdot
.39683 .42597 Mdot
.33911 .59353 Mdot
.58694 .34959 Mdot
.54235 .64041 Mdot
.6282 .35489 Mdot
.31877 .40316 Mdot
.45359 .39463 Mdot
.43617 .66314 Mdot
.66587 .54154 Mdot
.48492 .63978 Mdot
.43946 .39074 Mdot
.664 .45999 Mdot
.52025 .5662 Mdot
.39892 .59415 Mdot
.47139 .37892 Mdot
.58622 .32467 Mdot
.43782 .68473 Mdot
.5326 .58808 Mdot
.3661 .41968 Mdot
.66858 .53269 Mdot
.54038 .35632 Mdot
.66394 .48848 Mdot
.79329 .47629 Mdot
.52536 .27335 Mdot
.54501 .79655 Mdot
.32549 .56587 Mdot
.48454 .23259 Mdot
.8002 .61349 Mdot
.33107 .27772 Mdot
.3758 .68955 Mdot
.82173 .47848 Mdot
.40037 .38452 Mdot
.47696 .32524 Mdot
.3569 .40973 Mdot
.47264 .61083 Mdot
.39027 .41106 Mdot
.79558 .62942 Mdot
.50525 .65486 Mdot
.3929 .41785 Mdot
.23629 .42089 Mdot
.47826 .64722 Mdot
.65949 .51526 Mdot
.55617 .85719 Mdot
.37868 .21524 Mdot
.61627 .24319 Mdot
.42107 .40285 Mdot
.47523 .72453 Mdot
.48382 .65713 Mdot
.45738 .64283 Mdot
.67654 .47417 Mdot
.51933 .66052 Mdot
.26186 .55599 Mdot
.26847 .58926 Mdot
.39344 .53352 Mdot
.17504 .46365 Mdot
.54426 .53534 Mdot
.67192 .47813 Mdot
.5162 .76324 Mdot
.42807 .20676 Mdot
.32097 .43124 Mdot
.55809 .37853 Mdot
.6323 .80836 Mdot
.46731 .54259 Mdot
.57124 .38662 Mdot
.62306 .30067 Mdot
.67497 .51209 Mdot
.66881 .78534 Mdot
.56813 .3523 Mdot
.68633 .6071 Mdot
.59696 .62869 Mdot
.51006 .60095 Mdot
.54925 .32557 Mdot
.55276 .54408 Mdot
.4714 .17415 Mdot
.4097 .76924 Mdot
.21196 .62062 Mdot
.53326 .56864 Mdot
.36829 .24745 Mdot
.5043 .6446 Mdot
.59929 .47747 Mdot
.46467 .64535 Mdot
.65819 .48844 Mdot
.55751 .51114 Mdot
.49172 .41532 Mdot
.15891 .50171 Mdot
.60449 .25126 Mdot
.29111 .53739 Mdot
.51613 .64771 Mdot
.5096 .60214 Mdot
.27789 .58219 Mdot
.6418 .50115 Mdot
.45764 .6082 Mdot
.35923 .60085 Mdot
.5264 .60624 Mdot
.56288 .35671 Mdot
.26972 .66689 Mdot
.61779 .51949 Mdot
.48138 .67345 Mdot
.64856 .46476 Mdot
.59004 .33002 Mdot
.54591 .35558 Mdot
.4384 .6603 Mdot
.5424 .36426 Mdot
.49349 .64923 Mdot
.32825 .74199 Mdot
.64761 .48125 Mdot
.41367 .62736 Mdot
.64491 .51534 Mdot
.60274 .75222 Mdot
.54286 .31581 Mdot
.48177 .35386 Mdot
.60265 .55074 Mdot
.56489 .35104 Mdot
.63714 .25929 Mdot
.47641 .5507 Mdot
.52904 .66604 Mdot
.54029 .19995 Mdot
.4234 .39892 Mdot
.46699 .38225 Mdot
.53476 .33328 Mdot
.53425 .59072 Mdot
.5284 .65739 Mdot
.59309 .33326 Mdot
.63634 .63941 Mdot
.27625 .40828 Mdot
.4896 .65886 Mdot
.65173 .49033 Mdot
.66394 .50077 Mdot
.53897 .58001 Mdot
.50688 .58231 Mdot
.37767 .39283 Mdot
.41879 .42252 Mdot
.34663 .43063 Mdot
.47034 .3791 Mdot
.48079 .34423 Mdot
.73442 .40727 Mdot
.58058 .36794 Mdot
.70123 .34237 Mdot
.49272 .19571 Mdot
.5749 .58955 Mdot
.41478 .41409 Mdot
.50438 .6085 Mdot
.48963 .64044 Mdot
.54021 .35661 Mdot
.53203 .25925 Mdot
.52003 .69362 Mdot
.6634 .46969 Mdot
.53359 .33371 Mdot
.50243 .53647 Mdot
.74397 .37344 Mdot
.29922 .55183 Mdot
.60307 .22625 Mdot
.54374 .34139 Mdot
.67326 .51605 Mdot
.57341 .30094 Mdot
.51606 .60516 Mdot
.55622 .57831 Mdot
.67593 .50547 Mdot
.30967 .56101 Mdot
.4638 .56691 Mdot
.50953 .63458 Mdot
.2232 .29908 Mdot
.38536 .2263 Mdot
.51747 .38387 Mdot
.46084 .613 Mdot
.5155 .66892 Mdot
.26875 .54215 Mdot
.5224 .60513 Mdot
.53299 .63754 Mdot
.24428 .32928 Mdot
.56698 .40786 Mdot
.26404 .53998 Mdot
.69068 .61051 Mdot
.70352 .51334 Mdot
.70803 .7602 Mdot
.36619 .42862 Mdot
.53246 .31158 Mdot
.26774 .36593 Mdot
.44133 .40805 Mdot
.44726 .22715 Mdot
.69055 .77601 Mdot
.46848 .3812 Mdot
.34544 .55297 Mdot
.5793 .61342 Mdot
.50214 .65964 Mdot
.5096 .64376 Mdot
.28244 .56627 Mdot
.69148 .49441 Mdot
.41927 .50617 Mdot
.42369 .79831 Mdot
.49746 .6413 Mdot
.72476 .53408 Mdot
.57972 .82027 Mdot
.45821 .38717 Mdot
.26423 .55643 Mdot
.30486 .58343 Mdot
.51627 .64568 Mdot
.25187 .33728 Mdot
.67402 .48128 Mdot
.51664 .58365 Mdot
.51244 .5714 Mdot
.42339 .40391 Mdot
.6879 .51082 Mdot
.40857 .38502 Mdot
.48558 .35606 Mdot
.78769 .55289 Mdot
.2418 .27026 Mdot
.53664 .34155 Mdot
.70361 .73254 Mdot
.57952 .35741 Mdot
.21536 .6009 Mdot
.43999 .41084 Mdot
.48613 .59064 Mdot
.66041 .53221 Mdot
.51776 .58173 Mdot
.49819 .59379 Mdot
.50944 .59386 Mdot
.51067 .54093 Mdot
.43337 .15568 Mdot
.27935 .55215 Mdot
.4734 .67348 Mdot
.34386 .39669 Mdot
.70119 .74009 Mdot
.45143 .82976 Mdot
.51082 .61311 Mdot
.52763 .63895 Mdot
.66089 .51938 Mdot
.52114 .655 Mdot
.58716 .34743 Mdot
.66986 .53308 Mdot
.45364 .61342 Mdot
.65587 .78378 Mdot
.46856 .59113 Mdot
.78271 .63274 Mdot
.57278 .3004 Mdot
.63633 .26229 Mdot
.45416 .64898 Mdot
.47717 .36762 Mdot
.46704 .3823 Mdot
.3777 .43029 Mdot
.53957 .3101 Mdot
.37885 .41942 Mdot
.36984 .78213 Mdot
.56727 .61283 Mdot
.46538 .62187 Mdot
.53358 .65281 Mdot
.40714 .41973 Mdot
.62634 .42572 Mdot
.40102 .26327 Mdot
.48631 .54062 Mdot
.39048 .39729 Mdot
.67591 .46016 Mdot
.35902 .5102 Mdot
.65645 .52835 Mdot
.25078 .55415 Mdot
.55637 .32354 Mdot
.28941 .54362 Mdot
.64904 .24598 Mdot
.68572 .50391 Mdot
.62912 .46932 Mdot
.40569 .41522 Mdot
.56591 .43995 Mdot
.88419 .50787 Mdot
.44101 .38348 Mdot
.3254 .64048 Mdot
.6682 .4744 Mdot
.49723 .56933 Mdot
.24987 .63041 Mdot
.57557 .44029 Mdot
.37705 .41742 Mdot
.47987 .60346 Mdot
.23809 .37058 Mdot
.38014 .39293 Mdot
.54571 .63656 Mdot
.40054 .38886 Mdot
.54912 .3449 Mdot
.40837 .39708 Mdot
.71238 .50781 Mdot
.5368 .61911 Mdot
.88231 .52558 Mdot
.23794 .5988 Mdot
.4622 .6379 Mdot
.53452 .3294 Mdot
.39537 .55781 Mdot
.49566 .60459 Mdot
.25909 .57588 Mdot
.38665 .40425 Mdot
.34073 .36567 Mdot
.48144 .65808 Mdot
.40761 .40959 Mdot
.63485 .50674 Mdot
.54187 .30726 Mdot
.26269 .52265 Mdot
.4751 .36221 Mdot
.68171 .47487 Mdot
.50124 .31702 Mdot
.52881 .33651 Mdot
.51336 .66822 Mdot
.52435 .57771 Mdot
.65376 .49683 Mdot
.19936 .45437 Mdot
.48839 .66778 Mdot
.48381 .58896 Mdot
.34533 .39244 Mdot
.38478 .42302 Mdot
.20693 .44866 Mdot
.40911 .38829 Mdot
.56073 .58175 Mdot
.65471 .49566 Mdot
.48294 .62947 Mdot
.66856 .52057 Mdot
.53907 .6339 Mdot
.72854 .50361 Mdot
.64071 .4893 Mdot
.35044 .28737 Mdot
.47956 .61597 Mdot
.43193 .68257 Mdot
.50388 .59373 Mdot
.52945 .60172 Mdot
.36669 .39395 Mdot
.26648 .56113 Mdot
.43671 .63265 Mdot
.29892 .5259 Mdot
.26019 .57166 Mdot
.76996 .53016 Mdot
.42216 .4012 Mdot
.29261 .56905 Mdot
.51453 .80867 Mdot
.41057 .42507 Mdot
.28701 .55758 Mdot
.48041 .83438 Mdot
.53695 .34619 Mdot
.7097 .49797 Mdot
.47778 .64618 Mdot
.81698 .46836 Mdot
.34543 .73964 Mdot
.43825 .40787 Mdot
.46067 .63554 Mdot
.50141 .60825 Mdot
.6493 .4731 Mdot
.19904 .64812 Mdot
.32843 .40457 Mdot
.4712 .61631 Mdot
.69281 .5133 Mdot
.14791 .57025 Mdot
.33804 .40332 Mdot
.28467 .56044 Mdot
.59387 .32701 Mdot
.70724 .53316 Mdot
.46651 .37317 Mdot
.59481 .33299 Mdot
.37128 .29105 Mdot
.63546 .24931 Mdot
.49858 .57368 Mdot
.41414 .4147 Mdot
.63517 .22163 Mdot
.52741 .52716 Mdot
.50744 .34719 Mdot
.52268 .7068 Mdot
.67184 .51318 Mdot
.58818 .34289 Mdot
.28961 .54069 Mdot
.69145 .52876 Mdot
.64405 .49565 Mdot
.54842 .36206 Mdot
.35151 .53842 Mdot
.58312 .45309 Mdot
.55742 .35823 Mdot
.52041 .19755 Mdot
.79029 .43374 Mdot
.40762 .42445 Mdot
.26314 .57435 Mdot
.76919 .352 Mdot
.67292 .48748 Mdot
.6361 .80627 Mdot
.60601 .21877 Mdot
.49372 .65641 Mdot
.29316 .57356 Mdot
.67352 .41019 Mdot
.39839 .79555 Mdot
.57852 .33365 Mdot
.50202 .40462 Mdot
.31589 .56503 Mdot
.49412 .66256 Mdot
.52009 .72146 Mdot
.47525 .60342 Mdot
.56267 .32272 Mdot
.55058 .7635 Mdot
.67308 .51685 Mdot
.5313 .33843 Mdot
.60447 .22683 Mdot
.4949 .64639 Mdot
.47828 .60743 Mdot
.30838 .68638 Mdot
.69914 .49502 Mdot
.35198 .42972 Mdot
.49689 .57617 Mdot
.50607 .63716 Mdot
.52198 .67467 Mdot
.42072 .64782 Mdot
.27211 .30796 Mdot
.47242 .61573 Mdot
.49722 .30243 Mdot
.47822 .67313 Mdot
.4818 .61685 Mdot
.65193 .46384 Mdot
.2849 .23593 Mdot
.48357 .35098 Mdot
.50323 .63967 Mdot
.48979 .57476 Mdot
.54523 .36112 Mdot
.53747 .48579 Mdot
.57279 .4352 Mdot
.45491 .37639 Mdot
.39884 .71148 Mdot
.51316 .54092 Mdot
.6775 .52719 Mdot
.30725 .57629 Mdot
.53708 .58173 Mdot
.67926 .52583 Mdot
.4616 .58811 Mdot
.38686 .39404 Mdot
.41349 .42316 Mdot
.62793 .27106 Mdot
.29184 .56206 Mdot
.32766 .72139 Mdot
.69695 .35345 Mdot
.35368 .38694 Mdot
.4676 .62791 Mdot
.55969 .29269 Mdot
.44501 .39248 Mdot
.46775 .37475 Mdot
.45054 .67905 Mdot
.68367 .48259 Mdot
.65949 .51059 Mdot
.31987 .6117 Mdot
.44946 .28392 Mdot
.21583 .33333 Mdot
.54823 .3414 Mdot
.45142 .61753 Mdot
.66799 .30285 Mdot
.65955 .51197 Mdot
.27058 .63013 Mdot
.29447 .56792 Mdot
.58012 .33323 Mdot
.32637 .43271 Mdot
.66853 .52422 Mdot
.69307 .4748 Mdot
.50927 .56098 Mdot
.51428 .62488 Mdot
.36778 .67677 Mdot
.36074 .57472 Mdot
.59069 .33364 Mdot
.27174 .58063 Mdot
.40587 .38292 Mdot
.47096 .6049 Mdot
.63584 .49784 Mdot
.78987 .38895 Mdot
.49394 .57273 Mdot
.37314 .39199 Mdot
.67007 .51077 Mdot
.28575 .58343 Mdot
.25871 .57177 Mdot
.52851 .60234 Mdot
.53364 .75003 Mdot
.57908 .34363 Mdot
.66101 .51537 Mdot
.73155 .32832 Mdot
.48938 .6699 Mdot
.51814 .62724 Mdot
.46692 .70462 Mdot
.5624 .36582 Mdot
.64007 .27023 Mdot
.31183 .55818 Mdot
.68155 .49216 Mdot
.46438 .59772 Mdot
.29493 .55561 Mdot
.65389 .28066 Mdot
.43162 .41406 Mdot
.40505 .39346 Mdot
.25848 .57439 Mdot
.28336 .58014 Mdot
.26874 .58327 Mdot
.62258 .81561 Mdot
.71355 .50795 Mdot
.41044 .62796 Mdot
.47592 .66339 Mdot
.30857 .61716 Mdot
.4397 .59845 Mdot
.57143 .29873 Mdot
.42267 .3963 Mdot
.50069 .59608 Mdot
.51634 .56309 Mdot
.44759 .69474 Mdot
.41775 .6572 Mdot
.62083 .52428 Mdot
.68819 .50652 Mdot
.57071 .61148 Mdot
.42698 .40296 Mdot
.20968 .69598 Mdot
.83702 .58288 Mdot
.4552 .65547 Mdot
.57165 .46005 Mdot
.63719 .50071 Mdot
.5627 .36874 Mdot
.54494 .42287 Mdot
.57223 .30257 Mdot
.67547 .49521 Mdot
.4713 .60788 Mdot
.70744 .34986 Mdot
.2555 .56136 Mdot
.53569 .5961 Mdot
.56958 .32678 Mdot
.53499 .59859 Mdot
.59433 .33138 Mdot
.76924 .4619 Mdot
.48349 .18544 Mdot
.4944 .65343 Mdot
.49839 .67576 Mdot
.50174 .71567 Mdot
.5092 .61436 Mdot
.21641 .52805 Mdot
.63961 .50431 Mdot
.19431 .41407 Mdot
.5044 .56069 Mdot
.66624 .69843 Mdot
.48234 .66839 Mdot
.24222 .37792 Mdot
.51934 .62214 Mdot
.47006 .44195 Mdot
.49599 .6597 Mdot
.5383 .62544 Mdot
.56133 .30416 Mdot
.54475 .36047 Mdot
.63002 .51327 Mdot
.35285 .4294 Mdot
.76131 .67575 Mdot
.51286 .63275 Mdot
.47233 .36215 Mdot
.51855 .37668 Mdot
.27649 .57988 Mdot
.67434 .49348 Mdot
.15462 .58898 Mdot
.5868 .31459 Mdot
.3027 .42637 Mdot
.19234 .48239 Mdot
.46574 .37271 Mdot
.49105 .37957 Mdot
.58785 .50127 Mdot
.30457 .57133 Mdot
.49036 .66316 Mdot
.70996 .27949 Mdot
.39754 .22557 Mdot
.43305 .61031 Mdot
.5311 .32951 Mdot
.67097 .72478 Mdot
.77385 .36399 Mdot
.30566 .58564 Mdot
.29745 .54362 Mdot
.58797 .31997 Mdot
.31784 .4124 Mdot
.53733 .54837 Mdot
.29668 .56653 Mdot
.37893 .38584 Mdot
.39964 .42804 Mdot
.42188 .44165 Mdot
.67643 .48376 Mdot
.60731 .23281 Mdot
.67436 .38009 Mdot
.5917 .3278 Mdot
.26957 .60881 Mdot
.70125 .53716 Mdot
.69033 .53675 Mdot
.38667 .42632 Mdot
.36223 .39375 Mdot
.70637 .51803 Mdot
.55554 .56839 Mdot
.43437 .69542 Mdot
.50015 .64189 Mdot
.27767 .56917 Mdot
.51695 .61654 Mdot
.37711 .39534 Mdot
.57279 .33587 Mdot
.35474 .39779 Mdot
.58034 .30973 Mdot
.73177 .3957 Mdot
.51783 .58835 Mdot
.53467 .62923 Mdot
.33803 .7374 Mdot
.63044 .50142 Mdot
.683 .27238 Mdot
.48633 .32183 Mdot
.35209 .40834 Mdot
.53024 .64169 Mdot
.64371 .51943 Mdot
.2746 .59672 Mdot
.33256 .73586 Mdot
.53714 .58904 Mdot
.63974 .50665 Mdot
.46787 .61658 Mdot
.54009 .80999 Mdot
.35913 .22525 Mdot
.66229 .49223 Mdot
.15898 .52493 Mdot
.47022 .59607 Mdot
.55876 .51819 Mdot
.54848 .63566 Mdot
.35387 .61877 Mdot
.49067 .66845 Mdot
.70104 .51646 Mdot
.49896 .63662 Mdot
.68614 .53032 Mdot
.33752 .39442 Mdot
.57781 .36719 Mdot
.66827 .47195 Mdot
.52334 .57501 Mdot
.71574 .78035 Mdot
.55641 .32666 Mdot
.51206 .64887 Mdot
.56369 .31205 Mdot
.69499 .5158 Mdot
.69119 .47552 Mdot
.40108 .80654 Mdot
.53986 .39692 Mdot
.55014 .34621 Mdot
.47323 .62357 Mdot
.64431 .3702 Mdot
.47892 .62249 Mdot
.35197 .66622 Mdot
.54779 .5817 Mdot
.49343 .66947 Mdot
.39345 .82353 Mdot
.58726 .35072 Mdot
.22487 .32921 Mdot
.43735 .80037 Mdot
.60682 .82214 Mdot
.71908 .51403 Mdot
.30466 .58609 Mdot
.66468 .78869 Mdot
.4845 .35873 Mdot
.39989 .40147 Mdot
.50224 .59618 Mdot
.61187 .52355 Mdot
.57809 .35199 Mdot
.26779 .56131 Mdot
.4955 .6534 Mdot
.36379 .3924 Mdot
.29066 .42638 Mdot
.58811 .36587 Mdot
.67414 .48838 Mdot
.6552 .47333 Mdot
.14488 .52775 Mdot
.46234 .60034 Mdot
.53106 .63749 Mdot
.56052 .32203 Mdot
.43748 .57011 Mdot
.29931 .58062 Mdot
.25345 .39605 Mdot
.55004 .34485 Mdot
.53425 .45349 Mdot
.6919 .50124 Mdot
.50271 .60774 Mdot
.63673 .4294 Mdot
.37319 .44381 Mdot
.72706 .58588 Mdot
.28044 .56358 Mdot
.3502 .67441 Mdot
.70159 .51583 Mdot
.56581 .33386 Mdot
.44883 .3108 Mdot
.51942 .68363 Mdot
.50094 .61406 Mdot
.34612 .67556 Mdot
.37713 .54245 Mdot
.21984 .62928 Mdot
.55093 .62103 Mdot
.38695 .53249 Mdot
.5475 .6208 Mdot
.52646 .67443 Mdot
.55679 .57519 Mdot
.52414 .62685 Mdot
.63878 .50449 Mdot
.42284 .62754 Mdot
.4079 .40473 Mdot
.62254 .62299 Mdot
.52212 .40918 Mdot
.47221 .65294 Mdot
.47419 .61148 Mdot
.74245 .60764 Mdot
.55762 .38862 Mdot
.6475 .48668 Mdot
.67554 .45155 Mdot
.54879 .3689 Mdot
.4366 .69146 Mdot
.34645 .42653 Mdot
.43001 .65448 Mdot
.36134 .39681 Mdot
.64247 .5144 Mdot
.34789 .40866 Mdot
.57833 .37158 Mdot
.41615 .414 Mdot
.48332 .33688 Mdot
.58499 .34777 Mdot
.69605 .48722 Mdot
.53191 .61063 Mdot
.53379 .33518 Mdot
.3126 .68601 Mdot
.27859 .56898 Mdot
.40389 .80855 Mdot
.46483 .58811 Mdot
.55027 .40977 Mdot
.39806 .59501 Mdot
.35615 .39849 Mdot
.30778 .26208 Mdot
.64181 .4877 Mdot
.25087 .56776 Mdot
.6413 .51384 Mdot
.5553 .18847 Mdot
.26495 .56875 Mdot
.48854 .83546 Mdot
.47315 .27554 Mdot
.31861 .38532 Mdot
.55028 .56448 Mdot
.56207 .68188 Mdot
.44108 .38726 Mdot
.57952 .35069 Mdot
.46059 .27239 Mdot
.54036 .61967 Mdot
.33241 .27982 Mdot
.62798 .51084 Mdot
.38614 .42911 Mdot
.56177 .34011 Mdot
.53293 .34391 Mdot
.51327 .57713 Mdot
.23017 .4532 Mdot
.54633 .60627 Mdot
.43562 .28331 Mdot
.38131 .70164 Mdot
.46818 .70945 Mdot
.5109 .65276 Mdot
.33999 .41272 Mdot
.46824 .61784 Mdot
.43719 .71045 Mdot
.68004 .24907 Mdot
.49423 .54662 Mdot
.51439 .27207 Mdot
.27598 .60748 Mdot
.68023 .50398 Mdot
.44899 .63808 Mdot
.46913 .37099 Mdot
.46405 .60416 Mdot
.62923 .17434 Mdot
.28919 .55655 Mdot
.43679 .36567 Mdot
.48364 .67264 Mdot
.50579 .57627 Mdot
.5993 .59797 Mdot
.60776 .52717 Mdot
.32566 .43335 Mdot
.50129 .62092 Mdot
.39815 .72958 Mdot
.55077 .3211 Mdot
.5457 .60137 Mdot
.5109 .64508 Mdot
.77588 .54005 Mdot
.55275 .36168 Mdot
.34911 .40115 Mdot
.44261 .41021 Mdot
.38882 .37998 Mdot
.29277 .53212 Mdot
.51638 .42399 Mdot
.29432 .62467 Mdot
.3716 .22467 Mdot
.28987 .5903 Mdot
.47819 .58021 Mdot
.53684 .68604 Mdot
.48335 .58253 Mdot
.28974 .53949 Mdot
.56084 .36434 Mdot
.6488 .48337 Mdot
.63525 .29223 Mdot
.45792 .38974 Mdot
.54178 .64163 Mdot
.26855 .54755 Mdot
.68783 .48231 Mdot
.23744 .58233 Mdot
.68172 .49811 Mdot
.55546 .34781 Mdot
.52949 .35608 Mdot
.27301 .55042 Mdot
.65249 .52519 Mdot
.50022 .30607 Mdot
.41447 .79249 Mdot
.55118 .58336 Mdot
.53443 .29346 Mdot
.6357 .51307 Mdot
.62914 .53218 Mdot
.64063 .5309 Mdot
.52687 .59629 Mdot
.56743 .46558 Mdot
.50424 .68412 Mdot
.58892 .32955 Mdot
.39579 .38863 Mdot
.35197 .58645 Mdot
.77721 .41593 Mdot
.34344 .57976 Mdot
.45675 .57715 Mdot
.49435 .64255 Mdot
.51585 .64585 Mdot
.53816 .56691 Mdot
.43116 .30244 Mdot
.51082 .58419 Mdot
.56539 .30422 Mdot
.37551 .40061 Mdot
.47317 .65809 Mdot
.43369 .41076 Mdot
.59532 .4518 Mdot
.30705 .57798 Mdot
.50835 .41771 Mdot
.72688 .74783 Mdot
.68519 .47925 Mdot
.41541 .3888 Mdot
.40114 .40308 Mdot
.28039 .58778 Mdot
.57538 .35229 Mdot
.68772 .49689 Mdot
.36285 .62462 Mdot
.26987 .58212 Mdot
.50162 .6372 Mdot
.31445 .32759 Mdot
.30719 .31364 Mdot
.50279 .66377 Mdot
.49106 .59704 Mdot
.42521 .42135 Mdot
.32021 .41156 Mdot
.80269 .35215 Mdot
.24859 .63857 Mdot
.26906 .55503 Mdot
.30839 .55882 Mdot
.67291 .54054 Mdot
.47035 .67689 Mdot
.58741 .32634 Mdot
.27651 .67695 Mdot
.3885 .55661 Mdot
.30941 .70885 Mdot
.26734 .51934 Mdot
.52633 .58243 Mdot
.56843 .70128 Mdot
.49337 .64752 Mdot
.64184 .48212 Mdot
.69905 .50547 Mdot
.66017 .47949 Mdot
.58175 .34456 Mdot
.61556 .74979 Mdot
.55176 .30984 Mdot
.76341 .70292 Mdot
.70238 .51741 Mdot
.41417 .32932 Mdot
.3552 .4172 Mdot
.4505 .6336 Mdot
.29469 .58139 Mdot
.60535 .34177 Mdot
.51519 .54722 Mdot
.25855 .32385 Mdot
.40979 .41576 Mdot
.69817 .48879 Mdot
.58765 .50479 Mdot
.81294 .57023 Mdot
.5541 .43557 Mdot
.56065 .5347 Mdot
.58828 .63582 Mdot
.27128 .57868 Mdot
.72178 .58713 Mdot
.29533 .53685 Mdot
.57651 .32755 Mdot
.53491 .62405 Mdot
.53088 .61946 Mdot
.54149 .63122 Mdot
.51268 .58597 Mdot
.54744 .36527 Mdot
.44727 .59382 Mdot
.50649 .16003 Mdot
.41327 .42409 Mdot
.5625 .80929 Mdot
.30095 .55794 Mdot
.53657 .31607 Mdot
.37246 .3995 Mdot
.33949 .4312 Mdot
.28082 .6468 Mdot
.49279 .65877 Mdot
.50175 .59433 Mdot
.3157 .43235 Mdot
.54852 .62703 Mdot
.49037 .5414 Mdot
.40606 .40707 Mdot
.34558 .57786 Mdot
.28172 .59306 Mdot
.29134 .54467 Mdot
.55772 .36162 Mdot
.64737 .52118 Mdot
.28742 .56879 Mdot
.33802 .39571 Mdot
.45805 .58713 Mdot
.51408 .56942 Mdot
.63515 .51369 Mdot
.60361 .21668 Mdot
.30983 .58088 Mdot
.5852 .50042 Mdot
.6858 .52787 Mdot
.71455 .5064 Mdot
.49941 .61442 Mdot
.43047 .61276 Mdot
.64895 .54582 Mdot
.26728 .58586 Mdot
.53235 .32145 Mdot
.38386 .36564 Mdot
.57185 .32292 Mdot
.69097 .49147 Mdot
.52659 .57005 Mdot
.69594 .49392 Mdot
.45957 .61484 Mdot
.55254 .8885 Mdot
.5265 .62138 Mdot
.40865 .19749 Mdot
.3429 .63217 Mdot
.39654 .4063 Mdot
.49868 .31058 Mdot
.3875 .42721 Mdot
.69132 .52503 Mdot
.5299 .57508 Mdot
.30902 .55335 Mdot
.55662 .84259 Mdot
.69478 .54084 Mdot
.39424 .39444 Mdot
.33045 .42293 Mdot
.58294 .35366 Mdot
.46997 .65656 Mdot
.5043 .61129 Mdot
.39174 .41946 Mdot
.40267 .67024 Mdot
.66107 .52364 Mdot
.52609 .64194 Mdot
.48834 .6306 Mdot
.39933 .40768 Mdot
.40873 .7885 Mdot
.59695 .53385 Mdot
.5299 .62835 Mdot
.45608 .33486 Mdot
.56404 .2994 Mdot
.54321 .56395 Mdot
.44556 .59572 Mdot
.29273 .57697 Mdot
.61596 .78939 Mdot
.69746 .2608 Mdot
.5783 .29978 Mdot
.35779 .42895 Mdot
.4638 .59401 Mdot
.35886 .41822 Mdot
.51756 .57156 Mdot
.72299 .70296 Mdot
.39754 .42726 Mdot
.49503 .58294 Mdot
.45856 .66629 Mdot
.7008 .49916 Mdot
.50962 .5814 Mdot
.75874 .58477 Mdot
.4307 .38706 Mdot
.50158 .58104 Mdot
.53854 .74664 Mdot
.54426 .35105 Mdot
.45334 .65308 Mdot
.30156 .55218 Mdot
.35852 .61336 Mdot
.69814 .36536 Mdot
.46576 .35381 Mdot
.29327 .54713 Mdot
.53836 .6009 Mdot
.31552 .41632 Mdot
.59271 .3273 Mdot
.32575 .27831 Mdot
.52775 .64643 Mdot
.56144 .32364 Mdot
.57069 .33686 Mdot
.29062 .55088 Mdot
.18544 .37948 Mdot
.44616 .60359 Mdot
.5116 .61391 Mdot
.7692 .57829 Mdot
.66069 .46452 Mdot
.52063 .61517 Mdot
.48946 .57343 Mdot
.56565 .30574 Mdot
.60351 .55016 Mdot
.70844 .67633 Mdot
.23695 .41825 Mdot
.59345 .31322 Mdot
.39068 .37611 Mdot
.31468 .4179 Mdot
.30083 .56066 Mdot
.67239 .50494 Mdot
.31553 .55239 Mdot
.41801 .40375 Mdot
.47551 .58441 Mdot
.57951 .31283 Mdot
.74942 .53669 Mdot
.59687 .33647 Mdot
.4602 .36214 Mdot
.63194 .49179 Mdot
.66208 .31317 Mdot
.55155 .14287 Mdot
.68281 .38515 Mdot
.58581 .3839 Mdot
.27682 .57989 Mdot
.36581 .29409 Mdot
.49024 .63473 Mdot
.69994 .59262 Mdot
.53269 .60607 Mdot
.55323 .73157 Mdot
.40739 .3888 Mdot
.33638 .42907 Mdot
.53296 .62519 Mdot
.37007 .69223 Mdot
.5972 .34456 Mdot
.5875 .3486 Mdot
.49973 .58609 Mdot
.56445 .35129 Mdot
.51097 .62497 Mdot
.36793 .39498 Mdot
.25429 .29359 Mdot
.50087 .64728 Mdot
.52325 .67064 Mdot
.62209 .35279 Mdot
.42046 .81766 Mdot
.4867 .28806 Mdot
.57287 .69185 Mdot
.81497 .54006 Mdot
.56463 .35066 Mdot
.45777 .67761 Mdot
.44828 .38408 Mdot
.42687 .42055 Mdot
.50015 .3078 Mdot
.52392 .60897 Mdot
.52233 .60392 Mdot
.52796 .64356 Mdot
.47773 .60656 Mdot
.70505 .59357 Mdot
.42966 .58844 Mdot
.5897 .71481 Mdot
.49962 .59311 Mdot
.52354 .72182 Mdot
.53508 .33381 Mdot
.62825 .47457 Mdot
.3184 .55716 Mdot
.52465 .5816 Mdot
.67254 .55615 Mdot
.55604 .30168 Mdot
.76562 .70009 Mdot
.57041 .36152 Mdot
.36431 .40933 Mdot
.57362 .36664 Mdot
.46238 .63355 Mdot
.66317 .50107 Mdot
.44964 .3769 Mdot
.38964 .25174 Mdot
.39893 .40071 Mdot
.46221 .63804 Mdot
.42372 .36382 Mdot
.4035 .40148 Mdot
.6021 .43695 Mdot
.66407 .50535 Mdot
.39101 .73034 Mdot
.69937 .50558 Mdot
.49631 .58099 Mdot
.49002 .58366 Mdot
.51144 .30245 Mdot
.5892 .36007 Mdot
.69787 .51299 Mdot
.21286 .31068 Mdot
.29755 .53648 Mdot
.6613 .48127 Mdot
.54951 .65707 Mdot
.47107 .49137 Mdot
.65626 .50152 Mdot
.38877 .66925 Mdot
.58316 .34719 Mdot
.69726 .52707 Mdot
.5433 .66486 Mdot
.53328 .22353 Mdot
.25378 .57099 Mdot
.3298 .41296 Mdot
.4485 .45711 Mdot
.43649 .38933 Mdot
.52853 .32614 Mdot
.405 .41905 Mdot
.54768 .32216 Mdot
.67489 .2717 Mdot
.48445 .7478 Mdot
.56229 .29117 Mdot
.52687 .34176 Mdot
.40555 .41418 Mdot
.51426 .65355 Mdot
.46928 .41543 Mdot
.55653 .60733 Mdot
.52426 .55086 Mdot
.54338 .32969 Mdot
.70271 .5121 Mdot
.70971 .49412 Mdot
.53663 .70938 Mdot
.65492 .47309 Mdot
.36126 .39564 Mdot
.36364 .22392 Mdot
.65311 .24881 Mdot
.55169 .32495 Mdot
.5345 .35684 Mdot
.47735 .61924 Mdot
.3779 .41862 Mdot
.33368 .39456 Mdot
.58488 .33221 Mdot
.68197 .57924 Mdot
.4915 .68094 Mdot
.62408 .51298 Mdot
.70316 .51774 Mdot
.65777 .49375 Mdot
.65124 .53575 Mdot
.70402 .66235 Mdot
.58411 .34671 Mdot
.69764 .52146 Mdot
.49607 .58532 Mdot
.52211 .60548 Mdot
.47039 .37663 Mdot
.29353 .54545 Mdot
.45827 .59423 Mdot
.56236 .57898 Mdot
.49898 .61107 Mdot
.4049 .39456 Mdot
.5648 .64117 Mdot
.35539 .43029 Mdot
.32731 .40774 Mdot
.42571 .41455 Mdot
.48202 .35586 Mdot
.56973 .66535 Mdot
.82514 .53014 Mdot
.47097 .61605 Mdot
.43302 .56917 Mdot
.35676 .41626 Mdot
.28617 .28635 Mdot
.64474 .27691 Mdot
.52926 .6437 Mdot
.38868 .44627 Mdot
.39319 .42025 Mdot
.6719 .46577 Mdot
.52523 .61267 Mdot
.46182 .38968 Mdot
.3052 .57928 Mdot
.55784 .63995 Mdot
.45206 .40176 Mdot
.6607 .5293 Mdot
.32251 .54848 Mdot
.68847 .53308 Mdot
.42911 .40829 Mdot
.45714 .66334 Mdot
.88887 .49926 Mdot
.38555 .38034 Mdot
.49731 .81844 Mdot
.64042 .55266 Mdot
.5247 .64403 Mdot
.41662 .3879 Mdot
.6589 .46586 Mdot
.53222 .31835 Mdot
.43438 .50132 Mdot
.64819 .48115 Mdot
.33997 .4298 Mdot
.45309 .39846 Mdot
.40523 .40586 Mdot
.6849 .5093 Mdot
.54533 .58899 Mdot
.67826 .51815 Mdot
.57368 .36599 Mdot
.48402 .6432 Mdot
.79518 .62805 Mdot
.4305 .57652 Mdot
.69207 .52342 Mdot
.35201 .39349 Mdot
.26442 .54541 Mdot
.4884 .65369 Mdot
.4836 .80822 Mdot
.45534 .61717 Mdot
.55787 .31845 Mdot
.2255 .37602 Mdot
.74856 .54501 Mdot
.48058 .66586 Mdot
.47699 .61757 Mdot
.59087 .33914 Mdot
.49147 .65736 Mdot
.48596 .66648 Mdot
.51748 .3801 Mdot
.68942 .51151 Mdot
.4961 .63602 Mdot
.36074 .38764 Mdot
.71089 .28814 Mdot
.49825 .68271 Mdot
.32736 .46093 Mdot
.37931 .71565 Mdot
.20939 .38283 Mdot
.53579 .60876 Mdot
.2702 .65901 Mdot
.48135 .60223 Mdot
.53075 .59232 Mdot
.47608 .6249 Mdot
.58423 .67275 Mdot
.41348 .41156 Mdot
.38498 .39773 Mdot
.25523 .57426 Mdot
.38465 .71944 Mdot
.29425 .57385 Mdot
.57431 .3573 Mdot
.2925 .46793 Mdot
.40103 .42611 Mdot
.65948 .52957 Mdot
.54268 .6038 Mdot
.43189 .38498 Mdot
.50434 .60511 Mdot
.46106 .62699 Mdot
.33765 .41292 Mdot
.32884 .39567 Mdot
.46527 .3659 Mdot
.30875 .56521 Mdot
.66176 .47593 Mdot
.50092 .55899 Mdot
.26007 .57044 Mdot
.54376 .5882 Mdot
.29022 .61973 Mdot
.65657 .47947 Mdot
.68735 .51347 Mdot
.6963 .47316 Mdot
.47441 .5854 Mdot
.47 .64829 Mdot
.55059 .31122 Mdot
.65055 .52566 Mdot
.54977 .35433 Mdot
.4521 .37818 Mdot
.30219 .45587 Mdot
.52386 .60877 Mdot
.56643 .51102 Mdot
.29981 .57383 Mdot
.36475 .40488 Mdot
.31357 .43773 Mdot
.25227 .5613 Mdot
.45664 .61877 Mdot
.34189 .41405 Mdot
.28409 .54211 Mdot
.64473 .57787 Mdot
.83375 .48564 Mdot
.27302 .54049 Mdot
.4962 .58688 Mdot
.60812 .56671 Mdot
.3888 .7713 Mdot
.28793 .53346 Mdot
.57101 .31343 Mdot
.47403 .5849 Mdot
.405 .60276 Mdot
.31349 .57357 Mdot
.70915 .29513 Mdot
.39254 .40763 Mdot
.5507 .23829 Mdot
.56916 .56891 Mdot
.67057 .59842 Mdot
.31102 .54437 Mdot
.68476 .49452 Mdot
.64957 .4614 Mdot
.49145 .6132 Mdot
.29933 .53277 Mdot
.59556 .31879 Mdot
.38598 .40641 Mdot
.48696 .33267 Mdot
.68305 .51126 Mdot
.62996 .37143 Mdot
.38273 .3884 Mdot
.57836 .5007 Mdot
.23632 .39443 Mdot
.44214 .70486 Mdot
.52506 .73683 Mdot
.4239 .21835 Mdot
.48789 .57156 Mdot
.28654 .53713 Mdot
.55668 .30271 Mdot
.58596 .31668 Mdot
.55125 .34336 Mdot
.49701 .31418 Mdot
.53693 .42055 Mdot
.43573 .40082 Mdot
.35981 .26798 Mdot
.29534 .55688 Mdot
.41693 .74727 Mdot
.5417 .58863 Mdot
.49565 .64368 Mdot
.45126 .61556 Mdot
.54857 .60497 Mdot
.48351 .6099 Mdot
.5699 .35369 Mdot
.49699 .31113 Mdot
.34275 .36385 Mdot
.65026 .49248 Mdot
.34209 .57421 Mdot
.35476 .41702 Mdot
.42015 .42342 Mdot
.27488 .55437 Mdot
.59535 .47956 Mdot
.44236 .39866 Mdot
.34855 .4075 Mdot
.45203 .60282 Mdot
.67147 .52393 Mdot
.4269 .62711 Mdot
.48302 .59025 Mdot
.36525 .40178 Mdot
.3421 .50967 Mdot
.73603 .64021 Mdot
.48475 .69561 Mdot
.32004 .57832 Mdot
.55244 .47508 Mdot
.28752 .53396 Mdot
.54938 .63636 Mdot
.27483 .29726 Mdot
.41739 .40473 Mdot
.37243 .41326 Mdot
.28001 .54103 Mdot
.57279 .52357 Mdot
.67403 .51028 Mdot
.3297 .42873 Mdot
.55815 .31282 Mdot
.48769 .58088 Mdot
.3011 .44223 Mdot
.54617 .52063 Mdot
.24791 .4463 Mdot
.54991 .33603 Mdot
.33319 .40128 Mdot
.47154 .65849 Mdot
.4949 .58865 Mdot
.2758 .58111 Mdot
.76012 .46337 Mdot
.56612 .62077 Mdot
.61034 .82127 Mdot
.49465 .18809 Mdot
.56447 .21801 Mdot
.50111 .61417 Mdot
.68915 .50935 Mdot
.44001 .41064 Mdot
.26474 .57612 Mdot
.46499 .57276 Mdot
.83098 .49976 Mdot
.62664 .4931 Mdot
.57103 .32942 Mdot
.46515 .38559 Mdot
.54525 .42219 Mdot
.46023 .60101 Mdot
.53204 .60685 Mdot
.52134 .59215 Mdot
.82642 .40875 Mdot
.39261 .39161 Mdot
.63505 .49156 Mdot
.27827 .56256 Mdot
.65096 .47542 Mdot
.39108 .40097 Mdot
.64415 .32473 Mdot
.47883 .65818 Mdot
.62756 .49849 Mdot
.68134 .49528 Mdot
.58204 .35434 Mdot
.52748 .32517 Mdot
.38944 .37248 Mdot
.52531 .6225 Mdot
.45858 .39355 Mdot
.702 .49889 Mdot
.31657 .42587 Mdot
.26543 .57096 Mdot
.53952 .32097 Mdot
.50098 .59237 Mdot
.41246 .40324 Mdot
.44971 .5821 Mdot
.65476 .50857 Mdot
.34886 .40831 Mdot
.47092 .36653 Mdot
.30705 .55666 Mdot
.51319 .59819 Mdot
.30897 .58911 Mdot
.35689 .42852 Mdot
.48815 .6322 Mdot
.59986 .49054 Mdot
.33058 .55744 Mdot
.40086 .25854 Mdot
.4343 .39696 Mdot
.47615 .36381 Mdot
.69644 .47519 Mdot
.7109 .30849 Mdot
.37334 .41135 Mdot
.60208 .47808 Mdot
.74702 .42749 Mdot
.49974 .55868 Mdot
.6686 .48814 Mdot
.34353 .30564 Mdot
.67894 .79456 Mdot
.44456 .78127 Mdot
.51199 .64802 Mdot
.42447 .39076 Mdot
.26767 .55024 Mdot
.55099 .32517 Mdot
.32665 .45962 Mdot
.44005 .71114 Mdot
.35185 .42271 Mdot
.4747 .61995 Mdot
.69627 .50852 Mdot
.58078 .33754 Mdot
.71786 .36129 Mdot
.34265 .39472 Mdot
.41203 .39073 Mdot
.47517 .66128 Mdot
.29409 .56667 Mdot
.49148 .78107 Mdot
.37499 .39403 Mdot
.30449 .42397 Mdot
.37193 .28913 Mdot
.26892 .54675 Mdot
.48645 .59788 Mdot
.53045 .71217 Mdot
.53859 .56504 Mdot
.51035 .82531 Mdot
.37231 .42839 Mdot
.6479 .49593 Mdot
.53305 .60151 Mdot
.22804 .42448 Mdot
.37082 .40368 Mdot
.57282 .45733 Mdot
.32855 .50031 Mdot
.58401 .34595 Mdot
.30232 .43008 Mdot
.5155 .611 Mdot
.59747 .3427 Mdot
.29944 .57384 Mdot
.52671 .62934 Mdot
.47014 .64714 Mdot
.66061 .46703 Mdot
.57754 .32662 Mdot
.78062 .44737 Mdot
.53121 .34055 Mdot
.57236 .30065 Mdot
.70423 .47468 Mdot
.49739 .62638 Mdot
.35996 .40833 Mdot
.38964 .42134 Mdot
.49076 .55943 Mdot
.30344 .25472 Mdot
.67527 .51196 Mdot
.2608 .60784 Mdot
.81106 .38565 Mdot
.50165 .7031 Mdot
.31092 .43767 Mdot
.75675 .46128 Mdot
.595 .31916 Mdot
.49931 .58899 Mdot
.67765 .52829 Mdot
.30971 .41845 Mdot
.38051 .38781 Mdot
.53522 .57589 Mdot
.57404 .33913 Mdot
.29507 .58704 Mdot
.38493 .38146 Mdot
.23169 .4513 Mdot
.51974 .58656 Mdot
.34136 .27908 Mdot
.40474 .38547 Mdot
.58405 .84566 Mdot
.29466 .38744 Mdot
.66437 .48804 Mdot
.46269 .6301 Mdot
.65808 .47236 Mdot
.27465 .56675 Mdot
.403 .37602 Mdot
.5736 .33711 Mdot
.50973 .70134 Mdot
.61643 .18512 Mdot
.40869 .41429 Mdot
.63885 .50291 Mdot
.47976 .66584 Mdot
.57199 .64403 Mdot
.51446 .61715 Mdot
.60069 .5609 Mdot
.2542 .60486 Mdot
.54188 .33569 Mdot
.56178 .31642 Mdot
.48824 .63766 Mdot
.28533 .58581 Mdot
.33495 .40488 Mdot
.38472 .40729 Mdot
.31728 .81087 Mdot
.32098 .42833 Mdot
.36575 .66904 Mdot
.51935 .60181 Mdot
.32059 .42353 Mdot
.77552 .39399 Mdot
.55924 .32246 Mdot
.54934 .59951 Mdot
.33859 .42651 Mdot
.51236 .20869 Mdot
.33375 .59792 Mdot
.48473 .60694 Mdot
.52128 .53708 Mdot
.56076 .31266 Mdot
.33522 .71788 Mdot
.4277 .40763 Mdot
.55005 .58839 Mdot
.55297 .37306 Mdot
.21259 .43001 Mdot
.64891 .2319 Mdot
.66202 .47598 Mdot
.42862 .38322 Mdot
.57067 .35366 Mdot
.57259 .57727 Mdot
.30001 .55497 Mdot
.43569 .38702 Mdot
.40114 .39506 Mdot
.47328 .63008 Mdot
.44872 .61348 Mdot
.52098 .70452 Mdot
.64136 .50461 Mdot
.53566 .34372 Mdot
.53751 .62076 Mdot
.62624 .37483 Mdot
.54447 .62594 Mdot
.54083 .32253 Mdot
.89622 .57201 Mdot
.54102 .55747 Mdot
.51241 .61753 Mdot
.48431 .7828 Mdot
.65095 .47861 Mdot
.6604 .46935 Mdot
.43947 .19088 Mdot
.51876 .60149 Mdot
.28901 .40508 Mdot
.66538 .47351 Mdot
.67053 .51308 Mdot
.38812 .33178 Mdot
.49437 .65086 Mdot
.32866 .73016 Mdot
.58627 .32017 Mdot
.57477 .30467 Mdot
.67908 .5165 Mdot
.57127 .60033 Mdot
.59281 .31869 Mdot
.71293 .6136 Mdot
.37784 .41938 Mdot
.26445 .30648 Mdot
.65223 .51013 Mdot
.49196 .39914 Mdot
.55216 .32799 Mdot
.75967 .7077 Mdot
.38719 .44345 Mdot
.52144 .64817 Mdot
.51422 .59478 Mdot
.30197 .5701 Mdot
.50441 .55739 Mdot
.34614 .43063 Mdot
.56419 .35156 Mdot
.52407 .78525 Mdot
.6611 .4794 Mdot
.52002 .62382 Mdot
.58892 .48019 Mdot
.72227 .38224 Mdot
.48477 .26741 Mdot
.67977 .50337 Mdot
.67343 .48436 Mdot
.4284 .40301 Mdot
.40246 .38741 Mdot
.49255 .61978 Mdot
.58803 .33111 Mdot
.65721 .53029 Mdot
.54211 .32356 Mdot
.41684 .40296 Mdot
.35274 .40641 Mdot
.39851 .4273 Mdot
.5583 .6086 Mdot
.34422 .39879 Mdot
.21803 .45985 Mdot
.63466 .35974 Mdot
.68842 .53767 Mdot
.66576 .21723 Mdot
.7177 .35934 Mdot
.38926 .59446 Mdot
.3109 .5546 Mdot
.35658 .42825 Mdot
.55422 .36738 Mdot
.47934 .62087 Mdot
.50278 .5993 Mdot
.45733 .38814 Mdot
.58634 .3582 Mdot
.26884 .56426 Mdot
.58916 .35687 Mdot
.29307 .55048 Mdot
.31196 .42699 Mdot
.46572 .65212 Mdot
.50657 .5712 Mdot
.56332 .35407 Mdot
.34471 .40457 Mdot
.37846 .39966 Mdot
.28943 .53443 Mdot
.37517 .55196 Mdot
.40706 .4046 Mdot
.653 .50993 Mdot
.69134 .66818 Mdot
.44742 .4038 Mdot
.52341 .61363 Mdot
.28346 .62581 Mdot
.70854 .58117 Mdot
.54082 .57146 Mdot
.47509 .37148 Mdot
.19184 .61089 Mdot
.5401 .60644 Mdot
.17002 .57156 Mdot
.47705 .36312 Mdot
.64693 .48149 Mdot
.42286 .39135 Mdot
.34446 .43154 Mdot
.54504 .53339 Mdot
.24417 .57443 Mdot
.4736 .57105 Mdot
.66277 .4719 Mdot
.65978 .46165 Mdot
.53484 .19861 Mdot
.49845 .81949 Mdot
.2964 .53838 Mdot
.27874 .54906 Mdot
.3778 .4114 Mdot
.34252 .78442 Mdot
.51102 .6873 Mdot
.26875 .55694 Mdot
.45777 .75231 Mdot
.47256 .6123 Mdot
.34037 .66415 Mdot
.38922 .4493 Mdot
.68609 .51084 Mdot
.55455 .69063 Mdot
.3721 .40797 Mdot
.6399 .4972 Mdot
.63211 .30339 Mdot
.45981 .59483 Mdot
.65647 .48042 Mdot
.54663 .31649 Mdot
.44768 .2306 Mdot
.68882 .47459 Mdot
.275 .62336 Mdot
.58601 .33274 Mdot
.384 .2973 Mdot
.43665 .74192 Mdot
.496 .11556 Mdot
.57209 .35084 Mdot
.35202 .41943 Mdot
.39091 .42057 Mdot
.38577 .40856 Mdot
.63989 .4891 Mdot
.33149 .39809 Mdot
.64393 .51044 Mdot
.3856 .77782 Mdot
.3751 .55317 Mdot
.27218 .55062 Mdot
.54642 .398 Mdot
.67878 .48989 Mdot
.33758 .24905 Mdot
.56989 .15107 Mdot
.50236 .58534 Mdot
.53336 .35172 Mdot
.28504 .54036 Mdot
.53703 .85654 Mdot
.29641 .5749 Mdot
.44672 .38509 Mdot
.23986 .32957 Mdot
.51356 .62797 Mdot
.6783 .72565 Mdot
.30679 .55098 Mdot
.68983 .49984 Mdot
.49046 .63675 Mdot
.50272 .30357 Mdot
.29844 .5657 Mdot
.29911 .58394 Mdot
.48908 .62284 Mdot
.69873 .48966 Mdot
.35711 .4055 Mdot
.56299 .3716 Mdot
.26893 .53654 Mdot
.49687 .52941 Mdot
.50522 .55916 Mdot
.46954 .58541 Mdot
.57025 .43873 Mdot
.4312 .71141 Mdot
.56567 .35028 Mdot
.4025 .76416 Mdot
.40042 .38753 Mdot
.35084 .32015 Mdot
.45156 .19108 Mdot
.51241 .3841 Mdot
.38715 .42674 Mdot
.3698 .42931 Mdot
.48605 .61198 Mdot
.43224 .71378 Mdot
.21764 .38879 Mdot
.60076 .38223 Mdot
.4434 .40695 Mdot
.38235 .40515 Mdot
.64246 .46537 Mdot
.53934 .1943 Mdot
.46633 .56889 Mdot
.58816 .30347 Mdot
.40952 .40089 Mdot
.72621 .69959 Mdot
.2913 .56373 Mdot
.30314 .27525 Mdot
.47579 .65992 Mdot
.53429 .62998 Mdot
.56 .34334 Mdot
.55416 .30808 Mdot
.52622 .28643 Mdot
.51323 .19 Mdot
.27366 .68685 Mdot
.74058 .35066 Mdot
.72864 .69161 Mdot
.62866 .47549 Mdot
.69359 .52196 Mdot
.48738 .35175 Mdot
.53371 .32552 Mdot
.53615 .60209 Mdot
.66017 .53066 Mdot
.4681 .26619 Mdot
.71889 .46877 Mdot
.3536 .6711 Mdot
.26741 .42625 Mdot
.45798 .61728 Mdot
.67831 .52357 Mdot
.64437 .48855 Mdot
.65769 .53388 Mdot
.47925 .36329 Mdot
.50193 .62082 Mdot
.50361 .65558 Mdot
.54402 .61794 Mdot
.44853 .55924 Mdot
.51426 .58301 Mdot
.58768 .39347 Mdot
.53908 .45693 Mdot
.56689 .79144 Mdot
.54881 .5749 Mdot
.58491 .3112 Mdot
.47612 .57703 Mdot
.28533 .58646 Mdot
.47654 .62274 Mdot
.35502 .66572 Mdot
.56097 .32879 Mdot
.58402 .53294 Mdot
.73411 .34226 Mdot
.47704 .65875 Mdot
.28824 .59138 Mdot
.39974 .61952 Mdot
.77426 .4694 Mdot
.35331 .5598 Mdot
.65395 .51092 Mdot
.37643 .42373 Mdot
.5722 .36515 Mdot
.35957 .41047 Mdot
.55504 .58817 Mdot
.47597 .37237 Mdot
.66493 .40663 Mdot
.48858 .40187 Mdot
.53393 .58742 Mdot
.52058 .6903 Mdot
.66157 .5135 Mdot
.34301 .41453 Mdot
.62521 .47188 Mdot
.52753 .59813 Mdot
.27938 .56585 Mdot
.29875 .56174 Mdot
.6082 .26506 Mdot
.76266 .66685 Mdot
.69567 .29382 Mdot
.56028 .3455 Mdot
.37934 .39312 Mdot
.3117 .54363 Mdot
.45138 .5443 Mdot
.56474 .29546 Mdot
.59079 .34184 Mdot
.58056 .33011 Mdot
.47675 .58658 Mdot
.35355 .43009 Mdot
.56344 .78412 Mdot
.34353 .4301 Mdot
.47551 .65441 Mdot
.39671 .39135 Mdot
.38385 .42949 Mdot
.30367 .56459 Mdot
.55805 .36211 Mdot
.41882 .40012 Mdot
.49775 .57971 Mdot
.67927 .47586 Mdot
.40286 .52177 Mdot
.34078 .61452 Mdot
.53787 .823 Mdot
.55681 .82019 Mdot
.70564 .49405 Mdot
.74147 .71457 Mdot
.60165 .31553 Mdot
.67947 .58046 Mdot
.43766 .3465 Mdot
.52413 .56747 Mdot
.36778 .20973 Mdot
.4355 .4019 Mdot
.3417 .41525 Mdot
.48449 .5974 Mdot
.32116 .40437 Mdot
.51786 .62207 Mdot
.41264 .39306 Mdot
.34348 .56912 Mdot
.44443 .59143 Mdot
.339 .40377 Mdot
.54925 .64146 Mdot
.48671 .6517 Mdot
.68658 .51225 Mdot
.4206 .38802 Mdot
.55297 .60888 Mdot
.45009 .85273 Mdot
.54466 .31515 Mdot
.47588 .36939 Mdot
.22934 .61228 Mdot
.5695 .35481 Mdot
.65863 .48391 Mdot
.51732 .551 Mdot
.29064 .58078 Mdot
.68716 .49086 Mdot
.29071 .60905 Mdot
.30229 .54718 Mdot
.3585 .22446 Mdot
.65836 .51549 Mdot
.44868 .40162 Mdot
.30598 .5664 Mdot
.48699 .68464 Mdot
.41173 .38368 Mdot
.39722 .54423 Mdot
.37029 .42782 Mdot
.505 .61062 Mdot
.49428 .31004 Mdot
.53867 .32093 Mdot
.5146 .64531 Mdot
.36803 .38118 Mdot
.48228 .35346 Mdot
.47196 .59321 Mdot
.47958 .61493 Mdot
.59337 .2158 Mdot
.29323 .30941 Mdot
.27044 .57725 Mdot
.64234 .47445 Mdot
.49607 .58498 Mdot
.30824 .56773 Mdot
.25404 .49388 Mdot
.48153 .57541 Mdot
.63025 .50781 Mdot
.44001 .6786 Mdot
.38444 .3832 Mdot
.55149 .35658 Mdot
.44355 .37912 Mdot
.30634 .57752 Mdot
.16963 .37119 Mdot
.40151 .42724 Mdot
.54695 .64049 Mdot
.545 .59716 Mdot
.49026 .27735 Mdot
.64178 .4947 Mdot
.27774 .68729 Mdot
.51319 .59782 Mdot
.41426 .62894 Mdot
.52356 .63229 Mdot
.31111 .37743 Mdot
.67351 .5114 Mdot
.51044 .6137 Mdot
.5693 .50139 Mdot
.50808 .67864 Mdot
.29791 .58671 Mdot
.45926 .78125 Mdot
.49414 .56653 Mdot
.87098 .40081 Mdot
.31458 .43373 Mdot
.33968 .40217 Mdot
.50302 .29006 Mdot
.23456 .70316 Mdot
.68348 .2783 Mdot
.64308 .51072 Mdot
.72858 .44101 Mdot
.35803 .40784 Mdot
.72772 .31574 Mdot
.72523 .73897 Mdot
.4841 .65063 Mdot
.46004 .60211 Mdot
.44671 .38508 Mdot
.32367 .42547 Mdot
.45627 .39678 Mdot
.55421 .57942 Mdot
.49718 .69149 Mdot
.34895 .39364 Mdot
.50547 .57636 Mdot
.43003 .65237 Mdot
.55877 .37123 Mdot
.7011 .48719 Mdot
.54653 .33026 Mdot
.56828 .36299 Mdot
.65453 .62916 Mdot
.51261 .19519 Mdot
.53969 .32374 Mdot
.59961 .3135 Mdot
.34254 .6579 Mdot
.51964 .70903 Mdot
.31445 .56827 Mdot
.67032 .77483 Mdot
.38969 .41029 Mdot
.50214 .62345 Mdot
.70896 .50227 Mdot
.65398 .60619 Mdot
.36632 .46324 Mdot
.22202 .36486 Mdot
.53133 .59881 Mdot
.37458 .4059 Mdot
.47549 .36104 Mdot
.4321 .62286 Mdot
.3608 .32346 Mdot
.53265 .63532 Mdot
.43172 .38506 Mdot
.66573 .7117 Mdot
.59036 .49531 Mdot
.33505 .30661 Mdot
.6553 .44932 Mdot
.53497 .61632 Mdot
.64856 .50643 Mdot
.54792 .33689 Mdot
.29646 .58209 Mdot
.27156 .57709 Mdot
.48716 .62734 Mdot
.43012 .69209 Mdot
.40359 .44733 Mdot
.48612 .65365 Mdot
.47733 .63373 Mdot
.47663 .36296 Mdot
.47891 .636 Mdot
.54533 .59956 Mdot
.54716 .61002 Mdot
.50819 .67156 Mdot
.57386 .30124 Mdot
.58706 .48763 Mdot
.56066 .60065 Mdot
.42779 .63003 Mdot
.57187 .37355 Mdot
.74122 .44021 Mdot
.55705 .36426 Mdot
.7972 .62454 Mdot
.55482 .31962 Mdot
.26583 .5674 Mdot
.48597 .31713 Mdot
.45176 .70428 Mdot
.68303 .53304 Mdot
.54494 .30612 Mdot
.28195 .55531 Mdot
.55545 .34879 Mdot
.39042 .38935 Mdot
.77204 .32303 Mdot
.72044 .47207 Mdot
.26335 .66322 Mdot
.59903 .26331 Mdot
.35698 .27821 Mdot
.42031 .41048 Mdot
.67716 .51366 Mdot
.73609 .64661 Mdot
.54884 .61615 Mdot
.30701 .56223 Mdot
.48889 .6185 Mdot
.57178 .29991 Mdot
.37813 .40829 Mdot
.44117 .78651 Mdot
.28086 .5819 Mdot
.61018 .20797 Mdot
.39141 .40565 Mdot
.53446 .64086 Mdot
.58767 .30355 Mdot
.65356 .20627 Mdot
.54369 .33271 Mdot
.36473 .56785 Mdot
.62741 .52049 Mdot
.53792 .72674 Mdot
.67185 .48971 Mdot
.42412 .42458 Mdot
.83123 .39234 Mdot
.62552 .80681 Mdot
.69016 .482 Mdot
.29954 .34291 Mdot
.46216 .60069 Mdot
.47132 .58286 Mdot
.58859 .51765 Mdot
.63266 .49509 Mdot
.50564 .58295 Mdot
.47093 .36742 Mdot
.64651 .34925 Mdot
.27912 .37094 Mdot
.37008 .42378 Mdot
.51827 .61566 Mdot
.56483 .37428 Mdot
.59075 .35382 Mdot
.35476 .43114 Mdot
.55196 .36258 Mdot
.50525 .65453 Mdot
.67611 .49006 Mdot
.47215 .40187 Mdot
.28116 .57542 Mdot
.45273 .83258 Mdot
.31687 .54901 Mdot
.39188 .4253 Mdot
.45824 .66488 Mdot
.35201 .40626 Mdot
.12727 .56531 Mdot
.51665 .64988 Mdot
.65875 .47618 Mdot
.47586 .60159 Mdot
.53314 .62214 Mdot
.4619 .59341 Mdot
.35756 .39061 Mdot
.22297 .63918 Mdot
.50303 .5767 Mdot
.57469 .33594 Mdot
.59003 .80045 Mdot
.47235 .57939 Mdot
.34615 .55818 Mdot
.39329 .71552 Mdot
.36284 .26412 Mdot
.69519 .53044 Mdot
.34079 .41166 Mdot
.66844 .47838 Mdot
.69185 .45536 Mdot
.65819 .48409 Mdot
.60606 .78049 Mdot
.72033 .66419 Mdot
.19256 .59093 Mdot
.54388 .74419 Mdot
.63234 .59914 Mdot
.63521 .48181 Mdot
.23335 .51688 Mdot
.68158 .52925 Mdot
.64352 .49826 Mdot
.69055 .84012 Mdot
.69375 .52504 Mdot
.51955 .60804 Mdot
.45267 .59248 Mdot
.69635 .38094 Mdot
.32183 .66106 Mdot
.48368 .63577 Mdot
.4894 .58951 Mdot
.30077 .57743 Mdot
.41657 .67291 Mdot
.47671 .37235 Mdot
.36745 .22259 Mdot
.74444 .38937 Mdot
.48794 .61996 Mdot
.49518 .58375 Mdot
.50128 .68831 Mdot
.77243 .27331 Mdot
.67812 .61183 Mdot
.63498 .47827 Mdot
.57328 .61638 Mdot
.52412 .83668 Mdot
.50236 .6597 Mdot
.49023 .57257 Mdot
.45949 .61498 Mdot
.35936 .40802 Mdot
.62595 .49398 Mdot
.57067 .62403 Mdot
.36953 .24336 Mdot
.46917 .65287 Mdot
.52541 .39102 Mdot
.25502 .69775 Mdot
.51491 .60992 Mdot
.65922 .53805 Mdot
.46753 .61486 Mdot
.65868 .51772 Mdot
.69268 .50987 Mdot
.47985 .67764 Mdot
.67711 .74545 Mdot
.62983 .51786 Mdot
.47227 .65223 Mdot
.35217 .39994 Mdot
.654 .79987 Mdot
.50577 .60811 Mdot
.26173 .57316 Mdot
.51468 .59664 Mdot
.2767 .5909 Mdot
.47623 .64024 Mdot
.34315 .42967 Mdot
.74205 .55784 Mdot
.37658 .4133 Mdot
.29884 .72685 Mdot
.31624 .41952 Mdot
.59087 .21423 Mdot
.63184 .50263 Mdot
.48372 .34852 Mdot
.19675 .37017 Mdot
.47341 .37037 Mdot
.56478 .47542 Mdot
.50898 .48291 Mdot
.58865 .33241 Mdot
.67078 .46734 Mdot
.38102 .74627 Mdot
.47842 .27169 Mdot
.47497 .30948 Mdot
.40817 .42109 Mdot
.20521 .33066 Mdot
.24806 .30648 Mdot
.49253 .57878 Mdot
.64789 .75191 Mdot
.59859 .71175 Mdot
.48452 .57394 Mdot
.53394 .55221 Mdot
.37225 .37925 Mdot
.54299 .5934 Mdot
.59409 .43623 Mdot
.40474 .41461 Mdot
.28527 .55227 Mdot
.64677 .49879 Mdot
.26227 .58177 Mdot
.47807 .28298 Mdot
.51158 .48552 Mdot
.41195 .39598 Mdot
.51328 .67375 Mdot
.47914 .59639 Mdot
.67887 .51926 Mdot
.61155 .50599 Mdot
.70044 .49877 Mdot
.28514 .53927 Mdot
.40264 .4131 Mdot
.68129 .60097 Mdot
.49223 .59406 Mdot
.67834 .4961 Mdot
.60088 .27532 Mdot
.49596 .5883 Mdot
.5543 .35246 Mdot
.45647 .622 Mdot
.68784 .47827 Mdot
.47896 .63642 Mdot
.67635 .4884 Mdot
.37646 .42019 Mdot
.49983 .66184 Mdot
.48473 .60113 Mdot
.65061 .20922 Mdot
.26913 .56653 Mdot
.63271 .49981 Mdot
.46499 .44925 Mdot
.54466 .62865 Mdot
.42093 .28033 Mdot
.53431 .61015 Mdot
.73183 .46787 Mdot
.54098 .65072 Mdot
.47933 .35917 Mdot
.46324 .56729 Mdot
.50633 .60915 Mdot
.52213 .49722 Mdot
.59586 .73926 Mdot
.61505 .48994 Mdot
.58786 .30646 Mdot
.65038 .53501 Mdot
.30039 .44678 Mdot
.44208 .40343 Mdot
.33334 .3924 Mdot
.29919 .67145 Mdot
.47335 .67092 Mdot
.51195 .62751 Mdot
.52917 .35581 Mdot
.28532 .54798 Mdot
.68081 .50172 Mdot
.29071 .55085 Mdot
.41417 .20636 Mdot
.29189 .54091 Mdot
.34522 .43125 Mdot
.28976 .39128 Mdot
.71546 .59229 Mdot
.30139 .57636 Mdot
.70144 .49394 Mdot
.26205 .42974 Mdot
.5347 .57277 Mdot
.23857 .58872 Mdot
.28084 .56658 Mdot
.2042 .32139 Mdot
.53901 .59209 Mdot
.57021 .46769 Mdot
.53868 .33872 Mdot
.30199 .55771 Mdot
.57537 .32338 Mdot
.48414 .63198 Mdot
.40255 .26212 Mdot
.63911 .5078 Mdot
.59128 .36365 Mdot
.55463 .56624 Mdot
.28164 .54265 Mdot
.40636 .3996 Mdot
.52709 .37558 Mdot
.58669 .31358 Mdot
.78591 .50098 Mdot
.44073 .77881 Mdot
.40171 .41399 Mdot
.24918 .36669 Mdot
.57872 .31692 Mdot
.49116 .57035 Mdot
.41894 .65031 Mdot
.5198 .64972 Mdot
.50044 .30192 Mdot
.33964 .41168 Mdot
.65425 .3754 Mdot
.47735 .59621 Mdot
.53913 .60061 Mdot
.65629 .54617 Mdot
.38749 .41837 Mdot
.66045 .50084 Mdot
.66432 .53578 Mdot
.3781 .42066 Mdot
.66454 .48966 Mdot
.30714 .55347 Mdot
.65481 .3343 Mdot
.57753 .31486 Mdot
.57106 .33481 Mdot
.38267 .40586 Mdot
.34229 .39745 Mdot
.35013 .40807 Mdot
.45663 .62316 Mdot
.67807 .50683 Mdot
.46466 .63065 Mdot
.46123 .59644 Mdot
.62078 .46691 Mdot
.70533 .5151 Mdot
.46344 .61252 Mdot
.34985 .30121 Mdot
.25734 .59985 Mdot
.35307 .39637 Mdot
.53829 .33035 Mdot
.76709 .37096 Mdot
.56461 .38083 Mdot
.52044 .61691 Mdot
.50604 .21258 Mdot
.69443 .48692 Mdot
.29979 .57203 Mdot
.27795 .59861 Mdot
.28963 .57908 Mdot
.52114 .33493 Mdot
.64598 .52445 Mdot
.36572 .22406 Mdot
.51729 .61926 Mdot
.57105 .43746 Mdot
.39324 .75467 Mdot
.42012 .21211 Mdot
.53849 .32632 Mdot
.49431 .58708 Mdot
.46586 .38178 Mdot
.74309 .61995 Mdot
.53187 .6341 Mdot
.55231 .598 Mdot
.4101 .34511 Mdot
.43976 .67252 Mdot
.628 .51886 Mdot
.51039 .18507 Mdot
.4567 .58937 Mdot
.60016 .5027 Mdot
.33769 .80802 Mdot
.52625 .6186 Mdot
.52577 .5931 Mdot
.49754 .60482 Mdot
.47324 .61012 Mdot
.65278 .53789 Mdot
.34014 .7111 Mdot
.58338 .30034 Mdot
.54485 .4374 Mdot
.58015 .31447 Mdot
.43444 .38567 Mdot
.58959 .4626 Mdot
.68423 .46798 Mdot
.30156 .57121 Mdot
.78151 .54228 Mdot
.45627 .18025 Mdot
.42929 .40339 Mdot
.70516 .63241 Mdot
.27692 .57086 Mdot
.50746 .56117 Mdot
.2613 .58441 Mdot
.33107 .42608 Mdot
.58188 .33564 Mdot
.44556 .59771 Mdot
.69873 .51362 Mdot
.68555 .47311 Mdot
.50359 .58465 Mdot
.55125 .84177 Mdot
.55375 .35417 Mdot
.60779 .35624 Mdot
.46977 .59304 Mdot
.55273 .59687 Mdot
.65683 .49906 Mdot
.36678 .39761 Mdot
.19851 .47481 Mdot
.27384 .55703 Mdot
.5289 .65132 Mdot
.47341 .61473 Mdot
.50733 .19131 Mdot
.57059 .35873 Mdot
.42004 .42172 Mdot
.47792 .5865 Mdot
.59825 .25305 Mdot
.47636 .58837 Mdot
.43353 .6114 Mdot
.35492 .40219 Mdot
.5502 .64938 Mdot
.50512 .57289 Mdot
.57924 .57556 Mdot
.57772 .31927 Mdot
.65394 .48062 Mdot
.65751 .5436 Mdot
.4643 .38681 Mdot
.55316 .35082 Mdot
.46503 .61266 Mdot
.56724 .35849 Mdot
.48207 .57305 Mdot
.50891 .57905 Mdot
.54059 .32312 Mdot
.66047 .50022 Mdot
.70054 .41826 Mdot
.58703 .48142 Mdot
.47321 .6055 Mdot
.45753 .57738 Mdot
.31172 .67186 Mdot
.15843 .48824 Mdot
.53125 .60174 Mdot
.68629 .47574 Mdot
.48913 .59478 Mdot
.56712 .32345 Mdot
.29323 .54293 Mdot
.68253 .47643 Mdot
.38009 .39757 Mdot
.42535 .40963 Mdot
.73155 .33814 Mdot
.36704 .43002 Mdot
.52777 .56533 Mdot
.7355 .50306 Mdot
.71334 .49405 Mdot
.38804 .8245 Mdot
.381 .42137 Mdot
.30832 .57993 Mdot
.48129 .61992 Mdot
.53704 .22371 Mdot
.5258 .34783 Mdot
.86944 .3866 Mdot
.36022 .22531 Mdot
.3172 .54669 Mdot
.21281 .36784 Mdot
.45723 .39044 Mdot
.51986 .57601 Mdot
.29401 .58363 Mdot
.43049 .39752 Mdot
.51359 .56535 Mdot
.5153 .53713 Mdot
.26151 .67166 Mdot
.41793 .3792 Mdot
.56066 .35989 Mdot
.35664 .38487 Mdot
.25036 .57385 Mdot
.3447 .43101 Mdot
.69082 .47391 Mdot
.50709 .61381 Mdot
.53973 .67682 Mdot
.37261 .39632 Mdot
.33782 .42971 Mdot
.45832 .62218 Mdot
.66423 .46937 Mdot
.32386 .39987 Mdot
.49036 .6281 Mdot
.6619 .58476 Mdot
.65231 .45055 Mdot
.40421 .40883 Mdot
.54384 .60449 Mdot
.50267 .71184 Mdot
.38338 .40243 Mdot
.35466 .39483 Mdot
.50476 .58269 Mdot
.30854 .55689 Mdot
.47121 .65845 Mdot
.55167 .31987 Mdot
.22732 .65358 Mdot
.56881 .32522 Mdot
.29829 .45733 Mdot
.45482 .67249 Mdot
.38805 .27547 Mdot
.70008 .47968 Mdot
.25126 .57875 Mdot
.77275 .36808 Mdot
.55214 .58667 Mdot
.73716 .7122 Mdot
.50131 .40022 Mdot
.51056 .84808 Mdot
.82505 .44848 Mdot
.28455 .56489 Mdot
.55168 .34486 Mdot
.52494 .59316 Mdot
.53339 .35503 Mdot
.27946 .58395 Mdot
.40376 .7708 Mdot
.54511 .6039 Mdot
.67101 .51224 Mdot
.46604 .64649 Mdot
.65372 .51122 Mdot
.49858 .58815 Mdot
.43598 .66405 Mdot
.47136 .3484 Mdot
.33675 .59872 Mdot
.52756 .56878 Mdot
.76757 .31464 Mdot
.39076 .46159 Mdot
.27651 .56274 Mdot
.46796 .642 Mdot
.43476 .41053 Mdot
.59269 .34785 Mdot
.42397 .55744 Mdot
.35588 .40667 Mdot
.53614 .35154 Mdot
.6564 .49169 Mdot
.37349 .42212 Mdot
.41718 .41968 Mdot
.57334 .59342 Mdot
.28088 .59038 Mdot
.58595 .33946 Mdot
.50965 .60861 Mdot
.53906 .59413 Mdot
.25437 .37924 Mdot
.34859 .47079 Mdot
.63848 .54298 Mdot
.60766 .18714 Mdot
.69382 .53689 Mdot
.26938 .55788 Mdot
.35273 .40346 Mdot
.53087 .6045 Mdot
.51058 .64721 Mdot
.48447 .34221 Mdot
.63441 .49721 Mdot
.43263 .38094 Mdot
.67308 .63078 Mdot
.33401 .41877 Mdot
.35923 .70176 Mdot
.66383 .47282 Mdot
.35565 .70009 Mdot
.25134 .57515 Mdot
.7456 .68456 Mdot
.35895 .62488 Mdot
.53854 .34219 Mdot
.36283 .70569 Mdot
.69082 .49795 Mdot
.48639 .58464 Mdot
.44959 .39937 Mdot
.38977 .42828 Mdot
.65084 .49803 Mdot
.44418 .38626 Mdot
.30123 .55949 Mdot
.52496 .5896 Mdot
.32874 .27048 Mdot
.70053 .34674 Mdot
.37402 .39227 Mdot
.43835 .59054 Mdot
.57743 .32842 Mdot
.51812 .57783 Mdot
.26034 .56984 Mdot
.57735 .34597 Mdot
.32092 .43936 Mdot
.64985 .3588 Mdot
.48663 .63057 Mdot
.55116 .21097 Mdot
.56211 .35342 Mdot
.19915 .41453 Mdot
.49393 .62498 Mdot
.57873 .31714 Mdot
.461 .69249 Mdot
.41283 .22377 Mdot
.48472 .42487 Mdot
.71626 .75093 Mdot
.42279 .37793 Mdot
.44449 .39014 Mdot
.44439 .23977 Mdot
.45782 .3097 Mdot
.54017 .36108 Mdot
.34445 .43078 Mdot
.40683 .69857 Mdot
.57704 .32333 Mdot
.45971 .60123 Mdot
.53131 .61328 Mdot
.65397 .62267 Mdot
.51234 .41904 Mdot
.33604 .43055 Mdot
.67101 .2812 Mdot
.54444 .62792 Mdot
.5645 .57039 Mdot
.50808 .64409 Mdot
.65425 .46278 Mdot
.58192 .34854 Mdot
.68856 .23821 Mdot
.5486 .34753 Mdot
.29311 .29101 Mdot
.38815 .41031 Mdot
.3339 .40232 Mdot
.51744 .6119 Mdot
.3567 .28533 Mdot
.44947 .7361 Mdot
.49936 .65609 Mdot
.38093 .29589 Mdot
.45491 .78682 Mdot
.5559 .56556 Mdot
.62675 .52123 Mdot
.44379 .61284 Mdot
.67931 .45848 Mdot
.58617 .31775 Mdot
.29098 .56702 Mdot
.24447 .56464 Mdot
.58479 .33963 Mdot
.51107 .62914 Mdot
.39153 .2984 Mdot
.52891 .63144 Mdot
.48642 .58104 Mdot
.29625 .27683 Mdot
.31259 .54314 Mdot
.3494 .41201 Mdot
.27475 .57955 Mdot
.64279 .49877 Mdot
.89218 .60858 Mdot
.28849 .54726 Mdot
.47377 .7341 Mdot
.33381 .74202 Mdot
.36 .70562 Mdot
.68251 .47128 Mdot
.26446 .54313 Mdot
.55126 .35536 Mdot
.55975 .86067 Mdot
.15833 .51023 Mdot
.58571 .37737 Mdot
.49528 .63356 Mdot
.68284 .46574 Mdot
.70436 .49784 Mdot
.59901 .35401 Mdot
.69271 .50626 Mdot
.51022 .69374 Mdot
.47647 .5935 Mdot
.538 .35826 Mdot
.70081 .36859 Mdot
.58772 .31415 Mdot
.64518 .31932 Mdot
.46605 .64184 Mdot
.67013 .4725 Mdot
.44658 .63138 Mdot
.72549 .49822 Mdot
.41908 .4232 Mdot
.50168 .56228 Mdot
.3028 .56314 Mdot
.55737 .42587 Mdot
.39993 .41029 Mdot
.50453 .21501 Mdot
.676 .51967 Mdot
.55567 .28127 Mdot
.68831 .51139 Mdot
.66661 .46389 Mdot
.56901 .36319 Mdot
.6511 .52327 Mdot
.5263 .59236 Mdot
.32052 .32372 Mdot
.6615 .52163 Mdot
.55874 .33674 Mdot
.29182 .57231 Mdot
.66354 .49306 Mdot
.37675 .37842 Mdot
.48071 .60885 Mdot
.40671 .39007 Mdot
.46948 .34157 Mdot
.66131 .46858 Mdot
.27123 .53976 Mdot
.33626 .41079 Mdot
.28373 .58895 Mdot
.43737 .79945 Mdot
.5345 .32286 Mdot
.2264 .36455 Mdot
.51039 .70717 Mdot
.70109 .51193 Mdot
.46936 .34518 Mdot
.52838 .60501 Mdot
.47972 .61038 Mdot
.25109 .56181 Mdot
.70454 .49863 Mdot
.62159 .81345 Mdot
.73967 .46658 Mdot
.65647 .34724 Mdot
.5396 .3135 Mdot
.63731 .22139 Mdot
.62798 .37444 Mdot
.32989 .76748 Mdot
.56749 .60693 Mdot
.45671 .39083 Mdot
.51935 .62799 Mdot
.77929 .38196 Mdot
.28315 .54109 Mdot
.1998 .51181 Mdot
.48735 .68096 Mdot
.35762 .41607 Mdot
.49239 .61121 Mdot
.44141 .51817 Mdot
.44046 .62582 Mdot
.3101 .55499 Mdot
.55334 .4026 Mdot
.67911 .53389 Mdot
.27916 .57429 Mdot
.41555 .41405 Mdot
.41822 .73318 Mdot
.5207 .56821 Mdot
.55702 .58751 Mdot
.33152 .41947 Mdot
.67626 .51258 Mdot
.42758 .38718 Mdot
.57796 .31516 Mdot
.29423 .55881 Mdot
.47819 .6179 Mdot
.52637 .66667 Mdot
.42252 .28194 Mdot
.58656 .34397 Mdot
.33202 .41394 Mdot
.54438 .33501 Mdot
.45431 .39389 Mdot
.45024 .58667 Mdot
.33311 .40109 Mdot
.52778 .57763 Mdot
.72291 .29336 Mdot
.29022 .28487 Mdot
.60839 .73961 Mdot
.3539 .41689 Mdot
.37173 .69416 Mdot
.55992 .32741 Mdot
.55211 .32238 Mdot
.5459 .71545 Mdot
.40229 .64896 Mdot
.28035 .41331 Mdot
.79002 .50099 Mdot
.57733 .31409 Mdot
.56886 .32879 Mdot
.4216 .39248 Mdot
.65064 .52092 Mdot
.68845 .46357 Mdot
.44928 .38788 Mdot
.27479 .62723 Mdot
.68074 .5016 Mdot
.71919 .72924 Mdot
.30061 .4364 Mdot
.57067 .57621 Mdot
.51197 .29802 Mdot
.29714 .56357 Mdot
.29197 .62296 Mdot
.45221 .51355 Mdot
.53563 .59853 Mdot
.5205 .18709 Mdot
.36718 .40073 Mdot
.31519 .70118 Mdot
.79884 .61905 Mdot
.54638 .60436 Mdot
.49993 .62366 Mdot
.51193 .63516 Mdot
.3026 .53674 Mdot
.74793 .523 Mdot
.53607 .59335 Mdot
.26554 .62648 Mdot
.5426 .63296 Mdot
.36678 .58943 Mdot
.27196 .57774 Mdot
.59763 .57409 Mdot
.4456 .36726 Mdot
.37332 .23331 Mdot
.59016 .54938 Mdot
.57013 .31497 Mdot
.45993 .37588 Mdot
.58567 .32179 Mdot
.60057 .77807 Mdot
.35817 .6295 Mdot
.62436 .52526 Mdot
.53218 .59661 Mdot
.39574 .42401 Mdot
.70269 .49285 Mdot
.44466 .27005 Mdot
.75056 .79639 Mdot
.59393 .32887 Mdot
.13687 .56931 Mdot
.54743 .32658 Mdot
.41119 .42461 Mdot
.65546 .49818 Mdot
.71035 .67297 Mdot
.57345 .43778 Mdot
.66583 .49117 Mdot
.67705 .40929 Mdot
.71205 .52534 Mdot
.37121 .7025 Mdot
.71345 .50727 Mdot
.5578 .33356 Mdot
.52414 .36071 Mdot
.56571 .56528 Mdot
.5209 .6043 Mdot
.50467 .48674 Mdot
.48571 .72541 Mdot
.52449 .60382 Mdot
.40386 .41486 Mdot
.19296 .41402 Mdot
.453 .38541 Mdot
.67847 .52751 Mdot
.59343 .3138 Mdot
.49833 .62102 Mdot
.47154 .59942 Mdot
.50994 .56769 Mdot
.62662 .18659 Mdot
.70251 .74149 Mdot
.50217 .57741 Mdot
.51421 .66238 Mdot
.372 .41993 Mdot
.32838 .5416 Mdot
.79531 .41116 Mdot
.38973 .65483 Mdot
.53429 .63607 Mdot
.27098 .57336 Mdot
.31726 .56197 Mdot
.51568 .565 Mdot
.34973 .26604 Mdot
.31318 .32709 Mdot
.50926 .60835 Mdot
.37466 .59969 Mdot
.47172 .28612 Mdot
.35233 .43158 Mdot
.37509 .39788 Mdot
.66157 .53785 Mdot
.39805 .42492 Mdot
.31455 .41839 Mdot
.72027 .65036 Mdot
.47169 .37792 Mdot
.61616 .37143 Mdot
.28488 .53929 Mdot
.5162 .64485 Mdot
.69789 .53653 Mdot
.49375 .32108 Mdot
.58775 .33401 Mdot
.68157 .48209 Mdot
.59496 .3447 Mdot
.32286 .55158 Mdot
.27996 .67638 Mdot
.38993 .42883 Mdot
.56914 .31165 Mdot
.64935 .35738 Mdot
.27105 .5746 Mdot
.5485 .35892 Mdot
.39651 .27729 Mdot
.46449 .58715 Mdot
.73185 .67935 Mdot
.48691 .65721 Mdot
.55181 .8495 Mdot
.55041 .35921 Mdot
.48202 .35986 Mdot
.51084 .62289 Mdot
.39011 .40561 Mdot
.45512 .68129 Mdot
.53197 .63688 Mdot
.38696 .39667 Mdot
.49168 .57967 Mdot
.26347 .57851 Mdot
.67354 .45296 Mdot
.50594 .39102 Mdot
.36208 .17978 Mdot
.27526 .58862 Mdot
.4373 .27083 Mdot
.53146 .60067 Mdot
.44178 .78472 Mdot
.66508 .49364 Mdot
.54966 .59857 Mdot
.58075 .65842 Mdot
.64881 .51483 Mdot
.67174 .47974 Mdot
.47183 .62877 Mdot
.54009 .34338 Mdot
.39727 .40602 Mdot
.27459 .57782 Mdot
.38464 .80923 Mdot
.4961 .6425 Mdot
.48653 .59817 Mdot
.27776 .57216 Mdot
.56924 .32677 Mdot
.47005 .60361 Mdot
.54446 .25158 Mdot
.46561 .85152 Mdot
.58861 .34751 Mdot
.45187 .61099 Mdot
.77419 .58974 Mdot
.72822 .50459 Mdot
.14239 .5344 Mdot
.30911 .59878 Mdot
.34051 .40902 Mdot
.44197 .67653 Mdot
.89217 .48246 Mdot
.29248 .56768 Mdot
.36873 .22899 Mdot
.48988 .57687 Mdot
.49457 .59721 Mdot
.69738 .49273 Mdot
.46356 .62245 Mdot
.63777 .49616 Mdot
.30951 .21806 Mdot
.54834 .17772 Mdot
.66959 .51717 Mdot
.69635 .52032 Mdot
.52436 .71713 Mdot
.79249 .40557 Mdot
.65023 .49376 Mdot
.45366 .63256 Mdot
.6307 .79268 Mdot
.57106 .56278 Mdot
.25067 .56156 Mdot
.46283 .33537 Mdot
.60308 .54304 Mdot
.35836 .50809 Mdot
.74649 .45199 Mdot
.58838 .53591 Mdot
.40395 .43953 Mdot
.55103 .31807 Mdot
.54615 .61745 Mdot
.3769 .42976 Mdot
.33243 .39488 Mdot
.43903 .63654 Mdot
.52465 .6398 Mdot
.65543 .51538 Mdot
.30562 .54131 Mdot
.57786 .36402 Mdot
.48871 .5902 Mdot
.38166 .37692 Mdot
.28075 .55174 Mdot
.6752 .52632 Mdot
.53111 .72541 Mdot
.31225 .56868 Mdot
.44235 .59064 Mdot
.51022 .59522 Mdot
.45814 .6171 Mdot
.50474 .70352 Mdot
.55438 .30685 Mdot
.49707 .2903 Mdot
.4597 .64134 Mdot
.42031 .2032 Mdot
.37372 .54807 Mdot
.54031 .66054 Mdot
.68639 .50386 Mdot
.52361 .33894 Mdot
.42862 .41837 Mdot
.41844 .74871 Mdot
.49016 .63706 Mdot
.69599 .74513 Mdot
.67425 .61824 Mdot
.4306 .41282 Mdot
.63406 .48497 Mdot
.29799 .57419 Mdot
.50567 .65386 Mdot
.61428 .78693 Mdot
.52816 .61492 Mdot
.49524 .71042 Mdot
.35538 .39821 Mdot
.55005 .31753 Mdot
.49919 .85134 Mdot
.33258 .39512 Mdot
.66951 .47861 Mdot
.72911 .7448 Mdot
.70244 .47614 Mdot
.66748 .53365 Mdot
.65985 .75886 Mdot
.55938 .30578 Mdot
.8897 .46476 Mdot
.15372 .51374 Mdot
.50683 .68303 Mdot
.56006 .32399 Mdot
.65525 .50634 Mdot
.5188 .57855 Mdot
.71091 .50299 Mdot
.64027 .51617 Mdot
.49054 .56281 Mdot
.50296 .59401 Mdot
.58483 .4781 Mdot
.76753 .67226 Mdot
.29309 .57884 Mdot
.65077 .47854 Mdot
.62325 .61367 Mdot
.53203 .58547 Mdot
.51679 .61887 Mdot
.46458 .27237 Mdot
.30991 .55942 Mdot
.5269 .50144 Mdot
.4812 .58383 Mdot
.56016 .1933 Mdot
.44325 .5943 Mdot
.6445 .53652 Mdot
.58713 .34945 Mdot
.35247 .25778 Mdot
.50108 .30213 Mdot
.63483 .49429 Mdot
.26265 .55559 Mdot
.64928 .54362 Mdot
.47759 .73279 Mdot
.5751 .3072 Mdot
.68789 .47831 Mdot
.44565 .37947 Mdot
.57158 .34409 Mdot
.548 .3577 Mdot
.59292 .80004 Mdot
.34469 .41996 Mdot
.27086 .54318 Mdot
.58258 .33274 Mdot
.67997 .57938 Mdot
.55421 .33954 Mdot
.63015 .62388 Mdot
.4926 .66237 Mdot
.26184 .64552 Mdot
.61563 .39266 Mdot
.47166 .70651 Mdot
.5465 .31073 Mdot
.28046 .58332 Mdot
.47209 .62125 Mdot
.69427 .50438 Mdot
.29083 .54886 Mdot
.50755 .35284 Mdot
.34838 .39553 Mdot
.68761 .51485 Mdot
.58176 .29888 Mdot
.65435 .47708 Mdot
.36678 .73791 Mdot
.23976 .66735 Mdot
.54862 .24399 Mdot
.56858 .44401 Mdot
.50673 .56813 Mdot
.76947 .44887 Mdot
.49738 .55787 Mdot
.52905 .63599 Mdot
.40345 .40874 Mdot
.29824 .67225 Mdot
.65986 .50067 Mdot
.50254 .85438 Mdot
.56325 .31182 Mdot
.52194 .18048 Mdot
.65661 .44479 Mdot
.55274 .60418 Mdot
.65725 .51946 Mdot
.7086 .48422 Mdot
.59018 .74196 Mdot
.30891 .41698 Mdot
.5119 .54007 Mdot
.48919 .55674 Mdot
.56501 .60816 Mdot
.54943 .35778 Mdot
.48876 .21905 Mdot
.43859 .38766 Mdot
.19314 .62903 Mdot
.35922 .39559 Mdot
.37267 .33845 Mdot
.65661 .52702 Mdot
.29619 .54638 Mdot
.51572 .61681 Mdot
.6713 .44195 Mdot
.63559 .48701 Mdot
.30024 .59532 Mdot
.30461 .56221 Mdot
.44734 .22459 Mdot
.54093 .32169 Mdot
.5318 .57267 Mdot
.54285 .60254 Mdot
.46715 .63557 Mdot
.48192 .6585 Mdot
.59442 .32935 Mdot
.46719 .59127 Mdot
.55831 .37472 Mdot
.67482 .58615 Mdot
.53831 .18187 Mdot
.46172 .37802 Mdot
.40813 .58768 Mdot
.69294 .51749 Mdot
.68376 .57257 Mdot
.44947 .56998 Mdot
.27018 .30265 Mdot
.49564 .8102 Mdot
.53779 .55795 Mdot
.43038 .39378 Mdot
.40598 .646 Mdot
.33952 .42625 Mdot
.11141 .44823 Mdot
.42297 .29317 Mdot
.72644 .73412 Mdot
.52689 .58494 Mdot
.46738 .2729 Mdot
.42934 .59974 Mdot
.48487 .5627 Mdot
.44561 .29601 Mdot
.6504 .26159 Mdot
.6853 .39065 Mdot
.31585 .56458 Mdot
.4839 .6157 Mdot
.71578 .4996 Mdot
.52753 .59161 Mdot
.51964 .62228 Mdot
.49287 .57379 Mdot
.59066 .30409 Mdot
.44592 .59935 Mdot
.45548 .62095 Mdot
.3709 .48392 Mdot
.34532 .6665 Mdot
.36537 .38374 Mdot
.51517 .74185 Mdot
.28653 .54872 Mdot
.66629 .52117 Mdot
.63715 .42964 Mdot
.53818 .34119 Mdot
.59116 .7284 Mdot
.46032 .6355 Mdot
.62878 .38613 Mdot
.57988 .29794 Mdot
.29616 .55732 Mdot
.4507 .40197 Mdot
.67175 .79082 Mdot
.38939 .42527 Mdot
.46969 .38067 Mdot
.39667 .41114 Mdot
.62166 .55979 Mdot
.65363 .514 Mdot
.50272 .56685 Mdot
.57944 .33129 Mdot
.40015 .40304 Mdot
.31244 .66064 Mdot
.50975 .64255 Mdot
.37645 .41928 Mdot
.5 .56822 Mdot
.2627 .66078 Mdot
.23679 .39637 Mdot
.31794 .42153 Mdot
.52387 .3225 Mdot
.56693 .34187 Mdot
.30489 .55066 Mdot
.67532 .52314 Mdot
.69495 .49186 Mdot
.57532 .34678 Mdot
.1544 .46232 Mdot
.53556 .63302 Mdot
.52356 .58103 Mdot
.42506 .20034 Mdot
.52207 .59631 Mdot
.40552 .72455 Mdot
.46901 .38331 Mdot
.68404 .52325 Mdot
.51173 .57585 Mdot
.47155 .60555 Mdot
.48397 .62529 Mdot
.36093 .73742 Mdot
.36784 .3952 Mdot
.53424 .63962 Mdot
.30562 .57322 Mdot
.42537 .42472 Mdot
.52452 .58021 Mdot
.56438 .60655 Mdot
.6934 .48989 Mdot
.52417 .16773 Mdot
.54389 .32642 Mdot
.41844 .40994 Mdot
.33499 .4071 Mdot
.46435 .33173 Mdot
.60641 .48992 Mdot
.46805 .38383 Mdot
.21748 .65611 Mdot
.47793 .36472 Mdot
.27381 .56729 Mdot
.4014 .3631 Mdot
.34938 .52987 Mdot
.42508 .40031 Mdot
.59686 .34701 Mdot
.4709 .65611 Mdot
.52562 .64741 Mdot
.35122 .23083 Mdot
.55424 .60776 Mdot
.29836 .57009 Mdot
.56767 .37509 Mdot
.68914 .49673 Mdot
.29863 .55907 Mdot
.54906 .32701 Mdot
.67877 .51162 Mdot
.46865 .58116 Mdot
.4582 .5947 Mdot
.67828 .48225 Mdot
.70207 .4939 Mdot
.51076 .60431 Mdot
.38711 .43773 Mdot
.66663 .53693 Mdot
.67757 .47293 Mdot
.38213 .43006 Mdot
.40634 .42195 Mdot
.5682 .62733 Mdot
.55516 .32614 Mdot
.46003 .60741 Mdot
.36999 .42659 Mdot
.30103 .54174 Mdot
.66521 .49886 Mdot
.47306 .60183 Mdot
.48503 .58946 Mdot
.27448 .57637 Mdot
.31373 .55007 Mdot
.30007 .55664 Mdot
.56453 .37764 Mdot
.47727 .64851 Mdot
.65311 .49067 Mdot
.54787 .31444 Mdot
.31729 .56265 Mdot
.2759 .59297 Mdot
.42863 .48607 Mdot
.53287 .6048 Mdot
.47438 .42996 Mdot
.88935 .60307 Mdot
.40587 .70766 Mdot
.42489 .42064 Mdot
.33795 .42096 Mdot
.33504 .6878 Mdot
.30109 .34776 Mdot
.56268 .35558 Mdot
.42216 .71133 Mdot
.25058 .5783 Mdot
.49471 .5665 Mdot
.4552 .57987 Mdot
.53117 .55075 Mdot
.28766 .55516 Mdot
.38574 .74232 Mdot
.70511 .48641 Mdot
.59533 .6824 Mdot
.28708 .54911 Mdot
.31659 .42221 Mdot
.32759 .40543 Mdot
.35831 .39578 Mdot
.45136 .58958 Mdot
.60805 .73176 Mdot
.64702 .58202 Mdot
.78125 .46277 Mdot
.53492 .33956 Mdot
.62152 .52146 Mdot
.43565 .79428 Mdot
.67324 .4814 Mdot
.32867 .3979 Mdot
.28326 .55441 Mdot
.69158 .47908 Mdot
.59099 .33188 Mdot
.57071 .32957 Mdot
.36666 .39357 Mdot
.38227 .40672 Mdot
.40487 .39082 Mdot
.6515 .53068 Mdot
.65268 .52437 Mdot
.49223 .64328 Mdot
.67464 .49348 Mdot
.44235 .17168 Mdot
.30815 .53747 Mdot
.32571 .40526 Mdot
.55005 .34342 Mdot
.65604 .51327 Mdot
.50797 .64569 Mdot
.34253 .36893 Mdot
.72445 .3378 Mdot
.27749 .58745 Mdot
.24644 .38155 Mdot
.11386 .46864 Mdot
.53777 .58115 Mdot
.56235 .36043 Mdot
.31728 .28296 Mdot
.50949 .637 Mdot
.36052 .40582 Mdot
.74522 .31734 Mdot
.44175 .40414 Mdot
.46041 .60102 Mdot
.55439 .60434 Mdot
.55441 .36411 Mdot
.33599 .74673 Mdot
.49431 .64716 Mdot
.62934 .29833 Mdot
.5967 .31934 Mdot
.40028 .38251 Mdot
.47178 .85661 Mdot
.48678 .28377 Mdot
.2902 .62508 Mdot
.40138 .42573 Mdot
.53368 .61993 Mdot
.4115 .41123 Mdot
.28124 .58709 Mdot
.41235 .40245 Mdot
.62499 .50536 Mdot
.38696 .38338 Mdot
.48735 .59882 Mdot
.64934 .49249 Mdot
.5605 .35363 Mdot
.50177 .18156 Mdot
.35497 .4823 Mdot
.3891 .40551 Mdot
.39564 .42907 Mdot
.50917 .57252 Mdot
.56051 .49814 Mdot
.46957 .68278 Mdot
.52964 .58536 Mdot
.58284 .31474 Mdot
.66093 .52243 Mdot
.55669 .30214 Mdot
.53941 .64677 Mdot
.63416 .24147 Mdot
.54268 .3367 Mdot
.62093 .4028 Mdot
.27608 .57035 Mdot
.44632 .49927 Mdot
.51179 .64795 Mdot
.58265 .32918 Mdot
.47639 .64858 Mdot
.7098 .50847 Mdot
.5003 .44494 Mdot
.51899 .27325 Mdot
.5781 .33222 Mdot
.59826 .82537 Mdot
.45626 .45274 Mdot
.44832 .63073 Mdot
.58129 .31822 Mdot
.58833 .64597 Mdot
.41462 .42216 Mdot
.27276 .55953 Mdot
.31696 .56229 Mdot
.28934 .58886 Mdot
.55092 .57433 Mdot
.5124 .53564 Mdot
.25927 .55727 Mdot
.58914 .35008 Mdot
.31012 .553 Mdot
.64521 .44116 Mdot
.61047 .82096 Mdot
.27697 .5447 Mdot
.49249 .62666 Mdot
.55997 .55867 Mdot
.34093 .66475 Mdot
.32185 .4034 Mdot
.74227 .70739 Mdot
.42141 .58373 Mdot
.52235 .60687 Mdot
.53922 .52664 Mdot
.70292 .48559 Mdot
.30611 .30029 Mdot
.48352 .72364 Mdot
.28831 .3541 Mdot
.68939 .52768 Mdot
.48582 .34133 Mdot
.67923 .52388 Mdot
.53216 .57725 Mdot
.51165 .5798 Mdot
.69544 .46474 Mdot
.51193 .20511 Mdot
.40898 .25634 Mdot
.45842 .8325 Mdot
.67684 .47161 Mdot
.57802 .31965 Mdot
.5943 .32635 Mdot
.53554 .3378 Mdot
.30042 .44184 Mdot
.65168 .47483 Mdot
.48113 .64553 Mdot
.37 .42032 Mdot
.54107 .62437 Mdot
.57851 .33915 Mdot
.50878 .85325 Mdot
.69252 .49269 Mdot
.50713 .60918 Mdot
.16153 .50133 Mdot
.37319 .40925 Mdot
.26799 .56897 Mdot
.27593 .67839 Mdot
.30207 .42826 Mdot
.5719 .30345 Mdot
.6999 .46972 Mdot
.51616 .38592 Mdot
.61252 .42131 Mdot
.56934 .61179 Mdot
.53596 .67206 Mdot
.34776 .788 Mdot
.32872 .44348 Mdot
.51386 .56193 Mdot
.42071 .41178 Mdot
.48427 .34159 Mdot
.47548 .60296 Mdot
.68532 .47089 Mdot
.30595 .58583 Mdot
.30774 .5709 Mdot
.48236 .55279 Mdot
.5684 .43791 Mdot
.43204 .50363 Mdot
.46455 .6092 Mdot
.44353 .58438 Mdot
.33253 .40928 Mdot
.47775 .36689 Mdot
.47435 .18487 Mdot
.26791 .54924 Mdot
.48401 .57974 Mdot
.71763 .4068 Mdot
.64117 .51467 Mdot
.39907 .38631 Mdot
.57763 .30664 Mdot
.38141 .75189 Mdot
.41808 .38465 Mdot
.47524 .60093 Mdot
.47036 .60387 Mdot
.5484 .35917 Mdot
.64403 .5364 Mdot
.28545 .55593 Mdot
.34756 .41545 Mdot
.26583 .55074 Mdot
.64106 .50353 Mdot
.68996 .49304 Mdot
.57037 .56046 Mdot
.44865 .57862 Mdot
.37846 .39817 Mdot
.5463 .63587 Mdot
.31761 .4117 Mdot
.32777 .74461 Mdot
.5456 .3055 Mdot
.54127 .585 Mdot
.63247 .47465 Mdot
.5828 .33618 Mdot
.49877 .59896 Mdot
.34299 .79584 Mdot
.54992 .60582 Mdot
.49779 .31485 Mdot
.61807 .23337 Mdot
.29735 .57956 Mdot
.52365 .75576 Mdot
.54659 .51761 Mdot
.5192 .59369 Mdot
.34545 .39327 Mdot
.45717 .681 Mdot
.54377 .34951 Mdot
.67001 .52966 Mdot
.13547 .5135 Mdot
.55673 .34025 Mdot
.52439 .58655 Mdot
.29492 .5582 Mdot
.70474 .47706 Mdot
.46517 .37526 Mdot
.40165 .21565 Mdot
.44463 .65783 Mdot
.45621 .64139 Mdot
.46151 .6011 Mdot
.79896 .39041 Mdot
.41874 .40805 Mdot
.65506 .50951 Mdot
.55017 .3578 Mdot
.57573 .34888 Mdot
.36252 .39676 Mdot
.67487 .38066 Mdot
.4505 .49397 Mdot
.89371 .52689 Mdot
.39223 .39714 Mdot
.27314 .53808 Mdot
.58567 .45532 Mdot
.34835 .38997 Mdot
.37824 .41819 Mdot
.33548 .41207 Mdot
.60456 .38483 Mdot
.67914 .50881 Mdot
.48622 .58717 Mdot
.694 .5314 Mdot
.53552 .61886 Mdot
.38512 .54812 Mdot
.5846 .33737 Mdot
.67111 .53062 Mdot
.35226 .79655 Mdot
.73408 .4839 Mdot
.50309 .63272 Mdot
.41656 .79578 Mdot
.4722 .68017 Mdot
.37778 .72179 Mdot
.47097 .67321 Mdot
.39069 .40917 Mdot
.41963 .64376 Mdot
.5563 .62589 Mdot
.47626 .17346 Mdot
.54906 .34142 Mdot
.41319 .42461 Mdot
.53623 .56446 Mdot
.44319 .59221 Mdot
.71376 .4772 Mdot
.68927 .47686 Mdot
.2641 .55044 Mdot
.33064 .59892 Mdot
.55624 .35302 Mdot
.24322 .66427 Mdot
.51763 .60211 Mdot
.55749 .22613 Mdot
.54796 .73845 Mdot
.49923 .60057 Mdot
.64177 .78717 Mdot
.60059 .73042 Mdot
.50922 .65168 Mdot
.59696 .62326 Mdot
.56599 .32788 Mdot
.61864 .23925 Mdot
.49875 .6694 Mdot
.35976 .40728 Mdot
.65711 .52562 Mdot
.69633 .47428 Mdot
.25908 .57072 Mdot
.27462 .27795 Mdot
.54349 .31244 Mdot
.66522 .53043 Mdot
.51519 .63914 Mdot
.56531 .30379 Mdot
.36492 .4298 Mdot
.5309 .65929 Mdot
.43458 .72654 Mdot
.67802 .49423 Mdot
.51601 .66181 Mdot
.67915 .30227 Mdot
.30976 .61453 Mdot
.8346 .56837 Mdot
.53628 .3382 Mdot
.29019 .54395 Mdot
.49947 .68882 Mdot
.21452 .63399 Mdot
.54953 .56305 Mdot
.26885 .6515 Mdot
.61096 .47822 Mdot
.29423 .54371 Mdot
.50546 .62549 Mdot
.48227 .62961 Mdot
.58534 .43948 Mdot
.31079 .54454 Mdot
.54558 .6081 Mdot
.42115 .60006 Mdot
.67472 .51228 Mdot
.444 .40997 Mdot
.68104 .49751 Mdot
.49529 .63288 Mdot
.52532 .53558 Mdot
.69865 .49208 Mdot
.23165 .67673 Mdot
.24444 .57267 Mdot
.54253 .32718 Mdot
.47113 .55344 Mdot
.48482 .6629 Mdot
.80027 .35134 Mdot
.41873 .42326 Mdot
.7823 .41969 Mdot
.40707 .38013 Mdot
.71272 .41644 Mdot
.48791 .279 Mdot
.71633 .75665 Mdot
.51429 .1891 Mdot
.48702 .55819 Mdot
.39264 .58284 Mdot
.6127 .59116 Mdot
.55923 .30243 Mdot
.73044 .58358 Mdot
.52143 .60454 Mdot
.52019 .62467 Mdot
.41532 .38876 Mdot
.65166 .37886 Mdot
.34461 .2706 Mdot
.54758 .43416 Mdot
.28319 .55954 Mdot
.64347 .49154 Mdot
.49784 .58702 Mdot
.38691 .52371 Mdot
.37888 .38387 Mdot
.54526 .22595 Mdot
.5066 .61515 Mdot
.26355 .31462 Mdot
.58063 .39422 Mdot
.5487 .31107 Mdot
.33614 .39953 Mdot
.30295 .42465 Mdot
.53706 .61 Mdot
.58703 .31444 Mdot
.49762 .64841 Mdot
.43548 .46037 Mdot
.55196 .62547 Mdot
.27868 .54526 Mdot
.501 .56987 Mdot
.53913 .41736 Mdot
.81038 .62775 Mdot
.44717 .71404 Mdot
.67848 .46585 Mdot
.31146 .40971 Mdot
.36884 .39607 Mdot
.69265 .48207 Mdot
.37133 .39803 Mdot
.59721 .70058 Mdot
.68259 .69601 Mdot
.28039 .56335 Mdot
.44628 .57734 Mdot
.26504 .55552 Mdot
.41876 .42369 Mdot
.52852 .60761 Mdot
.21811 .66207 Mdot
.39056 .39997 Mdot
.67522 .24349 Mdot
.55423 .34373 Mdot
.41645 .42389 Mdot
.54036 .63587 Mdot
.41029 .36012 Mdot
.33691 .39171 Mdot
.48924 .33333 Mdot
.48545 .62845 Mdot
.69387 .4984 Mdot
.47893 .62382 Mdot
.46641 .67338 Mdot
.45647 .39596 Mdot
.46829 .65158 Mdot
.54915 .32699 Mdot
.65019 .5349 Mdot
.65487 .79729 Mdot
.49822 .31062 Mdot
.53825 .59973 Mdot
.5137 .63845 Mdot
.71336 .48803 Mdot
.51647 .65836 Mdot
.59232 .32557 Mdot
.78771 .25777 Mdot
.27546 .57042 Mdot
.3367 .42879 Mdot
.48889 .28576 Mdot
.54029 .55821 Mdot
.46733 .61058 Mdot
.38436 .81147 Mdot
.51704 .26099 Mdot
.56669 .31692 Mdot
.44276 .67015 Mdot
.36442 .41973 Mdot
.29566 .55976 Mdot
.58225 .36009 Mdot
.45855 .61736 Mdot
.51415 .62038 Mdot
.28667 .54483 Mdot
.59833 .80348 Mdot
.27986 .35884 Mdot
.53564 .34867 Mdot
.42123 .6486 Mdot
.3081 .38302 Mdot
.53409 .63473 Mdot
.291 .43381 Mdot
.68355 .47601 Mdot
.57023 .30825 Mdot
.78699 .44403 Mdot
.49427 .56889 Mdot
.58952 .33936 Mdot
.55343 .35104 Mdot
.51637 .67918 Mdot
.71295 .46861 Mdot
.641 .52511 Mdot
.64954 .48108 Mdot
.47467 .15784 Mdot
.32096 .62281 Mdot
.40416 .39071 Mdot
.56767 .32741 Mdot
.32667 .42286 Mdot
.29741 .53253 Mdot
.38621 .53244 Mdot
.32135 .42348 Mdot
.7036 .49317 Mdot
.32453 .40988 Mdot
.48148 .62512 Mdot
.5625 .35428 Mdot
.42382 .39891 Mdot
.54053 .56698 Mdot
.538 .50701 Mdot
.42896 .4499 Mdot
.29455 .59212 Mdot
.27272 .60039 Mdot
.50728 .5815 Mdot
.42995 .41748 Mdot
.51208 .60655 Mdot
.54638 .36696 Mdot
.59971 .42696 Mdot
.54424 .56256 Mdot
.38359 .4033 Mdot
.47506 .53146 Mdot
.30341 .42923 Mdot
.45165 .67483 Mdot
.49372 .627 Mdot
.53544 .62785 Mdot
.49704 .64909 Mdot
.66359 .39887 Mdot
.53734 .31578 Mdot
.5 .50363 Mdot
.46558 .3503 Mdot
.67289 .48787 Mdot
.63068 .4852 Mdot
.26677 .42781 Mdot
.32032 .42858 Mdot
.5571 .32561 Mdot
.52378 .64412 Mdot
.50232 .29453 Mdot
.51843 .85411 Mdot
.23496 .68464 Mdot
.30052 .59697 Mdot
.43398 .40159 Mdot
.6763 .46399 Mdot
.35146 .38628 Mdot
.53229 .61723 Mdot
.51004 .68438 Mdot
.70167 .77482 Mdot
.51593 .34593 Mdot
.28455 .5542 Mdot
.53553 .62548 Mdot
.30551 .61967 Mdot
.37138 .41992 Mdot
.33453 .41377 Mdot
.54771 .61117 Mdot
.62947 .51251 Mdot
.84957 .46574 Mdot
.5492 .30988 Mdot
.41787 .58006 Mdot
.69688 .5525 Mdot
.63651 .26864 Mdot
.58267 .34317 Mdot
.39451 .44993 Mdot
.43539 .40348 Mdot
.54925 .76552 Mdot
.67735 .48659 Mdot
.28485 .55151 Mdot
.53072 .67395 Mdot
.70039 .50461 Mdot
.44748 .39074 Mdot
.68998 .52173 Mdot
.50978 .56566 Mdot
.54846 .30625 Mdot
.33936 .40613 Mdot
.52127 .33406 Mdot
.68133 .45969 Mdot
.26543 .57621 Mdot
.55121 .48516 Mdot
.74636 .59775 Mdot
.59823 .72945 Mdot
.53143 .64219 Mdot
.37656 .52626 Mdot
.47605 .64513 Mdot
.716 .47748 Mdot
.50436 .64682 Mdot
.64917 .55541 Mdot
.3421 .39674 Mdot
.51219 .66373 Mdot
.46362 .59602 Mdot
.70058 .60007 Mdot
.4993 .61731 Mdot
.48274 .67205 Mdot
.51193 .65183 Mdot
.61578 .51 Mdot
.43937 .61453 Mdot
.6855 .50607 Mdot
.39518 .22272 Mdot
.38037 .4178 Mdot
.30357 .58864 Mdot
.30854 .57444 Mdot
.26251 .64127 Mdot
.35935 .57497 Mdot
.66459 .38283 Mdot
.67441 .50268 Mdot
.54536 .33924 Mdot
.50076 .64972 Mdot
.78604 .4897 Mdot
.46414 .30892 Mdot
.3651 .42113 Mdot
.49761 .31378 Mdot
.47822 .69936 Mdot
.79997 .38949 Mdot
.53814 .64097 Mdot
.35033 .22574 Mdot
.52091 .5463 Mdot
.54918 .59983 Mdot
.32975 .39187 Mdot
.35978 .57254 Mdot
.53909 .6345 Mdot
.71402 .47838 Mdot
.27681 .55182 Mdot
.74401 .48481 Mdot
.35709 .31851 Mdot
.37904 .44505 Mdot
.71846 .63149 Mdot
.48289 .65156 Mdot
.34177 .40764 Mdot
.68664 .51524 Mdot
.48875 .18545 Mdot
.54931 .31362 Mdot
.61182 .38871 Mdot
.6516 .5943 Mdot
.3796 .78566 Mdot
.28139 .55161 Mdot
.59339 .80193 Mdot
.48758 .59712 Mdot
.30244 .45707 Mdot
.48934 .56422 Mdot
.52227 .85333 Mdot
.26706 .54125 Mdot
.62824 .5025 Mdot
.57663 .31911 Mdot
.70777 .51256 Mdot
.60315 .74251 Mdot
.56376 .27175 Mdot
.51209 .4671 Mdot
.37908 .42648 Mdot
.51516 .49866 Mdot
.64904 .4993 Mdot
.47122 .59461 Mdot
.89561 .55494 Mdot
.67915 .47397 Mdot
.63649 .49315 Mdot
.3026 .72673 Mdot
.30419 .73295 Mdot
.45425 .69165 Mdot
.69963 .51536 Mdot
.38355 .42497 Mdot
.2835 .58154 Mdot
.47893 .63129 Mdot
.48937 .64291 Mdot
.69692 .49321 Mdot
.32742 .39914 Mdot
.40773 .60599 Mdot
.38569 .40826 Mdot
.67523 .51406 Mdot
.37549 .41311 Mdot
.48938 .31738 Mdot
.42681 .40497 Mdot
.49143 .66367 Mdot
.50353 .6477 Mdot
.32008 .34768 Mdot
.6898 .49314 Mdot
.46639 .61794 Mdot
.49594 .57706 Mdot
.65197 .49331 Mdot
.40807 .37951 Mdot
.77288 .52545 Mdot
.53133 .59848 Mdot
.48294 .61049 Mdot
.29142 .543 Mdot
.34761 .51929 Mdot
.21238 .42236 Mdot
.47218 .62177 Mdot
.29157 .5347 Mdot
.65417 .53146 Mdot
.50899 .60454 Mdot
.63758 .44244 Mdot
.48639 .33297 Mdot
.49286 .57064 Mdot
.4174 .41984 Mdot
.55692 .58469 Mdot
.836 .5161 Mdot
.5365 .59007 Mdot
.65556 .5034 Mdot
.65032 .51769 Mdot
.31413 .72762 Mdot
.66673 .47794 Mdot
.39177 .42775 Mdot
.57436 .34186 Mdot
.54642 .85099 Mdot
.36125 .4297 Mdot
.5509 .59239 Mdot
.15344 .51436 Mdot
.51825 .66384 Mdot
.5378 .56268 Mdot
.78108 .34974 Mdot
.36212 .42931 Mdot
.65158 .51433 Mdot
.62437 .34611 Mdot
.50339 .54617 Mdot
.57272 .30439 Mdot
.54247 .65381 Mdot
.45979 .63966 Mdot
.60058 .23371 Mdot
.73995 .33541 Mdot
.57163 .37341 Mdot
.57491 .59477 Mdot
.47175 .6218 Mdot
.36551 .50144 Mdot
.51183 .64399 Mdot
.26523 .55333 Mdot
.63993 .48921 Mdot
.37938 .38662 Mdot
.28135 .57676 Mdot
.51914 .59858 Mdot
.28964 .55461 Mdot
.40503 .3899 Mdot
.57873 .31116 Mdot
.533 .61018 Mdot
.25136 .55761 Mdot
.28464 .55872 Mdot
.4712 .63957 Mdot
.66522 .52952 Mdot
.44709 .70543 Mdot
.50625 .60298 Mdot
.47626 .59165 Mdot
.69489 .49219 Mdot
.20365 .66816 Mdot
.54292 .59496 Mdot
.4663 .43522 Mdot
.63604 .48803 Mdot
.51527 .28718 Mdot
.40814 .38898 Mdot
.4619 .64481 Mdot
.58514 .31496 Mdot
.58536 .33441 Mdot
.35397 .42458 Mdot
.71331 .50082 Mdot
.31832 .40576 Mdot
.47255 .53404 Mdot
.46652 .55794 Mdot
.51444 .6721 Mdot
.15094 .45311 Mdot
.69676 .77143 Mdot
.68604 .47001 Mdot
.44102 .3861 Mdot
.54672 .43731 Mdot
.57068 .32437 Mdot
.33546 .4224 Mdot
.70409 .47473 Mdot
.68101 .46447 Mdot
.69137 .51803 Mdot
.30177 .55309 Mdot
.43882 .38433 Mdot
.63594 .53174 Mdot
.63016 .51441 Mdot
.48352 .62622 Mdot
.4704 .62117 Mdot
.57531 .65298 Mdot
.36946 .68333 Mdot
.26254 .57411 Mdot
.35837 .3989 Mdot
.70362 .20898 Mdot
.55233 .37082 Mdot
.70061 .60333 Mdot
.54178 .56118 Mdot
.82638 .71731 Mdot
.5453 .63241 Mdot
.5163 .64078 Mdot
.65939 .53612 Mdot
.25001 .5681 Mdot
.26556 .55888 Mdot
.64777 .50108 Mdot
.68388 .46147 Mdot
.27024 .54825 Mdot
.52225 .81865 Mdot
.6083 .82416 Mdot
.62642 .31303 Mdot
.65732 .49587 Mdot
.74239 .62148 Mdot
.5792 .30647 Mdot
.68098 .45854 Mdot
.55176 .36774 Mdot
.37023 .41807 Mdot
.43796 .40167 Mdot
.54628 .35656 Mdot
.48761 .63196 Mdot
.41267 .39485 Mdot
.44716 .61164 Mdot
.55522 .82486 Mdot
.68311 .73158 Mdot
.48199 .2479 Mdot
.46067 .5742 Mdot
.35376 .26258 Mdot
.35683 .27493 Mdot
.51578 .58776 Mdot
.7087 .43375 Mdot
.28621 .55377 Mdot
.64384 .45848 Mdot
.5916 .32302 Mdot
.83752 .55742 Mdot
.5309 .6384 Mdot
.65936 .50354 Mdot
.54875 .3363 Mdot
.3179 .71818 Mdot
.63204 .30308 Mdot
.53671 .62013 Mdot
.89113 .50026 Mdot
.6232 .47148 Mdot
.38196 .38691 Mdot
.19757 .38653 Mdot
.68884 .53517 Mdot
.29058 .60451 Mdot
.45929 .36535 Mdot
.38013 .79841 Mdot
.66617 .52082 Mdot
.45035 .38711 Mdot
.6441 .49357 Mdot
.26023 .563 Mdot
.65539 .44938 Mdot
.34005 .41136 Mdot
.50269 .62078 Mdot
.36983 .40116 Mdot
.26471 .57792 Mdot
.30088 .44644 Mdot
.58973 .31955 Mdot
.41486 .42326 Mdot
.56767 .33539 Mdot
.31736 .6102 Mdot
.6558 .24776 Mdot
.54888 .31831 Mdot
.28912 .69945 Mdot
.51143 .56109 Mdot
.65218 .53982 Mdot
.38951 .39421 Mdot
.46194 .36745 Mdot
.55653 .47184 Mdot
.66776 .4863 Mdot
.35219 .39825 Mdot
.65516 .58752 Mdot
.18019 .56565 Mdot
.50844 .53611 Mdot
.3447 .61245 Mdot
.65485 .49223 Mdot
.33281 .41547 Mdot
.42637 .19961 Mdot
.70446 .49166 Mdot
.39352 .39696 Mdot
.58204 .32305 Mdot
.57901 .34694 Mdot
.54447 .6213 Mdot
.61938 .35188 Mdot
.3699 .39033 Mdot
.39569 .23945 Mdot
.6394 .51198 Mdot
.31967 .7164 Mdot
.27046 .58732 Mdot
.38901 .41813 Mdot
.54895 .63769 Mdot
.71238 .53408 Mdot
.48512 .33151 Mdot
.39937 .62923 Mdot
.70042 .21266 Mdot
.36218 .39751 Mdot
.63817 .49229 Mdot
.66323 .50197 Mdot
.47116 .68228 Mdot
.57232 .44034 Mdot
.31587 .40564 Mdot
.2127 .60615 Mdot
.27937 .66208 Mdot
.4536 .39508 Mdot
.36806 .28719 Mdot
.55534 .60472 Mdot
.47589 .65128 Mdot
.57163 .3226 Mdot
.49719 .62203 Mdot
.63661 .52485 Mdot
.53372 .64157 Mdot
.58241 .34869 Mdot
.40261 .41853 Mdot
.52899 .61129 Mdot
.28635 .58311 Mdot
.59093 .36303 Mdot
.55044 .36197 Mdot
.39494 .41417 Mdot
.69794 .516 Mdot
.23829 .58658 Mdot
.38104 .40626 Mdot
.48485 .65162 Mdot
.46708 .37351 Mdot
.50961 .56773 Mdot
.52908 .7974 Mdot
.70588 .4996 Mdot
.34655 .38931 Mdot
.63604 .48215 Mdot
.56293 .33488 Mdot
.46499 .35168 Mdot
.50051 .63858 Mdot
.39562 .39876 Mdot
.33059 .33094 Mdot
.5494 .81043 Mdot
.71562 .49303 Mdot
.39545 .2919 Mdot
.63244 .50195 Mdot
.45248 .39721 Mdot
.44874 .76066 Mdot
.27518 .55947 Mdot
.3559 .41847 Mdot
.6968 .76083 Mdot
.38435 .40086 Mdot
.49747 .61309 Mdot
.49871 .59322 Mdot
.42004 .39112 Mdot
.30888 .55797 Mdot
.54028 .17692 Mdot
.43377 .44117 Mdot
.65755 .51846 Mdot
.50617 .75811 Mdot
.76166 .26865 Mdot
.57294 .29069 Mdot
.56929 .31969 Mdot
.49387 .55246 Mdot
.55218 .60536 Mdot
.57146 .36698 Mdot
.59349 .31354 Mdot
.25864 .57649 Mdot
.33948 .41459 Mdot
.65118 .44906 Mdot
.59811 .3304 Mdot
.58427 .58701 Mdot
.35763 .57827 Mdot
.43039 .64445 Mdot
.53862 .52871 Mdot
.45669 .58957 Mdot
.25746 .64972 Mdot
.57027 .35878 Mdot
.50272 .58043 Mdot
.43806 .63847 Mdot
.57359 .31144 Mdot
.26142 .55989 Mdot
.72555 .31977 Mdot
.36325 .41182 Mdot
.36225 .82916 Mdot
.52147 .57434 Mdot
.50015 .61002 Mdot
.53495 .33664 Mdot
.34514 .5029 Mdot
.69836 .50333 Mdot
.70706 .50427 Mdot
.4197 .40617 Mdot
.53304 .4865 Mdot
.50915 .65948 Mdot
.51281 .58486 Mdot
.34897 .40743 Mdot
.4173 .4227 Mdot
.44359 .24158 Mdot
.48397 .59215 Mdot
.55039 .33574 Mdot
.45943 .37601 Mdot
.57651 .35581 Mdot
.52831 .57322 Mdot
.49569 .60963 Mdot
.49495 .66385 Mdot
.55258 .6028 Mdot
.54606 .36032 Mdot
.49956 .58279 Mdot
.54958 .54703 Mdot
.68449 .52652 Mdot
.48391 .65954 Mdot
.27023 .65964 Mdot
.48881 .62127 Mdot
.27116 .57914 Mdot
.35461 .558 Mdot
.53681 .6259 Mdot
.48116 .66104 Mdot
.43748 .44146 Mdot
.50822 .62805 Mdot
.5465 .36683 Mdot
.67146 .49165 Mdot
.56843 .32751 Mdot
.55201 .36021 Mdot
.41027 .42068 Mdot
.25768 .56335 Mdot
.52547 .55518 Mdot
.29111 .58758 Mdot
.5711 .59185 Mdot
.50265 .56421 Mdot
.44737 .34853 Mdot
.34568 .22688 Mdot
.27844 .36228 Mdot
.49939 .63923 Mdot
.40744 .41381 Mdot
.372 .386 Mdot
.40256 .57705 Mdot
.44423 .61351 Mdot
.57837 .36444 Mdot
.58235 .32947 Mdot
.40721 .7205 Mdot
.59955 .23538 Mdot
.26505 .57486 Mdot
.38317 .52951 Mdot
.44601 .59514 Mdot
.48657 .58352 Mdot
.53098 .65816 Mdot
.3222 .42327 Mdot
.47402 .37415 Mdot
.36617 .42122 Mdot
.49354 .33291 Mdot
.58297 .35005 Mdot
.51796 .65215 Mdot
.72565 .70029 Mdot
.69369 .47909 Mdot
.67236 .49156 Mdot
.58142 .35853 Mdot
.31332 .41238 Mdot
.53935 .68365 Mdot
.12921 .55057 Mdot
.61955 .48803 Mdot
.26979 .5905 Mdot
.52087 .58883 Mdot
.40167 .41364 Mdot
.67101 .46932 Mdot
.31161 .55516 Mdot
.48949 .57466 Mdot
.31689 .40059 Mdot
.49655 .64116 Mdot
.61173 .59079 Mdot
.67126 .52724 Mdot
.54232 .85795 Mdot
.70425 .47861 Mdot
.59687 .35437 Mdot
.56205 .31322 Mdot
.49731 .60005 Mdot
.16396 .43299 Mdot
.66222 .54114 Mdot
.60433 .37546 Mdot
.25947 .54901 Mdot
.46762 .3712 Mdot
.28773 .53797 Mdot
.34995 .38997 Mdot
.27788 .55214 Mdot
.33633 .40446 Mdot
.3952 .70303 Mdot
.62318 .53575 Mdot
.27695 .57373 Mdot
.40125 .48992 Mdot
.44339 .60267 Mdot
.31537 .5712 Mdot
.55415 .5596 Mdot
.53215 .76164 Mdot
.35178 .40706 Mdot
.30819 .56184 Mdot
.47079 .59637 Mdot
.80854 .59373 Mdot
.55212 .32238 Mdot
.57594 .36646 Mdot
.4524 .63812 Mdot
.3403 .41588 Mdot
.70394 .46888 Mdot
.61959 .42279 Mdot
.51198 .30035 Mdot
.50783 .58281 Mdot
.53728 .63724 Mdot
.6295 .48696 Mdot
.64418 .54685 Mdot
.49439 .60449 Mdot
.69933 .579 Mdot
.4905 .59107 Mdot
.58842 .32878 Mdot
.69842 .47862 Mdot
.66621 .49788 Mdot
.35724 .39196 Mdot
.68872 .5303 Mdot
.51597 .52734 Mdot
.52086 .39447 Mdot
.54176 .55319 Mdot
.55865 .3404 Mdot
.5644 .42221 Mdot
.49728 .31427 Mdot
.76036 .67745 Mdot
.63952 .4703 Mdot
.47339 .65942 Mdot
.63595 .50382 Mdot
.29996 .56286 Mdot
.68736 .49375 Mdot
.65457 .47178 Mdot
.51071 .59816 Mdot
.53349 .6206 Mdot
.37899 .42827 Mdot
.567 .44157 Mdot
.66868 .53235 Mdot
.50309 .58466 Mdot
.51238 .66583 Mdot
.48025 .67172 Mdot
.48712 .43773 Mdot
.68182 .4686 Mdot
.65267 .62575 Mdot
.45062 .74323 Mdot
.6716 .53198 Mdot
.83745 .49582 Mdot
.47387 .36367 Mdot
.33068 .42824 Mdot
.52789 .31523 Mdot
.48327 .59197 Mdot
.42658 .3916 Mdot
.53218 .61657 Mdot
.54398 .52907 Mdot
.51667 .62129 Mdot
.29765 .53887 Mdot
.48687 .55832 Mdot
.44678 .40153 Mdot
.37826 .40423 Mdot
.5239 .58184 Mdot
.52676 .6136 Mdot
.30983 .44063 Mdot
.67766 .46087 Mdot
.69747 .50646 Mdot
.32033 .50001 Mdot
.28728 .56921 Mdot
.57191 .30678 Mdot
.50906 .64984 Mdot
.41381 .41132 Mdot
.37141 .40241 Mdot
.70719 .51542 Mdot
.36228 .40672 Mdot
.53957 .32136 Mdot
.50393 .64003 Mdot
.5723 .36748 Mdot
.30796 .56633 Mdot
.64786 .48142 Mdot
.52614 .64339 Mdot
.48307 .62516 Mdot
.65041 .51765 Mdot
.50528 .55964 Mdot
.29069 .54262 Mdot
.37892 .39954 Mdot
.67364 .52064 Mdot
.57627 .3418 Mdot
.34201 .39549 Mdot
.47408 .61081 Mdot
.69277 .20714 Mdot
.49278 .61363 Mdot
.47657 .59949 Mdot
.66131 .80345 Mdot
.49464 .55523 Mdot
.37646 .39243 Mdot
.62628 .4968 Mdot
.44962 .61935 Mdot
.28211 .64009 Mdot
.23049 .68476 Mdot
.36187 .42558 Mdot
.52817 .59109 Mdot
.76136 .68613 Mdot
.52781 .587 Mdot
.24029 .65857 Mdot
.22849 .4481 Mdot
.46708 .50567 Mdot
.5539 .53809 Mdot
.53919 .34563 Mdot
.3834 .42808 Mdot
.34314 .39682 Mdot
.56837 .70142 Mdot
.50977 .59268 Mdot
.6012 .59332 Mdot
.46968 .58863 Mdot
.58165 .34531 Mdot
.45823 .72979 Mdot
.36219 .3997 Mdot
.38055 .21338 Mdot
.48107 .64658 Mdot
.68402 .46791 Mdot
.32411 .40805 Mdot
.47694 .3592 Mdot
.47305 .60032 Mdot
.29921 .58279 Mdot
.53474 .36941 Mdot
.50095 .54433 Mdot
.56125 .34457 Mdot
.49095 .57754 Mdot
.57237 .5606 Mdot
.21905 .34215 Mdot
.67714 .527 Mdot
.57519 .32012 Mdot
.35778 .28257 Mdot
.49851 .55881 Mdot
.66994 .52178 Mdot
.67601 .48636 Mdot
.26638 .58293 Mdot
.5244 .45085 Mdot
.68147 .31461 Mdot
.74883 .64632 Mdot
.52213 .74432 Mdot
.33041 .41784 Mdot
.40497 .26358 Mdot
.47628 .62863 Mdot
.53889 .23166 Mdot
.55878 .37294 Mdot
.50129 .61375 Mdot
.55664 .74076 Mdot
.65621 .47634 Mdot
.48299 .60472 Mdot
.26462 .55571 Mdot
.51578 .21393 Mdot
.52269 .22776 Mdot
.81361 .43236 Mdot
.37627 .42519 Mdot
.53378 .66495 Mdot
.53203 .529 Mdot
.40172 .42763 Mdot
.48536 .56957 Mdot
.37998 .39451 Mdot
.4687 .80101 Mdot
.30446 .54695 Mdot
.6601 .47182 Mdot
.47497 .36224 Mdot
.45364 .59762 Mdot
.49894 .67347 Mdot
.29992 .59055 Mdot
.46415 .63828 Mdot
.27599 .27947 Mdot
.47279 .26937 Mdot
.4205 .39861 Mdot
.68935 .52041 Mdot
.45193 .58868 Mdot
.47123 .37857 Mdot
.50632 .59529 Mdot
.6794 .71488 Mdot
.47375 .65796 Mdot
.66509 .29889 Mdot
.65705 .52592 Mdot
.56245 .34187 Mdot
.56167 .63128 Mdot
.51752 .62795 Mdot
.32541 .37439 Mdot
.55882 .54032 Mdot
.53467 .58619 Mdot
.71281 .47941 Mdot
.69045 .47408 Mdot
.68449 .50561 Mdot
.37838 .38299 Mdot
.58397 .23692 Mdot
.55533 .332 Mdot
.55747 .59908 Mdot
.5985 .33089 Mdot
.40922 .62291 Mdot
.29301 .59328 Mdot
.80473 .55794 Mdot
.46304 .64187 Mdot
.67644 .50607 Mdot
.72875 .39729 Mdot
.65144 .53023 Mdot
.41025 .37675 Mdot
.55731 .3535 Mdot
.66681 .47214 Mdot
.51739 .63558 Mdot
.55528 .43091 Mdot
.80365 .49496 Mdot
.57334 .32935 Mdot
.56615 .57587 Mdot
.43164 .40818 Mdot
.49109 .28955 Mdot
.74916 .23978 Mdot
.56455 .3171 Mdot
.36857 .27504 Mdot
.51183 .58825 Mdot
.697 .48418 Mdot
.53715 .33739 Mdot
.54591 .3257 Mdot
.355 .40451 Mdot
.53412 .62277 Mdot
.53303 .62984 Mdot
.44952 .39569 Mdot
.58263 .33173 Mdot
.4807 .67794 Mdot
.54395 .64066 Mdot
.70079 .77689 Mdot
.55913 .69353 Mdot
.24262 .73858 Mdot
.46182 .53961 Mdot
.56131 .746 Mdot
.5979 .45533 Mdot
.64083 .48438 Mdot
.53801 .62249 Mdot
.46241 .57865 Mdot
.36531 .39127 Mdot
.49836 .62801 Mdot
.37933 .38002 Mdot
.55791 .32298 Mdot
.83252 .49321 Mdot
.73726 .3566 Mdot
.45933 .79427 Mdot
.50087 .62708 Mdot
.62054 .25603 Mdot
.29434 .57394 Mdot
.59739 .36008 Mdot
.68074 .51386 Mdot
.51796 .56492 Mdot
.30291 .4344 Mdot
.36035 .41937 Mdot
.68003 .48055 Mdot
.36766 .24369 Mdot
.29529 .4101 Mdot
.52798 .57264 Mdot
.39897 .38435 Mdot
.69009 .41357 Mdot
.70733 .57233 Mdot
.59571 .30443 Mdot
.29321 .53782 Mdot
.37034 .42108 Mdot
.57884 .35753 Mdot
.61603 .46776 Mdot
.66767 .47419 Mdot
.62325 .51676 Mdot
.26745 .40225 Mdot
.30909 .41499 Mdot
.2837 .57878 Mdot
.58954 .23762 Mdot
.57424 .22233 Mdot
.29609 .53871 Mdot
.44284 .39566 Mdot
.68305 .47133 Mdot
.66304 .51308 Mdot
.67013 .49216 Mdot
.39704 .2045 Mdot
.71208 .49619 Mdot
.70171 .62936 Mdot
.51031 .66817 Mdot
.59029 .57573 Mdot
.52962 .59048 Mdot
.5534 .36754 Mdot
.66696 .52626 Mdot
.58092 .4602 Mdot
.55097 .58299 Mdot
.81454 .46041 Mdot
.51164 .583 Mdot
.59874 .3095 Mdot
.48088 .59947 Mdot
.72716 .59902 Mdot
.63383 .49182 Mdot
.49744 .63377 Mdot
.5269 .33815 Mdot
.28717 .56122 Mdot
.71152 .46474 Mdot
.5358 .62658 Mdot
.64911 .37066 Mdot
.50238 .5526 Mdot
.50569 .81765 Mdot
.34346 .72491 Mdot
.27044 .59101 Mdot
.41871 .60695 Mdot
.34283 .4208 Mdot
.5938 .58347 Mdot
.46341 .55364 Mdot
.57322 .3309 Mdot
.71243 .2861 Mdot
.38175 .41944 Mdot
.45284 .71952 Mdot
.45169 .67747 Mdot
.25908 .56042 Mdot
.70156 .5381 Mdot
.53965 .35962 Mdot
.5368 .56683 Mdot
.51401 .68027 Mdot
.48292 .80202 Mdot
.47391 .54936 Mdot
.52181 .65458 Mdot
.30376 .58611 Mdot
.65621 .63279 Mdot
.48601 .62122 Mdot
.42992 .38007 Mdot
.62391 .51095 Mdot
.4494 .62959 Mdot
.65434 .6211 Mdot
.50367 .5855 Mdot
.68706 .48028 Mdot
.6411 .54311 Mdot
.7068 .37065 Mdot
.25581 .55635 Mdot
.47326 .65735 Mdot
.37214 .75518 Mdot
.47834 .64839 Mdot
.55095 .33947 Mdot
.54155 .58862 Mdot
.35561 .4168 Mdot
.37692 .22218 Mdot
.39897 .39059 Mdot
.53978 .60758 Mdot
.66472 .49413 Mdot
.53871 .35141 Mdot
.27208 .37963 Mdot
.24792 .45095 Mdot
.69496 .62839 Mdot
.3515 .79816 Mdot
.30657 .55501 Mdot
.31003 .54131 Mdot
.53547 .3549 Mdot
.49587 .63344 Mdot
.33216 .73961 Mdot
.51109 .54619 Mdot
.48185 .60917 Mdot
.51747 .62017 Mdot
.57001 .24612 Mdot
.56513 .32446 Mdot
.36971 .40986 Mdot
.49406 .60713 Mdot
.50061 .58444 Mdot
.63909 .5027 Mdot
.28511 .56103 Mdot
.39299 .3873 Mdot
.27913 .56766 Mdot
.40172 .40721 Mdot
.83875 .50837 Mdot
.56326 .59632 Mdot
.28884 .56311 Mdot
.56196 .37563 Mdot
.69522 .49159 Mdot
.47573 .37344 Mdot
.34789 .39134 Mdot
.35705 .39837 Mdot
.50924 .58387 Mdot
.69245 .4833 Mdot
.68267 .53191 Mdot
.30089 .5634 Mdot
.5539 .31208 Mdot
.53699 .61223 Mdot
.50727 .56347 Mdot
.42528 .54127 Mdot
.31697 .41989 Mdot
.66482 .57889 Mdot
.69296 .38674 Mdot
.49731 .63759 Mdot
.69828 .51745 Mdot
.5205 .61199 Mdot
.72019 .71774 Mdot
.70332 .49516 Mdot
.54875 .60213 Mdot
.57335 .21098 Mdot
.46425 .37478 Mdot
.66463 .34125 Mdot
.49561 .66639 Mdot
.40154 .82585 Mdot
.47247 .63027 Mdot
.74267 .72904 Mdot
.33097 .4663 Mdot
.51901 .65242 Mdot
.4784 .62545 Mdot
.76555 .62642 Mdot
.52087 .59565 Mdot
.44702 .4035 Mdot
.45052 .72036 Mdot
.67769 .46339 Mdot
.5859 .47056 Mdot
.34614 .53257 Mdot
.25373 .55725 Mdot
.41997 .40571 Mdot
.37465 .29597 Mdot
.27597 .54624 Mdot
.6555 .49688 Mdot
.49686 .64942 Mdot
.49704 .49035 Mdot
.45185 .39023 Mdot
.46001 .67224 Mdot
.55178 .34473 Mdot
.43502 .27963 Mdot
.3945 .38002 Mdot
.57039 .34243 Mdot
.45537 .6135 Mdot
.7759 .5361 Mdot
.21767 .44465 Mdot
.55581 .8572 Mdot
.53541 .34719 Mdot
.58619 .33984 Mdot
.44815 .18482 Mdot
.25748 .54905 Mdot
.49068 .78223 Mdot
.64631 .2934 Mdot
.55432 .3056 Mdot
.42743 .75737 Mdot
.36217 .42212 Mdot
.64719 .35885 Mdot
.644 .45843 Mdot
.51752 .67024 Mdot
.51704 .63359 Mdot
.55816 .31013 Mdot
.63583 .44692 Mdot
.21104 .35962 Mdot
.56913 .33506 Mdot
.56604 .56066 Mdot
.48048 .45835 Mdot
.47497 .36485 Mdot
.35291 .4299 Mdot
.25448 .56282 Mdot
.33146 .56861 Mdot
.64213 .50212 Mdot
.25825 .57339 Mdot
.51473 .22678 Mdot
.46379 .64078 Mdot
.57777 .33386 Mdot
.48402 .35829 Mdot
.57564 .34563 Mdot
.26991 .55223 Mdot
.26296 .58606 Mdot
.68586 .52595 Mdot
.697 .5053 Mdot
.57619 .74096 Mdot
.38558 .7205 Mdot
.52634 .58473 Mdot
.78141 .44576 Mdot
.64182 .51636 Mdot
.43958 .57513 Mdot
.29426 .53584 Mdot
.28653 .56501 Mdot
.60301 .62287 Mdot
.51727 .64928 Mdot
.30112 .71803 Mdot
.51656 .64803 Mdot
.42965 .73105 Mdot
.48215 .56954 Mdot
.35802 .40564 Mdot
.51217 .65369 Mdot
.24182 .56035 Mdot
.55512 .60454 Mdot
.5321 .5823 Mdot
.3469 .41888 Mdot
.49222 .54696 Mdot
.35385 .41619 Mdot
.54122 .60667 Mdot
.29252 .53279 Mdot
.41513 .41056 Mdot
.31926 .63233 Mdot
.46312 .43694 Mdot
.43037 .41604 Mdot
.27752 .5846 Mdot
.27788 .58931 Mdot
.27151 .62689 Mdot
.67925 .51497 Mdot
.72831 .48282 Mdot
.49467 .62955 Mdot
.33375 .41318 Mdot
.56872 .32185 Mdot
.49736 .5857 Mdot
.48339 .56382 Mdot
.51673 .66008 Mdot
.64242 .48811 Mdot
.31564 .40823 Mdot
.29187 .55858 Mdot
.39434 .38342 Mdot
.33702 .37507 Mdot
.41101 .38278 Mdot
.43748 .62832 Mdot
.54107 .66651 Mdot
.56016 .77397 Mdot
.77747 .40211 Mdot
.5208 .17643 Mdot
.671 .47573 Mdot
.41712 .42073 Mdot
.25867 .57921 Mdot
.427 .68615 Mdot
.6762 .51103 Mdot
.34169 .41232 Mdot
.49721 .64202 Mdot
.56826 .58012 Mdot
.51154 .33894 Mdot
.59564 .57983 Mdot
.29709 .67323 Mdot
.36559 .38065 Mdot
.45923 .38893 Mdot
.56717 .22423 Mdot
.47092 .71986 Mdot
.54613 .48056 Mdot
.5096 .6131 Mdot
.30217 .58044 Mdot
.6711 .46934 Mdot
.24615 .40382 Mdot
.58033 .31549 Mdot
.57026 .4405 Mdot
.50078 .62831 Mdot
.61678 .28637 Mdot
.6659 .49272 Mdot
.26136 .56457 Mdot
.56009 .30934 Mdot
.24926 .56939 Mdot
.34782 .4303 Mdot
.30978 .74651 Mdot
.47155 .64524 Mdot
.53575 .58982 Mdot
.59858 .34178 Mdot
.64495 .49421 Mdot
.27165 .59926 Mdot
.52747 .81306 Mdot
.41379 .39072 Mdot
.28903 .71202 Mdot
.65625 .53697 Mdot
.72362 .62926 Mdot
.38909 .38299 Mdot
.58218 .35774 Mdot
.27588 .62328 Mdot
.58155 .34988 Mdot
.53964 .6256 Mdot
.67123 .50176 Mdot
.55141 .32478 Mdot
.35277 .36185 Mdot
.78797 .64739 Mdot
.73582 .62706 Mdot
.49295 .65683 Mdot
.81264 .53719 Mdot
.58871 .82122 Mdot
.70638 .44677 Mdot
.58925 .31722 Mdot
.50542 .6008 Mdot
.46165 .59379 Mdot
.4846 .64842 Mdot
.54686 .34815 Mdot
.42701 .34418 Mdot
.34734 .40281 Mdot
.51947 .58509 Mdot
.26142 .57979 Mdot
.35885 .41596 Mdot
.47106 .35554 Mdot
.36686 .39316 Mdot
.65652 .46505 Mdot
.55115 .60193 Mdot
.60487 .39639 Mdot
.81612 .63008 Mdot
.56961 .32792 Mdot
.43082 .41563 Mdot
.51096 .57174 Mdot
.63738 .24926 Mdot
.68265 .50619 Mdot
.41635 .39154 Mdot
.50073 .61005 Mdot
.40817 .35061 Mdot
.30476 .43965 Mdot
.36358 .39447 Mdot
.66706 .51626 Mdot
.70783 .44145 Mdot
.49683 .62423 Mdot
.4706 .63155 Mdot
.64683 .49582 Mdot
.31188 .51818 Mdot
.39079 .21935 Mdot
.52433 .61355 Mdot
.56405 .34192 Mdot
.16175 .58752 Mdot
.48934 .67118 Mdot
.52936 .7149 Mdot
.36523 .42769 Mdot
.66854 .37473 Mdot
.66899 .57658 Mdot
.41493 .62946 Mdot
.77091 .62836 Mdot
.39607 .52753 Mdot
.82913 .50566 Mdot
.34222 .38134 Mdot
.37955 .4701 Mdot
.83625 .52125 Mdot
.52893 .33467 Mdot
.59125 .53271 Mdot
.42045 .5718 Mdot
.35829 .23487 Mdot
.63394 .43997 Mdot
.29839 .49303 Mdot
.28382 .40239 Mdot
.47346 .48374 Mdot
.39035 .40062 Mdot
.40754 .6882 Mdot
.53498 .61336 Mdot
.58103 .8247 Mdot
.70389 .58242 Mdot
.19719 .37022 Mdot
.81314 .54775 Mdot
.376 .75518 Mdot
.79882 .5178 Mdot
.74077 .70824 Mdot
.54638 .77392 Mdot
.77112 .40922 Mdot
.20608 .63779 Mdot
.55649 .21331 Mdot
.3999 .77793 Mdot
.50577 .69131 Mdot
.38887 .52292 Mdot
.44101 .81288 Mdot
.69569 .65693 Mdot
.15623 .46071 Mdot
.37663 .38861 Mdot
.62692 .5009 Mdot
.42286 .56104 Mdot
.72012 .49673 Mdot
.56836 .28097 Mdot
.77701 .62196 Mdot
.7259 .74126 Mdot
.72117 .59802 Mdot
.40178 .8288 Mdot
.58035 .70743 Mdot
.42363 .15476 Mdot
.4315 .45247 Mdot
.63668 .53669 Mdot
.2199 .52022 Mdot
.57987 .22623 Mdot
.71642 .33365 Mdot
.45517 .54177 Mdot
.47478 .32287 Mdot
.33659 .65342 Mdot
.65915 .50251 Mdot
.70061 .5697 Mdot
.3302 .43228 Mdot
.72491 .3262 Mdot
.26352 .60917 Mdot
.7694 .65668 Mdot
.51193 .47807 Mdot
.63893 .36926 Mdot
.41297 .25621 Mdot
.69514 .20898 Mdot
.39129 .74264 Mdot
.64787 .777 Mdot
.53861 .29586 Mdot
.65004 .43724 Mdot
.30671 .28059 Mdot
.36305 .69909 Mdot
.58097 .22465 Mdot
.73683 .28586 Mdot
.5489 .84267 Mdot
.77287 .31161 Mdot
.72227 .47472 Mdot
.51523 .66015 Mdot
.64357 .76934 Mdot
.51004 .74199 Mdot
.32768 .55521 Mdot
.80621 .40661 Mdot
.30876 .56912 Mdot
.72265 .48268 Mdot
.36298 .24145 Mdot
.7117 .61601 Mdot
.28547 .70433 Mdot
.25892 .5964 Mdot
.46078 .57311 Mdot
.19527 .29979 Mdot
.82438 .50475 Mdot
.69931 .36839 Mdot
.70308 .77516 Mdot
.60529 .26881 Mdot
.32887 .724 Mdot
.54861 .32962 Mdot
.83565 .57034 Mdot
.66609 .51028 Mdot
.87183 .49735 Mdot
.81053 .6195 Mdot
.20743 .39684 Mdot
.10273 .53016 Mdot
.51067 .24553 Mdot
.49414 .5022 Mdot
.39027 .53711 Mdot
.29977 .65226 Mdot
.23363 .33899 Mdot
.18385 .43514 Mdot
.59047 .24897 Mdot
.40298 .80934 Mdot
.8306 .55047 Mdot
.43997 .76084 Mdot
.34056 .762 Mdot
.34339 .2512 Mdot
.4802 .43331 Mdot
.70342 .54105 Mdot
.45669 .42339 Mdot
.76603 .47706 Mdot
.80485 .38489 Mdot
.50169 .73364 Mdot
.13032 .55994 Mdot
.24191 .58406 Mdot
.31902 .4711 Mdot
.65155 .79348 Mdot
.33484 .62434 Mdot
.47492 .74759 Mdot
.47923 .18765 Mdot
.43999 .65785 Mdot
.51198 .19504 Mdot
.74919 .44409 Mdot
.39011 .29297 Mdot
.5445 .21102 Mdot
.65442 .41007 Mdot
.49872 .80663 Mdot
.6663 .74283 Mdot
.59659 .22528 Mdot
.67655 .46232 Mdot
.34049 .69122 Mdot
.40671 .75093 Mdot
.69041 .7853 Mdot
.35851 .28225 Mdot
.5899 .86148 Mdot
.32069 .29609 Mdot
.54883 .56007 Mdot
.50423 .53545 Mdot
.55773 .65815 Mdot
.36683 .71509 Mdot
.51805 .66152 Mdot
.59775 .25495 Mdot
.67507 .79794 Mdot
.55081 .73702 Mdot
.39118 .3032 Mdot
.72419 .29493 Mdot
.56185 .85465 Mdot
.57797 .78359 Mdot
.33658 .44819 Mdot
.53338 .70369 Mdot
.52589 .1587 Mdot
.37609 .41538 Mdot
.43475 .76241 Mdot
.56424 .29734 Mdot
.25383 .4139 Mdot
.75455 .62873 Mdot
.22625 .3784 Mdot
.67379 .79969 Mdot
.40176 .21884 Mdot
.28392 .35553 Mdot
.24206 .61049 Mdot
.2684 .69537 Mdot
.75323 .33121 Mdot
.55429 .63423 Mdot
.53064 .51535 Mdot
.30547 .58231 Mdot
.59729 .74777 Mdot
.47065 .76082 Mdot
.24548 .48224 Mdot
.53443 .53712 Mdot
.19273 .47676 Mdot
.46097 .38827 Mdot
.5646 .43632 Mdot
.80379 .32192 Mdot
.44672 .65418 Mdot
.52272 .25626 Mdot
.52783 .83591 Mdot
.33129 .70426 Mdot
.65361 .78583 Mdot
.62948 .40238 Mdot
.76714 .31028 Mdot
.79544 .65113 Mdot
.24337 .46311 Mdot
.82861 .46438 Mdot
.66779 .81851 Mdot
.73674 .27356 Mdot
.62779 .5598 Mdot
.53439 .35998 Mdot
.87009 .3935 Mdot
.44427 .38976 Mdot
.68119 .25502 Mdot
.52326 .7434 Mdot
.40583 .33667 Mdot
.69175 .45607 Mdot
.49793 .69859 Mdot
.48235 .48337 Mdot
.61922 .47422 Mdot
.44766 .61209 Mdot
.74221 .25421 Mdot
.69988 .25179 Mdot
.76078 .28209 Mdot
.48601 .83489 Mdot
.83187 .47124 Mdot
.4327 .52379 Mdot
.70735 .63765 Mdot
.39867 .60146 Mdot
.5372 .58086 Mdot
.39188 .67576 Mdot
.50621 .24692 Mdot
.22206 .42702 Mdot
.70147 .32022 Mdot
.718 .48257 Mdot
.79924 .44036 Mdot
.65996 .15508 Mdot
.59452 .69964 Mdot
.62389 .63963 Mdot
.53431 .22735 Mdot
.38922 .72863 Mdot
.7588 .46352 Mdot
.21182 .41758 Mdot
.66984 .79284 Mdot
.40959 .59362 Mdot
.44237 .77529 Mdot
.25861 .4969 Mdot
.22843 .63704 Mdot
.36569 .50475 Mdot
.7841 .63945 Mdot
.38668 .56506 Mdot
.25667 .35835 Mdot
.57517 .48402 Mdot
.20837 .38039 Mdot
.27924 .44826 Mdot
.43593 .27392 Mdot
.41167 .77028 Mdot
.49944 .29709 Mdot
.42453 .73854 Mdot
.49239 .45466 Mdot
.41218 .67664 Mdot
.39841 .52567 Mdot
.42784 .74094 Mdot
.22654 .62991 Mdot
.81367 .39865 Mdot
.65953 .83279 Mdot
.63502 .19119 Mdot
.41557 .83287 Mdot
.736 .43386 Mdot
.50554 .67572 Mdot
.62953 .81715 Mdot
.79749 .33432 Mdot
.79178 .66621 Mdot
.41627 .22196 Mdot
.3764 .3553 Mdot
.5932 .36273 Mdot
.63931 .19765 Mdot
.31299 .49859 Mdot
.70847 .74319 Mdot
.53029 .18198 Mdot
.52502 .31926 Mdot
.33589 .23348 Mdot
.67918 .24396 Mdot
.756 .60811 Mdot
.63108 .58107 Mdot
.46163 .67737 Mdot
.7303 .58286 Mdot
.6368 .47708 Mdot
.39704 .25827 Mdot
.36764 .70806 Mdot
.39124 .41494 Mdot
.36044 .59039 Mdot
.49558 .51878 Mdot
.48606 .55833 Mdot
.35528 .53723 Mdot
.62658 .48438 Mdot
.77656 .40309 Mdot
.56297 .40809 Mdot
.85027 .46745 Mdot
.48701 .25228 Mdot
.56566 .5424 Mdot
.34775 .71502 Mdot
.28996 .35853 Mdot
.46118 .18632 Mdot
.54651 .30816 Mdot
.81219 .57483 Mdot
.47442 .38884 Mdot
.34431 .69584 Mdot
.72952 .57591 Mdot
.51541 .79827 Mdot
.53342 .67487 Mdot
.71025 .38892 Mdot
.64912 .73425 Mdot
.56115 .44205 Mdot
.71865 .52011 Mdot
.67012 .55362 Mdot
.50528 .87792 Mdot
.50101 .21678 Mdot
.42038 .27113 Mdot
.80883 .58593 Mdot
.56105 .35735 Mdot
.66109 .53288 Mdot
.40598 .69879 Mdot
.50224 .81136 Mdot
.67351 .7033 Mdot
.30361 .43849 Mdot
.46735 .3053 Mdot
.26649 .47696 Mdot
.80748 .54853 Mdot
.80482 .52276 Mdot
.19219 .37182 Mdot
.7159 .49818 Mdot
.53992 .79883 Mdot
.45175 .78816 Mdot
.63346 .50738 Mdot
.70201 .45583 Mdot
.70088 .30179 Mdot
.83343 .42555 Mdot
.60998 .38266 Mdot
.39314 .81325 Mdot
.25421 .64156 Mdot
.41709 .35135 Mdot
.2729 .3738 Mdot
.37472 .76757 Mdot
.80472 .59562 Mdot
.71791 .56044 Mdot
.76778 .5804 Mdot
.57641 .59338 Mdot
.59654 .59872 Mdot
.61602 .1782 Mdot
.45934 .44707 Mdot
.72649 .62175 Mdot
.63984 .41408 Mdot
.48413 .65319 Mdot
.69775 .21205 Mdot
.55262 .82639 Mdot
.46653 .17864 Mdot
.54714 .37578 Mdot
.46672 .60863 Mdot
.55595 .62001 Mdot
.56074 .67996 Mdot
.68762 .37542 Mdot
.72099 .27894 Mdot
.37846 .77009 Mdot
.69239 .42408 Mdot
.70833 .57864 Mdot
.52263 .25699 Mdot
.7616 .66685 Mdot
.6104 .81096 Mdot
.53043 .44232 Mdot
.49724 .24635 Mdot
.2883 .61905 Mdot
.42744 .83134 Mdot
.41818 .50209 Mdot
.43412 .52877 Mdot
.64928 .26795 Mdot
.66528 .39042 Mdot
.26023 .381 Mdot
.50022 .57002 Mdot
.36835 .24288 Mdot
.74166 .70499 Mdot
.14734 .46152 Mdot
.26275 .31401 Mdot
.71516 .22291 Mdot
.69885 .69907 Mdot
.64996 .39264 Mdot
.7809 .54415 Mdot
.13675 .47452 Mdot
.38475 .52196 Mdot
.80738 .47004 Mdot
.25683 .61722 Mdot
.80895 .56767 Mdot
.52441 .3326 Mdot
.63318 .30985 Mdot
.71942 .2898 Mdot
.83441 .44471 Mdot
.59539 .78478 Mdot
.7846 .62744 Mdot
.56942 .48277 Mdot
.82526 .3898 Mdot
.64929 .25633 Mdot
.46198 .48612 Mdot
.42112 .4144 Mdot
.4579 .1967 Mdot
.78269 .48774 Mdot
.76417 .4236 Mdot
.43539 .7662 Mdot
.40958 .49577 Mdot
.44448 .71788 Mdot
.75798 .57321 Mdot
.35527 .62701 Mdot
.67351 .39816 Mdot
.3459 .71407 Mdot
.74298 .71244 Mdot
.37728 .51612 Mdot
.28523 .368 Mdot
.50947 .26659 Mdot
.33035 .76457 Mdot
.68986 .37087 Mdot
.49152 .21708 Mdot
.65268 .77489 Mdot
.29532 .46383 Mdot
.3838 .75344 Mdot
.62457 .87943 Mdot
.39415 .78903 Mdot
.7568 .36402 Mdot
.80232 .38199 Mdot
.63983 .79855 Mdot
.77073 .38667 Mdot
.24335 .32256 Mdot
.57478 .67387 Mdot
.39279 .69853 Mdot
.51733 .62183 Mdot
.79676 .3173 Mdot
.34756 .65296 Mdot
.80533 .37887 Mdot
.59648 .83705 Mdot
.73822 .57774 Mdot
.48441 .55843 Mdot
.3484 .38334 Mdot
.39731 .44009 Mdot
.36297 .62258 Mdot
.77426 .58144 Mdot
.56898 .68563 Mdot
.47524 .27616 Mdot
.39073 .4306 Mdot
.33063 .50026 Mdot
.74015 .47074 Mdot
.47391 .24225 Mdot
.68576 .38861 Mdot
.32162 .52905 Mdot
.53963 .46701 Mdot
.4029 .73867 Mdot
.67271 .57738 Mdot
.75305 .61768 Mdot
.22942 .3723 Mdot
.48322 .38836 Mdot
.37644 .3916 Mdot
.73626 .66727 Mdot
.41523 .80466 Mdot
.68892 .40855 Mdot
.75953 .30869 Mdot
.4431 .19588 Mdot
.39064 .62357 Mdot
.44895 .73895 Mdot
.22393 .36074 Mdot
.21117 .63142 Mdot
.79174 .41339 Mdot
.69007 .558 Mdot
.30313 .71546 Mdot
.48092 .51997 Mdot
.83755 .5105 Mdot
.40901 .77771 Mdot
.4908 .7656 Mdot
.44523 .44339 Mdot
.67927 .67484 Mdot
.75011 .56089 Mdot
.3129 .62936 Mdot
.55933 .46913 Mdot
.44002 .14893 Mdot
.65479 .45163 Mdot
.67153 .18562 Mdot
.58592 .32311 Mdot
.38587 .20058 Mdot
.22186 .60256 Mdot
.49319 .45021 Mdot
.56631 .46988 Mdot
.71359 .38341 Mdot
.66422 .29668 Mdot
.44838 .82802 Mdot
.18301 .42015 Mdot
.42811 .38482 Mdot
.33701 .74855 Mdot
.29177 .73669 Mdot
.76174 .63341 Mdot
.44842 .59617 Mdot
.38767 .79028 Mdot
.46532 .44408 Mdot
.22421 .42203 Mdot
.60991 .8225 Mdot
.74417 .41597 Mdot
.56543 .5549 Mdot
.38444 .7239 Mdot
.8051 .47337 Mdot
.79594 .64222 Mdot
.2922 .26459 Mdot
.74846 .44333 Mdot
.54132 .36515 Mdot
.44255 .50845 Mdot
.79452 .57179 Mdot
.30716 .70232 Mdot
.63427 .36467 Mdot
.4012 .75227 Mdot
.57558 .13991 Mdot
.73634 .29596 Mdot
.7203 .27868 Mdot
.33939 .72474 Mdot
.70865 .52345 Mdot
.67913 .27194 Mdot
.46223 .7494 Mdot
.74126 .40498 Mdot
.45772 .81687 Mdot
.42328 .75204 Mdot
.18387 .36408 Mdot
.52888 .76691 Mdot
.33514 .37679 Mdot
.7534 .54636 Mdot
.54501 .75152 Mdot
.53838 .36795 Mdot
.38289 .67521 Mdot
.64732 .41534 Mdot
.59814 .3518 Mdot
.68023 .39691 Mdot
.65225 .36642 Mdot
.50076 .76948 Mdot
.6902 .68758 Mdot
.7058 .42566 Mdot
.71784 .70301 Mdot
.60173 .50693 Mdot
.24775 .40261 Mdot
.30954 .34979 Mdot
.63727 .42662 Mdot
.42736 .39951 Mdot
.41571 .61988 Mdot
.55216 .4459 Mdot
.35925 .56527 Mdot
.61346 .1903 Mdot
.31013 .57044 Mdot
.69865 .52729 Mdot
.43163 .17372 Mdot
.6326 .51459 Mdot
.76333 .27473 Mdot
.21932 .40415 Mdot
.72422 .57876 Mdot
.25358 .45763 Mdot
.23199 .5068 Mdot
.29641 .22225 Mdot
.75776 .50922 Mdot
.44215 .43682 Mdot
.61905 .53908 Mdot
.70815 .49335 Mdot
.48724 .28203 Mdot
.38587 .43058 Mdot
.62265 .59723 Mdot
.54388 .27075 Mdot
.39433 .60917 Mdot
.65691 .54518 Mdot
.37788 .36689 Mdot
.45835 .72537 Mdot
.83764 .43909 Mdot
.38805 .39658 Mdot
.51524 .14671 Mdot
.55983 .56477 Mdot
.63093 .76026 Mdot
.6607 .80738 Mdot
.31394 .24703 Mdot
.31697 .32632 Mdot
.22363 .67617 Mdot
.54227 .55789 Mdot
.71942 .43155 Mdot
.65787 .50645 Mdot
.47388 .76927 Mdot
.27928 .55327 Mdot
.3133 .68008 Mdot
.59884 .33057 Mdot
.2578 .35958 Mdot
.46553 .24527 Mdot
.69563 .53611 Mdot
.75542 .43306 Mdot
.53741 .78527 Mdot
.63854 .30574 Mdot
.46992 .44245 Mdot
.76003 .63218 Mdot
.68371 .69014 Mdot
.65292 .54494 Mdot
.76506 .32589 Mdot
.43699 .7788 Mdot
.84277 .56369 Mdot
.57155 .63513 Mdot
.40648 .45814 Mdot
.62219 .26371 Mdot
.70133 .398 Mdot
.65293 .57756 Mdot
.67529 .79087 Mdot
.35181 .69422 Mdot
.60875 .25814 Mdot
.4229 .73238 Mdot
.45309 .69256 Mdot
.5191 .46664 Mdot
.40689 .24463 Mdot
.21982 .31396 Mdot
.60544 .5911 Mdot
.31442 .26607 Mdot
.67381 .5584 Mdot
.52036 .25485 Mdot
.63197 .46187 Mdot
.35718 .33745 Mdot
.69262 .66591 Mdot
.34263 .29666 Mdot
.84064 .53036 Mdot
.67195 .79373 Mdot
.51449 .33722 Mdot
.48144 .30215 Mdot
.60166 .46807 Mdot
.5801 .59177 Mdot
.59037 .43917 Mdot
.53002 .64508 Mdot
.69449 .44632 Mdot
.34028 .22605 Mdot
.7294 .39845 Mdot
.47578 .68929 Mdot
.8313 .51062 Mdot
.83446 .57785 Mdot
.82188 .38946 Mdot
.28365 .70803 Mdot
.64752 .47779 Mdot
.73717 .2674 Mdot
.64297 .60512 Mdot
.7529 .70478 Mdot
.78882 .41958 Mdot
.52628 .87652 Mdot
.76988 .58524 Mdot
.63008 .41362 Mdot
.18965 .42097 Mdot
.66868 .31822 Mdot
.57887 .83041 Mdot
.44727 .48941 Mdot
.41805 .29152 Mdot
.5781 .83469 Mdot
.22485 .27109 Mdot
.64707 .56006 Mdot
.6444 .36912 Mdot
.45766 .52792 Mdot
.64234 .42214 Mdot
.3503 .46089 Mdot
.54013 .58701 Mdot
.48267 .33739 Mdot
.27731 .36141 Mdot
.40831 .74275 Mdot
.44085 .71726 Mdot
.34863 .46237 Mdot
.36726 .62018 Mdot
.43124 .72888 Mdot
.39657 .77816 Mdot
.76359 .60998 Mdot
.62799 .59154 Mdot
.5717 .58129 Mdot
.6468 .44984 Mdot
.26375 .54677 Mdot
.35623 .30453 Mdot
.54353 .61147 Mdot
.34035 .30179 Mdot
.65095 .30281 Mdot
.72374 .23352 Mdot
.38276 .3213 Mdot
.53044 .82131 Mdot
.64159 .46035 Mdot
.69537 .37972 Mdot
.71086 .71822 Mdot
.36116 .23633 Mdot
.35378 .47962 Mdot
.50096 .73395 Mdot
.81977 .51867 Mdot
.54407 .2127 Mdot
.49425 .79787 Mdot
.60679 .21121 Mdot
.57829 .36986 Mdot
.60938 .56243 Mdot
.44618 .53061 Mdot
.41632 .216 Mdot
.70905 .53342 Mdot
.63466 .4098 Mdot
.42321 .47134 Mdot
.52573 .20438 Mdot
.53056 .83766 Mdot
.5264 .79095 Mdot
.76032 .5335 Mdot
.80767 .52297 Mdot
.35632 .42662 Mdot
.44831 .77922 Mdot
.61264 .41079 Mdot
.37656 .4771 Mdot
.60086 .23371 Mdot
.84587 .48136 Mdot
.58536 .44755 Mdot
.33144 .64655 Mdot
.4725 .63961 Mdot
.65508 .62412 Mdot
.72595 .38997 Mdot
.23472 .56153 Mdot
.45811 .26519 Mdot
.70182 .50012 Mdot
.44063 .25602 Mdot
.34558 .50939 Mdot
.38171 .68898 Mdot
.62072 .53601 Mdot
.53709 .7214 Mdot
.32422 .55511 Mdot
.51245 .29257 Mdot
.46825 .66288 Mdot
.32032 .65548 Mdot
.27701 .6959 Mdot
.6128 .55853 Mdot
.77103 .47442 Mdot
.75278 .64064 Mdot
.48729 .80877 Mdot
.71149 .41066 Mdot
.79032 .4057 Mdot
.6705 .30107 Mdot
.71169 .65175 Mdot
.35411 .26865 Mdot
.51258 .66274 Mdot
.3603 .33743 Mdot
.66179 .53494 Mdot
.78406 .59002 Mdot
.68702 .70856 Mdot
.32148 .63128 Mdot
.51069 .42957 Mdot
.69309 .73523 Mdot
.5006 .41562 Mdot
.64556 .81098 Mdot
.67082 .31921 Mdot
.36648 .70588 Mdot
.54965 .29909 Mdot
.23747 .61241 Mdot
.23485 .34475 Mdot
.82369 .58307 Mdot
.2169 .38367 Mdot
.51219 .49096 Mdot
.31986 .2575 Mdot
.73021 .32227 Mdot
.59048 .83507 Mdot
.3804 .70978 Mdot
.58924 .43765 Mdot
.45104 .71602 Mdot
.51544 .32562 Mdot
.47132 .37947 Mdot
.34122 .34807 Mdot
.62736 .60605 Mdot
.44489 .31761 Mdot
.31683 .31565 Mdot
.52317 .68673 Mdot
.62119 .24026 Mdot
.81324 .51975 Mdot
.50274 .75708 Mdot
.47052 .45214 Mdot
.23672 .43494 Mdot
.3723 .68089 Mdot
.35786 .83333 Mdot
.69496 .20813 Mdot
.47138 .6399 Mdot
.40379 .51967 Mdot
.32604 .67593 Mdot
.40316 .38248 Mdot
.61063 .63049 Mdot
.76994 .62396 Mdot
.58911 .33419 Mdot
.367 .35355 Mdot
.51704 .20216 Mdot
.71861 .37892 Mdot
.33734 .60977 Mdot
.57816 .24717 Mdot
.74173 .2474 Mdot
.42213 .81268 Mdot
.71431 .39882 Mdot
.41559 .85924 Mdot
.39392 .2404 Mdot
.669 .55465 Mdot
.64001 .77409 Mdot
.8148 .39812 Mdot
.33593 .7104 Mdot
.26572 .4038 Mdot
.77271 .36962 Mdot
.36099 .69858 Mdot
.44526 .75446 Mdot
.50889 .26616 Mdot
.44633 .25826 Mdot
.48861 .47119 Mdot
.23347 .50666 Mdot
.64345 .22278 Mdot
.7207 .56496 Mdot
.80889 .49827 Mdot
.2777 .35227 Mdot
.17181 .38112 Mdot
.83617 .56947 Mdot
.38199 .65066 Mdot
.34416 .45534 Mdot
.62753 .78069 Mdot
.27672 .66074 Mdot
.51582 .73584 Mdot
.23807 .38492 Mdot
.65914 .7118 Mdot
.21763 .49683 Mdot
.30079 .29537 Mdot
.42552 .7389 Mdot
.54523 .7476 Mdot
.58283 .45129 Mdot
.74295 .64746 Mdot
.48638 .27043 Mdot
.35424 .72845 Mdot
.34017 .36296 Mdot
.27679 .64515 Mdot
.74311 .66163 Mdot
.68271 .75099 Mdot
.60118 .43832 Mdot
.24627 .25289 Mdot
.8034 .42162 Mdot
.35144 .24806 Mdot
.50754 .66909 Mdot
.84577 .5156 Mdot
.60715 .42479 Mdot
.78857 .39067 Mdot
.50643 .82341 Mdot
.34072 .33344 Mdot
.63018 .27285 Mdot
.51944 .65788 Mdot
.77876 .455 Mdot
.73006 .61768 Mdot
.55116 .75091 Mdot
.26512 .37089 Mdot
.34832 .71227 Mdot
.32818 .44282 Mdot
.29707 .6321 Mdot
.58276 .5529 Mdot
.66028 .53766 Mdot
.77294 .29635 Mdot
.51816 .49483 Mdot
.41776 .62872 Mdot
.58827 .59426 Mdot
.19637 .40325 Mdot
.32528 .78611 Mdot
.58008 .60409 Mdot
.55632 .21863 Mdot
.42857 .76013 Mdot
.40138 .65142 Mdot
.71459 .55091 Mdot
.10746 .58961 Mdot
.68411 .80068 Mdot
.70349 .47174 Mdot
.57023 .69271 Mdot
.34427 .73826 Mdot
.82281 .41024 Mdot
.26117 .49492 Mdot
.30729 .34796 Mdot
.15849 .48534 Mdot
.28163 .67363 Mdot
.4919 .56165 Mdot
.51641 .83696 Mdot
.81816 .59387 Mdot
.26852 .35374 Mdot
.83267 .52172 Mdot
.43209 .61606 Mdot
.55834 .61923 Mdot
.19927 .71051 Mdot
.79725 .58142 Mdot
.44076 .66085 Mdot
.19703 .39416 Mdot
.70829 .53666 Mdot
.52985 .62098 Mdot
.54226 .25445 Mdot
.40547 .7719 Mdot
.4357 .73861 Mdot
.83418 .44301 Mdot
.70894 .52919 Mdot
.33192 .30768 Mdot
.58874 .34762 Mdot
.56309 .47031 Mdot
.56776 .59622 Mdot
.54377 .33966 Mdot
.39369 .64471 Mdot
.62439 .42793 Mdot
.52606 .35819 Mdot
.34388 .76007 Mdot
.57478 .8646 Mdot
.71278 .68044 Mdot
.51743 .36255 Mdot
.48302 .70806 Mdot
.53298 .76547 Mdot
.36483 .62275 Mdot
.39869 .57705 Mdot
.56593 .84405 Mdot
.78288 .73675 Mdot
.4247 .29562 Mdot
.55195 .67864 Mdot
.62361 .53797 Mdot
.6371 .58837 Mdot
.75267 .59959 Mdot
.60627 .36632 Mdot
.37004 .42951 Mdot
.50834 .54742 Mdot
.58321 .55232 Mdot
.5978 .32975 Mdot
.64204 .17713 Mdot
.51689 .57021 Mdot
.7016 .56227 Mdot
.76162 .69048 Mdot
.24863 .39997 Mdot
.61202 .76488 Mdot
.53813 .56176 Mdot
.67053 .26941 Mdot
.59852 .42306 Mdot
.69346 .43453 Mdot
.28575 .36515 Mdot
.82213 .46148 Mdot
.68144 .71401 Mdot
.75573 .53392 Mdot
.50503 .58143 Mdot
.27731 .53441 Mdot
.64691 .35166 Mdot
.77393 .36276 Mdot
.55931 .53214 Mdot
.77701 .67805 Mdot
.33466 .33801 Mdot
.45581 .32099 Mdot
.40791 .64876 Mdot
.79678 .34698 Mdot
.28864 .29418 Mdot
.74369 .5896 Mdot
.43326 .18702 Mdot
.46671 .21225 Mdot
.35542 .63007 Mdot
.3374 .38754 Mdot
.48351 .69334 Mdot
.69708 .54115 Mdot
.76524 .26418 Mdot
.76822 .35211 Mdot
.5385 .39556 Mdot
.43866 .27759 Mdot
.69243 .61719 Mdot
.58447 .4645 Mdot
.48576 .88311 Mdot
.30151 .49471 Mdot
.73459 .23948 Mdot
.47907 .76997 Mdot
.74973 .48007 Mdot
.6513 .4 Mdot
.52012 .53341 Mdot
.36598 .39566 Mdot
.82396 .42632 Mdot
.58573 .55041 Mdot
.32981 .28091 Mdot
.49962 .56252 Mdot
.48761 .17826 Mdot
.52357 .39959 Mdot
.48844 .30044 Mdot
.49657 .30323 Mdot
.24426 .32374 Mdot
.72868 .7127 Mdot
.57745 .42117 Mdot
.45158 .86332 Mdot
.78395 .54877 Mdot
.81282 .57568 Mdot
.30242 .44199 Mdot
.28827 .25629 Mdot
.76939 .42283 Mdot
.699 .42058 Mdot
.54012 .40032 Mdot
.37461 .55805 Mdot
.44194 .2002 Mdot
.40084 .65687 Mdot
.65905 .33918 Mdot
.51904 .32259 Mdot
.85644 .67627 Mdot
.38976 .65996 Mdot
.47723 .52998 Mdot
.37124 .24718 Mdot
.81964 .54897 Mdot
.28528 .52124 Mdot
.53465 .84895 Mdot
.39188 .52121 Mdot
.55961 .62 Mdot
.67861 .70487 Mdot
.49226 .76 Mdot
.47068 .19444 Mdot
.35462 .1783 Mdot
.43135 .81136 Mdot
.44808 .3016 Mdot
.53987 .46112 Mdot
.63463 .50868 Mdot
.69435 .45743 Mdot
.24567 .47532 Mdot
.49004 .85183 Mdot
.62744 .41861 Mdot
.79492 .57327 Mdot
.27853 .24102 Mdot
.49008 .78381 Mdot
.82627 .41337 Mdot
.7611 .38741 Mdot
.66136 .44791 Mdot
.37121 .61841 Mdot
.28998 .60623 Mdot
.48511 .33995 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Mooooo`;o
0000Z_ooool001cooooo00?o0000ooooooooool0WOooool2o`000:[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0;Oooooo0_l0002@ooooo`007?ooool00ol0003oooooooooo`2_oooo
o`;o00001_ooool2o`00093ooooo000Looooo`03o`000?oooooooooo0:Cooooo0_l00009ooooo`;o
0000V?ooool001cooooo00?o0000ooooooooool0Roooool2o`0001Oooooo0_l0002Sooooo`007?oo
ool2o`0008cooooo0_l0000Xooooo`;o0000T_ooool001cooooo00?o0000ooooooooool0Q_ooool2
o`000003ooooool0003o000002[ooooo0_l0000Looooo`;o0000M?ooool001cooooo00?o0000oooo
ooooool0P_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000;ooooo`;o00003oooool2o`00
02[ooooo0_l0001dooooo`007?ooool00ol0003oooooooooo`22ooooo`;o00004_ooool2o`0000Wo
oooo0_l00004ooooo`;o0000X?ooool001cooooo00?o0000ooooooooool0XOooool2o`000:Kooooo
000Looooo`03o`000?oooooooooo0:Oooooo0_l0002Pooooo`007?ooool00ol0003oooooooooo`2<
ooooo`;o00006Oooool2o`000:3ooooo000Looooo`03o`000?oooooooooo08Sooooo0_l00002oooo
o`;o00001oooool4o`00033ooooo0_l0001nooooo`007?ooool00ol0003oooooooooo`1_ooooo`;o
00005oooool2o`0000_ooooo1?l00002ooooo`;o00002?ooool2o`0000Gooooo1?l0000Dooooo`;o
00000oooool2o`0000;ooooo0_l0001jooooo`007?ooool00ol0003oooooooooo`1_ooooo`;o0000
00?oooooo`000?l000007?ooool2o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`0000Cooooo
0ol00004ooooo`Co00005?ooool2o`0000Oooooo0_l0001jooooo`007?ooool00ol0003ooooooooo
o`1booooo`;o00007?ooool2o`0000;ooooo0_l00009ooooo`;o00001Oooool4o`000003ooooool0
003o000009cooooo000Looooo`03o`000?oooooooooo08Wooooo0_l00003ooooo`;o00000_ooool2
o`0000;ooooo1ol00005ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00
000Eooooo`Co00000_ooool2o`0000cooooo0_l0001aooooo`007?ooool00ol0003oooooooooo`29
ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`Wo00000oooool5o`0000[ooooo0_l0000?
ooooo`Co00000_ooool2o`0000cooooo0_l0001aooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^
k^h5ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0Roooool2o`0000;ooooo0_l0
000<ooooo`;o00000_ooool5o`0000_ooooo0ol0000?ooooo`;o00001Oooool2o`0007gooooo0000
1_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01_ooool00ol0003oooooooooo`2;ooooo`?o000000?oooooo`000?l000000_l00002ooooo`;o
00001Oooool2o`0000?ooooo1Ol00005ooooo`;o00001Oooool2o`0001Kooooo0_l0001mooooo`00
00?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo
00?o0000ooooooooool0POooool2o`0000Cooooo0_l00003ooooo`;o00000oooool2o`0000;ooooo
0_l00005ooooo`;o00001Oooool4o`0000?ooooo1?l0000Nooooo`;o0000Noooool00003ooooool0
003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06ooooo`?o0000N_oo
ool2o`0000Gooooo0_l00003ooooo`?o00000oooool2o`0001Kooooo0ol00003ooooo`Co00007_oo
ool2o`0007_ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oMgMg
ofIVI_ooool01Oooool00ol0003oooooooooo`1jooooo`;o000000?oooooo`000?l000001_ooool3
o`0000Cooooo0_l0000Eooooo`?o000000?oooooo`000?l00000X?ooool00003ooooool@413ooooo
00;ooooo00?o410@ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
07gooooo0_l00004ooooo`Ko00006_ooool2o`0000;ooooo0_l0000Iooooo`;o00003?ooool3o`00
00[ooooo0ol000000ooooooo0000o`00001Vooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;
ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`1dooooo`;o00003Ooo
ool6o`0000_ooooo0_l0000=ooooo`;o00002?ooool4o`0000Gooooo0_l00009ooooo`?o00003?oo
ool3o`0000[ooooo1_l0001Vooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1dooooo`;o000000Coooooo`000?l0
003o00002oooool2o`0000gooooo0_l0000:ooooo`?o000000?oooooo`000?l000001oooool6o`00
00?ooooo0_l00004ooooo`;o00000oooool2o`0001cooooo0ol0001Wooooo`007?ooool00ol0003o
ooooooooo`1Qooooo`;o00005?ooool3o`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l0
00005?ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000001oooool2o`0000;o
oooo0_l000000ooooooo0000o`000006ooooo`?o000000?oooooo`000?l000004_ooool2o`0000[o
oooo0_l0001Wooooo`007?ooool00ol0003oooooooooo`1Qooooo`;o00006?ooool2o`000004oooo
ool0003o0000o`0000;ooooo0_l000000ooooooo0000o`00000Cooooo`?o000000?oooooo`000?l0
00004?ooool2o`000003ooooool0003o000000Oooooo0_l000001?oooooo0000o`000?l00008oooo
o`;o00001oooool2o`0007?ooooo000Looooo`03o`000?oooooooooo05gooooo0_l0000Booooo`So
00000_ooool6o`000004ooooool0003o0000o`0000Wooooo0_l0000;ooooo`;o00003?ooool4o`00
00Cooooo0_l000001?oooooo0000o`000?ooool4o`0000Kooooo0_l00008ooooo`Co00005_ooool2
o`0006;ooooo000Looooo`03o`000?oooooooooo05gooooo0_l0000<ooooo`Go000000?oooooo`00
0?l000002?l00002ooooo`;o00000oooool3o`0000Wooooo0_l0000Cooooo`;o000000Coooooo`00
0?l0003ooooo1_l00002ooooo`;o000000Coooooo`000?l0003ooooo1?l00003ooooo`Go00002?oo
ool4o`0001Kooooo0_l0001Rooooo`007?ooool00ol0003oooooooooo`1[ooooo`Go000000Cooooo
o`000?l0003ooooo0_l00003ooooo`;o00000_ooool2o`0000oooooo0_l0000Cooooo`;o000000?o
ooooo`000?l000000_ooool2o`000003ooooool0003o000000;ooooo0_l00006ooooo`;o00000ooo
ool5o`0008Kooooo000Looooo`03o`000?oooooooooo06Wooooo0_l00003ooooo`;o00001?ooool4
o`00017ooooo0_l00003ooooo`;o00002_ooool2o`0000oooooo0_l0000Booooo`Co00000_ooool2
o`0000Sooooo0_l0000Fooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0FOooool2o`00
00kooooo0_l00006ooooo`?o00000_ooool2o`00017ooooo0_l0000?ooooo`;o00003oooool2o`00
00gooooo0_l00003ooooo`Co00000_ooool2o`0000Sooooo0_l0000Fooooo`;o0000H?ooool001co
oooo00?o0000ooooooooool0FOooool2o`0001Kooooo0ol00009ooooo`;o00003_ooool2o`00023o
oooo0_l00009ooooo`Co000000?oooooo`000?l000001?ooool2o`0001Gooooo0_l0000=ooooo`;o
00000oooool2o`0005Oooooo000Looooo`03o`000?oooooooooo05Oooooo0_l0000Iooooo`Co0000
1_ooool3o`0000gooooo0ol00007ooooo`;o00005oooool2o`0000_ooooo0_l00007ooooo`?o0000
0_ooool2o`00013ooooo0_l0000=ooooo`;o00000oooool2o`0005Oooooo000Looooo`03o`000?oo
oooooooo05Oooooo0_l0000Iooooo`Co00001_ooool2o`0000;ooooo0_l0000:ooooo`;o00001Ooo
ool2o`000003ooooool0003o000000[ooooo0_l0000:ooooo`;o00001Oooool2o`0000gooooo1?l0
0002ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`Co0000K_ooool001cooooo00?o0000
ooooooooool0H_ooool2o`0000Kooooo0_l00002ooooo`;o00001?ooool3o`0000Wooooo0_l0000A
ooooo`;o00001?ooool2o`0000?ooooo0_l000001?oooooo0000o`000?l0000:ooooo`;o00001Ooo
ool2o`000003ooooool0003o000000;ooooo0_l00006ooooo`;o00001Oooool2o`0000;ooooo1_l0
0002ooooo`Co00004_ooool2o`0005[ooooo000Looooo`;o0000Hoooool2o`0000Kooooo1_l00004
ooooo`?o00001?ooool2o`0001cooooo0ol00002ooooo`;o000000?oooooo`000?l000002_ooool2
o`0000Wooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l00008ooooo`;o00000oooool3
o`0000Kooooo0_l00005ooooo`;o00002oooool2o`0005[ooooo000Looooo`03o`000?oooooooooo
04cooooo0_l0000Aooooo`;o00002oooool2o`0000gooooo0_l0000Mooooo`;o00002Oooool2o`00
00Gooooo0ol0000?ooooo`Go00005_ooool2o`0000Gooooo0_l0000;ooooo`;o0000F_ooool001co
oooo00?o0000ooooooooool0C?ooool2o`0000cooooo0_l00003ooooo`;o00000oooool2o`0000Wo
oooo0_l00007ooooo`;o00000oooool3o`000004ooooool0003o0000o`0000Oooooo1?l000000ooo
oooo0000o`00000Cooooo`?o00001?ooool2o`0000gooooo0_l000001Ooooooo0000o`000?l0003o
oooo00;o00000_ooool2o`0000Oooooo0_l00008ooooo`;o00004_ooool2o`0000gooooo0_l0001;
ooooo`007?ooool00ol0003oooooooooo`1Jooooo`;o00002?ooool2o`0000Wooooo0_l00007oooo
o`;o00000oooool3o`000004ooooool0003o0000o`0000Oooooo1?l000000ooooooo0000o`00000B
ooooo`Co000000?oooooo`000?l000004?ooool2o`0000Gooooo0_l00002ooooo`;o00000oooool2
o`0000;ooooo0_l0000<ooooo`Co00006oooool2o`0004_ooooo000Looooo`03o`000?oooooooooo
05_ooooo0_l00003ooooo`;o00003Oooool2o`000003ooooool0003o000000_ooooo0ol0000Roooo
o`;o00000oooool2o`0001Cooooo0_l00005ooooo`;o00000oooool2o`0000;ooooo0_l0000<oooo
o`Co00005?ooool2o`0005;ooooo000Looooo`03o`000?oooooooooo05_ooooo0_l00003ooooo`Co
00002_ooool3o`000003ooooool0003o000000_ooooo0ol0000?ooooo`;o000000?oooooo`000?l0
00001?ooool2o`0000Kooooo0_l0000Kooooo`;o000000?oooooo`000?l000000_ooool2o`0000?o
oooo0_l0000<ooooo`;o00004Oooool2o`0000Oooooo0_l0001Booooo`007?ooool00ol0003ooooo
ooooo`1;ooooo`;o00005Oooool2o`0000?ooooo0_l00003ooooo`Oo00005oooool2o`000003oooo
ool0003o000000;ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00006ooooo`;o0000
2Oooool2o`0001;ooooo0ol00007ooooo`?o000000?oooooo`000?l000001Oooool2o`000003oooo
ool0003o0000017ooooo0_l00006ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0AOoo
ool2o`0000Cooooo0_l0000Jooooo`;o00000oooool2o`000003ooooool0003o000000;o00004_oo
ool2o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`[o00001oooool6o`0000Cooooo0_l0
0004ooooo`;o00003?ooool2o`0000Gooooo1_l000000ooooooo0000o`000005ooooo`Ko00004?oo
ool2o`0000Kooooo0_l000000ooooooo0000o`00001@ooooo`007?ooool00ol0003oooooooooo`15
ooooo`;o00005_ooool4o`0000oooooo0_l00002ooooo`;o00001?ooool2o`0000Wooooo0_l00003
ooooo`;o00001_ooool8o`0000Wooooo1_l0000:ooooo`;o000000?oooooo`000?l000001oooool2
o`0000Oooooo0ol00003ooooo`;o00001oooool5o`00013ooooo0_l00006ooooo`;o000000?ooooo
o`000?l00000D?ooool001cooooo00?o0000ooooooooool0EOooool3o`0000Gooooo1?l00005oooo
o`Co000000?oooooo`000?l000000oooool2o`0000;ooooo0_l00004ooooo`;o000000?oooooo`00
0?l000002oooool3o`0000Wooooo0ol00002ooooo`;o00006Oooool2o`0000Oooooo0_l0000=oooo
o`;o00002_ooool2o`0000Oooooo0_l000000ooooooo0000o`00000<ooooo`;o0000Doooool001co
oooo00?o0000ooooooooool0EOooool3o`0000Sooooo0_l000001?oooooo0000o`000?ooool4o`00
0003ooooool0003o000000?ooooo0ol0000:ooooo`;o00001_ooool3o`0000;ooooo0ol0000;oooo
o`;o000000?oooooo`000?l000005?ooool2o`0000;ooooo0_l0000:ooooo`;o00003_ooool2o`00
00?ooooo0_l00002ooooo`;o00001oooool2o`000003ooooool0003o000000_ooooo0_l0001Doooo
o`007?ooool00ol0003oooooooooo`1Kooooo`;o00000oooool2o`000003ooooool0003o000000;o
oooo0_l00007ooooo`?o00004_ooool3o`0000;ooooo0_l00002ooooo`;o00001Oooool2o`000003
ooooool0003o000000?o00005?ooool2o`0000;ooooo0_l0000:ooooo`;o00003_ooool2o`0000?o
oooo0_l0000<ooooo`;o00001_ooool2o`0000Gooooo0_l0001Dooooo`007?ooool00ol0003ooooo
ooooo`1Iooooo`Co00004Oooool4o`0000;ooooo0ol0000Cooooo`;o00000_ooool2o`0000Gooooo
0_l00003ooooo`?o00001oooool2o`000003ooooool0003o000000_ooooo0_l0000?ooooo`;o0000
7?ooool3o`0000Kooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`1Iooooo`Co00004Ooo
ool2o`0000Cooooo0ol00006ooooo`;o00001Oooool2o`0001Cooooo2?l00002ooooo`;o000000?o
ooooo`000?l000002_ooool5o`0000gooooo0_l00004ooooo`;o00005_ooool2o`000003ooooool0
003o0000067ooooo000Looooo`03o`000?oooooooooo04oooooo0_l00009ooooo`?o000000?ooooo
o`000?l000004oooool4o`0000Cooooo1?l00005ooooo`Co00005?ooool6o`000003ooooool0003o
000000Gooooo0_l00006ooooo`Ko00004oooool2o`000003ooooool0003o000000Cooooo0_l00008
ooooo`;o00000oooool2o`000004ooooool0003o0000o`00063ooooo000Looooo`03o`000?oooooo
oooo04oooooo0_l00005ooooo`;o00000_ooool2o`0000;ooooo0_l00004ooooo`;o00001_ooool2
o`0000Gooooo0_l000000ooooooo0000o`000005o`0000Wooooo0_l00005ooooo`;o00003oooool3
o`0000;ooooo0_l00005ooooo`?o00001Oooool4o`0000?ooooo0_l0000>ooooo`;o00000oooool2
o`0000Cooooo0_l00008ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`;o00002_ooool2
o`00053ooooo000Looooo`;o0000?Oooool2o`0000Oooooo0_l0000?ooooo`?o00001oooool2o`00
00;ooooo0_l00006ooooo`Co00001_ooool7o`0000Wooooo0_l00005ooooo`?o00002oooool2o`00
0003ooooool0003o000000?ooooo0_l00006ooooo`;o00000_ooool=o`0000_ooooo1?l00009oooo
o`Co00004oooool2o`0000[ooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`0looooo`;o
00001oooool2o`0000gooooo0_l000000ooooooo0000o`000007ooooo`;o00002Oooool2o`000003
ooooool0003o000000;o00002Oooool2o`0000_ooooo0_l00004ooooo`;o00002Oooool4o`000003
ooooool0003o000000Go00002_oooolAo`0000Oooooo0_l000000ooooooo0000o`000004ooooo`;o
00000_ooool4o`000003ooooool0003o000000Gooooo0_l0001Wooooo`007?ooool00ol0003ooooo
ooooo`1=ooooo`;o00000oooool4o`0001;ooooo1_l00002ooooo`;o00002Oooool2o`0000_ooooo
0_l000000ooooooo0000o`000007ooooo`;o00000oooool2o`0000?ooooo1_l00008ooooo`ko0000
00?oooooo`000?l000000ol0000:ooooo`Co00000_ooool2o`0000?ooooo0_l00002ooooo`;o0000
1Oooool2o`0006Oooooo000Looooo`03o`000?oooooooooo047ooooo0_l0000:ooooo`;o00000ooo
ool2o`000003ooooool0003o000000Gooooo0_l0000:ooooo`?o000000?oooooo`000?l000007Ooo
ool2o`000004ooooool0003o0000ooooo`Go000000?oooooo`000?l000001?ooool4o`0000_ooooo
4Ol00002ooooo`;o00002Oooool4o`0001Gooooo0_l0000>ooooo`Co0000D_ooool001cooooo00?o
0000ooooooooool0@Oooool2o`000003ooooool0003o000000cooooo0_l000000ooooooo0000o`00
0005ooooo`;o00000_ooool2o`0002cooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l0
0004ooooo`?o00002Oooool2o`000003ooooool0003o000001?o00001oooool4o`0000Oooooo0_l0
000>ooooo`;o00003_ooool6o`00053ooooo000Looooo`03o`000?oooooooooo04Cooooo0_l0000<
ooooo`;o00003?ooool2o`000003ooooool0003o000003Wooooo0ol00007oooooa[o00001_ooool2
o`0000Wooooo0_l00005ooooo`;o00003Oooool2o`0000_ooooo0ol0001@ooooo`007?ooool00ol0
003oooooooooo`1Booooo`;o00003oooool2o`0000Wooooo1?l0000Kooooo`;o00002oooool3o`00
0004ooooool0003o0000o`0000Kooooo6ol0000<ooooo`;o00001Oooool7o`0000cooooo0ol00003
ooooo`;o00001_ooool2o`0000Oooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`0ooooo
o`;o00002_ooool2o`00027ooooo1?l00007ooooo`;o00004_ooool2o`000003ooooool0003o0000
00Cooooo0_l00002ooooo`Go00001_oooolLo`0000gooooo0_l00005ooooo`Go00001_ooool2o`00
00Kooooo0ol00003ooooo`;o00001oooool2o`0000Kooooo1?l00016ooooo`007?ooool00ol0003o
ooooooooo`0oooooo`;o00002_ooool3o`0000;ooooo0_l0000Aooooo`?o00002oooool2o`0000Ko
oooo0_l0000Eooooo`;o00001?ooool3o`000003ooooool0003o000000?o00001OoooolKo`0000ko
oooo0_l0000Aooooo`;o00001_ooool3o`0000[ooooo1?l00008ooooo`;o0000A_ooool001cooooo
00?o0000ooooooooool0AOooool2o`0000Gooooo0_l00002ooooo`;o00004?ooool4o`0000_ooooo
0_l00006ooooo`;o00002?ooool2o`0001;ooooo0_l00002ooooo`;o00001oooool2o`0000;ooooo
5ol0000>ooooo`;o00006Oooool4o`0000Wooooo0_l0001Booooo`007?ooool00ol0003ooooooooo
o`0oooooo`;o00001?ooool2o`0000?ooooo1?l0000Dooooo`;o00001?ooool2o`00013ooooo0_l0
0007ooooo`;o00003_ooool2o`0000Gooooo0_l0000=oooooaSo0000:Oooool2o`0000Gooooo0_l0
0007ooooo`;o0000COooool001cooooo00?o0000ooooooooool0?oooool2o`000003ooooool0003o
000000Kooooo0_l0000Looooo`;o000000?oooooo`000?l000003Oooool2o`0001Cooooo0_l00000
0ooooooo0000o`000005ooooo`Go00001oooool:o`000003ooooool0003o000000ko00004?ooool2
o`0001;ooooo0_l00006ooooo`;o00000_ooool2o`0000Oooooo0_l00003ooooo`;o0000B?ooool0
01cooooo00?o0000ooooooooool0@_ooool2o`0000[ooooo0_l0000Iooooo`Co00000oooool3o`00
00;ooooo0_l00009ooooo`;o00003_ooool2o`000003ooooool0003o000000Cooooo1_l00004oooo
o`;o000000?oooooo`000?l000006?l0000Aooooo`;o00004_ooool2o`000003ooooool0003o0000
00;o000000?oooooo`000?l000004?ooool2o`0004Sooooo000Looooo`03o`000?oooooooooo04So
oooo0_l00004ooooo`;o00006Oooool2o`0000Gooooo0ol00002ooooo`;o00002Oooool2o`0001?o
oooo0_l00002ooooo`?o00001_ooool3o`000003ooooool0003o000000go000000?oooooo`000?l0
00002?l0000Booooo`Co00004_ooool4o`0005gooooo000Looooo`03o`000?oooooooooo04?ooooo
0_l00003ooooo`?o00004oooool2o`0002Oooooo0_l0000<ooooo`;o000000?oooooo`000?l00000
0_l00006ooooo`;o00000_oooolMo`0000oooooo1?l0000:ooooo`;o00002Oooool2o`0005cooooo
000Looooo`03o`000?oooooooooo04?ooooo0_l00004ooooo`;o00004oooool2o`0000Cooooo0_l0
000Kooooo`;o00001?ooool2o`000003ooooool0003o000000Sooooo0ol000000ooooooo0000o`00
0002o`0000Gooooo0_l000001?oooooo0000o`000?oooolLo`0000Cooooo0_l00008ooooo`;o0000
3Oooool2o`0000Wooooo0_l0000Booooo`;o0000B?ooool001cooooo0_l0001Oooooo`Go000000?o
ooooo`000?l000001Oooool2o`0001Cooooo0_l00007ooooo`;o00000_ooool2o`0000?ooooo1?l0
0002ooooo`;o00001_ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l00000
5?l00006ooooo`?o00001Oooool2o`000003ooooool0003o000000gooooo1?l00009ooooo`;o0000
2oooool2o`0000?ooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`1Dooooo`Co00002?oo
ool3o`0000Sooooo0_l00006ooooo`;o00003?ooool2o`000003ooooool0003o000000Sooooo0_l0
0003ooooo`Co00000_ooool4o`0000Cooooo0_l00006oooooaGo000000?oooooo`000?l000001?oo
ool3o`0000Kooooo0_l0000?ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Oooooo0_l0
0002ooooo`;o00001?ooool3o`0004Kooooo000Looooo`03o`000?oooooooooo05Cooooo1?l00000
1?oooooo0000o`000?l0000Gooooo`;o00000_ooool2o`0000_ooooo0_l0000=ooooo`Co00000_oo
ool4o`0000Cooooo0_l00005oooooaWo000000Coooooo`000?l0003ooooo1Ol00004ooooo`;o0000
3oooool2o`0000_ooooo0_l00008ooooo`;o00002?ooool3o`0004Kooooo000Looooo`03o`000?oo
oooooooo047ooooo0_l0000=ooooo`;o00001Oooool5o`0001_ooooo0_l00009ooooo`;o00004Ooo
ool7o`0000_ooooo6Ol00002ooooo`;o00001?ooool4o`0000;ooooo0ol0000Dooooo`;o00001Ooo
ool2o`0005_ooooo000Looooo`03o`000?oooooooooo047ooooo0_l00002ooooo`;o00002Oooool2
o`0000Cooooo0ol000000ooooooo0000o`00000?ooooo`;o00000_ooool2o`0000kooooo0_l00000
0ooooooo0000o`00000>ooooo`;o00000_ooool6o`0000Sooooo1Ol000000ooooooo0000o`00000D
o`0000[ooooo0_l00002ooooo`?o00005?ooool2o`00017ooooo0_l0001?ooooo`007?ooool00ol0
003oooooooooo`0hooooo`;o00002_ooool4o`0000_ooooo0_l000000ooooooo0000o`000003o`00
013ooooo0ol000000ooooooo0000o`000008ooooo`;o00001?ooool2o`0000Gooooo0_l00002oooo
o`;o00001Oooool4o`000003ooooool0003o000000;o00002_ooool4o`0000Cooooo3_l000000ooo
oooo0000o`000002o`0000;ooooo0_l00007ooooo`;o00004oooool2o`0000Cooooo0_l0000;oooo
o`;o00001?ooool2o`0004oooooo000Looooo`03o`000?oooooooooo03Sooooo0_l00007ooooo`;o
000000?oooooo`000?l000000_l00005ooooo`;o00001?ooool2o`0000Cooooo0_l0000@ooooo`?o
00002Oooool4o`0000_ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool9o`00013o
oooo2ol000000ooooooo0000o`000006o`0000?ooooo0_l00007ooooo`So00003Oooool3o`00013o
oooo0_l00003ooooo`?o00000oooool2o`0004[ooooo000Looooo`03o`000?oooooooooo03?ooooo
0_l00006ooooo`?o00000oooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0000?o
oooo0_l00003ooooo`Co00004Oooool2o`0000Wooooo0_l00002ooooo`;o00004?ooool2o`0000?o
oooo1ol0000Aooooo`?o000000?oooooo`000?l000002ol00009ooooo`;o00000oooool2o`000003
ooooool0003o000000Co00002_ooool2o`000003ooooool0003o000000?o00004Oooool4o`0000Co
oooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00001_ooool3o`0000Wooooo
0_l000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l000000_l0000=ooooo`;o0000
0_ooool2o`0000oooooo0_l0000<ooooo`;o00002?ooool6o`0000kooooo0_l00007ooooo`[o0000
1oooool2o`000003ooooool0003o000000;ooooo0ol00003ooooo`Go00000_ooool2o`0000Gooooo
0_l00004ooooo`;o00002_ooool2o`0000Gooooo1?l0001@ooooo`007?ooool00ol0003ooooooooo
o`16ooooo`;o00000oooool2o`0000Sooooo0_l0000:ooooo`;o00000oooool2o`000004ooooool0
003o0000o`0000_ooooo0ol000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l00000
0_ooool2o`000003ooooool0003o000000?ooooo2ol0000<ooooo`Co00001Oooool:o`0000;ooooo
0_l00005ooooo`;o00001Oooool2o`0000Oooooo0_l00002ooooo`;o00001Oooool2o`00013ooooo
0_l0001Iooooo`007?ooool00ol0003oooooooooo`0dooooo`;o00000oooool2o`0000Gooooo0_l0
0004ooooo`;o00000oooool3o`000003ooooool0003o000000;o00000_ooool2o`0000[ooooo0_l0
0006ooooo`Co00001_ooool;o`000003ooooool0003o000000[o000000?oooooo`000?l000002Ol0
0005ooooo`;o00001_ooool3o`0000Oooooo0_l00002ooooo`Co00001?ooool2o`0001Cooooo0_l0
0005ooooo`;o00001Oooool2o`0000Kooooo0_l0000Jooooo`;o0000AOooool001cooooo00?o0000
ooooooooool0=?ooool2o`0000?ooooo0_l00005ooooo`;o000000?oooooo`000?l000001oooool2
o`000003ooooool0003o000000;o00000_ooool2o`0000Wooooo0_l00009ooooo`Co000000Cooooo
o`000?l0003ooooo4ol000000ooooooo0000o`000007o`0000Cooooo0ol00005ooooo`;o00001Ooo
ool3o`0000kooooo0_l00005ooooo`;o00000_ooool5o`0000cooooo0_l00002ooooo`;o000000?o
ooooo`000?l000001Oooool2o`0000Cooooo1Ol0000@ooooo`;o00001_ooool3o`0004Gooooo000L
ooooo`03o`000?oooooooooo03cooooo0_l00002ooooo`;o000000?oooooo`000?l000001Oooool2
o`00013ooooo0_l00002ooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`00000G
o`000003ooooool0003o000000ko00003?ooool3o`0000oooooo0ol00003ooooo`;o00000_ooool5
o`0000Cooooo0_l0000:ooooo`;o00001?ooool2o`000003ooooool0003o000000Gooooo0_l00000
0ooooooo0000o`00000:ooooo`;o00000_ooool4o`0000Kooooo1Ol0000Aooooo`;o0000<?ooool0
01cooooo00?o0000ooooooooool0??ooool2o`0000Gooooo0_l00005ooooo`;o00004?ooool2o`00
00Kooooo0_l00004ooooo`;o000000?oooooo`000?l000001?l000000ooooooo0000o`00000Oo`00
0004ooooool0003o0000ooooo`;o00001_ooool2o`000004ooooool0003o0000ooooo`;o00002?oo
ool2o`0000;ooooo0ol0000;ooooo`;o00000oooool2o`0000[ooooo0_l00004ooooo`Go00001?oo
ool2o`0000?ooooo0_l00004ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`?o000000?o
ooooo`000?l000001?l000001?oooooo0000o`000?l0000=ooooo`;o0000<?ooool00006ooooooo^
k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03
o`000?oooooooooo04?ooooo0_l0000Eooooo`;o00002oooool]o`0000;ooooo0_l000000ooooooo
0000o`000006ooooo`;o00001?ooool2o`0000Sooooo0_l00008ooooo`;o00001_ooool3o`0000Wo
oooo0_l00003ooooo`;o00001Oooool2o`0000Kooooo0_l00003ooooo`;o00001?ooool2o`0000So
oooo0_l00002ooooo`?o000000?oooooo`000?l000001Oooool5o`0000_ooooo0_l0000`ooooo`00
00KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo03cooooo0_l00002ooooo`;o00001oooool2o`0000Cooooo0_l00009oooo
o`;o00002ooooolTo`000003ooooool0003o000000Go00004_ooool2o`0000Cooooo0ol0000;oooo
o`Co00001?ooool2o`000003ooooool0003o000000Wooooo0_l00008ooooo`;o00003oooool2o`00
00cooooo0_l0000@ooooo`;o00002oooool2o`00033ooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00Wooooo1Ol00006ooooo`03o`000?oooooooooo03cooooo0_l00002ooooo`;o
00001oooool2o`0000;ooooo1?l0000Dooooobko00002Oooool2o`000003ooooool0003o000000Co
oooo0ol00003ooooo`Go00002Oooool2o`0000Kooooo0_l0000=ooooo`;o00000_ooool2o`000003
ooooool0003o000000;o00001Oooool2o`0000;ooooo0_l00003ooooo`?o00006?ooool3o`0004;o
oooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo
00001oooool3o`0003cooooo0_l00009ooooo`;o00001?ooool2o`0000Cooooo0_l00003ooooo`;o
00002Oooool^o`0000Gooooo0_l00003ooooo`?o000000?oooooo`000?l000001Oooool2o`0000Co
oooo1_l0000Dooooo`;o000000?oooooo`000?l000001Oooool2o`0000;ooooo0_l000000ooooooo
0000o`000007ooooo`;o00000_ooool2o`0000?ooooo0_l0000=ooooo`?o00002Oooool3o`00013o
oooo0_l0000`ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgM
gOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0??ooool2o`0000Kooooo0_l000000ooooooo
0000o`000003ooooo`?o00001?ooool2o`0000?ooooo1?l00007ooooobko00001Oooool2o`0000?o
oooo0_l00002ooooo`;o00002oooool2o`0000;ooooo0_l0000Dooooo`;o000000?oooooo`000?l0
00008_ooool2o`0000Wooooo0ol00002ooooo`?o00005oooool2o`00033ooooo00000ooooooo410@
ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oMgMgolc<c?l000001oooool00ol0003ooooo
ooooo`14ooooo`;o00001_ooool2o`0000Gooooo0_l000000ooooooo0000o`000002ooooo`;o0000
1ooooolPo`000003ooooool0003o000000[o00003oooool2o`0000Gooooo0_l0000;ooooo`?o0000
7_ooool2o`0000;ooooo0_l00002ooooo`;o00001oooool2o`0000Cooooo1?l00008ooooo`;o0000
1?ooool3o`0000;ooooo0_l00005ooooo`;o0000?_ooool00006oooooomgMgOoV9RHoooooonHV9So
MgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo05Kooooo0_l00004ooooo`;o
00000oooool]o`0001Sooooo0_l00007ooooo`;o00000_ooool3o`0000gooooo0_l00005ooooo`;o
00001Oooool2o`000004ooooool0003o0000ooooo`?o00000_ooool2o`0000Gooooo1?l00004oooo
o`;o00002_ooool2o`0000Kooooo0_l000000ooooooo0000o`000003ooooo`Co0000?_ooool00006
ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooo
oooo03_ooooo1?l0000@ooooo`;o00001_ooool2o`0000?ooooo0_l00003ooooobgo00001oooool2
o`0000Gooooo0_l000000ooooooo0000o`00000>ooooo`;o00004_ooool2o`0000Cooooo1ol00000
0ooooooo0000o`000004ooooo`;o00000oooool2o`0000Gooooo0_l0000Hooooo`Co00001_ooool4
o`0003kooooo000Looooo`03o`000?oooooooooo03_ooooo1?l00002ooooo`;o00001_ooool2o`00
00Cooooo0_l00006ooooo`;o00002?ooool4o`0000;ooooo3?l00002oooooaGo00000_ooool2o`00
00Oooooo0_l00005ooooo`;o000000?oooooo`000?l000000_l00008ooooo`;o00006oooool3o`00
0003ooooool0003o000000;o00003?ooool2o`0000;ooooo0_l00002ooooo`;o00002?ooool2o`00
00Wooooo0_l00002ooooo`;o00002_ooool2o`0003kooooo000Looooo`03o`000?oooooooooo03So
oooo1?l00005ooooo`;o00001_ooool2o`0001Kooooo1Ol00002oooooaKo000000?oooooo`000?l0
00002Ol00002ooooo`;o00004oooool4o`0000Kooooo0_l0000;ooooo`;o00002Oooool2o`0000?o
oooo0_l0000Eooooo`?o00000_ooool2o`0000Sooooo0_l00009ooooo`Go00000oooool2o`0004Ko
oooo000Looooo`03o`000?oooooooooo03Sooooo1?l00005ooooo`;o00000_ooool3o`000003oooo
ool0003o000001Cooooo0_l00002ooooobKo00002?ooool2o`0000Oooooo0_l00007ooooo`?o0000
1Oooool4o`0000Gooooo0_l00002ooooo`;o00001Oooool8o`0000Kooooo0_l0000>ooooo`Co0000
4oooool4o`0000;ooooo1?l00003ooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0@Ooo
ool2o`000003ooooool0003o000000;o00002oooool2o`0000Kooooo0_l00002ooooo`;o000000?o
ooooo`000?l000009?l00009ooooo`;o00001oooool2o`0000Sooooo0_l00007ooooo`;o00000_oo
ool2o`000003ooooool0003o000000Wooooo1?l000000ooooooo0000o`000004o`000003ooooool0
003o000000;o00003_ooool2o`0000;ooooo0_l0000<ooooo`;o00000oooool4o`00013ooooo0_l0
00000ooooooo0000o`00000looooo`007?ooool00ol0003oooooooooo`11ooooo`;o000000?ooooo
o`000?l000002oooool4o`0000Kooooo0_l000001Ooooooo0000o`000?l0003ooooo01oo000000?o
ooooo`000?l000004_ooool2o`0000[ooooo0_l0000=ooooo`;o00003?ooool2o`0000?ooooo0_l0
00001Ooooooo0000o`000?l0003ooooo00;o00005?ooool2o`0000cooooo0_l0000Gooooo`;o0000
00?oooooo`000?l00000??ooool001cooooo00?o0000ooooooooool0<_ooool2o`0000gooooo0_l0
000>ooooo`;o00002?ooool2o`000005ooooool0003o0000o`000?ooool07_l0000Fooooo`Co0000
2?ooool2o`0000[ooooo0_l000000ooooooo0000o`00000Hooooo`;o00005Oooool2o`0000;ooooo
0_l00003ooooo`;o00001Oooool2o`0000Wooooo0_l00005ooooo`;o0000@oooool001cooooo00?o
0000ooooooooool0<_ooool2o`0000Cooooo0_l0000?ooooo`;o00001_ooool2o`0000Sooooo0_l0
00001Ooooooo0000o`000?l0003ooooo00So000000Goooooo`000?l0003o0000ooooo`03o`0001[o
oooo0_l00005ooooo`?o00000_ooool2o`0001Cooooo1?l00002ooooo`Co00001Oooool2o`000003
ooooool0003o000000gooooo0_l0000<ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o
00001Oooool2o`0000Wooooo0_l00005ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0
>?ooool2o`0000oooooo0_l0000Cooooo`Ko000000?oooooo`000?l000002?ooool2o`0000Wooooo
0_l000000ooooooo0000o`000002o`0000_ooooo0_l00005ooooo`?o00001?ooool2o`00017ooooo
1Ol00002ooooo`Go000000?oooooo`000?l000000ol000000ooooooo0000o`000008ooooo`;o0000
0oooool2o`0000cooooo0_l0000>ooooo`;o00007Oooool2o`0003_ooooo000Looooo`03o`000?oo
oooooooo05kooooo1_l000000ooooooo0000o`000002o`0000Kooooo0_l00009ooooo`;o000000?o
ooooo`000?l000000_l00004ooooo`;o00000_ooool3o`000003ooooool0003o000000Kooooo0_l0
0003ooooo`;o00003Oooool2o`0000;ooooo0ol00003ooooo`Ko000000?oooooo`000?l000000_l0
0002ooooo`;o00002?ooool3o`000003ooooool0003o000000Kooooo0_l0000:ooooo`;o00001Ooo
ool2o`0000;ooooo1?l0000?ooooo`;o00002Oooool3o`0003_ooooo000Looooo`03o`000?oooooo
oooo03;ooooo0_l0000?ooooo`;o00002?ooool2o`0000oooooo1Ol00004ooooo`;o00003?ooool4
o`000004ooooool0003o0000o`0000Sooooo0_l00002ooooo`?o000000?oooooo`000?l000001?oo
ool4o`0000Sooooo0_l00008ooooo`;o00001Oooool2o`000003ooooool0003o000000?o00004ooo
ool2o`000004ooooool0003o0000ooooo`;o00000oooool2o`0000Kooooo0_l00002ooooo`;o0000
1Oooool2o`0000Cooooo0ol00008ooooo`Co00000_ooool2o`0000Wooooo0_l0000looooo`007?oo
ool00ol0003oooooooooo`0Qooooo`;o00003oooool2o`0000cooooo0_l000000ooooooo0000o`00
0002ooooo`;o00001?ooool2o`0000Sooooo0_l00005ooooo`;o00001oooool2o`000003ooooool0
003o000000Wooooo1?l000001?oooooo0000o`000?l00002ooooo`;o00004?ooool4o`0000[ooooo
0_l0000?ooooo`;o00000oooool2o`0000?ooooo0_l0000?ooooo`;o00000oooool5o`0000Wooooo
0_l00002ooooo`;o00003?ooool2o`0000Cooooo0_l00002ooooo`Co00002_ooool2o`000003oooo
ool0003o000003cooooo000Looooo`;o00008_ooool2o`0001gooooo0_l00005ooooo`?o00000ooo
ool2o`0000Sooooo0_l00005ooooo`;o00002_ooool2o`0000oooooo0ol000000ooooooo0000o`00
0007ooooo`;o00001oooool6o`0000Gooooo0_l00009ooooo`;o00004Oooool2o`0000;ooooo0_l0
000;ooooo`;o000000?oooooo`000?l000001Ol00003ooooo`;o00002?ooool2o`0000_ooooo0_l0
0005ooooo`;o00000_ooool2o`0000cooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0]
ooooo`;o00003_ooool2o`0000Sooooo0ol00003ooooo`;o00007Oooool2o`0000kooooo0_l0000:
ooooo`;o00001_ooool2o`0000?ooooo0_l00005ooooo`;o00002Oooool2o`000003ooooool0003o
000000kooooo0_l00002ooooo`;o00003_ooool5o`0000Cooooo0ol00003ooooo`;o00004?ooool2
o`0000Sooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o00003_ooool2o`00
00Sooooo0_l00006ooooo`;o00003?ooool4o`0000_ooooo0_l0000Booooo`;o00003?ooool4o`00
00Kooooo0_l00002ooooo`;o00003?ooool3o`0000Wooooo0_l00002ooooo`;o00000_ooool2o`00
00gooooo0_l00008ooooo`Co00000_ooool5o`0001Oooooo0_l0001>ooooo`007?ooool00ol0003o
ooooooooo`0/ooooo`;o000000?oooooo`000?l000004_ooool2o`0000[ooooo0_l0000<ooooo`Co
00001Oooool3o`0000Gooooo0_l0000;ooooo`;o00000oooool2o`0000Sooooo0_l00002ooooo`;o
00002?ooool2o`00017ooooo0ol00008ooooo`;o000000Coooooo`000?l0003o00003Oooool2o`00
00;ooooo1?l00002ooooo`?o00000_ooool4o`000003ooooool0003o000000?o00004?ooool2o`00
017ooooo1?l00010ooooo`007?ooool00ol0003oooooooooo`0/ooooo`Go00001?ooool2o`0000co
oooo0_l00006ooooo`;o00003oooool2o`0000Kooooo1Ol00005ooooo`;o00000oooool2o`0000Ko
oooo0_l0000=ooooo`;o00008?ooool2o`0000Sooooo0_l000000ooooooo0000o`000005o`0000Wo
oooo0_l00002oooooa?o00000oooool2o`0000gooooo0ol000000ooooooo0000o`000002ooooo`;o
00002Oooool6o`0001;ooooo0_l0000Zooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o0000
1Oooool2o`0001Cooooo0_l0000>ooooo`?o00001_ooool2o`0000;ooooo0_l00004ooooo`;o0000
0oooool2o`0002kooooo1?l00005ooooo`;o00001oooool2o`0000?ooooo1_l00004ooooo`Co0000
1OoooolCo`0000?ooooo0_l00005ooooo`Co00001?ooool3o`000003ooooool0003o000000;ooooo
0_l0000=ooooo`;o00001Oooool2o`0000_ooooo0_l0000Zooooo`007?ooool00ol0003ooooooooo
o`0Qooooo`;o0000>?ooool2o`0000Oooooo0_l00002ooooo`;o00001?ooool2o`0000Sooooo0_l0
000Yooooo`Co00001Oooool2o`0000Cooooo1Ol00004ooooo`;o00000oooool2o`0000;ooooo1?l0
00001?oooooo0000o`000?ooool3o`0000;ooooo1ol000000ooooooo0000o`000002o`0000?ooooo
2?l00002ooooo`Go00000oooool2o`0000Cooooo0_l00008ooooo`;o00000_ooool2o`0000Sooooo
0_l0000gooooo`007?ooool00ol0003oooooooooo`0Qooooo`;o0000=_ooool2o`0000Wooooo0_l0
0008ooooo`;o00002?ooool2o`0000cooooo0_l0000Cooooo`;o00005?ooool5o`0000Gooooo0_l0
0003ooooo`;o00001Oooool4o`000004ooooool0003o0000oooooaCo000000?oooooo`000?l00000
0_l00005ooooo`;o00002Oooool2o`0000Sooooo0_l00002ooooo`;o00000_ooool2o`0003gooooo
000Looooo`03o`000?oooooooooo02Wooooo0_l0000@ooooo`Co00003Oooool2o`0000Gooooo0_l0
0004ooooo`;o00007?ooool2o`0000gooooo0_l0000Cooooo`;o00004oooool3o`000003ooooool0
003o000000oooooo7_l000000ooooooo0000o`000003o`0000cooooo1?l00005ooooo`;o00000_oo
ool2o`0000Kooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0Yooooo`;o00004?ooool4
o`0000gooooo0_l00005ooooo`;o00006_ooool2o`0000Kooooo0_l0000Zooooo`;o00002oooool2
o`0000;ooooo0_l00004ooooo`So000000?oooooo`000?l000004ol000000ooooooo0000o`000008
o`000003ooooool0003o000000?o00001oooool2o`0000?ooooo1?l00005ooooo`;o00001oooool2
o`00043ooooo000Looooo`03o`000?oooooooooo03_ooooo0_l0000?ooooo`;o00008Oooool3o`00
02Oooooo0_l00007ooooo`?o00002Oooool2o`0000Gooooo0_l00003ooooo`So000000?oooooo`00
0?l000000_ooool2o`000003ooooool0003o000001Oo000000?oooooo`000?l000001Ol00005oooo
o`;o00005Oooool2o`0000Kooooo0_l0000=ooooo`;o0000:Oooool001cooooo00?o0000oooooooo
ool0<?ooool2o`0000Wooooo0_l0000?ooooo`;o00008_ooool2o`0000?ooooo0_l0000@ooooo`;o
00002Oooool2o`0000;ooooo0_l000000ooooooo0000o`000007ooooo`;o00001Oooool4o`000004
ooooool0003o0000o`0000Cooooo1?l00002ooooo`;o00002ooooolLo`000003ooooool0003o0000
00Ko000000?oooooo`000?l000006oooool2o`0000;ooooo0_l0000=ooooo`;o0000:Oooool001co
oooo00?o0000ooooooooool0<?ooool2o`0004?ooooo0_l0000@ooooo`;o00001Oooool2o`0000;o
oooo0_l00002ooooo`;o00002?ooool4o`0000Gooooo1?l00002ooooo`;o00001_ooool2o`0000;o
oooo0_l00008ooooo`;o000000?oooooo`000?l000001ol000000ooooooo0000o`000006o`000003
ooooool0003o000000Wo00001Oooool2o`000003ooooool0003o000000[ooooo0_l0000?ooooo`;o
0000??ooool001cooooo00?o0000ooooooooool0<?ooool2o`0004gooooo0_l0000=ooooo`;o0000
1Oooool2o`0000Oooooo1?l000000ooooooo0000o`00000Fooooo`;o00000_ooool4o`000004oooo
ool0003o0000o`0000;ooooo6_l000000ooooooo0000o`00000@ooooo`;o00000_ooool4o`0002?o
oooo0_l0000Vooooo`007?ooool00ol0003oooooooooo`1?ooooo`Co00002_ooool3o`0001oooooo
1?l0000<ooooo`;o00001?ooool2o`0000Oooooo0_l00003ooooo`Co00005Oooool2o`000003oooo
ool0003o000000;o000000?oooooo`000?l000000_oooolOo`0000oooooo0_l00004ooooo`;o0000
0oooool2o`0000Sooooo0_l0000Dooooo`;o00009_ooool001cooooo00?o0000ooooooooool0@ooo
ool2o`0000[ooooo1?l0000:ooooo`?o00000_ooool2o`0001gooooo0_l0000<ooooo`;o00004ooo
ool4o`0000[ooooo0_l00008ooooo`;o00002_oooolRo`0001Oooooo1?l00006ooooo`?o00002Ooo
ool2o`00033ooooo000Looooo`;o0000;_ooool2o`000004ooooool0003o0000o`00013ooooo0_l0
000;ooooo`;o00004?ooool4o`000004ooooool0003o0000o`0000Wooooo0_l0000Dooooo`;o0000
0_ooool2o`0001Gooooo1Ol00007ooooo`Co000000Coooooo`000?l0003ooooo1Ol0000;oooooa3o
000000?oooooo`000?l000003ol0000Aooooo`Co00001?ooool2o`0000Gooooo1?l00009ooooo`;o
00001?ooool3o`0002Wooooo000Looooo`03o`000?oooooooooo02gooooo0_l000001?oooooo0000
o`000?l0000aooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0000Gooooo0_l0000?oooo
o`;o00000oooool2o`0000;ooooo0_l0000>ooooo`Co00001_ooool2o`0000Oooooo0_l00003oooo
o`;o000000?oooooo`000?l000000ol00002ooooo`;o00001ooooolOo`0000;ooooo1?l0000>oooo
o`Co00002Oooool4o`00017ooooo0ol0000Yooooo`007?ooool00ol0003oooooooooo`18ooooo`;o
00008_ooool2o`0000?ooooo1?l0000?ooooo`;o00000oooool2o`0000Wooooo0_l00007ooooo`Co
00002_ooool2o`0000kooooo0_l00002ooooo`?o000000?oooooo`000?l000000_ooool?o`000003
ooooool0003o000000go00000oooool4o`0001_ooooo1?l0000?ooooo`;o0000;?ooool001cooooo
00?o0000ooooooooool0<?ooool2o`0001Kooooo0_l0000Oooooo`Ko00000_ooool2o`00017ooooo
0_l00006ooooo`;o00001_ooool2o`0001Gooooo0_l00004ooooo`;o000000?oooooo`000?l00000
2_ooool2o`000005ooooool0003o0000o`000?ooool06_l00002ooooo`?o00003?ooool2o`0001Ko
oooo1Ol0000<ooooo`;o0000;?ooool001cooooo00?o0000ooooooooool0:?ooool2o`0000Cooooo
1?l0000;ooooo`;o0000:_ooool6o`0000;ooooo0_l0000Iooooo`;o000000?oooooo`000?l00000
8?ooool2o`000003ooooool0003o000000kooooo0_l000000ooooooo0000o`000006o`000003oooo
ool0003o000001?o000000?oooooo`000?l000002_ooool2o`0001Kooooo1Ol0000jooooo`007?oo
ool00ol0003oooooooooo`0Xooooo`;o00001?ooool2o`0000gooooo0_l00009ooooo`;o0000;Ooo
ool2o`0001Kooooo0_l0000Hooooo`;o00007?oooolMo`0000;ooooo0_l0000Tooooo`;o000000?o
ooooo`000?l00000>?ooool001cooooo00?o0000ooooooooool0;_ooool2o`0001Cooooo0_l00002
ooooo`;o00002Oooool2o`0000gooooo0_l00009ooooo`;o00002?ooool2o`0000Kooooo0_l0000;
ooooo`;o00002_ooool2o`0000?ooooo0_l0000:ooooo`;o00000oooool2o`0000;ooooo0_l00007
ooooo`;o00002?oooolOo`0000;ooooo0_l0000Hooooo`;o00000_ooool4o`0000Cooooo0_l00000
0ooooooo0000o`00000hooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00003?ooool3o`00
00Cooooo0_l00007ooooo`;o00002Oooool2o`0000[ooooo1Ol000000ooooooo0000o`00000;oooo
o`;o00002_ooool2o`0000?ooooo0_l0000?ooooo`;o00000_ooool2o`0000Oooooo0_l00008oooo
o`Ko00000_oooolGo`0000;ooooo0_l00007ooooo`;o00003oooool8o`0000?ooooo0ol0000koooo
o`007?ooool00ol0003oooooooooo`0`ooooo`;o00008?ooool2o`0000Gooooo0_l00002ooooo`;o
00006?ooool:o`0000Sooooo0_l0000Sooooo`;o00001_ooool2o`0000_ooooo0_l000000ooooooo
0000o`000002o`000003ooooool0003o000001Co000000Coooooo`000?l0003o00002_ooool2o`00
00Kooooo0_l00009ooooo`?o00001_ooool3o`0000gooooo0_l0000/ooooo`007?ooool00ol0003o
ooooooooo`0[ooooo`;o00000oooool2o`00017ooooo0_l0000Hooooo`;o00001_ooool2o`00013o
oooo1Ol000001?oooooo0000o`000?l00009ooooo`;o00001_ooool2o`0000_ooooo0_l00004oooo
o`;o00000_ooool7o`0000Oooooo0_l0000:ooooo`?o000000Coooooo`000?l0003o00000_oooolF
o`000004ooooool0003o0000o`0001;ooooo0_l0000Rooooo`;o000000?oooooo`000?l00000:Ooo
ool001cooooo00?o0000ooooooooool07_ooool2o`0000_ooooo0_l0000Fooooo`;o00005_ooool4
o`0000Kooooo0_l00006ooooo`?o00002Oooool3o`000003ooooool0003o000000[ooooo0_l00002
ooooo`;o00000_ooool2o`0000Cooooo0_l00003ooooo`Co00001?ooool2o`0000;ooooo1ol00003
ooooo`;o00002?ooool2o`0000Cooooo0_l00005ooooo`Go00000_oooolAo`000003ooooool0003o
000001;ooooo0_l0000@ooooo`;o00000oooool2o`0000oooooo0_l0000Yooooo`007?ooool00ol0
003oooooooooo`0Nooooo`;o00002oooool2o`0002Wooooo0_l00002ooooo`Ko00003Oooool3o`00
00[ooooo1?l0000?ooooo`;o00001oooool3o`0000?ooooo0_l00002ooooo`;o000000?oooooo`00
0?l000001?l00003ooooo`?o00000oooool2o`0000Kooooo1_l00007oooooa7o000000?oooooo`00
0?l000001Ol00002ooooo`Co00000_ooool4o`0000Kooooo0ol000000ooooooo0000o`00000@oooo
o`;o00000oooool2o`0003[ooooo000Looooo`03o`000?oooooooooo02_ooooo0_l0000Wooooo`Co
000000?oooooo`000?l000001ol0000<ooooo`Co00002Oooool3o`0001Sooooo0_l00007ooooo`[o
000000?oooooo`000?l000000ol000000ooooooo0000o`000002o`0000Kooooo0ol000000ooooooo
0000o`000006ooooo`?o00000_ooool=o`000003ooooool0003o000000_o00000_ooool4o`0000Co
oooo1Ol00003ooooo`;o00002_ooool2o`0004?ooooo000Looooo`03o`000?oooooooooo05;ooooo
4Ol00004ooooo`;o00001Oooool4o`0000Wooooo0_l00009ooooo`;o00002?ooool4o`0000Kooooo
1?l000000ooooooo0000o`000007o`0000;ooooo0_l00004ooooo`Co00001oooool2o`0000Sooooo
1?l00002ooooo`ko00000oooool8o`0000cooooo0_l00006ooooo`;o00002_ooool3o`0004;ooooo
000Looooo`03o`000?oooooooooo05;ooooo4_l00003ooooo`;o00003_ooool2o`0000Cooooo0_l0
0007ooooo`;o00001oooool7o`0000Cooooo1?l000001?oooooo0000o`000?ooool3o`0000_ooooo
1_l0000:ooooo`;o00000oooool2o`0000Gooooo0_l000000ooooooo0000o`000008o`0000Gooooo
1Ol0000<ooooo`;o00001oooool4o`0000Wooooo0_l00012ooooo`007?ooool00ol0003ooooooooo
o`1Boooooa?o00004Oooool5o`0000;ooooo0_l0000@ooooo`;o00000oooool2o`0000Kooooo2ol0
0008ooooo`?o00000_ooool2o`0000[ooooo0_l0000:ooooo`So00006oooool4o`0000Oooooo0_l0
0008ooooo`;o0000@oooool001cooooo0_l0000Wooooo`;o0000:?oooolGo`0000oooooo0_l00000
0ooooooo0000o`00000Kooooo`?o00000oooool3o`000003ooooool0003o000000_o00000_ooool3
o`0000Sooooo1?l00002ooooo`;o00002oooool7o`00013ooooo0_l0000;ooooo`;o00001?ooool2
o`0000;ooooo0_l00005ooooo`Ko00000_ooool2o`0003gooooo000Looooo`03o`000?oooooooooo
02Kooooo0_l0000VoooooaWo00001Oooool2o`0000Sooooo0_l0000Kooooo`So00000_ooool4o`00
00?ooooo0_l000000ooooooo0000o`000005o`0000;ooooo0_l00008ooooo`Co00000_ooool2o`00
00[ooooo0_l00008ooooo`;o00001oooool2o`0000?ooooo0_l0000Aooooo`;o00000_ooool3o`00
00Cooooo0_l00002ooooo`;o00000_ooool2o`0003gooooo000Looooo`03o`000?oooooooooo03Wo
oooo0_l0000Coooooa_o00000oooool2o`0000Sooooo0_l00002ooooo`;o00005oooool4o`0000;o
oooo2?l00006ooooo`;o000000?oooooo`000?l000000_l00006ooooo`;o00001?ooool2o`00013o
oooo0_l000000ooooooo0000o`000005ooooo`?o00001_ooool2o`0001_ooooo0_l0000Qooooo`;o
0000:?ooool001cooooo00?o0000ooooooooool09oooool2o`00013ooooo0_l0000@ooooo`;o0000
00?oooooo`000?l000006_l00003ooooo`Co00001Oooool2o`0000;ooooo0_l000000ooooooo0000
o`000007ooooo`;o00001_ooool2o`0000Cooooo0_l00004ooooo`So00001Oooool2o`0000;ooooo
0ol000000ooooooo0000o`000005o`0000gooooo0_l000000ooooooo0000o`000002o`0000Cooooo
0ol00005ooooo`?o00000oooool2o`0000Oooooo0_l00006ooooo`;o00004oooool2o`0000Sooooo
0_l0000Aooooo`;o0000:?ooool001cooooo00?o0000ooooooooool09oooool2o`00023ooooo1?l0
00000ooooooo0000o`00000Eo`0000?ooooo0_l00003ooooo`Co00001Oooool2o`0000Gooooo0_l0
0007ooooo`;o00000oooool2o`000003ooooool0003o000000Cooooo0_l00004ooooo`co000000?o
ooooo`000?l000000_ooool=o`0000Oooooo0_l000001Ooooooo0000o`000?l0003ooooo00Co0000
1?ooool2o`0000Oooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00006ooooo`;o0000
00?oooooo`000?l000004?ooool2o`0000Sooooo0_l0000kooooo`007?ooool00ol0003ooooooooo
o`0Vooooo`;o00003oooool2o`00013ooooo0_l000000ooooooo0000o`00000Go`000003ooooool0
003o000000Wooooo0_l00007ooooo`;o00002_ooool2o`0000?ooooo0_l0000<oooooaoo00001ooo
ool2o`000003ooooool0003o000001cooooo0_l00004ooooo`;o00002?ooool2o`0001cooooo0_l0
000iooooo`007?ooool00ol0003oooooooooo`0Vooooo`;o000000?oooooo`000?l000003?ooool2
o`0001?ooooo1?l000000ooooooo0000o`00000Bo`000003ooooool0003o000000;o00000_ooool2
o`0000?ooooo1?l00005ooooo`;o00003Oooool2o`0000Gooooo0_l000001?oooooo0000o`000?l0
0003oooooako00002oooool2o`0001cooooo0_l00004ooooo`;o00006oooool2o`0000Kooooo1Ol0
000iooooo`007?ooool00ol0003oooooooooo`0Yooooo`;o000000?oooooo`000?l000001_ooool2
o`0001Kooooo3Ol000000ooooooo0000o`000009o`0000?ooooo0_l00002ooooo`;o00000oooool4
o`00013ooooo0_l00002ooooo`Wo000000?oooooo`000?l000000ol000000ooooooo0000o`00000E
o`000004ooooool0003o0000ooooo`?o00002oooool2o`0001Kooooo0_l00004ooooo`Co00006_oo
ool2o`0000?ooooo0ol00005ooooo`?o00004Oooool2o`0002Sooooo000Looooo`03o`000?oooooo
oooo02cooooo0_l00006ooooo`;o00005_ooool>o`000003ooooool0003o000000So00001_ooool2
o`0000Cooooo0_l0000Booooo`;o00000oooool6o`0000;ooooo1_l000000ooooooo0000o`00000H
o`000003ooooool0003o000000;ooooo0_l00002ooooo`Co00006_ooool2o`0000Kooooo0_l0000>
ooooo`;o00002_ooool2o`0000Cooooo0_l00006ooooo`;o00004Oooool2o`0002Sooooo000Loooo
o`03o`000?oooooooooo04cooooo3_l000000ooooooo0000o`000009o`0000Gooooo1?l000001?oo
oooo0000o`000?l0000;ooooo`?o00001oooool2o`000003ooooool0003o000000?o000000Cooooo
o`000?l0003o00000ooooolEo`000003ooooool0003o000000Co000000?oooooo`000?l000001?l0
0002ooooo`Co00003_ooool4o`0000;ooooo1Ol00009ooooo`;o00000oooool4o`000003ooooool0
003o000000Cooooo0_l00002ooooo`;o00001_ooool2o`0000Cooooo0_l00005ooooo`;o0000??oo
ool001cooooo00?o0000ooooooooool0C_oooolEo`000003ooooool0003o000000Kooooo0ol00000
0ooooooo0000o`00000<ooooo`?o00000oooool2o`0000;ooooo0_l00003ooooob3o000000?ooooo
o`000?l000002?l00006ooooo`;o00002Oooool2o`0000?ooooo1?l00002ooooo`So00000oooool2
o`000003ooooool0003o000000?ooooo1?l000000ooooooo0000o`000008ooooo`Co00001Oooool2
o`0000[ooooo0_l0000looooo`007?ooool00ol0003oooooooooo`19ooooo`Co00000ooooolCo`00
00Wooooo0_l0000>ooooo`;o00001_ooool3o`0000Gooooo1_l00002ooooobCo00001Oooool3o`00
00Wooooo0_l00003ooooo`;o00000oooool2o`0000Cooooo0ol00003ooooo`Go00001Oooool2o`00
00Sooooo0_l000000ooooooo0000o`000002o`0000Gooooo0_l00007ooooo`;o00000_ooool2o`00
03_ooooo000Looooo`03o`000?oooooooooo037ooooo0_l0000Fooooo`Co00000ooooolBo`0000go
oooo0_l0000;ooooo`;o00000oooool2o`0000;ooooo0_l00005ooooob;o000000?oooooo`000?l0
00000_l00007ooooo`;o000000?oooooo`000?l000004_ooool4o`0000;ooooo0_l00008ooooo`;o
00001?ooool4o`0000Sooooo0_l000000ooooooo0000o`00000;ooooo`;o00000oooool2o`0000;o
oooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0Oooooo`;o00003_ooool4o`0000Sooooo
0_l0000=ooooo`;o00001?oooolCo`0000cooooo1_l0000<ooooo`;o00001Oooool2o`000005oooo
ool0003o0000o`000?ooool09?l00004ooooo`;o000000?oooooo`000?l000001Oooool4o`0000Ko
oooo0_l00002ooooo`Co00001?ooool2o`0000kooooo0ol00004ooooo`;o00001_ooool4o`000003
ooooool0003o000000Kooooo0_l00014ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5oooo
o`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool07oooool2
o`0000kooooo0_l0000:ooooo`;o00003Oooool2o`0000Gooooo4_l00007ooooo`;o00001Oooool4
o`0000Wooooo0_l000000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l000009?l00002
ooooo`;o000000?oooooo`000?l000001Ol00003ooooo`Go00000oooool2o`000003ooooool0003o
000000;ooooo0ol0000>ooooo`?o00000_ooool2o`0000Oooooo0_l00008ooooo`;o000000?ooooo
o`000?l000001_ooool2o`000003ooooool0003o0000047ooooo00001_ooooooMgMgoiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`1@ooooo`;o00000oooool;o`0000[ooooo0_l0000?ooooo`;o000000Coooooo`000?l0003o
oooo0_l00009ooooobKo000000?oooooo`000?l000002?l00003ooooo`;o00001?ooool4o`0000Ko
oooo0_l0000>ooooo`?o00000_ooool2o`0001_ooooo0ol000000ooooooo0000o`000011ooooo`00
00?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`1:ooooo`;o00001?ooool2o`0000?ooooo1?l00005ooooo`;o
000000?oooooo`000?l000001Oooool4o`0000[ooooo0_l00003ooooo`;o000000?oooooo`000?l0
00001Oooool2o`000004ooooool0003o0000ooooobko00001Oooool3o`0000Gooooo0_l00002oooo
o`;o00002_ooool2o`0000Sooooo0_l00004ooooo`Co00001Oooool4o`0000oooooo0_l00015oooo
o`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9SooooooiRH
V?lQ8B401_ooool3o`0004;ooooo1?l00004ooooo`;o00001?ooool2o`0000?ooooo1?l00008oooo
o`;o00001Oooool4o`0000Gooooo0_l00003ooooo`;o00001_ooool4o`0000?ooooo0_l000001?oo
oooo0000o`000?oooolBo`000003ooooool0003o000000Oo000000?oooooo`000?l000002_l00002
ooooo`;o00001_ooool3o`0000Wooooo0_l0000:ooooo`;o00000_ooool2o`0000Cooooo0_l00004
ooooo`Co00001Oooool4o`0002[ooooo0_l0000Zooooo`0000?oooooo`000?ooool00_ooool00ol0
003oooooooooo`09ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`11
ooooo`Go00002Oooool2o`0000Wooooo0ol0000Dooooo`;o00002oooool5o`0000Wooooo1Ol00000
0ooooooo0000o`000008o`000003ooooool0003o000001Oo00000oooool2o`0000gooooo0_l00003
ooooo`;o00000_ooool2o`0000Oooooo0_l00004ooooo`;o0000>oooool2o`0002[ooooo00000ooo
oooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0
003oooooooooo`11ooooo`;o00003?ooool9o`0000;ooooo0ol0000Oooooo`;o00000oooool2o`00
0003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000002ooooo`_o000000?oooooo`00
0?l000006?l00002ooooo`;o00003Oooool2o`0000?ooooo0_l00002ooooo`;o00002?ooool2o`00
013ooooo0_l00003ooooo`;o0000:_ooool2o`0002Wooooo00001_ooooooMgMgoiRHV?ooooooV9RH
ogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0kooooo`;o00002_ooool6
o`0000;ooooo2Ol00003ooooo`;o00001_ooool4o`0000?ooooo1?l0000>ooooo`;o00001_ooool2
o`0000;ooooo1?l00002ooooob[o00008?ooool2o`000003ooooool0003o000000;o00003_ooool2
o`0000?ooooo1?l0000Xooooo`;o0000:Oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?oo
ool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo03_ooooo0_l0000:ooooo`Ko0000
5?ooool6o`0000?ooooo1?l00003ooooo`;o00005OoooolZo`0000;ooooo1_l0000=ooooo`;o0000
3oooool2o`0000?ooooo0_l00005ooooo`;o00003_ooool2o`0000[ooooo0_l00017ooooo`007?oo
ool00ol0003oooooooooo`1=ooooo`;o000000?oooooo`000?l000003oooool2o`0000Sooooo0_l0
0002ooooo`Co00000_ooool2o`0001;ooooo:?l00003ooooo`Ko00003Oooool2o`0000kooooo0_l0
0004ooooo`;o00001?ooool3o`0000?ooooo0_l00006ooooo`;o00003Oooool2o`0004Oooooo000L
ooooo`03o`000?oooooooooo047ooooo0_l0000:ooooo`;o000000?oooooo`000?l000002?ooool3
o`0000?ooooo0ol0000<ooooo`;o00000oooool3o`0000Oooooo0_l00003ooooo`;o00001?ooool2
o`0000?ooooo5?l000000ooooooo0000o`00000Co`0001Wooooo0_l00004ooooo`;o00001?ooool2
o`0000Cooooo0_l00003ooooo`?o00000_ooool3o`000003ooooool0003o000000Kooooo0_l00005
ooooo`;o000000?oooooo`000?l00000A?ooool001cooooo00?o0000ooooooooool0@Oooool2o`00
01?ooooo0_l00002ooooo`Co00000_ooool2o`0000?ooooo0_l00002ooooo`;o00001_ooool5o`00
00Gooooo0_l000001?oooooo0000o`000?ooool4o`0000Cooooo0_l00003ooooob[o00001_ooool4
o`0000Cooooo0_l000000ooooooo0000o`000006ooooo`;o00005Oooool2o`0000?ooooo0ol00006
ooooo`;o000000?oooooo`000?l000001?ooool3o`000003ooooool0003o000004Cooooo000Loooo
o`03o`000?oooooooooo05?ooooo1ol000001?oooooo0000o`000?l00007ooooo`;o00000_ooool2
o`0000Gooooo1Ol00006ooooo`;o00001?ooool4o`000003ooooool0003o000000Go00001?oooolR
o`0000;ooooo0ol00006ooooo`Co00001?ooool2o`000003ooooool0003o000000Gooooo0ol0000H
ooooo`;o00002?ooool3o`0000?ooooo0_l000001?oooooo0000o`000?l00002ooooo`;o0000A?oo
ool001cooooo00?o0000ooooooooool0>oooool2o`0000Oooooo1?l00005ooooo`;o00001?ooool7
o`0000Sooooo0_l000000ooooooo0000o`000009ooooo`?o00002oooool2o`0000;ooooo1ol00000
1Ooooooo0000o`000?l0003ooooo00;o00000_oooolUo`0000Oooooo0_l00003ooooo`Co00002Ooo
ool3o`0000Cooooo0_l00005ooooo`Co00001Oooool2o`0000;ooooo0_l00004ooooo`;o00000_oo
ool4o`0000;ooooo0_l000001?oooooo0000o`000?l00002ooooo`Co0000@_ooool001cooooo00?o
0000ooooooooool0>oooool2o`0000Cooooo1ol00005ooooo`;o00001Oooool2o`0000Oooooo0_l0
0003ooooo`Go00001Oooool2o`0000;ooooo0ol0000;ooooo`;o00000oooool3o`000004ooooool0
003o0000ooooo`;o000000?oooooo`000?l000008?l000001?oooooo0000o`000?ooool2o`0000Wo
oooo0_l00003ooooo`Co00002_ooool2o`0000Cooooo0_l00005ooooo`Go00000oooool3o`0000So
oooo1Ol000001?oooooo0000o`000?ooool2o`0000?ooooo0_l00004ooooo`;o0000@_ooool001co
oooo00?o0000ooooooooool0@Oooool3o`0000;ooooo0_l0000Eooooo`;o00001Oooool2o`0000Ko
oooo0_l0000LooooobSo00001?ooool2o`0000?ooooo0_l0000Dooooo`;o00003_ooool2o`0000?o
oooo0_l0000;ooooo`?o00001?ooool2o`0004gooooo000Looooo`03o`000?oooooooooo03oooooo
0_l00004ooooo`?o00001Oooool2o`0000Wooooo0_l0000<ooooo`;o00008oooool2o`000003oooo
ool0003o000001Ko000000?oooooo`000?l000002_l00003ooooo`;o00000oooool2o`0000[ooooo
0_l00002ooooo`;o00005Oooool2o`0000Oooooo0_l0000>ooooo`;o0000C?ooool001cooooo00?o
0000ooooooooool0?oooool2o`0000Cooooo0_l00006ooooo`Co000000?oooooo`000?l000001?oo
ool2o`0000cooooo0_l0000Sooooo`;o000000?oooooo`000?l000005_l000000ooooooo0000o`00
000:o`000003ooooool0003o0000017ooooo0_l00002ooooo`;o00005Oooool2o`0000Oooooo0_l0
0004ooooo`;o00002?ooool2o`0000;ooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`15
ooooo`;o00002?ooool5o`0000;ooooo0_l0000@ooooo`;o00004_ooool2o`0000;ooooo0_l00003
ooooo`;o000000?oooooo`000?l000001_oooolQo`0000?ooooo1?l00003ooooo`;o0000;_ooool2
o`0000;ooooo1?l00008ooooo`;o00000_ooool2o`0004Sooooo000Looooo`03o`000?oooooooooo
03gooooo0_l00006ooooo`;o00002Oooool3o`0000?ooooo1?l0000>ooooo`;o00004_ooool2o`00
0003ooooool0003o000000;o00000_ooool2o`000003ooooool0003o000000Kooooo3?l000000ooo
oooo0000o`00000;o`000003ooooool0003o000000;ooooo0_l00005ooooo`;o00000oooool2o`00
02kooooo0_l000001?oooooo0000o`000?l0000;ooooo`;o0000Boooool001cooooo0_l0000noooo
o`;o00004Oooool2o`0000;ooooo0_l00002ooooo`;o00001?ooool2o`0001Sooooo0_l00005oooo
o`Co000000Goooooo`000?l0003o0000ooooo`02o`0000Kooooo0_l00002ooooo`So000000?ooooo
o`000?l000003ol000000ooooooo0000o`00000booooo`;o000000?oooooo`000?l000001_ooool2
o`0000cooooo0_l000000ooooooo0000o`000018ooooo`007?ooool00ol0003oooooooooo`16oooo
o`;o00003?ooool2o`0000Sooooo0_l00004ooooo`;o00001?ooool2o`000003ooooool0003o0000
00Wooooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool2o`0000;ooooo0_l00003oooo
o`;o000000?oooooo`000?l000000_ooool;o`000003ooooool0003o000000co00002Oooool2o`00
02[ooooo0_l000000ooooooo0000o`00000Gooooo`;o0000B?ooool001cooooo00?o0000oooooooo
ool0@oooool2o`000003ooooool0003o000000;ooooo0_l00008ooooo`;o00001?ooool2o`0000So
oooo0_l00004ooooo`Go00003?ooool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o
000000?oooooo`000?l000000_l000000ooooooo0000o`000003oooooaKo000000?oooooo`000?l0
00001Ol00004ooooo`Co00008oooool2o`0001Kooooo0_l0001Aooooo`007?ooool00ol0003ooooo
ooooo`13ooooo`;o00001Oooool2o`0000Kooooo1ol000000ooooooo0000o`000002ooooo`;o0000
0_ooool2o`000003ooooool0003o000000Gooooo0_l0000=ooooo`;o000000?oooooo`000?l00000
1?ooool2o`0000Gooooo1?l00006ooooo`co000000?oooooo`000?l000000ol000001Ooooooo0000
o`000?l0003ooooo00Oo00001_ooool2o`0002?ooooo0_l0000>ooooo`;o00001_ooool2o`00057o
oooo000Looooo`03o`000?oooooooooo04?ooooo0_l00006ooooo`;o00001Oooool7o`0000Gooooo
0_l00002ooooo`;o000000?oooooo`000?l000001?ooool2o`0000kooooo0_l0000=ooooo`?o0000
1?ooool2o`000003ooooool0003o0000017o00000_ooool6o`0003;ooooo0_l00003ooooo`;o0000
1_ooool2o`0005Wooooo000Looooo`03o`000?oooooooooo03kooooo0_l0000:ooooo`?o00001Ooo
ool4o`0001Gooooo0ol000001?oooooo0000o`000?l0000Hooooo`;o00001Oooool2o`000004oooo
ool0003o0000ooooo`So000000?oooooo`000?l000003Ol00006ooooo`;o00009_ooool2o`0000;o
oooo0_l00003ooooo`;o00000oooool2o`0000Oooooo0_l00007ooooo`;o0000B_ooool001cooooo
00?o0000ooooooooool0?_ooool2o`0000[ooooo0_l00008ooooo`;o00005_ooool2o`000005oooo
ool0003o0000o`000?ooool00_l00006ooooo`;o00000_ooool2o`0000_ooooo0_l00003ooooo`;o
00000ooooolDo`0000;ooooo0_l00007ooooo`;o00009_ooool2o`0000cooooo0_l00007ooooo`;o
00001oooool2o`0004[ooooo000Looooo`03o`000?oooooooooo057ooooo0_l00005ooooo`;o0000
0oooool2o`0000?ooooo0_l0000:ooooo`?o00000_ooool2o`0000Kooooo0_l00002ooooo`;o0000
0oooool2o`0000Gooooo0ol00002oooooaco00002oooool2o`000003ooooool0003o000002Oooooo
0_l0000Aooooo`;o0000DOooool001cooooo00?o0000ooooooooool0AOooool2o`000003ooooool0
003o000000Oooooo0_l00003ooooo`Co00000oooool2o`0000?ooooo0_l00002ooooo`;o00001Ooo
ool3o`0000Cooooo0_l00003ooooo`;o000000?oooooo`000?l000001?ooool4o`0000Gooooo0ol0
00000ooooooo0000o`00000:o`0000?ooooo1ol000000ooooooo0000o`000006o`0000Wooooo0_l0
00000ooooooo0000o`00000Mooooo`;o00001oooool3o`0000kooooo0_l000000ooooooo0000o`00
000Jooooo`;o0000=Oooool001cooooo00?o0000ooooooooool0AOooool2o`000003ooooool0003o
000000cooooo0ol00009ooooo`;o00000_ooool2o`0000Gooooo0_l00005ooooo`;o00000oooool2
o`000003ooooool0003o000000Cooooo0_l00007ooooo`?o000000?oooooo`000?l000000ol00000
0ooooooo0000o`000003o`0000Cooooo2_l00002ooooo`Co00000_ooool4o`0002Gooooo0_l00007
ooooo`Co00001?ooool2o`0000Oooooo0_l00004ooooo`;o00005oooool2o`0003Gooooo000Loooo
o`03o`000?oooooooooo05Kooooo0_l0000:ooooo`;o00004?ooool3o`0001;ooooo1?l00002oooo
o`Co00000_ooool5o`000003ooooool0003o000000?o000000?oooooo`000?l000001?l00004oooo
o`;o00000oooool5o`0000Wooooo0_l0000Tooooo`;o00001?ooool2o`0000gooooo0_l0001>oooo
o`007?ooool00ol0003oooooooooo`17ooooo`Co00005Oooool4o`00013ooooo0ol0000@ooooo`Go
00001?ooool3o`0000;ooooo0_l00003ooooo`[o000000Coooooo`000?l0003o00000oooool2o`00
00Kooooo1?l00007ooooo`;o0000;_ooool2o`0000Cooooo0_l0001Cooooo`007?ooool00ol0003o
ooooooooo`17ooooo`Co00002_ooool4o`0000Oooooo1?l00005ooooo`;o00002oooool4o`0000Oo
oooo0_l00004ooooo`Go00002oooool2o`000003ooooool0003o000000So00000_ooool2o`0000?o
oooo0_l00008ooooo`;o00009Oooool2o`00013ooooo0_l00004ooooo`;o0000Doooool001cooooo
00?o0000ooooooooool0EOooool4o`00013ooooo1?l00007ooooo`Ko00001oooool2o`0000Gooooo
1?l00003ooooo`Go00000oooool2o`0000Gooooo1_l000000ooooooo0000o`000009ooooo`;o0000
0oooool3o`0002;ooooo1?l0000;ooooo`;o00002Oooool2o`0005?ooooo000Looooo`03o`000?oo
oooooooo043ooooo0_l0000Aooooo`;o000000?oooooo`000?l000004oooool3o`000003ooooool0
003o000000?ooooo0ol0000Aooooo`Co00000_ooool6o`0000Gooooo0ol00002ooooo`;o000000Go
ooooo`000?l0003o0000ooooo`02o`0000Wooooo1?l000001?oooooo0000o`000?l0000Rooooo`;o
00003Oooool2o`0000Wooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`10ooooo`;o0000
3Oooool2o`0000;ooooo0_l000000ooooooo0000o`00000Dooooo`;o000000Coooooo`000?l0003o
oooo0_l000000ooooooo0000o`000005ooooo`;o00000_ooool2o`0000Oooooo0_l00003ooooo`;o
00002Oooool3o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000002oooool2o`00027o
oooo0_l00003ooooo`;o00000oooool2o`0006Sooooo000Looooo`;o0000D?ooool2o`0000Wooooo
0_l00007ooooo`;o00000oooool2o`0000Kooooo1?l00004ooooo`;o00000_ooool2o`0000;ooooo
0_l0000Fooooo`;o00001?ooool2o`0000;ooooo0_l0000Aooooo`;o00001_ooool3o`0001Gooooo
0_l00003ooooo`;o00000oooool2o`0000Oooooo0_l0000;ooooo`;o0000D_ooool001cooooo00?o
0000ooooooooool0B?ooool2o`0000oooooo0ol00004ooooo`;o000000?oooooo`000?l000000ooo
ool2o`0000Kooooo1?l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l0000=ooooo`;o0000
00?oooooo`000?l000000oooool2o`0000;ooooo0_l00005ooooo`Go000000?oooooo`000?l00000
0_ooool2o`0000[ooooo0_l00006ooooo`?o00005oooool4o`0000[ooooo1Ol00003ooooo`;o0000
0_ooool2o`000004ooooool0003o0000o`0005;ooooo000Looooo`03o`000?oooooooooo04Sooooo
0_l0000>ooooo`?o00001Oooool2o`0000Kooooo0_l00007ooooo`Ko00001_ooool2o`000003oooo
ool0003o000000[ooooo1Ol00003ooooo`?o00000_ooool2o`0000Cooooo1Ol000001Ooooooo0000
o`000?l0003ooooo00;o00003_ooool2o`0001cooooo1?l0000:ooooo`Co00001?ooool2o`0000;o
oooo1Ol0001Cooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00006Oooool2o`0000Oooooo
0_l00006ooooo`Co00001?ooool5o`0000;ooooo0_l00006ooooo`;o00000oooool2o`0000?ooooo
1Ol00005ooooo`?o00000_ooool2o`0000;ooooo0_l00003ooooo`;o000000Coooooo`000?l0003o
00000oooool2o`0000cooooo0_l0000Pooooo`Co00003_ooool4o`0000;ooooo0_l0001Dooooo`00
7?ooool00ol0003oooooooooo`0mooooo`;o00006oooool2o`0000Gooooo0_l00006ooooo`Ko0000
2Oooool2o`0000Cooooo0_l00005ooooo`;o000000?oooooo`000?l000000ol000000ooooooo0000
o`000004ooooo`;o00001oooool2o`000003ooooool0003o000000?ooooo0_l00002ooooo`Co0000
4_ooool2o`00017ooooo1?l00004ooooo`Go00002_ooool2o`000003ooooool0003o000000?o0000
F?ooool001cooooo00?o0000ooooooooool0F_ooool2o`0000?ooooo0_l00003ooooo`;o00001ooo
ool2o`0000Cooooo0_l00002ooooo`;o00000oooool4o`0000Sooooo1Ol000001?oooooo0000o`00
0?l0000>ooooo`?o00001Oooool4o`0000?ooooo0_l0000<ooooo`;o000000?oooooo`000?l00000
4Oooool4o`0000?ooooo0ol0000=ooooo`;o000000?oooooo`000?l000000_l0000Iooooo`;o0000
?_ooool001cooooo00?o0000ooooooooool0A_ooool2o`0001Kooooo0ol00003ooooo`;o00000ooo
ool2o`0000;ooooo0_l00004ooooo`;o00000_ooool7o`0000?ooooo0_l00008ooooo`Ko00001?oo
ool2o`0000Sooooo0_l00006ooooo`?o00001?ooool2o`0000cooooo0_l0000Kooooo`;o00002?oo
ool2o`000003ooooool0003o000000Gooooo0_l0000Jooooo`;o0000?_ooool001cooooo00?o0000
ooooooooool0A_ooool2o`0001Kooooo0_l00004ooooo`;o000000?oooooo`000?l000000_l0000<
ooooo`Go00001Oooool2o`0000[ooooo1?l00004ooooo`;o00000_ooool2o`0000[ooooo0ol00003
ooooo`;o0000=_ooool2o`000003ooooool0003o0000067ooooo000Looooo`03o`000?oooooooooo
05oooooo0_l00006ooooo`;o00000_ooool3o`0000Wooooo1?l00005ooooo`;o00001oooool2o`00
00Kooooo0_l00004ooooo`Go00002Oooool3o`000003ooooool0003o000000;o0000:Oooool2o`00
0003ooooool0003o000006kooooo000Looooo`03o`000?oooooooooo05gooooo1?l000000ooooooo
0000o`000003ooooo`;o00000_ooool3o`000003ooooool0003o000000Sooooo1?l000000ooooooo
0000o`000002o`0000Kooooo0ol00006ooooo`;o00001?ooool2o`000003ooooool0003o000000go
oooo1?l0000?ooooo`;o000000?oooooo`000?l000005Oooool2o`000003ooooool0003o000000_o
oooo0_l00005ooooo`;o0000F_ooool001cooooo00?o0000ooooooooool0GOooool4o`000003oooo
ool0003o000000?ooooo0_l00006ooooo`;o00002_ooool2o`000003ooooool0003o000000Kooooo
1?l00007ooooo`;o00001?ooool2o`0001Oooooo0_l0000:ooooo`;o000000Coooooo`000?l0003o
oooo0_l0000Fooooo`;o00001Oooool2o`0000?ooooo0_l00005ooooo`;o0000F_ooool001cooooo
00?o0000ooooooooool0Goooool2o`0000Kooooo0ol0000Aooooo`;o00001oooool6o`0000cooooo
0ol00006ooooo`;o00000oooool2o`0000[ooooo0_l0000=ooooo`;o000000?oooooo`000?l00000
2oooool2o`0000Wooooo0_l000000ooooooo0000o`000002ooooo`;o00001Oooool2o`0005oooooo
000Looooo`03o`000?oooooooooo04_ooooo0_l0000>ooooo`;o00002oooool6o`0000Cooooo0ol0
000:ooooo`;o00000oooool4o`0000;ooooo0_l00002ooooo`;o00001_ooool2o`0000Oooooo0_l0
0003ooooo`;o000000?oooooo`000?l000001Oooool3o`0001kooooo0_l0000<ooooo`;o00002Ooo
ool2o`00013ooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o00003_ooool2
o`0000[ooooo1ol00004ooooo`?o00002_ooool2o`0000Gooooo0ol000000ooooooo0000o`000002
ooooo`;o00004_ooool4o`000003ooooool0003o000000Gooooo1Ol00004ooooo`;o00000oooool4
o`000004ooooool0003o0000o`0001?ooooo0_l00007ooooo`;o000000?oooooo`000?l000000ooo
ool2o`00013ooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`1Wooooo`Co000000?ooooo
o`000?l000003?ooool3o`0000;ooooo1?l00004ooooo`;o000000?oooooo`000?l000000oooool2
o`00017ooooo1_l00005ooooo`;o00000_ooool2o`0000Cooooo0_l00003ooooo`So00003Oooool2
o`0000;ooooo1?l00005ooooo`Oo00000oooool3o`0005kooooo000Looooo`03o`000?oooooooooo
067ooooo0_l00004ooooo`Co00003Oooool5o`0000;ooooo1?l000000ooooooo0000o`000009oooo
o`;o00001_ooool2o`000003ooooool0003o000000[ooooo0_l00003ooooo`Co00000oooool3o`00
00Wooooo1?l0000?ooooo`;o00000_ooool2o`000003ooooool0003o000000Cooooo0_l00002oooo
o`;o00001?ooool3o`0005kooooo000Looooo`;o0000H_ooool2o`0000Kooooo0ol0000<ooooo`;o
00001_ooool2o`0000;ooooo0_l0000<ooooo`;o00000oooool2o`000003ooooool0003o000000ko
oooo1ol000001?oooooo0000o`000?l00009ooooo`;o00001?ooool2o`0001;ooooo1?l00009oooo
o`;o000000?oooooo`000?l00000Goooool001cooooo00?o0000ooooooooool0J_ooool2o`0000co
oooo0ol00004ooooo`?o00000_ooool4o`0000Gooooo0_l00002ooooo`?o00005_ooool2o`000003
ooooool0003o000000;o00003oooool2o`0000;ooooo0_l00009ooooo`;o00002Oooool2o`0000Wo
oooo0_l0001Rooooo`007?ooool00ol0003oooooooooo`1eooooo`Ko000000Coooooo`000?l0003o
oooo0_l00005ooooo`?o00001?ooool2o`000004ooooool0003o0000o`0000gooooo0_l00004oooo
o`;o00001Oooool2o`00017ooooo0_l0000=ooooo`;o00005?ooool2o`0006;ooooo000Looooo`03
o`000?oooooooooo06cooooo0_l00007ooooo`?o00001?ooool2o`0000Wooooo0_l00005ooooo`Co
00002_ooool2o`0000;ooooo0ol00003ooooo`;o00008Oooool2o`0000Sooooo0_l0000=ooooo`;o
000000?oooooo`000?l00000H_ooool001cooooo00?o0000ooooooooool0Joooool3o`0001Wooooo
1_l000000ooooooo0000o`000005ooooo`;o00001Oooool2o`0000?ooooo0_l000000ooooooo0000
o`000003ooooo`;o00001?ooool2o`0001Sooooo0_l00008ooooo`;o00002_ooool2o`000003oooo
ool0003o000006Gooooo000Looooo`03o`000?oooooooooo06Sooooo0_l000000ooooooo0000o`00
000Booooo`;o00002?ooool4o`0000Sooooo0_l00005ooooo`;o00001_ooool2o`0000?ooooo0_l0
0004ooooo`;o00004_ooool2o`0001[ooooo0_l0001Xooooo`007?ooool00ol0003oooooooooo`1W
ooooo`?o00003?ooool2o`0000Oooooo1?l00007ooooo`;o00002_ooool2o`0000Cooooo0_l00000
0ooooooo0000o`000007ooooo`?o00001?ooool2o`0000;ooooo0_l0000>ooooo`;o00002?ooool2
o`0007[ooooo000Looooo`03o`000?oooooooooo06Oooooo0_l0000=ooooo`?o00000_ooool2o`00
00;ooooo1Ol0000Booooo`Co00001Oooool2o`0000Oooooo0_l00009ooooo`;o00006?ooool2o`00
013ooooo0_l0001Xooooo`007?ooool00ol0003oooooooooo`1gooooo`;o00000_ooool2o`0000;o
oooo1Ol00008ooooo`;o00002_ooool2o`0001Cooooo0_l00002ooooo`;o00006?ooool2o`0000;o
oooo0_l00004ooooo`;o00001Oooool6o`0006Kooooo000Looooo`03o`000?oooooooooo07[ooooo
0_l000001Ooooooo0000o`000?l0003ooooo00;o00001oooool4o`00023ooooo0_l00002ooooo`;o
00002oooool2o`0000_ooooo0_l000001?oooooo0000o`000?l00004ooooo`;o00001Oooool2o`00
0004ooooool0003o0000o`0006Kooooo000Looooo`03o`000?oooooooooo07Cooooo0_l00004oooo
o`;o000000Goooooo`000?l0003o0000ooooo`02o`0000Oooooo1_l000000ooooooo0000o`000009
ooooo`;o00008Oooool4o`0000Gooooo0_l00005ooooo`;o00003oooool2o`0000?ooooo0_l0001R
ooooo`007?ooool00ol0003oooooooooo`1/ooooo`;o00001_ooool2o`0001Kooooo1?l000000ooo
oooo0000o`000007ooooo`Co00002?ooool2o`0000?ooooo0_l00006ooooo`;o00000oooool2o`00
00Cooooo0_l000000ooooooo0000o`000005ooooo`;o00001oooool2o`0000Wooooo0_l00007oooo
o`;o0000H_ooool001cooooo00?o0000ooooooooool0I_ooool2o`0000Cooooo0ol00009ooooo`;o
00004_ooool2o`000004ooooool0003o0000o`0000Sooooo0ol00009ooooo`;o00000oooool2o`00
00Kooooo0_l00003ooooo`;o00001?ooool2o`0000Cooooo0_l00007ooooo`;o00000_ooool2o`00
00;ooooo0_l00005ooooo`;o0000Joooool001cooooo00?o0000ooooooooool0I_ooool2o`0000Go
oooo0_l00009ooooo`Ko00000oooool2o`0000Wooooo0_l000001?oooooo0000o`000?l0000Eoooo
o`;o00002oooool2o`0000kooooo0_l00007ooooo`;o00000_ooool2o`000003ooooool0003o0000
00Co0000Koooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<
ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo07[ooooo1?l00003ooooo`Co00001Ooo
ool2o`0000Gooooo0_l0000=ooooo`;o00001Oooool2o`0000_ooooo0_l0000>ooooo`;o00000ooo
ool2o`0000Gooooo0_l00002ooooo`Oo0000K_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo06co
oooo0_l000000ooooooo0000o`00000=ooooo`;o00000oooool3o`0000Cooooo0_l00005ooooo`;o
00003Oooool2o`0000Kooooo0_l00003ooooo`;o00006_ooool2o`0000Gooooo0ol00003ooooo`;o
000000?oooooo`000?l000005Oooool2o`0005Oooooo00000ooooooo410@ooooo`02ooooo`03oa0@
4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo06co
oooo1Ol00007ooooo`;o00001?ooool2o`0000Cooooo1?l00002ooooo`;o00004Oooool2o`0000Go
oooo0_l00002ooooo`;o00000_ooool3o`0000gooooo0ol0000=ooooo`;o00000oooool2o`0000Co
oooo0_l000000ooooooo0000o`00000Dooooo`;o0000Eoooool00003ooooool0003ooooo00;ooooo
00?o0000ooooooooool02Oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0001^ooooo`;o
00002?ooool2o`0000cooooo0_l00002ooooo`;o00002?ooool2o`0000?ooooo0_l000001?oooooo
0000o`000?l00005ooooo`;o00001_ooool2o`0000kooooo1Ol0000;ooooo`;o00000oooool4o`00
00;ooooo0_l000000ooooooo0000o`00001]ooooo`0000?oooooo`000?ooool00_ooool00ol0003o
ooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`1ooooo
o`;o00000_ooool2o`0000oooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l0000Moooo
o`Co00001_ooool2o`0000;ooooo0_l00006ooooo`;o0000M?ooool00003ooooool@413ooooo00;o
oooo00?o410@ooooooooool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000oooo
ooooool0J_ooool2o`0000gooooo0_l00004ooooo`;o00000_ooool2o`0001Cooooo1?l000000ooo
oooo0000o`000003ooooo`;o00003_ooool2o`0001;ooooo0_l000001?oooooo0000o`000?l00006
ooooo`;o0000M?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooo
oonj^[[o000000Kooooo00?o0000ooooooooool0Hoooool2o`0000Gooooo0_l0000=ooooo`;o0000
1?ooool2o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o00002oooool8o`0000;ooooo
0_l00007ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00009ooooo`;o0000
1_ooool2o`0000;ooooo0_l00003ooooo`;o0000M?ooool00006ooooooo^k^ko<S8bo`000?lb<S;o
k^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0Hoooool2o`00
01Cooooo0_l000000ooooooo0000o`000007ooooo`;o000000?oooooo`000?l000000_ooool2o`00
00oooooo1?l00007ooooo`;o00000_ooool2o`000003ooooool0003o000000Kooooo0_l00009oooo
o`;o00000_ooool2o`0000Kooooo0_l00003ooooo`;o0000M?ooool001cooooo00?o0000oooooooo
ool0O?ooool2o`0000Oooooo0_l0000:ooooo`;o00002oooool2o`000003ooooool0003o000000?o
oooo1?l0000Looooo`;o000000?oooooo`000?l000002_ooool2o`0007;ooooo000Looooo`03o`00
0?oooooooooo08Gooooo0_l0000:ooooo`;o00002oooool2o`000003ooooool0003o000000?ooooo
0_l000000ooooooo0000o`000006ooooo`;o00001_ooool4o`0000Cooooo1?l00004ooooo`;o0000
2_ooool2o`0007;ooooo000Looooo`03o`000?oooooooooo07[ooooo1_l0000Nooooo`;o000000Co
ooooo`000?l0003o00001Oooool4o`0000Cooooo0_l00006ooooo`Co00000_ooool6o`0008Cooooo
000Looooo`03o`000?oooooooooo07[ooooo1ol0000=ooooo`;o00004Oooool3o`0000Oooooo0_l0
0003ooooo`?o00001_ooool2o`0000Cooooo0_l000000ooooooo0000o`000025ooooo`007?ooool0
0ol0003oooooooooo`1booooo`;o00002oooool2o`0000Kooooo0_l00005ooooo`?o00007oooool2
o`0000Kooooo0_l0002?ooooo`007?ooool00ol0003oooooooooo`1aooooo`?o00002oooool2o`00
00;ooooo0_l00002ooooo`;o00001_ooool4o`0000Gooooo0_l0000Nooooo`;o00006?ooool2o`00
07Gooooo000Looooo`03o`000?oooooooooo077ooooo0_l0000@ooooo`;o00002_ooool4o`0000Go
oooo1Ol00007ooooo`Oo00003Oooool2o`0000;ooooo1?l0000Booooo`;o0000MOooool001cooooo
00?o0000ooooooooool0V_ooool3o`0000Oooooo1ol0000=ooooo`;o00000_ooool4o`0001gooooo
0_l0001Zooooo`007?ooool00ol0003oooooooooo`2_ooooo`Co0000:_ooool2o`0006[ooooo000L
ooooo`03o`000?oooooooooo0:oooooo1?l000000ooooooo0000o`000004ooooo`;o0000SOooool0
01cooooo00?o0000ooooooooool0XOooool3o`0000Kooooo0_l00003ooooo`;o00000oooool2o`00
00Cooooo0_l0002=ooooo`007?ooool2o`0008oooooo0_l00003ooooo`;o00001_ooool2o`000004
ooooool0003o0000ooooo`?o00001_ooool2o`0000;ooooo0ol0002Hooooo`007?ooool00ol0003o
ooooooooo`2>ooooo`;o00000oooool2o`0000Kooooo0_l000001Ooooooo0000o`000?l0003ooooo
00;o000000Coooooo`000?l0003o00001_ooool2o`0000?ooooo0_l0002Dooooo`007?ooool00ol0
003oooooooooo`23ooooo`;o00004?ooool2o`0000Sooooo0_l000001?oooooo0000o`000?ooool3
o`0000?ooooo0ol00003ooooo`Co0000U?ooool001cooooo00?o0000ooooooooool0Poooool2o`00
013ooooo0_l0000Dooooo`?o00000oooool3o`0000Sooooo0_l0002;ooooo`007?ooool00ol0003o
ooooooooo`2?ooooo`;o00008Oooool4o`000003ooooool0003o000000?ooooo0_l0002;ooooo`00
7?ooool00ol0003oooooooooo`2?ooooo`;o00008oooool2o`000003ooooool0003o0000093ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`2Wooooo`;o0000X?ooool001cooooo00?o0000oooooooo
ool0X?ooool2o`0000Gooooo0_l0000Nooooo`;o0000P?ooool001cooooo00?o0000ooooooooool0
V_ooool2o`0000Cooooo0_l0000Uooooo`;o0000P?ooool001cooooo00?o0000ooooooooool0V_oo
ool2o`000:gooooo000Looooo`03o`000?oooooooooo0;3ooooo0_l0002Gooooo`007?ooool00ol0
003oooooooooo`2`ooooo`;o0000Uoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2
o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooo
oom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool0
01Cooooo00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o0000oooooooo
ool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oo
oooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`004_ooool00omE
EEGoIVIVo`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Q
ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05_ooool4o`000008oa0@4?oo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool5
o`0008cooooo002Rooooo`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0S?ooool00:;ooooo00Go0000oooooooooooo
ooooo`00000Kooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003oooo
o`05oa0@4?ooooooooooooooool@41001?ooool00onHV9So8B4Qonk^kP2=ooooo`00X_ooool01Ol0
003ooooooooooooooooo000000Wooooo1_l0000<ooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001Oooool00onHV9So8B4Q
onk^kP2<ooooo`00X_ooool01Ol0003oQhN7oooooonYZJWo000001_ooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000006oooo
o`03ogMgMomVIVKooooo08_ooooo002Qooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHoooooooo
ool06Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@00Oooooo00?o0000ooooooooool0R_ooool00<;ooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05o`000?nj^[[ooooooiRHV?l@4100S?ooool00<3ooooo00?oEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`0S?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1008) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.63798 .509 Mdot
.67495 .53973 Mdot
.3859 .36413 Mdot
.45525 .61887 Mdot
.76151 .50873 Mdot
.40791 .39751 Mdot
.61578 .35531 Mdot
.56103 .35057 Mdot
.38729 .38334 Mdot
.56264 .5081 Mdot
.59899 .33563 Mdot
.55755 .57242 Mdot
.58054 .34763 Mdot
.47117 .60645 Mdot
.54184 .86889 Mdot
.43862 .66887 Mdot
.70158 .53883 Mdot
.29039 .50334 Mdot
.5379 .63411 Mdot
.33166 .37199 Mdot
.64581 .488 Mdot
.46408 .61939 Mdot
.64328 .5084 Mdot
.47155 .6066 Mdot
.45314 .6008 Mdot
.68533 .51815 Mdot
.61857 .54911 Mdot
.44262 .63441 Mdot
.4811 .57246 Mdot
.5697 .36822 Mdot
.30673 .67401 Mdot
.63614 .82512 Mdot
.49348 .67997 Mdot
.71803 .28567 Mdot
.56201 .3437 Mdot
.64753 .75831 Mdot
.37986 .39585 Mdot
.58261 .36894 Mdot
.56423 .34329 Mdot
.57819 .38371 Mdot
.57115 .35622 Mdot
.68144 .52286 Mdot
.56943 .39465 Mdot
.64409 .31142 Mdot
.53849 .60719 Mdot
.70069 .42667 Mdot
.41816 .74634 Mdot
.51325 .62289 Mdot
.70086 .53372 Mdot
.34146 .36464 Mdot
.70577 .2914 Mdot
.61199 .37256 Mdot
.4442 .41379 Mdot
.902 .50883 Mdot
.59413 .36992 Mdot
.54315 .60321 Mdot
.36906 .37691 Mdot
.47063 .62745 Mdot
.4733 .61053 Mdot
.52161 .7589 Mdot
.43665 .62589 Mdot
.29406 .53257 Mdot
.7131 .51066 Mdot
.33867 .48653 Mdot
.38938 .39156 Mdot
.5681 .34074 Mdot
.67507 .55158 Mdot
.58592 .35142 Mdot
.52911 .55769 Mdot
.46298 .38637 Mdot
.51221 .62386 Mdot
.57419 .33875 Mdot
.65174 .563 Mdot
.50101 .63458 Mdot
.43051 .21015 Mdot
.37057 .81047 Mdot
.24517 .54187 Mdot
.57581 .75796 Mdot
.52954 .77713 Mdot
.29274 .43947 Mdot
.49457 .57861 Mdot
.18387 .52319 Mdot
.47898 .84775 Mdot
.65032 .5025 Mdot
.44352 .68174 Mdot
.46571 .36889 Mdot
.49516 .63766 Mdot
.6297 .4455 Mdot
.53453 .58555 Mdot
.54823 .19591 Mdot
.39065 .38019 Mdot
.65473 .52807 Mdot
.45673 .61573 Mdot
.44711 .58319 Mdot
.584 .66072 Mdot
.4483 .65726 Mdot
.449 .63742 Mdot
.62374 .54085 Mdot
.60421 .3318 Mdot
.55218 .54818 Mdot
.61351 .3946 Mdot
.45716 .40327 Mdot
.51607 .64178 Mdot
.35884 .37465 Mdot
.62912 .5514 Mdot
.50077 .64124 Mdot
.58968 .32056 Mdot
.5171 .5985 Mdot
.62656 .27343 Mdot
.67476 .5433 Mdot
.45076 .57906 Mdot
.28726 .55427 Mdot
.30433 .27478 Mdot
.65055 .52876 Mdot
.32125 .42871 Mdot
.51211 .57825 Mdot
.46399 .64303 Mdot
.67406 .53709 Mdot
.43463 .38077 Mdot
.60887 .47372 Mdot
.69499 .50087 Mdot
.56626 .37791 Mdot
.70268 .50371 Mdot
.45488 .68985 Mdot
.40058 .38884 Mdot
.49983 .36437 Mdot
.49508 .37349 Mdot
.27458 .6329 Mdot
.48942 .63873 Mdot
.70111 .34878 Mdot
.4245 .39561 Mdot
.66276 .52578 Mdot
.58843 .34844 Mdot
.43517 .56909 Mdot
.64593 .54547 Mdot
.60592 .35055 Mdot
.25799 .54774 Mdot
.47712 .29521 Mdot
.70234 .51541 Mdot
.64169 .29352 Mdot
.62756 .36007 Mdot
.58624 .38585 Mdot
.70223 .26691 Mdot
.68298 .54058 Mdot
.26737 .53914 Mdot
.60152 .3559 Mdot
.36818 .72232 Mdot
.54375 .58479 Mdot
.29529 .58905 Mdot
.15404 .47529 Mdot
.69009 .26927 Mdot
.4913 .25014 Mdot
.30519 .51682 Mdot
.60079 .38545 Mdot
.45752 .58469 Mdot
.69514 .53006 Mdot
.68942 .53028 Mdot
.4638 .65715 Mdot
.45088 .61327 Mdot
.50976 .6281 Mdot
.45775 .57487 Mdot
.47108 .79321 Mdot
.52274 .60008 Mdot
.20645 .61225 Mdot
.65223 .52129 Mdot
.44419 .60911 Mdot
.38773 .3588 Mdot
.49226 .55651 Mdot
.56949 .34915 Mdot
.46398 .62928 Mdot
.45244 .62142 Mdot
.43896 .59843 Mdot
.61634 .36122 Mdot
.62998 .81491 Mdot
.17472 .41722 Mdot
.74851 .68499 Mdot
.3478 .4054 Mdot
.4125 .40513 Mdot
.48476 .64457 Mdot
.28132 .52739 Mdot
.66614 .72961 Mdot
.48906 .58537 Mdot
.43618 .14938 Mdot
.45106 .63423 Mdot
.76619 .53177 Mdot
.39746 .65838 Mdot
.7642 .66882 Mdot
.2278 .57837 Mdot
.46754 .5737 Mdot
.61938 .61751 Mdot
.75741 .58739 Mdot
.61664 .2915 Mdot
.57342 .35762 Mdot
.39394 .36067 Mdot
.37305 .37081 Mdot
.61589 .30822 Mdot
.51367 .52935 Mdot
.45517 .54582 Mdot
.47361 .54742 Mdot
.46903 .39724 Mdot
.72153 .52023 Mdot
.26825 .51291 Mdot
.62799 .54328 Mdot
.20699 .69557 Mdot
.63747 .26904 Mdot
.63572 .38645 Mdot
.25153 .55067 Mdot
.40952 .37243 Mdot
.45753 .40572 Mdot
.2759 .52459 Mdot
.50505 .60307 Mdot
.68133 .54769 Mdot
.80434 .39736 Mdot
.45289 .53778 Mdot
.79775 .35703 Mdot
.67561 .55989 Mdot
.59541 .46552 Mdot
.59889 .34293 Mdot
.36698 .39654 Mdot
.46101 .64338 Mdot
.49566 .61562 Mdot
.65471 .48162 Mdot
.50998 .62302 Mdot
.71012 .57783 Mdot
.45961 .64786 Mdot
.52329 .31406 Mdot
.24431 .54031 Mdot
.61357 .3075 Mdot
.26326 .62803 Mdot
.63439 .53432 Mdot
.23537 .56744 Mdot
.40906 .36283 Mdot
.62886 .75987 Mdot
.57921 .33385 Mdot
.27834 .55586 Mdot
.43195 .37297 Mdot
.27488 .50999 Mdot
.51198 .56185 Mdot
.4323 .408 Mdot
.29917 .54105 Mdot
.54743 .82113 Mdot
.52311 .56878 Mdot
.45853 .79786 Mdot
.61768 .34936 Mdot
.70491 .50767 Mdot
.43722 .6276 Mdot
.35241 .39196 Mdot
.47637 .68496 Mdot
.46494 .22356 Mdot
.50321 .36461 Mdot
.41806 .41766 Mdot
.32024 .47049 Mdot
.28081 .5531 Mdot
.41155 .24415 Mdot
.69186 .32239 Mdot
.69762 .54302 Mdot
.51463 .64765 Mdot
.72445 .73444 Mdot
.6011 .35533 Mdot
.50507 .59703 Mdot
.50095 .33718 Mdot
.59911 .35738 Mdot
.47256 .62884 Mdot
.62038 .33862 Mdot
.68984 .5342 Mdot
.24394 .37059 Mdot
.70072 .54108 Mdot
.52941 .58147 Mdot
.60175 .32079 Mdot
.44859 .39926 Mdot
.6859 .51506 Mdot
.51566 .60339 Mdot
.47565 .65245 Mdot
.48554 .37988 Mdot
.44364 .60156 Mdot
.68795 .75991 Mdot
.44042 .60298 Mdot
.37364 .36282 Mdot
.44368 .65282 Mdot
.53522 .16111 Mdot
.42106 .30861 Mdot
.67616 .55118 Mdot
.41323 .41682 Mdot
.38129 .38095 Mdot
.27301 .39483 Mdot
.44225 .42001 Mdot
.50844 .58094 Mdot
.39132 .40836 Mdot
.32022 .57415 Mdot
.59358 .37568 Mdot
.48964 .6631 Mdot
.64553 .38949 Mdot
.34736 .35993 Mdot
.46568 .39933 Mdot
.40637 .62612 Mdot
.63504 .56047 Mdot
.45592 .61546 Mdot
.45859 .3922 Mdot
.69161 .4932 Mdot
.5293 .58778 Mdot
.39197 .5643 Mdot
.48943 .38134 Mdot
.61165 .3593 Mdot
.4015 .65448 Mdot
.52039 .61706 Mdot
.37156 .38952 Mdot
.6411 .55197 Mdot
.55881 .34759 Mdot
.67478 .51634 Mdot
.7949 .51167 Mdot
.56918 .2763 Mdot
.51386 .80247 Mdot
.31176 .55438 Mdot
.51994 .22951 Mdot
.78378 .64207 Mdot
.36149 .25679 Mdot
.34852 .66325 Mdot
.82312 .50939 Mdot
.43549 .37777 Mdot
.51342 .31493 Mdot
.3762 .37857 Mdot
.46973 .58584 Mdot
.39946 .39515 Mdot
.77781 .65725 Mdot
.45622 .64535 Mdot
.39483 .40077 Mdot
.24887 .38735 Mdot
.44676 .61702 Mdot
.64879 .53063 Mdot
.53124 .86237 Mdot
.40919 .20245 Mdot
.65046 .2635 Mdot
.43281 .40095 Mdot
.43088 .71405 Mdot
.44302 .63033 Mdot
.43492 .60287 Mdot
.69403 .5147 Mdot
.46372 .6627 Mdot
.27158 .51219 Mdot
.25018 .54441 Mdot
.39416 .5135 Mdot
.18201 .43536 Mdot
.55377 .55147 Mdot
.68821 .51475 Mdot
.47811 .76478 Mdot
.4588 .19915 Mdot
.32923 .38791 Mdot
.55762 .38033 Mdot
.60673 .82147 Mdot
.48665 .5303 Mdot
.57056 .39706 Mdot
.65386 .33549 Mdot
.66029 .53911 Mdot
.6449 .80211 Mdot
.57814 .3624 Mdot
.65698 .63502 Mdot
.56165 .66174 Mdot
.49869 .60791 Mdot
.58984 .33086 Mdot
.55778 .56552 Mdot
.50056 .17103 Mdot
.37646 .7528 Mdot
.19793 .5862 Mdot
.53512 .59769 Mdot
.39895 .23241 Mdot
.46201 .63567 Mdot
.61049 .4839 Mdot
.43904 .60762 Mdot
.67118 .51225 Mdot
.56515 .51989 Mdot
.49776 .41844 Mdot
.1619 .47465 Mdot
.64054 .27088 Mdot
.30436 .51598 Mdot
.46701 .64846 Mdot
.4975 .60828 Mdot
.26083 .54155 Mdot
.64921 .5096 Mdot
.45932 .57487 Mdot
.34338 .57787 Mdot
.50216 .62562 Mdot
.57177 .36121 Mdot
.2457 .63744 Mdot
.61469 .52072 Mdot
.43322 .6482 Mdot
.67559 .48796 Mdot
.60962 .36572 Mdot
.56295 .34948 Mdot
.40942 .62233 Mdot
.55407 .35651 Mdot
.4533 .63039 Mdot
.30002 .71748 Mdot
.66813 .50014 Mdot
.39849 .59094 Mdot
.63946 .52129 Mdot
.57192 .76723 Mdot
.59057 .31936 Mdot
.51001 .34821 Mdot
.59039 .56957 Mdot
.57748 .35899 Mdot
.66868 .2839 Mdot
.49871 .5411 Mdot
.47235 .67538 Mdot
.57377 .20662 Mdot
.4383 .39803 Mdot
.48465 .38485 Mdot
.57257 .32645 Mdot
.51909 .62047 Mdot
.47244 .66706 Mdot
.60959 .36967 Mdot
.60418 .66674 Mdot
.29378 .36941 Mdot
.44504 .63628 Mdot
.66522 .50906 Mdot
.66419 .52408 Mdot
.53028 .61381 Mdot
.51159 .59293 Mdot
.41031 .3773 Mdot
.41309 .41572 Mdot
.34822 .39232 Mdot
.48862 .38144 Mdot
.51308 .33583 Mdot
.75011 .44231 Mdot
.57941 .38428 Mdot
.72253 .37304 Mdot
.5243 .19416 Mdot
.55188 .62847 Mdot
.41709 .40775 Mdot
.48985 .60822 Mdot
.4578 .61982 Mdot
.55846 .34778 Mdot
.57379 .26425 Mdot
.4663 .69677 Mdot
.68738 .50181 Mdot
.57107 .32625 Mdot
.52363 .53951 Mdot
.76109 .40474 Mdot
.29837 .5351 Mdot
.63771 .24265 Mdot
.57381 .33716 Mdot
.65584 .54058 Mdot
.61977 .32867 Mdot
.49821 .61596 Mdot
.54335 .61547 Mdot
.66681 .53551 Mdot
.29849 .54661 Mdot
.48433 .54921 Mdot
.47187 .6319 Mdot
.24442 .27527 Mdot
.41625 .21421 Mdot
.52781 .38252 Mdot
.45901 .57965 Mdot
.45936 .66785 Mdot
.28471 .50559 Mdot
.5012 .62151 Mdot
.48339 .65378 Mdot
.26701 .30204 Mdot
.57111 .41759 Mdot
.28062 .50146 Mdot
.66175 .63848 Mdot
.67996 .55924 Mdot
.68444 .77976 Mdot
.36397 .39697 Mdot
.58028 .31045 Mdot
.29116 .33354 Mdot
.44619 .41085 Mdot
.48018 .22077 Mdot
.66697 .79431 Mdot
.48624 .38377 Mdot
.34109 .53813 Mdot
.5445 .65169 Mdot
.45149 .64697 Mdot
.46553 .63947 Mdot
.27706 .5323 Mdot
.68593 .53924 Mdot
.42152 .49006 Mdot
.39146 .78614 Mdot
.46094 .62706 Mdot
.70105 .57887 Mdot
.55298 .82881 Mdot
.47533 .38994 Mdot
.27329 .51384 Mdot
.27924 .56023 Mdot
.46827 .64683 Mdot
.27511 .30905 Mdot
.687 .51853 Mdot
.51551 .60257 Mdot
.52198 .5887 Mdot
.43377 .40252 Mdot
.66923 .5476 Mdot
.4415 .3803 Mdot
.51199 .35111 Mdot
.77589 .58678 Mdot
.26409 .24827 Mdot
.56818 .33315 Mdot
.67958 .75284 Mdot
.58261 .37524 Mdot
.20409 .56267 Mdot
.44281 .41333 Mdot
.4943 .58169 Mdot
.63604 .54644 Mdot
.51753 .60225 Mdot
.49833 .59309 Mdot
.504 .6028 Mdot
.5304 .54917 Mdot
.45886 .14931 Mdot
.28745 .52027 Mdot
.42848 .64474 Mdot
.37818 .36395 Mdot
.67714 .75992 Mdot
.42172 .82217 Mdot
.48936 .61676 Mdot
.47894 .65061 Mdot
.64614 .53478 Mdot
.46632 .65903 Mdot
.59508 .37453 Mdot
.64176 .55317 Mdot
.45125 .57717 Mdot
.6314 .79948 Mdot
.48069 .56973 Mdot
.76376 .66068 Mdot
.6196 .32765 Mdot
.66789 .28736 Mdot
.42838 .60901 Mdot
.50028 .36606 Mdot
.48465 .38492 Mdot
.37243 .40355 Mdot
.58891 .31289 Mdot
.3814 .39527 Mdot
.34018 .76248 Mdot
.53017 .65192 Mdot
.4562 .58842 Mdot
.47827 .66691 Mdot
.40497 .40837 Mdot
.64492 .44679 Mdot
.43396 .25132 Mdot
.50865 .53642 Mdot
.41503 .38558 Mdot
.70105 .50049 Mdot
.35978 .48922 Mdot
.63623 .54022 Mdot
.2601 .50723 Mdot
.59598 .33521 Mdot
.29955 .5211 Mdot
.67937 .26928 Mdot
.67388 .54154 Mdot
.65227 .48184 Mdot
.40821 .40461 Mdot
.57444 .4476 Mdot
.88241 .52923 Mdot
.46652 .38298 Mdot
.3007 .6143 Mdot
.68842 .5092 Mdot
.51422 .57347 Mdot
.22897 .5954 Mdot
.58511 .45003 Mdot
.38222 .39315 Mdot
.48068 .58598 Mdot
.25748 .33979 Mdot
.41214 .37836 Mdot
.49452 .66218 Mdot
.43161 .382 Mdot
.57439 .34308 Mdot
.42896 .39178 Mdot
.69339 .55901 Mdot
.49705 .64287 Mdot
.87845 .54715 Mdot
.22383 .55551 Mdot
.44213 .59989 Mdot
.57533 .32359 Mdot
.39428 .53477 Mdot
.48842 .59864 Mdot
.25326 .52716 Mdot
.40441 .38917 Mdot
.38355 .33884 Mdot
.4411 .62967 Mdot
.4154 .40144 Mdot
.63848 .51077 Mdot
.59202 .31216 Mdot
.27954 .4863 Mdot
.50186 .35835 Mdot
.69671 .51859 Mdot
.53904 .30859 Mdot
.56405 .32666 Mdot
.45763 .66539 Mdot
.52402 .60264 Mdot
.66122 .51469 Mdot
.20776 .42316 Mdot
.43969 .64537 Mdot
.49423 .57872 Mdot
.38255 .36189 Mdot
.38315 .40058 Mdot
.21587 .4168 Mdot
.43859 .38367 Mdot
.54422 .62033 Mdot
.66288 .51459 Mdot
.46249 .60624 Mdot
.64946 .54075 Mdot
.48968 .65567 Mdot
.7163 .55671 Mdot
.65695 .50119 Mdot
.38225 .2683 Mdot
.47059 .59431 Mdot
.39745 .65162 Mdot
.50129 .59778 Mdot
.50736 .62519 Mdot
.40036 .37328 Mdot
.27145 .51856 Mdot
.42114 .59186 Mdot
.31277 .50459 Mdot
.25803 .52337 Mdot
.75974 .56896 Mdot
.43507 .39986 Mdot
.28009 .54154 Mdot
.48338 .80953 Mdot
.40413 .41387 Mdot
.28706 .52983 Mdot
.45112 .82984 Mdot
.56495 .33683 Mdot
.69734 .55106 Mdot
.44721 .61577 Mdot
.81977 .49967 Mdot
.31611 .71608 Mdot
.44335 .41025 Mdot
.44254 .59722 Mdot
.48855 .60566 Mdot
.67382 .49513 Mdot
.18326 .61866 Mdot
.35693 .36319 Mdot
.46462 .5884 Mdot
.67082 .55262 Mdot
.14289 .54466 Mdot
.36754 .36556 Mdot
.28344 .53003 Mdot
.61517 .36559 Mdot
.67654 .57457 Mdot
.48975 .37226 Mdot
.6114 .37035 Mdot
.40456 .27494 Mdot
.66741 .27235 Mdot
.51271 .57854 Mdot
.41595 .40791 Mdot
.66626 .24121 Mdot
.54209 .53694 Mdot
.53502 .33657 Mdot
.47292 .71116 Mdot
.65756 .53756 Mdot
.59863 .37263 Mdot
.3017 .51857 Mdot
.66049 .56298 Mdot
.65537 .50746 Mdot
.55923 .35677 Mdot
.35097 .52085 Mdot
.59348 .46259 Mdot
.56745 .35797 Mdot
.55299 .20062 Mdot
.79815 .46678 Mdot
.40172 .41203 Mdot
.25805 .52661 Mdot
.78619 .38057 Mdot
.68114 .52203 Mdot
.61063 .81965 Mdot
.63981 .23488 Mdot
.44876 .63716 Mdot
.27671 .54507 Mdot
.69488 .44193 Mdot
.36751 .77974 Mdot
.5993 .3597 Mdot
.50974 .40746 Mdot
.30133 .55179 Mdot
.44543 .64356 Mdot
.47388 .72449 Mdot
.47737 .58266 Mdot
.60033 .33997 Mdot
.51517 .77206 Mdot
.65507 .54103 Mdot
.56535 .32878 Mdot
.63901 .2435 Mdot
.45597 .62911 Mdot
.47634 .58762 Mdot
.28303 .65919 Mdot
.69007 .54483 Mdot
.35259 .39303 Mdot
.51032 .57926 Mdot
.46825 .63104 Mdot
.4645 .67847 Mdot
.39782 .61089 Mdot
.29777 .28219 Mdot
.4659 .58891 Mdot
.53755 .29602 Mdot
.43146 .64621 Mdot
.47135 .59657 Mdot
.67927 .48921 Mdot
.30961 .21631 Mdot
.51261 .34443 Mdot
.46494 .63061 Mdot
.50645 .57219 Mdot
.55794 .35432 Mdot
.54712 .48965 Mdot
.58193 .4449 Mdot
.48026 .37497 Mdot
.36721 .68771 Mdot
.53218 .55036 Mdot
.6504 .5525 Mdot
.28523 .55639 Mdot
.52788 .61421 Mdot
.65241 .55253 Mdot
.47564 .5637 Mdot
.4159 .3817 Mdot
.40784 .41375 Mdot
.66057 .29728 Mdot
.28568 .53641 Mdot
.30051 .69559 Mdot
.71817 .38484 Mdot
.39432 .3619 Mdot
.45348 .5943 Mdot
.61092 .30951 Mdot
.4611 .39527 Mdot
.48959 .37476 Mdot
.41199 .64726 Mdot
.69172 .5259 Mdot
.65286 .52732 Mdot
.29403 .58817 Mdot
.48585 .27429 Mdot
.23569 .30671 Mdot
.5769 .34005 Mdot
.4461 .57932 Mdot
.6931 .33347 Mdot
.65168 .5283 Mdot
.24617 .5969 Mdot
.28208 .54212 Mdot
.6005 .36077 Mdot
.3323 .39055 Mdot
.64663 .54383 Mdot
.70391 .52504 Mdot
.52567 .57475 Mdot
.48163 .62839 Mdot
.34241 .64966 Mdot
.35128 .5551 Mdot
.60723 .36858 Mdot
.25827 .53629 Mdot
.44092 .37735 Mdot
.47307 .58067 Mdot
.64705 .50384 Mdot
.80311 .41854 Mdot
.5103 .57378 Mdot
.40748 .37476 Mdot
.65874 .53467 Mdot
.26473 .54769 Mdot
.25649 .52328 Mdot
.50639 .62485 Mdot
.49454 .7558 Mdot
.59138 .36592 Mdot
.64961 .5317 Mdot
.75151 .35729 Mdot
.43949 .64867 Mdot
.48149 .63348 Mdot
.42145 .68676 Mdot
.56661 .36918 Mdot
.6708 .29678 Mdot
.30293 .54476 Mdot
.68211 .531 Mdot
.47281 .57162 Mdot
.29284 .53441 Mdot
.68229 .30888 Mdot
.43231 .41373 Mdot
.43023 .38746 Mdot
.25398 .52568 Mdot
.26563 .54322 Mdot
.25441 .53763 Mdot
.59692 .82799 Mdot
.6947 .55943 Mdot
.39472 .59224 Mdot
.43455 .63214 Mdot
.28097 .59107 Mdot
.44363 .56206 Mdot
.61925 .32475 Mdot
.44049 .39519 Mdot
.49781 .59657 Mdot
.52872 .58183 Mdot
.40743 .66912 Mdot
.39186 .622 Mdot
.6146 .52666 Mdot
.67304 .54499 Mdot
.53505 .65083 Mdot
.43749 .40278 Mdot
.1909 .6711 Mdot
.82512 .61 Mdot
.42548 .6165 Mdot
.58022 .46686 Mdot
.64593 .50655 Mdot
.56533 .37226 Mdot
.55104 .42751 Mdot
.6183 .3298 Mdot
.67587 .52875 Mdot
.47103 .58292 Mdot
.72814 .3808 Mdot
.26178 .51347 Mdot
.51528 .62595 Mdot
.60075 .34829 Mdot
.51279 .62729 Mdot
.61222 .36896 Mdot
.77425 .50064 Mdot
.51398 .18333 Mdot
.45095 .63494 Mdot
.4443 .66209 Mdot
.45289 .71169 Mdot
.4876 .61627 Mdot
.22131 .48947 Mdot
.64489 .51035 Mdot
.20581 .38411 Mdot
.52302 .5709 Mdot
.63912 .71908 Mdot
.43584 .6422 Mdot
.26108 .34627 Mdot
.48608 .63061 Mdot
.47227 .44158 Mdot
.44804 .64207 Mdot
.49388 .64865 Mdot
.61036 .3236 Mdot
.55815 .35346 Mdot
.62916 .5155 Mdot
.35344 .39296 Mdot
.73981 .70088 Mdot
.47482 .63326 Mdot
.50003 .35779 Mdot
.53092 .37287 Mdot
.26171 .53861 Mdot
.67676 .52687 Mdot
.14723 .56269 Mdot
.62018 .35138 Mdot
.31616 .38233 Mdot
.19857 .45125 Mdot
.48953 .37146 Mdot
.50513 .38239 Mdot
.59264 .5061 Mdot
.28599 .5514 Mdot
.44302 .64142 Mdot
.73355 .30601 Mdot
.42867 .21484 Mdot
.42903 .57183 Mdot
.57162 .32216 Mdot
.64484 .74385 Mdot
.78993 .39299 Mdot
.27924 .5624 Mdot
.30422 .5264 Mdot
.61673 .35684 Mdot
.34006 .36754 Mdot
.54693 .57019 Mdot
.28451 .54279 Mdot
.41712 .37177 Mdot
.39257 .41129 Mdot
.41174 .4319 Mdot
.68637 .5219 Mdot
.64196 .25056 Mdot
.69506 .41184 Mdot
.61277 .36504 Mdot
.24495 .57062 Mdot
.66852 .57493 Mdot
.65659 .56885 Mdot
.38229 .40399 Mdot
.39684 .37103 Mdot
.68027 .56382 Mdot
.54925 .6023 Mdot
.3976 .66881 Mdot
.4618 .62983 Mdot
.27166 .53129 Mdot
.48945 .62436 Mdot
.40725 .37895 Mdot
.59445 .35619 Mdot
.38704 .37008 Mdot
.61954 .34291 Mdot
.74848 .42968 Mdot
.51252 .60678 Mdot
.48913 .64862 Mdot
.30931 .71324 Mdot
.63874 .50482 Mdot
.70878 .29918 Mdot
.52267 .31205 Mdot
.37425 .37531 Mdot
.47939 .655 Mdot
.63525 .52478 Mdot
.25082 .55621 Mdot
.30427 .71124 Mdot
.52205 .6209 Mdot
.64297 .51211 Mdot
.4621 .58616 Mdot
.51025 .81469 Mdot
.38927 .20953 Mdot
.67059 .51765 Mdot
.15912 .49745 Mdot
.47899 .57415 Mdot
.56568 .52883 Mdot
.49791 .66301 Mdot
.3339 .59409 Mdot
.44084 .64784 Mdot
.67554 .56003 Mdot
.4653 .62466 Mdot
.65504 .56086 Mdot
.37361 .3595 Mdot
.57706 .38184 Mdot
.69003 .50717 Mdot
.52538 .59932 Mdot
.69328 .79939 Mdot
.59354 .33709 Mdot
.46393 .64595 Mdot
.60842 .3331 Mdot
.67084 .55577 Mdot
.70214 .52497 Mdot
.37075 .79188 Mdot
.54425 .39876 Mdot
.57383 .3447 Mdot
.46066 .59471 Mdot
.6628 .40185 Mdot
.4652 .59824 Mdot
.32761 .63926 Mdot
.5349 .6184 Mdot
.44216 .65104 Mdot
.36488 .80932 Mdot
.59323 .37664 Mdot
.24576 .30256 Mdot
.4045 .79027 Mdot
.58097 .83314 Mdot
.69835 .5647 Mdot
.27803 .56224 Mdot
.64059 .80498 Mdot
.51005 .35458 Mdot
.41769 .39245 Mdot
.49853 .59792 Mdot
.60727 .52748 Mdot
.58463 .37032 Mdot
.27224 .51949 Mdot
.45155 .63581 Mdot
.39933 .3708 Mdot
.30441 .38391 Mdot
.58858 .38771 Mdot
.68111 .52348 Mdot
.67905 .49917 Mdot
.1446 .50226 Mdot
.46943 .57204 Mdot
.48205 .65221 Mdot
.59967 .33772 Mdot
.44866 .54295 Mdot
.27551 .55463 Mdot
.27065 .36189 Mdot
.57497 .34369 Mdot
.542 .45603 Mdot
.6801 .54405 Mdot
.4896 .60633 Mdot
.65845 .45248 Mdot
.36351 .41577 Mdot
.70288 .6193 Mdot
.27843 .52907 Mdot
.32528 .64744 Mdot
.67643 .55991 Mdot
.59279 .34914 Mdot
.48547 .29964 Mdot
.46334 .68596 Mdot
.48382 .6094 Mdot
.32109 .64858 Mdot
.37577 .52203 Mdot
.20374 .59537 Mdot
.50726 .65351 Mdot
.38724 .51234 Mdot
.5041 .65147 Mdot
.46931 .68134 Mdot
.54586 .6116 Mdot
.48455 .63827 Mdot
.644 .5101 Mdot
.40866 .58908 Mdot
.42051 .39803 Mdot
.59096 .6526 Mdot
.52865 .41126 Mdot
.43907 .61906 Mdot
.47032 .58739 Mdot
.72032 .63836 Mdot
.55801 .39282 Mdot
.66464 .50376 Mdot
.70265 .48997 Mdot
.55596 .36525 Mdot
.3997 .66362 Mdot
.3512 .38785 Mdot
.40421 .61671 Mdot
.3934 .37272 Mdot
.63851 .51951 Mdot
.37064 .37353 Mdot
.5766 .38596 Mdot
.41834 .40829 Mdot
.51679 .32769 Mdot
.59308 .37306 Mdot
.69503 .53747 Mdot
.50125 .63302 Mdot
.57017 .32738 Mdot
.28723 .65884 Mdot
.27238 .53172 Mdot
.37353 .79442 Mdot
.47885 .56549 Mdot
.55469 .41519 Mdot
.39071 .5652 Mdot
.38762 .37125 Mdot
.33609 .24085 Mdot
.65889 .50087 Mdot
.25175 .51839 Mdot
.63808 .51865 Mdot
.5876 .19704 Mdot
.2642 .523 Mdot
.45939 .83192 Mdot
.5114 .2686 Mdot
.35422 .34754 Mdot
.54812 .59604 Mdot
.5163 .70227 Mdot
.46312 .38797 Mdot
.58662 .37061 Mdot
.49759 .26443 Mdot
.49892 .64598 Mdot
.36298 .25888 Mdot
.6291 .51277 Mdot
.38007 .40603 Mdot
.58538 .34945 Mdot
.56301 .33363 Mdot
.51864 .59488 Mdot
.23964 .41946 Mdot
.51337 .64034 Mdot
.47118 .27284 Mdot
.35226 .67661 Mdot
.4229 .69348 Mdot
.4609 .64833 Mdot
.36026 .37311 Mdot
.46144 .58724 Mdot
.39909 .68859 Mdot
.70699 .27352 Mdot
.517 .54699 Mdot
.55672 .27264 Mdot
.24978 .57068 Mdot
.67057 .53764 Mdot
.43041 .59699 Mdot
.49281 .36958 Mdot
.46832 .57551 Mdot
.65612 .18835 Mdot
.28906 .53076 Mdot
.47265 .3584 Mdot
.43492 .64848 Mdot
.51534 .58737 Mdot
.57249 .63224 Mdot
.60224 .53327 Mdot
.33138 .39122 Mdot
.47875 .61449 Mdot
.36563 .70773 Mdot
.59439 .32929 Mdot
.51701 .63621 Mdot
.46549 .64171 Mdot
.76464 .57684 Mdot
.56214 .35836 Mdot
.37924 .3694 Mdot
.44596 .41304 Mdot
.42859 .3694 Mdot
.30735 .51049 Mdot
.52279 .42618 Mdot
.267 .59545 Mdot
.40217 .2108 Mdot
.26416 .55703 Mdot
.49525 .56785 Mdot
.48446 .69789 Mdot
.49786 .57357 Mdot
.30256 .51747 Mdot
.56629 .36645 Mdot
.66783 .50236 Mdot
.66527 .32327 Mdot
.47315 .39326 Mdot
.48874 .66366 Mdot
.28227 .50979 Mdot
.69449 .5285 Mdot
.22962 .53398 Mdot
.67681 .53499 Mdot
.57546 .34954 Mdot
.55041 .34472 Mdot
.28441 .51464 Mdot
.63638 .53502 Mdot
.5404 .29959 Mdot
.38238 .77858 Mdot
.53602 .62099 Mdot
.58407 .29694 Mdot
.6341 .51668 Mdot
.61621 .53704 Mdot
.62481 .53712 Mdot
.51064 .6195 Mdot
.57568 .47154 Mdot
.4485 .67622 Mdot
.60922 .36467 Mdot
.42836 .3804 Mdot
.33791 .56684 Mdot
.78813 .44835 Mdot
.32926 .56273 Mdot
.47439 .55374 Mdot
.4585 .62545 Mdot
.46793 .64661 Mdot
.53906 .59777 Mdot
.46695 .2908 Mdot
.51213 .59769 Mdot
.61319 .32676 Mdot
.40026 .38195 Mdot
.43625 .62487 Mdot
.43696 .4116 Mdot
.6079 .46352 Mdot
.28412 .55745 Mdot
.51469 .42014 Mdot
.70376 .76883 Mdot
.69548 .52447 Mdot
.44276 .38571 Mdot
.41688 .39413 Mdot
.25861 .54844 Mdot
.5826 .36828 Mdot
.68145 .53833 Mdot
.34303 .5985 Mdot
.25598 .53688 Mdot
.46612 .62734 Mdot
.34612 .30113 Mdot
.33695 .2882 Mdot
.45014 .65183 Mdot
.49191 .58991 Mdot
.42001 .41747 Mdot
.34313 .367 Mdot
.81789 .37897 Mdot
.2276 .605 Mdot
.27798 .51571 Mdot
.29929 .54429 Mdot
.64049 .56301 Mdot
.42545 .64845 Mdot
.61099 .36129 Mdot
.25192 .64842 Mdot
.38634 .53433 Mdot
.28355 .68199 Mdot
.28452 .4846 Mdot
.52152 .60813 Mdot
.52688 .71928 Mdot
.45443 .62878 Mdot
.66239 .49719 Mdot
.6816 .55147 Mdot
.67951 .50742 Mdot
.59267 .36859 Mdot
.58626 .76598 Mdot
.60056 .32127 Mdot
.74181 .72681 Mdot
.67632 .56142 Mdot
.45248 .31721 Mdot
.36635 .3827 Mdot
.43476 .59267 Mdot
.27193 .55204 Mdot
.6186 .38 Mdot
.53304 .56007 Mdot
.28281 .29687 Mdot
.41118 .40677 Mdot
.69494 .53995 Mdot
.59163 .51004 Mdot
.80099 .60029 Mdot
.56136 .44092 Mdot
.56499 .55167 Mdot
.54997 .66882 Mdot
.2596 .53429 Mdot
.69654 .62007 Mdot
.3073 .51769 Mdot
.60357 .35452 Mdot
.49254 .64495 Mdot
.49362 .63836 Mdot
.4931 .65534 Mdot
.51173 .60054 Mdot
.55681 .36012 Mdot
.45559 .56137 Mdot
.53522 .16112 Mdot
.40717 .41436 Mdot
.53398 .81667 Mdot
.29417 .54024 Mdot
.58394 .31561 Mdot
.39927 .37981 Mdot
.3428 .39075 Mdot
.25591 .61705 Mdot
.44684 .63864 Mdot
.49975 .59631 Mdot
.32442 .38889 Mdot
.50185 .65657 Mdot
.51316 .53916 Mdot
.41655 .399 Mdot
.33255 .56078 Mdot
.25699 .55499 Mdot
.29991 .52353 Mdot
.56555 .36129 Mdot
.63634 .52824 Mdot
.27746 .53758 Mdot
.37326 .36055 Mdot
.47244 .56118 Mdot
.52405 .58777 Mdot
.63317 .5171 Mdot
.63747 .23226 Mdot
.28553 .56089 Mdot
.59024 .50553 Mdot
.65605 .55862 Mdot
.69689 .55849 Mdot
.48277 .60846 Mdot
.42461 .57411 Mdot
.62279 .56008 Mdot
.2516 .53996 Mdot
.57774 .31717 Mdot
.42854 .35236 Mdot
.60516 .34787 Mdot
.68825 .53693 Mdot
.53049 .59564 Mdot
.68906 .54194 Mdot
.45633 .58049 Mdot
.53199 .89254 Mdot
.48998 .63612 Mdot
.43861 .18782 Mdot
.3202 .60673 Mdot
.40964 .39462 Mdot
.53763 .30306 Mdot
.38245 .4051 Mdot
.66224 .56001 Mdot
.52893 .60318 Mdot
.30458 .53971 Mdot
.5307 .84818 Mdot
.66077 .57469 Mdot
.42101 .38474 Mdot
.34257 .37966 Mdot
.58779 .37524 Mdot
.43529 .62169 Mdot
.48763 .61012 Mdot
.39224 .4013 Mdot
.37516 .63941 Mdot
.64276 .5386 Mdot
.47641 .65186 Mdot
.46467 .6113 Mdot
.41033 .39671 Mdot
.37672 .77351 Mdot
.59155 .54492 Mdot
.48658 .64415 Mdot
.49256 .32398 Mdot
.61371 .32053 Mdot
.54396 .5943 Mdot
.45244 .56204 Mdot
.27382 .54725 Mdot
.58937 .80217 Mdot
.72252 .28636 Mdot
.62337 .33015 Mdot
.35725 .39403 Mdot
.47451 .56885 Mdot
.36788 .38506 Mdot
.52458 .59242 Mdot
.69957 .7253 Mdot
.39112 .4097 Mdot
.50526 .58324 Mdot
.42223 .63024 Mdot
.68777 .54855 Mdot
.51363 .59474 Mdot
.74006 .61805 Mdot
.45571 .38635 Mdot
.50995 .58744 Mdot
.49948 .75383 Mdot
.56586 .34476 Mdot
.42534 .61352 Mdot
.29971 .53634 Mdot
.34014 .58889 Mdot
.71882 .39735 Mdot
.49805 .34635 Mdot
.29909 .52707 Mdot
.51265 .63139 Mdot
.33495 .37092 Mdot
.61401 .36519 Mdot
.3558 .25695 Mdot
.47522 .65703 Mdot
.59892 .33947 Mdot
.59256 .35498 Mdot
.29461 .52786 Mdot
.1998 .35186 Mdot
.44908 .56743 Mdot
.4891 .61796 Mdot
.75236 .61163 Mdot
.68722 .49535 Mdot
.49223 .62658 Mdot
.50693 .57079 Mdot
.61272 .32855 Mdot
.59118 .5685 Mdot
.68341 .69988 Mdot
.24987 .38471 Mdot
.62545 .35305 Mdot
.43156 .36572 Mdot
.33301 .37239 Mdot
.29178 .54197 Mdot
.66529 .53264 Mdot
.31076 .54085 Mdot
.42958 .40079 Mdot
.49089 .56923 Mdot
.61709 .34562 Mdot
.73399 .57815 Mdot
.61107 .37365 Mdot
.49171 .35549 Mdot
.64654 .49821 Mdot
.68661 .34522 Mdot
.57676 .14874 Mdot
.70331 .41734 Mdot
.58602 .40139 Mdot
.2619 .53882 Mdot
.39896 .27702 Mdot
.4625 .61592 Mdot
.67129 .62272 Mdot
.50537 .63058 Mdot
.51398 .74328 Mdot
.43678 .38373 Mdot
.34206 .38764 Mdot
.49056 .64427 Mdot
.34287 .66613 Mdot
.60642 .37914 Mdot
.59465 .3755 Mdot
.50519 .58919 Mdot
.57705 .35881 Mdot
.48007 .62564 Mdot
.40043 .37461 Mdot
.27851 .26897 Mdot
.4584 .635 Mdot
.46619 .67551 Mdot
.63798 .38831 Mdot
.38996 .80634 Mdot
.52673 .2818 Mdot
.5312 .71218 Mdot
.80693 .57145 Mdot
.57768 .35854 Mdot
.41733 .6461 Mdot
.47092 .38463 Mdot
.42212 .41744 Mdot
.53992 .30097 Mdot
.49877 .62527 Mdot
.50216 .62068 Mdot
.47685 .65476 Mdot
.47664 .58662 Mdot
.67709 .62408 Mdot
.4338 .5553 Mdot
.55416 .73322 Mdot
.49965 .59372 Mdot
.47786 .72606 Mdot
.57248 .32699 Mdot
.65054 .48534 Mdot
.30977 .54584 Mdot
.52127 .60639 Mdot
.63917 .58097 Mdot
.60676 .31717 Mdot
.74416 .72412 Mdot
.57427 .37154 Mdot
.38207 .38198 Mdot
.5742 .37845 Mdot
.4453 .59633 Mdot
.66347 .52373 Mdot
.47644 .375 Mdot
.42137 .23928 Mdot
.41777 .3915 Mdot
.44204 .60002 Mdot
.46247 .35595 Mdot
.42055 .39384 Mdot
.61594 .45204 Mdot
.66022 .52696 Mdot
.35907 .70804 Mdot
.68175 .55175 Mdot
.5073 .58284 Mdot
.50182 .57971 Mdot
.55469 .29861 Mdot
.59081 .38424 Mdot
.6751 .55572 Mdot
.23298 .28632 Mdot
.3088 .51823 Mdot
.67891 .50952 Mdot
.49626 .6795 Mdot
.47981 .48517 Mdot
.65875 .51935 Mdot
.3628 .64 Mdot
.59196 .37127 Mdot
.66662 .56523 Mdot
.48852 .68293 Mdot
.56911 .22843 Mdot
.25227 .52181 Mdot
.35116 .37011 Mdot
.44741 .45144 Mdot
.45775 .38999 Mdot
.57109 .31869 Mdot
.40384 .40696 Mdot
.59147 .32759 Mdot
.70147 .29857 Mdot
.44355 .74217 Mdot
.613 .30922 Mdot
.5584 .33046 Mdot
.40911 .40383 Mdot
.46245 .65188 Mdot
.47255 .41944 Mdot
.52165 .64526 Mdot
.53815 .56938 Mdot
.58248 .32928 Mdot
.67994 .55799 Mdot
.70046 .54781 Mdot
.49014 .71894 Mdot
.67891 .49879 Mdot
.39434 .37187 Mdot
.39393 .20891 Mdot
.68292 .27265 Mdot
.59193 .33234 Mdot
.55401 .3462 Mdot
.46659 .59486 Mdot
.38155 .39432 Mdot
.36947 .358 Mdot
.60421 .36377 Mdot
.65102 .60782 Mdot
.43846 .66409 Mdot
.62422 .5138 Mdot
.6769 .56207 Mdot
.66651 .51548 Mdot
.62847 .54652 Mdot
.67813 .68665 Mdot
.59303 .37173 Mdot
.66963 .56138 Mdot
.50395 .58567 Mdot
.50078 .62148 Mdot
.49018 .37792 Mdot
.30054 .52588 Mdot
.46898 .5659 Mdot
.5474 .61692 Mdot
.48513 .60576 Mdot
.42897 .38841 Mdot
.51793 .67265 Mdot
.35471 .39471 Mdot
.35335 .36526 Mdot
.42637 .41215 Mdot
.50937 .35082 Mdot
.52473 .69087 Mdot
.81883 .56055 Mdot
.46466 .58806 Mdot
.44246 .54174 Mdot
.36854 .38275 Mdot
.31307 .26246 Mdot
.67453 .30461 Mdot
.47772 .65591 Mdot
.37733 .424 Mdot
.39269 .40249 Mdot
.69561 .50381 Mdot
.49637 .62883 Mdot
.4762 .39353 Mdot
.28155 .55732 Mdot
.50853 .67018 Mdot
.45982 .40671 Mdot
.6381 .54352 Mdot
.31963 .53872 Mdot
.65575 .56462 Mdot
.43491 .408 Mdot
.42267 .62623 Mdot
.88816 .5198 Mdot
.42573 .36873 Mdot
.46647 .81621 Mdot
.61555 .56877 Mdot
.47444 .65249 Mdot
.44458 .38503 Mdot
.68523 .49538 Mdot
.57833 .31502 Mdot
.43858 .48785 Mdot
.66871 .50044 Mdot
.34417 .38925 Mdot
.4623 .40387 Mdot
.41711 .39778 Mdot
.66851 .54446 Mdot
.52718 .62536 Mdot
.65699 .54567 Mdot
.57455 .37793 Mdot
.45288 .61757 Mdot
.77748 .65598 Mdot
.43788 .54684 Mdot
.66375 .55929 Mdot
.38803 .36584 Mdot
.27912 .5059 Mdot
.44772 .63033 Mdot
.45128 .80399 Mdot
.45031 .58063 Mdot
.60084 .33328 Mdot
.24306 .34563 Mdot
.73158 .58498 Mdot
.43599 .63788 Mdot
.46762 .59349 Mdot
.6032 .37232 Mdot
.44697 .63624 Mdot
.43885 .64211 Mdot
.52869 .37787 Mdot
.66972 .54911 Mdot
.46438 .6218 Mdot
.4003 .3657 Mdot
.73393 .31528 Mdot
.44341 .67046 Mdot
.32741 .42745 Mdot
.34902 .69165 Mdot
.225 .353 Mdot
.50477 .63481 Mdot
.24627 .62905 Mdot
.4826 .58621 Mdot
.51591 .6195 Mdot
.46156 .59779 Mdot
.544 .69805 Mdot
.41846 .40535 Mdot
.41045 .3838 Mdot
.25107 .52507 Mdot
.35373 .69594 Mdot
.27716 .54606 Mdot
.57894 .37106 Mdot
.29927 .43264 Mdot
.39482 .41034 Mdot
.63714 .54305 Mdot
.51277 .63649 Mdot
.45859 .38393 Mdot
.49249 .60579 Mdot
.44876 .59035 Mdot
.35816 .37241 Mdot
.36337 .35708 Mdot
.49335 .36157 Mdot
.29407 .54948 Mdot
.68305 .50589 Mdot
.52158 .5663 Mdot
.259 .52222 Mdot
.52676 .62394 Mdot
.26254 .58919 Mdot
.67688 .50484 Mdot
.66666 .54896 Mdot
.7073 .52438 Mdot
.48938 .56924 Mdot
.44081 .61317 Mdot
.59907 .32155 Mdot
.63486 .53456 Mdot
.56641 .35045 Mdot
.47741 .37714 Mdot
.30741 .4186 Mdot
.49891 .62508 Mdot
.57233 .51938 Mdot
.28064 .55001 Mdot
.38757 .37951 Mdot
.32003 .3959 Mdot
.25803 .51299 Mdot
.45046 .58229 Mdot
.3603 .37493 Mdot
.2973 .51574 Mdot
.61713 .60248 Mdot
.83426 .51517 Mdot
.28937 .50666 Mdot
.5028 .58684 Mdot
.58997 .59197 Mdot
.35725 .75225 Mdot
.30342 .50935 Mdot
.61184 .34019 Mdot
.48933 .56863 Mdot
.39703 .57034 Mdot
.29328 .55745 Mdot
.73187 .32285 Mdot
.40502 .3939 Mdot
.58894 .24656 Mdot
.55885 .60274 Mdot
.64054 .62588 Mdot
.31298 .53183 Mdot
.68186 .53474 Mdot
.67743 .48577 Mdot
.4796 .6014 Mdot
.31153 .51413 Mdot
.62304 .3596 Mdot
.40142 .39029 Mdot
.52089 .3232 Mdot
.66563 .54441 Mdot
.64569 .40233 Mdot
.41838 .37558 Mdot
.58356 .50679 Mdot
.25232 .36201 Mdot
.40296 .68206 Mdot
.48281 .74095 Mdot
.45512 .21022 Mdot
.50682 .56796 Mdot
.30125 .51259 Mdot
.60701 .31864 Mdot
.61809 .35285 Mdot
.57698 .34351 Mdot
.53498 .30592 Mdot
.54287 .42397 Mdot
.44622 .40317 Mdot
.39122 .25121 Mdot
.29195 .53556 Mdot
.38226 .72954 Mdot
.52502 .6234 Mdot
.45829 .62749 Mdot
.44728 .57781 Mdot
.51631 .64035 Mdot
.47782 .59313 Mdot
.57822 .36482 Mdot
.53564 .30333 Mdot
.38574 .33792 Mdot
.66247 .5095 Mdot
.32938 .55843 Mdot
.36623 .38238 Mdot
.41399 .41704 Mdot
.28274 .51881 Mdot
.60513 .48565 Mdot
.45322 .4023 Mdot
.37239 .3731 Mdot
.45655 .56901 Mdot
.64859 .54553 Mdot
.41334 .58782 Mdot
.49282 .57903 Mdot
.39145 .37785 Mdot
.34493 .4879 Mdot
.71236 .66722 Mdot
.43392 .6802 Mdot
.29895 .56275 Mdot
.56072 .4794 Mdot
.30298 .50969 Mdot
.49875 .66398 Mdot
.30075 .2723 Mdot
.42818 .40142 Mdot
.38338 .38833 Mdot
.295 .51178 Mdot
.57559 .5352 Mdot
.66139 .53722 Mdot
.33735 .38619 Mdot
.60441 .32913 Mdot
.50185 .57564 Mdot
.3087 .40159 Mdot
.55602 .5312 Mdot
.25827 .41142 Mdot
.5821 .33781 Mdot
.36457 .36229 Mdot
.43499 .62457 Mdot
.50072 .58704 Mdot
.26036 .53927 Mdot
.7653 .50387 Mdot
.52506 .65799 Mdot
.58455 .83258 Mdot
.52579 .1871 Mdot
.60013 .22813 Mdot
.48382 .60961 Mdot
.67133 .5475 Mdot
.443 .41314 Mdot
.25763 .52879 Mdot
.48497 .55434 Mdot
.82942 .5297 Mdot
.63967 .49752 Mdot
.59921 .35103 Mdot
.4814 .38872 Mdot
.55131 .42692 Mdot
.46715 .57117 Mdot
.5044 .63059 Mdot
.51127 .61233 Mdot
.83567 .43687 Mdot
.42286 .38188 Mdot
.65004 .49944 Mdot
.27801 .52697 Mdot
.67435 .49799 Mdot
.41147 .38865 Mdot
.66821 .3596 Mdot
.43955 .62811 Mdot
.63798 .50153 Mdot
.67919 .53291 Mdot
.58659 .375 Mdot
.5703 .31763 Mdot
.4321 .36135 Mdot
.48853 .63597 Mdot
.47059 .39835 Mdot
.68902 .549 Mdot
.32913 .38111 Mdot
.26268 .52488 Mdot
.58587 .32083 Mdot
.50091 .59438 Mdot
.42564 .39856 Mdot
.46402 .55433 Mdot
.65164 .52291 Mdot
.37177 .37376 Mdot
.49667 .36356 Mdot
.30006 .54197 Mdot
.50245 .60892 Mdot
.2818 .56676 Mdot
.35689 .39331 Mdot
.46335 .61233 Mdot
.60779 .4947 Mdot
.32293 .54599 Mdot
.43353 .24682 Mdot
.44846 .39881 Mdot
.50173 .36069 Mdot
.7059 .52666 Mdot
.7328 .33703 Mdot
.38623 .38759 Mdot
.61403 .4843 Mdot
.75983 .46415 Mdot
.52088 .56499 Mdot
.67794 .51941 Mdot
.37625 .28465 Mdot
.65531 .81189 Mdot
.40982 .77109 Mdot
.46439 .64516 Mdot
.44746 .38966 Mdot
.27983 .51133 Mdot
.5913 .33193 Mdot
.32677 .4257 Mdot
.40133 .68982 Mdot
.35832 .38601 Mdot
.46429 .59336 Mdot
.67715 .55171 Mdot
.59721 .36377 Mdot
.73737 .39295 Mdot
.37841 .36208 Mdot
.43827 .38682 Mdot
.43541 .62934 Mdot
.28294 .54102 Mdot
.45604 .7783 Mdot
.40702 .37712 Mdot
.31907 .37949 Mdot
.40511 .27321 Mdot
.28307 .50937 Mdot
.48875 .58701 Mdot
.48353 .71932 Mdot
.54045 .59521 Mdot
.48073 .82507 Mdot
.36913 .39951 Mdot
.65794 .51021 Mdot
.5093 .62787 Mdot
.23993 .39156 Mdot
.39334 .38172 Mdot
.58156 .46453 Mdot
.33337 .47545 Mdot
.59344 .37119 Mdot
.31408 .38662 Mdot
.49325 .61929 Mdot
.6078 .37804 Mdot
.2804 .54976 Mdot
.48401 .64229 Mdot
.44167 .61216 Mdot
.68631 .49756 Mdot
.6049 .35473 Mdot
.78746 .48286 Mdot
.56375 .3304 Mdot
.61922 .32767 Mdot
.712 .52766 Mdot
.4726 .61539 Mdot
.38007 .37922 Mdot
.38874 .40163 Mdot
.51362 .55886 Mdot
.3311 .23388 Mdot
.66057 .53924 Mdot
.2388 .56757 Mdot
.82362 .41392 Mdot
.44958 .69747 Mdot
.31793 .39583 Mdot
.76269 .50206 Mdot
.62233 .35973 Mdot
.50273 .59075 Mdot
.64981 .55358 Mdot
.32755 .37304 Mdot
.41702 .37419 Mdot
.5313 .60725 Mdot
.59224 .35913 Mdot
.26946 .55719 Mdot
.42465 .36966 Mdot
.24132 .4175 Mdot
.51487 .6073 Mdot
.37241 .25916 Mdot
.4382 .37983 Mdot
.55916 .85427 Mdot
.321 .34909 Mdot
.67542 .51636 Mdot
.44797 .59359 Mdot
.68194 .50037 Mdot
.27204 .52763 Mdot
.44161 .36868 Mdot
.59377 .35758 Mdot
.45718 .69945 Mdot
.64558 .19887 Mdot
.41168 .40525 Mdot
.64546 .50897 Mdot
.43552 .63733 Mdot
.52768 .67545 Mdot
.48785 .62265 Mdot
.58598 .58527 Mdot
.23469 .56288 Mdot
.57674 .33221 Mdot
.60461 .33511 Mdot
.45923 .61653 Mdot
.26297 .54964 Mdot
.36327 .36545 Mdot
.39944 .39028 Mdot
.29383 .79233 Mdot
.33107 .38438 Mdot
.34117 .64172 Mdot
.50249 .61674 Mdot
.33422 .37883 Mdot
.78899 .42456 Mdot
.59858 .33691 Mdot
.52146 .63628 Mdot
.34563 .38519 Mdot
.54563 .21002 Mdot
.31257 .57789 Mdot
.48081 .592 Mdot
.53803 .54837 Mdot
.60627 .3312 Mdot
.30787 .69222 Mdot
.43424 .407 Mdot
.53114 .62631 Mdot
.55668 .37204 Mdot
.2233 .3981 Mdot
.67907 .25349 Mdot
.68323 .50613 Mdot
.45791 .38136 Mdot
.57872 .36542 Mdot
.55702 .61363 Mdot
.29609 .53772 Mdot
.45941 .38697 Mdot
.42559 .38767 Mdot
.45593 .5996 Mdot
.44605 .57527 Mdot
.47031 .70819 Mdot
.64593 .51163 Mdot
.56572 .33431 Mdot
.49632 .6446 Mdot
.64067 .40474 Mdot
.49862 .65332 Mdot
.58635 .3228 Mdot
.88901 .59013 Mdot
.54609 .58456 Mdot
.48662 .62115 Mdot
.44902 .77883 Mdot
.67268 .50041 Mdot
.68517 .49944 Mdot
.46923 .18428 Mdot
.50248 .61601 Mdot
.30961 .36392 Mdot
.68705 .50649 Mdot
.65694 .53656 Mdot
.42726 .3171 Mdot
.45264 .63258 Mdot
.30092 .70493 Mdot
.61551 .35596 Mdot
.61893 .33382 Mdot
.65881 .5451 Mdot
.54184 .64064 Mdot
.62106 .35826 Mdot
.68644 .64255 Mdot
.38068 .39477 Mdot
.2895 .28077 Mdot
.64867 .5223 Mdot
.50016 .40322 Mdot
.58983 .33454 Mdot
.73783 .73132 Mdot
.37598 .42034 Mdot
.47003 .65332 Mdot
.50567 .60768 Mdot
.28488 .54892 Mdot
.52418 .56696 Mdot
.34788 .39216 Mdot
.57668 .35878 Mdot
.49005 .7881 Mdot
.6802 .50803 Mdot
.48505 .63248 Mdot
.59771 .48619 Mdot
.74055 .41542 Mdot
.52411 .26294 Mdot
.67087 .53692 Mdot
.68408 .52027 Mdot
.43861 .40325 Mdot
.43453 .38116 Mdot
.47519 .60681 Mdot
.60722 .36523 Mdot
.63529 .54263 Mdot
.58646 .32436 Mdot
.42935 .39978 Mdot
.3769 .37443 Mdot
.39196 .41017 Mdot
.5226 .64683 Mdot
.377 .3655 Mdot
.22665 .42677 Mdot
.65264 .39305 Mdot
.65448 .56857 Mdot
.69344 .23756 Mdot
.73729 .39084 Mdot
.38008 .56651 Mdot
.30513 .54136 Mdot
.35687 .39294 Mdot
.56022 .36572 Mdot
.46669 .59744 Mdot
.4963 .60044 Mdot
.47396 .3911 Mdot
.58864 .38094 Mdot
.27046 .52224 Mdot
.59194 .38205 Mdot
.29627 .52946 Mdot
.32429 .38239 Mdot
.43538 .61495 Mdot
.51887 .58343 Mdot
.57409 .35974 Mdot
.3723 .36941 Mdot
.40351 .38262 Mdot
.30421 .51142 Mdot
.37229 .53144 Mdot
.41996 .39759 Mdot
.64933 .52267 Mdot
.66484 .69164 Mdot
.45458 .40782 Mdot
.49475 .6279 Mdot
.25699 .59434 Mdot
.68064 .61358 Mdot
.53774 .60451 Mdot
.49656 .37119 Mdot
.18069 .57853 Mdot
.50899 .63653 Mdot
.16494 .54168 Mdot
.50272 .35986 Mdot
.66737 .49988 Mdot
.44569 .39 Mdot
.34603 .39263 Mdot
.55452 .54875 Mdot
.24062 .52333 Mdot
.49493 .55752 Mdot
.68592 .5033 Mdot
.68747 .49217 Mdot
.56802 .20443 Mdot
.46776 .81741 Mdot
.30703 .51999 Mdot
.28942 .5175 Mdot
.38946 .38973 Mdot
.31502 .76389 Mdot
.4555 .6844 Mdot
.27627 .51692 Mdot
.41926 .74213 Mdot
.46857 .58675 Mdot
.3159 .63727 Mdot
.37804 .42758 Mdot
.66797 .54632 Mdot
.50794 .70757 Mdot
.38927 .38496 Mdot
.65109 .5057 Mdot
.66092 .33747 Mdot
.47031 .56708 Mdot
.67618 .50545 Mdot
.59388 .32272 Mdot
.48097 .22407 Mdot
.70135 .52284 Mdot
.24954 .58976 Mdot
.60446 .36493 Mdot
.41843 .28259 Mdot
.3994 .72662 Mdot
.51613 .11537 Mdot
.58155 .36458 Mdot
.36168 .38314 Mdot
.3905 .40167 Mdot
.39877 .39154 Mdot
.65633 .50055 Mdot
.3649 .35953 Mdot
.64282 .51721 Mdot
.35457 .75895 Mdot
.37201 .5326 Mdot
.2836 .51427 Mdot
.54963 .40172 Mdot
.68252 .52764 Mdot
.36733 .22998 Mdot
.59582 .15909 Mdot
.50705 .59099 Mdot
.55722 .34086 Mdot
.29888 .51485 Mdot
.5113 .85911 Mdot
.27771 .54834 Mdot
.469 .38579 Mdot
.26215 .30241 Mdot
.47887 .63016 Mdot
.65258 .74505 Mdot
.30478 .53694 Mdot
.68005 .54171 Mdot
.46105 .61767 Mdot
.54381 .29795 Mdot
.28619 .5435 Mdot
.27383 .55716 Mdot
.471 .60627 Mdot
.69454 .54091 Mdot
.38127 .37607 Mdot
.56408 .37531 Mdot
.28636 .5009 Mdot
.51682 .52909 Mdot
.52413 .56976 Mdot
.48493 .56625 Mdot
.57921 .44746 Mdot
.39442 .68904 Mdot
.57851 .35911 Mdot
.36967 .74625 Mdot
.43289 .38074 Mdot
.38603 .29952 Mdot
.48157 .1857 Mdot
.52352 .38369 Mdot
.38244 .40456 Mdot
.36653 .39926 Mdot
.47765 .59644 Mdot
.3952 .69212 Mdot
.23305 .35808 Mdot
.60547 .40594 Mdot
.44892 .41012 Mdot
.40013 .38789 Mdot
.66901 .48498 Mdot
.57222 .20086 Mdot
.48715 .55195 Mdot
.62766 .33894 Mdot
.42586 .39558 Mdot
.70296 .72225 Mdot
.28394 .53709 Mdot
.33135 .25286 Mdot
.43663 .62811 Mdot
.48841 .64888 Mdot
.58171 .35009 Mdot
.60323 .32166 Mdot
.57239 .28837 Mdot
.54515 .19184 Mdot
.24904 .65874 Mdot
.75892 .38066 Mdot
.70551 .71484 Mdot
.65088 .48614 Mdot
.66584 .55918 Mdot
.5152 .34547 Mdot
.57751 .32051 Mdot
.51046 .63057 Mdot
.63683 .54456 Mdot
.50568 .25957 Mdot
.72691 .52101 Mdot
.32892 .64412 Mdot
.28035 .38829 Mdot
.45289 .5817 Mdot
.65316 .54996 Mdot
.66069 .503 Mdot
.63341 .54699 Mdot
.50413 .3604 Mdot
.47914 .61493 Mdot
.45481 .64457 Mdot
.5028 .64731 Mdot
.46472 .53774 Mdot
.51477 .59998 Mdot
.59059 .41059 Mdot
.54699 .45989 Mdot
.53677 .80024 Mdot
.54065 .61015 Mdot
.62142 .347 Mdot
.49491 .56391 Mdot
.2626 .55028 Mdot
.46345 .59663 Mdot
.33073 .63872 Mdot
.59455 .34212 Mdot
.58206 .54659 Mdot
.75321 .37205 Mdot
.43813 .62763 Mdot
.26255 .55714 Mdot
.38558 .58657 Mdot
.77737 .50799 Mdot
.34728 .54301 Mdot
.64909 .52395 Mdot
.37573 .39736 Mdot
.57388 .37613 Mdot
.3773 .38035 Mdot
.53514 .62727 Mdot
.49665 .37256 Mdot
.68609 .43706 Mdot
.49616 .4062 Mdot
.52164 .61735 Mdot
.46616 .69365 Mdot
.65157 .53068 Mdot
.3606 .37576 Mdot
.64685 .48241 Mdot
.50942 .62127 Mdot
.2757 .52998 Mdot
.28969 .54118 Mdot
.64444 .28808 Mdot
.74123 .69251 Mdot
.71932 .32202 Mdot
.57999 .35172 Mdot
.41133 .3782 Mdot
.31394 .53123 Mdot
.46664 .52683 Mdot
.61485 .31623 Mdot
.6013 .37397 Mdot
.60345 .35927 Mdot
.4907 .57168 Mdot
.35348 .39392 Mdot
.53209 .79307 Mdot
.34645 .39075 Mdot
.44012 .62233 Mdot
.42619 .38305 Mdot
.3779 .40536 Mdot
.2904 .54634 Mdot
.56552 .36203 Mdot
.43368 .39788 Mdot
.5089 .58304 Mdot
.69444 .51786 Mdot
.40463 .50311 Mdot
.31932 .59115 Mdot
.5093 .8269 Mdot
.52906 .82648 Mdot
.6965 .54692 Mdot
.71871 .73736 Mdot
.63024 .35714 Mdot
.64862 .60867 Mdot
.47514 .33621 Mdot
.53072 .59127 Mdot
.39768 .19579 Mdot
.44528 .40413 Mdot
.35886 .37583 Mdot
.48805 .58518 Mdot
.34926 .36131 Mdot
.48546 .62929 Mdot
.43634 .38927 Mdot
.33288 .55389 Mdot
.45302 .55888 Mdot
.36803 .36628 Mdot
.49732 .66765 Mdot
.44821 .62719 Mdot
.66713 .54759 Mdot
.44737 .38592 Mdot
.51705 .64531 Mdot
.42353 .84555 Mdot
.59248 .32015 Mdot
.49834 .36837 Mdot
.21415 .57405 Mdot
.5772 .3653 Mdot
.67505 .50945 Mdot
.53389 .56642 Mdot
.2696 .54872 Mdot
.68653 .53393 Mdot
.26193 .57766 Mdot
.30467 .53185 Mdot
.38859 .20869 Mdot
.64789 .53009 Mdot
.45689 .40606 Mdot
.29075 .54888 Mdot
.4349 .66641 Mdot
.4451 .37955 Mdot
.3976 .52306 Mdot
.36787 .39811 Mdot
.48849 .61022 Mdot
.53286 .30206 Mdot
.58499 .32027 Mdot
.46751 .64507 Mdot
.41047 .36321 Mdot
.51058 .34768 Mdot
.48247 .57324 Mdot
.4714 .59363 Mdot
.62796 .22986 Mdot
.32101 .28385 Mdot
.2603 .53261 Mdot
.66671 .49198 Mdot
.50421 .58545 Mdot
.29167 .55098 Mdot
.26513 .45831 Mdot
.50006 .56643 Mdot
.63339 .51056 Mdot
.40456 .64607 Mdot
.42337 .37126 Mdot
.56547 .35318 Mdot
.47117 .37741 Mdot
.28368 .55673 Mdot
.18345 .34597 Mdot
.39465 .41147 Mdot
.49469 .66581 Mdot
.52009 .63243 Mdot
.53074 .27293 Mdot
.65434 .50534 Mdot
.25292 .65929 Mdot
.50274 .60869 Mdot
.39854 .59237 Mdot
.48028 .64192 Mdot
.34468 .34124 Mdot
.66009 .53759 Mdot
.48871 .61684 Mdot
.5755 .50794 Mdot
.45153 .67225 Mdot
.27181 .55873 Mdot
.42396 .77346 Mdot
.51374 .56842 Mdot
.87922 .42176 Mdot
.32271 .39061 Mdot
.37008 .36551 Mdot
.545 .28661 Mdot
.21323 .67753 Mdot
.70892 .30564 Mdot
.64201 .51685 Mdot
.74246 .4819 Mdot
.37923 .37796 Mdot
.74847 .34408 Mdot
.70191 .76028 Mdot
.44757 .62427 Mdot
.46627 .57176 Mdot
.46901 .38577 Mdot
.33519 .3815 Mdot
.46604 .40236 Mdot
.54117 .6166 Mdot
.44346 .68097 Mdot
.3851 .36444 Mdot
.51512 .58716 Mdot
.40504 .61422 Mdot
.56125 .37203 Mdot
.69882 .53963 Mdot
.58426 .33182 Mdot
.57216 .37121 Mdot
.6238 .65602 Mdot
.54482 .1968 Mdot
.58449 .32282 Mdot
.62981 .35475 Mdot
.31844 .63118 Mdot
.47008 .71207 Mdot
.29749 .55395 Mdot
.64642 .792 Mdot
.39982 .3944 Mdot
.47719 .61703 Mdot
.69319 .55413 Mdot
.62417 .6335 Mdot
.35992 .4372 Mdot
.24061 .33545 Mdot
.51072 .62472 Mdot
.39349 .38486 Mdot
.50263 .3569 Mdot
.42121 .58298 Mdot
.39734 .30439 Mdot
.48427 .65171 Mdot
.4584 .384 Mdot
.63897 .73135 Mdot
.59642 .49977 Mdot
.36723 .28438 Mdot
.68381 .47772 Mdot
.49824 .63941 Mdot
.64935 .51752 Mdot
.5801 .33699 Mdot
.27268 .55383 Mdot
.26112 .53322 Mdot
.46651 .60798 Mdot
.39473 .6642 Mdot
.3922 .43082 Mdot
.44655 .6286 Mdot
.45595 .6052 Mdot
.50253 .35958 Mdot
.4553 .60807 Mdot
.51829 .63458 Mdot
.51096 .64365 Mdot
.45271 .66467 Mdot
.61993 .3293 Mdot
.59436 .49299 Mdot
.53055 .64081 Mdot
.41293 .59056 Mdot
.57037 .3835 Mdot
.75324 .47962 Mdot
.56369 .36359 Mdot
.77988 .6526 Mdot
.59811 .33157 Mdot
.26589 .52257 Mdot
.52301 .30764 Mdot
.41018 .68292 Mdot
.65116 .5613 Mdot
.59536 .31323 Mdot
.28632 .52446 Mdot
.5746 .35019 Mdot
.42365 .37928 Mdot
.79004 .34989 Mdot
.72654 .52509 Mdot
.23987 .63311 Mdot
.63704 .28448 Mdot
.38871 .2606 Mdot
.4253 .40707 Mdot
.6601 .54174 Mdot
.71245 .67311 Mdot
.50815 .64889 Mdot
.29504 .54652 Mdot
.47422 .6031 Mdot
.61917 .32645 Mdot
.3933 .38797 Mdot
.40702 .7761 Mdot
.26283 .54314 Mdot
.64256 .22346 Mdot
.40641 .3921 Mdot
.48278 .65766 Mdot
.62732 .33891 Mdot
.68165 .22501 Mdot
.58036 .33144 Mdot
.35764 .54803 Mdot
.62223 .52197 Mdot
.49542 .73528 Mdot
.67859 .52273 Mdot
.4179 .41954 Mdot
.84211 .41904 Mdot
.59977 .81955 Mdot
.69615 .52985 Mdot
.32964 .31355 Mdot
.46906 .57214 Mdot
.48789 .56542 Mdot
.58955 .52457 Mdot
.6455 .50062 Mdot
.51049 .59227 Mdot
.49616 .36481 Mdot
.66744 .38336 Mdot
.30376 .33733 Mdot
.37057 .39449 Mdot
.49077 .62486 Mdot
.56407 .37931 Mdot
.5948 .38118 Mdot
.35378 .39546 Mdot
.56113 .35902 Mdot
.45642 .64505 Mdot
.68083 .52594 Mdot
.47895 .40753 Mdot
.26829 .5381 Mdot
.42338 .82516 Mdot
.31423 .53836 Mdot
.38747 .40558 Mdot
.42268 .62834 Mdot
.37648 .37398 Mdot
.12289 .54319 Mdot
.46606 .65077 Mdot
.68055 .50389 Mdot
.47929 .5818 Mdot
.49276 .64215 Mdot
.47307 .56736 Mdot
.39534 .36649 Mdot
.20548 .60651 Mdot
.5136 .58526 Mdot
.59533 .35783 Mdot
.56247 .8107 Mdot
.49051 .5634 Mdot
.34001 .54311 Mdot
.36193 .69204 Mdot
.39419 .24789 Mdot
.66342 .5665 Mdot
.36193 .37262 Mdot
.68582 .51252 Mdot
.71348 .50078 Mdot
.67461 .50926 Mdot
.57806 .79321 Mdot
.6958 .68898 Mdot
.18433 .55678 Mdot
.50514 .75281 Mdot
.6042 .62749 Mdot
.65594 .49331 Mdot
.24251 .4783 Mdot
.65203 .55702 Mdot
.65288 .50881 Mdot
.67117 .85455 Mdot
.66433 .56157 Mdot
.49752 .62086 Mdot
.46332 .56227 Mdot
.71638 .41367 Mdot
.29687 .63399 Mdot
.45823 .61145 Mdot
.49701 .5834 Mdot
.27887 .55324 Mdot
.38682 .64068 Mdot
.49718 .37262 Mdot
.39785 .20817 Mdot
.76053 .422 Mdot
.47256 .60339 Mdot
.50471 .58391 Mdot
.4465 .67943 Mdot
.79145 .29674 Mdot
.64841 .63921 Mdot
.65765 .4908 Mdot
.53603 .65469 Mdot
.49612 .83816 Mdot
.45158 .64721 Mdot
.50791 .57065 Mdot
.45613 .58057 Mdot
.37999 .37874 Mdot
.63841 .49797 Mdot
.52984 .66071 Mdot
.40012 .22862 Mdot
.43719 .6173 Mdot
.53294 .39078 Mdot
.23175 .67056 Mdot
.49383 .61807 Mdot
.63227 .55296 Mdot
.46312 .58483 Mdot
.64619 .53204 Mdot
.67341 .55025 Mdot
.43096 .65319 Mdot
.65195 .76377 Mdot
.62588 .51967 Mdot
.43959 .61837 Mdot
.38301 .37017 Mdot
.62922 .81471 Mdot
.49083 .60909 Mdot
.25802 .5251 Mdot
.50443 .60927 Mdot
.25454 .5499 Mdot
.45052 .60962 Mdot
.34651 .39014 Mdot
.72215 .59601 Mdot
.3864 .39034 Mdot
.27276 .70057 Mdot
.33337 .37408 Mdot
.62547 .22782 Mdot
.6391 .50628 Mdot
.51376 .34123 Mdot
.2129 .34204 Mdot
.49606 .36939 Mdot
.57282 .48071 Mdot
.5194 .48305 Mdot
.60661 .36651 Mdot
.69409 .50463 Mdot
.3495 .72451 Mdot
.51719 .26587 Mdot
.51275 .29944 Mdot
.40459 .40979 Mdot
.22408 .3049 Mdot
.27171 .28097 Mdot
.50618 .57782 Mdot
.62185 .76881 Mdot
.56447 .73135 Mdot
.50313 .56743 Mdot
.54366 .57519 Mdot
.41499 .36295 Mdot
.52187 .62828 Mdot
.60638 .45026 Mdot
.40799 .40378 Mdot
.29057 .5248 Mdot
.65473 .51132 Mdot
.25108 .53378 Mdot
.51707 .27596 Mdot
.52241 .48612 Mdot
.4328 .39187 Mdot
.45675 .67103 Mdot
.48581 .58042 Mdot
.65646 .5469 Mdot
.61561 .50722 Mdot
.6878 .5481 Mdot
.29944 .51384 Mdot
.40768 .40184 Mdot
.65149 .62889 Mdot
.49492 .58873 Mdot
.67671 .53133 Mdot
.63953 .3005 Mdot
.50156 .58761 Mdot
.57074 .35188 Mdot
.44801 .5847 Mdot
.69789 .52545 Mdot
.45503 .60843 Mdot
.6824 .52501 Mdot
.3788 .3947 Mdot
.44906 .64732 Mdot
.48529 .58799 Mdot
.67922 .22815 Mdot
.26874 .52401 Mdot
.64245 .50398 Mdot
.46675 .44724 Mdot
.49732 .65546 Mdot
.45566 .26901 Mdot
.50287 .6346 Mdot
.73847 .51641 Mdot
.48619 .67026 Mdot
.50604 .35497 Mdot
.48363 .54926 Mdot
.4903 .61028 Mdot
.53387 .49995 Mdot
.56323 .75508 Mdot
.62681 .49301 Mdot
.62594 .34274 Mdot
.62831 .54517 Mdot
.30706 .40726 Mdot
.44996 .40668 Mdot
.37033 .35645 Mdot
.27409 .64395 Mdot
.42945 .64114 Mdot
.47851 .62844 Mdot
.55033 .3444 Mdot
.29398 .52159 Mdot
.67297 .53662 Mdot
.29469 .5279 Mdot
.44485 .19725 Mdot
.30284 .52034 Mdot
.34678 .39255 Mdot
.31388 .35266 Mdot
.6891 .62395 Mdot
.28008 .55288 Mdot
.69278 .54528 Mdot
.27428 .39277 Mdot
.5332 .60344 Mdot
.2279 .54181 Mdot
.27589 .53144 Mdot
.22319 .29653 Mdot
.52051 .62483 Mdot
.57845 .47384 Mdot
.572 .33226 Mdot
.29508 .5407 Mdot
.60657 .35094 Mdot
.46131 .609 Mdot
.43551 .25036 Mdot
.64141 .5128 Mdot
.59258 .38814 Mdot
.54989 .59915 Mdot
.29531 .51441 Mdot
.4248 .39336 Mdot
.53778 .37042 Mdot
.62083 .3503 Mdot
.78259 .53794 Mdot
.40599 .76783 Mdot
.40601 .40206 Mdot
.27016 .33542 Mdot
.61365 .34872 Mdot
.50973 .56945 Mdot
.39519 .61398 Mdot
.46809 .65331 Mdot
.54131 .29617 Mdot
.361 .37219 Mdot
.67367 .4067 Mdot
.48471 .57897 Mdot
.51331 .63178 Mdot
.6273 .56284 Mdot
.38975 .39863 Mdot
.66204 .52171 Mdot
.63655 .55274 Mdot
.37964 .39579 Mdot
.67415 .51754 Mdot
.30294 .53923 Mdot
.67754 .36815 Mdot
.61457 .34615 Mdot
.59453 .35412 Mdot
.39954 .38848 Mdot
.37621 .36369 Mdot
.37304 .37419 Mdot
.44736 .58565 Mdot
.66677 .53791 Mdot
.44921 .59495 Mdot
.47078 .56891 Mdot
.64081 .47776 Mdot
.68073 .56134 Mdot
.4618 .58051 Mdot
.38257 .28138 Mdot
.23802 .55604 Mdot
.38681 .36832 Mdot
.57797 .32643 Mdot
.78298 .40062 Mdot
.56338 .38649 Mdot
.49074 .62765 Mdot
.53951 .21276 Mdot
.69432 .53618 Mdot
.28197 .54875 Mdot
.25256 .55992 Mdot
.27023 .54666 Mdot
.55634 .32394 Mdot
.63293 .53125 Mdot
.39609 .20935 Mdot
.48743 .62666 Mdot
.58008 .44651 Mdot
.36091 .73472 Mdot
.45102 .20364 Mdot
.58133 .32383 Mdot
.50165 .5855 Mdot
.48416 .38413 Mdot
.72064 .64916 Mdot
.48442 .65014 Mdot
.52519 .63602 Mdot
.45022 .33363 Mdot
.40614 .63781 Mdot
.62377 .5202 Mdot
.54193 .18656 Mdot
.4698 .562 Mdot
.60451 .50584 Mdot
.31217 .78952 Mdot
.49206 .63385 Mdot
.51272 .61645 Mdot
.48922 .60024 Mdot
.4707 .5858 Mdot
.6284 .55003 Mdot
.31299 .68513 Mdot
.6263 .33336 Mdot
.55197 .44131 Mdot
.61631 .34759 Mdot
.45979 .3851 Mdot
.60034 .47156 Mdot
.70297 .51358 Mdot
.28379 .5494 Mdot
.77066 .57798 Mdot
.48559 .1754 Mdot
.43904 .40384 Mdot
.67825 .6591 Mdot
.26971 .53201 Mdot
.52454 .57368 Mdot
.24846 .53657 Mdot
.34038 .38331 Mdot
.59946 .36355 Mdot
.45148 .56333 Mdot
.67538 .55669 Mdot
.70044 .51954 Mdot
.50818 .59161 Mdot
.52503 .84672 Mdot
.56892 .35271 Mdot
.61683 .38996 Mdot
.48063 .57177 Mdot
.52646 .63516 Mdot
.66129 .51816 Mdot
.39698 .37588 Mdot
.20557 .44319 Mdot
.27986 .52014 Mdot
.47411 .66211 Mdot
.46733 .58898 Mdot
.53915 .19212 Mdot
.5757 .36927 Mdot
.41465 .4157 Mdot
.49168 .57246 Mdot
.63534 .27188 Mdot
.48932 .57273 Mdot
.42909 .5727 Mdot
.38305 .37295 Mdot
.49755 .67395 Mdot
.51707 .58371 Mdot
.56347 .61026 Mdot
.61124 .34987 Mdot
.67398 .50386 Mdot
.62898 .55971 Mdot
.48002 .39014 Mdot
.57152 .34997 Mdot
.46291 .58165 Mdot
.57357 .36635 Mdot
.50169 .56487 Mdot
.51504 .59247 Mdot
.5857 .32302 Mdot
.66258 .52136 Mdot
.72022 .45413 Mdot
.59541 .48731 Mdot
.47425 .58267 Mdot
.47532 .55424 Mdot
.28656 .64463 Mdot
.16283 .4615 Mdot
.50823 .62661 Mdot
.69889 .52228 Mdot
.49266 .58687 Mdot
.60227 .34424 Mdot
.30221 .52327 Mdot
.69601 .52041 Mdot
.40699 .38178 Mdot
.43048 .40794 Mdot
.751 .36774 Mdot
.36384 .3987 Mdot
.53406 .59062 Mdot
.72546 .55428 Mdot
.70418 .54847 Mdot
.35994 .80981 Mdot
.38139 .39764 Mdot
.28433 .55947 Mdot
.46865 .59826 Mdot
.57303 .2293 Mdot
.55319 .33577 Mdot
.87892 .40699 Mdot
.39042 .20974 Mdot
.31605 .5363 Mdot
.23035 .33873 Mdot
.47207 .39411 Mdot
.5228 .59844 Mdot
.27006 .55345 Mdot
.44505 .39854 Mdot
.52603 .5828 Mdot
.53387 .54607 Mdot
.23796 .64217 Mdot
.45215 .37515 Mdot
.56841 .36196 Mdot
.39836 .36161 Mdot
.24686 .52384 Mdot
.3466 .39212 Mdot
.70312 .52316 Mdot
.48703 .61415 Mdot
.48588 .69115 Mdot
.40283 .37771 Mdot
.34267 .38868 Mdot
.44966 .58552 Mdot
.68815 .50209 Mdot
.35526 .35862 Mdot
.46767 .61105 Mdot
.63194 .61114 Mdot
.68058 .47742 Mdot
.41323 .39949 Mdot
.51301 .63767 Mdot
.4528 .70777 Mdot
.40404 .38658 Mdot
.38943 .36807 Mdot
.51025 .59133 Mdot
.30114 .54262 Mdot
.43481 .62438 Mdot
.59594 .32922 Mdot
.20819 .62255 Mdot
.60167 .34671 Mdot
.30419 .42014 Mdot
.41715 .63827 Mdot
.42114 .26191 Mdot
.70488 .53228 Mdot
.24423 .5287 Mdot
.78858 .39734 Mdot
.5341 .62498 Mdot
.71427 .73486 Mdot
.50953 .40319 Mdot
.48326 .84745 Mdot
.83021 .47819 Mdot
.27942 .53286 Mdot
.57591 .34484 Mdot
.51226 .61585 Mdot
.55454 .34417 Mdot
.26047 .54409 Mdot
.37108 .75369 Mdot
.51447 .63786 Mdot
.65793 .53633 Mdot
.4393 .60934 Mdot
.64868 .52401 Mdot
.50302 .58959 Mdot
.40586 .62726 Mdot
.50429 .34034 Mdot
.3163 .57842 Mdot
.53184 .5947 Mdot
.78611 .34122 Mdot
.382 .44162 Mdot
.27673 .52598 Mdot
.44367 .60629 Mdot
.43813 .41175 Mdot
.59951 .3789 Mdot
.43062 .53308 Mdot
.379 .37616 Mdot
.5597 .34147 Mdot
.66735 .51318 Mdot
.37472 .39478 Mdot
.41366 .41287 Mdot
.54808 .63314 Mdot
.25744 .55147 Mdot
.59919 .36891 Mdot
.49235 .6127 Mdot
.51882 .62658 Mdot
.27429 .34646 Mdot
.34613 .44281 Mdot
.61737 .55366 Mdot
.63772 .20019 Mdot
.6603 .57088 Mdot
.27601 .518 Mdot
.37997 .37262 Mdot
.50576 .62812 Mdot
.46404 .64327 Mdot
.51652 .3335 Mdot
.64608 .50275 Mdot
.46259 .37879 Mdot
.64335 .65717 Mdot
.34928 .37623 Mdot
.33156 .67597 Mdot
.68624 .50482 Mdot
.32838 .67402 Mdot
.24683 .52523 Mdot
.72335 .70878 Mdot
.33866 .59915 Mdot
.56929 .33459 Mdot
.3345 .68034 Mdot
.68235 .54114 Mdot
.49876 .57757 Mdot
.45882 .4042 Mdot
.38375 .40702 Mdot
.65819 .51354 Mdot
.46621 .38704 Mdot
.29303 .54147 Mdot
.51516 .61328 Mdot
.3588 .2498 Mdot
.72174 .37768 Mdot
.40795 .37535 Mdot
.44517 .55665 Mdot
.60328 .35579 Mdot
.5206 .59919 Mdot
.25977 .52172 Mdot
.58844 .36593 Mdot
.32503 .39846 Mdot
.67001 .39197 Mdot
.46377 .60991 Mdot
.586 .21907 Mdot
.57405 .35835 Mdot
.2108 .38415 Mdot
.47193 .6116 Mdot
.61348 .34891 Mdot
.41689 .66838 Mdot
.44407 .21456 Mdot
.4895 .42742 Mdot
.69278 .77129 Mdot
.45637 .37406 Mdot
.46292 .39217 Mdot
.47837 .23247 Mdot
.49485 .29887 Mdot
.55485 .35197 Mdot
.34659 .39179 Mdot
.37513 .67269 Mdot
.60746 .3522 Mdot
.46647 .57104 Mdot
.49882 .63432 Mdot
.62345 .6498 Mdot
.51865 .42139 Mdot
.34076 .38938 Mdot
.6975 .30917 Mdot
.49749 .65477 Mdot
.5544 .60548 Mdot
.46444 .63848 Mdot
.68186 .48973 Mdot
.59007 .37114 Mdot
.71458 .26141 Mdot
.57173 .34465 Mdot
.32059 .26706 Mdot
.39863 .39372 Mdot
.3644 .36327 Mdot
.49343 .62156 Mdot
.38873 .26731 Mdot
.41013 .72216 Mdot
.45205 .64144 Mdot
.41512 .28087 Mdot
.4203 .77859 Mdot
.55109 .59836 Mdot
.62125 .52273 Mdot
.44104 .57314 Mdot
.70408 .50034 Mdot
.61738 .35388 Mdot
.28094 .539 Mdot
.24683 .51474 Mdot
.59829 .36809 Mdot
.47684 .62895 Mdot
.42632 .28448 Mdot
.48401 .6457 Mdot
.50086 .57477 Mdot
.32393 .25402 Mdot
.31488 .53098 Mdot
.36809 .37647 Mdot
.26094 .53721 Mdot
.65194 .50866 Mdot
.88238 .62591 Mdot
.29632 .52345 Mdot
.43116 .72477 Mdot
.30522 .71788 Mdot
.33187 .68014 Mdot
.69979 .51589 Mdot
.28 .50415 Mdot
.56641 .35209 Mdot
.53536 .86624 Mdot
.16025 .4831 Mdot
.585 .39547 Mdot
.46591 .6192 Mdot
.7034 .51047 Mdot
.69204 .54933 Mdot
.60412 .38606 Mdot
.67634 .54791 Mdot
.456 .69121 Mdot
.48605 .57644 Mdot
.55559 .34847 Mdot
.72117 .4008 Mdot
.62108 .35137 Mdot
.67001 .35375 Mdot
.44242 .6051 Mdot
.69092 .5089 Mdot
.43225 .59022 Mdot
.71529 .55276 Mdot
.41303 .41637 Mdot
.52064 .57043 Mdot
.29099 .54484 Mdot
.56396 .43253 Mdot
.40812 .39878 Mdot
.53819 .21492 Mdot
.65444 .54518 Mdot
.60505 .29412 Mdot
.66903 .54825 Mdot
.69227 .49859 Mdot
.57257 .37195 Mdot
.63704 .53234 Mdot
.51359 .6163 Mdot
.35272 .29836 Mdot
.64464 .5371 Mdot
.58678 .34493 Mdot
.27693 .54323 Mdot
.67065 .51904 Mdot
.41913 .36368 Mdot
.4769 .59035 Mdot
.43498 .38477 Mdot
.5044 .33211 Mdot
.68621 .49939 Mdot
.28798 .50499 Mdot
.35902 .3703 Mdot
.26013 .55175 Mdot
.40445 .7893 Mdot
.57968 .31922 Mdot
.24539 .33492 Mdot
.45948 .70604 Mdot
.67854 .55697 Mdot
.50364 .33621 Mdot
.50411 .62645 Mdot
.47502 .59067 Mdot
.25628 .51327 Mdot
.69158 .54996 Mdot
.59584 .8258 Mdot
.74577 .5127 Mdot
.67808 .3808 Mdot
.58799 .31544 Mdot
.66816 .24108 Mdot
.64294 .40458 Mdot
.30215 .74509 Mdot
.5337 .64705 Mdot
.47136 .39458 Mdot
.48145 .63509 Mdot
.79371 .41162 Mdot
.29717 .51413 Mdot
.20419 .47768 Mdot
.43544 .66162 Mdot
.36939 .38302 Mdot
.4816 .60075 Mdot
.44939 .50347 Mdot
.4291 .58495 Mdot
.30412 .54145 Mdot
.55625 .40818 Mdot
.64778 .55969 Mdot
.26809 .53597 Mdot
.41779 .40806 Mdot
.38335 .71367 Mdot
.52837 .59038 Mdot
.53717 .6268 Mdot
.34656 .37627 Mdot
.66057 .54037 Mdot
.4533 .38605 Mdot
.61458 .34673 Mdot
.28972 .53604 Mdot
.46818 .59459 Mdot
.46961 .67405 Mdot
.45737 .27065 Mdot
.59671 .37201 Mdot
.35231 .37145 Mdot
.57908 .33341 Mdot
.46691 .39841 Mdot
.46307 .55756 Mdot
.36465 .36212 Mdot
.52594 .60458 Mdot
.74489 .32058 Mdot
.31746 .26124 Mdot
.57755 .75649 Mdot
.36577 .38191 Mdot
.34419 .66825 Mdot
.59506 .34042 Mdot
.59425 .33109 Mdot
.50256 .72714 Mdot
.37959 .61552 Mdot
.29724 .37309 Mdot
.78694 .53715 Mdot
.61499 .3453 Mdot
.59867 .34884 Mdot
.44363 .39096 Mdot
.63858 .52969 Mdot
.70822 .51048 Mdot
.46842 .38979 Mdot
.24961 .59425 Mdot
.67304 .53649 Mdot
.69566 .7505 Mdot
.31006 .39427 Mdot
.55601 .61257 Mdot
.5554 .29502 Mdot
.28725 .54121 Mdot
.26457 .59312 Mdot
.46192 .50149 Mdot
.51319 .62771 Mdot
.5524 .19028 Mdot
.39405 .37815 Mdot
.28948 .67418 Mdot
.782 .64737 Mdot
.51504 .63887 Mdot
.47597 .6154 Mdot
.47252 .63436 Mdot
.31173 .52009 Mdot
.73499 .5674 Mdot
.51784 .62393 Mdot
.24185 .59183 Mdot
.49317 .65745 Mdot
.35469 .56678 Mdot
.26081 .534 Mdot
.57944 .60434 Mdot
.4787 .36091 Mdot
.40397 .21946 Mdot
.58184 .57003 Mdot
.6103 .34077 Mdot
.48383 .37504 Mdot
.61377 .35686 Mdot
.57187 .79057 Mdot
.33714 .60348 Mdot
.61687 .5277 Mdot
.51301 .62379 Mdot
.3917 .40635 Mdot
.69488 .54495 Mdot
.4805 .26094 Mdot
.73204 .81354 Mdot
.61376 .367 Mdot
.13197 .54566 Mdot
.58784 .33009 Mdot
.40495 .41381 Mdot
.66118 .51669 Mdot
.68535 .69682 Mdot
.58275 .44735 Mdot
.67367 .51944 Mdot
.69819 .44149 Mdot
.68464 .57087 Mdot
.34272 .67724 Mdot
.695 .55894 Mdot
.58891 .34229 Mdot
.54264 .35 Mdot
.55812 .59797 Mdot
.50119 .61967 Mdot
.51553 .48624 Mdot
.44027 .71778 Mdot
.50325 .62247 Mdot
.407 .40358 Mdot
.20442 .38419 Mdot
.47305 .38699 Mdot
.65084 .55343 Mdot
.62506 .35373 Mdot
.4772 .61221 Mdot
.47774 .57729 Mdot
.52273 .58279 Mdot
.65513 .20149 Mdot
.67853 .76133 Mdot
.51269 .58509 Mdot
.45918 .66015 Mdot
.37575 .39248 Mdot
.32893 .52916 Mdot
.80547 .44204 Mdot
.36612 .624 Mdot
.48504 .65363 Mdot
.26399 .53007 Mdot
.30498 .5497 Mdot
.52742 .58373 Mdot
.38069 .24786 Mdot
.34462 .30057 Mdot
.49237 .61218 Mdot
.36163 .57413 Mdot
.50994 .27793 Mdot
.35177 .39519 Mdot
.40297 .3799 Mdot
.63384 .55384 Mdot
.39304 .40808 Mdot
.33253 .37288 Mdot
.69529 .67612 Mdot
.49026 .37996 Mdot
.6276 .40151 Mdot
.29925 .51367 Mdot
.46872 .64605 Mdot
.66481 .57275 Mdot
.53008 .31174 Mdot
.60465 .36696 Mdot
.69087 .52416 Mdot
.60367 .37824 Mdot
.31801 .54171 Mdot
.25521 .64798 Mdot
.38354 .40753 Mdot
.61182 .33706 Mdot
.66961 .39069 Mdot
.26295 .53102 Mdot
.56168 .35368 Mdot
.42997 .2644 Mdot
.47903 .56463 Mdot
.70873 .70344 Mdot
.44462 .63264 Mdot
.52615 .85429 Mdot
.56255 .35479 Mdot
.50774 .356 Mdot
.48165 .62393 Mdot
.40546 .39154 Mdot
.41453 .65099 Mdot
.483 .65244 Mdot
.41307 .38376 Mdot
.50518 .57787 Mdot
.25461 .53067 Mdot
.70087 .49071 Mdot
.51602 .39268 Mdot
.38757 .16711 Mdot
.2549 .54658 Mdot
.47272 .26114 Mdot
.50922 .62608 Mdot
.40746 .7743 Mdot
.67108 .52048 Mdot
.5225 .63563 Mdot
.53898 .68657 Mdot
.64243 .52334 Mdot
.68685 .51585 Mdot
.45591 .5976 Mdot
.56966 .33626 Mdot
.41052 .39472 Mdot
.26232 .53576 Mdot
.35558 .79283 Mdot
.45938 .62689 Mdot
.48857 .58727 Mdot
.26906 .53347 Mdot
.60059 .34799 Mdot
.47337 .57917 Mdot
.58524 .25922 Mdot
.43869 .84579 Mdot
.59623 .37568 Mdot
.45108 .57466 Mdot
.75705 .62164 Mdot
.7154 .55753 Mdot
.14138 .50934 Mdot
.28051 .57468 Mdot
.36437 .37052 Mdot
.40661 .64325 Mdot
.89338 .50223 Mdot
.28118 .54053 Mdot
.39925 .21457 Mdot
.5054 .57406 Mdot
.49366 .59269 Mdot
.69099 .54213 Mdot
.45425 .58793 Mdot
.65002 .50373 Mdot
.335 .20027 Mdot
.57934 .18518 Mdot
.65288 .53882 Mdot
.66908 .55975 Mdot
.47773 .7218 Mdot
.80355 .43618 Mdot
.6614 .51033 Mdot
.43843 .5922 Mdot
.60501 .80609 Mdot
.56332 .59348 Mdot
.25596 .513 Mdot
.49896 .32489 Mdot
.59311 .55756 Mdot
.35914 .4869 Mdot
.75579 .49298 Mdot
.58452 .54994 Mdot
.39301 .42334 Mdot
.59658 .32742 Mdot
.50491 .64829 Mdot
.3721 .40274 Mdot
.36791 .35771 Mdot
.42146 .59553 Mdot
.47658 .64885 Mdot
.64616 .52811 Mdot
.31113 .52657 Mdot
.57842 .37922 Mdot
.49608 .58335 Mdot
.42382 .3638 Mdot
.28855 .52103 Mdot
.64942 .55019 Mdot
.48727 .73199 Mdot
.29488 .55348 Mdot
.45058 .55771 Mdot
.50333 .60438 Mdot
.45317 .58163 Mdot
.45265 .69939 Mdot
.60379 .32073 Mdot
.53827 .28568 Mdot
.43786 .60187 Mdot
.45083 .19472 Mdot
.37143 .52783 Mdot
.48469 .67785 Mdot
.67433 .54198 Mdot
.55667 .32764 Mdot
.4256 .41629 Mdot
.38362 .73136 Mdot
.46065 .61765 Mdot
.67176 .76445 Mdot
.64446 .64531 Mdot
.43242 .41233 Mdot
.65279 .49479 Mdot
.27923 .54896 Mdot
.45708 .64483 Mdot
.58743 .79977 Mdot
.49593 .63286 Mdot
.44549 .70326 Mdot
.38721 .37068 Mdot
.59614 .32623 Mdot
.47207 .84922 Mdot
.36792 .35793 Mdot
.68635 .51345 Mdot
.70602 .76601 Mdot
.70956 .52896 Mdot
.63984 .55232 Mdot
.63484 .77596 Mdot
.6084 .32375 Mdot
.89266 .48462 Mdot
.15514 .48713 Mdot
.45064 .67659 Mdot
.59786 .33851 Mdot
.65389 .52177 Mdot
.52043 .60026 Mdot
.69482 .55524 Mdot
.63541 .52042 Mdot
.51312 .5622 Mdot
.5006 .59716 Mdot
.59351 .48428 Mdot
.74637 .6977 Mdot
.27256 .54889 Mdot
.67258 .50024 Mdot
.59305 .64346 Mdot
.52218 .61439 Mdot
.48752 .62594 Mdot
.50195 .2648 Mdot
.30012 .5453 Mdot
.53884 .50542 Mdot
.49562 .57293 Mdot
.59309 .20257 Mdot
.45011 .56037 Mdot
.62389 .54518 Mdot
.59382 .37574 Mdot
.38317 .24018 Mdot
.54204 .29646 Mdot
.64827 .50103 Mdot
.27248 .51236 Mdot
.62391 .55693 Mdot
.43436 .72411 Mdot
.61787 .33686 Mdot
.69789 .52552 Mdot
.47243 .37813 Mdot
.58677 .36001 Mdot
.56241 .35235 Mdot
.56549 .81055 Mdot
.35604 .38091 Mdot
.28634 .50763 Mdot
.60235 .36241 Mdot
.64901 .60766 Mdot
.58198 .34313 Mdot
.59882 .65256 Mdot
.44469 .64221 Mdot
.23887 .61359 Mdot
.62769 .41739 Mdot
.42527 .69054 Mdot
.59547 .31807 Mdot
.26153 .54415 Mdot
.46158 .59229 Mdot
.67894 .5477 Mdot
.29639 .52654 Mdot
.53218 .34365 Mdot
.3832 .36542 Mdot
.66577 .55009 Mdot
.62584 .3307 Mdot
.67646 .50153 Mdot
.33617 .71503 Mdot
.21856 .63748 Mdot
.58797 .25214 Mdot
.57731 .45184 Mdot
.5206 .58053 Mdot
.777 .48602 Mdot
.51928 .56215 Mdot
.48147 .64936 Mdot
.41267 .39912 Mdot
.27314 .64471 Mdot
.66183 .5212 Mdot
.47583 .85268 Mdot
.60826 .33253 Mdot
.5534 .18399 Mdot
.68461 .47381 Mdot
.52056 .64143 Mdot
.64385 .53257 Mdot
.70798 .53837 Mdot
.55696 .75694 Mdot
.3276 .37165 Mdot
.53136 .5486 Mdot
.51216 .5548 Mdot
.53018 .6479 Mdot
.56319 .35306 Mdot
.52251 .21662 Mdot
.46092 .38816 Mdot
.17971 .59821 Mdot
.39269 .37085 Mdot
.41285 .32127 Mdot
.63734 .539 Mdot
.30132 .52856 Mdot
.48869 .62349 Mdot
.6984 .4766 Mdot
.65326 .49684 Mdot
.27159 .56791 Mdot
.29312 .54528 Mdot
.48001 .21834 Mdot
.58694 .32229 Mdot
.53166 .60162 Mdot
.51395 .63564 Mdot
.44759 .6004 Mdot
.44108 .63041 Mdot
.61383 .36758 Mdot
.47932 .56901 Mdot
.55926 .37589 Mdot
.64436 .61382 Mdot
.56992 .18812 Mdot
.48371 .37848 Mdot
.40524 .55722 Mdot
.66801 .55558 Mdot
.65204 .60149 Mdot
.46577 .54589 Mdot
.29572 .27725 Mdot
.4639 .80785 Mdot
.5439 .58479 Mdot
.44879 .39428 Mdot
.38399 .61167 Mdot
.34653 .38517 Mdot
.1175 .42936 Mdot
.45823 .28147 Mdot
.70311 .75563 Mdot
.51988 .61067 Mdot
.505 .26555 Mdot
.42912 .56365 Mdot
.508 .55783 Mdot
.4819 .28543 Mdot
.68013 .28706 Mdot
.70551 .42311 Mdot
.30162 .55142 Mdot
.47353 .59737 Mdot
.70277 .55348 Mdot
.51483 .61664 Mdot
.4861 .63096 Mdot
.50903 .57382 Mdot
.62891 .34062 Mdot
.45115 .56452 Mdot
.44778 .58351 Mdot
.36818 .46182 Mdot
.32083 .63958 Mdot
.40687 .36451 Mdot
.47308 .74315 Mdot
.29411 .5231 Mdot
.64773 .53974 Mdot
.65901 .4528 Mdot
.56974 .3337 Mdot
.55701 .74506 Mdot
.44228 .59702 Mdot
.64405 .41402 Mdot
.625 .32856 Mdot
.292 .53646 Mdot
.45851 .40668 Mdot
.64789 .80768 Mdot
.38537 .40442 Mdot
.48734 .38329 Mdot
.40451 .398 Mdot
.60152 .58009 Mdot
.64621 .52591 Mdot
.51884 .57577 Mdot
.60181 .35911 Mdot
.41614 .39372 Mdot
.28736 .63341 Mdot
.46634 .63857 Mdot
.37975 .39409 Mdot
.51651 .57477 Mdot
.23932 .63043 Mdot
.25255 .36377 Mdot
.33346 .37631 Mdot
.56673 .31472 Mdot
.58638 .35479 Mdot
.3036 .53604 Mdot
.65157 .54752 Mdot
.69028 .5399 Mdot
.58654 .36475 Mdot
.161 .43663 Mdot
.48758 .65224 Mdot
.52114 .60525 Mdot
.45538 .19236 Mdot
.50829 .61562 Mdot
.37246 .70268 Mdot
.48544 .38638 Mdot
.65733 .55372 Mdot
.51874 .59239 Mdot
.473 .58152 Mdot
.46624 .60404 Mdot
.33067 .71434 Mdot
.40015 .37472 Mdot
.48321 .65647 Mdot
.28561 .55334 Mdot
.41928 .42008 Mdot
.52228 .60512 Mdot
.53038 .64654 Mdot
.69109 .53751 Mdot
.55408 .1714 Mdot
.58544 .32749 Mdot
.42421 .40602 Mdot
.36147 .36705 Mdot
.5007 .32108 Mdot
.61602 .49345 Mdot
.48449 .3869 Mdot
.19923 .62595 Mdot
.50244 .36216 Mdot
.27104 .52749 Mdot
.44405 .35318 Mdot
.35035 .51141 Mdot
.43812 .39993 Mdot
.60455 .38061 Mdot
.43616 .62162 Mdot
.47322 .65614 Mdot
.38105 .21382 Mdot
.51907 .64491 Mdot
.28258 .54637 Mdot
.56627 .38212 Mdot
.68244 .53918 Mdot
.29188 .53937 Mdot
.58857 .33158 Mdot
.66283 .54155 Mdot
.48614 .56261 Mdot
.46864 .56617 Mdot
.68876 .5221 Mdot
.69336 .54552 Mdot
.49633 .61075 Mdot
.37701 .41436 Mdot
.63759 .55544 Mdot
.6955 .51426 Mdot
.37614 .40515 Mdot
.40232 .40959 Mdot
.52544 .66301 Mdot
.5932 .33576 Mdot
.46256 .57517 Mdot
.36848 .39687 Mdot
.3078 .52563 Mdot
.66661 .52381 Mdot
.47701 .58001 Mdot
.49463 .58002 Mdot
.26349 .53456 Mdot
.31095 .53833 Mdot
.29472 .53881 Mdot
.56309 .38266 Mdot
.44524 .61761 Mdot
.66593 .51025 Mdot
.59563 .32208 Mdot
.30451 .55027 Mdot
.25296 .55199 Mdot
.4293 .47334 Mdot
.5065 .62988 Mdot
.47761 .43182 Mdot
.87974 .62105 Mdot
.37362 .6834 Mdot
.42002 .41682 Mdot
.35023 .3794 Mdot
.30942 .66078 Mdot
.33157 .31779 Mdot
.57248 .36023 Mdot
.38711 .68817 Mdot
.24396 .52814 Mdot
.51413 .56883 Mdot
.47193 .55499 Mdot
.54242 .57216 Mdot
.28945 .52865 Mdot
.35391 .72057 Mdot
.70308 .53968 Mdot
.55825 .70639 Mdot
.29412 .52383 Mdot
.33174 .37696 Mdot
.35539 .3636 Mdot
.39177 .37054 Mdot
.46312 .55987 Mdot
.57674 .74951 Mdot
.61889 .6074 Mdot
.78547 .49957 Mdot
.56808 .33094 Mdot
.6169 .52268 Mdot
.40242 .78353 Mdot
.68643 .51807 Mdot
.36186 .35855 Mdot
.28773 .52481 Mdot
.69952 .52864 Mdot
.6089 .36755 Mdot
.59892 .35085 Mdot
.40068 .373 Mdot
.39825 .38883 Mdot
.43283 .38498 Mdot
.63165 .54032 Mdot
.63713 .53431 Mdot
.45692 .62427 Mdot
.67694 .52709 Mdot
.47038 .16568 Mdot
.31489 .52268 Mdot
.35353 .36302 Mdot
.57623 .3427 Mdot
.64835 .52695 Mdot
.46341 .63976 Mdot
.38592 .34227 Mdot
.74436 .36754 Mdot
.25695 .54642 Mdot
.26523 .34928 Mdot
.11833 .44888 Mdot
.52873 .61411 Mdot
.56928 .36394 Mdot
.3468 .26076 Mdot
.46996 .63376 Mdot
.38341 .37798 Mdot
.76496 .34514 Mdot
.4492 .40728 Mdot
.46732 .57127 Mdot
.52196 .6421 Mdot
.56197 .36197 Mdot
.3072 .72305 Mdot
.45514 .62926 Mdot
.65955 .33151 Mdot
.62354 .36048 Mdot
.43667 .37557 Mdot
.44548 .85163 Mdot
.52703 .27809 Mdot
.26313 .595 Mdot
.39537 .4102 Mdot
.49471 .64095 Mdot
.4171 .40426 Mdot
.25956 .54828 Mdot
.42637 .39787 Mdot
.63026 .50695 Mdot
.42535 .37237 Mdot
.4885 .58834 Mdot
.66178 .50889 Mdot
.57306 .35722 Mdot
.53276 .18183 Mdot
.35357 .45744 Mdot
.40481 .39105 Mdot
.3885 .41035 Mdot
.51955 .58706 Mdot
.56802 .50432 Mdot
.42343 .65675 Mdot
.52099 .61277 Mdot
.61768 .34932 Mdot
.64366 .53745 Mdot
.60718 .3181 Mdot
.48519 .6661 Mdot
.66625 .2634 Mdot
.57657 .3334 Mdot
.63547 .42644 Mdot
.26967 .53112 Mdot
.45235 .48803 Mdot
.46431 .64492 Mdot
.60548 .36019 Mdot
.44466 .61714 Mdot
.68994 .55867 Mdot
.50665 .44606 Mdot
.56195 .27474 Mdot
.60031 .35854 Mdot
.57231 .83557 Mdot
.45647 .44903 Mdot
.43442 .58969 Mdot
.61406 .35151 Mdot
.54909 .67688 Mdot
.40949 .41352 Mdot
.27712 .5213 Mdot
.30444 .54988 Mdot
.26425 .55524 Mdot
.54245 .60969 Mdot
.53166 .54289 Mdot
.26854 .51166 Mdot
.59522 .37765 Mdot
.30576 .53975 Mdot
.67096 .46558 Mdot
.58467 .83228 Mdot
.2909 .51281 Mdot
.46991 .61168 Mdot
.55731 .58874 Mdot
.31643 .63786 Mdot
.3507 .3607 Mdot
.71967 .73051 Mdot
.4235 .55219 Mdot
.49976 .62256 Mdot
.55082 .53866 Mdot
.70192 .53847 Mdot
.33507 .27617 Mdot
.43795 .71515 Mdot
.31631 .32295 Mdot
.65919 .56082 Mdot
.51784 .33248 Mdot
.65354 .55085 Mdot
.52861 .60681 Mdot
.51587 .59547 Mdot
.71213 .51421 Mdot
.54488 .20642 Mdot
.44195 .24546 Mdot
.42904 .82565 Mdot
.69588 .51258 Mdot
.6111 .3504 Mdot
.61606 .36529 Mdot
.56994 .33001 Mdot
.30826 .40108 Mdot
.67529 .498 Mdot
.44962 .61747 Mdot
.37386 .39183 Mdot
.49658 .64989 Mdot
.59455 .36284 Mdot
.48202 .85236 Mdot
.68808 .53881 Mdot
.49067 .61096 Mdot
.16466 .47392 Mdot
.38857 .38625 Mdot
.26597 .52503 Mdot
.25133 .6499 Mdot
.31468 .38452 Mdot
.61774 .33061 Mdot
.71209 .52125 Mdot
.52637 .38515 Mdot
.62704 .44032 Mdot
.53323 .65121 Mdot
.48029 .68507 Mdot
.32011 .76796 Mdot
.32944 .40514 Mdot
.52785 .5789 Mdot
.42443 .40825 Mdot
.51653 .33279 Mdot
.4779 .5825 Mdot
.70185 .51721 Mdot
.27947 .5627 Mdot
.28898 .55292 Mdot
.50534 .54636 Mdot
.57717 .44631 Mdot
.43618 .48956 Mdot
.46508 .57909 Mdot
.45461 .55399 Mdot
.35712 .36791 Mdot
.5011 .36512 Mdot
.50447 .18183 Mdot
.28065 .51072 Mdot
.49982 .57186 Mdot
.73512 .44205 Mdot
.6373 .51935 Mdot
.43309 .37923 Mdot
.61971 .33793 Mdot
.34991 .73056 Mdot
.44885 .38174 Mdot
.47936 .5809 Mdot
.47341 .57955 Mdot
.5614 .35387 Mdot
.62365 .54486 Mdot
.28766 .52753 Mdot
.36286 .37827 Mdot
.27786 .51068 Mdot
.64664 .5107 Mdot
.68625 .53731 Mdot
.56391 .59013 Mdot
.46345 .55162 Mdot
.40515 .38156 Mdot
.49542 .662 Mdot
.34035 .36688 Mdot
.29955 .72026 Mdot
.59618 .31318 Mdot
.52769 .61971 Mdot
.65582 .48706 Mdot
.59958 .3646 Mdot
.4945 .59708 Mdot
.31618 .77633 Mdot
.51675 .6416 Mdot
.5357 .30655 Mdot
.65166 .25275 Mdot
.27491 .55244 Mdot
.48462 .75895 Mdot
.55644 .52717 Mdot
.509 .61146 Mdot
.38204 .3625 Mdot
.41592 .65095 Mdot
.56692 .34324 Mdot
.64385 .54983 Mdot
.13663 .48939 Mdot
.58273 .3455 Mdot
.51731 .61051 Mdot
.2906 .53613 Mdot
.71062 .53033 Mdot
.4876 .37505 Mdot
.43256 .20531 Mdot
.41581 .61871 Mdot
.43483 .60122 Mdot
.46824 .57199 Mdot
.81158 .41965 Mdot
.42624 .40458 Mdot
.65101 .52373 Mdot
.56361 .35345 Mdot
.58522 .36638 Mdot
.39441 .37327 Mdot
.69557 .41242 Mdot
.45636 .48402 Mdot
.8901 .54654 Mdot
.41652 .38613 Mdot
.29017 .50457 Mdot
.59635 .46493 Mdot
.38724 .36164 Mdot
.38229 .3942 Mdot
.35711 .37104 Mdot
.61144 .40889 Mdot
.66556 .53996 Mdot
.49701 .57931 Mdot
.66186 .56656 Mdot
.49653 .64165 Mdot
.38355 .52691 Mdot
.59989 .36665 Mdot
.64398 .55147 Mdot
.3248 .77743 Mdot
.73326 .53546 Mdot
.47034 .62506 Mdot
.38457 .78241 Mdot
.42556 .65383 Mdot
.34712 .69815 Mdot
.42713 .64341 Mdot
.40186 .39413 Mdot
.39828 .60667 Mdot
.5108 .65948 Mdot
.5055 .17086 Mdot
.57741 .34063 Mdot
.40682 .41472 Mdot
.53938 .59382 Mdot
.45103 .559 Mdot
.71755 .53225 Mdot
.6999 .52525 Mdot
.27645 .50951 Mdot
.30839 .57867 Mdot
.57135 .35359 Mdot
.22176 .63397 Mdot
.50143 .6154 Mdot
.59411 .23532 Mdot
.50899 .74843 Mdot
.49345 .59852 Mdot
.61653 .80153 Mdot
.56812 .74774 Mdot
.46052 .64598 Mdot
.56273 .65706 Mdot
.59797 .34587 Mdot
.65241 .25939 Mdot
.44567 .65486 Mdot
.38114 .37849 Mdot
.63877 .53801 Mdot
.7065 .52563 Mdot
.25775 .52236 Mdot
.30051 .25445 Mdot
.59214 .31723 Mdot
.64023 .54751 Mdot
.47139 .64032 Mdot
.61332 .32626 Mdot
.36218 .39752 Mdot
.47473 .67054 Mdot
.39711 .70811 Mdot
.67822 .52994 Mdot
.46074 .66112 Mdot
.70338 .33216 Mdot
.28207 .58887 Mdot
.82415 .59648 Mdot
.5703 .33067 Mdot
.29977 .522 Mdot
.44497 .67895 Mdot
.19855 .60122 Mdot
.54845 .59388 Mdot
.24507 .62081 Mdot
.62574 .48434 Mdot
.30224 .52473 Mdot
.47713 .62138 Mdot
.46199 .60582 Mdot
.59632 .45135 Mdot
.3127 .53194 Mdot
.51129 .64131 Mdot
.41817 .56473 Mdot
.65998 .53906 Mdot
.44752 .413 Mdot
.67697 .53413 Mdot
.46646 .61868 Mdot
.54084 .54773 Mdot
.69234 .54255 Mdot
.21094 .64829 Mdot
.24192 .52181 Mdot
.58386 .32704 Mdot
.49272 .54111 Mdot
.43999 .63708 Mdot
.81564 .3783 Mdot
.41268 .41625 Mdot
.79238 .45214 Mdot
.4433 .37442 Mdot
.73062 .45281 Mdot
.52818 .27401 Mdot
.69294 .77679 Mdot
.54619 .19115 Mdot
.51012 .55483 Mdot
.38694 .556 Mdot
.58749 .6217 Mdot
.6092 .32025 Mdot
.70697 .61749 Mdot
.50124 .62029 Mdot
.48445 .63327 Mdot
.44274 .38565 Mdot
.6707 .40964 Mdot
.37552 .25155 Mdot
.55454 .43864 Mdot
.28346 .52831 Mdot
.6579 .50439 Mdot
.50352 .58824 Mdot
.38765 .50398 Mdot
.41835 .36987 Mdot
.58175 .23303 Mdot
.48575 .61469 Mdot
.28842 .28833 Mdot
.58186 .40866 Mdot
.59739 .31998 Mdot
.36889 .36224 Mdot
.31726 .38038 Mdot
.50442 .63662 Mdot
.62043 .35134 Mdot
.45595 .63317 Mdot
.43197 .45175 Mdot
.50622 .65722 Mdot
.29191 .51448 Mdot
.51622 .57718 Mdot
.54482 .4211 Mdot
.79369 .65491 Mdot
.40692 .69472 Mdot
.70048 .50812 Mdot
.33479 .365 Mdot
.40009 .3758 Mdot
.69758 .53159 Mdot
.40004 .37831 Mdot
.5619 .72174 Mdot
.65664 .71742 Mdot
.27861 .52888 Mdot
.46026 .55008 Mdot
.27456 .51367 Mdot
.41253 .41659 Mdot
.50206 .62824 Mdot
.19941 .63258 Mdot
.41219 .3877 Mdot
.70275 .26724 Mdot
.57834 .34592 Mdot
.41023 .41568 Mdot
.48976 .65818 Mdot
.45144 .35081 Mdot
.37463 .35745 Mdot
.52269 .32396 Mdot
.46472 .60745 Mdot
.68383 .54351 Mdot
.46422 .59916 Mdot
.42427 .64208 Mdot
.46682 .40138 Mdot
.43748 .61548 Mdot
.58865 .33164 Mdot
.62826 .54494 Mdot
.63016 .81229 Mdot
.53711 .30304 Mdot
.51357 .63051 Mdot
.47096 .63848 Mdot
.70909 .54291 Mdot
.46161 .65812 Mdot
.61517 .36358 Mdot
.80554 .27881 Mdot
.26924 .53078 Mdot
.3425 .38737 Mdot
.52936 .28024 Mdot
.54532 .58559 Mdot
.46612 .5819 Mdot
.35548 .79523 Mdot
.55813 .2626 Mdot
.60706 .33959 Mdot
.40921 .63447 Mdot
.37027 .38875 Mdot
.28968 .5377 Mdot
.58384 .37928 Mdot
.4534 .58197 Mdot
.48512 .6248 Mdot
.29712 .52009 Mdot
.57137 .81429 Mdot
.30602 .32706 Mdot
.56177 .33859 Mdot
.39803 .61166 Mdot
.34 .34516 Mdot
.4856 .65241 Mdot
.30229 .39212 Mdot
.69697 .52071 Mdot
.61437 .33458 Mdot
.79386 .47834 Mdot
.51257 .57065 Mdot
.60191 .37158 Mdot
.57149 .35031 Mdot
.45918 .67903 Mdot
.72216 .52159 Mdot
.6291 .53045 Mdot
.66994 .50126 Mdot
.50215 .15535 Mdot
.29559 .59792 Mdot
.43242 .38468 Mdot
.59924 .34703 Mdot
.33963 .37901 Mdot
.31035 .51312 Mdot
.38645 .51227 Mdot
.33487 .3789 Mdot
.69541 .54552 Mdot
.3488 .36633 Mdot
.46485 .60202 Mdot
.57351 .35923 Mdot
.43862 .39815 Mdot
.54047 .59827 Mdot
.54921 .5135 Mdot
.42153 .44116 Mdot
.26743 .56168 Mdot
.24843 .56031 Mdot
.51239 .59274 Mdot
.42771 .41602 Mdot
.49518 .61339 Mdot
.55529 .36176 Mdot
.61226 .44307 Mdot
.54542 .59244 Mdot
.40322 .38726 Mdot
.49339 .52294 Mdot
.31542 .38554 Mdot
.41413 .64127 Mdot
.47027 .61291 Mdot
.49049 .64821 Mdot
.45519 .63325 Mdot
.684 .42914 Mdot
.5849 .31581 Mdot
.51363 .50239 Mdot
.49899 .34201 Mdot
.68079 .52227 Mdot
.64879 .49345 Mdot
.27942 .38999 Mdot
.33039 .38457 Mdot
.59479 .33704 Mdot
.4738 .6518 Mdot
.54397 .29025 Mdot
.49194 .85444 Mdot
.21368 .65697 Mdot
.27153 .56956 Mdot
.44425 .4035 Mdot
.69971 .50481 Mdot
.39262 .36038 Mdot
.49613 .6379 Mdot
.45393 .68038 Mdot
.67827 .79369 Mdot
.54438 .33348 Mdot
.2886 .52563 Mdot
.49202 .64651 Mdot
.27779 .59284 Mdot
.37529 .39219 Mdot
.35468 .37205 Mdot
.51052 .64479 Mdot
.62922 .51467 Mdot
.85249 .49267 Mdot
.5982 .31937 Mdot
.41961 .54979 Mdot
.66344 .58592 Mdot
.66782 .2948 Mdot
.59433 .36848 Mdot
.38341 .43024 Mdot
.44405 .40556 Mdot
.51397 .77371 Mdot
.68452 .52446 Mdot
.29097 .52392 Mdot
.47424 .68358 Mdot
.68325 .55177 Mdot
.46458 .39336 Mdot
.66293 .55664 Mdot
.52366 .5804 Mdot
.59859 .3158 Mdot
.3663 .36799 Mdot
.55703 .32323 Mdot
.70517 .5028 Mdot
.25803 .52914 Mdot
.55972 .48995 Mdot
.72521 .62976 Mdot
.56532 .74667 Mdot
.48 .65637 Mdot
.37684 .50609 Mdot
.4469 .61374 Mdot
.71917 .53289 Mdot
.46063 .63762 Mdot
.62107 .57405 Mdot
.37652 .36314 Mdot
.4573 .65978 Mdot
.47318 .57006 Mdot
.67227 .62953 Mdot
.48052 .61039 Mdot
.43459 .64718 Mdot
.46208 .6484 Mdot
.61793 .51074 Mdot
.43464 .57477 Mdot
.67178 .54277 Mdot
.42621 .21176 Mdot
.38438 .39496 Mdot
.27624 .56377 Mdot
.28754 .5558 Mdot
.23949 .60882 Mdot
.34961 .55562 Mdot
.68483 .41397 Mdot
.66848 .53266 Mdot
.57658 .33676 Mdot
.45676 .63701 Mdot
.7849 .52674 Mdot
.50147 .29835 Mdot
.36937 .39013 Mdot
.53574 .30563 Mdot
.42937 .6828 Mdot
.81264 .41863 Mdot
.48558 .66059 Mdot
.37993 .2089 Mdot
.53693 .56141 Mdot
.52107 .63649 Mdot
.36656 .35475 Mdot
.35077 .55338 Mdot
.48939 .65615 Mdot
.71695 .53358 Mdot
.2861 .51823 Mdot
.74306 .53325 Mdot
.39251 .29902 Mdot
.36864 .41924 Mdot
.69291 .6588 Mdot
.44629 .62426 Mdot
.36681 .3701 Mdot
.66477 .54968 Mdot
.51946 .1839 Mdot
.5972 .32253 Mdot
.62218 .41363 Mdot
.62245 .62118 Mdot
.3494 .76694 Mdot
.28901 .52141 Mdot
.56609 .81238 Mdot
.48997 .58733 Mdot
.30753 .4201 Mdot
.51173 .56262 Mdot
.49579 .85416 Mdot
.28341 .50395 Mdot
.63564 .5052 Mdot
.6108 .34897 Mdot
.68498 .5607 Mdot
.57177 .75865 Mdot
.61009 .2861 Mdot
.52093 .4678 Mdot
.37588 .40078 Mdot
.52752 .50033 Mdot
.65585 .51316 Mdot
.48084 .57376 Mdot
.88968 .57364 Mdot
.69581 .51625 Mdot
.65064 .50114 Mdot
.27632 .70044 Mdot
.27767 .70707 Mdot
.41235 .66586 Mdot
.67495 .55845 Mdot
.38062 .40149 Mdot
.26468 .54453 Mdot
.45874 .60449 Mdot
.45581 .62158 Mdot
.69029 .54213 Mdot
.35973 .35903 Mdot
.39936 .57252 Mdot
.39905 .39133 Mdot
.65867 .5406 Mdot
.38581 .3897 Mdot
.52633 .30814 Mdot
.4357 .40445 Mdot
.44337 .64278 Mdot
.45961 .63766 Mdot
.35464 .31917 Mdot
.68606 .53726 Mdot
.46001 .58606 Mdot
.50923 .57921 Mdot
.663 .51121 Mdot
.44434 .37389 Mdot
.76394 .56413 Mdot
.51099 .62449 Mdot
.47701 .59311 Mdot
.30115 .52208 Mdot
.34964 .49921 Mdot
.22383 .3907 Mdot
.46126 .59271 Mdot
.30565 .51302 Mdot
.6327 .54242 Mdot
.49527 .60936 Mdot
.66176 .46382 Mdot
.52032 .3235 Mdot
.51071 .57106 Mdot
.4137 .41308 Mdot
.53923 .62339 Mdot
.83192 .54549 Mdot
.52085 .6214 Mdot
.65665 .52009 Mdot
.64099 .52656 Mdot
.28727 .7016 Mdot
.68502 .51098 Mdot
.38582 .40749 Mdot
.59006 .361 Mdot
.52062 .855 Mdot
.35929 .3959 Mdot
.52858 .63048 Mdot
.15477 .48778 Mdot
.46242 .66504 Mdot
.54137 .59171 Mdot
.79759 .37766 Mdot
.36018 .3958 Mdot
.64463 .52479 Mdot
.64255 .38299 Mdot
.52461 .55207 Mdot
.61783 .33219 Mdot
.48755 .6736 Mdot
.43904 .6003 Mdot
.63594 .25043 Mdot
.75908 .36459 Mdot
.57016 .38319 Mdot
.54891 .63436 Mdot
.46095 .5924 Mdot
.36551 .48029 Mdot
.46668 .64157 Mdot
.27591 .51223 Mdot
.6563 .50065 Mdot
.41699 .37268 Mdot
.26723 .53924 Mdot
.50503 .61448 Mdot
.29095 .52976 Mdot
.43389 .38418 Mdot
.61774 .34347 Mdot
.50216 .63359 Mdot
.25916 .50992 Mdot
.28489 .52884 Mdot
.44765 .60597 Mdot
.6408 .54658 Mdot
.4067 .68357 Mdot
.49514 .60593 Mdot
.48716 .575 Mdot
.68995 .54009 Mdot
.18618 .64054 Mdot
.52051 .62957 Mdot
.46773 .4357 Mdot
.65314 .49772 Mdot
.55914 .28655 Mdot
.43716 .3841 Mdot
.43732 .60597 Mdot
.6189 .35084 Mdot
.60265 .36552 Mdot
.35804 .38847 Mdot
.69909 .55405 Mdot
.34515 .36187 Mdot
.49103 .52444 Mdot
.48755 .54301 Mdot
.45799 .67024 Mdot
.15823 .42804 Mdot
.67316 .79011 Mdot
.70286 .51669 Mdot
.46415 .38645 Mdot
.55389 .44149 Mdot
.60335 .34778 Mdot
.34698 .38016 Mdot
.71185 .52769 Mdot
.70295 .50819 Mdot
.66637 .5549 Mdot
.29901 .53723 Mdot
.46424 .38386 Mdot
.62109 .53739 Mdot
.62848 .51657 Mdot
.46527 .60435 Mdot
.4605 .59098 Mdot
.53179 .68221 Mdot
.34333 .65656 Mdot
.2578 .5262 Mdot
.38912 .37265 Mdot
.72713 .22899 Mdot
.55733 .36907 Mdot
.6724 .63251 Mdot
.54467 .59013 Mdot
.81025 .73587 Mdot
.49605 .65872 Mdot
.47107 .64265 Mdot
.63327 .55058 Mdot
.2506 .51856 Mdot
.27249 .5164 Mdot
.65342 .51349 Mdot
.70621 .50605 Mdot
.28337 .5113 Mdot
.49252 .8205 Mdot
.58258 .83526 Mdot
.65367 .35061 Mdot
.6644 .51651 Mdot
.71979 .65051 Mdot
.62073 .33867 Mdot
.70524 .50118 Mdot
.55845 .3651 Mdot
.3764 .39038 Mdot
.44748 .40441 Mdot
.56233 .35054 Mdot
.46325 .61172 Mdot
.43451 .39101 Mdot
.4455 .57335 Mdot
.52779 .83082 Mdot
.6578 .75086 Mdot
.51923 .24412 Mdot
.47961 .55338 Mdot
.38472 .24506 Mdot
.38842 .25745 Mdot
.51194 .60454 Mdot
.72725 .47328 Mdot
.28984 .52658 Mdot
.67119 .48022 Mdot
.61676 .36122 Mdot
.82853 .58566 Mdot
.48147 .65281 Mdot
.65901 .52264 Mdot
.58111 .33718 Mdot
.29136 .69181 Mdot
.66092 .33709 Mdot
.49627 .64351 Mdot
.89033 .52044 Mdot
.64408 .48154 Mdot
.41889 .37392 Mdot
.21206 .35737 Mdot
.65551 .56663 Mdot
.2617 .57258 Mdot
.48975 .35958 Mdot
.35066 .78078 Mdot
.64794 .53937 Mdot
.46983 .3889 Mdot
.65697 .50613 Mdot
.26551 .51613 Mdot
.68391 .47783 Mdot
.36165 .3721 Mdot
.47955 .61551 Mdot
.39549 .37967 Mdot
.25602 .53049 Mdot
.3075 .40686 Mdot
.61827 .3574 Mdot
.40906 .41446 Mdot
.59237 .35159 Mdot
.29085 .58647 Mdot
.68531 .27157 Mdot
.59486 .32589 Mdot
.26386 .67213 Mdot
.52685 .57633 Mdot
.62717 .55248 Mdot
.4177 .38282 Mdot
.49024 .36313 Mdot
.56463 .4765 Mdot
.67899 .51761 Mdot
.38446 .3691 Mdot
.62589 .61382 Mdot
.17614 .53343 Mdot
.52863 .54177 Mdot
.32421 .58921 Mdot
.66587 .51247 Mdot
.35158 .37292 Mdot
.45665 .19176 Mdot
.69762 .54449 Mdot
.41769 .38647 Mdot
.61046 .35555 Mdot
.58887 .36785 Mdot
.50114 .64997 Mdot
.63455 .38781 Mdot
.40625 .37206 Mdot
.42719 .22815 Mdot
.63809 .51654 Mdot
.29317 .69 Mdot
.25264 .54288 Mdot
.39127 .39918 Mdot
.49784 .66473 Mdot
.68337 .57693 Mdot
.51958 .32191 Mdot
.38227 .59592 Mdot
.72436 .233 Mdot
.39346 .37361 Mdot
.65281 .50152 Mdot
.66273 .52432 Mdot
.42454 .65656 Mdot
.58147 .44936 Mdot
.34239 .36163 Mdot
.20077 .56933 Mdot
.25484 .63306 Mdot
.46528 .39993 Mdot
.40088 .27079 Mdot
.52254 .64272 Mdot
.44247 .61947 Mdot
.60532 .34748 Mdot
.47585 .61202 Mdot
.62615 .52931 Mdot
.48192 .65768 Mdot
.59038 .37161 Mdot
.40231 .40555 Mdot
.49928 .63107 Mdot
.26532 .54782 Mdot
.59224 .38747 Mdot
.56052 .35761 Mdot
.40007 .39929 Mdot
.67313 .55778 Mdot
.22854 .53911 Mdot
.39784 .38801 Mdot
.44728 .62576 Mdot
.48992 .37284 Mdot
.52252 .58256 Mdot
.49721 .80088 Mdot
.69208 .55117 Mdot
.38588 .36031 Mdot
.65662 .49394 Mdot
.59049 .3473 Mdot
.4981 .34361 Mdot
.46451 .62749 Mdot
.41734 .38869 Mdot
.36506 .30614 Mdot
.52018 .81631 Mdot
.70727 .54802 Mdot
.42979 .2785 Mdot
.64028 .50584 Mdot
.46262 .40245 Mdot
.41195 .7497 Mdot
.2788 .52278 Mdot
.36545 .38392 Mdot
.67291 .77973 Mdot
.40654 .38588 Mdot
.4828 .606 Mdot
.49907 .5931 Mdot
.44386 .38918 Mdot
.30048 .54368 Mdot
.57133 .18334 Mdot
.42642 .43497 Mdot
.64488 .53193 Mdot
.46691 .75747 Mdot
.78154 .29223 Mdot
.62112 .31467 Mdot
.60648 .34371 Mdot
.5165 .55335 Mdot
.5191 .64217 Mdot
.57249 .37721 Mdot
.62527 .35344 Mdot
.25235 .52769 Mdot
.35793 .3744 Mdot
.67916 .47544 Mdot
.61663 .36992 Mdot
.56215 .62358 Mdot
.3467 .55885 Mdot
.40878 .60524 Mdot
.55039 .5414 Mdot
.46969 .56213 Mdot
.23493 .61799 Mdot
.57546 .36906 Mdot
.51097 .58802 Mdot
.41939 .59757 Mdot
.61454 .34015 Mdot
.26872 .51464 Mdot
.74623 .3484 Mdot
.37842 .38302 Mdot
.33679 .81325 Mdot
.52484 .59761 Mdot
.48654 .60592 Mdot
.57023 .32893 Mdot
.34734 .48019 Mdot
.68268 .54967 Mdot
.68973 .55483 Mdot
.42876 .40333 Mdot
.54305 .48999 Mdot
.45589 .65278 Mdot
.51264 .59992 Mdot
.37281 .37325 Mdot
.41162 .41517 Mdot
.47769 .23412 Mdot
.4919 .58109 Mdot
.58265 .33795 Mdot
.48343 .37514 Mdot
.5812 .37165 Mdot
.52935 .60022 Mdot
.48453 .6022 Mdot
.4453 .6456 Mdot
.52153 .64023 Mdot
.55906 .3539 Mdot
.50765 .58685 Mdot
.555 .56964 Mdot
.65577 .55665 Mdot
.44147 .63277 Mdot
.2463 .62973 Mdot
.47205 .60496 Mdot
.25915 .53459 Mdot
.34923 .5409 Mdot
.49258 .64784 Mdot
.43899 .63258 Mdot
.4312 .43618 Mdot
.47639 .6257 Mdot
.55544 .36165 Mdot
.67666 .52369 Mdot
.59955 .34774 Mdot
.56265 .35642 Mdot
.40678 .41044 Mdot
.26263 .51556 Mdot
.53755 .57605 Mdot
.26613 .55515 Mdot
.54681 .63167 Mdot
.52019 .57312 Mdot
.48378 .33847 Mdot
.37497 .20951 Mdot
.30402 .33004 Mdot
.46346 .62706 Mdot
.41109 .40438 Mdot
.41117 .3692 Mdot
.40032 .54955 Mdot
.44116 .57371 Mdot
.5786 .37993 Mdot
.60505 .36016 Mdot
.37409 .69821 Mdot
.63512 .25209 Mdot
.25898 .52774 Mdot
.38342 .50934 Mdot
.4533 .56182 Mdot
.49956 .57685 Mdot
.47495 .6696 Mdot
.33571 .3788 Mdot
.49419 .37485 Mdot
.3701 .39071 Mdot
.52666 .32347 Mdot
.58996 .3729 Mdot
.46553 .65384 Mdot
.70238 .72289 Mdot
.70083 .52968 Mdot
.67728 .52426 Mdot
.58383 .3775 Mdot
.33521 .36736 Mdot
.48703 .69689 Mdot
.12647 .52789 Mdot
.63339 .49233 Mdot
.25037 .54647 Mdot
.51366 .60973 Mdot
.40632 .40181 Mdot
.69341 .50669 Mdot
.30527 .54206 Mdot
.5063 .57187 Mdot
.34658 .35774 Mdot
.46061 .62618 Mdot
.58668 .62146 Mdot
.64619 .54836 Mdot
.51689 .86117 Mdot
.70904 .53187 Mdot
.60093 .38552 Mdot
.6068 .33282 Mdot
.49286 .59672 Mdot
.17319 .40646 Mdot
.63285 .55833 Mdot
.60998 .40185 Mdot
.27276 .50602 Mdot
.49169 .36961 Mdot
.30184 .51438 Mdot
.38876 .36239 Mdot
.28656 .51922 Mdot
.36497 .36562 Mdot
.36463 .67815 Mdot
.61006 .54227 Mdot
.26724 .53415 Mdot
.39946 .47256 Mdot
.44622 .56584 Mdot
.29669 .55644 Mdot
.55319 .58947 Mdot
.49475 .76654 Mdot
.37543 .37436 Mdot
.29641 .54674 Mdot
.47929 .5747 Mdot
.79386 .62287 Mdot
.59426 .3311 Mdot
.57595 .37994 Mdot
.43355 .59738 Mdot
.35717 .37579 Mdot
.71549 .52076 Mdot
.63602 .44293 Mdot
.55546 .29699 Mdot
.51168 .5941 Mdot
.48668 .65692 Mdot
.64641 .49413 Mdot
.61942 .56047 Mdot
.48783 .5976 Mdot
.66977 .61039 Mdot
.49636 .58534 Mdot
.60953 .36379 Mdot
.70452 .53078 Mdot
.66807 .5239 Mdot
.39397 .36732 Mdot
.65726 .5625 Mdot
.53336 .53373 Mdot
.52872 .39503 Mdot
.54818 .57811 Mdot
.58357 .34711 Mdot
.57125 .43089 Mdot
.53526 .30602 Mdot
.73882 .70247 Mdot
.66493 .4872 Mdot
.43551 .62636 Mdot
.64202 .50846 Mdot
.28939 .54279 Mdot
.68408 .536 Mdot
.67914 .49748 Mdot
.50124 .60669 Mdot
.49409 .64129 Mdot
.37465 .40228 Mdot
.57561 .44931 Mdot
.64136 .55168 Mdot
.50793 .59117 Mdot
.45715 .66212 Mdot
.43319 .64524 Mdot
.49186 .43901 Mdot
.70105 .51289 Mdot
.62198 .65282 Mdot
.4118 .7307 Mdot
.64356 .55316 Mdot
.8366 .525 Mdot
.5003 .36009 Mdot
.33842 .38575 Mdot
.57366 .31119 Mdot
.49165 .58043 Mdot
.44817 .39101 Mdot
.49661 .63734 Mdot
.55415 .54251 Mdot
.48554 .62767 Mdot
.30748 .52113 Mdot
.50998 .55486 Mdot
.45525 .40568 Mdot
.39813 .38551 Mdot
.52069 .60615 Mdot
.49634 .63076 Mdot
.31597 .39973 Mdot
.70212 .50231 Mdot
.67966 .55111 Mdot
.32666 .47416 Mdot
.27701 .53777 Mdot
.61614 .33425 Mdot
.46155 .64425 Mdot
.41899 .40531 Mdot
.39522 .3812 Mdot
.68264 .56238 Mdot
.38364 .37939 Mdot
.5858 .32113 Mdot
.465 .63149 Mdot
.57285 .37826 Mdot
.2925 .54987 Mdot
.66824 .50042 Mdot
.47572 .65313 Mdot
.4658 .60326 Mdot
.64108 .52659 Mdot
.524 .57038 Mdot
.30098 .52117 Mdot
.40399 .38274 Mdot
.65229 .54427 Mdot
.59109 .36256 Mdot
.37729 .36228 Mdot
.47076 .58686 Mdot
.71722 .22678 Mdot
.47996 .60273 Mdot
.48151 .58079 Mdot
.63684 .81884 Mdot
.51708 .55703 Mdot
.40976 .3765 Mdot
.63742 .50001 Mdot
.44308 .57994 Mdot
.25681 .60995 Mdot
.20967 .65731 Mdot
.36272 .39219 Mdot
.51559 .61671 Mdot
.7398 .71077 Mdot
.51873 .61305 Mdot
.21943 .62765 Mdot
.23819 .41458 Mdot
.47799 .4975 Mdot
.55974 .55664 Mdot
.5672 .33745 Mdot
.37838 .40396 Mdot
.37743 .36369 Mdot
.52682 .71938 Mdot
.50508 .60234 Mdot
.57592 .62672 Mdot
.48328 .56862 Mdot
.59207 .36896 Mdot
.41701 .7165 Mdot
.39136 .37506 Mdot
.41105 .20083 Mdot
.44883 .61835 Mdot
.70289 .51339 Mdot
.34981 .36475 Mdot
.50434 .35477 Mdot
.4782 .57895 Mdot
.27439 .55628 Mdot
.54616 .36093 Mdot
.52286 .54834 Mdot
.58126 .35188 Mdot
.50576 .57548 Mdot
.56528 .59008 Mdot
.23892 .31463 Mdot
.65028 .55211 Mdot
.60922 .34869 Mdot
.38973 .26486 Mdot
.51998 .56416 Mdot
.64925 .54267 Mdot
.68392 .52339 Mdot
.25311 .5363 Mdot
.53202 .45275 Mdot
.7046 .34536 Mdot
.72636 .67313 Mdot
.48096 .74744 Mdot
.34719 .37447 Mdot
.43814 .25195 Mdot
.45898 .60057 Mdot
.57605 .23761 Mdot
.56041 .37397 Mdot
.48423 .60946 Mdot
.51909 .75221 Mdot
.6784 .50222 Mdot
.48158 .58916 Mdot
.27409 .51356 Mdot
.54962 .2158 Mdot
.5587 .23071 Mdot
.82068 .46278 Mdot
.37456 .39849 Mdot
.47747 .67755 Mdot
.54562 .5406 Mdot
.39463 .41188 Mdot
.50602 .56433 Mdot
.41028 .37949 Mdot
.43545 .7948 Mdot
.3064 .53234 Mdot
.68388 .50134 Mdot
.50176 .35837 Mdot
.46171 .56605 Mdot
.44507 .65977 Mdot
.27232 .56341 Mdot
.44341 .60111 Mdot
.30204 .25585 Mdot
.51089 .26301 Mdot
.43649 .3969 Mdot
.66314 .55522 Mdot
.4643 .5595 Mdot
.48953 .38084 Mdot
.5013 .60095 Mdot
.65359 .73499 Mdot
.43669 .62504 Mdot
.69085 .32924 Mdot
.63849 .53824 Mdot
.58417 .3511 Mdot
.51548 .66505 Mdot
.48065 .6335 Mdot
.36439 .34121 Mdot
.5626 .56019 Mdot
.52303 .61673 Mdot
.71525 .53444 Mdot
.70276 .52315 Mdot
.67159 .54176 Mdot
.4184 .36882 Mdot
.62096 .25093 Mdot
.58867 .33939 Mdot
.52879 .63857 Mdot
.61668 .37044 Mdot
.39518 .58762 Mdot
.26583 .56193 Mdot
.79385 .58951 Mdot
.44011 .60375 Mdot
.66655 .53626 Mdot
.74561 .43151 Mdot
.63195 .53981 Mdot
.4471 .37096 Mdot
.57151 .3547 Mdot
.68884 .50632 Mdot
.47474 .6393 Mdot
.5622 .43678 Mdot
.80225 .52869 Mdot
.60041 .35294 Mdot
.55247 .61268 Mdot
.43722 .40871 Mdot
.53159 .2839 Mdot
.76997 .26146 Mdot
.60575 .33798 Mdot
.40075 .25927 Mdot
.50956 .60129 Mdot
.69845 .5358 Mdot
.57167 .33055 Mdot
.58745 .32845 Mdot
.38069 .3744 Mdot
.49291 .64339 Mdot
.48764 .64779 Mdot
.46154 .40016 Mdot
.60326 .36181 Mdot
.4314 .65402 Mdot
.49122 .66429 Mdot
.67742 .79568 Mdot
.51423 .71109 Mdot
.22137 .71598 Mdot
.47912 .52594 Mdot
.52499 .75777 Mdot
.61097 .46665 Mdot
.66005 .49808 Mdot
.49553 .64625 Mdot
.48067 .55751 Mdot
.40155 .37064 Mdot
.4718 .61742 Mdot
.42071 .36622 Mdot
.59735 .33614 Mdot
.83196 .52294 Mdot
.75552 .38715 Mdot
.42539 .78685 Mdot
.47373 .61879 Mdot
.65444 .27872 Mdot
.27715 .54619 Mdot
.60016 .38946 Mdot
.66196 .54446 Mdot
.52877 .585 Mdot
.31268 .39176 Mdot
.36768 .38655 Mdot
.69125 .52207 Mdot
.39821 .22866 Mdot
.31559 .36706 Mdot
.52956 .5994 Mdot
.43449 .37719 Mdot
.71067 .44774 Mdot
.67858 .60582 Mdot
.63201 .34229 Mdot
.30551 .51774 Mdot
.37338 .39256 Mdot
.58199 .3748 Mdot
.63397 .47752 Mdot
.6882 .50865 Mdot
.62121 .51714 Mdot
.28507 .36559 Mdot
.32896 .3698 Mdot
.26693 .54235 Mdot
.62618 .25272 Mdot
.61023 .23397 Mdot
.30664 .52025 Mdot
.45635 .39889 Mdot
.7001 .51629 Mdot
.65279 .53135 Mdot
.67542 .52307 Mdot
.42747 .19365 Mdot
.70126 .55002 Mdot
.67435 .6562 Mdot
.45504 .6628 Mdot
.57271 .6082 Mdot
.51685 .61719 Mdot
.55961 .36556 Mdot
.64416 .54461 Mdot
.5905 .46836 Mdot
.53615 .62052 Mdot
.81844 .49184 Mdot
.51345 .59762 Mdot
.63154 .3496 Mdot
.48447 .58393 Mdot
.70275 .63051 Mdot
.6486 .49904 Mdot
.4668 .62117 Mdot
.5608 .32758 Mdot
.28401 .5324 Mdot
.72323 .51637 Mdot
.49148 .64754 Mdot
.6682 .40238 Mdot
.52348 .55952 Mdot
.4751 .8168 Mdot
.31503 .70021 Mdot
.2505 .54735 Mdot
.41258 .57098 Mdot
.35391 .38101 Mdot
.57265 .61702 Mdot
.48347 .53821 Mdot
.599 .35373 Mdot
.7355 .31303 Mdot
.38381 .39665 Mdot
.41172 .7028 Mdot
.4133 .6451 Mdot
.26638 .51378 Mdot
.66876 .5758 Mdot
.55566 .35033 Mdot
.53829 .59731 Mdot
.45703 .67852 Mdot
.44989 .79771 Mdot
.49573 .53875 Mdot
.467 .65921 Mdot
.27714 .56176 Mdot
.62547 .65942 Mdot
.4705 .60277 Mdot
.46096 .37742 Mdot
.62539 .51187 Mdot
.43623 .5887 Mdot
.62388 .64827 Mdot
.50757 .59223 Mdot
.69576 .52652 Mdot
.61899 .55422 Mdot
.72668 .40307 Mdot
.26531 .50973 Mdot
.4368 .62415 Mdot
.3413 .73358 Mdot
.44597 .61816 Mdot
.58016 .34069 Mdot
.52494 .62331 Mdot
.36709 .38258 Mdot
.40758 .20909 Mdot
.42865 .38311 Mdot
.50786 .63709 Mdot
.67043 .52054 Mdot
.56181 .34229 Mdot
.29422 .34519 Mdot
.25799 .4161 Mdot
.66691 .65512 Mdot
.3242 .77916 Mdot
.30114 .54038 Mdot
.31414 .528 Mdot
.55635 .34449 Mdot
.4663 .61961 Mdot
.30374 .7152 Mdot
.53027 .55652 Mdot
.47739 .5914 Mdot
.48679 .6275 Mdot
.60936 .25849 Mdot
.60034 .34312 Mdot
.38534 .38494 Mdot
.48561 .59919 Mdot
.50689 .58886 Mdot
.64585 .50895 Mdot
.28315 .53074 Mdot
.42752 .37832 Mdot
.27391 .53112 Mdot
.41279 .39734 Mdot
.83595 .53748 Mdot
.53617 .63695 Mdot
.28319 .53487 Mdot
.56125 .37863 Mdot
.69069 .5399 Mdot
.49583 .37405 Mdot
.38588 .36238 Mdot
.38848 .37163 Mdot
.51158 .59606 Mdot
.69638 .53234 Mdot
.65147 .56008 Mdot
.2895 .54379 Mdot
.60161 .32493 Mdot
.50261 .63811 Mdot
.52329 .57607 Mdot
.43196 .5207 Mdot
.33378 .37449 Mdot
.6344 .60501 Mdot
.71295 .41956 Mdot
.46375 .62404 Mdot
.67247 .559 Mdot
.49476 .62426 Mdot
.69671 .73932 Mdot
.69335 .54699 Mdot
.51883 .63815 Mdot
.60819 .22215 Mdot
.4873 .37419 Mdot
.68672 .37433 Mdot
.44463 .64897 Mdot
.37266 .81272 Mdot
.45524 .5992 Mdot
.71988 .75127 Mdot
.33082 .43462 Mdot
.46603 .65496 Mdot
.46267 .59992 Mdot
.74541 .6551 Mdot
.50825 .61418 Mdot
.45438 .40749 Mdot
.40989 .70338 Mdot
.70102 .50503 Mdot
.59542 .47784 Mdot
.347 .51503 Mdot
.26232 .50991 Mdot
.42941 .40303 Mdot
.40853 .28013 Mdot
.28935 .51338 Mdot
.66234 .5159 Mdot
.45488 .63338 Mdot
.50829 .48854 Mdot
.46825 .39323 Mdot
.4207 .6387 Mdot
.57608 .34483 Mdot
.47049 .26931 Mdot
.43321 .3712 Mdot
.58761 .35802 Mdot
.453 .57792 Mdot
.76535 .57328 Mdot
.22722 .41193 Mdot
.53086 .86233 Mdot
.56279 .33719 Mdot
.5991 .36932 Mdot
.47767 .17905 Mdot
.27057 .50517 Mdot
.45539 .77933 Mdot
.67466 .324 Mdot
.60412 .31954 Mdot
.39199 .74239 Mdot
.36618 .3895 Mdot
.66709 .39207 Mdot
.67138 .48026 Mdot
.4609 .67077 Mdot
.47602 .63745 Mdot
.60572 .32681 Mdot
.66024 .46694 Mdot
.2292 .33119 Mdot
.59338 .35264 Mdot
.56071 .59101 Mdot
.48558 .45674 Mdot
.50035 .36191 Mdot
.35313 .39351 Mdot
.25944 .5146 Mdot
.31806 .55606 Mdot
.6486 .51046 Mdot
.25464 .52472 Mdot
.5502 .22831 Mdot
.44141 .60312 Mdot
.59872 .3592 Mdot
.50988 .35398 Mdot
.58766 .36432 Mdot
.28064 .51412 Mdot
.24854 .53888 Mdot
.65721 .55712 Mdot
.6802 .55006 Mdot
.54107 .75483 Mdot
.35454 .69711 Mdot
.51976 .61015 Mdot
.78842 .48097 Mdot
.63642 .52103 Mdot
.45096 .54676 Mdot
.30704 .51589 Mdot
.28032 .5344 Mdot
.56974 .6556 Mdot
.46679 .65078 Mdot
.27517 .69131 Mdot
.46708 .64909 Mdot
.39308 .71271 Mdot
.50361 .56194 Mdot
.38178 .37661 Mdot
.46111 .65021 Mdot
.24604 .51091 Mdot
.52248 .6425 Mdot
.52472 .61159 Mdot
.35869 .3808 Mdot
.51517 .54616 Mdot
.36653 .3814 Mdot
.5095 .63746 Mdot
.30697 .51119 Mdot
.42085 .40531 Mdot
.29389 .60646 Mdot
.46387 .43685 Mdot
.4294 .41496 Mdot
.25882 .54351 Mdot
.25614 .5487 Mdot
.24681 .59326 Mdot
.66015 .54415 Mdot
.72794 .53598 Mdot
.46876 .6156 Mdot
.35455 .37136 Mdot
.60445 .34462 Mdot
.5043 .58696 Mdot
.50641 .55782 Mdot
.46153 .66001 Mdot
.6592 .5015 Mdot
.34055 .36375 Mdot
.2887 .53414 Mdot
.43134 .37486 Mdot
.37938 .34533 Mdot
.44513 .37837 Mdot
.42433 .5876 Mdot
.4859 .68317 Mdot
.52714 .78321 Mdot
.78994 .43321 Mdot
.55185 .17973 Mdot
.68937 .51223 Mdot
.41267 .41361 Mdot
.25019 .53036 Mdot
.39303 .65638 Mdot
.66193 .53929 Mdot
.36198 .37347 Mdot
.46028 .62744 Mdot
.55162 .61791 Mdot
.54306 .32734 Mdot
.57571 .61214 Mdot
.272 .64565 Mdot
.40864 .36182 Mdot
.47475 .39234 Mdot
.60349 .23488 Mdot
.42652 .70732 Mdot
.55489 .48462 Mdot
.48878 .61573 Mdot
.27807 .55634 Mdot
.69347 .50677 Mdot
.26152 .36987 Mdot
.61565 .34864 Mdot
.5792 .44905 Mdot
.47272 .61968 Mdot
.65101 .31678 Mdot
.67237 .52047 Mdot
.26518 .51788 Mdot
.60752 .32771 Mdot
.24891 .51961 Mdot
.34929 .39233 Mdot
.28283 .72173 Mdot
.44391 .61117 Mdot
.52065 .62067 Mdot
.6097 .37787 Mdot
.65714 .50711 Mdot
.24793 .55846 Mdot
.49736 .81585 Mdot
.4396 .38726 Mdot
.26364 .68508 Mdot
.63095 .55027 Mdot
.69863 .65698 Mdot
.42733 .37269 Mdot
.58493 .37751 Mdot
.25027 .58984 Mdot
.58887 .37169 Mdot
.49473 .6498 Mdot
.66751 .52983 Mdot
.59188 .33202 Mdot
.39682 .33933 Mdot
.76851 .6742 Mdot
.71228 .65536 Mdot
.44809 .63692 Mdot
.80489 .56893 Mdot
.5623 .83057 Mdot
.72486 .49066 Mdot
.61978 .35506 Mdot
.49646 .60371 Mdot
.47261 .56746 Mdot
.44939 .62261 Mdot
.57011 .34399 Mdot
.46544 .33357 Mdot
.37617 .36955 Mdot
.51587 .60603 Mdot
.25196 .53141 Mdot
.37042 .38352 Mdot
.50147 .34928 Mdot
.40123 .37279 Mdot
.68339 .49314 Mdot
.52097 .63901 Mdot
.61378 .41806 Mdot
.79977 .65658 Mdot
.59979 .34897 Mdot
.43019 .41478 Mdot
.521 .58789 Mdot
.66909 .27242 Mdot
.66997 .54081 Mdot
.44068 .38872 Mdot
.48681 .6064 Mdot
.44898 .33959 Mdot
.31229 .39838 Mdot
.39729 .37219 Mdot
.65227 .53639 Mdot
.72636 .48333 Mdot
.47399 .61333 Mdot
.45299 .59906 Mdot
.65725 .50942 Mdot
.3218 .49688 Mdot
.42165 .20791 Mdot
.49524 .62864 Mdot
.58492 .35245 Mdot
.15446 .55985 Mdot
.43898 .65022 Mdot
.48298 .7215 Mdot
.36381 .39567 Mdot
.6892 .40653 Mdot
.63813 .60308 Mdot
.39907 .59274 Mdot
.75119 .65681 Mdot
.39722 .50809 Mdot
.82661 .53579 Mdot
.38513 .35248 Mdot
.37322 .44819 Mdot
.83141 .55057 Mdot
.56551 .32519 Mdot
.58757 .54459 Mdot
.4244 .54352 Mdot
.38853 .21866 Mdot
.65672 .46062 Mdot
.30777 .46246 Mdot
.304 .36266 Mdot
.4811 .47857 Mdot
.41131 .3881 Mdot
.37678 .66014 Mdot
.50061 .63734 Mdot
.55459 .83329 Mdot
.67522 .61409 Mdot
.21337 .34205 Mdot
.80406 .57901 Mdot
.34491 .73378 Mdot
.79336 .55186 Mdot
.7181 .73125 Mdot
.51198 .78102 Mdot
.78329 .44141 Mdot
.1906 .60628 Mdot
.59164 .22221 Mdot
.36788 .76092 Mdot
.45112 .68571 Mdot
.38973 .50335 Mdot
.40929 .80379 Mdot
.66895 .68132 Mdot
.16303 .43482 Mdot
.4132 .37338 Mdot
.6356 .50337 Mdot
.42903 .53573 Mdot
.70956 .55187 Mdot
.61641 .29931 Mdot
.75829 .65087 Mdot
.70262 .76252 Mdot
.69576 .62936 Mdot
.37319 .81591 Mdot
.54217 .72601 Mdot
.44849 .14747 Mdot
.42538 .44403 Mdot
.61876 .54394 Mdot
.22624 .48228 Mdot
.61605 .23885 Mdot
.73704 .36329 Mdot
.47109 .52575 Mdot
.51158 .31241 Mdot
.31241 .62684 Mdot
.65977 .52186 Mdot
.67017 .60234 Mdot
.33536 .39059 Mdot
.74534 .35521 Mdot
.24058 .56981 Mdot
.74844 .68303 Mdot
.52186 .4786 Mdot
.65665 .40086 Mdot
.44616 .24567 Mdot
.71944 .22885 Mdot
.35904 .7214 Mdot
.62293 .79245 Mdot
.58987 .30079 Mdot
.67593 .4638 Mdot
.3353 .258 Mdot
.33545 .6733 Mdot
.61695 .23738 Mdot
.75817 .31207 Mdot
.52263 .84729 Mdot
.79123 .33773 Mdot
.72676 .52799 Mdot
.46027 .65878 Mdot
.61816 .78499 Mdot
.46781 .74194 Mdot
.32099 .5444 Mdot
.81642 .43644 Mdot
.29117 .55221 Mdot
.72214 .53755 Mdot
.39341 .22577 Mdot
.6851 .64463 Mdot
.26024 .67711 Mdot
.24024 .55138 Mdot
.47996 .55262 Mdot
.21362 .27762 Mdot
.82194 .53538 Mdot
.71978 .40057 Mdot
.67974 .79408 Mdot
.64238 .29242 Mdot
.30149 .69842 Mdot
.58624 .33283 Mdot
.82503 .59825 Mdot
.65697 .53153 Mdot
.87112 .52086 Mdot
.79435 .64713 Mdot
.22134 .36646 Mdot
.10179 .51198 Mdot
.54897 .24618 Mdot
.5073 .49961 Mdot
.39047 .51674 Mdot
.27439 .62455 Mdot
.25496 .31119 Mdot
.19326 .40602 Mdot
.6282 .26563 Mdot
.37274 .79515 Mdot
.82203 .57975 Mdot
.40382 .74836 Mdot
.31177 .73964 Mdot
.37347 .23264 Mdot
.48431 .43491 Mdot
.67084 .57892 Mdot
.45648 .42577 Mdot
.76748 .51803 Mdot
.81779 .4135 Mdot
.45736 .73104 Mdot
.12654 .53719 Mdot
.23309 .53477 Mdot
.3217 .43881 Mdot
.62675 .8083 Mdot
.3116 .59973 Mdot
.43444 .74013 Mdot
.5097 .18503 Mdot
.41188 .6191 Mdot
.54417 .19655 Mdot
.75958 .48319 Mdot
.42439 .27907 Mdot
.57919 .21804 Mdot
.67559 .43876 Mdot
.46673 .80487 Mdot
.64062 .76079 Mdot
.63171 .24056 Mdot
.70068 .50321 Mdot
.3146 .6643 Mdot
.37321 .73222 Mdot
.66703 .8035 Mdot
.39049 .26466 Mdot
.567 .87008 Mdot
.35098 .27317 Mdot
.54966 .58944 Mdot
.52496 .53912 Mdot
.50762 .68316 Mdot
.33729 .69057 Mdot
.46251 .66259 Mdot
.6351 .27403 Mdot
.65129 .81481 Mdot
.51202 .74772 Mdot
.42638 .28911 Mdot
.74601 .32223 Mdot
.53695 .86067 Mdot
.54792 .79394 Mdot
.33428 .41251 Mdot
.48472 .71248 Mdot
.55459 .16242 Mdot
.38368 .39139 Mdot
.39908 .7492 Mdot
.61424 .31821 Mdot
.26818 .37857 Mdot
.73312 .65717 Mdot
.24358 .34779 Mdot
.64994 .81637 Mdot
.43277 .20853 Mdot
.31107 .32419 Mdot
.2246 .57057 Mdot
.24404 .66772 Mdot
.77186 .35957 Mdot
.50521 .6647 Mdot
.54391 .5222 Mdot
.28032 .5597 Mdot
.56546 .76278 Mdot
.43248 .75364 Mdot
.25522 .44702 Mdot
.54697 .55268 Mdot
.19938 .44578 Mdot
.47655 .39165 Mdot
.5729 .44397 Mdot
.82 .34655 Mdot
.41934 .61438 Mdot
.56341 .25914 Mdot
.49993 .83793 Mdot
.30504 .67758 Mdot
.62901 .80122 Mdot
.64609 .42757 Mdot
.78586 .3366 Mdot
.77636 .67742 Mdot
.25285 .42844 Mdot
.83184 .49417 Mdot
.64413 .83363 Mdot
.75845 .29867 Mdot
.60586 .57953 Mdot
.55146 .34931 Mdot
.87899 .41419 Mdot
.4631 .39166 Mdot
.70788 .28013 Mdot
.48203 .74684 Mdot
.44532 .3243 Mdot
.71324 .50174 Mdot
.44531 .6902 Mdot
.49099 .47954 Mdot
.63803 .48265 Mdot
.44579 .57385 Mdot
.76368 .27733 Mdot
.72484 .27643 Mdot
.7805 .30686 Mdot
.45677 .83102 Mdot
.83423 .50079 Mdot
.4395 .50699 Mdot
.68082 .66394 Mdot
.38973 .57056 Mdot
.52864 .61348 Mdot
.36471 .647 Mdot
.54451 .24678 Mdot
.23345 .39448 Mdot
.72338 .34987 Mdot
.71735 .53867 Mdot
.80583 .47288 Mdot
.68195 .16916 Mdot
.55858 .72078 Mdot
.59069 .66798 Mdot
.57074 .23244 Mdot
.35748 .70608 Mdot
.76402 .50428 Mdot
.22374 .38613 Mdot
.64588 .80946 Mdot
.40546 .56178 Mdot
.40726 .76434 Mdot
.27034 .46154 Mdot
.21045 .60372 Mdot
.36594 .48384 Mdot
.7648 .66688 Mdot
.38291 .54189 Mdot
.27933 .32741 Mdot
.58238 .48983 Mdot
.2242 .35077 Mdot
.28851 .41009 Mdot
.47133 .26397 Mdot
.37831 .75422 Mdot
.54049 .2919 Mdot
.38881 .72069 Mdot
.49868 .45448 Mdot
.38234 .64573 Mdot
.39974 .50649 Mdot
.39172 .72399 Mdot
.20949 .59556 Mdot
.82455 .42752 Mdot
.63669 .84648 Mdot
.66333 .20732 Mdot
.38693 .82173 Mdot
.74948 .47262 Mdot
.44993 .66724 Mdot
.60413 .82994 Mdot
.81367 .36033 Mdot
.77213 .69161 Mdot
.44749 .21311 Mdot
.42016 .33928 Mdot
.59491 .3887 Mdot
.66792 .21474 Mdot
.32057 .47135 Mdot
.6847 .76336 Mdot
.56189 .18693 Mdot
.56912 .31286 Mdot
.3648 .21493 Mdot
.70629 .26782 Mdot
.73572 .6388 Mdot
.6056 .60705 Mdot
.4199 .64652 Mdot
.70682 .61688 Mdot
.66012 .49085 Mdot
.4295 .24622 Mdot
.33875 .68309 Mdot
.39624 .3981 Mdot
.34702 .56873 Mdot
.51292 .51721 Mdot
.50919 .5543 Mdot
.35473 .51887 Mdot
.64424 .49142 Mdot
.78899 .43433 Mdot
.56688 .41657 Mdot
.85299 .49431 Mdot
.52505 .24898 Mdot
.56681 .56273 Mdot
.31971 .6897 Mdot
.31806 .32671 Mdot
.49106 .18191 Mdot
.59624 .31599 Mdot
.79961 .6047 Mdot
.48661 .39339 Mdot
.318 .66913 Mdot
.70604 .61101 Mdot
.48314 .79952 Mdot
.47767 .68604 Mdot
.72904 .42253 Mdot
.62213 .75221 Mdot
.5692 .44847 Mdot
.69509 .569 Mdot
.63697 .57712 Mdot
.48198 .87693 Mdot
.53478 .21608 Mdot
.45483 .26027 Mdot
.79487 .61547 Mdot
.57018 .36014 Mdot
.63605 .54757 Mdot
.37439 .67297 Mdot
.47087 .81008 Mdot
.64711 .72384 Mdot
.31177 .3969 Mdot
.50491 .29502 Mdot
.27635 .44198 Mdot
.79802 .58037 Mdot
.79889 .55575 Mdot
.20782 .34399 Mdot
.70393 .55233 Mdot
.50877 .80393 Mdot
.41734 .7795 Mdot
.63667 .51099 Mdot
.72017 .50337 Mdot
.72373 .33036 Mdot
.84079 .45356 Mdot
.61893 .40856 Mdot
.3638 .79815 Mdot
.23233 .60864 Mdot
.45688 .3412 Mdot
.29602 .34011 Mdot
.34404 .74701 Mdot
.78966 .62493 Mdot
.69104 .59763 Mdot
.7506 .61363 Mdot
.55119 .63261 Mdot
.56943 .63373 Mdot
.64434 .19131 Mdot
.4598 .44478 Mdot
.70183 .65035 Mdot
.65986 .43972 Mdot
.44583 .62673 Mdot
.72192 .23228 Mdot
.52519 .832 Mdot
.49595 .17492 Mdot
.55168 .37333 Mdot
.46711 .58021 Mdot
.51309 .65495 Mdot
.51428 .7005 Mdot
.70834 .40765 Mdot
.74388 .30507 Mdot
.3476 .74996 Mdot
.71374 .45999 Mdot
.68026 .61137 Mdot
.56344 .25985 Mdot
.7401 .69249 Mdot
.58424 .82247 Mdot
.53753 .44467 Mdot
.53501 .24477 Mdot
.2607 .58795 Mdot
.39823 .82135 Mdot
.41979 .48622 Mdot
.44183 .51122 Mdot
.67887 .2943 Mdot
.6855 .42116 Mdot
.28054 .34751 Mdot
.51568 .57664 Mdot
.3989 .22798 Mdot
.71908 .72818 Mdot
.15376 .43677 Mdot
.28756 .28777 Mdot
.73816 .24423 Mdot
.67389 .72093 Mdot
.66906 .42175 Mdot
.76967 .57976 Mdot
.1416 .4509 Mdot
.38543 .50217 Mdot
.80998 .50287 Mdot
.23515 .57945 Mdot
.79709 .59822 Mdot
.56171 .32261 Mdot
.66053 .34522 Mdot
.74182 .31684 Mdot
.83978 .47323 Mdot
.56689 .79642 Mdot
.76618 .65573 Mdot
.57697 .48835 Mdot
.83668 .41697 Mdot
.67935 .28103 Mdot
.46832 .47889 Mdot
.4223 .41051 Mdot
.48839 .19192 Mdot
.78182 .52542 Mdot
.77553 .45806 Mdot
.39998 .75344 Mdot
.40953 .47934 Mdot
.40492 .69908 Mdot
.73995 .60794 Mdot
.33429 .6014 Mdot
.69402 .42961 Mdot
.31809 .68859 Mdot
.72031 .73538 Mdot
.3778 .49611 Mdot
.31156 .33466 Mdot
.55075 .26644 Mdot
.30241 .74195 Mdot
.7107 .40302 Mdot
.52513 .215 Mdot
.628 .79082 Mdot
.30156 .42787 Mdot
.35215 .73242 Mdot
.60639 .88918 Mdot
.36314 .77218 Mdot
.77366 .39383 Mdot
.81569 .41059 Mdot
.61447 .81228 Mdot
.78514 .41705 Mdot
.26623 .29591 Mdot
.53198 .69812 Mdot
.36291 .67307 Mdot
.48541 .62865 Mdot
.81358 .34225 Mdot
.3239 .62633 Mdot
.81887 .40711 Mdot
.57116 .84693 Mdot
.71649 .61267 Mdot
.50759 .55329 Mdot
.39118 .35676 Mdot
.3863 .4211 Mdot
.3435 .59662 Mdot
.75774 .61409 Mdot
.52567 .70655 Mdot
.51375 .26943 Mdot
.38334 .40942 Mdot
.33505 .47561 Mdot
.74474 .51782 Mdot
.51014 .23774 Mdot
.70602 .42105 Mdot
.32765 .51349 Mdot
.54806 .47019 Mdot
.36975 .71815 Mdot
.64176 .60451 Mdot
.73194 .64728 Mdot
.24778 .34194 Mdot
.49498 .39242 Mdot
.41051 .37583 Mdot
.71304 .69225 Mdot
.38395 .7918 Mdot
.70927 .44218 Mdot
.77874 .33529 Mdot
.47327 .18972 Mdot
.37424 .59245 Mdot
.40993 .72541 Mdot
.24305 .33154 Mdot
.19587 .5986 Mdot
.80184 .44466 Mdot
.6564 .58868 Mdot
.2772 .68869 Mdot
.49735 .51404 Mdot
.83438 .53974 Mdot
.37631 .7619 Mdot
.45294 .76216 Mdot
.44136 .43944 Mdot
.65227 .69754 Mdot
.73169 .59798 Mdot
.28675 .60311 Mdot
.56739 .47409 Mdot
.46474 .1434 Mdot
.68348 .47974 Mdot
.69617 .20287 Mdot
.6128 .358 Mdot
.41564 .1888 Mdot
.20961 .56326 Mdot
.49928 .45053 Mdot
.57445 .47553 Mdot
.73241 .41673 Mdot
.69026 .32682 Mdot
.41845 .82009 Mdot
.19365 .39126 Mdot
.45599 .38327 Mdot
.30815 .72506 Mdot
.26611 .7113 Mdot
.74085 .66143 Mdot
.45588 .5633 Mdot
.35717 .77274 Mdot
.46674 .44291 Mdot
.23621 .38947 Mdot
.58417 .83375 Mdot
.7583 .45128 Mdot
.56273 .58217 Mdot
.35328 .70071 Mdot
.80721 .50665 Mdot
.77733 .66916 Mdot
.31927 .24257 Mdot
.75906 .4824 Mdot
.55286 .35707 Mdot
.44934 .49541 Mdot
.78094 .60338 Mdot
.28156 .6753 Mdot
.65163 .39702 Mdot
.36821 .73301 Mdot
.59947 .14783 Mdot
.75736 .32294 Mdot
.74325 .30481 Mdot
.31128 .69981 Mdot
.68066 .56841 Mdot
.70527 .29878 Mdot
.42296 .73976 Mdot
.75649 .43933 Mdot
.42638 .80969 Mdot
.38799 .73581 Mdot
.19947 .33763 Mdot
.49211 .77099 Mdot
.3771 .34601 Mdot
.73732 .58549 Mdot
.50739 .75984 Mdot
.54944 .35945 Mdot
.35671 .64721 Mdot
.6686 .44244 Mdot
.60375 .38431 Mdot
.70058 .42907 Mdot
.67201 .39871 Mdot
.46349 .76807 Mdot
.66442 .70978 Mdot
.72489 .46325 Mdot
.69414 .72515 Mdot
.60465 .51005 Mdot
.26343 .36858 Mdot
.34186 .31993 Mdot
.65866 .4502 Mdot
.44065 .39982 Mdot
.40376 .5833 Mdot
.55975 .45053 Mdot
.35222 .54682 Mdot
.64349 .2042 Mdot
.29157 .5538 Mdot
.66796 .56623 Mdot
.45952 .16657 Mdot
.63039 .51732 Mdot
.783 .29877 Mdot
.23304 .37256 Mdot
.69954 .61316 Mdot
.26347 .42248 Mdot
.24101 .46977 Mdot
.32112 .20393 Mdot
.75032 .55294 Mdot
.43758 .43397 Mdot
.60575 .54822 Mdot
.69958 .54681 Mdot
.52755 .27664 Mdot
.37901 .40718 Mdot
.59547 .62661 Mdot
.58952 .27867 Mdot
.38236 .57832 Mdot
.62798 .56167 Mdot
.42298 .3521 Mdot
.41668 .71122 Mdot
.84354 .46704 Mdot
.41399 .3841 Mdot
.54173 .14873 Mdot
.55404 .59779 Mdot
.60399 .77603 Mdot
.63616 .82257 Mdot
.34207 .22708 Mdot
.34889 .30026 Mdot
.20377 .64805 Mdot
.54668 .58533 Mdot
.73587 .47073 Mdot
.65549 .52354 Mdot
.43676 .7631 Mdot
.28649 .52102 Mdot
.28802 .65288 Mdot
.61725 .37034 Mdot
.28051 .32842 Mdot
.50151 .23969 Mdot
.66238 .5712 Mdot
.76665 .46971 Mdot
.50409 .79038 Mdot
.66609 .33929 Mdot
.47215 .44199 Mdot
.73903 .66032 Mdot
.65766 .71195 Mdot
.62562 .56002 Mdot
.7833 .3533 Mdot
.40247 .7672 Mdot
.83336 .59107 Mdot
.52803 .66899 Mdot
.39743 .44253 Mdot
.65588 .28799 Mdot
.7205 .43186 Mdot
.62399 .60249 Mdot
.65155 .80803 Mdot
.32529 .6677 Mdot
.64453 .27969 Mdot
.38738 .71332 Mdot
.41147 .66696 Mdot
.52799 .468 Mdot
.43907 .23417 Mdot
.2406 .28892 Mdot
.58069 .6232 Mdot
.34336 .24485 Mdot
.64046 .58398 Mdot
.56068 .25721 Mdot
.65632 .47742 Mdot
.39617 .31707 Mdot
.6661 .68957 Mdot
.37453 .27598 Mdot
.83468 .55906 Mdot
.64806 .81051 Mdot
.54719 .32554 Mdot
.52009 .29328 Mdot
.61468 .47668 Mdot
.5557 .63012 Mdot
.60212 .45211 Mdot
.4776 .65768 Mdot
.71673 .4887 Mdot
.36911 .20826 Mdot
.74613 .43277 Mdot
.42695 .66808 Mdot
.82802 .54051 Mdot
.82289 .60555 Mdot
.8335 .41697 Mdot
.25846 .68094 Mdot
.67014 .49761 Mdot
.75896 .2919 Mdot
.61356 .6328 Mdot
.73076 .72843 Mdot
.79841 .45155 Mdot
.50296 .87783 Mdot
.75259 .61784 Mdot
.64809 .43729 Mdot
.20037 .39132 Mdot
.69227 .35014 Mdot
.55271 .83869 Mdot
.45174 .4794 Mdot
.45306 .27959 Mdot
.55219 .84282 Mdot
.24553 .24971 Mdot
.61927 .58021 Mdot
.66299 .40093 Mdot
.47141 .51492 Mdot
.66403 .44755 Mdot
.34594 .43113 Mdot
.52535 .62104 Mdot
.51615 .32824 Mdot
.30279 .32932 Mdot
.37461 .7233 Mdot
.40201 .69767 Mdot
.34477 .43264 Mdot
.34875 .5939 Mdot
.39439 .71038 Mdot
.36479 .76072 Mdot
.74413 .64037 Mdot
.60138 .61955 Mdot
.55389 .61893 Mdot
.67418 .47409 Mdot
.27796 .5066 Mdot
.3897 .28553 Mdot
.50711 .64245 Mdot
.37249 .28053 Mdot
.67766 .33459 Mdot
.74636 .25552 Mdot
.42005 .30586 Mdot
.50133 .82425 Mdot
.66848 .48055 Mdot
.7155 .41237 Mdot
.68703 .73944 Mdot
.39151 .22052 Mdot
.35211 .45414 Mdot
.4567 .73116 Mdot
.81501 .54976 Mdot
.57891 .21961 Mdot
.46109 .79547 Mdot
.63983 .22664 Mdot
.57683 .38444 Mdot
.592 .58578 Mdot
.45739 .51472 Mdot
.44733 .20714 Mdot
.67891 .57541 Mdot
.65318 .43488 Mdot
.41966 .459 Mdot
.55911 .20834 Mdot
.50295 .84 Mdot
.49339 .79411 Mdot
.74783 .57361 Mdot
.80181 .55559 Mdot
.35798 .39123 Mdot
.41322 .76953 Mdot
.62597 .43149 Mdot
.37204 .45532 Mdot
.63619 .25048 Mdot
.84697 .50914 Mdot
.59621 .45826 Mdot
.30714 .62019 Mdot
.4485 .60681 Mdot
.62453 .65116 Mdot
.74351 .42364 Mdot
.2367 .51307 Mdot
.49476 .25757 Mdot
.68786 .54973 Mdot
.47556 .24744 Mdot
.34797 .48774 Mdot
.35404 .66257 Mdot
.60819 .54305 Mdot
.49339 .73013 Mdot
.31718 .54494 Mdot
.55591 .29053 Mdot
.43034 .62829 Mdot
.29533 .62853 Mdot
.25214 .66829 Mdot
.59547 .57954 Mdot
.77308 .51408 Mdot
.73076 .66797 Mdot
.45511 .80509 Mdot
.72959 .44619 Mdot
.80151 .43643 Mdot
.69556 .33137 Mdot
.68602 .67709 Mdot
.38533 .25101 Mdot
.45777 .65909 Mdot
.39954 .31771 Mdot
.63538 .55038 Mdot
.76789 .62119 Mdot
.6616 .72943 Mdot
.29632 .60564 Mdot
.51704 .4316 Mdot
.6685 .75484 Mdot
.50711 .41828 Mdot
.62042 .82488 Mdot
.69419 .35103 Mdot
.33789 .6807 Mdot
.6017 .31028 Mdot
.22066 .57344 Mdot
.25601 .31639 Mdot
.81088 .6116 Mdot
.23288 .3533 Mdot
.52371 .49183 Mdot
.34895 .2371 Mdot
.75054 .35091 Mdot
.56486 .84442 Mdot
.35059 .6854 Mdot
.60079 .45057 Mdot
.41005 .69802 Mdot
.55422 .31575 Mdot
.48906 .38205 Mdot
.38062 .32339 Mdot
.59841 .63522 Mdot
.48155 .3062 Mdot
.34794 .29071 Mdot
.46823 .6915 Mdot
.65472 .26081 Mdot
.80808 .55169 Mdot
.46329 .7557 Mdot
.47356 .45031 Mdot
.24786 .40108 Mdot
.34626 .6539 Mdot
.33321 .81768 Mdot
.71924 .22791 Mdot
.44754 .60635 Mdot
.40561 .50122 Mdot
.30086 .64881 Mdot
.439 .37622 Mdot
.57703 .66124 Mdot
.75039 .65283 Mdot
.6055 .36799 Mdot
.41029 .33522 Mdot
.54988 .20448 Mdot
.73734 .41192 Mdot
.31568 .5873 Mdot
.61705 .26117 Mdot
.76322 .26998 Mdot
.39113 .80129 Mdot
.73239 .43321 Mdot
.39096 .8494 Mdot
.42537 .22889 Mdot
.63601 .57797 Mdot
.61449 .7892 Mdot
.8257 .42687 Mdot
.30907 .68422 Mdot
.28286 .36726 Mdot
.78844 .39896 Mdot
.33357 .67266 Mdot
.40809 .74225 Mdot
.55008 .26591 Mdot
.48176 .25001 Mdot
.49624 .46919 Mdot
.24271 .46957 Mdot
.67375 .243 Mdot
.69493 .60163 Mdot
.80708 .53115 Mdot
.304 .32143 Mdot
.18502 .355 Mdot
.82569 .59736 Mdot
.35927 .62081 Mdot
.34028 .42292 Mdot
.60132 .79468 Mdot
.25235 .63144 Mdot
.47253 .73732 Mdot
.25558 .35304 Mdot
.63188 .73129 Mdot
.22507 .46177 Mdot
.32905 .27141 Mdot
.38967 .72125 Mdot
.50712 .75628 Mdot
.59319 .46099 Mdot
.71994 .67405 Mdot
.52603 .26593 Mdot
.32472 .70449 Mdot
.38255 .33629 Mdot
.2522 .6148 Mdot
.72024 .68715 Mdot
.65802 .76937 Mdot
.6149 .45308 Mdot
.26824 .23234 Mdot
.81194 .45256 Mdot
.38169 .23053 Mdot
.45256 .66148 Mdot
.84198 .54377 Mdot
.6209 .44238 Mdot
.8017 .42042 Mdot
.47645 .82257 Mdot
.37707 .31007 Mdot
.66238 .29956 Mdot
.46422 .66027 Mdot
.78451 .49153 Mdot
.70588 .64684 Mdot
.51419 .76054 Mdot
.28751 .33805 Mdot
.32047 .68674 Mdot
.32924 .40418 Mdot
.2704 .60369 Mdot
.5754 .5769 Mdot
.6331 .55297 Mdot
.79168 .32146 Mdot
.52994 .49683 Mdot
.4025 .59138 Mdot
.5627 .63101 Mdot
.20903 .37346 Mdot
.29923 .7652 Mdot
.54952 .64306 Mdot
.59205 .22753 Mdot
.39319 .74564 Mdot
.37809 .61837 Mdot
.68606 .58969 Mdot
.10111 .57186 Mdot
.66082 .81801 Mdot
.71344 .52415 Mdot
.52801 .71247 Mdot
.31509 .71454 Mdot
.83198 .43882 Mdot
.27279 .45987 Mdot
.33903 .31827 Mdot
.16317 .45866 Mdot
.25687 .64523 Mdot
.51453 .5621 Mdot
.48812 .83731 Mdot
.80402 .62226 Mdot
.29323 .32289 Mdot
.82771 .5514 Mdot
.42482 .57686 Mdot
.51619 .65521 Mdot
.18144 .68809 Mdot
.78289 .61214 Mdot
.41124 .62272 Mdot
.21068 .36469 Mdot
.67747 .57747 Mdot
.49191 .63863 Mdot
.58352 .26172 Mdot
.37271 .75511 Mdot
.39842 .7226 Mdot
.83973 .4715 Mdot
.67959 .57241 Mdot
.36392 .28501 Mdot
.59628 .37585 Mdot
.57119 .47563 Mdot
.54075 .6367 Mdot
.57513 .33604 Mdot
.37214 .61259 Mdot
.64275 .44823 Mdot
.54594 .34694 Mdot
.31479 .73772 Mdot
.55157 .87174 Mdot
.68823 .70387 Mdot
.53613 .35328 Mdot
.43446 .69594 Mdot
.49628 .77042 Mdot
.34555 .59656 Mdot
.39553 .55017 Mdot
.54043 .85074 Mdot
.76371 .75707 Mdot
.46013 .28393 Mdot
.5023 .69713 Mdot
.6094 .54569 Mdot
.60987 .61503 Mdot
.73235 .63132 Mdot
.61323 .39612 Mdot
.36662 .39955 Mdot
.52821 .55662 Mdot
.57591 .57593 Mdot
.61678 .36933 Mdot
.66826 .19241 Mdot
.52506 .59049 Mdot
.67027 .59599 Mdot
.74003 .71494 Mdot
.26478 .36603 Mdot
.58335 .7793 Mdot
.54211 .59045 Mdot
.69768 .29607 Mdot
.61034 .43943 Mdot
.71561 .47279 Mdot
.31248 .3323 Mdot
.8258 .49195 Mdot
.65575 .73428 Mdot
.7422 .57481 Mdot
.51134 .5907 Mdot
.2946 .5035 Mdot
.66758 .38557 Mdot
.79009 .3917 Mdot
.56448 .54809 Mdot
.75634 .70319 Mdot
.37088 .31312 Mdot
.49267 .30974 Mdot
.38507 .61429 Mdot
.81251 .37389 Mdot
.31573 .26982 Mdot
.72247 .62273 Mdot
.46267 .17972 Mdot
.49888 .20791 Mdot
.33406 .6042 Mdot
.37747 .35485 Mdot
.43263 .6766 Mdot
.66334 .5761 Mdot
.78492 .28721 Mdot
.78526 .38073 Mdot
.54321 .39673 Mdot
.47429 .26763 Mdot
.66381 .64477 Mdot
.59428 .47254 Mdot
.46349 .88019 Mdot
.31066 .46491 Mdot
.75654 .26163 Mdot
.44196 .76466 Mdot
.75057 .52604 Mdot
.67102 .42864 Mdot
.53721 .5429 Mdot
.39821 .37417 Mdot
.8314 .45541 Mdot
.57832 .57252 Mdot
.36023 .25969 Mdot
.5193 .56903 Mdot
.5177 .17681 Mdot
.53026 .40121 Mdot
.52787 .29277 Mdot
.53672 .29658 Mdot
.26718 .29698 Mdot
.70549 .73487 Mdot
.58554 .43322 Mdot
.42656 .85664 Mdot
.77235 .58351 Mdot
.80018 .60545 Mdot
.30979 .40131 Mdot
.31462 .23488 Mdot
.78029 .4567 Mdot
.71904 .45665 Mdot
.54456 .40291 Mdot
.37061 .53728 Mdot
.47238 .19398 Mdot
.37625 .62447 Mdot
.68133 .37268 Mdot
.56018 .31388 Mdot
.84236 .69462 Mdot
.36519 .62954 Mdot
.49558 .5223 Mdot
.40197 .23259 Mdot
.81072 .57949 Mdot
.30272 .49325 Mdot
.50821 .85148 Mdot
.3929 .50191 Mdot
.51724 .65618 Mdot
.65259 .72555 Mdot
.45347 .75661 Mdot
.50131 .19082 Mdot
.37929 .16522 Mdot
.3998 .80105 Mdot
.48455 .29081 Mdot
.54798 .4642 Mdot
.63666 .51246 Mdot
.71465 .50433 Mdot
.25524 .4403 Mdot
.46296 .84863 Mdot
.64542 .441 Mdot
.78119 .60473 Mdot
.30295 .22089 Mdot
.45498 .78079 Mdot
.83501 .44172 Mdot
.77607 .41855 Mdot
.68983 .47914 Mdot
.35356 .5917 Mdot
.26113 .57429 Mdot
.5176 .33097 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Tooooo`;o
0000Xoooool001cooooo00?o0000ooooooooool0Y?ooool2o`000:?ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0Toooool2o`00
0;Cooooo000Looooo`03o`000?oooooooooo08kooooo0_l00003ooooo`;o0000]?ooool001cooooo
00?o0000ooooooooool0R_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000Iooooo`;o0000
2_ooool2o`0000Gooooo0_l00028ooooo`007?ooool2o`0008_ooooo0_l00005ooooo`;o00006Ooo
ool2o`0000[ooooo0_l00005ooooo`;o0000R?ooool001cooooo00?o0000ooooooooool0Woooool2
o`000:Sooooo000Looooo`03o`000?oooooooooo09oooooo0_l0000Mooooo`;o0000ROooool001co
oooo00?o0000ooooooooool0Z_ooool2o`0000Cooooo0_l0000<ooooo`;o0000ROooool001cooooo
00?o0000ooooooooool0Moooool2o`0001cooooo0_l0000Cooooo`;o00001?ooool2o`0009Oooooo
000Looooo`03o`000?oooooooooo07Oooooo0_l000000ooooooo0000o`00000Fooooo`;o000000?o
ooooo`000?l00000@oooool2o`0006gooooo000Looooo`03o`000?oooooooooo07[ooooo0_l0000F
ooooo`;o00002oooool3o`0000kooooo0_l0000Xooooo`;o0000KOooool001cooooo00?o0000oooo
ooooool0V_ooool2o`000003ooooool0003o000000?o00003_ooool2o`0009Oooooo000Looooo`03
o`000?oooooooooo09[ooooo0_l000000ooooooo0000o`000005ooooo`;o0000Xoooool001cooooo
00?o0000ooooooooool0Toooool2o`0000;ooooo0_l0000;ooooo`;o00002Oooool2o`0009Sooooo
000Looooo`03o`000?oooooooooo09?ooooo1_l00003ooooo`;o00000_ooool2o`000003ooooool0
003o000000;o00000_ooool2o`0000Cooooo0ol00004ooooo`;o0000TOooool001cooooo00?o0000
ooooooooool0UOooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`_o000000?ooooo
o`000?l000000_ooool2o`000004ooooool0003o0000ooooo`Co0000Soooool001cooooo00?o0000
ooooooooool0Poooool2o`0000Kooooo0_l00009ooooo`;o000000?oooooo`000?l000001oooool2
o`0000?ooooo0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o000000;o000000?ooooo
o`000?l000005oooool2o`0007Kooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ
8B44ooooo`Go00001_ooool00ol0003oooooooooo`23ooooo`;o00000_ooool2o`0000;ooooo0_l0
0003ooooo`?o00000oooool2o`0000?ooooo0_l00002ooooo`;o00002_ooool7o`0000?ooooo0_l0
000Gooooo`;o000000?oooooo`000?l000000_ooool2o`0007;ooooo00001_ooooooMgMgoiRHV?oo
ooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`1mooooo`;o00002?ooool2o`0000Kooooo1?l00003ooooo`;o00000oooool2o`0000;o
oooo0_l00006ooooo`;o00000_ooool5o`0001kooooo0_l00005ooooo`;o0000L_ooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`00
0?oooooooooo07gooooo0_l0000>ooooo`Ko00000oooool2o`0000oooooo0_l00004ooooo`?o0000
2oooool2o`00017ooooo0_l0001iooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooooooo
o`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0001Yooooo`;o00005_ooool3o`0000Wooooo0_l0
0002ooooo`;o00007Oooool2o`0000Cooooo0_l00003ooooo`Co00003?ooool2o`000004ooooool0
003o0000ooooo`;o00002oooool2o`0006Wooooo00000ooooooo0000ooooo`02ooooo`03o`000?oo
oooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`1Uooooo`;o00000_oo
ool2o`0001Kooooo0ol00005ooooo`;o00001?ooool2o`0001kooooo0ol00003ooooo`?o00001Ooo
ool2o`0000cooooo1?l00002ooooo`;o00002oooool2o`0006Wooooo00000ooooooo410@ooooo`02
ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1U
ooooo`;o00003Oooool2o`0000;ooooo1ol00002ooooo`;o00000_ooool2o`0000;ooooo0_l00003
ooooo`?o00003Oooool2o`0000gooooo1?l000001?oooooo0000o`000?ooool4o`0001Cooooo0_l0
0005ooooo`;o0000Loooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zj
oooooonHV9So410@00Kooooo00?o0000ooooooooool0M?ooool?o`0000;ooooo1_l00003ooooo`Co
00003?ooool2o`0000gooooo0_l00003ooooo`;o00000oooool2o`0001_ooooo0_l0001cooooo`00
00Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`1cooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000004
o`0000;ooooo0_l00002ooooo`?o00000_ooool6o`0001Gooooo0_l00002ooooo`Co00009_ooool2
o`0007;ooooo000Looooo`03o`000?oooooooooo067ooooo0_l0000@ooooo`;o00000oooool2o`00
00Cooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo1?l00008ooooo`;o00003?ooool3o`00
0004ooooool0003o0000o`0000;ooooo0_l00007ooooo`;o00006oooool2o`0007;ooooo000Loooo
o`03o`000?oooooooooo05oooooo1?l0000Gooooo`?o00000_ooool2o`0001Oooooo0_l0000<oooo
o`;o00000_ooool2o`0000?ooooo0_l00007ooooo`;o000000?oooooo`000?l00000S?ooool001co
oooo00?o0000ooooooooool0Goooool2o`0001Wooooo0ol00002ooooo`;o00004_ooool2o`0000?o
oooo0_l0000Nooooo`;o000000Coooooo`000?l0003o00001?ooool2o`0000Wooooo0_l0001joooo
o`007?ooool00ol0003oooooooooo`1[ooooo`;o00003oooool2o`0001Gooooo0_l00003ooooo`;o
00008_ooool3o`0000?ooooo0_l00008ooooo`?o00002oooool2o`0000Wooooo0_l0001Rooooo`00
7?ooool00ol0003oooooooooo`1[ooooo`;o00001oooool2o`0000;ooooo0_l00002ooooo`Co0000
1_ooool3o`0001cooooo0_l00008ooooo`;o000000Coooooo`000?l0003ooooo0ol00005ooooo`Co
00001_ooool3o`0000;ooooo0_l0000;ooooo`?o00002Oooool5o`0005oooooo000Looooo`03o`00
0?oooooooooo05?ooooo0_l0000Cooooo`;o00002_ooool6o`0000Cooooo0ol00005ooooo`?o0000
3oooool2o`0000_ooooo0_l00008ooooo`;o000000Coooooo`000?l0003ooooo0ol000000ooooooo
0000o`000004ooooo`;o00001_ooool3o`000003ooooool0003o000000cooooo0_l0000;ooooo`Co
0000Goooool001cooooo00?o0000ooooooooool0Doooool2o`0000gooooo0_l00004ooooo`;o0000
3?ooool2o`0000Kooooo0ol0000:ooooo`;o00002_ooool3o`0001cooooo0_l000000ooooooo0000
o`000002ooooo`;o000000?oooooo`000?l000000_l00007ooooo`?o00006Oooool2o`00063ooooo
000Looooo`03o`000?oooooooooo06;ooooo0_l0000:ooooo`;o00005Oooool2o`0000Cooooo0_l0
000:ooooo`;o00001_ooool2o`000003ooooool0003o000001?ooooo0_l00004ooooo`;o000000?o
ooooo`000?l000001Ol00005ooooo`;o00003oooool2o`0006[ooooo000Looooo`03o`000?oooooo
oooo06Cooooo0_l00003ooooo`;o00000oooool2o`0000Wooooo0_l0000:ooooo`;o00006?ooool2
o`000003ooooool0003o000001?ooooo0_l0000;ooooo`?o00000_ooool4o`0000Sooooo1?l00004
ooooo`;o0000J_ooool001cooooo00?o0000ooooooooool0I?ooool2o`0000?ooooo0_l000000ooo
oooo0000o`00000;ooooo`;o00001oooool2o`0000Cooooo0_l00002ooooo`?o00005_ooool2o`00
00?ooooo0_l00003ooooo`;o00006?ooool5o`0000Oooooo1?l0000Cooooo`;o0000Foooool001co
oooo00?o0000ooooooooool0D_ooool2o`0001Sooooo0_l0000:ooooo`?o000000?oooooo`000?l0
00001?ooool2o`0000Cooooo0ol000001?oooooo0000o`000?l00008ooooo`;o00003?ooool4o`00
0004ooooool0003o0000ooooo`Co00002oooool2o`0000kooooo0_l0000Nooooo`;o0000Foooool0
01cooooo0_l0001=ooooo`;o00001?ooool2o`0001gooooo0_l00003ooooo`So00002oooool4o`00
00[ooooo1?l000000ooooooo0000o`000009ooooo`;o00001?ooool2o`0000cooooo0ol00008oooo
o`;o00000oooool4o`0007[ooooo000Looooo`03o`000?oooooooooo04cooooo0_l0000@ooooo`;o
00001Oooool2o`000003ooooool0003o000000Oooooo0_l00003ooooo`;o000000?oooooo`000?l0
00000_l0000<ooooo`Co00003?ooool2o`000003ooooool0003o000001gooooo0_l00009ooooo`Co
000000?oooooo`000?l000000_l000000ooooooo0000o`000007ooooo`;o0000K_ooool001cooooo
00?o0000ooooooooool0G_ooool2o`0000Gooooo0_l000001?oooooo0000o`000?l00005ooooo`Co
00001_ooool2o`00027ooooo0_l0000Cooooo`;o00003_ooool2o`0000Cooooo0_l00006ooooo`;o
00001oooool2o`0001Cooooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o0000
0oooool2o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000
o`000003ooooo`?o000000?oooooo`000?l000004?ooool2o`0000Cooooo1?l00003ooooo`;o0000
00?oooooo`000?l000004?ooool3o`0000Gooooo0_l00006ooooo`;o000000?oooooo`000?l00000
2Oooool3o`00017ooooo0_l00009ooooo`;o000000?oooooo`000?l000000_ooool2o`00057ooooo
000Looooo`03o`000?oooooooooo06;ooooo0ol00008ooooo`;o00000_ooool3o`000003ooooool0
003o000000Cooooo0_l000000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l000001_oo
ool2o`0000?ooooo1Ol00004ooooo`Ko00000_ooool2o`0000[ooooo0ol00002ooooo`;o000000?o
ooooo`000?l000002Oooool2o`0000Sooooo1?l00002ooooo`;o00003Oooool2o`0000cooooo0_l0
0002ooooo`;o0000DOooool001cooooo00?o0000ooooooooool0H_ooool4o`0001Gooooo0_l00008
ooooo`;o000000?oooooo`000?l000002oooool3o`0000Kooooo2ol00006ooooo`;o000000?ooooo
o`000?l000000oooool2o`000003ooooool0003o000000cooooo0_l00005ooooo`;o00001?ooool2
o`0000Wooooo0_l0001Wooooo`007?ooool00ol0003oooooooooo`1Gooooo`;o00002_ooool3o`00
01;ooooo0_l000001?oooooo0000o`000?ooool2o`00013ooooo0ol00002ooooo`?o00001oooool7
o`000003ooooool0003o000000Kooooo0_l0000Gooooo`;o000000Coooooo`000?l0003o00002ooo
ool2o`000003ooooool0003o000000;ooooo1?l0000@ooooo`;o0000Doooool001cooooo00?o0000
ooooooooool0Eoooool2o`0000Gooooo0_l00003ooooo`;o00000_ooool2o`0000Gooooo0_l00008
ooooo`;o00001?ooool4o`0000kooooo0ol00002ooooo`;o00002oooool3o`0000Cooooo0_l00006
ooooo`;o00005Oooool2o`000004ooooool0003o0000o`0000Oooooo0ol000000ooooooo0000o`00
0003o`0000Cooooo0_l0000@ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0C?ooool2
o`00013ooooo0ol00006ooooo`Co00000oooool2o`0000Kooooo0_l00006ooooo`Co00004oooool2
o`0000?ooooo0_l00008ooooo`;o00000_ooool3o`0000Kooooo1_l0000Aooooo`;o000000?ooooo
o`000?l000002?ooool3o`0000;ooooo0ol00005ooooo`;o00001?ooool2o`0005oooooo000Loooo
o`03o`000?oooooooooo04;ooooo0_l00008ooooo`;o00003_ooool2o`000003ooooool0003o0000
00Sooooo0_l0000;ooooo`;o00001_ooool5o`0000?ooooo1?l00005ooooo`;o00002Oooool2o`00
00Kooooo1?l000001?oooooo0000o`000?l00009ooooo`Co00001Oooool2o`0000gooooo0_l00000
1?oooooo0000o`000?ooool2o`0000oooooo0_l00004ooooo`;o00002_ooool2o`0000cooooo0_l0
0015ooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00004Oooool2o`0000?ooooo1Ol0000F
ooooo`;o00000_ooool2o`0000Kooooo2Ol00005ooooo`Co00003oooool2o`0000?ooooo0ol0000B
ooooo`;o00004?ooool2o`000003ooooool0003o000000Kooooo0_l00007ooooo`;o00004?ooool2
o`0000cooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`1Eooooo`;o00000oooool2o`00
0003ooooool0003o000000Kooooo0_l0000;ooooo`Ko000000?oooooo`000?l000000_l00006oooo
o`?o000000?oooooo`000?l000002?ooool3o`0000Gooooo0_l0000<ooooo`Ko00005Oooool2o`00
00Oooooo0_l00008ooooo`;o00000_ooool2o`0000[ooooo0_l0001Rooooo`007?ooool00ol0003o
ooooooooo`18ooooo`Co00003_ooool2o`0000Wooooo0_l00003ooooo`;o00001_ooool6o`0000?o
oooo0_l0000:ooooo`;o00002Oooool2o`0000Gooooo0_l0000>ooooo`Ko00000oooool2o`0000;o
oooo0_l0000:ooooo`;o00001oooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`00
00;ooooo0_l0000:ooooo`Co00004_ooool2o`0004cooooo000Looooo`03o`000?oooooooooo04So
oooo1?l0000>ooooo`;o00003_ooool2o`000003ooooool0003o000001Sooooo0_l0000;ooooo`;o
00001?ooool2o`00013ooooo0ol00002ooooo`?o00000_ooool2o`0000gooooo0_l00006ooooo`?o
000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00006ooooo`;o00001?ooool2o`0000[o
oooo0_l00005ooooo`?o0000C?ooool001cooooo00?o0000ooooooooool0KOooool2o`0002Gooooo
0_l000001?oooooo0000o`000?ooool2o`0000Cooooo0_l00003ooooo`;o000000?oooooo`000?l0
00000_ooool3o`0000;ooooo0_l0000>ooooo`;o00000_ooool2o`0000Kooooo0_l00006ooooo`;o
00000_ooool2o`0000Kooooo0_l0000@ooooo`;o00001Oooool2o`0004gooooo000Looooo`03o`00
0?oooooooooo04Gooooo0_l0000<ooooo`;o00000oooool2o`0001Gooooo0_l0000Vooooo`;o0000
1_ooool3o`0000?ooooo0_l000001?oooooo0000o`000?ooool4o`000004ooooool0003o0000o`00
00Oooooo0_l00005ooooo`;o00002_ooool2o`0000Cooooo1Ol000000ooooooo0000o`000004oooo
o`?o00006oooool2o`0004[ooooo000Looooo`;o0000A_ooool2o`0000cooooo0_l00003ooooo`;o
00004_ooool5o`0000Wooooo1?l0000Looooo`;o000000?oooooo`000?l000000_l00002ooooo`;o
00001_ooool4o`000004ooooool0003o0000o`0000Oooooo1?l00006ooooo`;o00001_ooool2o`00
00Gooooo0_l000000ooooooo0000o`000007ooooo`Go00003oooool2o`0000Kooooo1?l0001:oooo
o`007?ooool00ol0003oooooooooo`1<ooooo`;o00000oooool4o`0001Oooooo1?l0000:ooooo`Go
00006oooool2o`000003ooooool0003o000000Cooooo0_l00004ooooo`Go00003_ooool2o`0000Ko
oooo0_l00006ooooo`;o00001Oooool2o`0000;ooooo0_l00008ooooo`?o00003oooool2o`0000Ko
oooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00000_ooool2o`000003oooo
ool0003o000000?ooooo1?l0000Nooooo`;o00002?ooool2o`0000Kooooo0_l0000Booooo`;o0000
2oooool2o`000003ooooool0003o000000;o00005oooool2o`00017ooooo0_l00009ooooo`;o0000
1_ooool2o`0000;ooooo0_l0000:ooooo`;o0000COooool001cooooo00?o0000ooooooooool0AOoo
ool2o`0000;ooooo0_l0000;ooooo`;o00006oooool2o`0000;ooooo0_l0000<ooooo`;o00004_oo
ool2o`000003ooooool0003o000000Sooooo0ol000001?oooooo0000o`000?l0000<ooooo`;o0000
1Oooool2o`000004ooooool0003o0000o`0001Cooooo0_l00003ooooo`;o000000?oooooo`000?l0
00001_ooool2o`0000;ooooo0_l0000:ooooo`;o0000COooool001cooooo00?o0000ooooooooool0
Coooool2o`0000Gooooo0_l0000?ooooo`;o00003?ooool4o`0000cooooo0_l0000Eooooo`;o0000
1?ooool2o`0000;ooooo1?l000000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l00000
1?l000000ooooooo0000o`000004o`000004ooooool0003o0000o`0000Oooooo0_l0000;ooooo`;o
00000oooool2o`0000[ooooo0_l00005ooooo`;o0000EOooool001cooooo00?o0000ooooooooool0
B_ooool2o`0000?ooooo0_l0000Fooooo`;o00003?ooool2o`0000Kooooo0_l00008ooooo`;o0000
6Oooool3o`000003ooooool0003o000000;o00001_oooolAo`0000?ooooo1?l00005ooooo`;o0000
00?oooooo`000?l000006Oooool4o`0000?ooooo0_l0001Eooooo`007?ooool00ol0003ooooooooo
o`1:ooooo`;o00000oooool2o`0001Oooooo1Ol00002ooooo`;o00003?ooool3o`0000Oooooo0_l0
0006ooooo`;o00004_ooool2o`000003ooooool0003o000000Sooooo0_l00002ooooo`oo000000?o
ooooo`000?l000000_l00008ooooo`;o00006Oooool4o`0005[ooooo000Looooo`03o`000?oooooo
oooo05cooooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool5o`0000;ooooo0_l0000=
ooooo`;o00000_ooool2o`0000_ooooo0_l0000>ooooo`;o00001?ooool2o`0000[ooooo5Ol0000G
ooooo`;o00001oooool2o`0000;ooooo0_l00002ooooo`?o000000?oooooo`000?l000002Oooool2
o`0004[ooooo000Looooo`03o`000?oooooooooo05cooooo0_l000000ooooooo0000o`000004o`00
01?ooooo0_l00008ooooo`;o00002Oooool2o`0000gooooo1Ol00004ooooo`Co00001Oooool2o`00
0003ooooool0003o000001Co00003Oooool2o`000003ooooool0003o000000Cooooo0_l00007oooo
o`;o00000_ooool2o`0000;ooooo0ol000000ooooooo0000o`000009ooooo`;o0000B_ooool001co
oooo00?o0000ooooooooool0Eoooool2o`0000Kooooo1?l000000ooooooo0000o`00000Booooo`;o
00004oooool2o`0000gooooo1?l00004ooooo`Go00001?ooool3o`000003ooooool0003o000001Ko
00002oooool2o`000003ooooool0003o000000?ooooo0ol0001Zooooo`007?ooool00ol0003ooooo
ooooo`17ooooo`;o00000_ooool2o`0000[ooooo0_l00006ooooo`Oo0000>_ooool2o`0000;ooooo
0_l00007ooooo`;o00000_oooolIo`0000Sooooo0_l00008ooooo`Co000000?oooooo`000?l00000
1?ooool2o`00063ooooo000Looooo`03o`000?oooooooooo04Oooooo0_l000000ooooooo0000o`00
0002o`0000Kooooo0_l00005ooooo`;o00000_ooool5o`0001kooooo0_l0000:ooooo`;o00000ooo
ool2o`0000_ooooo0_l00002ooooo`;o00001oooool2o`0000?ooooo6?l00007ooooo`?o00001?oo
ool2o`0000?ooooo0ol000000ooooooo0000o`000004ooooo`;o00004?ooool2o`0004kooooo000L
ooooo`03o`000?oooooooooo03gooooo0_l0000;ooooo`Co00001_ooool2o`0000Cooooo0ol00002
ooooo`Co00005_ooool3o`0000Kooooo0_l0000:ooooo`;o00000oooool2o`0000;ooooo1?l00004
ooooo`?o000000Coooooo`000?l0003o00001?ooool2o`000004ooooool0003o0000ooooo`;o0000
00?oooooo`000?l000005Ol00007ooooo`Co00000oooool2o`0000?ooooo0_l0000;ooooo`;o0000
3Oooool6o`0004[ooooo000Looooo`03o`000?oooooooooo03gooooo0_l00008ooooo`;o00001ooo
ool2o`0000Sooooo1?l000000ooooooo0000o`00000;ooooo`;o00001Oooool2o`0000Cooooo0ol0
00000ooooooo0000o`000006ooooo`;o00001oooool2o`000003ooooool0003o000000Cooooo1?l0
0004ooooo`?o000000?oooooo`000?l000001Oooool2o`0000Cooooo6ol00008ooooo`Co00004ooo
ool2o`0000oooooo1?l0001:ooooo`007?ooool00ol0003oooooooooo`10ooooo`Co00000oooool2
o`0000Cooooo0_l000000ooooooo0000o`00000:ooooo`;o00003_ooool2o`0000Gooooo0_l00004
ooooo`?o000000?oooooo`000?l000001_ooool2o`0000Oooooo0_l000000ooooooo0000o`00000;
ooooo`Co000000?oooooo`000?l000001?ooool2o`0000Cooooo7Ol00009ooooo`;o00006?ooool2
o`0000_ooooo0_l00006ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0>?ooool2o`00
00Kooooo1?l00007ooooo`Co00000_ooool2o`0000;ooooo1?l00003ooooo`;o00003Oooool2o`00
00;ooooo0_l00006ooooo`;o000000?oooooo`000?l000008_ooool2o`0000;ooooo1?l00003oooo
o`;o00000ooooolEo`000003ooooool0003o000000Ko00001oooool2o`0000Kooooo0_l00004oooo
o`;o00003?ooool2o`0000Cooooo0_l0000=ooooo`;o000000?oooooo`000?l00000@?ooool001co
oooo0_l0000iooooo`;o00002oooool2o`0000Cooooo0_l00004ooooo`?o000000?oooooo`000?l0
00000_l00003ooooo`;o00001oooool2o`0000Cooooo0_l00002ooooo`;o00001_ooool2o`0001Ko
oooo0_l0000=ooooo`?o000000?oooooo`000?l000000_l00006oooooaco000000?oooooo`000?l0
00001_ooool4o`0000Kooooo1?l000001?oooooo0000o`000?l00004ooooo`;o00001_ooool3o`00
00?ooooo0_l00006ooooo`;o00002?ooool2o`00043ooooo000Looooo`03o`000?oooooooooo03go
oooo0_l00006ooooo`;o000000?oooooo`000?l000001Oooool2o`000003ooooool0003o000000ko
oooo0_l000000ooooooo0000o`00000Booooo`;o00002oooool3o`0000?ooooo0_l000000ooooooo
0000o`00000>ooooo`;o000000Coooooo`000?l0003o00001Oooool4o`000003ooooool0003o0000
01[o00001_ooool2o`0000?ooooo0_l00005ooooo`Go00001Oooool2o`0000Kooooo0ol00009oooo
o`Co0000B_ooool001cooooo00?o0000ooooooooool0>?ooool2o`0000?ooooo0_l00006ooooo`;o
000000?oooooo`000?l000001Oooool2o`00017ooooo0_l0000>ooooo`_o00002Oooool3o`0000?o
oooo0_l00004ooooo`;o00002?ooool2o`0000;ooooo1Ol00005ooooo`;o00001?ooool8o`000003
ooooool0003o0000013o00002oooool2o`0000Kooooo0_l0000>ooooo`;o00002oooool2o`0000;o
oooo0_l00018ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00001oooool2o`0000Gooooo
0_l0000Sooooo`;o000000?oooooo`000?l000001ol000001?oooooo0000o`000?l0000Eooooo`;o
00000_ooool2o`0000?ooooo0ol000000ooooooo0000o`000003o`0000_ooooo2ol000000ooooooo
0000o`00000>o`0000[ooooo0_l0000Gooooo`Co00001Oooool2o`0000Kooooo0_l00018ooooo`00
7?ooool00ol0003oooooooooo`11ooooo`;o00001Oooool2o`0000Cooooo0_l00004ooooo`;o0000
2Oooool2o`0000[ooooo5Ol000000ooooooo0000o`000002o`0000Cooooo0_l0000;ooooo`Co0000
00Goooooo`000?l0003o0000ooooo`03o`0000cooooo3?l000000ooooooo0000o`00000=o`0000_o
oooo0_l0000Eooooo`;o00000_ooool2o`0000Gooooo0_l0000;ooooo`;o0000@oooool001cooooo
00?o0000ooooooooool0@Oooool2o`0000_ooooo0_l00002ooooo`Co00000oooool2o`0000Cooooo
1?l00006ooooob;o00003Oooool2o`000003ooooool0003o000000Go00003?ooool2o`000003oooo
ool0003o000001Ko00008oooool2o`0000Gooooo0_l0000?ooooo`;o0000@oooool001cooooo00?o
0000ooooooooool0@Oooool2o`000003ooooool0003o000000Sooooo0_l00002ooooo`;o00001?oo
ool3o`000003ooooool0003o000000?ooooo1?l00004ooooob7o00000_ooool2o`0000Kooooo0_l0
0007ooooo`Go00003ooooolFo`00017ooooo0_l0000Dooooo`Co000000?oooooo`000?l00000E?oo
ool001cooooo00?o0000ooooooooool0A?ooool2o`0000Kooooo0_l00003ooooo`?o00001?ooool2
o`0000;ooooo0_l00005ooooo`;o00000_oooolTo`000004ooooool0003o0000o`0000Gooooo0_l0
0005ooooo`Go00002oooool2o`0000Cooooo5_l0000Aooooo`;o00005?ooool5o`0005Kooooo000L
ooooo`03o`000?oooooooooo043ooooo0_l00006ooooo`;o00000_ooool2o`0000?ooooo0_l0000:
ooooo`;o00002?ooool4o`0000;ooooo9Ol00005ooooo`Wo00002Oooool4o`0000;ooooo6?l0000C
ooooo`?o00002_ooool2o`0000Sooooo0_l0000Aooooo`;o0000@oooool001cooooo00?o0000oooo
ooooool0@?ooool2o`0000Kooooo0_l00009ooooo`;o00002?ooool2o`0000Sooooo1?l00002oooo
oaWo000000?oooooo`000?l000002ol000000ooooooo0000o`000009o`0000Sooooo0ol00004oooo
o`;o000000?oooooo`000?l000004Ol0000Eooooo`?o00002_ooool2o`0001Kooooo0_l00003oooo
o`?o0000@_ooool001cooooo00?o0000ooooooooool0Doooool2o`0000kooooo0ol000000ooooooo
0000o`00000Lo`000003ooooool0003o000000So000000?oooooo`000?l000002_l0000;ooooo`;o
00001ooooolCo`000003ooooool0003o0000017ooooo0_l0000=ooooo`Co00002?ooool2o`0000Ko
oooo0ol000000ooooooo0000o`000004ooooo`?o0000@Oooool001cooooo00?o0000ooooooooool0
?oooool4o`0000[ooooo0_l0000@ooooo`;o000000?oooooo`000?l00000<ol00003ooooo`?o0000
0oooool2o`0000Cooooo1?l00007oooooa;o00000_ooool2o`0000Kooooo0_l00006ooooo`;o0000
00?oooooo`000?l000002oooool2o`0000;ooooo0_l00008ooooo`;o00001_ooool3o`0000Sooooo
0_l00011ooooo`007?ooool00ol0003oooooooooo`0oooooo`Co00000_ooool2o`0000Kooooo0_l0
000@ooooo`;o000000Goooooo`000?l0003o0000ooooo`0:o`000003ooooool0003o000002Go0000
0_ooool3o`0000?ooooo0_l00004ooooo`Co00002Oooool7o`000003ooooool0003o000000Go0000
2?ooool5o`0000Kooooo0_l0000>ooooo`;o00002oooool2o`0005Gooooo000Looooo`03o`000?oo
oooooooo04Gooooo0_l00002ooooo`;o00000_ooool2o`0000Sooooo0_l00009ooooo`ko000000?o
ooooo`000?l000004ol000000ooooooo0000o`00000Co`0000_ooooo1?l00008ooooo`;o00000ooo
ool2o`000003ooooool0003o000000Go00000oooool2o`0000?ooooo0ol000000ooooooo0000o`00
0005ooooo`?o00005?ooool2o`0000Cooooo0_l0001Eooooo`0000Koooooonk^k_lb<S;o0000oc8b
<_o^k^h5ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0
>oooool4o`0000Kooooo0_l00002ooooo`?o00002Oooool4o`0000Gooooo0_l00002ooooo`;o0000
00?oooooo`000?l00000:Ol000000ooooooo0000o`000009o`000003ooooool0003o000000Gooooo
0_l00003ooooo`;o00001_ooool2o`0000[ooooo1?l00004ooooo`;o00001?ooool2o`000003oooo
ool0003o000000;o00000oooool3o`0001Cooooo0_l00009ooooo`;o00001?ooool2o`0004[ooooo
00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0>oooool4o`0000Wooooo1?l00009ooooo`;o00001oooool2o`000003
ooooool0003o000000?o00000_ooool2o`0000?ooooo4?l000000ooooooo0000o`00000=o`000004
ooooool0003o0000ooooo`So000000Coooooo`000?l0003ooooo0_l00005ooooo`;o00000_ooool2
o`0000?ooooo0_l00002ooooo`;o00000_ooool3o`0000;ooooo0_l00007ooooo`?o00002_ooool2
o`0000?ooooo0ol0000Dooooo`;o00002Oooool2o`0000Cooooo0_l0001:ooooo`0000?ooooooa0@
4?ooool00_ooool00ol@413oooooooooo`09ooooo`Go00001_ooool00ol0003oooooooooo`15oooo
o`;o000000?oooooo`000?l000002oooool2o`0000[ooooo1ol00007ooooobSo00004Oooool2o`00
00?ooooo0_l00006ooooo`?o00000_ooool2o`0000Oooooo0ol0000:ooooo`;o00001?ooool2o`00
00kooooo0_l0000Dooooo`;o00000oooool2o`0004Kooooo00000ooooooo0000ooooo`02ooooo`03
o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`0004Gooooo0_l00006oooo
o`;o00004Oooool5o`000003ooooool0003o000000[ooooo9Ol00008ooooo`;o000000?oooooo`00
0?l000001?ooool2o`0000?ooooo1?l0000:ooooo`;o00001Oooool2o`0000Cooooo0_l00004oooo
o`;o00000_ooool6o`0000_ooooo0_l000000ooooooo0000o`000002o`00017ooooo0ol00003oooo
o`;o0000A_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?oMgMgo
EEEEooooool00007ooooo`03o`000?oooooooooo03_ooooo0_l0000@ooooo`;o00004Oooool3o`00
00Cooooo0_l00004ooooo`;o00001_oooolQo`0000Oooooo1?l000000ooooooo0000o`000004oooo
o`;o00000oooool4o`0000[ooooo0_l00004ooooo`?o00001?ooool2o`0000;ooooo1?l00002oooo
o`Go00003?ooool2o`000003ooooool0003o000000;o00002Oooool2o`0000Kooooo0_l0001<oooo
o`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oo
oooo00?o0000ooooooooool0=Oooool2o`0000Cooooo0_l0000Sooooo`;o00001Oooool2o`0000Co
oooo0_l00006ooooo`Wo000000?oooooo`000?l000004ol00004ooooo`;o00000oooool2o`0000?o
oooo0_l0000=ooooo`;o00001_ooool2o`0000Kooooo1_l00005ooooo`?o00002?ooool2o`0000?o
oooo0_l00004ooooo`;o00003oooool2o`00017ooooo0_l0000Booooo`;o0000;Oooool00006oooo
oomgMgOoV9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo
03Gooooo0_l0000?ooooo`;o00002?ooool2o`0000Sooooo0_l00004ooooo`;o00001oooool2o`00
00cooooo7Ol00004ooooo`;o00002?ooool2o`0000Cooooo0_l00007ooooo`;o00001_ooool2o`00
0003ooooool0003o000000Gooooo1?l0000?ooooo`?o00000oooool4o`0000;ooooo0_l000000ooo
oooo0000o`000005ooooo`;o00004?ooool2o`0000Gooooo0ol0000Booooo`;o0000;Oooool00006
ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooo
oooo04Kooooo0_l00002ooooo`;o00001?ooool2o`0000Sooooo0_l0000=ooooo`;o00003?ooool2
o`000003ooooool0003o000001Co00006?ooool2o`0000Kooooo0_l0000:ooooo`;o00002?ooool2
o`0000Gooooo0_l00007ooooo`;o00000oooool2o`000003ooooool0003o000000Gooooo0_l00005
ooooo`?o00003oooool2o`0000Gooooo1Ol0000@ooooo`;o0000;Oooool001cooooo00?o0000oooo
ooooool0=Oooool2o`0000_ooooo0_l00006ooooo`?o00000oooool2o`0000kooooo0_l0000@oooo
o`;o00000oooool2o`0000Oooooo2ol000000ooooooo0000o`000002o`0000kooooo0_l000000ooo
oooo0000o`00000=ooooo`;o00000_ooool4o`0000cooooo1_l00003ooooo`;o00003?ooool2o`00
00Cooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000000Wooooo0_l000000ooo
oooo0000o`000004ooooo`;o000000?oooooo`000?l000001?l000001?oooooo0000o`000?l0000<
ooooo`;o0000;Oooool001cooooo00?o0000ooooooooool0=Oooool2o`0000_ooooo0_l00006oooo
o`?o00000oooool2o`0000gooooo0ol0000@ooooo`Ko00000_ooool2o`0000Kooooo1ol00003oooo
o`;o00002?ooool2o`0000Kooooo0_l000000ooooooo0000o`000004o`0000Kooooo0_l00005oooo
o`Co00003?ooool2o`0000;ooooo0_l0000<ooooo`;o00000oooool2o`0000Cooooo1Ol00004oooo
o`;o00003?ooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000005oooo
o`Go00002_ooool2o`0002gooooo000Looooo`03o`000?oooooooooo043ooooo0_l00008ooooo`;o
00001_ooool2o`0000_ooooo0ol00009ooooo`;o00001oooool5o`000003ooooool0003o000000;o
00001_ooool2o`0000Kooooo0_l00008ooooo`;o00002oooool4o`0000Kooooo0_l0000Wooooo`;o
00000oooool2o`0000Cooooo1Ol00003ooooo`;o00000oooool2o`0000?ooooo0_l00007ooooo`;o
00000oooool2o`000003ooooool0003o000000Sooooo0_l0000:ooooo`;o0000;Oooool001cooooo
00?o0000ooooooooool0@?ooool2o`0000Cooooo0_l0000:ooooo`;o00002_ooool2o`0000Kooooo
0ol00002ooooo`;o00002_ooool2o`0000?ooooo0_l0000Cooooo`;o00002?ooool2o`0000Wooooo
0_l00005ooooo`Co00006_ooool2o`000003ooooool0003o0000013ooooo0ol00006ooooo`;o0000
0oooool2o`0000?ooooo0_l00007ooooo`;o00002_ooool2o`0003oooooo000Looooo`03o`000?oo
oooooooo02;ooooo0_l0000<ooooo`;o00005?ooool2o`0000Kooooo0_l0000>ooooo`;o00001Ooo
ool4o`0000kooooo1?l000000ooooooo0000o`00000Cooooo`;o00002?ooool2o`0000Wooooo0_l0
0007ooooo`;o00001Oooool2o`0001?ooooo0_l000000ooooooo0000o`000006ooooo`;o00000_oo
ool2o`0000;ooooo1?l0000=ooooo`;o00005oooool2o`0003oooooo000Looooo`03o`000?oooooo
oooo02;ooooo0_l0000<ooooo`;o00007?ooool2o`0000gooooo0_l00006ooooo`;o00001Oooool3
o`0000[ooooo0_l000000ooooooo0000o`000004ooooo`;o00001_ooool2o`0000_ooooo0_l0000;
ooooo`;o00003Oooool2o`000003ooooool0003o000000;ooooo0_l0000<ooooo`;o00003?ooool2
o`0000;ooooo0_l00002ooooo`Co00001?ooool2o`0000;ooooo0_l00002ooooo`?o00003?ooool2
o`0004[ooooo000Looooo`03o`000?oooooooooo02kooooo0_l000000ooooooo0000o`000004oooo
o`;o00009?ooool2o`0000Wooooo0_l00002ooooo`?o00000_ooool2o`0000oooooo0_l00003oooo
o`Go00001oooool3o`000004ooooool0003o0000ooooo`;o00002?ooool2o`0000gooooo0_l00005
ooooo`;o00003?ooool2o`0000Kooooo0_l00009ooooo`;o00002Oooool2o`0000;ooooo0_l00002
ooooo`?o00002oooool3o`0000;ooooo0_l00002ooooo`;o00001Oooool2o`0003_ooooo000Loooo
o`03o`000?oooooooooo02kooooo0_l000000ooooooo0000o`000004ooooo`;o00005_ooool2o`00
00[ooooo0_l00008ooooo`;o000000?oooooo`000?l000001oooool2o`0001Cooooo0ol00002oooo
o`;o00001Oooool3o`0000Cooooo1?l0000Booooo`;o000000?oooooo`000?l000003Oooool2o`00
00Cooooo0_l00005ooooo`?o000000?oooooo`000?l000000oooool2o`000003ooooool0003o0000
01Gooooo0_l00008ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`Co0000>oooool001co
oooo00?o0000ooooooooool0?oooool2o`0000kooooo0_l00005ooooo`;o00000oooool2o`0000So
oooo0_l00006ooooo`;o00002Oooool2o`0000?ooooo0_l00006ooooo`;o00001Oooool2o`0000Ko
oooo1?l00004ooooo`;o00004_ooool2o`000003ooooool0003o000000gooooo0ol000000ooooooo
0000o`000002o`000004ooooool0003o0000ooooo`?o00000_ooool4o`000003ooooool0003o0000
00Cooooo0ol00002ooooo`;o00001_ooool2o`0000?ooooo1?l00007ooooo`;o00001Oooool2o`00
00Kooooo0ol0000looooo`007?ooool00ol0003oooooooooo`0mooooo`Co00005Oooool2o`0001Go
oooo0_l00009ooooo`;o00000oooool2o`0000Kooooo0ol0000:ooooo`Ko00002Oooool2o`0000So
oooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo1Ol00008ooooo`;o000000Coooooo`00
0?l0003ooooo1?l000000ooooooo0000o`000005ooooo`;o00001oooool3o`0000;ooooo0_l00004
ooooo`Co00000oooool2o`0000Wooooo0_l00004ooooo`?o00001oooool2o`0003cooooo000Loooo
o`03o`000?oooooooooo02?ooooo0_l0000Hooooo`;o00004?ooool2o`0002Cooooo0_l0000?oooo
o`;o00002Oooool5o`0000_ooooo0_l00008ooooo`;o00002?ooool7o`0000gooooo0_l00002oooo
o`?o00001?ooool2o`0000gooooo0_l00004ooooo`;o00004Oooool2o`0000?ooooo0_l00016oooo
o`007?ooool2o`0002Cooooo0_l00005ooooo`;o00004Oooool2o`00013ooooo0_l0000Tooooo`;o
00004_ooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool4o`0000Kooooo0_l0000Boooo
o`;o000000?oooooo`000?l000001Ol00002ooooo`Go000000?oooooo`000?l000001oooool3o`00
00;ooooo1?l0000=ooooo`;o00003_ooool2o`0000Oooooo1_l00002ooooo`;o0000@oooool001co
oooo00?o0000ooooooooool0:_ooool2o`00017ooooo0_l0000`ooooo`;o00001?ooool2o`0001;o
oooo0_l00003ooooo`;o00001_ooool2o`0000Kooooo0_l00009ooooo`;o00001oooool2o`0000Co
oooo1?l00002ooooo`Go000000?oooooo`000?l000003?ooool2o`0001;ooooo0_l00002ooooo`;o
00001oooool2o`0000Wooooo1?l00002ooooo`;o00001?ooool2o`000003ooooool0003o000003[o
oooo000Looooo`03o`000?oooooooooo037ooooo0_l0000Oooooo`;o00006oooool2o`0000Cooooo
0_l0000Sooooo`;o00000_ooool2o`0000Wooooo0_l000000ooooooo0000o`00000@ooooo`;o0000
1?ooool2o`0000cooooo0_l0000Booooo`;o00000_ooool2o`0000cooooo1?l0000>ooooo`;o0000
00?oooooo`000?l00000>_ooool001cooooo00?o0000ooooooooool0<Oooool2o`0001;ooooo0_l0
000;ooooo`Go00006?ooool2o`0000?ooooo0_l0000?ooooo`;o00004oooool2o`00013ooooo1?l0
000=ooooo`?o00004_ooool2o`00013ooooo1?l0000@ooooo`Co0000COooool001cooooo00?o0000
ooooooooool0<Oooool2o`0001;ooooo0_l0000=ooooo`?o00002Oooool3o`00017ooooo0_l0000?
ooooo`;o00009oooool2o`0000Wooooo0_l00002ooooo`?o00000_ooool2o`0000kooooo0ol00003
ooooo`;o00002_ooool2o`0000;ooooo0_l00009ooooo`;o00004_ooool2o`00043ooooo000Loooo
o`03o`000?oooooooooo063ooooo0ol00012ooooo`;o000000?oooooo`000?l000001?ooool2o`00
00Wooooo0_l00002ooooo`?o00000_ooool3o`0000kooooo0_l000000ooooooo0000o`000002o`00
00kooooo0_l00009ooooo`;o00002_ooool2o`0000Kooooo0_l00005ooooo`;o0000>Oooool001co
oooo00?o0000ooooooooool0Boooool2o`0001Oooooo0_l0000gooooo`;o00001_ooool2o`000003
ooooool0003o000000Cooooo0_l00009ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o
00003_ooool2o`000003ooooool0003o000001?ooooo0_l00008ooooo`;o00002?ooool2o`0000go
oooo0_l0000iooooo`007?ooool00ol0003oooooooooo`0booooo`;o00005oooool2o`0001Oooooo
1?l0000Fooooo`;o00002?ooool2o`0001?ooooo0_l0000?ooooo`;o00001Oooool5o`0000;ooooo
1Ol000000ooooooo0000o`00000Cooooo`;o00000_ooool2o`0000Sooooo0_l000001?oooooo0000
o`000?ooool2o`0000?ooooo0_l00003ooooo`;o00002oooool2o`0000Wooooo0_l0000jooooo`00
7?ooool00ol0003oooooooooo`0^ooooo`;o000000Coooooo`000?l0003o0000<?ooool4o`000003
ooooool0003o000001?ooooo0_l00008ooooo`;o0000:_ooool6o`0000?ooooo1?l000000ooooooo
0000o`000002o`00017ooooo1_l00002ooooo`;o00001?ooool2o`000003ooooool0003o000000Ko
oooo0_l0000@ooooo`;o00002Oooool2o`0003[ooooo000Looooo`03o`000?oooooooooo02kooooo
0_l000000ooooooo0000o`00000<ooooo`;o00002_ooool2o`0001cooooo0_l00002ooooo`;o0000
1?ooool2o`0000cooooo0_l0000<ooooo`;o00000oooool2o`0000?ooooo0_l000000ooooooo0000
o`000008ooooo`;o00002_ooool7o`0000Gooooo0_l00004ooooo`;o00001?ooool4o`0000?ooooo
0_l00003ooooo`;o000000?oooooo`000?l000000ol000000ooooooo0000o`00000@ooooo`;o0000
2oooool2o`0000[ooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00003Ooo
ool2o`0000Gooooo0_l00003ooooo`;o00008?ooool2o`0000Cooooo0_l0000<ooooo`;o00003?oo
ool2o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000001oooool3o`0000[ooooo0_l0
0002ooooo`;o00001_ooool2o`0000[ooooo2Ol00002ooooo`?o000000?oooooo`000?l000000ol0
000:ooooo`;o00000oooool2o`0000;ooooo1?l00007ooooo`Co00002_ooool2o`0003gooooo000L
ooooo`03o`000?oooooooooo033ooooo0_l0000Dooooo`;o00003oooool4o`0001Sooooo0_l0000@
ooooo`;o00002Oooool2o`0000Kooooo0_l0000:ooooo`Co00002?ooool2o`0000Cooooo0_l00005
ooooo`?o000000?oooooo`000?l000000ol000000ooooooo0000o`000002ooooo`So00000_ooool5
o`0000kooooo0_l00003ooooo`;o00001?ooool2o`0000Cooooo0_l000000ooooooo0000o`00000P
ooooo`;o0000:Oooool001cooooo00?o0000ooooooooool0:Oooool2o`0000Cooooo0_l0000Coooo
o`;o00004Oooool4o`0000oooooo1Ol00002ooooo`Co00004?ooool2o`0000?ooooo0ol00002oooo
o`?o00001_ooool2o`0000Oooooo0_l000000ooooooo0000o`000002o`0000Sooooo0_l00006oooo
o`;o00000oooool3o`000003ooooool0003o000000?o000000?oooooo`000?l000001Oooool5o`00
0003ooooool0003o000000Go00002_ooool2o`0001;ooooo0_l0000Sooooo`;o0000:Oooool001co
oooo00?o0000ooooooooool0:Oooool2o`0000Cooooo0_l0000Cooooo`;o00009?ooool5o`0000;o
oooo0_l0000Booooo`;o00000oooool3o`0000;ooooo0_l0000@ooooo`;o00000oooool2o`0000Go
oooo0ol00002ooooo`;o00001?ooool3o`0000?ooooo0_l0000:ooooo`;o000000Goooooo`000?l0
003o0000ooooo`06o`000003ooooool0003o000000Co00000_ooool2o`0000?ooooo0_l000000ooo
oooo0000o`00000Aooooo`;o00002Oooool4o`0000Oooooo0_l0000fooooo`007?ooool00ol0003o
ooooooooo`1Oooooo`;o00009?ooool2o`0000Oooooo0_l0000Fooooo`;o00001Oooool3o`0000;o
oooo0_l00005ooooo`;o00000_ooool2o`0000?ooooo1?l00002ooooo`Co000000?oooooo`000?l0
00002_l000000ooooooo0000o`000003o`000003ooooool0003o000000Kooooo0_l00008ooooo`;o
00001oooool2o`0000Wooooo1_l00005ooooo`;o0000=_ooool001cooooo00?o0000ooooooooool0
<?ooool2o`0002gooooo0_l00004ooooo`;o00004?ooool2o`0001Gooooo0_l00008ooooo`;o0000
3_ooool2o`0001?ooooo0_l00003ooooo`Co00000_ooool2o`0000;ooooo2Ol000000ooooooo0000
o`000007o`0001?ooooo0_l0000Fooooo`;o00001Oooool2o`0003Kooooo000Looooo`;o0000<Ooo
ool2o`0002Gooooo1?l0000:ooooo`;o00001oooool2o`0000Oooooo0_l00003ooooo`;o00000_oo
ool2o`00013ooooo0_l00004ooooo`;o00001oooool2o`0000Gooooo1?l0000Booooo`;o00002ooo
oolHo`000003ooooool0003o000001;ooooo0_l000000ooooooo0000o`000009ooooo`;o00000ooo
ool2o`0003cooooo000Looooo`03o`000?oooooooooo02_ooooo0_l0000Zooooo`Oo00001?ooool2
o`0000[ooooo0_l00009ooooo`Go00000_ooool2o`0000cooooo0_l00002ooooo`;o00003Oooool4
o`0000?ooooo1?l00009ooooo`;o00001oooool2o`0000_ooooo6?l000000ooooooo0000o`000002
o`0000cooooo0ol000001?oooooo0000o`000?ooool2o`0000Kooooo0_l000000ooooooo0000o`00
0003ooooo`;o00004Oooool2o`0002Wooooo000Looooo`03o`000?oooooooooo02_ooooo0_l0000T
ooooo`;o000000?oooooo`000?l000002?l00004ooooo`;o00004oooool;o`0000Wooooo0_l00000
0ooooooo0000o`00000Cooooo`;o00001_ooool2o`0000Sooooo1?l000000ooooooo0000o`000003
o`0000;ooooo0_l000000ooooooo0000o`000003oooooaoo00003?ooool3o`0000;ooooo0_l00007
ooooo`?o00006Oooool2o`0002Wooooo000Looooo`03o`000?oooooooooo02[ooooo0_l0000Poooo
o`;o00000_ooool<o`0000?ooooo0ol0000Eooooo`Co00000_ooool3o`0000_ooooo0_l0000Noooo
o`;o00001_ooool2o`0000;ooooo0_l000000ooooooo0000o`000003o`0000;ooooo0_l000001?oo
oooo0000o`000?l00002oooooaKo000000?oooooo`000?l000001?l0000>ooooo`;o00000oooool2
o`0000Oooooo0_l00004ooooo`;o00001Oooool2o`00013ooooo0_l0000Vooooo`007?ooool00ol0
003oooooooooo`0Mooooo`;o00002oooool2o`0001gooooo0_l000001?oooooo0000o`000?oooolD
o`0000Cooooo0_l00005ooooo`;o00002Oooool5o`0000kooooo0_l0000@ooooo`;o00003oooool2
o`0000;ooooo0_l00007ooooo`;o00000oooool2o`0000;ooooo8Ol00008ooooo`;o00001?ooool2
o`000003ooooool0003o000000Gooooo0_l00008ooooo`;o00001Oooool2o`00013ooooo0_l0000V
ooooo`007?ooool00ol0003oooooooooo`0Mooooo`;o0000:_ooool2o`000004ooooool0003o0000
oooooaCo00001?ooool2o`0000Cooooo0ol0000:ooooo`Co00003_ooool2o`0000?ooooo0_l00002
ooooo`;o00001oooool2o`0000?ooooo0_l0000:ooooo`;o00005OoooolDo`000003ooooool0003o
000000Ko000000Coooooo`000?l0003ooooo0_l00003ooooo`Co00001oooool2o`0000Gooooo0_l0
000;ooooo`;o0000??ooool001cooooo00?o0000ooooooooool0C?ooool4o`000003ooooool0003o
0000017o00002Oooool4o`0000[ooooo0_l0000Dooooo`;o00000_ooool2o`0000cooooo0_l0000?
ooooo`Co00003_ooool;o`000003ooooool0003o000000oo00001?ooool2o`0000?ooooo1?l00005
ooooo`;o00005?ooool2o`00013ooooo0_l0000Zooooo`007?ooool00ol0003oooooooooo`0hoooo
o`;o00004?oooolKo`0000Wooooo0ol00005ooooo`;o00001Oooool2o`0000[ooooo0_l0000Boooo
o`;o00003_ooool2o`0000Gooooo1?l0000<ooooo`Ko000000?oooooo`000?l000002?l000000ooo
oooo0000o`00000;o`000003ooooool0003o000000Co00001?ooool2o`0000Gooooo0_l0000Coooo
o`;o00002oooool2o`0000Cooooo0_l0000Zooooo`007?ooool00ol0003oooooooooo`0hooooo`;o
00004?oooolKo`0000Wooooo0_l00006ooooo`;o00001Oooool2o`0000[ooooo0_l0000:ooooo`;o
000000?oooooo`000?l000000_ooool3o`0000kooooo0_l0000=ooooo`;o00001_ooool4o`0000?o
oooo7ol00006ooooo`;o00002?ooool2o`0000kooooo1?l00009ooooo`;o00001?ooool2o`0002[o
oooo000Looooo`03o`000?oooooooooo02Gooooo0_l0000UoooooaSo00000oooool2o`0000cooooo
0_l00002ooooo`;o00006Oooool3o`000003ooooool0003o000000;ooooo0_l00005ooooo`?o0000
2oooool2o`000003ooooool0003o000000Kooooo0_l00003ooooo`;o000000Goooooo`000?l0003o
0000ooooo`02o`000003ooooool0003o000000[o000000?oooooo`000?l000003?l00002ooooo`;o
00001_ooool2o`0000Sooooo0ol00004ooooo`;o00002Oooool2o`0000gooooo0_l0000/ooooo`00
7?ooool00ol0003oooooooooo`0Uooooo`;o00009OoooolIo`0000;ooooo0_l0000<ooooo`;o0000
0_ooool2o`0001Wooooo0_l00004ooooo`;o00001oooool3o`0000_ooooo0_l000000ooooooo0000
o`00000;ooooo`;o000000Goooooo`000?l0003o0000ooooo`0?o`000003ooooool0003o000000go
000000?oooooo`000?l000002oooool2o`0000Cooooo0_l00004ooooo`?o00001_ooool2o`0000oo
oooo0_l0000/ooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00003oooool3o`0000Cooooo
5ol0000@ooooo`;o00000oooool4o`0000[ooooo0_l0000@ooooo`;o00003Oooool2o`0000Kooooo
0_l00004ooooo`;o00001oooool2o`0000Oooooo3_l000000ooooooo0000o`00000>o`0000;ooooo
0_l00002ooooo`;o00001Oooool2o`0000_ooooo0_l00003ooooo`Go0000?Oooool001cooooo00?o
0000ooooooooool09Oooool2o`0000oooooo0_l0000?ooooo`?o00000ooooolIo`0000Gooooo0_l0
0008ooooo`;o00000oooool4o`0000[ooooo0_l00005ooooo`;o00000_ooool2o`0000Cooooo0_l0
0002ooooo`;o00000_ooool2o`0000Kooooo0_l000001?oooooo0000o`000?ooool2o`0000Kooooo
0_l00007ooooo`;o00000_ooool5o`000003ooooool0003o000001So000000?oooooo`000?l00000
1Ol00002ooooo`;o00002_ooool4o`0000Wooooo1?l000000ooooooo0000o`00000kooooo`007?oo
ool00ol0003oooooooooo`0Uooooo`;o00002oooool2o`0001;ooooo0ol00003ooooo`Wo000000?o
ooooo`000?l000003_l00005ooooo`;o000000?oooooo`000?l000001Oooool2o`0000;ooooo0_l0
000Aooooo`;o000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l000000ooooooo0000o`00
0002o`000003ooooool0003o000000;o000000?oooooo`000?l000000_l00002ooooo`Go00004ooo
oolPo`000003ooooool0003o000000Co00003oooool4o`0000_ooooo1Ol0000kooooo`007?ooool0
0ol0003oooooooooo`0Tooooo`;o00001Oooool2o`0000Gooooo0_l0000Booooo`?o00000oooool9
o`000003ooooool0003o000000oo00001?ooool5o`0000Wooooo0_l0000;ooooo`;o00001?ooool4
o`0000_ooooo1Ol00003ooooo`;o000000?oooooo`000?l000002_l00009ooooo`?o00001?ooool2
o`000003ooooool0003o000001ko00009?ooool4o`000003ooooool0003o000003Wooooo000Loooo
o`03o`000?oooooooooo02Cooooo0_l000000ooooooo0000o`000002ooooo`;o00008OoooolIo`00
00Cooooo1ol0000Dooooo`;o00000_ooool2o`0000;ooooo1?l00002ooooo`Co00000oooool2o`00
00?ooooo0_l00002ooooo`;o00000oooool5o`0000;ooooo0_l00002ooooo`;o00000oooool5o`00
00Cooooo0_l000000ooooooo0000o`00000No`0002Gooooo0_l00002ooooo`;o00002_ooool2o`00
0003ooooool0003o000002[ooooo000Looooo`;o0000:?ooool2o`0002Gooooo5Ol00002ooooo`;o
00002?ooool3o`0000_ooooo0ol00005ooooo`;o00000oooool2o`0000?ooooo2Ol000001?oooooo
0000o`000?l00004ooooo`;o00000_ooool4o`000003ooooool0003o000000?o00000_ooool2o`00
00;ooooo0_l00003ooooo`?o00001Oooool3o`000003ooooool0003o000001go00008Oooool2o`00
00?ooooo0_l0000>ooooo`;o000000?oooooo`000?l00000:_ooool001cooooo00?o0000oooooooo
ool0B_ooool2o`0000;ooooo4ol00007ooooo`;o00001?ooool2o`0000gooooo0ol00005ooooo`?o
00002?ooool5o`000003ooooool0003o000000Co00001Oooool2o`000003ooooool0003o000000Oo
000000?oooooo`000?l000000_l00002ooooo`;o00001?ooool2o`0000Gooooo0_l00002ooooo`;o
000000?oooooo`000?l000007Ol000000ooooooo0000o`000006ooooo`;o00003?ooool2o`0000?o
oooo1?l00002ooooo`?o0000?Oooool001cooooo00?o0000ooooooooool0>?ooool2o`0000_ooooo
0_l00003ooooo`;o00000_oooolBo`0000;ooooo1?l00002ooooo`;o00001?ooool2o`0000[ooooo
0_l00004ooooo`;o00001?ooool2o`000003ooooool0003o000000;ooooo0_l000001?oooooo0000
o`000?ooool2o`000003ooooool0003o000000Ko00000oooool5o`000004ooooool0003o0000o`00
00Cooooo2?l0000?ooooob;o000000?oooooo`000?l000001_ooool2o`0000cooooo1ol00004oooo
o`;o0000?_ooool001cooooo00?o0000ooooooooool0;_ooool2o`0000Sooooo0_l0000;ooooo`;o
00000oooool2o`000003ooooool0003o0000013o00000oooool4o`000003ooooool0003o000000Co
oooo0ol0000:ooooo`;o00001?ooool2o`0000Oooooo0_l00002ooooo`Co00000_ooool2o`000003
ooooool0003o000000Oo00000_ooool:o`0000Oooooo0ol00008ooooo`;o00002?ooool6o`0000;o
oooo3?l000000ooooooo0000o`000003o`0000Cooooo0_l0000Iooooo`?o00002?ooool2o`0003co
oooo000Looooo`03o`000?oooooooooo02cooooo1?l0000?ooooo`?o00001oooool2o`0000;ooooo
0ol00003ooooo`So000000Coooooo`000?l0003o00002?ooool3o`0000?ooooo0_l0000Aooooo`;o
00002_ooool6o`000003ooooool0003o000000[o000000?oooooo`000?l000002ol00006ooooo`?o
00001oooool2o`0000Kooooo2Ol000000ooooooo0000o`00000@o`0000Cooooo0_l0000Oooooo`;o
00000oooool2o`0003cooooo000Looooo`03o`000?oooooooooo02cooooo0_l0000Aooooo`?o0000
1oooool2o`0000Sooooo2?l00002ooooo`;o00002?ooool3o`0000kooooo0_l000001?oooooo0000
o`000?l00002ooooo`;o00000_ooool2o`0000;ooooo0_l00002oooooaco00000_ooool3o`0000Co
oooo0_l000000ooooooo0000o`00000?ooooo`;o000000?oooooo`000?l000001?l00002ooooo`go
00000_ooool2o`0001?ooooo0_l0000@ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0
?_ooool2o`0000Wooooo0ol00008ooooo`Ko00004?ooool2o`000003ooooool0003o000000;o0000
1oooool2o`000004ooooool0003o0000o`0000Kooooo0_l00002ooooo`Co000000?oooooo`000?l0
00006_l000001?oooooo0000o`000?l00004ooooo`;o00002Oooool2o`0000Kooooo0_l0000;oooo
o`Ko00000_ooool2o`0000?ooooo0ol0000:ooooo`;o00001_ooool3o`0000cooooo0_l00015oooo
o`007?ooool00ol0003oooooooooo`0Mooooo`;o00007oooool2o`0000Gooooo0_l00002ooooo`Ko
00000_ooool2o`000005ooooool0003o0000o`000?ooool00_l0000@ooooo`;o000000?oooooo`00
0?l000000_l0000:ooooo`Go00000_ooool2o`0000Cooooo1?l00002ooooo`;o000000Coooooo`00
0?l0003ooooo5Ol00002ooooo`Go000000?oooooo`000?l000001Oooool3o`000003ooooool0003o
000000Kooooo0_l0000;ooooo`Go00000oooool4o`000003ooooool0003o000000_ooooo0_l00006
ooooo`;o00003Oooool2o`0004Gooooo000Looooo`03o`000?oooooooooo01gooooo0_l0000Soooo
o`Go00000oooool5o`0000;ooooo0_l00004ooooo`;o00002oooool2o`0000cooooo0_l00007oooo
o`Go00000_ooool2o`0000;ooooo1Ol000000ooooooo0000o`00000Ko`0000?ooooo1?l000000ooo
oooo0000o`000005ooooo`?o00002oooool2o`0000_ooooo1?l000000ooooooo0000o`000003o`00
013ooooo1?l00004ooooo`;o00002oooool2o`0001Wooooo0_l0000Zooooo`007?ooool00ol0003o
ooooooooo`0gooooo`;o00002Oooool6o`0000Wooooo0_l00004ooooo`;o00001oooool6o`0000Ko
oooo0_l00004ooooo`;o00001?ooool2o`0000cooooo0_l000001?oooooo0000o`000?ooool:o`00
0003ooooool0003o000000?o000000?oooooo`000?l000002ol000000ooooooo0000o`000003o`00
00Oooooo0_l0000=ooooo`;o00000oooool2o`0000Kooooo2Ol00004ooooo`;o000000?oooooo`00
0?l000001_ooool6o`0000Cooooo1?l0000Tooooo`;o0000:_ooool001cooooo00?o0000oooooooo
ool0=oooool2o`0000gooooo0_l000000ooooooo0000o`000006ooooo`;o00003Oooool5o`0000Oo
oooo0_l0000:ooooo`;o00003?ooool2o`0000Cooooo7_l000001?oooooo0000o`000?ooool2o`00
00Oooooo0_l00005ooooo`Go00000_ooool2o`0000Cooooo0ol00006ooooo`So00001?ooool2o`00
0003ooooool0003o000000Kooooo0_l00008ooooo`Co00001_ooool4o`000004ooooool0003o0000
ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0BOooool2o`0003Cooooo0_l00004oooo
o`;o000000?oooooo`000?l000000_oooolNo`0000?ooooo0ol00003ooooo`;o00002Oooool5o`00
00;ooooo0_l00005ooooo`;o00007?ooool2o`0000[ooooo0ol00006ooooo`Co000000Coooooo`00
0?l0003ooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00004_ooool2o`00
00Sooooo0ol00005ooooo`;o00005Oooool2o`000003ooooool0003o000000;o00000_ooool7o`00
00?ooooo7ol000001?oooooo0000o`000?l00003ooooo`;o00001_ooool4o`0000gooooo0_l00006
ooooo`;o00005?ooool4o`0000Cooooo0_l00003ooooo`?o00003oooool2o`0003kooooo000Loooo
o`03o`000?oooooooooo03gooooo0_l0000>ooooo`?o000000Coooooo`000?l0003o00001?ooool2
o`000004ooooool0003o0000o`0000Gooooo1Ol00003ooooo`;o00003Oooool2o`000005ooooool0
003o0000o`000?ooool01?l000001?oooooo0000o`000?ooool3o`0000;ooooo:?l00005ooooo`Co
00004_ooool2o`000003ooooool0003o000000Gooooo0_l0000?ooooo`;o00001?ooool2o`0000Co
oooo0_l00004ooooo`;o00002Oooool4o`00013ooooo0_l0000Zooooo`0000Koooooonk^k_lb<S;o
0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000
ooooooooool0Boooool9o`0000?ooooo0ol00002ooooo`;o00001_ooool4o`000003ooooool0003o
000000;o000000Coooooo`000?l0003o00001Oooool2o`0000Cooooo2?l000000ooooooo0000o`00
0002ooooo`Co000000?oooooo`000?l000009_l00006ooooo`;o00004oooool2o`0000Sooooo0_l0
000Qooooo`;o00002oooool2o`00013ooooo0_l0000Zooooo`0000KoooooogMgMonHV9SooooooiRH
V?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000oooooooo
ool0?_ooool4o`0000Gooooo0_l00002ooooo`Co000000?oooooo`000?l000000ol00002ooooo`;o
00004?ooool2o`000003ooooool0003o000000?o00001Oooool4o`0000;ooooo1Ol00004ooooo`;o
000000?oooooo`000?l000004?l00002oooooaCo00000oooool2o`0000Oooooo0_l0000Hooooo`;o
00003oooool2o`0001oooooo0_l0000oooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooo
ooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0gooooo`;o
00000oooool6o`0000Gooooo0_l00003ooooo`;o00001?ooool3o`0000Oooooo0_l00003ooooo`;o
00001oooool5o`0000Wooooo0_l0000:ooooo`?o000000?oooooo`000?l000003ol000000ooooooo
0000o`00000Ho`0002;ooooo0_l00005ooooo`;o00002?ooool2o`000003ooooool0003o000001?o
oooo0ol00006ooooo`;o0000?oooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
2Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0000gooooo`;o00000oooool3o`0001[o
oooo0_l000000ooooooo0000o`000003ooooo`;o00001_ooool5o`0001Kooooo0_l00003ooooob_o
00004Oooool4o`0000;ooooo0_l00003ooooo`;o00001?ooool2o`0000Gooooo0ol0000:ooooo`;o
00003_ooool2o`0000?ooooo0ol00006ooooo`;o0000?oooool00003ooooool0003ooooo00;ooooo
00?o0000ooooooooool02Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000oooooooo
ool0>_ooool2o`000003ooooool0003o000000Co00000oooool2o`0000cooooo0_l00003ooooo`;o
000000Coooooo`000?l0003o00002_ooool3o`0001Gooooo0_l00006ooooob_o00001?ooool2o`00
00_ooooo1?l000000ooooooo0000o`000003o`000003ooooool0003o000000Cooooo0_l000000ooo
oooo0000o`000003ooooo`;o00006_ooool2o`0000Cooooo0_l00005ooooo`;o0000@?ooool00003
ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03
o`000?oooooooooo03[ooooo0_l00003ooooo`Co00000oooool6o`0000Sooooo0_l00006ooooo`?o
00001Oooool2o`0000?ooooo0_l0000Cooooo`;o000000?oooooo`000?l000001?ooool2o`000003
ooooool0003o000001Ko000000?oooooo`000?l000002Ol00002ooooo`;o00001?ooool4o`0000Oo
oooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000000?o00001oooool2o`0001;o
oooo0_l0000;ooooo`;o00001?ooool2o`0000Gooooo0_l00010ooooo`0000KoooooogMgMonHV9So
oooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0?oooool2o`00
00Oooooo1?l00004ooooo`;o00004_ooool2o`0000oooooo0_l00002ooooo`;o00000_ooool3o`00
00Oooooo0_l00002ooooob[o000000Coooooo`000?l0003o00002?ooool2o`0000;ooooo0_l00002
ooooo`;o00001?ooool3o`0000Cooooo0_l000000ooooooo0000o`000007ooooo`;o000000?ooooo
o`000?l000001_ooool2o`0000;ooooo0_l00007ooooo`;o00002?ooool2o`0000;ooooo0_l0000o
ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo
00?o0000ooooooooool0?oooool2o`0000Wooooo0_l00002ooooo`Co00003?ooool2o`0001Gooooo
0_l000001?oooooo0000o`000?l00002ooooo`Go00000_ooool4o`0000;ooooo8?l00002ooooo`Wo
00000_ooool2o`0000Wooooo0_l00004ooooo`?o00000oooool2o`0000Kooooo1Ol00004ooooo`;o
000000Coooooo`000?l0003ooooo0_l00009ooooo`Co00001_ooool2o`0000;ooooo0_l00004oooo
o`;o00000_ooool2o`0003oooooo000Looooo`03o`000?oooooooooo03Sooooo0_l0000?ooooo`?o
00000_ooool3o`0000gooooo0_l0000Gooooo`Co00000_ooool2o`000004ooooool0003o0000oooo
o`Go00000_oooolYo`0000?ooooo0_l0000:ooooo`;o000000Coooooo`000?l0003ooooo0_l00004
ooooo`;o00002?ooool3o`0000Cooooo0_l000000ooooooo0000o`000009ooooo`;o000000?ooooo
o`000?l000000_l0000:ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0>?ooool2o`00
00oooooo0_l000001?oooooo0000o`000?ooool2o`0000oooooo0_l0000?ooooo`;o00001?ooool2
o`0000?ooooo0_l00002ooooo`Go000000?oooooo`000?l000000_ooool?o`000003ooooool0003o
000000Go000000?oooooo`000?l000003_l00004ooooo`;o00000oooool2o`0000?ooooo0_l00003
ooooo`?o00005_ooool2o`000004ooooool0003o0000o`0000Wooooo0_l00002ooooo`?o00000_oo
ool2o`0002;ooooo0_l0000]ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00002_ooool2
o`0000Oooooo0_l00009ooooo`;o00003oooool4o`000003ooooool0003o000000Cooooo0_l00003
ooooo`?o00001OoooolVo`0000Cooooo0_l00004ooooo`Co00000oooool2o`0000Cooooo0_l0000>
ooooo`Co00000_ooool4o`000003ooooool0003o000000Cooooo0_l00009ooooo`;o00000_ooool2
o`0000Gooooo0ol000000ooooooo0000o`00000Gooooo`;o0000;Oooool001cooooo00?o0000oooo
ooooool0?Oooool2o`000003ooooool0003o000000;ooooo0_l0000<ooooo`;o000000?oooooo`00
0?l000002oooool2o`000003ooooool0003o000000cooooo0_l000000ooooooo0000o`000008oooo
o`Co00000_ooool2o`000003ooooool0003o000000Go000000?oooooo`000?l000006_l00006oooo
o`;o00000_ooool4o`0000?ooooo1?l0000:ooooo`;o00002?ooool4o`0000;ooooo0_l00009oooo
o`;o00005?ooool3o`000003ooooool0003o000001Sooooo0_l0000/ooooo`007?ooool00ol0003o
ooooooooo`0mooooo`;o00001Oooool2o`0000Cooooo1?l00004ooooo`;o00002?ooool2o`0000Co
oooo1Ol0000<ooooo`;o00002oooool2o`0000?ooooo:?l00002ooooo`Ko00000_ooool2o`0000Go
oooo1?l0000:ooooo`;o00000_ooool2o`0000Gooooo0_l00005ooooo`Co00001_ooool2o`00037o
oooo0_l0000/ooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00001Oooool2o`0000Cooooo
1ol00004ooooo`;o00000oooool5o`0000Gooooo0_l0000=ooooo`;o00004?oooolUo`000004oooo
ool0003o0000ooooo`[o00003?ooool2o`000003ooooool0003o000000Oooooo0_l00005ooooo`;o
00001Oooool4o`0000Kooooo1?l0001Mooooo`007?ooool00ol0003oooooooooo`0mooooo`;o0000
1Oooool2o`0000Cooooo1ol00004ooooo`;o00000oooool2o`000003ooooool0003o000000Cooooo
0_l0000Looooo`;o00001_oooolPo`000003ooooool0003o000000Go00001?ooool3o`0000Oooooo
0_l00003ooooo`;o000000?oooooo`000?l000002Oooool2o`0000?ooooo0_l0000Aooooo`;o0000
GOooool001cooooo00?o0000ooooooooool0>Oooool2o`0000Sooooo0_l00007ooooo`;o00005Ooo
ool3o`000004ooooool0003o0000o`0000Sooooo0_l00002ooooo`;o00002?ooool3o`000004oooo
ool0003o0000o`0000?ooooo9?l0000Aooooo`;o00003_ooool2o`000004ooooool0003o0000o`00
017ooooo0_l00003ooooo`;o000000?oooooo`000?l00000FOooool001cooooo00?o0000oooooooo
ool0>Oooool2o`0000Sooooo0_l00005ooooo`;o00005oooool3o`000005ooooool0003o0000o`00
0?ooool00_l00005ooooo`;o00000_ooool2o`0000;ooooo0_l00004ooooo`;o000000?oooooo`00
0?l000003?l000000ooooooo0000o`00000Go`000004ooooool0003o0000ooooo`;o00003?ooool2
o`00013ooooo0_l00002ooooo`;o00001_ooool2o`0000Wooooo0_l00003ooooo`;o000000?ooooo
o`000?l000002oooool2o`0004cooooo000Looooo`03o`000?oooooooooo04[ooooo0_l00004oooo
o`;o00000oooool2o`0000;ooooo0_l0000<ooooo`;o00000_ooool2o`0000_ooooo1?l00004oooo
o`;o000000?oooooo`000?l000004_l000000ooooooo0000o`00000>o`000004ooooool0003o0000
ooooo`;o000000?oooooo`000?l000003?ooool2o`0000oooooo0_l00004ooooo`;o00001Oooool2
o`0001kooooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`0nooooo`;o000000?oooooo`00
0?l000002oooool4o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000Gooooo1?l00002oooo
o`;o00000oooool2o`000003ooooool0003o000000?ooooo0_l00006ooooobco00006oooool2o`00
00Gooooo0_l00004ooooo`;o00001Oooool2o`0000Cooooo0_l00003ooooo`;o00000_ooool2o`00
00kooooo0_l00002ooooo`;o0000BOooool001cooooo0_l0000oooooo`;o000000?oooooo`000?l0
00002oooool3o`0000gooooo0_l00005ooooo`?o00000oooool2o`0000?ooooo0_l000000ooooooo
0000o`000008ooooo`;o00000oooool3o`000004ooooool0003o0000oooooaco000000?oooooo`00
0?l000001?l000000ooooooo0000o`00000=ooooo`;o000000?oooooo`000?l000001Oooool3o`00
01Oooooo0ol00003ooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`000005oooo
o`;o00000_ooool2o`0004Wooooo000Looooo`03o`000?oooooooooo04kooooo0_l0000:ooooo`;o
00004Oooool2o`0000kooooo1?l00002ooooo`;o000000?oooooo`000?l000000_l000000ooooooo
0000o`00000Io`0000;ooooo1?l000000ooooooo0000o`000006ooooo`;o00001Oooool2o`000003
ooooool0003o000000Gooooo0ol0000<ooooo`;o00002Oooool2o`0000;ooooo1?l00006ooooo`Co
000000?oooooo`000?l000000_l00003ooooo`;o00000_ooool2o`0004Wooooo000Looooo`03o`00
0?oooooooooo043ooooo1?l00009ooooo`;o00002oooool2o`00013ooooo0ol0000=ooooo`Go0000
1Oooool4o`0000?ooooo0ol00002oooooaCo000000Coooooo`000?l0003ooooo0_l00007ooooo`Co
00004?ooool2o`0000Cooooo0_l00006ooooo`Co00001?ooool4o`0000?ooooo0_l00004ooooo`;o
00000_ooool4o`0000?ooooo0_l00002ooooo`;o00000oooool4o`0004Oooooo000Looooo`03o`00
0?oooooooooo043ooooo1?l00009ooooo`?o00002?ooool4o`0000Gooooo0_l00009ooooo`;o0000
2Oooool2o`0000?ooooo0ol00007ooooo`;o00000_ooool2o`000003ooooool0003o000001Oo0000
00Coooooo`000?l0003o00002Oooool2o`0000?ooooo1?l0000;ooooo`;o00001?ooool2o`0000So
oooo1?l00002ooooo`Co00002Oooool5o`000003ooooool0003o000000;ooooo0_l00003ooooo`;o
00001Oooool2o`0004Oooooo000Looooo`03o`000?oooooooooo04kooooo0_l00008ooooo`;o0000
1oooool3o`0000Wooooo1?l00006ooooo`;o00000oooool4o`0000[ooooo3_l00002ooooo`co0000
00Coooooo`000?l0003o00002Oooool2o`0000?ooooo1?l0000;ooooo`;o00004?ooool2o`00017o
oooo0ol00005ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0C?ooool2o`0001Cooooo
0_l00002ooooo`;o00001?ooool5o`0000_ooooo1?l00002ooooo`;o00000oooool2o`000005oooo
ool0003o0000o`000?ooool01ol000000ooooooo0000o`00000:o`0000;ooooo0_l000000ooooooo
0000o`00000Cooooo`;o00000_ooool2o`0001Oooooo0_l00009ooooo`;o00001?ooool2o`0000Wo
oooo0_l0001Booooo`007?ooool00ol0003oooooooooo`0jooooo`;o00003?ooool2o`0000;ooooo
1?l0000Dooooo`Co00001?ooool2o`0000oooooo0_l00002ooooo`Go000000Coooooo`000?l0003o
oooo1_l000001?oooooo0000o`000?l00002ooooo`Ko000000Goooooo`000?l0003o0000ooooo`02
o`0000Gooooo0_l00005ooooo`;o00002oooool2o`0000;ooooo0_l0000Rooooo`;o00001?ooool2
o`0000Sooooo0ol00002ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0>_ooool2o`00
00cooooo0_l00004ooooo`;o00000_ooool2o`0000Kooooo0_l00004ooooo`;o00000_ooool2o`00
0003ooooool0003o000000;o00001oooool2o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`00
0003ooooool0003o000000Gooooo0ol000000ooooooo0000o`000003o`000003ooooool0003o0000
00;o000000Goooooo`000?l0003o0000ooooo`02o`000004ooooool0003o0000ooooo`;o00000_oo
ool2o`0000Gooooo0_l0000cooooo`Ko00002_ooool4o`000003ooooool0003o000004kooooo000L
ooooo`03o`000?oooooooooo057ooooo0ol00004ooooo`Co00001?ooool2o`0000Gooooo1?l00000
1?oooooo0000o`000?ooool2o`000003ooooool0003o000000;ooooo0_l0000Aooooo`;o00000ooo
ool3o`0000?ooooo1?l00003ooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo0_l0
0005ooooo`;o0000:_ooool2o`000003ooooool0003o000000Cooooo1_l0000<ooooo`Co0000Cooo
ool001cooooo00?o0000ooooooooool0@_ooool2o`0000gooooo0_l00005ooooo`;o00001Oooool2
o`0000Oooooo0ol000001?oooooo0000o`000?ooool2o`0000;ooooo0_l0000Dooooo`;o00000_oo
ool<o`000004ooooool0003o0000ooooo`;o00002Oooool2o`0000Gooooo0_l0000Zooooo`;o0000
00?oooooo`000?l000006?ooool2o`0004oooooo000Looooo`03o`000?oooooooooo04;ooooo0_l0
000<ooooo`;o00001_ooool2o`0000Gooooo0_l00007ooooo`Co00001oooool2o`000003ooooool0
003o000000Oooooo1?l00005ooooo`?o000000Goooooo`000?l0003o0000ooooo`09o`000003oooo
ool0003o000000?o00000_ooool2o`0000Kooooo0_l0000[ooooo`;o00005oooool2o`0005Sooooo
000Looooo`03o`000?oooooooooo053ooooo1?l00004ooooo`;o00001oooool5o`0000Cooooo0_l0
0002ooooo`;o00001_ooool2o`0000Oooooo1?l00005ooooo`;o00000_ooool2o`000005ooooool0
003o0000o`000?ooool02_l00004ooooo`;o00001_ooool4o`0002Wooooo1?l0000Eooooo`;o0000
F?ooool001cooooo00?o0000ooooooooool0=oooool2o`0001Wooooo0_l00002ooooo`;o00002Ooo
ool5o`0000Sooooo0_l00004ooooo`;o00001?ooool7o`0000Cooooo0_l00008ooooo`?o000000?o
ooooo`000?l000000_ooool3o`00017ooooo0_l0000Xooooo`;o000000?oooooo`000?l000001?oo
ool2o`0000Kooooo0_l00007ooooo`;o0000F?ooool001cooooo00?o0000ooooooooool0=oooool2
o`0001gooooo0_l00003ooooo`?o00000_ooool2o`0000;ooooo0_l00004ooooo`;o00000_ooool2
o`0000;ooooo1?l00004ooooo`Oo00001?ooool3o`0000Gooooo0_l000000ooooooo0000o`000002
ooooo`;o00001?ooool2o`0000_ooooo0_l0000[ooooo`?o00001oooool2o`0000Cooooo1?l00005
ooooo`;o00002?ooool2o`00053ooooo000Looooo`03o`000?oooooooooo043ooooo0_l0000Doooo
o`;o00000oooool7o`0000Sooooo0_l00002ooooo`?o000000?oooooo`000?l000002Oooool2o`00
0003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`00
0?l000000_ooool2o`0000Cooooo0_l0000;ooooo`;o0000:oooool2o`0000kooooo0_l00007oooo
o`;o00002?ooool2o`0001Gooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`10ooooo`;o
00007?ooool2o`0000gooooo1?l00005ooooo`;o00001oooool4o`0000?ooooo0_l000000ooooooo
0000o`000003ooooo`;o00001?ooool2o`0000Cooooo0_l00003ooooo`;o00002?ooool2o`0000;o
oooo0_l0000Qooooo`;o00002Oooool2o`0001;ooooo0_l0000Mooooo`;o0000>Oooool001cooooo
0_l0001Fooooo`?o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000Sooooo
1?l00005ooooo`;o00001oooool4o`0000_ooooo1Ol000000ooooooo0000o`000004ooooo`;o0000
0oooool2o`0000;ooooo0_l00004ooooo`;o00000_ooool2o`00027ooooo0_l00008ooooo`?o0000
4?ooool4o`0005Sooooo000Looooo`03o`000?oooooooooo05Gooooo0ol00002ooooo`;o00000_oo
ool2o`000003ooooool0003o000000;o000000?oooooo`000?l000001oooool2o`0000Cooooo0_l0
0009ooooo`Co00002Oooool6o`00013ooooo0ol0000dooooo`Co00001?ooool2o`0000Sooooo0ol0
0003ooooo`;o0000EOooool001cooooo00?o0000ooooooooool0E_ooool2o`0000Kooooo0_l00006
ooooo`;o00002?ooool7o`0000Kooooo0_l00002ooooo`?o00000oooool2o`0000Cooooo1?l00000
1?oooooo0000o`000?ooool2o`0000[ooooo0_l000001?oooooo0000o`000?ooool2o`0000Wooooo
0_l0000Xooooo`;o00001?ooool2o`0000Sooooo0_l00004ooooo`;o0000EOooool001cooooo00?o
0000ooooooooool0Doooool2o`000003ooooool0003o000000Oooooo0_l0000?ooooo`Go00001ooo
ool3o`0000Gooooo0_l000000ooooooo0000o`000006ooooo`;o000000Coooooo`000?l0003ooooo
0ol00009ooooo`Co00000_ooool2o`0000Wooooo0_l0000Pooooo`;o00004Oooool2o`0000Cooooo
0_l0001Jooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00002_ooool4o`0000Gooooo0_l0
000?ooooo`Go00001_ooool2o`0000;ooooo0_l00005ooooo`;o00001?ooool3o`0000;ooooo0_l0
0007ooooo`;o00000oooool3o`0002Oooooo1?l0000Aooooo`;o00001?ooool2o`0005[ooooo000L
ooooo`03o`000?oooooooooo04Cooooo0_l0000Hooooo`Oo00000oooool3o`0000kooooo1Ol00006
ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o00000oooool2
o`0000cooooo0ol0000Wooooo`;o00003Oooool2o`0000[ooooo0_l0001Jooooo`007?ooool00ol0
003oooooooooo`14ooooo`;o00006?ooool3o`0000;ooooo0_l00004ooooo`;o00001?ooool2o`00
00?ooooo0_l0000>ooooo`;o00001Oooool2o`0000cooooo1?l0000:ooooo`;o00008oooool2o`00
00Cooooo0_l0000=ooooo`;o00002_ooool2o`0005[ooooo000Looooo`03o`000?oooooooooo05So
oooo0_l00004ooooo`Co00003Oooool4o`000003ooooool0003o000000;o00000oooool2o`000004
ooooool0003o0000ooooo`;o00002?ooool2o`0000[ooooo1_l0000:ooooo`;o00002Oooool3o`00
01Oooooo0_l00009ooooo`;o00001oooool3o`0006Kooooo000Looooo`03o`000?oooooooooo05So
oooo0_l00006ooooo`;o00003?ooool2o`000004ooooool0003o0000ooooo`Co00000oooool5o`00
0003ooooool0003o000000Gooooo0ol0000;ooooo`Go00004Oooool2o`0000Cooooo0ol0000Ioooo
o`Co00001Oooool2o`0000Gooooo1Ol0000;ooooo`;o0000FOooool001cooooo00?o0000oooooooo
ool0H?ooool2o`0000cooooo0_l00008ooooo`;o00000_ooool4o`000003ooooool0003o000000Go
oooo0ol0000;ooooo`?o00001_ooool2o`0000_ooooo0_l0000Pooooo`Co000000?oooooo`000?l0
00000_l00007ooooo`?o00001Oooool2o`0000;ooooo0_l000001?oooooo0000o`000?l0001Ioooo
o`007?ooool00ol0003oooooooooo`1^ooooo`?o00001?ooool2o`000004ooooool0003o0000o`00
00Oooooo0_l0000=ooooo`;o00002?ooool6o`0001?ooooo0_l0000Cooooo`;o000000?oooooo`00
0?l000001Oooool4o`0000kooooo0ol00002ooooo`Go0000F_ooool001cooooo00?o0000oooooooo
ool0Joooool6o`000003ooooool0003o000000?o00000_ooool3o`0000Kooooo0_l0000=ooooo`;o
00002?ooool4o`00017ooooo0_l00002ooooo`;o00004oooool2o`000003ooooool0003o000000?o
oooo0_l0000>ooooo`;o000000?oooooo`000?l000001?l00002ooooo`;o00005Oooool2o`0004Co
oooo000Looooo`03o`000?oooooooooo06?ooooo0_l00006ooooo`?o00001?ooool4o`0000Cooooo
0_l0000Jooooo`;o00001Oooool2o`00017ooooo0_l0000Oooooo`;o00003_ooool2o`000003oooo
ool0003o000000Co00006Oooool2o`0004Cooooo000Looooo`03o`000?oooooooooo05oooooo0_l0
00001?oooooo0000o`000?l0000Oooooo`Co000000Coooooo`000?l0003ooooo0_l00006ooooo`Co
000000?oooooo`000?l00000@?ooool2o`0000;ooooo0_l00005ooooo`;o0000HOooool001cooooo
00?o0000ooooooooool0G_ooool3o`000003ooooool0003o000001Sooooo0_l00003ooooo`;o0000
00?oooooo`000?l000000_l000001?oooooo0000o`000?ooool2o`0000Kooooo1?l000000ooooooo
0000o`000008ooooo`;o00003?ooool2o`0001_ooooo1?l00009ooooo`;o00000_ooool2o`0006So
oooo000Looooo`03o`000?oooooooooo05kooooo0_l0000<ooooo`;o00001_ooool2o`0000Kooooo
0_l000000ooooooo0000o`000002o`000003ooooool0003o0000013ooooo1Ol00008ooooo`;o0000
3?ooool2o`000004ooooool0003o0000o`0001Oooooo1?l0001gooooo`007?ooool2o`0006gooooo
0ol00005ooooo`;o00001_ooool5o`000003ooooool0003o000000;o00004_ooool3o`0000Oooooo
0ol0000?ooooo`?o000000?oooooo`000?l000006?ooool2o`0000[ooooo0_l00006ooooo`;o0000
HOooool001cooooo00?o0000ooooooooool0KOooool2o`000003ooooool0003o000000?ooooo1?l0
0005ooooo`;o00000_ooool2o`0000Gooooo0_l0000Cooooo`Ko000000?oooooo`000?l000004Ooo
ool2o`0000cooooo0_l0000:ooooo`;o00001Oooool2o`0000?ooooo0_l00006ooooo`;o0000HOoo
ool001cooooo00?o0000ooooooooool0L?ooool2o`0000?ooooo1?l00005ooooo`;o00002Oooool2
o`0000Gooooo0_l000001?oooooo0000o`000?l00007ooooo`Ko00000_ooool2o`0000Gooooo0_l0
0003ooooo`Co00000oooool2o`0000cooooo0_l0000=ooooo`;o00000_ooool2o`0000Kooooo0_l0
000Aooooo`;o0000Doooool001cooooo00?o0000ooooooooool0Koooool2o`0000Cooooo0_l0000I
ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`000003ooooool0003o000000;ooooo1?l0
00001?oooooo0000o`000?l00003ooooo`;o00000oooool4o`000003ooooool0003o000000;o0000
3_ooool2o`0000Gooooo0_l00004ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo
0ol0000Aooooo`;o0000Doooool001cooooo00?o0000ooooooooool0Joooool2o`0000;ooooo0_l0
0002ooooo`?o000000?oooooo`000?l000004Oooool2o`0000?ooooo0_l00009ooooo`;o00001Ooo
ool4o`000004ooooool0003o0000o`0000_ooooo1Ol0000?ooooo`;o00000_ooool2o`000003oooo
ool0003o000000Oooooo1_l00002ooooo`;o0000Ioooool001cooooo00?o0000ooooooooool0GOoo
ool2o`0000Cooooo0_l00006ooooo`;o00001_ooool3o`000003ooooool0003o000000Sooooo0_l0
0007ooooo`Co000000?oooooo`000?l000001oooool2o`0000?ooooo0_l0000Eooooo`;o00001Ooo
ool2o`0000oooooo0_l00002ooooo`;o00001?ooool2o`000003ooooool0003o000000;o00000ooo
ool4o`0006Gooooo000Looooo`03o`000?oooooooooo05gooooo0_l00004ooooo`?o00002?ooool2
o`0000oooooo1Ol00008ooooo`;o00001Oooool2o`0000?ooooo0_l00003ooooo`;o00005oooool2
o`0000?ooooo0_l00009ooooo`;o00002?ooool4o`0000;ooooo0_l00009ooooo`?o0000IOooool0
01cooooo00?o0000ooooooooool0I?ooool2o`0000Sooooo1_l0000;ooooo`Go00003oooool2o`00
00Oooooo0ol00005ooooo`;o00004?ooool2o`0000kooooo0_l0000:ooooo`;o00002Oooool2o`00
00;ooooo0_l0001Vooooo`007?ooool00ol0003oooooooooo`1`ooooo`Co00000oooool2o`0000So
oooo0_l00003ooooo`;o00005?ooool3o`0000Cooooo0ol0000Jooooo`;o00002?ooool2o`00017o
oooo0_l0001Zooooo`007?ooool00ol0003oooooooooo`1Sooooo`;o000000?oooooo`000?l00000
3oooool3o`0000Kooooo0ol00002ooooo`?o00001_ooool4o`00017ooooo0_l00003ooooo`;o0000
5_ooool2o`0000Sooooo0_l0000Aooooo`;o0000J_ooool001cooooo00?o0000ooooooooool0Hooo
ool2o`000003ooooool0003o000000Kooooo0_l00004ooooo`;o00000_ooool2o`0000Kooooo0_l0
0002ooooo`?o00001oooool4o`00017ooooo0_l00003ooooo`;o00004?ooool2o`0001_ooooo0_l0
0002ooooo`Co0000J_ooool001cooooo00?o0000ooooooooool0K_ooool2o`0000Cooooo0_l00003
ooooo`;o00001?ooool2o`0000?ooooo0_l0000:ooooo`;o00004Oooool2o`0000;ooooo0_l0000A
ooooo`;o00002Oooool2o`00013ooooo0_l00002ooooo`;o0000K?ooool001cooooo00?o0000oooo
ooooool0NOooool4o`0000;ooooo0_l00005ooooo`;o00004oooool2o`0000[ooooo0_l0000Loooo
o`;o0000P_ooool001cooooo00?o0000ooooooooool0H_ooool2o`0001Oooooo0_l00003ooooo`;o
00001?ooool2o`0001?ooooo0_l00003ooooo`;o00005?ooool2o`0000cooooo0_l00002ooooo`;o
00003Oooool2o`00073ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44oooo
o`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Looooo`;o00001?ooool2
o`0000cooooo0_l00003ooooo`?o000000?oooooo`000?l000001Oooool2o`0001?ooooo0_l00006
ooooo`;o000000?oooooo`000?l000001oooool2o`0000?ooooo0_l00006ooooo`Co00002_ooool2
o`000004ooooool0003o0000o`0000Cooooo0_l00005ooooo`Ko0000K_ooool00006oooooomgMgOo
V9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03
o`000?oooooooooo05cooooo0_l0000Booooo`;o00000oooool3o`000003ooooool0003o000000oo
oooo0_l00006ooooo`;o000000?oooooo`000?l000001_ooool2o`0000[ooooo0_l00003ooooo`;o
00001?ooool2o`0000;ooooo0_l00006ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o
000000Coooooo`000?l0003o0000K_ooool00003ooooool@413ooooo00;ooooo00?o410@oooooooo
ool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0L?ooool4o`00
0003ooooool0003o000001?ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00001Oooool2
o`00013ooooo0_l00007ooooo`;o00001Oooool2o`0000?ooooo0_l00007ooooo`;o00003Oooool2
o`0000?ooooo0_l0001Zooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09oooo
o`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`0007;ooooo0_l00007ooooo`;o000000Cooooo
o`000?l0003ooooo0_l0000;ooooo`;o000000?oooooo`000?l000001_ooool2o`0000?ooooo0_l0
0003ooooo`;o00001_ooool2o`0000kooooo0ol00006ooooo`;o00000oooool2o`0000?ooooo0_l0
0005ooooo`;o00001_ooool2o`0006[ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo00Wooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo07_ooooo0_l0
00001?oooooo0000o`000?ooool2o`0000cooooo0ol00002ooooo`;o00002?ooool2o`0000;ooooo
0ol0000Gooooo`;o00000oooool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000
o`000002o`0000Gooooo0_l0001booooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`1aooooo`Co0000
1_ooool2o`0000[ooooo0_l00006ooooo`?o000000Coooooo`000?l0003o00000oooool2o`0000Oo
oooo0_l0000Mooooo`;o00001Oooool2o`0000;ooooo1_l0001gooooo`0000KoooooogMgMonHV9So
oooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`1a
ooooo`Ko00004?ooool2o`0000[ooooo1?l00002ooooo`;o00006?ooool3o`0000kooooo0_l00002
ooooo`?o00000oooool5o`0007Kooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00Go
ZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo06[ooooo0_l00009ooooo`;o0000
7_ooool2o`0000Oooooo0_l00002ooooo`;o00003oooool5o`0000cooooo0_l00003ooooo`;o0000
1?ooool4o`0001Oooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1Yooooo`?o00002Ooo
ool2o`0001gooooo0_l000000ooooooo0000o`000005ooooo`;o00000_ooool2o`000003ooooool0
003o000000?ooooo0_l0000:ooooo`;o00004Oooool4o`0000;ooooo0ol000000ooooooo0000o`00
000Eooooo`;o0000GOooool001cooooo00?o0000ooooooooool0JOooool2o`0000oooooo0_l00002
ooooo`;o00001?ooool3o`0000gooooo0_l000000ooooooo0000o`000003ooooo`;o00001oooool2
o`0000?ooooo0_l00002ooooo`;o00003oooool6o`0000Kooooo0_l00002ooooo`;o00000_ooool2
o`0007Cooooo000Looooo`03o`000?oooooooooo07[ooooo0_l00002ooooo`;o00001?ooool4o`00
00oooooo0ol00002ooooo`;o000000?oooooo`000?l000003Oooool2o`0000[ooooo0_l00003oooo
o`Ko000000?oooooo`000?l000000oooool2o`0007cooooo000Looooo`03o`000?oooooooooo08Ko
oooo1?l0000=ooooo`?o00001Oooool2o`000003ooooool0003o000000Cooooo0_l0000@ooooo`;o
00000_ooool2o`0000Kooooo0_l00003ooooo`;o0000O?ooool001cooooo00?o0000ooooooooool0
R?ooool2o`0000Gooooo1?l0000?ooooo`;o00001?ooool2o`0000Kooooo0_l000000ooooooo0000
o`000009ooooo`Co0000Qoooool001cooooo00?o0000ooooooooool0Soooool4o`0001Cooooo0ol0
0006ooooo`;o000000?oooooo`000?l000001?ooool3o`0000Cooooo0_l0000;ooooo`;o0000N_oo
ool001cooooo00?o0000ooooooooool0TOooool2o`0000Sooooo0_l0000:ooooo`;o00001oooool2
o`0000Cooooo0_l000001?oooooo0000o`000?l0000Aooooo`;o0000N_ooool001cooooo00?o0000
ooooooooool0Voooool7o`0000kooooo0_l00004ooooo`;o000000?oooooo`000?l00000S_ooool0
01cooooo00?o0000ooooooooool0WOooool5o`0000kooooo0_l0002Gooooo`007?ooool00ol0003o
ooooooooo`26ooooo`;o00000oooool2o`0001[ooooo0_l00007ooooo`;o00000_ooool4o`0001?o
oooo0_l0001looooo`007?ooool00ol0003oooooooooo`1kooooo`;o00002Oooool2o`0000?ooooo
0_l00006ooooo`;o000000?oooooo`000?l000000ol0000;ooooo`Go00002Oooool4o`0001?ooooo
0_l0001looooo`007?ooool2o`0007cooooo0_l0000@ooooo`;o00001?ooool2o`000003ooooool0
003o000000?o00001_ooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0009_ooooo
000Looooo`03o`000?oooooooooo08gooooo0_l00008ooooo`Co000000Coooooo`000?l0003o0000
0_ooool2o`0000;ooooo1?l00003ooooo`;o00001?ooool2o`0002;ooooo0_l0001aooooo`007?oo
ool00ol0003oooooooooo`27ooooo`;o00004oooool3o`0000?ooooo0_l000000ooooooo0000o`00
0002o`0000Wooooo0_l0000Rooooo`;o0000LOooool001cooooo00?o0000ooooooooool0Qoooool2
o`0001Wooooo1?l00003ooooo`Co0000W?ooool001cooooo00?o0000ooooooooool0Y?ooool2o`00
00?ooooo1?l0002Looooo`007?ooool00ol0003oooooooooo`2Yooooo`?o0000WOooool001cooooo
00?o0000ooooooooool0Z_ooool4o`0000Kooooo0_l0002Cooooo`007?ooool00ol0003ooooooooo
o`2/ooooo`;o000000?oooooo`000?l000000oooool2o`0009?ooooo000Looooo`03o`000?oooooo
oooo09Wooooo0_l0000Dooooo`;o0000V?ooool001cooooo00?o0000ooooooooool0Toooool2o`00
00Cooooo0_l00005ooooo`;o0000Yoooool001cooooo00?o0000ooooooooool0Toooool2o`0000_o
oooo0_l0002Wooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0<7ooooo0_l00026ooooo`007?ooool00ol0003oooooooooo`2Yooooo`;o00005_ooool2
o`0008Kooooo000Looooo`03o`000?oooooooooo0:Wooooo0_l0002Nooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBooo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
4_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom:ooooo`005?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000
ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o0000ooooooooool0oooooomBoooo
o`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?oooooo
D_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`004_ooool00omEEEGoIVIVo`00003o
oooooeCooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Qooooo`04oa0@4?l0
003o0000ooooo`;o000000?o410@ooooooooool05_ooool4o`000008oa0@4?ooooooooooonk^k_lb
<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo<c<co8B4Qo`00
0?lQ8B7oc<c<08cooooo002Rooooo`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40S?ooool00:;ooooo00Go0000oooo
ooooooooooooo`00000Kooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol0003ooooooooooooooooo000008co
oooo002Rooooo`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80S?ooool00:;ooooo00Go0000ohN7QoooooooZJVYo`00
000Kooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000oooool01Oo<c<co0000o`000?l0003oc<c<08cooooo002Qooooo`03
oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool06Oooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@
okZj^_oooooo^[Zjoa0@402<ooooo`00`_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go0000okZj^_oooooo
^[Zjo`00002<ooooo`00`?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2<
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1014) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.65428 .52228 Mdot
.65524 .56827 Mdot
.42718 .35337 Mdot
.44645 .59033 Mdot
.75861 .54999 Mdot
.41615 .38136 Mdot
.62435 .39158 Mdot
.5931 .34731 Mdot
.41103 .36312 Mdot
.56903 .51569 Mdot
.63009 .36659 Mdot
.54585 .6018 Mdot
.60988 .35872 Mdot
.46541 .59303 Mdot
.51855 .87259 Mdot
.39941 .6324 Mdot
.67531 .58509 Mdot
.30919 .4833 Mdot
.48839 .66062 Mdot
.36267 .33287 Mdot
.66879 .51135 Mdot
.45112 .59713 Mdot
.65949 .52553 Mdot
.4655 .59343 Mdot
.45852 .5755 Mdot
.68134 .5615 Mdot
.60848 .5517 Mdot
.42552 .59484 Mdot
.4962 .57564 Mdot
.58528 .36495 Mdot
.28398 .64394 Mdot
.61168 .83746 Mdot
.43596 .6749 Mdot
.74126 .31379 Mdot
.59979 .34324 Mdot
.62072 .77335 Mdot
.39217 .36467 Mdot
.59301 .37339 Mdot
.60192 .3444 Mdot
.58046 .38376 Mdot
.59636 .35694 Mdot
.6745 .56247 Mdot
.57111 .39619 Mdot
.67413 .34876 Mdot
.50391 .63987 Mdot
.71509 .46157 Mdot
.3816 .73041 Mdot
.47272 .63836 Mdot
.67861 .58112 Mdot
.37924 .3299 Mdot
.72961 .3206 Mdot
.61158 .3993 Mdot
.44128 .4101 Mdot
.90093 .52703 Mdot
.59874 .38254 Mdot
.51141 .63764 Mdot
.40054 .34954 Mdot
.44799 .60766 Mdot
.46335 .59766 Mdot
.48527 .76374 Mdot
.42735 .58552 Mdot
.28936 .51139 Mdot
.70949 .56464 Mdot
.34676 .46516 Mdot
.40458 .3677 Mdot
.60724 .34525 Mdot
.64584 .57649 Mdot
.60981 .3653 Mdot
.53364 .58171 Mdot
.48003 .39203 Mdot
.47134 .63822 Mdot
.61313 .34853 Mdot
.62318 .57392 Mdot
.45656 .63603 Mdot
.46203 .20393 Mdot
.34184 .79418 Mdot
.24718 .49138 Mdot
.54431 .76936 Mdot
.49619 .78224 Mdot
.30613 .40664 Mdot
.50111 .59117 Mdot
.18583 .48898 Mdot
.45184 .84378 Mdot
.66873 .52635 Mdot
.39921 .65241 Mdot
.49467 .37116 Mdot
.45135 .63333 Mdot
.6427 .46773 Mdot
.51762 .61884 Mdot
.57997 .20234 Mdot
.41727 .36394 Mdot
.65341 .54654 Mdot
.44973 .58914 Mdot
.46319 .55883 Mdot
.5442 .68351 Mdot
.41178 .61979 Mdot
.42725 .60062 Mdot
.62002 .54125 Mdot
.63597 .36703 Mdot
.55315 .5675 Mdot
.61149 .4174 Mdot
.46106 .40646 Mdot
.46218 .65346 Mdot
.39235 .34288 Mdot
.61545 .55415 Mdot
.45181 .64069 Mdot
.63443 .34667 Mdot
.49457 .62252 Mdot
.66242 .29687 Mdot
.65216 .57048 Mdot
.46873 .55813 Mdot
.26816 .52223 Mdot
.33301 .25216 Mdot
.65021 .54406 Mdot
.33043 .39416 Mdot
.50964 .6022 Mdot
.43134 .61421 Mdot
.65703 .56597 Mdot
.45884 .38347 Mdot
.62077 .48756 Mdot
.70211 .55203 Mdot
.57541 .37345 Mdot
.70588 .55618 Mdot
.40632 .66774 Mdot
.41777 .3733 Mdot
.52448 .36466 Mdot
.51538 .37673 Mdot
.25397 .60231 Mdot
.4479 .62962 Mdot
.71949 .38299 Mdot
.43371 .38922 Mdot
.66032 .55074 Mdot
.61373 .36576 Mdot
.45245 .54306 Mdot
.63271 .55352 Mdot
.62131 .38146 Mdot
.25359 .50002 Mdot
.51382 .29078 Mdot
.69564 .56823 Mdot
.67454 .32407 Mdot
.63505 .40008 Mdot
.58573 .39176 Mdot
.72796 .29345 Mdot
.65947 .57462 Mdot
.26777 .49716 Mdot
.61439 .38063 Mdot
.33712 .69696 Mdot
.52585 .61954 Mdot
.27205 .55945 Mdot
.15992 .44869 Mdot
.71704 .29617 Mdot
.52725 .24881 Mdot
.31131 .50339 Mdot
.59651 .40101 Mdot
.47195 .56687 Mdot
.67718 .57548 Mdot
.67285 .57231 Mdot
.42095 .6274 Mdot
.44801 .58315 Mdot
.46644 .6391 Mdot
.47714 .56005 Mdot
.43788 .78826 Mdot
.49643 .62739 Mdot
.19295 .5798 Mdot
.65733 .54046 Mdot
.44664 .57547 Mdot
.43146 .34982 Mdot
.51184 .56666 Mdot
.60106 .3515 Mdot
.44287 .60404 Mdot
.44284 .5901 Mdot
.44809 .56505 Mdot
.62084 .39575 Mdot
.60505 .82692 Mdot
.18631 .39033 Mdot
.72459 .70997 Mdot
.35663 .36473 Mdot
.41351 .38791 Mdot
.44105 .63059 Mdot
.28709 .49942 Mdot
.63887 .74744 Mdot
.49228 .59181 Mdot
.46074 .1437 Mdot
.4313 .59915 Mdot
.75753 .57243 Mdot
.37153 .62048 Mdot
.74159 .69524 Mdot
.21646 .5385 Mdot
.48551 .56667 Mdot
.58743 .6403 Mdot
.73772 .62277 Mdot
.6567 .3189 Mdot
.59685 .35924 Mdot
.4366 .35475 Mdot
.40975 .34892 Mdot
.65539 .3437 Mdot
.52927 .53847 Mdot
.4782 .53434 Mdot
.49721 .54593 Mdot
.47656 .40343 Mdot
.71128 .57446 Mdot
.2882 .48011 Mdot
.62134 .54508 Mdot
.18884 .67154 Mdot
.6712 .2931 Mdot
.64213 .41995 Mdot
.24639 .50177 Mdot
.44216 .36942 Mdot
.46037 .40842 Mdot
.28646 .49392 Mdot
.48521 .61723 Mdot
.65275 .57818 Mdot
.81589 .42608 Mdot
.47368 .52577 Mdot
.81209 .38434 Mdot
.64062 .58353 Mdot
.60444 .4778 Mdot
.624 .37134 Mdot
.37997 .35971 Mdot
.4294 .61261 Mdot
.47078 .61888 Mdot
.6782 .51058 Mdot
.47092 .63582 Mdot
.67632 .61506 Mdot
.42508 .6157 Mdot
.56179 .31164 Mdot
.24737 .4898 Mdot
.65403 .34206 Mdot
.24329 .59685 Mdot
.63367 .53928 Mdot
.2252 .52371 Mdot
.44959 .36244 Mdot
.60157 .77364 Mdot
.61978 .34923 Mdot
.26102 .51796 Mdot
.46248 .37572 Mdot
.29501 .48164 Mdot
.52161 .5833 Mdot
.43115 .40059 Mdot
.28574 .51992 Mdot
.52043 .82613 Mdot
.52324 .59637 Mdot
.42577 .79085 Mdot
.6307 .38861 Mdot
.7046 .56062 Mdot
.42661 .58707 Mdot
.37009 .35167 Mdot
.42204 .67133 Mdot
.4975 .22065 Mdot
.52711 .36486 Mdot
.41183 .40041 Mdot
.33185 .44462 Mdot
.26437 .51702 Mdot
.44447 .2353 Mdot
.71397 .35565 Mdot
.66875 .58573 Mdot
.45811 .65679 Mdot
.70001 .75585 Mdot
.61462 .37997 Mdot
.49036 .61265 Mdot
.53583 .33279 Mdot
.61181 .37939 Mdot
.44787 .61007 Mdot
.64144 .38201 Mdot
.66971 .57513 Mdot
.26183 .33984 Mdot
.6728 .58622 Mdot
.51723 .61342 Mdot
.64176 .35498 Mdot
.45345 .40085 Mdot
.68443 .55953 Mdot
.48975 .62538 Mdot
.43056 .63071 Mdot
.50411 .38503 Mdot
.45068 .56991 Mdot
.66291 .77795 Mdot
.44725 .5689 Mdot
.41616 .34477 Mdot
.41169 .61303 Mdot
.56347 .16544 Mdot
.46019 .30182 Mdot
.64683 .57698 Mdot
.40749 .39706 Mdot
.40806 .35847 Mdot
.28963 .36058 Mdot
.43592 .41391 Mdot
.50568 .60213 Mdot
.39227 .37881 Mdot
.30121 .55055 Mdot
.59485 .38668 Mdot
.43325 .65245 Mdot
.65537 .42305 Mdot
.38874 .32883 Mdot
.4719 .40472 Mdot
.3941 .58387 Mdot
.61322 .56609 Mdot
.44945 .58836 Mdot
.47033 .39738 Mdot
.70424 .54194 Mdot
.51167 .61962 Mdot
.39419 .53633 Mdot
.50641 .38666 Mdot
.61832 .39103 Mdot
.37651 .61495 Mdot
.48141 .63943 Mdot
.39068 .35711 Mdot
.62366 .55767 Mdot
.59362 .34407 Mdot
.67623 .55366 Mdot
.79199 .54667 Mdot
.61199 .28913 Mdot
.48312 .80442 Mdot
.29244 .53474 Mdot
.55485 .23178 Mdot
.76395 .67027 Mdot
.39402 .23991 Mdot
.32546 .63263 Mdot
.82106 .54002 Mdot
.46237 .38109 Mdot
.5514 .31134 Mdot
.40573 .35436 Mdot
.48017 .57712 Mdot
.4103 .37521 Mdot
.75683 .68453 Mdot
.42505 .61151 Mdot
.40068 .37512 Mdot
.26539 .35561 Mdot
.44272 .58292 Mdot
.64755 .54406 Mdot
.50686 .86488 Mdot
.44036 .19367 Mdot
.68234 .28815 Mdot
.43592 .3961 Mdot
.3897 .69413 Mdot
.42918 .59163 Mdot
.44101 .56682 Mdot
.69007 .56386 Mdot
.41755 .63362 Mdot
.2913 .48155 Mdot
.24981 .49495 Mdot
.3993 .49414 Mdot
.19273 .40703 Mdot
.55299 .57213 Mdot
.6862 .56059 Mdot
.44044 .76037 Mdot
.48951 .19595 Mdot
.34975 .34591 Mdot
.5679 .374 Mdot
.58135 .83154 Mdot
.50682 .53204 Mdot
.57116 .39976 Mdot
.67589 .37645 Mdot
.64716 .55757 Mdot
.62057 .8161 Mdot
.59589 .36561 Mdot
.62319 .65788 Mdot
.51668 .68428 Mdot
.47841 .6157 Mdot
.62835 .35581 Mdot
.54952 .592 Mdot
.52942 .17169 Mdot
.34436 .73185 Mdot
.18865 .55181 Mdot
.50803 .6306 Mdot
.43087 .22179 Mdot
.43643 .60722 Mdot
.62289 .49565 Mdot
.44306 .57165 Mdot
.6773 .54838 Mdot
.57023 .5286 Mdot
.50235 .4223 Mdot
.16825 .44706 Mdot
.67385 .29563 Mdot
.31132 .50232 Mdot
.42878 .62093 Mdot
.47757 .61501 Mdot
.26139 .49466 Mdot
.6637 .53056 Mdot
.47846 .56124 Mdot
.33067 .55341 Mdot
.46498 .6311 Mdot
.59271 .36047 Mdot
.22644 .60612 Mdot
.62229 .5229 Mdot
.40725 .60563 Mdot
.69481 .52924 Mdot
.61304 .39305 Mdot
.59558 .34772 Mdot
.39951 .58006 Mdot
.58164 .34925 Mdot
.43597 .59739 Mdot
.2741 .68998 Mdot
.68368 .53748 Mdot
.39722 .55618 Mdot
.64841 .53151 Mdot
.54084 .77739 Mdot
.63565 .34611 Mdot
.54017 .34504 Mdot
.57464 .58807 Mdot
.59838 .36287 Mdot
.69732 .31274 Mdot
.51811 .54944 Mdot
.41913 .65612 Mdot
.60664 .21743 Mdot
.44406 .3968 Mdot
.50041 .39064 Mdot
.61815 .33853 Mdot
.47788 .6411 Mdot
.42108 .64502 Mdot
.61078 .39545 Mdot
.56726 .68808 Mdot
.31678 .33347 Mdot
.42563 .59756 Mdot
.6756 .54186 Mdot
.66271 .55074 Mdot
.49128 .64274 Mdot
.49686 .61411 Mdot
.43865 .3728 Mdot
.40775 .39601 Mdot
.36559 .3512 Mdot
.50569 .38678 Mdot
.54698 .33163 Mdot
.75951 .47812 Mdot
.58112 .38489 Mdot
.73897 .40583 Mdot
.55545 .19686 Mdot
.50833 .65898 Mdot
.41577 .39222 Mdot
.47402 .60871 Mdot
.44721 .59285 Mdot
.59314 .34401 Mdot
.61419 .27725 Mdot
.41569 .68161 Mdot
.69614 .54952 Mdot
.61681 .33733 Mdot
.53616 .55367 Mdot
.77345 .43689 Mdot
.28987 .51583 Mdot
.67056 .26323 Mdot
.61392 .34715 Mdot
.64321 .55563 Mdot
.64815 .37175 Mdot
.47164 .62123 Mdot
.50355 .64807 Mdot
.65415 .55973 Mdot
.28144 .52324 Mdot
.50632 .55374 Mdot
.44493 .61167 Mdot
.26733 .25245 Mdot
.44778 .20641 Mdot
.54137 .38246 Mdot
.47583 .56442 Mdot
.41283 .63795 Mdot
.30432 .48317 Mdot
.46815 .62755 Mdot
.43408 .63791 Mdot
.29232 .27635 Mdot
.57396 .42493 Mdot
.30297 .47634 Mdot
.62822 .6615 Mdot
.64419 .58596 Mdot
.65989 .797 Mdot
.37688 .35902 Mdot
.62984 .32938 Mdot
.31861 .30347 Mdot
.44504 .40858 Mdot
.51307 .21933 Mdot
.64275 .81013 Mdot
.50241 .38943 Mdot
.33787 .52195 Mdot
.49397 .67486 Mdot
.42094 .61043 Mdot
.43513 .61245 Mdot
.28006 .49959 Mdot
.66258 .57581 Mdot
.42637 .47493 Mdot
.35978 .77021 Mdot
.44307 .60026 Mdot
.66435 .61365 Mdot
.52667 .83413 Mdot
.48852 .39638 Mdot
.29169 .484 Mdot
.25912 .52288 Mdot
.43069 .62029 Mdot
.30119 .28256 Mdot
.68208 .56273 Mdot
.49037 .62463 Mdot
.50576 .61733 Mdot
.43566 .39758 Mdot
.64528 .56949 Mdot
.46577 .38434 Mdot
.54062 .34834 Mdot
.75926 .62047 Mdot
.28771 .22758 Mdot
.6111 .34021 Mdot
.65407 .77045 Mdot
.58784 .37769 Mdot
.19881 .52425 Mdot
.43992 .40931 Mdot
.49836 .59334 Mdot
.62475 .55089 Mdot
.49166 .62578 Mdot
.49066 .6045 Mdot
.48497 .6162 Mdot
.53801 .56906 Mdot
.48415 .14589 Mdot
.29676 .4987 Mdot
.40582 .60117 Mdot
.41983 .34838 Mdot
.65175 .77707 Mdot
.39215 .81143 Mdot
.4668 .61457 Mdot
.43357 .63135 Mdot
.64245 .54496 Mdot
.42118 .63104 Mdot
.5965 .38685 Mdot
.62308 .55903 Mdot
.46991 .55712 Mdot
.60659 .8122 Mdot
.49746 .57307 Mdot
.74145 .68774 Mdot
.64871 .37056 Mdot
.69635 .31679 Mdot
.42987 .56973 Mdot
.52387 .36685 Mdot
.50037 .39071 Mdot
.37901 .3669 Mdot
.63633 .33764 Mdot
.39409 .36522 Mdot
.31157 .73941 Mdot
.47455 .66969 Mdot
.46872 .56855 Mdot
.42475 .64883 Mdot
.40435 .38564 Mdot
.661 .47257 Mdot
.46782 .24499 Mdot
.52582 .54635 Mdot
.43533 .37969 Mdot
.7069 .55246 Mdot
.36507 .46829 Mdot
.63043 .54499 Mdot
.28282 .47084 Mdot
.62874 .36399 Mdot
.30331 .5065 Mdot
.70755 .29613 Mdot
.65308 .56868 Mdot
.67579 .50938 Mdot
.41002 .38511 Mdot
.58097 .45629 Mdot
.87886 .55069 Mdot
.48619 .38854 Mdot
.27966 .58449 Mdot
.69104 .55636 Mdot
.51455 .59887 Mdot
.21487 .55897 Mdot
.59262 .46125 Mdot
.3968 .36457 Mdot
.48698 .58572 Mdot
.28001 .31064 Mdot
.4395 .37428 Mdot
.43696 .65514 Mdot
.45474 .38366 Mdot
.60972 .35127 Mdot
.44203 .38933 Mdot
.65667 .59432 Mdot
.44871 .63901 Mdot
.8728 .56913 Mdot
.21949 .5106 Mdot
.45034 .56783 Mdot
.62188 .33839 Mdot
.39915 .51285 Mdot
.48109 .60048 Mdot
.26612 .4816 Mdot
.42113 .37569 Mdot
.43115 .32752 Mdot
.42822 .59024 Mdot
.41914 .38749 Mdot
.65403 .52378 Mdot
.63881 .33872 Mdot
.30162 .45783 Mdot
.52911 .3571 Mdot
.68842 .5683 Mdot
.58039 .30986 Mdot
.60969 .33298 Mdot
.41273 .6337 Mdot
.4952 .63021 Mdot
.6687 .54268 Mdot
.22039 .39263 Mdot
.41444 .60364 Mdot
.50083 .59102 Mdot
.42523 .34964 Mdot
.3907 .36901 Mdot
.22907 .38583 Mdot
.45959 .38655 Mdot
.50202 .65203 Mdot
.66991 .54383 Mdot
.46061 .58625 Mdot
.63923 .55142 Mdot
.43672 .6447 Mdot
.68622 .6013 Mdot
.67482 .53023 Mdot
.41631 .25427 Mdot
.47443 .58376 Mdot
.37379 .61228 Mdot
.48804 .61028 Mdot
.46777 .63513 Mdot
.43284 .36601 Mdot
.28771 .48666 Mdot
.42776 .55591 Mdot
.32396 .49065 Mdot
.27359 .48141 Mdot
.74291 .60702 Mdot
.43908 .39662 Mdot
.27289 .50747 Mdot
.45243 .80669 Mdot
.40031 .38932 Mdot
.28793 .5049 Mdot
.42187 .82228 Mdot
.60646 .34052 Mdot
.66404 .59086 Mdot
.4439 .58235 Mdot
.81902 .5306 Mdot
.28913 .68901 Mdot
.44211 .40722 Mdot
.45202 .56622 Mdot
.47546 .60576 Mdot
.69052 .53615 Mdot
.1709 .58935 Mdot
.39896 .33541 Mdot
.47497 .57494 Mdot
.64236 .57432 Mdot
.14034 .51915 Mdot
.40853 .34277 Mdot
.28578 .50255 Mdot
.61767 .39748 Mdot
.6373 .599 Mdot
.51197 .37505 Mdot
.61205 .39738 Mdot
.4399 .26482 Mdot
.69695 .29933 Mdot
.50968 .60287 Mdot
.41465 .39169 Mdot
.69595 .26411 Mdot
.54941 .55176 Mdot
.56991 .33141 Mdot
.4247 .70177 Mdot
.64689 .55471 Mdot
.6 .388 Mdot
.3072 .5044 Mdot
.62886 .57759 Mdot
.66971 .53355 Mdot
.58643 .35083 Mdot
.35341 .50327 Mdot
.60226 .47478 Mdot
.59214 .35586 Mdot
.58508 .20796 Mdot
.80159 .49942 Mdot
.39913 .38655 Mdot
.27138 .4835 Mdot
.7996 .40971 Mdot
.67508 .56174 Mdot
.58525 .82996 Mdot
.67211 .25488 Mdot
.42732 .60027 Mdot
.26783 .50763 Mdot
.70985 .47767 Mdot
.33729 .76034 Mdot
.60998 .38079 Mdot
.517 .41185 Mdot
.28129 .52867 Mdot
.41983 .60411 Mdot
.42891 .71697 Mdot
.4876 .58081 Mdot
.62729 .37066 Mdot
.48009 .77511 Mdot
.64235 .55543 Mdot
.61016 .33528 Mdot
.67177 .26433 Mdot
.4386 .59816 Mdot
.48307 .58351 Mdot
.26143 .62915 Mdot
.66129 .58223 Mdot
.36936 .35254 Mdot
.50796 .60193 Mdot
.44371 .60841 Mdot
.41337 .65579 Mdot
.39007 .57226 Mdot
.32606 .25871 Mdot
.47553 .57629 Mdot
.57935 .29896 Mdot
.40727 .60309 Mdot
.47314 .58597 Mdot
.69702 .53231 Mdot
.33526 .19868 Mdot
.54406 .3406 Mdot
.44228 .60568 Mdot
.51173 .59251 Mdot
.58719 .34852 Mdot
.55513 .49534 Mdot
.58869 .45559 Mdot
.503 .37868 Mdot
.33927 .6585 Mdot
.53863 .57121 Mdot
.62934 .56191 Mdot
.26556 .52287 Mdot
.48903 .64179 Mdot
.63062 .5629 Mdot
.49716 .56456 Mdot
.44025 .37811 Mdot
.40382 .39138 Mdot
.68925 .32877 Mdot
.2809 .50802 Mdot
.27625 .66666 Mdot
.73423 .4183 Mdot
.43645 .35609 Mdot
.46295 .57094 Mdot
.652 .34437 Mdot
.46983 .40059 Mdot
.51032 .37847 Mdot
.38912 .6046 Mdot
.67847 .57066 Mdot
.65286 .54474 Mdot
.27062 .55836 Mdot
.52249 .27136 Mdot
.25771 .28109 Mdot
.61387 .3515 Mdot
.46373 .55547 Mdot
.71371 .3677 Mdot
.6513 .54456 Mdot
.2291 .56078 Mdot
.27349 .50923 Mdot
.60979 .3824 Mdot
.35121 .3485 Mdot
.63466 .55242 Mdot
.68862 .57625 Mdot
.52026 .60486 Mdot
.45308 .61658 Mdot
.32137 .61882 Mdot
.34525 .53423 Mdot
.60946 .3928 Mdot
.2639 .48978 Mdot
.46775 .38148 Mdot
.48574 .57603 Mdot
.66526 .52498 Mdot
.81247 .44796 Mdot
.51239 .59663 Mdot
.4382 .36998 Mdot
.65013 .55359 Mdot
.25855 .50185 Mdot
.27217 .48049 Mdot
.46759 .6341 Mdot
.45589 .75484 Mdot
.60044 .3779 Mdot
.64719 .54533 Mdot
.76769 .38778 Mdot
.41178 .60718 Mdot
.4486 .61998 Mdot
.38342 .65645 Mdot
.5823 .36462 Mdot
.69797 .32784 Mdot
.2864 .52459 Mdot
.66738 .56799 Mdot
.49062 .56896 Mdot
.28695 .51168 Mdot
.7068 .34126 Mdot
.42835 .40473 Mdot
.44776 .38708 Mdot
.26788 .48091 Mdot
.26305 .49873 Mdot
.25904 .48981 Mdot
.57154 .83741 Mdot
.65788 .59536 Mdot
.39199 .55761 Mdot
.42088 .5898 Mdot
.25801 .55881 Mdot
.46431 .54168 Mdot
.6503 .36711 Mdot
.44929 .39549 Mdot
.48745 .60658 Mdot
.51641 .61366 Mdot
.37663 .63272 Mdot
.37879 .58299 Mdot
.61867 .52843 Mdot
.64975 .57039 Mdot
.48115 .67115 Mdot
.43941 .39972 Mdot
.17467 .64614 Mdot
.81025 .63755 Mdot
.42269 .57439 Mdot
.58752 .47572 Mdot
.66281 .5261 Mdot
.57897 .36733 Mdot
.55642 .4318 Mdot
.64632 .37257 Mdot
.66566 .56212 Mdot
.48293 .57608 Mdot
.74395 .41362 Mdot
.28232 .47667 Mdot
.47137 .64209 Mdot
.62041 .37591 Mdot
.46876 .64105 Mdot
.61341 .39715 Mdot
.77337 .53893 Mdot
.54409 .18529 Mdot
.43063 .59967 Mdot
.40632 .62452 Mdot
.40704 .69595 Mdot
.46632 .61281 Mdot
.2336 .45154 Mdot
.65982 .52801 Mdot
.22055 .35501 Mdot
.5216 .59922 Mdot
.60967 .73547 Mdot
.41393 .59954 Mdot
.28331 .31637 Mdot
.45333 .62152 Mdot
.47347 .44005 Mdot
.42272 .60411 Mdot
.4434 .64146 Mdot
.64521 .36263 Mdot
.58808 .34799 Mdot
.64193 .52228 Mdot
.37026 .35265 Mdot
.71567 .72458 Mdot
.44535 .61482 Mdot
.52787 .35644 Mdot
.54867 .36986 Mdot
.26477 .49294 Mdot
.66792 .56161 Mdot
.1423 .53668 Mdot
.63156 .39122 Mdot
.33885 .34141 Mdot
.20938 .42017 Mdot
.51229 .37396 Mdot
.5196 .38684 Mdot
.59868 .51221 Mdot
.26896 .51897 Mdot
.41994 .60106 Mdot
.75445 .33476 Mdot
.46035 .20845 Mdot
.44368 .54321 Mdot
.61913 .33464 Mdot
.6171 .75926 Mdot
.80228 .42236 Mdot
.25812 .52526 Mdot
.30237 .5126 Mdot
.62421 .39312 Mdot
.37597 .33137 Mdot
.53855 .601 Mdot
.27429 .51136 Mdot
.4497 .3715 Mdot
.39175 .38196 Mdot
.40344 .41161 Mdot
.67856 .56481 Mdot
.67462 .27255 Mdot
.71033 .44602 Mdot
.61596 .39523 Mdot
.23191 .52697 Mdot
.63047 .59529 Mdot
.62304 .58267 Mdot
.38721 .37086 Mdot
.43173 .3632 Mdot
.64284 .59035 Mdot
.51865 .63715 Mdot
.36873 .63338 Mdot
.44122 .60285 Mdot
.27777 .49524 Mdot
.46041 .61994 Mdot
.43422 .37235 Mdot
.6103 .37484 Mdot
.42377 .35753 Mdot
.6374 .38497 Mdot
.7593 .46461 Mdot
.48546 .62575 Mdot
.44062 .63764 Mdot
.28299 .68577 Mdot
.65674 .51997 Mdot
.73173 .32895 Mdot
.56136 .30972 Mdot
.4069 .35175 Mdot
.43097 .63602 Mdot
.64184 .53176 Mdot
.24225 .50787 Mdot
.27845 .68346 Mdot
.47962 .6434 Mdot
.65721 .52785 Mdot
.47456 .57141 Mdot
.48084 .81579 Mdot
.42034 .19758 Mdot
.67244 .55143 Mdot
.1625 .46946 Mdot
.49372 .57546 Mdot
.56912 .53936 Mdot
.43958 .6586 Mdot
.31699 .56719 Mdot
.41337 .60663 Mdot
.64049 .58361 Mdot
.44744 .60176 Mdot
.62657 .57279 Mdot
.41803 .34248 Mdot
.58028 .38094 Mdot
.69373 .55556 Mdot
.49888 .62812 Mdot
.67018 .81648 Mdot
.62596 .36341 Mdot
.42899 .6167 Mdot
.63745 .37083 Mdot
.64008 .57681 Mdot
.68701 .57554 Mdot
.34092 .77389 Mdot
.55102 .39962 Mdot
.60797 .3518 Mdot
.46811 .57633 Mdot
.6762 .43481 Mdot
.46827 .58242 Mdot
.3073 .60898 Mdot
.49274 .64807 Mdot
.41191 .61056 Mdot
.33649 .79236 Mdot
.59412 .38725 Mdot
.26889 .27708 Mdot
.37213 .77641 Mdot
.55544 .84115 Mdot
.66091 .6014 Mdot
.25737 .52439 Mdot
.61612 .81846 Mdot
.53745 .35249 Mdot
.43057 .3844 Mdot
.48665 .60815 Mdot
.60963 .53002 Mdot
.59301 .37582 Mdot
.28772 .48789 Mdot
.43025 .60074 Mdot
.43417 .36419 Mdot
.32518 .34467 Mdot
.58684 .39552 Mdot
.6737 .56264 Mdot
.69198 .54282 Mdot
.14705 .47631 Mdot
.48786 .56682 Mdot
.4342 .63529 Mdot
.62877 .36859 Mdot
.46969 .52869 Mdot
.25993 .5149 Mdot
.29179 .3298 Mdot
.6096 .35207 Mdot
.54893 .45981 Mdot
.65481 .57486 Mdot
.47543 .60711 Mdot
.67713 .48184 Mdot
.36576 .37803 Mdot
.67216 .64851 Mdot
.28395 .49852 Mdot
.30429 .61701 Mdot
.64121 .5841 Mdot
.61547 .36976 Mdot
.5227 .29528 Mdot
.41226 .66573 Mdot
.46998 .6048 Mdot
.29994 .61816 Mdot
.37905 .50134 Mdot
.1927 .56124 Mdot
.44904 .65601 Mdot
.39195 .49254 Mdot
.44807 .65194 Mdot
.41657 .66243 Mdot
.50868 .64523 Mdot
.446 .62561 Mdot
.65922 .52721 Mdot
.41147 .55406 Mdot
.42737 .38852 Mdot
.55282 .67628 Mdot
.53562 .4142 Mdot
.43479 .58083 Mdot
.47952 .57867 Mdot
.69317 .66651 Mdot
.5638 .39098 Mdot
.67879 .53772 Mdot
.71343 .53917 Mdot
.57709 .35725 Mdot
.3719 .62659 Mdot
.37245 .34825 Mdot
.39568 .57609 Mdot
.42706 .36232 Mdot
.64905 .52972 Mdot
.4051 .34878 Mdot
.57866 .38632 Mdot
.41653 .39328 Mdot
.55269 .32374 Mdot
.59596 .38408 Mdot
.67081 .58048 Mdot
.45805 .6352 Mdot
.61547 .33753 Mdot
.26559 .62874 Mdot
.27781 .49601 Mdot
.34363 .77699 Mdot
.49851 .56821 Mdot
.55933 .41898 Mdot
.39242 .53709 Mdot
.42324 .35841 Mdot
.3661 .2227 Mdot
.67652 .53144 Mdot
.26967 .47504 Mdot
.64932 .52886 Mdot
.61932 .20938 Mdot
.27901 .48503 Mdot
.43027 .82533 Mdot
.54969 .26863 Mdot
.39963 .32271 Mdot
.52175 .63127 Mdot
.46753 .7081 Mdot
.47871 .39367 Mdot
.59388 .37749 Mdot
.53467 .26311 Mdot
.44797 .64318 Mdot
.39571 .24209 Mdot
.64287 .52034 Mdot
.38374 .37125 Mdot
.6112 .36378 Mdot
.60577 .33715 Mdot
.49858 .62046 Mdot
.25378 .38722 Mdot
.46087 .65027 Mdot
.50712 .26887 Mdot
.32699 .64689 Mdot
.38378 .66587 Mdot
.42547 .61688 Mdot
.39517 .34279 Mdot
.47344 .57166 Mdot
.36631 .65839 Mdot
.73196 .30077 Mdot
.53058 .5632 Mdot
.59866 .28215 Mdot
.23545 .52721 Mdot
.65448 .56379 Mdot
.43818 .56137 Mdot
.51596 .37145 Mdot
.48509 .5686 Mdot
.68271 .20457 Mdot
.28817 .50684 Mdot
.50573 .35683 Mdot
.4084 .60618 Mdot
.50347 .61204 Mdot
.53365 .66098 Mdot
.6015 .53617 Mdot
.34986 .3492 Mdot
.4631 .60465 Mdot
.33578 .68065 Mdot
.63205 .35804 Mdot
.46587 .6502 Mdot
.43325 .61416 Mdot
.74756 .6131 Mdot
.58761 .35341 Mdot
.41683 .35215 Mdot
.44368 .41011 Mdot
.46196 .3717 Mdot
.31737 .49721 Mdot
.5289 .42934 Mdot
.24616 .5613 Mdot
.43359 .20092 Mdot
.25096 .51167 Mdot
.50844 .58106 Mdot
.43221 .69117 Mdot
.50647 .58863 Mdot
.30875 .50343 Mdot
.58429 .36182 Mdot
.68204 .53902 Mdot
.68962 .35985 Mdot
.48376 .40001 Mdot
.43247 .65242 Mdot
.30054 .4861 Mdot
.67806 .57402 Mdot
.23438 .48573 Mdot
.66056 .56666 Mdot
.60503 .35582 Mdot
.58671 .33871 Mdot
.29901 .49197 Mdot
.6349 .54052 Mdot
.58267 .303 Mdot
.35097 .76078 Mdot
.49245 .65043 Mdot
.63218 .31637 Mdot
.64682 .52522 Mdot
.61477 .53803 Mdot
.62338 .53832 Mdot
.47418 .63388 Mdot
.58256 .47927 Mdot
.40364 .64575 Mdot
.61327 .39208 Mdot
.45339 .38166 Mdot
.32558 .54508 Mdot
.7944 .48078 Mdot
.31489 .54254 Mdot
.49751 .55325 Mdot
.44306 .59735 Mdot
.43067 .61986 Mdot
.51146 .63186 Mdot
.50326 .28609 Mdot
.49296 .61834 Mdot
.64496 .36753 Mdot
.42459 .37038 Mdot
.42772 .58458 Mdot
.4344 .40552 Mdot
.61905 .4788 Mdot
.26414 .52316 Mdot
.52073 .42361 Mdot
.67939 .78782 Mdot
.6824 .57174 Mdot
.46151 .38903 Mdot
.42802 .38482 Mdot
.25352 .50086 Mdot
.59356 .37294 Mdot
.66045 .5721 Mdot
.32723 .57056 Mdot
.26119 .48955 Mdot
.44564 .60424 Mdot
.382 .27971 Mdot
.37015 .26662 Mdot
.41652 .61449 Mdot
.49002 .59721 Mdot
.41376 .40129 Mdot
.38013 .33196 Mdot
.83012 .40579 Mdot
.21267 .57028 Mdot
.29411 .48865 Mdot
.28355 .52213 Mdot
.61557 .57024 Mdot
.40068 .60502 Mdot
.61662 .39159 Mdot
.23165 .61785 Mdot
.38984 .5124 Mdot
.26092 .65234 Mdot
.30565 .45724 Mdot
.48917 .63318 Mdot
.48371 .72707 Mdot
.438 .59687 Mdot
.68115 .53101 Mdot
.65015 .58104 Mdot
.68651 .55013 Mdot
.59891 .38056 Mdot
.55657 .77759 Mdot
.64075 .35477 Mdot
.71811 .74933 Mdot
.64046 .58542 Mdot
.49056 .31272 Mdot
.39248 .35097 Mdot
.44578 .55928 Mdot
.25937 .51 Mdot
.6165 .40911 Mdot
.53469 .58617 Mdot
.30987 .27175 Mdot
.41113 .3882 Mdot
.66877 .58206 Mdot
.59706 .51577 Mdot
.78536 .63046 Mdot
.56724 .44708 Mdot
.56136 .57045 Mdot
.502 .68856 Mdot
.2668 .48909 Mdot
.6649 .64832 Mdot
.31231 .50482 Mdot
.61669 .38162 Mdot
.44486 .63709 Mdot
.45008 .63261 Mdot
.43895 .64703 Mdot
.49028 .62034 Mdot
.58162 .35275 Mdot
.47849 .5481 Mdot
.56347 .16545 Mdot
.40289 .3915 Mdot
.50601 .82053 Mdot
.28264 .5162 Mdot
.63203 .33737 Mdot
.42573 .36886 Mdot
.36152 .34922 Mdot
.23672 .58458 Mdot
.42482 .60047 Mdot
.48859 .60797 Mdot
.34422 .34705 Mdot
.44362 .65473 Mdot
.52906 .55119 Mdot
.4226 .38698 Mdot
.31973 .54095 Mdot
.24744 .50769 Mdot
.3013 .50894 Mdot
.58797 .35712 Mdot
.64007 .53499 Mdot
.27515 .50312 Mdot
.41715 .34303 Mdot
.49532 .55998 Mdot
.50791 .61753 Mdot
.64564 .52504 Mdot
.66986 .25171 Mdot
.26342 .52731 Mdot
.59623 .51181 Mdot
.62861 .57079 Mdot
.66055 .5959 Mdot
.4702 .60329 Mdot
.43697 .54416 Mdot
.60463 .56533 Mdot
.25453 .49111 Mdot
.62659 .33466 Mdot
.46925 .35269 Mdot
.62318 .37921 Mdot
.66621 .57588 Mdot
.50587 .62715 Mdot
.66272 .57966 Mdot
.47317 .56302 Mdot
.51196 .89474 Mdot
.45037 .62829 Mdot
.46884 .18207 Mdot
.30066 .57816 Mdot
.4206 .38111 Mdot
.57916 .30502 Mdot
.38649 .37173 Mdot
.6317 .57532 Mdot
.49851 .63297 Mdot
.29149 .52219 Mdot
.50521 .85086 Mdot
.62451 .59164 Mdot
.44201 .38203 Mdot
.37033 .3402 Mdot
.59098 .38162 Mdot
.42916 .5817 Mdot
.47136 .60833 Mdot
.39804 .37416 Mdot
.35548 .60375 Mdot
.63688 .54586 Mdot
.43137 .63068 Mdot
.45788 .5917 Mdot
.41917 .38243 Mdot
.34549 .75461 Mdot
.58625 .55314 Mdot
.44229 .63167 Mdot
.52971 .31891 Mdot
.64915 .36046 Mdot
.51877 .62946 Mdot
.47487 .5466 Mdot
.26434 .50732 Mdot
.56283 .81157 Mdot
.74537 .3143 Mdot
.64998 .37391 Mdot
.37311 .35449 Mdot
.49344 .56799 Mdot
.39161 .35295 Mdot
.50423 .62181 Mdot
.674 .74524 Mdot
.39134 .37988 Mdot
.50228 .60195 Mdot
.41023 .58621 Mdot
.65679 .58325 Mdot
.49623 .61701 Mdot
.71585 .64957 Mdot
.47318 .39147 Mdot
.50088 .6085 Mdot
.4608 .75408 Mdot
.60196 .3464 Mdot
.4241 .57219 Mdot
.28981 .51743 Mdot
.32505 .56261 Mdot
.73416 .4313 Mdot
.53087 .34283 Mdot
.29724 .51147 Mdot
.4657 .64357 Mdot
.36746 .33248 Mdot
.6169 .39632 Mdot
.38805 .23943 Mdot
.42737 .63502 Mdot
.62694 .36922 Mdot
.61033 .37263 Mdot
.29397 .50886 Mdot
.21664 .32485 Mdot
.47016 .5487 Mdot
.46569 .61523 Mdot
.73019 .64387 Mdot
.7 .54289 Mdot
.45971 .62365 Mdot
.51299 .59127 Mdot
.64346 .36919 Mdot
.57572 .58632 Mdot
.65538 .72041 Mdot
.26666 .35298 Mdot
.63628 .39457 Mdot
.46716 .36837 Mdot
.36417 .33329 Mdot
.27955 .51576 Mdot
.65579 .55684 Mdot
.2976 .52529 Mdot
.43302 .39438 Mdot
.50493 .57976 Mdot
.6331 .38572 Mdot
.7092 .61684 Mdot
.61024 .39929 Mdot
.52211 .3535 Mdot
.66729 .52049 Mdot
.70586 .38084 Mdot
.60208 .15707 Mdot
.71799 .45192 Mdot
.58389 .41007 Mdot
.2647 .4932 Mdot
.43437 .26594 Mdot
.45299 .59347 Mdot
.63737 .64721 Mdot
.46209 .63707 Mdot
.47454 .74721 Mdot
.45781 .38619 Mdot
.3632 .34631 Mdot
.44425 .63492 Mdot
.31963 .63586 Mdot
.60369 .39963 Mdot
.5957 .38735 Mdot
.4972 .60672 Mdot
.59828 .36245 Mdot
.45462 .61352 Mdot
.43167 .36676 Mdot
.30473 .24608 Mdot
.43499 .6043 Mdot
.41495 .65255 Mdot
.64533 .42151 Mdot
.35968 .79186 Mdot
.5674 .2835 Mdot
.48715 .72152 Mdot
.79524 .60284 Mdot
.5989 .36276 Mdot
.39477 .60252 Mdot
.48875 .39037 Mdot
.41579 .40234 Mdot
.58203 .30398 Mdot
.46378 .62807 Mdot
.46928 .62778 Mdot
.42967 .63386 Mdot
.48405 .58304 Mdot
.64359 .64925 Mdot
.45112 .5327 Mdot
.51738 .74432 Mdot
.49075 .60601 Mdot
.43313 .7199 Mdot
.61782 .33886 Mdot
.67382 .51173 Mdot
.29335 .52836 Mdot
.49038 .63164 Mdot
.60807 .5954 Mdot
.64671 .35336 Mdot
.72057 .74683 Mdot
.58568 .36981 Mdot
.40772 .35937 Mdot
.58008 .37611 Mdot
.45487 .56727 Mdot
.66258 .54999 Mdot
.49996 .37875 Mdot
.45419 .23175 Mdot
.43167 .38397 Mdot
.45019 .56786 Mdot
.49738 .35518 Mdot
.43183 .38646 Mdot
.62742 .47056 Mdot
.65773 .54965 Mdot
.32973 .68082 Mdot
.65004 .58134 Mdot
.50356 .60296 Mdot
.50363 .59684 Mdot
.6001 .30692 Mdot
.58968 .39325 Mdot
.64289 .5797 Mdot
.25487 .26279 Mdot
.31313 .50577 Mdot
.68446 .55143 Mdot
.43849 .67598 Mdot
.48962 .48212 Mdot
.66334 .54384 Mdot
.34292 .60663 Mdot
.5964 .38185 Mdot
.63169 .58314 Mdot
.43194 .67558 Mdot
.60427 .23853 Mdot
.26845 .47759 Mdot
.38772 .33678 Mdot
.44603 .44327 Mdot
.47164 .39519 Mdot
.61999 .33154 Mdot
.40423 .38399 Mdot
.63144 .35441 Mdot
.72509 .32868 Mdot
.40389 .72956 Mdot
.65338 .34458 Mdot
.60191 .33243 Mdot
.41147 .38518 Mdot
.42375 .62123 Mdot
.47238 .42158 Mdot
.4655 .65995 Mdot
.53229 .60051 Mdot
.62484 .34858 Mdot
.64484 .58491 Mdot
.66894 .59045 Mdot
.44398 .71636 Mdot
.69209 .54237 Mdot
.4287 .36241 Mdot
.4252 .19773 Mdot
.71054 .29996 Mdot
.62854 .35864 Mdot
.58983 .34099 Mdot
.47166 .58105 Mdot
.3951 .36479 Mdot
.41484 .33901 Mdot
.61013 .38728 Mdot
.61677 .62976 Mdot
.40139 .62582 Mdot
.63646 .51974 Mdot
.64069 .58644 Mdot
.67165 .54708 Mdot
.61897 .54853 Mdot
.64886 .70756 Mdot
.59678 .38302 Mdot
.63563 .58094 Mdot
.49965 .60307 Mdot
.46799 .62718 Mdot
.50886 .38269 Mdot
.29953 .51122 Mdot
.49094 .56179 Mdot
.50754 .64972 Mdot
.47365 .60311 Mdot
.44559 .38727 Mdot
.46074 .68078 Mdot
.37003 .35434 Mdot
.39367 .33488 Mdot
.42264 .40047 Mdot
.5385 .34809 Mdot
.47436 .70025 Mdot
.80907 .59123 Mdot
.47521 .57473 Mdot
.46138 .52518 Mdot
.39453 .3521 Mdot
.34215 .24123 Mdot
.70038 .33688 Mdot
.42947 .63569 Mdot
.3746 .39072 Mdot
.39745 .37513 Mdot
.70033 .55539 Mdot
.45958 .62848 Mdot
.48647 .40043 Mdot
.26236 .52141 Mdot
.44999 .67326 Mdot
.46247 .40963 Mdot
.6289 .54874 Mdot
.31022 .52529 Mdot
.62485 .57741 Mdot
.43397 .40196 Mdot
.41338 .58253 Mdot
.88578 .54035 Mdot
.45984 .37059 Mdot
.43576 .8105 Mdot
.59478 .57978 Mdot
.42987 .62987 Mdot
.46395 .38881 Mdot
.69853 .54193 Mdot
.62759 .33296 Mdot
.44484 .47587 Mdot
.6839 .53809 Mdot
.36402 .34797 Mdot
.46643 .40777 Mdot
.42441 .38671 Mdot
.64746 .56683 Mdot
.48112 .64955 Mdot
.63942 .56002 Mdot
.5807 .37568 Mdot
.44603 .58768 Mdot
.75654 .68336 Mdot
.45601 .52761 Mdot
.63314 .57546 Mdot
.42811 .35577 Mdot
.30018 .48025 Mdot
.43256 .59397 Mdot
.41918 .79595 Mdot
.46759 .55896 Mdot
.63293 .36609 Mdot
.26364 .31658 Mdot
.70582 .62214 Mdot
.41758 .59523 Mdot
.47331 .58087 Mdot
.60392 .39178 Mdot
.42695 .59854 Mdot
.4164 .60011 Mdot
.54409 .37665 Mdot
.64438 .57092 Mdot
.44931 .59906 Mdot
.43959 .36171 Mdot
.75401 .34462 Mdot
.40203 .63574 Mdot
.33561 .39267 Mdot
.32188 .66306 Mdot
.24352 .32427 Mdot
.45825 .63933 Mdot
.22749 .59717 Mdot
.48792 .58737 Mdot
.47693 .63792 Mdot
.46647 .57924 Mdot
.49947 .7118 Mdot
.41862 .39142 Mdot
.43274 .37655 Mdot
.26506 .47938 Mdot
.32584 .66766 Mdot
.26726 .50868 Mdot
.58913 .3721 Mdot
.31173 .39884 Mdot
.39421 .38215 Mdot
.62858 .548 Mdot
.46254 .64705 Mdot
.47815 .38929 Mdot
.47727 .60904 Mdot
.46114 .56507 Mdot
.3936 .34134 Mdot
.40889 .33481 Mdot
.52113 .36079 Mdot
.27615 .52263 Mdot
.69006 .55074 Mdot
.52409 .59261 Mdot
.27526 .48123 Mdot
.48156 .64835 Mdot
.24238 .55328 Mdot
.68664 .54657 Mdot
.64258 .5687 Mdot
.69259 .57675 Mdot
.50392 .57877 Mdot
.44105 .5766 Mdot
.6397 .35413 Mdot
.63391 .53963 Mdot
.59758 .35037 Mdot
.49944 .38162 Mdot
.31937 .38257 Mdot
.464 .62805 Mdot
.57656 .52729 Mdot
.26618 .51417 Mdot
.41512 .36178 Mdot
.33648 .35498 Mdot
.27887 .47416 Mdot
.4669 .56026 Mdot
.39363 .34378 Mdot
.3063 .5003 Mdot
.5877 .62396 Mdot
.8315 .5445 Mdot
.30706 .48683 Mdot
.49814 .60323 Mdot
.56581 .6176 Mdot
.32694 .72925 Mdot
.31525 .49492 Mdot
.63391 .37867 Mdot
.50421 .57814 Mdot
.39978 .5406 Mdot
.27139 .5286 Mdot
.7514 .35282 Mdot
.41691 .37803 Mdot
.62578 .26087 Mdot
.52907 .63708 Mdot
.60677 .64825 Mdot
.30682 .51897 Mdot
.66382 .57014 Mdot
.6968 .52744 Mdot
.47415 .59566 Mdot
.31811 .50209 Mdot
.62959 .39781 Mdot
.41708 .37436 Mdot
.55805 .31981 Mdot
.64577 .56481 Mdot
.65593 .4332 Mdot
.44783 .37484 Mdot
.58901 .51335 Mdot
.27172 .33127 Mdot
.37036 .64995 Mdot
.44117 .73709 Mdot
.4865 .20663 Mdot
.51491 .58802 Mdot
.31163 .49812 Mdot
.64611 .35532 Mdot
.62833 .3912 Mdot
.61104 .35354 Mdot
.57577 .30669 Mdot
.54857 .42751 Mdot
.44888 .40296 Mdot
.42422 .23917 Mdot
.28537 .51179 Mdot
.3494 .70642 Mdot
.48036 .64697 Mdot
.44125 .59865 Mdot
.46549 .55511 Mdot
.46305 .65258 Mdot
.47958 .58849 Mdot
.5939 .36729 Mdot
.5768 .3047 Mdot
.43297 .32723 Mdot
.67337 .54015 Mdot
.31606 .53945 Mdot
.39268 .35075 Mdot
.40815 .39767 Mdot
.29513 .49437 Mdot
.61601 .49625 Mdot
.45711 .40454 Mdot
.40717 .34962 Mdot
.47811 .55486 Mdot
.63438 .5549 Mdot
.41823 .5529 Mdot
.49984 .59025 Mdot
.42026 .36343 Mdot
.35209 .46681 Mdot
.68483 .69179 Mdot
.39319 .64827 Mdot
.27484 .53608 Mdot
.5678 .48531 Mdot
.31474 .49522 Mdot
.44031 .66028 Mdot
.32907 .24968 Mdot
.43113 .39404 Mdot
.40248 .36285 Mdot
.30794 .49532 Mdot
.57584 .5454 Mdot
.64947 .55705 Mdot
.35948 .34458 Mdot
.63799 .36477 Mdot
.5069 .59315 Mdot
.3238 .36282 Mdot
.56082 .54372 Mdot
.27338 .37858 Mdot
.61882 .35436 Mdot
.40776 .33908 Mdot
.42678 .58389 Mdot
.49701 .602 Mdot
.26318 .49263 Mdot
.76372 .54402 Mdot
.46782 .67181 Mdot
.55908 .84094 Mdot
.55649 .19023 Mdot
.63467 .24293 Mdot
.46981 .60496 Mdot
.64667 .5709 Mdot
.44023 .40923 Mdot
.26944 .48464 Mdot
.5066 .56027 Mdot
.82454 .55961 Mdot
.66065 .5154 Mdot
.61723 .37612 Mdot
.49498 .39501 Mdot
.55665 .43122 Mdot
.48662 .5645 Mdot
.46164 .63626 Mdot
.48038 .62905 Mdot
.84174 .46472 Mdot
.44677 .38104 Mdot
.67007 .5239 Mdot
.28568 .4969 Mdot
.68929 .53919 Mdot
.42858 .37939 Mdot
.68528 .39748 Mdot
.42823 .58832 Mdot
.6573 .51725 Mdot
.66386 .56709 Mdot
.59031 .38046 Mdot
.61942 .33011 Mdot
.47048 .36376 Mdot
.44983 .62707 Mdot
.47759 .40461 Mdot
.65743 .5844 Mdot
.35402 .33978 Mdot
.27646 .48528 Mdot
.63163 .34404 Mdot
.49078 .60749 Mdot
.43166 .39128 Mdot
.48771 .54732 Mdot
.65562 .54107 Mdot
.406 .34956 Mdot
.52249 .36354 Mdot
.2857 .52108 Mdot
.47925 .61953 Mdot
.25861 .53163 Mdot
.37337 .3538 Mdot
.45632 .59147 Mdot
.61916 .50349 Mdot
.31092 .53083 Mdot
.4671 .24054 Mdot
.45361 .40048 Mdot
.52805 .35989 Mdot
.68931 .57806 Mdot
.7511 .3678 Mdot
.40575 .36417 Mdot
.62754 .49654 Mdot
.7661 .50116 Mdot
.52459 .59065 Mdot
.67548 .55789 Mdot
.41191 .26927 Mdot
.63133 .82668 Mdot
.37587 .7564 Mdot
.42987 .6163 Mdot
.46203 .39323 Mdot
.29796 .48598 Mdot
.62845 .35781 Mdot
.33515 .39056 Mdot
.36793 .65996 Mdot
.3814 .34924 Mdot
.47138 .57817 Mdot
.64707 .57807 Mdot
.60549 .38128 Mdot
.75191 .4261 Mdot
.42114 .34723 Mdot
.456 .38885 Mdot
.42368 .58786 Mdot
.27495 .50907 Mdot
.42079 .77054 Mdot
.43562 .37117 Mdot
.34345 .33853 Mdot
.44031 .2632 Mdot
.30134 .48622 Mdot
.49074 .59271 Mdot
.43729 .71453 Mdot
.51466 .62993 Mdot
.45133 .82156 Mdot
.37929 .3626 Mdot
.66972 .53731 Mdot
.4664 .63857 Mdot
.25576 .36025 Mdot
.41822 .36618 Mdot
.58904 .47384 Mdot
.34256 .45144 Mdot
.59742 .38293 Mdot
.33469 .34575 Mdot
.46661 .61953 Mdot
.60543 .39988 Mdot
.2662 .51379 Mdot
.44242 .62815 Mdot
.44265 .57613 Mdot
.69814 .54482 Mdot
.61724 .38288 Mdot
.7894 .51788 Mdot
.60787 .33537 Mdot
.64842 .37049 Mdot
.69519 .58023 Mdot
.45902 .60068 Mdot
.4087 .35702 Mdot
.39475 .37262 Mdot
.5242 .57965 Mdot
.36026 .21588 Mdot
.64722 .55785 Mdot
.22796 .52334 Mdot
.8329 .44184 Mdot
.4028 .67652 Mdot
.33455 .3551 Mdot
.76158 .54254 Mdot
.6286 .39761 Mdot
.49474 .60618 Mdot
.62807 .56263 Mdot
.35694 .33337 Mdot
.44767 .37334 Mdot
.4973 .63741 Mdot
.60662 .37456 Mdot
.25434 .51403 Mdot
.45817 .37127 Mdot
.2556 .38528 Mdot
.4862 .62786 Mdot
.40554 .24365 Mdot
.46318 .38349 Mdot
.53468 .86015 Mdot
.35507 .31606 Mdot
.67662 .55414 Mdot
.45864 .56696 Mdot
.69328 .54541 Mdot
.28133 .49324 Mdot
.47399 .37202 Mdot
.60876 .375 Mdot
.40873 .68157 Mdot
.67414 .21528 Mdot
.41268 .38752 Mdot
.66107 .52746 Mdot
.41765 .5946 Mdot
.47364 .68757 Mdot
.46115 .61751 Mdot
.56463 .61048 Mdot
.22616 .5177 Mdot
.61898 .34603 Mdot
.63366 .37006 Mdot
.45061 .59153 Mdot
.25576 .50317 Mdot
.40439 .34026 Mdot
.41519 .37319 Mdot
.27078 .77199 Mdot
.35399 .34271 Mdot
.321 .61088 Mdot
.47282 .62531 Mdot
.36141 .33823 Mdot
.79814 .45528 Mdot
.62884 .36721 Mdot
.46955 .6535 Mdot
.36893 .34497 Mdot
.57833 .21602 Mdot
.29114 .55259 Mdot
.4822 .59 Mdot
.54307 .56889 Mdot
.6376 .36781 Mdot
.28345 .66321 Mdot
.43375 .40091 Mdot
.48457 .65218 Mdot
.57277 .36462 Mdot
.23786 .3674 Mdot
.70755 .27834 Mdot
.69 .55103 Mdot
.47986 .38663 Mdot
.59369 .36807 Mdot
.52085 .647 Mdot
.28609 .51591 Mdot
.47611 .3924 Mdot
.44324 .38554 Mdot
.46139 .57647 Mdot
.46481 .5526 Mdot
.42155 .69745 Mdot
.65987 .52962 Mdot
.60826 .33931 Mdot
.44725 .63989 Mdot
.64987 .43446 Mdot
.4434 .64936 Mdot
.63101 .3462 Mdot
.88037 .60902 Mdot
.52819 .61927 Mdot
.46181 .61552 Mdot
.41395 .76998 Mdot
.68672 .54049 Mdot
.69619 .54615 Mdot
.49902 .18168 Mdot
.47343 .62478 Mdot
.33735 .32691 Mdot
.69227 .55337 Mdot
.64739 .55361 Mdot
.46705 .31159 Mdot
.4337 .59874 Mdot
.27581 .67662 Mdot
.62365 .39185 Mdot
.64396 .37696 Mdot
.64104 .56078 Mdot
.49151 .66652 Mdot
.628 .39613 Mdot
.65495 .66745 Mdot
.39391 .36455 Mdot
.31701 .25712 Mdot
.65408 .53861 Mdot
.50732 .4089 Mdot
.62578 .35862 Mdot
.71399 .75349 Mdot
.37426 .38588 Mdot
.42692 .62756 Mdot
.48163 .62121 Mdot
.26974 .51617 Mdot
.52519 .59409 Mdot
.36539 .35102 Mdot
.59806 .36218 Mdot
.45632 .78636 Mdot
.68649 .55097 Mdot
.45121 .622 Mdot
.60654 .4957 Mdot
.75322 .44991 Mdot
.56323 .26553 Mdot
.65529 .56355 Mdot
.67861 .56234 Mdot
.44038 .40056 Mdot
.45835 .38374 Mdot
.46738 .59633 Mdot
.61142 .39072 Mdot
.62754 .54697 Mdot
.63022 .34768 Mdot
.43384 .39372 Mdot
.41019 .353 Mdot
.39182 .3807 Mdot
.46601 .6617 Mdot
.41761 .34855 Mdot
.24001 .39481 Mdot
.66451 .42647 Mdot
.62172 .58159 Mdot
.71995 .26036 Mdot
.75196 .42386 Mdot
.37847 .53891 Mdot
.29083 .5235 Mdot
.37367 .35353 Mdot
.58039 .35882 Mdot
.46975 .58299 Mdot
.48348 .6082 Mdot
.48632 .39765 Mdot
.58911 .38798 Mdot
.2845 .48864 Mdot
.5912 .3917 Mdot
.29346 .511 Mdot
.34776 .34093 Mdot
.43402 .57637 Mdot
.5085 .61111 Mdot
.59555 .36094 Mdot
.4102 .34776 Mdot
.42709 .37241 Mdot
.31455 .4975 Mdot
.37421 .51041 Mdot
.4273 .38805 Mdot
.65424 .53931 Mdot
.63514 .71127 Mdot
.45606 .40904 Mdot
.45967 .62656 Mdot
.238 .55864 Mdot
.64638 .63988 Mdot
.5052 .63732 Mdot
.51793 .37364 Mdot
.17344 .54643 Mdot
.45987 .64403 Mdot
.16311 .51167 Mdot
.5292 .35888 Mdot
.68331 .53676 Mdot
.45994 .39305 Mdot
.36318 .35119 Mdot
.55459 .56813 Mdot
.25309 .47582 Mdot
.51336 .56921 Mdot
.69401 .55006 Mdot
.70178 .53931 Mdot
.60062 .21435 Mdot
.4372 .81191 Mdot
.31038 .50723 Mdot
.30015 .4978 Mdot
.40649 .36697 Mdot
.28865 .74054 Mdot
.40684 .66025 Mdot
.29218 .48853 Mdot
.38222 .72581 Mdot
.47877 .57685 Mdot
.29527 .60709 Mdot
.37486 .39549 Mdot
.64558 .56773 Mdot
.45965 .71055 Mdot
.41117 .36496 Mdot
.66755 .52921 Mdot
.68231 .3768 Mdot
.49129 .56364 Mdot
.68572 .54667 Mdot
.63585 .35172 Mdot
.51421 .22261 Mdot
.68818 .5737 Mdot
.23228 .55234 Mdot
.60956 .38819 Mdot
.45457 .27443 Mdot
.3642 .70511 Mdot
.53615 .11712 Mdot
.59605 .36968 Mdot
.38749 .34893 Mdot
.39623 .37352 Mdot
.41325 .37329 Mdot
.67474 .52931 Mdot
.40969 .3375 Mdot
.65392 .53118 Mdot
.32462 .73641 Mdot
.37375 .51149 Mdot
.29872 .49111 Mdot
.55513 .40304 Mdot
.67072 .56619 Mdot
.39844 .21455 Mdot
.6218 .16969 Mdot
.49647 .60943 Mdot
.59673 .33876 Mdot
.30814 .49989 Mdot
.48593 .859 Mdot
.26573 .51086 Mdot
.48611 .39165 Mdot
.28695 .27671 Mdot
.45013 .61571 Mdot
.62525 .76102 Mdot
.2939 .52056 Mdot
.65666 .57327 Mdot
.45078 .59366 Mdot
.58678 .30267 Mdot
.27464 .513 Mdot
.2572 .51635 Mdot
.46545 .59277 Mdot
.66775 .58245 Mdot
.41274 .35644 Mdot
.57584 .37011 Mdot
.30729 .47849 Mdot
.53173 .53872 Mdot
.52315 .59791 Mdot
.50246 .573 Mdot
.58597 .45729 Mdot
.36246 .65905 Mdot
.5989 .36373 Mdot
.33813 .72381 Mdot
.45726 .38304 Mdot
.42451 .28612 Mdot
.51146 .18443 Mdot
.53681 .38494 Mdot
.3869 .37132 Mdot
.3772 .36158 Mdot
.47689 .59068 Mdot
.36273 .66286 Mdot
.25156 .32864 Mdot
.60439 .42402 Mdot
.44852 .40892 Mdot
.41832 .37266 Mdot
.69022 .52244 Mdot
.60454 .21145 Mdot
.50848 .55845 Mdot
.64779 .3838 Mdot
.43504 .38986 Mdot
.67748 .74258 Mdot
.27926 .50725 Mdot
.3616 .23358 Mdot
.42569 .58729 Mdot
.44003 .6373 Mdot
.60854 .36108 Mdot
.64209 .35672 Mdot
.61825 .30277 Mdot
.57658 .19772 Mdot
.2284 .62877 Mdot
.77303 .41178 Mdot
.67994 .73578 Mdot
.67406 .51269 Mdot
.63453 .57652 Mdot
.54589 .34169 Mdot
.62519 .33751 Mdot
.46482 .64129 Mdot
.627 .54934 Mdot
.54313 .25954 Mdot
.71722 .57422 Mdot
.3083 .6137 Mdot
.29818 .35298 Mdot
.46947 .56145 Mdot
.63328 .56109 Mdot
.67646 .53429 Mdot
.6223 .55055 Mdot
.53012 .3595 Mdot
.46295 .60527 Mdot
.42483 .61001 Mdot
.44962 .64741 Mdot
.48724 .53117 Mdot
.49219 .62206 Mdot
.59024 .42294 Mdot
.55396 .46415 Mdot
.50709 .80501 Mdot
.5039 .6431 Mdot
.63602 .38873 Mdot
.5103 .57659 Mdot
.25499 .50371 Mdot
.46845 .57988 Mdot
.31056 .6084 Mdot
.62239 .36734 Mdot
.57718 .55872 Mdot
.76815 .40316 Mdot
.42737 .58742 Mdot
.24983 .51132 Mdot
.38165 .55409 Mdot
.77486 .54611 Mdot
.34362 .52496 Mdot
.65306 .53996 Mdot
.38702 .36346 Mdot
.58168 .37371 Mdot
.40505 .35579 Mdot
.48835 .6546 Mdot
.51718 .37547 Mdot
.70153 .47136 Mdot
.50254 .41181 Mdot
.482 .6405 Mdot
.41504 .67749 Mdot
.64925 .54603 Mdot
.39322 .34438 Mdot
.6702 .50688 Mdot
.47212 .63415 Mdot
.2815 .49721 Mdot
.27882 .51383 Mdot
.67692 .3171 Mdot
.71698 .71676 Mdot
.73957 .35281 Mdot
.60615 .36058 Mdot
.43884 .37381 Mdot
.30828 .51872 Mdot
.48646 .52057 Mdot
.65208 .35511 Mdot
.60139 .39128 Mdot
.61279 .38409 Mdot
.50351 .58203 Mdot
.36947 .35342 Mdot
.50118 .79769 Mdot
.36511 .34961 Mdot
.43326 .58384 Mdot
.44863 .38285 Mdot
.38232 .36992 Mdot
.27535 .5179 Mdot
.58736 .35768 Mdot
.43992 .39488 Mdot
.50414 .60419 Mdot
.68755 .56646 Mdot
.41018 .48536 Mdot
.29975 .56437 Mdot
.48111 .82752 Mdot
.5018 .82953 Mdot
.66556 .58759 Mdot
.69406 .75828 Mdot
.63982 .39932 Mdot
.61463 .63046 Mdot
.51164 .33209 Mdot
.50969 .62339 Mdot
.42815 .18553 Mdot
.44735 .40335 Mdot
.39136 .34354 Mdot
.49188 .59089 Mdot
.39059 .33055 Mdot
.45419 .62014 Mdot
.45156 .39014 Mdot
.32191 .53582 Mdot
.47581 .54435 Mdot
.40847 .34346 Mdot
.43915 .66335 Mdot
.43552 .5917 Mdot
.64399 .56804 Mdot
.4657 .39004 Mdot
.46124 .65683 Mdot
.39677 .83579 Mdot
.63645 .34825 Mdot
.52101 .36987 Mdot
.20548 .53528 Mdot
.59285 .36693 Mdot
.68204 .54914 Mdot
.53144 .5955 Mdot
.26063 .5056 Mdot
.66761 .57283 Mdot
.24251 .53857 Mdot
.29778 .51725 Mdot
.41959 .19665 Mdot
.64743 .54307 Mdot
.45949 .40848 Mdot
.27394 .52004 Mdot
.39792 .62851 Mdot
.4698 .38403 Mdot
.40307 .50296 Mdot
.37935 .36113 Mdot
.47172 .6091 Mdot
.5737 .30289 Mdot
.63125 .34286 Mdot
.43165 .61828 Mdot
.4505 .36305 Mdot
.54088 .34441 Mdot
.49674 .5773 Mdot
.47544 .5839 Mdot
.66103 .24796 Mdot
.35185 .26141 Mdot
.26873 .48851 Mdot
.68667 .52889 Mdot
.49996 .60305 Mdot
.2734 .5223 Mdot
.2818 .42552 Mdot
.51212 .58232 Mdot
.64869 .52071 Mdot
.3827 .60448 Mdot
.4558 .3725 Mdot
.59453 .35162 Mdot
.49429 .38205 Mdot
.26421 .5222 Mdot
.19933 .32102 Mdot
.39343 .38304 Mdot
.43689 .65941 Mdot
.47048 .64999 Mdot
.57131 .27619 Mdot
.6703 .53132 Mdot
.23207 .62932 Mdot
.47956 .61961 Mdot
.39687 .55728 Mdot
.44086 .62503 Mdot
.38749 .31437 Mdot
.64838 .55641 Mdot
.46641 .61411 Mdot
.58069 .51498 Mdot
.40662 .64102 Mdot
.25492 .517 Mdot
.38928 .76097 Mdot
.51819 .59285 Mdot
.88564 .44201 Mdot
.34159 .34901 Mdot
.41099 .34427 Mdot
.58774 .29262 Mdot
.19478 .65121 Mdot
.73131 .33592 Mdot
.65357 .53037 Mdot
.74746 .52374 Mdot
.4091 .35596 Mdot
.7657 .37414 Mdot
.67717 .77945 Mdot
.43758 .58896 Mdot
.48562 .56428 Mdot
.48612 .39163 Mdot
.36065 .34042 Mdot
.47112 .40713 Mdot
.50044 .64849 Mdot
.39931 .65126 Mdot
.42621 .35309 Mdot
.50354 .61171 Mdot
.39778 .57388 Mdot
.57628 .36579 Mdot
.67222 .58414 Mdot
.62437 .35202 Mdot
.5845 .36861 Mdot
.58874 .67779 Mdot
.57659 .20259 Mdot
.62976 .34481 Mdot
.64046 .39758 Mdot
.29819 .60124 Mdot
.42226 .70179 Mdot
.27667 .52816 Mdot
.62195 .80631 Mdot
.41139 .37511 Mdot
.46018 .60532 Mdot
.65843 .59058 Mdot
.59035 .65626 Mdot
.36167 .40577 Mdot
.26187 .30727 Mdot
.46984 .63759 Mdot
.41515 .36749 Mdot
.53034 .35537 Mdot
.43037 .54978 Mdot
.43678 .29342 Mdot
.43585 .63661 Mdot
.4779 .38936 Mdot
.61027 .74693 Mdot
.60385 .50672 Mdot
.40248 .26737 Mdot
.70294 .51955 Mdot
.45143 .6371 Mdot
.65836 .53601 Mdot
.61824 .35215 Mdot
.2585 .51213 Mdot
.26883 .48939 Mdot
.46156 .59063 Mdot
.36744 .62807 Mdot
.38636 .40343 Mdot
.4332 .59195 Mdot
.45728 .58076 Mdot
.52915 .35856 Mdot
.45469 .58247 Mdot
.46781 .65005 Mdot
.45745 .6509 Mdot
.41016 .63077 Mdot
.64783 .3725 Mdot
.60217 .50098 Mdot
.477 .66192 Mdot
.4169 .55493 Mdot
.57514 .38121 Mdot
.75774 .5193 Mdot
.58471 .35807 Mdot
.75928 .68018 Mdot
.63261 .36272 Mdot
.28068 .48584 Mdot
.56223 .30575 Mdot
.37575 .65094 Mdot
.62375 .57164 Mdot
.64098 .34218 Mdot
.29248 .50092 Mdot
.60388 .3556 Mdot
.44985 .37936 Mdot
.8051 .37743 Mdot
.71438 .57802 Mdot
.22134 .6014 Mdot
.67115 .31204 Mdot
.42234 .24795 Mdot
.42413 .39619 Mdot
.64477 .55925 Mdot
.68514 .6972 Mdot
.45232 .65287 Mdot
.27872 .52103 Mdot
.46976 .59286 Mdot
.64918 .3691 Mdot
.41178 .36858 Mdot
.37357 .76144 Mdot
.2614 .4968 Mdot
.67378 .24239 Mdot
.42003 .37809 Mdot
.43144 .64136 Mdot
.64748 .38374 Mdot
.70887 .24623 Mdot
.6221 .34844 Mdot
.35451 .52721 Mdot
.63043 .52526 Mdot
.45318 .73478 Mdot
.67285 .56041 Mdot
.41088 .40188 Mdot
.85018 .44527 Mdot
.57422 .82914 Mdot
.67813 .57587 Mdot
.36459 .28851 Mdot
.48753 .56662 Mdot
.50493 .57409 Mdot
.5917 .53012 Mdot
.66529 .5216 Mdot
.49693 .61282 Mdot
.52137 .36517 Mdot
.68219 .4189 Mdot
.33352 .3066 Mdot
.38508 .3596 Mdot
.46057 .62132 Mdot
.573 .37432 Mdot
.59353 .39285 Mdot
.3685 .35479 Mdot
.58628 .35335 Mdot
.42541 .61135 Mdot
.67124 .56397 Mdot
.48348 .41288 Mdot
.26929 .49714 Mdot
.39413 .81468 Mdot
.30378 .52403 Mdot
.39058 .37467 Mdot
.41202 .58443 Mdot
.41021 .35254 Mdot
.1204 .52112 Mdot
.42654 .62247 Mdot
.68988 .54779 Mdot
.48951 .58169 Mdot
.44685 .63489 Mdot
.49321 .5658 Mdot
.43456 .36008 Mdot
.19276 .57352 Mdot
.50444 .60914 Mdot
.60939 .37644 Mdot
.53522 .81745 Mdot
.50774 .57359 Mdot
.33479 .52645 Mdot
.33396 .66342 Mdot
.427 .2364 Mdot
.62881 .58283 Mdot
.39729 .34344 Mdot
.68658 .55757 Mdot
.71637 .55376 Mdot
.68191 .54873 Mdot
.55016 .80214 Mdot
.66802 .71097 Mdot
.18041 .52268 Mdot
.46665 .75443 Mdot
.5708 .65214 Mdot
.67746 .52287 Mdot
.25967 .44223 Mdot
.62699 .56718 Mdot
.66699 .53267 Mdot
.65218 .86736 Mdot
.63212 .57808 Mdot
.46709 .62409 Mdot
.48646 .55443 Mdot
.73061 .44847 Mdot
.27587 .6037 Mdot
.45395 .58709 Mdot
.49832 .59668 Mdot
.26299 .51584 Mdot
.36702 .6025 Mdot
.51758 .37553 Mdot
.42919 .19764 Mdot
.77142 .45537 Mdot
.4686 .59182 Mdot
.50148 .60214 Mdot
.40157 .6499 Mdot
.80871 .32092 Mdot
.61448 .66161 Mdot
.67957 .52167 Mdot
.48229 .67436 Mdot
.46842 .83665 Mdot
.42081 .6107 Mdot
.51358 .59174 Mdot
.47296 .56293 Mdot
.40908 .35676 Mdot
.65915 .51498 Mdot
.47413 .67631 Mdot
.43183 .21822 Mdot
.43417 .57884 Mdot
.54377 .39094 Mdot
.2119 .64211 Mdot
.46791 .61915 Mdot
.6165 .55634 Mdot
.4761 .57127 Mdot
.64476 .54316 Mdot
.64577 .57433 Mdot
.40212 .61107 Mdot
.62568 .77897 Mdot
.63608 .52448 Mdot
.43583 .58044 Mdot
.4198 .35499 Mdot
.60425 .82664 Mdot
.4738 .61015 Mdot
.27239 .48251 Mdot
.4798 .6214 Mdot
.24925 .50159 Mdot
.45048 .58023 Mdot
.36567 .34911 Mdot
.69391 .63063 Mdot
.40316 .36545 Mdot
.24938 .67187 Mdot
.36367 .33453 Mdot
.65858 .24544 Mdot
.65651 .52119 Mdot
.54625 .33705 Mdot
.23155 .31468 Mdot
.5186 .37124 Mdot
.57954 .48778 Mdot
.52909 .48581 Mdot
.61016 .39098 Mdot
.69858 .55568 Mdot
.32001 .69838 Mdot
.55588 .26703 Mdot
.55187 .29674 Mdot
.40305 .3864 Mdot
.24493 .27989 Mdot
.29757 .25704 Mdot
.5072 .59794 Mdot
.59504 .78186 Mdot
.52898 .74398 Mdot
.51326 .58521 Mdot
.53275 .60836 Mdot
.45459 .36371 Mdot
.47457 .64838 Mdot
.61626 .46675 Mdot
.41048 .38449 Mdot
.29451 .50406 Mdot
.66665 .53572 Mdot
.25876 .48597 Mdot
.55626 .27624 Mdot
.53216 .4894 Mdot
.44548 .39086 Mdot
.41019 .64131 Mdot
.49464 .58579 Mdot
.638 .56056 Mdot
.62717 .51318 Mdot
.65714 .58296 Mdot
.30936 .49901 Mdot
.41182 .38324 Mdot
.61751 .65155 Mdot
.49261 .59875 Mdot
.6638 .56432 Mdot
.67232 .3337 Mdot
.49691 .603 Mdot
.59968 .354 Mdot
.46337 .56046 Mdot
.68325 .57374 Mdot
.45424 .58254 Mdot
.67309 .56445 Mdot
.39232 .36351 Mdot
.41918 .60948 Mdot
.48798 .59069 Mdot
.70686 .24971 Mdot
.28192 .48869 Mdot
.66079 .5219 Mdot
.46785 .44401 Mdot
.44136 .65031 Mdot
.4911 .264 Mdot
.4574 .63758 Mdot
.73252 .56563 Mdot
.42976 .65861 Mdot
.53393 .35305 Mdot
.50574 .55345 Mdot
.47256 .6106 Mdot
.54353 .50579 Mdot
.53 .76525 Mdot
.64554 .50594 Mdot
.64341 .38719 Mdot
.61998 .54707 Mdot
.32085 .36948 Mdot
.45137 .40672 Mdot
.41637 .33835 Mdot
.25323 .61366 Mdot
.40938 .59732 Mdot
.45141 .61425 Mdot
.58679 .33846 Mdot
.29926 .50414 Mdot
.6568 .56488 Mdot
.29397 .50894 Mdot
.47561 .19242 Mdot
.30667 .50652 Mdot
.36396 .35118 Mdot
.3449 .31836 Mdot
.6567 .65077 Mdot
.26401 .51632 Mdot
.66307 .58429 Mdot
.29119 .35835 Mdot
.50189 .63487 Mdot
.22897 .49393 Mdot
.28022 .49826 Mdot
.244 .27236 Mdot
.47571 .64515 Mdot
.58545 .48192 Mdot
.6151 .34232 Mdot
.28296 .51709 Mdot
.62133 .38224 Mdot
.45775 .58748 Mdot
.46934 .24421 Mdot
.65556 .52722 Mdot
.58964 .39862 Mdot
.52149 .63422 Mdot
.30615 .49819 Mdot
.4364 .38821 Mdot
.55665 .3647 Mdot
.63306 .39075 Mdot
.77403 .57465 Mdot
.37212 .7523 Mdot
.41006 .38236 Mdot
.29439 .30602 Mdot
.62774 .38596 Mdot
.51538 .59152 Mdot
.38571 .57532 Mdot
.42589 .62625 Mdot
.58375 .30025 Mdot
.39673 .34271 Mdot
.68821 .44006 Mdot
.49496 .58377 Mdot
.4659 .64434 Mdot
.60648 .56915 Mdot
.39823 .37138 Mdot
.66344 .5477 Mdot
.61975 .55712 Mdot
.39203 .36452 Mdot
.67478 .55396 Mdot
.29028 .52105 Mdot
.69416 .40447 Mdot
.63065 .38467 Mdot
.61212 .37383 Mdot
.41715 .37254 Mdot
.41809 .34695 Mdot
.40679 .35052 Mdot
.46227 .56079 Mdot
.65202 .56124 Mdot
.45898 .5687 Mdot
.49063 .56539 Mdot
.66312 .49975 Mdot
.64404 .58835 Mdot
.47753 .5672 Mdot
.418 .26722 Mdot
.23197 .50798 Mdot
.42506 .35651 Mdot
.62293 .34264 Mdot
.79486 .43069 Mdot
.5694 .38329 Mdot
.4581 .62317 Mdot
.57239 .21768 Mdot
.67132 .57919 Mdot
.26794 .51405 Mdot
.24136 .51275 Mdot
.26271 .50435 Mdot
.60187 .32706 Mdot
.63457 .53631 Mdot
.42742 .19851 Mdot
.45742 .61989 Mdot
.58683 .45662 Mdot
.33026 .71019 Mdot
.48205 .19968 Mdot
.62692 .34322 Mdot
.49874 .60143 Mdot
.50045 .38982 Mdot
.69366 .67604 Mdot
.4369 .63523 Mdot
.47327 .65571 Mdot
.48875 .33052 Mdot
.38815 .59523 Mdot
.63337 .52427 Mdot
.57297 .19195 Mdot
.49276 .55889 Mdot
.61303 .5118 Mdot
.28715 .76877 Mdot
.45326 .62836 Mdot
.47775 .63323 Mdot
.48022 .60226 Mdot
.48086 .57786 Mdot
.61602 .55248 Mdot
.28893 .65565 Mdot
.65038 .37772 Mdot
.55796 .44598 Mdot
.63081 .38672 Mdot
.47819 .39056 Mdot
.61028 .48412 Mdot
.69789 .56664 Mdot
.26869 .51581 Mdot
.75443 .61337 Mdot
.51469 .17451 Mdot
.44054 .40115 Mdot
.64707 .68189 Mdot
.27587 .49436 Mdot
.52038 .60322 Mdot
.25401 .4876 Mdot
.36492 .34246 Mdot
.607 .38307 Mdot
.47362 .54703 Mdot
.64242 .58068 Mdot
.6903 .57093 Mdot
.49645 .61071 Mdot
.49925 .84873 Mdot
.59762 .35337 Mdot
.61496 .41548 Mdot
.49626 .57473 Mdot
.47497 .65585 Mdot
.66601 .54495 Mdot
.42728 .36569 Mdot
.21733 .41201 Mdot
.29245 .49347 Mdot
.42403 .63992 Mdot
.47644 .57745 Mdot
.57054 .19695 Mdot
.58853 .3688 Mdot
.40928 .39689 Mdot
.50374 .58347 Mdot
.66951 .29619 Mdot
.50202 .58205 Mdot
.44361 .54383 Mdot
.41734 .35628 Mdot
.43944 .67053 Mdot
.50739 .61016 Mdot
.5303 .64345 Mdot
.62506 .38514 Mdot
.68531 .5441 Mdot
.60936 .56456 Mdot
.49269 .39664 Mdot
.60188 .35333 Mdot
.47774 .56887 Mdot
.58956 .36538 Mdot
.51389 .58142 Mdot
.49891 .61605 Mdot
.63047 .34591 Mdot
.66411 .54789 Mdot
.73182 .49269 Mdot
.60372 .49633 Mdot
.48538 .57839 Mdot
.49833 .5544 Mdot
.26544 .6144 Mdot
.17057 .43435 Mdot
.46696 .63682 Mdot
.68674 .57209 Mdot
.49299 .59567 Mdot
.62469 .37474 Mdot
.30353 .50924 Mdot
.68637 .56921 Mdot
.43135 .37381 Mdot
.42919 .39959 Mdot
.76637 .39876 Mdot
.37526 .36026 Mdot
.51293 .62386 Mdot
.70023 .60027 Mdot
.67271 .59267 Mdot
.332 .79247 Mdot
.39186 .36646 Mdot
.26319 .5252 Mdot
.47027 .5851 Mdot
.60829 .24006 Mdot
.59369 .33364 Mdot
.88668 .42659 Mdot
.42156 .19796 Mdot
.3074 .52284 Mdot
.25055 .31068 Mdot
.482 .40086 Mdot
.49786 .62603 Mdot
.25721 .51023 Mdot
.45028 .39921 Mdot
.51362 .61378 Mdot
.54118 .56506 Mdot
.21896 .61117 Mdot
.4794 .37964 Mdot
.58964 .35909 Mdot
.44048 .35777 Mdot
.26075 .47741 Mdot
.36414 .35079 Mdot
.68951 .57459 Mdot
.46776 .61081 Mdot
.43167 .68391 Mdot
.43105 .36953 Mdot
.363 .34731 Mdot
.46454 .56209 Mdot
.69646 .55017 Mdot
.39894 .33153 Mdot
.45978 .59381 Mdot
.59971 .63272 Mdot
.7005 .51815 Mdot
.41907 .38533 Mdot
.46207 .64807 Mdot
.40638 .69104 Mdot
.42351 .37444 Mdot
.42776 .35792 Mdot
.49765 .61189 Mdot
.28614 .52215 Mdot
.42676 .58367 Mdot
.63297 .3591 Mdot
.1934 .59102 Mdot
.62226 .37578 Mdot
.31642 .38446 Mdot
.39937 .59403 Mdot
.45563 .25413 Mdot
.68362 .58183 Mdot
.25464 .48054 Mdot
.80059 .42695 Mdot
.48836 .65255 Mdot
.68946 .75553 Mdot
.51741 .40788 Mdot
.45616 .84404 Mdot
.83197 .50746 Mdot
.28088 .50155 Mdot
.60925 .35347 Mdot
.47801 .63244 Mdot
.59203 .3397 Mdot
.25875 .49693 Mdot
.33954 .73222 Mdot
.46303 .64938 Mdot
.6482 .55413 Mdot
.44222 .57302 Mdot
.65274 .53971 Mdot
.49587 .60551 Mdot
.39299 .585 Mdot
.5382 .3361 Mdot
.29587 .5535 Mdot
.50772 .62685 Mdot
.80189 .36859 Mdot
.37894 .41462 Mdot
.28587 .49541 Mdot
.44801 .5732 Mdot
.43557 .40621 Mdot
.59767 .39399 Mdot
.44437 .51469 Mdot
.41057 .35506 Mdot
.59928 .34041 Mdot
.67405 .54618 Mdot
.38857 .36154 Mdot
.40969 .39404 Mdot
.50175 .66219 Mdot
.25032 .50386 Mdot
.60282 .38594 Mdot
.47158 .61404 Mdot
.47327 .64516 Mdot
.29794 .31568 Mdot
.35093 .41215 Mdot
.60424 .55751 Mdot
.66709 .21609 Mdot
.625 .58665 Mdot
.29133 .48922 Mdot
.41475 .35414 Mdot
.46442 .63577 Mdot
.43116 .61444 Mdot
.55087 .32933 Mdot
.66485 .52352 Mdot
.48619 .38393 Mdot
.60952 .67875 Mdot
.38058 .33992 Mdot
.30739 .64623 Mdot
.69306 .55155 Mdot
.30461 .64413 Mdot
.25986 .47844 Mdot
.69856 .73113 Mdot
.32206 .57131 Mdot
.61156 .34198 Mdot
.30959 .65091 Mdot
.6586 .57453 Mdot
.50396 .59303 Mdot
.46247 .40752 Mdot
.38629 .37389 Mdot
.66751 .53971 Mdot
.48252 .39293 Mdot
.28087 .51625 Mdot
.48155 .63269 Mdot
.3908 .23291 Mdot
.738 .41069 Mdot
.43811 .37055 Mdot
.46651 .53829 Mdot
.61547 .38206 Mdot
.49585 .62539 Mdot
.27627 .48137 Mdot
.59881 .37575 Mdot
.3399 .35752 Mdot
.68455 .42664 Mdot
.45846 .58999 Mdot
.62007 .23171 Mdot
.59668 .36008 Mdot
.22575 .3547 Mdot
.46173 .59743 Mdot
.62746 .38598 Mdot
.38411 .63098 Mdot
.47574 .2098 Mdot
.49288 .43001 Mdot
.66815 .78941 Mdot
.48382 .37835 Mdot
.47463 .39783 Mdot
.51235 .23052 Mdot
.53264 .29495 Mdot
.58602 .34559 Mdot
.36439 .35051 Mdot
.34857 .64079 Mdot
.62078 .38371 Mdot
.48617 .5639 Mdot
.45582 .63407 Mdot
.58856 .67196 Mdot
.52483 .42472 Mdot
.36057 .34776 Mdot
.72054 .34055 Mdot
.44187 .6498 Mdot
.52244 .63987 Mdot
.43538 .61098 Mdot
.69871 .53402 Mdot
.59536 .38035 Mdot
.73904 .28697 Mdot
.60654 .35021 Mdot
.35048 .24602 Mdot
.41093 .3741 Mdot
.40696 .33958 Mdot
.46468 .62123 Mdot
.42288 .25453 Mdot
.3732 .7012 Mdot
.42575 .6057 Mdot
.45113 .27229 Mdot
.38624 .76598 Mdot
.52332 .63346 Mdot
.62885 .52558 Mdot
.45932 .54849 Mdot
.70934 .55246 Mdot
.62686 .39155 Mdot
.27574 .50639 Mdot
.26482 .4709 Mdot
.60278 .38464 Mdot
.45008 .61335 Mdot
.46253 .27722 Mdot
.43983 .63095 Mdot
.50709 .59169 Mdot
.35361 .23412 Mdot
.30947 .51873 Mdot
.4 .34879 Mdot
.26543 .4916 Mdot
.66638 .53189 Mdot
.8712 .64421 Mdot
.29893 .50714 Mdot
.39085 .70739 Mdot
.2789 .69059 Mdot
.30713 .65064 Mdot
.69292 .56794 Mdot
.30157 .47893 Mdot
.5962 .35142 Mdot
.51155 .86921 Mdot
.16553 .45542 Mdot
.58207 .40231 Mdot
.45226 .59834 Mdot
.70101 .56345 Mdot
.65999 .58654 Mdot
.59967 .40381 Mdot
.64944 .57476 Mdot
.40713 .67003 Mdot
.49751 .58274 Mdot
.58966 .34325 Mdot
.73613 .4349 Mdot
.63253 .39158 Mdot
.68802 .39166 Mdot
.44775 .57158 Mdot
.69294 .55749 Mdot
.44356 .55676 Mdot
.68588 .59854 Mdot
.40746 .39654 Mdot
.52047 .59812 Mdot
.27681 .51721 Mdot
.56917 .43916 Mdot
.41509 .38204 Mdot
.57122 .21963 Mdot
.6383 .55801 Mdot
.64881 .32001 Mdot
.64463 .56982 Mdot
.70181 .5487 Mdot
.58417 .36943 Mdot
.63749 .53858 Mdot
.47831 .63379 Mdot
.38895 .27823 Mdot
.63953 .54556 Mdot
.61576 .36243 Mdot
.26959 .50648 Mdot
.67127 .55235 Mdot
.45764 .36503 Mdot
.48122 .58584 Mdot
.45501 .38653 Mdot
.53985 .32766 Mdot
.69697 .54665 Mdot
.30686 .48418 Mdot
.39624 .34063 Mdot
.25213 .50463 Mdot
.37201 .77537 Mdot
.62765 .33799 Mdot
.26712 .30663 Mdot
.41152 .69087 Mdot
.64433 .58309 Mdot
.53838 .33185 Mdot
.46513 .63329 Mdot
.47987 .58462 Mdot
.27684 .47348 Mdot
.65919 .58667 Mdot
.57039 .83512 Mdot
.74162 .55911 Mdot
.69386 .41637 Mdot
.63508 .33999 Mdot
.69762 .26402 Mdot
.65268 .43466 Mdot
.27593 .71997 Mdot
.47981 .66781 Mdot
.48089 .40128 Mdot
.4472 .62106 Mdot
.80414 .44132 Mdot
.30757 .49862 Mdot
.21411 .44349 Mdot
.40055 .6222 Mdot
.39507 .35267 Mdot
.47579 .5967 Mdot
.4604 .49298 Mdot
.44104 .55239 Mdot
.28973 .52307 Mdot
.56066 .4107 Mdot
.6224 .56836 Mdot
.27115 .49569 Mdot
.41619 .39282 Mdot
.35104 .68826 Mdot
.50871 .62167 Mdot
.49081 .65514 Mdot
.3775 .33905 Mdot
.64624 .55861 Mdot
.47119 .39095 Mdot
.63016 .3851 Mdot
.28359 .51056 Mdot
.4728 .58209 Mdot
.41747 .65256 Mdot
.4929 .26573 Mdot
.59908 .38607 Mdot
.38797 .33807 Mdot
.61998 .34881 Mdot
.47365 .40414 Mdot
.48657 .5498 Mdot
.40795 .33902 Mdot
.49501 .63282 Mdot
.76394 .34971 Mdot
.34686 .24038 Mdot
.54612 .76821 Mdot
.39269 .35028 Mdot
.32059 .63809 Mdot
.62411 .36679 Mdot
.63074 .35948 Mdot
.45894 .72857 Mdot
.36672 .57971 Mdot
.32002 .33611 Mdot
.77888 .57308 Mdot
.63171 .3843 Mdot
.61882 .37449 Mdot
.45689 .39324 Mdot
.64098 .53694 Mdot
.70526 .56394 Mdot
.48222 .39597 Mdot
.23207 .5578 Mdot
.65696 .56486 Mdot
.67056 .76939 Mdot
.3275 .35437 Mdot
.52017 .64614 Mdot
.60047 .30392 Mdot
.2773 .51217 Mdot
.24407 .55823 Mdot
.47401 .4942 Mdot
.46867 .64163 Mdot
.58376 .19744 Mdot
.42239 .36511 Mdot
.26714 .64428 Mdot
.76179 .67526 Mdot
.46289 .65054 Mdot
.46083 .60322 Mdot
.44319 .61387 Mdot
.31424 .50851 Mdot
.71153 .6088 Mdot
.47449 .64264 Mdot
.22591 .55453 Mdot
.43774 .64907 Mdot
.34685 .54312 Mdot
.26798 .48964 Mdot
.551 .63435 Mdot
.5102 .35941 Mdot
.43549 .20979 Mdot
.5673 .59144 Mdot
.63238 .37815 Mdot
.50572 .3788 Mdot
.6215 .39132 Mdot
.54327 .79909 Mdot
.31986 .5751 Mdot
.62075 .52916 Mdot
.47184 .63881 Mdot
.39389 .37743 Mdot
.66508 .58536 Mdot
.51653 .25813 Mdot
.71322 .82954 Mdot
.61578 .3972 Mdot
.12922 .52208 Mdot
.62768 .35361 Mdot
.4011 .38974 Mdot
.66712 .54394 Mdot
.65727 .71765 Mdot
.58979 .45811 Mdot
.67281 .55481 Mdot
.71276 .47744 Mdot
.64534 .5997 Mdot
.31783 .64771 Mdot
.65839 .59516 Mdot
.61914 .36272 Mdot
.57339 .34267 Mdot
.53112 .63256 Mdot
.46974 .62628 Mdot
.52572 .48874 Mdot
.39757 .70043 Mdot
.46822 .62989 Mdot
.40973 .38379 Mdot
.21909 .35519 Mdot
.48877 .39304 Mdot
.62886 .56298 Mdot
.63546 .39484 Mdot
.46411 .60182 Mdot
.49101 .57702 Mdot
.51135 .61253 Mdot
.68306 .21897 Mdot
.65325 .77854 Mdot
.50416 .6084 Mdot
.41643 .62797 Mdot
.39166 .36077 Mdot
.32671 .51689 Mdot
.81165 .47258 Mdot
.34958 .59016 Mdot
.43515 .63908 Mdot
.2735 .48939 Mdot
.28599 .52902 Mdot
.5138 .61514 Mdot
.41329 .23398 Mdot
.38024 .27896 Mdot
.47201 .61368 Mdot
.354 .54804 Mdot
.54845 .27694 Mdot
.36673 .35418 Mdot
.42921 .37081 Mdot
.61691 .5576 Mdot
.39394 .3794 Mdot
.36332 .33359 Mdot
.66663 .69891 Mdot
.50778 .38512 Mdot
.63187 .42865 Mdot
.30936 .49878 Mdot
.43152 .61993 Mdot
.62793 .59091 Mdot
.56948 .3106 Mdot
.60832 .38955 Mdot
.67947 .56896 Mdot
.60148 .39667 Mdot
.30632 .5272 Mdot
.23481 .61744 Mdot
.3858 .37422 Mdot
.63648 .37616 Mdot
.68417 .42548 Mdot
.27195 .48927 Mdot
.59106 .34981 Mdot
.46463 .25748 Mdot
.49912 .5676 Mdot
.68284 .72524 Mdot
.42848 .59425 Mdot
.5009 .85626 Mdot
.59086 .35106 Mdot
.5349 .35423 Mdot
.4569 .61356 Mdot
.41969 .37728 Mdot
.38953 .60871 Mdot
.43464 .63629 Mdot
.43536 .37784 Mdot
.5067 .59735 Mdot
.26495 .48455 Mdot
.71188 .54013 Mdot
.52671 .39636 Mdot
.41312 .15703 Mdot
.25205 .49821 Mdot
.50847 .25764 Mdot
.46792 .63728 Mdot
.37387 .75954 Mdot
.67027 .55357 Mdot
.47083 .65376 Mdot
.49101 .70085 Mdot
.64893 .53492 Mdot
.68435 .56066 Mdot
.46274 .57498 Mdot
.6111 .3434 Mdot
.42132 .38167 Mdot
.2676 .49165 Mdot
.32698 .77351 Mdot
.44235 .59901 Mdot
.49041 .59275 Mdot
.27411 .49481 Mdot
.62057 .37561 Mdot
.48681 .57515 Mdot
.62416 .27405 Mdot
.41163 .8374 Mdot
.59673 .38872 Mdot
.47055 .55522 Mdot
.73522 .65259 Mdot
.68476 .60171 Mdot
.14297 .48387 Mdot
.25673 .54019 Mdot
.40158 .3437 Mdot
.38598 .60099 Mdot
.89296 .5218 Mdot
.27443 .50754 Mdot
.43069 .20418 Mdot
.5098 .59378 Mdot
.48863 .60051 Mdot
.66404 .58105 Mdot
.46735 .56684 Mdot
.66779 .52703 Mdot
.36116 .18491 Mdot
.60986 .19615 Mdot
.64298 .55238 Mdot
.63625 .57908 Mdot
.43209 .71528 Mdot
.81057 .46653 Mdot
.67204 .53993 Mdot
.45035 .56044 Mdot
.57926 .81635 Mdot
.53912 .62705 Mdot
.27654 .47314 Mdot
.536 .32001 Mdot
.58206 .56976 Mdot
.36449 .46574 Mdot
.75724 .53393 Mdot
.57801 .56235 Mdot
.38726 .39434 Mdot
.63456 .358 Mdot
.45042 .64987 Mdot
.37934 .36614 Mdot
.41344 .33791 Mdot
.42693 .55851 Mdot
.43358 .62798 Mdot
.64781 .54059 Mdot
.30876 .51442 Mdot
.58217 .37805 Mdot
.49787 .59591 Mdot
.46169 .36569 Mdot
.29671 .49999 Mdot
.63073 .55938 Mdot
.44388 .72904 Mdot
.27466 .52626 Mdot
.47302 .54195 Mdot
.48336 .61685 Mdot
.46977 .56159 Mdot
.40528 .68005 Mdot
.643 .3561 Mdot
.58023 .28986 Mdot
.44508 .56701 Mdot
.48137 .19049 Mdot
.37375 .50716 Mdot
.42835 .66703 Mdot
.65299 .5693 Mdot
.60087 .32973 Mdot
.41985 .40321 Mdot
.35054 .70865 Mdot
.45057 .59336 Mdot
.64632 .78102 Mdot
.61046 .66746 Mdot
.42915 .40377 Mdot
.67421 .52198 Mdot
.2661 .51237 Mdot
.42597 .61152 Mdot
.56065 .80913 Mdot
.45584 .63079 Mdot
.40018 .68316 Mdot
.42339 .3579 Mdot
.63506 .35659 Mdot
.44505 .8444 Mdot
.41338 .33809 Mdot
.68613 .55858 Mdot
.68163 .78524 Mdot
.69137 .58077 Mdot
.62248 .55759 Mdot
.60902 .78969 Mdot
.64391 .36181 Mdot
.89395 .50409 Mdot
.15966 .46002 Mdot
.40488 .6471 Mdot
.62716 .36774 Mdot
.65806 .54193 Mdot
.49484 .62619 Mdot
.65966 .59235 Mdot
.64555 .52858 Mdot
.52208 .58429 Mdot
.48826 .60927 Mdot
.60173 .49356 Mdot
.72254 .72185 Mdot
.26226 .5078 Mdot
.68676 .54028 Mdot
.5561 .66815 Mdot
.48464 .63861 Mdot
.4581 .61948 Mdot
.53933 .26394 Mdot
.28354 .52334 Mdot
.54822 .51242 Mdot
.50572 .58656 Mdot
.6253 .21565 Mdot
.47236 .54386 Mdot
.61641 .54639 Mdot
.59499 .38692 Mdot
.41533 .22678 Mdot
.58462 .30076 Mdot
.66771 .52383 Mdot
.2919 .48225 Mdot
.60734 .56069 Mdot
.39344 .70711 Mdot
.64088 .37928 Mdot
.6832 .57379 Mdot
.49485 .38291 Mdot
.60285 .37064 Mdot
.59275 .34932 Mdot
.53837 .81758 Mdot
.38386 .34517 Mdot
.3045 .48633 Mdot
.60978 .38489 Mdot
.61496 .62938 Mdot
.61444 .35739 Mdot
.56172 .67569 Mdot
.42042 .60255 Mdot
.22179 .57996 Mdot
.6352 .44209 Mdot
.38575 .66204 Mdot
.63939 .34804 Mdot
.25952 .49728 Mdot
.47034 .57532 Mdot
.65121 .57648 Mdot
.29618 .50925 Mdot
.56438 .33743 Mdot
.42368 .35248 Mdot
.64111 .56893 Mdot
.65168 .37472 Mdot
.68864 .54359 Mdot
.30795 .68806 Mdot
.20159 .60675 Mdot
.62558 .26675 Mdot
.58426 .46095 Mdot
.51191 .60966 Mdot
.77886 .52283 Mdot
.52552 .58622 Mdot
.43583 .6322 Mdot
.41893 .38485 Mdot
.25227 .61444 Mdot
.66376 .54724 Mdot
.44925 .84836 Mdot
.63779 .37023 Mdot
.58433 .19127 Mdot
.70376 .51458 Mdot
.46617 .65645 Mdot
.64284 .54188 Mdot
.68254 .58726 Mdot
.52325 .76621 Mdot
.35767 .33237 Mdot
.53879 .56839 Mdot
.5252 .57315 Mdot
.47505 .66673 Mdot
.5928 .35026 Mdot
.55575 .21905 Mdot
.47643 .3937 Mdot
.16987 .56763 Mdot
.4282 .36106 Mdot
.45445 .3145 Mdot
.6324 .54424 Mdot
.29759 .51361 Mdot
.46082 .61873 Mdot
.71377 .52073 Mdot
.674 .5241 Mdot
.25099 .52841 Mdot
.27809 .51892 Mdot
.51265 .21693 Mdot
.63166 .34619 Mdot
.50199 .63276 Mdot
.46391 .64741 Mdot
.45454 .57159 Mdot
.42762 .59083 Mdot
.61553 .3976 Mdot
.49687 .5715 Mdot
.5721 .36928 Mdot
.61075 .63577 Mdot
.60098 .19806 Mdot
.50353 .38334 Mdot
.41231 .53071 Mdot
.63837 .57475 Mdot
.61744 .62286 Mdot
.48999 .5401 Mdot
.3237 .25406 Mdot
.43234 .80175 Mdot
.52599 .61954 Mdot
.45855 .39718 Mdot
.37295 .57536 Mdot
.3699 .34516 Mdot
.12546 .40985 Mdot
.49407 .27643 Mdot
.67828 .77501 Mdot
.48609 .63416 Mdot
.54265 .265 Mdot
.44474 .53753 Mdot
.52143 .5759 Mdot
.51856 .28171 Mdot
.70698 .31641 Mdot
.71974 .45806 Mdot
.28175 .52855 Mdot
.47379 .58821 Mdot
.669 .59536 Mdot
.47867 .63498 Mdot
.45303 .62178 Mdot
.51174 .59585 Mdot
.64785 .3856 Mdot
.47308 .54776 Mdot
.46372 .55945 Mdot
.37075 .43763 Mdot
.30027 .60933 Mdot
.4464 .36322 Mdot
.43182 .73681 Mdot
.298 .50536 Mdot
.63907 .54952 Mdot
.67777 .48234 Mdot
.61236 .3417 Mdot
.52201 .75539 Mdot
.45188 .56593 Mdot
.65488 .44277 Mdot
.65232 .37222 Mdot
.2846 .51237 Mdot
.46103 .40938 Mdot
.62365 .82186 Mdot
.38956 .37273 Mdot
.50361 .38887 Mdot
.41244 .37954 Mdot
.57988 .59935 Mdot
.64955 .53921 Mdot
.51496 .60423 Mdot
.6119 .38261 Mdot
.42774 .38425 Mdot
.26642 .60303 Mdot
.43634 .61232 Mdot
.39374 .3637 Mdot
.51459 .60174 Mdot
.22103 .59851 Mdot
.27175 .33289 Mdot
.36222 .33624 Mdot
.61598 .32541 Mdot
.60715 .36745 Mdot
.29343 .51946 Mdot
.63446 .55819 Mdot
.66517 .57912 Mdot
.59873 .37356 Mdot
.17071 .41068 Mdot
.43751 .63978 Mdot
.49121 .63064 Mdot
.48573 .18854 Mdot
.47629 .62919 Mdot
.34231 .67518 Mdot
.50013 .39237 Mdot
.63287 .56658 Mdot
.5008 .61844 Mdot
.48518 .5766 Mdot
.46447 .58749 Mdot
.30281 .68734 Mdot
.43131 .36669 Mdot
.43238 .64044 Mdot
.26754 .52038 Mdot
.41195 .40304 Mdot
.492 .63127 Mdot
.47553 .66584 Mdot
.66776 .57807 Mdot
.58374 .17848 Mdot
.62785 .34959 Mdot
.42368 .39489 Mdot
.40136 .34012 Mdot
.53812 .31629 Mdot
.63029 .50362 Mdot
.49896 .39296 Mdot
.18487 .59558 Mdot
.52783 .36176 Mdot
.28075 .49248 Mdot
.48211 .35357 Mdot
.35456 .49342 Mdot
.44184 .398 Mdot
.60139 .39935 Mdot
.43004 .58195 Mdot
.42681 .63264 Mdot
.41187 .20043 Mdot
.46323 .65796 Mdot
.27013 .51262 Mdot
.57279 .37815 Mdot
.66033 .57334 Mdot
.28185 .51412 Mdot
.62712 .35538 Mdot
.64656 .56094 Mdot
.50522 .57029 Mdot
.49054 .56175 Mdot
.67993 .56632 Mdot
.6634 .58481 Mdot
.47504 .61587 Mdot
.37703 .379 Mdot
.61825 .56002 Mdot
.69142 .56435 Mdot
.38099 .36926 Mdot
.40107 .38491 Mdot
.46872 .67618 Mdot
.62676 .3622 Mdot
.48085 .56397 Mdot
.381 .36044 Mdot
.30638 .51279 Mdot
.66447 .55234 Mdot
.48898 .57857 Mdot
.49999 .59239 Mdot
.26942 .49172 Mdot
.2998 .5234 Mdot
.28421 .51568 Mdot
.57042 .37795 Mdot
.44133 .58228 Mdot
.67527 .54321 Mdot
.63731 .35233 Mdot
.28525 .52919 Mdot
.24659 .50351 Mdot
.43139 .46012 Mdot
.46322 .63757 Mdot
.47922 .43286 Mdot
.86867 .63997 Mdot
.34554 .65328 Mdot
.41402 .40076 Mdot
.37903 .34221 Mdot
.28748 .63041 Mdot
.36736 .29249 Mdot
.59402 .36023 Mdot
.3566 .65814 Mdot
.25466 .48004 Mdot
.51808 .5936 Mdot
.4952 .55305 Mdot
.5337 .60449 Mdot
.29036 .50579 Mdot
.32419 .69426 Mdot
.6761 .5864 Mdot
.51807 .72122 Mdot
.29736 .50587 Mdot
.35972 .3366 Mdot
.39695 .33486 Mdot
.4277 .36044 Mdot
.48654 .55209 Mdot
.54459 .76177 Mdot
.58848 .62927 Mdot
.78468 .53586 Mdot
.61192 .33862 Mdot
.62384 .52467 Mdot
.36975 .76886 Mdot
.68211 .56207 Mdot
.40675 .33503 Mdot
.29294 .50211 Mdot
.68175 .57681 Mdot
.61142 .39356 Mdot
.61724 .37578 Mdot
.4334 .366 Mdot
.41554 .3719 Mdot
.45277 .38613 Mdot
.62676 .54346 Mdot
.63607 .5402 Mdot
.44316 .59537 Mdot
.66783 .56187 Mdot
.49838 .16325 Mdot
.31518 .51188 Mdot
.39506 .33355 Mdot
.61124 .35249 Mdot
.6502 .54137 Mdot
.43373 .61124 Mdot
.43386 .33235 Mdot
.76007 .39888 Mdot
.25384 .4985 Mdot
.2875 .31885 Mdot
.12478 .42855 Mdot
.48978 .64217 Mdot
.58861 .36112 Mdot
.37867 .24221 Mdot
.44233 .61157 Mdot
.41287 .35857 Mdot
.78144 .37422 Mdot
.45022 .40692 Mdot
.48669 .5647 Mdot
.4672 .65787 Mdot
.58462 .35598 Mdot
.28051 .69619 Mdot
.438 .59771 Mdot
.68252 .37052 Mdot
.62977 .3986 Mdot
.46505 .3791 Mdot
.41908 .8441 Mdot
.56764 .28021 Mdot
.24293 .56022 Mdot
.39475 .38228 Mdot
.44863 .63546 Mdot
.41826 .39 Mdot
.25441 .50085 Mdot
.43308 .39128 Mdot
.64631 .51687 Mdot
.4568 .37386 Mdot
.48948 .59345 Mdot
.67331 .53923 Mdot
.59692 .35876 Mdot
.56328 .18599 Mdot
.35815 .43082 Mdot
.41958 .3767 Mdot
.38868 .37921 Mdot
.50577 .61456 Mdot
.57414 .51147 Mdot
.3941 .61511 Mdot
.48515 .63654 Mdot
.63073 .38859 Mdot
.63856 .54531 Mdot
.6465 .35472 Mdot
.42951 .65281 Mdot
.69619 .28911 Mdot
.61819 .34676 Mdot
.6463 .45198 Mdot
.27664 .49378 Mdot
.46032 .47908 Mdot
.43001 .61605 Mdot
.61342 .38633 Mdot
.44126 .58158 Mdot
.65326 .59205 Mdot
.51258 .44799 Mdot
.60433 .28564 Mdot
.61152 .38104 Mdot
.54673 .84265 Mdot
.45609 .44335 Mdot
.4466 .55703 Mdot
.62585 .38805 Mdot
.50194 .69488 Mdot
.40548 .39216 Mdot
.28983 .49247 Mdot
.28534 .52888 Mdot
.25228 .50967 Mdot
.50613 .64309 Mdot
.54064 .56001 Mdot
.28908 .47925 Mdot
.59511 .38972 Mdot
.29268 .52277 Mdot
.69181 .50021 Mdot
.55919 .84065 Mdot
.30455 .49438 Mdot
.46054 .59597 Mdot
.53604 .62281 Mdot
.2958 .60766 Mdot
.39265 .33079 Mdot
.69504 .75176 Mdot
.43691 .52834 Mdot
.46659 .62707 Mdot
.55523 .55393 Mdot
.67591 .58499 Mdot
.36695 .25551 Mdot
.3954 .69675 Mdot
.34934 .29538 Mdot
.62927 .57464 Mdot
.55243 .32835 Mdot
.63275 .56204 Mdot
.49535 .63595 Mdot
.49668 .61911 Mdot
.70592 .56819 Mdot
.57732 .21226 Mdot
.47566 .24009 Mdot
.39974 .81572 Mdot
.69313 .56327 Mdot
.6245 .3854 Mdot
.61856 .398 Mdot
.61411 .33926 Mdot
.32353 .36228 Mdot
.68995 .53971 Mdot
.44416 .58526 Mdot
.39055 .35948 Mdot
.44424 .64471 Mdot
.6048 .37855 Mdot
.45544 .84879 Mdot
.66446 .57697 Mdot
.47218 .6114 Mdot
.17126 .44601 Mdot
.40922 .36504 Mdot
.27899 .48752 Mdot
.23101 .61941 Mdot
.33624 .34367 Mdot
.64538 .37322 Mdot
.70035 .57477 Mdot
.53915 .38588 Mdot
.63864 .46244 Mdot
.47869 .67057 Mdot
.4252 .67367 Mdot
.29349 .74505 Mdot
.34111 .3652 Mdot
.51829 .61026 Mdot
.42249 .39654 Mdot
.55106 .32865 Mdot
.48809 .58111 Mdot
.6936 .5696 Mdot
.25815 .52572 Mdot
.27023 .52219 Mdot
.52264 .55888 Mdot
.58372 .4557 Mdot
.44251 .47698 Mdot
.48076 .56873 Mdot
.47783 .54114 Mdot
.39608 .3383 Mdot
.52509 .36559 Mdot
.53429 .18287 Mdot
.29888 .48594 Mdot
.50865 .5881 Mdot
.74571 .47876 Mdot
.64814 .52885 Mdot
.45889 .38187 Mdot
.64143 .38112 Mdot
.32025 .70498 Mdot
.47117 .38642 Mdot
.49013 .58107 Mdot
.48663 .57547 Mdot
.59068 .34981 Mdot
.61647 .54601 Mdot
.29041 .50385 Mdot
.39326 .3469 Mdot
.29693 .48415 Mdot
.661 .52949 Mdot
.66449 .57479 Mdot
.54161 .62305 Mdot
.48733 .54437 Mdot
.42974 .37274 Mdot
.43764 .65561 Mdot
.37672 .33103 Mdot
.27351 .69296 Mdot
.64156 .34259 Mdot
.48502 .64586 Mdot
.67866 .51673 Mdot
.6063 .38376 Mdot
.48543 .60426 Mdot
.29019 .75422 Mdot
.4628 .65385 Mdot
.57655 .30739 Mdot
.6833 .27612 Mdot
.26085 .51236 Mdot
.44606 .75574 Mdot
.56175 .53857 Mdot
.48002 .62665 Mdot
.4244 .34978 Mdot
.3908 .60847 Mdot
.60411 .34609 Mdot
.62741 .55661 Mdot
.14032 .46479 Mdot
.61292 .35936 Mdot
.4849 .6321 Mdot
.28402 .51122 Mdot
.69148 .58207 Mdot
.50862 .37885 Mdot
.4639 .19927 Mdot
.40937 .57651 Mdot
.44183 .56553 Mdot
.48699 .56592 Mdot
.8205 .44867 Mdot
.42674 .395 Mdot
.65454 .54116 Mdot
.59281 .35076 Mdot
.59662 .37364 Mdot
.42744 .36312 Mdot
.71081 .44661 Mdot
.46389 .47615 Mdot
.88491 .56657 Mdot
.43619 .38069 Mdot
.30856 .48474 Mdot
.60552 .4775 Mdot
.4298 .35213 Mdot
.39586 .36513 Mdot
.39363 .34005 Mdot
.61263 .42939 Mdot
.64953 .56172 Mdot
.50175 .59344 Mdot
.6277 .58217 Mdot
.44912 .63754 Mdot
.38714 .50581 Mdot
.60495 .3852 Mdot
.62606 .55819 Mdot
.29809 .75554 Mdot
.71758 .58543 Mdot
.44983 .60578 Mdot
.35321 .76522 Mdot
.39745 .61133 Mdot
.31935 .67 Mdot
.40561 .59958 Mdot
.41361 .37621 Mdot
.39212 .56869 Mdot
.45157 .66409 Mdot
.53442 .17203 Mdot
.6137 .35224 Mdot
.40239 .39161 Mdot
.51479 .62837 Mdot
.4735 .54328 Mdot
.69849 .58445 Mdot
.6849 .57469 Mdot
.29645 .48216 Mdot
.28601 .55254 Mdot
.5987 .35545 Mdot
.20477 .60269 Mdot
.4735 .62348 Mdot
.62951 .24964 Mdot
.47005 .75107 Mdot
.48372 .60444 Mdot
.59109 .8128 Mdot
.53479 .75919 Mdot
.42707 .61454 Mdot
.51804 .68072 Mdot
.621 .37228 Mdot
.68406 .28368 Mdot
.41168 .61605 Mdot
.41036 .35737 Mdot
.63442 .54383 Mdot
.69077 .57746 Mdot
.274 .48059 Mdot
.32824 .23317 Mdot
.63758 .34489 Mdot
.62695 .55314 Mdot
.43755 .61724 Mdot
.64536 .36701 Mdot
.37478 .35882 Mdot
.42154 .65116 Mdot
.36281 .68267 Mdot
.66598 .56456 Mdot
.41676 .63001 Mdot
.72356 .36527 Mdot
.25881 .55667 Mdot
.8106 .62499 Mdot
.61417 .33997 Mdot
.30265 .50745 Mdot
.4007 .64872 Mdot
.18709 .56839 Mdot
.52364 .62915 Mdot
.22686 .58817 Mdot
.64384 .49921 Mdot
.30218 .51061 Mdot
.4566 .60835 Mdot
.46064 .58556 Mdot
.60507 .46537 Mdot
.30644 .51899 Mdot
.45888 .64936 Mdot
.42921 .53673 Mdot
.64703 .55732 Mdot
.4455 .41058 Mdot
.66142 .56623 Mdot
.45298 .59838 Mdot
.54529 .56776 Mdot
.66477 .58219 Mdot
.19389 .61919 Mdot
.2555 .47496 Mdot
.62708 .34795 Mdot
.51345 .54728 Mdot
.42138 .59588 Mdot
.82801 .40531 Mdot
.40715 .39624 Mdot
.79792 .48443 Mdot
.47186 .37847 Mdot
.74086 .49095 Mdot
.56857 .27664 Mdot
.66851 .79475 Mdot
.57758 .19722 Mdot
.52397 .57246 Mdot
.38873 .53011 Mdot
.55413 .6494 Mdot
.64653 .35822 Mdot
.67685 .6474 Mdot
.46923 .62675 Mdot
.45024 .62208 Mdot
.46156 .38897 Mdot
.68499 .44247 Mdot
.40825 .23674 Mdot
.56034 .44357 Mdot
.28739 .50147 Mdot
.67354 .53324 Mdot
.49727 .60482 Mdot
.39251 .48451 Mdot
.45229 .37023 Mdot
.61729 .24532 Mdot
.46667 .6102 Mdot
.31596 .26406 Mdot
.58166 .41711 Mdot
.63962 .35147 Mdot
.41196 .34155 Mdot
.34099 .33948 Mdot
.45684 .64028 Mdot
.63186 .3913 Mdot
.43513 .6013 Mdot
.42862 .43933 Mdot
.44705 .65863 Mdot
.30396 .4966 Mdot
.51248 .60396 Mdot
.55032 .42475 Mdot
.77406 .68185 Mdot
.37172 .66641 Mdot
.70043 .56077 Mdot
.37038 .32842 Mdot
.43025 .36724 Mdot
.67771 .57787 Mdot
.42785 .3685 Mdot
.52467 .73513 Mdot
.62822 .73514 Mdot
.28424 .49853 Mdot
.4843 .54101 Mdot
.29276 .48467 Mdot
.40689 .39645 Mdot
.46263 .63276 Mdot
.1845 .60285 Mdot
.4303 .37931 Mdot
.7284 .29381 Mdot
.60992 .35599 Mdot
.40511 .39437 Mdot
.43527 .64718 Mdot
.48861 .35024 Mdot
.41992 .34148 Mdot
.55973 .32061 Mdot
.46095 .58886 Mdot
.65773 .57715 Mdot
.46701 .58233 Mdot
.40395 .59793 Mdot
.47234 .40648 Mdot
.43581 .57747 Mdot
.62713 .35548 Mdot
.62013 .54683 Mdot
.60523 .82439 Mdot
.57856 .30487 Mdot
.46692 .64373 Mdot
.43889 .61562 Mdot
.68136 .59064 Mdot
.41909 .62715 Mdot
.61863 .39632 Mdot
.82217 .30022 Mdot
.27663 .49329 Mdot
.36385 .34612 Mdot
.57038 .28274 Mdot
.5267 .62042 Mdot
.47998 .57154 Mdot
.32703 .77613 Mdot
.59846 .27201 Mdot
.63141 .37508 Mdot
.39314 .59125 Mdot
.39024 .35608 Mdot
.28201 .51157 Mdot
.58609 .38216 Mdot
.4698 .56199 Mdot
.45795 .61683 Mdot
.30247 .50468 Mdot
.5448 .82171 Mdot
.33684 .29822 Mdot
.60256 .33971 Mdot
.39006 .57287 Mdot
.38142 .31608 Mdot
.43623 .63834 Mdot
.32034 .35323 Mdot
.68677 .56995 Mdot
.64013 .37563 Mdot
.79613 .51219 Mdot
.51593 .5947 Mdot
.60325 .39011 Mdot
.60158 .35351 Mdot
.4097 .65397 Mdot
.71112 .57564 Mdot
.63157 .53439 Mdot
.68424 .53953 Mdot
.5293 .15617 Mdot
.27337 .56816 Mdot
.45269 .3858 Mdot
.62068 .37398 Mdot
.36753 .33906 Mdot
.31788 .50075 Mdot
.39112 .4924 Mdot
.36212 .33834 Mdot
.66525 .58604 Mdot
.38759 .3335 Mdot
.46521 .58492 Mdot
.59557 .36026 Mdot
.44425 .39699 Mdot
.51237 .63274 Mdot
.55724 .52179 Mdot
.41441 .42514 Mdot
.25057 .51865 Mdot
.2383 .51251 Mdot
.49742 .6145 Mdot
.42227 .40409 Mdot
.47237 .61686 Mdot
.57896 .35387 Mdot
.62184 .46152 Mdot
.52161 .62768 Mdot
.42199 .37423 Mdot
.51143 .52543 Mdot
.33658 .34456 Mdot
.39446 .59753 Mdot
.45975 .59715 Mdot
.44168 .63836 Mdot
.43462 .60089 Mdot
.69918 .46272 Mdot
.63268 .33824 Mdot
.52577 .50593 Mdot
.53328 .3378 Mdot
.67464 .56167 Mdot
.67088 .51808 Mdot
.29694 .35479 Mdot
.35312 .34287 Mdot
.62669 .36436 Mdot
.43 .62874 Mdot
.58671 .29567 Mdot
.46572 .8521 Mdot
.19592 .62854 Mdot
.25052 .53055 Mdot
.44651 .40257 Mdot
.70261 .55721 Mdot
.43548 .35387 Mdot
.45155 .63426 Mdot
.40611 .65385 Mdot
.65416 .81028 Mdot
.58292 .32986 Mdot
.29266 .50325 Mdot
.44361 .63805 Mdot
.25532 .56012 Mdot
.39152 .36039 Mdot
.39016 .33947 Mdot
.45651 .65144 Mdot
.64236 .5217 Mdot
.8526 .5192 Mdot
.64042 .35129 Mdot
.43155 .52598 Mdot
.62587 .60677 Mdot
.69563 .32557 Mdot
.59996 .38171 Mdot
.379 .39992 Mdot
.44526 .40401 Mdot
.47903 .77646 Mdot
.67495 .56546 Mdot
.29552 .50375 Mdot
.42029 .66832 Mdot
.65106 .5824 Mdot
.47516 .39918 Mdot
.63435 .57245 Mdot
.51406 .61072 Mdot
.64242 .34739 Mdot
.40546 .3434 Mdot
.60303 .32687 Mdot
.70853 .55539 Mdot
.26955 .48508 Mdot
.56679 .49632 Mdot
.69869 .65934 Mdot
.53153 .75788 Mdot
.43055 .63792 Mdot
.38134 .48579 Mdot
.44516 .58069 Mdot
.70011 .58505 Mdot
.43401 .60776 Mdot
.59673 .58659 Mdot
.41871 .34677 Mdot
.41554 .62652 Mdot
.49177 .56801 Mdot
.63883 .65385 Mdot
.46741 .60299 Mdot
.40907 .60465 Mdot
.42608 .61771 Mdot
.62933 .51601 Mdot
.45087 .54683 Mdot
.65081 .568 Mdot
.45776 .20509 Mdot
.397 .36667 Mdot
.25552 .52527 Mdot
.26762 .52377 Mdot
.22266 .5746 Mdot
.34309 .53493 Mdot
.69989 .44755 Mdot
.65766 .55916 Mdot
.61607 .34912 Mdot
.43232 .60485 Mdot
.7787 .56342 Mdot
.53973 .29483 Mdot
.38805 .35641 Mdot
.57669 .30664 Mdot
.38959 .65152 Mdot
.82167 .44754 Mdot
.43149 .64649 Mdot
.41044 .19551 Mdot
.5362 .58901 Mdot
.46909 .65337 Mdot
.41289 .33481 Mdot
.34504 .53292 Mdot
.43625 .64494 Mdot
.69684 .5855 Mdot
.29761 .49616 Mdot
.73092 .58067 Mdot
.43101 .28693 Mdot
.3689 .38334 Mdot
.66306 .68276 Mdot
.43669 .58823 Mdot
.40433 .34486 Mdot
.64081 .56793 Mdot
.54975 .18641 Mdot
.63795 .35385 Mdot
.62737 .43731 Mdot
.58986 .64392 Mdot
.32011 .74482 Mdot
.29664 .50058 Mdot
.53915 .8194 Mdot
.49114 .59388 Mdot
.31931 .38429 Mdot
.52105 .58426 Mdot
.46961 .8523 Mdot
.3041 .48064 Mdot
.65325 .51836 Mdot
.62555 .38421 Mdot
.6479 .59056 Mdot
.53987 .76953 Mdot
.65121 .31034 Mdot
.52919 .47027 Mdot
.38411 .36571 Mdot
.53791 .50544 Mdot
.66616 .53776 Mdot
.49527 .57652 Mdot
.88224 .593 Mdot
.68989 .56604 Mdot
.66981 .52561 Mdot
.25276 .67162 Mdot
.25369 .67865 Mdot
.38141 .62801 Mdot
.64097 .58185 Mdot
.3877 .36825 Mdot
.26131 .49902 Mdot
.45963 .5822 Mdot
.44465 .59267 Mdot
.6635 .58059 Mdot
.40423 .33418 Mdot
.40241 .54211 Mdot
.41374 .37337 Mdot
.64489 .55752 Mdot
.40326 .36483 Mdot
.56573 .30673 Mdot
.43662 .39991 Mdot
.41907 .60246 Mdot
.43341 .60714 Mdot
.39514 .29798 Mdot
.6644 .57464 Mdot
.4731 .56972 Mdot
.50749 .60117 Mdot
.67254 .5417 Mdot
.47314 .37793 Mdot
.74876 .60227 Mdot
.47018 .63766 Mdot
.47912 .58785 Mdot
.30373 .50784 Mdot
.35548 .47978 Mdot
.23895 .36028 Mdot
.46985 .57537 Mdot
.31448 .49955 Mdot
.62573 .54588 Mdot
.47568 .61397 Mdot
.68289 .49492 Mdot
.55739 .32005 Mdot
.51469 .59397 Mdot
.40961 .39423 Mdot
.49471 .65331 Mdot
.8247 .57499 Mdot
.47837 .64298 Mdot
.66129 .5428 Mdot
.64542 .536 Mdot
.26309 .67277 Mdot
.68733 .55591 Mdot
.3879 .37538 Mdot
.60385 .37386 Mdot
.49524 .85622 Mdot
.37349 .35657 Mdot
.47965 .6538 Mdot
.1592 .46069 Mdot
.41578 .63589 Mdot
.51823 .62664 Mdot
.81079 .40588 Mdot
.37442 .3568 Mdot
.64933 .53739 Mdot
.65149 .41809 Mdot
.53354 .57221 Mdot
.64433 .37493 Mdot
.43075 .66358 Mdot
.44726 .56638 Mdot
.66924 .27163 Mdot
.77439 .39501 Mdot
.57509 .38073 Mdot
.50241 .66319 Mdot
.46984 .57492 Mdot
.37021 .45875 Mdot
.43401 .61485 Mdot
.29459 .48429 Mdot
.67465 .52935 Mdot
.44886 .37217 Mdot
.2676 .49712 Mdot
.4758 .62576 Mdot
.29016 .50752 Mdot
.45461 .38581 Mdot
.63548 .38445 Mdot
.45796 .63634 Mdot
.28096 .47244 Mdot
.28768 .50279 Mdot
.45116 .57558 Mdot
.62818 .55247 Mdot
.373 .65183 Mdot
.4784 .61133 Mdot
.49917 .58239 Mdot
.66478 .57903 Mdot
.17181 .61298 Mdot
.47259 .64835 Mdot
.46754 .4342 Mdot
.67355 .52474 Mdot
.60343 .29682 Mdot
.45778 .38655 Mdot
.44217 .56983 Mdot
.63071 .39023 Mdot
.60782 .38696 Mdot
.37885 .35078 Mdot
.66462 .59392 Mdot
.38511 .32932 Mdot
.5096 .52653 Mdot
.50923 .54763 Mdot
.4112 .6407 Mdot
.16848 .4027 Mdot
.64881 .80639 Mdot
.69499 .56944 Mdot
.48108 .39219 Mdot
.55983 .44635 Mdot
.62226 .37775 Mdot
.37482 .34172 Mdot
.695 .58022 Mdot
.7025 .56098 Mdot
.6378 .5731 Mdot
.28862 .51749 Mdot
.48342 .38947 Mdot
.61979 .53773 Mdot
.64066 .52289 Mdot
.46367 .58697 Mdot
.47046 .57356 Mdot
.48079 .69493 Mdot
.32139 .62585 Mdot
.27142 .4831 Mdot
.42327 .3599 Mdot
.74993 .2506 Mdot
.57547 .36152 Mdot
.63914 .65671 Mdot
.52258 .62534 Mdot
.79291 .75442 Mdot
.43878 .65247 Mdot
.43546 .61875 Mdot
.61916 .55404 Mdot
.26823 .47471 Mdot
.28974 .48563 Mdot
.6642 .53623 Mdot
.70697 .55903 Mdot
.30042 .48824 Mdot
.46309 .8189 Mdot
.55718 .84341 Mdot
.67109 .39191 Mdot
.66942 .54618 Mdot
.69273 .67718 Mdot
.6417 .3822 Mdot
.70968 .55353 Mdot
.5794 .35766 Mdot
.39423 .36 Mdot
.44968 .40426 Mdot
.59419 .34806 Mdot
.45674 .59094 Mdot
.44799 .39084 Mdot
.46467 .55093 Mdot
.50087 .8336 Mdot
.63098 .76696 Mdot
.55599 .24637 Mdot
.50218 .55609 Mdot
.41721 .23191 Mdot
.42182 .2448 Mdot
.48702 .62359 Mdot
.73602 .51537 Mdot
.29248 .50474 Mdot
.69279 .51795 Mdot
.62126 .39599 Mdot
.8165 .61431 Mdot
.43349 .63541 Mdot
.66068 .54606 Mdot
.61871 .35312 Mdot
.26779 .66252 Mdot
.68241 .37639 Mdot
.44787 .63891 Mdot
.8879 .54065 Mdot
.66727 .50464 Mdot
.44962 .37371 Mdot
.22935 .3291 Mdot
.62348 .57964 Mdot
.24305 .53172 Mdot
.51923 .35819 Mdot
.32181 .76009 Mdot
.63953 .54937 Mdot
.48429 .39509 Mdot
.67175 .53379 Mdot
.28428 .48095 Mdot
.70301 .51973 Mdot
.39747 .34301 Mdot
.4627 .60599 Mdot
.42229 .36664 Mdot
.26654 .48499 Mdot
.32133 .36898 Mdot
.62539 .39429 Mdot
.40462 .39269 Mdot
.61315 .37072 Mdot
.26712 .55603 Mdot
.71271 .29874 Mdot
.6345 .35535 Mdot
.24213 .64255 Mdot
.51977 .60705 Mdot
.61313 .55526 Mdot
.44088 .37954 Mdot
.51785 .36272 Mdot
.57161 .48277 Mdot
.67773 .55748 Mdot
.42213 .35539 Mdot
.59399 .63579 Mdot
.17595 .50091 Mdot
.53895 .55783 Mdot
.30572 .56295 Mdot
.67357 .54463 Mdot
.38597 .33865 Mdot
.48695 .18805 Mdot
.66785 .58669 Mdot
.43695 .3814 Mdot
.62005 .38802 Mdot
.59743 .37732 Mdot
.447 .64838 Mdot
.64041 .42063 Mdot
.43942 .36781 Mdot
.45942 .22155 Mdot
.65069 .52742 Mdot
.26969 .66064 Mdot
.25313 .49406 Mdot
.39906 .37246 Mdot
.43955 .66047 Mdot
.64354 .60495 Mdot
.55695 .3185 Mdot
.37515 .56225 Mdot
.74748 .25505 Mdot
.42626 .36278 Mdot
.67134 .52744 Mdot
.66159 .54981 Mdot
.39509 .61484 Mdot
.58858 .45967 Mdot
.38163 .3282 Mdot
.19426 .53239 Mdot
.23523 .60175 Mdot
.4712 .40514 Mdot
.43572 .26012 Mdot
.46749 .65871 Mdot
.43764 .58244 Mdot
.6236 .3791 Mdot
.46353 .60067 Mdot
.62951 .53251 Mdot
.43093 .64073 Mdot
.59517 .3809 Mdot
.40381 .38217 Mdot
.45889 .63231 Mdot
.25882 .50224 Mdot
.58961 .39769 Mdot
.5869 .35203 Mdot
.40686 .37737 Mdot
.64023 .58008 Mdot
.23088 .49093 Mdot
.416 .37134 Mdot
.43613 .58999 Mdot
.51175 .37585 Mdot
.51141 .61224 Mdot
.46562 .80039 Mdot
.65892 .58782 Mdot
.42918 .3503 Mdot
.67787 .52394 Mdot
.61583 .36685 Mdot
.53204 .3396 Mdot
.44466 .60315 Mdot
.43424 .38236 Mdot
.40384 .28811 Mdot
.49148 .81868 Mdot
.67672 .59349 Mdot
.46546 .27157 Mdot
.65789 .52167 Mdot
.46736 .40671 Mdot
.37633 .73324 Mdot
.28972 .49464 Mdot
.3904 .35115 Mdot
.64813 .79606 Mdot
.4267 .3755 Mdot
.47222 .60147 Mdot
.49101 .6051 Mdot
.45898 .39196 Mdot
.2849 .52246 Mdot
.60187 .19327 Mdot
.41847 .42065 Mdot
.64401 .54217 Mdot
.4282 .75053 Mdot
.79965 .31675 Mdot
.65678 .35425 Mdot
.62752 .37752 Mdot
.52833 .57237 Mdot
.46453 .65597 Mdot
.57995 .37442 Mdot
.63587 .39474 Mdot
.26474 .48165 Mdot
.3916 .34231 Mdot
.69951 .5151 Mdot
.61695 .40121 Mdot
.52313 .65489 Mdot
.33875 .53799 Mdot
.40624 .56628 Mdot
.5541 .55786 Mdot
.49264 .55895 Mdot
.21798 .58484 Mdot
.58855 .3685 Mdot
.50086 .60965 Mdot
.42346 .5597 Mdot
.63577 .38029 Mdot
.28769 .48179 Mdot
.76325 .37876 Mdot
.4034 .35762 Mdot
.31134 .79507 Mdot
.49993 .6264 Mdot
.47424 .60435 Mdot
.61486 .33869 Mdot
.35428 .45777 Mdot
.65222 .58053 Mdot
.65466 .58897 Mdot
.43013 .3955 Mdot
.55142 .49548 Mdot
.41935 .61844 Mdot
.49125 .6205 Mdot
.40744 .34995 Mdot
.40664 .39473 Mdot
.5118 .23206 Mdot
.49755 .59103 Mdot
.61903 .35492 Mdot
.50535 .37894 Mdot
.58997 .37417 Mdot
.50121 .63065 Mdot
.47625 .59996 Mdot
.4181 .60591 Mdot
.46761 .65625 Mdot
.58858 .3487 Mdot
.50033 .60648 Mdot
.54528 .59843 Mdot
.62973 .5686 Mdot
.42605 .59292 Mdot
.22748 .59791 Mdot
.46708 .59259 Mdot
.26614 .48906 Mdot
.34647 .52273 Mdot
.44314 .6397 Mdot
.42425 .59175 Mdot
.42419 .42376 Mdot
.45258 .61078 Mdot
.57918 .3538 Mdot
.67079 .55958 Mdot
.62023 .37462 Mdot
.5896 .35228 Mdot
.40471 .38819 Mdot
.28204 .47876 Mdot
.52739 .60897 Mdot
.25356 .51024 Mdot
.50063 .66093 Mdot
.51803 .60161 Mdot
.51976 .33412 Mdot
.40519 .19548 Mdot
.33429 .30062 Mdot
.44445 .60209 Mdot
.41281 .38664 Mdot
.44639 .36782 Mdot
.40622 .52472 Mdot
.45934 .54895 Mdot
.58193 .37892 Mdot
.61316 .38594 Mdot
.34421 .67012 Mdot
.66857 .27336 Mdot
.27148 .48475 Mdot
.38802 .48936 Mdot
.47588 .54696 Mdot
.50491 .59288 Mdot
.42189 .65006 Mdot
.36317 .33833 Mdot
.51385 .37859 Mdot
.38817 .35708 Mdot
.56407 .32047 Mdot
.59396 .38151 Mdot
.42412 .62516 Mdot
.67688 .74314 Mdot
.68194 .57824 Mdot
.67064 .56039 Mdot
.58686 .3803 Mdot
.36984 .33009 Mdot
.43444 .69114 Mdot
.12586 .50508 Mdot
.65418 .50802 Mdot
.24843 .49707 Mdot
.48364 .62886 Mdot
.41057 .38241 Mdot
.69642 .55705 Mdot
.29047 .52402 Mdot
.51189 .59208 Mdot
.38831 .32705 Mdot
.44362 .59939 Mdot
.55329 .64933 Mdot
.63029 .55625 Mdot
.49191 .86176 Mdot
.68848 .58284 Mdot
.59659 .40117 Mdot
.6367 .36953 Mdot
.48491 .60267 Mdot
.18539 .38003 Mdot
.61292 .56286 Mdot
.60871 .42215 Mdot
.29521 .47672 Mdot
.51507 .37148 Mdot
.31067 .50008 Mdot
.43089 .3536 Mdot
.29714 .49728 Mdot
.40596 .34133 Mdot
.33827 .64803 Mdot
.60511 .54466 Mdot
.27234 .49398 Mdot
.40079 .45357 Mdot
.46705 .54587 Mdot
.27484 .52967 Mdot
.53152 .62422 Mdot
.45781 .76557 Mdot
.40888 .35205 Mdot
.27967 .52203 Mdot
.49362 .57613 Mdot
.77568 .65198 Mdot
.63074 .35948 Mdot
.58016 .37812 Mdot
.4421 .56234 Mdot
.3896 .34272 Mdot
.70434 .57462 Mdot
.64972 .46685 Mdot
.60083 .30576 Mdot
.49587 .61515 Mdot
.43418 .64358 Mdot
.6684 .51708 Mdot
.60187 .56638 Mdot
.4816 .59931 Mdot
.63465 .63493 Mdot
.49628 .59752 Mdot
.61404 .39182 Mdot
.68447 .58061 Mdot
.6653 .55346 Mdot
.43262 .35997 Mdot
.62706 .57563 Mdot
.5438 .54706 Mdot
.53839 .39674 Mdot
.53467 .6115 Mdot
.6121 .36097 Mdot
.57615 .43916 Mdot
.57609 .30684 Mdot
.71465 .72603 Mdot
.68647 .52269 Mdot
.42598 .5855 Mdot
.65836 .52469 Mdot
.2772 .5147 Mdot
.66417 .57248 Mdot
.69298 .54118 Mdot
.48054 .61689 Mdot
.4481 .63524 Mdot
.38184 .36645 Mdot
.5823 .45816 Mdot
.62408 .55748 Mdot
.49671 .61019 Mdot
.41412 .62926 Mdot
.40939 .60234 Mdot
.49589 .44048 Mdot
.69677 .5657 Mdot
.58689 .67484 Mdot
.37493 .71154 Mdot
.62431 .55962 Mdot
.8325 .55409 Mdot
.52718 .35917 Mdot
.36093 .3443 Mdot
.62345 .32616 Mdot
.49799 .59037 Mdot
.46134 .39449 Mdot
.45224 .63426 Mdot
.55642 .55928 Mdot
.45565 .6191 Mdot
.30986 .50848 Mdot
.52387 .57245 Mdot
.45782 .40768 Mdot
.41889 .37055 Mdot
.49021 .63107 Mdot
.45787 .62973 Mdot
.33115 .35982 Mdot
.70645 .55459 Mdot
.6491 .57941 Mdot
.33719 .44951 Mdot
.27471 .50293 Mdot
.64163 .37622 Mdot
.429 .61369 Mdot
.4191 .39169 Mdot
.42052 .36711 Mdot
.64534 .59055 Mdot
.41171 .3593 Mdot
.63143 .34426 Mdot
.44157 .60633 Mdot
.57939 .37557 Mdot
.27468 .52194 Mdot
.68358 .53777 Mdot
.43014 .63143 Mdot
.46481 .58657 Mdot
.64547 .53608 Mdot
.52261 .59873 Mdot
.30442 .5069 Mdot
.42742 .37272 Mdot
.6378 .55598 Mdot
.60313 .3756 Mdot
.41995 .34666 Mdot
.48018 .57864 Mdot
.74092 .24821 Mdot
.47331 .5969 Mdot
.49167 .58268 Mdot
.61223 .83147 Mdot
.52709 .57804 Mdot
.43883 .37207 Mdot
.65737 .51586 Mdot
.46017 .55432 Mdot
.23763 .57675 Mdot
.19224 .62924 Mdot
.37994 .35507 Mdot
.47901 .63561 Mdot
.71579 .734 Mdot
.48363 .63514 Mdot
.20316 .59589 Mdot
.25247 .38255 Mdot
.49046 .49404 Mdot
.55511 .57888 Mdot
.60841 .34241 Mdot
.38377 .36898 Mdot
.41927 .34773 Mdot
.48367 .72716 Mdot
.48584 .6167 Mdot
.5393 .65584 Mdot
.49994 .57396 Mdot
.59827 .38037 Mdot
.3787 .69519 Mdot
.42292 .36221 Mdot
.44212 .1923 Mdot
.44302 .58532 Mdot
.69798 .56645 Mdot
.38963 .33297 Mdot
.53262 .35281 Mdot
.49042 .57867 Mdot
.25811 .51573 Mdot
.57031 .35255 Mdot
.53379 .56632 Mdot
.60678 .36172 Mdot
.50888 .59545 Mdot
.54299 .62264 Mdot
.26111 .28821 Mdot
.6296 .56149 Mdot
.6248 .38287 Mdot
.42371 .25232 Mdot
.52461 .58932 Mdot
.63739 .55286 Mdot
.67558 .56437 Mdot
.25887 .48841 Mdot
.53898 .45579 Mdot
.72328 .37908 Mdot
.70037 .69801 Mdot
.44038 .74324 Mdot
.37968 .33813 Mdot
.47212 .24602 Mdot
.46277 .57936 Mdot
.61225 .24912 Mdot
.57428 .36755 Mdot
.47015 .60517 Mdot
.48151 .75687 Mdot
.68952 .54521 Mdot
.48491 .58863 Mdot
.29246 .48427 Mdot
.58279 .22252 Mdot
.59408 .23904 Mdot
.8241 .49276 Mdot
.38493 .36367 Mdot
.42272 .66215 Mdot
.55095 .55689 Mdot
.39319 .38339 Mdot
.51674 .58323 Mdot
.43671 .37415 Mdot
.40251 .78466 Mdot
.29924 .51801 Mdot
.694 .54726 Mdot
.52903 .35713 Mdot
.48419 .55648 Mdot
.40813 .6218 Mdot
.25307 .52297 Mdot
.45074 .56946 Mdot
.32997 .23452 Mdot
.54891 .26345 Mdot
.44357 .39544 Mdot
.63549 .57127 Mdot
.48773 .55257 Mdot
.50675 .3861 Mdot
.48535 .61265 Mdot
.62587 .75155 Mdot
.42801 .58486 Mdot
.71216 .36332 Mdot
.634 .54394 Mdot
.60912 .36369 Mdot
.45724 .67251 Mdot
.44816 .61936 Mdot
.41172 .32171 Mdot
.55576 .58334 Mdot
.4834 .64097 Mdot
.69411 .58606 Mdot
.68918 .57445 Mdot
.65153 .56718 Mdot
.45314 .36936 Mdot
.65584 .27001 Mdot
.62137 .36085 Mdot
.47587 .65948 Mdot
.61678 .40156 Mdot
.39382 .55394 Mdot
.2494 .51843 Mdot
.77896 .62112 Mdot
.44654 .56927 Mdot
.65334 .56002 Mdot
.75642 .46672 Mdot
.62744 .54307 Mdot
.47741 .37465 Mdot
.5979 .35623 Mdot
.69363 .55421 Mdot
.44019 .61899 Mdot
.56783 .44316 Mdot
.79677 .56219 Mdot
.61626 .37814 Mdot
.51586 .64639 Mdot
.43611 .40363 Mdot
.5728 .28652 Mdot
.78958 .28417 Mdot
.63198 .37299 Mdot
.4346 .24873 Mdot
.48868 .61931 Mdot
.67488 .58134 Mdot
.61552 .34087 Mdot
.62847 .35196 Mdot
.41378 .35538 Mdot
.44607 .63605 Mdot
.44025 .63567 Mdot
.46711 .40479 Mdot
.61082 .38534 Mdot
.40195 .61212 Mdot
.43416 .65507 Mdot
.65339 .81218 Mdot
.46759 .71597 Mdot
.20205 .69254 Mdot
.49888 .52421 Mdot
.48875 .76325 Mdot
.62291 .48215 Mdot
.67894 .53006 Mdot
.4458 .64067 Mdot
.50288 .56155 Mdot
.43633 .36508 Mdot
.45691 .60153 Mdot
.45717 .36756 Mdot
.62882 .36576 Mdot
.8281 .55257 Mdot
.76932 .41882 Mdot
.39187 .77537 Mdot
.45686 .60395 Mdot
.6855 .30615 Mdot
.26715 .50878 Mdot
.59536 .40447 Mdot
.64351 .56239 Mdot
.51368 .61679 Mdot
.33109 .3513 Mdot
.38995 .35363 Mdot
.68162 .56772 Mdot
.42991 .21793 Mdot
.34415 .32878 Mdot
.50203 .63005 Mdot
.46183 .38032 Mdot
.72375 .48519 Mdot
.64315 .63214 Mdot
.64988 .38748 Mdot
.31086 .50443 Mdot
.38943 .35966 Mdot
.58784 .37693 Mdot
.65434 .49674 Mdot
.69133 .55579 Mdot
.63177 .52122 Mdot
.3074 .33142 Mdot
.36036 .33108 Mdot
.26461 .49901 Mdot
.66063 .27277 Mdot
.64476 .25026 Mdot
.30986 .50739 Mdot
.46218 .40293 Mdot
.69282 .56838 Mdot
.64943 .54732 Mdot
.67061 .55831 Mdot
.45807 .1869 Mdot
.66865 .59231 Mdot
.64264 .67894 Mdot
.41251 .62927 Mdot
.54201 .63979 Mdot
.47929 .63692 Mdot
.58002 .35846 Mdot
.63231 .55196 Mdot
.59892 .47928 Mdot
.49285 .65012 Mdot
.8187 .5228 Mdot
.49362 .61924 Mdot
.64515 .39389 Mdot
.49089 .58722 Mdot
.67259 .65828 Mdot
.6689 .52256 Mdot
.45114 .6004 Mdot
.60582 .33172 Mdot
.28383 .5044 Mdot
.71577 .5705 Mdot
.44267 .63855 Mdot
.68226 .43579 Mdot
.52948 .5832 Mdot
.44468 .8125 Mdot
.28926 .67198 Mdot
.24789 .498 Mdot
.42068 .54085 Mdot
.38155 .34447 Mdot
.53833 .64799 Mdot
.50559 .54016 Mdot
.61483 .37738 Mdot
.7557 .34214 Mdot
.39492 .36725 Mdot
.37472 .67726 Mdot
.3915 .60195 Mdot
.2862 .47967 Mdot
.63055 .59644 Mdot
.5882 .34463 Mdot
.51114 .6312 Mdot
.40846 .65231 Mdot
.41706 .78939 Mdot
.51586 .54535 Mdot
.42145 .63167 Mdot
.257 .52338 Mdot
.59047 .68093 Mdot
.4679 .58981 Mdot
.48579 .38236 Mdot
.63852 .51871 Mdot
.44926 .55701 Mdot
.58908 .6705 Mdot
.49562 .61077 Mdot
.68077 .57332 Mdot
.60526 .5579 Mdot
.74115 .43726 Mdot
.28718 .47574 Mdot
.42876 .58419 Mdot
.31226 .70797 Mdot
.44143 .58315 Mdot
.61538 .35449 Mdot
.48034 .64686 Mdot
.3933 .35129 Mdot
.43899 .20005 Mdot
.45085 .38363 Mdot
.45873 .64348 Mdot
.66981 .55312 Mdot
.60087 .34216 Mdot
.32113 .31326 Mdot
.27292 .38326 Mdot
.63453 .67743 Mdot
.29761 .75744 Mdot
.28777 .52072 Mdot
.31067 .51629 Mdot
.59382 .34068 Mdot
.45215 .59892 Mdot
.2777 .68767 Mdot
.53488 .58017 Mdot
.48068 .58695 Mdot
.45639 .61996 Mdot
.64616 .27689 Mdot
.6246 .37259 Mdot
.40764 .36255 Mdot
.47917 .59867 Mdot
.49825 .6076 Mdot
.66141 .52771 Mdot
.28494 .50279 Mdot
.4543 .37966 Mdot
.27932 .49668 Mdot
.42082 .38414 Mdot
.83002 .56665 Mdot
.4852 .66188 Mdot
.281 .50537 Mdot
.57159 .37281 Mdot
.66547 .57939 Mdot
.51564 .37748 Mdot
.42816 .35203 Mdot
.4237 .35911 Mdot
.49412 .61666 Mdot
.67615 .57777 Mdot
.62465 .57031 Mdot
.2765 .51545 Mdot
.63911 .35907 Mdot
.45477 .63981 Mdot
.51759 .60601 Mdot
.44381 .5045 Mdot
.36389 .33488 Mdot
.60234 .62585 Mdot
.72694 .45461 Mdot
.44712 .60017 Mdot
.63898 .58065 Mdot
.46288 .62413 Mdot
.67139 .75853 Mdot
.66252 .58579 Mdot
.46629 .6529 Mdot
.64186 .23755 Mdot
.50891 .37767 Mdot
.70315 .40984 Mdot
.41509 .60916 Mdot
.34398 .79684 Mdot
.46115 .57571 Mdot
.69548 .77176 Mdot
.33837 .40143 Mdot
.42363 .6266 Mdot
.46554 .58168 Mdot
.7214 .68238 Mdot
.47745 .62811 Mdot
.45599 .40873 Mdot
.37327 .67783 Mdot
.7035 .55754 Mdot
.60429 .48846 Mdot
.35065 .49805 Mdot
.28426 .47419 Mdot
.43099 .39564 Mdot
.44443 .27059 Mdot
.30315 .49407 Mdot
.66854 .54429 Mdot
.43432 .6008 Mdot
.519 .49013 Mdot
.47896 .3995 Mdot
.40282 .59432 Mdot
.60937 .35359 Mdot
.50634 .26538 Mdot
.46492 .3742 Mdot
.60501 .37018 Mdot
.4714 .55882 Mdot
.74893 .60996 Mdot
.24113 .38049 Mdot
.50647 .86479 Mdot
.60413 .33941 Mdot
.60245 .38611 Mdot
.50705 .1773 Mdot
.2935 .47467 Mdot
.4203 .77152 Mdot
.69795 .35928 Mdot
.6439 .35503 Mdot
.35796 .72216 Mdot
.38568 .35464 Mdot
.68128 .42659 Mdot
.69295 .51809 Mdot
.41278 .64286 Mdot
.44242 .61865 Mdot
.64029 .36336 Mdot
.68205 .4977 Mdot
.24979 .30375 Mdot
.61278 .3721 Mdot
.53793 .62481 Mdot
.49077 .45578 Mdot
.52629 .36146 Mdot
.36947 .35302 Mdot
.27968 .47615 Mdot
.30072 .53704 Mdot
.66269 .53072 Mdot
.26926 .48054 Mdot
.58508 .2352 Mdot
.44802 .56959 Mdot
.61007 .38003 Mdot
.53756 .35179 Mdot
.59972 .37412 Mdot
.29688 .48904 Mdot
.2524 .48953 Mdot
.63035 .5698 Mdot
.65023 .57904 Mdot
.50566 .76252 Mdot
.32647 .66893 Mdot
.48645 .63366 Mdot
.79059 .51573 Mdot
.646 .52953 Mdot
.4732 .53306 Mdot
.31344 .50287 Mdot
.27988 .50312 Mdot
.527 .67966 Mdot
.42693 .62294 Mdot
.25223 .6621 Mdot
.42834 .62156 Mdot
.35924 .68792 Mdot
.51659 .57897 Mdot
.41271 .35699 Mdot
.42421 .61883 Mdot
.2647 .46807 Mdot
.46753 .6585 Mdot
.48861 .63792 Mdot
.3867 .3462 Mdot
.5295 .56157 Mdot
.39392 .3504 Mdot
.45968 .6451 Mdot
.31668 .49792 Mdot
.42085 .39268 Mdot
.27227 .57632 Mdot
.46297 .43438 Mdot
.42461 .40416 Mdot
.2579 .49603 Mdot
.25139 .50066 Mdot
.22985 .55643 Mdot
.6427 .56097 Mdot
.71021 .58694 Mdot
.45674 .59794 Mdot
.39055 .33901 Mdot
.62556 .37662 Mdot
.49871 .60433 Mdot
.52047 .57514 Mdot
.41786 .62918 Mdot
.67637 .53214 Mdot
.37841 .32903 Mdot
.28479 .50869 Mdot
.46054 .37741 Mdot
.42789 .33308 Mdot
.47082 .38286 Mdot
.43352 .55349 Mdot
.42968 .67441 Mdot
.49447 .78774 Mdot
.79801 .4644 Mdot
.58248 .18672 Mdot
.68915 .55933 Mdot
.40839 .39407 Mdot
.26035 .48309 Mdot
.36816 .61887 Mdot
.64798 .5588 Mdot
.39658 .34392 Mdot
.44239 .60004 Mdot
.51218 .65083 Mdot
.583 .32526 Mdot
.54378 .64289 Mdot
.25112 .61538 Mdot
.44997 .36152 Mdot
.48606 .39905 Mdot
.63843 .25041 Mdot
.38604 .68484 Mdot
.56221 .49038 Mdot
.46735 .61336 Mdot
.26054 .51824 Mdot
.6964 .55715 Mdot
.28067 .33794 Mdot
.62945 .38706 Mdot
.58609 .45879 Mdot
.45558 .60381 Mdot
.67857 .35462 Mdot
.67108 .5545 Mdot
.28309 .48206 Mdot
.64079 .36533 Mdot
.26567 .47486 Mdot
.36665 .35137 Mdot
.25799 .69437 Mdot
.44504 .57677 Mdot
.47874 .64235 Mdot
.6073 .40124 Mdot
.67125 .5346 Mdot
.23891 .51005 Mdot
.46755 .81507 Mdot
.45682 .3895 Mdot
.24142 .6559 Mdot
.61772 .55315 Mdot
.66923 .68155 Mdot
.45838 .37456 Mdot
.58768 .38126 Mdot
.23285 .55251 Mdot
.59424 .37985 Mdot
.44321 .64316 Mdot
.65962 .5567 Mdot
.62873 .35835 Mdot
.44322 .33247 Mdot
.74605 .70022 Mdot
.68437 .68102 Mdot
.42709 .59972 Mdot
.7934 .60066 Mdot
.53628 .83672 Mdot
.73027 .53835 Mdot
.62858 .39349 Mdot
.48083 .61076 Mdot
.49281 .56556 Mdot
.44012 .58875 Mdot
.60593 .34866 Mdot
.50265 .32983 Mdot
.41378 .35025 Mdot
.4877 .6276 Mdot
.26154 .4843 Mdot
.39554 .35346 Mdot
.53254 .34633 Mdot
.4341 .36613 Mdot
.69838 .53864 Mdot
.4677 .65502 Mdot
.6181 .43871 Mdot
.78062 .68301 Mdot
.6193 .37549 Mdot
.42556 .40443 Mdot
.50587 .61611 Mdot
.69842 .29946 Mdot
.65139 .56539 Mdot
.45633 .39085 Mdot
.47398 .60492 Mdot
.48762 .33712 Mdot
.3282 .35871 Mdot
.43106 .36403 Mdot
.64475 .5503 Mdot
.73355 .5283 Mdot
.46145 .60023 Mdot
.45958 .57412 Mdot
.66979 .53628 Mdot
.33274 .47942 Mdot
.45306 .20073 Mdot
.45923 .62744 Mdot
.60837 .36503 Mdot
.14991 .53234 Mdot
.41027 .6088 Mdot
.43728 .71669 Mdot
.37788 .35801 Mdot
.7046 .44068 Mdot
.60562 .62365 Mdot
.39745 .55752 Mdot
.72777 .68405 Mdot
.40251 .48931 Mdot
.82075 .56597 Mdot
.43166 .34269 Mdot
.37298 .42162 Mdot
.82343 .58006 Mdot
.6118 .33286 Mdot
.58281 .55412 Mdot
.43768 .52194 Mdot
.4198 .20637 Mdot
.67711 .48958 Mdot
.321 .43387 Mdot
.33053 .32651 Mdot
.48962 .47587 Mdot
.429 .37904 Mdot
.35237 .62609 Mdot
.4541 .63754 Mdot
.5286 .83865 Mdot
.64073 .63946 Mdot
.23205 .31466 Mdot
.7912 .6103 Mdot
.3156 .70826 Mdot
.78338 .58596 Mdot
.69341 .75235 Mdot
.47793 .78318 Mdot
.79072 .47377 Mdot
.17909 .57484 Mdot
.62593 .23574 Mdot
.33686 .73986 Mdot
.40384 .66058 Mdot
.39465 .48408 Mdot
.37787 .79124 Mdot
.63868 .70189 Mdot
.17295 .4087 Mdot
.44482 .37153 Mdot
.65392 .51711 Mdot
.44275 .51652 Mdot
.67817 .59671 Mdot
.65684 .33009 Mdot
.73579 .67878 Mdot
.67797 .78167 Mdot
.66458 .65651 Mdot
.34479 .80034 Mdot
.50247 .73619 Mdot
.47315 .143 Mdot
.41911 .42938 Mdot
.61259 .54535 Mdot
.23992 .44526 Mdot
.65056 .25618 Mdot
.75341 .39478 Mdot
.49084 .52107 Mdot
.54974 .30879 Mdot
.29202 .59699 Mdot
.66186 .54613 Mdot
.634 .62688 Mdot
.35428 .34857 Mdot
.76192 .38591 Mdot
.22873 .52612 Mdot
.72449 .70813 Mdot
.53102 .48135 Mdot
.66924 .43337 Mdot
.48002 .2407 Mdot
.74296 .25049 Mdot
.32887 .69537 Mdot
.59763 .80467 Mdot
.63785 .32337 Mdot
.69592 .49966 Mdot
.3661 .23867 Mdot
.31146 .64347 Mdot
.65131 .25471 Mdot
.77699 .33988 Mdot
.49679 .849 Mdot
.80698 .36454 Mdot
.71302 .58047 Mdot
.41791 .62706 Mdot
.59223 .79715 Mdot
.42649 .7342 Mdot
.30892 .52957 Mdot
.82283 .46596 Mdot
.2723 .52297 Mdot
.7014 .58873 Mdot
.42495 .21422 Mdot
.6536 .66922 Mdot
.23842 .64774 Mdot
.23668 .50152 Mdot
.50253 .55543 Mdot
.23328 .25586 Mdot
.81604 .56609 Mdot
.73483 .43468 Mdot
.65566 .81075 Mdot
.67512 .32264 Mdot
.27691 .66969 Mdot
.6249 .35444 Mdot
.81135 .62657 Mdot
.65182 .55033 Mdot
.86824 .54432 Mdot
.77507 .67456 Mdot
.23836 .33719 Mdot
.1024 .49361 Mdot
.58664 .25321 Mdot
.51953 .50162 Mdot
.39529 .49689 Mdot
.25386 .59365 Mdot
.27882 .28474 Mdot
.20611 .37739 Mdot
.66321 .28782 Mdot
.34293 .7777 Mdot
.81023 .60939 Mdot
.36889 .73054 Mdot
.2847 .71415 Mdot
.40497 .21776 Mdot
.48714 .43617 Mdot
.63191 .60108 Mdot
.45307 .42342 Mdot
.76229 .55849 Mdot
.82729 .44188 Mdot
.41454 .71964 Mdot
.12481 .51443 Mdot
.23809 .48549 Mdot
.33086 .4063 Mdot
.60169 .8202 Mdot
.29096 .57141 Mdot
.39541 .72581 Mdot
.53983 .18651 Mdot
.40419 .57715 Mdot
.57592 .20221 Mdot
.76288 .52232 Mdot
.46018 .27158 Mdot
.6132 .22967 Mdot
.69187 .47164 Mdot
.43494 .79924 Mdot
.61377 .77529 Mdot
.66505 .26015 Mdot
.70465 .55555 Mdot
.29232 .63393 Mdot
.34134 .70853 Mdot
.64312 .81928 Mdot
.42447 .25227 Mdot
.54472 .87624 Mdot
.38407 .25429 Mdot
.52803 .62449 Mdot
.53712 .55333 Mdot
.45165 .68588 Mdot
.31091 .66186 Mdot
.41691 .63277 Mdot
.66939 .29875 Mdot
.62722 .82911 Mdot
.47317 .75107 Mdot
.46306 .28199 Mdot
.76488 .3514 Mdot
.51258 .86398 Mdot
.51817 .80007 Mdot
.34308 .37403 Mdot
.43656 .70752 Mdot
.58296 .16921 Mdot
.39977 .36449 Mdot
.36464 .7308 Mdot
.65071 .3576 Mdot
.28665 .34544 Mdot
.7077 .68379 Mdot
.26396 .31856 Mdot
.62586 .83048 Mdot
.46423 .20254 Mdot
.34302 .29608 Mdot
.21555 .52917 Mdot
.22332 .63843 Mdot
.78705 .389 Mdot
.44642 .66558 Mdot
.55249 .53236 Mdot
.26016 .52299 Mdot
.53325 .7726 Mdot
.39525 .74063 Mdot
.2705 .41371 Mdot
.54763 .57465 Mdot
.21056 .41502 Mdot
.48831 .39832 Mdot
.57917 .45253 Mdot
.83387 .37132 Mdot
.4163 .57256 Mdot
.60312 .26953 Mdot
.47233 .83697 Mdot
.28209 .64765 Mdot
.60409 .81363 Mdot
.65903 .45518 Mdot
.80192 .36375 Mdot
.75445 .70311 Mdot
.26744 .3956 Mdot
.83172 .52358 Mdot
.62045 .84632 Mdot
.77803 .32525 Mdot
.58357 .59753 Mdot
.58439 .34272 Mdot
.88611 .43413 Mdot
.4753 .39734 Mdot
.7324 .30809 Mdot
.44137 .7429 Mdot
.48432 .32019 Mdot
.71561 .55487 Mdot
.39968 .66515 Mdot
.50013 .47836 Mdot
.66 .50255 Mdot
.4649 .55145 Mdot
.78355 .30171 Mdot
.74797 .30332 Mdot
.79812 .33266 Mdot
.42759 .82412 Mdot
.83329 .53002 Mdot
.44979 .49386 Mdot
.65019 .68655 Mdot
.39025 .54127 Mdot
.49018 .64161 Mdot
.34353 .61362 Mdot
.5822 .25305 Mdot
.24877 .36342 Mdot
.74114 .38189 Mdot
.69431 .58945 Mdot
.80845 .50491 Mdot
.70412 .18466 Mdot
.52068 .73388 Mdot
.55198 .68957 Mdot
.60638 .24285 Mdot
.3284 .67865 Mdot
.76233 .54471 Mdot
.23919 .3559 Mdot
.62158 .82338 Mdot
.41228 .53413 Mdot
.37307 .74868 Mdot
.28752 .42932 Mdot
.19761 .56996 Mdot
.37078 .46268 Mdot
.74231 .69346 Mdot
.38517 .51882 Mdot
.3053 .29848 Mdot
.58921 .49738 Mdot
.24289 .32221 Mdot
.30328 .37432 Mdot
.50713 .26026 Mdot
.34608 .73365 Mdot
.58274 .29611 Mdot
.35531 .69696 Mdot
.50492 .45534 Mdot
.36106 .60888 Mdot
.40514 .48805 Mdot
.35768 .70111 Mdot
.19784 .56082 Mdot
.83203 .45597 Mdot
.61413 .85795 Mdot
.69102 .22594 Mdot
.35835 .80781 Mdot
.75548 .51191 Mdot
.4073 .63313 Mdot
.57893 .83988 Mdot
.82716 .38653 Mdot
.7499 .71631 Mdot
.47906 .2087 Mdot
.46316 .33617 Mdot
.59114 .40066 Mdot
.6958 .23441 Mdot
.33217 .4457 Mdot
.65967 .781 Mdot
.59295 .19562 Mdot
.61861 .32512 Mdot
.39472 .19984 Mdot
.73154 .29439 Mdot
.71077 .66767 Mdot
.57631 .63081 Mdot
.39696 .60272 Mdot
.67662 .64685 Mdot
.68176 .52348 Mdot
.46296 .2395 Mdot
.31322 .6539 Mdot
.40442 .37456 Mdot
.33696 .54579 Mdot
.52728 .52317 Mdot
.5236 .57135 Mdot
.35756 .50039 Mdot
.66678 .5134 Mdot
.79697 .46568 Mdot
.57004 .42285 Mdot
.85292 .52079 Mdot
.5626 .25206 Mdot
.55801 .58579 Mdot
.29466 .66069 Mdot
.35155 .2986 Mdot
.52074 .18157 Mdot
.64085 .3462 Mdot
.78341 .63468 Mdot
.49667 .40025 Mdot
.2952 .63889 Mdot
.67524 .64173 Mdot
.45104 .79675 Mdot
.4232 .67345 Mdot
.74174 .45787 Mdot
.59395 .76596 Mdot
.57565 .45607 Mdot
.65665 .60329 Mdot
.60708 .59 Mdot
.45877 .8738 Mdot
.56792 .22024 Mdot
.4899 .25541 Mdot
.77725 .64504 Mdot
.59242 .35877 Mdot
.62378 .55198 Mdot
.34785 .64121 Mdot
.43967 .80514 Mdot
.61849 .74045 Mdot
.32824 .3571 Mdot
.54336 .29201 Mdot
.29128 .40921 Mdot
.78455 .61225 Mdot
.78881 .58883 Mdot
.22592 .31685 Mdot
.67076 .59511 Mdot
.47796 .80512 Mdot
.3835 .76655 Mdot
.65213 .52279 Mdot
.72055 .55654 Mdot
.74299 .36146 Mdot
.84499 .48116 Mdot
.62177 .43198 Mdot
.33482 .77999 Mdot
.21646 .57436 Mdot
.49458 .33859 Mdot
.32381 .30893 Mdot
.31478 .72262 Mdot
.77106 .65412 Mdot
.6556 .62727 Mdot
.7281 .64564 Mdot
.50602 .66205 Mdot
.52942 .66249 Mdot
.67218 .20692 Mdot
.45911 .44031 Mdot
.67245 .67582 Mdot
.67619 .46948 Mdot
.43427 .59003 Mdot
.74526 .25427 Mdot
.49827 .83446 Mdot
.52509 .1751 Mdot
.56757 .36592 Mdot
.48168 .57112 Mdot
.45417 .66156 Mdot
.46474 .70566 Mdot
.72345 .44208 Mdot
.76421 .33314 Mdot
.31808 .72602 Mdot
.72609 .49973 Mdot
.6457 .63774 Mdot
.60327 .27028 Mdot
.71578 .71669 Mdot
.55846 .83088 Mdot
.54404 .44795 Mdot
.57221 .24942 Mdot
.24098 .55146 Mdot
.36912 .80839 Mdot
.42377 .47086 Mdot
.45344 .49828 Mdot
.7052 .32473 Mdot
.70054 .45473 Mdot
.30485 .31614 Mdot
.51267 .60308 Mdot
.43057 .21738 Mdot
.69442 .74948 Mdot
.16313 .41167 Mdot
.31501 .26352 Mdot
.76017 .26709 Mdot
.64658 .73968 Mdot
.68372 .45358 Mdot
.75303 .61504 Mdot
.14915 .42688 Mdot
.39021 .48254 Mdot
.80867 .53527 Mdot
.22215 .53941 Mdot
.78141 .62884 Mdot
.60886 .32876 Mdot
.67987 .38503 Mdot
.76134 .34588 Mdot
.84195 .50129 Mdot
.53861 .80416 Mdot
.74431 .68321 Mdot
.58343 .49554 Mdot
.84522 .44388 Mdot
.70684 .3095 Mdot
.47589 .47378 Mdot
.41895 .39702 Mdot
.51874 .19138 Mdot
.77569 .56273 Mdot
.78147 .49254 Mdot
.36571 .73566 Mdot
.41209 .46238 Mdot
.36971 .67193 Mdot
.71583 .64091 Mdot
.31678 .57341 Mdot
.70876 .46422 Mdot
.29328 .65946 Mdot
.69571 .7565 Mdot
.38244 .47593 Mdot
.34338 .30462 Mdot
.59163 .27434 Mdot
.27605 .71655 Mdot
.72604 .43731 Mdot
.55821 .21776 Mdot
.60287 .80356 Mdot
.3137 .39336 Mdot
.32227 .70712 Mdot
.58895 .89724 Mdot
.33292 .7517 Mdot
.7864 .42428 Mdot
.82559 .43903 Mdot
.58904 .82296 Mdot
.79529 .44765 Mdot
.29154 .27077 Mdot
.48495 .70899 Mdot
.33747 .64248 Mdot
.45472 .61967 Mdot
.82803 .36746 Mdot
.30415 .59659 Mdot
.82904 .43517 Mdot
.54635 .85388 Mdot
.68789 .64414 Mdot
.52294 .5693 Mdot
.43533 .34951 Mdot
.38217 .3892 Mdot
.32804 .56894 Mdot
.73624 .64586 Mdot
.47946 .71497 Mdot
.55228 .26972 Mdot
.38451 .37577 Mdot
.34392 .45173 Mdot
.73865 .56504 Mdot
.54599 .23889 Mdot
.72034 .45593 Mdot
.3327 .50036 Mdot
.55542 .47481 Mdot
.33875 .69243 Mdot
.60864 .62539 Mdot
.70643 .67497 Mdot
.26915 .313 Mdot
.50533 .39891 Mdot
.44014 .37197 Mdot
.68678 .71499 Mdot
.35315 .7754 Mdot
.72256 .47888 Mdot
.7952 .3629 Mdot
.50341 .18771 Mdot
.36607 .5609 Mdot
.37312 .70506 Mdot
.26482 .30359 Mdot
.18496 .56582 Mdot
.80785 .47563 Mdot
.6204 .60833 Mdot
.25434 .65934 Mdot
.51325 .51614 Mdot
.82808 .56905 Mdot
.34458 .74191 Mdot
.41556 .75297 Mdot
.4362 .43043 Mdot
.6222 .71611 Mdot
.70586 .63253 Mdot
.26484 .57227 Mdot
.57432 .4807 Mdot
.48926 .14069 Mdot
.70258 .52214 Mdot
.72046 .22194 Mdot
.61998 .39128 Mdot
.44583 .1808 Mdot
.20378 .52362 Mdot
.5052 .45173 Mdot
.58124 .48291 Mdot
.74542 .45168 Mdot
.71193 .3607 Mdot
.3887 .80898 Mdot
.20743 .36293 Mdot
.47634 .38848 Mdot
.28135 .69838 Mdot
.24284 .68376 Mdot
.71627 .68797 Mdot
.47859 .5499 Mdot
.32745 .75179 Mdot
.46706 .44009 Mdot
.25203 .35846 Mdot
.55873 .84206 Mdot
.76618 .48714 Mdot
.54497 .61355 Mdot
.32491 .6728 Mdot
.80531 .53953 Mdot
.75577 .69551 Mdot
.34802 .22317 Mdot
.76255 .52152 Mdot
.57998 .34949 Mdot
.45855 .48537 Mdot
.76312 .63484 Mdot
.25932 .64553 Mdot
.66323 .42963 Mdot
.33687 .70892 Mdot
.62356 .15797 Mdot
.77556 .3515 Mdot
.76365 .3329 Mdot
.28586 .67145 Mdot
.64206 .59502 Mdot
.72855 .32871 Mdot
.38525 .72364 Mdot
.76578 .47438 Mdot
.39532 .79902 Mdot
.35432 .7142 Mdot
.21723 .31166 Mdot
.45575 .76948 Mdot
.42555 .33266 Mdot
.71322 .62245 Mdot
.47016 .76173 Mdot
.57471 .3512 Mdot
.33572 .615 Mdot
.6856 .4742 Mdot
.59957 .402 Mdot
.71488 .46409 Mdot
.68651 .43277 Mdot
.42658 .76107 Mdot
.63598 .72845 Mdot
.73518 .50334 Mdot
.66825 .74477 Mdot
.61236 .51511 Mdot
.28291 .33657 Mdot
.38005 .29599 Mdot
.67688 .47961 Mdot
.44447 .39874 Mdot
.40622 .54998 Mdot
.56607 .45619 Mdot
.34841 .52723 Mdot
.67279 .22098 Mdot
.27176 .52453 Mdot
.63228 .58499 Mdot
.48739 .16298 Mdot
.6425 .52402 Mdot
.80076 .32374 Mdot
.25016 .34239 Mdot
.66776 .64269 Mdot
.27822 .38935 Mdot
.25698 .43461 Mdot
.34654 .18772 Mdot
.73434 .59547 Mdot
.43114 .42418 Mdot
.59745 .55271 Mdot
.66854 .58933 Mdot
.5681 .27896 Mdot
.38205 .37187 Mdot
.56168 .6526 Mdot
.63234 .2967 Mdot
.37923 .54791 Mdot
.60762 .56739 Mdot
.46456 .35207 Mdot
.37838 .68854 Mdot
.84636 .49448 Mdot
.4359 .37845 Mdot
.56797 .15352 Mdot
.52688 .63273 Mdot
.57666 .78781 Mdot
.61163 .835 Mdot
.37155 .21015 Mdot
.385 .27935 Mdot
.18738 .61951 Mdot
.52818 .6201 Mdot
.74349 .51145 Mdot
.65768 .54416 Mdot
.40032 .75156 Mdot
.29558 .49858 Mdot
.2666 .62271 Mdot
.61734 .40193 Mdot
.3066 .29933 Mdot
.53728 .23986 Mdot
.62647 .58797 Mdot
.77173 .50644 Mdot
.47111 .79106 Mdot
.68697 .37767 Mdot
.47339 .4404 Mdot
.71426 .68689 Mdot
.62899 .73002 Mdot
.60676 .56504 Mdot
.79842 .38154 Mdot
.36883 .75111 Mdot
.82109 .61884 Mdot
.47272 .68225 Mdot
.39203 .41934 Mdot
.68614 .31741 Mdot
.73312 .46781 Mdot
.59371 .62321 Mdot
.62741 .82257 Mdot
.30239 .63747 Mdot
.67724 .30656 Mdot
.35449 .68815 Mdot
.38039 .62954 Mdot
.53605 .47103 Mdot
.47192 .22873 Mdot
.26331 .26488 Mdot
.54597 .65197 Mdot
.37412 .22696 Mdot
.60865 .59959 Mdot
.60012 .26692 Mdot
.67984 .50713 Mdot
.43833 .30672 Mdot
.63631 .70941 Mdot
.40913 .26039 Mdot
.82569 .58797 Mdot
.62383 .82464 Mdot
.5892 .32485 Mdot
.55983 .2923 Mdot
.62828 .49099 Mdot
.51273 .66036 Mdot
.61165 .46745 Mdot
.4284 .63748 Mdot
.72415 .53753 Mdot
.3988 .19383 Mdot
.75678 .46804 Mdot
.39169 .63025 Mdot
.82146 .5705 Mdot
.80828 .63361 Mdot
.84216 .44424 Mdot
.23656 .65175 Mdot
.68654 .53647 Mdot
.77877 .31784 Mdot
.57964 .65634 Mdot
.70654 .75045 Mdot
.80368 .48324 Mdot
.4799 .87692 Mdot
.73026 .64931 Mdot
.66284 .46451 Mdot
.21439 .36241 Mdot
.71069 .38532 Mdot
.52705 .84379 Mdot
.45766 .47075 Mdot
.48879 .27428 Mdot
.52681 .8479 Mdot
.26741 .22923 Mdot
.59378 .59572 Mdot
.67641 .43402 Mdot
.48819 .51002 Mdot
.68188 .4784 Mdot
.3505 .39743 Mdot
.48206 .64558 Mdot
.5519 .32424 Mdot
.33281 .29998 Mdot
.34282 .69861 Mdot
.36756 .66997 Mdot
.3496 .3993 Mdot
.33468 .56623 Mdot
.36045 .68522 Mdot
.33405 .7393 Mdot
.72026 .66929 Mdot
.56939 .64478 Mdot
.51455 .65157 Mdot
.69549 .5116 Mdot
.29898 .48026 Mdot
.42584 .2727 Mdot
.45525 .64692 Mdot
.4075 .2645 Mdot
.69898 .3707 Mdot
.76778 .279 Mdot
.45884 .29874 Mdot
.47256 .82385 Mdot
.69049 .51706 Mdot
.72989 .44709 Mdot
.66138 .75803 Mdot
.42289 .2087 Mdot
.35665 .42663 Mdot
.41396 .71962 Mdot
.80664 .58109 Mdot
.61309 .23122 Mdot
.42805 .78885 Mdot
.67161 .24571 Mdot
.5793 .38435 Mdot
.56981 .60935 Mdot
.47261 .50561 Mdot
.4786 .20275 Mdot
.63929 .60117 Mdot
.66822 .46338 Mdot
.41735 .44338 Mdot
.59187 .21675 Mdot
.47566 .8394 Mdot
.46068 .793 Mdot
.7276 .61227 Mdot
.792 .58825 Mdot
.37628 .35266 Mdot
.37892 .7552 Mdot
.63581 .4542 Mdot
.37306 .43024 Mdot
.66947 .27171 Mdot
.84507 .53665 Mdot
.60533 .4716 Mdot
.28654 .59046 Mdot
.45116 .57676 Mdot
.58966 .67321 Mdot
.75524 .45846 Mdot
.25111 .46815 Mdot
.53134 .2563 Mdot
.656 .58411 Mdot
.51065 .24474 Mdot
.35472 .46661 Mdot
.33079 .63158 Mdot
.60275 .54589 Mdot
.44988 .72894 Mdot
.30354 .52932 Mdot
.60041 .29974 Mdot
.42006 .5851 Mdot
.27437 .59824 Mdot
.23095 .63879 Mdot
.57501 .60031 Mdot
.76909 .55326 Mdot
.70512 .6935 Mdot
.42316 .79763 Mdot
.74044 .48352 Mdot
.80859 .46693 Mdot
.71628 .36518 Mdot
.65668 .69917 Mdot
.41822 .23792 Mdot
.41625 .62604 Mdot
.44162 .30818 Mdot
.62088 .5545 Mdot
.74739 .65177 Mdot
.63406 .74695 Mdot
.27475 .57573 Mdot
.52304 .43456 Mdot
.64247 .77155 Mdot
.51257 .42198 Mdot
.5954 .83585 Mdot
.71247 .38603 Mdot
.31275 .65135 Mdot
.64595 .34182 Mdot
.21139 .53337 Mdot
.27981 .28942 Mdot
.79478 .64032 Mdot
.25187 .32417 Mdot
.53382 .49564 Mdot
.37962 .22001 Mdot
.76723 .38116 Mdot
.53975 .85075 Mdot
.32413 .65637 Mdot
.61 .46573 Mdot
.37379 .67091 Mdot
.60038 .32016 Mdot
.50572 .38746 Mdot
.42484 .3094 Mdot
.56326 .66017 Mdot
.51867 .30149 Mdot
.38263 .27031 Mdot
.41638 .67567 Mdot
.68609 .28551 Mdot
.7992 .58372 Mdot
.42444 .74793 Mdot
.47636 .44816 Mdot
.26329 .36904 Mdot
.3246 .62295 Mdot
.3085 .79993 Mdot
.74277 .24945 Mdot
.45084 .57577 Mdot
.41106 .48364 Mdot
.27951 .61848 Mdot
.46675 .38008 Mdot
.53584 .68411 Mdot
.72698 .68047 Mdot
.60839 .39095 Mdot
.4542 .33032 Mdot
.58222 .21123 Mdot
.75049 .44639 Mdot
.29526 .56081 Mdot
.65327 .28103 Mdot
.78327 .29378 Mdot
.3604 .78658 Mdot
.74394 .46919 Mdot
.3661 .83746 Mdot
.45761 .22207 Mdot
.60627 .59121 Mdot
.58863 .8009 Mdot
.83325 .4552 Mdot
.28536 .65464 Mdot
.3046 .3332 Mdot
.8003 .42863 Mdot
.30974 .64278 Mdot
.37235 .72427 Mdot
.59087 .27365 Mdot
.51725 .24776 Mdot
.50413 .46909 Mdot
.25892 .43452 Mdot
.70263 .26638 Mdot
.6609 .6317 Mdot
.80139 .5639 Mdot
.33455 .29342 Mdot
.20051 .3293 Mdot
.81216 .62566 Mdot
.34264 .5883 Mdot
.34644 .38698 Mdot
.57507 .80519 Mdot
.23299 .59994 Mdot
.43018 .73044 Mdot
.2764 .32284 Mdot
.6027 .74652 Mdot
.23849 .42756 Mdot
.35997 .25066 Mdot
.35602 .6977 Mdot
.46932 .75822 Mdot
.60195 .4733 Mdot
.69336 .6985 Mdot
.56555 .26864 Mdot
.29781 .67679 Mdot
.4297 .32421 Mdot
.23347 .58184 Mdot
.69422 .71061 Mdot
.63231 .7848 Mdot
.62634 .47126 Mdot
.29123 .21304 Mdot
.81662 .48309 Mdot
.41326 .21689 Mdot
.41176 .62662 Mdot
.83529 .57217 Mdot
.63174 .46289 Mdot
.81088 .45 Mdot
.44667 .81842 Mdot
.41758 .29474 Mdot
.69055 .33149 Mdot
.41922 .63108 Mdot
.78518 .52755 Mdot
.67686 .67299 Mdot
.47751 .76385 Mdot
.31395 .30747 Mdot
.29569 .6575 Mdot
.3413 .36404 Mdot
.2495 .57102 Mdot
.55881 .60285 Mdot
.61709 .55651 Mdot
.80813 .34733 Mdot
.53981 .5018 Mdot
.40234 .55612 Mdot
.52154 .6608 Mdot
.22475 .34459 Mdot
.27421 .74194 Mdot
.50154 .66951 Mdot
.6268 .24126 Mdot
.35914 .72598 Mdot
.36423 .58257 Mdot
.64831 .6185 Mdot
.09608 .55473 Mdot
.63729 .83297 Mdot
.6995 .57742 Mdot
.48354 .72102 Mdot
.28826 .68735 Mdot
.83786 .46707 Mdot
.28968 .42782 Mdot
.37637 .29403 Mdot
.17119 .43158 Mdot
.23653 .61458 Mdot
.52293 .5847 Mdot
.4601 .83468 Mdot
.7866 .65079 Mdot
.32173 .29438 Mdot
.81948 .5813 Mdot
.43684 .54609 Mdot
.45743 .66402 Mdot
.16557 .66578 Mdot
.76451 .6427 Mdot
.40154 .58025 Mdot
.22724 .33612 Mdot
.63782 .60264 Mdot
.4491 .63147 Mdot
.62302 .27648 Mdot
.34106 .73399 Mdot
.36337 .70027 Mdot
.84208 .49954 Mdot
.64033 .59842 Mdot
.39908 .26742 Mdot
.59668 .3889 Mdot
.57805 .48264 Mdot
.49103 .66347 Mdot
.61553 .34745 Mdot
.35891 .57861 Mdot
.65872 .47335 Mdot
.57956 .34007 Mdot
.2875 .71213 Mdot
.52894 .87642 Mdot
.66082 .72446 Mdot
.56394 .34618 Mdot
.39194 .67079 Mdot
.45999 .76977 Mdot
.33047 .56875 Mdot
.40009 .5252 Mdot
.51541 .8546 Mdot
.74333 .77659 Mdot
.49607 .27898 Mdot
.45037 .69786 Mdot
.60225 .54894 Mdot
.57874 .63877 Mdot
.70694 .66098 Mdot
.61139 .41856 Mdot
.37704 .36184 Mdot
.53364 .57988 Mdot
.55969 .60137 Mdot
.61732 .40096 Mdot
.69417 .20978 Mdot
.50623 .62038 Mdot
.63314 .62015 Mdot
.71606 .738 Mdot
.28473 .3341 Mdot
.55454 .78957 Mdot
.51988 .62548 Mdot
.72186 .3261 Mdot
.6191 .45768 Mdot
.72671 .51593 Mdot
.34461 .30275 Mdot
.826 .52203 Mdot
.62812 .75106 Mdot
.7203 .61376 Mdot
.4987 .61211 Mdot
.31202 .48516 Mdot
.68221 .42086 Mdot
.80254 .42101 Mdot
.56237 .5655 Mdot
.7332 .72728 Mdot
.4118 .29625 Mdot
.53025 .30517 Mdot
.3734 .57748 Mdot
.82527 .40092 Mdot
.34526 .24823 Mdot
.69536 .65316 Mdot
.4921 .17633 Mdot
.53074 .20817 Mdot
.31629 .57586 Mdot
.42377 .34101 Mdot
.39318 .64289 Mdot
.62622 .59444 Mdot
.80298 .31107 Mdot
.79868 .40994 Mdot
.55079 .39704 Mdot
.51024 .26406 Mdot
.63065 .66761 Mdot
.60312 .48374 Mdot
.4411 .8753 Mdot
.32363 .43704 Mdot
.77718 .28511 Mdot
.40541 .75397 Mdot
.74205 .57152 Mdot
.68633 .46059 Mdot
.54434 .56061 Mdot
.43004 .36549 Mdot
.83546 .48411 Mdot
.56327 .59595 Mdot
.39289 .24253 Mdot
.52075 .59594 Mdot
.54739 .17929 Mdot
.53839 .40345 Mdot
.56846 .29347 Mdot
.5784 .29923 Mdot
.29257 .27174 Mdot
.68038 .75484 Mdot
.59108 .44532 Mdot
.40135 .84768 Mdot
.75563 .618 Mdot
.78394 .63534 Mdot
.3249 .36237 Mdot
.34241 .21585 Mdot
.78607 .49055 Mdot
.73068 .4957 Mdot
.55088 .40443 Mdot
.37153 .51588 Mdot
.5028 .19201 Mdot
.36054 .58863 Mdot
.69771 .40854 Mdot
.60826 .32119 Mdot
.82688 .71352 Mdot
.34742 .59568 Mdot
.51323 .52528 Mdot
.43395 .22246 Mdot
.79824 .61012 Mdot
.31977 .47299 Mdot
.48213 .85122 Mdot
.39787 .48296 Mdot
.45849 .66557 Mdot
.62438 .74252 Mdot
.41524 .74706 Mdot
.53167 .19142 Mdot
.40395 .15451 Mdot
.36852 .78733 Mdot
.52151 .28693 Mdot
.5551 .46865 Mdot
.65147 .52377 Mdot
.71516 .55797 Mdot
.27016 .40716 Mdot
.43583 .84272 Mdot
.66041 .46733 Mdot
.76328 .63604 Mdot
.32839 .20266 Mdot
.4201 .77298 Mdot
.84053 .46977 Mdot
.78642 .45003 Mdot
.70738 .52298 Mdot
.34087 .56375 Mdot
.24236 .53389 Mdot
.55261 .3269 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0:[ooooo0_l0002Mooooo`007?ooool00ol0003ooooooooo
o`2Zooooo`;o0000WOooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo09_ooooo0_l0002/ooooo`007?ooool00ol0003oooooooooo`2Boooo
o`;o00000_ooool2o`0000?ooooo0_l0002/ooooo`007?ooool00ol0003oooooooooo`2Booooo`;o
00000_ooool2o`0000;ooooo0_l0002]ooooo`007?ooool00ol0003oooooooooo`2Jooooo`;o0000
[Oooool001cooooo0_l0002fooooo`;o0000T_ooool001cooooo00?o0000ooooooooool0Ooooool2
o`0002Oooooo0_l0000;ooooo`;o0000T_ooool001cooooo00?o0000ooooooooool0Ooooool2o`00
0003ooooool0003o000002Cooooo0_l0000Fooooo`;o00001Oooool2o`00083ooooo000Looooo`03
o`000?oooooooooo08;ooooo0_l0000Gooooo`;o00008oooool2o`0000Gooooo0_l00020ooooo`00
7?ooool00ol0003oooooooooo`2Kooooo`;o000000?oooooo`000?l000004oooool2o`0009Cooooo
000Looooo`03o`000?oooooooooo09kooooo0_l0000Cooooo`;o00001Oooool2o`0008gooooo000L
ooooo`03o`000?oooooooooo0:Sooooo1?l0000>ooooo`;o00002_ooool2o`00087ooooo000Loooo
o`03o`000?oooooooooo0:?ooooo0_l00002ooooo`Go00006_ooool2o`00087ooooo000Looooo`03
o`000?oooooooooo09cooooo0_l00003ooooo`Co00000_ooool2o`00017ooooo0_l0002=ooooo`00
7?ooool00ol0003oooooooooo`2=ooooo`;o00003Oooool2o`0000?ooooo0_l0000;ooooo`;o0000
2_ooool2o`0008gooooo000Looooo`03o`000?oooooooooo08gooooo0_l00006ooooo`;o00001ooo
ool2o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o00000_ooool2o`0009Wooooo000L
ooooo`03o`000?oooooooooo06gooooo0_l00003ooooo`;o00004oooool2o`0000Sooooo0_l00002
ooooo`;o00001oooool6o`000003ooooool0003o000000?ooooo1ol00002ooooo`;o00001?ooool2
o`0002Kooooo0_l0001Vooooo`007?ooool00ol0003oooooooooo`1]ooooo`;o00000oooool2o`00
01?ooooo0_l00008ooooo`;o00001_ooool3o`0000Cooooo0_l0000:ooooo`Wo00001?ooool2o`00
02Kooooo0_l0001Vooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5
o`0000Kooooo00?o0000ooooooooool0O_ooool2o`0000_ooooo0ol00009ooooo`Go00001?ooool2
o`0000?ooooo0_l00002ooooo`;o00001_ooool2o`0000?ooooo0_l00002ooooo`;o00001?ooool2
o`0008Oooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1nooooo`Ko000000?oooooo`000?l00000
1?ooool3o`0000Wooooo0_l00002ooooo`;o00000oooool2o`0000?ooooo0_l00002ooooo`;o0000
1_ooool2o`0000?ooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo1?l00025ooooo`00
00?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo
00?o0000ooooooooool0JOooool2o`00017ooooo0_l00002ooooo`Co000000?oooooo`000?l00000
0ol000000ooooooo0000o`000006ooooo`;o00001?ooool4o`0001Cooooo0_l00003ooooo`Ko0000
00?oooooo`000?l000000_l000000ooooooo0000o`000025ooooo`0000?oooooo`000?ooool00_oo
ool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0001Wooooo`Co00004Ooo
ool2o`0000Cooooo0_l000000ooooooo0000o`000006o`0000;ooooo0_l00002ooooo`;o00000ooo
ool3o`0001cooooo1Ol00003ooooo`;o0000R?ooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo06Oooooo0_l0000I
ooooo`;o00001?ooool3o`0000Cooooo1_l00003ooooo`;o00007Oooool4o`0001oooooo0_l0001]
ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0QOooool5o`0000Cooooo0_l000001?oooooo0000o`000?l00004
ooooo`Co00003Oooool2o`0000oooooo0_l0000Kooooo`;o000000?oooooo`000?l00000KOooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo
00?o0000ooooooooool0MOooool2o`0000kooooo0ol00002ooooo`;o00000_ooool2o`0000;ooooo
0_l00003ooooo`Go00003Oooool2o`0000gooooo1?l00005ooooo`;o00000_ooool2o`00013ooooo
0_l00005ooooo`;o0000JOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So
410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0Foooool2o`0001Sooooo0_l00007oooo
o`;o00001_ooool2o`0000;ooooo0_l0000;ooooo`;o00007oooool3o`0000Cooooo1?l00002oooo
o`;o00004?ooool2o`0000Gooooo0_l0001Yooooo`007?ooool00ol0003oooooooooo`1Kooooo`;o
00003_ooool2o`0000Cooooo0_l0000;ooooo`Ko00000_ooool5o`0001Sooooo0_l0000=ooooo`;o
00000_ooool4o`0000;ooooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l0000<ooooo`Co
0000L?ooool001cooooo00?o0000ooooooooool0Joooool2o`0000Cooooo0_l00005ooooo`;o0000
1_ooool4o`0000Cooooo0ol00006ooooo`;o00002oooool2o`0000?ooooo0_l0000<ooooo`?o0000
00?oooooo`000?l000000ol00002ooooo`;o00000oooool2o`0000Cooooo0_l0000<ooooo`Co0000
00?oooooo`000?l00000KOooool001cooooo00?o0000ooooooooool0KOooool2o`0000Cooooo0_l0
0003ooooo`;o00003_ooool3o`0000Kooooo0_l0000;ooooo`;o00000oooool2o`0000cooooo0_l0
0002ooooo`?o00000_ooool2o`0001_ooooo0_l000000ooooooo0000o`00000:ooooo`;o0000HOoo
ool001cooooo00?o0000ooooooooool0F_ooool2o`00017ooooo0_l00004ooooo`;o000000?ooooo
o`000?l000002oooool2o`0000?ooooo0ol00006ooooo`;o00004?ooool2o`0001Gooooo0_l0000Q
ooooo`;o00001oooool2o`00067ooooo000Looooo`03o`000?oooooooooo05?ooooo0_l00005oooo
o`;o00006_ooool2o`0000_ooooo0_l0000Aooooo`;o00002oooool2o`0001kooooo0_l0000Hoooo
o`;o0000J_ooool001cooooo00?o0000ooooooooool0Doooool2o`0001;ooooo0_l00009ooooo`;o
00001oooool2o`0000Oooooo0_l0000:ooooo`;o00001?ooool2o`0000[ooooo0ol0000;ooooo`;o
00004Oooool2o`000003ooooool0003o0000087ooooo000Looooo`03o`000?oooooooooo06Oooooo
0_l00006ooooo`;o000000?oooooo`000?l000001oooool2o`0000Cooooo1Ol000000ooooooo0000
o`000004ooooo`;o000000?oooooo`000?l000004?ooool2o`0000cooooo0_l00008ooooo`;o0000
1oooool2o`000003ooooool0003o000000;o00005?ooool2o`0006Wooooo000Looooo`03o`000?oo
oooooooo06Oooooo0_l00006ooooo`;o00000_ooool2o`0000Gooooo1?l00003ooooo`So00001?oo
ool2o`0000Cooooo0_l00002ooooo`;o00004_ooool2o`000003ooooool0003o000000[ooooo0_l0
00000ooooooo0000o`000002ooooo`?o00001?ooool2o`0000?ooooo0_l0000?ooooo`;o0000JOoo
ool001cooooo00?o0000ooooooooool0Joooool4o`0000Cooooo0_l00002ooooo`;o000000?ooooo
o`000?l000000ol00005ooooo`Co00002oooool3o`000004ooooool0003o0000o`00017ooooo0_l0
00000ooooooo0000o`00000=ooooo`;o00000_ooool3o`0000Cooooo1?l000000ooooooo0000o`00
0008ooooo`;o0000L?ooool001cooooo00?o0000ooooooooool0Goooool2o`0000[ooooo1Ol00007
ooooo`;o00000oooool3o`000003ooooool0003o000000?ooooo0_l0000=ooooo`Ko00002?ooool2
o`0001gooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l00006ooooo`;o00000_ooool3
o`0000Wooooo0_l0001Uooooo`007?ooool00ol0003oooooooooo`1Oooooo`;o00002oooool4o`00
013ooooo0_l00003ooooo`;o00000_ooool2o`0000Wooooo1?l0000:ooooo`Co00000_ooool2o`00
00Oooooo0_l0000@ooooo`Co00002oooool3o`000003ooooool0003o000000[ooooo0_l00009oooo
o`;o0000F_ooool001cooooo0_l0001Xooooo`?o00000_ooool2o`0000?ooooo0_l0000Booooo`?o
000000?oooooo`000?l000006Oooool2o`0000;ooooo0_l00007ooooo`Co000000?oooooo`000?l0
00002oooool2o`0000Cooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l000000ooooooo
0000o`00000:ooooo`;o00002Oooool5o`0005Oooooo000Looooo`03o`000?oooooooooo05?ooooo
0_l0000@ooooo`Go00001oooool2o`0000Kooooo0_l00008ooooo`;o000000?oooooo`000?l00000
2?ooool2o`0000Wooooo0_l0000Fooooo`;o000000Coooooo`000?l0003ooooo1?l0000<ooooo`;o
000000?oooooo`000?l000001?l00004ooooo`?o00002Oooool2o`0000Wooooo1Ol0001Gooooo`00
7?ooool00ol0003oooooooooo`18ooooo`;o00002Oooool2o`0000Sooooo0_l00004ooooo`Co0000
3?ooool2o`0000Cooooo0_l00008ooooo`;o000000?oooooo`000?l000002?ooool2o`000003oooo
ool0003o000000Kooooo0_l00004ooooo`;o000000?oooooo`000?l000000oooool2o`0000kooooo
1?l0000Cooooo`;o00001Oooool2o`0001Gooooo0ol0001Hooooo`007?ooool00ol0003ooooooooo
o`18ooooo`;o00004oooool2o`0000Cooooo0_l000000ooooooo0000o`000007ooooo`;o00000_oo
ool2o`0000cooooo0_l00007ooooo`;o00001oooool2o`0000cooooo0_l000000ooooooo0000o`00
0003ooooo`;o00000_ooool2o`0001Sooooo0_l00007ooooo`;o00000_ooool2o`00013ooooo0_l0
001Qooooo`007?ooool00ol0003oooooooooo`1?ooooo`;o00004_ooool2o`000003ooooool0003o
000000Oooooo0_l0000@ooooo`;o00001oooool3o`0000oooooo0_l00003ooooo`?o00001_ooool7
o`0001Kooooo0_l0000;ooooo`Co00001_ooool3o`0000Gooooo0_l0001Qooooo`007?ooool00ol0
003oooooooooo`1?ooooo`;o000000?oooooo`000?l000003oooool2o`00013ooooo0_l00007oooo
o`Go000000?oooooo`000?l000000oooool4o`0000oooooo0_l00003ooooo`?o00001_ooool;o`00
00[ooooo0_l00006ooooo`;o00003Oooool2o`0000Kooooo1?l0000Aooooo`;o0000E?ooool001co
oooo00?o0000ooooooooool0D_ooool2o`0000Oooooo0_l0000Hooooo`;o00000_ooool2o`0000?o
oooo0ol000000ooooooo0000o`000002o`0000?ooooo1_l0000=ooooo`;o00000oooool2o`0000[o
oooo2Ol00009ooooo`?o00001Oooool2o`0000Sooooo0_l0000=ooooo`;o00004Oooool2o`0005Co
oooo000Looooo`03o`000?oooooooooo04cooooo0_l0000=ooooo`;o00001?ooool2o`0001Kooooo
0_l00007ooooo`;o00000oooool2o`0000Cooooo1?l000001?oooooo0000o`000?l0000<ooooo`;o
00000oooool2o`0000Oooooo0ol00002ooooo`;o00001_ooool2o`000004ooooool0003o0000o`00
00oooooo2?l0001`ooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00002oooool4o`0000Co
oooo0_l0000Tooooo`;o00001_ooool6o`0000Kooooo1?l00007ooooo`;o00001_ooool2o`000003
ooooool0003o000000;ooooo0ol00004ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Go
oooo0_l00003ooooo`Ko000000?oooooo`000?l00000KOooool001cooooo00?o0000ooooooooool0
C?ooool2o`0000Kooooo0_l00003ooooo`Co00006oooool5o`0001?ooooo1?l00007ooooo`Co0000
3oooool2o`000003ooooool0003o000000;ooooo0ol00004ooooo`;o00001_ooool2o`000003oooo
ool0003o000000Gooooo0_l0000:ooooo`;o00001_ooool2o`0001;ooooo0_l0001Aooooo`007?oo
ool00ol0003oooooooooo`1<ooooo`;o00000_ooool2o`0000;ooooo0_l00008ooooo`;o00006?oo
ool5o`0001Gooooo0ol00008ooooo`;o00001_ooool2o`0000kooooo0ol00007ooooo`;o00000ooo
ool2o`0000[ooooo0_l0000@ooooo`;o00004_ooool2o`00057ooooo000Looooo`03o`000?oooooo
oooo053ooooo0_l00005ooooo`;o00001Oooool2o`0002Kooooo0_l0000;ooooo`;o00002oooool2
o`0000?ooooo0_l0000>ooooo`?o00001oooool4o`0000gooooo0_l00008ooooo`?o00007?ooool2
o`0000;ooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o00001?ooool2o`00
01[ooooo0_l0000:ooooo`;o00001Oooool4o`0001Kooooo0_l00004ooooo`;o00003Oooool3o`00
00Wooooo1?l0000?ooooo`;o00001?ooool3o`000003ooooool0003o000000cooooo0_l0000;oooo
o`;o00000_ooool2o`0004[ooooo000Looooo`03o`000?oooooooooo057ooooo0_l00004ooooo`;o
00006_ooool2o`0000[ooooo0_l00007ooooo`;o00006Oooool2o`000003ooooool0003o000000Go
oooo0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o000000Sooooo0_l0000?ooooo`;o
00001?ooool2o`0000;ooooo0_l0000<ooooo`;o0000Foooool001cooooo00?o0000ooooooooool0
Eoooool2o`0000cooooo0_l00002ooooo`;o00000oooool2o`0000Cooooo0_l000000ooooooo0000
o`00000;ooooo`;o00001?ooool2o`0001Oooooo0_l000001?oooooo0000o`000?ooool2o`000004
ooooool0003o0000o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`Co00006Oooool2o`00
017ooooo0ol0000?ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0Goooool2o`0000Co
oooo0_l00002ooooo`Oo00001?ooool2o`000004ooooool0003o0000o`0000?ooooo0_l00003oooo
o`Co00001?ooool2o`0001[ooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o
000000Cooooo0_l00003ooooo`?o00000oooool2o`0000Sooooo0_l00007ooooo`;o000000Cooooo
o`000?l0003o00002Oooool2o`000003ooooool0003o000000;ooooo0ol0000?ooooo`;o0000C?oo
ool001cooooo0_l0001Pooooo`?o00001_ooool8o`0000Sooooo0_l00003ooooo`;o00000oooool2
o`0000gooooo0_l0000Booooo`;o00002?ooool2o`0000Oooooo1Ol00002ooooo`?o00002?ooool2
o`0000Oooooo0_l000001?oooooo0000o`000?l00006ooooo`;o000000?oooooo`000?l000000ol0
0003ooooo`;o00006oooool2o`00043ooooo000Looooo`03o`000?oooooooooo04gooooo0_l00003
ooooo`;o00003?ooool2o`0000;ooooo0_l00002ooooo`?o000000?oooooo`000?l000008oooool3
o`00017ooooo0_l0000@ooooo`Ko00000_ooool2o`0000Cooooo0_l0000?ooooo`;o00001oooool2
o`0000;ooooo0ol00004ooooo`;o00000oooool2o`0000[ooooo0_l0000:ooooo`;o0000@?ooool0
01cooooo00?o0000ooooooooool0COooool2o`0000;ooooo1?l00007ooooo`;o00001?ooool4o`00
00?ooooo0_l000000ooooooo0000o`00000Mooooo`;o00001Oooool2o`0001Cooooo0_l00009oooo
o`?o000000?oooooo`000?l000001?l00002ooooo`;o00001?ooool2o`00017ooooo0_l000000ooo
oooo0000o`00000Booooo`;o00002_ooool2o`0004cooooo000Looooo`03o`000?oooooooooo04ko
oooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00003ooooo`;o00001?ooool2o`000003
ooooool0003o000000;ooooo0_l0000Kooooo`;o00000oooool3o`0001[ooooo0_l00005ooooo`;o
00000_ooool8o`0000Cooooo0_l0000?ooooo`;o00001_ooool2o`000003ooooool0003o000000Go
oooo0_l00006ooooo`;o0000GOooool001cooooo00?o0000ooooooooool0@oooool2o`0000Wooooo
0_l00004ooooo`;o000000?oooooo`000?l000003?ooool2o`0001oooooo0_l00004ooooo`;o0000
1_ooool2o`0000Kooooo0_l0000Aooooo`;o00000_ooool4o`0000;ooooo0_l0000Eooooo`;o0000
1?ooool2o`0000Oooooo0_l000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l00000
4_ooool2o`0004Kooooo000Looooo`03o`000?oooooooooo04?ooooo0_l000000ooooooo0000o`00
0002o`0000Sooooo1?l00002ooooo`;o00000oooool4o`0000Cooooo0_l00009ooooo`;o00001_oo
ool4o`0001Cooooo0_l00002ooooo`;o00001_ooool2o`0000gooooo0_l00002ooooo`;o00000_oo
ool2o`0001Gooooo0_l0000:ooooo`Co00001?ooool3o`000003ooooool0003o000000Wooooo0ol0
000@ooooo`?o0000A_ooool001cooooo00?o0000ooooooooool0A_ooool4o`0000Sooooo0_l00004
ooooo`Co000000?oooooo`000?l000000_l0000;ooooo`;o00000_ooool2o`0000Kooooo1?l0000D
ooooo`;o00005_ooool5o`0000Cooooo0ol0000;ooooo`;o00002Oooool2o`0000?ooooo0_l00000
0ooooooo0000o`000004ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00002_oo
ool2o`0000Wooooo0_l00005ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0?Oooool2
o`0000cooooo0_l00005ooooo`;o00000_ooool2o`0000;ooooo0_l0000@ooooo`;o00004?ooool2
o`0000;ooooo0_l0000Fooooo`;o00003?ooool4o`0000Gooooo1?l0000:ooooo`;o000000?ooooo
o`000?l000002oooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`00000<
ooooo`;o00003_ooool2o`0000Sooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0moooo
o`;o00001?ooool2o`0000Kooooo0_l000000ooooooo0000o`000006ooooo`;o00009_ooool2o`00
00;ooooo0_l00004ooooo`;o00004?ooool2o`0001Cooooo1Ol00005ooooo`Co00001?ooool7o`00
00;ooooo0_l0000:ooooo`?o00001?ooool2o`000003ooooool0003o000000Cooooo1?l0000>oooo
o`;o00001Oooool2o`000003ooooool0003o000004Cooooo000Looooo`03o`000?oooooooooo03go
oooo0_l00004ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000Hooooo`Ko
00001oooool8o`0000_ooooo0ol0000Qooooo`;o000000Coooooo`000?l0003o00002?ooool4o`00
00;ooooo3Ol0000:ooooo`;o00000oooool7o`0000Cooooo1Ol0000=ooooo`;o00001Oooool2o`00
04Oooooo000Looooo`03o`000?oooooooooo03gooooo0_l00008ooooo`;o00001Oooool2o`0000Go
oooo0_l00004ooooo`;o00000oooool2o`0000Kooooo1_l00002ooooo`?o000000?oooooo`000?l0
00002_l00008ooooo`?o000000?oooooo`000?l000000_ooool2o`0000Wooooo0_l00003ooooo`Co
00001oooool7o`0000?ooooo0_l00003ooooo`;o00000oooool5o`000005ooooool0003o0000o`00
0?ooool00_l00007ooooo`;o00002?ooool5o`0000Oooooo1?l0001Mooooo`007?ooool00ol0003o
ooooooooo`1Eooooo`;o00000_ooool4o`0000;ooooo0ol000000ooooooo0000o`00000;oooooaCo
00000_ooool5o`000003ooooool0003o000000;ooooo0_l00009ooooo`;o00000oooool4o`000003
ooooool0003o000000?ooooo0ol000000ooooooo0000o`000005ooooo`;o00000oooool2o`000003
ooooool0003o000000_o00002?ooool2o`0000?ooooo0_l00004ooooo`;o00004_ooool2o`000003
ooooool0003o000000Wooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`16ooooo`;o0000
0_ooool2o`0000Wooooo1_l00004ooooo`;o00000_ooool3o`0000Kooooo0_l00002ooooo`Go0000
0ooooolAo`0000[ooooo0_l00006ooooo`Co00001_ooool2o`0000;ooooo1?l000000ooooooo0000
o`000004ooooo`;o00001Oooool4o`0000;ooooo3?l0000:ooooo`;o00001oooool2o`0000Sooooo
0_l00005ooooo`;o000000?oooooo`000?l000002Oooool2o`0004Sooooo000Looooo`03o`000?oo
oooooooo04Kooooo0_l00002ooooo`;o00001Oooool2o`0000Cooooo0ol0000:ooooo`;o00001?oo
oolNo`0000_ooooo0_l00006ooooo`Co00002_ooool7o`0000Cooooo0_l00002ooooo`;o000000?o
ooooo`000?l000004Ol0000Booooo`Co00000_ooool2o`0000;ooooo0_l0000=ooooo`;o0000C_oo
ool001cooooo00?o0000ooooooooool0AOooool2o`0000Oooooo0_l000000ooooooo0000o`00000C
ooooo`;o000000?oooooo`000?l000003ol000000ooooooo0000o`00000=o`0001oooooo0_l00000
0ooooooo0000o`000002o`0000Kooooo7Ol0000?ooooo`;o00000_ooool2o`0000Wooooo0ol00005
ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0AOooool2o`0000Oooooo0_l00009oooo
o`;o00002oooool2o`000003ooooool0003o000000_o000000?oooooo`000?l000003_l000000ooo
oooo0000o`00000Oooooo`;o000000?oooooo`000?l000001Oooool2o`000003ooooool0003o0000
00;ooooo6Ol0000Nooooo`Co00003_ooool2o`0004Cooooo000Looooo`;o0000F_ooool2o`0000ko
oooo8ol0000?ooooo`;o00003?ooool5o`0000Gooooo0_l00004oooooaKo00002?ooool2o`0001[o
oooo0ol0000=ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0Doooool2o`0000Sooooo
0_l00005ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`?o000000?oooooo`000?l0
00006?l00007ooooo`Co00000_ooool4o`0000Wooooo0_l000000ooooooo0000o`000003o`0000Oo
oooo5Ol000000ooooooo0000o`000003o`0000Oooooo0_l0000Cooooo`;o00000_ooool2o`0000;o
oooo0ol000000ooooooo0000o`00001?ooooo`007?ooool00ol0003oooooooooo`13ooooo`Go0000
0_ooool2o`0000Kooooo0ol00008ooooo`;o00001Oooool2o`000003ooooool0003o000000?o0000
1_ooool=o`000003ooooool0003o000000[o00001oooool4o`0000;ooooo0_l00003ooooo`;o0000
00?oooooo`000?l000000oooool7o`0000Sooooo7ol00005ooooo`;o00002Oooool2o`0000Kooooo
0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000004oooooo000Looooo`03o`000?oo
oooooooo04?ooooo1Ol00002ooooo`;o00000_ooool2o`0000;ooooo0_l00007ooooo`Co00002?oo
ool6o`0000Kooooo2ol000000ooooooo0000o`00000<o`00017ooooo0_l000001Ooooooo0000o`00
0?l0003ooooo00Oo00003?oooolLo`0000Gooooo0_l000001?oooooo0000o`000?ooool2o`0000?o
oooo0_l0001Sooooo`007?ooool00ol0003oooooooooo`10ooooo`Co00001_ooool2o`0000;ooooo
0ol00009ooooo`?o00002?ooool5o`000003ooooool0003o000000Wooooo2?l000000ooooooo0000
o`000004o`000003ooooool0003o000000Wo00004Oooool8o`0000gooooo6ol0000:ooooo`;o0000
00?oooooo`000?l000000_ooool2o`0000Wooooo0_l0000>ooooo`;o0000BOooool001cooooo00?o
0000ooooooooool0@?ooool4o`0000Kooooo0_l000000ooooooo0000o`000002o`0000Wooooo0_l0
0009ooooo`?o00000oooool2o`0000?ooooo0_l00004oooooako000000?oooooo`000?l000003Ooo
ool6o`0000Oooooo0_l00002oooooaco00004_ooool6o`0000Gooooo0_l0000>ooooo`;o000000Co
ooooo`000?l0003o0000AOooool001cooooo00?o0000ooooooooool0B_ooool2o`000003ooooool0
003o000000?ooooo0_l0000Aooooo`;o00001?ooool2o`0000?ooooo0_l00005ooooob3o00003ooo
ool3o`0000Sooooo0_l00002oooooaco00004oooool5o`0000Oooooo0_l0000?ooooo`?o00001Ooo
ool2o`0003kooooo000Looooo`03o`000?oooooooooo04[ooooo0_l00006ooooo`;o00004?ooool3
o`00013ooooo8Ol00005ooooo`;o00001Oooool4o`0000Kooooo0_l00006oooooaco00002?ooool2
o`0000?ooooo0_l00003ooooo`;o00002_ooool2o`0000oooooo0_l00006ooooo`Co0000??ooool0
01cooooo00?o0000ooooooooool0Goooool2o`0000?ooooo0_l00006ooooo`;o00002_oooolMo`00
0004ooooool0003o0000o`0000Cooooo0_l00004ooooo`Co00001oooool2o`0000Gooooo7Ol00008
ooooo`;o00000oooool2o`0001Cooooo0_l00003ooooo`;o00003oooool2o`0003cooooo000Loooo
o`03o`000?oooooooooo03oooooo0_l0000Dooooo`;o00002?ooool2o`0000_ooooo0_l00005oooo
o`;o00001?oooolDo`000004ooooool0003o0000ooooo`Co000000?oooooo`000?l000000ol00005
ooooo`Ko00001oooool2o`0000Kooooo7Ol00006ooooo`Go00006?ooool2o`0000?ooooo0_l00006
ooooo`;o0000AOooool001cooooo00?o0000ooooooooool0>Oooool2o`0000Cooooo0_l0000:oooo
o`;o00002?ooool2o`0001cooooo0_l00002ooooo`Oo00000_oooolKo`0000?ooooo2?l00007oooo
o`;o00001ooooolKo`0000Oooooo1Ol00004ooooo`;o00001?ooool2o`0000_ooooo0ol00009oooo
o`Co0000AOooool001cooooo00?o0000ooooooooool0>Oooool2o`00013ooooo0_l000000ooooooo
0000o`000005ooooo`;o00003?ooool3o`0000kooooo0_l000000ooooooo0000o`000002ooooo`?o
000000?oooooo`000?l000005_l000000ooooooo0000o`000002o`000003ooooool0003o000000Go
00002?ooool2o`0000Oooooo7?l0000@ooooo`;o00000oooool3o`0000Cooooo0_l00005ooooo`?o
00002Oooool2o`0000;ooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`17ooooo`;o0000
1Oooool3o`0000Cooooo0_l0000<ooooo`?o00001oooool2o`0000Gooooo1?l00004ooooo`oo0000
00?oooooo`000?l000002Ol000000ooooooo0000o`000002o`000004ooooool0003o0000ooooo`Co
000000?oooooo`000?l000001?ooool3o`0000Oooooo0_l000000ooooooo0000o`00000Go`0000So
oooo0_l00008ooooo`Go00001Oooool2o`0000Gooooo1?l0000<ooooo`;o00000oooool2o`0003ko
oooo000Looooo`03o`000?oooooooooo03Wooooo0_l0000<ooooo`;o00001_ooool2o`0000Kooooo
0_l0000@ooooo`;o00000_ooool2o`0000Oooooo1?l00004oooooaoo00000_ooool4o`0000;ooooo
0_l00004ooooo`Co00001?ooool2o`0000?ooooo0ol000000ooooooo0000o`00000Co`0000Sooooo
0_l00008ooooo`?o00003_ooool4o`0000Cooooo0_l0000;ooooo`;o0000?_ooool00006ooooooo^
k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03
o`000?oooooooooo03Wooooo0_l00009ooooo`;o00004Oooool2o`0000Wooooo0_l00005ooooo`;o
00002oooool4o`0000Cooooo7ol000000ooooooo0000o`000002o`0000_ooooo0_l00004ooooo`;o
00001OoooolCo`000003ooooool0003o000000Kooooo0_l00004ooooo`;o00007_ooool2o`0004_o
oooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0A?ooool2o`0000Cooooo0_l00007ooooo`;o00003Oooool2o`00
00Cooooo0ol0000;ooooo`;o00000_ooool2o`0000?ooooo4Ol000001Ooooooo0000o`000?l0003o
oooo00co00001_ooool2o`0000;ooooo0_l00002ooooo`;o00001Oooool2o`0000;ooooo4ol00000
0ooooooo0000o`000006ooooo`;o00001?ooool2o`0001?ooooo0_l00005ooooo`;o0000Coooool0
0003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo00?o0000oooo
ooooool0B_ooool2o`0000Oooooo0_l0000=ooooo`;o00001?ooool2o`0000Cooooo0_l00006oooo
o`?o000000?oooooo`000?l000001?ooool3o`000003ooooool0003o000000ko000000?oooooo`00
0?l000002ol00005ooooo`;o00000_ooool2o`0000;ooooo0_l00005ooooo`;o00000oooool3o`00
00;ooooo3_l0000=ooooo`;o00005?ooool6o`000003ooooool0003o000004oooooo00000ooooooo
0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`00
03?ooooo0_l0000]ooooo`;o00001_ooool2o`0000;ooooo0_l00007ooooo`;o00002?oooolCo`00
0003ooooool0003o000000Ko000000?oooooo`000?l000000_l0000=ooooo`Co00000oooool2o`00
0004ooooool0003o0000ooooo`_o000000?oooooo`000?l000001?l0000=ooooo`;o00005_ooool5
o`00013ooooo0_l0000oooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09oooo
o`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0<oooool2o`0003?ooooo1?l00006
ooooo`;o00001_ooool2o`0000Kooooo6_l0000?ooooo`;o00000_ooool4o`0000Kooooo0_l00000
0ooooooo0000o`000005o`0000;ooooo0_l0000Gooooo`;o00003?ooool2o`0000Sooooo0_l0000<
ooooo`;o00000_ooool4o`0003gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo
00[ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0dooooo`;o00001Oooool2o`00
01Oooooo0_l00005ooooo`;o00000oooool2o`0000Kooooo0_l00008ooooo`;o00001_ooool2o`00
00Wooooo5?l00008ooooo`;o000000?oooooo`000?l000001Oooool2o`0000;ooooo0_l0000=oooo
o`?o00000oooool2o`0001Sooooo0ol0000;ooooo`;o00005_ooool2o`0000?ooooo0ol0000moooo
o`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000
ooooooooool09Oooool2o`0000[ooooo0_l000000ooooooo0000o`000005ooooo`;o00001_ooool2
o`0000oooooo0_l00005ooooo`;o00000oooool2o`0000cooooo0_l0000?ooooo`;o00002_ooool=
o`0000Oooooo1?l000000ooooooo0000o`00000<ooooo`;o00001_ooool2o`0000Sooooo0_l0000I
ooooo`Co00002Oooool2o`0000Wooooo0_l00007ooooo`;o0000Aoooool00006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo02Gooooo0_l0
000:ooooo`;o000000?oooooo`000?l000002oooool4o`0000oooooo0_l0000Hooooo`;o00001ooo
ool2o`0000Kooooo0_l00009ooooo`Go00000oooool2o`0000Gooooo0_l00004ooooo`;o00000ooo
ool2o`0000Cooooo0_l00006ooooo`;o00001_ooool2o`0000Sooooo0_l0000Kooooo`;o00002Ooo
ool4o`0000Oooooo0_l00007ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0@Oooool2
o`00017ooooo0_l0000Qooooo`;o00004Oooool2o`0000gooooo0_l0000?ooooo`;o00003Oooool2
o`0000Sooooo0ol0000:ooooo`;o00003?ooool2o`0000_ooooo0_l000000ooooooo0000o`00001I
ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o0000<oooool2o`0000Gooooo0_l00006oooo
o`;o00004?ooool2o`0001[ooooo0_l00005ooooo`;o00002?ooool2o`0000Oooooo1_l00008oooo
o`;o00000_ooool2o`0000_ooooo0_l00009ooooo`;o00002Oooool2o`0004Kooooo000Looooo`03
o`000?oooooooooo043ooooo0_l0000cooooo`;o00001Oooool2o`0000Kooooo1_l00005ooooo`;o
00001Oooool2o`0000Oooooo0_l00002ooooo`Ko00001_ooool2o`000004ooooool0003o0000oooo
o`;o00001Oooool2o`0000?ooooo0ol00008ooooo`Co000000?oooooo`000?l000001oooool2o`00
01Cooooo0_l00004ooooo`;o00001?ooool2o`0000?ooooo0_l00016ooooo`007?ooool00ol0003o
ooooooooo`0]ooooo`;o00006oooool2o`0000cooooo1?l0000Dooooo`;o00004Oooool2o`000003
ooooool0003o000000;o00001Oooool2o`0000kooooo0_l00002ooooo`Ko00001Oooool3o`0000Co
oooo1?l00003ooooo`;o00000oooool3o`0000gooooo0_l000000ooooooo0000o`000004ooooo`?o
00004oooool2o`0000[ooooo0_l00002ooooo`?o00000_ooool2o`0001Gooooo0_l0000[ooooo`00
7?ooool00ol0003oooooooooo`0Uooooo`;o00001_ooool2o`0001_ooooo0_l0000<ooooo`Co0000
5?ooool3o`0000;ooooo0_l0000<ooooo`?o00001?ooool2o`00013ooooo0_l0000:ooooo`;o0000
1?ooool2o`0000Oooooo0_l0000:ooooo`;o00001?ooool2o`0000Wooooo0_l00004ooooo`?o0000
4oooool2o`0000cooooo1?l00003ooooo`;o00005Oooool2o`0002_ooooo000Looooo`03o`000?oo
oooooooo02Gooooo0_l0000=ooooo`;o00009?ooool2o`0000Wooooo0_l0000:ooooo`;o00000_oo
ool2o`0000gooooo0_l00004ooooo`;o00003?ooool2o`0000;ooooo0_l0000:ooooo`;o00001ooo
ool2o`00013ooooo0_l000001?oooooo0000o`000?ooool2o`0000Kooooo0_l000000ooooooo0000
o`000004o`000003ooooool0003o000000kooooo0_l0000Aooooo`Co00006_ooool2o`0002_ooooo
000Looooo`03o`000?oooooooooo03Cooooo0_l0000Jooooo`;o00004oooool2o`0002cooooo0ol0
0002ooooo`Co00002_ooool2o`0000Wooooo0_l0000Cooooo`;o00001oooool4o`0000?ooooo1ol0
000>ooooo`;o00002_ooool2o`00013ooooo0_l0000Aooooo`;o0000:oooool001cooooo00?o0000
ooooooooool0=?ooool2o`0001[ooooo0_l0000Cooooo`;o00003_ooool2o`00013ooooo0_l00008
ooooo`Oo00000_ooool2o`0000[ooooo0_l0000=ooooo`Co00003?ooool2o`000003ooooool0003o
000000Gooooo0ol00006ooooo`Ko00002_ooool2o`000003ooooool0003o000000;o00002?ooool2
o`0000oooooo0ol0000nooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o00008_ooool2o`00
00gooooo0_l000000ooooooo0000o`000004ooooo`;o000000Goooooo`000?l0003o0000ooooo`04
o`0000Gooooo0_l0000Fooooo`Co00003?ooool2o`000004ooooool0003o0000ooooo`;o00001?oo
ool2o`0000Sooooo0ol00003ooooo`;o00001?ooool3o`0000?ooooo0_l0000Booooo`;o00001Ooo
ool5o`0000oooooo0_l0000[ooooo`007?ooool00ol0003oooooooooo`0dooooo`;o00003?ooool2
o`0000Kooooo0_l00005ooooo`;o00005Oooool2o`0001[ooooo0_l00007ooooo`;o000000?ooooo
o`000?l000000_ooool4o`0000Gooooo0_l0000Booooo`?o000000?oooooo`000?l000001Oooool2
o`0000gooooo0_l00004ooooo`;o00002?ooool2o`0000Cooooo1?l00002ooooo`;o00001oooool2
o`0000oooooo0_l00006ooooo`Co000000?oooooo`000?l000000_l0000:ooooo`;o0000:oooool0
01cooooo00?o0000ooooooooool0<?ooool2o`000004ooooool0003o0000o`0000cooooo0_l00006
ooooo`;o00007?ooool4o`0002Sooooo0_l000000ooooooo0000o`00000:ooooo`;o00002?ooool2
o`0000;ooooo1Ol00006ooooo`;o00008_ooool2o`000003ooooool0003o000000Cooooo0ol00004
ooooo`;o00003Oooool2o`0000?ooooo0_l000000ooooooo0000o`000005ooooo`Co0000=oooool0
01cooooo0_l0000aooooo`;o000000?oooooo`000?l000004oooool2o`00023ooooo1?l0000Yoooo
o`;o00001oooool2o`000003ooooool0003o000000Sooooo0_l00005ooooo`;o00000_ooool2o`00
01Cooooo0_l0000@ooooo`;o000000?oooooo`000?l000000_l00002ooooo`?o00000_ooool2o`00
0003ooooool0003o000000Wooooo0_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`00
0?l00000@?ooool001cooooo00?o0000ooooooooool0<_ooool2o`0001Cooooo0_l0000Rooooo`;o
00004?ooool2o`00023ooooo0_l0000Fooooo`Go00003_ooool2o`000003ooooool0003o000000;o
oooo0_l00006ooooo`;o00001?ooool2o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`;o
000000?oooooo`000?l000001?ooool2o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`;o
00001Oooool2o`0003cooooo000Looooo`03o`000?oooooooooo03;ooooo0_l0000Zooooo`Co0000
3Oooool2o`0000Cooooo0_l00007ooooo`;o00007?ooool2o`0000;ooooo0_l00009ooooo`;o0000
1oooool2o`000003ooooool0003o000000Go00001oooool2o`0000Cooooo0_l00005ooooo`;o0000
1_ooool2o`0000Cooooo0_l00004ooooo`Co00000oooool2o`0000?ooooo0_l00003ooooo`;o0000
1_ooool2o`0000Wooooo0ol0000looooo`007?ooool00ol0003oooooooooo`0`ooooo`;o0000;?oo
ool4o`0000gooooo0_l00004ooooo`;o00004Oooool2o`0001;ooooo0_l0000=ooooo`;o00000_oo
ool2o`0000?ooooo0_l000000ooooooo0000o`000006o`0000Kooooo0ol0000Cooooo`;o00001ooo
ool4o`0000Gooooo0_l00003ooooo`;o00005_ooool2o`0003gooooo000Looooo`03o`000?oooooo
oooo02[ooooo0_l00004ooooo`;o0000@oooool2o`0000_ooooo0_l00004ooooo`;o00009Oooool3
o`0000Sooooo1Ol00007ooooo`;o000000Coooooo`000?l0003ooooo0_l00006ooooo`?o00001?oo
ool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000gooooo0_l0000:ooooo`;o00003Ooo
ool2o`0003Wooooo000Looooo`03o`000?oooooooooo02[ooooo0_l00011ooooo`Co00000_ooool4
o`0000_ooooo0_l0000/ooooo`;o00003oooool5o`0000?ooooo0_l000000ooooooo0000o`000003
o`0000;ooooo1?l00008ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o00001_ooool3
o`0000[ooooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo1?l0000iooooo`007?ooool00ol0
003oooooooooo`0aooooo`;o00006oooool2o`0000;ooooo0_l00004ooooo`;o00004oooool4o`00
00;ooooo0_l0000Aooooo`;o00002Oooool2o`0000gooooo0_l00006ooooo`Co00001Oooool2o`00
00kooooo1Ol00002ooooo`;o00000oooool4o`0000;ooooo0_l00003ooooo`;o00004?ooool2o`00
00;ooooo0_l00002ooooo`;o00002oooool2o`0000;ooooo0_l00002ooooo`;o00000oooool3o`00
03[ooooo000Looooo`03o`000?oooooooooo037ooooo0_l0000Kooooo`;o00000_ooool2o`0000;o
oooo1Ol00009ooooo`;o00003Oooool2o`00017ooooo0_l00009ooooo`;o00001?ooool2o`0000Oo
oooo0_l00006ooooo`Co00001Oooool2o`0000Wooooo0_l00002ooooo`?o00001Oooool2o`0000So
oooo0ol00003ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`00000<ooooo`;o
00003Oooool2o`0000Gooooo0_l00007ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0
;?ooool2o`00027ooooo0_l00002ooooo`_o000000?oooooo`000?l000000oooool2o`0001;ooooo
0_l0000=ooooo`;o00000oooool3o`0000Cooooo0_l00002ooooo`;o00000_ooool2o`0001Cooooo
0_l00008ooooo`?o00000_ooool3o`0000Gooooo0_l00008ooooo`?o00001_ooool4o`000003oooo
ool0003o000001?ooooo0_l00006ooooo`;o00001?ooool3o`0004?ooooo000Looooo`03o`000?oo
oooooooo02cooooo0_l0000Qooooo`Oo000000?oooooo`000?l000002Ol00006ooooo`;o00001_oo
ool2o`0000Kooooo0_l0000=ooooo`;o00000oooool3o`0000?ooooo0ol00006ooooo`;o00000_oo
ool2o`00013ooooo0_l00006ooooo`Co00000_ooool4o`0000;ooooo0_l0000Aooooo`Co00001ooo
ool3o`000003ooooool0003o000000Gooooo0_l00003ooooo`Co00003?ooool2o`0004Cooooo000L
ooooo`03o`000?oooooooooo04oooooo5?l00005ooooo`;o00001_ooool2o`0000Wooooo0_l00000
0ooooooo0000o`00000Booooo`;o00001oooool2o`0000;ooooo0_l00008ooooo`;o00002oooool6
o`0000?ooooo1?l00002ooooo`Co00003oooool4o`0000Oooooo0ol000000ooooooo0000o`000005
ooooo`;o00000oooool2o`0000Wooooo0_l000000ooooooo0000o`000002ooooo`;o00002?ooool2
o`0003Sooooo000Looooo`03o`000?oooooooooo02_ooooo0_l0000Kooooo`Co00000ooooolEo`00
01Cooooo0_l000000ooooooo0000o`000003o`000004ooooool0003o0000o`0000gooooo0_l00008
ooooo`;o00002oooool3o`0000[ooooo1ol00004ooooo`Co00000oooool2o`0000oooooo0_l0000=
ooooo`;o00001?ooool2o`0000oooooo1Ol00002ooooo`;o00001Oooool2o`000003ooooool0003o
000003Sooooo000Looooo`03o`000?oooooooooo02_ooooo0_l0000<ooooo`;o00003Oooool4o`00
00;ooooo5_l0000Dooooo`Ko000000?oooooo`000?l000000ol0000=ooooo`;o00005?ooool4o`00
00[ooooo0_l000000ooooooo0000o`000006ooooo`Co00000_ooool2o`00013ooooo0_l0000=oooo
o`;o00001?ooool2o`0000Kooooo0_l00008ooooo`;o00002oooool2o`0003_ooooo000Looooo`03
o`000?oooooooooo03Wooooo0_l0000<ooooo`;o00001?oooolEo`0000Cooooo0_l0000Booooo`Co
000000Coooooo`000?l0003o00008oooool6o`0000Sooooo0_l00003ooooo`;o00001oooool2o`00
00?ooooo1?l0000>ooooo`;o00004?ooool2o`000003ooooool0003o000000Kooooo0_l00003oooo
o`Co0000Boooool001cooooo00?o0000ooooooooool07_ooool2o`0002Oooooo0_l00004oooooaGo
000000Coooooo`000?l0003ooooo0_l00007ooooo`;o00002_ooool5o`0000kooooo0_l00002oooo
o`;o00000_ooool2o`0000Cooooo0_l00007ooooo`;o00000oooool2o`0000?ooooo1_l00005oooo
o`;o00001?ooool3o`0000Cooooo0ol0000@ooooo`;o00003_ooool2o`000003ooooool0003o0000
00_ooooo1?l0000:ooooo`;o00001Oooool2o`0003Sooooo000Looooo`03o`000?oooooooooo01ko
oooo0_l0000Wooooo`;o00001?oooolHo`0000Wooooo0ol0000<ooooo`?o00003_ooool6o`0000;o
oooo0_l00004ooooo`;o00003?ooool2o`0000?ooooo1?l000000ooooooo0000o`000004ooooo`Co
00000_ooool3o`000004ooooool0003o0000ooooo`?o00001oooool2o`0000Oooooo0_l0000>oooo
o`;o00007?ooool2o`0000Gooooo0_l0000hooooo`007?ooool2o`0003Kooooo0_l0000Booooo`;o
000000?oooooo`000?l000002?l000000ooooooo0000o`00000=o`0000;ooooo0_l00004ooooo`Co
00001Oooool2o`0000Cooooo0_l0000Aooooo`;o00004oooool2o`0000Gooooo0_l00006ooooo`;o
00001_ooool2o`0000;ooooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o
000000?oooooo`000?l000001?ooool2o`000004ooooool0003o0000o`0000Sooooo0_l0000;oooo
o`;o00002_ooool2o`0000_ooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`0eooooo`;o
00004_ooool2o`000003ooooool0003o000000Ko00000_ooool@o`0000;ooooo0_l00005ooooo`?o
00001Oooool2o`0000Kooooo0_l0000;ooooo`;o00005oooool2o`0000Gooooo0_l0000Booooo`;o
00000oooool2o`0000;ooooo0_l00002ooooo`;o00001?ooool4o`0000Kooooo0ol00008ooooo`;o
000000?oooooo`000?l000002?ooool2o`0000[ooooo1?l00009ooooo`;o00003oooool2o`0002So
oooo000Looooo`03o`000?oooooooooo02Gooooo0_l0000Qooooo`;o000000?oooooo`000?l00000
6Ol00009ooooo`;o00001Oooool2o`0000;ooooo0_l00003ooooo`;o00002oooool2o`0000Sooooo
0_l0000?ooooo`;o00000_ooool4o`00017ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo
0_l000000ooooooo0000o`000005o`000003ooooool0003o0000013ooooo0_l0000:ooooo`;o0000
2_ooool2o`0000Gooooo0_l0000Cooooo`;o0000:?ooool001cooooo00?o0000ooooooooool09Ooo
ool2o`0001gooooo0_l00002oooooaco00004_ooool2o`0000;ooooo0_l0000Jooooo`;o00000ooo
ool2o`0000[ooooo0_l00002ooooo`Co00004Oooool2o`0000cooooo0_l000000ooooooo0000o`00
0003ooooo`Go00007?ooool2o`00017ooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0a
ooooo`;o00004Oooool2o`0000Cooooo6ol0000Aooooo`;o00000oooool2o`000003ooooool0003o
000001_ooooo0_l0000Aooooo`;o00001oooool2o`0000?ooooo1Ol00002ooooo`;o00000oooool2
o`0000_ooooo1_l00003ooooo`;o00003_ooool2o`0000;ooooo0_l0000;ooooo`;o0000B?ooool0
01cooooo00?o0000ooooooooool09Oooool2o`0000[ooooo0_l0000Goooooa;o000000?oooooo`00
0?l000001_l000000ooooooo0000o`00000=ooooo`?o00000oooool2o`000003ooooool0003o0000
00cooooo0ol0000Dooooo`;o00002Oooool2o`0000Gooooo1_l000000ooooooo0000o`000003o`00
00;ooooo0_l00003ooooo`?o00000oooool2o`000003ooooool0003o000000So000000?oooooo`00
0?l000001Ol00005ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00002Oooool4
o`0004Sooooo000Looooo`03o`000?oooooooooo02Gooooo0_l00003ooooo`;o00006_ooool2o`00
00Gooooo4_l000001?oooooo0000o`000?l00003ooooo`;o00003Oooool2o`0000;ooooo0_l0000A
ooooo`?o00005?ooool2o`00013ooooo0_l00002ooooo`;o00000oooool2o`0000?ooooo0_l00004
ooooo`oo000000Coooooo`000?l0003ooooo1ol00005ooooo`;o000000?oooooo`000?l000001Ooo
ool2o`0000Wooooo0_l0000Booooo`;o0000=_ooool001cooooo00?o0000ooooooooool08oooool2
o`000003ooooool0003o000000;ooooo0_l0000;ooooo`;o00003Oooool2o`0000Gooooo5_l00007
ooooo`;o000000?oooooo`000?l000002_ooool2o`0000oooooo0_l0000>ooooo`Co00002_ooool2
o`0000Oooooo0_l0000Cooooo`;o000000?oooooo`000?l000005?l000000ooooooo0000o`000004
o`0000cooooo1?l00003ooooo`;o00000_ooool2o`0000Oooooo1?l00007ooooo`;o00002oooool2
o`0002Wooooo000Looooo`03o`000?oooooooooo02?ooooo0_l000000ooooooo0000o`00000?oooo
o`;o00001?ooool3o`0000Gooooo1?l00005oooooaGo00001_ooool6o`0000oooooo1?l00006oooo
o`Co00001_ooool2o`0000;ooooo0_l00002ooooo`Ko00000_ooool3o`0000?ooooo0_l00007oooo
o`;o00004ooooolHo`0000;ooooo1_l00009ooooo`;o00000oooool2o`0000?ooooo0_l0000;oooo
o`Ko00001Oooool2o`0000_ooooo0_l0000Yooooo`007?ooool00ol0003oooooooooo`0mooooo`?o
00000_ooool2o`000003ooooool0003o000000Co00000ooooolEo`0000Kooooo0_l000000ooooooo
0000o`000003o`0000gooooo1?l00006ooooo`Co00001?ooool4o`000004ooooool0003o0000o`00
00Kooooo0_l00002ooooo`?o00004?ooool2o`000003ooooool0003o000000_ooooo5Ol000001?oo
oooo0000o`000?ooool3o`0000Wooooo0_l00003ooooo`;o00002_ooool2o`0000gooooo0_l0000E
ooooo`;o00009_ooool001cooooo00?o0000ooooooooool0;Oooool2o`0000cooooo0_l00005oooo
o`;o00001?ooool5o`000003ooooool0003o000000_o000000Coooooo`000?l0003ooooo1?l0000:
ooooo`Co00002_ooool2o`0000Gooooo0_l00006ooooo`;o00000oooool3o`0000?ooooo0_l00004
ooooo`;o00001?ooool2o`0000gooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2
o`0000Cooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00000_ooool@o`000004ooooool0
003o0000o`0000Wooooo0_l0000?ooooo`;o00002Oooool2o`0000?ooooo0_l0000Dooooo`;o0000
9_ooool001cooooo00?o0000ooooooooool0;Oooool2o`0000cooooo0_l00002ooooo`Co00002?oo
ool2o`000003ooooool0003o000000;o00001?ooool2o`0000?ooooo0_l00004ooooo`;o00002Ooo
ool2o`0000gooooo0_l00005ooooo`;o00002oooool2o`0000Gooooo1?l000000ooooooo0000o`00
0004ooooo`;o00003Oooool2o`0000[ooooo0_l00004ooooo`;o00001Oooool2o`000003ooooool0
003o000000go00001?ooool2o`00017ooooo0_l0000?ooooo`;o000000?oooooo`000?l000000ooo
ool2o`0003cooooo000Looooo`03o`000?oooooooooo02_ooooo0_l0000Booooo`Ko00001_ooool2
o`0000Wooooo0_l00003ooooo`;o000000?oooooo`000?l000001Oooool2o`0000?ooooo1?l0000>
ooooo`;o00001?ooool2o`0000Cooooo0_l00003ooooo`;o00001Oooool6o`0000kooooo0ol00008
ooooo`;o00002oooool2o`0000;ooooo7Ol00006ooooo`Co00001oooool2o`0000Oooooo0_l00006
ooooo`;o00002_ooool2o`0003Sooooo000Looooo`03o`000?oooooooooo02_ooooo0_l0000Foooo
o`?o00001Oooool2o`0000?ooooo0_l00004ooooo`;o00001_ooool2o`0000?ooooo1?l00003oooo
o`;o00002oooool2o`0000;ooooo1Ol00005ooooo`;o000000?oooooo`000?l000000oooool2o`00
00Cooooo1_l000001?oooooo0000o`000?l00003ooooo`;o00001_ooool3o`0000Sooooo1?l00009
ooooo`;o00000_ooool5o`000003ooooool0003o000001[o000000?oooooo`000?l000000_l0000<
ooooo`;o00000_ooool2o`0000Gooooo0_l00003ooooo`;o00001_ooool2o`0000_ooooo0ol0000Z
ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00002_ooool2o`00017ooooo0ol00007oooo
o`;o00002?ooool2o`0000;ooooo0_l000001?oooooo0000o`000?l00004ooooo`;o00000oooool4
o`000003ooooool0003o000000;ooooo0_l000001Ooooooo0000o`000?l0003ooooo00?o00000ooo
ool2o`00013ooooo0_l000000ooooooo0000o`00000:ooooo`;o00000ooooolPo`0000kooooo0_l0
00000ooooooo0000o`000009ooooo`;o00000oooool2o`000003ooooool0003o000000[ooooo0_l0
0004ooooo`?o0000:_ooool001cooooo00?o0000ooooooooool0=Oooool2o`0002cooooo0_l00000
0ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000_l00006ooooo`;o00001_ooool2
o`0000Wooooo1?l000000ooooooo0000o`000003ooooo`Ko000000Coooooo`000?l0003ooooo0_l0
0002ooooo`Co000000?oooooo`000?l000001?ooool2o`0000?ooooo0_l00003ooooo`;o00001ooo
oolJo`000003ooooool0003o000000Go00004_ooool2o`0000;ooooo0_l00003ooooo`;o00002ooo
ool2o`0000[ooooo0_l0000aooooo`007?ooool2o`0003Kooooo0_l0000Wooooo`;o00001_ooool2
o`0000;ooooo0_l00003ooooo`;o00001_ooool2o`0000Oooooo0_l00006ooooo`Co00000oooool>
o`000003ooooool0003o000000;ooooo2?l00003ooooo`;o00002?ooool2o`0000Oooooo0_l00000
0ooooooo0000o`00000Mo`00017ooooo0_l00003ooooo`;o00000oooool2o`0001_ooooo0_l0000]
ooooo`007?ooool00ol0003oooooooooo`0jooooo`;o00003?ooool2o`000003ooooool0003o0000
00cooooo1ol00008ooooo`;o00003_ooool2o`0000;ooooo0_l00002ooooo`Ko00000_ooool3o`00
0003ooooool0003o000000?ooooo1_l000000ooooooo0000o`000006o`000003ooooool0003o0000
00;ooooo0_l000000ooooooo0000o`000003o`0000;ooooo1?l00007ooooo`?o000000?oooooo`00
0?l000009ol0000<ooooo`;o000000?oooooo`000?l000004Oooool4o`0000gooooo0_l0000]oooo
o`007?ooool00ol0003oooooooooo`0Looooo`;o00007?ooool2o`0000[ooooo1?l000000ooooooo
0000o`000003ooooo`;o000000?oooooo`000?l000001?ooool5o`0000[ooooo0_l0000>ooooo`;o
00000_ooool5o`000003ooooool0003o000000;o000000?oooooo`000?l000000_l000000ooooooo
0000o`000002o`0000;ooooo1Ol000000ooooooo0000o`000009o`0000Oooooo0ol00002ooooo`Co
00001oooool3o`000003ooooool0003o000000;ooooo6?l000000ooooooo0000o`00000;o`0000ko
oooo0_l0000Aooooo`Co0000??ooool001cooooo00?o0000ooooooooool07?ooool2o`0002Cooooo
0_l00002ooooo`So000000Goooooo`000?l0003o0000ooooo`04o`0002Gooooo1Ol00003ooooo`Go
00000oooool5o`000003ooooool0003o000000oo00000oooool2o`0000?ooooo0ol000000ooooooo
0000o`000002o`0000Gooooo0_l00006oooooaCo00000_ooool4o`000003ooooool0003o000000Oo
000000Coooooo`000?l0003o00001Oooool2o`0000Gooooo0_l0000Booooo`;o0000?oooool001co
oooo00?o0000ooooooooool0>oooool4o`0000?ooooo0_l00003ooooo`Oo000000Coooooo`000?l0
003o00000_ooool3o`0000Gooooo0_l00002ooooo`;o00001?ooool2o`0000_ooooo0_l000000ooo
oooo0000o`000004ooooo`?o00001oooool3o`0000;ooooo1_l000000ooooooo0000o`000006o`00
00;ooooo0ol000001?oooooo0000o`000?l00003ooooo`Wo000000Coooooo`000?l0003o00001Ooo
ool2o`0000Kooooo7ol000000ooooooo0000o`000002o`000003ooooool0003o000000Kooooo0_l0
0005ooooo`;o00000_ooool3o`0000Cooooo0_l00007ooooo`;o0000?oooool001cooooo00?o0000
ooooooooool0>?ooool2o`000003ooooool0003o000000;o00002?ooool2o`0000?ooooo0_l0000>
ooooo`Ko00001?ooool2o`000003ooooool0003o000000;o00001_ooool2o`000003ooooool0003o
000000Sooooo0_l00009ooooo`Ko000000?oooooo`000?l000003_l00006ooooo`Oo00001?ooool2
o`0000?ooooo0_l00006ooooo`Go00000ooooolMo`0000Gooooo1?l0000:ooooo`?o00001?ooool3
o`0000?ooooo1?l0000Cooooo`;o0000:oooool001cooooo00?o0000ooooooooool0<oooool2o`00
00?ooooo0ol0000Jooooo`;o00001oooool2o`0000?ooooo0_l00002ooooo`Ko00003oooool2o`00
00;ooooo0_l0000:oooooaCo00000_ooool3o`000003ooooool0003o000000;ooooo1Ol000001?oo
oooo0000o`000?ooool2o`0000_ooooo1Ol000000ooooooo0000o`00000Mo`0000Gooooo1?l0000B
ooooo`;o00000oooool7o`0000cooooo0_l00002ooooo`;o0000:oooool001cooooo00?o0000oooo
ooooool0<oooool2o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`;o00002_ooool2o`00
00?ooooo0_l000000ooooooo0000o`000004ooooo`;o00001_ooool7o`00017ooooo0ol00005oooo
o`;o000000?oooooo`000?l000000_l00002oooooaWo000000?oooooo`000?l000001ol000001?oo
oooo0000o`000?ooool2o`0000Cooooo0_l00006ooooob3o000000Coooooo`000?l0003ooooo0_l0
0006ooooo`;o00000oooool2o`0001?ooooo1ol0000:ooooo`;o0000;oooool001cooooo00?o0000
ooooooooool0=_ooool2o`0000?ooooo0ol00003ooooo`Ko00001_ooool2o`0000?ooooo0_l00002
ooooo`;o00000oooool2o`0000Kooooo1_l0000<ooooo`;o00000oooool5o`0000Cooooo0_l00000
0ooooooo0000o`000002o`0000;ooooo4?l000000ooooooo0000o`000004o`0000;ooooo2?l00000
0ooooooo0000o`000002o`000003ooooool0003o000000Cooooo0_l00009ooooo`;o000000?ooooo
o`000?l000005Ol00002ooooo`Oo00001_ooool2o`0000?ooooo0_l00004ooooo`?o00003?ooool3
o`0000;ooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00000oooool2o`00
00Kooooo1?l00002ooooo`;o00002_ooool3o`0000Kooooo0_l00003ooooo`?o00002oooool2o`00
00;ooooo0ol00002ooooo`Go000000Coooooo`000?l0003o00000oooool2o`000003ooooool0003o
000001Wo000000?oooooo`000?l000000_l00005ooooo`;o000000?oooooo`000?l000005?oooolP
o`00017ooooo0ol0000=ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0>oooool2o`00
00Oooooo0_l00002ooooo`?o00002_ooool2o`0000Oooooo0_l0000Aooooo`Co000000?oooooo`00
0?l000001Oooool6o`0000Gooooo8Ol000000ooooooo0000o`000005ooooo`;o00002_ooool2o`00
00Oooooo6ol00003ooooo`;o00001?ooool2o`0001Kooooo0_l00002ooooo`Co0000?oooool001co
oooo00?o0000ooooooooool0>oooool2o`0000Kooooo0ol00002ooooo`?o00003?ooool2o`0001[o
oooo0_l00002ooooo`;o00000oooool5o`000003ooooool0003o000002So00001Oooool2o`0000[o
oooo0_l00007oooooaco00000_ooool2o`0000Cooooo0_l0000Dooooo`Co00000_ooool4o`0003oo
oooo000Looooo`03o`000?oooooooooo04?ooooo0_l000001?oooooo0000o`000?ooool2o`0000co
oooo0_l0000Jooooo`;o00000_ooool2o`0000?ooooo0_l00004ooooob[o00001Oooool2o`0000Co
oooo0_l00005ooooo`;o00001ooooolKo`000003ooooool0003o000000;o00005?ooool2o`0000?o
oooo0_l00006ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0=?ooool2o`0000Gooooo
0_l00009ooooo`;o00004Oooool2o`00017ooooo1?l000000ooooooo0000o`000009ooooo`;o0000
1?ooool2o`000003ooooool0003o000001ko00000_ooool2o`000003ooooool0003o000000Gooooo
0_l00004ooooo`;o00001Oooool2o`000003ooooool0003o000000Cooooo0ol00002oooooa3o0000
0_ooool4o`000003ooooool0003o000000;o00005?ooool4o`0000Cooooo0_l00003ooooo`;o0000
?oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0
003o410@olc<c006ooooo`03o`000?oooooooooo03Cooooo0_l00005ooooo`;o00004_ooool2o`00
00Sooooo0_l0000Aooooo`Co000000?oooooo`000?l000002Oooool5o`0000Cooooo9?l000000ooo
oooo0000o`000003ooooo`;o00001?ooool2o`0000[ooooo0_l00004ooooo`?o00000oooool?o`00
00;ooooo1?l0000Jooooo`?o00001?ooool2o`0001Kooooo0_l0000/ooooo`0000KoooooogMgMonH
V9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o
0000ooooooooool0>?ooool2o`0000Cooooo0_l00006ooooo`;o00000oooool2o`0000;ooooo0_l0
000:ooooo`;o00000_ooool2o`0000cooooo0_l0000;ooooo`;o00000_ooool5o`000003ooooool0
003o000001?o00000_ooool@o`0000Cooooo0_l00002ooooo`Co00001_ooool2o`0000?ooooo0_l0
0003ooooo`Co00000_ooool2o`000003ooooool0003o000000So00004Oooool2o`0002kooooo0_l0
000/ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`0hooooo`;o00001?ooool2o`0000Cooooo1_l0
00000ooooooo0000o`000008ooooo`;o00001?ooool2o`0000;ooooo0_l0000<ooooo`;o00002ooo
ool4o`000003ooooool0003o000002Oo000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l0
0002ooooo`Go000000?oooooo`000?l000000oooool2o`0000Cooooo2?l00002ooooo`?o000000?o
ooooo`000?l000000_l000000ooooooo0000o`000003ooooo`;o00002Oooool2o`0005cooooo0000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oiRHV?ooooooV9RHob4Q
8@06ooooo`?o0000>?ooool2o`0000Gooooo0_l00003ooooo`Oo00001?ooool2o`0000;ooooo1?l0
0006ooooo`;o00005?ooool2o`0000Gooooo;_l000000ooooooo0000o`000005o`0000;ooooo0_l0
0003ooooo`Go00001_ooool2o`0000Gooooo1ol00002ooooo`?o00001_ooool2o`0000?ooooo0_l0
000=ooooo`;o00003Oooool2o`0004Wooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo03Sooooo0_l0
0005ooooo`;o00000oooool4o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o000000?o
ooooo`000?l000001Oooool2o`0000gooooo0_l00002ooooo`;o000000?oooooo`000?l000001?oo
ool^o`0000;ooooo1?l000000ooooooo0000o`000002ooooo`;o00005Oooool6o`0000?ooooo0ol0
0006ooooo`;o00004_ooool2o`0000gooooo0_l00019ooooo`0000?ooooooa0@4?ooool00_ooool0
0ol@413oooooooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0?_ooool2
o`0000Kooooo0_l0000>ooooo`;o00001?ooool7o`0000Wooooo0_l00002ooooo`Co00001Oooool4
o`000004ooooool0003o0000ooooob7o000000?oooooo`000?l000000_l000000ooooooo0000o`00
0002o`0000Wooooo0_l0000?ooooo`Co00000oooool2o`0001Cooooo0_l00009ooooo`;o00004ooo
ool2o`0001Gooooo0_l0000]ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgM
gOl@413oV9RH00Sooooo00?o0000ooooooooool0?_ooool2o`0000?ooooo0_l0000Gooooo`Oo0000
0_ooool2o`0000_ooooo0_l00002ooooo`;o00000oooool6o`000003ooooool0003o000000oo0000
00?oooooo`000?l000004Ol000000ooooooo0000o`000002o`0000Sooooo0ol0000?ooooo`Co0000
6Oooool2o`0000Cooooo0_l00003ooooo`?o00002_ooool6o`0000;ooooo0_l0000Eooooo`;o0000
;Oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106oooo
o`03o`000?oooooooooo03Cooooo0_l0000=ooooo`;o00001?ooool2o`0000?ooooo0ol00002oooo
o`;o00002oooool2o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000002?ooool3o`00
00?ooooo1Ol000000ooooooo0000o`00000So`0000?ooooo0_l000000ooooooo0000o`000005oooo
o`;o00007_ooool2o`0000;ooooo0_l0000<ooooo`;o000000?oooooo`000?l000001?ooool4o`00
00Sooooo1_l00004ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0=?ooool2o`0001;o
oooo0ol00003ooooo`?o00000_ooool2o`0000;ooooo0_l00005ooooo`Co00000oooool2o`0000;o
oooo0_l000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l000000oooool3o`0000?o
oooo9?l00007ooooo`;o00001Oooool2o`0001Wooooo0_l00003ooooo`;o00000_ooool2o`0000Wo
oooo0_l000000ooooooo0000o`000007ooooo`Go00004Oooool4o`00043ooooo000Looooo`03o`00
0?oooooooooo03Wooooo1?l0000:ooooo`Co00003?ooool2o`0000Gooooo0ol00004ooooo`;o0000
3Oooool3o`0000[ooooo9Ol000001?oooooo0000o`000?l0000:ooooo`;o00005?ooool2o`0000?o
oooo0_l0000Booooo`;o00003Oooool3o`0000Cooooo0_l0000<ooooo`;o0000@?ooool001cooooo
00?o0000ooooooooool0>Oooool4o`0000[ooooo0_l0000:ooooo`;o00004Oooool2o`0000gooooo
0_l00007ooooo`Ko00000_ooool4o`000004ooooool0003o0000oooooaOo00000_ooool8o`0000co
oooo1?l00002ooooo`;o00000_ooool2o`0000?ooooo0_l0000Eooooo`;o000000?oooooo`000?l0
00001_ooool2o`0000Gooooo0_l00004ooooo`;o00002?ooool2o`0004Cooooo000Looooo`03o`00
0?oooooooooo05?ooooo0_l0000@ooooo`?o00001oooool2o`0000?ooooo0ol000000ooooooo0000
o`000004oooooc7o00003?ooool4o`000003ooooool0003o000000;o000000?oooooo`000?l00000
0oooool2o`0000Gooooo0_l0000>ooooo`;o000000?oooooo`000?l000001_ooool2o`0001Gooooo
0ol00013ooooo`007?ooool00ol0003oooooooooo`0kooooo`?o00002?ooool4o`0000Oooooo1?l0
0005ooooo`;o00002Oooool2o`0000Sooooo0_l00003ooooo`?o000000?oooooo`000?l000000ol0
00000ooooooo0000o`00000Xo`0000?ooooo0_l0000:ooooo`;o00000_ooool2o`0000?ooooo1ol0
0003ooooo`;o00001Oooool2o`0000_ooooo0_l0000Jooooo`?o00001oooool2o`0004?ooooo000L
ooooo`03o`000?oooooooooo03_ooooo0ol00008ooooo`Co00001oooool4o`0000Gooooo0ol00009
ooooo`Co00002_ooool2o`000003ooooool0003o000000Co000000Coooooo`000?l0003ooooo:_l0
0004ooooo`;o00001_ooool2o`0000;ooooo0_l00002ooooo`;o00000oooool3o`0000Kooooo0_l0
0004ooooo`;o00002Oooool2o`000003ooooool0003o000001Oooooo0ol00006ooooo`;o0000A?oo
ool001cooooo00?o0000ooooooooool0Foooool2o`0000Oooooo1_l0000:ooooo`;o000000?ooooo
o`000?l000001Oooool]o`0000Cooooo0_l0000<ooooo`Co00000_ooool2o`0000Gooooo0_l00000
0ooooooo0000o`000004ooooo`;o00003?ooool2o`00017ooooo0_l00005ooooo`;o00001_ooool2
o`0004Cooooo000Looooo`03o`000?oooooooooo04Gooooo1?l0000Cooooo`;o000000?oooooo`00
0?l000000oooool2o`0001Wooooo0_l000001Ooooooo0000o`000?l0003ooooo01ko000000?ooooo
o`000?l000000ol00002ooooo`;o00002_ooool2o`000003ooooool0003o000000;o00001?ooool2
o`0000Gooooo1_l0000Tooooo`;o00001Oooool2o`000003ooooool0003o000000?ooooo0_l0000A
ooooo`;o0000<Oooool001cooooo00?o0000ooooooooool0@Oooool2o`0000;ooooo1?l00002oooo
o`;o00003oooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000001?ooool2o`00
0003ooooool0003o000000gooooo0_l00002ooooo`Co00000_oooolHo`0000;ooooo1?l00002oooo
o`Co00000_ooool3o`0000Wooooo0_l000000ooooooo0000o`00000?ooooo`Co00001Oooool2o`00
0003ooooool0003o000000_ooooo0_l0000>ooooo`;o00001oooool2o`0000?ooooo0_l0000Aoooo
o`;o0000<Oooool001cooooo00?o0000ooooooooool0=Oooool2o`0000[ooooo0_l00008ooooo`;o
00001?ooool4o`0000Cooooo0_l00004ooooo`Co00001oooool2o`000003ooooool0003o000000go
oooo0_l000000ooooooo0000o`000003o`000004ooooool0003o0000oooooaKo00000_ooool3o`00
0005ooooool0003o0000o`000?ooool00_l00003ooooo`;o00001_ooool2o`0000Gooooo0_l0000G
ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Oooooo0_l00002ooooo`Co00002?ooool2
o`0000;ooooo0_l0000Looooo`;o0000<?ooool001cooooo00?o0000ooooooooool0=Oooool2o`00
01?ooooo0_l00005ooooo`Co00000oooool3o`0000Cooooo0ol00002ooooo`Co00000_ooool2o`00
013ooooo1_l00003oooooaWo000000?oooooo`000?l000000_l000001?oooooo0000o`000?l00004
ooooo`;o00000oooool2o`0000?ooooo0_l00005ooooo`;o00000oooool2o`0000Sooooo1?l00005
ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0000Oooooo0_l00002ooooo`Co00003?oo
ool2o`0001cooooo0_l0000`ooooo`007?ooool2o`0003gooooo0_l0000;ooooo`?o00001Oooool2
o`0000Gooooo0_l00006ooooo`So00000_ooool2o`0000Wooooo0ol00003ooooob?o000000?ooooo
o`000?l000001_l00004ooooo`;o000000?oooooo`000?l000000_l000001?oooooo0000o`000?oo
ool2o`0000Wooooo0_l00002ooooo`;o00001?ooool4o`0000?ooooo1?l000001?oooooo0000o`00
0?l0000;ooooo`;o00000_ooool4o`0000;ooooo0_l00007ooooo`;o00000_ooool2o`0004_ooooo
000Looooo`03o`000?oooooooooo03cooooo0_l0000;ooooo`Co00001?ooool2o`0000Kooooo0ol0
0004ooooo`Co00002Oooool2o`0000Kooooo0ol00003ooooo`;o000000?oooooo`000?l000001ol0
00000ooooooo0000o`00000Go`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o000000?o
ooooo`000?l000000oooool2o`000003ooooool0003o000000gooooo0_l00005ooooo`;o00001?oo
ool2o`0000[ooooo0_l0000;ooooo`;o00000_ooool2o`0000Kooooo0ol00002ooooo`;o0000Booo
ool001cooooo00?o0000ooooooooool0Boooool2o`0000cooooo1Ol00004ooooo`;o00000_ooool2
o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000Cooooo0_l0
0005ooooo`Ko00000_ooool8o`000003ooooool0003o000000Oo000000?oooooo`000?l000000_l0
0002ooooo`;o00000oooool2o`0000?ooooo0_l0000<ooooo`;o000000?oooooo`000?l000002Ooo
ool2o`0000?ooooo0_l00006ooooo`;o000000?oooooo`000?l000001Oooool2o`0001Oooooo0_l0
001@ooooo`007?ooool00ol0003oooooooooo`1>ooooo`?o00000oooool2o`0000Kooooo0_l00003
ooooo`;o00000oooool2o`0000;ooooo0_l00004ooooo`Ko00000oooool3o`0000?ooooo0ol00002
ooooo`;o00000_ooool>o`000004ooooool0003o0000ooooo`?o00000_ooool6o`000003ooooool0
003o000000;ooooo0_l00007ooooo`;o00001?ooool2o`000003ooooool0003o000000Kooooo0_l0
00001?oooooo0000o`000?l00002ooooo`;o00001_ooool2o`000003ooooool0003o000000Kooooo
0_l000000ooooooo0000o`00001Uooooo`007?ooool00ol0003oooooooooo`1>ooooo`?o00000_oo
ool3o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`;o00001ooo
ool4o`0000Cooooo0_l00002ooooo`Co00000_ooool9o`0000;ooooo1ol000001?oooooo0000o`00
0?ooool4o`000003ooooool0003o000000Co000000?oooooo`000?l000001?l00007ooooo`;o0000
3oooool2o`0000;ooooo0_l0000Eooooo`;o000000?oooooo`000?l00000IOooool001cooooo00?o
0000ooooooooool0<_ooool2o`0001oooooo0_l000000ooooooo0000o`000002o`0000_ooooo0ol0
00000ooooooo0000o`000007ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo3?l0
00000ooooooo0000o`000006o`0000Cooooo0ol00002ooooo`;o000000?oooooo`000?l000001ooo
ool2o`0000Oooooo0_l0000@ooooo`;o00001?ooool2o`0000Kooooo0_l0000:ooooo`;o00001?oo
ool2o`0006Cooooo000Looooo`03o`000?oooooooooo03;ooooo0_l0000Rooooo`;o00003?ooool4
o`0000Cooooo0_l00006ooooo`Co000000Coooooo`000?l0003ooooo0_l00002ooooo`Co000000?o
ooooo`000?l000000_l00002ooooo`Co00000_ooool2o`0000?ooooo1Ol000001?oooooo0000o`00
0?ooool2o`00013ooooo0_l00009ooooo`;o00001Oooool2o`0000Cooooo0_l00006ooooo`;o0000
2_ooool2o`0000Cooooo0_l000000ooooooo0000o`00000<ooooo`;o0000Doooool001cooooo00?o
0000ooooooooool0>_ooool2o`00017ooooo0ol00002ooooo`;o00000_ooool2o`000004ooooool0
003o0000o`0000Sooooo1?l00004ooooo`;o00001_ooool4o`0000Cooooo0_l00003ooooo`;o0000
0_ooool5o`000004ooooool0003o0000ooooo`;o000000Coooooo`000?l0003ooooo1ol00004oooo
o`;o00006_ooool3o`0001?ooooo0_l00005ooooo`;o00003?ooool2o`0000cooooo0_l0001Coooo
o`007?ooool00ol0003oooooooooo`0jooooo`;o00004Oooool3o`0000;ooooo0_l00002ooooo`;o
000000Goooooo`000?l0003o0000ooooo`02o`0000Oooooo0_l00003ooooo`;o00001oooool4o`00
00Oooooo0_l00002ooooo`[o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000002
o`000003ooooool0003o000000;ooooo0_l0000Aooooo`;o000000?oooooo`000?l000001_ooool3
o`0000cooooo0_l0000;ooooo`?o00000oooool3o`0000;ooooo0_l0000@ooooo`;o00000_ooool2
o`0004oooooo000Looooo`03o`000?oooooooooo04oooooo0_l00005ooooo`;o00001Oooool2o`00
00Sooooo0_l00002ooooo`;o00002Oooool2o`0000Oooooo0ol000001?oooooo0000o`000?l00003
ooooo`Co00002?ooool3o`0000Gooooo0_l00008ooooo`;o00001oooool2o`000003ooooool0003o
000000Kooooo0_l00005ooooo`;o00001_ooool2o`000003ooooool0003o000000Sooooo0_l00004
ooooo`?o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`000006ooooo`?o00000_ooool2
o`0004oooooo000Looooo`03o`000?oooooooooo04oooooo0_l00006ooooo`;o00003_ooool4o`00
00Oooooo0_l00002ooooo`;o00001_ooool7o`0000gooooo0_l00002ooooo`;o00003Oooool4o`00
00Cooooo0_l0000<ooooo`?o00001?ooool2o`0000Wooooo0ol00004ooooo`Co00000oooool2o`00
00[ooooo0ol000001?oooooo0000o`000?ooool2o`0000;ooooo0ol00003ooooo`Co0000COooool0
01cooooo00?o0000ooooooooool0Boooool2o`0000[ooooo0ol0000=ooooo`Co00001_ooool3o`00
00Kooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o00001Oooool2o`00
0003ooooool0003o000000;ooooo0_l0000<ooooo`?o00000oooool2o`000003ooooool0003o0000
00gooooo0_l0000@ooooo`?o00000oooool4o`0000?ooooo0_l00005ooooo`;o00000oooool4o`00
00?ooooo0_l00002ooooo`;o00001?ooool4o`0004gooooo000Looooo`03o`000?oooooooooo04_o
oooo0_l00009ooooo`Ko00000oooool3o`0000cooooo1Ol00004ooooo`;o000000?oooooo`000?l0
00003?ooool2o`0000Gooooo0_l00005ooooo`;o00001oooool2o`0000?ooooo0_l00004ooooo`;o
00001?ooool2o`0000;ooooo0_l0000Iooooo`;o00004Oooool5o`0000;ooooo0_l00002ooooo`;o
00000oooool2o`0005Gooooo000Looooo`03o`000?oooooooooo03kooooo0_l0000Eooooo`Co0000
00?oooooo`000?l000000oooool3o`0000Sooooo0_l00002ooooo`Go00001?ooool2o`0000Oooooo
1?l00005ooooo`;o00002oooool2o`0000Oooooo0_l0000?ooooo`;o00000_ooool2o`0002Gooooo
0_l00007ooooo`?o00001_ooool2o`0005[ooooo000Looooo`03o`000?oooooooooo03kooooo0_l0
000@ooooo`;o00000oooool4o`0000gooooo0ol000000ooooooo0000o`00000;ooooo`;o00000_oo
ool2o`0000?ooooo1?l00005ooooo`;o00003Oooool2o`0000Gooooo0_l0000jooooo`;o00001?oo
ool2o`0000[ooooo0_l00003ooooo`;o0000EOooool001cooooo00?o0000ooooooooool0D?ooool2
o`0000?ooooo1Ol0000:ooooo`Go000000?oooooo`000?l000000_l00002ooooo`;o00001Oooool2
o`0000;ooooo1?l000000ooooooo0000o`000003ooooo`;o00002?ooool2o`0000Oooooo0_l00005
ooooo`;o0000=?ooool2o`0000Cooooo1?l000001?oooooo0000o`000?l0000:ooooo`;o00000ooo
ool2o`0005Gooooo000Looooo`;o0000F?ooool3o`0000[ooooo0_l00004ooooo`Co00000_ooool4
o`000003ooooool0003o000000Kooooo0_l00006ooooo`?o00001oooool2o`0000Gooooo0_l00004
ooooo`;o0000;_ooool2o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`Co000000?ooooo
o`000?l000003Oooool2o`0005Sooooo000Looooo`03o`000?oooooooooo06Cooooo0_l0000:oooo
o`Oo00001_ooool2o`0000Kooooo0ol0000>ooooo`;o00001?ooool2o`0002kooooo0_l00004oooo
o`;o00006oooool4o`0005Kooooo000Looooo`03o`000?oooooooooo06;ooooo1Ol00007ooooo`;o
00000oooool4o`0000Cooooo0ol0000<ooooo`;o00001oooool3o`0003Wooooo0_l0000Gooooo`;o
00001oooool2o`0005Kooooo000Looooo`03o`000?oooooooooo06;ooooo1Ol000000ooooooo0000
o`000003o`000003ooooool0003o000000_ooooo0ol0000<ooooo`;o00001_ooool4o`0000Cooooo
0_l0000_ooooo`;o00000_ooool2o`0000Cooooo0_l00007ooooo`;o00002?ooool2o`0005oooooo
000Looooo`03o`000?oooooooooo05Wooooo0ol0000<ooooo`Go000000Coooooo`000?l0003o0000
1Oooool2o`0001[ooooo0_l00006ooooo`;o00000_ooool2o`0002_ooooo0_l00008ooooo`;o0000
1oooool2o`0000Sooooo0_l0000Oooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0E_oo
ool2o`000004ooooool0003o0000o`0001?ooooo0_l00005ooooo`;o00004?ooool6o`0000Kooooo
0_l00002ooooo`;o00001?ooool2o`0002Kooooo0_l0000Cooooo`;o00002?ooool2o`0000Wooooo
0_l0000Gooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0E_ooool2o`0002_ooooo0_l0
0003ooooo`Ko00001_ooool2o`0000;ooooo0_l0000/ooooo`;o00002Oooool3o`0000Oooooo0_l0
0008ooooo`;o00002Oooool2o`0005Oooooo000Looooo`03o`000?oooooooooo05Kooooo0_l0000;
ooooo`;o00003?ooool2o`0000Kooooo0_l00008ooooo`;o00001?ooool2o`0000kooooo0ol00009
ooooo`;o0000:_ooool3o`0001?ooooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`1Soooo
o`?o00001?ooool2o`0000Gooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00000_ooool2
o`0001[ooooo0ol00009ooooo`;o0000;?ooool2o`0000Gooooo0_l00008ooooo`Go0000H?ooool0
01cooooo00?o0000ooooooooool0I?ooool4o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`00
0003ooooool0003o000000?ooooo1?l0000;ooooo`Co000000?oooooo`000?l000001_ooool2o`00
033ooooo0_l00006ooooo`;o00001Oooool2o`0000Sooooo0ol00003ooooo`;o0000GOooool001co
oooo00?o0000ooooooooool0I_ooool2o`0000?ooooo0ol00005ooooo`?o00000_ooool2o`0000Go
oooo0_l00007ooooo`;o00000_ooool4o`000003ooooool0003o000000Kooooo0_l0000^ooooo`Co
00004_ooool2o`0000Wooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1[ooooo`Co0000
1?ooool3o`000004ooooool0003o0000o`0000gooooo0ol00005ooooo`;o00005?ooool4o`0001Wo
oooo0_l00004ooooo`?o00003_ooool2o`0000Cooooo0_l00004ooooo`;o0000H_ooool001cooooo
00?o0000ooooooooool0I_ooool2o`0000?ooooo1?l00004ooooo`;o00000_ooool2o`0000kooooo
1?l000001?oooooo0000o`000?ooool2o`0000kooooo0_l00004ooooo`Co00006Oooool2o`0000Co
oooo0_l0000?ooooo`;o00002_ooool2o`0006;ooooo000Looooo`03o`000?oooooooooo05Gooooo
0_l00003ooooo`;o00001Oooool2o`0000?ooooo0_l000000ooooooo0000o`000003o`0000oooooo
0_l0000:ooooo`;o000000?oooooo`000?l000004Oooool2o`0002Cooooo0_l00007ooooo`;o0000
5Oooool2o`0006;ooooo000Looooo`03o`000?oooooooooo05Gooooo0_l00003ooooo`Co00000ooo
ool2o`000003ooooool0003o000000?ooooo1Ol0000?ooooo`;o00003?ooool3o`0001Kooooo0_l0
0002ooooo`;o00006oooool4o`0000Gooooo0_l00005ooooo`Go0000Koooool001cooooo00?o0000
ooooooooool0G?ooool2o`0000Kooooo0_l0000Mooooo`;o000000?oooooo`000?l000000oooool3
o`0000Sooooo0_l0000<ooooo`;o00000_ooool2o`0001Kooooo1?l00003ooooo`;o000000?ooooo
o`000?l000000_l00007ooooo`Go00003?ooool2o`00067ooooo000Looooo`;o0000MOooool3o`00
00cooooo0_l000001?oooooo0000o`000?l0000<ooooo`?o0000:?ooool4o`0000Cooooo1_l0000@
ooooo`;o00000_ooool2o`000004ooooool0003o0000o`00067ooooo000Looooo`03o`000?oooooo
oooo05_ooooo0_l0000:ooooo`?o00002_ooool3o`0000Oooooo1?l000000ooooooo0000o`000002
ooooo`;o00002Oooool6o`00033ooooo0_l0000Cooooo`?o00000_ooool5o`0001Oooooo0_l00019
ooooo`007?ooool00ol0003oooooooooo`1Kooooo`Co00002?ooool3o`0000;ooooo0_l00007oooo
o`Co00001Oooool4o`000003ooooool0003o000000Sooooo0_l000000ooooooo0000o`000004o`00
00?ooooo0_l0000;ooooo`;o00008?ooool2o`0000oooooo0_l000000ooooooo0000o`000004o`00
00;ooooo0_l0000Hooooo`;o0000BOooool001cooooo00?o0000ooooooooool0GOooool2o`0000Ko
oooo0_l00003ooooo`Co00002?ooool3o`0001;ooooo1?l000000ooooooo0000o`000003ooooo`;o
00000_ooool2o`0000_ooooo0_l000001?oooooo0000o`000?l0000Iooooo`;o00003?ooool2o`00
0004ooooool0003o0000ooooo`;o000000?oooooo`000?l000001?l0001Wooooo`007?ooool00ol0
003oooooooooo`1Uooooo`;o00000oooool2o`0000;ooooo0_l00006ooooo`;o00000oooool2o`00
00[ooooo0_l00002ooooo`;o00002?ooool2o`0000?ooooo0ol00003ooooo`;o00001oooool3o`00
0003ooooool0003o000001Kooooo1?l0000:ooooo`;o000000?oooooo`000?l000001_ooool2o`00
06Wooooo000Looooo`03o`000?oooooooooo06kooooo0ol00005ooooo`;o000000?oooooo`000?l0
00000_l0000:ooooo`;o00002?ooool2o`0000;ooooo1?l000001?oooooo0000o`000?l00003oooo
o`;o00001?ooool4o`0000?ooooo0_l0000>ooooo`;o00002?ooool2o`00083ooooo000Looooo`03
o`000?oooooooooo05[ooooo0_l0000Cooooo`;o00000oooool2o`0000?ooooo0ol0000Dooooo`Co
00000oooool2o`0000gooooo1?l00002ooooo`Co00003Oooool2o`0000[ooooo0_l0000;ooooo`;o
0000LOooool001cooooo00?o0000ooooooooool0E?ooool2o`0000Cooooo0_l0000Eooooo`;o0000
00?oooooo`000?l000003Oooool4o`0000Wooooo1?l0000Eooooo`;o000000?oooooo`000?l00000
0_l0000Iooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o00001_ooool2o`0006Wooooo
000Looooo`03o`000?oooooooooo05Cooooo0_l0000@ooooo`;o00000oooool2o`0000;ooooo1?l0
0002ooooo`;o00001Oooool2o`0000Gooooo1?l0000Aooooo`;o00003oooool2o`0001Gooooo0_l0
0002ooooo`Co00001Oooool2o`0000;ooooo0_l00006ooooo`;o00000oooool2o`0006Wooooo000L
ooooo`03o`000?oooooooooo06Kooooo0ol00002ooooo`?o000000?oooooo`000?l000001?ooool2
o`0000Gooooo0_l0000Jooooo`;o00004_ooool2o`0000?ooooo0_l0000=ooooo`;o00000_ooool5
o`0000Oooooo0_l00002ooooo`;o00000oooool2o`0001?ooooo0_l0001Iooooo`007?ooool00ol0
003oooooooooo`1Wooooo`Co000000?oooooo`000?l000001oooool2o`00027ooooo0_l00003oooo
o`;o00003Oooool2o`0000?ooooo0_l0000;ooooo`;o00001oooool2o`0000Gooooo2?l00002oooo
o`;o00005?ooool2o`0005Wooooo000Looooo`03o`000?oooooooooo06Wooooo0_l0000Dooooo`;o
00005_ooool2o`0000Cooooo0_l0000Oooooo`;o00002_ooool2o`0000;ooooo0_l00002ooooo`;o
00001?ooool4o`0006gooooo000Looooo`03o`000?oooooooooo077ooooo0_l000000ooooooo0000
o`000009ooooo`;o00002Oooool2o`0000Cooooo0_l00005ooooo`;o00001?ooool2o`0001Wooooo
0_l0000@ooooo`;o00003Oooool3o`0006gooooo000Looooo`03o`000?oooooooooo077ooooo0_l0
00001?oooooo0000o`000?ooool2o`0000_ooooo0_l000001?oooooo0000o`000?ooool2o`0000Co
oooo0_l00003ooooo`;o00001_ooool2o`00017ooooo0_l00006ooooo`;o00002?ooool2o`00017o
oooo0_l00002ooooo`;o0000K_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q
8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo06Sooooo1Ol00004
ooooo`;o00001?ooool2o`0000_ooooo0_l000000ooooooo0000o`000009ooooo`;o000000?ooooo
o`000?l000006Oooool2o`00013ooooo0_l0000Aooooo`;o0000L_ooool00006oooooomgMgOoV9RH
oooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`00
0?oooooooooo067ooooo0_l00005ooooo`Ko00000oooool2o`00017ooooo1?l00007ooooo`;o0000
00?oooooo`000?l00000:Oooool2o`00013ooooo0_l00002ooooo`Co0000L_ooool00003ooooool@
413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0H?ooool3o`0000Wooooo0_l0000?ooooo`;o00001Oooool4o`0000;ooooo
0_l00003ooooo`;o00000_ooool2o`0000[ooooo0_l00004ooooo`;o00001_ooool2o`0000kooooo
0_l0000@ooooo`;o00000_ooool4o`0007;ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oo
oooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000H?ooool2o`0000[ooooo
0_l0000?ooooo`;o00002_ooool3o`0000Oooooo0_l0000:ooooo`;o00001?ooool2o`0000Kooooo
1?l0000:ooooo`;o00000oooool2o`0008Oooooo00000ooooooo0000ooooo`02ooooo`03o`000?oo
oooooooo00Wooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo08Wooooo
1?l00002ooooo`;o00001oooool3o`0000Kooooo0_l00008ooooo`;o00000_ooool2o`0000Kooooo
0_l00002ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o00001oooool2o`0007Sooooo
00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go410@okZj^_oooooo^[Zj
oa0@4006ooooo`03o`000?oooooooooo077ooooo0_l000000ooooooo0000o`000005ooooo`;o0000
3_ooool2o`0000;ooooo0_l00007ooooo`?o00001_ooool2o`0000Sooooo0_l00005ooooo`;o0000
0oooool2o`0000Gooooo0_l00006ooooo`;o00001oooool2o`0007Sooooo00001_ooooooMgMgoiRH
V?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo
077ooooo0_l000000ooooooo0000o`000005ooooo`?o00003?ooool2o`000003ooooool0003o0000
02?ooooo0ol00007ooooo`;o00000oooool2o`0000[ooooo0_l000001?oooooo0000o`000?l0001f
ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0
1_ooool00ol0003oooooooooo`1looooo`Co00002_ooool2o`000003ooooool0003o000000Gooooo
0_l00002ooooo`;o00006Oooool2o`0000Oooooo0_l00002ooooo`?o00000oooool2o`0000Gooooo
0_l000001?oooooo0000o`000?l0001fooooo`007?ooool00ol0003oooooooooo`1looooo`Co0000
3Oooool2o`0000Cooooo0ol00002ooooo`;o00000_ooool2o`0000cooooo0ol0000;ooooo`;o0000
1_ooool2o`0000;ooooo1?l0000>ooooo`;o0000LOooool001cooooo00?o0000ooooooooool0QOoo
ool2o`0000Kooooo1?l00002ooooo`;o00001oooool2o`0000?ooooo0_l00007ooooo`Go00002Ooo
ool2o`0000Kooooo0_l00002ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Oooooo0_l0
001aooooo`007?ooool00ol0003oooooooooo`25ooooo`Go00001Oooool2o`0000Gooooo0_l00009
ooooo`;o00002?ooool4o`0000gooooo0_l00002ooooo`?o00000oooool4o`0000?ooooo0_l0001j
ooooo`007?ooool00ol0003oooooooooo`27ooooo`?o00003?ooool2o`000003ooooool0003o0000
00[ooooo0_l0000Eooooo`;o00000_ooool3o`0000?ooooo1Ol0001nooooo`007?ooool00ol0003o
ooooooooo`2Iooooo`;o00001?ooool2o`0000Cooooo0_l0000;ooooo`;o00000oooool2o`000003
ooooool0003o000000Cooooo1Ol00003ooooo`?o00006Oooool2o`0006?ooooo000Looooo`03o`00
0?oooooooooo09kooooo0ol00006ooooo`;o00002Oooool2o`0000?ooooo1Ol00007ooooo`;o0000
0oooool2o`000003ooooool0003o000001Oooooo0_l0001Sooooo`007?ooool00ol0003ooooooooo
o`1cooooo`;o00002?ooool2o`0000?ooooo0_l0000>ooooo`Ko00001_ooool3o`0000Kooooo0_l0
00000ooooooo0000o`00000:ooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo0_l0
0006ooooo`;o0000O?ooool001cooooo00?o0000ooooooooool0Loooool2o`0000Sooooo0_l00003
ooooo`;o00003_ooool7o`0000oooooo1?l00006ooooo`;o00000_ooool4o`0000Cooooo0_l00003
ooooo`;o0000Q?ooool001cooooo00?o0000ooooooooool0R_ooool2o`0000?ooooo0_l00006oooo
o`;o00003_ooool3o`0000Cooooo0_l000001?oooooo0000o`000?l00004ooooo`;o0000Soooool0
01cooooo00?o0000ooooooooool0Q?ooool2o`0000Cooooo0_l000000ooooooo0000o`000003o`00
01Gooooo0_l00005ooooo`;o000000Coooooo`000?l0003o00004_ooool2o`00087ooooo000Loooo
o`03o`000?oooooooooo07oooooo0_l00003ooooo`;o00001oooool5o`0000cooooo0_l00007oooo
o`;o00007Oooool2o`00087ooooo000Looooo`;o0000P?ooool2o`0000gooooo1?l00002ooooo`?o
00000_ooool2o`0000?ooooo1?l00005ooooo`;o00000oooool2o`0009_ooooo000Looooo`03o`00
0?oooooooooo09Cooooo0ol00002ooooo`;o00001Oooool2o`0000;ooooo0_l00006ooooo`Co0000
VOooool001cooooo00?o0000ooooooooool0V_ooool2o`000003ooooool0003o000000;o00000ooo
ool2o`0000Sooooo0_l0000Dooooo`;o0000Poooool001cooooo00?o0000ooooooooool0V_ooool7
o`0000Wooooo0_l0000Hooooo`;o0000Poooool001cooooo00?o0000ooooooooool0W?ooool2o`00
00?ooooo1?l00005ooooo`;o0000WOooool001cooooo00?o0000ooooooooool0XOooool4o`0002_o
oooo0_l0001gooooo`007?ooool00ol0003oooooooooo`2Rooooo`;o0000;?ooool2o`0007Oooooo
000Looooo`03o`000?oooooooooo097ooooo0_l0000?ooooo`;o000000?oooooo`000?l00000X_oo
ool001cooooo00?o0000ooooooooool0S?ooool2o`0000?ooooo0_l00005ooooo`;o00002oooool2
o`000003ooooool0003o000000?ooooo0_l0002Jooooo`007?ooool00ol0003oooooooooo`2<oooo
o`;o00002_ooool2o`0000kooooo0_l00003ooooo`;o0000V_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`2Sooooo`;o0000Y?ooool001cooooo00?o0000ooooooooool0Xoooool2o`0001Oo
oooo0_l0002;ooooo`007?ooool2o`000;gooooo0_l0002;ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBooo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
4_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom:ooooo`005?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000
ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o0000ooooooooool0oooooomBoooo
o`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?oooooo
D_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`004_ooool00omEEEGoIVIVo`00003o
oooooeCooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Qooooo`04oa0@4?l0
003o0000ooooo`;o000000?o410@ooooooooool05_ooool4o`000008oa0@4?ooooooooooonk^k_lb
<S;o0000oc8b<_o^k^h4ooooo`Co000000?o410@ooooooooool00_ooool2o`000003oa0@4?oooooo
oooo08[ooooo002Rooooo`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`2;ooooo`00X_ooool01Ol0003ooooooooooooooooo000001_ooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0
0_ooool5o`0008cooooo002Rooooo`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool00_ooool01?m4A4CogMgMooooool0002=ooooo`00X_ooool01Ol0003oQhN7oooooonYZJWo0000
01_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool00_ooool01?oMgMgoEEEEooooool0002=ooooo`00XOooool00ol@413o0000ogMgM`02
o`000003oiRHV?oooooooooo01Wooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@00Kooooo00?o0000ooooooooool00oooool00omgMgOoc<c<o`00002=ooooo`00`_ooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003ooooooooo
o`03ooooo`03onk^k_m4A4Co000008gooooo0030ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP04ooooo`03oeEEEOmVIVKo000000Kooooo00?oMgMgo`000?ooool0S?oo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1020) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.66986 .55315 Mdot
.63479 .58666 Mdot
.46177 .35713 Mdot
.45415 .57458 Mdot
.74887 .59024 Mdot
.42833 .35986 Mdot
.6215 .41298 Mdot
.63408 .3604 Mdot
.43915 .34972 Mdot
.5742 .52397 Mdot
.64271 .40254 Mdot
.51667 .63102 Mdot
.6381 .3817 Mdot
.46268 .59012 Mdot
.49566 .87376 Mdot
.38224 .58554 Mdot
.63585 .61189 Mdot
.32272 .47202 Mdot
.42858 .65776 Mdot
.40337 .30443 Mdot
.68439 .55064 Mdot
.4513 .58278 Mdot
.67202 .55968 Mdot
.46239 .59049 Mdot
.47222 .5714 Mdot
.65764 .60025 Mdot
.60894 .55371 Mdot
.43521 .56393 Mdot
.49423 .59758 Mdot
.61636 .36662 Mdot
.26538 .6111 Mdot
.58715 .84714 Mdot
.38772 .64656 Mdot
.76166 .34392 Mdot
.64189 .3628 Mdot
.5929 .78489 Mdot
.41928 .336 Mdot
.6154 .37664 Mdot
.64304 .36543 Mdot
.59715 .37871 Mdot
.63142 .36941 Mdot
.65199 .59637 Mdot
.58089 .39248 Mdot
.69452 .39226 Mdot
.4493 .65007 Mdot
.72278 .49817 Mdot
.34725 .70901 Mdot
.42644 .62676 Mdot
.64057 .61108 Mdot
.42619 .31059 Mdot
.75011 .35218 Mdot
.60851 .4094 Mdot
.43619 .39538 Mdot
.89834 .54522 Mdot
.61181 .38626 Mdot
.45812 .65228 Mdot
.44031 .33659 Mdot
.44073 .58773 Mdot
.45765 .59212 Mdot
.44947 .76275 Mdot
.44298 .55842 Mdot
.28369 .48325 Mdot
.68454 .61433 Mdot
.35867 .44535 Mdot
.42922 .34601 Mdot
.64619 .37049 Mdot
.62161 .58589 Mdot
.6326 .38538 Mdot
.51765 .61104 Mdot
.49004 .3994 Mdot
.4259 .62557 Mdot
.64766 .37749 Mdot
.60743 .57488 Mdot
.42055 .61255 Mdot
.49391 .20224 Mdot
.3137 .7753 Mdot
.26654 .44591 Mdot
.51272 .77571 Mdot
.46344 .78247 Mdot
.32417 .37593 Mdot
.48408 .61302 Mdot
.19231 .45449 Mdot
.4249 .83711 Mdot
.67787 .56705 Mdot
.37075 .60932 Mdot
.51926 .37807 Mdot
.42025 .60687 Mdot
.65221 .49343 Mdot
.47346 .64236 Mdot
.61106 .21268 Mdot
.4442 .35518 Mdot
.65315 .57181 Mdot
.45712 .57607 Mdot
.48488 .55971 Mdot
.49947 .69661 Mdot
.40342 .57487 Mdot
.43274 .56881 Mdot
.62942 .54803 Mdot
.64639 .40665 Mdot
.54448 .58785 Mdot
.60608 .43032 Mdot
.45984 .40317 Mdot
.4105 .63142 Mdot
.43589 .32715 Mdot
.6158 .55633 Mdot
.41403 .61214 Mdot
.66223 .3895 Mdot
.45244 .63146 Mdot
.69401 .32555 Mdot
.63093 .58594 Mdot
.48923 .56283 Mdot
.26075 .478 Mdot
.3636 .23246 Mdot
.65329 .56783 Mdot
.34654 .36087 Mdot
.47978 .62641 Mdot
.42497 .5803 Mdot
.63796 .58651 Mdot
.47284 .38831 Mdot
.63119 .50602 Mdot
.68443 .60377 Mdot
.5999 .36885 Mdot
.68556 .60776 Mdot
.3697 .63066 Mdot
.43659 .35843 Mdot
.54979 .36722 Mdot
.53512 .38241 Mdot
.23869 .56958 Mdot
.42168 .60191 Mdot
.73234 .41928 Mdot
.43883 .377 Mdot
.65351 .57946 Mdot
.63432 .38892 Mdot
.47743 .53648 Mdot
.63341 .563 Mdot
.62559 .40398 Mdot
.26871 .45385 Mdot
.55012 .29312 Mdot
.66549 .61231 Mdot
.70125 .36036 Mdot
.62916 .42802 Mdot
.59537 .38878 Mdot
.75121 .32226 Mdot
.63166 .59356 Mdot
.28252 .46014 Mdot
.62217 .39769 Mdot
.30921 .66717 Mdot
.48247 .64584 Mdot
.25524 .52426 Mdot
.16894 .42144 Mdot
.74124 .32569 Mdot
.56255 .2534 Mdot
.30959 .48983 Mdot
.59696 .40151 Mdot
.48608 .57348 Mdot
.64296 .60625 Mdot
.64226 .60128 Mdot
.40566 .58434 Mdot
.46041 .57029 Mdot
.42275 .6223 Mdot
.49369 .57035 Mdot
.40513 .77913 Mdot
.44951 .63627 Mdot
.18401 .54743 Mdot
.66059 .57035 Mdot
.46435 .56307 Mdot
.46812 .35676 Mdot
.51159 .59194 Mdot
.63819 .36973 Mdot
.4409 .58154 Mdot
.45203 .57183 Mdot
.47057 .55506 Mdot
.61653 .41326 Mdot
.58007 .83609 Mdot
.20115 .36356 Mdot
.69809 .73311 Mdot
.37881 .32561 Mdot
.42106 .36152 Mdot
.41701 .59762 Mdot
.29302 .47478 Mdot
.60997 .7617 Mdot
.47851 .60779 Mdot
.48531 .14071 Mdot
.43691 .57042 Mdot
.74239 .61196 Mdot
.35791 .57861 Mdot
.71611 .72022 Mdot
.21257 .4983 Mdot
.49441 .58212 Mdot
.55149 .65842 Mdot
.71199 .6563 Mdot
.68868 .35447 Mdot
.63002 .37124 Mdot
.47026 .36308 Mdot
.44941 .34328 Mdot
.67991 .38983 Mdot
.53691 .55342 Mdot
.49993 .53956 Mdot
.51217 .56206 Mdot
.47963 .40723 Mdot
.68179 .62116 Mdot
.30948 .46117 Mdot
.62826 .55126 Mdot
.17307 .64731 Mdot
.7013 .32154 Mdot
.64038 .44832 Mdot
.25949 .45354 Mdot
.46474 .37388 Mdot
.45854 .40443 Mdot
.29766 .47104 Mdot
.4515 .62125 Mdot
.62459 .59171 Mdot
.82386 .45475 Mdot
.49473 .52717 Mdot
.82335 .41196 Mdot
.61273 .58969 Mdot
.61148 .49252 Mdot
.63525 .40049 Mdot
.40952 .32654 Mdot
.42506 .57792 Mdot
.44286 .61201 Mdot
.69116 .55358 Mdot
.42781 .62363 Mdot
.63398 .64029 Mdot
.41945 .57723 Mdot
.60156 .31786 Mdot
.26756 .44485 Mdot
.67969 .38783 Mdot
.22888 .56386 Mdot
.64463 .55335 Mdot
.22513 .47861 Mdot
.47866 .372 Mdot
.57349 .78341 Mdot
.6511 .38284 Mdot
.25942 .4706 Mdot
.48376 .3846 Mdot
.31313 .46588 Mdot
.50565 .61336 Mdot
.42981 .38179 Mdot
.27401 .48654 Mdot
.49387 .82782 Mdot
.49592 .62714 Mdot
.3934 .77991 Mdot
.62859 .41635 Mdot
.68081 .61074 Mdot
.44127 .55914 Mdot
.40342 .31823 Mdot
.37924 .63776 Mdot
.52998 .22273 Mdot
.55207 .36729 Mdot
.41262 .37079 Mdot
.34724 .42045 Mdot
.26256 .47117 Mdot
.47837 .23173 Mdot
.73095 .39178 Mdot
.63002 .60811 Mdot
.40632 .63214 Mdot
.67398 .77519 Mdot
.62282 .39749 Mdot
.45835 .62158 Mdot
.57153 .33398 Mdot
.62176 .39482 Mdot
.43863 .58925 Mdot
.64188 .41972 Mdot
.63772 .60091 Mdot
.28278 .3113 Mdot
.63313 .61112 Mdot
.47706 .63826 Mdot
.66111 .40015 Mdot
.45277 .39481 Mdot
.66175 .60091 Mdot
.44708 .63031 Mdot
.41013 .59152 Mdot
.5203 .39272 Mdot
.47083 .56111 Mdot
.63681 .79333 Mdot
.46858 .55791 Mdot
.45795 .34534 Mdot
.40835 .56999 Mdot
.59131 .17299 Mdot
.49897 .3038 Mdot
.62184 .5869 Mdot
.41071 .36568 Mdot
.44019 .3457 Mdot
.3103 .32939 Mdot
.43059 .3964 Mdot
.477 .62421 Mdot
.40784 .34336 Mdot
.28292 .52105 Mdot
.60582 .38683 Mdot
.3943 .61358 Mdot
.65876 .45503 Mdot
.43776 .31539 Mdot
.47357 .4063 Mdot
.40041 .54644 Mdot
.60444 .56667 Mdot
.45755 .57529 Mdot
.4745 .40031 Mdot
.69449 .59558 Mdot
.46726 .6399 Mdot
.40511 .51236 Mdot
.52158 .3943 Mdot
.6171 .40756 Mdot
.36572 .57226 Mdot
.43009 .63446 Mdot
.42395 .33208 Mdot
.62261 .56061 Mdot
.63601 .35854 Mdot
.66101 .59211 Mdot
.78463 .58096 Mdot
.65169 .31074 Mdot
.45287 .80254 Mdot
.27367 .50324 Mdot
.58879 .23912 Mdot
.74088 .69761 Mdot
.42824 .2274 Mdot
.30754 .59872 Mdot
.81559 .5703 Mdot
.47911 .38804 Mdot
.59024 .31545 Mdot
.4414 .34241 Mdot
.48366 .58826 Mdot
.42819 .35305 Mdot
.73287 .71071 Mdot
.42307 .57426 Mdot
.41928 .34629 Mdot
.2855 .32627 Mdot
.45698 .56638 Mdot
.65166 .56595 Mdot
.4829 .86474 Mdot
.47203 .18895 Mdot
.71102 .31645 Mdot
.43695 .38221 Mdot
.35357 .66601 Mdot
.44058 .56391 Mdot
.46359 .55205 Mdot
.66293 .60683 Mdot
.39786 .58828 Mdot
.31062 .46413 Mdot
.2678 .44908 Mdot
.40864 .47652 Mdot
.20718 .37877 Mdot
.54165 .59401 Mdot
.66228 .60262 Mdot
.40372 .75036 Mdot
.52028 .19714 Mdot
.38041 .30999 Mdot
.59107 .36905 Mdot
.55604 .83867 Mdot
.52101 .5445 Mdot
.57899 .39686 Mdot
.6874 .41951 Mdot
.64001 .57469 Mdot
.59598 .82729 Mdot
.62406 .37408 Mdot
.58627 .67473 Mdot
.46624 .69247 Mdot
.4494 .61534 Mdot
.65099 .3936 Mdot
.52622 .61961 Mdot
.55809 .17608 Mdot
.31427 .70683 Mdot
.18411 .51778 Mdot
.45716 .64555 Mdot
.46367 .21575 Mdot
.43407 .57921 Mdot
.63518 .51386 Mdot
.46383 .55748 Mdot
.66628 .58952 Mdot
.57382 .53704 Mdot
.50555 .42643 Mdot
.17801 .41892 Mdot
.70345 .32465 Mdot
.31044 .48905 Mdot
.41756 .58312 Mdot
.44961 .61425 Mdot
.27984 .45449 Mdot
.67196 .56716 Mdot
.49369 .57233 Mdot
.32065 .52751 Mdot
.4291 .61588 Mdot
.62617 .36872 Mdot
.21225 .57368 Mdot
.6364 .53565 Mdot
.40832 .56331 Mdot
.69447 .58105 Mdot
.61231 .40481 Mdot
.63612 .36262 Mdot
.4092 .54453 Mdot
.62132 .35416 Mdot
.44177 .57226 Mdot
.25108 .66002 Mdot
.68009 .58532 Mdot
.40897 .52778 Mdot
.66076 .55709 Mdot
.50982 .78281 Mdot
.66347 .3895 Mdot
.57278 .34592 Mdot
.55416 .60614 Mdot
.62797 .37451 Mdot
.72203 .34517 Mdot
.52531 .56937 Mdot
.38331 .61501 Mdot
.63856 .23212 Mdot
.44517 .38751 Mdot
.5131 .3991 Mdot
.65731 .37239 Mdot
.427 .63295 Mdot
.39175 .60094 Mdot
.60943 .40492 Mdot
.52669 .70205 Mdot
.34414 .30166 Mdot
.43356 .5658 Mdot
.6707 .58422 Mdot
.65493 .58113 Mdot
.43673 .64438 Mdot
.46081 .62699 Mdot
.45781 .37341 Mdot
.41147 .3649 Mdot
.39786 .3165 Mdot
.5208 .3945 Mdot
.5832 .33352 Mdot
.76264 .51412 Mdot
.59685 .38013 Mdot
.75014 .44002 Mdot
.58611 .20349 Mdot
.45139 .66751 Mdot
.42021 .36585 Mdot
.45353 .60737 Mdot
.45263 .57692 Mdot
.6356 .35814 Mdot
.65197 .29747 Mdot
.37343 .65178 Mdot
.68064 .59971 Mdot
.65707 .37025 Mdot
.5374 .57311 Mdot
.78088 .46929 Mdot
.28043 .48636 Mdot
.70095 .28744 Mdot
.64909 .37705 Mdot
.63955 .57078 Mdot
.65516 .41535 Mdot
.44119 .61423 Mdot
.44668 .65616 Mdot
.64201 .58082 Mdot
.26872 .48679 Mdot
.51538 .57423 Mdot
.43559 .58813 Mdot
.29146 .23108 Mdot
.47995 .20293 Mdot
.5578 .38423 Mdot
.49002 .57375 Mdot
.39067 .59178 Mdot
.31904 .47053 Mdot
.43382 .61596 Mdot
.40618 .59912 Mdot
.31957 .25278 Mdot
.57735 .42931 Mdot
.32166 .46207 Mdot
.59144 .67854 Mdot
.61319 .59388 Mdot
.6346 .81179 Mdot
.40632 .32463 Mdot
.66906 .36704 Mdot
.34931 .27664 Mdot
.44052 .39603 Mdot
.54565 .22279 Mdot
.61803 .82345 Mdot
.5159 .39765 Mdot
.33588 .50416 Mdot
.43726 .67519 Mdot
.4203 .57147 Mdot
.42886 .58177 Mdot
.28853 .46995 Mdot
.63257 .59649 Mdot
.43352 .46134 Mdot
.3292 .75081 Mdot
.44414 .57912 Mdot
.62147 .6347 Mdot
.50081 .83628 Mdot
.49658 .40414 Mdot
.30928 .46677 Mdot
.25406 .47571 Mdot
.41947 .58379 Mdot
.32943 .25849 Mdot
.65712 .60148 Mdot
.44811 .63017 Mdot
.46404 .63493 Mdot
.43586 .38288 Mdot
.62763 .58084 Mdot
.48035 .39102 Mdot
.57198 .34912 Mdot
.73796 .65333 Mdot
.31223 .20849 Mdot
.65174 .36924 Mdot
.62738 .78514 Mdot
.60784 .37638 Mdot
.19919 .48599 Mdot
.43504 .39395 Mdot
.48059 .61292 Mdot
.62786 .55685 Mdot
.4479 .63189 Mdot
.46605 .61601 Mdot
.45227 .62035 Mdot
.53015 .59387 Mdot
.50946 .1454 Mdot
.29995 .48096 Mdot
.40927 .55983 Mdot
.45854 .34966 Mdot
.62534 .79138 Mdot
.36292 .79769 Mdot
.44472 .60623 Mdot
.41161 .59367 Mdot
.64769 .563 Mdot
.40285 .5874 Mdot
.60684 .38782 Mdot
.62122 .56116 Mdot
.49038 .56248 Mdot
.5815 .82187 Mdot
.49701 .59602 Mdot
.71603 .71335 Mdot
.65644 .41476 Mdot
.72065 .34994 Mdot
.4514 .548 Mdot
.54807 .36983 Mdot
.51301 .39919 Mdot
.40271 .33008 Mdot
.66945 .38006 Mdot
.42085 .3375 Mdot
.28471 .71336 Mdot
.41627 .65865 Mdot
.48305 .5728 Mdot
.39148 .6064 Mdot
.4145 .35443 Mdot
.67271 .5027 Mdot
.50222 .24451 Mdot
.5323 .56435 Mdot
.44788 .37393 Mdot
.68955 .60495 Mdot
.37476 .44829 Mdot
.63733 .55579 Mdot
.30931 .44819 Mdot
.64415 .39978 Mdot
.29847 .48934 Mdot
.73279 .32584 Mdot
.63315 .58545 Mdot
.68978 .55118 Mdot
.42 .35761 Mdot
.58579 .46567 Mdot
.87345 .57233 Mdot
.49968 .39712 Mdot
.26358 .55139 Mdot
.67009 .60255 Mdot
.48645 .62622 Mdot
.2072 .52224 Mdot
.59764 .4735 Mdot
.42423 .33906 Mdot
.48062 .5996 Mdot
.30495 .28385 Mdot
.45746 .37452 Mdot
.3949 .61833 Mdot
.46779 .38695 Mdot
.64369 .3768 Mdot
.44813 .38259 Mdot
.61661 .60904 Mdot
.41388 .6087 Mdot
.86533 .59142 Mdot
.22452 .46551 Mdot
.47165 .55906 Mdot
.6598 .37444 Mdot
.40967 .49375 Mdot
.46468 .60647 Mdot
.29158 .44846 Mdot
.43769 .36194 Mdot
.47558 .33262 Mdot
.44067 .56235 Mdot
.4263 .36502 Mdot
.66892 .55431 Mdot
.6705 .3821 Mdot
.32465 .43648 Mdot
.55749 .35866 Mdot
.65807 .60869 Mdot
.62277 .32224 Mdot
.65365 .36091 Mdot
.39374 .58744 Mdot
.44628 .63755 Mdot
.66564 .57994 Mdot
.2371 .36303 Mdot
.41821 .56434 Mdot
.48405 .61274 Mdot
.46249 .35349 Mdot
.41403 .33708 Mdot
.24627 .35611 Mdot
.47109 .39029 Mdot
.44385 .65844 Mdot
.66542 .58154 Mdot
.46583 .58171 Mdot
.64059 .56533 Mdot
.40214 .60646 Mdot
.64313 .63139 Mdot
.6792 .57491 Mdot
.45212 .24595 Mdot
.47519 .58956 Mdot
.36352 .57044 Mdot
.45927 .6183 Mdot
.42689 .62071 Mdot
.45752 .36718 Mdot
.30464 .46691 Mdot
.45026 .53608 Mdot
.33179 .47961 Mdot
.2983 .4533 Mdot
.71955 .64336 Mdot
.43964 .38446 Mdot
.27657 .46996 Mdot
.42181 .8002 Mdot
.40843 .3547 Mdot
.28849 .47846 Mdot
.39284 .81169 Mdot
.64846 .36607 Mdot
.6237 .60975 Mdot
.45816 .56675 Mdot
.81469 .5611 Mdot
.26517 .659 Mdot
.43764 .39323 Mdot
.47367 .55879 Mdot
.45695 .60632 Mdot
.68652 .58655 Mdot
.16198 .56046 Mdot
.44607 .32648 Mdot
.48231 .58286 Mdot
.62125 .58219 Mdot
.1403 .49367 Mdot
.45267 .33933 Mdot
.28925 .47565 Mdot
.61361 .41243 Mdot
.6014 .60779 Mdot
.53299 .38071 Mdot
.60953 .40781 Mdot
.47655 .26133 Mdot
.72316 .3296 Mdot
.47923 .62692 Mdot
.41961 .36488 Mdot
.72346 .28987 Mdot
.54914 .56788 Mdot
.61057 .33673 Mdot
.38104 .68059 Mdot
.64242 .57271 Mdot
.60822 .39091 Mdot
.30439 .48919 Mdot
.60885 .57932 Mdot
.6736 .57399 Mdot
.62588 .35809 Mdot
.35913 .48562 Mdot
.60884 .48908 Mdot
.62895 .36539 Mdot
.61635 .21928 Mdot
.80074 .53153 Mdot
.40908 .35186 Mdot
.29534 .45342 Mdot
.8093 .4392 Mdot
.65304 .59631 Mdot
.55995 .83738 Mdot
.70223 .27827 Mdot
.43305 .56863 Mdot
.27326 .46687 Mdot
.71717 .51575 Mdot
.30832 .73772 Mdot
.61963 .39422 Mdot
.52349 .41755 Mdot
.2656 .49186 Mdot
.42418 .56661 Mdot
.38682 .6999 Mdot
.48501 .59617 Mdot
.6377 .40282 Mdot
.44564 .77302 Mdot
.63922 .57007 Mdot
.65331 .36372 Mdot
.70203 .28878 Mdot
.44306 .57455 Mdot
.48018 .5953 Mdot
.24428 .59689 Mdot
.62669 .60041 Mdot
.40182 .31848 Mdot
.47879 .62532 Mdot
.43766 .58507 Mdot
.37956 .61398 Mdot
.39731 .53836 Mdot
.35637 .23803 Mdot
.48164 .58443 Mdot
.62078 .31131 Mdot
.40992 .56159 Mdot
.47268 .59029 Mdot
.69436 .58512 Mdot
.36148 .18322 Mdot
.5785 .34172 Mdot
.43914 .58222 Mdot
.49002 .61955 Mdot
.62772 .357 Mdot
.56155 .50267 Mdot
.59329 .46689 Mdot
.52299 .38582 Mdot
.31628 .62478 Mdot
.52926 .59665 Mdot
.62344 .56675 Mdot
.25858 .47732 Mdot
.43503 .6421 Mdot
.62347 .56816 Mdot
.50305 .5864 Mdot
.4549 .3765 Mdot
.4105 .35863 Mdot
.71269 .36473 Mdot
.28096 .47535 Mdot
.25551 .63518 Mdot
.74471 .45302 Mdot
.46925 .36411 Mdot
.47798 .57071 Mdot
.67681 .39054 Mdot
.47234 .40233 Mdot
.52971 .38488 Mdot
.38558 .56139 Mdot
.64757 .60407 Mdot
.65433 .57019 Mdot
.25392 .52283 Mdot
.55862 .27494 Mdot
.28149 .25704 Mdot
.64596 .38024 Mdot
.48591 .55644 Mdot
.72876 .40451 Mdot
.65356 .56896 Mdot
.21943 .52342 Mdot
.2753 .4715 Mdot
.61826 .39511 Mdot
.38094 .31202 Mdot
.63592 .56336 Mdot
.65286 .6139 Mdot
.4864 .63328 Mdot
.43593 .59742 Mdot
.30535 .58515 Mdot
.34287 .51256 Mdot
.60997 .40161 Mdot
.28518 .45285 Mdot
.48506 .38964 Mdot
.48778 .591 Mdot
.67622 .56322 Mdot
.81792 .47727 Mdot
.48675 .62344 Mdot
.45979 .37202 Mdot
.64523 .57423 Mdot
.27186 .45738 Mdot
.29757 .4516 Mdot
.42771 .61989 Mdot
.41815 .74763 Mdot
.61659 .38462 Mdot
.65043 .56659 Mdot
.77971 .41933 Mdot
.41266 .56589 Mdot
.43057 .59627 Mdot
.35617 .61658 Mdot
.61403 .36468 Mdot
.72044 .36274 Mdot
.27149 .49079 Mdot
.6424 .59487 Mdot
.49595 .58778 Mdot
.28173 .48176 Mdot
.72641 .37699 Mdot
.42535 .38323 Mdot
.45668 .38503 Mdot
.29352 .44907 Mdot
.27779 .45816 Mdot
.28074 .44987 Mdot
.54633 .84377 Mdot
.61714 .61087 Mdot
.40177 .52808 Mdot
.43412 .55787 Mdot
.24342 .52208 Mdot
.48896 .54156 Mdot
.66017 .41301 Mdot
.45206 .38986 Mdot
.4624 .61526 Mdot
.47613 .63803 Mdot
.35882 .58988 Mdot
.37922 .54578 Mdot
.63121 .53823 Mdot
.62956 .58428 Mdot
.42291 .66443 Mdot
.43811 .38631 Mdot
.16103 .62135 Mdot
.79261 .66518 Mdot
.44197 .54806 Mdot
.59318 .48644 Mdot
.67393 .56251 Mdot
.60858 .36489 Mdot
.56196 .4358 Mdot
.65269 .41516 Mdot
.6466 .59018 Mdot
.48609 .58919 Mdot
.75441 .44761 Mdot
.3072 .45447 Mdot
.42283 .62839 Mdot
.62938 .40014 Mdot
.42226 .62551 Mdot
.61061 .40871 Mdot
.76681 .57631 Mdot
.5738 .19114 Mdot
.43603 .57034 Mdot
.39449 .57776 Mdot
.36673 .66997 Mdot
.44603 .6047 Mdot
.25342 .4152 Mdot
.67085 .56211 Mdot
.23837 .32708 Mdot
.49203 .62934 Mdot
.57843 .7472 Mdot
.42045 .56129 Mdot
.30814 .28895 Mdot
.43176 .60083 Mdot
.47412 .437 Mdot
.42675 .5682 Mdot
.40882 .60719 Mdot
.65813 .40767 Mdot
.62883 .35727 Mdot
.65923 .54501 Mdot
.40291 .31883 Mdot
.68926 .7463 Mdot
.43315 .5905 Mdot
.5566 .358 Mdot
.5715 .36893 Mdot
.28376 .45549 Mdot
.64847 .59142 Mdot
.1399 .51097 Mdot
.62816 .41884 Mdot
.36872 .30641 Mdot
.22486 .38937 Mdot
.53384 .37936 Mdot
.53425 .393 Mdot
.60626 .52163 Mdot
.26383 .47563 Mdot
.4265 .56467 Mdot
.77216 .36527 Mdot
.49246 .20666 Mdot
.46788 .53227 Mdot
.65996 .36875 Mdot
.58815 .7708 Mdot
.8108 .45189 Mdot
.25174 .47852 Mdot
.29297 .49258 Mdot
.6206 .41396 Mdot
.42161 .30977 Mdot
.50887 .63151 Mdot
.27382 .4734 Mdot
.47181 .37798 Mdot
.40508 .3454 Mdot
.40317 .38059 Mdot
.65273 .6005 Mdot
.70456 .29827 Mdot
.71941 .48171 Mdot
.6133 .40905 Mdot
.22985 .48114 Mdot
.59795 .60164 Mdot
.60062 .58444 Mdot
.40873 .33614 Mdot
.45883 .36542 Mdot
.60914 .5981 Mdot
.46668 .65533 Mdot
.35062 .59238 Mdot
.44091 .57954 Mdot
.29098 .46575 Mdot
.43684 .60512 Mdot
.45334 .37046 Mdot
.62473 .39102 Mdot
.45545 .35731 Mdot
.6362 .41943 Mdot
.7642 .49991 Mdot
.44424 .62759 Mdot
.41055 .60248 Mdot
.25969 .65554 Mdot
.67286 .55269 Mdot
.75113 .36104 Mdot
.60111 .31595 Mdot
.44465 .34238 Mdot
.40579 .59602 Mdot
.65556 .55276 Mdot
.25074 .45824 Mdot
.25568 .65306 Mdot
.42686 .6363 Mdot
.66915 .56013 Mdot
.48452 .5794 Mdot
.45186 .81338 Mdot
.45205 .1895 Mdot
.66048 .58822 Mdot
.16929 .4408 Mdot
.49291 .59579 Mdot
.57066 .54845 Mdot
.3945 .62391 Mdot
.30281 .53781 Mdot
.41487 .56606 Mdot
.61258 .58971 Mdot
.44535 .58333 Mdot
.61124 .57441 Mdot
.46112 .34508 Mdot
.59901 .37604 Mdot
.67325 .6033 Mdot
.45048 .63844 Mdot
.64664 .83156 Mdot
.64302 .39734 Mdot
.42141 .58028 Mdot
.6447 .41013 Mdot
.61752 .58262 Mdot
.65167 .61252 Mdot
.31209 .75285 Mdot
.56119 .40056 Mdot
.64226 .37573 Mdot
.47735 .57909 Mdot
.68423 .46873 Mdot
.47303 .58423 Mdot
.29159 .57609 Mdot
.43616 .64965 Mdot
.41038 .56833 Mdot
.30873 .77289 Mdot
.60484 .38695 Mdot
.29379 .25335 Mdot
.34076 .759 Mdot
.53029 .84605 Mdot
.61796 .61938 Mdot
.25174 .47737 Mdot
.59145 .8291 Mdot
.56714 .35346 Mdot
.43924 .37242 Mdot
.46052 .61582 Mdot
.61934 .53716 Mdot
.61338 .37809 Mdot
.30371 .46791 Mdot
.43495 .5708 Mdot
.46049 .36734 Mdot
.35176 .31028 Mdot
.59354 .39305 Mdot
.6513 .59595 Mdot
.68254 .59291 Mdot
.15224 .44985 Mdot
.49579 .58385 Mdot
.40856 .59714 Mdot
.64024 .40283 Mdot
.49161 .52906 Mdot
.26136 .46738 Mdot
.31615 .30066 Mdot
.64304 .37724 Mdot
.55493 .46447 Mdot
.62864 .59061 Mdot
.4557 .60725 Mdot
.68981 .51679 Mdot
.38228 .33812 Mdot
.6361 .67159 Mdot
.2919 .47205 Mdot
.28792 .58385 Mdot
.61268 .59058 Mdot
.63184 .39263 Mdot
.55962 .29781 Mdot
.37439 .62823 Mdot
.45501 .60185 Mdot
.28338 .58497 Mdot
.38719 .48141 Mdot
.18647 .52737 Mdot
.40155 .62562 Mdot
.40097 .47405 Mdot
.40347 .62034 Mdot
.37853 .6238 Mdot
.45302 .65663 Mdot
.42417 .59795 Mdot
.67089 .56098 Mdot
.42865 .52934 Mdot
.43332 .37198 Mdot
.50915 .69118 Mdot
.54293 .41829 Mdot
.45245 .5594 Mdot
.48209 .58914 Mdot
.66142 .69082 Mdot
.57702 .38761 Mdot
.67614 .58358 Mdot
.70548 .59153 Mdot
.61284 .35716 Mdot
.35614 .58459 Mdot
.409 .31745 Mdot
.40448 .54132 Mdot
.45491 .362 Mdot
.66224 .55605 Mdot
.44546 .33992 Mdot
.59382 .38086 Mdot
.42022 .36705 Mdot
.59067 .32699 Mdot
.6087 .38546 Mdot
.63447 .60528 Mdot
.42202 .61315 Mdot
.65608 .36957 Mdot
.24841 .59632 Mdot
.29034 .46625 Mdot
.31468 .75651 Mdot
.50137 .59103 Mdot
.56502 .42181 Mdot
.40286 .51274 Mdot
.45427 .35742 Mdot
.39741 .20791 Mdot
.67945 .57699 Mdot
.29694 .44507 Mdot
.66292 .55553 Mdot
.65022 .22516 Mdot
.30015 .45988 Mdot
.40141 .81582 Mdot
.58708 .27521 Mdot
.45007 .31571 Mdot
.47237 .65253 Mdot
.41977 .70049 Mdot
.4872 .40046 Mdot
.61265 .37962 Mdot
.57102 .26812 Mdot
.40993 .61141 Mdot
.43018 .2298 Mdot
.66066 .544 Mdot
.40462 .33474 Mdot
.63464 .38568 Mdot
.64934 .36243 Mdot
.45653 .6326 Mdot
.27226 .35694 Mdot
.41161 .6272 Mdot
.54272 .27135 Mdot
.3066 .61338 Mdot
.35348 .62883 Mdot
.41868 .57831 Mdot
.43892 .3291 Mdot
.4837 .57887 Mdot
.34098 .62148 Mdot
.7543 .33025 Mdot
.52797 .58701 Mdot
.63846 .29974 Mdot
.23289 .48064 Mdot
.6385 .58347 Mdot
.4618 .54565 Mdot
.53844 .376 Mdot
.49286 .58375 Mdot
.70862 .22277 Mdot
.28687 .47973 Mdot
.53632 .35963 Mdot
.40935 .56406 Mdot
.46674 .62987 Mdot
.48424 .67696 Mdot
.60765 .54085 Mdot
.37897 .31255 Mdot
.45156 .59691 Mdot
.30967 .64907 Mdot
.65143 .39764 Mdot
.41452 .63097 Mdot
.42624 .58158 Mdot
.72467 .64794 Mdot
.62602 .36051 Mdot
.45312 .34969 Mdot
.43863 .39662 Mdot
.48604 .38133 Mdot
.32053 .48692 Mdot
.53473 .43328 Mdot
.23359 .52418 Mdot
.4657 .19515 Mdot
.25634 .46306 Mdot
.49791 .60745 Mdot
.38563 .66861 Mdot
.48982 .61375 Mdot
.30684 .489 Mdot
.61821 .36398 Mdot
.67756 .5861 Mdot
.70656 .40033 Mdot
.48928 .40616 Mdot
.39384 .61329 Mdot
.31408 .47242 Mdot
.64467 .6059 Mdot
.25173 .44053 Mdot
.63939 .58934 Mdot
.63759 .3759 Mdot
.63131 .35003 Mdot
.30792 .477 Mdot
.64489 .55496 Mdot
.62475 .31644 Mdot
.32085 .73944 Mdot
.43504 .65138 Mdot
.6722 .34889 Mdot
.6626 .55073 Mdot
.62492 .54394 Mdot
.63468 .54752 Mdot
.4311 .62489 Mdot
.58808 .48885 Mdot
.37792 .6004 Mdot
.613 .40423 Mdot
.46787 .38533 Mdot
.31453 .52104 Mdot
.79605 .5129 Mdot
.29967 .51754 Mdot
.5098 .57211 Mdot
.44652 .57709 Mdot
.41984 .58347 Mdot
.46023 .64821 Mdot
.53919 .28815 Mdot
.45492 .62736 Mdot
.65457 .41099 Mdot
.44546 .36296 Mdot
.4439 .55792 Mdot
.43087 .38759 Mdot
.62797 .49754 Mdot
.25743 .47713 Mdot
.52624 .42807 Mdot
.65407 .80462 Mdot
.64993 .60729 Mdot
.47125 .39231 Mdot
.43659 .37069 Mdot
.26795 .45443 Mdot
.61619 .37671 Mdot
.63442 .59258 Mdot
.31503 .54117 Mdot
.28291 .45099 Mdot
.44228 .58371 Mdot
.42125 .26444 Mdot
.40617 .24964 Mdot
.41236 .57279 Mdot
.47247 .61033 Mdot
.41379 .37249 Mdot
.42682 .31262 Mdot
.83932 .43243 Mdot
.20361 .53528 Mdot
.30734 .47215 Mdot
.27092 .48705 Mdot
.60339 .57091 Mdot
.40061 .56126 Mdot
.61561 .40662 Mdot
.21609 .58592 Mdot
.39898 .49231 Mdot
.24211 .62052 Mdot
.32748 .43608 Mdot
.43988 .63561 Mdot
.44089 .72547 Mdot
.44366 .57325 Mdot
.68301 .57831 Mdot
.6207 .59241 Mdot
.6716 .5961 Mdot
.6135 .38505 Mdot
.52678 .78464 Mdot
.66046 .39958 Mdot
.69271 .77012 Mdot
.61121 .59171 Mdot
.5274 .31532 Mdot
.43068 .33103 Mdot
.46956 .54832 Mdot
.26545 .46333 Mdot
.60973 .42365 Mdot
.51526 .61628 Mdot
.339 .24906 Mdot
.41885 .36038 Mdot
.63198 .60513 Mdot
.60427 .52438 Mdot
.76626 .6604 Mdot
.5721 .4534 Mdot
.55031 .58928 Mdot
.45018 .69209 Mdot
.28816 .45428 Mdot
.62824 .67021 Mdot
.30963 .49118 Mdot
.62266 .40018 Mdot
.41347 .60474 Mdot
.42022 .60545 Mdot
.40167 .60994 Mdot
.45166 .62699 Mdot
.61986 .35646 Mdot
.49867 .55703 Mdot
.59132 .173 Mdot
.40959 .35817 Mdot
.47854 .82095 Mdot
.27491 .48192 Mdot
.66682 .37831 Mdot
.44788 .36331 Mdot
.39379 .31411 Mdot
.22368 .55059 Mdot
.43094 .56721 Mdot
.46172 .61704 Mdot
.37315 .31084 Mdot
.39913 .62109 Mdot
.53302 .57059 Mdot
.42995 .36752 Mdot
.30665 .51721 Mdot
.25611 .45884 Mdot
.29455 .4898 Mdot
.62463 .36321 Mdot
.65258 .55408 Mdot
.28209 .46865 Mdot
.46001 .34494 Mdot
.50483 .58024 Mdot
.46565 .63631 Mdot
.66164 .54979 Mdot
.70013 .27456 Mdot
.25409 .48193 Mdot
.60331 .52093 Mdot
.61465 .57316 Mdot
.619 .6129 Mdot
.45649 .60095 Mdot
.46026 .53002 Mdot
.59624 .56588 Mdot
.27529 .44837 Mdot
.66485 .37276 Mdot
.50305 .36172 Mdot
.62845 .40426 Mdot
.63478 .59898 Mdot
.45688 .64194 Mdot
.62953 .5993 Mdot
.48938 .57071 Mdot
.49228 .89511 Mdot
.42419 .60293 Mdot
.49949 .18036 Mdot
.28482 .54653 Mdot
.43262 .36333 Mdot
.621 .31709 Mdot
.40727 .33633 Mdot
.61291 .57805 Mdot
.44691 .64171 Mdot
.277 .49183 Mdot
.48013 .85063 Mdot
.596 .5962 Mdot
.4536 .37917 Mdot
.41118 .31229 Mdot
.60713 .38076 Mdot
.44681 .55665 Mdot
.45253 .60524 Mdot
.41746 .34408 Mdot
.34457 .56635 Mdot
.64281 .55995 Mdot
.41071 .59194 Mdot
.45975 .58383 Mdot
.43021 .36268 Mdot
.31566 .73214 Mdot
.58294 .55852 Mdot
.41677 .5992 Mdot
.56721 .32028 Mdot
.66336 .4073 Mdot
.46946 .65009 Mdot
.49632 .55317 Mdot
.27126 .46446 Mdot
.53657 .8176 Mdot
.76547 .34415 Mdot
.65605 .41761 Mdot
.40514 .32085 Mdot
.49835 .58871 Mdot
.42828 .33118 Mdot
.45947 .63714 Mdot
.64665 .76242 Mdot
.40611 .34367 Mdot
.47495 .62206 Mdot
.42272 .55118 Mdot
.62316 .59844 Mdot
.45798 .62859 Mdot
.68628 .67813 Mdot
.48279 .39775 Mdot
.46813 .62578 Mdot
.42295 .7479 Mdot
.64188 .36692 Mdot
.44418 .54706 Mdot
.27904 .48735 Mdot
.31281 .5346 Mdot
.74366 .46641 Mdot
.5645 .34375 Mdot
.2895 .48863 Mdot
.41881 .62501 Mdot
.41011 .30612 Mdot
.61347 .41073 Mdot
.42201 .22616 Mdot
.40419 .59342 Mdot
.63867 .40169 Mdot
.62663 .38986 Mdot
.28913 .48488 Mdot
.23579 .29886 Mdot
.49231 .55291 Mdot
.44359 .60586 Mdot
.70287 .67402 Mdot
.68947 .59593 Mdot
.4332 .60703 Mdot
.49207 .61895 Mdot
.65192 .41152 Mdot
.55607 .60357 Mdot
.62496 .73721 Mdot
.28697 .32368 Mdot
.63143 .42489 Mdot
.4936 .37838 Mdot
.40531 .30526 Mdot
.27332 .47975 Mdot
.64555 .58019 Mdot
.28134 .49797 Mdot
.43512 .37931 Mdot
.49656 .60517 Mdot
.63216 .41647 Mdot
.67506 .65025 Mdot
.60752 .40828 Mdot
.5524 .35505 Mdot
.68011 .56038 Mdot
.71879 .4188 Mdot
.62744 .16779 Mdot
.72636 .48795 Mdot
.58616 .41102 Mdot
.28351 .45562 Mdot
.47126 .26155 Mdot
.45546 .58154 Mdot
.60015 .66512 Mdot
.42239 .61751 Mdot
.43575 .74394 Mdot
.46929 .38947 Mdot
.39789 .31284 Mdot
.41503 .60279 Mdot
.30122 .60231 Mdot
.60241 .4029 Mdot
.60587 .3878 Mdot
.46757 .62208 Mdot
.62826 .37419 Mdot
.43938 .59655 Mdot
.45564 .36672 Mdot
.33239 .22539 Mdot
.43557 .57626 Mdot
.38241 .60968 Mdot
.64515 .4507 Mdot
.33005 .77446 Mdot
.6071 .29281 Mdot
.44318 .72069 Mdot
.77993 .63404 Mdot
.6284 .37487 Mdot
.39409 .55958 Mdot
.50112 .39902 Mdot
.41494 .37432 Mdot
.62413 .31715 Mdot
.43125 .61299 Mdot
.43415 .61697 Mdot
.40678 .5936 Mdot
.48113 .59558 Mdot
.6064 .66783 Mdot
.47383 .52522 Mdot
.48022 .74855 Mdot
.46469 .61715 Mdot
.39103 .70431 Mdot
.65691 .37251 Mdot
.68785 .55348 Mdot
.27599 .49796 Mdot
.442 .63532 Mdot
.58134 .60396 Mdot
.66648 .39991 Mdot
.6952 .76787 Mdot
.61255 .37004 Mdot
.43915 .34575 Mdot
.60255 .37203 Mdot
.47544 .56175 Mdot
.6555 .58055 Mdot
.52016 .38621 Mdot
.48773 .22948 Mdot
.44057 .37304 Mdot
.47152 .55899 Mdot
.52887 .35893 Mdot
.43891 .37428 Mdot
.636 .49212 Mdot
.65298 .57692 Mdot
.30402 .64936 Mdot
.62041 .59261 Mdot
.47483 .62359 Mdot
.48056 .61895 Mdot
.64396 .32719 Mdot
.59708 .39138 Mdot
.61704 .58675 Mdot
.2781 .24056 Mdot
.30988 .49212 Mdot
.66882 .59585 Mdot
.38927 .64894 Mdot
.49965 .4822 Mdot
.66134 .57696 Mdot
.32971 .57108 Mdot
.61081 .38413 Mdot
.6068 .58655 Mdot
.38504 .64647 Mdot
.63824 .25333 Mdot
.29521 .44664 Mdot
.43381 .32041 Mdot
.44526 .43187 Mdot
.47785 .39954 Mdot
.66174 .36554 Mdot
.41559 .3533 Mdot
.65414 .39445 Mdot
.74498 .36132 Mdot
.36657 .7104 Mdot
.6778 .39085 Mdot
.64751 .35496 Mdot
.42122 .35853 Mdot
.41335 .58075 Mdot
.46957 .41954 Mdot
.40984 .64076 Mdot
.50226 .63143 Mdot
.65467 .38557 Mdot
.61438 .59306 Mdot
.62789 .61235 Mdot
.40004 .70294 Mdot
.683 .59257 Mdot
.45646 .36316 Mdot
.45701 .1905 Mdot
.73511 .3301 Mdot
.64868 .39585 Mdot
.6337 .35371 Mdot
.47593 .58559 Mdot
.42227 .338 Mdot
.46003 .3403 Mdot
.61455 .3985 Mdot
.58121 .64583 Mdot
.38842 .57895 Mdot
.65399 .53962 Mdot
.61061 .59294 Mdot
.66374 .58491 Mdot
.62358 .55255 Mdot
.61687 .72424 Mdot
.61012 .38521 Mdot
.6112 .58507 Mdot
.47234 .62115 Mdot
.43407 .6156 Mdot
.52614 .38969 Mdot
.29144 .48999 Mdot
.50095 .58056 Mdot
.45044 .65953 Mdot
.45842 .60321 Mdot
.45396 .3838 Mdot
.40591 .66467 Mdot
.40132 .31972 Mdot
.4409 .32271 Mdot
.42137 .37574 Mdot
.56991 .34897 Mdot
.42425 .69407 Mdot
.79608 .62181 Mdot
.4826 .58285 Mdot
.48292 .52167 Mdot
.43208 .33296 Mdot
.37288 .22305 Mdot
.72118 .37288 Mdot
.40506 .59502 Mdot
.38583 .3516 Mdot
.41608 .34417 Mdot
.67985 .60579 Mdot
.4288 .61005 Mdot
.49233 .40695 Mdot
.25752 .47459 Mdot
.3972 .64952 Mdot
.46076 .40628 Mdot
.63324 .5576 Mdot
.29572 .50412 Mdot
.60588 .57843 Mdot
.43184 .38451 Mdot
.42831 .5498 Mdot
.88167 .56098 Mdot
.48443 .38019 Mdot
.40543 .80146 Mdot
.57745 .58727 Mdot
.41038 .59049 Mdot
.47432 .39301 Mdot
.6889 .5946 Mdot
.66622 .37097 Mdot
.4525 .46591 Mdot
.67978 .58594 Mdot
.39796 .3141 Mdot
.46604 .40642 Mdot
.43184 .3688 Mdot
.63151 .58057 Mdot
.42556 .64271 Mdot
.63274 .57135 Mdot
.60343 .3719 Mdot
.45589 .57233 Mdot
.73258 .70963 Mdot
.47791 .52204 Mdot
.61382 .57868 Mdot
.46102 .35931 Mdot
.31767 .46618 Mdot
.44171 .56765 Mdot
.38746 .78425 Mdot
.48818 .56295 Mdot
.64496 .40413 Mdot
.28663 .28955 Mdot
.6713 .654 Mdot
.42751 .55981 Mdot
.47696 .58662 Mdot
.6075 .39658 Mdot
.43397 .56726 Mdot
.42314 .56251 Mdot
.5632 .37718 Mdot
.62572 .58116 Mdot
.44866 .58283 Mdot
.46829 .36886 Mdot
.77066 .3757 Mdot
.38269 .58889 Mdot
.35138 .35878 Mdot
.29886 .6306 Mdot
.2646 .29719 Mdot
.4185 .616 Mdot
.21415 .56415 Mdot
.4798 .6015 Mdot
.42884 .62981 Mdot
.47441 .58038 Mdot
.45378 .71415 Mdot
.4231 .36688 Mdot
.44799 .37102 Mdot
.29146 .44605 Mdot
.30198 .63532 Mdot
.27193 .46721 Mdot
.61351 .37344 Mdot
.32934 .36708 Mdot
.40734 .34647 Mdot
.63344 .55693 Mdot
.41462 .62542 Mdot
.49019 .397 Mdot
.45487 .60989 Mdot
.48092 .56432 Mdot
.43802 .32711 Mdot
.4556 .33221 Mdot
.5488 .36291 Mdot
.26571 .48326 Mdot
.67411 .59824 Mdot
.49983 .62358 Mdot
.29976 .4543 Mdot
.4264 .64201 Mdot
.23135 .51439 Mdot
.67478 .59373 Mdot
.62663 .5787 Mdot
.65685 .61626 Mdot
.49671 .60387 Mdot
.45971 .56019 Mdot
.66014 .3986 Mdot
.64462 .55375 Mdot
.63638 .36607 Mdot
.5179 .38943 Mdot
.33761 .34893 Mdot
.43137 .61315 Mdot
.58005 .53497 Mdot
.26625 .47025 Mdot
.44405 .35269 Mdot
.36115 .31858 Mdot
.30536 .44985 Mdot
.48729 .5639 Mdot
.43678 .32857 Mdot
.30704 .48581 Mdot
.55485 .64214 Mdot
.82553 .57353 Mdot
.31874 .47513 Mdot
.47135 .62023 Mdot
.53301 .64072 Mdot
.29863 .70259 Mdot
.32007 .48445 Mdot
.63649 .41281 Mdot
.49744 .60329 Mdot
.41247 .51662 Mdot
.25867 .48649 Mdot
.7672 .38455 Mdot
.4318 .35927 Mdot
.66055 .28044 Mdot
.4802 .65865 Mdot
.57008 .66511 Mdot
.29411 .49869 Mdot
.63823 .5937 Mdot
.69706 .57978 Mdot
.46518 .59818 Mdot
.31787 .49116 Mdot
.62362 .42208 Mdot
.43505 .3582 Mdot
.59713 .32455 Mdot
.63238 .57824 Mdot
.661 .46383 Mdot
.46679 .3792 Mdot
.59524 .52189 Mdot
.29405 .30296 Mdot
.34691 .61074 Mdot
.40101 .72562 Mdot
.51799 .20772 Mdot
.49642 .61651 Mdot
.31413 .48584 Mdot
.66449 .4017 Mdot
.62523 .41614 Mdot
.64281 .3794 Mdot
.61726 .31747 Mdot
.55454 .4312 Mdot
.44668 .3937 Mdot
.45854 .23222 Mdot
.28053 .48073 Mdot
.31936 .6785 Mdot
.42597 .63992 Mdot
.44442 .5767 Mdot
.48738 .55723 Mdot
.41149 .63114 Mdot
.47408 .59669 Mdot
.62119 .37365 Mdot
.61832 .31594 Mdot
.47703 .33258 Mdot
.67072 .58154 Mdot
.30146 .51542 Mdot
.43106 .33108 Mdot
.41094 .36656 Mdot
.30283 .47713 Mdot
.62671 .51218 Mdot
.4556 .39956 Mdot
.44666 .34181 Mdot
.49673 .56508 Mdot
.63366 .56494 Mdot
.43768 .53033 Mdot
.48413 .61151 Mdot
.4474 .3574 Mdot
.36313 .44693 Mdot
.65394 .71295 Mdot
.36767 .60473 Mdot
.25824 .49688 Mdot
.57353 .49299 Mdot
.31937 .48453 Mdot
.394 .62642 Mdot
.35916 .22986 Mdot
.43343 .37779 Mdot
.43129 .34274 Mdot
.3129 .48241 Mdot
.57506 .55347 Mdot
.64177 .57596 Mdot
.39377 .31061 Mdot
.64993 .40606 Mdot
.48605 .61781 Mdot
.34549 .32785 Mdot
.56131 .55555 Mdot
.29274 .34829 Mdot
.64662 .386 Mdot
.45328 .33559 Mdot
.44337 .5569 Mdot
.47189 .61856 Mdot
.28272 .45428 Mdot
.75569 .58306 Mdot
.41042 .65694 Mdot
.53396 .84619 Mdot
.58668 .19711 Mdot
.66757 .26196 Mdot
.45478 .60184 Mdot
.62718 .58259 Mdot
.43534 .39404 Mdot
.29309 .45296 Mdot
.51218 .58293 Mdot
.81643 .58937 Mdot
.67737 .5505 Mdot
.62742 .39762 Mdot
.50469 .40375 Mdot
.5622 .43518 Mdot
.49652 .58067 Mdot
.42288 .61662 Mdot
.43853 .62629 Mdot
.84461 .49215 Mdot
.46028 .38174 Mdot
.68019 .56571 Mdot
.29445 .47229 Mdot
.68322 .58889 Mdot
.44144 .36899 Mdot
.69472 .43618 Mdot
.44195 .56097 Mdot
.67421 .55029 Mdot
.641 .59189 Mdot
.60756 .37947 Mdot
.66165 .3634 Mdot
.4995 .37353 Mdot
.42499 .60175 Mdot
.48045 .40848 Mdot
.62269 .5998 Mdot
.38874 .30621 Mdot
.29823 .45831 Mdot
.66228 .38545 Mdot
.46334 .61822 Mdot
.43555 .3766 Mdot
.50537 .56074 Mdot
.65904 .56957 Mdot
.44564 .34089 Mdot
.54857 .36605 Mdot
.27315 .48743 Mdot
.44638 .61862 Mdot
.2485 .48674 Mdot
.406 .32058 Mdot
.45906 .58252 Mdot
.63157 .51917 Mdot
.29535 .50813 Mdot
.50123 .23989 Mdot
.45316 .39468 Mdot
.55546 .36164 Mdot
.65249 .61545 Mdot
.76534 .40019 Mdot
.4333 .34576 Mdot
.6412 .51617 Mdot
.76622 .53784 Mdot
.50198 .6216 Mdot
.65676 .59424 Mdot
.44965 .26041 Mdot
.60715 .83881 Mdot
.34334 .73746 Mdot
.4223 .58062 Mdot
.46832 .39481 Mdot
.31223 .47144 Mdot
.64935 .39517 Mdot
.3512 .35643 Mdot
.34197 .62315 Mdot
.41939 .32291 Mdot
.47796 .58307 Mdot
.62108 .58792 Mdot
.61673 .39092 Mdot
.76112 .46015 Mdot
.46049 .34968 Mdot
.46492 .39022 Mdot
.43798 .55807 Mdot
.27635 .4723 Mdot
.38621 .75802 Mdot
.45591 .37092 Mdot
.3754 .30429 Mdot
.47677 .2597 Mdot
.31463 .47276 Mdot
.47686 .60748 Mdot
.39377 .69903 Mdot
.46459 .64847 Mdot
.42226 .81486 Mdot
.40637 .32763 Mdot
.67069 .57685 Mdot
.4232 .62192 Mdot
.27522 .33109 Mdot
.44315 .35665 Mdot
.59471 .48495 Mdot
.35591 .42887 Mdot
.61062 .38558 Mdot
.36239 .31022 Mdot
.44027 .60941 Mdot
.60368 .40478 Mdot
.26661 .47001 Mdot
.41994 .59697 Mdot
.46111 .5609 Mdot
.68627 .5968 Mdot
.62198 .40137 Mdot
.78652 .5522 Mdot
.6515 .36215 Mdot
.65618 .41459 Mdot
.65806 .61977 Mdot
.45269 .59117 Mdot
.44196 .34568 Mdot
.41538 .34129 Mdot
.51095 .60944 Mdot
.39054 .20097 Mdot
.63979 .5749 Mdot
.22778 .47747 Mdot
.83888 .46951 Mdot
.36517 .64302 Mdot
.35901 .31894 Mdot
.75383 .58199 Mdot
.62274 .42113 Mdot
.46671 .62001 Mdot
.62182 .56651 Mdot
.39515 .30288 Mdot
.46788 .3783 Mdot
.44382 .64427 Mdot
.62294 .38778 Mdot
.25734 .4658 Mdot
.48202 .38037 Mdot
.27416 .35507 Mdot
.4428 .62965 Mdot
.44029 .23308 Mdot
.478 .38968 Mdot
.51064 .86323 Mdot
.39585 .2904 Mdot
.66086 .59265 Mdot
.47809 .56415 Mdot
.6815 .59545 Mdot
.295 .46701 Mdot
.49863 .38179 Mdot
.62373 .38982 Mdot
.36855 .65074 Mdot
.70169 .23412 Mdot
.42063 .36079 Mdot
.672 .56251 Mdot
.42798 .55941 Mdot
.41938 .67923 Mdot
.43931 .60406 Mdot
.53418 .63417 Mdot
.22843 .47123 Mdot
.65291 .37967 Mdot
.64223 .4074 Mdot
.45574 .57843 Mdot
.26825 .45696 Mdot
.44968 .33429 Mdot
.43434 .35627 Mdot
.2485 .75012 Mdot
.38729 .30813 Mdot
.30577 .57752 Mdot
.43807 .61792 Mdot
.39961 .30733 Mdot
.80303 .48582 Mdot
.64144 .40203 Mdot
.41526 .63709 Mdot
.40658 .31411 Mdot
.61005 .2263 Mdot
.27215 .52047 Mdot
.47432 .59966 Mdot
.53451 .59264 Mdot
.6472 .40805 Mdot
.2627 .63144 Mdot
.43215 .38366 Mdot
.42738 .6475 Mdot
.60385 .36106 Mdot
.25605 .33829 Mdot
.73367 .30589 Mdot
.6738 .59842 Mdot
.49422 .39501 Mdot
.62038 .37396 Mdot
.46736 .66322 Mdot
.27754 .4839 Mdot
.48533 .39905 Mdot
.45242 .38155 Mdot
.47328 .57431 Mdot
.48733 .554 Mdot
.37799 .6744 Mdot
.66997 .56357 Mdot
.65033 .36634 Mdot
.41234 .6083 Mdot
.65389 .46333 Mdot
.40251 .61471 Mdot
.66033 .38715 Mdot
.87027 .62863 Mdot
.48558 .64615 Mdot
.44138 .60323 Mdot
.37962 .75654 Mdot
.68009 .58908 Mdot
.68345 .59712 Mdot
.52884 .18316 Mdot
.43885 .61801 Mdot
.3706 .29569 Mdot
.6738 .60111 Mdot
.64367 .57235 Mdot
.50544 .31494 Mdot
.43903 .57169 Mdot
.25393 .64577 Mdot
.62075 .41254 Mdot
.64755 .41722 Mdot
.63316 .57278 Mdot
.43311 .6657 Mdot
.62271 .41947 Mdot
.61955 .6869 Mdot
.42123 .33711 Mdot
.34636 .236 Mdot
.66008 .56668 Mdot
.51342 .41517 Mdot
.64705 .39394 Mdot
.68853 .77384 Mdot
.38709 .34602 Mdot
.41024 .58721 Mdot
.44615 .62155 Mdot
.26674 .47398 Mdot
.49961 .62524 Mdot
.39772 .31632 Mdot
.62835 .37387 Mdot
.4231 .78017 Mdot
.67086 .59664 Mdot
.4302 .59954 Mdot
.61523 .50927 Mdot
.76017 .48504 Mdot
.60114 .27456 Mdot
.63919 .58389 Mdot
.65493 .59902 Mdot
.43854 .38735 Mdot
.47202 .3883 Mdot
.46096 .59395 Mdot
.61264 .40174 Mdot
.63314 .55567 Mdot
.65874 .38807 Mdot
.4363 .37951 Mdot
.44662 .34535 Mdot
.40602 .34446 Mdot
.40966 .64316 Mdot
.45647 .34832 Mdot
.25786 .36435 Mdot
.67034 .45955 Mdot
.60029 .58295 Mdot
.74471 .28521 Mdot
.76135 .45779 Mdot
.38475 .5131 Mdot
.27564 .49245 Mdot
.4066 .32055 Mdot
.61607 .35973 Mdot
.47333 .5857 Mdot
.45882 .61364 Mdot
.49331 .40478 Mdot
.60061 .38586 Mdot
.301 .46629 Mdot
.59928 .3902 Mdot
.28698 .48581 Mdot
.38005 .30626 Mdot
.45379 .55546 Mdot
.47123 .63225 Mdot
.62776 .37117 Mdot
.45069 .34308 Mdot
.44606 .36552 Mdot
.3175 .4863 Mdot
.38133 .48972 Mdot
.43358 .37169 Mdot
.65963 .56731 Mdot
.6029 .72641 Mdot
.45344 .40267 Mdot
.43057 .60889 Mdot
.22709 .52089 Mdot
.60849 .65876 Mdot
.45146 .64889 Mdot
.53903 .37847 Mdot
.17005 .51482 Mdot
.41544 .62074 Mdot
.16459 .48154 Mdot
.55692 .36053 Mdot
.68038 .58453 Mdot
.46601 .39398 Mdot
.39472 .31583 Mdot
.54542 .58827 Mdot
.2793 .43701 Mdot
.51085 .59537 Mdot
.67823 .59935 Mdot
.69389 .59296 Mdot
.6323 .22824 Mdot
.407 .8031 Mdot
.30575 .49222 Mdot
.30345 .48183 Mdot
.43164 .34727 Mdot
.26391 .71474 Mdot
.37283 .61997 Mdot
.30612 .47104 Mdot
.34756 .70377 Mdot
.48306 .58711 Mdot
.27923 .57415 Mdot
.38478 .35746 Mdot
.62948 .57993 Mdot
.41292 .70075 Mdot
.43772 .35041 Mdot
.67531 .56877 Mdot
.69459 .41859 Mdot
.5 .58285 Mdot
.67393 .59337 Mdot
.65929 .39466 Mdot
.54711 .22615 Mdot
.65393 .61199 Mdot
.22325 .5134 Mdot
.61352 .39863 Mdot
.49155 .27349 Mdot
.33218 .67798 Mdot
.55628 .12081 Mdot
.62071 .37658 Mdot
.42671 .32674 Mdot
.41616 .34265 Mdot
.4325 .35472 Mdot
.67978 .57397 Mdot
.45554 .33535 Mdot
.66496 .56068 Mdot
.2965 .7104 Mdot
.38073 .49072 Mdot
.30848 .47619 Mdot
.56442 .40361 Mdot
.64618 .59608 Mdot
.43064 .20294 Mdot
.64773 .18277 Mdot
.46471 .62346 Mdot
.64126 .35699 Mdot
.30922 .48611 Mdot
.46095 .85623 Mdot
.26897 .46773 Mdot
.49717 .39982 Mdot
.31365 .25306 Mdot
.43508 .59464 Mdot
.59669 .77336 Mdot
.28012 .49218 Mdot
.63113 .59077 Mdot
.45405 .58007 Mdot
.62921 .31767 Mdot
.27261 .47477 Mdot
.25775 .46845 Mdot
.46292 .58996 Mdot
.631 .60476 Mdot
.44614 .34867 Mdot
.60299 .3661 Mdot
.32375 .46566 Mdot
.53874 .55361 Mdot
.49456 .62858 Mdot
.50044 .59732 Mdot
.59077 .46795 Mdot
.33747 .6228 Mdot
.6276 .37541 Mdot
.30876 .6973 Mdot
.47132 .38754 Mdot
.46477 .28111 Mdot
.54126 .18728 Mdot
.55211 .38813 Mdot
.40803 .33628 Mdot
.40468 .32617 Mdot
.47081 .59642 Mdot
.3368 .62726 Mdot
.27281 .30107 Mdot
.60135 .43504 Mdot
.44456 .39834 Mdot
.43765 .35868 Mdot
.69496 .57204 Mdot
.63596 .22579 Mdot
.51447 .58089 Mdot
.64894 .42348 Mdot
.43974 .37827 Mdot
.65014 .76022 Mdot
.28066 .47381 Mdot
.39342 .21775 Mdot
.44025 .55878 Mdot
.4105 .60185 Mdot
.63541 .38195 Mdot
.66001 .40173 Mdot
.65973 .32804 Mdot
.60753 .20743 Mdot
.21209 .59753 Mdot
.78266 .44346 Mdot
.65235 .75398 Mdot
.68779 .55483 Mdot
.61387 .58005 Mdot
.58003 .34273 Mdot
.66242 .37534 Mdot
.42012 .62255 Mdot
.63102 .55701 Mdot
.57968 .26572 Mdot
.69048 .62143 Mdot
.29229 .58062 Mdot
.32024 .32123 Mdot
.48826 .56683 Mdot
.62715 .56849 Mdot
.67727 .57939 Mdot
.62573 .55536 Mdot
.55749 .36115 Mdot
.45095 .59722 Mdot
.42403 .5732 Mdot
.40748 .6165 Mdot
.50667 .53896 Mdot
.45135 .62954 Mdot
.5899 .42967 Mdot
.55983 .46938 Mdot
.47786 .80595 Mdot
.44846 .65253 Mdot
.63333 .42074 Mdot
.50304 .60319 Mdot
.26707 .45705 Mdot
.47511 .58237 Mdot
.29502 .57551 Mdot
.63768 .39687 Mdot
.57131 .56795 Mdot
.77869 .43505 Mdot
.44175 .55983 Mdot
.25557 .46257 Mdot
.38788 .52471 Mdot
.76687 .58326 Mdot
.34276 .50576 Mdot
.65839 .56695 Mdot
.41458 .33233 Mdot
.60586 .37074 Mdot
.43958 .34237 Mdot
.42965 .65219 Mdot
.53738 .38076 Mdot
.71011 .5082 Mdot
.50724 .41755 Mdot
.42992 .6358 Mdot
.37354 .6457 Mdot
.65115 .56854 Mdot
.43598 .32859 Mdot
.68616 .54568 Mdot
.42987 .62345 Mdot
.29156 .46954 Mdot
.27454 .47794 Mdot
.7042 .35113 Mdot
.69026 .73898 Mdot
.75576 .38571 Mdot
.63447 .37968 Mdot
.45714 .37393 Mdot
.29606 .49914 Mdot
.50479 .52495 Mdot
.67001 .40246 Mdot
.60644 .39426 Mdot
.61858 .39856 Mdot
.49357 .60674 Mdot
.4013 .31903 Mdot
.47083 .7982 Mdot
.39835 .31541 Mdot
.44929 .56072 Mdot
.46108 .38367 Mdot
.40408 .33332 Mdot
.26882 .47879 Mdot
.62375 .3632 Mdot
.44168 .38407 Mdot
.47409 .62482 Mdot
.65859 .60708 Mdot
.41905 .46957 Mdot
.28288 .53348 Mdot
.45332 .82493 Mdot
.47501 .82932 Mdot
.62645 .60764 Mdot
.6679 .77701 Mdot
.63481 .43086 Mdot
.57923 .64665 Mdot
.54737 .33352 Mdot
.46284 .64146 Mdot
.45927 .17897 Mdot
.4448 .39313 Mdot
.43445 .32684 Mdot
.47907 .60682 Mdot
.43946 .31785 Mdot
.43342 .60058 Mdot
.45872 .38865 Mdot
.31035 .51396 Mdot
.4975 .55098 Mdot
.45227 .33976 Mdot
.39198 .63035 Mdot
.44574 .56795 Mdot
.62818 .57913 Mdot
.47534 .39434 Mdot
.40815 .63433 Mdot
.37018 .82356 Mdot
.66241 .39188 Mdot
.54383 .37367 Mdot
.20313 .49661 Mdot
.62074 .37269 Mdot
.6689 .59302 Mdot
.5049 .6267 Mdot
.27026 .46104 Mdot
.63832 .59801 Mdot
.23445 .49511 Mdot
.28588 .49249 Mdot
.45121 .18848 Mdot
.65236 .56516 Mdot
.45751 .40403 Mdot
.26614 .4796 Mdot
.383 .58175 Mdot
.48524 .39181 Mdot
.41331 .48546 Mdot
.40762 .32691 Mdot
.45202 .60602 Mdot
.61478 .31313 Mdot
.66287 .3841 Mdot
.4218 .58312 Mdot
.47922 .37262 Mdot
.57377 .3453 Mdot
.49322 .59937 Mdot
.47561 .59038 Mdot
.69208 .26968 Mdot
.38517 .24262 Mdot
.29016 .4552 Mdot
.68854 .57794 Mdot
.47253 .62135 Mdot
.26415 .48132 Mdot
.30313 .39588 Mdot
.49942 .60978 Mdot
.66598 .54804 Mdot
.37733 .56183 Mdot
.47829 .38062 Mdot
.63333 .36441 Mdot
.51265 .3904 Mdot
.25816 .47603 Mdot
.21714 .29669 Mdot
.40596 .34678 Mdot
.39247 .62403 Mdot
.4175 .63452 Mdot
.61079 .28674 Mdot
.67554 .57254 Mdot
.21556 .59794 Mdot
.44647 .6189 Mdot
.40846 .52852 Mdot
.42176 .59386 Mdot
.43571 .3008 Mdot
.64173 .57481 Mdot
.44493 .60564 Mdot
.58594 .52308 Mdot
.38335 .59472 Mdot
.25533 .46877 Mdot
.35582 .74404 Mdot
.49457 .62247 Mdot
.89028 .46165 Mdot
.36921 .31257 Mdot
.45402 .34199 Mdot
.62903 .30784 Mdot
.17933 .62452 Mdot
.74992 .36854 Mdot
.66517 .55974 Mdot
.74417 .56523 Mdot
.44321 .34563 Mdot
.77905 .40545 Mdot
.65135 .79627 Mdot
.4493 .56734 Mdot
.49605 .57979 Mdot
.4972 .39981 Mdot
.39759 .30843 Mdot
.47187 .40781 Mdot
.44331 .65481 Mdot
.37141 .60779 Mdot
.46103 .3563 Mdot
.46707 .62969 Mdot
.40786 .54017 Mdot
.60705 .36266 Mdot
.63359 .60905 Mdot
.6517 .38809 Mdot
.61256 .36861 Mdot
.55019 .6933 Mdot
.60773 .21236 Mdot
.66049 .38511 Mdot
.63571 .43002 Mdot
.28245 .56855 Mdot
.37905 .68008 Mdot
.26265 .48893 Mdot
.59695 .81772 Mdot
.42927 .35386 Mdot
.44941 .59522 Mdot
.61948 .60607 Mdot
.5527 .67345 Mdot
.37222 .37187 Mdot
.28536 .28096 Mdot
.42573 .62397 Mdot
.43921 .35449 Mdot
.55924 .35681 Mdot
.45302 .53212 Mdot
.47738 .29168 Mdot
.40846 .59901 Mdot
.48985 .39702 Mdot
.58008 .7582 Mdot
.61262 .51798 Mdot
.43997 .25638 Mdot
.70611 .56946 Mdot
.41699 .60937 Mdot
.66474 .56773 Mdot
.648 .38401 Mdot
.26274 .46474 Mdot
.28958 .45585 Mdot
.46265 .58565 Mdot
.351 .58712 Mdot
.39172 .36791 Mdot
.44372 .56662 Mdot
.468 .57496 Mdot
.557 .36019 Mdot
.46522 .5745 Mdot
.41579 .63239 Mdot
.40935 .62536 Mdot
.39366 .58418 Mdot
.65438 .41574 Mdot
.61027 .51275 Mdot
.41804 .6513 Mdot
.43603 .53148 Mdot
.59398 .37528 Mdot
.75524 .55845 Mdot
.621 .36178 Mdot
.73563 .70674 Mdot
.64772 .40151 Mdot
.30065 .46161 Mdot
.60214 .31245 Mdot
.3514 .61092 Mdot
.60991 .5728 Mdot
.66988 .38681 Mdot
.29512 .47935 Mdot
.63709 .3748 Mdot
.46548 .38258 Mdot
.81708 .40544 Mdot
.68483 .62383 Mdot
.20796 .56878 Mdot
.70026 .34485 Mdot
.45747 .24077 Mdot
.42534 .37402 Mdot
.63707 .57413 Mdot
.65468 .71801 Mdot
.40528 .62407 Mdot
.26852 .48334 Mdot
.46515 .59304 Mdot
.65781 .41393 Mdot
.4352 .35203 Mdot
.34145 .74275 Mdot
.27811 .45588 Mdot
.70324 .2644 Mdot
.43462 .36183 Mdot
.40156 .60086 Mdot
.64858 .42332 Mdot
.73463 .26957 Mdot
.65307 .38376 Mdot
.35589 .50599 Mdot
.64614 .54085 Mdot
.4121 .72596 Mdot
.65274 .59403 Mdot
.41125 .37184 Mdot
.8553 .47103 Mdot
.54883 .83574 Mdot
.64343 .60715 Mdot
.4037 .26917 Mdot
.4957 .58343 Mdot
.50129 .59908 Mdot
.59654 .53617 Mdot
.67812 .56006 Mdot
.46198 .62613 Mdot
.54669 .36804 Mdot
.6905 .45486 Mdot
.36741 .27991 Mdot
.41556 .3295 Mdot
.4357 .60615 Mdot
.59662 .36932 Mdot
.60002 .39195 Mdot
.39901 .31952 Mdot
.62462 .35967 Mdot
.42344 .57439 Mdot
.64849 .59509 Mdot
.48453 .41594 Mdot
.28361 .46111 Mdot
.36518 .80123 Mdot
.28826 .50053 Mdot
.40937 .34013 Mdot
.42586 .55058 Mdot
.447 .34517 Mdot
.11978 .49907 Mdot
.41447 .58309 Mdot
.67646 .59605 Mdot
.48539 .5981 Mdot
.41651 .60451 Mdot
.49973 .58629 Mdot
.46442 .36592 Mdot
.18472 .54067 Mdot
.46991 .62848 Mdot
.62286 .39113 Mdot
.50841 .82073 Mdot
.50364 .59919 Mdot
.33029 .50765 Mdot
.31036 .63042 Mdot
.46105 .22993 Mdot
.60493 .58547 Mdot
.44085 .33109 Mdot
.66519 .60092 Mdot
.69993 .60574 Mdot
.66914 .59269 Mdot
.52245 .80737 Mdot
.63751 .7294 Mdot
.18077 .4887 Mdot
.42891 .74952 Mdot
.53159 .67085 Mdot
.68576 .56855 Mdot
.28388 .40994 Mdot
.61673 .56949 Mdot
.6725 .57127 Mdot
.63363 .87862 Mdot
.61083 .58066 Mdot
.43644 .61284 Mdot
.50227 .56941 Mdot
.73857 .48437 Mdot
.2598 .57071 Mdot
.46135 .5776 Mdot
.47757 .61546 Mdot
.26273 .46943 Mdot
.35859 .56316 Mdot
.53771 .38079 Mdot
.46107 .19111 Mdot
.77704 .48887 Mdot
.46539 .59146 Mdot
.47429 .62169 Mdot
.37395 .60581 Mdot
.82403 .34556 Mdot
.57742 .6782 Mdot
.68788 .56796 Mdot
.42464 .66858 Mdot
.44106 .83225 Mdot
.41994 .57161 Mdot
.49209 .61962 Mdot
.48932 .57049 Mdot
.44253 .3459 Mdot
.67634 .54908 Mdot
.41701 .66614 Mdot
.46451 .21231 Mdot
.45295 .55747 Mdot
.55709 .39274 Mdot
.19568 .6128 Mdot
.44125 .6101 Mdot
.61567 .55815 Mdot
.48553 .58032 Mdot
.65054 .56336 Mdot
.62346 .58428 Mdot
.39894 .56596 Mdot
.59848 .79087 Mdot
.65268 .54319 Mdot
.45355 .55976 Mdot
.45364 .35319 Mdot
.57924 .83573 Mdot
.45212 .60821 Mdot
.29672 .45335 Mdot
.44503 .62037 Mdot
.26281 .45378 Mdot
.46403 .56969 Mdot
.39945 .31531 Mdot
.65789 .65911 Mdot
.42975 .34415 Mdot
.22926 .64131 Mdot
.40417 .30586 Mdot
.68976 .26671 Mdot
.67208 .55366 Mdot
.58151 .3385 Mdot
.25237 .28864 Mdot
.54092 .37552 Mdot
.58504 .49668 Mdot
.53749 .49072 Mdot
.61167 .4009 Mdot
.67786 .60534 Mdot
.29348 .66841 Mdot
.59353 .27468 Mdot
.59102 .30192 Mdot
.41281 .35417 Mdot
.26738 .25616 Mdot
.32501 .2352 Mdot
.48188 .62185 Mdot
.56755 .79104 Mdot
.49285 .74993 Mdot
.49769 .6131 Mdot
.49766 .63821 Mdot
.48331 .37397 Mdot
.42105 .63643 Mdot
.62313 .48531 Mdot
.42084 .35748 Mdot
.29363 .48249 Mdot
.67006 .57348 Mdot
.28256 .44708 Mdot
.59463 .28358 Mdot
.54044 .49487 Mdot
.45112 .38543 Mdot
.38611 .59523 Mdot
.48496 .60466 Mdot
.63115 .57089 Mdot
.64314 .53001 Mdot
.62359 .5984 Mdot
.31117 .48581 Mdot
.42294 .35755 Mdot
.5806 .66833 Mdot
.47249 .61321 Mdot
.64347 .5902 Mdot
.69753 .37355 Mdot
.47089 .61921 Mdot
.63566 .37025 Mdot
.48472 .5616 Mdot
.64919 .6091 Mdot
.46489 .57424 Mdot
.6493 .59663 Mdot
.42043 .33562 Mdot
.41923 .57012 Mdot
.47705 .60414 Mdot
.73293 .27351 Mdot
.29924 .46448 Mdot
.67479 .55722 Mdot
.46873 .43917 Mdot
.40066 .6147 Mdot
.5265 .26537 Mdot
.41959 .61418 Mdot
.7147 .61261 Mdot
.38868 .62079 Mdot
.56348 .35425 Mdot
.51513 .57374 Mdot
.4511 .60764 Mdot
.55086 .51369 Mdot
.49673 .77002 Mdot
.66394 .53204 Mdot
.64208 .42408 Mdot
.62564 .55192 Mdot
.34113 .33499 Mdot
.44831 .39806 Mdot
.46161 .34055 Mdot
.23726 .58132 Mdot
.41595 .55837 Mdot
.43703 .59464 Mdot
.63148 .34989 Mdot
.29679 .48575 Mdot
.63883 .58571 Mdot
.28906 .48493 Mdot
.50661 .1919 Mdot
.30211 .49051 Mdot
.39575 .31605 Mdot
.38186 .29018 Mdot
.61992 .6712 Mdot
.26295 .47043 Mdot
.62648 .60321 Mdot
.31216 .32709 Mdot
.44912 .64518 Mdot
.24184 .44736 Mdot
.28983 .46927 Mdot
.26624 .24938 Mdot
.42341 .63454 Mdot
.59118 .49203 Mdot
.65298 .37385 Mdot
.2744 .48277 Mdot
.62507 .40445 Mdot
.46327 .58061 Mdot
.50367 .24389 Mdot
.66835 .55842 Mdot
.59332 .39696 Mdot
.47102 .65448 Mdot
.30875 .48408 Mdot
.44222 .37841 Mdot
.58339 .36202 Mdot
.62974 .41973 Mdot
.76039 .6107 Mdot
.33977 .73249 Mdot
.42204 .35592 Mdot
.32115 .27924 Mdot
.62755 .41217 Mdot
.49362 .62016 Mdot
.39056 .54027 Mdot
.41061 .58566 Mdot
.62567 .31416 Mdot
.44063 .33021 Mdot
.69707 .4748 Mdot
.48683 .6033 Mdot
.41835 .62579 Mdot
.59539 .56993 Mdot
.41994 .34292 Mdot
.65803 .57964 Mdot
.61894 .55903 Mdot
.41925 .33585 Mdot
.65978 .59135 Mdot
.27672 .49021 Mdot
.70417 .44204 Mdot
.63061 .41379 Mdot
.62657 .39203 Mdot
.43666 .35768 Mdot
.45805 .34774 Mdot
.44557 .34185 Mdot
.4838 .56112 Mdot
.63942 .58025 Mdot
.47712 .56589 Mdot
.49846 .58426 Mdot
.68028 .53362 Mdot
.61133 .59635 Mdot
.48916 .57748 Mdot
.45531 .25957 Mdot
.23923 .45923 Mdot
.45746 .35761 Mdot
.6577 .37917 Mdot
.80261 .46083 Mdot
.58679 .37731 Mdot
.4328 .60551 Mdot
.60431 .227 Mdot
.63575 .60473 Mdot
.26747 .47128 Mdot
.24665 .46263 Mdot
.27277 .46154 Mdot
.64817 .34936 Mdot
.6472 .55161 Mdot
.45933 .19166 Mdot
.43533 .60286 Mdot
.59156 .46748 Mdot
.30216 .68162 Mdot
.51321 .20025 Mdot
.65981 .38206 Mdot
.47338 .61933 Mdot
.51367 .39822 Mdot
.66262 .69941 Mdot
.41036 .59849 Mdot
.41711 .6422 Mdot
.52478 .33413 Mdot
.38826 .55438 Mdot
.64969 .54155 Mdot
.60358 .20103 Mdot
.50387 .57793 Mdot
.62471 .52411 Mdot
.26307 .74605 Mdot
.42565 .60517 Mdot
.43343 .62722 Mdot
.4626 .60714 Mdot
.4835 .58934 Mdot
.6175 .55509 Mdot
.26874 .62329 Mdot
.65456 .42039 Mdot
.56329 .45086 Mdot
.6297 .41522 Mdot
.4892 .398 Mdot
.61856 .49989 Mdot
.66897 .61238 Mdot
.26637 .47303 Mdot
.73294 .64767 Mdot
.54372 .17747 Mdot
.43837 .38779 Mdot
.61249 .6996 Mdot
.29046 .46386 Mdot
.48779 .63205 Mdot
.27665 .44577 Mdot
.40252 .31121 Mdot
.61616 .39332 Mdot
.49529 .55299 Mdot
.61599 .58749 Mdot
.65792 .61136 Mdot
.46355 .62434 Mdot
.47388 .84783 Mdot
.63462 .36812 Mdot
.60883 .4299 Mdot
.49498 .59683 Mdot
.41832 .64365 Mdot
.66202 .57958 Mdot
.45216 .36335 Mdot
.23373 .38138 Mdot
.3019 .47492 Mdot
.39772 .59613 Mdot
.48129 .58605 Mdot
.60145 .20567 Mdot
.6158 .37101 Mdot
.4123 .36644 Mdot
.49246 .60806 Mdot
.69983 .3251 Mdot
.49254 .60611 Mdot
.46789 .53281 Mdot
.45041 .35207 Mdot
.39047 .64111 Mdot
.47121 .63094 Mdot
.48055 .66336 Mdot
.62589 .40937 Mdot
.67586 .59139 Mdot
.60169 .56485 Mdot
.50128 .40504 Mdot
.63752 .37166 Mdot
.48815 .57919 Mdot
.61952 .36956 Mdot
.50149 .60936 Mdot
.46037 .6297 Mdot
.66018 .38656 Mdot
.65828 .58023 Mdot
.73538 .53231 Mdot
.6119 .50913 Mdot
.48571 .59277 Mdot
.50981 .57381 Mdot
.2491 .58177 Mdot
.18165 .40673 Mdot
.425 .6212 Mdot
.65354 .61016 Mdot
.47549 .61121 Mdot
.63283 .403 Mdot
.29653 .49117 Mdot
.65544 .60812 Mdot
.44904 .36907 Mdot
.42842 .37981 Mdot
.77737 .43069 Mdot
.40335 .32473 Mdot
.46572 .64347 Mdot
.66108 .63574 Mdot
.63035 .61666 Mdot
.30468 .77271 Mdot
.41742 .3366 Mdot
.25535 .47931 Mdot
.47187 .58764 Mdot
.64231 .25555 Mdot
.63959 .35031 Mdot
.89268 .44547 Mdot
.45332 .19009 Mdot
.29292 .50142 Mdot
.27294 .28429 Mdot
.48696 .40649 Mdot
.45157 .63623 Mdot
.26331 .4628 Mdot
.45044 .39224 Mdot
.47347 .6368 Mdot
.53522 .58792 Mdot
.20473 .57929 Mdot
.49922 .38897 Mdot
.62495 .36564 Mdot
.47228 .3667 Mdot
.28774 .44185 Mdot
.39625 .31585 Mdot
.65476 .6133 Mdot
.44852 .60438 Mdot
.38458 .65854 Mdot
.45255 .36733 Mdot
.39699 .31338 Mdot
.48491 .56408 Mdot
.6804 .60035 Mdot
.44765 .32345 Mdot
.459 .58676 Mdot
.56499 .64974 Mdot
.70469 .56799 Mdot
.42783 .36389 Mdot
.41368 .62597 Mdot
.36628 .6634 Mdot
.44096 .36343 Mdot
.45913 .3604 Mdot
.46321 .62596 Mdot
.27281 .48859 Mdot
.44345 .55673 Mdot
.65114 .39901 Mdot
.18303 .55943 Mdot
.63057 .40157 Mdot
.33464 .35117 Mdot
.40426 .55354 Mdot
.49093 .2525 Mdot
.64487 .61477 Mdot
.28016 .44114 Mdot
.80867 .45664 Mdot
.43042 .65048 Mdot
.66308 .77389 Mdot
.52479 .41401 Mdot
.42927 .83794 Mdot
.83025 .53627 Mdot
.28717 .47165 Mdot
.64182 .37789 Mdot
.43428 .62687 Mdot
.63649 .35428 Mdot
.27596 .4543 Mdot
.30996 .70683 Mdot
.41336 .62794 Mdot
.64366 .57325 Mdot
.46251 .55806 Mdot
.65839 .56654 Mdot
.46795 .62031 Mdot
.39853 .54719 Mdot
.57337 .33728 Mdot
.27726 .52247 Mdot
.45883 .64276 Mdot
.81468 .39653 Mdot
.385 .38253 Mdot
.29591 .47151 Mdot
.4668 .56209 Mdot
.43176 .38884 Mdot
.60194 .39411 Mdot
.46183 .50476 Mdot
.4453 .34646 Mdot
.64279 .36024 Mdot
.66604 .58597 Mdot
.41793 .33246 Mdot
.41412 .36416 Mdot
.44409 .66722 Mdot
.26216 .45588 Mdot
.61148 .39182 Mdot
.44754 .6093 Mdot
.42191 .63251 Mdot
.32442 .28772 Mdot
.36297 .38052 Mdot
.60091 .55785 Mdot
.69534 .23463 Mdot
.59952 .58972 Mdot
.30497 .47111 Mdot
.44974 .34919 Mdot
.42468 .6185 Mdot
.42467 .58033 Mdot
.58776 .33175 Mdot
.67679 .56158 Mdot
.50316 .39288 Mdot
.57258 .69451 Mdot
.42451 .318 Mdot
.28761 .61321 Mdot
.67608 .60016 Mdot
.28523 .61103 Mdot
.28661 .44216 Mdot
.67163 .75117 Mdot
.30879 .54166 Mdot
.65095 .3711 Mdot
.28901 .61809 Mdot
.63121 .59292 Mdot
.48423 .61613 Mdot
.4613 .4046 Mdot
.40543 .33768 Mdot
.66739 .57704 Mdot
.49209 .40041 Mdot
.2737 .48089 Mdot
.4359 .62974 Mdot
.42429 .22015 Mdot
.74887 .44502 Mdot
.4592 .3722 Mdot
.49041 .53881 Mdot
.62165 .39942 Mdot
.45083 .63442 Mdot
.3005 .45511 Mdot
.61746 .3821 Mdot
.36387 .32064 Mdot
.69309 .46203 Mdot
.46154 .58299 Mdot
.65294 .24846 Mdot
.62922 .3716 Mdot
.24386 .32656 Mdot
.45698 .59081 Mdot
.6273 .41194 Mdot
.36733 .58635 Mdot
.50764 .20981 Mdot
.49507 .43217 Mdot
.64265 .80512 Mdot
.50475 .38755 Mdot
.47945 .4024 Mdot
.54599 .23389 Mdot
.57025 .2981 Mdot
.62775 .35433 Mdot
.39678 .31575 Mdot
.32877 .60449 Mdot
.62364 .40484 Mdot
.49664 .57976 Mdot
.42191 .61073 Mdot
.55 .68796 Mdot
.53055 .42899 Mdot
.3934 .3129 Mdot
.73928 .37464 Mdot
.4013 .61439 Mdot
.47061 .65875 Mdot
.43026 .58098 Mdot
.69464 .58746 Mdot
.61132 .38238 Mdot
.76141 .31441 Mdot
.6425 .37348 Mdot
.38224 .22832 Mdot
.4297 .35313 Mdot
.45236 .33551 Mdot
.43784 .60915 Mdot
.45867 .24757 Mdot
.33989 .67393 Mdot
.42793 .5711 Mdot
.48809 .27082 Mdot
.35329 .74919 Mdot
.47364 .65456 Mdot
.64421 .54035 Mdot
.48368 .54604 Mdot
.69243 .60511 Mdot
.62375 .41513 Mdot
.27934 .47106 Mdot
.29316 .43861 Mdot
.61249 .39093 Mdot
.43708 .59305 Mdot
.49929 .27715 Mdot
.41598 .59706 Mdot
.48751 .61666 Mdot
.38487 .21748 Mdot
.29758 .49959 Mdot
.44031 .33587 Mdot
.28529 .45503 Mdot
.67268 .57017 Mdot
.8587 .66336 Mdot
.29408 .48723 Mdot
.35423 .68275 Mdot
.25551 .66068 Mdot
.28667 .61783 Mdot
.66282 .61083 Mdot
.31937 .46493 Mdot
.63473 .36565 Mdot
.48815 .8696 Mdot
.17419 .42711 Mdot
.58657 .39973 Mdot
.45091 .58449 Mdot
.67453 .61173 Mdot
.62283 .60317 Mdot
.59846 .40614 Mdot
.62539 .58693 Mdot
.36957 .63398 Mdot
.48915 .60417 Mdot
.6325 .35517 Mdot
.74523 .47009 Mdot
.6289 .41988 Mdot
.69843 .4309 Mdot
.46767 .56054 Mdot
.67088 .60423 Mdot
.46768 .54466 Mdot
.64263 .62888 Mdot
.41095 .36521 Mdot
.49191 .62805 Mdot
.27034 .47916 Mdot
.57363 .44537 Mdot
.42683 .35933 Mdot
.60336 .22882 Mdot
.63384 .56939 Mdot
.6831 .35598 Mdot
.62691 .58064 Mdot
.68674 .60102 Mdot
.6116 .36896 Mdot
.64849 .55512 Mdot
.43321 .62805 Mdot
.4283 .26454 Mdot
.64523 .56139 Mdot
.63823 .38869 Mdot
.27544 .46722 Mdot
.65891 .58802 Mdot
.4857 .37532 Mdot
.47719 .59588 Mdot
.4657 .38858 Mdot
.57649 .32927 Mdot
.68376 .59779 Mdot
.32038 .4724 Mdot
.44116 .32853 Mdot
.26342 .45683 Mdot
.3406 .75785 Mdot
.66369 .37709 Mdot
.29112 .28033 Mdot
.3701 .66395 Mdot
.61543 .59093 Mdot
.57427 .3332 Mdot
.42722 .61742 Mdot
.47742 .59403 Mdot
.30383 .44795 Mdot
.62218 .60279 Mdot
.54509 .84139 Mdot
.72778 .60386 Mdot
.70333 .45305 Mdot
.66731 .38264 Mdot
.72494 .28979 Mdot
.65731 .46424 Mdot
.25193 .69257 Mdot
.42093 .6599 Mdot
.48553 .40662 Mdot
.42884 .59593 Mdot
.81058 .471 Mdot
.30976 .4849 Mdot
.22961 .40952 Mdot
.3899 .57554 Mdot
.4322 .33357 Mdot
.46522 .60009 Mdot
.47294 .48712 Mdot
.46568 .53926 Mdot
.27503 .49146 Mdot
.56769 .41194 Mdot
.61166 .5695 Mdot
.28613 .46145 Mdot
.42021 .36653 Mdot
.32243 .65765 Mdot
.46318 .63969 Mdot
.43172 .65421 Mdot
.42099 .3156 Mdot
.63853 .5747 Mdot
.48098 .39685 Mdot
.62998 .41365 Mdot
.28038 .47873 Mdot
.47569 .58717 Mdot
.38417 .60991 Mdot
.52836 .26723 Mdot
.60918 .3889 Mdot
.43352 .32139 Mdot
.65152 .38264 Mdot
.47588 .40658 Mdot
.50406 .56352 Mdot
.45347 .33567 Mdot
.44406 .63936 Mdot
.77962 .38028 Mdot
.37794 .2227 Mdot
.51456 .77485 Mdot
.43142 .3309 Mdot
.30182 .60456 Mdot
.63911 .39793 Mdot
.64934 .39793 Mdot
.41646 .72069 Mdot
.36401 .54481 Mdot
.34753 .30356 Mdot
.76608 .60843 Mdot
.63167 .41444 Mdot
.62966 .39805 Mdot
.46231 .39288 Mdot
.65215 .55623 Mdot
.67943 .61315 Mdot
.48953 .40277 Mdot
.2223 .5199 Mdot
.63894 .5858 Mdot
.64422 .7857 Mdot
.35163 .31908 Mdot
.4666 .66235 Mdot
.64368 .32411 Mdot
.27499 .47584 Mdot
.23216 .52044 Mdot
.4871 .49195 Mdot
.42176 .62587 Mdot
.61459 .20836 Mdot
.44795 .35961 Mdot
.2489 .612 Mdot
.73845 .70221 Mdot
.41253 .62893 Mdot
.45155 .59428 Mdot
.4327 .5883 Mdot
.30943 .49431 Mdot
.67754 .64444 Mdot
.42414 .63139 Mdot
.21769 .51611 Mdot
.39935 .6115 Mdot
.34336 .51913 Mdot
.28876 .45544 Mdot
.51055 .65806 Mdot
.53968 .36195 Mdot
.46788 .20443 Mdot
.54521 .61283 Mdot
.63566 .41128 Mdot
.52539 .38569 Mdot
.61922 .41028 Mdot
.51489 .80374 Mdot
.30612 .5448 Mdot
.63372 .5396 Mdot
.42562 .62636 Mdot
.41057 .34329 Mdot
.62733 .60539 Mdot
.55209 .26156 Mdot
.6943 .84435 Mdot
.61234 .41068 Mdot
.12861 .49852 Mdot
.65241 .39146 Mdot
.40893 .35556 Mdot
.66358 .57968 Mdot
.6267 .73475 Mdot
.59461 .46972 Mdot
.65773 .59059 Mdot
.71965 .5156 Mdot
.6068 .61071 Mdot
.29754 .61461 Mdot
.6176 .61093 Mdot
.63982 .39159 Mdot
.61377 .34617 Mdot
.48427 .65597 Mdot
.43572 .6163 Mdot
.53457 .49362 Mdot
.35945 .67474 Mdot
.43175 .61757 Mdot
.42068 .35657 Mdot
.23683 .32732 Mdot
.49909 .40139 Mdot
.62208 .5672 Mdot
.63049 .42445 Mdot
.45453 .59568 Mdot
.49009 .59533 Mdot
.47244 .63481 Mdot
.71003 .23869 Mdot
.62696 .79296 Mdot
.47034 .62781 Mdot
.4013 .58309 Mdot
.42201 .33412 Mdot
.32203 .50161 Mdot
.81387 .50284 Mdot
.34024 .55562 Mdot
.40587 .60065 Mdot
.29297 .45905 Mdot
.26914 .49464 Mdot
.47254 .63787 Mdot
.4472 .22477 Mdot
.41923 .2633 Mdot
.44807 .60936 Mdot
.35207 .52214 Mdot
.58628 .2829 Mdot
.3972 .31862 Mdot
.44955 .36651 Mdot
.61536 .55918 Mdot
.40908 .34449 Mdot
.404 .30513 Mdot
.6349 .71782 Mdot
.52379 .39248 Mdot
.63063 .45221 Mdot
.31136 .48562 Mdot
.42033 .58409 Mdot
.59886 .59562 Mdot
.61025 .31908 Mdot
.61174 .39855 Mdot
.64975 .60368 Mdot
.60231 .39801 Mdot
.29027 .50391 Mdot
.21917 .58544 Mdot
.40465 .33767 Mdot
.64004 .41333 Mdot
.69267 .46094 Mdot
.29195 .45791 Mdot
.63096 .36059 Mdot
.49988 .2569 Mdot
.50221 .59048 Mdot
.65466 .74423 Mdot
.43812 .56531 Mdot
.47604 .85543 Mdot
.63022 .36126 Mdot
.56394 .35543 Mdot
.44055 .59828 Mdot
.43499 .3613 Mdot
.38419 .56465 Mdot
.40797 .59814 Mdot
.44961 .37326 Mdot
.48209 .6211 Mdot
.28922 .44992 Mdot
.70341 .59281 Mdot
.53729 .40205 Mdot
.43874 .14948 Mdot
.26836 .45203 Mdot
.54386 .26037 Mdot
.42507 .62226 Mdot
.34165 .7407 Mdot
.65718 .58813 Mdot
.41611 .63839 Mdot
.44176 .7006 Mdot
.65912 .5602 Mdot
.66072 .60157 Mdot
.47509 .57402 Mdot
.64979 .37193 Mdot
.43284 .36412 Mdot
.28691 .45651 Mdot
.29934 .75143 Mdot
.44478 .57773 Mdot
.47664 .60731 Mdot
.28889 .46292 Mdot
.62971 .40011 Mdot
.48909 .59094 Mdot
.66037 .29523 Mdot
.38465 .82643 Mdot
.60549 .38939 Mdot
.49126 .56071 Mdot
.7089 .68172 Mdot
.64147 .63109 Mdot
.14719 .45793 Mdot
.24411 .49834 Mdot
.44521 .33457 Mdot
.38301 .55867 Mdot
.89084 .54127 Mdot
.27745 .47097 Mdot
.46293 .19789 Mdot
.4875 .61975 Mdot
.46868 .61175 Mdot
.62929 .60122 Mdot
.48341 .57031 Mdot
.67684 .567 Mdot
.38775 .17205 Mdot
.63979 .21052 Mdot
.64222 .56848 Mdot
.61301 .58318 Mdot
.38934 .69865 Mdot
.81361 .49664 Mdot
.67006 .58044 Mdot
.47365 .55229 Mdot
.55368 .82334 Mdot
.49692 .65302 Mdot
.30366 .44741 Mdot
.57378 .32166 Mdot
.57048 .5799 Mdot
.3743 .44546 Mdot
.7515 .57408 Mdot
.57029 .57219 Mdot
.39513 .35692 Mdot
.65318 .39908 Mdot
.4062 .61961 Mdot
.40366 .32968 Mdot
.45894 .33819 Mdot
.44936 .53781 Mdot
.41459 .59115 Mdot
.65451 .56368 Mdot
.29907 .49654 Mdot
.60283 .37434 Mdot
.47801 .61457 Mdot
.48952 .37601 Mdot
.29875 .48169 Mdot
.62686 .56585 Mdot
.40229 .7174 Mdot
.26222 .4858 Mdot
.4959 .54657 Mdot
.45085 .61966 Mdot
.48835 .56715 Mdot
.36629 .64824 Mdot
.66126 .40159 Mdot
.62109 .30259 Mdot
.46731 .55483 Mdot
.51211 .19051 Mdot
.38107 .48682 Mdot
.3842 .63266 Mdot
.63252 .58577 Mdot
.64702 .3515 Mdot
.41789 .37678 Mdot
.32024 .68112 Mdot
.45418 .5797 Mdot
.61997 .79473 Mdot
.57326 .68383 Mdot
.42648 .38292 Mdot
.68404 .56611 Mdot
.26784 .46899 Mdot
.42369 .57487 Mdot
.5341 .81507 Mdot
.42484 .60867 Mdot
.36224 .65209 Mdot
.4548 .35725 Mdot
.65472 .39825 Mdot
.41815 .83687 Mdot
.45884 .33834 Mdot
.66396 .60131 Mdot
.65623 .8023 Mdot
.65339 .61835 Mdot
.62159 .55992 Mdot
.58261 .80001 Mdot
.6576 .40648 Mdot
.8935 .52329 Mdot
.16736 .43224 Mdot
.37814 .60205 Mdot
.64003 .401 Mdot
.65978 .5719 Mdot
.44953 .63433 Mdot
.61959 .60859 Mdot
.66 .55269 Mdot
.50517 .6145 Mdot
.46033 .61774 Mdot
.60936 .5062 Mdot
.69639 .7442 Mdot
.26945 .46347 Mdot
.68029 .58893 Mdot
.51303 .68455 Mdot
.43273 .63636 Mdot
.43604 .60309 Mdot
.57592 .26942 Mdot
.27016 .48809 Mdot
.55496 .52107 Mdot
.49113 .61162 Mdot
.65655 .23217 Mdot
.49501 .54851 Mdot
.62192 .5504 Mdot
.60573 .3871 Mdot
.4486 .21783 Mdot
.62668 .31498 Mdot
.67858 .56392 Mdot
.31059 .46513 Mdot
.60259 .56081 Mdot
.35631 .68264 Mdot
.64251 .41763 Mdot
.64911 .6091 Mdot
.51263 .39127 Mdot
.6242 .38251 Mdot
.63282 .3615 Mdot
.51166 .82117 Mdot
.42511 .32269 Mdot
.31705 .47382 Mdot
.61627 .3967 Mdot
.57963 .64546 Mdot
.64174 .38461 Mdot
.51973 .69103 Mdot
.4259 .56589 Mdot
.21072 .54556 Mdot
.63841 .46642 Mdot
.35621 .62363 Mdot
.66459 .39281 Mdot
.27632 .45499 Mdot
.47936 .57988 Mdot
.62502 .58937 Mdot
.29039 .48661 Mdot
.60298 .34038 Mdot
.45908 .35433 Mdot
.62542 .578 Mdot
.65757 .41885 Mdot
.67907 .5923 Mdot
.28291 .65769 Mdot
.18897 .57556 Mdot
.66089 .28705 Mdot
.58925 .47116 Mdot
.47528 .63299 Mdot
.7753 .5589 Mdot
.5066 .61685 Mdot
.41234 .59558 Mdot
.42809 .36356 Mdot
.23627 .58213 Mdot
.65864 .57955 Mdot
.42282 .84144 Mdot
.64549 .40986 Mdot
.61475 .20212 Mdot
.70842 .56268 Mdot
.41164 .63743 Mdot
.65011 .56112 Mdot
.64162 .61813 Mdot
.48957 .77006 Mdot
.39657 .30246 Mdot
.5312 .59286 Mdot
.51691 .60135 Mdot
.41631 .65551 Mdot
.63244 .36217 Mdot
.58818 .22593 Mdot
.4846 .40007 Mdot
.1636 .53751 Mdot
.45714 .36234 Mdot
.49457 .31822 Mdot
.63979 .55629 Mdot
.28819 .49014 Mdot
.43808 .60463 Mdot
.71435 .56948 Mdot
.68273 .56833 Mdot
.24476 .48156 Mdot
.26973 .48124 Mdot
.545 .22034 Mdot
.66077 .38752 Mdot
.45013 .6437 Mdot
.41515 .62685 Mdot
.47233 .56522 Mdot
.43973 .56241 Mdot
.61201 .41087 Mdot
.49785 .59418 Mdot
.59936 .36495 Mdot
.57515 .65235 Mdot
.63142 .21162 Mdot
.52075 .39093 Mdot
.42762 .51109 Mdot
.61812 .58022 Mdot
.5825 .63793 Mdot
.50843 .55189 Mdot
.35355 .23357 Mdot
.40113 .79204 Mdot
.48264 .64587 Mdot
.46098 .39563 Mdot
.37312 .5408 Mdot
.40779 .31466 Mdot
.13532 .38956 Mdot
.52973 .27808 Mdot
.65228 .79202 Mdot
.43713 .63414 Mdot
.57945 .27083 Mdot
.46791 .52726 Mdot
.51166 .605 Mdot
.55479 .28467 Mdot
.73007 .34895 Mdot
.72742 .49446 Mdot
.26599 .49198 Mdot
.47118 .59241 Mdot
.62615 .61705 Mdot
.43232 .62917 Mdot
.43137 .60077 Mdot
.48698 .62247 Mdot
.6483 .42474 Mdot
.49474 .55354 Mdot
.48519 .56077 Mdot
.37893 .41235 Mdot
.28428 .57639 Mdot
.47455 .37171 Mdot
.3923 .72324 Mdot
.29488 .48559 Mdot
.64201 .56387 Mdot
.69043 .5175 Mdot
.65166 .37147 Mdot
.48684 .75963 Mdot
.47366 .55843 Mdot
.66116 .47231 Mdot
.65948 .41741 Mdot
.27947 .48056 Mdot
.45908 .40548 Mdot
.5992 .83327 Mdot
.40981 .33847 Mdot
.51746 .39695 Mdot
.42645 .35624 Mdot
.55454 .61766 Mdot
.65668 .56391 Mdot
.48233 .63045 Mdot
.61927 .39693 Mdot
.43675 .37022 Mdot
.25059 .57013 Mdot
.42974 .58253 Mdot
.42179 .33665 Mdot
.48407 .62845 Mdot
.20798 .5657 Mdot
.29392 .30446 Mdot
.40158 .3064 Mdot
.65988 .35556 Mdot
.62933 .38434 Mdot
.28046 .4911 Mdot
.63078 .56724 Mdot
.6315 .60054 Mdot
.61925 .38082 Mdot
.18357 .3844 Mdot
.40677 .60242 Mdot
.44339 .63517 Mdot
.51625 .18894 Mdot
.43633 .62327 Mdot
.31643 .64288 Mdot
.51168 .40097 Mdot
.62169 .5719 Mdot
.45963 .63259 Mdot
.48701 .59113 Mdot
.46681 .58534 Mdot
.27812 .65708 Mdot
.45533 .36647 Mdot
.40294 .60043 Mdot
.26174 .47587 Mdot
.41164 .37347 Mdot
.44334 .63617 Mdot
.41671 .6548 Mdot
.634 .60152 Mdot
.61305 .1888 Mdot
.65575 .38831 Mdot
.42568 .37285 Mdot
.44675 .33197 Mdot
.57609 .31838 Mdot
.64587 .52319 Mdot
.51008 .40165 Mdot
.17451 .56523 Mdot
.55431 .36374 Mdot
.29529 .46613 Mdot
.51474 .3602 Mdot
.36209 .47573 Mdot
.44177 .38682 Mdot
.60073 .40058 Mdot
.44758 .55734 Mdot
.40579 .59119 Mdot
.44347 .19087 Mdot
.40907 .637 Mdot
.27013 .47166 Mdot
.59367 .37257 Mdot
.63328 .59331 Mdot
.27618 .47999 Mdot
.65061 .39247 Mdot
.63654 .57636 Mdot
.50442 .59484 Mdot
.50072 .58031 Mdot
.65234 .60235 Mdot
.62638 .60385 Mdot
.4476 .61302 Mdot
.39275 .33912 Mdot
.61528 .56123 Mdot
.66386 .60786 Mdot
.40316 .33241 Mdot
.41201 .35189 Mdot
.41192 .66285 Mdot
.64453 .39713 Mdot
.49333 .57648 Mdot
.41014 .32745 Mdot
.29721 .49465 Mdot
.6546 .58339 Mdot
.48766 .59529 Mdot
.48235 .61326 Mdot
.28821 .45778 Mdot
.28418 .4979 Mdot
.27641 .48253 Mdot
.59127 .37237 Mdot
.45643 .56492 Mdot
.66936 .58487 Mdot
.65984 .39592 Mdot
.26846 .49442 Mdot
.25841 .45505 Mdot
.43525 .44651 Mdot
.42252 .61874 Mdot
.47943 .4322 Mdot
.85622 .6597 Mdot
.32321 .61845 Mdot
.41423 .37209 Mdot
.42127 .31821 Mdot
.26996 .59733 Mdot
.40774 .27341 Mdot
.6273 .36959 Mdot
.33241 .6225 Mdot
.28034 .4408 Mdot
.4938 .62319 Mdot
.50841 .57121 Mdot
.50123 .6349 Mdot
.28929 .48064 Mdot
.29764 .66396 Mdot
.63599 .61346 Mdot
.47666 .72693 Mdot
.29399 .48545 Mdot
.39792 .30577 Mdot
.44428 .32477 Mdot
.45718 .36176 Mdot
.50327 .56646 Mdot
.51223 .76865 Mdot
.55451 .6474 Mdot
.7789 .57138 Mdot
.65316 .36835 Mdot
.63812 .53757 Mdot
.33824 .75049 Mdot
.65772 .60109 Mdot
.45355 .33107 Mdot
.29434 .48032 Mdot
.6459 .61017 Mdot
.61087 .40386 Mdot
.6277 .39743 Mdot
.45811 .36753 Mdot
.43576 .35615 Mdot
.46336 .38739 Mdot
.63479 .55283 Mdot
.64618 .55543 Mdot
.44816 .5758 Mdot
.64818 .59151 Mdot
.52644 .16436 Mdot
.30869 .49678 Mdot
.44292 .32262 Mdot
.64371 .37886 Mdot
.65547 .56592 Mdot
.42898 .58001 Mdot
.4772 .33941 Mdot
.7712 .43126 Mdot
.27012 .45289 Mdot
.31256 .29104 Mdot
.13326 .40748 Mdot
.43557 .64291 Mdot
.62244 .36628 Mdot
.41239 .22772 Mdot
.43415 .58618 Mdot
.44456 .34963 Mdot
.79438 .40421 Mdot
.44691 .39756 Mdot
.49644 .58092 Mdot
.41179 .63967 Mdot
.62176 .36038 Mdot
.25662 .66669 Mdot
.443 .57384 Mdot
.69638 .41274 Mdot
.62352 .42284 Mdot
.484 .38749 Mdot
.3926 .83403 Mdot
.60719 .28976 Mdot
.23101 .5228 Mdot
.40779 .34678 Mdot
.41695 .6062 Mdot
.42374 .36578 Mdot
.26885 .45477 Mdot
.43696 .37763 Mdot
.66477 .54304 Mdot
.47844 .38183 Mdot
.47552 .6072 Mdot
.67142 .58083 Mdot
.63045 .37101 Mdot
.59328 .19377 Mdot
.36859 .40354 Mdot
.43538 .36101 Mdot
.40393 .3422 Mdot
.4663 .63301 Mdot
.57931 .51962 Mdot
.38656 .56973 Mdot
.43443 .63518 Mdot
.62862 .41636 Mdot
.64464 .56059 Mdot
.66529 .4012 Mdot
.3918 .61278 Mdot
.72315 .31802 Mdot
.65191 .37972 Mdot
.65304 .47898 Mdot
.29146 .46404 Mdot
.46939 .47277 Mdot
.42259 .58056 Mdot
.61714 .40046 Mdot
.45684 .56433 Mdot
.61497 .60453 Mdot
.51819 .45079 Mdot
.64417 .30505 Mdot
.62029 .39561 Mdot
.52157 .84671 Mdot
.45578 .43502 Mdot
.47059 .5467 Mdot
.62478 .4119 Mdot
.45197 .69818 Mdot
.41156 .36029 Mdot
.30114 .47255 Mdot
.26864 .49417 Mdot
.25922 .46139 Mdot
.45077 .65374 Mdot
.53775 .58104 Mdot
.31056 .4607 Mdot
.60355 .38947 Mdot
.27762 .493 Mdot
.70234 .54295 Mdot
.53406 .84591 Mdot
.3106 .4806 Mdot
.45757 .58888 Mdot
.49428 .64975 Mdot
.27976 .57471 Mdot
.44167 .31924 Mdot
.66874 .77078 Mdot
.45695 .51556 Mdot
.43351 .61447 Mdot
.55308 .5694 Mdot
.63643 .61222 Mdot
.40116 .23888 Mdot
.35783 .66981 Mdot
.38666 .27261 Mdot
.6117 .57677 Mdot
.58964 .33105 Mdot
.62585 .56882 Mdot
.44273 .6419 Mdot
.45649 .63038 Mdot
.6777 .61612 Mdot
.60882 .2223 Mdot
.50972 .24043 Mdot
.37072 .80276 Mdot
.66638 .60804 Mdot
.6253 .40905 Mdot
.61406 .41359 Mdot
.65426 .37041 Mdot
.34534 .32733 Mdot
.68335 .58958 Mdot
.45638 .56919 Mdot
.42186 .3329 Mdot
.40658 .61057 Mdot
.61853 .38862 Mdot
.42906 .84264 Mdot
.63279 .59857 Mdot
.45019 .60792 Mdot
.18133 .41758 Mdot
.43584 .34884 Mdot
.29821 .46162 Mdot
.21534 .58757 Mdot
.36484 .30834 Mdot
.6513 .41521 Mdot
.66685 .61861 Mdot
.55419 .38853 Mdot
.64669 .48727 Mdot
.42033 .66227 Mdot
.38086 .64195 Mdot
.26837 .71963 Mdot
.36235 .32818 Mdot
.48048 .63641 Mdot
.42355 .37303 Mdot
.58809 .33115 Mdot
.48505 .59672 Mdot
.6623 .61221 Mdot
.25145 .47909 Mdot
.26214 .47927 Mdot
.52439 .58207 Mdot
.58844 .46575 Mdot
.45035 .46652 Mdot
.49009 .58103 Mdot
.49965 .54805 Mdot
.44197 .32676 Mdot
.54986 .36826 Mdot
.56379 .18785 Mdot
.31295 .47173 Mdot
.4918 .61426 Mdot
.74958 .51586 Mdot
.662 .55471 Mdot
.47427 .38742 Mdot
.64227 .4191 Mdot
.29329 .67556 Mdot
.48478 .39377 Mdot
.48627 .59803 Mdot
.48873 .5911 Mdot
.63059 .36031 Mdot
.62224 .55013 Mdot
.29108 .47957 Mdot
.43442 .32985 Mdot
.31282 .46928 Mdot
.67081 .56427 Mdot
.6346 .59708 Mdot
.5016 .64993 Mdot
.50571 .55662 Mdot
.44836 .36757 Mdot
.39504 .61923 Mdot
.42269 .30996 Mdot
.25034 .66323 Mdot
.67003 .3874 Mdot
.43017 .64253 Mdot
.68946 .56163 Mdot
.61521 .3932 Mdot
.46348 .6122 Mdot
.26547 .72984 Mdot
.41065 .63227 Mdot
.61819 .31843 Mdot
.71223 .30289 Mdot
.26451 .46569 Mdot
.40853 .74656 Mdot
.56384 .54917 Mdot
.44048 .62431 Mdot
.46164 .35309 Mdot
.38594 .56439 Mdot
.64356 .36851 Mdot
.6266 .56204 Mdot
.14652 .43964 Mdot
.63929 .38456 Mdot
.43829 .63178 Mdot
.28009 .47944 Mdot
.65301 .6193 Mdot
.52797 .38547 Mdot
.49553 .19769 Mdot
.42421 .54456 Mdot
.46466 .55146 Mdot
.49583 .58235 Mdot
.82572 .47745 Mdot
.42855 .37519 Mdot
.65831 .56886 Mdot
.63223 .36251 Mdot
.61778 .37927 Mdot
.45459 .36254 Mdot
.71984 .48232 Mdot
.47235 .47064 Mdot
.87814 .58697 Mdot
.44792 .37489 Mdot
.32136 .47355 Mdot
.61266 .49254 Mdot
.46518 .3579 Mdot
.42277 .33865 Mdot
.43871 .32634 Mdot
.61025 .44519 Mdot
.63755 .57882 Mdot
.48247 .61517 Mdot
.60456 .58445 Mdot
.41539 .60795 Mdot
.3959 .48621 Mdot
.61329 .39305 Mdot
.6243 .56231 Mdot
.27264 .7312 Mdot
.68759 .62895 Mdot
.44332 .58784 Mdot
.32305 .74457 Mdot
.39289 .56641 Mdot
.29548 .63804 Mdot
.40987 .55872 Mdot
.43034 .35599 Mdot
.4008 .53601 Mdot
.39948 .63738 Mdot
.56309 .17692 Mdot
.64533 .38065 Mdot
.40908 .35797 Mdot
.46544 .64745 Mdot
.49599 .54842 Mdot
.66053 .62407 Mdot
.65009 .61074 Mdot
.31382 .46704 Mdot
.26707 .51926 Mdot
.634 .37038 Mdot
.19236 .57091 Mdot
.44004 .61714 Mdot
.66317 .26856 Mdot
.43182 .74686 Mdot
.46241 .61114 Mdot
.56559 .82087 Mdot
.50127 .76498 Mdot
.42195 .57757 Mdot
.46697 .68959 Mdot
.63274 .39859 Mdot
.71269 .31146 Mdot
.40617 .57209 Mdot
.44321 .34714 Mdot
.64204 .55707 Mdot
.65439 .61583 Mdot
.29907 .45292 Mdot
.35728 .21452 Mdot
.66566 .38893 Mdot
.62848 .55951 Mdot
.42638 .58655 Mdot
.65531 .4108 Mdot
.40389 .32375 Mdot
.38782 .60865 Mdot
.33318 .6511 Mdot
.64459 .59184 Mdot
.40002 .58487 Mdot
.73877 .40073 Mdot
.24409 .51958 Mdot
.79413 .65351 Mdot
.65391 .37115 Mdot
.297 .48964 Mdot
.37387 .6043 Mdot
.18013 .53578 Mdot
.4756 .65167 Mdot
.21447 .55448 Mdot
.66121 .52473 Mdot
.29417 .49129 Mdot
.44487 .59458 Mdot
.46642 .58121 Mdot
.61093 .48082 Mdot
.29363 .49854 Mdot
.41111 .62483 Mdot
.44952 .52052 Mdot
.64016 .57445 Mdot
.44073 .39811 Mdot
.6403 .58969 Mdot
.45129 .58505 Mdot
.5372 .5905 Mdot
.62899 .60258 Mdot
.1806 .58985 Mdot
.28241 .43735 Mdot
.65652 .38642 Mdot
.52268 .56638 Mdot
.43098 .56218 Mdot
.8373 .43214 Mdot
.41084 .36478 Mdot
.79896 .51634 Mdot
.49204 .38778 Mdot
.74371 .52963 Mdot
.60793 .28656 Mdot
.64328 .8104 Mdot
.6085 .20709 Mdot
.51642 .60056 Mdot
.39804 .50694 Mdot
.51187 .66959 Mdot
.66262 .40461 Mdot
.64112 .67135 Mdot
.43505 .61624 Mdot
.4296 .59886 Mdot
.47135 .39229 Mdot
.69377 .47677 Mdot
.44239 .22662 Mdot
.5655 .44869 Mdot
.2913 .47617 Mdot
.67623 .57651 Mdot
.46937 .62077 Mdot
.4014 .46612 Mdot
.47584 .37801 Mdot
.65141 .26241 Mdot
.44851 .60319 Mdot
.34549 .24233 Mdot
.58319 .42033 Mdot
.66217 .39631 Mdot
.45658 .34094 Mdot
.37201 .3049 Mdot
.41695 .61554 Mdot
.6284 .41914 Mdot
.43807 .57437 Mdot
.42728 .42254 Mdot
.3989 .62766 Mdot
.30812 .48212 Mdot
.48049 .62914 Mdot
.55634 .42829 Mdot
.75165 .7081 Mdot
.34353 .63062 Mdot
.67577 .60972 Mdot
.41517 .3048 Mdot
.45377 .36595 Mdot
.64173 .6082 Mdot
.45024 .36475 Mdot
.48679 .741 Mdot
.59794 .74871 Mdot
.29207 .47225 Mdot
.50427 .55088 Mdot
.30952 .46793 Mdot
.41051 .36484 Mdot
.42646 .61512 Mdot
.1734 .57311 Mdot
.44311 .37024 Mdot
.75159 .32265 Mdot
.64028 .38005 Mdot
.41003 .362 Mdot
.3993 .60832 Mdot
.52155 .35523 Mdot
.46334 .34541 Mdot
.59891 .32556 Mdot
.46382 .58391 Mdot
.6285 .5942 Mdot
.47244 .58327 Mdot
.40857 .55714 Mdot
.47354 .4078 Mdot
.45503 .55742 Mdot
.65052 .39256 Mdot
.62594 .55183 Mdot
.58025 .83364 Mdot
.62031 .31672 Mdot
.41932 .62613 Mdot
.4286 .58642 Mdot
.63919 .6201 Mdot
.40428 .5834 Mdot
.61472 .41208 Mdot
.83745 .32177 Mdot
.29189 .46373 Mdot
.3989 .31293 Mdot
.61025 .29284 Mdot
.48308 .64666 Mdot
.48769 .58317 Mdot
.29948 .7543 Mdot
.63701 .28849 Mdot
.63697 .40872 Mdot
.39661 .55154 Mdot
.42429 .33139 Mdot
.27846 .47834 Mdot
.60289 .37906 Mdot
.4881 .56755 Mdot
.43825 .60124 Mdot
.29917 .48778 Mdot
.51853 .82584 Mdot
.37149 .27342 Mdot
.64584 .36234 Mdot
.39717 .53878 Mdot
.42917 .29978 Mdot
.4072 .60059 Mdot
.34421 .3188 Mdot
.65524 .60881 Mdot
.644 .41477 Mdot
.7939 .54539 Mdot
.49117 .62331 Mdot
.60842 .39494 Mdot
.6372 .37152 Mdot
.37792 .6112 Mdot
.68102 .62192 Mdot
.64511 .54844 Mdot
.67888 .58736 Mdot
.5564 .16022 Mdot
.25696 .53397 Mdot
.46355 .38719 Mdot
.63113 .39928 Mdot
.40786 .31018 Mdot
.31854 .49006 Mdot
.4001 .47384 Mdot
.40057 .30764 Mdot
.62707 .60609 Mdot
.43509 .31819 Mdot
.46935 .58395 Mdot
.62835 .37081 Mdot
.44526 .38772 Mdot
.46088 .64928 Mdot
.56226 .53113 Mdot
.41198 .40133 Mdot
.25049 .4698 Mdot
.24368 .46236 Mdot
.46081 .62762 Mdot
.41962 .37869 Mdot
.44541 .61178 Mdot
.61634 .35583 Mdot
.62826 .48176 Mdot
.47362 .65002 Mdot
.43973 .36215 Mdot
.52441 .53633 Mdot
.36496 .30904 Mdot
.39595 .55594 Mdot
.45612 .58916 Mdot
.41054 .60367 Mdot
.43803 .57375 Mdot
.70805 .49853 Mdot
.66674 .37965 Mdot
.53546 .51305 Mdot
.56823 .33876 Mdot
.6528 .59598 Mdot
.68362 .55989 Mdot
.31868 .32308 Mdot
.38606 .30806 Mdot
.64262 .39851 Mdot
.41146 .5897 Mdot
.62831 .31064 Mdot
.43975 .8472 Mdot
.18173 .59976 Mdot
.24338 .48432 Mdot
.4442 .3921 Mdot
.6809 .60785 Mdot
.46968 .36196 Mdot
.41954 .60762 Mdot
.37539 .61088 Mdot
.62953 .82454 Mdot
.62749 .3406 Mdot
.29311 .48078 Mdot
.41192 .60462 Mdot
.24121 .52341 Mdot
.42218 .33388 Mdot
.43528 .32367 Mdot
.40849 .62529 Mdot
.65978 .5448 Mdot
.84987 .54536 Mdot
.66291 .3964 Mdot
.4502 .51171 Mdot
.5915 .61738 Mdot
.71873 .36029 Mdot
.61322 .38666 Mdot
.38697 .3629 Mdot
.44216 .39242 Mdot
.44473 .77417 Mdot
.64966 .59849 Mdot
.29458 .48301 Mdot
.37875 .6329 Mdot
.62024 .59419 Mdot
.4794 .40356 Mdot
.61737 .57673 Mdot
.47627 .63481 Mdot
.66732 .39286 Mdot
.44934 .33744 Mdot
.64921 .34986 Mdot
.68937 .60746 Mdot
.29295 .45336 Mdot
.57266 .50431 Mdot
.66716 .68505 Mdot
.49755 .7633 Mdot
.40386 .59738 Mdot
.39011 .46649 Mdot
.46012 .56633 Mdot
.66239 .62513 Mdot
.43205 .5779 Mdot
.57585 .59557 Mdot
.45872 .34804 Mdot
.40164 .5816 Mdot
.49732 .58761 Mdot
.60189 .67187 Mdot
.4553 .59881 Mdot
.41111 .56325 Mdot
.41843 .57924 Mdot
.64593 .53317 Mdot
.4761 .53935 Mdot
.63244 .5835 Mdot
.48976 .20292 Mdot
.42265 .34005 Mdot
.24982 .4782 Mdot
.25927 .47926 Mdot
.21211 .5395 Mdot
.33996 .51331 Mdot
.70899 .48286 Mdot
.64454 .58291 Mdot
.64896 .38013 Mdot
.43328 .57484 Mdot
.7676 .5994 Mdot
.57785 .29862 Mdot
.42154 .3301 Mdot
.61831 .31776 Mdot
.36316 .60939 Mdot
.82702 .47621 Mdot
.39744 .60594 Mdot
.44154 .18598 Mdot
.5146 .61936 Mdot
.41498 .63659 Mdot
.45925 .33458 Mdot
.34286 .51159 Mdot
.40166 .60646 Mdot
.65815 .62407 Mdot
.30292 .47962 Mdot
.70782 .62477 Mdot
.47099 .28333 Mdot
.38322 .34356 Mdot
.62958 .70222 Mdot
.44912 .56621 Mdot
.44743 .3375 Mdot
.62615 .57719 Mdot
.57959 .19274 Mdot
.6591 .3975 Mdot
.62829 .45908 Mdot
.55351 .66171 Mdot
.29243 .71956 Mdot
.29818 .48197 Mdot
.51259 .82302 Mdot
.47606 .60864 Mdot
.33736 .35078 Mdot
.50434 .61432 Mdot
.44373 .84784 Mdot
.32033 .46758 Mdot
.67064 .54879 Mdot
.62684 .40921 Mdot
.61208 .6003 Mdot
.50793 .77534 Mdot
.68533 .34244 Mdot
.53665 .4742 Mdot
.40942 .33173 Mdot
.54582 .5132 Mdot
.66813 .57465 Mdot
.49299 .59773 Mdot
.87328 .61298 Mdot
.66117 .60807 Mdot
.67902 .56713 Mdot
.23249 .64086 Mdot
.23278 .64828 Mdot
.36577 .58385 Mdot
.61421 .58805 Mdot
.41137 .33498 Mdot
.27629 .45725 Mdot
.46841 .57785 Mdot
.45121 .57496 Mdot
.6293 .60052 Mdot
.45154 .32877 Mdot
.41596 .51829 Mdot
.43287 .35514 Mdot
.63878 .57312 Mdot
.43037 .34402 Mdot
.60602 .31428 Mdot
.43538 .38477 Mdot
.42453 .5652 Mdot
.43217 .57707 Mdot
.4397 .28656 Mdot
.63467 .59692 Mdot
.48482 .57687 Mdot
.47913 .6245 Mdot
.66889 .58198 Mdot
.49381 .38737 Mdot
.72735 .639 Mdot
.42583 .62428 Mdot
.47435 .59589 Mdot
.29778 .49039 Mdot
.36492 .46124 Mdot
.25753 .3315 Mdot
.47903 .57955 Mdot
.31588 .48796 Mdot
.63211 .55399 Mdot
.44961 .61218 Mdot
.6958 .53394 Mdot
.59637 .32462 Mdot
.49089 .62212 Mdot
.41396 .36429 Mdot
.43613 .65518 Mdot
.81428 .6045 Mdot
.42627 .63492 Mdot
.66098 .57479 Mdot
.65592 .55858 Mdot
.24225 .64173 Mdot
.66726 .6003 Mdot
.40599 .33934 Mdot
.62199 .38514 Mdot
.47024 .85467 Mdot
.404 .3221 Mdot
.42264 .64532 Mdot
.16679 .43295 Mdot
.39464 .5901 Mdot
.47003 .64795 Mdot
.82053 .43436 Mdot
.405 .32255 Mdot
.6578 .56239 Mdot
.65276 .44972 Mdot
.52445 .59878 Mdot
.64917 .41595 Mdot
.38694 .62822 Mdot
.46946 .55572 Mdot
.69979 .29674 Mdot
.78559 .42628 Mdot
.59426 .37486 Mdot
.44505 .66846 Mdot
.47934 .57916 Mdot
.37942 .43764 Mdot
.42615 .58256 Mdot
.31107 .46841 Mdot
.6797 .57396 Mdot
.47026 .37809 Mdot
.28243 .46001 Mdot
.43915 .62047 Mdot
.2876 .48149 Mdot
.46582 .38804 Mdot
.63478 .41759 Mdot
.42097 .61381 Mdot
.30748 .44911 Mdot
.29027 .4771 Mdot
.46741 .56626 Mdot
.63006 .55974 Mdot
.34869 .61247 Mdot
.45336 .61228 Mdot
.49041 .60499 Mdot
.63133 .60022 Mdot
.16059 .58571 Mdot
.41973 .63478 Mdot
.46636 .42972 Mdot
.68203 .56876 Mdot
.64514 .31738 Mdot
.46895 .38966 Mdot
.46374 .55536 Mdot
.62783 .41746 Mdot
.61351 .39648 Mdot
.41519 .32204 Mdot
.62299 .61315 Mdot
.43342 .31361 Mdot
.52305 .53757 Mdot
.51967 .56639 Mdot
.38736 .5946 Mdot
.18169 .37709 Mdot
.62391 .8202 Mdot
.66392 .61277 Mdot
.49108 .39964 Mdot
.56507 .45149 Mdot
.629 .40268 Mdot
.41627 .31547 Mdot
.65784 .61968 Mdot
.678 .61049 Mdot
.61923 .57886 Mdot
.27809 .48661 Mdot
.49587 .39766 Mdot
.63101 .54543 Mdot
.65782 .54468 Mdot
.46683 .58439 Mdot
.48065 .57845 Mdot
.429 .69061 Mdot
.30451 .59207 Mdot
.29559 .45315 Mdot
.45318 .35825 Mdot
.77158 .27345 Mdot
.60924 .35931 Mdot
.60234 .67472 Mdot
.47584 .64871 Mdot
.77454 .77279 Mdot
.39769 .61593 Mdot
.42378 .58609 Mdot
.62024 .5566 Mdot
.29566 .4439 Mdot
.30676 .46721 Mdot
.66814 .5721 Mdot
.6849 .61002 Mdot
.31229 .47435 Mdot
.434 .81394 Mdot
.53218 .84849 Mdot
.67832 .43243 Mdot
.66308 .58276 Mdot
.66165 .70035 Mdot
.64212 .41994 Mdot
.69207 .60603 Mdot
.61539 .35848 Mdot
.42545 .33557 Mdot
.44708 .39512 Mdot
.63473 .36175 Mdot
.45976 .58244 Mdot
.45406 .3869 Mdot
.48755 .55207 Mdot
.47443 .83319 Mdot
.60305 .77968 Mdot
.59163 .25426 Mdot
.51149 .57671 Mdot
.45092 .22343 Mdot
.45665 .23747 Mdot
.44702 .62712 Mdot
.73524 .55809 Mdot
.29166 .48149 Mdot
.6989 .56744 Mdot
.61676 .4138 Mdot
.80153 .64297 Mdot
.40799 .59685 Mdot
.65779 .5766 Mdot
.64752 .38505 Mdot
.24784 .63089 Mdot
.6948 .4182 Mdot
.41353 .60803 Mdot
.88378 .56094 Mdot
.68387 .54151 Mdot
.4699 .37929 Mdot
.24919 .30221 Mdot
.603 .58057 Mdot
.23749 .48536 Mdot
.54824 .36008 Mdot
.29417 .73651 Mdot
.64249 .56405 Mdot
.49249 .40241 Mdot
.6747 .57567 Mdot
.30636 .45984 Mdot
.7061 .56967 Mdot
.44128 .33097 Mdot
.45019 .59752 Mdot
.44652 .36001 Mdot
.29039 .45128 Mdot
.34169 .33443 Mdot
.62107 .41585 Mdot
.41051 .36026 Mdot
.62979 .39122 Mdot
.25081 .51967 Mdot
.73715 .32868 Mdot
.65538 .39696 Mdot
.22445 .61126 Mdot
.4843 .6347 Mdot
.6124 .55697 Mdot
.45437 .37744 Mdot
.54483 .36535 Mdot
.57715 .49073 Mdot
.65866 .59543 Mdot
.4555 .35502 Mdot
.55886 .6534 Mdot
.17968 .46814 Mdot
.53752 .57839 Mdot
.28935 .53301 Mdot
.66706 .58461 Mdot
.43113 .32052 Mdot
.51741 .18856 Mdot
.62877 .60833 Mdot
.44813 .37568 Mdot
.6201 .4068 Mdot
.61526 .38193 Mdot
.40531 .61583 Mdot
.63829 .44835 Mdot
.46303 .37189 Mdot
.49209 .21989 Mdot
.66466 .55524 Mdot
.24987 .62888 Mdot
.27206 .4497 Mdot
.41987 .34396 Mdot
.39347 .62639 Mdot
.6045 .61732 Mdot
.59602 .32315 Mdot
.37829 .53081 Mdot
.76933 .27844 Mdot
.45372 .36162 Mdot
.67891 .56998 Mdot
.65506 .57973 Mdot
.38792 .56944 Mdot
.5935 .47097 Mdot
.42951 .31071 Mdot
.19286 .49576 Mdot
.22096 .56902 Mdot
.47259 .40634 Mdot
.47195 .25576 Mdot
.41166 .64076 Mdot
.4537 .5625 Mdot
.62882 .40455 Mdot
.45519 .59445 Mdot
.64358 .54594 Mdot
.40174 .60002 Mdot
.61074 .38266 Mdot
.41657 .35194 Mdot
.42503 .61195 Mdot
.27177 .45778 Mdot
.59394 .39598 Mdot
.62586 .35917 Mdot
.42319 .35137 Mdot
.61502 .58577 Mdot
.24536 .44466 Mdot
.43666 .35636 Mdot
.44748 .56712 Mdot
.53237 .38169 Mdot
.47272 .63463 Mdot
.43441 .796 Mdot
.6213 .60366 Mdot
.46575 .35617 Mdot
.68537 .56986 Mdot
.63451 .39129 Mdot
.56676 .34048 Mdot
.44263 .58225 Mdot
.44434 .37422 Mdot
.4455 .27846 Mdot
.46325 .81757 Mdot
.63366 .61973 Mdot
.50167 .27152 Mdot
.67284 .55503 Mdot
.46747 .40598 Mdot
.34275 .71168 Mdot
.29908 .47378 Mdot
.42829 .32962 Mdot
.62267 .80973 Mdot
.44301 .36627 Mdot
.45918 .60107 Mdot
.46567 .61668 Mdot
.4658 .39303 Mdot
.2717 .48812 Mdot
.63187 .20669 Mdot
.41461 .39656 Mdot
.65072 .56213 Mdot
.39077 .7377 Mdot
.81578 .34187 Mdot
.67512 .40166 Mdot
.6326 .40691 Mdot
.52007 .59981 Mdot
.41072 .63575 Mdot
.60377 .37059 Mdot
.63095 .4247 Mdot
.29027 .44763 Mdot
.43538 .32631 Mdot
.70495 .56395 Mdot
.61188 .41556 Mdot
.46995 .66992 Mdot
.3334 .51577 Mdot
.42123 .53692 Mdot
.55036 .57476 Mdot
.50376 .57795 Mdot
.20667 .55108 Mdot
.61607 .37084 Mdot
.46708 .62657 Mdot
.44507 .53737 Mdot
.63694 .41526 Mdot
.30806 .46251 Mdot
.77622 .4104 Mdot
.43652 .3417 Mdot
.28629 .77488 Mdot
.4526 .63784 Mdot
.4576 .60449 Mdot
.65506 .37034 Mdot
.36554 .43633 Mdot
.62239 .59326 Mdot
.61761 .60222 Mdot
.43163 .37796 Mdot
.55815 .50262 Mdot
.41184 .57675 Mdot
.45209 .62777 Mdot
.44664 .34214 Mdot
.41115 .36314 Mdot
.54557 .23538 Mdot
.48215 .61062 Mdot
.64629 .38655 Mdot
.52498 .38588 Mdot
.61244 .37524 Mdot
.45051 .64172 Mdot
.46264 .60277 Mdot
.42086 .5672 Mdot
.41274 .63832 Mdot
.62902 .35808 Mdot
.46959 .62402 Mdot
.51783 .62784 Mdot
.61752 .57171 Mdot
.43694 .56294 Mdot
.21406 .56493 Mdot
.46393 .59097 Mdot
.28761 .45383 Mdot
.3468 .50362 Mdot
.41019 .60558 Mdot
.43611 .56109 Mdot
.41972 .4021 Mdot
.44062 .59321 Mdot
.61663 .35589 Mdot
.65213 .59215 Mdot
.63034 .39928 Mdot
.62847 .36114 Mdot
.41319 .35659 Mdot
.30614 .45647 Mdot
.49094 .63836 Mdot
.25993 .46212 Mdot
.44254 .66551 Mdot
.48701 .62986 Mdot
.55538 .33515 Mdot
.43598 .18528 Mdot
.36842 .27516 Mdot
.4434 .58137 Mdot
.42136 .36028 Mdot
.47091 .37462 Mdot
.41939 .50499 Mdot
.48361 .54654 Mdot
.60195 .37497 Mdot
.61731 .40002 Mdot
.31887 .63715 Mdot
.6992 .29864 Mdot
.29475 .45444 Mdot
.39689 .47059 Mdot
.49701 .55419 Mdot
.48498 .61652 Mdot
.38877 .60732 Mdot
.40205 .30804 Mdot
.53278 .3847 Mdot
.42113 .33044 Mdot
.60397 .32645 Mdot
.6094 .38235 Mdot
.41016 .58397 Mdot
.64955 .7607 Mdot
.6452 .61123 Mdot
.65131 .59253 Mdot
.60494 .37774 Mdot
.41407 .3057 Mdot
.38732 .66916 Mdot
.12736 .48208 Mdot
.67267 .53859 Mdot
.26497 .45015 Mdot
.44049 .62852 Mdot
.42246 .35627 Mdot
.67456 .60557 Mdot
.27503 .49265 Mdot
.49053 .61923 Mdot
.43754 .31364 Mdot
.44518 .57892 Mdot
.5108 .66955 Mdot
.62925 .56346 Mdot
.46728 .8597 Mdot
.64948 .61826 Mdot
.59699 .40175 Mdot
.64507 .40881 Mdot
.46467 .61071 Mdot
.20059 .35382 Mdot
.60685 .56348 Mdot
.60474 .43478 Mdot
.31606 .4604 Mdot
.53763 .37612 Mdot
.31158 .48712 Mdot
.46529 .35959 Mdot
.30152 .48021 Mdot
.45075 .33627 Mdot
.31731 .61365 Mdot
.60871 .54784 Mdot
.28837 .46119 Mdot
.40589 .43364 Mdot
.49046 .54784 Mdot
.26055 .48955 Mdot
.48775 .65026 Mdot
.42169 .75901 Mdot
.44622 .34402 Mdot
.2684 .48474 Mdot
.49232 .5963 Mdot
.75416 .68058 Mdot
.64933 .39794 Mdot
.60106 .3737 Mdot
.46556 .54884 Mdot
.43297 .32518 Mdot
.67199 .61997 Mdot
.65969 .49433 Mdot
.64443 .32621 Mdot
.45935 .62704 Mdot
.40148 .60417 Mdot
.68234 .55732 Mdot
.59264 .56784 Mdot
.46603 .60599 Mdot
.59723 .65222 Mdot
.47566 .61478 Mdot
.61369 .40467 Mdot
.64618 .61442 Mdot
.65412 .58468 Mdot
.46254 .36474 Mdot
.60914 .57714 Mdot
.5462 .56298 Mdot
.54938 .40022 Mdot
.49805 .64086 Mdot
.6375 .38483 Mdot
.58013 .44639 Mdot
.61763 .31773 Mdot
.68824 .74761 Mdot
.69215 .57114 Mdot
.44167 .55765 Mdot
.67165 .55812 Mdot
.27279 .47759 Mdot
.6364 .59539 Mdot
.68471 .59192 Mdot
.44938 .61769 Mdot
.41686 .60566 Mdot
.40623 .33097 Mdot
.5872 .46791 Mdot
.62312 .56072 Mdot
.46417 .62415 Mdot
.3983 .58344 Mdot
.41301 .56176 Mdot
.49949 .44211 Mdot
.66841 .61129 Mdot
.54815 .69059 Mdot
.34106 .68638 Mdot
.62174 .56225 Mdot
.82531 .58299 Mdot
.55498 .36089 Mdot
.39592 .3109 Mdot
.66529 .36014 Mdot
.48298 .61039 Mdot
.46645 .39525 Mdot
.4199 .60813 Mdot
.55164 .57606 Mdot
.43509 .601 Mdot
.30429 .4929 Mdot
.51634 .60055 Mdot
.45576 .4025 Mdot
.43998 .3585 Mdot
.44239 .63479 Mdot
.42682 .60955 Mdot
.35384 .32398 Mdot
.68743 .60662 Mdot
.6213 .59033 Mdot
.3515 .42653 Mdot
.28199 .46824 Mdot
.64534 .41576 Mdot
.4239 .57835 Mdot
.42336 .36738 Mdot
.44444 .35879 Mdot
.61054 .59921 Mdot
.44291 .34896 Mdot
.66199 .38554 Mdot
.43814 .58215 Mdot
.60231 .3714 Mdot
.26524 .48177 Mdot
.67978 .58555 Mdot
.40921 .59186 Mdot
.46776 .5849 Mdot
.6559 .55867 Mdot
.49334 .62926 Mdot
.29931 .49003 Mdot
.44612 .36588 Mdot
.63537 .56772 Mdot
.62007 .38554 Mdot
.45986 .3487 Mdot
.48249 .58955 Mdot
.76343 .27105 Mdot
.4637 .5985 Mdot
.48582 .60029 Mdot
.5875 .84136 Mdot
.51473 .60736 Mdot
.45867 .37324 Mdot
.67473 .54891 Mdot
.48329 .55274 Mdot
.22504 .54186 Mdot
.17826 .60091 Mdot
.4132 .32448 Mdot
.43192 .62987 Mdot
.68974 .75533 Mdot
.43484 .63304 Mdot
.19162 .56371 Mdot
.27091 .35248 Mdot
.50285 .49518 Mdot
.53966 .60205 Mdot
.64859 .36905 Mdot
.4064 .33339 Mdot
.45852 .34894 Mdot
.44087 .72555 Mdot
.4523 .62131 Mdot
.49177 .67398 Mdot
.49793 .59784 Mdot
.61325 .38441 Mdot
.34479 .66677 Mdot
.45098 .359 Mdot
.4737 .1878 Mdot
.45557 .56843 Mdot
.6692 .6123 Mdot
.43758 .31905 Mdot
.56235 .35404 Mdot
.48842 .59632 Mdot
.25904 .46797 Mdot
.60605 .35198 Mdot
.52855 .5908 Mdot
.63388 .38083 Mdot
.48532 .62073 Mdot
.50356 .64956 Mdot
.28519 .2635 Mdot
.62403 .56662 Mdot
.62709 .40776 Mdot
.45927 .24549 Mdot
.50314 .62019 Mdot
.63784 .56528 Mdot
.65105 .59825 Mdot
.28147 .44884 Mdot
.54536 .45968 Mdot
.73665 .41493 Mdot
.67125 .72016 Mdot
.40121 .73222 Mdot
.42413 .31635 Mdot
.50652 .24602 Mdot
.47217 .57778 Mdot
.64703 .26574 Mdot
.60326 .36373 Mdot
.45476 .60222 Mdot
.44453 .75519 Mdot
.67842 .5939 Mdot
.47702 .6005 Mdot
.3096 .46741 Mdot
.61515 .2337 Mdot
.62832 .2523 Mdot
.82388 .52229 Mdot
.41205 .3312 Mdot
.38261 .62427 Mdot
.54816 .57424 Mdot
.40548 .34696 Mdot
.50198 .61205 Mdot
.45443 .37275 Mdot
.37018 .77062 Mdot
.28656 .49393 Mdot
.68057 .59717 Mdot
.5574 .35869 Mdot
.4999 .5706 Mdot
.39834 .57541 Mdot
.24946 .475 Mdot
.47117 .56076 Mdot
.35925 .21586 Mdot
.58595 .27017 Mdot
.44555 .38654 Mdot
.61924 .57646 Mdot
.50385 .56767 Mdot
.52224 .39366 Mdot
.45569 .6181 Mdot
.5967 .76427 Mdot
.44401 .5583 Mdot
.72797 .40014 Mdot
.64156 .55691 Mdot
.63358 .38389 Mdot
.40228 .65199 Mdot
.43086 .59554 Mdot
.46111 .3199 Mdot
.53771 .60736 Mdot
.43067 .63728 Mdot
.65467 .62323 Mdot
.65451 .61303 Mdot
.63363 .58349 Mdot
.47751 .37767 Mdot
.68789 .29364 Mdot
.64264 .39227 Mdot
.41752 .64776 Mdot
.61167 .41582 Mdot
.40443 .5256 Mdot
.2497 .46941 Mdot
.76025 .65237 Mdot
.46782 .55776 Mdot
.64128 .58044 Mdot
.76114 .5024 Mdot
.63575 .55289 Mdot
.5006 .38426 Mdot
.63293 .37022 Mdot
.67431 .60233 Mdot
.42656 .5895 Mdot
.57252 .44938 Mdot
.78719 .5953 Mdot
.62523 .39789 Mdot
.4611 .66079 Mdot
.43316 .38704 Mdot
.61305 .29711 Mdot
.80772 .30753 Mdot
.63883 .40799 Mdot
.46978 .24391 Mdot
.45163 .62515 Mdot
.63735 .60871 Mdot
.65424 .37289 Mdot
.65423 .39064 Mdot
.44791 .34901 Mdot
.41506 .60481 Mdot
.41207 .60076 Mdot
.46773 .40439 Mdot
.61649 .3978 Mdot
.39806 .56683 Mdot
.39329 .61732 Mdot
.62887 .82637 Mdot
.4219 .70925 Mdot
.1848 .66861 Mdot
.51497 .53278 Mdot
.45301 .76285 Mdot
.63287 .50173 Mdot
.68209 .57664 Mdot
.41086 .60798 Mdot
.50886 .58388 Mdot
.46203 .36898 Mdot
.45082 .59019 Mdot
.48352 .37737 Mdot
.64266 .40104 Mdot
.82106 .58198 Mdot
.77845 .451 Mdot
.3592 .75985 Mdot
.44874 .59182 Mdot
.71259 .33753 Mdot
.27177 .46721 Mdot
.59533 .40602 Mdot
.63326 .5753 Mdot
.4712 .639 Mdot
.35651 .31566 Mdot
.42594 .33028 Mdot
.65245 .60431 Mdot
.46259 .21165 Mdot
.37914 .29753 Mdot
.45161 .64178 Mdot
.47915 .38744 Mdot
.72891 .52425 Mdot
.60479 .65024 Mdot
.65046 .42677 Mdot
.30831 .49043 Mdot
.42047 .33225 Mdot
.60848 .37585 Mdot
.67186 .52644 Mdot
.67084 .60232 Mdot
.64835 .53838 Mdot
.33353 .3008 Mdot
.40086 .30245 Mdot
.27872 .45932 Mdot
.69217 .29722 Mdot
.67728 .27075 Mdot
.30504 .49216 Mdot
.46214 .40085 Mdot
.66239 .61106 Mdot
.65018 .56956 Mdot
.65315 .59126 Mdot
.48917 .18425 Mdot
.62694 .61392 Mdot
.60752 .69638 Mdot
.39687 .5831 Mdot
.49728 .66238 Mdot
.4309 .63099 Mdot
.61581 .35929 Mdot
.63421 .56168 Mdot
.60543 .49236 Mdot
.43552 .65138 Mdot
.81533 .55328 Mdot
.45457 .62843 Mdot
.64252 .42942 Mdot
.48163 .60333 Mdot
.63769 .68072 Mdot
.68015 .56357 Mdot
.44856 .58512 Mdot
.65083 .35685 Mdot
.28627 .47533 Mdot
.69009 .61883 Mdot
.41093 .60443 Mdot
.69072 .47024 Mdot
.51272 .61333 Mdot
.41458 .8048 Mdot
.26703 .6408 Mdot
.26379 .45069 Mdot
.43956 .52147 Mdot
.42287 .32086 Mdot
.49103 .66806 Mdot
.51904 .55541 Mdot
.62507 .39625 Mdot
.77255 .37295 Mdot
.42 .33892 Mdot
.34376 .64409 Mdot
.38999 .55924 Mdot
.30843 .45967 Mdot
.59755 .60325 Mdot
.63041 .35513 Mdot
.46018 .64758 Mdot
.37791 .60892 Mdot
.3847 .77724 Mdot
.52505 .56373 Mdot
.40254 .58803 Mdot
.25213 .47606 Mdot
.55216 .69619 Mdot
.4667 .58947 Mdot
.50389 .39137 Mdot
.65638 .53993 Mdot
.47312 .54828 Mdot
.55059 .68662 Mdot
.46302 .62383 Mdot
.64733 .60727 Mdot
.60188 .55825 Mdot
.74983 .47236 Mdot
.31104 .45594 Mdot
.44509 .55825 Mdot
.28577 .67888 Mdot
.45594 .56566 Mdot
.64456 .38348 Mdot
.426 .63981 Mdot
.43135 .33175 Mdot
.47102 .19518 Mdot
.46313 .38522 Mdot
.41529 .61943 Mdot
.65727 .58754 Mdot
.64327 .36285 Mdot
.35178 .28483 Mdot
.29217 .35289 Mdot
.59884 .69428 Mdot
.27223 .73331 Mdot
.27495 .4884 Mdot
.30057 .49831 Mdot
.63772 .35627 Mdot
.45036 .58482 Mdot
.25461 .65755 Mdot
.51987 .60895 Mdot
.47596 .59633 Mdot
.43473 .60212 Mdot
.6797 .30064 Mdot
.63456 .4017 Mdot
.43645 .34676 Mdot
.46533 .60385 Mdot
.46736 .62341 Mdot
.67209 .56298 Mdot
.2885 .47521 Mdot
.47069 .3846 Mdot
.29069 .4677 Mdot
.43041 .36475 Mdot
.82103 .5957 Mdot
.42551 .65697 Mdot
.28357 .47389 Mdot
.59612 .36798 Mdot
.63147 .60093 Mdot
.53496 .38327 Mdot
.46365 .35684 Mdot
.45418 .35813 Mdot
.45704 .62693 Mdot
.64053 .60707 Mdot
.61186 .57173 Mdot
.27169 .4777 Mdot
.65566 .40229 Mdot
.4163 .61361 Mdot
.48317 .63292 Mdot
.45845 .4945 Mdot
.40436 .30617 Mdot
.56865 .64222 Mdot
.73449 .49079 Mdot
.44649 .58201 Mdot
.61375 .58586 Mdot
.43435 .60973 Mdot
.64464 .77505 Mdot
.62517 .60414 Mdot
.41326 .63391 Mdot
.67396 .25683 Mdot
.52887 .3841 Mdot
.71334 .44662 Mdot
.41496 .56846 Mdot
.31583 .77838 Mdot
.47366 .57349 Mdot
.66984 .79019 Mdot
.35291 .36856 Mdot
.40852 .58487 Mdot
.47217 .58172 Mdot
.69384 .70755 Mdot
.43788 .62339 Mdot
.45341 .40238 Mdot
.34248 .64487 Mdot
.68171 .60829 Mdot
.61202 .50227 Mdot
.35719 .48124 Mdot
.30944 .45273 Mdot
.43241 .37865 Mdot
.48154 .26809 Mdot
.30962 .47991 Mdot
.66416 .5809 Mdot
.4379 .5735 Mdot
.52858 .49459 Mdot
.48387 .40494 Mdot
.40889 .55449 Mdot
.64181 .37808 Mdot
.54188 .26784 Mdot
.48759 .38367 Mdot
.62581 .38406 Mdot
.49077 .56537 Mdot
.72665 .64526 Mdot
.25901 .35067 Mdot
.48248 .8646 Mdot
.64722 .36334 Mdot
.61113 .39164 Mdot
.53642 .17951 Mdot
.31599 .4574 Mdot
.38585 .75898 Mdot
.71485 .39808 Mdot
.66285 .40086 Mdot
.32626 .69715 Mdot
.42027 .32789 Mdot
.68956 .46175 Mdot
.69896 .56767 Mdot
.38708 .59732 Mdot
.42818 .59087 Mdot
.65307 .40614 Mdot
.69522 .53741 Mdot
.27248 .27788 Mdot
.62841 .39166 Mdot
.49608 .65132 Mdot
.49614 .45571 Mdot
.55307 .36347 Mdot
.4016 .3188 Mdot
.30537 .4524 Mdot
.28208 .50904 Mdot
.67119 .56656 Mdot
.29494 .44968 Mdot
.61886 .24697 Mdot
.46893 .55903 Mdot
.62027 .39381 Mdot
.56753 .35275 Mdot
.61942 .38191 Mdot
.30894 .47375 Mdot
.27379 .4464 Mdot
.61688 .57294 Mdot
.62231 .59073 Mdot
.4705 .76443 Mdot
.30241 .63666 Mdot
.43779 .63403 Mdot
.788 .54981 Mdot
.65995 .55379 Mdot
.4955 .53578 Mdot
.31227 .49017 Mdot
.28505 .47182 Mdot
.47776 .69074 Mdot
.41435 .58364 Mdot
.23281 .63087 Mdot
.41666 .58335 Mdot
.3295 .65737 Mdot
.50553 .60748 Mdot
.44568 .34888 Mdot
.41587 .57914 Mdot
.29352 .436 Mdot
.41177 .64057 Mdot
.43612 .63877 Mdot
.42768 .32499 Mdot
.52815 .58491 Mdot
.43268 .33184 Mdot
.41452 .62147 Mdot
.31932 .48733 Mdot
.42435 .36931 Mdot
.25621 .54249 Mdot
.46114 .4284 Mdot
.42187 .38026 Mdot
.27587 .45323 Mdot
.26589 .45356 Mdot
.22067 .51828 Mdot
.6341 .5739 Mdot
.67639 .62919 Mdot
.45376 .5875 Mdot
.4359 .32362 Mdot
.63194 .4048 Mdot
.47063 .62142 Mdot
.51148 .60405 Mdot
.40161 .58458 Mdot
.67884 .57758 Mdot
.42536 .30949 Mdot
.28291 .47846 Mdot
.48009 .3853 Mdot
.47235 .339 Mdot
.48734 .39112 Mdot
.45713 .53654 Mdot
.38369 .64412 Mdot
.46242 .78763 Mdot
.8017 .49535 Mdot
.61255 .19714 Mdot
.66588 .60348 Mdot
.41301 .3635 Mdot
.28545 .44593 Mdot
.35475 .57783 Mdot
.63935 .576 Mdot
.43981 .33081 Mdot
.44394 .57848 Mdot
.45601 .66248 Mdot
.62732 .33687 Mdot
.49918 .66466 Mdot
.23509 .58312 Mdot
.47975 .37142 Mdot
.49235 .40583 Mdot
.67146 .27033 Mdot
.35148 .65377 Mdot
.56822 .49784 Mdot
.44606 .60581 Mdot
.25881 .47078 Mdot
.67446 .60563 Mdot
.30301 .30875 Mdot
.62836 .41431 Mdot
.59097 .46947 Mdot
.44816 .59077 Mdot
.69694 .39764 Mdot
.65688 .58926 Mdot
.30487 .46014 Mdot
.65197 .40777 Mdot
.29315 .44255 Mdot
.39913 .31695 Mdot
.2359 .66507 Mdot
.46244 .56305 Mdot
.42685 .63469 Mdot
.60478 .4081 Mdot
.67377 .57592 Mdot
.24587 .45994 Mdot
.43813 .81081 Mdot
.46534 .39089 Mdot
.22282 .62504 Mdot
.61911 .55579 Mdot
.63612 .70179 Mdot
.4798 .38277 Mdot
.60485 .37887 Mdot
.22368 .51359 Mdot
.61095 .38128 Mdot
.40728 .60855 Mdot
.64786 .58276 Mdot
.64906 .39576 Mdot
.48463 .34052 Mdot
.72091 .72494 Mdot
.65266 .70297 Mdot
.43326 .56813 Mdot
.7782 .63216 Mdot
.51065 .83971 Mdot
.72287 .58633 Mdot
.62438 .41797 Mdot
.45511 .6136 Mdot
.49966 .58582 Mdot
.45125 .56894 Mdot
.64313 .37188 Mdot
.53847 .33202 Mdot
.4519 .34674 Mdot
.4439 .63053 Mdot
.28607 .44756 Mdot
.43208 .33422 Mdot
.56474 .34734 Mdot
.45873 .36803 Mdot
.69119 .59166 Mdot
.4133 .63714 Mdot
.61846 .45726 Mdot
.75885 .70891 Mdot
.62908 .399 Mdot
.42272 .38114 Mdot
.46509 .63414 Mdot
.72444 .32975 Mdot
.63523 .58231 Mdot
.46364 .39141 Mdot
.45695 .60471 Mdot
.52313 .34127 Mdot
.3511 .32323 Mdot
.45743 .36531 Mdot
.64497 .56831 Mdot
.72956 .57378 Mdot
.45443 .59264 Mdot
.47381 .57098 Mdot
.67154 .57613 Mdot
.3442 .46488 Mdot
.48496 .19789 Mdot
.42956 .60913 Mdot
.63205 .38402 Mdot
.14822 .50509 Mdot
.40982 .5665 Mdot
.39415 .70155 Mdot
.40836 .32468 Mdot
.71392 .47623 Mdot
.57209 .63948 Mdot
.40924 .52879 Mdot
.70095 .70941 Mdot
.41167 .4723 Mdot
.81157 .59604 Mdot
.47225 .35068 Mdot
.38018 .39194 Mdot
.81226 .60956 Mdot
.6553 .36214 Mdot
.57883 .56061 Mdot
.45631 .50978 Mdot
.45204 .19802 Mdot
.69091 .52596 Mdot
.33816 .40724 Mdot
.36205 .29532 Mdot
.49849 .47572 Mdot
.44212 .36919 Mdot
.33589 .5883 Mdot
.41798 .61165 Mdot
.50305 .8409 Mdot
.60306 .65758 Mdot
.25291 .28859 Mdot
.77473 .64131 Mdot
.28884 .67918 Mdot
.76916 .61962 Mdot
.66707 .77119 Mdot
.44453 .78066 Mdot
.79342 .50597 Mdot
.17156 .54378 Mdot
.65884 .25337 Mdot
.30756 .71515 Mdot
.37053 .62045 Mdot
.40352 .46591 Mdot
.34715 .77544 Mdot
.60561 .71778 Mdot
.18608 .38229 Mdot
.46603 .37611 Mdot
.67159 .54799 Mdot
.46053 .50608 Mdot
.63421 .62341 Mdot
.68656 .37091 Mdot
.70982 .705 Mdot
.65229 .79851 Mdot
.6288 .67789 Mdot
.31683 .78227 Mdot
.46271 .73838 Mdot
.49782 .14131 Mdot
.41644 .40775 Mdot
.61779 .54916 Mdot
.26091 .41025 Mdot
.68281 .27776 Mdot
.76508 .42754 Mdot
.50842 .52681 Mdot
.58854 .31281 Mdot
.2761 .56426 Mdot
.65844 .57749 Mdot
.59639 .64334 Mdot
.38467 .31221 Mdot
.77424 .41783 Mdot
.22738 .48077 Mdot
.69792 .73138 Mdot
.53907 .48604 Mdot
.67634 .46632 Mdot
.51414 .24148 Mdot
.76528 .27353 Mdot
.30184 .66521 Mdot
.57192 .8136 Mdot
.67543 .36018 Mdot
.70549 .54266 Mdot
.39863 .223 Mdot
.292 .61032 Mdot
.68345 .27621 Mdot
.79299 .36888 Mdot
.47137 .8478 Mdot
.81992 .39183 Mdot
.68192 .62534 Mdot
.40332 .58289 Mdot
.56599 .80582 Mdot
.3871 .7192 Mdot
.29297 .50659 Mdot
.82569 .49511 Mdot
.26294 .48129 Mdot
.6636 .62805 Mdot
.45754 .20694 Mdot
.61827 .6884 Mdot
.22047 .61679 Mdot
.24838 .45233 Mdot
.51206 .57588 Mdot
.25395 .23492 Mdot
.80669 .59665 Mdot
.744 .4699 Mdot
.63109 .82513 Mdot
.70195 .35842 Mdot
.25577 .6384 Mdot
.65005 .39031 Mdot
.7948 .6549 Mdot
.64901 .57326 Mdot
.86316 .56775 Mdot
.75287 .70139 Mdot
.25822 .30955 Mdot
.10452 .47491 Mdot
.6231 .26611 Mdot
.52992 .50747 Mdot
.40455 .47858 Mdot
.23894 .56046 Mdot
.30467 .26031 Mdot
.22239 .34942 Mdot
.6946 .3148 Mdot
.31406 .75723 Mdot
.79533 .63895 Mdot
.33606 .70782 Mdot
.25997 .68603 Mdot
.43756 .20703 Mdot
.48905 .43663 Mdot
.59721 .60987 Mdot
.44803 .41385 Mdot
.7507 .59774 Mdot
.83333 .46997 Mdot
.37473 .70028 Mdot
.12512 .4916 Mdot
.25689 .44039 Mdot
.346 .37462 Mdot
.57658 .82912 Mdot
.27415 .53917 Mdot
.35891 .70514 Mdot
.56957 .19196 Mdot
.41656 .54374 Mdot
.60705 .21186 Mdot
.75969 .56078 Mdot
.49664 .2711 Mdot
.64611 .24547 Mdot
.70158 .50767 Mdot
.40345 .78988 Mdot
.58602 .78614 Mdot
.69599 .2835 Mdot
.68457 .60706 Mdot
.27441 .60076 Mdot
.31218 .68036 Mdot
.61887 .83262 Mdot
.46002 .24559 Mdot
.52285 .88005 Mdot
.41941 .24002 Mdot
.48308 .64975 Mdot
.53828 .57256 Mdot
.39974 .66768 Mdot
.28852 .62962 Mdot
.39799 .58735 Mdot
.69964 .3282 Mdot
.60297 .84078 Mdot
.43499 .74755 Mdot
.50015 .28221 Mdot
.78035 .38197 Mdot
.48866 .86456 Mdot
.48876 .8022 Mdot
.36175 .33722 Mdot
.39189 .69049 Mdot
.61109 .17898 Mdot
.42727 .34119 Mdot
.3323 .70767 Mdot
.66695 .40481 Mdot
.30867 .31526 Mdot
.67863 .70777 Mdot
.28683 .29137 Mdot
.60159 .84196 Mdot
.49601 .20109 Mdot
.37896 .27235 Mdot
.21425 .48747 Mdot
.20658 .60799 Mdot
.79859 .41906 Mdot
.39583 .63675 Mdot
.55702 .54342 Mdot
.25475 .47595 Mdot
.50109 .77735 Mdot
.35991 .72205 Mdot
.29081 .38294 Mdot
.53506 .59901 Mdot
.22628 .38457 Mdot
.49531 .40565 Mdot
.5838 .4613 Mdot
.84532 .39604 Mdot
.43433 .54412 Mdot
.64097 .28666 Mdot
.44511 .83308 Mdot
.26319 .61498 Mdot
.57896 .82297 Mdot
.66752 .48499 Mdot
.8151 .39148 Mdot
.73005 .72775 Mdot
.28665 .36504 Mdot
.82825 .55254 Mdot
.59701 .85659 Mdot
.79512 .35298 Mdot
.55884 .61431 Mdot
.62725 .35137 Mdot
.89146 .4534 Mdot
.48056 .40235 Mdot
.75401 .3383 Mdot
.40211 .73206 Mdot
.52148 .32353 Mdot
.69837 .60685 Mdot
.36578 .62692 Mdot
.50928 .47984 Mdot
.67772 .53545 Mdot
.48763 .55279 Mdot
.80154 .32699 Mdot
.76868 .33199 Mdot
.81341 .35917 Mdot
.39863 .81425 Mdot
.82907 .55884 Mdot
.46215 .48528 Mdot
.61625 .70433 Mdot
.40008 .5158 Mdot
.43611 .64274 Mdot
.32916 .57762 Mdot
.61873 .26522 Mdot
.26774 .33428 Mdot
.75419 .41568 Mdot
.65409 .62571 Mdot
.80699 .53637 Mdot
.72613 .20145 Mdot
.48213 .73921 Mdot
.50924 .70248 Mdot
.64078 .25821 Mdot
.30304 .64704 Mdot
.75408 .58404 Mdot
.258 .32732 Mdot
.59709 .83454 Mdot
.42799 .5139 Mdot
.34049 .72861 Mdot
.30901 .40048 Mdot
.18979 .53627 Mdot
.38 .44207 Mdot
.7169 .71861 Mdot
.39362 .49747 Mdot
.3339 .27237 Mdot
.59552 .50739 Mdot
.26407 .29527 Mdot
.32304 .3417 Mdot
.54261 .26283 Mdot
.31582 .709 Mdot
.62418 .30969 Mdot
.3252 .66791 Mdot
.51096 .45714 Mdot
.34976 .56995 Mdot
.41424 .47147 Mdot
.32686 .67289 Mdot
.19137 .52621 Mdot
.83611 .48413 Mdot
.59167 .86718 Mdot
.71765 .24679 Mdot
.33017 .79137 Mdot
.75442 .55087 Mdot
.38934 .58632 Mdot
.55392 .84682 Mdot
.83778 .41272 Mdot
.72539 .73987 Mdot
.51082 .20906 Mdot
.501 .34355 Mdot
.59331 .3997 Mdot
.72244 .25638 Mdot
.34749 .42179 Mdot
.63365 .79599 Mdot
.62346 .208 Mdot
.66192 .3565 Mdot
.42538 .18825 Mdot
.75437 .32316 Mdot
.68142 .69362 Mdot
.54127 .65084 Mdot
.39692 .55966 Mdot
.6408 .67081 Mdot
.68835 .57059 Mdot
.49705 .23833 Mdot
.29202 .62119 Mdot
.42328 .34853 Mdot
.32975 .52163 Mdot
.53681 .53398 Mdot
.51696 .59915 Mdot
.36411 .48198 Mdot
.68244 .55205 Mdot
.80052 .49679 Mdot
.57395 .4266 Mdot
.85002 .54689 Mdot
.59903 .26108 Mdot
.53861 .60951 Mdot
.27342 .6286 Mdot
.38979 .27577 Mdot
.55025 .18526 Mdot
.667 .39132 Mdot
.76373 .66439 Mdot
.50418 .40829 Mdot
.27674 .60573 Mdot
.63856 .66581 Mdot
.41923 .78992 Mdot
.3796 .64116 Mdot
.74815 .49393 Mdot
.56486 .77543 Mdot
.58061 .46425 Mdot
.61437 .61971 Mdot
.58321 .59674 Mdot
.43563 .86851 Mdot
.6002 .22894 Mdot
.52495 .25675 Mdot
.75627 .67418 Mdot
.62731 .36749 Mdot
.62625 .55705 Mdot
.32799 .60505 Mdot
.40882 .79661 Mdot
.58818 .75279 Mdot
.35161 .32165 Mdot
.58162 .29638 Mdot
.31072 .37893 Mdot
.7673 .64373 Mdot
.77473 .6216 Mdot
.2462 .29091 Mdot
.62778 .61781 Mdot
.44763 .8025 Mdot
.35078 .74952 Mdot
.66795 .55217 Mdot
.70339 .60771 Mdot
.7581 .39447 Mdot
.84605 .50836 Mdot
.61999 .45141 Mdot
.30672 .75909 Mdot
.20653 .53959 Mdot
.52967 .34187 Mdot
.35535 .28133 Mdot
.28768 .6949 Mdot
.74903 .68267 Mdot
.61569 .6473 Mdot
.70048 .67549 Mdot
.44907 .66913 Mdot
.47876 .6773 Mdot
.6992 .22483 Mdot
.45818 .43288 Mdot
.63912 .69684 Mdot
.68722 .50286 Mdot
.44599 .56593 Mdot
.76733 .27765 Mdot
.47181 .83375 Mdot
.55409 .17913 Mdot
.59631 .36196 Mdot
.48901 .58389 Mdot
.40181 .63546 Mdot
.41646 .69683 Mdot
.73241 .47776 Mdot
.78158 .36274 Mdot
.29063 .69868 Mdot
.72952 .54109 Mdot
.60766 .65645 Mdot
.64121 .28753 Mdot
.68899 .73883 Mdot
.53293 .83615 Mdot
.54998 .45203 Mdot
.6083 .25986 Mdot
.23049 .51213 Mdot
.34044 .79276 Mdot
.43019 .45662 Mdot
.46708 .49073 Mdot
.72734 .35854 Mdot
.70946 .49012 Mdot
.3323 .28778 Mdot
.48138 .62857 Mdot
.46324 .21122 Mdot
.66804 .7685 Mdot
.17544 .38616 Mdot
.34442 .24178 Mdot
.78078 .29111 Mdot
.6174 .75494 Mdot
.69293 .48739 Mdot
.73109 .64917 Mdot
.15943 .40223 Mdot
.39903 .46395 Mdot
.80349 .56711 Mdot
.21758 .49842 Mdot
.76213 .65919 Mdot
.65385 .35559 Mdot
.69014 .42609 Mdot
.77754 .37646 Mdot
.84089 .52893 Mdot
.51051 .80818 Mdot
.71922 .70928 Mdot
.58931 .50492 Mdot
.85065 .47022 Mdot
.7308 .34107 Mdot
.48416 .47102 Mdot
.42007 .37109 Mdot
.54889 .19503 Mdot
.76443 .59927 Mdot
.78218 .52669 Mdot
.3334 .71329 Mdot
.41755 .44535 Mdot
.34071 .63765 Mdot
.68565 .67067 Mdot
.30257 .54319 Mdot
.71679 .50073 Mdot
.27231 .6273 Mdot
.66955 .77543 Mdot
.39116 .45663 Mdot
.37992 .27945 Mdot
.63092 .28957 Mdot
.25202 .68883 Mdot
.7353 .47282 Mdot
.59046 .2249 Mdot
.57726 .81305 Mdot
.33143 .36097 Mdot
.29505 .67794 Mdot
.57211 .90367 Mdot
.30413 .72795 Mdot
.79485 .45506 Mdot
.83201 .46717 Mdot
.56369 .83069 Mdot
.80115 .47817 Mdot
.31867 .24768 Mdot
.43754 .70711 Mdot
.3176 .60787 Mdot
.43411 .60068 Mdot
.83997 .39268 Mdot
.28876 .56424 Mdot
.83586 .46294 Mdot
.52188 .85805 Mdot
.65306 .67018 Mdot
.51788 .59649 Mdot
.47192 .35794 Mdot
.39282 .35036 Mdot
.31612 .53985 Mdot
.70996 .67587 Mdot
.43348 .71173 Mdot
.58991 .27665 Mdot
.40225 .3384 Mdot
.35703 .42921 Mdot
.7224 .61029 Mdot
.58082 .24547 Mdot
.72819 .49218 Mdot
.33673 .48764 Mdot
.56154 .48074 Mdot
.31112 .66214 Mdot
.57452 .64121 Mdot
.67683 .69973 Mdot
.2929 .28617 Mdot
.5139 .40691 Mdot
.46023 .37399 Mdot
.65793 .73487 Mdot
.32332 .75578 Mdot
.72829 .51714 Mdot
.80868 .39123 Mdot
.53349 .1899 Mdot
.36639 .53064 Mdot
.33968 .67855 Mdot
.2888 .27755 Mdot
.1785 .53328 Mdot
.80977 .5063 Mdot
.587 .61968 Mdot
.2351 .62793 Mdot
.52569 .52442 Mdot
.81867 .5983 Mdot
.31456 .71809 Mdot
.37937 .73835 Mdot
.43198 .41475 Mdot
.58984 .72987 Mdot
.67274 .66264 Mdot
.24925 .53772 Mdot
.57972 .48888 Mdot
.51379 .14075 Mdot
.70466 .57281 Mdot
.744 .24258 Mdot
.6181 .40905 Mdot
.47658 .17661 Mdot
.20428 .4841 Mdot
.51086 .45374 Mdot
.58676 .49217 Mdot
.75242 .48726 Mdot
.72818 .39742 Mdot
.35932 .79486 Mdot
.22426 .33541 Mdot
.48884 .39613 Mdot
.25726 .66902 Mdot
.22239 .65456 Mdot
.68831 .71224 Mdot
.49837 .55932 Mdot
.29915 .72767 Mdot
.46696 .43511 Mdot
.27141 .32947 Mdot
.53367 .84729 Mdot
.76803 .5229 Mdot
.50979 .64192 Mdot
.30045 .64085 Mdot
.79945 .57178 Mdot
.7315 .72079 Mdot
.378 .20673 Mdot
.75952 .55998 Mdot
.61932 .35343 Mdot
.46913 .47877 Mdot
.74112 .66552 Mdot
.24112 .6136 Mdot
.66913 .46204 Mdot
.30817 .68054 Mdot
.64777 .17024 Mdot
.79062 .38121 Mdot
.78107 .36252 Mdot
.26394 .64025 Mdot
.60592 .6035 Mdot
.74819 .36105 Mdot
.35006 .70157 Mdot
.76921 .50943 Mdot
.36469 .78498 Mdot
.32329 .68775 Mdot
.23696 .28663 Mdot
.42018 .76265 Mdot
.47055 .33784 Mdot
.68094 .65518 Mdot
.43363 .75769 Mdot
.6122 .35229 Mdot
.32067 .58009 Mdot
.6962 .50953 Mdot
.59885 .40362 Mdot
.72239 .50091 Mdot
.6952 .46783 Mdot
.39057 .74878 Mdot
.60542 .74307 Mdot
.73684 .54425 Mdot
.64061 .76147 Mdot
.62409 .52654 Mdot
.3056 .30736 Mdot
.42294 .27994 Mdot
.68925 .51415 Mdot
.44428 .38874 Mdot
.42136 .52505 Mdot
.57129 .46274 Mdot
.34826 .50684 Mdot
.70091 .24036 Mdot
.26146 .48244 Mdot
.60591 .58897 Mdot
.5154 .16289 Mdot
.65914 .54684 Mdot
.81642 .34931 Mdot
.27034 .31414 Mdot
.63057 .66535 Mdot
.29753 .35874 Mdot
.27946 .4023 Mdot
.37238 .17374 Mdot
.70975 .63522 Mdot
.42628 .40558 Mdot
.59554 .55491 Mdot
.62808 .6111 Mdot
.60761 .28869 Mdot
.4024 .33462 Mdot
.52082 .67178 Mdot
.67017 .32307 Mdot
.38515 .51995 Mdot
.59777 .56775 Mdot
.49891 .36183 Mdot
.34508 .65838 Mdot
.84609 .52152 Mdot
.44964 .37385 Mdot
.59408 .16106 Mdot
.47855 .6551 Mdot
.54903 .79562 Mdot
.58698 .84474 Mdot
.40206 .19642 Mdot
.42437 .26477 Mdot
.17451 .59087 Mdot
.48511 .64674 Mdot
.74298 .55224 Mdot
.65765 .57317 Mdot
.36528 .73485 Mdot
.29927 .4801 Mdot
.24976 .59019 Mdot
.61197 .4166 Mdot
.33537 .27309 Mdot
.57219 .24553 Mdot
.59973 .59164 Mdot
.77093 .54269 Mdot
.43867 .78743 Mdot
.6996 .4185 Mdot
.47409 .43729 Mdot
.68604 .71111 Mdot
.59832 .74385 Mdot
.59862 .56523 Mdot
.81027 .41032 Mdot
.33675 .7308 Mdot
.80604 .64676 Mdot
.41689 .67245 Mdot
.39437 .38975 Mdot
.71183 .35111 Mdot
.73893 .50475 Mdot
.56092 .64049 Mdot
.60305 .83437 Mdot
.28393 .60423 Mdot
.70557 .338 Mdot
.32541 .65758 Mdot
.36405 .58566 Mdot
.5433 .47545 Mdot
.5051 .22855 Mdot
.28747 .24236 Mdot
.50094 .67151 Mdot
.40631 .2127 Mdot
.58035 .60957 Mdot
.63788 .28321 Mdot
.69309 .54951 Mdot
.48054 .30751 Mdot
.60393 .72474 Mdot
.44563 .25065 Mdot
.81367 .61696 Mdot
.59941 .83602 Mdot
.63473 .33974 Mdot
.59937 .29927 Mdot
.64095 .51146 Mdot
.45705 .67046 Mdot
.61826 .48469 Mdot
.40279 .59598 Mdot
.71689 .58752 Mdot
.42903 .18297 Mdot
.76131 .50375 Mdot
.37552 .58413 Mdot
.8116 .60042 Mdot
.79078 .66172 Mdot
.84762 .471 Mdot
.21839 .62105 Mdot
.68312 .58542 Mdot
.7963 .34485 Mdot
.5411 .67403 Mdot
.68062 .7705 Mdot
.80474 .51454 Mdot
.45708 .87376 Mdot
.7031 .67873 Mdot
.67309 .49497 Mdot
.23157 .33444 Mdot
.72312 .42261 Mdot
.50182 .84596 Mdot
.46453 .46364 Mdot
.52447 .27565 Mdot
.50184 .85009 Mdot
.2901 .20997 Mdot
.569 .60869 Mdot
.68443 .46804 Mdot
.50416 .51284 Mdot
.69341 .51369 Mdot
.36401 .36279 Mdot
.42789 .64006 Mdot
.58973 .32732 Mdot
.36661 .2745 Mdot
.31417 .66922 Mdot
.33932 .63538 Mdot
.36298 .36512 Mdot
.32466 .53748 Mdot
.33084 .65417 Mdot
.30502 .7143 Mdot
.69223 .69581 Mdot
.53095 .66452 Mdot
.45894 .66413 Mdot
.70295 .5592 Mdot
.3168 .4658 Mdot
.46385 .26702 Mdot
.4109 .61992 Mdot
.44453 .2545 Mdot
.71359 .40964 Mdot
.78765 .30356 Mdot
.4976 .30023 Mdot
.44421 .82016 Mdot
.69761 .56559 Mdot
.73803 .48293 Mdot
.63431 .77366 Mdot
.45527 .20096 Mdot
.3673 .39827 Mdot
.37423 .70016 Mdot
.79483 .61221 Mdot
.64614 .24705 Mdot
.39545 .77821 Mdot
.70146 .26798 Mdot
.59575 .37893 Mdot
.54022 .63159 Mdot
.48865 .5039 Mdot
.51002 .20299 Mdot
.60227 .61106 Mdot
.67843 .49496 Mdot
.4181 .42441 Mdot
.62372 .22937 Mdot
.44874 .8359 Mdot
.42835 .78767 Mdot
.6995 .64806 Mdot
.77826 .6207 Mdot
.41058 .32145 Mdot
.34606 .73649 Mdot
.64185 .47848 Mdot
.38044 .40305 Mdot
.69999 .29686 Mdot
.84015 .56397 Mdot
.61192 .48692 Mdot
.27051 .55767 Mdot
.46665 .56726 Mdot
.55117 .68911 Mdot
.76109 .49384 Mdot
.27749 .43059 Mdot
.56725 .26123 Mdot
.62203 .59871 Mdot
.54537 .24786 Mdot
.36545 .44656 Mdot
.31303 .59722 Mdot
.60504 .54856 Mdot
.40789 .71879 Mdot
.28652 .50423 Mdot
.64278 .31963 Mdot
.43567 .55428 Mdot
.25843 .56517 Mdot
.21382 .6079 Mdot
.54917 .62036 Mdot
.75923 .5913 Mdot
.67621 .71642 Mdot
.39154 .78649 Mdot
.74415 .52146 Mdot
.81163 .4972 Mdot
.73169 .40153 Mdot
.62433 .71704 Mdot
.45246 .22975 Mdot
.40266 .58149 Mdot
.48342 .30973 Mdot
.6219 .55721 Mdot
.72276 .68106 Mdot
.6049 .76072 Mdot
.25854 .54205 Mdot
.52846 .43831 Mdot
.61536 .78517 Mdot
.5172 .42653 Mdot
.57034 .84401 Mdot
.72483 .4231 Mdot
.29198 .61852 Mdot
.67373 .38696 Mdot
.20912 .49326 Mdot
.30568 .26456 Mdot
.77559 .66892 Mdot
.27347 .29686 Mdot
.54213 .50178 Mdot
.41153 .20654 Mdot
.7799 .41255 Mdot
.51504 .85424 Mdot
.30214 .62347 Mdot
.61625 .48257 Mdot
.34422 .63609 Mdot
.64667 .34143 Mdot
.52043 .39524 Mdot
.46976 .30839 Mdot
.52202 .67799 Mdot
.55549 .30356 Mdot
.42016 .2553 Mdot
.37474 .64322 Mdot
.71441 .31363 Mdot
.78661 .6156 Mdot
.38697 .73418 Mdot
.47902 .44567 Mdot
.28267 .33934 Mdot
.30815 .58901 Mdot
.28409 .7803 Mdot
.7651 .27238 Mdot
.46706 .56619 Mdot
.41971 .46795 Mdot
.26277 .58555 Mdot
.48513 .3885 Mdot
.48946 .6961 Mdot
.70001 .70614 Mdot
.61068 .39951 Mdot
.49381 .33746 Mdot
.61364 .22211 Mdot
.7579 .48149 Mdot
.27758 .52939 Mdot
.68599 .30603 Mdot
.80159 .31844 Mdot
.33041 .76883 Mdot
.74897 .50573 Mdot
.34126 .82352 Mdot
.49032 .2202 Mdot
.58189 .59862 Mdot
.56248 .80914 Mdot
.83742 .48325 Mdot
.2655 .62229 Mdot
.33008 .3026 Mdot
.80821 .45835 Mdot
.29042 .60961 Mdot
.33891 .70099 Mdot
.63011 .28866 Mdot
.55225 .2514 Mdot
.51192 .47083 Mdot
.28159 .40244 Mdot
.72938 .29245 Mdot
.62161 .65311 Mdot
.79182 .5962 Mdot
.36848 .26915 Mdot
.21813 .30428 Mdot
.79577 .65399 Mdot
.33213 .55493 Mdot
.36203 .35104 Mdot
.54874 .81226 Mdot
.21902 .56709 Mdot
.38994 .71575 Mdot
.29998 .29506 Mdot
.57209 .75719 Mdot
.25778 .3948 Mdot
.39298 .23359 Mdot
.32573 .66881 Mdot
.43223 .75396 Mdot
.60839 .48759 Mdot
.66367 .71998 Mdot
.60389 .27806 Mdot
.2744 .64587 Mdot
.47483 .32803 Mdot
.22099 .54754 Mdot
.6655 .73136 Mdot
.60582 .7972 Mdot
.63493 .49249 Mdot
.31485 .19525 Mdot
.81747 .51322 Mdot
.44593 .20744 Mdot
.39819 .58046 Mdot
.82574 .60051 Mdot
.63927 .48589 Mdot
.8161 .47947 Mdot
.41718 .81104 Mdot
.46034 .28926 Mdot
.71334 .36785 Mdot
.40125 .58664 Mdot
.78081 .56281 Mdot
.64371 .69476 Mdot
.44148 .76138 Mdot
.34356 .27998 Mdot
.27481 .62518 Mdot
.36295 .32697 Mdot
.23574 .53558 Mdot
.53078 .62826 Mdot
.61625 .55834 Mdot
.82211 .37369 Mdot
.54754 .50912 Mdot
.41607 .52879 Mdot
.46827 .67403 Mdot
.24334 .317 Mdot
.25076 .71669 Mdot
.44499 .67379 Mdot
.66007 .2593 Mdot
.32733 .70163 Mdot
.36012 .54735 Mdot
.60793 .63566 Mdot
.09234 .53815 Mdot
.61357 .84551 Mdot
.66449 .61991 Mdot
.43932 .71924 Mdot
.26449 .65723 Mdot
.84046 .49502 Mdot
.31079 .39901 Mdot
.41827 .27705 Mdot
.18254 .40407 Mdot
.22107 .58244 Mdot
.50555 .61505 Mdot
.43241 .82916 Mdot
.76608 .67903 Mdot
.35311 .26913 Mdot
.80804 .61116 Mdot
.46039 .53167 Mdot
.40326 .64055 Mdot
.15172 .64376 Mdot
.74226 .67249 Mdot
.41209 .54513 Mdot
.24649 .3089 Mdot
.60097 .61288 Mdot
.4207 .60399 Mdot
.65965 .29788 Mdot
.31133 .70893 Mdot
.33177 .67223 Mdot
.84121 .52716 Mdot
.60362 .60752 Mdot
.43659 .2557 Mdot
.60531 .3895 Mdot
.58341 .49131 Mdot
.43205 .66237 Mdot
.64984 .37846 Mdot
.35404 .54498 Mdot
.67057 .50294 Mdot
.62273 .34694 Mdot
.26259 .68378 Mdot
.5067 .87869 Mdot
.63109 .74156 Mdot
.59992 .34686 Mdot
.35843 .63499 Mdot
.42445 .76376 Mdot
.31915 .53966 Mdot
.41188 .50433 Mdot
.49075 .85558 Mdot
.722 .79509 Mdot
.53175 .28073 Mdot
.4015 .68262 Mdot
.60284 .55091 Mdot
.54243 .65796 Mdot
.67671 .68735 Mdot
.60625 .43168 Mdot
.40429 .32626 Mdot
.51901 .60878 Mdot
.53242 .62646 Mdot
.61221 .41557 Mdot
.71939 .22902 Mdot
.46204 .63734 Mdot
.59563 .63528 Mdot
.69015 .75919 Mdot
.30788 .30499 Mdot
.52585 .79577 Mdot
.47246 .64788 Mdot
.74232 .35878 Mdot
.62456 .47718 Mdot
.72686 .56081 Mdot
.3814 .27812 Mdot
.82274 .55163 Mdot
.599 .76405 Mdot
.68981 .64901 Mdot
.46363 .62682 Mdot
.32386 .47465 Mdot
.69052 .45662 Mdot
.8112 .4505 Mdot
.55378 .58258 Mdot
.70791 .74986 Mdot
.4554 .2895 Mdot
.56784 .3075 Mdot
.37332 .54233 Mdot
.83493 .42785 Mdot
.37671 .22988 Mdot
.66276 .67921 Mdot
.52161 .17694 Mdot
.5622 .21293 Mdot
.30201 .5453 Mdot
.46681 .34684 Mdot
.37035 .59805 Mdot
.59549 .60001 Mdot
.8192 .33544 Mdot
.80838 .43951 Mdot
.56196 .39774 Mdot
.54581 .26684 Mdot
.59414 .68463 Mdot
.61038 .49762 Mdot
.41857 .86846 Mdot
.34046 .41107 Mdot
.79621 .30952 Mdot
.37014 .7381 Mdot
.72468 .61494 Mdot
.69589 .49489 Mdot
.54058 .58094 Mdot
.45511 .36518 Mdot
.83615 .51245 Mdot
.53883 .61941 Mdot
.42732 .22981 Mdot
.49395 .62627 Mdot
.57674 .18555 Mdot
.5478 .40714 Mdot
.60877 .30256 Mdot
.61976 .31124 Mdot
.31982 .24859 Mdot
.65372 .77231 Mdot
.59414 .45643 Mdot
.37607 .83643 Mdot
.7339 .65148 Mdot
.76425 .66497 Mdot
.34671 .32728 Mdot
.37119 .19951 Mdot
.78684 .52408 Mdot
.73401 .53588 Mdot
.56001 .40602 Mdot
.37781 .49476 Mdot
.53313 .19431 Mdot
.35413 .55272 Mdot
.70772 .44565 Mdot
.65393 .34651 Mdot
.81013 .73276 Mdot
.33665 .56066 Mdot
.52579 .5363 Mdot
.46675 .217 Mdot
.78235 .64058 Mdot
.33549 .45856 Mdot
.45644 .84822 Mdot
.40665 .46518 Mdot
.40367 .64322 Mdot
.59449 .7554 Mdot
.37846 .73175 Mdot
.5617 .19614 Mdot
.42856 .14619 Mdot
.33801 .77044 Mdot
.55807 .2898 Mdot
.56105 .47421 Mdot
.66697 .55258 Mdot
.69598 .60962 Mdot
.28993 .3764 Mdot
.4088 .83415 Mdot
.67112 .49727 Mdot
.74123 .66658 Mdot
.35444 .18655 Mdot
.38582 .76049 Mdot
.8428 .49744 Mdot
.7922 .4816 Mdot
.70824 .57319 Mdot
.33273 .53536 Mdot
.23602 .4885 Mdot
.59007 .32978 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0/Ooo
ool2o`0009Kooooo000Looooo`03o`000?oooooooooo0;7ooooo0_l0002Fooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo09[ooooo0_l00002ooooo`;o00000oooool2o`000:Cooooo000Loooo
o`03o`000?oooooooooo09[ooooo0_l00002ooooo`;o00000oooool2o`000:Cooooo000Looooo`03
o`000?oooooooooo08Oooooo0_l0000Iooooo`;o0000YOooool001cooooo00?o0000ooooooooool0
Qoooool2o`0000;ooooo0_l0000Eooooo`;o0000YOooool001cooooo0_l0002<ooooo`;o0000_?oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0:Cooooo0_l0000;ooooo`;o00002_ooool2o`0008[o
oooo000Looooo`03o`000?oooooooooo0:Cooooo0_l000000ooooooo0000o`000008ooooo`;o0000
2_ooool2o`0008[ooooo000Looooo`03o`000?oooooooooo0:Oooooo0_l0000Oooooo`;o0000Oooo
ool001cooooo00?o0000ooooooooool0N_ooool2o`0004cooooo0_l00005ooooo`;o0000N?ooool0
01cooooo00?o0000ooooooooool0MOooool2o`0000?ooooo0_l00010ooooo`;o00004Oooool2o`00
07Sooooo000Looooo`03o`000?oooooooooo07Gooooo0_l0000Pooooo`;o00003Oooool2o`0000Go
oooo0_l00003ooooo`?o00001oooool2o`0008_ooooo000Looooo`03o`000?oooooooooo097ooooo
0_l00004ooooo`;o00001Oooool2o`0000Kooooo0_l00002ooooo`;o000000Coooooo`000?l0003o
oooo1Ol0000>ooooo`;o0000Q?ooool001cooooo00?o0000ooooooooool0L_ooool2o`0001Cooooo
0_l00007ooooo`;o00002?ooool2o`000003ooooool0003o000000Sooooo1?l00004ooooo`;o0000
4Oooool2o`0000[ooooo0_l0001hooooo`007?ooool00ol0003oooooooooo`1_ooooo`;o000000?o
ooooo`000?l000005?ooool6o`0000gooooo0_l0000;ooooo`;o00000_ooool2o`000003ooooool0
003o000000Oooooo0_l0000Eooooo`;o0000N?ooool001cooooo00?o0000ooooooooool0Koooool2
o`0001Gooooo0_l00002ooooo`Co000000?oooooo`000?l000000_l00003ooooo`;o00002oooool3
o`0000Cooooo1?l000000ooooooo0000o`000002ooooo`;o00000oooool2o`0000Wooooo0_l00024
ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o
0000ooooooooool0Q_ooool2o`0000Cooooo0_l000000ooooooo0000o`000003o`0000;ooooo0_l0
0009ooooo`Go00001?ooool2o`0000Oooooo1ol00003ooooo`;o00001?ooool2o`0008Cooooo0000
1_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01_ooool00ol0003oooooooooo`1Sooooo`;o00006_ooool2o`0000_ooooo0_l00003ooooo`Ko
00002_ooool2o`0000Kooooo0_l00004ooooo`;o00000_ooool7o`0000?ooooo0_l0002:ooooo`00
00?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo
00?o0000ooooooooool0Hoooool2o`00013ooooo0_l00008ooooo`;o00003_ooool2o`0000;ooooo
1?l00003ooooo`;o000000?oooooo`000?l000001_ooool2o`0000;ooooo0_l00004ooooo`;o0000
0_ooool2o`0000Kooooo0_l00006ooooo`;o0000Q?ooool00003ooooool0003ooooo00;ooooo00?o
0000ooooooooool02oooool00onHV9So8B4Qonk^kP06ooooo`?o0000MOooool2o`0000Cooooo0_l0
000;ooooo`;o00001Oooool3o`000003ooooool0003o000000?ooooo1ol00003ooooo`Go00005?oo
ool2o`0000?ooooo0_l000001?oooooo0000o`000?l0000Rooooo`;o0000Goooool00003ooooool0
003ooooo00;ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oo
oooooooo07_ooooo0_l0000;ooooo`;o00001_ooool2o`0000;ooooo0_l00002ooooo`;o000000?o
ooooo`000?l000000_l00003ooooo`?o00005_ooool2o`0000?ooooo0_l00002ooooo`;o00008_oo
ool2o`0005oooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`1Rooooo`;o00004oooool2o`0000Cooooo0_l00003
ooooo`;o00001_ooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000006
ooooo`;o00001?ooool4o`0001Gooooo0_l00003ooooo`Ko000000?oooooo`000?l000000_l0001n
ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
1_ooool00ol0003oooooooooo`1Kooooo`;o00001Oooool2o`0001?ooooo0_l00004ooooo`;o0000
0oooool2o`0000Kooooo0_l000000ooooooo0000o`000002ooooo`Co00001oooool2o`0000?ooooo
1Ol0000Kooooo`Go000000?oooooo`000?l000000_l000000ooooooo0000o`00001kooooo`0000Ko
ooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0
003oooooooooo`1Kooooo`;o00004oooool2o`0000kooooo0_l0000Aooooo`;o00003?ooool2o`00
013ooooo0_l0000<ooooo`Co00001?ooool2o`000003ooooool0003o000007_ooooo000Looooo`03
o`000?oooooooooo073ooooo0ol00006ooooo`;o000000?oooooo`000?l000000_ooool2o`0000co
oooo0_l00003ooooo`?o00007Oooool2o`0000kooooo0_l00024ooooo`007?ooool00ol0003ooooo
ooooo`1aooooo`;o00001_ooool2o`000003ooooool0003o000000Sooooo0_l00006ooooo`;o0000
0oooool3o`0000Kooooo0_l0000?ooooo`;o00005Oooool2o`0008?ooooo000Looooo`03o`000?oo
oooooooo07Gooooo1?l00005ooooo`;o00001_ooool2o`0000Oooooo0_l0000;ooooo`;o00002_oo
ool2o`0000?ooooo0_l0000Cooooo`Co00007?ooool2o`0006Gooooo000Looooo`03o`000?oooooo
oooo06Sooooo0_l0000;ooooo`Co00001Oooool2o`0000;ooooo0_l000000ooooooo0000o`000002
o`0000?ooooo1Ol0000Gooooo`;o00000oooool3o`0000_ooooo0ol00003ooooo`Go00001Oooool2
o`0000;ooooo0_l0000>ooooo`;o000000?oooooo`000?l00000IOooool001cooooo00?o0000oooo
ooooool0J?ooool2o`0000Oooooo0_l00004ooooo`?o00002?ooool2o`000003ooooool0003o0000
00?o00000_ooool5o`000003ooooool0003o000000Oooooo0_l00003ooooo`;o00003?ooool2o`00
00_ooooo0ol000000ooooooo0000o`000003o`0000?ooooo0_l000001?oooooo0000o`000?l00002
ooooo`;o00003_ooool2o`0000Gooooo0_l0001Qooooo`007?ooool00ol0003oooooooooo`1Koooo
o`;o00004_ooool5o`0000?ooooo0ol00002ooooo`;o00002Oooool3o`000003ooooool0003o0000
00;ooooo1Ol00004ooooo`;o000000?oooooo`000?l000000oooool2o`0000cooooo0_l0000?oooo
o`?o00000_ooool2o`000004ooooool0003o0000ooooo`Co00000oooool2o`0001?ooooo0_l0001Q
ooooo`007?ooool00ol0003oooooooooo`1?ooooo`;o00002_ooool2o`0000Wooooo0_l00005oooo
o`Co000000?oooooo`000?l000002?ooool2o`0000gooooo0_l00004ooooo`;o00001Oooool2o`00
01?ooooo0ol0000Dooooo`;o00001_ooool2o`0000?ooooo0_l0000;ooooo`Co0000Ioooool001co
oooo00?o0000ooooooooool0Coooool2o`0001Gooooo0_l00005ooooo`;o000000?oooooo`000?l0
00003Oooool2o`0000?ooooo0_l0000;ooooo`;o00002oooool3o`0000cooooo0_l0000<ooooo`;o
00008Oooool4o`000003ooooool0003o000006Cooooo000Looooo`03o`000?oooooooooo05Oooooo
0_l000000ooooooo0000o`00000@ooooo`;o00000_ooool2o`0000Oooooo0_l00004ooooo`;o0000
0oooool2o`0000_ooooo0_l0000;ooooo`?o000000Coooooo`000?l0003o00005_ooool2o`0002?o
oooo0_l000000ooooooo0000o`000009ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0
Eoooool2o`000003ooooool0003o0000013ooooo0_l0000;ooooo`;o00005?ooool5o`000003oooo
ool0003o000000Sooooo1_l0000Aooooo`;o000000?oooooo`000?l000004oooool2o`00013ooooo
0_l0000<ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0I?ooool2o`0000Cooooo0_l0
000Sooooo`Go000000?oooooo`000?l000002?ooool4o`0000[ooooo0_l00007ooooo`;o000000?o
ooooo`000?l000002_ooool2o`0000Oooooo1?l0000Cooooo`;o0000H_ooool001cooooo0_l0001D
ooooo`;o00003oooool2o`0000Cooooo0_l0000Dooooo`;o00002oooool2o`0000;ooooo0_l0000J
ooooo`;o000000?oooooo`000?l000004oooool2o`000003ooooool0003o000000Cooooo1?l0000C
ooooo`;o0000H_ooool001cooooo00?o0000ooooooooool0Doooool2o`0000Oooooo0_l00004oooo
o`Co00006_ooool2o`0000?ooooo0_l00006ooooo`;o00003Oooool2o`0001;ooooo0_l000000ooo
oooo0000o`000007ooooo`;o00002_ooool2o`0000;ooooo0_l00004ooooo`;o0000MOooool001co
oooo00?o0000ooooooooool0Doooool2o`0000?ooooo0_l00002ooooo`;o00001?ooool4o`000003
ooooool0003o000001cooooo0_l00003ooooo`Go00001oooool2o`0000Cooooo0_l000000ooooooo
0000o`000006ooooo`;o00002_ooool2o`0000Oooooo0_l0000>ooooo`?o00000oooool2o`0000?o
oooo0_l0000>ooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0Doooool2o`0000?ooooo
0_l00005ooooo`;o00001_ooool2o`00027ooooo0ol000000ooooooo0000o`000002o`0000?ooooo
1?l00006ooooo`;o00001_ooool2o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o0000
2Oooool2o`000003ooooool0003o000000Sooooo0ol00004ooooo`;o00000_ooool2o`0000kooooo
0_l0001Pooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o00001?ooool3o`0002;ooooo1Ol0
0005ooooo`Co00000oooool4o`0001?ooooo0ol000000ooooooo0000o`000002ooooo`;o00002Ooo
ool2o`000003ooooool0003o000000cooooo0_l000000ooooooo0000o`000002o`0000[ooooo0_l0
001Vooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o00001Oooool2o`0002;ooooo1Ol0000:
ooooo`;o00004_ooool3o`0000;ooooo1?l00009ooooo`;o00002_ooool4o`0000Gooooo1?l00003
ooooo`;o00001Oooool2o`0000?ooooo0_l0001Vooooo`007?ooool00ol0003oooooooooo`1_oooo
o`;o00000oooool2o`0000Wooooo0_l00005ooooo`;o00002oooool2o`0000Cooooo1?l0000:oooo
o`?o00000_ooool4o`0000Kooooo1ol00008ooooo`Co00001Oooool2o`0000Cooooo1_l00002oooo
o`?o000000?oooooo`000?l000002Oooool2o`0005cooooo000Looooo`03o`000?oooooooooo06Wo
oooo0_l00004ooooo`;o00000oooool5o`000003ooooool0003o000000?ooooo1?l0000Fooooo`So
00002oooool3o`0000Oooooo1?l000000ooooooo0000o`00000Gooooo`Ko00000oooool2o`000003
ooooool0003o000000Sooooo0ol00007ooooo`Go0000D?ooool001cooooo00?o0000ooooooooool0
JOooool2o`0000?ooooo0_l00003ooooo`Ko000000Coooooo`000?l0003o00001?ooool2o`000003
ooooool0003o000001Kooooo1Ol00006ooooo`;o00001?ooool2o`0000?ooooo0_l00007ooooo`Ko
00006Oooool2o`0000Cooooo0_l00008ooooo`;o00002?ooool5o`00053ooooo000Looooo`03o`00
0?oooooooooo05Gooooo0_l00003ooooo`;o00002Oooool2o`0000Gooooo1?l00003ooooo`?o0000
0_ooool2o`000003ooooool0003o000000Oooooo1?l00005ooooo`;o00003oooool2o`0000Oooooo
0ol00008ooooo`;o00001oooool7o`0001Sooooo0_l00004ooooo`;o00004oooool3o`00057ooooo
000Looooo`03o`000?oooooooooo05Gooooo0_l00002ooooo`Co00002?ooool2o`0000Gooooo0_l0
0002ooooo`;o00000_ooool2o`0000;ooooo0_l0000<ooooo`;o00001Oooool2o`0000Cooooo0_l0
0009ooooo`?o00001oooool3o`00013ooooo0_l00003ooooo`;o00002Oooool2o`0000Kooooo0_l0
0005ooooo`;o00001?ooool2o`0001?ooooo0ol0001Aooooo`007?ooool00ol0003oooooooooo`1E
ooooo`;o00000_ooool4o`0000;ooooo0_l0000>ooooo`?o00008Oooool4o`0000Sooooo0_l00008
ooooo`;o00001Oooool2o`0000Wooooo1?l0000<ooooo`;o00001_ooool2o`0000Wooooo0_l0000>
ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0BOooool2o`0000?ooooo0_l00005oooo
o`;o00001?ooool2o`0000;ooooo0ol00004ooooo`Co00001Oooool2o`0001[ooooo0_l00005oooo
o`;o000000?oooooo`000?l000005?ooool2o`0000?ooooo0_l0000;ooooo`;o00000oooool3o`00
00Cooooo1Ol00005ooooo`;o00002Oooool4o`0000cooooo0_l0001Iooooo`007?ooool00ol0003o
ooooooooo`19ooooo`;o000000?oooooo`000?l000000_l00009ooooo`;o00001Oooool4o`0000;o
oooo1?l0000>ooooo`;o00000oooool2o`0000cooooo0_l00003ooooo`Co00000oooool2o`0001;o
oooo0_l00005ooooo`;o00003Oooool4o`0000Cooooo1Ol00005ooooo`;o00002oooool2o`0000Go
oooo1?l0000?ooooo`;o0000COooool001cooooo00?o0000ooooooooool0C?ooool2o`0000Cooooo
0_l00005ooooo`;o00000oooool2o`0000;ooooo0_l0000>ooooo`;o00001?ooool2o`0000?ooooo
0_l0000Aooooo`;o00001Oooool2o`0001Kooooo0_l000000ooooooo0000o`00000=ooooo`?o0000
1Oooool2o`0000Sooooo0_l00007ooooo`;o00002Oooool4o`0000oooooo0_l0001=ooooo`007?oo
ool00ol0003oooooooooo`13ooooo`;o00003Oooool2o`000003ooooool0003o000000Oooooo0_l0
000Booooo`;o000000?oooooo`000?l000000_l0000fooooo`;o000000Coooooo`000?l0003ooooo
0_l000001?oooooo0000o`000?l00006ooooo`Co00002oooool5o`0000Oooooo0ol000001?oooooo
0000o`000?l0001Vooooo`007?ooool2o`0004Cooooo0_l00004ooooo`;o00001oooool2o`000003
ooooool0003o000000cooooo0_l00004ooooo`;o000000?oooooo`000?l000001oooool4o`0000oo
oooo1?l0000Booooo`;o00004_ooool2o`000004ooooool0003o0000ooooo`?o00001?ooool2o`00
00;ooooo0_l00007ooooo`;o00000_ooool4o`0000Gooooo0_l00002ooooo`Ko0000I_ooool001co
oooo00?o0000ooooooooool0@oooool2o`0000Cooooo0_l00002ooooo`;o00001_ooool2o`0000Go
oooo0_l00005ooooo`;o00000_ooool4o`000004ooooool0003o0000o`0000Oooooo0_l00005oooo
o`Co00001oooool4o`0001;ooooo0_l0000Aooooo`;o00002Oooool2o`000004ooooool0003o0000
ooooo`;o00000_ooool2o`0000Cooooo0_l0000;ooooo`;o00001?ooool2o`0000?ooooo0_l0000F
ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0@oooool2o`0000Sooooo0_l0000=oooo
o`;o00000_ooool2o`0000Gooooo0_l00004ooooo`;o00001Oooool6o`000003ooooool0003o0000
00So00004oooool2o`0000Cooooo0_l0000Aooooo`;o00000_ooool2o`0000Gooooo0_l00004oooo
o`;o00000_ooool2o`000003ooooool0003o000000;ooooo0_l0000<ooooo`;o00001oooool2o`00
00Gooooo0_l0000?ooooo`;o00001Oooool2o`0004Cooooo000Looooo`03o`000?oooooooooo04co
oooo0_l00002ooooo`;o00003Oooool3o`0000gooooo0_l000000ooooooo0000o`000003o`000003
ooooool0003o0000013o00002oooool2o`000004ooooool0003o0000o`0001[ooooo0_l0000@oooo
o`Co00000_ooool2o`000003ooooool0003o000000Wooooo0_l0000>ooooo`;o00004_ooool2o`00
00;ooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00000_ooool2o`0000Ko
oooo0_l00005ooooo`;o00003_ooool2o`000003ooooool0003o0000013o000000?oooooo`000?l0
00001Ol00009ooooo`;o00000_ooool2o`00023ooooo0_l00003ooooo`;o00000_ooool6o`0000Ko
oooo0_l0000Booooo`;o00006Oooool2o`0004Sooooo000Looooo`03o`000?oooooooooo04_ooooo
0_l00007ooooo`;o00000_ooool2o`0000Oooooo0_l0000=ooooo`;o00000_ooool2o`000003oooo
ool0003o000000;o000000?oooooo`000?l000003_l00002ooooo`;o00004?ooool2o`0000Kooooo
0_l0000Aooooo`?o000000?oooooo`000?l000000_l000000ooooooo0000o`000004o`0001Cooooo
0_l00003ooooo`?o00003_ooool2o`0005?ooooo000Looooo`03o`000?oooooooooo04_ooooo0_l0
0007ooooo`;o00002oooool2o`0000Wooooo2?l00008ooooo`co00000_ooool6o`0000;ooooo0_l0
0009ooooo`;o000000?oooooo`000?l000001_ooool2o`0000gooooo0_l00003ooooo`;o000000?o
ooooo`000?l000000ol000000ooooooo0000o`000004o`0000;ooooo0ol0000>ooooo`;o00000ooo
ool2o`0000;ooooo0_l0000;ooooo`;o00002oooool2o`0004Kooooo000Looooo`03o`000?oooooo
oooo06Cooooo0_l00006ooooo`Co000000Coooooo`000?l0003o00002OoooolAo`0000Cooooo0_l0
0009ooooo`;o00005Oooool2o`000003ooooool0003o000000Gooooo1_l000000ooooooo0000o`00
0004o`0000;ooooo0ol00006ooooo`;o00002?ooool2o`0000Gooooo0_l00007ooooo`?o00003_oo
ool2o`0000Wooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o00002Oooool2
o`0000Sooooo0ol000000ooooooo0000o`000003ooooo`;o00001_oooolAo`0001Kooooo0_l0000<
ooooo`;o000000?oooooo`000?l000001Oooool3o`0000Kooooo0_l00004ooooo`?o00001_ooool2
o`0000Kooooo1Ol00007ooooo`;o000000Coooooo`000?l0003ooooo0ol0000Iooooo`;o0000>ooo
ool001cooooo00?o0000ooooooooool0BOooool5o`0000;ooooo0_l00007ooooo`;o00001_ooool3
o`0000Sooooo1Ol000000ooooooo0000o`000003ooooo`;o00001_ooool5o`000003ooooool0003o
000000[o00001Oooool2o`0000kooooo0_l0000?ooooo`;o00000oooool6o`0000_ooooo0ol00003
ooooo`;o00002Oooool5o`0000Oooooo1Ol0000Booooo`;o0000A_ooool001cooooo00?o0000oooo
ooooool0BOooool5o`0000;ooooo0_l00002ooooo`Co00002Oooool3o`0000Sooooo0ol00003oooo
o`;o00002ooooolCo`0000Cooooo0_l0000Cooooo`;o00002_ooool2o`0000;ooooo0ol00002oooo
o`;o00002oooool2o`0000Cooooo0_l0000:ooooo`;o00001_ooool3o`000004ooooool0003o0000
o`0000?ooooo0_l00003ooooo`;o00002Oooool2o`0004Kooooo000Looooo`03o`000?oooooooooo
04Gooooo0_l000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l000000ol0000Coooo
o`;o00004_oooolDo`0000Cooooo0_l0000>ooooo`;o00000_ooool2o`000004ooooool0003o0000
ooooo`;o00000oooool3o`000003ooooool0003o000000;o0000:Oooool3o`000003ooooool0003o
000000Cooooo0_l00003ooooo`;o00003_ooool2o`00047ooooo000Looooo`03o`000?oooooooooo
04Gooooo0_l000000ooooooo0000o`000005ooooo`;o00000_ooool2o`0001Kooooo0_l00005oooo
o`;o00001?ooool2o`0000Gooooo2Ol000000ooooooo0000o`000008o`0000;ooooo1?l00004oooo
o`;o00002?ooool2o`0000Gooooo0_l000000ooooooo0000o`000003ooooo`Ko00001oooool2o`00
00?ooooo0_l0000Gooooo`;o000000?oooooo`000?l000002oooool2o`0001?ooooo0_l00011oooo
o`007?ooool00ol0003oooooooooo`1?ooooo`;o00001oooool2o`0000_ooooo0_l0000;ooooo`;o
00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000008o`000003ooooool0003o000000So
000000?oooooo`000?l000000_l000001?oooooo0000o`000?ooool2o`0000Oooooo0_l0000<oooo
o`Oo00001Oooool2o`000003ooooool0003o000000?ooooo1?l00002ooooo`;o00004Oooool2o`00
0003ooooool0003o000000Cooooo0_l00005ooooo`;o0000E_ooool001cooooo00?o0000oooooooo
ool0F?ooool2o`0000_ooooo0_l0000Booooo`;o000000Coooooo`000?l0003ooooo5Ol00002oooo
o`?o000000?oooooo`000?l000000oooool2o`0000Gooooo1?l0000:ooooo`?o000000Coooooo`00
0?l0003o00001Oooool2o`0000Kooooo1?l00002ooooo`;o00002oooool2o`0000gooooo0_l00008
ooooo`?o00003_ooool2o`0004;ooooo000Looooo`03o`000?oooooooooo07Wooooo0ol00003oooo
o`So000000?oooooo`000?l000003?l00009ooooo`;o00001oooool2o`0000[ooooo1ol00004oooo
o`;o00000oooool4o`0000Wooooo0_l00008ooooo`;o00000oooool2o`0000Gooooo0_l0000;oooo
o`?o00002?ooool2o`0000Cooooo0_l000000ooooooo0000o`00000oooooo`007?ooool2o`0004Ko
oooo0_l00009ooooo`;o00002Oooool2o`0000gooooo0_l0000>ooooo`Co00000_ooool3o`000003
ooooool0003o000001;o00007?ooool5o`0000Kooooo0_l00003ooooo`Co000000Coooooo`000?l0
003ooooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l00007ooooo`;o00001?ooool5o`00
01Cooooo0_l00004ooooo`;o000000?oooooo`000?l00000?oooool001cooooo00?o0000oooooooo
ool0?Oooool2o`0000Kooooo0_l00009ooooo`;o00000_ooool2o`0000Gooooo0_l0000<ooooo`?o
00001_ooool2o`0000Kooooo1?l00003oooooa?o00000_ooool2o`0001_ooooo1Ol00009ooooo`Ko
000000?oooooo`000?l000001ol00006ooooo`;o00002?ooool4o`000004ooooool0003o0000oooo
o`;o00001Oooool2o`0000cooooo0_l00005ooooo`;o0000@_ooool001cooooo00?o0000oooooooo
ool0?Oooool2o`0000gooooo0_l00006ooooo`?o00001?ooool2o`0000cooooo0_l00003ooooo`;o
00000_ooool2o`0000Kooooo0_l000000ooooooo0000o`000002oooooaGo00004?ooool2o`0000So
oooo1ol0000:oooooaCo00001Oooool4o`0000?ooooo1?l0000;ooooo`;o00003?ooool2o`0004Wo
oooo000Looooo`03o`000?oooooooooo04cooooo0_l00007ooooo`;o00001_ooool2o`0000oooooo
0_l00009ooooo`;o00000_ooool2o`0000;ooooo5ol0000;ooooo`;o000000?oooooo`000?l00000
1?l00002ooooo`Oo00003OoooolDo`0000;ooooo1_l00002ooooo`;o00001_ooool2o`0000?ooooo
0_l0000Eooooo`;o0000@oooool001cooooo00?o0000ooooooooool0BOooool2o`0001;ooooo0_l0
0009ooooo`;o00000oooool3o`0000?ooooo0_l00004ooooo`?o00001OoooolGo`0000Kooooo1?l0
00000ooooooo0000o`000003ooooo`So000000?oooooo`000?l000001oooool2o`0000;ooooo5Ol0
00000ooooooo0000o`000002ooooo`;o00001_ooool2o`0000Cooooo1?l00003ooooo`Go00002?oo
ool2o`0000Sooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00002Oooool2
o`0000Gooooo0_l00007ooooo`;o00003Oooool2o`0000?ooooo0_l00003ooooo`?o00001Oooool2
o`0000Gooooo5_l00007ooooo`Co00002_ooool7o`0000Oooooo0_l00002oooooaOo00002oooool2
o`0000;ooooo1?l00006ooooo`Co00001Oooool2o`000003ooooool0003o000004gooooo000Loooo
o`03o`000?oooooooooo03kooooo0_l0000@ooooo`;o00001oooool2o`0000cooooo0_l00006oooo
o`;o000000?oooooo`000?l000002?ooool2o`0000Cooooo5_l0000Eooooo`Go00001?ooool2o`00
00Cooooo5_l000001?oooooo0000o`000?ooool2o`0000cooooo0_l0000:ooooo`;o00001Oooool2
o`0000Gooooo0_l00019ooooo`007?ooool00ol0003oooooooooo`1Wooooo`;o00001_ooool2o`00
00Cooooo0_l00005ooooo`;o00001?oooolHo`0001Cooooo1?l00004ooooo`;o00001?ooool;o`00
0003ooooool0003o000000ko00000oooool2o`0000Oooooo0_l0000:ooooo`;o00003?ooool2o`00
04Wooooo000Looooo`03o`000?oooooooooo06gooooo0_l00006ooooo`;o00002ooooolJo`0000;o
oooo0_l0000<ooooo`Co00003?oooolKo`0000Cooooo0_l00002ooooo`;o00001Oooool2o`0000Co
oooo0_l00009ooooo`;o00003_ooool2o`00043ooooo000Looooo`03o`000?oooooooooo03Oooooo
0_l0000Qooooo`;o00002_ooool2o`0000Gooooo0_l0000Coooooako00001Oooool2o`0000Cooooo
1?l00004ooooo`;o00001_ooool?o`000003ooooool0003o000000[o00002?ooool2o`0000Gooooo
1?l00002ooooo`;o00002Oooool4o`0000cooooo0_l00010ooooo`007?ooool00ol0003ooooooooo
o`0gooooo`;o00001oooool2o`0000Kooooo0_l0000@ooooo`;o00001Oooool2o`0000?ooooo0_l0
000:ooooo`;o00002oooool2o`0000?ooooo7?l00005ooooo`;o00000_ooool4o`0000Kooooo0_l0
0006ooooo`go00000_ooool>o`00013ooooo0_l0000=ooooo`Co00000_ooool2o`0004[ooooo000L
ooooo`03o`000?oooooooooo03Sooooo0ol00005ooooo`;o00001?ooool4o`00017ooooo0_l00004
ooooo`;o00003oooool2o`0000Gooooo0_l00004ooooo`;o00001?oooolBo`000003ooooool0003o
000000?o000000Coooooo`000?l0003o00001oooool5o`0000Cooooo0_l0000:oooooa_o00007Ooo
ool2o`0000;ooooo0ol000000ooooooo0000o`00001:ooooo`007?ooool00ol0003oooooooooo`0e
ooooo`;o000000Coooooo`000?l0003o00002oooool2o`0001?ooooo0_l0000Looooo`;o00002ooo
oolLo`0000?ooooo1ol00005ooooo`;o00001Oooool2o`0000Gooooo7?l0000Gooooo`;o000000?o
ooooo`000?l000000oooool2o`0004gooooo000Looooo`03o`000?oooooooooo02Sooooo0_l0000;
ooooo`;o00003_ooool2o`0003Gooooo0_l0000:oooooa[o000000?oooooo`000?l000001Ol00006
ooooo`;o00001_ooool2o`0000Cooooo7Ol0000Gooooo`;o0000EOooool00006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oo
oooooooo02Sooooo0_l0000Kooooo`;o0000<Oooool2o`0000;ooooo0_l0000;oooooaCo000000?o
ooooo`000?l000000_l000000ooooooo0000o`000004o`000003ooooool0003o000000Cooooo0ol0
0006ooooo`;o00000_oooolJo`000004ooooool0003o0000o`0000?ooooo0_l0000:ooooo`;o0000
5oooool6o`0000Cooooo0_l0000jooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o
8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo053ooooo0_l0000=ooooo`;o
00005oooool2o`0000Wooooo0_l00003ooooo`Wo000000?oooooo`000?l000003_l000000ooooooo
0000o`000003o`0000;ooooo0_l00005ooooo`;o00001Oooool3o`0000;ooooo6_l00007ooooo`;o
00002_ooool2o`0000Kooooo0_l0000?ooooo`Ko00001?ooool4o`0003Sooooo00000ooooooo410@
ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006ooooo`03o`000?oooooooooo053ooooo
0_l0000=ooooo`Co00004Oooool2o`0000gooooo0_l00003ooooo`ko000000?oooooo`000?l00000
2?l00002ooooo`Go00001oooool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l00000
0_l000000ooooooo0000o`00000Eo`0000Sooooo0_l00003ooooo`;o00000oooool2o`0000Oooooo
0_l000000ooooooo0000o`00000>ooooo`;o00002?ooool2o`0003Sooooo00000ooooooo0000oooo
o`02ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`00033ooooo
0_l0000Uooooo`?o00001oooool2o`00017ooooo0_l00002ooooo`;o00002?ooool2o`000003oooo
ool0003o000000Cooooo2Ol00002ooooo`_o000000?oooooo`000?l000000_l00005ooooo`;o0000
0_ooool2o`0000;ooooo0_l00006oooooaoo00001Oooool2o`000003ooooool0003o000000;o0000
0oooool5o`0000Oooooo0_l0001Booooo`0000?oooooo`000?ooool00_ooool00ol0003ooooooooo
o`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0<?ooool2o`0000Kooooo
0_l0000Mooooo`?o00001oooool2o`00017ooooo0_l00002ooooo`;o00002?ooool2o`000003oooo
ool0003o000000;o00001ooooolDo`0000Oooooo0_l00005ooooo`Co00002?oooolLo`0000Sooooo
0_l00005ooooo`Go00002oooool2o`0000?ooooo0_l00006ooooo`;o0000@Oooool00003ooooool@
413ooooo00;ooooo00?o410@ooooooooool02_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oo
oooooooo02Sooooo0_l0000=ooooo`?o0000<?ooool2o`0000Sooooo0_l0000>ooooo`;o000000?o
ooooo`000?l000002?oooolAo`000003ooooool0003o000000Wooooo0_l00002ooooo`Co00002?oo
oolIo`0001;ooooo0_l0000>ooooo`;o00000oooool2o`0000Kooooo0_l00011ooooo`0000Kooooo
ogMgMonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0
:?ooool2o`0000gooooo0_l0000>ooooo`;o00002?ooool2o`0000Gooooo0_l0000@ooooo`?o0000
2_ooool2o`0000_ooooo0_l0000@ooooo`So00000_ooool2o`000003ooooool0003o000000Wooooo
0_l00005ooooo`;o00001?ooool2o`0000Cooooo5Ol0000>ooooo`;o00004_ooool4o`0000Oooooo
0_l00003ooooo`;o0000?oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo
0000ooooo`06ooooo`03o`000?oooooooooo04Oooooo0_l00006ooooo`Co00001Oooool2o`00017o
oooo0_l0000:ooooo`;o00004?ooool2o`0000?ooooo0_l0000Cooooo`;o00000_ooool2o`0000co
oooo0_l00004ooooo`;o00001_oooolBo`0000Wooooo0_l00004ooooo`;o00001Oooool2o`0000_o
oooo1?l00007ooooo`;o00000oooool2o`0000;ooooo0_l0000kooooo`007?ooool00ol0003ooooo
ooooo`0gooooo`;o00005_ooool2o`0003Sooooo0_l00003ooooo`;o00002_ooool2o`0000Gooooo
1?l000001?oooooo0000o`000?l00004ooooo`;o00005?oooolBo`0000Wooooo0ol0000:ooooo`;o
00001?ooool2o`0000Gooooo0_l0000Booooo`;o0000>oooool001cooooo00?o0000ooooooooool0
<oooool2o`000004ooooool0003o0000o`0003Cooooo0_l0000Vooooo`;o00000oooool2o`0000Go
oooo0_l00003ooooo`;o00001Oooool2o`0000Gooooo0_l00004ooooo`;o00001oooool2o`000003
ooooool0003o000000co00001oooool2o`000004ooooool0003o0000o`0000Gooooo0_l00002oooo
o`;o00001Oooool2o`0000Gooooo0ol00005ooooo`;o0000Aoooool001cooooo00?o0000oooooooo
ool0<oooool2o`000003ooooool0003o000003Gooooo0_l0000Eooooo`;o000000?oooooo`000?l0
00003?ooool2o`0001gooooo0_l00004ooooo`;o00001_ooool2o`0000;ooooo3_l00007ooooo`;o
00002Oooool6o`0000gooooo0_l00005ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0
=Oooool2o`0003Oooooo0_l0000Dooooo`;o000000?oooooo`000?l000005oooool2o`0000;ooooo
0_l0000Aooooo`;o00002Oooool2o`0000?ooooo1?l00002ooooo`Co00002oooool2o`0000Wooooo
0ol0000;ooooo`;o00001?ooool2o`0000kooooo0_l0000looooo`007?ooool00ol0003ooooooooo
o`0eooooo`;o00007oooool2o`0001Kooooo1?l0000Pooooo`Co00002_ooool2o`0000;ooooo0_l0
00000ooooooo0000o`000002o`0000Kooooo0_l00004ooooo`?o00000_ooool2o`0000?ooooo0ol0
0005ooooo`So00002oooool2o`000003ooooool0003o000001Cooooo0_l00002ooooo`Co00003_oo
ool2o`0003cooooo000Looooo`03o`000?oooooooooo03;ooooo0ol0000Qooooo`;o00006?ooool2
o`0000kooooo0_l0000;ooooo`;o00000_ooool5o`0000;ooooo0_l00003ooooo`;o00002?ooool5
o`0000Cooooo0ol00005ooooo`;o00000_ooool2o`0000?ooooo0ol00005ooooo`Ko00002_ooool2
o`0000Cooooo0_l0000Fooooo`Co00004Oooool3o`0003[ooooo000Looooo`03o`000?oooooooooo
03;ooooo0ol0000Rooooo`;o00000oooool2o`0000Sooooo0ol0000:ooooo`;o00002oooool2o`00
00_ooooo0_l000001Ooooooo0000o`000?l0003ooooo00Ko000000?oooooo`000?l000000_l0000;
ooooo`;o00001?ooool2o`000003ooooool0003o000000_ooooo0ol0000Fooooo`;o00000oooool2
o`0001Oooooo1?l0000<ooooo`;o00000oooool3o`0003[ooooo000Looooo`03o`000?oooooooooo
02cooooo0_l0000Yooooo`?o00000_ooool2o`0000Sooooo0ol0000:ooooo`;o00000oooool2o`00
01Kooooo0_l00002ooooo`Co00000oooool2o`0000_ooooo0_l00009ooooo`;o00002oooool3o`00
01_ooooo0_l0000@ooooo`;o00001oooool2o`0000Sooooo0_l00002ooooo`;o0000@?ooool001co
oooo00?o0000ooooooooool0;?ooool2o`0000Gooooo0_l0000Iooooo`Co00001Oooool7o`0001[o
oooo0_l0000Kooooo`?o00001_ooool2o`0000Sooooo0_l0000gooooo`;o00003Oooool2o`00017o
oooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00005oooool6o`000003oooo
ool0003o000000[o00004_ooool2o`0000?ooooo1?l0000:ooooo`;o00004_ooool2o`0000Cooooo
0_l0000Gooooo`Co00001oooool2o`0001gooooo0ol0000;ooooo`;o00002Oooool2o`0002;ooooo
0_l0000Yooooo`007?ooool00ol0003oooooooooo`1;ooooo`?o00001Oooool@o`0000kooooo1?l0
00000ooooooo0000o`00000<ooooo`;o00001?ooool2o`0000cooooo0_l0000Jooooo`Oo00001ooo
ool2o`0000Sooooo0_l0000Dooooo`Co00002Oooool4o`0000Oooooo0_l0000Rooooo`;o0000:Ooo
ool001cooooo0_l0000_ooooo`;o00006oooool4o`0000?ooooo4Ol0000?ooooo`?o000000?ooooo
o`000?l000004_ooool2o`0001Wooooo0_l00008ooooo`;o00000_ooool5o`0000kooooo0_l00000
1?oooooo0000o`000?ooool6o`0001;ooooo0_l0000;ooooo`;o00001_ooool2o`0000Wooooo0_l0
0013ooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00002oooool2o`00013ooooo0_l00000
0ooooooo0000o`00000Ao`0003[ooooo0_l00003ooooo`;o000000?oooooo`000?l000002?ooool2
o`0000;ooooo1Ol0000>ooooo`;o000000?oooooo`000?l000000oooool6o`0000Sooooo0_l00003
ooooo`;o00002oooool2o`0000Wooooo0_l00003ooooo`;o00001?ooool2o`0000;ooooo0_l0000D
ooooo`;o0000:Oooool001cooooo00?o0000ooooooooool0;?ooool2o`0000gooooo0_l0000Aoooo
oaOo00001?ooool2o`00013ooooo0_l0000;ooooo`;o00004oooool2o`0000?ooooo0_l0000Boooo
o`;o00001Oooool2o`0000Kooooo0_l0000;ooooo`;o00002?ooool3o`0000;ooooo0_l0000;oooo
o`;o00000oooool2o`0000Wooooo0_l00003ooooo`;o00000oooool2o`0001Cooooo0_l0000Yoooo
o`007?ooool00ol0003oooooooooo`0/ooooo`;o00007?oooolKo`0000Cooooo0_l00008ooooo`;o
00001_ooool2o`0000_ooooo0ol0000Gooooo`;o00002Oooool2o`0000_ooooo0_l000000ooooooo
0000o`000006ooooo`;o000000?oooooo`000?l000003?ooool2o`0000Cooooo0ol0000Dooooo`;o
00003?ooool4o`0001Sooooo0_l0000Zooooo`007?ooool00ol0003oooooooooo`1:ooooo`Co0000
00?oooooo`000?l000005_l00005ooooo`;o00001Oooool2o`0000Wooooo0_l00009ooooo`;o0000
2?ooool2o`0001Sooooo0_l000000ooooooo0000o`000004ooooo`;o000000Coooooo`000?l0003o
00003?ooool2o`0000Oooooo1?l000000ooooooo0000o`000004ooooo`?o00005?ooool2o`0000co
oooo0_l00009ooooo`;o00003oooool2o`0002[ooooo000Looooo`03o`000?oooooooooo04Gooooo
0_l00004ooooo`?o000000?oooooo`000?l000001ol00002ooooo`go00001Oooool2o`0000gooooo
0_l000000ooooooo0000o`000002o`0000?ooooo0_l00008ooooo`;o00000_ooool2o`0001_ooooo
0_l00004ooooo`;o000000?oooooo`000?l000001?l0000=ooooo`;o00000oooool4o`000003oooo
ool0003o000000;o000000?oooooo`000?l000000ol0000>ooooo`;o00006_ooool4o`0003_ooooo
000Looooo`03o`000?oooooooooo03Oooooo0_l0000<ooooo`;o00001_oooolJo`0001Cooooo1ol0
0002ooooo`?o00002?ooool2o`0000Gooooo0_l00002ooooo`;o00001oooool2o`0000gooooo0_l0
0007ooooo`Co00003Oooool2o`0000[ooooo2?l0000>ooooo`;o00002_ooool2o`0000Oooooo0_l0
0005ooooo`Go000000?oooooo`000?l000000_l0000eooooo`007?ooool00ol0003oooooooooo`0g
ooooo`;o00003Oooool2o`0000Gooooo6_l0000Fooooo`Co000000?oooooo`000?l000000_l0000?
ooooo`?o00000_ooool2o`0000Oooooo0_l00006ooooo`;o00001Oooool2o`0000Sooooo1?l0000C
ooooo`;o00001Oooool2o`000003ooooool0003o000000cooooo0_l000000ooooooo0000o`000002
o`0000Sooooo0_l00007ooooo`;o00001_ooool4o`000003ooooool0003o000000;o0000=Oooool0
01cooooo00?o0000ooooooooool07_ooool2o`0002Kooooo0_l00005oooooa[o00002oooool2o`00
00[ooooo1ol0000@ooooo`;o00001oooool2o`0000_ooooo1?l00003ooooo`;o00002?ooool4o`00
00Oooooo0_l0000:ooooo`;o00002Oooool3o`0000?ooooo0_l00005ooooo`;o00000oooool2o`00
01Cooooo0_l000000ooooooo0000o`00000nooooo`007?ooool00ol0003oooooooooo`0Nooooo`;o
00009Oooool3o`0000Gooooo6_l000000ooooooo0000o`000008ooooo`;o00003?ooool3o`0001;o
oooo0_l00007ooooo`;o00000_ooool2o`0000Wooooo0_l00003ooooo`;o00004oooool2o`0000Co
oooo0_l000000ooooooo0000o`00000<ooooo`?o00000oooool2o`0000Cooooo0_l0000Dooooo`;o
00000oooool6o`0003kooooo000Looooo`03o`000?oooooooooo02Kooooo0_l0000:ooooo`;o0000
4Oooool5o`0000;ooooo6?l00004ooooo`;o00001_ooool2o`000003ooooool0003o000000Gooooo
0_l00004ooooo`;o00004oooool2o`0000Sooooo0_l000000ooooooo0000o`00000?ooooo`;o0000
3_ooool3o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000004Oooool2o`000003oooo
ool0003o000000;ooooo1?l00004ooooo`;o00002_ooool4o`0000?ooooo0_l000000ooooooo0000
o`000002ooooo`;o0000>oooool001cooooo00?o0000ooooooooool09_ooool2o`0000[ooooo0_l0
0009ooooo`Co00001Oooool8o`000003ooooool0003o000001Go00002_ooool5o`0000Gooooo0_l0
00000ooooooo0000o`000004ooooo`;o00003Oooool2o`0000_ooooo0_l0000:ooooo`;o00001_oo
ool2o`0000Sooooo0_l00004ooooo`Oo00000_ooool2o`0000Oooooo0_l0000<ooooo`;o000000?o
ooooo`000?l000001?ooool2o`0000Cooooo0ol00009ooooo`;o000000?oooooo`000?l000002Ooo
ool2o`0003_ooooo000Looooo`03o`000?oooooooooo03Oooooo0_l00004ooooo`Co000000?ooooo
o`000?l000001Oooool6o`000003ooooool0003o000000Oo000000?oooooo`000?l000002_l00004
ooooo`;o00001Oooool2o`0000Gooooo0_l00003ooooo`;o00001?ooool2o`0000gooooo0_l00002
ooooo`;o00004oooool2o`0000cooooo1_l00003ooooo`Oo00000oooool4o`0000Gooooo0_l00006
ooooo`;o00002Oooool2o`0000;ooooo0_l00003ooooo`Co00001?ooool2o`0000Kooooo0_l00009
ooooo`;o0000>oooool001cooooo00?o0000ooooooooool09Oooool2o`00013ooooo0_l00009oooo
o`;o00001Oooool2o`0000;ooooo0_l00002oooooaGo00001?ooool2o`0000cooooo0_l00004oooo
o`;o00005?ooool4o`0000;ooooo0_l0000?ooooo`;o00002oooool6o`0000?ooooo1?l00005oooo
o`?o000000?oooooo`000?l000003Oooool2o`0000Cooooo0_l00003ooooo`Go00001?ooool2o`00
00Kooooo0_l0000Dooooo`;o0000>?ooool001cooooo00?o0000ooooooooool09Oooool2o`0000?o
oooo0_l0000?ooooo`;o00000oooool2o`0000Kooooo0_l00009oooooa?o00004Oooool3o`0000Co
oooo0_l000000ooooooo0000o`00000>ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Co
oooo0_l00006ooooo`Ko00002Oooool7o`0000?ooooo1?l00005ooooo`?o00000oooool4o`0000?o
oooo1?l00003ooooo`;o00000oooool2o`0000?ooooo1Ol00002ooooo`;o00000_ooool2o`0000co
oooo0_l00005ooooo`;o00000oooool4o`0003Sooooo000Looooo`03o`000?oooooooooo02Kooooo
0_l00002ooooo`;o00003oooool2o`000003ooooool0003o000000Go00000oooool2o`0000;ooooo
0_l00002ooooo`;o000000?oooooo`000?l000001_l000000ooooooo0000o`000005o`0001Cooooo
0_l00003ooooo`;o00000oooool2o`0000kooooo0_l0000=ooooo`;o00001_ooool6o`0000Oooooo
1?l000000ooooooo0000o`000006ooooo`;o00001?ooool2o`0000Kooooo1?l00002ooooo`Go0000
0oooool2o`0000;ooooo0_l00003ooooo`?o00001Oooool2o`0000;ooooo0_l0000;ooooo`?o0000
00?oooooo`000?l000000_ooool2o`0000?ooooo0ol0000iooooo`007?ooool2o`0002Cooooo0_l0
00000ooooooo0000o`00000Fooooo`;o000000?oooooo`000?l000000_l00007ooooo`;o00000_oo
ool2o`0000Cooooo2_l000000ooooooo0000o`000002ooooo`;o00005Oooool2o`0002kooooo0_l0
0007ooooo`;o00000oooool2o`0000Kooooo0_l000001?oooooo0000o`000?ooool4o`0000[ooooo
0_l0000:ooooo`;o000000?oooooo`000?l000000_l0000;ooooo`;o00002_ooool2o`0000;ooooo
0_l00008ooooo`;o0000>Oooool001cooooo00?o0000ooooooooool08oooool2o`00033ooooo0_l0
0002ooooo`Ko00001_ooool2o`0000;ooooo0_l00002ooooo`;o00004oooool4o`0000cooooo0_l0
0007ooooo`;o00003oooool2o`0000Cooooo0ol000000ooooooo0000o`000004ooooo`;o00001Ooo
ool4o`0000?ooooo0_l0000:ooooo`?o00000_ooool2o`0000Sooooo1?l00003ooooo`;o00001Ooo
ool3o`0000oooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00009oooool2
o`0000;ooooo1Ol0000:ooooo`?o000000Goooooo`000?l0003o0000ooooo`02o`0000cooooo0_l0
0002ooooo`Co00003?ooool2o`0000Oooooo0_l0000;ooooo`;o00002?ooool3o`000003ooooool0
003o000000Cooooo1?l00002ooooo`?o00001?ooool2o`0000_ooooo0ol00002ooooo`;o00000ooo
ool2o`0000[ooooo0_l000000ooooooo0000o`000002ooooo`;o00002Oooool2o`0000?ooooo1?l0
0012ooooo`007?ooool00ol0003oooooooooo`0Zooooo`Co0000:_ooool2o`000004ooooool0003o
0000o`0000[ooooo0_l00002ooooo`?o000000?oooooo`000?l000003?ooool2o`0000Oooooo0_l0
0007ooooo`Co00005?ooool2o`0000Cooooo0_l0000>ooooo`;o00000_ooool4o`0000?ooooo0_l0
000Cooooo`Co000000?oooooo`000?l000002_ooool2o`0000Gooooo0_l00006ooooo`;o00000ooo
ool2o`0000[ooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0Zooooo`;o00006Oooool4
o`0000oooooo0_l00002ooooo`;o00000oooool2o`0000Sooooo0ol0000;ooooo`;o00001?ooool3
o`0000Gooooo0_l00005ooooo`Co00003_ooool2o`0000Sooooo0_l00002ooooo`?o00004Oooool4
o`0000;ooooo0_l000001?oooooo0000o`000?l0000>ooooo`Co00000oooool2o`0000oooooo1?l0
0007ooooo`;o00001Oooool2o`0000Cooooo0_l000000ooooooo0000o`00000hooooo`007?ooool0
0ol0003oooooooooo`0dooooo`;o00003Oooool6o`0001Gooooo1Ol00006ooooo`Go00002oooool2
o`0000?ooooo1_l00003ooooo`;o00001Oooool2o`000003ooooool0003o000000gooooo0_l00008
ooooo`;o00000_ooool3o`00017ooooo0_l00004ooooo`;o000000Coooooo`000?l0003o00003_oo
ool3o`0000Kooooo0ol000000ooooooo0000o`000005ooooo`;o00000_ooool2o`0000Wooooo1Ol0
0002ooooo`;o00001?ooool2o`0003_ooooo000Looooo`03o`000?oooooooooo03Cooooo0_l00002
ooooo`;o00002Oooool6o`0000?ooooo1?l00003ooooo`;o00002Oooool4o`0000Oooooo0_l00000
0ooooooo0000o`00000;ooooo`;o00000oooool2o`0000;ooooo0ol0000<ooooo`;o00009Oooool2
o`0000Wooooo0_l00004ooooo`;o000000?oooooo`000?l000003_ooool2o`0000Oooooo0ol00000
0ooooooo0000o`000005ooooo`;o00003_ooool4o`0004Gooooo000Looooo`03o`000?oooooooooo
03Sooooo0_l00006ooooo`;o00000_ooool6o`000003ooooool0003o000000Co00000_ooool7o`00
00Cooooo0_l00002ooooo`;o00000oooool2o`0000?ooooo0_l000000ooooooo0000o`000008oooo
o`;o00002?ooool2o`0000Kooooo0_l000000ooooooo0000o`000007ooooo`Co00005Oooool2o`00
00Kooooo0_l000001?oooooo0000o`000?ooool7o`0000Cooooo0_l00003ooooo`;o00003?ooool2
o`00013ooooo0_l00006ooooo`;o00004?ooool2o`0000Gooooo0_l0000=ooooo`;o0000:Oooool0
01cooooo00?o0000ooooooooool0>_ooool2o`0000Cooooo0_l00002ooooo`Ko000000?oooooo`00
0?l000000_ooool2o`0000Cooooo1Ol00008ooooo`;o00000oooool2o`0000Kooooo0_l00009oooo
o`;o00001?ooool2o`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l000001_ooool5o`00
00Gooooo0_l00005ooooo`;o00001oooool2o`0000Gooooo0_l00002ooooo`;o000000?oooooo`00
0?l000000ol00004ooooo`;o00001Oooool2o`0000?ooooo0_l000000ooooooo0000o`000005oooo
o`;o00002_ooool2o`0000?ooooo0_l00006ooooo`;o00001?ooool2o`0000[ooooo0_l00005oooo
o`;o00003Oooool2o`0002Wooooo000Looooo`03o`000?oooooooooo03Wooooo0ol0000<ooooo`;o
00001Oooool2o`0000Gooooo0_l0000<ooooo`;o00005?ooool2o`0000?ooooo2_l0000;ooooo`Co
00001?ooool3o`000004ooooool0003o0000o`0000Cooooo0_l0000>ooooo`;o00002?ooool2o`00
00Cooooo0_l0000:ooooo`;o000000?oooooo`000?l000001Oooool2o`0000[ooooo0_l00003oooo
o`;o00002_ooool4o`0000oooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`0iooooo`;o
00006oooool2o`0000cooooo0_l0000=ooooo`;o00000_ooool2o`0000Kooooo1_l00002ooooo`;o
000000?oooooo`000?l000000oooool2o`000003ooooool0003o000000;o00001_ooool3o`0000;o
oooo0_l0000@ooooo`;o00006?ooool2o`0000Gooooo0_l0000Eooooo`;o000000?oooooo`000?l0
00002_ooool2o`0000Cooooo0_l0000;ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0
=_ooool3o`0000Gooooo0_l00009ooooo`;o00001Oooool2o`0000Kooooo1?l00006ooooo`;o0000
1?ooool2o`0000Wooooo0_l00002ooooo`;o00004Oooool2o`0000?ooooo0_l000000ooooooo0000
o`000002o`0000Oooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00004ooooo`;o0000
4?ooool5o`0000Cooooo0_l00002ooooo`?o00000oooool2o`0000_ooooo0_l0000Cooooo`;o0000
Aoooool001cooooo00?o0000ooooooooool06_ooool2o`0001Gooooo0_l00003ooooo`?o000000?o
ooooo`000?l000000_ooool2o`0000Wooooo0_l00002ooooo`;o000000?oooooo`000?l000001_oo
ool4o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`Co00004oooool3o`0000Gooooo0_l0
0006ooooo`Ko000000Coooooo`000?l0003ooooo0_l00003ooooo`?o00001Oooool5o`0000;ooooo
0_l0000:ooooo`Co00000oooool2o`0000Gooooo0_l00002ooooo`Co000000Coooooo`000?l0003o
00001_ooool4o`0000?ooooo0_l0000;ooooo`;o00002?ooool2o`0000_ooooo0_l00006ooooo`;o
0000?Oooool001cooooo00?o0000ooooooooool06_ooool2o`0001Gooooo0_l00005ooooo`Co0000
0oooool4o`0000;ooooo0_l00006ooooo`;o00001_ooool2o`0000Sooooo2Ol0000=ooooo`;o0000
1?ooool8o`0000;ooooo0_l00006ooooo`Ko000000Coooooo`000?l0003ooooo0_l00002ooooo`?o
000000?oooooo`000?l000000_l00003ooooo`?o00003_ooool2o`0000Gooooo0_l00002ooooo`;o
000000?oooooo`000?l000000_ooool:o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o
00002Oooool4o`0000Sooooo0_l0000;ooooo`;o00001_ooool2o`0001;ooooo0_l0000Yooooo`00
7?ooool00ol0003oooooooooo`0dooooo`;o00000_ooool2o`0000Gooooo1?l00002ooooo`;o0000
2Oooool2o`0000?ooooo0_l00008ooooo`Oo00002Oooool2o`0000;ooooo1Ol00003ooooo`;o0000
0oooool3o`000003ooooool0003o000000;o000000?oooooo`000?l000002Oooool2o`000003oooo
ool0003o000000;ooooo0_l00002ooooo`Co00000_ooool2o`0000[ooooo0_l0000?ooooo`;o0000
0oooool2o`000004ooooool0003o0000ooooo`Wo00001?ooool2o`0000Cooooo0ol00006ooooo`;o
000000?oooooo`000?l000002Oooool2o`0002Gooooo0_l0000Yooooo`007?ooool00ol0003ooooo
ooooo`0dooooo`;o00000_ooool2o`0000Oooooo0_l000000ooooooo0000o`00000:ooooo`;o0000
1oooool2o`0000?ooooo1?l0000=ooooo`Ko000000Coooooo`000?l0003o00001Oooool2o`000003
ooooool0003o000000Go000000Coooooo`000?l0003ooooo1Ol000000ooooooo0000o`000003o`00
00;ooooo0_l000000ooooooo0000o`000003o`0000Cooooo0_l0000:ooooo`;o00003oooool2o`00
00?ooooo1Ol000001?oooooo0000o`000?ooool8o`0000?ooooo0_l00003ooooo`?o00002Oooool2
o`0000Wooooo0_l00005ooooo`;o00004?ooool2o`0000kooooo0_l0000Wooooo`007?ooool2o`00
03Wooooo0_l00005ooooo`Co000000Coooooo`000?l0003o00004_ooool2o`0000?ooooo0_l0000A
ooooo`;o00001?ooool2o`0000Gooooo0_l00002ooooo`;o00000_ooool3o`0000?ooooo1Ol00000
0ooooooo0000o`000004o`000004ooooool0003o0000ooooo`Ko00004Oooool2o`000003ooooool0
003o000000Sooooo1?l000001Ooooooo0000o`000?l0003ooooo00?o000000Coooooo`000?l0003o
00000_ooool8o`000003ooooool0003o000000;o00004_ooool2o`0000Wooooo1?l0000@ooooo`;o
00003_ooool2o`0002Oooooo000Looooo`03o`000?oooooooooo03oooooo0_l00004ooooo`;o0000
2oooool2o`0001_ooooo0_l0000<ooooo`;o000000?oooooo`000?l000001?ooool3o`000003oooo
ool0003o000000Oooooo1Ol000000ooooooo0000o`000008o`0000Sooooo0_l00006ooooo`;o0000
00Coooooo`000?l0003o00001oooool4o`000003ooooool0003o000000Ko000000?oooooo`000?l0
00003ol0000?ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Oooooo1_l0000nooooo`00
7?ooool00ol0003oooooooooo`12ooooo`;o00003_ooool2o`0001Cooooo0_l000000ooooooo0000
o`000002ooooo`;o00002Oooool2o`000004ooooool0003o0000ooooo`?o00001oooool8o`000003
ooooool0003o000000?o000000?oooooo`000?l000001Ol000000ooooooo0000o`000002ooooo`;o
00001?ooool2o`0000Kooooo0_l00002ooooo`;o00001Oooool2o`0000;ooooo5ol000000ooooooo
0000o`000003o`0000oooooo0_l0000<ooooo`;o00001oooool6o`0003kooooo000Looooo`03o`00
0?oooooooooo03Sooooo0_l00008ooooo`;o00004?ooool2o`0001;ooooo0_l000000ooooooo0000
o`00000<ooooo`Ko00000_ooool4o`0000;ooooo4Ol00002ooooo`?o000000Coooooo`000?l0003o
oooo0_l00002ooooo`;o00003?ooool2o`0000Gooooo0_l00002ooooo`Co000000?oooooo`000?l0
00006Ol00003ooooo`;o00002?ooool2o`0000Gooooo0ol00003ooooo`;o00003oooool2o`0003ko
oooo000Looooo`03o`000?oooooooooo037ooooo0_l00005ooooo`;o00004?ooool2o`0000Sooooo
0_l0000Dooooo`;o00001Oooool2o`0000Cooooo2Ol000000ooooooo0000o`00000Oo`000003oooo
ool0003o000000Wooooo0_l00008ooooo`Co00000oooool4o`000003ooooool0003o000001So0000
0oooool3o`0000Cooooo0_l000000ooooooo0000o`000005ooooo`?o00000oooool4o`0000Wooooo
0_l00002ooooo`;o00004?ooool2o`0002cooooo000Looooo`03o`000?oooooooooo037ooooo0_l0
0002ooooo`;o00001?ooool2o`0000?ooooo1?l00003ooooo`;o000000?oooooo`000?l000001?oo
ool2o`0000Cooooo0_l00002ooooo`;o00003_ooool4o`0000?ooooo0_l00004ooooo`Wo000000?o
ooooo`000?l000007ol000000ooooooo0000o`000006o`0000?ooooo0_l00008ooooo`;o00001?oo
ool5o`000003ooooool0003o000001So000000?oooooo`000?l000000ol00004ooooo`;o00001?oo
ool2o`0000?ooooo0_l00005ooooo`;o00002Oooool2o`0000Kooooo0_l0000<ooooo`;o0000;?oo
ool001cooooo00?o0000ooooooooool0=Oooool2o`0000Cooooo0_l00003ooooo`Ko000000Cooooo
o`000?l0003ooooo0_l00004ooooo`;o00001?ooool6o`00013ooooo0_l0000;ooooo`Oo000000?o
ooooo`000?l000007ol00003ooooo`Ko00001?ooool3o`0000Cooooo0_l00005ooooob7o000000?o
ooooo`000?l000001Ol00008ooooo`;o00004Oooool2o`0000[ooooo0_l00006ooooo`;o0000<_oo
ool001cooooo00?o0000ooooooooool0>oooool2o`0000?ooooo0_l000001?oooooo0000o`000?l0
0004ooooo`;o00000_ooool2o`000003ooooool0003o000000Gooooo0_l0000=ooooo`;o00001Ooo
ool2o`0000;ooooo0ol00005ooooo`;o00000_oooolVo`0000?ooooo1_l00002ooooo`?o00000ooo
ool3o`0000Gooooo:Ol0000Cooooo`;o00001Oooool3o`0000;ooooo0_l0000>ooooo`;o000000?o
ooooo`000?l00000;oooool001cooooo00?o0000ooooooooool0=Oooool2o`0000?ooooo0ol00004
ooooo`;o00002oooool2o`000003ooooool0003o000000Cooooo0_l00003ooooo`;o00002Oooool2
o`0000Gooooo0_l00002ooooo`?o00001Oooool3o`000003ooooool0003o000002Ko00000oooool4
o`000004ooooool0003o0000o`0000Cooooo0_l00007ooooo`[o000000?oooooo`000?l000005Ol0
00001?oooooo0000o`000?l00005ooooo`;o00001Oooool2o`0000Oooooo0_l00005ooooo`;o0000
0oooool2o`000003ooooool0003o000000kooooo0_l0000_ooooo`007?ooool00ol0003ooooooooo
o`0eooooo`;o00000oooool2o`0000Gooooo0_l0000Dooooo`Oo00000_ooool2o`0000Gooooo0_l0
0007ooooo`?o00002?ooool6o`000003ooooool0003o000000Co000000?oooooo`000?l000004ol0
0002ooooo`Ko00001Oooool2o`000004ooooool0003o0000o`00013ooooo7Ol00003ooooo`?o0000
1Oooool2o`0000Gooooo0_l00003ooooo`;o00004Oooool2o`0003oooooo000Looooo`03o`000?oo
oooooooo03oooooo0_l00008ooooo`;o00000_ooool2o`0000[ooooo1?l00003ooooo`;o00000_oo
ool2o`000003ooooool0003o000000Oooooo0ol00006ooooo`So000000?oooooo`000?l000008Ol0
0006ooooo`?o000000?oooooo`000?l000001Oooool2o`0000Sooooo8Ol0000@ooooo`;o00000_oo
ool2o`0000Cooooo0_l0000:ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0?oooool2
o`0000?ooooo0_l00003ooooo`;o00000_ooool2o`0000Wooooo1Ol00007ooooo`;o00002_ooool2
o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l00000:_l00002ooooo`?o000000Co
ooooo`000?l0003o00000_ooool2o`0000Cooooo0_l00007oooooaco00000oooool3o`00013ooooo
0ol000000ooooooo0000o`000004ooooo`;o00002_ooool3o`0003oooooo000Looooo`03o`000?oo
oooooooo033ooooo0_l0000@ooooo`Co00000oooool2o`0000Oooooo0_l00004ooooo`Co00000ooo
ool2o`0000gooooo1?l000000ooooooo0000o`000005o`000003ooooool0003o000002So00000_oo
ool5o`000004ooooool0003o0000ooooo`;o00001_ooool2o`0000Gooooo7_l000000ooooooo0000
o`000005ooooo`Co00002?ooool3o`000003ooooool0003o0000017ooooo0_l0000?ooooo`;o0000
;_ooool001cooooo00?o0000ooooooooool0<?ooool2o`0000?ooooo1?l00009ooooo`?o00002?oo
ool2o`0000?ooooo0_l0000;ooooo`?o00001oooool2o`0000?ooooo0_l000000ooooooo0000o`00
0003o`0000;ooooo3Ol000000ooooooo0000o`00000Jo`0000Kooooo2Ol00007ooooo`;o00001Ooo
oolHo`000003ooooool0003o000000?o000000?oooooo`000?l000001Oooool4o`0000Kooooo0_l0
000Dooooo`;o00004_ooool2o`0002kooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo
0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0eooooo`Co
00005?ooool2o`00013ooooo0ol00007ooooo`;o00000oooool2o`000003ooooool0003o000000Ko
oooo1_l000000ooooooo0000o`00000;o`000003ooooool0003o000000go000000Goooooo`000?l0
003o0000ooooo`02o`0000Cooooo2Ol0000>ooooob7o000000?oooooo`000?l000003?ooool2o`00
00;ooooo0_l0000@ooooo`;o00003_ooool2o`0003;ooooo00001_ooooooMgMgoiRHV?ooooooV9RH
ogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooooooo
o`1<ooooo`?o00001Oooool2o`0000Wooooo0_l000000ooooooo0000o`00000:ooooo`;o00002Ooo
ool>o`000003ooooool0003o000001co00000_ooool6o`0000Wooooo0_l000000ooooooo0000o`00
0002ooooo`?o00000_oooolMo`000003ooooool0003o0000013ooooo0_l00007ooooo`?o00000ooo
ool4o`000003ooooool0003o000000cooooo0_l0000booooo`0000?ooooooa0@4?ooool00_ooool0
0ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`0gooooo`;o00002?ooool3o`0000Sooooo0ol00005ooooo`;o00002_ooool4o`00017ooooo1ol0
00000ooooooo0000o`00000Co`000003ooooool0003o000001Oo00002oooool5o`0000;ooooo0ol0
00001Ooooooo0000o`000?l0003ooooo00ko000000?oooooo`000?l000002Ol0000@ooooo`;o0000
0_ooool4o`0000Cooooo0ol00003ooooo`Oo0000@?ooool00003ooooool0003ooooo00;ooooo00?o
0000ooooooooool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0000fooooo`?o0000
2?ooool3o`00017ooooo0_l00007ooooo`Co00004oooool4o`0000?ooooo0_l000000ooooooo0000
o`00000Do`000003ooooool0003o000000[o00000_ooool5o`000003ooooool0003o000000;o0000
0oooool2o`0000Kooooo0_l00003ooooo`;o000000?oooooo`000?l000006_l0000Cooooo`;o0000
0_ooool4o`0000cooooo1_l0000oooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooooooo
o`09ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0fooooo`;o0000
7Oooool3o`000003ooooool0003o000000?ooooo0_l00007ooooo`;o00002oooool5o`0000;ooooo
6ol000000ooooooo0000o`00000=o`0000Kooooo0_l00002ooooo`?o00001_ooool2o`0000?ooooo
0_l000001?oooooo0000o`000?oooolKo`000003ooooool0003o000000Oooooo0_l0000Jooooo`;o
000000?oooooo`000?l00000?oooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool0
2Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo03oooooo0_l000000ooooooo0000
o`00000Booooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000003ooooo`;o0000
0_ooool2o`0000Wooooo9?l000000ooooooo0000o`00000>o`0000Cooooo0_l00003ooooo`;o0000
0oooool2o`0000;ooooo0_l00005ooooo`;o00000_oooolOo`0000Kooooo0_l0000:ooooo`;o0000
3Oooool3o`0004;ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nH
V9P02?ooool00ol0003oooooooooo`0looooo`;o000000Coooooo`000?l0003ooooo0_l000000ooo
oooo0000o`000006ooooo`;o00000oooool2o`0000Gooooo1?l00006ooooo`;o00002?ooool3o`00
00;ooooo0_l000000ooooooo0000o`00000`o`0000Cooooo0_l00008ooooo`;o00000_ooool2o`00
00?ooooo1Ol00002oooooako000000Coooooo`000?l0003ooooo0_l00004ooooo`;o00001?ooool4
o`0000Oooooo0_l00003ooooo`?o0000@oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?oo
ool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo03cooooo0_l00007ooooo`;o0000
1?ooool4o`0000?ooooo0_l00005ooooo`Ko000000Coooooo`000?l0003ooooo0_l00008ooooo`?o
00001_ooool5o`000003ooooool0003o000002Co000000Coooooo`000?l0003o00001oooool2o`00
00?ooooo0_l0000:ooooo`Go00000_oooolHo`0000Oooooo0_l000001?oooooo0000o`000?l00003
ooooo`;o00001?ooool2o`0000Oooooo1?l00003ooooo`;o00004oooool2o`0002oooooo000Loooo
o`03o`000?oooooooooo04Cooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo1_l000001?oo
oooo0000o`000?ooool4o`0000Wooooo0_l00006ooooo`?o000000?oooooo`000?l00000:?l00007
ooooo`;o000000?oooooo`000?l000000_l00008ooooo`;o000000?oooooo`000?l000000_l00002
ooooo`oo000000Coooooo`000?l0003ooooo1_l0000:ooooo`;o00004_ooool2o`0000Kooooo0_l0
000Booooo`;o0000;oooool001cooooo00?o0000ooooooooool0<Oooool2o`00013ooooo0ol00005
ooooo`;o00003?ooool4o`0000Sooooo0_l00004ooooo`;o00000oooool2o`0000?ooooo0_l00004
ooooob_o000000?oooooo`000?l000000_ooool2o`0000;ooooo0ol00009ooooo`?o00000oooool2
o`000005ooooool0003o0000o`000?ooool05_l0000Hooooo`Go00001?ooool2o`0000?ooooo0_l0
0013ooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00001?ooool2o`0000[ooooo1?l00004
ooooo`;o00001_ooool3o`0000Gooooo0_l000000ooooooo0000o`000003ooooo`;o00000oooool5
o`0000?ooooo0_l00003ooooobgo000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00002
ooooo`;o00002_ooool2o`0000Oooooo0ol00003ooooo`Co00000_ooool8o`000003ooooool0003o
000000?o00001?ooool2o`0001;ooooo1Ol00004ooooo`;o0000B?ooool001cooooo00?o0000oooo
ooooool0=oooool2o`0000cooooo0_l00002ooooo`;o00002?ooool5o`0000Kooooo0_l00003oooo
o`;o00000oooool5o`0000?ooooo0_l000000ooooooo0000o`000002ooooob_o00000_ooool2o`00
00?ooooo0_l0000Oooooo`;o00001Oooool5o`0000Cooooo0ol00005ooooo`;o0000IOooool001co
oooo00?o0000ooooooooool0B?ooool3o`0000;ooooo0_l00006ooooo`?o00000_ooool2o`000003
ooooool0003o000000;ooooo0_l00007ooooo`Co000000?oooooo`000?l000000_ooool5o`0000;o
oooo7Ol000000ooooooo0000o`000008o`0000;ooooo0_l00003ooooo`;o00008_ooool2o`0000;o
oooo0_l000000ooooooo0000o`000002ooooo`Ko0000>Oooool2o`00033ooooo000Looooo`03o`00
0?oooooooooo04Sooooo0_l00003ooooo`;o00000oooool2o`000003ooooool0003o000000?ooooo
0_l000000ooooooo0000o`000002ooooo`;o00002Oooool2o`000003ooooool0003o000000?ooooo
1ol000000ooooooo0000o`000002ooooob7o000000?oooooo`000?l000000_l00003ooooo`Go0000
7oooool2o`0000Wooooo0_l00002ooooo`;o00006oooool3o`0001_ooooo0_l0000`ooooo`007?oo
ool00ol0003oooooooooo`1?ooooo`;o000000?oooooo`000?l000002_ooool3o`0000?ooooo0_l0
0004ooooo`Co00000oooool2o`000004ooooool0003o0000ooooo`Co00000_oooolPo`0000;ooooo
0_l000000ooooooo0000o`000006ooooo`Co00004?ooool2o`0000;ooooo0_l00002ooooo`;o0000
1Oooool2o`0000Cooooo0_l0000>ooooo`;o00005?ooool3o`0004gooooo000Looooo`03o`000?oo
oooooooo04oooooo0_l000000ooooooo0000o`000008ooooo`Go00000oooool2o`0000Cooooo1?l0
0003ooooo`;o00001?ooool2o`0000Cooooo9?l0000Aooooo`;o00000_ooool2o`000003ooooool0
003o000000?ooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo0_l00007ooooo`;o00003_oo
ool2o`0000?ooooo0_l0000Eooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0Aoooool3
o`000003ooooool0003o000000;ooooo0_l000001?oooooo0000o`000?l00007ooooo`Co00000ooo
ool2o`0000Kooooo0_l00006ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`00
0002oooooa[o00000oooool4o`0000;ooooo0_l00005ooooo`;o00001Oooool4o`000003ooooool0
003o000000Co00000oooool2o`0000[ooooo0_l0000Jooooo`Co00003_ooool4o`0000?ooooo1?l0
0016ooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00005oooool3o`000003ooooool0003o
000000;ooooo0_l00002ooooo`Co00001oooool2o`0000?ooooo0_l00007ooooo`;o00001Oooool2
o`000003ooooool0003o000000Go00000_oooolIo`000004ooooool0003o0000o`0000;ooooo0_l0
0002ooooo`;o00001Oooool2o`0000Gooooo0_l00003ooooo`Ko00000oooool2o`0001Sooooo0_l0
000<ooooo`Co00002oooool2o`000003ooooool0003o000000;o00001Oooool2o`0004Kooooo000L
ooooo`03o`000?oooooooooo02kooooo0_l00005ooooo`;o00004Oooool2o`0000Gooooo0_l00004
ooooo`;o00002?ooool4o`0000Wooooo0_l00005ooooo`;o000000Coooooo`000?l0003ooooo1_l0
0005ooooo`Go000000?oooooo`000?l000004?l000001?oooooo0000o`000?ooool2o`0000kooooo
0_l00002ooooo`;o00000_ooool3o`0000Wooooo0_l0000Booooo`;o00000_ooool2o`000003oooo
ool0003o000000Oooooo1?l00009ooooo`;o00002oooool2o`0004Gooooo000Looooo`;o0000=_oo
ool2o`00017ooooo0_l0000Eooooo`Co00001_ooool2o`0000Oooooo1_l00003ooooo`Ko00000ooo
ool2o`000003ooooool0003o000000?o00000_oooolDo`0000[ooooo0_l00002ooooo`;o00000_oo
ool2o`000003ooooool0003o000000Gooooo0_l000001?oooooo0000o`000?ooool2o`00017ooooo
0_l00003ooooo`;o000000?oooooo`000?l000001oooool5o`0000Kooooo0_l0000=ooooo`;o0000
AOooool001cooooo00?o0000ooooooooool0AOooool2o`0000Sooooo1?l0000Eooooo`?o00000ooo
ool2o`0000;ooooo1_l00007ooooo`;o00000_ooool3o`0000;ooooo2ol000000ooooooo0000o`00
0004o`000003ooooool0003o000000Co00002oooool2o`0000Cooooo0_l00003ooooo`;o00001Ooo
ool2o`000003ooooool0003o000000?ooooo0_l0000>ooooo`Go00004?ooool3o`0000Gooooo0_l0
0009ooooo`?o0000B?ooool001cooooo00?o0000ooooooooool0AOooool2o`0000Sooooo1Ol00003
ooooo`?o00002oooool5o`0000;ooooo1?l00009ooooo`;o00001oooool?o`0000?ooooo2?l00002
ooooo`;o00000_ooool2o`0000Sooooo0_l000001?oooooo0000o`000?ooool2o`0000cooooo1?l0
0002ooooo`;o00003_ooool2o`000003ooooool0003o000000Sooooo0_l00007ooooo`;o00004?oo
ool3o`0004Sooooo000Looooo`03o`000?oooooooooo04kooooo0ol000000ooooooo0000o`000003
ooooo`?o00002oooool4o`0000?ooooo0_l0000;ooooo`;o00001oooool7o`0000?ooooo1Ol00000
1?oooooo0000o`000?ooool2o`000003ooooool0003o000000;o00001_ooool2o`0000Sooooo0_l0
00001?oooooo0000o`000?l0000>ooooo`Co00003_ooool2o`0000oooooo0_l0000?ooooo`?o0000
1_ooool2o`0001?ooooo0_l0000eooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00000ooo
ool3o`0000cooooo0_l00002ooooo`;o00004?ooool3o`0000[ooooo1?l000001Ooooooo0000o`00
0?l0003ooooo00;o00001?ooool7o`0000;ooooo0_l00004ooooo`;o00002Oooool2o`0000Gooooo
0_l00003ooooo`;o00002?ooool2o`00017ooooo0_l00003ooooo`;o00006oooool3o`0000Kooooo
0ol0000Booooo`?o0000=?ooool001cooooo00?o0000ooooooooool0BOooool2o`0000?ooooo1?l0
000;ooooo`?o000000?oooooo`000?l000000oooool2o`0000Cooooo0_l000000ooooooo0000o`00
0002ooooo`?o00002?ooool:o`000004ooooool0003o0000ooooo`Oo000000?oooooo`000?l00000
0_ooool2o`0000;ooooo1?l00009ooooo`;o00002_ooool2o`0000Sooooo1?l00006ooooo`;o0000
00?oooooo`000?l000002Oooool2o`0001Cooooo0_l00005ooooo`;o00002?ooool2o`0001?ooooo
0_l0000dooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00005_ooool2o`0000[ooooo1?l0
00001?oooooo0000o`000?l00002ooooo`;o00001?ooool2o`000003ooooool0003o000000Co0000
1Oooool2o`0000;ooooo0_l00004ooooo`Co000000Coooooo`000?l0003ooooo1ol00002ooooo`;o
00001Oooool2o`0000Cooooo0ol00004ooooo`;o00003_ooool2o`0000Kooooo0_l00003ooooo`Go
000000?oooooo`000?l000000_ooool2o`0000Wooooo0_l0000@ooooo`;o00002Oooool2o`0004oo
oooo000Looooo`03o`000?oooooooooo03Sooooo0_l0000Fooooo`;o00002_ooool2o`0000Cooooo
0_l00002ooooo`Co000000?oooooo`000?l000001?ooool4o`0000;ooooo0_l000000ooooooo0000
o`000008ooooo`Co00001Oooool3o`000004ooooool0003o0000ooooo`?o00001Oooool2o`000004
ooooool0003o0000ooooo`Go00000_ooool2o`000003ooooool0003o000000;ooooo0_l00007oooo
o`;o00001Oooool2o`0000Cooooo1?l000001?oooooo0000o`000?l00002ooooo`;o00002Oooool2
o`0000Cooooo0_l0000:ooooo`;o00000oooool2o`0000Cooooo0_l0001?ooooo`007?ooool00ol0
003oooooooooo`1Looooo`;o00002?ooool4o`000003ooooool0003o000000Cooooo0_l00004oooo
o`;o00002oooool2o`0000Cooooo0_l000000ooooooo0000o`000005ooooo`;o00000_ooool6o`00
0003ooooool0003o000000Cooooo0_l00005ooooo`;o00000_ooool2o`0000Wooooo0_l00003oooo
o`;o00002Oooool2o`0001?ooooo1Ol00008ooooo`;o00000oooool2o`0005Gooooo000Looooo`03
o`000?oooooooooo05Wooooo1Ol00002ooooo`Ko00000_ooool2o`000003ooooool0003o000000Co
oooo0_l00004ooooo`?o00002_ooool2o`0000Cooooo0_l0000<ooooo`Co00002_ooool2o`00013o
oooo0_l000001?oooooo0000o`000?l00002ooooo`;o00001_ooool2o`0000Wooooo0_l00006oooo
o`;o00000oooool5o`0000cooooo0_l00002ooooo`;o0000D_ooool001cooooo00?o0000oooooooo
ool0FOooool=o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`?o00001Oooool3o`0000Go
oooo0_l00003ooooo`;o00008?ooool2o`00013ooooo0_l00002ooooo`;o00002_ooool2o`000003
ooooool0003o000000Kooooo0_l00006ooooo`;o00001?ooool3o`0000?ooooo0_l00006ooooo`Co
00000_ooool2o`0005;ooooo000Looooo`03o`000?oooooooooo057ooooo0ol0000:ooooo`;o0000
1?ooool2o`0000Gooooo0_l00002ooooo`?o00003Oooool2o`0002;ooooo0_l0000:ooooo`;o0000
1Oooool2o`0000Gooooo0_l0000<ooooo`;o00002?ooool2o`0000_ooooo0_l00003ooooo`;o0000
1_ooool2o`0005Sooooo000Looooo`03o`000?oooooooooo04kooooo0_l000001?oooooo0000o`00
0?l0000Aooooo`;o00001?ooool2o`0002Oooooo0_l0000=ooooo`;o00002_ooool2o`0000Gooooo
0_l00005ooooo`;o00001_ooool2o`0000kooooo0_l000000ooooooo0000o`00001_ooooo`007?oo
ool00ol0003oooooooooo`1>ooooo`;o00005Oooool2o`0001Gooooo0_l0000:ooooo`;o00001?oo
ool2o`0000Cooooo0_l000000ooooooo0000o`000009ooooo`;o000000?oooooo`000?l000001ooo
ool3o`0001Cooooo0_l0000<ooooo`;o00000oooool2o`0006oooooo000Looooo`03o`000?oooooo
oooo04kooooo0_l0000:ooooo`;o00008?ooool2o`0000Sooooo1?l00004ooooo`;o00001?ooool2
o`000003ooooool0003o000000Wooooo0_l000000ooooooo0000o`000007ooooo`?o00001Oooool2
o`0000Oooooo0_l0000<ooooo`;o00001?ooool2o`0000Gooooo0_l000000ooooooo0000o`00001Z
ooooo`007?ooool00ol0003oooooooooo`1Jooooo`?o00001?ooool2o`0000?ooooo0_l0000Coooo
o`?o00001_ooool4o`0000Oooooo0_l0000:ooooo`;o000000?oooooo`000?l000003oooool3o`00
00Cooooo0_l00007ooooo`;o000000?oooooo`000?l000002?ooool3o`0000_ooooo0_l000000ooo
oooo0000o`00000>ooooo`;o0000F_ooool001cooooo0_l0001Looooo`;o00001?ooool2o`0000?o
oooo0ol000000ooooooo0000o`000002ooooo`;o00001_ooool2o`0000;ooooo1?l00004ooooo`Go
00001Oooool2o`000003ooooool0003o000000[ooooo0_l000000ooooooo0000o`000007ooooo`;o
00001oooool2o`00013ooooo0ol00006ooooo`?o00001Oooool2o`0000?ooooo0_l0000Cooooo`;o
00000_ooool2o`0005Kooooo000Looooo`03o`000?oooooooooo05gooooo0_l00008ooooo`;o0000
00Coooooo`000?l0003ooooo0ol000000ooooooo0000o`000003ooooo`;o00000_ooool6o`0000;o
oooo0_l000000ooooooo0000o`000005ooooo`;o00005?ooool2o`0000?ooooo0_l0000Jooooo`?o
00000oooool4o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`;o00002Oooool2o`0000Oo
oooo0_l00003ooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0GOooool2o`0000;ooooo
0ol00004ooooo`?o00000_ooool2o`0000;ooooo0_l00008ooooo`;o000000?oooooo`000?l00000
2_ooool2o`0001Kooooo0_l0000Pooooo`;o00000oooool2o`0000Gooooo0_l00007ooooo`;o0000
0oooool4o`000003ooooool0003o000000Kooooo0ol00002ooooo`;o0000Eoooool001cooooo00?o
0000ooooooooool0GOooool2o`0000;ooooo1?l00003ooooo`?o00000_ooool2o`0000Cooooo0_l0
000@ooooo`;o00000oooool2o`0004gooooo1?l000000ooooooo0000o`000002o`0000Cooooo0_l0
0002ooooo`?o00000oooool2o`000003ooooool0003o000005Cooooo000Looooo`03o`000?oooooo
oooo05Wooooo0_l00002ooooo`So00001?ooool2o`000004ooooool0003o0000o`0000Cooooo0_l0
000@ooooo`;o00000_ooool2o`0000Gooooo0_l0000oooooo`;o00002?ooool3o`0000;ooooo0_l0
0003ooooo`?o00000_ooool2o`0000Oooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`1>
ooooo`;o00000_ooool2o`0000Gooooo0_l00004ooooo`?o00001oooool2o`000003ooooool0003o
000000gooooo0_l00002ooooo`;o00002?ooool2o`0000Gooooo0_l0000eooooo`;o00002?ooool2
o`0000Gooooo0_l00002ooooo`;o00001oooool2o`0006;ooooo000Looooo`03o`000?oooooooooo
04kooooo0_l00002ooooo`?o00001_ooool2o`0000?ooooo1?l0000Fooooo`?o00000_ooool4o`00
00Sooooo0_l0000dooooo`;o00001?ooool2o`000003ooooool0003o000000Gooooo0_l000000ooo
oooo0000o`000004o`0000_ooooo0_l0001Rooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o
00001_ooool2o`0000Gooooo0_l0000=ooooo`;o00001oooool4o`0000?ooooo0_l000000ooooooo
0000o`000005ooooo`?o0000<oooool2o`0000Oooooo0_l00005ooooo`;o000000?oooooo`000?l0
00000_l0000=ooooo`;o00000oooool2o`0005gooooo000Looooo`03o`000?oooooooooo077ooooo
0_l00009ooooo`;o000000Coooooo`000?l0003ooooo1?l00005ooooo`?o0000<_ooool2o`0000?o
oooo0_l0000Oooooo`;o00000_ooool2o`0005gooooo000Looooo`03o`000?oooooooooo05?ooooo
0_l00008ooooo`Co00002_ooool2o`0001;ooooo0_l000000ooooooo0000o`000007ooooo`;o0000
2_ooool2o`0002?ooooo0_l00002ooooo`;o00000oooool2o`0000Cooooo0_l0000Iooooo`;o0000
00?oooooo`000?l00000G_ooool001cooooo00?o0000ooooooooool0Doooool4o`0000Kooooo1?l0
0002ooooo`;o00001Oooool3o`0000[ooooo0_l00006ooooo`;o00005_ooool2o`0002?ooooo0_l0
000=ooooo`;o00001oooool2o`0000Wooooo0_l00008ooooo`;o00006?ooool2o`0004Cooooo000L
ooooo`03o`000?oooooooooo05Gooooo0_l0000<ooooo`;o00001Oooool3o`0000Kooooo0_l00002
ooooo`;o000000?oooooo`000?l000000oooool2o`0004Oooooo0_l00008ooooo`Co00002Oooool2
o`0002;ooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`1Eooooo`;o00001Oooool2o`00
00;ooooo0_l0000:ooooo`?o00001?ooool3o`000004ooooool0003o0000ooooo`?o00005_ooool2
o`0003;ooooo0ol00008ooooo`;o00002?ooool2o`000003ooooool0003o000006Sooooo000Loooo
o`03o`000?oooooooooo05cooooo0_l00002ooooo`;o00000_ooool2o`0000Gooooo1?l00005oooo
o`;o000000?oooooo`000?l000000_ooool2o`0001Kooooo0_l00004ooooo`?o0000:oooool4o`00
017ooooo0_l0000:ooooo`;o0000Goooool001cooooo00?o0000ooooooooool0I?ooool3o`0000Co
oooo0_l00003ooooo`;o00006?ooool2o`0000gooooo0ol0000Sooooo`Co00001_ooool2o`0000Ko
oooo0_l0000;ooooo`;o00002?ooool2o`0005oooooo000Looooo`03o`000?oooooooooo05;ooooo
0_l0000Aooooo`;o00001?ooool2o`0000?ooooo0_l0000?ooooo`;o000000?oooooo`000?l00000
0_l000001?oooooo0000o`000?l0000/ooooo`;o00001Oooool4o`0000kooooo0_l00009ooooo`Co
0000JOooool001cooooo0_l0001>ooooo`;o00000oooool2o`0000[ooooo0_l00007ooooo`;o0000
00?oooooo`000?l000000_ooool3o`0000[ooooo0_l00002ooooo`Co000000?oooooo`000?l00000
1_l0000<ooooo`;o00000_ooool2o`0001[ooooo0_l00004ooooo`;o00005_ooool2o`0000Cooooo
0_l00004ooooo`;o0000IOooool001cooooo00?o0000ooooooooool0COooool2o`0000oooooo0_l0
0002ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo0ol0000:ooooo`;o00000_oo
ool2o`0000Oooooo0ol0000=ooooo`;o00000_ooool2o`0001gooooo0_l000000ooooooo0000o`00
000@ooooo`;o00001?ooool2o`0000[ooooo0_l0001Uooooo`007?ooool00ol0003oooooooooo`1N
ooooo`;o00000_ooool2o`000003ooooool0003o0000017ooooo0_l0000?ooooo`;o00000_ooool2
o`0002Oooooo0_l00003ooooo`Co00001_ooool2o`0000Wooooo0_l0000:ooooo`;o0000Joooool0
01cooooo00?o0000ooooooooool0H?ooool4o`000003ooooool0003o000000Cooooo0_l00004oooo
o`;o00001Oooool4o`0000Wooooo0_l00002ooooo`;o00000_ooool2o`0000_ooooo0_l0000Joooo
o`;o000000?oooooo`000?l000000_ooool2o`0000Kooooo0_l00008ooooo`;o00002oooool2o`00
06_ooooo000Looooo`03o`000?oooooooooo063ooooo0_l00009ooooo`;o00001?ooool2o`0000Oo
oooo0_l00009ooooo`?o000000Coooooo`000?l0003ooooo1Ol00009ooooo`;o00000_ooool2o`00
01Wooooo0_l00006ooooo`?o00002?ooool5o`0000_ooooo0_l0001[ooooo`007?ooool00ol0003o
ooooooooo`25ooooo`?o00001?ooool5o`0000Cooooo0_l00007ooooo`?o00007Oooool6o`0000So
oooo1Ol0001hooooo`007?ooool00ol0003oooooooooo`1Xooooo`;o0000:oooool2o`0000Sooooo
0_l00002ooooo`;o00006Oooool3o`0001Cooooo0_l00007ooooo`;o0000JOooool001cooooo00?o
0000ooooooooool0Goooool4o`0000Gooooo1?l00009ooooo`;o00009?ooool2o`000003ooooool0
003o000000?ooooo0_l0000Fooooo`;o00005?ooool2o`0000;ooooo0_l00002ooooo`;o00000_oo
ool3o`0001Sooooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o00001?ooool5
o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0000Kooooo0_l0000Fooooo`;o00003?oo
ool2o`000004ooooool0003o0000ooooo`Co00003oooool2o`0000Gooooo0_l000000ooooooo0000
o`00000:ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`Oo000000Coooooo`000?l0
003o00006Oooool2o`0004oooooo000Looooo`03o`000?oooooooooo05Wooooo0_l00007ooooo`?o
00000_ooool2o`0000Cooooo0_l0000:ooooo`;o00000_ooool2o`000003ooooool0003o000000_o
oooo0_l0000@ooooo`Ko00003oooool2o`0000Sooooo0_l0000:ooooo`;o00000_ooool2o`0000Co
oooo1Ol00003ooooo`;o0000Joooool001cooooo00?o0000ooooooooool0FOooool2o`0000Sooooo
0_l0000Dooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000Cooooo0_l00005ooooo`;o
00004?ooool2o`0001oooooo0_l0000Cooooo`;o0000L_ooool001cooooo00?o0000ooooooooool0
FOooool2o`0000Sooooo0_l0000>ooooo`;o00001Oooool4o`0000Sooooo0_l00005ooooo`;o0000
1?ooool2o`0000gooooo0_l00003ooooo`;o00003_ooool2o`0000Cooooo0_l000000ooooooo0000
o`000002ooooo`;o00000_ooool2o`0007oooooo000Looooo`03o`000?oooooooooo06?ooooo0_l0
000>ooooo`;o00001Oooool3o`0000[ooooo0_l00002ooooo`;o00001Oooool3o`0000gooooo0_l0
0003ooooo`;o00003_ooool2o`0000;ooooo1?l00005ooooo`;o00000_ooool2o`0000?ooooo0_l0
001jooooo`007?ooool00ol0003oooooooooo`1Xooooo`;o00004Oooool2o`0000;ooooo0_l00003
ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Gooooo0_l0000Qooooo`;o00001?ooool2
o`0000;ooooo0_l00006ooooo`;o00001?ooool2o`0000Oooooo0_l0001aooooo`0000Koooooonk^
k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo
00?o0000ooooooooool0J?ooool2o`000003ooooool0003o000001;ooooo0_l00003ooooo`;o0000
;oooool2o`0000Sooooo0_l00006ooooo`?o000000?oooooo`000?l000000oooool2o`0000Cooooo
0_l0001aooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7o
V9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0Joooool2o`0000Cooooo0_l0000<oooo
o`Co00001_ooool2o`0001cooooo0_l00006ooooo`;o00004?ooool2o`0000?ooooo1ol00003oooo
o`;o00005Oooool2o`00063ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wo
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo077ooooo0ol0000=oooo
o`;o00000_ooool2o`0000;ooooo0_l0000:ooooo`;o00004?ooool2o`0000Kooooo0_l00008oooo
o`;o00001_ooool2o`0000?ooooo0_l00002ooooo`;o00001?ooool2o`0001Gooooo0_l0001Poooo
o`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRH
V?lb<S801_ooool3o`0007;ooooo1Ol00009ooooo`;o00000oooool2o`0000Oooooo0ol00004oooo
o`;o00001?ooool2o`0000Kooooo0_l0000Dooooo`;o00005Oooool3o`0007Kooooo00000ooooooo
0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Goc<c<o`000?l0003o0000olc<c006oooo
o`03o`000?oooooooooo07?ooooo1?l00009ooooo`;o000000?oooooo`000?l000002Oooool3o`00
00Kooooo0_l00002ooooo`;o00001_ooool2o`0000oooooo0_l0000Gooooo`;o00000_ooool2o`00
07Kooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go410@okZj^_oo
oooo^[Zjoa0@4006ooooo`03o`000?oooooooooo08?ooooo0_l0000Booooo`;o00002Oooool2o`00
00;ooooo0_l0000;ooooo`?o00004?ooool2o`0000Gooooo0_l00002ooooo`;o0000M_ooool00006
oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o
0000ooooooooool0O?ooool2o`0000Kooooo0_l00005ooooo`;o00005Oooool2o`0000;ooooo0_l0
0006ooooo`;o00000oooool2o`0000?ooooo0_l0000<ooooo`;o00000_ooool2o`000003ooooool0
003o000007[ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@06ooooo`03o`000?oooooooooo07cooooo1Ol00003ooooo`?o00000_ooool4o`0000;o
oooo0_l0000Iooooo`;o00000_ooool2o`0000Kooooo1?l0000@ooooo`;o000000?oooooo`000?l0
0000N_ooool001cooooo00?o0000ooooooooool0O_ooool3o`0000Cooooo0_l00002ooooo`;o0000
1?ooool2o`0000;ooooo0_l0000Eooooo`?o00002Oooool2o`0000Kooooo0_l00029ooooo`007?oo
ool00ol0003oooooooooo`2=ooooo`;o00001?ooool2o`0000?ooooo0_l00007ooooo`?o00001ooo
ool2o`0000Oooooo0_l00003ooooo`;o00000oooool2o`0000Oooooo0_l00020ooooo`007?ooool0
0ol0003oooooooooo`1[ooooo`;o00002?ooool2o`0001Kooooo0_l000000ooooooo0000o`000006
ooooo`;o00001oooool4o`0000_ooooo0_l00002ooooo`;o00000_ooool3o`0000[ooooo1_l0001n
ooooo`007?ooool00ol0003oooooooooo`1[ooooo`;o00002?ooool2o`0000;ooooo0_l0000Eoooo
o`;o00002oooool2o`0000Cooooo1?l00009ooooo`;o00001_ooool2o`0000Cooooo0_l00005oooo
o`;o000000Coooooo`000?l0003o0000O_ooool001cooooo00?o0000ooooooooool0NOooool2o`00
00kooooo0_l0000<ooooo`;o00001?ooool2o`0000Kooooo0_l0000<ooooo`;o00000oooool2o`00
00;ooooo1?l00008ooooo`;o0000Ooooool001cooooo00?o0000ooooooooool0O?ooool2o`0000?o
oooo0_l00006ooooo`;o000000Coooooo`000?l0003o00001oooool3o`0001[ooooo0_l00003oooo
o`?o000000?oooooo`000?l000001?l00003ooooo`;o00001oooool2o`0007Wooooo000Looooo`03
o`000?oooooooooo07Kooooo0_l00004ooooo`;o00000oooool2o`000003ooooool0003o000000;o
00001?ooool4o`0000Kooooo0_l00007ooooo`;o00002?ooool2o`0000Cooooo0_l000000ooooooo
0000o`000004ooooo`?o00000oooool4o`0000?ooooo0_l00007ooooo`;o0000NOooool001cooooo
00?o0000ooooooooool0M_ooool2o`0000cooooo1_l00004ooooo`;o00003oooool2o`000003oooo
ool0003o000000Gooooo0_l00004ooooo`Go00001?ooool3o`0000Cooooo1?l00026ooooo`007?oo
ool00ol0003oooooooooo`26ooooo`Co00005_ooool4o`0000Wooooo0ol000000ooooooo0000o`00
0008ooooo`;o00000oooool3o`0008Kooooo000Looooo`03o`000?oooooooooo08Kooooo1?l0000E
ooooo`?o00001?ooool6o`000003ooooool0003o000000?o00000oooool2o`0000Cooooo0_l00003
ooooo`;o00000_ooool2o`0001Sooooo0_l0001Yooooo`007?ooool00ol0003oooooooooo`2;oooo
o`?o00000oooool2o`0000;ooooo0ol00007ooooo`;o00001Oooool6o`0000Cooooo0_l00003oooo
o`;o00001?ooool2o`0000Oooooo0_l0000Hooooo`;o0000JOooool001cooooo0_l0002<ooooo`?o
00000oooool2o`0000;ooooo1Ol00005ooooo`;o00002?ooool3o`0000oooooo0_l0002<ooooo`00
7?ooool00ol0003oooooooooo`2Eooooo`Go00000_ooool2o`000003ooooool0003o000000?ooooo
0_l0002Sooooo`007?ooool00ol0003oooooooooo`2Booooo`;o000000?oooooo`000?l000000_l0
0003ooooo`;o00001_ooool4o`0001Kooooo0_l00029ooooo`007?ooool00ol0003oooooooooo`2B
ooooo`Co00004?ooool2o`0001Kooooo0_l00029ooooo`007?ooool00ol0003oooooooooo`2Doooo
o`;o00000oooool4o`0000Gooooo0_l0002Uooooo`007?ooool00ol0003oooooooooo`24ooooo`;o
00004oooool4o`0000Gooooo0_l0000Hooooo`;o0000Roooool001cooooo00?o0000ooooooooool0
Q?ooool2o`0000Cooooo0_l0000?ooooo`;o00007oooool2o`0008_ooooo000Looooo`03o`000?oo
oooooooo08[ooooo0_l00005ooooo`;o00002?ooool4o`000:[ooooo000Looooo`03o`000?oooooo
oooo097ooooo0_l0000:ooooo`;o0000Z_ooool001cooooo00?o0000ooooooooool0XOooool2o`00
00?ooooo0_l0000Rooooo`;o0000OOooool001cooooo00?o0000ooooooooool0XOooool2o`0000?o
oooo0_l0000Rooooo`;o0000OOooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0W?ooool2o`000:_ooooo000Looooo`03o`000?oooooooooo09co
oooo0_l0002[ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0]_oo
ool2o`00097ooooo000Looooo`03o`000?oooooooooo0;Kooooo0_l0002Aooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooo
oom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Booooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooood[ooooo
000Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool0
0ol0003oooooooooo`05ooooo`?o0000oooooom:ooooo`005?ooool00ol0003oooooooooo`3ooooo
oe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0
oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Booooo`03oeEEEOmVIVKo
00000?ooooooE?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:7ooooo00Co
410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0Fooooo`Co000000So410@oooooooooooo
k^k^oc8b<_l0003o<S8bonk^kP?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0S?oo
ool00:;ooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00003?ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OnHV9So8B4Qonk^k_ooooooA4A400?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`2<ooooo`00X_ooool01Ol0003ooooooooooooooooo0000
01_ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Cooooo00?oV9RH
ob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@08cooooo002Rooooo`05o`000?oooooo
ooooooooool000002Oooool6o`0000cooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000Gooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000008co
oooo002Rooooo`05o`000?n7QhOoooooojVYZOl000006oooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000001_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooooooo
ooooool00000S?ooool00:7ooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Ioooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4007ooooo`05o`000?oooooo
ooooooooool@41000oooool00ol@413oooooooooo`2:ooooo`00`_ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`2<ooooo`00`?ooool00omEEEGoIVIVo`000004ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP2<ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1026) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.67118 .598 Mdot
.61972 .60003 Mdot
.48383 .36751 Mdot
.45994 .57747 Mdot
.73271 .62861 Mdot
.45093 .3383 Mdot
.62123 .41794 Mdot
.66959 .39444 Mdot
.46826 .34456 Mdot
.57837 .53337 Mdot
.64237 .42886 Mdot
.47028 .6492 Mdot
.65614 .41318 Mdot
.45129 .59397 Mdot
.47301 .87243 Mdot
.38878 .54267 Mdot
.59839 .6186 Mdot
.32905 .46138 Mdot
.37909 .62579 Mdot
.45134 .28949 Mdot
.68301 .5994 Mdot
.45119 .58131 Mdot
.66806 .60552 Mdot
.45079 .59404 Mdot
.47395 .58588 Mdot
.62311 .62355 Mdot
.61895 .5633 Mdot
.45589 .55701 Mdot
.46473 .61803 Mdot
.65394 .38531 Mdot
.25163 .57611 Mdot
.56269 .85404 Mdot
.35602 .60241 Mdot
.77872 .3755 Mdot
.67299 .40176 Mdot
.56443 .79281 Mdot
.45804 .32043 Mdot
.64743 .39159 Mdot
.67189 .40482 Mdot
.62947 .38071 Mdot
.66197 .39979 Mdot
.62226 .61741 Mdot
.6002 .39026 Mdot
.70369 .43795 Mdot
.39572 .62738 Mdot
.72357 .53519 Mdot
.31607 .68271 Mdot
.39647 .59137 Mdot
.60225 .62023 Mdot
.47506 .30957 Mdot
.7667 .38555 Mdot
.61589 .40952 Mdot
.43799 .36921 Mdot
.89421 .56352 Mdot
.63717 .39453 Mdot
.40189 .63558 Mdot
.47825 .33958 Mdot
.44046 .57759 Mdot
.44655 .59202 Mdot
.41464 .75625 Mdot
.46438 .55735 Mdot
.28464 .44678 Mdot
.64227 .64988 Mdot
.37378 .42753 Mdot
.4618 .33391 Mdot
.67025 .41111 Mdot
.61135 .59139 Mdot
.64991 .41087 Mdot
.47964 .63423 Mdot
.49425 .40448 Mdot
.39725 .59015 Mdot
.66555 .4176 Mdot
.60682 .57732 Mdot
.40652 .57862 Mdot
.52614 .20506 Mdot
.28665 .75416 Mdot
.29869 .41243 Mdot
.48128 .77716 Mdot
.43139 .77814 Mdot
.34662 .34796 Mdot
.44386 .62398 Mdot
.20325 .42007 Mdot
.39829 .82777 Mdot
.66619 .61465 Mdot
.36173 .56177 Mdot
.54009 .38767 Mdot
.4116 .57518 Mdot
.65734 .52215 Mdot
.41721 .63676 Mdot
.64117 .22663 Mdot
.46856 .35122 Mdot
.64524 .60377 Mdot
.46047 .58048 Mdot
.4913 .57959 Mdot
.45241 .69843 Mdot
.42019 .54388 Mdot
.45112 .55903 Mdot
.64223 .57032 Mdot
.64276 .43444 Mdot
.526 .60706 Mdot
.6047 .4338 Mdot
.45721 .3896 Mdot
.38284 .58684 Mdot
.4792 .33002 Mdot
.62651 .5684 Mdot
.40286 .57379 Mdot
.66748 .43381 Mdot
.40826 .61297 Mdot
.72031 .35857 Mdot
.6179 .59694 Mdot
.49176 .58445 Mdot
.27225 .4312 Mdot
.39538 .21605 Mdot
.64878 .60125 Mdot
.36861 .3303 Mdot
.43135 .62989 Mdot
.43686 .5616 Mdot
.62191 .60213 Mdot
.47836 .38978 Mdot
.63891 .52922 Mdot
.64601 .64325 Mdot
.63642 .37579 Mdot
.64576 .64628 Mdot
.34904 .58447 Mdot
.45958 .34527 Mdot
.5756 .37265 Mdot
.55416 .38995 Mdot
.22919 .53542 Mdot
.41691 .57337 Mdot
.73899 .45678 Mdot
.44873 .35526 Mdot
.63852 .60877 Mdot
.64784 .41426 Mdot
.49655 .54751 Mdot
.63869 .58468 Mdot
.63089 .41571 Mdot
.29755 .41967 Mdot
.5852 .30186 Mdot
.6224 .63691 Mdot
.72032 .40115 Mdot
.62043 .44047 Mdot
.61999 .38731 Mdot
.77136 .35273 Mdot
.6112 .60221 Mdot
.30498 .43362 Mdot
.63413 .40895 Mdot
.28542 .6337 Mdot
.42569 .64633 Mdot
.24741 .48564 Mdot
.18106 .39363 Mdot
.76192 .35715 Mdot
.59676 .2636 Mdot
.30267 .46813 Mdot
.61248 .39726 Mdot
.48088 .59431 Mdot
.60786 .61799 Mdot
.61144 .61402 Mdot
.41795 .55126 Mdot
.4674 .57793 Mdot
.39858 .58585 Mdot
.48861 .59383 Mdot
.3732 .76594 Mdot
.40274 .6144 Mdot
.17961 .51521 Mdot
.65151 .6079 Mdot
.47576 .57413 Mdot
.49126 .37062 Mdot
.48586 .6178 Mdot
.66586 .40534 Mdot
.44598 .57345 Mdot
.46097 .57407 Mdot
.48534 .56919 Mdot
.61809 .41622 Mdot
.5549 .84232 Mdot
.21921 .33706 Mdot
.66942 .75387 Mdot
.41152 .29383 Mdot
.44279 .33323 Mdot
.41737 .56743 Mdot
.29861 .4491 Mdot
.57977 .77204 Mdot
.44465 .61675 Mdot
.51011 .14035 Mdot
.45274 .56301 Mdot
.72123 .64923 Mdot
.35759 .53832 Mdot
.6882 .74317 Mdot
.21569 .45869 Mdot
.47869 .60538 Mdot
.51099 .6701 Mdot
.68061 .68656 Mdot
.71132 .39634 Mdot
.65983 .39997 Mdot
.49 .37529 Mdot
.48198 .35073 Mdot
.68691 .4383 Mdot
.53675 .56989 Mdot
.51163 .55621 Mdot
.51005 .58578 Mdot
.47878 .40567 Mdot
.63756 .65321 Mdot
.32343 .44998 Mdot
.64022 .57237 Mdot
.15969 .6231 Mdot
.72674 .35362 Mdot
.63395 .47089 Mdot
.28858 .41431 Mdot
.47637 .37676 Mdot
.45585 .39015 Mdot
.30524 .45026 Mdot
.41609 .60579 Mdot
.60807 .59691 Mdot
.82823 .48322 Mdot
.50957 .53897 Mdot
.8314 .43972 Mdot
.60021 .59008 Mdot
.61587 .50926 Mdot
.63887 .42156 Mdot
.4517 .30744 Mdot
.43871 .56003 Mdot
.41955 .59459 Mdot
.68663 .60345 Mdot
.40015 .59026 Mdot
.59012 .6518 Mdot
.43503 .55565 Mdot
.6405 .33278 Mdot
.30001 .4121 Mdot
.68765 .43658 Mdot
.22033 .5298 Mdot
.65332 .58466 Mdot
.23441 .43363 Mdot
.49563 .38408 Mdot
.54471 .78924 Mdot
.66326 .42368 Mdot
.27738 .42573 Mdot
.49472 .39313 Mdot
.3228 .4554 Mdot
.4636 .63447 Mdot
.43818 .35284 Mdot
.27498 .44401 Mdot
.46767 .82623 Mdot
.44542 .64035 Mdot
.36186 .76522 Mdot
.62396 .42697 Mdot
.6388 .64555 Mdot
.46283 .55695 Mdot
.44781 .29828 Mdot
.35375 .59132 Mdot
.56217 .22995 Mdot
.57792 .37254 Mdot
.42915 .33517 Mdot
.36626 .3984 Mdot
.27976 .42765 Mdot
.51295 .23379 Mdot
.74189 .4298 Mdot
.59751 .61263 Mdot
.37945 .58575 Mdot
.64671 .79216 Mdot
.63463 .40938 Mdot
.42003 .61091 Mdot
.60801 .34177 Mdot
.6363 .40701 Mdot
.43788 .57716 Mdot
.63263 .44108 Mdot
.60871 .611 Mdot
.3064 .28551 Mdot
.59718 .61666 Mdot
.42142 .63592 Mdot
.65883 .441 Mdot
.453 .37914 Mdot
.62587 .62678 Mdot
.40564 .60836 Mdot
.41699 .55873 Mdot
.53358 .40261 Mdot
.4814 .57589 Mdot
.60991 .8059 Mdot
.48235 .57155 Mdot
.48812 .35794 Mdot
.42766 .54356 Mdot
.61891 .18368 Mdot
.53545 .31409 Mdot
.61055 .5922 Mdot
.43018 .33029 Mdot
.47216 .34398 Mdot
.33446 .30187 Mdot
.43356 .36844 Mdot
.43084 .62645 Mdot
.44045 .31449 Mdot
.27016 .48462 Mdot
.6319 .39086 Mdot
.38507 .56599 Mdot
.65647 .48465 Mdot
.48545 .32147 Mdot
.47212 .40122 Mdot
.42164 .5223 Mdot
.6079 .57066 Mdot
.4614 .58015 Mdot
.47422 .39678 Mdot
.66286 .64168 Mdot
.4129 .62983 Mdot
.423 .49517 Mdot
.53416 .40402 Mdot
.62305 .41144 Mdot
.36987 .53323 Mdot
.39205 .59988 Mdot
.46528 .32306 Mdot
.63095 .57568 Mdot
.67189 .3939 Mdot
.63231 .6212 Mdot
.77303 .61435 Mdot
.68631 .33968 Mdot
.42323 .79692 Mdot
.26486 .46094 Mdot
.62135 .25118 Mdot
.71493 .72349 Mdot
.46364 .2196 Mdot
.2954 .56249 Mdot
.80664 .6001 Mdot
.48649 .39318 Mdot
.62866 .32743 Mdot
.47566 .34371 Mdot
.46554 .60565 Mdot
.45576 .33557 Mdot
.70631 .73528 Mdot
.43972 .55614 Mdot
.45145 .32467 Mdot
.30869 .29977 Mdot
.46851 .57282 Mdot
.64928 .59888 Mdot
.45917 .86193 Mdot
.50423 .18842 Mdot
.73567 .34775 Mdot
.44382 .3569 Mdot
.32395 .63131 Mdot
.46032 .56078 Mdot
.48209 .56238 Mdot
.62317 .6314 Mdot
.40775 .54913 Mdot
.32201 .45304 Mdot
.29904 .41557 Mdot
.42147 .46166 Mdot
.22537 .35074 Mdot
.51912 .61456 Mdot
.62521 .62822 Mdot
.36843 .73512 Mdot
.5511 .20276 Mdot
.41797 .28279 Mdot
.62503 .37257 Mdot
.53073 .84266 Mdot
.52587 .56249 Mdot
.59584 .39463 Mdot
.688 .46046 Mdot
.63406 .59664 Mdot
.57101 .83563 Mdot
.65436 .39703 Mdot
.54718 .68504 Mdot
.41537 .68534 Mdot
.42033 .60106 Mdot
.65461 .43001 Mdot
.48676 .64073 Mdot
.58674 .18416 Mdot
.28699 .67824 Mdot
.18428 .48423 Mdot
.40311 .62788 Mdot
.49741 .21452 Mdot
.44368 .56721 Mdot
.64511 .53878 Mdot
.47958 .56865 Mdot
.63841 .62338 Mdot
.57741 .5458 Mdot
.50769 .43021 Mdot
.19118 .39028 Mdot
.72835 .35726 Mdot
.30403 .46808 Mdot
.42954 .5583 Mdot
.42147 .60061 Mdot
.30671 .42747 Mdot
.662 .61176 Mdot
.48694 .59583 Mdot
.31252 .49971 Mdot
.40823 .58667 Mdot
.65928 .395 Mdot
.20323 .54064 Mdot
.65049 .56231 Mdot
.4301 .53899 Mdot
.67128 .63105 Mdot
.62215 .4068 Mdot
.66943 .39784 Mdot
.4328 .52516 Mdot
.66279 .37877 Mdot
.45426 .56754 Mdot
.23157 .62816 Mdot
.65317 .62956 Mdot
.43039 .5104 Mdot
.66251 .59765 Mdot
.47906 .78368 Mdot
.66878 .43427 Mdot
.60726 .35274 Mdot
.52721 .62259 Mdot
.65624 .40052 Mdot
.74191 .38029 Mdot
.51742 .59253 Mdot
.37276 .56569 Mdot
.66918 .25031 Mdot
.44857 .36761 Mdot
.52278 .40884 Mdot
.67653 .41862 Mdot
.39151 .59665 Mdot
.39203 .55578 Mdot
.62003 .40566 Mdot
.48402 .7076 Mdot
.37486 .275 Mdot
.4536 .55737 Mdot
.64634 .6232 Mdot
.63793 .61073 Mdot
.38905 .6132 Mdot
.41724 .61611 Mdot
.46849 .37068 Mdot
.43137 .32997 Mdot
.44086 .29355 Mdot
.53324 .4043 Mdot
.6208 .34336 Mdot
.75984 .54969 Mdot
.62855 .38145 Mdot
.75557 .47492 Mdot
.61601 .2142 Mdot
.39557 .6495 Mdot
.43918 .33525 Mdot
.43031 .5994 Mdot
.45702 .5781 Mdot
.67183 .39321 Mdot
.68592 .3237 Mdot
.343 .61106 Mdot
.64389 .63863 Mdot
.67794 .41657 Mdot
.5275 .59297 Mdot
.78337 .50175 Mdot
.27971 .44665 Mdot
.72829 .31475 Mdot
.66686 .41818 Mdot
.63711 .59393 Mdot
.64663 .4472 Mdot
.4165 .59465 Mdot
.39216 .6328 Mdot
.6298 .60164 Mdot
.27091 .44186 Mdot
.50414 .59969 Mdot
.4371 .57428 Mdot
.31636 .21162 Mdot
.51261 .20398 Mdot
.57694 .38829 Mdot
.48325 .59594 Mdot
.39663 .54911 Mdot
.32556 .46016 Mdot
.41074 .59018 Mdot
.40804 .56071 Mdot
.34808 .23196 Mdot
.58296 .43162 Mdot
.33419 .45288 Mdot
.55252 .68896 Mdot
.59691 .59352 Mdot
.60876 .82409 Mdot
.4487 .30388 Mdot
.68959 .41552 Mdot
.38219 .25407 Mdot
.44098 .37134 Mdot
.57766 .23111 Mdot
.59292 .83417 Mdot
.52654 .40758 Mdot
.33521 .48451 Mdot
.38516 .65326 Mdot
.43901 .5523 Mdot
.43825 .56532 Mdot
.30017 .44348 Mdot
.60907 .60472 Mdot
.44263 .44969 Mdot
.3003 .7282 Mdot
.44999 .57394 Mdot
.58001 .64283 Mdot
.47528 .83532 Mdot
.50105 .41074 Mdot
.31869 .45418 Mdot
.26752 .42743 Mdot
.43045 .56012 Mdot
.3591 .23749 Mdot
.62182 .62395 Mdot
.4064 .60898 Mdot
.41395 .62395 Mdot
.44251 .35675 Mdot
.62055 .59162 Mdot
.48626 .39527 Mdot
.60562 .35553 Mdot
.7123 .68444 Mdot
.33718 .19134 Mdot
.67488 .41314 Mdot
.59986 .7967 Mdot
.64174 .38572 Mdot
.205 .44837 Mdot
.43754 .36728 Mdot
.4414 .62164 Mdot
.63763 .57658 Mdot
.40492 .61004 Mdot
.4298 .61326 Mdot
.41739 .60584 Mdot
.50579 .61764 Mdot
.53502 .14779 Mdot
.29826 .45717 Mdot
.43217 .5371 Mdot
.48566 .36114 Mdot
.59822 .80261 Mdot
.33432 .78111 Mdot
.42599 .59259 Mdot
.41649 .56113 Mdot
.64897 .5942 Mdot
.41342 .55141 Mdot
.63194 .3921 Mdot
.62939 .5751 Mdot
.49277 .58447 Mdot
.55612 .82858 Mdot
.46828 .61803 Mdot
.68793 .73685 Mdot
.64808 .44768 Mdot
.73986 .38593 Mdot
.47434 .55117 Mdot
.57272 .37544 Mdot
.52264 .40891 Mdot
.44134 .30406 Mdot
.68127 .42957 Mdot
.4588 .32252 Mdot
.26026 .68476 Mdot
.37081 .62269 Mdot
.47952 .59257 Mdot
.38771 .5597 Mdot
.44091 .32494 Mdot
.67825 .53643 Mdot
.53673 .25009 Mdot
.52737 .58436 Mdot
.45881 .36217 Mdot
.65186 .64641 Mdot
.38822 .42974 Mdot
.64631 .58207 Mdot
.33221 .43648 Mdot
.64524 .42828 Mdot
.29169 .46118 Mdot
.75424 .35776 Mdot
.61979 .59818 Mdot
.68685 .60039 Mdot
.44437 .33031 Mdot
.5888 .4748 Mdot
.86611 .59417 Mdot
.50751 .40605 Mdot
.25371 .51568 Mdot
.63203 .63354 Mdot
.43699 .6342 Mdot
.20568 .48567 Mdot
.60032 .48583 Mdot
.4613 .32636 Mdot
.45337 .61236 Mdot
.33186 .26007 Mdot
.46735 .37079 Mdot
.38183 .56979 Mdot
.47288 .38533 Mdot
.66361 .41441 Mdot
.45371 .36672 Mdot
.58722 .60962 Mdot
.40573 .57173 Mdot
.85598 .61391 Mdot
.23853 .42145 Mdot
.48346 .57417 Mdot
.67688 .42143 Mdot
.42476 .47906 Mdot
.4378 .60641 Mdot
.31895 .42973 Mdot
.45798 .34756 Mdot
.51054 .35043 Mdot
.46115 .55951 Mdot
.44534 .33907 Mdot
.66977 .59874 Mdot
.68095 .43153 Mdot
.34686 .42099 Mdot
.58718 .36401 Mdot
.61779 .62932 Mdot
.66228 .34512 Mdot
.68199 .40596 Mdot
.40321 .54693 Mdot
.39968 .61314 Mdot
.64635 .61732 Mdot
.25775 .33471 Mdot
.44035 .54584 Mdot
.44405 .62377 Mdot
.48704 .36586 Mdot
.4515 .3161 Mdot
.26731 .32803 Mdot
.47526 .38947 Mdot
.38961 .63406 Mdot
.64476 .61813 Mdot
.46076 .59 Mdot
.64223 .59113 Mdot
.39871 .56309 Mdot
.59706 .64341 Mdot
.66081 .62155 Mdot
.48912 .24384 Mdot
.45914 .60148 Mdot
.36717 .53199 Mdot
.42359 .6097 Mdot
.4024 .58781 Mdot
.47247 .36805 Mdot
.31469 .45165 Mdot
.47494 .53688 Mdot
.33646 .46754 Mdot
.32096 .43802 Mdot
.68999 .67661 Mdot
.44498 .36046 Mdot
.29242 .43501 Mdot
.39159 .79022 Mdot
.43436 .32164 Mdot
.29218 .4477 Mdot
.36419 .79824 Mdot
.675 .40852 Mdot
.59182 .61183 Mdot
.46892 .57379 Mdot
.80678 .59108 Mdot
.24494 .62672 Mdot
.43971 .36743 Mdot
.4849 .57471 Mdot
.43337 .60107 Mdot
.65874 .63313 Mdot
.15652 .5318 Mdot
.48841 .33619 Mdot
.46963 .60086 Mdot
.61469 .58863 Mdot
.14282 .46817 Mdot
.48758 .35083 Mdot
.29531 .44685 Mdot
.61693 .41438 Mdot
.57572 .60768 Mdot
.55281 .38844 Mdot
.61781 .40842 Mdot
.51374 .265 Mdot
.74517 .36241 Mdot
.4306 .62983 Mdot
.43923 .33422 Mdot
.74821 .31792 Mdot
.54242 .58291 Mdot
.65204 .35525 Mdot
.34421 .64974 Mdot
.63736 .59711 Mdot
.63055 .3948 Mdot
.2972 .46487 Mdot
.60596 .58081 Mdot
.65741 .618 Mdot
.66541 .38622 Mdot
.36864 .4683 Mdot
.61272 .50504 Mdot
.66317 .39475 Mdot
.64657 .23426 Mdot
.79572 .56307 Mdot
.43676 .32018 Mdot
.31869 .43653 Mdot
.81518 .4688 Mdot
.62305 .61809 Mdot
.53457 .84168 Mdot
.72971 .30452 Mdot
.45148 .55912 Mdot
.2927 .43112 Mdot
.71663 .55472 Mdot
.28129 .71223 Mdot
.63571 .4049 Mdot
.52853 .42405 Mdot
.26481 .44518 Mdot
.44495 .55152 Mdot
.34918 .67461 Mdot
.45932 .61234 Mdot
.63863 .42501 Mdot
.41212 .7661 Mdot
.63748 .59327 Mdot
.67994 .40871 Mdot
.7292 .3163 Mdot
.45313 .57001 Mdot
.45699 .60888 Mdot
.2321 .56298 Mdot
.60163 .60432 Mdot
.44563 .29729 Mdot
.43137 .62847 Mdot
.441 .57367 Mdot
.36927 .56505 Mdot
.41714 .51464 Mdot
.38791 .22053 Mdot
.46773 .6017 Mdot
.65936 .33249 Mdot
.43246 .53872 Mdot
.457 .60045 Mdot
.66862 .63417 Mdot
.38792 .17008 Mdot
.61461 .34978 Mdot
.44434 .57273 Mdot
.44429 .63188 Mdot
.66719 .38656 Mdot
.56642 .51135 Mdot
.59573 .47763 Mdot
.53999 .39521 Mdot
.29927 .58768 Mdot
.50284 .62055 Mdot
.62797 .58011 Mdot
.27086 .4298 Mdot
.38939 .60987 Mdot
.62716 .58099 Mdot
.48177 .61186 Mdot
.46341 .36934 Mdot
.43411 .32511 Mdot
.72953 .40404 Mdot
.2902 .44077 Mdot
.2389 .60175 Mdot
.74919 .48827 Mdot
.48814 .37541 Mdot
.47813 .58869 Mdot
.6828 .43921 Mdot
.47124 .39691 Mdot
.54746 .39328 Mdot
.40052 .5274 Mdot
.61283 .61928 Mdot
.64746 .60353 Mdot
.24646 .48393 Mdot
.59355 .28469 Mdot
.30658 .2351 Mdot
.66215 .41841 Mdot
.49421 .57617 Mdot
.73747 .4429 Mdot
.64801 .60219 Mdot
.21672 .48574 Mdot
.29006 .43496 Mdot
.6342 .40426 Mdot
.41817 .28427 Mdot
.64034 .5867 Mdot
.61047 .6299 Mdot
.43228 .63896 Mdot
.429 .58066 Mdot
.2949 .54963 Mdot
.34416 .49056 Mdot
.62319 .40282 Mdot
.31165 .42973 Mdot
.49326 .39646 Mdot
.46586 .60986 Mdot
.66813 .6107 Mdot
.81948 .50626 Mdot
.43903 .63252 Mdot
.47169 .37184 Mdot
.63784 .59996 Mdot
.29852 .42419 Mdot
.32161 .43615 Mdot
.40365 .58791 Mdot
.38185 .73465 Mdot
.64179 .39723 Mdot
.64791 .59848 Mdot
.78737 .45159 Mdot
.434 .54339 Mdot
.42703 .57613 Mdot
.34224 .57183 Mdot
.65279 .38205 Mdot
.73715 .40053 Mdot
.26994 .44671 Mdot
.61701 .60999 Mdot
.47476 .61091 Mdot
.28467 .44456 Mdot
.74003 .41517 Mdot
.43381 .35191 Mdot
.46006 .37499 Mdot
.32008 .43145 Mdot
.30289 .42883 Mdot
.31005 .42427 Mdot
.52132 .84706 Mdot
.58622 .61176 Mdot
.4216 .50787 Mdot
.45723 .551 Mdot
.238 .48308 Mdot
.50324 .55759 Mdot
.6523 .44902 Mdot
.45391 .37485 Mdot
.42833 .61021 Mdot
.42072 .63501 Mdot
.35552 .54696 Mdot
.39245 .51533 Mdot
.64542 .56225 Mdot
.61857 .595 Mdot
.37408 .63294 Mdot
.44273 .36091 Mdot
.14998 .5968 Mdot
.77247 .6924 Mdot
.46706 .54628 Mdot
.59672 .49835 Mdot
.66714 .60895 Mdot
.64747 .37832 Mdot
.56764 .43985 Mdot
.64415 .44526 Mdot
.62409 .61018 Mdot
.46633 .60762 Mdot
.75931 .48214 Mdot
.32658 .44257 Mdot
.39302 .59033 Mdot
.63598 .41646 Mdot
.39531 .58773 Mdot
.61784 .40972 Mdot
.75505 .61241 Mdot
.60299 .20078 Mdot
.45223 .56236 Mdot
.40866 .54101 Mdot
.33391 .63582 Mdot
.42817 .59262 Mdot
.28077 .38221 Mdot
.66539 .60707 Mdot
.25901 .30063 Mdot
.44019 .63969 Mdot
.54592 .75394 Mdot
.44368 .54506 Mdot
.33507 .26473 Mdot
.42363 .5799 Mdot
.47487 .43212 Mdot
.44646 .55445 Mdot
.4036 .56729 Mdot
.65216 .44404 Mdot
.66779 .3876 Mdot
.66796 .58439 Mdot
.44692 .29826 Mdot
.66099 .76563 Mdot
.43358 .57416 Mdot
.58648 .3634 Mdot
.59904 .37199 Mdot
.30894 .43095 Mdot
.62421 .61217 Mdot
.14009 .48546 Mdot
.62259 .42908 Mdot
.40347 .27912 Mdot
.24495 .35927 Mdot
.5543 .38692 Mdot
.54822 .4012 Mdot
.61416 .53577 Mdot
.27695 .43115 Mdot
.44796 .55165 Mdot
.78626 .39706 Mdot
.52491 .20949 Mdot
.48922 .53913 Mdot
.68117 .41635 Mdot
.55823 .77825 Mdot
.81544 .48139 Mdot
.26279 .42939 Mdot
.28524 .45969 Mdot
.61994 .41832 Mdot
.47083 .30617 Mdot
.45974 .64823 Mdot
.28715 .43504 Mdot
.48278 .38423 Mdot
.43608 .314 Mdot
.41672 .34434 Mdot
.61932 .62036 Mdot
.73107 .32709 Mdot
.72198 .51802 Mdot
.61936 .41111 Mdot
.23839 .43484 Mdot
.57667 .6006 Mdot
.59291 .58325 Mdot
.44565 .31132 Mdot
.47509 .36849 Mdot
.5898 .59656 Mdot
.40896 .64445 Mdot
.34456 .55032 Mdot
.44766 .57207 Mdot
.30561 .44288 Mdot
.42253 .58619 Mdot
.46597 .36559 Mdot
.64105 .40741 Mdot
.47703 .36255 Mdot
.62849 .43651 Mdot
.76335 .53496 Mdot
.40608 .60453 Mdot
.40865 .56575 Mdot
.24018 .6232 Mdot
.67346 .59892 Mdot
.76638 .39485 Mdot
.63993 .33071 Mdot
.47847 .34636 Mdot
.41006 .55857 Mdot
.66187 .59103 Mdot
.27564 .41443 Mdot
.23671 .62067 Mdot
.3888 .59957 Mdot
.66582 .6045 Mdot
.47436 .59919 Mdot
.42334 .80756 Mdot
.48442 .1855 Mdot
.63531 .61862 Mdot
.17931 .41163 Mdot
.46531 .61603 Mdot
.57194 .5566 Mdot
.37692 .57472 Mdot
.2917 .50556 Mdot
.43625 .54489 Mdot
.60006 .59003 Mdot
.44715 .57768 Mdot
.61117 .57866 Mdot
.49124 .35932 Mdot
.63275 .37989 Mdot
.63462 .63611 Mdot
.40205 .61682 Mdot
.62285 .84459 Mdot
.64625 .42597 Mdot
.43446 .55909 Mdot
.63929 .43547 Mdot
.61096 .58724 Mdot
.61015 .62799 Mdot
.28485 .72911 Mdot
.57441 .40326 Mdot
.66362 .41268 Mdot
.4701 .59517 Mdot
.68639 .50281 Mdot
.46276 .59626 Mdot
.28112 .54104 Mdot
.38653 .61903 Mdot
.43053 .54367 Mdot
.28208 .7512 Mdot
.63096 .39032 Mdot
.31995 .23194 Mdot
.3108 .73833 Mdot
.50542 .84798 Mdot
.58117 .62196 Mdot
.2637 .42841 Mdot
.56644 .83687 Mdot
.59921 .35932 Mdot
.45209 .35338 Mdot
.42667 .60918 Mdot
.63236 .55479 Mdot
.64501 .39093 Mdot
.31303 .45177 Mdot
.45115 .56195 Mdot
.47566 .37062 Mdot
.38251 .28214 Mdot
.6147 .39022 Mdot
.62213 .61669 Mdot
.65019 .63558 Mdot
.16014 .42286 Mdot
.47814 .60738 Mdot
.41139 .56115 Mdot
.6403 .42707 Mdot
.50726 .54099 Mdot
.28183 .42456 Mdot
.34308 .27519 Mdot
.66286 .41426 Mdot
.56009 .46993 Mdot
.61196 .59846 Mdot
.43175 .6008 Mdot
.69378 .55519 Mdot
.41173 .30375 Mdot
.59664 .68699 Mdot
.30037 .44695 Mdot
.27689 .54846 Mdot
.59937 .59069 Mdot
.64339 .41424 Mdot
.59534 .30688 Mdot
.35474 .58071 Mdot
.43632 .59699 Mdot
.27217 .54959 Mdot
.39972 .4635 Mdot
.1851 .49391 Mdot
.38142 .57792 Mdot
.41362 .45779 Mdot
.38765 .57405 Mdot
.36158 .57505 Mdot
.39715 .63723 Mdot
.42191 .57275 Mdot
.6663 .6061 Mdot
.45297 .52016 Mdot
.44712 .34814 Mdot
.46254 .6954 Mdot
.55006 .42373 Mdot
.47108 .56434 Mdot
.46372 .60542 Mdot
.62574 .70993 Mdot
.59811 .38665 Mdot
.65114 .62617 Mdot
.6794 .63969 Mdot
.65445 .37538 Mdot
.3537 .54313 Mdot
.45478 .30213 Mdot
.42667 .52017 Mdot
.47325 .36383 Mdot
.66419 .59735 Mdot
.48098 .34589 Mdot
.62435 .3809 Mdot
.43845 .33609 Mdot
.6292 .3388 Mdot
.63544 .39189 Mdot
.60293 .61257 Mdot
.40682 .58002 Mdot
.6777 .41553 Mdot
.23625 .56217 Mdot
.30474 .44275 Mdot
.28721 .73335 Mdot
.47624 .61554 Mdot
.57238 .42447 Mdot
.42037 .49485 Mdot
.47578 .36152 Mdot
.42966 .19668 Mdot
.65929 .62328 Mdot
.3246 .42897 Mdot
.665 .59717 Mdot
.67988 .24401 Mdot
.31713 .44433 Mdot
.37285 .80345 Mdot
.62281 .28795 Mdot
.49535 .32708 Mdot
.41467 .64549 Mdot
.376 .68131 Mdot
.49019 .40391 Mdot
.64329 .39133 Mdot
.60598 .27898 Mdot
.40076 .5705 Mdot
.4659 .22235 Mdot
.66936 .5838 Mdot
.44132 .30785 Mdot
.65076 .41269 Mdot
.67809 .40542 Mdot
.4102 .61674 Mdot
.29472 .3291 Mdot
.38729 .58337 Mdot
.5773 .28007 Mdot
.29188 .57707 Mdot
.3345 .58578 Mdot
.43373 .55585 Mdot
.48093 .33358 Mdot
.47431 .59838 Mdot
.32486 .58028 Mdot
.77338 .36133 Mdot
.50794 .61129 Mdot
.67463 .32424 Mdot
.24186 .4333 Mdot
.62508 .60073 Mdot
.48286 .55366 Mdot
.56039 .38285 Mdot
.47608 .60628 Mdot
.73346 .2427 Mdot
.28991 .44718 Mdot
.56505 .36588 Mdot
.431 .54011 Mdot
.41946 .62254 Mdot
.43004 .67559 Mdot
.6182 .55296 Mdot
.41536 .28437 Mdot
.43866 .59128 Mdot
.28843 .61395 Mdot
.65218 .4327 Mdot
.38581 .58821 Mdot
.43668 .56336 Mdot
.69635 .68025 Mdot
.66421 .38846 Mdot
.48056 .35697 Mdot
.43944 .37135 Mdot
.49981 .39216 Mdot
.3169 .47188 Mdot
.54022 .43825 Mdot
.22908 .48591 Mdot
.49832 .19361 Mdot
.27976 .41943 Mdot
.45956 .62725 Mdot
.34835 .63368 Mdot
.44794 .62784 Mdot
.29996 .46613 Mdot
.65671 .38482 Mdot
.6504 .62854 Mdot
.71479 .44264 Mdot
.49127 .40916 Mdot
.38486 .56563 Mdot
.31888 .46019 Mdot
.60932 .61874 Mdot
.28135 .40234 Mdot
.62017 .60475 Mdot
.66068 .40925 Mdot
.67164 .38134 Mdot
.30937 .45946 Mdot
.65277 .58627 Mdot
.66349 .33951 Mdot
.29272 .71485 Mdot
.38516 .62055 Mdot
.70022 .39119 Mdot
.66771 .59212 Mdot
.63838 .56385 Mdot
.64719 .57309 Mdot
.40078 .59342 Mdot
.59182 .49986 Mdot
.37588 .55319 Mdot
.62312 .40663 Mdot
.47378 .38459 Mdot
.30417 .4932 Mdot
.79325 .54465 Mdot
.28623 .48593 Mdot
.50049 .59776 Mdot
.45313 .57411 Mdot
.43095 .56016 Mdot
.40458 .63274 Mdot
.57395 .29664 Mdot
.41302 .61196 Mdot
.64746 .44365 Mdot
.46388 .35529 Mdot
.46523 .55745 Mdot
.43648 .35888 Mdot
.63375 .51945 Mdot
.26988 .42929 Mdot
.53117 .43345 Mdot
.62807 .81907 Mdot
.612 .62294 Mdot
.47445 .39059 Mdot
.45092 .35019 Mdot
.29654 .41963 Mdot
.64788 .39229 Mdot
.61393 .60336 Mdot
.30628 .5101 Mdot
.31104 .42663 Mdot
.44496 .57586 Mdot
.46284 .25641 Mdot
.44432 .23795 Mdot
.43064 .54791 Mdot
.43881 .61427 Mdot
.42932 .33706 Mdot
.47529 .31179 Mdot
.84546 .45897 Mdot
.20035 .50037 Mdot
.31257 .45637 Mdot
.27232 .44307 Mdot
.60446 .57302 Mdot
.42123 .53327 Mdot
.62287 .40994 Mdot
.20544 .55318 Mdot
.41289 .47535 Mdot
.22772 .58706 Mdot
.34907 .42015 Mdot
.39693 .6072 Mdot
.39984 .71538 Mdot
.4546 .56949 Mdot
.66125 .62592 Mdot
.60445 .59548 Mdot
.63767 .63072 Mdot
.63937 .3951 Mdot
.49709 .78727 Mdot
.6584 .44035 Mdot
.66597 .78889 Mdot
.59712 .5911 Mdot
.56249 .32434 Mdot
.47233 .32827 Mdot
.4876 .56042 Mdot
.28877 .42412 Mdot
.60873 .42572 Mdot
.47378 .63824 Mdot
.36944 .22942 Mdot
.4414 .33099 Mdot
.60135 .61109 Mdot
.61225 .5377 Mdot
.74398 .68949 Mdot
.57623 .45942 Mdot
.5317 .60642 Mdot
.4001 .67958 Mdot
.31289 .4329 Mdot
.58872 .68428 Mdot
.30209 .46903 Mdot
.63236 .41084 Mdot
.40888 .56915 Mdot
.41285 .57436 Mdot
.39529 .56551 Mdot
.41124 .60941 Mdot
.66098 .37985 Mdot
.50242 .58011 Mdot
.61891 .18369 Mdot
.43347 .3244 Mdot
.45149 .81799 Mdot
.27969 .44091 Mdot
.68004 .42727 Mdot
.46571 .35775 Mdot
.43585 .28976 Mdot
.21681 .51585 Mdot
.4506 .55661 Mdot
.42625 .61074 Mdot
.40811 .28265 Mdot
.38339 .57316 Mdot
.52452 .59148 Mdot
.44704 .34316 Mdot
.29384 .48792 Mdot
.28206 .4165 Mdot
.28812 .45879 Mdot
.66168 .38947 Mdot
.65899 .59052 Mdot
.29728 .43821 Mdot
.49028 .35874 Mdot
.48874 .60656 Mdot
.41414 .6261 Mdot
.6676 .59071 Mdot
.72787 .3003 Mdot
.26253 .43261 Mdot
.61058 .53428 Mdot
.61554 .57935 Mdot
.58604 .61429 Mdot
.43801 .59737 Mdot
.48265 .53365 Mdot
.59825 .56838 Mdot
.30634 .41949 Mdot
.68234 .42148 Mdot
.52891 .37477 Mdot
.63224 .41827 Mdot
.60836 .60782 Mdot
.40445 .62421 Mdot
.60454 .60496 Mdot
.48547 .59269 Mdot
.47278 .8936 Mdot
.41755 .57578 Mdot
.53047 .18281 Mdot
.27399 .5117 Mdot
.45245 .34348 Mdot
.66001 .33886 Mdot
.44375 .31044 Mdot
.6108 .58183 Mdot
.39746 .61707 Mdot
.27319 .44991 Mdot
.45539 .8475 Mdot
.57836 .59527 Mdot
.46051 .36939 Mdot
.45907 .30069 Mdot
.6381 .38804 Mdot
.4679 .55795 Mdot
.43168 .59745 Mdot
.45096 .32213 Mdot
.34229 .53009 Mdot
.64795 .58887 Mdot
.41714 .55941 Mdot
.45519 .58772 Mdot
.45067 .34112 Mdot
.28793 .70653 Mdot
.58396 .56335 Mdot
.41586 .56823 Mdot
.60417 .32851 Mdot
.65801 .44692 Mdot
.41222 .6411 Mdot
.50314 .5749 Mdot
.29306 .42839 Mdot
.51052 .82018 Mdot
.78231 .37537 Mdot
.64709 .44954 Mdot
.4489 .30102 Mdot
.47581 .61252 Mdot
.46998 .32634 Mdot
.4092 .62222 Mdot
.61793 .77647 Mdot
.43824 .31356 Mdot
.43086 .62356 Mdot
.44868 .53838 Mdot
.60079 .60086 Mdot
.4141 .61502 Mdot
.65183 .70231 Mdot
.48533 .39985 Mdot
.42336 .62089 Mdot
.3865 .73584 Mdot
.67014 .40544 Mdot
.46909 .5464 Mdot
.27797 .44688 Mdot
.30311 .50424 Mdot
.74716 .50186 Mdot
.59885 .35022 Mdot
.28463 .45434 Mdot
.3938 .58526 Mdot
.45925 .29564 Mdot
.61815 .41274 Mdot
.45718 .21739 Mdot
.41069 .55589 Mdot
.64001 .42511 Mdot
.64302 .40836 Mdot
.28709 .45168 Mdot
.25701 .27426 Mdot
.50052 .57391 Mdot
.42565 .59155 Mdot
.67086 .70088 Mdot
.65625 .64053 Mdot
.4188 .58472 Mdot
.44651 .63262 Mdot
.64485 .44204 Mdot
.53074 .6193 Mdot
.59264 .74974 Mdot
.31028 .29725 Mdot
.62321 .43863 Mdot
.51107 .39125 Mdot
.45362 .29149 Mdot
.28051 .43858 Mdot
.63266 .60373 Mdot
.27275 .4575 Mdot
.44393 .35369 Mdot
.46011 .62494 Mdot
.62659 .43027 Mdot
.63294 .675 Mdot
.61604 .40804 Mdot
.58303 .36068 Mdot
.67305 .61012 Mdot
.72482 .45787 Mdot
.65272 .18087 Mdot
.72809 .52435 Mdot
.59612 .40843 Mdot
.30868 .43089 Mdot
.50884 .26442 Mdot
.45474 .58327 Mdot
.56137 .67603 Mdot
.40294 .58275 Mdot
.3983 .73422 Mdot
.4735 .38775 Mdot
.44212 .29144 Mdot
.4116 .56912 Mdot
.28838 .5663 Mdot
.61635 .40053 Mdot
.63115 .39148 Mdot
.42561 .61808 Mdot
.65664 .40055 Mdot
.43171 .58257 Mdot
.47081 .36624 Mdot
.36087 .20728 Mdot
.44702 .56618 Mdot
.37548 .56082 Mdot
.63978 .47536 Mdot
.30155 .75435 Mdot
.64486 .30919 Mdot
.40097 .71062 Mdot
.76116 .66453 Mdot
.65622 .40111 Mdot
.41282 .52894 Mdot
.50841 .40763 Mdot
.42939 .33908 Mdot
.66297 .34007 Mdot
.41215 .58664 Mdot
.40997 .59099 Mdot
.41271 .55776 Mdot
.45733 .60966 Mdot
.56739 .67919 Mdot
.49328 .53202 Mdot
.44343 .74633 Mdot
.42793 .61295 Mdot
.35294 .68055 Mdot
.67614 .41856 Mdot
.68406 .60315 Mdot
.26877 .45562 Mdot
.3985 .60845 Mdot
.55837 .60937 Mdot
.66547 .44285 Mdot
.66848 .7869 Mdot
.64914 .3848 Mdot
.47122 .34307 Mdot
.63826 .37936 Mdot
.48377 .57852 Mdot
.63884 .61078 Mdot
.53681 .396 Mdot
.52174 .23269 Mdot
.45286 .35493 Mdot
.48343 .57404 Mdot
.5575 .36631 Mdot
.45057 .35398 Mdot
.64107 .51651 Mdot
.6405 .60687 Mdot
.28301 .61454 Mdot
.60403 .59548 Mdot
.42972 .62446 Mdot
.43696 .62553 Mdot
.6816 .35807 Mdot
.61992 .38969 Mdot
.60661 .58995 Mdot
.30226 .2201 Mdot
.30196 .46977 Mdot
.63538 .62872 Mdot
.35612 .6057 Mdot
.50907 .48554 Mdot
.64604 .61261 Mdot
.32321 .53513 Mdot
.63818 .39261 Mdot
.5977 .5855 Mdot
.35403 .60246 Mdot
.67051 .27233 Mdot
.32263 .42994 Mdot
.48082 .32413 Mdot
.44665 .41718 Mdot
.4782 .39835 Mdot
.68476 .41332 Mdot
.44278 .32501 Mdot
.65633 .43292 Mdot
.76047 .39586 Mdot
.33264 .68539 Mdot
.68381 .43944 Mdot
.68113 .39621 Mdot
.44493 .33171 Mdot
.42752 .55386 Mdot
.46684 .41156 Mdot
.37505 .59652 Mdot
.45119 .64634 Mdot
.66353 .42772 Mdot
.59862 .59323 Mdot
.59263 .61576 Mdot
.36024 .6803 Mdot
.65088 .63562 Mdot
.47405 .36564 Mdot
.48951 .18739 Mdot
.75587 .36239 Mdot
.65134 .42953 Mdot
.6726 .3872 Mdot
.46323 .59906 Mdot
.45996 .32406 Mdot
.4933 .3553 Mdot
.62904 .40334 Mdot
.54458 .65653 Mdot
.40002 .53981 Mdot
.66563 .57595 Mdot
.5955 .59206 Mdot
.64059 .61896 Mdot
.63533 .57033 Mdot
.58285 .73595 Mdot
.63675 .39274 Mdot
.60302 .58606 Mdot
.42964 .62106 Mdot
.41122 .59017 Mdot
.54134 .39883 Mdot
.28538 .45669 Mdot
.48494 .6062 Mdot
.39469 .63899 Mdot
.43712 .60011 Mdot
.45822 .37217 Mdot
.3629 .62946 Mdot
.4445 .29763 Mdot
.48586 .33031 Mdot
.43438 .34332 Mdot
.60336 .35529 Mdot
.37845 .67432 Mdot
.77989 .65198 Mdot
.46982 .601 Mdot
.50018 .52966 Mdot
.47255 .33049 Mdot
.40467 .20823 Mdot
.73576 .41166 Mdot
.41023 .55746 Mdot
.41117 .31509 Mdot
.44937 .32095 Mdot
.63985 .64187 Mdot
.41357 .5832 Mdot
.49484 .41103 Mdot
.2721 .42758 Mdot
.36153 .60653 Mdot
.45761 .39294 Mdot
.64197 .58086 Mdot
.28265 .47102 Mdot
.60332 .57894 Mdot
.43849 .35625 Mdot
.45465 .54037 Mdot
.87571 .58179 Mdot
.49842 .39091 Mdot
.37551 .78908 Mdot
.56354 .59227 Mdot
.41799 .55824 Mdot
.47765 .39302 Mdot
.65634 .63945 Mdot
.6847 .41978 Mdot
.46118 .45846 Mdot
.65244 .62976 Mdot
.44178 .29221 Mdot
.46338 .39635 Mdot
.44792 .34534 Mdot
.62327 .59418 Mdot
.38333 .60527 Mdot
.63199 .58949 Mdot
.63929 .37981 Mdot
.46289 .57687 Mdot
.70598 .73427 Mdot
.49626 .52902 Mdot
.61124 .58269 Mdot
.48154 .36798 Mdot
.32705 .45662 Mdot
.45811 .56426 Mdot
.35649 .76904 Mdot
.491 .58422 Mdot
.64305 .43163 Mdot
.31166 .26513 Mdot
.62957 .67738 Mdot
.45078 .54846 Mdot
.46289 .60045 Mdot
.6254 .39786 Mdot
.45309 .55876 Mdot
.44573 .54776 Mdot
.58588 .38048 Mdot
.61901 .59049 Mdot
.44958 .57956 Mdot
.48394 .3774 Mdot
.78341 .40804 Mdot
.38793 .545 Mdot
.37362 .3277 Mdot
.28096 .59515 Mdot
.28788 .27223 Mdot
.40205 .57915 Mdot
.20626 .53063 Mdot
.45114 .61319 Mdot
.3951 .59526 Mdot
.46714 .59431 Mdot
.40944 .70589 Mdot
.4412 .33798 Mdot
.46076 .36096 Mdot
.32002 .42716 Mdot
.28322 .59988 Mdot
.29136 .43043 Mdot
.64809 .38792 Mdot
.35167 .33812 Mdot
.43808 .31591 Mdot
.6425 .58047 Mdot
.39083 .58337 Mdot
.4955 .40295 Mdot
.42877 .60179 Mdot
.48528 .58323 Mdot
.48116 .33158 Mdot
.49389 .34626 Mdot
.57643 .36841 Mdot
.27163 .43755 Mdot
.63849 .63362 Mdot
.45147 .63988 Mdot
.32123 .43957 Mdot
.38429 .60495 Mdot
.22899 .47458 Mdot
.64217 .63142 Mdot
.62186 .58966 Mdot
.61267 .63431 Mdot
.46128 .62401 Mdot
.47518 .56917 Mdot
.65865 .43955 Mdot
.65312 .58501 Mdot
.6673 .40098 Mdot
.53272 .39957 Mdot
.36123 .31894 Mdot
.41207 .58682 Mdot
.58439 .54374 Mdot
.28387 .42884 Mdot
.47029 .35013 Mdot
.39175 .28899 Mdot
.3284 .43736 Mdot
.48969 .58492 Mdot
.47927 .33161 Mdot
.30201 .46422 Mdot
.51699 .65562 Mdot
.81641 .60225 Mdot
.32196 .46364 Mdot
.42957 .61973 Mdot
.49049 .65633 Mdot
.27317 .67285 Mdot
.3174 .47027 Mdot
.63161 .43091 Mdot
.46236 .6239 Mdot
.43234 .50143 Mdot
.26323 .4375 Mdot
.77884 .41754 Mdot
.45462 .34116 Mdot
.69253 .30455 Mdot
.42157 .65614 Mdot
.53087 .6758 Mdot
.2831 .46519 Mdot
.61534 .60652 Mdot
.67499 .63038 Mdot
.4456 .6012 Mdot
.31203 .47313 Mdot
.61818 .42917 Mdot
.45838 .34377 Mdot
.63614 .33814 Mdot
.62596 .59342 Mdot
.66086 .49384 Mdot
.47548 .38074 Mdot
.60139 .53312 Mdot
.31879 .27761 Mdot
.33456 .56801 Mdot
.36326 .70737 Mdot
.54945 .2135 Mdot
.45207 .63322 Mdot
.30993 .46805 Mdot
.66211 .44336 Mdot
.62149 .42361 Mdot
.66092 .4155 Mdot
.6564 .33788 Mdot
.561 .43546 Mdot
.44753 .37389 Mdot
.49382 .23072 Mdot
.28481 .44313 Mdot
.29327 .6465 Mdot
.38551 .60255 Mdot
.45217 .57242 Mdot
.49464 .57759 Mdot
.38374 .587 Mdot
.4521 .60598 Mdot
.65302 .39433 Mdot
.65731 .33663 Mdot
.51184 .35025 Mdot
.64869 .62155 Mdot
.28799 .48458 Mdot
.47266 .32862 Mdot
.42992 .33108 Mdot
.3042 .45669 Mdot
.63543 .53381 Mdot
.45427 .3845 Mdot
.48064 .34776 Mdot
.49488 .58942 Mdot
.63747 .58611 Mdot
.46235 .52497 Mdot
.44504 .62303 Mdot
.46962 .35508 Mdot
.37767 .429 Mdot
.62025 .72969 Mdot
.36043 .55799 Mdot
.25581 .44986 Mdot
.57779 .50193 Mdot
.31656 .46998 Mdot
.37439 .57732 Mdot
.39033 .21317 Mdot
.44345 .35165 Mdot
.46608 .33462 Mdot
.31051 .46536 Mdot
.57578 .56031 Mdot
.63407 .59862 Mdot
.43687 .28768 Mdot
.64601 .43681 Mdot
.442 .62836 Mdot
.37239 .29801 Mdot
.55986 .56555 Mdot
.3159 .32093 Mdot
.65771 .42231 Mdot
.49029 .34832 Mdot
.46513 .55607 Mdot
.43114 .61909 Mdot
.30898 .42929 Mdot
.74179 .62067 Mdot
.36754 .61891 Mdot
.50909 .84846 Mdot
.6162 .2079 Mdot
.69831 .28457 Mdot
.43619 .59683 Mdot
.61861 .59236 Mdot
.43775 .36748 Mdot
.31738 .43484 Mdot
.49382 .60939 Mdot
.80513 .61877 Mdot
.67783 .5986 Mdot
.63696 .41333 Mdot
.51101 .4116 Mdot
.56794 .43919 Mdot
.48152 .60483 Mdot
.40406 .58259 Mdot
.40376 .59962 Mdot
.84427 .51931 Mdot
.46568 .3762 Mdot
.66893 .61473 Mdot
.30182 .44887 Mdot
.65355 .63347 Mdot
.45632 .35393 Mdot
.69663 .47418 Mdot
.46273 .55916 Mdot
.67582 .5969 Mdot
.61882 .60731 Mdot
.63951 .38756 Mdot
.68609 .41086 Mdot
.52051 .3867 Mdot
.41906 .57566 Mdot
.47949 .40712 Mdot
.59926 .60173 Mdot
.4307 .28262 Mdot
.31696 .44202 Mdot
.6706 .43094 Mdot
.42612 .61258 Mdot
.4461 .35241 Mdot
.5053 .58453 Mdot
.65117 .60635 Mdot
.48042 .34649 Mdot
.57485 .37157 Mdot
.27365 .44439 Mdot
.41544 .60074 Mdot
.25384 .43814 Mdot
.45008 .30155 Mdot
.45596 .58636 Mdot
.64264 .54287 Mdot
.28163 .47479 Mdot
.53553 .24514 Mdot
.45341 .3793 Mdot
.58381 .36684 Mdot
.60939 .63101 Mdot
.77508 .43379 Mdot
.46598 .33773 Mdot
.6517 .5433 Mdot
.76056 .57372 Mdot
.4549 .63924 Mdot
.62745 .61944 Mdot
.48866 .259 Mdot
.58281 .84841 Mdot
.31292 .71463 Mdot
.4348 .55995 Mdot
.4698 .38983 Mdot
.31775 .45865 Mdot
.65231 .42965 Mdot
.37378 .32534 Mdot
.3253 .58187 Mdot
.46513 .3144 Mdot
.46676 .59847 Mdot
.60896 .59255 Mdot
.63673 .4008 Mdot
.76486 .49436 Mdot
.48754 .36241 Mdot
.46777 .3848 Mdot
.46045 .5537 Mdot
.29003 .43607 Mdot
.35286 .74107 Mdot
.4682 .36806 Mdot
.41243 .27808 Mdot
.51381 .26323 Mdot
.31919 .46066 Mdot
.44397 .6154 Mdot
.35481 .67446 Mdot
.40807 .63607 Mdot
.3935 .80506 Mdot
.44729 .3054 Mdot
.6528 .61845 Mdot
.3992 .58593 Mdot
.29787 .30446 Mdot
.46656 .35078 Mdot
.59814 .49711 Mdot
.37295 .40822 Mdot
.63683 .3933 Mdot
.39503 .28204 Mdot
.42048 .59124 Mdot
.6159 .40297 Mdot
.28438 .4289 Mdot
.42006 .56913 Mdot
.47547 .57052 Mdot
.65188 .63988 Mdot
.63104 .41103 Mdot
.77907 .58564 Mdot
.67973 .40619 Mdot
.64785 .44737 Mdot
.61227 .63811 Mdot
.44447 .58805 Mdot
.47371 .34552 Mdot
.45046 .31909 Mdot
.47223 .63262 Mdot
.42159 .18933 Mdot
.63373 .59661 Mdot
.23773 .43161 Mdot
.84151 .49701 Mdot
.3395 .60063 Mdot
.38918 .28937 Mdot
.73998 .61998 Mdot
.61783 .42739 Mdot
.42659 .61612 Mdot
.62673 .57885 Mdot
.44054 .28343 Mdot
.47742 .38128 Mdot
.39395 .61752 Mdot
.64284 .40415 Mdot
.27891 .42165 Mdot
.49512 .39016 Mdot
.29667 .32735 Mdot
.40346 .60488 Mdot
.47624 .22768 Mdot
.48403 .39355 Mdot
.48693 .8635 Mdot
.44172 .27404 Mdot
.63173 .6214 Mdot
.48361 .58205 Mdot
.64745 .63658 Mdot
.3071 .44626 Mdot
.51504 .39392 Mdot
.64155 .40593 Mdot
.33954 .61024 Mdot
.72785 .25505 Mdot
.44286 .33248 Mdot
.66584 .608 Mdot
.45132 .54842 Mdot
.37222 .65304 Mdot
.42486 .58734 Mdot
.49307 .65123 Mdot
.24101 .42546 Mdot
.66729 .42248 Mdot
.6389 .43163 Mdot
.45763 .58127 Mdot
.29548 .4216 Mdot
.48793 .34501 Mdot
.45915 .34243 Mdot
.22737 .72703 Mdot
.42815 .28321 Mdot
.29587 .54248 Mdot
.41124 .5944 Mdot
.44604 .28907 Mdot
.80367 .51617 Mdot
.64174 .42752 Mdot
.38125 .59448 Mdot
.45313 .29833 Mdot
.64076 .24055 Mdot
.26138 .48214 Mdot
.44957 .60827 Mdot
.51173 .6153 Mdot
.64258 .436 Mdot
.24625 .59754 Mdot
.43912 .3556 Mdot
.38164 .61176 Mdot
.64387 .37277 Mdot
.27755 .31114 Mdot
.75666 .33554 Mdot
.63809 .63352 Mdot
.50183 .4035 Mdot
.65235 .39387 Mdot
.40912 .65324 Mdot
.27982 .44357 Mdot
.48812 .40194 Mdot
.45806 .36962 Mdot
.47202 .58893 Mdot
.49666 .5737 Mdot
.3422 .64146 Mdot
.66364 .60787 Mdot
.67606 .40976 Mdot
.40504 .5704 Mdot
.65318 .49133 Mdot
.39185 .56937 Mdot
.66734 .43144 Mdot
.85874 .64881 Mdot
.42892 .64859 Mdot
.42678 .58834 Mdot
.34661 .73878 Mdot
.65037 .63189 Mdot
.64846 .63866 Mdot
.55876 .18878 Mdot
.41159 .59501 Mdot
.40733 .27118 Mdot
.63636 .63512 Mdot
.6385 .59773 Mdot
.54104 .32591 Mdot
.45303 .56532 Mdot
.23596 .61299 Mdot
.62116 .41715 Mdot
.63838 .443 Mdot
.63114 .59067 Mdot
.3813 .63864 Mdot
.61829 .42524 Mdot
.58152 .69971 Mdot
.45943 .32271 Mdot
.37683 .21786 Mdot
.65439 .60511 Mdot
.51737 .42157 Mdot
.65159 .42716 Mdot
.66176 .79216 Mdot
.41464 .31007 Mdot
.42041 .556 Mdot
.41255 .60219 Mdot
.28089 .43152 Mdot
.45034 .64096 Mdot
.44071 .29336 Mdot
.65693 .40041 Mdot
.39068 .76976 Mdot
.63662 .63055 Mdot
.42392 .57798 Mdot
.62217 .52675 Mdot
.76132 .52018 Mdot
.63709 .28959 Mdot
.62514 .60145 Mdot
.62212 .62096 Mdot
.44259 .36204 Mdot
.47738 .38918 Mdot
.44688 .59549 Mdot
.62499 .40445 Mdot
.64285 .57926 Mdot
.6651 .43144 Mdot
.44483 .3546 Mdot
.47799 .34935 Mdot
.43769 .31394 Mdot
.37339 .59958 Mdot
.48468 .35893 Mdot
.27983 .3359 Mdot
.67049 .49162 Mdot
.59386 .58181 Mdot
.76721 .31167 Mdot
.76529 .49191 Mdot
.39843 .49124 Mdot
.27177 .44994 Mdot
.45081 .30201 Mdot
.65659 .37987 Mdot
.46159 .59752 Mdot
.42767 .60673 Mdot
.49676 .40987 Mdot
.62805 .38715 Mdot
.31225 .44927 Mdot
.62317 .38953 Mdot
.28483 .45069 Mdot
.41831 .28017 Mdot
.47365 .56085 Mdot
.42104 .62747 Mdot
.65854 .39806 Mdot
.48326 .35166 Mdot
.46263 .35683 Mdot
.31356 .47006 Mdot
.39338 .47091 Mdot
.44756 .34819 Mdot
.65354 .60524 Mdot
.5688 .7363 Mdot
.45152 .38594 Mdot
.41563 .58386 Mdot
.224 .48239 Mdot
.56938 .67006 Mdot
.39774 .62754 Mdot
.55988 .38537 Mdot
.17056 .48367 Mdot
.39574 .58017 Mdot
.16942 .45131 Mdot
.58582 .36574 Mdot
.654 .62923 Mdot
.46743 .3877 Mdot
.43661 .29129 Mdot
.5268 .60718 Mdot
.31272 .41086 Mdot
.4822 .62087 Mdot
.64165 .63693 Mdot
.66353 .63971 Mdot
.66276 .24565 Mdot
.37719 .79099 Mdot
.29711 .46765 Mdot
.30098 .45979 Mdot
.4633 .3367 Mdot
.24137 .68695 Mdot
.35803 .57176 Mdot
.31238 .45503 Mdot
.31632 .67667 Mdot
.46619 .60446 Mdot
.26857 .53905 Mdot
.40792 .32076 Mdot
.62258 .59238 Mdot
.37046 .68014 Mdot
.46651 .34349 Mdot
.66298 .61475 Mdot
.69751 .45968 Mdot
.48217 .60795 Mdot
.64163 .63068 Mdot
.66058 .43638 Mdot
.57941 .23466 Mdot
.61229 .62895 Mdot
.22218 .47403 Mdot
.62822 .40273 Mdot
.52818 .27999 Mdot
.30452 .64611 Mdot
.57675 .12649 Mdot
.65067 .39588 Mdot
.47105 .3228 Mdot
.45044 .32036 Mdot
.45863 .34016 Mdot
.66202 .62113 Mdot
.4923 .34913 Mdot
.66264 .60292 Mdot
.27098 .68154 Mdot
.39271 .47176 Mdot
.31055 .45931 Mdot
.57695 .40551 Mdot
.61847 .61327 Mdot
.46364 .19531 Mdot
.67336 .19824 Mdot
.42259 .6168 Mdot
.67605 .39545 Mdot
.30424 .4656 Mdot
.4363 .85092 Mdot
.28847 .4289 Mdot
.50329 .4077 Mdot
.34161 .23206 Mdot
.43103 .57824 Mdot
.56715 .78186 Mdot
.27513 .45137 Mdot
.61349 .6001 Mdot
.45521 .58129 Mdot
.66775 .34244 Mdot
.28489 .43509 Mdot
.27738 .42358 Mdot
.45157 .59401 Mdot
.60098 .61027 Mdot
.47511 .35039 Mdot
.64098 .37571 Mdot
.33412 .45628 Mdot
.53833 .56964 Mdot
.44323 .64061 Mdot
.46992 .62049 Mdot
.59348 .47829 Mdot
.32089 .58237 Mdot
.65535 .40081 Mdot
.28249 .66729 Mdot
.47694 .38831 Mdot
.50512 .28554 Mdot
.57093 .19427 Mdot
.56927 .39322 Mdot
.44471 .31092 Mdot
.44586 .30345 Mdot
.45042 .60365 Mdot
.31889 .58724 Mdot
.29639 .27586 Mdot
.60064 .43906 Mdot
.4441 .37648 Mdot
.46032 .34635 Mdot
.67788 .6232 Mdot
.66618 .24355 Mdot
.49787 .60715 Mdot
.63891 .44955 Mdot
.44872 .35673 Mdot
.62138 .77475 Mdot
.29148 .4398 Mdot
.42633 .20562 Mdot
.46213 .5559 Mdot
.40913 .56535 Mdot
.65438 .41119 Mdot
.6567 .44155 Mdot
.69368 .36194 Mdot
.63751 .2207 Mdot
.20036 .56551 Mdot
.7877 .47551 Mdot
.62316 .76897 Mdot
.68321 .6048 Mdot
.61013 .58368 Mdot
.61622 .35088 Mdot
.67839 .42312 Mdot
.39688 .58425 Mdot
.64035 .57888 Mdot
.61463 .27753 Mdot
.64932 .65725 Mdot
.28163 .54538 Mdot
.34572 .29355 Mdot
.48798 .58834 Mdot
.63001 .58376 Mdot
.65558 .62398 Mdot
.63639 .574 Mdot
.58617 .3663 Mdot
.43802 .59109 Mdot
.44118 .55608 Mdot
.39437 .57275 Mdot
.51659 .55554 Mdot
.40898 .61085 Mdot
.59293 .43136 Mdot
.56474 .47551 Mdot
.44908 .80311 Mdot
.39435 .62959 Mdot
.62588 .43554 Mdot
.46757 .626 Mdot
.29433 .42095 Mdot
.46571 .59619 Mdot
.2847 .54054 Mdot
.64309 .42149 Mdot
.56628 .57494 Mdot
.78452 .46746 Mdot
.46301 .55796 Mdot
.27916 .41883 Mdot
.4035 .501 Mdot
.75386 .61909 Mdot
.34486 .48575 Mdot
.653 .60413 Mdot
.45489 .31452 Mdot
.64232 .38062 Mdot
.4741 .34211 Mdot
.38135 .61887 Mdot
.5572 .38794 Mdot
.71117 .5461 Mdot
.50934 .42255 Mdot
.39095 .60094 Mdot
.34529 .60286 Mdot
.64674 .60027 Mdot
.47852 .33099 Mdot
.68687 .59309 Mdot
.40145 .59163 Mdot
.30248 .44542 Mdot
.28318 .43801 Mdot
.72515 .38925 Mdot
.66152 .75871 Mdot
.76734 .42002 Mdot
.65578 .4091 Mdot
.46741 .37029 Mdot
.28465 .46678 Mdot
.51709 .53682 Mdot
.66859 .4459 Mdot
.62637 .39581 Mdot
.63148 .40642 Mdot
.45633 .62478 Mdot
.44473 .29722 Mdot
.44097 .7947 Mdot
.44189 .2932 Mdot
.46829 .56375 Mdot
.46572 .37795 Mdot
.44139 .30675 Mdot
.27804 .43574 Mdot
.66109 .38873 Mdot
.44707 .36203 Mdot
.42832 .62472 Mdot
.61922 .62856 Mdot
.43066 .45629 Mdot
.27105 .49813 Mdot
.42598 .8192 Mdot
.4486 .8259 Mdot
.59542 .61055 Mdot
.64056 .79329 Mdot
.62522 .44776 Mdot
.54247 .65751 Mdot
.58256 .34042 Mdot
.40901 .62805 Mdot
.49088 .17626 Mdot
.44594 .37192 Mdot
.47807 .32876 Mdot
.44586 .61648 Mdot
.48659 .32524 Mdot
.42476 .58092 Mdot
.46062 .37879 Mdot
.29824 .48632 Mdot
.50526 .57208 Mdot
.48695 .35086 Mdot
.36956 .58163 Mdot
.46037 .56715 Mdot
.62246 .591 Mdot
.47812 .39432 Mdot
.37888 .58869 Mdot
.34379 .809 Mdot
.66596 .43557 Mdot
.56679 .37981 Mdot
.2067 .45861 Mdot
.65343 .3933 Mdot
.6376 .62715 Mdot
.45613 .64379 Mdot
.29478 .42564 Mdot
.61154 .6093 Mdot
.23706 .45024 Mdot
.27922 .4545 Mdot
.4835 .18434 Mdot
.65042 .59882 Mdot
.45497 .38927 Mdot
.2752 .43498 Mdot
.39141 .54035 Mdot
.49215 .39773 Mdot
.42723 .47175 Mdot
.4492 .30603 Mdot
.43064 .59757 Mdot
.65365 .33236 Mdot
.67218 .43019 Mdot
.43253 .5613 Mdot
.49602 .38466 Mdot
.60851 .35228 Mdot
.46234 .61899 Mdot
.45866 .60234 Mdot
.72065 .2945 Mdot
.42026 .22798 Mdot
.3137 .43491 Mdot
.66689 .62743 Mdot
.42962 .62132 Mdot
.2721 .43528 Mdot
.3283 .3697 Mdot
.45931 .62964 Mdot
.67146 .59064 Mdot
.38832 .52602 Mdot
.49001 .3889 Mdot
.66652 .39737 Mdot
.52647 .40104 Mdot
.27155 .42876 Mdot
.23674 .2733 Mdot
.43632 .3153 Mdot
.375 .57464 Mdot
.38469 .59295 Mdot
.648 .3038 Mdot
.66005 .61788 Mdot
.20371 .56571 Mdot
.41522 .60096 Mdot
.4299 .51086 Mdot
.42391 .56843 Mdot
.48487 .304 Mdot
.63506 .59791 Mdot
.42665 .59238 Mdot
.59107 .53326 Mdot
.38588 .54905 Mdot
.27446 .4229 Mdot
.32422 .72306 Mdot
.44681 .63638 Mdot
.89306 .48083 Mdot
.40275 .2839 Mdot
.48692 .35338 Mdot
.66681 .33128 Mdot
.16686 .59769 Mdot
.76409 .40287 Mdot
.66351 .60221 Mdot
.73351 .60533 Mdot
.47483 .34659 Mdot
.78821 .43762 Mdot
.62471 .81059 Mdot
.46307 .569 Mdot
.48195 .60389 Mdot
.50333 .4077 Mdot
.44296 .28854 Mdot
.47004 .40153 Mdot
.38998 .62932 Mdot
.36339 .5603 Mdot
.48358 .36663 Mdot
.41982 .62267 Mdot
.43081 .52081 Mdot
.64679 .37576 Mdot
.5992 .61516 Mdot
.65929 .42747 Mdot
.64987 .38378 Mdot
.50907 .70141 Mdot
.6379 .22577 Mdot
.66908 .43007 Mdot
.62602 .4474 Mdot
.27203 .53362 Mdot
.34268 .64901 Mdot
.26468 .44099 Mdot
.57169 .82621 Mdot
.45622 .33687 Mdot
.43888 .58867 Mdot
.59174 .6068 Mdot
.51155 .68352 Mdot
.39169 .33855 Mdot
.31069 .25715 Mdot
.39866 .58898 Mdot
.46478 .34634 Mdot
.58966 .36231 Mdot
.47673 .53333 Mdot
.51676 .29978 Mdot
.40989 .56222 Mdot
.49505 .4028 Mdot
.54883 .76479 Mdot
.62096 .53428 Mdot
.47918 .25241 Mdot
.69139 .62014 Mdot
.40722 .5743 Mdot
.65668 .60857 Mdot
.66024 .42226 Mdot
.28516 .42351 Mdot
.31284 .43508 Mdot
.45527 .59085 Mdot
.34651 .54584 Mdot
.41127 .33034 Mdot
.46023 .56487 Mdot
.46819 .58621 Mdot
.58604 .36543 Mdot
.46688 .58416 Mdot
.38537 .5901 Mdot
.38741 .58078 Mdot
.40472 .5448 Mdot
.64573 .44693 Mdot
.61722 .52865 Mdot
.37413 .61268 Mdot
.46093 .52551 Mdot
.62669 .37729 Mdot
.7464 .59644 Mdot
.65997 .38536 Mdot
.70927 .73172 Mdot
.64683 .43215 Mdot
.31607 .44588 Mdot
.64083 .32752 Mdot
.33931 .56721 Mdot
.61064 .57702 Mdot
.67729 .43484 Mdot
.29596 .45291 Mdot
.66128 .40815 Mdot
.47205 .38124 Mdot
.82582 .43368 Mdot
.64154 .65666 Mdot
.19974 .5357 Mdot
.72301 .38196 Mdot
.49364 .23944 Mdot
.43884 .34437 Mdot
.63263 .59424 Mdot
.62159 .73463 Mdot
.38569 .57789 Mdot
.2737 .43899 Mdot
.45013 .59759 Mdot
.64967 .44804 Mdot
.46308 .34173 Mdot
.31127 .72038 Mdot
.30461 .4274 Mdot
.73051 .28901 Mdot
.45535 .34469 Mdot
.40291 .5588 Mdot
.63852 .44914 Mdot
.75846 .29458 Mdot
.66387 .42553 Mdot
.36235 .48521 Mdot
.65884 .57324 Mdot
.37324 .70982 Mdot
.62482 .61657 Mdot
.42736 .33568 Mdot
.85754 .4966 Mdot
.52346 .83915 Mdot
.60743 .61891 Mdot
.44614 .25662 Mdot
.47846 .60697 Mdot
.46914 .62222 Mdot
.60421 .54601 Mdot
.67189 .60896 Mdot
.41868 .61644 Mdot
.57208 .37373 Mdot
.69231 .49048 Mdot
.40409 .25842 Mdot
.45757 .31418 Mdot
.42097 .586 Mdot
.63224 .37455 Mdot
.62253 .3911 Mdot
.44142 .29597 Mdot
.66373 .3866 Mdot
.43995 .55649 Mdot
.62093 .61427 Mdot
.48295 .41489 Mdot
.30493 .43501 Mdot
.33678 .78501 Mdot
.27703 .46318 Mdot
.44416 .31374 Mdot
.45205 .53967 Mdot
.47846 .3496 Mdot
.12106 .477 Mdot
.42697 .55615 Mdot
.64218 .63384 Mdot
.45783 .61402 Mdot
.41114 .57119 Mdot
.479 .61088 Mdot
.48117 .37323 Mdot
.18133 .50808 Mdot
.42274 .624 Mdot
.63999 .40593 Mdot
.48192 .82061 Mdot
.47122 .62312 Mdot
.32627 .4864 Mdot
.29231 .59415 Mdot
.49602 .22884 Mdot
.5968 .58423 Mdot
.48165 .33634 Mdot
.62875 .62918 Mdot
.66642 .64963 Mdot
.63808 .62713 Mdot
.495 .8089 Mdot
.60484 .74356 Mdot
.18529 .45505 Mdot
.39246 .7387 Mdot
.48728 .68054 Mdot
.67145 .61878 Mdot
.31289 .38272 Mdot
.62003 .57778 Mdot
.65894 .61533 Mdot
.61553 .88838 Mdot
.60676 .58269 Mdot
.41513 .59039 Mdot
.49573 .59504 Mdot
.74022 .52052 Mdot
.24946 .53572 Mdot
.46176 .58423 Mdot
.43735 .62121 Mdot
.28147 .42658 Mdot
.36165 .52686 Mdot
.55752 .38793 Mdot
.49358 .18873 Mdot
.77749 .52223 Mdot
.45169 .59665 Mdot
.43064 .62284 Mdot
.36761 .55826 Mdot
.83726 .37035 Mdot
.53799 .68822 Mdot
.67387 .61867 Mdot
.37529 .63948 Mdot
.41408 .82495 Mdot
.43862 .55215 Mdot
.4461 .63309 Mdot
.48561 .59245 Mdot
.47404 .3461 Mdot
.67797 .5965 Mdot
.37001 .63373 Mdot
.49804 .21109 Mdot
.47231 .5626 Mdot
.57282 .39668 Mdot
.18318 .58303 Mdot
.42039 .59234 Mdot
.62571 .56966 Mdot
.47416 .60039 Mdot
.65066 .59635 Mdot
.61437 .59123 Mdot
.41818 .53555 Mdot
.57066 .79933 Mdot
.66364 .57941 Mdot
.47161 .56535 Mdot
.47841 .35908 Mdot
.55405 .84187 Mdot
.42866 .59893 Mdot
.31975 .43723 Mdot
.41298 .60073 Mdot
.29194 .41625 Mdot
.47018 .57953 Mdot
.44348 .29382 Mdot
.6162 .67876 Mdot
.46361 .3337 Mdot
.2128 .60935 Mdot
.45216 .29114 Mdot
.71852 .29108 Mdot
.6723 .59958 Mdot
.61854 .34755 Mdot
.27512 .26433 Mdot
.56308 .38205 Mdot
.58909 .50735 Mdot
.54436 .4974 Mdot
.62502 .40322 Mdot
.63804 .64037 Mdot
.27078 .63543 Mdot
.62939 .28842 Mdot
.62881 .31459 Mdot
.43929 .3237 Mdot
.29107 .23421 Mdot
.35342 .21601 Mdot
.43607 .62831 Mdot
.53958 .79633 Mdot
.45684 .74955 Mdot
.45544 .63134 Mdot
.44398 .64911 Mdot
.50068 .38678 Mdot
.38531 .59648 Mdot
.62675 .50534 Mdot
.44528 .33092 Mdot
.29228 .45355 Mdot
.65531 .61575 Mdot
.31274 .42285 Mdot
.63122 .29738 Mdot
.54711 .50202 Mdot
.45491 .37098 Mdot
.38903 .55016 Mdot
.45156 .61873 Mdot
.63123 .58809 Mdot
.65624 .55942 Mdot
.60114 .60104 Mdot
.3066 .46647 Mdot
.44733 .33276 Mdot
.54163 .67873 Mdot
.43618 .61616 Mdot
.62199 .60804 Mdot
.71292 .41788 Mdot
.42997 .61875 Mdot
.66395 .40387 Mdot
.48977 .58157 Mdot
.61019 .62379 Mdot
.46689 .58375 Mdot
.62015 .61572 Mdot
.45951 .32134 Mdot
.43875 .55063 Mdot
.44712 .61322 Mdot
.75693 .29906 Mdot
.31249 .44714 Mdot
.6717 .60455 Mdot
.4701 .43273 Mdot
.39021 .56869 Mdot
.56116 .27319 Mdot
.40442 .57888 Mdot
.68598 .65415 Mdot
.37402 .57114 Mdot
.59499 .35997 Mdot
.50428 .59916 Mdot
.42856 .5979 Mdot
.5562 .52303 Mdot
.46378 .76964 Mdot
.67409 .57006 Mdot
.63202 .44546 Mdot
.6375 .57117 Mdot
.36664 .30507 Mdot
.44785 .37885 Mdot
.49456 .35608 Mdot
.22661 .54754 Mdot
.43999 .53998 Mdot
.43212 .57962 Mdot
.6718 .38129 Mdot
.29246 .45773 Mdot
.62321 .60226 Mdot
.28701 .45166 Mdot
.53784 .19571 Mdot
.29422 .46435 Mdot
.438 .29202 Mdot
.42249 .26908 Mdot
.58065 .68409 Mdot
.28077 .42735 Mdot
.59914 .60663 Mdot
.33657 .29957 Mdot
.39739 .62202 Mdot
.2667 .40552 Mdot
.30164 .44407 Mdot
.28956 .22806 Mdot
.38819 .59603 Mdot
.595 .50371 Mdot
.6722 .41783 Mdot
.27856 .44131 Mdot
.63022 .41556 Mdot
.46021 .58764 Mdot
.53809 .24958 Mdot
.66655 .60252 Mdot
.61173 .39321 Mdot
.41308 .64644 Mdot
.30499 .46411 Mdot
.45093 .35917 Mdot
.61691 .36688 Mdot
.62347 .43143 Mdot
.742 .64531 Mdot
.30967 .70876 Mdot
.44759 .33129 Mdot
.34979 .25587 Mdot
.62554 .42254 Mdot
.44717 .6343 Mdot
.40836 .5138 Mdot
.42179 .55526 Mdot
.66415 .3373 Mdot
.4819 .33558 Mdot
.69968 .51027 Mdot
.45408 .6188 Mdot
.39279 .5856 Mdot
.59505 .57165 Mdot
.45442 .3239 Mdot
.64137 .61198 Mdot
.62863 .57221 Mdot
.45811 .32034 Mdot
.63209 .61992 Mdot
.27417 .44837 Mdot
.70716 .47965 Mdot
.62675 .42655 Mdot
.64116 .40949 Mdot
.4602 .34508 Mdot
.48655 .35958 Mdot
.47967 .34688 Mdot
.48954 .58074 Mdot
.62866 .59951 Mdot
.48166 .5835 Mdot
.47979 .60864 Mdot
.68615 .57635 Mdot
.59319 .59524 Mdot
.4793 .59924 Mdot
.49377 .25927 Mdot
.25979 .41382 Mdot
.47888 .36438 Mdot
.67143 .42446 Mdot
.80621 .49095 Mdot
.6161 .37755 Mdot
.41997 .58352 Mdot
.63525 .24041 Mdot
.60425 .61281 Mdot
.28397 .43014 Mdot
.26797 .41662 Mdot
.29653 .4276 Mdot
.68373 .3893 Mdot
.65621 .58475 Mdot
.49188 .18896 Mdot
.42377 .58372 Mdot
.59417 .47794 Mdot
.27756 .64967 Mdot
.54449 .20528 Mdot
.67081 .42763 Mdot
.43163 .62067 Mdot
.52378 .40812 Mdot
.62808 .71814 Mdot
.41174 .56324 Mdot
.37867 .60086 Mdot
.55836 .34314 Mdot
.405 .52324 Mdot
.66166 .57605 Mdot
.63332 .21368 Mdot
.4898 .60424 Mdot
.63611 .54484 Mdot
.24035 .72173 Mdot
.41634 .57814 Mdot
.39999 .59661 Mdot
.43598 .60542 Mdot
.46445 .60638 Mdot
.62869 .56843 Mdot
.25317 .58865 Mdot
.64513 .45072 Mdot
.56812 .45599 Mdot
.62535 .42697 Mdot
.49371 .40312 Mdot
.62429 .51865 Mdot
.62566 .63921 Mdot
.28143 .43073 Mdot
.70653 .6799 Mdot
.57286 .18427 Mdot
.44227 .36235 Mdot
.57551 .71125 Mdot
.30698 .4414 Mdot
.4343 .63901 Mdot
.30869 .41808 Mdot
.44896 .29354 Mdot
.63442 .40164 Mdot
.50252 .57454 Mdot
.605 .59001 Mdot
.61607 .63114 Mdot
.42114 .61648 Mdot
.44885 .84403 Mdot
.66481 .40137 Mdot
.60655 .43413 Mdot
.46596 .61779 Mdot
.37841 .60304 Mdot
.64412 .61467 Mdot
.46963 .36184 Mdot
.25466 .35186 Mdot
.30526 .4549 Mdot
.4025 .55411 Mdot
.46601 .60269 Mdot
.63144 .21805 Mdot
.65121 .38806 Mdot
.43126 .33148 Mdot
.45436 .62525 Mdot
.72519 .35786 Mdot
.45594 .62385 Mdot
.48929 .53981 Mdot
.47631 .35571 Mdot
.36092 .59485 Mdot
.42194 .62658 Mdot
.4229 .661 Mdot
.62666 .4193 Mdot
.64486 .6307 Mdot
.60568 .56835 Mdot
.50644 .41218 Mdot
.66401 .40632 Mdot
.47702 .60049 Mdot
.65463 .39006 Mdot
.46168 .63011 Mdot
.41498 .61759 Mdot
.66766 .43097 Mdot
.641 .6125 Mdot
.73139 .57173 Mdot
.61844 .52564 Mdot
.46285 .61014 Mdot
.49908 .59973 Mdot
.23823 .54749 Mdot
.19619 .37871 Mdot
.4009 .58675 Mdot
.61305 .6273 Mdot
.43976 .61697 Mdot
.63563 .42111 Mdot
.28906 .46112 Mdot
.6159 .62712 Mdot
.46294 .36109 Mdot
.43807 .35044 Mdot
.78369 .46319 Mdot
.44485 .30175 Mdot
.41036 .63195 Mdot
.61405 .65555 Mdot
.59122 .62101 Mdot
.27842 .75079 Mdot
.45565 .31896 Mdot
.26592 .43042 Mdot
.45895 .59802 Mdot
.67453 .27518 Mdot
.67777 .38666 Mdot
.89693 .4638 Mdot
.48576 .18631 Mdot
.28079 .46679 Mdot
.29722 .26011 Mdot
.48824 .40841 Mdot
.40425 .61584 Mdot
.28715 .42261 Mdot
.45154 .37547 Mdot
.41949 .63217 Mdot
.51563 .61024 Mdot
.19528 .54686 Mdot
.51146 .39971 Mdot
.66048 .39166 Mdot
.49035 .37835 Mdot
.31884 .4205 Mdot
.43877 .2922 Mdot
.61233 .63055 Mdot
.42998 .59419 Mdot
.34945 .61959 Mdot
.46733 .36368 Mdot
.44064 .29121 Mdot
.48803 .58431 Mdot
.64328 .63887 Mdot
.49094 .33419 Mdot
.45213 .58923 Mdot
.52704 .66158 Mdot
.69062 .61895 Mdot
.44758 .33967 Mdot
.38971 .58336 Mdot
.33459 .6273 Mdot
.45974 .35121 Mdot
.47874 .36686 Mdot
.4197 .61727 Mdot
.27251 .44525 Mdot
.46525 .55595 Mdot
.65104 .43328 Mdot
.17694 .52788 Mdot
.63551 .41835 Mdot
.35802 .32139 Mdot
.4265 .52963 Mdot
.52651 .25738 Mdot
.60343 .62592 Mdot
.31312 .41565 Mdot
.81278 .4863 Mdot
.38245 .61708 Mdot
.6355 .78967 Mdot
.53081 .42097 Mdot
.40273 .82915 Mdot
.82516 .56462 Mdot
.2977 .44337 Mdot
.66157 .41381 Mdot
.4008 .59699 Mdot
.6742 .38954 Mdot
.30374 .42467 Mdot
.28316 .67801 Mdot
.38774 .58491 Mdot
.6377 .59828 Mdot
.47837 .56855 Mdot
.65335 .60385 Mdot
.42717 .61724 Mdot
.41916 .522 Mdot
.60964 .34509 Mdot
.26557 .48533 Mdot
.40547 .62636 Mdot
.82434 .42478 Mdot
.40088 .34861 Mdot
.30353 .44944 Mdot
.47809 .57462 Mdot
.43671 .36055 Mdot
.62257 .39356 Mdot
.47913 .50386 Mdot
.47602 .3487 Mdot
.6752 .39975 Mdot
.64131 .62114 Mdot
.45871 .31769 Mdot
.43436 .33062 Mdot
.38962 .6455 Mdot
.29021 .41734 Mdot
.63236 .39744 Mdot
.42484 .59637 Mdot
.38894 .5933 Mdot
.35312 .26341 Mdot
.38171 .34973 Mdot
.60801 .56331 Mdot
.72214 .25542 Mdot
.58714 .58852 Mdot
.31131 .45443 Mdot
.47789 .35383 Mdot
.40329 .58494 Mdot
.43663 .56141 Mdot
.62598 .34269 Mdot
.66981 .6096 Mdot
.51389 .40299 Mdot
.53333 .70365 Mdot
.47193 .31492 Mdot
.27298 .57767 Mdot
.63906 .63604 Mdot
.271 .57548 Mdot
.31786 .42022 Mdot
.64301 .76844 Mdot
.29877 .50981 Mdot
.67293 .41441 Mdot
.2735 .58264 Mdot
.61152 .60152 Mdot
.44172 .62609 Mdot
.45833 .39161 Mdot
.44073 .3099 Mdot
.65024 .61659 Mdot
.4966 .40617 Mdot
.27974 .43958 Mdot
.39926 .60012 Mdot
.45884 .21173 Mdot
.75391 .48 Mdot
.47089 .3714 Mdot
.50514 .55399 Mdot
.63243 .40952 Mdot
.40497 .61394 Mdot
.32113 .44058 Mdot
.6444 .39649 Mdot
.39452 .29057 Mdot
.69535 .49753 Mdot
.45701 .58828 Mdot
.68412 .26885 Mdot
.6591 .39957 Mdot
.26483 .30006 Mdot
.44732 .59066 Mdot
.62552 .42216 Mdot
.36798 .54333 Mdot
.53963 .21458 Mdot
.49637 .4334 Mdot
.61646 .81836 Mdot
.5189 .39863 Mdot
.47944 .40162 Mdot
.57902 .24251 Mdot
.60667 .30801 Mdot
.66794 .38374 Mdot
.43955 .29246 Mdot
.31676 .56557 Mdot
.62912 .41461 Mdot
.4824 .60406 Mdot
.40904 .57856 Mdot
.50873 .69656 Mdot
.53587 .4343 Mdot
.43568 .28884 Mdot
.75288 .41072 Mdot
.39106 .5687 Mdot
.41204 .65032 Mdot
.4398 .56576 Mdot
.66756 .63592 Mdot
.64006 .39194 Mdot
.7812 .34318 Mdot
.66557 .41121 Mdot
.41528 .21428 Mdot
.45716 .337 Mdot
.48957 .3477 Mdot
.41938 .58932 Mdot
.49555 .24701 Mdot
.31162 .64136 Mdot
.44575 .55733 Mdot
.5249 .2768 Mdot
.32204 .72856 Mdot
.4156 .64827 Mdot
.65728 .57159 Mdot
.49817 .56227 Mdot
.65583 .64741 Mdot
.62093 .42131 Mdot
.29325 .43749 Mdot
.324 .41943 Mdot
.63381 .39766 Mdot
.43358 .57861 Mdot
.53544 .28444 Mdot
.4171 .56635 Mdot
.44397 .6285 Mdot
.41713 .20436 Mdot
.2858 .46805 Mdot
.47864 .33912 Mdot
.31032 .4316 Mdot
.65998 .61455 Mdot
.84493 .68313 Mdot
.2893 .45675 Mdot
.32265 .65195 Mdot
.23566 .62875 Mdot
.27127 .58244 Mdot
.62072 .63406 Mdot
.32978 .45563 Mdot
.66659 .39945 Mdot
.465 .86743 Mdot
.18615 .39826 Mdot
.60253 .3957 Mdot
.44942 .58223 Mdot
.63146 .64231 Mdot
.59654 .60487 Mdot
.61077 .40211 Mdot
.61321 .5941 Mdot
.34725 .58847 Mdot
.45493 .62073 Mdot
.67121 .38806 Mdot
.74837 .50554 Mdot
.62276 .43084 Mdot
.70126 .46983 Mdot
.47986 .57373 Mdot
.63183 .63513 Mdot
.48741 .55494 Mdot
.59696 .64027 Mdot
.43068 .33001 Mdot
.44087 .63874 Mdot
.27885 .43674 Mdot
.57793 .45048 Mdot
.44988 .33678 Mdot
.63442 .24216 Mdot
.63428 .58905 Mdot
.70629 .39956 Mdot
.62027 .591 Mdot
.65017 .64269 Mdot
.64882 .3833 Mdot
.65533 .58874 Mdot
.39913 .59701 Mdot
.46965 .25839 Mdot
.64859 .59149 Mdot
.65024 .41728 Mdot
.29405 .43277 Mdot
.6344 .61742 Mdot
.50304 .3883 Mdot
.45466 .60742 Mdot
.46949 .38453 Mdot
.6136 .33805 Mdot
.64842 .63923 Mdot
.32589 .46165 Mdot
.48322 .33476 Mdot
.29092 .41871 Mdot
.31062 .73706 Mdot
.67818 .42506 Mdot
.31697 .25668 Mdot
.33742 .62782 Mdot
.60139 .5922 Mdot
.61098 .34141 Mdot
.40573 .58617 Mdot
.45646 .60618 Mdot
.32832 .43478 Mdot
.59639 .60426 Mdot
.51996 .84454 Mdot
.70503 .64525 Mdot
.70618 .48981 Mdot
.67752 .43082 Mdot
.74952 .3178 Mdot
.65699 .49328 Mdot
.23059 .66338 Mdot
.37346 .62573 Mdot
.48639 .40789 Mdot
.42634 .5747 Mdot
.81298 .5005 Mdot
.30556 .46515 Mdot
.25089 .37652 Mdot
.40336 .5379 Mdot
.47231 .33091 Mdot
.4439 .60254 Mdot
.48541 .48635 Mdot
.48757 .54722 Mdot
.27204 .44879 Mdot
.57768 .41348 Mdot
.61445 .57558 Mdot
.30634 .43698 Mdot
.43876 .33572 Mdot
.29888 .62283 Mdot
.41009 .62675 Mdot
.38213 .62256 Mdot
.46886 .31042 Mdot
.63308 .59561 Mdot
.48353 .39856 Mdot
.62638 .42588 Mdot
.28657 .44199 Mdot
.46163 .60006 Mdot
.37732 .56097 Mdot
.56301 .27516 Mdot
.63298 .39423 Mdot
.48012 .32466 Mdot
.66373 .4238 Mdot
.47471 .4029 Mdot
.50207 .58798 Mdot
.49042 .34849 Mdot
.39689 .61304 Mdot
.79159 .41188 Mdot
.41012 .20848 Mdot
.48312 .77654 Mdot
.4731 .32883 Mdot
.28863 .5685 Mdot
.64309 .42326 Mdot
.65039 .43125 Mdot
.3764 .70463 Mdot
.37124 .51369 Mdot
.37863 .27653 Mdot
.74878 .64254 Mdot
.62722 .42806 Mdot
.63781 .41546 Mdot
.46338 .38425 Mdot
.65728 .59208 Mdot
.63624 .64631 Mdot
.49257 .40673 Mdot
.22001 .48148 Mdot
.62321 .6024 Mdot
.61695 .79916 Mdot
.38074 .28975 Mdot
.40835 .65182 Mdot
.68101 .35422 Mdot
.28561 .43706 Mdot
.22849 .48164 Mdot
.49918 .49465 Mdot
.39471 .58768 Mdot
.64446 .22273 Mdot
.46842 .35645 Mdot
.23528 .57797 Mdot
.7123 .72765 Mdot
.38634 .5854 Mdot
.441 .58945 Mdot
.43522 .57238 Mdot
.3004 .47099 Mdot
.63447 .67056 Mdot
.39113 .5936 Mdot
.21655 .47767 Mdot
.39175 .56589 Mdot
.34417 .49524 Mdot
.31256 .43424 Mdot
.46002 .668 Mdot
.56754 .36798 Mdot
.50092 .2035 Mdot
.5137 .63171 Mdot
.63184 .42902 Mdot
.54258 .39475 Mdot
.62212 .41463 Mdot
.48678 .80457 Mdot
.29594 .51233 Mdot
.64797 .56497 Mdot
.39638 .59055 Mdot
.44368 .31618 Mdot
.59791 .60896 Mdot
.58657 .27092 Mdot
.67544 .85797 Mdot
.61746 .41226 Mdot
.13017 .47497 Mdot
.65722 .4299 Mdot
.43436 .32241 Mdot
.64513 .61579 Mdot
.59417 .74753 Mdot
.59717 .48106 Mdot
.63131 .61806 Mdot
.71876 .55455 Mdot
.5783 .61096 Mdot
.28259 .57877 Mdot
.58651 .61189 Mdot
.64875 .42019 Mdot
.65628 .36581 Mdot
.42621 .65605 Mdot
.41147 .59177 Mdot
.54176 .50042 Mdot
.32762 .64201 Mdot
.40807 .58956 Mdot
.44576 .33038 Mdot
.25738 .30088 Mdot
.50512 .4092 Mdot
.62655 .57946 Mdot
.62263 .43742 Mdot
.44153 .5924 Mdot
.46361 .61436 Mdot
.42014 .63006 Mdot
.73557 .26036 Mdot
.59996 .80435 Mdot
.42352 .62387 Mdot
.41421 .54781 Mdot
.46207 .32216 Mdot
.31476 .48124 Mdot
.81218 .53272 Mdot
.33769 .52216 Mdot
.40665 .5614 Mdot
.31273 .43969 Mdot
.26552 .44945 Mdot
.41808 .63222 Mdot
.48205 .22059 Mdot
.46061 .25467 Mdot
.42509 .59679 Mdot
.35595 .49733 Mdot
.62251 .29536 Mdot
.4392 .29436 Mdot
.46508 .36056 Mdot
.62492 .57022 Mdot
.44125 .31588 Mdot
.45203 .29045 Mdot
.60076 .73195 Mdot
.5374 .40199 Mdot
.62601 .47135 Mdot
.30691 .46646 Mdot
.43081 .56093 Mdot
.58183 .5943 Mdot
.64956 .337 Mdot
.62709 .4015 Mdot
.61464 .62039 Mdot
.61988 .39656 Mdot
.27758 .46768 Mdot
.20847 .55251 Mdot
.43977 .30937 Mdot
.63395 .43428 Mdot
.69488 .49645 Mdot
.31297 .43819 Mdot
.66748 .39233 Mdot
.53519 .26292 Mdot
.47746 .6153 Mdot
.62457 .75983 Mdot
.45757 .56017 Mdot
.45152 .8518 Mdot
.6666 .39237 Mdot
.59517 .36109 Mdot
.4308 .58455 Mdot
.45606 .34482 Mdot
.39796 .5293 Mdot
.41016 .56135 Mdot
.46076 .36339 Mdot
.43672 .62795 Mdot
.31637 .4297 Mdot
.67605 .6409 Mdot
.54818 .40951 Mdot
.46435 .14443 Mdot
.29816 .41813 Mdot
.57831 .26911 Mdot
.39992 .58745 Mdot
.31144 .7181 Mdot
.63312 .61628 Mdot
.38075 .59618 Mdot
.39493 .68723 Mdot
.65922 .59971 Mdot
.62458 .62648 Mdot
.47339 .58981 Mdot
.6715 .4145 Mdot
.4521 .34402 Mdot
.31054 .4339 Mdot
.27326 .72694 Mdot
.45152 .57339 Mdot
.444 .61513 Mdot
.3068 .43975 Mdot
.63618 .41672 Mdot
.46685 .61043 Mdot
.69288 .32176 Mdot
.35787 .81302 Mdot
.62954 .39219 Mdot
.49468 .58285 Mdot
.67844 .70809 Mdot
.5957 .64247 Mdot
.154 .43153 Mdot
.2441 .45274 Mdot
.48391 .34218 Mdot
.39707 .525 Mdot
.88696 .56078 Mdot
.29206 .43613 Mdot
.49575 .19586 Mdot
.44194 .63053 Mdot
.4353 .61255 Mdot
.60277 .60642 Mdot
.48193 .59022 Mdot
.66551 .61409 Mdot
.41449 .16169 Mdot
.66879 .228 Mdot
.64083 .59429 Mdot
.60639 .58554 Mdot
.35118 .67339 Mdot
.8127 .52642 Mdot
.64915 .62045 Mdot
.48883 .56709 Mdot
.52801 .82722 Mdot
.4415 .65997 Mdot
.32845 .43408 Mdot
.61112 .33046 Mdot
.55963 .58751 Mdot
.38794 .42663 Mdot
.73921 .61276 Mdot
.5633 .57959 Mdot
.41919 .31951 Mdot
.65255 .43489 Mdot
.39046 .57456 Mdot
.44276 .30453 Mdot
.49363 .35311 Mdot
.47442 .53853 Mdot
.42088 .5616 Mdot
.65315 .59926 Mdot
.28864 .46669 Mdot
.63771 .38104 Mdot
.43834 .62096 Mdot
.50744 .38928 Mdot
.29679 .45674 Mdot
.6314 .5819 Mdot
.36351 .69802 Mdot
.26681 .43797 Mdot
.50632 .5659 Mdot
.41717 .60445 Mdot
.48777 .5887 Mdot
.33856 .60722 Mdot
.65821 .44206 Mdot
.65921 .3231 Mdot
.48335 .56748 Mdot
.54302 .19486 Mdot
.39311 .46825 Mdot
.36116 .58455 Mdot
.61909 .59792 Mdot
.68219 .39161 Mdot
.43066 .34227 Mdot
.29377 .64949 Mdot
.4556 .58112 Mdot
.59298 .80533 Mdot
.53374 .69353 Mdot
.43489 .3522 Mdot
.67181 .61626 Mdot
.28636 .42899 Mdot
.43984 .55699 Mdot
.50775 .81749 Mdot
.41265 .57953 Mdot
.33407 .61272 Mdot
.47642 .36193 Mdot
.65427 .43557 Mdot
.39155 .82678 Mdot
.49345 .35318 Mdot
.62746 .62855 Mdot
.63011 .81701 Mdot
.60896 .63421 Mdot
.63049 .57456 Mdot
.55567 .80684 Mdot
.6522 .44286 Mdot
.89126 .54243 Mdot
.1782 .4039 Mdot
.37516 .55456 Mdot
.64141 .42578 Mdot
.64957 .60836 Mdot
.40418 .61297 Mdot
.58981 .60958 Mdot
.6649 .59305 Mdot
.46239 .63516 Mdot
.42476 .61014 Mdot
.61521 .52208 Mdot
.66833 .7643 Mdot
.29224 .42663 Mdot
.65068 .6319 Mdot
.46615 .69021 Mdot
.39216 .6032 Mdot
.42394 .58438 Mdot
.61103 .28077 Mdot
.27095 .44364 Mdot
.55948 .53085 Mdot
.45053 .62715 Mdot
.68645 .25181 Mdot
.50478 .56848 Mdot
.63428 .56751 Mdot
.6316 .39096 Mdot
.48285 .21366 Mdot
.66517 .33858 Mdot
.66921 .61249 Mdot
.32115 .45381 Mdot
.60894 .56601 Mdot
.32437 .65182 Mdot
.63396 .43973 Mdot
.61013 .62373 Mdot
.52597 .40188 Mdot
.64785 .40229 Mdot
.66808 .3945 Mdot
.48525 .82138 Mdot
.47147 .3192 Mdot
.32097 .46235 Mdot
.63167 .40355 Mdot
.54307 .65627 Mdot
.65583 .4177 Mdot
.47479 .69688 Mdot
.44686 .55216 Mdot
.20541 .51109 Mdot
.63767 .48981 Mdot
.33926 .57941 Mdot
.66773 .43708 Mdot
.30365 .42544 Mdot
.47057 .59701 Mdot
.6106 .59555 Mdot
.2867 .45366 Mdot
.64386 .35533 Mdot
.48288 .36429 Mdot
.6217 .58839 Mdot
.64857 .45154 Mdot
.64708 .63328 Mdot
.26193 .62456 Mdot
.18064 .54428 Mdot
.69305 .31223 Mdot
.59228 .48155 Mdot
.42345 .63094 Mdot
.76675 .59393 Mdot
.46273 .63727 Mdot
.41553 .56283 Mdot
.44805 .3397 Mdot
.22556 .5484 Mdot
.64185 .61234 Mdot
.39663 .8319 Mdot
.6401 .4359 Mdot
.64433 .21631 Mdot
.69746 .61269 Mdot
.37866 .59337 Mdot
.65221 .5945 Mdot
.59936 .62749 Mdot
.45629 .76874 Mdot
.4426 .28387 Mdot
.5077 .61638 Mdot
.48476 .62619 Mdot
.3717 .61817 Mdot
.66741 .39478 Mdot
.61961 .23726 Mdot
.48682 .40232 Mdot
.16098 .50771 Mdot
.47533 .3659 Mdot
.53062 .33074 Mdot
.64807 .58408 Mdot
.28256 .45441 Mdot
.42366 .5868 Mdot
.70056 .61804 Mdot
.66893 .61777 Mdot
.25366 .4326 Mdot
.27646 .43793 Mdot
.57679 .22856 Mdot
.6675 .43186 Mdot
.39878 .62122 Mdot
.38986 .58482 Mdot
.47916 .58057 Mdot
.46036 .5589 Mdot
.6171 .41231 Mdot
.4706 .61687 Mdot
.63723 .37299 Mdot
.53737 .66347 Mdot
.66087 .22839 Mdot
.53496 .40076 Mdot
.44769 .50105 Mdot
.61387 .58581 Mdot
.5471 .64829 Mdot
.51299 .57312 Mdot
.38449 .21614 Mdot
.37054 .77881 Mdot
.42586 .64648 Mdot
.46063 .38486 Mdot
.38408 .51104 Mdot
.45433 .29956 Mdot
.14708 .36844 Mdot
.56444 .28627 Mdot
.62539 .80647 Mdot
.39641 .6042 Mdot
.61471 .28259 Mdot
.48866 .53285 Mdot
.476 .62903 Mdot
.58986 .29389 Mdot
.74854 .3839 Mdot
.72838 .53114 Mdot
.26502 .44548 Mdot
.4542 .60101 Mdot
.58796 .62018 Mdot
.39766 .59717 Mdot
.42346 .57959 Mdot
.43984 .63202 Mdot
.63817 .45027 Mdot
.50181 .57519 Mdot
.4907 .58084 Mdot
.39276 .38681 Mdot
.27357 .54126 Mdot
.4903 .38228 Mdot
.3554 .70315 Mdot
.29101 .45627 Mdot
.64435 .59108 Mdot
.69427 .55613 Mdot
.67314 .41511 Mdot
.45205 .75819 Mdot
.48515 .57431 Mdot
.66259 .50227 Mdot
.65084 .45175 Mdot
.28424 .44233 Mdot
.45618 .39139 Mdot
.57448 .842 Mdot
.44565 .31322 Mdot
.52854 .40688 Mdot
.45174 .33525 Mdot
.52294 .63371 Mdot
.65445 .60088 Mdot
.43062 .63432 Mdot
.63323 .40607 Mdot
.45139 .35012 Mdot
.24063 .53551 Mdot
.43821 .56645 Mdot
.46028 .32304 Mdot
.43344 .63416 Mdot
.20018 .53248 Mdot
.31855 .279 Mdot
.44884 .28971 Mdot
.68905 .40073 Mdot
.64906 .40759 Mdot
.27616 .4506 Mdot
.63363 .58553 Mdot
.60483 .60709 Mdot
.64652 .39724 Mdot
.1996 .35789 Mdot
.40592 .56307 Mdot
.39951 .60928 Mdot
.54692 .19363 Mdot
.40523 .59616 Mdot
.29587 .60686 Mdot
.52042 .41023 Mdot
.62348 .58205 Mdot
.4124 .61902 Mdot
.46522 .60956 Mdot
.45803 .59324 Mdot
.25743 .62417 Mdot
.47066 .36587 Mdot
.40453 .55925 Mdot
.27495 .43028 Mdot
.42691 .33735 Mdot
.39876 .61004 Mdot
.37218 .61726 Mdot
.60573 .60933 Mdot
.64175 .20222 Mdot
.6622 .43019 Mdot
.43983 .34373 Mdot
.48656 .3413 Mdot
.61375 .3277 Mdot
.65767 .55284 Mdot
.51826 .41059 Mdot
.16801 .53507 Mdot
.58174 .36891 Mdot
.30812 .4459 Mdot
.54203 .37044 Mdot
.37321 .45908 Mdot
.44575 .36413 Mdot
.61662 .39776 Mdot
.46826 .55914 Mdot
.41365 .55557 Mdot
.47568 .18535 Mdot
.37732 .59182 Mdot
.28584 .43187 Mdot
.62725 .3755 Mdot
.6125 .60309 Mdot
.28237 .44011 Mdot
.6552 .42909 Mdot
.63032 .59521 Mdot
.47582 .61957 Mdot
.48496 .60592 Mdot
.61757 .62126 Mdot
.59853 .60713 Mdot
.4214 .59851 Mdot
.42418 .30482 Mdot
.62359 .57154 Mdot
.62336 .63271 Mdot
.44069 .3056 Mdot
.43989 .32189 Mdot
.36714 .62786 Mdot
.64746 .42704 Mdot
.48305 .59977 Mdot
.45203 .30841 Mdot
.28786 .46407 Mdot
.63565 .6118 Mdot
.46193 .61308 Mdot
.44241 .62301 Mdot
.31053 .43574 Mdot
.27493 .45857 Mdot
.28023 .44205 Mdot
.62408 .37481 Mdot
.46937 .57132 Mdot
.64476 .62272 Mdot
.66024 .43751 Mdot
.26516 .44895 Mdot
.28675 .41483 Mdot
.44139 .4326 Mdot
.40185 .58354 Mdot
.47898 .42885 Mdot
.84241 .68 Mdot
.30767 .58028 Mdot
.42992 .33683 Mdot
.46856 .31268 Mdot
.25762 .56209 Mdot
.45163 .26202 Mdot
.65938 .39656 Mdot
.31591 .583 Mdot
.31334 .4154 Mdot
.44565 .63646 Mdot
.4999 .59684 Mdot
.44902 .64835 Mdot
.29075 .44941 Mdot
.27513 .63047 Mdot
.59722 .61998 Mdot
.43548 .72408 Mdot
.29038 .45555 Mdot
.444 .28696 Mdot
.48773 .33386 Mdot
.47576 .36572 Mdot
.49906 .59158 Mdot
.47992 .77028 Mdot
.51573 .66022 Mdot
.76849 .60584 Mdot
.67652 .41303 Mdot
.65223 .56523 Mdot
.30842 .72869 Mdot
.62257 .62412 Mdot
.49271 .34433 Mdot
.29456 .45286 Mdot
.60687 .62254 Mdot
.62194 .4053 Mdot
.63726 .41345 Mdot
.47288 .36869 Mdot
.46052 .3437 Mdot
.46706 .38198 Mdot
.64552 .57795 Mdot
.65345 .5875 Mdot
.45523 .5743 Mdot
.62393 .61202 Mdot
.5547 .16901 Mdot
.29853 .47232 Mdot
.48757 .33136 Mdot
.66192 .41584 Mdot
.65188 .60143 Mdot
.43975 .56422 Mdot
.50953 .35772 Mdot
.77746 .4643 Mdot
.29937 .41982 Mdot
.33978 .26659 Mdot
.14368 .38558 Mdot
.38918 .61099 Mdot
.65851 .39007 Mdot
.44748 .21754 Mdot
.43793 .57197 Mdot
.47302 .3494 Mdot
.80353 .43483 Mdot
.44662 .37746 Mdot
.48124 .60502 Mdot
.37703 .59585 Mdot
.66122 .38485 Mdot
.23613 .63512 Mdot
.45369 .56947 Mdot
.70078 .45488 Mdot
.61791 .4301 Mdot
.49322 .39483 Mdot
.3663 .82162 Mdot
.64468 .3061 Mdot
.22707 .48442 Mdot
.43839 .31637 Mdot
.40998 .57248 Mdot
.44248 .33768 Mdot
.29719 .42041 Mdot
.44666 .35404 Mdot
.67267 .58426 Mdot
.48945 .38961 Mdot
.44344 .61429 Mdot
.64983 .62155 Mdot
.66025 .40015 Mdot
.62261 .20518 Mdot
.38469 .37654 Mdot
.45662 .34508 Mdot
.43647 .31148 Mdot
.41692 .62432 Mdot
.58368 .52934 Mdot
.40031 .53324 Mdot
.39399 .60323 Mdot
.62398 .42701 Mdot
.64878 .59053 Mdot
.66335 .4433 Mdot
.38327 .5646 Mdot
.74636 .34939 Mdot
.66654 .42195 Mdot
.6555 .50716 Mdot
.30747 .44219 Mdot
.4789 .46963 Mdot
.43505 .56012 Mdot
.62905 .40649 Mdot
.4701 .57107 Mdot
.58949 .60432 Mdot
.5234 .45471 Mdot
.67975 .33159 Mdot
.63488 .4062 Mdot
.49672 .84784 Mdot
.4566 .4239 Mdot
.48885 .55873 Mdot
.62396 .41996 Mdot
.40351 .68735 Mdot
.43417 .32672 Mdot
.30667 .45311 Mdot
.26545 .44877 Mdot
.2841 .41951 Mdot
.39584 .63249 Mdot
.5229 .60186 Mdot
.32468 .44991 Mdot
.62774 .39118 Mdot
.2728 .4512 Mdot
.7001 .58973 Mdot
.50918 .84819 Mdot
.30932 .46304 Mdot
.44939 .58973 Mdot
.43861 .6562 Mdot
.26907 .5396 Mdot
.48801 .32782 Mdot
.64115 .78726 Mdot
.47723 .51508 Mdot
.41199 .58913 Mdot
.5458 .5832 Mdot
.59851 .61915 Mdot
.43714 .22671 Mdot
.32686 .63589 Mdot
.42708 .25566 Mdot
.61034 .58043 Mdot
.62807 .3425 Mdot
.62877 .58305 Mdot
.39436 .6144 Mdot
.41174 .61513 Mdot
.63342 .6473 Mdot
.63938 .23621 Mdot
.54372 .24657 Mdot
.34218 .78699 Mdot
.62549 .63452 Mdot
.62659 .41861 Mdot
.61634 .41563 Mdot
.67576 .41549 Mdot
.37232 .29753 Mdot
.65323 .63397 Mdot
.46582 .57471 Mdot
.46267 .3215 Mdot
.39902 .56803 Mdot
.63971 .40098 Mdot
.40294 .83386 Mdot
.60738 .60633 Mdot
.42774 .59743 Mdot
.19496 .38867 Mdot
.46603 .34119 Mdot
.31424 .44457 Mdot
.20454 .55493 Mdot
.39837 .28055 Mdot
.64273 .44426 Mdot
.62087 .64252 Mdot
.57134 .39321 Mdot
.65073 .51424 Mdot
.37266 .62896 Mdot
.35292 .59666 Mdot
.24535 .69216 Mdot
.39092 .29721 Mdot
.42521 .63705 Mdot
.43786 .34259 Mdot
.62635 .3422 Mdot
.45885 .61278 Mdot
.61953 .63471 Mdot
.26207 .42992 Mdot
.27233 .43274 Mdot
.50746 .60698 Mdot
.59121 .4754 Mdot
.4593 .45872 Mdot
.47662 .60288 Mdot
.50833 .56817 Mdot
.48482 .33402 Mdot
.57523 .37369 Mdot
.59296 .19664 Mdot
.31824 .4592 Mdot
.44927 .62931 Mdot
.74696 .55266 Mdot
.66497 .59597 Mdot
.48054 .39038 Mdot
.63318 .44083 Mdot
.26994 .64317 Mdot
.49033 .39861 Mdot
.45848 .61446 Mdot
.46646 .61039 Mdot
.6674 .3918 Mdot
.63465 .56749 Mdot
.29291 .45013 Mdot
.47642 .33057 Mdot
.31985 .45774 Mdot
.66362 .60886 Mdot
.60989 .60638 Mdot
.44776 .65946 Mdot
.50828 .57929 Mdot
.46331 .35985 Mdot
.38125 .57051 Mdot
.47183 .30697 Mdot
.23057 .63161 Mdot
.67706 .43532 Mdot
.38621 .60751 Mdot
.68007 .61258 Mdot
.6339 .40085 Mdot
.43182 .60916 Mdot
.24257 .70359 Mdot
.38221 .58772 Mdot
.65741 .33925 Mdot
.73765 .33253 Mdot
.2861 .42509 Mdot
.37253 .73182 Mdot
.56435 .5586 Mdot
.40668 .59978 Mdot
.4864 .36518 Mdot
.4006 .52952 Mdot
.67011 .40791 Mdot
.63351 .57929 Mdot
.15518 .41397 Mdot
.65437 .41578 Mdot
.39898 .60324 Mdot
.28571 .44214 Mdot
.60828 .63488 Mdot
.54537 .39415 Mdot
.52751 .2005 Mdot
.4505 .53332 Mdot
.48305 .56218 Mdot
.47953 .60607 Mdot
.82727 .50593 Mdot
.44091 .34708 Mdot
.65131 .60538 Mdot
.66705 .39491 Mdot
.6469 .39516 Mdot
.47256 .36375 Mdot
.72235 .51864 Mdot
.48124 .46799 Mdot
.86968 .60774 Mdot
.45825 .36264 Mdot
.32637 .46252 Mdot
.61711 .50961 Mdot
.48716 .36985 Mdot
.46007 .32481 Mdot
.48216 .33153 Mdot
.60731 .45542 Mdot
.62875 .59738 Mdot
.44108 .62432 Mdot
.59736 .58323 Mdot
.40739 .57238 Mdot
.40909 .46902 Mdot
.63267 .3994 Mdot
.63137 .5779 Mdot
.24902 .70485 Mdot
.64524 .66154 Mdot
.44191 .57942 Mdot
.29475 .72069 Mdot
.41013 .53302 Mdot
.27643 .60309 Mdot
.43304 .53662 Mdot
.45568 .33864 Mdot
.42141 .51412 Mdot
.37035 .59014 Mdot
.59171 .18546 Mdot
.66141 .41822 Mdot
.43308 .32404 Mdot
.40897 .63564 Mdot
.50552 .56846 Mdot
.61343 .64357 Mdot
.60988 .6256 Mdot
.32251 .45655 Mdot
.25731 .47988 Mdot
.66284 .40263 Mdot
.18446 .53907 Mdot
.41307 .59542 Mdot
.69449 .29144 Mdot
.39492 .7365 Mdot
.43217 .60776 Mdot
.53994 .82584 Mdot
.46797 .76538 Mdot
.43674 .55762 Mdot
.41521 .6824 Mdot
.63902 .41835 Mdot
.73753 .34214 Mdot
.42443 .54366 Mdot
.4737 .3472 Mdot
.64937 .58617 Mdot
.61078 .63246 Mdot
.3218 .43809 Mdot
.38706 .19872 Mdot
.67147 .43472 Mdot
.63675 .57892 Mdot
.43279 .56682 Mdot
.64821 .44407 Mdot
.446 .30161 Mdot
.38224 .56023 Mdot
.30961 .61464 Mdot
.62122 .60975 Mdot
.41199 .54812 Mdot
.74832 .43772 Mdot
.23895 .48011 Mdot
.77491 .6816 Mdot
.67495 .41597 Mdot
.29029 .46038 Mdot
.36841 .55694 Mdot
.17761 .50352 Mdot
.41791 .64689 Mdot
.20778 .52041 Mdot
.67152 .56002 Mdot
.28698 .45958 Mdot
.43672 .58514 Mdot
.46157 .59 Mdot
.61386 .49712 Mdot
.28274 .46476 Mdot
.38911 .58112 Mdot
.4716 .51842 Mdot
.63437 .5966 Mdot
.44055 .37357 Mdot
.62043 .60556 Mdot
.44914 .58287 Mdot
.51623 .61232 Mdot
.60142 .60741 Mdot
.17105 .56041 Mdot
.31548 .41275 Mdot
.66441 .42926 Mdot
.51666 .58974 Mdot
.45299 .55268 Mdot
.8435 .45893 Mdot
.43083 .32965 Mdot
.79568 .54784 Mdot
.50345 .39804 Mdot
.73962 .56785 Mdot
.64511 .303 Mdot
.61743 .82368 Mdot
.63844 .2205 Mdot
.48471 .62552 Mdot
.41375 .48839 Mdot
.46293 .67737 Mdot
.65819 .44474 Mdot
.60159 .68764 Mdot
.41116 .59125 Mdot
.4242 .57713 Mdot
.47457 .39065 Mdot
.69641 .51181 Mdot
.47755 .22147 Mdot
.57026 .45379 Mdot
.2962 .44857 Mdot
.6572 .62127 Mdot
.4278 .6186 Mdot
.41365 .44967 Mdot
.48831 .38643 Mdot
.68348 .28362 Mdot
.43107 .59344 Mdot
.37626 .22367 Mdot
.58931 .41971 Mdot
.66264 .43863 Mdot
.48985 .35411 Mdot
.40793 .27818 Mdot
.40152 .57782 Mdot
.62267 .42962 Mdot
.45018 .56655 Mdot
.43043 .40136 Mdot
.37758 .57907 Mdot
.30561 .46258 Mdot
.43003 .63218 Mdot
.56316 .43236 Mdot
.72682 .7332 Mdot
.32438 .58971 Mdot
.63375 .64179 Mdot
.46528 .29829 Mdot
.46943 .36428 Mdot
.60541 .61873 Mdot
.46689 .36055 Mdot
.44909 .73989 Mdot
.56621 .75773 Mdot
.30029 .44718 Mdot
.51037 .57187 Mdot
.31794 .45505 Mdot
.43048 .32956 Mdot
.4075 .58433 Mdot
.16604 .54356 Mdot
.45695 .35607 Mdot
.77166 .35313 Mdot
.65883 .41394 Mdot
.43166 .32727 Mdot
.39435 .56349 Mdot
.55082 .364 Mdot
.49315 .36051 Mdot
.63809 .33968 Mdot
.45754 .59036 Mdot
.6085 .60073 Mdot
.46329 .5952 Mdot
.43166 .53472 Mdot
.47194 .40256 Mdot
.47377 .56375 Mdot
.65507 .42907 Mdot
.63782 .5713 Mdot
.55503 .83993 Mdot
.65932 .33821 Mdot
.39308 .58642 Mdot
.43429 .56828 Mdot
.59676 .62851 Mdot
.41708 .54982 Mdot
.61789 .41446 Mdot
.85124 .34322 Mdot
.30802 .44226 Mdot
.44352 .2921 Mdot
.64803 .30996 Mdot
.42621 .64742 Mdot
.47293 .60368 Mdot
.27342 .73011 Mdot
.6726 .31098 Mdot
.63427 .42827 Mdot
.41657 .52436 Mdot
.46605 .32307 Mdot
.28563 .44051 Mdot
.63564 .38417 Mdot
.48729 .58902 Mdot
.42684 .5848 Mdot
.29312 .46062 Mdot
.4925 .8267 Mdot
.40869 .25356 Mdot
.67584 .40345 Mdot
.41701 .51493 Mdot
.47894 .30027 Mdot
.40772 .56229 Mdot
.37248 .2898 Mdot
.61531 .62748 Mdot
.63633 .43842 Mdot
.78737 .57783 Mdot
.4431 .63507 Mdot
.62746 .39734 Mdot
.66392 .40598 Mdot
.36914 .56269 Mdot
.6365 .6534 Mdot
.65567 .58034 Mdot
.6506 .6301 Mdot
.58348 .16751 Mdot
.2482 .49678 Mdot
.46739 .38203 Mdot
.6376 .41742 Mdot
.45584 .29692 Mdot
.31327 .47279 Mdot
.41275 .45743 Mdot
.44729 .2899 Mdot
.59714 .60944 Mdot
.48255 .32283 Mdot
.46082 .59379 Mdot
.65914 .39829 Mdot
.44856 .36784 Mdot
.40481 .63431 Mdot
.56587 .54097 Mdot
.41876 .37073 Mdot
.26804 .42243 Mdot
.26423 .4161 Mdot
.41677 .61653 Mdot
.43118 .34468 Mdot
.42125 .59628 Mdot
.65798 .3767 Mdot
.63124 .50321 Mdot
.41624 .644 Mdot
.45959 .34955 Mdot
.53092 .55119 Mdot
.39838 .28111 Mdot
.41554 .52721 Mdot
.44828 .58895 Mdot
.40766 .56644 Mdot
.45068 .5661 Mdot
.70991 .53529 Mdot
.67901 .42837 Mdot
.54227 .52239 Mdot
.60396 .34586 Mdot
.62316 .61773 Mdot
.67632 .61035 Mdot
.34386 .29537 Mdot
.42641 .28278 Mdot
.6451 .42634 Mdot
.41949 .55847 Mdot
.66634 .33425 Mdot
.41403 .83973 Mdot
.17113 .57082 Mdot
.25061 .43563 Mdot
.44577 .37056 Mdot
.64011 .64377 Mdot
.48996 .37438 Mdot
.41046 .5751 Mdot
.36633 .5627 Mdot
.60454 .83638 Mdot
.66929 .36796 Mdot
.29332 .45224 Mdot
.40788 .56798 Mdot
.23588 .48471 Mdot
.46239 .32221 Mdot
.48049 .32735 Mdot
.38688 .58034 Mdot
.66845 .58438 Mdot
.84427 .57126 Mdot
.66342 .43898 Mdot
.47013 .50857 Mdot
.56095 .6224 Mdot
.73608 .39801 Mdot
.63786 .39579 Mdot
.40831 .3258 Mdot
.44374 .36919 Mdot
.41136 .76712 Mdot
.61883 .61708 Mdot
.29253 .45451 Mdot
.35613 .58543 Mdot
.60246 .5965 Mdot
.47917 .40253 Mdot
.61612 .58301 Mdot
.4229 .63288 Mdot
.67073 .43818 Mdot
.48594 .34731 Mdot
.68424 .39038 Mdot
.65087 .64783 Mdot
.31702 .4351 Mdot
.57702 .51365 Mdot
.63121 .7055 Mdot
.46384 .76325 Mdot
.40751 .55807 Mdot
.4027 .44886 Mdot
.47048 .57454 Mdot
.61525 .64565 Mdot
.44341 .5649 Mdot
.55691 .60199 Mdot
.48697 .36022 Mdot
.41535 .5471 Mdot
.47597 .61122 Mdot
.56294 .68298 Mdot
.4392 .5951 Mdot
.43323 .54059 Mdot
.43295 .55631 Mdot
.65925 .56444 Mdot
.49505 .55095 Mdot
.62115 .59654 Mdot
.52215 .20526 Mdot
.45911 .3253 Mdot
.26105 .42916 Mdot
.26987 .4314 Mdot
.20749 .50441 Mdot
.3401 .49114 Mdot
.71158 .51884 Mdot
.6295 .6046 Mdot
.66416 .42042 Mdot
.44669 .56363 Mdot
.75188 .63412 Mdot
.61474 .30936 Mdot
.46408 .32002 Mdot
.65746 .33858 Mdot
.353 .56313 Mdot
.82874 .50459 Mdot
.39435 .56121 Mdot
.47327 .18023 Mdot
.47139 .64058 Mdot
.38147 .59385 Mdot
.49579 .35004 Mdot
.34426 .48987 Mdot
.39824 .56292 Mdot
.61118 .64226 Mdot
.30219 .45819 Mdot
.67475 .66286 Mdot
.51066 .28913 Mdot
.41097 .30824 Mdot
.5934 .71608 Mdot
.4639 .56804 Mdot
.48426 .34599 Mdot
.62286 .58842 Mdot
.60883 .20288 Mdot
.65829 .43829 Mdot
.62593 .47841 Mdot
.51309 .673 Mdot
.26704 .69174 Mdot
.29613 .45649 Mdot
.48631 .82331 Mdot
.44244 .61563 Mdot
.36077 .3208 Mdot
.46159 .63474 Mdot
.4181 .84082 Mdot
.32898 .45794 Mdot
.67421 .59352 Mdot
.62731 .41999 Mdot
.59054 .59906 Mdot
.47618 .77621 Mdot
.7115 .38069 Mdot
.54323 .47954 Mdot
.44892 .30979 Mdot
.55161 .52253 Mdot
.65291 .61546 Mdot
.46363 .61758 Mdot
.86279 .63349 Mdot
.62085 .63101 Mdot
.66694 .61531 Mdot
.21596 .60864 Mdot
.21546 .61647 Mdot
.36669 .54159 Mdot
.60295 .58959 Mdot
.4495 .31292 Mdot
.30234 .42712 Mdot
.46585 .58873 Mdot
.45781 .57576 Mdot
.60335 .60582 Mdot
.49201 .34119 Mdot
.43665 .50426 Mdot
.45866 .34066 Mdot
.63461 .59482 Mdot
.46432 .33425 Mdot
.6449 .33059 Mdot
.44121 .35815 Mdot
.44593 .55072 Mdot
.44416 .56442 Mdot
.48518 .28723 Mdot
.61008 .60632 Mdot
.47695 .59714 Mdot
.43219 .62817 Mdot
.64693 .62067 Mdot
.50589 .39805 Mdot
.70007 .67309 Mdot
.39842 .58925 Mdot
.45297 .60558 Mdot
.29055 .46143 Mdot
.37786 .4444 Mdot
.27922 .30472 Mdot
.47068 .59656 Mdot
.31091 .47022 Mdot
.64273 .57722 Mdot
.42341 .59945 Mdot
.69709 .57793 Mdot
.63532 .33799 Mdot
.44355 .63411 Mdot
.43413 .33063 Mdot
.38482 .62593 Mdot
.80094 .63364 Mdot
.38952 .59797 Mdot
.64776 .61103 Mdot
.65826 .59648 Mdot
.2253 .60907 Mdot
.63093 .63023 Mdot
.44052 .31112 Mdot
.64451 .4019 Mdot
.44559 .8504 Mdot
.44691 .30082 Mdot
.37999 .60691 Mdot
.17751 .40463 Mdot
.40271 .54903 Mdot
.4131 .63944 Mdot
.8268 .46282 Mdot
.44799 .30178 Mdot
.65653 .60061 Mdot
.64816 .47736 Mdot
.49553 .62355 Mdot
.64037 .44323 Mdot
.36665 .57925 Mdot
.48426 .56947 Mdot
.72689 .32517 Mdot
.79251 .45807 Mdot
.6272 .37713 Mdot
.39048 .64756 Mdot
.47123 .59646 Mdot
.39277 .41766 Mdot
.43584 .56396 Mdot
.31892 .45623 Mdot
.66196 .62108 Mdot
.48064 .38319 Mdot
.30502 .43347 Mdot
.40943 .59658 Mdot
.28885 .44865 Mdot
.46989 .38434 Mdot
.62814 .43361 Mdot
.40559 .57964 Mdot
.33038 .43716 Mdot
.29464 .4483 Mdot
.47515 .5786 Mdot
.63798 .58018 Mdot
.33587 .56936 Mdot
.42561 .60213 Mdot
.45516 .62199 Mdot
.60498 .60673 Mdot
.15243 .55874 Mdot
.38586 .59422 Mdot
.46523 .42136 Mdot
.66799 .61792 Mdot
.68141 .34646 Mdot
.47299 .38759 Mdot
.48072 .56631 Mdot
.62287 .42733 Mdot
.63008 .40142 Mdot
.46049 .31004 Mdot
.58866 .61529 Mdot
.48151 .31684 Mdot
.52951 .55295 Mdot
.5137 .59039 Mdot
.39091 .55009 Mdot
.1979 .35126 Mdot
.59858 .83143 Mdot
.62073 .6362 Mdot
.49553 .40515 Mdot
.56975 .45679 Mdot
.6338 .41773 Mdot
.46372 .30664 Mdot
.61212 .6379 Mdot
.63568 .64371 Mdot
.61619 .58534 Mdot
.27785 .44585 Mdot
.50257 .40582 Mdot
.64435 .56895 Mdot
.66705 .58343 Mdot
.4589 .59256 Mdot
.47271 .59663 Mdot
.38161 .67116 Mdot
.29323 .55624 Mdot
.31907 .43645 Mdot
.47411 .36086 Mdot
.79172 .29719 Mdot
.65023 .37478 Mdot
.56344 .68586 Mdot
.41857 .64435 Mdot
.75538 .79076 Mdot
.3864 .56872 Mdot
.4315 .5647 Mdot
.63087 .5713 Mdot
.32416 .42707 Mdot
.31619 .45305 Mdot
.65517 .61366 Mdot
.6441 .64735 Mdot
.31573 .46032 Mdot
.40528 .80575 Mdot
.50743 .85065 Mdot
.67638 .46962 Mdot
.64202 .61727 Mdot
.62714 .71887 Mdot
.63273 .44145 Mdot
.65504 .64789 Mdot
.65642 .37833 Mdot
.46463 .32596 Mdot
.44743 .37541 Mdot
.66912 .39609 Mdot
.45644 .58677 Mdot
.45691 .37425 Mdot
.49794 .57139 Mdot
.44832 .82965 Mdot
.57423 .78881 Mdot
.62565 .26739 Mdot
.49831 .6029 Mdot
.48553 .21998 Mdot
.49252 .23582 Mdot
.40817 .60617 Mdot
.72616 .60004 Mdot
.29171 .45159 Mdot
.68488 .61879 Mdot
.61782 .4168 Mdot
.78382 .67135 Mdot
.41116 .56058 Mdot
.64398 .60996 Mdot
.65907 .42248 Mdot
.2321 .5975 Mdot
.69785 .45936 Mdot
.40607 .57109 Mdot
.87789 .58143 Mdot
.68699 .5874 Mdot
.47951 .38342 Mdot
.27131 .27707 Mdot
.59908 .57948 Mdot
.24438 .43743 Mdot
.57708 .36561 Mdot
.26843 .71053 Mdot
.64454 .59151 Mdot
.4965 .4078 Mdot
.65679 .61985 Mdot
.32198 .44746 Mdot
.69126 .62036 Mdot
.48209 .33656 Mdot
.43728 .59079 Mdot
.4669 .35522 Mdot
.31649 .43172 Mdot
.36732 .30449 Mdot
.61877 .42021 Mdot
.43314 .32619 Mdot
.64351 .41175 Mdot
.24431 .48016 Mdot
.75788 .3607 Mdot
.65563 .43532 Mdot
.21118 .57876 Mdot
.42954 .63854 Mdot
.62247 .56716 Mdot
.46229 .36926 Mdot
.57133 .37114 Mdot
.58119 .49984 Mdot
.62777 .62144 Mdot
.47876 .3616 Mdot
.51978 .6653 Mdot
.18725 .4353 Mdot
.52436 .59895 Mdot
.27719 .49857 Mdot
.64326 .62103 Mdot
.47827 .32231 Mdot
.54801 .19335 Mdot
.59645 .61224 Mdot
.45794 .3632 Mdot
.62556 .41285 Mdot
.64316 .39466 Mdot
.39324 .57129 Mdot
.63199 .47006 Mdot
.47564 .37448 Mdot
.52513 .22326 Mdot
.66633 .59768 Mdot
.23432 .59533 Mdot
.30279 .41856 Mdot
.45367 .32426 Mdot
.37395 .57724 Mdot
.57202 .61937 Mdot
.6349 .33643 Mdot
.39108 .5042 Mdot
.78953 .30281 Mdot
.47231 .36263 Mdot
.6646 .61753 Mdot
.6393 .61 Mdot
.40238 .53336 Mdot
.59624 .48222 Mdot
.47817 .31156 Mdot
.1965 .45974 Mdot
.21215 .53546 Mdot
.471 .40062 Mdot
.50896 .25825 Mdot
.37621 .59709 Mdot
.46968 .56781 Mdot
.6322 .41875 Mdot
.44302 .59199 Mdot
.65523 .57694 Mdot
.40377 .55832 Mdot
.63937 .3917 Mdot
.4447 .32493 Mdot
.40968 .58151 Mdot
.29822 .42442 Mdot
.61307 .39254 Mdot
.66485 .38717 Mdot
.45196 .33036 Mdot
.60576 .58833 Mdot
.27203 .40408 Mdot
.46117 .34462 Mdot
.46215 .56769 Mdot
.55171 .38956 Mdot
.42046 .63015 Mdot
.40373 .7878 Mdot
.59504 .60483 Mdot
.48891 .36914 Mdot
.67009 .61984 Mdot
.64594 .41573 Mdot
.60204 .34734 Mdot
.44644 .5751 Mdot
.45548 .35908 Mdot
.48834 .27869 Mdot
.43543 .81312 Mdot
.59262 .62579 Mdot
.53744 .27854 Mdot
.67188 .60134 Mdot
.46508 .39689 Mdot
.31215 .68552 Mdot
.30377 .45267 Mdot
.47088 .32555 Mdot
.59671 .82067 Mdot
.45953 .35427 Mdot
.43949 .59922 Mdot
.42896 .61339 Mdot
.4676 .38703 Mdot
.27205 .44434 Mdot
.66098 .22323 Mdot
.42142 .36428 Mdot
.65179 .59562 Mdot
.35527 .7194 Mdot
.82975 .36731 Mdot
.67541 .44717 Mdot
.63254 .42336 Mdot
.48954 .6249 Mdot
.37938 .59121 Mdot
.64014 .37918 Mdot
.6229 .43805 Mdot
.3184 .42814 Mdot
.47919 .32911 Mdot
.69315 .61484 Mdot
.61357 .41671 Mdot
.41299 .66207 Mdot
.33029 .49231 Mdot
.44618 .52438 Mdot
.54015 .5902 Mdot
.48968 .60425 Mdot
.20093 .51717 Mdot
.6515 .38815 Mdot
.42205 .62062 Mdot
.47049 .53611 Mdot
.63074 .4333 Mdot
.32121 .45052 Mdot
.78487 .4429 Mdot
.47177 .33906 Mdot
.26212 .75294 Mdot
.40393 .61784 Mdot
.43546 .60038 Mdot
.67638 .41583 Mdot
.3807 .4166 Mdot
.60496 .59688 Mdot
.59344 .60227 Mdot
.44181 .35071 Mdot
.5632 .51112 Mdot
.42823 .55024 Mdot
.41089 .61021 Mdot
.48038 .3479 Mdot
.43208 .32853 Mdot
.57873 .244 Mdot
.44436 .62116 Mdot
.65704 .42237 Mdot
.54205 .395 Mdot
.64622 .3883 Mdot
.40006 .61962 Mdot
.43998 .60262 Mdot
.44165 .54967 Mdot
.37869 .59475 Mdot
.6675 .38852 Mdot
.42567 .62085 Mdot
.47268 .64699 Mdot
.6195 .57965 Mdot
.45783 .5574 Mdot
.20608 .53145 Mdot
.45127 .59537 Mdot
.3128 .43217 Mdot
.35053 .48399 Mdot
.40587 .56731 Mdot
.45787 .55522 Mdot
.42435 .37196 Mdot
.43544 .58123 Mdot
.65823 .37695 Mdot
.62605 .61509 Mdot
.63718 .41675 Mdot
.66552 .39097 Mdot
.43816 .3253 Mdot
.3243 .44413 Mdot
.43598 .6455 Mdot
.28442 .42031 Mdot
.38832 .6425 Mdot
.43505 .63702 Mdot
.59102 .34179 Mdot
.46737 .1787 Mdot
.40509 .25457 Mdot
.44765 .57501 Mdot
.44388 .33273 Mdot
.48361 .38197 Mdot
.43752 .49249 Mdot
.49796 .56294 Mdot
.63648 .38091 Mdot
.62952 .4063 Mdot
.29928 .60048 Mdot
.72627 .32729 Mdot
.31753 .43704 Mdot
.40947 .45362 Mdot
.50302 .57631 Mdot
.44202 .62683 Mdot
.38418 .55953 Mdot
.44911 .29116 Mdot
.5507 .39266 Mdot
.46346 .31979 Mdot
.64362 .34232 Mdot
.63858 .39057 Mdot
.42247 .55388 Mdot
.6208 .77514 Mdot
.60564 .62299 Mdot
.62515 .61475 Mdot
.63838 .38463 Mdot
.46394 .29824 Mdot
.34954 .63446 Mdot
.13099 .45885 Mdot
.67977 .58173 Mdot
.29566 .41481 Mdot
.40299 .60249 Mdot
.44776 .33181 Mdot
.63467 .63836 Mdot
.27119 .44988 Mdot
.44496 .63195 Mdot
.48538 .31934 Mdot
.45079 .57449 Mdot
.46157 .67714 Mdot
.63489 .58204 Mdot
.44293 .85502 Mdot
.60573 .63186 Mdot
.61235 .39746 Mdot
.64036 .43484 Mdot
.43392 .60909 Mdot
.21874 .32799 Mdot
.61247 .5695 Mdot
.60281 .43974 Mdot
.32977 .45089 Mdot
.55953 .38307 Mdot
.30636 .46748 Mdot
.48621 .37084 Mdot
.30029 .45773 Mdot
.48779 .3473 Mdot
.30273 .57621 Mdot
.61913 .5587 Mdot
.30798 .4383 Mdot
.41496 .4133 Mdot
.502 .56673 Mdot
.26256 .44082 Mdot
.43073 .65327 Mdot
.38669 .74727 Mdot
.47863 .34841 Mdot
.2724 .44005 Mdot
.46441 .61615 Mdot
.72964 .70809 Mdot
.65038 .43125 Mdot
.63595 .37957 Mdot
.48455 .55935 Mdot
.47763 .32668 Mdot
.62602 .64669 Mdot
.66479 .52484 Mdot
.68186 .35698 Mdot
.41621 .61505 Mdot
.40004 .56116 Mdot
.67712 .60744 Mdot
.59252 .57021 Mdot
.43903 .607 Mdot
.55911 .66272 Mdot
.43661 .61942 Mdot
.62322 .40736 Mdot
.60466 .62632 Mdot
.63415 .61222 Mdot
.47975 .37125 Mdot
.60744 .57953 Mdot
.54166 .57826 Mdot
.5617 .40581 Mdot
.44412 .65126 Mdot
.65309 .41451 Mdot
.58369 .452 Mdot
.6568 .3383 Mdot
.66002 .76679 Mdot
.67565 .62226 Mdot
.46359 .55574 Mdot
.66896 .60386 Mdot
.28222 .43688 Mdot
.61259 .60639 Mdot
.65311 .63609 Mdot
.41812 .60235 Mdot
.41039 .57211 Mdot
.44537 .30702 Mdot
.59019 .47753 Mdot
.63131 .57608 Mdot
.4217 .61683 Mdot
.4108 .54634 Mdot
.43581 .54068 Mdot
.50256 .44388 Mdot
.62568 .63809 Mdot
.50676 .69883 Mdot
.31142 .65611 Mdot
.62919 .57614 Mdot
.81505 .61162 Mdot
.58363 .36615 Mdot
.43987 .28909 Mdot
.69075 .40705 Mdot
.44512 .62156 Mdot
.4674 .38874 Mdot
.41022 .57564 Mdot
.54081 .59117 Mdot
.42531 .58238 Mdot
.29524 .46728 Mdot
.48463 .62552 Mdot
.45368 .38701 Mdot
.46247 .34847 Mdot
.39914 .6083 Mdot
.41296 .58147 Mdot
.38224 .29401 Mdot
.64857 .64645 Mdot
.60686 .59432 Mdot
.36941 .40562 Mdot
.29759 .43793 Mdot
.63705 .44021 Mdot
.4376 .55951 Mdot
.44112 .33848 Mdot
.46607 .35279 Mdot
.5901 .59778 Mdot
.47209 .34765 Mdot
.67025 .4309 Mdot
.44379 .57201 Mdot
.63823 .37881 Mdot
.27256 .43616 Mdot
.65273 .62952 Mdot
.41599 .55832 Mdot
.459 .59351 Mdot
.65818 .59655 Mdot
.44161 .64039 Mdot
.29202 .46221 Mdot
.46244 .35703 Mdot
.63667 .58909 Mdot
.64313 .40053 Mdot
.48759 .36141 Mdot
.4636 .60596 Mdot
.78438 .29493 Mdot
.44445 .60045 Mdot
.45613 .61593 Mdot
.56277 .84841 Mdot
.47821 .63114 Mdot
.46957 .37134 Mdot
.67695 .59553 Mdot
.49481 .57086 Mdot
.21899 .50623 Mdot
.16775 .57248 Mdot
.45718 .3096 Mdot
.39683 .59741 Mdot
.66204 .77441 Mdot
.39587 .60175 Mdot
.18467 .53157 Mdot
.29322 .3248 Mdot
.51362 .50026 Mdot
.51212 .62312 Mdot
.67291 .41128 Mdot
.44428 .30837 Mdot
.48615 .36067 Mdot
.39984 .71547 Mdot
.41653 .6064 Mdot
.43837 .6756 Mdot
.46739 .61988 Mdot
.63972 .39455 Mdot
.31666 .63265 Mdot
.47152 .3591 Mdot
.5058 .18752 Mdot
.46596 .57364 Mdot
.62592 .63931 Mdot
.48459 .3253 Mdot
.59381 .35976 Mdot
.46154 .61427 Mdot
.27911 .42383 Mdot
.64803 .36678 Mdot
.50597 .61498 Mdot
.65448 .40931 Mdot
.43953 .6298 Mdot
.45032 .65989 Mdot
.31072 .24107 Mdot
.62854 .58043 Mdot
.62864 .4193 Mdot
.4959 .24489 Mdot
.45695 .6386 Mdot
.64035 .58929 Mdot
.62001 .61787 Mdot
.31108 .42379 Mdot
.55089 .46454 Mdot
.74405 .45205 Mdot
.6395 .73875 Mdot
.36414 .7149 Mdot
.47189 .31326 Mdot
.54095 .25208 Mdot
.46819 .59098 Mdot
.67967 .28675 Mdot
.64218 .37428 Mdot
.43583 .59706 Mdot
.40857 .74763 Mdot
.64544 .63381 Mdot
.45041 .61064 Mdot
.31845 .45477 Mdot
.64619 .24896 Mdot
.66092 .26999 Mdot
.82004 .5514 Mdot
.45244 .31179 Mdot
.36539 .57511 Mdot
.53808 .59047 Mdot
.43567 .31517 Mdot
.46043 .63227 Mdot
.46548 .36745 Mdot
.33893 .75302 Mdot
.27901 .45618 Mdot
.64537 .63708 Mdot
.58707 .36404 Mdot
.49264 .59618 Mdot
.41429 .54133 Mdot
.26301 .42631 Mdot
.48188 .57569 Mdot
.38931 .20012 Mdot
.62129 .2828 Mdot
.44938 .36721 Mdot
.61816 .58367 Mdot
.4986 .593 Mdot
.53517 .40333 Mdot
.42159 .60703 Mdot
.56638 .77292 Mdot
.4652 .55789 Mdot
.73741 .43872 Mdot
.64911 .58574 Mdot
.65171 .41082 Mdot
.36388 .61035 Mdot
.42783 .57586 Mdot
.50269 .33464 Mdot
.50702 .62851 Mdot
.39027 .60273 Mdot
.60841 .63966 Mdot
.61226 .63018 Mdot
.62192 .59736 Mdot
.49079 .38698 Mdot
.7165 .32114 Mdot
.64999 .42277 Mdot
.37555 .60784 Mdot
.61326 .41688 Mdot
.42454 .50672 Mdot
.26739 .422 Mdot
.73799 .68256 Mdot
.48197 .57102 Mdot
.62968 .60091 Mdot
.75995 .53785 Mdot
.64631 .57861 Mdot
.51591 .39592 Mdot
.66231 .40162 Mdot
.6362 .63619 Mdot
.43047 .5689 Mdot
.57676 .45495 Mdot
.77374 .62768 Mdot
.63558 .41164 Mdot
.40337 .64673 Mdot
.4385 .35933 Mdot
.65116 .31508 Mdot
.82417 .33123 Mdot
.63602 .42933 Mdot
.50583 .24524 Mdot
.41274 .60821 Mdot
.60202 .61677 Mdot
.67387 .41767 Mdot
.65912 .43082 Mdot
.4764 .35211 Mdot
.4099 .57033 Mdot
.41117 .56581 Mdot
.46558 .39561 Mdot
.63087 .40434 Mdot
.41687 .53566 Mdot
.38114 .56851 Mdot
.60399 .83816 Mdot
.37932 .69244 Mdot
.16972 .64448 Mdot
.52401 .54745 Mdot
.41821 .7569 Mdot
.63977 .52542 Mdot
.66175 .62426 Mdot
.40432 .56918 Mdot
.48961 .61025 Mdot
.47638 .37251 Mdot
.44424 .58611 Mdot
.49896 .38893 Mdot
.64329 .42787 Mdot
.81083 .61108 Mdot
.78265 .48347 Mdot
.32789 .74064 Mdot
.44154 .58585 Mdot
.73482 .37206 Mdot
.29123 .43033 Mdot
.60791 .40146 Mdot
.62912 .59228 Mdot
.41639 .63206 Mdot
.38696 .28665 Mdot
.46833 .32399 Mdot
.61615 .62259 Mdot
.49615 .21003 Mdot
.41835 .27389 Mdot
.40082 .62044 Mdot
.4869 .39289 Mdot
.72641 .56351 Mdot
.56614 .66065 Mdot
.64063 .45368 Mdot
.30088 .46785 Mdot
.46167 .31996 Mdot
.64262 .3858 Mdot
.68018 .56516 Mdot
.63284 .6339 Mdot
.66122 .5718 Mdot
.36259 .27459 Mdot
.44845 .28632 Mdot
.30284 .43033 Mdot
.72015 .32539 Mdot
.70729 .29484 Mdot
.29637 .46721 Mdot
.46 .38897 Mdot
.62021 .63393 Mdot
.64522 .60029 Mdot
.62754 .61528 Mdot
.52068 .18579 Mdot
.59077 .61702 Mdot
.57004 .70756 Mdot
.40928 .54543 Mdot
.4431 .66779 Mdot
.3953 .59755 Mdot
.65651 .37931 Mdot
.64024 .5844 Mdot
.60953 .50739 Mdot
.38547 .6208 Mdot
.80829 .58322 Mdot
.41196 .61243 Mdot
.63228 .45118 Mdot
.45061 .61568 Mdot
.59932 .69633 Mdot
.6706 .61296 Mdot
.44746 .58108 Mdot
.68233 .39993 Mdot
.29364 .44456 Mdot
.649 .65533 Mdot
.40733 .56717 Mdot
.69315 .50507 Mdot
.47213 .63582 Mdot
.38485 .79384 Mdot
.24899 .60735 Mdot
.29418 .41457 Mdot
.46237 .51603 Mdot
.46964 .31603 Mdot
.43632 .67017 Mdot
.51951 .57718 Mdot
.63684 .41058 Mdot
.78562 .40502 Mdot
.45705 .32233 Mdot
.32055 .6052 Mdot
.40718 .52713 Mdot
.32373 .44815 Mdot
.57516 .60277 Mdot
.66979 .38652 Mdot
.40471 .63206 Mdot
.37059 .56059 Mdot
.35319 .76136 Mdot
.52063 .58585 Mdot
.41272 .5516 Mdot
.26515 .4274 Mdot
.51139 .70419 Mdot
.45423 .5961 Mdot
.51562 .40181 Mdot
.66743 .57732 Mdot
.49014 .56179 Mdot
.50935 .69538 Mdot
.42119 .61576 Mdot
.61004 .62131 Mdot
.60913 .56397 Mdot
.75265 .50766 Mdot
.3285 .44514 Mdot
.46606 .55854 Mdot
.26266 .64701 Mdot
.46847 .57164 Mdot
.65855 .41925 Mdot
.38561 .60246 Mdot
.47255 .32922 Mdot
.50353 .19459 Mdot
.46773 .3806 Mdot
.3969 .57911 Mdot
.63372 .61601 Mdot
.67384 .40257 Mdot
.38508 .26105 Mdot
.31534 .32542 Mdot
.56083 .70472 Mdot
.24862 .70721 Mdot
.27421 .44602 Mdot
.28912 .46892 Mdot
.67413 .39256 Mdot
.4488 .58208 Mdot
.23517 .62545 Mdot
.48368 .63255 Mdot
.45353 .60695 Mdot
.4241 .58283 Mdot
.70925 .32889 Mdot
.63757 .42174 Mdot
.46811 .341 Mdot
.44056 .60513 Mdot
.42451 .61878 Mdot
.66552 .60843 Mdot
.29523 .44609 Mdot
.47768 .38645 Mdot
.30363 .44382 Mdot
.4494 .34222 Mdot
.80904 .62455 Mdot
.37728 .62344 Mdot
.29328 .44191 Mdot
.6321 .37349 Mdot
.6045 .60739 Mdot
.5536 .39086 Mdot
.4861 .36848 Mdot
.47517 .36173 Mdot
.41477 .61325 Mdot
.60553 .6172 Mdot
.61337 .57716 Mdot
.28128 .43641 Mdot
.65271 .43876 Mdot
.40291 .57626 Mdot
.42963 .63654 Mdot
.47366 .49123 Mdot
.45237 .29151 Mdot
.53232 .65421 Mdot
.73552 .5272 Mdot
.44899 .57754 Mdot
.60456 .58781 Mdot
.41692 .5871 Mdot
.61679 .78853 Mdot
.59742 .60678 Mdot
.38256 .59039 Mdot
.704 .27942 Mdot
.54698 .39257 Mdot
.71696 .48397 Mdot
.43532 .54662 Mdot
.28871 .75769 Mdot
.47299 .5885 Mdot
.64323 .80641 Mdot
.37384 .3378 Mdot
.42035 .55341 Mdot
.46455 .5939 Mdot
.66316 .72978 Mdot
.406 .59735 Mdot
.45155 .38565 Mdot
.31921 .60631 Mdot
.64084 .64452 Mdot
.61763 .51901 Mdot
.36708 .46472 Mdot
.32948 .44146 Mdot
.44203 .35162 Mdot
.5188 .27309 Mdot
.3088 .46209 Mdot
.64443 .61691 Mdot
.4508 .56582 Mdot
.53641 .5012 Mdot
.48467 .40581 Mdot
.43222 .53289 Mdot
.6614 .41391 Mdot
.57642 .27649 Mdot
.50036 .39411 Mdot
.64746 .4045 Mdot
.49078 .58767 Mdot
.69891 .67809 Mdot
.28068 .32289 Mdot
.45874 .86174 Mdot
.67607 .40517 Mdot
.63225 .39709 Mdot
.56591 .18569 Mdot
.33168 .44761 Mdot
.35261 .74207 Mdot
.72425 .43878 Mdot
.66055 .44215 Mdot
.29795 .66794 Mdot
.46394 .31786 Mdot
.69159 .49682 Mdot
.68479 .61902 Mdot
.38903 .55184 Mdot
.43031 .57093 Mdot
.64856 .43926 Mdot
.69606 .58258 Mdot
.29686 .25414 Mdot
.64243 .41083 Mdot
.44058 .65829 Mdot
.50152 .45687 Mdot
.58057 .36872 Mdot
.44521 .29731 Mdot
.32671 .43998 Mdot
.26976 .47034 Mdot
.66198 .6109 Mdot
.32082 .43289 Mdot
.65118 .2632 Mdot
.4818 .57291 Mdot
.6364 .40521 Mdot
.59982 .35867 Mdot
.64572 .39798 Mdot
.31285 .45818 Mdot
.30599 .41696 Mdot
.61806 .58019 Mdot
.60727 .59509 Mdot
.436 .76087 Mdot
.28342 .60125 Mdot
.39689 .60458 Mdot
.78088 .58304 Mdot
.66424 .59417 Mdot
.50947 .55055 Mdot
.30569 .46975 Mdot
.29618 .44194 Mdot
.42678 .68722 Mdot
.4265 .55643 Mdot
.21742 .59823 Mdot
.42866 .55783 Mdot
.3052 .62218 Mdot
.46722 .62997 Mdot
.47455 .35007 Mdot
.43081 .55449 Mdot
.32477 .41632 Mdot
.37641 .59691 Mdot
.39229 .60734 Mdot
.47293 .32263 Mdot
.50964 .60904 Mdot
.47375 .33039 Mdot
.39447 .5802 Mdot
.31527 .47157 Mdot
.4408 .34041 Mdot
.24715 .50619 Mdot
.45959 .41774 Mdot
.4323 .3473 Mdot
.30428 .42379 Mdot
.29506 .41781 Mdot
.21888 .47977 Mdot
.63084 .59201 Mdot
.63083 .65681 Mdot
.44839 .58623 Mdot
.48107 .32775 Mdot
.63373 .42149 Mdot
.42824 .61995 Mdot
.47644 .62824 Mdot
.41375 .54892 Mdot
.65832 .62341 Mdot
.47447 .3081 Mdot
.28849 .44369 Mdot
.48947 .39214 Mdot
.5052 .35728 Mdot
.4953 .39826 Mdot
.48093 .54037 Mdot
.35412 .59935 Mdot
.43103 .78318 Mdot
.80117 .52604 Mdot
.64194 .21088 Mdot
.62769 .63123 Mdot
.43368 .32962 Mdot
.31548 .42352 Mdot
.35363 .53806 Mdot
.63247 .59696 Mdot
.48085 .3354 Mdot
.45039 .57336 Mdot
.39909 .64579 Mdot
.66895 .36357 Mdot
.44596 .67035 Mdot
.22429 .54946 Mdot
.49742 .38411 Mdot
.49522 .41022 Mdot
.70202 .294 Mdot
.32475 .61607 Mdot
.57282 .50665 Mdot
.42717 .5933 Mdot
.27662 .42558 Mdot
.63454 .63833 Mdot
.32803 .28287 Mdot
.62481 .42494 Mdot
.59377 .48003 Mdot
.44214 .58472 Mdot
.70486 .4422 Mdot
.6319 .61671 Mdot
.32058 .4469 Mdot
.64673 .43949 Mdot
.32273 .42416 Mdot
.4425 .29457 Mdot
.21694 .63431 Mdot
.47458 .57306 Mdot
.39003 .59808 Mdot
.61424 .4067 Mdot
.65587 .61956 Mdot
.26843 .41459 Mdot
.40914 .80321 Mdot
.46799 .38549 Mdot
.20826 .59294 Mdot
.63008 .56995 Mdot
.60014 .71656 Mdot
.49066 .39067 Mdot
.63764 .38531 Mdot
.22252 .47421 Mdot
.64071 .39103 Mdot
.4014 .56701 Mdot
.63178 .60681 Mdot
.65167 .42976 Mdot
.51634 .35777 Mdot
.69352 .74786 Mdot
.61776 .72002 Mdot
.45199 .55891 Mdot
.75945 .66292 Mdot
.48535 .83966 Mdot
.7038 .63154 Mdot
.61999 .42461 Mdot
.42544 .60411 Mdot
.47935 .61043 Mdot
.46292 .57142 Mdot
.66723 .41035 Mdot
.57306 .33955 Mdot
.48165 .35449 Mdot
.40346 .60628 Mdot
.3152 .42549 Mdot
.47183 .33114 Mdot
.59818 .35357 Mdot
.47322 .3694 Mdot
.66089 .63812 Mdot
.37997 .59371 Mdot
.61632 .47292 Mdot
.7348 .73383 Mdot
.63673 .41553 Mdot
.43259 .34856 Mdot
.41525 .62419 Mdot
.74629 .36252 Mdot
.62405 .59779 Mdot
.46566 .38445 Mdot
.43487 .60008 Mdot
.55541 .35025 Mdot
.37936 .29347 Mdot
.47364 .36727 Mdot
.6428 .59599 Mdot
.71565 .61782 Mdot
.44417 .59023 Mdot
.47531 .5865 Mdot
.65406 .61845 Mdot
.35634 .45254 Mdot
.51725 .19941 Mdot
.41485 .58325 Mdot
.65077 .40965 Mdot
.14944 .47806 Mdot
.43067 .54208 Mdot
.3553 .67765 Mdot
.45117 .30557 Mdot
.71685 .51238 Mdot
.5364 .65118 Mdot
.43088 .51141 Mdot
.67113 .73216 Mdot
.42401 .45786 Mdot
.79924 .6257 Mdot
.49934 .36769 Mdot
.39531 .36098 Mdot
.7982 .63872 Mdot
.68238 .40793 Mdot
.57794 .56568 Mdot
.47531 .50816 Mdot
.48496 .19393 Mdot
.6945 .56696 Mdot
.35905 .38286 Mdot
.39681 .27017 Mdot
.50707 .47833 Mdot
.45678 .35466 Mdot
.3281 .54922 Mdot
.40578 .5763 Mdot
.47783 .84014 Mdot
.56431 .66852 Mdot
.2757 .26428 Mdot
.75475 .6715 Mdot
.26551 .64723 Mdot
.75078 .6523 Mdot
.63946 .78748 Mdot
.41199 .77371 Mdot
.79156 .53785 Mdot
.16796 .51305 Mdot
.68991 .27465 Mdot
.28078 .68725 Mdot
.35537 .57272 Mdot
.41565 .44977 Mdot
.3175 .75659 Mdot
.57049 .72815 Mdot
.20241 .35572 Mdot
.47647 .37878 Mdot
.67529 .59301 Mdot
.47827 .50505 Mdot
.59211 .63061 Mdot
.70348 .41787 Mdot
.68074 .72887 Mdot
.62581 .8129 Mdot
.59006 .6921 Mdot
.28983 .76201 Mdot
.42382 .73337 Mdot
.52273 .14232 Mdot
.42166 .37947 Mdot
.6302 .56391 Mdot
.2887 .37884 Mdot
.71229 .30293 Mdot
.77178 .46113 Mdot
.51973 .53946 Mdot
.62682 .32452 Mdot
.26577 .52922 Mdot
.64361 .61095 Mdot
.5592 .65296 Mdot
.42337 .28518 Mdot
.78205 .45057 Mdot
.23594 .43522 Mdot
.66913 .75221 Mdot
.54575 .49239 Mdot
.67791 .49937 Mdot
.54807 .24806 Mdot
.78599 .29758 Mdot
.27888 .63168 Mdot
.54603 .81933 Mdot
.69852 .40665 Mdot
.7029 .58873 Mdot
.43237 .21124 Mdot
.27783 .57459 Mdot
.71287 .30125 Mdot
.80586 .39869 Mdot
.44629 .84373 Mdot
.82992 .41939 Mdot
.63773 .65647 Mdot
.41638 .54892 Mdot
.53938 .81094 Mdot
.35057 .69766 Mdot
.27948 .47195 Mdot
.82488 .52392 Mdot
.27118 .43465 Mdot
.61634 .6491 Mdot
.49094 .20411 Mdot
.58033 .70104 Mdot
.20675 .5847 Mdot
.2745 .40989 Mdot
.49957 .60191 Mdot
.27532 .21518 Mdot
.7941 .62672 Mdot
.74719 .50541 Mdot
.60616 .83712 Mdot
.72145 .39859 Mdot
.23871 .60515 Mdot
.65646 .42745 Mdot
.77552 .68284 Mdot
.64119 .60189 Mdot
.85591 .5912 Mdot
.72807 .72707 Mdot
.28062 .28393 Mdot
.10815 .45583 Mdot
.65752 .2841 Mdot
.53766 .51594 Mdot
.41752 .46304 Mdot
.23019 .52586 Mdot
.33196 .23851 Mdot
.24195 .3224 Mdot
.72147 .34572 Mdot
.28665 .7341 Mdot
.77748 .66811 Mdot
.30627 .6807 Mdot
.23809 .65581 Mdot
.47103 .20038 Mdot
.4905 .43605 Mdot
.5705 .61132 Mdot
.44607 .39567 Mdot
.73323 .63515 Mdot
.83589 .49788 Mdot
.3392 .67396 Mdot
.12749 .46866 Mdot
.28817 .4037 Mdot
.36675 .34505 Mdot
.55122 .83512 Mdot
.26355 .50328 Mdot
.32601 .67878 Mdot
.59886 .20128 Mdot
.44171 .52839 Mdot
.63722 .22515 Mdot
.75053 .59809 Mdot
.53275 .2778 Mdot
.67743 .26495 Mdot
.70371 .54529 Mdot
.37264 .77691 Mdot
.55763 .79328 Mdot
.72401 .31011 Mdot
.64473 .64536 Mdot
.26171 .56538 Mdot
.28667 .64845 Mdot
.59429 .84357 Mdot
.49663 .24516 Mdot
.50122 .88153 Mdot
.45646 .23081 Mdot
.42579 .65004 Mdot
.52872 .59205 Mdot
.35839 .633 Mdot
.27101 .59462 Mdot
.40844 .54861 Mdot
.72477 .36156 Mdot
.57865 .84982 Mdot
.3981 .73787 Mdot
.53637 .29006 Mdot
.79211 .41354 Mdot
.46498 .86243 Mdot
.45971 .80045 Mdot
.38815 .30542 Mdot
.35279 .66341 Mdot
.63879 .19164 Mdot
.46306 .33015 Mdot
.30294 .6803 Mdot
.66359 .44645 Mdot
.33366 .28872 Mdot
.6464 .72818 Mdot
.31177 .26682 Mdot
.5773 .8508 Mdot
.52811 .20411 Mdot
.41765 .25389 Mdot
.22029 .44638 Mdot
.194 .57682 Mdot
.80627 .44964 Mdot
.36795 .58926 Mdot
.55851 .55405 Mdot
.26807 .42775 Mdot
.46921 .77727 Mdot
.32723 .69846 Mdot
.31539 .3552 Mdot
.50835 .62141 Mdot
.24647 .35495 Mdot
.49895 .41131 Mdot
.58684 .46966 Mdot
.85429 .42063 Mdot
.46127 .5383 Mdot
.67589 .30951 Mdot
.41825 .82628 Mdot
.24898 .58023 Mdot
.55355 .82937 Mdot
.67099 .51646 Mdot
.82524 .41956 Mdot
.70353 .75081 Mdot
.30996 .33724 Mdot
.82149 .58105 Mdot
.57343 .86443 Mdot
.80945 .38148 Mdot
.52915 .62929 Mdot
.66819 .38016 Mdot
.89501 .47215 Mdot
.4809 .40215 Mdot
.7722 .37015 Mdot
.36493 .71489 Mdot
.55593 .33305 Mdot
.66386 .64998 Mdot
.3472 .58096 Mdot
.51765 .48384 Mdot
.68401 .5786 Mdot
.49756 .5723 Mdot
.81738 .3528 Mdot
.78651 .36192 Mdot
.82621 .3861 Mdot
.37001 .80152 Mdot
.82165 .58723 Mdot
.47493 .4817 Mdot
.5799 .71635 Mdot
.41753 .49669 Mdot
.38961 .61113 Mdot
.32183 .54082 Mdot
.65328 .28254 Mdot
.28996 .30744 Mdot
.76207 .45052 Mdot
.60727 .64186 Mdot
.80154 .56725 Mdot
.74766 .21933 Mdot
.44389 .73736 Mdot
.46462 .70576 Mdot
.67331 .27785 Mdot
.2824 .61213 Mdot
.73982 .62186 Mdot
.2798 .30077 Mdot
.57237 .84298 Mdot
.44874 .50405 Mdot
.31027 .70448 Mdot
.3339 .3751 Mdot
.18692 .50292 Mdot
.39321 .42275 Mdot
.68903 .74174 Mdot
.40752 .47905 Mdot
.36423 .24987 Mdot
.60038 .51955 Mdot
.28739 .27043 Mdot
.34702 .31283 Mdot
.57709 .2715 Mdot
.2883 .68078 Mdot
.66243 .33184 Mdot
.2997 .63443 Mdot
.51669 .46018 Mdot
.34865 .5325 Mdot
.42639 .45745 Mdot
.30051 .64017 Mdot
.19002 .49202 Mdot
.83677 .51205 Mdot
.5695 .87421 Mdot
.74273 .26954 Mdot
.30279 .77257 Mdot
.74693 .58879 Mdot
.39795 .54501 Mdot
.52905 .85073 Mdot
.84559 .43894 Mdot
.69896 .76186 Mdot
.54264 .21415 Mdot
.5319 .35716 Mdot
.60988 .39533 Mdot
.74735 .28022 Mdot
.36639 .40002 Mdot
.60689 .80817 Mdot
.653 .2236 Mdot
.69006 .4021 Mdot
.45661 .18037 Mdot
.77415 .3535 Mdot
.64815 .71561 Mdot
.49963 .66385 Mdot
.41661 .53028 Mdot
.60119 .68704 Mdot
.67231 .62117 Mdot
.53141 .24304 Mdot
.27591 .58574 Mdot
.45404 .3293 Mdot
.32477 .49622 Mdot
.54157 .54691 Mdot
.48633 .62433 Mdot
.37469 .46458 Mdot
.6807 .60109 Mdot
.79981 .52761 Mdot
.58025 .42876 Mdot
.84427 .57275 Mdot
.6336 .27539 Mdot
.50709 .63026 Mdot
.25679 .5941 Mdot
.43146 .25919 Mdot
.57958 .19291 Mdot
.67135 .43696 Mdot
.74096 .69325 Mdot
.50875 .415 Mdot
.26343 .57029 Mdot
.59819 .68149 Mdot
.38801 .77929 Mdot
.35227 .59577 Mdot
.74837 .52994 Mdot
.53513 .7805 Mdot
.58408 .47228 Mdot
.57848 .62225 Mdot
.5645 .5999 Mdot
.41245 .86106 Mdot
.6314 .24182 Mdot
.55949 .2643 Mdot
.73218 .7023 Mdot
.66078 .39502 Mdot
.63609 .57563 Mdot
.3158 .56624 Mdot
.37844 .78459 Mdot
.55662 .76045 Mdot
.38023 .29203 Mdot
.61856 .30773 Mdot
.3342 .35154 Mdot
.74641 .67422 Mdot
.75677 .65357 Mdot
.26843 .26658 Mdot
.58884 .62152 Mdot
.4179 .79622 Mdot
.31977 .72872 Mdot
.67052 .59608 Mdot
.67099 .65129 Mdot
.76852 .4288 Mdot
.84395 .5353 Mdot
.61599 .46622 Mdot
.28002 .73571 Mdot
.20237 .50487 Mdot
.56223 .34983 Mdot
.38943 .25836 Mdot
.26354 .66441 Mdot
.72395 .70998 Mdot
.57563 .65783 Mdot
.66819 .7019 Mdot
.39379 .65035 Mdot
.424 .67378 Mdot
.72506 .24472 Mdot
.45814 .42206 Mdot
.60267 .7122 Mdot
.69119 .53855 Mdot
.46223 .56587 Mdot
.78774 .30204 Mdot
.44568 .82994 Mdot
.58303 .18695 Mdot
.63455 .36969 Mdot
.4732 .60483 Mdot
.37354 .58816 Mdot
.37268 .67597 Mdot
.735 .51382 Mdot
.79564 .3934 Mdot
.26608 .6685 Mdot
.72444 .58241 Mdot
.5686 .66758 Mdot
.67616 .31055 Mdot
.66016 .75844 Mdot
.50759 .83822 Mdot
.55537 .45676 Mdot
.64252 .2754 Mdot
.22872 .47197 Mdot
.31254 .77455 Mdot
.43881 .44363 Mdot
.48077 .48909 Mdot
.74436 .39489 Mdot
.7117 .52632 Mdot
.36205 .26332 Mdot
.43113 .63243 Mdot
.49675 .20971 Mdot
.64032 .78495 Mdot
.19075 .36024 Mdot
.37505 .22309 Mdot
.79964 .31588 Mdot
.58676 .76628 Mdot
.69585 .52248 Mdot
.70419 .68115 Mdot
.17239 .37694 Mdot
.41131 .44704 Mdot
.7946 .59825 Mdot
.22065 .45788 Mdot
.73956 .68861 Mdot
.68497 .39955 Mdot
.69118 .46552 Mdot
.79004 .40815 Mdot
.83661 .55627 Mdot
.48273 .80849 Mdot
.69135 .73335 Mdot
.59378 .51624 Mdot
.85304 .49633 Mdot
.75047 .37495 Mdot
.49265 .4708 Mdot
.43587 .33887 Mdot
.5787 .20287 Mdot
.74836 .63442 Mdot
.77792 .56027 Mdot
.30388 .68675 Mdot
.4262 .42841 Mdot
.31958 .59817 Mdot
.64996 .69564 Mdot
.29196 .51046 Mdot
.71773 .538 Mdot
.25594 .59276 Mdot
.64219 .79192 Mdot
.40361 .43873 Mdot
.41958 .26008 Mdot
.66733 .3111 Mdot
.23072 .65929 Mdot
.73834 .50873 Mdot
.62175 .2364 Mdot
.55142 .81938 Mdot
.35401 .33156 Mdot
.27136 .64571 Mdot
.55568 .90856 Mdot
.27746 .70134 Mdot
.79898 .48587 Mdot
.83493 .49513 Mdot
.53819 .83537 Mdot
.80276 .50849 Mdot
.34697 .22727 Mdot
.39272 .69379 Mdot
.30425 .57041 Mdot
.42506 .58148 Mdot
.84939 .41791 Mdot
.27849 .52957 Mdot
.83931 .49058 Mdot
.49766 .8594 Mdot
.61357 .68876 Mdot
.48937 .62197 Mdot
.49504 .37292 Mdot
.41953 .3137 Mdot
.30754 .50911 Mdot
.67929 .70305 Mdot
.39007 .69813 Mdot
.62582 .28979 Mdot
.43639 .30828 Mdot
.37387 .40857 Mdot
.69693 .6514 Mdot
.61426 .25704 Mdot
.72936 .52874 Mdot
.34044 .4735 Mdot
.56643 .48786 Mdot
.28785 .62814 Mdot
.53857 .65259 Mdot
.64367 .72053 Mdot
.31861 .26209 Mdot
.52093 .41516 Mdot
.47084 .37297 Mdot
.62694 .75119 Mdot
.29503 .7332 Mdot
.72665 .55566 Mdot
.81895 .42001 Mdot
.56351 .19634 Mdot
.37505 .50349 Mdot
.31092 .64686 Mdot
.31451 .25406 Mdot
.17638 .50117 Mdot
.8077 .53658 Mdot
.55619 .62649 Mdot
.22 .59506 Mdot
.53349 .53622 Mdot
.80628 .62727 Mdot
.28698 .69094 Mdot
.34512 .71873 Mdot
.43312 .39191 Mdot
.55577 .73823 Mdot
.63332 .68584 Mdot
.24116 .50094 Mdot
.58364 .49829 Mdot
.53856 .14351 Mdot
.68785 .62369 Mdot
.76639 .26444 Mdot
.62244 .41312 Mdot
.50767 .17642 Mdot
.21074 .44524 Mdot
.51619 .45681 Mdot
.59063 .50304 Mdot
.75343 .52289 Mdot
.7381 .43597 Mdot
.33065 .77788 Mdot
.24398 .30901 Mdot
.49418 .40177 Mdot
.23655 .6376 Mdot
.20518 .62422 Mdot
.65741 .73346 Mdot
.50057 .58307 Mdot
.27296 .70088 Mdot
.46728 .42765 Mdot
.2939 .3029 Mdot
.50886 .84956 Mdot
.76417 .5581 Mdot
.45934 .65586 Mdot
.28082 .60574 Mdot
.78984 .60337 Mdot
.70494 .74448 Mdot
.40877 .19343 Mdot
.7505 .59731 Mdot
.66116 .37656 Mdot
.48 .47609 Mdot
.71551 .6948 Mdot
.22743 .58008 Mdot
.66952 .49377 Mdot
.28306 .64856 Mdot
.67192 .18462 Mdot
.80222 .41175 Mdot
.79519 .39323 Mdot
.24616 .60688 Mdot
.58278 .60222 Mdot
.76356 .3952 Mdot
.31848 .67421 Mdot
.76706 .54413 Mdot
.33493 .76777 Mdot
.29589 .65711 Mdot
.25845 .26294 Mdot
.38569 .75084 Mdot
.50409 .35589 Mdot
.64131 .68108 Mdot
.39815 .74813 Mdot
.65452 .37063 Mdot
.31191 .5439 Mdot
.69902 .54716 Mdot
.6129 .39961 Mdot
.7229 .53816 Mdot
.6977 .50332 Mdot
.35605 .7316 Mdot
.57328 .75309 Mdot
.73078 .58464 Mdot
.61159 .77488 Mdot
.63597 .54696 Mdot
.33096 .28154 Mdot
.46849 .27415 Mdot
.69331 .55187 Mdot
.44719 .36781 Mdot
.44421 .51295 Mdot
.57543 .46952 Mdot
.35208 .48625 Mdot
.72747 .26194 Mdot
.26901 .43481 Mdot
.59462 .58764 Mdot
.54367 .16634 Mdot
.66731 .58646 Mdot
.8298 .37523 Mdot
.29323 .28828 Mdot
.59042 .67959 Mdot
.32084 .33107 Mdot
.30695 .37398 Mdot
.39832 .16205 Mdot
.67703 .67023 Mdot
.42891 .37847 Mdot
.60152 .55998 Mdot
.59374 .61457 Mdot
.645 .3051 Mdot
.43857 .30631 Mdot
.47436 .68044 Mdot
.70142 .35594 Mdot
.39951 .49685 Mdot
.5993 .56973 Mdot
.52435 .37585 Mdot
.3184 .62239 Mdot
.84269 .54831 Mdot
.46041 .36368 Mdot
.62004 .17134 Mdot
.42027 .65193 Mdot
.52127 .79948 Mdot
.56239 .85167 Mdot
.43322 .18611 Mdot
.46594 .2576 Mdot
.16517 .56229 Mdot
.42835 .64878 Mdot
.73516 .59204 Mdot
.647 .60772 Mdot
.33239 .71349 Mdot
.29835 .45624 Mdot
.23813 .55596 Mdot
.6129 .41774 Mdot
.36591 .25053 Mdot
.60579 .25632 Mdot
.58584 .59034 Mdot
.76465 .57806 Mdot
.40696 .77972 Mdot
.70367 .45933 Mdot
.47491 .43243 Mdot
.65482 .73219 Mdot
.5661 .75296 Mdot
.60174 .56776 Mdot
.81863 .43943 Mdot
.30694 .70663 Mdot
.78843 .67447 Mdot
.36999 .6428 Mdot
.40726 .3562 Mdot
.7318 .38824 Mdot
.73802 .54175 Mdot
.5242 .65346 Mdot
.57843 .84357 Mdot
.27072 .56861 Mdot
.72869 .37305 Mdot
.30155 .62263 Mdot
.36371 .54306 Mdot
.54947 .48115 Mdot
.5384 .23376 Mdot
.31262 .22183 Mdot
.44927 .67649 Mdot
.4395 .20225 Mdot
.55437 .61645 Mdot
.6729 .30512 Mdot
.69022 .59846 Mdot
.51945 .31925 Mdot
.56964 .73478 Mdot
.48362 .24748 Mdot
.79882 .64569 Mdot
.5748 .84475 Mdot
.67537 .37058 Mdot
.63735 .31379 Mdot
.65029 .53818 Mdot
.40077 .6561 Mdot
.62179 .50322 Mdot
.40767 .55651 Mdot
.69601 .63422 Mdot
.45978 .17564 Mdot
.75992 .53922 Mdot
.3801 .54114 Mdot
.79868 .62994 Mdot
.77064 .68936 Mdot
.84996 .49749 Mdot
.20431 .58925 Mdot
.65601 .63106 Mdot
.81122 .37259 Mdot
.49844 .68372 Mdot
.65331 .7883 Mdot
.80165 .54543 Mdot
.43441 .86834 Mdot
.67153 .70499 Mdot
.67762 .52797 Mdot
.25171 .30778 Mdot
.72891 .46096 Mdot
.4769 .84514 Mdot
.47215 .45861 Mdot
.55929 .28366 Mdot
.47717 .84933 Mdot
.3132 .19226 Mdot
.54274 .61989 Mdot
.68655 .50218 Mdot
.51654 .52135 Mdot
.69667 .55177 Mdot
.38546 .33017 Mdot
.38652 .60369 Mdot
.62818 .33889 Mdot
.40285 .25381 Mdot
.28968 .63598 Mdot
.31895 .5958 Mdot
.38402 .33281 Mdot
.31798 .50815 Mdot
.30697 .6184 Mdot
.27852 .68617 Mdot
.66049 .719 Mdot
.48649 .67529 Mdot
.40158 .6494 Mdot
.69366 .61012 Mdot
.32645 .45616 Mdot
.50265 .26929 Mdot
.39356 .57703 Mdot
.48314 .25142 Mdot
.72068 .44994 Mdot
.80559 .32879 Mdot
.53432 .31011 Mdot
.41626 .81331 Mdot
.6848 .61697 Mdot
.73988 .51904 Mdot
.60614 .78607 Mdot
.48835 .19747 Mdot
.38394 .3702 Mdot
.33877 .67378 Mdot
.77963 .64296 Mdot
.67756 .26661 Mdot
.36368 .76368 Mdot
.72901 .29298 Mdot
.62767 .38021 Mdot
.50139 .64846 Mdot
.50248 .50889 Mdot
.54159 .20775 Mdot
.57428 .61173 Mdot
.68265 .52886 Mdot
.42366 .40227 Mdot
.65433 .24569 Mdot
.42218 .82952 Mdot
.39673 .77838 Mdot
.66396 .67894 Mdot
.76077 .65245 Mdot
.45527 .30573 Mdot
.31534 .71377 Mdot
.64414 .50372 Mdot
.39437 .37492 Mdot
.72706 .32531 Mdot
.83229 .591 Mdot
.61563 .5037 Mdot
.26031 .52235 Mdot
.47385 .57902 Mdot
.51005 .69767 Mdot
.76109 .5291 Mdot
.31079 .40325 Mdot
.60185 .27184 Mdot
.59972 .60051 Mdot
.5793 .25662 Mdot
.37981 .42839 Mdot
.30141 .56055 Mdot
.61431 .55795 Mdot
.36855 .70071 Mdot
.27427 .46626 Mdot
.67973 .34865 Mdot
.45974 .54869 Mdot
.24843 .53011 Mdot
.20105 .57613 Mdot
.5157 .63748 Mdot
.744 .62785 Mdot
.64452 .73587 Mdot
.36068 .77188 Mdot
.74107 .55908 Mdot
.81069 .52715 Mdot
.741 .43953 Mdot
.58969 .72985 Mdot
.48768 .22688 Mdot
.41646 .54764 Mdot
.52179 .32181 Mdot
.63212 .57286 Mdot
.69432 .70824 Mdot
.57447 .7705 Mdot
.24928 .5057 Mdot
.5333 .44279 Mdot
.58749 .79548 Mdot
.52119 .43196 Mdot
.54539 .84921 Mdot
.73066 .46124 Mdot
.27636 .58299 Mdot
.68123 .43613 Mdot
.21349 .45383 Mdot
.33305 .24242 Mdot
.75362 .69684 Mdot
.29728 .2719 Mdot
.54854 .50975 Mdot
.44435 .19685 Mdot
.78831 .44473 Mdot
.49061 .85485 Mdot
.28551 .5876 Mdot
.61944 .50042 Mdot
.32328 .59578 Mdot
.68405 .37775 Mdot
.5325 .40505 Mdot
.51084 .32048 Mdot
.4762 .68577 Mdot
.59119 .31211 Mdot
.45995 .24656 Mdot
.34732 .59937 Mdot
.73891 .34458 Mdot
.77049 .64697 Mdot
.35159 .71492 Mdot
.48181 .44276 Mdot
.3055 .31237 Mdot
.29744 .55314 Mdot
.2604 .75903 Mdot
.78586 .29632 Mdot
.47497 .57835 Mdot
.43107 .45466 Mdot
.25142 .55063 Mdot
.49407 .39586 Mdot
.44112 .69571 Mdot
.66989 .72913 Mdot
.62549 .40153 Mdot
.5262 .35257 Mdot
.64406 .23677 Mdot
.75954 .51672 Mdot
.26611 .49319 Mdot
.71454 .3354 Mdot
.81793 .34358 Mdot
.30166 .74825 Mdot
.74762 .54212 Mdot
.31665 .80764 Mdot
.52345 .22335 Mdot
.56192 .60264 Mdot
.53609 .81388 Mdot
.8382 .51107 Mdot
.25023 .58773 Mdot
.35851 .27631 Mdot
.81212 .48804 Mdot
.27638 .57392 Mdot
.30888 .67302 Mdot
.66652 .30993 Mdot
.58634 .26071 Mdot
.51915 .47456 Mdot
.30907 .37443 Mdot
.75339 .32066 Mdot
.58094 .66525 Mdot
.77853 .62795 Mdot
.40471 .2495 Mdot
.23776 .28023 Mdot
.77666 .68194 Mdot
.32737 .52188 Mdot
.38562 .31857 Mdot
.52245 .81585 Mdot
.21053 .53353 Mdot
.35278 .69403 Mdot
.32574 .27033 Mdot
.54049 .76306 Mdot
.28264 .36439 Mdot
.42757 .22055 Mdot
.30004 .63547 Mdot
.39627 .74398 Mdot
.61208 .50339 Mdot
.63136 .73763 Mdot
.64019 .29362 Mdot
.25521 .61245 Mdot
.51133 .34511 Mdot
.21466 .51267 Mdot
.63452 .74869 Mdot
.57874 .80635 Mdot
.64004 .51655 Mdot
.33868 .17923 Mdot
.81452 .54294 Mdot
.47946 .20232 Mdot
.41219 .54442 Mdot
.81336 .62873 Mdot
.64309 .51089 Mdot
.81739 .50864 Mdot
.38803 .80054 Mdot
.50256 .29507 Mdot
.7294 .4075 Mdot
.41233 .54995 Mdot
.77175 .59706 Mdot
.60725 .71088 Mdot
.40644 .75345 Mdot
.37546 .2567 Mdot
.25864 .59043 Mdot
.39191 .29609 Mdot
.22933 .49881 Mdot
.49003 .64694 Mdot
.62624 .57012 Mdot
.83355 .40034 Mdot
.5533 .51801 Mdot
.43894 .51429 Mdot
.4122 .66569 Mdot
.26454 .29106 Mdot
.22934 .68982 Mdot
.3911 .65452 Mdot
.69132 .28113 Mdot
.29868 .6731 Mdot
.36562 .51545 Mdot
.56964 .64362 Mdot
.08989 .522 Mdot
.58986 .85553 Mdot
.61809 .64211 Mdot
.39703 .70808 Mdot
.2445 .62486 Mdot
.8397 .5227 Mdot
.33534 .37353 Mdot
.46329 .26934 Mdot
.19734 .37618 Mdot
.21064 .54932 Mdot
.46247 .63568 Mdot
.40512 .82072 Mdot
.74277 .70648 Mdot
.38642 .2479 Mdot
.79359 .64067 Mdot
.483 .53575 Mdot
.37077 .5947 Mdot
.13984 .62216 Mdot
.71658 .70088 Mdot
.43635 .52717 Mdot
.26818 .2834 Mdot
.57198 .61423 Mdot
.41444 .57387 Mdot
.69237 .32486 Mdot
.28431 .68045 Mdot
.30484 .63939 Mdot
.83711 .55449 Mdot
.57787 .60713 Mdot
.47589 .25085 Mdot
.62929 .39216 Mdot
.5873 .50153 Mdot
.38056 .63358 Mdot
.66618 .41972 Mdot
.3574 .51382 Mdot
.67636 .53629 Mdot
.66492 .37221 Mdot
.24061 .65324 Mdot
.48468 .87856 Mdot
.59951 .75467 Mdot
.64054 .35947 Mdot
.33671 .59188 Mdot
.38994 .75273 Mdot
.31121 .50933 Mdot
.42922 .48974 Mdot
.46639 .85367 Mdot
.69999 .8124 Mdot
.56645 .28901 Mdot
.35957 .65432 Mdot
.61128 .55893 Mdot
.50046 .66986 Mdot
.64216 .70916 Mdot
.60448 .43579 Mdot
.4453 .30322 Mdot
.4827 .6324 Mdot
.4927 .64541 Mdot
.61377 .41683 Mdot
.74352 .24987 Mdot
.41086 .6242 Mdot
.55948 .64395 Mdot
.66267 .77818 Mdot
.33363 .27932 Mdot
.49736 .7979 Mdot
.41545 .64116 Mdot
.75834 .39345 Mdot
.62673 .49723 Mdot
.71691 .60516 Mdot
.42132 .25928 Mdot
.81603 .58076 Mdot
.56871 .773 Mdot
.65113 .67798 Mdot
.41938 .61817 Mdot
.32882 .46343 Mdot
.6924 .49212 Mdot
.81599 .47998 Mdot
.53943 .59756 Mdot
.68086 .77055 Mdot
.49865 .29452 Mdot
.60458 .3166 Mdot
.38431 .51214 Mdot
.84151 .45479 Mdot
.40944 .21509 Mdot
.62549 .69929 Mdot
.55148 .18149 Mdot
.59298 .22208 Mdot
.29153 .51235 Mdot
.49571 .36283 Mdot
.36721 .55207 Mdot
.57527 .59926 Mdot
.83342 .36004 Mdot
.81422 .4692 Mdot
.57624 .4002 Mdot
.58036 .27575 Mdot
.55549 .69502 Mdot
.61531 .514 Mdot
.39586 .85961 Mdot
.36094 .38733 Mdot
.81333 .33446 Mdot
.33686 .7176 Mdot
.69909 .65465 Mdot
.69875 .53071 Mdot
.52601 .60079 Mdot
.4713 .36519 Mdot
.83345 .54045 Mdot
.50325 .63876 Mdot
.46303 .22189 Mdot
.44398 .63866 Mdot
.60559 .19536 Mdot
.55815 .41262 Mdot
.64713 .31951 Mdot
.65838 .33207 Mdot
.34826 .22813 Mdot
.62588 .78693 Mdot
.59567 .46602 Mdot
.35089 .82306 Mdot
.7075 .68299 Mdot
.74148 .69375 Mdot
.37382 .29741 Mdot
.40056 .18603 Mdot
.78284 .55708 Mdot
.72956 .57586 Mdot
.57153 .40914 Mdot
.38943 .47514 Mdot
.56335 .20096 Mdot
.35684 .51946 Mdot
.71095 .483 Mdot
.68836 .38715 Mdot
.7923 .75211 Mdot
.33276 .52616 Mdot
.53206 .55098 Mdot
.50045 .21641 Mdot
.76317 .67039 Mdot
.34949 .44778 Mdot
.43107 .84256 Mdot
.41858 .44946 Mdot
.36939 .59836 Mdot
.56335 .76388 Mdot
.34389 .71114 Mdot
.59131 .2049 Mdot
.45306 .14018 Mdot
.30869 .75059 Mdot
.59342 .29908 Mdot
.56592 .48081 Mdot
.66961 .59607 Mdot
.65955 .65121 Mdot
.314 .34856 Mdot
.38201 .82308 Mdot
.67607 .53011 Mdot
.71559 .69573 Mdot
.38071 .17268 Mdot
.35273 .7437 Mdot
.84179 .52485 Mdot
.79342 .51297 Mdot
.69182 .6234 Mdot
.32876 .5068 Mdot
.24139 .44156 Mdot
.62855 .34137 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0;Sooooo0_l0002?ooooo`007?ooool00ol0003oooooooooo`2hooooo`;o0000Soooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo08oooooo0_l0000Aooooo`;o0000YOooool001cooooo00?o0000oooo
ooooool0Soooool2o`0000;ooooo0_l0000=ooooo`;o00000_ooool2o`0000?ooooo0_l0002Loooo
o`007?ooool00ol0003oooooooooo`2Cooooo`;o00004Oooool2o`0000?ooooo0_l0002Looooo`00
7?ooool00ol0003oooooooooo`2Zooooo`;o0000WOooool001cooooo0_l0002[ooooo`;o0000WOoo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo07kooooo0_l00003ooooo`;o0000a?ooool001cooooo
00?o0000ooooooooool0O_ooool2o`0000?ooooo0_l00034ooooo`007?ooool00ol0003ooooooooo
o`2]ooooo`;o000000?oooooo`000?l000002?ooool2o`0008gooooo000Looooo`03o`000?oooooo
oooo07[ooooo0_l0000aooooo`;o000000?oooooo`000?l000002?ooool2o`0000[ooooo0_l00021
ooooo`007?ooool00ol0003oooooooooo`1hooooo`Co0000B_ooool2o`00087ooooo000Looooo`03
o`000?oooooooooo07Sooooo0_l0000Hooooo`;o00002?ooool2o`0000?ooooo0_l0002Vooooo`00
7?ooool00ol0003oooooooooo`1Zooooo`;o00009Oooool7o`0000Cooooo0_l00003ooooo`;o0000
3?ooool2o`0001oooooo0_l0001gooooo`007?ooool00ol0003oooooooooo`1Zooooo`;o00009Ooo
ool2o`000003ooooool0003o000000;o000000?oooooo`000?l000003_ooool2o`0000Cooooo0_l0
0005ooooo`;o00000oooool2o`0000Sooooo0_l00009ooooo`;o00001?ooool2o`00077ooooo000L
ooooo`03o`000?oooooooooo07kooooo0_l00009ooooo`;o00003?ooool6o`0000Cooooo0_l00002
ooooo`;o00000_ooool2o`0000Wooooo1?l00002ooooo`Co00001oooool2o`0000oooooo0_l0001a
ooooo`007?ooool00ol0003oooooooooo`1nooooo`;o00001Oooool2o`0000;ooooo0_l0000<oooo
o`;o000000?oooooo`000?l000000ol000001?oooooo0000o`000?l00002ooooo`;o00002oooool4
o`0000Cooooo1?l0002;ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?oo
ool5o`0000Kooooo00?o0000ooooooooool0H_ooool2o`0000Kooooo0_l0000Eooooo`;o00000_oo
ool2o`0001Gooooo1_l0000<ooooo`;o00000_ooool2o`0000Cooooo0_l0000Booooo`;o0000Nooo
ool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A006ooooo`03o`000?oooooooooo06;ooooo0_l00006ooooo`;o00005Oooool2o`0000Go
oooo0_l00003ooooo`;o00001?ooool2o`0000Gooooo0_l000000ooooooo0000o`000003o`0000Wo
oooo1Ol00003ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o00000_ooool2o`0000Wo
oooo0_l0001kooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0N_ooool2o`0000cooooo0_l00003ooooo`;o0000
1?ooool2o`0000Gooooo1Ol000000ooooooo0000o`000002ooooo`;o00001Oooool4o`0000Cooooo
0_l000000ooooooo0000o`000005ooooo`;o00000_ooool2o`0001Cooooo0_l0001`ooooo`0000?o
ooooo`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0
001jooooo`?o00003_ooool2o`0000Sooooo0_l000001?oooooo0000o`000?ooool2o`0000Oooooo
0_l00002ooooo`;o00001Oooool2o`0000;ooooo0_l00003ooooo`;o00001Oooool5o`0000Wooooo
0_l00008ooooo`;o0000L?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?oo
ool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo07_ooooo0_l00007ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0000Sooooo0_l000000ooooooo0000o`000002ooooo`;o000000?o
ooooo`000?l000000_ooool2o`000003ooooool0003o000000;o00000oooool4o`0000;ooooo0_l0
0003ooooo`;o00000_ooool2o`000003ooooool0003o000000?o00000_ooool2o`0000Gooooo0_l0
001jooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0LOooool2o`0000gooooo0ol000001?oooooo0000o`000?oo
ool2o`0001?ooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000_l0
0002ooooo`?o00003Oooool2o`0000Kooooo1?l00021ooooo`0000KoooooogMgMonHV9SooooooiRH
V?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`1Sooooo`;o
00003?ooool2o`0000gooooo0ol00006ooooo`;o00001_ooool2o`0000[ooooo0ol00007ooooo`;o
00000oooool2o`0001Kooooo0_l00007ooooo`;o0000N_ooool00006ooooooo^k^ko<S8bo`000?lb
<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0E_ooool2
o`0000_ooooo0_l0000Fooooo`;o00001?ooool4o`0000Cooooo0_l00006ooooo`;o00001_ooool2
o`0000;ooooo0ol00007ooooo`;o00000oooool2o`000003ooooool0003o000001?ooooo0_l00004
ooooo`;o000000?oooooo`000?l00000N_ooool001cooooo00?o0000ooooooooool0E_ooool2o`00
01Oooooo0_l00006ooooo`So00000_ooool4o`0000Wooooo0_l000000ooooooo0000o`000006oooo
o`;o00000oooool3o`0000_ooooo0_l000000ooooooo0000o`00000Cooooo`;o00000oooool3o`00
00;ooooo0_l0001iooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o00003oooool2o`0000Ko
oooo1Ol000000ooooooo0000o`000008ooooo`;o00001Oooool2o`000003ooooool0003o000000;o
00000_ooool5o`0000?ooooo0_l0000Xooooo`Oo00007oooool2o`0005Sooooo000Looooo`03o`00
0?oooooooooo05kooooo0_l00002ooooo`;o00004_ooool2o`0000;ooooo0_l0000;ooooo`;o0000
2_ooool3o`000003ooooool0003o000000?o00002_ooool3o`0001Cooooo0_l0000<ooooo`Oo0000
00?oooooo`000?l000006_ooool2o`0005Sooooo000Looooo`03o`000?oooooooooo06;ooooo0_l0
0009ooooo`;o00001oooool2o`0001;ooooo0_l00007ooooo`?o000000?oooooo`000?l000000_oo
ool2o`0000Wooooo0ol0000Dooooo`;o00003?ooool7o`000003ooooool0003o000007Cooooo000L
ooooo`03o`000?oooooooooo05[ooooo0_l0000Aooooo`;o00001Oooool2o`0000oooooo0_l00003
ooooo`;o00001Oooool2o`0000Cooooo0_l00002ooooo`Co00005?ooool2o`0000?ooooo0_l0000A
ooooo`?o00001Oooool4o`0007;ooooo000Looooo`03o`000?oooooooooo05[ooooo0_l00008oooo
o`;o00001Oooool4o`0000Gooooo0_l0000?ooooo`;o00002_ooool2o`0000[ooooo0_l00004oooo
o`;o000000?oooooo`000?l000000oooool2o`0000Kooooo0_l00003ooooo`;o00006Oooool4o`00
07;ooooo000Looooo`03o`000?oooooooooo05_ooooo0_l00003ooooo`;o00000_ooool2o`0000Go
oooo1?l0000]ooooo`;o00001Oooool2o`000003ooooool0003o000000?ooooo0_l0000;ooooo`;o
00003?ooool2o`0000Cooooo1?l0001iooooo`007?ooool00ol0003oooooooooo`1Kooooo`;o0000
0oooool2o`0000Kooooo0_l00007ooooo`;o00006_ooool2o`0000gooooo0ol0000Iooooo`;o0000
2oooool3o`0000Cooooo1?l0001iooooo`007?ooool00ol0003oooooooooo`1Qooooo`;o00001Ooo
ool2o`0000Oooooo0_l0000Jooooo`;o00003_ooool2o`0000[ooooo0_l0000=ooooo`;o00002ooo
ool2o`0000;ooooo1Ol0000Looooo`;o0000GOooool001cooooo00?o0000ooooooooool0HOooool2
o`0000Gooooo0_l0000aooooo`Go000000?oooooo`000?l000001_ooool3o`0000cooooo0_l0000?
ooooo`Go00000oooool6o`0000;ooooo0_l0000=ooooo`Co0000GOooool001cooooo00?o0000oooo
ooooool0N_ooool2o`0001Kooooo0_l00005ooooo`Oo000000?oooooo`000?l000001oooool2o`00
0004ooooool0003o0000o`0000Sooooo0_l0000Dooooo`;o000000?oooooo`000?l000001?l00002
ooooo`;o00003Oooool2o`0005oooooo000Looooo`;o0000M?ooool2o`0000Gooooo0_l00004oooo
o`;o00004?ooool2o`0000?ooooo1?l00002ooooo`;o00003?ooool5o`0001Kooooo0_l00006oooo
o`;o00001_ooool2o`0000?ooooo0_l0000Aooooo`;o0000FOooool001cooooo00?o0000oooooooo
ool0GOooool2o`0000?ooooo0_l0000?ooooo`;o00000oooool2o`0000Gooooo1?l000000ooooooo
0000o`00000<ooooo`;o00000oooool4o`00013ooooo0ol0000Hooooo`;o00003_ooool2o`0000?o
oooo0_l0000:ooooo`Co00000oooool2o`0005Wooooo000Looooo`03o`000?oooooooooo05gooooo
0_l00002ooooo`Co00002Oooool2o`0000Kooooo1?l000000ooooooo0000o`000002ooooo`Co0000
00Coooooo`000?l0003ooooo0_l00004ooooo`;o00000oooool5o`0000_ooooo0_l00003ooooo`;o
00003oooool2o`0000Oooooo0_l000000ooooooo0000o`00000Qooooo`Co0000G_ooool001cooooo
00?o0000ooooooooool0GOooool2o`0000;ooooo1?l00003ooooo`;o00001?ooool2o`0000Kooooo
0_l000000ooooooo0000o`000002o`0000?ooooo0_l00003ooooo`Go00000oooool2o`0000Cooooo
1?l00004ooooo`Co00000oooool2o`0000?ooooo0_l0000?ooooo`;o000000?oooooo`000?l00000
1?ooool2o`000003ooooool0003o000002Gooooo0_l0001Looooo`007?ooool00ol0003ooooooooo
o`1@ooooo`;o00001?ooool2o`0000Gooooo0_l00005ooooo`;o00000_ooool3o`0000Cooooo0_l0
00000ooooooo0000o`000005ooooo`;o00002_ooool2o`000003ooooool0003o000000Gooooo0_l0
000:ooooo`Co00000oooool3o`0000Gooooo0_l00006ooooo`;o00001oooool2o`000003ooooool0
003o0000013ooooo0_l0000Fooooo`;o000000?oooooo`000?l000002?ooool2o`0005;ooooo000L
ooooo`03o`000?oooooooooo053ooooo0_l000001?oooooo0000o`000?ooool2o`0000[ooooo1?l0
0003ooooo`Co00000_ooool2o`000003ooooool0003o000001_ooooo0_l0000Aooooo`?o00001Ooo
ool2o`0000Kooooo0_l0000:ooooo`;o00001oooool2o`0000Oooooo0_l00006ooooo`;o00003_oo
ool2o`0000_ooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00001Oooool2
o`0000Kooooo0_l00002ooooo`;o00000oooool2o`00013ooooo0_l00006ooooo`;o00003?ooool2
o`0000_ooooo0_l000000ooooooo0000o`00000Cooooo`;o00003Oooool2o`0000[ooooo0_l00003
ooooo`Co00004Oooool2o`0005[ooooo000Looooo`03o`000?oooooooooo04Wooooo0_l0000?oooo
o`;o000000?oooooo`000?l000001oooool2o`0001Gooooo0_l00002ooooo`;o000000Coooooo`00
0?l0003o00003?ooool2o`0000_ooooo0_l00003ooooo`;o00003?ooool2o`0000?ooooo0_l00000
0ooooooo0000o`000003ooooo`;o00004Oooool2o`000003ooooool0003o000000;ooooo0_l0000A
ooooo`;o0000F_ooool001cooooo00?o0000ooooooooool0BOooool2o`0000Gooooo0_l00008oooo
o`;o000000?oooooo`000?l000003Oooool2o`0000?ooooo0ol00002ooooo`?o00002?ooool2o`00
0003ooooool0003o000000Kooooo0_l00006ooooo`;o00003oooool4o`0000[ooooo0_l00002oooo
o`Ko00000oooool2o`0000Sooooo0_l000000ooooooo0000o`000007ooooo`?o00000oooool2o`00
06_ooooo000Looooo`03o`000?oooooooooo053ooooo0_l00002ooooo`;o00001oooool2o`0000Go
oooo0_l00003ooooo`;o000000?oooooo`000?l000000oooool3o`0000;ooooo0ol00006ooooo`Go
00002?ooool2o`0000Kooooo0_l00005ooooo`;o00002_ooool6o`0000Kooooo0_l00002ooooo`Co
00001_ooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000008ooooo`;o
00000oooool2o`0000?ooooo0_l0001Vooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o0000
2?ooool2o`0000kooooo0_l000000ooooooo0000o`000002o`0000kooooo0_l00002ooooo`Wo0000
00Coooooo`000?l0003o00004Oooool2o`0000_ooooo1Ol0000;ooooo`;o00001oooool7o`0000So
oooo0_l00005ooooo`;o00001?ooool2o`0000;ooooo0_l0000<ooooo`;o0000F?ooool001cooooo
00?o0000ooooooooool0B_ooool2o`0000Oooooo0_l00002ooooo`;o00001oooool2o`0000Gooooo
0ol0000?ooooo`;o00000_ooool=o`000004ooooool0003o0000o`0001;ooooo0_l00008ooooo`;o
00001_ooool4o`0000Oooooo0_l00004ooooo`Go00002?ooool4o`0000Kooooo0_l000000ooooooo
0000o`000002o`0000kooooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o0000
0_ooool2o`0000?ooooo0_l00002ooooo`;o00001oooool2o`0000oooooo1?l000000ooooooo0000
o`000002ooooo`Go00000_ooool6o`0000[ooooo0_l00004ooooo`Co00001_ooool2o`0000Kooooo
1?l00007ooooo`;o00002?ooool4o`0000Oooooo0_l00005ooooo`?o00000oooool2o`0000Sooooo
0_l0001Nooooo`007?ooool00ol0003oooooooooo`1Booooo`;o00002?ooool2o`0000_ooooo0_l0
000:ooooo`;o000000?oooooo`000?l000001?l0000<ooooo`So00002?ooool2o`0000Kooooo0_l0
0006ooooo`;o00002?ooool2o`00017ooooo1_l0000<ooooo`;o00000oooool2o`0000Kooooo0_l0
00000ooooooo0000o`00001Nooooo`007?ooool00ol0003oooooooooo`1Booooo`;o00006?ooool3
o`0000Kooooo1Ol00002ooooo`;o00001?ooool2o`0000Kooooo2?l0000<ooooo`?o00002Oooool2
o`00013ooooo0_l00008ooooo`Co000000Coooooo`000?l0003o00004?ooool6o`0000;ooooo0_l0
00000ooooooo0000o`000008ooooo`;o00001_ooool2o`0004cooooo000Looooo`03o`000?oooooo
oooo067ooooo0_l00009ooooo`?o00001_ooool5o`000004ooooool0003o0000o`0000Cooooo0_l0
0007ooooo`[o00002Oooool3o`0001Kooooo0_l00003ooooo`;o00002?ooool2o`000004ooooool0
003o0000ooooo`;o00004_ooool4o`0000;ooooo0_l000000ooooooo0000o`000008ooooo`;o0000
1_ooool4o`0004[ooooo000Looooo`;o0000DOooool4o`0000?ooooo0_l00008ooooo`;o00001ooo
ool2o`0000Wooooo0ol00003ooooo`?o00003_ooool9o`0000?ooooo0_l0000:ooooo`;o00004Ooo
ool2o`0000Cooooo0_l0000:ooooo`;o00006Oooool2o`0000?ooooo0_l00007ooooo`;o00001ooo
ool4o`0004[ooooo000Looooo`03o`000?oooooooooo053ooooo1?l00003ooooo`;o00000oooool3
o`0000;ooooo0_l00006ooooo`?o00002?ooool2o`0000cooooo0_l00008ooooo`Oo00001Oooool4
o`0000Sooooo0_l0000Dooooo`;o000000?oooooo`000?l000003oooool3o`0000cooooo0_l00005
ooooo`;o00000oooool2o`0000Oooooo0_l00008ooooo`?o0000B_ooool001cooooo00?o0000oooo
ooooool0C_ooool2o`0000Oooooo0_l000000ooooooo0000o`000003o`0000[ooooo0_l00008oooo
o`?o00001?ooool2o`0000Kooooo0_l00002ooooo`;o00000oooool7o`000003ooooool0003o0000
00?o00000_ooool2o`0001kooooo0_l00002ooooo`;o00001Oooool2o`0000Oooooo0ol00006oooo
o`;o00001?ooool2o`0000Gooooo0_l00003ooooo`;o00004Oooool3o`0004[ooooo000Looooo`03
o`000?oooooooooo04cooooo1?l0000:ooooo`;o00005oooool2o`0000Gooooo0_l00006ooooo`?o
000000?oooooo`000?l000000_ooool?o`00017ooooo0_l0000Booooo`;o000000Coooooo`000?l0
003ooooo0ol00007ooooo`?o00001?ooool5o`0000gooooo0_l0001Pooooo`007?ooool00ol0003o
ooooooooo`1<ooooo`;o00002?ooool2o`0000Sooooo0_l0000;ooooo`;o00004oooool5o`0000?o
oooo4?l0000@ooooo`;o00004?ooool2o`0000?ooooo0_l000000ooooooo0000o`000005ooooo`;o
000000Coooooo`000?l0003o00001?ooool5o`0000?ooooo0_l00008ooooo`;o00003?ooool2o`00
05;ooooo000Looooo`03o`000?oooooooooo05Kooooo0_l00008ooooo`;o00002oooool2o`0001?o
oooo0_l000000ooooooo0000o`000003oooooa7o00003oooool2o`00013ooooo0_l00003ooooo`;o
00001Oooool2o`000003ooooool0003o000000?ooooo0_l00003ooooo`Co00001?ooool2o`0000[o
oooo0_l0000:ooooo`;o00002Oooool2o`0004Oooooo000Looooo`03o`000?oooooooooo07;ooooo
0_l00006ooooo`;o00001_ooool4o`0000Cooooo1?l000000ooooooo0000o`000007o`000004oooo
ool0003o0000o`0000Wooooo0_l00003ooooo`;o00005Oooool2o`0000Gooooo0_l00004ooooo`Co
00005oooool2o`0000Cooooo0ol0000>ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0
Boooool2o`0000[ooooo0_l0000:ooooo`;o00003?ooool3o`0000Kooooo0_l00005ooooo`;o0000
00?oooooo`000?l000000oooool4o`000003ooooool0003o000000co00001_ooool2o`000004oooo
ool0003o0000o`0002Kooooo0_l00002ooooo`;o00002Oooool2o`0000Kooooo0_l00008ooooo`Co
0000E_ooool001cooooo00?o0000ooooooooool0Boooool2o`0000[ooooo0_l00003ooooo`;o0000
1Oooool2o`0000cooooo0_l00003ooooo`;o00002Oooool2o`0000Kooooo4ol00006ooooo`;o0000
0_ooool2o`0000Cooooo0_l00005ooooo`;o00004oooool2o`0000Sooooo0_l00003ooooo`;o0000
0_ooool4o`0000Kooooo1Ol00007ooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0@ooo
ool2o`0000kooooo0_l00007ooooo`?o00001?ooool2o`00017ooooo0_l00009ooooo`;o00001Ooo
oolGo`0000gooooo0_l00005ooooo`;o00002oooool2o`0000;ooooo0_l00002ooooo`;o00000_oo
ool2o`0000Wooooo0_l00002ooooo`Co00001?ooool2o`000003ooooool0003o000000Co00005_oo
ool2o`0004Gooooo000Looooo`03o`000?oooooooooo04?ooooo0_l0000>ooooo`;o00001oooool3
o`0000Gooooo0_l00009ooooo`;o00000oooool4o`000003ooooool0003o000000Oooooo0_l00004
ooooo`?o000000?oooooo`000?l000001ol000000ooooooo0000o`000007o`0000[ooooo0_l0000E
ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0000;ooooo1?l000000ooooooo0000o`00
0004o`0000;ooooo0_l00008ooooo`;o00000oooool4o`0001Kooooo0_l00004ooooo`;o0000?ooo
ool001cooooo00?o0000ooooooooool0D?ooool2o`0001;ooooo0_l00009ooooo`;o00000oooool2
o`0000?ooooo0_l00007ooooo`;o00001?oooolFo`0000;ooooo0_l00007ooooo`;o00001_ooool2
o`00013ooooo0_l00007ooooo`Co000000?oooooo`000?l000001?l00002ooooo`;o00002Oooool2
o`0000Kooooo0_l00004ooooo`;o00004?ooool2o`0000;ooooo0_l0000oooooo`007?ooool00ol0
003oooooooooo`14ooooo`;o00002_ooool2o`0000Gooooo0_l00008ooooo`;o00003?ooool2o`00
00Gooooo0_l000000ooooooo0000o`000002o`0000[ooooo0ol000000ooooooo0000o`000009o`00
00;ooooo1_l00002ooooo`;o00003oooool2o`00017ooooo0_l00004ooooo`Co000000?oooooo`00
0?l000001_l0000=ooooo`;o00001_ooool2o`0000Cooooo0_l0000@ooooo`;o0000@oooool001co
oooo00?o0000ooooooooool0A?ooool2o`00017ooooo0_l00008ooooo`;o00003?ooool2o`0000Go
oooo0_l00003ooooo`;o00002_ooool@o`000003ooooool0003o000000Co00006?ooool2o`000003
ooooool0003o000000Sooooo0ol00002ooooo`Go00000_ooool7o`0000Gooooo0_l0001/ooooo`00
7?ooool00ol0003oooooooooo`24ooooo`;o00000_oooolFo`0001Cooooo0_l00002ooooo`;o0000
00Coooooo`000?l0003ooooo0_l00004ooooo`?o000000?oooooo`000?l000001ol00003ooooo`Go
00001?ooool2o`0000oooooo0_l0000<ooooo`;o00002_ooool2o`0000Wooooo0_l0000fooooo`00
7?ooool00ol0003oooooooooo`1cooooo`;o00003oooool2o`0000;ooooo5ol00003ooooo`;o0000
3_ooool2o`0000Sooooo0_l00002ooooo`Co000000?oooooo`000?l000000ol00003ooooo`;o0000
1?ooool4o`0000?ooooo0_l0000;ooooo`;o00000_ooool3o`0000cooooo0_l0000:ooooo`;o0000
2Oooool2o`0003Kooooo000Looooo`;o0000Aoooool2o`0001[ooooo0_l00009ooooo`;o00001?oo
ool2o`0000?ooooo0_l00004ooooo`;o00002OoooolFo`0000?ooooo0_l0000=ooooo`Co00002_oo
ool8o`0000cooooo0_l00004ooooo`?o00002oooool2o`0000;ooooo0_l00002ooooo`;o0000F?oo
ool001cooooo00?o0000ooooooooool0?Oooool2o`0000Oooooo0_l00007ooooo`;o00004Oooool2
o`0000Gooooo0_l00002ooooo`;o00002Oooool2o`0000Cooooo0_l00009oooooaKo00000oooool2
o`0000?ooooo0_l00008ooooo`Co00002_ooool7o`0001?ooooo0_l0000=ooooo`;o00001Oooool2
o`0000Kooooo0ol0000<ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0?Oooool3o`00
00cooooo0_l000000ooooooo0000o`00000Booooo`;o00001?ooool2o`0001Kooooo0_l00006oooo
oaKo000000?oooooo`000?l000001Oooool2o`0001Kooooo1Ol00009ooooo`;o000000?oooooo`00
0?l000001oooool3o`0000Cooooo0_l00006ooooo`;o00002_ooool2o`000004ooooool0003o0000
o`0000cooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0mooooo`?o00003?ooool2o`00
01Gooooo0_l0000Looooo`;o00001ooooolEo`000003ooooool0003o000000Co00000oooool2o`00
01;ooooo1_l00009ooooo`?o000000?oooooo`000?l000001oooool3o`0000Cooooo0_l00004oooo
o`Go00001_ooool2o`000003ooooool0003o000001Gooooo0_l0000looooo`007?ooool00ol0003o
ooooooooo`0jooooo`;o000000?oooooo`000?l000003Oooool2o`0002oooooo0_l0000;oooooaGo
000000?oooooo`000?l000001?l00003ooooo`;o00003oooool7o`0000_ooooo0_l0000<ooooo`;o
00000_ooool2o`0000Kooooo1Ol00003ooooo`Ko00000oooool2o`0000?ooooo0_l0000=ooooo`;o
0000??ooool001cooooo00?o0000ooooooooool0>_ooool2o`0001cooooo0_l0000Sooooo`;o0000
1_ooool2o`0000?ooooo1Ol00002ooooo`ko00004?ooool4o`000003ooooool0003o000000;ooooo
2?l0000Aooooo`;o00000oooool2o`0000Kooooo0_l00008ooooo`;o00001?ooool3o`000003oooo
ool0003o000000?ooooo0_l00003ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0;?oo
ool2o`0002[ooooo0_l0000[ooooo`;o00000_oooolDo`000003ooooool0003o000000oooooo1?l0
00000ooooooo0000o`000007o`0000Sooooo0_l00008ooooo`Co00000oooool2o`0003;ooooo0_l0
000mooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o0000>Oooool2o`00013ooooo0_l00009
ooooo`Co000000?oooooo`000?l000005Ol0000<ooooo`;o00001oooool7o`0000?ooooo0_l00004
ooooo`;o00000oooool2o`0000?ooooo1?l000000ooooooo0000o`000004o`00017ooooo0_l0000:
ooooo`;o00004Oooool4o`0003_ooooo000Looooo`03o`000?oooooooooo063ooooo0ol00004oooo
o`Co00003_ooool2o`000003ooooool0003o000000Kooooo1?l00003oooooaCo00002Oooool2o`00
00;ooooo0_l00008ooooo`Co00001Oooool2o`0000Kooooo3?l000000ooooooo0000o`000002oooo
o`;o00003oooool4o`0000?ooooo0_l00005ooooo`Go00002?ooool2o`0000Cooooo1?l0000koooo
o`007?ooool00ol0003oooooooooo`0dooooo`;o00001_ooool2o`00013ooooo0_l0000@ooooo`?o
00001_ooool2o`0000kooooo0_l000000ooooooo0000o`00000:ooooo`;o000000?oooooo`000?l0
00004_l00008ooooo`?o00003?ooool3o`0000_ooooo0_l000000ooooooo0000o`00000<o`0000Go
oooo0_l0000=ooooo`;o00001Oooool2o`0000Oooooo0ol00008ooooo`;o00001?ooool2o`0003go
oooo000Looooo`03o`000?oooooooooo03Cooooo0_l00006ooooo`;o00004?ooool2o`0000[ooooo
0_l0000Mooooo`;o00002_ooool2o`000003ooooool0003o000000?ooooo3_l000000ooooooo0000
o`000009ooooo`;o00002oooool2o`0000Gooooo0_l00007ooooo`;o000000?oooooo`000?l00000
3ol00002ooooo`;o00001oooool2o`0000Sooooo0_l0000Dooooo`;o0000A?ooool001cooooo00?o
0000ooooooooool0Eoooool2o`000003ooooool0003o000000Kooooo0_l0000=ooooo`;o00004_oo
ool2o`0000Oooooo3Ol000000ooooooo0000o`000002o`0001;ooooo1?l00005ooooo`;o00002_oo
oolAo`0000_ooooo0_l00002ooooo`;o00001?ooool4o`0001;ooooo0_l00014ooooo`007?ooool0
0ol0003oooooooooo`0[ooooo`;o0000:_ooool2o`0000Wooooo0_l0000=ooooo`?o00002?ooool2
o`00017ooooo4_l00004ooooo`;o00001Oooool2o`0000;ooooo1Ol0000:ooooo`;o00001Oooool4
o`000003ooooool0003o000000go00000_ooool2o`0000Wooooo0_l00004ooooo`Co00001?ooool2
o`0001;ooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o00003Oooool4o`00
03Cooooo0_l00008ooooo`;o00004Oooool;o`000003ooooool0003o000000Ko00000_ooool2o`00
00Gooooo0_l000000ooooooo0000o`000003o`0000Cooooo0_l00005ooooo`;o00000ooooolJo`00
00[ooooo1?l000000ooooooo0000o`000006ooooo`;o00004_ooool2o`0003kooooo00001_oooooo
k^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool0
0ol0003oooooooooo`0gooooo`;o000000?oooooo`000?l000000_l0001;ooooo`;o00001OoooolF
o`0000Sooooo1?l00003ooooo`Go00001Oooool2o`0000;ooooo5_l000000ooooooo0000o`000004
ooooo`;o00001_ooool4o`0000Oooooo0_l00009ooooo`?o0000B?ooool00006oooooomgMgOoV9RH
oooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0gooooo`;o0000D?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000?o`000003ooooool0
003o000000;o00001Oooool6o`0000Cooooo0ol00006ooooo`Oo000000?oooooo`000?l000005?l0
0004ooooo`;o000000?oooooo`000?l000002Oooool2o`0000?ooooo1?l00005ooooo`Go0000B?oo
ool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo00?o0000
ooooooooool0>Oooool2o`0003Sooooo0_l0000Hooooo`;o00001?ooool<o`000003ooooool0003o
000000Go00000_ooool6o`0000Oooooo0ol00005oooooaoo00001Oooool3o`0000;ooooo0_l00002
ooooo`;o000000?oooooo`000?l000000oooool4o`0000Gooooo0_l00004ooooo`;o0000AOooool0
0003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?m4A4CogMgMooooool00007
ooooo`?o0000>Oooool2o`0001gooooo0_l00007ooooo`;o00004?ooool2o`00017ooooo1?l0000;
ooooo`[o000000?oooooo`000?l000003_l00007ooooo`;o00002OoooolLo`0000Cooooo0_l00002
ooooo`?o00000_ooool3o`0000Kooooo0_l0000<ooooo`;o00001oooool2o`0003cooooo00000ooo
oooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo00001oooool0
0ol0003oooooooooo`0fooooo`;o00006oooool4o`000003ooooool0003o000000;o00001Oooool2
o`00017ooooo0_l0000@ooooo`Co00002ooooolAo`000003ooooool0003o000000Co000000?ooooo
o`000?l000000oooool2o`0000;ooooo0ol00008oooooaco00002?ooool2o`000004ooooool0003o
0000ooooo`;o00001_ooool2o`0000Gooooo0_l0000>ooooo`;o0000??ooool00003ooooool@413o
oooo00;ooooo00?o410@ooooooooool02_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooo
oooo03Kooooo0_l0000Kooooo`Co00000oooool2o`0001Sooooo1?l0000Pooooo`_o00000oooool6
o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o00001?oooolH
o`000003ooooool0003o000000;o00002?ooool2o`00013ooooo1?l0001:ooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0=ooo
ool2o`0001cooooo0_l00006ooooo`?o00000_ooool2o`00017ooooo0ol0000Looooo`;o00000_oo
ool<o`000003ooooool0003o000000?o00001?ooool2o`0000Kooooo0_l00006ooooo`;o00001?oo
oolMo`0000Sooooo1?l00004ooooo`;o00002?ooool4o`0000;ooooo0_l00016ooooo`0000Kooooo
onk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0
;oooool2o`0000Kooooo0_l0000Hooooo`Oo000000?oooooo`000?l000001Ol00002ooooo`?o0000
7_ooool2o`0000oooooo0_l00003ooooo`;o00000_ooool7o`000003ooooool0003o000000_ooooo
0_l00004ooooo`;o00002_oooolFo`000004ooooool0003o0000o`0000gooooo1?l00002ooooo`;o
00002_ooool2o`0000;ooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o0000
8?ooool4o`000003ooooool0003o000000go000000?oooooo`000?l000004?ooool2o`0000;ooooo
0_l00005ooooo`;o00002?ooool2o`0000?ooooo0_l00005ooooo`;o00001_ooool2o`0000;ooooo
0_l0000;ooooo`;o00001?ooool2o`0000Wooooo6ol00003ooooo`;o000000?oooooo`000?l00000
1oooool2o`0000[ooooo0_l00002ooooo`;o00004Oooool2o`0003Oooooo000Looooo`03o`000?oo
oooooooo03kooooo0_l0000:ooooo`;o00001_ooool3o`0000;ooooo3?l000000ooooooo0000o`00
0002o`0000Gooooo0ol00008ooooo`;o00000_ooool2o`0000oooooo0_l00003ooooo`?o00003ooo
ool2o`0000?ooooo0_l0000Aooooo`;o00001OoooolJo`0000Cooooo0_l000000ooooooo0000o`00
000?ooooo`;o00000_ooool2o`0000_ooooo1_l00004ooooo`Co0000=Oooool001cooooo00?o0000
ooooooooool0<?ooool2o`0000cooooo0_l0000:ooooo`;o00001ooooolEo`0000Gooooo0ol0000<
ooooo`;o00004oooool4o`0000gooooo1?l00002ooooo`?o00001?ooool2o`0000Gooooo0_l00004
ooooo`;o00001oooool<o`000003ooooool0003o000000Wo00006?ooool2o`0000oooooo1_l00006
ooooo`;o0000=Oooool001cooooo00?o0000ooooooooool0<?ooool2o`0001Wooooo0_l00005oooo
oaKo00003_ooool2o`0000;ooooo1?l0000Cooooo`;o000000?oooooo`000?l000003?ooool2o`00
00Cooooo0_l00005ooooo`;o00001Oooool2o`0000[ooooo0_l000000ooooooo0000o`00000Do`00
02gooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o00001?oooolGo`0000ko
oooo1_l0000;ooooo`;o00002oooool2o`0000;ooooo0_l00007ooooo`;o00005_ooool2o`0000Oo
oooo0_l000000ooooooo0000o`00000Eo`00017ooooo0_l00007ooooo`;o0000DOooool001cooooo
00?o0000ooooooooool0;_ooool2o`0001Sooooo1Ol00002ooooo`oo000000?oooooo`000?l00000
2?l0000>ooooo`Go00002oooool2o`0000?ooooo0_l00007ooooo`Go00000oooool2o`0000;ooooo
0_l00003ooooo`;o000000?oooooo`000?l000002?ooool2o`0000Cooooo0ol000000ooooooo0000
o`000002ooooo`;o00000_oooolGo`00017ooooo0_l00007ooooo`Co00003_ooool2o`0003oooooo
000Looooo`03o`000?oooooooooo02kooooo0_l00009ooooo`;o00003Oooool5o`000005ooooool0
003o0000o`000?ooool03?l000000ooooooo0000o`000009o`0002;ooooo0_l00007ooooo`Co0000
0oooool3o`0000Oooooo0_l000001?oooooo0000o`000?l00006ooooo`?o00001Oooool2o`000003
ooooool0003o000000;ooooo0_l00004oooooaCo000000?oooooo`000?l000003_ooool2o`0000[o
oooo0_l00007ooooo`;o00001Oooool2o`0003oooooo000Looooo`03o`000?oooooooooo03Wooooo
0_l0000>ooooo`So000000?oooooo`000?l000005_l0000Eooooo`;o00006oooool2o`0000cooooo
1?l00004ooooo`;o000000?oooooo`000?l000002?ooool4o`0000?ooooo6?l00003ooooo`;o0000
1?ooool2o`0000?ooooo1Ol0000;ooooo`;o00000oooool2o`0000?ooooo0_l00002ooooo`;o0000
0oooool2o`0003Sooooo000Looooo`03o`000?oooooooooo04_ooooo0ol000001?oooooo0000o`00
0?oooolGo`0001Kooooo0_l0000Hooooo`;o00003_ooool2o`000003ooooool0003o000000Oooooo
0_l00008ooooo`?o00001?ooool3o`000003ooooool0003o000000co00000_ooool3o`0000Cooooo
0_l000001?oooooo0000o`000?ooool2o`0000?ooooo1Ol0000:ooooo`?o00002?ooool2o`0000;o
oooo0_l00003ooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0@Oooool2o`000003oooo
ool0003o000000Gooooo0_l00005oooooaOo00003_ooool2o`0001;ooooo0_l0000<ooooo`;o0000
1?ooool2o`0000Sooooo0_l0000Kooooo`;o00000_ooool=o`0000[ooooo0_l000000ooooooo0000
o`000006ooooo`;o00003Oooool3o`0004_ooooo000Looooo`03o`000?oooooooooo03oooooo1?l0
00000ooooooo0000o`00000<oooooaSo00001?ooool2o`0000Oooooo0_l00006ooooo`;o000000?o
ooooo`000?l000000_l00005ooooo`;o00004_ooool2o`0002Kooooo4?l000000ooooooo0000o`00
000Rooooo`;o0000Boooool001cooooo0_l0000dooooo`;o00002_ooool2o`0000Sooooo0_l00004
ooooo`;o000000?oooooo`000?l000003Ol000000ooooooo0000o`000006o`0000Cooooo1?l0000=
ooooo`;o000000?oooooo`000?l000000_l00006ooooo`;o0000:_ooool4o`0000_ooooo3Ol00004
ooooo`;o00003?ooool2o`0000Kooooo0_l00004ooooo`;o00001?ooool4o`0000Cooooo0_l00015
ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00000oooool2o`0000Sooooo0_l00005oooo
o`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`[o000000?oooooo`000?l000002_l00005
ooooo`;o00003oooool4o`0000?ooooo0_l00002ooooo`;o00006?ooool2o`0000gooooo0_l00000
0ooooooo0000o`000002o`0000Gooooo0_l00007ooooo`So00003_ooool2o`0000Cooooo0_l00006
ooooo`;o00001?ooool2o`0000Cooooo1?l00004ooooo`;o00002_ooool2o`0003Wooooo000Loooo
o`03o`000?oooooooooo01oooooo0_l0000Gooooo`;o00001Oooool2o`000003ooooool0003o0000
00;o00001_ooool2o`0000Kooooo5ol0000Fooooo`Co000000?oooooo`000?l000000_l00007oooo
o`?o00000_ooool2o`0000Oooooo0_l00003ooooo`Co00002Oooool2o`0000;ooooo0_l000000ooo
oooo0000o`000007ooooo`;o00002Oooool2o`0001;ooooo0_l00006ooooo`;o00000_ooool2o`00
013ooooo0_l0000>ooooo`;o0000>Oooool001cooooo00?o0000ooooooooool07oooool2o`0000Ko
oooo0_l0000Cooooo`;o000000Coooooo`000?l0003ooooo1?l0000<ooooo`;o000000?oooooo`00
0?l000005?l0000:ooooo`;o00002oooool8o`0000Oooooo0ol00002ooooo`;o00001oooool2o`00
00?ooooo0_l0000;ooooo`;o00000_ooool4o`0002?ooooo0_l000000ooooooo0000o`000002o`00
00Gooooo1_l00009ooooo`;o00001Oooool2o`0000kooooo0ol0000hooooo`007?ooool00ol0003o
ooooooooo`0Wooooo`;o00004oooool2o`0001Cooooo0_l00002oooooa?o00002oooool4o`0000Ko
oooo0_l00004ooooo`?o00007Oooool2o`0000Wooooo0_l00006ooooo`;o00008oooool2o`000003
ooooool0003o000000;o00001_ooool3o`0000_ooooo1_l0000<ooooo`;o00000oooool3o`0000oo
oooo0_l0000Wooooo`007?ooool00ol0003oooooooooo`1Eooooo`ko00000_ooool4o`000003oooo
ool0003o000000Sooooo1?l00006ooooo`;o00001?ooool2o`0001?ooooo0_l0000Dooooo`;o0000
3Oooool2o`0000Cooooo0_l0000Gooooo`;o00006_ooool4o`0000cooooo0_l0000Eooooo`;o0000
9oooool001cooooo00?o0000ooooooooool09_ooool2o`0000?ooooo0_l0000Woooooa7o00001Ooo
ool2o`0000Sooooo0_l00006ooooo`;o00000oooool2o`0001Gooooo0ol000000ooooooo0000o`00
000Dooooo`;o00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`;o00001?oo
ool2o`0000cooooo0_l00003ooooo`;o000000?oooooo`000?l000006Oooool2o`0000Sooooo0_l0
0012ooooo`007?ooool00ol0003oooooooooo`0Vooooo`;o00000oooool2o`0001Oooooo0_l00000
0ooooooo0000o`00000;ooooo`;o000000?oooooo`000?l000000ol000000ooooooo0000o`000006
o`0000Kooooo0_l00007ooooo`;o00001_ooool2o`0000?ooooo0_l00004ooooo`;o00003oooool2
o`0000;ooooo0_l0000Dooooo`;o00000oooool2o`000004ooooool0003o0000o`0000Oooooo0_l0
0002ooooo`Co00003?ooool2o`0000Cooooo1?l0000Sooooo`;o00006?ooool2o`0002Sooooo000L
ooooo`03o`000?oooooooooo02Cooooo0_l000000ooooooo0000o`00000Kooooo`Go00003_ooool3
o`0000?ooooo0_l00003ooooo`?o00001_ooool2o`0000kooooo0ol00004ooooo`;o00000oooool2
o`0000oooooo0_l0000;ooooo`;o00003Oooool2o`0000Cooooo1?l00006ooooo`;o00000_ooool2
o`0000;ooooo0_l0000@ooooo`;o00004_ooool2o`0000Sooooo0_l0000Qooooo`;o0000:?ooool0
01cooooo00?o0000ooooooooool09?ooool2o`000003ooooool0003o000000Cooooo0_l0000Doooo
o`Ko000000?oooooo`000?l000000_l00002ooooo`;o00001_ooool2o`00027ooooo0_l00004oooo
o`?o00000_ooool2o`00013ooooo0_l00007ooooo`;o00000_ooool2o`0000Kooooo0_l00005oooo
o`;o00001Oooool5o`0000Sooooo0_l00002ooooo`;o000000?oooooo`000?l000004Oooool2o`00
00gooooo0ol00008ooooo`;o00001oooool2o`0004;ooooo000Looooo`03o`000?oooooooooo02go
oooo0_l0000Dooooo`Ko000000?oooooo`000?l000000_l00002ooooo`?o00004?ooool2o`0001co
oooo0_l00003ooooo`;o00003oooool2o`0000Sooooo0_l0000:ooooo`Co00000oooool2o`0000Ko
oooo1?l00008ooooo`;o00001Oooool2o`00017ooooo0ol0000<ooooo`Co00004?ooool2o`0000;o
oooo0_l0000Cooooo`;o0000:Oooool001cooooo00?o0000ooooooooool0:_ooool2o`0000Sooooo
0_l00002ooooo`;o00001Oooool2o`0000;ooooo3?l00002ooooo`Go00000oooool3o`000003oooo
ool0003o000000Cooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000?o
000000?oooooo`000?l000008oooool2o`000003ooooool0003o000000Kooooo1?l00009ooooo`;o
00000oooool2o`0000Oooooo1?l0000@ooooo`;o00004?ooool4o`0000cooooo0_l00005ooooo`;o
00001?ooool2o`0000;ooooo0ol00002ooooo`;o00004oooool2o`0002Wooooo000Looooo`03o`00
0?oooooooooo02[ooooo0_l00008ooooo`;o00000_ooool2o`0000Gooooo0_l00002ooooo`;o0000
00?oooooo`000?l000000ol000001?oooooo0000o`000?l00004ooooo`?o00000oooool6o`0000Oo
oooo0_l000001?oooooo0000o`000?ooool5o`000003ooooool0003o000000oooooo0_l0000Coooo
o`Co00001_ooool4o`0000kooooo0_l00009ooooo`;o00004?ooool2o`0001;ooooo0_l00009oooo
o`;o00002?ooool2o`0000Cooooo0_l00002ooooo`;o0000@oooool001cooooo00?o0000oooooooo
ool0>_ooool2o`00023ooooo0_l0000:ooooo`;o000000Coooooo`000?l0003o00004?ooool2o`00
00?ooooo0_l00003ooooo`Co00002_ooool4o`0001Cooooo0_l00004ooooo`;o00005Oooool2o`00
00?ooooo0_l00004ooooo`;o00001Oooool2o`0000?ooooo0_l0000<ooooo`;o00000oooool2o`00
00_ooooo1?l00007ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0>?ooool4o`0001Oo
oooo0_l0000:ooooo`;o00001oooool2o`000004ooooool0003o0000o`00013ooooo0_l00005oooo
o`Oo00002_ooool2o`0000Kooooo0_l0000>ooooo`;o00006oooool2o`0000?ooooo1Ol000000ooo
oooo0000o`000005ooooo`;o00000oooool2o`00017ooooo0_l0000;ooooo`;o00001oooool4o`00
03[ooooo000Looooo`03o`000?oooooooooo03Sooooo0_l0000=ooooo`;o00001?ooool2o`0000Co
oooo1Ol00007ooooo`;o00001Oooool2o`0000Cooooo0_l00002ooooo`;o00003?ooool2o`0000Co
oooo1?l0000Fooooo`;o00003Oooool2o`0000_ooooo0_l00002ooooo`?o00000oooool2o`0000;o
oooo0_l00008ooooo`?o000000?oooooo`000?l000001Oooool3o`0001Gooooo0_l0000Dooooo`[o
0000=?ooool001cooooo0_l0000gooooo`;o00001Oooool2o`0000Sooooo0_l00002ooooo`Co0000
1Oooool4o`0000[ooooo0_l00002ooooo`;o00002?ooool2o`0000cooooo0ol00003ooooo`;o0000
0oooool2o`0000?ooooo0_l0000Cooooo`;o00001Oooool5o`0000Wooooo2Ol00003ooooo`?o0000
00?oooooo`000?l000003_ooool2o`0000?ooooo0ol0000?ooooo`;o00002_ooool2o`0000Oooooo
0_l00006ooooo`Wo0000=?ooool001cooooo00?o0000ooooooooool0=_ooool2o`000003ooooool0
003o000000;ooooo1Ol00009ooooo`;o00001Oooool2o`0000_ooooo0_l000000ooooooo0000o`00
000Booooo`;o00000oooool2o`0000;ooooo0_l00008ooooo`?o00000_ooool2o`0000Sooooo0_l0
0009ooooo`;o00001Oooool6o`0000Sooooo1ol00004ooooo`Go000000?oooooo`000?l000000_oo
ool2o`0000Cooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`0000kooooo0_l0
000:ooooo`;o00001oooool2o`0000?ooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0a
ooooo`;o00000oooool5o`0000?ooooo1?l000000ooooooo0000o`000008ooooo`;o00000oooool2
o`0000Oooooo0_l00002ooooo`;o00001_ooool2o`0000gooooo0_l00003ooooo`;o00002?ooool3
o`0000;ooooo0_l00002ooooo`;o00002?ooool2o`0001Cooooo0_l00006ooooo`;o00001?ooool3
o`0000?ooooo2Ol00002ooooo`;o00000_ooool4o`0000Kooooo1_l0000>ooooo`Co00004oooool2
o`000003ooooool0003o000003kooooo000Looooo`03o`000?oooooooooo037ooooo0_l00004oooo
o`;o00001_ooool2o`0000;ooooo0_l00008ooooo`;o00003?ooool4o`000005ooooool0003o0000
o`000?ooool00_l000000ooooooo0000o`00000@ooooo`;o00002_ooool5o`0000_ooooo1Ol00005
ooooo`;o00003Oooool2o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`;o00001?ooool5
o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o00002_ooool4o`0000_ooooo0_l00000
0ooooooo0000o`000002o`0000kooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l0
000kooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00002_ooool2o`000003ooooool0003o
0000017ooooo0_l00004ooooo`Co000000Goooooo`000?l0003o0000ooooo`02o`0000[ooooo0_l0
0003ooooo`;o00000_ooool2o`0000Kooooo0_l00002ooooo`;o000000?oooooo`000?l000000ooo
ool2o`0000Kooooo1?l00006ooooo`;o00003Oooool2o`0000?ooooo0ol00002ooooo`;o00002_oo
ool3o`0000Kooooo0_l000000ooooooo0000o`00000<ooooo`?o00001?ooool2o`0000Cooooo0ol0
000@ooooo`;o000000?oooooo`000?l000000oooool2o`0000Cooooo0_l0000kooooo`007?ooool0
0ol0003oooooooooo`0cooooo`;o00000_ooool2o`0000Gooooo0_l00002ooooo`?o00002_ooool2
o`0000Cooooo0_l00004ooooo`?o00004_ooool2o`000003ooooool0003o000000;o00000_ooool2
o`000003ooooool0003o000000?ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o000000?o
ooooo`000?l000000_l00003ooooo`;o00000oooool2o`0001;ooooo0_l00007ooooo`;o00000_oo
ool2o`0000?ooooo0_l00005ooooo`;o00001_ooool2o`0000;ooooo0_l00004ooooo`;o00001_oo
ool2o`0000Gooooo0_l00004ooooo`;o00001_ooool2o`0000Wooooo0_l000000ooooooo0000o`00
0009ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0=oooool2o`0000Gooooo1?l00000
0ooooooo0000o`00000:ooooo`;o00007oooool2o`000003ooooool0003o000000Oooooo0_l00006
ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l000001?oooooo0000o`000?oo
ool4o`0001;ooooo0_l00003ooooo`;o00002oooool4o`0000Cooooo1?l000000ooooooo0000o`00
0002o`0000Sooooo0_l0000;ooooo`;o00000_ooool2o`0000Cooooo0_l00004ooooo`;o00003?oo
ool2o`0000_ooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`0Jooooo`;o00009?ooool2
o`0000oooooo0_l0000Dooooo`;o000000?oooooo`000?l000001?ooool2o`0000kooooo0_l00002
ooooo`Ko00001Oooool2o`0000Cooooo0_l0000=ooooo`;o00001_ooool2o`000003ooooool0003o
000000;o00003?ooool2o`0000?ooooo1Ol000000ooooooo0000o`000006ooooo`;o00002_ooool2
o`0000?ooooo0_l00002ooooo`;o00001?ooool2o`0000;ooooo1?l00004ooooo`;o00004_ooool3
o`0003Wooooo000Looooo`03o`000?oooooooooo01[ooooo0_l0000[ooooo`;o00002?ooool2o`00
01Cooooo1Ol0000>ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`?o000000Cooooo
o`000?l0003o00000_ooool2o`0000?ooooo0_l0000@ooooo`;o00001_ooool2o`000003ooooool0
003o000000;o00004Oooool3o`0000Gooooo0_l00004ooooo`Co00002?ooool2o`0000?ooooo0_l0
0004ooooo`;o00000_ooool2o`0000;ooooo0_l00006ooooo`;o00001Oooool2o`0000;ooooo0_l0
0002ooooo`;o00000oooool3o`0003Wooooo000Looooo`03o`000?oooooooooo03Kooooo0_l0000?
ooooo`;o00002_ooool2o`0000;ooooo0_l0000?ooooo`;o00002?ooool2o`0000Kooooo0_l00000
1Ooooooo0000o`000?l0003ooooo00Go000000?oooooo`000?l000001_l00003ooooo`;o00002Ooo
ool2o`0001_ooooo0_l00009ooooo`?o00001?ooool2o`0000Kooooo0_l00002ooooo`Co00001ooo
ool2o`0000Cooooo1?l00006ooooo`;o00002oooool2o`0000;ooooo0_l00002ooooo`;o00001?oo
ool2o`0003Wooooo000Looooo`03o`000?oooooooooo02oooooo0_l00005ooooo`Co00000oooool4
o`0000?ooooo0_l00007ooooo`;o00001?ooool2o`0000;ooooo0_l0000Booooo`;o000000?ooooo
o`000?l000000_ooool4o`0000Sooooo0_l000000ooooooo0000o`000003o`000004ooooool0003o
0000ooooo`Co00003_ooool5o`00017ooooo0_l00006ooooo`;o00002Oooool3o`0000Cooooo0_l0
000:ooooo`Co00000oooool2o`0000Sooooo1?l00002ooooo`;o00000_ooool2o`0000_ooooo0_l0
0002ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0;oooool2o`0000;ooooo0_l00003
ooooo`;o00000oooool6o`000004ooooool0003o0000ooooo`;o000000Coooooo`000?l0003ooooo
0_l00006ooooo`;o00003_ooool2o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`;o0000
2?ooool5o`000005ooooool0003o0000o`000?ooool00ol00004ooooo`;o00001_ooool7o`000003
ooooool0003o0000017ooooo0_l00004ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo
0000o`000003o`0000?ooooo0_l0000;ooooo`;o00001Oooool2o`0000;ooooo0_l00002ooooo`Co
00001?ooool2o`0000?ooooo0_l0000>ooooo`;o00002?ooool2o`0003Wooooo000Looooo`03o`00
0?oooooooooo03?ooooo0_l00008ooooo`;o00000_ooool2o`0000Cooooo0_l000001?oooooo0000
o`000?ooool2o`0000Kooooo0_l0000>ooooo`;o00002?ooool3o`0000;ooooo0_l00008ooooo`Go
000000Goooooo`000?l0003o0000ooooo`03o`0000?ooooo0ol000001?oooooo0000o`000?ooool8
o`0000Oooooo0_l00004ooooo`;o00003?ooool2o`0000;ooooo0_l00002ooooo`;o000000?ooooo
o`000?l000000ol00003ooooo`;o000000Coooooo`000?l0003o00001oooool3o`0000;ooooo0_l0
0004ooooo`Ko00002_ooool3o`0000Oooooo0_l00004ooooo`;o00002Oooool2o`0003Wooooo000L
ooooo`03o`000?oooooooooo03Sooooo0_l00004ooooo`;o00005?ooool3o`000004ooooool0003o
0000o`0000[ooooo0_l00008ooooo`?o000000?oooooo`000?l000000oooool2o`000004ooooool0
003o0000ooooo`Oo00000oooool5o`000003ooooool0003o000000Co000000?oooooo`000?l00000
0ol000000ooooooo0000o`000004ooooo`Ko00000oooool2o`0000Sooooo0_l0000=ooooo`;o0000
2Oooool3o`0000Oooooo0ol00002ooooo`;o00001_ooool4o`0000?ooooo0_l00005ooooo`;o0000
2?ooool2o`0000Cooooo0_l00006ooooo`;o0000??ooool001cooooo00?o0000ooooooooool0<_oo
ool2o`0000?ooooo0ol00004ooooo`;o00005?ooool3o`000005ooooool0003o0000o`000?ooool0
0_l00004ooooo`;o000000?oooooo`000?l000002?ooool2o`000003ooooool0003o000000;o0000
0_ooool5o`000003ooooool0003o000000go00000_ooool3o`0000Kooooo0_l000000ooooooo0000
o`000004ooooo`?o000000?oooooo`000?l000003Oooool2o`0000Cooooo0_l0000?ooooo`Co0000
00?oooooo`000?l000006_ooool2o`000003ooooool0003o000000;ooooo1?l00007ooooo`;o0000
1Oooool2o`0000Cooooo0_l0000Aooooo`;o0000:Oooool001cooooo00?o0000ooooooooool0<_oo
ool2o`0000?ooooo0_l00003ooooo`;o00002?ooool2o`0000;ooooo0_l0000<ooooo`;o00000_oo
ool2o`0000Cooooo0_l00009ooooo`Wo00001?ooool3o`000003ooooool0003o000000oo00001Ooo
ool3o`0000Cooooo0_l000000ooooooo0000o`000006ooooo`;o00001?ooool2o`0000[ooooo1?l0
0004ooooo`;o00002Oooool4o`000003ooooool0003o000000gooooo1_l0000:ooooo`;o00001?oo
ool2o`0000Oooooo1Ol00002ooooo`;o00005oooool2o`0002Wooooo000Looooo`;o0000?Oooool2
o`0000?ooooo0_l00002ooooo`?o00000_ooool2o`0000;ooooo0_l00005ooooo`Go00000_ooool2
o`0000Wooooo0_l00003ooooo`?o000000?oooooo`000?l000002?ooool<o`000003ooooool0003o
000000oo00000oooool5o`0000;ooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l0
000:ooooo`;o00001_ooool2o`0000Wooooo0_l0000Booooo`Ko00003_ooool2o`0000[ooooo1?l0
000;ooooo`;o0000>Oooool001cooooo00?o0000ooooooooool0?oooool4o`0000;ooooo0ol00006
ooooo`;o00001Oooool3o`0000Cooooo0ol00008ooooo`;o00000oooool2o`0000Kooooo1?l00002
ooooo`oo00000_ooool9o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o000000?ooooo
o`000?l000000_l00004ooooo`?o00001oooool2o`00017ooooo0_l0000;ooooo`;o00002Oooool4
o`0000kooooo0_l00002ooooo`;o00004_ooool2o`0000Gooooo0_l0000iooooo`007?ooool00ol0
003oooooooooo`0oooooo`?o00002?ooool2o`00013ooooo0ol0000Eooooo`Co00000oooool3o`00
0003ooooool0003o000001Co00001?ooool4o`0000?ooooo1_l00002ooooo`;o00002?ooool2o`00
00;ooooo0_l0000=ooooo`;o00000oooool2o`0000Kooooo0_l00009ooooo`Co00001?ooool5o`00
00Gooooo0_l00009ooooo`;o00002oooool2o`0000?ooooo0_l0000kooooo`007?ooool00ol0003o
ooooooooo`0^ooooo`;o00001?ooool2o`0000Wooooo0_l00009ooooo`;o00004?ooool2o`0001?o
oooo3Ol000000ooooooo0000o`00000Eo`0000Cooooo0ol00003ooooo`Ko00003_ooool5o`0000Oo
oooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l00005ooooo`;o00000oooool2o`0000Ko
oooo0_l00005ooooo`Go00000oooool2o`0000Gooooo0_l00003ooooo`?o00004?ooool2o`0003_o
oooo000Looooo`03o`000?oooooooooo02kooooo0_l00002ooooo`Co00004_ooool3o`0000Gooooo
0_l0000:ooooo`Co00003ooooolNo`0000;ooooo2Ol000000ooooooo0000o`000002o`000003oooo
ool0003o000000;o00001Oooool2o`0000_ooooo0_l000001?oooooo0000o`000?ooool2o`0000Co
oooo1ol00007ooooo`Go00000oooool2o`00013ooooo0_l00003ooooo`;o00001Oooool2o`0000?o
oooo0_l00004ooooo`;o00006oooool2o`000003ooooool0003o000002Sooooo000Looooo`03o`00
0?oooooooooo03;ooooo0_l00009ooooo`?o00002?ooool3o`0000Gooooo0ol00007ooooo`Ko0000
0oooool2o`0000[ooooo0_l000000ooooooo0000o`000007o`000003ooooool0003o000000Wo0000
00?oooooo`000?l000004ol000001?oooooo0000o`000?ooool2o`0000Cooooo0_l00009ooooo`;o
00001?ooool4o`0000Kooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l0
00001_l00005ooooo`;o00003Oooool2o`0001Gooooo0_l00007ooooo`;o00004_ooool2o`000003
ooooool0003o000002Sooooo000Looooo`03o`000?oooooooooo03gooooo0ol0000Aooooo`;o0000
00?oooooo`000?l000001?ooool2o`0000Oooooo0_l00004ooooo`?o00002?ooool3o`000003oooo
ool0003o000002?o00000_ooool4o`0000Sooooo0_l00005ooooo`;o00001?ooool2o`0000Gooooo
1_l000000ooooooo0000o`00000<o`0000Gooooo0_l00003ooooo`;o00003?ooool2o`0001?ooooo
0_l00005ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0<oooool3o`0001cooooo1?l0
0004ooooo`;o00000oooool2o`0000Sooooo1?l00003ooooo`?o00000oooool^o`0000Oooooo0_l0
000@ooooo`So000000?oooooo`000?l000002?l00002ooooo`?o00000_ooool2o`0000Gooooo0_l0
000:ooooo`Co00004oooool2o`0000_ooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`0c
ooooo`?o00007?ooool7o`0000Kooooo0_l0000:ooooo`;o00000oooool5o`000003ooooool0003o
000002Co000000?oooooo`000?l000001_l00006ooooo`;o00001oooool2o`0000Oooooo2Ol00000
0ooooooo0000o`000007o`0000;ooooo0ol00002ooooo`;o00004?ooool3o`0000Oooooo0_l0000I
ooooo`;o0000>Oooool001cooooo00?o0000ooooooooool0>oooool2o`000004ooooool0003o0000
ooooo`;o00001_ooool2o`0000?ooooo0_l00004ooooo`Ko000000?oooooo`000?l000000_ooool2
o`00017ooooo0ol000000ooooooo0000o`000006o`000003ooooool0003o000001_o000000?ooooo
o`000?l000000ol000000ooooooo0000o`000002o`0000Gooooo0_l00006ooooo`;o00002_ooool@
o`000003ooooool0003o000000Co00000oooool3o`0000;ooooo0_l00008ooooo`;o00002?ooool4
o`0000Gooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`0kooooo`;o000000Coooooo`00
0?l0003ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool3o`0000Gooooo0_l00000
1?oooooo0000o`000?ooool2o`0000;ooooo0ol00004ooooo`;o00000_ooool2o`000004ooooool0
003o0000ooooo`;o000000?oooooo`000?l000004?l000000ooooooo0000o`00000Ko`0000;ooooo
0_l00005ooooo`;o00001Oooool2o`0000Sooooo4ol000000ooooooo0000o`000004o`0000;ooooo
1?l00002ooooo`;o00005?ooool2o`0000Gooooo0_l00007ooooo`Co00004?ooool2o`0002kooooo
000Looooo`03o`000?oooooooooo03Sooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l0
0005ooooo`Co00002?ooool2o`000003ooooool0003o000000?o00000_ooool2o`000003ooooool0
003o000000Oo000000Coooooo`000?l0003ooooo:Ol00005ooooo`;o00000_ooool4o`0000?ooooo
0_l00008oooooaKo000000?oooooo`000?l000001Ol00003ooooo`;o00002?ooool4o`0000kooooo
0_l00007ooooo`Ko00004?ooool2o`0002kooooo000Looooo`03o`000?oooooooooo03Sooooo0_l0
0005ooooo`;o00001Oooool2o`0000Kooooo0_l00004ooooo`Co000000?oooooo`000?l000000_oo
ool2o`0000Cooooo1?l00002ooooo`;o00000oooool6o`0000;ooooo;_l000001?oooooo0000o`00
0?ooool2o`0000;ooooo1?l00002ooooo`;o00002OoooolFo`0000;ooooo1?l00002ooooo`;o0000
00?oooooo`000?l000002?ooool4o`0000gooooo0ol00007ooooo`;o00000_ooool2o`00043ooooo
000Looooo`03o`000?oooooooooo03oooooo0_l00005ooooo`;o00001_ooool4o`0000Cooooo0_l0
00000ooooooo0000o`000002ooooo`;o00001Oooool4o`000003ooooool0003o000000;ooooo0_l0
00000ooooooo0000o`000002oooooaGo000000?oooooo`000?l000005Ol000000ooooooo0000o`00
0003o`0000Cooooo0ol00004ooooo`;o00001ooooolMo`0000?ooooo0_l00003ooooo`?o00003?oo
ool2o`0000Sooooo0_l00007ooooo`;o00000oooool2o`0000;ooooo0_l00005ooooo`;o0000=Ooo
ool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o
410@olc<c006ooooo`03o`000?oooooooooo03oooooo0ol0000=ooooo`?o00002Oooool2o`0000Wo
oooo0_l00002ooooo`;o000000?oooooo`000?l000000_l00003ooooobco00000oooool3o`000005
ooooool0003o0000o`000?ooool00ol00005ooooo`;o00001?ooool4o`000003ooooool0003o0000
01[o000000?oooooo`000?l000000oooool3o`0000Sooooo0_l00002ooooo`;o00001?ooool2o`00
00_ooooo0_l00007ooooo`;o00001Oooool2o`0000;ooooo0_l0000aooooo`0000KoooooogMgMonH
V9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o
0000ooooooooool0;Oooool2o`00017ooooo0_l00002ooooo`;o00000_ooool2o`0000Gooooo0ol0
0002ooooo`;o00000_ooool2o`000003ooooool0003o000000Oooooo0ol00003ooooo`;o00000ooo
ool2o`000004ooooool0003o0000ooooobco00000oooool2o`000004ooooool0003o0000o`0000Wo
oooo0_l00003ooooo`?o000000?oooooo`000?l000007?l000000ooooooo0000o`00000>ooooo`;o
00000_ooool3o`0000?ooooo1?l0000Mooooo`;o0000<Oooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool0;Oooool2o`0000Cooooo0_l0000>ooooo`?o00000_ooool2o`0000;ooooo0_l00006ooooo`;o
00000_ooool2o`0000?ooooo0_l00005ooooo`?o00001_ooool4o`000003ooooool0003o000002ko
00001Oooool2o`0000;ooooo0_l00007ooooo`;o000000Coooooo`000?l0003o00000_ooool3o`00
0003ooooool0003o000001co00002_ooool2o`0000Gooooo0ol00005ooooo`;o00001Oooool2o`00
00;ooooo0_l00015ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05
o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0003?ooooo0_l0000>ooooo`;o00000oooool6o`00
00Sooooo1?l00003ooooo`;o00001Oooool2o`0000Gooooo1ol00002ooooobOo00000oooool4o`00
00Cooooo0ol00002ooooo`;o00001?ooool5o`000003ooooool0003o000000So000000?oooooo`00
0?l000006_l0000:ooooo`;o00001_ooool2o`0000_ooooo0ol00002ooooo`;o000000?oooooo`00
0?l00000@_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003o
EEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0B_ooool2o`0000[ooooo1?l0000:oooo
o`;o00001Oooool3o`000003ooooool0003o000000?o00000ooooolVo`000004ooooool0003o0000
o`0000Gooooo1Ol00006ooooo`Co00000_oooolQo`000003ooooool0003o000000;o00002?ooool2
o`0000?ooooo0_l0000:ooooo`;o00001Oooool2o`0000Kooooo0_l00012ooooo`0000?ooooooa0@
4?ooool00_ooool00ol@413oooooooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000oooo
ooooool0@Oooool3o`000003ooooool0003o000000?ooooo1Ol00009ooooo`;o00000_ooool2o`00
00Kooooo0_l00004ooooo`;o00001?ooool4o`0000;ooooo5ol000000ooooooo0000o`00000@o`00
0004ooooool0003o0000o`0000?ooooo1?l00007ooooo`;o00000oooool3o`000003ooooool0003o
000000_o000000?oooooo`000?l000004Ol00009ooooo`;o00000oooool2o`0000[ooooo0_l0000O
ooooo`;o0000<?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@oiRH
V008ooooo`03o`000?oooooooooo047ooooo0ol000000ooooooo0000o`000005ooooo`Go00001ooo
ool2o`0000;ooooo0_l0000;ooooo`Go00001?ooool2o`0000;ooooo3_l000000ooooooo0000o`00
0006o`000003ooooool0003o0000013o000000?oooooo`000?l000000ol000000ooooooo0000o`00
0009ooooo`;o00000_ooool4o`000003ooooool0003o000001ko00000oooool3o`0000_ooooo0_l0
0003ooooo`;o00004Oooool3o`00013ooooo0_l0000`ooooo`0000Koooooonk^k_lb<S;o0000oc8b
<_o^k^h<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0BOooool2o`0000Co
oooo0_l00007ooooo`Co00001Oooool2o`0000Kooooo1Ol00004ooooo`;o00000_ooool4o`000003
ooooool0003o0000023o00001?ooool6o`0000oooooo1?l000000ooooooo0000o`00000No`0000;o
oooo1?l0000;ooooo`;o00000oooool2o`0000Cooooo0_l0000;ooooo`?o00002oooool2o`0003Go
oooo000Looooo`03o`000?oooooooooo04;ooooo0_l00005ooooo`;o00003Oooool4o`0000Cooooo
0ol00003ooooo`;o00003?ooool3o`000004ooooool0003o0000oooooako000000?oooooo`000?l0
00001Oooool3o`000003ooooool0003o000000Wooooo0_l00004ooooo`;o00000ooooolNo`0000;o
oooo1?l000000ooooooo0000o`000003ooooo`;o00004?ooool2o`0000Wooooo0_l0000>ooooo`;o
0000=Oooool001cooooo00?o0000ooooooooool0@_ooool2o`0000Gooooo0_l0000Eooooo`;o0000
1?ooool2o`0000Kooooo0_l00004ooooo`?o000000?oooooo`000?l000001ol000000ooooooo0000
o`00000Io`0000?ooooo0ol00006ooooo`;o00000_ooool2o`000003ooooool0003o000000Cooooo
0_l000000ooooooo0000o`00000No`0000;ooooo1?l000000ooooooo0000o`000003ooooo`;o0000
1_ooool2o`0000;ooooo0_l0000?ooooo`;o0000AOooool001cooooo00?o0000ooooooooool0:_oo
ool2o`0000Cooooo0_l0000=ooooo`;o00002?ooool5o`0000;ooooo0ol0000:ooooo`Co00000ooo
ool2o`0000Sooooo0_l00005ooooo`Oo000000?oooooo`000?l000004?l000000ooooooo0000o`00
000=o`000003ooooool0003o000000?o00000_ooool4o`0000;ooooo0_l00003ooooo`;o00000_oo
oolOo`000003ooooool0003o000000;o000000?oooooo`000?l000000_l0000>ooooo`;o00000_oo
ool2o`00013ooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0Zooooo`;o00001?ooool2
o`0000gooooo0_l00007ooooo`Ko00000_ooool3o`0000Oooooo0_l000000ooooooo0000o`000002
o`0000?ooooo0_l00003ooooo`?o00002?ooool7o`0000;ooooo6_l00003ooooo`Go00001?ooool2
o`0000;ooooo0_l00008ooooo`?o00001?ooool2o`0000?ooooo3Ol000000ooooooo0000o`00000:
o`000003ooooool0003o000000;ooooo0ol0000?ooooo`;o00002?ooool3o`0000?ooooo1ol00014
ooooo`007?ooool00ol0003oooooooooo`18ooooo`?o000000?oooooo`000?l000002?ooool2o`00
00;ooooo0_l0000=ooooo`?o00001_oooolTo`000003ooooool0003o000000?o00001Oooool2o`00
00Gooooo0_l00007ooooo`;o00002_oooolLo`00017ooooo0_l00002ooooo`;o00002?ooool3o`00
00?ooooo2?l00013ooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00000_ooool4o`0000_o
oooo1Ol00008ooooo`;o000000?oooooo`000?l000001Oooool2o`0000;ooooo2Ol000000ooooooo
0000o`000002o`000003ooooool0003o000001Wo00001_ooool4o`000003ooooool0003o000000;o
00004oooool3o`000003ooooool0003o0000017o000000?oooooo`000?l000000_l00005ooooo`;o
000000?oooooo`000?l000001oooool2o`0000Cooooo0_l0000>ooooo`;o00000_ooool2o`0000ko
oooo0_l0000cooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00000_ooool4o`0000Wooooo
0_l000000ooooooo0000o`000003o`0000;ooooo0_l00003ooooo`;o000000Coooooo`000?l0003o
oooo0_l00002ooooo`?o000000Coooooo`000?l0003ooooo1_l000000ooooooo0000o`00000Ho`00
0003ooooool0003o000000?o00002?ooool2o`000003ooooool0003o000001Wooooo4ol000000ooo
oooo0000o`000007ooooo`;o000000?oooooo`000?l000001oooool2o`0000?ooooo0ol0000>oooo
o`;o00004_ooool2o`0003?ooooo000Looooo`03o`000?oooooooooo04Wooooo0_l00009ooooo`;o
00001?ooool2o`0000;ooooo0ol00005ooooo`;o000000?oooooo`000?l000000oooool2o`0000Ko
oooo1?l00002oooooaWo000000?oooooo`000?l000002?ooool2o`0000;ooooo0_l0000Hooooo`;o
00000_oooolEo`0000;ooooo0_l0000?ooooo`;o00000oooool2o`0000kooooo0_l00018ooooo`00
7?ooool00ol0003oooooooooo`19ooooo`;o00002Oooool2o`0000Sooooo0ol000000ooooooo0000
o`000003ooooo`;o00000_ooool2o`0000Oooooo2_l00004ooooo`?o00000oooool;o`0000;ooooo
0ol00002ooooo`;o00001?ooool2o`0000;ooooo0_l0000?ooooo`;o00000_ooool2o`0000?ooooo
0_l000000ooooooo0000o`00000Co`0000;ooooo0ol0000Dooooo`;o00002?ooool2o`0000?ooooo
0ol00018ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00007oooool2o`0000Kooooo0_l0
00001?oooooo0000o`000?ooool2o`0000?ooooo0_l00002ooooo`;o00001oooool2o`0000Cooooo
0ol000001?oooooo0000o`000?ooool5o`000004ooooool0003o0000ooooo`Co000000Coooooo`00
0?l0003o00000oooool2o`0000?ooooo1?l0000Dooooo`;o000000?oooooo`000?l000000_ooool2
o`0000?ooooo0_l000000ooooooo0000o`00000?o`0000;ooooo0_l00002ooooo`;o00001oooool2
o`0000[ooooo1?l00008ooooo`;o00000oooool4o`0004Oooooo000Looooo`03o`000?oooooooooo
03?ooooo0_l0000Mooooo`Wo000000Coooooo`000?l0003ooooo1?l00009ooooo`;o00003Oooool;
o`000003ooooool0003o000000_o000000Coooooo`000?l0003o00000oooool3o`000003ooooool0
003o000000gooooo0_l00002ooooo`;o00004?ooool2o`0000;ooooo2ol00002ooooo`;o00002_oo
ool2o`0000?ooooo0_l00005ooooo`;o00001oooool2o`0000Sooooo0_l0000Aooooo`;o0000=?oo
ool001cooooo0_l0001Cooooo`?o000000?oooooo`000?l000000ol000000ooooooo0000o`000003
ooooo`;o00000_ooool3o`0000Cooooo0_l0000=ooooo`oo00000_ooool4o`0000;ooooo0_l00000
1?oooooo0000o`000?l00003ooooo`?o000000?oooooo`000?l000002Oooool3o`000003ooooool0
003o000000cooooo0_l00006ooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`So0000
1oooool2o`0000Gooooo0_l00008ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o
00005oooool2o`0003Cooooo000Looooo`03o`000?oooooooooo04[ooooo0_l0000Iooooo`?o0000
2Oooool2o`0000;ooooo0_l00002ooooo`Go00000oooool3o`000003ooooool0003o000000?o0000
0oooool2o`0000;ooooo0_l00009ooooo`;o00001_ooool2o`000003ooooool0003o000000Co0000
1Oooool2o`0000Sooooo0_l00006ooooo`;o00001Oooool6o`000003ooooool0003o000000Co0000
0oooool2o`0000;ooooo0_l0000?ooooo`Go00001Oooool2o`0004gooooo000Looooo`03o`000?oo
oooooooo04[ooooo0_l0000@ooooo`;o00000oooool2o`0000kooooo0_l00002ooooo`;o00000_oo
ool4o`000004ooooool0003o0000ooooo`;o00000_ooool5o`000003ooooool0003o000000Cooooo
0_l00009ooooo`;o00001_ooool2o`000003ooooool0003o000000;o000000Coooooo`000?l0003o
00000oooool2o`0000?ooooo0_l0000;ooooo`;o00000oooool8o`0000[ooooo0_l00002ooooo`;o
00004Oooool2o`0005Gooooo000Looooo`03o`000?oooooooooo04Oooooo0_l0000Cooooo`;o0000
0oooool2o`0001_ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l00002ooooo`Ko0000
2oooool2o`0000Kooooo0_l000000ooooooo0000o`000003ooooo`?o00001Oooool2o`000003oooo
ool0003o0000013ooooo2?l0001hooooo`007?ooool00ol0003oooooooooo`17ooooo`;o00002Ooo
ool2o`0001_ooooo0_l0000Aooooo`;o00000_ooool2o`0000Cooooo1Ol0000>ooooo`;o00000ooo
ool2o`000003ooooool0003o000000;ooooo0_l00005ooooo`Co00006?ooool2o`0000Oooooo0_l0
000Jooooo`;o0000E?ooool001cooooo00?o0000ooooooooool0Aoooool2o`0000Wooooo0_l00004
ooooo`;o00000oooool2o`00013ooooo0_l0000Aooooo`;o00002?ooool2o`0000Cooooo0_l0000;
ooooo`;o00001?ooool2o`0000Cooooo0_l00005ooooo`;o000000?oooooo`000?l000000_ooool2
o`0001cooooo0_l0000Jooooo`;o00001?ooool2o`0004kooooo000Looooo`03o`000?oooooooooo
05?ooooo0_l00003ooooo`;o00000oooool2o`0001Wooooo0_l00008ooooo`;o00001_ooool5o`00
00?ooooo0_l0000;ooooo`;o000000Coooooo`000?l0003ooooo0_l0000=ooooo`?o00000_ooool2
o`0000oooooo0_l0000<ooooo`;o00006_ooool2o`0000?ooooo1?l0001<ooooo`007?ooool00ol0
003oooooooooo`1Cooooo`Co00001_ooool2o`0000;ooooo0_l000000ooooooo0000o`000004oooo
o`;o00000_ooool2o`0000Oooooo0ol0000<ooooo`;o00000_ooool2o`000003ooooool0003o0000
013ooooo0_l000001?oooooo0000o`000?l0000?ooooo`?o00004oooool2o`0000cooooo0_l00006
ooooo`;o00003Oooool4o`000003ooooool0003o000000Gooooo0_l0001<ooooo`007?ooool00ol0
003oooooooooo`1Eooooo`;o00001_ooool2o`0000;ooooo1Ol00004ooooo`;o00000_ooool4o`00
00?ooooo1?l0000=ooooo`Co000000Coooooo`000?l0003ooooo0_l00002ooooo`?o00001Oooool2
o`0000Oooooo0_l00004ooooo`;o00002?ooool2o`0001Cooooo0ol0000@ooooo`;o00000_ooool2
o`0000gooooo1?l00009ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0F?ooool4o`00
00?ooooo0_l00002ooooo`;o000000?oooooo`000?l000001_ooool5o`0000;ooooo0_l00007oooo
o`;o00002?ooool2o`000004ooooool0003o0000ooooo`;o00000_ooool3o`000003ooooool0003o
000000;ooooo0ol0000<ooooo`;o000000?oooooo`000?l000001Oooool4o`0000Gooooo0_l00006
ooooo`;o00000oooool3o`0000Cooooo0_l00002ooooo`;o00001_ooool5o`000003ooooool0003o
000001Sooooo0_l0000@ooooo`;o0000>Oooool001cooooo00?o0000ooooooooool0E?ooool2o`00
00;ooooo1?l00003ooooo`?o000000Coooooo`000?l0003ooooo0_l00007ooooo`Co00000_ooool3
o`0000Kooooo0_l00003ooooo`;o00004Oooool2o`0000?ooooo0_l00005ooooo`;o00002?ooool2
o`0000Gooooo1?l00005ooooo`;o000000?oooooo`000?l000000oooool2o`0000Oooooo0_l00000
0ooooooo0000o`000002ooooo`;o00002?ooool6o`0000Sooooo0_l0000:ooooo`;o00005?ooool3
o`0003Sooooo000Looooo`03o`000?oooooooooo057ooooo0_l000001?oooooo0000o`000?ooool2
o`000003ooooool0003o000000?ooooo1_l00003ooooo`;o00003?ooool2o`0000_ooooo0_l0000B
ooooo`;o00001Oooool2o`0000;ooooo0_l0000:ooooo`;o00000oooool2o`0000Cooooo1?l00002
ooooo`;o00002Oooool2o`000003ooooool0003o000000[ooooo0_l00006ooooo`Go00001_ooool2
o`0000[ooooo0_l0000Eooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0Aoooool2o`00
00;ooooo0_l00004ooooo`;o00001?ooool2o`0000Kooooo0_l000000ooooooo0000o`000004oooo
o`;o00004oooool4o`0000;ooooo0_l00002ooooo`;o00003_ooool2o`0000Gooooo0_l0000;oooo
o`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000004ooooo`Co000000?oooooo`00
0?l000000_l00002ooooo`;o00001?ooool2o`0000gooooo0_l00009ooooo`;o00001_ooool4o`00
00Oooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`17ooooo`;o00000_ooool3o`0000Go
oooo0_l00002ooooo`;o000000?oooooo`000?l000006oooool2o`0000Cooooo1?l00006ooooo`;o
00002oooool2o`0001Gooooo0_l00003ooooo`;o00002_ooool6o`0000;ooooo0_l0000Vooooo`Co
00001oooool2o`00053ooooo000Looooo`03o`000?oooooooooo04cooooo0_l00005ooooo`;o0000
1Oooool2o`0001?ooooo0_l00006ooooo`;o00000oooool2o`0000kooooo0_l00004ooooo`Co0000
3?ooool2o`0000Kooooo0_l00005ooooo`;o00002Oooool2o`00017ooooo0_l0000Dooooo`;o0000
1_ooool2o`0000Sooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`1Wooooo`;o00001Ooo
ool3o`000003ooooool0003o000000Oooooo0ol0000>ooooo`;o000000Coooooo`000?l0003ooooo
0_l00002ooooo`;o00002Oooool3o`0000Kooooo0_l00005ooooo`;o00003?ooool2o`0000kooooo
0_l0000Dooooo`;o00001_ooool2o`0000;ooooo0_l0001Fooooo`007?ooool2o`0005Kooooo0ol0
000?ooooo`;o00001Oooool2o`0000;ooooo1?l00005ooooo`;o00004_ooool2o`0000Gooooo0_l0
0009ooooo`?o00005Oooool2o`0000Cooooo0_l00006ooooo`;o00003?ooool3o`0000gooooo0_l0
000:ooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0Boooool4o`0000Kooooo0ol00009
ooooo`;o00003Oooool2o`0000;ooooo0_l000000ooooooo0000o`00000Yooooo`;o00001Oooool2
o`0000Oooooo0_l00005ooooo`;o00003?ooool2o`0000Oooooo0_l00003ooooo`?o000000?ooooo
o`000?l000002_ooool2o`0000?ooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1;oooo
o`Co00002oooool2o`0000Cooooo0ol0000=ooooo`Co00000oooool2o`0000Cooooo0_l00002oooo
o`;o00004?ooool2o`0000Cooooo0_l00007ooooo`;o00001Oooool2o`0000Oooooo0_l000000ooo
oooo0000o`00000Booooo`;o00001Oooool2o`0000Cooooo0_l000000ooooooo0000o`000003oooo
o`;o00002Oooool3o`000003ooooool0003o000005[ooooo000Looooo`03o`000?oooooooooo04go
oooo0_l00004ooooo`;o00001Oooool2o`0000Cooooo0ol00009ooooo`;o00001?ooool2o`0000;o
oooo0_l00005ooooo`Ko00004?ooool2o`0000Cooooo0_l0000Jooooo`Co00002?ooool2o`0000Co
oooo1?l00002ooooo`;o00002_ooool2o`0000?ooooo0_l00007ooooo`Co00000_ooool2o`0005[o
oooo000Looooo`03o`000?oooooooooo05?ooooo0_l00003ooooo`;o00001oooool4o`0000?ooooo
0_l00002ooooo`;o00002?ooool2o`0000Oooooo0_l0000fooooo`;o00001oooool3o`0000Cooooo
0_l00004ooooo`;o00006?ooool2o`00063ooooo000Looooo`03o`000?oooooooooo05Sooooo0_l0
00000ooooooo0000o`000005ooooo`?o00000oooool2o`0000Cooooo0_l00003ooooo`;o00002Ooo
ool2o`0003Wooooo0_l00002ooooo`Go00003Oooool2o`0007Sooooo000Looooo`03o`000?oooooo
oooo05_ooooo0_l00004ooooo`?o00001_ooool8o`000003ooooool0003o000000Wooooo0_l0000i
ooooo`;o00000_ooool4o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`Co00000_ooool2
o`0007Cooooo000Looooo`03o`000?oooooooooo04[ooooo0_l0000@ooooo`;o00000oooool2o`00
00?ooooo0_l00002ooooo`Co00000_ooool2o`0005?ooooo0_l000000ooooooo0000o`000003oooo
o`;o00001?ooool2o`0000oooooo0_l0001Sooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o
00004?ooool2o`0000Sooooo0_l0000Rooooo`;o0000F?ooool2o`0006?ooooo000Looooo`03o`00
0?oooooooooo04Kooooo0_l0000=ooooo`;o00000_ooool2o`0000?ooooo1?l00002ooooo`?o0000
8oooool2o`0002[ooooo0_l00004ooooo`;o00002?ooool2o`0000Kooooo0_l00004ooooo`Co0000
00?oooooo`000?l000002Oooool2o`0000?ooooo0_l0001Nooooo`007?ooool00ol0003ooooooooo
o`16ooooo`;o00003Oooool2o`0000;ooooo0_l00003ooooo`Co00000_ooool3o`0000Wooooo0_l0
0003ooooo`;o0000?oooool2o`0000Cooooo0_l000000ooooooo0000o`000005ooooo`;o00001_oo
ool2o`000004ooooool0003o0000ooooo`Co000000?oooooo`000?l000002?ooool3o`0000?ooooo
0_l0001Nooooo`007?ooool00ol0003oooooooooo`1Eooooo`Wo00004_ooool2o`0000;ooooo0ol0
00000ooooooo0000o`000002o`0000;ooooo0_l00006ooooo`;o0000;Oooool2o`0000?ooooo0_l0
0003ooooo`;o00001Oooool2o`0000Kooooo0_l000001?oooooo0000o`000?l00002ooooo`;o0000
1Oooool2o`0000?ooooo0ol00003ooooo`;o000000?oooooo`000?l00000G?ooool001cooooo00?o
0000ooooooooool0Eoooool7o`0000?ooooo0_l0000:ooooo`;o00001Oooool2o`0000;ooooo2?l0
0006ooooo`;o00001?ooool2o`0002?ooooo0_l00002ooooo`;o00000oooool2o`0000[ooooo0_l0
00001?oooooo0000o`000?ooool4o`0000;ooooo0_l00008ooooo`?o00000oooool2o`0000Cooooo
0_l000000ooooooo0000o`00001Looooo`007?ooool00ol0003oooooooooo`1Qooooo`;o00001?oo
ool2o`0000Cooooo1?l0000;ooooo`Co00003?ooool4o`00027ooooo0_l00002ooooo`;o00004_oo
ool2o`000003ooooool0003o000000kooooo0_l0001[ooooo`007?ooool00ol0003oooooooooo`1W
ooooo`;o00001_ooool2o`0000cooooo0_l0000?ooooo`;o0000<Oooool2o`0001Wooooo0_l00003
ooooo`;o0000I_ooool001cooooo00?o0000ooooooooool0G_ooool2o`0000oooooo0_l00009oooo
o`;o000000Goooooo`000?l0003o0000ooooo`02o`0000Wooooo0_l0000_ooooo`;o00000_ooool2
o`0001Wooooo0ol00002ooooo`;o0000I_ooool001cooooo0_l0001Hooooo`?o00001?ooool2o`00
0003ooooool0003o000001Oooooo0_l00002ooooo`;o000000?oooooo`000?l000002Oooool2o`00
00?ooooo0_l0000Zooooo`;o00002Oooool4o`00017ooooo0_l00002ooooo`;o0000I_ooool001co
oooo00?o0000ooooooooool0DOooool2o`0000Cooooo1?l00003ooooo`;o000000?oooooo`000?l0
00001oooool2o`0000kooooo0ol00003ooooo`;o00003oooool2o`0001_ooooo0_l00004ooooo`Co
00001Oooool2o`0000Wooooo1?l0000:ooooo`;o00002Oooool2o`0001_ooooo0_l00019ooooo`00
7?ooool00ol0003oooooooooo`1Aooooo`;o00001_ooool2o`0000?ooooo0_l00003ooooo`;o0000
1Oooool2o`0000oooooo0_l00003ooooo`;o000000Coooooo`000?l0003o0000:?ooool2o`0000Co
oooo1?l00007ooooo`;o00005Oooool2o`0002Kooooo0_l00019ooooo`007?ooool00ol0003ooooo
ooooo`1Aooooo`;o00001oooool2o`0000Oooooo0_l0000Nooooo`?o00002Oooool2o`00023ooooo
0_l000000ooooooo0000o`000009ooooo`;o00001_ooool2o`0000[ooooo0_l0001dooooo`007?oo
ool00ol0003oooooooooo`1Aooooo`;o00001oooool2o`0001?ooooo0_l000000ooooooo0000o`00
000Fooooo`;o00000oooool2o`0000;ooooo0_l0000Gooooo`;o00000oooool2o`000003ooooool0
003o0000017ooooo0_l0000:ooooo`;o00002_ooool2o`0006Sooooo000Looooo`03o`000?oooooo
oooo05[ooooo0_l0000Cooooo`;o000000Coooooo`000?l0003ooooo0_l0000;ooooo`;o00001_oo
ool2o`0000Oooooo0ol0000Fooooo`;o000000?oooooo`000?l000000_ooool2o`0000Kooooo0_l0
000Fooooo`Co00002?ooool2o`0006Sooooo000Looooo`03o`000?oooooooooo06Wooooo0_l00005
ooooo`Co000000?oooooo`000?l000001?ooool2o`0000Gooooo0_l0000<ooooo`;o000000Cooooo
o`000?l0003o00006Oooool2o`0000;ooooo0_l00006ooooo`;o00002_ooool2o`0000Cooooo0_l0
0004ooooo`Co0000L_ooool001cooooo00?o0000ooooooooool0Goooool2o`0000Sooooo0_l00005
ooooo`?o00002?ooool2o`0000Gooooo0_l0000<ooooo`;o000000?oooooo`000?l000000oooool2
o`0001[ooooo1ol0000<ooooo`;o00001?ooool2o`0000[ooooo0_l0001^ooooo`007?ooool00ol0
003oooooooooo`1Oooooo`;o000000?oooooo`000?l000003Oooool2o`0000oooooo0_l0000Doooo
o`;o00006_ooool7o`0000Sooooo0_l000000ooooooo0000o`00000;ooooo`;o00001?ooool2o`00
06kooooo000Looooo`03o`000?oooooooooo06;ooooo0_l00004ooooo`;o00002oooool2o`0000Ko
oooo0_l00003ooooo`;o00001?ooool2o`0000_ooooo1_l0000Gooooo`;o00003oooool5o`0000_o
oooo0_l0001dooooo`007?ooool00ol0003oooooooooo`1Xooooo`?o00002_ooool2o`0000?ooooo
0_l000001?oooooo0000o`000?ooool2o`0000Kooooo0_l0000;ooooo`Ko00003oooool2o`0000Ko
oooo1?l0000?ooooo`;o00003?ooool2o`0007Cooooo000Looooo`03o`000?oooooooooo06Wooooo
0ol0000;ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Kooooo0_l0000>ooooo`;o0000
4?ooool2o`0000Sooooo0_l0000Fooooo`;o0000Noooool001cooooo00?o0000ooooooooool0J_oo
ool3o`0000[ooooo0_l00006ooooo`;o00001oooool2o`0000kooooo0_l00004ooooo`;o00008Ooo
ool2o`0000Gooooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo0_l0001booooo`007?ooool0
0ol0003oooooooooo`1[ooooo`;o00002Oooool3o`0000;ooooo0_l00002ooooo`;o00007Oooool2
o`0000gooooo0_l00008ooooo`;o00002?ooool2o`0000;ooooo0_l000001?oooooo0000o`000?oo
ool3o`0000;ooooo0_l00003ooooo`;o00006oooool2o`0005Gooooo00001_ooooook^k^oc8b<_l0
003o<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003o
ooooooooo`1fooooo`Oo0000<?ooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`00
00cooooo0_l00004ooooo`Go00000oooool4o`0001_ooooo0_l0001Eooooo`0000KoooooogMgMonH
V9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o
0000ooooooooool0NOooool2o`0000Wooooo1?l00003ooooo`;o00007oooool2o`0000?ooooo0_l0
00000ooooooo0000o`000005ooooo`;o00000_ooool2o`0000_ooooo1?l00003ooooo`;o0000M?oo
ool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool0Loooool2o`0000Gooooo0_l00008ooooo`Co00000ooo
ool2o`0000Gooooo0_l0000:ooooo`;o00001_ooool2o`0000Cooooo0_l00008ooooo`;o00000ooo
ool2o`0000;ooooo0_l00004ooooo`;o0000P_ooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool02Oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0001cooooo`Co00000ooo
ool2o`0000Gooooo0_l0000;ooooo`;o00000_ooool2o`0000[ooooo0_l00006ooooo`;o00003_oo
ool2o`0000Oooooo0_l00004ooooo`;o0000P_ooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool02Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0M?oo
ool3o`0000Gooooo0_l00002ooooo`?o00002oooool2o`0000[ooooo0_l0000Eooooo`;o00001Ooo
ool2o`0000?ooooo1?l000000ooooooo0000o`000003ooooo`;o00001?ooool2o`0007[ooooo0000
0ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go410@okZj^_oooooo^[Zjoa0@
4006ooooo`03o`000?oooooooooo06?ooooo0_l00007ooooo`;o00003_ooool2o`0000;ooooo0_l0
0004ooooo`;o00004Oooool3o`000003ooooool0003o000001;ooooo0_l00005ooooo`;o00000ooo
ool7o`0000?ooooo0_l00004ooooo`;o0000N_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0Hoooool2o`0000Oo
oooo0_l00003ooooo`;o00004oooool2o`00017ooooo0_l00002ooooo`;o00003?ooool2o`0001Co
oooo0_l00004ooooo`;o00005oooool2o`0006Oooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^
kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo077ooooo0_l0000@
ooooo`;o00001Oooool2o`0001[ooooo0_l00002ooooo`?o00006_ooool2o`0001Oooooo0_l0001W
ooooo`007?ooool00ol0003oooooooooo`23ooooo`;o00000_ooool2o`000003ooooool0003o0000
00?ooooo0_l0000@ooooo`;o00000oooool2o`0000;ooooo0_l0000Hooooo`;o00000_ooool3o`00
07kooooo000Looooo`03o`000?oooooooooo07?ooooo0_l0000;ooooo`;o00001Oooool2o`0000Ko
oooo0_l00008ooooo`?o00001Oooool3o`0000[ooooo0ol0000=ooooo`;o00001?ooool2o`0000;o
oooo0ol0001nooooo`007?ooool00ol0003oooooooooo`1^ooooo`;o00000oooool2o`0000?ooooo
0_l00006ooooo`;o000000?oooooo`000?l000005?ooool3o`0000Kooooo0_l0000:ooooo`?o0000
3Oooool2o`0000;ooooo0_l000000ooooooo0000o`000022ooooo`007?ooool00ol0003ooooooooo
o`1^ooooo`;o00002?ooool2o`000004ooooool0003o0000ooooo`;o00000oooool3o`0000Sooooo
0_l00004ooooo`;o00001?ooool4o`0000[ooooo0_l00002ooooo`;o00002?ooool2o`0000[ooooo
0_l000000ooooooo0000o`000022ooooo`007?ooool00ol0003oooooooooo`1kooooo`;o000000Co
ooooo`000?l0003o00000oooool3o`0000Kooooo0ol00004ooooo`;o00001_ooool2o`0000[ooooo
0_l00002ooooo`;o00000_ooool3o`0000?ooooo0_l00007ooooo`;o0000R?ooool001cooooo00?o
0000ooooooooool0OOooool4o`0000Cooooo0_l00006ooooo`?o00008?ooool3o`0000[ooooo1?l0
0028ooooo`007?ooool00ol0003oooooooooo`1mooooo`Co00005_ooool2o`0001;ooooo0_l00002
ooooo`;o00000oooool4o`0000Gooooo0_l00002ooooo`;o0000Q_ooool001cooooo00?o0000oooo
ooooool0Poooool2o`0001;ooooo0_l000000ooooooo0000o`000005ooooo`;o00000oooool2o`00
00?ooooo0_l00002ooooo`Co000000?oooooo`000?l000000_l00008ooooo`?o0000Q_ooool001co
oooo00?o0000ooooooooool0Poooool3o`0000;ooooo0_l00003ooooo`;o00002?ooool2o`000003
ooooool0003o000000Gooooo0_l00003ooooo`;o000000Coooooo`000?l0003o00001?ooool3o`00
00?ooooo1?l00003ooooo`;o000000?oooooo`000?l00000Qoooool001cooooo00?o0000oooooooo
ool0Q?ooool2o`0000;ooooo0_l00003ooooo`?o00001oooool2o`0000cooooo0_l00002ooooo`?o
00001?ooool2o`0000Cooooo1?l00003ooooo`;o00002?ooool2o`00083ooooo000Looooo`03o`00
0?oooooooooo08kooooo1?l00005ooooo`;o00001Oooool6o`000004ooooool0003o0000o`0000Go
oooo0_l00004ooooo`;o00000_ooool5o`0000_ooooo0_l00020ooooo`007?ooool2o`0008_ooooo
0_l000000ooooooo0000o`000003o`0000Gooooo0_l00005ooooo`Ko00000_ooool4o`0000?ooooo
0_l00004ooooo`;o00000oooool4o`0008gooooo000Looooo`03o`000?oooooooooo08[ooooo1ol0
0003ooooo`;o00001_ooool2o`0000?ooooo0_l00005ooooo`;o00002Oooool2o`0000?ooooo0_l0
0002ooooo`;o0000Roooool001cooooo00?o0000ooooooooool0S?ooool2o`0000Kooooo0_l00006
ooooo`;o00005Oooool2o`0000Oooooo0_l0000Jooooo`;o0000Koooool001cooooo00?o0000oooo
ooooool0OOooool2o`0000?ooooo0_l0000=ooooo`;o00002oooool2o`0003Sooooo0_l0001_oooo
o`007?ooool00ol0003oooooooooo`1mooooo`;o00000oooool2o`0000gooooo1?l00005ooooo`;o
00000_ooool2o`0001Kooooo0_l0002Aooooo`007?ooool00ol0003oooooooooo`29ooooo`;o0000
2?ooool2o`0000Gooooo0_l0000Jooooo`;o0000TOooool001cooooo00?o0000ooooooooool0ROoo
ool2o`0000Sooooo0_l0002dooooo`007?ooool00ol0003oooooooooo`2Fooooo`;o00007Oooool2
o`0009;ooooo000Looooo`03o`000?oooooooooo09Kooooo0_l0000Mooooo`;o0000T_ooool001co
oooo00?o0000ooooooooool0V_ooool2o`000:gooooo000Looooo`03o`000?oooooooooo09[ooooo
0_l00003ooooo`;o0000Z?ooool001cooooo00?o0000ooooooooool0Woooool2o`000:Sooooo000L
ooooo`03o`000?oooooooooo0<Cooooo0_l00023ooooo`007?ooool00ol0003oooooooooo`34oooo
o`;o0000Poooool001cooooo00?o0000ooooooooool0U_ooool2o`000;7ooooo000Looooo`03o`00
0?oooooooooo09Kooooo0_l0002aooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0;7ooooo0_l0002Fooooo`007?ooool00ol0003oooooooooo`2aooooo`;o0000
U_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Booooo`Co000000?o410@ooooooooool00oooool00ol0003ooooooooo
o`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom:
ooooo`005?ooool00ol0003oooooooooo`05ooooo`?o0000oooooom:ooooo`005?ooool00ol0003o
ooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o
0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Boooo
o`03oeEEEOmVIVKo00000?ooooooE?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00:7ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0Fooooo`Co000000So
410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000
oa0@4?o<c<`0S?ooool00:;ooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00003?ooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OnHV9So8B4Qonk^
k_ooooooA4A400?ooooo00GoEEEEogMgMoooooooV9RHob4Q8@2<ooooo`00X_ooool01Ol0003ooooo
oooooooooooo000001_ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@
00Cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol0003ooooooooooooooooo000008cooooo002Roooo
o`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000Gooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003oV9RHoooo
oonHV9So8B4Q08cooooo002Rooooo`05o`000?n7QhOoooooojVYZOl000006oooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00omgMgOoIVIVooooo`02ooooo`05
o`000?mEEEGo0000oa0@4?o<c<`0S?ooool00:7ooooo00?o410@o`000?mgMgL00_l000000onHV9So
ooooooooo`0Iooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4007oooo
o`06o`000?oooooooooooooooomEEEGoQhN7Soooool00<;ooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`03omgM
gOl@413oV9RH08kooooo0030ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool01?o<c<coA4A4o`000?l@412<oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1032) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.65105 .64555 Mdot
.60968 .6158 Mdot
.49482 .37342 Mdot
.44883 .58856 Mdot
.71099 .66449 Mdot
.48278 .32485 Mdot
.63674 .41967 Mdot
.68572 .441 Mdot
.49483 .34621 Mdot
.58174 .54439 Mdot
.64142 .44131 Mdot
.41469 .64614 Mdot
.66152 .44441 Mdot
.42736 .59334 Mdot
.4504 .86858 Mdot
.41383 .51684 Mdot
.57606 .61495 Mdot
.33013 .44566 Mdot
.35246 .57598 Mdot
.50042 .29027 Mdot
.6621 .64859 Mdot
.43915 .58557 Mdot
.64169 .64978 Mdot
.42696 .59307 Mdot
.45103 .6014 Mdot
.59153 .63112 Mdot
.62918 .58673 Mdot
.46437 .5724 Mdot
.41624 .61769 Mdot
.68228 .42392 Mdot
.24326 .53975 Mdot
.53802 .85817 Mdot
.34473 .55251 Mdot
.79194 .40806 Mdot
.68218 .44895 Mdot
.5353 .79697 Mdot
.49842 .32277 Mdot
.67409 .42401 Mdot
.67889 .45068 Mdot
.66715 .40107 Mdot
.67633 .4406 Mdot
.59581 .62669 Mdot
.6278 .39473 Mdot
.70104 .48168 Mdot
.36406 .58047 Mdot
.71764 .57173 Mdot
.28889 .65226 Mdot
.39463 .55304 Mdot
.57795 .61731 Mdot
.51742 .32618 Mdot
.77884 .42007 Mdot
.63831 .4115 Mdot
.45508 .33711 Mdot
.88845 .58206 Mdot
.66607 .41756 Mdot
.36343 .59186 Mdot
.50584 .35338 Mdot
.43498 .5766 Mdot
.4259 .5891 Mdot
.3811 .74472 Mdot
.47038 .57577 Mdot
.29932 .40828 Mdot
.59267 .66471 Mdot
.3916 .41228 Mdot
.49513 .33393 Mdot
.67295 .45343 Mdot
.61072 .60475 Mdot
.65994 .43785 Mdot
.42526 .63771 Mdot
.49481 .40595 Mdot
.39637 .55289 Mdot
.66476 .45413 Mdot
.61486 .59205 Mdot
.41279 .55326 Mdot
.5586 .21257 Mdot
.26111 .73108 Mdot
.3341 .39406 Mdot
.45021 .77388 Mdot
.40019 .76944 Mdot
.37297 .32343 Mdot
.39728 .60778 Mdot
.21857 .38603 Mdot
.37196 .81583 Mdot
.63245 .65487 Mdot
.37219 .5205 Mdot
.55705 .39911 Mdot
.41875 .55519 Mdot
.6573 .55319 Mdot
.37252 .60011 Mdot
.67003 .24398 Mdot
.4909 .34959 Mdot
.62425 .63564 Mdot
.44635 .59074 Mdot
.47333 .60235 Mdot
.40629 .68896 Mdot
.4454 .53942 Mdot
.45934 .5718 Mdot
.64633 .60829 Mdot
.63791 .44575 Mdot
.49693 .62273 Mdot
.61102 .43246 Mdot
.46231 .36556 Mdot
.38699 .542 Mdot
.51222 .34713 Mdot
.63472 .59688 Mdot
.41428 .54768 Mdot
.65623 .46652 Mdot
.38346 .57374 Mdot
.74066 .39476 Mdot
.61112 .61282 Mdot
.46916 .6063 Mdot
.30103 .39198 Mdot
.42766 .2033 Mdot
.62908 .63661 Mdot
.39563 .30415 Mdot
.38534 .60307 Mdot
.44714 .56483 Mdot
.60931 .61844 Mdot
.47984 .38229 Mdot
.64231 .55679 Mdot
.59777 .66141 Mdot
.67463 .40161 Mdot
.59679 .66384 Mdot
.34603 .5374 Mdot
.48714 .33726 Mdot
.60222 .38168 Mdot
.57201 .3996 Mdot
.22555 .50053 Mdot
.42358 .55817 Mdot
.73899 .49456 Mdot
.47155 .3321 Mdot
.61507 .63367 Mdot
.65603 .43783 Mdot
.5016 .56797 Mdot
.63512 .61998 Mdot
.6453 .42438 Mdot
.33022 .40099 Mdot
.61831 .3165 Mdot
.58057 .64 Mdot
.73038 .44471 Mdot
.61974 .43988 Mdot
.65527 .39924 Mdot
.78796 .38439 Mdot
.60181 .61094 Mdot
.32576 .4162 Mdot
.65295 .4232 Mdot
.26681 .59754 Mdot
.37385 .61645 Mdot
.2488 .44562 Mdot
.19621 .36551 Mdot
.77861 .39 Mdot
.62922 .27895 Mdot
.29748 .43425 Mdot
.64319 .40178 Mdot
.44923 .61045 Mdot
.5845 .61844 Mdot
.59095 .61788 Mdot
.44008 .54374 Mdot
.4539 .59286 Mdot
.40144 .55134 Mdot
.45748 .61278 Mdot
.34238 .74912 Mdot
.37854 .571 Mdot
.1796 .48316 Mdot
.62527 .64201 Mdot
.46435 .59368 Mdot
.50106 .38228 Mdot
.43853 .62851 Mdot
.67428 .44674 Mdot
.44273 .57756 Mdot
.45273 .58703 Mdot
.47745 .5925 Mdot
.63541 .41684 Mdot
.52963 .84571 Mdot
.24028 .31112 Mdot
.63911 .77178 Mdot
.45048 .27218 Mdot
.47804 .31423 Mdot
.42898 .55483 Mdot
.3077 .41933 Mdot
.5486 .77819 Mdot
.4033 .60339 Mdot
.53529 .14254 Mdot
.4569 .5753 Mdot
.69468 .68355 Mdot
.36969 .50427 Mdot
.65834 .76358 Mdot
.22542 .42019 Mdot
.43834 .61698 Mdot
.46652 .67316 Mdot
.6443 .71196 Mdot
.72308 .4419 Mdot
.67479 .43927 Mdot
.49775 .38377 Mdot
.50171 .36281 Mdot
.67761 .48033 Mdot
.53059 .58422 Mdot
.51089 .5762 Mdot
.48941 .60785 Mdot
.4771 .39598 Mdot
.58791 .6652 Mdot
.32882 .43645 Mdot
.64399 .60975 Mdot
.14869 .59908 Mdot
.74697 .38843 Mdot
.62588 .48763 Mdot
.32495 .39056 Mdot
.48278 .37135 Mdot
.46115 .36573 Mdot
.3118 .42497 Mdot
.39455 .57504 Mdot
.60431 .60581 Mdot
.82899 .51167 Mdot
.5153 .55551 Mdot
.83622 .46767 Mdot
.60194 .59623 Mdot
.61706 .52727 Mdot
.64524 .43403 Mdot
.49728 .30709 Mdot
.44978 .56494 Mdot
.40624 .57159 Mdot
.66372 .652 Mdot
.39856 .55479 Mdot
.55083 .65226 Mdot
.44981 .55905 Mdot
.67609 .35587 Mdot
.33526 .39431 Mdot
.67905 .47923 Mdot
.21761 .49535 Mdot
.64626 .62763 Mdot
.25221 .39096 Mdot
.50168 .39351 Mdot
.51543 .79089 Mdot
.65871 .45641 Mdot
.31002 .39196 Mdot
.49776 .39824 Mdot
.3249 .4395 Mdot
.4084 .62974 Mdot
.46348 .32299 Mdot
.29368 .40067 Mdot
.44178 .82139 Mdot
.39017 .62295 Mdot
.33154 .74705 Mdot
.63158 .42869 Mdot
.59081 .65852 Mdot
.46953 .57486 Mdot
.49611 .29591 Mdot
.34834 .54258 Mdot
.59387 .24217 Mdot
.60488 .38151 Mdot
.46343 .30577 Mdot
.38859 .37888 Mdot
.31121 .39473 Mdot
.54785 .24177 Mdot
.74604 .46879 Mdot
.58065 .61049 Mdot
.38428 .53982 Mdot
.61853 .80653 Mdot
.65288 .42384 Mdot
.39274 .58113 Mdot
.64383 .35684 Mdot
.65581 .424 Mdot
.43364 .57464 Mdot
.62811 .44698 Mdot
.59178 .61446 Mdot
.33226 .2628 Mdot
.57669 .6132 Mdot
.37558 .60176 Mdot
.646 .46538 Mdot
.46269 .35287 Mdot
.59097 .63495 Mdot
.3856 .56891 Mdot
.43485 .54854 Mdot
.54425 .4131 Mdot
.46733 .59724 Mdot
.58241 .81542 Mdot
.47243 .59406 Mdot
.50352 .37201 Mdot
.45144 .54438 Mdot
.64602 .19742 Mdot
.56813 .33123 Mdot
.60954 .6047 Mdot
.46694 .30258 Mdot
.49826 .34998 Mdot
.36141 .27845 Mdot
.45164 .3352 Mdot
.38727 .59979 Mdot
.48426 .30056 Mdot
.26783 .44339 Mdot
.66486 .41065 Mdot
.40332 .53111 Mdot
.64993 .51148 Mdot
.52144 .3425 Mdot
.47225 .38781 Mdot
.44843 .51689 Mdot
.61765 .58714 Mdot
.44732 .59109 Mdot
.47486 .38518 Mdot
.61586 .67124 Mdot
.37385 .59028 Mdot
.44412 .48691 Mdot
.54446 .41431 Mdot
.64319 .41657 Mdot
.38771 .5032 Mdot
.38342 .55487 Mdot
.50385 .33124 Mdot
.63572 .60738 Mdot
.68778 .44144 Mdot
.60015 .636 Mdot
.75755 .6465 Mdot
.71441 .37405 Mdot
.39427 .7877 Mdot
.27177 .41304 Mdot
.65214 .26757 Mdot
.68665 .74731 Mdot
.49987 .21655 Mdot
.28973 .52469 Mdot
.79449 .62928 Mdot
.48809 .39168 Mdot
.66461 .34708 Mdot
.50115 .35335 Mdot
.42709 .60984 Mdot
.48862 .32841 Mdot
.67768 .75768 Mdot
.45323 .5625 Mdot
.49007 .3183 Mdot
.33453 .27651 Mdot
.45976 .58968 Mdot
.63152 .63561 Mdot
.43545 .85643 Mdot
.53694 .19207 Mdot
.75568 .38129 Mdot
.46628 .32951 Mdot
.30249 .59178 Mdot
.46437 .57725 Mdot
.48046 .58562 Mdot
.5853 .63645 Mdot
.4328 .53427 Mdot
.32524 .43775 Mdot
.3333 .39765 Mdot
.43616 .45024 Mdot
.24714 .32331 Mdot
.48424 .62996 Mdot
.58933 .63546 Mdot
.33523 .71524 Mdot
.58198 .21272 Mdot
.45989 .26532 Mdot
.66405 .39113 Mdot
.50537 .84368 Mdot
.52185 .57991 Mdot
.62036 .39777 Mdot
.67918 .49692 Mdot
.62247 .62411 Mdot
.54579 .84109 Mdot
.67394 .43332 Mdot
.50675 .68838 Mdot
.36908 .66468 Mdot
.40112 .57569 Mdot
.64859 .45315 Mdot
.43417 .64529 Mdot
.6152 .19584 Mdot
.26343 .64672 Mdot
.18901 .45118 Mdot
.36886 .58345 Mdot
.53182 .21826 Mdot
.44677 .57238 Mdot
.64943 .56954 Mdot
.47263 .59104 Mdot
.60288 .64165 Mdot
.58115 .55586 Mdot
.50933 .43337 Mdot
.20762 .36144 Mdot
.74791 .39249 Mdot
.29871 .43502 Mdot
.44405 .5575 Mdot
.40219 .57633 Mdot
.33195 .41291 Mdot
.63055 .65081 Mdot
.454 .61383 Mdot
.30683 .46868 Mdot
.40683 .55884 Mdot
.67854 .43551 Mdot
.19932 .50724 Mdot
.65447 .60173 Mdot
.45477 .54122 Mdot
.62904 .66788 Mdot
.64625 .41314 Mdot
.68283 .44396 Mdot
.45806 .52622 Mdot
.69179 .42181 Mdot
.45389 .57901 Mdot
.21605 .59499 Mdot
.61062 .65633 Mdot
.45432 .5072 Mdot
.64322 .64215 Mdot
.44869 .78009 Mdot
.65733 .46779 Mdot
.64275 .36724 Mdot
.49237 .63522 Mdot
.67214 .43701 Mdot
.75625 .41734 Mdot
.49415 .61246 Mdot
.38735 .52551 Mdot
.698 .27154 Mdot
.46461 .34054 Mdot
.52939 .4181 Mdot
.67287 .46264 Mdot
.38596 .55269 Mdot
.41509 .52834 Mdot
.64555 .41098 Mdot
.44091 .70418 Mdot
.40771 .2539 Mdot
.46245 .57172 Mdot
.60911 .6473 Mdot
.61296 .63428 Mdot
.36938 .56423 Mdot
.38679 .58231 Mdot
.4796 .35979 Mdot
.46836 .30311 Mdot
.49004 .28554 Mdot
.5433 .41459 Mdot
.65735 .36138 Mdot
.75155 .58437 Mdot
.66603 .40099 Mdot
.75515 .51004 Mdot
.64502 .2285 Mdot
.35354 .6092 Mdot
.47375 .31208 Mdot
.40864 .58227 Mdot
.44622 .58717 Mdot
.68829 .44076 Mdot
.71493 .35462 Mdot
.32671 .56471 Mdot
.59786 .65613 Mdot
.67529 .46232 Mdot
.50689 .60998 Mdot
.781 .53396 Mdot
.29561 .40488 Mdot
.75203 .34446 Mdot
.66535 .45545 Mdot
.62684 .62471 Mdot
.63469 .46177 Mdot
.40446 .56927 Mdot
.35831 .58605 Mdot
.61523 .62383 Mdot
.29149 .39744 Mdot
.47172 .61959 Mdot
.43577 .5725 Mdot
.34171 .19443 Mdot
.54574 .20971 Mdot
.5984 .3952 Mdot
.4501 .6126 Mdot
.42195 .52624 Mdot
.32581 .44353 Mdot
.40512 .56257 Mdot
.42734 .54325 Mdot
.37735 .21443 Mdot
.591 .43361 Mdot
.34105 .44242 Mdot
.51238 .69235 Mdot
.59596 .59737 Mdot
.58255 .83375 Mdot
.49594 .30175 Mdot
.68977 .46407 Mdot
.41626 .23644 Mdot
.45666 .34049 Mdot
.60891 .24421 Mdot
.56752 .84225 Mdot
.53425 .41723 Mdot
.33562 .46279 Mdot
.34574 .61364 Mdot
.45493 .55873 Mdot
.44469 .56796 Mdot
.3137 .41791 Mdot
.59804 .61081 Mdot
.45316 .44019 Mdot
.27363 .70288 Mdot
.44512 .5803 Mdot
.54428 .6421 Mdot
.44993 .83126 Mdot
.50163 .41434 Mdot
.32042 .43705 Mdot
.29789 .38738 Mdot
.44366 .55956 Mdot
.38955 .22008 Mdot
.59025 .63056 Mdot
.38557 .56984 Mdot
.3786 .58552 Mdot
.46522 .32848 Mdot
.61741 .61155 Mdot
.48721 .39287 Mdot
.64079 .36948 Mdot
.68273 .71288 Mdot
.36218 .17643 Mdot
.67508 .45799 Mdot
.57164 .80492 Mdot
.67432 .41469 Mdot
.21614 .41181 Mdot
.45557 .33504 Mdot
.3973 .60425 Mdot
.64003 .61292 Mdot
.38368 .56949 Mdot
.39673 .59005 Mdot
.39532 .57608 Mdot
.46478 .63264 Mdot
.561 .15302 Mdot
.30082 .42328 Mdot
.45668 .54025 Mdot
.49963 .37165 Mdot
.57047 .81065 Mdot
.3067 .76196 Mdot
.41175 .57531 Mdot
.43298 .54989 Mdot
.63533 .63262 Mdot
.4368 .54048 Mdot
.6642 .41156 Mdot
.63481 .60568 Mdot
.47024 .60648 Mdot
.53031 .83223 Mdot
.41951 .61986 Mdot
.65768 .75769 Mdot
.63562 .46331 Mdot
.75318 .42386 Mdot
.48231 .57246 Mdot
.59814 .38427 Mdot
.5292 .41815 Mdot
.48874 .29446 Mdot
.67254 .47253 Mdot
.49811 .32475 Mdot
.2389 .65408 Mdot
.34727 .57274 Mdot
.44948 .60863 Mdot
.40903 .52853 Mdot
.48024 .30753 Mdot
.67647 .57243 Mdot
.57082 .26195 Mdot
.51185 .60197 Mdot
.47639 .34485 Mdot
.60299 .66809 Mdot
.40481 .4134 Mdot
.64272 .62198 Mdot
.34735 .42915 Mdot
.64361 .44352 Mdot
.29311 .42215 Mdot
.77139 .39125 Mdot
.61137 .61485 Mdot
.66586 .64936 Mdot
.4809 .31416 Mdot
.5903 .48316 Mdot
.85687 .61622 Mdot
.5111 .41293 Mdot
.25087 .4786 Mdot
.59058 .64352 Mdot
.3865 .61117 Mdot
.20989 .44957 Mdot
.60058 .49752 Mdot
.4985 .32934 Mdot
.41273 .60652 Mdot
.36019 .23986 Mdot
.47861 .35873 Mdot
.39743 .53177 Mdot
.47638 .37449 Mdot
.66565 .45071 Mdot
.46948 .3432 Mdot
.57298 .60587 Mdot
.4178 .54864 Mdot
.84471 .63659 Mdot
.26095 .38017 Mdot
.47094 .59644 Mdot
.67151 .4647 Mdot
.44213 .46996 Mdot
.40739 .59183 Mdot
.33972 .4203 Mdot
.48436 .33664 Mdot
.53307 .37246 Mdot
.46613 .57652 Mdot
.4774 .31987 Mdot
.64906 .6457 Mdot
.67147 .47365 Mdot
.36838 .41028 Mdot
.61798 .37422 Mdot
.58295 .63204 Mdot
.69528 .37683 Mdot
.68732 .45488 Mdot
.42912 .52909 Mdot
.37744 .56829 Mdot
.61346 .64379 Mdot
.28202 .30812 Mdot
.45965 .55377 Mdot
.39755 .60777 Mdot
.49882 .37563 Mdot
.49372 .31289 Mdot
.29177 .30202 Mdot
.47728 .37979 Mdot
.35581 .58711 Mdot
.61162 .64314 Mdot
.43748 .59682 Mdot
.63275 .62661 Mdot
.41895 .5379 Mdot
.55822 .64095 Mdot
.62233 .65611 Mdot
.52687 .24859 Mdot
.426 .60307 Mdot
.38383 .5017 Mdot
.39589 .58314 Mdot
.4025 .55501 Mdot
.48416 .36215 Mdot
.31833 .43288 Mdot
.48877 .55373 Mdot
.33911 .45221 Mdot
.33501 .42733 Mdot
.65482 .70496 Mdot
.46531 .33274 Mdot
.31539 .40799 Mdot
.36214 .77692 Mdot
.4753 .29972 Mdot
.30412 .4139 Mdot
.33622 .78205 Mdot
.67836 .45515 Mdot
.57586 .60826 Mdot
.45916 .59057 Mdot
.79552 .62041 Mdot
.22898 .59281 Mdot
.45735 .33603 Mdot
.47178 .59719 Mdot
.40913 .58544 Mdot
.61362 .66261 Mdot
.15442 .50345 Mdot
.51651 .35691 Mdot
.43431 .60906 Mdot
.61524 .60538 Mdot
.148 .44256 Mdot
.50677 .36709 Mdot
.3072 .41579 Mdot
.63566 .41514 Mdot
.56017 .60541 Mdot
.57109 .39833 Mdot
.64115 .41162 Mdot
.55031 .27645 Mdot
.76234 .39704 Mdot
.38491 .60246 Mdot
.47429 .31152 Mdot
.76966 .34769 Mdot
.53102 .59469 Mdot
.68779 .38599 Mdot
.31589 .61151 Mdot
.62436 .62668 Mdot
.66158 .41226 Mdot
.29488 .42839 Mdot
.61232 .59405 Mdot
.62179 .65169 Mdot
.68901 .43116 Mdot
.38204 .45225 Mdot
.61347 .52188 Mdot
.68123 .43791 Mdot
.67534 .25267 Mdot
.78676 .59397 Mdot
.47829 .30088 Mdot
.33409 .42536 Mdot
.81722 .49851 Mdot
.59582 .62762 Mdot
.50912 .84302 Mdot
.75394 .333 Mdot
.45952 .57209 Mdot
.31878 .40612 Mdot
.70872 .59311 Mdot
.25679 .68436 Mdot
.65717 .42238 Mdot
.53317 .43119 Mdot
.28242 .39792 Mdot
.46016 .56171 Mdot
.31733 .64251 Mdot
.4168 .61041 Mdot
.64236 .43598 Mdot
.37979 .75465 Mdot
.62763 .62458 Mdot
.68302 .45692 Mdot
.75274 .3462 Mdot
.45088 .57983 Mdot
.41816 .60657 Mdot
.22526 .52806 Mdot
.59254 .60652 Mdot
.49413 .2929 Mdot
.38628 .60187 Mdot
.439 .57469 Mdot
.38246 .52415 Mdot
.4427 .50574 Mdot
.41997 .20675 Mdot
.43214 .60852 Mdot
.69278 .36109 Mdot
.45683 .54239 Mdot
.42539 .601 Mdot
.62456 .66882 Mdot
.41414 .15934 Mdot
.65095 .36616 Mdot
.44223 .57614 Mdot
.39287 .6145 Mdot
.68995 .43219 Mdot
.5696 .52125 Mdot
.59644 .48738 Mdot
.55412 .406 Mdot
.28911 .54852 Mdot
.45983 .63436 Mdot
.63089 .60892 Mdot
.30037 .39044 Mdot
.37242 .56129 Mdot
.62969 .60898 Mdot
.43658 .62287 Mdot
.47617 .35382 Mdot
.47352 .30179 Mdot
.73881 .44553 Mdot
.30882 .40916 Mdot
.22697 .56703 Mdot
.74761 .52348 Mdot
.49555 .38209 Mdot
.45179 .60529 Mdot
.67194 .47963 Mdot
.47236 .38334 Mdot
.56322 .40349 Mdot
.42723 .50985 Mdot
.58717 .62203 Mdot
.6261 .63698 Mdot
.24836 .44369 Mdot
.62649 .30004 Mdot
.3326 .21568 Mdot
.6616 .45215 Mdot
.47955 .59963 Mdot
.73922 .4818 Mdot
.62768 .63663 Mdot
.2204 .44833 Mdot
.31366 .4062 Mdot
.65675 .42078 Mdot
.46017 .26645 Mdot
.63478 .62249 Mdot
.57692 .62898 Mdot
.38094 .61234 Mdot
.42447 .57072 Mdot
.29057 .5128 Mdot
.34893 .46852 Mdot
.65033 .41152 Mdot
.33388 .41729 Mdot
.49505 .39916 Mdot
.42371 .61285 Mdot
.63747 .65321 Mdot
.81718 .53508 Mdot
.3888 .6112 Mdot
.48156 .36368 Mdot
.62226 .62856 Mdot
.32822 .40552 Mdot
.33715 .42611 Mdot
.40315 .55599 Mdot
.34759 .71652 Mdot
.66678 .42326 Mdot
.63083 .63451 Mdot
.79041 .48428 Mdot
.45618 .54798 Mdot
.42743 .56676 Mdot
.34215 .52795 Mdot
.68361 .42012 Mdot
.74724 .4402 Mdot
.28646 .40031 Mdot
.5987 .61911 Mdot
.43019 .61872 Mdot
.30128 .4071 Mdot
.74687 .45478 Mdot
.45986 .32033 Mdot
.47053 .35437 Mdot
.33938 .42203 Mdot
.32812 .41173 Mdot
.33667 .41186 Mdot
.49628 .84737 Mdot
.5699 .60777 Mdot
.44573 .50029 Mdot
.46965 .5671 Mdot
.24107 .44357 Mdot
.50244 .57963 Mdot
.63884 .46808 Mdot
.46547 .34955 Mdot
.39835 .58708 Mdot
.37563 .60034 Mdot
.36594 .50977 Mdot
.41524 .4955 Mdot
.65076 .59969 Mdot
.61323 .61218 Mdot
.34466 .58556 Mdot
.46314 .33182 Mdot
.14144 .57256 Mdot
.75009 .71873 Mdot
.47956 .56486 Mdot
.59768 .5108 Mdot
.63788 .65165 Mdot
.68206 .41247 Mdot
.57384 .44431 Mdot
.63387 .45806 Mdot
.60355 .62418 Mdot
.42601 .61163 Mdot
.7585 .51677 Mdot
.33725 .4329 Mdot
.3928 .55024 Mdot
.64769 .42873 Mdot
.39704 .55027 Mdot
.64015 .4125 Mdot
.73862 .64683 Mdot
.63166 .21417 Mdot
.45713 .57458 Mdot
.43548 .52779 Mdot
.31015 .59568 Mdot
.41305 .57689 Mdot
.31436 .35449 Mdot
.63772 .64965 Mdot
.28221 .27596 Mdot
.38631 .61869 Mdot
.51253 .7553 Mdot
.46264 .55484 Mdot
.36356 .24425 Mdot
.42168 .56666 Mdot
.47653 .42534 Mdot
.45951 .56529 Mdot
.41968 .54429 Mdot
.63985 .4627 Mdot
.68962 .43349 Mdot
.65845 .63231 Mdot
.49525 .29502 Mdot
.63133 .78221 Mdot
.43355 .57006 Mdot
.61732 .37366 Mdot
.63083 .38199 Mdot
.33087 .41677 Mdot
.60183 .62528 Mdot
.14291 .46 Mdot
.62907 .42969 Mdot
.44121 .25996 Mdot
.26949 .33045 Mdot
.57335 .3967 Mdot
.56124 .4107 Mdot
.61988 .55499 Mdot
.30618 .39473 Mdot
.46247 .56363 Mdot
.79636 .42971 Mdot
.55756 .21714 Mdot
.49885 .55711 Mdot
.67891 .46344 Mdot
.52757 .78139 Mdot
.81617 .51088 Mdot
.29079 .38658 Mdot
.28921 .4168 Mdot
.63548 .41912 Mdot
.51471 .3206 Mdot
.4028 .64017 Mdot
.31136 .40407 Mdot
.48632 .38243 Mdot
.47999 .29637 Mdot
.44534 .31039 Mdot
.59122 .62661 Mdot
.75359 .35835 Mdot
.71804 .55397 Mdot
.64044 .4142 Mdot
.2566 .39099 Mdot
.56718 .59891 Mdot
.59726 .58889 Mdot
.49031 .30371 Mdot
.4861 .3652 Mdot
.586 .59682 Mdot
.36373 .60587 Mdot
.35004 .51164 Mdot
.44517 .57775 Mdot
.31823 .42168 Mdot
.41528 .56939 Mdot
.48024 .35398 Mdot
.65808 .4283 Mdot
.49086 .36393 Mdot
.62741 .43951 Mdot
.75701 .5694 Mdot
.38924 .56687 Mdot
.42432 .54713 Mdot
.22491 .58937 Mdot
.65258 .64687 Mdot
.77702 .42989 Mdot
.6755 .35347 Mdot
.50165 .35736 Mdot
.43008 .54323 Mdot
.64819 .63696 Mdot
.31221 .38268 Mdot
.22195 .58687 Mdot
.38125 .55254 Mdot
.64027 .64824 Mdot
.43958 .61048 Mdot
.39545 .79846 Mdot
.51732 .18553 Mdot
.60443 .63669 Mdot
.19251 .38225 Mdot
.41807 .61664 Mdot
.57486 .56559 Mdot
.38878 .53234 Mdot
.28602 .46984 Mdot
.45702 .5506 Mdot
.60182 .59612 Mdot
.43973 .58083 Mdot
.61825 .59598 Mdot
.50618 .375 Mdot
.67051 .4028 Mdot
.5913 .64733 Mdot
.37611 .57245 Mdot
.59896 .85549 Mdot
.64596 .44305 Mdot
.4473 .5615 Mdot
.63509 .44457 Mdot
.61302 .60178 Mdot
.57816 .62729 Mdot
.25972 .70305 Mdot
.59015 .40884 Mdot
.66699 .44965 Mdot
.43953 .60549 Mdot
.68267 .53665 Mdot
.43307 .60196 Mdot
.27661 .50452 Mdot
.36281 .5691 Mdot
.45346 .5462 Mdot
.25697 .72761 Mdot
.66447 .4095 Mdot
.34697 .21328 Mdot
.28285 .71482 Mdot
.48064 .84691 Mdot
.55604 .61737 Mdot
.29247 .38634 Mdot
.54121 .84174 Mdot
.63293 .37153 Mdot
.47564 .33388 Mdot
.39818 .5852 Mdot
.64145 .58505 Mdot
.67308 .42153 Mdot
.31687 .43169 Mdot
.45674 .57367 Mdot
.48546 .36702 Mdot
.41604 .26041 Mdot
.64814 .39816 Mdot
.59633 .62619 Mdot
.60472 .65839 Mdot
.17074 .39557 Mdot
.43617 .6181 Mdot
.4294 .54608 Mdot
.64168 .43847 Mdot
.51283 .55827 Mdot
.31484 .39428 Mdot
.37192 .25388 Mdot
.66522 .45007 Mdot
.56433 .47591 Mdot
.60572 .60946 Mdot
.40835 .58412 Mdot
.6885 .59516 Mdot
.44963 .27924 Mdot
.5558 .69367 Mdot
.31086 .41967 Mdot
.27192 .51165 Mdot
.60062 .59629 Mdot
.65362 .43393 Mdot
.6291 .32187 Mdot
.35516 .53349 Mdot
.41453 .58515 Mdot
.26705 .51275 Mdot
.41547 .4485 Mdot
.18838 .46095 Mdot
.39222 .53623 Mdot
.42868 .44448 Mdot
.40129 .53749 Mdot
.3668 .52909 Mdot
.35936 .59263 Mdot
.4273 .56132 Mdot
.63942 .64946 Mdot
.47408 .52757 Mdot
.47411 .32655 Mdot
.41593 .68816 Mdot
.55734 .43079 Mdot
.46966 .5842 Mdot
.42591 .60857 Mdot
.58709 .72263 Mdot
.62592 .39217 Mdot
.61104 .65265 Mdot
.63822 .6763 Mdot
.68795 .41371 Mdot
.36372 .50697 Mdot
.50196 .30606 Mdot
.45268 .51713 Mdot
.48702 .36057 Mdot
.64498 .64267 Mdot
.50395 .35929 Mdot
.66187 .39765 Mdot
.47264 .31198 Mdot
.66566 .35901 Mdot
.66671 .41428 Mdot
.58561 .61258 Mdot
.4118 .55426 Mdot
.67573 .46149 Mdot
.22955 .52692 Mdot
.3177 .42097 Mdot
.26176 .70788 Mdot
.42862 .62265 Mdot
.58169 .42864 Mdot
.44143 .48562 Mdot
.49033 .36205 Mdot
.4623 .18913 Mdot
.61985 .65629 Mdot
.34514 .42106 Mdot
.64588 .64285 Mdot
.70788 .26557 Mdot
.326 .43024 Mdot
.34492 .78838 Mdot
.65604 .30601 Mdot
.52734 .35076 Mdot
.36693 .60964 Mdot
.33827 .65258 Mdot
.4901 .40259 Mdot
.6718 .4204 Mdot
.63883 .29529 Mdot
.41537 .54415 Mdot
.5024 .21984 Mdot
.66 .63175 Mdot
.48766 .29713 Mdot
.65892 .43955 Mdot
.68369 .45374 Mdot
.38172 .57767 Mdot
.32065 .30419 Mdot
.39382 .54276 Mdot
.6101 .29459 Mdot
.28363 .53881 Mdot
.32806 .54109 Mdot
.44868 .55837 Mdot
.51165 .35098 Mdot
.44021 .60992 Mdot
.31875 .5378 Mdot
.78875 .39354 Mdot
.4703 .62816 Mdot
.70567 .3544 Mdot
.26134 .38893 Mdot
.61275 .61998 Mdot
.48749 .57583 Mdot
.58172 .39208 Mdot
.43527 .61623 Mdot
.75691 .26405 Mdot
.3029 .41203 Mdot
.59232 .37609 Mdot
.45541 .54314 Mdot
.38311 .58828 Mdot
.37905 .65678 Mdot
.62791 .57535 Mdot
.45632 .26592 Mdot
.42119 .58338 Mdot
.27301 .57632 Mdot
.64532 .45284 Mdot
.38856 .54454 Mdot
.44542 .5658 Mdot
.66305 .70855 Mdot
.68667 .43283 Mdot
.49687 .36455 Mdot
.45538 .33979 Mdot
.50454 .40051 Mdot
.31128 .44686 Mdot
.54493 .44427 Mdot
.23201 .44746 Mdot
.53157 .19639 Mdot
.3153 .38923 Mdot
.40775 .6215 Mdot
.32317 .59044 Mdot
.39788 .61385 Mdot
.29628 .431 Mdot
.68438 .42533 Mdot
.60889 .65367 Mdot
.71384 .48414 Mdot
.49087 .40795 Mdot
.40324 .53078 Mdot
.31721 .44038 Mdot
.58494 .61965 Mdot
.31949 .37484 Mdot
.60573 .61858 Mdot
.66761 .44549 Mdot
.69632 .42795 Mdot
.30839 .43302 Mdot
.64462 .62866 Mdot
.69612 .3704 Mdot
.26712 .68761 Mdot
.36063 .57037 Mdot
.71423 .43941 Mdot
.65256 .63972 Mdot
.64529 .59896 Mdot
.64866 .61354 Mdot
.39599 .55697 Mdot
.5932 .51164 Mdot
.39521 .51876 Mdot
.64713 .41371 Mdot
.47734 .37464 Mdot
.29625 .45987 Mdot
.7862 .57591 Mdot
.28007 .44648 Mdot
.46835 .61787 Mdot
.44718 .58233 Mdot
.444 .55994 Mdot
.3668 .5895 Mdot
.60662 .31107 Mdot
.38743 .57653 Mdot
.63668 .45851 Mdot
.48465 .34648 Mdot
.47096 .57617 Mdot
.45872 .32708 Mdot
.63553 .544 Mdot
.29955 .38965 Mdot
.53537 .43957 Mdot
.60156 .83108 Mdot
.58362 .62427 Mdot
.47635 .3801 Mdot
.47639 .33108 Mdot
.32951 .40037 Mdot
.67387 .42489 Mdot
.60264 .61346 Mdot
.30108 .47679 Mdot
.33581 .4145 Mdot
.43982 .57841 Mdot
.50608 .25652 Mdot
.48377 .23183 Mdot
.45109 .54984 Mdot
.40151 .59753 Mdot
.46272 .30722 Mdot
.51698 .32862 Mdot
.84846 .48538 Mdot
.20256 .46592 Mdot
.3134 .43378 Mdot
.29193 .39878 Mdot
.61378 .58705 Mdot
.44762 .52876 Mdot
.64428 .41547 Mdot
.19977 .51991 Mdot
.42979 .46296 Mdot
.21811 .5526 Mdot
.37052 .40867 Mdot
.38046 .56251 Mdot
.36145 .69786 Mdot
.45239 .58041 Mdot
.62012 .65925 Mdot
.60262 .60236 Mdot
.597 .64567 Mdot
.66696 .41978 Mdot
.46757 .78545 Mdot
.64585 .46442 Mdot
.63819 .80543 Mdot
.59767 .59578 Mdot
.59514 .3387 Mdot
.50746 .34084 Mdot
.48683 .58375 Mdot
.3209 .39892 Mdot
.61949 .4231 Mdot
.41762 .63811 Mdot
.40051 .21339 Mdot
.47787 .31162 Mdot
.58565 .61093 Mdot
.61834 .55639 Mdot
.7189 .71703 Mdot
.58006 .465 Mdot
.50482 .62053 Mdot
.35623 .65366 Mdot
.33224 .42018 Mdot
.54833 .68992 Mdot
.29667 .43473 Mdot
.65031 .42277 Mdot
.42195 .5495 Mdot
.42021 .55569 Mdot
.41456 .53704 Mdot
.38838 .57356 Mdot
.69012 .4224 Mdot
.48461 .60362 Mdot
.64603 .19743 Mdot
.47313 .3009 Mdot
.42478 .81172 Mdot
.3006 .40177 Mdot
.67201 .47044 Mdot
.48462 .34953 Mdot
.485 .27884 Mdot
.21595 .48099 Mdot
.46094 .56959 Mdot
.39664 .5858 Mdot
.44684 .26335 Mdot
.39735 .53456 Mdot
.50395 .60958 Mdot
.47676 .32368 Mdot
.28653 .45138 Mdot
.31835 .38833 Mdot
.29208 .41804 Mdot
.68431 .43257 Mdot
.64621 .63519 Mdot
.31622 .41324 Mdot
.5054 .37403 Mdot
.44799 .62192 Mdot
.37718 .58749 Mdot
.65353 .63841 Mdot
.75253 .32827 Mdot
.28845 .38852 Mdot
.61578 .55223 Mdot
.62179 .59949 Mdot
.56746 .61005 Mdot
.4153 .58656 Mdot
.49527 .5498 Mdot
.60745 .57962 Mdot
.33664 .40513 Mdot
.67716 .46763 Mdot
.54839 .38937 Mdot
.64395 .42694 Mdot
.59459 .61225 Mdot
.37226 .58025 Mdot
.59442 .60832 Mdot
.45506 .61108 Mdot
.45324 .89014 Mdot
.42175 .56003 Mdot
.56164 .18947 Mdot
.26988 .47452 Mdot
.48151 .32903 Mdot
.6933 .36873 Mdot
.48897 .30124 Mdot
.61606 .59799 Mdot
.37265 .57058 Mdot
.28701 .40368 Mdot
.43083 .84152 Mdot
.57224 .59459 Mdot
.47379 .35095 Mdot
.50621 .30852 Mdot
.67067 .4136 Mdot
.47261 .5776 Mdot
.41115 .58215 Mdot
.49076 .31628 Mdot
.34793 .49693 Mdot
.63891 .62831 Mdot
.43455 .54916 Mdot
.43588 .59201 Mdot
.48111 .32604 Mdot
.26292 .67829 Mdot
.58924 .5717 Mdot
.42731 .55421 Mdot
.6397 .3435 Mdot
.6442 .47044 Mdot
.3672 .60284 Mdot
.48979 .5988 Mdot
.32118 .40478 Mdot
.48451 .81936 Mdot
.79544 .40748 Mdot
.63449 .46482 Mdot
.49684 .29959 Mdot
.42992 .62039 Mdot
.50639 .33752 Mdot
.37682 .58099 Mdot
.58811 .78705 Mdot
.48245 .29794 Mdot
.38931 .59758 Mdot
.46941 .54982 Mdot
.59526 .60382 Mdot
.38565 .57932 Mdot
.61346 .72069 Mdot
.4848 .39521 Mdot
.38675 .58999 Mdot
.35202 .7185 Mdot
.67718 .44983 Mdot
.481 .56559 Mdot
.29394 .40392 Mdot
.29676 .47055 Mdot
.74461 .53705 Mdot
.63341 .36328 Mdot
.29292 .41273 Mdot
.39796 .5479 Mdot
.50722 .3035 Mdot
.63807 .41463 Mdot
.49325 .21317 Mdot
.4321 .54173 Mdot
.64309 .43707 Mdot
.65832 .43052 Mdot
.29696 .41273 Mdot
.28008 .25136 Mdot
.48775 .59796 Mdot
.41244 .57449 Mdot
.63489 .72302 Mdot
.60847 .66629 Mdot
.41445 .56582 Mdot
.39434 .6168 Mdot
.63564 .45492 Mdot
.4979 .63187 Mdot
.55892 .75743 Mdot
.33619 .27411 Mdot
.62263 .43857 Mdot
.52021 .40357 Mdot
.5023 .29418 Mdot
.30325 .40108 Mdot
.61535 .62693 Mdot
.28059 .41005 Mdot
.46818 .32742 Mdot
.4092 .62003 Mdot
.63079 .43309 Mdot
.5865 .68804 Mdot
.63965 .41056 Mdot
.6141 .37108 Mdot
.64334 .65465 Mdot
.72348 .49671 Mdot
.67769 .19626 Mdot
.72335 .56032 Mdot
.6148 .40844 Mdot
.33073 .41659 Mdot
.54597 .27533 Mdot
.43977 .58896 Mdot
.52167 .68004 Mdot
.40716 .55277 Mdot
.36279 .71868 Mdot
.47618 .37701 Mdot
.49162 .28479 Mdot
.42376 .55156 Mdot
.28179 .52859 Mdot
.64628 .40559 Mdot
.66396 .41047 Mdot
.39033 .58984 Mdot
.67237 .43732 Mdot
.42448 .57362 Mdot
.48376 .35929 Mdot
.38965 .19215 Mdot
.45004 .57377 Mdot
.39297 .52347 Mdot
.63156 .49509 Mdot
.27463 .73198 Mdot
.67924 .33158 Mdot
.36167 .69258 Mdot
.73931 .6938 Mdot
.67164 .43736 Mdot
.44056 .51867 Mdot
.51187 .41437 Mdot
.46183 .30873 Mdot
.6957 .37094 Mdot
.40904 .5618 Mdot
.40398 .56239 Mdot
.43242 .54461 Mdot
.41773 .60732 Mdot
.52761 .68337 Mdot
.50365 .54798 Mdot
.40776 .73817 Mdot
.39585 .58844 Mdot
.32011 .65003 Mdot
.67258 .46233 Mdot
.66086 .65179 Mdot
.27848 .40784 Mdot
.38053 .56428 Mdot
.53716 .61302 Mdot
.65155 .47221 Mdot
.6407 .80372 Mdot
.67955 .41983 Mdot
.49811 .3486 Mdot
.67527 .40648 Mdot
.46688 .59995 Mdot
.61356 .63495 Mdot
.55023 .40701 Mdot
.55593 .24172 Mdot
.47545 .33542 Mdot
.47103 .59633 Mdot
.58374 .3771 Mdot
.47392 .33286 Mdot
.6419 .54299 Mdot
.61813 .63405 Mdot
.26763 .57735 Mdot
.60229 .60206 Mdot
.38796 .59738 Mdot
.39171 .60378 Mdot
.70955 .39701 Mdot
.65451 .40079 Mdot
.60765 .60047 Mdot
.32703 .20176 Mdot
.2963 .43534 Mdot
.59652 .64264 Mdot
.34292 .55592 Mdot
.51701 .49188 Mdot
.61719 .64094 Mdot
.32278 .49998 Mdot
.66794 .41707 Mdot
.60184 .59207 Mdot
.34245 .55299 Mdot
.70041 .2949 Mdot
.34277 .4216 Mdot
.5165 .34314 Mdot
.45236 .39875 Mdot
.47778 .3889 Mdot
.68533 .46148 Mdot
.48193 .30946 Mdot
.64803 .45675 Mdot
.77099 .43174 Mdot
.30301 .65543 Mdot
.67322 .48019 Mdot
.69359 .44608 Mdot
.48071 .31551 Mdot
.44525 .55262 Mdot
.46729 .39681 Mdot
.37006 .54672 Mdot
.39411 .63303 Mdot
.65624 .4593 Mdot
.59814 .5978 Mdot
.57311 .61168 Mdot
.32601 .65002 Mdot
.60531 .65892 Mdot
.48673 .36246 Mdot
.52255 .1884 Mdot
.77223 .3962 Mdot
.64674 .44987 Mdot
.69319 .43479 Mdot
.431 .60405 Mdot
.49842 .32677 Mdot
.51042 .37336 Mdot
.65414 .41615 Mdot
.50607 .66185 Mdot
.42725 .52076 Mdot
.66128 .62257 Mdot
.59517 .59587 Mdot
.60796 .64066 Mdot
.64138 .60513 Mdot
.54738 .74207 Mdot
.66697 .41597 Mdot
.60671 .59555 Mdot
.3904 .59485 Mdot
.4054 .56293 Mdot
.55432 .40917 Mdot
.29163 .41481 Mdot
.44387 .6204 Mdot
.35681 .59434 Mdot
.41235 .58754 Mdot
.47043 .35065 Mdot
.3371 .58232 Mdot
.49301 .29217 Mdot
.51756 .3507 Mdot
.46498 .31389 Mdot
.63816 .36879 Mdot
.3399 .64348 Mdot
.76087 .6813 Mdot
.43435 .60927 Mdot
.50956 .5448 Mdot
.50658 .34261 Mdot
.4369 .19702 Mdot
.74328 .45201 Mdot
.43086 .54254 Mdot
.44687 .28725 Mdot
.48978 .31384 Mdot
.59307 .65591 Mdot
.41288 .56107 Mdot
.49461 .41161 Mdot
.30332 .38982 Mdot
.34838 .55562 Mdot
.46177 .36945 Mdot
.64036 .61891 Mdot
.28073 .4264 Mdot
.61096 .59105 Mdot
.46193 .32582 Mdot
.47296 .55417 Mdot
.86785 .60286 Mdot
.50308 .39919 Mdot
.3464 .77365 Mdot
.55345 .59524 Mdot
.43584 .54893 Mdot
.47851 .38432 Mdot
.60884 .66554 Mdot
.68113 .46675 Mdot
.47052 .45377 Mdot
.60987 .65595 Mdot
.49116 .28517 Mdot
.46575 .37702 Mdot
.47637 .32568 Mdot
.61718 .61506 Mdot
.37123 .55541 Mdot
.62682 .61832 Mdot
.67584 .40769 Mdot
.45152 .58985 Mdot
.67728 .75674 Mdot
.50648 .54415 Mdot
.61594 .59888 Mdot
.4923 .37146 Mdot
.32985 .44194 Mdot
.45959 .57906 Mdot
.32672 .75062 Mdot
.46855 .60597 Mdot
.63984 .44367 Mdot
.33831 .24377 Mdot
.58393 .6896 Mdot
.46632 .56174 Mdot
.42957 .60475 Mdot
.65587 .41019 Mdot
.46095 .57266 Mdot
.46281 .55855 Mdot
.61188 .38799 Mdot
.61715 .60972 Mdot
.43968 .5835 Mdot
.48993 .37921 Mdot
.79189 .44122 Mdot
.41252 .51822 Mdot
.40109 .30136 Mdot
.26903 .55761 Mdot
.31305 .24976 Mdot
.40959 .55015 Mdot
.20377 .49688 Mdot
.41054 .60556 Mdot
.39 .55429 Mdot
.438 .60329 Mdot
.36819 .68856 Mdot
.47426 .31547 Mdot
.47872 .34614 Mdot
.34249 .41864 Mdot
.27038 .56226 Mdot
.31834 .40476 Mdot
.6769 .42162 Mdot
.37807 .31292 Mdot
.48135 .2993 Mdot
.64101 .61881 Mdot
.397 .54494 Mdot
.49649 .40558 Mdot
.40565 .58252 Mdot
.46358 .60394 Mdot
.51296 .34956 Mdot
.51583 .36714 Mdot
.60438 .37782 Mdot
.29572 .39524 Mdot
.59589 .6483 Mdot
.39536 .62659 Mdot
.33401 .42863 Mdot
.37239 .55534 Mdot
.2346 .43495 Mdot
.60024 .64953 Mdot
.61983 .61124 Mdot
.57518 .63354 Mdot
.41064 .62006 Mdot
.46857 .58966 Mdot
.64632 .46394 Mdot
.64585 .62782 Mdot
.67881 .44504 Mdot
.54425 .4105 Mdot
.38904 .29359 Mdot
.40884 .56183 Mdot
.58902 .555 Mdot
.31367 .39836 Mdot
.49292 .35091 Mdot
.42603 .26678 Mdot
.3429 .42939 Mdot
.46651 .60626 Mdot
.5114 .34843 Mdot
.29884 .43052 Mdot
.47346 .66122 Mdot
.80425 .63047 Mdot
.31918 .44429 Mdot
.39138 .59391 Mdot
.44015 .65828 Mdot
.25135 .6407 Mdot
.31215 .44598 Mdot
.63346 .4365 Mdot
.41166 .62067 Mdot
.45444 .49733 Mdot
.2863 .39178 Mdot
.78595 .45132 Mdot
.48473 .33005 Mdot
.72096 .33226 Mdot
.36974 .62745 Mdot
.48906 .67932 Mdot
.28402 .42032 Mdot
.60072 .61613 Mdot
.6342 .66876 Mdot
.41697 .59401 Mdot
.30568 .44483 Mdot
.62578 .42751 Mdot
.48686 .33527 Mdot
.67229 .36036 Mdot
.61962 .61651 Mdot
.65627 .5226 Mdot
.48008 .37311 Mdot
.60602 .54812 Mdot
.34547 .25565 Mdot
.33377 .52579 Mdot
.32885 .68321 Mdot
.58069 .22403 Mdot
.39879 .62126 Mdot
.30479 .43934 Mdot
.6483 .47022 Mdot
.63252 .42424 Mdot
.66286 .44944 Mdot
.69028 .36656 Mdot
.56761 .44063 Mdot
.46081 .34575 Mdot
.52982 .23502 Mdot
.30265 .40643 Mdot
.27203 .61132 Mdot
.37565 .55369 Mdot
.44804 .58071 Mdot
.47866 .60094 Mdot
.38768 .54262 Mdot
.41726 .60146 Mdot
.67533 .43044 Mdot
.69102 .36535 Mdot
.53468 .37213 Mdot
.61209 .64795 Mdot
.28169 .44546 Mdot
.50758 .34137 Mdot
.46626 .30304 Mdot
.30598 .42749 Mdot
.64005 .56091 Mdot
.46162 .35889 Mdot
.50247 .36011 Mdot
.46825 .6107 Mdot
.63319 .62004 Mdot
.48094 .53613 Mdot
.39874 .60795 Mdot
.48933 .35244 Mdot
.39504 .41344 Mdot
.58432 .74118 Mdot
.37117 .51779 Mdot
.26979 .40139 Mdot
.58022 .51171 Mdot
.31133 .44526 Mdot
.38392 .53305 Mdot
.42193 .20004 Mdot
.46889 .32572 Mdot
.49871 .33876 Mdot
.30643 .43777 Mdot
.57916 .56839 Mdot
.6208 .62522 Mdot
.48643 .27791 Mdot
.63874 .45039 Mdot
.3932 .60984 Mdot
.40296 .27398 Mdot
.55865 .57385 Mdot
.34229 .29704 Mdot
.65569 .45101 Mdot
.51093 .36696 Mdot
.47196 .57484 Mdot
.39285 .59472 Mdot
.33224 .41555 Mdot
.72277 .65612 Mdot
.34656 .5686 Mdot
.48429 .84773 Mdot
.6449 .22218 Mdot
.72628 .31017 Mdot
.41459 .58497 Mdot
.61542 .61062 Mdot
.45566 .33531 Mdot
.33433 .42357 Mdot
.45248 .62524 Mdot
.79087 .64756 Mdot
.65722 .6474 Mdot
.65089 .42787 Mdot
.51415 .41808 Mdot
.57422 .44359 Mdot
.44149 .61794 Mdot
.40797 .55353 Mdot
.39217 .5624 Mdot
.84069 .54634 Mdot
.4746 .36091 Mdot
.63529 .65618 Mdot
.31031 .42167 Mdot
.60875 .65928 Mdot
.47914 .33815 Mdot
.69143 .51036 Mdot
.46763 .57677 Mdot
.65651 .64557 Mdot
.60245 .61897 Mdot
.67187 .41436 Mdot
.68848 .45966 Mdot
.53383 .4004 Mdot
.42276 .56104 Mdot
.47763 .3979 Mdot
.59285 .6038 Mdot
.47783 .27012 Mdot
.3278 .42865 Mdot
.66075 .46668 Mdot
.39506 .58683 Mdot
.47082 .32823 Mdot
.48445 .60724 Mdot
.62639 .64093 Mdot
.50311 .35924 Mdot
.60169 .38073 Mdot
.29208 .40023 Mdot
.39853 .5717 Mdot
.27432 .39114 Mdot
.49791 .30125 Mdot
.43769 .59163 Mdot
.64811 .57391 Mdot
.27847 .43094 Mdot
.56946 .25653 Mdot
.46294 .35321 Mdot
.61333 .37654 Mdot
.57523 .62943 Mdot
.77999 .46802 Mdot
.49704 .3404 Mdot
.65547 .57703 Mdot
.74965 .6083 Mdot
.39857 .62831 Mdot
.59796 .6315 Mdot
.52811 .26608 Mdot
.55828 .85525 Mdot
.28521 .6884 Mdot
.447 .5624 Mdot
.47259 .37581 Mdot
.31696 .43877 Mdot
.6473 .45083 Mdot
.40151 .29911 Mdot
.31877 .53917 Mdot
.50752 .32484 Mdot
.43412 .6058 Mdot
.60807 .60377 Mdot
.66109 .42103 Mdot
.76305 .5284 Mdot
.5009 .37418 Mdot
.47247 .36956 Mdot
.47019 .57098 Mdot
.31273 .40676 Mdot
.32137 .72024 Mdot
.48069 .35774 Mdot
.45252 .26056 Mdot
.55032 .27445 Mdot
.3173 .44086 Mdot
.40396 .60202 Mdot
.32185 .64243 Mdot
.3672 .59486 Mdot
.36533 .79231 Mdot
.49411 .30141 Mdot
.61762 .64888 Mdot
.40187 .55178 Mdot
.32332 .28079 Mdot
.48959 .34725 Mdot
.59893 .50971 Mdot
.39335 .38997 Mdot
.66666 .41643 Mdot
.43067 .26129 Mdot
.40969 .57052 Mdot
.64371 .40702 Mdot
.31404 .39876 Mdot
.4294 .5579 Mdot
.46755 .59082 Mdot
.60427 .66276 Mdot
.6493 .42186 Mdot
.76734 .61794 Mdot
.68471 .45477 Mdot
.63553 .46279 Mdot
.57206 .63685 Mdot
.42811 .58537 Mdot
.49848 .35228 Mdot
.49157 .3138 Mdot
.41781 .63295 Mdot
.45292 .18106 Mdot
.62227 .62386 Mdot
.25686 .38846 Mdot
.84085 .52437 Mdot
.32754 .55433 Mdot
.42298 .26695 Mdot
.72086 .65574 Mdot
.62682 .4257 Mdot
.39249 .58937 Mdot
.63079 .60701 Mdot
.49075 .27679 Mdot
.48137 .3752 Mdot
.36969 .56979 Mdot
.66173 .42814 Mdot
.31357 .39029 Mdot
.49914 .3968 Mdot
.32259 .3026 Mdot
.38715 .56527 Mdot
.51312 .22776 Mdot
.48509 .38982 Mdot
.46326 .86097 Mdot
.49026 .26801 Mdot
.59956 .6357 Mdot
.46308 .60261 Mdot
.60186 .65719 Mdot
.31647 .42444 Mdot
.52458 .40622 Mdot
.65958 .42796 Mdot
.32359 .56458 Mdot
.75223 .27767 Mdot
.47847 .31387 Mdot
.63739 .65044 Mdot
.46675 .56195 Mdot
.33679 .61332 Mdot
.41564 .57166 Mdot
.4432 .65492 Mdot
.26299 .3828 Mdot
.66278 .45856 Mdot
.6373 .44108 Mdot
.44363 .58949 Mdot
.32759 .40147 Mdot
.51059 .36331 Mdot
.48832 .33547 Mdot
.20775 .70305 Mdot
.47429 .26933 Mdot
.2919 .50618 Mdot
.40169 .56512 Mdot
.49568 .28576 Mdot
.80017 .54621 Mdot
.64213 .43998 Mdot
.37879 .5463 Mdot
.50125 .30103 Mdot
.66988 .25846 Mdot
.26168 .43988 Mdot
.41358 .60129 Mdot
.47382 .63107 Mdot
.63694 .44707 Mdot
.23475 .5622 Mdot
.46286 .32562 Mdot
.36435 .56103 Mdot
.68116 .40363 Mdot
.302 .28634 Mdot
.77614 .36676 Mdot
.59561 .64792 Mdot
.50423 .40919 Mdot
.67529 .42959 Mdot
.36164 .61837 Mdot
.29837 .40328 Mdot
.48773 .39919 Mdot
.47162 .34873 Mdot
.44661 .60244 Mdot
.48414 .59751 Mdot
.3159 .6014 Mdot
.63533 .64935 Mdot
.67833 .45665 Mdot
.4184 .54733 Mdot
.64846 .51786 Mdot
.40875 .53716 Mdot
.65722 .46478 Mdot
.84578 .6694 Mdot
.37577 .62131 Mdot
.41595 .57355 Mdot
.3155 .71725 Mdot
.6069 .65593 Mdot
.60174 .65946 Mdot
.58874 .19853 Mdot
.40134 .5657 Mdot
.44625 .25416 Mdot
.59326 .64777 Mdot
.62461 .62781 Mdot
.57246 .34257 Mdot
.45503 .5769 Mdot
.2224 .57888 Mdot
.63728 .41913 Mdot
.63118 .45237 Mdot
.62531 .61847 Mdot
.34752 .59271 Mdot
.62887 .42384 Mdot
.54211 .70514 Mdot
.49861 .3255 Mdot
.40774 .20318 Mdot
.62993 .64232 Mdot
.52046 .42796 Mdot
.64847 .44856 Mdot
.63401 .8082 Mdot
.45263 .28386 Mdot
.43886 .54908 Mdot
.39552 .57029 Mdot
.3093 .39767 Mdot
.39408 .62688 Mdot
.48993 .28526 Mdot
.67266 .43744 Mdot
.35936 .75544 Mdot
.59625 .64474 Mdot
.42368 .56573 Mdot
.62581 .54801 Mdot
.7569 .55481 Mdot
.67027 .3097 Mdot
.61215 .62039 Mdot
.59283 .6288 Mdot
.46244 .33269 Mdot
.47915 .38113 Mdot
.42296 .5914 Mdot
.65034 .41375 Mdot
.64205 .61785 Mdot
.65526 .46308 Mdot
.46847 .32868 Mdot
.49937 .35835 Mdot
.48172 .29771 Mdot
.36581 .54879 Mdot
.49972 .36949 Mdot
.30559 .30999 Mdot
.66552 .52238 Mdot
.59935 .58816 Mdot
.78703 .33931 Mdot
.7637 .52592 Mdot
.41726 .47524 Mdot
.28564 .40327 Mdot
.49848 .30236 Mdot
.68727 .42017 Mdot
.43113 .60203 Mdot
.40084 .58453 Mdot
.49685 .41174 Mdot
.66358 .40488 Mdot
.31804 .42983 Mdot
.658 .40293 Mdot
.29611 .41068 Mdot
.46031 .26343 Mdot
.47472 .58236 Mdot
.38051 .59337 Mdot
.67558 .43705 Mdot
.50226 .36443 Mdot
.4827 .34595 Mdot
.30811 .4434 Mdot
.40941 .45508 Mdot
.47448 .32694 Mdot
.62916 .64185 Mdot
.53347 .7404 Mdot
.45912 .35968 Mdot
.41345 .56297 Mdot
.228 .44402 Mdot
.53026 .67411 Mdot
.36538 .5812 Mdot
.58018 .39455 Mdot
.17501 .4529 Mdot
.40411 .54622 Mdot
.17764 .42124 Mdot
.61596 .37566 Mdot
.61154 .65668 Mdot
.47123 .37185 Mdot
.48571 .28054 Mdot
.49792 .62261 Mdot
.34532 .39763 Mdot
.43294 .62924 Mdot
.59677 .65316 Mdot
.61696 .67012 Mdot
.6915 .26622 Mdot
.34817 .77585 Mdot
.29342 .43087 Mdot
.30082 .42658 Mdot
.49511 .33701 Mdot
.22153 .65762 Mdot
.36318 .52659 Mdot
.31412 .43291 Mdot
.28948 .64527 Mdot
.42862 .60943 Mdot
.26411 .50237 Mdot
.44154 .29162 Mdot
.61817 .61347 Mdot
.33403 .65054 Mdot
.49411 .34387 Mdot
.62918 .65318 Mdot
.6916 .49794 Mdot
.43964 .6204 Mdot
.60028 .64864 Mdot
.64904 .46305 Mdot
.61085 .24801 Mdot
.57908 .62905 Mdot
.2282 .43517 Mdot
.65408 .41518 Mdot
.56314 .2941 Mdot
.28221 .61052 Mdot
.59773 .1342 Mdot
.67276 .42971 Mdot
.50902 .33583 Mdot
.49103 .31461 Mdot
.48901 .3338 Mdot
.62375 .65657 Mdot
.51256 .36853 Mdot
.63865 .64576 Mdot
.2488 .65029 Mdot
.40877 .45581 Mdot
.30955 .43384 Mdot
.59237 .41025 Mdot
.59672 .62185 Mdot
.49719 .19188 Mdot
.69843 .21595 Mdot
.38955 .58676 Mdot
.68975 .44431 Mdot
.29995 .43312 Mdot
.41184 .84301 Mdot
.31726 .40172 Mdot
.5052 .41279 Mdot
.37036 .21424 Mdot
.42807 .57068 Mdot
.53688 .78629 Mdot
.28761 .40545 Mdot
.6053 .61143 Mdot
.44195 .58803 Mdot
.69954 .37496 Mdot
.30957 .40243 Mdot
.31116 .39059 Mdot
.42751 .59355 Mdot
.58612 .61022 Mdot
.49646 .35601 Mdot
.67845 .40486 Mdot
.33954 .44448 Mdot
.53245 .58344 Mdot
.38835 .62173 Mdot
.42009 .62261 Mdot
.59443 .48784 Mdot
.31367 .54035 Mdot
.67139 .43651 Mdot
.26019 .63451 Mdot
.47897 .38013 Mdot
.54319 .30028 Mdot
.6005 .20534 Mdot
.58772 .4008 Mdot
.48963 .3025 Mdot
.49335 .29851 Mdot
.41808 .59881 Mdot
.31008 .54522 Mdot
.32196 .25339 Mdot
.60522 .43846 Mdot
.45697 .34697 Mdot
.48718 .33855 Mdot
.6408 .66492 Mdot
.69472 .26431 Mdot
.45891 .62437 Mdot
.62886 .4603 Mdot
.47071 .33297 Mdot
.59145 .78582 Mdot
.31062 .40967 Mdot
.45981 .19736 Mdot
.46982 .57366 Mdot
.42495 .54723 Mdot
.66215 .44184 Mdot
.64417 .46411 Mdot
.71818 .40198 Mdot
.66643 .23738 Mdot
.19322 .53296 Mdot
.78806 .50761 Mdot
.59263 .78038 Mdot
.65877 .65309 Mdot
.61437 .5988 Mdot
.65277 .36767 Mdot
.67196 .46681 Mdot
.40149 .54932 Mdot
.6405 .61638 Mdot
.64735 .29456 Mdot
.59979 .67633 Mdot
.27692 .5087 Mdot
.37394 .27048 Mdot
.46154 .60849 Mdot
.62971 .61303 Mdot
.61618 .65425 Mdot
.64054 .60964 Mdot
.61623 .37616 Mdot
.42093 .58283 Mdot
.45438 .56335 Mdot
.40866 .54092 Mdot
.51568 .57442 Mdot
.38568 .57283 Mdot
.60119 .43101 Mdot
.56842 .48206 Mdot
.42082 .79663 Mdot
.36172 .58263 Mdot
.62648 .43726 Mdot
.41567 .62543 Mdot
.32715 .40026 Mdot
.43529 .60368 Mdot
.28031 .5041 Mdot
.64764 .43767 Mdot
.56486 .58092 Mdot
.78564 .50006 Mdot
.46886 .57584 Mdot
.31488 .38836 Mdot
.42508 .48602 Mdot
.73633 .65323 Mdot
.34986 .4652 Mdot
.62973 .6409 Mdot
.49757 .31523 Mdot
.67752 .41078 Mdot
.50096 .35104 Mdot
.35873 .56794 Mdot
.57618 .39733 Mdot
.70477 .58385 Mdot
.51073 .42658 Mdot
.38164 .55479 Mdot
.33271 .55536 Mdot
.6284 .63477 Mdot
.51114 .34745 Mdot
.67026 .64218 Mdot
.39819 .55643 Mdot
.31375 .42054 Mdot
.30584 .40269 Mdot
.73865 .43024 Mdot
.63126 .77552 Mdot
.77387 .4554 Mdot
.66469 .44178 Mdot
.47892 .35845 Mdot
.28428 .4228 Mdot
.52208 .55218 Mdot
.65447 .47694 Mdot
.65787 .40964 Mdot
.65328 .41974 Mdot
.40604 .61735 Mdot
.49328 .29201 Mdot
.41169 .78731 Mdot
.49112 .28609 Mdot
.46795 .5826 Mdot
.4738 .36223 Mdot
.48807 .29644 Mdot
.30348 .39794 Mdot
.68448 .4316 Mdot
.46627 .33528 Mdot
.38692 .59652 Mdot
.58464 .63221 Mdot
.44393 .4459 Mdot
.26738 .45955 Mdot
.39903 .81047 Mdot
.42257 .81936 Mdot
.58055 .60836 Mdot
.61236 .80686 Mdot
.62079 .45146 Mdot
.50356 .66283 Mdot
.61642 .35293 Mdot
.37263 .58637 Mdot
.52286 .17733 Mdot
.46043 .34322 Mdot
.51196 .34538 Mdot
.40431 .60408 Mdot
.52066 .34648 Mdot
.42146 .56802 Mdot
.46914 .35776 Mdot
.29029 .45097 Mdot
.49438 .59582 Mdot
.50615 .36667 Mdot
.3744 .53498 Mdot
.45866 .58213 Mdot
.61921 .61254 Mdot
.47861 .38565 Mdot
.38112 .54164 Mdot
.31789 .79219 Mdot
.65409 .46671 Mdot
.59002 .38859 Mdot
.21598 .42161 Mdot
.67636 .42999 Mdot
.59941 .64331 Mdot
.39891 .63356 Mdot
.32451 .40426 Mdot
.59548 .61509 Mdot
.24951 .40646 Mdot
.28857 .40931 Mdot
.51631 .18419 Mdot
.63245 .63628 Mdot
.46074 .36449 Mdot
.30144 .39579 Mdot
.41723 .51633 Mdot
.49338 .39912 Mdot
.44308 .4626 Mdot
.49556 .30371 Mdot
.41039 .58148 Mdot
.68791 .35938 Mdot
.66271 .46724 Mdot
.44441 .56189 Mdot
.50199 .39408 Mdot
.64418 .36706 Mdot
.41372 .61688 Mdot
.42492 .60332 Mdot
.74627 .32175 Mdot
.45621 .21773 Mdot
.33118 .42199 Mdot
.62522 .66348 Mdot
.39019 .59502 Mdot
.29807 .39421 Mdot
.35659 .34731 Mdot
.40651 .62325 Mdot
.65708 .63901 Mdot
.41192 .50322 Mdot
.4935 .3919 Mdot
.68127 .44196 Mdot
.53629 .41188 Mdot
.30189 .39019 Mdot
.25799 .2511 Mdot
.47976 .2974 Mdot
.38623 .53163 Mdot
.38365 .54642 Mdot
.6818 .32642 Mdot
.62415 .65334 Mdot
.1965 .53286 Mdot
.39822 .57165 Mdot
.45396 .50753 Mdot
.43258 .56022 Mdot
.52629 .323 Mdot
.62209 .62552 Mdot
.41234 .57567 Mdot
.59519 .54611 Mdot
.40927 .52018 Mdot
.30836 .38824 Mdot
.29509 .69853 Mdot
.39294 .6203 Mdot
.89398 .49977 Mdot
.43999 .26367 Mdot
.50468 .36828 Mdot
.69896 .3614 Mdot
.15739 .57088 Mdot
.77337 .43849 Mdot
.64009 .6457 Mdot
.71659 .6431 Mdot
.49866 .35394 Mdot
.79287 .47037 Mdot
.59749 .82219 Mdot
.45907 .58458 Mdot
.44266 .61748 Mdot
.50526 .41281 Mdot
.49289 .28295 Mdot
.47049 .38686 Mdot
.35873 .58138 Mdot
.37515 .51988 Mdot
.495 .37267 Mdot
.38324 .58864 Mdot
.45646 .51999 Mdot
.68265 .40922 Mdot
.57991 .61276 Mdot
.65332 .45563 Mdot
.68061 .41947 Mdot
.46656 .70136 Mdot
.66687 .24265 Mdot
.65964 .46504 Mdot
.62144 .45141 Mdot
.26779 .49706 Mdot
.31475 .61077 Mdot
.28547 .39457 Mdot
.54591 .83168 Mdot
.4884 .32955 Mdot
.42371 .58197 Mdot
.5804 .60436 Mdot
.46787 .6851 Mdot
.41891 .30947 Mdot
.33742 .23628 Mdot
.39858 .55314 Mdot
.49092 .34332 Mdot
.62123 .3729 Mdot
.4909 .54917 Mdot
.55223 .31722 Mdot
.42762 .54568 Mdot
.49598 .40515 Mdot
.51675 .76654 Mdot
.62628 .55581 Mdot
.51931 .25622 Mdot
.66088 .66463 Mdot
.41674 .55131 Mdot
.62866 .64572 Mdot
.65735 .45316 Mdot
.31834 .39595 Mdot
.33036 .42167 Mdot
.43298 .59397 Mdot
.35333 .50849 Mdot
.44335 .29892 Mdot
.46064 .58037 Mdot
.44635 .59868 Mdot
.61631 .37539 Mdot
.44739 .59665 Mdot
.38661 .5453 Mdot
.39602 .54135 Mdot
.43108 .52838 Mdot
.63416 .46087 Mdot
.62138 .54834 Mdot
.35682 .56108 Mdot
.47989 .53657 Mdot
.66535 .39635 Mdot
.73206 .63254 Mdot
.68613 .42788 Mdot
.68077 .75458 Mdot
.64202 .4475 Mdot
.32377 .43065 Mdot
.67626 .35029 Mdot
.33979 .52454 Mdot
.61851 .59432 Mdot
.66642 .4737 Mdot
.30254 .4193 Mdot
.66892 .44524 Mdot
.47724 .37049 Mdot
.83126 .46219 Mdot
.59163 .67112 Mdot
.1966 .50244 Mdot
.73858 .4222 Mdot
.5305 .24451 Mdot
.46873 .3174 Mdot
.62346 .6217 Mdot
.58638 .74626 Mdot
.39651 .53865 Mdot
.29667 .39712 Mdot
.42326 .59477 Mdot
.6368 .46491 Mdot
.49233 .33938 Mdot
.28362 .69479 Mdot
.33044 .41164 Mdot
.75512 .31564 Mdot
.48354 .33254 Mdot
.42474 .53808 Mdot
.62878 .45964 Mdot
.77998 .32078 Mdot
.65797 .4581 Mdot
.37405 .46601 Mdot
.65726 .61891 Mdot
.33753 .68733 Mdot
.59841 .62802 Mdot
.46114 .30553 Mdot
.8569 .5221 Mdot
.49804 .83947 Mdot
.58332 .61882 Mdot
.49059 .25166 Mdot
.43679 .61799 Mdot
.41871 .62345 Mdot
.61172 .56206 Mdot
.6429 .65351 Mdot
.38744 .58358 Mdot
.59796 .38277 Mdot
.68791 .52516 Mdot
.44201 .24288 Mdot
.5003 .31773 Mdot
.41455 .56814 Mdot
.67118 .39751 Mdot
.65685 .40354 Mdot
.49021 .288 Mdot
.68768 .43081 Mdot
.45316 .56292 Mdot
.59758 .62406 Mdot
.48128 .40836 Mdot
.32454 .41701 Mdot
.30928 .76623 Mdot
.28039 .41645 Mdot
.48798 .30379 Mdot
.47139 .55253 Mdot
.49957 .35893 Mdot
.12433 .45486 Mdot
.44346 .55401 Mdot
.59886 .65125 Mdot
.41436 .61056 Mdot
.42178 .55249 Mdot
.43419 .62096 Mdot
.48921 .37407 Mdot
.18241 .47574 Mdot
.38401 .59175 Mdot
.65876 .42659 Mdot
.45566 .81712 Mdot
.42048 .62529 Mdot
.32225 .46165 Mdot
.28065 .55569 Mdot
.53169 .23343 Mdot
.60155 .59084 Mdot
.51061 .35349 Mdot
.59116 .63836 Mdot
.62011 .67893 Mdot
.59981 .64365 Mdot
.46778 .80672 Mdot
.57045 .75276 Mdot
.19395 .42191 Mdot
.35787 .72257 Mdot
.44002 .67892 Mdot
.63534 .65983 Mdot
.34461 .36123 Mdot
.62627 .6013 Mdot
.62506 .65108 Mdot
.59791 .89673 Mdot
.61195 .59584 Mdot
.40741 .56601 Mdot
.46467 .61511 Mdot
.73572 .55616 Mdot
.24542 .49955 Mdot
.44366 .59382 Mdot
.39503 .60088 Mdot
.31342 .39533 Mdot
.37566 .49704 Mdot
.57655 .39728 Mdot
.52667 .19054 Mdot
.77294 .55511 Mdot
.42517 .59521 Mdot
.38969 .59687 Mdot
.3821 .51947 Mdot
.84831 .39513 Mdot
.49698 .69115 Mdot
.63833 .66061 Mdot
.3427 .59423 Mdot
.38747 .81484 Mdot
.4547 .55836 Mdot
.3938 .6169 Mdot
.45541 .61095 Mdot
.49837 .35289 Mdot
.65891 .64544 Mdot
.34107 .58697 Mdot
.53223 .21472 Mdot
.47214 .58327 Mdot
.59051 .40337 Mdot
.17442 .55284 Mdot
.40868 .57104 Mdot
.6337 .59762 Mdot
.43844 .61119 Mdot
.63478 .63492 Mdot
.61316 .60684 Mdot
.44473 .52915 Mdot
.54225 .80427 Mdot
.65802 .62663 Mdot
.46918 .58521 Mdot
.49383 .36348 Mdot
.52874 .84517 Mdot
.408 .5808 Mdot
.33448 .42631 Mdot
.39708 .5698 Mdot
.32737 .39449 Mdot
.45447 .5953 Mdot
.49259 .28794 Mdot
.57227 .68765 Mdot
.49691 .3357 Mdot
.20036 .57658 Mdot
.50101 .29263 Mdot
.74444 .31791 Mdot
.65086 .64713 Mdot
.65512 .36501 Mdot
.29951 .24213 Mdot
.58503 .39103 Mdot
.59098 .51919 Mdot
.54942 .5056 Mdot
.65135 .41308 Mdot
.59215 .65331 Mdot
.25281 .60018 Mdot
.66261 .3074 Mdot
.66404 .33399 Mdot
.47926 .30529 Mdot
.31568 .21439 Mdot
.38224 .19986 Mdot
.38932 .60532 Mdot
.51119 .79765 Mdot
.42162 .74324 Mdot
.40244 .62204 Mdot
.38752 .63155 Mdot
.50754 .39727 Mdot
.38107 .54889 Mdot
.62675 .52619 Mdot
.48142 .31542 Mdot
.29933 .41732 Mdot
.6217 .64895 Mdot
.3396 .41165 Mdot
.66506 .31685 Mdot
.55182 .51066 Mdot
.46825 .34714 Mdot
.41294 .52256 Mdot
.40624 .60948 Mdot
.62738 .61687 Mdot
.65918 .60011 Mdot
.5954 .60409 Mdot
.30196 .43565 Mdot
.48234 .31844 Mdot
.50073 .68224 Mdot
.39833 .59673 Mdot
.60402 .62159 Mdot
.71707 .46332 Mdot
.39242 .59361 Mdot
.67425 .44446 Mdot
.4698 .60369 Mdot
.58153 .62397 Mdot
.4478 .5964 Mdot
.59573 .62431 Mdot
.49939 .32482 Mdot
.45569 .55712 Mdot
.40782 .60285 Mdot
.77846 .32588 Mdot
.31987 .42896 Mdot
.64626 .65046 Mdot
.47269 .42477 Mdot
.40757 .53571 Mdot
.59436 .28709 Mdot
.41128 .5518 Mdot
.6476 .68749 Mdot
.38668 .52923 Mdot
.6279 .37144 Mdot
.47227 .61919 Mdot
.40881 .58015 Mdot
.55953 .53322 Mdot
.43142 .76431 Mdot
.67001 .61544 Mdot
.62608 .45206 Mdot
.64268 .60723 Mdot
.39601 .28049 Mdot
.45886 .35075 Mdot
.5115 .37447 Mdot
.22151 .51305 Mdot
.46253 .54813 Mdot
.42751 .57221 Mdot
.69646 .42794 Mdot
.29613 .42008 Mdot
.61009 .61944 Mdot
.29692 .41267 Mdot
.56939 .20386 Mdot
.29292 .42624 Mdot
.48722 .28211 Mdot
.46527 .25596 Mdot
.54068 .68904 Mdot
.31232 .39528 Mdot
.58789 .60707 Mdot
.3637 .27626 Mdot
.36886 .57518 Mdot
.30246 .37171 Mdot
.31427 .41928 Mdot
.31367 .20874 Mdot
.38386 .55025 Mdot
.59639 .51621 Mdot
.66977 .45908 Mdot
.2993 .40125 Mdot
.645 .4238 Mdot
.43935 .59502 Mdot
.57207 .2615 Mdot
.64268 .64723 Mdot
.64334 .39893 Mdot
.36562 .61027 Mdot
.30147 .4326 Mdot
.47126 .33614 Mdot
.65441 .38221 Mdot
.62791 .43227 Mdot
.71939 .67791 Mdot
.28244 .68165 Mdot
.48329 .3179 Mdot
.37967 .23644 Mdot
.63611 .42593 Mdot
.39415 .61874 Mdot
.43339 .50049 Mdot
.44029 .54955 Mdot
.69666 .36794 Mdot
.51128 .35307 Mdot
.69594 .5456 Mdot
.40784 .61124 Mdot
.39681 .54745 Mdot
.60364 .58085 Mdot
.49325 .32102 Mdot
.61435 .63737 Mdot
.63532 .6023 Mdot
.49852 .32279 Mdot
.601 .63509 Mdot
.2892 .40299 Mdot
.70331 .51645 Mdot
.63374 .43004 Mdot
.65639 .42948 Mdot
.48782 .33783 Mdot
.50119 .37167 Mdot
.50225 .35877 Mdot
.47035 .60302 Mdot
.61629 .62188 Mdot
.45979 .60304 Mdot
.43664 .61982 Mdot
.6776 .62285 Mdot
.59064 .59718 Mdot
.44376 .61307 Mdot
.5325 .26734 Mdot
.29229 .37539 Mdot
.49158 .36684 Mdot
.66502 .46285 Mdot
.8056 .52093 Mdot
.65325 .39043 Mdot
.41616 .56608 Mdot
.66459 .25759 Mdot
.58653 .61331 Mdot
.31278 .39916 Mdot
.30263 .38047 Mdot
.32442 .40683 Mdot
.70048 .43923 Mdot
.64843 .62915 Mdot
.52501 .19045 Mdot
.41821 .56893 Mdot
.59506 .48752 Mdot
.25733 .61515 Mdot
.57585 .21477 Mdot
.66262 .46457 Mdot
.39192 .59613 Mdot
.5308 .41757 Mdot
.59082 .73117 Mdot
.42823 .54778 Mdot
.37046 .55068 Mdot
.58923 .35635 Mdot
.43161 .50837 Mdot
.65814 .62255 Mdot
.66218 .22968 Mdot
.45084 .62068 Mdot
.64307 .57433 Mdot
.21944 .69617 Mdot
.41894 .56043 Mdot
.39237 .55819 Mdot
.40707 .5899 Mdot
.42564 .60966 Mdot
.63649 .59841 Mdot
.24285 .55248 Mdot
.6328 .465 Mdot
.57261 .4612 Mdot
.63249 .42955 Mdot
.49436 .40447 Mdot
.6264 .53993 Mdot
.58234 .64422 Mdot
.31035 .39763 Mdot
.67567 .70898 Mdot
.60193 .19494 Mdot
.462 .3328 Mdot
.53718 .71601 Mdot
.32052 .42198 Mdot
.38224 .6138 Mdot
.33905 .40465 Mdot
.49776 .29235 Mdot
.65899 .41955 Mdot
.48939 .59851 Mdot
.60622 .59939 Mdot
.58023 .63258 Mdot
.38892 .58546 Mdot
.42401 .83736 Mdot
.67688 .44353 Mdot
.6124 .43279 Mdot
.41747 .61829 Mdot
.3684 .55246 Mdot
.61404 .64076 Mdot
.48523 .35555 Mdot
.27992 .32395 Mdot
.30822 .42737 Mdot
.42626 .53429 Mdot
.42999 .60815 Mdot
.66046 .23393 Mdot
.67878 .42419 Mdot
.46755 .30401 Mdot
.40419 .61632 Mdot
.74503 .39345 Mdot
.40615 .61634 Mdot
.4987 .55801 Mdot
.49402 .35971 Mdot
.35503 .54434 Mdot
.38167 .59325 Mdot
.37063 .63467 Mdot
.63949 .42398 Mdot
.6029 .65107 Mdot
.61563 .58376 Mdot
.5082 .4171 Mdot
.67226 .44602 Mdot
.44079 .61274 Mdot
.67954 .42848 Mdot
.40845 .62511 Mdot
.38416 .58163 Mdot
.65776 .46467 Mdot
.61364 .6374 Mdot
.7205 .60976 Mdot
.622 .54551 Mdot
.42126 .61116 Mdot
.46519 .61918 Mdot
.23315 .51216 Mdot
.214 .35055 Mdot
.40241 .55338 Mdot
.58096 .62816 Mdot
.39994 .59998 Mdot
.6437 .43128 Mdot
.29116 .42045 Mdot
.58327 .62948 Mdot
.48039 .34841 Mdot
.46469 .32104 Mdot
.78525 .49598 Mdot
.49275 .29612 Mdot
.37095 .59117 Mdot
.56814 .6585 Mdot
.56713 .61611 Mdot
.2537 .72709 Mdot
.49661 .31917 Mdot
.29403 .38848 Mdot
.42883 .60069 Mdot
.70429 .29834 Mdot
.69733 .43551 Mdot
.89946 .48181 Mdot
.51872 .1866 Mdot
.28129 .42088 Mdot
.32301 .23853 Mdot
.48746 .4053 Mdot
.37841 .57298 Mdot
.32055 .39672 Mdot
.46325 .34885 Mdot
.37654 .59667 Mdot
.48135 .62696 Mdot
.19059 .51421 Mdot
.51802 .40962 Mdot
.68192 .43385 Mdot
.49708 .38583 Mdot
.34552 .41112 Mdot
.48808 .28282 Mdot
.57784 .63035 Mdot
.41286 .57907 Mdot
.32925 .5729 Mdot
.48237 .35417 Mdot
.49021 .28345 Mdot
.4653 .60545 Mdot
.59722 .65587 Mdot
.51993 .35629 Mdot
.43235 .59102 Mdot
.48539 .66668 Mdot
.66035 .66379 Mdot
.47907 .32233 Mdot
.39601 .54424 Mdot
.31303 .58531 Mdot
.48373 .34021 Mdot
.49017 .36807 Mdot
.38739 .58486 Mdot
.29023 .40027 Mdot
.47214 .57477 Mdot
.6442 .45223 Mdot
.17509 .49644 Mdot
.64585 .42944 Mdot
.3855 .29604 Mdot
.45244 .528 Mdot
.56165 .26902 Mdot
.57444 .62282 Mdot
.34346 .40354 Mdot
.81285 .51587 Mdot
.36093 .56633 Mdot
.60703 .80256 Mdot
.53601 .42869 Mdot
.37646 .81772 Mdot
.81672 .59258 Mdot
.312 .416 Mdot
.66464 .44887 Mdot
.39259 .55894 Mdot
.69273 .43777 Mdot
.33169 .40888 Mdot
.26003 .64639 Mdot
.39295 .5439 Mdot
.62359 .62755 Mdot
.47173 .59048 Mdot
.63024 .64097 Mdot
.39195 .59051 Mdot
.44607 .51514 Mdot
.64552 .36038 Mdot
.26423 .44411 Mdot
.37145 .58282 Mdot
.83076 .45335 Mdot
.4267 .31742 Mdot
.31116 .42325 Mdot
.46575 .59502 Mdot
.45807 .32857 Mdot
.65583 .40525 Mdot
.4932 .51124 Mdot
.49824 .35614 Mdot
.6856 .44807 Mdot
.60672 .64242 Mdot
.50015 .32152 Mdot
.47123 .30553 Mdot
.35077 .60275 Mdot
.32558 .39452 Mdot
.66099 .41542 Mdot
.40782 .57654 Mdot
.38685 .54927 Mdot
.38329 .24331 Mdot
.40677 .32201 Mdot
.61813 .58057 Mdot
.7471 .27806 Mdot
.58703 .59068 Mdot
.31357 .43176 Mdot
.49644 .36041 Mdot
.40551 .55419 Mdot
.44717 .56458 Mdot
.66266 .36217 Mdot
.64015 .65313 Mdot
.52029 .41276 Mdot
.49281 .70557 Mdot
.51322 .33001 Mdot
.26428 .54033 Mdot
.595 .65052 Mdot
.26265 .53821 Mdot
.34492 .41056 Mdot
.61308 .78257 Mdot
.29319 .47527 Mdot
.6727 .45742 Mdot
.26393 .54531 Mdot
.60267 .6108 Mdot
.39444 .60781 Mdot
.46264 .36823 Mdot
.48636 .2979 Mdot
.61703 .64605 Mdot
.49725 .40879 Mdot
.30178 .40109 Mdot
.38853 .55967 Mdot
.49424 .20772 Mdot
.75302 .51509 Mdot
.48116 .36263 Mdot
.50611 .57476 Mdot
.65142 .42214 Mdot
.38045 .57212 Mdot
.33309 .42935 Mdot
.6688 .42501 Mdot
.42914 .2683 Mdot
.69143 .53251 Mdot
.43658 .59347 Mdot
.71298 .29225 Mdot
.67467 .43847 Mdot
.28838 .27553 Mdot
.42769 .5888 Mdot
.63641 .4256 Mdot
.38504 .50983 Mdot
.57153 .22422 Mdot
.49735 .43365 Mdot
.58982 .82892 Mdot
.5279 .41003 Mdot
.47808 .39228 Mdot
.61096 .25615 Mdot
.64097 .32403 Mdot
.69236 .42947 Mdot
.48891 .28362 Mdot
.31294 .52586 Mdot
.6451 .42243 Mdot
.44297 .6178 Mdot
.41435 .55514 Mdot
.46571 .69677 Mdot
.54042 .44064 Mdot
.48485 .27803 Mdot
.76066 .44821 Mdot
.40847 .53623 Mdot
.364 .61528 Mdot
.44536 .56916 Mdot
.62277 .66955 Mdot
.66952 .41815 Mdot
.79796 .37281 Mdot
.66953 .45014 Mdot
.44905 .20409 Mdot
.48921 .33062 Mdot
.51055 .36613 Mdot
.41074 .56869 Mdot
.53297 .25353 Mdot
.28935 .60472 Mdot
.45689 .56723 Mdot
.56028 .29041 Mdot
.29307 .70457 Mdot
.36665 .61379 Mdot
.65677 .61637 Mdot
.49458 .58607 Mdot
.60722 .67155 Mdot
.63397 .42189 Mdot
.3139 .40986 Mdot
.34991 .41036 Mdot
.66177 .41677 Mdot
.42942 .5726 Mdot
.56963 .29908 Mdot
.42966 .55392 Mdot
.39454 .61142 Mdot
.44989 .19494 Mdot
.28451 .42482 Mdot
.50644 .35341 Mdot
.33137 .41796 Mdot
.62652 .6513 Mdot
.82997 .70324 Mdot
.29457 .41744 Mdot
.29731 .61624 Mdot
.21987 .59539 Mdot
.26172 .54519 Mdot
.58141 .63695 Mdot
.334 .44241 Mdot
.67962 .44354 Mdot
.44184 .86266 Mdot
.20137 .36919 Mdot
.62954 .39858 Mdot
.43707 .58505 Mdot
.58611 .6509 Mdot
.58696 .60494 Mdot
.63819 .40454 Mdot
.61015 .6078 Mdot
.34185 .54117 Mdot
.4071 .61321 Mdot
.69162 .43529 Mdot
.7455 .54069 Mdot
.62787 .43134 Mdot
.69664 .50722 Mdot
.46807 .59507 Mdot
.5895 .64461 Mdot
.49039 .57737 Mdot
.55909 .63696 Mdot
.46761 .30268 Mdot
.38724 .61828 Mdot
.30337 .399 Mdot
.58272 .45508 Mdot
.48259 .323 Mdot
.66389 .25935 Mdot
.62874 .61968 Mdot
.7166 .44713 Mdot
.6177 .61096 Mdot
.6019 .66384 Mdot
.6802 .41823 Mdot
.64469 .63188 Mdot
.39136 .55785 Mdot
.51225 .26073 Mdot
.63728 .63055 Mdot
.65492 .44156 Mdot
.31846 .40803 Mdot
.60475 .63537 Mdot
.51023 .39897 Mdot
.41781 .60408 Mdot
.47394 .37087 Mdot
.64975 .3543 Mdot
.60144 .65986 Mdot
.32556 .4446 Mdot
.51286 .35321 Mdot
.32567 .39623 Mdot
.28271 .71339 Mdot
.67094 .46788 Mdot
.34418 .23613 Mdot
.31542 .5854 Mdot
.60184 .59827 Mdot
.647 .35706 Mdot
.40586 .55668 Mdot
.42011 .60444 Mdot
.3446 .42705 Mdot
.5874 .60447 Mdot
.49483 .84467 Mdot
.67454 .68195 Mdot
.70249 .52603 Mdot
.66793 .47113 Mdot
.77084 .34749 Mdot
.6525 .52101 Mdot
.21246 .63293 Mdot
.3478 .57634 Mdot
.48533 .40351 Mdot
.42832 .56547 Mdot
.81136 .52982 Mdot
.30141 .4338 Mdot
.27791 .34544 Mdot
.43072 .52123 Mdot
.50616 .3427 Mdot
.41465 .59372 Mdot
.49658 .49057 Mdot
.49468 .56776 Mdot
.28683 .40248 Mdot
.5906 .41706 Mdot
.62258 .59566 Mdot
.32386 .41909 Mdot
.47313 .31199 Mdot
.28141 .58493 Mdot
.37418 .58567 Mdot
.35688 .57213 Mdot
.51199 .32364 Mdot
.62265 .62283 Mdot
.48306 .39285 Mdot
.63402 .42925 Mdot
.305 .40709 Mdot
.42899 .6037 Mdot
.39548 .52429 Mdot
.59613 .28916 Mdot
.6636 .41387 Mdot
.51569 .3433 Mdot
.65901 .45684 Mdot
.47409 .39096 Mdot
.47775 .61026 Mdot
.51096 .36715 Mdot
.3755 .56695 Mdot
.7995 .44419 Mdot
.44281 .19795 Mdot
.45202 .77348 Mdot
.50786 .3419 Mdot
.28171 .53071 Mdot
.64627 .43871 Mdot
.64499 .45017 Mdot
.33982 .6816 Mdot
.38794 .48892 Mdot
.41198 .2554 Mdot
.72743 .67492 Mdot
.63287 .43159 Mdot
.64955 .4297 Mdot
.4691 .36502 Mdot
.6436 .63549 Mdot
.58846 .65765 Mdot
.4926 .40669 Mdot
.22443 .44337 Mdot
.60996 .6195 Mdot
.58896 .80957 Mdot
.41322 .26686 Mdot
.36134 .61603 Mdot
.70941 .39183 Mdot
.30854 .40397 Mdot
.23241 .4428 Mdot
.50907 .50183 Mdot
.39659 .54985 Mdot
.67312 .24037 Mdot
.48755 .35178 Mdot
.22675 .54281 Mdot
.68392 .75099 Mdot
.3913 .54332 Mdot
.42444 .58387 Mdot
.43627 .57016 Mdot
.29465 .43571 Mdot
.58684 .68363 Mdot
.38836 .55082 Mdot
.22192 .4397 Mdot
.41079 .53496 Mdot
.34911 .47187 Mdot
.33085 .42094 Mdot
.40637 .65996 Mdot
.59453 .37782 Mdot
.5346 .20718 Mdot
.47159 .64289 Mdot
.63505 .43508 Mdot
.55718 .40533 Mdot
.63993 .41809 Mdot
.459 .80159 Mdot
.29071 .47734 Mdot
.652 .60415 Mdot
.39531 .55254 Mdot
.48652 .30488 Mdot
.58444 .60819 Mdot
.61935 .28585 Mdot
.65683 .8704 Mdot
.6378 .41398 Mdot
.13399 .45135 Mdot
.6504 .4554 Mdot
.47498 .3002 Mdot
.61383 .64208 Mdot
.56018 .75539 Mdot
.59775 .49153 Mdot
.60196 .6335 Mdot
.7107 .59278 Mdot
.56096 .60786 Mdot
.27379 .5411 Mdot
.57012 .60788 Mdot
.65179 .44185 Mdot
.69108 .40189 Mdot
.37312 .62955 Mdot
.40413 .56394 Mdot
.54694 .50889 Mdot
.30328 .604 Mdot
.40417 .56021 Mdot
.48211 .31559 Mdot
.28047 .2762 Mdot
.50723 .41449 Mdot
.63028 .60737 Mdot
.62309 .43716 Mdot
.42212 .58599 Mdot
.41821 .61446 Mdot
.37825 .59508 Mdot
.75931 .28358 Mdot
.57236 .8126 Mdot
.38458 .59224 Mdot
.439 .53819 Mdot
.50134 .32767 Mdot
.30744 .453 Mdot
.80666 .56224 Mdot
.34133 .49071 Mdot
.42589 .54269 Mdot
.32628 .42482 Mdot
.27997 .40175 Mdot
.37562 .59579 Mdot
.51769 .22144 Mdot
.50373 .25389 Mdot
.40762 .57696 Mdot
.36602 .4747 Mdot
.6562 .31346 Mdot
.4882 .28488 Mdot
.48241 .35025 Mdot
.6329 .59764 Mdot
.4844 .30223 Mdot
.50096 .29182 Mdot
.56477 .74053 Mdot
.54884 .41231 Mdot
.62 .48559 Mdot
.30228 .43588 Mdot
.4434 .56042 Mdot
.57749 .59334 Mdot
.68438 .36341 Mdot
.65429 .41362 Mdot
.58767 .62386 Mdot
.65208 .40525 Mdot
.27839 .4218 Mdot
.20286 .51907 Mdot
.48556 .29663 Mdot
.63236 .44055 Mdot
.69091 .53138 Mdot
.32777 .4239 Mdot
.68594 .43809 Mdot
.56962 .27567 Mdot
.42999 .62314 Mdot
.59298 .77159 Mdot
.4629 .57574 Mdot
.42718 .84542 Mdot
.68533 .43769 Mdot
.6279 .37239 Mdot
.42204 .57414 Mdot
.48413 .33333 Mdot
.42448 .5102 Mdot
.4284 .54529 Mdot
.4773 .34748 Mdot
.38996 .60551 Mdot
.33761 .41933 Mdot
.63333 .67621 Mdot
.55845 .41817 Mdot
.4899 .14183 Mdot
.33145 .39982 Mdot
.61117 .28352 Mdot
.40103 .55309 Mdot
.28382 .69223 Mdot
.60475 .63382 Mdot
.37673 .54744 Mdot
.3533 .66279 Mdot
.63864 .64188 Mdot
.59026 .63395 Mdot
.44689 .60372 Mdot
.67152 .45646 Mdot
.48089 .32895 Mdot
.3296 .41965 Mdot
.24925 .70047 Mdot
.44671 .5809 Mdot
.4042 .60187 Mdot
.32181 .42102 Mdot
.64759 .42904 Mdot
.424 .61384 Mdot
.72077 .35251 Mdot
.3315 .79727 Mdot
.66237 .40966 Mdot
.47383 .60546 Mdot
.64457 .73062 Mdot
.55737 .63973 Mdot
.16336 .40485 Mdot
.25586 .40714 Mdot
.50881 .3589 Mdot
.42274 .50591 Mdot
.88126 .58048 Mdot
.31417 .4083 Mdot
.52921 .1982 Mdot
.39191 .61161 Mdot
.40071 .59379 Mdot
.59148 .60842 Mdot
.4537 .60811 Mdot
.63217 .65417 Mdot
.44115 .15389 Mdot
.69645 .24821 Mdot
.62913 .62753 Mdot
.60998 .59747 Mdot
.31901 .64101 Mdot
.80794 .55587 Mdot
.6132 .64759 Mdot
.48247 .59064 Mdot
.50216 .82788 Mdot
.38587 .64261 Mdot
.3452 .42641 Mdot
.64705 .34639 Mdot
.55061 .5926 Mdot
.4048 .40998 Mdot
.72137 .64921 Mdot
.55912 .58498 Mdot
.45698 .29117 Mdot
.64431 .45481 Mdot
.40373 .53945 Mdot
.49004 .29621 Mdot
.51188 .37197 Mdot
.48792 .55591 Mdot
.43575 .55353 Mdot
.63419 .63819 Mdot
.28737 .42511 Mdot
.67405 .40753 Mdot
.39585 .60148 Mdot
.51591 .40104 Mdot
.30008 .4221 Mdot
.63207 .61274 Mdot
.32874 .67204 Mdot
.29018 .39328 Mdot
.50005 .58887 Mdot
.39634 .5751 Mdot
.46099 .60871 Mdot
.32379 .5615 Mdot
.64522 .46583 Mdot
.69289 .35014 Mdot
.47718 .59072 Mdot
.57423 .20348 Mdot
.40898 .45248 Mdot
.36141 .53564 Mdot
.6111 .61421 Mdot
.69773 .44156 Mdot
.46166 .31157 Mdot
.27209 .61464 Mdot
.44238 .58816 Mdot
.56543 .8128 Mdot
.49256 .69601 Mdot
.46074 .32101 Mdot
.63748 .65828 Mdot
.31554 .40024 Mdot
.45274 .56326 Mdot
.48148 .81645 Mdot
.41564 .55841 Mdot
.31725 .56859 Mdot
.49066 .36295 Mdot
.64511 .45689 Mdot
.36524 .81414 Mdot
.51165 .37195 Mdot
.59072 .63712 Mdot
.60345 .82927 Mdot
.5725 .63226 Mdot
.63591 .60598 Mdot
.52818 .81023 Mdot
.64023 .46153 Mdot
.88719 .56171 Mdot
.19208 .37525 Mdot
.39393 .51938 Mdot
.64333 .43869 Mdot
.62344 .64098 Mdot
.3807 .57093 Mdot
.57585 .60605 Mdot
.64924 .63968 Mdot
.40698 .62959 Mdot
.39623 .5843 Mdot
.61817 .54071 Mdot
.63885 .78178 Mdot
.32184 .40306 Mdot
.60716 .65616 Mdot
.41861 .68377 Mdot
.38051 .55697 Mdot
.41773 .56942 Mdot
.64394 .29749 Mdot
.29004 .39858 Mdot
.56236 .54133 Mdot
.40024 .61513 Mdot
.71445 .27402 Mdot
.49659 .59212 Mdot
.6413 .60124 Mdot
.66458 .41048 Mdot
.51789 .21425 Mdot
.69748 .36969 Mdot
.63726 .65481 Mdot
.32369 .43787 Mdot
.6192 .58356 Mdot
.29881 .61595 Mdot
.6295 .44606 Mdot
.58152 .62389 Mdot
.53541 .41257 Mdot
.66596 .43138 Mdot
.68464 .44035 Mdot
.45907 .81822 Mdot
.51112 .33348 Mdot
.31841 .44298 Mdot
.65572 .41834 Mdot
.5044 .66168 Mdot
.65785 .44668 Mdot
.42911 .69213 Mdot
.46134 .56351 Mdot
.20574 .47677 Mdot
.63363 .51173 Mdot
.33606 .53463 Mdot
.65523 .46912 Mdot
.33111 .40948 Mdot
.43833 .60697 Mdot
.60715 .6068 Mdot
.29505 .41371 Mdot
.68107 .38267 Mdot
.49547 .37068 Mdot
.62066 .61028 Mdot
.6354 .46825 Mdot
.60328 .65452 Mdot
.24576 .58945 Mdot
.17653 .51283 Mdot
.72126 .34121 Mdot
.59336 .49135 Mdot
.37978 .59824 Mdot
.75357 .62757 Mdot
.4064 .6315 Mdot
.43116 .55037 Mdot
.47947 .3228 Mdot
.22034 .514 Mdot
.61439 .63791 Mdot
.3707 .81991 Mdot
.63539 .44543 Mdot
.67285 .23365 Mdot
.67246 .65845 Mdot
.37686 .54499 Mdot
.63758 .63458 Mdot
.56982 .62342 Mdot
.42372 .76251 Mdot
.493 .2786 Mdot
.46785 .6318 Mdot
.43432 .63396 Mdot
.35081 .56732 Mdot
.68396 .44026 Mdot
.64965 .2525 Mdot
.48611 .39849 Mdot
.16188 .47817 Mdot
.48766 .36399 Mdot
.56095 .34923 Mdot
.64259 .6245 Mdot
.29128 .41139 Mdot
.41541 .57052 Mdot
.67436 .66229 Mdot
.63305 .65819 Mdot
.2769 .38708 Mdot
.30021 .39813 Mdot
.6079 .2415 Mdot
.65717 .46518 Mdot
.37043 .57485 Mdot
.39491 .54516 Mdot
.46068 .5999 Mdot
.46606 .57575 Mdot
.6374 .41386 Mdot
.42232 .62041 Mdot
.67574 .39927 Mdot
.49721 .66838 Mdot
.68897 .24819 Mdot
.54646 .41141 Mdot
.46765 .50178 Mdot
.61641 .6029 Mdot
.51039 .65413 Mdot
.5022 .59508 Mdot
.41589 .20226 Mdot
.34085 .76235 Mdot
.37394 .61674 Mdot
.46658 .36294 Mdot
.40412 .4895 Mdot
.50227 .30349 Mdot
.16071 .34657 Mdot
.59731 .30061 Mdot
.5979 .81811 Mdot
.38274 .56034 Mdot
.64768 .29965 Mdot
.49995 .54894 Mdot
.42313 .63222 Mdot
.62288 .30892 Mdot
.76171 .4205 Mdot
.72282 .56732 Mdot
.28241 .3982 Mdot
.42296 .59956 Mdot
.56453 .61527 Mdot
.39011 .55701 Mdot
.42187 .56636 Mdot
.38962 .61136 Mdot
.62814 .46084 Mdot
.48806 .59916 Mdot
.47147 .60328 Mdot
.41222 .36187 Mdot
.26902 .50462 Mdot
.49582 .38811 Mdot
.32205 .67744 Mdot
.29622 .41824 Mdot
.63438 .62788 Mdot
.68878 .59629 Mdot
.67239 .45801 Mdot
.41804 .75135 Mdot
.47241 .59692 Mdot
.65938 .53211 Mdot
.63724 .47009 Mdot
.30291 .40563 Mdot
.46108 .36725 Mdot
.54957 .84784 Mdot
.48954 .30495 Mdot
.53686 .41672 Mdot
.48505 .3241 Mdot
.48356 .64422 Mdot
.63377 .63994 Mdot
.38227 .60659 Mdot
.6547 .42095 Mdot
.47686 .33147 Mdot
.23677 .4998 Mdot
.44364 .56862 Mdot
.49924 .32651 Mdot
.38415 .60848 Mdot
.19752 .49911 Mdot
.34516 .25694 Mdot
.49811 .28851 Mdot
.69815 .45153 Mdot
.6622 .43536 Mdot
.2892 .4053 Mdot
.63096 .61691 Mdot
.59255 .60987 Mdot
.66937 .42724 Mdot
.21871 .33138 Mdot
.42427 .54327 Mdot
.38055 .56546 Mdot
.57783 .20257 Mdot
.39643 .56156 Mdot
.28163 .56828 Mdot
.52618 .41909 Mdot
.62633 .60709 Mdot
.38136 .58075 Mdot
.42349 .61226 Mdot
.43259 .59715 Mdot
.24143 .58937 Mdot
.48383 .35891 Mdot
.42572 .5396 Mdot
.30464 .39301 Mdot
.45986 .30661 Mdot
.37937 .5655 Mdot
.35183 .56624 Mdot
.59108 .61179 Mdot
.66964 .21856 Mdot
.6537 .45994 Mdot
.47 .31772 Mdot
.51172 .35983 Mdot
.64963 .34415 Mdot
.66069 .59136 Mdot
.5235 .41921 Mdot
.16538 .50504 Mdot
.61036 .3783 Mdot
.31753 .42503 Mdot
.56525 .38318 Mdot
.38778 .44385 Mdot
.464 .33602 Mdot
.64808 .404 Mdot
.4719 .57879 Mdot
.43438 .5437 Mdot
.50845 .18378 Mdot
.37653 .54367 Mdot
.31294 .40148 Mdot
.66627 .39515 Mdot
.6019 .61231 Mdot
.30343 .4032 Mdot
.64958 .45306 Mdot
.62109 .62063 Mdot
.42637 .62522 Mdot
.44411 .62021 Mdot
.58921 .6262 Mdot
.5868 .60719 Mdot
.40394 .57512 Mdot
.46732 .28251 Mdot
.63144 .59806 Mdot
.58441 .63747 Mdot
.48769 .29496 Mdot
.48063 .30468 Mdot
.3414 .5797 Mdot
.64591 .44476 Mdot
.44688 .61515 Mdot
.49721 .30808 Mdot
.28837 .42226 Mdot
.6104 .63323 Mdot
.41805 .61256 Mdot
.39698 .60599 Mdot
.328 .4209 Mdot
.28165 .41126 Mdot
.30004 .40274 Mdot
.66283 .39254 Mdot
.46189 .58891 Mdot
.6082 .64585 Mdot
.64832 .46366 Mdot
.27998 .40124 Mdot
.3231 .38988 Mdot
.44995 .4185 Mdot
.40583 .55237 Mdot
.47918 .42258 Mdot
.82734 .7006 Mdot
.29958 .54038 Mdot
.46351 .30725 Mdot
.51105 .32557 Mdot
.25109 .52546 Mdot
.49744 .2593 Mdot
.67732 .43664 Mdot
.308 .54169 Mdot
.34375 .40332 Mdot
.39195 .61954 Mdot
.46828 .61712 Mdot
.39197 .63383 Mdot
.30157 .41381 Mdot
.25764 .59466 Mdot
.57375 .6158 Mdot
.39594 .7135 Mdot
.29633 .41736 Mdot
.49412 .28233 Mdot
.51724 .35464 Mdot
.48812 .36435 Mdot
.47129 .61296 Mdot
.448 .76691 Mdot
.47184 .66503 Mdot
.75382 .63891 Mdot
.67645 .45907 Mdot
.65512 .60627 Mdot
.28087 .70394 Mdot
.59066 .63114 Mdot
.51571 .36519 Mdot
.30154 .41834 Mdot
.57989 .62129 Mdot
.64731 .41211 Mdot
.65094 .42818 Mdot
.48416 .36296 Mdot
.48889 .33753 Mdot
.47299 .36653 Mdot
.64479 .6178 Mdot
.64419 .62997 Mdot
.44849 .58373 Mdot
.60176 .625 Mdot
.58334 .17722 Mdot
.29281 .43614 Mdot
.51846 .35241 Mdot
.66332 .45036 Mdot
.63127 .63869 Mdot
.44674 .56819 Mdot
.5292 .37856 Mdot
.77869 .49765 Mdot
.33146 .40212 Mdot
.36862 .24605 Mdot
.15606 .36298 Mdot
.37132 .56223 Mdot
.68191 .43122 Mdot
.48343 .21179 Mdot
.43844 .57176 Mdot
.49549 .35341 Mdot
.80868 .46589 Mdot
.45852 .34891 Mdot
.44106 .61794 Mdot
.37284 .54658 Mdot
.68728 .42795 Mdot
.2196 .6021 Mdot
.45176 .57984 Mdot
.69594 .49464 Mdot
.62485 .42839 Mdot
.49549 .39813 Mdot
.34029 .8069 Mdot
.67882 .32826 Mdot
.23045 .44598 Mdot
.48147 .29987 Mdot
.41999 .55237 Mdot
.47555 .31649 Mdot
.32954 .40145 Mdot
.47039 .32969 Mdot
.66248 .63247 Mdot
.49263 .39187 Mdot
.40451 .60092 Mdot
.61299 .64876 Mdot
.6749 .43967 Mdot
.65113 .21994 Mdot
.40638 .35081 Mdot
.4845 .33403 Mdot
.48127 .29508 Mdot
.38021 .58787 Mdot
.58702 .54111 Mdot
.42759 .51504 Mdot
.38184 .5582 Mdot
.63156 .42874 Mdot
.6382 .62994 Mdot
.64945 .4711 Mdot
.40169 .52933 Mdot
.76522 .38256 Mdot
.6625 .45766 Mdot
.65353 .53592 Mdot
.32019 .42274 Mdot
.48838 .46999 Mdot
.44707 .56269 Mdot
.6516 .41789 Mdot
.46271 .58902 Mdot
.58041 .60178 Mdot
.52813 .45963 Mdot
.70952 .36397 Mdot
.65562 .42238 Mdot
.472 .84595 Mdot
.46033 .40945 Mdot
.4891 .58184 Mdot
.63713 .42274 Mdot
.36002 .66458 Mdot
.47284 .30288 Mdot
.31071 .42752 Mdot
.2804 .40112 Mdot
.31936 .39227 Mdot
.36107 .58646 Mdot
.49574 .61915 Mdot
.33037 .43693 Mdot
.66146 .40757 Mdot
.2856 .40454 Mdot
.68529 .63574 Mdot
.48436 .84746 Mdot
.30619 .43522 Mdot
.42998 .58958 Mdot
.38292 .6366 Mdot
.26458 .50292 Mdot
.52063 .34943 Mdot
.6126 .80095 Mdot
.49247 .52531 Mdot
.40675 .56297 Mdot
.53503 .59365 Mdot
.57568 .6154 Mdot
.47406 .21916 Mdot
.30398 .59678 Mdot
.46885 .24524 Mdot
.61651 .59671 Mdot
.66479 .36257 Mdot
.62937 .61164 Mdot
.37249 .56709 Mdot
.38405 .57767 Mdot
.58584 .65695 Mdot
.66843 .25372 Mdot
.57723 .25865 Mdot
.31449 .7686 Mdot
.58455 .63994 Mdot
.64001 .42342 Mdot
.63417 .4157 Mdot
.6742 .4601 Mdot
.40293 .27355 Mdot
.60819 .65939 Mdot
.4558 .5899 Mdot
.50224 .32786 Mdot
.41588 .54132 Mdot
.66267 .4237 Mdot
.37707 .82256 Mdot
.59528 .61076 Mdot
.4087 .57928 Mdot
.21195 .35962 Mdot
.49518 .3423 Mdot
.32328 .42879 Mdot
.19865 .52175 Mdot
.43483 .26045 Mdot
.6334 .4561 Mdot
.57727 .64515 Mdot
.59009 .40047 Mdot
.65026 .5427 Mdot
.34545 .58052 Mdot
.34441 .54756 Mdot
.22496 .66308 Mdot
.42404 .27362 Mdot
.37733 .60545 Mdot
.46877 .31555 Mdot
.66301 .36177 Mdot
.41611 .6104 Mdot
.58002 .63687 Mdot
.28953 .38667 Mdot
.30008 .39289 Mdot
.47177 .62503 Mdot
.59242 .48417 Mdot
.46892 .45371 Mdot
.43853 .61419 Mdot
.50057 .59094 Mdot
.51465 .35335 Mdot
.60149 .38261 Mdot
.62178 .20931 Mdot
.31714 .4394 Mdot
.39814 .616 Mdot
.73827 .5885 Mdot
.64687 .64195 Mdot
.48189 .38452 Mdot
.62857 .44696 Mdot
.25099 .60843 Mdot
.49099 .3983 Mdot
.41443 .61128 Mdot
.42373 .61357 Mdot
.68629 .43755 Mdot
.64159 .60144 Mdot
.30256 .41566 Mdot
.50968 .34573 Mdot
.3196 .43973 Mdot
.63446 .64999 Mdot
.59706 .61231 Mdot
.39165 .64524 Mdot
.49221 .60237 Mdot
.48143 .34813 Mdot
.39634 .53189 Mdot
.5154 .32197 Mdot
.21471 .59871 Mdot
.66603 .47389 Mdot
.37178 .55819 Mdot
.64977 .65842 Mdot
.65931 .41868 Mdot
.40136 .58909 Mdot
.22194 .6759 Mdot
.38574 .54211 Mdot
.69115 .36846 Mdot
.75908 .36434 Mdot
.31817 .39769 Mdot
.33871 .71216 Mdot
.56558 .56757 Mdot
.39398 .56458 Mdot
.4985 .37463 Mdot
.42758 .51184 Mdot
.67528 .45132 Mdot
.63541 .61236 Mdot
.16629 .38787 Mdot
.65843 .44433 Mdot
.38549 .56135 Mdot
.30422 .40653 Mdot
.57149 .63269 Mdot
.56055 .40451 Mdot
.55978 .20786 Mdot
.47181 .54414 Mdot
.48147 .58545 Mdot
.43853 .61788 Mdot
.82514 .53426 Mdot
.46915 .32073 Mdot
.62734 .64049 Mdot
.68362 .4402 Mdot
.67123 .42619 Mdot
.4865 .35976 Mdot
.71834 .5546 Mdot
.49017 .46849 Mdot
.85954 .62882 Mdot
.47565 .34456 Mdot
.32583 .44533 Mdot
.61833 .52799 Mdot
.49706 .378 Mdot
.49815 .32729 Mdot
.51382 .35007 Mdot
.60618 .4602 Mdot
.61819 .62078 Mdot
.39519 .60598 Mdot
.60281 .59039 Mdot
.41838 .5503 Mdot
.42513 .45565 Mdot
.65972 .41685 Mdot
.63469 .60958 Mdot
.22772 .67693 Mdot
.59584 .67847 Mdot
.43432 .57859 Mdot
.26883 .69418 Mdot
.43774 .52099 Mdot
.26307 .56598 Mdot
.45747 .54021 Mdot
.487 .32987 Mdot
.44673 .50734 Mdot
.36943 .54114 Mdot
.62004 .19755 Mdot
.66118 .45148 Mdot
.47286 .30039 Mdot
.36802 .59474 Mdot
.49739 .59197 Mdot
.57096 .64358 Mdot
.57985 .62525 Mdot
.32385 .44008 Mdot
.25871 .43744 Mdot
.67455 .44294 Mdot
.18098 .50706 Mdot
.40184 .56705 Mdot
.72279 .3175 Mdot
.35991 .72059 Mdot
.40273 .58851 Mdot
.51392 .82766 Mdot
.43521 .7606 Mdot
.44995 .5618 Mdot
.36833 .66086 Mdot
.64786 .4323 Mdot
.758 .37498 Mdot
.44901 .54236 Mdot
.49741 .35308 Mdot
.64207 .6269 Mdot
.57517 .63122 Mdot
.33578 .42767 Mdot
.41698 .18613 Mdot
.65997 .46991 Mdot
.63794 .61443 Mdot
.43975 .56539 Mdot
.637 .45952 Mdot
.49389 .29717 Mdot
.40214 .52606 Mdot
.29336 .575 Mdot
.60191 .62193 Mdot
.43694 .53669 Mdot
.75155 .4755 Mdot
.24265 .44012 Mdot
.75328 .70881 Mdot
.67323 .45984 Mdot
.29257 .42061 Mdot
.38362 .51879 Mdot
.17936 .47158 Mdot
.36845 .61293 Mdot
.2067 .4863 Mdot
.6704 .60198 Mdot
.29061 .41785 Mdot
.42547 .57843 Mdot
.43803 .59731 Mdot
.61364 .51357 Mdot
.284 .41967 Mdot
.39737 .54258 Mdot
.48811 .52897 Mdot
.62273 .62431 Mdot
.45536 .34255 Mdot
.60517 .61919 Mdot
.43627 .58526 Mdot
.48123 .62851 Mdot
.58927 .60851 Mdot
.16521 .53101 Mdot
.34652 .40064 Mdot
.65601 .46104 Mdot
.49501 .6102 Mdot
.46548 .56709 Mdot
.8465 .4856 Mdot
.46793 .30254 Mdot
.78828 .57885 Mdot
.50771 .40571 Mdot
.72924 .60479 Mdot
.67898 .32504 Mdot
.5912 .83444 Mdot
.66733 .23729 Mdot
.43449 .63346 Mdot
.43306 .47665 Mdot
.41206 .67018 Mdot
.64471 .46842 Mdot
.56038 .69503 Mdot
.40442 .56343 Mdot
.42466 .56542 Mdot
.47645 .38025 Mdot
.69279 .54684 Mdot
.51352 .22137 Mdot
.57491 .45887 Mdot
.30637 .41725 Mdot
.61924 .6536 Mdot
.39124 .59185 Mdot
.4283 .4356 Mdot
.49223 .3889 Mdot
.7128 .30821 Mdot
.41419 .57943 Mdot
.40756 .20859 Mdot
.6018 .41929 Mdot
.6499 .46651 Mdot
.50724 .37071 Mdot
.44679 .25984 Mdot
.41032 .54901 Mdot
.62871 .43021 Mdot
.45192 .57592 Mdot
.44062 .37594 Mdot
.38699 .53514 Mdot
.30301 .43207 Mdot
.38315 .60417 Mdot
.57035 .43747 Mdot
.70002 .75665 Mdot
.31526 .54667 Mdot
.58816 .65185 Mdot
.51189 .30984 Mdot
.4837 .35667 Mdot
.58191 .61769 Mdot
.48384 .35206 Mdot
.41227 .73229 Mdot
.53344 .76181 Mdot
.31061 .41971 Mdot
.50018 .59444 Mdot
.31915 .43704 Mdot
.46759 .30225 Mdot
.40849 .55706 Mdot
.16242 .51407 Mdot
.47841 .33985 Mdot
.7882 .38481 Mdot
.66261 .44698 Mdot
.46987 .30154 Mdot
.41466 .53511 Mdot
.57678 .37602 Mdot
.50781 .37686 Mdot
.6742 .36263 Mdot
.43499 .59509 Mdot
.60134 .60825 Mdot
.43437 .60162 Mdot
.45641 .53708 Mdot
.47189 .38906 Mdot
.47232 .58479 Mdot
.64951 .45294 Mdot
.64284 .60751 Mdot
.52966 .84337 Mdot
.69272 .36777 Mdot
.39636 .54809 Mdot
.43941 .56723 Mdot
.56678 .6242 Mdot
.44035 .54204 Mdot
.63654 .41561 Mdot
.86347 .36434 Mdot
.32054 .42318 Mdot
.4929 .28648 Mdot
.68231 .33306 Mdot
.37402 .61818 Mdot
.43472 .61278 Mdot
.24937 .70397 Mdot
.70413 .33832 Mdot
.63713 .43587 Mdot
.44391 .51623 Mdot
.50456 .33199 Mdot
.30559 .40569 Mdot
.67101 .40853 Mdot
.46019 .60883 Mdot
.41918 .57165 Mdot
.29453 .42257 Mdot
.46666 .82427 Mdot
.44702 .23944 Mdot
.68318 .45144 Mdot
.44262 .50599 Mdot
.52234 .3172 Mdot
.42606 .5441 Mdot
.40386 .26666 Mdot
.58254 .62945 Mdot
.63165 .44592 Mdot
.77676 .60934 Mdot
.39051 .61646 Mdot
.65771 .41147 Mdot
.67248 .44575 Mdot
.38316 .52262 Mdot
.58692 .66478 Mdot
.65106 .62501 Mdot
.60811 .65486 Mdot
.61063 .178 Mdot
.24752 .45824 Mdot
.47323 .36687 Mdot
.64782 .43058 Mdot
.50398 .30206 Mdot
.30711 .44534 Mdot
.42785 .44394 Mdot
.49671 .28751 Mdot
.58324 .60823 Mdot
.51849 .34263 Mdot
.43394 .59922 Mdot
.67575 .43763 Mdot
.46448 .34071 Mdot
.36604 .59144 Mdot
.56862 .55138 Mdot
.43798 .33764 Mdot
.30087 .38448 Mdot
.29784 .37855 Mdot
.38616 .58224 Mdot
.46099 .3136 Mdot
.40578 .57379 Mdot
.68965 .41714 Mdot
.63054 .52516 Mdot
.36842 .60838 Mdot
.48461 .33924 Mdot
.5313 .56621 Mdot
.4348 .2609 Mdot
.44318 .51861 Mdot
.42994 .5884 Mdot
.42314 .54683 Mdot
.45268 .57594 Mdot
.70477 .57196 Mdot
.67052 .47049 Mdot
.5464 .53305 Mdot
.63929 .36006 Mdot
.5962 .62748 Mdot
.64691 .65582 Mdot
.3718 .2722 Mdot
.47178 .26818 Mdot
.64498 .44225 Mdot
.43676 .55022 Mdot
.69849 .36481 Mdot
.38853 .82963 Mdot
.1641 .54185 Mdot
.27146 .38938 Mdot
.46091 .34186 Mdot
.59257 .65777 Mdot
.49806 .38321 Mdot
.41811 .55426 Mdot
.37887 .52204 Mdot
.57921 .84581 Mdot
.69978 .40928 Mdot
.30113 .41716 Mdot
.42214 .54798 Mdot
.23868 .44558 Mdot
.50161 .328 Mdot
.51465 .34574 Mdot
.39586 .54078 Mdot
.65886 .63233 Mdot
.8358 .59703 Mdot
.65044 .4674 Mdot
.48642 .51608 Mdot
.53349 .62492 Mdot
.74681 .43768 Mdot
.66558 .41897 Mdot
.44091 .29552 Mdot
.45989 .33965 Mdot
.37915 .75561 Mdot
.59357 .62424 Mdot
.29877 .41809 Mdot
.35451 .53711 Mdot
.60036 .6016 Mdot
.47773 .39299 Mdot
.62008 .60257 Mdot
.37823 .59968 Mdot
.65808 .472 Mdot
.50732 .36366 Mdot
.70025 .44045 Mdot
.60179 .66866 Mdot
.33379 .42363 Mdot
.57966 .52428 Mdot
.59191 .71932 Mdot
.43073 .75795 Mdot
.42855 .54096 Mdot
.41799 .4337 Mdot
.45968 .59179 Mdot
.57177 .64655 Mdot
.44867 .5708 Mdot
.53958 .60655 Mdot
.5013 .37242 Mdot
.44024 .5385 Mdot
.43097 .61963 Mdot
.52312 .68694 Mdot
.41812 .58603 Mdot
.45705 .54498 Mdot
.4478 .55822 Mdot
.66056 .60768 Mdot
.49879 .57246 Mdot
.61373 .61489 Mdot
.55483 .21232 Mdot
.49699 .32655 Mdot
.28863 .38582 Mdot
.29813 .39087 Mdot
.20863 .46959 Mdot
.34306 .4685 Mdot
.70761 .55464 Mdot
.61238 .62515 Mdot
.66164 .45491 Mdot
.45212 .572 Mdot
.73199 .66717 Mdot
.6494 .32633 Mdot
.5043 .32828 Mdot
.69118 .36768 Mdot
.35923 .52064 Mdot
.82682 .53282 Mdot
.41581 .53362 Mdot
.50544 .17827 Mdot
.41497 .63896 Mdot
.37961 .54588 Mdot
.51588 .37069 Mdot
.34905 .46805 Mdot
.41865 .53744 Mdot
.56956 .64136 Mdot
.30312 .42669 Mdot
.63278 .69173 Mdot
.54769 .3047 Mdot
.44786 .28236 Mdot
.55541 .72336 Mdot
.46061 .58419 Mdot
.50665 .36169 Mdot
.62143 .61112 Mdot
.63744 .21666 Mdot
.64652 .4626 Mdot
.62127 .49471 Mdot
.46906 .67586 Mdot
.24463 .66173 Mdot
.29978 .42154 Mdot
.46025 .82026 Mdot
.40277 .60107 Mdot
.38841 .29538 Mdot
.40641 .62878 Mdot
.39267 .83111 Mdot
.33178 .4435 Mdot
.6575 .64215 Mdot
.63935 .42495 Mdot
.58555 .59869 Mdot
.44485 .77233 Mdot
.72859 .4232 Mdot
.54841 .48612 Mdot
.49385 .30599 Mdot
.55522 .53286 Mdot
.62003 .64719 Mdot
.41561 .61669 Mdot
.85076 .65435 Mdot
.5839 .63485 Mdot
.63274 .65566 Mdot
.20355 .57558 Mdot
.20208 .58381 Mdot
.38321 .50832 Mdot
.60466 .59772 Mdot
.49314 .30868 Mdot
.329 .41014 Mdot
.44223 .59899 Mdot
.44895 .5862 Mdot
.59257 .6083 Mdot
.51687 .36252 Mdot
.45884 .50228 Mdot
.48878 .33407 Mdot
.62436 .62346 Mdot
.49728 .33673 Mdot
.68006 .3548 Mdot
.46332 .32877 Mdot
.46141 .56158 Mdot
.44963 .57095 Mdot
.52766 .30159 Mdot
.59725 .6124 Mdot
.44347 .61041 Mdot
.38697 .60224 Mdot
.61133 .64615 Mdot
.51102 .40656 Mdot
.66747 .70314 Mdot
.39814 .55313 Mdot
.4182 .60176 Mdot
.29209 .42165 Mdot
.3937 .42956 Mdot
.30369 .28034 Mdot
.4388 .60673 Mdot
.30523 .44176 Mdot
.64322 .61584 Mdot
.40434 .57719 Mdot
.68665 .62272 Mdot
.67152 .35995 Mdot
.39126 .6159 Mdot
.47098 .30537 Mdot
.35688 .57641 Mdot
.78477 .6622 Mdot
.38322 .55214 Mdot
.6198 .64124 Mdot
.64067 .63914 Mdot
.21267 .57531 Mdot
.59192 .64044 Mdot
.4857 .29849 Mdot
.66448 .42834 Mdot
.42112 .84339 Mdot
.49491 .2974 Mdot
.36675 .55613 Mdot
.19126 .37602 Mdot
.42813 .53046 Mdot
.36855 .6012 Mdot
.82951 .49141 Mdot
.49582 .29937 Mdot
.63566 .641 Mdot
.6397 .50043 Mdot
.44914 .63525 Mdot
.63234 .45361 Mdot
.37195 .5328 Mdot
.4762 .59262 Mdot
.75 .35622 Mdot
.79496 .49017 Mdot
.66592 .39654 Mdot
.35071 .60581 Mdot
.43933 .60697 Mdot
.40978 .39935 Mdot
.44431 .56566 Mdot
.31948 .43833 Mdot
.62372 .65651 Mdot
.48406 .37966 Mdot
.32592 .41614 Mdot
.39871 .56488 Mdot
.30084 .41214 Mdot
.47434 .37106 Mdot
.62929 .43682 Mdot
.41139 .55312 Mdot
.34503 .42958 Mdot
.30544 .41597 Mdot
.4594 .59678 Mdot
.63796 .61634 Mdot
.33501 .52674 Mdot
.40343 .58035 Mdot
.40656 .61434 Mdot
.59303 .60971 Mdot
.1473 .53206 Mdot
.38353 .54782 Mdot
.4668 .4088 Mdot
.63194 .65782 Mdot
.71015 .38209 Mdot
.47581 .37646 Mdot
.47581 .58931 Mdot
.63058 .42833 Mdot
.65638 .4159 Mdot
.50454 .31728 Mdot
.56944 .61093 Mdot
.52022 .33655 Mdot
.52937 .56844 Mdot
.49075 .6113 Mdot
.41519 .52354 Mdot
.217 .32542 Mdot
.57292 .84009 Mdot
.57974 .63856 Mdot
.4962 .40732 Mdot
.5741 .46206 Mdot
.64536 .42775 Mdot
.50852 .31693 Mdot
.5721 .63662 Mdot
.58904 .65489 Mdot
.61873 .60426 Mdot
.29471 .40328 Mdot
.50468 .41116 Mdot
.6484 .60762 Mdot
.65832 .63121 Mdot
.43381 .59728 Mdot
.44036 .60789 Mdot
.34212 .6394 Mdot
.28819 .51894 Mdot
.33451 .42545 Mdot
.48927 .35988 Mdot
.81008 .32146 Mdot
.68535 .41044 Mdot
.52363 .68979 Mdot
.36972 .60989 Mdot
.73571 .80814 Mdot
.40337 .53351 Mdot
.44084 .56333 Mdot
.63747 .60302 Mdot
.34601 .41928 Mdot
.31875 .43473 Mdot
.62325 .64763 Mdot
.59492 .66361 Mdot
.31399 .43826 Mdot
.3772 .79442 Mdot
.48275 .84982 Mdot
.66704 .50192 Mdot
.61037 .64073 Mdot
.58995 .73171 Mdot
.62805 .44749 Mdot
.60628 .67145 Mdot
.6879 .41828 Mdot
.50177 .33232 Mdot
.46007 .3472 Mdot
.68406 .44227 Mdot
.43762 .59218 Mdot
.46826 .35109 Mdot
.48732 .59541 Mdot
.42253 .82305 Mdot
.54476 .79417 Mdot
.65742 .28522 Mdot
.4621 .62136 Mdot
.52093 .22156 Mdot
.52912 .24026 Mdot
.38918 .56935 Mdot
.70975 .63949 Mdot
.30045 .41571 Mdot
.65243 .66357 Mdot
.63472 .4171 Mdot
.76369 .69899 Mdot
.42962 .54551 Mdot
.61797 .63809 Mdot
.65643 .45231 Mdot
.22099 .56299 Mdot
.69203 .49775 Mdot
.41854 .54852 Mdot
.87013 .60219 Mdot
.67345 .63595 Mdot
.48265 .37871 Mdot
.29543 .25401 Mdot
.60682 .58879 Mdot
.2628 .39176 Mdot
.60593 .37531 Mdot
.24514 .68255 Mdot
.63417 .62827 Mdot
.49688 .40998 Mdot
.61987 .65241 Mdot
.32876 .43426 Mdot
.6606 .66478 Mdot
.51084 .35392 Mdot
.4207 .58215 Mdot
.48712 .34962 Mdot
.3361 .4209 Mdot
.3968 .27994 Mdot
.63315 .41969 Mdot
.47196 .30184 Mdot
.65576 .43272 Mdot
.24733 .43951 Mdot
.77435 .39419 Mdot
.64618 .4579 Mdot
.20248 .5455 Mdot
.37936 .60996 Mdot
.63161 .59289 Mdot
.47531 .35266 Mdot
.59789 .38047 Mdot
.58333 .50991 Mdot
.59662 .63291 Mdot
.49288 .36519 Mdot
.47676 .66967 Mdot
.19864 .40278 Mdot
.49933 .61625 Mdot
.27252 .46035 Mdot
.60829 .64376 Mdot
.51523 .34015 Mdot
.57884 .20238 Mdot
.58001 .60986 Mdot
.47506 .34457 Mdot
.64401 .41893 Mdot
.66942 .42269 Mdot
.40867 .53927 Mdot
.62423 .48586 Mdot
.48338 .36925 Mdot
.55844 .23192 Mdot
.64667 .64374 Mdot
.22347 .56062 Mdot
.33454 .40252 Mdot
.49236 .32044 Mdot
.38337 .53288 Mdot
.54745 .61749 Mdot
.67102 .35814 Mdot
.41143 .48534 Mdot
.80777 .32777 Mdot
.48688 .35886 Mdot
.62869 .65582 Mdot
.61456 .63486 Mdot
.42989 .51641 Mdot
.59692 .49271 Mdot
.51938 .32977 Mdot
.20507 .42439 Mdot
.20884 .50154 Mdot
.47143 .38656 Mdot
.54582 .26826 Mdot
.37089 .54737 Mdot
.46541 .58637 Mdot
.64353 .42723 Mdot
.4235 .58675 Mdot
.65265 .62132 Mdot
.42566 .53836 Mdot
.66926 .41741 Mdot
.48371 .3114 Mdot
.41221 .55723 Mdot
.32785 .40551 Mdot
.64538 .39894 Mdot
.68799 .43186 Mdot
.48772 .32183 Mdot
.60783 .59885 Mdot
.30922 .37248 Mdot
.48896 .33866 Mdot
.45956 .58323 Mdot
.56943 .39952 Mdot
.37841 .5954 Mdot
.37387 .77607 Mdot
.58551 .60432 Mdot
.4992 .37927 Mdot
.63302 .66005 Mdot
.65379 .43695 Mdot
.63711 .36111 Mdot
.44156 .57884 Mdot
.47534 .34002 Mdot
.52969 .29052 Mdot
.40808 .80536 Mdot
.56493 .62112 Mdot
.5716 .2926 Mdot
.64902 .6483 Mdot
.46713 .3789 Mdot
.28532 .65545 Mdot
.30871 .42503 Mdot
.50754 .33769 Mdot
.57037 .82874 Mdot
.48169 .34152 Mdot
.41467 .58868 Mdot
.39612 .58949 Mdot
.47158 .37138 Mdot
.29055 .3995 Mdot
.68886 .24274 Mdot
.44253 .33009 Mdot
.63629 .63512 Mdot
.32244 .69645 Mdot
.84141 .39284 Mdot
.66229 .48173 Mdot
.63997 .43097 Mdot
.44084 .6346 Mdot
.37956 .54355 Mdot
.67672 .40775 Mdot
.62283 .43788 Mdot
.34046 .41886 Mdot
.51269 .3464 Mdot
.66578 .66061 Mdot
.63057 .41547 Mdot
.3636 .63247 Mdot
.32879 .4672 Mdot
.46877 .531 Mdot
.52443 .60257 Mdot
.45071 .62065 Mdot
.2006 .48336 Mdot
.67891 .4245 Mdot
.38617 .58879 Mdot
.48571 .55227 Mdot
.63113 .438 Mdot
.32582 .43588 Mdot
.78886 .47595 Mdot
.5011 .34719 Mdot
.23924 .72956 Mdot
.37661 .57431 Mdot
.41105 .58652 Mdot
.67447 .46075 Mdot
.39923 .39905 Mdot
.60209 .60357 Mdot
.58633 .60193 Mdot
.46795 .32384 Mdot
.56655 .52083 Mdot
.44795 .5502 Mdot
.38748 .57379 Mdot
.50217 .35994 Mdot
.46976 .30265 Mdot
.61077 .25769 Mdot
.3996 .60609 Mdot
.65523 .45046 Mdot
.5565 .40562 Mdot
.67551 .42042 Mdot
.37256 .57383 Mdot
.41202 .59107 Mdot
.45853 .558 Mdot
.37568 .54601 Mdot
.68878 .43433 Mdot
.38817 .59169 Mdot
.41729 .6452 Mdot
.6249 .60246 Mdot
.46544 .57352 Mdot
.20347 .49773 Mdot
.42606 .59417 Mdot
.33277 .41961 Mdot
.35812 .46447 Mdot
.42125 .54602 Mdot
.46719 .57154 Mdot
.44238 .3387 Mdot
.42822 .57534 Mdot
.68969 .41757 Mdot
.60059 .62812 Mdot
.64813 .42987 Mdot
.68569 .43585 Mdot
.47744 .30528 Mdot
.33369 .43304 Mdot
.38154 .62217 Mdot
.31934 .39313 Mdot
.35099 .59835 Mdot
.38373 .61238 Mdot
.62551 .35453 Mdot
.49908 .17591 Mdot
.4429 .23972 Mdot
.4425 .57952 Mdot
.47927 .315 Mdot
.48796 .38175 Mdot
.45711 .48864 Mdot
.49391 .58678 Mdot
.67322 .40648 Mdot
.65208 .41814 Mdot
.28636 .56136 Mdot
.74928 .35862 Mdot
.3326 .42527 Mdot
.4246 .43937 Mdot
.48849 .60014 Mdot
.39419 .60862 Mdot
.40485 .52654 Mdot
.49819 .29015 Mdot
.56708 .40256 Mdot
.50383 .32755 Mdot
.67945 .36743 Mdot
.66949 .41593 Mdot
.44162 .54904 Mdot
.5909 .78613 Mdot
.57856 .62102 Mdot
.60022 .62729 Mdot
.67278 .41111 Mdot
.51081 .30917 Mdot
.32393 .59121 Mdot
.13684 .4354 Mdot
.66984 .63006 Mdot
.33092 .39515 Mdot
.389 .56355 Mdot
.48319 .31834 Mdot
.59028 .64928 Mdot
.28512 .40307 Mdot
.39335 .61505 Mdot
.5223 .34042 Mdot
.44519 .58112 Mdot
.41051 .66955 Mdot
.63441 .61538 Mdot
.41877 .84776 Mdot
.57177 .6291 Mdot
.64295 .40187 Mdot
.63614 .44459 Mdot
.40271 .59061 Mdot
.23969 .30275 Mdot
.62241 .58893 Mdot
.6066 .43917 Mdot
.33621 .43956 Mdot
.58069 .39239 Mdot
.30131 .43627 Mdot
.49561 .37764 Mdot
.30193 .42495 Mdot
.50905 .36485 Mdot
.2951 .53714 Mdot
.62951 .58212 Mdot
.32392 .42096 Mdot
.42845 .39262 Mdot
.49496 .59067 Mdot
.28322 .394 Mdot
.37665 .62844 Mdot
.35336 .73086 Mdot
.50047 .35852 Mdot
.2945 .39704 Mdot
.41728 .61617 Mdot
.70267 .73383 Mdot
.64498 .45015 Mdot
.67336 .40491 Mdot
.48501 .58247 Mdot
.51267 .34341 Mdot
.5801 .65233 Mdot
.66424 .55748 Mdot
.70984 .39553 Mdot
.38698 .58086 Mdot
.42117 .53758 Mdot
.64993 .65403 Mdot
.60034 .57895 Mdot
.40766 .59309 Mdot
.52083 .667 Mdot
.39599 .59914 Mdot
.64662 .4142 Mdot
.57513 .62356 Mdot
.60897 .63238 Mdot
.48881 .37155 Mdot
.61441 .59413 Mdot
.53243 .59061 Mdot
.57487 .41319 Mdot
.38758 .63408 Mdot
.65873 .44254 Mdot
.58761 .45642 Mdot
.69062 .36716 Mdot
.63042 .78323 Mdot
.63848 .66358 Mdot
.47105 .57399 Mdot
.64396 .64906 Mdot
.30602 .40142 Mdot
.59893 .61412 Mdot
.60707 .66084 Mdot
.39872 .57466 Mdot
.42056 .55246 Mdot
.4918 .30059 Mdot
.5915 .4865 Mdot
.63575 .608 Mdot
.38898 .5861 Mdot
.43639 .53423 Mdot
.45901 .54658 Mdot
.50549 .44588 Mdot
.58281 .64312 Mdot
.46376 .69862 Mdot
.28702 .62165 Mdot
.6342 .60652 Mdot
.80192 .63974 Mdot
.61332 .37593 Mdot
.48978 .28113 Mdot
.69605 .45725 Mdot
.3998 .60691 Mdot
.4709 .37278 Mdot
.41751 .55439 Mdot
.52473 .60322 Mdot
.42044 .56923 Mdot
.29219 .42951 Mdot
.43438 .63343 Mdot
.4604 .36153 Mdot
.4877 .34183 Mdot
.38112 .56457 Mdot
.41409 .55968 Mdot
.41445 .27062 Mdot
.59959 .66593 Mdot
.60524 .60337 Mdot
.39057 .38723 Mdot
.31668 .41333 Mdot
.63136 .44832 Mdot
.44934 .56385 Mdot
.47393 .31568 Mdot
.48796 .34764 Mdot
.58571 .5977 Mdot
.49587 .35165 Mdot
.6604 .46641 Mdot
.44249 .57537 Mdot
.67548 .40594 Mdot
.29783 .39494 Mdot
.61025 .65599 Mdot
.43439 .54748 Mdot
.43299 .59792 Mdot
.64055 .63914 Mdot
.38715 .62038 Mdot
.29268 .4232 Mdot
.48243 .34586 Mdot
.63037 .62143 Mdot
.6649 .4264 Mdot
.50139 .37367 Mdot
.42538 .60885 Mdot
.80346 .31947 Mdot
.41687 .59277 Mdot
.41159 .61072 Mdot
.5379 .85264 Mdot
.42479 .63481 Mdot
.48014 .36131 Mdot
.65862 .64442 Mdot
.48479 .59469 Mdot
.21915 .47059 Mdot
.16065 .54407 Mdot
.50156 .31393 Mdot
.38928 .55662 Mdot
.63307 .79096 Mdot
.38456 .5585 Mdot
.18223 .49936 Mdot
.31885 .29999 Mdot
.52161 .50877 Mdot
.47186 .6367 Mdot
.67484 .45543 Mdot
.49029 .30042 Mdot
.50032 .37187 Mdot
.36146 .69796 Mdot
.39431 .57574 Mdot
.38642 .65983 Mdot
.41785 .62068 Mdot
.66756 .41972 Mdot
.29565 .59424 Mdot
.4883 .35624 Mdot
.53839 .19139 Mdot
.45693 .58922 Mdot
.58253 .64447 Mdot
.51901 .34571 Mdot
.62658 .37111 Mdot
.41674 .61312 Mdot
.31275 .3919 Mdot
.68489 .39903 Mdot
.46602 .63076 Mdot
.66376 .44086 Mdot
.39065 .6092 Mdot
.39427 .64701 Mdot
.33731 .22135 Mdot
.63108 .60958 Mdot
.64079 .42527 Mdot
.53308 .25118 Mdot
.40059 .6291 Mdot
.63282 .62423 Mdot
.59377 .62547 Mdot
.33776 .41185 Mdot
.55562 .47021 Mdot
.745 .48959 Mdot
.60562 .75312 Mdot
.32997 .69214 Mdot
.51375 .32837 Mdot
.57485 .26436 Mdot
.4418 .60173 Mdot
.70942 .31138 Mdot
.67961 .40414 Mdot
.41415 .58485 Mdot
.37424 .73483 Mdot
.6016 .65368 Mdot
.41216 .6034 Mdot
.3198 .43725 Mdot
.67555 .26792 Mdot
.69126 .29147 Mdot
.81268 .5801 Mdot
.4963 .31086 Mdot
.37227 .52987 Mdot
.52171 .60367 Mdot
.47912 .29677 Mdot
.40638 .62608 Mdot
.47884 .35465 Mdot
.30922 .73219 Mdot
.28702 .41036 Mdot
.59986 .65604 Mdot
.61785 .37424 Mdot
.46013 .61544 Mdot
.44063 .53229 Mdot
.29261 .38476 Mdot
.46795 .59723 Mdot
.41956 .18766 Mdot
.65422 .3006 Mdot
.46551 .3407 Mdot
.62145 .60451 Mdot
.46966 .61399 Mdot
.54585 .41365 Mdot
.39688 .58002 Mdot
.53518 .77717 Mdot
.47058 .57656 Mdot
.73981 .4779 Mdot
.64218 .6264 Mdot
.66097 .43938 Mdot
.34844 .55939 Mdot
.4282 .56715 Mdot
.53104 .35868 Mdot
.46328 .64027 Mdot
.3795 .55564 Mdot
.56821 .63731 Mdot
.57808 .63001 Mdot
.61355 .61591 Mdot
.49499 .39137 Mdot
.74107 .35169 Mdot
.65059 .44446 Mdot
.36167 .55633 Mdot
.63012 .41551 Mdot
.44829 .50028 Mdot
.30025 .3839 Mdot
.71259 .71094 Mdot
.47259 .59353 Mdot
.61578 .62337 Mdot
.75318 .57255 Mdot
.64498 .61881 Mdot
.52505 .40782 Mdot
.67503 .44196 Mdot
.59254 .64849 Mdot
.43635 .56498 Mdot
.58103 .46006 Mdot
.75672 .65899 Mdot
.65154 .42582 Mdot
.35941 .60714 Mdot
.46029 .32827 Mdot
.68557 .33932 Mdot
.83874 .35492 Mdot
.63736 .43769 Mdot
.54214 .25327 Mdot
.39037 .57393 Mdot
.5809 .61495 Mdot
.67122 .46016 Mdot
.65113 .45773 Mdot
.49636 .35813 Mdot
.42167 .55101 Mdot
.426 .54908 Mdot
.46778 .37798 Mdot
.65455 .41813 Mdot
.44357 .52834 Mdot
.39735 .53066 Mdot
.57881 .84753 Mdot
.34138 .66705 Mdot
.15685 .62043 Mdot
.52566 .56352 Mdot
.38465 .7459 Mdot
.64235 .5527 Mdot
.62162 .65846 Mdot
.41881 .54602 Mdot
.44675 .62468 Mdot
.48506 .36885 Mdot
.42974 .58406 Mdot
.50448 .39811 Mdot
.64272 .44155 Mdot
.79762 .63961 Mdot
.78199 .51595 Mdot
.29842 .71822 Mdot
.4281 .5821 Mdot
.75131 .40888 Mdot
.31833 .40461 Mdot
.6349 .40329 Mdot
.62267 .61805 Mdot
.37465 .59448 Mdot
.42073 .26453 Mdot
.50612 .33455 Mdot
.58709 .62629 Mdot
.53038 .21322 Mdot
.46015 .25865 Mdot
.37246 .57493 Mdot
.48867 .39183 Mdot
.71672 .60171 Mdot
.52806 .66458 Mdot
.62925 .46642 Mdot
.29612 .433 Mdot
.50209 .32601 Mdot
.67482 .41548 Mdot
.67587 .60918 Mdot
.59102 .64435 Mdot
.65965 .61732 Mdot
.39365 .25331 Mdot
.49815 .2849 Mdot
.32693 .41276 Mdot
.74397 .35652 Mdot
.73425 .32178 Mdot
.29308 .43006 Mdot
.46469 .36636 Mdot
.58114 .6366 Mdot
.62726 .63378 Mdot
.60151 .62929 Mdot
.55249 .19162 Mdot
.5701 .61259 Mdot
.53134 .71172 Mdot
.43522 .53227 Mdot
.38885 .65264 Mdot
.388 .55571 Mdot
.68749 .41948 Mdot
.63646 .62086 Mdot
.61063 .52355 Mdot
.36071 .57069 Mdot
.79781 .61254 Mdot
.38637 .57603 Mdot
.62416 .45928 Mdot
.40813 .60683 Mdot
.55911 .70408 Mdot
.63848 .65564 Mdot
.43678 .58312 Mdot
.69207 .44974 Mdot
.30798 .41347 Mdot
.59934 .67427 Mdot
.42237 .54705 Mdot
.68948 .53974 Mdot
.41642 .63535 Mdot
.35581 .77974 Mdot
.23579 .57233 Mdot
.32975 .39407 Mdot
.48106 .52431 Mdot
.51084 .32941 Mdot
.3832 .65254 Mdot
.50684 .59751 Mdot
.65314 .42633 Mdot
.79455 .43791 Mdot
.49655 .32285 Mdot
.3064 .56305 Mdot
.4346 .51343 Mdot
.33031 .43542 Mdot
.5634 .60108 Mdot
.69172 .43315 Mdot
.36729 .58877 Mdot
.38601 .5217 Mdot
.32307 .74213 Mdot
.50253 .60558 Mdot
.43617 .54009 Mdot
.2949 .38632 Mdot
.46942 .70429 Mdot
.42738 .5965 Mdot
.52288 .41226 Mdot
.66209 .62431 Mdot
.48794 .58527 Mdot
.46629 .69576 Mdot
.38952 .58503 Mdot
.58341 .62196 Mdot
.61937 .58179 Mdot
.74959 .54262 Mdot
.33766 .43545 Mdot
.4707 .57744 Mdot
.24366 .61296 Mdot
.46086 .58877 Mdot
.65835 .44994 Mdot
.37582 .55364 Mdot
.50719 .34171 Mdot
.53664 .19831 Mdot
.47413 .36607 Mdot
.40594 .54641 Mdot
.60541 .6341 Mdot
.68219 .44998 Mdot
.4199 .24273 Mdot
.34184 .3014 Mdot
.52166 .70812 Mdot
.22728 .67955 Mdot
.29123 .40149 Mdot
.28672 .42772 Mdot
.69051 .44086 Mdot
.43677 .58458 Mdot
.21982 .59195 Mdot
.43067 .63812 Mdot
.41743 .60303 Mdot
.41923 .56868 Mdot
.73424 .36079 Mdot
.64435 .43313 Mdot
.49697 .34439 Mdot
.41022 .59303 Mdot
.38911 .58945 Mdot
.63671 .65058 Mdot
.3078 .41537 Mdot
.48004 .37926 Mdot
.31596 .42065 Mdot
.47938 .32541 Mdot
.79429 .65282 Mdot
.35234 .57315 Mdot
.31008 .41199 Mdot
.67113 .39636 Mdot
.59197 .60991 Mdot
.57102 .40054 Mdot
.49664 .37619 Mdot
.48971 .3615 Mdot
.38751 .57865 Mdot
.58342 .61677 Mdot
.62096 .59628 Mdot
.30567 .40049 Mdot
.64242 .45817 Mdot
.41244 .54917 Mdot
.38042 .60801 Mdot
.48734 .49483 Mdot
.50116 .29319 Mdot
.49224 .66033 Mdot
.73025 .56307 Mdot
.44115 .58188 Mdot
.60707 .5977 Mdot
.4113 .56565 Mdot
.58798 .79888 Mdot
.58603 .60656 Mdot
.38385 .54384 Mdot
.73144 .30471 Mdot
.56296 .40287 Mdot
.71393 .52092 Mdot
.45534 .55157 Mdot
.26304 .73508 Mdot
.44777 .60266 Mdot
.61593 .82022 Mdot
.4002 .31104 Mdot
.44043 .54711 Mdot
.43646 .60153 Mdot
.63002 .74832 Mdot
.39582 .56276 Mdot
.45923 .35935 Mdot
.30475 .56446 Mdot
.5929 .65892 Mdot
.62012 .53815 Mdot
.38041 .44937 Mdot
.34112 .43327 Mdot
.46765 .32464 Mdot
.55492 .28597 Mdot
.30619 .43421 Mdot
.6124 .64223 Mdot
.45301 .57585 Mdot
.542 .50973 Mdot
.48332 .40016 Mdot
.45703 .53522 Mdot
.66444 .44882 Mdot
.60928 .29093 Mdot
.50464 .40197 Mdot
.66389 .43229 Mdot
.46517 .6086 Mdot
.66616 .70703 Mdot
.30561 .29757 Mdot
.435 .85619 Mdot
.68199 .45295 Mdot
.66117 .41513 Mdot
.59538 .19586 Mdot
.34004 .43835 Mdot
.32121 .7213 Mdot
.72534 .47968 Mdot
.64717 .46789 Mdot
.27394 .63535 Mdot
.50512 .32662 Mdot
.68757 .5313 Mdot
.65219 .66371 Mdot
.4126 .52379 Mdot
.43438 .56602 Mdot
.63927 .45489 Mdot
.68421 .62848 Mdot
.3226 .23294 Mdot
.65595 .4313 Mdot
.38487 .64016 Mdot
.50692 .4594 Mdot
.60904 .37811 Mdot
.49373 .29253 Mdot
.33929 .43102 Mdot
.27131 .42475 Mdot
.63126 .65029 Mdot
.33895 .42336 Mdot
.68147 .28335 Mdot
.47062 .59503 Mdot
.65734 .42312 Mdot
.63372 .37108 Mdot
.66834 .42704 Mdot
.31242 .43496 Mdot
.3376 .40218 Mdot
.62345 .60187 Mdot
.60505 .60414 Mdot
.4025 .75219 Mdot
.27032 .56363 Mdot
.38276 .56087 Mdot
.7695 .61517 Mdot
.64773 .64029 Mdot
.51148 .56978 Mdot
.29977 .43761 Mdot
.31215 .4142 Mdot
.37908 .67003 Mdot
.44294 .5539 Mdot
.20635 .56473 Mdot
.44367 .55651 Mdot
.28751 .58368 Mdot
.41371 .62829 Mdot
.49624 .35529 Mdot
.44729 .55534 Mdot
.35172 .40629 Mdot
.37126 .54726 Mdot
.37688 .56022 Mdot
.51071 .33721 Mdot
.47371 .62653 Mdot
.50761 .34356 Mdot
.40301 .54539 Mdot
.30953 .44563 Mdot
.47268 .31648 Mdot
.24541 .46866 Mdot
.46189 .40163 Mdot
.46081 .31603 Mdot
.33267 .40842 Mdot
.32937 .39784 Mdot
.22372 .44165 Mdot
.62405 .61911 Mdot
.58184 .66572 Mdot
.43256 .58683 Mdot
.51493 .34639 Mdot
.64224 .43022 Mdot
.3904 .59302 Mdot
.4239 .63185 Mdot
.43822 .53877 Mdot
.61891 .65575 Mdot
.51731 .32435 Mdot
.30496 .40929 Mdot
.4919 .39348 Mdot
.52395 .37822 Mdot
.49701 .40187 Mdot
.49219 .5587 Mdot
.3443 .54987 Mdot
.40045 .77458 Mdot
.79642 .55637 Mdot
.67038 .22771 Mdot
.58875 .63898 Mdot
.47098 .30443 Mdot
.3413 .41352 Mdot
.36396 .50351 Mdot
.6211 .62316 Mdot
.51052 .35233 Mdot
.44594 .58019 Mdot
.35692 .60458 Mdot
.70007 .40292 Mdot
.39222 .6568 Mdot
.21895 .51515 Mdot
.50404 .3944 Mdot
.49513 .41116 Mdot
.72952 .32066 Mdot
.3073 .57417 Mdot
.57563 .51653 Mdot
.41185 .57655 Mdot
.30935 .39135 Mdot
.59019 .64917 Mdot
.35521 .26077 Mdot
.63372 .42749 Mdot
.5947 .48986 Mdot
.42955 .58184 Mdot
.70187 .48476 Mdot
.60349 .63317 Mdot
.32756 .43338 Mdot
.63793 .45355 Mdot
.34663 .41609 Mdot
.4915 .28775 Mdot
.20162 .60272 Mdot
.46442 .59239 Mdot
.38353 .55252 Mdot
.63874 .40891 Mdot
.61933 .65162 Mdot
.30368 .37921 Mdot
.38084 .79234 Mdot
.4724 .37037 Mdot
.19786 .56009 Mdot
.6372 .60099 Mdot
.56219 .72486 Mdot
.49374 .39354 Mdot
.6719 .41107 Mdot
.22848 .43532 Mdot
.67049 .41801 Mdot
.41833 .54246 Mdot
.61201 .6279 Mdot
.6468 .45033 Mdot
.53763 .37777 Mdot
.66435 .76843 Mdot
.58046 .73121 Mdot
.46005 .57222 Mdot
.73753 .69242 Mdot
.46018 .83655 Mdot
.67487 .67195 Mdot
.63071 .42413 Mdot
.40167 .58134 Mdot
.43484 .62084 Mdot
.45667 .58627 Mdot
.67137 .4508 Mdot
.60606 .35217 Mdot
.49922 .36434 Mdot
.38589 .5661 Mdot
.3398 .41534 Mdot
.50564 .34244 Mdot
.63239 .36627 Mdot
.48407 .36375 Mdot
.61413 .66751 Mdot
.3781 .54544 Mdot
.61274 .48533 Mdot
.7089 .75726 Mdot
.64889 .42884 Mdot
.46043 .31715 Mdot
.37926 .58659 Mdot
.76335 .39707 Mdot
.61463 .61766 Mdot
.47088 .36732 Mdot
.41093 .58593 Mdot
.58496 .36304 Mdot
.41122 .27005 Mdot
.48554 .36295 Mdot
.62914 .62982 Mdot
.69328 .65864 Mdot
.4259 .58647 Mdot
.45151 .60247 Mdot
.61866 .64972 Mdot
.36958 .44054 Mdot
.55 .2055 Mdot
.41356 .56206 Mdot
.66142 .43794 Mdot
.15366 .45108 Mdot
.45446 .54493 Mdot
.32212 .64647 Mdot
.4975 .30525 Mdot
.7133 .54827 Mdot
.49754 .65761 Mdot
.45494 .50864 Mdot
.63898 .75157 Mdot
.43813 .44644 Mdot
.78391 .6547 Mdot
.51244 .38418 Mdot
.41842 .3313 Mdot
.78137 .66725 Mdot
.68631 .45657 Mdot
.58129 .57237 Mdot
.4905 .51627 Mdot
.51847 .19411 Mdot
.68719 .60974 Mdot
.38349 .36115 Mdot
.43357 .2517 Mdot
.51475 .48356 Mdot
.4791 .33895 Mdot
.32864 .51127 Mdot
.41421 .55136 Mdot
.45274 .83635 Mdot
.52543 .67259 Mdot
.30014 .24208 Mdot
.73166 .70032 Mdot
.24633 .61303 Mdot
.72867 .68338 Mdot
.6109 .80094 Mdot
.38051 .76255 Mdot
.7853 .56928 Mdot
.16821 .48259 Mdot
.7185 .2989 Mdot
.2573 .65668 Mdot
.35924 .52743 Mdot
.43011 .43598 Mdot
.28944 .73509 Mdot
.53411 .73238 Mdot
.22182 .32921 Mdot
.4818 .37267 Mdot
.65887 .64177 Mdot
.49261 .51266 Mdot
.56118 .62634 Mdot
.70576 .46577 Mdot
.64922 .74969 Mdot
.59875 .82465 Mdot
.54995 .69833 Mdot
.26418 .7399 Mdot
.38659 .72178 Mdot
.54806 .14598 Mdot
.43777 .34805 Mdot
.63872 .59447 Mdot
.32173 .35275 Mdot
.73845 .331 Mdot
.77323 .49515 Mdot
.52378 .55496 Mdot
.66265 .34369 Mdot
.2618 .49248 Mdot
.61685 .63838 Mdot
.5224 .65722 Mdot
.46753 .26864 Mdot
.78506 .48378 Mdot
.25354 .39194 Mdot
.63866 .77015 Mdot
.55075 .50015 Mdot
.674 .53184 Mdot
.58141 .2605 Mdot
.80481 .32228 Mdot
.261 .59571 Mdot
.5198 .82185 Mdot
.70477 .45671 Mdot
.68844 .63391 Mdot
.4669 .20354 Mdot
.26968 .53712 Mdot
.73906 .32913 Mdot
.81542 .42905 Mdot
.4214 .8368 Mdot
.8369 .44718 Mdot
.58802 .66882 Mdot
.44042 .54085 Mdot
.51242 .81254 Mdot
.31793 .67051 Mdot
.27799 .42717 Mdot
.82046 .55246 Mdot
.29752 .39338 Mdot
.57163 .65104 Mdot
.52504 .20584 Mdot
.54106 .70633 Mdot
.19734 .55186 Mdot
.31181 .37841 Mdot
.46432 .62084 Mdot
.29716 .19696 Mdot
.77842 .65607 Mdot
.74433 .54061 Mdot
.58092 .84672 Mdot
.73232 .44166 Mdot
.22626 .57059 Mdot
.65148 .45312 Mdot
.7539 .70991 Mdot
.62294 .63191 Mdot
.84636 .61475 Mdot
.7012 .75108 Mdot
.30524 .26068 Mdot
.11333 .43633 Mdot
.68916 .30637 Mdot
.54257 .52599 Mdot
.43265 .45095 Mdot
.22761 .4906 Mdot
.36018 .21985 Mdot
.26453 .29665 Mdot
.74325 .37973 Mdot
.26124 .70869 Mdot
.75701 .69638 Mdot
.28041 .6499 Mdot
.21978 .62412 Mdot
.50516 .19799 Mdot
.49213 .43468 Mdot
.55098 .6102 Mdot
.45283 .36996 Mdot
.7105 .67011 Mdot
.83503 .52567 Mdot
.30915 .64172 Mdot
.13201 .44559 Mdot
.3262 .37945 Mdot
.39239 .31891 Mdot
.52558 .83815 Mdot
.26073 .46494 Mdot
.29772 .64766 Mdot
.62766 .21442 Mdot
.46516 .5345 Mdot
.6662 .24192 Mdot
.73611 .63361 Mdot
.5673 .29174 Mdot
.7066 .2876 Mdot
.69801 .58319 Mdot
.34272 .76061 Mdot
.52863 .7966 Mdot
.74851 .33923 Mdot
.59604 .66232 Mdot
.2548 .52848 Mdot
.2658 .6136 Mdot
.56954 .8518 Mdot
.53376 .25162 Mdot
.47964 .88063 Mdot
.49464 .22689 Mdot
.3733 .62135 Mdot
.509 .60873 Mdot
.33191 .58766 Mdot
.25921 .55763 Mdot
.43359 .53436 Mdot
.74412 .39781 Mdot
.55413 .85612 Mdot
.36304 .7226 Mdot
.57037 .30523 Mdot
.79977 .4458 Mdot
.44129 .85758 Mdot
.43108 .79486 Mdot
.41977 .28049 Mdot
.32097 .62834 Mdot
.66593 .20714 Mdot
.4982 .33317 Mdot
.27748 .64941 Mdot
.64932 .47417 Mdot
.36103 .26623 Mdot
.61159 .74413 Mdot
.33839 .24536 Mdot
.5528 .8569 Mdot
.56044 .21177 Mdot
.45749 .24146 Mdot
.23303 .40666 Mdot
.18569 .54518 Mdot
.80995 .48043 Mdot
.36711 .54004 Mdot
.55942 .56395 Mdot
.2984 .38784 Mdot
.43783 .77253 Mdot
.29804 .67051 Mdot
.34367 .33116 Mdot
.46715 .63537 Mdot
.27097 .3266 Mdot
.49897 .41399 Mdot
.58881 .47697 Mdot
.86077 .44513 Mdot
.47849 .55343 Mdot
.70686 .33698 Mdot
.39175 .81668 Mdot
.24007 .54406 Mdot
.52773 .83271 Mdot
.66901 .54894 Mdot
.83224 .44794 Mdot
.67531 .77186 Mdot
.33686 .31276 Mdot
.81147 .60913 Mdot
.55009 .86984 Mdot
.82079 .41045 Mdot
.49287 .64026 Mdot
.69466 .42546 Mdot
.89675 .49063 Mdot
.47921 .39356 Mdot
.78641 .40312 Mdot
.33066 .69221 Mdot
.58768 .34749 Mdot
.61676 .67804 Mdot
.34531 .53472 Mdot
.52456 .49044 Mdot
.67493 .626 Mdot
.4862 .59626 Mdot
.83086 .3788 Mdot
.80106 .39269 Mdot
.83637 .41319 Mdot
.34204 .78607 Mdot
.81104 .61521 Mdot
.48701 .48337 Mdot
.54203 .72168 Mdot
.43901 .48654 Mdot
.37155 .56249 Mdot
.32105 .50463 Mdot
.6851 .30422 Mdot
.31504 .28332 Mdot
.7644 .48601 Mdot
.56657 .6398 Mdot
.7923 .59749 Mdot
.7684 .23811 Mdot
.40664 .72889 Mdot
.42038 .69913 Mdot
.70327 .3011 Mdot
.26742 .57488 Mdot
.72034 .65746 Mdot
.30427 .27663 Mdot
.54748 .84853 Mdot
.46894 .50585 Mdot
.28304 .67688 Mdot
.36172 .35351 Mdot
.18879 .46996 Mdot
.40984 .40527 Mdot
.65916 .76232 Mdot
.42493 .46551 Mdot
.39565 .23155 Mdot
.60297 .5338 Mdot
.31256 .24804 Mdot
.37445 .28836 Mdot
.60997 .28589 Mdot
.26443 .64959 Mdot
.69536 .36108 Mdot
.27992 .59764 Mdot
.52198 .46485 Mdot
.35696 .49921 Mdot
.44023 .44643 Mdot
.27959 .60401 Mdot
.1936 .45835 Mdot
.83398 .53977 Mdot
.54738 .87906 Mdot
.76591 .29368 Mdot
.2766 .75175 Mdot
.73379 .62495 Mdot
.42429 .52383 Mdot
.5041 .85175 Mdot
.85042 .46508 Mdot
.67108 .78186 Mdot
.57433 .22407 Mdot
.55655 .37381 Mdot
.64015 .39977 Mdot
.77017 .30542 Mdot
.38855 .38082 Mdot
.57957 .8173 Mdot
.68131 .24236 Mdot
.69831 .45291 Mdot
.48816 .17612 Mdot
.79047 .38497 Mdot
.61177 .73255 Mdot
.45245 .66643 Mdot
.44397 .5225 Mdot
.55996 .69431 Mdot
.63494 .66173 Mdot
.56552 .25392 Mdot
.26578 .54833 Mdot
.49019 .32342 Mdot
.3213 .46899 Mdot
.5427 .55957 Mdot
.43692 .63319 Mdot
.3891 .44871 Mdot
.65843 .64992 Mdot
.79485 .55809 Mdot
.58905 .43129 Mdot
.83567 .59847 Mdot
.66576 .29444 Mdot
.4629 .64151 Mdot
.24544 .55793 Mdot
.47487 .24979 Mdot
.60873 .20455 Mdot
.65915 .47148 Mdot
.71543 .72051 Mdot
.51041 .41988 Mdot
.25587 .53327 Mdot
.55679 .6879 Mdot
.3577 .76506 Mdot
.34413 .54686 Mdot
.7426 .56533 Mdot
.50488 .78109 Mdot
.58624 .47971 Mdot
.55293 .61834 Mdot
.55095 .60137 Mdot
.3893 .85141 Mdot
.66102 .25863 Mdot
.59274 .27791 Mdot
.70551 .72865 Mdot
.67946 .43654 Mdot
.6395 .61113 Mdot
.31174 .52654 Mdot
.3489 .76933 Mdot
.5241 .7632 Mdot
.41238 .26882 Mdot
.65315 .32526 Mdot
.36132 .32767 Mdot
.7223 .70309 Mdot
.73532 .68416 Mdot
.29234 .24418 Mdot
.56437 .61651 Mdot
.38888 .78636 Mdot
.29102 .70463 Mdot
.65199 .64379 Mdot
.62627 .68187 Mdot
.77386 .46398 Mdot
.83872 .56213 Mdot
.61212 .47592 Mdot
.25524 .71023 Mdot
.20377 .4705 Mdot
.59277 .36196 Mdot
.42486 .24081 Mdot
.24308 .63177 Mdot
.69637 .7354 Mdot
.53718 .66094 Mdot
.63198 .7235 Mdot
.35212 .61023 Mdot
.37354 .65225 Mdot
.74936 .26628 Mdot
.46125 .40722 Mdot
.56417 .72084 Mdot
.68763 .57542 Mdot
.4613 .58188 Mdot
.80617 .32706 Mdot
.41988 .8231 Mdot
.61178 .19852 Mdot
.67364 .39401 Mdot
.43399 .61371 Mdot
.37488 .5403 Mdot
.33569 .64522 Mdot
.73134 .54949 Mdot
.80615 .42481 Mdot
.24515 .63612 Mdot
.7117 .62195 Mdot
.52974 .67157 Mdot
.70711 .33822 Mdot
.6298 .77507 Mdot
.48234 .83715 Mdot
.56022 .462 Mdot
.67431 .29541 Mdot
.235 .43213 Mdot
.28583 .75415 Mdot
.44925 .43222 Mdot
.493 .49324 Mdot
.75553 .43304 Mdot
.70721 .56243 Mdot
.39332 .24342 Mdot
.3837 .60521 Mdot
.53093 .21299 Mdot
.61162 .79855 Mdot
.20895 .33415 Mdot
.4062 .20794 Mdot
.81643 .34107 Mdot
.55502 .77331 Mdot
.69222 .55789 Mdot
.67281 .7099 Mdot
.18798 .35114 Mdot
.42609 .43244 Mdot
.78216 .62859 Mdot
.23064 .41842 Mdot
.71408 .71634 Mdot
.69491 .44978 Mdot
.68404 .50181 Mdot
.79849 .44058 Mdot
.82924 .58329 Mdot
.45525 .8051 Mdot
.66123 .75476 Mdot
.59608 .52921 Mdot
.85244 .52235 Mdot
.76517 .41048 Mdot
.50078 .47359 Mdot
.46876 .31175 Mdot
.60827 .21485 Mdot
.72797 .66777 Mdot
.7689 .59304 Mdot
.27797 .65675 Mdot
.43774 .41175 Mdot
.30752 .55588 Mdot
.60993 .71395 Mdot
.2867 .4749 Mdot
.71178 .57484 Mdot
.24485 .55658 Mdot
.61393 .80571 Mdot
.41881 .42289 Mdot
.46068 .24744 Mdot
.69963 .33771 Mdot
.21274 .62849 Mdot
.73517 .54431 Mdot
.65164 .25181 Mdot
.5252 .82254 Mdot
.38073 .3062 Mdot
.25201 .61109 Mdot
.53949 .91199 Mdot
.25357 .67241 Mdot
.79873 .51657 Mdot
.8344 .52299 Mdot
.51247 .837 Mdot
.80015 .53859 Mdot
.37593 .21002 Mdot
.3523 .67079 Mdot
.29787 .53158 Mdot
.42113 .56854 Mdot
.85621 .44301 Mdot
.2743 .49321 Mdot
.83942 .51816 Mdot
.47352 .85787 Mdot
.57154 .6983 Mdot
.44153 .63253 Mdot
.5048 .3861 Mdot
.45884 .28717 Mdot
.30242 .47612 Mdot
.64492 .72621 Mdot
.35062 .67578 Mdot
.65915 .3083 Mdot
.48218 .2929 Mdot
.39412 .39029 Mdot
.66297 .68642 Mdot
.64585 .27324 Mdot
.72407 .5648 Mdot
.34416 .45661 Mdot
.56982 .49572 Mdot
.27 .5914 Mdot
.49987 .65868 Mdot
.60764 .73639 Mdot
.34584 .24123 Mdot
.52537 .42298 Mdot
.48033 .36364 Mdot
.59428 .76342 Mdot
.26879 .70815 Mdot
.718 .59336 Mdot
.82594 .44918 Mdot
.59352 .20696 Mdot
.39161 .48152 Mdot
.28778 .61106 Mdot
.34156 .23359 Mdot
.17846 .46939 Mdot
.80167 .56645 Mdot
.52643 .63093 Mdot
.20935 .56129 Mdot
.53697 .54922 Mdot
.79109 .65567 Mdot
.26265 .66096 Mdot
.31354 .69482 Mdot
.4439 .36305 Mdot
.52058 .74072 Mdot
.58966 .69985 Mdot
.24053 .46316 Mdot
.58557 .50864 Mdot
.56374 .14893 Mdot
.65438 .66711 Mdot
.78728 .28718 Mdot
.64137 .4173 Mdot
.5393 .18014 Mdot
.22301 .40765 Mdot
.52118 .46128 Mdot
.59225 .51483 Mdot
.74864 .55794 Mdot
.74101 .47521 Mdot
.30304 .75834 Mdot
.26635 .28397 Mdot
.4951 .40372 Mdot
.21972 .6047 Mdot
.19144 .59312 Mdot
.62417 .75089 Mdot
.48004 .6061 Mdot
.24952 .6719 Mdot
.46932 .4176 Mdot
.31915 .27915 Mdot
.48411 .84883 Mdot
.75497 .59235 Mdot
.4032 .64746 Mdot
.26694 .5684 Mdot
.77663 .63401 Mdot
.67656 .76609 Mdot
.43972 .18349 Mdot
.73621 .63286 Mdot
.69173 .41839 Mdot
.49051 .47759 Mdot
.68659 .72169 Mdot
.21867 .54558 Mdot
.66494 .52439 Mdot
.2625 .6138 Mdot
.69577 .20102 Mdot
.81015 .44282 Mdot
.80572 .42469 Mdot
.23316 .572 Mdot
.57447 .59927 Mdot
.77417 .43063 Mdot
.29153 .6424 Mdot
.75961 .57815 Mdot
.30638 .74775 Mdot
.27314 .62316 Mdot
.28149 .24089 Mdot
.35276 .73454 Mdot
.52312 .3771 Mdot
.59645 .69725 Mdot
.36429 .73366 Mdot
.68944 .40766 Mdot
.30958 .50738 Mdot
.69374 .58543 Mdot
.64275 .4035 Mdot
.71662 .57491 Mdot
.69394 .53852 Mdot
.32369 .71014 Mdot
.53996 .75814 Mdot
.71775 .62313 Mdot
.58148 .78465 Mdot
.64336 .5769 Mdot
.35843 .25959 Mdot
.51403 .28073 Mdot
.68848 .59114 Mdot
.46336 .33995 Mdot
.46648 .51574 Mdot
.57865 .47601 Mdot
.36034 .46625 Mdot
.75207 .28532 Mdot
.29495 .39237 Mdot
.59675 .59252 Mdot
.57234 .17336 Mdot
.65643 .63438 Mdot
.84075 .40125 Mdot
.31848 .26515 Mdot
.54968 .68514 Mdot
.34762 .30694 Mdot
.33806 .35048 Mdot
.42406 .15268 Mdot
.63719 .69794 Mdot
.44396 .3462 Mdot
.61103 .57437 Mdot
.57529 .61086 Mdot
.67904 .32725 Mdot
.48521 .29347 Mdot
.42551 .67611 Mdot
.72512 .39356 Mdot
.41964 .4808 Mdot
.60864 .58125 Mdot
.54238 .39107 Mdot
.29968 .58233 Mdot
.83621 .57496 Mdot
.47685 .3473 Mdot
.64588 .18436 Mdot
.36918 .62099 Mdot
.49336 .79933 Mdot
.53763 .85579 Mdot
.46478 .17922 Mdot
.50899 .25879 Mdot
.15928 .53378 Mdot
.37533 .6212 Mdot
.72098 .62991 Mdot
.62211 .63892 Mdot
.30238 .68804 Mdot
.30161 .42275 Mdot
.23213 .52061 Mdot
.62914 .41604 Mdot
.39755 .23223 Mdot
.63768 .27194 Mdot
.58449 .59145 Mdot
.75333 .61214 Mdot
.37621 .76815 Mdot
.69927 .49839 Mdot
.47663 .42572 Mdot
.62121 .74929 Mdot
.53277 .75695 Mdot
.61131 .581 Mdot
.82345 .46879 Mdot
.28004 .67916 Mdot
.76853 .70154 Mdot
.33765 .59924 Mdot
.43135 .32372 Mdot
.74512 .4277 Mdot
.7308 .57793 Mdot
.48252 .65972 Mdot
.55364 .8499 Mdot
.26344 .53139 Mdot
.74561 .41076 Mdot
.28398 .58449 Mdot
.3786 .5087 Mdot
.55421 .48789 Mdot
.57156 .24456 Mdot
.33842 .20371 Mdot
.39731 .66477 Mdot
.47325 .19579 Mdot
.52829 .62148 Mdot
.70417 .33156 Mdot
.67084 .64722 Mdot
.55204 .33931 Mdot
.53412 .73898 Mdot
.52246 .25153 Mdot
.78141 .6738 Mdot
.55 .85059 Mdot
.70313 .41443 Mdot
.67237 .33491 Mdot
.65362 .5702 Mdot
.35577 .62005 Mdot
.62191 .52239 Mdot
.42958 .53994 Mdot
.66331 .67431 Mdot
.4907 .17191 Mdot
.75297 .57391 Mdot
.40238 .51203 Mdot
.78283 .65882 Mdot
.74818 .71606 Mdot
.84924 .52388 Mdot
.19439 .55672 Mdot
.61227 .65934 Mdot
.82333 .40074 Mdot
.4531 .68371 Mdot
.62502 .80353 Mdot
.79454 .57581 Mdot
.41166 .86059 Mdot
.63627 .72684 Mdot
.67568 .56264 Mdot
.27456 .28271 Mdot
.72763 .4992 Mdot
.45211 .84133 Mdot
.48019 .45602 Mdot
.59233 .2979 Mdot
.45262 .8456 Mdot
.33641 .17639 Mdot
.51291 .62914 Mdot
.68279 .53602 Mdot
.52373 .53358 Mdot
.69129 .5909 Mdot
.41344 .30255 Mdot
.37549 .55497 Mdot
.66465 .35882 Mdot
.44024 .23869 Mdot
.27039 .59983 Mdot
.30758 .55359 Mdot
.41152 .30518 Mdot
.31445 .47735 Mdot
.29001 .57938 Mdot
.25533 .65544 Mdot
.62579 .73792 Mdot
.43824 .67407 Mdot
.35743 .6104 Mdot
.66877 .65685 Mdot
.32929 .44142 Mdot
.54088 .28037 Mdot
.40468 .54293 Mdot
.52256 .25599 Mdot
.71982 .48995 Mdot
.82137 .35433 Mdot
.56738 .32715 Mdot
.3888 .8034 Mdot
.65329 .66232 Mdot
.73557 .55467 Mdot
.57702 .79508 Mdot
.52207 .19836 Mdot
.40641 .34362 Mdot
.30881 .64152 Mdot
.76141 .6728 Mdot
.70678 .28939 Mdot
.33316 .74559 Mdot
.75374 .32009 Mdot
.6656 .39941 Mdot
.454 .65436 Mdot
.5125 .51897 Mdot
.57319 .21713 Mdot
.55531 .60943 Mdot
.68014 .56409 Mdot
.4355 .37764 Mdot
.6833 .26547 Mdot
.39593 .82034 Mdot
.36606 .76534 Mdot
.62223 .70214 Mdot
.73994 .68295 Mdot
.50114 .3092 Mdot
.28737 .68755 Mdot
.64253 .52938 Mdot
.41518 .34732 Mdot
.75014 .35638 Mdot
.82163 .61769 Mdot
.61613 .52121 Mdot
.25681 .48538 Mdot
.45791 .59655 Mdot
.46721 .69793 Mdot
.75551 .56376 Mdot
.3449 .38692 Mdot
.6345 .28779 Mdot
.59456 .60314 Mdot
.61193 .27077 Mdot
.39711 .41257 Mdot
.29636 .52271 Mdot
.62475 .5788 Mdot
.333 .67587 Mdot
.27656 .41994 Mdot
.70874 .38467 Mdot
.47286 .56545 Mdot
.24487 .49388 Mdot
.19268 .54373 Mdot
.47325 .64726 Mdot
.72404 .66232 Mdot
.61055 .75115 Mdot
.33091 .75401 Mdot
.7317 .59562 Mdot
.80583 .55676 Mdot
.74352 .4782 Mdot
.55343 .73684 Mdot
.52373 .22952 Mdot
.44103 .53988 Mdot
.55379 .34171 Mdot
.63789 .60551 Mdot
.6627 .73234 Mdot
.54308 .77589 Mdot
.24743 .46805 Mdot
.53759 .44845 Mdot
.55892 .80232 Mdot
.5245 .43754 Mdot
.5203 .85155 Mdot
.72951 .49933 Mdot
.26674 .54555 Mdot
.67064 .47685 Mdot
.22421 .41566 Mdot
.36146 .22353 Mdot
.72917 .72351 Mdot
.32296 .24966 Mdot
.55291 .5191 Mdot
.47762 .19103 Mdot
.79215 .47742 Mdot
.46629 .85253 Mdot
.27509 .54973 Mdot
.61938 .51865 Mdot
.31213 .55277 Mdot
.70685 .42478 Mdot
.54217 .41526 Mdot
.54377 .34232 Mdot
.42858 .68168 Mdot
.62503 .32667 Mdot
.50116 .24455 Mdot
.33658 .55132 Mdot
.75898 .37764 Mdot
.75121 .67732 Mdot
.31909 .69093 Mdot
.48529 .4398 Mdot
.33135 .28857 Mdot
.29296 .51603 Mdot
.23783 .73644 Mdot
.80476 .3209 Mdot
.45951 .59651 Mdot
.44409 .44409 Mdot
.24605 .51447 Mdot
.49618 .3994 Mdot
.39441 .6834 Mdot
.63731 .74864 Mdot
.65308 .41246 Mdot
.551 .37116 Mdot
.67296 .25494 Mdot
.75553 .55144 Mdot
.26359 .45367 Mdot
.73829 .36818 Mdot
.83208 .36886 Mdot
.27463 .72527 Mdot
.74022 .57771 Mdot
.29253 .79 Mdot
.55686 .23183 Mdot
.54575 .60506 Mdot
.50942 .81522 Mdot
.83557 .53871 Mdot
.24016 .55169 Mdot
.38894 .2548 Mdot
.81197 .51763 Mdot
.26833 .5365 Mdot
.28322 .64111 Mdot
.69889 .33625 Mdot
.61892 .27535 Mdot
.52548 .48035 Mdot
.34005 .35125 Mdot
.77413 .35049 Mdot
.54142 .66878 Mdot
.76181 .6587 Mdot
.44202 .23522 Mdot
.25923 .25742 Mdot
.7552 .70903 Mdot
.32775 .48963 Mdot
.41518 .29201 Mdot
.49606 .81593 Mdot
.20753 .49964 Mdot
.31977 .66633 Mdot
.35326 .24912 Mdot
.50816 .7639 Mdot
.31238 .33752 Mdot
.46295 .21174 Mdot
.28004 .59877 Mdot
.36205 .7289 Mdot
.61266 .51992 Mdot
.59695 .75073 Mdot
.67356 .31437 Mdot
.24099 .57725 Mdot
.53598 .36764 Mdot
.21429 .47777 Mdot
.60177 .76204 Mdot
.5512 .81229 Mdot
.64099 .5428 Mdot
.36236 .1652 Mdot
.80789 .57223 Mdot
.51368 .20152 Mdot
.43814 .5336 Mdot
.79841 .65644 Mdot
.6428 .53716 Mdot
.81478 .53763 Mdot
.35949 .78704 Mdot
.54084 .31219 Mdot
.73776 .44918 Mdot
.43659 .53848 Mdot
.75839 .63001 Mdot
.56857 .72023 Mdot
.37285 .74062 Mdot
.40859 .2382 Mdot
.24785 .554 Mdot
.42535 .27272 Mdot
.22983 .46169 Mdot
.43901 .65096 Mdot
.634 .59845 Mdot
.84225 .4271 Mdot
.55704 .52798 Mdot
.46238 .51559 Mdot
.3633 .63736 Mdot
.28809 .26706 Mdot
.21037 .66177 Mdot
.34959 .61609 Mdot
.71991 .30604 Mdot
.27421 .64118 Mdot
.38048 .48933 Mdot
.53468 .64542 Mdot
.08873 .50614 Mdot
.56592 .86313 Mdot
.5751 .6434 Mdot
.35785 .68894 Mdot
.22881 .5909 Mdot
.83565 .55015 Mdot
.36292 .35176 Mdot
.50906 .27277 Mdot
.21542 .34816 Mdot
.20543 .51571 Mdot
.40683 .63006 Mdot
.37819 .80947 Mdot
.71712 .73249 Mdot
.42077 .23145 Mdot
.77635 .66945 Mdot
.49508 .55254 Mdot
.36661 .54455 Mdot
.1299 .60103 Mdot
.68791 .727 Mdot
.46087 .53051 Mdot
.29204 .25992 Mdot
.5508 .61253 Mdot
.42161 .55663 Mdot
.72019 .35625 Mdot
.26089 .64913 Mdot
.28364 .6029 Mdot
.82991 .58151 Mdot
.56349 .60452 Mdot
.51625 .25359 Mdot
.66219 .40945 Mdot
.58907 .5127 Mdot
.34941 .58593 Mdot
.66369 .45594 Mdot
.36892 .48689 Mdot
.67491 .57207 Mdot
.69579 .41393 Mdot
.22228 .62116 Mdot
.46272 .87599 Mdot
.56652 .76324 Mdot
.67872 .38601 Mdot
.32817 .54636 Mdot
.35696 .73723 Mdot
.30671 .47705 Mdot
.44884 .48299 Mdot
.44219 .8489 Mdot
.67761 .82836 Mdot
.59923 .30343 Mdot
.32733 .61584 Mdot
.62167 .57825 Mdot
.45405 .67174 Mdot
.60422 .72521 Mdot
.60981 .4347 Mdot
.49286 .29775 Mdot
.42955 .63763 Mdot
.44245 .65042 Mdot
.63069 .41562 Mdot
.76623 .27193 Mdot
.37643 .5837 Mdot
.52455 .64786 Mdot
.63397 .79473 Mdot
.36144 .25759 Mdot
.46909 .79597 Mdot
.36913 .6044 Mdot
.76933 .42951 Mdot
.62545 .51716 Mdot
.69825 .64682 Mdot
.46264 .24714 Mdot
.80593 .60937 Mdot
.53754 .77759 Mdot
.60645 .69742 Mdot
.38648 .58518 Mdot
.329 .44686 Mdot
.68812 .52678 Mdot
.8169 .50945 Mdot
.51955 .6098 Mdot
.65248 .78906 Mdot
.53777 .31158 Mdot
.63943 .33216 Mdot
.40458 .49048 Mdot
.84488 .48168 Mdot
.44283 .2041 Mdot
.58492 .7119 Mdot
.58152 .1901 Mdot
.62298 .23551 Mdot
.28644 .47675 Mdot
.50987 .37957 Mdot
.38281 .51543 Mdot
.56596 .59811 Mdot
.84552 .38466 Mdot
.8162 .499 Mdot
.5933 .40578 Mdot
.61319 .29038 Mdot
.51546 .69835 Mdot
.61711 .53218 Mdot
.37311 .84877 Mdot
.38487 .36621 Mdot
.82834 .35959 Mdot
.30629 .693 Mdot
.66591 .68891 Mdot
.69468 .5669 Mdot
.50045 .61736 Mdot
.48471 .3592 Mdot
.82744 .56817 Mdot
.45649 .64733 Mdot
.49954 .2188 Mdot
.38971 .62038 Mdot
.63397 .20882 Mdot
.56869 .41987 Mdot
.682 .34325 Mdot
.69197 .36034 Mdot
.37737 .21088 Mdot
.59706 .79852 Mdot
.59673 .47328 Mdot
.32594 .80761 Mdot
.67691 .71156 Mdot
.71599 .72096 Mdot
.40459 .27344 Mdot
.43004 .17557 Mdot
.7743 .58937 Mdot
.71802 .61428 Mdot
.58495 .41458 Mdot
.40552 .45867 Mdot
.5935 .21183 Mdot
.36848 .49091 Mdot
.70746 .51976 Mdot
.70554 .43674 Mdot
.77362 .77127 Mdot
.33502 .49333 Mdot
.53247 .56574 Mdot
.53478 .22085 Mdot
.74107 .69903 Mdot
.36248 .43791 Mdot
.40589 .8341 Mdot
.43268 .43607 Mdot
.36237 .54709 Mdot
.53121 .76761 Mdot
.31236 .68593 Mdot
.62049 .21767 Mdot
.47742 .13642 Mdot
.28107 .72821 Mdot
.62673 .31417 Mdot
.56942 .48792 Mdot
.65113 .64357 Mdot
.61129 .67687 Mdot
.34173 .32425 Mdot
.35551 .80948 Mdot
.67446 .56486 Mdot
.68669 .72248 Mdot
.40675 .16118 Mdot
.32143 .72308 Mdot
.83755 .55208 Mdot
.79014 .54405 Mdot
.66019 .66689 Mdot
.32825 .47807 Mdot
.25754 .39633 Mdot
.66519 .36153 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`2nooooo`;o0000ROooool001cooooo00?o0000ooooooooool0Uoooool2o`0002Gooooo0_l0
0029ooooo`007?ooool00ol0003oooooooooo`2Gooooo`;o0000/?ooool001cooooo00?o0000oooo
ooooool0Voooool2o`0000gooooo0_l0002Mooooo`007?ooool00ol0003oooooooooo`2Kooooo`;o
00003Oooool2o`0000;ooooo0_l0002Iooooo`007?ooool00ol0003oooooooooo`2^ooooo`;o0000
0oooool2o`0009Cooooo000Looooo`;o0000Qoooool2o`0002[ooooo0ol0002Dooooo`007?ooool0
0ol0003oooooooooo`26ooooo`;o00001?ooool2o`0002Cooooo0_l0002Eooooo`007?ooool00ol0
003oooooooooo`23ooooo`;o00001oooool2o`000;_ooooo000Looooo`03o`000?oooooooooo083o
oooo0_l000000ooooooo0000o`000034ooooo`007?ooool00ol0003oooooooooo`1booooo`;o0000
3?ooool2o`000<Oooooo000Looooo`03o`000?oooooooooo07;ooooo0_l0003Eooooo`007?ooool0
0ol0003oooooooooo`2Looooo`;o0000Zoooool001cooooo00?o0000ooooooooool0W?ooool2o`00
01Sooooo0_l0002Aooooo`007?ooool00ol0003oooooooooo`1Zooooo`;o00001_ooool2o`0001Co
oooo0_l0000Aooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o00003_ooool2o`0000;o
oooo0_l00007ooooo`;o0000Q?ooool001cooooo00?o0000ooooooooool0J_ooool2o`0000Kooooo
0_l0000Dooooo`;o00001Oooool2o`0000;ooooo0_l00006ooooo`;o000000?oooooo`000?l00000
0_l00004ooooo`;o00000oooool2o`0000gooooo0_l00007ooooo`;o0000Q?ooool001cooooo00?o
0000ooooooooool0Roooool2o`0000;ooooo0_l00002ooooo`;o00003?ooool2o`000003ooooool0
003o000000Gooooo0_l0000Qooooo`;o0000NOooool001cooooo00?o0000ooooooooool0Q?ooool3
o`0000Cooooo0_l0000Dooooo`;o000000Coooooo`000?l0003o00009oooool2o`0007Wooooo000L
ooooo`03o`000?oooooooooo08Cooooo0ol0000;ooooo`;o00004?ooool5o`0000[ooooo0_l00004
ooooo`;o0000S_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol0
0006ooooo`03o`000?oooooooooo07_ooooo0_l0000Eooooo`;o00000oooool2o`0000Gooooo0_l0
0006ooooo`?o00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`;o0000S_oo
ool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A006ooooo`03o`000?oooooooooo05gooooo0_l0000<ooooo`;o00003_ooool2o`00017o
oooo0_l00006ooooo`?o00001Oooool2o`0000Gooooo0_l00002ooooo`Co00000oooool2o`0000co
oooo1?l00002ooooo`;o00004_ooool2o`0006oooooo00000ooooooo410@ooooo`02ooooo`03oa0@
4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`1Mooooo`;o0000
3?ooool2o`0000_ooooo0_l0000;ooooo`;o00000oooool6o`0000;ooooo0_l00002ooooo`;o0000
2?ooool2o`0000?ooooo2?l0000>ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000
o`000003o`0000Kooooo0_l00008ooooo`;o0000Koooool00003ooooool0003ooooo00;ooooo00?o
0000ooooooooool02oooool00onHV9So8B4Qonk^kP06ooooo`?o0000Ioooool2o`0000oooooo0_l0
0009ooooo`Co00000oooool4o`0000Cooooo0_l0000<ooooo`;o000000Coooooo`000?l0003ooooo
1?l000000ooooooo0000o`00000;ooooo`;o000000?oooooo`000?l000001_ooool2o`000003oooo
ool0003o000000Kooooo0_l0000>ooooo`;o0000JOooool00003ooooool0003ooooo00;ooooo00?o
0000ooooooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo06Oooooo0_l0
00000ooooooo0000o`00000Eooooo`Co00000_ooool2o`0000?ooooo1?l00004ooooo`;o00003Ooo
ool2o`0000;ooooo0_l00006ooooo`;o00001?ooool5o`0000Gooooo0_l000000ooooooo0000o`00
000Jooooo`;o0000JOooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool03Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo06;ooooo0_l00006ooooo`;o00005?ooool3
o`0000;ooooo1?l00003ooooo`Co00001?ooool2o`0000Oooooo0_l00008ooooo`;o000000?ooooo
o`000?l000000oooool2o`000004ooooool0003o0000ooooo`Co00001?ooool4o`000003ooooool0
003o000000Kooooo0_l00009ooooo`;o0000L_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
2oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0H_ooool2o`0001;o
oooo0ol00007ooooo`?o00000_ooool2o`0000cooooo0_l00004ooooo`;o00000_ooool2o`0000_o
oooo0_l00002ooooo`Ko00002Oooool2o`0000Oooooo0_l00002ooooo`;o00002Oooool2o`0007;o
oooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006
ooooo`03o`000?oooooooooo06?ooooo0_l00008ooooo`;o00001_ooool4o`0000Gooooo0_l0000C
ooooo`;o00001?ooool2o`000003ooooool0003o000000Kooooo0_l00003ooooo`;o00000oooool6
o`0000?ooooo1?l00002ooooo`;o00000oooool2o`0000;ooooo1Ol0001nooooo`007?ooool00ol0
003oooooooooo`1Sooooo`;o00000oooool2o`0000?ooooo0_l00006ooooo`Co00001Oooool2o`00
013ooooo0_l0000:ooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo0_l00006oooo
o`?o00000_ooool5o`0000Oooooo0_l00002ooooo`Oo00004_ooool2o`0006Sooooo000Looooo`03
o`000?oooooooooo06Sooooo1?l00005ooooo`;o00002?ooool2o`0001?ooooo0_l00004ooooo`;o
00001oooool2o`0000;ooooo1?l00002ooooo`?o00001Oooool2o`0000?ooooo0_l0000>ooooo`;o
00000oooool2o`0000?ooooo0_l00004ooooo`;o00001oooool2o`0006Sooooo000Looooo`03o`00
0?oooooooooo06[ooooo0_l00005ooooo`?o00001oooool2o`0001Wooooo0_l00007ooooo`;o0000
0_ooool4o`0000?ooooo0_l0000:ooooo`Go00004oooool4o`0000Cooooo0_l0001aooooo`007?oo
ool00ol0003oooooooooo`1booooo`;o0000:Oooool2o`0000Cooooo0_l0000Aooooo`Go00004ooo
ool2o`0000Kooooo0_l0001aooooo`007?ooool00ol0003oooooooooo`2Mooooo`;o00001?ooool2
o`000003ooooool0003o000002Kooooo0_l00003ooooo`;o000000?oooooo`000?l00000LOooool0
01cooooo00?o0000ooooooooool0IOooool2o`0000Cooooo0_l0000@ooooo`;o00001_ooool2o`00
01;ooooo0_l0000;ooooo`;o000000?oooooo`000?l000001_ooool3o`0001[ooooo0_l00003oooo
o`;o00000_ooool2o`00073ooooo000Looooo`03o`000?oooooooooo06Gooooo0_l00003ooooo`Co
00002_ooool2o`0000?ooooo0_l00004ooooo`Co00001Oooool2o`0000_ooooo0_l0000=ooooo`?o
00001_ooool3o`0001?ooooo0_l0000:ooooo`;o00000_ooool2o`00073ooooo000Looooo`03o`00
0?oooooooooo06Gooooo0_l00003ooooo`Co00000oooool2o`0000Gooooo0_l00007ooooo`Co0000
1_ooool4o`0001Wooooo0_l0000Mooooo`;o00003?ooool2o`0001oooooo0_l0001Aooooo`007?oo
ool00ol0003oooooooooo`1Hooooo`;o00001?ooool2o`0000Gooooo0_l00006ooooo`;o00000_oo
ool2o`0000kooooo0_l00002ooooo`?o00000oooool4o`0000;ooooo0_l0000Eooooo`;o00001?oo
ool2o`000003ooooool0003o000000[ooooo0_l00003ooooo`;o00004Oooool4o`000003ooooool0
003o000000;o00006?ooool2o`00057ooooo000Looooo`03o`000?oooooooooo05Sooooo0_l00000
1?oooooo0000o`000?ooool2o`0000[ooooo0_l000000ooooooo0000o`000003ooooo`Co00000ooo
ool2o`000003ooooool0003o000000Oooooo0ol00004ooooo`;o00000oooool2o`0000;ooooo0_l0
0008ooooo`;o00001oooool3o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`;o00001Ooo
ool2o`0000?ooooo0_l0000Aooooo`Co000000?oooooo`000?l000000_l0001[ooooo`007?ooool0
0ol0003oooooooooo`1Kooooo`;o00001Oooool2o`0000Kooooo0_l00003ooooo`;o000000?ooooo
o`000?l000000_l00003ooooo`;o000000?oooooo`000?l000005?ooool5o`0000Sooooo0_l00006
ooooo`Co00002oooool2o`0000[ooooo0ol0000Aooooo`;o00001?ooool4o`0006Wooooo000Loooo
o`;o0000DOooool2o`0000Gooooo0_l00009ooooo`;o000000?oooooo`000?l000002?ooool2o`00
01Sooooo0_l00007ooooo`?o000000?oooooo`000?l000001?ooool2o`0000Sooooo1_l0000Goooo
o`;o00002oooool2o`0000[ooooo1?l0001Yooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o
00001Oooool2o`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l000003_ooool2o`0000Co
oooo0ol00003ooooo`?o00001Oooool2o`0000;ooooo0_l00007ooooo`;o00001?ooool2o`0000;o
oooo0_l00002ooooo`Co000000?oooooo`000?l000000ol00006ooooo`;o00006Oooool3o`0000?o
oooo1Ol0001_ooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00002_ooool2o`0000Oooooo
0_l00005ooooo`;o00001?ooool2o`000003ooooool0003o000000Cooooo0ol00003ooooo`?o0000
2Oooool2o`0000Cooooo0_l0000;ooooo`?o000000?oooooo`000?l000000_l000001?oooooo0000
o`000?ooool2o`0000Kooooo0ol0000<ooooo`;o00002_ooool2o`0000?ooooo1_l0001_ooooo`00
7?ooool00ol0003oooooooooo`1@ooooo`;o00002Oooool2o`0000;ooooo0_l0000;ooooo`;o0000
0_ooool4o`0000oooooo0_l00003ooooo`?o000000?oooooo`000?l000000ol000001?oooooo0000
o`000?l00009ooooo`;o000000?oooooo`000?l000001Ol0000=ooooo`Ko00002?ooool2o`0000ko
oooo1Ol0001aooooo`007?ooool00ol0003oooooooooo`1Kooooo`;o00000_ooool2o`0000Oooooo
0_l00006ooooo`?o00004?ooool4o`000003ooooool0003o000000Oo000000?oooooo`000?l00000
2_ooool2o`0000;ooooo0ol0000Aooooo`Go00006?ooool3o`0000Sooooo0_l0000Booooo`;o0000
EOooool001cooooo00?o0000ooooooooool0F_ooool2o`0000Sooooo0_l00002ooooo`;o00002?oo
ool2o`0000_ooooo0_l000001?oooooo0000o`000?ooool4o`0000;ooooo1?l000000ooooooo0000
o`000002o`0001Cooooo0ol0000;ooooo`?o00005oooool2o`0000Sooooo0_l000001?oooooo0000
o`000?l00002ooooo`;o00003?ooool4o`0005Gooooo000Looooo`03o`000?oooooooooo05[ooooo
0_l00008ooooo`;o00003?ooool2o`0000;ooooo0_l00007ooooo`;o000000Goooooo`000?l0003o
0000ooooo`04o`0000Kooooo2Ol00002ooooo`;o00002oooool3o`0000?ooooo0_l00003ooooo`;o
00003_ooool2o`0000_ooooo0_l00006ooooo`Co000000?oooooo`000?l000000oooool2o`0000co
oooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`1eooooo`?o00001oooool6o`000003oooo
ool0003o000000;o00001Oooool2o`0000?ooooo1Ol00002ooooo`;o00001Oooool2o`0000[ooooo
0_l00003ooooo`;o00003_ooool2o`0000Kooooo0_l000000ooooooo0000o`000008ooooo`;o0000
1Oooool2o`0001Cooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`1Gooooo`Go00000ooo
ool2o`0000Sooooo0_l00007ooooo`;o000000?oooooo`000?l000002?ooool3o`0000Cooooo0_l0
0007ooooo`;o00002oooool2o`0000Cooooo0_l0000:ooooo`?o00001?ooool2o`0000kooooo0_l0
0004ooooo`;o000000?oooooo`000?l000003oooool2o`0000?ooooo0_l0000?ooooo`;o0000D_oo
ool001cooooo00?o0000ooooooooool0Eoooool5o`0000?ooooo0_l00003ooooo`;o00000oooool2
o`0000Oooooo0_l00009ooooo`;o00003oooool2o`0000[ooooo1?l0000@ooooo`?o00001?ooool2
o`0000Kooooo0_l00006ooooo`;o00000_ooool2o`0001Wooooo0_l00009ooooo`Co0000E_ooool0
01cooooo00?o0000ooooooooool0EOooool2o`0000Sooooo0_l00003ooooo`?o00002oooool2o`00
00Wooooo0_l00006ooooo`;o00001oooool2o`0000Cooooo0_l00004ooooo`Go00001?ooool2o`00
00Oooooo0_l0000?ooooo`;o00002_ooool2o`0002Cooooo1?l0001Fooooo`007?ooool00ol0003o
ooooooooo`1Cooooo`Co00002?ooool2o`0000;ooooo1?l0000Fooooo`;o00001_ooool2o`0000Oo
oooo0ol00003ooooo`;o00001?ooool6o`0000?ooooo0_l00007ooooo`;o00000_ooool2o`00013o
oooo1Ol0000;ooooo`;o00001_ooool2o`0001Cooooo0_l000000ooooooo0000o`00001Dooooo`00
7?ooool00ol0003oooooooooo`1Cooooo`;o00002Oooool2o`0000?ooooo0_l00003ooooo`;o0000
3?ooool2o`0001Gooooo1_l00008ooooo`Go00004?ooool2o`0000_ooooo0ol00002ooooo`Go0000
0oooool2o`0000Kooooo0_l00006ooooo`;o00001_ooool2o`0000cooooo0_l000000ooooooo0000
o`000007ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0G_ooool2o`0000Sooooo0_l0
000<ooooo`;o00002oooool2o`0000Oooooo0ol00002ooooo`;o00002?ooool6o`0000Oooooo0_l0
0008ooooo`;o000000?oooooo`000?l000001_ooool3o`0000;ooooo0ol00005ooooo`;o00004Ooo
ool2o`0000?ooooo1?l0000Fooooo`;o0000Boooool001cooooo00?o0000ooooooooool0N_ooool3
o`0000Kooooo0_l00006ooooo`?o00000oooool2o`0000Kooooo2?l00007ooooo`;o00002?ooool6
o`0000[ooooo0ol00007ooooo`Co00001?ooool2o`000003ooooool0003o000000Cooooo0_l00000
0ooooooo0000o`000004o`0000oooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`1Boooo
o`;o00003?ooool2o`0000Wooooo0_l0000<ooooo`Co00003_ooool2o`0000_ooooo2Ol0000Boooo
o`;o000000?oooooo`000?l000001Oooool2o`0000?ooooo0_l00008ooooo`Co00001?ooool2o`00
0003ooooool0003o000000Oooooo0ol0000Booooo`;o0000D_ooool001cooooo0_l0001Cooooo`;o
00003?ooool2o`0000;ooooo0_l00005ooooo`;o00003?ooool2o`0000Cooooo0_l0000;ooooo`;o
00001oooool<o`0000Oooooo0_l00003ooooo`;o00001_ooool2o`0000Kooooo0ol00008ooooo`;o
00000oooool6o`0000kooooo0_l00003ooooo`;o0000HOooool001cooooo00?o0000ooooooooool0
B_ooool2o`0000oooooo0_l00007ooooo`?o00001?ooool2o`00013ooooo1?l00002ooooo`;o0000
1oooool2o`0000Kooooo3ol00005ooooo`;o00000oooool3o`0000Gooooo0_l00007ooooo`?o0000
1oooool2o`0000Gooooo1?l00008ooooo`;o00001?ooool2o`0000?ooooo0_l00002ooooo`;o0000
GOooool001cooooo00?o0000ooooooooool0B_ooool2o`0000oooooo0_l00007ooooo`?o00001_oo
ool2o`0000Wooooo0_l00003ooooo`;o00000oooool3o`0000gooooo4Ol0000;ooooo`;o00001_oo
ool2o`0000Oooooo0_l0000@ooooo`Co00001_ooool3o`0000Sooooo0_l00002ooooo`;o00002_oo
ool2o`00057ooooo000Looooo`03o`000?oooooooooo05Sooooo0_l00006ooooo`;o00002oooool2
o`0000Wooooo0_l00008ooooo`Co00001oooool2o`0000?ooooo4ol0000Aooooo`;o00003oooool2
o`0000Sooooo1?l000000ooooooo0000o`000004ooooo`;o00001_ooool6o`0000cooooo0_l0001A
ooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o00003?ooool2o`0000Kooooo0_l00008oooo
o`;o00002oooool2o`0000Gooooo0_l00004ooooo`;o00001oooool2o`0000?ooooo4ol00006oooo
o`?o00004oooool2o`0000Cooooo0_l00008ooooo`?o00000_ooool2o`0000_ooooo0ol00002oooo
o`;o0000Goooool001cooooo00?o0000ooooooooool0B_ooool2o`0001kooooo0_l0000;ooooo`;o
00001Oooool2o`0001;ooooo4Ol00008ooooo`?o00004oooool2o`0000;ooooo0_l000000ooooooo
0000o`000007ooooo`;o000000Coooooo`000?l0003ooooo0_l0000:ooooo`;o00003?ooool2o`00
05Kooooo000Looooo`03o`000?oooooooooo07cooooo0_l00009ooooo`;o00002Oooool2o`000003
ooooool0003o000000co00000oooool2o`0000Sooooo0_l0000Cooooo`;o000000?oooooo`000?l0
00002_ooool2o`000003ooooool0003o000000kooooo0_l00005ooooo`;o000000?oooooo`000?l0
00003_ooool2o`0004Kooooo000Looooo`03o`000?oooooooooo07cooooo0_l00002ooooo`;o0000
1Oooool2o`0000Wooooo4?l000000ooooooo0000o`000004o`0000Oooooo0_l0000Gooooo`;o0000
7?ooool6o`000003ooooool0003o000000?o00001oooool2o`0000Gooooo1?l00014ooooo`007?oo
ool00ol0003oooooooooo`13ooooo`;o00002?ooool2o`0000Sooooo0_l0000Booooo`;o00002?oo
ool2o`0000Wooooo0_l00006ooooo`;o00002?oooolDo`000003ooooool0003o0000023ooooo0_l0
00001?oooooo0000o`000?ooool3o`0000Oooooo0_l0000>ooooo`Co00000_ooool2o`0000Sooooo
0ol00006ooooo`?o0000A?ooool001cooooo00?o0000ooooooooool0@oooool3o`0000Oooooo0_l0
0005ooooo`;o000000?oooooo`000?l000004_ooool2o`0000Gooooo0_l000000ooooooo0000o`00
000Aooooo`;o00001oooool<o`000003ooooool0003o000000Ko00003oooool2o`00013ooooo0_l0
0003ooooo`;o000000Coooooo`000?l0003o00001oooool3o`00013ooooo0_l00003ooooo`;o0000
1_ooool2o`0000Oooooo0ol00014ooooo`007?ooool00ol0003oooooooooo`13ooooo`?o00003_oo
ool2o`0001Kooooo0_l00004ooooo`;o00004?ooool2o`0000Kooooo0_l00003ooooo`co000000?o
ooooo`000?l000001ol0000>ooooo`;o00004?ooool2o`0000?ooooo0_l0000;ooooo`?o00001Ooo
ool2o`0000?ooooo0_l00004ooooo`;o00000oooool2o`0000oooooo0ol00014ooooo`007?ooool0
0ol0003oooooooooo`10ooooo`;o000000?oooooo`000?l000003oooool2o`0001Kooooo0_l0000F
ooooo`;o00001_ooool2o`000003ooooool0003o000001Ko00003_ooool2o`0001Gooooo0_l00006
ooooo`;o000000?oooooo`000?l000000ol00005ooooo`;o00000oooool2o`0000Cooooo0_l00003
ooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0@?ooool2o`00023ooooo0_l0000Woooo
o`;o00000_oooolAo`000005ooooool0003o0000o`000?ooool00_l0000]ooooo`;o000000Cooooo
o`000?l0003ooooo0_l00003ooooo`Go00003Oooool2o`0005Kooooo000Looooo`03o`000?oooooo
oooo06;ooooo0_l0000Wooooo`?o00000_ooool@o`000003ooooool0003o000000Go00002?ooool2
o`0000cooooo0_l0000Kooooo`;o00000_ooool5o`0000;ooooo0_l00007ooooo`;o00002oooool2
o`0000Oooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`20ooooo`;o00002_ooool2o`00
00;ooooo6?l00005ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Kooooo0_l0000<oooo
o`;o000000?oooooo`000?l000000_ooool2o`0000Gooooo0ol00009ooooo`;o00001oooool3o`00
00[ooooo0_l00007ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0<Oooool2o`0002Co
oooo0_l0000Gooooo`;o00003_ooool2o`000003ooooool0003o000000Oooooo0_l00002oooooaSo
00001Oooool2o`0000Oooooo0_l00003ooooo`;o00003oooool5o`0000;ooooo0ol00004ooooo`;o
00005?ooool3o`0000?ooooo0ol0001@ooooo`007?ooool2o`0003;ooooo0_l0000?ooooo`;o0000
4oooool2o`00017ooooo0_l00004ooooo`;o00003_ooool2o`000003ooooool0003o000000Gooooo
1?l00003oooooa3o000000?oooooo`000?l000000ol000000ooooooo0000o`000008ooooo`;o0000
1oooool2o`00017ooooo0_l00004ooooo`;o00000_ooool2o`0000?ooooo0_l0000Booooo`;o0000
0oooool4o`0004oooooo000Looooo`03o`000?oooooooooo03Wooooo0_l00007ooooo`;o00008Ooo
ool2o`0000?ooooo0ol00005ooooo`;o00003?ooool2o`0000Sooooo0_l00005oooooaKo000000?o
ooooo`000?l000002?ooool2o`0000gooooo0_l000000ooooooo0000o`00000Booooo`;o00000ooo
ool2o`0000Oooooo0_l00005ooooo`;o00002Oooool2o`0004oooooo000Looooo`03o`000?oooooo
oooo03Wooooo0_l0000Wooooo`;o000000?oooooo`000?l000001?ooool2o`0000Gooooo0_l0000O
oooooaCo00005Oooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0000Cooooo1?l0
0007ooooo`?o00001_ooool2o`000003ooooool0003o000000;o00001Oooool5o`0001Gooooo0_l0
0004ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0@Oooool2o`0001oooooo0_l0000]
ooooo`?o000000Coooooo`000?l0003ooooo3ol00002ooooo`;o00004Oooool2o`0000Wooooo0_l0
0003ooooo`Go00000oooool7o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`00
0002o`0000Kooooo1Ol0000Dooooo`Co00000_ooool2o`0003[ooooo000Looooo`03o`000?oooooo
oooo02oooooo0_l0000?ooooo`?o0000:Oooool2o`0000_ooooo0_l00007ooooo`;o00002?ooool2
o`0000?ooooo5Ol00003ooooo`;o00003oooool2o`000003ooooool0003o000000_ooooo1_l00002
ooooo`Oo00000oooool5o`0000[ooooo0_l00003ooooo`?o00005_ooool2o`0003kooooo000Loooo
o`03o`000?oooooooooo02oooooo0_l0000;ooooo`;o00000_ooool2o`0002[ooooo0_l0000;oooo
o`;o00001oooool2o`0000Sooooo0_l00004oooooaCo00005?ooool2o`000003ooooool0003o0000
00_ooooo0ol000000ooooooo0000o`000006o`000003ooooool0003o000000;ooooo1_l00002oooo
o`;o00001_ooool2o`0000Kooooo0_l0000Pooooo`;o0000<_ooool001cooooo00?o0000oooooooo
ool0??ooool4o`0003Wooooo0_l0000GoooooaCo00001?ooool2o`0001kooooo1Ol000001?oooooo
0000o`000?l00006ooooo`So00000_ooool2o`0000Oooooo0_l00005ooooo`;o00000oooool2o`00
013ooooo0_l00009ooooo`;o0000<_ooool001cooooo00?o0000ooooooooool0?_ooool2o`0001oo
oooo1?l0000/ooooo`;o000000?oooooo`000?l000004_l00003ooooo`?o00000oooool2o`0001?o
oooo0_l00002ooooo`Oo000000?oooooo`000?l000001oooool2o`000003ooooool0003o000000?o
00002oooool2o`0000[ooooo0_l0000@ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0
>oooool2o`0001kooooo0_l00002ooooo`Co000000?oooooo`000?l00000:Oooool2o`0000Cooooo
4Ol00003ooooo`?o00000oooool4o`0000kooooo0_l000000ooooooo0000o`000008o`00013ooooo
0ol00003ooooo`;o00003?ooool2o`0000_ooooo0_l00018ooooo`007?ooool00ol0003ooooooooo
o`0jooooo`?o00007_ooool4o`0000?ooooo1?l0000Tooooo`?o00001oooool@o`0000;ooooo1?l0
00000ooooooo0000o`000004ooooo`;o00001Oooool4o`000003ooooool0003o000000;ooooo1ol0
000Fooooo`?o00000oooool2o`0000cooooo0ol0000:ooooo`;o0000B?ooool001cooooo00?o0000
ooooooooool0>_ooool2o`0001Gooooo0_l0000:ooooo`Co000000?oooooo`000?l000000_ooool2
o`0001;ooooo0_l0000>ooooo`?o00001oooool<o`000004ooooool0003o0000o`0000;ooooo1?l0
00000ooooooo0000o`00000;ooooo`Co000000?oooooo`000?l000001ol0000Hooooo`;o00003_oo
ool2o`0000;ooooo0ol0000Eooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0>oooool2
o`0001Cooooo0ol00007ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000;ooooo0_l0
000Booooo`;o00006?ooool=o`000004ooooool0003o0000o`0000oooooo0_l00008ooooo`Go0000
1_ooool2o`0000Kooooo0_l00006ooooo`;o00001oooool3o`0000Wooooo0_l00002ooooo`;o0000
00?oooooo`000?l000001Oooool2o`0000cooooo0_l00003ooooo`;o0000>?ooool001cooooo00?o
0000ooooooooool0<_ooool2o`0000Oooooo0_l00006ooooo`;o00003Oooool2o`0000;ooooo0_l0
0002ooooo`Ko00000_ooool2o`0000Sooooo0_l0000=ooooo`;o00006?ooool7o`000003ooooool0
003o000000?o000000?oooooo`000?l000003oooool2o`0000Sooooo1?l00007ooooo`;o00001_oo
ool2o`0000Kooooo0_l000000ooooooo0000o`000004ooooo`?o00004?ooool2o`0000Gooooo0ol0
000@ooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0<_ooool2o`0000oooooo0_l00009
ooooo`Go000000?oooooo`000?l000000_l00002ooooo`ko00001?ooool2o`0000gooooo0ol0000G
ooooo`go00003?ooool2o`0000[ooooo1?l00005ooooo`;o00002oooool2o`0000Oooooo0_l00000
0ooooooo0000o`00000Aooooo`;o00002?ooool2o`0000;ooooo0_l0001:ooooo`0000Koooooonk^
k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool0C_ooool9o`000003ooooool0003o0000017o00004Oooool2o`0000Wooooo0_l0
000=ooooo`_o00002oooool4o`0000Wooooo1Ol00005ooooo`;o00000oooool2o`0000Kooooo0_l0
0002ooooo`;o000000?oooooo`000?l000002_ooool2o`0000?ooooo0_l00004ooooo`?o00001_oo
ool4o`000003ooooool0003o000000;ooooo0_l0000;ooooo`;o0000>_ooool00006oooooomgMgOo
V9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0dooooo`;o00006Oooool5o`000004ooooool0003o0000oooooa?o00007?ooool2o`0000_o
oooo0_l000000ooooooo0000o`000009o`0000[ooooo0_l00008ooooo`;o000000?oooooo`000?l0
00001?ooool2o`0000Oooooo0_l0000:ooooo`Go00002_ooool2o`0000?ooooo0_l00003ooooo`Co
00000oooool2o`000004ooooool0003o0000o`0000;ooooo0_l00002ooooo`;o00002oooool2o`00
0003ooooool0003o000003Oooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wo
oooo1Ol00006ooooo`03o`000?oooooooooo03Cooooo0_l0000Jooooo`;o00001_oooolCo`000003
ooooool0003o0000013ooooo0_l000000ooooooo0000o`00000<ooooo`;o00000oooool2o`000003
ooooool0003o000000_o00003Oooool2o`0000;ooooo1_l00004ooooo`;o00001Oooool5o`000003
ooooool0003o000000co000000?oooooo`000?l000001_ooool2o`0000Sooooo0ol00004ooooo`;o
000000Coooooo`000?l0003o00005_ooool2o`0003Oooooo00000ooooooo0000ooooo`02ooooo`03
o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`0003gooooo0_l0000Eoooo
o`;o000000?oooooo`000?l000005_l0000?ooooo`;o000000?oooooo`000?l000003?ooool2o`00
0003ooooool0003o000000?ooooo3ol00004ooooo`;o00001Oooool9o`000004ooooool0003o0000
o`0000Sooooo0_l000000ooooooo0000o`00000?o`000003ooooool0003o000000;o000000?ooooo
o`000?l000000oooool2o`0000Oooooo0_l0000<ooooo`;o00002_ooool2o`0000?ooooo0_l0000j
ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGooooo
o`0000Oooooo00?o0000ooooooooool0<Oooool2o`0000[ooooo0_l0000Eooooo`;o000000?ooooo
o`000?l000006?l0000@ooooo`;o00003oooool2o`0000Kooooo2Ol000000ooooooo0000o`000003
o`000003ooooool0003o000000Cooooo2?l00003ooooo`Co00002ooooolAo`0000;ooooo0_l00000
0ooooooo0000o`000003ooooo`;o00005Oooool2o`0000[ooooo0_l00003ooooo`;o0000>_ooool0
0003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00omgMgOoc<c<o`000007oooo
o`03o`000?oooooooooo037ooooo0_l0000Booooo`;o000000?oooooo`000?l000000oooool4o`00
00Kooooo5ol000000ooooooo0000o`000004ooooo`;o00002_ooool2o`0000oooooo1?l00003oooo
o`_o000000?oooooo`000?l000000_l00006ooooo`Ko00001oooool3o`0000Gooooo0_l00006oooo
oa;o00000_ooool2o`0000kooooo0_l0000;ooooo`Co0000B?ooool00006oooooomgMgOoV9RHoooo
oonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo04?ooooo1?l00000
0ooooooo0000o`000003ooooo`Co00001_oooolIo`0000Cooooo0ol00004ooooo`Co000000?ooooo
o`000?l000002?ooool2o`0000Kooooo1?l00003ooooo`;o000000?oooooo`000?l000001_l00000
0ooooooo0000o`000005o`000003ooooool0003o000000?o000000?oooooo`000?l000001oooool3
o`0000Gooooo0_l00006oooooa;o00000_ooool2o`0000cooooo1?l00003ooooo`;o00001_ooool4
o`0000Kooooo0_l00010ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0
003ooooo00Kooooo00?o0000ooooooooool0@oooool4o`0000kooooo4?l000000ooooooo0000o`00
0008o`0000Cooooo0_l00005ooooo`Co000000?oooooo`000?l000002?ooool2o`00017ooooo5?l0
0002ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o00002_oooolGo`000003oooo
ool0003o000000_ooooo0_l00005ooooo`;o00004?ooool2o`0000?ooooo0_l0000kooooo`007?oo
ool00ol0003oooooooooo`15ooooo`Co00003?ooool4o`000003ooooool0003o000000Wo000000?o
ooooo`000?l000001ol0000>ooooo`;o000000?oooooo`000?l000003?ooool2o`0000Gooooo0_l0
0007ooooo`Wo000000?oooooo`000?l000001_l00002ooooo`;o00000oooool2o`000003ooooool0
003o000000;o00002ooooolBo`000003ooooool0003o000000;o000000?oooooo`000?l000003ooo
ool2o`0001Sooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00002_ooool2
o`0000;ooooo0ol0000=oooooaWo00007oooool2o`0000Gooooo0_l0000:ooooo`Co000000?ooooo
o`000?l000001Ol00005ooooo`;o000000?oooooo`000?l000001Oooool2o`0000;ooooo0_l00007
ooooo`Ko000000?oooooo`000?l000003Ol0000Cooooo`Co00000oooool2o`0004kooooo000Loooo
o`03o`000?oooooooooo03Kooooo0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o0000
00;ooooo0_l0000<oooooa_o00005Oooool2o`00013ooooo1?l00008ooooo`;o00000_ooool3o`00
00cooooo0_l00009ooooo`;o00000oooool2o`000003ooooool0003o000001Go00000oooool2o`00
00Gooooo0_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000000oooool2o`00
00Oooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`0kooooo`;o00000_ooool2o`0001?o
oooo0_l000000ooooooo0000o`00000Eo`0001Kooooo0_l0000@ooooo`Co00002?ooool2o`000003
ooooool0003o000000;o00007?oooolKo`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l0
00000_l000000ooooooo0000o`00000?ooooo`;o00002_ooool2o`0003Wooooo000Looooo`03o`00
0?oooooooooo05Oooooo6?l0000=ooooo`;o00006Oooool2o`0000Wooooo0_l000000ooooooo0000
o`000003ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001OoooolIo`0000cooooo
1?l00006ooooo`Go00001?ooool2o`0000Cooooo0_l00007ooooo`;o0000>Oooool001cooooo00?o
0000ooooooooool0BOooool2o`0000cooooo0_l00002oooooaCo00003Oooool2o`0000Kooooo0_l0
00000ooooooo0000o`000005ooooo`;o00003_ooool2o`0000;ooooo0_l00005ooooo`?o00001Ooo
ool2o`0000Kooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000_oo
oolHo`0000gooooo0_l00004ooooo`;o00000_ooool5o`0000Cooooo0_l00004ooooo`;o0000@_oo
ool001cooooo00?o0000ooooooooool08Oooool2o`0000Kooooo0_l0000Kooooo`Go00004?oooolB
o`0001Oooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l0000<ooooo`Co00000_ooool2
o`0000Gooooo0_l0000Aooooo`;o00001?ooool3o`0000;ooooo7?l0000?ooooo`;o00000oooool2
o`00053ooooo000Looooo`03o`000?oooooooooo027ooooo0_l00006ooooo`;o00006Oooool6o`00
0003ooooool0003o000000;o000000Coooooo`000?l0003o00002?oooolBo`0000Gooooo0_l0000B
ooooo`Go00001?ooool2o`0000Wooooo1?l00009ooooo`;o000000?oooooo`000?l000002Oooool2
o`0000[ooooo0ol00002ooooo`oo000000?oooooo`000?l000002ol000000ooooooo0000o`000009
ooooo`;o00001_ooool2o`0000Gooooo0_l00019ooooo`007?ooool00ol0003oooooooooo`0/oooo
o`;o00005_ooool3o`000004ooooool0003o0000ooooo`Co000000?oooooo`000?l000000ol00009
ooooo`oo00001Oooool4o`00013ooooo0_l00007ooooo`;o00002Oooool2o`0000_ooooo0_l00000
0ooooooo0000o`000002o`0000Oooooo0_l0000:ooooo`;o00000ooooolLo`0000;ooooo0_l00000
1?oooooo0000o`000?ooool2o`0000?ooooo0_l00006ooooo`;o00001?ooool5o`000003ooooool0
003o000000gooooo0_l0000eooooo`007?ooool00ol0003oooooooooo`0Wooooo`;o00000oooool2
o`0001Oooooo2_l00003ooooo`?o00000_ooool3o`0000Gooooo3_l00007ooooo`;o00001?ooool2
o`0000_ooooo0ol000000ooooooo0000o`000002o`00017ooooo0_l0000:ooooo`?o00001_ooool4
o`00013ooooo6Ol00005ooooo`Oo00003oooool2o`000004ooooool0003o0000ooooo`;o00003Ooo
ool4o`0003?ooooo000Looooo`03o`000?oooooooooo02Oooooo0_l0000Kooooo`_o00000oooool2
o`0000?ooooo0ol00006ooooo`[o000000?oooooo`000?l000002oooool5o`0000Kooooo0_l00002
ooooo`?o000000?oooooo`000?l000000_l0000Aooooo`;o00002Oooool4o`0000Sooooo0_l0000?
oooooaSo00001Oooool2o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`;o00002oooool2
o`0000Kooooo0_l000001?oooooo0000o`000?l00006ooooo`;o0000<oooool001cooooo0_l0000Y
ooooo`;o00001?ooool2o`0000[ooooo0_l00004ooooo`;o00000_ooool2o`0000;ooooo0_l0000?
ooooo`Co00001?ooool2o`0000Cooooo0_l000000ooooooo0000o`00000<ooooo`;o000000?ooooo
o`000?l000001?ooool4o`0000Cooooo0ol0000Oooooo`;o00006OoooolKo`0000Cooooo0_l00005
ooooo`Co00000oooool2o`0000Kooooo0_l0000;ooooo`;o000000Coooooo`000?l0003o0000>ooo
ool001cooooo00?o0000ooooooooool09Oooool2o`000003ooooool0003o000000Cooooo0_l00005
ooooo`;o00000oooool2o`0000Cooooo0_l0000@ooooo`;o00001Oooool4o`0000?ooooo0_l00008
ooooo`;o00003?ooool2o`0000Oooooo0_l00003ooooo`;o000000Coooooo`000?l0003o00002Ooo
ool2o`0002?ooooo0_l0000:oooooa_o00003Oooool3o`0000Oooooo0_l000000ooooooo0000o`00
000=ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool09Oooool2o`0000kooooo0_l00004
ooooo`;o00004?ooool2o`0000?ooooo0_l0000<ooooo`;o00002_ooool2o`0001;ooooo0ol00003
ooooo`;o00003Oooool2o`000003ooooool0003o0000023ooooo0ol0000=oooooa?o000000?ooooo
o`000?l000000ol0000<ooooo`;o00001oooool2o`00013ooooo0_l0000mooooo`007?ooool00ol0
003oooooooooo`0[ooooo`;o00003?ooool4o`0000[ooooo0_l00004ooooo`;o00001?ooool4o`00
00Kooooo0_l00006ooooo`;o00001Oooool2o`0001;ooooo0ol0000Eooooo`;o00001oooool2o`00
00?ooooo1?l0000<ooooo`Oo00001?ooool2o`0000Cooooo6Ol000000ooooooo0000o`00001Voooo
o`007?ooool00ol0003oooooooooo`0[ooooo`;o00003?ooool2o`0000cooooo0_l000000ooooooo
0000o`000005ooooo`Ko00001_ooool2o`0000Kooooo0_l00002ooooo`;o00001_ooool2o`0001Go
oooo0_l00002ooooo`;o00004oooool2o`0000?ooooo1?l00008ooooo`;o00000_ooool5o`0000Ko
oooo0_l00004oooooaOo00001oooool2o`00017ooooo0_l0000@ooooo`;o0000?Oooool001cooooo
00?o0000ooooooooool0?_ooool2o`0000[ooooo0_l00005ooooo`;o00005?ooool4o`0000?ooooo
0_l000000ooooooo0000o`000003ooooo`;o00003_ooool4o`0000;ooooo0_l0000Hooooo`;o0000
2_ooool2o`0000?ooooo1?l0000>oooooa;o000000?oooooo`000?l000000oooool2o`0000;ooooo
0_l0000Aooooo`Co00001oooool2o`0000Gooooo1?l00002ooooo`;o0000=oooool001cooooo00?o
0000ooooooooool0=_ooool2o`0000;ooooo0_l00002ooooo`Co000000?oooooo`000?l000001ooo
ool3o`0000[ooooo0_l00002ooooo`;o000000?oooooo`000?l000000oooool4o`0000?ooooo1?l0
00000ooooooo0000o`000003ooooo`;o00003_ooool2o`0000Cooooo0_l0000=ooooo`;o00005?oo
ool2o`0000Kooooo0_l0000>ooooo`co000000?oooooo`000?l000000ol00006ooooo`;o00003?oo
ool2o`0000Wooooo0_l00002ooooo`;o00000oooool2o`0000?ooooo0_l00002ooooo`;o00000_oo
ool2o`0003Oooooo000Looooo`03o`000?oooooooooo03Kooooo0ol000000ooooooo0000o`000002
ooooo`Co000000?oooooo`000?l000001oooool3o`0000[ooooo0_l00002ooooo`;o000000?ooooo
o`000?l000000oooool2o`0000Gooooo1?l0000Looooo`;o00003Oooool2o`0000;ooooo0_l0000@
ooooo`;o00002oooool2o`0000_ooooo3_l0000Fooooo`;o00003Oooool2o`0000Sooooo0_l0000o
ooooo`007?ooool00ol0003oooooooooo`0gooooo`?o00001Oooool2o`0001?ooooo0_l00003oooo
o`;o000000?oooooo`000?l000001?l0000<ooooo`;o00000oooool2o`0000oooooo0_l00003oooo
o`;o00005?ooool2o`0001?ooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l00003
ooooo`;o00002_ooool5o`000003ooooool0003o000000;o00005?ooool2o`000003ooooool0003o
000000[ooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00001Oooool2o`00
00Gooooo0_l000000ooooooo0000o`00000:ooooo`;o00001?ooool2o`0000?ooooo2ol00003oooo
o`;o00002_ooool2o`0000oooooo0_l00003ooooo`;o00004Oooool2o`0000Wooooo0_l0000;oooo
o`;o00000_ooool2o`000003ooooool0003o000000Kooooo0_l0000<ooooo`;o00000oooool5o`00
00gooooo0_l00003ooooo`Go00002_ooool3o`0004[ooooo000Looooo`03o`000?oooooooooo037o
oooo1?l00002ooooo`;o00001?ooool2o`0000?ooooo0_l0000:ooooo`;o00002oooool2o`0000Go
oooo0_l00003ooooo`;o00004_ooool2o`0000Sooooo0_l00007ooooo`;o00002_ooool4o`0000Wo
oooo0_l0000<ooooo`;o00001?ooool3o`0001Gooooo0_l000000ooooooo0000o`000003o`0000Go
oooo0_l00006ooooo`;o00000_ooool4o`0000gooooo0_l00004ooooo`;o00002_ooool2o`0000oo
oooo0_l0000Wooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00000_ooool2o`0000Cooooo
1?l000000ooooooo0000o`00000<ooooo`;o0000:Oooool2o`0000Gooooo0_l000001?oooooo0000
o`000?l00004ooooo`Co00002_ooool2o`0000Oooooo0_l00009ooooo`;o00001Oooool2o`0000Go
oooo0ol00004ooooo`;o000000Coooooo`000?l0003o00002_ooool2o`0000_ooooo0_l00002oooo
o`;o00001_ooool2o`0000Kooooo0_l00005ooooo`Co00001?ooool2o`0000[ooooo0ol0000>oooo
o`;o00009oooool001cooooo00?o0000ooooooooool0?oooool2o`0000oooooo0_l0000Rooooo`;o
00000_ooool4o`0000Cooooo1?l00002ooooo`;o00000oooool4o`0000;ooooo0_l0000@ooooo`;o
00002Oooool4o`0000?ooooo0_l00005ooooo`Co00000oooool2o`000003ooooool0003o000000;o
00005_ooool2o`0000;ooooo0_l00008ooooo`;o00001?ooool2o`0000Gooooo1?l0000@ooooo`?o
0000=oooool001cooooo00?o0000ooooooooool0A_ooool2o`0000Wooooo0_l0000Dooooo`;o0000
0_ooool2o`0000Oooooo0_l00002ooooo`Co00001?ooool2o`0000Wooooo1?l00002ooooo`;o0000
2oooool2o`0000Cooooo0_l000000ooooooo0000o`000007ooooo`;o00000oooool2o`0000Kooooo
0ol00008ooooo`;o00007?ooool2o`0000Kooooo0_l0000>ooooo`;o00002_ooool2o`0001?ooooo
0_l0000Xooooo`007?ooool00ol0003oooooooooo`13ooooo`;o000000?oooooo`000?l000001?oo
ool2o`0000?ooooo0_l00002ooooo`;o00004?ooool6o`0000Oooooo0_l0000:ooooo`;o000000?o
ooooo`000?l000005_ooool5o`0000Cooooo0_l000000ooooooo0000o`00000<ooooo`;o00001_oo
ool3o`0000Kooooo0_l000000ooooooo0000o`00000Cooooo`;o00001_ooool2o`0000Cooooo0_l0
0009ooooo`;o00001Oooool2o`0000[ooooo0_l0000Cooooo`;o0000:?ooool001cooooo00?o0000
ooooooooool0=Oooool2o`0000Oooooo0_l00003ooooo`;o00001oooool2o`0000Gooooo1?l0000B
ooooo`;o00000_ooool2o`0000Oooooo0_l0000;ooooo`;o00002oooool2o`0000Wooooo0ol0000G
ooooo`;o00001oooool3o`0000Gooooo0_l000000ooooooo0000o`00000>ooooo`;o00000_ooool4
o`0000Kooooo0_l00003ooooo`;o00002Oooool6o`0000Wooooo0_l00011ooooo`007?ooool2o`00
03Kooooo1?l00003ooooo`Ko00001?ooool2o`000004ooooool0003o0000ooooo`;o00001Oooool2
o`00013ooooo0_l00006ooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o
000000kooooo0_l00002ooooo`Go00000_ooool2o`0000cooooo0_l0000;ooooo`;o00003_ooool2
o`0000_ooooo0_l00007ooooo`;o00000_ooool3o`000003ooooool0003o000000;o00001_ooool4
o`0000kooooo1?l00008ooooo`?o00005oooool2o`0002Sooooo000Looooo`03o`000?oooooooooo
02kooooo0_l00007ooooo`;o00000oooool2o`0000;ooooo0_l00004ooooo`;o000000Coooooo`00
0?l0003ooooo0_l00004ooooo`Oo00003?ooool2o`0000Wooooo1_l00003ooooo`?o00001_ooool2
o`0000Gooooo0_l00002ooooo`?o000000Coooooo`000?l0003ooooo0_l0000<ooooo`;o00002ooo
ool2o`0001_ooooo0_l00007ooooo`;o00000oooool2o`0000gooooo0_l0000@ooooo`;o00002?oo
ool2o`0001Sooooo0_l0000Xooooo`007?ooool00ol0003oooooooooo`0Iooooo`;o00004oooool2
o`0000;ooooo0_l00003ooooo`;o00000oooool3o`0001?ooooo1ol00002ooooo`;o00001?ooool2
o`0000;ooooo0_l0000;ooooo`Co00001?ooool2o`0000Kooooo0_l00002ooooo`;o00001?ooool3
o`000004ooooool0003o0000o`0000;ooooo0_l0000Hooooo`;o0000;Oooool2o`0001cooooo0_l0
001;ooooo`007?ooool00ol0003oooooooooo`0Iooooo`;o00005oooool2o`0000?ooooo0_l00004
ooooo`;o00005oooool2o`0000?ooooo0_l00004ooooo`;o00003?ooool2o`000004ooooool0003o
0000o`0000;ooooo1?l0000;ooooo`Co00000_ooool3o`000003ooooool0003o000000?ooooo0_l0
000?ooooo`;o00001?ooool5o`0000Wooooo0_l00002ooooo`?o00007?ooool3o`00017ooooo0_l0
0009ooooo`;o00001oooool3o`00047ooooo000Looooo`03o`000?oooooooooo037ooooo0_l00003
ooooo`;o00000_ooool2o`0000Sooooo0_l00002ooooo`;o00002Oooool5o`0000?ooooo0_l0000:
ooooo`;o00001Oooool3o`0000;ooooo0_l00002ooooo`Co00001?ooool2o`0000Gooooo1Ol00005
ooooo`;o00002_ooool2o`0000Sooooo0_l00004ooooo`Go00002?ooool8o`0000?ooooo0_l00004
ooooo`;o00000oooool2o`0000cooooo0_l0000Booooo`;o00004_ooool3o`000003ooooool0003o
000003kooooo000Looooo`03o`000?oooooooooo037ooooo0_l00003ooooo`;o00000_ooool2o`00
00?ooooo0_l00002ooooo`?o00000_ooool2o`0000;ooooo0_l00005ooooo`Co00001?ooool2o`00
00[ooooo0_l00005ooooo`;o00002Oooool2o`0000Cooooo0_l00002ooooo`?o000000?oooooo`00
0?l000000_l000000ooooooo0000o`000003o`000003ooooool0003o000000;o00001?ooool4o`00
01Wooooo1?l000000ooooooo0000o`000002o`0000Cooooo0_l000001?oooooo0000o`000?ooool2
o`0000?ooooo0_l0000@ooooo`;o00003_ooool4o`0000Gooooo0_l00004ooooo`;o00000_ooool2
o`0000?ooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0mooooo`Co00000_ooool2o`00
00Oooooo0_l0000<ooooo`?o00006?ooool6o`000004ooooool0003o0000o`0000;ooooo1Ol00000
1Ooooooo0000o`000?l0003ooooo00_o00001?ooool4o`0000Gooooo0_l0000;ooooo`;o00001Ooo
ool2o`0000?ooooo1?l00003ooooo`Ko00001_ooool2o`00013ooooo0ol0000=ooooo`Co00001Ooo
ool2o`0000Cooooo0_l00002ooooo`;o00001oooool2o`0003[ooooo000Looooo`03o`000?oooooo
oooo03gooooo0ol00008ooooo`;o00004?ooool2o`000003ooooool0003o000001;ooooo0_l00002
ooooo`[o00000_ooool3o`0000?ooooo1ol00003ooooo`;o00004?ooool2o`0000_ooooo0_l00002
ooooo`?o00001Oooool2o`0000Gooooo1Ol00007ooooo`Co000000?oooooo`000?l000003?ooool4
o`0000Wooooo0_l0000Aooooo`Co00001Oooool4o`0000;ooooo1?l0000dooooo`007?ooool00ol0
003oooooooooo`0mooooo`;o00002Oooool2o`0000Cooooo0_l0000:ooooo`;o000000?oooooo`00
0?l000000oooool2o`0000Gooooo1?l00004ooooo`;o00000_oooolIo`0000?ooooo0_l00006oooo
o`;o000000?oooooo`000?l000003_ooool2o`0000Kooooo0ol00002ooooo`;o00002?ooool8o`00
00Gooooo0ol000000ooooooo0000o`000006ooooo`;o00000_ooool2o`0000;ooooo0_l00009oooo
o`;o00000oooool2o`0000cooooo0_l00007ooooo`Co000000?oooooo`000?l000000ol0000doooo
o`007?ooool00ol0003oooooooooo`15ooooo`Co00001Oooool3o`0000Oooooo1?l00006ooooo`;o
00001Oooool4o`0000Cooooo1?l00003ooooo`Co000000?oooooo`000?l000005?l00003ooooo`;o
000000?oooooo`000?l000000ol0000>ooooo`;o00000oooool2o`0000Kooooo0_l00003ooooo`;o
00000oooool4o`000004ooooool0003o0000o`0000;ooooo0_l00005ooooo`;o00001_ooool2o`00
00;ooooo0_l0000Booooo`;o00005Oooool4o`000003ooooool0003o000003Oooooo000Looooo`03
o`000?oooooooooo02cooooo0_l00004ooooo`;o00004Oooool4o`0000Kooooo0_l000000ooooooo
0000o`000004ooooo`;o00000oooool2o`0000[ooooo1?l00004ooooo`Ko00000oooool;o`0000;o
oooo2_l000001?oooooo0000o`000?ooool3o`0000?ooooo0_l0000Dooooo`;o00002oooool2o`00
00Gooooo0_l00006ooooo`;o00000oooool2o`0000?ooooo0_l00003ooooo`?o00005Oooool2o`00
00kooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00000_ooool4o`0000Oo
oooo0ol0000Aooooo`;o000000?oooooo`000?l000001?ooool2o`0000?ooooo0_l0000:ooooo`;o
000000?oooooo`000?l000000_ooool4o`000005ooooool0003o0000o`000?ooool03?l00002oooo
o`Ko00001?ooool6o`0000oooooo0_l00006ooooo`;o000000Coooooo`000?l0003o00003?ooool2
o`0000?ooooo0_l0000;ooooo`;o00000oooool2o`0000?ooooo0ol0000Kooooo`;o00002?ooool7
o`0003kooooo000Looooo`03o`000?oooooooooo033ooooo0_l00009ooooo`?o00004Oooool2o`00
0003ooooool0003o000000;o00000_ooool2o`0000;ooooo0_l00006ooooo`;o00000oooool2o`00
0003ooooool0003o000000Ko000000Goooooo`000?l0003o0000ooooo`0Do`0000Cooooo1?l00003
ooooo`;o00003?ooool2o`0000Kooooo0_l000001?oooooo0000o`000?l0000<ooooo`;o00001?oo
ool2o`0000Gooooo0_l000000ooooooo0000o`000008ooooo`;o00000_ooool2o`0000kooooo0_l0
000:ooooo`;o00001?ooool2o`0000?ooooo1_l000000ooooooo0000o`00000kooooo`007?ooool0
0ol0003oooooooooo`0booooo`;o00005oooool2o`0000Gooooo1Ol000000ooooooo0000o`000002
ooooo`[o000000?oooooo`000?l000000_ooool6o`0000?ooooo1ol000000ooooooo0000o`00000A
o`000004ooooool0003o0000o`0000Gooooo0_l0000Iooooo`;o00001_ooool2o`0000Sooooo1Ol0
0003ooooo`;o000000?oooooo`000?l000002?ooool6o`0000kooooo0_l0000@ooooo`;o00000ooo
ool2o`0000Cooooo0ol0000kooooo`007?ooool00ol0003oooooooooo`0`ooooo`Co00001oooool2
o`0000Wooooo0_l00002ooooo`?o00001Oooool2o`000003ooooool0003o000000Oooooo2?l00000
0ooooooo0000o`000002ooooo`Co000000Coooooo`000?l0003ooooo8?l00003ooooo`;o00002Ooo
ool3o`0000oooooo0_l00004ooooo`Co00002?ooool2o`000004ooooool0003o0000ooooo`Ko0000
2oooool2o`0000gooooo0_l000000ooooooo0000o`000002o`0000_ooooo0_l0000<ooooo`;o0000
??ooool001cooooo00?o0000ooooooooool0<?ooool2o`0000Oooooo1?l000000ooooooo0000o`00
0003ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Gooooo1?l0000<ooooo`Co00000_oo
ool2o`0000?ooooo0ol000000ooooooo0000o`00000@o`000003ooooool0003o000000So000000?o
ooooo`000?l000001?l00002ooooo`;o00002?ooool4o`0001Gooooo0_l00003ooooo`;o000000?o
ooooo`000?l000000oooool3o`0000;ooooo1_l0000<ooooo`?o00002oooool2o`0000?ooooo0_l0
000;ooooo`;o000000?oooooo`000?l000002oooool2o`0003[ooooo000Looooo`;o0000>_ooool2
o`0000?ooooo0_l00003ooooo`;o00003?ooool4o`000003ooooool0003o000000;ooooo0_l00005
ooooo`Co00000_ooool2o`0000?ooooo0_l00004ooooob;o000000?oooooo`000?l000001Oooool6
o`0000Wooooo0_l0000Aooooo`;o000000?oooooo`000?l000000oooool3o`0000gooooo0_l00005
ooooo`?o00001?ooool2o`0000Cooooo0_l0000Dooooo`;o00002_ooool3o`0003[ooooo000Loooo
o`03o`000?oooooooooo03Gooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo1Ol00004oooo
o`;o000000?oooooo`000?l000000_ooool2o`0000Cooooo1?l00006ooooo`Co00001OoooolQo`00
0003ooooool0003o000000[o00001Oooool2o`0000?ooooo0_l00008ooooo`;o00003Oooool4o`00
00Gooooo0_l00003ooooo`;o00000_ooool2o`0000cooooo0ol00003ooooo`;o00001_ooool2o`00
01?ooooo0_l00003ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0=Oooool2o`0000Co
oooo0ol00005ooooo`;o00001Oooool5o`0000Sooooo0_l00007ooooo`Co00000oooool8o`0000?o
oooo;_l00004ooooo`Co00003Oooool2o`0000;ooooo0_l000000ooooooo0000o`000006ooooo`Ko
00000oooool2o`0000?ooooo0_l0000>ooooo`;o000000Coooooo`000?l0003o00000oooool2o`00
00Gooooo0_l00003ooooo`;o00001_ooool2o`000004ooooool0003o0000o`0000;ooooo0_l00003
ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0>oooool4o`0000gooooo0_l00002oooo
o`;o00000_ooool2o`000003ooooool0003o000000Oooooo0_l00005ooooo`?o00000_ooool3o`00
00?ooooo6Ol000000ooooooo0000o`000007o`0000Kooooo1Ol00003ooooo`Go00001Oooool2o`00
00[ooooo0_l000000ooooooo0000o`000007ooooo`Go00000oooool2o`0000Gooooo0_l00007oooo
o`;o00000oooool2o`0000;ooooo0ol00002ooooo`;o00000_ooool2o`000003ooooool0003o0000
00?ooooo0_l00005ooooo`?o000000Coooooo`000?l0003o0000A?ooool001cooooo00?o0000oooo
ooooool0?Oooool2o`000003ooooool0003o000000;ooooo0ol00002ooooo`;o000000?oooooo`00
0?l000000_ooool2o`0000;ooooo0_l00003ooooo`;o00001Oooool2o`0000?ooooo0_l00006oooo
o`;o000000Coooooo`000?l0003ooooo8ol00006ooooo`Co00000oooool2o`0000;ooooo0_l00004
ooooo`;o00005?ooool2o`0000Oooooo0_l00006ooooo`;o00000_ooool2o`0000?ooooo0_l00003
ooooo`;o00000oooool4o`0000Cooooo0_l0000=ooooo`;o00000_ooool2o`0000Wooooo0_l0000=
ooooo`;o0000:oooool001cooooo00?o0000ooooooooool0?oooool3o`0000;ooooo0ol00002oooo
o`;o00001oooool4o`0000?ooooo0_l00004ooooo`?o00000oooool3o`0000Oooooo:ol0000=oooo
o`Co00001oooool2o`0000?ooooo0_l0000:ooooo`;o00001oooool2o`0000Wooooo1?l00007oooo
o`;o00000oooool4o`0000;ooooo0_l00003ooooo`;o00003Oooool3o`0000Wooooo0_l0000=oooo
o`;o0000:oooool001cooooo00?o0000ooooooooool0?oooool2o`0000Gooooo0_l0000:ooooo`Co
00000_ooool2o`0000Gooooo0_l00002ooooo`Go00001OoooolSo`000003ooooool0003o000000Oo
00000oooool4o`0000Oooooo0ol00007ooooo`Co000000Coooooo`000?l0003o00005Oooool2o`00
00Kooooo1?l00003ooooo`;o00001oooool2o`0000Cooooo0_l00003ooooo`;o00001oooool2o`00
00Cooooo0_l00006ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0:_ooool2o`0000?o
oooo0_l0000Eooooo`Go00002?ooool2o`0000?ooooo0_l00009ooooo`;o00002?oooolZo`0000;o
oooo0_l00002ooooo`Co000000?oooooo`000?l000001?ooool2o`0000[ooooo0_l00002ooooo`?o
000000?oooooo`000?l000004Oooool4o`0000Cooooo0ol00004ooooo`;o000000?oooooo`000?l0
00000_ooool4o`0000Sooooo0ol00007ooooo`;o00001_ooool2o`0000Cooooo0_l0000nooooo`00
7?ooool00ol0003oooooooooo`0Zooooo`;o00000oooool2o`0000gooooo0_l000000ooooooo0000
o`000003ooooo`Go00002?ooool2o`0000Oooooo0_l00002ooooo`;o00001Oooool2o`0000Cooooo
1_l000000ooooooo0000o`00000Ro`000003ooooool0003o000000;o000000Coooooo`000?l0003o
oooo1Ol0000<ooooo`;o00001Oooool2o`000003ooooool0003o000000Gooooo0_l00003ooooo`;o
00000oooool6o`0000Cooooo0ol00002ooooo`;o00000oooool6o`0000[ooooo0_l0000;ooooo`;o
00000oooool2o`0000Oooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0mooooo`?o0000
00?oooooo`000?l000000_ooool2o`0000Cooooo0_l00006ooooo`Co00001Oooool2o`0000;ooooo
0_l00005ooooo`;o00001?ooool5o`0000;ooooo9?l00003ooooo`?o00000oooool5o`0000cooooo
0_l0000?ooooo`;o000000?oooooo`000?l000000_l00003ooooo`Ko00002Oooool2o`0000Gooooo
1?l00003ooooo`;o000000?oooooo`000?l000000_ooool4o`0000Oooooo1?l0000<ooooo`;o0000
>oooool001cooooo00?o0000ooooooooool0?Oooool2o`0000Kooooo0_l00004ooooo`;o00001_oo
ool4o`0000?ooooo0_l0000?oooooa[o000000?oooooo`000?l000004?l00003ooooo`?o000000Co
ooooo`000?l0003ooooo0_l00002ooooo`;o00003?ooool2o`0000Wooooo2_l00004ooooo`;o0000
0_ooool2o`0001Oooooo0_l000000ooooooo0000o`000004ooooo`;o00001oooool2o`0000Kooooo
0_l00004ooooo`;o00003_ooool2o`0002gooooo000Looooo`03o`000?oooooooooo03kooooo0_l0
000Hooooo`Co00000_ooool2o`0000[ooooo1?l00003ooooobOo00000_ooool3o`0000;ooooo0_l0
0005ooooo`;o000000?oooooo`000?l000001oooool4o`0000Wooooo2?l00002ooooo`;o00000_oo
ool2o`00013ooooo1?l0000=ooooo`;o00004_ooool2o`0000Cooooo0_l0000>ooooo`;o000000?o
ooooo`000?l00000:_ooool001cooooo00?o0000ooooooooool0?_ooool2o`0000Cooooo0_l0000B
ooooo`Co00000_ooool2o`0000;ooooo0ol00003ooooocOo00002_ooool2o`0000Oooooo0_l0000;
ooooo`;o00000oooool3o`0000;ooooo0_l00002ooooo`;o00003oooool5o`0000gooooo0_l0000H
ooooo`;o00004Oooool2o`0002[ooooo000Looooo`03o`000?oooooooooo04Cooooo1Ol00002oooo
o`?o00005?ooool5o`000004ooooool0003o0000ooooocKo00002?ooool2o`00013ooooo0_l00000
0ooooooo0000o`000008o`000003ooooool0003o0000017ooooo1?l0000<ooooo`;o00002_ooool2
o`0004oooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0jooooo`;o00002?ooool5o`0000;ooooo
0ol00006ooooo`;o00001_ooool2o`000003ooooool0003o000000Cooooo0_l00005ooooo`?o0000
00?oooooo`000?l00000:Ol00002ooooo`Co00002?ooool3o`0000?ooooo0_l00007ooooo`Go0000
00?oooooo`000?l000002?l000000ooooooo0000o`000008ooooo`;o00001oooool3o`0000?ooooo
1Ol00005ooooo`;o00000oooool2o`0000?ooooo1?l00002ooooo`;o00001oooool2o`0004;ooooo
00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRH
V?lQ8B401_ooool00ol0003oooooooooo`0jooooo`;o00001_ooool4o`000003ooooool0003o0000
00Oooooo0ol000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l000000_l00009oooo
o`?o000000?oooooo`000?l000003_l000000ooooooo0000o`00000Fo`000003ooooool0003o0000
00Go00002?ooool3o`0000?ooooo0ol00004oooooa;o000000?oooooo`000?l000000ol00005oooo
o`;o00001oooool2o`0000Cooooo1Ol00003ooooo`;o00001Oooool2o`0000?ooooo0_l00004oooo
o`;o00001oooool2o`0000Gooooo0_l0000kooooo`0000?ooooooa0@4?ooool00_ooool00ol@413o
ooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0]oooo
o`;o00004oooool4o`0000Sooooo2?l000000ooooooo0000o`000006ooooo`Co00001oooool2o`00
00;ooooo0_l00004ooooo`go00000ooooolOo`0000Kooooo0_l00005ooooo`;o00000_ooool5o`00
0003ooooool0003o000000co000000?oooooo`000?l000002Ol00008ooooo`;o00003?ooool2o`00
01;ooooo0_l0000<ooooo`;o0000>oooool00003ooooool0003ooooo00;ooooo00?o0000oooooooo
ool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0000Wooooo`;o00001?ooool2o`00
00oooooo0_l00002ooooo`Co00002?ooool2o`0000?ooooo0ol000001?oooooo0000o`000?l00009
ooooo`;o00001Oooool2o`0000;ooooo0_l00004oooooago000000?oooooo`000?l000002_l00003
ooooo`Co00000_ooool2o`0000Kooooo0_l00002ooooo`?o000000?oooooo`000?l000006ol00002
ooooo`;o00003Oooool2o`0001Oooooo0_l0000<ooooo`;o00002?ooool3o`00033ooooo00000ooo
oooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006
ooooo`03o`000?oooooooooo02Oooooo0_l0000Eooooo`;o00001?ooool2o`00017ooooo1Ol00003
ooooo`;o00000_ooool2o`0000Wooooo8ol000000ooooooo0000o`00000:o`000003ooooool0003o
000000;ooooo0_l000001?oooooo0000o`000?l00003ooooo`Go000000Goooooo`000?l0003o0000
ooooo`0Io`000004ooooool0003o0000o`0000?ooooo0_l0000=ooooo`;o00000_ooool2o`0002_o
oooo0ol0000`ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`03oeEE
EOn7QhOooooo00Sooooo00?o0000ooooooooool0A?ooool2o`0000Sooooo0_l00007ooooo`;o0000
00?oooooo`000?l000000oooool2o`0000gooooo2?l000000ooooooo0000o`00000To`0000;ooooo
1Ol00002ooooo`;o00001?ooool4o`000003ooooool0003o000002;o00000oooool2o`000003oooo
ool0003o000000cooooo0_l00005ooooo`;o00001oooool2o`0000Oooooo1?l00013ooooo`0000Ko
ooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000oooooooo
ool0C_ooool2o`0000Gooooo0_l000000ooooooo0000o`000002o`0000Oooooo0_l0000:ooooo`Oo
000000?oooooo`000?l000007Ol000001?oooooo0000o`000?ooool5o`000003ooooool0003o0000
00;o000000?oooooo`000?l000002?ooool5o`000003ooooool0003o000001[o00000_ooool2o`00
00?ooooo0_l000000ooooooo0000o`000009ooooo`;o00002?ooool3o`0000Kooooo0_l00004oooo
o`;o000000?oooooo`000?l000000_l00013ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<
ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0Boooool<o`000003ooooool0
003o000000;o00001oooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool5o`000005oooo
ool0003o0000o`000?ooool08_l00003ooooo`?o00000_ooool2o`0000;ooooo0_l00004ooooo`;o
00000_ooool2o`0000?ooooo5?l000000ooooooo0000o`000006o`0000Gooooo0_l0000=ooooo`?o
00002Oooool2o`0000?ooooo0_l00007ooooo`;o00000oooool2o`0000Wooooo0_l0000hooooo`00
7?ooool00ol0003oooooooooo`1;ooooo`?o00000_ooool7o`0000Kooooo0_l00008ooooo`;o0000
00Coooooo`000?l0003ooooo0ol00002oooooa3o000000?oooooo`000?l000002_l000000ooooooo
0000o`000005o`0000Oooooo0ol0000:ooooo`;o000000?oooooo`000?l000000ol000001?oooooo
0000o`000?oooolJo`000003ooooool0003o000000;ooooo0_l0000=ooooo`;o00003_ooool3o`00
00cooooo0_l000000ooooooo0000o`000006ooooo`;o00000_ooool2o`0003Cooooo000Looooo`03
o`000?oooooooooo02oooooo0_l0000Cooooo`;o00005?ooool2o`000003ooooool0003o000000oo
oooo2_l00002ooooo`go000000?oooooo`000?l000001ol000000ooooooo0000o`000004o`0000Go
oooo1Ol00006ooooo`;o00001?ooool5o`000003ooooool0003o000000;ooooo7?l0000?ooooo`;o
00004?ooool2o`0000Sooooo0_l00006ooooo`;o00002_ooool2o`0003Cooooo000Looooo`03o`00
0?oooooooooo02oooooo0_l0000Cooooo`;o00003oooool2o`0000?ooooo0_l0000Dooooo`;o0000
0_oooolTo`0000Gooooo1Ol00006ooooo`Co00002?oooolKo`000003ooooool0003o000000?o0000
0oooool2o`000003ooooool0003o000000Kooooo1?l00004ooooo`;o00004_ooool2o`0004Sooooo
000Looooo`03o`000?oooooooooo04Cooooo0_l0000?ooooo`;o00007Oooool2o`0000;ooooo0_l0
00000ooooooo0000o`000002o`000003ooooool0003o000000[o000000?oooooo`000?l000001?l0
0002ooooo`?o000000?oooooo`000?l000000oooool2o`0000[ooooo0_l00007ooooo`oo000000?o
ooooo`000?l000001ol000000ooooooo0000o`000006o`0000;ooooo0ol000000ooooooo0000o`00
0008ooooo`;o00001?ooool2o`0000Cooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`11
ooooo`;o00008_ooool2o`0000gooooo1Ol00003oooooa7o00000_ooool2o`0000?ooooo1?l00000
1?oooooo0000o`000?l00007ooooo`;o00000_ooool2o`0000[ooooo0_l000000ooooooo0000o`00
000:o`000003ooooool0003o000000co000000?oooooo`000?l000000_ooool3o`000003ooooool0
003o000000[ooooo0_l00009ooooo`Co00001Oooool2o`0000;ooooo0_l000000ooooooo0000o`00
000@ooooo`;o0000=?ooool001cooooo00?o0000ooooooooool0@Oooool2o`0000Sooooo0_l0000H
ooooo`;o00002oooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000003?l00000
0ooooooo0000o`000003o`0000Cooooo1_l000001?oooooo0000o`000?l00002ooooo`;o00000ooo
ool2o`0000;ooooo0_l0000=oooooaoo000000?oooooo`000?l000000_ooool4o`0000Sooooo0_l0
0002ooooo`?o00001_ooool2o`0000?ooooo1?l00002ooooo`;o000000?oooooo`000?l000004?oo
ool2o`0003Cooooo000Looooo`03o`000?oooooooooo047ooooo0_l00008ooooo`?o00000oooool2
o`0000;ooooo0_l0000Kooooo`;o000000?oooooo`000?l000000_ooool9o`0000;ooooo1?l00000
0ooooooo0000o`000005o`0000;ooooo1_l00004ooooo`Co00004_ooool2o`000003ooooool0003o
000001ko00000_ooool2o`0000;ooooo0ol0000<ooooo`?o00002oooool2o`0001Gooooo0_l0000h
ooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00000oooool2o`0000;ooooo0_l0000Doooo
o`;o00001Oooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o00000_ooool7o`00
0004ooooool0003o0000ooooo`;o00000oooool5o`0000Cooooo0_l0000Cooooo`Oo000000?ooooo
o`000?l000000ol000000ooooooo0000o`000002o`000003ooooool0003o000000ko00000oooool2
o`0000;ooooo0_l00006ooooo`;o00003?ooool2o`0000cooooo1?l0000<ooooo`;o0000>?ooool0
01cooooo00?o0000ooooooooool0C_ooool2o`0000Gooooo0_l000001?oooooo0000o`000?ooool2
o`0000Cooooo1_l00004ooooo`;o00003?ooool3o`0000?ooooo0_l00002ooooo`Oo00002Oooool4
o`0000Gooooo0_l0000?ooooo`;o00000_oooolSo`0000;ooooo0_l0000;ooooo`Co00002_ooool2
o`0000cooooo1?l00016ooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o000000?oooooo`00
0?l000000_ooool2o`000003ooooool0003o000000?o00001?ooool6o`0000;ooooo1?l0000=oooo
o`?o00001_ooool3o`0000?ooooo0_l00008ooooo`Co00000_ooool2o`0000oooooo0_l000000ooo
oooo0000o`000003ooooo`;o000000?oooooo`000?l000007Ol00002ooooo`;o00003Oooool2o`00
00_ooooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`1Aooooo`?o00000_ooool2o`0000;o
oooo0_l000000ooooooo0000o`000006ooooo`;o00000_ooool2o`00013ooooo0ol000000ooooooo
0000o`000002ooooo`?o00000oooool2o`0000Kooooo0_l00003ooooo`;o000000?oooooo`000?l0
00003?ooool2o`000003ooooool0003o000000[ooooo1Ol000000ooooooo0000o`000003o`000003
ooooool0003o000000Ko000000?oooooo`000?l000002ol00007ooooo`;o00001_ooool2o`0000?o
oooo0_l00004ooooo`;o00002Oooool2o`0004[ooooo000Looooo`;o0000C_ooool2o`0000;ooooo
0ol00002ooooo`?o000000Coooooo`000?l0003ooooo0_l00005ooooo`Co000000Coooooo`000?l0
003o00002_ooool2o`000003ooooool0003o000000?o000000?oooooo`000?l000002_ooool3o`00
00?ooooo0_l00003ooooo`;o00003oooool2o`0000Kooooo0_l00005ooooo`;o000000?oooooo`00
0?l000007Ol00007ooooo`;o00001_ooool2o`0000?ooooo0_l0000?ooooo`?o0000BOooool001co
oooo00?o0000ooooooooool0B_ooool2o`000003ooooool0003o000000;o00001_ooool5o`0000?o
oooo0_l00003ooooo`Co000000Coooooo`000?l0003o00001?ooool2o`0000Cooooo0_l000000ooo
oooo0000o`000002o`0000kooooo0ol00002ooooo`;o00004?ooool2o`0000_ooooo0_l00005oooo
o`;o000000?oooooo`000?l000005_l000000ooooooo0000o`000002o`00013ooooo0_l00003oooo
o`;o00003_ooool5o`00017ooooo0_l0000fooooo`007?ooool00ol0003oooooooooo`14ooooo`;o
00001?ooool2o`0000?ooooo0ol00005ooooo`Co00001?ooool2o`0000oooooo0_l00005ooooo`;o
00000oooool2o`0000gooooo0ol00002ooooo`;o00003?ooool3o`000003ooooool0003o000000;o
oooo0_l0000=ooooo`;o00001?oooolFo`000004ooooool0003o0000ooooo`Co00001?ooool2o`00
00Oooooo0ol00002ooooo`;o00001Oooool4o`0000?ooooo1_l000000ooooooo0000o`00000?oooo
o`;o0000=_ooool001cooooo00?o0000ooooooooool0@Oooool2o`000003ooooool0003o000000Ko
oooo0_l00002ooooo`Co00000oooool2o`0001_ooooo0_l000001?oooooo0000o`000?ooool4o`00
00;ooooo0_l00009ooooo`;o00002Oooool2o`000004ooooool0003o0000ooooo`Oo00000oooool2
o`0000?ooooo0_l00008ooooo`;o00001?ooool:o`000003ooooool0003o000000Ko000000?ooooo
o`000?l000000oooool5o`0000Cooooo0_l00007ooooo`?o00002Oooool4o`0000?ooooo0ol00004
ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0@Oooool2o`0000;ooooo0_l00005oooo
o`;o00001?ooool2o`0001_ooooo1?l000000ooooooo0000o`000004ooooo`;o000000Coooooo`00
0?l0003ooooo0_l0000Dooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`?o00001Ooo
ool2o`000003ooooool0003o000000kooooo3_l000000ooooooo0000o`000002o`0000;ooooo0_l0
00001Ooooooo0000o`000?l0003ooooo00;o00002_ooool2o`0000;ooooo0_l0000Booooo`;o0000
C?ooool001cooooo00?o0000ooooooooool0AOooool2o`0001gooooo0_l00005ooooo`;o00000_oo
ool4o`000003ooooool0003o000000Oooooo0_l0000@ooooo`;o00001Oooool2o`0000;ooooo0_l0
0004ooooo`;o00000oooool2o`000003ooooool0003o000000oooooo3Ol000000ooooooo0000o`00
0002o`000003ooooool0003o000000;ooooo1Ol00002ooooo`;o00002_ooool2o`0000;ooooo1Ol0
000>ooooo`?o0000C?ooool001cooooo00?o0000ooooooooool0GOooool2o`0000Gooooo0_l00005
ooooo`;o00000_ooool2o`0000Kooooo0_l00009ooooo`;o00002oooool2o`0000Kooooo0_l00000
0ooooooo0000o`000002ooooo`;o00001Oooool2o`0000Gooooo0_l0000;ooooo`Go000000?ooooo
o`000?l000002ol00005ooooo`Co00003_ooool2o`0000Cooooo0ol0000<ooooo`Co00004oooool2
o`0003Sooooo000Looooo`03o`000?oooooooooo04gooooo1?l0000<ooooo`;o00001Oooool2o`00
0003ooooool0003o000000Kooooo0_l00006ooooo`;o00002Oooool2o`0000Oooooo0_l00003oooo
o`;o00000_ooool2o`000003ooooool0003o000000Gooooo0_l00007ooooo`?o00000_ooool2o`00
00gooooo0ol000000ooooooo0000o`000002o`000003ooooool0003o000000?o000000?oooooo`00
0?l000002?ooool2o`000003ooooool0003o000000[ooooo0_l0000?ooooo`;o00000_ooool4o`00
01?ooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`14ooooo`Co00001Oooool4o`0000Oo
oooo0_l0000;ooooo`Go00001?ooool2o`0001Kooooo0_l00003ooooo`;o00000oooool2o`0000;o
oooo0ol0000@ooooo`?o00005Oooool6o`0000Gooooo1?l00006ooooo`;o000000?oooooo`000?l0
00003oooool2o`0000Kooooo0_l00002ooooo`;o00001?ooool2o`0004gooooo000Looooo`03o`00
0?oooooooooo04Cooooo1?l0000:ooooo`;o00000oooool3o`0000_ooooo0_l000000ooooooo0000
o`000004ooooo`;o00005_ooool2o`0000?ooooo0_l00008ooooo`;o00001?ooool2o`0000Wooooo
0_l0000Fooooo`?o00000_ooool5o`0000;ooooo1?l0000Hooooo`Co00001_ooool2o`0005Oooooo
000Looooo`03o`000?oooooooooo04Kooooo0_l00004ooooo`;o00001?ooool2o`0000?ooooo0ol0
000=ooooo`;o00000_ooool2o`0000oooooo0_l00009ooooo`;o00000_ooool2o`0000kooooo0_l0
0002ooooo`;o00001Oooool4o`00017ooooo0_l000000ooooooo0000o`000005ooooo`Go00003Ooo
ool2o`0000Gooooo0_l00006ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l0
001Dooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00000_ooool2o`0000Kooooo0_l00008
ooooo`;o00000oooool2o`0000;ooooo0_l0000?ooooo`;o00001_ooool2o`000003ooooool0003o
000000Kooooo0_l00003ooooo`;o00002Oooool2o`0000Oooooo0_l00005ooooo`;o00002_ooool2
o`0000_ooooo0_l0000:ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Wooooo1_l00004
ooooo`;o0000E?ooool001cooooo00?o0000ooooooooool0D?ooool2o`000003ooooool0003o0000
00Cooooo0ol00003ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Gooooo0_l000000ooo
oooo0000o`00000:ooooo`;o000000Coooooo`000?l0003o00002Oooool2o`0000?ooooo0_l0000;
ooooo`;o00000oooool2o`0000Cooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l00002
ooooo`?o00004_ooool2o`0000?ooooo0ol0000Dooooo`;o0000G?ooool001cooooo00?o0000oooo
ooooool0Doooool2o`0000?ooooo1?l00003ooooo`;o00000oooool2o`000003ooooool0003o0000
00?o00001Oooool5o`0000[ooooo0_l000000ooooooo0000o`000003ooooo`;o00005?ooool2o`00
0003ooooool0003o000000;o000000?oooooo`000?l000001?ooool4o`000003ooooool0003o0000
00?ooooo0_l00002ooooo`?o00003Oooool2o`0000?ooooo0_l00004ooooo`;o00005Oooool2o`00
05_ooooo000Looooo`03o`000?oooooooooo05Cooooo0_l00002ooooo`;o00001_ooool6o`000004
ooooool0003o0000o`0000Sooooo0_l0000Dooooo`;o00002_ooool2o`0000Sooooo0_l00003oooo
o`;o00002Oooool2o`000004ooooool0003o0000o`0001Kooooo0_l0000Pooooo`;o0000Foooool0
01cooooo00?o0000ooooooooool0A?ooool2o`0000kooooo0_l00002ooooo`;o00000_ooool2o`00
00;ooooo1?l000000ooooooo0000o`00000;ooooo`;o00007oooool3o`0000Kooooo0_l00006oooo
o`;o00002Oooool5o`0000;ooooo0_l00006ooooo`;o000000?oooooo`000?l000002?ooool2o`00
01oooooo0ol00003ooooo`Co0000Doooool001cooooo0_l00015ooooo`;o00001oooool2o`0000go
oooo0_l00007ooooo`;o00002oooool2o`00017ooooo0_l0000<ooooo`?o00001_ooool2o`0000Ko
oooo0_l00009ooooo`;o00001Oooool2o`0000Cooooo1?l000000ooooooo0000o`000003ooooo`;o
00000oooool2o`0001gooooo0_l000000ooooooo0000o`000003ooooo`Ko00004Oooool2o`0003ko
oooo000Looooo`03o`000?oooooooooo043ooooo0_l0000;ooooo`;o00000_ooool2o`0000;ooooo
0_l000001?oooooo0000o`000?ooool2o`0002Sooooo0_l00004ooooo`;o00001oooool3o`0001Go
oooo0_l00004ooooo`;o00002?ooool2o`0000Sooooo0_l00009ooooo`;o00000_ooool2o`00013o
oooo0_l000000ooooooo0000o`00000:ooooo`;o00004Oooool3o`0003gooooo000Looooo`03o`00
0?oooooooooo043ooooo0_l0000;ooooo`;o00000_ooool2o`000005ooooool0003o0000o`000?oo
ool00_l000000ooooooo0000o`00000^ooooo`;o00002?ooool2o`0000Gooooo0_l00008ooooo`;o
00001?ooool2o`0000Cooooo0_l0000Mooooo`;o00000_ooool2o`00013ooooo0_l0000Qooooo`;o
0000?Oooool001cooooo00?o0000ooooooooool0Coooool4o`000003ooooool0003o000000oooooo
0_l0000eooooo`;o00002?ooool2o`0000Cooooo0_l0000Vooooo`Ko00002_ooool2o`0000_ooooo
0ol0001Eooooo`007?ooool00ol0003oooooooooo`1?ooooo`Co00001Oooool2o`0000_ooooo0_l0
0003ooooo`;o00004Oooool2o`0002[ooooo0_l0000?ooooo`;o00001_ooool2o`0000[ooooo0_l0
0004ooooo`;o000000?oooooo`000?l000000ol00008ooooo`;o00002oooool3o`0005Gooooo000L
ooooo`03o`000?oooooooooo05Sooooo0_l00009ooooo`;o00001?ooool3o`000003ooooool0003o
000000kooooo0_l0000Zooooo`Co00003Oooool2o`0000Kooooo0_l0000:ooooo`;o00002?ooool4
o`0000Sooooo1?l00007ooooo`;o0000F?ooool001cooooo00?o0000ooooooooool0F?ooool2o`00
00?ooooo0_l00004ooooo`Co00000_ooool2o`0000;ooooo1ol0000gooooo`;o00002?ooool2o`00
00Gooooo0_l0000Vooooo`Co00001oooool3o`0005Oooooo000Looooo`03o`000?oooooooooo05go
oooo0_l00006ooooo`;o00002?ooool5o`0000Kooooo0_l0000`ooooo`;o00000oooool6o`0000Co
oooo0ol00005ooooo`;o00001Oooool2o`0000oooooo0_l00008ooooo`;o00000_ooool2o`0000Go
oooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`1Eooooo`;o00003_ooool2o`0000[ooooo
0ol00006ooooo`;o0000<?ooool2o`0000?ooooo1?l00006ooooo`;o00000oooool2o`000003oooo
ool0003o000000Gooooo0_l00002ooooo`;o00002oooool2o`0000Sooooo0_l00002ooooo`;o0000
G_ooool001cooooo00?o0000ooooooooool0B_ooool2o`0000?ooooo0ol00003ooooo`;o000000?o
ooooo`000?l000006?ooool2o`0000cooooo0_l0000aooooo`;o00002oooool2o`0000Wooooo0_l0
00000ooooooo0000o`00000<ooooo`;o00000oooool2o`0006Kooooo000Looooo`03o`000?oooooo
oooo04[ooooo0_l00003ooooo`Co00000_ooool2o`000003ooooool0003o000000Oooooo0_l0000<
ooooo`;o000000?oooooo`000?l000003?ooool4o`0002Kooooo0_l0000=ooooo`;o000000?ooooo
o`000?l000001Oooool2o`0000Kooooo0_l000000ooooooo0000o`000003ooooo`;o00001oooool2
o`0000?ooooo0_l00002ooooo`;o0000H_ooool001cooooo00?o0000ooooooooool0DOooool3o`00
0003ooooool0003o000000?ooooo0_l00005ooooo`;o00003?ooool2o`0000;ooooo0_l000000ooo
oooo0000o`00000:ooooo`;o00009_ooool2o`0000gooooo0_l000000ooooooo0000o`000005oooo
o`;o00002Oooool2o`0000?ooooo0_l00009ooooo`Co00000oooool2o`0006;ooooo000Looooo`03
o`000?oooooooooo04[ooooo0_l00006ooooo`;o00001_ooool2o`0001?ooooo0ol000001?oooooo
0000o`000?ooool2o`0000Wooooo0_l0000Wooooo`;o00001?ooool2o`00013ooooo0_l00003oooo
o`;o00005Oooool4o`0006Oooooo000Looooo`03o`000?oooooooooo04[ooooo0_l00006ooooo`;o
00004Oooool2o`0000Wooooo0_l00003ooooo`;o00002_ooool2o`0002;ooooo0_l00003ooooo`;o
00000_ooool4o`0000;ooooo0_l00004ooooo`;o00001_ooool2o`0000?ooooo0_l00020ooooo`00
7?ooool00ol0003oooooooooo`1Booooo`;o00004Oooool2o`0000kooooo0_l000000ooooooo0000
o`00000;ooooo`;o00007_ooool2o`0000?ooooo0_l00002ooooo`;o00001?ooool2o`0000Cooooo
0_l00007ooooo`;o0000Q?ooool001cooooo00?o0000ooooooooool0H?ooool2o`0000Kooooo0_l0
000>ooooo`?o00002_ooool2o`0003Cooooo0_l00006ooooo`;o00001?ooool2o`00013ooooo0_l0
001/ooooo`007?ooool2o`00067ooooo0_l00004ooooo`Co000000?oooooo`000?l000003?ooool2
o`0000Wooooo0_l0000eooooo`;o000000?oooooo`000?l000000oooool2o`000003ooooool0003o
000000Go00000_ooool2o`0000Wooooo0ol00003ooooo`;o0000Ioooool001cooooo00?o0000oooo
ooooool0E_ooool2o`000003ooooool0003o000000_ooooo1?l000000ooooooo0000o`00000Boooo
o`;o00000oooool2o`00033ooooo0_l00006ooooo`;o000000?oooooo`000?l000000_l000001?oo
oooo0000o`000?l00002ooooo`?o000000?oooooo`000?l000002Oooool2o`0000Cooooo0_l0001W
ooooo`007?ooool00ol0003oooooooooo`1Fooooo`;o000000?oooooo`000?l000003Oooool2o`00
00Oooooo0_l00004ooooo`?o00001Oooool2o`0002;ooooo0_l00004ooooo`;o00001oooool2o`00
00;ooooo0_l00009ooooo`;o00002Oooool2o`0000Gooooo0_l00003ooooo`?o00001Oooool4o`00
06Gooooo000Looooo`03o`000?oooooooooo05oooooo0_l0000;ooooo`;o00000oooool2o`0000Co
oooo0ol0000>ooooo`Co00005oooool2o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`;o
00007_ooool3o`0000?ooooo0ol00005ooooo`Co0000IOooool001cooooo00?o0000ooooooooool0
Goooool3o`0000Wooooo0ol0000:ooooo`;o00003?ooool6o`0001[ooooo0_l00002ooooo`Co0000
1_ooool2o`0000Oooooo0_l000000ooooooo0000o`00000@ooooo`;o00001?ooool2o`0006oooooo
000Looooo`03o`000?oooooooooo063ooooo0ol00008ooooo`;o00000oooool2o`000003ooooool0
003o000000?ooooo0_l0000<ooooo`Co00005oooool2o`000003ooooool0003o000000;o00000_oo
ool2o`0000Sooooo0_l00007ooooo`;o000000?oooooo`000?l000004?ooool2o`0000Cooooo0_l0
001_ooooo`007?ooool00ol0003oooooooooo`1Qooooo`?o00002_ooool4o`000004ooooool0003o
0000ooooo`;o00001_ooool2o`0000Sooooo0_l00004ooooo`;o00004Oooool2o`000003ooooool0
003o000000?ooooo0_l0000Yooooo`;o00000_ooool2o`0006oooooo000Looooo`03o`000?oooooo
oooo06;ooooo0_l0000:ooooo`;o00001_ooool2o`0000Kooooo0_l0000:ooooo`;o000000Cooooo
o`000?l0003o00006Oooool2o`0001;ooooo0_l0000=ooooo`;o00001_ooool2o`0000;ooooo0_l0
000Mooooo`;o0000D?ooool001cooooo00?o0000ooooooooool0KOooool2o`0000Oooooo0_l00006
ooooo`;o00002_ooool2o`000003ooooool0003o000000;o00007?ooool2o`0000;ooooo0_l0000:
ooooo`;o00002_ooool2o`000003ooooool0003o000000[ooooo0_l0000Mooooo`;o0000D?ooool0
01cooooo00?o0000ooooooooool0KOooool2o`0000?ooooo0_l00002ooooo`;o00001_ooool2o`00
00kooooo0ol0000Iooooo`Ko000000?oooooo`000?l000005_ooool2o`0007kooooo000Looooo`03
o`000?oooooooooo06Wooooo0_l00005ooooo`Co00006_ooool2o`00013ooooo0_l00006ooooo`Go
000000?oooooo`000?l000003Oooool2o`0000[ooooo0_l000000ooooooo0000o`000008ooooo`;o
0000LOooool001cooooo00?o0000ooooooooool0JOooool2o`0000Gooooo0_l0000Looooo`;o0000
4?ooool2o`0000Kooooo0_l0000?ooooo`;o00000_ooool2o`0000Cooooo0_l00004ooooo`;o0000
00?oooooo`000?l000002?ooool2o`00077ooooo000Looooo`03o`000?oooooooooo06_ooooo0ol0
0003ooooo`;o00002?ooool3o`0000Cooooo0_l0000@ooooo`;o00005Oooool2o`0000cooooo1Ol0
0005ooooo`;o00001?ooool2o`0007kooooo000Looooo`03o`000?oooooooooo05_ooooo0_l0000>
ooooo`?o00000oooool2o`0000Sooooo0ol00004ooooo`;o00004?ooool2o`0000kooooo0_l00005
ooooo`;o00003_ooool3o`0000cooooo0_l00004ooooo`;o0000Moooool00006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`00
0?oooooooooo05_ooooo0_l00007ooooo`;o00003Oooool2o`0000;ooooo0ol0000Zooooo`;o0000
1oooool2o`0001_ooooo0_l00004ooooo`;o0000Moooool00006oooooomgMgOoV9RHoooooonHV9So
MgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo
06Cooooo0_l00002ooooo`;o00002Oooool2o`0000;ooooo0ol0000;ooooo`;o000000?oooooo`00
0?l000002oooool2o`0000_ooooo0_l00004ooooo`Co000000?oooooo`000?l000002Oooool2o`00
013ooooo0_l0001mooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`1Xooooo`;o00004oooool2o`00
00Kooooo0_l000000ooooooo0000o`00000;ooooo`;o00001_ooool2o`0000?ooooo0_l00004oooo
o`Co00003?ooool2o`000004ooooool0003o0000ooooo`;o00000oooool2o`0000Gooooo0_l0001m
ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9Sooooo
oiRHV?lb<S801_ooool3o`0007_ooooo1?l0000Booooo`;o00002_ooool2o`0001?ooooo0_l00007
ooooo`;o000000Coooooo`000?l0003ooooo1?l00002ooooo`;o00000oooool2o`0007_ooooo0000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Goc<c<o`000?l0003o0000olc<
c006ooooo`03o`000?oooooooooo07_ooooo0_l00004ooooo`;o00003Oooool3o`000003ooooool0
003o000001Kooooo0_l00004ooooo`;o00000_ooool2o`0000Wooooo2?l00003ooooo`;o0000Nooo
ool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol@413o^[Zjoooooonj
^[[o410@00Kooooo00?o0000ooooooooool0I_ooool2o`0000?ooooo0_l00003ooooo`;o00001Ooo
ool2o`0000Sooooo0_l0000=ooooo`;o00000_ooool2o`0001Kooooo0_l00008ooooo`;o00001?oo
ool2o`0000Gooooo1?l00003ooooo`Co00007Oooool2o`0005cooooo00001_ooooooMgMgoiRHV?oo
ooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo06Ko
oooo0_l00003ooooo`;o00000oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0001_o
oooo0_l00003ooooo`;o00001Oooool2o`0000?ooooo1?l00004ooooo`;o00003?ooool2o`0001oo
oooo0_l0001Looooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000
oa0@4?nYZJT01_ooool00ol0003oooooooooo`1cooooo`Co00000oooool2o`0000;ooooo0_l00006
ooooo`;o00005Oooool2o`0000?ooooo0ol00003ooooo`;o00001Oooool2o`0000?ooooo1?l00000
0ooooooo0000o`00002>ooooo`007?ooool00ol0003oooooooooo`1cooooo`Ko000000?oooooo`00
0?l000000_l0000Booooo`?o00001_ooool2o`0000;ooooo0_l00003ooooo`;o00005?ooool3o`00
00?ooooo0_l00029ooooo`007?ooool00ol0003oooooooooo`1eooooo`Co00000oooool3o`0000Oo
oooo0_l00004ooooo`;o00000_ooool4o`0000Gooooo0ol00009ooooo`;o00004Oooool2o`0000Co
oooo0_l00004ooooo`;o0000Poooool001cooooo00?o0000ooooooooool0MOooool4o`0000Cooooo
0_l00006ooooo`?o00001?ooool2o`0000Cooooo1?l00004ooooo`;o00002Oooool4o`0001Gooooo
0ol00003ooooo`;o0000Poooool001cooooo00?o0000ooooooooool0Moooool2o`0000cooooo0ol0
000<ooooo`;o00002Oooool2o`0000;ooooo0_l00002ooooo`;o00005_ooool2o`0001Oooooo0_l0
001_ooooo`007?ooool00ol0003oooooooooo`1jooooo`Co00004?ooool2o`0000oooooo0_l00002
ooooo`;o00004Oooool2o`0000Cooooo0_l00002ooooo`;o00005_ooool2o`0006oooooo000Loooo
o`03o`000?oooooooooo07[ooooo1?l00002ooooo`;o00003?ooool2o`0001Sooooo0_l00004oooo
o`;o00001_ooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0008Oooooo000Loooo
o`03o`000?oooooooooo083ooooo0_l00003ooooo`?o00001oooool2o`000003ooooool0003o0000
00Gooooo0_l00008ooooo`;o00000oooool2o`0000Cooooo0_l00009ooooo`;o000000?oooooo`00
0?l00000Roooool001cooooo00?o0000ooooooooool0QOooool3o`0000Oooooo0_l000000ooooooo
0000o`000005ooooo`;o00000oooool2o`0000?ooooo0_l00002ooooo`;o00003Oooool2o`00097o
oooo000Looooo`03o`000?oooooooooo08;ooooo0_l000001?oooooo0000o`000?ooool2o`0000Go
oooo0_l0000=ooooo`Ko00000oooool3o`0000;ooooo1?l00005ooooo`?o0000TOooool001cooooo
00?o0000ooooooooool0P_ooool2o`000003ooooool0003o000000?o00001Oooool2o`0000Gooooo
1?l00003ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o00000_ooool4o`0000Gooooo
0_l000001?oooooo0000o`000?l0002>ooooo`007?ooool00ol0003oooooooooo`1eooooo`;o0000
3Oooool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000005ooooo`Ko0000
00?oooooo`000?l000002Oooool2o`0000Cooooo1?l00006ooooo`?o0000S_ooool001cooooo0_l0
001fooooo`;o00001?ooool2o`0000Oooooo0_l00006ooooo`;o00001_ooool2o`0000?ooooo0ol0
00001?oooooo0000o`000?ooool2o`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l00000
0_l00003ooooo`;o000000?oooooo`000?l00000Soooool001cooooo00?o0000ooooooooool0Nooo
ool2o`0001Oooooo0_l0000:ooooo`;o00000oooool2o`0000Cooooo0_l00002ooooo`Go000000?o
ooooo`000?l000002?ooool2o`0008Sooooo000Looooo`03o`000?oooooooooo08[ooooo1?l00008
ooooo`;o00004oooool2o`0000?ooooo1?l0000;ooooo`;o0000R?ooool001cooooo00?o0000oooo
ooooool0P_ooool2o`0000Kooooo1?l00005ooooo`;o000000?oooooo`000?l000004oooool2o`00
00?ooooo0_l0002Gooooo`007?ooool00ol0003oooooooooo`22ooooo`;o00002?ooool2o`0000Go
oooo0_l0000Oooooo`;o0000Toooool001cooooo00?o0000ooooooooool0S?ooool2o`0002Kooooo
0_l0002Cooooo`007?ooool00ol0003oooooooooo`2?ooooo`;o00007_ooool2o`00027ooooo0_l0
001eooooo`007?ooool00ol0003oooooooooo`2?ooooo`;o00007_ooool2o`00027ooooo0_l0001e
ooooo`007?ooool00ol0003oooooooooo`2Cooooo`;o0000]?ooool001cooooo00?o0000oooooooo
ool0Toooool2o`0000?ooooo0_l0000Dooooo`;o0000VOooool001cooooo00?o0000ooooooooool0
V?ooool2o`0001Cooooo0_l0002Iooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0Soooool2o`00
0;Sooooo000Looooo`03o`000?oooooooooo08oooooo0_l0002hooooo`007?ooool00ol0003ooooo
ooooo`2nooooo`;o0000ROooool001cooooo0_l0002oooooo`;o0000ROooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0Zoooool2o`0009cooooo
000Looooo`03o`000?oooooooooo0:_ooooo0_l0002Looooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Booooo`Co000000?o410@ooooooooool00oooool00ol0003ooooooooo
o`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom:
ooooo`005?ooool00ol0003oooooooooo`05ooooo`?o0000oooooom:ooooo`005?ooool00ol0003o
ooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o
0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Boooo
o`03oeEEEOmVIVKo00000?ooooooE?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00:7ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0Fooooo`Co000000So
410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003
ooooo`Go0000S?ooool00:;ooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00003?ooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Ol@413o^[Zjoooo
oomgMgOo<S8b00?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A02<ooooo`00X_ooool01Ol0003ooooo
oooooooooooo000001_ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@
00Oooooo00?o0000ooooooooool00_ooool00onHV9So8B4Qonk^kP2=ooooo`00X_ooool01Ol0003o
oooooooooooooooo000000Wooooo1_l0000<ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03ojVYZOl@413ooooo00Cooooo00?oV9RHob4Q8Oo^k^h0S?ooool0
0:;ooooo00Go0000ohN7QoooooooZJVYo`00000Kooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000005ooooo`03oa0@4?l0003o^[Zj00Kooooo00?oMgMgofIVI_ooool0Rooo
ool00:7ooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Iooooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03okZj^_lQ8B7ooooo00Kooooo00?o
0000ooooooooool0R_ooool00<;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05o`000?nj^[[ooooooiRHV?l@
4100S?ooool00<3ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0S?ooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1038) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.611 .68186 Mdot
.59816 .63733 Mdot
.50206 .37053 Mdot
.41865 .59002 Mdot
.68482 .69685 Mdot
.5183 .32377 Mdot
.66469 .43243 Mdot
.67871 .48468 Mdot
.51641 .3519 Mdot
.58343 .55744 Mdot
.65191 .44953 Mdot
.36291 .61898 Mdot
.66006 .46779 Mdot
.39849 .57824 Mdot
.42755 .86216 Mdot
.44234 .51479 Mdot
.56986 .61471 Mdot
.32968 .42143 Mdot
.35276 .52498 Mdot
.54408 .30826 Mdot
.62449 .68786 Mdot
.41371 .58189 Mdot
.59763 .67854 Mdot
.39844 .5778 Mdot
.40974 .59869 Mdot
.57191 .63226 Mdot
.6293 .62364 Mdot
.44726 .59116 Mdot
.37203 .58711 Mdot
.68923 .47033 Mdot
.24085 .50244 Mdot
.51305 .85943 Mdot
.35311 .50755 Mdot
.80106 .44126 Mdot
.67027 .48803 Mdot
.50565 .79722 Mdot
.53007 .33853 Mdot
.68324 .46612 Mdot
.66663 .48664 Mdot
.6956 .44039 Mdot
.67149 .47799 Mdot
.579 .63274 Mdot
.66106 .41029 Mdot
.68783 .51999 Mdot
.36419 .52912 Mdot
.70557 .60696 Mdot
.26645 .6185 Mdot
.4113 .53206 Mdot
.57066 .61687 Mdot
.54472 .35353 Mdot
.78616 .45529 Mdot
.67018 .42821 Mdot
.48969 .31011 Mdot
.88099 .60102 Mdot
.68427 .45585 Mdot
.35502 .53862 Mdot
.51999 .36737 Mdot
.41854 .57439 Mdot
.40112 .57474 Mdot
.34934 .72868 Mdot
.45065 .59557 Mdot
.32735 .37552 Mdot
.54871 .65945 Mdot
.41148 .39985 Mdot
.52314 .3443 Mdot
.66062 .48368 Mdot
.60725 .63128 Mdot
.66443 .46231 Mdot
.37145 .61343 Mdot
.49481 .40193 Mdot
.41279 .53337 Mdot
.65495 .47737 Mdot
.61755 .62351 Mdot
.42361 .54649 Mdot
.59115 .22472 Mdot
.23751 .70651 Mdot
.36375 .38773 Mdot
.41959 .76599 Mdot
.37005 .75667 Mdot
.40267 .30324 Mdot
.36664 .56724 Mdot
.23805 .35325 Mdot
.34612 .80143 Mdot
.58556 .67527 Mdot
.39823 .4942 Mdot
.57095 .41192 Mdot
.4257 .55196 Mdot
.65162 .58535 Mdot
.35661 .54806 Mdot
.69728 .26444 Mdot
.51204 .34969 Mdot
.59182 .65839 Mdot
.41465 .58956 Mdot
.43286 .61159 Mdot
.36383 .66912 Mdot
.45634 .55698 Mdot
.44293 .58818 Mdot
.63147 .65368 Mdot
.64619 .45015 Mdot
.45715 .63075 Mdot
.62685 .43306 Mdot
.48344 .33763 Mdot
.41176 .51963 Mdot
.52883 .3682 Mdot
.62918 .63809 Mdot
.42942 .54447 Mdot
.64246 .48154 Mdot
.3874 .53446 Mdot
.75444 .4332 Mdot
.60154 .6367 Mdot
.42564 .61203 Mdot
.33902 .36752 Mdot
.45987 .1946 Mdot
.59474 .66257 Mdot
.4263 .28353 Mdot
.36321 .55633 Mdot
.43851 .57689 Mdot
.5957 .63844 Mdot
.48833 .36401 Mdot
.63958 .58755 Mdot
.5537 .65747 Mdot
.69994 .44518 Mdot
.55211 .65995 Mdot
.35894 .49724 Mdot
.51614 .33761 Mdot
.62932 .39494 Mdot
.58866 .41135 Mdot
.22786 .46544 Mdot
.42633 .55717 Mdot
.73213 .53168 Mdot
.50726 .3173 Mdot
.58682 .65038 Mdot
.66244 .45892 Mdot
.4922 .58739 Mdot
.61338 .65791 Mdot
.66732 .44198 Mdot
.35655 .39328 Mdot
.64861 .33628 Mdot
.55457 .63217 Mdot
.73044 .48894 Mdot
.63409 .43895 Mdot
.68877 .43084 Mdot
.80067 .41675 Mdot
.59663 .62883 Mdot
.34111 .40046 Mdot
.67285 .44796 Mdot
.25408 .55953 Mdot
.34491 .56602 Mdot
.25863 .4059 Mdot
.21428 .33749 Mdot
.79091 .42375 Mdot
.65936 .29902 Mdot
.30554 .39081 Mdot
.6779 .42443 Mdot
.40268 .60363 Mdot
.57734 .62061 Mdot
.583 .62476 Mdot
.4495 .55822 Mdot
.41901 .59548 Mdot
.41777 .53663 Mdot
.40928 .6101 Mdot
.31324 .729 Mdot
.38556 .52961 Mdot
.18393 .4514 Mdot
.58742 .66255 Mdot
.428 .60209 Mdot
.50376 .38376 Mdot
.38445 .61143 Mdot
.66599 .48023 Mdot
.4237 .58029 Mdot
.42331 .59174 Mdot
.44461 .60764 Mdot
.66515 .42966 Mdot
.50406 .84617 Mdot
.2641 .28611 Mdot
.60761 .78641 Mdot
.49245 .26063 Mdot
.52003 .31034 Mdot
.43302 .55921 Mdot
.32402 .3875 Mdot
.51669 .77986 Mdot
.37386 .56766 Mdot
.56091 .14719 Mdot
.43765 .58859 Mdot
.66378 .71399 Mdot
.39247 .48024 Mdot
.62706 .781 Mdot
.24106 .38319 Mdot
.38902 .60143 Mdot
.41973 .66541 Mdot
.60386 .73074 Mdot
.7229 .48827 Mdot
.67155 .47589 Mdot
.50036 .3822 Mdot
.5123 .36945 Mdot
.6585 .51021 Mdot
.52065 .594 Mdot
.49914 .59268 Mdot
.45143 .62011 Mdot
.48209 .37805 Mdot
.54491 .65837 Mdot
.33111 .41396 Mdot
.62844 .65443 Mdot
.14002 .57537 Mdot
.76139 .42517 Mdot
.61846 .49807 Mdot
.3586 .38109 Mdot
.49541 .35688 Mdot
.48238 .33736 Mdot
.32248 .39365 Mdot
.39303 .54373 Mdot
.60212 .62739 Mdot
.82615 .54016 Mdot
.51293 .5717 Mdot
.83771 .49579 Mdot
.60601 .61837 Mdot
.61449 .54589 Mdot
.65985 .44772 Mdot
.53549 .32359 Mdot
.44064 .5785 Mdot
.40311 .55088 Mdot
.62541 .69047 Mdot
.41296 .53611 Mdot
.51722 .64642 Mdot
.44573 .57503 Mdot
.70594 .3857 Mdot
.36456 .3883 Mdot
.65999 .51 Mdot
.22059 .46084 Mdot
.61738 .66878 Mdot
.27757 .35195 Mdot
.50232 .39446 Mdot
.48561 .78836 Mdot
.64992 .47431 Mdot
.3465 .37459 Mdot
.49779 .39606 Mdot
.32547 .41287 Mdot
.36051 .59498 Mdot
.50422 .30386 Mdot
.32782 .36731 Mdot
.4161 .81336 Mdot
.35168 .57846 Mdot
.30295 .72586 Mdot
.65332 .43493 Mdot
.5503 .65197 Mdot
.45053 .5947 Mdot
.53934 .31165 Mdot
.36124 .50093 Mdot
.62463 .25943 Mdot
.63259 .39502 Mdot
.51013 .29075 Mdot
.41386 .36229 Mdot
.34585 .37761 Mdot
.5826 .25597 Mdot
.74296 .50782 Mdot
.57859 .61391 Mdot
.41017 .5162 Mdot
.5897 .81812 Mdot
.6723 .44825 Mdot
.38675 .54579 Mdot
.67692 .37919 Mdot
.67375 .45095 Mdot
.41925 .57251 Mdot
.63705 .44776 Mdot
.58617 .62349 Mdot
.35994 .24351 Mdot
.57178 .61395 Mdot
.35766 .55055 Mdot
.63711 .47304 Mdot
.48994 .32674 Mdot
.56805 .63416 Mdot
.39256 .53345 Mdot
.44226 .55927 Mdot
.55193 .42396 Mdot
.42882 .60563 Mdot
.5544 .8218 Mdot
.43709 .60635 Mdot
.50945 .37766 Mdot
.45788 .56453 Mdot
.67268 .21418 Mdot
.59597 .3531 Mdot
.60649 .6304 Mdot
.51468 .29105 Mdot
.51645 .35781 Mdot
.39052 .25952 Mdot
.4866 .30747 Mdot
.36722 .55477 Mdot
.53042 .30557 Mdot
.27694 .40012 Mdot
.68879 .44919 Mdot
.43094 .5236 Mdot
.64028 .53544 Mdot
.54086 .36908 Mdot
.48107 .36627 Mdot
.46757 .52966 Mdot
.62111 .61949 Mdot
.41512 .59037 Mdot
.48378 .36403 Mdot
.56445 .67851 Mdot
.3656 .54078 Mdot
.46372 .48835 Mdot
.55192 .42498 Mdot
.67146 .43561 Mdot
.41494 .48709 Mdot
.40081 .52427 Mdot
.53081 .34999 Mdot
.62341 .64863 Mdot
.6805 .48597 Mdot
.57419 .64056 Mdot
.73864 .67687 Mdot
.73501 .41224 Mdot
.36609 .77503 Mdot
.29497 .36692 Mdot
.68071 .28789 Mdot
.65661 .76856 Mdot
.53639 .21827 Mdot
.29094 .48649 Mdot
.77924 .65757 Mdot
.49133 .38176 Mdot
.69612 .37325 Mdot
.51651 .36279 Mdot
.38503 .58857 Mdot
.52079 .33289 Mdot
.64746 .77742 Mdot
.44568 .5791 Mdot
.52582 .32686 Mdot
.36259 .25687 Mdot
.42694 .59743 Mdot
.59754 .66386 Mdot
.41172 .84828 Mdot
.57012 .19995 Mdot
.77058 .41638 Mdot
.50394 .31108 Mdot
.29004 .54936 Mdot
.44286 .59383 Mdot
.45394 .60482 Mdot
.56195 .63189 Mdot
.45068 .54573 Mdot
.32674 .41199 Mdot
.36108 .39115 Mdot
.45131 .44249 Mdot
.27215 .297 Mdot
.4381 .63375 Mdot
.56627 .63348 Mdot
.30482 .6915 Mdot
.61265 .22717 Mdot
.50379 .25792 Mdot
.69664 .42579 Mdot
.47975 .84171 Mdot
.51102 .59285 Mdot
.65049 .40989 Mdot
.66414 .5275 Mdot
.60022 .65123 Mdot
.52026 .84362 Mdot
.67554 .4717 Mdot
.46549 .68451 Mdot
.33052 .63348 Mdot
.39631 .54913 Mdot
.64646 .46344 Mdot
.37979 .62643 Mdot
.64353 .21116 Mdot
.24417 .6129 Mdot
.1981 .41871 Mdot
.36669 .53336 Mdot
.56655 .22681 Mdot
.43153 .58061 Mdot
.64582 .60483 Mdot
.43964 .60482 Mdot
.57164 .64588 Mdot
.58444 .5691 Mdot
.51086 .436 Mdot
.22723 .33291 Mdot
.76153 .42957 Mdot
.30599 .39198 Mdot
.44223 .57079 Mdot
.39639 .55031 Mdot
.34926 .40254 Mdot
.58601 .67138 Mdot
.40524 .60879 Mdot
.30595 .43348 Mdot
.41488 .54474 Mdot
.67654 .47681 Mdot
.2004 .47374 Mdot
.64234 .64739 Mdot
.46238 .5626 Mdot
.57755 .68303 Mdot
.6756 .43582 Mdot
.67377 .48518 Mdot
.47168 .54466 Mdot
.69855 .47307 Mdot
.43165 .58857 Mdot
.2049 .56099 Mdot
.56599 .66067 Mdot
.47271 .51772 Mdot
.60388 .67539 Mdot
.41873 .77212 Mdot
.64263 .48365 Mdot
.6763 .38988 Mdot
.44851 .63898 Mdot
.67172 .47232 Mdot
.76436 .4555 Mdot
.45602 .62351 Mdot
.41664 .5076 Mdot
.72449 .2954 Mdot
.49754 .31826 Mdot
.5334 .42641 Mdot
.65633 .49078 Mdot
.40441 .52503 Mdot
.44117 .52849 Mdot
.67627 .43367 Mdot
.39891 .69183 Mdot
.44181 .23862 Mdot
.44593 .58988 Mdot
.57161 .65375 Mdot
.58481 .64909 Mdot
.38067 .52074 Mdot
.38227 .54194 Mdot
.49955 .34454 Mdot
.51617 .29251 Mdot
.53823 .29462 Mdot
.5505 .42517 Mdot
.6897 .38736 Mdot
.73819 .61773 Mdot
.69493 .43962 Mdot
.74875 .54479 Mdot
.67289 .24642 Mdot
.33305 .55655 Mdot
.51802 .30417 Mdot
.39527 .55856 Mdot
.41779 .58756 Mdot
.68151 .48568 Mdot
.73823 .38903 Mdot
.32507 .51817 Mdot
.55706 .65294 Mdot
.65849 .49239 Mdot
.47601 .6215 Mdot
.77383 .56566 Mdot
.32684 .37094 Mdot
.77183 .37591 Mdot
.65442 .47887 Mdot
.60296 .6548 Mdot
.63189 .46451 Mdot
.40407 .54824 Mdot
.35364 .53323 Mdot
.59528 .64556 Mdot
.32742 .36384 Mdot
.42247 .62186 Mdot
.42275 .57299 Mdot
.36726 .17975 Mdot
.57913 .21997 Mdot
.62161 .40625 Mdot
.40222 .60563 Mdot
.44692 .53031 Mdot
.32503 .41661 Mdot
.41052 .5453 Mdot
.4414 .55078 Mdot
.40693 .20049 Mdot
.60176 .43767 Mdot
.34348 .42561 Mdot
.47167 .68857 Mdot
.60084 .61538 Mdot
.5559 .84068 Mdot
.53687 .31737 Mdot
.67298 .50314 Mdot
.45081 .224 Mdot
.48995 .31345 Mdot
.63896 .26198 Mdot
.54181 .84747 Mdot
.53935 .42664 Mdot
.33657 .43819 Mdot
.3237 .5634 Mdot
.45037 .5778 Mdot
.43369 .57702 Mdot
.3296 .39168 Mdot
.59382 .626 Mdot
.46439 .4329 Mdot
.24964 .67542 Mdot
.42316 .58331 Mdot
.51348 .63766 Mdot
.4247 .82412 Mdot
.50073 .41376 Mdot
.32217 .40762 Mdot
.3382 .36167 Mdot
.44016 .57188 Mdot
.42036 .20664 Mdot
.57138 .63116 Mdot
.39182 .53393 Mdot
.37343 .53954 Mdot
.50342 .3095 Mdot
.60689 .64059 Mdot
.49042 .38228 Mdot
.67449 .39167 Mdot
.65011 .73785 Mdot
.38699 .16395 Mdot
.65996 .48877 Mdot
.54279 .80967 Mdot
.69112 .45892 Mdot
.23227 .37666 Mdot
.49107 .30868 Mdot
.36948 .5644 Mdot
.62281 .6555 Mdot
.39078 .53232 Mdot
.38137 .55418 Mdot
.39259 .5449 Mdot
.41282 .62883 Mdot
.58755 .16103 Mdot
.31601 .38471 Mdot
.46442 .56188 Mdot
.50636 .37389 Mdot
.54217 .81534 Mdot
.28046 .7406 Mdot
.40343 .55713 Mdot
.43994 .55909 Mdot
.60317 .66505 Mdot
.44946 .5539 Mdot
.6878 .44954 Mdot
.62389 .64671 Mdot
.4268 .61265 Mdot
.50407 .83279 Mdot
.37286 .59098 Mdot
.62584 .77534 Mdot
.63167 .4667 Mdot
.7599 .46289 Mdot
.46703 .59532 Mdot
.62382 .39698 Mdot
.53317 .42641 Mdot
.53522 .3037 Mdot
.6535 .49957 Mdot
.52906 .33994 Mdot
.22108 .622 Mdot
.34777 .52245 Mdot
.404 .60255 Mdot
.43654 .5249 Mdot
.52474 .30729 Mdot
.66728 .60919 Mdot
.60359 .28019 Mdot
.48715 .61443 Mdot
.50516 .33099 Mdot
.5555 .66819 Mdot
.42378 .39952 Mdot
.61824 .66349 Mdot
.35681 .41961 Mdot
.65133 .45281 Mdot
.31085 .37918 Mdot
.78382 .42578 Mdot
.60008 .63803 Mdot
.62951 .6892 Mdot
.52196 .31336 Mdot
.59088 .49021 Mdot
.84558 .63846 Mdot
.51187 .41691 Mdot
.25518 .44111 Mdot
.56063 .63941 Mdot
.35734 .56414 Mdot
.21943 .41417 Mdot
.59876 .50807 Mdot
.52752 .34404 Mdot
.37755 .57629 Mdot
.38956 .22352 Mdot
.49948 .34288 Mdot
.42606 .52026 Mdot
.48974 .35372 Mdot
.65781 .47559 Mdot
.50043 .32388 Mdot
.57187 .60813 Mdot
.43082 .54752 Mdot
.83152 .6593 Mdot
.291 .3433 Mdot
.43354 .60702 Mdot
.65455 .49154 Mdot
.45901 .46704 Mdot
.38628 .56322 Mdot
.35136 .41103 Mdot
.51445 .334 Mdot
.54501 .3929 Mdot
.44536 .59428 Mdot
.51692 .3141 Mdot
.6085 .68082 Mdot
.65232 .49993 Mdot
.38898 .40276 Mdot
.64933 .39055 Mdot
.56366 .62805 Mdot
.71929 .41484 Mdot
.67272 .49525 Mdot
.45052 .53755 Mdot
.38658 .52735 Mdot
.57745 .65475 Mdot
.30953 .28379 Mdot
.45839 .57617 Mdot
.36681 .56739 Mdot
.50377 .37616 Mdot
.53055 .32588 Mdot
.31929 .27856 Mdot
.48775 .3595 Mdot
.34992 .53422 Mdot
.57667 .65302 Mdot
.40265 .58717 Mdot
.60599 .66002 Mdot
.43944 .54065 Mdot
.52998 .63245 Mdot
.5757 .66899 Mdot
.56499 .26065 Mdot
.38938 .58324 Mdot
.41012 .48395 Mdot
.38685 .54939 Mdot
.41547 .53935 Mdot
.50102 .3508 Mdot
.32259 .40326 Mdot
.48606 .57558 Mdot
.33994 .43172 Mdot
.34166 .41322 Mdot
.61472 .72694 Mdot
.50165 .31285 Mdot
.33924 .38869 Mdot
.33371 .76053 Mdot
.52374 .29581 Mdot
.32608 .3821 Mdot
.30925 .76339 Mdot
.66388 .48928 Mdot
.57402 .61066 Mdot
.4256 .59751 Mdot
.78102 .64891 Mdot
.21777 .55779 Mdot
.49255 .31026 Mdot
.43407 .60783 Mdot
.39287 .56073 Mdot
.5659 .66869 Mdot
.15559 .47518 Mdot
.52789 .37758 Mdot
.3908 .593 Mdot
.60995 .63501 Mdot
.15594 .41681 Mdot
.5144 .37712 Mdot
.32666 .38544 Mdot
.66617 .42873 Mdot
.55468 .6046 Mdot
.58795 .41031 Mdot
.67255 .43049 Mdot
.5847 .29618 Mdot
.77424 .43291 Mdot
.36345 .55559 Mdot
.51868 .30429 Mdot
.78748 .37866 Mdot
.51694 .60239 Mdot
.71289 .42628 Mdot
.29733 .56839 Mdot
.59944 .65395 Mdot
.68594 .44826 Mdot
.30751 .38473 Mdot
.6148 .6237 Mdot
.57772 .66554 Mdot
.68933 .47882 Mdot
.39916 .43865 Mdot
.61071 .53894 Mdot
.67678 .48005 Mdot
.70226 .27414 Mdot
.77395 .62401 Mdot
.52616 .29973 Mdot
.34184 .41143 Mdot
.81542 .52838 Mdot
.5782 .63321 Mdot
.48341 .84138 Mdot
.77461 .36303 Mdot
.44284 .58844 Mdot
.34342 .39047 Mdot
.69396 .62993 Mdot
.23544 .65468 Mdot
.67579 .45127 Mdot
.53649 .43856 Mdot
.3167 .35897 Mdot
.45245 .58271 Mdot
.29241 .60526 Mdot
.37743 .58185 Mdot
.65669 .44667 Mdot
.34898 .7391 Mdot
.60368 .65531 Mdot
.66735 .49407 Mdot
.77228 .37784 Mdot
.42835 .587 Mdot
.38124 .5801 Mdot
.22394 .49261 Mdot
.59201 .61931 Mdot
.53917 .30665 Mdot
.36481 .55586 Mdot
.4233 .57631 Mdot
.41121 .50318 Mdot
.46432 .51253 Mdot
.452 .19693 Mdot
.38959 .59112 Mdot
.71934 .39513 Mdot
.46333 .56423 Mdot
.39064 .58151 Mdot
.57276 .68109 Mdot
.43993 .15116 Mdot
.68411 .39099 Mdot
.42454 .57926 Mdot
.35881 .5707 Mdot
.68943 .48004 Mdot
.57063 .53198 Mdot
.59594 .49544 Mdot
.56547 .4181 Mdot
.2865 .50859 Mdot
.40688 .62801 Mdot
.61872 .64749 Mdot
.33923 .36591 Mdot
.3861 .5203 Mdot
.61781 .64695 Mdot
.38446 .60499 Mdot
.50045 .33715 Mdot
.52167 .29589 Mdot
.73983 .4876 Mdot
.33341 .38381 Mdot
.22017 .53149 Mdot
.74008 .55805 Mdot
.49894 .37866 Mdot
.40818 .60172 Mdot
.65238 .50631 Mdot
.4828 .36072 Mdot
.57705 .41533 Mdot
.45279 .5122 Mdot
.57667 .62432 Mdot
.59213 .66051 Mdot
.25872 .40386 Mdot
.65668 .32039 Mdot
.35926 .19905 Mdot
.65442 .4733 Mdot
.44246 .61255 Mdot
.73361 .52022 Mdot
.59363 .66152 Mdot
.23003 .41165 Mdot
.33938 .38641 Mdot
.67687 .45002 Mdot
.50431 .25896 Mdot
.61106 .65915 Mdot
.56027 .62341 Mdot
.35288 .56311 Mdot
.41594 .56413 Mdot
.29275 .47556 Mdot
.35696 .44695 Mdot
.6794 .43811 Mdot
.34762 .40634 Mdot
.49547 .39502 Mdot
.38051 .58839 Mdot
.59126 .67768 Mdot
.81111 .56384 Mdot
.35875 .56543 Mdot
.49865 .34938 Mdot
.5963 .65331 Mdot
.35166 .39585 Mdot
.34471 .41368 Mdot
.41503 .54036 Mdot
.31611 .69402 Mdot
.68 .46009 Mdot
.59786 .66278 Mdot
.78872 .51718 Mdot
.45939 .56989 Mdot
.42155 .56435 Mdot
.35458 .49025 Mdot
.69327 .46804 Mdot
.74997 .4809 Mdot
.32047 .36255 Mdot
.58762 .63101 Mdot
.38158 .59733 Mdot
.32975 .37657 Mdot
.74634 .49491 Mdot
.50173 .29927 Mdot
.49584 .33297 Mdot
.34975 .41205 Mdot
.34672 .39968 Mdot
.35456 .404 Mdot
.47103 .84465 Mdot
.56663 .60812 Mdot
.46663 .50593 Mdot
.4574 .58921 Mdot
.25156 .40465 Mdot
.48678 .59827 Mdot
.63117 .4735 Mdot
.49397 .32582 Mdot
.38488 .55359 Mdot
.35886 .54928 Mdot
.38809 .48309 Mdot
.44064 .48969 Mdot
.64029 .6449 Mdot
.60349 .63788 Mdot
.3378 .53319 Mdot
.5001 .31051 Mdot
.13534 .54863 Mdot
.72586 .74366 Mdot
.46944 .58855 Mdot
.596 .52333 Mdot
.59255 .67703 Mdot
.69785 .46055 Mdot
.58054 .45022 Mdot
.63347 .45983 Mdot
.58678 .63703 Mdot
.38299 .5891 Mdot
.75186 .55096 Mdot
.34172 .41796 Mdot
.41182 .52908 Mdot
.66546 .44645 Mdot
.41522 .5325 Mdot
.67138 .4303 Mdot
.7182 .67892 Mdot
.65957 .23118 Mdot
.4385 .58835 Mdot
.45537 .53929 Mdot
.29645 .552 Mdot
.40292 .55893 Mdot
.35213 .33364 Mdot
.59354 .67576 Mdot
.30764 .25345 Mdot
.35172 .57191 Mdot
.47865 .75117 Mdot
.46033 .5774 Mdot
.39316 .22778 Mdot
.41747 .56019 Mdot
.48031 .41663 Mdot
.44877 .58459 Mdot
.43569 .54622 Mdot
.6349 .46709 Mdot
.68817 .48085 Mdot
.62812 .67605 Mdot
.53913 .30997 Mdot
.60062 .79563 Mdot
.4232 .57027 Mdot
.6486 .38993 Mdot
.66468 .40067 Mdot
.34521 .4043 Mdot
.58461 .63633 Mdot
.14843 .43444 Mdot
.65009 .43434 Mdot
.48029 .24846 Mdot
.2981 .30363 Mdot
.59111 .40876 Mdot
.57259 .42176 Mdot
.62106 .57883 Mdot
.34176 .37357 Mdot
.45302 .58481 Mdot
.80222 .46296 Mdot
.59028 .22958 Mdot
.4947 .57688 Mdot
.66148 .49608 Mdot
.49633 .77999 Mdot
.81297 .54039 Mdot
.33146 .3563 Mdot
.31173 .37368 Mdot
.66394 .43122 Mdot
.54462 .34732 Mdot
.35411 .60604 Mdot
.33937 .38349 Mdot
.49252 .37046 Mdot
.5285 .29724 Mdot
.48527 .28745 Mdot
.57568 .62952 Mdot
.77174 .39139 Mdot
.70799 .58874 Mdot
.67082 .43173 Mdot
.28319 .35138 Mdot
.56822 .6019 Mdot
.60476 .6083 Mdot
.5325 .3143 Mdot
.50053 .35509 Mdot
.59167 .60854 Mdot
.34458 .55237 Mdot
.36543 .47975 Mdot
.42549 .58208 Mdot
.33016 .39709 Mdot
.4109 .55674 Mdot
.50311 .34111 Mdot
.67138 .45531 Mdot
.50404 .35898 Mdot
.64238 .44041 Mdot
.74556 .6027 Mdot
.39668 .5351 Mdot
.4363 .55114 Mdot
.21433 .55455 Mdot
.61219 .68337 Mdot
.78263 .46552 Mdot
.70555 .38282 Mdot
.51478 .36573 Mdot
.44313 .55245 Mdot
.61285 .67552 Mdot
.35185 .36692 Mdot
.21184 .55217 Mdot
.40036 .52135 Mdot
.59693 .67673 Mdot
.39399 .59756 Mdot
.36812 .78615 Mdot
.55051 .18953 Mdot
.57671 .64396 Mdot
.20882 .35308 Mdot
.37394 .5874 Mdot
.57925 .57724 Mdot
.41708 .5142 Mdot
.28796 .43132 Mdot
.45836 .57267 Mdot
.60596 .61819 Mdot
.41843 .5798 Mdot
.6183 .63003 Mdot
.51052 .38215 Mdot
.69676 .4444 Mdot
.55842 .64274 Mdot
.38202 .52926 Mdot
.57497 .86426 Mdot
.65297 .45436 Mdot
.44152 .57504 Mdot
.64501 .44778 Mdot
.61095 .63091 Mdot
.56308 .62288 Mdot
.23716 .67518 Mdot
.60773 .41753 Mdot
.65938 .47598 Mdot
.39724 .59405 Mdot
.67344 .56964 Mdot
.39517 .58735 Mdot
.27876 .46724 Mdot
.37003 .52117 Mdot
.45833 .56721 Mdot
.23384 .70262 Mdot
.6894 .44789 Mdot
.37453 .19767 Mdot
.25738 .68906 Mdot
.45573 .84275 Mdot
.5416 .61302 Mdot
.33337 .3572 Mdot
.51567 .8437 Mdot
.66649 .39158 Mdot
.50953 .32254 Mdot
.38639 .55235 Mdot
.63847 .62578 Mdot
.68479 .46373 Mdot
.32212 .40148 Mdot
.43898 .58762 Mdot
.49921 .35592 Mdot
.45104 .2451 Mdot
.6834 .42478 Mdot
.57981 .63286 Mdot
.56032 .65846 Mdot
.18406 .36825 Mdot
.3866 .60085 Mdot
.44053 .55406 Mdot
.65433 .44776 Mdot
.5093 .57496 Mdot
.34879 .37962 Mdot
.40209 .23703 Mdot
.658 .47476 Mdot
.56753 .48224 Mdot
.60045 .63078 Mdot
.39348 .55939 Mdot
.6743 .6346 Mdot
.49189 .26589 Mdot
.5155 .69167 Mdot
.32599 .39015 Mdot
.27357 .47413 Mdot
.60501 .61752 Mdot
.66442 .45454 Mdot
.65999 .34212 Mdot
.37264 .4962 Mdot
.39673 .5645 Mdot
.26856 .47517 Mdot
.43285 .43717 Mdot
.19617 .42854 Mdot
.41936 .51974 Mdot
.44452 .43457 Mdot
.42627 .52743 Mdot
.39031 .4976 Mdot
.35006 .53916 Mdot
.42619 .56168 Mdot
.59536 .67683 Mdot
.48327 .54706 Mdot
.51164 .31571 Mdot
.37229 .66996 Mdot
.56376 .4393 Mdot
.44212 .59989 Mdot
.38512 .58687 Mdot
.5467 .72779 Mdot
.6586 .40763 Mdot
.56879 .65841 Mdot
.58759 .69581 Mdot
.70119 .46407 Mdot
.38453 .48014 Mdot
.53929 .32602 Mdot
.47041 .53108 Mdot
.50355 .35248 Mdot
.60548 .67681 Mdot
.51565 .36921 Mdot
.69378 .43317 Mdot
.51723 .30298 Mdot
.6969 .38679 Mdot
.68718 .45378 Mdot
.58207 .61806 Mdot
.4221 .54628 Mdot
.65915 .49204 Mdot
.22852 .49111 Mdot
.33026 .39633 Mdot
.23878 .68061 Mdot
.37824 .59959 Mdot
.59232 .43501 Mdot
.46131 .48602 Mdot
.50468 .35699 Mdot
.49497 .18536 Mdot
.57345 .6673 Mdot
.35733 .4135 Mdot
.60641 .67744 Mdot
.73367 .28936 Mdot
.33139 .40786 Mdot
.31784 .77077 Mdot
.68609 .32857 Mdot
.54398 .37681 Mdot
.34453 .55699 Mdot
.30807 .61655 Mdot
.49101 .39509 Mdot
.68502 .46209 Mdot
.66891 .31625 Mdot
.43311 .54318 Mdot
.53918 .22224 Mdot
.63031 .67601 Mdot
.53367 .30549 Mdot
.66251 .46244 Mdot
.66926 .49227 Mdot
.38293 .5355 Mdot
.34963 .28277 Mdot
.41737 .52544 Mdot
.64038 .31441 Mdot
.28229 .4999 Mdot
.33375 .49918 Mdot
.44536 .57395 Mdot
.52609 .37059 Mdot
.39487 .59757 Mdot
.32237 .49678 Mdot
.80011 .42646 Mdot
.41999 .62768 Mdot
.73067 .38852 Mdot
.29008 .34954 Mdot
.59681 .6418 Mdot
.4709 .59795 Mdot
.60239 .40427 Mdot
.38702 .59885 Mdot
.77865 .28645 Mdot
.32681 .38024 Mdot
.61876 .38994 Mdot
.46176 .56477 Mdot
.37455 .54382 Mdot
.33749 .62378 Mdot
.63006 .60776 Mdot
.49935 .25732 Mdot
.40279 .56824 Mdot
.26421 .53711 Mdot
.64493 .4606 Mdot
.41177 .52242 Mdot
.43621 .57639 Mdot
.62545 .73172 Mdot
.68592 .47896 Mdot
.50776 .3659 Mdot
.48892 .31232 Mdot
.50458 .40278 Mdot
.31074 .41106 Mdot
.54883 .45135 Mdot
.24163 .40968 Mdot
.56532 .20351 Mdot
.35205 .37564 Mdot
.36388 .58543 Mdot
.31147 .54315 Mdot
.36243 .57282 Mdot
.30682 .38753 Mdot
.68982 .47229 Mdot
.56655 .65763 Mdot
.7038 .52304 Mdot
.49146 .40165 Mdot
.43105 .52326 Mdot
.31776 .40815 Mdot
.57692 .62157 Mdot
.35871 .3603 Mdot
.5931 .63586 Mdot
.6628 .47375 Mdot
.6983 .47972 Mdot
.3148 .39692 Mdot
.61491 .66873 Mdot
.72079 .40683 Mdot
.24469 .65824 Mdot
.36674 .52115 Mdot
.71309 .48788 Mdot
.61631 .67902 Mdot
.63622 .64387 Mdot
.63015 .659 Mdot
.40935 .53517 Mdot
.59202 .5237 Mdot
.42529 .50653 Mdot
.67591 .43699 Mdot
.49031 .35456 Mdot
.29653 .42073 Mdot
.77507 .60641 Mdot
.28661 .40227 Mdot
.41855 .61912 Mdot
.42298 .58573 Mdot
.44013 .5723 Mdot
.36027 .53699 Mdot
.63654 .33081 Mdot
.38752 .53909 Mdot
.63517 .46115 Mdot
.50999 .34091 Mdot
.45095 .59601 Mdot
.49766 .30403 Mdot
.63256 .57027 Mdot
.33884 .36467 Mdot
.53836 .44645 Mdot
.57468 .84061 Mdot
.57144 .62361 Mdot
.48697 .35918 Mdot
.5113 .32132 Mdot
.35634 .39239 Mdot
.68234 .46659 Mdot
.5952 .63088 Mdot
.30141 .44062 Mdot
.35172 .40543 Mdot
.42068 .57865 Mdot
.54937 .26508 Mdot
.52339 .23149 Mdot
.45393 .56899 Mdot
.37771 .56241 Mdot
.50905 .29127 Mdot
.54325 .35574 Mdot
.84833 .51188 Mdot
.2098 .43204 Mdot
.31825 .40076 Mdot
.32724 .36498 Mdot
.6182 .61697 Mdot
.46331 .5458 Mdot
.67289 .43581 Mdot
.19898 .48636 Mdot
.44695 .45604 Mdot
.21351 .5175 Mdot
.39155 .4006 Mdot
.39339 .52614 Mdot
.32691 .6742 Mdot
.42908 .58827 Mdot
.57233 .66989 Mdot
.60319 .62377 Mdot
.56414 .6448 Mdot
.68294 .45814 Mdot
.43831 .77922 Mdot
.6376 .47186 Mdot
.60981 .81939 Mdot
.60299 .61512 Mdot
.62509 .35759 Mdot
.52847 .36029 Mdot
.46395 .60413 Mdot
.35025 .38686 Mdot
.64294 .42638 Mdot
.3654 .61006 Mdot
.43173 .20122 Mdot
.52118 .30808 Mdot
.58311 .61717 Mdot
.62002 .58005 Mdot
.69156 .74239 Mdot
.58388 .47029 Mdot
.46901 .62924 Mdot
.32146 .61767 Mdot
.34373 .40717 Mdot
.50865 .68739 Mdot
.30458 .39095 Mdot
.6717 .44538 Mdot
.43276 .55092 Mdot
.42623 .55329 Mdot
.43655 .53656 Mdot
.3906 .53815 Mdot
.69676 .47276 Mdot
.44709 .61653 Mdot
.67269 .21419 Mdot
.52147 .29481 Mdot
.39839 .80219 Mdot
.33315 .37336 Mdot
.65345 .4972 Mdot
.50827 .34279 Mdot
.53579 .28322 Mdot
.22095 .44637 Mdot
.44636 .58789 Mdot
.38499 .55154 Mdot
.4873 .25257 Mdot
.42458 .52236 Mdot
.47193 .6216 Mdot
.51476 .31633 Mdot
.29019 .40912 Mdot
.35481 .3763 Mdot
.3133 .37592 Mdot
.68398 .47764 Mdot
.61184 .67342 Mdot
.33549 .39171 Mdot
.51012 .38078 Mdot
.39511 .61117 Mdot
.3706 .5403 Mdot
.61832 .67858 Mdot
.77369 .35781 Mdot
.32817 .35617 Mdot
.61686 .57421 Mdot
.61868 .6351 Mdot
.56209 .60852 Mdot
.39604 .56586 Mdot
.49433 .56988 Mdot
.61428 .60418 Mdot
.35932 .39925 Mdot
.65888 .49829 Mdot
.56256 .40452 Mdot
.66453 .44233 Mdot
.58999 .62429 Mdot
.37227 .53271 Mdot
.59253 .62179 Mdot
.40789 .60756 Mdot
.43337 .88467 Mdot
.4234 .55689 Mdot
.59318 .20029 Mdot
.27349 .43602 Mdot
.51571 .32536 Mdot
.71883 .40432 Mdot
.5328 .31076 Mdot
.61554 .63017 Mdot
.3799 .52641 Mdot
.31891 .3648 Mdot
.40624 .83268 Mdot
.57603 .6004 Mdot
.50013 .33303 Mdot
.54169 .33101 Mdot
.68984 .45585 Mdot
.45153 .59742 Mdot
.39704 .56035 Mdot
.52714 .32586 Mdot
.36064 .46838 Mdot
.60969 .66521 Mdot
.44159 .55956 Mdot
.40569 .58327 Mdot
.51669 .32278 Mdot
.24131 .64799 Mdot
.5961 .58727 Mdot
.43237 .5576 Mdot
.67247 .36474 Mdot
.63311 .47809 Mdot
.34994 .54963 Mdot
.4574 .61451 Mdot
.34637 .39129 Mdot
.45838 .81511 Mdot
.80458 .44023 Mdot
.63009 .46827 Mdot
.53835 .31606 Mdot
.3804 .59849 Mdot
.52957 .35695 Mdot
.37574 .53546 Mdot
.55735 .79391 Mdot
.53004 .30114 Mdot
.37042 .55429 Mdot
.46967 .57288 Mdot
.59618 .6195 Mdot
.38412 .5393 Mdot
.57245 .73163 Mdot
.48808 .38278 Mdot
.37551 .54717 Mdot
.32024 .69671 Mdot
.66582 .48471 Mdot
.4705 .58929 Mdot
.32597 .36922 Mdot
.29703 .43331 Mdot
.73628 .5714 Mdot
.66672 .38347 Mdot
.3184 .37334 Mdot
.41764 .53192 Mdot
.54424 .32653 Mdot
.66859 .43019 Mdot
.52959 .21359 Mdot
.4455 .55246 Mdot
.65622 .44796 Mdot
.66966 .45674 Mdot
.32186 .37599 Mdot
.30469 .23038 Mdot
.45498 .6138 Mdot
.40459 .55722 Mdot
.59576 .73903 Mdot
.56044 .66928 Mdot
.41349 .5543 Mdot
.35812 .57362 Mdot
.63705 .45741 Mdot
.45675 .63718 Mdot
.52425 .75978 Mdot
.36423 .25463 Mdot
.63785 .43865 Mdot
.52333 .41339 Mdot
.54402 .31397 Mdot
.33566 .37521 Mdot
.59273 .64719 Mdot
.30766 .3657 Mdot
.50659 .31083 Mdot
.36573 .58482 Mdot
.64967 .43734 Mdot
.54093 .68793 Mdot
.6718 .42854 Mdot
.64507 .38709 Mdot
.59682 .68242 Mdot
.71481 .53417 Mdot
.70217 .21387 Mdot
.71261 .59509 Mdot
.64065 .4159 Mdot
.34523 .4041 Mdot
.58103 .2949 Mdot
.41117 .58419 Mdot
.4817 .67726 Mdot
.42045 .5419 Mdot
.33001 .69814 Mdot
.48835 .35596 Mdot
.53954 .29499 Mdot
.43221 .55342 Mdot
.28183 .49029 Mdot
.67925 .43001 Mdot
.68845 .44841 Mdot
.37783 .54938 Mdot
.67162 .47269 Mdot
.41346 .56556 Mdot
.50233 .34836 Mdot
.41831 .18029 Mdot
.43309 .58348 Mdot
.42296 .5097 Mdot
.62256 .50997 Mdot
.24974 .70779 Mdot
.70923 .35872 Mdot
.32657 .66796 Mdot
.71487 .72124 Mdot
.67117 .47209 Mdot
.46198 .52963 Mdot
.5127 .41842 Mdot
.50764 .29178 Mdot
.7204 .40743 Mdot
.41367 .54801 Mdot
.40995 .5443 Mdot
.44359 .55488 Mdot
.38038 .58032 Mdot
.48794 .68053 Mdot
.5034 .56623 Mdot
.37365 .72456 Mdot
.38226 .55254 Mdot
.29368 .61419 Mdot
.6562 .49029 Mdot
.62138 .6895 Mdot
.30647 .36349 Mdot
.39222 .52714 Mdot
.51706 .61488 Mdot
.63689 .48425 Mdot
.61228 .818 Mdot
.69043 .46606 Mdot
.51715 .35681 Mdot
.69749 .45129 Mdot
.42663 .60699 Mdot
.58468 .64989 Mdot
.56052 .41902 Mdot
.58977 .25682 Mdot
.50871 .32344 Mdot
.43373 .607 Mdot
.60847 .39116 Mdot
.50872 .32012 Mdot
.63788 .57083 Mdot
.58869 .65291 Mdot
.25858 .53861 Mdot
.60312 .62332 Mdot
.36977 .55333 Mdot
.36654 .56061 Mdot
.72621 .4417 Mdot
.68768 .43196 Mdot
.60807 .62604 Mdot
.35218 .18579 Mdot
.3039 .39143 Mdot
.56608 .64236 Mdot
.34939 .50987 Mdot
.52293 .50102 Mdot
.58236 .65586 Mdot
.32802 .46625 Mdot
.68564 .45683 Mdot
.6075 .61434 Mdot
.34971 .5078 Mdot
.7273 .32033 Mdot
.35413 .41296 Mdot
.53531 .36753 Mdot
.46462 .3765 Mdot
.4844 .36978 Mdot
.66835 .49888 Mdot
.52485 .31068 Mdot
.64361 .46579 Mdot
.77617 .46826 Mdot
.2785 .62148 Mdot
.6537 .5076 Mdot
.68432 .49172 Mdot
.52121 .31423 Mdot
.44711 .568 Mdot
.47531 .37643 Mdot
.39087 .51049 Mdot
.34972 .59293 Mdot
.64669 .47479 Mdot
.60246 .61717 Mdot
.56828 .6116 Mdot
.29855 .61388 Mdot
.56055 .65938 Mdot
.50234 .35357 Mdot
.5559 .19345 Mdot
.78379 .431 Mdot
.64798 .45968 Mdot
.69064 .48349 Mdot
.39208 .58731 Mdot
.5285 .3419 Mdot
.51515 .38457 Mdot
.67898 .44485 Mdot
.46512 .66079 Mdot
.45268 .52658 Mdot
.6372 .66877 Mdot
.60084 .61359 Mdot
.57603 .64884 Mdot
.62931 .64943 Mdot
.51116 .74201 Mdot
.68601 .45529 Mdot
.60987 .62108 Mdot
.37349 .55297 Mdot
.41038 .54571 Mdot
.56483 .42083 Mdot
.31559 .37373 Mdot
.39173 .60743 Mdot
.34601 .54079 Mdot
.3932 .56431 Mdot
.4976 .33013 Mdot
.33056 .53172 Mdot
.53868 .30489 Mdot
.53231 .37359 Mdot
.50957 .2977 Mdot
.67181 .39022 Mdot
.31053 .60459 Mdot
.73938 .70922 Mdot
.39069 .59317 Mdot
.5103 .56169 Mdot
.52669 .36084 Mdot
.46908 .18974 Mdot
.74307 .49291 Mdot
.44412 .5524 Mdot
.48842 .27125 Mdot
.52757 .32277 Mdot
.55369 .65048 Mdot
.41673 .55066 Mdot
.4946 .40772 Mdot
.34198 .36769 Mdot
.35724 .50981 Mdot
.48118 .34147 Mdot
.61853 .66019 Mdot
.29679 .3793 Mdot
.61482 .61954 Mdot
.50153 .30495 Mdot
.47024 .57763 Mdot
.85809 .62423 Mdot
.5029 .40064 Mdot
.31843 .75536 Mdot
.54904 .59813 Mdot
.44265 .56014 Mdot
.48659 .36508 Mdot
.56102 .66871 Mdot
.66287 .50036 Mdot
.4799 .45207 Mdot
.56562 .65985 Mdot
.53912 .29508 Mdot
.48086 .35106 Mdot
.51362 .31742 Mdot
.60395 .64248 Mdot
.38829 .51613 Mdot
.60828 .6514 Mdot
.69704 .45284 Mdot
.41973 .59242 Mdot
.64697 .7765 Mdot
.50744 .56154 Mdot
.61492 .63085 Mdot
.50136 .36647 Mdot
.33013 .4184 Mdot
.43656 .59213 Mdot
.29859 .72934 Mdot
.42513 .61154 Mdot
.64915 .44991 Mdot
.3662 .22578 Mdot
.53905 .68942 Mdot
.45845 .58423 Mdot
.39055 .58679 Mdot
.6839 .44192 Mdot
.44363 .5896 Mdot
.45766 .58095 Mdot
.64021 .40105 Mdot
.6081 .63926 Mdot
.41596 .58115 Mdot
.49626 .37085 Mdot
.79584 .47504 Mdot
.44132 .51578 Mdot
.43233 .28092 Mdot
.26369 .51889 Mdot
.33976 .23008 Mdot
.42432 .54241 Mdot
.20649 .46316 Mdot
.37678 .57412 Mdot
.40668 .52904 Mdot
.39769 .59154 Mdot
.33159 .66376 Mdot
.51679 .30734 Mdot
.50623 .33424 Mdot
.35588 .41078 Mdot
.26417 .52337 Mdot
.34413 .38939 Mdot
.6871 .46607 Mdot
.40782 .29242 Mdot
.52895 .30136 Mdot
.61917 .66045 Mdot
.41879 .52938 Mdot
.49624 .40257 Mdot
.39314 .55645 Mdot
.42078 .6077 Mdot
.52813 .37042 Mdot
.52255 .38444 Mdot
.63269 .39188 Mdot
.33264 .36555 Mdot
.5613 .64607 Mdot
.35302 .5849 Mdot
.34 .41325 Mdot
.38966 .51679 Mdot
.24733 .39651 Mdot
.56366 .64944 Mdot
.60884 .64223 Mdot
.55452 .62608 Mdot
.36667 .58567 Mdot
.43594 .60222 Mdot
.63816 .4716 Mdot
.61682 .66872 Mdot
.66999 .48289 Mdot
.5525 .42178 Mdot
.41986 .27372 Mdot
.41352 .54787 Mdot
.59222 .56992 Mdot
.34525 .38194 Mdot
.51252 .3527 Mdot
.46227 .25188 Mdot
.35061 .41807 Mdot
.42262 .61071 Mdot
.52733 .36859 Mdot
.30915 .38837 Mdot
.42568 .65575 Mdot
.78921 .65803 Mdot
.31793 .41268 Mdot
.37491 .55292 Mdot
.38841 .64302 Mdot
.23376 .60667 Mdot
.31169 .41062 Mdot
.65006 .44081 Mdot
.36702 .58688 Mdot
.47311 .50419 Mdot
.32416 .35719 Mdot
.78816 .48572 Mdot
.51747 .3297 Mdot
.74526 .36266 Mdot
.33598 .57967 Mdot
.44547 .67474 Mdot
.30402 .3742 Mdot
.59163 .63091 Mdot
.583 .68692 Mdot
.39078 .57141 Mdot
.30668 .4057 Mdot
.64789 .43148 Mdot
.51677 .33587 Mdot
.70255 .38995 Mdot
.60451 .64514 Mdot
.6479 .54991 Mdot
.49286 .35564 Mdot
.60716 .56652 Mdot
.37375 .23741 Mdot
.34322 .48776 Mdot
.29872 .65439 Mdot
.61164 .23933 Mdot
.35813 .58038 Mdot
.30832 .39966 Mdot
.63557 .47985 Mdot
.65734 .43262 Mdot
.65708 .47236 Mdot
.71673 .40118 Mdot
.57406 .44722 Mdot
.49167 .31975 Mdot
.56631 .24515 Mdot
.33125 .3774 Mdot
.25649 .57388 Mdot
.39421 .51789 Mdot
.42517 .58551 Mdot
.44052 .61297 Mdot
.41204 .52055 Mdot
.38468 .57612 Mdot
.67856 .47126 Mdot
.71744 .39988 Mdot
.54735 .39268 Mdot
.57314 .65618 Mdot
.28816 .40117 Mdot
.52823 .36077 Mdot
.51386 .29085 Mdot
.31654 .39121 Mdot
.63811 .59241 Mdot
.48607 .33108 Mdot
.51411 .36831 Mdot
.42203 .61435 Mdot
.61179 .65671 Mdot
.48623 .55698 Mdot
.36739 .56822 Mdot
.50947 .34973 Mdot
.41461 .40059 Mdot
.54691 .74663 Mdot
.39651 .49158 Mdot
.2981 .35813 Mdot
.58048 .5221 Mdot
.3112 .40941 Mdot
.41152 .51111 Mdot
.45343 .19078 Mdot
.50794 .31013 Mdot
.52319 .35143 Mdot
.3105 .39939 Mdot
.58458 .58072 Mdot
.59807 .65051 Mdot
.5369 .28307 Mdot
.64302 .4542 Mdot
.36252 .56661 Mdot
.43583 .25604 Mdot
.56031 .5822 Mdot
.37138 .27712 Mdot
.65193 .46767 Mdot
.51788 .3807 Mdot
.45327 .59545 Mdot
.37506 .55449 Mdot
.34745 .40437 Mdot
.6995 .68861 Mdot
.34896 .51925 Mdot
.45933 .84394 Mdot
.6726 .23998 Mdot
.75093 .33786 Mdot
.39693 .56444 Mdot
.6062 .63853 Mdot
.49105 .30893 Mdot
.34319 .41052 Mdot
.39914 .61657 Mdot
.77389 .67543 Mdot
.61814 .68555 Mdot
.66796 .44871 Mdot
.51523 .42241 Mdot
.58107 .44951 Mdot
.39107 .60414 Mdot
.42029 .54292 Mdot
.40224 .53497 Mdot
.83394 .57335 Mdot
.49555 .34089 Mdot
.58763 .67809 Mdot
.324 .39074 Mdot
.56317 .66207 Mdot
.51018 .32922 Mdot
.68013 .54394 Mdot
.44674 .59506 Mdot
.61806 .68416 Mdot
.59045 .63364 Mdot
.68993 .45724 Mdot
.67232 .49925 Mdot
.54167 .41324 Mdot
.42319 .5582 Mdot
.4821 .38062 Mdot
.59402 .61779 Mdot
.52668 .26954 Mdot
.33402 .40838 Mdot
.64548 .48515 Mdot
.38319 .55096 Mdot
.50836 .3138 Mdot
.44465 .61866 Mdot
.58914 .6628 Mdot
.51502 .36834 Mdot
.62889 .3941 Mdot
.32658 .36591 Mdot
.39827 .54491 Mdot
.30809 .35175 Mdot
.53835 .31854 Mdot
.40732 .58428 Mdot
.64473 .61055 Mdot
.29209 .38367 Mdot
.6024 .27417 Mdot
.49 .32716 Mdot
.64359 .39178 Mdot
.55808 .62302 Mdot
.7798 .50258 Mdot
.52117 .35071 Mdot
.64991 .6152 Mdot
.73399 .6412 Mdot
.35428 .58835 Mdot
.57643 .63669 Mdot
.56659 .28284 Mdot
.53344 .85943 Mdot
.26085 .65948 Mdot
.44049 .5754 Mdot
.48644 .35256 Mdot
.31837 .40672 Mdot
.64753 .46078 Mdot
.43292 .27889 Mdot
.32215 .49788 Mdot
.53664 .34707 Mdot
.39297 .59062 Mdot
.60609 .62868 Mdot
.67892 .45396 Mdot
.75574 .56195 Mdot
.50621 .37692 Mdot
.48947 .34657 Mdot
.45469 .59233 Mdot
.33824 .38592 Mdot
.2924 .6961 Mdot
.50134 .34422 Mdot
.4941 .25162 Mdot
.58485 .29384 Mdot
.31766 .40863 Mdot
.37539 .56715 Mdot
.29624 .60478 Mdot
.35638 .54185 Mdot
.33788 .77674 Mdot
.53584 .31554 Mdot
.57627 .66072 Mdot
.41773 .5372 Mdot
.35113 .26038 Mdot
.51256 .34681 Mdot
.5971 .52224 Mdot
.41657 .37444 Mdot
.68549 .45542 Mdot
.4678 .24779 Mdot
.40628 .55301 Mdot
.67661 .42909 Mdot
.34525 .38249 Mdot
.43069 .56137 Mdot
.4338 .60232 Mdot
.55838 .66286 Mdot
.6718 .44399 Mdot
.75169 .64881 Mdot
.66992 .49364 Mdot
.6319 .46603 Mdot
.5484 .62823 Mdot
.40592 .57413 Mdot
.51526 .35946 Mdot
.52874 .32454 Mdot
.36652 .60391 Mdot
.48424 .17633 Mdot
.60028 .65095 Mdot
.28409 .34945 Mdot
.83681 .55178 Mdot
.3296 .50955 Mdot
.45871 .25164 Mdot
.69739 .68842 Mdot
.65023 .43069 Mdot
.3795 .55057 Mdot
.62 .64584 Mdot
.54026 .2845 Mdot
.49267 .35888 Mdot
.37725 .52458 Mdot
.67338 .45839 Mdot
.35017 .37557 Mdot
.49914 .39566 Mdot
.3515 .28138 Mdot
.39648 .53267 Mdot
.55048 .23338 Mdot
.48933 .37709 Mdot
.43942 .85563 Mdot
.53835 .27349 Mdot
.57402 .64 Mdot
.42102 .6066 Mdot
.55914 .65584 Mdot
.32659 .39698 Mdot
.52877 .41614 Mdot
.67243 .45644 Mdot
.32117 .51852 Mdot
.77451 .30153 Mdot
.52051 .3105 Mdot
.59275 .67599 Mdot
.4587 .58446 Mdot
.31584 .56515 Mdot
.40917 .55817 Mdot
.39072 .64052 Mdot
.29351 .34522 Mdot
.65092 .47933 Mdot
.64957 .44631 Mdot
.41362 .58708 Mdot
.35403 .3924 Mdot
.51917 .37803 Mdot
.5177 .33768 Mdot
.18992 .67854 Mdot
.52234 .26703 Mdot
.2943 .46941 Mdot
.40608 .54387 Mdot
.54211 .29923 Mdot
.79253 .57593 Mdot
.65335 .44915 Mdot
.40158 .51594 Mdot
.54074 .32064 Mdot
.69707 .27964 Mdot
.27248 .39715 Mdot
.38232 .57343 Mdot
.42414 .63123 Mdot
.64439 .45068 Mdot
.22858 .52592 Mdot
.50249 .30548 Mdot
.37659 .51657 Mdot
.70294 .45044 Mdot
.32904 .26428 Mdot
.79165 .39901 Mdot
.56137 .64563 Mdot
.50394 .41036 Mdot
.67923 .47073 Mdot
.33457 .56702 Mdot
.33027 .37232 Mdot
.48966 .38955 Mdot
.49951 .32963 Mdot
.40509 .59661 Mdot
.45011 .61283 Mdot
.30029 .55685 Mdot
.59135 .6739 Mdot
.66325 .49035 Mdot
.43232 .54716 Mdot
.64036 .54275 Mdot
.4321 .53249 Mdot
.64408 .48063 Mdot
.83139 .69015 Mdot
.3431 .57222 Mdot
.40775 .55935 Mdot
.28699 .69259 Mdot
.56351 .65793 Mdot
.55755 .65762 Mdot
.61883 .2123 Mdot
.40533 .5439 Mdot
.48607 .24446 Mdot
.55965 .64417 Mdot
.59868 .65471 Mdot
.59957 .36293 Mdot
.43455 .58828 Mdot
.21362 .54395 Mdot
.66549 .4325 Mdot
.63555 .45374 Mdot
.60703 .65042 Mdot
.33692 .53965 Mdot
.6538 .43038 Mdot
.50253 .70283 Mdot
.52915 .34102 Mdot
.43863 .19224 Mdot
.59107 .66616 Mdot
.52247 .43363 Mdot
.64992 .46015 Mdot
.60571 .82165 Mdot
.49635 .27024 Mdot
.44475 .56193 Mdot
.3977 .54181 Mdot
.34252 .37814 Mdot
.35209 .58479 Mdot
.53821 .29421 Mdot
.6717 .47301 Mdot
.32958 .73756 Mdot
.56426 .6437 Mdot
.4197 .56118 Mdot
.62481 .57219 Mdot
.74713 .58838 Mdot
.69993 .33399 Mdot
.59604 .64155 Mdot
.57496 .63179 Mdot
.49904 .31072 Mdot
.4884 .36225 Mdot
.39709 .57404 Mdot
.67812 .43979 Mdot
.62082 .66025 Mdot
.64391 .47756 Mdot
.50627 .31204 Mdot
.51254 .36413 Mdot
.52954 .30018 Mdot
.38437 .50951 Mdot
.50749 .37236 Mdot
.33465 .28723 Mdot
.65604 .5515 Mdot
.60663 .60879 Mdot
.80392 .36766 Mdot
.7566 .55949 Mdot
.43796 .46705 Mdot
.31766 .36381 Mdot
.53828 .32008 Mdot
.69609 .46973 Mdot
.39376 .58609 Mdot
.38852 .55396 Mdot
.49647 .40898 Mdot
.69145 .44249 Mdot
.32425 .4012 Mdot
.689 .43664 Mdot
.32284 .37431 Mdot
.50405 .25645 Mdot
.44967 .60097 Mdot
.36826 .5462 Mdot
.67367 .47524 Mdot
.51199 .37108 Mdot
.50907 .33842 Mdot
.30922 .40571 Mdot
.42772 .44348 Mdot
.51173 .31637 Mdot
.59076 .66535 Mdot
.49745 .73828 Mdot
.48345 .33074 Mdot
.41539 .55208 Mdot
.23842 .40648 Mdot
.49154 .67172 Mdot
.365 .53021 Mdot
.59986 .40649 Mdot
.18332 .4224 Mdot
.42357 .53592 Mdot
.18924 .39138 Mdot
.64682 .39144 Mdot
.56657 .66165 Mdot
.48741 .34792 Mdot
.53628 .28573 Mdot
.45862 .63073 Mdot
.37132 .39269 Mdot
.37952 .60876 Mdot
.55841 .65015 Mdot
.56574 .67801 Mdot
.71806 .28951 Mdot
.32023 .75786 Mdot
.3046 .38638 Mdot
.31342 .38679 Mdot
.52171 .34648 Mdot
.20481 .62727 Mdot
.38531 .4943 Mdot
.31929 .40058 Mdot
.26773 .61049 Mdot
.3864 .58934 Mdot
.26641 .46494 Mdot
.48106 .27358 Mdot
.60591 .6423 Mdot
.30492 .61414 Mdot
.51729 .34969 Mdot
.58343 .67192 Mdot
.67833 .532 Mdot
.38806 .60483 Mdot
.56436 .64884 Mdot
.6403 .47267 Mdot
.64097 .26606 Mdot
.56251 .62437 Mdot
.24068 .39748 Mdot
.67958 .4441 Mdot
.59472 .3155 Mdot
.26612 .5723 Mdot
.61937 .14392 Mdot
.67776 .4687 Mdot
.53266 .35745 Mdot
.52803 .3247 Mdot
.51888 .33727 Mdot
.57673 .67037 Mdot
.51871 .38309 Mdot
.59688 .67427 Mdot
.2305 .61726 Mdot
.42717 .44417 Mdot
.31525 .39834 Mdot
.61011 .41843 Mdot
.58384 .63096 Mdot
.53097 .19252 Mdot
.72264 .23575 Mdot
.38009 .54671 Mdot
.68081 .48892 Mdot
.3082 .39105 Mdot
.38743 .83239 Mdot
.34557 .3867 Mdot
.50495 .41407 Mdot
.39948 .1999 Mdot
.41857 .56668 Mdot
.50602 .78645 Mdot
.31845 .36616 Mdot
.5987 .6317 Mdot
.41364 .58515 Mdot
.72276 .41297 Mdot
.3393 .38115 Mdot
.34811 .3742 Mdot
.39842 .57847 Mdot
.58396 .61708 Mdot
.51178 .35963 Mdot
.70048 .45089 Mdot
.34084 .42646 Mdot
.52345 .59291 Mdot
.35119 .57621 Mdot
.3717 .59384 Mdot
.59412 .4959 Mdot
.31592 .49917 Mdot
.67167 .47138 Mdot
.24252 .59966 Mdot
.48873 .36111 Mdot
.5757 .32454 Mdot
.6298 .22045 Mdot
.60705 .41124 Mdot
.53263 .31255 Mdot
.53659 .31212 Mdot
.38743 .57507 Mdot
.31065 .50358 Mdot
.34915 .23399 Mdot
.61725 .43876 Mdot
.48738 .31884 Mdot
.51563 .33858 Mdot
.59096 .68785 Mdot
.72111 .28772 Mdot
.4066 .61947 Mdot
.62851 .46078 Mdot
.50621 .31718 Mdot
.56056 .79318 Mdot
.33429 .38553 Mdot
.49333 .19309 Mdot
.45193 .59402 Mdot
.43662 .55164 Mdot
.66242 .46668 Mdot
.63679 .47055 Mdot
.73225 .44643 Mdot
.69388 .25715 Mdot
.19073 .50014 Mdot
.78363 .53961 Mdot
.5611 .78789 Mdot
.61785 .68963 Mdot
.61384 .6296 Mdot
.68592 .39318 Mdot
.65438 .4938 Mdot
.41935 .53557 Mdot
.6206 .65836 Mdot
.67721 .3161 Mdot
.55042 .67658 Mdot
.27882 .47131 Mdot
.40407 .25224 Mdot
.41593 .60953 Mdot
.61474 .64997 Mdot
.57154 .66309 Mdot
.62555 .65301 Mdot
.6471 .39192 Mdot
.40309 .56775 Mdot
.44594 .58031 Mdot
.43024 .53567 Mdot
.50584 .58974 Mdot
.38954 .53566 Mdot
.61495 .43355 Mdot
.57101 .48887 Mdot
.39301 .78655 Mdot
.36009 .53035 Mdot
.64273 .43852 Mdot
.36729 .59406 Mdot
.35445 .39113 Mdot
.3954 .58997 Mdot
.28248 .46691 Mdot
.6582 .45199 Mdot
.56768 .58858 Mdot
.78186 .53264 Mdot
.44893 .59502 Mdot
.35209 .37454 Mdot
.44728 .48175 Mdot
.71495 .68504 Mdot
.35779 .44473 Mdot
.59193 .66525 Mdot
.53239 .3313 Mdot
.696 .45689 Mdot
.51767 .36121 Mdot
.36573 .51911 Mdot
.59429 .40912 Mdot
.69148 .62041 Mdot
.51182 .42953 Mdot
.39933 .52287 Mdot
.33594 .50989 Mdot
.59573 .6611 Mdot
.52766 .36771 Mdot
.63828 .68452 Mdot
.41136 .53665 Mdot
.32745 .39289 Mdot
.33641 .37822 Mdot
.74384 .47245 Mdot
.59987 .78894 Mdot
.77499 .4913 Mdot
.66387 .46883 Mdot
.49983 .34298 Mdot
.30245 .37653 Mdot
.52106 .56709 Mdot
.63812 .49224 Mdot
.68543 .44302 Mdot
.67583 .44633 Mdot
.36541 .58064 Mdot
.53891 .30494 Mdot
.38307 .77622 Mdot
.53888 .29614 Mdot
.44173 .59828 Mdot
.49426 .34131 Mdot
.53417 .30517 Mdot
.33786 .37357 Mdot
.6849 .47699 Mdot
.50138 .31549 Mdot
.36987 .55206 Mdot
.5651 .62897 Mdot
.45735 .43866 Mdot
.27275 .41949 Mdot
.37253 .79872 Mdot
.39681 .8097 Mdot
.57998 .61255 Mdot
.58355 .81759 Mdot
.62761 .45001 Mdot
.46206 .66152 Mdot
.64873 .371 Mdot
.36772 .53729 Mdot
.55519 .18213 Mdot
.49252 .31746 Mdot
.5296 .36676 Mdot
.37393 .56883 Mdot
.53799 .37176 Mdot
.41615 .56068 Mdot
.49299 .33454 Mdot
.29311 .409 Mdot
.4659 .61265 Mdot
.51409 .37627 Mdot
.39975 .50578 Mdot
.43292 .59306 Mdot
.60738 .64254 Mdot
.48612 .36659 Mdot
.4061 .51491 Mdot
.2928 .77338 Mdot
.64102 .48013 Mdot
.61313 .40089 Mdot
.23052 .38582 Mdot
.67956 .47174 Mdot
.56779 .64467 Mdot
.35276 .59538 Mdot
.3495 .39289 Mdot
.58857 .62655 Mdot
.27052 .36528 Mdot
.31681 .3689 Mdot
.54938 .18799 Mdot
.59782 .66486 Mdot
.48263 .33593 Mdot
.33739 .37046 Mdot
.44522 .51595 Mdot
.49415 .39376 Mdot
.45842 .45837 Mdot
.53579 .31893 Mdot
.39712 .55942 Mdot
.71555 .3922 Mdot
.64669 .48719 Mdot
.43878 .57363 Mdot
.50255 .39523 Mdot
.67766 .39009 Mdot
.37088 .58488 Mdot
.38844 .58266 Mdot
.76851 .35067 Mdot
.4924 .21227 Mdot
.34138 .40746 Mdot
.57529 .67696 Mdot
.37321 .55296 Mdot
.33525 .36669 Mdot
.38751 .32937 Mdot
.36207 .58655 Mdot
.62243 .6802 Mdot
.4394 .49745 Mdot
.49556 .38655 Mdot
.67384 .4828 Mdot
.54273 .42255 Mdot
.34062 .36688 Mdot
.28062 .23029 Mdot
.52811 .298 Mdot
.41443 .51174 Mdot
.40628 .51973 Mdot
.71134 .35338 Mdot
.5788 .66839 Mdot
.19404 .4997 Mdot
.39812 .54465 Mdot
.47243 .5181 Mdot
.431 .56493 Mdot
.55438 .35124 Mdot
.59875 .65165 Mdot
.4035 .55776 Mdot
.59669 .5616 Mdot
.43862 .51633 Mdot
.34694 .37025 Mdot
.26899 .6712 Mdot
.35491 .57649 Mdot
.89305 .51875 Mdot
.47887 .25139 Mdot
.51216 .37605 Mdot
.72427 .39645 Mdot
.15081 .54418 Mdot
.77734 .47468 Mdot
.59836 .67523 Mdot
.69446 .67759 Mdot
.51442 .36066 Mdot
.79287 .50352 Mdot
.56987 .831 Mdot
.43103 .59448 Mdot
.39236 .60453 Mdot
.50502 .41411 Mdot
.54084 .29367 Mdot
.4802 .36452 Mdot
.35732 .52928 Mdot
.40228 .49533 Mdot
.50254 .37011 Mdot
.37433 .54415 Mdot
.47233 .53578 Mdot
.70045 .45744 Mdot
.57615 .61498 Mdot
.64738 .46929 Mdot
.6915 .46624 Mdot
.42399 .69286 Mdot
.69428 .2627 Mdot
.64544 .48271 Mdot
.6282 .45014 Mdot
.27038 .45969 Mdot
.29647 .56779 Mdot
.32193 .35851 Mdot
.51973 .83408 Mdot
.52017 .33347 Mdot
.40576 .56924 Mdot
.58242 .6101 Mdot
.42312 .67707 Mdot
.45177 .28752 Mdot
.36519 .21867 Mdot
.41427 .53527 Mdot
.51561 .34588 Mdot
.6532 .39005 Mdot
.49032 .57012 Mdot
.58142 .34168 Mdot
.43966 .55255 Mdot
.49581 .40183 Mdot
.48412 .76322 Mdot
.6265 .58174 Mdot
.55951 .26839 Mdot
.61838 .69762 Mdot
.42784 .54831 Mdot
.58763 .6671 Mdot
.65133 .47063 Mdot
.35022 .38299 Mdot
.34089 .40666 Mdot
.40193 .58246 Mdot
.36976 .47819 Mdot
.48344 .27906 Mdot
.43632 .5934 Mdot
.40758 .594 Mdot
.64726 .39127 Mdot
.41021 .5935 Mdot
.4096 .52136 Mdot
.42006 .52626 Mdot
.45214 .53777 Mdot
.63201 .4632 Mdot
.62108 .57127 Mdot
.36685 .5141 Mdot
.48512 .55772 Mdot
.69637 .43341 Mdot
.71288 .66615 Mdot
.68924 .47498 Mdot
.65061 .77482 Mdot
.64732 .4543 Mdot
.32903 .40631 Mdot
.70636 .37934 Mdot
.35144 .48747 Mdot
.61934 .62849 Mdot
.64796 .49658 Mdot
.32042 .38362 Mdot
.66377 .47471 Mdot
.49235 .3508 Mdot
.83331 .49092 Mdot
.54613 .66734 Mdot
.19838 .46916 Mdot
.746 .46404 Mdot
.5677 .25649 Mdot
.51145 .30365 Mdot
.60298 .65076 Mdot
.54971 .7522 Mdot
.42188 .52475 Mdot
.33261 .3675 Mdot
.39441 .57625 Mdot
.63159 .46904 Mdot
.51872 .34502 Mdot
.25904 .66667 Mdot
.34887 .40096 Mdot
.77674 .34365 Mdot
.51562 .33014 Mdot
.44336 .54498 Mdot
.62879 .45992 Mdot
.79885 .34773 Mdot
.64844 .47514 Mdot
.39103 .44979 Mdot
.63517 .66525 Mdot
.30598 .65978 Mdot
.57976 .63525 Mdot
.50744 .28909 Mdot
.8534 .54758 Mdot
.4724 .83671 Mdot
.57587 .62018 Mdot
.53485 .25469 Mdot
.38716 .60117 Mdot
.37032 .59383 Mdot
.61536 .5846 Mdot
.59688 .68145 Mdot
.38157 .54319 Mdot
.62394 .39568 Mdot
.67789 .55835 Mdot
.48049 .23362 Mdot
.5335 .33582 Mdot
.41151 .55555 Mdot
.69956 .43798 Mdot
.68793 .43639 Mdot
.53779 .29764 Mdot
.68838 .47792 Mdot
.44526 .57931 Mdot
.58257 .63268 Mdot
.48338 .39578 Mdot
.3394 .39988 Mdot
.28306 .74526 Mdot
.30313 .37019 Mdot
.53108 .31206 Mdot
.46983 .57584 Mdot
.51241 .36472 Mdot
.12964 .43252 Mdot
.44458 .56807 Mdot
.56135 .64987 Mdot
.37563 .58027 Mdot
.43009 .55257 Mdot
.38341 .60178 Mdot
.4982 .3657 Mdot
.18791 .44382 Mdot
.37215 .54686 Mdot
.67315 .45497 Mdot
.42946 .81027 Mdot
.37087 .59685 Mdot
.31981 .4311 Mdot
.27609 .51628 Mdot
.56782 .2437 Mdot
.60768 .61293 Mdot
.52374 .3716 Mdot
.56524 .63625 Mdot
.56835 .68901 Mdot
.56783 .64516 Mdot
.44068 .8008 Mdot
.53489 .7565 Mdot
.20662 .38938 Mdot
.32584 .70186 Mdot
.39304 .66505 Mdot
.58601 .68057 Mdot
.37763 .34568 Mdot
.62063 .63872 Mdot
.58093 .66759 Mdot
.58077 .90372 Mdot
.61379 .62524 Mdot
.40887 .54887 Mdot
.41549 .61547 Mdot
.72547 .59066 Mdot
.24794 .46293 Mdot
.40981 .5895 Mdot
.37098 .5604 Mdot
.34706 .37951 Mdot
.39893 .47646 Mdot
.59474 .40905 Mdot
.56009 .19644 Mdot
.7636 .58725 Mdot
.39536 .57784 Mdot
.37128 .554 Mdot
.41097 .49904 Mdot
.85707 .41976 Mdot
.45502 .68652 Mdot
.58885 .68306 Mdot
.33082 .5421 Mdot
.36132 .80196 Mdot
.45049 .57741 Mdot
.3577 .57345 Mdot
.40831 .60767 Mdot
.51483 .35971 Mdot
.62133 .68495 Mdot
.33288 .53525 Mdot
.5667 .22304 Mdot
.44582 .60046 Mdot
.60973 .41311 Mdot
.16942 .52258 Mdot
.40518 .5525 Mdot
.62806 .63843 Mdot
.39259 .5973 Mdot
.60088 .66585 Mdot
.60746 .63447 Mdot
.46118 .54522 Mdot
.51334 .80561 Mdot
.63112 .67163 Mdot
.44066 .60019 Mdot
.5062 .36187 Mdot
.50313 .84554 Mdot
.39613 .55725 Mdot
.34166 .41226 Mdot
.39907 .54275 Mdot
.35812 .38574 Mdot
.41728 .59713 Mdot
.53949 .29953 Mdot
.52974 .68555 Mdot
.52355 .34747 Mdot
.19217 .54323 Mdot
.54369 .31144 Mdot
.76708 .34642 Mdot
.60991 .68263 Mdot
.68789 .39084 Mdot
.32524 .22228 Mdot
.60659 .4032 Mdot
.5902 .53179 Mdot
.55238 .51483 Mdot
.6792 .4402 Mdot
.5548 .64788 Mdot
.24008 .56343 Mdot
.69249 .33071 Mdot
.6953 .35887 Mdot
.52519 .30442 Mdot
.34095 .19692 Mdot
.41114 .18707 Mdot
.36377 .56051 Mdot
.48229 .79496 Mdot
.38771 .7315 Mdot
.36004 .5831 Mdot
.34599 .58874 Mdot
.50833 .40193 Mdot
.40239 .51915 Mdot
.62292 .54712 Mdot
.52169 .31494 Mdot
.31978 .38013 Mdot
.57946 .66379 Mdot
.35768 .4049 Mdot
.69525 .3409 Mdot
.55441 .52024 Mdot
.49752 .32587 Mdot
.4419 .52126 Mdot
.37093 .5741 Mdot
.60989 .65094 Mdot
.64695 .64549 Mdot
.59614 .61978 Mdot
.30819 .39458 Mdot
.52083 .31839 Mdot
.4586 .67835 Mdot
.3765 .55964 Mdot
.58933 .63609 Mdot
.70961 .50646 Mdot
.37578 .55341 Mdot
.66756 .47872 Mdot
.4279 .61074 Mdot
.56966 .62237 Mdot
.41076 .59361 Mdot
.58099 .63148 Mdot
.53002 .34112 Mdot
.45236 .57716 Mdot
.37718 .57037 Mdot
.79714 .35354 Mdot
.32644 .40217 Mdot
.60243 .68186 Mdot
.47752 .41525 Mdot
.43189 .5304 Mdot
.62519 .30667 Mdot
.42395 .54457 Mdot
.60142 .70979 Mdot
.41545 .51022 Mdot
.66088 .39025 Mdot
.42324 .6218 Mdot
.39722 .5575 Mdot
.56086 .54421 Mdot
.39993 .75426 Mdot
.65034 .66118 Mdot
.63166 .45203 Mdot
.62898 .65173 Mdot
.42794 .26168 Mdot
.48745 .32286 Mdot
.51595 .38624 Mdot
.22202 .47825 Mdot
.46466 .57066 Mdot
.41682 .56701 Mdot
.69844 .47974 Mdot
.31501 .37947 Mdot
.59541 .63953 Mdot
.32187 .37592 Mdot
.601 .21645 Mdot
.3075 .38218 Mdot
.537 .28855 Mdot
.50881 .25113 Mdot
.50122 .68632 Mdot
.34633 .37877 Mdot
.5875 .61644 Mdot
.39297 .25747 Mdot
.3726 .52779 Mdot
.34446 .34928 Mdot
.3289 .39274 Mdot
.33833 .19162 Mdot
.40412 .52205 Mdot
.59496 .52924 Mdot
.65527 .48531 Mdot
.33248 .37203 Mdot
.66755 .44141 Mdot
.40556 .58736 Mdot
.60473 .27973 Mdot
.60022 .67776 Mdot
.67865 .42211 Mdot
.34304 .55749 Mdot
.30968 .39172 Mdot
.50519 .32005 Mdot
.68877 .41017 Mdot
.64725 .43553 Mdot
.69323 .70772 Mdot
.25876 .65185 Mdot
.52167 .31904 Mdot
.41027 .22124 Mdot
.65947 .43592 Mdot
.35666 .5754 Mdot
.45725 .50213 Mdot
.44549 .56307 Mdot
.72155 .40393 Mdot
.52456 .37181 Mdot
.68634 .58006 Mdot
.37076 .57654 Mdot
.417 .53072 Mdot
.61099 .60349 Mdot
.52693 .33223 Mdot
.58324 .65177 Mdot
.6265 .64388 Mdot
.53014 .33863 Mdot
.57557 .64066 Mdot
.32174 .36567 Mdot
.69318 .55165 Mdot
.65449 .43697 Mdot
.66954 .45447 Mdot
.51638 .33881 Mdot
.50766 .3753 Mdot
.51456 .36721 Mdot
.42892 .6106 Mdot
.59768 .64541 Mdot
.41727 .60505 Mdot
.38595 .60246 Mdot
.65532 .6671 Mdot
.59597 .61172 Mdot
.39605 .60206 Mdot
.57009 .28481 Mdot
.33411 .34782 Mdot
.50311 .36203 Mdot
.6501 .48481 Mdot
.80083 .55081 Mdot
.68832 .41937 Mdot
.41435 .55575 Mdot
.69206 .27817 Mdot
.58242 .61909 Mdot
.34405 .3818 Mdot
.34464 .3588 Mdot
.34745 .39452 Mdot
.69572 .48954 Mdot
.6186 .67065 Mdot
.55847 .19602 Mdot
.41321 .55873 Mdot
.5947 .49555 Mdot
.24214 .57891 Mdot
.60703 .22889 Mdot
.64767 .48453 Mdot
.37327 .55489 Mdot
.53516 .42624 Mdot
.55176 .73745 Mdot
.43836 .55431 Mdot
.38958 .513 Mdot
.61781 .37345 Mdot
.45614 .51204 Mdot
.6338 .66849 Mdot
.68971 .24876 Mdot
.39838 .61181 Mdot
.64097 .61075 Mdot
.20072 .66977 Mdot
.42111 .55503 Mdot
.40571 .53295 Mdot
.38772 .56183 Mdot
.38414 .58745 Mdot
.62967 .64058 Mdot
.23826 .51526 Mdot
.62886 .46801 Mdot
.57699 .46671 Mdot
.65364 .43597 Mdot
.49444 .4001 Mdot
.62414 .56283 Mdot
.553 .63612 Mdot
.34331 .37892 Mdot
.64114 .73391 Mdot
.63102 .2094 Mdot
.49858 .31051 Mdot
.49837 .71352 Mdot
.33194 .39906 Mdot
.35263 .56515 Mdot
.36187 .39967 Mdot
.54166 .30889 Mdot
.67904 .45129 Mdot
.457 .6143 Mdot
.60765 .62414 Mdot
.56059 .62706 Mdot
.38083 .54544 Mdot
.39924 .82783 Mdot
.66982 .48032 Mdot
.62849 .43324 Mdot
.37249 .58839 Mdot
.38612 .51294 Mdot
.58027 .65341 Mdot
.50528 .34734 Mdot
.30906 .29845 Mdot
.31823 .39271 Mdot
.44634 .54194 Mdot
.38832 .58939 Mdot
.68813 .25299 Mdot
.68627 .46893 Mdot
.51509 .29257 Mdot
.36486 .57863 Mdot
.75871 .43107 Mdot
.36615 .57981 Mdot
.49412 .57785 Mdot
.50815 .35932 Mdot
.37038 .50309 Mdot
.36919 .54674 Mdot
.33404 .59033 Mdot
.66367 .43708 Mdot
.56439 .65216 Mdot
.6203 .61413 Mdot
.50831 .41917 Mdot
.66525 .47806 Mdot
.39364 .59994 Mdot
.68319 .47241 Mdot
.36243 .58963 Mdot
.38122 .53962 Mdot
.64445 .48094 Mdot
.58271 .65125 Mdot
.7036 .64554 Mdot
.62114 .5681 Mdot
.37999 .58548 Mdot
.41447 .61858 Mdot
.23409 .47639 Mdot
.23488 .32274 Mdot
.41681 .53845 Mdot
.56523 .62468 Mdot
.37465 .56296 Mdot
.66111 .44476 Mdot
.31051 .37704 Mdot
.56628 .62662 Mdot
.50625 .33749 Mdot
.50624 .3032 Mdot
.78191 .52879 Mdot
.53716 .30911 Mdot
.36255 .54001 Mdot
.53163 .64945 Mdot
.55807 .61191 Mdot
.23093 .70205 Mdot
.53009 .33393 Mdot
.33413 .35974 Mdot
.39328 .58366 Mdot
.73094 .32425 Mdot
.69434 .48587 Mdot
.90032 .49972 Mdot
.55199 .19088 Mdot
.30097 .37414 Mdot
.34999 .21991 Mdot
.48862 .39634 Mdot
.38387 .53075 Mdot
.35138 .38478 Mdot
.49238 .32384 Mdot
.36253 .54678 Mdot
.43448 .63087 Mdot
.19055 .48146 Mdot
.52015 .41737 Mdot
.68079 .47745 Mdot
.49947 .38359 Mdot
.36426 .406 Mdot
.53744 .28997 Mdot
.56007 .62466 Mdot
.40088 .55994 Mdot
.32513 .52486 Mdot
.50431 .34342 Mdot
.53883 .29229 Mdot
.42177 .60958 Mdot
.55679 .65241 Mdot
.53224 .37857 Mdot
.40401 .5803 Mdot
.44043 .663 Mdot
.61768 .69692 Mdot
.51692 .31781 Mdot
.41839 .52814 Mdot
.30269 .54033 Mdot
.51251 .33583 Mdot
.50161 .36157 Mdot
.38044 .54396 Mdot
.32467 .36472 Mdot
.45353 .59547 Mdot
.64481 .45929 Mdot
.17739 .46514 Mdot
.66382 .44533 Mdot
.41601 .276 Mdot
.46699 .54613 Mdot
.59516 .2878 Mdot
.5628 .61845 Mdot
.36666 .39939 Mdot
.80894 .54544 Mdot
.36947 .51859 Mdot
.57791 .81247 Mdot
.53992 .43683 Mdot
.35065 .80379 Mdot
.80502 .62015 Mdot
.32994 .38945 Mdot
.65853 .47345 Mdot
.40531 .53351 Mdot
.68818 .48547 Mdot
.3521 .39984 Mdot
.24112 .6126 Mdot
.41599 .52549 Mdot
.59813 .65381 Mdot
.43902 .60411 Mdot
.59231 .66566 Mdot
.37819 .55094 Mdot
.46628 .52653 Mdot
.67861 .38332 Mdot
.27351 .40169 Mdot
.36949 .53416 Mdot
.83384 .48216 Mdot
.46032 .29341 Mdot
.32336 .39223 Mdot
.42856 .60356 Mdot
.49636 .30484 Mdot
.68648 .43732 Mdot
.5018 .52484 Mdot
.51289 .36157 Mdot
.67412 .48961 Mdot
.57378 .64904 Mdot
.5319 .33896 Mdot
.51856 .29673 Mdot
.33428 .54949 Mdot
.3567 .38504 Mdot
.68334 .45035 Mdot
.39972 .55479 Mdot
.40737 .52382 Mdot
.41439 .22775 Mdot
.43704 .29948 Mdot
.62278 .61126 Mdot
.76987 .30209 Mdot
.59417 .60402 Mdot
.31952 .39939 Mdot
.50945 .36246 Mdot
.41812 .54131 Mdot
.43875 .57675 Mdot
.69437 .38961 Mdot
.59403 .67945 Mdot
.52279 .4203 Mdot
.45183 .69999 Mdot
.53924 .35511 Mdot
.26215 .50208 Mdot
.55899 .64721 Mdot
.26084 .50006 Mdot
.36398 .40544 Mdot
.58204 .79324 Mdot
.29426 .4381 Mdot
.65834 .48641 Mdot
.26088 .50702 Mdot
.59735 .62939 Mdot
.36488 .5656 Mdot
.48245 .34049 Mdot
.53262 .305 Mdot
.57814 .65868 Mdot
.49684 .40623 Mdot
.33453 .37399 Mdot
.40173 .53075 Mdot
.5299 .20815 Mdot
.74617 .54971 Mdot
.49898 .34817 Mdot
.49399 .59271 Mdot
.67285 .44601 Mdot
.38645 .53139 Mdot
.33873 .41294 Mdot
.67955 .46275 Mdot
.46583 .25356 Mdot
.68185 .5663 Mdot
.40492 .58459 Mdot
.73897 .31806 Mdot
.67208 .47531 Mdot
.31416 .2533 Mdot
.40263 .5758 Mdot
.65998 .43591 Mdot
.41317 .49205 Mdot
.60324 .2388 Mdot
.49882 .43311 Mdot
.56276 .83676 Mdot
.53258 .41964 Mdot
.4836 .37394 Mdot
.64138 .27467 Mdot
.67218 .34531 Mdot
.69361 .4791 Mdot
.53785 .2915 Mdot
.31705 .48722 Mdot
.66862 .44073 Mdot
.39244 .60496 Mdot
.42293 .54868 Mdot
.42247 .68821 Mdot
.54383 .44788 Mdot
.53558 .28216 Mdot
.76224 .48637 Mdot
.43231 .53147 Mdot
.33829 .56316 Mdot
.4332 .57807 Mdot
.57087 .68069 Mdot
.6856 .45882 Mdot
.81146 .40297 Mdot
.66064 .47851 Mdot
.48279 .19814 Mdot
.52031 .33519 Mdot
.51793 .37982 Mdot
.40859 .55287 Mdot
.57036 .26774 Mdot
.27401 .56529 Mdot
.4448 .58414 Mdot
.59241 .31167 Mdot
.26691 .67796 Mdot
.34139 .56167 Mdot
.63623 .66283 Mdot
.4727 .60551 Mdot
.55757 .67431 Mdot
.66043 .43203 Mdot
.33656 .38832 Mdot
.36925 .4057 Mdot
.68271 .45192 Mdot
.41788 .56855 Mdot
.60042 .32036 Mdot
.43428 .55917 Mdot
.3621 .56876 Mdot
.48264 .18941 Mdot
.30122 .37852 Mdot
.52043 .36797 Mdot
.34471 .4053 Mdot
.58206 .66879 Mdot
.81391 .7234 Mdot
.31592 .37701 Mdot
.27909 .577 Mdot
.20853 .56113 Mdot
.25863 .507 Mdot
.55795 .63034 Mdot
.33476 .42161 Mdot
.67151 .4826 Mdot
.41844 .85523 Mdot
.21973 .34036 Mdot
.66312 .41388 Mdot
.41261 .58015 Mdot
.55169 .64338 Mdot
.58799 .61455 Mdot
.67224 .42303 Mdot
.60468 .6329 Mdot
.35224 .49947 Mdot
.36889 .57768 Mdot
.68875 .48314 Mdot
.73689 .57498 Mdot
.6478 .43488 Mdot
.68538 .54178 Mdot
.43113 .60482 Mdot
.55893 .63963 Mdot
.47342 .59892 Mdot
.53343 .62857 Mdot
.51541 .29163 Mdot
.35259 .57182 Mdot
.33712 .37413 Mdot
.58807 .45946 Mdot
.51893 .32222 Mdot
.69143 .27998 Mdot
.60862 .65351 Mdot
.71332 .49387 Mdot
.60756 .64046 Mdot
.55611 .66268 Mdot
.69218 .46503 Mdot
.61253 .67074 Mdot
.40519 .53198 Mdot
.5545 .27251 Mdot
.6065 .66532 Mdot
.65884 .46048 Mdot
.34161 .39113 Mdot
.57806 .6435 Mdot
.51141 .40501 Mdot
.38295 .5782 Mdot
.48988 .34866 Mdot
.68252 .37783 Mdot
.55712 .65783 Mdot
.32454 .41731 Mdot
.52599 .37295 Mdot
.35571 .38666 Mdot
.2573 .68748 Mdot
.65318 .49401 Mdot
.37241 .21899 Mdot
.30516 .53985 Mdot
.60497 .62008 Mdot
.67995 .38015 Mdot
.41616 .54286 Mdot
.38423 .58003 Mdot
.35376 .41726 Mdot
.58868 .61455 Mdot
.46949 .84175 Mdot
.63745 .71241 Mdot
.69272 .56104 Mdot
.64977 .49498 Mdot
.78858 .37835 Mdot
.6444 .54731 Mdot
.19784 .60166 Mdot
.34658 .52525 Mdot
.48706 .39264 Mdot
.42333 .56437 Mdot
.80578 .55905 Mdot
.30886 .39264 Mdot
.31009 .31749 Mdot
.45477 .52878 Mdot
.52631 .36057 Mdot
.38946 .56959 Mdot
.50541 .49929 Mdot
.48458 .5889 Mdot
.31948 .36401 Mdot
.60593 .42408 Mdot
.62141 .63162 Mdot
.33715 .40031 Mdot
.51761 .30347 Mdot
.27091 .54508 Mdot
.36959 .53755 Mdot
.36078 .52203 Mdot
.54098 .34876 Mdot
.60143 .65073 Mdot
.48715 .37861 Mdot
.65529 .43664 Mdot
.33237 .37967 Mdot
.39095 .5857 Mdot
.4256 .51223 Mdot
.62683 .30878 Mdot
.68583 .45114 Mdot
.53438 .36729 Mdot
.64982 .47491 Mdot
.4813 .37078 Mdot
.43375 .61821 Mdot
.51783 .38084 Mdot
.38556 .52543 Mdot
.80316 .47705 Mdot
.47546 .19139 Mdot
.42136 .76576 Mdot
.52814 .36136 Mdot
.28144 .49231 Mdot
.65662 .45159 Mdot
.64683 .45849 Mdot
.30785 .65305 Mdot
.41174 .47328 Mdot
.44659 .2403 Mdot
.70269 .70482 Mdot
.65265 .43745 Mdot
.66573 .44859 Mdot
.48923 .34043 Mdot
.60881 .67207 Mdot
.54912 .65032 Mdot
.49293 .40135 Mdot
.23499 .40616 Mdot
.59527 .63947 Mdot
.56041 .81683 Mdot
.44759 .25046 Mdot
.3357 .56403 Mdot
.72744 .43481 Mdot
.33738 .3811 Mdot
.24313 .40482 Mdot
.5158 .5126 Mdot
.41517 .53191 Mdot
.70026 .26099 Mdot
.50878 .3474 Mdot
.2236 .50694 Mdot
.65383 .77175 Mdot
.41487 .52381 Mdot
.40464 .57078 Mdot
.42515 .57223 Mdot
.30235 .39132 Mdot
.54079 .6824 Mdot
.40772 .52588 Mdot
.23323 .40265 Mdot
.43473 .53195 Mdot
.35784 .44954 Mdot
.34187 .40666 Mdot
.35822 .63428 Mdot
.62101 .3914 Mdot
.56862 .21549 Mdot
.421 .63963 Mdot
.65235 .44082 Mdot
.56933 .41734 Mdot
.66827 .43388 Mdot
.43149 .79481 Mdot
.29219 .4401 Mdot
.639 .65008 Mdot
.41221 .53233 Mdot
.52974 .31158 Mdot
.58372 .61481 Mdot
.64971 .30577 Mdot
.63865 .88163 Mdot
.66862 .42954 Mdot
.14011 .42753 Mdot
.64587 .46666 Mdot
.52335 .29593 Mdot
.57908 .65403 Mdot
.52521 .75782 Mdot
.59665 .50056 Mdot
.57762 .64051 Mdot
.69597 .62939 Mdot
.55438 .6062 Mdot
.27172 .50251 Mdot
.56685 .60826 Mdot
.657 .45818 Mdot
.71047 .44982 Mdot
.33741 .58305 Mdot
.40868 .54521 Mdot
.54991 .51848 Mdot
.28741 .56249 Mdot
.41201 .54335 Mdot
.52203 .31585 Mdot
.30581 .2536 Mdot
.50727 .4165 Mdot
.61938 .6459 Mdot
.63912 .43771 Mdot
.40118 .57034 Mdot
.37554 .58583 Mdot
.36513 .54638 Mdot
.78091 .30788 Mdot
.54423 .81756 Mdot
.37209 .54755 Mdot
.4525 .5529 Mdot
.53041 .3451 Mdot
.30641 .41582 Mdot
.79736 .59135 Mdot
.35033 .46215 Mdot
.44092 .54944 Mdot
.33505 .40506 Mdot
.31187 .3601 Mdot
.36256 .54569 Mdot
.55379 .22736 Mdot
.54703 .26117 Mdot
.39922 .55487 Mdot
.38199 .45544 Mdot
.68653 .33626 Mdot
.53707 .29242 Mdot
.50651 .34088 Mdot
.62747 .63809 Mdot
.52974 .30717 Mdot
.54393 .31044 Mdot
.52777 .74288 Mdot
.55753 .42345 Mdot
.61443 .49419 Mdot
.30831 .39501 Mdot
.43921 .57223 Mdot
.58337 .60117 Mdot
.71234 .39625 Mdot
.68074 .44318 Mdot
.57539 .62569 Mdot
.6839 .4344 Mdot
.29747 .37443 Mdot
.20223 .4853 Mdot
.53252 .3029 Mdot
.64612 .44319 Mdot
.68129 .56509 Mdot
.33702 .40577 Mdot
.68115 .48258 Mdot
.60206 .29519 Mdot
.37912 .60095 Mdot
.56022 .77908 Mdot
.44275 .59228 Mdot
.4028 .83625 Mdot
.68085 .48198 Mdot
.66089 .39115 Mdot
.4113 .56408 Mdot
.51569 .33137 Mdot
.45064 .51147 Mdot
.44049 .55285 Mdot
.50454 .33371 Mdot
.364 .56104 Mdot
.34976 .40951 Mdot
.58203 .69313 Mdot
.56738 .42846 Mdot
.51534 .14162 Mdot
.35831 .39267 Mdot
.64174 .30315 Mdot
.4161 .53721 Mdot
.25938 .66379 Mdot
.57937 .6427 Mdot
.39874 .51512 Mdot
.31881 .62985 Mdot
.59932 .67216 Mdot
.56837 .63315 Mdot
.40452 .59763 Mdot
.65794 .48472 Mdot
.51532 .32462 Mdot
.34175 .40507 Mdot
.22777 .67246 Mdot
.4239 .5847 Mdot
.37567 .56721 Mdot
.33384 .39961 Mdot
.66516 .44655 Mdot
.38004 .58932 Mdot
.74336 .38642 Mdot
.30585 .77938 Mdot
.68814 .44657 Mdot
.43164 .61369 Mdot
.60791 .74825 Mdot
.52968 .63156 Mdot
.1754 .37808 Mdot
.27779 .36436 Mdot
.51961 .37359 Mdot
.44902 .50516 Mdot
.87366 .60056 Mdot
.33807 .38783 Mdot
.56314 .20492 Mdot
.36035 .5675 Mdot
.38047 .55947 Mdot
.58985 .61974 Mdot
.40835 .60475 Mdot
.58568 .67463 Mdot
.46745 .14861 Mdot
.72238 .27095 Mdot
.60236 .65792 Mdot
.6115 .62528 Mdot
.29407 .60327 Mdot
.79938 .58499 Mdot
.57419 .65674 Mdot
.45267 .60835 Mdot
.47605 .82527 Mdot
.34249 .60448 Mdot
.35479 .41708 Mdot
.67976 .36897 Mdot
.54557 .59643 Mdot
.42409 .39578 Mdot
.69889 .68255 Mdot
.55947 .59044 Mdot
.50286 .27711 Mdot
.64289 .46116 Mdot
.4272 .53081 Mdot
.53546 .30678 Mdot
.51698 .38481 Mdot
.48408 .57814 Mdot
.43899 .56347 Mdot
.59785 .66707 Mdot
.30357 .37936 Mdot
.69607 .45175 Mdot
.37096 .56137 Mdot
.51808 .40991 Mdot
.31641 .3834 Mdot
.61675 .65113 Mdot
.29897 .64079 Mdot
.328 .36038 Mdot
.47812 .60691 Mdot
.39403 .54513 Mdot
.41522 .60938 Mdot
.3225 .51584 Mdot
.63638 .47313 Mdot
.72061 .38218 Mdot
.44561 .60654 Mdot
.60547 .21649 Mdot
.42707 .44068 Mdot
.38155 .4996 Mdot
.60041 .63748 Mdot
.69133 .49029 Mdot
.50671 .29372 Mdot
.25603 .5775 Mdot
.41385 .58551 Mdot
.53738 .81688 Mdot
.45063 .69078 Mdot
.50239 .30033 Mdot
.58883 .68092 Mdot
.34535 .38457 Mdot
.44461 .57927 Mdot
.45513 .8119 Mdot
.42082 .55143 Mdot
.31263 .52319 Mdot
.5044 .35802 Mdot
.64184 .46343 Mdot
.33942 .79909 Mdot
.51677 .3846 Mdot
.56596 .63527 Mdot
.57643 .83902 Mdot
.55266 .62452 Mdot
.62452 .64753 Mdot
.50019 .81003 Mdot
.63585 .46578 Mdot
.8813 .58133 Mdot
.20894 .34675 Mdot
.42399 .50635 Mdot
.65505 .44923 Mdot
.58685 .6606 Mdot
.38757 .53087 Mdot
.5755 .60931 Mdot
.61224 .67762 Mdot
.35951 .59402 Mdot
.38605 .55033 Mdot
.61702 .56143 Mdot
.60831 .79627 Mdot
.34818 .39058 Mdot
.56352 .65824 Mdot
.37386 .66551 Mdot
.397 .5232 Mdot
.41247 .5586 Mdot
.67396 .31883 Mdot
.32536 .36358 Mdot
.5637 .55262 Mdot
.36308 .57527 Mdot
.7401 .29836 Mdot
.47141 .60992 Mdot
.63171 .64563 Mdot
.68877 .44885 Mdot
.55324 .21957 Mdot
.72195 .40616 Mdot
.59021 .67851 Mdot
.32505 .41082 Mdot
.62296 .61559 Mdot
.28052 .57649 Mdot
.63898 .44727 Mdot
.56973 .62232 Mdot
.54154 .42301 Mdot
.67285 .46383 Mdot
.67811 .48368 Mdot
.43293 .8117 Mdot
.5357 .35687 Mdot
.31779 .41112 Mdot
.67825 .44765 Mdot
.46311 .66056 Mdot
.65633 .46635 Mdot
.38528 .67699 Mdot
.45202 .58432 Mdot
.21141 .44281 Mdot
.62675 .53176 Mdot
.34534 .49442 Mdot
.6406 .48344 Mdot
.35112 .39993 Mdot
.39529 .59426 Mdot
.60336 .6301 Mdot
.31947 .37524 Mdot
.70869 .42017 Mdot
.50381 .36903 Mdot
.61019 .64227 Mdot
.62889 .47285 Mdot
.56207 .65478 Mdot
.23493 .55303 Mdot
.17661 .48148 Mdot
.7449 .37308 Mdot
.59283 .50004 Mdot
.36362 .54947 Mdot
.73629 .65938 Mdot
.35856 .59615 Mdot
.43828 .55806 Mdot
.51698 .31861 Mdot
.2207 .47927 Mdot
.58283 .65209 Mdot
.34518 .8055 Mdot
.64453 .44863 Mdot
.69999 .25389 Mdot
.6362 .69593 Mdot
.39995 .51378 Mdot
.60364 .66762 Mdot
.5569 .61709 Mdot
.39212 .75158 Mdot
.54182 .28829 Mdot
.41662 .62947 Mdot
.3798 .61439 Mdot
.35535 .51832 Mdot
.6775 .48329 Mdot
.67795 .27154 Mdot
.4885 .3875 Mdot
.16629 .44889 Mdot
.50207 .35568 Mdot
.58547 .37054 Mdot
.61609 .66514 Mdot
.31786 .37165 Mdot
.41001 .55741 Mdot
.63824 .69857 Mdot
.5846 .67794 Mdot
.31293 .34988 Mdot
.3351 .37095 Mdot
.63787 .25907 Mdot
.6438 .48096 Mdot
.37444 .52827 Mdot
.41691 .52783 Mdot
.41996 .60354 Mdot
.44598 .59381 Mdot
.66831 .42916 Mdot
.37451 .5933 Mdot
.70173 .44264 Mdot
.45444 .66594 Mdot
.7153 .27056 Mdot
.55492 .42261 Mdot
.48262 .51231 Mdot
.61253 .63416 Mdot
.47091 .65452 Mdot
.47733 .61144 Mdot
.44721 .1922 Mdot
.31257 .74292 Mdot
.34477 .56637 Mdot
.48828 .33718 Mdot
.42867 .4791 Mdot
.54051 .32368 Mdot
.17612 .32422 Mdot
.62744 .32045 Mdot
.56996 .82691 Mdot
.39675 .5267 Mdot
.67769 .32131 Mdot
.49926 .56797 Mdot
.37077 .60604 Mdot
.65309 .32904 Mdot
.76908 .45805 Mdot
.71119 .60225 Mdot
.31657 .35914 Mdot
.39017 .57894 Mdot
.55504 .61108 Mdot
.40486 .53057 Mdot
.41785 .56019 Mdot
.35913 .56603 Mdot
.62772 .46126 Mdot
.45467 .6146 Mdot
.43006 .61131 Mdot
.43748 .33882 Mdot
.27116 .46724 Mdot
.49807 .38472 Mdot
.29322 .64717 Mdot
.3166 .3785 Mdot
.60626 .66186 Mdot
.67434 .63584 Mdot
.65779 .4866 Mdot
.38527 .73954 Mdot
.43504 .60796 Mdot
.65178 .56126 Mdot
.6291 .47564 Mdot
.33209 .37725 Mdot
.48162 .33891 Mdot
.52433 .85079 Mdot
.53148 .31464 Mdot
.54256 .42663 Mdot
.52012 .32574 Mdot
.43663 .64424 Mdot
.59615 .66766 Mdot
.35829 .55777 Mdot
.67563 .44828 Mdot
.51146 .32208 Mdot
.23924 .46377 Mdot
.43223 .57665 Mdot
.52924 .34243 Mdot
.35795 .56046 Mdot
.19984 .46576 Mdot
.37342 .23861 Mdot
.54311 .30449 Mdot
.68737 .4972 Mdot
.66764 .46281 Mdot
.32024 .36699 Mdot
.6126 .65332 Mdot
.58988 .62138 Mdot
.67798 .46446 Mdot
.24061 .30527 Mdot
.4394 .5487 Mdot
.39143 .52779 Mdot
.60878 .21581 Mdot
.40586 .53787 Mdot
.27461 .52842 Mdot
.52947 .42663 Mdot
.61668 .64366 Mdot
.37988 .53745 Mdot
.38078 .58781 Mdot
.39891 .58409 Mdot
.23065 .55332 Mdot
.50258 .34817 Mdot
.44308 .54708 Mdot
.34151 .37115 Mdot
.50564 .28915 Mdot
.39039 .52697 Mdot
.35732 .5175 Mdot
.58737 .62145 Mdot
.69642 .23766 Mdot
.64483 .47332 Mdot
.51237 .30505 Mdot
.52155 .37673 Mdot
.68217 .3671 Mdot
.65111 .63436 Mdot
.52625 .4262 Mdot
.16647 .47508 Mdot
.63977 .39288 Mdot
.32707 .39815 Mdot
.58481 .39804 Mdot
.40524 .43119 Mdot
.49905 .31439 Mdot
.68136 .43007 Mdot
.44963 .59792 Mdot
.44555 .55526 Mdot
.54145 .18619 Mdot
.40012 .51278 Mdot
.34249 .38333 Mdot
.69731 .43231 Mdot
.59561 .6297 Mdot
.33431 .37648 Mdot
.64707 .46419 Mdot
.60214 .64844 Mdot
.3754 .60055 Mdot
.39203 .60743 Mdot
.57449 .62799 Mdot
.58645 .61578 Mdot
.39849 .551 Mdot
.51664 .27556 Mdot
.62621 .63787 Mdot
.56025 .63209 Mdot
.53439 .30322 Mdot
.52636 .30536 Mdot
.33692 .52847 Mdot
.65158 .45551 Mdot
.39762 .60547 Mdot
.53503 .32446 Mdot
.3066 .37724 Mdot
.58388 .64661 Mdot
.37676 .5843 Mdot
.36786 .56558 Mdot
.33939 .40444 Mdot
.308 .36697 Mdot
.33204 .37339 Mdot
.69568 .42707 Mdot
.42964 .59828 Mdot
.57211 .65221 Mdot
.6395 .4727 Mdot
.31215 .35978 Mdot
.35763 .37984 Mdot
.46121 .40374 Mdot
.41996 .54065 Mdot
.48204 .41349 Mdot
.8111 .7212 Mdot
.2994 .50022 Mdot
.50994 .29186 Mdot
.53934 .34994 Mdot
.25091 .48813 Mdot
.54292 .26577 Mdot
.67498 .47646 Mdot
.30895 .50073 Mdot
.36706 .39918 Mdot
.35474 .57521 Mdot
.41863 .61854 Mdot
.34814 .59332 Mdot
.32436 .37999 Mdot
.24571 .55731 Mdot
.56648 .61422 Mdot
.35907 .69611 Mdot
.31742 .37809 Mdot
.54182 .29376 Mdot
.52988 .3763 Mdot
.50215 .35642 Mdot
.42425 .61715 Mdot
.41666 .75873 Mdot
.42438 .65887 Mdot
.73541 .67015 Mdot
.66065 .49068 Mdot
.6405 .65244 Mdot
.25604 .6769 Mdot
.57119 .63175 Mdot
.52319 .38302 Mdot
.32051 .38234 Mdot
.57039 .61993 Mdot
.67693 .43597 Mdot
.66773 .44894 Mdot
.50058 .35141 Mdot
.51726 .33983 Mdot
.49142 .3442 Mdot
.6234 .66135 Mdot
.61346 .66938 Mdot
.42277 .58731 Mdot
.5848 .63615 Mdot
.61237 .18896 Mdot
.30067 .3915 Mdot
.53244 .3752 Mdot
.65667 .47339 Mdot
.59492 .66524 Mdot
.43523 .57847 Mdot
.53839 .39653 Mdot
.77477 .53098 Mdot
.35688 .3948 Mdot
.39857 .22968 Mdot
.1703 .33993 Mdot
.38425 .52028 Mdot
.68292 .47549 Mdot
.51964 .21063 Mdot
.42542 .57452 Mdot
.51267 .357 Mdot
.80976 .49733 Mdot
.48798 .32117 Mdot
.3907 .60387 Mdot
.39446 .51205 Mdot
.69017 .47558 Mdot
.20734 .56814 Mdot
.42908 .58759 Mdot
.68294 .52985 Mdot
.64627 .43174 Mdot
.49601 .39432 Mdot
.31479 .79005 Mdot
.70873 .35502 Mdot
.24042 .40827 Mdot
.52891 .30204 Mdot
.429 .55123 Mdot
.51722 .3095 Mdot
.35568 .39338 Mdot
.50741 .31447 Mdot
.63298 .67697 Mdot
.49488 .38579 Mdot
.37665 .56676 Mdot
.57312 .6573 Mdot
.67131 .47622 Mdot
.67864 .23802 Mdot
.43351 .32795 Mdot
.51565 .33229 Mdot
.52974 .29719 Mdot
.37275 .54198 Mdot
.5881 .55488 Mdot
.45329 .51923 Mdot
.39738 .52487 Mdot
.65327 .43495 Mdot
.60777 .66565 Mdot
.63581 .4815 Mdot
.43061 .52107 Mdot
.77936 .41695 Mdot
.65132 .47837 Mdot
.64715 .56456 Mdot
.33107 .39917 Mdot
.49724 .47394 Mdot
.4403 .5756 Mdot
.67618 .44369 Mdot
.43031 .59881 Mdot
.58399 .6086 Mdot
.53219 .46577 Mdot
.73249 .40018 Mdot
.67497 .4499 Mdot
.44717 .84096 Mdot
.46892 .39191 Mdot
.46843 .60271 Mdot
.66269 .43464 Mdot
.32382 .63253 Mdot
.5208 .29613 Mdot
.31993 .39453 Mdot
.31273 .35991 Mdot
.35338 .38043 Mdot
.3566 .53358 Mdot
.45608 .62818 Mdot
.3325 .41544 Mdot
.68875 .44379 Mdot
.31681 .36455 Mdot
.65958 .6772 Mdot
.45939 .84366 Mdot
.31182 .39719 Mdot
.40357 .57783 Mdot
.3416 .59485 Mdot
.26684 .4655 Mdot
.53648 .37389 Mdot
.58336 .81166 Mdot
.49919 .54217 Mdot
.41119 .5468 Mdot
.52305 .60038 Mdot
.56911 .61481 Mdot
.51123 .2165 Mdot
.29007 .55445 Mdot
.51079 .24193 Mdot
.61662 .62939 Mdot
.6962 .39061 Mdot
.61556 .64879 Mdot
.38222 .52399 Mdot
.38451 .53713 Mdot
.54752 .64897 Mdot
.69567 .27448 Mdot
.60951 .27675 Mdot
.28804 .74796 Mdot
.55828 .63367 Mdot
.6645 .43713 Mdot
.66439 .42812 Mdot
.65831 .48969 Mdot
.43582 .25565 Mdot
.56267 .66179 Mdot
.42335 .59511 Mdot
.53104 .34595 Mdot
.43551 .54156 Mdot
.67754 .45678 Mdot
.35157 .80879 Mdot
.59163 .62392 Mdot
.3979 .55695 Mdot
.23218 .33097 Mdot
.51886 .3499 Mdot
.32973 .40484 Mdot
.1976 .48831 Mdot
.47269 .24772 Mdot
.63452 .45787 Mdot
.54756 .63584 Mdot
.61002 .41083 Mdot
.64496 .57191 Mdot
.34138 .52859 Mdot
.35425 .50407 Mdot
.20761 .63292 Mdot
.45966 .25748 Mdot
.35586 .55475 Mdot
.51231 .30224 Mdot
.69467 .38924 Mdot
.37696 .58136 Mdot
.55672 .62973 Mdot
.33003 .35558 Mdot
.33774 .36739 Mdot
.42212 .62594 Mdot
.59269 .49145 Mdot
.4786 .45178 Mdot
.39085 .59951 Mdot
.47755 .6085 Mdot
.52773 .37409 Mdot
.62824 .39569 Mdot
.65003 .22568 Mdot
.31817 .40731 Mdot
.36113 .57493 Mdot
.72411 .62283 Mdot
.60812 .67751 Mdot
.48877 .36834 Mdot
.63746 .44788 Mdot
.23704 .57217 Mdot
.49241 .39111 Mdot
.37515 .58084 Mdot
.38002 .58893 Mdot
.6819 .48233 Mdot
.63182 .64591 Mdot
.32349 .38172 Mdot
.52737 .36548 Mdot
.31998 .40895 Mdot
.59016 .67366 Mdot
.59192 .62615 Mdot
.34611 .60978 Mdot
.45882 .61689 Mdot
.50708 .33844 Mdot
.42505 .51962 Mdot
.54466 .34885 Mdot
.20311 .56498 Mdot
.64759 .4965 Mdot
.38727 .51809 Mdot
.60362 .68861 Mdot
.6799 .45103 Mdot
.38491 .55707 Mdot
.20398 .64724 Mdot
.41056 .51874 Mdot
.7172 .4036 Mdot
.77607 .39767 Mdot
.34896 .38429 Mdot
.30782 .68835 Mdot
.56848 .57766 Mdot
.40167 .53751 Mdot
.50402 .37508 Mdot
.45315 .51497 Mdot
.66357 .48415 Mdot
.61959 .65258 Mdot
.17987 .36165 Mdot
.65845 .4652 Mdot
.39816 .52933 Mdot
.33226 .37877 Mdot
.55116 .62472 Mdot
.57358 .41641 Mdot
.59216 .2198 Mdot
.47478 .56697 Mdot
.45541 .60487 Mdot
.38863 .60222 Mdot
.81935 .56255 Mdot
.51033 .30661 Mdot
.59026 .66327 Mdot
.67723 .48305 Mdot
.67978 .46546 Mdot
.50369 .35141 Mdot
.70824 .58937 Mdot
.49856 .47237 Mdot
.8476 .65017 Mdot
.50472 .33008 Mdot
.32474 .41814 Mdot
.61572 .54701 Mdot
.50136 .37635 Mdot
.5281 .34206 Mdot
.52869 .37127 Mdot
.60938 .46087 Mdot
.59995 .6463 Mdot
.36678 .5645 Mdot
.60877 .61329 Mdot
.42976 .54889 Mdot
.44217 .44671 Mdot
.68155 .45024 Mdot
.62107 .64994 Mdot
.20921 .6479 Mdot
.54709 .67804 Mdot
.41628 .57488 Mdot
.24585 .66554 Mdot
.45942 .53156 Mdot
.25597 .5276 Mdot
.46507 .56193 Mdot
.51908 .33212 Mdot
.46721 .51595 Mdot
.39186 .5068 Mdot
.64815 .21322 Mdot
.65464 .47246 Mdot
.5213 .29416 Mdot
.35722 .54193 Mdot
.47261 .60973 Mdot
.54226 .63381 Mdot
.56676 .62234 Mdot
.32407 .41244 Mdot
.27057 .39488 Mdot
.66879 .47799 Mdot
.18183 .47506 Mdot
.40442 .54498 Mdot
.74752 .34584 Mdot
.32755 .69992 Mdot
.38623 .55776 Mdot
.48755 .82628 Mdot
.40325 .75088 Mdot
.44349 .57675 Mdot
.32994 .62819 Mdot
.6627 .4487 Mdot
.7737 .40933 Mdot
.45722 .56142 Mdot
.51409 .35883 Mdot
.61369 .66642 Mdot
.55647 .62432 Mdot
.3423 .41391 Mdot
.44682 .17693 Mdot
.64376 .48788 Mdot
.62001 .65551 Mdot
.43189 .57244 Mdot
.63478 .4624 Mdot
.53747 .31117 Mdot
.43185 .51832 Mdot
.28526 .53354 Mdot
.58754 .63472 Mdot
.45202 .55043 Mdot
.74807 .51327 Mdot
.25404 .40076 Mdot
.72968 .73461 Mdot
.6576 .48871 Mdot
.31162 .37782 Mdot
.41265 .49936 Mdot
.18538 .44001 Mdot
.34338 .56099 Mdot
.21101 .45237 Mdot
.65618 .64631 Mdot
.31214 .37505 Mdot
.41005 .56865 Mdot
.40262 .58782 Mdot
.61014 .5295 Mdot
.30448 .37362 Mdot
.42048 .52814 Mdot
.49473 .54718 Mdot
.60024 .65152 Mdot
.48773 .31453 Mdot
.59219 .63575 Mdot
.41183 .57971 Mdot
.43413 .63194 Mdot
.58783 .61824 Mdot
.16302 .50162 Mdot
.37101 .39636 Mdot
.64552 .4762 Mdot
.4584 .62206 Mdot
.45307 .58822 Mdot
.84634 .51237 Mdot
.51579 .29176 Mdot
.7769 .60911 Mdot
.50816 .4092 Mdot
.71322 .63971 Mdot
.70875 .35153 Mdot
.56457 .8426 Mdot
.69474 .25715 Mdot
.38003 .61398 Mdot
.45245 .4729 Mdot
.36513 .64825 Mdot
.63455 .47592 Mdot
.51961 .69344 Mdot
.40931 .54519 Mdot
.42069 .56173 Mdot
.48697 .35939 Mdot
.68325 .58114 Mdot
.5499 .22635 Mdot
.57962 .46417 Mdot
.32483 .38546 Mdot
.57439 .66489 Mdot
.37662 .55138 Mdot
.44414 .42418 Mdot
.4951 .38246 Mdot
.73872 .3354 Mdot
.40147 .5611 Mdot
.43891 .19736 Mdot
.61998 .42406 Mdot
.63866 .47677 Mdot
.51316 .38003 Mdot
.48706 .24955 Mdot
.42578 .54233 Mdot
.6494 .43451 Mdot
.43278 .58578 Mdot
.46054 .3484 Mdot
.4144 .51494 Mdot
.31118 .3924 Mdot
.36087 .55611 Mdot
.57758 .44407 Mdot
.67181 .778 Mdot
.31643 .50432 Mdot
.55271 .64501 Mdot
.54592 .33522 Mdot
.50374 .34648 Mdot
.57512 .61881 Mdot
.50638 .3436 Mdot
.37709 .71876 Mdot
.49996 .76061 Mdot
.32577 .38996 Mdot
.47494 .61135 Mdot
.32102 .40667 Mdot
.51545 .29129 Mdot
.41749 .54513 Mdot
.16241 .48468 Mdot
.50892 .32967 Mdot
.80084 .41717 Mdot
.65872 .47041 Mdot
.51802 .29254 Mdot
.43758 .53481 Mdot
.60043 .39077 Mdot
.51165 .38496 Mdot
.70412 .39306 Mdot
.40238 .58447 Mdot
.59835 .62687 Mdot
.39638 .588 Mdot
.46588 .55822 Mdot
.48041 .36773 Mdot
.44462 .60136 Mdot
.64712 .46404 Mdot
.62892 .65204 Mdot
.50399 .84387 Mdot
.7185 .40307 Mdot
.41621 .53073 Mdot
.43006 .57307 Mdot
.55243 .61726 Mdot
.45088 .55692 Mdot
.66676 .42969 Mdot
.87409 .38497 Mdot
.33105 .39965 Mdot
.54004 .298 Mdot
.71201 .36079 Mdot
.34386 .56808 Mdot
.38865 .59592 Mdot
.22774 .67632 Mdot
.73077 .36924 Mdot
.6535 .4426 Mdot
.46467 .52737 Mdot
.53101 .35115 Mdot
.33392 .37951 Mdot
.69364 .45112 Mdot
.4143 .60902 Mdot
.41152 .56077 Mdot
.3117 .38022 Mdot
.4409 .81853 Mdot
.48573 .23139 Mdot
.66981 .49035 Mdot
.46427 .51285 Mdot
.55275 .34526 Mdot
.4399 .55045 Mdot
.43713 .24952 Mdot
.5656 .62625 Mdot
.64098 .44774 Mdot
.76231 .63971 Mdot
.35589 .57135 Mdot
.68428 .44453 Mdot
.66558 .47807 Mdot
.41206 .50235 Mdot
.54429 .6576 Mdot
.62444 .66878 Mdot
.56513 .65794 Mdot
.638 .1917 Mdot
.25451 .4197 Mdot
.49142 .34466 Mdot
.66405 .44765 Mdot
.54231 .3233 Mdot
.30768 .40708 Mdot
.44379 .43382 Mdot
.54242 .30221 Mdot
.58262 .61407 Mdot
.53764 .36803 Mdot
.39809 .58623 Mdot
.67333 .47573 Mdot
.49734 .31832 Mdot
.35798 .53858 Mdot
.57058 .56314 Mdot
.46967 .30902 Mdot
.342 .36141 Mdot
.34031 .35392 Mdot
.38196 .54141 Mdot
.50532 .29481 Mdot
.40083 .55171 Mdot
.70008 .46819 Mdot
.62605 .54691 Mdot
.34665 .55579 Mdot
.51353 .33614 Mdot
.5276 .57864 Mdot
.47265 .24811 Mdot
.4637 .53042 Mdot
.40455 .57711 Mdot
.43577 .55013 Mdot
.43341 .58629 Mdot
.69306 .60767 Mdot
.65213 .49619 Mdot
.54809 .54443 Mdot
.67259 .38149 Mdot
.5786 .63341 Mdot
.60075 .68537 Mdot
.40173 .25379 Mdot
.51907 .26483 Mdot
.65309 .45302 Mdot
.44233 .56166 Mdot
.72341 .40047 Mdot
.36334 .81704 Mdot
.16053 .51284 Mdot
.30443 .35014 Mdot
.49359 .31672 Mdot
.55208 .65194 Mdot
.50071 .38196 Mdot
.42611 .55097 Mdot
.40709 .49917 Mdot
.55363 .85254 Mdot
.7134 .45928 Mdot
.32121 .38141 Mdot
.43417 .55014 Mdot
.2487 .40705 Mdot
.53048 .34559 Mdot
.532 .36854 Mdot
.42025 .52575 Mdot
.6286 .67616 Mdot
.82465 .62257 Mdot
.63843 .47807 Mdot
.49582 .53122 Mdot
.50691 .62612 Mdot
.75016 .47844 Mdot
.6829 .45647 Mdot
.48013 .27636 Mdot
.49361 .31434 Mdot
.34845 .74005 Mdot
.57949 .62988 Mdot
.31871 .38013 Mdot
.37118 .49837 Mdot
.60198 .62161 Mdot
.48318 .37463 Mdot
.61538 .63666 Mdot
.3613 .54985 Mdot
.64178 .48879 Mdot
.51638 .3753 Mdot
.6948 .49041 Mdot
.55438 .66822 Mdot
.34263 .41021 Mdot
.58008 .53582 Mdot
.5508 .7253 Mdot
.39848 .74766 Mdot
.44386 .54987 Mdot
.43498 .42127 Mdot
.42494 .59844 Mdot
.54123 .63665 Mdot
.43455 .58109 Mdot
.52358 .60898 Mdot
.5074 .37596 Mdot
.45317 .55379 Mdot
.38167 .59857 Mdot
.48313 .68386 Mdot
.3984 .56756 Mdot
.46197 .56698 Mdot
.44475 .57336 Mdot
.64459 .65407 Mdot
.48656 .59249 Mdot
.60167 .63979 Mdot
.58765 .22402 Mdot
.52751 .34032 Mdot
.32919 .35443 Mdot
.33699 .36449 Mdot
.21526 .43524 Mdot
.34821 .44521 Mdot
.69745 .5895 Mdot
.59216 .64406 Mdot
.65257 .47545 Mdot
.43644 .58392 Mdot
.70866 .69783 Mdot
.68069 .34865 Mdot
.53249 .34788 Mdot
.71731 .40268 Mdot
.37935 .4887 Mdot
.82127 .56103 Mdot
.43918 .53419 Mdot
.53776 .18016 Mdot
.36325 .60983 Mdot
.40266 .5163 Mdot
.5214 .387 Mdot
.35706 .44662 Mdot
.43943 .53997 Mdot
.54226 .63177 Mdot
.31503 .38858 Mdot
.58472 .70809 Mdot
.57909 .32887 Mdot
.48965 .26784 Mdot
.51662 .72345 Mdot
.43276 .59524 Mdot
.51671 .37338 Mdot
.61009 .64334 Mdot
.66518 .23398 Mdot
.6391 .47024 Mdot
.61514 .50739 Mdot
.42297 .66848 Mdot
.22569 .6302 Mdot
.31664 .38283 Mdot
.43426 .81387 Mdot
.37545 .56568 Mdot
.41911 .27538 Mdot
.35933 .5927 Mdot
.36755 .81889 Mdot
.33196 .42089 Mdot
.62124 .68237 Mdot
.66284 .43758 Mdot
.59049 .60968 Mdot
.41408 .76389 Mdot
.73555 .46804 Mdot
.55206 .49373 Mdot
.53368 .31964 Mdot
.55668 .54394 Mdot
.57937 .66152 Mdot
.37226 .58588 Mdot
.83716 .67541 Mdot
.56207 .63023 Mdot
.58546 .676 Mdot
.19546 .54184 Mdot
.19286 .55048 Mdot
.41076 .48976 Mdot
.60734 .6216 Mdot
.532 .32157 Mdot
.34874 .39927 Mdot
.4042 .59156 Mdot
.4209 .58887 Mdot
.59089 .62044 Mdot
.52571 .38168 Mdot
.4762 .51178 Mdot
.5186 .3372 Mdot
.60217 .65232 Mdot
.5233 .34859 Mdot
.70939 .38532 Mdot
.50156 .30828 Mdot
.45377 .58304 Mdot
.43524 .58179 Mdot
.56175 .32792 Mdot
.592 .62634 Mdot
.39743 .60002 Mdot
.36493 .55658 Mdot
.57403 .65455 Mdot
.51203 .41166 Mdot
.63017 .72797 Mdot
.41394 .53491 Mdot
.38508 .57697 Mdot
.31037 .37833 Mdot
.41179 .41735 Mdot
.33055 .2587 Mdot
.39582 .59441 Mdot
.3076 .40232 Mdot
.62341 .6592 Mdot
.39694 .55245 Mdot
.66527 .66477 Mdot
.70191 .38929 Mdot
.35675 .57119 Mdot
.51836 .2964 Mdot
.35819 .52533 Mdot
.7661 .68973 Mdot
.40239 .52263 Mdot
.58398 .658 Mdot
.60322 .67211 Mdot
.20456 .5409 Mdot
.56409 .63797 Mdot
.53202 .30495 Mdot
.67461 .46088 Mdot
.39664 .8336 Mdot
.53801 .31226 Mdot
.38236 .51439 Mdot
.20797 .34753 Mdot
.44928 .53864 Mdot
.35242 .54818 Mdot
.82866 .52019 Mdot
.53779 .31501 Mdot
.59716 .66958 Mdot
.62936 .51884 Mdot
.39473 .62351 Mdot
.63554 .45524 Mdot
.3969 .50284 Mdot
.44291 .60719 Mdot
.76872 .38919 Mdot
.79286 .52241 Mdot
.69668 .43398 Mdot
.33241 .55296 Mdot
.39606 .59492 Mdot
.42992 .38301 Mdot
.4354 .57561 Mdot
.32058 .4078 Mdot
.57674 .6703 Mdot
.49228 .36563 Mdot
.3413 .40055 Mdot
.4044 .54137 Mdot
.32527 .37858 Mdot
.49006 .34912 Mdot
.64589 .43914 Mdot
.42285 .54536 Mdot
.35348 .41901 Mdot
.32525 .38411 Mdot
.42064 .60093 Mdot
.61857 .65694 Mdot
.34481 .48856 Mdot
.39366 .55351 Mdot
.36775 .5783 Mdot
.59041 .62163 Mdot
.14512 .50549 Mdot
.40531 .52043 Mdot
.47333 .39241 Mdot
.5837 .67695 Mdot
.73006 .42218 Mdot
.48837 .35518 Mdot
.44502 .60522 Mdot
.65258 .43415 Mdot
.68051 .4467 Mdot
.53715 .33831 Mdot
.5641 .60976 Mdot
.54254 .36404 Mdot
.5247 .58109 Mdot
.4515 .62248 Mdot
.44347 .52368 Mdot
.23877 .29996 Mdot
.54695 .84595 Mdot
.55501 .63087 Mdot
.49597 .40417 Mdot
.57839 .46755 Mdot
.66484 .44393 Mdot
.54063 .34053 Mdot
.54863 .62804 Mdot
.55136 .64806 Mdot
.6132 .63684 Mdot
.32711 .36946 Mdot
.5044 .41236 Mdot
.63374 .65341 Mdot
.62862 .6752 Mdot
.39966 .58498 Mdot
.39625 .59625 Mdot
.31287 .59885 Mdot
.28984 .48118 Mdot
.3422 .41177 Mdot
.50525 .35437 Mdot
.82646 .34589 Mdot
.70151 .45964 Mdot
.48364 .68661 Mdot
.34658 .55773 Mdot
.71586 .82472 Mdot
.42977 .52564 Mdot
.43454 .5722 Mdot
.62765 .64562 Mdot
.35956 .41252 Mdot
.32193 .40479 Mdot
.58167 .66418 Mdot
.55075 .6589 Mdot
.31629 .40459 Mdot
.3498 .78011 Mdot
.45792 .84595 Mdot
.65281 .52886 Mdot
.57769 .65066 Mdot
.55099 .73785 Mdot
.6366 .44824 Mdot
.55688 .6737 Mdot
.69793 .46843 Mdot
.52868 .34926 Mdot
.49028 .32051 Mdot
.67612 .48477 Mdot
.40679 .58455 Mdot
.49561 .32882 Mdot
.45605 .61213 Mdot
.39706 .81339 Mdot
.51464 .7956 Mdot
.68651 .3071 Mdot
.41057 .61872 Mdot
.55681 .22821 Mdot
.56616 .25116 Mdot
.39461 .53641 Mdot
.68733 .67533 Mdot
.32196 .38012 Mdot
.60636 .69338 Mdot
.66431 .4294 Mdot
.74151 .72543 Mdot
.44111 .55381 Mdot
.58523 .65489 Mdot
.65141 .46923 Mdot
.21489 .5278 Mdot
.6788 .5319 Mdot
.43139 .54796 Mdot
.8605 .62327 Mdot
.645 .67939 Mdot
.49183 .36339 Mdot
.3212 .2333 Mdot
.61228 .61422 Mdot
.29145 .35153 Mdot
.63493 .38987 Mdot
.22483 .65305 Mdot
.60576 .66192 Mdot
.49652 .40724 Mdot
.57565 .66458 Mdot
.33204 .41252 Mdot
.61796 .69764 Mdot
.52372 .37207 Mdot
.40351 .56722 Mdot
.50973 .34558 Mdot
.34693 .40985 Mdot
.42881 .2612 Mdot
.66125 .43012 Mdot
.52015 .29453 Mdot
.66652 .4557 Mdot
.25885 .39943 Mdot
.78616 .42864 Mdot
.64178 .46519 Mdot
.19854 .51174 Mdot
.35365 .56006 Mdot
.62893 .63229 Mdot
.50041 .33557 Mdot
.62439 .39369 Mdot
.58329 .52047 Mdot
.57422 .63654 Mdot
.50475 .36213 Mdot
.43067 .66422 Mdot
.21379 .37094 Mdot
.4622 .62633 Mdot
.27719 .42005 Mdot
.57382 .65097 Mdot
.53575 .3647 Mdot
.60971 .21569 Mdot
.57827 .61325 Mdot
.50426 .32958 Mdot
.67046 .43781 Mdot
.6818 .46193 Mdot
.43108 .53429 Mdot
.61746 .4951 Mdot
.49683 .35569 Mdot
.59155 .24603 Mdot
.6068 .67838 Mdot
.21774 .5252 Mdot
.35927 .39644 Mdot
.52653 .33088 Mdot
.41093 .51057 Mdot
.52932 .61489 Mdot
.70152 .38711 Mdot
.43465 .47676 Mdot
.82384 .35295 Mdot
.50442 .35123 Mdot
.58155 .67333 Mdot
.58546 .6506 Mdot
.45509 .5221 Mdot
.59581 .50192 Mdot
.54497 .35752 Mdot
.21826 .38998 Mdot
.21087 .46753 Mdot
.48094 .36443 Mdot
.58127 .28651 Mdot
.39168 .51134 Mdot
.4355 .59895 Mdot
.66404 .44215 Mdot
.40148 .57173 Mdot
.62872 .66647 Mdot
.44377 .54586 Mdot
.68606 .45804 Mdot
.52502 .31422 Mdot
.4197 .54814 Mdot
.35135 .39566 Mdot
.68061 .42356 Mdot
.68787 .47887 Mdot
.52281 .32703 Mdot
.60916 .62488 Mdot
.35063 .35329 Mdot
.51685 .34073 Mdot
.43268 .59414 Mdot
.58562 .41145 Mdot
.36498 .54668 Mdot
.34505 .76095 Mdot
.58707 .61323 Mdot
.50246 .37943 Mdot
.58372 .67921 Mdot
.66201 .45648 Mdot
.67046 .38209 Mdot
.42166 .58009 Mdot
.50661 .32658 Mdot
.56569 .31474 Mdot
.3812 .79442 Mdot
.55207 .61497 Mdot
.6028 .31332 Mdot
.60701 .68224 Mdot
.48102 .35366 Mdot
.26296 .62229 Mdot
.32025 .39151 Mdot
.53041 .3579 Mdot
.54359 .83392 Mdot
.51052 .33438 Mdot
.39379 .56664 Mdot
.3815 .55337 Mdot
.48789 .34768 Mdot
.32546 .36447 Mdot
.71512 .26477 Mdot
.47734 .30253 Mdot
.60207 .667 Mdot
.29309 .66961 Mdot
.85064 .41828 Mdot
.64378 .50321 Mdot
.659 .44164 Mdot
.38601 .61863 Mdot
.40361 .51488 Mdot
.69754 .45331 Mdot
.63844 .43819 Mdot
.35332 .41028 Mdot
.5297 .36795 Mdot
.62605 .69642 Mdot
.6605 .42582 Mdot
.32995 .58686 Mdot
.32889 .43921 Mdot
.47803 .55137 Mdot
.50424 .61101 Mdot
.39824 .61171 Mdot
.20537 .44982 Mdot
.6861 .46922 Mdot
.3762 .54595 Mdot
.48372 .57466 Mdot
.64699 .44065 Mdot
.32824 .41122 Mdot
.78807 .50931 Mdot
.51998 .35899 Mdot
.21802 .70518 Mdot
.38104 .53074 Mdot
.3932 .56278 Mdot
.65832 .49045 Mdot
.42049 .38405 Mdot
.6021 .62428 Mdot
.5893 .61228 Mdot
.508 .30786 Mdot
.5678 .53136 Mdot
.45111 .56759 Mdot
.38986 .53759 Mdot
.51395 .36791 Mdot
.51774 .29331 Mdot
.64125 .27628 Mdot
.36938 .56727 Mdot
.65208 .46689 Mdot
.56843 .41763 Mdot
.6872 .4644 Mdot
.37735 .52856 Mdot
.38996 .56615 Mdot
.45409 .57941 Mdot
.39814 .51357 Mdot
.68675 .48108 Mdot
.37489 .54929 Mdot
.36489 .61882 Mdot
.61891 .63913 Mdot
.44735 .5923 Mdot
.20605 .46402 Mdot
.39687 .57784 Mdot
.34468 .40717 Mdot
.36982 .44615 Mdot
.43523 .54834 Mdot
.45097 .59176 Mdot
.4745 .3098 Mdot
.41462 .56903 Mdot
.69981 .46862 Mdot
.58128 .63684 Mdot
.66481 .44749 Mdot
.68265 .48076 Mdot
.52397 .30252 Mdot
.33767 .41557 Mdot
.34652 .57454 Mdot
.35281 .38115 Mdot
.33718 .54479 Mdot
.35465 .56423 Mdot
.65842 .37356 Mdot
.53086 .1768 Mdot
.48113 .23088 Mdot
.42179 .58109 Mdot
.52052 .31226 Mdot
.49388 .37134 Mdot
.4743 .49347 Mdot
.47131 .60614 Mdot
.69628 .45018 Mdot
.6763 .44427 Mdot
.28094 .52117 Mdot
.76779 .39192 Mdot
.34049 .41029 Mdot
.44087 .42817 Mdot
.45467 .61527 Mdot
.36408 .56614 Mdot
.43422 .52055 Mdot
.54266 .30657 Mdot
.58192 .41427 Mdot
.53244 .34694 Mdot
.7082 .39995 Mdot
.68738 .45701 Mdot
.44693 .56333 Mdot
.56004 .79341 Mdot
.56898 .61921 Mdot
.58173 .63617 Mdot
.69287 .4547 Mdot
.54524 .33409 Mdot
.31198 .54375 Mdot
.14496 .41166 Mdot
.64318 .67479 Mdot
.36057 .38775 Mdot
.39912 .53316 Mdot
.5214 .31927 Mdot
.55619 .64372 Mdot
.31719 .36344 Mdot
.3587 .57146 Mdot
.54286 .3677 Mdot
.42247 .58377 Mdot
.36366 .64713 Mdot
.6165 .65436 Mdot
.39458 .83782 Mdot
.55451 .62186 Mdot
.67764 .42432 Mdot
.64582 .44833 Mdot
.38442 .55901 Mdot
.26318 .27846 Mdot
.62401 .62375 Mdot
.61864 .43906 Mdot
.33811 .42123 Mdot
.60107 .40459 Mdot
.3073 .39464 Mdot
.50058 .37472 Mdot
.31548 .38657 Mdot
.51726 .37766 Mdot
.29505 .49762 Mdot
.63049 .61763 Mdot
.33575 .40125 Mdot
.44676 .37188 Mdot
.47012 .609 Mdot
.31948 .35694 Mdot
.3402 .58196 Mdot
.32226 .71038 Mdot
.51329 .36534 Mdot
.33064 .36578 Mdot
.37372 .58651 Mdot
.67383 .75727 Mdot
.64684 .45848 Mdot
.69736 .44851 Mdot
.46251 .60319 Mdot
.53143 .3657 Mdot
.54564 .64318 Mdot
.65743 .59126 Mdot
.72683 .43967 Mdot
.38362 .54121 Mdot
.44124 .54202 Mdot
.60533 .68602 Mdot
.60816 .59967 Mdot
.38538 .56417 Mdot
.48203 .66541 Mdot
.37304 .55974 Mdot
.67528 .4369 Mdot
.56302 .6192 Mdot
.58358 .6451 Mdot
.49913 .36315 Mdot
.6164 .62538 Mdot
.52062 .59867 Mdot
.58799 .42284 Mdot
.3452 .59233 Mdot
.66 .4642 Mdot
.59268 .46004 Mdot
.71693 .40197 Mdot
.59979 .79651 Mdot
.58847 .6854 Mdot
.453 .59462 Mdot
.60059 .67961 Mdot
.33749 .3777 Mdot
.59195 .62854 Mdot
.56126 .66256 Mdot
.3958 .54671 Mdot
.4293 .55168 Mdot
.53476 .31283 Mdot
.59165 .49418 Mdot
.62299 .64917 Mdot
.38031 .54588 Mdot
.45306 .54753 Mdot
.46262 .56888 Mdot
.50876 .44858 Mdot
.55421 .63536 Mdot
.42073 .68973 Mdot
.26871 .58412 Mdot
.62287 .64714 Mdot
.78606 .66718 Mdot
.64365 .39125 Mdot
.53904 .28922 Mdot
.68268 .50046 Mdot
.36886 .56805 Mdot
.4867 .34866 Mdot
.42561 .55061 Mdot
.50436 .61142 Mdot
.41442 .56052 Mdot
.30451 .38472 Mdot
.37994 .61389 Mdot
.48373 .33291 Mdot
.51447 .3414 Mdot
.39248 .52774 Mdot
.41871 .55089 Mdot
.44878 .2539 Mdot
.55358 .66381 Mdot
.60441 .62637 Mdot
.41447 .3717 Mdot
.33578 .39213 Mdot
.63879 .44996 Mdot
.44121 .57761 Mdot
.51646 .30717 Mdot
.51135 .34526 Mdot
.59107 .60905 Mdot
.51393 .35633 Mdot
.64534 .48461 Mdot
.42542 .57908 Mdot
.69796 .45077 Mdot
.33469 .367 Mdot
.56589 .66014 Mdot
.44275 .55819 Mdot
.39854 .58482 Mdot
.60309 .67203 Mdot
.35118 .57411 Mdot
.30965 .37976 Mdot
.50894 .33807 Mdot
.60842 .6556 Mdot
.67643 .46016 Mdot
.50687 .37697 Mdot
.38454 .5867 Mdot
.82047 .34428 Mdot
.39177 .5706 Mdot
.37366 .57858 Mdot
.51272 .85399 Mdot
.37152 .60987 Mdot
.49907 .34616 Mdot
.62149 .6842 Mdot
.45295 .61135 Mdot
.2254 .43533 Mdot
.15684 .51563 Mdot
.53597 .3333 Mdot
.4045 .52971 Mdot
.60322 .8046 Mdot
.39946 .5271 Mdot
.18421 .46724 Mdot
.34743 .27856 Mdot
.52646 .5199 Mdot
.42113 .6347 Mdot
.66101 .48667 Mdot
.53394 .3113 Mdot
.50682 .37468 Mdot
.32693 .67431 Mdot
.39229 .54393 Mdot
.3429 .62939 Mdot
.37124 .59068 Mdot
.6833 .45856 Mdot
.28266 .55301 Mdot
.50672 .35101 Mdot
.57144 .19947 Mdot
.42495 .59546 Mdot
.55299 .6364 Mdot
.53656 .37054 Mdot
.65937 .38962 Mdot
.37546 .58381 Mdot
.34868 .3764 Mdot
.70761 .44489 Mdot
.41449 .6279 Mdot
.66407 .46745 Mdot
.36145 .56464 Mdot
.34779 .61306 Mdot
.36465 .20464 Mdot
.61838 .64811 Mdot
.66365 .43885 Mdot
.57036 .26493 Mdot
.35525 .59026 Mdot
.60803 .6588 Mdot
.57857 .63064 Mdot
.35567 .40439 Mdot
.55947 .47659 Mdot
.73924 .52679 Mdot
.57018 .76255 Mdot
.2996 .66498 Mdot
.54046 .354 Mdot
.60725 .28293 Mdot
.40171 .59301 Mdot
.73565 .33873 Mdot
.70165 .45057 Mdot
.39673 .56406 Mdot
.34196 .71726 Mdot
.56153 .65316 Mdot
.3796 .57378 Mdot
.32146 .40726 Mdot
.7027 .29014 Mdot
.71872 .31609 Mdot
.8018 .6084 Mdot
.53323 .32627 Mdot
.39776 .50101 Mdot
.5 .61282 Mdot
.52768 .29679 Mdot
.36055 .58959 Mdot
.50183 .34023 Mdot
.28164 .70868 Mdot
.31441 .36874 Mdot
.55857 .6539 Mdot
.64918 .39055 Mdot
.41038 .61336 Mdot
.45694 .5473 Mdot
.33402 .35608 Mdot
.42954 .60595 Mdot
.44972 .17866 Mdot
.68412 .32283 Mdot
.49827 .31898 Mdot
.61499 .63893 Mdot
.42175 .61708 Mdot
.55369 .42448 Mdot
.3901 .54832 Mdot
.50334 .77678 Mdot
.45016 .59613 Mdot
.73475 .5167 Mdot
.61417 .66618 Mdot
.66372 .46412 Mdot
.3559 .51244 Mdot
.42177 .56508 Mdot
.54574 .38313 Mdot
.41049 .63426 Mdot
.39692 .5217 Mdot
.54378 .6283 Mdot
.56061 .62455 Mdot
.60073 .64024 Mdot
.49683 .38723 Mdot
.7612 .3845 Mdot
.65428 .45903 Mdot
.37558 .51254 Mdot
.65995 .42561 Mdot
.46854 .50665 Mdot
.34164 .36045 Mdot
.68466 .73687 Mdot
.43768 .60614 Mdot
.59607 .64576 Mdot
.7412 .60607 Mdot
.62282 .6622 Mdot
.52921 .41743 Mdot
.66977 .47777 Mdot
.55856 .64431 Mdot
.4297 .56985 Mdot
.58555 .46484 Mdot
.73657 .68861 Mdot
.66998 .44815 Mdot
.33978 .55351 Mdot
.49884 .30583 Mdot
.71491 .36833 Mdot
.85131 .37844 Mdot
.65234 .44393 Mdot
.57817 .26865 Mdot
.39148 .5399 Mdot
.57582 .61673 Mdot
.65585 .48735 Mdot
.64474 .46924 Mdot
.51052 .36084 Mdot
.43129 .55162 Mdot
.43579 .55353 Mdot
.48191 .35282 Mdot
.67777 .44648 Mdot
.46073 .5437 Mdot
.42637 .51929 Mdot
.55338 .85424 Mdot
.3094 .63492 Mdot
.14622 .59663 Mdot
.52175 .57726 Mdot
.3528 .73033 Mdot
.63923 .58255 Mdot
.57401 .67032 Mdot
.43369 .54666 Mdot
.39311 .61278 Mdot
.49805 .35705 Mdot
.40821 .57452 Mdot
.50465 .40064 Mdot
.65243 .45074 Mdot
.78163 .66735 Mdot
.77637 .54814 Mdot
.27145 .69315 Mdot
.40876 .57234 Mdot
.76142 .44723 Mdot
.34424 .38929 Mdot
.66884 .41999 Mdot
.60543 .64826 Mdot
.36287 .54427 Mdot
.45622 .24926 Mdot
.53097 .35435 Mdot
.57266 .62677 Mdot
.56488 .22108 Mdot
.50315 .25207 Mdot
.37642 .52925 Mdot
.49176 .38243 Mdot
.70079 .63795 Mdot
.49032 .6628 Mdot
.62576 .46881 Mdot
.30532 .3892 Mdot
.53169 .3443 Mdot
.6908 .45989 Mdot
.65877 .65331 Mdot
.56039 .6403 Mdot
.63854 .6639 Mdot
.42595 .23715 Mdot
.54397 .29983 Mdot
.34486 .39954 Mdot
.76324 .38983 Mdot
.75765 .35077 Mdot
.30488 .38552 Mdot
.48502 .33934 Mdot
.558 .62999 Mdot
.59567 .65974 Mdot
.58093 .63809 Mdot
.58477 .20168 Mdot
.56392 .61094 Mdot
.49228 .70861 Mdot
.45329 .54469 Mdot
.34422 .61975 Mdot
.40409 .52823 Mdot
.69676 .46926 Mdot
.61376 .65928 Mdot
.60827 .54014 Mdot
.36664 .52138 Mdot
.78398 .6411 Mdot
.38729 .53799 Mdot
.62561 .45825 Mdot
.37417 .57339 Mdot
.51864 .70334 Mdot
.59102 .67986 Mdot
.4141 .5789 Mdot
.68061 .49372 Mdot
.32918 .38504 Mdot
.55073 .67388 Mdot
.4351 .54973 Mdot
.68006 .57355 Mdot
.36495 .60607 Mdot
.32778 .76277 Mdot
.2279 .53625 Mdot
.36025 .38627 Mdot
.48987 .54227 Mdot
.53745 .35321 Mdot
.34028 .61843 Mdot
.48241 .61229 Mdot
.67044 .44986 Mdot
.79908 .47143 Mdot
.52863 .33689 Mdot
.30203 .51999 Mdot
.45849 .5201 Mdot
.33312 .41446 Mdot
.56203 .60205 Mdot
.69039 .48158 Mdot
.36133 .53645 Mdot
.41536 .50341 Mdot
.29478 .71996 Mdot
.47205 .61894 Mdot
.44931 .55327 Mdot
.33581 .35877 Mdot
.42736 .69619 Mdot
.39582 .58014 Mdot
.52605 .42039 Mdot
.63711 .67028 Mdot
.46429 .60526 Mdot
.42294 .6873 Mdot
.38154 .54565 Mdot
.57343 .6221 Mdot
.62343 .61336 Mdot
.74088 .5767 Mdot
.34129 .41974 Mdot
.4495 .59668 Mdot
.22935 .57752 Mdot
.4288 .59762 Mdot
.65418 .46904 Mdot
.39443 .51798 Mdot
.52773 .3607 Mdot
.57023 .20647 Mdot
.49249 .34466 Mdot
.42482 .53747 Mdot
.5796 .64334 Mdot
.66972 .48871 Mdot
.45544 .23005 Mdot
.37116 .28136 Mdot
.48211 .70429 Mdot
.20863 .65081 Mdot
.32488 .36606 Mdot
.30116 .38175 Mdot
.68374 .48677 Mdot
.41281 .57969 Mdot
.20898 .55756 Mdot
.37624 .61677 Mdot
.38352 .57724 Mdot
.4141 .55936 Mdot
.75404 .39533 Mdot
.66006 .44644 Mdot
.51882 .35306 Mdot
.3871 .566 Mdot
.37745 .54828 Mdot
.59199 .67559 Mdot
.32743 .38573 Mdot
.48986 .36124 Mdot
.32908 .39475 Mdot
.51579 .32045 Mdot
.77697 .68026 Mdot
.35421 .52279 Mdot
.33193 .38611 Mdot
.69997 .4364 Mdot
.58935 .62098 Mdot
.58721 .41222 Mdot
.50194 .3745 Mdot
.5046 .35593 Mdot
.38579 .54035 Mdot
.57736 .61904 Mdot
.61997 .63159 Mdot
.33793 .37692 Mdot
.63936 .46273 Mdot
.42698 .54399 Mdot
.35593 .55837 Mdot
.49806 .50424 Mdot
.5436 .31217 Mdot
.44826 .65836 Mdot
.71914 .59771 Mdot
.41859 .58134 Mdot
.60917 .62332 Mdot
.41165 .55175 Mdot
.55854 .8058 Mdot
.58615 .6149 Mdot
.40786 .51833 Mdot
.75577 .33196 Mdot
.57692 .41481 Mdot
.70453 .55647 Mdot
.45624 .57275 Mdot
.23923 .71098 Mdot
.40597 .59748 Mdot
.58825 .83143 Mdot
.43076 .28982 Mdot
.44739 .56118 Mdot
.39793 .58934 Mdot
.59496 .7624 Mdot
.40441 .538 Mdot
.4837 .33048 Mdot
.29981 .52161 Mdot
.55156 .65306 Mdot
.61846 .55902 Mdot
.39717 .43606 Mdot
.34683 .41983 Mdot
.50738 .30822 Mdot
.58797 .30703 Mdot
.31241 .39637 Mdot
.57795 .65305 Mdot
.43377 .58646 Mdot
.54524 .51956 Mdot
.48595 .3871 Mdot
.46725 .55608 Mdot
.65845 .47324 Mdot
.63968 .31069 Mdot
.50466 .40414 Mdot
.67105 .46256 Mdot
.4198 .6115 Mdot
.62905 .73099 Mdot
.33348 .27523 Mdot
.41126 .848 Mdot
.66791 .49054 Mdot
.68366 .45026 Mdot
.62493 .20994 Mdot
.34339 .42262 Mdot
.29229 .69725 Mdot
.71799 .51927 Mdot
.63628 .47657 Mdot
.25497 .6001 Mdot
.5339 .34699 Mdot
.67795 .56463 Mdot
.606 .69335 Mdot
.4414 .52242 Mdot
.42733 .56894 Mdot
.63975 .45839 Mdot
.66065 .67087 Mdot
.3494 .21459 Mdot
.66781 .45507 Mdot
.34217 .60062 Mdot
.5123 .46371 Mdot
.63822 .39259 Mdot
.53903 .30591 Mdot
.34508 .41774 Mdot
.28813 .37754 Mdot
.58698 .67158 Mdot
.3484 .41274 Mdot
.70914 .30681 Mdot
.43414 .60607 Mdot
.67526 .45182 Mdot
.66731 .39135 Mdot
.67764 .46347 Mdot
.31683 .40104 Mdot
.3622 .39718 Mdot
.61827 .63795 Mdot
.60376 .62677 Mdot
.37038 .73886 Mdot
.26385 .52472 Mdot
.39638 .527 Mdot
.7542 .64595 Mdot
.6101 .67709 Mdot
.5029 .58653 Mdot
.30529 .39481 Mdot
.33159 .38879 Mdot
.33831 .64172 Mdot
.44425 .56771 Mdot
.19985 .53055 Mdot
.44274 .56994 Mdot
.27725 .54316 Mdot
.36482 .59614 Mdot
.51206 .35895 Mdot
.44667 .57112 Mdot
.37314 .40189 Mdot
.39221 .51149 Mdot
.39161 .52237 Mdot
.53333 .35972 Mdot
.42444 .62783 Mdot
.52693 .36238 Mdot
.42326 .53451 Mdot
.30961 .40879 Mdot
.51515 .30653 Mdot
.25084 .43101 Mdot
.47088 .38149 Mdot
.50435 .2965 Mdot
.35333 .39998 Mdot
.3577 .38985 Mdot
.23464 .40446 Mdot
.60557 .64986 Mdot
.5401 .65771 Mdot
.40778 .57802 Mdot
.5319 .36917 Mdot
.66102 .44295 Mdot
.37509 .55166 Mdot
.37145 .60605 Mdot
.4516 .55309 Mdot
.57295 .6662 Mdot
.54539 .35172 Mdot
.33054 .38065 Mdot
.49401 .38685 Mdot
.53093 .39505 Mdot
.49673 .39917 Mdot
.48701 .58013 Mdot
.35339 .50568 Mdot
.37083 .76204 Mdot
.78758 .58628 Mdot
.69752 .2474 Mdot
.56271 .63528 Mdot
.51858 .29568 Mdot
.35818 .40676 Mdot
.38436 .47758 Mdot
.60002 .64971 Mdot
.52431 .37075 Mdot
.42392 .58382 Mdot
.33914 .55074 Mdot
.71668 .45107 Mdot
.34694 .62639 Mdot
.21912 .48048 Mdot
.50476 .39702 Mdot
.49504 .40752 Mdot
.75345 .34947 Mdot
.29999 .53047 Mdot
.57623 .52716 Mdot
.40241 .55786 Mdot
.3463 .37365 Mdot
.55619 .64358 Mdot
.384 .24275 Mdot
.65623 .43536 Mdot
.59415 .49834 Mdot
.41002 .5732 Mdot
.68916 .52267 Mdot
.57901 .64146 Mdot
.33124 .41102 Mdot
.63982 .45678 Mdot
.36238 .41034 Mdot
.53877 .29844 Mdot
.19012 .57054 Mdot
.42908 .60146 Mdot
.40243 .52307 Mdot
.67154 .42666 Mdot
.57569 .66365 Mdot
.3458 .35816 Mdot
.35325 .77838 Mdot
.48901 .34725 Mdot
.19196 .52678 Mdot
.62872 .64358 Mdot
.52328 .72599 Mdot
.49546 .38839 Mdot
.69238 .45415 Mdot
.24093 .39761 Mdot
.68625 .45935 Mdot
.43635 .54419 Mdot
.58954 .64514 Mdot
.64766 .46004 Mdot
.55039 .39658 Mdot
.63385 .78627 Mdot
.54164 .73558 Mdot
.4432 .58884 Mdot
.71296 .72003 Mdot
.43501 .83035 Mdot
.63791 .70517 Mdot
.65553 .43156 Mdot
.39175 .55274 Mdot
.38398 .6021 Mdot
.42741 .59383 Mdot
.66137 .48052 Mdot
.6373 .36978 Mdot
.50959 .36815 Mdot
.39495 .53216 Mdot
.35522 .40759 Mdot
.52606 .35995 Mdot
.66573 .38622 Mdot
.5001 .35192 Mdot
.56448 .67385 Mdot
.40119 .51493 Mdot
.60896 .49352 Mdot
.68168 .7788 Mdot
.66607 .44752 Mdot
.50357 .29709 Mdot
.37307 .54061 Mdot
.77519 .43284 Mdot
.60004 .64198 Mdot
.48942 .34355 Mdot
.39364 .56234 Mdot
.61203 .37928 Mdot
.44518 .2531 Mdot
.50139 .35276 Mdot
.60044 .65912 Mdot
.66405 .69445 Mdot
.40341 .57323 Mdot
.40958 .59969 Mdot
.57644 .66198 Mdot
.38458 .42904 Mdot
.583 .21613 Mdot
.41627 .5517 Mdot
.66512 .46365 Mdot
.16091 .4241 Mdot
.45993 .56639 Mdot
.29585 .60973 Mdot
.53642 .32202 Mdot
.70359 .5831 Mdot
.45478 .65679 Mdot
.47309 .51983 Mdot
.60503 .767 Mdot
.45263 .43837 Mdot
.76588 .68265 Mdot
.51551 .39453 Mdot
.44861 .30658 Mdot
.76209 .6947 Mdot
.67092 .49588 Mdot
.58756 .58523 Mdot
.49906 .53119 Mdot
.55239 .19848 Mdot
.66965 .65123 Mdot
.41117 .34273 Mdot
.47122 .23991 Mdot
.52086 .4916 Mdot
.5098 .32976 Mdot
.3365 .47624 Mdot
.42618 .5465 Mdot
.42769 .82952 Mdot
.48655 .67043 Mdot
.3259 .22226 Mdot
.70598 .72712 Mdot
.23194 .57738 Mdot
.70351 .71217 Mdot
.58167 .8114 Mdot
.35036 .74756 Mdot
.77484 .59993 Mdot
.17228 .45234 Mdot
.74407 .32551 Mdot
.23762 .62414 Mdot
.3793 .49342 Mdot
.44569 .42479 Mdot
.2634 .71144 Mdot
.4971 .73006 Mdot
.24407 .30317 Mdot
.49414 .35703 Mdot
.62324 .6826 Mdot
.50117 .52662 Mdot
.54336 .61903 Mdot
.69419 .5087 Mdot
.61582 .76678 Mdot
.57133 .8337 Mdot
.5099 .69638 Mdot
.24029 .71632 Mdot
.35192 .70443 Mdot
.57393 .1522 Mdot
.46627 .31863 Mdot
.63328 .63723 Mdot
.35817 .33308 Mdot
.76083 .36114 Mdot
.76928 .52916 Mdot
.52217 .56954 Mdot
.69436 .36911 Mdot
.26478 .45498 Mdot
.58419 .6542 Mdot
.48494 .65653 Mdot
.51396 .2635 Mdot
.78316 .51717 Mdot
.27906 .35252 Mdot
.60697 .78474 Mdot
.55385 .50888 Mdot
.66511 .56329 Mdot
.61341 .27885 Mdot
.82152 .34724 Mdot
.2488 .55809 Mdot
.4931 .82105 Mdot
.69443 .50225 Mdot
.66388 .67484 Mdot
.50148 .20012 Mdot
.26818 .49878 Mdot
.76151 .35902 Mdot
.82144 .4598 Mdot
.3966 .82703 Mdot
.8408 .47514 Mdot
.54405 .66321 Mdot
.45172 .55594 Mdot
.48503 .81057 Mdot
.29003 .63884 Mdot
.29375 .37966 Mdot
.81248 .58086 Mdot
.33516 .36571 Mdot
.53856 .64128 Mdot
.55951 .21215 Mdot
.50158 .70395 Mdot
.19252 .51863 Mdot
.35239 .36166 Mdot
.41325 .61944 Mdot
.3193 .18042 Mdot
.75996 .68426 Mdot
.7357 .57494 Mdot
.55541 .85367 Mdot
.73354 .48562 Mdot
.21888 .5352 Mdot
.64808 .4658 Mdot
.73032 .7356 Mdot
.59397 .65551 Mdot
.83458 .6383 Mdot
.6728 .77295 Mdot
.33169 .24008 Mdot
.12012 .41629 Mdot
.7173 .3321 Mdot
.54481 .53703 Mdot
.44838 .44271 Mdot
.23118 .45523 Mdot
.38901 .20465 Mdot
.2898 .27254 Mdot
.75944 .4159 Mdot
.23828 .6815 Mdot
.73434 .72328 Mdot
.25913 .61617 Mdot
.2053 .59147 Mdot
.53959 .19992 Mdot
.4946 .433 Mdot
.53812 .60859 Mdot
.47328 .34022 Mdot
.6836 .70164 Mdot
.83065 .55346 Mdot
.28549 .60499 Mdot
.13873 .42225 Mdot
.36313 .3683 Mdot
.42209 .29764 Mdot
.4996 .8382 Mdot
.26605 .4259 Mdot
.27474 .61274 Mdot
.65575 .23125 Mdot
.47388 .55556 Mdot
.69365 .26186 Mdot
.71709 .66678 Mdot
.59883 .31267 Mdot
.73299 .31278 Mdot
.68523 .62018 Mdot
.31424 .74125 Mdot
.4991 .79595 Mdot
.76918 .37017 Mdot
.55203 .65773 Mdot
.25432 .49087 Mdot
.25033 .57672 Mdot
.54447 .85745 Mdot
.57096 .26557 Mdot
.45788 .87735 Mdot
.53306 .22838 Mdot
.34138 .57181 Mdot
.47971 .62018 Mdot
.322 .53809 Mdot
.25366 .51954 Mdot
.45116 .54625 Mdot
.75702 .43612 Mdot
.5293 .85969 Mdot
.33056 .70252 Mdot
.60061 .32679 Mdot
.8032 .47862 Mdot
.41756 .85002 Mdot
.4029 .78555 Mdot
.45433 .26295 Mdot
.29802 .58741 Mdot
.69219 .2253 Mdot
.52564 .34678 Mdot
.25656 .61569 Mdot
.63483 .48537 Mdot
.39014 .24806 Mdot
.57492 .75473 Mdot
.36629 .22728 Mdot
.52799 .86028 Mdot
.59284 .22407 Mdot
.49774 .2356 Mdot
.25198 .36911 Mdot
.18164 .51328 Mdot
.80957 .51148 Mdot
.38907 .50487 Mdot
.56112 .57365 Mdot
.33848 .36239 Mdot
.40713 .76336 Mdot
.27301 .63907 Mdot
.37505 .31143 Mdot
.41545 .63192 Mdot
.29935 .30027 Mdot
.49819 .41221 Mdot
.59016 .48294 Mdot
.86476 .46955 Mdot
.47578 .57735 Mdot
.73311 .36781 Mdot
.36567 .80424 Mdot
.23691 .50696 Mdot
.5015 .83296 Mdot
.66144 .5817 Mdot
.83599 .47655 Mdot
.64589 .79046 Mdot
.36687 .29233 Mdot
.79835 .63667 Mdot
.52665 .87282 Mdot
.82897 .43976 Mdot
.44883 .64278 Mdot
.69842 .47719 Mdot
.89672 .50908 Mdot
.48405 .3761 Mdot
.79639 .43677 Mdot
.30019 .6651 Mdot
.61658 .3659 Mdot
.56496 .68631 Mdot
.35834 .49536 Mdot
.52983 .4992 Mdot
.65102 .67051 Mdot
.45386 .61256 Mdot
.84185 .40482 Mdot
.81205 .42398 Mdot
.84376 .44037 Mdot
.31497 .76808 Mdot
.79744 .64262 Mdot
.49734 .48998 Mdot
.50354 .71992 Mdot
.45946 .48652 Mdot
.38435 .52056 Mdot
.32641 .46994 Mdot
.71352 .32946 Mdot
.34261 .26228 Mdot
.76092 .52154 Mdot
.54013 .63034 Mdot
.7794 .62697 Mdot
.78808 .25757 Mdot
.3713 .71445 Mdot
.37848 .68315 Mdot
.73003 .32721 Mdot
.25881 .53614 Mdot
.69656 .68998 Mdot
.33103 .25521 Mdot
.52225 .8512 Mdot
.48334 .51795 Mdot
.25951 .6465 Mdot
.39203 .33619 Mdot
.19531 .43747 Mdot
.42922 .3899 Mdot
.62783 .7799 Mdot
.44299 .45788 Mdot
.42757 .21771 Mdot
.60222 .54967 Mdot
.3392 .22842 Mdot
.40445 .26881 Mdot
.64051 .30556 Mdot
.24478 .61608 Mdot
.72141 .39557 Mdot
.26663 .55857 Mdot
.52661 .47112 Mdot
.37367 .47222 Mdot
.45437 .4387 Mdot
.26495 .56543 Mdot
.2019 .4253 Mdot
.82777 .5674 Mdot
.52501 .88171 Mdot
.78686 .31877 Mdot
.25201 .72927 Mdot
.71566 .65876 Mdot
.44947 .52878 Mdot
.4789 .8498 Mdot
.85232 .49132 Mdot
.64223 .79951 Mdot
.6058 .23889 Mdot
.57601 .39159 Mdot
.67539 .42068 Mdot
.79054 .33151 Mdot
.41356 .36454 Mdot
.55175 .82331 Mdot
.70802 .26387 Mdot
.68709 .4982 Mdot
.51971 .1756 Mdot
.80298 .4171 Mdot
.57321 .74325 Mdot
.40317 .65529 Mdot
.46299 .536 Mdot
.51925 .69259 Mdot
.58498 .68172 Mdot
.59883 .27111 Mdot
.26218 .50993 Mdot
.52386 .33091 Mdot
.31991 .43792 Mdot
.54201 .57083 Mdot
.38219 .61507 Mdot
.40674 .43566 Mdot
.61873 .68755 Mdot
.78579 .58811 Mdot
.60014 .43605 Mdot
.8244 .62396 Mdot
.69492 .31743 Mdot
.41017 .63522 Mdot
.23986 .52067 Mdot
.51827 .248 Mdot
.63756 .22004 Mdot
.6427 .48899 Mdot
.68774 .74552 Mdot
.51091 .42261 Mdot
.25471 .4955 Mdot
.51655 .6853 Mdot
.3287 .74756 Mdot
.35404 .50357 Mdot
.73122 .59961 Mdot
.47422 .77704 Mdot
.58753 .48615 Mdot
.53658 .61406 Mdot
.54295 .60258 Mdot
.36615 .83954 Mdot
.68872 .27892 Mdot
.62398 .29721 Mdot
.67689 .75268 Mdot
.67639 .47809 Mdot
.62367 .65373 Mdot
.3156 .48781 Mdot
.32058 .75107 Mdot
.49095 .76069 Mdot
.44655 .25211 Mdot
.68426 .34803 Mdot
.39158 .30803 Mdot
.69556 .7297 Mdot
.711 .71274 Mdot
.31764 .22398 Mdot
.55408 .6119 Mdot
.36069 .77311 Mdot
.26508 .67797 Mdot
.61321 .68128 Mdot
.57524 .6953 Mdot
.77377 .49956 Mdot
.83039 .58883 Mdot
.60957 .48058 Mdot
.23282 .6832 Mdot
.21035 .4366 Mdot
.62131 .37803 Mdot
.46089 .22899 Mdot
.22685 .59761 Mdot
.66686 .75832 Mdot
.50054 .65819 Mdot
.59267 .73884 Mdot
.33117 .55804 Mdot
.3337 .61663 Mdot
.77181 .28909 Mdot
.46975 .38904 Mdot
.52467 .72203 Mdot
.6767 .61214 Mdot
.43554 .59451 Mdot
.82241 .35232 Mdot
.3944 .81323 Mdot
.64037 .21382 Mdot
.70232 .43437 Mdot
.38751 .5961 Mdot
.39925 .50961 Mdot
.30695 .60723 Mdot
.72178 .58409 Mdot
.81275 .45667 Mdot
.22841 .6021 Mdot
.69254 .6586 Mdot
.4913 .66933 Mdot
.73326 .36927 Mdot
.59833 .78828 Mdot
.457 .83293 Mdot
.56445 .46806 Mdot
.70309 .31917 Mdot
.24848 .39355 Mdot
.26067 .73188 Mdot
.46088 .42199 Mdot
.50253 .50243 Mdot
.76013 .47201 Mdot
.69641 .59753 Mdot
.42548 .2283 Mdot
.36035 .55731 Mdot
.5654 .22095 Mdot
.58221 .8091 Mdot
.22978 .30826 Mdot
.43741 .19662 Mdot
.83097 .36638 Mdot
.52243 .77567 Mdot
.68235 .59273 Mdot
.63766 .73434 Mdot
.20602 .32523 Mdot
.44222 .42035 Mdot
.76647 .65779 Mdot
.2471 .38071 Mdot
.68627 .74173 Mdot
.68409 .49481 Mdot
.67058 .53393 Mdot
.80267 .47361 Mdot
.8188 .61011 Mdot
.42807 .79802 Mdot
.62941 .77302 Mdot
.59538 .54337 Mdot
.84885 .54839 Mdot
.77446 .44705 Mdot
.50826 .47933 Mdot
.51405 .29923 Mdot
.63725 .23089 Mdot
.70404 .69854 Mdot
.75549 .62467 Mdot
.25627 .62397 Mdot
.45221 .39503 Mdot
.30518 .51324 Mdot
.56732 .72385 Mdot
.28857 .43703 Mdot
.69947 .61043 Mdot
.23951 .51934 Mdot
.58503 .81665 Mdot
.43595 .40931 Mdot
.50216 .24194 Mdot
.72705 .36825 Mdot
.19838 .59687 Mdot
.72607 .57887 Mdot
.67981 .27092 Mdot
.49846 .82237 Mdot
.41069 .28573 Mdot
.23764 .57489 Mdot
.52333 .91401 Mdot
.23308 .6417 Mdot
.79407 .54717 Mdot
.83035 .55086 Mdot
.48646 .83562 Mdot
.79333 .56839 Mdot
.40518 .19624 Mdot
.31793 .6402 Mdot
.29893 .49252 Mdot
.41547 .56069 Mdot
.86044 .46814 Mdot
.27694 .45587 Mdot
.83611 .54576 Mdot
.44928 .85342 Mdot
.52933 .69845 Mdot
.38679 .61701 Mdot
.50701 .39027 Mdot
.50543 .2749 Mdot
.30264 .44024 Mdot
.60752 .74417 Mdot
.31662 .64647 Mdot
.68919 .33127 Mdot
.53088 .2959 Mdot
.41722 .37469 Mdot
.62186 .71371 Mdot
.67506 .29369 Mdot
.71275 .59964 Mdot
.34796 .43665 Mdot
.57158 .50392 Mdot
.25834 .55281 Mdot
.45766 .65781 Mdot
.56965 .74623 Mdot
.37422 .22389 Mdot
.52831 .42997 Mdot
.49794 .34808 Mdot
.56028 .771 Mdot
.24507 .68111 Mdot
.70316 .62936 Mdot
.82946 .47862 Mdot
.62329 .22176 Mdot
.41403 .46716 Mdot
.27122 .57239 Mdot
.36958 .21641 Mdot
.18476 .43796 Mdot
.7918 .59584 Mdot
.4957 .63335 Mdot
.20338 .5269 Mdot
.53717 .56173 Mdot
.77333 .68318 Mdot
.24208 .62886 Mdot
.28538 .66743 Mdot
.46747 .33322 Mdot
.48482 .73702 Mdot
.54496 .70329 Mdot
.24685 .42555 Mdot
.58531 .5193 Mdot
.58947 .15695 Mdot
.60875 .69673 Mdot
.80641 .31043 Mdot
.66978 .43455 Mdot
.57131 .18771 Mdot
.24061 .37179 Mdot
.5256 .46719 Mdot
.5912 .52715 Mdot
.7383 .592 Mdot
.73647 .51419 Mdot
.27689 .73661 Mdot
.29105 .26064 Mdot
.49508 .3998 Mdot
.20713 .57085 Mdot
.18148 .56176 Mdot
.58914 .76382 Mdot
.43929 .61655 Mdot
.22942 .64126 Mdot
.47493 .40495 Mdot
.34674 .25855 Mdot
.45921 .84506 Mdot
.74097 .62522 Mdot
.35417 .6164 Mdot
.25947 .52971 Mdot
.76018 .66342 Mdot
.64681 .78517 Mdot
.47063 .17708 Mdot
.71728 .66607 Mdot
.70088 .46996 Mdot
.49989 .48315 Mdot
.6552 .74559 Mdot
.21503 .51042 Mdot
.65577 .55362 Mdot
.2472 .57712 Mdot
.7191 .21935 Mdot
.81423 .47437 Mdot
.81234 .4566 Mdot
.22538 .53612 Mdot
.57815 .60452 Mdot
.77961 .46667 Mdot
.26991 .60708 Mdot
.74726 .61104 Mdot
.27957 .72533 Mdot
.25576 .58674 Mdot
.30578 .22071 Mdot
.32195 .71431 Mdot
.5299 .39402 Mdot
.55031 .70187 Mdot
.33255 .71475 Mdot
.70612 .45723 Mdot
.31342 .47141 Mdot
.68091 .623 Mdot
.67704 .4255 Mdot
.70417 .6103 Mdot
.68445 .57269 Mdot
.29425 .68511 Mdot
.50593 .75776 Mdot
.69884 .65885 Mdot
.55041 .79053 Mdot
.64102 .61436 Mdot
.38747 .24179 Mdot
.5554 .30085 Mdot
.67506 .63001 Mdot
.49669 .31696 Mdot
.48045 .53098 Mdot
.58102 .48211 Mdot
.37307 .44784 Mdot
.77437 .31 Mdot
.33333 .36311 Mdot
.6034 .61153 Mdot
.60151 .18389 Mdot
.62444 .67685 Mdot
.84919 .42724 Mdot
.34568 .24507 Mdot
.5101 .68232 Mdot
.37729 .28693 Mdot
.37165 .3325 Mdot
.44933 .14571 Mdot
.59167 .71565 Mdot
.47371 .31655 Mdot
.61695 .59963 Mdot
.57156 .61199 Mdot
.70889 .35395 Mdot
.53301 .29927 Mdot
.37858 .65846 Mdot
.74063 .4344 Mdot
.44125 .47402 Mdot
.61511 .60676 Mdot
.55443 .40605 Mdot
.28984 .53999 Mdot
.82676 .60143 Mdot
.5043 .33315 Mdot
.67148 .20011 Mdot
.33865 .57074 Mdot
.46516 .79521 Mdot
.51257 .85705 Mdot
.49625 .17594 Mdot
.55188 .26888 Mdot
.15678 .50532 Mdot
.34286 .57199 Mdot
.70132 .66486 Mdot
.58754 .65848 Mdot
.27595 .65932 Mdot
.31699 .38498 Mdot
.23198 .48475 Mdot
.65857 .42545 Mdot
.4297 .21848 Mdot
.66733 .29191 Mdot
.59139 .60326 Mdot
.73751 .64455 Mdot
.34669 .75297 Mdot
.68733 .53396 Mdot
.48043 .41716 Mdot
.58577 .7617 Mdot
.49875 .75545 Mdot
.61732 .60805 Mdot
.82465 .49842 Mdot
.25676 .64906 Mdot
.74672 .7275 Mdot
.3228 .5486 Mdot
.46497 .29799 Mdot
.75101 .46854 Mdot
.71777 .6127 Mdot
.43635 .65635 Mdot
.52849 .85339 Mdot
.26274 .49334 Mdot
.75562 .45032 Mdot
.27355 .54438 Mdot
.40522 .48781 Mdot
.5575 .49544 Mdot
.60405 .2611 Mdot
.36463 .18825 Mdot
.35177 .63817 Mdot
.50708 .19333 Mdot
.50131 .62501 Mdot
.73097 .36137 Mdot
.63717 .68814 Mdot
.57701 .36355 Mdot
.49791 .7369 Mdot
.56166 .26323 Mdot
.76163 .70089 Mdot
.52488 .85359 Mdot
.71385 .46485 Mdot
.7031 .36128 Mdot
.64899 .60608 Mdot
.32895 .56983 Mdot
.61838 .54151 Mdot
.44523 .54969 Mdot
.62112 .70472 Mdot
.52162 .17172 Mdot
.74082 .60741 Mdot
.43172 .50325 Mdot
.76435 .68663 Mdot
.72378 .74129 Mdot
.84541 .5503 Mdot
.18891 .52383 Mdot
.56597 .66454 Mdot
.83249 .42922 Mdot
.40737 .67287 Mdot
.59602 .81601 Mdot
.78356 .60562 Mdot
.38875 .85053 Mdot
.59811 .743 Mdot
.66718 .59775 Mdot
.29978 .25957 Mdot
.71931 .53633 Mdot
.42731 .83451 Mdot
.48828 .45619 Mdot
.62265 .31783 Mdot
.42802 .83889 Mdot
.35953 .16253 Mdot
.47816 .63462 Mdot
.67353 .56898 Mdot
.52629 .54722 Mdot
.6777 .62938 Mdot
.44589 .28184 Mdot
.39331 .51851 Mdot
.69603 .38633 Mdot
.47799 .22942 Mdot
.25706 .56166 Mdot
.3058 .51118 Mdot
.44358 .28418 Mdot
.31478 .44431 Mdot
.28079 .53842 Mdot
.23596 .6228 Mdot
.58881 .75153 Mdot
.39025 .65945 Mdot
.33587 .55745 Mdot
.63132 .69455 Mdot
.32963 .41762 Mdot
.57627 .3012 Mdot
.42606 .53415 Mdot
.56204 .26882 Mdot
.71086 .52811 Mdot
.83478 .37991 Mdot
.5956 .3493 Mdot
.36193 .79048 Mdot
.60766 .69297 Mdot
.7255 .58918 Mdot
.5472 .80042 Mdot
.55624 .20359 Mdot
.43442 .32042 Mdot
.28523 .60477 Mdot
.74052 .70121 Mdot
.73317 .31471 Mdot
.30439 .72441 Mdot
.7753 .34864 Mdot
.69538 .43745 Mdot
.40229 .64388 Mdot
.51758 .53226 Mdot
.60461 .23121 Mdot
.54498 .60772 Mdot
.67093 .59952 Mdot
.45564 .35154 Mdot
.71009 .28819 Mdot
.37007 .80833 Mdot
.33669 .74885 Mdot
.57644 .71496 Mdot
.71632 .71156 Mdot
.53745 .32855 Mdot
.26281 .65855 Mdot
.63689 .55496 Mdot
.44267 .32268 Mdot
.76883 .38936 Mdot
.80822 .64401 Mdot
.61306 .5388 Mdot
.26045 .4478 Mdot
.41935 .59991 Mdot
.42418 .68958 Mdot
.74467 .59727 Mdot
.37559 .37966 Mdot
.66457 .30839 Mdot
.59599 .61855 Mdot
.64261 .28996 Mdot
.41666 .39941 Mdot
.29829 .48464 Mdot
.62763 .61135 Mdot
.30234 .64565 Mdot
.29668 .37256 Mdot
.72842 .42554 Mdot
.46205 .58822 Mdot
.24792 .45724 Mdot
.18887 .51104 Mdot
.42366 .6439 Mdot
.70018 .69397 Mdot
.57494 .76149 Mdot
.3027 .73328 Mdot
.71669 .63045 Mdot
.79713 .58599 Mdot
.73888 .51663 Mdot
.51636 .73738 Mdot
.56032 .23768 Mdot
.45284 .55539 Mdot
.5785 .36533 Mdot
.62634 .64813 Mdot
.62849 .75261 Mdot
.51098 .77667 Mdot
.25289 .43021 Mdot
.54099 .45528 Mdot
.52981 .8055 Mdot
.52674 .44306 Mdot
.49492 .85094 Mdot
.72137 .53637 Mdot
.26371 .50714 Mdot
.65112 .50266 Mdot
.24058 .37909 Mdot
.39055 .20821 Mdot
.7028 .74831 Mdot
.35015 .23047 Mdot
.55507 .5293 Mdot
.51098 .18916 Mdot
.79134 .51042 Mdot
.4419 .84723 Mdot
.27149 .51083 Mdot
.61575 .53662 Mdot
.31128 .5099 Mdot
.71189 .47532 Mdot
.54906 .42569 Mdot
.56685 .36818 Mdot
.38268 .6654 Mdot
.65609 .34658 Mdot
.54274 .24955 Mdot
.34215 .50655 Mdot
.77423 .41213 Mdot
.72918 .70607 Mdot
.2903 .66308 Mdot
.48971 .4376 Mdot
.35975 .2684 Mdot
.29509 .47857 Mdot
.21676 .71295 Mdot
.82157 .34574 Mdot
.42094 .60085 Mdot
.45735 .43648 Mdot
.24703 .4777 Mdot
.49633 .39607 Mdot
.35252 .66062 Mdot
.60283 .76396 Mdot
.68072 .44126 Mdot
.56945 .39035 Mdot
.69998 .27626 Mdot
.74608 .58514 Mdot
.27049 .41303 Mdot
.75666 .40345 Mdot
.84389 .39407 Mdot
.24975 .70039 Mdot
.72728 .61197 Mdot
.26919 .77082 Mdot
.59012 .24576 Mdot
.53319 .60601 Mdot
.48237 .81302 Mdot
.82953 .56626 Mdot
.23571 .51468 Mdot
.42071 .23832 Mdot
.80782 .54719 Mdot
.26691 .49821 Mdot
.26264 .60612 Mdot
.72646 .36648 Mdot
.64937 .29489 Mdot
.53063 .48799 Mdot
.37342 .33351 Mdot
.79131 .38143 Mdot
.50385 .6656 Mdot
.74207 .68788 Mdot
.47952 .22652 Mdot
.28225 .23605 Mdot
.7318 .73478 Mdot
.33254 .45841 Mdot
.44844 .27273 Mdot
.46939 .81248 Mdot
.20984 .4657 Mdot
.2918 .63381 Mdot
.38212 .23177 Mdot
.47542 .75955 Mdot
.34627 .31516 Mdot
.4986 .20752 Mdot
.26649 .55977 Mdot
.33013 .70929 Mdot
.6098 .53655 Mdot
.56102 .7586 Mdot
.70326 .33936 Mdot
.23217 .54092 Mdot
.55012 .38942 Mdot
.21973 .44319 Mdot
.56763 .77084 Mdot
.5232 .8148 Mdot
.63708 .5704 Mdot
.38572 .15335 Mdot
.79756 .60109 Mdot
.54829 .20516 Mdot
.45457 .54765 Mdot
.78101 .68343 Mdot
.63802 .56411 Mdot
.80836 .5665 Mdot
.33178 .77075 Mdot
.57126 .33828 Mdot
.73774 .49126 Mdot
.45067 .55204 Mdot
.74115 .66125 Mdot
.52877 .72205 Mdot
.34116 .7233 Mdot
.44235 .22481 Mdot
.24299 .51652 Mdot
.46123 .25685 Mdot
.2368 .42495 Mdot
.38548 .63474 Mdot
.62783 .63946 Mdot
.84821 .45389 Mdot
.55863 .53869 Mdot
.47755 .53039 Mdot
.32843 .59417 Mdot
.31363 .24531 Mdot
.19418 .63295 Mdot
.32583 .56572 Mdot
.74524 .33328 Mdot
.25452 .60656 Mdot
.40325 .47132 Mdot
.50142 .64371 Mdot
.08884 .49038 Mdot
.54198 .86828 Mdot
.54658 .63405 Mdot
.32306 .66327 Mdot
.2179 .55585 Mdot
.82834 .57744 Mdot
.39313 .33413 Mdot
.55293 .28795 Mdot
.23656 .32052 Mdot
.20532 .48181 Mdot
.35927 .59454 Mdot
.35181 .79552 Mdot
.68967 .75645 Mdot
.45539 .22004 Mdot
.75661 .69709 Mdot
.49297 .57288 Mdot
.38692 .50736 Mdot
.12181 .58043 Mdot
.657 .75029 Mdot
.4722 .55048 Mdot
.31769 .23873 Mdot
.53662 .61029 Mdot
.42635 .55484 Mdot
.74242 .3909 Mdot
.24162 .61562 Mdot
.26902 .56389 Mdot
.81965 .60834 Mdot
.56014 .60403 Mdot
.55691 .26428 Mdot
.68814 .44621 Mdot
.58834 .52435 Mdot
.34315 .53317 Mdot
.65311 .47792 Mdot
.38801 .46587 Mdot
.666 .6088 Mdot
.70734 .46527 Mdot
.20789 .58807 Mdot
.44061 .87098 Mdot
.53245 .76681 Mdot
.70689 .42445 Mdot
.33264 .50323 Mdot
.326 .71771 Mdot
.307 .44226 Mdot
.46701 .48452 Mdot
.41795 .8413 Mdot
.65517 .84285 Mdot
.62923 .32325 Mdot
.30653 .57065 Mdot
.62547 .60948 Mdot
.40596 .66108 Mdot
.564 .73411 Mdot
.62434 .43491 Mdot
.5366 .31093 Mdot
.3752 .61563 Mdot
.38888 .6355 Mdot
.66059 .42598 Mdot
.78718 .29485 Mdot
.37313 .53722 Mdot
.48908 .6481 Mdot
.60446 .80846 Mdot
.39073 .24006 Mdot
.44094 .78999 Mdot
.35037 .55154 Mdot
.77491 .46625 Mdot
.6208 .53632 Mdot
.67244 .68378 Mdot
.50431 .24216 Mdot
.79261 .63739 Mdot
.50571 .77758 Mdot
.55939 .70486 Mdot
.37958 .54359 Mdot
.32818 .42163 Mdot
.67821 .56004 Mdot
.8139 .53896 Mdot
.49416 .61843 Mdot
.62318 .80495 Mdot
.5685 .3381 Mdot
.67133 .35331 Mdot
.42937 .48033 Mdot
.84503 .50867 Mdot
.47617 .19731 Mdot
.54286 .71578 Mdot
.61183 .20265 Mdot
.65187 .25303 Mdot
.28839 .43903 Mdot
.51329 .3888 Mdot
.41141 .49589 Mdot
.56669 .60098 Mdot
.85535 .40908 Mdot
.8143 .52895 Mdot
.61251 .4148 Mdot
.64356 .31021 Mdot
.47501 .69442 Mdot
.61503 .55145 Mdot
.3503 .8359 Mdot
.41198 .34824 Mdot
.84108 .38467 Mdot
.27912 .66512 Mdot
.62622 .71634 Mdot
.68408 .60249 Mdot
.46349 .62711 Mdot
.50295 .34923 Mdot
.81818 .59572 Mdot
.40366 .63805 Mdot
.53632 .22055 Mdot
.35281 .57519 Mdot
.66168 .22574 Mdot
.57901 .42911 Mdot
.71167 .3723 Mdot
.71876 .3941 Mdot
.40677 .19714 Mdot
.56761 .80684 Mdot
.59806 .47836 Mdot
.3015 .79025 Mdot
.64289 .7362 Mdot
.68835 .74594 Mdot
.43766 .25566 Mdot
.45923 .16835 Mdot
.76146 .62064 Mdot
.7004 .65028 Mdot
.5997 .42282 Mdot
.42429 .44675 Mdot
.6233 .22701 Mdot
.3882 .469 Mdot
.69766 .55519 Mdot
.70351 .48687 Mdot
.75438 .78993 Mdot
.34224 .46286 Mdot
.5291 .57798 Mdot
.56951 .23025 Mdot
.71653 .72591 Mdot
.37564 .42726 Mdot
.38096 .82298 Mdot
.44786 .42515 Mdot
.38016 .50716 Mdot
.4984 .76627 Mdot
.28466 .65706 Mdot
.64894 .23431 Mdot
.50156 .13486 Mdot
.25559 .7038 Mdot
.65717 .3344 Mdot
.57162 .49532 Mdot
.61224 .68081 Mdot
.55979 .68227 Mdot
.37262 .30415 Mdot
.32958 .7936 Mdot
.66603 .60034 Mdot
.65536 .74628 Mdot
.43235 .15226 Mdot
.29255 .69921 Mdot
.83011 .57918 Mdot
.78241 .57465 Mdot
.61711 .69889 Mdot
.33078 .44865 Mdot
.28312 .35527 Mdot
.69652 .38952 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`2Oooooo`;o0000Z?ooool001cooooo00?o0000ooooooooool0Woooool2o`000:Sooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0Y?ooool2o`00
01oooooo0_l00022ooooo`007?ooool00ol0003oooooooooo`2>ooooo`;o00005?ooool2o`0000co
oooo0_l0000Aooooo`;o0000P_ooool001cooooo00?o0000ooooooooool0S_ooool2o`0000Cooooo
0_l0000Looooo`;o0000UOooool001cooooo0_l0001kooooo`;o00003Oooool4o`0000Oooooo0_l0
000Qooooo`;o0000T?ooool001cooooo00?o0000ooooooooool0N_ooool2o`0000gooooo1?l0000Z
ooooo`;o0000T?ooool001cooooo00?o0000ooooooooool0_?ooool2o`0008_ooooo000Looooo`03
o`000?oooooooooo077ooooo0_l00018ooooo`?o0000Roooool001cooooo00?o0000ooooooooool0
LOooool2o`0000Oooooo0_l0000oooooo`;o0000S?ooool001cooooo00?o0000ooooooooool0N_oo
ool2o`0001Gooooo0_l0002fooooo`007?ooool00ol0003oooooooooo`2Aooooo`;o00004oooool2
o`000:7ooooo000Looooo`03o`000?oooooooooo0:Kooooo0_l0002Qooooo`007?ooool00ol0003o
ooooooooo`2=ooooo`;o00001_ooool2o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`;o
00000_ooool2o`0009kooooo000Looooo`03o`000?oooooooooo06Cooooo0_l0000>ooooo`;o0000
3_ooool2o`0000Oooooo0ol00005ooooo`;o00000oooool2o`000003ooooool0003o000000Kooooo
0_l00002ooooo`Co0000W?ooool001cooooo00?o0000ooooooooool0I?ooool2o`0000kooooo0_l0
000>ooooo`;o00002?ooool2o`0001_ooooo0_l00004ooooo`;o00003Oooool2o`0008Oooooo000L
ooooo`03o`000?oooooooooo06oooooo0_l0000Aooooo`;o00006Oooool2o`0000gooooo0_l00003
ooooo`;o00000oooool2o`0000Sooooo0_l00027ooooo`007?ooool00ol0003oooooooooo`1_oooo
o`;o00000_ooool2o`0000gooooo0_l0000<ooooo`;o00000oooool2o`0000;ooooo0_l00002oooo
o`;o00000oooool2o`0000Sooooo0_l000000ooooooo0000o`000005ooooo`;o00002oooool2o`00
08Cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool0
0ol0003oooooooooo`1Zooooo`;o00001oooool2o`0001Kooooo0_l000000ooooooo0000o`000002
o`0000?ooooo1_l000000ooooooo0000o`000003ooooo`?o00001Oooool2o`0000Cooooo1?l0000@
ooooo`;o00001_ooool2o`0007cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ
8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1Zooooo`?o0000
4oooool2o`0000Sooooo0ol000001Ooooooo0000o`000?l0003ooooo00;o00000oooool2o`0000?o
oooo0_l00003ooooo`;o00001_ooool2o`0000Gooooo1?l0000Gooooo`;o0000O?ooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`00
0?oooooooooo06_ooooo0_l00004ooooo`;o00000oooool2o`0000Kooooo1?l00008ooooo`?o0000
0_ooool2o`000003ooooool0003o000000?ooooo1?l0000Aooooo`;o00000_ooool4o`000004oooo
ool0003o0000o`00097ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo
00?oV9RHob4Q8Oo^k^h01_ooool3o`00077ooooo0_l00003ooooo`;o00001_ooool4o`0000Kooooo
0_l000000ooooooo0000o`00000:ooooo`Co00001?ooool2o`0000_ooooo0_l00002ooooo`;o0000
0oooool3o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`;o00004Oooool2o`00077ooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Ooo
ool00ol0003oooooooooo`1cooooo`;o00001_ooool2o`0000?ooooo0_l00006ooooo`;o00005Ooo
ool2o`0000gooooo0_l000000ooooooo0000o`000003o`0000Cooooo0_l000000ooooooo0000o`00
0004ooooo`;o00004Oooool2o`00077ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooo
oooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1cooooo`;o00001_ooool2
o`0000Sooooo0_l0000Gooooo`;o00002?ooool2o`0000Cooooo0_l000000ooooooo0000o`000004
o`0009;ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RH
oa0@4006ooooo`03o`000?oooooooooo07_ooooo0_l00008ooooo`;o00005Oooool4o`0000Gooooo
0_l000000ooooooo0000o`000008ooooo`;o000000?oooooo`000?l000003_ooool6o`0000;ooooo
0_l0001jooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01_ooool00ol0003oooooooooo`1^ooooo`;o0000;?ooool2o`0000Oooooo0_l000000ooo
oooo0000o`000008ooooo`;o00004Oooool6o`000003ooooool0003o000000?o00001_ooool2o`00
00Oooooo0_l0001Wooooo`007?ooool00ol0003oooooooooo`1^ooooo`;o00001?ooool2o`00017o
oooo0ol0000Hooooo`;o00001?ooool4o`0000Wooooo0_l00003ooooo`;o00000oooool5o`0000So
oooo0_l000000ooooooo0000o`000006ooooo`;o00001oooool2o`0006Oooooo000Looooo`03o`00
0?oooooooooo063ooooo0_l0000<ooooo`;o00000oooool4o`0000_ooooo0_l00003ooooo`?o0000
1_ooool2o`00013ooooo0_l00006ooooo`;o00001?ooool2o`0000;ooooo0ol000000ooooooo0000
o`000002o`000003ooooool0003o000000Go00001Oooool4o`0001Wooooo0_l0001Qooooo`007?oo
ool00ol0003oooooooooo`1Pooooo`;o000000Coooooo`000?l0003ooooo0_l00006ooooo`;o0000
0oooool5o`0000?ooooo0_l00005ooooo`;o00002oooool3o`0001Sooooo0ol00003ooooo`;o0000
0_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000Sooooo1_l0000Iooooo`;o0000
HOooool001cooooo00?o0000ooooooooool0Hoooool2o`000003ooooool0003o000000_ooooo0_l0
00000ooooooo0000o`000003ooooo`;o00001_ooool2o`0000Oooooo0_l000000ooooooo0000o`00
0007ooooo`;o00004Oooool2o`0000;ooooo0ol00002ooooo`;o00001Oooool4o`0000Cooooo0_l0
0002ooooo`;o00001_ooool2o`0000;ooooo0_l00008ooooo`;o0000J_ooool001cooooo00?o0000
ooooooooool0Eoooool2o`0000Kooooo0_l00009ooooo`?o000000?oooooo`000?l000000oooool2
o`0000Oooooo1?l00003ooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo1?l00004
ooooo`;o00003oooool2o`0000Cooooo1?l000001?oooooo0000o`000?l00005ooooo`;o00000ooo
ool4o`0000;ooooo0_l00006ooooo`;o00000_ooool2o`0000Sooooo0_l0001Zooooo`007?ooool0
0ol0003oooooooooo`1Gooooo`;o00001_ooool2o`0000Cooooo0_l00003ooooo`?o000000?ooooo
o`000?l000002?ooool2o`0000;ooooo1?l00006ooooo`;o00002?ooool4o`0000Cooooo1?l0000:
ooooo`;o000000?oooooo`000?l000001?ooool4o`0000;ooooo0_l00005ooooo`;o00000oooool2
o`0000Sooooo0_l00004ooooo`?o0000MOooool001cooooo00?o0000ooooooooool0F?ooool2o`00
00_ooooo0_l00007ooooo`;o00002?ooool2o`0001kooooo1?l00002ooooo`;o00001_ooool2o`00
00Oooooo0_l0000@ooooo`;o00002?ooool2o`0000;ooooo1ol0000Aooooo`;o0000H?ooool001co
oooo00?o0000ooooooooool0F?ooool2o`0000Wooooo0_l00003ooooo`;o00001?ooool2o`0000Ko
oooo0_l00003ooooo`;o00000_ooool2o`0000Cooooo1?l00003ooooo`;o00001oooool2o`0000Oo
oooo0_l0000Booooo`;o00003?ooool5o`0000[ooooo0_l00003ooooo`;o000000?oooooo`000?l0
00000_l00003ooooo`;o00001oooool2o`00063ooooo000Looooo`03o`000?oooooooooo06?ooooo
0_l00003ooooo`;o00003?ooool2o`000003ooooool0003o000000;o00000_ooool2o`0000Cooooo
1?l00003ooooo`?o00001_ooool2o`0000Sooooo1Ol0000>ooooo`;o00003?ooool5o`0001;ooooo
1?l00003ooooo`;o0000JOooool001cooooo00?o0000ooooooooool0H_ooool2o`0000Wooooo0_l0
0002ooooo`;o00001_ooool3o`00017ooooo1?l00009ooooo`;o00000oooool5o`00013ooooo0ol0
0005ooooo`;o0000Roooool001cooooo00?o0000ooooooooool0H_ooool2o`0000Wooooo0_l00002
ooooo`;o00002?ooool2o`0001;ooooo0ol00002ooooo`So00002Oooool2o`0000gooooo0ol00005
ooooo`;o00006Oooool2o`0000?ooooo0_l000000ooooooo0000o`00001Xooooo`007?ooool2o`00
07cooooo0_l00003ooooo`;o00002?ooool2o`000003ooooool0003o000000go000000Coooooo`00
0?l0003ooooo1?l000000ooooooo0000o`000006ooooo`;o00001Oooool2o`00027ooooo0_l00003
ooooo`;o000000?oooooo`000?l00000J?ooool001cooooo00?o0000ooooooooool0H?ooool4o`00
00Cooooo0_l00009ooooo`;o00002_ooool3o`0000Sooooo0_l000001Ooooooo0000o`000?l0003o
oooo00Go00000_ooool7o`000003ooooool0003o000000;o00001_ooool2o`000003ooooool0003o
000000Gooooo0_l0000Jooooo`;o00002_ooool2o`0000;ooooo0_l0001Wooooo`007?ooool00ol0
003oooooooooo`1Pooooo`Co00001?ooool2o`0000?ooooo0_l00003ooooo`?o00001oooool2o`00
0003ooooool0003o000000Wooooo0_l000001?oooooo0000o`000?l00002ooooo`Co00001Oooool2
o`000003ooooool0003o000000;o00002?ooool2o`0000Wooooo0_l00002ooooo`;o000000?ooooo
o`000?l000004_ooool2o`0000[ooooo1_l0000Jooooo`;o0000Boooool001cooooo00?o0000oooo
ooooool0Foooool2o`000003ooooool0003o000000Sooooo0_l00003ooooo`?o00000_ooool2o`00
00Oooooo0ol0000:ooooo`Co00001_ooool2o`0000Sooooo1_l0000<ooooo`;o00001?ooool3o`00
00;ooooo0_l000000ooooooo0000o`000002ooooo`;o00001Oooool2o`0000;ooooo0_l0000Aoooo
o`Co00006_ooool2o`0004_ooooo000Looooo`03o`000?oooooooooo05_ooooo0_l000000ooooooo
0000o`000007ooooo`?o00000_ooool4o`0000_ooooo0_l0000:ooooo`?o00001_ooool2o`0000[o
oooo0_l00002ooooo`;o000000?oooooo`000?l000002Oooool2o`000003ooooool0003o000000?o
00002_ooool2o`0000Gooooo0_l00002ooooo`?o00004?ooool6o`0006Gooooo000Looooo`03o`00
0?oooooooooo06Oooooo0_l00003ooooo`;o00006Oooool2o`0000Oooooo0_l0000:ooooo`;o0000
1Oooool5o`0000Gooooo2ol0000Dooooo`;o00004?ooool3o`000003ooooool0003o000000;o0000
Hoooool001cooooo00?o0000ooooooooool0LOooool2o`0000gooooo0_l0000Iooooo`Co00001_oo
ool4o`0000Cooooo1?l000000ooooooo0000o`000006o`0001;ooooo0_l0000Fooooo`?o0000H_oo
ool001cooooo00?o0000ooooooooool0F_ooool2o`0001Gooooo0_l0000=ooooo`;o00000oooool2
o`0000Oooooo0_l00009ooooo`Ko00002?ooool2o`0000;ooooo0_l00002ooooo`Ko00000oooool2
o`0000Gooooo0_l0000Gooooo`?o00002_ooool4o`00063ooooo000Looooo`03o`000?oooooooooo
05[ooooo0_l0000=ooooo`;o00006?ooool4o`0000Oooooo0_l00008ooooo`Go00000oooool2o`00
00;ooooo0_l00005ooooo`;o00000oooool2o`0000gooooo1Ol00009ooooo`;o00002Oooool3o`00
00?ooooo1?l00005ooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0D_ooool2o`00013o
oooo0_l00003ooooo`;o00000_ooool2o`0000Kooooo0_l0000<ooooo`?o00000oooool2o`0000go
oooo0ol00005ooooo`;o00000_ooool2o`0001[ooooo1Ol00008ooooo`;o00003Oooool6o`0006Oo
oooo000Looooo`03o`000?oooooooooo05;ooooo0_l0000@ooooo`;o00001oooool3o`0000Gooooo
0_l0000Booooo`;o00000_ooool2o`0000[ooooo0_l00005ooooo`;o00002?ooool3o`0000Oooooo
0_l0000:ooooo`Go00005oooool5o`0006Sooooo000Looooo`03o`000?oooooooooo05;ooooo0_l0
000=ooooo`;o00002oooool2o`0000Gooooo0_l0000;ooooo`;o00000oooool4o`000004ooooool0
003o0000o`0001_ooooo1?l00006ooooo`?o00002Oooool3o`0008Kooooo000Looooo`03o`000?oo
oooooooo05;ooooo0_l0000=ooooo`;o00001_ooool2o`0000cooooo0_l00009ooooo`;o00000ooo
ool2o`0000?ooooo0_l000000ooooooo0000o`000009ooooo`;o00001?ooool3o`0000Oooooo1?l0
0002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00006Oooool2o`0000Sooooo0_l0
00000ooooooo0000o`000003ooooo`;o00002_ooool4o`0004kooooo000Looooo`03o`000?oooooo
oooo06Wooooo0_l00008ooooo`;o00000_ooool2o`0000Sooooo0_l00005ooooo`;o00001Oooool2
o`0000Wooooo0_l00004ooooo`Ko00001Oooool3o`0000;ooooo0_l00007ooooo`;o00000oooool2
o`0000gooooo0_l00006ooooo`;o00000_ooool2o`0000Gooooo0_l000000ooooooo0000o`000003
o`0000?ooooo0_l0000:ooooo`Co0000C_ooool001cooooo00?o0000ooooooooool0Loooool2o`00
00cooooo0_l00005ooooo`;o00002?ooool2o`0000cooooo2?l00003ooooo`?o00002oooool3o`00
00Cooooo0_l0000;ooooo`Co00001?ooool4o`0000Oooooo0_l00003ooooo`;o000000?oooooo`00
0?l000004_ooool2o`0004_ooooo000Looooo`03o`000?oooooooooo05Gooooo0_l0000:ooooo`;o
00008_ooool2o`0000_ooooo0ol0000;ooooo`ko00002oooool3o`0000Cooooo0_l00005ooooo`;o
00001_ooool2o`0000Kooooo0_l0000?ooooo`;o00000oooool2o`0000gooooo0_l0001;ooooo`00
7?ooool2o`0004_ooooo0_l00009ooooo`;o00001oooool2o`000003ooooool0003o000002;ooooo
0_l00003ooooo`;o00001oooool2o`0000[ooooo4?l00002ooooo`;o00001?ooool2o`000003oooo
ool0003o000000_ooooo0_l00009ooooo`;o00006Oooool2o`0000Wooooo0_l0001?ooooo`007?oo
ool00ol0003oooooooooo`1:ooooo`Co00003oooool3o`0001Gooooo0_l00008ooooo`;o00002Ooo
ool2o`0000_ooooo0_l00005oooooa7o00000_ooool2o`0000Cooooo0_l0000Dooooo`;o00000ooo
ool2o`0002;ooooo1?l0001?ooooo`007?ooool00ol0003oooooooooo`1:ooooo`Co00003oooool2
o`0001Kooooo0_l00008ooooo`;o00003Oooool2o`0000Oooooo0_l000001?oooooo0000o`000?oo
oolBo`0000cooooo0_l0000:ooooo`;o00000oooool5o`0000[ooooo0_l00006ooooo`;o00004Ooo
ool2o`00057ooooo000Looooo`03o`000?oooooooooo04Oooooo0_l000000ooooooo0000o`00000_
ooooo`;o00004Oooool2o`0000Gooooo0ol00002oooooaGo00003?ooool2o`0000[ooooo0ol00002
ooooo`Go00000oooool2o`0000Gooooo0_l00006ooooo`;o00004oooool4o`0000Kooooo0_l00015
ooooo`007?ooool00ol0003oooooooooo`17ooooo`;o0000;Oooool2o`0000?ooooo0_l0000Hoooo
o`?o00000oooool8o`000003ooooool0003o000000Wo00003_ooool5o`0000Kooooo0_l00002oooo
o`?o00001Oooool2o`0001Cooooo0_l0000<ooooo`Co00001_ooool2o`0004Gooooo000Looooo`03
o`000?oooooooooo06gooooo0_l00007ooooo`;o00007_ooool2o`0000?ooooo5?l00005ooooo`;o
00001oooool5o`0000[ooooo0_l00007ooooo`;o000000?oooooo`000?l000003?ooool2o`0000;o
oooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1Qooooo`;o00002_ooool2o`0002Gooooo
1?l00003oooooa;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001?ooool2o`0000Oooooo
1Ol00004ooooo`;o000000?oooooo`000?l000000oooool2o`0000;ooooo1?l0000>ooooo`;o0000
Boooool001cooooo00?o0000ooooooooool0BOooool2o`0001Kooooo0_l0000Vooooo`;o000000?o
ooooo`000?l000001_ooool2o`0000Gooooo4ol0000Aooooo`;o00001Oooool5o`0000Oooooo0_l0
0003ooooo`Go00000_ooool2o`000003ooooool0003o000000Gooooo0_l00002ooooo`;o00003_oo
ool2o`0004_ooooo000Looooo`03o`000?oooooooooo03Kooooo0_l00007ooooo`;o00002?ooool2
o`0003kooooo0_l000000ooooooo0000o`00000=oooooa?o00002Oooool2o`0000Kooooo0_l00007
ooooo`?o00001oooool2o`0000Cooooo1?l0000<ooooo`Co00000_ooool2o`0005Wooooo000Loooo
o`03o`000?oooooooooo03Kooooo0_l00007ooooo`;o0000>Oooool2o`0000gooooo0_l0000@oooo
oaCo00001?ooool2o`0000;ooooo0ol00005ooooo`;o00003oooool2o`0000Wooooo0_l0000<oooo
o`?o00000_ooool2o`0005Wooooo000Looooo`03o`000?oooooooooo04Sooooo0_l0000[ooooo`;o
00000oooool2o`0000gooooo0_l0000>oooooaKo00001?ooool2o`0000?ooooo0_l00005ooooo`;o
00002_ooool2o`0000?ooooo0_l00009ooooo`Co00001Oooool3o`0000;ooooo0_l00007ooooo`;o
00002Oooool2o`0004[ooooo000Looooo`03o`000?oooooooooo04Kooooo1?l0000Uooooo`Co0000
0_ooool3o`0000Cooooo0_l0000Fooooo`;o00000ooooolGo`0001_ooooo0_l00005ooooo`;o0000
2?ooool3o`000003ooooool0003o000000;ooooo0ol00005ooooo`Co00000_ooool2o`0000Wooooo
0_l0001:ooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00000_ooool2o`0002Oooooo1?l0
0003ooooo`;o00001?ooool2o`0001Kooooo0_l00003ooooo`ko000000?oooooo`000?l000001_l0
0005ooooo`?o00005oooool2o`000003ooooool0003o000000Oooooo0_l00003ooooo`;o00002_oo
ool6o`0005Oooooo000Looooo`03o`000?oooooooooo03Cooooo0_l0000<ooooo`Co0000=_ooool2
o`0000cooooo0_l0000:ooooo`;o000000?oooooo`000?l000003?l000000ooooooo0000o`000004
o`0000Oooooo0ol000000ooooooo0000o`00000Dooooo`;o00002_ooool2o`000004ooooool0003o
0000ooooo`;o00002?ooool2o`0000?ooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`0d
ooooo`;o00003_ooool2o`0001Gooooo0_l0000Uooooo`;o00001_ooool2o`0000[ooooo0_l00000
0ooooooo0000o`00000@o`000003ooooool0003o000000_ooooo0_l0000Hooooo`;o00002Oooool2
o`000003ooooool0003o000000Sooooo0_l0000;ooooo`;o00003Oooool2o`00043ooooo000Loooo
o`03o`000?oooooooooo043ooooo0_l0000Iooooo`?o00002oooool2o`0000cooooo0_l00009oooo
o`;o00005ooooolDo`000003ooooool0003o000001oooooo1?l00002ooooo`;o00005_ooool2o`00
00Cooooo0_l000000ooooooo0000o`000006ooooo`;o00001Oooool4o`0003kooooo000Looooo`;o
0000@Oooool2o`0001Oooooo1Ol000001?oooooo0000o`000?ooool2o`0000Gooooo0_l000000ooo
oooo0000o`000009ooooo`;o00002Oooool2o`0000kooooo0_l00006oooooaGo000000?oooooo`00
0?l000003?ooool2o`00017ooooo0_l00004ooooo`Go00004oooool5o`000003ooooool0003o0000
00?o00001_ooool2o`0000Gooooo1?l0000nooooo`007?ooool00ol0003oooooooooo`10ooooo`;o
00002?ooool2o`0000[ooooo1ol00002ooooo`Go00001oooool5o`0001;ooooo0_l0000<ooooo`Co
00001?oooolGo`000003ooooool0003o000000cooooo0_l0000Fooooo`;o000000Coooooo`000?l0
003o00001_ooool3o`0000cooooo0ol00002ooooo`Co00001Oooool2o`0000Kooooo0ol0000ooooo
o`007?ooool00ol0003oooooooooo`10ooooo`;o00002?ooool2o`0000[ooooo1?l000000ooooooo
0000o`000003ooooo`;o00000_ooool2o`000003ooooool0003o000000Co000000?oooooo`000?l0
00008?ooool2o`0000Kooooo5ol000000ooooooo0000o`00000<ooooo`;o00005_ooool2o`0000[o
oooo0ol0000Jooooo`;o00001_ooool3o`0003oooooo000Looooo`03o`000?oooooooooo05Sooooo
0_l00003ooooo`;o00000oooool9o`000004ooooool0003o0000o`0002_ooooo5Ol0000Hooooo`;o
00005Oooool2o`0000;ooooo0ol0000?ooooo`;o00000_ooool2o`0004oooooo000Looooo`03o`00
0?oooooooooo03Oooooo0_l0000Tooooo`;o00000ooooolAo`00013ooooo0_l0000Doooooa;o0000
0_ooool2o`00013ooooo0_l00006ooooo`;o00005Oooool2o`000003ooooool0003o000000;o0000
1Oooool2o`0000;ooooo0_l00003ooooo`?o00000_ooool2o`0004oooooo000Looooo`03o`000?oo
oooooooo03Oooooo0_l0000Kooooo`;o000000?oooooo`000?l000001oooool2o`000003ooooool0
003o000000So00000_ooool4o`00013ooooo0_l0000Cooooo`ko000000?oooooo`000?l000001Ol0
000:ooooo`;o00001Oooool2o`0000Cooooo0_l0000@ooooo`;o00002?ooool4o`0000Gooooo0_l0
0002ooooo`;o00000oooool2o`0000?ooooo0_l0000@ooooo`;o0000?Oooool001cooooo00?o0000
ooooooooool0>?ooool2o`0001Cooooo0_l00004ooooo`;o000000?oooooo`000?l000000oooool2
o`0000;ooooo3Ol00002ooooo`;o000000?oooooo`000?l000003oooool2o`0001?ooooo3ol00000
0ooooooo0000o`000005o`0000Gooooo0_l00002ooooo`;o00002oooool2o`00013ooooo1Ol00002
ooooo`;o00001?ooool2o`0000;ooooo1?l0000Eooooo`;o00001oooool2o`0003gooooo000Loooo
o`03o`000?oooooooooo03Sooooo0_l00008ooooo`;o00001_ooool2o`0000;ooooo0_l0000<oooo
o`;o000000?oooooo`000?l000004?l000000ooooooo0000o`00000?ooooo`;o00002?ooool2o`00
00Wooooo5ol00005ooooo`;o00001?ooool2o`0000oooooo0_l00002ooooo`;o00002?ooool3o`00
00;ooooo0_l00003ooooo`?o00000_ooool4o`0000[ooooo0_l00009ooooo`;o0000A_ooool001co
oooo00?o0000ooooooooool0@_ooool2o`0000Kooooo0_l0000Aooooo`Co000000?oooooo`000?l0
00003Ol0000Booooo`?o00001oooool2o`0000[ooooo5?l0000=ooooo`;o00002Oooool2o`0000Co
oooo0_l00002ooooo`;o000000?oooooo`000?l000002_ooool2o`0000?ooooo0_l00009ooooo`;o
00001_ooool2o`00057ooooo000Looooo`03o`000?oooooooooo03Gooooo0_l0000Aooooo`;o0000
4?ooool2o`000003ooooool0003o000001?o00004_ooool2o`0000gooooo0_l00002ooooo`Ko0000
00?oooooo`000?l000003?l000000ooooooo0000o`00000Fooooo`?o00002_ooool2o`0000Kooooo
0_l00002ooooo`;o00003_ooool2o`0000Oooooo0_l00003ooooo`;o00004oooool2o`0003Kooooo
000Looooo`03o`000?oooooooooo03Gooooo0_l0000Aooooo`Co000000?oooooo`000?l000002ooo
oolIo`0000?ooooo0_l0000KoooooaSo00000_ooool2o`0001Cooooo0_l000000ooooooo0000o`00
000?ooooo`Go00001_ooool2o`0001?ooooo0_l00003ooooo`?o00003?ooool2o`0000Cooooo0_l0
000fooooo`007?ooool00ol0003oooooooooo`1:ooooo`Go00003?oooolHo`0000?ooooo0_l0000=
ooooo`;o000000?oooooo`000?l000002oooool2o`0000;ooooo4?l00005ooooo`;o00004oooool2
o`00013ooooo1_l00006ooooo`?o00000_ooool2o`0000_ooooo0_l00008ooooo`;o00003?ooool4
o`0003[ooooo000Looooo`03o`000?oooooooooo04Oooooo0_l00002ooooo`;o00003_ooool2o`00
00;ooooo5Ol0000Aooooo`;o000000?oooooo`000?l000004?ooool>o`0000Kooooo0_l0000Noooo
o`;o00001?ooool4o`000004ooooool0003o0000ooooo`Wo000000?oooooo`000?l000001_ooool2
o`0000?ooooo0_l0000Hooooo`;o00002Oooool2o`0002oooooo000Looooo`03o`000?oooooooooo
03oooooo0_l00002ooooo`;o00000_ooool2o`0001Kooooo1_l000000ooooooo0000o`00000=o`00
01?ooooo0_l0000;ooooo`;o00000oooool6o`000003ooooool0003o000000Go00001oooool2o`00
00Cooooo0_l00008ooooo`;o00001?ooool2o`0000?ooooo0_l00002oooooaOo00001Oooool6o`00
00Cooooo1?l0000Pooooo`;o0000;oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2
ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo03[ooooo0_l00003
ooooo`;o00000_ooool2o`0000Sooooo0_l0000?oooooaWo00004Oooool2o`0000_ooooo0ol00002
ooooo`Go00000_ooool4o`0000?ooooo0_l00003ooooo`Co00001?ooool4o`0000Kooooo0_l00000
1?oooooo0000o`000?oooolNo`0000;ooooo0ol00002ooooo`Go00001Oooool5o`0001Gooooo0_l0
000iooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo03[ooooo0_l0000Aooooo`;o00001Oooool3o`0000Oooooo
5_l000000ooooooo0000o`00000?ooooo`;o00001oooool2o`0000Cooooo0ol000000ooooooo0000
o`000007o`0000;ooooo0_l00002ooooo`Wo00001_ooool2o`0000Wooooo0_l00002ooooo`[o0000
0oooool6o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l000000ol00008ooooo`;o0000
0oooool3o`0001Gooooo0_l0000iooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`09ooooo`Go00001_ooool00ol0003oooooooooo`1:ooooo`Go000000?oooooo`000?l000000_oo
ool4o`0000Oooooo6?l0000;ooooo`Ko00001oooool2o`0000Sooooo2Ol00002ooooo`;o00000ooo
ool4o`0000;ooooo0_l00009ooooo`;o00002oooool5o`0001Kooooo1ol000000ooooooo0000o`00
0005ooooo`;o00001Oooool2o`0000?ooooo0_l0001:ooooo`0000?oooooo`000?ooool00_ooool0
0ol0003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol00018ooooo`Go00000_oo
ool3o`0000?ooooo0ol000001?oooooo0000o`000?l00004oooooaOo00001?ooool2o`0000Gooooo
1_l0000Dooooo`Oo00005oooool2o`0000Gooooo1?l00007ooooo`;o00001_ooool2o`0000cooooo
0_l000000ooooooo0000o`000002o`000003ooooool0003o000000cooooo0_l00003ooooo`;o0000
1Oooool2o`0004?ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Co
gMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`18ooooo`Go000000?oooooo`000?l00000
0_l00003ooooo`;o00000_ooool3o`0000Cooooo5ol00004ooooo`;o00001_ooool2o`0000gooooo
0_l00003ooooo`;o00000oooool8o`0000cooooo0_l000000ooooooo0000o`00000:ooooo`Ko0000
00?oooooo`000?l000001?ooool2o`0000Kooooo0_l0000?ooooo`Co00002Oooool2o`00013ooooo
0_l00008ooooo`;o0000>Oooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_oo
ool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo04Wooooo2Ol00009ooooo`;o00000ooo
oolFo`0001Cooooo0_l00006ooooo`;o00000oooool2o`0000Cooooo1ol0000<ooooo`;o000000?o
ooooo`000?l000001oooool6o`0000Cooooo0_l0000:ooooo`;o00004Oooool4o`0000Wooooo0_l0
0004ooooo`;o00005?ooool2o`0000;ooooo0_l0000eooooo`0000KoooooogMgMonHV9SooooooiRH
V?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0:oooool2o`0001[ooooo
0_l000000ooooooo0000o`000003o`0000cooooo0_l00003oooooaCo00005_ooool2o`00017ooooo
2_l0000?ooooo`;o00000_ooool:o`0000cooooo1Ol00007ooooo`;o00002?ooool2o`0000?ooooo
0_l0000;ooooo`;o00006?ooool2o`0003Gooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPgo
oooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`0[ooooo`;o00005oooool2o`000003
ooooool0003o000000;ooooo0_l00007ooooo`;o00002ooooolCo`0002?ooooo1?l00003ooooo`Co
000000?oooooo`000?l000000ol00004ooooo`;o00002?ooool7o`0000Cooooo1?l0000;ooooo`;o
000000Coooooo`000?l0003o00001_ooool2o`0000Sooooo0ol00002ooooo`;o00002oooool2o`00
04oooooo000Looooo`03o`000?oooooooooo02?ooooo0_l0000:ooooo`;o00003?ooool2o`0000Go
oooo0_l0000>ooooo`;o00002_ooool2o`0000;ooooo3_l0000@ooooo`;o00004oooool4o`0000Co
oooo2ol00002ooooo`;o00001_ooool7o`0000Oooooo0ol00007ooooo`;o00001_ooool2o`00013o
oooo0ol0000:ooooo`;o000000Coooooo`000?l0003ooooo0_l00005ooooo`?o00003Oooool2o`00
03Oooooo000Looooo`03o`000?oooooooooo02?ooooo0_l0000:ooooo`;o00003?ooool2o`00013o
oooo0_l00004ooooo`?o00001Oooool2o`000003ooooool0003o000000Cooooo3?l0000@ooooo`;o
00001_ooool4o`0000[ooooo0_l00007ooooo`[o00001Oooool9o`0000Wooooo0_l00008ooooo`;o
00001oooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o00003oooool2o`000004
ooooool0003o0000ooooo`;o00001Oooool3o`0000gooooo0_l000000ooooooo0000o`00000doooo
o`007?ooool00ol0003oooooooooo`0Yooooo`;o00001_ooool2o`0000Gooooo0_l0000Eooooo`;o
00001?ooool3o`0000Gooooo0_l00008ooooo`_o00006?ooool5o`0000?ooooo0_l0000=ooooo`[o
000000Goooooo`000?l0003o0000ooooo`08o`0000?ooooo0_l00002ooooo`Co00000oooool2o`00
00gooooo2Ol00004ooooo`;o00001Oooool2o`0001;ooooo0_l00005ooooo`;o00003Oooool2o`00
03Cooooo000Looooo`03o`000?oooooooooo02Wooooo0ol00005ooooo`;o00001Oooool2o`0000Co
oooo0_l00009ooooo`;o000000?oooooo`000?l000001Oooool2o`0001Kooooo0ol00008ooooo`;o
00005Oooool3o`0000;ooooo0_l0000>ooooo`Co000000?oooooo`000?l000002_l00008ooooo`;o
00000_ooool4o`0000?ooooo0_l00005ooooo`;o00000oooool3o`000003ooooool0003o000000Co
00000_ooool2o`0000;ooooo1?l00003ooooo`;o00002Oooool2o`0000Gooooo1?l000000ooooooo
0000o`000002ooooo`;o00002_ooool2o`0003Oooooo000Looooo`03o`000?oooooooooo02[ooooo
0_l0000@ooooo`Co00002Oooool2o`000003ooooool0003o000000;o00000oooool2o`0001Kooooo
0ol00008ooooo`;o000000?oooooo`000?l000004?ooool2o`000003ooooool0003o000001;ooooo
0_l00003ooooo`Oo000000Coooooo`000?l0003o00000oooool2o`000003ooooool0003o000001?o
oooo4ol00004ooooo`;o00000oooool2o`0000Sooooo0ol00005ooooo`?o00000_ooool2o`0000Wo
oooo0_l00003ooooo`;o0000=oooool001cooooo00?o0000ooooooooool09_ooool2o`0001Cooooo
0_l00002ooooo`;o00003?ooool2o`0000[ooooo0_l000001?oooooo0000o`000?ooool2o`0000;o
oooo0_l00005ooooo`;o00003?ooool2o`0000Gooooo0_l00009ooooo`?o00001Oooool2o`0000So
oooo0ol00002ooooo`;o00000_ooool4o`0000_ooooo0_l000000ooooooo0000o`00000:ooooo`;o
00000_ooool2o`0000Cooooo4ol0000@ooooo`Go00000_ooool2o`000004ooooool0003o0000o`00
00gooooo0_l0000looooo`007?ooool00ol0003oooooooooo`0Vooooo`;o00001Oooool2o`00017o
oooo1?l00002ooooo`;o00003Oooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`00
00;ooooo0_l00005ooooo`Co00003_ooool2o`000003ooooool0003o000000Oooooo0_l000001?oo
oooo0000o`000?l00002ooooo`Co00002?ooool3o`0000;ooooo0_l00002ooooo`;o00001?ooool2
o`0000oooooo1?l00003ooooo`;o000000Coooooo`000?l0003o00001?oooolDo`0000Kooooo0_l0
0003ooooo`;o00000_ooool3o`0000Cooooo0_l00005ooooo`;o0000B?ooool001cooooo00?o0000
ooooooooool0;Oooool2o`0000Wooooo0ol000000ooooooo0000o`000003ooooo`?o00000_ooool2
o`0000gooooo0_l00003ooooo`Co000000?oooooo`000?l000000oooool2o`000004ooooool0003o
0000ooooo`;o000000?oooooo`000?l000003_ooool5o`0000Oooooo0_l00002ooooo`Ko00002?oo
ool2o`0000Gooooo0_l00007ooooo`?o00001Oooool2o`0000Sooooo1Ol00003ooooo`Co000000?o
ooooo`000?l000005_l00006ooooo`;o00000oooool2o`0000?ooooo0_l0000;ooooo`;o000000?o
ooooo`000?l000001Oooool2o`0003kooooo000Looooo`03o`000?oooooooooo03Sooooo0ol00000
0ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Wooooo2?l00002
ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Booooo`;o00001oooool2o`0000Gooooo1Ol0
0008ooooo`;o00002_ooool2o`0000;ooooo0_l00006ooooo`;o00002oooool2o`0000?ooooo0_l0
0003oooooaSo00001_ooool2o`0001Kooooo1?l00005ooooo`;o00000oooool2o`0003Wooooo000L
ooooo`03o`000?oooooooooo03Wooooo0_l00006ooooo`;o000000?oooooo`000?l000002Oooool2
o`0000gooooo1?l000000ooooooo0000o`000008ooooo`;o000000?oooooo`000?l000000_ooool2
o`00017ooooo0_l00005ooooo`?o00005_ooool2o`0000;ooooo0_l0000;ooooo`;o00004ooooolG
o`0000Cooooo1?l0000Dooooo`;o00003?ooool2o`0003Wooooo000Looooo`03o`000?oooooooooo
03;ooooo0_l00005ooooo`;o00002Oooool2o`0000_ooooo0_l0000@ooooo`;o00000oooool2o`00
00?ooooo0_l000001Ooooooo0000o`000?l0003ooooo00?o00003oooool3o`0000?ooooo0_l0000C
ooooo`;o00002?ooool4o`0000Sooooo1?l0000@oooooa?o000000?oooooo`000?l000000ol00006
ooooo`;o00002?ooool2o`0000;ooooo0_l0001?ooooo`007?ooool2o`0003?ooooo1?l00002oooo
o`;o00001Oooool4o`0000kooooo0_l0000Eooooo`;o00001_ooool3o`0000;ooooo0_l00004oooo
o`;o00002Oooool2o`0000Cooooo0_l0000:ooooo`;o00001oooool2o`0000[ooooo1?l00006oooo
o`Co00003OoooolOo`0000_ooooo1?l00002ooooo`;o0000Coooool001cooooo00?o0000oooooooo
ool0=?ooool2o`0000;ooooo0_l00005ooooo`Co00001?ooool2o`0000Wooooo0_l0000Tooooo`;o
000000?oooooo`000?l000006oooool2o`0001;ooooo0_l000000ooooooo0000o`000008ooooo`;o
00003OoooolOo`0000_ooooo1?l00006ooooo`;o00004_ooool2o`0003Oooooo000Looooo`03o`00
0?oooooooooo04Oooooo0_l00004ooooo`;o00000oooool2o`0000;ooooo0_l0000@ooooo`;o0000
3_ooool2o`0001;ooooo0ol00002ooooo`;o00002?ooool2o`0000oooooo0_l0000Iooooo`;o0000
00?oooooo`000?l000006?l0000@ooooo`Co00001?ooool2o`0000Kooooo0_l0000:ooooo`;o0000
=oooool001cooooo00?o0000ooooooooool0A?ooool2o`0000Oooooo0_l00005ooooo`Co00004?oo
ool2o`0002;ooooo0ol00002ooooo`;o00002?ooool2o`0001kooooo1?l00003ooooo`;o00000ooo
ool>o`000003ooooool0003o000000ko00004?ooool2o`0000cooooo0_l000000ooooooo0000o`00
0010ooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00000oooool2o`0000Cooooo0_l00000
0ooooooo0000o`000004ooooo`?o00005Oooool2o`000003ooooool0003o000003?ooooo0_l0000D
ooooo`Ko00000oooool2o`0000Cooooo6_l00002ooooo`;o00002Oooool2o`0000;ooooo0_l0000<
ooooo`;o00001?ooool2o`00043ooooo000Looooo`03o`000?oooooooooo03Kooooo1?l00003oooo
o`Ko00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`?o000000Coooooo`00
0?l0003o00003Oooool2o`0000;ooooo0_l000000ooooooo0000o`00000:ooooo`;o00001oooool2
o`0000Kooooo0_l00004ooooo`;o00004?ooool2o`0000;ooooo1?l0000=ooooo`Co00003?oooolG
o`000003ooooool0003o000000Co00001Oooool2o`0000;ooooo0_l00002ooooo`;o00000oooool4
o`0000Gooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`0fooooo`Co00000oooool2o`00
0004ooooool0003o0000o`0000?ooooo0_l0000;ooooo`?o000000Coooooo`000?l0003o00000_oo
ool2o`0000Sooooo0ol00008ooooo`;o00001oooool2o`0000Oooooo0_l00006ooooo`;o00001?oo
ool2o`0001Cooooo1?l00009ooooo`;o00000_ooool4o`0000_ooooo3ol00002ooooo`co00001ooo
ool2o`0000?ooooo0_l00006ooooo`Co00006?ooool3o`0003;ooooo000Looooo`03o`000?oooooo
oooo03gooooo0_l0000Fooooo`Co00000oooool2o`0000Cooooo0_l00002ooooo`;o00002Oooool2
o`0000?ooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000000Sooooo0_l00000
0ooooooo0000o`00000=ooooo`;o00001oooool2o`0000_ooooo0_l00004ooooo`;o00002ooooolK
o`0000cooooo1?l000000ooooooo0000o`000003ooooo`;o00001_ooool3o`00017ooooo0ol0000b
ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o000000?oooooo`000?l000000oooool2o`00
00Cooooo0_l00009ooooo`;o00002_ooool5o`0000;ooooo0_l00005ooooo`;o00001_ooool2o`00
00[ooooo0_l00006ooooo`?o000000?oooooo`000?l000001Oooool2o`000004ooooool0003o0000
ooooo`;o00003Oooool2o`0001;ooooo0_l0000DoooooaKo000000?oooooo`000?l000000_ooool2
o`0000Wooooo0_l00003ooooo`;o00001?ooool2o`0000Cooooo1?l00002ooooo`;o00001Oooool3
o`0003[ooooo000Looooo`03o`000?oooooooooo02oooooo0_l000000ooooooo0000o`000003oooo
o`;o00002oooool2o`0000;ooooo0_l00003ooooo`;o00001Oooool2o`0000Gooooo0ol0000<oooo
o`;o00001oooool3o`0000?ooooo0_l000000ooooooo0000o`000002o`0000Oooooo1?l0000Foooo
o`;o00003oooool2o`0000[ooooo0_l00009oooooaSo00000_ooool2o`0000_ooooo0_l00007oooo
o`;o00001?ooool4o`0000;ooooo0_l00003ooooo`Go0000>_ooool001cooooo00?o0000oooooooo
ool0=_ooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool3o`0000Oooooo0_l0000;ooooo`Co
00005Oooool3o`0000?ooooo1Ol00009ooooo`?o00001?ooool2o`0000oooooo1?l0000Booooo`;o
00000_ooool2o`000003ooooool0003o000000;o00000_ooool2o`0000Kooooo5ol0000?ooooo`;o
00003oooool2o`0000Oooooo0ol0000looooo`007?ooool00ol0003oooooooooo`0aooooo`;o0000
0oooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00003ooooo`;o0000
4?ooool5o`0001_ooooo0_l00005ooooo`;o00002oooool2o`000003ooooool0003o000000?o0000
2Oooool2o`0001Cooooo0_l00002ooooo`Go00001?ooool2o`0000Kooooo5_l0000:ooooo`;o0000
1?ooool2o`0000;ooooo0_l00006ooooo`;o00003Oooool2o`0003cooooo000Looooo`03o`000?oo
oooooooo037ooooo0_l00009ooooo`Co00002?ooool2o`0000Cooooo0_l0000;ooooo`Co00001?oo
ool2o`0000Oooooo1?l00007ooooo`;o00001oooool5o`0000cooooo1Ol0000Cooooo`;o00002ooo
ool2o`0000?ooooo0_l0000=oooooaKo000000Coooooo`000?l0003ooooo0_l000000ooooooo0000
o`000003o`000003ooooool0003o000000Gooooo0_l00006ooooo`;o0000Boooool001cooooo00?o
0000ooooooooool06Oooool2o`00027ooooo0_l00007ooooo`Co00001Oooool3o`0000Oooooo0_l0
0003ooooo`;o00001?ooool2o`0000Oooooo1Ol00006ooooo`;o00001?ooool2o`000003ooooool0
003o000000?o00001_ooool2o`0000Kooooo0_l00009ooooo`;o00001Oooool2o`0000;ooooo0_l0
000;ooooo`;o00001?ooool3o`0000cooooo1Ol000000ooooooo0000o`000009o`000005ooooool0
003o0000o`000?ooool00_l000001?oooooo0000o`000?ooool4o`000004ooooool0003o0000o`00
00Wooooo0_l0000Aooooo`;o00001?ooool2o`0003Kooooo000Looooo`03o`000?oooooooooo01Wo
oooo0_l0000Zooooo`Co00001_ooool2o`000003ooooool0003o000000Cooooo0_l00003ooooo`;o
00003Oooool2o`000003ooooool0003o000000;o00001?ooool4o`0000;ooooo1?l000000ooooooo
0000o`000007ooooo`;o00002Oooool2o`0000Kooooo0_l00005ooooo`;o00002Oooool3o`0000?o
oooo0_l00004ooooo`Co00000_ooool5o`0000Cooooo0_l00002ooooo`go000000Coooooo`000?l0
003o00001?ooool2o`0000Kooooo1Ol00007ooooo`;o00004Oooool2o`0000Cooooo0_l0000foooo
o`007?ooool00ol0003oooooooooo`1?ooooo`;o000000Coooooo`000?l0003o00001oooool2o`00
00Oooooo0_l00005ooooo`;o00000oooool2o`0000;ooooo2?l000001Ooooooo0000o`000?l0003o
oooo00;o00001oooool2o`0000Wooooo0_l0000Hooooo`?o00000oooool2o`0000Cooooo1?l00002
ooooo`Go00002?ooool>o`0000Oooooo0_l00008ooooo`?o00004_ooool2o`0000?ooooo0_l00002
ooooo`;o0000>oooool001cooooo0_l0000booooo`;o00001oooool3o`0001Cooooo1?l00003oooo
o`;o00000_ooool4o`000003ooooool0003o000000Co00000_ooool2o`0000Cooooo1Ol000001?oo
oooo0000o`000?ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000000_l00007
ooooo`;o00004oooool2o`0000Cooooo1?l0000Cooooo`?o00001Oooool2o`0000Sooooo2_l00000
1?oooooo0000o`000?l0000Kooooo`;o00002Oooool2o`0000?ooooo0_l00002ooooo`;o00004ooo
ool2o`0002Kooooo000Looooo`03o`000?oooooooooo037ooooo0_l00007ooooo`?o00003_ooool2
o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o
000000;o00000oooool3o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`000004ooooool0
003o0000ooooo`Co000000?oooooo`000?l000000ol00003ooooo`;o00001oooool2o`0000?ooooo
0_l00006ooooo`Co00001?ooool4o`0000cooooo0_l00005ooooo`?o00003Oooool2o`000003oooo
ool0003o000000;ooooo1Ol000000ooooooo0000o`000002ooooo`;o00006?ooool3o`0000?ooooo
0_l0000Qooooo`;o00009_ooool001cooooo00?o0000ooooooooool0:oooool2o`0000;ooooo0_l0
000Dooooo`;o00000_ooool4o`0000?ooooo1?l000000ooooooo0000o`00000:ooooo`Co00000ooo
ool2o`000004ooooool0003o0000ooooo`?o00001?ooool2o`000003ooooool0003o000000Ko0000
0_ooool8o`0000Cooooo0_l000001?oooooo0000o`000?ooool4o`0000Kooooo0ol0000Eooooo`;o
00001oooool2o`0000?ooooo0_l00007ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`00
00Gooooo0_l00003ooooo`;o00002Oooool2o`0000Wooooo0_l00003ooooo`;o0000BOooool001co
oooo00?o0000ooooooooool0:oooool2o`0000;ooooo0_l00009ooooo`;o00001_ooool2o`000003
ooooool0003o000000;ooooo0_l00005ooooo`Ko00000oooool2o`0000Kooooo0_l00004ooooo`Ko
000000?oooooo`000?l000000_l00006ooooo`So00000_ooool6o`0000Kooooo0_l00004ooooo`;o
00006_ooool2o`0000gooooo0_l00003ooooo`Co00002?ooool5o`0000Wooooo0_l00003ooooo`;o
00002Oooool2o`0000cooooo0ol0000@ooooo`;o00003_ooool2o`0002Sooooo000Looooo`03o`00
0?oooooooooo033ooooo0_l00005ooooo`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o
00003Oooool2o`000003ooooool0003o000000?ooooo0_l00004ooooo`Co00001?ooool4o`0000?o
oooo1?l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000Go00000_ooool7o`00
00Kooooo0ol000000ooooooo0000o`000002ooooo`Co00002Oooool2o`0000[ooooo0_l0000Doooo
o`;o00002_ooool3o`0000Wooooo0_l0000;ooooo`;o00000_ooool2o`0000_ooooo0ol00004oooo
o`;o00002_ooool3o`0000gooooo0_l0000Xooooo`007?ooool00ol0003oooooooooo`0_ooooo`?o
00001Oooool2o`0000Cooooo0_l0000:ooooo`Co00002Oooool2o`0000Oooooo0ol00003ooooo`;o
00002Oooool2o`000004ooooool0003o0000oooooa3o000000?oooooo`000?l000000_ooool7o`00
0005ooooool0003o0000o`000?ooool01?l00009ooooo`;o00002_ooool2o`0003Wooooo0ol00000
0ooooooo0000o`00000:ooooo`?o00001Oooool2o`0000[ooooo0ol0000gooooo`007?ooool00ol0
003oooooooooo`0_ooooo`;o00002_ooool2o`0000Gooooo0_l00005ooooo`Co00000_ooool2o`00
0003ooooool0003o000000;ooooo0_l00006ooooo`;o00001Oooool3o`0000Kooooo1?l000001Ooo
oooo0000o`000?l0003ooooo01co000000?oooooo`000?l000000_l000000ooooooo0000o`00000<
ooooo`;o00001?ooool5o`0000Sooooo0_l0000=ooooo`;o00004Oooool2o`0000Oooooo0_l00003
ooooo`Co00003Oooool3o`0000_ooooo0_l0000Cooooo`;o0000:Oooool001cooooo00?o0000oooo
ooooool0<oooool2o`0000Kooooo0_l00005ooooo`;o00001_ooool2o`0000?ooooo0_l000000ooo
oooo0000o`000004ooooo`;o00001?ooool2o`0000;ooooo0_l000001?oooooo0000o`000?l00005
ooooo`Wo00000_oooolCo`000004ooooool0003o0000ooooo`Co00000oooool2o`000003ooooool0
003o000000cooooo0_l00004ooooo`Go00001oooool3o`0000;ooooo0_l00009ooooo`;o00004Ooo
ool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000Oooooo0_l00009ooooo`;o00002Ooo
ool2o`0001?ooooo0_l0000Yooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00001Oooool2
o`0000Oooooo0_l00002ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Cooooo0_l00004
ooooo`;o00000_ooool2o`0000;ooooo0_l00005ooooo`Wo000000?oooooo`000?l000005Ol00002
ooooo`;o00000_ooool2o`0000Wooooo0_l0000Hooooo`Oo00007?ooool2o`0000?ooooo0_l0000@
ooooo`;o00002Oooool2o`0004Wooooo000Looooo`03o`000?oooooooooo03[ooooo0ol000000ooo
oooo0000o`000002ooooo`?o00000_ooool2o`0000Kooooo0_l000001?oooooo0000o`000?ooool2
o`0000oooooo0_l00002ooooobco00002Oooool2o`00013ooooo0_l00004ooooo`;o00000_ooool4
o`0000?ooooo0_l0000<ooooo`;o00000_ooool2o`0000gooooo0_l00007ooooo`;o00002?ooool2
o`0000;ooooo0_l00009ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0>oooool5o`00
00;ooooo1?l00009ooooo`Co00000_ooool2o`0000Oooooo0_l00008ooooo`Go00000ooooolKo`00
0003ooooool0003o000000co00000oooool4o`0000?ooooo0_l0000;ooooo`;o00000_ooool4o`00
00?ooooo0ol00003ooooo`;o00001?ooool2o`0000Kooooo0_l00002ooooo`;o00000oooool3o`00
00Oooooo0_l00005ooooo`Co00002?ooool6o`0000Wooooo0_l00012ooooo`007?ooool00ol0003o
ooooooooo`0mooooo`;o00001?ooool3o`0000_ooooo0_l00006ooooo`;o00000oooool2o`0000So
oooo9ol00002ooooo`Wo00000oooool3o`0000Cooooo0_l0000?ooooo`?o00001?ooool2o`0000[o
oooo0_l00002ooooo`;o00002?ooool2o`000003ooooool0003o000000;o00001oooool2o`0000Co
oooo0_l0000<ooooo`Co0000COooool001cooooo00?o0000ooooooooool0@oooool2o`000003oooo
ool0003o000000Sooooo1?l00003ooooo`Co00002_ooool2o`000003ooooool0003o000002?o0000
00Coooooo`000?l0003o00000_ooool2o`000003ooooool0003o000001Gooooo0_l00003ooooo`;o
00001Oooool2o`0000Oooooo1_l00004ooooo`;o00002?ooool2o`0000?ooooo0_l00007ooooo`Go
0000H?ooool001cooooo00?o0000ooooooooool0??ooool2o`000003ooooool0003o000000Gooooo
1?l00006ooooo`Co00000oooool2o`000003ooooool0003o000000?ooooo0_l00004ooooo`;o0000
0oooool2o`000003ooooool0003o000001Wo00000_ooool8o`000003ooooool0003o000001Sooooo
0_l00003ooooo`;o00001Oooool2o`0000Oooooo1_l0000Cooooo`;o00002Oooool3o`0001;ooooo
0_l00007ooooo`?o00000_ooool2o`0003kooooo000Looooo`03o`000?oooooooooo02gooooo0_l0
000<ooooo`?o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o00002oooool3o`0000;ooooo
0_l00003ooooo`Go00001?ooool4o`000003ooooool0003o000002Go000000?oooooo`000?l00000
1?ooool2o`000003ooooool0003o000000kooooo0_l000001?oooooo0000o`000?l0000:ooooo`;o
00000_ooool5o`0000Gooooo0_l0000;ooooo`Co00004_ooool2o`0000[ooooo0_l00007ooooo`?o
00000_ooool2o`0003kooooo000Looooo`03o`000?oooooooooo02gooooo0_l0000<ooooo`;o0000
1Oooool2o`00013ooooo1?l00009ooooo`?o00001?ooool4o`0000Cooooo7_l000000ooooooo0000
o`000006o`0000;ooooo1ol00007ooooo`;o00001Oooool2o`000004ooooool0003o0000o`0000[o
oooo0_l00004ooooo`;o000000Coooooo`000?l0003o00000_ooool4o`0000Wooooo0_l0000Doooo
o`;o00003Oooool2o`0000?ooooo0_l00007ooooo`;o00000oooool2o`0003Kooooo000Looooo`;o
0000:Oooool2o`00017ooooo0_l0000Gooooo`;o00001?ooool2o`0000Wooooo0_l00002ooooo`?o
00000_oooolZo`000003ooooool0003o000000;ooooo0_l00008ooooo`;o00005oooool2o`0000;o
oooo0_l000001?oooooo0000o`000?l00004ooooo`?o00007_ooool3o`0000Kooooo0_l00004oooo
o`Co000000?oooooo`000?l000001Oooool4o`000003ooooool0003o000000;o0000=_ooool001co
oooo00?o0000ooooooooool0:?ooool2o`00017ooooo0_l00004ooooo`;o00001?ooool4o`0000Go
oooo0_l00006ooooo`Co000000?oooooo`000?l000001_ooool2o`000003ooooool0003o000002Oo
00001Oooool4o`0001Wooooo0_l0000;ooooo`;o00000_ooool2o`0000Wooooo1?l0000:ooooo`;o
00004?ooool3o`0000Kooooo0_l00006ooooo`;o00002?ooool4o`000004ooooool0003o0000o`00
03Oooooo000Looooo`03o`000?oooooooooo047ooooo1?l00002ooooo`Co000000?oooooo`000?l0
00000_ooool2o`0000Kooooo0_l000000ooooooo0000o`000003o`0000Sooooo0_l000000ooooooo
0000o`00000Uo`0000;ooooo2?l0000Gooooo`;o00001_ooool2o`0000Oooooo0_l00005ooooo`;o
00001?ooool2o`0000[ooooo1_l0000Wooooo`Co0000>oooool001cooooo00?o0000ooooooooool0
@?ooool5o`0000Oooooo1Ol00002ooooo`;o00001_ooool2o`000003ooooool0003o000000Sooooo
0ol000000ooooooo0000o`00000To`0000;ooooo1?l00002ooooo`;o00007_ooool3o`0000Sooooo
0_l00004ooooo`;o00002oooool3o`0000Cooooo1?l0000:ooooo`;o00000oooool2o`0000kooooo
0_l00015ooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00001_ooool3o`000003ooooool0
003o000000Gooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000Gooooo0_l0
0009ooooo`;o000000?oooooo`000?l000009_l000000ooooooo0000o`000003o`0000Cooooo0_l0
0005ooooo`?o00001oooool2o`0000Wooooo0_l00002ooooo`;o00000_ooool2o`0000Gooooo1?l0
0007ooooo`;o00000_ooool2o`0000;ooooo0ol00002ooooo`;o00003_ooool2o`0000?ooooo0_l0
000>ooooo`;o00000_ooool3o`00043ooooo000Looooo`03o`000?oooooooooo03Oooooo0_l00005
ooooo`Co00002?ooool2o`0000Cooooo1ol00003ooooo`;o00001oooool5o`000003ooooool0003o
000000?o000000?oooooo`000?l000004?l000000ooooooo0000o`000006o`000003ooooool0003o
000000?o000000?oooooo`000?l000000_l0000;ooooo`Co00001oooool2o`0000Wooooo0_l00006
ooooo`;o000000?oooooo`000?l000000_ooool4o`0000;ooooo0_l000000ooooooo0000o`000002
o`0000;ooooo0_l00002ooooo`Co000000?oooooo`000?l000004oooool2o`0000Cooooo0_l00009
ooooo`Ko000000?oooooo`000?l00000?Oooool001cooooo00?o0000ooooooooool0?_ooool4o`00
013ooooo1Ol00006ooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`;o000000Cooooo
o`000?l0003ooooo6ol00003ooooo`So000000?oooooo`000?l000001_ooool4o`0000?ooooo0ol0
000Booooo`;o00001Oooool2o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000001ooo
ool5o`0001cooooo0_l00004ooooo`;o00000oooool3o`0000?ooooo0ol0000mooooo`007?ooool0
0ol0003oooooooooo`0jooooo`;o00001?ooool2o`0000Oooooo0_l00008ooooo`?o00001oooool2
o`000003ooooool0003o000000Gooooo1ol000000ooooooo0000o`000008o`0000;ooooo6_l00000
0ooooooo0000o`000004ooooo`Co00000oooool5o`0000Cooooo0_l0000<ooooo`;o000000?ooooo
o`000?l000001oooool3o`000005ooooool0003o0000o`000?ooool00_l00007ooooo`;o00000_oo
ool2o`0000kooooo0_l0000Aooooo`;o00002Oooool2o`0003kooooo000Looooo`03o`000?oooooo
oooo02[ooooo0_l0000>ooooo`;o00001?ooool2o`0000Oooooo0_l00005ooooo`;o000000Cooooo
o`000?l0003o00002_ooool2o`0000Gooooo0_l000000ooooooo0000o`000008o`000003ooooool0
003o000001So000000?oooooo`000?l000001Ol00002ooooo`Ko00000oooool3o`0000Oooooo0_l0
0004ooooo`;o00002Oooool2o`0000Kooooo1?l000001Ooooooo0000o`000?l0003ooooo00;o0000
2Oooool4o`0000kooooo0ol0000<ooooo`;o00003oooool2o`0003cooooo000Looooo`03o`000?oo
oooooooo02[ooooo0_l0000Kooooo`_o00001Oooool2o`0001Cooooo9ol000000ooooooo0000o`00
0008o`0000?ooooo0_l00002ooooo`Co00002?ooool2o`000004ooooool0003o0000ooooo`;o0000
2oooool3o`00017ooooo0_l0000=ooooo`;o000000?oooooo`000?l000000_l0000;ooooo`;o0000
0_ooool2o`0000Wooooo1?l0000looooo`007?ooool00ol0003oooooooooo`0Tooooo`;o00008Ooo
ool3o`000003ooooool0003o000000Co00001_ooool2o`00013ooooo1?l000000ooooooo0000o`00
000To`000003ooooool0003o000000Go000000?oooooo`000?l000001oooool4o`0000_ooooo0_l0
00000ooooooo0000o`000002o`0000[ooooo1?l00009ooooo`;o00001Oooool3o`0000_ooooo0_l0
0003ooooo`;o00003oooool2o`0000Cooooo0_l00003ooooo`?o00003_ooool2o`0002gooooo000L
ooooo`03o`000?oooooooooo02Cooooo0_l0000^ooooo`;o00004oooool4o`0000;ooooo7Ol00000
0ooooooo0000o`000004o`0000Oooooo0_l0000;ooooo`;o00002Oooool2o`0000Kooooo0_l00008
ooooo`Ko00000_ooool2o`0000Gooooo0_l00005ooooo`?o00001?ooool2o`0000Cooooo0_l0000G
ooooo`;o00000_ooool2o`0000Cooooo0_l0000>ooooo`;o0000;Oooool001cooooo00?o0000oooo
ooooool0@?ooool2o`0000gooooo0_l00003ooooo`;o00001oooool2o`0000Sooooo0_l000000ooo
oooo0000o`000003ooooobCo00002Oooool2o`0000;ooooo0_l0000@ooooo`;o00001oooool2o`00
0003ooooool0003o000000Cooooo0_l00006ooooo`;o00000_ooool2o`0000oooooo0_l00004oooo
o`;o00001_ooool2o`0000?ooooo0_l00005ooooo`?o000000Coooooo`000?l0003o0000Aoooool0
01cooooo00?o0000ooooooooool0@?ooool2o`0000gooooo0_l0000<ooooo`;o00002?ooool4o`00
00;ooooo9ol000000ooooooo0000o`000003ooooo`Co00000_ooool3o`0000oooooo0_l000000ooo
oooo0000o`000004ooooo`;o000000?oooooo`000?l000003?ooool2o`0000;ooooo1?l0000;oooo
o`;o000000?oooooo`000?l000001?ooool2o`0000Gooooo0_l00003ooooo`;o00001Oooool3o`00
0003ooooool0003o000000Wooooo0_l0000mooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5
ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0?ooo
ool2o`0002Kooooo1?l000000ooooooo0000o`00000Vo`000003ooooool0003o000000?ooooo0_l0
00001Ooooooo0000o`000?l0003ooooo00?o000000Coooooo`000?l0003o00002_ooool2o`000003
ooooool0003o000001Cooooo0_l00005ooooo`;o00001_ooool2o`0000?ooooo0_l000000ooooooo
0000o`000004ooooo`;o00000_ooool2o`000003ooooool0003o000000kooooo0_l00009ooooo`;o
0000?Oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMg
MoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo02cooooo0_l0000?ooooo`Co00009_ooool2
o`0000;ooooo9ol00002ooooo`;o00001?ooool2o`000004ooooool0003o0000o`0000;ooooo0_l0
00001?oooooo0000o`000?l00005ooooo`;o00007?ooool2o`0000gooooo0_l00008ooooo`;o0000
1_ooool4o`0000gooooo1?l00005ooooo`;o0000@Oooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
;?ooool2o`0000oooooo0_l00007ooooo`;o00000oooool2o`0000;ooooo0_l0000Aooooo`;o0000
1oooool2o`0000;ooooo4?l000001Ooooooo0000o`000?l0003ooooo00ko00000_ooool4o`0000;o
oooo0_l00009ooooo`?o00001Oooool4o`0000Kooooo0_l00009ooooo`;o000000?oooooo`000?l0
00003_ooool3o`0000Kooooo0_l00004ooooo`Co00000_ooool2o`0000;ooooo0_l00008ooooo`;o
00000oooool2o`0000Oooooo0_l00011ooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooo
ooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0003gooooo0_l00007ooooo`;o
00000oooool2o`0000;ooooo0_l0000;ooooo`;o00001?ooool2o`0000Oooooo0_l00009ooooo`go
000000?oooooo`000?l000002_l00002ooooo`Ko00000_ooool2o`0000Sooooo1?l00005ooooo`Co
00000_ooool6o`000003ooooool0003o000000;o00001?ooool5o`0000kooooo0ol00002ooooo`;o
00000_ooool2o`0000?ooooo1Ol00002ooooo`;o00000_ooool2o`0000Sooooo0_l00005ooooo`;o
00002?ooool2o`0000gooooo1?l0000]ooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooo
ooooo`09ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0mooooo`;o
00001oooool2o`0000Oooooo0_l000000ooooooo0000o`000005ooooo`Ko00000_ooool2o`0000So
oooo0ol000000ooooooo0000o`000002oooooa3o000000?oooooo`000?l000004_l0000<ooooo`;o
00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000005o`000003ooooool0003o000000Go
00001?ooool3o`0000Sooooo0ol00009ooooo`;o00001oooool2o`0000Sooooo0ol00008ooooo`;o
000000?oooooo`000?l000000_ooool2o`0000Sooooo0_l0000=ooooo`Co0000;Oooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`00
0?oooooooooo04Sooooo0_l00005ooooo`;o000000?oooooo`000?l000000_l00003ooooo`Ko0000
00Coooooo`000?l0003o00002Oooool2o`000003ooooool0003o000000;ooooo1?l000000ooooooo
0000o`00000Ho`000003ooooool0003o000000Go00003?ooool2o`000003ooooool0003o000000Co
000000?oooooo`000?l000003Ol00002ooooo`;o000000?oooooo`000?l000001Ol00003ooooo`?o
00001?ooool2o`0000Kooooo0_l00002ooooo`;o00002_ooool2o`0000Wooooo1Ol00004ooooo`;o
00000oooool2o`00047ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@
4?nHV9P02?ooool00ol0003oooooooooo`18ooooo`;o000000?oooooo`000?l000001_ooool5o`00
00Cooooo0_l00002ooooo`;o00002oooool2o`0000?ooooo1Ol000001Ooooooo0000o`000?l0003o
oooo01Ko00000_ooool7o`0000Cooooo0ol00004ooooo`;o00000oooool4o`000003ooooool0003o
0000017o000000?oooooo`000?l000001Ol000000ooooooo0000o`000002o`0000Gooooo0_l00000
0ooooooo0000o`000003ooooo`Ko00000_ooool2o`000003ooooool0003o000000?ooooo1?l00008
ooooo`;o00001_ooool2o`0000?ooooo0_l00011ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^
k^h<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0Boooool3o`0000;ooooo
0_l000001?oooooo0000o`000?ooool2o`0000Cooooo1Ol0000<ooooo`;o00000oooool9o`000003
ooooool0003o000000;o000000?oooooo`000?l000004?l000000ooooooo0000o`000006o`0000?o
oooo0ol00002ooooo`;o00000_ooool2o`000004ooooool0003o0000o`0000;ooooo5Ol000000ooo
oooo0000o`000002o`0000;ooooo1Ol00007ooooo`;o00001Oooool4o`0000;ooooo0_l000000ooo
oooo0000o`000005ooooo`;o00005Oooool2o`00047ooooo000Looooo`03o`000?oooooooooo04Oo
oooo0_l00002ooooo`?o00000_ooool2o`000003ooooool0003o000000Oooooo1_l00003ooooo`;o
00000_ooool8o`000003ooooool0003o000000So00000_ooool2o`0000;ooooo4Ol00003ooooo`;o
00000_ooool2o`000003ooooool0003o000000Gooooo0_l00002ooooo`;o000000Coooooo`000?l0
003o00000_oooolKo`000004ooooool0003o0000ooooo`;o00006oooool2o`0005_ooooo000Loooo
o`03o`000?oooooooooo04Cooooo0_l000000ooooooo0000o`000003ooooo`;o00000_ooool2o`00
0003ooooool0003o000000;ooooo0_l00007ooooo`;o00000oooool2o`0000;ooooo1Ol000001?oo
oooo0000o`000?ooool3o`000003ooooool0003o000000;ooooo0_l00002ooooo`[o000000?ooooo
o`000?l000002?l00003ooooo`Co00000oooool2o`0000kooooo0_l000000ooooooo0000o`00000F
o`000003ooooool0003o0000013ooooo1?l0000=ooooo`;o00001_ooool2o`0000cooooo0_l00015
ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00000oooool2o`0000Gooooo1?l00003oooo
o`;o00004Oooool4o`0000kooooo0_l00002ooooo`So00001oooool4o`0000?ooooo1?l00005oooo
o`;o00003?oooolNo`0000kooooo1_l00008ooooo`;o00002Oooool4o`0000;ooooo0_l00008oooo
o`;o00001?ooool2o`0000Wooooo0ol0000cooooo`007?ooool00ol0003oooooooooo`0oooooo`;o
00002?ooool2o`0000Gooooo1?l0000Cooooo`;o000000Coooooo`000?l0003ooooo0_l00009oooo
o`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000003o`0000Oooooo1_l0000:oooo
o`Co00002ooooolMo`000003ooooool0003o000000_ooooo0_l0000<ooooo`;o00001?ooool2o`00
00?ooooo0_l00004ooooo`?o00003Oooool2o`0000Wooooo0ol0000cooooo`007?ooool00ol0003o
ooooooooo`0oooooo`;o00001Oooool2o`0000?ooooo0_l0000Gooooo`;o000000?oooooo`000?l0
00000oooool3o`0000Wooooo0_l00006ooooo`So000000?oooooo`000?l000001Oooool7o`0000[o
oooo0_l00007oooooago00001Oooool2o`0000Wooooo0ol00004ooooo`;o000000?oooooo`000?l0
00000_ooool2o`0000Kooooo0_l0000:ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0
>oooool2o`0000?ooooo0_l00004ooooo`;o00000oooool2o`0000kooooo0_l00007ooooo`?o0000
00?oooooo`000?l000000_ooool2o`0000?ooooo0_l0000?ooooo`Ko000000?oooooo`000?l00000
0_l00004ooooo`;o00000_ooool2o`0000Kooooo0_l00009ooooob3o000000?oooooo`000?l00000
1Oooool2o`0000Gooooo0ol00004ooooo`;o000000?oooooo`000?l000000_ooool2o`0006;ooooo
000Looooo`03o`000?oooooooooo03_ooooo0_l00003ooooo`;o00006Oooool2o`0000Cooooo0_l0
0002ooooo`;o000000?oooooo`000?l000001oooool2o`0000Kooooo1?l00004ooooo`Ko00000_oo
ool4o`0000Cooooo0_l00005ooooo`;o00000oooool2o`0000Wooooo0_l00002oooooaco000000Co
ooooo`000?l0003o00001?ooool2o`0000Gooooo0_l0000Uooooo`Co0000Aoooool001cooooo00?o
0000ooooooooool0EOooool2o`0000?ooooo0_l00005ooooo`;o000000?oooooo`000?l000002Ooo
ool2o`0000Sooooo1?l00002ooooo`Co00000_ooool2o`0000Oooooo0_l000000ooooooo0000o`00
0005ooooo`;o00002Oooool2o`0000Oooooo2_l000000ooooooo0000o`00000Co`0000_ooooo0_l0
0007ooooo`;o00000_ooool2o`0000kooooo0_l00008ooooo`Co00002Oooool2o`0000;ooooo0_l0
000hooooo`007?ooool00ol0003oooooooooo`17ooooo`?o00002oooool2o`0000?ooooo0_l00000
0ooooooo0000o`000005ooooo`;o00001?ooool2o`0000?ooooo0_l00009ooooo`?o00000_ooool2
o`0000Cooooo0_l00007ooooo`;o00004oooool2o`0000Kooooo2ol000000ooooooo0000o`000002
o`0000?ooooo3Ol0000Eooooo`;o00000_ooool2o`0000Gooooo0_l00007ooooo`;o00001Oooool2
o`0000;ooooo0_l0000:ooooo`;o00000_ooool2o`0003Sooooo000Looooo`03o`000?oooooooooo
04Oooooo0ol00007ooooo`;o00002_ooool3o`0000?ooooo0_l00005ooooo`;o00003_ooool2o`00
00?ooooo0_l00005ooooo`;o00000_ooool2o`0000;ooooo0_l0000?ooooo`;o00000oooool2o`00
00Gooooo6Ol000000ooooooo0000o`000009o`000003ooooool0003o000000kooooo0_l00008oooo
o`?o00000oooool2o`0000Sooooo0_l00002ooooo`;o00000_ooool2o`0004Cooooo000Looooo`03
o`000?oooooooooo03oooooo0ol00009ooooo`;o00000oooool3o`0000Wooooo1?l00003ooooo`;o
00003Oooool3o`0000[ooooo0_l00005ooooo`;o00000_ooool2o`0000oooooo0_l00002ooooo`;o
00000oooool2o`0000?ooooo0_l00003oooooaGo000000?oooooo`000?l000002_l000000ooooooo
0000o`00000>ooooo`;o00002Oooool2o`0000;ooooo0ol00007ooooo`;o00001oooool2o`0004Co
oooo000Looooo`;o0000@?ooool3o`0000Wooooo0_l00003ooooo`;o00002_ooool2o`0001Cooooo
0ol0000Vooooo`;o00003?ooool2o`0000?ooooo7Ol000001?oooooo0000o`000?l00007ooooo`;o
00002?ooool2o`0000kooooo0_l00008ooooo`;o00004oooool2o`0003Sooooo000Looooo`03o`00
0?oooooooooo043ooooo0_l00003ooooo`;o00000_ooool2o`0000Gooooo0_l0000;ooooo`;o0000
00?oooooo`000?l000007Oooool2o`0000Kooooo0_l0000<ooooo`;o00006?oooolQo`0000;ooooo
0_l00002ooooo`;o00002?ooool2o`0002gooooo0_l0000hooooo`007?ooool00ol0003ooooooooo
o`15ooooo`;o00000_ooool2o`000003ooooool0003o000000Cooooo0_l00005ooooo`;o00000_oo
ool2o`000003ooooool0003o000001Gooooo0_l00006ooooo`;o00001Oooool3o`000003ooooool0
003o000000;ooooo1Ol00002ooooo`;o00000oooool2o`0000?ooooo0_l0000;ooooob3o00000_oo
ool2o`0000;ooooo0_l00009ooooo`Co00001?ooool2o`0000kooooo0_l00002ooooo`;o00000_oo
ool2o`0004[ooooo000Looooo`03o`000?oooooooooo04cooooo0_l00003ooooo`?o00000_ooool2
o`000003ooooool0003o000000Gooooo0_l0000=ooooo`;o00001_ooool2o`0000;ooooo0_l00003
ooooo`;o00001?ooool2o`0000;ooooo0_l00002ooooo`Oo00001Oooool2o`0000?ooooo0_l0000;
oooooaoo00001?ooool2o`0000cooooo1?l00004ooooo`;o00001?ooool4o`0000Kooooo0_l00002
ooooo`;o00000_ooool2o`0000_ooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`1Aoooo
o`;o00000oooool3o`0000;ooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l000000ooo
oooo0000o`000005ooooo`;o00002_ooool3o`0000;ooooo0_l00006ooooo`;o000000?oooooo`00
0?l000001Oooool3o`0000Oooooo0_l0000?oooooaco00000_ooool3o`000003ooooool0003o0000
00?ooooo0_l0000:ooooo`;o00002Oooool4o`0000Cooooo0_l0000Eooooo`;o0000?Oooool001co
oooo00?o0000ooooooooool0C?ooool2o`0000;ooooo0ol00004ooooo`Ko000000?oooooo`000?l0
00001Oooool5o`0000cooooo0_l000001?oooooo0000o`000?ooool2o`0000Oooooo0_l000001?oo
oooo0000o`000?ooool2o`0000?ooooo0_l00007ooooo`;o000000?oooooo`000?l000000_ooool2
o`0000_ooooo7Ol000001?oooooo0000o`000?l00003ooooo`;o000000?oooooo`000?l000002_oo
ool2o`0000;ooooo0ol0000<ooooo`;o00001Oooool4o`0004_ooooo000Looooo`03o`000?oooooo
oooo03kooooo0_l0000<ooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`Co00002Oooool2
o`0000[ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00002_ooool3o`0000Sooooo0_l0
0007ooooo`Go00000_ooool2o`0000cooooo7ol00003ooooo`Go00003oooool3o`0000Cooooo0_l0
000=ooooo`Co0000Boooool001cooooo00?o0000ooooooooool0?_ooool2o`0000Kooooo0_l0000<
ooooo`;o00001Oooool2o`0000Wooooo0_l0000:ooooo`;o000000?oooooo`000?l000002_ooool2
o`0000?ooooo0_l0000Booooo`Co00004OoooolNo`0000?ooooo0_l000000ooooooo0000o`00000F
ooooo`;o0000G?ooool001cooooo00?o0000ooooooooool0A_ooool2o`000003ooooool0003o0000
00;ooooo1?l0000Eooooo`;o00004Oooool2o`0000Kooooo0_l00003ooooo`;o00001Oooool2o`00
00[ooooo0_l000000ooooooo0000o`00000Aooooo`Co000000Coooooo`000?l0003ooooo3_l00002
ooooo`Go000000?oooooo`000?l000000oooool4o`0000Gooooo0_l0000?ooooo`;o00002_ooool2
o`0001;ooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0jooooo`;o00002_ooool2o`00
0003ooooool0003o000000;ooooo1?l000001?oooooo0000o`000?l0000Tooooo`;o00002oooool2
o`0000Gooooo0_l00002ooooo`;o00001_ooool4o`00017ooooo0ol00003ooooo`;o000000Cooooo
o`000?l0003ooooo4_l000001?oooooo0000o`000?l00002ooooo`Co00001Oooool2o`000003oooo
ool0003o000000Gooooo0_l00005ooooo`;o00002_ooool3o`00017ooooo0_l0000kooooo`007?oo
ool00ol0003oooooooooo`0jooooo`;o00003?ooool6o`0000Cooooo0ol0000Rooooo`;o00006?oo
ool2o`0000Sooooo0_l00005ooooo`;o00002?ooool4o`0000;ooooo5ol00005ooooo`;o00003_oo
ool3o`0000Cooooo0_l0000>ooooo`Oo0000COooool001cooooo00?o0000ooooooooool0B?ooool6
o`0000kooooo0_l0000Iooooo`;o00005oooool2o`000003ooooool0003o000000Cooooo0_l00004
ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00000_ooool2o`0000Cooooo2ol00000
0ooooooo0000o`000009o`0000?ooooo0_l00009ooooo`;o00001_ooool2o`0000?ooooo0_l0000=
ooooo`Ko000000?oooooo`000?l00000COooool001cooooo00?o0000ooooooooool0D?ooool2o`00
00[ooooo0_l00002ooooo`;o00008oooool3o`0000Sooooo0_l000000ooooooo0000o`000002o`00
00;ooooo0_l00004ooooo`Co000000?oooooo`000?l000000_ooool2o`000004ooooool0003o0000
o`0000Kooooo0ol00003ooooo`Co000000?oooooo`000?l000000_l00002ooooo`Wo00002Oooool2
o`0000Kooooo0_l00003ooooo`;o00001Oooool4o`0000Cooooo1?l0001Booooo`007?ooool00ol0
003oooooooooo`1@ooooo`;o00002?ooool2o`0000?ooooo0ol0000Looooo`;o00001Oooool3o`00
00Oooooo0_l00004ooooo`;o00002_ooool2o`000004ooooool0003o0000o`0000Cooooo0ol00007
ooooo`;o00000oooool4o`0000;ooooo0_l00003ooooo`So00004Oooool3o`0000[ooooo1?l00006
ooooo`;o00004oooool2o`0003gooooo000Looooo`03o`000?oooooooooo05Cooooo0_l00004oooo
o`;o00000oooool2o`0000;ooooo0_l0000Iooooo`;o00001_ooool2o`0000Oooooo0_l00006oooo
o`;o00002oooool3o`00013ooooo1_l00004ooooo`?o00000oooool6o`0000Oooooo0_l00008oooo
o`Co00004_ooool2o`0001Cooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o
00001Oooool2o`0000Kooooo0ol000000ooooooo0000o`000008ooooo`;o00005?ooool2o`0000ko
oooo0_l00009ooooo`;o000000Coooooo`000?l0003ooooo0_l0000=ooooo`Ko00001?ooool3o`00
0004ooooool0003o0000ooooo`Ko00001_ooool2o`0000Gooooo0_l00003ooooo`Co00003_ooool4
o`0005?ooooo000Looooo`;o0000B?ooool2o`0000Cooooo0_l0000<ooooo`;o00001oooool5o`00
00Sooooo0_l0000Dooooo`;o00001_ooool2o`00017ooooo0_l00004ooooo`;o00001Oooool2o`00
017ooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l0000<ooooo`?o00001?ooool3
o`0000Wooooo0_l00003ooooo`Co0000Doooool001cooooo00?o0000ooooooooool0@oooool2o`00
00;ooooo0ol00003ooooo`Co00002_ooool2o`0000Wooooo1?l00005ooooo`;o00007_ooool2o`00
00Sooooo0_l00004ooooo`;o00001?ooool2o`0000Kooooo1?l000000ooooooo0000o`00000Boooo
o`;o00000oooool2o`0000gooooo0_l00004ooooo`;o00002oooool2o`0000Gooooo0_l0001Coooo
o`007?ooool00ol0003oooooooooo`13ooooo`;o00000oooool3o`0000;ooooo1?l0000Gooooo`;o
00001Oooool2o`0002Sooooo0_l00004ooooo`;o00001?ooool2o`0000Kooooo0_l00003ooooo`;o
00001_ooool2o`0000[ooooo0_l00003ooooo`;o00004?ooool2o`000003ooooool0003o000000Oo
oooo0_l0001Nooooo`007?ooool00ol0003oooooooooo`19ooooo`?o000000?oooooo`000?l00000
2Oooool2o`0000_ooooo0_l000000ooooooo0000o`00000booooo`;o00007?ooool2o`0000Cooooo
0_l0000Kooooo`;o00002_ooool2o`000003ooooool0003o000005_ooooo000Looooo`03o`000?oo
oooooooo04?ooooo0_l00005ooooo`;o00001_ooool2o`0000Cooooo0_l0000;ooooo`;o000000?o
ooooo`000?l000002oooool2o`0002Gooooo1?l0000Pooooo`;o00001?ooool2o`0000?ooooo0_l0
0007ooooo`;o00002oooool6o`0000Gooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`13
ooooo`;o00001Oooool2o`0000Kooooo0_l0000Aooooo`;o000000Coooooo`000?l0003ooooo0_l0
0008ooooo`;o00009oooool2o`0000gooooo0_l00008ooooo`;o00000oooool2o`0000Sooooo1?l0
00000ooooooo0000o`000007ooooo`;o00002oooool6o`0006;ooooo000Looooo`03o`000?oooooo
oooo04[ooooo0_l0000@ooooo`;o00002?ooool4o`000003ooooool0003o000000[ooooo0_l0000W
ooooo`;o00002oooool2o`0000Sooooo0_l00003ooooo`;o00002_ooool2o`0001[ooooo0_l0001S
ooooo`007?ooool00ol0003oooooooooo`1Looooo`;o00002?ooool2o`0000?ooooo0_l0000:oooo
o`;o00009oooool2o`0000;ooooo0_l000001?oooooo0000o`000?l0000jooooo`;o00001Oooool2
o`0001Oooooo0ol00012ooooo`007?ooool00ol0003oooooooooo`1Gooooo`;o00001_ooool2o`00
00[ooooo0_l00009ooooo`;o0000;?ooool6o`0000Gooooo0_l00004ooooo`;o0000;Oooool3o`00
00Cooooo1?l0000Eooooo`?o0000@_ooool001cooooo00?o0000ooooooooool0C_ooool2o`0000Oo
oooo0_l00004ooooo`Co000000?oooooo`000?l000002_ooool2o`0000Kooooo0_l0000^ooooo`;o
00001_ooool3o`0000Cooooo0_l0000=ooooo`;o00000oooool2o`0001?ooooo0_l00002ooooo`;o
000000?oooooo`000?l000001_ooool4o`0005Sooooo000Looooo`03o`000?oooooooooo04kooooo
0_l000000ooooooo0000o`00000:ooooo`;o00000oooool2o`0000[ooooo0ol00009ooooo`;o0000
8_ooool2o`0000kooooo0_l00006ooooo`;o00002?ooool2o`0000;ooooo0_l000000ooooooo0000
o`000002o`0001?ooooo0_l00002ooooo`;o00002oooool2o`0005Sooooo000Looooo`03o`000?oo
oooooooo057ooooo0_l0000<ooooo`;o00003_ooool2o`0000Wooooo0_l0000Rooooo`;o00003?oo
ool2o`0000Gooooo0_l000000ooooooo0000o`000008ooooo`;o00001Oooool7o`0001_ooooo0ol0
001Mooooo`007?ooool00ol0003oooooooooo`1Fooooo`;o00001oooool2o`0000Kooooo0_l00005
ooooo`;o00001Oooool2o`0002?ooooo0_l00002ooooo`;o00001?ooool2o`0000Kooooo0_l00000
0ooooooo0000o`000002ooooo`;o00002?ooool3o`0000_ooooo1_l0000:ooooo`;o00003?ooool3
o`0005gooooo000Looooo`03o`000?oooooooooo05Kooooo0ol00009ooooo`;o00000oooool2o`00
00Cooooo0ol00005ooooo`;o00000_ooool2o`0001oooooo0_l00002ooooo`;o00000_ooool4o`00
00Wooooo0_l0000<ooooo`?o00003Oooool4o`0000[ooooo0_l0000:ooooo`;o0000H?ooool001co
oooo00?o0000ooooooooool0Eoooool3o`0000Sooooo0_l00009ooooo`;o00002_ooool2o`0002Oo
oooo0_l00004ooooo`;o00003?ooool2o`0000Oooooo0_l000000ooooooo0000o`00000Gooooo`Co
00002?ooool3o`0005oooooo000Looooo`03o`000?oooooooooo05Sooooo1?l00006ooooo`;o0000
0oooool2o`0000Gooooo0_l0000>ooooo`;o0000:?ooool2o`0000Cooooo0_l00005ooooo`?o0000
1oooool2o`000003ooooool0003o000000gooooo0_l00009ooooo`?o000000?oooooo`000?l00000
1_ooool2o`0005oooooo000Looooo`;o0000Foooool2o`0000Sooooo0_l000001?oooooo0000o`00
0?ooool2o`0000;ooooo0_l0000>ooooo`?o00005oooool2o`0001Cooooo0_l00005ooooo`;o0000
2oooool2o`0000gooooo0ol00008ooooo`;o00000_ooool2o`0006Oooooo000Looooo`03o`000?oo
oooooooo06Cooooo0_l00004ooooo`;o000000?oooooo`000?l000003Oooool5o`0001Oooooo0_l0
000Eooooo`;o00002_ooool2o`0000_ooooo0_l00008ooooo`;o00001?ooool2o`0006oooooo000L
ooooo`03o`000?oooooooooo06Cooooo0_l00007ooooo`;o00001Oooool2o`0000Kooooo1?l0000N
ooooo`;o00002_ooool2o`0000?ooooo0_l00006ooooo`;o00000_ooool2o`0000_ooooo0_l0000=
ooooo`?o00000_ooool2o`0006_ooooo000Looooo`03o`000?oooooooooo06Cooooo0_l00003oooo
o`;o00002Oooool2o`0000kooooo0_l0000Aooooo`;o00001Oooool5o`0000Cooooo0_l000000ooo
oooo0000o`000006ooooo`;o00000oooool2o`0001cooooo1?l00003ooooo`;o0000Joooool001co
oooo00?o0000ooooooooool0HOooool2o`000004ooooool0003o0000ooooo`Co000000?oooooo`00
0?l000001oooool2o`0000[ooooo0_l000000ooooooo0000o`00000Aooooo`;o000000?oooooo`00
0?l000000_l000000ooooooo0000o`000002o`0000Cooooo0_l00009ooooo`;o000000?oooooo`00
0?l000000_l000001?oooooo0000o`000?ooool2o`0001Kooooo0_l0001booooo`007?ooool00ol0
003oooooooooo`1Qooooo`;o00001?ooool2o`0000?ooooo0_l00007ooooo`;o00002_ooool6o`00
01?ooooo1_l00009ooooo`;o00002_ooool4o`000003ooooool0003o000000?o000000?oooooo`00
0?l000000_ooool2o`0008?ooooo000Looooo`03o`000?oooooooooo06?ooooo0_l0000Nooooo`Co
00005oooool2o`0000Wooooo0_l0000Aooooo`;o00000_ooool3o`000003ooooool0003o000000_o
oooo0_l0001fooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o00003Oooool3o`0000;ooooo
0_l0000Jooooo`;o0000;?ooool2o`000003ooooool0003o000000[ooooo0_l0000>ooooo`;o0000
1?ooool2o`00073ooooo000Looooo`03o`000?oooooooooo05Cooooo0_l00005ooooo`;o00001ooo
ool2o`0000;ooooo0_l00007ooooo`Co00003oooool2o`00023ooooo0_l0000:ooooo`;o000000?o
ooooo`000?l000004Oooool3o`0000Gooooo0ol00004ooooo`;o0000L?ooool001cooooo00?o0000
ooooooooool0Foooool2o`0000gooooo0_l00003ooooo`Ko00001?ooool2o`0001_ooooo0_l00008
ooooo`Co00000_ooool2o`0000[ooooo0_l0000Dooooo`?o00000oooool4o`0000Cooooo0_l00002
ooooo`;o0000KOooool001cooooo00?o0000ooooooooool0H?ooool2o`0000Sooooo0_l00002oooo
o`?o00002?ooool2o`00013ooooo0_l00009ooooo`;o00001Oooool2o`000003ooooool0003o0000
00Co00003?ooool2o`0001Cooooo0_l00004ooooo`?o00001Oooool2o`0000;ooooo0_l0001]oooo
o`007?ooool00ol0003oooooooooo`1Pooooo`;o00003?ooool2o`0001_ooooo0_l0000@ooooo`;o
00001Oooool2o`0001_ooooo0_l00005ooooo`;o00001?ooool2o`0007Wooooo000Looooo`03o`00
0?oooooooooo07Cooooo0_l00006ooooo`;o000000?oooooo`000?l000006Oooool2o`0000Gooooo
0_l0000?ooooo`;o00002oooool5o`0000Kooooo0_l00002ooooo`;o0000NOooool001cooooo00?o
0000ooooooooool0G_ooool2o`0000?ooooo0_l0000=ooooo`Co00001_ooool2o`000003ooooool0
003o000000[ooooo0_l0000=ooooo`;o00001Oooool2o`0000cooooo0_l000000ooooooo0000o`00
000;ooooo`;o000000?oooooo`000?l000001_ooool2o`0000;ooooo0_l0000Qooooo`;o0000E_oo
ool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o
8B4Qolc<c006ooooo`03o`000?oooooooooo05kooooo0_l00003ooooo`;o00000_ooool2o`0000Wo
oooo0_l00004ooooo`;o00004Oooool2o`0002;ooooo1Ol00005ooooo`;o00001?ooool2o`0000go
oooo0_l0000Qooooo`;o0000E_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q
8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo06Oooooo0_l00006
ooooo`;o00001oooool2o`0000kooooo0_l00009ooooo`;o00001?ooool2o`0000?ooooo1?l00000
0ooooooo0000o`00000<ooooo`?o00001Oooool2o`0000Cooooo0_l000000ooooooo0000o`000025
ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`1[ooooo`;o00000_ooool2o`0000Cooooo0_l0000@
ooooo`?o00002Oooool2o`0000Cooooo0_l00003ooooo`Co000000?oooooo`000?l000002Oooool2
o`0000oooooo0_l000000ooooooo0000o`000009ooooo`;o0000N_ooool00003ooooool0003ooooo
00;ooooo00?o0000ooooooooool02Oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0001[
ooooo`Go00000_ooool2o`000003ooooool0003o000000Oooooo0_l00007ooooo`;o00000_ooool2
o`00027ooooo0_l0000Mooooo`;o0000N_ooool00003ooooool0003ooooo00;ooooo00?o0000oooo
ooooool02Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0K?ooool4
o`0000;ooooo0ol00009ooooo`;o00002oooool2o`0001Kooooo0_l00003ooooo`;o00002?ooool2
o`000003ooooool0003o000000Wooooo0_l00005ooooo`;o0000P?ooool00003ooooool@413ooooo
00;ooooo00?o410@ooooooooool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000
ooooooooool0K?ooool4o`0000?ooooo0ol00007ooooo`;o00009?ooool2o`0000?ooooo0_l00003
ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo0_l00005ooooo`?o00001?ooool2
o`00083ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zj
o`000006ooooo`03o`000?oooooooooo06kooooo0_l00004ooooo`;o00001oooool2o`0000Wooooo
0ol00005ooooo`;o00000oooool2o`0000;ooooo0ol00003ooooo`;o00003?ooool2o`0000Wooooo
1?l00005ooooo`;o0000Q_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo
410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0O?ooool3o`0000Cooooo0_l00003oooo
o`?o00001Oooool3o`0000;ooooo0_l00002ooooo`?o00000oooool2o`0000Gooooo0_l00004oooo
o`;o00002_ooool4o`0000;ooooo0_l00029ooooo`007?ooool00ol0003oooooooooo`1booooo`Co
00001_ooool3o`0000Cooooo0_l00004ooooo`Co00001?ooool2o`0001?ooooo0_l00003ooooo`Co
00000oooool2o`0000Kooooo1_l00003ooooo`;o0000Q?ooool001cooooo00?o0000ooooooooool0
L_ooool4o`0001Gooooo0_l0000?ooooo`;o00003Oooool4o`000003ooooool0003o000000;o0000
1_ooool4o`0000?ooooo1?l00024ooooo`007?ooool00ol0003oooooooooo`1hooooo`;o00003?oo
ool2o`0000oooooo0_l00003ooooo`Co00003oooool3o`0000oooooo0ol0000Qooooo`;o0000H_oo
ool001cooooo00?o0000ooooooooool0N?ooool2o`0000?ooooo0ol00006ooooo`;o00003oooool2
o`0000;ooooo0_l000000ooooooo0000o`00000?ooooo`;o00001?ooool2o`0002kooooo0_l0001R
ooooo`007?ooool00ol0003oooooooooo`1mooooo`?o00001oooool2o`000003ooooool0003o0000
00oooooo0_l0000Hooooo`;o00001?ooool2o`0008cooooo000Looooo`03o`000?oooooooooo07[o
oooo0_l000001?oooooo0000o`000?ooool2o`0000Gooooo0_l000000ooooooo0000o`000005oooo
o`;o00003?ooool3o`0000?ooooo0_l00006ooooo`;o00001_ooool3o`0000?ooooo0_l0002<oooo
o`007?ooool00ol0003oooooooooo`1^ooooo`;o00002_ooool2o`000003ooooool0003o000000?o
00001Oooool2o`0000Sooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0ol00003ooooo`;o
00001_ooool2o`0000Cooooo0_l000000ooooooo0000o`00002Aooooo`007?ooool00ol0003ooooo
ooooo`1^ooooo`;o00000oooool2o`0000Oooooo0_l000000ooooooo0000o`000006ooooo`;o0000
3Oooool2o`0000;ooooo0_l00003ooooo`;o00004?ooool4o`0000;ooooo0_l0002@ooooo`007?oo
ool00ol0003oooooooooo`1cooooo`;o00001oooool2o`0000Kooooo0_l000000ooooooo0000o`00
0005ooooo`Go00000_ooool2o`000004ooooool0003o0000o`0000Cooooo0_l00003ooooo`?o0000
2_ooool2o`000004ooooool0003o0000ooooo`;o00006?ooool2o`0007Kooooo000Looooo`03o`00
0?oooooooooo08Cooooo0_l00008ooooo`Go00000_ooool2o`000004ooooool0003o0000o`0000Go
oooo0_l00002ooooo`?o00001oooool2o`0000Cooooo0_l0000Kooooo`;o0000M_ooool001cooooo
00?o0000ooooooooool0P_ooool2o`0000Sooooo0_l00003ooooo`;o00000_ooool2o`000003oooo
ool0003o000000Kooooo0_l0000:ooooo`Co0000VOooool001cooooo0_l0001looooo`;o00001Ooo
ool4o`0000Kooooo0_l0000:ooooo`;o00000oooool2o`0000Oooooo0ol00003ooooo`;o00000_oo
ool2o`0009Oooooo000Looooo`03o`000?oooooooooo07_ooooo0_l00007ooooo`;o00001Oooool2
o`000003ooooool0003o000000gooooo0_l00004ooooo`;o000000?oooooo`000?l000000_l00006
ooooo`?o0000U_ooool001cooooo00?o0000ooooooooool0Q?ooool2o`0000Gooooo0_l000000ooo
oooo0000o`00000Cooooo`;o00000_ooool3o`0000?ooooo0_l000001?oooooo0000o`000?l0002F
ooooo`007?ooool00ol0003oooooooooo`27ooooo`;o00006_ooool2o`0000?ooooo1?l000000ooo
oooo0000o`00002Jooooo`007?ooool00ol0003oooooooooo`27ooooo`;o00006_ooool2o`0000?o
oooo1?l0000;ooooo`;o0000T?ooool001cooooo00?o0000ooooooooool0[?ooool2o`0000Wooooo
0_l0002@ooooo`007?ooool00ol0003oooooooooo`2;ooooo`;o00007oooool2o`0009_ooooo000L
ooooo`03o`000?oooooooooo08_ooooo0_l0000Jooooo`;o0000X?ooool001cooooo00?o0000oooo
ooooool0TOooool2o`0001Cooooo0_l0002Pooooo`007?ooool00ol0003oooooooooo`2Aooooo`;o
0000]_ooool001cooooo00?o0000ooooooooool0Yoooool2o`0002?ooooo0_l0001kooooo`007?oo
ool00ol0003oooooooooo`29ooooo`;o00007?ooool2o`0002?ooooo0_l0001kooooo`007?ooool0
0ol0003oooooooooo`29ooooo`;o0000__ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0;Wooooo0_l0002>
ooooo`007?ooool00ol0003oooooooooo`2iooooo`;o0000S_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Vooooo`;o0000XOooool001cooooo00?o
0000ooooooooool0Y_ooool2o`000:7ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003o
oooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001;ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB_oo
ool001Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood[ooooo000Doooo
o`03o`000?oooooooooo00Gooooo0ol0003ooooood[ooooo000Dooooo`03o`000?oooooooooo0?oo
ooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003ooooooooo
o`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001;ooooo00?oEEEEofIV
I_l00000oooooomDooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00XOooool0
1?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo01Kooooo1?l000002?l@413ooooooooo
ooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Goc<c<
ob4Q8Ol0003o8B4Qolc<c02<ooooo`00X_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l0
000<ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05oa0@
4?nj^[[oooooogMgMolb<S800oooool01OlQ8B7oV9RHoooooonHV9So8B4Q08cooooo002Rooooo`05
o`000?ooooooooooooooool000006oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41001oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0R_oo
ool00:;ooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00003?ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000001_ooool00onYZJWo410@ooooo`02ooooo`05oc8b
<_nHV9SooooooiRHV?lb<S80S?ooool00:;ooooo00Go0000ohN7QoooooooZJVYo`00000Kooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`03oa0@4?l0003o^[Zj
00?ooooo00Goc<c<o`000?l0003o0000olc<c02<ooooo`00XOooool00ol@413o0000ogMgM`02o`00
0003oiRHV?oooooooooo01Wooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@00Kooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413o^[Zjoooooonj^[[o410@08cooooo0032
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05oa0@4?nH
V9SooooookZj^_l000000oooool01Ol0003o^[Zjoooooonj^[[o000008cooooo0030ooooo`03oeEE
EOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05ojVYZOl@413o0000oa0@
4?nYZJT00oooool01OnYZJWo410@o`000?l@413oZJVY08cooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1044) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.56039 .69698 Mdot
.57805 .66157 Mdot
.51627 .35927 Mdot
.38424 .56979 Mdot
.6552 .72486 Mdot
.55123 .33398 Mdot
.69047 .4645 Mdot
.65892 .51269 Mdot
.5338 .35733 Mdot
.58218 .5723 Mdot
.67113 .46654 Mdot
.32736 .57338 Mdot
.66096 .48485 Mdot
.37844 .54868 Mdot
.40428 .85315 Mdot
.45791 .53253 Mdot
.57181 .62678 Mdot
.33454 .3877 Mdot
.3751 .48734 Mdot
.57414 .33827 Mdot
.57557 .71088 Mdot
.38659 .56177 Mdot
.54826 .68377 Mdot
.37878 .54839 Mdot
.37084 .56877 Mdot
.56227 .63846 Mdot
.61221 .66697 Mdot
.40747 .59306 Mdot
.35238 .5378 Mdot
.675 .51025 Mdot
.2446 .46493 Mdot
.48766 .85778 Mdot
.37689 .47543 Mdot
.80578 .47489 Mdot
.65143 .50883 Mdot
.47555 .7934 Mdot
.54847 .35935 Mdot
.67332 .50321 Mdot
.64975 .50476 Mdot
.70314 .49113 Mdot
.65813 .50148 Mdot
.56787 .64416 Mdot
.69213 .43817 Mdot
.66713 .55124 Mdot
.38895 .4961 Mdot
.68801 .64017 Mdot
.24929 .58247 Mdot
.42525 .53433 Mdot
.57162 .62892 Mdot
.55535 .3801 Mdot
.7884 .49099 Mdot
.69588 .46435 Mdot
.53666 .29788 Mdot
.87178 .6205 Mdot
.68286 .49662 Mdot
.37404 .49704 Mdot
.52715 .37315 Mdot
.39633 .56146 Mdot
.38327 .54859 Mdot
.31975 .70868 Mdot
.40804 .59789 Mdot
.36202 .35513 Mdot
.51923 .64441 Mdot
.43251 .39046 Mdot
.5416 .35806 Mdot
.64837 .4979 Mdot
.58944 .6649 Mdot
.66748 .485 Mdot
.33503 .56642 Mdot
.49904 .39214 Mdot
.42523 .53632 Mdot
.64991 .48849 Mdot
.60271 .66371 Mdot
.42252 .55174 Mdot
.62344 .24138 Mdot
.21622 .68097 Mdot
.38451 .38578 Mdot
.38972 .75374 Mdot
.34125 .74019 Mdot
.43513 .28826 Mdot
.36548 .52097 Mdot
.26139 .32233 Mdot
.3209 .78459 Mdot
.54003 .67275 Mdot
.42889 .488 Mdot
.58172 .42592 Mdot
.41956 .556 Mdot
.63984 .61793 Mdot
.37083 .50359 Mdot
.72257 .28764 Mdot
.53322 .351 Mdot
.55667 .66687 Mdot
.3814 .56666 Mdot
.38332 .59457 Mdot
.32708 .64066 Mdot
.44124 .57763 Mdot
.40534 .5882 Mdot
.59598 .69232 Mdot
.66637 .46288 Mdot
.40872 .62476 Mdot
.65139 .44273 Mdot
.52178 .31702 Mdot
.43444 .52579 Mdot
.53335 .38197 Mdot
.60321 .68032 Mdot
.42858 .555 Mdot
.63934 .4837 Mdot
.40788 .51623 Mdot
.76121 .47287 Mdot
.58093 .66393 Mdot
.37693 .5897 Mdot
.37562 .35879 Mdot
.49187 .19001 Mdot
.55589 .67151 Mdot
.45945 .26914 Mdot
.37173 .51218 Mdot
.40928 .57906 Mdot
.57543 .6602 Mdot
.51194 .34282 Mdot
.63004 .62013 Mdot
.52565 .64392 Mdot
.70294 .49658 Mdot
.52222 .64544 Mdot
.38394 .46999 Mdot
.5421 .34548 Mdot
.6563 .41372 Mdot
.60376 .42524 Mdot
.23601 .43057 Mdot
.41573 .55897 Mdot
.71859 .56715 Mdot
.54935 .31698 Mdot
.55925 .6589 Mdot
.6694 .48115 Mdot
.47114 .59973 Mdot
.57405 .6841 Mdot
.68555 .47453 Mdot
.37308 .38695 Mdot
.67534 .36048 Mdot
.54505 .62766 Mdot
.72022 .53115 Mdot
.65999 .44886 Mdot
.70547 .47785 Mdot
.8093 .44958 Mdot
.58377 .65555 Mdot
.35366 .37953 Mdot
.68324 .48308 Mdot
.24772 .5205 Mdot
.34507 .51145 Mdot
.27592 .36797 Mdot
.23508 .31013 Mdot
.79862 .45809 Mdot
.68661 .32323 Mdot
.33223 .3488 Mdot
.70235 .46492 Mdot
.36194 .56811 Mdot
.57522 .63631 Mdot
.57707 .64297 Mdot
.4336 .57599 Mdot
.38059 .57312 Mdot
.4262 .54223 Mdot
.36412 .57774 Mdot
.28623 .70611 Mdot
.40952 .51165 Mdot
.19252 .41998 Mdot
.55032 .66584 Mdot
.38356 .58372 Mdot
.51042 .37443 Mdot
.34462 .5675 Mdot
.6537 .49879 Mdot
.39549 .56851 Mdot
.3867 .57419 Mdot
.39647 .60061 Mdot
.69193 .46212 Mdot
.478 .84365 Mdot
.29024 .26256 Mdot
.5753 .79755 Mdot
.53501 .25816 Mdot
.56 .32272 Mdot
.41921 .56542 Mdot
.3508 .35835 Mdot
.48425 .77674 Mdot
.37046 .52584 Mdot
.58683 .15421 Mdot
.40047 .58411 Mdot
.62973 .73957 Mdot
.42062 .46951 Mdot
.59483 .79513 Mdot
.26206 .34831 Mdot
.35337 .55852 Mdot
.37421 .64559 Mdot
.56038 .74135 Mdot
.7108 .53134 Mdot
.65972 .50003 Mdot
.50943 .36967 Mdot
.52171 .3676 Mdot
.63782 .5279 Mdot
.50953 .59974 Mdot
.47891 .60234 Mdot
.40074 .61315 Mdot
.50003 .3558 Mdot
.51605 .64294 Mdot
.33844 .3814 Mdot
.59188 .69178 Mdot
.13366 .55205 Mdot
.76966 .46315 Mdot
.61252 .50255 Mdot
.38268 .3798 Mdot
.52093 .34086 Mdot
.5208 .31632 Mdot
.34489 .36031 Mdot
.40441 .52571 Mdot
.58878 .65887 Mdot
.81978 .56882 Mdot
.50521 .58411 Mdot
.8358 .52421 Mdot
.59814 .65404 Mdot
.60805 .56434 Mdot
.6773 .47188 Mdot
.5593 .34921 Mdot
.4099 .58156 Mdot
.40487 .53731 Mdot
.57669 .7133 Mdot
.4232 .53821 Mdot
.48767 .63772 Mdot
.41684 .58348 Mdot
.72883 .42027 Mdot
.38511 .38634 Mdot
.6389 .52826 Mdot
.2291 .42658 Mdot
.57197 .69336 Mdot
.30929 .31756 Mdot
.50619 .38645 Mdot
.45541 .78139 Mdot
.64952 .48253 Mdot
.37626 .36824 Mdot
.50278 .38529 Mdot
.33446 .37688 Mdot
.33747 .5409 Mdot
.55326 .30283 Mdot
.36766 .35025 Mdot
.39051 .80217 Mdot
.34218 .52317 Mdot
.27661 .70208 Mdot
.681 .45749 Mdot
.52644 .63862 Mdot
.4085 .59734 Mdot
.5686 .33981 Mdot
.38757 .47406 Mdot
.65398 .28148 Mdot
.66017 .41431 Mdot
.56 .29543 Mdot
.44168 .34907 Mdot
.37361 .37023 Mdot
.61654 .27651 Mdot
.73247 .54581 Mdot
.58028 .63271 Mdot
.43469 .52095 Mdot
.5604 .82675 Mdot
.68273 .48283 Mdot
.3985 .52215 Mdot
.70495 .40783 Mdot
.68108 .48579 Mdot
.39835 .56106 Mdot
.65899 .45612 Mdot
.58036 .64448 Mdot
.38907 .22791 Mdot
.57393 .62763 Mdot
.37037 .50562 Mdot
.64165 .47434 Mdot
.53234 .31156 Mdot
.55764 .63658 Mdot
.41234 .51979 Mdot
.42636 .57261 Mdot
.5568 .43495 Mdot
.38235 .58685 Mdot
.52586 .82493 Mdot
.38907 .59383 Mdot
.51608 .37289 Mdot
.43687 .58354 Mdot
.69866 .23379 Mdot
.61867 .37769 Mdot
.58958 .66383 Mdot
.56435 .29932 Mdot
.53025 .36201 Mdot
.42127 .24535 Mdot
.53314 .29436 Mdot
.37629 .51375 Mdot
.56775 .32732 Mdot
.29682 .35835 Mdot
.6914 .49479 Mdot
.44524 .54006 Mdot
.62808 .55659 Mdot
.54565 .39054 Mdot
.50534 .34175 Mdot
.47051 .55183 Mdot
.60788 .66119 Mdot
.38116 .56745 Mdot
.5086 .34065 Mdot
.52179 .66642 Mdot
.38472 .50432 Mdot
.47825 .4984 Mdot
.55668 .43582 Mdot
.69248 .47275 Mdot
.44205 .48743 Mdot
.42454 .52111 Mdot
.54317 .36992 Mdot
.58989 .68572 Mdot
.65972 .51521 Mdot
.55789 .64442 Mdot
.71676 .70508 Mdot
.7475 .45274 Mdot
.33893 .75912 Mdot
.33151 .32931 Mdot
.70665 .31158 Mdot
.62553 .78681 Mdot
.57258 .2249 Mdot
.29926 .44876 Mdot
.7612 .68478 Mdot
.50442 .36364 Mdot
.72197 .40446 Mdot
.52756 .36601 Mdot
.36051 .54601 Mdot
.5468 .34576 Mdot
.61632 .7942 Mdot
.41401 .58565 Mdot
.55254 .34444 Mdot
.39242 .24116 Mdot
.38571 .58011 Mdot
.5571 .67448 Mdot
.38777 .83741 Mdot
.6033 .21202 Mdot
.78012 .45252 Mdot
.5498 .30878 Mdot
.28704 .50578 Mdot
.40136 .59099 Mdot
.40877 .6053 Mdot
.55357 .6314 Mdot
.44472 .56697 Mdot
.33583 .37687 Mdot
.37954 .38745 Mdot
.46556 .43854 Mdot
.29994 .2724 Mdot
.38612 .61845 Mdot
.55656 .63498 Mdot
.27786 .66458 Mdot
.64277 .24588 Mdot
.5477 .25952 Mdot
.7134 .47278 Mdot
.45367 .83673 Mdot
.49594 .6003 Mdot
.68158 .43303 Mdot
.64583 .55209 Mdot
.56839 .67013 Mdot
.49425 .84312 Mdot
.6649 .50055 Mdot
.4241 .67319 Mdot
.30144 .59477 Mdot
.40197 .53097 Mdot
.65635 .47257 Mdot
.3374 .58612 Mdot
.67145 .22991 Mdot
.2297 .57758 Mdot
.21146 .38691 Mdot
.38979 .50038 Mdot
.60122 .24022 Mdot
.40118 .5751 Mdot
.63265 .64264 Mdot
.39198 .59476 Mdot
.55137 .64539 Mdot
.58482 .5857 Mdot
.51294 .43841 Mdot
.24972 .30532 Mdot
.76889 .46785 Mdot
.33187 .34982 Mdot
.41698 .5788 Mdot
.40102 .53163 Mdot
.3597 .38763 Mdot
.54301 .67043 Mdot
.36123 .57418 Mdot
.31367 .39457 Mdot
.41765 .54435 Mdot
.66172 .50488 Mdot
.2064 .44035 Mdot
.61266 .68972 Mdot
.44341 .58346 Mdot
.52978 .67532 Mdot
.6945 .47594 Mdot
.65525 .50907 Mdot
.46627 .56784 Mdot
.68273 .51732 Mdot
.39561 .57911 Mdot
.19831 .52652 Mdot
.5341 .65044 Mdot
.47987 .53701 Mdot
.5553 .68647 Mdot
.38945 .75998 Mdot
.63786 .48625 Mdot
.70405 .41968 Mdot
.39873 .62807 Mdot
.66258 .49774 Mdot
.76598 .49433 Mdot
.4067 .61838 Mdot
.44209 .51521 Mdot
.74821 .3213 Mdot
.54201 .30975 Mdot
.53544 .43409 Mdot
.64081 .5015 Mdot
.42626 .52453 Mdot
.44969 .54834 Mdot
.69641 .47438 Mdot
.3597 .67135 Mdot
.47623 .22903 Mdot
.407 .5914 Mdot
.5446 .64971 Mdot
.55885 .65669 Mdot
.40965 .50138 Mdot
.39865 .51668 Mdot
.53081 .33408 Mdot
.56559 .30211 Mdot
.57828 .32047 Mdot
.55502 .4358 Mdot
.71521 .41952 Mdot
.72028 .64929 Mdot
.70324 .49017 Mdot
.73653 .57866 Mdot
.6993 .26758 Mdot
.33612 .50396 Mdot
.56227 .31537 Mdot
.39317 .53527 Mdot
.38538 .56783 Mdot
.66064 .51576 Mdot
.75538 .42575 Mdot
.3372 .47616 Mdot
.5326 .64136 Mdot
.64139 .50466 Mdot
.43596 .62381 Mdot
.762 .5967 Mdot
.36475 .35197 Mdot
.78741 .40842 Mdot
.64846 .48938 Mdot
.56774 .67414 Mdot
.64345 .46586 Mdot
.40768 .5369 Mdot
.37423 .49303 Mdot
.5693 .66336 Mdot
.36909 .34705 Mdot
.37123 .59694 Mdot
.40057 .56408 Mdot
.39285 .16774 Mdot
.61241 .23473 Mdot
.64623 .42224 Mdot
.36043 .56962 Mdot
.45288 .55152 Mdot
.33251 .38015 Mdot
.4143 .541 Mdot
.43264 .56721 Mdot
.43668 .19039 Mdot
.61487 .44523 Mdot
.34682 .40017 Mdot
.43108 .67762 Mdot
.59653 .64892 Mdot
.5289 .84476 Mdot
.56343 .3442 Mdot
.64922 .52663 Mdot
.48548 .21689 Mdot
.53614 .30073 Mdot
.66735 .28415 Mdot
.51564 .84981 Mdot
.54196 .43564 Mdot
.34031 .40888 Mdot
.32066 .51051 Mdot
.41956 .58791 Mdot
.40556 .57513 Mdot
.35131 .36519 Mdot
.58397 .65163 Mdot
.4758 .42761 Mdot
.22888 .6464 Mdot
.39277 .56965 Mdot
.48525 .63184 Mdot
.39951 .81393 Mdot
.50211 .40926 Mdot
.33461 .36999 Mdot
.37796 .3526 Mdot
.41448 .57785 Mdot
.45125 .19735 Mdot
.56259 .63749 Mdot
.41148 .51947 Mdot
.39309 .50874 Mdot
.5501 .30701 Mdot
.58172 .67003 Mdot
.50358 .36383 Mdot
.70251 .42127 Mdot
.61539 .75861 Mdot
.41156 .15404 Mdot
.64429 .50196 Mdot
.51335 .81075 Mdot
.68508 .5033 Mdot
.25301 .3433 Mdot
.53851 .29753 Mdot
.37002 .52105 Mdot
.58485 .68941 Mdot
.41188 .51767 Mdot
.38762 .52279 Mdot
.40314 .52599 Mdot
.36259 .59999 Mdot
.61453 .17176 Mdot
.34692 .35037 Mdot
.44646 .58326 Mdot
.51658 .36652 Mdot
.5133 .8165 Mdot
.25602 .71738 Mdot
.39989 .54054 Mdot
.42465 .57086 Mdot
.56059 .67971 Mdot
.43713 .57299 Mdot
.69048 .4944 Mdot
.59168 .68483 Mdot
.37769 .59109 Mdot
.47732 .83017 Mdot
.34988 .5415 Mdot
.5929 .78947 Mdot
.64139 .46778 Mdot
.75965 .5023 Mdot
.43048 .60607 Mdot
.64964 .41471 Mdot
.53519 .43404 Mdot
.57137 .32892 Mdot
.63564 .51061 Mdot
.54712 .35983 Mdot
.20719 .58898 Mdot
.36858 .48362 Mdot
.36368 .56804 Mdot
.44853 .54337 Mdot
.56403 .32423 Mdot
.65061 .64535 Mdot
.63409 .3047 Mdot
.45406 .61957 Mdot
.54104 .32766 Mdot
.51988 .65359 Mdot
.4443 .38834 Mdot
.57552 .69089 Mdot
.36298 .40448 Mdot
.66835 .46828 Mdot
.34586 .34383 Mdot
.79128 .46097 Mdot
.57882 .66349 Mdot
.58236 .71457 Mdot
.55912 .32727 Mdot
.59107 .49594 Mdot
.83231 .66086 Mdot
.51237 .41801 Mdot
.26635 .40411 Mdot
.54681 .63485 Mdot
.35978 .51437 Mdot
.23394 .3799 Mdot
.59519 .5169 Mdot
.54405 .36212 Mdot
.36572 .53342 Mdot
.41961 .21121 Mdot
.5317 .33261 Mdot
.44378 .53462 Mdot
.51902 .33418 Mdot
.65298 .48913 Mdot
.54226 .31663 Mdot
.57587 .62302 Mdot
.42712 .55765 Mdot
.81639 .68191 Mdot
.3279 .31235 Mdot
.38568 .5915 Mdot
.63924 .50105 Mdot
.4735 .47037 Mdot
.38309 .53136 Mdot
.3583 .39482 Mdot
.54353 .34028 Mdot
.5491 .40884 Mdot
.40338 .59323 Mdot
.55638 .32311 Mdot
.55805 .69425 Mdot
.63477 .5105 Mdot
.40842 .39749 Mdot
.6789 .41378 Mdot
.55814 .63023 Mdot
.73336 .45709 Mdot
.6503 .51777 Mdot
.45074 .55977 Mdot
.41158 .5109 Mdot
.54843 .65417 Mdot
.33976 .26229 Mdot
.4295 .59123 Mdot
.36549 .52117 Mdot
.51416 .36643 Mdot
.55534 .34765 Mdot
.34942 .25816 Mdot
.51419 .33815 Mdot
.36896 .49207 Mdot
.54929 .65271 Mdot
.37399 .55678 Mdot
.56627 .67933 Mdot
.43941 .55944 Mdot
.51045 .62415 Mdot
.53629 .66221 Mdot
.60218 .28011 Mdot
.36798 .54536 Mdot
.4379 .48121 Mdot
.39547 .52419 Mdot
.42237 .54222 Mdot
.52779 .3406 Mdot
.33768 .36679 Mdot
.46772 .5921 Mdot
.34291 .40375 Mdot
.34779 .38834 Mdot
.5709 .74099 Mdot
.54738 .30835 Mdot
.36027 .3722 Mdot
.30665 .74135 Mdot
.56979 .31201 Mdot
.35639 .35749 Mdot
.28366 .7425 Mdot
.6465 .50522 Mdot
.57733 .62671 Mdot
.38459 .57917 Mdot
.76356 .67636 Mdot
.21157 .52223 Mdot
.53993 .29963 Mdot
.38582 .59256 Mdot
.38968 .53474 Mdot
.52833 .65704 Mdot
.16004 .4469 Mdot
.52951 .38854 Mdot
.36093 .55276 Mdot
.5885 .66899 Mdot
.16664 .39089 Mdot
.51866 .37659 Mdot
.35418 .35963 Mdot
.69297 .4619 Mdot
.55707 .61054 Mdot
.60308 .42441 Mdot
.69632 .46851 Mdot
.61481 .32421 Mdot
.78055 .46958 Mdot
.37247 .5119 Mdot
.56257 .31606 Mdot
.80147 .41031 Mdot
.50151 .60606 Mdot
.72467 .47338 Mdot
.28929 .52297 Mdot
.56573 .67084 Mdot
.69037 .49225 Mdot
.33851 .34552 Mdot
.60059 .66268 Mdot
.54029 .66099 Mdot
.67028 .5162 Mdot
.41896 .42865 Mdot
.60452 .55543 Mdot
.65982 .50737 Mdot
.72691 .29825 Mdot
.75764 .65298 Mdot
.56911 .31807 Mdot
.34865 .38715 Mdot
.80969 .55838 Mdot
.56686 .64379 Mdot
.45722 .83676 Mdot
.7914 .39398 Mdot
.40508 .58826 Mdot
.36226 .37659 Mdot
.67338 .66408 Mdot
.21758 .62379 Mdot
.68179 .4876 Mdot
.53855 .4459 Mdot
.36161 .33487 Mdot
.41865 .5919 Mdot
.27532 .5645 Mdot
.36081 .53678 Mdot
.67633 .46851 Mdot
.32004 .71992 Mdot
.56791 .67498 Mdot
.64681 .51268 Mdot
.78759 .41053 Mdot
.39408 .5756 Mdot
.36502 .53807 Mdot
.22819 .45702 Mdot
.58753 .64588 Mdot
.57173 .33442 Mdot
.37344 .51289 Mdot
.39835 .5662 Mdot
.43956 .50675 Mdot
.47509 .53067 Mdot
.48383 .19132 Mdot
.36158 .55066 Mdot
.73818 .43274 Mdot
.44341 .58478 Mdot
.37031 .54515 Mdot
.52684 .67145 Mdot
.46513 .1456 Mdot
.71038 .42258 Mdot
.39695 .56868 Mdot
.35555 .51972 Mdot
.6698 .51713 Mdot
.56913 .54316 Mdot
.59456 .50154 Mdot
.57393 .43082 Mdot
.29179 .46896 Mdot
.35768 .59612 Mdot
.58616 .68215 Mdot
.37674 .3576 Mdot
.41447 .50523 Mdot
.58576 .68118 Mdot
.34797 .56 Mdot
.53526 .32861 Mdot
.5686 .31043 Mdot
.73195 .52875 Mdot
.3599 .36478 Mdot
.21862 .49563 Mdot
.72688 .59132 Mdot
.51049 .36469 Mdot
.36752 .5699 Mdot
.63363 .51981 Mdot
.50971 .33688 Mdot
.58867 .4287 Mdot
.46645 .53025 Mdot
.57199 .63784 Mdot
.55536 .66825 Mdot
.27654 .36592 Mdot
.68349 .34496 Mdot
.38632 .18538 Mdot
.65296 .48496 Mdot
.39252 .60238 Mdot
.72066 .55694 Mdot
.55579 .67002 Mdot
.245 .37623 Mdot
.36208 .37124 Mdot
.68345 .48754 Mdot
.54846 .26075 Mdot
.57109 .68298 Mdot
.55815 .62553 Mdot
.35589 .51205 Mdot
.40266 .55414 Mdot
.30173 .43864 Mdot
.36774 .42642 Mdot
.69482 .48044 Mdot
.35634 .38859 Mdot
.50166 .38273 Mdot
.35748 .54307 Mdot
.54285 .67814 Mdot
.80127 .59243 Mdot
.36017 .51577 Mdot
.52751 .33717 Mdot
.56389 .66795 Mdot
.36623 .38572 Mdot
.35063 .39126 Mdot
.42124 .54248 Mdot
.28808 .66795 Mdot
.67629 .49671 Mdot
.5581 .67415 Mdot
.78223 .55003 Mdot
.43471 .58776 Mdot
.40647 .55869 Mdot
.37683 .4625 Mdot
.6803 .51101 Mdot
.74482 .52134 Mdot
.36411 .34045 Mdot
.5758 .64995 Mdot
.35111 .55093 Mdot
.36298 .35784 Mdot
.73817 .53431 Mdot
.55141 .29683 Mdot
.53473 .32075 Mdot
.35634 .39423 Mdot
.35914 .38393 Mdot
.36408 .39262 Mdot
.44534 .83891 Mdot
.57023 .61938 Mdot
.47856 .52191 Mdot
.42026 .59848 Mdot
.26879 .36757 Mdot
.45885 .60849 Mdot
.63567 .47389 Mdot
.53642 .31335 Mdot
.39051 .52504 Mdot
.37254 .50547 Mdot
.41661 .47056 Mdot
.46103 .49807 Mdot
.6114 .68768 Mdot
.58139 .66604 Mdot
.35227 .48788 Mdot
.54712 .30509 Mdot
.13154 .525 Mdot
.70036 .76664 Mdot
.43719 .60222 Mdot
.59186 .53514 Mdot
.54421 .67853 Mdot
.68924 .50855 Mdot
.58717 .45771 Mdot
.64912 .4626 Mdot
.57029 .65237 Mdot
.35863 .54508 Mdot
.7396 .58422 Mdot
.34614 .39205 Mdot
.42785 .53274 Mdot
.68108 .47597 Mdot
.42756 .53756 Mdot
.69578 .46751 Mdot
.69442 .70819 Mdot
.68647 .25156 Mdot
.40134 .58469 Mdot
.45348 .56288 Mdot
.29326 .50706 Mdot
.39804 .54109 Mdot
.39136 .3207 Mdot
.54569 .67833 Mdot
.33487 .23336 Mdot
.34749 .51823 Mdot
.44486 .74136 Mdot
.43106 .59287 Mdot
.42349 .21553 Mdot
.40695 .5534 Mdot
.4877 .40705 Mdot
.41344 .5907 Mdot
.4319 .5607 Mdot
.64445 .46884 Mdot
.66827 .51691 Mdot
.58191 .70487 Mdot
.56957 .3379 Mdot
.56935 .80568 Mdot
.40305 .56306 Mdot
.6781 .41301 Mdot
.69447 .42869 Mdot
.35513 .38527 Mdot
.56929 .65032 Mdot
.1567 .40875 Mdot
.67835 .45461 Mdot
.51953 .24412 Mdot
.33021 .27969 Mdot
.60733 .42312 Mdot
.58204 .43405 Mdot
.61573 .60611 Mdot
.37335 .36482 Mdot
.41794 .59342 Mdot
.80362 .49653 Mdot
.62266 .24664 Mdot
.47911 .59144 Mdot
.64198 .51092 Mdot
.46474 .77389 Mdot
.80588 .56998 Mdot
.37488 .34229 Mdot
.34992 .34127 Mdot
.69052 .46272 Mdot
.5573 .37506 Mdot
.32623 .55463 Mdot
.36428 .36976 Mdot
.5111 .35166 Mdot
.57164 .31717 Mdot
.53083 .27877 Mdot
.56743 .6399 Mdot
.78528 .42559 Mdot
.69241 .62175 Mdot
.6946 .46855 Mdot
.31697 .31737 Mdot
.57309 .61536 Mdot
.60227 .64214 Mdot
.56311 .33778 Mdot
.52485 .34363 Mdot
.59261 .63578 Mdot
.35336 .50219 Mdot
.38873 .45782 Mdot
.39548 .57085 Mdot
.34757 .36837 Mdot
.40526 .54652 Mdot
.53445 .33483 Mdot
.67638 .4865 Mdot
.52394 .35033 Mdot
.66839 .45403 Mdot
.72943 .63452 Mdot
.41363 .52398 Mdot
.42831 .56379 Mdot
.20871 .51921 Mdot
.56126 .69901 Mdot
.78292 .5015 Mdot
.72894 .41688 Mdot
.525 .36671 Mdot
.43271 .56917 Mdot
.56428 .69392 Mdot
.3853 .36427 Mdot
.20664 .51698 Mdot
.42555 .5182 Mdot
.54823 .68171 Mdot
.35969 .5581 Mdot
.34163 .77082 Mdot
.58363 .19745 Mdot
.55698 .64802 Mdot
.22814 .32458 Mdot
.35357 .53893 Mdot
.58199 .59391 Mdot
.44049 .52346 Mdot
.29889 .39156 Mdot
.4317 .58905 Mdot
.59823 .65384 Mdot
.39189 .56418 Mdot
.59879 .66988 Mdot
.51459 .37849 Mdot
.70077 .4955 Mdot
.54215 .63547 Mdot
.4068 .50859 Mdot
.55101 .87081 Mdot
.66821 .47052 Mdot
.41308 .58053 Mdot
.66664 .46059 Mdot
.5925 .66692 Mdot
.56131 .62699 Mdot
.21765 .64616 Mdot
.62672 .43012 Mdot
.65354 .49054 Mdot
.36472 .55764 Mdot
.65934 .60119 Mdot
.36853 .55183 Mdot
.28786 .43003 Mdot
.39831 .49436 Mdot
.43539 .58555 Mdot
.21304 .67672 Mdot
.69286 .49423 Mdot
.40241 .18531 Mdot
.23489 .66167 Mdot
.43049 .83545 Mdot
.53664 .61134 Mdot
.37598 .34445 Mdot
.48963 .84262 Mdot
.69557 .41916 Mdot
.54815 .32372 Mdot
.39261 .52547 Mdot
.61927 .66915 Mdot
.67637 .5027 Mdot
.33859 .36515 Mdot
.40225 .58472 Mdot
.52365 .34317 Mdot
.48655 .23612 Mdot
.70567 .46799 Mdot
.56844 .64485 Mdot
.53112 .64648 Mdot
.20004 .3412 Mdot
.35206 .55667 Mdot
.42922 .56859 Mdot
.67402 .46728 Mdot
.49949 .58721 Mdot
.37461 .37364 Mdot
.43308 .2248 Mdot
.65376 .48862 Mdot
.56982 .48887 Mdot
.58494 .65975 Mdot
.39125 .53444 Mdot
.65226 .67132 Mdot
.53533 .26265 Mdot
.47717 .68202 Mdot
.35005 .36135 Mdot
.28207 .43664 Mdot
.59804 .65282 Mdot
.67393 .4801 Mdot
.68713 .36676 Mdot
.40137 .47561 Mdot
.38907 .53964 Mdot
.27691 .4377 Mdot
.45042 .42981 Mdot
.20834 .39664 Mdot
.43947 .53076 Mdot
.46021 .42792 Mdot
.43945 .54134 Mdot
.42156 .48699 Mdot
.3675 .49525 Mdot
.41203 .56109 Mdot
.54678 .68057 Mdot
.4777 .56842 Mdot
.55272 .31958 Mdot
.33404 .64242 Mdot
.56887 .44879 Mdot
.39653 .59355 Mdot
.36199 .5449 Mdot
.50621 .72437 Mdot
.68971 .43413 Mdot
.53831 .65059 Mdot
.53593 .69518 Mdot
.69034 .51253 Mdot
.41185 .46599 Mdot
.56066 .35398 Mdot
.47235 .55321 Mdot
.52783 .34454 Mdot
.55629 .68882 Mdot
.52351 .3705 Mdot
.70719 .48219 Mdot
.56247 .31358 Mdot
.72118 .42018 Mdot
.68657 .49705 Mdot
.58081 .6381 Mdot
.42155 .55052 Mdot
.64198 .50472 Mdot
.23324 .45518 Mdot
.34823 .36807 Mdot
.21874 .65216 Mdot
.34714 .55153 Mdot
.60337 .44406 Mdot
.47638 .49524 Mdot
.52548 .34934 Mdot
.52738 .1855 Mdot
.53549 .65956 Mdot
.36493 .40063 Mdot
.55701 .69006 Mdot
.75691 .31495 Mdot
.3414 .37631 Mdot
.29198 .75091 Mdot
.71226 .35477 Mdot
.54846 .39698 Mdot
.35062 .50518 Mdot
.28661 .57548 Mdot
.49878 .3811 Mdot
.67793 .5017 Mdot
.69557 .3412 Mdot
.43246 .55708 Mdot
.57572 .22983 Mdot
.58487 .70596 Mdot
.56939 .32979 Mdot
.66653 .48344 Mdot
.64885 .51219 Mdot
.40375 .51335 Mdot
.38116 .26543 Mdot
.43425 .534 Mdot
.66736 .33877 Mdot
.28841 .46117 Mdot
.34972 .46317 Mdot
.41727 .58265 Mdot
.53001 .3814 Mdot
.36032 .55867 Mdot
.33504 .45964 Mdot
.8072 .45981 Mdot
.36858 .60221 Mdot
.74901 .42539 Mdot
.32668 .31671 Mdot
.57345 .66276 Mdot
.4352 .60843 Mdot
.62227 .41945 Mdot
.35374 .55504 Mdot
.79843 .30956 Mdot
.35829 .35722 Mdot
.64407 .40816 Mdot
.4411 .58485 Mdot
.39109 .51206 Mdot
.30842 .58116 Mdot
.61995 .64721 Mdot
.54258 .25737 Mdot
.39001 .54613 Mdot
.26248 .49712 Mdot
.65777 .46952 Mdot
.43267 .52806 Mdot
.40794 .5769 Mdot
.58461 .74866 Mdot
.66713 .51393 Mdot
.52148 .36011 Mdot
.53528 .29925 Mdot
.50561 .39867 Mdot
.32367 .36815 Mdot
.55175 .45916 Mdot
.25728 .37333 Mdot
.5989 .2149 Mdot
.3801 .37207 Mdot
.34735 .53295 Mdot
.31361 .49606 Mdot
.35707 .5226 Mdot
.33591 .347 Mdot
.6742 .51197 Mdot
.53712 .64875 Mdot
.68597 .55792 Mdot
.49701 .39044 Mdot
.44552 .53974 Mdot
.33091 .3676 Mdot
.57416 .63651 Mdot
.39354 .35781 Mdot
.57573 .6568 Mdot
.65719 .49133 Mdot
.67948 .52184 Mdot
.33637 .35725 Mdot
.56944 .69141 Mdot
.73664 .44682 Mdot
.22581 .62737 Mdot
.39429 .4923 Mdot
.69723 .53128 Mdot
.56673 .69901 Mdot
.60726 .68629 Mdot
.59145 .69538 Mdot
.42158 .53472 Mdot
.58841 .53525 Mdot
.44842 .51752 Mdot
.69379 .47714 Mdot
.51896 .33527 Mdot
.30863 .37828 Mdot
.76006 .63597 Mdot
.30599 .35838 Mdot
.36858 .59181 Mdot
.39082 .57075 Mdot
.41411 .57804 Mdot
.38102 .4988 Mdot
.66297 .35496 Mdot
.40462 .51903 Mdot
.64974 .46431 Mdot
.53765 .34188 Mdot
.40814 .59835 Mdot
.5468 .29786 Mdot
.62439 .59737 Mdot
.3771 .35617 Mdot
.54055 .45395 Mdot
.54744 .84743 Mdot
.56797 .6335 Mdot
.5138 .33744 Mdot
.5497 .3243 Mdot
.37344 .38628 Mdot
.67238 .50282 Mdot
.58117 .65567 Mdot
.30968 .40263 Mdot
.36057 .39141 Mdot
.39451 .56531 Mdot
.59058 .28281 Mdot
.56238 .23704 Mdot
.42931 .58479 Mdot
.37779 .52511 Mdot
.55891 .29514 Mdot
.55285 .3813 Mdot
.84506 .53864 Mdot
.22204 .3989 Mdot
.33622 .36191 Mdot
.36841 .34788 Mdot
.60718 .65722 Mdot
.45657 .57 Mdot
.69311 .47398 Mdot
.20309 .45281 Mdot
.46296 .45466 Mdot
.21406 .48216 Mdot
.41178 .39499 Mdot
.41773 .51579 Mdot
.29709 .64564 Mdot
.39375 .57684 Mdot
.53294 .66113 Mdot
.59234 .65714 Mdot
.54611 .63985 Mdot
.67994 .4974 Mdot
.40936 .76866 Mdot
.64308 .47349 Mdot
.581 .83078 Mdot
.59815 .64961 Mdot
.65186 .38056 Mdot
.53676 .37563 Mdot
.42286 .61004 Mdot
.37084 .37945 Mdot
.67276 .44385 Mdot
.33237 .56064 Mdot
.46286 .19321 Mdot
.56181 .32173 Mdot
.58209 .63811 Mdot
.61504 .60751 Mdot
.66267 .76496 Mdot
.58787 .47579 Mdot
.4252 .62776 Mdot
.29753 .57489 Mdot
.35233 .38582 Mdot
.47064 .67775 Mdot
.33116 .34852 Mdot
.68486 .48042 Mdot
.42577 .5609 Mdot
.41885 .55705 Mdot
.44049 .55501 Mdot
.40737 .52086 Mdot
.68096 .51619 Mdot
.39654 .60823 Mdot
.69867 .2338 Mdot
.56888 .30907 Mdot
.37236 .7895 Mdot
.36761 .35877 Mdot
.63619 .50728 Mdot
.53583 .3416 Mdot
.58092 .30385 Mdot
.23148 .41231 Mdot
.4088 .59068 Mdot
.39236 .524 Mdot
.52804 .24938 Mdot
.44148 .53592 Mdot
.42987 .62314 Mdot
.55413 .32302 Mdot
.30688 .36523 Mdot
.38208 .37402 Mdot
.35021 .34364 Mdot
.66622 .51154 Mdot
.56412 .6918 Mdot
.35532 .37037 Mdot
.51486 .37658 Mdot
.35212 .57143 Mdot
.38993 .50727 Mdot
.56909 .70021 Mdot
.7911 .38826 Mdot
.37245 .34001 Mdot
.61216 .59923 Mdot
.59541 .67423 Mdot
.56533 .61679 Mdot
.38743 .53991 Mdot
.4815 .58601 Mdot
.60982 .63968 Mdot
.37235 .39209 Mdot
.63957 .51202 Mdot
.57212 .41989 Mdot
.68391 .47245 Mdot
.58252 .64771 Mdot
.3959 .50365 Mdot
.58614 .64796 Mdot
.364 .57456 Mdot
.41296 .87718 Mdot
.41381 .55652 Mdot
.62479 .21514 Mdot
.28504 .39756 Mdot
.54918 .33293 Mdot
.73562 .44372 Mdot
.56554 .33449 Mdot
.59656 .66877 Mdot
.40651 .50495 Mdot
.36174 .34098 Mdot
.3817 .82101 Mdot
.58168 .6188 Mdot
.53736 .32458 Mdot
.5604 .35987 Mdot
.68667 .50026 Mdot
.4082 .59951 Mdot
.39283 .53755 Mdot
.55372 .34463 Mdot
.37933 .44617 Mdot
.56619 .68518 Mdot
.42558 .5723 Mdot
.37934 .55667 Mdot
.55116 .33133 Mdot
.22345 .61633 Mdot
.59798 .61131 Mdot
.42002 .56405 Mdot
.7008 .39131 Mdot
.63423 .47831 Mdot
.36176 .50196 Mdot
.41011 .61296 Mdot
.36427 .37935 Mdot
.43198 .80732 Mdot
.80948 .47336 Mdot
.63845 .469 Mdot
.56516 .34377 Mdot
.34944 .5514 Mdot
.53906 .37417 Mdot
.39767 .50785 Mdot
.52584 .79673 Mdot
.57026 .32252 Mdot
.37927 .51549 Mdot
.4463 .59152 Mdot
.59044 .64911 Mdot
.40204 .51657 Mdot
.53007 .73363 Mdot
.50179 .36363 Mdot
.3893 .51466 Mdot
.29187 .67118 Mdot
.65046 .50246 Mdot
.43839 .60278 Mdot
.36512 .35006 Mdot
.30654 .39356 Mdot
.72248 .60429 Mdot
.69573 .41044 Mdot
.35646 .34608 Mdot
.42972 .53891 Mdot
.56451 .35671 Mdot
.69406 .46531 Mdot
.56562 .21875 Mdot
.43477 .57034 Mdot
.67509 .46896 Mdot
.67443 .48592 Mdot
.35765 .35055 Mdot
.33049 .21154 Mdot
.40716 .61121 Mdot
.4006 .54156 Mdot
.5543 .74765 Mdot
.52346 .65569 Mdot
.40901 .54748 Mdot
.35232 .52166 Mdot
.65418 .4625 Mdot
.40862 .62976 Mdot
.48914 .75634 Mdot
.39396 .23907 Mdot
.66464 .45021 Mdot
.5237 .41908 Mdot
.57059 .34431 Mdot
.36789 .3618 Mdot
.56615 .66208 Mdot
.34936 .3338 Mdot
.55174 .31091 Mdot
.34936 .53315 Mdot
.6767 .45664 Mdot
.50038 .67645 Mdot
.69682 .46587 Mdot
.67429 .40953 Mdot
.54659 .68673 Mdot
.69927 .56904 Mdot
.72594 .23358 Mdot
.69647 .62799 Mdot
.67044 .43441 Mdot
.35524 .38516 Mdot
.61163 .32326 Mdot
.38279 .56116 Mdot
.44189 .66802 Mdot
.42393 .54717 Mdot
.30063 .67344 Mdot
.51671 .33529 Mdot
.57886 .32161 Mdot
.42329 .56175 Mdot
.28907 .45219 Mdot
.70038 .4724 Mdot
.69184 .49399 Mdot
.38927 .51755 Mdot
.66224 .49791 Mdot
.39974 .55291 Mdot
.52993 .33993 Mdot
.44671 .17183 Mdot
.40033 .57779 Mdot
.44601 .52089 Mdot
.61375 .51929 Mdot
.2273 .6823 Mdot
.73391 .38929 Mdot
.29668 .63826 Mdot
.68843 .74626 Mdot
.6625 .49713 Mdot
.46557 .5523 Mdot
.51324 .41992 Mdot
.55751 .29457 Mdot
.73616 .44758 Mdot
.41421 .54478 Mdot
.41473 .54009 Mdot
.43111 .57089 Mdot
.36423 .53765 Mdot
.44876 .6712 Mdot
.49463 .58105 Mdot
.34173 .70614 Mdot
.38966 .52254 Mdot
.27456 .57468 Mdot
.64103 .50093 Mdot
.57133 .71019 Mdot
.3485 .33171 Mdot
.41627 .51549 Mdot
.49763 .61451 Mdot
.63313 .48593 Mdot
.58343 .82969 Mdot
.67901 .508 Mdot
.53118 .36195 Mdot
.69572 .50186 Mdot
.37992 .58628 Mdot
.55808 .65698 Mdot
.5677 .43147 Mdot
.62265 .27807 Mdot
.54723 .32378 Mdot
.38586 .59164 Mdot
.63161 .40869 Mdot
.54904 .32065 Mdot
.62869 .599 Mdot
.55855 .66159 Mdot
.25636 .49908 Mdot
.59263 .65677 Mdot
.37952 .51449 Mdot
.37097 .51686 Mdot
.73069 .48949 Mdot
.70409 .47881 Mdot
.59408 .66159 Mdot
.37749 .17232 Mdot
.33011 .34865 Mdot
.54986 .63972 Mdot
.37169 .47559 Mdot
.52634 .51188 Mdot
.55134 .6582 Mdot
.33825 .43425 Mdot
.68292 .49823 Mdot
.60148 .65031 Mdot
.37214 .47423 Mdot
.75072 .34792 Mdot
.36089 .39829 Mdot
.53938 .38686 Mdot
.48626 .353 Mdot
.50593 .34697 Mdot
.64604 .5188 Mdot
.56202 .32746 Mdot
.6525 .47242 Mdot
.77565 .50508 Mdot
.25971 .58477 Mdot
.63429 .52224 Mdot
.6609 .52282 Mdot
.55826 .32738 Mdot
.42338 .5805 Mdot
.49566 .35234 Mdot
.4221 .50046 Mdot
.33021 .53799 Mdot
.64721 .48065 Mdot
.59652 .65138 Mdot
.57131 .62327 Mdot
.27892 .57364 Mdot
.53056 .64723 Mdot
.52662 .34422 Mdot
.58931 .20252 Mdot
.79032 .46645 Mdot
.66062 .47077 Mdot
.6698 .52045 Mdot
.36645 .54976 Mdot
.54577 .36107 Mdot
.51703 .38514 Mdot
.68904 .48537 Mdot
.42192 .65179 Mdot
.45952 .54867 Mdot
.59651 .70396 Mdot
.59755 .64709 Mdot
.55233 .65005 Mdot
.59594 .68877 Mdot
.47491 .73534 Mdot
.6845 .49737 Mdot
.59894 .6582 Mdot
.38279 .51666 Mdot
.41387 .54106 Mdot
.57272 .43309 Mdot
.35373 .34405 Mdot
.35164 .56593 Mdot
.36136 .49498 Mdot
.38682 .53697 Mdot
.53739 .3197 Mdot
.34238 .48603 Mdot
.57257 .33226 Mdot
.53485 .38886 Mdot
.55917 .30182 Mdot
.70022 .41899 Mdot
.29172 .56043 Mdot
.71587 .73518 Mdot
.36071 .55282 Mdot
.50455 .57601 Mdot
.53526 .37437 Mdot
.501 .18645 Mdot
.73477 .53294 Mdot
.43361 .56965 Mdot
.53214 .26619 Mdot
.55573 .34188 Mdot
.53125 .63842 Mdot
.41414 .54843 Mdot
.49795 .39969 Mdot
.37758 .36057 Mdot
.38255 .47888 Mdot
.51779 .31925 Mdot
.57759 .68923 Mdot
.32908 .33775 Mdot
.60335 .65869 Mdot
.55061 .30152 Mdot
.44438 .59488 Mdot
.84633 .64589 Mdot
.50472 .39486 Mdot
.29199 .73453 Mdot
.55071 .60433 Mdot
.42598 .57334 Mdot
.51011 .34296 Mdot
.52428 .65534 Mdot
.64178 .51713 Mdot
.48886 .45358 Mdot
.53447 .6497 Mdot
.57857 .32151 Mdot
.51301 .32725 Mdot
.55301 .32289 Mdot
.57804 .66878 Mdot
.41775 .50341 Mdot
.57445 .67667 Mdot
.69421 .50267 Mdot
.38336 .5719 Mdot
.61571 .79328 Mdot
.50112 .57634 Mdot
.59559 .66906 Mdot
.51818 .35464 Mdot
.33592 .38494 Mdot
.3971 .58498 Mdot
.27263 .70567 Mdot
.37668 .5889 Mdot
.66885 .46476 Mdot
.39509 .21139 Mdot
.49865 .67836 Mdot
.42466 .59606 Mdot
.36582 .54839 Mdot
.69439 .48631 Mdot
.405 .58948 Mdot
.4257 .59373 Mdot
.66918 .42124 Mdot
.5837 .67018 Mdot
.38892 .56305 Mdot
.51311 .35453 Mdot
.79506 .50921 Mdot
.45678 .53364 Mdot
.46594 .267 Mdot
.26544 .47978 Mdot
.36767 .21341 Mdot
.42642 .55018 Mdot
.21423 .42967 Mdot
.36703 .53162 Mdot
.42463 .52883 Mdot
.36697 .5562 Mdot
.30073 .63324 Mdot
.55984 .31708 Mdot
.53971 .33181 Mdot
.36352 .39798 Mdot
.26508 .48401 Mdot
.36361 .37658 Mdot
.67608 .50598 Mdot
.44012 .27737 Mdot
.56957 .32188 Mdot
.57812 .68984 Mdot
.43244 .53788 Mdot
.49977 .39358 Mdot
.39357 .53258 Mdot
.37473 .58268 Mdot
.53184 .38304 Mdot
.52299 .39085 Mdot
.66036 .41156 Mdot
.37215 .35268 Mdot
.54245 .63891 Mdot
.33847 .52922 Mdot
.34612 .38692 Mdot
.41869 .50505 Mdot
.2662 .3601 Mdot
.54166 .64225 Mdot
.58195 .67229 Mdot
.54919 .62416 Mdot
.3494 .53426 Mdot
.38991 .58998 Mdot
.64381 .47346 Mdot
.57142 .6929 Mdot
.65404 .5041 Mdot
.5577 .43317 Mdot
.45268 .25969 Mdot
.41423 .5446 Mdot
.5916 .58835 Mdot
.37 .37305 Mdot
.53157 .35389 Mdot
.49913 .24392 Mdot
.35596 .39921 Mdot
.37495 .58648 Mdot
.53195 .38095 Mdot
.33769 .34866 Mdot
.37786 .63671 Mdot
.77152 .68469 Mdot
.32853 .37188 Mdot
.38394 .51757 Mdot
.34407 .6104 Mdot
.2208 .57148 Mdot
.32467 .36791 Mdot
.67512 .4594 Mdot
.34869 .53542 Mdot
.4838 .51953 Mdot
.36918 .33845 Mdot
.78539 .5204 Mdot
.5473 .33918 Mdot
.76491 .39478 Mdot
.32551 .52442 Mdot
.40161 .66117 Mdot
.34086 .33729 Mdot
.57868 .65295 Mdot
.53358 .68264 Mdot
.37906 .53925 Mdot
.32322 .36186 Mdot
.67712 .45084 Mdot
.54338 .34455 Mdot
.72537 .42471 Mdot
.57634 .67055 Mdot
.63596 .57565 Mdot
.52015 .33783 Mdot
.60359 .5875 Mdot
.4032 .22312 Mdot
.36114 .4567 Mdot
.27377 .62201 Mdot
.64175 .25924 Mdot
.34653 .52682 Mdot
.32853 .35653 Mdot
.6351 .48035 Mdot
.68525 .45872 Mdot
.65528 .48613 Mdot
.73465 .43976 Mdot
.5801 .45552 Mdot
.5362 .30691 Mdot
.60245 .2613 Mdot
.36335 .35956 Mdot
.24719 .53512 Mdot
.42205 .50974 Mdot
.39268 .57233 Mdot
.39031 .6013 Mdot
.43413 .52683 Mdot
.37086 .5379 Mdot
.66672 .5028 Mdot
.73555 .43822 Mdot
.5524 .40919 Mdot
.54376 .65209 Mdot
.30805 .35689 Mdot
.53638 .37576 Mdot
.56359 .29844 Mdot
.34236 .35453 Mdot
.62875 .62625 Mdot
.52704 .31287 Mdot
.52322 .36826 Mdot
.37303 .58929 Mdot
.57342 .68225 Mdot
.4768 .57693 Mdot
.36521 .52205 Mdot
.53211 .34836 Mdot
.43542 .39077 Mdot
.50876 .7452 Mdot
.427 .48396 Mdot
.33774 .32456 Mdot
.57848 .53259 Mdot
.32489 .36654 Mdot
.43734 .51613 Mdot
.48468 .18552 Mdot
.55295 .31151 Mdot
.53768 .36383 Mdot
.33067 .35712 Mdot
.58722 .59935 Mdot
.56737 .66802 Mdot
.58168 .30422 Mdot
.66121 .4637 Mdot
.3628 .51809 Mdot
.46989 .24429 Mdot
.56373 .59351 Mdot
.40273 .26167 Mdot
.65625 .47918 Mdot
.5195 .38315 Mdot
.41128 .59966 Mdot
.38268 .5186 Mdot
.35711 .3872 Mdot
.67289 .71747 Mdot
.37063 .48194 Mdot
.43402 .83703 Mdot
.69899 .26095 Mdot
.77187 .36704 Mdot
.38926 .53975 Mdot
.58285 .66843 Mdot
.53845 .29771 Mdot
.35033 .38765 Mdot
.35349 .57912 Mdot
.75439 .70205 Mdot
.56759 .70503 Mdot
.68037 .47952 Mdot
.51596 .42507 Mdot
.58787 .45704 Mdot
.35302 .5622 Mdot
.42297 .54756 Mdot
.41721 .52855 Mdot
.82406 .60032 Mdot
.53035 .32743 Mdot
.53974 .67597 Mdot
.34822 .35998 Mdot
.53064 .65026 Mdot
.54448 .33104 Mdot
.66407 .57441 Mdot
.40419 .59472 Mdot
.56761 .70393 Mdot
.57569 .65356 Mdot
.68555 .50133 Mdot
.64888 .5218 Mdot
.54516 .42438 Mdot
.41259 .55696 Mdot
.49877 .35898 Mdot
.59 .64617 Mdot
.57389 .28109 Mdot
.34318 .37851 Mdot
.63859 .48916 Mdot
.39166 .52236 Mdot
.55157 .31501 Mdot
.39308 .60817 Mdot
.55147 .66729 Mdot
.52367 .36916 Mdot
.65582 .41292 Mdot
.36745 .34814 Mdot
.40675 .53045 Mdot
.35164 .32405 Mdot
.56369 .34629 Mdot
.37977 .55841 Mdot
.63037 .65017 Mdot
.32086 .34047 Mdot
.63337 .29802 Mdot
.53226 .31193 Mdot
.67272 .41362 Mdot
.55575 .6242 Mdot
.77427 .53724 Mdot
.5369 .3613 Mdot
.63355 .65508 Mdot
.7142 .67195 Mdot
.33705 .53295 Mdot
.56275 .64422 Mdot
.6017 .30958 Mdot
.50816 .86083 Mdot
.24031 .62853 Mdot
.41197 .57991 Mdot
.51706 .33129 Mdot
.3322 .36663 Mdot
.65936 .47131 Mdot
.4666 .26516 Mdot
.33479 .46049 Mdot
.54922 .37141 Mdot
.36434 .55249 Mdot
.59064 .6624 Mdot
.68108 .49174 Mdot
.74316 .59445 Mdot
.51493 .36935 Mdot
.52278 .32787 Mdot
.41493 .59875 Mdot
.36163 .37002 Mdot
.26661 .66938 Mdot
.53191 .33559 Mdot
.53574 .25035 Mdot
.61535 .32149 Mdot
.33056 .36799 Mdot
.37202 .52651 Mdot
.2789 .56332 Mdot
.37412 .49968 Mdot
.3115 .75857 Mdot
.56402 .34161 Mdot
.5425 .65671 Mdot
.42571 .54258 Mdot
.38087 .24367 Mdot
.53519 .34927 Mdot
.59283 .53394 Mdot
.44201 .36189 Mdot
.68404 .49711 Mdot
.50527 .2412 Mdot
.4052 .54097 Mdot
.69944 .46975 Mdot
.36959 .3734 Mdot
.41568 .56466 Mdot
.38812 .58835 Mdot
.52591 .64926 Mdot
.68608 .47954 Mdot
.73256 .67792 Mdot
.64882 .5141 Mdot
.64219 .4672 Mdot
.54041 .6223 Mdot
.38717 .55178 Mdot
.5287 .36206 Mdot
.5552 .34475 Mdot
.33617 .55245 Mdot
.51509 .17525 Mdot
.56866 .67005 Mdot
.31835 .31606 Mdot
.82943 .57925 Mdot
.34414 .47021 Mdot
.49512 .24315 Mdot
.67049 .71737 Mdot
.67966 .45173 Mdot
.38947 .51942 Mdot
.58852 .68204 Mdot
.58339 .30779 Mdot
.51797 .34061 Mdot
.40491 .50167 Mdot
.67467 .4901 Mdot
.37855 .37109 Mdot
.50375 .38552 Mdot
.38291 .26425 Mdot
.41545 .52248 Mdot
.58734 .2445 Mdot
.50553 .35724 Mdot
.41536 .8474 Mdot
.58334 .29107 Mdot
.55823 .64402 Mdot
.37546 .58197 Mdot
.53219 .64416 Mdot
.34514 .36542 Mdot
.53019 .42337 Mdot
.67589 .48808 Mdot
.33178 .47622 Mdot
.79443 .32623 Mdot
.56015 .3233 Mdot
.54494 .67791 Mdot
.42482 .59633 Mdot
.31073 .51442 Mdot
.40291 .54579 Mdot
.34563 .60755 Mdot
.33149 .3143 Mdot
.64609 .48725 Mdot
.67146 .46268 Mdot
.38246 .56455 Mdot
.37097 .38506 Mdot
.52086 .38148 Mdot
.54273 .34715 Mdot
.17413 .65386 Mdot
.56948 .2764 Mdot
.30342 .43287 Mdot
.41257 .53657 Mdot
.57819 .32776 Mdot
.78084 .60517 Mdot
.67239 .46742 Mdot
.42841 .51395 Mdot
.56424 .34966 Mdot
.72179 .30367 Mdot
.29306 .35642 Mdot
.37156 .53471 Mdot
.37216 .6085 Mdot
.6645 .46208 Mdot
.22807 .48922 Mdot
.55114 .30277 Mdot
.40664 .4952 Mdot
.70194 .50161 Mdot
.35822 .24535 Mdot
.80304 .43198 Mdot
.54287 .6387 Mdot
.505 .407 Mdot
.66746 .50301 Mdot
.33201 .51248 Mdot
.36638 .35581 Mdot
.49985 .37296 Mdot
.53889 .32089 Mdot
.36868 .5644 Mdot
.40136 .60771 Mdot
.29596 .51085 Mdot
.54534 .67563 Mdot
.64552 .5058 Mdot
.42856 .55861 Mdot
.62905 .56567 Mdot
.44031 .54941 Mdot
.64109 .48347 Mdot
.81562 .71084 Mdot
.33847 .51637 Mdot
.40096 .5452 Mdot
.26169 .66552 Mdot
.53431 .64745 Mdot
.52924 .64499 Mdot
.64868 .22999 Mdot
.41206 .53594 Mdot
.52581 .24185 Mdot
.54238 .63691 Mdot
.56458 .6706 Mdot
.62246 .38571 Mdot
.39817 .58137 Mdot
.20983 .50858 Mdot
.69097 .46522 Mdot
.65441 .45939 Mdot
.57419 .67519 Mdot
.34931 .49197 Mdot
.68314 .45404 Mdot
.46381 .6932 Mdot
.54661 .36086 Mdot
.46928 .18523 Mdot
.55054 .67073 Mdot
.5238 .43838 Mdot
.66149 .47237 Mdot
.57698 .83252 Mdot
.54184 .26819 Mdot
.42629 .57562 Mdot
.40893 .52842 Mdot
.37061 .36856 Mdot
.33773 .52901 Mdot
.57847 .31994 Mdot
.66202 .49819 Mdot
.30182 .71654 Mdot
.54714 .6393 Mdot
.4077 .55561 Mdot
.61823 .59835 Mdot
.73242 .6206 Mdot
.72544 .36151 Mdot
.57311 .66202 Mdot
.5652 .64055 Mdot
.5461 .30448 Mdot
.51301 .34114 Mdot
.38109 .5453 Mdot
.69282 .48104 Mdot
.57998 .69084 Mdot
.64333 .48068 Mdot
.55099 .31165 Mdot
.52476 .36313 Mdot
.57057 .32116 Mdot
.4157 .49481 Mdot
.51791 .36605 Mdot
.36649 .26827 Mdot
.64305 .57877 Mdot
.60336 .64337 Mdot
.81771 .39632 Mdot
.7442 .59204 Mdot
.45703 .46716 Mdot
.36097 .33928 Mdot
.56278 .34779 Mdot
.68193 .51375 Mdot
.36861 .55009 Mdot
.39264 .5279 Mdot
.49916 .40189 Mdot
.69854 .49163 Mdot
.34032 .36642 Mdot
.70157 .48484 Mdot
.3595 .35045 Mdot
.54773 .25816 Mdot
.40459 .60019 Mdot
.38366 .50926 Mdot
.66125 .50137 Mdot
.5207 .36885 Mdot
.53867 .33867 Mdot
.32536 .36238 Mdot
.4461 .43646 Mdot
.55247 .32022 Mdot
.55089 .67002 Mdot
.46154 .7297 Mdot
.5243 .31142 Mdot
.4121 .54799 Mdot
.25458 .3704 Mdot
.45328 .66346 Mdot
.38939 .4973 Mdot
.6187 .42127 Mdot
.19543 .39225 Mdot
.43114 .54589 Mdot
.20417 .36201 Mdot
.67623 .41405 Mdot
.53381 .65141 Mdot
.52033 .32786 Mdot
.58065 .30762 Mdot
.41065 .62537 Mdot
.39068 .39053 Mdot
.34251 .56245 Mdot
.53628 .63987 Mdot
.52306 .66625 Mdot
.742 .3151 Mdot
.29377 .73731 Mdot
.33426 .34534 Mdot
.343 .34995 Mdot
.53963 .35841 Mdot
.19148 .5963 Mdot
.41579 .48056 Mdot
.33715 .36244 Mdot
.25173 .57333 Mdot
.36084 .54741 Mdot
.2756 .42773 Mdot
.52318 .26599 Mdot
.57965 .67017 Mdot
.28443 .57301 Mdot
.53555 .3565 Mdot
.54061 .66908 Mdot
.66026 .56115 Mdot
.35049 .56137 Mdot
.54279 .64232 Mdot
.64479 .47507 Mdot
.66926 .28851 Mdot
.55978 .62739 Mdot
.25883 .36158 Mdot
.69001 .48525 Mdot
.62115 .343 Mdot
.25684 .53261 Mdot
.64168 .15564 Mdot
.6683 .50043 Mdot
.54105 .37735 Mdot
.55478 .34428 Mdot
.54347 .34799 Mdot
.53624 .66388 Mdot
.51966 .38642 Mdot
.54928 .67986 Mdot
.21648 .58311 Mdot
.44567 .43719 Mdot
.33563 .35848 Mdot
.62971 .43087 Mdot
.57305 .64698 Mdot
.56458 .19722 Mdot
.7457 .25742 Mdot
.39322 .51772 Mdot
.65877 .5179 Mdot
.33476 .35004 Mdot
.36315 .81925 Mdot
.36672 .37621 Mdot
.50589 .41176 Mdot
.42883 .18927 Mdot
.40248 .55755 Mdot
.47472 .78212 Mdot
.36062 .34157 Mdot
.58297 .65889 Mdot
.38395 .5635 Mdot
.73678 .45439 Mdot
.36599 .36834 Mdot
.37779 .36886 Mdot
.37819 .54876 Mdot
.58277 .6386 Mdot
.52689 .35858 Mdot
.69889 .5022 Mdot
.34372 .39902 Mdot
.51391 .59857 Mdot
.34352 .52126 Mdot
.3468 .54353 Mdot
.59283 .50214 Mdot
.32697 .46086 Mdot
.66329 .49707 Mdot
.22995 .56342 Mdot
.51394 .34021 Mdot
.59957 .35488 Mdot
.65863 .23943 Mdot
.62697 .42527 Mdot
.56428 .33619 Mdot
.56668 .33855 Mdot
.37366 .53911 Mdot
.32027 .46416 Mdot
.37761 .21787 Mdot
.63609 .44528 Mdot
.5319 .30374 Mdot
.54132 .34582 Mdot
.5403 .68836 Mdot
.74493 .3133 Mdot
.35866 .58577 Mdot
.64268 .46191 Mdot
.54876 .31593 Mdot
.52889 .7965 Mdot
.35918 .36639 Mdot
.52664 .19292 Mdot
.41049 .598 Mdot
.42815 .56431 Mdot
.66295 .48611 Mdot
.6434 .47221 Mdot
.73514 .49263 Mdot
.71957 .27973 Mdot
.19287 .46723 Mdot
.77435 .57123 Mdot
.52866 .79112 Mdot
.56693 .70792 Mdot
.5957 .66756 Mdot
.71168 .42547 Mdot
.638 .50344 Mdot
.42821 .54268 Mdot
.58083 .68961 Mdot
.70363 .34138 Mdot
.51149 .66237 Mdot
.28764 .43401 Mdot
.43548 .23907 Mdot
.3699 .58112 Mdot
.58087 .68074 Mdot
.53679 .65525 Mdot
.58939 .68948 Mdot
.67653 .41459 Mdot
.39064 .54608 Mdot
.41345 .58649 Mdot
.43645 .55055 Mdot
.48964 .59887 Mdot
.4086 .51865 Mdot
.63379 .44169 Mdot
.5725 .49565 Mdot
.3658 .77311 Mdot
.38353 .49447 Mdot
.6697 .45291 Mdot
.34334 .54207 Mdot
.37226 .38448 Mdot
.36656 .55366 Mdot
.2916 .42987 Mdot
.67307 .47317 Mdot
.57255 .60228 Mdot
.77309 .5649 Mdot
.40655 .59633 Mdot
.38085 .37115 Mdot
.46557 .48818 Mdot
.69042 .71389 Mdot
.3682 .42486 Mdot
.55185 .67084 Mdot
.55357 .35433 Mdot
.69038 .5049 Mdot
.52908 .36592 Mdot
.39333 .49024 Mdot
.61123 .4234 Mdot
.67223 .65473 Mdot
.51328 .43161 Mdot
.42412 .51865 Mdot
.35273 .47154 Mdot
.55766 .6715 Mdot
.53265 .38056 Mdot
.59498 .7149 Mdot
.42172 .53727 Mdot
.34892 .36396 Mdot
.36617 .36427 Mdot
.74006 .51469 Mdot
.56777 .79879 Mdot
.77044 .52735 Mdot
.66179 .48877 Mdot
.53184 .33303 Mdot
.33767 .33801 Mdot
.51654 .57899 Mdot
.62889 .49587 Mdot
.6944 .48816 Mdot
.68609 .4842 Mdot
.35265 .52966 Mdot
.57267 .33244 Mdot
.35532 .76162 Mdot
.57789 .32273 Mdot
.39715 .59232 Mdot
.52924 .32674 Mdot
.56985 .32981 Mdot
.37059 .36236 Mdot
.66732 .51179 Mdot
.54611 .31039 Mdot
.38057 .5138 Mdot
.55878 .63171 Mdot
.4704 .43443 Mdot
.28696 .38004 Mdot
.34659 .78412 Mdot
.37131 .79701 Mdot
.58199 .63243 Mdot
.55428 .82523 Mdot
.64649 .45428 Mdot
.41834 .65191 Mdot
.67789 .39461 Mdot
.38879 .5035 Mdot
.5874 .19058 Mdot
.53767 .30558 Mdot
.5346 .38157 Mdot
.36952 .5266 Mdot
.54115 .39155 Mdot
.40563 .55259 Mdot
.53182 .31996 Mdot
.3097 .3647 Mdot
.42284 .61565 Mdot
.51895 .37553 Mdot
.43074 .50239 Mdot
.39348 .58242 Mdot
.58057 .6714 Mdot
.50892 .34431 Mdot
.4321 .51644 Mdot
.26883 .75283 Mdot
.63936 .48157 Mdot
.63616 .41701 Mdot
.24988 .35165 Mdot
.66683 .50395 Mdot
.5493 .64211 Mdot
.33109 .54089 Mdot
.36613 .38251 Mdot
.57987 .6481 Mdot
.29873 .32829 Mdot
.3576 .34209 Mdot
.58235 .19565 Mdot
.55659 .67524 Mdot
.52162 .31524 Mdot
.37251 .35989 Mdot
.45948 .53441 Mdot
.50123 .38043 Mdot
.47228 .45917 Mdot
.56189 .34499 Mdot
.39368 .53708 Mdot
.73566 .429 Mdot
.63782 .49204 Mdot
.41204 .57761 Mdot
.50611 .38762 Mdot
.70518 .42021 Mdot
.35336 .53546 Mdot
.36783 .54438 Mdot
.78702 .38062 Mdot
.52834 .21176 Mdot
.35 .38397 Mdot
.53102 .66851 Mdot
.38257 .51648 Mdot
.37342 .35552 Mdot
.42076 .3164 Mdot
.34496 .53328 Mdot
.5735 .70414 Mdot
.46007 .50858 Mdot
.50481 .3715 Mdot
.6565 .50713 Mdot
.54611 .43251 Mdot
.37716 .35929 Mdot
.30431 .21107 Mdot
.57105 .31771 Mdot
.43928 .51883 Mdot
.43063 .52175 Mdot
.73586 .38348 Mdot
.53927 .66369 Mdot
.19632 .46645 Mdot
.40687 .5302 Mdot
.47951 .5375 Mdot
.41309 .56675 Mdot
.56763 .38065 Mdot
.56699 .66914 Mdot
.39941 .54091 Mdot
.59421 .5794 Mdot
.45461 .53386 Mdot
.3795 .365 Mdot
.24651 .64172 Mdot
.34682 .52276 Mdot
.89027 .538 Mdot
.5181 .2464 Mdot
.51817 .37368 Mdot
.74199 .43454 Mdot
.14712 .51756 Mdot
.77571 .51114 Mdot
.55013 .68172 Mdot
.66816 .7081 Mdot
.52762 .36215 Mdot
.78812 .53686 Mdot
.5418 .83687 Mdot
.391 .58169 Mdot
.35365 .56321 Mdot
.50596 .41184 Mdot
.58028 .32049 Mdot
.50561 .3395 Mdot
.38029 .49231 Mdot
.43253 .49169 Mdot
.51672 .3593 Mdot
.39065 .51209 Mdot
.4718 .55834 Mdot
.6937 .50772 Mdot
.57756 .6317 Mdot
.65205 .47732 Mdot
.67985 .50875 Mdot
.38294 .67612 Mdot
.71979 .28557 Mdot
.64037 .48651 Mdot
.64721 .4545 Mdot
.28 .42243 Mdot
.28857 .52257 Mdot
.36697 .33817 Mdot
.49309 .83333 Mdot
.5462 .34572 Mdot
.39122 .54892 Mdot
.58479 .63167 Mdot
.3796 .65904 Mdot
.48791 .27386 Mdot
.39379 .20451 Mdot
.42476 .53869 Mdot
.53706 .3517 Mdot
.68296 .4142 Mdot
.47607 .58705 Mdot
.60293 .36949 Mdot
.42975 .56717 Mdot
.49969 .3924 Mdot
.45137 .75456 Mdot
.62004 .61091 Mdot
.59797 .28938 Mdot
.56789 .71489 Mdot
.42421 .55579 Mdot
.54724 .66874 Mdot
.65341 .48087 Mdot
.37345 .37702 Mdot
.34992 .383 Mdot
.37728 .55353 Mdot
.39371 .45808 Mdot
.52723 .27126 Mdot
.39602 .58541 Mdot
.37251 .56432 Mdot
.67669 .414 Mdot
.37493 .56576 Mdot
.43206 .52579 Mdot
.43557 .53638 Mdot
.4519 .56044 Mdot
.64467 .46482 Mdot
.61523 .59645 Mdot
.39506 .48717 Mdot
.47507 .57782 Mdot
.70883 .48298 Mdot
.68969 .6967 Mdot
.67222 .51346 Mdot
.6195 .79207 Mdot
.66447 .46645 Mdot
.34041 .3735 Mdot
.73012 .41293 Mdot
.3721 .45909 Mdot
.60068 .66904 Mdot
.63278 .50373 Mdot
.35127 .35329 Mdot
.65688 .4928 Mdot
.52266 .33331 Mdot
.83185 .51996 Mdot
.512 .65158 Mdot
.20502 .43598 Mdot
.74453 .50642 Mdot
.60422 .27532 Mdot
.55852 .30897 Mdot
.57082 .67213 Mdot
.51215 .75166 Mdot
.43794 .53631 Mdot
.37105 .35425 Mdot
.37736 .54464 Mdot
.63942 .46991 Mdot
.53898 .35421 Mdot
.23804 .63661 Mdot
.36026 .38642 Mdot
.79502 .37244 Mdot
.54629 .33768 Mdot
.43908 .56403 Mdot
.6437 .4612 Mdot
.81484 .375 Mdot
.64796 .4821 Mdot
.41179 .43808 Mdot
.59514 .70103 Mdot
.27948 .6284 Mdot
.56652 .64602 Mdot
.5574 .29185 Mdot
.84706 .5732 Mdot
.44645 .83084 Mdot
.57426 .63495 Mdot
.57743 .26595 Mdot
.35223 .55728 Mdot
.34579 .543 Mdot
.61193 .61259 Mdot
.54684 .68583 Mdot
.39715 .51686 Mdot
.64986 .41361 Mdot
.66324 .58949 Mdot
.51842 .23048 Mdot
.55201 .35944 Mdot
.40665 .54646 Mdot
.70812 .48884 Mdot
.7011 .48403 Mdot
.57647 .32385 Mdot
.66987 .51494 Mdot
.41346 .58548 Mdot
.57072 .64688 Mdot
.49363 .37913 Mdot
.35251 .37775 Mdot
.25855 .72243 Mdot
.34166 .33434 Mdot
.56389 .33438 Mdot
.44481 .59362 Mdot
.52436 .3635 Mdot
.13704 .40985 Mdot
.42113 .57893 Mdot
.53925 .64117 Mdot
.36087 .53466 Mdot
.42237 .55966 Mdot
.34927 .55612 Mdot
.51708 .35103 Mdot
.19772 .41225 Mdot
.38668 .51218 Mdot
.67744 .48779 Mdot
.40339 .80007 Mdot
.34394 .5461 Mdot
.32475 .39369 Mdot
.27911 .4767 Mdot
.60361 .25985 Mdot
.60231 .64874 Mdot
.52761 .3801 Mdot
.55359 .63583 Mdot
.52158 .67984 Mdot
.54891 .64241 Mdot
.41365 .79118 Mdot
.49872 .75416 Mdot
.22308 .35773 Mdot
.29703 .67729 Mdot
.35049 .63938 Mdot
.53735 .67717 Mdot
.41116 .33641 Mdot
.59438 .67793 Mdot
.54156 .66446 Mdot
.56408 .90947 Mdot
.59878 .66366 Mdot
.41031 .54122 Mdot
.36726 .58641 Mdot
.70995 .62341 Mdot
.25703 .42653 Mdot
.3776 .56315 Mdot
.37454 .51958 Mdot
.37325 .37248 Mdot
.42624 .46803 Mdot
.61181 .42335 Mdot
.59359 .20648 Mdot
.74968 .61833 Mdot
.37664 .54623 Mdot
.38019 .51587 Mdot
.44002 .50147 Mdot
.86351 .44418 Mdot
.41305 .674 Mdot
.5394 .68187 Mdot
.33979 .49338 Mdot
.33572 .78647 Mdot
.41993 .58777 Mdot
.35206 .52141 Mdot
.3643 .57489 Mdot
.52834 .36181 Mdot
.57158 .7068 Mdot
.34482 .48857 Mdot
.60113 .23611 Mdot
.40014 .59696 Mdot
.6301 .42685 Mdot
.16811 .4922 Mdot
.40489 .5398 Mdot
.60183 .6803 Mdot
.35887 .55705 Mdot
.5582 .67824 Mdot
.58705 .66703 Mdot
.45467 .56947 Mdot
.484 .8031 Mdot
.58722 .70356 Mdot
.39498 .59251 Mdot
.52308 .35488 Mdot
.47703 .84292 Mdot
.39487 .53517 Mdot
.34815 .38761 Mdot
.40903 .53003 Mdot
.37949 .38271 Mdot
.37803 .57286 Mdot
.57635 .32703 Mdot
.49114 .6745 Mdot
.54006 .36106 Mdot
.18839 .50975 Mdot
.57187 .34155 Mdot
.78606 .37601 Mdot
.55908 .69675 Mdot
.71343 .42316 Mdot
.35197 .205 Mdot
.62769 .41865 Mdot
.58668 .54443 Mdot
.55307 .52468 Mdot
.6931 .48212 Mdot
.53449 .63695 Mdot
.2331 .52576 Mdot
.71838 .35747 Mdot
.72153 .38795 Mdot
.5659 .32201 Mdot
.36664 .182 Mdot
.43995 .17779 Mdot
.36891 .51503 Mdot
.45299 .7881 Mdot
.35553 .71479 Mdot
.34604 .52963 Mdot
.32961 .53311 Mdot
.50872 .40011 Mdot
.42791 .51787 Mdot
.61526 .5675 Mdot
.55804 .3285 Mdot
.35333 .351 Mdot
.54296 .66088 Mdot
.36748 .39504 Mdot
.72112 .3685 Mdot
.55468 .53035 Mdot
.53924 .31603 Mdot
.45444 .54033 Mdot
.3628 .52789 Mdot
.57609 .67767 Mdot
.61904 .68786 Mdot
.59021 .6493 Mdot
.33217 .35251 Mdot
.55557 .33104 Mdot
.41605 .66669 Mdot
.37931 .52266 Mdot
.57289 .65393 Mdot
.69163 .5447 Mdot
.38419 .51845 Mdot
.65563 .49883 Mdot
.37934 .59023 Mdot
.56731 .6315 Mdot
.37529 .5662 Mdot
.57045 .64504 Mdot
.54706 .3617 Mdot
.42204 .58875 Mdot
.37054 .5296 Mdot
.81281 .38159 Mdot
.34119 .36864 Mdot
.55182 .69032 Mdot
.48588 .40444 Mdot
.44165 .54737 Mdot
.65273 .33137 Mdot
.42436 .55101 Mdot
.55138 .71795 Mdot
.44048 .51768 Mdot
.69049 .41631 Mdot
.3719 .59732 Mdot
.39539 .53609 Mdot
.56017 .55565 Mdot
.36957 .73983 Mdot
.61724 .70009 Mdot
.65071 .45677 Mdot
.59411 .69026 Mdot
.46137 .24891 Mdot
.53098 .30699 Mdot
.51724 .38764 Mdot
.22809 .44343 Mdot
.44088 .58949 Mdot
.40096 .55634 Mdot
.67964 .52192 Mdot
.3497 .34685 Mdot
.57433 .66051 Mdot
.3577 .35052 Mdot
.63243 .23325 Mdot
.34022 .34392 Mdot
.58017 .31187 Mdot
.55181 .25437 Mdot
.46297 .67678 Mdot
.37317 .37142 Mdot
.58579 .64044 Mdot
.42378 .24352 Mdot
.39876 .50062 Mdot
.3862 .33986 Mdot
.35001 .36513 Mdot
.36331 .17686 Mdot
.42806 .52214 Mdot
.59087 .54198 Mdot
.64414 .49579 Mdot
.3681 .35739 Mdot
.68612 .47431 Mdot
.37597 .55889 Mdot
.63517 .30415 Mdot
.55086 .68514 Mdot
.70374 .46231 Mdot
.34855 .50505 Mdot
.33573 .35114 Mdot
.54693 .31745 Mdot
.71276 .44812 Mdot
.67524 .4536 Mdot
.66448 .73404 Mdot
.23908 .62008 Mdot
.55552 .33252 Mdot
.44129 .21045 Mdot
.68535 .46327 Mdot
.3494 .52251 Mdot
.4722 .51669 Mdot
.42599 .5767 Mdot
.73797 .44331 Mdot
.52816 .38101 Mdot
.67124 .61292 Mdot
.36056 .52925 Mdot
.43016 .53761 Mdot
.60784 .63774 Mdot
.55006 .35078 Mdot
.55544 .65677 Mdot
.59645 .68395 Mdot
.54846 .3595 Mdot
.55886 .64553 Mdot
.36372 .34388 Mdot
.67766 .58431 Mdot
.681 .46001 Mdot
.67627 .48441 Mdot
.54151 .34677 Mdot
.51646 .36905 Mdot
.52407 .36776 Mdot
.38029 .59088 Mdot
.57114 .66523 Mdot
.3731 .57816 Mdot
.35057 .55799 Mdot
.62202 .70402 Mdot
.59474 .64202 Mdot
.35793 .56296 Mdot
.60405 .31208 Mdot
.37868 .3339 Mdot
.52161 .35215 Mdot
.64154 .4918 Mdot
.79185 .58051 Mdot
.71066 .4617 Mdot
.40841 .54884 Mdot
.71715 .30175 Mdot
.58045 .63906 Mdot
.36914 .37214 Mdot
.38355 .35237 Mdot
.36314 .38191 Mdot
.67389 .52774 Mdot
.57243 .69541 Mdot
.592 .20573 Mdot
.4052 .54932 Mdot
.59342 .50171 Mdot
.23245 .54156 Mdot
.63768 .24736 Mdot
.64033 .48984 Mdot
.38097 .51769 Mdot
.53735 .43437 Mdot
.51207 .73602 Mdot
.42732 .56709 Mdot
.42003 .5017 Mdot
.64387 .39428 Mdot
.46899 .53017 Mdot
.59196 .70279 Mdot
.71566 .27069 Mdot
.35438 .57359 Mdot
.62725 .65083 Mdot
.18445 .64294 Mdot
.41365 .55386 Mdot
.42101 .53038 Mdot
.38527 .53163 Mdot
.36082 .54467 Mdot
.6021 .6824 Mdot
.23971 .47766 Mdot
.63734 .46859 Mdot
.58109 .47309 Mdot
.68077 .45856 Mdot
.49934 .38946 Mdot
.61718 .58663 Mdot
.54068 .62903 Mdot
.37066 .36963 Mdot
.60403 .75398 Mdot
.65985 .22751 Mdot
.54577 .30395 Mdot
.46018 .70385 Mdot
.34735 .37087 Mdot
.35396 .51347 Mdot
.37528 .3934 Mdot
.57197 .338 Mdot
.68353 .48995 Mdot
.40965 .61261 Mdot
.59522 .65988 Mdot
.55571 .62786 Mdot
.3948 .51757 Mdot
.37458 .81549 Mdot
.65557 .50185 Mdot
.65366 .44321 Mdot
.35168 .5391 Mdot
.41698 .49908 Mdot
.5518 .65541 Mdot
.5318 .34215 Mdot
.34147 .27619 Mdot
.34251 .35661 Mdot
.44399 .56246 Mdot
.36212 .54868 Mdot
.71412 .27499 Mdot
.67345 .50732 Mdot
.56463 .30128 Mdot
.35394 .52789 Mdot
.76584 .46986 Mdot
.35398 .52933 Mdot
.47791 .5923 Mdot
.52552 .35466 Mdot
.39945 .48043 Mdot
.38415 .51017 Mdot
.3178 .53666 Mdot
.68729 .4678 Mdot
.53995 .64428 Mdot
.61015 .65478 Mdot
.50907 .41895 Mdot
.65498 .49651 Mdot
.35764 .55974 Mdot
.6687 .50733 Mdot
.34289 .53623 Mdot
.39964 .51457 Mdot
.64109 .48406 Mdot
.55548 .65612 Mdot
.68164 .67822 Mdot
.61507 .5925 Mdot
.35957 .54072 Mdot
.36544 .58896 Mdot
.2411 .44072 Mdot
.25853 .29596 Mdot
.42404 .54268 Mdot
.5619 .6295 Mdot
.37508 .52349 Mdot
.68028 .47108 Mdot
.34675 .34235 Mdot
.56145 .63131 Mdot
.53791 .33485 Mdot
.55505 .30402 Mdot
.77356 .56134 Mdot
.56894 .33584 Mdot
.38199 .50203 Mdot
.50516 .63662 Mdot
.55993 .61689 Mdot
.21045 .67614 Mdot
.55087 .35506 Mdot
.37573 .34783 Mdot
.37028 .54825 Mdot
.75399 .35224 Mdot
.67293 .52433 Mdot
.89952 .51777 Mdot
.58523 .19911 Mdot
.33711 .33586 Mdot
.37788 .20443 Mdot
.49685 .38192 Mdot
.40746 .51106 Mdot
.37325 .37888 Mdot
.53566 .31068 Mdot
.37779 .50612 Mdot
.38199 .61364 Mdot
.19512 .44874 Mdot
.5204 .42174 Mdot
.66392 .50886 Mdot
.50832 .37047 Mdot
.37594 .39863 Mdot
.57993 .31405 Mdot
.55696 .62616 Mdot
.3958 .54011 Mdot
.33619 .48103 Mdot
.53375 .33804 Mdot
.57973 .31779 Mdot
.37471 .58492 Mdot
.53277 .64088 Mdot
.53383 .39265 Mdot
.38059 .55381 Mdot
.39437 .64841 Mdot
.56693 .71384 Mdot
.55428 .32655 Mdot
.43304 .53669 Mdot
.3037 .4953 Mdot
.54164 .33994 Mdot
.52121 .35033 Mdot
.39572 .51644 Mdot
.36662 .34564 Mdot
.41161 .59984 Mdot
.65881 .46848 Mdot
.1838 .43391 Mdot
.68116 .47382 Mdot
.44858 .26168 Mdot
.46035 .56991 Mdot
.62562 .31359 Mdot
.56368 .62422 Mdot
.38154 .39521 Mdot
.80105 .57499 Mdot
.39803 .49212 Mdot
.5483 .81907 Mdot
.54221 .4448 Mdot
.32541 .7874 Mdot
.7902 .64714 Mdot
.35325 .36442 Mdot
.65517 .48799 Mdot
.42031 .53035 Mdot
.66666 .52038 Mdot
.36394 .38833 Mdot
.22691 .57742 Mdot
.43326 .53314 Mdot
.56485 .66969 Mdot
.39169 .59377 Mdot
.55184 .67136 Mdot
.38818 .51869 Mdot
.47092 .54823 Mdot
.70625 .41279 Mdot
.2927 .36086 Mdot
.39229 .50269 Mdot
.83353 .51129 Mdot
.49841 .27905 Mdot
.34661 .36025 Mdot
.38321 .58517 Mdot
.54525 .29764 Mdot
.69955 .48411 Mdot
.50389 .54139 Mdot
.52634 .36132 Mdot
.65343 .51327 Mdot
.55038 .64859 Mdot
.54937 .3612 Mdot
.56639 .30874 Mdot
.34135 .49859 Mdot
.37843 .38165 Mdot
.68699 .49205 Mdot
.39938 .53642 Mdot
.42893 .52594 Mdot
.44593 .21686 Mdot
.47091 .28381 Mdot
.61321 .65163 Mdot
.79018 .32707 Mdot
.596 .63228 Mdot
.3382 .36176 Mdot
.52417 .35861 Mdot
.42268 .54522 Mdot
.40957 .57919 Mdot
.71878 .42295 Mdot
.54474 .6818 Mdot
.52358 .4254 Mdot
.41147 .68701 Mdot
.54841 .37933 Mdot
.26697 .46373 Mdot
.53932 .63828 Mdot
.26596 .46181 Mdot
.37568 .39813 Mdot
.55044 .80013 Mdot
.30377 .39921 Mdot
.64505 .4988 Mdot
.26478 .46852 Mdot
.58385 .65645 Mdot
.36555 .51884 Mdot
.51951 .31898 Mdot
.56917 .32851 Mdot
.54565 .65673 Mdot
.49953 .3986 Mdot
.36804 .36021 Mdot
.42024 .52578 Mdot
.56531 .21314 Mdot
.73357 .58332 Mdot
.52841 .3365 Mdot
.47147 .60334 Mdot
.68488 .48173 Mdot
.40915 .51354 Mdot
.34504 .38559 Mdot
.67389 .49808 Mdot
.50321 .24596 Mdot
.66713 .59838 Mdot
.37771 .55686 Mdot
.76165 .34566 Mdot
.66041 .50008 Mdot
.34176 .23367 Mdot
.38342 .55029 Mdot
.68572 .46368 Mdot
.44109 .49328 Mdot
.63422 .25815 Mdot
.50165 .43227 Mdot
.53526 .84172 Mdot
.53458 .42769 Mdot
.50319 .35138 Mdot
.66968 .2977 Mdot
.69933 .37096 Mdot
.67446 .51904 Mdot
.5795 .31627 Mdot
.32849 .45113 Mdot
.6872 .47471 Mdot
.35343 .56366 Mdot
.42019 .55232 Mdot
.38075 .67087 Mdot
.54643 .45568 Mdot
.58091 .30224 Mdot
.75729 .52446 Mdot
.4412 .54858 Mdot
.33903 .50878 Mdot
.40437 .57524 Mdot
.5256 .67044 Mdot
.68115 .49966 Mdot
.82143 .43338 Mdot
.65223 .49346 Mdot
.51633 .1964 Mdot
.54528 .34748 Mdot
.51966 .38224 Mdot
.40686 .54282 Mdot
.60626 .28985 Mdot
.26625 .52427 Mdot
.40981 .58759 Mdot
.61945 .33947 Mdot
.24412 .64937 Mdot
.34392 .50744 Mdot
.59759 .69975 Mdot
.43535 .61323 Mdot
.5184 .66043 Mdot
.6878 .46067 Mdot
.35861 .36971 Mdot
.38294 .40039 Mdot
.68523 .49276 Mdot
.40049 .55797 Mdot
.62635 .34709 Mdot
.42021 .56641 Mdot
.36046 .51946 Mdot
.51514 .18787 Mdot
.33514 .33872 Mdot
.52714 .37404 Mdot
.35414 .38545 Mdot
.54165 .66604 Mdot
.79683 .74331 Mdot
.3521 .3462 Mdot
.26865 .53578 Mdot
.20187 .52636 Mdot
.26243 .46857 Mdot
.55022 .6284 Mdot
.33867 .39063 Mdot
.65512 .50507 Mdot
.39488 .84519 Mdot
.24104 .31237 Mdot
.69408 .4433 Mdot
.38716 .56002 Mdot
.53444 .63281 Mdot
.58714 .63916 Mdot
.69916 .45969 Mdot
.58627 .66415 Mdot
.37513 .46899 Mdot
.3581 .52903 Mdot
.66802 .519 Mdot
.72293 .60777 Mdot
.67599 .45347 Mdot
.6689 .57306 Mdot
.38465 .588 Mdot
.54486 .63406 Mdot
.43865 .60922 Mdot
.51758 .62097 Mdot
.56498 .30053 Mdot
.34843 .51846 Mdot
.36967 .3622 Mdot
.59432 .46496 Mdot
.55243 .33303 Mdot
.71652 .30363 Mdot
.57315 .67805 Mdot
.69675 .53564 Mdot
.58235 .67043 Mdot
.52399 .64863 Mdot
.68127 .5083 Mdot
.56602 .6907 Mdot
.42144 .52939 Mdot
.59424 .29413 Mdot
.56316 .68262 Mdot
.66644 .47909 Mdot
.36033 .37538 Mdot
.5584 .6488 Mdot
.51145 .40527 Mdot
.36786 .53802 Mdot
.52196 .32991 Mdot
.70988 .40735 Mdot
.52867 .64502 Mdot
.33182 .38052 Mdot
.52896 .38317 Mdot
.3764 .38229 Mdot
.2349 .65992 Mdot
.63713 .50299 Mdot
.40141 .20545 Mdot
.30687 .49442 Mdot
.59631 .65523 Mdot
.70755 .40948 Mdot
.42 .54455 Mdot
.36718 .53996 Mdot
.35974 .40093 Mdot
.58767 .63962 Mdot
.44375 .83577 Mdot
.59568 .73531 Mdot
.67765 .59384 Mdot
.63452 .50237 Mdot
.80251 .40988 Mdot
.63282 .57194 Mdot
.18697 .56997 Mdot
.36643 .48505 Mdot
.49701 .37618 Mdot
.40777 .56013 Mdot
.79621 .58804 Mdot
.33425 .35142 Mdot
.34676 .29416 Mdot
.45986 .55154 Mdot
.53512 .37381 Mdot
.37972 .53725 Mdot
.51095 .51124 Mdot
.45937 .60206 Mdot
.36261 .34082 Mdot
.62308 .43485 Mdot
.60019 .67266 Mdot
.35033 .376 Mdot
.56242 .31436 Mdot
.26783 .50423 Mdot
.39053 .50489 Mdot
.38653 .48939 Mdot
.55285 .37483 Mdot
.56968 .67086 Mdot
.50328 .35811 Mdot
.68184 .46038 Mdot
.36238 .36178 Mdot
.36699 .54795 Mdot
.44713 .52511 Mdot
.6542 .33344 Mdot
.68787 .49427 Mdot
.53859 .38595 Mdot
.64896 .4829 Mdot
.50312 .34698 Mdot
.38229 .60078 Mdot
.51944 .38326 Mdot
.41173 .50872 Mdot
.80238 .51027 Mdot
.50789 .18886 Mdot
.39142 .75364 Mdot
.53604 .37612 Mdot
.28842 .4541 Mdot
.67255 .47162 Mdot
.66086 .46916 Mdot
.28153 .62029 Mdot
.43708 .46876 Mdot
.48155 .23117 Mdot
.67537 .7316 Mdot
.67923 .45894 Mdot
.67944 .47753 Mdot
.52587 .32239 Mdot
.56162 .68847 Mdot
.52641 .63706 Mdot
.49802 .3906 Mdot
.25107 .37035 Mdot
.57428 .66037 Mdot
.53136 .82069 Mdot
.48276 .24053 Mdot
.33523 .50979 Mdot
.73447 .48097 Mdot
.36469 .36682 Mdot
.25986 .36843 Mdot
.51877 .52555 Mdot
.42798 .53712 Mdot
.72553 .28424 Mdot
.53325 .34579 Mdot
.22595 .47083 Mdot
.62274 .78952 Mdot
.4337 .53114 Mdot
.38912 .54894 Mdot
.40296 .56565 Mdot
.32857 .34811 Mdot
.50138 .66974 Mdot
.42763 .52756 Mdot
.24988 .3671 Mdot
.44261 .55009 Mdot
.36981 .42897 Mdot
.35084 .38385 Mdot
.32175 .59517 Mdot
.64663 .4096 Mdot
.60251 .22821 Mdot
.37004 .61676 Mdot
.67706 .46112 Mdot
.5788 .4303 Mdot
.69185 .46867 Mdot
.40416 .78428 Mdot
.30178 .40155 Mdot
.60721 .69148 Mdot
.42564 .5352 Mdot
.5636 .33273 Mdot
.58378 .63663 Mdot
.67703 .33009 Mdot
.62105 .8917 Mdot
.69432 .46462 Mdot
.14862 .40339 Mdot
.65325 .47449 Mdot
.56952 .31183 Mdot
.55034 .6549 Mdot
.48982 .75433 Mdot
.59436 .50769 Mdot
.56055 .64701 Mdot
.67553 .66338 Mdot
.55625 .6115 Mdot
.27683 .46391 Mdot
.57044 .61964 Mdot
.66741 .47612 Mdot
.71034 .50089 Mdot
.32497 .52776 Mdot
.41315 .53942 Mdot
.5505 .52872 Mdot
.28055 .51934 Mdot
.41685 .54139 Mdot
.55763 .32971 Mdot
.33294 .2334 Mdot
.50804 .41558 Mdot
.58792 .68168 Mdot
.66635 .45022 Mdot
.38709 .54614 Mdot
.35605 .53851 Mdot
.38056 .50745 Mdot
.80012 .33284 Mdot
.51552 .81906 Mdot
.38608 .51255 Mdot
.44076 .57327 Mdot
.54528 .36549 Mdot
.31806 .37299 Mdot
.78439 .61992 Mdot
.36398 .43726 Mdot
.43334 .56615 Mdot
.34578 .377 Mdot
.35608 .33259 Mdot
.37851 .50548 Mdot
.58969 .23845 Mdot
.58838 .27721 Mdot
.39898 .53611 Mdot
.40274 .4414 Mdot
.71276 .36282 Mdot
.57866 .31701 Mdot
.53618 .33819 Mdot
.60145 .67988 Mdot
.56642 .32839 Mdot
.57267 .34056 Mdot
.49051 .73839 Mdot
.56345 .43513 Mdot
.61054 .49791 Mdot
.33197 .35287 Mdot
.41348 .57725 Mdot
.58791 .62321 Mdot
.73218 .43342 Mdot
.69147 .48532 Mdot
.56991 .63761 Mdot
.70019 .47972 Mdot
.33234 .33476 Mdot
.20659 .45155 Mdot
.57043 .32629 Mdot
.67023 .45828 Mdot
.66658 .59705 Mdot
.34701 .3791 Mdot
.66157 .51297 Mdot
.63121 .32117 Mdot
.34683 .55327 Mdot
.52654 .78186 Mdot
.40234 .59012 Mdot
.37843 .82434 Mdot
.66161 .51226 Mdot
.69053 .41726 Mdot
.39947 .55042 Mdot
.54559 .339 Mdot
.4651 .52915 Mdot
.43018 .5679 Mdot
.53921 .32959 Mdot
.36866 .5155 Mdot
.35714 .39247 Mdot
.53186 .68958 Mdot
.57461 .43956 Mdot
.54062 .14386 Mdot
.37546 .38733 Mdot
.66932 .32736 Mdot
.42452 .54136 Mdot
.2386 .63336 Mdot
.56007 .64939 Mdot
.42659 .51086 Mdot
.29289 .59083 Mdot
.55255 .68042 Mdot
.55863 .63627 Mdot
.36749 .56474 Mdot
.64609 .49704 Mdot
.54947 .33178 Mdot
.35158 .38275 Mdot
.20925 .64349 Mdot
.3923 .57093 Mdot
.37217 .52673 Mdot
.34833 .37275 Mdot
.68085 .47577 Mdot
.35639 .54351 Mdot
.7603 .4223 Mdot
.28123 .75957 Mdot
.69316 .49246 Mdot
.38156 .59545 Mdot
.569 .76015 Mdot
.51041 .62358 Mdot
.19001 .35142 Mdot
.30801 .32672 Mdot
.5233 .37795 Mdot
.46557 .52041 Mdot
.86416 .62108 Mdot
.36007 .37078 Mdot
.59692 .216 Mdot
.35994 .51785 Mdot
.38238 .5251 Mdot
.58567 .64465 Mdot
.3658 .57239 Mdot
.54055 .67239 Mdot
.49329 .14599 Mdot
.74619 .29579 Mdot
.56498 .67525 Mdot
.59712 .66269 Mdot
.27728 .56195 Mdot
.78706 .61361 Mdot
.54413 .65309 Mdot
.406 .60657 Mdot
.44972 .81933 Mdot
.31826 .55331 Mdot
.36096 .40153 Mdot
.70763 .39699 Mdot
.54601 .60211 Mdot
.44519 .38412 Mdot
.67275 .71219 Mdot
.56412 .60088 Mdot
.55162 .27763 Mdot
.6559 .46866 Mdot
.43782 .54475 Mdot
.56951 .33233 Mdot
.5182 .38689 Mdot
.46373 .59434 Mdot
.42037 .57237 Mdot
.555 .67646 Mdot
.33752 .34029 Mdot
.69435 .50131 Mdot
.37371 .52016 Mdot
.51774 .4137 Mdot
.34821 .35001 Mdot
.58179 .68282 Mdot
.27522 .60568 Mdot
.37096 .34426 Mdot
.44306 .61455 Mdot
.40388 .52721 Mdot
.36939 .58057 Mdot
.33399 .47432 Mdot
.64089 .47432 Mdot
.7417 .41764 Mdot
.39798 .60064 Mdot
.63649 .23363 Mdot
.44544 .43321 Mdot
.41236 .48366 Mdot
.5795 .66345 Mdot
.66858 .52601 Mdot
.55654 .2957 Mdot
.24608 .53894 Mdot
.38384 .56385 Mdot
.50879 .81749 Mdot
.40907 .6777 Mdot
.55209 .29826 Mdot
.53976 .6795 Mdot
.36812 .37478 Mdot
.41288 .58498 Mdot
.42855 .80376 Mdot
.41635 .55202 Mdot
.31987 .47981 Mdot
.52471 .34991 Mdot
.65327 .46963 Mdot
.31428 .7817 Mdot
.5181 .38649 Mdot
.55496 .63576 Mdot
.549 .84607 Mdot
.54803 .62231 Mdot
.59176 .68566 Mdot
.47171 .80616 Mdot
.64648 .46814 Mdot
.87354 .60143 Mdot
.22864 .31886 Mdot
.44755 .51685 Mdot
.67342 .46882 Mdot
.55123 .66422 Mdot
.41035 .51411 Mdot
.57923 .62667 Mdot
.56291 .69486 Mdot
.33738 .53972 Mdot
.39412 .52412 Mdot
.61123 .58342 Mdot
.57718 .80756 Mdot
.36642 .38028 Mdot
.53405 .64767 Mdot
.33488 .63711 Mdot
.42214 .5168 Mdot
.4048 .54868 Mdot
.70048 .34403 Mdot
.36768 .34525 Mdot
.56308 .56475 Mdot
.35544 .52466 Mdot
.763 .32435 Mdot
.43193 .61574 Mdot
.60102 .68674 Mdot
.69167 .49452 Mdot
.58842 .2297 Mdot
.73777 .446 Mdot
.54159 .67808 Mdot
.33501 .37468 Mdot
.61136 .65706 Mdot
.27018 .53504 Mdot
.66127 .45675 Mdot
.5674 .63152 Mdot
.54468 .43275 Mdot
.66995 .49312 Mdot
.65891 .51136 Mdot
.40685 .80182 Mdot
.54395 .37901 Mdot
.32928 .37036 Mdot
.68624 .48688 Mdot
.41948 .65126 Mdot
.66008 .48118 Mdot
.34557 .65247 Mdot
.41714 .59254 Mdot
.22227 .40947 Mdot
.61731 .54941 Mdot
.36492 .46254 Mdot
.63656 .48546 Mdot
.36293 .38765 Mdot
.36317 .55655 Mdot
.58756 .66152 Mdot
.35626 .34808 Mdot
.72378 .465 Mdot
.51792 .35943 Mdot
.58296 .67328 Mdot
.63392 .47298 Mdot
.53571 .64464 Mdot
.22976 .51581 Mdot
.1808 .45012 Mdot
.7636 .40673 Mdot
.59104 .50712 Mdot
.37706 .50838 Mdot
.71546 .68894 Mdot
.33517 .54195 Mdot
.4242 .569 Mdot
.55383 .32738 Mdot
.22655 .44452 Mdot
.55486 .65664 Mdot
.32021 .78874 Mdot
.66573 .46085 Mdot
.72541 .27672 Mdot
.59175 .72227 Mdot
.42801 .51052 Mdot
.55918 .68149 Mdot
.55703 .61983 Mdot
.36182 .73641 Mdot
.58313 .31369 Mdot
.3657 .60261 Mdot
.34024 .56975 Mdot
.37962 .48405 Mdot
.6587 .51053 Mdot
.70413 .29384 Mdot
.49994 .36985 Mdot
.17417 .41978 Mdot
.52516 .34568 Mdot
.60477 .39291 Mdot
.57247 .69023 Mdot
.35704 .34466 Mdot
.4041 .54611 Mdot
.59482 .7248 Mdot
.53753 .674 Mdot
.35774 .3249 Mdot
.37065 .35872 Mdot
.66629 .28102 Mdot
.64068 .48362 Mdot
.40036 .50223 Mdot
.43221 .53547 Mdot
.37617 .5789 Mdot
.40429 .59349 Mdot
.69425 .46397 Mdot
.34927 .54425 Mdot
.70668 .49386 Mdot
.41011 .65445 Mdot
.73949 .29528 Mdot
.56045 .43419 Mdot
.48983 .52936 Mdot
.59116 .67011 Mdot
.42842 .64753 Mdot
.44035 .6174 Mdot
.4783 .18617 Mdot
.28606 .72097 Mdot
.34467 .51166 Mdot
.52668 .31903 Mdot
.45161 .48086 Mdot
.5626 .35251 Mdot
.19323 .3017 Mdot
.65402 .34511 Mdot
.54158 .83265 Mdot
.42005 .51919 Mdot
.70412 .34675 Mdot
.48869 .58339 Mdot
.338 .55639 Mdot
.67982 .35346 Mdot
.7703 .49614 Mdot
.69421 .6352 Mdot
.36144 .33493 Mdot
.37218 .54328 Mdot
.55597 .61501 Mdot
.42234 .52831 Mdot
.40722 .5537 Mdot
.36004 .51634 Mdot
.64131 .46225 Mdot
.40649 .61151 Mdot
.38102 .59232 Mdot
.46843 .31983 Mdot
.28022 .42994 Mdot
.50706 .37077 Mdot
.26974 .61356 Mdot
.35173 .34756 Mdot
.56522 .68054 Mdot
.65204 .67256 Mdot
.6446 .49861 Mdot
.35408 .72316 Mdot
.38662 .5934 Mdot
.64002 .58953 Mdot
.63229 .47551 Mdot
.36402 .3602 Mdot
.51941 .31727 Mdot
.49862 .85077 Mdot
.56245 .33722 Mdot
.54568 .43605 Mdot
.55077 .33785 Mdot
.3864 .62832 Mdot
.55329 .67541 Mdot
.36601 .51034 Mdot
.68432 .48544 Mdot
.54931 .32523 Mdot
.24803 .42806 Mdot
.40477 .57373 Mdot
.54591 .3622 Mdot
.36358 .51192 Mdot
.20703 .43257 Mdot
.40287 .22424 Mdot
.57572 .33386 Mdot
.66327 .52943 Mdot
.66848 .48805 Mdot
.36179 .34356 Mdot
.57659 .68098 Mdot
.58453 .64576 Mdot
.6718 .49786 Mdot
.26499 .28017 Mdot
.43271 .56488 Mdot
.41526 .51526 Mdot
.6395 .23314 Mdot
.41721 .53323 Mdot
.27524 .48807 Mdot
.53115 .43332 Mdot
.58726 .67852 Mdot
.40005 .51219 Mdot
.35815 .54279 Mdot
.3738 .55235 Mdot
.22533 .51655 Mdot
.53017 .34003 Mdot
.43714 .56559 Mdot
.37488 .36293 Mdot
.55557 .29063 Mdot
.41488 .51381 Mdot
.3824 .48442 Mdot
.58264 .64402 Mdot
.72191 .25931 Mdot
.6472 .47843 Mdot
.55841 .31102 Mdot
.52346 .38241 Mdot
.70979 .39528 Mdot
.62827 .67632 Mdot
.52763 .4321 Mdot
.17124 .44519 Mdot
.66851 .41377 Mdot
.34457 .36645 Mdot
.60137 .41459 Mdot
.42464 .42184 Mdot
.5447 .3076 Mdot
.70156 .4737 Mdot
.40562 .59842 Mdot
.43247 .5722 Mdot
.5743 .19246 Mdot
.42851 .50968 Mdot
.36676 .37202 Mdot
.71024 .48165 Mdot
.58239 .65528 Mdot
.36605 .36158 Mdot
.65611 .4735 Mdot
.57198 .67031 Mdot
.3445 .55145 Mdot
.35185 .56607 Mdot
.5675 .63817 Mdot
.58533 .63918 Mdot
.4018 .53355 Mdot
.56632 .28343 Mdot
.60032 .67938 Mdot
.55162 .63057 Mdot
.57121 .3279 Mdot
.56595 .32388 Mdot
.3521 .48455 Mdot
.66643 .47026 Mdot
.35695 .56688 Mdot
.55858 .34973 Mdot
.34221 .34043 Mdot
.56021 .65477 Mdot
.35824 .53804 Mdot
.36781 .52074 Mdot
.34977 .38032 Mdot
.34932 .33479 Mdot
.36685 .35791 Mdot
.71207 .47445 Mdot
.3873 .58266 Mdot
.54632 .64919 Mdot
.6441 .47477 Mdot
.35644 .33251 Mdot
.38252 .37836 Mdot
.47568 .38843 Mdot
.42458 .54619 Mdot
.4891 .4032 Mdot
.79379 .7415 Mdot
.30731 .46109 Mdot
.55977 .29639 Mdot
.55065 .37513 Mdot
.25733 .4508 Mdot
.58595 .28209 Mdot
.66102 .50333 Mdot
.31853 .46178 Mdot
.38216 .39523 Mdot
.34772 .52174 Mdot
.36885 .5913 Mdot
.32864 .53851 Mdot
.35677 .35495 Mdot
.23989 .51901 Mdot
.56869 .62394 Mdot
.32574 .67291 Mdot
.35272 .34797 Mdot
.58084 .32098 Mdot
.5318 .38906 Mdot
.52472 .34637 Mdot
.37394 .59337 Mdot
.38616 .74593 Mdot
.37729 .63969 Mdot
.71374 .69905 Mdot
.64364 .50431 Mdot
.6079 .6935 Mdot
.23448 .64813 Mdot
.56202 .63766 Mdot
.52389 .38991 Mdot
.35228 .35273 Mdot
.56965 .63069 Mdot
.6951 .47692 Mdot
.68007 .47946 Mdot
.52721 .34066 Mdot
.5413 .34853 Mdot
.52565 .32705 Mdot
.58224 .69313 Mdot
.56765 .69064 Mdot
.3895 .5714 Mdot
.56958 .65037 Mdot
.64157 .20414 Mdot
.3267 .34767 Mdot
.53463 .39017 Mdot
.65417 .48663 Mdot
.55412 .6731 Mdot
.40557 .57712 Mdot
.53992 .41017 Mdot
.76562 .56395 Mdot
.37244 .38809 Mdot
.42923 .2177 Mdot
.1864 .31673 Mdot
.41288 .50379 Mdot
.66655 .50921 Mdot
.55562 .21418 Mdot
.40136 .56702 Mdot
.52895 .35742 Mdot
.80659 .52907 Mdot
.53197 .30595 Mdot
.35294 .56176 Mdot
.42448 .50462 Mdot
.67276 .51449 Mdot
.19964 .53368 Mdot
.39422 .57648 Mdot
.66435 .56008 Mdot
.67543 .45001 Mdot
.50223 .38202 Mdot
.29017 .77126 Mdot
.73352 .38507 Mdot
.2563 .37203 Mdot
.56915 .32253 Mdot
.42267 .55816 Mdot
.55894 .31937 Mdot
.37209 .38655 Mdot
.55066 .31473 Mdot
.58829 .70784 Mdot
.50474 .3702 Mdot
.37326 .52708 Mdot
.54279 .65269 Mdot
.65936 .50007 Mdot
.70483 .25909 Mdot
.46556 .31004 Mdot
.54503 .33989 Mdot
.57232 .31809 Mdot
.39076 .50972 Mdot
.58593 .57015 Mdot
.46389 .5395 Mdot
.42157 .51843 Mdot
.68095 .45747 Mdot
.56411 .68385 Mdot
.63415 .48241 Mdot
.44648 .53724 Mdot
.78848 .45214 Mdot
.64705 .48671 Mdot
.63614 .59287 Mdot
.34664 .37019 Mdot
.50464 .48122 Mdot
.41166 .57986 Mdot
.68853 .4826 Mdot
.38747 .58348 Mdot
.58653 .63116 Mdot
.53522 .47313 Mdot
.74811 .43899 Mdot
.68258 .48604 Mdot
.4221 .83285 Mdot
.48449 .37178 Mdot
.42991 .61072 Mdot
.68812 .46488 Mdot
.29642 .59392 Mdot
.56801 .31 Mdot
.34236 .35894 Mdot
.35712 .33298 Mdot
.37813 .37688 Mdot
.37804 .49467 Mdot
.40712 .6222 Mdot
.33896 .38357 Mdot
.69581 .49086 Mdot
.35983 .33918 Mdot
.62554 .71127 Mdot
.43406 .83675 Mdot
.33355 .35597 Mdot
.38236 .55211 Mdot
.32219 .54087 Mdot
.276 .42828 Mdot
.539 .39218 Mdot
.55361 .81914 Mdot
.49705 .56001 Mdot
.41353 .54221 Mdot
.51124 .60382 Mdot
.57105 .62629 Mdot
.54815 .21892 Mdot
.28563 .51068 Mdot
.55208 .24551 Mdot
.59795 .6686 Mdot
.72014 .42443 Mdot
.58245 .68064 Mdot
.4096 .50501 Mdot
.40391 .51558 Mdot
.52554 .63573 Mdot
.72063 .2981 Mdot
.63972 .3007 Mdot
.26325 .72538 Mdot
.54824 .63044 Mdot
.68769 .46852 Mdot
.692 .45993 Mdot
.6427 .50176 Mdot
.46988 .24393 Mdot
.53043 .64985 Mdot
.38437 .5761 Mdot
.54528 .36674 Mdot
.43562 .55802 Mdot
.67786 .49261 Mdot
.32656 .79265 Mdot
.58396 .64868 Mdot
.39632 .53628 Mdot
.25533 .30336 Mdot
.53618 .35828 Mdot
.34178 .37281 Mdot
.20142 .45485 Mdot
.51079 .242 Mdot
.65136 .46165 Mdot
.53433 .6268 Mdot
.63083 .42507 Mdot
.63446 .60137 Mdot
.35842 .48575 Mdot
.37831 .47332 Mdot
.19361 .60211 Mdot
.49625 .24851 Mdot
.36549 .5074 Mdot
.55983 .30847 Mdot
.71906 .42258 Mdot
.36089 .53618 Mdot
.54921 .62741 Mdot
.37405 .34059 Mdot
.3748 .35783 Mdot
.37049 .60133 Mdot
.59248 .49721 Mdot
.4878 .45311 Mdot
.35593 .55771 Mdot
.44167 .61553 Mdot
.53023 .38555 Mdot
.65499 .41421 Mdot
.67749 .24559 Mdot
.33171 .36706 Mdot
.354 .52366 Mdot
.70516 .655 Mdot
.55869 .69153 Mdot
.5098 .34741 Mdot
.65937 .4564 Mdot
.22849 .53503 Mdot
.50101 .37608 Mdot
.36004 .53472 Mdot
.3567 .5432 Mdot
.66225 .51338 Mdot
.60099 .68697 Mdot
.35487 .35504 Mdot
.53353 .37856 Mdot
.33219 .36961 Mdot
.54461 .67468 Mdot
.58252 .65031 Mdot
.31889 .56035 Mdot
.41119 .61509 Mdot
.53776 .33657 Mdot
.44347 .53355 Mdot
.55684 .37632 Mdot
.19594 .53082 Mdot
.63257 .50348 Mdot
.41623 .5043 Mdot
.55119 .69693 Mdot
.68424 .49036 Mdot
.38751 .52697 Mdot
.18896 .61803 Mdot
.43402 .52402 Mdot
.73446 .44277 Mdot
.78841 .43203 Mdot
.3714 .37706 Mdot
.28053 .66123 Mdot
.5713 .59141 Mdot
.41484 .52946 Mdot
.51484 .36559 Mdot
.46567 .53394 Mdot
.64961 .50036 Mdot
.5834 .68567 Mdot
.19585 .3356 Mdot
.66231 .48187 Mdot
.41916 .52202 Mdot
.363 .36119 Mdot
.54605 .62168 Mdot
.5842 .4296 Mdot
.62436 .2361 Mdot
.45675 .58708 Mdot
.41066 .60624 Mdot
.35258 .55908 Mdot
.81002 .59083 Mdot
.55626 .31058 Mdot
.55199 .66842 Mdot
.65864 .51012 Mdot
.67184 .50003 Mdot
.52858 .3438 Mdot
.69261 .62237 Mdot
.50565 .4794 Mdot
.83389 .67171 Mdot
.54136 .32635 Mdot
.33166 .38147 Mdot
.60915 .56592 Mdot
.51289 .36447 Mdot
.54546 .36085 Mdot
.53206 .38417 Mdot
.61856 .46207 Mdot
.57206 .66751 Mdot
.36792 .51939 Mdot
.60284 .64954 Mdot
.42518 .55755 Mdot
.45839 .4424 Mdot
.68596 .49084 Mdot
.58661 .68516 Mdot
.19376 .61822 Mdot
.50816 .66404 Mdot
.39426 .56 Mdot
.22628 .63537 Mdot
.46212 .55487 Mdot
.2557 .48862 Mdot
.44724 .58338 Mdot
.54652 .3433 Mdot
.47616 .53498 Mdot
.42367 .49775 Mdot
.67578 .23228 Mdot
.65381 .48448 Mdot
.569 .3082 Mdot
.37506 .50015 Mdot
.43378 .61582 Mdot
.52822 .62466 Mdot
.56484 .62935 Mdot
.33351 .37553 Mdot
.29171 .3546 Mdot
.65679 .49926 Mdot
.18704 .44321 Mdot
.41059 .53568 Mdot
.76822 .37581 Mdot
.2985 .67527 Mdot
.38781 .5283 Mdot
.46082 .82159 Mdot
.37247 .73662 Mdot
.41357 .5829 Mdot
.30185 .58779 Mdot
.67792 .475 Mdot
.78431 .44468 Mdot
.4386 .58114 Mdot
.52845 .36034 Mdot
.56939 .68909 Mdot
.55282 .62414 Mdot
.34816 .3894 Mdot
.47614 .17134 Mdot
.63553 .49162 Mdot
.58193 .68762 Mdot
.40783 .57133 Mdot
.64828 .4651 Mdot
.56779 .33816 Mdot
.44889 .53466 Mdot
.28574 .49176 Mdot
.57274 .65182 Mdot
.44228 .57118 Mdot
.73771 .55024 Mdot
.27236 .36348 Mdot
.70458 .75849 Mdot
.64293 .50038 Mdot
.34743 .34353 Mdot
.44131 .50284 Mdot
.19554 .40885 Mdot
.3467 .5075 Mdot
.22048 .41888 Mdot
.62962 .68689 Mdot
.34954 .34234 Mdot
.39476 .55187 Mdot
.37345 .55715 Mdot
.60372 .54409 Mdot
.34172 .33717 Mdot
.43456 .53809 Mdot
.49063 .56597 Mdot
.56818 .67029 Mdot
.53333 .30045 Mdot
.57518 .65602 Mdot
.38692 .55921 Mdot
.38173 .61457 Mdot
.58501 .64208 Mdot
.1644 .47217 Mdot
.38859 .39363 Mdot
.64538 .48083 Mdot
.40991 .61843 Mdot
.41577 .59541 Mdot
.84296 .5394 Mdot
.5653 .30099 Mdot
.76174 .63846 Mdot
.50871 .40798 Mdot
.69241 .67204 Mdot
.73356 .38122 Mdot
.53759 .848 Mdot
.72039 .27979 Mdot
.34055 .56927 Mdot
.4689 .47718 Mdot
.32682 .61428 Mdot
.63705 .47658 Mdot
.48104 .68382 Mdot
.41359 .53994 Mdot
.40794 .55666 Mdot
.51367 .33763 Mdot
.66822 .61397 Mdot
.58605 .23655 Mdot
.58425 .47044 Mdot
.35294 .35806 Mdot
.5379 .65834 Mdot
.3866 .51783 Mdot
.46021 .41527 Mdot
.5064 .36633 Mdot
.76076 .3644 Mdot
.39522 .54119 Mdot
.47007 .19022 Mdot
.64244 .43541 Mdot
.64004 .47795 Mdot
.51669 .37838 Mdot
.52744 .24661 Mdot
.4276 .5512 Mdot
.67763 .45426 Mdot
.39848 .57867 Mdot
.49185 .3239 Mdot
.43827 .52257 Mdot
.33665 .35233 Mdot
.36986 .51062 Mdot
.58451 .45268 Mdot
.64279 .79677 Mdot
.32721 .46501 Mdot
.53442 .63424 Mdot
.56255 .36552 Mdot
.53168 .33989 Mdot
.57453 .63356 Mdot
.53458 .34028 Mdot
.34422 .7 Mdot
.46629 .75382 Mdot
.35004 .36106 Mdot
.43675 .61706 Mdot
.33429 .36836 Mdot
.56503 .3002 Mdot
.41908 .54663 Mdot
.16596 .45528 Mdot
.54364 .33017 Mdot
.8094 .45 Mdot
.65789 .48584 Mdot
.56718 .30372 Mdot
.4426 .5538 Mdot
.62183 .40832 Mdot
.51468 .38269 Mdot
.72614 .42856 Mdot
.37595 .55501 Mdot
.58651 .65568 Mdot
.36883 .55304 Mdot
.4509 .58062 Mdot
.50406 .34317 Mdot
.39853 .59656 Mdot
.65627 .47343 Mdot
.59384 .69045 Mdot
.47782 .84138 Mdot
.73565 .44218 Mdot
.42959 .53705 Mdot
.40597 .57012 Mdot
.55087 .61783 Mdot
.43596 .57575 Mdot
.69301 .46337 Mdot
.88307 .40507 Mdot
.34627 .37042 Mdot
.57756 .32557 Mdot
.73628 .39189 Mdot
.34247 .51264 Mdot
.3571 .55357 Mdot
.20898 .64773 Mdot
.75186 .40261 Mdot
.67687 .46321 Mdot
.46912 .54935 Mdot
.54276 .37101 Mdot
.36353 .36304 Mdot
.69313 .4993 Mdot
.36879 .5797 Mdot
.40236 .54895 Mdot
.34604 .34497 Mdot
.41506 .80952 Mdot
.5239 .22936 Mdot
.65003 .51068 Mdot
.47494 .53108 Mdot
.56714 .37556 Mdot
.43166 .56619 Mdot
.47131 .23838 Mdot
.56113 .63061 Mdot
.663 .45813 Mdot
.7444 .66864 Mdot
.35208 .51927 Mdot
.69246 .48851 Mdot
.65513 .49677 Mdot
.44039 .50625 Mdot
.51587 .64226 Mdot
.58 .69817 Mdot
.53567 .64819 Mdot
.66541 .20845 Mdot
.26851 .38236 Mdot
.5254 .32744 Mdot
.67944 .47551 Mdot
.56428 .35288 Mdot
.32324 .3634 Mdot
.45962 .42694 Mdot
.57663 .33117 Mdot
.5833 .63531 Mdot
.54173 .38864 Mdot
.37146 .55309 Mdot
.66072 .50143 Mdot
.54182 .30965 Mdot
.37765 .4985 Mdot
.57094 .57656 Mdot
.51056 .29135 Mdot
.38082 .35439 Mdot
.38199 .34428 Mdot
.39882 .51615 Mdot
.55511 .29561 Mdot
.40271 .53578 Mdot
.68684 .5148 Mdot
.61783 .56788 Mdot
.3539 .50505 Mdot
.54188 .34135 Mdot
.52279 .58798 Mdot
.51076 .24233 Mdot
.46666 .55307 Mdot
.38367 .55243 Mdot
.42873 .56284 Mdot
.39863 .57944 Mdot
.67551 .64149 Mdot
.63564 .50518 Mdot
.54752 .55594 Mdot
.70104 .40952 Mdot
.56703 .64421 Mdot
.54942 .69223 Mdot
.433 .24043 Mdot
.56577 .27258 Mdot
.66935 .46973 Mdot
.42448 .57391 Mdot
.74036 .43921 Mdot
.33849 .80203 Mdot
.16036 .48376 Mdot
.34684 .32121 Mdot
.53893 .30567 Mdot
.52835 .63909 Mdot
.50972 .36971 Mdot
.42069 .55582 Mdot
.43693 .49937 Mdot
.52765 .85672 Mdot
.708 .50953 Mdot
.35347 .35288 Mdot
.4275 .5616 Mdot
.26521 .3702 Mdot
.54509 .36597 Mdot
.536 .3849 Mdot
.43606 .53611 Mdot
.58252 .70521 Mdot
.81075 .64793 Mdot
.63883 .47909 Mdot
.49665 .54941 Mdot
.47943 .6249 Mdot
.74556 .51907 Mdot
.6814 .49616 Mdot
.52241 .26808 Mdot
.53969 .30371 Mdot
.31961 .7209 Mdot
.57046 .64305 Mdot
.35245 .35011 Mdot
.39995 .4768 Mdot
.59309 .65482 Mdot
.50253 .35205 Mdot
.59152 .67341 Mdot
.37461 .50722 Mdot
.63361 .49214 Mdot
.5205 .37657 Mdot
.67262 .52793 Mdot
.51889 .6534 Mdot
.34991 .38694 Mdot
.57777 .54791 Mdot
.50955 .72223 Mdot
.36756 .73284 Mdot
.43549 .56785 Mdot
.4526 .41163 Mdot
.38342 .57922 Mdot
.52504 .62646 Mdot
.40316 .57784 Mdot
.50935 .60936 Mdot
.516 .36946 Mdot
.44069 .57417 Mdot
.35027 .55211 Mdot
.4434 .67399 Mdot
.38758 .54256 Mdot
.43984 .58644 Mdot
.41714 .58193 Mdot
.61244 .69502 Mdot
.46073 .60439 Mdot
.57853 .66564 Mdot
.62027 .2402 Mdot
.54606 .35879 Mdot
.37382 .33884 Mdot
.37583 .3547 Mdot
.22719 .40165 Mdot
.3558 .42126 Mdot
.68174 .62261 Mdot
.56832 .66011 Mdot
.65011 .48526 Mdot
.40274 .58079 Mdot
.68253 .72549 Mdot
.70769 .37524 Mdot
.54542 .36944 Mdot
.73477 .44164 Mdot
.40799 .472 Mdot
.81221 .58927 Mdot
.44427 .55367 Mdot
.56994 .1858 Mdot
.331 .5601 Mdot
.42907 .51516 Mdot
.52134 .39261 Mdot
.36778 .42618 Mdot
.43996 .5589 Mdot
.52949 .62331 Mdot
.34308 .35202 Mdot
.53541 .70911 Mdot
.60245 .3583 Mdot
.53298 .26362 Mdot
.47826 .71597 Mdot
.39185 .58345 Mdot
.52171 .37511 Mdot
.58205 .67377 Mdot
.69182 .2546 Mdot
.64575 .47281 Mdot
.60839 .51573 Mdot
.37794 .64974 Mdot
.21062 .59764 Mdot
.3488 .34989 Mdot
.40828 .80417 Mdot
.37332 .52565 Mdot
.45187 .26122 Mdot
.33817 .5383 Mdot
.34274 .80419 Mdot
.33653 .38839 Mdot
.57166 .70487 Mdot
.68651 .46749 Mdot
.59122 .6362 Mdot
.38416 .75107 Mdot
.73163 .51264 Mdot
.5541 .50182 Mdot
.56037 .34405 Mdot
.55606 .55534 Mdot
.54448 .6593 Mdot
.35358 .53692 Mdot
.822 .69648 Mdot
.55493 .63051 Mdot
.53947 .67318 Mdot
.19193 .50797 Mdot
.18801 .51705 Mdot
.43897 .48909 Mdot
.59688 .65767 Mdot
.55846 .34457 Mdot
.36119 .38542 Mdot
.37174 .56052 Mdot
.38687 .57083 Mdot
.58595 .64588 Mdot
.52667 .39055 Mdot
.48457 .52935 Mdot
.54339 .34765 Mdot
.56901 .67225 Mdot
.53929 .36172 Mdot
.73178 .42028 Mdot
.54921 .30439 Mdot
.4199 .59286 Mdot
.40323 .57875 Mdot
.5829 .36034 Mdot
.58243 .65049 Mdot
.36036 .56208 Mdot
.373 .51339 Mdot
.54586 .65177 Mdot
.51228 .41259 Mdot
.58945 .74653 Mdot
.42481 .53821 Mdot
.3704 .53867 Mdot
.34585 .34304 Mdot
.43122 .40808 Mdot
.35939 .24014 Mdot
.36343 .557 Mdot
.32609 .35875 Mdot
.58342 .6919 Mdot
.39954 .53316 Mdot
.63545 .70092 Mdot
.72494 .42385 Mdot
.35308 .51943 Mdot
.56637 .30821 Mdot
.3825 .49019 Mdot
.74521 .71586 Mdot
.42653 .52116 Mdot
.55085 .66052 Mdot
.55618 .68375 Mdot
.20128 .50611 Mdot
.55125 .63608 Mdot
.56891 .32797 Mdot
.67317 .49271 Mdot
.37227 .82116 Mdot
.5674 .33963 Mdot
.41299 .49753 Mdot
.22751 .31965 Mdot
.44893 .56044 Mdot
.36576 .50185 Mdot
.8242 .54916 Mdot
.56551 .34232 Mdot
.55266 .67726 Mdot
.61837 .53261 Mdot
.34856 .58587 Mdot
.65371 .46036 Mdot
.42857 .49726 Mdot
.39466 .59901 Mdot
.7828 .4234 Mdot
.78613 .55461 Mdot
.70868 .48373 Mdot
.33705 .50131 Mdot
.36321 .55751 Mdot
.45285 .36873 Mdot
.40795 .57584 Mdot
.3333 .36903 Mdot
.5363 .66382 Mdot
.51365 .34667 Mdot
.35377 .37975 Mdot
.41352 .53387 Mdot
.3584 .35499 Mdot
.52185 .33041 Mdot
.67237 .45537 Mdot
.42288 .55061 Mdot
.35908 .40192 Mdot
.35427 .35776 Mdot
.37826 .57758 Mdot
.57959 .68741 Mdot
.36339 .45778 Mdot
.39645 .53137 Mdot
.35663 .52893 Mdot
.58473 .6463 Mdot
.14578 .47893 Mdot
.42964 .52163 Mdot
.48775 .37228 Mdot
.5375 .67278 Mdot
.74056 .46504 Mdot
.51716 .33461 Mdot
.39771 .59935 Mdot
.68066 .45629 Mdot
.68834 .48772 Mdot
.55346 .36413 Mdot
.56721 .61897 Mdot
.54929 .38733 Mdot
.51848 .58984 Mdot
.40073 .61511 Mdot
.45429 .54342 Mdot
.26288 .27543 Mdot
.52055 .84895 Mdot
.54643 .62716 Mdot
.49926 .39561 Mdot
.58246 .47378 Mdot
.68277 .47378 Mdot
.55563 .36784 Mdot
.5408 .62231 Mdot
.53062 .63596 Mdot
.5896 .67223 Mdot
.36588 .35123 Mdot
.5054 .40954 Mdot
.59895 .69275 Mdot
.58277 .7046 Mdot
.37358 .55341 Mdot
.36233 .55856 Mdot
.29542 .55281 Mdot
.29846 .44382 Mdot
.34887 .38771 Mdot
.52739 .34776 Mdot
.8407 .37015 Mdot
.69343 .50957 Mdot
.44399 .67657 Mdot
.35258 .5063 Mdot
.69616 .84029 Mdot
.44319 .54169 Mdot
.41 .57341 Mdot
.59643 .68563 Mdot
.3682 .40104 Mdot
.33615 .36748 Mdot
.54452 .66272 Mdot
.52168 .64434 Mdot
.33198 .36387 Mdot
.32339 .76298 Mdot
.43274 .83899 Mdot
.63681 .55085 Mdot
.5521 .65217 Mdot
.5114 .73633 Mdot
.65825 .45624 Mdot
.51812 .65965 Mdot
.68452 .51383 Mdot
.5421 .3675 Mdot
.53456 .30672 Mdot
.65702 .5106 Mdot
.37915 .55818 Mdot
.53657 .31701 Mdot
.40912 .61082 Mdot
.37174 .80075 Mdot
.4841 .79285 Mdot
.71237 .3324 Mdot
.36218 .58702 Mdot
.5925 .23999 Mdot
.60275 .26848 Mdot
.41128 .52303 Mdot
.6602 .7067 Mdot
.35496 .35289 Mdot
.55324 .70294 Mdot
.69146 .46118 Mdot
.71775 .75009 Mdot
.4299 .56882 Mdot
.55434 .65984 Mdot
.65462 .47994 Mdot
.21389 .4923 Mdot
.66071 .56118 Mdot
.42719 .55831 Mdot
.84893 .64468 Mdot
.6051 .71278 Mdot
.51468 .34424 Mdot
.34827 .21514 Mdot
.60469 .6519 Mdot
.32853 .31836 Mdot
.66304 .41014 Mdot
.20787 .62259 Mdot
.56479 .68017 Mdot
.49927 .39974 Mdot
.53919 .65894 Mdot
.33977 .38069 Mdot
.56736 .71465 Mdot
.52734 .38046 Mdot
.39138 .5461 Mdot
.53475 .34533 Mdot
.35424 .39036 Mdot
.46231 .24852 Mdot
.68909 .45949 Mdot
.56818 .30772 Mdot
.67392 .4826 Mdot
.27783 .3615 Mdot
.79308 .46373 Mdot
.65176 .47085 Mdot
.19943 .47781 Mdot
.35908 .51017 Mdot
.6067 .67532 Mdot
.5361 .32716 Mdot
.65051 .41196 Mdot
.58097 .53093 Mdot
.56112 .64245 Mdot
.52228 .35377 Mdot
.38467 .6471 Mdot
.23249 .34008 Mdot
.4155 .62341 Mdot
.29115 .37997 Mdot
.54876 .64965 Mdot
.5407 .38517 Mdot
.64035 .23308 Mdot
.58032 .63197 Mdot
.54142 .3254 Mdot
.69037 .47387 Mdot
.67588 .49928 Mdot
.43818 .5502 Mdot
.61271 .49863 Mdot
.52254 .3409 Mdot
.62401 .26557 Mdot
.55709 .69107 Mdot
.21723 .48949 Mdot
.37413 .39023 Mdot
.55061 .34911 Mdot
.43709 .51513 Mdot
.51643 .61238 Mdot
.72494 .42129 Mdot
.45579 .47917 Mdot
.83765 .37803 Mdot
.52902 .34438 Mdot
.5382 .6689 Mdot
.55807 .65793 Mdot
.46383 .5433 Mdot
.59345 .50936 Mdot
.5543 .38335 Mdot
.23571 .35675 Mdot
.21808 .43372 Mdot
.50622 .33976 Mdot
.6133 .31324 Mdot
.42244 .50183 Mdot
.39145 .5876 Mdot
.68381 .47192 Mdot
.3861 .54715 Mdot
.58625 .69919 Mdot
.43872 .56485 Mdot
.68215 .4994 Mdot
.5599 .33094 Mdot
.41822 .54968 Mdot
.36606 .38539 Mdot
.7044 .46517 Mdot
.66888 .51527 Mdot
.55112 .34179 Mdot
.59575 .66125 Mdot
.38933 .34683 Mdot
.5406 .34883 Mdot
.39254 .5828 Mdot
.59998 .42537 Mdot
.38023 .50755 Mdot
.31755 .74281 Mdot
.58708 .6374 Mdot
.51184 .36857 Mdot
.53605 .67445 Mdot
.67123 .47925 Mdot
.69912 .40974 Mdot
.3941 .56681 Mdot
.54433 .32483 Mdot
.5913 .3475 Mdot
.35486 .7804 Mdot
.55093 .61623 Mdot
.62965 .33984 Mdot
.55622 .69423 Mdot
.51189 .32959 Mdot
.24557 .58697 Mdot
.345 .35726 Mdot
.53922 .37566 Mdot
.51634 .83601 Mdot
.54162 .33642 Mdot
.38521 .53871 Mdot
.38842 .52244 Mdot
.52086 .32793 Mdot
.36737 .3461 Mdot
.73941 .28914 Mdot
.52103 .28764 Mdot
.55831 .67984 Mdot
.26788 .63987 Mdot
.85742 .44357 Mdot
.62869 .51211 Mdot
.68143 .46715 Mdot
.3432 .57708 Mdot
.43028 .51445 Mdot
.69422 .50332 Mdot
.66546 .4502 Mdot
.36055 .39587 Mdot
.53419 .38254 Mdot
.57776 .7182 Mdot
.68998 .45468 Mdot
.31566 .53334 Mdot
.33334 .40715 Mdot
.46965 .57342 Mdot
.4801 .61452 Mdot
.35431 .57342 Mdot
.21504 .41671 Mdot
.67312 .50739 Mdot
.39083 .51445 Mdot
.46488 .5918 Mdot
.67251 .45714 Mdot
.33735 .37714 Mdot
.78239 .54273 Mdot
.53165 .36649 Mdot
.19879 .68023 Mdot
.40519 .50881 Mdot
.38814 .53611 Mdot
.64226 .5025 Mdot
.44382 .37173 Mdot
.59116 .65678 Mdot
.58922 .63798 Mdot
.55406 .30962 Mdot
.56655 .54235 Mdot
.42748 .58251 Mdot
.40733 .51997 Mdot
.52336 .36776 Mdot
.56678 .30432 Mdot
.66955 .29942 Mdot
.3675 .52274 Mdot
.65701 .47872 Mdot
.57765 .43052 Mdot
.67756 .50484 Mdot
.40306 .50451 Mdot
.38303 .53566 Mdot
.42254 .59097 Mdot
.42671 .50889 Mdot
.66688 .51608 Mdot
.38706 .51544 Mdot
.32874 .57328 Mdot
.59258 .67718 Mdot
.40678 .59372 Mdot
.21366 .43054 Mdot
.37767 .54729 Mdot
.35322 .38664 Mdot
.38522 .43015 Mdot
.42979 .56148 Mdot
.41096 .59611 Mdot
.517 .29247 Mdot
.39775 .55565 Mdot
.68634 .51494 Mdot
.56638 .64798 Mdot
.67992 .47605 Mdot
.66351 .51276 Mdot
.56639 .31916 Mdot
.34309 .38684 Mdot
.34027 .5186 Mdot
.37711 .37715 Mdot
.34759 .49544 Mdot
.35686 .5135 Mdot
.68777 .39848 Mdot
.56252 .18143 Mdot
.51884 .22798 Mdot
.39341 .56744 Mdot
.55913 .32491 Mdot
.51144 .35343 Mdot
.48625 .50537 Mdot
.43304 .61349 Mdot
.69571 .50028 Mdot
.68809 .4831 Mdot
.28346 .48089 Mdot
.78154 .4265 Mdot
.34784 .38516 Mdot
.45732 .41989 Mdot
.40628 .61191 Mdot
.36449 .51867 Mdot
.44933 .53784 Mdot
.5741 .33599 Mdot
.59487 .42774 Mdot
.54583 .36859 Mdot
.72811 .43739 Mdot
.68396 .4995 Mdot
.42703 .57771 Mdot
.52842 .79665 Mdot
.56888 .62922 Mdot
.56727 .648 Mdot
.68975 .50138 Mdot
.56232 .36422 Mdot
.31406 .49646 Mdot
.15544 .38756 Mdot
.6033 .7093 Mdot
.38095 .38501 Mdot
.4167 .52492 Mdot
.55526 .33249 Mdot
.53911 .63486 Mdot
.36068 .33866 Mdot
.35477 .52025 Mdot
.5487 .39011 Mdot
.39189 .56934 Mdot
.32566 .61273 Mdot
.57926 .68448 Mdot
.37045 .82531 Mdot
.5522 .62168 Mdot
.70223 .46463 Mdot
.66705 .46145 Mdot
.38549 .52768 Mdot
.28877 .25557 Mdot
.6076 .6663 Mdot
.63811 .44556 Mdot
.34152 .39202 Mdot
.62056 .41971 Mdot
.33126 .35221 Mdot
.51335 .36209 Mdot
.34505 .35105 Mdot
.51973 .37948 Mdot
.30263 .45879 Mdot
.61634 .66008 Mdot
.34861 .37529 Mdot
.47103 .35189 Mdot
.43031 .61484 Mdot
.36489 .335 Mdot
.32851 .52616 Mdot
.29398 .68641 Mdot
.52446 .3649 Mdot
.37053 .35123 Mdot
.35414 .53811 Mdot
.64376 .77775 Mdot
.66087 .46915 Mdot
.69784 .49953 Mdot
.4211 .6089 Mdot
.53654 .38238 Mdot
.52714 .63126 Mdot
.64446 .62502 Mdot
.73212 .48698 Mdot
.40021 .51729 Mdot
.43974 .56102 Mdot
.55356 .696 Mdot
.60692 .63176 Mdot
.38165 .53124 Mdot
.44248 .65757 Mdot
.37664 .52049 Mdot
.69352 .47663 Mdot
.56359 .62487 Mdot
.56124 .6538 Mdot
.51907 .34946 Mdot
.6006 .66494 Mdot
.50813 .60302 Mdot
.60058 .43453 Mdot
.32675 .53746 Mdot
.66394 .48245 Mdot
.59934 .46499 Mdot
.73463 .44074 Mdot
.56861 .80645 Mdot
.5386 .68414 Mdot
.41136 .59905 Mdot
.55063 .68695 Mdot
.36729 .36475 Mdot
.58074 .6518 Mdot
.52865 .64995 Mdot
.40368 .52937 Mdot
.42251 .55861 Mdot
.56519 .33805 Mdot
.59094 .50029 Mdot
.58911 .6858 Mdot
.39408 .51743 Mdot
.44545 .5692 Mdot
.43937 .58789 Mdot
.51243 .45235 Mdot
.54251 .62925 Mdot
.37933 .67223 Mdot
.25708 .5447 Mdot
.59036 .6845 Mdot
.76769 .69363 Mdot
.67277 .41314 Mdot
.58114 .31383 Mdot
.6582 .52967 Mdot
.36645 .52289 Mdot
.51934 .32809 Mdot
.42061 .55527 Mdot
.48014 .61479 Mdot
.40457 .55115 Mdot
.33522 .34421 Mdot
.34053 .56913 Mdot
.52385 .31333 Mdot
.5392 .34692 Mdot
.41611 .51613 Mdot
.41531 .55012 Mdot
.48407 .24382 Mdot
.5209 .64908 Mdot
.59121 .65972 Mdot
.44055 .35929 Mdot
.35521 .37082 Mdot
.65967 .45846 Mdot
.411 .58156 Mdot
.55975 .31662 Mdot
.53562 .34677 Mdot
.59193 .63592 Mdot
.52993 .35822 Mdot
.63889 .48849 Mdot
.39775 .5693 Mdot
.6965 .50168 Mdot
.37285 .35541 Mdot
.53445 .65002 Mdot
.42766 .57232 Mdot
.37293 .55253 Mdot
.5561 .68359 Mdot
.34517 .51969 Mdot
.34423 .34351 Mdot
.53881 .3382 Mdot
.57145 .67898 Mdot
.67457 .49379 Mdot
.51522 .36999 Mdot
.36173 .54441 Mdot
.83521 .36902 Mdot
.38042 .5395 Mdot
.36092 .53236 Mdot
.48709 .85238 Mdot
.33659 .56156 Mdot
.52962 .33497 Mdot
.57184 .70635 Mdot
.40538 .60853 Mdot
.23725 .40086 Mdot
.1563 .4872 Mdot
.55492 .35876 Mdot
.42278 .5275 Mdot
.57276 .81521 Mdot
.42173 .52184 Mdot
.19059 .43531 Mdot
.37849 .26106 Mdot
.52801 .53225 Mdot
.36968 .61109 Mdot
.64633 .50077 Mdot
.56575 .33592 Mdot
.51638 .36769 Mdot
.29711 .64577 Mdot
.40376 .52526 Mdot
.31133 .58857 Mdot
.34891 .54051 Mdot
.67981 .49795 Mdot
.27807 .51075 Mdot
.53014 .34655 Mdot
.60452 .21174 Mdot
.38544 .5775 Mdot
.54049 .62917 Mdot
.53979 .38989 Mdot
.68907 .41528 Mdot
.35771 .53696 Mdot
.37676 .37096 Mdot
.71064 .49607 Mdot
.36398 .59963 Mdot
.66303 .48802 Mdot
.36358 .51624 Mdot
.3189 .56493 Mdot
.39252 .19109 Mdot
.58541 .68226 Mdot
.68605 .46917 Mdot
.60638 .28629 Mdot
.33656 .53516 Mdot
.56883 .68035 Mdot
.56912 .64274 Mdot
.36518 .39357 Mdot
.5623 .48346 Mdot
.72676 .56265 Mdot
.53358 .76632 Mdot
.27374 .63452 Mdot
.55023 .37892 Mdot
.63724 .30756 Mdot
.36877 .55982 Mdot
.75783 .36802 Mdot
.70043 .5018 Mdot
.38945 .53939 Mdot
.31228 .69566 Mdot
.5366 .64329 Mdot
.36935 .53317 Mdot
.33429 .36918 Mdot
.72718 .31509 Mdot
.74278 .34312 Mdot
.78763 .6361 Mdot
.55664 .3501 Mdot
.42926 .49578 Mdot
.47333 .61667 Mdot
.57143 .31604 Mdot
.3414 .53556 Mdot
.53431 .33273 Mdot
.25675 .68304 Mdot
.35545 .34014 Mdot
.53327 .64255 Mdot
.67874 .41374 Mdot
.36379 .58149 Mdot
.4491 .57029 Mdot
.37679 .34352 Mdot
.38281 .58765 Mdot
.47941 .17334 Mdot
.71033 .34869 Mdot
.5424 .31088 Mdot
.58943 .67466 Mdot
.37187 .5917 Mdot
.5588 .43562 Mdot
.39856 .52599 Mdot
.47114 .77149 Mdot
.40715 .59783 Mdot
.72218 .55384 Mdot
.57 .68933 Mdot
.66566 .48556 Mdot
.38064 .48017 Mdot
.40606 .55925 Mdot
.55045 .4019 Mdot
.36079 .60578 Mdot
.42274 .51546 Mdot
.53399 .62115 Mdot
.55766 .62639 Mdot
.57749 .66513 Mdot
.50527 .37307 Mdot
.77658 .41872 Mdot
.66516 .47462 Mdot
.40587 .4913 Mdot
.68963 .45408 Mdot
.47987 .52287 Mdot
.38091 .35309 Mdot
.65502 .7597 Mdot
.38969 .59414 Mdot
.56971 .66409 Mdot
.72453 .63796 Mdot
.58116 .69325 Mdot
.53074 .42467 Mdot
.65744 .49989 Mdot
.54115 .63642 Mdot
.40823 .56819 Mdot
.59056 .47039 Mdot
.71379 .71609 Mdot
.68175 .48087 Mdot
.3467 .5016 Mdot
.54782 .30015 Mdot
.73845 .40087 Mdot
.8618 .4016 Mdot
.67514 .46318 Mdot
.61257 .29152 Mdot
.40656 .5225 Mdot
.57637 .63272 Mdot
.64295 .49802 Mdot
.65041 .47557 Mdot
.52561 .35827 Mdot
.42408 .56012 Mdot
.42597 .56464 Mdot
.51308 .32929 Mdot
.68698 .48571 Mdot
.45524 .56809 Mdot
.44457 .53375 Mdot
.52755 .85845 Mdot
.28451 .59791 Mdot
.13784 .57324 Mdot
.5154 .5873 Mdot
.32305 .71075 Mdot
.62988 .61374 Mdot
.53402 .66225 Mdot
.43001 .55939 Mdot
.35011 .57243 Mdot
.52232 .34315 Mdot
.38851 .55371 Mdot
.50598 .39611 Mdot
.67063 .46773 Mdot
.76305 .69402 Mdot
.7659 .57984 Mdot
.24751 .66615 Mdot
.39074 .55293 Mdot
.76487 .48645 Mdot
.36377 .37661 Mdot
.69775 .45392 Mdot
.57462 .67285 Mdot
.37971 .50481 Mdot
.49231 .24064 Mdot
.54122 .37353 Mdot
.56679 .63612 Mdot
.59934 .23361 Mdot
.54596 .25353 Mdot
.40181 .5043 Mdot
.50436 .36462 Mdot
.6795 .67129 Mdot
.45238 .65558 Mdot
.63347 .46889 Mdot
.33316 .34756 Mdot
.54656 .36578 Mdot
.68405 .5038 Mdot
.63046 .6926 Mdot
.54595 .63519 Mdot
.60024 .70106 Mdot
.4588 .22623 Mdot
.57908 .32913 Mdot
.35759 .38229 Mdot
.77768 .42457 Mdot
.77709 .38107 Mdot
.33511 .34488 Mdot
.52251 .3193 Mdot
.55051 .62822 Mdot
.55858 .67071 Mdot
.56509 .64833 Mdot
.61704 .21581 Mdot
.56678 .61972 Mdot
.45373 .69838 Mdot
.44777 .56694 Mdot
.31427 .57486 Mdot
.42366 .52627 Mdot
.68288 .51378 Mdot
.5735 .68513 Mdot
.60252 .55641 Mdot
.39412 .49241 Mdot
.76711 .66869 Mdot
.40532 .51823 Mdot
.64036 .45963 Mdot
.36578 .52953 Mdot
.47941 .69451 Mdot
.54194 .67999 Mdot
.38933 .56047 Mdot
.65687 .52196 Mdot
.35616 .36165 Mdot
.51291 .65914 Mdot
.42854 .56211 Mdot
.66548 .60587 Mdot
.33395 .55509 Mdot
.30108 .74318 Mdot
.22559 .49968 Mdot
.38145 .38392 Mdot
.487 .56217 Mdot
.54733 .37696 Mdot
.31177 .57331 Mdot
.44772 .61822 Mdot
.68054 .48235 Mdot
.79902 .5053 Mdot
.54848 .35667 Mdot
.30755 .47792 Mdot
.46752 .54069 Mdot
.3398 .38303 Mdot
.56656 .61203 Mdot
.67021 .51889 Mdot
.38243 .49909 Mdot
.44238 .50939 Mdot
.26895 .69539 Mdot
.43023 .62133 Mdot
.43751 .57247 Mdot
.37724 .34772 Mdot
.38669 .68018 Mdot
.37497 .54788 Mdot
.52725 .42648 Mdot
.59584 .70494 Mdot
.42297 .61082 Mdot
.38105 .66997 Mdot
.39511 .51822 Mdot
.57076 .63416 Mdot
.61282 .65444 Mdot
.72691 .60939 Mdot
.34505 .39311 Mdot
.40608 .59764 Mdot
.22008 .54131 Mdot
.38707 .58164 Mdot
.65647 .48166 Mdot
.4222 .51 Mdot
.53605 .37524 Mdot
.60368 .21892 Mdot
.52621 .32817 Mdot
.43086 .5478 Mdot
.55971 .64988 Mdot
.65073 .50903 Mdot
.49084 .22304 Mdot
.40281 .26584 Mdot
.44299 .69341 Mdot
.193 .62143 Mdot
.36606 .34682 Mdot
.33333 .34076 Mdot
.66208 .51832 Mdot
.38769 .55992 Mdot
.20289 .52267 Mdot
.33697 .57203 Mdot
.3691 .53781 Mdot
.4053 .55034 Mdot
.76834 .43161 Mdot
.67842 .47123 Mdot
.53426 .36077 Mdot
.38122 .53351 Mdot
.38995 .51665 Mdot
.54466 .67714 Mdot
.35448 .36045 Mdot
.51467 .34095 Mdot
.34861 .36628 Mdot
.55221 .32802 Mdot
.75732 .70651 Mdot
.3775 .48654 Mdot
.35715 .36459 Mdot
.70954 .48697 Mdot
.58444 .64513 Mdot
.60179 .42597 Mdot
.51413 .36313 Mdot
.52611 .3484 Mdot
.40246 .51844 Mdot
.57635 .6354 Mdot
.599 .67203 Mdot
.36816 .36457 Mdot
.65214 .46758 Mdot
.42713 .55293 Mdot
.36296 .50974 Mdot
.50399 .51786 Mdot
.57136 .34227 Mdot
.40196 .64601 Mdot
.70277 .63048 Mdot
.39078 .5651 Mdot
.59691 .65998 Mdot
.40983 .54482 Mdot
.52839 .80913 Mdot
.58556 .63825 Mdot
.43225 .52148 Mdot
.77663 .36055 Mdot
.58861 .42827 Mdot
.68945 .59006 Mdot
.42923 .58815 Mdot
.21768 .68588 Mdot
.36872 .56554 Mdot
.56011 .84002 Mdot
.46416 .27509 Mdot
.42922 .57672 Mdot
.36885 .55492 Mdot
.55835 .77138 Mdot
.41619 .53206 Mdot
.52466 .31132 Mdot
.30453 .47946 Mdot
.52691 .63984 Mdot
.61225 .58082 Mdot
.41668 .42606 Mdot
.35119 .39762 Mdot
.55346 .30939 Mdot
.61587 .33536 Mdot
.3347 .35568 Mdot
.55027 .65361 Mdot
.39881 .57983 Mdot
.54598 .53011 Mdot
.49845 .36845 Mdot
.45409 .57894 Mdot
.6553 .48778 Mdot
.66687 .33503 Mdot
.50566 .4003 Mdot
.6702 .49077 Mdot
.37227 .58527 Mdot
.58875 .74892 Mdot
.36382 .25636 Mdot
.38731 .83707 Mdot
.64863 .50944 Mdot
.68725 .4922 Mdot
.65427 .22777 Mdot
.34685 .39733 Mdot
.2665 .67064 Mdot
.70244 .55588 Mdot
.63811 .47742 Mdot
.24155 .56299 Mdot
.54692 .36967 Mdot
.66347 .59622 Mdot
.55285 .70268 Mdot
.45344 .5416 Mdot
.40718 .56576 Mdot
.65596 .46466 Mdot
.62816 .70637 Mdot
.37698 .19932 Mdot
.67501 .48331 Mdot
.31972 .54818 Mdot
.51694 .46996 Mdot
.66675 .41318 Mdot
.57213 .33355 Mdot
.34977 .39467 Mdot
.31832 .33593 Mdot
.54362 .67119 Mdot
.35474 .39363 Mdot
.73368 .33293 Mdot
.38661 .59128 Mdot
.68104 .48757 Mdot
.69629 .41912 Mdot
.67243 .49693 Mdot
.33489 .36131 Mdot
.37725 .39188 Mdot
.59294 .67599 Mdot
.59044 .65957 Mdot
.34004 .72134 Mdot
.26447 .48532 Mdot
.41959 .51906 Mdot
.7354 .67507 Mdot
.56089 .69282 Mdot
.48667 .59702 Mdot
.32917 .35163 Mdot
.35486 .36556 Mdot
.30654 .60535 Mdot
.42115 .5785 Mdot
.19816 .49618 Mdot
.41809 .57869 Mdot
.27488 .50175 Mdot
.33994 .54326 Mdot
.52745 .35832 Mdot
.42056 .58196 Mdot
.38884 .39828 Mdot
.42283 .50237 Mdot
.41815 .51135 Mdot
.54055 .37965 Mdot
.3724 .60475 Mdot
.53471 .37576 Mdot
.43201 .5447 Mdot
.3239 .3655 Mdot
.55932 .31485 Mdot
.26303 .39415 Mdot
.48976 .35844 Mdot
.5541 .29639 Mdot
.36506 .38927 Mdot
.37655 .38523 Mdot
.25102 .36872 Mdot
.57349 .67377 Mdot
.51123 .64252 Mdot
.38526 .55532 Mdot
.53572 .38527 Mdot
.6816 .46981 Mdot
.38518 .51695 Mdot
.33847 .55662 Mdot
.43978 .5731 Mdot
.53578 .65841 Mdot
.55671 .37893 Mdot
.36043 .3607 Mdot
.50373 .37111 Mdot
.53104 .40566 Mdot
.50109 .38906 Mdot
.46695 .59533 Mdot
.37723 .47417 Mdot
.34245 .74589 Mdot
.77477 .61551 Mdot
.72312 .26971 Mdot
.55186 .63374 Mdot
.56676 .30765 Mdot
.36753 .39653 Mdot
.41097 .46334 Mdot
.56942 .66923 Mdot
.52852 .37992 Mdot
.39297 .5705 Mdot
.34732 .4997 Mdot
.71619 .50204 Mdot
.31476 .58423 Mdot
.22471 .44581 Mdot
.50709 .39161 Mdot
.49825 .39959 Mdot
.77335 .37972 Mdot
.30286 .48713 Mdot
.57442 .5381 Mdot
.39859 .54011 Mdot
.37675 .36738 Mdot
.53921 .63479 Mdot
.41401 .22899 Mdot
.68321 .46014 Mdot
.59245 .50505 Mdot
.39095 .55435 Mdot
.6692 .55435 Mdot
.56083 .64852 Mdot
.33979 .37888 Mdot
.65707 .46356 Mdot
.37255 .4007 Mdot
.57659 .32538 Mdot
.18262 .53816 Mdot
.38479 .58411 Mdot
.42635 .52158 Mdot
.69735 .46351 Mdot
.53986 .65831 Mdot
.38455 .35205 Mdot
.32666 .7615 Mdot
.52203 .3282 Mdot
.1906 .49334 Mdot
.59905 .68442 Mdot
.4847 .71945 Mdot
.50398 .37377 Mdot
.68984 .50068 Mdot
.25907 .36168 Mdot
.68116 .50047 Mdot
.43409 .56011 Mdot
.56557 .65854 Mdot
.66009 .47084 Mdot
.55657 .41273 Mdot
.60256 .80108 Mdot
.50252 .73229 Mdot
.40513 .58875 Mdot
.6863 .74513 Mdot
.40983 .8211 Mdot
.59522 .72976 Mdot
.68425 .45637 Mdot
.39585 .52958 Mdot
.34945 .55673 Mdot
.38855 .57848 Mdot
.65108 .49566 Mdot
.66582 .39227 Mdot
.52114 .36394 Mdot
.4149 .52097 Mdot
.36351 .39542 Mdot
.53524 .3731 Mdot
.69482 .41319 Mdot
.52667 .34059 Mdot
.52427 .66165 Mdot
.42849 .51263 Mdot
.60622 .4979 Mdot
.65367 .79799 Mdot
.68048 .47716 Mdot
.55329 .2963 Mdot
.39203 .50913 Mdot
.78149 .46938 Mdot
.5756 .66548 Mdot
.52438 .32523 Mdot
.38881 .53618 Mdot
.63677 .39901 Mdot
.48012 .24264 Mdot
.52671 .34259 Mdot
.56264 .6743 Mdot
.62966 .72398 Mdot
.38616 .54941 Mdot
.37 .56932 Mdot
.54169 .65765 Mdot
.40147 .41886 Mdot
.6159 .23106 Mdot
.413 .54853 Mdot
.66667 .48646 Mdot
.17124 .39707 Mdot
.43778 .5855 Mdot
.27743 .56918 Mdot
.56068 .34834 Mdot
.68837 .61621 Mdot
.40906 .64625 Mdot
.47941 .53963 Mdot
.56969 .77792 Mdot
.46669 .43354 Mdot
.74546 .70917 Mdot
.5153 .39654 Mdot
.48401 .28957 Mdot
.74064 .72069 Mdot
.64878 .51717 Mdot
.59058 .60567 Mdot
.4998 .54879 Mdot
.5863 .2071 Mdot
.64362 .68843 Mdot
.44192 .32839 Mdot
.50872 .2347 Mdot
.52498 .50153 Mdot
.54399 .33118 Mdot
.35017 .44518 Mdot
.42445 .55364 Mdot
.40264 .81967 Mdot
.44762 .66222 Mdot
.35268 .20502 Mdot
.67833 .75137 Mdot
.22265 .54092 Mdot
.67593 .73801 Mdot
.55191 .81859 Mdot
.32185 .72912 Mdot
.76036 .6297 Mdot
.18012 .42223 Mdot
.76611 .35371 Mdot
.22222 .59029 Mdot
.4089 .47644 Mdot
.46148 .41608 Mdot
.23983 .68617 Mdot
.46031 .72093 Mdot
.2688 .27823 Mdot
.52006 .34004 Mdot
.57425 .70634 Mdot
.50292 .54349 Mdot
.5378 .61515 Mdot
.67224 .54273 Mdot
.58106 .77966 Mdot
.54344 .83989 Mdot
.47138 .68697 Mdot
.21854 .69175 Mdot
.32036 .68214 Mdot
.60022 .16087 Mdot
.50523 .29856 Mdot
.60803 .68033 Mdot
.39605 .32069 Mdot
.77904 .39253 Mdot
.75987 .56274 Mdot
.51748 .58099 Mdot
.72059 .39942 Mdot
.27475 .41776 Mdot
.55413 .65872 Mdot
.44613 .65039 Mdot
.56015 .26904 Mdot
.77623 .55046 Mdot
.3112 .31798 Mdot
.57443 .79578 Mdot
.55485 .51814 Mdot
.65162 .59339 Mdot
.64322 .30289 Mdot
.83596 .37211 Mdot
.2428 .51952 Mdot
.46598 .81684 Mdot
.67171 .53721 Mdot
.63159 .70908 Mdot
.53582 .20101 Mdot
.27373 .46044 Mdot
.77987 .39013 Mdot
.82378 .49079 Mdot
.37193 .81447 Mdot
.84158 .50337 Mdot
.51221 .64745 Mdot
.43758 .57531 Mdot
.45719 .8049 Mdot
.26778 .60383 Mdot
.32491 .33747 Mdot
.80098 .60892 Mdot
.37389 .3546 Mdot
.51864 .62929 Mdot
.59381 .22294 Mdot
.46287 .69428 Mdot
.19232 .48525 Mdot
.38839 .35886 Mdot
.36417 .58918 Mdot
.34153 .16565 Mdot
.73907 .71089 Mdot
.72172 .60776 Mdot
.52952 .85814 Mdot
.72461 .52803 Mdot
.21665 .49944 Mdot
.65541 .47531 Mdot
.70528 .75938 Mdot
.56046 .66715 Mdot
.82054 .66182 Mdot
.64349 .79219 Mdot
.35962 .2224 Mdot
.1286 .39571 Mdot
.7414 .36037 Mdot
.54449 .54844 Mdot
.46319 .4384 Mdot
.24075 .42029 Mdot
.41825 .19306 Mdot
.3173 .25047 Mdot
.76964 .45347 Mdot
.21823 .65315 Mdot
.70995 .74824 Mdot
.24297 .58036 Mdot
.19494 .55827 Mdot
.57393 .20612 Mdot
.4984 .43148 Mdot
.53235 .60857 Mdot
.5095 .31604 Mdot
.65354 .72892 Mdot
.82287 .58135 Mdot
.26905 .56515 Mdot
.14774 .39855 Mdot
.39371 .36692 Mdot
.4548 .28231 Mdot
.47313 .83519 Mdot
.27902 .38755 Mdot
.25776 .57518 Mdot
.68284 .25156 Mdot
.46246 .57776 Mdot
.71922 .28465 Mdot
.6942 .69707 Mdot
.62573 .33962 Mdot
.75618 .33989 Mdot
.666 .65505 Mdot
.28758 .7193 Mdot
.46913 .7912 Mdot
.78568 .4022 Mdot
.52382 .6437 Mdot
.26055 .45324 Mdot
.24074 .53859 Mdot
.51898 .86052 Mdot
.60684 .28717 Mdot
.43575 .87168 Mdot
.57092 .23547 Mdot
.33685 .51609 Mdot
.44162 .62333 Mdot
.32864 .49072 Mdot
.25483 .48096 Mdot
.44474 .56754 Mdot
.76306 .47552 Mdot
.50403 .86043 Mdot
.30128 .6784 Mdot
.62586 .35332 Mdot
.80219 .51178 Mdot
.39362 .83971 Mdot
.37528 .7727 Mdot
.49025 .25273 Mdot
.28481 .54309 Mdot
.7174 .24597 Mdot
.54154 .36266 Mdot
.24069 .57997 Mdot
.63081 .48698 Mdot
.42056 .23446 Mdot
.53687 .75912 Mdot
.39522 .21283 Mdot
.50278 .86082 Mdot
.62496 .24085 Mdot
.53746 .23602 Mdot
.27636 .33443 Mdot
.18183 .4812 Mdot
.80504 .54278 Mdot
.42086 .4938 Mdot
.56317 .58558 Mdot
.37789 .35361 Mdot
.37735 .7499 Mdot
.25284 .60511 Mdot
.409 .2968 Mdot
.36475 .60505 Mdot
.33106 .27676 Mdot
.50021 .40638 Mdot
.59192 .48796 Mdot
.86626 .49397 Mdot
.4524 .59468 Mdot
.75395 .40096 Mdot
.3401 .78918 Mdot
.23975 .46957 Mdot
.47477 .83004 Mdot
.64837 .61393 Mdot
.83648 .50545 Mdot
.61574 .80636 Mdot
.39946 .27648 Mdot
.7823 .66351 Mdot
.50283 .87335 Mdot
.83386 .46928 Mdot
.39967 .63162 Mdot
.68065 .52013 Mdot
.89493 .52775 Mdot
.50241 .35408 Mdot
.80181 .47095 Mdot
.27424 .63465 Mdot
.64249 .38781 Mdot
.5193 .67553 Mdot
.38281 .46819 Mdot
.53289 .50933 Mdot
.61534 .70687 Mdot
.40614 .6098 Mdot
.85028 .43067 Mdot
.81931 .45556 Mdot
.84836 .46761 Mdot
.28919 .74787 Mdot
.78101 .6693 Mdot
.50459 .50056 Mdot
.46561 .7109 Mdot
.47498 .49582 Mdot
.41285 .50408 Mdot
.33718 .43731 Mdot
.73797 .35735 Mdot
.37221 .2447 Mdot
.75139 .55651 Mdot
.52712 .62222 Mdot
.76314 .65544 Mdot
.80649 .2775 Mdot
.33849 .69474 Mdot
.34063 .65902 Mdot
.75308 .35541 Mdot
.25705 .49666 Mdot
.66939 .71875 Mdot
.35966 .23685 Mdot
.49657 .85089 Mdot
.4889 .53619 Mdot
.24018 .61411 Mdot
.42439 .32377 Mdot
.20632 .40536 Mdot
.45089 .37664 Mdot
.59552 .79416 Mdot
.45995 .45629 Mdot
.45962 .20844 Mdot
.59781 .56635 Mdot
.36701 .21179 Mdot
.43625 .25456 Mdot
.66798 .32982 Mdot
.22983 .58105 Mdot
.73981 .43337 Mdot
.26038 .51828 Mdot
.5303 .47874 Mdot
.39692 .4541 Mdot
.46806 .43415 Mdot
.25716 .52558 Mdot
.21469 .39295 Mdot
.81825 .59507 Mdot
.50236 .88215 Mdot
.80528 .34438 Mdot
.22938 .70557 Mdot
.69334 .68973 Mdot
.45578 .55043 Mdot
.45327 .84491 Mdot
.85128 .51781 Mdot
.61278 .81459 Mdot
.63651 .25841 Mdot
.59107 .40987 Mdot
.70205 .45865 Mdot
.80821 .35801 Mdot
.44101 .3516 Mdot
.5234 .82611 Mdot
.73273 .28782 Mdot
.66295 .53015 Mdot
.55105 .17876 Mdot
.81148 .44961 Mdot
.53314 .74656 Mdot
.35739 .62967 Mdot
.46276 .55966 Mdot
.48076 .68291 Mdot
.53617 .67776 Mdot
.63029 .29466 Mdot
.2656 .47128 Mdot
.54934 .34668 Mdot
.32507 .40215 Mdot
.5413 .58115 Mdot
.34158 .57134 Mdot
.42643 .42632 Mdot
.56809 .70692 Mdot
.77274 .61739 Mdot
.61308 .44419 Mdot
.8104 .64926 Mdot
.72057 .34366 Mdot
.36056 .60686 Mdot
.24038 .4829 Mdot
.56077 .25388 Mdot
.66583 .23928 Mdot
.63408 .49262 Mdot
.65858 .76771 Mdot
.51185 .42377 Mdot
.26027 .45766 Mdot
.47875 .67523 Mdot
.30141 .72713 Mdot
.37799 .47286 Mdot
.71487 .63209 Mdot
.4434 .76835 Mdot
.5887 .49173 Mdot
.52835 .61188 Mdot
.54135 .60533 Mdot
.34305 .8255 Mdot
.71403 .30232 Mdot
.65222 .32179 Mdot
.64693 .77374 Mdot
.66081 .50566 Mdot
.58688 .6889 Mdot
.32681 .45145 Mdot
.29388 .73013 Mdot
.45766 .7527 Mdot
.48162 .24191 Mdot
.71101 .37497 Mdot
.42447 .2934 Mdot
.66684 .75348 Mdot
.68439 .73863 Mdot
.34402 .20615 Mdot
.55444 .61514 Mdot
.33357 .7567 Mdot
.24247 .64938 Mdot
.56281 .69821 Mdot
.52634 .69001 Mdot
.768 .53517 Mdot
.81902 .61545 Mdot
.61134 .48155 Mdot
.21318 .65513 Mdot
.22201 .40339 Mdot
.6478 .39833 Mdot
.49672 .22286 Mdot
.21528 .56248 Mdot
.63616 .77823 Mdot
.46494 .65123 Mdot
.55116 .74663 Mdot
.33288 .50528 Mdot
.30729 .57171 Mdot
.79216 .31279 Mdot
.48607 .368 Mdot
.48566 .71529 Mdot
.65902 .64751 Mdot
.3946 .58533 Mdot
.83636 .3775 Mdot
.36909 .8004 Mdot
.66851 .23269 Mdot
.71279 .48434 Mdot
.35614 .55301 Mdot
.42902 .50588 Mdot
.28787 .56435 Mdot
.7068 .61696 Mdot
.81537 .48884 Mdot
.2163 .56704 Mdot
.6681 .69136 Mdot
.45314 .66132 Mdot
.75397 .40266 Mdot
.56611 .79787 Mdot
.43151 .82552 Mdot
.56779 .47493 Mdot
.72827 .34587 Mdot
.26812 .35717 Mdot
.23745 .70817 Mdot
.47344 .41308 Mdot
.5081 .51524 Mdot
.75782 .51117 Mdot
.68 .63082 Mdot
.45796 .21815 Mdot
.36853 .51102 Mdot
.5998 .23356 Mdot
.55225 .81634 Mdot
.25296 .28313 Mdot
.46842 .18934 Mdot
.84322 .39154 Mdot
.48927 .77308 Mdot
.6667 .62616 Mdot
.59986 .75373 Mdot
.22635 .29969 Mdot
.45885 .41061 Mdot
.7478 .68559 Mdot
.26919 .34541 Mdot
.65689 .76417 Mdot
.65998 .52534 Mdot
.65323 .56131 Mdot
.8024 .50699 Mdot
.80534 .63661 Mdot
.40109 .78733 Mdot
.59644 .78775 Mdot
.59155 .55814 Mdot
.84225 .57463 Mdot
.77805 .48425 Mdot
.5142 .48778 Mdot
.56241 .30727 Mdot
.6654 .25083 Mdot
.67727 .72613 Mdot
.7381 .65485 Mdot
.23928 .58922 Mdot
.47028 .37831 Mdot
.31249 .47215 Mdot
.52385 .72363 Mdot
.29878 .39808 Mdot
.68152 .64402 Mdot
.24026 .48159 Mdot
.55566 .82451 Mdot
.45428 .3979 Mdot
.54318 .2434 Mdot
.74877 .40141 Mdot
.18788 .56485 Mdot
.7116 .61176 Mdot
.70588 .29325 Mdot
.47128 .81885 Mdot
.44301 .27083 Mdot
.22866 .53781 Mdot
.50703 .9147 Mdot
.21634 .60985 Mdot
.78495 .57757 Mdot
.82287 .57885 Mdot
.46004 .83112 Mdot
.7823 .59783 Mdot
.43448 .18617 Mdot
.29083 .60414 Mdot
.30751 .4544 Mdot
.40516 .55207 Mdot
.86205 .4933 Mdot
.28676 .41847 Mdot
.82938 .57343 Mdot
.42478 .846 Mdot
.4895 .68937 Mdot
.34423 .57526 Mdot
.51043 .38507 Mdot
.554 .27679 Mdot
.31071 .40233 Mdot
.56761 .75599 Mdot
.2892 .61208 Mdot
.71525 .35781 Mdot
.57358 .31744 Mdot
.44258 .36203 Mdot
.57548 .73105 Mdot
.70147 .31774 Mdot
.6961 .63254 Mdot
.35333 .4134 Mdot
.57162 .51203 Mdot
.25334 .51326 Mdot
.41257 .64785 Mdot
.53026 .74898 Mdot
.40347 .21029 Mdot
.52994 .43618 Mdot
.52787 .33548 Mdot
.52529 .77338 Mdot
.22435 .65272 Mdot
.68294 .66279 Mdot
.82946 .50839 Mdot
.65261 .24055 Mdot
.43771 .46198 Mdot
.26186 .53204 Mdot
.39833 .20274 Mdot
.19515 .40695 Mdot
.77822 .62457 Mdot
.46233 .63198 Mdot
.20232 .49226 Mdot
.53586 .57301 Mdot
.7533 .70941 Mdot
.22577 .59531 Mdot
.26128 .63739 Mdot
.50423 .31015 Mdot
.44922 .72705 Mdot
.5025 .69563 Mdot
.25973 .38894 Mdot
.58274 .52973 Mdot
.61569 .16752 Mdot
.55626 .70782 Mdot
.82357 .33383 Mdot
.69226 .47048 Mdot
.60334 .19907 Mdot
.26305 .33818 Mdot
.52916 .47446 Mdot
.58763 .5392 Mdot
.72298 .62446 Mdot
.72431 .55161 Mdot
.25264 .71309 Mdot
.31767 .23932 Mdot
.49984 .3893 Mdot
.19906 .53651 Mdot
.17528 .53012 Mdot
.55262 .77159 Mdot
.38804 .60317 Mdot
.21301 .60957 Mdot
.48548 .38951 Mdot
.37624 .24148 Mdot
.43394 .83818 Mdot
.72263 .65628 Mdot
.32221 .5695 Mdot
.25891 .49039 Mdot
.74075 .69123 Mdot
.61627 .80145 Mdot
.50105 .17434 Mdot
.69447 .69639 Mdot
.68679 .51636 Mdot
.50691 .49228 Mdot
.62217 .76577 Mdot
.21662 .47502 Mdot
.643 .5812 Mdot
.23767 .53926 Mdot
.74166 .23944 Mdot
.81427 .50625 Mdot
.81497 .48883 Mdot
.22306 .49981 Mdot
.58303 .62398 Mdot
.77958 .503 Mdot
.25431 .56931 Mdot
.73042 .6424 Mdot
.25496 .70095 Mdot
.24428 .54868 Mdot
.33101 .20262 Mdot
.29378 .69071 Mdot
.52982 .40429 Mdot
.50683 .69431 Mdot
.30351 .69209 Mdot
.70046 .50797 Mdot
.32327 .4364 Mdot
.6612 .65843 Mdot
.70137 .46575 Mdot
.68621 .64365 Mdot
.66963 .60525 Mdot
.26833 .65735 Mdot
.47168 .7516 Mdot
.67505 .69095 Mdot
.51857 .79213 Mdot
.62614 .65541 Mdot
.41765 .22834 Mdot
.58689 .33337 Mdot
.65396 .66651 Mdot
.5417 .30805 Mdot
.48159 .55198 Mdot
.58307 .48795 Mdot
.38993 .43244 Mdot
.79409 .33552 Mdot
.37384 .35091 Mdot
.60022 .64568 Mdot
.63087 .19787 Mdot
.5769 .7032 Mdot
.85507 .45315 Mdot
.37442 .22831 Mdot
.47257 .67269 Mdot
.40938 .27167 Mdot
.40682 .32053 Mdot
.47405 .14126 Mdot
.54366 .72089 Mdot
.51532 .29739 Mdot
.6127 .63406 Mdot
.57444 .62596 Mdot
.73368 .3839 Mdot
.57291 .32278 Mdot
.33796 .62889 Mdot
.74724 .4771 Mdot
.46042 .47688 Mdot
.60962 .64345 Mdot
.56151 .42067 Mdot
.28932 .49701 Mdot
.8143 .6278 Mdot
.53941 .32882 Mdot
.69677 .21844 Mdot
.33444 .51541 Mdot
.43671 .78701 Mdot
.48707 .85537 Mdot
.52739 .1763 Mdot
.59252 .28854 Mdot
.15758 .47682 Mdot
.33838 .51616 Mdot
.67718 .6962 Mdot
.5533 .66352 Mdot
.25368 .62815 Mdot
.34751 .35127 Mdot
.23776 .44886 Mdot
.68857 .45295 Mdot
.46197 .20934 Mdot
.69422 .31572 Mdot
.59397 .62978 Mdot
.71772 .67486 Mdot
.31867 .73457 Mdot
.66971 .56532 Mdot
.48774 .40783 Mdot
.54883 .76872 Mdot
.46458 .74815 Mdot
.61076 .64598 Mdot
.82205 .52832 Mdot
.23749 .61704 Mdot
.7234 .75183 Mdot
.32599 .49862 Mdot
.50448 .28278 Mdot
.74879 .50965 Mdot
.69962 .64541 Mdot
.38874 .64063 Mdot
.50289 .85397 Mdot
.26892 .45534 Mdot
.75822 .49066 Mdot
.27074 .50329 Mdot
.43422 .48393 Mdot
.55918 .50325 Mdot
.63523 .28339 Mdot
.39103 .17563 Mdot
.31687 .60047 Mdot
.54066 .19499 Mdot
.47185 .62523 Mdot
.75261 .39348 Mdot
.59319 .71707 Mdot
.59476 .38817 Mdot
.46183 .72828 Mdot
.59964 .28291 Mdot
.73986 .72652 Mdot
.4993 .85364 Mdot
.70579 .51404 Mdot
.72845 .39158 Mdot
.63504 .64393 Mdot
.32361 .51575 Mdot
.61111 .55989 Mdot
.43682 .56832 Mdot
.57243 .72272 Mdot
.55235 .17507 Mdot
.724 .63927 Mdot
.45367 .51504 Mdot
.74356 .71299 Mdot
.698 .76449 Mdot
.83848 .57699 Mdot
.18788 .49077 Mdot
.53115 .65343 Mdot
.8386 .45778 Mdot
.36419 .65122 Mdot
.56652 .82562 Mdot
.76891 .63457 Mdot
.36571 .83811 Mdot
.55755 .75239 Mdot
.65222 .63225 Mdot
.32695 .23867 Mdot
.70434 .57119 Mdot
.40243 .82469 Mdot
.496 .45935 Mdot
.64934 .34273 Mdot
.40327 .82918 Mdot
.38247 .15076 Mdot
.43779 .63311 Mdot
.65942 .60049 Mdot
.52508 .5604 Mdot
.65676 .66543 Mdot
.48105 .26863 Mdot
.4211 .50954 Mdot
.72052 .4195 Mdot
.51529 .22605 Mdot
.25022 .52242 Mdot
.31353 .47042 Mdot
.47843 .27056 Mdot
.32117 .40855 Mdot
.27969 .49692 Mdot
.22084 .5889 Mdot
.54997 .75894 Mdot
.34742 .63203 Mdot
.33936 .50442 Mdot
.58486 .71927 Mdot
.33582 .38391 Mdot
.60581 .3312 Mdot
.43443 .54645 Mdot
.59985 .2903 Mdot
.69453 .56332 Mdot
.8457 .40533 Mdot
.61847 .37445 Mdot
.33582 .77474 Mdot
.55472 .70349 Mdot
.71012 .62194 Mdot
.51676 .80185 Mdot
.59029 .21327 Mdot
.46713 .30287 Mdot
.26885 .56494 Mdot
.7174 .72763 Mdot
.75632 .34199 Mdot
.27791 .70058 Mdot
.79335 .37804 Mdot
.70524 .48777 Mdot
.35494 .61507 Mdot
.51796 .54663 Mdot
.63547 .24976 Mdot
.54293 .60901 Mdot
.65541 .63403 Mdot
.48548 .32779 Mdot
.73428 .31341 Mdot
.34464 .7937 Mdot
.309 .72928 Mdot
.52991 .7152 Mdot
.69044 .73766 Mdot
.55824 .35519 Mdot
.24213 .62746 Mdot
.62722 .57965 Mdot
.47609 .30396 Mdot
.78287 .42358 Mdot
.7922 .6698 Mdot
.60649 .55568 Mdot
.27101 .41061 Mdot
.37783 .57599 Mdot
.38261 .67263 Mdot
.72904 .62935 Mdot
.40064 .37847 Mdot
.69143 .33304 Mdot
.59093 .64822 Mdot
.67066 .31374 Mdot
.43758 .38918 Mdot
.30734 .44734 Mdot
.61679 .65208 Mdot
.27758 .61142 Mdot
.33192 .33337 Mdot
.73825 .46945 Mdot
.42683 .60019 Mdot
.25754 .4209 Mdot
.18957 .4782 Mdot
.37328 .62274 Mdot
.67321 .72215 Mdot
.53807 .76621 Mdot
.27653 .7101 Mdot
.69683 .6629 Mdot
.78465 .61471 Mdot
.72693 .55367 Mdot
.47933 .73098 Mdot
.59657 .25141 Mdot
.4391 .57527 Mdot
.59647 .38941 Mdot
.59336 .68687 Mdot
.59241 .76848 Mdot
.47844 .7725 Mdot
.26519 .39315 Mdot
.54337 .46268 Mdot
.50018 .80486 Mdot
.52878 .44882 Mdot
.46911 .84743 Mdot
.70661 .57129 Mdot
.26773 .46854 Mdot
.63353 .51396 Mdot
.26213 .34468 Mdot
.42008 .19659 Mdot
.67503 .77073 Mdot
.37851 .21456 Mdot
.55479 .53997 Mdot
.54408 .19131 Mdot
.78576 .54349 Mdot
.41723 .83884 Mdot
.27523 .47179 Mdot
.60865 .55356 Mdot
.3203 .4693 Mdot
.69861 .52222 Mdot
.55329 .43606 Mdot
.58116 .39285 Mdot
.34198 .63813 Mdot
.68351 .37098 Mdot
.58316 .26179 Mdot
.36153 .47078 Mdot
.78434 .44759 Mdot
.70495 .73258 Mdot
.26586 .63235 Mdot
.49515 .43662 Mdot
.39024 .25227 Mdot
.30413 .44159 Mdot
.19748 .68898 Mdot
.83613 .37048 Mdot
.37856 .57774 Mdot
.47044 .43164 Mdot
.25452 .44103 Mdot
.50186 .38458 Mdot
.31749 .62956 Mdot
.56682 .77453 Mdot
.69306 .48388 Mdot
.58267 .40915 Mdot
.72464 .30032 Mdot
.7316 .61748 Mdot
.28631 .37347 Mdot
.76933 .44033 Mdot
.85327 .41906 Mdot
.22749 .67415 Mdot
.70944 .64426 Mdot
.24696 .75033 Mdot
.62278 .26513 Mdot
.52529 .6069 Mdot
.45486 .80717 Mdot
.82021 .59383 Mdot
.2372 .47731 Mdot
.45311 .22697 Mdot
.79967 .57671 Mdot
.2725 .45992 Mdot
.24775 .56892 Mdot
.74839 .39933 Mdot
.67706 .31883 Mdot
.53405 .49703 Mdot
.40826 .32177 Mdot
.80471 .413 Mdot
.46788 .65736 Mdot
.71976 .71509 Mdot
.51667 .22356 Mdot
.30648 .21637 Mdot
.70693 .75865 Mdot
.3412 .4278 Mdot
.48375 .26078 Mdot
.44239 .80544 Mdot
.21729 .43198 Mdot
.26983 .59782 Mdot
.41191 .21844 Mdot
.44266 .74992 Mdot
.38313 .29834 Mdot
.53401 .20799 Mdot
.25997 .51953 Mdot
.30111 .68587 Mdot
.60367 .55246 Mdot
.52399 .76046 Mdot
.72855 .36749 Mdot
.22909 .50395 Mdot
.55642 .40742 Mdot
.23067 .40924 Mdot
.53245 .77453 Mdot
.49474 .81372 Mdot
.62804 .59834 Mdot
.40869 .14375 Mdot
.78376 .62933 Mdot
.58276 .21333 Mdot
.44671 .56979 Mdot
.76144 .70931 Mdot
.62859 .59088 Mdot
.79812 .59512 Mdot
.30526 .7519 Mdot
.59156 .36812 Mdot
.72868 .53215 Mdot
.43977 .57197 Mdot
.72053 .69035 Mdot
.48943 .71577 Mdot
.31187 .70218 Mdot
.47626 .21659 Mdot
.24435 .47859 Mdot
.49803 .24817 Mdot
.24971 .38919 Mdot
.34131 .5986 Mdot
.60091 .68106 Mdot
.85136 .48073 Mdot
.55794 .54983 Mdot
.47903 .55178 Mdot
.31099 .54274 Mdot
.34076 .22604 Mdot
.18098 .60379 Mdot
.32212 .5123 Mdot
.76685 .36212 Mdot
.24017 .57001 Mdot
.429 .46373 Mdot
.46801 .63894 Mdot
.09021 .47458 Mdot
.51776 .87095 Mdot
.53419 .62542 Mdot
.29373 .63265 Mdot
.21204 .52026 Mdot
.81779 .60472 Mdot
.42553 .32138 Mdot
.59021 .31631 Mdot
.26044 .29393 Mdot
.21027 .44795 Mdot
.33682 .54024 Mdot
.32617 .779 Mdot
.66101 .77783 Mdot
.49007 .21377 Mdot
.73469 .72314 Mdot
.47843 .58869 Mdot
.41854 .49467 Mdot
.1155 .56034 Mdot
.62463 .77011 Mdot
.46349 .57339 Mdot
.34478 .22005 Mdot
.52949 .60958 Mdot
.41766 .55789 Mdot
.75871 .4276 Mdot
.22697 .5807 Mdot
.26157 .52348 Mdot
.80635 .63488 Mdot
.56419 .61245 Mdot
.5961 .28341 Mdot
.69346 .49222 Mdot
.58521 .53572 Mdot
.35982 .48924 Mdot
.64844 .48762 Mdot
.41199 .45299 Mdot
.6495 .64508 Mdot
.69712 .51464 Mdot
.19775 .5544 Mdot
.41805 .86355 Mdot
.49773 .7649 Mdot
.72103 .47117 Mdot
.34835 .466 Mdot
.29758 .69478 Mdot
.31439 .40521 Mdot
.4807 .49356 Mdot
.39351 .83079 Mdot
.63296 .85578 Mdot
.65571 .34778 Mdot
.29823 .5229 Mdot
.61589 .64949 Mdot
.36083 .63733 Mdot
.52279 .7346 Mdot
.64755 .44346 Mdot
.56745 .33734 Mdot
.33667 .57021 Mdot
.34389 .60034 Mdot
.68999 .4549 Mdot
.80616 .31829 Mdot
.3942 .5071 Mdot
.45169 .64359 Mdot
.57434 .81932 Mdot
.42108 .22695 Mdot
.41297 .77998 Mdot
.36107 .50337 Mdot
.77471 .5033 Mdot
.61287 .55407 Mdot
.64122 .71513 Mdot
.5455 .24414 Mdot
.7763 .6646 Mdot
.47349 .77269 Mdot
.51419 .69896 Mdot
.39537 .51558 Mdot
.33328 .38708 Mdot
.66361 .59134 Mdot
.80702 .56856 Mdot
.4631 .62156 Mdot
.59334 .81813 Mdot
.58833 .3684 Mdot
.69904 .37914 Mdot
.45227 .48266 Mdot
.84196 .53593 Mdot
.50931 .19469 Mdot
.5016 .71015 Mdot
.64206 .21902 Mdot
.67926 .27444 Mdot
.29843 .40037 Mdot
.51494 .3884 Mdot
.44006 .49751 Mdot
.57166 .61373 Mdot
.86293 .43325 Mdot
.80845 .55901 Mdot
.63347 .4283 Mdot
.67075 .33456 Mdot
.43503 .68348 Mdot
.60885 .57105 Mdot
.32759 .82107 Mdot
.44206 .33416 Mdot
.85137 .40951 Mdot
.25597 .63479 Mdot
.58171 .73506 Mdot
.66738 .63651 Mdot
.41737 .62445 Mdot
.52964 .34128 Mdot
.80569 .62298 Mdot
.35547 .60794 Mdot
.57282 .22739 Mdot
.34589 .52106 Mdot
.6885 .24592 Mdot
.58849 .44002 Mdot
.73542 .40522 Mdot
.73793 .43148 Mdot
.43622 .18715 Mdot
.53749 .81165 Mdot
.60097 .48197 Mdot
.27785 .77119 Mdot
.6065 .75623 Mdot
.65926 .76811 Mdot
.47187 .24412 Mdot
.48797 .16445 Mdot
.74472 .65064 Mdot
.67768 .68291 Mdot
.61526 .43412 Mdot
.44343 .43984 Mdot
.6525 .24625 Mdot
.41299 .45615 Mdot
.68241 .58829 Mdot
.6843 .52896 Mdot
.73487 .80782 Mdot
.35398 .43513 Mdot
.52485 .58744 Mdot
.60409 .24455 Mdot
.69016 .75049 Mdot
.38976 .41647 Mdot
.35622 .80921 Mdot
.46326 .41661 Mdot
.41126 .48976 Mdot
.46536 .75962 Mdot
.26148 .6254 Mdot
.6764 .25462 Mdot
.52545 .13556 Mdot
.23271 .67791 Mdot
.684 .35891 Mdot
.57238 .50241 Mdot
.56192 .69711 Mdot
.51645 .66966 Mdot
.40613 .28897 Mdot
.30446 .77551 Mdot
.65086 .63529 Mdot
.62241 .7664 Mdot
.45736 .14596 Mdot
.26674 .67278 Mdot
.81948 .60624 Mdot
.77042 .60459 Mdot
.56648 .71525 Mdot
.33686 .41773 Mdot
.31651 .32012 Mdot
.72052 .42324 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0:Oooooo0_l0002Pooooo`007?ooool0
0ol0003oooooooooo`2Fooooo`;o00003oooool2o`000:3ooooo000Looooo`03o`000?oooooooooo
087ooooo0_l0000Cooooo`;o00005?ooool2o`0009_ooooo000Looooo`03o`000?oooooooooo087o
oooo0_l0000>ooooo`Co00001oooool2o`0000kooooo0_l0002Kooooo`007?ooool00ol0003ooooo
ooooo`1iooooo`;o00005_ooool4o`0000Oooooo0_l0002[ooooo`007?ooool2o`0007[ooooo0_l0
003>ooooo`007?ooool00ol0003oooooooooo`22ooooo`;o0000=oooool2o`00013ooooo0_l0001j
ooooo`007?ooool00ol0003oooooooooo`22ooooo`;o0000=oooool2o`00013ooooo0_l0001joooo
o`007?ooool00ol0003oooooooooo`2oooooo`;o0000R?ooool001cooooo00?o0000ooooooooool0
Joooool2o`0002kooooo0_l0000Rooooo`;o0000R?ooool001cooooo00?o0000ooooooooool0Jooo
ool2o`0000oooooo0_l0000Mooooo`;o00009oooool2o`0008?ooooo000Looooo`03o`000?oooooo
oooo07Oooooo0_l00003ooooo`;o00003oooool2o`0000Sooooo0_l0000[ooooo`;o0000Poooool0
01cooooo00?o0000ooooooooool0Moooool2o`0001Cooooo0_l00008ooooo`?o00001Oooool2o`00
00?ooooo0_l0000:ooooo`;o00004_ooool2o`0008?ooooo000Looooo`03o`000?oooooooooo07;o
oooo0_l00007ooooo`;o00003_ooool2o`0000_ooooo0_l00005ooooo`;o00000oooool2o`0000;o
oooo0_l00006ooooo`;o0000Uoooool001cooooo00?o0000ooooooooool0L_ooool2o`0000Oooooo
0_l0000>ooooo`;o00006oooool2o`0000Gooooo0_l00002ooooo`;o0000U?ooool001cooooo00?o
0000ooooooooool0Loooool2o`0003[ooooo0_l00002ooooo`;o0000U?ooool001cooooo00?o0000
ooooooooool0Loooool2o`0000Gooooo0_l00003ooooo`;o00002?ooool3o`0000Wooooo0_l00000
0ooooooo0000o`000002o`0000?ooooo0_l00007ooooo`;o00002oooool2o`0009;ooooo000Loooo
o`03o`000?oooooooooo07[ooooo0_l00003ooooo`;o00001oooool4o`0000Sooooo0ol000000ooo
oooo0000o`000004o`000003ooooool0003o000000;o000000?oooooo`000?l000000_ooool2o`00
00_ooooo0_l00004ooooo`;o0000S?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2
ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo07cooooo0_l00006ooooo`;o00000_ooool4
o`0000Oooooo1?l00002ooooo`;o000000?oooooo`000?l000000oooool2o`000004ooooool0003o
0000ooooo`;o00001?ooool2o`0000Sooooo0_l00002ooooo`;o0000S?ooool00006oooooomgMgOo
V9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03
o`000?oooooooooo07cooooo0_l00006ooooo`?o00003?ooool2o`0000Cooooo0_l00007ooooo`Co
000000?oooooo`000?l000000oooool3o`0000Sooooo1?l0002>ooooo`0000?ooooooa0@4?ooool0
0_ooool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0
Moooool2o`0000cooooo0_l00008ooooo`;o00004Oooool4o`0000Kooooo0_l00006ooooo`;o0000
0oooool3o`0000Cooooo0_l00007ooooo`;o0000O_ooool00003ooooool0003ooooo00;ooooo00?o
0000ooooooooool02oooool00onHV9So8B4Qonk^kP06ooooo`?o0000J?ooool2o`0000gooooo0_l0
0005ooooo`;o00003oooool2o`0001Wooooo0_l00008ooooo`;o00001?ooool4o`0000;ooooo0_l0
0007ooooo`;o0000O_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool0
0omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo06Sooooo0_l00002ooooo`;o000000?ooooo
o`000?l000001_ooool2o`0000?ooooo1Ol0000Yooooo`;o00002oooool2o`0000?ooooo0ol0000>
ooooo`;o0000N_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool03Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo06cooooo0_l000000ooooooo0000o`000006oooo
o`;o00000oooool2o`000003ooooool0003o0000017ooooo0_l0000Fooooo`;o00002oooool2o`00
00;ooooo1?l0000>ooooo`;o00001Oooool2o`0007?ooooo00001_ooooooMgMgoiRHV?ooooooV9RH
ogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo05oooooo0_l0
0007ooooo`;o00002Oooool2o`0000Sooooo1?l00004ooooo`;o00001Oooool2o`0000Cooooo0_l0
000Dooooo`Co00003oooool4o`000004ooooool0003o0000o`00017ooooo0_l0001cooooo`0000Ko
ooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0
003oooooooooo`1Oooooo`;o00001oooool2o`0000?ooooo0_l00004ooooo`?o000000?oooooo`00
0?l000001?ooool4o`0000Cooooo0_l00005ooooo`;o00001?ooool2o`0000Oooooo0_l0000;oooo
o`;o00001oooool2o`000003ooooool0003o000000Cooooo1?l000000ooooooo0000o`000002o`00
00Cooooo0_l00020ooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o00002oooool2o`0000Go
oooo0_l000000ooooooo0000o`000004ooooo`;o00000oooool2o`0000;ooooo1?l00003ooooo`;o
00000_ooool2o`0000Cooooo0_l000001?oooooo0000o`000?l0000Dooooo`;o000000?oooooo`00
0?l000001?ooool7o`0000Cooooo1?l0000Fooooo`;o0000J?ooool001cooooo00?o0000oooooooo
ool0H?ooool2o`0000[ooooo0_l00009ooooo`;o00002Oooool2o`0000;ooooo1?l00003ooooo`;o
00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`00000Booooo`;o00001?ooool2o`0000So
oooo1?l00003ooooo`;o00001_ooool2o`00013ooooo0_l0001Xooooo`007?ooool00ol0003ooooo
ooooo`1/ooooo`;o00000oooool2o`0000cooooo0_l0000Kooooo`Co00001?ooool2o`0000Sooooo
0_l00004ooooo`;o00001oooool2o`000003ooooool0003o000000_ooooo0_l0001jooooo`007?oo
ool00ol0003oooooooooo`1[ooooo`;o00001?ooool2o`0000cooooo0_l00004ooooo`;o00000_oo
ool2o`0000Cooooo1?l00009ooooo`Co00001?ooool2o`00013ooooo0_l00005ooooo`;o00004_oo
ool4o`0007Cooooo000Looooo`03o`000?oooooooooo06_ooooo0_l00009ooooo`;o00000oooool2
o`0000Kooooo1?l00002ooooo`;o00001?ooool4o`0000Cooooo0_l0000;ooooo`Co00003_ooool3
o`0000;ooooo0_l00003ooooo`;o00003Oooool6o`000003ooooool0003o0000077ooooo000Loooo
o`03o`000?oooooooooo06Sooooo1Ol00009ooooo`;o00000oooool2o`0000Kooooo0ol0000Aoooo
o`Co00002_ooool3o`0000oooooo0_l00002ooooo`;o00000_ooool3o`0000;ooooo0_l00004oooo
o`Co000000?oooooo`000?l000001?ooool5o`0000Gooooo0_l00007ooooo`;o0000Goooool001co
oooo00?o0000ooooooooool0J?ooool5o`0000Cooooo0_l0000Booooo`;o00004_ooool3o`0000Go
oooo0_l00008ooooo`;o00002Oooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool3o`000004
ooooool0003o0000ooooo`Co00001oooool2o`000003ooooool0003o000000Gooooo0_l00007oooo
o`;o0000Goooool001cooooo00?o0000ooooooooool0Hoooool2o`000003ooooool0003o000000Wo
oooo0_l00009ooooo`;o00001oooool2o`0000?ooooo0_l00009ooooo`;o00000oooool2o`0000Go
oooo0_l00008ooooo`;o00001_ooool2o`000003ooooool0003o000000?ooooo1_l00002ooooo`;o
00000_ooool2o`0000Wooooo1?l0000Gooooo`;o0000F_ooool001cooooo00?o0000ooooooooool0
Hoooool2o`000003ooooool0003o000000Wooooo0_l00003ooooo`;o00001?ooool2o`0000_ooooo
0ol00009ooooo`;o000000Goooooo`000?l0003o0000ooooo`03o`000003ooooool0003o000000;o
00000oooool2o`0000[ooooo0_l00007ooooo`?o000000?oooooo`000?l000001?ooool3o`0000Oo
oooo1_l0000Gooooo`;o0000F_ooool001cooooo00?o0000ooooooooool0LOooool2o`0000;ooooo
1Ol00002ooooo`;o00001oooool3o`000003ooooool0003o000000[ooooo1_l000000ooooooo0000
o`000006o`000003ooooool0003o000000;o00001?ooool2o`000003ooooool0003o000000Wooooo
0_l00003ooooo`;o00001?ooool3o`0000Cooooo0_l000000ooooooo0000o`000006ooooo`;o0000
0_ooool2o`0000Oooooo0_l0001Rooooo`007?ooool00ol0003oooooooooo`1aooooo`;o00000_oo
ool2o`000003ooooool0003o000000_ooooo0ol0000:ooooo`;o000000Goooooo`000?l0003o0000
ooooo`02o`0000;ooooo1Ol00003ooooo`;o000000?oooooo`000?l000000oooool2o`000003oooo
ool0003o000000Wooooo0_l00003ooooo`;o00001?ooool2o`0000?ooooo1?l000000ooooooo0000
o`000006ooooo`;o00000_ooool2o`0000Oooooo0_l0001Rooooo`007?ooool2o`0006Cooooo0_l0
000Fooooo`;o00005Oooool2o`0000Wooooo0ol00005ooooo`;o000000?oooooo`000?l000000_l0
000Booooo`;o00001_ooool2o`0000?ooooo0_l00007ooooo`;o00001?ooool3o`0006cooooo000L
ooooo`03o`000?oooooooooo06?ooooo0_l0000Fooooo`;o00003Oooool2o`0000oooooo0_l0000;
ooooo`Co00000_ooool3o`000003ooooool0003o000000[ooooo0_l0000;ooooo`;o00001oooool2
o`0000;ooooo1ol0001Zooooo`007?ooool00ol0003oooooooooo`1Jooooo`;o00004_ooool2o`00
00;ooooo0_l0000Fooooo`;o00003oooool2o`0000gooooo1ol000000ooooooo0000o`00000Foooo
o`?o00002oooool2o`0000?ooooo0_l0000?ooooo`;o0000FOooool001cooooo00?o0000oooooooo
ool0F_ooool2o`0001;ooooo0_l00002ooooo`;o00000oooool2o`0001Kooooo0_l00008ooooo`;o
00003oooool6o`00013ooooo0_l00008ooooo`Go00004?ooool4o`0000Cooooo0_l00005ooooo`;o
0000FOooool001cooooo00?o0000ooooooooool0Foooool2o`0000kooooo0_l0000:ooooo`Co0000
1?ooool2o`0000gooooo0ol00008ooooo`;o00003_ooool3o`0000;ooooo0_l0000:ooooo`;o0000
1?ooool2o`0000_ooooo0_l0000@ooooo`Co00001?ooool2o`00063ooooo000Looooo`03o`000?oo
oooooooo05_ooooo0_l0000>ooooo`;o00002oooool3o`0000Cooooo0_l0000=ooooo`;o00001?oo
ool2o`00013ooooo0_l000001?oooooo0000o`000?l0000<ooooo`Co00002oooool2o`0001Kooooo
0_l0001Xooooo`007?ooool00ol0003oooooooooo`1cooooo`;o00000oooool2o`0000Gooooo0_l0
000;ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo0ol0000;ooooo`;o000000Co
ooooo`000?l0003ooooo0_l00004ooooo`;o00001?ooool2o`0000Kooooo0_l00005ooooo`;o0000
5_ooool2o`0000Cooooo1?l0001Pooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o00004ooo
ool2o`0000cooooo0_l00009ooooo`;o00000oooool2o`0000Gooooo1Ol00009ooooo`?o00000ooo
ool2o`0000Cooooo1?l0000:ooooo`;o00008oooool4o`00063ooooo000Looooo`03o`000?oooooo
oooo05;ooooo0_l0000:ooooo`;o00002?ooool2o`000003ooooool0003o0000017ooooo0_l00000
0ooooooo0000o`00000@ooooo`;o00001_ooool2o`0000[ooooo0_l00007ooooo`;o00000_ooool3
o`0000Wooooo0_l00002ooooo`;o00004oooool2o`0000Wooooo0_l00002ooooo`;o0000Goooool0
01cooooo00?o0000ooooooooool0D_ooool4o`0001;ooooo0_l000000ooooooo0000o`00000Aoooo
o`;o00002oooool2o`0000Kooooo0_l00009ooooo`;o00002Oooool2o`0000Cooooo0ol00003oooo
o`;o00001?ooool2o`0000?ooooo0_l00002ooooo`Co00004Oooool2o`0000Wooooo1_l0000Hoooo
o`;o0000AOooool001cooooo00?o0000ooooooooool0C_ooool2o`0000;ooooo1?l0000Booooo`;o
00008Oooool2o`0000?ooooo0_l0000<ooooo`Co00001oooool2o`0000Cooooo0_l00006ooooo`;o
00000_ooool3o`000004ooooool0003o0000o`0000Cooooo0_l00009ooooo`;o00000_ooool2o`00
00oooooo0_l0000Jooooo`;o0000AOooool001cooooo00?o0000ooooooooool0C_ooool2o`0000;o
oooo0_l0000looooo`;o00000oooool2o`0000Wooooo0_l0000Booooo`;o000000?oooooo`000?l0
00000_ooool8o`0000Sooooo0_l00004ooooo`;o00000_ooool2o`0000oooooo1?l0001Oooooo`00
7?ooool00ol0003oooooooooo`20ooooo`;o00002?ooool2o`0000Wooooo0_l0000>ooooo`;o0000
3Oooool2o`0000Oooooo0ol000000ooooooo0000o`000008ooooo`;o00002?ooool3o`0000kooooo
2?l0001Kooooo`007?ooool00ol0003oooooooooo`20ooooo`;o00002?ooool2o`0000gooooo0_l0
0007ooooo`;o000000?oooooo`000?l000002_ooool2o`0000Oooooo0_l000000ooooooo0000o`00
0006o`00017ooooo0_l0000?ooooo`;o000000?oooooo`000?l000000_l0001Kooooo`007?ooool0
0ol0003oooooooooo`1Aooooo`;o00006_ooool2o`0001Oooooo0_l0000Aooooo`;o00001oooool4
o`0000?ooooo0_l00006ooooo`?o00001_ooool2o`000003ooooool0003o000000Ko00001?ooool2
o`0001Kooooo0_l00009ooooo`;o0000Foooool001cooooo00?o0000ooooooooool0D?ooool3o`00
01[ooooo0_l0000:ooooo`;o00001_ooool2o`0000?ooooo0_l0000Hooooo`;o00000_ooool2o`00
00?ooooo3?l00008ooooo`;o00002_ooool3o`0000[ooooo0_l00009ooooo`;o00000oooool4o`00
00;ooooo0_l000000ooooooo0000o`00001Hooooo`007?ooool2o`0003cooooo0_l00009ooooo`;o
00002?ooool2o`0002Oooooo0_l00006ooooo`;o00007Oooool2o`0000;ooooo0_l00003ooooo`go
00005?ooool4o`0000Sooooo0_l0000>ooooo`Co00001Oooool2o`0005Sooooo000Looooo`03o`00
0?oooooooooo03_ooooo0_l00009ooooo`;o00001oooool2o`0004?ooooo0_l000000ooooooo0000
o`00000@ooooo`go00000oooool2o`0000oooooo1Ol00007ooooo`;o00003?ooool6o`0005oooooo
000Looooo`03o`000?oooooooooo04gooooo1?l00013ooooo`;o000000?oooooo`000?l000004?oo
ool>o`0000;ooooo0ol0000>ooooo`Go00005Oooool5o`00063ooooo000Looooo`03o`000?oooooo
oooo04Wooooo0_l00002ooooo`;o0000A?ooool2o`0000_ooooo0_l00007ooooo`ko00000_ooool3
o`0000Cooooo0_l00009ooooo`;o0000<oooool2o`0004Oooooo000Looooo`03o`000?oooooooooo
04Wooooo1?l0000Jooooo`;o0000:_ooool2o`0000_ooooo0_l00004oooooa7o00000_ooool3o`00
00Cooooo0_l000000ooooooo0000o`000002ooooo`;o00003Oooool2o`0000[ooooo0_l00007oooo
o`;o000000?oooooo`000?l000003_ooool4o`0004Oooooo000Looooo`03o`000?oooooooooo03Wo
oooo0_l0000@ooooo`;o00005oooool6o`0001_ooooo0_l0000Kooooo`;o000000?oooooo`000?l0
00005ol00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000gooooo0_l00006ooooo`;o
00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`000003o`0000;ooooo0_l0000:ooooo`;o
0000BOooool001cooooo00?o0000ooooooooool0>Oooool2o`0000_ooooo0ol0000Hooooo`Wo0000
6oooool2o`0000gooooo0_l0000<oooooaWo000000?oooooo`000?l000006_ooool2o`0000Cooooo
1?l00006ooooo`;o00000oooool2o`0000?ooooo0_l0000>ooooo`;o0000AOooool001cooooo00?o
0000ooooooooool0A_ooool3o`0000Sooooo0_l0000>ooooo`Co00000_ooool2o`0000Cooooo0_l0
000<ooooo`Co000000Coooooo`000?l0003o00000oooool2o`0000cooooo0_l0000>ooooo`Wo0000
00?oooooo`000?l000002ol00008ooooo`?o00000oooool2o`0000Gooooo0_l00006ooooo`;o0000
00?oooooo`000?l000000oooool2o`0000gooooo0_l0000Aooooo`;o0000AOooool001cooooo00?o
0000ooooooooool0A_ooool2o`0000Wooooo0_l0000Gooooo`;o000000?oooooo`000?l000000ol0
0009ooooo`Co000000Coooooo`000?l0003o00000oooool2o`0001Cooooo0_l00009ooooo`;o0000
00?oooooo`000?l000003ol00008ooooo`?o00000oooool2o`0000Gooooo0_l00009ooooo`;o0000
4_ooool2o`0000?ooooo0_l00008ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0A_oo
ool2o`0001Gooooo0_l000000ooooooo0000o`000006ooooo`Co00000_ooool4o`0001Cooooo0_l0
0004ooooo`;o00003?ooool4o`0000Gooooo5ol0000:ooooo`;o00004?ooool2o`0001cooooo0_l0
0007ooooo`?o0000BOooool001cooooo00?o0000ooooooooool0GOooool2o`000003ooooool0003o
000000Kooooo0_l00003ooooo`;o00007Oooool2o`0000cooooo0_l00007oooooaOo00001oooool2
o`0000gooooo0_l00003ooooo`Go00002_ooool2o`0001Oooooo0_l0001:ooooo`007?ooool00ol0
003oooooooooo`1Fooooo`;o00004?ooool2o`000003ooooool0003o000000So00000_ooool2o`00
01?ooooo0_l0000EoooooaOo000000?oooooo`000?l000001?ooool2o`000003ooooool0003o0000
00[ooooo0ol00002ooooo`Go00000oooool2o`0000Gooooo0_l00005ooooo`;o00004Oooool4o`00
00Kooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0looooo`;o00005?ooool2o`0000;o
oooo0_l0000<ooooo`Wo000000?oooooo`000?l000001_l000000ooooooo0000o`000009ooooo`;o
00002?ooool2o`0001Cooooo5ol00002ooooo`;o00001oooool2o`0000_ooooo0_l00002ooooo`?o
00001Oooool2o`0000cooooo0_l0000Aooooo`Co00001_ooool2o`0003oooooo000Looooo`03o`00
0?oooooooooo03cooooo0ol00009ooooo`;o00002?ooool2o`00013ooooo2Ol000000ooooooo0000
o`000008o`0000;ooooo0_l00006ooooo`;o00007?oooolAo`0000;ooooo1_l0000<ooooo`Ko0000
2_ooool2o`0000Oooooo0_l000000ooooooo0000o`00000?ooooo`;o0000EOooool001cooooo00?o
0000ooooooooool0?Oooool2o`0000Wooooo0_l00004ooooo`;o000000?oooooo`000?l000004_oo
ool2o`0000;ooooo4ol0000ToooooaSo00003Oooool6o`0000Cooooo0_l00004ooooo`;o00001ooo
ool5o`0000?ooooo0_l00005ooooo`;o00000oooool2o`0000kooooo0_l00015ooooo`007?ooool0
0ol0003oooooooooo`1>ooooo`;o000000Coooooo`000?l0003ooooo0_l0000@oooooaCo000000?o
ooooo`000?l000008oooool5o`000003ooooool0003o0000013o00001?ooool2o`0000Sooooo1?l0
0005ooooo`Co00001oooool2o`0000Cooooo0ol00003ooooo`;o000000?oooooo`000?l000000_oo
ool2o`0000?ooooo1?l0000<ooooo`;o0000AOooool001cooooo0_l0001Booooo`;o000000?ooooo
o`000?l000004?oooolCo`0000;ooooo0_l0000?ooooo`;o00004_oooolFo`0000Kooooo0_l0000:
ooooo`;o00001oooool2o`0000Oooooo0_l00005ooooo`Co00001?ooool2o`0000Gooooo0_l00002
ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0>_ooool2o`00017ooooo0_l00002oooo
o`;o00005?oooolDo`00017ooooo0_l00007ooooo`;o00000oooool2o`000003ooooool0003o0000
01Oo00004_ooool2o`0000oooooo0_l00008ooooo`;o00002oooool3o`0000;ooooo0_l0001Boooo
o`007?ooool00ol0003oooooooooo`0jooooo`;o00003Oooool2o`0000;ooooo0_l0000<ooooo`;o
00000oooool2o`0000Gooooo5?l0000Aooooo`;o00001oooool2o`0000?ooooo0_l000000ooooooo
0000o`00000>o`000003ooooool0003o000000Ko00002Oooool2o`0000Oooooo0_l0000:ooooo`;o
00000oooool2o`0000Wooooo0_l0000;ooooo`;o00000_ooool2o`0005;ooooo000Looooo`03o`00
0?oooooooooo04Gooooo0_l00002ooooo`;o00002?ooool2o`0000Kooooo1?l000000ooooooo0000
o`000004oooooaSo00003Oooool2o`0000kooooo0_l000000ooooooo0000o`000002o`000003oooo
ool0003o0000017o00002Oooool3o`0001;ooooo0_l00004ooooo`;o00002?ooool4o`0000Cooooo
0_l00003ooooo`;o00004?ooool2o`0004Cooooo000Looooo`03o`000?oooooooooo03oooooo0_l0
0004ooooo`;o00002Oooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`Co000000?o
ooooo`000?l000000oooool3o`000003ooooool0003o000000ko000000?oooooo`000?l000000_l0
000=ooooo`?o00003Oooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000003ol0
0006ooooo`;o00001?ooool2o`0001Kooooo1?l00008ooooo`Ko00000_ooool3o`0000Kooooo0_l0
00000ooooooo0000o`000009ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0?oooool2
o`0000oooooo0_l00003ooooo`Co00000_ooool2o`0000?ooooo0ol00002oooooaKo00004Oooool2
o`00017ooooo4ol000000ooooooo0000o`000005ooooo`;o00007?ooool2o`0000[ooooo0_l00002
ooooo`;o00000oooool2o`0000Cooooo1?l000000ooooooo0000o`00001?ooooo`007?ooool00ol0
003oooooooooo`1=ooooo`?o000000Coooooo`000?l0003ooooo1?l00008ooooo`?o00000_oooolF
o`000003ooooool0003o0000017ooooo0_l00009ooooo`;o00000_oooolGo`0000Kooooo0ol0000M
ooooo`;o00002Oooool2o`000003ooooool0003o000000Oooooo0ol00002ooooo`;o00004_ooool2
o`0003cooooo000Looooo`03o`000?oooooooooo04gooooo2ol0000=ooooo`[o000000?oooooo`00
0?l000002?l00002ooooo`;o00003_ooool2o`000003ooooool0003o000000Wooooo0ol000000ooo
oooo0000o`00000;o`000003ooooool0003o000000Go00002?ooool3o`0000;ooooo0_l0000Hoooo
o`?o00000_ooool2o`0000Gooooo0_l000000ooooooo0000o`000007ooooo`;o00000oooool2o`00
00Gooooo0_l0000;ooooo`Co0000>_ooool001cooooo00?o0000ooooooooool0C_ooool6o`0000Go
oooo0_l00009ooooo`;o000000?oooooo`000?l000004Ol0000Booooo`;o00003?ooool3o`0000;o
oooo2_l000000ooooooo0000o`000007o`000003ooooool0003o000000[ooooo0_l00003ooooo`;o
00004oooool2o`0000?ooooo0_l000001?oooooo0000o`000?l0000Iooooo`;o00001Oooool2o`00
00Gooooo0ol0000jooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00000_ooool2o`0000Oo
oooo0_l00006ooooo`;o000000?oooooo`000?l000000ooooolBo`0000?ooooo0_l0000?ooooo`;o
00001?ooool2o`0000Oooooo2ol000000ooooooo0000o`000007o`000003ooooool0003o000000oo
oooo0_l0000Kooooo`?o00004Oooool2o`0000Cooooo1?l00005ooooo`;o00001Oooool2o`0003_o
oooo000Looooo`03o`000?oooooooooo04Sooooo0_l00002ooooo`;o00002oooool4o`0000Cooooo
0_l00005ooooo`Wo000000?oooooo`000?l000001ol00003ooooo`;o00003oooool2o`0000Cooooo
0_l00006ooooo`Co00000_ooool@o`0000;ooooo0_l0000>ooooo`;o00002Oooool2o`0000gooooo
0_l00009ooooo`;o00002_ooool5o`000003ooooool0003o000000;o00001?ooool2o`0000Kooooo
0_l0000kooooo`007?ooool00ol0003oooooooooo`18ooooo`;o00002_ooool2o`0000?ooooo1?l0
000;oooooa?o00004_ooool2o`0000kooooo1?l00002oooooa3o00000_ooool2o`0001Wooooo0_l0
000=ooooo`;o00002Oooool3o`0000[ooooo1?l000000ooooooo0000o`000006ooooo`;o0000@ooo
ool001cooooo00?o0000ooooooooool0;oooool2o`00013ooooo0_l0000Aooooo`;o000000?ooooo
o`000?l000004?oooolBo`0001;ooooo0_l0000?oooooa3o000000Coooooo`000?l0003o00005?oo
ool2o`0000Gooooo0_l0000Hooooo`;o000000Coooooo`000?l0003o0000G?ooool001cooooo00?o
0000ooooooooool0;oooool2o`000003ooooool0003o000000gooooo0_l0000:ooooo`;o00000_oo
ool2o`0000Cooooo0_l0000@oooooaCo00003?ooool3o`000003ooooool0003o000000Sooooo0_l0
00000ooooooo0000o`000002oooooa?o00003?ooool3o`0000Kooooo0_l00005ooooo`;o00006?oo
ool2o`000004ooooool0003o0000o`0000gooooo0_l000000ooooooo0000o`00001:ooooo`0000Ko
ooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Co
oooo00?o0000ooooooooool0<_ooool2o`0000Sooooo0_l00004ooooo`;o00002Oooool2o`0000;o
oooo0ol00009ooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo3ol000001?oooooo
0000o`000?l0000<ooooo`?o000000?oooooo`000?l000002?ooool2o`000003ooooool0003o0000
00;ooooo1Ol000000ooooooo0000o`00000:o`0000Wooooo0_l00002ooooo`?o000000?oooooo`00
0?l000004Oooool2o`0000[ooooo0_l00007ooooo`Co00001?ooool2o`0000Kooooo0ol000000ooo
oooo0000o`00000?ooooo`;o0000>Oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Vooooo`;o00003?ooool2
o`0000Kooooo0_l00002ooooo`Co00003_ooool2o`0000Wooooo0_l000000ooooooo0000o`000002
o`0000;ooooo0_l00003oooooa7o00001_ooool2o`0001[ooooo1Ol000000ooooooo0000o`000002
o`0000;ooooo1_l00009ooooo`;o00001_ooool2o`0000[ooooo0_l00005ooooo`;o00000_ooool2
o`0000Kooooo1Ol00004ooooo`Co00001?ooool2o`0000;ooooo0_l00002ooooo`;o00000_ooool2
o`0000Oooooo0_l00006ooooo`;o0000>Oooool00003ooooool@413ooooo00;ooooo00?o410@oooo
ooooool02Oooool5o`0000Kooooo00?o0000ooooooooool09_ooool2o`0000Cooooo0_l00006oooo
o`;o00002_ooool2o`0000;ooooo0_l0000<ooooo`;o00001Oooool2o`0000;ooooo1?l000000ooo
oooo0000o`000008ooooo`ko000000?oooooo`000?l000001?ooool3o`0000cooooo0_l0000<oooo
o`Go000000?oooooo`000?l000002?ooool2o`0001_ooooo1_l00007ooooo`;o00000_ooool2o`00
00Cooooo0ol000000ooooooo0000o`000007ooooo`;o00001?ooool2o`0000oooooo0_l00011oooo
o`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`00
00Oooooo0ol0000/ooooo`;o00005_ooool4o`000003ooooool0003o000000kooooo0_l00002oooo
o`Ko00000oooool2o`0000Cooooo3?l000000ooooooo0000o`000002o`0000Cooooo0_l0000=oooo
o`;o00002Oooool2o`000003ooooool0003o000000?o00003?ooool2o`0001[ooooo0_l00002oooo
o`;o00002oooool2o`0000Sooooo0_l00004ooooo`;o000000?oooooo`000?l000000_l00008oooo
o`;o00005oooool2o`0003?ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wo
oooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`0]ooooo`;o00004?ooool2o`00
00?ooooo1?l000000ooooooo0000o`000008ooooo`;o00002?ooool3o`000004ooooool0003o0000
o`0000;ooooo0_l00004ooooo`;o00000oooool6o`0000;ooooo0_l0000Oooooo`?o000000?ooooo
o`000?l000001?l00004ooooo`?o00001?ooool2o`0003Kooooo0_l00002ooooo`?o000000?ooooo
o`000?l000000_l00008ooooo`;o00004_ooool2o`0000?ooooo0_l00005ooooo`;o0000;?ooool0
0003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00omgMgOoc<c<o`000007oooo
o`03o`000?oooooooooo02gooooo1?l0000;ooooo`;o000000?oooooo`000?l000000oooool2o`00
0003ooooool0003o000000[ooooo0_l0000=ooooo`;o000000?oooooo`000?l000000_ooool5o`00
00Cooooo0_l0000Dooooo`;o00004?ooool3o`0000;ooooo1Ol00004ooooo`?o00001?ooool4o`00
00Kooooo0_l0000;ooooo`;o000000?oooooo`000?l000000_ooool2o`0001;ooooo1?l00002oooo
o`;o00000_ooool2o`0000Oooooo0_l00006ooooo`;o00004Oooool4o`0000Sooooo0_l0000/oooo
o`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000
ooooooooool0:Oooool2o`0000Cooooo0_l0000;ooooo`?o00001Oooool2o`000003ooooool0003o
000000_ooooo0_l0000?ooooo`;o00000_ooool4o`0001_ooooo0_l00005ooooo`Co00002?ooool2
o`0000;ooooo1_l00007ooooo`;o000000?oooooo`000?l000000_l00006ooooo`;o000000?ooooo
o`000?l000002?ooool2o`000003ooooool0003o000000;ooooo1Ol000001Ooooooo0000o`000?l0
003ooooo00;o00001Oooool7o`0000oooooo0_l00006ooooo`;o00000oooool2o`0000kooooo0_l0
000fooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo
00?o0000ooooooooool0:Oooool2o`0001;ooooo0_l00008ooooo`;o00002oooool2o`0001Wooooo
0_l0000Nooooo`Go00000_ooool2o`0000Sooooo1_l00006ooooo`;o00000oooool2o`0000Wooooo
0_l00002ooooo`;o00003?oooolFo`0000Gooooo0_l0000Aooooo`;o00000oooool3o`0004Gooooo
000Looooo`03o`000?oooooooooo04;ooooo0_l0000Booooo`;o000000?oooooo`000?l000003ooo
ool2o`0000?ooooo0_l0000:ooooo`;o00005Oooool3o`000003ooooool0003o000000Wooooo1Ol0
000;ooooo`;o00003Oooool2o`0000Kooooo0_l000000ooooooo0000o`000002oooooa7o00000_oo
ool2o`0000Gooooo0_l00002ooooo`;o00002Oooool2o`0000Sooooo0_l00015ooooo`007?ooool0
0ol0003oooooooooo`0eooooo`;o00001?ooool2o`0000Gooooo1?l00004ooooo`;o00001?ooool2
o`0000Cooooo0_l000000ooooooo0000o`00000?ooooo`;o00001?ooool2o`0000Wooooo0_l00002
ooooo`;o00001Oooool2o`0000Wooooo1?l0000=ooooo`Ko00002oooool2o`000003ooooool0003o
000000gooooo1Ol000000ooooooo0000o`000009ooooo`;o00001?ooool7o`0000;ooooo1ol00000
0ooooooo0000o`000009ooooo`;o00005oooool2o`0003Kooooo000Looooo`03o`000?oooooooooo
03Gooooo1?l00002ooooo`;o00001oooool2o`0000Cooooo0_l00004ooooo`;o00001Oooool2o`00
01Oooooo0_l00002ooooo`;o00002Oooool2o`0000Gooooo0_l00009ooooo`;o00003oooool9o`00
00;ooooo0_l00004ooooo`;o000000?oooooo`000?l000002?ooool8o`0000Kooooo0_l00006oooo
o`;o00001_ooool>o`0000Oooooo0_l00004ooooo`?o00005Oooool2o`0003Kooooo000Looooo`03
o`000?oooooooooo03Oooooo0_l0000>ooooo`;o00001oooool2o`0000Cooooo0ol0000Booooo`;o
00001oooool2o`0000kooooo0_l000000ooooooo0000o`000009ooooo`;o00000oooool2o`0000[o
oooo2Ol000000ooooooo0000o`00000:ooooo`;o00000_ooool8o`0000?ooooo0ol00003ooooo`;o
00004oooool7o`0000Gooooo0_l000001?oooooo0000o`000?l00004ooooo`Co0000C?ooool001co
oooo00?o0000ooooooooool0@_ooool2o`0000?ooooo1?l00002ooooo`;o000000?oooooo`000?l0
00001?ooool3o`000004ooooool0003o0000o`0000kooooo0_l00007ooooo`;o00000oooool2o`00
00Wooooo0_l000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l000000oooool2o`00
00_ooooo2?l0000;ooooo`_o00001_ooool4o`0001;ooooo0_l00003ooooo`;o00000oooool2o`00
0003ooooool0003o000000;ooooo0_l000001?oooooo0000o`000?l00005ooooo`?o00004oooool2
o`0003Oooooo000Looooo`03o`000?oooooooooo03Sooooo0_l00006ooooo`Go00001?ooool2o`00
00;ooooo0_l00007ooooo`?o000000Coooooo`000?l0003o00000_ooool2o`0001?ooooo0_l00003
ooooo`Co00001oooool2o`0000Oooooo1?l00003ooooo`?o00001oooool3o`0000;ooooo0_l00003
ooooo`Co000000Goooooo`000?l0003o0000ooooo`02o`0000;ooooo2?l00007ooooo`;o00000_oo
ool4o`0000kooooo1_l00008ooooo`Oo00001oooool2o`0000Cooooo0_l00003ooooo`;o00001?oo
ool2o`0000Oooooo0_l00002ooooo`;o0000<oooool001cooooo00?o0000ooooooooool0>?ooool4
o`0000?ooooo0ol000000ooooooo0000o`00000Cooooo`Co00000oooool2o`0000Cooooo0_l00003
ooooo`;o00000oooool2o`0000[ooooo0_l0000@ooooo`;o00001Oooool3o`0000Kooooo1?l00002
ooooo`;o00000oooool@o`000003ooooool0003o000000Cooooo0_l00003ooooo`;o000000?ooooo
o`000?l000001?ooool2o`0000Oooooo0_l00002ooooo`Co00003?ooool5o`0000Oooooo0_l00004
ooooo`;o00000oooool2o`0000Cooooo0_l0000;ooooo`;o0000<oooool001cooooo00?o0000oooo
ooooool0>_ooool2o`0000?ooooo0_l0000Eooooo`Co00001?ooool2o`0000Gooooo0_l00003oooo
o`;o00000oooool2o`000003ooooool0003o000000kooooo0_l00008ooooo`?o00001?ooool4o`00
00Kooooo0_l00004ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000002o`00
0003ooooool0003o000000?o00000_ooool2o`0000;ooooo0_l00002ooooo`;o00001_ooool2o`00
00Cooooo0_l00007ooooo`;o00001Oooool2o`0000[ooooo2?l0001Hooooo`007?ooool00ol0003o
ooooooooo`0iooooo`;o00001?ooool2o`0000[ooooo0_l00002ooooo`;o00001Oooool2o`0000Ko
oooo0ol00009ooooo`;o00001_ooool2o`0000_ooooo0_l000000ooooooo0000o`000008ooooo`;o
00000oooool4o`0000kooooo0_l000000ooooooo0000o`00000?ooooo`;o00000_ooool2o`0000go
oooo0_l00004ooooo`?o00002_ooool3o`0000Wooooo2?l00005ooooo`;o0000DOooool001cooooo
00?o0000ooooooooool0=?ooool2o`0000?ooooo0_l00004ooooo`;o00001?ooool3o`0000?ooooo
0_l00002ooooo`;o00003?ooool4o`0000gooooo0_l00007ooooo`;o00001_ooool2o`00013ooooo
0_l0000Hooooo`?o00004_ooool2o`000004ooooool0003o0000o`0000Cooooo0ol00002ooooo`Co
00001?ooool2o`0000Gooooo0_l0000;ooooo`?o00002?ooool2o`0000?ooooo0_l0000Fooooo`Co
0000<_ooool001cooooo00?o0000ooooooooool0<?ooool2o`0000;ooooo0_l00006ooooo`;o0000
0oooool2o`0000;ooooo0ol00002ooooo`;o00004Oooool2o`000003ooooool0003o000000cooooo
0_l00007ooooo`;o0000;oooool2o`000004ooooool0003o0000o`0000Oooooo0_l00009ooooo`;o
000000Coooooo`000?l0003o00001Oooool2o`0000;ooooo0_l00002ooooo`;o00000_ooool2o`00
00_ooooo0_l00005ooooo`?o00003Oooool2o`0001Kooooo1?l0000booooo`007?ooool2o`00037o
oooo0_l00005ooooo`;o00000oooool2o`000003ooooool0003o000000;o00001oooool2o`0000Co
oooo0_l00008ooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`?o0000>_ooool2o`00
00?ooooo0_l0000;ooooo`;o00007?ooool4o`000004ooooool0003o0000o`0000Wooooo0_l00005
ooooo`;o00003Oooool4o`0000Gooooo0ol00013ooooo`007?ooool00ol0003oooooooooo`0boooo
o`;o00000oooool2o`0000Gooooo0ol00007ooooo`;o00001_ooool3o`000003ooooool0003o0000
00Cooooo0_l00004ooooo`;o00001?ooool3o`0001Cooooo0_l00003ooooo`;o00003oooool2o`00
00Kooooo0_l00006ooooo`;o00001oooool4o`0000Wooooo0ol0000Booooo`;o00001?ooool:o`00
0003ooooool0003o000000_ooooo0_l000000ooooooo0000o`000005ooooo`;o00000_ooool4o`00
00Gooooo1Ol0000:ooooo`;o0000=Oooool001cooooo00?o0000ooooooooool0<_ooool2o`0000[o
oooo0_l00006ooooo`Co00001oooool2o`000003ooooool0003o000000Cooooo0_l00003ooooo`?o
00004?ooool2o`0000Oooooo1?l00003ooooo`;o00003_ooool3o`0000Kooooo0_l0000?ooooo`Co
00002Oooool4o`00017ooooo4?l000001?oooooo0000o`000?l00008ooooo`Co000000?oooooo`00
0?l000001Oooool2o`0000Sooooo0_l00004ooooo`;o00001Oooool2o`0000?ooooo0_l0000eoooo
o`007?ooool00ol0003oooooooooo`16ooooo`;o00002Oooool6o`0000?ooooo0_l00003ooooo`?o
00000_ooool4o`000003ooooool0003o000000Oooooo0_l000000ooooooo0000o`000004ooooo`?o
00001?ooool2o`0000kooooo0_l00002ooooo`;o00001Oooool2o`00013ooooo0_l0000:ooooo`;o
00003oooool3o`000003ooooool0003o0000013o000000?oooooo`000?l000001Oooool2o`00017o
oooo0_l000000ooooooo0000o`000002o`0000Wooooo0_l0000jooooo`007?ooool00ol0003ooooo
ooooo`1<ooooo`;o00001Oooool5o`0000;ooooo0_l00004ooooo`;o00000_ooool4o`000003oooo
ool0003o000000?ooooo0_l00003ooooo`Ko00002Oooool2o`0000Cooooo1?l0000:ooooo`;o0000
1Oooool2o`0000kooooo1?l0000<ooooo`;o00001_ooool2o`0000Gooooo6Ol0000Aooooo`;o0000
1Oooool3o`0000;ooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`0kooooo`?o00003_oo
ool2o`0000Gooooo0_l000000ooooooo0000o`00000<ooooo`;o000000?oooooo`000?l000001?oo
ool3o`0000?ooooo0_l00002ooooo`;o00002Oooool2o`0000?ooooo1Ol00005ooooo`;o00006_oo
ool2o`0000kooooo1?l00004ooooo`;o00001_oooolFo`0000Cooooo0_l00004ooooo`;o00001ooo
ool2o`0000Gooooo0ol0000@ooooo`;o0000=oooool001cooooo00?o0000ooooooooool0>oooool3
o`0000Sooooo0_l00002ooooo`;o00001_ooool3o`0000Kooooo0_l00005ooooo`Co000000?ooooo
o`000?l000000oooool3o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000001oooool7
o`000003ooooool0003o000000Gooooo0_l00003ooooo`;o00003?ooool2o`0001Cooooo1?l00000
0ooooooo0000o`000009oooooaWo00001?ooool2o`0000?ooooo0ol00006ooooo`?o00000_ooool2
o`000003ooooool0003o000000;ooooo0_l00008ooooo`;o00000oooool2o`0003Oooooo000Loooo
o`03o`000?oooooooooo03;ooooo0_l0000Booooo`;o00000_ooool2o`0000Kooooo0ol000000ooo
oooo0000o`000003ooooo`;o00001Oooool4o`0000Kooooo0_l000001?oooooo0000o`000?ooool2
o`0000;ooooo1_l00005ooooo`;o000000Coooooo`000?l0003o00000oooool2o`0000[ooooo0_l0
000<ooooo`;o00001?ooool2o`0000gooooo1Ol0000<oooooaSo00000_ooool6o`0000;ooooo0_l0
0005ooooo`Co00000oooool2o`0000Gooooo1?l00006ooooo`;o0000??ooool001cooooo00?o0000
ooooooooool06_ooool2o`0001?ooooo0_l000000ooooooo0000o`00000?ooooo`;o00003_ooool2
o`000004ooooool0003o0000o`0000Wooooo0_l00004ooooo`Co00000oooool2o`0000Cooooo1?l0
00000ooooooo0000o`000002ooooo`Go00003oooool2o`000003ooooool0003o0000017ooooo1?l0
0009ooooo`;o00000_ooool4o`0000gooooo6?l00002ooooo`Ko00001Oooool2o`0000;ooooo0ol0
000<ooooo`?o0000A?ooool001cooooo00?o0000ooooooooool06_ooool2o`00013ooooo0_l00000
0ooooooo0000o`000009ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Cooooo1Ol00005
ooooo`;o00000_ooool2o`0000Kooooo0ol00002ooooo`;o00000_ooool4o`0000Wooooo1_l00003
ooooo`Go00003Oooool4o`000003ooooool0003o000000Wooooo0_l00006ooooo`;o00002oooool2
o`0000Cooooo0_l0000=oooooaWo000000?oooooo`000?l000002Oooool2o`0000?ooooo0_l0000<
ooooo`;o0000AOooool001cooooo00?o0000ooooooooool0;?ooool2o`0000Wooooo0_l000001?oo
oooo0000o`000?ooool2o`0000?ooooo0_l00005ooooo`Go000000?oooooo`000?l000000_ooool2
o`0000?ooooo0_l00005ooooo`?o00000_ooool2o`0000?ooooo0_l0000:ooooo`;o000000Cooooo
o`000?l0003o00000oooool2o`0000?ooooo0_l00005ooooo`;o00000oooool3o`0000kooooo0_l0
0006ooooo`;o00005Oooool2o`0000;ooooo0_l00005oooooa_o00001_ooool2o`0002Cooooo0_l0
000fooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00001Oooool2o`0000;ooooo0_l00005
ooooo`;o00001_ooool2o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`;o00003oooool4
o`0000;ooooo2?l000000ooooooo0000o`000004ooooo`;o00000_ooool3o`0000;ooooo1Ol00003
ooooo`;o00003oooool2o`00017ooooo0_l0000:ooooo`;o00000_ooool2o`0000Gooooo7?l00005
ooooo`;o00002?ooool2o`0000;ooooo0_l0000Fooooo`;o0000=_ooool001cooooo00?o0000oooo
ooooool0;oooool3o`0000Wooooo0_l00006ooooo`;o000000?oooooo`000?l000001oooool2o`00
0003ooooool0003o000000;ooooo0_l00007ooooo`;o00002_ooool3o`000003ooooool0003o0000
00_o000000?oooooo`000?l000000oooool2o`000003ooooool0003o000000Oo00001Oooool2o`00
00kooooo0_l0000>ooooo`Co00000oooool4o`0000_ooooo7Ol00004ooooo`;o00002Oooool2o`00
00;ooooo0_l0000:ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0;oooool2o`0000;o
oooo0_l00004ooooo`;o00000oooool2o`0000;ooooo0ol000000ooooooo0000o`000007ooooo`?o
00001?ooool2o`000003ooooool0003o000000Cooooo0_l00006ooooo`;o00000oooool7o`000003
ooooool0003o000000ko000000Coooooo`000?l0003ooooo1_l00005ooooo`;o00003?ooool4o`00
013ooooo0_l00003ooooo`Co00002ooooolLo`0000Gooooo0ol00005ooooo`;o00002?ooool2o`00
00Oooooo0_l000000ooooooo0000o`00000oooooo`007?ooool00ol0003oooooooooo`0cooooo`;o
00001?ooool3o`0000;ooooo0_l00002ooooo`?o00002oooool2o`0000Oooooo0_l00004ooooo`?o
00001Oooool2o`0000;ooooo1Ol00002ooooo`Wo000000?oooooo`000?l000002Ol00002ooooo`;o
000000?oooooo`000?l000002Oooool3o`0000Oooooo0_l0000Cooooo`;o00000oooool2o`0000go
oooo1Ol000000ooooooo0000o`000002o`0000;ooooo3_l00007ooooo`;o00001Oooool2o`000003
ooooool0003o000000Gooooo0_l0000:ooooo`;o00002_ooool4o`00037ooooo000Looooo`03o`00
0?oooooooooo03[ooooo0_l000000ooooooo0000o`000004ooooo`;o00002oooool4o`0000?ooooo
0_l000000ooooooo0000o`000003ooooo`Go00000_ooool2o`0000?ooooo1?l00003ooooo`_o0000
00?oooooo`000?l000002_l000001?oooooo0000o`000?l00004ooooo`;o00000oooool3o`00013o
oooo0_l0000:ooooo`;o00001?ooool3o`0000;ooooo1?l00003ooooo`;o00000ooooolBo`000003
ooooool0003o000000?o00004?ooool3o`0000Wooooo0_l0000Aooooo`Co0000<Oooool001cooooo
0_l0000nooooo`;o00001?ooool5o`0000Sooooo1?l00002ooooo`?o000000?oooooo`000?l00000
1_ooool2o`0000;ooooo0_l00002ooooo`Go00001?ooool2o`000003ooooool0003o000000;o0000
00Coooooo`000?l0003ooooo3ol00005ooooo`;o00000oooool3o`0000Kooooo0_l00005ooooo`;o
000000?oooooo`000?l000001?ooool2o`0000[ooooo0ol00002ooooo`Co00000oooool2o`0000;o
oooo6Ol0000Aooooo`;o00000oooool2o`0000Cooooo0_l00016ooooo`007?ooool00ol0003ooooo
ooooo`13ooooo`Ko00001oooool2o`000003ooooool0003o000000?o00004Oooool8o`000003oooo
ool0003o000001[o00004_ooool2o`0000Gooooo0_l00007ooooo`Co00000_ooool2o`0000Cooooo
0ol00004ooooo`;o00001OoooolHo`000003ooooool0003o000000;o00003?ooool2o`0000?ooooo
1Ol0000Aooooo`;o0000>Oooool001cooooo00?o0000ooooooooool0>oooool2o`000003ooooool0
003o000000Oooooo0_l0000:ooooo`?o00001?ooool4o`0000[ooooo2Ol000000ooooooo0000o`00
000Fo`000004ooooool0003o0000o`0000cooooo0_l0000Fooooo`;o00000_ooool2o`0000Cooooo
0ol00004ooooo`;o00001OoooolHo`0000?ooooo0_l00007ooooo`;o00000oooool2o`0000?ooooo
0ol00005ooooo`?o00000_ooool2o`0000Gooooo1?l0000iooooo`007?ooool00ol0003ooooooooo
o`0iooooo`Co000000?oooooo`000?l000000_l0000Eooooo`Oo00001_ooool2o`0000;ooooo5ol0
00000ooooooo0000o`000008o`000004ooooool0003o0000o`0000Cooooo0_l00006ooooo`;o0000
3Oooool2o`00017ooooo0ol0000;oooooa[o00002_ooool3o`000003ooooool0003o000000Cooooo
0_l00004ooooo`Go00000_ooool2o`0000?ooooo1?l0000kooooo`007?ooool00ol0003ooooooooo
o`0iooooo`;o00001Oooool2o`0000gooooo0_l00006ooooo`Co000000?oooooo`000?l000001_oo
ool3o`000003ooooool0003o000000Co000000?oooooo`000?l000006?l00003ooooo`;o00001?oo
ool2o`0000kooooo0_l00003ooooo`Co00002oooool2o`0000Gooooo0_l00009oooooaOo00000_oo
ool3o`0000Kooooo0_l00003ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Cooooo0_l0
00000ooooooo0000o`000007ooooo`?o0000??ooool001cooooo00?o0000ooooooooool0>Oooool2
o`0000Cooooo0_l00004ooooo`Co00001_ooool2o`00013ooooo0_l00002ooooo`;o000000?ooooo
o`000?l000001?l000000ooooooo0000o`00000Qo`0000Cooooo0_l00009ooooo`?o00000oooool2
o`0000gooooo0_l00006ooooo`;o00000_ooool2o`0000Cooooo5_l000000ooooooo0000o`000002
o`0000Oooooo0_l000000ooooooo0000o`00000Booooo`;o00002?ooool2o`0003cooooo000Loooo
o`03o`000?oooooooooo02cooooo0_l0000;ooooo`;o00001?ooool4o`0000;ooooo1?l000001?oo
oooo0000o`000?l00004ooooo`;o00001?ooool2o`0000Sooooo0_l00002ooooo`;o00000_oooolY
o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000001Oooool3o`0000gooooo0_l0
000<ooooo`;o00000_ooool4o`0000Cooooo0_l000000ooooooo0000o`000002o`000003ooooool0
003o000000Wo00000_ooool2o`0000cooooo0ol0000;ooooo`;o00003Oooool2o`0000Gooooo0_l0
000=ooooo`;o00009oooool001cooooo00?o0000ooooooooool0;?ooool2o`00013ooooo1Ol00007
ooooo`Ko000000?oooooo`000?l000001?ooool2o`000004ooooool0003o0000ooooo`;o00003?oo
oolUo`0000?ooooo0_l00003ooooo`?o00001Oooool2o`0000kooooo0_l0000Booooo`;o00001?oo
ool2o`0000;ooooo0ol000000ooooooo0000o`000007o`0000Cooooo0_l0000=ooooo`;o00002ooo
ool2o`0000gooooo0_l00005ooooo`;o00003Oooool2o`0002Oooooo000Looooo`03o`000?oooooo
oooo02Oooooo0_l0000Dooooo`?o000000?oooooo`000?l000001Oooool2o`0000?ooooo2?l00005
ooooo`;o000000?oooooo`000?l000001oooool3o`0000;ooooo1ol000000ooooooo0000o`00000J
o`0000Wooooo0_l0000;ooooo`;o00002Oooool2o`0001Sooooo0_l00003ooooo`;o000000?ooooo
o`000?l000001ol00004ooooo`;o00003Oooool2o`0000;ooooo0_l0000Hooooo`;o0000>oooool0
01cooooo00?o0000ooooooooool09oooool2o`0001Cooooo0ol00008ooooo`;o00001_ooool2o`00
0003ooooool0003o0000017ooooo0ol000001?oooooo0000o`000?oooolNo`0000;ooooo0_l00004
ooooo`;o00001Oooool3o`0000Sooooo0_l00008ooooo`?o00006Oooool3o`000003ooooool0003o
000000;ooooo1_l000000ooooooo0000o`00000<ooooo`Co00001_ooool2o`0000;ooooo0_l0000:
ooooo`;o00000oooool2o`0000?ooooo0_l0000Aooooo`;o0000:?ooool001cooooo00?o0000oooo
ooooool0=Oooool2o`0000Gooooo0_l0000Booooo`?o00004oooool2o`0000;ooooo0_l000000ooo
oooo0000o`00000No`0000Cooooo2?l000001?oooooo0000o`000?l0000;ooooo`;o00001?ooool4
o`0000Kooooo1?l00009ooooo`;o00001?ooool3o`000004ooooool0003o0000ooooo`Co000000Co
ooooo`000?l0003ooooo0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o000000Co0000
2_ooool2o`0000[ooooo0_l00003ooooo`;o00005_ooool2o`0002Sooooo000Looooo`03o`000?oo
oooooooo03Gooooo0_l00005ooooo`?o00002?ooool2o`0000Cooooo0_l000001Ooooooo0000o`00
0?l0003ooooo00;o00003Oooool2o`0000;ooooo0_l000000ooooooo0000o`00000;o`000003oooo
ool0003o000001oo00003oooool2o`0000Cooooo1?l00006ooooo`Oo00001_ooool2o`0000_ooooo
1?l00009ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`Go00002?ooool2o`00057o
oooo000Looooo`03o`000?oooooooooo03Sooooo0_l00003ooooo`;o00002?ooool2o`000004oooo
ool0003o0000ooooo`;o00001Oooool2o`0000gooooo5?l000000ooooooo0000o`00000Lo`000005
ooooool0003o0000o`000?ooool00_l0000Jooooo`;o000000?oooooo`000?l000000ol0000Goooo
o`;o00001oooool2o`0000[ooooo0ol00008ooooo`Co00000_ooool2o`00013ooooo0ol0000<oooo
o`;o0000:_ooool001cooooo00?o0000ooooooooool0>?ooool2o`0000?ooooo0_l00005ooooo`[o
00005_ooool^o`000004ooooool0003o0000o`0000;ooooo0_l000000ooooooo0000o`000003oooo
o`;o00003_ooool2o`0000Gooooo0_l00002ooooo`;o00006Oooool2o`00023ooooo0_l00002oooo
o`;o00004?ooool3o`0000cooooo0_l0000Zooooo`007?ooool00ol0003oooooooooo`14ooooo`?o
000000Goooooo`000?l0003o0000ooooo`02o`0000;ooooo0_l00007ooooo`;o00001_ooool2o`00
00;ooooo0_l000000ooooooo0000o`00000Xo`000004ooooool0003o0000o`0000;ooooo0_l00006
ooooo`;o00003_ooool2o`0000;ooooo0ol00004ooooo`?o00000_ooool2o`0001Gooooo0_l00004
ooooo`;o00006oooool3o`0000Gooooo0_l0000:ooooo`;o0000>Oooool001cooooo00?o0000oooo
ooooool0D?ooool2o`0000Oooooo0_l00006ooooo`;o00002?oooolBo`0000;ooooo4ol000000ooo
oooo0000o`00000;ooooo`;o00000_ooool2o`0000kooooo0ol000001?oooooo0000o`000?ooool3
o`0000;ooooo0_l0000Eooooo`;o00001?ooool2o`0000_ooooo0_l0000>ooooo`?o00001Oooool2
o`0004Gooooo000Looooo`;o0000COooool2o`0001Kooooo0_l00006ooooo`Co000000?oooooo`00
0?l000002_l000000ooooooo0000o`00000Do`000003ooooool0003o000000Oooooo0ol00003oooo
o`;o00001oooool2o`0000;ooooo0_l00005ooooo`;o00002oooool2o`0000Cooooo0_l0000Moooo
o`Co00002_ooool4o`0000cooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0Xooooo`;o
00008_ooool2o`0000kooooo0_l00006ooooo`;o00000oooool2o`000003ooooool0003o000001_o
000000?oooooo`000?l000003ol00003ooooo`?o00003?ooool2o`0000;ooooo0_l0000=ooooo`Oo
00001?ooool2o`000003ooooool0003o000000Gooooo0_l0000@ooooo`?o00000_ooool2o`0000[o
oooo1?l0000<ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0:?ooool2o`0001?ooooo
0_l0000Mooooo`;o00001_ooool4o`000003ooooool0003o000002Ko000000?oooooo`000?l00000
1ol0000Cooooo`;o000000Coooooo`000?l0003o00003?ooool5o`0000?ooooo0_l00004ooooo`;o
00001Oooool3o`0000Sooooo0_l00004ooooo`Co00001_ooool2o`0000[ooooo0_l0001;ooooo`00
7?ooool00ol0003oooooooooo`0Rooooo`;o00006?ooool3o`0001cooooo0_l00007ooooo`So0000
00?oooooo`000?l000007_l000001Ooooooo0000o`000?l0003ooooo00?o000000?oooooo`000?l0
00001_ooool2o`0000Oooooo0_l00005ooooo`;o000000Coooooo`000?l0003o00002?ooool2o`00
00;ooooo1Ol00003ooooo`;o00002_ooool4o`0000?ooooo0_l00003ooooo`;o00001?ooool2o`00
00Sooooo0_l0000:ooooo`;o00001Oooool2o`0004Cooooo000Looooo`03o`000?oooooooooo02;o
oooo0_l0000Hooooo`;o00001?ooool2o`0000?ooooo0_l00002ooooo`;o00002Oooool3o`0000;o
oooo0_l00007ooooo`;o00000_oooolZo`000004ooooool0003o0000ooooo`;o00000_ooool2o`00
00;ooooo0_l00007ooooo`;o00004oooool2o`0000Gooooo0_l0000;ooooo`;o000000Coooooo`00
0?l0003o00001Oooool2o`000003ooooool0003o000000Sooooo0_l00009ooooo`;o00000_ooool2
o`0000[ooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00001oooool2o`00
00?ooooo0_l00002ooooo`;o00001oooool5o`000003ooooool0003o000000Sooooo0_l00002oooo
o`_o000000?oooooo`000?l000006?l00002ooooo`;o00002?ooool4o`0001Gooooo0_l00009oooo
o`;o00000_ooool2o`0000Gooooo0_l00005ooooo`;o000000Coooooo`000?l0003ooooo0_l00006
ooooo`;o00002?ooool2o`0000Wooooo1_l0001@ooooo`007?ooool00ol0003oooooooooo`0ioooo
o`;o00002?ooool2o`0000Sooooo1?l00003ooooo`Co00000_ooool2o`0000Sooooo0ol00002oooo
obWo00000_ooool2o`000003ooooool0003o000000?ooooo0_l0000Eooooo`;o00002Oooool2o`00
00;ooooo1Ol00002ooooo`;o00002oooool2o`0000Oooooo0_l00005ooooo`;o00003Oooool4o`00
00Wooooo0_l00002ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0>Oooool2o`0000So
oooo0ol00004ooooo`;o000000?oooooo`000?l000000_l00005ooooo`;o00002?ooool2o`0000?o
oooo0_l00003ooooo`go000000?oooooo`000?l000002_l000000ooooooo0000o`00000?o`000003
ooooool0003o0000023ooooo1?l00005ooooo`Go00000oooool2o`0001?ooooo1Ol00002ooooo`;o
00004?ooool2o`0000Sooooo0_l00002ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0
:Oooool2o`0000kooooo0_l00009ooooo`;o00001?ooool2o`0000;ooooo1?l00003ooooo`Ko0000
0_ooool2o`000003ooooool0003o000000;o00000oooool2o`000003ooooool0003o000000Go0000
00?oooooo`000?l000000_l000000ooooooo0000o`00000:o`0000;ooooo2ol000000ooooooo0000
o`000004o`0001?ooooo0_l0000=ooooo`Co00001Oooool2o`0000Kooooo0ol00007ooooo`?o0000
2_ooool3o`0001Cooooo0_l00006ooooo`Co00001_ooool2o`0000;ooooo0ol0000hooooo`007?oo
ool00ol0003oooooooooo`0Yooooo`;o00006oooool3o`0000Gooooo1?l00003ooooo`Ko00000_oo
ool2o`0000?ooooo0_l00003ooooo`;o00000oooool2o`000004ooooool0003o0000oooooaco0000
0_ooool9o`0000Kooooo0ol00008ooooo`;o00002_ooool2o`0001?ooooo1?l00005ooooo`?o0000
5?ooool2o`0000kooooo0_l00003ooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`Co
0000>?ooool001cooooo00?o0000ooooooooool0A_ooool3o`000004ooooool0003o0000o`0001?o
oooo0_l0000:ooooo`;o000000Coooooo`000?l0003ooooo7?l000000ooooooo0000o`000003o`00
00?ooooo0_l00004ooooo`Go00000_ooool2o`0000Kooooo0_l00008ooooo`;o00001Oooool2o`00
00Cooooo0_l00003ooooo`;o00000oooool2o`0001cooooo0_l00008ooooo`;o00001?ooool4o`00
0003ooooool0003o000000Gooooo0_l000001?oooooo0000o`000?ooool2o`0003[ooooo000Loooo
o`03o`000?oooooooooo04?ooooo0_l000001Ooooooo0000o`000?l0003ooooo00Go00000_ooool2
o`0000gooooo0_l000000ooooooo0000o`00000:ooooo`;o000000?oooooo`000?l000001?l00000
0ooooooo0000o`00000Fo`0000[ooooo1?l000000ooooooo0000o`000002ooooo`;o00001_ooool2
o`0000oooooo0_l00004ooooo`;o00000oooool2o`0000?ooooo0_l00009ooooo`;o00004?ooool4
o`0000Oooooo0_l00006ooooo`;o00002?ooool2o`000003ooooool0003o000003gooooo000Loooo
o`03o`000?oooooooooo04?ooooo0_l00007ooooo`?o00000_ooool2o`0000_ooooo0_l00003oooo
o`;o00001Oooool2o`000003ooooool0003o000000;ooooo7ol000000ooooooo0000o`000004oooo
o`Ko000000?oooooo`000?l000000_l00002ooooo`Go00002_ooool2o`0000Gooooo0_l00004oooo
o`;o000000?oooooo`000?l000000_l0000Aooooo`;o00004?ooool4o`00017ooooo0_l00018oooo
o`007?ooool00ol0003oooooooooo`10ooooo`;o00000_ooool2o`0000Cooooo1?l0000=ooooo`;o
000000Coooooo`000?l0003ooooo0_l00007ooooo`;o000000?oooooo`000?l000000_oooolLo`00
00Cooooo0_l00004ooooo`Co00000oooool2o`0000Cooooo1Ol0000:ooooo`;o00001Oooool4o`00
00;ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Kooooo0_l00004oooo
o`Co00008Oooool2o`0000;ooooo0ol00013ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5
ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0@?oo
ool2o`0000;ooooo0_l00004ooooo`;o00003oooool4o`0000;ooooo0_l0000@oooooaOo000000?o
ooooo`000?l000000_l00004ooooo`?o000000Coooooo`000?l0003o00002oooool2o`0000cooooo
0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000Kooooo0_l00002ooooo`;o
000000Coooooo`000?l0003o00000_ooool2o`0000;ooooo0_l00002ooooo`Ko00002_ooool2o`00
00Cooooo0_l0000@ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`00043ooooo00001_oo
ooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40
1_ooool00ol0003oooooooooo`0kooooo`;o00002Oooool2o`0001Gooooo0ol00005ooooo`;o0000
2Oooool2o`0000;ooooo5_l00003ooooo`Co00000_ooool3o`000003ooooool0003o000000?o0000
5oooool2o`000004ooooool0003o0000ooooo`;o00002Oooool2o`000003ooooool0003o000000;o
oooo0_l00003ooooo`;o00000_ooool3o`000003ooooool0003o000000kooooo0_l00004ooooo`;o
00001?ooool2o`0000Wooooo0ol00004ooooo`?o0000@?ooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool0>oooool2o`0000Cooooo0_l00003ooooo`;o00003?ooool2o`0000?ooooo0_l00003ooooo`;o
00000oooool4o`0000Cooooo0ol00002ooooo`Co000000Coooooo`000?l0003ooooo0ol000000ooo
oooo0000o`00000;o`0000Cooooo1?l00003ooooo`?o00000oooool5o`0000?ooooo0ol0000Foooo
o`;o00001_ooool7o`0000Sooooo1Ol0000Gooooo`;o00001?ooool2o`0000Cooooo0_l00003oooo
o`;o00001Oooool4o`0003oooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wo
oooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000>oooool2o`0000Cooooo0_l0000Aoooo
o`;o00000oooool2o`0000Sooooo0_l00006ooooo`?o00001?ooool5o`000003ooooool0003o0000
00oo000000Coooooo`000?l0003o00001?ooool2o`0000;ooooo0_l000001?oooooo0000o`000?oo
ool4o`0000;ooooo1?l00009ooooo`;o00000oooool2o`000003ooooool0003o000000?ooooo0_l0
0006ooooo`Co000000?oooooo`000?l000000_l00006ooooo`;o000000?oooooo`000?l000008ooo
ool2o`0000cooooo0_l0000>ooooo`;o0000;oooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool02Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0=ooo
ool2o`0000;ooooo0_l0000Aooooo`;o00000oooool2o`000003ooooool0003o000000?ooooo0_l0
0003ooooo`;o00003oooool6o`000003ooooool0003o000000[o00001?ooool5o`0000Cooooo0ol0
00001?oooooo0000o`000?ooool2o`0000Gooooo1Ol00008ooooo`Go00000_ooool2o`000003oooo
ool0003o000000Cooooo0_l00006ooooo`;o00001?ooool2o`0000Kooooo1_l0000?ooooo`;o0000
3Oooool2o`0000;ooooo0_l0000:ooooo`;o00004?ooool2o`0002oooooo00000ooooooo410@oooo
o`02ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003ooooooooo
o`0gooooo`;o00002?ooool2o`0000_ooooo0_l00003ooooo`;o000000?oooooo`000?l000000ooo
ool2o`0000?ooooo0_l0000;ooooo`;o000000?oooooo`000?l000001Ol00005ooooo`So000000Co
ooooo`000?l0003ooooo1Ol00004ooooo`?o00002oooool2o`000003ooooool0003o000000?ooooo
1?l000000ooooooo0000o`000003o`0000_ooooo0_l00006ooooo`;o00003_ooool4o`0000oooooo
0ol0000<ooooo`;o00000_ooool2o`0000Cooooo0_l00004ooooo`;o0000@Oooool00006oooooomg
MgOoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo047o
oooo1?l0000Aooooo`;o00000_ooool2o`0000[ooooo0_l00004ooooo`?o000000Goooooo`000?l0
003o0000ooooo`03o`0000Gooooo1ol00002ooooo`So00001?ooool2o`0000oooooo1?l000000ooo
oooo0000o`000006o`0000;ooooo1Ol00008ooooo`;o00000oooool5o`0001_ooooo0_l00002oooo
o`?o00005_ooool2o`0004Oooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<
odA4A?l0003o410@1_ooool00ol0003oooooooooo`13ooooo`;o00001Oooool2o`0000Sooooo1?l0
0002ooooo`;o00002_ooool2o`0000Cooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo0_l0
0004ooooo`Ko00000_ooool8o`0000[ooooo0_l00004ooooo`;o00001?ooool2o`0000;ooooo0_l0
00000ooooooo0000o`000003ooooo`So00001_ooool2o`0000?ooooo0_l000001?oooooo0000o`00
0?ooool2o`0000Cooooo0_l00004ooooo`?o00002oooool2o`0001?ooooo0_l000001?oooooo0000
o`000?l00008ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0>_ooool3o`0000Sooooo
0_l00002ooooo`?o00002?ooool2o`00013ooooo0_l00008ooooo`;o00000_ooool2o`0000;ooooo
1?l00002ooooo`Ko00000_ooool:o`0000Kooooo1?l00004ooooo`;o00002oooool2o`0000;ooooo
2Ol000000ooooooo0000o`00000>ooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`?o
00001?ooool2o`0000Cooooo0_l00006ooooo`;o00001?ooool2o`0000Gooooo0ol000001?oooooo
0000o`000?l00008ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0>_ooool3o`0000So
oooo0_l00002ooooo`?o00002Oooool2o`000003ooooool0003o000001[ooooo0_l00004ooooo`;o
00001?ooool3o`0000Gooooo1Ol000000ooooooo0000o`000002o`000004ooooool0003o0000oooo
o`;o00003?ooool2o`0000Cooooo0_l00002ooooo`[o000000?oooooo`000?l000003_ooool2o`00
0003ooooool0003o000000kooooo0ol00003ooooo`?o00001Oooool2o`0000Cooooo0_l00005oooo
o`;o00000_ooool2o`0001Sooooo1?l0000`ooooo`007?ooool00ol0003oooooooooo`0kooooo`;o
00000oooool2o`000003ooooool0003o000000Gooooo0_l00009ooooo`;o000000?oooooo`000?l0
00007?ooool2o`0000Wooooo1Ol00002ooooo`Ko00000_ooool2o`000003ooooool0003o000000?o
oooo0_l00008ooooo`Co000000?oooooo`000?l000004?l000001?oooooo0000o`000?l0000<oooo
o`;o00000oooool2o`0000[ooooo0_l000000ooooooo0000o`000004ooooo`;o00000_ooool2o`00
0003ooooool0003o000000gooooo1?l00005ooooo`;o00004Oooool4o`00033ooooo000Looooo`03
o`000?oooooooooo043ooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l00002oooo
o`Co00008oooool2o`0000Kooooo0_l000000ooooooo0000o`00000;o`0000Sooooo1?l00008oooo
o`;o00000ooooolFo`0000_ooooo0_l00004ooooo`;o00001Oooool2o`0000?ooooo0_l000001?oo
oooo0000o`000?l00003ooooo`;o00000_ooool2o`00013ooooo0_l00007ooooo`;o000000?ooooo
o`000?l00000@_ooool001cooooo00?o0000ooooooooool0A_ooool2o`0000;ooooo0ol00002oooo
o`Co00001?ooool2o`0000[ooooo0_l00005ooooo`;o00001?ooool2o`0000Sooooo0_l00002oooo
o`;o000000Coooooo`000?l0003o00000_ooool2o`0000kooooo0_l0000=ooooo`Co000000?ooooo
o`000?l000003_l000000ooooooo0000o`000002o`0000Wooooo0_l0000;ooooo`;o00000_ooool2
o`0000?ooooo1?l00007ooooo`;o00002?ooool2o`0000Kooooo0_l00008ooooo`;o0000@_ooool0
01cooooo00?o0000ooooooooool0B_ooool2o`0000Oooooo0_l00002ooooo`;o00000oooool4o`00
00?ooooo0_l00005ooooo`;o000000Coooooo`000?l0003ooooo0_l00008ooooo`;o00000_ooool2
o`000003ooooool0003o000000Oooooo0_l00006ooooo`;o00001_ooool2o`0000Wooooo1?l00000
0ooooooo0000o`00000Do`000003ooooool0003o000000;o00002oooool3o`0000Kooooo0_l00003
ooooo`Co00000_ooool2o`0000?ooooo0_l00008ooooo`;o00001_ooool2o`0004cooooo000Loooo
o`03o`000?oooooooooo04Kooooo0_l00002ooooo`;o00000oooool8o`0000Gooooo1?l00009oooo
o`;o00000_ooool2o`0000;ooooo0_l00004ooooo`;o00001Oooool2o`0000[ooooo0_l00006oooo
o`;o00001_ooool2o`0000Cooooo0_l00005oooooaWo000000?oooooo`000?l000000_l0000;oooo
o`?o00000_ooool2o`0000Oooooo0_l00004ooooo`;o00000oooool2o`0000Sooooo0_l000000ooo
oooo0000o`000004ooooo`;o00001?ooool2o`0004Gooooo000Looooo`03o`000?oooooooooo04Ko
oooo0_l00002ooooo`;o00000oooool8o`0000Kooooo0_l0000:ooooo`Co000000Coooooo`000?l0
003ooooo0_l00004ooooo`;o00006oooool2o`0000Gooooo0_l00003ooooo`;o00001OoooolHo`00
00?ooooo0_l0000<ooooo`;o00000oooool2o`0000Gooooo1?l00007ooooo`Co00002?ooool5o`00
00Cooooo0_l00004ooooo`;o0000AOooool001cooooo00?o0000ooooooooool0>?ooool2o`0000Ko
oooo0_l0000:ooooo`;o00001Oooool2o`0000Sooooo0_l00008ooooo`Ko000000?oooooo`000?l0
00001oooool2o`0000;ooooo0_l0000Booooo`;o00000oooool2o`0000Gooooo0_l00005ooooo`Co
000000?oooooo`000?l000002?l000000ooooooo0000o`00000;o`000003ooooool0003o000000;o
00001_ooool2o`0000cooooo0_l00002ooooo`;o00002Oooool4o`0000Wooooo0_l0001Cooooo`00
7?ooool00ol0003oooooooooo`0hooooo`;o00001_ooool2o`000003ooooool0003o000000;ooooo
0_l00003ooooo`;o00003oooool2o`0000Sooooo1?l0000;ooooo`;o00000oooool2o`0000;ooooo
1?l0000<ooooo`;o00004OoooolSo`0000Gooooo0_l00003ooooo`?o00001_ooool5o`0000;ooooo
0_l00002ooooo`;o00001?ooool2o`0002Cooooo0ol0000gooooo`007?ooool00ol0003ooooooooo
o`10ooooo`;o000000?oooooo`000?l000000_ooool3o`000004ooooool0003o0000o`0000oooooo
0_l0000Gooooo`Go000000Coooooo`000?l0003ooooo1Ol00003ooooo`;o00006_oooolEo`000003
ooooool0003o000000Oo000000?oooooo`000?l000000ol00002ooooo`;o00000oooool5o`0000Ko
oooo0ol00002ooooo`;o00000_ooool2o`000003ooooool0003o000001Gooooo0_l00004ooooo`?o
00002Oooool3o`0003Oooooo000Looooo`;o0000@Oooool2o`000003ooooool0003o000000;o0000
00Coooooo`000?l0003ooooo0ol0000Oooooo`;o00001?ooool2o`0000;ooooo1?l000000ooooooo
0000o`000004ooooo`Oo00001?ooool2o`0000Cooooo0_l0000>ooooobSo00001oooool2o`0001;o
oooo0_l00006ooooo`;o00003Oooool2o`0000Cooooo0ol00013ooooo`007?ooool00ol0003ooooo
ooooo`0eooooo`;o00002oooool5o`0002Kooooo0_l00004ooooo`;o00003?ooool2o`000004oooo
ool0003o0000o`0000Kooooo1?l00002ooooo`;o00003_oooolTo`000003ooooool0003o000000;o
00002Oooool4o`0000Sooooo0_l00009ooooo`Co00000_ooool4o`0005?ooooo000Looooo`03o`00
0?oooooooooo03Gooooo0_l0000;ooooo`?o00003_ooool2o`0001Kooooo0_l0000Dooooo`;o0000
2Oooool2o`000003ooooool0003o000000?ooooo0_l0000?ooooob3o00000oooool4o`0000Oooooo
1_l00008ooooo`;o00001?ooool2o`0000?ooooo0_l00004ooooo`Co0000Doooool001cooooo00?o
0000ooooooooool0BOooool2o`0000Sooooo0_l00002ooooo`;o00004_ooool2o`0000_ooooo0_l0
0005ooooo`;o00002oooool2o`000003ooooool0003o000000?ooooo0_l0000=ooooob?o00003Ooo
ool2o`0001;ooooo0_l0000Nooooo`;o00000_ooool2o`0003cooooo000Looooo`03o`000?oooooo
oooo04Wooooo0_l0000<ooooo`;o00007oooool2o`0000Gooooo0_l0000=ooooo`?o00004?oooolU
o`00017ooooo1Ol00003ooooo`;o00005oooool4o`0000_ooooo0_l00002ooooo`;o0000??ooool0
01cooooo00?o0000ooooooooool0COooool2o`0000;ooooo0_l00004ooooo`;o000000?oooooo`00
0?l000009oooool2o`0000Oooooo1Ol0000@ooooo`?o00000_ooool2o`0000;ooooo6ol0000<oooo
o`?o00000oooool5o`0000?ooooo0_l0000Gooooo`Co0000COooool001cooooo00?o0000oooooooo
ool0COooool2o`0000;ooooo1?l00005ooooo`?o00005?ooool2o`0000Gooooo0_l00009ooooo`;o
00001oooool4o`0000oooooo0_l00003oooooago000000?oooooo`000?l000000ol00009ooooo`Co
00001Oooool2o`0001?ooooo0_l00005ooooo`;o00000oooool2o`0000;ooooo0_l00019ooooo`00
7?ooool00ol0003oooooooooo`16ooooo`;o00002oooool2o`0000Kooooo0_l000000ooooooo0000
o`000006ooooo`;o00002Oooool2o`0000Cooooo1?l00007ooooo`;o00000_ooool2o`0000Cooooo
1?l00006ooooo`;o00001oooool2o`0000?ooooo0_l000000ooooooo0000o`00000Ho`0000Cooooo
0_l00009ooooo`;o00001oooool2o`0000;ooooo0_l00005ooooo`;o00002?ooool2o`0000Gooooo
0_l00003ooooo`;o00000_ooool2o`0000_ooooo0_l0000looooo`007?ooool00ol0003ooooooooo
o`11ooooo`;o00000oooool2o`0000_ooooo0_l00008ooooo`?o00001_ooool2o`0000oooooo1?l0
0007ooooo`;o00000_ooool2o`0000Cooooo0_l00005ooooo`;o000000?oooooo`000?l000000_l0
0002ooooo`;o000000?oooooo`000?l000001?oooolNo`0000Gooooo0_l00006ooooo`;o00002ooo
ool2o`0000Gooooo0ol00004ooooo`;o00001oooool2o`0001Gooooo0_l0000looooo`007?ooool0
0ol0003oooooooooo`0mooooo`;o00000_ooool2o`0000Gooooo0_l0000Cooooo`?o00006Oooool3
o`0000Gooooo0_l00005ooooo`;o00000_ooool2o`0000Gooooo1?l000000ooooooo0000o`000002
ooooo`Go00001?oooolDo`0000;ooooo2Ol00004ooooo`;o00004?ooool2o`0000Wooooo0_l00003
ooooo`?o00001oooool2o`0005?ooooo000Looooo`03o`000?oooooooooo03gooooo0_l00004oooo
o`;o000000?oooooo`000?l000000_l00006ooooo`;o00003?ooool2o`0000Cooooo0_l0000Doooo
o`;o00001Oooool2o`0000Gooooo1?l00009ooooo`Go00001?ooool2o`0000Kooooo0_l00002oooo
oa[o00005?ooool4o`0000kooooo0_l0000Iooooo`;o0000@_ooool001cooooo00?o0000oooooooo
ool0@oooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o00002_ooool4o`0000Co
oooo0_l0000Tooooo`;o00002oooool4o`0000oooooo6Ol0000Eooooo`;o00005Oooool2o`0000;o
oooo0_l00002ooooo`;o00003?ooool2o`0004;ooooo000Looooo`03o`000?oooooooooo03cooooo
0_l00005ooooo`;o00001Oooool2o`00013ooooo1?l0000Rooooo`;o00004Oooool2o`0000;ooooo
1?l0000<oooooako00000_ooool2o`0000;ooooo0_l0000>ooooo`;o00001_ooool2o`0000Sooooo
0_l00002ooooo`;o00000_ooool2o`00053ooooo000Looooo`03o`000?oooooooooo03cooooo0_l0
0005ooooo`;o00005oooool2o`000003ooooool0003o0000027ooooo0_l0000Aooooo`;o00001?oo
ool2o`0000[ooooo1?l000001?oooooo0000o`000?oooolHo`0000;ooooo0_l00002ooooo`;o0000
1_ooool4o`0000Cooooo0_l00006ooooo`?o00001Oooool2o`0005[ooooo000Looooo`03o`000?oo
oooooooo04?ooooo0_l0000?ooooo`;o00001_ooool5o`000003ooooool0003o000000Kooooo0_l0
000Pooooo`;o00001Oooool2o`0000?ooooo0_l00005ooooo`Co00001?ooool2o`000003ooooool0
003o000000?ooooo5_l00004ooooo`;o00002_ooool4o`0000gooooo0_l00005ooooo`;o00001Ooo
ool4o`00057ooooo000Looooo`03o`000?oooooooooo05Cooooo0_l00007ooooo`;o00000oooool2
o`0000Kooooo0_l0000Pooooo`;o00000_ooool2o`000003ooooool0003o000000?ooooo0_l00005
ooooo`Ko00001Oooool2o`0000?ooooo2Ol000001?oooooo0000o`000?ooool2o`0000Cooooo0ol0
000Cooooo`;o00000_ooool4o`0000Cooooo0_l0000>ooooo`Co00003oooool2o`00043ooooo000L
ooooo`;o0000D?ooool2o`0000Gooooo0ol0000Cooooo`;o00008_ooool2o`00017ooooo0_l0000:
ooooo`So00000_ooool4o`000004ooooool0003o0000o`0000Cooooo0_l00004ooooo`;o00002ooo
ool2o`0000;ooooo1?l00004ooooo`;o00002oooool2o`0001Cooooo0_l00010ooooo`007?ooool0
0ol0003oooooooooo`1?ooooo`;o00001Oooool3o`0000Wooooo0_l00008ooooo`;o00009?ooool2
o`0001cooooo0_l00003ooooo`co00001?ooool3o`0000?ooooo0_l0000Hooooo`;o00002_ooool2
o`0005Kooooo000Looooo`03o`000?oooooooooo04Oooooo1?l0000:ooooo`;o00000_ooool2o`00
00Oooooo0_l00007ooooo`;o00009Oooool2o`0001cooooo0ol000000ooooooo0000o`00000:o`00
00Cooooo1_l00009ooooo`Co00001oooool2o`0000Gooooo0_l0000;ooooo`;o0000EOooool001co
oooo00?o0000ooooooooool0Aoooool4o`0000[ooooo0ol000000ooooooo0000o`000009ooooo`?o
00001?ooool2o`0002Kooooo0_l0000:ooooo`;o00002Oooool2o`0000Gooooo0_l000000ooooooo
0000o`000003o`000004ooooool0003o0000o`0000?ooooo0_l00002ooooo`;o000000?oooooo`00
0?l000000_l00008ooooo`Co00001oooool2o`0000cooooo1?l000000ooooooo0000o`000003o`00
00oooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o00001_ooool2o`0000co
oooo0ol0000/ooooo`;o00002_ooool2o`0000Wooooo0_l00008ooooo`Ko00001_ooool3o`0000Co
oooo1?l0000<ooooo`;o00000oooool2o`0000kooooo1?l000001?oooooo0000o`000?ooool2o`00
00oooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`1>ooooo`?o00003Oooool2o`00013o
oooo0_l0000Vooooo`Go00002oooool2o`0000[ooooo0ol000001?oooooo0000o`000?l00002oooo
o`;o00000_ooool2o`0000[ooooo0_l00007ooooo`?o00000oooool2o`0000Kooooo1?l00006oooo
o`;o0000FOooool001cooooo00?o0000ooooooooool0Coooool2o`0000Wooooo0_l00002ooooo`;o
00001?ooool2o`0000[ooooo0_l0000Vooooo`Go00002oooool2o`0000Gooooo0_l00003ooooo`?o
000000?oooooo`000?l000000_l000000ooooooo0000o`00000>ooooo`;o00001oooool3o`0000_o
oooo1?l00006ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0D?ooool2o`0000Oooooo
0ol00008ooooo`;o00001Oooool2o`0000;ooooo0_l0000Qooooo`;o00001_ooool2o`0000Kooooo
0_l00002ooooo`;o00001Oooool4o`0000Gooooo2?l0000Hooooo`?o00004_ooool4o`0005[ooooo
000Looooo`03o`000?oooooooooo053ooooo1?l00005ooooo`;o00002Oooool2o`0000Gooooo0_l0
0002ooooo`;o00008Oooool2o`0000gooooo0ol00002ooooo`;o00001Oooool2o`0000Oooooo0_l0
0004ooooo`?o00002_ooool2o`0000Kooooo0_l00004ooooo`Go00003oooool4o`0005[ooooo000L
ooooo`03o`000?oooooooooo05;ooooo0_l0000:ooooo`;o000000?oooooo`000?l000000_ooool2
o`0002Oooooo0_l00002ooooo`;o00003Oooool2o`0001[ooooo0ol00009ooooo`;o00001Oooool3
o`0000Gooooo1?l00009ooooo`;o00001_ooool2o`0005[ooooo000Looooo`03o`000?oooooooooo
05cooooo1?l000000ooooooo0000o`000002ooooo`;o00003Oooool2o`0001Sooooo0_l00002oooo
o`;o00001?ooool2o`0000Gooooo0_l0000Fooooo`;o00001Oooool2o`00013ooooo0_l00006oooo
o`;o00001oooool2o`0000;ooooo0_l0001Rooooo`007?ooool00ol0003oooooooooo`1Kooooo`?o
00001_ooool2o`0000kooooo0_l0000Qooooo`?o00001Oooool2o`0000;ooooo0_l000000ooooooo
0000o`000002o`0000gooooo1?l00003ooooo`;o00005?ooool2o`0000;ooooo0_l00007ooooo`;o
00000_ooool2o`0006;ooooo000Looooo`03o`000?oooooooooo05_ooooo0ol00006ooooo`;o0000
3?ooool2o`000003ooooool0003o0000023ooooo0_l00003ooooo`;o00001?ooool3o`000003oooo
ool0003o000000;o00003oooool2o`0000?ooooo0_l0000Dooooo`;o00000_ooool2o`000004oooo
ool0003o0000o`0000Oooooo0_l0001Rooooo`007?ooool00ol0003oooooooooo`1Looooo`;o0000
0_ooool2o`0000Wooooo0_l00005ooooo`Go00005_ooool2o`0000gooooo0_l00004ooooo`;o0000
3_ooool2o`0000;ooooo0_l0000Aooooo`;o00003Oooool2o`000004ooooool0003o0000o`00023o
oooo0_l00019ooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o00001?ooool4o`000003oooo
ool0003o000000Kooooo0_l00007ooooo`;o00005oooool2o`0001;ooooo0_l0000?ooooo`;o0000
0_ooool2o`00017ooooo0_l0000@ooooo`;o00008Oooool3o`0004Sooooo000Looooo`03o`000?oo
oooooooo05Sooooo1?l00002ooooo`;o00000oooool2o`0000Oooooo0_l0000<ooooo`;o00005ooo
ool2o`0000cooooo0_l00006ooooo`;o00001?ooool3o`0000[ooooo0_l0000Mooooo`?o00001Ooo
ool2o`0001[ooooo0_l00018ooooo`007?ooool2o`0004kooooo0_l0000;ooooo`?o00003oooool2
o`0000Wooooo1Ol0000@ooooo`;o00001Oooool2o`0001?ooooo0ol00004ooooo`?o00002?ooool4
o`0001_ooooo0_l000000ooooooo0000o`000005ooooo`Co0000H_ooool001cooooo00?o0000oooo
ooooool0COooool2o`0000Gooooo0_l00005ooooo`;o00000_ooool2o`0001Kooooo1_l0000?oooo
o`;o00000oooool2o`000004ooooool0003o0000o`0000Cooooo0_l000000ooooooo0000o`000003
ooooo`;o00000oooool2o`0000Oooooo0_l00007ooooo`?o00000_ooool3o`0001?ooooo0_l00002
ooooo`;o000000?oooooo`000?l000001oooool4o`00063ooooo000Looooo`03o`000?oooooooooo
05Cooooo0_l00009ooooo`;o00002?ooool2o`00013ooooo0_l0000Booooo`Co000000Coooooo`00
0?l0003o00001?ooool2o`000003ooooool0003o000000?ooooo0_l0000<ooooo`;o00000_ooool2
o`0000Sooooo1?l0000Booooo`;o00004?ooool2o`00063ooooo000Looooo`03o`000?oooooooooo
05Sooooo0_l00007ooooo`;o00001_ooool3o`0000oooooo0_l0000Booooo`;o00000_ooool2o`00
00Kooooo0_l00009ooooo`;o00000oooool2o`0000;ooooo0_l00004ooooo`;o00002_ooool2o`00
0003ooooool0003o000000_ooooo0_l0000>ooooo`?o0000IOooool001cooooo00?o0000oooooooo
ool0F?ooool2o`0000Oooooo0_l00002ooooo`?o00000_ooool2o`0000Cooooo0_l00009ooooo`;o
00005_ooool2o`00017ooooo0_l00003ooooo`;o00000_ooool2o`0000Cooooo0_l0000=ooooo`;o
00002oooool2o`0000kooooo0ol0001Uooooo`007?ooool00ol0003oooooooooo`1Uooooo`?o0000
2?ooool2o`0002cooooo0_l0000:ooooo`?o00006Oooool2o`0000[ooooo0ol0000:ooooo`?o0000
Ioooool001cooooo00?o0000ooooooooool0POooool2o`0000Wooooo0_l0000@ooooo`;o00002_oo
ool3o`0000;ooooo0_l0000<ooooo`;o00001oooool2o`0000[ooooo0ol0000:ooooo`?o0000Iooo
ool001cooooo00?o0000ooooooooool0Eoooool2o`0000;ooooo0_l0000>ooooo`;o00002Oooool2
o`0000Wooooo0_l00009ooooo`;o00001oooool5o`0001Gooooo1Ol00009ooooo`;o00002?ooool2
o`0000Wooooo0_l00003ooooo`;o0000L?ooool001cooooo00?o0000ooooooooool0Eoooool2o`00
00;ooooo0_l00002ooooo`;o00002?ooool4o`0000Kooooo0_l000000ooooooo0000o`00000Koooo
o`Oo000000?oooooo`000?l000002_ooool4o`0000Gooooo1_l0000Aooooo`;o00001Oooool2o`00
00Oooooo0_l0001`ooooo`007?ooool00ol0003oooooooooo`1Oooooo`;o00001Oooool2o`000003
ooooool0003o000000Sooooo0_l0000Nooooo`;o00001Oooool3o`0000[ooooo1?l00009ooooo`?o
00005?ooool5o`0000?ooooo0_l0001dooooo`007?ooool00ol0003oooooooooo`1Rooooo`;o0000
0_ooool2o`0000Sooooo0_l0000@ooooo`;o00003?ooool2o`0000Cooooo0_l00002ooooo`;o0000
2oooool2o`0000cooooo0_l00002ooooo`;o00004?ooool4o`0000Cooooo0_l0001dooooo`007?oo
ool00ol0003oooooooooo`1Rooooo`;o000000?oooooo`000?l000001_ooool2o`000003ooooool0
003o000000kooooo1?l0000<ooooo`;o00001?ooool2o`0000oooooo0_l0000@ooooo`;o0000S_oo
ool001cooooo00?o0000ooooooooool0IOooool3o`000003ooooool0003o000000;ooooo0_l0000@
ooooo`?o00002?ooool2o`0000?ooooo0_l0000]ooooo`;o00001oooool2o`00083ooooo000Loooo
o`03o`000?oooooooooo06Cooooo1?l000000ooooooo0000o`000002o`0000Sooooo0_l00008oooo
o`;o00000_ooool2o`0000Gooooo0_l00003ooooo`;o00001?ooool2o`00017ooooo0_l0000Coooo
o`?o00001oooool2o`00083ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44
ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Tooooo`Co00000ooo
ool3o`0000Oooooo0_l0000<ooooo`;o00004?ooool6o`0000[ooooo0_l000000ooooooo0000o`00
000Cooooo`?o00001?ooool5o`0000Cooooo0_l0001jooooo`0000KoooooogMgMonHV9SooooooiRH
V?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000oooooooo
ool0I_ooool2o`0000Cooooo0_l00007ooooo`;o00008?ooool4o`0000[ooooo1Ol0000=ooooo`;o
00001?ooool3o`0000Cooooo0ol00006ooooo`;o0000N_ooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool0M?ooool3o`0000Sooooo0_l0000Vooooo`?o00001Oooool2o`0000?ooooo1Ol00004ooooo`;o
00003_ooool2o`0000;ooooo0_l0001fooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooo
ooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`0006[ooooo0_l00008ooooo`?o
00001?ooool2o`0000;ooooo0ol00005ooooo`;o00004?ooool2o`0000Wooooo0_l00009ooooo`;o
00000oooool3o`0000Wooooo0_l00002ooooo`;o00002oooool2o`0007Kooooo00000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03
o`000?oooooooooo06[ooooo1?l00007ooooo`;o00001?ooool2o`0000?ooooo0ol00004ooooo`;o
00000oooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`0000Cooooo0_l00003ooooo`;o
00003oooool2o`0000Wooooo0_l00002ooooo`;o0000Poooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000oooooooo
ool0K?ooool2o`0000;ooooo0_l0000?ooooo`Co00001?ooool2o`000003ooooool0003o000000;o
oooo0ol00002ooooo`;o00002?ooool2o`0000Oooooo0_l0000;ooooo`;o000000?oooooo`000?l0
00002_ooool2o`0002Gooooo0_l0001Looooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;oooo
o`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`1`ooooo`;o00004Oooool2
o`0000Cooooo0_l00005ooooo`;o00004Oooool2o`0000?ooooo0_l000000ooooooo0000o`00000;
ooooo`;o0000<Oooool2o`0005cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00Go
ZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo07Gooooo0ol00006ooooo`;o0000
7Oooool2o`0000Cooooo0_l00006ooooo`;o00002Oooool2o`0000_ooooo0_l00024ooooo`007?oo
ool00ol0003oooooooooo`1eooooo`?o00001_ooool2o`0001Cooooo0ol00006ooooo`;o00000ooo
ool4o`0000Sooooo1?l00004ooooo`;o00001Oooool2o`0000Cooooo0_l00024ooooo`007?ooool0
0ol0003oooooooooo`1Wooooo`;o00002Oooool2o`000004ooooool0003o0000ooooo`;o00001Ooo
ool4o`0000_ooooo0_l00002ooooo`Go00002oooool4o`0000?ooooo0_l00003ooooo`Co00001Ooo
ool2o`0000Cooooo0_l0002:ooooo`007?ooool00ol0003oooooooooo`1Wooooo`;o00002Oooool2
o`000003ooooool0003o000000?o00001Oooool4o`0000_ooooo0_l00002ooooo`;o00004oooool4
o`0000Gooooo0ol00004ooooo`;o0000T?ooool001cooooo00?o0000ooooooooool0K?ooool2o`00
00Oooooo1?l00006ooooo`;o00001oooool2o`0001cooooo0ol00007ooooo`Ko0000Toooool001co
oooo00?o0000ooooooooool0K?ooool2o`0000kooooo0_l000000ooooooo0000o`000007ooooo`;o
00000oooool2o`0000?ooooo0_l00002ooooo`?o00003Oooool2o`0000[ooooo1?l00003ooooo`?o
0000SOooool001cooooo00?o0000ooooooooool0O?ooool2o`000003ooooool0003o000000Cooooo
0_l00006ooooo`;o00000oooool2o`0000;ooooo0ol00003ooooo`;o00003_ooool2o`0000[ooooo
1?l0002=ooooo`007?ooool00ol0003oooooooooo`1jooooo`;o00002Oooool2o`000005ooooool0
003o0000o`000?ooool00_l00002ooooo`?o00000oooool2o`0000Cooooo0_l00006ooooo`;o0000
1_ooool2o`0000[ooooo0_l0002?ooooo`007?ooool00ol0003oooooooooo`1cooooo`;o00001Ooo
ool4o`0000Kooooo0_l00002ooooo`?o000000Goooooo`000?l0003o0000ooooo`03o`0000?ooooo
0_l0000<ooooo`;o00001_ooool3o`0000?ooooo0_l0000Zooooo`;o0000JOooool001cooooo00?o
0000ooooooooool0Loooool2o`0000Oooooo0_l00006ooooo`;o00000oooool2o`0000;ooooo0_l0
0008ooooo`?o000000?oooooo`000?l000000_l0000;ooooo`;o000000?oooooo`000?l000000ooo
ool2o`0002[ooooo0_l0001Yooooo`007?ooool00ol0003oooooooooo`1mooooo`;o00001oooool2
o`0000Oooooo0_l00006ooooo`?o000000?oooooo`000?l000000_l00009ooooo`Co00000oooool2
o`0009Sooooo000Looooo`03o`000?oooooooooo07gooooo0_l00004ooooo`;o000000?oooooo`00
0?l000001oooool2o`0000Cooooo0_l0000=ooooo`?o000000Coooooo`000?l0003ooooo0_l00000
1?oooooo0000o`000?l0002Hooooo`007?ooool2o`0008Cooooo0_l0000@ooooo`;o00000oooool2
o`0000;ooooo0_l00004ooooo`?o00001?ooool2o`000003ooooool0003o000009Wooooo000Loooo
o`03o`000?oooooooooo083ooooo0_l0000Hooooo`;o00000_ooool4o`0002Sooooo0_l0001moooo
o`007?ooool00ol0003oooooooooo`20ooooo`;o00006?ooool3o`000003ooooool0003o000000;o
00001_ooool2o`00023ooooo0_l0001mooooo`007?ooool00ol0003oooooooooo`2Kooooo`;o0000
0oooool3o`0000;ooooo0_l000000ooooooo0000o`00002Oooooo`007?ooool00ol0003ooooooooo
o`24ooooo`;o00006_ooool3o`0000;ooooo0_l0002Rooooo`007?ooool00ol0003oooooooooo`24
ooooo`;o0000`oooool001cooooo00?o0000ooooooooool0Y?ooool2o`0000Wooooo0_l0002Hoooo
o`007?ooool00ol0003oooooooooo`2:ooooo`;o00005?ooool2o`0000;ooooo0_l00009ooooo`;o
0000V?ooool001cooooo00?o0000ooooooooool0P_ooool2o`0000Kooooo0_l0000Dooooo`;o0000
Yoooool001cooooo00?o0000ooooooooool0P_ooool2o`000<Gooooo000Looooo`03o`000?oooooo
oooo09oooooo0_l0002Xooooo`007?ooool00ol0003oooooooooo`2Oooooo`;o0000Z?ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`36ooooo`;o0000
POooool001cooooo00?o0000ooooooooool0a_ooool2o`00087ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`2cooooo`;o0000U?ooool001cooooo00?o0000ooooooooool0XOooool2o`00013ooooo0_l0002D
ooooo`007?ooool00ol0003oooooooooo`2Qooooo`;o0000Y_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooo
ooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
ooooB_ooool001Cooooo00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o
0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Doooo
o`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`00
4_ooool00omEEEGoIVIVo`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo002Qooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05_ooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o000000?o410@ooooooooool0
0oooool2o`000003oa0@4?oooooooooo08[ooooo002Rooooo`05o`000?ooooooooooooooool00000
2Oooool6o`0000cooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2;ooooo`00X_ooool01Ol0003ooooo
oooooooooooo000001_ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@
00?ooooo1Ol00003ooooo`Go0000S?ooool00:;ooooo00Go0000ooooooooooooooooo`000009oooo
o`Ko00003?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool0
1?m4A4CogMgMooooool00004ooooo`04odA4A?oMgMgoooooo`0008gooooo002Rooooo`05o`000?n7
QhOoooooojVYZOl000006oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00000oooool01?oMgMgoEEEEooooool00004ooooo`04omgMgOmEEEGoooooo`0008gooooo002Qoooo
o`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool06Oooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41001?ooool00omgMgOoc<c<o`000005ooooo`03ogMgMoo<c<co
000008gooooo0032ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04
ooooo`03onk^k_m4A4Co000000Gooooo00?ok^k^odA4A?l00000SOooool00<3ooooo00?oEEEEofIV
I_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?oMgMgo`000?ooool01Oooool0
0omgMgOo0000ooooo`2<ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1050) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.51201 .68844 Mdot
.54727 .68035 Mdot
.54336 .34734 Mdot
.36468 .53161 Mdot
.62322 .74817 Mdot
.57637 .3524 Mdot
.69873 .51039 Mdot
.64104 .52283 Mdot
.55124 .35986 Mdot
.57722 .58808 Mdot
.68665 .49931 Mdot
.31369 .51888 Mdot
.66593 .50357 Mdot
.37641 .51558 Mdot
.38068 .84152 Mdot
.45192 .55558 Mdot
.56696 .65319 Mdot
.35256 .34774 Mdot
.4077 .47275 Mdot
.58628 .37089 Mdot
.52319 .71412 Mdot
.37261 .52881 Mdot
.50851 .66916 Mdot
.37691 .51569 Mdot
.35476 .52163 Mdot
.55307 .65567 Mdot
.57639 .7039 Mdot
.36487 .56606 Mdot
.36308 .49125 Mdot
.65257 .53228 Mdot
.25461 .42803 Mdot
.46177 .85325 Mdot
.40823 .46135 Mdot
.80603 .50875 Mdot
.63968 .5148 Mdot
.4452 .78528 Mdot
.55644 .37434 Mdot
.65617 .52516 Mdot
.64203 .51026 Mdot
.68649 .53754 Mdot
.6497 .51301 Mdot
.55317 .66314 Mdot
.71244 .47616 Mdot
.64346 .5754 Mdot
.41888 .49095 Mdot
.66578 .67057 Mdot
.23787 .5451 Mdot
.41967 .54575 Mdot
.56575 .65507 Mdot
.55492 .39811 Mdot
.78536 .52683 Mdot
.70205 .51288 Mdot
.58691 .30557 Mdot
.86081 .64057 Mdot
.6662 .52831 Mdot
.40552 .48101 Mdot
.53766 .37033 Mdot
.37961 .53625 Mdot
.38032 .51917 Mdot
.2928 .68542 Mdot
.36288 .57051 Mdot
.39489 .34563 Mdot
.50413 .6306 Mdot
.45381 .384 Mdot
.55384 .36731 Mdot
.64688 .50361 Mdot
.55363 .69141 Mdot
.66908 .50877 Mdot
.32475 .50977 Mdot
.51136 .37763 Mdot
.41802 .54703 Mdot
.65548 .49835 Mdot
.56715 .69884 Mdot
.40352 .5532 Mdot
.65475 .26227 Mdot
.1976 .65489 Mdot
.39731 .38106 Mdot
.361 .73735 Mdot
.31419 .72046 Mdot
.46951 .27914 Mdot
.38698 .49117 Mdot
.2882 .29386 Mdot
.29655 .76554 Mdot
.5087 .65681 Mdot
.45075 .50071 Mdot
.58945 .44063 Mdot
.39819 .55285 Mdot
.62175 .64978 Mdot
.40041 .48391 Mdot
.74549 .31317 Mdot
.55617 .35328 Mdot
.52743 .66494 Mdot
.36484 .52765 Mdot
.34721 .5502 Mdot
.29749 .60565 Mdot
.40227 .58138 Mdot
.36613 .5606 Mdot
.54658 .71304 Mdot
.68622 .493 Mdot
.35996 .59924 Mdot
.6782 .46496 Mdot
.57019 .31377 Mdot
.43298 .54555 Mdot
.5358 .38473 Mdot
.55889 .70971 Mdot
.40513 .5598 Mdot
.65128 .48854 Mdot
.4233 .52185 Mdot
.7607 .5131 Mdot
.54758 .68401 Mdot
.34556 .54206 Mdot
.40147 .3581 Mdot
.52346 .18963 Mdot
.5233 .66673 Mdot
.49387 .26125 Mdot
.39739 .49062 Mdot
.37469 .55747 Mdot
.54647 .67742 Mdot
.55139 .32951 Mdot
.61289 .65307 Mdot
.51373 .63225 Mdot
.68309 .54117 Mdot
.508 .632 Mdot
.41438 .45926 Mdot
.56352 .3556 Mdot
.68113 .43866 Mdot
.61696 .44113 Mdot
.2498 .39647 Mdot
.3935 .5511 Mdot
.69881 .59995 Mdot
.58896 .33513 Mdot
.5356 .66308 Mdot
.67358 .50794 Mdot
.44069 .60272 Mdot
.52933 .68926 Mdot
.68763 .51521 Mdot
.38301 .37486 Mdot
.69783 .38837 Mdot
.54411 .63487 Mdot
.70003 .56904 Mdot
.68652 .47549 Mdot
.69846 .5282 Mdot
.81371 .48255 Mdot
.55607 .6819 Mdot
.37169 .3524 Mdot
.67848 .51988 Mdot
.24817 .48124 Mdot
.3694 .47141 Mdot
.29955 .33318 Mdot
.25835 .28395 Mdot
.80163 .49272 Mdot
.71031 .35088 Mdot
.37387 .31798 Mdot
.70658 .51439 Mdot
.34785 .51652 Mdot
.56413 .66375 Mdot
.56077 .66948 Mdot
.39469 .57521 Mdot
.35941 .53083 Mdot
.41387 .55113 Mdot
.34307 .52528 Mdot
.26184 .68099 Mdot
.42729 .51931 Mdot
.20523 .38885 Mdot
.52292 .65935 Mdot
.35409 .54035 Mdot
.52912 .35968 Mdot
.33319 .51066 Mdot
.64936 .5079 Mdot
.37366 .53974 Mdot
.3632 .53621 Mdot
.35303 .56421 Mdot
.70151 .50894 Mdot
.45135 .83801 Mdot
.31814 .24097 Mdot
.54259 .80496 Mdot
.57669 .26386 Mdot
.58944 .34882 Mdot
.39073 .5577 Mdot
.38525 .33805 Mdot
.45166 .7684 Mdot
.38804 .49762 Mdot
.61285 .16356 Mdot
.36539 .55364 Mdot
.59362 .75967 Mdot
.44561 .47313 Mdot
.56226 .80575 Mdot
.28759 .31627 Mdot
.34761 .50537 Mdot
.33447 .61431 Mdot
.5153 .74226 Mdot
.68751 .56815 Mdot
.65184 .51285 Mdot
.53198 .35406 Mdot
.53961 .35994 Mdot
.62139 .53536 Mdot
.49981 .60249 Mdot
.45216 .60467 Mdot
.35298 .58112 Mdot
.53411 .33626 Mdot
.50003 .62904 Mdot
.35936 .34339 Mdot
.54201 .70949 Mdot
.12954 .52906 Mdot
.7715 .50178 Mdot
.61133 .50357 Mdot
.39632 .37587 Mdot
.5589 .33368 Mdot
.56935 .31252 Mdot
.37942 .33407 Mdot
.41358 .52463 Mdot
.55746 .68741 Mdot
.80981 .59759 Mdot
.49532 .59144 Mdot
.83053 .553 Mdot
.56916 .6899 Mdot
.59804 .58197 Mdot
.68582 .50773 Mdot
.56873 .37243 Mdot
.37334 .5596 Mdot
.40413 .53061 Mdot
.52407 .71739 Mdot
.41502 .5468 Mdot
.45957 .62791 Mdot
.37675 .56663 Mdot
.74429 .45789 Mdot
.39805 .38177 Mdot
.62197 .53597 Mdot
.24297 .39305 Mdot
.52283 .69403 Mdot
.34604 .28871 Mdot
.51834 .37259 Mdot
.42522 .76997 Mdot
.66017 .49414 Mdot
.39629 .36474 Mdot
.51712 .36983 Mdot
.35897 .33792 Mdot
.3449 .48634 Mdot
.59841 .32321 Mdot
.40221 .34638 Mdot
.36521 .78778 Mdot
.36096 .47703 Mdot
.25298 .67633 Mdot
.69861 .49769 Mdot
.51744 .62964 Mdot
.36349 .57041 Mdot
.58082 .36955 Mdot
.41842 .46587 Mdot
.68112 .30803 Mdot
.68519 .44004 Mdot
.60522 .31882 Mdot
.47184 .33971 Mdot
.3927 .3642 Mdot
.64832 .3033 Mdot
.71463 .58161 Mdot
.57019 .66458 Mdot
.43687 .54226 Mdot
.53069 .83238 Mdot
.67844 .51937 Mdot
.4125 .51787 Mdot
.7261 .44109 Mdot
.67471 .52011 Mdot
.38124 .53767 Mdot
.68412 .4819 Mdot
.56202 .67286 Mdot
.41936 .21618 Mdot
.56813 .65544 Mdot
.3992 .48508 Mdot
.65948 .48363 Mdot
.58043 .31604 Mdot
.55073 .65085 Mdot
.4235 .5279 Mdot
.39087 .56772 Mdot
.55922 .44566 Mdot
.35117 .54221 Mdot
.49672 .82468 Mdot
.35156 .55285 Mdot
.53326 .36119 Mdot
.39516 .58226 Mdot
.72369 .25599 Mdot
.63637 .40397 Mdot
.55452 .69089 Mdot
.60694 .32635 Mdot
.54676 .36139 Mdot
.45316 .23616 Mdot
.58287 .29966 Mdot
.40073 .49531 Mdot
.58981 .3579 Mdot
.32552 .32114 Mdot
.67363 .53337 Mdot
.43184 .56032 Mdot
.61388 .57493 Mdot
.54353 .40158 Mdot
.54572 .32569 Mdot
.45623 .57095 Mdot
.5745 .69889 Mdot
.36406 .52794 Mdot
.54943 .32602 Mdot
.49404 .64615 Mdot
.41298 .49558 Mdot
.4852 .51455 Mdot
.55906 .44641 Mdot
.69283 .51847 Mdot
.45969 .50213 Mdot
.42998 .53625 Mdot
.54723 .3805 Mdot
.54186 .70384 Mdot
.64006 .52597 Mdot
.54531 .65515 Mdot
.69246 .73072 Mdot
.75179 .4944 Mdot
.31307 .74031 Mdot
.3771 .3042 Mdot
.72948 .33818 Mdot
.594 .80174 Mdot
.60806 .23646 Mdot
.31456 .41259 Mdot
.74067 .71055 Mdot
.53264 .34571 Mdot
.74124 .43894 Mdot
.54299 .36317 Mdot
.36404 .50081 Mdot
.56482 .35979 Mdot
.5848 .80769 Mdot
.37352 .56576 Mdot
.56806 .36317 Mdot
.42368 .2297 Mdot
.35812 .53911 Mdot
.52207 .66921 Mdot
.36368 .82393 Mdot
.63606 .22802 Mdot
.78418 .4892 Mdot
.59378 .32711 Mdot
.29361 .46314 Mdot
.36172 .5595 Mdot
.36084 .578 Mdot
.55037 .64409 Mdot
.41265 .5773 Mdot
.36019 .33849 Mdot
.39056 .37966 Mdot
.47857 .43796 Mdot
.32983 .25015 Mdot
.34177 .58095 Mdot
.55087 .64898 Mdot
.25483 .63541 Mdot
.67182 .26853 Mdot
.59007 .26952 Mdot
.71066 .52354 Mdot
.42718 .82854 Mdot
.47862 .60277 Mdot
.70534 .46642 Mdot
.6267 .57142 Mdot
.53391 .67616 Mdot
.46757 .8395 Mdot
.65414 .5168 Mdot
.38403 .65446 Mdot
.28283 .55125 Mdot
.40759 .52512 Mdot
.67301 .49239 Mdot
.31627 .53278 Mdot
.69861 .25182 Mdot
.22031 .5413 Mdot
.22886 .35602 Mdot
.4188 .49605 Mdot
.63487 .25836 Mdot
.3724 .54842 Mdot
.60988 .67925 Mdot
.35306 .55573 Mdot
.53959 .65043 Mdot
.58053 .60513 Mdot
.5159 .44098 Mdot
.2748 .2793 Mdot
.7697 .50673 Mdot
.37293 .3184 Mdot
.37986 .56369 Mdot
.40643 .52463 Mdot
.37161 .36352 Mdot
.51304 .65683 Mdot
.34307 .52111 Mdot
.33214 .35415 Mdot
.40639 .5453 Mdot
.64887 .51805 Mdot
.21712 .40732 Mdot
.5693 .71957 Mdot
.4033 .58614 Mdot
.49722 .65519 Mdot
.69116 .5222 Mdot
.64168 .5174 Mdot
.4427 .58253 Mdot
.65457 .54454 Mdot
.36573 .54641 Mdot
.19633 .49191 Mdot
.51965 .64031 Mdot
.47451 .55703 Mdot
.5127 .67566 Mdot
.36118 .74388 Mdot
.6479 .4895 Mdot
.72349 .45443 Mdot
.35158 .59853 Mdot
.65538 .51306 Mdot
.76082 .53317 Mdot
.35773 .5909 Mdot
.44761 .53786 Mdot
.76874 .34881 Mdot
.58845 .32178 Mdot
.53653 .44057 Mdot
.63879 .50247 Mdot
.42837 .5397 Mdot
.43092 .56724 Mdot
.69358 .52228 Mdot
.32487 .64397 Mdot
.5108 .22515 Mdot
.36543 .56438 Mdot
.53062 .64729 Mdot
.53697 .66172 Mdot
.43354 .51011 Mdot
.4163 .51461 Mdot
.56826 .3356 Mdot
.6063 .33041 Mdot
.60252 .3568 Mdot
.55727 .44609 Mdot
.73272 .45571 Mdot
.69846 .6785 Mdot
.68724 .53692 Mdot
.7187 .6108 Mdot
.72386 .2916 Mdot
.35892 .46231 Mdot
.59641 .34311 Mdot
.39799 .52003 Mdot
.36702 .53135 Mdot
.64037 .52721 Mdot
.76596 .46395 Mdot
.36019 .44241 Mdot
.52388 .63478 Mdot
.63657 .50608 Mdot
.38975 .61177 Mdot
.74568 .62663 Mdot
.39903 .34551 Mdot
.79853 .4415 Mdot
.65373 .49801 Mdot
.53042 .67757 Mdot
.66484 .47902 Mdot
.40624 .53286 Mdot
.4065 .47757 Mdot
.5397 .67371 Mdot
.40551 .34487 Mdot
.33748 .54768 Mdot
.38036 .54122 Mdot
.41845 .15844 Mdot
.64486 .25381 Mdot
.67063 .44446 Mdot
.34554 .51702 Mdot
.43285 .57011 Mdot
.35506 .33997 Mdot
.40697 .54068 Mdot
.40005 .56946 Mdot
.46635 .18421 Mdot
.62948 .4569 Mdot
.35711 .36705 Mdot
.39177 .65968 Mdot
.57143 .68534 Mdot
.50145 .84591 Mdot
.57489 .37014 Mdot
.62898 .5359 Mdot
.5199 .21498 Mdot
.58618 .3082 Mdot
.69343 .31029 Mdot
.48893 .8492 Mdot
.54318 .44343 Mdot
.35087 .37444 Mdot
.33539 .4636 Mdot
.37637 .57208 Mdot
.37516 .55199 Mdot
.38051 .34221 Mdot
.55927 .67973 Mdot
.4872 .42452 Mdot
.2116 .61643 Mdot
.37095 .53824 Mdot
.45693 .62416 Mdot
.3743 .80062 Mdot
.50797 .40277 Mdot
.36383 .33265 Mdot
.40787 .3539 Mdot
.37892 .56103 Mdot
.482 .1923 Mdot
.554 .65537 Mdot
.42323 .52705 Mdot
.41751 .50524 Mdot
.59477 .32543 Mdot
.54378 .68779 Mdot
.53192 .34556 Mdot
.722 .45607 Mdot
.57952 .77454 Mdot
.43588 .14672 Mdot
.64102 .50419 Mdot
.48322 .80806 Mdot
.66325 .53473 Mdot
.2778 .31226 Mdot
.58863 .30647 Mdot
.39093 .49468 Mdot
.53529 .70198 Mdot
.42485 .52597 Mdot
.40378 .50944 Mdot
.41254 .52371 Mdot
.33001 .54966 Mdot
.64177 .18508 Mdot
.38751 .33021 Mdot
.40747 .58756 Mdot
.5382 .35487 Mdot
.48375 .81406 Mdot
.23374 .69279 Mdot
.39827 .52785 Mdot
.39076 .56533 Mdot
.52096 .6746 Mdot
.40023 .57597 Mdot
.67317 .53248 Mdot
.54406 .70472 Mdot
.3453 .54381 Mdot
.45005 .82421 Mdot
.35779 .49222 Mdot
.55948 .79993 Mdot
.66184 .47913 Mdot
.75216 .54159 Mdot
.38212 .59427 Mdot
.67398 .43827 Mdot
.53629 .44046 Mdot
.59078 .3614 Mdot
.62748 .51211 Mdot
.55548 .37369 Mdot
.19748 .55543 Mdot
.40035 .46466 Mdot
.34936 .51727 Mdot
.43305 .56346 Mdot
.59028 .35278 Mdot
.62712 .67872 Mdot
.66083 .3348 Mdot
.41376 .61407 Mdot
.5775 .33827 Mdot
.49976 .63632 Mdot
.46566 .37975 Mdot
.52681 .69512 Mdot
.37063 .38161 Mdot
.68377 .49863 Mdot
.39003 .32501 Mdot
.79373 .49653 Mdot
.54634 .68196 Mdot
.52974 .72231 Mdot
.58521 .3524 Mdot
.59146 .50055 Mdot
.81705 .6833 Mdot
.51511 .41712 Mdot
.28393 .36864 Mdot
.54269 .64108 Mdot
.38521 .48294 Mdot
.25297 .34717 Mdot
.59063 .52308 Mdot
.55262 .37337 Mdot
.37839 .49805 Mdot
.45018 .20313 Mdot
.56967 .33502 Mdot
.43452 .55591 Mdot
.56131 .32673 Mdot
.65711 .50074 Mdot
.5858 .32897 Mdot
.57173 .65207 Mdot
.40201 .56002 Mdot
.79941 .70425 Mdot
.37021 .28874 Mdot
.35058 .54845 Mdot
.63778 .50177 Mdot
.48451 .47936 Mdot
.39366 .51022 Mdot
.3677 .36846 Mdot
.56843 .35188 Mdot
.54936 .42042 Mdot
.36188 .56294 Mdot
.58749 .34656 Mdot
.5114 .68457 Mdot
.62689 .51189 Mdot
.42728 .39348 Mdot
.70309 .44339 Mdot
.55493 .64698 Mdot
.73699 .50178 Mdot
.63273 .52363 Mdot
.42493 .57506 Mdot
.42914 .52004 Mdot
.53043 .65226 Mdot
.37222 .24413 Mdot
.38456 .58234 Mdot
.38686 .49128 Mdot
.53703 .35324 Mdot
.56714 .36834 Mdot
.38169 .24134 Mdot
.55554 .32692 Mdot
.40096 .47289 Mdot
.5323 .65223 Mdot
.3664 .51657 Mdot
.52566 .67911 Mdot
.41171 .56987 Mdot
.49786 .61736 Mdot
.5127 .64807 Mdot
.63652 .30718 Mdot
.37061 .50595 Mdot
.45782 .49264 Mdot
.40875 .51641 Mdot
.41117 .54829 Mdot
.56268 .33881 Mdot
.36888 .3322 Mdot
.43718 .59774 Mdot
.35342 .36936 Mdot
.36223 .35504 Mdot
.52517 .74553 Mdot
.59252 .32467 Mdot
.38121 .35412 Mdot
.28134 .71978 Mdot
.60292 .34413 Mdot
.38953 .34245 Mdot
.25979 .71975 Mdot
.6397 .50854 Mdot
.57114 .65685 Mdot
.35798 .53764 Mdot
.74346 .70246 Mdot
.21052 .48645 Mdot
.58964 .30975 Mdot
.35006 .54956 Mdot
.3959 .51704 Mdot
.50798 .6413 Mdot
.16764 .41855 Mdot
.53139 .3891 Mdot
.35881 .50524 Mdot
.55003 .69293 Mdot
.18014 .36478 Mdot
.5317 .36688 Mdot
.38655 .34176 Mdot
.7023 .50914 Mdot
.56066 .62787 Mdot
.61616 .44044 Mdot
.69854 .51745 Mdot
.63815 .3582 Mdot
.78122 .5066 Mdot
.39823 .49102 Mdot
.59609 .34404 Mdot
.81144 .44216 Mdot
.48632 .60619 Mdot
.72204 .52303 Mdot
.29215 .47796 Mdot
.53144 .67428 Mdot
.67468 .53097 Mdot
.38241 .3203 Mdot
.56555 .69715 Mdot
.51767 .64954 Mdot
.6464 .53449 Mdot
.43944 .4232 Mdot
.59529 .57066 Mdot
.6457 .51883 Mdot
.74893 .32457 Mdot
.73811 .6805 Mdot
.59817 .35 Mdot
.36342 .3544 Mdot
.80009 .58845 Mdot
.55267 .66214 Mdot
.43061 .82889 Mdot
.80404 .42539 Mdot
.36591 .56043 Mdot
.37981 .35846 Mdot
.64801 .69455 Mdot
.20357 .59218 Mdot
.67334 .52178 Mdot
.53959 .45314 Mdot
.40602 .32808 Mdot
.3738 .57429 Mdot
.26668 .52172 Mdot
.37179 .49615 Mdot
.68807 .50449 Mdot
.29341 .69771 Mdot
.52991 .67812 Mdot
.63388 .51642 Mdot
.79842 .4438 Mdot
.36732 .543 Mdot
.37413 .49995 Mdot
.23803 .42175 Mdot
.56641 .67844 Mdot
.58675 .36653 Mdot
.3986 .49245 Mdot
.37732 .54064 Mdot
.45071 .52808 Mdot
.47197 .55169 Mdot
.51525 .18993 Mdot
.36109 .50423 Mdot
.74902 .47233 Mdot
.40292 .58694 Mdot
.37265 .50759 Mdot
.49654 .6511 Mdot
.48985 .14278 Mdot
.72804 .45864 Mdot
.3745 .54101 Mdot
.37832 .48313 Mdot
.64566 .53514 Mdot
.56515 .554 Mdot
.59362 .50605 Mdot
.57968 .44411 Mdot
.30482 .43082 Mdot
.32816 .54422 Mdot
.54005 .69852 Mdot
.40324 .35786 Mdot
.43445 .51649 Mdot
.54022 .69758 Mdot
.34173 .50375 Mdot
.57418 .33434 Mdot
.60326 .34169 Mdot
.71509 .5674 Mdot
.38631 .34967 Mdot
.22246 .45981 Mdot
.70843 .62263 Mdot
.53608 .3495 Mdot
.35126 .52064 Mdot
.62089 .52289 Mdot
.55199 .32358 Mdot
.59779 .44326 Mdot
.46281 .55274 Mdot
.5607 .66248 Mdot
.52532 .66461 Mdot
.30067 .33123 Mdot
.70626 .37307 Mdot
.41376 .17475 Mdot
.6606 .49797 Mdot
.34959 .56371 Mdot
.70082 .5908 Mdot
.52434 .66587 Mdot
.26484 .34271 Mdot
.38311 .35522 Mdot
.67428 .523 Mdot
.59112 .2711 Mdot
.52762 .68593 Mdot
.5573 .64332 Mdot
.38219 .4787 Mdot
.38935 .53728 Mdot
.31753 .40307 Mdot
.38142 .40715 Mdot
.68747 .52572 Mdot
.36856 .36132 Mdot
.51807 .36617 Mdot
.36375 .49735 Mdot
.50758 .66221 Mdot
.78766 .62074 Mdot
.38491 .48409 Mdot
.5646 .33565 Mdot
.53226 .67135 Mdot
.3777 .36799 Mdot
.36307 .35958 Mdot
.41019 .54752 Mdot
.264 .63915 Mdot
.66267 .52307 Mdot
.52312 .66979 Mdot
.77083 .58252 Mdot
.39134 .58359 Mdot
.38818 .54302 Mdot
.40523 .44775 Mdot
.6555 .53712 Mdot
.73153 .56045 Mdot
.40597 .33598 Mdot
.55462 .67256 Mdot
.35156 .49907 Mdot
.39346 .34808 Mdot
.72202 .57175 Mdot
.5989 .31495 Mdot
.57949 .32672 Mdot
.36631 .36632 Mdot
.373 .36021 Mdot
.37343 .37163 Mdot
.41925 .83005 Mdot
.56906 .64478 Mdot
.47909 .5419 Mdot
.37279 .58073 Mdot
.29177 .33331 Mdot
.42116 .60732 Mdot
.6531 .48012 Mdot
.58333 .32087 Mdot
.40432 .51288 Mdot
.40133 .48666 Mdot
.44264 .47347 Mdot
.47098 .51661 Mdot
.56795 .71782 Mdot
.54636 .68546 Mdot
.38143 .45845 Mdot
.59341 .32102 Mdot
.13004 .50158 Mdot
.67402 .78729 Mdot
.39027 .59515 Mdot
.58558 .54554 Mdot
.50849 .66315 Mdot
.66377 .54173 Mdot
.59318 .46684 Mdot
.67211 .48025 Mdot
.54878 .66925 Mdot
.36313 .49919 Mdot
.72199 .61592 Mdot
.35944 .35792 Mdot
.42282 .5463 Mdot
.68405 .5133 Mdot
.41869 .54927 Mdot
.69909 .51623 Mdot
.66807 .73415 Mdot
.71199 .27501 Mdot
.3656 .55478 Mdot
.42682 .57771 Mdot
.3006 .46345 Mdot
.39656 .52669 Mdot
.43042 .31577 Mdot
.50989 .66369 Mdot
.36346 .21594 Mdot
.36998 .47694 Mdot
.41188 .72585 Mdot
.38571 .58458 Mdot
.45434 .20763 Mdot
.39255 .5405 Mdot
.4982 .39762 Mdot
.3704 .56904 Mdot
.40387 .56533 Mdot
.66472 .48158 Mdot
.64476 .53379 Mdot
.52961 .71267 Mdot
.58276 .36846 Mdot
.5375 .81227 Mdot
.38272 .54267 Mdot
.70239 .44241 Mdot
.71505 .46376 Mdot
.36928 .35766 Mdot
.54961 .66741 Mdot
.16768 .38285 Mdot
.69878 .49303 Mdot
.55812 .24664 Mdot
.36517 .25944 Mdot
.62167 .4396 Mdot
.58927 .44733 Mdot
.60341 .6357 Mdot
.39572 .36063 Mdot
.37254 .57486 Mdot
.80045 .53029 Mdot
.65396 .26811 Mdot
.4549 .59761 Mdot
.63205 .51314 Mdot
.43322 .76279 Mdot
.7949 .59946 Mdot
.41256 .343 Mdot
.39456 .32631 Mdot
.70022 .50886 Mdot
.55742 .39514 Mdot
.3231 .49819 Mdot
.38561 .35633 Mdot
.54589 .33658 Mdot
.60037 .3505 Mdot
.57714 .28328 Mdot
.55595 .66052 Mdot
.79405 .46038 Mdot
.67208 .6522 Mdot
.69751 .51649 Mdot
.35633 .28986 Mdot
.57218 .64155 Mdot
.58122 .68139 Mdot
.57868 .36442 Mdot
.5593 .33906 Mdot
.57762 .67249 Mdot
.38232 .47038 Mdot
.41615 .44796 Mdot
.37186 .54118 Mdot
.37555 .34073 Mdot
.39689 .53537 Mdot
.56954 .33924 Mdot
.67186 .51679 Mdot
.55356 .34468 Mdot
.69237 .48616 Mdot
.70915 .6643 Mdot
.42082 .53147 Mdot
.39866 .56428 Mdot
.20813 .48367 Mdot
.51178 .69084 Mdot
.77774 .53754 Mdot
.74514 .45402 Mdot
.54151 .36177 Mdot
.39875 .57062 Mdot
.51651 .68855 Mdot
.40764 .36607 Mdot
.20642 .48162 Mdot
.43294 .53472 Mdot
.50974 .6675 Mdot
.35344 .50809 Mdot
.31619 .75273 Mdot
.61639 .20923 Mdot
.54195 .65615 Mdot
.25018 .29723 Mdot
.36343 .49257 Mdot
.57912 .61546 Mdot
.43984 .54606 Mdot
.31875 .35287 Mdot
.38763 .58238 Mdot
.56938 .6898 Mdot
.37456 .53426 Mdot
.55906 .7007 Mdot
.52833 .36637 Mdot
.68137 .53942 Mdot
.53797 .63792 Mdot
.42732 .51488 Mdot
.52705 .87517 Mdot
.68204 .50015 Mdot
.37612 .56153 Mdot
.6879 .49129 Mdot
.55499 .69469 Mdot
.55927 .64693 Mdot
.20138 .61649 Mdot
.64664 .44706 Mdot
.65633 .50202 Mdot
.35806 .51045 Mdot
.64071 .63094 Mdot
.36586 .50978 Mdot
.30384 .39404 Mdot
.42725 .49559 Mdot
.39281 .58259 Mdot
.19495 .65033 Mdot
.67519 .53395 Mdot
.43062 .17626 Mdot
.21573 .63311 Mdot
.40496 .82516 Mdot
.53875 .61747 Mdot
.41193 .34541 Mdot
.46295 .83841 Mdot
.71683 .45255 Mdot
.58345 .34062 Mdot
.40561 .51475 Mdot
.58438 .7061 Mdot
.65821 .52725 Mdot
.37084 .33181 Mdot
.3662 .55554 Mdot
.55903 .33769 Mdot
.52201 .23328 Mdot
.70695 .51794 Mdot
.55309 .66396 Mdot
.51926 .63634 Mdot
.21855 .31475 Mdot
.34789 .50341 Mdot
.39602 .56769 Mdot
.68772 .50191 Mdot
.48648 .59383 Mdot
.39149 .36705 Mdot
.46471 .21737 Mdot
.65807 .5009 Mdot
.57093 .4956 Mdot
.55372 .68516 Mdot
.39731 .51811 Mdot
.62371 .70329 Mdot
.57807 .26853 Mdot
.44153 .66641 Mdot
.38252 .33903 Mdot
.29748 .40036 Mdot
.56995 .68895 Mdot
.67678 .51089 Mdot
.70974 .39503 Mdot
.43097 .47463 Mdot
.39146 .51901 Mdot
.2921 .40129 Mdot
.46696 .4263 Mdot
.2247 .36551 Mdot
.43306 .55185 Mdot
.47498 .42436 Mdot
.42496 .55884 Mdot
.44589 .49726 Mdot
.39914 .47467 Mdot
.38963 .54906 Mdot
.50928 .66582 Mdot
.45929 .58242 Mdot
.58865 .34037 Mdot
.30291 .6077 Mdot
.5724 .4589 Mdot
.35686 .55785 Mdot
.3662 .50121 Mdot
.46736 .71186 Mdot
.71119 .46993 Mdot
.52384 .64327 Mdot
.49354 .6766 Mdot
.66306 .54556 Mdot
.43834 .46605 Mdot
.56713 .37778 Mdot
.45799 .57184 Mdot
.55974 .34243 Mdot
.51239 .67842 Mdot
.53815 .36451 Mdot
.69705 .53218 Mdot
.59777 .34137 Mdot
.73769 .45709 Mdot
.66838 .53146 Mdot
.56706 .66916 Mdot
.40386 .55177 Mdot
.63699 .50626 Mdot
.24369 .41969 Mdot
.37623 .34113 Mdot
.20187 .62304 Mdot
.34747 .49741 Mdot
.61461 .45587 Mdot
.48422 .51093 Mdot
.55494 .34501 Mdot
.5593 .18957 Mdot
.51395 .64611 Mdot
.37274 .37934 Mdot
.51242 .68004 Mdot
.77721 .3419 Mdot
.36514 .34098 Mdot
.2677 .72911 Mdot
.73401 .3837 Mdot
.54681 .40902 Mdot
.37832 .47073 Mdot
.27468 .53162 Mdot
.51737 .36317 Mdot
.65975 .52779 Mdot
.71825 .3694 Mdot
.40688 .56377 Mdot
.61133 .24237 Mdot
.53252 .71587 Mdot
.58875 .36113 Mdot
.67003 .50708 Mdot
.6355 .5167 Mdot
.42224 .51648 Mdot
.41471 .25274 Mdot
.42654 .55101 Mdot
.69041 .36703 Mdot
.30191 .42373 Mdot
.37337 .43599 Mdot
.37752 .56642 Mdot
.53386 .38145 Mdot
.35353 .50879 Mdot
.35493 .42785 Mdot
.80995 .49335 Mdot
.33329 .55361 Mdot
.7604 .46387 Mdot
.36957 .29205 Mdot
.54311 .67698 Mdot
.38784 .59897 Mdot
.64117 .43794 Mdot
.35066 .50315 Mdot
.81609 .33306 Mdot
.39094 .34393 Mdot
.66757 .43139 Mdot
.39989 .58571 Mdot
.41378 .50585 Mdot
.29313 .53339 Mdot
.59535 .68688 Mdot
.58446 .26553 Mdot
.38699 .52308 Mdot
.26817 .45737 Mdot
.67606 .49137 Mdot
.42997 .54607 Mdot
.37535 .55503 Mdot
.54184 .75837 Mdot
.64553 .52986 Mdot
.54507 .35204 Mdot
.58561 .30607 Mdot
.51271 .38956 Mdot
.35359 .32774 Mdot
.55311 .46745 Mdot
.27824 .33928 Mdot
.63208 .23043 Mdot
.39788 .36948 Mdot
.36121 .48565 Mdot
.32822 .453 Mdot
.37823 .48587 Mdot
.37887 .31933 Mdot
.65112 .53325 Mdot
.52406 .64158 Mdot
.66279 .5875 Mdot
.51088 .37475 Mdot
.43239 .56018 Mdot
.36169 .3294 Mdot
.5632 .66312 Mdot
.41938 .36171 Mdot
.54929 .676 Mdot
.65798 .50494 Mdot
.65097 .54679 Mdot
.37383 .32567 Mdot
.52186 .6906 Mdot
.74314 .4888 Mdot
.21089 .59557 Mdot
.42436 .49075 Mdot
.67001 .56475 Mdot
.51599 .69444 Mdot
.56255 .71546 Mdot
.54075 .71177 Mdot
.41679 .54366 Mdot
.58263 .54561 Mdot
.45185 .54076 Mdot
.68971 .52263 Mdot
.56065 .32762 Mdot
.3326 .33728 Mdot
.74149 .66417 Mdot
.33653 .31954 Mdot
.33827 .54084 Mdot
.36874 .53736 Mdot
.37855 .56084 Mdot
.41135 .48771 Mdot
.68522 .38288 Mdot
.41909 .52114 Mdot
.67201 .48188 Mdot
.5652 .34842 Mdot
.36273 .57097 Mdot
.59529 .31288 Mdot
.61088 .62485 Mdot
.4046 .35679 Mdot
.5415 .46154 Mdot
.51992 .85152 Mdot
.56053 .6565 Mdot
.55555 .32611 Mdot
.58369 .34244 Mdot
.38355 .37464 Mdot
.65597 .52412 Mdot
.55407 .67998 Mdot
.32673 .36403 Mdot
.37078 .36743 Mdot
.37547 .53703 Mdot
.62749 .30996 Mdot
.6001 .24813 Mdot
.38645 .57771 Mdot
.39438 .50286 Mdot
.60454 .31775 Mdot
.55233 .39757 Mdot
.83862 .56583 Mdot
.23891 .36679 Mdot
.37076 .32831 Mdot
.40446 .34509 Mdot
.57617 .6956 Mdot
.42728 .58297 Mdot
.69211 .5198 Mdot
.21206 .4195 Mdot
.47653 .45849 Mdot
.21988 .44695 Mdot
.43142 .39113 Mdot
.42982 .52827 Mdot
.27255 .61333 Mdot
.36617 .54351 Mdot
.51001 .64584 Mdot
.56175 .68868 Mdot
.53961 .64369 Mdot
.66395 .52649 Mdot
.38108 .7539 Mdot
.66127 .4839 Mdot
.55202 .83937 Mdot
.57234 .68661 Mdot
.67487 .40722 Mdot
.53993 .38099 Mdot
.37342 .59284 Mdot
.38451 .36776 Mdot
.69778 .4769 Mdot
.32578 .50385 Mdot
.4937 .18939 Mdot
.59121 .34906 Mdot
.56803 .66999 Mdot
.60273 .63754 Mdot
.6328 .78433 Mdot
.59223 .48213 Mdot
.37759 .61066 Mdot
.28521 .52852 Mdot
.36688 .35587 Mdot
.43481 .66261 Mdot
.37273 .31718 Mdot
.68185 .51908 Mdot
.39867 .56067 Mdot
.39691 .55279 Mdot
.41578 .56797 Mdot
.4196 .52468 Mdot
.65349 .54227 Mdot
.35042 .57272 Mdot
.72369 .256 Mdot
.60427 .34032 Mdot
.34687 .77375 Mdot
.39579 .3523 Mdot
.63024 .50844 Mdot
.56488 .34657 Mdot
.61498 .33821 Mdot
.24724 .37922 Mdot
.3671 .56525 Mdot
.40653 .51381 Mdot
.56802 .2534 Mdot
.43105 .5562 Mdot
.38232 .60847 Mdot
.58659 .3448 Mdot
.33537 .32524 Mdot
.39896 .37176 Mdot
.39381 .32846 Mdot
.64636 .52684 Mdot
.51743 .68671 Mdot
.3793 .34861 Mdot
.52989 .36444 Mdot
.33725 .51574 Mdot
.41613 .50201 Mdot
.51767 .69749 Mdot
.80446 .41914 Mdot
.41207 .33978 Mdot
.60123 .62634 Mdot
.55294 .70115 Mdot
.566 .63907 Mdot
.39006 .51787 Mdot
.45993 .59398 Mdot
.5896 .67948 Mdot
.38134 .37819 Mdot
.6295 .51401 Mdot
.57794 .43478 Mdot
.68862 .51253 Mdot
.56118 .67637 Mdot
.42296 .50388 Mdot
.56375 .67895 Mdot
.34512 .52259 Mdot
.39195 .86763 Mdot
.39427 .54815 Mdot
.656 .23377 Mdot
.30383 .36073 Mdot
.57654 .3498 Mdot
.74326 .48515 Mdot
.58258 .36312 Mdot
.55754 .69854 Mdot
.42935 .51159 Mdot
.404 .33491 Mdot
.3572 .80654 Mdot
.57771 .65033 Mdot
.57803 .33239 Mdot
.56395 .38346 Mdot
.66617 .53371 Mdot
.36219 .572 Mdot
.39586 .52089 Mdot
.56846 .36425 Mdot
.40275 .4318 Mdot
.5225 .68332 Mdot
.39046 .56691 Mdot
.37089 .52055 Mdot
.57859 .34995 Mdot
.20977 .58379 Mdot
.59004 .64219 Mdot
.39223 .55761 Mdot
.72361 .42194 Mdot
.64989 .48232 Mdot
.39204 .47603 Mdot
.361 .58708 Mdot
.37958 .36191 Mdot
.40536 .79603 Mdot
.81006 .50673 Mdot
.65806 .47835 Mdot
.57635 .3708 Mdot
.34967 .49852 Mdot
.54198 .38143 Mdot
.42149 .50803 Mdot
.49357 .79527 Mdot
.59532 .35488 Mdot
.40232 .49879 Mdot
.40475 .59249 Mdot
.56625 .68231 Mdot
.41885 .51729 Mdot
.48806 .72538 Mdot
.53074 .34463 Mdot
.41065 .50607 Mdot
.26735 .64277 Mdot
.64437 .50877 Mdot
.39173 .59626 Mdot
.4007 .34446 Mdot
.32571 .35394 Mdot
.70375 .6351 Mdot
.71794 .44276 Mdot
.39755 .33537 Mdot
.4192 .55145 Mdot
.56932 .38216 Mdot
.70003 .51326 Mdot
.60098 .22866 Mdot
.39982 .57277 Mdot
.68706 .50399 Mdot
.67151 .51486 Mdot
.39553 .33933 Mdot
.35712 .19501 Mdot
.35854 .58316 Mdot
.39789 .52892 Mdot
.51136 .74763 Mdot
.50302 .63872 Mdot
.39849 .53917 Mdot
.37378 .48203 Mdot
.6771 .48363 Mdot
.36066 .605 Mdot
.45422 .7465 Mdot
.42509 .22778 Mdot
.6902 .47973 Mdot
.52467 .4218 Mdot
.58002 .37434 Mdot
.39367 .35458 Mdot
.53839 .67042 Mdot
.39667 .31926 Mdot
.5938 .33086 Mdot
.36328 .48682 Mdot
.69665 .49422 Mdot
.46693 .6583 Mdot
.70132 .51478 Mdot
.69893 .43807 Mdot
.50555 .67108 Mdot
.67801 .60037 Mdot
.74872 .25516 Mdot
.67564 .65831 Mdot
.69635 .46445 Mdot
.36942 .35768 Mdot
.63503 .35797 Mdot
.37015 .52561 Mdot
.40265 .65192 Mdot
.40821 .55203 Mdot
.27514 .64544 Mdot
.55891 .32619 Mdot
.60215 .35808 Mdot
.39616 .5591 Mdot
.30342 .41538 Mdot
.69821 .52241 Mdot
.67453 .53311 Mdot
.40867 .50777 Mdot
.65506 .51294 Mdot
.38844 .53424 Mdot
.56414 .33995 Mdot
.47477 .1669 Mdot
.36986 .54942 Mdot
.44728 .54402 Mdot
.60584 .52349 Mdot
.20764 .65602 Mdot
.75292 .42207 Mdot
.27265 .60466 Mdot
.66054 .76839 Mdot
.65587 .51254 Mdot
.44932 .57157 Mdot
.51576 .41976 Mdot
.60369 .31612 Mdot
.74246 .48974 Mdot
.40389 .54247 Mdot
.40797 .54062 Mdot
.39605 .57042 Mdot
.37383 .49915 Mdot
.41047 .65557 Mdot
.4805 .5899 Mdot
.31254 .6837 Mdot
.40553 .51091 Mdot
.26339 .53293 Mdot
.63947 .50188 Mdot
.51943 .71053 Mdot
.39638 .3168 Mdot
.42913 .52713 Mdot
.47875 .61162 Mdot
.64306 .48766 Mdot
.55442 .83859 Mdot
.65636 .53356 Mdot
.54713 .36216 Mdot
.67294 .541 Mdot
.34982 .54023 Mdot
.53614 .66123 Mdot
.57219 .44397 Mdot
.65339 .30526 Mdot
.583 .33991 Mdot
.35061 .54868 Mdot
.65296 .43013 Mdot
.58619 .33849 Mdot
.61423 .62711 Mdot
.53298 .66382 Mdot
.2613 .45962 Mdot
.56227 .68864 Mdot
.40316 .49841 Mdot
.39422 .49295 Mdot
.72195 .5365 Mdot
.6962 .52895 Mdot
.5601 .69253 Mdot
.40288 .16138 Mdot
.37142 .31666 Mdot
.54259 .64651 Mdot
.40272 .45844 Mdot
.52683 .52348 Mdot
.5297 .65637 Mdot
.35301 .40368 Mdot
.66505 .52944 Mdot
.57488 .68859 Mdot
.40294 .45732 Mdot
.77027 .37703 Mdot
.369 .37385 Mdot
.53847 .39411 Mdot
.52011 .33321 Mdot
.544 .33032 Mdot
.62954 .52339 Mdot
.58645 .35454 Mdot
.67019 .48944 Mdot
.76924 .54187 Mdot
.24726 .54635 Mdot
.62069 .52658 Mdot
.63759 .53597 Mdot
.58474 .35189 Mdot
.38315 .57001 Mdot
.53129 .33229 Mdot
.44217 .51535 Mdot
.33766 .48376 Mdot
.66003 .49141 Mdot
.56964 .68715 Mdot
.56822 .64945 Mdot
.26784 .53101 Mdot
.51809 .63641 Mdot
.55958 .34107 Mdot
.62224 .21558 Mdot
.79174 .50222 Mdot
.67717 .49444 Mdot
.64424 .53876 Mdot
.36583 .50711 Mdot
.5541 .37378 Mdot
.52502 .37545 Mdot
.6796 .52542 Mdot
.37851 .6331 Mdot
.44327 .56872 Mdot
.54576 .72215 Mdot
.57365 .68437 Mdot
.53684 .65339 Mdot
.54747 .7106 Mdot
.43963 .72185 Mdot
.6667 .5301 Mdot
.56695 .69328 Mdot
.4043 .50225 Mdot
.40666 .54033 Mdot
.57809 .44589 Mdot
.39647 .33159 Mdot
.34058 .51025 Mdot
.39241 .47009 Mdot
.39198 .51594 Mdot
.58155 .32789 Mdot
.36843 .45221 Mdot
.58895 .36507 Mdot
.53486 .39318 Mdot
.60262 .32625 Mdot
.72056 .4531 Mdot
.28432 .51374 Mdot
.69079 .75875 Mdot
.35859 .50516 Mdot
.49549 .58571 Mdot
.54002 .37845 Mdot
.53249 .18726 Mdot
.7181 .57074 Mdot
.39923 .57155 Mdot
.57549 .27101 Mdot
.5715 .36315 Mdot
.52354 .63232 Mdot
.40092 .54425 Mdot
.50757 .38826 Mdot
.40181 .36065 Mdot
.4144 .46855 Mdot
.56602 .31333 Mdot
.52928 .69571 Mdot
.37322 .30903 Mdot
.57107 .69568 Mdot
.59699 .31981 Mdot
.40116 .59366 Mdot
.83262 .66784 Mdot
.51368 .38376 Mdot
.26749 .71159 Mdot
.55381 .61763 Mdot
.39004 .56783 Mdot
.54977 .32865 Mdot
.50432 .63873 Mdot
.62749 .52003 Mdot
.49675 .45809 Mdot
.5206 .6402 Mdot
.60201 .35787 Mdot
.55952 .31733 Mdot
.58622 .3438 Mdot
.54185 .6839 Mdot
.43767 .51642 Mdot
.53376 .68479 Mdot
.67111 .54066 Mdot
.36242 .53218 Mdot
.58407 .80674 Mdot
.49067 .58615 Mdot
.55643 .69805 Mdot
.54783 .3441 Mdot
.35518 .34548 Mdot
.36255 .55156 Mdot
.24926 .68016 Mdot
.34586 .54116 Mdot
.68652 .49626 Mdot
.42473 .20079 Mdot
.46463 .66061 Mdot
.37797 .58228 Mdot
.36642 .50591 Mdot
.68246 .52944 Mdot
.36513 .56129 Mdot
.37982 .58134 Mdot
.6943 .44918 Mdot
.54524 .68959 Mdot
.37332 .53133 Mdot
.54513 .34059 Mdot
.78942 .54346 Mdot
.44991 .55643 Mdot
.50066 .25982 Mdot
.27449 .4412 Mdot
.39648 .19993 Mdot
.40751 .55557 Mdot
.22685 .39668 Mdot
.38083 .49808 Mdot
.42377 .5417 Mdot
.36107 .51092 Mdot
.27648 .59838 Mdot
.5939 .34326 Mdot
.57395 .34093 Mdot
.37157 .37582 Mdot
.27335 .44512 Mdot
.38083 .35969 Mdot
.65589 .52955 Mdot
.47413 .26832 Mdot
.59541 .35391 Mdot
.52935 .69655 Mdot
.4221 .55244 Mdot
.51123 .37996 Mdot
.40053 .519 Mdot
.34826 .53442 Mdot
.53454 .38472 Mdot
.52636 .38705 Mdot
.68531 .43742 Mdot
.4035 .35112 Mdot
.53667 .64028 Mdot
.35313 .479 Mdot
.36173 .35273 Mdot
.43734 .51861 Mdot
.29032 .32659 Mdot
.53392 .64158 Mdot
.54241 .68917 Mdot
.54943 .63529 Mdot
.36253 .48752 Mdot
.35437 .54989 Mdot
.66201 .48432 Mdot
.52264 .69325 Mdot
.64511 .51251 Mdot
.56024 .44426 Mdot
.48658 .25166 Mdot
.40405 .54239 Mdot
.58584 .60957 Mdot
.38789 .3632 Mdot
.55331 .35462 Mdot
.53582 .2427 Mdot
.36437 .37081 Mdot
.34604 .538 Mdot
.53519 .38253 Mdot
.3799 .32164 Mdot
.33646 .60349 Mdot
.75147 .71012 Mdot
.35656 .3319 Mdot
.40457 .50367 Mdot
.31378 .56436 Mdot
.21278 .53555 Mdot
.35482 .32778 Mdot
.69398 .49596 Mdot
.36095 .48787 Mdot
.48505 .5383 Mdot
.41017 .33608 Mdot
.77749 .55502 Mdot
.5706 .35399 Mdot
.77974 .42798 Mdot
.33804 .47356 Mdot
.36004 .63819 Mdot
.38777 .31624 Mdot
.55438 .6765 Mdot
.49662 .66267 Mdot
.38435 .51109 Mdot
.35642 .32283 Mdot
.69973 .4879 Mdot
.56474 .35577 Mdot
.74021 .46261 Mdot
.53932 .68327 Mdot
.62084 .59955 Mdot
.56008 .33058 Mdot
.59478 .61022 Mdot
.43358 .21294 Mdot
.38503 .43457 Mdot
.25451 .58717 Mdot
.67037 .28347 Mdot
.36419 .48147 Mdot
.36554 .32081 Mdot
.64975 .48409 Mdot
.70024 .50155 Mdot
.66122 .50024 Mdot
.74371 .48043 Mdot
.58494 .465 Mdot
.58468 .3144 Mdot
.63696 .28331 Mdot
.39241 .34949 Mdot
.24461 .49583 Mdot
.43675 .5252 Mdot
.36883 .53983 Mdot
.34856 .56117 Mdot
.43196 .5461 Mdot
.37893 .50422 Mdot
.65318 .51985 Mdot
.74499 .47864 Mdot
.55332 .42186 Mdot
.52797 .64779 Mdot
.33954 .31807 Mdot
.53965 .38081 Mdot
.60678 .32482 Mdot
.38106 .32875 Mdot
.61062 .66077 Mdot
.57553 .31355 Mdot
.53969 .36191 Mdot
.34296 .53992 Mdot
.52983 .68745 Mdot
.45523 .58835 Mdot
.38607 .49157 Mdot
.558 .34978 Mdot
.45665 .38382 Mdot
.47075 .73621 Mdot
.45001 .49446 Mdot
.38488 .30368 Mdot
.57423 .54237 Mdot
.35582 .32677 Mdot
.44279 .53843 Mdot
.51552 .18435 Mdot
.59413 .33243 Mdot
.54839 .36976 Mdot
.36773 .32212 Mdot
.58325 .62362 Mdot
.53478 .67428 Mdot
.61534 .33881 Mdot
.68223 .48981 Mdot
.3862 .48748 Mdot
.50447 .23848 Mdot
.56476 .61013 Mdot
.43576 .25115 Mdot
.66789 .49661 Mdot
.5274 .37463 Mdot
.36458 .57452 Mdot
.4029 .50327 Mdot
.3698 .36085 Mdot
.64377 .74221 Mdot
.40247 .46433 Mdot
.40837 .82709 Mdot
.7237 .28476 Mdot
.78877 .39708 Mdot
.39151 .51921 Mdot
.54578 .68794 Mdot
.58857 .30663 Mdot
.36445 .35602 Mdot
.33338 .5239 Mdot
.73278 .72706 Mdot
.51617 .70195 Mdot
.68037 .5154 Mdot
.51806 .42623 Mdot
.59408 .46628 Mdot
.34453 .50797 Mdot
.40722 .55146 Mdot
.41917 .53692 Mdot
.81098 .62736 Mdot
.57245 .32933 Mdot
.50626 .65907 Mdot
.38224 .3367 Mdot
.516 .63814 Mdot
.57641 .34421 Mdot
.64453 .60172 Mdot
.36165 .56481 Mdot
.51622 .70068 Mdot
.55177 .67434 Mdot
.66468 .53364 Mdot
.63039 .52878 Mdot
.54619 .43361 Mdot
.39318 .54732 Mdot
.5311 .33904 Mdot
.56814 .67999 Mdot
.61607 .30426 Mdot
.36488 .34376 Mdot
.64633 .49186 Mdot
.4072 .51239 Mdot
.5913 .33497 Mdot
.34804 .57076 Mdot
.5228 .66103 Mdot
.5392 .36323 Mdot
.68059 .43781 Mdot
.40363 .34469 Mdot
.41106 .52894 Mdot
.39964 .31079 Mdot
.57383 .37216 Mdot
.36987 .52182 Mdot
.60496 .68786 Mdot
.36137 .30729 Mdot
.66104 .3276 Mdot
.58029 .31633 Mdot
.69741 .44198 Mdot
.55558 .64026 Mdot
.76325 .57151 Mdot
.54972 .36653 Mdot
.6067 .69203 Mdot
.69097 .70003 Mdot
.34917 .48088 Mdot
.54924 .659 Mdot
.62934 .34546 Mdot
.48235 .85932 Mdot
.22399 .59626 Mdot
.37582 .56021 Mdot
.56141 .32302 Mdot
.36367 .32917 Mdot
.67598 .49382 Mdot
.50129 .25816 Mdot
.35478 .42854 Mdot
.55102 .38649 Mdot
.36191 .507 Mdot
.55648 .69076 Mdot
.66919 .52381 Mdot
.72562 .62543 Mdot
.53534 .35668 Mdot
.56774 .32389 Mdot
.36802 .57671 Mdot
.38364 .35412 Mdot
.24441 .64077 Mdot
.56781 .33781 Mdot
.57634 .25633 Mdot
.63941 .3554 Mdot
.36107 .32957 Mdot
.38877 .49916 Mdot
.27057 .51981 Mdot
.40491 .48336 Mdot
.28652 .73812 Mdot
.57676 .36825 Mdot
.5231 .64908 Mdot
.41323 .55098 Mdot
.41221 .23094 Mdot
.55821 .35334 Mdot
.58651 .54411 Mdot
.46932 .35263 Mdot
.66658 .52957 Mdot
.54233 .24132 Mdot
.4013 .5326 Mdot
.69982 .51949 Mdot
.38735 .36307 Mdot
.38909 .55423 Mdot
.35421 .54726 Mdot
.51074 .6355 Mdot
.68332 .51926 Mdot
.71042 .70489 Mdot
.63401 .51864 Mdot
.66295 .47919 Mdot
.54209 .62811 Mdot
.38071 .52383 Mdot
.54618 .3601 Mdot
.56912 .36545 Mdot
.3354 .49603 Mdot
.54552 .17784 Mdot
.53417 .67634 Mdot
.35803 .28911 Mdot
.81886 .60687 Mdot
.36815 .43999 Mdot
.53144 .24131 Mdot
.64106 .74204 Mdot
.70096 .49041 Mdot
.40758 .50904 Mdot
.54216 .70044 Mdot
.61474 .34351 Mdot
.55711 .3314 Mdot
.43025 .50776 Mdot
.66775 .5176 Mdot
.39687 .36794 Mdot
.51753 .37049 Mdot
.41631 .25175 Mdot
.42315 .53179 Mdot
.62296 .26112 Mdot
.53773 .33974 Mdot
.39087 .83632 Mdot
.62127 .32079 Mdot
.54588 .65522 Mdot
.34928 .53415 Mdot
.52189 .63592 Mdot
.37597 .33706 Mdot
.53095 .42845 Mdot
.67017 .51736 Mdot
.35305 .44083 Mdot
.81177 .35138 Mdot
.58903 .34946 Mdot
.50954 .66304 Mdot
.37804 .5826 Mdot
.32093 .46686 Mdot
.39597 .53299 Mdot
.3156 .56022 Mdot
.37529 .29168 Mdot
.6537 .49511 Mdot
.68953 .49638 Mdot
.36729 .52724 Mdot
.38175 .37168 Mdot
.52908 .37382 Mdot
.56232 .35771 Mdot
.1605 .62933 Mdot
.61252 .29657 Mdot
.31926 .39741 Mdot
.40955 .53699 Mdot
.59716 .36334 Mdot
.76524 .63369 Mdot
.68671 .50087 Mdot
.43798 .53275 Mdot
.57245 .37551 Mdot
.74378 .33004 Mdot
.32155 .32019 Mdot
.38202 .50308 Mdot
.33365 .56309 Mdot
.68549 .49101 Mdot
.23333 .45263 Mdot
.59697 .3216 Mdot
.43367 .50143 Mdot
.67938 .5442 Mdot
.38915 .22987 Mdot
.81018 .4651 Mdot
.53722 .64047 Mdot
.51018 .40076 Mdot
.65336 .52054 Mdot
.35115 .4664 Mdot
.39722 .34931 Mdot
.52349 .35372 Mdot
.58147 .33024 Mdot
.35618 .51731 Mdot
.35421 .57518 Mdot
.30292 .4663 Mdot
.51145 .66166 Mdot
.63858 .50864 Mdot
.4025 .56164 Mdot
.61498 .58647 Mdot
.41957 .5644 Mdot
.65288 .48947 Mdot
.79852 .73125 Mdot
.35909 .47107 Mdot
.39521 .53108 Mdot
.24005 .63667 Mdot
.52215 .63898 Mdot
.51791 .63448 Mdot
.67783 .2513 Mdot
.40977 .53624 Mdot
.5647 .24585 Mdot
.53754 .63899 Mdot
.53077 .67321 Mdot
.64127 .41054 Mdot
.36581 .54994 Mdot
.21119 .47308 Mdot
.69841 .51134 Mdot
.67873 .48143 Mdot
.5345 .68373 Mdot
.37772 .46014 Mdot
.702 .49515 Mdot
.42715 .67707 Mdot
.55465 .37427 Mdot
.4996 .18226 Mdot
.51943 .66219 Mdot
.52546 .44254 Mdot
.67652 .4962 Mdot
.54806 .8406 Mdot
.58642 .27676 Mdot
.38866 .56941 Mdot
.41415 .52982 Mdot
.39117 .36094 Mdot
.35231 .47858 Mdot
.60305 .35635 Mdot
.6547 .513 Mdot
.27644 .69292 Mdot
.54075 .64417 Mdot
.39128 .54236 Mdot
.60598 .62565 Mdot
.7133 .65088 Mdot
.7463 .3913 Mdot
.54344 .67633 Mdot
.5538 .65913 Mdot
.59288 .31956 Mdot
.55312 .32872 Mdot
.3812 .51577 Mdot
.68576 .52483 Mdot
.53024 .69874 Mdot
.65695 .489 Mdot
.593 .33107 Mdot
.54404 .35778 Mdot
.59664 .35377 Mdot
.4404 .5056 Mdot
.53918 .3553 Mdot
.40057 .25374 Mdot
.62673 .60414 Mdot
.58137 .68275 Mdot
.82825 .425 Mdot
.72678 .62314 Mdot
.47205 .47484 Mdot
.40405 .3326 Mdot
.57233 .37299 Mdot
.65522 .54071 Mdot
.36731 .50891 Mdot
.40372 .51597 Mdot
.5075 .39173 Mdot
.68176 .5355 Mdot
.37149 .33374 Mdot
.68911 .53261 Mdot
.39679 .34076 Mdot
.58978 .26805 Mdot
.35915 .5698 Mdot
.4098 .49849 Mdot
.65157 .51494 Mdot
.5383 .36038 Mdot
.56829 .34629 Mdot
.35864 .32378 Mdot
.46323 .43407 Mdot
.58805 .3408 Mdot
.52026 .66206 Mdot
.42673 .71459 Mdot
.57326 .31039 Mdot
.4 .54221 Mdot
.27585 .33661 Mdot
.41532 .6491 Mdot
.41904 .49253 Mdot
.63646 .43902 Mdot
.21122 .36251 Mdot
.41457 .55664 Mdot
.22226 .33342 Mdot
.70066 .44313 Mdot
.5186 .64059 Mdot
.56609 .32213 Mdot
.61275 .34296 Mdot
.36192 .60094 Mdot
.40525 .38707 Mdot
.33477 .50542 Mdot
.529 .63648 Mdot
.49553 .64614 Mdot
.76287 .34242 Mdot
.26918 .71466 Mdot
.3779 .31714 Mdot
.38435 .32665 Mdot
.55271 .36603 Mdot
.18175 .56522 Mdot
.44267 .48653 Mdot
.37132 .32924 Mdot
.24192 .53479 Mdot
.36315 .50182 Mdot
.29156 .39162 Mdot
.56535 .26785 Mdot
.54206 .68603 Mdot
.27331 .52931 Mdot
.55244 .36059 Mdot
.51184 .65457 Mdot
.63954 .58571 Mdot
.34292 .50609 Mdot
.53494 .64243 Mdot
.66206 .48603 Mdot
.6951 .31489 Mdot
.55785 .64615 Mdot
.28193 .32827 Mdot
.68029 .52597 Mdot
.64129 .37451 Mdot
.25488 .49238 Mdot
.66452 .16923 Mdot
.65586 .5192 Mdot
.54224 .38596 Mdot
.56926 .3647 Mdot
.56186 .35912 Mdot
.51139 .6491 Mdot
.52584 .37879 Mdot
.51182 .66682 Mdot
.20696 .54828 Mdot
.46286 .43492 Mdot
.37235 .32589 Mdot
.65059 .44818 Mdot
.55488 .66876 Mdot
.59776 .20607 Mdot
.76731 .28064 Mdot
.41157 .51094 Mdot
.63812 .52845 Mdot
.37611 .32034 Mdot
.33907 .80358 Mdot
.38338 .36228 Mdot
.51049 .40725 Mdot
.45823 .18244 Mdot
.38661 .53905 Mdot
.44329 .77305 Mdot
.40293 .33474 Mdot
.55287 .68311 Mdot
.36927 .52778 Mdot
.74077 .4978 Mdot
.38774 .35701 Mdot
.39741 .36605 Mdot
.37615 .51544 Mdot
.56821 .67077 Mdot
.54813 .35511 Mdot
.67582 .5431 Mdot
.35514 .36421 Mdot
.50657 .60229 Mdot
.36366 .47651 Mdot
.35323 .49189 Mdot
.59178 .5069 Mdot
.34566 .4269 Mdot
.65632 .51307 Mdot
.22279 .52635 Mdot
.55439 .32844 Mdot
.61328 .38654 Mdot
.68646 .262 Mdot
.64702 .44323 Mdot
.58054 .3638 Mdot
.5804 .36733 Mdot
.38018 .50694 Mdot
.33796 .42849 Mdot
.40705 .20522 Mdot
.65962 .46075 Mdot
.58168 .30821 Mdot
.56298 .35528 Mdot
.49961 .67011 Mdot
.76575 .34055 Mdot
.33383 .53161 Mdot
.6656 .47591 Mdot
.58936 .33361 Mdot
.49648 .79556 Mdot
.38467 .3499 Mdot
.55945 .1969 Mdot
.36469 .57251 Mdot
.39816 .56444 Mdot
.66583 .50588 Mdot
.66222 .48321 Mdot
.72624 .53807 Mdot
.74314 .30471 Mdot
.19962 .4343 Mdot
.76037 .60223 Mdot
.49544 .78975 Mdot
.5155 .70486 Mdot
.55754 .69719 Mdot
.72848 .46217 Mdot
.63469 .50435 Mdot
.41497 .55277 Mdot
.53156 .69862 Mdot
.72605 .36969 Mdot
.48411 .64313 Mdot
.30336 .39792 Mdot
.46775 .23105 Mdot
.34551 .53069 Mdot
.53641 .69304 Mdot
.51868 .6445 Mdot
.53996 .70589 Mdot
.70093 .44375 Mdot
.38747 .52354 Mdot
.37266 .56589 Mdot
.41513 .56291 Mdot
.46919 .60209 Mdot
.42208 .52423 Mdot
.65634 .45739 Mdot
.57286 .502 Mdot
.33948 .75647 Mdot
.41454 .48541 Mdot
.69369 .48579 Mdot
.35072 .4892 Mdot
.38307 .37234 Mdot
.36278 .50925 Mdot
.3076 .39397 Mdot
.68264 .50565 Mdot
.57264 .62389 Mdot
.75947 .59655 Mdot
.36251 .56801 Mdot
.39922 .36927 Mdot
.47678 .50304 Mdot
.66347 .73936 Mdot
.38134 .40578 Mdot
.52047 .66322 Mdot
.56189 .37366 Mdot
.66655 .53976 Mdot
.54362 .36438 Mdot
.42395 .48785 Mdot
.62664 .44006 Mdot
.6479 .68578 Mdot
.51603 .43322 Mdot
.43167 .53423 Mdot
.37912 .44463 Mdot
.52475 .66808 Mdot
.53573 .38267 Mdot
.54478 .73032 Mdot
.41478 .54521 Mdot
.37976 .33946 Mdot
.39071 .35473 Mdot
.72691 .55539 Mdot
.53518 .80486 Mdot
.76011 .56295 Mdot
.66291 .50657 Mdot
.56947 .33551 Mdot
.38405 .31453 Mdot
.51115 .58802 Mdot
.63144 .4959 Mdot
.68104 .53068 Mdot
.67898 .5226 Mdot
.36919 .48678 Mdot
.58888 .36528 Mdot
.32876 .74381 Mdot
.60059 .3587 Mdot
.35801 .55732 Mdot
.5723 .32785 Mdot
.58904 .3614 Mdot
.39508 .3571 Mdot
.64688 .52787 Mdot
.59088 .32577 Mdot
.4045 .49886 Mdot
.55463 .64856 Mdot
.48263 .43304 Mdot
.30893 .34317 Mdot
.32145 .76686 Mdot
.34623 .78135 Mdot
.57168 .66535 Mdot
.52457 .82977 Mdot
.67206 .47239 Mdot
.37478 .6323 Mdot
.70247 .4232 Mdot
.41696 .49817 Mdot
.61927 .20256 Mdot
.58623 .31418 Mdot
.5367 .38526 Mdot
.38672 .49731 Mdot
.53863 .39991 Mdot
.39238 .53893 Mdot
.57822 .32364 Mdot
.33891 .32433 Mdot
.37354 .59799 Mdot
.53261 .36599 Mdot
.44677 .52076 Mdot
.36189 .54688 Mdot
.54193 .68749 Mdot
.54812 .32911 Mdot
.43857 .53711 Mdot
.24631 .73082 Mdot
.65301 .4871 Mdot
.65855 .43785 Mdot
.27337 .31974 Mdot
.65229 .52083 Mdot
.54042 .64725 Mdot
.33706 .48608 Mdot
.37915 .36559 Mdot
.55895 .67467 Mdot
.33245 .29669 Mdot
.40042 .33304 Mdot
.61499 .20713 Mdot
.52109 .66923 Mdot
.57023 .3121 Mdot
.39832 .35679 Mdot
.45249 .55733 Mdot
.51932 .36316 Mdot
.48367 .46474 Mdot
.57328 .36995 Mdot
.39685 .52132 Mdot
.7479 .46807 Mdot
.64337 .49367 Mdot
.37751 .55887 Mdot
.51766 .37412 Mdot
.7243 .4552 Mdot
.3658 .49049 Mdot
.37129 .50533 Mdot
.80158 .41101 Mdot
.56363 .21613 Mdot
.36623 .35263 Mdot
.5027 .65015 Mdot
.40426 .50197 Mdot
.40228 .35415 Mdot
.45562 .30905 Mdot
.35831 .48463 Mdot
.52167 .70546 Mdot
.46664 .53034 Mdot
.52777 .35397 Mdot
.644 .51659 Mdot
.54763 .44133 Mdot
.40231 .35945 Mdot
.32868 .19363 Mdot
.59961 .35072 Mdot
.4424 .54149 Mdot
.43349 .54035 Mdot
.75498 .41564 Mdot
.51458 .65046 Mdot
.20331 .4332 Mdot
.41135 .52892 Mdot
.47391 .55754 Mdot
.38596 .55323 Mdot
.56954 .40294 Mdot
.53365 .6745 Mdot
.39764 .52767 Mdot
.58729 .59858 Mdot
.44729 .55644 Mdot
.40122 .36459 Mdot
.22803 .61086 Mdot
.36686 .47923 Mdot
.88566 .55774 Mdot
.5568 .24844 Mdot
.53365 .36346 Mdot
.7519 .47429 Mdot
.14628 .49105 Mdot
.76825 .54752 Mdot
.51128 .66868 Mdot
.63883 .73394 Mdot
.54573 .35925 Mdot
.77855 .57007 Mdot
.5133 .83974 Mdot
.36071 .54439 Mdot
.34433 .50905 Mdot
.51053 .40738 Mdot
.60413 .35741 Mdot
.54691 .3239 Mdot
.41232 .4811 Mdot
.45244 .50684 Mdot
.54358 .34766 Mdot
.41342 .50554 Mdot
.45495 .57572 Mdot
.66822 .544 Mdot
.56868 .6617 Mdot
.66643 .4924 Mdot
.6564 .53484 Mdot
.34527 .65188 Mdot
.74299 .31086 Mdot
.64993 .49104 Mdot
.67282 .47296 Mdot
.29643 .38638 Mdot
.29142 .47775 Mdot
.4087 .33469 Mdot
.46576 .82924 Mdot
.56465 .35924 Mdot
.38569 .52547 Mdot
.57425 .66591 Mdot
.34033 .63155 Mdot
.52538 .26828 Mdot
.42305 .19401 Mdot
.41573 .54815 Mdot
.55678 .35729 Mdot
.70664 .44462 Mdot
.45141 .59483 Mdot
.61668 .39759 Mdot
.3975 .56728 Mdot
.51166 .37822 Mdot
.41907 .74052 Mdot
.60614 .64206 Mdot
.63193 .31949 Mdot
.51618 .71363 Mdot
.40136 .55668 Mdot
.51805 .65858 Mdot
.66447 .49563 Mdot
.38828 .36835 Mdot
.36679 .35182 Mdot
.37166 .51731 Mdot
.42107 .45029 Mdot
.57121 .27436 Mdot
.36153 .55102 Mdot
.35937 .51969 Mdot
.70109 .44317 Mdot
.36028 .52233 Mdot
.43131 .54413 Mdot
.4257 .55337 Mdot
.42608 .57578 Mdot
.66656 .47904 Mdot
.60375 .62297 Mdot
.42596 .48551 Mdot
.45236 .589 Mdot
.69839 .53291 Mdot
.66338 .72371 Mdot
.64905 .53316 Mdot
.58799 .80605 Mdot
.68264 .49438 Mdot
.36645 .33837 Mdot
.74694 .44951 Mdot
.39879 .44191 Mdot
.56158 .70125 Mdot
.62994 .50405 Mdot
.38912 .33564 Mdot
.65649 .50574 Mdot
.56421 .3286 Mdot
.82689 .54938 Mdot
.49006 .6344 Mdot
.21629 .40322 Mdot
.73399 .54778 Mdot
.63844 .30112 Mdot
.59856 .33388 Mdot
.53413 .67916 Mdot
.47445 .7439 Mdot
.42762 .55473 Mdot
.40156 .35157 Mdot
.37872 .51262 Mdot
.65885 .47944 Mdot
.55536 .36134 Mdot
.22097 .60534 Mdot
.37261 .36308 Mdot
.80977 .40153 Mdot
.57154 .35176 Mdot
.40835 .57222 Mdot
.66699 .47601 Mdot
.82784 .40217 Mdot
.65936 .49287 Mdot
.43389 .4325 Mdot
.54424 .7189 Mdot
.25867 .59425 Mdot
.55079 .663 Mdot
.60403 .31247 Mdot
.83785 .5992 Mdot
.42013 .82176 Mdot
.56425 .66198 Mdot
.61738 .2852 Mdot
.34757 .50392 Mdot
.35258 .49104 Mdot
.59983 .64445 Mdot
.50621 .67033 Mdot
.41507 .51352 Mdot
.67417 .4373 Mdot
.64447 .61842 Mdot
.55559 .23329 Mdot
.55829 .37737 Mdot
.39782 .53656 Mdot
.69371 .53738 Mdot
.68923 .53186 Mdot
.59866 .35912 Mdot
.64676 .53289 Mdot
.37326 .56519 Mdot
.55325 .66685 Mdot
.51469 .35998 Mdot
.37215 .35034 Mdot
.23609 .69817 Mdot
.38905 .31442 Mdot
.58175 .36197 Mdot
.40212 .59308 Mdot
.54362 .35784 Mdot
.14655 .38674 Mdot
.38253 .56719 Mdot
.53192 .63927 Mdot
.37353 .4951 Mdot
.39703 .55716 Mdot
.34585 .50162 Mdot
.55012 .33973 Mdot
.21169 .3811 Mdot
.41034 .50261 Mdot
.67114 .51842 Mdot
.37753 .78649 Mdot
.34856 .49205 Mdot
.34191 .35283 Mdot
.2898 .43803 Mdot
.63785 .28165 Mdot
.57673 .68747 Mdot
.53291 .37798 Mdot
.54797 .64713 Mdot
.48698 .65874 Mdot
.53991 .6471 Mdot
.38688 .77784 Mdot
.46263 .74511 Mdot
.24303 .32741 Mdot
.27188 .64967 Mdot
.31577 .60394 Mdot
.50329 .65916 Mdot
.44405 .33333 Mdot
.54979 .70263 Mdot
.51616 .65226 Mdot
.54783 .91406 Mdot
.56313 .6967 Mdot
.40429 .53723 Mdot
.34025 .53456 Mdot
.68987 .65374 Mdot
.27245 .39112 Mdot
.36444 .52284 Mdot
.39575 .49737 Mdot
.39097 .36537 Mdot
.44966 .47235 Mdot
.62739 .44005 Mdot
.62661 .22052 Mdot
.73156 .64789 Mdot
.37688 .51292 Mdot
.40282 .49974 Mdot
.45371 .52143 Mdot
.86761 .46837 Mdot
.37294 .65376 Mdot
.5022 .66364 Mdot
.36509 .45647 Mdot
.31094 .76852 Mdot
.37673 .57229 Mdot
.37364 .48171 Mdot
.34513 .52299 Mdot
.54622 .35953 Mdot
.5198 .70695 Mdot
.37184 .45526 Mdot
.63465 .25374 Mdot
.35756 .56356 Mdot
.65107 .44502 Mdot
.17052 .46177 Mdot
.40207 .53177 Mdot
.55714 .709 Mdot
.35357 .507 Mdot
.52017 .67204 Mdot
.55015 .69069 Mdot
.42475 .58221 Mdot
.45422 .79659 Mdot
.53522 .71544 Mdot
.35638 .55579 Mdot
.54965 .34834 Mdot
.45035 .83717 Mdot
.39928 .5213 Mdot
.36284 .35453 Mdot
.41285 .53069 Mdot
.39133 .3762 Mdot
.35759 .52889 Mdot
.59613 .36196 Mdot
.45749 .65796 Mdot
.55124 .36901 Mdot
.189 .47619 Mdot
.58244 .37269 Mdot
.80118 .40604 Mdot
.51111 .6875 Mdot
.73042 .45968 Mdot
.37944 .19042 Mdot
.6481 .43794 Mdot
.58056 .55615 Mdot
.5515 .53441 Mdot
.68498 .52578 Mdot
.5281 .6336 Mdot
.23205 .4879 Mdot
.73978 .38675 Mdot
.74207 .41989 Mdot
.59321 .35182 Mdot
.39263 .16967 Mdot
.46854 .17215 Mdot
.39334 .49022 Mdot
.4236 .77703 Mdot
.32572 .69392 Mdot
.36187 .48295 Mdot
.33942 .48008 Mdot
.51402 .39281 Mdot
.43474 .53584 Mdot
.6039 .58687 Mdot
.58369 .35277 Mdot
.39221 .33611 Mdot
.52022 .65137 Mdot
.37602 .3766 Mdot
.74208 .39864 Mdot
.55259 .54027 Mdot
.58443 .32582 Mdot
.44249 .56182 Mdot
.38009 .49298 Mdot
.53442 .68687 Mdot
.5788 .71956 Mdot
.56593 .68232 Mdot
.37193 .32023 Mdot
.5805 .35316 Mdot
.37492 .64672 Mdot
.39736 .50277 Mdot
.54948 .67219 Mdot
.666 .5755 Mdot
.40418 .50437 Mdot
.65047 .50923 Mdot
.34697 .54366 Mdot
.5612 .65445 Mdot
.36024 .52285 Mdot
.55442 .66566 Mdot
.55443 .37547 Mdot
.37807 .57476 Mdot
.38522 .49965 Mdot
.82528 .40961 Mdot
.37061 .33577 Mdot
.50808 .67727 Mdot
.49754 .39394 Mdot
.42239 .56382 Mdot
.6762 .36033 Mdot
.40536 .55436 Mdot
.50294 .71003 Mdot
.44437 .54042 Mdot
.71294 .44839 Mdot
.33775 .54835 Mdot
.39887 .52217 Mdot
.55677 .56737 Mdot
.34085 .7215 Mdot
.57454 .72764 Mdot
.67598 .47688 Mdot
.54493 .7102 Mdot
.49551 .24201 Mdot
.58014 .31073 Mdot
.52395 .37882 Mdot
.23969 .40907 Mdot
.39816 .58852 Mdot
.38658 .53712 Mdot
.6511 .54698 Mdot
.39177 .33031 Mdot
.54545 .67663 Mdot
.39558 .33936 Mdot
.66307 .254 Mdot
.38483 .32053 Mdot
.60985 .34807 Mdot
.59301 .26518 Mdot
.42641 .66159 Mdot
.39156 .36465 Mdot
.56918 .6738 Mdot
.45566 .23455 Mdot
.42647 .50304 Mdot
.42217 .34216 Mdot
.37966 .34105 Mdot
.38845 .16454 Mdot
.43147 .53907 Mdot
.58429 .55356 Mdot
.64575 .49944 Mdot
.39716 .35172 Mdot
.68811 .51543 Mdot
.36637 .51923 Mdot
.66191 .33409 Mdot
.50985 .67192 Mdot
.70975 .51151 Mdot
.3757 .46934 Mdot
.37658 .3217 Mdot
.58752 .33366 Mdot
.72345 .49276 Mdot
.69726 .48999 Mdot
.63392 .7563 Mdot
.22381 .587 Mdot
.57923 .35444 Mdot
.47251 .20416 Mdot
.69695 .50593 Mdot
.37001 .48064 Mdot
.47488 .53737 Mdot
.38764 .56981 Mdot
.74551 .48455 Mdot
.53284 .37949 Mdot
.65133 .64351 Mdot
.37718 .49205 Mdot
.42058 .55089 Mdot
.5888 .67735 Mdot
.56228 .36733 Mdot
.53417 .65899 Mdot
.54955 .70787 Mdot
.55636 .37448 Mdot
.54527 .65648 Mdot
.40415 .33908 Mdot
.65781 .6141 Mdot
.69699 .50029 Mdot
.67377 .51542 Mdot
.56224 .35634 Mdot
.53631 .35738 Mdot
.54039 .36209 Mdot
.34726 .54479 Mdot
.53959 .67618 Mdot
.34999 .52985 Mdot
.34556 .50357 Mdot
.58136 .73111 Mdot
.57508 .67909 Mdot
.34821 .51078 Mdot
.63075 .34789 Mdot
.41837 .33329 Mdot
.55129 .34439 Mdot
.64681 .49524 Mdot
.7787 .60988 Mdot
.71559 .51141 Mdot
.39703 .53935 Mdot
.73952 .32782 Mdot
.56612 .66958 Mdot
.38777 .36194 Mdot
.41281 .35509 Mdot
.37721 .36249 Mdot
.646 .54973 Mdot
.52213 .69589 Mdot
.62505 .21945 Mdot
.39466 .53678 Mdot
.59246 .50637 Mdot
.22853 .50378 Mdot
.66719 .26996 Mdot
.64735 .49321 Mdot
.40218 .50138 Mdot
.5384 .44124 Mdot
.47302 .72595 Mdot
.39554 .56534 Mdot
.44015 .5158 Mdot
.66695 .41911 Mdot
.46561 .55224 Mdot
.54053 .71813 Mdot
.73969 .29511 Mdot
.33771 .51835 Mdot
.60139 .68922 Mdot
.17078 .616 Mdot
.39628 .54661 Mdot
.42005 .54053 Mdot
.39512 .51206 Mdot
.36542 .50027 Mdot
.55678 .71047 Mdot
.24728 .4404 Mdot
.6569 .47753 Mdot
.58477 .48016 Mdot
.69779 .49866 Mdot
.51285 .37404 Mdot
.60556 .61079 Mdot
.53941 .63278 Mdot
.39056 .36164 Mdot
.56543 .76841 Mdot
.68801 .24899 Mdot
.5928 .31874 Mdot
.42374 .68751 Mdot
.37353 .34201 Mdot
.37953 .47826 Mdot
.38455 .38138 Mdot
.58453 .36974 Mdot
.67211 .52462 Mdot
.36062 .58641 Mdot
.56235 .69216 Mdot
.55401 .64319 Mdot
.41285 .51209 Mdot
.35011 .80041 Mdot
.6479 .51165 Mdot
.68061 .4665 Mdot
.36139 .49168 Mdot
.43959 .51143 Mdot
.53226 .65545 Mdot
.56312 .34358 Mdot
.37662 .2579 Mdot
.37989 .33002 Mdot
.41474 .57422 Mdot
.3632 .50334 Mdot
.73808 .29955 Mdot
.65346 .52855 Mdot
.60616 .32893 Mdot
.37175 .48664 Mdot
.76614 .50928 Mdot
.37082 .48746 Mdot
.45283 .59815 Mdot
.55069 .35018 Mdot
.43007 .47987 Mdot
.40972 .49949 Mdot
.32253 .48309 Mdot
.69432 .51105 Mdot
.53059 .64135 Mdot
.58094 .69394 Mdot
.51248 .41744 Mdot
.65208 .50705 Mdot
.35039 .50829 Mdot
.65068 .5249 Mdot
.35415 .48536 Mdot
.41846 .51404 Mdot
.65241 .48986 Mdot
.5347 .65872 Mdot
.65567 .70716 Mdot
.60375 .61792 Mdot
.36758 .49732 Mdot
.33743 .53656 Mdot
.25402 .40575 Mdot
.28458 .27087 Mdot
.41196 .54979 Mdot
.55842 .64939 Mdot
.39342 .49989 Mdot
.68796 .50912 Mdot
.39139 .32461 Mdot
.55704 .65043 Mdot
.57104 .34214 Mdot
.59912 .32586 Mdot
.76025 .59329 Mdot
.5837 .36634 Mdot
.41129 .49139 Mdot
.4855 .62491 Mdot
.56197 .63643 Mdot
.19263 .64981 Mdot
.56007 .37217 Mdot
.40949 .3486 Mdot
.37014 .5092 Mdot
.7731 .38164 Mdot
.64546 .54525 Mdot
.89709 .53614 Mdot
.61807 .21125 Mdot
.38362 .31249 Mdot
.40648 .19222 Mdot
.51552 .36376 Mdot
.42625 .51738 Mdot
.3869 .36937 Mdot
.58334 .31769 Mdot
.40597 .49135 Mdot
.3392 .57286 Mdot
.20426 .41614 Mdot
.52168 .42355 Mdot
.64679 .52273 Mdot
.53074 .35436 Mdot
.38481 .38573 Mdot
.60825 .35055 Mdot
.55591 .64286 Mdot
.39582 .52446 Mdot
.35947 .44596 Mdot
.56707 .34146 Mdot
.60554 .35451 Mdot
.34683 .53646 Mdot
.52432 .63464 Mdot
.53309 .39663 Mdot
.37414 .51994 Mdot
.35136 .62204 Mdot
.51537 .71182 Mdot
.58375 .3482 Mdot
.42351 .55204 Mdot
.31573 .45283 Mdot
.56813 .35 Mdot
.55258 .34229 Mdot
.41429 .51212 Mdot
.4049 .34233 Mdot
.36479 .57494 Mdot
.67749 .49143 Mdot
.19417 .40299 Mdot
.68602 .51179 Mdot
.48236 .25332 Mdot
.43289 .58363 Mdot
.65136 .34547 Mdot
.56225 .6458 Mdot
.39246 .38625 Mdot
.78917 .60434 Mdot
.42742 .49284 Mdot
.51827 .82236 Mdot
.54338 .45254 Mdot
.30099 .76875 Mdot
.77242 .67339 Mdot
.38236 .34353 Mdot
.65957 .5014 Mdot
.41961 .5401 Mdot
.6422 .53659 Mdot
.37479 .36795 Mdot
.21771 .54132 Mdot
.42646 .54985 Mdot
.53166 .673 Mdot
.35341 .5546 Mdot
.52007 .6635 Mdot
.40708 .5076 Mdot
.45853 .56804 Mdot
.7265 .44692 Mdot
.32011 .32413 Mdot
.42039 .50026 Mdot
.82975 .54076 Mdot
.53842 .27423 Mdot
.3808 .33548 Mdot
.35287 .54125 Mdot
.59416 .31146 Mdot
.68785 .53111 Mdot
.50028 .55699 Mdot
.54587 .35734 Mdot
.63725 .51995 Mdot
.5364 .65116 Mdot
.55593 .3769 Mdot
.60304 .33856 Mdot
.36704 .46095 Mdot
.39043 .37481 Mdot
.6725 .52849 Mdot
.40137 .52548 Mdot
.42902 .54235 Mdot
.47776 .21071 Mdot
.50691 .27566 Mdot
.58608 .69134 Mdot
.8078 .3526 Mdot
.58213 .66954 Mdot
.37278 .32953 Mdot
.54716 .35288 Mdot
.40893 .55005 Mdot
.37478 .55779 Mdot
.73497 .46002 Mdot
.50678 .66586 Mdot
.52478 .42856 Mdot
.37318 .66709 Mdot
.54831 .39298 Mdot
.27877 .42618 Mdot
.53336 .63764 Mdot
.27797 .42439 Mdot
.38456 .3852 Mdot
.51817 .80316 Mdot
.32184 .36067 Mdot
.64408 .50203 Mdot
.2757 .4307 Mdot
.55542 .68247 Mdot
.38829 .48999 Mdot
.56787 .31406 Mdot
.5897 .3598 Mdot
.52596 .65137 Mdot
.50903 .38712 Mdot
.39498 .35365 Mdot
.42339 .537 Mdot
.60012 .22265 Mdot
.71549 .61515 Mdot
.5655 .33577 Mdot
.44071 .60513 Mdot
.68064 .52002 Mdot
.42587 .52064 Mdot
.36168 .35086 Mdot
.66042 .52201 Mdot
.54041 .24529 Mdot
.64805 .62832 Mdot
.36939 .51943 Mdot
.78066 .37443 Mdot
.65219 .51334 Mdot
.37076 .21687 Mdot
.37912 .5202 Mdot
.69683 .50654 Mdot
.45767 .51036 Mdot
.66375 .28203 Mdot
.5066 .4322 Mdot
.50738 .84374 Mdot
.53534 .43405 Mdot
.53927 .33326 Mdot
.69521 .32473 Mdot
.72163 .39997 Mdot
.64791 .54042 Mdot
.6064 .35288 Mdot
.34626 .41839 Mdot
.68832 .51643 Mdot
.34381 .50929 Mdot
.40154 .55151 Mdot
.34271 .64556 Mdot
.5476 .46373 Mdot
.61578 .3361 Mdot
.74555 .5618 Mdot
.42105 .56436 Mdot
.36209 .46661 Mdot
.37433 .5511 Mdot
.49583 .64996 Mdot
.66294 .52897 Mdot
.82787 .46387 Mdot
.65303 .50311 Mdot
.54937 .19897 Mdot
.56286 .36015 Mdot
.52805 .37369 Mdot
.40084 .53494 Mdot
.63846 .31986 Mdot
.2665 .48301 Mdot
.36954 .56376 Mdot
.63988 .37162 Mdot
.2251 .61943 Mdot
.36914 .46827 Mdot
.54725 .71951 Mdot
.38827 .60289 Mdot
.49354 .64108 Mdot
.70032 .50519 Mdot
.38189 .35121 Mdot
.39382 .39065 Mdot
.67074 .52766 Mdot
.38502 .53766 Mdot
.64663 .37757 Mdot
.39071 .5591 Mdot
.38338 .48656 Mdot
.54717 .19038 Mdot
.38088 .31334 Mdot
.53701 .37126 Mdot
.36844 .35697 Mdot
.51504 .65325 Mdot
.77887 .76272 Mdot
.39411 .33192 Mdot
.2665 .4939 Mdot
.19992 .49136 Mdot
.2732 .43077 Mdot
.54861 .63921 Mdot
.35443 .35225 Mdot
.64493 .51401 Mdot
.37091 .83248 Mdot
.26499 .28574 Mdot
.71279 .48409 Mdot
.37438 .52827 Mdot
.52989 .63117 Mdot
.57115 .67348 Mdot
.70817 .50815 Mdot
.55156 .68853 Mdot
.40512 .45363 Mdot
.37514 .49014 Mdot
.64367 .53593 Mdot
.70412 .6385 Mdot
.6978 .49029 Mdot
.64874 .60086 Mdot
.35205 .54463 Mdot
.54123 .63905 Mdot
.39226 .60138 Mdot
.51079 .61694 Mdot
.60673 .32818 Mdot
.37097 .47766 Mdot
.39457 .35627 Mdot
.60084 .4728 Mdot
.57763 .35249 Mdot
.73886 .3298 Mdot
.53191 .68445 Mdot
.67006 .5684 Mdot
.544 .68854 Mdot
.50856 .63443 Mdot
.65764 .53561 Mdot
.51951 .68734 Mdot
.42117 .54013 Mdot
.62817 .32608 Mdot
.52132 .67879 Mdot
.67393 .50434 Mdot
.37911 .35601 Mdot
.54249 .65767 Mdot
.51476 .40068 Mdot
.37644 .50204 Mdot
.56588 .32511 Mdot
.73041 .44114 Mdot
.51715 .63421 Mdot
.35422 .34008 Mdot
.53268 .38259 Mdot
.38793 .37395 Mdot
.21587 .6312 Mdot
.63429 .50374 Mdot
.43105 .19573 Mdot
.31982 .45193 Mdot
.56664 .68974 Mdot
.72811 .44331 Mdot
.4077 .54747 Mdot
.37434 .50254 Mdot
.36725 .37537 Mdot
.57123 .67411 Mdot
.41765 .82663 Mdot
.55076 .74922 Mdot
.65816 .6242 Mdot
.63247 .50273 Mdot
.81248 .44156 Mdot
.61819 .59466 Mdot
.18001 .5381 Mdot
.39805 .46464 Mdot
.51929 .35681 Mdot
.38783 .54492 Mdot
.78272 .61678 Mdot
.37489 .32079 Mdot
.38683 .27685 Mdot
.44198 .5709 Mdot
.54036 .37775 Mdot
.38644 .51058 Mdot
.51234 .5247 Mdot
.42235 .60303 Mdot
.40471 .33534 Mdot
.64162 .45016 Mdot
.55876 .70332 Mdot
.37194 .34749 Mdot
.5972 .34216 Mdot
.27253 .46364 Mdot
.41801 .50079 Mdot
.41835 .48245 Mdot
.55331 .39202 Mdot
.53429 .67759 Mdot
.53535 .33976 Mdot
.6972 .50115 Mdot
.39013 .35006 Mdot
.36772 .50656 Mdot
.44534 .54804 Mdot
.67751 .36228 Mdot
.6713 .53057 Mdot
.53816 .39267 Mdot
.65943 .49404 Mdot
.54135 .3293 Mdot
.34329 .55635 Mdot
.5273 .37472 Mdot
.43057 .51818 Mdot
.79705 .54368 Mdot
.53984 .19046 Mdot
.36262 .73734 Mdot
.53929 .38089 Mdot
.30257 .41714 Mdot
.68362 .50416 Mdot
.67845 .4935 Mdot
.26144 .58458 Mdot
.45765 .47523 Mdot
.51654 .22789 Mdot
.64616 .75471 Mdot
.69667 .4981 Mdot
.68178 .51335 Mdot
.57309 .32134 Mdot
.51702 .68211 Mdot
.51807 .62876 Mdot
.51146 .3752 Mdot
.27209 .33671 Mdot
.54553 .67652 Mdot
.50174 .82114 Mdot
.5181 .23679 Mdot
.35641 .46572 Mdot
.72944 .52775 Mdot
.38791 .35497 Mdot
.28187 .33453 Mdot
.51792 .53872 Mdot
.41936 .54923 Mdot
.7485 .30974 Mdot
.56051 .34832 Mdot
.2338 .43497 Mdot
.59123 .80399 Mdot
.42834 .54878 Mdot
.38421 .52386 Mdot
.38067 .5441 Mdot
.36984 .31544 Mdot
.46981 .65141 Mdot
.42683 .54269 Mdot
.2713 .33369 Mdot
.42146 .56597 Mdot
.38489 .41066 Mdot
.3669 .35314 Mdot
.30007 .54769 Mdot
.67047 .43309 Mdot
.63574 .24531 Mdot
.33061 .57442 Mdot
.69394 .49879 Mdot
.58562 .4441 Mdot
.69595 .51477 Mdot
.37736 .77003 Mdot
.31958 .36344 Mdot
.56128 .71883 Mdot
.41924 .54656 Mdot
.58293 .3603 Mdot
.57034 .66982 Mdot
.70063 .35812 Mdot
.60418 .90062 Mdot
.70081 .51263 Mdot
.15954 .37894 Mdot
.66939 .49138 Mdot
.60289 .34377 Mdot
.53146 .65407 Mdot
.45466 .74434 Mdot
.59194 .51286 Mdot
.5455 .65857 Mdot
.65039 .69377 Mdot
.5598 .62845 Mdot
.28922 .42627 Mdot
.56915 .64521 Mdot
.67703 .50324 Mdot
.69023 .54644 Mdot
.33587 .47599 Mdot
.40754 .53889 Mdot
.54871 .53883 Mdot
.2829 .47645 Mdot
.40827 .54315 Mdot
.5825 .35354 Mdot
.36141 .21581 Mdot
.51186 .41283 Mdot
.54181 .69972 Mdot
.69164 .48079 Mdot
.38492 .52083 Mdot
.36618 .49383 Mdot
.40794 .49464 Mdot
.81673 .35812 Mdot
.48614 .81705 Mdot
.40963 .50238 Mdot
.40378 .5786 Mdot
.55126 .37777 Mdot
.34502 .33091 Mdot
.7679 .64771 Mdot
.38139 .4165 Mdot
.40141 .56939 Mdot
.36791 .34458 Mdot
.4026 .32234 Mdot
.40689 .49144 Mdot
.62452 .25453 Mdot
.62626 .30192 Mdot
.40136 .525 Mdot
.42583 .43423 Mdot
.73433 .39217 Mdot
.60527 .35338 Mdot
.56787 .34368 Mdot
.55681 .70854 Mdot
.58813 .35809 Mdot
.58365 .37221 Mdot
.45409 .7266 Mdot
.56693 .44665 Mdot
.61119 .49898 Mdot
.3715 .32034 Mdot
.3787 .55984 Mdot
.58033 .65694 Mdot
.74359 .47299 Mdot
.68117 .52696 Mdot
.55934 .66084 Mdot
.69159 .52854 Mdot
.37782 .3087 Mdot
.21586 .41805 Mdot
.59234 .35847 Mdot
.6916 .49164 Mdot
.64757 .62687 Mdot
.36729 .34687 Mdot
.64255 .52491 Mdot
.65556 .35248 Mdot
.34583 .49843 Mdot
.49205 .77945 Mdot
.36292 .55962 Mdot
.3541 .80973 Mdot
.64301 .52423 Mdot
.71289 .44947 Mdot
.39016 .53268 Mdot
.5702 .3524 Mdot
.46193 .5519 Mdot
.39736 .56801 Mdot
.57531 .3385 Mdot
.39288 .49033 Mdot
.36754 .36533 Mdot
.49211 .66976 Mdot
.57982 .45148 Mdot
.56577 .14859 Mdot
.38546 .37698 Mdot
.6932 .35553 Mdot
.41337 .54945 Mdot
.22187 .60171 Mdot
.54336 .65932 Mdot
.43895 .5288 Mdot
.2763 .54809 Mdot
.51405 .66919 Mdot
.55172 .65147 Mdot
.35494 .51684 Mdot
.64617 .50149 Mdot
.5776 .349 Mdot
.36812 .35292 Mdot
.19388 .61398 Mdot
.36963 .53866 Mdot
.38873 .49938 Mdot
.37287 .34392 Mdot
.68412 .51301 Mdot
.36238 .49698 Mdot
.77122 .45951 Mdot
.25794 .73812 Mdot
.67663 .53294 Mdot
.34551 .55013 Mdot
.52868 .76565 Mdot
.49797 .61701 Mdot
.2072 .32515 Mdot
.34459 .29559 Mdot
.53263 .37211 Mdot
.46684 .54287 Mdot
.85271 .64213 Mdot
.38206 .35314 Mdot
.63026 .23128 Mdot
.38368 .48519 Mdot
.39796 .5065 Mdot
.56591 .67652 Mdot
.34812 .52169 Mdot
.50942 .65683 Mdot
.51876 .14612 Mdot
.76755 .32234 Mdot
.52757 .67583 Mdot
.56216 .69507 Mdot
.26931 .51863 Mdot
.77116 .64158 Mdot
.52751 .64854 Mdot
.35823 .57726 Mdot
.42285 .81005 Mdot
.31508 .49854 Mdot
.36852 .377 Mdot
.72955 .42894 Mdot
.54871 .6134 Mdot
.4673 .37507 Mdot
.64384 .73757 Mdot
.56597 .61922 Mdot
.5982 .29144 Mdot
.67523 .48935 Mdot
.42091 .56002 Mdot
.58674 .36353 Mdot
.52479 .3784 Mdot
.43034 .59872 Mdot
.38663 .56268 Mdot
.51891 .66868 Mdot
.38338 .31609 Mdot
.67194 .53977 Mdot
.39468 .49705 Mdot
.5193 .4132 Mdot
.38877 .33107 Mdot
.53607 .69516 Mdot
.25805 .56794 Mdot
.40865 .3433 Mdot
.39843 .60728 Mdot
.41197 .52492 Mdot
.34546 .52997 Mdot
.35572 .43993 Mdot
.65876 .48314 Mdot
.75585 .45514 Mdot
.35404 .56522 Mdot
.66673 .25468 Mdot
.46276 .43014 Mdot
.43972 .48936 Mdot
.54686 .68253 Mdot
.64184 .54453 Mdot
.60278 .31698 Mdot
.24273 .49979 Mdot
.36891 .52789 Mdot
.47955 .81448 Mdot
.36958 .65709 Mdot
.59907 .31718 Mdot
.50397 .66176 Mdot
.38533 .36267 Mdot
.37316 .56437 Mdot
.40187 .79207 Mdot
.39943 .54802 Mdot
.33762 .44119 Mdot
.55418 .34491 Mdot
.67257 .4881 Mdot
.29011 .76224 Mdot
.5249 .37782 Mdot
.54912 .64819 Mdot
.52133 .85036 Mdot
.54912 .63307 Mdot
.54386 .70532 Mdot
.44283 .79846 Mdot
.66711 .48238 Mdot
.86386 .62213 Mdot
.25093 .29208 Mdot
.45149 .53999 Mdot
.68625 .50269 Mdot
.52493 .65923 Mdot
.42633 .52198 Mdot
.5726 .65812 Mdot
.51497 .68835 Mdot
.34558 .48546 Mdot
.40778 .51528 Mdot
.6008 .60604 Mdot
.54557 .81557 Mdot
.38062 .3644 Mdot
.52172 .63891 Mdot
.30378 .60091 Mdot
.43183 .53165 Mdot
.39491 .53609 Mdot
.72295 .37234 Mdot
.40588 .34263 Mdot
.56003 .57742 Mdot
.37531 .48585 Mdot
.78274 .3515 Mdot
.38421 .60316 Mdot
.55414 .7127 Mdot
.67404 .53336 Mdot
.62287 .24455 Mdot
.74444 .48774 Mdot
.50653 .66156 Mdot
.36098 .3364 Mdot
.58095 .69596 Mdot
.26829 .49293 Mdot
.68589 .48407 Mdot
.56125 .65452 Mdot
.54607 .44125 Mdot
.66289 .51568 Mdot
.64195 .52157 Mdot
.38094 .78855 Mdot
.5443 .38962 Mdot
.35824 .33096 Mdot
.67651 .5246 Mdot
.37584 .63195 Mdot
.66858 .50071 Mdot
.31206 .62028 Mdot
.3723 .57352 Mdot
.23798 .37698 Mdot
.60544 .56448 Mdot
.39142 .44198 Mdot
.64721 .48837 Mdot
.37425 .36651 Mdot
.35763 .50886 Mdot
.55451 .68809 Mdot
.39622 .33662 Mdot
.72525 .51393 Mdot
.54406 .34863 Mdot
.54259 .6906 Mdot
.65123 .47883 Mdot
.52567 .63859 Mdot
.23046 .47846 Mdot
.18902 .4189 Mdot
.77698 .44152 Mdot
.58896 .51257 Mdot
.40432 .49243 Mdot
.69168 .71583 Mdot
.34139 .48696 Mdot
.39174 .56391 Mdot
.58289 .34857 Mdot
.23789 .41018 Mdot
.53381 .65846 Mdot
.29603 .76982 Mdot
.68711 .49088 Mdot
.74875 .30178 Mdot
.54251 .73541 Mdot
.4401 .52929 Mdot
.51872 .67472 Mdot
.55867 .63762 Mdot
.33327 .71743 Mdot
.61111 .35057 Mdot
.33118 .55361 Mdot
.32765 .51309 Mdot
.41215 .4724 Mdot
.64244 .52072 Mdot
.72776 .31908 Mdot
.52555 .35028 Mdot
.18552 .39073 Mdot
.55784 .3412 Mdot
.61924 .41575 Mdot
.52483 .69214 Mdot
.39876 .33475 Mdot
.39647 .53416 Mdot
.54693 .73927 Mdot
.50549 .65669 Mdot
.40538 .31483 Mdot
.39788 .35458 Mdot
.69252 .30695 Mdot
.65244 .48931 Mdot
.42692 .50563 Mdot
.42385 .55075 Mdot
.35188 .532 Mdot
.36238 .56389 Mdot
.70133 .51188 Mdot
.35508 .49366 Mdot
.68896 .54066 Mdot
.367 .63285 Mdot
.76118 .3219 Mdot
.5634 .44552 Mdot
.48808 .54775 Mdot
.55156 .69567 Mdot
.38478 .63064 Mdot
.39487 .60842 Mdot
.50899 .1842 Mdot
.26176 .69691 Mdot
.36882 .47131 Mdot
.57434 .31894 Mdot
.46729 .49337 Mdot
.56964 .37729 Mdot
.21191 .2794 Mdot
.67642 .37365 Mdot
.51276 .83531 Mdot
.42864 .53237 Mdot
.72639 .37519 Mdot
.47131 .59183 Mdot
.33456 .49956 Mdot
.70234 .38148 Mdot
.76511 .53425 Mdot
.67261 .66546 Mdot
.40587 .32804 Mdot
.37566 .50802 Mdot
.55904 .63209 Mdot
.42268 .53993 Mdot
.39248 .5409 Mdot
.38451 .48434 Mdot
.66399 .47535 Mdot
.35793 .58303 Mdot
.34691 .54661 Mdot
.50444 .30731 Mdot
.2961 .39381 Mdot
.52976 .35409 Mdot
.25213 .5776 Mdot
.39306 .33254 Mdot
.52413 .67904 Mdot
.62325 .70443 Mdot
.64395 .50159 Mdot
.32507 .70294 Mdot
.3501 .55083 Mdot
.62413 .61653 Mdot
.64839 .47983 Mdot
.39236 .35043 Mdot
.56786 .31251 Mdot
.47232 .84773 Mdot
.57872 .3635 Mdot
.54721 .44455 Mdot
.57292 .35558 Mdot
.34206 .59448 Mdot
.51829 .66681 Mdot
.39295 .48501 Mdot
.6768 .52226 Mdot
.58282 .34297 Mdot
.26286 .39322 Mdot
.37569 .55047 Mdot
.55354 .37501 Mdot
.38993 .48423 Mdot
.21887 .39984 Mdot
.43328 .21399 Mdot
.59055 .36775 Mdot
.63743 .54579 Mdot
.66677 .5114 Mdot
.4029 .33742 Mdot
.53293 .68937 Mdot
.56418 .67654 Mdot
.65963 .52019 Mdot
.2914 .25672 Mdot
.40172 .56822 Mdot
.42866 .52628 Mdot
.66945 .25431 Mdot
.41522 .53945 Mdot
.28354 .44848 Mdot
.53235 .43884 Mdot
.54294 .69727 Mdot
.42036 .51279 Mdot
.36459 .49758 Mdot
.36973 .51403 Mdot
.22569 .47965 Mdot
.56418 .34023 Mdot
.40541 .57173 Mdot
.39811 .3605 Mdot
.60278 .30979 Mdot
.42945 .52479 Mdot
.41487 .47459 Mdot
.56407 .6742 Mdot
.74574 .28321 Mdot
.66186 .48987 Mdot
.59728 .33598 Mdot
.52971 .37712 Mdot
.73155 .42718 Mdot
.5939 .7113 Mdot
.52891 .43675 Mdot
.17954 .41529 Mdot
.69339 .44126 Mdot
.37477 .3372 Mdot
.61471 .43255 Mdot
.44424 .4162 Mdot
.59097 .32171 Mdot
.69817 .52378 Mdot
.36081 .56906 Mdot
.39637 .57218 Mdot
.6068 .20253 Mdot
.44099 .52864 Mdot
.38598 .35987 Mdot
.701 .53179 Mdot
.55526 .6807 Mdot
.39263 .35297 Mdot
.67218 .49283 Mdot
.53633 .67932 Mdot
.3451 .49598 Mdot
.34067 .51045 Mdot
.55721 .65952 Mdot
.56974 .67263 Mdot
.40532 .5262 Mdot
.61074 .30507 Mdot
.5556 .70762 Mdot
.549 .64191 Mdot
.59152 .36038 Mdot
.59166 .3536 Mdot
.38098 .45562 Mdot
.68115 .4986 Mdot
.34449 .51338 Mdot
.56789 .37251 Mdot
.38825 .31969 Mdot
.53947 .66197 Mdot
.36858 .495 Mdot
.3892 .4928 Mdot
.36841 .34973 Mdot
.39627 .32013 Mdot
.39594 .35111 Mdot
.70813 .52515 Mdot
.35743 .54214 Mdot
.53256 .64832 Mdot
.66161 .48539 Mdot
.40292 .3225 Mdot
.39698 .37484 Mdot
.49485 .37286 Mdot
.40947 .55205 Mdot
.50019 .39234 Mdot
.77554 .76123 Mdot
.32299 .42425 Mdot
.60484 .31993 Mdot
.55125 .39078 Mdot
.27028 .41425 Mdot
.62428 .30832 Mdot
.64981 .51637 Mdot
.33585 .42613 Mdot
.39329 .38655 Mdot
.36848 .47916 Mdot
.33874 .54039 Mdot
.33539 .48415 Mdot
.39168 .34131 Mdot
.24046 .48051 Mdot
.566 .6485 Mdot
.29671 .64515 Mdot
.39361 .33366 Mdot
.60429 .358 Mdot
.53276 .39132 Mdot
.55711 .3415 Mdot
.34132 .5446 Mdot
.35706 .72894 Mdot
.33631 .60733 Mdot
.68943 .72528 Mdot
.63856 .50631 Mdot
.56182 .72043 Mdot
.2165 .61823 Mdot
.55345 .65502 Mdot
.52727 .38656 Mdot
.39026 .3362 Mdot
.56334 .65531 Mdot
.69065 .52333 Mdot
.68027 .51517 Mdot
.56235 .3384 Mdot
.56073 .35784 Mdot
.57004 .32533 Mdot
.5314 .70229 Mdot
.52084 .68859 Mdot
.36732 .5367 Mdot
.54979 .66768 Mdot
.67055 .22254 Mdot
.3676 .31421 Mdot
.53435 .39445 Mdot
.66003 .49986 Mdot
.52066 .66621 Mdot
.3737 .55325 Mdot
.53886 .41837 Mdot
.75132 .59612 Mdot
.38213 .37519 Mdot
.46037 .2102 Mdot
.20425 .2937 Mdot
.43425 .51418 Mdot
.6481 .52492 Mdot
.59094 .22237 Mdot
.37861 .5436 Mdot
.54969 .35576 Mdot
.79918 .56106 Mdot
.58127 .31039 Mdot
.34478 .50759 Mdot
.44141 .52113 Mdot
.64885 .53456 Mdot
.19656 .49904 Mdot
.36676 .54367 Mdot
.64288 .58528 Mdot
.69883 .48596 Mdot
.51886 .3655 Mdot
.26671 .75075 Mdot
.75281 .41734 Mdot
.27742 .33808 Mdot
.59462 .35428 Mdot
.3984 .55661 Mdot
.59174 .34488 Mdot
.38222 .37373 Mdot
.59103 .33394 Mdot
.53603 .71999 Mdot
.52859 .35257 Mdot
.38932 .5004 Mdot
.52657 .64739 Mdot
.6516 .51265 Mdot
.7294 .28287 Mdot
.50159 .29899 Mdot
.56926 .35276 Mdot
.6001 .35178 Mdot
.41511 .50416 Mdot
.58013 .586 Mdot
.45463 .56154 Mdot
.43021 .53264 Mdot
.69859 .49763 Mdot
.52147 .68056 Mdot
.64702 .48524 Mdot
.43546 .55851 Mdot
.79258 .48783 Mdot
.65485 .49536 Mdot
.62079 .62017 Mdot
.37352 .34104 Mdot
.50956 .49125 Mdot
.37566 .55993 Mdot
.68187 .52309 Mdot
.35698 .54285 Mdot
.57584 .66599 Mdot
.537 .48138 Mdot
.7562 .4791 Mdot
.67526 .5214 Mdot
.39682 .8218 Mdot
.51014 .35196 Mdot
.38151 .59787 Mdot
.69718 .50917 Mdot
.27864 .55113 Mdot
.60319 .34087 Mdot
.37828 .33121 Mdot
.40329 .32339 Mdot
.39291 .37144 Mdot
.40969 .48171 Mdot
.35815 .59545 Mdot
.35843 .34557 Mdot
.68001 .5334 Mdot
.40324 .33175 Mdot
.58609 .73675 Mdot
.40841 .82681 Mdot
.37154 .32312 Mdot
.37688 .52037 Mdot
.3261 .48606 Mdot
.29191 .39215 Mdot
.53685 .39928 Mdot
.52344 .82337 Mdot
.48824 .57411 Mdot
.40552 .54059 Mdot
.50198 .6052 Mdot
.56664 .65224 Mdot
.58431 .22631 Mdot
.29086 .46767 Mdot
.59189 .25552 Mdot
.55901 .69935 Mdot
.73577 .46185 Mdot
.53776 .69437 Mdot
.43136 .51346 Mdot
.42087 .51817 Mdot
.51746 .62764 Mdot
.74295 .3241 Mdot
.66665 .32998 Mdot
.24046 .70129 Mdot
.5459 .63916 Mdot
.69392 .51189 Mdot
.70328 .50652 Mdot
.64009 .50323 Mdot
.50445 .23813 Mdot
.51606 .6378 Mdot
.36007 .53557 Mdot
.55049 .37903 Mdot
.40904 .56653 Mdot
.66695 .52174 Mdot
.30228 .77429 Mdot
.56154 .67794 Mdot
.39937 .52299 Mdot
.28108 .2775 Mdot
.5514 .3629 Mdot
.36799 .33895 Mdot
.21006 .42158 Mdot
.54838 .24304 Mdot
.67475 .48105 Mdot
.5325 .6275 Mdot
.652 .4437 Mdot
.61884 .63022 Mdot
.38887 .46017 Mdot
.40937 .4599 Mdot
.18318 .57118 Mdot
.53291 .24644 Mdot
.39377 .48263 Mdot
.59957 .33423 Mdot
.7353 .45963 Mdot
.37234 .4959 Mdot
.54808 .63772 Mdot
.41299 .34102 Mdot
.40155 .35685 Mdot
.33492 .55286 Mdot
.59261 .50164 Mdot
.49591 .45747 Mdot
.35048 .50609 Mdot
.39656 .60752 Mdot
.53277 .38626 Mdot
.67976 .43886 Mdot
.70375 .26874 Mdot
.36289 .32927 Mdot
.37441 .48431 Mdot
.68213 .68443 Mdot
.51311 .68244 Mdot
.54735 .33212 Mdot
.68437 .48241 Mdot
.22562 .49762 Mdot
.52217 .35777 Mdot
.3728 .49451 Mdot
.36293 .49695 Mdot
.64273 .52579 Mdot
.55404 .71283 Mdot
.39039 .33974 Mdot
.53686 .38128 Mdot
.36171 .33135 Mdot
.51147 .6606 Mdot
.55921 .67793 Mdot
.31216 .50572 Mdot
.36188 .59008 Mdot
.56968 .34357 Mdot
.43502 .55502 Mdot
.55682 .39589 Mdot
.19333 .49655 Mdot
.62993 .50374 Mdot
.43615 .51653 Mdot
.50502 .68376 Mdot
.67216 .52542 Mdot
.40053 .5115 Mdot
.17715 .58865 Mdot
.43404 .54406 Mdot
.74255 .48406 Mdot
.79603 .46696 Mdot
.38651 .36678 Mdot
.25737 .63167 Mdot
.57051 .60948 Mdot
.41694 .53546 Mdot
.53798 .35282 Mdot
.45997 .55637 Mdot
.64558 .5064 Mdot
.53586 .69834 Mdot
.21415 .31003 Mdot
.66922 .50284 Mdot
.42579 .53379 Mdot
.39096 .3502 Mdot
.54755 .63127 Mdot
.59225 .44378 Mdot
.65569 .25652 Mdot
.42158 .5932 Mdot
.36231 .5804 Mdot
.34648 .50538 Mdot
.79708 .61893 Mdot
.59644 .33392 Mdot
.52239 .66205 Mdot
.64274 .52034 Mdot
.65781 .52163 Mdot
.56063 .34236 Mdot
.67223 .65281 Mdot
.51055 .48907 Mdot
.8184 .69329 Mdot
.57859 .33734 Mdot
.35353 .34092 Mdot
.59893 .58405 Mdot
.5377 .35054 Mdot
.55406 .3733 Mdot
.53435 .38611 Mdot
.63259 .469 Mdot
.53851 .67806 Mdot
.3901 .49211 Mdot
.5767 .6883 Mdot
.4006 .5584 Mdot
.47286 .44237 Mdot
.67286 .52697 Mdot
.53887 .70077 Mdot
.18167 .58832 Mdot
.47944 .64499 Mdot
.37935 .53376 Mdot
.21043 .60431 Mdot
.44315 .57345 Mdot
.26249 .44979 Mdot
.40854 .58798 Mdot
.56684 .3572 Mdot
.47122 .5557 Mdot
.44452 .5126 Mdot
.70256 .25445 Mdot
.66161 .4982 Mdot
.60487 .33937 Mdot
.40565 .48447 Mdot
.38648 .60418 Mdot
.52568 .6229 Mdot
.56059 .65109 Mdot
.35904 .33644 Mdot
.32037 .31885 Mdot
.65078 .51034 Mdot
.19643 .41158 Mdot
.40907 .53482 Mdot
.78461 .40664 Mdot
.27322 .64745 Mdot
.3997 .51239 Mdot
.43358 .81361 Mdot
.34337 .71827 Mdot
.37488 .56348 Mdot
.2851 .54279 Mdot
.68339 .51049 Mdot
.78984 .48063 Mdot
.39784 .58188 Mdot
.54729 .35815 Mdot
.52303 .68884 Mdot
.55284 .63795 Mdot
.362 .35631 Mdot
.50505 .16935 Mdot
.64131 .49286 Mdot
.53357 .6983 Mdot
.37937 .55156 Mdot
.6702 .48148 Mdot
.58135 .36769 Mdot
.44022 .55662 Mdot
.29484 .45109 Mdot
.55098 .67102 Mdot
.40694 .57833 Mdot
.7205 .58536 Mdot
.29653 .32931 Mdot
.67849 .78001 Mdot
.64146 .50188 Mdot
.39148 .32606 Mdot
.45404 .52329 Mdot
.20977 .37807 Mdot
.37282 .46991 Mdot
.23491 .38608 Mdot
.59362 .71913 Mdot
.39379 .32685 Mdot
.38587 .52978 Mdot
.36566 .51636 Mdot
.59509 .55679 Mdot
.38868 .31677 Mdot
.42358 .55386 Mdot
.47829 .5794 Mdot
.53364 .67605 Mdot
.5837 .30596 Mdot
.5495 .67515 Mdot
.37484 .52765 Mdot
.33894 .57406 Mdot
.56735 .67445 Mdot
.16934 .44264 Mdot
.4021 .38858 Mdot
.65844 .49038 Mdot
.36062 .59289 Mdot
.36995 .57467 Mdot
.83637 .56684 Mdot
.6067 .32888 Mdot
.74311 .66646 Mdot
.51273 .40325 Mdot
.66771 .70106 Mdot
.75304 .41305 Mdot
.51022 .85065 Mdot
.74392 .30481 Mdot
.32823 .51255 Mdot
.48066 .48827 Mdot
.29982 .57164 Mdot
.65379 .48247 Mdot
.44544 .66801 Mdot
.40738 .53952 Mdot
.39062 .54315 Mdot
.55535 .3262 Mdot
.64832 .64459 Mdot
.62116 .25173 Mdot
.5886 .47773 Mdot
.38689 .33977 Mdot
.51739 .64674 Mdot
.40644 .50588 Mdot
.47615 .40868 Mdot
.53228 .34926 Mdot
.77862 .39459 Mdot
.39454 .52456 Mdot
.50087 .18724 Mdot
.66738 .45517 Mdot
.65619 .48505 Mdot
.52945 .36748 Mdot
.56705 .25065 Mdot
.40751 .55702 Mdot
.69849 .49219 Mdot
.36798 .54846 Mdot
.53336 .30922 Mdot
.43844 .545 Mdot
.37687 .32307 Mdot
.39647 .48815 Mdot
.59048 .46268 Mdot
.61347 .81273 Mdot
.34632 .43055 Mdot
.52923 .632 Mdot
.56481 .38921 Mdot
.56494 .34136 Mdot
.56529 .66107 Mdot
.56563 .34424 Mdot
.31432 .67692 Mdot
.43297 .74116 Mdot
.38273 .33887 Mdot
.3902 .60661 Mdot
.36461 .33133 Mdot
.60693 .32779 Mdot
.40545 .54769 Mdot
.17295 .42587 Mdot
.57677 .34273 Mdot
.81374 .48298 Mdot
.66326 .50185 Mdot
.60637 .33306 Mdot
.41888 .56829 Mdot
.64091 .42886 Mdot
.52532 .37117 Mdot
.73987 .46705 Mdot
.36941 .5171 Mdot
.55805 .68393 Mdot
.36513 .51064 Mdot
.41455 .58787 Mdot
.54385 .32642 Mdot
.35664 .562 Mdot
.67234 .4929 Mdot
.54458 .71012 Mdot
.45106 .8357 Mdot
.7438 .4833 Mdot
.42061 .55018 Mdot
.37913 .54928 Mdot
.55348 .63136 Mdot
.39713 .57674 Mdot
.70108 .51075 Mdot
.89043 .42457 Mdot
.37308 .34088 Mdot
.59827 .3611 Mdot
.75484 .4251 Mdot
.36566 .47069 Mdot
.35481 .50387 Mdot
.19328 .61862 Mdot
.76712 .4375 Mdot
.69234 .50053 Mdot
.45565 .56912 Mdot
.54629 .38126 Mdot
.38992 .35176 Mdot
.67194 .53758 Mdot
.34555 .52895 Mdot
.39318 .5342 Mdot
.38965 .32597 Mdot
.38918 .79716 Mdot
.56123 .23315 Mdot
.63738 .51571 Mdot
.47162 .55212 Mdot
.56901 .39884 Mdot
.39989 .56816 Mdot
.50582 .23314 Mdot
.55719 .64967 Mdot
.68671 .48657 Mdot
.72345 .69577 Mdot
.37477 .48049 Mdot
.67933 .52974 Mdot
.65195 .50735 Mdot
.45161 .52755 Mdot
.50005 .62861 Mdot
.52815 .70464 Mdot
.523 .6403 Mdot
.69251 .22801 Mdot
.28867 .34725 Mdot
.56963 .32549 Mdot
.68365 .51188 Mdot
.57089 .37848 Mdot
.35561 .324 Mdot
.47457 .42313 Mdot
.59322 .36582 Mdot
.57087 .66852 Mdot
.53994 .39738 Mdot
.36723 .51266 Mdot
.65123 .51464 Mdot
.58834 .32153 Mdot
.40841 .48493 Mdot
.56805 .5916 Mdot
.55554 .28706 Mdot
.40898 .35658 Mdot
.41651 .34661 Mdot
.41679 .51441 Mdot
.60181 .31596 Mdot
.40404 .52803 Mdot
.65899 .54514 Mdot
.60599 .5877 Mdot
.38241 .47277 Mdot
.56699 .35152 Mdot
.51961 .5953 Mdot
.54838 .24334 Mdot
.45041 .57211 Mdot
.37766 .52153 Mdot
.39969 .56408 Mdot
.36751 .54907 Mdot
.65297 .67241 Mdot
.63133 .50602 Mdot
.5447 .56737 Mdot
.72256 .44252 Mdot
.5525 .66249 Mdot
.50536 .6779 Mdot
.46518 .23218 Mdot
.60921 .29053 Mdot
.68328 .50044 Mdot
.38848 .56695 Mdot
.74901 .47967 Mdot
.31419 .78468 Mdot
.16361 .45462 Mdot
.39444 .30524 Mdot
.58723 .31524 Mdot
.51976 .63086 Mdot
.53213 .35424 Mdot
.39903 .55372 Mdot
.45252 .51821 Mdot
.50121 .85824 Mdot
.6848 .55168 Mdot
.39102 .33731 Mdot
.39953 .56244 Mdot
.28735 .33595 Mdot
.55086 .3781 Mdot
.53672 .38979 Mdot
.4263 .55348 Mdot
.53019 .71344 Mdot
.79425 .67294 Mdot
.65441 .4851 Mdot
.49011 .56545 Mdot
.44938 .61966 Mdot
.73276 .55845 Mdot
.66572 .52685 Mdot
.56494 .26963 Mdot
.58838 .31381 Mdot
.29304 .69874 Mdot
.5559 .66458 Mdot
.39211 .3348 Mdot
.42997 .47555 Mdot
.56413 .68764 Mdot
.53831 .33366 Mdot
.54979 .69779 Mdot
.40251 .48956 Mdot
.63886 .49313 Mdot
.53251 .36833 Mdot
.64494 .54923 Mdot
.49851 .63598 Mdot
.36448 .35509 Mdot
.57258 .55962 Mdot
.47018 .70956 Mdot
.33844 .71398 Mdot
.40227 .57186 Mdot
.47011 .40466 Mdot
.35709 .53681 Mdot
.52083 .62228 Mdot
.37165 .55174 Mdot
.49834 .60829 Mdot
.53578 .35749 Mdot
.40313 .57906 Mdot
.34986 .49942 Mdot
.40469 .65761 Mdot
.38806 .51935 Mdot
.39776 .58601 Mdot
.37786 .56581 Mdot
.568 .72298 Mdot
.42426 .60484 Mdot
.54452 .68277 Mdot
.65193 .2607 Mdot
.55554 .37178 Mdot
.41338 .33866 Mdot
.40469 .3549 Mdot
.24399 .36915 Mdot
.36614 .39577 Mdot
.66113 .6532 Mdot
.54146 .67131 Mdot
.65828 .49634 Mdot
.3692 .55326 Mdot
.65436 .74965 Mdot
.72953 .405 Mdot
.54895 .38183 Mdot
.7432 .48268 Mdot
.43592 .47255 Mdot
.79956 .61737 Mdot
.42084 .56895 Mdot
.60164 .19505 Mdot
.32473 .50332 Mdot
.43753 .53424 Mdot
.52466 .38805 Mdot
.38137 .40692 Mdot
.41261 .56995 Mdot
.5279 .62277 Mdot
.38317 .32792 Mdot
.4907 .69423 Mdot
.61665 .389 Mdot
.57579 .26871 Mdot
.44179 .70111 Mdot
.36004 .54628 Mdot
.53406 .36783 Mdot
.54153 .69006 Mdot
.71697 .27817 Mdot
.66419 .48507 Mdot
.60231 .51991 Mdot
.3379 .62009 Mdot
.19971 .56457 Mdot
.38931 .3315 Mdot
.38242 .7911 Mdot
.39045 .4997 Mdot
.48577 .25307 Mdot
.34746 .48468 Mdot
.31841 .78711 Mdot
.35385 .34909 Mdot
.51996 .70488 Mdot
.69418 .51029 Mdot
.57632 .67256 Mdot
.3555 .73423 Mdot
.71682 .55484 Mdot
.55432 .51005 Mdot
.57272 .36823 Mdot
.55284 .56694 Mdot
.52288 .6517 Mdot
.36495 .49144 Mdot
.80531 .71739 Mdot
.55201 .64456 Mdot
.50787 .65688 Mdot
.19292 .47403 Mdot
.1875 .4835 Mdot
.45734 .50423 Mdot
.56543 .69166 Mdot
.57113 .3675 Mdot
.37386 .36319 Mdot
.36161 .51691 Mdot
.36584 .53425 Mdot
.56518 .67748 Mdot
.52888 .38939 Mdot
.48259 .54869 Mdot
.56212 .35872 Mdot
.53275 .6777 Mdot
.55049 .36902 Mdot
.74682 .45807 Mdot
.5951 .32191 Mdot
.37449 .57608 Mdot
.37102 .55236 Mdot
.58966 .39022 Mdot
.55901 .67797 Mdot
.35095 .51122 Mdot
.39794 .49241 Mdot
.53011 .6492 Mdot
.51517 .41024 Mdot
.54663 .75778 Mdot
.41616 .54791 Mdot
.37794 .50428 Mdot
.39035 .32441 Mdot
.45076 .40197 Mdot
.38986 .22496 Mdot
.3575 .50929 Mdot
.36146 .32148 Mdot
.53296 .70243 Mdot
.4042 .52409 Mdot
.59952 .72932 Mdot
.74005 .46161 Mdot
.37579 .48126 Mdot
.60335 .33795 Mdot
.41474 .48059 Mdot
.72244 .74021 Mdot
.43124 .53746 Mdot
.52746 .65706 Mdot
.5149 .67405 Mdot
.20287 .47123 Mdot
.54591 .64541 Mdot
.58999 .35916 Mdot
.66473 .51802 Mdot
.348 .80606 Mdot
.58015 .36868 Mdot
.4376 .50764 Mdot
.24964 .29286 Mdot
.42218 .5749 Mdot
.39617 .47885 Mdot
.81617 .57839 Mdot
.57739 .36976 Mdot
.51642 .6674 Mdot
.60691 .54176 Mdot
.32561 .53145 Mdot
.67765 .4817 Mdot
.44789 .51349 Mdot
.35262 .56153 Mdot
.79206 .45826 Mdot
.7747 .58646 Mdot
.69769 .53354 Mdot
.3607 .46091 Mdot
.3569 .50951 Mdot
.47874 .35695 Mdot
.37613 .55439 Mdot
.36318 .3314 Mdot
.51148 .64909 Mdot
.55075 .33365 Mdot
.37162 .35262 Mdot
.4124 .5365 Mdot
.39268 .34266 Mdot
.5655 .32547 Mdot
.69455 .49012 Mdot
.40468 .55293 Mdot
.36653 .37586 Mdot
.38798 .34078 Mdot
.35442 .53225 Mdot
.53178 .69616 Mdot
.38809 .43663 Mdot
.40361 .52069 Mdot
.37382 .48904 Mdot
.56392 .677 Mdot
.14927 .45227 Mdot
.43293 .53966 Mdot
.51312 .35219 Mdot
.50628 .65575 Mdot
.74107 .50936 Mdot
.55963 .32591 Mdot
.35451 .56382 Mdot
.69919 .49624 Mdot
.67707 .52661 Mdot
.5569 .38309 Mdot
.56684 .64254 Mdot
.5479 .40075 Mdot
.51363 .59634 Mdot
.35284 .58348 Mdot
.44007 .56424 Mdot
.28886 .25241 Mdot
.49366 .84903 Mdot
.5456 .6355 Mdot
.51009 .38271 Mdot
.58629 .48069 Mdot
.68688 .51281 Mdot
.55733 .38795 Mdot
.54244 .62836 Mdot
.52381 .63059 Mdot
.54885 .69559 Mdot
.40032 .3458 Mdot
.51028 .4042 Mdot
.55002 .71542 Mdot
.53048 .71305 Mdot
.36872 .51443 Mdot
.35532 .50976 Mdot
.29059 .50473 Mdot
.31396 .40787 Mdot
.36332 .35506 Mdot
.55691 .34513 Mdot
.85272 .39405 Mdot
.66722 .54522 Mdot
.40546 .66007 Mdot
.38052 .47275 Mdot
.67687 .85466 Mdot
.42831 .56077 Mdot
.37919 .55462 Mdot
.54896 .70891 Mdot
.37615 .38222 Mdot
.36701 .33161 Mdot
.52023 .65337 Mdot
.50779 .63121 Mdot
.36518 .32716 Mdot
.29827 .74333 Mdot
.40719 .82902 Mdot
.61999 .56849 Mdot
.53504 .65419 Mdot
.47247 .72625 Mdot
.68341 .48149 Mdot
.49366 .64046 Mdot
.65716 .54269 Mdot
.54822 .37716 Mdot
.58335 .31299 Mdot
.64143 .51977 Mdot
.36954 .52123 Mdot
.58236 .32459 Mdot
.36029 .5841 Mdot
.34683 .78519 Mdot
.4532 .78571 Mdot
.73455 .36044 Mdot
.33594 .53362 Mdot
.62711 .25675 Mdot
.63738 .29231 Mdot
.4202 .5291 Mdot
.62968 .73284 Mdot
.39206 .33859 Mdot
.50463 .69121 Mdot
.70199 .5077 Mdot
.69281 .77256 Mdot
.39645 .56833 Mdot
.5309 .65951 Mdot
.66615 .4959 Mdot
.21814 .45688 Mdot
.63992 .58583 Mdot
.40158 .56042 Mdot
.83543 .66639 Mdot
.55784 .73329 Mdot
.5529 .33218 Mdot
.37629 .19978 Mdot
.57696 .69072 Mdot
.37236 .29415 Mdot
.68797 .43658 Mdot
.19459 .59157 Mdot
.52397 .67839 Mdot
.50839 .38868 Mdot
.51819 .64784 Mdot
.36086 .34346 Mdot
.51573 .71304 Mdot
.53261 .37816 Mdot
.38797 .52412 Mdot
.56137 .34919 Mdot
.36619 .36121 Mdot
.4965 .24172 Mdot
.70192 .50466 Mdot
.6047 .33838 Mdot
.67439 .51242 Mdot
.30303 .32705 Mdot
.79503 .49912 Mdot
.67059 .48784 Mdot
.20515 .44389 Mdot
.38637 .47976 Mdot
.56533 .70823 Mdot
.57559 .33372 Mdot
.67482 .4359 Mdot
.57663 .54049 Mdot
.54928 .65678 Mdot
.55024 .34656 Mdot
.34306 .61819 Mdot
.25445 .31065 Mdot
.3664 .60133 Mdot
.31346 .34243 Mdot
.53427 .6504 Mdot
.53988 .39329 Mdot
.67022 .25429 Mdot
.57065 .66395 Mdot
.57931 .33652 Mdot
.69073 .51791 Mdot
.66042 .52442 Mdot
.417 .56367 Mdot
.61323 .49914 Mdot
.55979 .33492 Mdot
.65489 .29028 Mdot
.51203 .68103 Mdot
.22207 .45389 Mdot
.38352 .37816 Mdot
.56369 .36614 Mdot
.44331 .53732 Mdot
.50947 .61132 Mdot
.74069 .45871 Mdot
.47056 .49113 Mdot
.84904 .40284 Mdot
.5603 .34329 Mdot
.50965 .65332 Mdot
.5354 .66166 Mdot
.45219 .56464 Mdot
.59071 .5148 Mdot
.55361 .40021 Mdot
.25694 .3252 Mdot
.23033 .40036 Mdot
.54747 .32429 Mdot
.63943 .34722 Mdot
.44164 .51706 Mdot
.35696 .54909 Mdot
.68902 .51205 Mdot
.38344 .52059 Mdot
.53443 .71074 Mdot
.40743 .57245 Mdot
.66373 .5296 Mdot
.58244 .35629 Mdot
.40246 .54846 Mdot
.3777 .36759 Mdot
.70811 .5148 Mdot
.64594 .53249 Mdot
.56972 .35953 Mdot
.56187 .69332 Mdot
.42118 .34982 Mdot
.56026 .35755 Mdot
.36098 .54638 Mdot
.61214 .44108 Mdot
.4076 .49443 Mdot
.29175 .72203 Mdot
.57234 .67205 Mdot
.53419 .35414 Mdot
.50379 .65652 Mdot
.67624 .50821 Mdot
.72091 .44248 Mdot
.37403 .5376 Mdot
.58098 .33843 Mdot
.60361 .3814 Mdot
.32935 .76352 Mdot
.55391 .62989 Mdot
.65105 .37067 Mdot
.50998 .68351 Mdot
.55754 .31864 Mdot
.23361 .55036 Mdot
.38153 .33252 Mdot
.5414 .38298 Mdot
.48855 .83497 Mdot
.57111 .3467 Mdot
.3894 .51556 Mdot
.40464 .50988 Mdot
.56641 .32257 Mdot
.40506 .34311 Mdot
.76135 .31539 Mdot
.56774 .28733 Mdot
.51908 .67297 Mdot
.24737 .60801 Mdot
.86167 .46869 Mdot
.62125 .51305 Mdot
.69183 .50676 Mdot
.32576 .52133 Mdot
.43884 .53431 Mdot
.67078 .54114 Mdot
.69089 .48021 Mdot
.36933 .37136 Mdot
.53618 .38598 Mdot
.52557 .72323 Mdot
.70554 .49906 Mdot
.32114 .48087 Mdot
.34568 .37027 Mdot
.44555 .58624 Mdot
.45185 .61267 Mdot
.33777 .51816 Mdot
.22949 .38426 Mdot
.65321 .52835 Mdot
.41195 .50711 Mdot
.43285 .59736 Mdot
.69371 .49202 Mdot
.36132 .33936 Mdot
.77172 .57586 Mdot
.54417 .3672 Mdot
.18182 .65509 Mdot
.42609 .51398 Mdot
.39365 .51653 Mdot
.6391 .50391 Mdot
.46884 .36238 Mdot
.56103 .68769 Mdot
.57358 .67341 Mdot
.59576 .33125 Mdot
.5629 .55301 Mdot
.38553 .57472 Mdot
.42029 .52414 Mdot
.54011 .3615 Mdot
.60581 .33362 Mdot
.69503 .32657 Mdot
.38764 .49368 Mdot
.66876 .49688 Mdot
.5842 .4442 Mdot
.65745 .52984 Mdot
.42731 .5091 Mdot
.3902 .51235 Mdot
.37767 .57681 Mdot
.44034 .52693 Mdot
.64423 .5319 Mdot
.40839 .50481 Mdot
.315 .51847 Mdot
.54851 .7008 Mdot
.36402 .56605 Mdot
.22612 .39754 Mdot
.37687 .51426 Mdot
.36715 .35724 Mdot
.40402 .41791 Mdot
.40154 .56415 Mdot
.36594 .57131 Mdot
.56383 .29001 Mdot
.385 .53416 Mdot
.65848 .54492 Mdot
.54922 .66386 Mdot
.68339 .51261 Mdot
.6439 .52605 Mdot
.5958 .34941 Mdot
.3596 .35096 Mdot
.36078 .47326 Mdot
.39165 .37101 Mdot
.37547 .46187 Mdot
.38266 .48029 Mdot
.71173 .42845 Mdot
.59375 .18965 Mdot
.55579 .23089 Mdot
.37308 .53743 Mdot
.5872 .35025 Mdot
.5449 .3385 Mdot
.49079 .52173 Mdot
.38545 .60188 Mdot
.67373 .53988 Mdot
.68116 .52316 Mdot
.29403 .44165 Mdot
.79036 .46175 Mdot
.36393 .3521 Mdot
.47327 .41439 Mdot
.35772 .58333 Mdot
.38744 .48909 Mdot
.43829 .55933 Mdot
.58769 .36892 Mdot
.60551 .44277 Mdot
.54966 .38136 Mdot
.73896 .47758 Mdot
.66482 .53111 Mdot
.38777 .57122 Mdot
.49604 .79564 Mdot
.5636 .65356 Mdot
.54988 .6646 Mdot
.66792 .53676 Mdot
.56484 .388 Mdot
.32876 .4533 Mdot
.16832 .36313 Mdot
.55496 .7299 Mdot
.39265 .37865 Mdot
.42189 .53422 Mdot
.57914 .35422 Mdot
.53469 .63544 Mdot
.40404 .33172 Mdot
.37724 .4829 Mdot
.54695 .40291 Mdot
.37057 .53735 Mdot
.29919 .56976 Mdot
.53314 .694 Mdot
.34636 .81022 Mdot
.55328 .63554 Mdot
.70672 .51406 Mdot
.68764 .49232 Mdot
.39842 .51026 Mdot
.31594 .23452 Mdot
.57112 .7025 Mdot
.66239 .46166 Mdot
.35596 .35529 Mdot
.63896 .43797 Mdot
.37104 .31952 Mdot
.53966 .34839 Mdot
.38547 .32904 Mdot
.53003 .37072 Mdot
.3178 .42198 Mdot
.585 .69877 Mdot
.37122 .34568 Mdot
.50265 .33513 Mdot
.38222 .60157 Mdot
.40833 .32995 Mdot
.34142 .47488 Mdot
.26899 .65969 Mdot
.54263 .3594 Mdot
.40344 .34896 Mdot
.36461 .49245 Mdot
.61314 .79496 Mdot
.67846 .49351 Mdot
.67615 .54061 Mdot
.37157 .59057 Mdot
.53773 .38756 Mdot
.52149 .626 Mdot
.62489 .6575 Mdot
.72457 .5339 Mdot
.41704 .51628 Mdot
.41099 .57098 Mdot
.5072 .68391 Mdot
.59091 .67044 Mdot
.39264 .50904 Mdot
.40238 .64267 Mdot
.39683 .49952 Mdot
.69001 .52207 Mdot
.56189 .64635 Mdot
.54099 .66237 Mdot
.55239 .33967 Mdot
.56411 .69858 Mdot
.49722 .60434 Mdot
.61205 .4484 Mdot
.33357 .48334 Mdot
.66961 .50444 Mdot
.60694 .47247 Mdot
.74337 .48161 Mdot
.53684 .81293 Mdot
.50023 .66548 Mdot
.36489 .57406 Mdot
.50871 .67338 Mdot
.39109 .35597 Mdot
.55675 .67747 Mdot
.51379 .63702 Mdot
.41003 .52581 Mdot
.39794 .55671 Mdot
.5798 .36597 Mdot
.59035 .50506 Mdot
.54102 .70325 Mdot
.4124 .51144 Mdot
.41209 .57897 Mdot
.39675 .58665 Mdot
.51599 .45741 Mdot
.5411 .63417 Mdot
.34163 .64694 Mdot
.25264 .50436 Mdot
.54281 .70346 Mdot
.74712 .71878 Mdot
.69746 .44149 Mdot
.60938 .35046 Mdot
.63381 .54372 Mdot
.38664 .49297 Mdot
.56521 .32167 Mdot
.39943 .55337 Mdot
.45187 .61285 Mdot
.39285 .53721 Mdot
.37941 .31709 Mdot
.3283 .51238 Mdot
.57258 .31182 Mdot
.5614 .35455 Mdot
.42857 .52757 Mdot
.4003 .54614 Mdot
.51957 .24009 Mdot
.50396 .63379 Mdot
.55891 .68952 Mdot
.4684 .35034 Mdot
.3789 .34876 Mdot
.68396 .48447 Mdot
.37405 .56049 Mdot
.5942 .34274 Mdot
.56043 .35132 Mdot
.57702 .67246 Mdot
.54937 .35737 Mdot
.64714 .49153 Mdot
.37455 .54204 Mdot
.67377 .54135 Mdot
.40196 .35366 Mdot
.52033 .64035 Mdot
.39212 .56859 Mdot
.36888 .51347 Mdot
.51493 .67387 Mdot
.36651 .47646 Mdot
.38875 .32346 Mdot
.56872 .34597 Mdot
.53004 .68352 Mdot
.66441 .51982 Mdot
.53503 .35752 Mdot
.36639 .50077 Mdot
.84762 .39347 Mdot
.3852 .51227 Mdot
.37525 .49393 Mdot
.46092 .8478 Mdot
.32946 .50467 Mdot
.56708 .3354 Mdot
.52005 .70665 Mdot
.3574 .57895 Mdot
.25441 .36765 Mdot
.15898 .45869 Mdot
.56027 .3791 Mdot
.42364 .53965 Mdot
.54195 .82267 Mdot
.42757 .53514 Mdot
.20121 .40362 Mdot
.41154 .24801 Mdot
.52636 .54454 Mdot
.33136 .56626 Mdot
.64325 .50454 Mdot
.58154 .36455 Mdot
.53726 .35594 Mdot
.27256 .61349 Mdot
.41355 .52386 Mdot
.29321 .54179 Mdot
.35754 .49111 Mdot
.66346 .52673 Mdot
.2821 .46883 Mdot
.55885 .34634 Mdot
.63717 .22788 Mdot
.35982 .53725 Mdot
.53912 .63275 Mdot
.53799 .39744 Mdot
.71182 .44697 Mdot
.36897 .49406 Mdot
.39515 .36678 Mdot
.69282 .54313 Mdot
.33114 .54935 Mdot
.66418 .5071 Mdot
.38782 .48692 Mdot
.3099 .51084 Mdot
.42076 .1809 Mdot
.53937 .69795 Mdot
.69252 .51135 Mdot
.63909 .31528 Mdot
.3473 .48221 Mdot
.52719 .68207 Mdot
.55513 .66337 Mdot
.37418 .3734 Mdot
.56371 .49077 Mdot
.70783 .59623 Mdot
.49613 .76374 Mdot
.25307 .60162 Mdot
.5501 .39383 Mdot
.66343 .33755 Mdot
.3597 .51432 Mdot
.77566 .39854 Mdot
.67762 .54363 Mdot
.39193 .51917 Mdot
.28559 .67075 Mdot
.52756 .63854 Mdot
.38149 .50063 Mdot
.36405 .33192 Mdot
.74855 .34224 Mdot
.76303 .37193 Mdot
.77023 .66303 Mdot
.56634 .37164 Mdot
.44893 .51168 Mdot
.44159 .61403 Mdot
.60109 .34927 Mdot
.35292 .4842 Mdot
.57089 .33726 Mdot
.23488 .6559 Mdot
.3995 .32952 Mdot
.52406 .63584 Mdot
.70295 .44331 Mdot
.3404 .52847 Mdot
.41627 .58113 Mdot
.41311 .34472 Mdot
.35099 .5432 Mdot
.50866 .17171 Mdot
.73232 .37734 Mdot
.58841 .32324 Mdot
.54715 .69681 Mdot
.34074 .54201 Mdot
.56139 .44659 Mdot
.40959 .51987 Mdot
.43896 .76096 Mdot
.36224 .56977 Mdot
.70251 .58815 Mdot
.52338 .68951 Mdot
.66769 .50768 Mdot
.41275 .46884 Mdot
.3875 .54298 Mdot
.54988 .41452 Mdot
.32677 .55758 Mdot
.43321 .53085 Mdot
.53469 .62379 Mdot
.55648 .64363 Mdot
.54415 .68161 Mdot
.52699 .35586 Mdot
.78698 .45376 Mdot
.67695 .50053 Mdot
.43368 .49617 Mdot
.70571 .49816 Mdot
.48003 .54272 Mdot
.40997 .3553 Mdot
.62428 .77897 Mdot
.35182 .55358 Mdot
.53944 .67441 Mdot
.70372 .66768 Mdot
.53032 .70147 Mdot
.53153 .42995 Mdot
.65062 .51126 Mdot
.53641 .63779 Mdot
.38196 .55 Mdot
.59587 .47743 Mdot
.68889 .74096 Mdot
.6798 .5173 Mdot
.37391 .46592 Mdot
.59545 .31625 Mdot
.7558 .43553 Mdot
.87017 .4243 Mdot
.69137 .49934 Mdot
.64338 .32164 Mdot
.41768 .52484 Mdot
.56719 .66169 Mdot
.64331 .50012 Mdot
.66646 .49008 Mdot
.54793 .35375 Mdot
.39791 .55885 Mdot
.39619 .56289 Mdot
.55891 .31899 Mdot
.67806 .52429 Mdot
.42631 .58148 Mdot
.43606 .55541 Mdot
.50125 .86003 Mdot
.26742 .55772 Mdot
.13169 .55025 Mdot
.50932 .5942 Mdot
.29588 .68787 Mdot
.61369 .64528 Mdot
.51031 .64702 Mdot
.40316 .56319 Mdot
.33482 .51648 Mdot
.55835 .33664 Mdot
.38021 .52587 Mdot
.51395 .38604 Mdot
.68548 .49986 Mdot
.74222 .71929 Mdot
.75064 .61064 Mdot
.22697 .63773 Mdot
.38233 .52719 Mdot
.76137 .52585 Mdot
.38092 .35986 Mdot
.71081 .50021 Mdot
.53641 .68288 Mdot
.40828 .4919 Mdot
.52832 .23848 Mdot
.54389 .38246 Mdot
.55805 .65765 Mdot
.63295 .25071 Mdot
.58719 .26256 Mdot
.42662 .50818 Mdot
.53197 .34667 Mdot
.6539 .7009 Mdot
.41389 .64229 Mdot
.65194 .47606 Mdot
.37561 .31775 Mdot
.5518 .37912 Mdot
.66222 .53432 Mdot
.59383 .72331 Mdot
.54174 .64063 Mdot
.55039 .72215 Mdot
.49196 .22063 Mdot
.59697 .3649 Mdot
.37275 .35766 Mdot
.78703 .46006 Mdot
.7923 .41205 Mdot
.37901 .31744 Mdot
.57068 .31627 Mdot
.54896 .63931 Mdot
.52607 .66841 Mdot
.548 .66297 Mdot
.64892 .23387 Mdot
.56631 .64315 Mdot
.41691 .68167 Mdot
.41658 .57857 Mdot
.30088 .52425 Mdot
.42523 .53934 Mdot
.65592 .54145 Mdot
.52835 .68948 Mdot
.59362 .57161 Mdot
.4242 .49075 Mdot
.74745 .69502 Mdot
.42012 .52118 Mdot
.66399 .47305 Mdot
.38144 .49604 Mdot
.44304 .67872 Mdot
.50555 .66312 Mdot
.37562 .53017 Mdot
.63538 .53267 Mdot
.38631 .34462 Mdot
.48742 .64032 Mdot
.40005 .56353 Mdot
.64615 .63613 Mdot
.33111 .4985 Mdot
.2761 .72135 Mdot
.229 .46312 Mdot
.39347 .37813 Mdot
.47439 .57695 Mdot
.54781 .39011 Mdot
.29922 .52307 Mdot
.40489 .61155 Mdot
.67774 .51749 Mdot
.79424 .5393 Mdot
.55795 .37173 Mdot
.32236 .4386 Mdot
.45834 .56219 Mdot
.35941 .34552 Mdot
.56774 .63397 Mdot
.64516 .53732 Mdot
.41253 .48907 Mdot
.45147 .53136 Mdot
.24597 .66898 Mdot
.38253 .60702 Mdot
.40098 .57593 Mdot
.41068 .34899 Mdot
.34911 .65693 Mdot
.37423 .51255 Mdot
.5283 .4308 Mdot
.54494 .72252 Mdot
.37352 .59363 Mdot
.34286 .64456 Mdot
.41266 .51275 Mdot
.56214 .65889 Mdot
.58408 .69385 Mdot
.70818 .64008 Mdot
.35823 .35846 Mdot
.36153 .56875 Mdot
.21613 .50472 Mdot
.358 .54124 Mdot
.66589 .49829 Mdot
.43668 .52554 Mdot
.53974 .38002 Mdot
.63665 .23549 Mdot
.56963 .32677 Mdot
.41278 .55754 Mdot
.54272 .65927 Mdot
.63911 .51451 Mdot
.52617 .22164 Mdot
.43624 .25535 Mdot
.40549 .67608 Mdot
.18063 .59183 Mdot
.40368 .34282 Mdot
.37825 .31354 Mdot
.64009 .53114 Mdot
.37486 .52862 Mdot
.20159 .48758 Mdot
.32321 .51594 Mdot
.37759 .50285 Mdot
.39393 .5374 Mdot
.77691 .46891 Mdot
.68691 .508 Mdot
.54904 .36368 Mdot
.39053 .50985 Mdot
.40978 .50776 Mdot
.50981 .66234 Mdot
.38614 .34248 Mdot
.55459 .32948 Mdot
.37782 .34047 Mdot
.58174 .34784 Mdot
.73568 .73124 Mdot
.41012 .47357 Mdot
.38475 .34711 Mdot
.69656 .53625 Mdot
.56459 .67608 Mdot
.61439 .44163 Mdot
.53935 .34991 Mdot
.55595 .34463 Mdot
.41789 .51889 Mdot
.56555 .66389 Mdot
.5579 .70221 Mdot
.39182 .35655 Mdot
.67272 .48583 Mdot
.40576 .55757 Mdot
.39031 .48234 Mdot
.50477 .53293 Mdot
.58164 .37306 Mdot
.35761 .62134 Mdot
.68184 .66069 Mdot
.37307 .53393 Mdot
.56384 .69321 Mdot
.40112 .53856 Mdot
.49754 .80868 Mdot
.57058 .672 Mdot
.43479 .54114 Mdot
.79376 .38994 Mdot
.59775 .44291 Mdot
.66958 .6209 Mdot
.38528 .57998 Mdot
.19869 .66024 Mdot
.35536 .51812 Mdot
.53168 .84584 Mdot
.49912 .2672 Mdot
.39028 .57236 Mdot
.36364 .51165 Mdot
.52056 .77478 Mdot
.41557 .53796 Mdot
.5736 .31054 Mdot
.31863 .43989 Mdot
.51757 .63052 Mdot
.60161 .60291 Mdot
.43698 .42017 Mdot
.36118 .36644 Mdot
.59557 .33055 Mdot
.63664 .36852 Mdot
.37299 .32363 Mdot
.53242 .65342 Mdot
.36734 .54946 Mdot
.54425 .54057 Mdot
.52518 .34847 Mdot
.41988 .58777 Mdot
.65984 .50134 Mdot
.69019 .36332 Mdot
.51207 .39191 Mdot
.6651 .51443 Mdot
.34477 .5356 Mdot
.54652 .75989 Mdot
.39621 .24142 Mdot
.36322 .82355 Mdot
.63755 .5138 Mdot
.67255 .52877 Mdot
.68293 .2491 Mdot
.35804 .36395 Mdot
.24427 .64215 Mdot
.68008 .5881 Mdot
.65458 .48357 Mdot
.23405 .52489 Mdot
.54989 .38321 Mdot
.64468 .62579 Mdot
.5044 .69075 Mdot
.44032 .56276 Mdot
.38316 .54767 Mdot
.67758 .48651 Mdot
.58971 .73332 Mdot
.40514 .18719 Mdot
.67423 .51373 Mdot
.3195 .4929 Mdot
.52034 .47778 Mdot
.69169 .44032 Mdot
.58768 .36597 Mdot
.36111 .3626 Mdot
.35824 .30359 Mdot
.51305 .65769 Mdot
.36524 .36455 Mdot
.75466 .3611 Mdot
.35134 .54879 Mdot
.67298 .52119 Mdot
.71742 .45262 Mdot
.66071 .52009 Mdot
.36983 .32709 Mdot
.38715 .38154 Mdot
.54952 .7004 Mdot
.55835 .68892 Mdot
.31193 .70031 Mdot
.27246 .44635 Mdot
.42845 .532 Mdot
.71357 .70213 Mdot
.51431 .68515 Mdot
.46504 .60099 Mdot
.36888 .31795 Mdot
.38256 .34558 Mdot
.28485 .56344 Mdot
.38285 .56695 Mdot
.20125 .46177 Mdot
.38064 .56454 Mdot
.28056 .46085 Mdot
.34628 .48846 Mdot
.54851 .35534 Mdot
.3802 .56869 Mdot
.40205 .39191 Mdot
.44159 .51784 Mdot
.43318 .52456 Mdot
.54111 .38778 Mdot
.33499 .55797 Mdot
.53882 .37944 Mdot
.41622 .5565 Mdot
.35526 .32576 Mdot
.59522 .34062 Mdot
.28139 .35906 Mdot
.52199 .3379 Mdot
.60092 .31625 Mdot
.37536 .36971 Mdot
.38719 .37618 Mdot
.27229 .33517 Mdot
.53492 .68233 Mdot
.49291 .62824 Mdot
.37664 .52427 Mdot
.53643 .38998 Mdot
.68972 .50898 Mdot
.40594 .50426 Mdot
.33489 .49974 Mdot
.40283 .57787 Mdot
.51518 .6456 Mdot
.55642 .39797 Mdot
.38969 .34783 Mdot
.5273 .35315 Mdot
.53033 .40957 Mdot
.51406 .37417 Mdot
.43508 .59965 Mdot
.40839 .46019 Mdot
.31567 .72655 Mdot
.75815 .6438 Mdot
.74677 .29427 Mdot
.54769 .64436 Mdot
.60392 .33752 Mdot
.37593 .3779 Mdot
.4373 .46235 Mdot
.53533 .6766 Mdot
.53343 .37855 Mdot
.37043 .53893 Mdot
.37503 .46494 Mdot
.69804 .54783 Mdot
.29765 .53565 Mdot
.23574 .4115 Mdot
.51638 .38005 Mdot
.5078 .38819 Mdot
.78898 .41072 Mdot
.31581 .44625 Mdot
.57015 .54853 Mdot
.39774 .52663 Mdot
.39726 .36448 Mdot
.53486 .63546 Mdot
.44499 .21973 Mdot
.69814 .50176 Mdot
.59075 .51015 Mdot
.3814 .52811 Mdot
.64599 .57965 Mdot
.5446 .65953 Mdot
.36208 .34197 Mdot
.67911 .48653 Mdot
.38074 .38506 Mdot
.5976 .36054 Mdot
.17925 .5057 Mdot
.35469 .54148 Mdot
.43078 .53764 Mdot
.70379 .51231 Mdot
.51936 .64799 Mdot
.41393 .35488 Mdot
.30138 .74201 Mdot
.56703 .32364 Mdot
.19378 .45986 Mdot
.55234 .71 Mdot
.44792 .70521 Mdot
.52568 .3561 Mdot
.66837 .53631 Mdot
.28218 .32835 Mdot
.66239 .52955 Mdot
.40625 .56658 Mdot
.54064 .66822 Mdot
.6768 .49407 Mdot
.5586 .42625 Mdot
.57095 .81265 Mdot
.46445 .7207 Mdot
.36565 .56084 Mdot
.65817 .76729 Mdot
.38449 .80879 Mdot
.5487 .74395 Mdot
.70118 .49839 Mdot
.40471 .51934 Mdot
.34555 .50212 Mdot
.36133 .54033 Mdot
.65044 .50385 Mdot
.69034 .41954 Mdot
.54208 .35565 Mdot
.42405 .53043 Mdot
.3722 .37356 Mdot
.5409 .37711 Mdot
.71689 .44566 Mdot
.56211 .33793 Mdot
.49984 .64297 Mdot
.43897 .5316 Mdot
.6066 .5 Mdot
.62538 .81451 Mdot
.68265 .51377 Mdot
.60036 .31559 Mdot
.41646 .50472 Mdot
.78222 .50628 Mdot
.54255 .68014 Mdot
.57046 .32276 Mdot
.39409 .51708 Mdot
.65895 .42249 Mdot
.51532 .23835 Mdot
.56088 .33964 Mdot
.52652 .67347 Mdot
.59197 .74679 Mdot
.38177 .52182 Mdot
.35369 .52154 Mdot
.5216 .64897 Mdot
.42033 .41149 Mdot
.64805 .25022 Mdot
.40013 .54329 Mdot
.66736 .50901 Mdot
.1846 .36994 Mdot
.39561 .58412 Mdot
.26756 .52638 Mdot
.5703 .37238 Mdot
.66837 .64679 Mdot
.36437 .62374 Mdot
.47287 .55952 Mdot
.53347 .78408 Mdot
.47977 .43171 Mdot
.72299 .7339 Mdot
.51942 .39025 Mdot
.52228 .28156 Mdot
.71741 .74481 Mdot
.63202 .5222 Mdot
.58548 .63307 Mdot
.49408 .5644 Mdot
.61969 .21986 Mdot
.61116 .71895 Mdot
.47542 .31901 Mdot
.54562 .23569 Mdot
.52647 .51244 Mdot
.57612 .34393 Mdot
.3686 .41899 Mdot
.40328 .55577 Mdot
.37747 .80679 Mdot
.40874 .64743 Mdot
.38019 .19051 Mdot
.64933 .77255 Mdot
.21878 .50408 Mdot
.64668 .7604 Mdot
.52175 .82251 Mdot
.29537 .70775 Mdot
.74217 .65812 Mdot
.19166 .39231 Mdot
.78438 .38301 Mdot
.21139 .55559 Mdot
.43721 .47862 Mdot
.47708 .40964 Mdot
.21908 .65984 Mdot
.42492 .70518 Mdot
.29551 .25499 Mdot
.55886 .33235 Mdot
.52224 .70838 Mdot
.49882 .55907 Mdot
.54056 .62115 Mdot
.64603 .56684 Mdot
.54553 .78821 Mdot
.51515 .84314 Mdot
.43509 .67121 Mdot
.19925 .66661 Mdot
.29247 .65592 Mdot
.62675 .17195 Mdot
.54999 .2916 Mdot
.56516 .71196 Mdot
.43406 .31567 Mdot
.79281 .42465 Mdot
.74502 .5954 Mdot
.51236 .58955 Mdot
.74066 .4329 Mdot
.29146 .38179 Mdot
.5316 .65883 Mdot
.40603 .63696 Mdot
.60397 .28445 Mdot
.76414 .58328 Mdot
.34861 .2893 Mdot
.54148 .803 Mdot
.55373 .52738 Mdot
.63402 .62187 Mdot
.66972 .33203 Mdot
.84803 .3967 Mdot
.24334 .48073 Mdot
.4382 .80915 Mdot
.64464 .55991 Mdot
.59416 .73549 Mdot
.56971 .2063 Mdot
.2864 .42301 Mdot
.79385 .42194 Mdot
.82231 .522 Mdot
.34749 .7992 Mdot
.83916 .53187 Mdot
.49228 .63147 Mdot
.399 .57764 Mdot
.42902 .79554 Mdot
.25173 .56658 Mdot
.36763 .30675 Mdot
.78605 .63659 Mdot
.4033 .35377 Mdot
.5096 .62201 Mdot
.62757 .2382 Mdot
.4262 .6781 Mdot
.19674 .45181 Mdot
.41345 .36233 Mdot
.33635 .53654 Mdot
.36369 .15269 Mdot
.71613 .7356 Mdot
.70287 .63849 Mdot
.50317 .86 Mdot
.70592 .56679 Mdot
.21978 .46369 Mdot
.67039 .49351 Mdot
.67927 .78083 Mdot
.53025 .66813 Mdot
.80433 .68515 Mdot
.61381 .80852 Mdot
.38869 .20785 Mdot
.13885 .37456 Mdot
.76105 .39039 Mdot
.54189 .55959 Mdot
.47672 .43762 Mdot
.256 .38629 Mdot
.44766 .18526 Mdot
.34645 .23082 Mdot
.77356 .49182 Mdot
.20132 .62415 Mdot
.68433 .7708 Mdot
.2323 .54339 Mdot
.18897 .5249 Mdot
.60773 .21664 Mdot
.50398 .43072 Mdot
.53275 .61351 Mdot
.55647 .30688 Mdot
.62129 .75159 Mdot
.81174 .60935 Mdot
.26032 .52354 Mdot
.15906 .37449 Mdot
.41588 .36939 Mdot
.48935 .27351 Mdot
.44612 .82888 Mdot
.29902 .35135 Mdot
.24729 .53606 Mdot
.70856 .27501 Mdot
.43305 .58878 Mdot
.74251 .30986 Mdot
.66829 .72399 Mdot
.64683 .37093 Mdot
.7758 .36835 Mdot
.64131 .68655 Mdot
.26317 .69519 Mdot
.43895 .78213 Mdot
.79774 .43483 Mdot
.51125 .63148 Mdot
.27338 .41644 Mdot
.23742 .49998 Mdot
.49302 .8608 Mdot
.63933 .3164 Mdot
.41299 .8636 Mdot
.60756 .24783 Mdot
.35693 .47024 Mdot
.39698 .61351 Mdot
.34931 .45093 Mdot
.26292 .44262 Mdot
.41231 .57764 Mdot
.762 .51544 Mdot
.47823 .85823 Mdot
.27567 .65104 Mdot
.64544 .38315 Mdot
.79662 .54514 Mdot
.36941 .82671 Mdot
.3485 .75647 Mdot
.5265 .24942 Mdot
.28203 .49796 Mdot
.7413 .26888 Mdot
.55102 .3718 Mdot
.23023 .54315 Mdot
.63952 .48833 Mdot
.45199 .2256 Mdot
.49796 .75646 Mdot
.42493 .2022 Mdot
.47701 .85843 Mdot
.65613 .2618 Mdot
.57619 .24248 Mdot
.30515 .30345 Mdot
.18629 .44907 Mdot
.79635 .57422 Mdot
.4442 .50644 Mdot
.56298 .6007 Mdot
.4071 .3548 Mdot
.34894 .73259 Mdot
.23796 .56944 Mdot
.44482 .28798 Mdot
.32972 .55696 Mdot
.3655 .25681 Mdot
.50694 .39832 Mdot
.59414 .49301 Mdot
.86529 .5185 Mdot
.41261 .5967 Mdot
.76919 .43553 Mdot
.31528 .77163 Mdot
.24863 .43268 Mdot
.44753 .82381 Mdot
.62983 .64486 Mdot
.83359 .53464 Mdot
.58537 .81927 Mdot
.43402 .26599 Mdot
.7635 .68943 Mdot
.47853 .87137 Mdot
.83541 .49897 Mdot
.35289 .60334 Mdot
.65214 .5458 Mdot
.8914 .54684 Mdot
.53712 .3355 Mdot
.8026 .50535 Mdot
.25349 .60175 Mdot
.66506 .41327 Mdot
.48674 .65448 Mdot
.41289 .45671 Mdot
.53333 .52007 Mdot
.57186 .73209 Mdot
.35785 .5809 Mdot
.85612 .45634 Mdot
.82274 .48736 Mdot
.8501 .49493 Mdot
.26504 .72573 Mdot
.76195 .69502 Mdot
.50788 .5136 Mdot
.42942 .69504 Mdot
.48295 .51181 Mdot
.43406 .51444 Mdot
.35272 .40669 Mdot
.75804 .38711 Mdot
.40347 .23094 Mdot
.73585 .59038 Mdot
.52531 .62095 Mdot
.74378 .68258 Mdot
.82349 .29769 Mdot
.30889 .67072 Mdot
.30827 .62831 Mdot
.77207 .38505 Mdot
.26247 .45728 Mdot
.63975 .74321 Mdot
.38986 .22181 Mdot
.47028 .84757 Mdot
.48496 .5547 Mdot
.22542 .58037 Mdot
.45862 .31664 Mdot
.22167 .37393 Mdot
.47471 .36587 Mdot
.56286 .8049 Mdot
.47425 .46045 Mdot
.4916 .20381 Mdot
.58969 .58302 Mdot
.39569 .19829 Mdot
.46922 .24587 Mdot
.69169 .35805 Mdot
.21987 .54502 Mdot
.75027 .47304 Mdot
.26159 .47788 Mdot
.53253 .48743 Mdot
.42318 .44694 Mdot
.48081 .43256 Mdot
.25671 .48539 Mdot
.23178 .36154 Mdot
.80533 .62266 Mdot
.47923 .88039 Mdot
.82101 .37015 Mdot
.20897 .68104 Mdot
.66773 .7173 Mdot
.43731 .56973 Mdot
.42709 .83693 Mdot
.84733 .54465 Mdot
.58313 .82685 Mdot
.66574 .28242 Mdot
.60175 .42826 Mdot
.71099 .50702 Mdot
.82304 .38452 Mdot
.47058 .34243 Mdot
.49442 .82555 Mdot
.7551 .31384 Mdot
.63714 .54657 Mdot
.58206 .18559 Mdot
.81587 .4823 Mdot
.49251 .74142 Mdot
.32094 .59143 Mdot
.44149 .57688 Mdot
.44524 .66714 Mdot
.50184 .65926 Mdot
.65863 .32412 Mdot
.27613 .43327 Mdot
.56494 .36276 Mdot
.33988 .3633 Mdot
.5409 .59205 Mdot
.32791 .51487 Mdot
.44614 .42113 Mdot
.51657 .70451 Mdot
.7559 .64567 Mdot
.62713 .45604 Mdot
.79382 .67421 Mdot
.74219 .37234 Mdot
.32628 .5591 Mdot
.24715 .4454 Mdot
.60121 .26702 Mdot
.69313 .26195 Mdot
.639 .4936 Mdot
.62854 .78664 Mdot
.51471 .4239 Mdot
.27251 .42058 Mdot
.44394 .65999 Mdot
.27624 .70424 Mdot
.40898 .45921 Mdot
.69413 .66219 Mdot
.41284 .75484 Mdot
.58992 .49683 Mdot
.52735 .61437 Mdot
.54408 .61442 Mdot
.32008 .80931 Mdot
.7366 .32833 Mdot
.67665 .35085 Mdot
.61632 .79145 Mdot
.6477 .51809 Mdot
.53752 .70339 Mdot
.34447 .41835 Mdot
.26922 .70701 Mdot
.4248 .73908 Mdot
.51691 .23789 Mdot
.73261 .40494 Mdot
.45931 .28445 Mdot
.63687 .77388 Mdot
.65609 .76139 Mdot
.37113 .19087 Mdot
.55752 .63116 Mdot
.30781 .73744 Mdot
.22361 .61947 Mdot
.51332 .69112 Mdot
.48736 .66986 Mdot
.75649 .57016 Mdot
.80459 .64194 Mdot
.61854 .4837 Mdot
.19657 .62651 Mdot
.23842 .37114 Mdot
.6715 .42315 Mdot
.53235 .22233 Mdot
.20855 .52681 Mdot
.60491 .79472 Mdot
.42907 .63962 Mdot
.50832 .74563 Mdot
.35403 .46204 Mdot
.29569 .52238 Mdot
.8102 .33703 Mdot
.51347 .34782 Mdot
.44873 .70073 Mdot
.63529 .67976 Mdot
.36063 .54982 Mdot
.84786 .40242 Mdot
.34421 .7847 Mdot
.69584 .25483 Mdot
.70226 .53412 Mdot
.35442 .50304 Mdot
.44372 .52454 Mdot
.27923 .51907 Mdot
.68716 .64742 Mdot
.81386 .52124 Mdot
.20898 .53139 Mdot
.63971 .71935 Mdot
.41509 .64724 Mdot
.76897 .43748 Mdot
.5334 .8036 Mdot
.4057 .81496 Mdot
.57014 .48229 Mdot
.74938 .37476 Mdot
.29298 .32386 Mdot
.21649 .68346 Mdot
.48704 .4053 Mdot
.50912 .52947 Mdot
.74829 .54994 Mdot
.65863 .66147 Mdot
.49056 .21292 Mdot
.39503 .48738 Mdot
.63338 .25073 Mdot
.52186 .82023 Mdot
.27814 .25936 Mdot
.49909 .18619 Mdot
.85302 .41639 Mdot
.45594 .76499 Mdot
.6458 .65722 Mdot
.56051 .76728 Mdot
.24872 .27503 Mdot
.47556 .40301 Mdot
.72653 .71161 Mdot
.29605 .31335 Mdot
.62654 .78323 Mdot
.63607 .53867 Mdot
.63375 .58455 Mdot
.79757 .54053 Mdot
.78898 .66271 Mdot
.37461 .77304 Mdot
.56294 .7988 Mdot
.58434 .57246 Mdot
.83268 .6012 Mdot
.77576 .52165 Mdot
.51757 .49817 Mdot
.6017 .33449 Mdot
.69223 .27435 Mdot
.64844 .75 Mdot
.71722 .6831 Mdot
.2274 .55328 Mdot
.49336 .36241 Mdot
.3286 .43413 Mdot
.48205 .71229 Mdot
.31735 .3599 Mdot
.65877 .67465 Mdot
.24723 .44415 Mdot
.52586 .82927 Mdot
.47348 .38858 Mdot
.58297 .25119 Mdot
.76459 .43617 Mdot
.18141 .53266 Mdot
.69233 .64234 Mdot
.72942 .31848 Mdot
.44349 .81186 Mdot
.47686 .26195 Mdot
.22533 .50038 Mdot
.49044 .91417 Mdot
.20374 .57735 Mdot
.77147 .60746 Mdot
.81202 .60697 Mdot
.43317 .82337 Mdot
.76729 .62661 Mdot
.46378 .17988 Mdot
.27177 .5643 Mdot
.32339 .41828 Mdot
.3925 .53823 Mdot
.86105 .51857 Mdot
.30352 .38233 Mdot
.81942 .60128 Mdot
.39984 .83563 Mdot
.45347 .67311 Mdot
.32781 .51923 Mdot
.52151 .37234 Mdot
.60017 .29145 Mdot
.3277 .36361 Mdot
.52625 .76089 Mdot
.26914 .57404 Mdot
.73679 .38699 Mdot
.60137 .35184 Mdot
.46987 .35263 Mdot
.52685 .73642 Mdot
.72456 .34486 Mdot
.67481 .6628 Mdot
.3621 .3855 Mdot
.57008 .51962 Mdot
.25541 .47363 Mdot
.36816 .62649 Mdot
.49034 .74365 Mdot
.4334 .20062 Mdot
.53131 .44148 Mdot
.56586 .33446 Mdot
.48956 .76995 Mdot
.20693 .62349 Mdot
.65832 .69282 Mdot
.82585 .53847 Mdot
.68093 .26304 Mdot
.45782 .46608 Mdot
.2601 .49132 Mdot
.42768 .19278 Mdot
.20956 .37631 Mdot
.76114 .65237 Mdot
.42556 .62444 Mdot
.20616 .45764 Mdot
.53377 .5839 Mdot
.7313 .73403 Mdot
.21408 .56084 Mdot
.24177 .60547 Mdot
.54979 .30061 Mdot
.41478 .71087 Mdot
.4652 .67865 Mdot
.27847 .35417 Mdot
.57832 .53912 Mdot
.6422 .18055 Mdot
.50646 .69859 Mdot
.83862 .3571 Mdot
.69464 .51651 Mdot
.63514 .21403 Mdot
.28966 .3074 Mdot
.53151 .48281 Mdot
.58168 .55019 Mdot
.7032 .65475 Mdot
.70498 .58631 Mdot
.23063 .68824 Mdot
.34569 .2203 Mdot
.51323 .37398 Mdot
.19558 .502 Mdot
.17295 .49863 Mdot
.51498 .77367 Mdot
.34622 .56202 Mdot
.20066 .57729 Mdot
.50266 .37306 Mdot
.40731 .22824 Mdot
.40832 .82828 Mdot
.70055 .68501 Mdot
.31086 .51535 Mdot
.26558 .45128 Mdot
.71881 .71709 Mdot
.58544 .81463 Mdot
.53102 .17531 Mdot
.66862 .72337 Mdot
.65857 .54644 Mdot
.51087 .50397 Mdot
.58831 .78185 Mdot
.22349 .43981 Mdot
.62671 .607 Mdot
.23418 .50096 Mdot
.76319 .26106 Mdot
.81019 .53835 Mdot
.81344 .52128 Mdot
.22635 .46349 Mdot
.57663 .65691 Mdot
.77388 .53938 Mdot
.24517 .5301 Mdot
.70966 .67171 Mdot
.23292 .67515 Mdot
.23916 .50984 Mdot
.35687 .18672 Mdot
.26875 .66443 Mdot
.52914 .40742 Mdot
.46932 .67667 Mdot
.27759 .6664 Mdot
.6754 .54802 Mdot
.33898 .40289 Mdot
.6357 .69023 Mdot
.70505 .51527 Mdot
.66358 .67408 Mdot
.65015 .6356 Mdot
.24652 .62756 Mdot
.43779 .73933 Mdot
.64754 .71878 Mdot
.48597 .78916 Mdot
.59838 .69391 Mdot
.44874 .21944 Mdot
.60287 .37027 Mdot
.62648 .69869 Mdot
.58869 .3198 Mdot
.4705 .56979 Mdot
.58471 .49378 Mdot
.41027 .4217 Mdot
.81102 .36147 Mdot
.40595 .35064 Mdot
.57695 .68417 Mdot
.66016 .2151 Mdot
.52488 .70711 Mdot
.85831 .47902 Mdot
.40443 .21507 Mdot
.4373 .6579 Mdot
.44324 .26171 Mdot
.44294 .31476 Mdot
.49834 .13943 Mdot
.49722 .71167 Mdot
.56275 .29362 Mdot
.59486 .67288 Mdot
.56931 .65413 Mdot
.75301 .41604 Mdot
.59687 .3565 Mdot
.30667 .5901 Mdot
.74467 .52044 Mdot
.47428 .488 Mdot
.58721 .6834 Mdot
.56489 .434 Mdot
.29805 .45532 Mdot
.79897 .65389 Mdot
.57595 .33797 Mdot
.72148 .23912 Mdot
.35376 .46896 Mdot
.40834 .77468 Mdot
.46105 .85078 Mdot
.55813 .18034 Mdot
.62802 .31817 Mdot
.16166 .44821 Mdot
.35903 .4709 Mdot
.64961 .72341 Mdot
.52721 .66053 Mdot
.23606 .5953 Mdot
.38747 .33125 Mdot
.24942 .41356 Mdot
.70574 .49624 Mdot
.49414 .20491 Mdot
.71784 .34278 Mdot
.58194 .66625 Mdot
.69462 .70259 Mdot
.29255 .71338 Mdot
.64845 .59234 Mdot
.49808 .39869 Mdot
.51078 .76971 Mdot
.43092 .73484 Mdot
.58679 .68599 Mdot
.81567 .55854 Mdot
.22266 .58374 Mdot
.69898 .77414 Mdot
.34514 .4559 Mdot
.54645 .27856 Mdot
.73828 .54992 Mdot
.67714 .67533 Mdot
.34544 .61118 Mdot
.47672 .85153 Mdot
.28196 .41823 Mdot
.75318 .53107 Mdot
.27583 .46256 Mdot
.45494 .496 Mdot
.55913 .5111 Mdot
.66399 .31108 Mdot
.41754 .16585 Mdot
.29453 .55548 Mdot
.57376 .20081 Mdot
.43865 .61991 Mdot
.76894 .42702 Mdot
.54294 .73126 Mdot
.60611 .41169 Mdot
.42689 .71309 Mdot
.6342 .3108 Mdot
.71646 .75028 Mdot
.47315 .85069 Mdot
.68094 .55422 Mdot
.74802 .42439 Mdot
.61184 .68012 Mdot
.33832 .46738 Mdot
.60053 .57693 Mdot
.40323 .57305 Mdot
.52156 .72539 Mdot
.58282 .18194 Mdot
.70307 .66894 Mdot
.45805 .53853 Mdot
.7208 .73752 Mdot
.67134 .78527 Mdot
.82853 .60385 Mdot
.19131 .45766 Mdot
.51408 .64028 Mdot
.84162 .48647 Mdot
.32689 .61997 Mdot
.53667 .83221 Mdot
.75079 .66236 Mdot
.34258 .8234 Mdot
.51552 .75398 Mdot
.63117 .6647 Mdot
.35554 .22035 Mdot
.68356 .60285 Mdot
.3774 .81195 Mdot
.50248 .46538 Mdot
.67172 .37164 Mdot
.37835 .81661 Mdot
.4051 .14109 Mdot
.39336 .62044 Mdot
.64082 .63019 Mdot
.5218 .57206 Mdot
.62976 .6973 Mdot
.51713 .26287 Mdot
.43627 .5245 Mdot
.73728 .45626 Mdot
.55192 .22837 Mdot
.25031 .48291 Mdot
.32991 .43279 Mdot
.51438 .26431 Mdot
.33573 .3709 Mdot
.28686 .45615 Mdot
.21028 .55418 Mdot
.51001 .75939 Mdot
.31358 .59419 Mdot
.36346 .46392 Mdot
.53351 .72863 Mdot
.3557 .34451 Mdot
.62628 .36674 Mdot
.41673 .55909 Mdot
.63321 .32074 Mdot
.67241 .59425 Mdot
.85414 .4305 Mdot
.63611 .40133 Mdot
.31072 .7564 Mdot
.50564 .6925 Mdot
.69018 .6523 Mdot
.48556 .79926 Mdot
.6239 .22715 Mdot
.50339 .29254 Mdot
.26017 .52335 Mdot
.69253 .75164 Mdot
.77583 .3706 Mdot
.2542 .67472 Mdot
.8077 .40777 Mdot
.691 .53593 Mdot
.32049 .57078 Mdot
.51479 .55987 Mdot
.66512 .27255 Mdot
.54598 .6184 Mdot
.63399 .66626 Mdot
.52478 .31233 Mdot
.75543 .34062 Mdot
.31987 .77653 Mdot
.28335 .70707 Mdot
.48661 .70186 Mdot
.66291 .76076 Mdot
.56443 .37773 Mdot
.22578 .59501 Mdot
.61379 .6034 Mdot
.51371 .29345 Mdot
.7921 .45845 Mdot
.77374 .69482 Mdot
.59689 .57119 Mdot
.28821 .37481 Mdot
.3552 .53087 Mdot
.34455 .64784 Mdot
.70914 .65936 Mdot
.4199 .37885 Mdot
.71452 .36106 Mdot
.56733 .68196 Mdot
.69542 .34151 Mdot
.45899 .38183 Mdot
.32334 .4118 Mdot
.58968 .69177 Mdot
.25927 .57442 Mdot
.37736 .30743 Mdot
.73738 .51472 Mdot
.37876 .58698 Mdot
.27345 .38566 Mdot
.19478 .44528 Mdot
.33247 .58349 Mdot
.64397 .74633 Mdot
.50025 .76455 Mdot
.25285 .68501 Mdot
.67291 .6923 Mdot
.76855 .64271 Mdot
.70799 .58824 Mdot
.44344 .71743 Mdot
.63142 .27062 Mdot
.40067 .57866 Mdot
.60839 .4127 Mdot
.54513 .70735 Mdot
.55534 .77956 Mdot
.44585 .76302 Mdot
.28374 .35793 Mdot
.54456 .47062 Mdot
.47 .80015 Mdot
.53046 .45492 Mdot
.44275 .84091 Mdot
.68599 .6031 Mdot
.27884 .43068 Mdot
.62375 .51565 Mdot
.28811 .31307 Mdot
.44983 .18891 Mdot
.64642 .79031 Mdot
.40779 .2021 Mdot
.55208 .55049 Mdot
.57671 .1975 Mdot
.77535 .57633 Mdot
.39228 .82758 Mdot
.28635 .43363 Mdot
.59866 .56885 Mdot
.3381 .43281 Mdot
.6711 .55777 Mdot
.5554 .446 Mdot
.58832 .4144 Mdot
.30927 .60209 Mdot
.70636 .39917 Mdot
.62138 .28116 Mdot
.38969 .44814 Mdot
.78933 .48363 Mdot
.67905 .75643 Mdot
.24636 .59953 Mdot
.5015 .437 Mdot
.42242 .24057 Mdot
.31999 .40609 Mdot
.18026 .66488 Mdot
.84835 .39494 Mdot
.35454 .53254 Mdot
.48283 .42948 Mdot
.26841 .40518 Mdot
.51703 .36859 Mdot
.29052 .59234 Mdot
.5298 .77999 Mdot
.68342 .52699 Mdot
.59116 .42712 Mdot
.74665 .32663 Mdot
.71264 .64789 Mdot
.30982 .33699 Mdot
.77605 .47817 Mdot
.86023 .44378 Mdot
.20823 .64704 Mdot
.68745 .67397 Mdot
.22611 .72882 Mdot
.65385 .28968 Mdot
.52318 .60978 Mdot
.42699 .79772 Mdot
.80754 .6214 Mdot
.24466 .44025 Mdot
.4859 .22085 Mdot
.7875 .606 Mdot
.28517 .42253 Mdot
.23895 .53053 Mdot
.76455 .43378 Mdot
.70134 .34651 Mdot
.53534 .5068 Mdot
.44409 .3161 Mdot
.81419 .44467 Mdot
.43254 .64477 Mdot
.69534 .73985 Mdot
.55315 .22615 Mdot
.33153 .19856 Mdot
.68107 .78021 Mdot
.35425 .39761 Mdot
.5196 .25607 Mdot
.41513 .79475 Mdot
.22975 .39874 Mdot
.25444 .55954 Mdot
.44244 .20934 Mdot
.41054 .7349 Mdot
.42189 .28815 Mdot
.56883 .21313 Mdot
.26089 .47915 Mdot
.27544 .65937 Mdot
.59467 .56697 Mdot
.48635 .75551 Mdot
.74901 .39786 Mdot
.2319 .46694 Mdot
.55783 .42167 Mdot
.24676 .37631 Mdot
.49643 .77253 Mdot
.46569 .8089 Mdot
.61375 .62626 Mdot
.43133 .13644 Mdot
.76659 .65673 Mdot
.61674 .22577 Mdot
.41329 .57994 Mdot
.73997 .73378 Mdot
.61461 .61719 Mdot
.78411 .62341 Mdot
.28026 .73082 Mdot
.60158 .39658 Mdot
.71079 .57015 Mdot
.40361 .57721 Mdot
.69709 .71693 Mdot
.45223 .70138 Mdot
.28537 .67792 Mdot
.51004 .21347 Mdot
.25211 .441 Mdot
.53485 .24643 Mdot
.26812 .35508 Mdot
.31484 .54832 Mdot
.55572 .709 Mdot
.85164 .5077 Mdot
.55467 .56102 Mdot
.46729 .56993 Mdot
.31166 .49028 Mdot
.3691 .20948 Mdot
.17098 .57458 Mdot
.33708 .46493 Mdot
.78448 .39199 Mdot
.23151 .53244 Mdot
.45142 .46708 Mdot
.43302 .62995 Mdot
.09284 .4586 Mdot
.49311 .87115 Mdot
.53297 .62658 Mdot
.27057 .59823 Mdot
.21134 .48445 Mdot
.80403 .63183 Mdot
.45991 .31393 Mdot
.61578 .35397 Mdot
.2867 .26905 Mdot
.22013 .41437 Mdot
.34455 .48575 Mdot
.30148 .7601 Mdot
.63167 .79626 Mdot
.52439 .21257 Mdot
.71104 .74717 Mdot
.45458 .59585 Mdot
.44239 .50672 Mdot
.1109 .54079 Mdot
.59156 .78603 Mdot
.43617 .58616 Mdot
.37293 .20416 Mdot
.52889 .61316 Mdot
.39551 .5522 Mdot
.76864 .46574 Mdot
.21724 .54483 Mdot
.2617 .48287 Mdot
.79015 .66103 Mdot
.56592 .63338 Mdot
.63144 .31128 Mdot
.67706 .53295 Mdot
.57986 .54609 Mdot
.39067 .46408 Mdot
.65513 .49684 Mdot
.4365 .44989 Mdot
.62605 .67862 Mdot
.66986 .55108 Mdot
.19212 .52054 Mdot
.39487 .85361 Mdot
.46276 .75699 Mdot
.71932 .52176 Mdot
.37242 .43797 Mdot
.27219 .66909 Mdot
.33045 .36677 Mdot
.48816 .50835 Mdot
.36895 .81753 Mdot
.61122 .86703 Mdot
.67803 .37613 Mdot
.30258 .47606 Mdot
.5901 .68931 Mdot
.32354 .60192 Mdot
.48207 .72554 Mdot
.67391 .46387 Mdot
.58168 .36679 Mdot
.32401 .51388 Mdot
.31624 .55032 Mdot
.70541 .49935 Mdot
.82298 .34196 Mdot
.41943 .50499 Mdot
.41226 .63209 Mdot
.54396 .82707 Mdot
.45226 .21841 Mdot
.38545 .76598 Mdot
.39095 .47656 Mdot
.76853 .54034 Mdot
.60195 .56994 Mdot
.60633 .74017 Mdot
.58538 .25251 Mdot
.75719 .69075 Mdot
.44126 .76258 Mdot
.47513 .68149 Mdot
.41461 .51131 Mdot
.35181 .34672 Mdot
.64483 .62048 Mdot
.79626 .59809 Mdot
.42652 .61679 Mdot
.56326 .82834 Mdot
.59706 .3966 Mdot
.72161 .40857 Mdot
.46749 .49595 Mdot
.83565 .56361 Mdot
.54198 .19637 Mdot
.46326 .69518 Mdot
.67188 .23895 Mdot
.70467 .29931 Mdot
.31661 .36243 Mdot
.52229 .37867 Mdot
.45548 .51612 Mdot
.57135 .63867 Mdot
.86819 .45712 Mdot
.79871 .58914 Mdot
.65545 .44686 Mdot
.69409 .36277 Mdot
.39641 .66577 Mdot
.5987 .59033 Mdot
.30511 .80431 Mdot
.47473 .3247 Mdot
.85931 .43407 Mdot
.23732 .60273 Mdot
.5345 .74346 Mdot
.64539 .66786 Mdot
.36845 .60343 Mdot
.56314 .34088 Mdot
.79009 .64985 Mdot
.32245 .56058 Mdot
.6085 .23922 Mdot
.36666 .47768 Mdot
.71408 .26908 Mdot
.59652 .45246 Mdot
.75263 .4406 Mdot
.74915 .47091 Mdot
.46564 .181 Mdot
.50679 .81281 Mdot
.60582 .48635 Mdot
.2553 .75066 Mdot
.56876 .77093 Mdot
.62928 .78706 Mdot
.50657 .23855 Mdot
.51633 .16395 Mdot
.72453 .67888 Mdot
.65098 .71153 Mdot
.63099 .44872 Mdot
.46101 .4379 Mdot
.68055 .26927 Mdot
.43787 .45398 Mdot
.66257 .61871 Mdot
.65537 .55697 Mdot
.71537 .82464 Mdot
.36926 .41006 Mdot
.52211 .59519 Mdot
.63758 .26365 Mdot
.66245 .77228 Mdot
.40592 .40698 Mdot
.33188 .79293 Mdot
.47845 .41025 Mdot
.43802 .49686 Mdot
.43258 .74735 Mdot
.24331 .59181 Mdot
.70238 .27827 Mdot
.54916 .13862 Mdot
.2128 .65106 Mdot
.70647 .38699 Mdot
.57193 .50916 Mdot
.51313 .68956 Mdot
.48642 .64911 Mdot
.44159 .2794 Mdot
.28042 .75544 Mdot
.62936 .66811 Mdot
.58867 .78243 Mdot
.48191 .14237 Mdot
.24442 .64447 Mdot
.8057 .63319 Mdot
.75427 .63359 Mdot
.51495 .71321 Mdot
.34871 .38428 Mdot
.35603 .29193 Mdot
.7364 .46052 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo08Sooooo0_l0002oooooo`007?ooool0
0ol0003oooooooooo`20ooooo`;o00001_ooool2o`0001Cooooo0_l0000?ooooo`;o0000V?ooool0
01cooooo00?o0000ooooooooool0P?ooool2o`0001Oooooo1?l000000ooooooo0000o`00000?oooo
o`;o0000V?ooool001cooooo00?o0000ooooooooool0R_ooool2o`0000gooooo1?l00008ooooo`;o
0000X_ooool001cooooo00?o0000ooooooooool0R_ooool2o`0001Wooooo0_l0000=ooooo`;o0000
Toooool001cooooo0_l0001cooooo`;o0000@?ooool2o`0009?ooooo000Looooo`03o`000?oooooo
oooo07;ooooo0_l0003Eooooo`007?ooool00ol0003oooooooooo`24ooooo`;o0000`oooool001co
oooo00?o0000ooooooooool0Ooooool2o`0000?ooooo0_l00033ooooo`007?ooool00ol0003ooooo
ooooo`1jooooo`;o00000oooool2o`0000?ooooo0_l0000Nooooo`;o00007Oooool2o`0008Cooooo
000Looooo`03o`000?oooooooooo07[ooooo0_l00008ooooo`;o00004?ooool2o`0000cooooo0_l0
000Mooooo`;o00003oooool2o`0007?ooooo000Looooo`03o`000?oooooooooo07cooooo0_l0000F
ooooo`Co00002?ooool3o`0002Gooooo0_l0000:ooooo`;o0000Loooool001cooooo00?o0000oooo
ooooool0O?ooool2o`0000Gooooo0_l0000?ooooo`;o00002_ooool3o`0000Kooooo0_l0000Moooo
o`;o0000Ooooool001cooooo00?o0000ooooooooool0Poooool2o`0000?ooooo0_l0000Oooooo`;o
00000_ooool2o`0009[ooooo000Looooo`03o`000?oooooooooo08Gooooo0_l000000ooooooo0000
o`000009ooooo`?o00005oooool2o`0000?ooooo0_l0000Iooooo`;o0000N_ooool001cooooo00?o
0000ooooooooool0QOooool2o`0000[ooooo1Ol00009ooooo`;o000000?oooooo`000?l000000_l0
000<ooooo`;o00001_ooool2o`00017ooooo0_l0001jooooo`007?ooool00ol0003oooooooooo`1`
ooooo`;o00003_ooool2o`0000cooooo0_l000001?oooooo0000o`000?ooool2o`0000Sooooo0ol0
00000ooooooo0000o`000002o`0000?ooooo0_l0000>ooooo`?o00004Oooool2o`0007[ooooo000L
ooooo`03o`000?oooooooooo073ooooo0_l00006ooooo`;o00001_ooool2o`0000cooooo0_l0000=
ooooo`Co00000oooool4o`000004ooooool0003o0000ooooo`Co00000_ooool2o`0000Gooooo0_l0
0002ooooo`;o00003_ooool2o`0007[ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo
0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`1Wooooo`;o00003?ooool2o`000003oooo
ool0003o000000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Wooooo0_l00002ooooo`;o0000
1Oooool4o`0000Cooooo1?l00002ooooo`;o00002Oooool2o`0008[ooooo00001_ooooooMgMgoiRH
V?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0
003oooooooooo`1Wooooo`;o00001oooool2o`0000?ooooo0_l00009ooooo`;o00001?ooool4o`00
00oooooo0_l0000Aooooo`;o00001?ooool2o`0000cooooo0_l00027ooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000oooooooo
ool0J?ooool2o`0000Kooooo0_l00004ooooo`;o00001Oooool2o`0000Oooooo1?l0000Rooooo`;o
000000Coooooo`000?l0003ooooo0_l00004ooooo`;o00001_ooool2o`0008Oooooo00000ooooooo
0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0006So
oooo0_l0000<ooooo`;o00001Oooool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l0
00000oooool2o`0001oooooo0_l00006ooooo`?o00001oooool2o`0000;ooooo0_l00022ooooo`00
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00Gooooo
00?o0000ooooooooool0MOooool2o`0000Wooooo0ol00003ooooo`;o000000?oooooo`000?l00000
0oooool2o`0000Kooooo0_l00004ooooo`?o00006?ooool2o`0000Gooooo0_l000000ooooooo0000
o`000002ooooo`;o0000P_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool03Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07Gooooo0_l00004ooooo`;o00000ooo
ool2o`0000kooooo0_l00004ooooo`;o00001?ooool3o`0001Kooooo0_l00007ooooo`;o00001?oo
ool2o`0008?ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo
V9RHoa0@4006ooooo`03o`000?oooooooooo07Cooooo0_l00005ooooo`;o00003oooool2o`0000;o
oooo1?l00003ooooo`;o00007?ooool2o`0000gooooo0ol00022ooooo`0000Koooooonk^k_lb<S;o
0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1d
ooooo`;o00002_ooool2o`0000Oooooo0_l000000ooooooo0000o`000004ooooo`;o00000oooool2
o`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l000000_l0000<ooooo`;o00003_ooool2
o`0000Cooooo0_l00006ooooo`;o0000M?ooool001cooooo00?o0000ooooooooool0L_ooool2o`00
0003ooooool0003o000000Wooooo0_l00002ooooo`;o00000oooool2o`0000Cooooo0_l00002oooo
o`;o00001oooool2o`0000Cooooo0_l000000ooooooo0000o`000002o`0000[ooooo1?l0000;oooo
o`;o00000_ooool2o`0000?ooooo0_l00006ooooo`;o0000M?ooool001cooooo00?o0000oooooooo
ool0KOooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000003Oooool2o`0000Oo
oooo1?l00002ooooo`;o00001Oooool4o`0001Gooooo0_l0000=ooooo`;o00000_ooool4o`0007oo
oooo000Looooo`03o`000?oooooooooo06gooooo0_l000000ooooooo0000o`000009ooooo`;o0000
4?ooool3o`0000[ooooo1?l00009ooooo`Co00004Oooool2o`000003ooooool0003o000000Gooooo
1?l0000<ooooo`;o0000LOooool001cooooo00?o0000ooooooooool0Noooool2o`0001;ooooo0_l0
000Aooooo`;o00000oooool4o`0000Gooooo0_l00008ooooo`Co000000?oooooo`000?l000001?oo
ool4o`0000gooooo0_l0001aooooo`007?ooool00ol0003oooooooooo`1]ooooo`;o00003?ooool2
o`0000Cooooo0_l00003ooooo`;o00001oooool2o`00017ooooo1?l0000:ooooo`;o00002?ooool2
o`0000?ooooo0_l00004ooooo`Co000000Coooooo`000?l0003o00004?ooool2o`0006[ooooo000L
ooooo`03o`000?oooooooooo06gooooo0_l0000<ooooo`;o00000_ooool5o`0000;ooooo0_l0000;
ooooo`?o00002oooool2o`000003ooooool0003o000000;o00002?ooool5o`0000[ooooo0_l00008
ooooo`Co00000_ooool4o`0000[ooooo0_l0001Zooooo`007?ooool00ol0003oooooooooo`1Soooo
o`;o00006_ooool2o`000003ooooool0003o000000_ooooo0ol000001?oooooo0000o`000?l0000;
ooooo`;o00000_ooool3o`0000Gooooo0_l00002ooooo`Co00003Oooool2o`0000Gooooo1?l00002
ooooo`Co0000M_ooool001cooooo00?o0000ooooooooool0Hoooool2o`0002[ooooo0ol0000>oooo
o`?o000000Goooooo`000?l0003o0000ooooo`02o`0000?ooooo0_l0000Cooooo`;o00001?ooool2
o`000003ooooool0003o000000Wooooo0_l0000?ooooo`;o0000H?ooool001cooooo00?o0000oooo
ooooool0I?ooool2o`0001;ooooo0_l00003ooooo`;o00001_ooool2o`0001Kooooo1_l000001Ooo
oooo0000o`000?l0003ooooo00So00001oooool2o`0000Wooooo0ol00003ooooo`;o00003?ooool2
o`0000oooooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`1Tooooo`;o00003oooool2o`00
0003ooooool0003o000000?ooooo0_l00006ooooo`;o00003_ooool2o`0000Kooooo0ol00009oooo
o`Oo00001?ooool2o`000003ooooool0003o000000[ooooo0_l00002ooooo`;o00000_ooool2o`00
07cooooo000Looooo`03o`000?oooooooooo07Gooooo0_l0000;ooooo`;o00004Oooool2o`0001;o
oooo1ol000000ooooooo0000o`000003o`0000Wooooo0_l000000ooooooo0000o`000003ooooo`;o
00000_ooool2o`0000gooooo1?l0001[ooooo`007?ooool2o`0005_ooooo0_l0000;ooooo`;o0000
6Oooool3o`0000Gooooo0_l0000>ooooo`;o00002oooool5o`0000Gooooo1Ol00004ooooo`;o0000
0oooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o00000oooool2o`0000Oooooo
1_l000000ooooooo0000o`00001Xooooo`007?ooool00ol0003oooooooooo`1Jooooo`Co00002Ooo
ool2o`0001Gooooo0_l00003ooooo`;o00001Oooool2o`0000gooooo0ol0000;ooooo`;o00002ooo
ool3o`0000?ooooo0_l0000:ooooo`?o000000?oooooo`000?l000000_ooool3o`0000?ooooo1_l0
0004ooooo`Co00003Oooool2o`0005Sooooo000Looooo`03o`000?oooooooooo05_ooooo0ol0000E
ooooo`;o00000_ooool2o`0000Gooooo0_l00003ooooo`;o00001Oooool2o`0000gooooo0ol00003
ooooo`;o00001?ooool2o`0000kooooo1?l000000ooooooo0000o`000002o`0000Wooooo1Ol00002
ooooo`;o000000Coooooo`000?l0003ooooo1?l00006ooooo`Co00001Oooool2o`0000Kooooo0_l0
001Hooooo`007?ooool00ol0003oooooooooo`1Gooooo`;o00000_ooool2o`0001Kooooo0_l00002
ooooo`;o00009?ooool4o`0000Cooooo0_l0000@ooooo`;o00000oooool2o`0000Wooooo1Ol00004
ooooo`?o00005?ooool2o`0000_ooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`1Goooo
o`;o00006_ooool2o`0001Oooooo0_l00009ooooo`;o00001?ooool4o`0000;ooooo0ol0000Boooo
o`;o000000?oooooo`000?l000002_ooool2o`0000;ooooo0_l00003ooooo`?o00001_ooool6o`00
01Gooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`29ooooo`;o000000?oooooo`000?l0
00002Oooool2o`0000Gooooo0_l00003ooooo`?o00004_ooool7o`000003ooooool0003o000000Wo
oooo0_l00004ooooo`;o00001_ooool6o`0006[ooooo000Looooo`03o`000?oooooooooo05Wooooo
0_l0000^ooooo`;o00002oooool2o`0000Kooooo0_l00007ooooo`;o00002oooool2o`000003oooo
ool0003o000000Ko000000?oooooo`000?l000001oooool2o`0000Kooooo0_l00002ooooo`?o0000
00?oooooo`000?l000001_ooool2o`000003ooooool0003o000000Oooooo0_l0001Jooooo`007?oo
ool00ol0003oooooooooo`1Iooooo`;o0000>oooool2o`0000?ooooo0_l0000:ooooo`;o00002ooo
ool2o`000004ooooool0003o0000o`0000;ooooo0_l0000;ooooo`;o00001_ooool2o`000003oooo
ool0003o000000;o000000?oooooo`000?l000001_ooool2o`000003ooooool0003o000000Oooooo
0_l0001Jooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o0000:oooool2o`0001oooooo0_l0
0004ooooo`;o00002?ooool2o`0000Wooooo0ol00002ooooo`?o00005_ooool2o`0000Oooooo0_l0
0003ooooo`?o0000I?ooool001cooooo00?o0000ooooooooool0@Oooool2o`0000[ooooo0_l00007
ooooo`Co00008?ooool2o`00013ooooo0_l00007ooooo`;o00002_ooool2o`0000Sooooo0_l00000
0ooooooo0000o`000006ooooo`;o00000oooool2o`00023ooooo0_l000000ooooooo0000o`000005
o`0006;ooooo000Looooo`03o`000?oooooooooo047ooooo0_l0000Cooooo`Co0000<_ooool2o`00
00Oooooo0_l0000?ooooo`;o00001_ooool2o`0001Kooooo0_l00003ooooo`;o00001oooool2o`00
00[ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00005ooooo`;o0000D_ooool001co
oooo00?o0000ooooooooool0D?ooool4o`0003gooooo0_l0000Cooooo`;o00004?ooool2o`0000Ko
oooo0_l00003ooooo`?o00000oooool2o`0000Oooooo1?l0000?ooooo`Co00000oooool2o`0000Go
oooo0_l0001Booooo`007?ooool00ol0003oooooooooo`1@ooooo`Co00006Oooool3o`000003oooo
ool0003o000000;ooooo0_l0000>ooooo`;o00001_ooool2o`0000;ooooo0_l0000Nooooo`;o0000
0_ooool2o`000003ooooool0003o000000Kooooo0_l00003ooooo`;o00001?ooool2o`0000Wooooo
0_l0000?ooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0C_ooool2o`0001gooooo1_l0
00000ooooooo0000o`000002o`0000gooooo0_l00006ooooo`;o00008?ooool8o`0000Sooooo0_l0
00000ooooooo0000o`000007ooooo`;o00001?ooool2o`0001Cooooo0_l0001Pooooo`007?ooool0
0ol0003oooooooooo`0oooooo`;o00003?ooool3o`0000[ooooo0_l0000Dooooo`;o00000_ooool4
o`0002Sooooo0_l000000ooooooo0000o`00000:ooooo`;o00000_ooool2o`0000[ooooo0_l00000
0ooooooo0000o`000007ooooo`;o00001?ooool2o`0001Cooooo0_l00003ooooo`;o000000?ooooo
o`000?l00000F?ooool001cooooo00?o0000ooooooooool0?oooool2o`0000cooooo0ol0000:oooo
o`;o00003?ooool2o`0000;ooooo0_l00007ooooo`;o0000:Oooool2o`000003ooooool0003o0000
00kooooo0_l0000>ooooo`;o00009oooool2o`000003ooooool0003o000001Oooooo0_l0000ooooo
o`007?ooool2o`0004oooooo0_l0000Hooooo`;o00000_ooool2o`00037ooooo0_l0000>ooooo`;o
00002Oooool2o`0000Oooooo0_l00007ooooo`;o00004oooool2o`0000Wooooo0_l0000Jooooo`;o
0000?oooool001cooooo00?o0000ooooooooool0Goooool2o`00013ooooo0_l00004ooooo`Co0000
9?ooool2o`0000kooooo0_l00009ooooo`;o00002?ooool2o`0000;ooooo0_l00002ooooo`;o0000
00?oooooo`000?l000004?ooool2o`0000Wooooo1Ol0001Hooooo`007?ooool00ol0003ooooooooo
o`1Jooooo`;o00000oooool2o`00013ooooo1Ol000000ooooooo0000o`000002o`000003ooooool0
003o000002;ooooo0_l0000?ooooo`;o00001oooool3o`0000Kooooo0ol00002ooooo`;o000000?o
ooooo`000?l000000_ooool3o`0000_ooooo0_l0000?ooooo`?o0000F?ooool001cooooo00?o0000
ooooooooool0@_ooool2o`0000_ooooo0_l00009ooooo`;o00005_ooool7o`0000?ooooo1?l0000@
ooooo`;o00003_ooool2o`0000Oooooo0_l00006ooooo`;o00000oooool8o`0000;ooooo0_l00000
0ooooooo0000o`000002ooooo`Ko00000oooool2o`0000Oooooo0_l00002ooooo`;o00003_ooool4
o`0005Sooooo000Looooo`03o`000?oooooooooo04;ooooo0_l0000;ooooo`;o00001_ooool2o`00
0003ooooool0003o000000;o00005oooool6o`0000?ooooo0_l0000@ooooo`Co00004oooool4o`00
00Wooooo3_l00005ooooo`Go00002?ooool2o`0000?ooooo0_l00002ooooo`;o00003_ooool6o`00
05Kooooo000Looooo`03o`000?oooooooooo04?ooooo0_l0000Booooo`;o000000?oooooo`000?l0
00000_l0000Fooooo`_o000000?oooooo`000?l000001_ooool3o`000004ooooool0003o0000o`00
00;ooooo0ol0000Cooooo`;o00002oooool>o`0000Oooooo0_l000000ooooooo0000o`000006oooo
o`;o00002?ooool2o`0000kooooo0_l000000ooooooo0000o`000002o`0005Cooooo000Looooo`03
o`000?oooooooooo04?ooooo0_l0000@ooooo`;o00000oooool2o`0000Sooooo0_l00004ooooo`?o
00001oooool;o`000003ooooool0003o000000Kooooo0ol000001?oooooo0000o`000?l00002oooo
o`;o00001?ooool2o`0001Sooooo0ol000000ooooooo0000o`00000<o`0000Gooooo0ol000000ooo
oooo0000o`00000@ooooo`;o00002Oooool2o`0000Sooooo0_l0001Dooooo`007?ooool00ol0003o
ooooooooo`1Eooooo`;o00003Oooool4o`0000;ooooo0ol00003ooooo`co000000?oooooo`000?l0
00000_l0000Fooooo`;o00006?ooool8o`000003ooooool0003o000000Oo00000oooool9o`0001[o
oooo0_l00008ooooo`;o000000?oooooo`000?l00000DOooool001cooooo00?o0000ooooooooool0
@?ooool2o`0000kooooo0_l00009ooooo`;o00001oooool4o`000004ooooool0003o0000o`0000Co
oooo3_l000000ooooooo0000o`00000Eooooo`;o00005OoooolFo`0000?ooooo1_l000000ooooooo
0000o`000003ooooo`;o00002_ooool2o`0000kooooo0ol00002ooooo`;o000000?oooooo`000?l0
0000DOooool001cooooo00?o0000ooooooooool0@?ooool2o`0000Wooooo0_l00003ooooo`;o0000
1_ooool2o`000003ooooool0003o000000Co00000oooool2o`0000?ooooo0ol00003ooooo`oo0000
00Coooooo`000?l0003o00005?ooool2o`0001Cooooo5ol00005ooooo`;o00002?ooool3o`0000Wo
oooo0_l0000;ooooo`Ko0000F?ooool001cooooo00?o0000ooooooooool0Boooool2o`0000_ooooo
0_l000000ooooooo0000o`000004o`0000_ooooo0_l000000ooooooo0000o`00000Bo`0002Kooooo
0_l000000ooooooo0000o`00000Bo`000003ooooool0003o0000013ooooo1Ol00006ooooo`;o0000
2oooool6o`0005Sooooo000Looooo`03o`000?oooooooooo04Cooooo0_l0000>ooooo`?o000000Co
ooooo`000?l0003ooooo0_l000000ooooooo0000o`00000<ooooo`;o00000_oooolCo`000003oooo
ool0003o000000Kooooo0_l0000Booooo`;o00000oooool2o`0000;ooooo6_l0000@ooooo`Go0000
5?ooool4o`0001Gooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00003_oo
ool9o`000004ooooool0003o0000ooooo`;o00001Oooool2o`0000Oooooo5Ol00006ooooo`;o0000
4_ooool2o`0000?ooooo0ol00002ooooo`Oo000000?oooooo`000?l000003ol000000ooooooo0000
o`00000=ooooo`?o00004oooool2o`0001Sooooo1?l00012ooooo`007?ooool00ol0003ooooooooo
o`1Eooooo`Co000000?oooooo`000?l000001Oooool2o`0000Gooooo0_l00005oooooaKo00004Ooo
ool2o`0000kooooo0_l000000ooooooo0000o`00000Bo`000003ooooool0003o000000?o000000?o
ooooo`000?l000003_ooool2o`0000Sooooo0_l00009ooooo`;o00001oooool2o`000003ooooool0
003o000000cooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`1Booooo`;o00000oooool2
o`0000Sooooo0ol0000;oooooaGo000000?oooooo`000?l000003_ooool3o`00017ooooo7Ol0000H
ooooo`;o00001Oooool2o`0000Sooooo0_l000000ooooooo0000o`000003o`0000;ooooo0_l0000=
ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0C_ooool2o`0000;ooooo0_l00006oooo
o`;o00001Oooool3o`0000_ooooo6?l0000>ooooo`;o00003?ooool2o`0000Cooooo0_l00002oooo
oaGo000000Coooooo`000?l0003o00000oooool2o`000003ooooool0003o000000;ooooo0_l0000>
ooooo`;o00000oooool2o`000003ooooool0003o000000Gooooo0_l00003ooooo`;o00000oooool2
o`0000gooooo0_l0000oooooo`007?ooool2o`0004oooooo0_l0000:ooooo`;o00004ooooolHo`00
00gooooo0_l0000=ooooo`;o00000_oooolJo`000004ooooool0003o0000o`0000Cooooo0_l00000
0ooooooo0000o`000002ooooo`;o00001_ooool2o`0000Kooooo0_l000000ooooooo0000o`000003
ooooo`;o00003?ooool2o`00057ooooo000Looooo`03o`000?oooooooooo05gooooo0_l00005oooo
o`Co00000oooool2o`0000;ooooo5Ol000000ooooooo0000o`00000=ooooo`?o00002oooool3o`00
0003ooooool0003o000001ko00002oooool2o`0000Gooooo0_l00009ooooo`;o00004Oooool2o`00
00;ooooo0_l00007ooooo`?o0000@oooool001cooooo00?o0000ooooooooool0Aoooool2o`0000[o
oooo0_l00002ooooo`;o00001?ooool2o`0000Gooooo1_l000000ooooooo0000o`000002oooooaKo
00004?ooool2o`000003ooooool0003o000000Sooooo8Ol000000ooooooo0000o`000006ooooo`;o
00000oooool2o`0000[ooooo0_l0000Kooooo`;o00001oooool3o`0000Oooooo0_l0000jooooo`00
7?ooool00ol0003oooooooooo`17ooooo`;o00002_ooool2o`0000;ooooo0ol00009ooooo`;o0000
0oooool2o`0000Kooooo5Ol0000Cooooo`;o00002OoooolPo`0000Oooooo1?l0000?ooooo`;o0000
00?oooooo`000?l000008oooool2o`0000Kooooo0_l0000jooooo`007?ooool00ol0003ooooooooo
o`0cooooo`;o00003?ooool2o`0000Gooooo0_l0000>ooooo`;o00001Oooool2o`0000;ooooo1?l0
0004ooooo`;o00001?ooool@o`0000;ooooo0ol0000?ooooo`;o00001_ooool2o`0000Cooooo5Ol0
00000ooooooo0000o`000008o`0000Oooooo1?l0000:ooooo`;o00000oooool5o`0000;ooooo0_l0
0005ooooo`;o00001?ooool2o`00017ooooo0ol00012ooooo`007?ooool00ol0003oooooooooo`0c
ooooo`;o00000_ooool2o`0000Sooooo0_l00002ooooo`;o000000?oooooo`000?l000005Oooool2
o`0000;ooooo1_l00002ooooo`;o00000ooooolFo`0000oooooo0ol00005ooooo`;o00001Oooool3
o`000003ooooool0003o000001Oo00005oooool2o`0000;ooooo1?l00004ooooo`;o00001Oooool2
o`0000Cooooo0_l0000Aooooo`;o0000@oooool001cooooo00?o0000ooooooooool0=oooool2o`00
00cooooo0_l00003ooooo`Co000000?oooooo`000?l000002?ooool2o`0000Wooooo1_l00005oooo
oaKo00004Oooool2o`0000cooooo0ol000000ooooooo0000o`000008o`000003ooooool0003o0000
00_o00002?ooool2o`000003ooooool0003o000000oooooo0_l00008ooooo`;o00004?ooool2o`00
04oooooo000Looooo`03o`000?oooooooooo03Sooooo0_l0000@ooooo`Co000000?oooooo`000?l0
00002?ooool2o`0000gooooo0ol00002oooooa?o00000oooool2o`0001oooooo6_l00002ooooo`;o
00001_ooool2o`000003ooooool0003o000000Go00001?ooool2o`0000Cooooo0_l00008ooooo`Co
00000oooool2o`0000Gooooo0_l00002ooooo`;o00003Oooool2o`00043ooooo000Looooo`03o`00
0?oooooooooo02Wooooo0_l00005ooooo`;o00001_ooool2o`0000[ooooo0_l00004ooooo`;o0000
3_ooool2o`0000gooooo0_l00002ooooo`?o00000oooool=o`0001Cooooo0_l00007ooooo`;o0000
00?oooooo`000?l000002ol000000ooooooo0000o`00000=o`0000?ooooo0_l0000:ooooo`Ko0000
1?ooool4o`0000Sooooo0_l00003ooooo`?o00000oooool2o`000003ooooool0003o000000;ooooo
0_l00002ooooo`Co00002oooool2o`00043ooooo000Looooo`03o`000?oooooooooo02Wooooo0_l0
0005ooooo`;o00003_ooool2o`0000;ooooo0_l00004ooooo`Co00003?ooool2o`0001;ooooo0_l0
0003ooooo`co00005Oooool2o`0000Oooooo0_l000000ooooooo0000o`00000Fo`000003ooooool0
003o000001;ooooo0ol00008ooooo`;o00002?ooool2o`0000Cooooo1?l00004ooooo`;o00001?oo
ool2o`0000;ooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00003_ooool3
o`0000Oooooo1Ol0000<ooooo`;o00005_ooool=o`0000Gooooo0_l0000=ooooo`;o00003?oooolF
o`0000Sooooo0_l0000<ooooo`;o00002?ooool2o`0000Kooooo0_l00008ooooo`;o00002_ooool3
o`00053ooooo000Looooo`03o`000?oooooooooo033ooooo0_l000000ooooooo0000o`00000<oooo
o`;o00001?ooool2o`0000Cooooo0_l0000<ooooo`;o00000_ooool2o`0000gooooo0_l00005oooo
o`?o000000?oooooo`000?l000001Ol00005ooooo`;o00002Oooool3o`000003ooooool0003o0000
00cooooo5Ol00009ooooo`;o00003?ooool2o`0000_ooooo0_l00003ooooo`;o00002Oooool2o`00
00[ooooo0_l00002ooooo`;o00002oooool2o`0003oooooo000Looooo`03o`000?oooooooooo02co
oooo0_l00005ooooo`;o00004_ooool4o`0000Cooooo0_l00004ooooo`;o00001_ooool4o`0000go
oooo0_l00002ooooo`;o00000_ooool5o`000003ooooool0003o000000;ooooo0_l0000>ooooo`?o
00003oooool3o`0000;ooooo4?l0000<ooooo`;o00002Oooool2o`0000_ooooo0_l00005ooooo`;o
00001oooool3o`0000Cooooo0_l00003ooooo`;o00000_ooool2o`0000_ooooo0_l0000oooooo`00
7?ooool00ol0003oooooooooo`0/ooooo`;o00002oooool2o`0000Cooooo0_l00008ooooo`;o0000
1?ooool2o`0000Cooooo0_l00006ooooo`;o00004oooool2o`0000Cooooo0ol000001?oooooo0000
o`000?ooool3o`0001Cooooo0_l00009oooooa;o000000?oooooo`000?l000001_ooool2o`0000Go
oooo1?l0000Hooooo`;o000000?oooooo`000?l000002?ooool2o`0000Cooooo0ol00002ooooo`;o
00001Oooool2o`0004Wooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0iooooo`Co00000_ooool2o`00
00[ooooo0_l00005ooooo`;o000000?oooooo`000?l000001?ooool3o`000004ooooool0003o0000
o`0001[ooooo0_l000000ooooooo0000o`000006ooooo`?o00003?ooool2o`0000Kooooo5?l00002
ooooo`;o00001_ooool2o`0000Oooooo0_l0000Hooooo`;o00002_ooool2o`0000;ooooo0_l00002
ooooo`;o00001_ooool2o`000003ooooool0003o0000013ooooo0ol0000fooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo03_ooooo0_l00009ooooo`;o00000oooool4o`0000?ooooo0_l000000ooooooo0000o`00
0004ooooo`?o000000Coooooo`000?l0003o00004Oooool2o`0000[ooooo0_l00006ooooo`?o0000
5?ooool7o`0000Cooooo2_l0000;ooooo`Co00008Oooool2o`0000Kooooo0_l00002ooooo`;o0000
2?ooool5o`0001;ooooo0ol0000fooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`09ooooo`Go00001_ooool00ol0003oooooooooo`13ooooo`;o000000Coooooo`000?l0003o0000
1?ooool2o`00013ooooo0_l00003ooooo`;o00002Oooool2o`0000;ooooo0_l0000Yooooo`;o0000
00?oooooo`000?l000001_ooool5o`0000;ooooo0ol00002ooooo`;o00001oooool4o`0000?ooooo
0_l0000Kooooo`?o00000_ooool2o`0000Cooooo1?l00007ooooo`?o000000?oooooo`000?l00000
4_ooool2o`0003Oooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Co
A4A4omgMgOoooooo00001oooool3o`0003_ooooo0_l00006ooooo`;o000000Coooooo`000?l0003o
00004_ooool6o`0000;ooooo0ol00004ooooo`;o00000oooool2o`0001kooooo0_l00006ooooo`;o
00001Oooool2o`000003ooooool0003o000000;o00001_ooool8o`0000;ooooo0_l0000>ooooo`;o
00001?ooool2o`0001Gooooo0_l00003ooooo`;o00001?ooool4o`0000Oooooo0_l00009ooooo`;o
00001?ooool2o`0000Gooooo0_l0000gooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooo
ooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0>oooool2o`000003
ooooool0003o000000?ooooo0_l00002ooooo`;o00001_ooool2o`0000;ooooo0_l00006ooooo`Co
00001?ooool3o`0000Cooooo0_l00003ooooo`;o00001oooool2o`0001Gooooo0_l00004ooooo`Co
000000?oooooo`000?l000001Oooool4o`0000Sooooo0ol00005ooooo`;o00005?ooool2o`0001co
oooo0ol0000Dooooo`;o000000?oooooo`000?l000001?ooool2o`0000Gooooo0_l0000gooooo`00
00?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo
00?o0000ooooooooool0?_ooool2o`0000?ooooo0_l00005ooooo`;o00000oooool2o`0000;ooooo
0_l0000=ooooo`Co00002Oooool2o`0000Oooooo0_l00006ooooo`;o00004oooool4o`000003oooo
ool0003o000000Kooooo0_l00004ooooo`;o00001?ooool2o`0001_ooooo0_l0000:ooooo`;o0000
3_ooool5o`0000oooooo0_l00003ooooo`;o000000?oooooo`000?l00000A?ooool00006oooooomg
MgOoV9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo03co
oooo0_l00005ooooo`;o00001?ooool3o`0001Kooooo0_l000000ooooooo0000o`000008ooooo`;o
00000oooool2o`0000;ooooo0ol00005ooooo`;o00000oooool2o`00013ooooo0ol00008ooooo`Co
00000_ooool3o`0000?ooooo0_l0000Aooooo`;o00002_ooool2o`0000Sooooo0_l0000>ooooo`;o
00004_ooool5o`000003ooooool0003o000000;o00000oooool2o`0003oooooo00001_ooooook^k^
oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`0goooo
o`;o00000oooool2o`0000Kooooo0_l00003ooooo`?o000000?oooooo`000?l000001Oooool2o`00
00Wooooo0_l000001?oooooo0000o`000?ooool2o`0000gooooo0_l00003ooooo`;o00002_ooool2
o`0000oooooo1?l00009ooooo`Co00000_ooool2o`0000Cooooo0_l0000:ooooo`;o00001?ooool3
o`0000Wooooo0_l00005ooooo`;o00006oooool2o`0000Wooooo1?l000000ooooooo0000o`000005
ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0<oooool2o`0000;ooooo0_l00006oooo
o`;o000000?oooooo`000?l000000_l00007ooooo`;o00001Oooool3o`000003ooooool0003o0000
00Gooooo0_l00004ooooo`;o00001Oooool3o`0000Wooooo0_l00005ooooo`;o00003?ooool2o`00
00Oooooo0_l0000;ooooo`Co00001?ooool2o`0000;ooooo0_l0000:ooooo`;o00001Oooool2o`00
0003ooooool0003o000000gooooo0_l0000Kooooo`;o00007_ooool2o`0003Kooooo000Looooo`03
o`000?oooooooooo03?ooooo0_l00005ooooo`;o00000oooool5o`0000Kooooo0ol00008ooooo`;o
000000?oooooo`000?l000001Oooool2o`0000Cooooo0_l00005ooooo`?o00001Oooool2o`0000;o
oooo0_l00005ooooo`;o000000?oooooo`000?l000001_ooool2o`000003ooooool0003o000001Co
oooo0ol000000ooooooo0000o`000002ooooo`;o00000_ooool4o`0001;ooooo0_l0000>ooooo`;o
00001Oooool2o`0000oooooo0_l00002ooooo`;o00003_ooool2o`0000kooooo0_l0000fooooo`00
7?ooool00ol0003oooooooooo`0jooooo`;o00001Oooool2o`0000Oooooo0ol00008ooooo`Ko0000
0oooool2o`0000Cooooo0ol0000=ooooo`;o00003?ooool2o`0000Kooooo1Ol00007ooooo`?o0000
0_ooool2o`0000Kooooo1_l00006ooooo`Co00007oooool2o`000004ooooool0003o0000o`0000Co
oooo0_l00002ooooo`;o00001Oooool2o`0000Cooooo1_l0000;ooooo`;o000000?oooooo`000?l0
00005?ooool2o`0000Cooooo0_l0000Zooooo`007?ooool00ol0003oooooooooo`0dooooo`;o0000
8Oooool5o`0000;ooooo0_l00004ooooo`?o00000_ooool2o`0000;ooooo0_l000000ooooooo0000
o`00000Iooooo`;o00001oooool5o`0000;ooooo0_l00006ooooo`Go00002?ooool4o`0000Sooooo
0_l0000Dooooo`;o00000_ooool2o`0000Sooooo0_l00005ooooo`;o000000?oooooo`000?l00000
0oooool4o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l00000
1_ooool2o`0000cooooo0_l00004ooooo`;o0000:_ooool001cooooo00?o0000ooooooooool0=?oo
ool2o`0001Wooooo0_l00004ooooo`Co000000?oooooo`000?l000000oooool2o`0000Sooooo0ol0
00001?oooooo0000o`000?ooool2o`00027ooooo0ol00003ooooo`;o00001Oooool2o`0000?ooooo
1_l00007ooooo`;o00002?ooool2o`0000;ooooo0_l0000:ooooo`;o00000_ooool2o`00017ooooo
0_l00004ooooo`?o00001Oooool2o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`;o0000
1_ooool2o`0000Oooooo0_l0000eooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00003Ooo
ool4o`0000Cooooo1_l00004ooooo`;o00001_ooool2o`000004ooooool0003o0000ooooo`;o0000
00?oooooo`000?l000003Oooool2o`0000Sooooo0_l00008ooooo`;o00000oooool3o`0000Gooooo
0ol000001?oooooo0000o`000?ooool5o`0000;ooooo0_l00004ooooo`;o00002_ooool2o`0000;o
oooo0_l00006ooooo`;o00000_ooool2o`0000?ooooo0ol0000;ooooo`;o00001?ooool2o`0000;o
oooo0_l00006ooooo`;o00006oooool3o`0003Cooooo000Looooo`03o`000?oooooooooo03gooooo
0ol00008ooooo`;o00000oooool2o`0000Oooooo0_l000000ooooooo0000o`00000<ooooo`;o0000
00?oooooo`000?l000002_ooool2o`000004ooooool0003o0000o`0000?ooooo0_l00006ooooo`Co
00002?ooool2o`0000?ooooo0ol00004ooooo`Co000000?oooooo`000?l000000_ooool4o`0000;o
oooo0_l00004ooooo`;o00000_ooool2o`0000[ooooo0_l0000?ooooo`Co00000oooool2o`0000oo
oooo0_l00003ooooo`;o000000Coooooo`000?l0003o00001oooool2o`0001;ooooo0_l0000doooo
o`007?ooool00ol0003oooooooooo`0mooooo`;o00001_ooool2o`000003ooooool0003o000000;o
oooo0_l0000<ooooo`;o00002?ooool3o`0000Wooooo0_l00002ooooo`Co000000Coooooo`000?l0
003o00002oooool2o`0000Wooooo0ol00002ooooo`?o00001Oooool2o`0000Oooooo0ol0000=oooo
o`;o00003?ooool4o`000005ooooool0003o0000o`000?ooool00_l000000ooooooo0000o`000003
ooooo`[o00003?ooool2o`0000?ooooo0_l000001?oooooo0000o`000?l00007ooooo`;o0000B?oo
ool001cooooo00?o0000ooooooooool0<oooool2o`00013ooooo0_l00005ooooo`Co00000_ooool2
o`000003ooooool0003o000000?ooooo1?l00006ooooo`?o00000oooool2o`0000?ooooo1?l00000
1?oooooo0000o`000?l00004ooooo`;o000000?oooooo`000?l000004_ooool2o`0000;ooooo1?l0
000:ooooo`;o000000?oooooo`000?l000001?l000000ooooooo0000o`00000<ooooo`Co000000?o
ooooo`000?l000001ol000000ooooooo0000o`000004o`000003ooooool0003o000000?ooooo3?l0
0002ooooo`Ko00000_ooool2o`0000;ooooo0_l00002ooooo`?o000000?oooooo`000?l000001Ooo
ool2o`0000;ooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00001oooool2
o`000003ooooool0003o000000cooooo0ol00002ooooo`;o000000?oooooo`000?l000001Oooool2
o`0000Gooooo0_l00005ooooo`;o00000oooool4o`0000Cooooo0_l00002ooooo`;o000000?ooooo
o`000?l000005_ooool2o`0000cooooo0_l000000ooooooo0000o`000007o`000003ooooool0003o
000000;o000000?oooooo`000?l000002?l000000ooooooo0000o`000004o`0000Oooooo1?l00004
ooooo`;o00001Oooool7o`000003ooooool0003o000000Co00001_ooool2o`0000Kooooo0_l00005
ooooo`;o00000_ooool3o`0000gooooo0_l0000cooooo`007?ooool00ol0003oooooooooo`0aoooo
o`;o00001_ooool2o`000004ooooool0003o0000ooooo`;o00000oooool2o`0000Oooooo0_l00006
ooooo`;o000000?oooooo`000?l000002Oooool2o`0000cooooo0_l00004ooooo`;o00000_ooool2
o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0002Gooooo0ol000000ooooooo0000o`00
000<o`0000Cooooo0_l00004ooooo`;o00000oooool5o`0000?ooooo0_l00006ooooo`Wo000000?o
ooooo`000?l000001Oooool2o`0000oooooo0_l00003ooooo`;o00003Oooool2o`0003?ooooo000L
ooooo`;o0000;_ooool2o`0000;ooooo0_l00006ooooo`;o000000?oooooo`000?l000001_ooool2
o`0000;ooooo0_l00008ooooo`?o00000oooool2o`0000;ooooo0_l00006ooooo`;o00002?ooool2
o`0000Cooooo0_l00005ooooo`;o00000oooool2o`000003ooooool0003o000000?o00000_ooool2
o`00027ooooo0_l00004ooooo`?o00000oooool2o`000003ooooool0003o000000;o00000oooool2
o`0000Cooooo0_l00002ooooo`Ko00002oooool2o`0000?ooooo1?l000000ooooooo0000o`000005
ooooo`;o0000F?ooool001cooooo00?o0000ooooooooool0;Oooool2o`0000;ooooo0_l00009oooo
o`;o00001_ooool2o`0000;ooooo0_l00008ooooo`?o00001oooool3o`0000Cooooo0ol000000ooo
oooo0000o`000005ooooo`;o00001?ooool3o`000003ooooool0003o000000Kooooo0_l00003oooo
o`;o00000oooool2o`0001gooooo0_l000001?oooooo0000o`000?l0000:ooooo`;o00000oooool2
o`0000gooooo0_l00006ooooo`;o00003_ooool4o`000003ooooool0003o000000;ooooo0_l00002
ooooo`;o00002?ooool2o`0004_ooooo000Looooo`03o`000?oooooooooo01[ooooo0_l0000Doooo
o`?o00001oooool2o`0000?ooooo0_l00002ooooo`?o00003?ooool3o`0000Cooooo0_l00002oooo
o`;o00001?ooool2o`0000;ooooo0_l00003ooooo`;o00001Oooool4o`000003ooooool0003o0000
00Gooooo1Ol00006ooooo`;o00002oooool2o`0000Cooooo0ol00004ooooo`;o00000oooool2o`00
0003ooooool0003o000001Kooooo0_l00002ooooo`?o00001_ooool2o`0000;ooooo0_l0000?oooo
o`_o000000?oooooo`000?l000002?ooool3o`0001?ooooo0_l00002ooooo`;o0000<Oooool001co
oooo00?o0000ooooooooool06_ooool2o`0001Cooooo0_l00002ooooo`;o00001?ooool3o`000004
ooooool0003o0000o`0000;ooooo1?l0000:ooooo`Co00000_ooool4o`00017ooooo0_l00003oooo
o`Co000000?oooooo`000?l000000_l000000ooooooo0000o`000002ooooo`Ko00004Oooool3o`00
00Cooooo0ol00004ooooo`;o00001_ooool2o`0000Sooooo0_l0000<ooooo`;o00000_ooool3o`00
00Kooooo1?l0000Booooo`[o00001_ooool2o`0000?ooooo1?l0000Booooo`;o00000_ooool2o`00
037ooooo000Looooo`03o`000?oooooooooo03Cooooo0_l00005ooooo`;o000000?oooooo`000?l0
00001?ooool5o`0000Sooooo0_l00002ooooo`Co00000oooool4o`0000Wooooo0ol00003ooooo`Ko
000000Coooooo`000?l0003o00000_ooool2o`000003ooooool0003o000000Go00001Oooool2o`00
00[ooooo0_l000000ooooooo0000o`00000Aooooo`Co00001_ooool2o`0000Cooooo0_l0000Doooo
o`?o00000_ooool4o`0000?ooooo0_l00004ooooo`;o00000oooool6o`0000Cooooo1_l00003oooo
o`Co00002Oooool2o`0003kooooo000Looooo`03o`000?oooooooooo04Cooooo1_l0000;ooooo`?o
00000oooool6o`0000Cooooo0_l00002ooooo`?o00000_ooool6o`0000;ooooo0_l00003ooooo`;o
000000Coooooo`000?l0003o00000oooool2o`0000Cooooo0ol00002ooooo`Co00001_ooool2o`00
00Cooooo0_l0000=ooooo`Co00002?ooool5o`0001Sooooo1?l00003ooooo`;o000000Coooooo`00
0?l0003ooooo0_l00003ooooo`;o00000_ooool2o`0000Cooooo1Ol00007ooooo`;o00000_ooool2
o`0000Cooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`18ooooo`;o00003_ooool2o`00
0003ooooool0003o000000;ooooo0_l00004ooooo`;o00000oooool2o`0000;ooooo3?l00002oooo
o`;o00001?ooool4o`0000Gooooo0_l00002ooooo`Co00003?ooool2o`0000cooooo0_l000000ooo
oooo0000o`000008ooooo`;o000000?oooooo`000?l000002oooool2o`0000gooooo0_l00006oooo
o`Co00002?ooool5o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`;o00000_ooool2o`00
00oooooo1?l0000aooooo`007?ooool00ol0003oooooooooo`0kooooo`;o000000Coooooo`000?l0
003ooooo0_l0000<ooooo`;o00001oooool2o`00013ooooo0_l00003ooooo`_o00000_ooool2o`00
0003ooooool0003o000000Co00001Oooool6o`0001gooooo0_l0000@ooooo`Co00001oooool2o`00
00Sooooo0_l000000ooooooo0000o`00000:ooooo`;o00002Oooool4o`0000Oooooo0_l0000Ioooo
o`Co0000<Oooool001cooooo00?o0000ooooooooool0>_ooool3o`000004ooooool0003o0000oooo
o`;o00003?ooool2o`0000Oooooo0_l00005ooooo`;o00002?ooool4o`0000Cooooo1Ol00002oooo
o`;o000000?oooooo`000?l000002?l00003ooooo`So000000?oooooo`000?l000000oooool2o`00
02Oooooo1?l0000=ooooo`;o00000_ooool6o`000003ooooool0003o000000;ooooo0_l00003oooo
o`;o00002?ooool4o`0005Oooooo000Looooo`03o`000?oooooooooo03[ooooo0_l0000:ooooo`?o
00002?ooool2o`0000Gooooo0_l000000ooooooo0000o`000002ooooo`;o00002?ooool4o`0000;o
oooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000So000000?oooooo`000?l0
00000oooool4o`0000Gooooo0_l00003ooooo`;o00000_ooool2o`0000Wooooo0_l0000Cooooo`?o
000000?oooooo`000?l000003oooool;o`000003ooooool0003o000000Co00000oooool2o`0000Ko
oooo2?l00004ooooo`;o00006Oooool2o`0003Cooooo000Looooo`03o`000?oooooooooo03oooooo
0_l00005ooooo`?o000000?oooooo`000?l000001?l000000ooooooo0000o`000002o`0000Kooooo
0_l00008ooooo`;o00000_ooool8o`000003ooooool0003o000000_o000000?oooooo`000?l00000
1?l00002ooooo`Co00003_ooool2o`0000Wooooo0_l00002ooooo`Co00002?ooool2o`0000?ooooo
1_l0000?oooooa3o00003Oooool5o`000003ooooool0003o000000Cooooo0_l00003ooooo`;o0000
1Oooool3o`0000cooooo0_l0000dooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00001?oo
ool4o`0000Oooooo2ol0000@ooooo`?o000000?oooooo`000?l000006ol000000ooooooo0000o`00
000Pooooo`Co00002?ooool2o`0000Cooooo1?l00002ooooo`;o00000_ooool2o`0000Oooooo4ol0
0003ooooo`;o00001oooool3o`0000gooooo0_l00005ooooo`?o00001oooool2o`0003Wooooo000L
ooooo`03o`000?oooooooooo03Wooooo0_l00003ooooo`Go00001Oooool2o`0000Kooooo0_l0000D
ooooo`;o000000?oooooo`000?l000006_l000001?oooooo0000o`000?l00002ooooo`?o00002?oo
ool4o`0000Sooooo0_l00005ooooo`;o00005_ooool2o`0000;ooooo0_l00005oooooaGo00000ooo
ool2o`0000Oooooo0ol0000;ooooo`Go00001oooool2o`0000Gooooo0_l0000iooooo`007?ooool0
0ol0003oooooooooo`0/ooooo`;o00003_ooool4o`0000Sooooo0_l00005ooooo`Co00003oooool2
o`0000Oooooo7Ol00003ooooo`?o00000oooool2o`0000;ooooo1Ol00008ooooo`;o00001Oooool2
o`0000Sooooo0_l0000GoooooaKo00002oooool3o`0000Oooooo0_l00002ooooo`;o000000?ooooo
o`000?l000001oooool2o`00043ooooo000Looooo`03o`000?oooooooooo02cooooo0_l0000>oooo
o`?o00004?ooool6o`0000gooooo1?l00007oooooaco00001Oooool2o`000004ooooool0003o0000
ooooo`?o00002oooool2o`0000oooooo0_l000000ooooooo0000o`000002ooooo`;o000000?ooooo
o`000?l000003OoooolFo`0000Gooooo0_l00004ooooo`;o000000?oooooo`000?l000001Oooool2
o`0000Sooooo1?l0000;ooooo`;o0000=oooool001cooooo00?o0000ooooooooool0=?ooool2o`00
00Gooooo0_l00009ooooo`;o00001?ooool2o`0000Gooooo0_l00003ooooo`;o00002Oooool4o`00
0005ooooool0003o0000o`000?ooool06_l000000ooooooo0000o`000009o`0000;ooooo0_l0000>
ooooo`;o00004?ooool2o`0000;ooooo1Ol0000:ooooo`;o000000?oooooo`000?l000000_l00000
0ooooooo0000o`00000@o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l000003?ooool2
o`000003ooooool0003o000000;o00002oooool2o`0003Oooooo000Looooo`;o0000:?ooool2o`00
00_ooooo0_l00005ooooo`?o00001oooool9o`0000[ooooo0_l00009ooooo`Co000000Goooooo`00
0?l0003o0000ooooo`04o`0000;ooooo4Ol000001?oooooo0000o`000?l00002ooooo`Wo00000_oo
ool2o`0000kooooo0_l0000Fooooo`?o00000_ooool4o`0000Cooooo1ol000000ooooooo0000o`00
0004o`000003ooooool0003o000000_o00001oooool3o`0000Sooooo0_l00005ooooo`;o00003?oo
ool2o`0003_ooooo000Looooo`03o`000?oooooooooo02Oooooo0_l0000Cooooo`;o00001Oooool:
o`000003ooooool0003o000000_ooooo0_l00009ooooo`oo000000?oooooo`000?l000004ol00004
ooooo`Go00000oooool2o`0000Wooooo0_l0000Booooo`;o00001?ooool3o`0000;ooooo1?l00004
oooooaco00001oooool2o`0000Wooooo0_l00004ooooo`?o00003?ooool2o`0003_ooooo000Loooo
o`03o`000?oooooooooo03Oooooo0_l00003ooooo`;o00001Oooool2o`0000;ooooo0_l00005oooo
o`;o00002oooool2o`0000Gooooo0_l00002oooooaCo00000_oooolHo`0000?ooooo0_l00009oooo
o`;o00001_ooool2o`0000[ooooo0_l00004ooooo`?o00001?ooool2o`0000Cooooo7?l0000Aoooo
o`;o00000_ooool2o`000003ooooool0003o000000;ooooo1?l0000<ooooo`;o0000=_ooool001co
oooo00?o0000ooooooooool0=oooool2o`00017ooooo0_l0000Eooooo`?o00000_ooool2o`000003
ooooool0003o000002So00001oooool3o`0000gooooo0_l00004ooooo`Co00000_ooool2o`0000Co
oooo0ol0000:ooooo`[o000000?oooooo`000?l000003ol00008ooooo`;o00001_ooool3o`0000;o
oooo0_l00005ooooo`Co00003?ooool2o`0003Kooooo000Looooo`03o`000?oooooooooo04[ooooo
0_l0000=ooooo`;o00001_ooool2o`0000?ooooo:_l000000ooooooo0000o`000006ooooo`Co0000
1?ooool2o`0000Cooooo0_l00007ooooo`Co00000_ooool2o`0000Cooooo0ol00007ooooo`go0000
0_oooolBo`000003ooooool0003o000000?ooooo0_l00004ooooo`Co00002oooool2o`0004Gooooo
000Looooo`03o`000?oooooooooo05Wooooo0_l00006ooooo`;o00000_ooool]o`0000?ooooo0_l0
0002ooooo`?o00001Oooool2o`0000Cooooo0_l0000Cooooo`?o00001oooool=o`000003ooooool0
003o0000017o000000?oooooo`000?l000000_ooool2o`0000Gooooo0ol0001Cooooo`007?ooool0
0ol0003oooooooooo`1Dooooo`;o000000?oooooo`000?l000002?ooool;o`000003ooooool0003o
000001oo000000Coooooo`000?l0003o00000oooool2o`0000?ooooo0_l0000=ooooo`;o00002_oo
ool2o`0000Gooooo0_l00002ooooo`;o00001OoooolMo`0000Sooooo0_l00006ooooo`;o00007_oo
ool3o`0003;ooooo000Looooo`03o`000?oooooooooo03_ooooo0_l0000Dooooo`Go000000?ooooo
o`000?l000000oooool3o`0000?ooooo0ol000001Ooooooo0000o`000?l0003ooooo02So00002_oo
ool2o`0000Wooooo1?l0000:ooooo`;o00001Oooool2o`0000;ooooo0ol00003oooooako00000_oo
ool3o`0000Gooooo0_l00008ooooo`;o00002_ooool5o`0000_ooooo0ol0000booooo`007?ooool0
0ol0003oooooooooo`0jooooo`?o00002?ooool2o`000003ooooool0003o000000Oooooo1?l00007
ooooo`Co00001_ooool2o`000004ooooool0003o0000ooooob?o000000?oooooo`000?l000002_oo
ool2o`0000Gooooo0_l00002ooooo`;o00004oooool2o`0000?ooooo0_l00003ooooo`;o000000?o
ooooo`000?l000005_l000001Ooooooo0000o`000?l0003ooooo00?o00001Oooool2o`0000Cooooo
0_l00002ooooo`;o00002_ooool5o`00043ooooo000Looooo`03o`000?oooooooooo02Kooooo0_l0
000Booooo`;o00001?ooool2o`0000?ooooo0_l000000ooooooo0000o`000007ooooo`Ko00000_oo
ool2o`0000?ooooo0_l00009ooooo`Ko000000Coooooo`000?l0003ooooo6ol000000ooooooo0000
o`00000Aooooo`?o00002oooool2o`0001Cooooo0_l000000ooooooo0000o`00000Fo`000004oooo
ool0003o0000o`0000Cooooo0_l00009ooooo`;o00001Oooool2o`0004cooooo000Looooo`03o`00
0?oooooooooo02Kooooo0_l0000?ooooo`;o00001oooool2o`0000Gooooo0_l000000ooooooo0000
o`000002o`0000Gooooo1Ol000000ooooooo0000o`00000;ooooo`;o000000?oooooo`000?l00000
8_l00002ooooo`;o00000oooool2o`0000cooooo0_l0000<ooooo`;o00005?ooool2o`000003oooo
ool0003o000001Oo00001oooool2o`0000Kooooo0_l00008ooooo`;o00000oooool2o`0000_ooooo
0_l0000jooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00001oooool3o`0000Cooooo0_l0
00000ooooooo0000o`000002o`0000Cooooo0ol000000ooooooo0000o`000003ooooo`Co00001?oo
ool2o`000004ooooool0003o0000ooooobCo00000_ooool2o`0000?ooooo0_l0000:ooooo`;o0000
3Oooool2o`0001Gooooo0_l00003oooooa?o000000Coooooo`000?l0003o00001_ooool2o`0000Oo
oooo1_l00009ooooo`;o00002Oooool4o`0003[ooooo000Looooo`03o`000?oooooooooo03Oooooo
0_l00008ooooo`;o00002?ooool4o`0000?ooooo0_l00007ooooo`Co00001?ooool2o`0000Cooooo
9ol000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo
0_l00008ooooo`?o00005Oooool2o`000003ooooool0003o000001Oo00001Oooool3o`0000Wooooo
1?l00002ooooo`;o00002?ooool2o`0000?ooooo0_l000000ooooooo0000o`00000Cooooo`;o0000
9oooool001cooooo00?o0000ooooooooool08?ooool2o`0001Gooooo0_l0000:ooooo`?o00001ooo
ool2o`0000gooooo0_l0000<ooooobWo00001?ooool5o`0000Sooooo0_l00007ooooo`Go00001_oo
ool2o`0000Oooooo0_l00003ooooo`;o000000?oooooo`000?l000002?l000000ooooooo0000o`00
000:o`0000Oooooo0ol00007ooooo`;o00000oooool5o`0000?ooooo0ol00002ooooo`;o00000ooo
ool4o`0001Cooooo0_l0000Wooooo`007?ooool00ol0003oooooooooo`0Pooooo`;o00008Oooool3
o`000004ooooool0003o0000o`0000oooooo0_l000000ooooooo0000o`000009ooooo`;o000000?o
ooooo`000?l000009Ol00003ooooo`;o00000_ooool2o`0000gooooo0_l00004ooooo`;o000000?o
ooooo`000?l000001Oooool3o`000003ooooool0003o000000Cooooo0_l00007ooooo`;o000000?o
ooooo`000?l000004?l0000Booooo`;o00000oooool4o`0000?ooooo1?l00009ooooo`;o00000ooo
ool2o`0003Sooooo000Looooo`03o`000?oooooooooo04?ooooo0ol000000ooooooo0000o`000003
o`000003ooooool0003o000000Oooooo0_l000000ooooooo0000o`000003ooooo`;o00001oooool2
o`000003ooooool0003o000002Co00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000:
ooooo`;o00003_ooool6o`0000gooooo3Ol000001Ooooooo0000o`000?l0003ooooo00Go00002_oo
ool2o`0000Wooooo0_l00005ooooo`Co00003_ooool2o`0000gooooo0_l0000Yooooo`007?ooool2
o`0002Sooooo0_l0000Gooooo`;o00001_ooool4o`000003ooooool0003o000000Oooooo0ol00005
ooooo`;o00000oooool2o`0000;ooooo1Ol000000ooooooo0000o`00000Po`0000[ooooo1?l0000C
ooooo`;o00000oooool2o`0000;ooooo0ol0000?ooooo`;o000000?oooooo`000?l000002_l00002
ooooo`;o000000?oooooo`000?l000002_ooool3o`000003ooooool0003o000000Gooooo0_l00007
ooooo`;o00002?ooool2o`0001?ooooo0_l0000Yooooo`007?ooool00ol0003oooooooooo`0Woooo
o`;o00005oooool3o`0000?ooooo1?l0000=ooooo`?o00002Oooool2o`0000;ooooo1Ol000000ooo
oooo0000o`00000Lo`0000Oooooo1_l000000ooooooo0000o`00000Eooooo`;o000000?oooooo`00
0?l000000_l00002ooooo`?o00004_ooool2o`0000Kooooo0_l000000ooooooo0000o`000002o`00
00oooooo0_l000000ooooooo0000o`00000Hooooo`?o0000?Oooool001cooooo00?o0000oooooooo
ool0??ooool2o`0000?ooooo0_l00003ooooo`;o00004?ooool2o`0000;ooooo0_l00009ooooo`Co
000000?oooooo`000?l000002ol000000ooooooo0000o`00000Ao`000005ooooool0003o0000o`00
0?ooool01_l00002ooooo`;o00000oooool2o`0001;ooooo0ol00003ooooo`?o00000_ooool2o`00
017ooooo0_l00006ooooo`Co00002?ooool2o`000003ooooool0003o000000oooooo0_l0000?oooo
o`;o0000?Oooool001cooooo00?o0000ooooooooool0??ooool2o`0000?ooooo0_l0000<ooooo`;o
00000_ooool2o`0000Oooooo0_l00005ooooo`;o000000?oooooo`000?l000000ol000001?oooooo
0000o`000?ooool6o`000004ooooool0003o0000o`0000;ooooo4_l000001Ooooooo0000o`000?l0
003ooooo00;o000000Coooooo`000?l0003o00000_ooool2o`0000;ooooo0ol00002ooooo`;o0000
1oooool2o`0000Sooooo0_l000000ooooooo0000o`000003ooooo`;o00003_ooool2o`000003oooo
ool0003o000000?ooooo0_l0000=ooooo`;o000000?oooooo`000?l000000_l0000=ooooo`;o0000
2_ooool2o`0001Gooooo0_l0000[ooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00002ooo
ool2o`0000;ooooo0_l00004ooooo`;o00002?ooool5o`000003ooooool0003o000000;ooooo2?l0
00001Ooooooo0000o`000?l0003ooooo01Co00000_ooool3o`0000?ooooo0_l00006ooooo`;o0000
0oooool2o`0000Oooooo0_l00002ooooo`;o00001?ooool2o`0001Kooooo0_l00006ooooo`;o0000
4_ooool2o`0000;ooooo0_l00003ooooo`;o00002oooool2o`0000?ooooo0_l0000Eooooo`;o0000
:oooool001cooooo00?o0000ooooooooool0=oooool2o`0000Cooooo0_l00003ooooo`;o00002_oo
ool2o`0000Gooooo0_l00002ooooo`;o00001oooool2o`000004ooooool0003o0000ooooo`?o0000
0_oooolQo`000003ooooool0003o000000;o00002?ooool4o`00017ooooo0_l0000?ooooo`;o0000
4oooool2o`0001Kooooo0_l00003ooooo`;o00002oooool2o`0000[ooooo0ol0000jooooo`007?oo
ool00ol0003oooooooooo`0gooooo`;o00001?ooool2o`0000_ooooo0_l00002ooooo`Co00000ooo
ool2o`0000_ooooo0_l00004ooooo`;o00001?oooolIo`000004ooooool0003o0000ooooo`?o0000
00?oooooo`000?l000000_l00008ooooo`Co00003_ooool2o`000004ooooool0003o0000o`0000[o
oooo1_l00003ooooo`;o00001_ooool2o`0000Kooooo0_l00004ooooo`;o00000_ooool6o`0002Ko
oooo0ol0000jooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00004?ooool2o`0000Cooooo
0_l0000;ooooo`?o00001?ooool2o`0000Oooooo0ol000000ooooooo0000o`00000Do`000003oooo
ool0003o000000Wo000000Coooooo`000?l0003o00003oooool2o`0000Gooooo0_l000001?oooooo
0000o`000?l00007ooooo`;o000000?oooooo`000?l000000ol00004ooooo`Co00001?ooool2o`00
00Kooooo0_l00004ooooo`;o00000_ooool9o`0000Wooooo1?l00003ooooo`;o00004Oooool2o`00
03_ooooo000Looooo`03o`000?oooooooooo03Cooooo0_l00002ooooo`;o00005oooool2o`000003
ooooool0003o000000Oooooo0ol00004ooooo`;o00000_ooool4o`000003ooooool0003o000002Co
000000Coooooo`000?l0003o00001?ooool2o`0000Wooooo0_l0000Booooo`;o000000?oooooo`00
0?l000000ol00002ooooo`;o00000_ooool2o`0000?ooooo0_l00006ooooo`;o00003?ooool6o`00
00Wooooo1?l000000ooooooo0000o`000002o`0000Cooooo0_l00018ooooo`007?ooool00ol0003o
ooooooooo`0dooooo`;o00001oooool3o`0000kooooo0_l000001?oooooo0000o`000?ooool2o`00
01;ooooo1?l00003oooooa[o00000oooool2o`0000;ooooo0_l00004ooooo`;o00000oooool2o`00
01Gooooo0_l0000;ooooo`;o00000oooool2o`0000Oooooo0_l00006ooooo`;o00008?ooool3o`00
00Gooooo0_l00004ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0?Oooool3o`0000Ko
oooo0_l00006ooooo`;o00006oooool2o`0000;ooooo3Ol000000ooooooo0000o`000007o`000003
ooooool0003o000000?ooooo0_l00008ooooo`Co00006?ooool2o`0000[ooooo0ol0000=ooooo`;o
00005?ooool2o`0001;ooooo0_l0000;ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0
@?ooool2o`0000?ooooo0ol00009ooooo`;o00005Oooool2o`000003ooooool0003o000000;ooooo
1Ol000000ooooooo0000o`00000:o`000005ooooool0003o0000o`000?ooool01Ol000000ooooooo
0000o`000003ooooo`;o00001Oooool2o`00013ooooo0_l0000@ooooo`Go00002Oooool2o`0000;o
oooo0_l0000Dooooo`;o00003_ooool2o`000003ooooool0003o0000053ooooo000Looooo`03o`00
0?oooooooooo043ooooo0_l00003ooooo`;o00002?ooool4o`0001Gooooo0_l00005ooooo`Go0000
0ooooolHo`0000;ooooo0_l00009ooooo`?o00000oooool2o`0000Kooooo0_l0000<ooooo`?o0000
00Coooooo`000?l0003ooooo1?l000000ooooooo0000o`000004ooooo`Go00001Oooool2o`0000?o
oooo0_l00005ooooo`?o00000oooool2o`0000cooooo0_l000001?oooooo0000o`000?l0001?oooo
o`007?ooool00ol0003oooooooooo`0fooooo`?o00003?ooool2o`0000Sooooo0_l0000?ooooo`;o
00003_ooool4o`000003ooooool0003o000000;o00001?ooool:o`0000;ooooo0ol000000ooooooo
0000o`000003o`0000Kooooo0_l00002ooooo`?o00000oooool3o`0001?ooooo0ol00004ooooo`Co
000000?oooooo`000?l000001_ooool3o`0000Gooooo0_l00003ooooo`;o00001Oooool4o`0000;o
oooo0_l00003ooooo`;o00002oooool2o`0000Kooooo0_l00017ooooo`0000Koooooonk^k_lb<S;o
0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000
ooooooooool0=_ooool3o`0000?ooooo1?l0000;ooooo`;o00000oooool2o`0000Wooooo0_l00003
ooooo`Co000000?oooooo`000?l000002Oooool4o`000003ooooool0003o000000?o00001?ooool4
o`0000?ooooo0_l00002ooooo`;o00001?ooool5o`000004ooooool0003o0000ooooo`Co000000?o
ooooo`000?l000000oooool3o`0000Oooooo0_l00007ooooo`;o00002?ooool2o`0000kooooo0_l0
0006ooooo`;o00001oooool4o`0000Oooooo0_l00006ooooo`;o00002oooool2o`0004Oooooo0000
1_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B401_ooool00ol0003oooooooooo`0gooooo`;o00000oooool4o`000003ooooool0003o000000;o
oooo0ol000000ooooooo0000o`000002o`0000?ooooo0_l00009ooooo`;o00001Oooool2o`000003
ooooool0003o000000Cooooo0_l00004ooooo`;o00000oooool4o`000005ooooool0003o0000o`00
0?ooool01Ol000000ooooooo0000o`000002ooooo`;o00001?ooool5o`000003ooooool0003o0000
00?ooooo0_l000000ooooooo0000o`000003ooooo`Ko00001?ooool2o`0000Oooooo0_l0000>oooo
o`;o00002?ooool2o`0000Kooooo0_l00009ooooo`;o00002_ooool4o`000003ooooool0003o0000
05Cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo047ooooo0_l00002ooooo`?o000000Coooooo`00
0?l0003ooooo0_l00006ooooo`Co00004oooool2o`000004ooooool0003o0000ooooo`;o00000ooo
ool8o`0000Cooooo0_l00004ooooo`Co00000oooool3o`00017ooooo1Ol0000Cooooo`;o00002?oo
ool3o`00013ooooo0_l00005ooooo`;o000000?oooooo`000?l000002_ooool4o`000003ooooool0
003o000000Wooooo0ol00002ooooo`;o00001oooool2o`0003_ooooo00000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo00Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000A?oo
ool2o`0000?ooooo0_l000000ooooooo0000o`000003o`0000?ooooo1?l00007ooooo`Co00000_oo
ool2o`0000?ooooo0_l00002oooooa3o00001oooool2o`000003ooooool0003o000000?o00000_oo
ool3o`000003ooooool0003o000000;o000000?oooooo`000?l000001Oooool4o`00013ooooo0_l0
0006ooooo`;o00000oooool2o`0000;ooooo1?l00006ooooo`?o00001oooool5o`0000;ooooo0_l0
000Booooo`;o00002Oooool3o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`?o0000>ooo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oEEEEo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0@Oooool2o`000003ooooool0003o000000?ooooo1?l0
00001?oooooo0000o`000?l00004ooooo`;o00001_ooool:o`0000?ooooo0_l00003ooooo`Oo0000
0_ooool6o`0000Oooooo0ol00003ooooo`;o00000_ooool2o`0000;ooooo1?l000000ooooooo0000
o`000002o`0000;ooooo1Ol0000@ooooo`;o00001?ooool2o`0000Cooooo0ol00002ooooo`;o0000
0_ooool2o`0000Cooooo0ol00009ooooo`?o00005_ooool2o`0000Oooooo0ol00007ooooo`;o0000
00?oooooo`000?l000000_l0000looooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0@Oooool2o`000003ooooool0
003o000000Gooooo1?l00006ooooo`;o00001_ooool4o`0000;ooooo0_l00005ooooo`;o00001Ooo
ool2o`0000Gooooo2?l00005ooooo`?o00000oooool2o`0000;ooooo0_l00009ooooo`;o00000_oo
ool3o`0001Gooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00007ooooo`;o0000;Ooo
ool2o`0000?ooooo0ol00005ooooo`Co000000?oooooo`000?l00000?_ooool00006oooooomgMgOo
V9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo04Kooooo
0_l00005ooooo`;o00004?ooool2o`0000Wooooo1?l00009ooooo`_o00000oooool2o`0000Sooooo
0_l00007ooooo`;o00001?ooool2o`0000;ooooo0_l00002ooooo`;o00003?ooool4o`0000?ooooo
1?l00002ooooo`;o00001Oooool2o`0001cooooo0_l00008ooooo`;o00001Oooool4o`0000Wooooo
1?l00011ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co0000oa0@
40Kooooo00?o0000ooooooooool0>oooool2o`0000Wooooo0_l0000=ooooo`;o00004_ooool2o`00
0003ooooool0003o000000Wooooo0_l00002ooooo`Co000000Coooooo`000?l0003ooooo0_l00007
ooooo`;o000000?oooooo`000?l000001oooool2o`0000Sooooo0_l00002ooooo`Go00000_ooool3
o`0000Cooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l0000?ooooo`;o00004Oooool3
o`0000Sooooo0_l00007ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0=?ooool2o`00
00Gooooo0_l000001?oooooo0000o`000?ooool4o`00013ooooo0_l0000Booooo`;o000000?ooooo
o`000?l000003oooool2o`0000Cooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o
000000gooooo0_l00002ooooo`;o00001?ooool:o`0000Kooooo0_l00006ooooo`;o00000_ooool2
o`000003ooooool0003o000000Gooooo0_l00002ooooo`?o00004?ooool4o`00017ooooo0_l00003
ooooo`?o0000Aoooool001cooooo00?o0000ooooooooool0=?ooool2o`0000Gooooo0_l000001?oo
oooo0000o`000?ooool6o`0001_ooooo0_l00002ooooo`;o00000_ooool8o`0000[ooooo0_l00009
ooooo`;o00000_ooool2o`000003ooooool0003o000000kooooo0_l00002ooooo`;o00000oooool2
o`0000;ooooo1ol00002ooooo`;o00002_ooool2o`0000;ooooo1Ol000000ooooooo0000o`000002
ooooo`;o00000oooool2o`000003ooooool0003o000000oooooo0_l0000Aooooo`Co000000?ooooo
o`000?l000000ol00015ooooo`007?ooool00ol0003oooooooooo`0nooooo`Co00000oooool2o`00
01_ooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo1?l000000ooooooo0000o`000007oooo
o`;o00002?ooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0000Oooooo0_l00006
ooooo`;o000000?oooooo`000?l000001ol00006ooooo`Co00000_ooool2o`0000Cooooo0_l00000
1?oooooo0000o`000?ooool2o`0000;ooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo0_l0
000:ooooo`;o00001?ooool2o`00017ooooo0ol00004ooooo`;o00004Oooool2o`0003;ooooo000L
ooooo`03o`000?oooooooooo03cooooo1_l0000:ooooo`;o00009Oooool3o`00013ooooo0_l00009
ooooo`?o00001_ooool2o`0000Sooooo2_l00004ooooo`;o00000_ooool2o`0000;ooooo0_l00004
ooooo`Ko00002?ooool3o`000003ooooool0003o000000kooooo0_l00004ooooo`;o00001?ooool2
o`0000Gooooo0_l00004ooooo`;o00001Oooool4o`0000oooooo0_l0000booooo`007?ooool00ol0
003oooooooooo`0`ooooo`;o00002_ooool2o`0000Cooooo0_l00008ooooo`;o00004_ooool2o`00
01;ooooo0_l00003ooooo`;o00003_ooool2o`0000Oooooo0_l00008ooooo`;o000000?oooooo`00
0?l000000_l000000ooooooo0000o`000005o`000003ooooool0003o000000Ko00003?ooool3o`00
0004ooooool0003o0000o`0000Gooooo1Ol0000Gooooo`;o00001?ooool2o`0000Gooooo0_l0000=
ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0<?ooool2o`00013ooooo0_l0000<oooo
o`;o00003_ooool2o`0000Wooooo0_l00006ooooo`;o000000?oooooo`000?l000000ol00007oooo
o`;o00001Oooool2o`00017ooooo0_l000000ooooooo0000o`000009o`000003ooooool0003o0000
00[o00000oooool2o`0000Wooooo0_l00005ooooo`;o000000?oooooo`000?l000008?ooool2o`00
00;ooooo0_l0000:ooooo`?o0000AOooool001cooooo00?o0000ooooooooool0@_ooool2o`0000Ko
oooo0_l00003ooooo`?o00006Oooool2o`0000Kooooo0_l000001?oooooo0000o`000?l00007oooo
o`Co00005ooooolLo`0000?ooooo0_l00004ooooo`;o00003?ooool3o`00013ooooo0_l0000>oooo
o`;o00000_ooool2o`0000Gooooo0_l00003ooooo`?o0000AOooool001cooooo00?o0000oooooooo
ool0A_ooool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000007Oooool2o`0000go
oooo0_l00006ooooo`;o00004OoooolMo`0000Sooooo0_l0000<ooooo`?o00004?ooool3o`0001So
oooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`16ooooo`;o00001?ooool2o`0000Cooooo
0ol0000Looooo`;o00003?ooool2o`0000;ooooo0_l00003ooooo`;o00003ooooolOo`0000Cooooo
0_l00002ooooo`?o00003Oooool2o`0000_ooooo0_l00002ooooo`?o00004_ooool3o`0000Wooooo
0_l0000=ooooo`;o000000?oooooo`000?l00000<oooool001cooooo00?o0000ooooooooool0C?oo
ool2o`0000Gooooo0_l000000ooooooo0000o`000005ooooo`;o00001oooool2o`0000Cooooo0_l0
000Aooooo`;o00000_ooool2o`0000Cooooo0_l0000=ooooo`?o00000_ooool;o`000003ooooool0
003o000000go00001?ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000000ooo
ool2o`0000Cooooo0ol0000;ooooo`;o00004oooool2o`0000;ooooo0ol00009ooooo`;o00003Ooo
ool2o`000003ooooool0003o000003?ooooo000Looooo`03o`000?oooooooooo043ooooo0_l0000:
ooooo`;o00001oooool3o`0000Gooooo0_l00007ooooo`;o00000oooool3o`0000Sooooo0_l00009
ooooo`Co00001?ooool2o`0000gooooo1?l000000ooooooo0000o`000003ooooo`Wo000000?ooooo
o`000?l000002Ol00008ooooo`;o00000oooool4o`000003ooooool0003o000000Cooooo0_l00004
ooooo`;o00001?ooool2o`0000Oooooo0_l00004ooooo`;o00001_ooool2o`0000;ooooo0_l0001A
ooooo`007?ooool2o`0003cooooo0ol00002ooooo`?o00004_ooool3o`0001?ooooo0ol00008oooo
o`;o00001oooool6o`00013ooooo0_l00003ooooo`;o000000?oooooo`000?l000006ol0000<oooo
o`;o00003Oooool4o`0000;ooooo0ol00006ooooo`;o00001?ooool2o`0000Oooooo0_l000000ooo
oooo0000o`000005ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0=oooool2o`0000;o
oooo0ol00003ooooo`;o00001_ooool2o`0000_ooooo0_l00003ooooo`;o00003oooool2o`0000Oo
oooo0_l00002ooooo`;o00001?ooool2o`000003ooooool0003o0000017ooooo0_l00003ooooo`;o
000000?oooooo`000?l000006ol00009ooooo`;o00003_ooool2o`0000;ooooo0_l00003ooooo`;o
00000oooool2o`000003ooooool0003o000000gooooo0_l00008ooooo`;o000000?oooooo`000?l0
0000Aoooool001cooooo00?o0000ooooooooool0=oooool2o`0000?ooooo0_l00002ooooo`;o0000
1oooool2o`00013ooooo0_l0000Aooooo`;o00001?ooool3o`0000;ooooo0_l00005ooooo`Co0000
1_ooool2o`0000Gooooo0_l000000ooooooo0000o`000004ooooo`;o00000_ooool9o`000003oooo
ool0003o0000017o00002?ooool2o`0000;ooooo0_l00005ooooo`;o00000oooool2o`0000?ooooo
0_l00002ooooo`;o00000oooool2o`0000[ooooo0_l00006ooooo`;o00002Oooool2o`0004Oooooo
000Looooo`03o`000?oooooooooo03gooooo0_l000001?oooooo0000o`000?ooool2o`0000oooooo
1?l0000Fooooo`;o00001?ooool2o`0000Kooooo0_l00002ooooo`;o00001Oooool2o`000003oooo
ool0003o000000;o00000oooool5o`0000Cooooo0_l00003oooooaco00002?ooool2o`0000;ooooo
0_l00005ooooo`;o00000_ooool2o`0000Cooooo1?l00007ooooo`;o00002?ooool2o`0000Kooooo
0_l00006ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0=oooool2o`0000Cooooo0_l0
0004ooooo`;o00003oooool4o`0002Cooooo0_l00002ooooo`;o00001Oooool4o`000003ooooool0
003o000000Gooooo0_l00009ooooo`Ko000000?oooooo`000?l000004Ol0000;ooooo`;o00001?oo
ool2o`0000Oooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l0
0008ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Cooooo0ol0001:ooooo`007?ooool0
0ol0003oooooooooo`0gooooo`;o00001?ooool2o`0001Gooooo1?l0000Mooooo`;o00001_ooool2
o`0000[ooooo0_l000001?oooooo0000o`000?l0000?oooooago00003_ooool3o`0000;ooooo0_l0
0007ooooo`;o00001Oooool2o`000003ooooool0003o000000;o00002?ooool5o`0000Cooooo0_l0
0004ooooo`;o00003Oooool3o`0003_ooooo000Looooo`03o`000?oooooooooo03gooooo0_l0000=
ooooo`;o00001oooool3o`000003ooooool0003o000000Kooooo0_l0000Booooo`;o00001_ooool2
o`0000_ooooo1Ol0000<ooooo`?o000000?oooooo`000?l000006_l000000ooooooo0000o`00000;
ooooo`?o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`000008ooooo`;o00002oooool2
o`0001_ooooo0ol0000kooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00001oooool2o`00
00;ooooo0_l00006ooooo`;o00009oooool2o`0000Cooooo0_l00009ooooo`?o000000?oooooo`00
0?l000006_l000001?oooooo0000o`000?l0000Aooooo`;o00000_ooool2o`0000Kooooo0_l00003
ooooo`Co00004_ooool2o`0000Gooooo0_l00019ooooo`007?ooool00ol0003oooooooooo`18oooo
o`;o00001?ooool3o`00017ooooo0_l0000Looooo`;o00001Oooool2o`0000Oooooo0_l00003oooo
o`;o00001_ooool2o`0000;ooooo6Ol000000ooooooo0000o`000002o`00017ooooo1_l00002oooo
o`;o00000_ooool2o`0000Gooooo0_l0000Booooo`;o00001Oooool2o`0004Wooooo000Looooo`03
o`000?oooooooooo04Sooooo0_l00003ooooo`Co00002?ooool2o`0000Oooooo0_l0000Looooo`;o
00001Oooool2o`0000?ooooo0_l00005ooooo`Co00001_ooool2o`000003ooooool0003o000001Oo
00000_ooool3o`0000Cooooo0ol00003ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Co
oooo0_l00005ooooo`;o00001oooool2o`0000;ooooo0_l0001Kooooo`007?ooool00ol0003ooooo
ooooo`10ooooo`;o000000?oooooo`000?l000002?ooool2o`0000;ooooo0_l00006ooooo`;o0000
:Oooool2o`000003ooooool0003o000000?ooooo0_l00005ooooo`;o00000_ooool2o`0000Oooooo
7_l00004ooooo`?o00000oooool2o`000003ooooool0003o000001;ooooo0_l00004ooooo`;o0000
00?oooooo`000?l000000_ooool4o`0001Kooooo0_l00011ooooo`007?ooool00ol0003ooooooooo
o`10ooooo`;o000000?oooooo`000?l000002Oooool2o`000003ooooool0003o000000Sooooo0_l0
0005ooooo`;o00008?ooool2o`00017ooooo0_l00007oooooago00004?ooool4o`0000Wooooo0_l0
0004ooooo`;o00000oooool2o`0000Oooooo0_l0000Aooooo`;o00000oooool2o`00047ooooo000L
ooooo`03o`000?oooooooooo04Oooooo0_l00005ooooo`;o00002oooool3o`0000Cooooo0_l0000R
ooooo`;o00006?oooolJo`000003ooooool0003o000000Ko00002_ooool4o`0000Wooooo0_l00004
ooooo`;o00004_ooool2o`0000_ooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`17oooo
o`?o00004_ooool2o`0002Sooooo0_l0000Hoooooa[o000000?oooooo`000?l000001_l00008oooo
o`;o00001Oooool2o`0000?ooooo0_l0000Iooooo`Co0000Doooool001cooooo00?o0000oooooooo
ool0B?ooool2o`0000Sooooo0_l00002ooooo`;o00003_ooool2o`00023ooooo0_l00009ooooo`;o
00001oooool2o`0000;ooooo3_l000000ooooooo0000o`00000=o`000003ooooool0003o000000;o
00002?ooool2o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o00003_ooool2o`0000Ko
oooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l0000<ooooo`;o0000@Oooool001cooooo
00?o0000ooooooooool0BOooool2o`0000Kooooo0ol00002ooooo`;o00000oooool3o`0000Sooooo
0_l0000Pooooo`;o00002Oooool2o`0000Oooooo0_l00003ooooo`;o000000?oooooo`000?l00000
5_l00003ooooo`;o00001oooool3o`0000Cooooo0_l0000Fooooo`;o00001_ooool2o`0000?ooooo
0_l00002ooooo`;o00003?ooool2o`00047ooooo000Looooo`;o0000B_ooool3o`0000Gooooo0_l0
0008ooooo`?o00001?ooool2o`0002Sooooo1Ol00009ooooo`;o00001Oooool2o`000003ooooool0
003o000000;ooooo3_l000001?oooooo0000o`000?ooool2o`0000cooooo0ol00006ooooo`;o0000
0_ooool2o`0000Kooooo0_l00005ooooo`;o0000Hoooool001cooooo00?o0000ooooooooool0B_oo
ool2o`0000[ooooo0_l0000:ooooo`;o00000_ooool2o`0001kooooo0_l00004ooooo`Go00002Ooo
ool2o`0000Sooooo0ol000000ooooooo0000o`00000;o`000004ooooool0003o0000o`0000kooooo
0_l00008ooooo`;o00000_ooool2o`0000Kooooo0ol00003ooooo`?o00002?ooool2o`00013ooooo
0_l00017ooooo`007?ooool00ol0003oooooooooo`1Dooooo`Ko00000_ooool2o`0000Sooooo0_l0
000Nooooo`;o00001_ooool2o`0001Cooooo5Ol000000ooooooo0000o`00000;ooooo`;o00002?oo
ool2o`0000_ooooo0_l00003ooooo`;o00002Oooool2o`00013ooooo0_l00017ooooo`007?ooool0
0ol0003oooooooooo`1Dooooo`;o00000_ooool2o`0000;ooooo0_l0000Uooooo`;o00004?ooool2
o`0000Wooooo0_l00003ooooo`Co000000?oooooo`000?l000002_l00004ooooo`;o000000?ooooo
o`000?l000004_ooool2o`0001[ooooo0_l000000ooooooo0000o`00001Gooooo`007?ooool00ol0
003oooooooooo`1Cooooo`;o00001_ooool2o`0000gooooo0_l0000Gooooo`;o00000_ooool2o`00
00_ooooo0ol00002ooooo`;o00000oooool4o`0000;ooooo4_l00007ooooo`;o00004Oooool2o`00
01Kooooo0_l00003ooooo`;o000000?oooooo`000?l00000Eoooool001cooooo00?o0000oooooooo
ool0Doooool3o`0000Gooooo0_l0000<ooooo`?o00006oooool2o`0000?ooooo0_l00006ooooo`;o
00000oooool2o`0000?ooooo0_l00004ooooo`ko000000Coooooo`000?l0003o00006_ooool2o`00
00?ooooo0_l00006ooooo`Co00001Oooool4o`0001Sooooo0_l00015ooooo`007?ooool00ol0003o
ooooooooo`1Aooooo`;o000000?oooooo`000?l000000_ooool2o`0000Sooooo0_l00005ooooo`;o
000000?oooooo`000?l000006Oooool2o`0000?ooooo0_l0000Hooooo`;o000000?oooooo`000?l0
00001_l00002ooooo`Co000000?oooooo`000?l000000oooool2o`0000Cooooo0_l00007ooooo`;o
000000?oooooo`000?l000001?ooool2o`0000Kooooo1?l00005ooooo`;o00001Oooool4o`00017o
oooo0_l00015ooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o00000oooool4o`000003oooo
ool0003o000000Gooooo0_l00007ooooo`?o00007Oooool2o`0000Kooooo0_l0000Booooo`[o0000
0_ooool4o`000003ooooool0003o000000?ooooo0_l00004ooooo`;o00001oooool2o`000003oooo
ool0003o000000?ooooo0ol0000Fooooo`Co0000F?ooool001cooooo00?o0000ooooooooool0D_oo
ool2o`0000;ooooo0_l00003ooooo`;o00001_ooool2o`0000Kooooo0_l0000Eooooo`;o00001ooo
ool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000;o0000
2Oooool4o`0000?ooooo1?l00004ooooo`;o00001_ooool2o`00013ooooo0_l00003ooooo`?o0000
1Oooool2o`0006_ooooo000Looooo`03o`000?oooooooooo04Kooooo0_l0000:ooooo`?o00003_oo
ool2o`0000_ooooo0_l0000@ooooo`;o00003?ooool2o`0000Cooooo0_l000000ooooooo0000o`00
0002o`0000Wooooo0_l00002ooooo`;o00002oooool2o`0000Kooooo0_l0000Dooooo`;o00001Ooo
ool2o`0000cooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`16ooooo`;o00001?ooool2
o`0000Gooooo0_l00002ooooo`;o00005Oooool4o`0003Sooooo0_l000001?oooooo0000o`000?oo
ool2o`0000Cooooo1Ol00004ooooo`;o00002?ooool2o`0001;ooooo0_l0000;ooooo`?o00004ooo
ool2o`0004Oooooo000Looooo`03o`000?oooooooooo04cooooo0_l00009ooooo`;o00005Oooool4
o`00013ooooo0_l00004ooooo`;o00008_ooool3o`000004ooooool0003o0000o`0000?ooooo0_l0
00001?oooooo0000o`000?ooool3o`0000[ooooo0_l000000ooooooo0000o`000007ooooo`;o0000
1_ooool2o`0000Kooooo1?l000000ooooooo0000o`000003o`00017ooooo0_l00017ooooo`007?oo
ool00ol0003oooooooooo`1@ooooo`;o00001oooool2o`0000Gooooo0_l0000>ooooo`Co00003_oo
ool2o`0000;ooooo1?l0000;ooooo`;o00004?ooool2o`0000?ooooo0_l00003ooooo`;o00002?oo
ool4o`0000gooooo0ol00006ooooo`;o00003_ooool4o`000004ooooool0003o0000ooooo`;o0000
F_ooool001cooooo00?o0000ooooooooool0D?ooool2o`0000Oooooo0_l00003ooooo`Ko00003_oo
ool2o`00013ooooo1?l000001?oooooo0000o`000?l00009ooooo`;o00001Oooool2o`0000Wooooo
0_l00005ooooo`;o00002oooool2o`0000Cooooo0_l00009ooooo`?o00001Oooool2o`0000Kooooo
1?l00006ooooo`?o0000H?ooool001cooooo00?o0000ooooooooool0GOooool3o`0000;ooooo0_l0
0003ooooo`;o00002Oooool2o`00013ooooo0_l00003ooooo`?o00001?ooool2o`000004ooooool0
003o0000ooooo`;o00001?ooool2o`0000Kooooo0_l00004ooooo`;o00000_ooool2o`00017ooooo
0_l00009ooooo`?o00001Oooool2o`0000Kooooo1?l00005ooooo`Co0000H?ooool001cooooo00?o
0000ooooooooool0GOooool2o`0000Sooooo0_l00009ooooo`;o00005Oooool2o`0000Gooooo0_l0
00001?oooooo0000o`000?ooool2o`0000Cooooo0_l00003ooooo`Go000000Coooooo`000?l0003o
oooo0_l00002ooooo`;o00003Oooool2o`0000Sooooo0_l00003ooooo`?o00005?ooool4o`0006;o
oooo000Looooo`;o0000D?ooool2o`0000;ooooo0_l0000dooooo`;o00001Oooool2o`0000oooooo
0ol00003ooooo`;o00001_ooool2o`0000cooooo0_l00008ooooo`;o00001?ooool6o`00013ooooo
1?l0001Rooooo`007?ooool00ol0003oooooooooo`1?ooooo`;o00000_ooool2o`0000kooooo0_l0
000Cooooo`;o0000:_ooool2o`0000Wooooo0_l0000Eooooo`;o00001oooool4o`0000[ooooo0_l0
0006ooooo`;o0000H_ooool001cooooo00?o0000ooooooooool0Eoooool2o`0000Sooooo1?l00006
ooooo`Co00002Oooool2o`0000Sooooo0_l0000?ooooo`;o00001Oooool2o`0000;ooooo0_l00004
ooooo`;o00008?ooool2o`0000;ooooo0_l00002ooooo`;o00002Oooool2o`0000;ooooo0_l0001Z
ooooo`007?ooool00ol0003oooooooooo`1Gooooo`;o00001Oooool2o`000003ooooool0003o0000
00Sooooo1?l0000Cooooo`;o00003oooool2o`0000Gooooo0_l00002ooooo`;o00000_ooool2o`00
00Sooooo1?l0000=ooooo`;o00002oooool2o`0000;ooooo0_l00009ooooo`;o00000_ooool2o`00
06[ooooo000Looooo`03o`000?oooooooooo05_ooooo0_l000000ooooooo0000o`000007ooooo`;o
00008?ooool6o`0000kooooo0_l00003ooooo`;o00000oooool2o`0000?ooooo1?l0000=ooooo`;o
00003oooool2o`000004ooooool0003o0000ooooo`;o00001oooool2o`0001Wooooo0ol0001>oooo
o`007?ooool00ol0003oooooooooo`1Kooooo`Co00002?ooool2o`00013ooooo0_l0000>ooooo`Ko
000000?oooooo`000?l000002oooool4o`0000Kooooo0ol0000Wooooo`;o000000?oooooo`000?l0
00008_ooool3o`0004kooooo000Looooo`03o`000?oooooooooo05cooooo1?l000000ooooooo0000
o`000002ooooo`;o00004_ooool2o`0001Cooooo0ol0000=ooooo`;o000000?oooooo`000?l00000
1?ooool2o`0000Sooooo1?l0000Looooo`?o0000M?ooool001cooooo00?o0000ooooooooool0G?oo
ool4o`000003ooooool0003o000000Co00004?ooool2o`0000gooooo0_l00007ooooo`;o00002_oo
ool4o`0000?ooooo0_l0000>ooooo`Go00006?ooool2o`000004ooooool0003o0000o`0000Gooooo
0_l000000ooooooo0000o`00001Zooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o00000ooo
ool2o`0000Sooooo0_l00007ooooo`?o00002?ooool2o`0000?ooooo0_l00004ooooo`;o00003Ooo
ool4o`0000Gooooo0ol0000>ooooo`;o000000?oooooo`000?l000004Oooool2o`0000;ooooo0_l0
0002ooooo`;o00001Oooool2o`000003ooooool0003o000000;o0000J?ooool001cooooo00?o0000
ooooooooool0G_ooool2o`0000Cooooo0_l00007ooooo`;o00001oooool2o`0000;ooooo0_l00005
ooooo`;o00000oooool2o`0000Cooooo0_l0000Fooooo`?o00004Oooool2o`0000gooooo0_l00002
ooooo`;o00004_ooool2o`0006Sooooo000Looooo`03o`000?oooooooooo06Cooooo0_l00007oooo
o`;o00002oooool2o`0000[ooooo0_l00003ooooo`;o00003oooool2o`0000[ooooo0_l00007oooo
o`;o00002?ooool2o`0000[ooooo0_l0000@ooooo`;o0000K_ooool001cooooo00?o0000oooooooo
ool0H_ooool2o`0000Sooooo0ol0000Looooo`Co00003Oooool2o`0000[ooooo1?l00005ooooo`;o
00002?ooool2o`0000_ooooo1?l0000:ooooo`;o000000?oooooo`000?l00000K_ooool001cooooo
00?o0000ooooooooool0H_ooool4o`0000Kooooo0ol00004ooooo`;o00000_ooool2o`0001Cooooo
1?l0000Iooooo`;o000000?oooooo`000?l000003?ooool3o`0000[ooooo1?l0000:ooooo`?o0000
L?ooool001cooooo00?o0000ooooooooool0I?ooool2o`0000gooooo0_l00002ooooo`?o00005Ooo
ool2o`0000Wooooo0_l000000ooooooo0000o`00000>ooooo`;o00003Oooool2o`0000Kooooo0_l0
0002ooooo`?o00000oooool2o`0000Oooooo0_l0001`ooooo`0000Koooooonk^k_lb<S;o0000oc8b
<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000oooooooo
ool0J?ooool2o`0000kooooo0_l00005ooooo`;o00006Oooool2o`000003ooooool0003o000002Go
oooo0_l00008ooooo`;o0000NOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q
8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo06Sooooo0_l0000A
ooooo`;o00000_ooool3o`000003ooooool0003o000000?ooooo0_l00006ooooo`;o00002oooool3
o`00027ooooo1?l00004ooooo`;o0000O_ooool00003ooooool@413ooooo00;ooooo00?o410@oooo
ooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0KOooool3
o`0000Kooooo0_l00003ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo0ol00002
ooooo`;o00000_ooool2o`0000?ooooo0_l00003ooooo`;o000000Coooooo`000?l0003o00004_oo
ool3o`0000cooooo1?l00004ooooo`;o0000O_ooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool02Oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0001Zooooo`;o000000Co
ooooo`000?l0003o00001_ooool2o`0000oooooo0_l00003ooooo`;o00001oooool2o`0000?ooooo
0_l00009ooooo`;o00000_ooool2o`000003ooooool0003o000000Cooooo0ol00008ooooo`;o0000
R_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Oo<c<co0000o`00
0?l0003oc<c<00Kooooo00?o0000ooooooooool0Goooool2o`0000Wooooo0_l000001?oooooo0000
o`000?ooool2o`0000Gooooo0_l0000/ooooo`;o00000_ooool5o`0000Gooooo0_l00005ooooo`Go
0000R_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol@413o^[Zj
oooooonj^[[o410@00Kooooo00?o0000ooooooooool0Goooool2o`0000?ooooo0_l00007ooooo`Go
00001Oooool4o`00013ooooo0_l00007ooooo`;o00000oooool2o`0000?ooooo0_l0000:ooooo`Co
00001Oooool2o`0000Gooooo1?l00006ooooo`;o0000Poooool00006oooooomgMgOoV9RHoooooonH
V9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0I?ooool2
o`0000Oooooo1?l00006ooooo`Co00002oooool2o`0000?ooooo0ol00006ooooo`;o00000oooool2
o`0000?ooooo0_l000000ooooooo0000o`000008ooooo`;o00002Oooool2o`0000;ooooo0_l00007
ooooo`?o0000Poooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`00
0?l@413oZJVY00Kooooo00?o0000ooooooooool0KOooool2o`0000Sooooo0_l00007ooooo`;o0000
1?ooool2o`000004ooooool0003o0000ooooo`;o00002_ooool3o`0000Kooooo0_l00008ooooo`Co
00001oooool2o`0000;ooooo0_l00007ooooo`;o00000_ooool2o`00083ooooo000Looooo`03o`00
0?oooooooooo07Cooooo0_l000000ooooooo0000o`000007ooooo`;o00001oooool2o`0000gooooo
1?l0000Aooooo`;o00002oooool2o`0000_ooooo0_l00020ooooo`007?ooool00ol0003ooooooooo
o`1dooooo`;o000000?oooooo`000?l000001?ooool2o`0000Kooooo0_l0000Cooooo`;o00000ooo
ool2o`0000Gooooo0_l0000Booooo`;o0000SOooool001cooooo00?o0000ooooooooool0K?ooool2
o`0000Cooooo0_l00009ooooo`;o000000?oooooo`000?l000000oooool2o`0000;ooooo0_l00003
ooooo`;o00003_ooool3o`0000Cooooo0ol00004ooooo`;o00003?ooool2o`0002Wooooo0_l0001R
ooooo`007?ooool00ol0003oooooooooo`1/ooooo`;o00001?ooool4o`0000Kooooo0_l00002oooo
o`?o000000?oooooo`000?l000000oooool2o`0000?ooooo0_l0000=ooooo`?o00001Oooool3o`00
00Cooooo0ol00004ooooo`;o00001Oooool2o`0002Wooooo0_l0001Rooooo`007?ooool00ol0003o
ooooooooo`1dooooo`;o00001_ooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool3o`00
00?ooooo0_l00005ooooo`;o00001oooool2o`0000Sooooo0_l00004ooooo`;o00001?ooool2o`00
00Gooooo0_l0002=ooooo`007?ooool00ol0003oooooooooo`1eooooo`;o00002_ooool2o`000004
ooooool0003o0000ooooo`?o00000oooool2o`0000Gooooo0_l0000Aooooo`Ko0000W?ooool001co
oooo00?o0000ooooooooool0MOooool2o`0000Cooooo0_l000000ooooooo0000o`000007ooooo`;o
00001_ooool2o`0000[ooooo0_l00006ooooo`;o00001?ooool4o`0009cooooo000Looooo`03o`00
0?oooooooooo07_ooooo0_l000000ooooooo0000o`000007ooooo`;o00001_ooool2o`0000;ooooo
0ol00005ooooo`;o00001_ooool2o`0000Wooooo1?l0002Gooooo`007?ooool00ol0003ooooooooo
o`1hooooo`;o00004_ooool2o`000003ooooool0003o000000;ooooo0ol0000;ooooo`Go00002?oo
ool4o`0009Oooooo000Looooo`03o`000?oooooooooo07Sooooo0_l0000Booooo`;o00004Oooool4
o`000003ooooool0003o000000?ooooo0_l0002Nooooo`007?ooool00ol0003oooooooooo`2Boooo
o`;o000000Coooooo`000?l0003o00000oooool6o`0000Sooooo0_l0002Nooooo`007?ooool2o`00
09?ooooo0_l000000ooooooo0000o`000002o`0000;ooooo1?l00003ooooo`;o000000Coooooo`00
0?l0003o0000XOooool001cooooo00?o0000ooooooooool0OOooool2o`0001?ooooo0_l00002oooo
o`?o00002Oooool2o`000004ooooool0003o0000o`00033ooooo0_l0001_ooooo`007?ooool00ol0
003oooooooooo`1mooooo`;o00004oooool2o`0000?ooooo0ol00005ooooo`;o0000=oooool2o`00
06oooooo000Looooo`03o`000?oooooooooo09Oooooo1?l000001?oooooo0000o`000?ooool3o`00
0:Oooooo000Looooo`03o`000?oooooooooo08;ooooo0_l0000Eooooo`;o000000Coooooo`000?l0
003ooooo0ol0002Wooooo`007?ooool00ol0003oooooooooo`1looooo`;o00001?ooool2o`0003oo
oooo0_l00024ooooo`007?ooool00ol0003oooooooooo`1looooo`;o00006_ooool2o`0000;ooooo
0_l0000Uooooo`;o0000Q?ooool001cooooo00?o0000ooooooooool0V?ooool2o`0000;ooooo0_l0
002[ooooo`007?ooool00ol0003oooooooooo`2Wooooo`;o0000X?ooool001cooooo00?o0000oooo
ooooool0V?ooool2o`0000gooooo0_l0002Pooooo`007?ooool00ol0003oooooooooo`2Hooooo`;o
0000[oooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000
`Oooool2o`0008Oooooo000Looooo`03o`000?oooooooooo0<3ooooo0_l00027ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0W?ooool2o`00013ooooo0_l0002Iooooo`007?ooool00ol0003ooooo
ooooo`2Looooo`;o00004?ooool2o`0009Wooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0
003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001;ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo
B_ooool001Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood[ooooo000D
ooooo`03o`000?oooooooooo00Gooooo0ol0003ooooood[ooooo000Dooooo`03o`000?oooooooooo
0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003ooooo
ooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001;ooooo00?oEEEE
ofIVI_l00000oooooomDooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00XOoo
ool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo01Kooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^1?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP2<ooooo`00X_ooool01Ol0003ooooooooooooooooo000000Wooooo
1_l0000<ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`09
ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg08cooooo002Rooooo`05o`000?oooooo
ooooooooool000006oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
2?ooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo08[ooooo002Rooooo`05o`00
0?ooooooooooooooool000002Oooool6o`0000cooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000Oooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooo
oooo08[ooooo002Rooooo`05o`000?n7QhOoooooojVYZOl000006oooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo
00Go0000ooooooooooooooooo`00002<ooooo`00XOooool00ol@413o0000ogMgM`02o`000003oiRH
V?oooooooooo01Wooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Co
oooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@08cooooo0032ooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03o`000?oooooooooo
00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`2<ooooo`00`?ooool00omEEEGoIVIVo`000004oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP2<ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1056) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.4783 .665 Mdot
.51106 .68676 Mdot
.58224 .34579 Mdot
.36857 .49224 Mdot
.58987 .76635 Mdot
.5929 .37235 Mdot
.68368 .55546 Mdot
.6373 .52476 Mdot
.575 .36148 Mdot
.56806 .60407 Mdot
.68532 .54089 Mdot
.32214 .46523 Mdot
.66945 .52949 Mdot
.38751 .49256 Mdot
.35666 .82728 Mdot
.42588 .56762 Mdot
.54479 .68558 Mdot
.38699 .31165 Mdot
.43384 .48174 Mdot
.58578 .3932 Mdot
.47629 .69675 Mdot
.37581 .49707 Mdot
.48665 .64918 Mdot
.38781 .49306 Mdot
.36765 .47803 Mdot
.53273 .67875 Mdot
.52726 .72472 Mdot
.34246 .51599 Mdot
.39189 .46636 Mdot
.63606 .53831 Mdot
.27077 .39233 Mdot
.43531 .84584 Mdot
.43616 .4667 Mdot
.80172 .54268 Mdot
.64302 .51787 Mdot
.41472 .77263 Mdot
.56273 .37884 Mdot
.64444 .53569 Mdot
.64816 .51656 Mdot
.65495 .56689 Mdot
.65165 .52341 Mdot
.52737 .68318 Mdot
.71883 .51977 Mdot
.61967 .5936 Mdot
.43459 .50763 Mdot
.63968 .69737 Mdot
.23255 .50687 Mdot
.393 .54489 Mdot
.54255 .68663 Mdot
.55185 .40515 Mdot
.77698 .56256 Mdot
.6846 .55878 Mdot
.63097 .33168 Mdot
.84807 .6612 Mdot
.64722 .5447 Mdot
.42976 .49083 Mdot
.55895 .36343 Mdot
.37519 .50715 Mdot
.38794 .49796 Mdot
.26894 .65972 Mdot
.33795 .51893 Mdot
.42136 .34199 Mdot
.49952 .6242 Mdot
.47448 .38058 Mdot
.56865 .37023 Mdot
.65684 .51562 Mdot
.50811 .69868 Mdot
.66646 .53491 Mdot
.34048 .45761 Mdot
.53443 .36266 Mdot
.39085 .54428 Mdot
.66729 .51815 Mdot
.51727 .7153 Mdot
.37653 .53614 Mdot
.68425 .28704 Mdot
.18176 .62869 Mdot
.40739 .36969 Mdot
.33399 .71716 Mdot
.28935 .698 Mdot
.5051 .27636 Mdot
.41097 .4871 Mdot
.31776 .26847 Mdot
.27344 .74456 Mdot
.49477 .64186 Mdot
.45516 .52312 Mdot
.59408 .455 Mdot
.37374 .53165 Mdot
.59733 .67935 Mdot
.42491 .49101 Mdot
.76567 .34058 Mdot
.58316 .35915 Mdot
.50677 .66106 Mdot
.37136 .48989 Mdot
.34189 .49353 Mdot
.27593 .5661 Mdot
.35801 .55545 Mdot
.34746 .5124 Mdot
.49449 .71065 Mdot
.69054 .53554 Mdot
.3236 .55507 Mdot
.69791 .49979 Mdot
.61773 .33218 Mdot
.40561 .55391 Mdot
.54532 .37789 Mdot
.50597 .7175 Mdot
.37224 .54141 Mdot
.66987 .5078 Mdot
.41549 .53502 Mdot
.75286 .55294 Mdot
.50883 .68909 Mdot
.34617 .48668 Mdot
.41773 .35454 Mdot
.55468 .19346 Mdot
.5022 .65827 Mdot
.5288 .25981 Mdot
.41919 .49463 Mdot
.35537 .51602 Mdot
.5125 .68445 Mdot
.59784 .33549 Mdot
.58796 .68427 Mdot
.51127 .63171 Mdot
.65078 .56776 Mdot
.50414 .6275 Mdot
.44073 .46589 Mdot
.58408 .36604 Mdot
.70066 .46943 Mdot
.62775 .45913 Mdot
.2689 .36377 Mdot
.37244 .5269 Mdot
.67373 .62905 Mdot
.61517 .36737 Mdot
.51444 .66759 Mdot
.66956 .5378 Mdot
.40286 .59399 Mdot
.49195 .67616 Mdot
.67106 .55225 Mdot
.3963 .3527 Mdot
.71544 .41916 Mdot
.53906 .6568 Mdot
.67142 .60031 Mdot
.7015 .517 Mdot
.67115 .56731 Mdot
.81389 .51566 Mdot
.51616 .69558 Mdot
.40133 .3257 Mdot
.66127 .54845 Mdot
.25558 .44254 Mdot
.40392 .45574 Mdot
.32822 .30261 Mdot
.28369 .25948 Mdot
.79986 .52746 Mdot
.72996 .38138 Mdot
.42174 .30472 Mdot
.68836 .56143 Mdot
.36446 .4701 Mdot
.53504 .69203 Mdot
.52822 .69299 Mdot
.35574 .54422 Mdot
.36537 .48748 Mdot
.38477 .5433 Mdot
.35461 .47356 Mdot
.24042 .65433 Mdot
.42121 .53549 Mdot
.2219 .35834 Mdot
.50676 .65438 Mdot
.35438 .49075 Mdot
.56251 .34928 Mdot
.35115 .45952 Mdot
.65538 .52002 Mdot
.36871 .50452 Mdot
.36445 .49389 Mdot
.33569 .50864 Mdot
.68728 .55585 Mdot
.42407 .82912 Mdot
.34716 .22189 Mdot
.5096 .80871 Mdot
.61644 .27695 Mdot
.60345 .37858 Mdot
.36535 .52854 Mdot
.4204 .32893 Mdot
.41923 .75454 Mdot
.40804 .4924 Mdot
.63882 .17528 Mdot
.35254 .50711 Mdot
.55646 .77404 Mdot
.46074 .48849 Mdot
.52956 .81283 Mdot
.31668 .28784 Mdot
.3703 .46291 Mdot
.30412 .57396 Mdot
.471 .73199 Mdot
.65669 .59623 Mdot
.65313 .52483 Mdot
.56886 .34553 Mdot
.56942 .35449 Mdot
.6112 .53501 Mdot
.49346 .60386 Mdot
.41934 .59846 Mdot
.32494 .52842 Mdot
.58008 .33162 Mdot
.4936 .62153 Mdot
.39679 .31162 Mdot
.49171 .7034 Mdot
.12767 .50632 Mdot
.7668 .54038 Mdot
.61552 .50584 Mdot
.40736 .36448 Mdot
.6014 .34455 Mdot
.61734 .33015 Mdot
.41929 .32144 Mdot
.40647 .52914 Mdot
.51341 .69985 Mdot
.79633 .62629 Mdot
.48614 .59515 Mdot
.82177 .58213 Mdot
.52293 .71092 Mdot
.58485 .59806 Mdot
.67663 .54642 Mdot
.57132 .38444 Mdot
.3528 .51644 Mdot
.39569 .52432 Mdot
.47641 .70138 Mdot
.38894 .54177 Mdot
.43061 .61575 Mdot
.34958 .52395 Mdot
.75181 .49692 Mdot
.40813 .37087 Mdot
.61139 .53561 Mdot
.26189 .3608 Mdot
.4842 .67537 Mdot
.38631 .2664 Mdot
.54462 .35769 Mdot
.39538 .75375 Mdot
.67333 .51879 Mdot
.40982 .35514 Mdot
.54564 .35458 Mdot
.39922 .30783 Mdot
.37487 .44897 Mdot
.63006 .35968 Mdot
.42644 .34765 Mdot
.34042 .7703 Mdot
.39488 .45382 Mdot
.23236 .64924 Mdot
.69464 .54652 Mdot
.51661 .63269 Mdot
.33843 .51915 Mdot
.58149 .38883 Mdot
.4425 .47616 Mdot
.70514 .33845 Mdot
.70426 .4716 Mdot
.63753 .35609 Mdot
.50423 .33465 Mdot
.40736 .35156 Mdot
.67638 .33585 Mdot
.68991 .61371 Mdot
.53975 .69577 Mdot
.41223 .55435 Mdot
.50076 .83488 Mdot
.66169 .54811 Mdot
.41148 .52491 Mdot
.74013 .47731 Mdot
.65899 .54572 Mdot
.37526 .50929 Mdot
.69684 .5236 Mdot
.52675 .69586 Mdot
.45069 .20862 Mdot
.54426 .68796 Mdot
.42349 .49135 Mdot
.67876 .50994 Mdot
.62378 .34173 Mdot
.53443 .67374 Mdot
.41023 .5385 Mdot
.35783 .53523 Mdot
.55977 .45552 Mdot
.35071 .49024 Mdot
.46711 .82104 Mdot
.3432 .49816 Mdot
.56448 .35233 Mdot
.35242 .55093 Mdot
.74739 .28039 Mdot
.64927 .43149 Mdot
.50904 .69919 Mdot
.6339 .36552 Mdot
.57168 .36001 Mdot
.48597 .23223 Mdot
.62859 .32195 Mdot
.41921 .50096 Mdot
.5962 .38542 Mdot
.36083 .29045 Mdot
.648 .55426 Mdot
.39529 .56161 Mdot
.59776 .59029 Mdot
.54244 .40354 Mdot
.59451 .32856 Mdot
.42843 .57769 Mdot
.52575 .72021 Mdot
.37063 .48941 Mdot
.59763 .3311 Mdot
.47986 .6292 Mdot
.42781 .50955 Mdot
.48381 .5322 Mdot
.55959 .4562 Mdot
.67219 .55763 Mdot
.46252 .52399 Mdot
.40913 .54711 Mdot
.55379 .37974 Mdot
.4931 .69745 Mdot
.63354 .52744 Mdot
.52746 .67216 Mdot
.66633 .75343 Mdot
.7478 .53607 Mdot
.28894 .71895 Mdot
.42677 .29376 Mdot
.74879 .36706 Mdot
.56253 .81309 Mdot
.64225 .25261 Mdot
.33635 .37895 Mdot
.71801 .73453 Mdot
.57583 .3385 Mdot
.75365 .4754 Mdot
.56834 .35934 Mdot
.38784 .47329 Mdot
.58062 .37038 Mdot
.55331 .81778 Mdot
.3482 .52117 Mdot
.57896 .37548 Mdot
.45612 .22273 Mdot
.35853 .49241 Mdot
.49949 .65844 Mdot
.33951 .80778 Mdot
.66779 .24776 Mdot
.78263 .52614 Mdot
.62428 .36224 Mdot
.30937 .4233 Mdot
.34539 .50891 Mdot
.33181 .52638 Mdot
.53855 .66829 Mdot
.36869 .55999 Mdot
.40027 .30888 Mdot
.40139 .3634 Mdot
.48977 .44074 Mdot
.36107 .23091 Mdot
.3173 .52669 Mdot
.53582 .67251 Mdot
.23608 .6047 Mdot
.69895 .29469 Mdot
.62941 .28698 Mdot
.68795 .5687 Mdot
.40026 .81727 Mdot
.46012 .60054 Mdot
.71691 .50624 Mdot
.60739 .5864 Mdot
.50408 .67235 Mdot
.44012 .83257 Mdot
.65096 .52884 Mdot
.3473 .62829 Mdot
.27517 .50533 Mdot
.4024 .52444 Mdot
.68271 .52746 Mdot
.31908 .47704 Mdot
.7245 .2765 Mdot
.21619 .5046 Mdot
.25 .32646 Mdot
.43171 .51282 Mdot
.66672 .28086 Mdot
.36124 .50872 Mdot
.5783 .71035 Mdot
.34215 .50114 Mdot
.52628 .66447 Mdot
.57051 .62645 Mdot
.51943 .44438 Mdot
.30198 .25545 Mdot
.76387 .54547 Mdot
.42078 .30435 Mdot
.35375 .52388 Mdot
.40213 .52323 Mdot
.39371 .33351 Mdot
.49926 .64494 Mdot
.35704 .47068 Mdot
.36106 .31706 Mdot
.3847 .53391 Mdot
.6468 .5259 Mdot
.23246 .37495 Mdot
.51804 .73287 Mdot
.35767 .56091 Mdot
.4807 .6356 Mdot
.66815 .55902 Mdot
.64288 .52049 Mdot
.40549 .58073 Mdot
.62994 .5535 Mdot
.3585 .50246 Mdot
.19909 .45735 Mdot
.51639 .6421 Mdot
.45946 .57028 Mdot
.48673 .65578 Mdot
.33444 .72409 Mdot
.66644 .50618 Mdot
.73454 .49199 Mdot
.31825 .55281 Mdot
.65508 .52744 Mdot
.74884 .57127 Mdot
.32417 .54283 Mdot
.42873 .55605 Mdot
.78582 .37749 Mdot
.62518 .35342 Mdot
.53765 .44663 Mdot
.6513 .50966 Mdot
.40501 .5479 Mdot
.39216 .56538 Mdot
.67006 .56059 Mdot
.29583 .6113 Mdot
.54513 .22682 Mdot
.3441 .51492 Mdot
.52105 .65488 Mdot
.51645 .66818 Mdot
.4339 .53171 Mdot
.41646 .5263 Mdot
.60469 .35342 Mdot
.63061 .36995 Mdot
.60866 .39102 Mdot
.55781 .45562 Mdot
.74225 .49417 Mdot
.67336 .70478 Mdot
.65594 .56689 Mdot
.6958 .64049 Mdot
.74619 .31806 Mdot
.39292 .43889 Mdot
.61307 .37808 Mdot
.40028 .51375 Mdot
.37034 .49403 Mdot
.63266 .52871 Mdot
.77016 .50255 Mdot
.38951 .41971 Mdot
.52225 .64146 Mdot
.64635 .51084 Mdot
.34587 .58234 Mdot
.72511 .65499 Mdot
.42446 .34511 Mdot
.80516 .47478 Mdot
.66635 .51662 Mdot
.50044 .66992 Mdot
.68492 .50976 Mdot
.39502 .52721 Mdot
.43176 .48737 Mdot
.51016 .6764 Mdot
.43042 .34825 Mdot
.33431 .48969 Mdot
.37204 .51068 Mdot
.44408 .15188 Mdot
.67573 .27681 Mdot
.69127 .47345 Mdot
.36185 .46922 Mdot
.39386 .56821 Mdot
.3939 .30707 Mdot
.38891 .53183 Mdot
.36256 .54392 Mdot
.49617 .18203 Mdot
.64514 .47356 Mdot
.38053 .32992 Mdot
.35537 .63476 Mdot
.52766 .70974 Mdot
.47356 .84406 Mdot
.57677 .38589 Mdot
.61714 .53522 Mdot
.55388 .21821 Mdot
.62993 .33489 Mdot
.7165 .33982 Mdot
.46166 .84555 Mdot
.54383 .45068 Mdot
.37242 .33713 Mdot
.36345 .42746 Mdot
.34556 .52837 Mdot
.36015 .513 Mdot
.41455 .3271 Mdot
.51986 .69724 Mdot
.49829 .42371 Mdot
.19804 .58594 Mdot
.36804 .50145 Mdot
.42684 .61288 Mdot
.34933 .78426 Mdot
.51822 .39532 Mdot
.40675 .30756 Mdot
.42634 .35607 Mdot
.35523 .52138 Mdot
.51264 .19152 Mdot
.53361 .67925 Mdot
.41077 .53786 Mdot
.42447 .5202 Mdot
.62614 .36076 Mdot
.50364 .68783 Mdot
.57516 .33809 Mdot
.73276 .49375 Mdot
.54322 .78544 Mdot
.46014 .14204 Mdot
.65184 .51217 Mdot
.45242 .80149 Mdot
.64057 .54758 Mdot
.30577 .28423 Mdot
.63191 .33374 Mdot
.41197 .49269 Mdot
.48905 .69054 Mdot
.41306 .53833 Mdot
.41181 .51268 Mdot
.40662 .52783 Mdot
.32529 .49115 Mdot
.66891 .20088 Mdot
.42727 .32582 Mdot
.36116 .56532 Mdot
.57267 .34932 Mdot
.45353 .80794 Mdot
.21391 .66731 Mdot
.39446 .51805 Mdot
.35941 .53342 Mdot
.49491 .66043 Mdot
.35901 .5492 Mdot
.64831 .5532 Mdot
.49472 .70033 Mdot
.34478 .48775 Mdot
.42224 .81501 Mdot
.38684 .46235 Mdot
.52599 .80656 Mdot
.6827 .50777 Mdot
.73738 .57974 Mdot
.33999 .55674 Mdot
.69403 .46771 Mdot
.53743 .44648 Mdot
.59469 .38853 Mdot
.63127 .51307 Mdot
.56298 .37758 Mdot
.19209 .52183 Mdot
.43007 .46806 Mdot
.36549 .47153 Mdot
.39607 .56421 Mdot
.60048 .38207 Mdot
.59785 .7072 Mdot
.68238 .36941 Mdot
.37057 .59436 Mdot
.60661 .36253 Mdot
.49147 .62568 Mdot
.4876 .37414 Mdot
.48666 .67887 Mdot
.38507 .35144 Mdot
.68409 .5387 Mdot
.4324 .32366 Mdot
.79103 .53222 Mdot
.50934 .68682 Mdot
.47986 .71048 Mdot
.59781 .37837 Mdot
.59245 .50539 Mdot
.79987 .70561 Mdot
.52084 .4152 Mdot
.30709 .33575 Mdot
.53468 .66119 Mdot
.41397 .4795 Mdot
.27604 .31655 Mdot
.5864 .52727 Mdot
.56216 .37549 Mdot
.40038 .4844 Mdot
.48115 .19935 Mdot
.6058 .35396 Mdot
.40035 .56057 Mdot
.60652 .33975 Mdot
.66656 .52094 Mdot
.61844 .35938 Mdot
.54944 .68631 Mdot
.3702 .53901 Mdot
.78069 .72609 Mdot
.416 .27399 Mdot
.34577 .49432 Mdot
.65086 .50865 Mdot
.49063 .49251 Mdot
.40416 .50477 Mdot
.38803 .33565 Mdot
.58973 .36652 Mdot
.54881 .42816 Mdot
.34284 .51166 Mdot
.60433 .37563 Mdot
.47992 .66147 Mdot
.63072 .51279 Mdot
.44529 .3915 Mdot
.71953 .47772 Mdot
.53992 .67342 Mdot
.7301 .54702 Mdot
.62899 .52353 Mdot
.38249 .56691 Mdot
.42217 .53694 Mdot
.51769 .65748 Mdot
.40627 .22975 Mdot
.34522 .54377 Mdot
.41081 .48708 Mdot
.57326 .34726 Mdot
.57367 .37961 Mdot
.41556 .22846 Mdot
.60222 .33587 Mdot
.42899 .47889 Mdot
.51921 .65907 Mdot
.37974 .48453 Mdot
.49568 .66657 Mdot
.37068 .55368 Mdot
.49114 .61344 Mdot
.50443 .64032 Mdot
.66577 .34152 Mdot
.38965 .4821 Mdot
.46465 .51278 Mdot
.4102 .52094 Mdot
.38521 .5395 Mdot
.59952 .35202 Mdot
.41183 .31123 Mdot
.39772 .58919 Mdot
.37637 .3317 Mdot
.39199 .32149 Mdot
.4795 .73921 Mdot
.62538 .35887 Mdot
.40662 .33449 Mdot
.2582 .69635 Mdot
.61768 .38172 Mdot
.42012 .33546 Mdot
.23801 .69557 Mdot
.64759 .51402 Mdot
.54588 .69032 Mdot
.35944 .49128 Mdot
.72108 .72681 Mdot
.21469 .45077 Mdot
.63174 .33872 Mdot
.34455 .49481 Mdot
.40091 .51036 Mdot
.50201 .63303 Mdot
.1784 .39019 Mdot
.54023 .38179 Mdot
.38109 .47132 Mdot
.50464 .69636 Mdot
.19638 .33868 Mdot
.55893 .35688 Mdot
.41873 .33234 Mdot
.68788 .55631 Mdot
.55346 .65627 Mdot
.62671 .45847 Mdot
.67782 .56014 Mdot
.65311 .39479 Mdot
.77614 .54363 Mdot
.41961 .49558 Mdot
.61205 .37865 Mdot
.81739 .47407 Mdot
.47242 .60342 Mdot
.70405 .56914 Mdot
.30541 .43555 Mdot
.50347 .66921 Mdot
.65029 .55314 Mdot
.42875 .31392 Mdot
.51615 .71289 Mdot
.50835 .6452 Mdot
.63061 .53745 Mdot
.4588 .42245 Mdot
.58322 .58386 Mdot
.64425 .52415 Mdot
.76799 .35263 Mdot
.71575 .70614 Mdot
.6087 .38433 Mdot
.39341 .32178 Mdot
.78661 .61833 Mdot
.52774 .68222 Mdot
.40355 .81796 Mdot
.81253 .45684 Mdot
.34745 .51213 Mdot
.40269 .33598 Mdot
.61902 .72037 Mdot
.19355 .56016 Mdot
.6568 .54573 Mdot
.53992 .46012 Mdot
.44179 .33398 Mdot
.34249 .52885 Mdot
.26694 .47847 Mdot
.3965 .47737 Mdot
.68127 .54547 Mdot
.26955 .67314 Mdot
.49966 .66976 Mdot
.63562 .51764 Mdot
.80472 .47725 Mdot
.36216 .50143 Mdot
.39604 .48177 Mdot
.25323 .38747 Mdot
.52647 .70234 Mdot
.58847 .38996 Mdot
.41912 .49701 Mdot
.37045 .50795 Mdot
.43893 .54978 Mdot
.45736 .56658 Mdot
.54635 .19281 Mdot
.38353 .47269 Mdot
.75171 .5127 Mdot
.3572 .56146 Mdot
.39008 .48483 Mdot
.48164 .63299 Mdot
.51436 .14275 Mdot
.73727 .49712 Mdot
.36832 .50595 Mdot
.4082 .4739 Mdot
.62961 .53782 Mdot
.55871 .56375 Mdot
.59343 .51022 Mdot
.5826 .45675 Mdot
.32517 .39559 Mdot
.32657 .4861 Mdot
.49415 .69126 Mdot
.41945 .35567 Mdot
.42983 .53713 Mdot
.49485 .69079 Mdot
.36469 .45832 Mdot
.60843 .35667 Mdot
.61974 .37997 Mdot
.68964 .60148 Mdot
.41293 .3366 Mdot
.23179 .42435 Mdot
.68531 .65124 Mdot
.57575 .34348 Mdot
.3652 .47496 Mdot
.61807 .52056 Mdot
.60089 .33042 Mdot
.60403 .45829 Mdot
.44376 .5673 Mdot
.53328 .68893 Mdot
.5053 .659 Mdot
.32982 .30084 Mdot
.72437 .40392 Mdot
.44133 .16727 Mdot
.67091 .52181 Mdot
.33347 .50712 Mdot
.67506 .62055 Mdot
.50364 .65874 Mdot
.28889 .31168 Mdot
.40705 .33688 Mdot
.6563 .54723 Mdot
.63057 .28912 Mdot
.49272 .6724 Mdot
.54382 .67167 Mdot
.41276 .47278 Mdot
.38103 .5157 Mdot
.33968 .36974 Mdot
.39807 .38954 Mdot
.66276 .55893 Mdot
.39282 .32986 Mdot
.54894 .35137 Mdot
.38944 .47089 Mdot
.49004 .64434 Mdot
.77048 .64853 Mdot
.41329 .48032 Mdot
.60296 .3507 Mdot
.50612 .66852 Mdot
.39552 .34171 Mdot
.38963 .32543 Mdot
.38519 .53827 Mdot
.24423 .6085 Mdot
.64996 .53875 Mdot
.49995 .65964 Mdot
.75457 .61429 Mdot
.34931 .54963 Mdot
.37574 .51797 Mdot
.43322 .4475 Mdot
.63421 .54461 Mdot
.71 .59678 Mdot
.43664 .34156 Mdot
.52161 .68936 Mdot
.37754 .46181 Mdot
.4187 .34216 Mdot
.69823 .60583 Mdot
.63554 .3496 Mdot
.61682 .353 Mdot
.38811 .3329 Mdot
.39684 .33188 Mdot
.39074 .34208 Mdot
.39273 .8181 Mdot
.55165 .67823 Mdot
.46972 .55843 Mdot
.33799 .53491 Mdot
.31941 .30289 Mdot
.37794 .59091 Mdot
.67467 .50235 Mdot
.62295 .34927 Mdot
.40972 .51512 Mdot
.42419 .49405 Mdot
.45845 .48903 Mdot
.46823 .53732 Mdot
.51604 .73063 Mdot
.507 .6888 Mdot
.41473 .44999 Mdot
.62853 .35507 Mdot
.1308 .47828 Mdot
.64723 .80531 Mdot
.34601 .56245 Mdot
.57792 .55383 Mdot
.49047 .64542 Mdot
.63683 .55513 Mdot
.59827 .47734 Mdot
.68949 .51567 Mdot
.51986 .6825 Mdot
.38797 .47149 Mdot
.69952 .64531 Mdot
.38769 .32221 Mdot
.39506 .54759 Mdot
.67036 .54865 Mdot
.38958 .54607 Mdot
.67924 .5596 Mdot
.63988 .75652 Mdot
.73562 .30112 Mdot
.35176 .50801 Mdot
.38391 .56984 Mdot
.31797 .4234 Mdot
.39424 .51602 Mdot
.46712 .3189 Mdot
.49163 .64658 Mdot
.39295 .20141 Mdot
.40327 .46127 Mdot
.38069 .7049 Mdot
.34505 .54699 Mdot
.48559 .20421 Mdot
.38049 .52011 Mdot
.51287 .38837 Mdot
.34384 .52194 Mdot
.3676 .54405 Mdot
.68368 .51216 Mdot
.63014 .53626 Mdot
.48143 .69847 Mdot
.58386 .38909 Mdot
.50552 .81534 Mdot
.37248 .51338 Mdot
.71908 .47658 Mdot
.72458 .50281 Mdot
.39584 .32761 Mdot
.52176 .68231 Mdot
.18135 .35684 Mdot
.69894 .54197 Mdot
.59542 .25533 Mdot
.40207 .24359 Mdot
.63376 .45859 Mdot
.59397 .46068 Mdot
.5833 .66608 Mdot
.41143 .3516 Mdot
.34131 .52865 Mdot
.79258 .56401 Mdot
.68322 .2936 Mdot
.42347 .59429 Mdot
.63586 .51478 Mdot
.40221 .74648 Mdot
.7801 .62868 Mdot
.43837 .34969 Mdot
.43455 .32742 Mdot
.68615 .55521 Mdot
.55402 .40309 Mdot
.34259 .44898 Mdot
.4079 .3399 Mdot
.59073 .33816 Mdot
.61033 .3857 Mdot
.62066 .29906 Mdot
.53128 .68402 Mdot
.79796 .49538 Mdot
.64771 .67945 Mdot
.67768 .55895 Mdot
.39957 .26998 Mdot
.55586 .67535 Mdot
.5414 .71222 Mdot
.58332 .3832 Mdot
.59781 .3497 Mdot
.54189 .7048 Mdot
.41513 .46419 Mdot
.4417 .45099 Mdot
.36647 .50395 Mdot
.41221 .32185 Mdot
.38735 .52088 Mdot
.60213 .35748 Mdot
.66049 .54161 Mdot
.58996 .35022 Mdot
.69975 .53241 Mdot
.68537 .69144 Mdot
.4051 .53838 Mdot
.36508 .53911 Mdot
.21268 .44826 Mdot
.47683 .66699 Mdot
.76695 .57337 Mdot
.75365 .49267 Mdot
.56889 .35718 Mdot
.36104 .54377 Mdot
.48213 .66725 Mdot
.42128 .3647 Mdot
.21125 .44639 Mdot
.41328 .54806 Mdot
.48901 .64881 Mdot
.37466 .46871 Mdot
.2922 .73213 Mdot
.64834 .22464 Mdot
.52423 .66979 Mdot
.27452 .27154 Mdot
.39152 .46753 Mdot
.56873 .64039 Mdot
.4131 .55806 Mdot
.34651 .3182 Mdot
.3473 .54579 Mdot
.52321 .71102 Mdot
.37326 .50194 Mdot
.50868 .71021 Mdot
.55705 .35496 Mdot
.64977 .565 Mdot
.53271 .6552 Mdot
.42498 .53237 Mdot
.50307 .87739 Mdot
.68163 .53888 Mdot
.35307 .51977 Mdot
.69297 .53493 Mdot
.50731 .70196 Mdot
.54299 .67607 Mdot
.18861 .58652 Mdot
.66606 .4696 Mdot
.66502 .52117 Mdot
.37741 .47374 Mdot
.61785 .65831 Mdot
.38374 .48009 Mdot
.32623 .36027 Mdot
.43835 .51573 Mdot
.35073 .54964 Mdot
.17965 .62386 Mdot
.64859 .5559 Mdot
.45899 .17061 Mdot
.20009 .60397 Mdot
.37911 .81169 Mdot
.53973 .63517 Mdot
.43623 .35135 Mdot
.43553 .83085 Mdot
.72921 .48929 Mdot
.60748 .3685 Mdot
.40926 .51729 Mdot
.53845 .72952 Mdot
.64367 .53842 Mdot
.41384 .31262 Mdot
.35154 .50892 Mdot
.59877 .34832 Mdot
.55707 .2363 Mdot
.68634 .56398 Mdot
.52671 .68355 Mdot
.51702 .63896 Mdot
.2394 .2893 Mdot
.37161 .4619 Mdot
.36116 .53941 Mdot
.68355 .54343 Mdot
.47288 .59551 Mdot
.40523 .35275 Mdot
.49666 .21473 Mdot
.66706 .52177 Mdot
.57105 .50209 Mdot
.51233 .69528 Mdot
.40115 .51214 Mdot
.59061 .72888 Mdot
.6184 .28244 Mdot
.40847 .64622 Mdot
.418 .32711 Mdot
.31928 .3663 Mdot
.52427 .7109 Mdot
.6685 .54191 Mdot
.72711 .42597 Mdot
.44958 .49031 Mdot
.39627 .50758 Mdot
.31367 .36711 Mdot
.48177 .42638 Mdot
.24501 .33549 Mdot
.40107 .55746 Mdot
.48856 .42384 Mdot
.38759 .55631 Mdot
.45267 .51929 Mdot
.42731 .4802 Mdot
.37176 .52263 Mdot
.48961 .64751 Mdot
.43132 .58547 Mdot
.61051 .3716 Mdot
.28012 .56787 Mdot
.57426 .46894 Mdot
.34327 .50492 Mdot
.38929 .47543 Mdot
.43219 .69067 Mdot
.71994 .5111 Mdot
.51832 .64721 Mdot
.46574 .65077 Mdot
.63449 .55912 Mdot
.45664 .47895 Mdot
.5674 .38896 Mdot
.43097 .5786 Mdot
.59491 .35278 Mdot
.48464 .65742 Mdot
.56482 .35774 Mdot
.6678 .56922 Mdot
.61553 .37734 Mdot
.7462 .49594 Mdot
.64607 .54871 Mdot
.5336 .69734 Mdot
.37789 .53558 Mdot
.64665 .51116 Mdot
.25972 .38529 Mdot
.41241 .32267 Mdot
.18835 .59363 Mdot
.37401 .45785 Mdot
.62506 .47057 Mdot
.48369 .52866 Mdot
.59031 .35145 Mdot
.59068 .19753 Mdot
.50694 .64037 Mdot
.38716 .3498 Mdot
.48362 .65853 Mdot
.79431 .36982 Mdot
.4037 .31384 Mdot
.24534 .70578 Mdot
.75096 .41464 Mdot
.5456 .41423 Mdot
.41191 .46178 Mdot
.27276 .48678 Mdot
.55013 .34853 Mdot
.64403 .53978 Mdot
.73647 .40007 Mdot
.37052 .54541 Mdot
.64551 .25971 Mdot
.48298 .70409 Mdot
.59322 .38708 Mdot
.66851 .53464 Mdot
.63715 .51821 Mdot
.41941 .53101 Mdot
.45002 .24538 Mdot
.39485 .55284 Mdot
.70887 .39831 Mdot
.32237 .38895 Mdot
.40125 .41925 Mdot
.35023 .52432 Mdot
.54671 .37315 Mdot
.37437 .4692 Mdot
.37941 .40234 Mdot
.80831 .52702 Mdot
.32595 .49524 Mdot
.76483 .50317 Mdot
.4162 .27701 Mdot
.51039 .68108 Mdot
.34372 .56579 Mdot
.65829 .46051 Mdot
.37461 .46365 Mdot
.83152 .35672 Mdot
.41994 .33756 Mdot
.68737 .45973 Mdot
.35486 .55795 Mdot
.42132 .51854 Mdot
.29216 .4841 Mdot
.55817 .718 Mdot
.62387 .28091 Mdot
.39007 .5059 Mdot
.28119 .4189 Mdot
.68532 .52853 Mdot
.40203 .55234 Mdot
.35779 .51497 Mdot
.49831 .7601 Mdot
.63404 .53286 Mdot
.57889 .35096 Mdot
.63 .33175 Mdot
.52797 .3766 Mdot
.397 .29824 Mdot
.55331 .4758 Mdot
.30369 .30826 Mdot
.66417 .24984 Mdot
.41009 .36034 Mdot
.39279 .46081 Mdot
.353 .41718 Mdot
.40702 .47613 Mdot
.42597 .31012 Mdot
.63442 .5384 Mdot
.51959 .64646 Mdot
.6368 .61168 Mdot
.53603 .35949 Mdot
.39604 .56183 Mdot
.406 .3039 Mdot
.53474 .69107 Mdot
.43683 .3657 Mdot
.51546 .68632 Mdot
.6638 .52425 Mdot
.62667 .5549 Mdot
.41933 .31103 Mdot
.48537 .6719 Mdot
.74059 .53125 Mdot
.20002 .56324 Mdot
.4387 .50941 Mdot
.63882 .58672 Mdot
.47853 .67212 Mdot
.5092 .72512 Mdot
.49014 .70487 Mdot
.39258 .54146 Mdot
.57533 .5541 Mdot
.43297 .55867 Mdot
.66667 .55837 Mdot
.60564 .34012 Mdot
.36651 .30239 Mdot
.71974 .69055 Mdot
.37512 .28896 Mdot
.3398 .48356 Mdot
.36723 .49913 Mdot
.35514 .52098 Mdot
.43076 .5007 Mdot
.70276 .41383 Mdot
.41286 .53193 Mdot
.68853 .51722 Mdot
.59168 .36157 Mdot
.33755 .51933 Mdot
.63428 .34547 Mdot
.59188 .65205 Mdot
.42133 .35603 Mdot
.54166 .46912 Mdot
.49208 .8529 Mdot
.53749 .68477 Mdot
.6026 .33512 Mdot
.60596 .37006 Mdot
.39678 .35293 Mdot
.64528 .53487 Mdot
.51605 .69272 Mdot
.35238 .3276 Mdot
.39086 .33642 Mdot
.37189 .50433 Mdot
.65789 .3458 Mdot
.63603 .26445 Mdot
.34892 .54037 Mdot
.40993 .50125 Mdot
.63767 .3546 Mdot
.54969 .40324 Mdot
.8291 .5934 Mdot
.26013 .33619 Mdot
.41543 .31028 Mdot
.42933 .34789 Mdot
.52887 .71903 Mdot
.38363 .5739 Mdot
.67055 .55804 Mdot
.22565 .38673 Mdot
.48633 .46703 Mdot
.23086 .41224 Mdot
.4499 .38951 Mdot
.41538 .54267 Mdot
.25364 .5785 Mdot
.36103 .50082 Mdot
.50275 .63703 Mdot
.51616 .70435 Mdot
.53056 .66039 Mdot
.64749 .54182 Mdot
.35394 .73503 Mdot
.67999 .51158 Mdot
.52305 .84512 Mdot
.52807 .7111 Mdot
.69338 .43722 Mdot
.55004 .37572 Mdot
.33395 .55048 Mdot
.40021 .34731 Mdot
.70857 .52124 Mdot
.34433 .45321 Mdot
.52433 .18977 Mdot
.60432 .37987 Mdot
.53387 .69845 Mdot
.58225 .66841 Mdot
.60247 .80018 Mdot
.59606 .48987 Mdot
.33585 .57614 Mdot
.2851 .48142 Mdot
.39522 .32483 Mdot
.40097 .64245 Mdot
.42086 .30309 Mdot
.66394 .55055 Mdot
.36771 .53673 Mdot
.37306 .53059 Mdot
.375 .55553 Mdot
.41015 .53404 Mdot
.63036 .54996 Mdot
.32807 .51742 Mdot
.7474 .28041 Mdot
.62159 .37927 Mdot
.32227 .75508 Mdot
.41735 .34662 Mdot
.63703 .51085 Mdot
.59327 .35987 Mdot
.63321 .37937 Mdot
.26785 .34765 Mdot
.34451 .51669 Mdot
.41057 .51753 Mdot
.60642 .26388 Mdot
.39579 .55872 Mdot
.33937 .57519 Mdot
.6054 .37371 Mdot
.37278 .2931 Mdot
.41083 .36302 Mdot
.4326 .32886 Mdot
.63732 .53052 Mdot
.48398 .66622 Mdot
.4093 .32959 Mdot
.55964 .35383 Mdot
.3537 .46428 Mdot
.42576 .51683 Mdot
.47833 .6757 Mdot
.81373 .45003 Mdot
.43981 .34709 Mdot
.58358 .6545 Mdot
.50326 .70506 Mdot
.55259 .6714 Mdot
.39606 .50576 Mdot
.4314 .59298 Mdot
.55327 .71278 Mdot
.39399 .35466 Mdot
.63239 .51489 Mdot
.58039 .44835 Mdot
.67408 .55121 Mdot
.52363 .69705 Mdot
.42965 .52153 Mdot
.52388 .70056 Mdot
.35821 .47279 Mdot
.37023 .85598 Mdot
.37531 .5258 Mdot
.68618 .25587 Mdot
.32894 .3271 Mdot
.59545 .37059 Mdot
.7419 .52722 Mdot
.58722 .38467 Mdot
.50801 .70717 Mdot
.42926 .53085 Mdot
.43572 .33976 Mdot
.33298 .78936 Mdot
.55554 .686 Mdot
.61181 .3576 Mdot
.56294 .39327 Mdot
.6431 .54889 Mdot
.3365 .52016 Mdot
.39812 .51238 Mdot
.57813 .3767 Mdot
.42796 .4267 Mdot
.49033 .66682 Mdot
.35812 .53432 Mdot
.38025 .4907 Mdot
.59635 .37212 Mdot
.20041 .55078 Mdot
.5699 .67608 Mdot
.36634 .5297 Mdot
.74005 .45527 Mdot
.67075 .50197 Mdot
.42144 .47725 Mdot
.32756 .53823 Mdot
.40029 .33828 Mdot
.37877 .78116 Mdot
.80628 .5402 Mdot
.6798 .50424 Mdot
.57739 .38734 Mdot
.37586 .46007 Mdot
.55064 .37749 Mdot
.42551 .52434 Mdot
.46055 .78932 Mdot
.60246 .38661 Mdot
.41835 .50496 Mdot
.35818 .56851 Mdot
.5239 .70441 Mdot
.41601 .52974 Mdot
.44893 .70634 Mdot
.57438 .33689 Mdot
.41899 .51639 Mdot
.24706 .61242 Mdot
.65101 .5172 Mdot
.34704 .56465 Mdot
.4265 .34549 Mdot
.35395 .31802 Mdot
.68079 .66318 Mdot
.73252 .47853 Mdot
.43043 .33679 Mdot
.38823 .54771 Mdot
.56747 .39474 Mdot
.6824 .55808 Mdot
.63524 .24306 Mdot
.36047 .5463 Mdot
.6811 .54453 Mdot
.66209 .54022 Mdot
.42623 .3385 Mdot
.38414 .18091 Mdot
.32756 .5322 Mdot
.39335 .51829 Mdot
.4687 .73787 Mdot
.496 .62841 Mdot
.38523 .52423 Mdot
.40484 .46905 Mdot
.691 .52192 Mdot
.32348 .56338 Mdot
.42028 .72996 Mdot
.45733 .22093 Mdot
.70225 .5239 Mdot
.52768 .42319 Mdot
.57832 .39267 Mdot
.4143 .34618 Mdot
.51146 .67364 Mdot
.44018 .32192 Mdot
.6214 .36615 Mdot
.39404 .46345 Mdot
.69633 .54248 Mdot
.4387 .63818 Mdot
.68239 .55975 Mdot
.71667 .47144 Mdot
.48225 .64892 Mdot
.65263 .62743 Mdot
.77025 .27828 Mdot
.65094 .68538 Mdot
.71106 .5033 Mdot
.39593 .32772 Mdot
.6494 .39501 Mdot
.37636 .49309 Mdot
.3654 .62852 Mdot
.38036 .53927 Mdot
.25391 .61523 Mdot
.60508 .3375 Mdot
.60754 .39179 Mdot
.36745 .53372 Mdot
.32446 .38104 Mdot
.67402 .56335 Mdot
.64874 .55474 Mdot
.41639 .51577 Mdot
.65499 .52715 Mdot
.38276 .51327 Mdot
.59913 .35406 Mdot
.50271 .16549 Mdot
.35881 .50738 Mdot
.42457 .5596 Mdot
.60125 .5249 Mdot
.19094 .62935 Mdot
.76596 .45615 Mdot
.25473 .56844 Mdot
.63176 .78731 Mdot
.65583 .52748 Mdot
.41739 .57628 Mdot
.5209 .41886 Mdot
.63801 .35234 Mdot
.73957 .53238 Mdot
.38567 .53031 Mdot
.38951 .53261 Mdot
.35943 .54146 Mdot
.3963 .48102 Mdot
.37388 .63329 Mdot
.46373 .59243 Mdot
.2867 .65814 Mdot
.41196 .515 Mdot
.26054 .49032 Mdot
.65235 .5097 Mdot
.47441 .69055 Mdot
.44047 .31868 Mdot
.41572 .54162 Mdot
.46011 .60605 Mdot
.66211 .50181 Mdot
.52542 .84462 Mdot
.63711 .54157 Mdot
.57107 .36097 Mdot
.64304 .56064 Mdot
.35096 .488 Mdot
.51617 .66718 Mdot
.57417 .45566 Mdot
.68042 .33789 Mdot
.60788 .36765 Mdot
.34563 .49451 Mdot
.67161 .45587 Mdot
.6108 .36852 Mdot
.59438 .65459 Mdot
.5119 .66556 Mdot
.27344 .42126 Mdot
.51667 .70476 Mdot
.4192 .50534 Mdot
.41548 .49402 Mdot
.7 .57862 Mdot
.66849 .56656 Mdot
.51266 .70525 Mdot
.42828 .153 Mdot
.41974 .30163 Mdot
.53125 .6647 Mdot
.43234 .46086 Mdot
.52439 .5346 Mdot
.51439 .65895 Mdot
.37227 .37439 Mdot
.64563 .54465 Mdot
.53009 .71386 Mdot
.43239 .45945 Mdot
.78573 .40715 Mdot
.38657 .3419 Mdot
.54165 .39136 Mdot
.56451 .32498 Mdot
.59132 .33161 Mdot
.6262 .52251 Mdot
.59666 .38077 Mdot
.6829 .52304 Mdot
.75689 .57812 Mdot
.24144 .50699 Mdot
.61555 .5249 Mdot
.62344 .53669 Mdot
.59798 .37768 Mdot
.35128 .5311 Mdot
.57797 .32733 Mdot
.43815 .53879 Mdot
.36609 .44305 Mdot
.67495 .51663 Mdot
.52481 .70961 Mdot
.54821 .68267 Mdot
.26571 .4875 Mdot
.51557 .63801 Mdot
.59611 .35157 Mdot
.65431 .2323 Mdot
.78792 .53806 Mdot
.68364 .53176 Mdot
.62606 .54109 Mdot
.38543 .47852 Mdot
.56235 .37682 Mdot
.54684 .36308 Mdot
.6575 .55295 Mdot
.33929 .60397 Mdot
.40889 .57245 Mdot
.49269 .71987 Mdot
.53062 .7106 Mdot
.52211 .66368 Mdot
.49592 .709 Mdot
.40643 .70167 Mdot
.64607 .54637 Mdot
.5191 .71141 Mdot
.41735 .50882 Mdot
.38902 .5314 Mdot
.58076 .45809 Mdot
.4323 .33298 Mdot
.36023 .46209 Mdot
.42311 .47057 Mdot
.39885 .50639 Mdot
.61705 .3556 Mdot
.40128 .43468 Mdot
.59122 .39015 Mdot
.54006 .3887 Mdot
.63073 .36448 Mdot
.73231 .49024 Mdot
.28863 .46758 Mdot
.66466 .77961 Mdot
.38094 .47108 Mdot
.4862 .59108 Mdot
.55234 .37315 Mdot
.56357 .19214 Mdot
.69348 .60464 Mdot
.36081 .54488 Mdot
.61635 .28439 Mdot
.58055 .3776 Mdot
.52251 .63923 Mdot
.38247 .52893 Mdot
.52457 .37488 Mdot
.41636 .3564 Mdot
.43928 .47864 Mdot
.61478 .32891 Mdot
.48817 .68107 Mdot
.42289 .29608 Mdot
.52267 .71589 Mdot
.63153 .35505 Mdot
.35483 .56743 Mdot
.81698 .68993 Mdot
.53223 .36956 Mdot
.2453 .68705 Mdot
.55082 .63999 Mdot
.35721 .53464 Mdot
.59685 .33369 Mdot
.49791 .62907 Mdot
.62662 .51884 Mdot
.50273 .46535 Mdot
.51747 .64287 Mdot
.60748 .39159 Mdot
.60927 .32904 Mdot
.6061 .3727 Mdot
.50482 .68378 Mdot
.43277 .53871 Mdot
.49813 .67688 Mdot
.64202 .55903 Mdot
.36665 .49072 Mdot
.55245 .81676 Mdot
.47926 .59081 Mdot
.5072 .70577 Mdot
.58767 .34583 Mdot
.39117 .31096 Mdot
.35228 .50387 Mdot
.22879 .65342 Mdot
.34702 .48622 Mdot
.68793 .53838 Mdot
.45508 .19404 Mdot
.43552 .6404 Mdot
.34081 .53967 Mdot
.38662 .47836 Mdot
.65636 .55792 Mdot
.34628 .51229 Mdot
.3425 .53968 Mdot
.71146 .48315 Mdot
.50348 .6902 Mdot
.37453 .49916 Mdot
.58885 .34105 Mdot
.77888 .57766 Mdot
.42243 .56759 Mdot
.53575 .25916 Mdot
.2906 .40422 Mdot
.42601 .18978 Mdot
.3771 .54078 Mdot
.24415 .36464 Mdot
.40223 .4866 Mdot
.39937 .54578 Mdot
.3795 .47659 Mdot
.25903 .56056 Mdot
.6112 .37689 Mdot
.60257 .36211 Mdot
.38767 .34534 Mdot
.28874 .40778 Mdot
.40252 .3377 Mdot
.6403 .53839 Mdot
.50914 .26546 Mdot
.60321 .38596 Mdot
.48775 .68179 Mdot
.38975 .55048 Mdot
.5327 .36515 Mdot
.40276 .51536 Mdot
.3535 .483 Mdot
.54464 .37727 Mdot
.53838 .37705 Mdot
.70446 .46885 Mdot
.42428 .35158 Mdot
.53027 .65573 Mdot
.3863 .44926 Mdot
.39313 .3195 Mdot
.43072 .54013 Mdot
.31874 .29692 Mdot
.52724 .65422 Mdot
.50175 .68741 Mdot
.54259 .6597 Mdot
.3931 .46328 Mdot
.34755 .49776 Mdot
.68028 .51249 Mdot
.48448 .6746 Mdot
.64884 .51995 Mdot
.56088 .45436 Mdot
.52103 .24968 Mdot
.38582 .5304 Mdot
.5741 .63264 Mdot
.40479 .34648 Mdot
.58064 .35838 Mdot
.57189 .24775 Mdot
.3844 .33642 Mdot
.34928 .48413 Mdot
.54656 .37498 Mdot
.42626 .31316 Mdot
.30698 .55921 Mdot
.72936 .73402 Mdot
.3991 .30256 Mdot
.41652 .5099 Mdot
.30093 .51106 Mdot
.20974 .4994 Mdot
.3985 .29889 Mdot
.69305 .54241 Mdot
.39161 .46214 Mdot
.47799 .55464 Mdot
.44023 .34333 Mdot
.7643 .58932 Mdot
.58862 .36958 Mdot
.78956 .46163 Mdot
.36746 .43599 Mdot
.32424 .60665 Mdot
.43386 .31313 Mdot
.51866 .69116 Mdot
.47608 .64009 Mdot
.39663 .49715 Mdot
.40202 .29628 Mdot
.70363 .5359 Mdot
.58441 .367 Mdot
.7467 .50209 Mdot
.50337 .68105 Mdot
.60256 .62167 Mdot
.60385 .3425 Mdot
.58094 .63376 Mdot
.46481 .20711 Mdot
.41226 .42308 Mdot
.24127 .55054 Mdot
.6967 .31156 Mdot
.3969 .46023 Mdot
.41298 .30062 Mdot
.67012 .50326 Mdot
.69255 .5502 Mdot
.66959 .52381 Mdot
.74395 .52186 Mdot
.58857 .47516 Mdot
.62707 .34236 Mdot
.66852 .31086 Mdot
.417 .34207 Mdot
.24892 .45671 Mdot
.42475 .54421 Mdot
.36552 .50073 Mdot
.33453 .50423 Mdot
.40409 .55361 Mdot
.397 .48854 Mdot
.64763 .53008 Mdot
.7458 .51978 Mdot
.55272 .43079 Mdot
.51864 .653 Mdot
.37929 .28807 Mdot
.55006 .37537 Mdot
.63482 .36366 Mdot
.42404 .31965 Mdot
.58385 .69266 Mdot
.62144 .33547 Mdot
.56787 .35625 Mdot
.34539 .48361 Mdot
.49343 .67525 Mdot
.42455 .58838 Mdot
.41004 .48665 Mdot
.58723 .35752 Mdot
.47746 .37992 Mdot
.43437 .71901 Mdot
.45739 .51572 Mdot
.43387 .29734 Mdot
.56817 .55071 Mdot
.4001 .29871 Mdot
.42189 .55491 Mdot
.54604 .18729 Mdot
.62035 .36781 Mdot
.564 .36923 Mdot
.41475 .30334 Mdot
.57017 .65196 Mdot
.50603 .6722 Mdot
.63319 .38 Mdot
.69038 .53051 Mdot
.41249 .48389 Mdot
.53907 .23866 Mdot
.55909 .63204 Mdot
.47016 .24607 Mdot
.67646 .52663 Mdot
.54914 .36306 Mdot
.33635 .52388 Mdot
.41564 .50832 Mdot
.39407 .3302 Mdot
.61303 .76249 Mdot
.43162 .46849 Mdot
.38238 .81401 Mdot
.74634 .31099 Mdot
.80154 .42753 Mdot
.39617 .50773 Mdot
.50494 .68971 Mdot
.63184 .33393 Mdot
.39315 .32352 Mdot
.34469 .46918 Mdot
.70939 .75014 Mdot
.47505 .67942 Mdot
.66628 .54723 Mdot
.52216 .42691 Mdot
.59936 .47695 Mdot
.36571 .46263 Mdot
.38019 .53813 Mdot
.39936 .53981 Mdot
.79493 .65423 Mdot
.61142 .35059 Mdot
.49048 .64178 Mdot
.41936 .32546 Mdot
.51256 .63745 Mdot
.60067 .36639 Mdot
.6223 .62598 Mdot
.34126 .51306 Mdot
.47565 .67813 Mdot
.51835 .68772 Mdot
.6422 .54767 Mdot
.62294 .52809 Mdot
.54684 .44128 Mdot
.37534 .52446 Mdot
.57636 .33259 Mdot
.52715 .70443 Mdot
.65069 .33801 Mdot
.40178 .31541 Mdot
.66404 .50692 Mdot
.41204 .51727 Mdot
.61665 .36855 Mdot
.32753 .51464 Mdot
.50555 .65508 Mdot
.56649 .35715 Mdot
.70018 .46845 Mdot
.42886 .34719 Mdot
.40125 .52921 Mdot
.44401 .31233 Mdot
.57492 .38718 Mdot
.3787 .49059 Mdot
.5703 .71817 Mdot
.40926 .28705 Mdot
.68387 .36195 Mdot
.62357 .342 Mdot
.71487 .47552 Mdot
.54445 .66794 Mdot
.74682 .60482 Mdot
.56775 .36685 Mdot
.57151 .7213 Mdot
.66496 .72498 Mdot
.38127 .44789 Mdot
.52757 .67765 Mdot
.64608 .3853 Mdot
.45597 .85489 Mdot
.21209 .56318 Mdot
.3539 .51862 Mdot
.60838 .33617 Mdot
.40819 .30513 Mdot
.68338 .53052 Mdot
.53636 .2576 Mdot
.37944 .40301 Mdot
.5532 .38927 Mdot
.38255 .47503 Mdot
.51056 .70087 Mdot
.65278 .54391 Mdot
.70352 .65429 Mdot
.56935 .3494 Mdot
.61203 .3416 Mdot
.33714 .52791 Mdot
.40815 .3367 Mdot
.22608 .61091 Mdot
.60264 .35501 Mdot
.61507 .26876 Mdot
.65516 .3923 Mdot
.40526 .3036 Mdot
.40774 .49408 Mdot
.27166 .47593 Mdot
.42826 .49287 Mdot
.26331 .71576 Mdot
.57919 .38524 Mdot
.51376 .64953 Mdot
.38445 .5427 Mdot
.44486 .22256 Mdot
.58401 .36058 Mdot
.57893 .55204 Mdot
.49832 .34712 Mdot
.64642 .54588 Mdot
.57857 .24752 Mdot
.39236 .52303 Mdot
.67742 .56221 Mdot
.40452 .34589 Mdot
.36718 .5252 Mdot
.34943 .49576 Mdot
.50673 .63159 Mdot
.66472 .55174 Mdot
.68582 .72929 Mdot
.63424 .51932 Mdot
.68348 .50861 Mdot
.54019 .64885 Mdot
.3849 .50084 Mdot
.57253 .35851 Mdot
.57733 .37818 Mdot
.35993 .45037 Mdot
.57561 .18416 Mdot
.50415 .67266 Mdot
.40154 .26984 Mdot
.80505 .6345 Mdot
.39725 .42118 Mdot
.56724 .24566 Mdot
.60999 .76214 Mdot
.70278 .5389 Mdot
.41472 .51561 Mdot
.49461 .69447 Mdot
.62971 .38428 Mdot
.60136 .34113 Mdot
.43282 .52819 Mdot
.65762 .53901 Mdot
.40936 .35825 Mdot
.54554 .35531 Mdot
.45141 .24455 Mdot
.4065 .54029 Mdot
.65648 .28274 Mdot
.58287 .33607 Mdot
.36606 .82242 Mdot
.64862 .3603 Mdot
.52783 .67268 Mdot
.35456 .48342 Mdot
.52011 .64087 Mdot
.41489 .32012 Mdot
.53272 .43226 Mdot
.65909 .54067 Mdot
.38096 .41482 Mdot
.82642 .37672 Mdot
.60261 .37881 Mdot
.49168 .64597 Mdot
.3407 .54008 Mdot
.34406 .42665 Mdot
.38875 .51885 Mdot
.30455 .50568 Mdot
.42233 .27909 Mdot
.66827 .51454 Mdot
.68976 .54019 Mdot
.37331 .49169 Mdot
.39659 .34853 Mdot
.5509 .36291 Mdot
.58154 .36695 Mdot
.1491 .60514 Mdot
.64969 .3266 Mdot
.34154 .36399 Mdot
.39346 .53205 Mdot
.59915 .39365 Mdot
.74592 .66113 Mdot
.6839 .54209 Mdot
.42014 .54947 Mdot
.57227 .38965 Mdot
.76264 .35829 Mdot
.35604 .28999 Mdot
.40011 .49067 Mdot
.32026 .50496 Mdot
.6916 .53333 Mdot
.24439 .41664 Mdot
.63029 .3572 Mdot
.43991 .52411 Mdot
.64697 .56823 Mdot
.42144 .21816 Mdot
.81303 .4983 Mdot
.5306 .65631 Mdot
.52064 .39252 Mdot
.6471 .53067 Mdot
.38424 .43753 Mdot
.42049 .34601 Mdot
.56164 .34209 Mdot
.6152 .3579 Mdot
.37163 .47634 Mdot
.32912 .52121 Mdot
.32061 .42563 Mdot
.49458 .64637 Mdot
.64648 .51347 Mdot
.36925 .54044 Mdot
.59814 .60498 Mdot
.37995 .55603 Mdot
.67075 .50968 Mdot
.78018 .75118 Mdot
.39335 .44712 Mdot
.38982 .51719 Mdot
.22232 .6067 Mdot
.51943 .64336 Mdot
.51587 .6365 Mdot
.70561 .27584 Mdot
.39422 .53184 Mdot
.60214 .25574 Mdot
.53175 .6556 Mdot
.50369 .66809 Mdot
.65595 .43737 Mdot
.35577 .50488 Mdot
.2177 .43783 Mdot
.68262 .55593 Mdot
.6934 .52054 Mdot
.4994 .6769 Mdot
.41167 .44975 Mdot
.69989 .5444 Mdot
.39304 .65536 Mdot
.56208 .37766 Mdot
.52971 .18331 Mdot
.50183 .65278 Mdot
.52766 .44721 Mdot
.68177 .53273 Mdot
.51914 .84584 Mdot
.62745 .29448 Mdot
.35528 .53475 Mdot
.40237 .53217 Mdot
.40824 .34783 Mdot
.38539 .44833 Mdot
.60951 .3909 Mdot
.65473 .52693 Mdot
.25386 .66742 Mdot
.53121 .66168 Mdot
.3782 .5201 Mdot
.58763 .6533 Mdot
.69029 .67865 Mdot
.76218 .42265 Mdot
.51108 .68106 Mdot
.53075 .6815 Mdot
.62923 .35312 Mdot
.59955 .3359 Mdot
.39097 .49689 Mdot
.66212 .55714 Mdot
.48718 .6842 Mdot
.67415 .51236 Mdot
.62077 .36588 Mdot
.5734 .35528 Mdot
.60439 .38646 Mdot
.44304 .52901 Mdot
.57293 .35024 Mdot
.43664 .24434 Mdot
.60723 .62761 Mdot
.54094 .71315 Mdot
.83553 .45343 Mdot
.70475 .65213 Mdot
.48101 .48849 Mdot
.43732 .33762 Mdot
.57343 .38711 Mdot
.63214 .54885 Mdot
.38534 .48087 Mdot
.40709 .51637 Mdot
.52278 .37959 Mdot
.65188 .56201 Mdot
.41336 .31435 Mdot
.65958 .56485 Mdot
.42609 .34047 Mdot
.62895 .2852 Mdot
.33603 .51654 Mdot
.42379 .51033 Mdot
.65116 .52591 Mdot
.5683 .35416 Mdot
.59505 .36212 Mdot
.40456 .29809 Mdot
.47799 .43599 Mdot
.6098 .37157 Mdot
.50267 .6534 Mdot
.39413 .69332 Mdot
.62056 .33012 Mdot
.38365 .52708 Mdot
.30141 .30583 Mdot
.37848 .62793 Mdot
.43388 .50937 Mdot
.65255 .4605 Mdot
.23053 .33348 Mdot
.3809 .54706 Mdot
.24332 .30604 Mdot
.71751 .47718 Mdot
.51508 .64137 Mdot
.61186 .33861 Mdot
.62787 .38361 Mdot
.32473 .55797 Mdot
.41734 .38012 Mdot
.35555 .45638 Mdot
.5261 .64677 Mdot
.48218 .62976 Mdot
.78036 .37108 Mdot
.24684 .69039 Mdot
.42558 .30714 Mdot
.42768 .32099 Mdot
.56946 .36826 Mdot
.17577 .53406 Mdot
.45454 .5063 Mdot
.4155 .31136 Mdot
.23855 .49561 Mdot
.38656 .47309 Mdot
.31373 .35778 Mdot
.60594 .27805 Mdot
.50355 .68523 Mdot
.27199 .48474 Mdot
.57476 .36294 Mdot
.49951 .64283 Mdot
.61738 .60625 Mdot
.36491 .46049 Mdot
.52753 .65559 Mdot
.6794 .51395 Mdot
.71781 .34463 Mdot
.54248 .67452 Mdot
.30916 .2983 Mdot
.65752 .55387 Mdot
.65445 .40762 Mdot
.26056 .45252 Mdot
.68765 .18458 Mdot
.64973 .53154 Mdot
.54828 .38316 Mdot
.57809 .3776 Mdot
.58 .36784 Mdot
.50248 .63975 Mdot
.54444 .36698 Mdot
.49162 .64963 Mdot
.20217 .51316 Mdot
.47763 .43704 Mdot
.41789 .3099 Mdot
.67091 .47169 Mdot
.52451 .68761 Mdot
.63011 .21881 Mdot
.78719 .30508 Mdot
.41608 .52015 Mdot
.6297 .52946 Mdot
.42326 .30877 Mdot
.31538 .78544 Mdot
.40251 .34182 Mdot
.51902 .40148 Mdot
.48788 .17947 Mdot
.37784 .51443 Mdot
.41203 .75889 Mdot
.43496 .33918 Mdot
.51311 .69339 Mdot
.37428 .49368 Mdot
.73523 .54158 Mdot
.40879 .34229 Mdot
.41034 .35716 Mdot
.38741 .49226 Mdot
.53348 .69908 Mdot
.57774 .35549 Mdot
.64432 .5647 Mdot
.38023 .32671 Mdot
.50293 .60569 Mdot
.39763 .45565 Mdot
.38253 .45846 Mdot
.59126 .51118 Mdot
.36956 .39829 Mdot
.65562 .52811 Mdot
.22121 .48894 Mdot
.60065 .3365 Mdot
.61734 .41524 Mdot
.71274 .28767 Mdot
.66601 .46631 Mdot
.58518 .3839 Mdot
.58253 .38668 Mdot
.39621 .49118 Mdot
.36167 .39769 Mdot
.43734 .1962 Mdot
.68251 .48712 Mdot
.62693 .33259 Mdot
.58416 .36541 Mdot
.47597 .64596 Mdot
.78326 .36906 Mdot
.34067 .47553 Mdot
.68669 .50702 Mdot
.61664 .36622 Mdot
.4633 .79015 Mdot
.41176 .33521 Mdot
.59168 .205 Mdot
.33775 .52182 Mdot
.36466 .53882 Mdot
.66734 .53078 Mdot
.68103 .51173 Mdot
.70564 .57966 Mdot
.76411 .33165 Mdot
.21089 .40165 Mdot
.74173 .63217 Mdot
.46146 .78357 Mdot
.47338 .68242 Mdot
.50847 .70613 Mdot
.73654 .50125 Mdot
.64556 .5089 Mdot
.38424 .54512 Mdot
.4882 .68509 Mdot
.74407 .40027 Mdot
.4653 .62586 Mdot
.3255 .36408 Mdot
.50058 .22831 Mdot
.35347 .47877 Mdot
.49492 .6846 Mdot
.51273 .64352 Mdot
.491 .69797 Mdot
.71765 .47789 Mdot
.39009 .50656 Mdot
.34756 .52071 Mdot
.37693 .55146 Mdot
.4452 .59931 Mdot
.41238 .53557 Mdot
.67877 .48235 Mdot
.57227 .50816 Mdot
.31447 .73688 Mdot
.43404 .49966 Mdot
.70089 .53246 Mdot
.38095 .45482 Mdot
.39725 .35029 Mdot
.38181 .47709 Mdot
.33005 .36026 Mdot
.67663 .54306 Mdot
.56277 .65195 Mdot
.74096 .62708 Mdot
.33948 .51635 Mdot
.41154 .36118 Mdot
.47848 .52159 Mdot
.63484 .7612 Mdot
.39749 .38787 Mdot
.5021 .65414 Mdot
.56611 .38152 Mdot
.63959 .55491 Mdot
.5674 .36091 Mdot
.43976 .50602 Mdot
.64018 .45969 Mdot
.61965 .71231 Mdot
.52005 .43512 Mdot
.41234 .54706 Mdot
.40996 .4322 Mdot
.50246 .66019 Mdot
.54673 .37538 Mdot
.49335 .72907 Mdot
.39 .5407 Mdot
.41592 .32487 Mdot
.41224 .34364 Mdot
.70449 .59264 Mdot
.50227 .80716 Mdot
.74392 .59755 Mdot
.66517 .52898 Mdot
.60533 .35425 Mdot
.43135 .3089 Mdot
.50713 .59532 Mdot
.64651 .50187 Mdot
.65451 .55777 Mdot
.65934 .5506 Mdot
.39906 .46865 Mdot
.59105 .39027 Mdot
.30386 .72314 Mdot
.60532 .3917 Mdot
.34451 .50518 Mdot
.61239 .34901 Mdot
.59327 .38745 Mdot
.41349 .34889 Mdot
.6367 .53167 Mdot
.62365 .3592 Mdot
.41987 .50676 Mdot
.5387 .67455 Mdot
.49362 .43451 Mdot
.33735 .31065 Mdot
.29746 .74712 Mdot
.32192 .76289 Mdot
.5406 .69701 Mdot
.49456 .8311 Mdot
.69246 .50665 Mdot
.33596 .60222 Mdot
.72086 .45566 Mdot
.42903 .51401 Mdot
.65042 .2179 Mdot
.6281 .34287 Mdot
.5455 .37899 Mdot
.40719 .49108 Mdot
.53872 .39925 Mdot
.38165 .5191 Mdot
.61829 .34888 Mdot
.37772 .29256 Mdot
.33322 .55753 Mdot
.56028 .35642 Mdot
.43915 .5438 Mdot
.35548 .50022 Mdot
.5025 .68598 Mdot
.59528 .33308 Mdot
.41766 .55232 Mdot
.22554 .70772 Mdot
.67195 .50792 Mdot
.67841 .46404 Mdot
.30037 .2907 Mdot
.64623 .53012 Mdot
.52903 .66331 Mdot
.36482 .44436 Mdot
.39782 .34087 Mdot
.52316 .69425 Mdot
.3701 .27121 Mdot
.43415 .33649 Mdot
.64682 .2222 Mdot
.49866 .65761 Mdot
.61806 .33022 Mdot
.41607 .35134 Mdot
.42617 .56878 Mdot
.55205 .34891 Mdot
.49155 .4745 Mdot
.57587 .38477 Mdot
.39852 .51345 Mdot
.75201 .50809 Mdot
.66046 .5064 Mdot
.35604 .51893 Mdot
.54274 .35931 Mdot
.73503 .49293 Mdot
.39454 .46826 Mdot
.39054 .48235 Mdot
.81203 .44151 Mdot
.59797 .22524 Mdot
.39693 .32216 Mdot
.49121 .6348 Mdot
.41752 .50862 Mdot
.42114 .35272 Mdot
.49138 .30748 Mdot
.39059 .4576 Mdot
.47775 .68569 Mdot
.45794 .55096 Mdot
.5654 .34374 Mdot
.64509 .52159 Mdot
.54831 .44939 Mdot
.41754 .35598 Mdot
.35332 .17815 Mdot
.60942 .38554 Mdot
.41939 .55654 Mdot
.40974 .55143 Mdot
.76849 .44898 Mdot
.50475 .64307 Mdot
.21491 .40034 Mdot
.40144 .52944 Mdot
.45849 .57065 Mdot
.36604 .52212 Mdot
.56631 .41628 Mdot
.50501 .6713 Mdot
.39419 .51743 Mdot
.57578 .61824 Mdot
.41834 .56684 Mdot
.4145 .35896 Mdot
.21375 .5791 Mdot
.39994 .46067 Mdot
.87924 .57807 Mdot
.59421 .25683 Mdot
.563 .35456 Mdot
.75383 .51475 Mdot
.14825 .46459 Mdot
.75498 .58329 Mdot
.48985 .65046 Mdot
.60747 .75486 Mdot
.57302 .35753 Mdot
.76413 .60284 Mdot
.48446 .83954 Mdot
.35655 .49774 Mdot
.36495 .4632 Mdot
.51903 .40166 Mdot
.61021 .39205 Mdot
.59628 .32766 Mdot
.43435 .49391 Mdot
.45355 .52987 Mdot
.58206 .34622 Mdot
.42129 .51808 Mdot
.4252 .58022 Mdot
.63854 .5606 Mdot
.54042 .69302 Mdot
.67854 .52247 Mdot
.63622 .54281 Mdot
.31285 .62148 Mdot
.76349 .33809 Mdot
.66755 .50876 Mdot
.69282 .50771 Mdot
.31914 .35269 Mdot
.30455 .43544 Mdot
.43978 .34155 Mdot
.43778 .82178 Mdot
.58107 .3698 Mdot
.38737 .50607 Mdot
.54271 .69852 Mdot
.30814 .59635 Mdot
.56301 .27051 Mdot
.45284 .18716 Mdot
.38839 .54309 Mdot
.57968 .36289 Mdot
.7223 .47947 Mdot
.41836 .59169 Mdot
.62328 .42422 Mdot
.36235 .5403 Mdot
.53428 .36331 Mdot
.38808 .72105 Mdot
.58413 .67319 Mdot
.65844 .35734 Mdot
.47128 .69344 Mdot
.37246 .53647 Mdot
.50287 .64993 Mdot
.67506 .52326 Mdot
.40244 .351 Mdot
.39794 .32197 Mdot
.38293 .48946 Mdot
.44546 .45524 Mdot
.61288 .28673 Mdot
.35198 .50285 Mdot
.37269 .48036 Mdot
.71786 .47727 Mdot
.37167 .48273 Mdot
.40482 .55213 Mdot
.39222 .5536 Mdot
.38361 .56811 Mdot
.68617 .51093 Mdot
.58629 .65006 Mdot
.44224 .50387 Mdot
.42009 .58811 Mdot
.66887 .57048 Mdot
.63483 .74687 Mdot
.63332 .53733 Mdot
.55653 .81656 Mdot
.68712 .53473 Mdot
.40642 .3131 Mdot
.75634 .48762 Mdot
.42711 .43774 Mdot
.51085 .71277 Mdot
.63985 .50743 Mdot
.42458 .33083 Mdot
.66221 .52366 Mdot
.60753 .3437 Mdot
.81834 .57911 Mdot
.47638 .62127 Mdot
.23208 .37113 Mdot
.71427 .58659 Mdot
.66853 .3336 Mdot
.62208 .37134 Mdot
.50218 .67402 Mdot
.43771 .72831 Mdot
.39302 .5557 Mdot
.42228 .35065 Mdot
.39127 .49297 Mdot
.68023 .50583 Mdot
.57517 .36555 Mdot
.20802 .57329 Mdot
.39471 .33383 Mdot
.82083 .43064 Mdot
.59121 .36857 Mdot
.36688 .55274 Mdot
.68767 .50799 Mdot
.83777 .42907 Mdot
.6736 .51721 Mdot
.45452 .43351 Mdot
.49106 .71489 Mdot
.24388 .55812 Mdot
.52577 .68109 Mdot
.63999 .34759 Mdot
.82587 .62537 Mdot
.39344 .80949 Mdot
.53644 .6909 Mdot
.65326 .31181 Mdot
.37102 .46199 Mdot
.38225 .4574 Mdot
.57776 .67712 Mdot
.48341 .64877 Mdot
.4165 .52466 Mdot
.69417 .46675 Mdot
.62221 .6449 Mdot
.59158 .24183 Mdot
.56147 .38322 Mdot
.38695 .52228 Mdot
.66252 .5712 Mdot
.6601 .56439 Mdot
.60288 .39127 Mdot
.63218 .53612 Mdot
.34846 .52056 Mdot
.52473 .68523 Mdot
.54916 .34532 Mdot
.40311 .32471 Mdot
.21597 .67298 Mdot
.43527 .31185 Mdot
.58742 .38323 Mdot
.35574 .56742 Mdot
.57314 .35507 Mdot
.1582 .36329 Mdot
.35288 .52846 Mdot
.52708 .65117 Mdot
.39844 .47827 Mdot
.36954 .53327 Mdot
.37031 .45941 Mdot
.59259 .34371 Mdot
.22968 .35067 Mdot
.42127 .51384 Mdot
.6586 .54202 Mdot
.35211 .76956 Mdot
.37744 .45515 Mdot
.37249 .31493 Mdot
.308 .40164 Mdot
.66925 .30882 Mdot
.53287 .71421 Mdot
.54931 .369 Mdot
.53493 .66915 Mdot
.46481 .63644 Mdot
.52871 .66277 Mdot
.36061 .76078 Mdot
.42757 .72894 Mdot
.26609 .29896 Mdot
.25076 .62 Mdot
.29117 .56151 Mdot
.48676 .64036 Mdot
.47549 .33542 Mdot
.50021 .70356 Mdot
.50512 .64529 Mdot
.53204 .91757 Mdot
.51383 .71065 Mdot
.39025 .52787 Mdot
.34616 .47869 Mdot
.6659 .68108 Mdot
.29377 .35767 Mdot
.37426 .4866 Mdot
.41419 .49855 Mdot
.40561 .35091 Mdot
.46394 .4873 Mdot
.64115 .4598 Mdot
.65867 .23828 Mdot
.70963 .67545 Mdot
.38968 .4915 Mdot
.41811 .50608 Mdot
.44658 .54431 Mdot
.86939 .49238 Mdot
.33698 .62624 Mdot
.48271 .64263 Mdot
.39867 .43711 Mdot
.28731 .74832 Mdot
.34566 .52878 Mdot
.40483 .46864 Mdot
.35797 .47308 Mdot
.57302 .35806 Mdot
.47583 .68646 Mdot
.40543 .44023 Mdot
.66655 .27566 Mdot
.3394 .50975 Mdot
.671 .46892 Mdot
.17659 .43123 Mdot
.3935 .52322 Mdot
.5046 .71552 Mdot
.37537 .46815 Mdot
.496 .65835 Mdot
.50619 .69518 Mdot
.38052 .57191 Mdot
.42415 .78578 Mdot
.48506 .70519 Mdot
.34452 .50315 Mdot
.58465 .35065 Mdot
.42305 .82817 Mdot
.40026 .51553 Mdot
.39283 .32151 Mdot
.40083 .53155 Mdot
.4027 .36078 Mdot
.36521 .48488 Mdot
.5989 .39211 Mdot
.42721 .63873 Mdot
.5659 .37025 Mdot
.194 .44273 Mdot
.58131 .39253 Mdot
.81225 .43621 Mdot
.47801 .66376 Mdot
.73902 .49844 Mdot
.40736 .17869 Mdot
.66669 .46189 Mdot
.57213 .56635 Mdot
.54774 .54346 Mdot
.66087 .55721 Mdot
.5264 .64373 Mdot
.23712 .45025 Mdot
.75628 .41785 Mdot
.75654 .45351 Mdot
.60325 .38318 Mdot
.4187 .15997 Mdot
.49708 .17017 Mdot
.41633 .49128 Mdot
.39438 .76146 Mdot
.29898 .66966 Mdot
.39436 .45936 Mdot
.36901 .44138 Mdot
.5273 .38124 Mdot
.41432 .5497 Mdot
.58933 .60464 Mdot
.59661 .37759 Mdot
.42627 .33362 Mdot
.50963 .64822 Mdot
.39056 .34888 Mdot
.75776 .43042 Mdot
.54825 .5495 Mdot
.62008 .35529 Mdot
.4095 .56809 Mdot
.4047 .48274 Mdot
.4973 .67881 Mdot
.53071 .7374 Mdot
.52359 .70417 Mdot
.41942 .30516 Mdot
.59439 .37573 Mdot
.33798 .61873 Mdot
.41213 .50362 Mdot
.51827 .68459 Mdot
.63754 .59838 Mdot
.41574 .51 Mdot
.65517 .52161 Mdot
.34627 .48867 Mdot
.53943 .68363 Mdot
.3713 .48302 Mdot
.52642 .68557 Mdot
.56084 .37876 Mdot
.34497 .53191 Mdot
.40469 .4914 Mdot
.83449 .43743 Mdot
.41149 .31483 Mdot
.48116 .65439 Mdot
.51376 .38348 Mdot
.38312 .5577 Mdot
.69482 .39252 Mdot
.37672 .53832 Mdot
.46236 .68659 Mdot
.42269 .55664 Mdot
.7269 .48425 Mdot
.33417 .4903 Mdot
.39935 .51563 Mdot
.55061 .5786 Mdot
.31437 .69972 Mdot
.52637 .74211 Mdot
.69372 .51407 Mdot
.49392 .70652 Mdot
.52993 .24093 Mdot
.62533 .33492 Mdot
.54322 .36639 Mdot
.25654 .3758 Mdot
.35296 .55973 Mdot
.37928 .51332 Mdot
.62666 .55521 Mdot
.42997 .32896 Mdot
.51232 .6831 Mdot
.42624 .33856 Mdot
.69218 .27831 Mdot
.43064 .31595 Mdot
.62154 .38753 Mdot
.63145 .28269 Mdot
.39159 .64088 Mdot
.40637 .35088 Mdot
.53221 .70163 Mdot
.4884 .23083 Mdot
.43302 .52238 Mdot
.44903 .35014 Mdot
.41479 .32568 Mdot
.41363 .15461 Mdot
.40856 .54953 Mdot
.57569 .56334 Mdot
.65926 .51212 Mdot
.41876 .34739 Mdot
.67122 .5527 Mdot
.378 .48607 Mdot
.6836 .36854 Mdot
.48632 .65166 Mdot
.69428 .55999 Mdot
.41003 .45852 Mdot
.42326 .31034 Mdot
.61562 .3651 Mdot
.72056 .54067 Mdot
.70024 .53821 Mdot
.60223 .77425 Mdot
.21323 .55315 Mdot
.5925 .3758 Mdot
.50384 .20242 Mdot
.68619 .55148 Mdot
.40217 .46456 Mdot
.46569 .55537 Mdot
.35436 .5343 Mdot
.74435 .52633 Mdot
.54789 .37057 Mdot
.6271 .67115 Mdot
.40306 .47969 Mdot
.38972 .54845 Mdot
.55315 .71116 Mdot
.57233 .37564 Mdot
.51621 .6643 Mdot
.49847 .70817 Mdot
.56255 .37893 Mdot
.52649 .67287 Mdot
.43305 .34347 Mdot
.63449 .64079 Mdot
.69121 .54766 Mdot
.66273 .54224 Mdot
.58283 .36577 Mdot
.56942 .35052 Mdot
.56808 .3568 Mdot
.34576 .48963 Mdot
.50836 .67748 Mdot
.358 .4808 Mdot
.36904 .46047 Mdot
.53608 .74728 Mdot
.53509 .70806 Mdot
.36805 .4667 Mdot
.64689 .38727 Mdot
.44942 .34196 Mdot
.58912 .34843 Mdot
.66282 .50975 Mdot
.76154 .63865 Mdot
.7015 .56014 Mdot
.38419 .52314 Mdot
.7588 .35591 Mdot
.53248 .69701 Mdot
.40546 .34545 Mdot
.43069 .35918 Mdot
.39833 .33673 Mdot
.62233 .55724 Mdot
.48265 .67652 Mdot
.65716 .23689 Mdot
.38481 .51981 Mdot
.59211 .51062 Mdot
.23056 .46598 Mdot
.69474 .29619 Mdot
.6643 .50862 Mdot
.4165 .50662 Mdot
.53929 .44761 Mdot
.43638 .70696 Mdot
.36242 .53733 Mdot
.43566 .53908 Mdot
.68609 .44791 Mdot
.4481 .56704 Mdot
.48841 .71162 Mdot
.76142 .32156 Mdot
.35291 .46625 Mdot
.56539 .71954 Mdot
.15989 .58927 Mdot
.37776 .52653 Mdot
.39723 .54237 Mdot
.4039 .507 Mdot
.38925 .47419 Mdot
.50385 .71649 Mdot
.26104 .4041 Mdot
.67895 .50265 Mdot
.58764 .48799 Mdot
.69322 .54684 Mdot
.53849 .3587 Mdot
.58938 .63477 Mdot
.53642 .65214 Mdot
.4074 .34774 Mdot
.52619 .77685 Mdot
.71496 .27339 Mdot
.62967 .35207 Mdot
.38995 .66534 Mdot
.40989 .32085 Mdot
.41073 .47025 Mdot
.3961 .36065 Mdot
.58476 .39123 Mdot
.65375 .54663 Mdot
.32758 .53719 Mdot
.51495 .70695 Mdot
.54161 .66962 Mdot
.41612 .52195 Mdot
.32603 .78264 Mdot
.65149 .52132 Mdot
.69954 .50273 Mdot
.39027 .46513 Mdot
.43836 .53504 Mdot
.51708 .66077 Mdot
.59529 .3562 Mdot
.41387 .24427 Mdot
.42239 .31944 Mdot
.37172 .55925 Mdot
.3857 .47401 Mdot
.75964 .3262 Mdot
.63985 .5361 Mdot
.63153 .36832 Mdot
.40128 .47087 Mdot
.75957 .54844 Mdot
.40014 .47063 Mdot
.42034 .59418 Mdot
.58345 .35291 Mdot
.44732 .49726 Mdot
.42306 .51111 Mdot
.34518 .43845 Mdot
.67962 .55354 Mdot
.52476 .65138 Mdot
.53572 .72029 Mdot
.5188 .41546 Mdot
.65802 .52137 Mdot
.37159 .46662 Mdot
.64159 .53176 Mdot
.3861 .45474 Mdot
.41844 .52746 Mdot
.67017 .50964 Mdot
.51681 .66465 Mdot
.62677 .73172 Mdot
.58714 .6437 Mdot
.39254 .4743 Mdot
.34169 .47988 Mdot
.2726 .37219 Mdot
.31259 .2481 Mdot
.38455 .54101 Mdot
.54081 .67763 Mdot
.41098 .49849 Mdot
.67679 .54863 Mdot
.43355 .32424 Mdot
.53916 .67762 Mdot
.60012 .36088 Mdot
.62855 .36303 Mdot
.74199 .62414 Mdot
.58599 .38794 Mdot
.42897 .50448 Mdot
.47057 .61489 Mdot
.55103 .66731 Mdot
.17757 .62343 Mdot
.56647 .37893 Mdot
.43167 .35285 Mdot
.38721 .48352 Mdot
.78803 .41193 Mdot
.62395 .5507 Mdot
.89304 .55497 Mdot
.65009 .22705 Mdot
.43148 .30643 Mdot
.43563 .18343 Mdot
.54796 .34868 Mdot
.422 .53364 Mdot
.40109 .35076 Mdot
.6249 .34565 Mdot
.42519 .50127 Mdot
.31947 .5162 Mdot
.21775 .38406 Mdot
.52522 .4245 Mdot
.64134 .52758 Mdot
.56765 .34522 Mdot
.3961 .36581 Mdot
.61853 .38877 Mdot
.54313 .67044 Mdot
.39545 .51424 Mdot
.38976 .42296 Mdot
.59898 .35743 Mdot
.61332 .39055 Mdot
.35096 .48354 Mdot
.5227 .64169 Mdot
.53717 .39276 Mdot
.3829 .4931 Mdot
.31656 .58517 Mdot
.47112 .69093 Mdot
.60076 .37434 Mdot
.39125 .55129 Mdot
.3373 .41524 Mdot
.59142 .36488 Mdot
.59172 .34758 Mdot
.41705 .52319 Mdot
.43156 .34616 Mdot
.33621 .52443 Mdot
.68615 .52942 Mdot
.20843 .37237 Mdot
.67302 .54908 Mdot
.51678 .25099 Mdot
.39107 .57718 Mdot
.67057 .38129 Mdot
.54586 .67678 Mdot
.40273 .37166 Mdot
.77343 .63334 Mdot
.43995 .5129 Mdot
.48791 .82223 Mdot
.54372 .45999 Mdot
.27772 .74807 Mdot
.75192 .69857 Mdot
.41483 .32953 Mdot
.66763 .52323 Mdot
.39723 .54179 Mdot
.62622 .53819 Mdot
.39351 .33948 Mdot
.21365 .50487 Mdot
.39567 .55213 Mdot
.50452 .66878 Mdot
.34326 .50055 Mdot
.50157 .65394 Mdot
.41541 .51433 Mdot
.43282 .57642 Mdot
.73917 .48387 Mdot
.35382 .29333 Mdot
.43015 .51741 Mdot
.82244 .57054 Mdot
.57836 .27826 Mdot
.41925 .32348 Mdot
.35275 .49062 Mdot
.6341 .3431 Mdot
.65936 .56295 Mdot
.49314 .56913 Mdot
.57471 .35598 Mdot
.63656 .52112 Mdot
.52323 .66204 Mdot
.56041 .38121 Mdot
.62188 .37729 Mdot
.40134 .44325 Mdot
.40215 .35875 Mdot
.65084 .54963 Mdot
.39839 .51941 Mdot
.40377 .54972 Mdot
.50964 .20931 Mdot
.54374 .27495 Mdot
.54392 .72021 Mdot
.82261 .37838 Mdot
.54881 .70415 Mdot
.41669 .31279 Mdot
.57922 .35299 Mdot
.38239 .5387 Mdot
.35518 .51629 Mdot
.74289 .49906 Mdot
.48681 .64619 Mdot
.52755 .43106 Mdot
.33866 .64088 Mdot
.54839 .39553 Mdot
.29742 .3905 Mdot
.52911 .65116 Mdot
.29678 .38882 Mdot
.39589 .365 Mdot
.48537 .80221 Mdot
.34805 .32507 Mdot
.6559 .51275 Mdot
.29351 .39461 Mdot
.51533 .69531 Mdot
.41263 .48725 Mdot
.61602 .33098 Mdot
.59479 .3867 Mdot
.51466 .65314 Mdot
.52641 .37341 Mdot
.41585 .34673 Mdot
.40254 .54306 Mdot
.63392 .23651 Mdot
.69252 .64439 Mdot
.60328 .35148 Mdot
.40309 .59582 Mdot
.66241 .55021 Mdot
.41879 .53567 Mdot
.39432 .31812 Mdot
.6497 .5365 Mdot
.57683 .251 Mdot
.62499 .65561 Mdot
.37996 .48877 Mdot
.79583 .40397 Mdot
.65292 .52537 Mdot
.40076 .20313 Mdot
.38632 .49747 Mdot
.68557 .55183 Mdot
.45679 .53348 Mdot
.69095 .30996 Mdot
.51273 .43357 Mdot
.47911 .84274 Mdot
.5366 .43941 Mdot
.58608 .33148 Mdot
.71724 .35509 Mdot
.73846 .43137 Mdot
.62768 .54477 Mdot
.61521 .38972 Mdot
.36867 .38957 Mdot
.67052 .55347 Mdot
.36425 .46309 Mdot
.37676 .53356 Mdot
.31042 .61377 Mdot
.54779 .47181 Mdot
.63532 .37735 Mdot
.72701 .59742 Mdot
.38149 .55709 Mdot
.39654 .44531 Mdot
.36033 .51181 Mdot
.48109 .63208 Mdot
.64476 .54275 Mdot
.83069 .4943 Mdot
.66185 .51948 Mdot
.58184 .20585 Mdot
.57945 .36941 Mdot
.55038 .36234 Mdot
.39013 .52389 Mdot
.66413 .35682 Mdot
.27504 .44261 Mdot
.3472 .51702 Mdot
.65304 .40533 Mdot
.21001 .58877 Mdot
.40386 .45247 Mdot
.49359 .71775 Mdot
.34388 .57089 Mdot
.48061 .62614 Mdot
.6894 .5528 Mdot
.4091 .33339 Mdot
.40484 .37745 Mdot
.65043 .54767 Mdot
.37782 .51234 Mdot
.66073 .41002 Mdot
.36418 .52937 Mdot
.41091 .48107 Mdot
.57865 .19693 Mdot
.4291 .30557 Mdot
.55774 .36403 Mdot
.39568 .32657 Mdot
.50341 .64484 Mdot
.76017 .78138 Mdot
.43043 .33185 Mdot
.27302 .4526 Mdot
.20284 .45642 Mdot
.29077 .39464 Mdot
.54014 .66314 Mdot
.38648 .31571 Mdot
.64762 .52071 Mdot
.34677 .81712 Mdot
.29116 .26108 Mdot
.71584 .53071 Mdot
.37737 .49819 Mdot
.52876 .64301 Mdot
.53436 .70249 Mdot
.69505 .55709 Mdot
.50859 .69522 Mdot
.43369 .45531 Mdot
.40245 .47655 Mdot
.62771 .53791 Mdot
.68115 .66651 Mdot
.7004 .53865 Mdot
.62594 .62533 Mdot
.34972 .4925 Mdot
.53474 .6587 Mdot
.34711 .57108 Mdot
.51018 .61899 Mdot
.63251 .36763 Mdot
.40389 .46275 Mdot
.41373 .34796 Mdot
.60748 .48275 Mdot
.59345 .37328 Mdot
.75803 .358 Mdot
.49695 .67501 Mdot
.63961 .59109 Mdot
.50329 .68847 Mdot
.50428 .62936 Mdot
.63647 .54436 Mdot
.48537 .66779 Mdot
.39839 .54301 Mdot
.65245 .36573 Mdot
.49238 .66311 Mdot
.67306 .53599 Mdot
.40397 .33381 Mdot
.52356 .67108 Mdot
.52401 .39256 Mdot
.39646 .48504 Mdot
.61028 .34148 Mdot
.74392 .47766 Mdot
.515 .63569 Mdot
.39285 .3068 Mdot
.54517 .37391 Mdot
.40023 .35589 Mdot
.20038 .6019 Mdot
.64557 .50833 Mdot
.46119 .18981 Mdot
.34236 .4149 Mdot
.52035 .70896 Mdot
.74143 .47996 Mdot
.38368 .53621 Mdot
.39457 .48345 Mdot
.38467 .34271 Mdot
.53399 .70297 Mdot
.39115 .81438 Mdot
.50452 .75326 Mdot
.6348 .65158 Mdot
.64414 .50699 Mdot
.81846 .47333 Mdot
.60052 .61544 Mdot
.17699 .50617 Mdot
.42843 .46699 Mdot
.55564 .34354 Mdot
.374 .51879 Mdot
.76544 .64489 Mdot
.42199 .3081 Mdot
.4293 .26672 Mdot
.40639 .57318 Mdot
.55313 .37263 Mdot
.39858 .49872 Mdot
.50967 .53765 Mdot
.37866 .58759 Mdot
.43602 .34045 Mdot
.66018 .47097 Mdot
.50774 .71213 Mdot
.40495 .32275 Mdot
.61445 .37771 Mdot
.2849 .42441 Mdot
.42799 .51675 Mdot
.43798 .49776 Mdot
.55207 .39722 Mdot
.50337 .67338 Mdot
.58055 .33498 Mdot
.6906 .54837 Mdot
.41509 .34037 Mdot
.38715 .47989 Mdot
.41931 .56139 Mdot
.696 .3943 Mdot
.64852 .55025 Mdot
.54227 .38932 Mdot
.67292 .51814 Mdot
.58928 .32921 Mdot
.33364 .49844 Mdot
.549 .36311 Mdot
.42501 .53637 Mdot
.7871 .57702 Mdot
.57131 .19615 Mdot
.33553 .7172 Mdot
.54984 .37525 Mdot
.32345 .38271 Mdot
.67871 .54265 Mdot
.68516 .53172 Mdot
.24796 .54675 Mdot
.46952 .49054 Mdot
.5512 .23027 Mdot
.6157 .77385 Mdot
.69296 .54574 Mdot
.66894 .54706 Mdot
.6167 .34277 Mdot
.48648 .66252 Mdot
.51763 .63253 Mdot
.53626 .36 Mdot
.2973 .30596 Mdot
.51245 .68311 Mdot
.47167 .81808 Mdot
.55314 .23906 Mdot
.39037 .44037 Mdot
.71259 .57187 Mdot
.41029 .34122 Mdot
.30827 .30395 Mdot
.51387 .55073 Mdot
.39008 .54658 Mdot
.76882 .33703 Mdot
.58971 .3581 Mdot
.24708 .39992 Mdot
.55978 .81495 Mdot
.39833 .55279 Mdot
.38747 .50391 Mdot
.37002 .51261 Mdot
.41846 .2994 Mdot
.44344 .63237 Mdot
.40141 .54845 Mdot
.29676 .30322 Mdot
.38143 .55847 Mdot
.40283 .39533 Mdot
.39712 .32294 Mdot
.29414 .49663 Mdot
.69038 .46189 Mdot
.66762 .26653 Mdot
.31157 .51929 Mdot
.69052 .5447 Mdot
.5896 .45748 Mdot
.67781 .55696 Mdot
.35131 .7521 Mdot
.3451 .32812 Mdot
.50812 .72737 Mdot
.39207 .54499 Mdot
.58952 .38271 Mdot
.53617 .69955 Mdot
.71988 .38918 Mdot
.58813 .9084 Mdot
.6836 .55804 Mdot
.17283 .35422 Mdot
.68116 .52407 Mdot
.61791 .38144 Mdot
.51734 .65934 Mdot
.42058 .72753 Mdot
.59002 .51666 Mdot
.52516 .6742 Mdot
.62168 .71963 Mdot
.55265 .65671 Mdot
.30861 .39088 Mdot
.55146 .67869 Mdot
.67574 .53771 Mdot
.65735 .57679 Mdot
.36448 .43685 Mdot
.39071 .53137 Mdot
.54465 .54824 Mdot
.29466 .43515 Mdot
.38756 .53423 Mdot
.59522 .37735 Mdot
.39077 .20106 Mdot
.5191 .40914 Mdot
.49468 .69355 Mdot
.70266 .52569 Mdot
.39017 .50288 Mdot
.39318 .4708 Mdot
.42486 .50565 Mdot
.83063 .38346 Mdot
.45611 .81145 Mdot
.42096 .51317 Mdot
.36033 .5542 Mdot
.55746 .37922 Mdot
.38456 .29795 Mdot
.74806 .67439 Mdot
.40171 .40053 Mdot
.36351 .54499 Mdot
.40383 .318 Mdot
.44273 .32723 Mdot
.42582 .50194 Mdot
.65763 .27532 Mdot
.65885 .33488 Mdot
.39879 .51916 Mdot
.44814 .43479 Mdot
.75077 .42347 Mdot
.61367 .38964 Mdot
.59728 .35977 Mdot
.50445 .71486 Mdot
.59483 .38448 Mdot
.58269 .39282 Mdot
.4197 .70734 Mdot
.5683 .45741 Mdot
.61727 .50217 Mdot
.41897 .3049 Mdot
.35602 .52041 Mdot
.55425 .69316 Mdot
.74636 .51355 Mdot
.65734 .5552 Mdot
.53348 .68691 Mdot
.66424 .56357 Mdot
.42758 .29889 Mdot
.22984 .38514 Mdot
.59768 .3874 Mdot
.69512 .53731 Mdot
.62462 .65407 Mdot
.40173 .31905 Mdot
.63651 .52719 Mdot
.67377 .38733 Mdot
.37177 .45741 Mdot
.4569 .77144 Mdot
.34611 .50971 Mdot
.33001 .7925 Mdot
.6375 .52673 Mdot
.72662 .48544 Mdot
.38515 .51385 Mdot
.58998 .36812 Mdot
.44272 .56671 Mdot
.36179 .54072 Mdot
.60539 .36114 Mdot
.41592 .49101 Mdot
.38959 .33262 Mdot
.46699 .64501 Mdot
.58281 .46316 Mdot
.59087 .15584 Mdot
.39761 .35684 Mdot
.71272 .38687 Mdot
.38575 .54194 Mdot
.20936 .56924 Mdot
.52304 .67271 Mdot
.42416 .54754 Mdot
.2696 .50338 Mdot
.49228 .65252 Mdot
.53472 .67489 Mdot
.3709 .47508 Mdot
.65796 .51377 Mdot
.59674 .37074 Mdot
.39823 .32362 Mdot
.18186 .58436 Mdot
.36689 .50065 Mdot
.40758 .4942 Mdot
.40811 .32137 Mdot
.67067 .54852 Mdot
.38852 .46945 Mdot
.77619 .4971 Mdot
.23633 .7154 Mdot
.65017 .55617 Mdot
.34048 .49289 Mdot
.48752 .76407 Mdot
.49129 .61324 Mdot
.2268 .2996 Mdot
.38552 .27181 Mdot
.55459 .3627 Mdot
.45331 .56049 Mdot
.83935 .66364 Mdot
.40785 .33468 Mdot
.6625 .25048 Mdot
.4118 .48023 Mdot
.40988 .50626 Mdot
.52736 .70087 Mdot
.3616 .47383 Mdot
.49556 .64232 Mdot
.54408 .14906 Mdot
.78611 .35016 Mdot
.4994 .66656 Mdot
.51351 .7087 Mdot
.27059 .47502 Mdot
.75181 .66854 Mdot
.51779 .65302 Mdot
.33056 .5247 Mdot
.39584 .7973 Mdot
.33137 .44902 Mdot
.38499 .34513 Mdot
.74492 .4635 Mdot
.54729 .63284 Mdot
.49042 .36915 Mdot
.61314 .75836 Mdot
.5593 .64496 Mdot
.63951 .31654 Mdot
.68629 .52633 Mdot
.38312 .55407 Mdot
.59023 .38763 Mdot
.54413 .36618 Mdot
.38847 .58731 Mdot
.35881 .52835 Mdot
.49716 .65555 Mdot
.43044 .31012 Mdot
.64301 .55872 Mdot
.41354 .49743 Mdot
.52451 .41045 Mdot
.4275 .32735 Mdot
.49337 .68574 Mdot
.24772 .52845 Mdot
.43435 .34851 Mdot
.35288 .58095 Mdot
.40524 .52796 Mdot
.35389 .47823 Mdot
.38378 .41508 Mdot
.6784 .50896 Mdot
.76281 .49397 Mdot
.33567 .50999 Mdot
.69543 .2792 Mdot
.47796 .43115 Mdot
.4511 .51009 Mdot
.50932 .68761 Mdot
.62194 .54862 Mdot
.63695 .35326 Mdot
.24613 .46069 Mdot
.37396 .49345 Mdot
.44962 .80783 Mdot
.33427 .62955 Mdot
.63442 .35253 Mdot
.48604 .64224 Mdot
.40348 .34376 Mdot
.34903 .51987 Mdot
.37529 .77676 Mdot
.37844 .52986 Mdot
.36311 .40946 Mdot
.59004 .35085 Mdot
.68528 .52345 Mdot
.26723 .74093 Mdot
.54471 .36558 Mdot
.53506 .6707 Mdot
.49335 .85192 Mdot
.54334 .65723 Mdot
.49438 .70073 Mdot
.4137 .78673 Mdot
.68489 .51455 Mdot
.85233 .64341 Mdot
.27538 .26691 Mdot
.43287 .55815 Mdot
.68185 .54313 Mdot
.50855 .65608 Mdot
.41795 .53678 Mdot
.54636 .69188 Mdot
.48093 .66633 Mdot
.37591 .44878 Mdot
.41036 .51944 Mdot
.586 .62863 Mdot
.51393 .82023 Mdot
.39947 .34112 Mdot
.51905 .64294 Mdot
.28198 .55928 Mdot
.41453 .54574 Mdot
.38553 .51964 Mdot
.74089 .403 Mdot
.43224 .3468 Mdot
.5536 .59015 Mdot
.40461 .47356 Mdot
.79912 .37939 Mdot
.34074 .56925 Mdot
.50096 .71635 Mdot
.64825 .55457 Mdot
.65595 .26389 Mdot
.74225 .52994 Mdot
.48922 .64341 Mdot
.40216 .308 Mdot
.53509 .72161 Mdot
.27518 .45149 Mdot
.69678 .5268 Mdot
.53942 .68372 Mdot
.54677 .44901 Mdot
.65688 .53431 Mdot
.6393 .52387 Mdot
.3554 .77191 Mdot
.5476 .38899 Mdot
.4015 .30283 Mdot
.65629 .54999 Mdot
.33682 .60204 Mdot
.67343 .52979 Mdot
.28608 .58261 Mdot
.34201 .52719 Mdot
.25824 .34584 Mdot
.59207 .57647 Mdot
.42059 .43485 Mdot
.66623 .50486 Mdot
.39391 .33784 Mdot
.37798 .47247 Mdot
.5109 .69761 Mdot
.42861 .33692 Mdot
.71226 .56174 Mdot
.58143 .34737 Mdot
.50095 .68843 Mdot
.67312 .50003 Mdot
.52247 .64577 Mdot
.23718 .44137 Mdot
.20124 .38794 Mdot
.785 .47674 Mdot
.58702 .51678 Mdot
.42345 .50119 Mdot
.66562 .73966 Mdot
.37031 .44723 Mdot
.36104 .53321 Mdot
.59994 .37404 Mdot
.25443 .37689 Mdot
.5163 .66371 Mdot
.273 .74902 Mdot
.69277 .5341 Mdot
.76963 .32863 Mdot
.49221 .73393 Mdot
.42504 .54838 Mdot
.49292 .65886 Mdot
.54806 .66704 Mdot
.30709 .69519 Mdot
.62159 .38975 Mdot
.32388 .49513 Mdot
.34284 .46029 Mdot
.43706 .48306 Mdot
.64055 .52328 Mdot
.74842 .34671 Mdot
.56601 .33971 Mdot
.20022 .36194 Mdot
.59519 .35042 Mdot
.62894 .439 Mdot
.4868 .6751 Mdot
.43174 .33701 Mdot
.38809 .51989 Mdot
.49733 .74065 Mdot
.49105 .63999 Mdot
.44753 .31904 Mdot
.4173 .34966 Mdot
.71583 .33629 Mdot
.67047 .50924 Mdot
.43161 .52484 Mdot
.39253 .55082 Mdot
.35823 .48348 Mdot
.34244 .51272 Mdot
.68465 .5578 Mdot
.38363 .46108 Mdot
.65655 .57102 Mdot
.32947 .6013 Mdot
.78001 .34989 Mdot
.56438 .45594 Mdot
.47951 .56234 Mdot
.50402 .69936 Mdot
.34449 .60263 Mdot
.34987 .58063 Mdot
.53939 .18636 Mdot
.24007 .67135 Mdot
.40335 .45518 Mdot
.6187 .34101 Mdot
.4728 .51207 Mdot
.56943 .38987 Mdot
.232 .25769 Mdot
.69391 .40522 Mdot
.48359 .83481 Mdot
.41084 .54423 Mdot
.74409 .40588 Mdot
.44924 .59297 Mdot
.35771 .45236 Mdot
.72005 .41232 Mdot
.75351 .57169 Mdot
.64719 .69233 Mdot
.4417 .33389 Mdot
.39204 .48773 Mdot
.5508 .66092 Mdot
.39972 .54405 Mdot
.38013 .52027 Mdot
.41286 .48022 Mdot
.68556 .50538 Mdot
.32722 .53191 Mdot
.34426 .49069 Mdot
.54408 .30319 Mdot
.31829 .35992 Mdot
.56707 .34454 Mdot
.24066 .54004 Mdot
.42929 .33161 Mdot
.4945 .66539 Mdot
.58998 .72984 Mdot
.65614 .51238 Mdot
.29883 .6795 Mdot
.34363 .49578 Mdot
.60428 .64213 Mdot
.66995 .49909 Mdot
.41631 .34258 Mdot
.61625 .32917 Mdot
.44531 .84163 Mdot
.58405 .38248 Mdot
.5478 .45251 Mdot
.58819 .37235 Mdot
.31283 .54617 Mdot
.49782 .6541 Mdot
.4189 .48697 Mdot
.65837 .54868 Mdot
.60501 .36988 Mdot
.28336 .36012 Mdot
.36172 .5125 Mdot
.56095 .37774 Mdot
.41709 .48424 Mdot
.23524 .36786 Mdot
.46457 .20811 Mdot
.59131 .39314 Mdot
.61852 .54961 Mdot
.66285 .5347 Mdot
.43308 .34154 Mdot
.49459 .67913 Mdot
.52587 .6996 Mdot
.65093 .53476 Mdot
.31933 .23548 Mdot
.3644 .54437 Mdot
.41608 .54082 Mdot
.6979 .2789 Mdot
.39472 .53795 Mdot
.29961 .41085 Mdot
.53396 .44415 Mdot
.49695 .69287 Mdot
.42094 .52749 Mdot
.38999 .47179 Mdot
.38375 .48592 Mdot
.23188 .44294 Mdot
.59889 .35431 Mdot
.36491 .54999 Mdot
.41328 .35347 Mdot
.64018 .3436 Mdot
.41817 .54023 Mdot
.43839 .48696 Mdot
.52744 .69818 Mdot
.76749 .30892 Mdot
.6771 .51691 Mdot
.61954 .37259 Mdot
.54828 .36669 Mdot
.74677 .46154 Mdot
.5518 .73527 Mdot
.53093 .44128 Mdot
.19143 .38554 Mdot
.71145 .47421 Mdot
.41397 .31915 Mdot
.62455 .45191 Mdot
.46296 .41467 Mdot
.62664 .35465 Mdot
.67309 .56423 Mdot
.33763 .51648 Mdot
.35859 .5431 Mdot
.6385 .21626 Mdot
.42653 .54835 Mdot
.4057 .34243 Mdot
.67224 .57101 Mdot
.5164 .69419 Mdot
.41471 .34432 Mdot
.68188 .52724 Mdot
.50375 .67604 Mdot
.37205 .45538 Mdot
.36021 .46227 Mdot
.53292 .6844 Mdot
.53357 .7012 Mdot
.40013 .52309 Mdot
.64678 .33852 Mdot
.50368 .71306 Mdot
.53891 .6657 Mdot
.59582 .38825 Mdot
.60064 .38357 Mdot
.41391 .44625 Mdot
.68247 .53721 Mdot
.36281 .46619 Mdot
.57071 .38401 Mdot
.43355 .31745 Mdot
.51821 .67054 Mdot
.39455 .47372 Mdot
.41172 .48997 Mdot
.40065 .32167 Mdot
.43961 .32274 Mdot
.41828 .34605 Mdot
.68395 .56911 Mdot
.35574 .49413 Mdot
.52193 .65708 Mdot
.67943 .51307 Mdot
.44287 .32748 Mdot
.40821 .3641 Mdot
.52061 .35937 Mdot
.38114 .5403 Mdot
.51659 .38103 Mdot
.75651 .78014 Mdot
.34526 .39093 Mdot
.63662 .35741 Mdot
.55133 .39456 Mdot
.28959 .37942 Mdot
.6558 .34376 Mdot
.64885 .52553 Mdot
.35911 .39497 Mdot
.40354 .37256 Mdot
.40135 .46198 Mdot
.34065 .48316 Mdot
.36292 .44242 Mdot
.42231 .33668 Mdot
.2475 .44245 Mdot
.54705 .68094 Mdot
.27254 .61407 Mdot
.42889 .33286 Mdot
.6101 .39252 Mdot
.53983 .38536 Mdot
.59458 .35013 Mdot
.34045 .48712 Mdot
.32993 .70813 Mdot
.30628 .56453 Mdot
.66312 .74844 Mdot
.64819 .51199 Mdot
.50901 .72926 Mdot
.2023 .58776 Mdot
.53347 .6786 Mdot
.53923 .37675 Mdot
.42493 .33216 Mdot
.54047 .68557 Mdot
.66694 .55945 Mdot
.66643 .54702 Mdot
.59973 .35142 Mdot
.58074 .36598 Mdot
.61277 .34477 Mdot
.48615 .68811 Mdot
.48573 .66961 Mdot
.36677 .49756 Mdot
.5217 .68259 Mdot
.6988 .24386 Mdot
.41637 .29679 Mdot
.53907 .39025 Mdot
.66914 .52261 Mdot
.50031 .65575 Mdot
.35819 .51264 Mdot
.53897 .42282 Mdot
.7319 .62689 Mdot
.39554 .35228 Mdot
.49184 .2073 Mdot
.22371 .27119 Mdot
.43146 .53528 Mdot
.64011 .52999 Mdot
.62521 .23507 Mdot
.36906 .51071 Mdot
.57792 .35702 Mdot
.78749 .59299 Mdot
.62617 .33517 Mdot
.36617 .46254 Mdot
.4328 .54352 Mdot
.63201 .5385 Mdot
.19824 .46444 Mdot
.36129 .50139 Mdot
.61999 .60612 Mdot
.70435 .53344 Mdot
.55011 .35092 Mdot
.24472 .72883 Mdot
.76636 .45087 Mdot
.30294 .30717 Mdot
.60228 .38581 Mdot
.37078 .53403 Mdot
.60838 .37694 Mdot
.39611 .35091 Mdot
.61733 .36746 Mdot
.48467 .71092 Mdot
.56723 .34272 Mdot
.40746 .49538 Mdot
.5178 .65163 Mdot
.65316 .52453 Mdot
.75194 .30891 Mdot
.54014 .29585 Mdot
.58922 .36775 Mdot
.60916 .38652 Mdot
.42349 .51801 Mdot
.57037 .60169 Mdot
.42836 .57175 Mdot
.41214 .54533 Mdot
.69468 .54646 Mdot
.49132 .66428 Mdot
.667 .50237 Mdot
.4006 .56257 Mdot
.7915 .52371 Mdot
.66893 .51558 Mdot
.60104 .64633 Mdot
.41054 .32028 Mdot
.51136 .50293 Mdot
.35401 .5183 Mdot
.66069 .55311 Mdot
.35486 .49436 Mdot
.54426 .69919 Mdot
.53717 .49003 Mdot
.75655 .51969 Mdot
.65818 .54694 Mdot
.3713 .80757 Mdot
.54786 .33827 Mdot
.33908 .56107 Mdot
.68347 .55381 Mdot
.27107 .50613 Mdot
.62027 .37929 Mdot
.42041 .31876 Mdot
.44259 .32847 Mdot
.40495 .35782 Mdot
.43229 .49347 Mdot
.32319 .54937 Mdot
.39457 .31255 Mdot
.65195 .55907 Mdot
.43724 .3365 Mdot
.54332 .75307 Mdot
.38241 .81371 Mdot
.41816 .30717 Mdot
.38455 .49566 Mdot
.34966 .44108 Mdot
.31407 .35829 Mdot
.53792 .39777 Mdot
.493 .82423 Mdot
.47606 .58237 Mdot
.38816 .53061 Mdot
.49695 .60629 Mdot
.54515 .68462 Mdot
.6193 .23849 Mdot
.30543 .42716 Mdot
.62942 .27134 Mdot
.50903 .7091 Mdot
.74298 .50114 Mdot
.49508 .68663 Mdot
.42953 .5333 Mdot
.41683 .53147 Mdot
.51717 .63126 Mdot
.76234 .35202 Mdot
.68901 .36371 Mdot
.21999 .67615 Mdot
.53825 .6617 Mdot
.67857 .5539 Mdot
.69106 .55482 Mdot
.65185 .51095 Mdot
.53904 .23833 Mdot
.51272 .63726 Mdot
.36263 .49111 Mdot
.55628 .38013 Mdot
.37036 .5491 Mdot
.65341 .54094 Mdot
.27904 .7539 Mdot
.52283 .69819 Mdot
.39909 .51648 Mdot
.30896 .25396 Mdot
.57205 .36443 Mdot
.40751 .31453 Mdot
.2233 .38883 Mdot
.58498 .25019 Mdot
.69087 .51799 Mdot
.53202 .64155 Mdot
.67189 .46794 Mdot
.59793 .65802 Mdot
.42145 .45658 Mdot
.43717 .46516 Mdot
.17647 .54011 Mdot
.56905 .25086 Mdot
.42079 .48566 Mdot
.62247 .37215 Mdot
.7433 .49864 Mdot
.39707 .4777 Mdot
.54051 .66146 Mdot
.43997 .34831 Mdot
.41866 .35383 Mdot
.32807 .4946 Mdot
.59344 .5063 Mdot
.50209 .46463 Mdot
.37285 .46533 Mdot
.35122 .58036 Mdot
.54264 .37845 Mdot
.69942 .46939 Mdot
.72825 .2947 Mdot
.40732 .30464 Mdot
.40453 .47153 Mdot
.65586 .71045 Mdot
.48275 .66068 Mdot
.59347 .33526 Mdot
.69671 .52426 Mdot
.22857 .46028 Mdot
.5578 .3452 Mdot
.3982 .47725 Mdot
.38898 .46992 Mdot
.63581 .52807 Mdot
.50084 .71639 Mdot
.42257 .33457 Mdot
.54837 .37438 Mdot
.40517 .30523 Mdot
.49529 .64579 Mdot
.52107 .69622 Mdot
.32514 .45469 Mdot
.32709 .54264 Mdot
.59819 .36101 Mdot
.40143 .56035 Mdot
.55347 .40362 Mdot
.19536 .46233 Mdot
.64007 .50719 Mdot
.43131 .53803 Mdot
.47436 .65815 Mdot
.65312 .54722 Mdot
.4081 .5112 Mdot
.1686 .55934 Mdot
.40782 .55373 Mdot
.74157 .52605 Mdot
.79878 .50202 Mdot
.40199 .34814 Mdot
.23864 .60048 Mdot
.56318 .63156 Mdot
.3992 .53728 Mdot
.57422 .34742 Mdot
.4382 .56948 Mdot
.65371 .51654 Mdot
.49137 .68791 Mdot
.23458 .28533 Mdot
.67188 .53155 Mdot
.4071 .54313 Mdot
.41554 .34121 Mdot
.54292 .65453 Mdot
.59743 .45803 Mdot
.6854 .28071 Mdot
.37675 .57911 Mdot
.33131 .52977 Mdot
.36911 .4622 Mdot
.78071 .64671 Mdot
.62064 .37034 Mdot
.50453 .65522 Mdot
.64114 .5231 Mdot
.6486 .53449 Mdot
.59535 .35338 Mdot
.64782 .68004 Mdot
.51247 .50036 Mdot
.8012 .71477 Mdot
.60794 .36253 Mdot
.3916 .30715 Mdot
.58548 .60073 Mdot
.57597 .34528 Mdot
.5628 .37631 Mdot
.54366 .37897 Mdot
.65062 .48355 Mdot
.50625 .6774 Mdot
.4128 .49019 Mdot
.53243 .71472 Mdot
.37065 .53689 Mdot
.48481 .44642 Mdot
.65223 .54881 Mdot
.4921 .69205 Mdot
.173 .55833 Mdot
.45789 .62699 Mdot
.37682 .50547 Mdot
.19849 .57268 Mdot
.40745 .57517 Mdot
.27622 .41218 Mdot
.36217 .56647 Mdot
.58392 .36955 Mdot
.45517 .56943 Mdot
.44248 .53606 Mdot
.72802 .27933 Mdot
.67137 .52277 Mdot
.62283 .37859 Mdot
.42825 .49436 Mdot
.34247 .57164 Mdot
.52664 .63265 Mdot
.54126 .68051 Mdot
.40003 .3069 Mdot
.35471 .28901 Mdot
.65455 .52252 Mdot
.20993 .38028 Mdot
.39502 .53054 Mdot
.79656 .43796 Mdot
.25209 .61751 Mdot
.40689 .51102 Mdot
.40597 .80213 Mdot
.3166 .69637 Mdot
.35078 .52033 Mdot
.28015 .49582 Mdot
.6725 .54653 Mdot
.79012 .51684 Mdot
.35439 .55251 Mdot
.57471 .35753 Mdot
.48733 .67127 Mdot
.54378 .66417 Mdot
.39095 .3223 Mdot
.53371 .17102 Mdot
.65875 .50454 Mdot
.4898 .68627 Mdot
.36322 .51596 Mdot
.68751 .51572 Mdot
.58311 .38758 Mdot
.40771 .56407 Mdot
.31228 .41318 Mdot
.52015 .68534 Mdot
.36307 .55645 Mdot
.69684 .61757 Mdot
.32536 .29931 Mdot
.65181 .79887 Mdot
.65394 .51098 Mdot
.43265 .32549 Mdot
.44586 .54587 Mdot
.22785 .34799 Mdot
.40734 .45695 Mdot
.25404 .35448 Mdot
.55136 .74089 Mdot
.43366 .32748 Mdot
.38431 .50862 Mdot
.37935 .48377 Mdot
.58438 .5669 Mdot
.43447 .31437 Mdot
.3899 .55238 Mdot
.46088 .5855 Mdot
.50394 .67205 Mdot
.62875 .33068 Mdot
.5162 .68609 Mdot
.37811 .4982 Mdot
.3186 .51766 Mdot
.53011 .70071 Mdot
.17775 .41295 Mdot
.41391 .37995 Mdot
.67449 .51461 Mdot
.32546 .5462 Mdot
.33975 .52696 Mdot
.82664 .59462 Mdot
.63199 .36838 Mdot
.72138 .69269 Mdot
.52157 .39605 Mdot
.64004 .72623 Mdot
.76697 .44613 Mdot
.48248 .85045 Mdot
.76484 .33177 Mdot
.34386 .4599 Mdot
.48574 .50383 Mdot
.28545 .52385 Mdot
.67455 .50474 Mdot
.41279 .64777 Mdot
.39009 .53156 Mdot
.37716 .52002 Mdot
.60241 .33506 Mdot
.62401 .67228 Mdot
.6546 .2717 Mdot
.59236 .48609 Mdot
.42031 .33147 Mdot
.50994 .64358 Mdot
.41622 .51277 Mdot
.49181 .4045 Mdot
.57296 .34142 Mdot
.79207 .42538 Mdot
.39446 .51319 Mdot
.53143 .18842 Mdot
.68926 .48403 Mdot
.6755 .50862 Mdot
.55691 .35649 Mdot
.60509 .26093 Mdot
.37593 .54165 Mdot
.69942 .54099 Mdot
.35838 .50539 Mdot
.58007 .30891 Mdot
.4122 .55669 Mdot
.42311 .31178 Mdot
.41983 .49199 Mdot
.5952 .47367 Mdot
.58419 .82556 Mdot
.37098 .40212 Mdot
.52791 .64322 Mdot
.56134 .40011 Mdot
.59815 .35577 Mdot
.53797 .69086 Mdot
.59577 .35856 Mdot
.28804 .6505 Mdot
.40092 .72253 Mdot
.41824 .32719 Mdot
.34564 .57636 Mdot
.40816 .30725 Mdot
.63292 .36724 Mdot
.38219 .53452 Mdot
.18338 .3964 Mdot
.60222 .36554 Mdot
.81386 .51608 Mdot
.66944 .52638 Mdot
.62871 .37285 Mdot
.37791 .55817 Mdot
.65724 .45276 Mdot
.55093 .35853 Mdot
.74492 .507 Mdot
.38151 .48742 Mdot
.51619 .69848 Mdot
.38265 .47996 Mdot
.36832 .57038 Mdot
.59257 .3281 Mdot
.33992 .508 Mdot
.68192 .52741 Mdot
.49366 .70615 Mdot
.42369 .82676 Mdot
.74307 .52508 Mdot
.3903 .54807 Mdot
.36492 .51445 Mdot
.54709 .65732 Mdot
.35649 .5474 Mdot
.68535 .55691 Mdot
.89618 .44349 Mdot
.41032 .31983 Mdot
.6014 .39253 Mdot
.76731 .45956 Mdot
.40016 .45199 Mdot
.37824 .46723 Mdot
.18082 .58942 Mdot
.77665 .47299 Mdot
.68788 .54511 Mdot
.42799 .57647 Mdot
.55293 .38004 Mdot
.41379 .34116 Mdot
.64428 .55669 Mdot
.35463 .47756 Mdot
.38599 .51717 Mdot
.43151 .32414 Mdot
.36345 .78146 Mdot
.59729 .24257 Mdot
.63989 .51789 Mdot
.45676 .56691 Mdot
.56504 .41193 Mdot
.36326 .54285 Mdot
.54025 .23377 Mdot
.53976 .67708 Mdot
.69569 .52981 Mdot
.69995 .72067 Mdot
.40621 .46853 Mdot
.65403 .55578 Mdot
.6577 .52147 Mdot
.4404 .54936 Mdot
.49373 .62128 Mdot
.48281 .68837 Mdot
.51958 .64493 Mdot
.71885 .25004 Mdot
.31406 .31544 Mdot
.61244 .34463 Mdot
.6714 .54754 Mdot
.5699 .39178 Mdot
.40072 .2967 Mdot
.48837 .42232 Mdot
.59464 .3932 Mdot
.53761 .6989 Mdot
.5407 .39631 Mdot
.38287 .48297 Mdot
.65121 .52548 Mdot
.62531 .35307 Mdot
.42996 .49624 Mdot
.56097 .60781 Mdot
.6004 .29521 Mdot
.42551 .35863 Mdot
.44038 .35357 Mdot
.41693 .52659 Mdot
.63685 .35173 Mdot
.39782 .52294 Mdot
.63228 .55639 Mdot
.59096 .60583 Mdot
.41455 .46675 Mdot
.58948 .36526 Mdot
.5186 .60399 Mdot
.585 .25048 Mdot
.41897 .57689 Mdot
.3843 .49698 Mdot
.36583 .53981 Mdot
.35759 .50547 Mdot
.62624 .69948 Mdot
.64015 .5092 Mdot
.53979 .57837 Mdot
.73668 .47863 Mdot
.52737 .68227 Mdot
.478 .65352 Mdot
.498 .22922 Mdot
.64738 .31771 Mdot
.68214 .53981 Mdot
.35679 .53273 Mdot
.74938 .52069 Mdot
.29073 .76514 Mdot
.17025 .42539 Mdot
.44118 .30334 Mdot
.62833 .34477 Mdot
.51916 .63539 Mdot
.56884 .34575 Mdot
.3735 .53284 Mdot
.44721 .54139 Mdot
.4743 .85693 Mdot
.6513 .57881 Mdot
.42465 .33354 Mdot
.36689 .53857 Mdot
.31412 .30525 Mdot
.55702 .37932 Mdot
.54301 .3849 Mdot
.3927 .55408 Mdot
.48173 .69978 Mdot
.77529 .69734 Mdot
.67399 .50734 Mdot
.47958 .57603 Mdot
.4161 .60875 Mdot
.71167 .59516 Mdot
.64818 .54334 Mdot
.60582 .27977 Mdot
.62958 .34349 Mdot
.2692 .67425 Mdot
.52826 .68625 Mdot
.42711 .33258 Mdot
.44861 .49145 Mdot
.51898 .7057 Mdot
.58502 .33135 Mdot
.50163 .69927 Mdot
.42358 .4974 Mdot
.65615 .50327 Mdot
.55816 .35866 Mdot
.62189 .55619 Mdot
.48956 .62505 Mdot
.39381 .32289 Mdot
.56483 .57019 Mdot
.43492 .68792 Mdot
.31178 .69165 Mdot
.36265 .54756 Mdot
.48714 .40021 Mdot
.35931 .49014 Mdot
.52238 .62936 Mdot
.35809 .51016 Mdot
.49146 .60746 Mdot
.569 .35034 Mdot
.35959 .55407 Mdot
.37564 .46077 Mdot
.36806 .63443 Mdot
.39354 .50482 Mdot
.35313 .55669 Mdot
.35088 .52407 Mdot
.51708 .73524 Mdot
.38136 .5899 Mdot
.5075 .68558 Mdot
.68183 .28505 Mdot
.56489 .37571 Mdot
.44172 .34662 Mdot
.42269 .35489 Mdot
.26529 .33824 Mdot
.38174 .36821 Mdot
.63635 .68049 Mdot
.51313 .67686 Mdot
.67059 .51888 Mdot
.35531 .50941 Mdot
.62478 .76997 Mdot
.74579 .43694 Mdot
.55415 .38243 Mdot
.74268 .52443 Mdot
.45369 .48784 Mdot
.78349 .64522 Mdot
.37978 .56006 Mdot
.63272 .20784 Mdot
.3431 .45277 Mdot
.41857 .55013 Mdot
.53675 .37771 Mdot
.39794 .38925 Mdot
.37135 .55445 Mdot
.52871 .63388 Mdot
.42605 .3209 Mdot
.4564 .66818 Mdot
.62234 .41776 Mdot
.61626 .28195 Mdot
.40828 .67972 Mdot
.35461 .49862 Mdot
.55954 .35891 Mdot
.50055 .68715 Mdot
.74018 .30431 Mdot
.68141 .51484 Mdot
.59871 .52169 Mdot
.30641 .58162 Mdot
.19313 .53131 Mdot
.42756 .32806 Mdot
.35686 .77469 Mdot
.40876 .49587 Mdot
.52025 .25101 Mdot
.3784 .44945 Mdot
.29489 .76777 Mdot
.38769 .3131 Mdot
.47671 .68417 Mdot
.68019 .55294 Mdot
.5404 .70431 Mdot
.32868 .71369 Mdot
.69124 .59151 Mdot
.55277 .51794 Mdot
.57671 .38286 Mdot
.54709 .57805 Mdot
.51181 .65064 Mdot
.39335 .46814 Mdot
.7872 .73793 Mdot
.53939 .66962 Mdot
.49378 .64141 Mdot
.19843 .4402 Mdot
.19135 .45002 Mdot
.45934 .52681 Mdot
.51822 .70916 Mdot
.5764 .38126 Mdot
.39553 .33474 Mdot
.37609 .48061 Mdot
.36755 .49485 Mdot
.52604 .7009 Mdot
.53857 .38121 Mdot
.47247 .56357 Mdot
.58048 .36767 Mdot
.50213 .67207 Mdot
.56558 .36979 Mdot
.75401 .49716 Mdot
.62891 .35685 Mdot
.34177 .53098 Mdot
.35719 .5101 Mdot
.58639 .41127 Mdot
.5209 .69606 Mdot
.3705 .4688 Mdot
.41863 .49646 Mdot
.51942 .65553 Mdot
.52199 .40579 Mdot
.503 .76103 Mdot
.38887 .5433 Mdot
.3962 .48769 Mdot
.43301 .32342 Mdot
.46947 .39889 Mdot
.42155 .21341 Mdot
.3776 .47261 Mdot
.40852 .29814 Mdot
.48719 .68932 Mdot
.40124 .5211 Mdot
.55989 .74945 Mdot
.7469 .50098 Mdot
.40677 .47006 Mdot
.62261 .37681 Mdot
.43623 .49431 Mdot
.69817 .76242 Mdot
.40947 .54854 Mdot
.51211 .65728 Mdot
.48989 .65601 Mdot
.20933 .43661 Mdot
.53451 .66649 Mdot
.59545 .38642 Mdot
.65567 .53704 Mdot
.32404 .78838 Mdot
.58138 .38766 Mdot
.43915 .53111 Mdot
.27394 .26765 Mdot
.37934 .56507 Mdot
.42414 .48355 Mdot
.80448 .60773 Mdot
.57865 .38697 Mdot
.49572 .65306 Mdot
.59659 .54624 Mdot
.33098 .47499 Mdot
.69252 .52025 Mdot
.4453 .53687 Mdot
.33739 .50587 Mdot
.79639 .49336 Mdot
.75864 .61767 Mdot
.66793 .57054 Mdot
.39473 .43875 Mdot
.37697 .47226 Mdot
.50775 .34863 Mdot
.3588 .51515 Mdot
.40667 .30628 Mdot
.50258 .63982 Mdot
.59566 .33877 Mdot
.40113 .32578 Mdot
.39555 .53414 Mdot
.42197 .33837 Mdot
.60986 .34155 Mdot
.69826 .53754 Mdot
.37745 .53692 Mdot
.38395 .34291 Mdot
.42031 .33307 Mdot
.36024 .48521 Mdot
.48975 .68333 Mdot
.41584 .42689 Mdot
.40365 .5189 Mdot
.4019 .47454 Mdot
.52533 .69966 Mdot
.15554 .42548 Mdot
.40962 .55073 Mdot
.55138 .33864 Mdot
.49265 .63983 Mdot
.73194 .55332 Mdot
.60575 .33774 Mdot
.33705 .5088 Mdot
.69643 .54541 Mdot
.65507 .5518 Mdot
.55825 .38882 Mdot
.55127 .6753 Mdot
.54606 .40473 Mdot
.51122 .60313 Mdot
.32373 .53152 Mdot
.40539 .56838 Mdot
.31626 .23146 Mdot
.46624 .8461 Mdot
.53981 .65809 Mdot
.5299 .36822 Mdot
.58934 .4885 Mdot
.67264 .55027 Mdot
.55645 .39472 Mdot
.54035 .64925 Mdot
.52318 .63801 Mdot
.5021 .69692 Mdot
.42526 .34614 Mdot
.51948 .39732 Mdot
.49672 .71566 Mdot
.48203 .69948 Mdot
.38277 .48527 Mdot
.37543 .47114 Mdot
.29833 .45807 Mdot
.33587 .37433 Mdot
.39287 .32219 Mdot
.5911 .35295 Mdot
.86249 .41743 Mdot
.63729 .56127 Mdot
.36908 .63694 Mdot
.41306 .46537 Mdot
.65818 .8677 Mdot
.39078 .55974 Mdot
.36059 .51762 Mdot
.49766 .70865 Mdot
.38893 .35523 Mdot
.41035 .30932 Mdot
.5083 .6492 Mdot
.50406 .62688 Mdot
.41048 .30492 Mdot
.27483 .72155 Mdot
.38129 .81593 Mdot
.6026 .58199 Mdot
.52014 .66253 Mdot
.4359 .7073 Mdot
.69659 .52283 Mdot
.48096 .62583 Mdot
.63239 .55238 Mdot
.55685 .37675 Mdot
.62675 .33978 Mdot
.64071 .52201 Mdot
.37887 .48996 Mdot
.61986 .35264 Mdot
.32831 .53394 Mdot
.32262 .76684 Mdot
.42213 .77387 Mdot
.75267 .39058 Mdot
.34187 .47733 Mdot
.65994 .27816 Mdot
.66865 .32229 Mdot
.40674 .53669 Mdot
.5969 .75352 Mdot
.42443 .33528 Mdot
.4704 .66521 Mdot
.68875 .55521 Mdot
.66712 .79253 Mdot
.36102 .54023 Mdot
.51328 .66159 Mdot
.67594 .52479 Mdot
.22763 .42188 Mdot
.61769 .60645 Mdot
.36964 .53892 Mdot
.82004 .6883 Mdot
.50718 .73967 Mdot
.59792 .33889 Mdot
.4049 .18731 Mdot
.5317 .71642 Mdot
.41977 .28036 Mdot
.70693 .46837 Mdot
.18503 .56036 Mdot
.49481 .66491 Mdot
.52502 .37539 Mdot
.51 .64479 Mdot
.39824 .31256 Mdot
.47109 .69257 Mdot
.54897 .36906 Mdot
.39003 .50731 Mdot
.58927 .35942 Mdot
.39107 .32842 Mdot
.53095 .24075 Mdot
.69136 .55303 Mdot
.62342 .3776 Mdot
.66583 .54099 Mdot
.33321 .29706 Mdot
.7919 .53462 Mdot
.68413 .5219 Mdot
.21565 .41037 Mdot
.41591 .47721 Mdot
.51275 .72108 Mdot
.60959 .35713 Mdot
.69474 .46544 Mdot
.5706 .54847 Mdot
.52921 .67643 Mdot
.5866 .34952 Mdot
.31038 .5793 Mdot
.27913 .28324 Mdot
.32781 .55968 Mdot
.34271 .30954 Mdot
.52197 .65973 Mdot
.54294 .39093 Mdot
.69859 .27891 Mdot
.54061 .69555 Mdot
.609 .36234 Mdot
.67105 .55597 Mdot
.64749 .53805 Mdot
.37802 .5535 Mdot
.61992 .50207 Mdot
.60114 .34637 Mdot
.683 .31981 Mdot
.48265 .65902 Mdot
.23223 .41871 Mdot
.39574 .35644 Mdot
.57413 .37543 Mdot
.4233 .55446 Mdot
.5077 .6138 Mdot
.74837 .49779 Mdot
.4763 .50885 Mdot
.85803 .42715 Mdot
.59434 .35389 Mdot
.49809 .64051 Mdot
.51529 .66672 Mdot
.42375 .573 Mdot
.58832 .51863 Mdot
.55086 .40691 Mdot
.28148 .29594 Mdot
.24742 .368 Mdot
.59662 .32835 Mdot
.6571 .38508 Mdot
.43628 .5403 Mdot
.35012 .49875 Mdot
.67481 .55116 Mdot
.38925 .50146 Mdot
.48551 .69926 Mdot
.36604 .55217 Mdot
.64471 .54378 Mdot
.59272 .37933 Mdot
.37982 .53253 Mdot
.39574 .34136 Mdot
.68988 .56209 Mdot
.632 .53544 Mdot
.583 .37335 Mdot
.51398 .7073 Mdot
.44403 .35678 Mdot
.58082 .36542 Mdot
.35521 .49929 Mdot
.62166 .45843 Mdot
.42474 .50523 Mdot
.2681 .69912 Mdot
.53661 .70208 Mdot
.57052 .34662 Mdot
.48904 .63902 Mdot
.67071 .53996 Mdot
.73522 .47846 Mdot
.37053 .50353 Mdot
.60815 .36513 Mdot
.60298 .40895 Mdot
.30502 .74398 Mdot
.54793 .65577 Mdot
.66645 .40398 Mdot
.47921 .65992 Mdot
.6074 .32915 Mdot
.22745 .51283 Mdot
.42177 .32233 Mdot
.54936 .37894 Mdot
.46013 .83068 Mdot
.5959 .36447 Mdot
.39722 .50395 Mdot
.41209 .51365 Mdot
.61185 .33929 Mdot
.43118 .34679 Mdot
.78063 .34306 Mdot
.61287 .30011 Mdot
.49442 .65808 Mdot
.23174 .57475 Mdot
.86343 .49365 Mdot
.62346 .5125 Mdot
.68173 .54919 Mdot
.33643 .46668 Mdot
.41997 .55079 Mdot
.64157 .55929 Mdot
.70247 .52473 Mdot
.38788 .33942 Mdot
.54481 .37966 Mdot
.47674 .70964 Mdot
.69982 .54875 Mdot
.34355 .43675 Mdot
.36916 .33219 Mdot
.40977 .58431 Mdot
.41924 .60411 Mdot
.35308 .46614 Mdot
.24845 .3529 Mdot
.63989 .5358 Mdot
.41913 .51814 Mdot
.3917 .58728 Mdot
.6962 .53885 Mdot
.401 .31014 Mdot
.75604 .60834 Mdot
.56481 .36406 Mdot
.16725 .6301 Mdot
.42467 .5311 Mdot
.39964 .50815 Mdot
.65049 .51077 Mdot
.49532 .35625 Mdot
.51606 .70317 Mdot
.53692 .70364 Mdot
.62231 .36752 Mdot
.55677 .56266 Mdot
.34997 .53694 Mdot
.41109 .53431 Mdot
.56843 .35613 Mdot
.62785 .37329 Mdot
.71693 .35704 Mdot
.41002 .48936 Mdot
.67673 .52749 Mdot
.58793 .45739 Mdot
.6409 .53962 Mdot
.42943 .52789 Mdot
.40011 .50294 Mdot
.34349 .53368 Mdot
.42708 .54702 Mdot
.63139 .5343 Mdot
.41834 .51373 Mdot
.32395 .46463 Mdot
.49957 .70065 Mdot
.34191 .5155 Mdot
.24326 .36546 Mdot
.38876 .49224 Mdot
.39448 .32598 Mdot
.42522 .41103 Mdot
.36691 .54135 Mdot
.33938 .52132 Mdot
.60984 .30152 Mdot
.3804 .51033 Mdot
.63209 .55585 Mdot
.52403 .68016 Mdot
.67058 .54777 Mdot
.63642 .52874 Mdot
.60724 .38272 Mdot
.39243 .31693 Mdot
.39499 .45037 Mdot
.40396 .35632 Mdot
.40976 .45024 Mdot
.41273 .47482 Mdot
.72908 .46208 Mdot
.62438 .20133 Mdot
.59158 .23939 Mdot
.37003 .50267 Mdot
.60083 .37818 Mdot
.58933 .33916 Mdot
.48794 .53824 Mdot
.34173 .56824 Mdot
.64409 .56007 Mdot
.66019 .55262 Mdot
.31236 .40496 Mdot
.79416 .49726 Mdot
.39538 .32043 Mdot
.4885 .41169 Mdot
.32695 .53227 Mdot
.4125 .48596 Mdot
.40419 .56458 Mdot
.5881 .39242 Mdot
.61352 .45892 Mdot
.55477 .38231 Mdot
.74033 .5189 Mdot
.64416 .54573 Mdot
.35357 .53558 Mdot
.46291 .79015 Mdot
.54186 .6843 Mdot
.52396 .68111 Mdot
.6422 .55296 Mdot
.56183 .39878 Mdot
.3537 .41753 Mdot
.18357 .33849 Mdot
.50345 .73464 Mdot
.40343 .36408 Mdot
.40349 .54058 Mdot
.59266 .37558 Mdot
.53127 .65051 Mdot
.43789 .33678 Mdot
.40738 .47275 Mdot
.54539 .40689 Mdot
.36843 .5006 Mdot
.28541 .52178 Mdot
.49198 .6827 Mdot
.32255 .79262 Mdot
.54522 .66191 Mdot
.68878 .56122 Mdot
.692 .53573 Mdot
.40751 .50876 Mdot
.3441 .21579 Mdot
.52078 .72061 Mdot
.68511 .4893 Mdot
.38615 .31866 Mdot
.65557 .4601 Mdot
.41874 .30385 Mdot
.57919 .34446 Mdot
.42678 .32352 Mdot
.5544 .36001 Mdot
.33961 .38823 Mdot
.5402 .72474 Mdot
.40567 .32109 Mdot
.54172 .32564 Mdot
.33925 .56623 Mdot
.44249 .33662 Mdot
.3719 .43863 Mdot
.24761 .63106 Mdot
.57139 .35579 Mdot
.42573 .35009 Mdot
.39256 .4685 Mdot
.58234 .80857 Mdot
.68516 .53173 Mdot
.64533 .56245 Mdot
.33335 .54673 Mdot
.54484 .38248 Mdot
.52212 .63276 Mdot
.59916 .68695 Mdot
.70428 .57674 Mdot
.41562 .52782 Mdot
.36958 .55392 Mdot
.47637 .65891 Mdot
.55877 .70543 Mdot
.40428 .50326 Mdot
.36396 .61927 Mdot
.41386 .50107 Mdot
.6673 .55819 Mdot
.54526 .67711 Mdot
.51907 .67211 Mdot
.59396 .34523 Mdot
.51416 .7128 Mdot
.48953 .60452 Mdot
.6217 .46432 Mdot
.36056 .44123 Mdot
.67064 .53278 Mdot
.61531 .48285 Mdot
.74322 .52321 Mdot
.50496 .81589 Mdot
.47924 .64296 Mdot
.33685 .52353 Mdot
.4842 .65206 Mdot
.41163 .34473 Mdot
.51964 .69381 Mdot
.51014 .6349 Mdot
.4033 .5268 Mdot
.37043 .53372 Mdot
.58296 .38517 Mdot
.59017 .50962 Mdot
.49263 .69612 Mdot
.41629 .52118 Mdot
.36754 .56086 Mdot
.3522 .55669 Mdot
.5188 .46377 Mdot
.53717 .65462 Mdot
.30959 .61537 Mdot
.25575 .46399 Mdot
.49402 .69794 Mdot
.72467 .74231 Mdot
.71497 .47499 Mdot
.61977 .38915 Mdot
.61689 .54605 Mdot
.40966 .48806 Mdot
.61152 .3375 Mdot
.37402 .53295 Mdot
.41928 .60424 Mdot
.38332 .51856 Mdot
.42694 .30831 Mdot
.34403 .45978 Mdot
.61983 .33142 Mdot
.58422 .36375 Mdot
.41483 .54154 Mdot
.38052 .52948 Mdot
.55479 .24249 Mdot
.49853 .62599 Mdot
.51322 .70234 Mdot
.49788 .34524 Mdot
.40893 .32931 Mdot
.69518 .52621 Mdot
.35256 .51757 Mdot
.61184 .37664 Mdot
.58687 .36047 Mdot
.54124 .70454 Mdot
.57637 .35818 Mdot
.66492 .50721 Mdot
.36758 .5066 Mdot
.6434 .56154 Mdot
.4212 .3522 Mdot
.51712 .64272 Mdot
.35809 .53691 Mdot
.38351 .48486 Mdot
.49003 .65592 Mdot
.40034 .45796 Mdot
.43259 .32159 Mdot
.59554 .36219 Mdot
.49612 .6728 Mdot
.65384 .5379 Mdot
.56847 .34997 Mdot
.3897 .47534 Mdot
.85764 .41741 Mdot
.39647 .49854 Mdot
.40046 .47911 Mdot
.43408 .84017 Mdot
.34896 .4544 Mdot
.60431 .35235 Mdot
.47613 .68622 Mdot
.32902 .52655 Mdot
.27631 .33631 Mdot
.16487 .43008 Mdot
.56188 .38638 Mdot
.40075 .5446 Mdot
.51105 .82687 Mdot
.40765 .545 Mdot
.21593 .3724 Mdot
.44623 .23997 Mdot
.52217 .5556 Mdot
.31639 .50878 Mdot
.65333 .51383 Mdot
.58541 .38513 Mdot
.57118 .34976 Mdot
.25363 .57868 Mdot
.40711 .52874 Mdot
.28913 .49244 Mdot
.38711 .4614 Mdot
.647 .54163 Mdot
.29495 .42858 Mdot
.59083 .35531 Mdot
.66881 .24776 Mdot
.36124 .49213 Mdot
.53619 .65188 Mdot
.53956 .39567 Mdot
.72624 .48259 Mdot
.39535 .47347 Mdot
.40814 .35582 Mdot
.66048 .57529 Mdot
.32665 .49091 Mdot
.66538 .53025 Mdot
.41401 .48468 Mdot
.32039 .45929 Mdot
.44935 .17405 Mdot
.49402 .69033 Mdot
.67798 .55276 Mdot
.666 .35136 Mdot
.3787 .44759 Mdot
.49488 .66951 Mdot
.52859 .68495 Mdot
.39047 .34432 Mdot
.56371 .49797 Mdot
.68319 .62637 Mdot
.45825 .75415 Mdot
.23773 .56709 Mdot
.54913 .39759 Mdot
.68456 .37182 Mdot
.37635 .47741 Mdot
.78888 .42972 Mdot
.64565 .56648 Mdot
.3965 .50808 Mdot
.26237 .64348 Mdot
.52401 .6472 Mdot
.40121 .48875 Mdot
.40732 .30723 Mdot
.76647 .37111 Mdot
.77921 .40194 Mdot
.74986 .68885 Mdot
.57035 .38223 Mdot
.44747 .53505 Mdot
.40515 .60294 Mdot
.61199 .38504 Mdot
.38503 .45298 Mdot
.60448 .35684 Mdot
.21633 .62777 Mdot
.43585 .33291 Mdot
.52215 .64245 Mdot
.71942 .47762 Mdot
.35019 .47432 Mdot
.37093 .56563 Mdot
.43787 .35118 Mdot
.34988 .49082 Mdot
.53765 .1738 Mdot
.74972 .40806 Mdot
.62409 .35499 Mdot
.50015 .69619 Mdot
.34169 .48472 Mdot
.56213 .45667 Mdot
.40806 .52353 Mdot
.40735 .74497 Mdot
.33806 .51787 Mdot
.67667 .61827 Mdot
.48721 .67203 Mdot
.66674 .53324 Mdot
.43807 .47844 Mdot
.37534 .5174 Mdot
.54874 .42193 Mdot
.31717 .49947 Mdot
.41657 .54601 Mdot
.53485 .63943 Mdot
.54305 .67144 Mdot
.50801 .68458 Mdot
.56332 .34518 Mdot
.79231 .4891 Mdot
.67819 .53608 Mdot
.44303 .51817 Mdot
.70072 .54779 Mdot
.47071 .55897 Mdot
.42743 .35819 Mdot
.59307 .79439 Mdot
.34284 .49885 Mdot
.50948 .6765 Mdot
.67945 .69463 Mdot
.48578 .68662 Mdot
.53323 .43408 Mdot
.65369 .52298 Mdot
.53151 .65379 Mdot
.36615 .51707 Mdot
.60092 .48617 Mdot
.66247 .76293 Mdot
.66427 .54792 Mdot
.40851 .45363 Mdot
.63272 .34997 Mdot
.76673 .4714 Mdot
.87636 .44657 Mdot
.68834 .54364 Mdot
.66819 .3581 Mdot
.40883 .53257 Mdot
.5391 .69232 Mdot
.65679 .51101 Mdot
.68004 .52072 Mdot
.57884 .3542 Mdot
.36868 .53498 Mdot
.36455 .53616 Mdot
.60841 .33042 Mdot
.65744 .55098 Mdot
.3825 .57224 Mdot
.40261 .56113 Mdot
.47448 .85881 Mdot
.25857 .51568 Mdot
.12775 .5276 Mdot
.50556 .60011 Mdot
.27176 .66247 Mdot
.59042 .67562 Mdot
.5025 .63786 Mdot
.36857 .54201 Mdot
.35042 .46403 Mdot
.59918 .34687 Mdot
.38304 .50153 Mdot
.53099 .37225 Mdot
.68408 .54065 Mdot
.71949 .74283 Mdot
.73077 .64008 Mdot
.21007 .60847 Mdot
.38364 .50412 Mdot
.75092 .5646 Mdot
.40248 .3379 Mdot
.70408 .54997 Mdot
.50141 .67813 Mdot
.42659 .50328 Mdot
.56385 .24239 Mdot
.551 .37994 Mdot
.53488 .68389 Mdot
.66505 .27211 Mdot
.626 .27828 Mdot
.42954 .52683 Mdot
.57463 .33903 Mdot
.62508 .72609 Mdot
.3761 .62121 Mdot
.67436 .49804 Mdot
.42339 .30591 Mdot
.55696 .38108 Mdot
.6402 .54643 Mdot
.55191 .74406 Mdot
.53421 .66019 Mdot
.49729 .72321 Mdot
.52511 .22023 Mdot
.59842 .39462 Mdot
.39843 .32994 Mdot
.79123 .49584 Mdot
.80317 .44331 Mdot
.42651 .30834 Mdot
.61739 .33543 Mdot
.54034 .66342 Mdot
.50329 .66154 Mdot
.5238 .67864 Mdot
.67972 .25546 Mdot
.55052 .67578 Mdot
.38263 .65912 Mdot
.37201 .56386 Mdot
.30437 .47331 Mdot
.40235 .54559 Mdot
.63222 .55016 Mdot
.49107 .67554 Mdot
.58178 .58493 Mdot
.43858 .50935 Mdot
.72536 .7197 Mdot
.41356 .5327 Mdot
.68593 .50286 Mdot
.40388 .48583 Mdot
.40985 .65762 Mdot
.4871 .64385 Mdot
.37687 .50033 Mdot
.62417 .53304 Mdot
.41655 .33375 Mdot
.47106 .62436 Mdot
.36643 .53972 Mdot
.62261 .66377 Mdot
.35346 .45059 Mdot
.25326 .69779 Mdot
.23824 .42698 Mdot
.40427 .36425 Mdot
.45521 .5837 Mdot
.5495 .39171 Mdot
.30286 .47262 Mdot
.36023 .58846 Mdot
.66297 .54647 Mdot
.78464 .57325 Mdot
.56595 .37717 Mdot
.34502 .40389 Mdot
.43403 .57286 Mdot
.3956 .31305 Mdot
.55625 .66559 Mdot
.62755 .53971 Mdot
.43099 .50272 Mdot
.43791 .55229 Mdot
.2261 .64138 Mdot
.33943 .57345 Mdot
.35957 .54977 Mdot
.4326 .35366 Mdot
.31641 .62768 Mdot
.38797 .48898 Mdot
.53047 .43437 Mdot
.49199 .71974 Mdot
.33385 .55157 Mdot
.31051 .61257 Mdot
.41551 .52217 Mdot
.537 .68752 Mdot
.54018 .72122 Mdot
.68529 .66815 Mdot
.38627 .3221 Mdot
.33831 .51649 Mdot
.21757 .46812 Mdot
.35686 .49384 Mdot
.67394 .52618 Mdot
.4244 .54439 Mdot
.55078 .37459 Mdot
.66848 .25596 Mdot
.61164 .34592 Mdot
.37895 .54618 Mdot
.5226 .67211 Mdot
.64264 .51748 Mdot
.56087 .22565 Mdot
.47106 .25046 Mdot
.37049 .65276 Mdot
.17161 .56218 Mdot
.43017 .3459 Mdot
.42681 .30393 Mdot
.62908 .5324 Mdot
.37745 .49879 Mdot
.20519 .45256 Mdot
.3357 .46229 Mdot
.39683 .48655 Mdot
.38385 .51954 Mdot
.77963 .50649 Mdot
.67711 .54727 Mdot
.57032 .36365 Mdot
.40215 .50189 Mdot
.41717 .5167 Mdot
.49242 .64573 Mdot
.41797 .33238 Mdot
.60034 .3376 Mdot
.41394 .32371 Mdot
.59997 .37275 Mdot
.71238 .75412 Mdot
.43538 .48387 Mdot
.4138 .3337 Mdot
.666 .57187 Mdot
.52653 .69965 Mdot
.62449 .45918 Mdot
.57763 .34563 Mdot
.59112 .35186 Mdot
.41403 .52987 Mdot
.53613 .69292 Mdot
.50726 .71046 Mdot
.4117 .34573 Mdot
.68674 .52146 Mdot
.37439 .54056 Mdot
.41837 .48299 Mdot
.50077 .54678 Mdot
.58037 .3924 Mdot
.32121 .58516 Mdot
.65714 .68771 Mdot
.37251 .50054 Mdot
.51596 .70888 Mdot
.38731 .52602 Mdot
.46609 .80441 Mdot
.53485 .70119 Mdot
.41063 .5526 Mdot
.807 .41968 Mdot
.60397 .458 Mdot
.64579 .64853 Mdot
.34686 .54177 Mdot
.18241 .63445 Mdot
.37043 .4762 Mdot
.50318 .84882 Mdot
.53466 .26608 Mdot
.35451 .53842 Mdot
.38092 .47926 Mdot
.48199 .77212 Mdot
.39618 .53747 Mdot
.62078 .33052 Mdot
.34067 .40456 Mdot
.51652 .63342 Mdot
.58684 .62471 Mdot
.45657 .41878 Mdot
.3841 .3306 Mdot
.62272 .36678 Mdot
.6495 .40307 Mdot
.41936 .30879 Mdot
.51854 .65982 Mdot
.35717 .5056 Mdot
.54025 .55032 Mdot
.56679 .33802 Mdot
.37434 .57365 Mdot
.66784 .5234 Mdot
.70897 .39469 Mdot
.52628 .37983 Mdot
.65919 .53519 Mdot
.3497 .48173 Mdot
.50349 .7632 Mdot
.43021 .23082 Mdot
.33905 .80736 Mdot
.64154 .51646 Mdot
.65065 .54988 Mdot
.71034 .27347 Mdot
.38291 .3271 Mdot
.22586 .6124 Mdot
.65302 .61494 Mdot
.67478 .5062 Mdot
.23266 .48621 Mdot
.55405 .38467 Mdot
.62198 .65286 Mdot
.47039 .66471 Mdot
.40613 .56764 Mdot
.3688 .51666 Mdot
.68959 .52501 Mdot
.54748 .75106 Mdot
.43379 .17837 Mdot
.66454 .54162 Mdot
.33892 .44506 Mdot
.52211 .48681 Mdot
.71003 .47293 Mdot
.58961 .39008 Mdot
.38621 .32697 Mdot
.40488 .28248 Mdot
.49874 .64536 Mdot
.3883 .33076 Mdot
.77174 .39076 Mdot
.3461 .49505 Mdot
.65711 .54508 Mdot
.72969 .48942 Mdot
.65162 .53544 Mdot
.41504 .30865 Mdot
.39828 .36279 Mdot
.50054 .70122 Mdot
.5131 .70149 Mdot
.28661 .67645 Mdot
.28757 .40889 Mdot
.41098 .54392 Mdot
.68923 .72669 Mdot
.48219 .66339 Mdot
.43875 .59818 Mdot
.41699 .30085 Mdot
.41352 .33084 Mdot
.27366 .51831 Mdot
.35325 .52851 Mdot
.20914 .42764 Mdot
.35358 .52505 Mdot
.29439 .42168 Mdot
.37601 .45128 Mdot
.57772 .35592 Mdot
.35035 .528 Mdot
.41486 .38325 Mdot
.43562 .54095 Mdot
.42181 .54201 Mdot
.54667 .38473 Mdot
.32471 .49961 Mdot
.55092 .37346 Mdot
.38212 .54828 Mdot
.39978 .29774 Mdot
.61432 .3755 Mdot
.30504 .3267 Mdot
.56615 .32891 Mdot
.6361 .35191 Mdot
.39303 .34151 Mdot
.3992 .35746 Mdot
.29769 .30455 Mdot
.50064 .67645 Mdot
.48229 .61861 Mdot
.38166 .4977 Mdot
.54274 .38502 Mdot
.67817 .54953 Mdot
.41704 .51137 Mdot
.3581 .4526 Mdot
.35994 .55284 Mdot
.5085 .64114 Mdot
.55311 .40573 Mdot
.41635 .33867 Mdot
.56557 .34285 Mdot
.53273 .40906 Mdot
.5395 .35894 Mdot
.39488 .58978 Mdot
.43645 .4652 Mdot
.29094 .70448 Mdot
.73797 .67078 Mdot
.76815 .32067 Mdot
.5365 .66691 Mdot
.62341 .37658 Mdot
.38997 .35016 Mdot
.45644 .4738 Mdot
.50486 .67383 Mdot
.54907 .36984 Mdot
.36722 .50146 Mdot
.40955 .45338 Mdot
.66633 .58161 Mdot
.29627 .48508 Mdot
.25194 .37818 Mdot
.53697 .36568 Mdot
.5248 .37479 Mdot
.80021 .44209 Mdot
.33739 .40978 Mdot
.56374 .5577 Mdot
.39511 .51698 Mdot
.41071 .35577 Mdot
.53139 .65067 Mdot
.4767 .21509 Mdot
.69074 .54932 Mdot
.58941 .51429 Mdot
.38229 .50383 Mdot
.62197 .5995 Mdot
.5238 .6739 Mdot
.40032 .31234 Mdot
.69061 .52586 Mdot
.3926 .36199 Mdot
.60098 .39184 Mdot
.18002 .47333 Mdot
.35408 .49193 Mdot
.40889 .54835 Mdot
.68683 .55908 Mdot
.51106 .64583 Mdot
.43216 .35935 Mdot
.27781 .72029 Mdot
.61171 .34082 Mdot
.20153 .42644 Mdot
.50024 .71248 Mdot
.4142 .68404 Mdot
.56199 .34495 Mdot
.64275 .55286 Mdot
.30943 .29838 Mdot
.64395 .54276 Mdot
.36835 .54684 Mdot
.5147 .67464 Mdot
.68369 .53122 Mdot
.55833 .4367 Mdot
.53938 .82083 Mdot
.42912 .70081 Mdot
.34697 .51228 Mdot
.62912 .78615 Mdot
.35922 .7934 Mdot
.50064 .74668 Mdot
.69625 .54781 Mdot
.40535 .51911 Mdot
.36973 .45955 Mdot
.36011 .49528 Mdot
.65935 .51818 Mdot
.70955 .45088 Mdot
.57422 .35225 Mdot
.40842 .54022 Mdot
.38899 .34327 Mdot
.55394 .37231 Mdot
.73093 .48164 Mdot
.60003 .35084 Mdot
.49001 .62951 Mdot
.4221 .54924 Mdot
.61087 .50348 Mdot
.59711 .82813 Mdot
.66907 .54793 Mdot
.6361 .35093 Mdot
.42406 .51922 Mdot
.77725 .54319 Mdot
.50783 .68224 Mdot
.61433 .34241 Mdot
.39956 .50882 Mdot
.6777 .44994 Mdot
.55031 .24011 Mdot
.59801 .35137 Mdot
.50018 .66446 Mdot
.55243 .76259 Mdot
.38713 .50067 Mdot
.36677 .47721 Mdot
.51251 .64819 Mdot
.44014 .40809 Mdot
.67874 .27318 Mdot
.38282 .52777 Mdot
.66534 .53377 Mdot
.20093 .34293 Mdot
.35199 .55315 Mdot
.26666 .48291 Mdot
.5724 .38533 Mdot
.64422 .67421 Mdot
.32651 .58949 Mdot
.45657 .57204 Mdot
.4966 .78515 Mdot
.4915 .4329 Mdot
.69888 .75648 Mdot
.53235 .37869 Mdot
.56151 .28242 Mdot
.69281 .76669 Mdot
.62951 .52196 Mdot
.56934 .66496 Mdot
.48484 .5752 Mdot
.65215 .23649 Mdot
.5744 .74201 Mdot
.51123 .3151 Mdot
.58158 .2426 Mdot
.52517 .52341 Mdot
.6008 .36597 Mdot
.39026 .39794 Mdot
.37433 .53747 Mdot
.35245 .7909 Mdot
.37122 .62515 Mdot
.40815 .17884 Mdot
.61952 .79035 Mdot
.22041 .46724 Mdot
.61633 .77902 Mdot
.49129 .82301 Mdot
.2714 .68406 Mdot
.72063 .68476 Mdot
.2068 .36272 Mdot
.79868 .41288 Mdot
.20538 .52055 Mdot
.45299 .49603 Mdot
.49245 .4056 Mdot
.20138 .6329 Mdot
.39197 .68333 Mdot
.32373 .23404 Mdot
.60218 .34327 Mdot
.47713 .68929 Mdot
.4912 .57091 Mdot
.54061 .64022 Mdot
.62079 .58241 Mdot
.50961 .79209 Mdot
.48657 .84341 Mdot
.40141 .65029 Mdot
.18256 .64131 Mdot
.26872 .62677 Mdot
.65321 .18533 Mdot
.59564 .29801 Mdot
.51218 .72393 Mdot
.4703 .31811 Mdot
.80206 .45701 Mdot
.72484 .6264 Mdot
.50878 .59689 Mdot
.75409 .46836 Mdot
.31426 .34825 Mdot
.5143 .6619 Mdot
.36683 .61442 Mdot
.64309 .30858 Mdot
.74699 .61516 Mdot
.38966 .26745 Mdot
.50824 .80646 Mdot
.55058 .53596 Mdot
.61252 .64841 Mdot
.69176 .36546 Mdot
.85771 .42078 Mdot
.25053 .44243 Mdot
.41016 .79781 Mdot
.61972 .57191 Mdot
.55353 .75363 Mdot
.60284 .21589 Mdot
.30593 .38774 Mdot
.80339 .45396 Mdot
.81706 .55344 Mdot
.32347 .78127 Mdot
.83344 .56069 Mdot
.48058 .62024 Mdot
.35732 .54966 Mdot
.4007 .78223 Mdot
.24203 .52786 Mdot
.41668 .29036 Mdot
.76778 .66359 Mdot
.42226 .35322 Mdot
.50857 .62219 Mdot
.66013 .25761 Mdot
.39208 .65628 Mdot
.20577 .41849 Mdot
.42897 .36476 Mdot
.34046 .47981 Mdot
.38557 .14153 Mdot
.69155 .75799 Mdot
.67986 .66646 Mdot
.47636 .8591 Mdot
.67826 .59957 Mdot
.22833 .42826 Mdot
.68033 .52644 Mdot
.6527 .79965 Mdot
.50678 .66515 Mdot
.78606 .70812 Mdot
.58414 .82159 Mdot
.41863 .19657 Mdot
.15085 .35288 Mdot
.77601 .4215 Mdot
.53707 .57005 Mdot
.48833 .44033 Mdot
.27656 .35396 Mdot
.47742 .18121 Mdot
.3766 .21404 Mdot
.77109 .53026 Mdot
.18773 .59487 Mdot
.65793 .79068 Mdot
.22747 .50563 Mdot
.18741 .49145 Mdot
.64066 .23121 Mdot
.51081 .43163 Mdot
.53424 .62708 Mdot
.60593 .31627 Mdot
.58784 .76923 Mdot
.79728 .6373 Mdot
.25964 .4814 Mdot
.17267 .35013 Mdot
.43111 .37056 Mdot
.52489 .27137 Mdot
.41858 .8194 Mdot
.3249 .3188 Mdot
.24364 .49612 Mdot
.73237 .30122 Mdot
.39153 .58103 Mdot
.76311 .33704 Mdot
.64019 .74721 Mdot
.6615 .40446 Mdot
.7916 .39772 Mdot
.61242 .71325 Mdot
.24143 .66953 Mdot
.40875 .76853 Mdot
.80534 .46769 Mdot
.50835 .62941 Mdot
.29273 .38141 Mdot
.24048 .46141 Mdot
.46652 .85821 Mdot
.6659 .35267 Mdot
.38962 .85309 Mdot
.64251 .26527 Mdot
.39098 .44475 Mdot
.3526 .5873 Mdot
.37909 .4227 Mdot
.27778 .40558 Mdot
.36824 .55999 Mdot
.7538 .55492 Mdot
.45184 .85316 Mdot
.25409 .62148 Mdot
.65918 .4147 Mdot
.78646 .57843 Mdot
.34507 .81098 Mdot
.32302 .73708 Mdot
.56245 .25269 Mdot
.2898 .45394 Mdot
.76353 .29366 Mdot
.56305 .37292 Mdot
.2255 .50557 Mdot
.65797 .50028 Mdot
.48413 .22165 Mdot
.4589 .7458 Mdot
.45538 .19544 Mdot
.45065 .85318 Mdot
.68551 .2866 Mdot
.61335 .25438 Mdot
.33752 .27675 Mdot
.19498 .41698 Mdot
.78347 .60548 Mdot
.44607 .5297 Mdot
.55758 .61913 Mdot
.42494 .35633 Mdot
.32241 .71174 Mdot
.22865 .53269 Mdot
.48165 .28556 Mdot
.32037 .49837 Mdot
.40182 .24108 Mdot
.51931 .38908 Mdot
.5968 .49883 Mdot
.86186 .54324 Mdot
.36641 .57734 Mdot
.77886 .47066 Mdot
.29153 .75174 Mdot
.26355 .39688 Mdot
.41976 .81435 Mdot
.60595 .67343 Mdot
.82726 .56414 Mdot
.5551 .82904 Mdot
.47003 .26141 Mdot
.74226 .7141 Mdot
.45366 .86689 Mdot
.83358 .52883 Mdot
.31843 .55984 Mdot
.62785 .55404 Mdot
.88617 .56646 Mdot
.58333 .33232 Mdot
.79869 .53979 Mdot
.23809 .5672 Mdot
.6836 .4422 Mdot
.46596 .63347 Mdot
.43977 .46196 Mdot
.53122 .53047 Mdot
.52382 .74478 Mdot
.32822 .52909 Mdot
.85929 .48178 Mdot
.82231 .51923 Mdot
.84899 .52237 Mdot
.24287 .70211 Mdot
.74057 .71944 Mdot
.50679 .52712 Mdot
.39597 .67314 Mdot
.48219 .52983 Mdot
.43109 .53538 Mdot
.37252 .37791 Mdot
.77346 .41809 Mdot
.43611 .2213 Mdot
.71451 .62219 Mdot
.52673 .63071 Mdot
.72169 .70799 Mdot
.839 .31795 Mdot
.2831 .64344 Mdot
.28251 .59284 Mdot
.78673 .41557 Mdot
.27505 .41905 Mdot
.60852 .76307 Mdot
.4212 .21032 Mdot
.4433 .84118 Mdot
.47428 .56815 Mdot
.21557 .54586 Mdot
.49372 .31496 Mdot
.24106 .34349 Mdot
.5008 .358 Mdot
.53008 .81207 Mdot
.48434 .4697 Mdot
.52338 .20383 Mdot
.57807 .59872 Mdot
.42504 .18809 Mdot
.50296 .24283 Mdot
.71097 .38944 Mdot
.21511 .50854 Mdot
.75268 .51344 Mdot
.27062 .43829 Mdot
.53285 .49662 Mdot
.4469 .45098 Mdot
.49223 .43395 Mdot
.2639 .44578 Mdot
.25287 .3315 Mdot
.78923 .65006 Mdot
.45558 .87645 Mdot
.83392 .39585 Mdot
.19096 .65611 Mdot
.63968 .74108 Mdot
.40006 .57027 Mdot
.40045 .8259 Mdot
.84047 .57193 Mdot
.55369 .83616 Mdot
.69268 .3104 Mdot
.6081 .44639 Mdot
.69912 .55632 Mdot
.83488 .41087 Mdot
.5023 .33745 Mdot
.46496 .82161 Mdot
.77478 .34145 Mdot
.61802 .55071 Mdot
.61252 .19589 Mdot
.81611 .51512 Mdot
.45289 .72681 Mdot
.29794 .5441 Mdot
.40409 .5765 Mdot
.41259 .64698 Mdot
.48482 .63978 Mdot
.68215 .35861 Mdot
.29359 .39698 Mdot
.57793 .37313 Mdot
.36613 .32497 Mdot
.53886 .60535 Mdot
.34236 .46168 Mdot
.46454 .42008 Mdot
.47432 .68237 Mdot
.7355 .67259 Mdot
.6419 .47248 Mdot
.7748 .69854 Mdot
.75943 .40279 Mdot
.3158 .50127 Mdot
.26022 .40878 Mdot
.6387 .28658 Mdot
.71887 .2876 Mdot
.65616 .50369 Mdot
.5981 .80202 Mdot
.51973 .42386 Mdot
.29134 .38523 Mdot
.41125 .64064 Mdot
.2536 .67954 Mdot
.43692 .46411 Mdot
.66975 .68932 Mdot
.38315 .7365 Mdot
.59152 .50217 Mdot
.52921 .62529 Mdot
.54385 .63289 Mdot
.29749 .79103 Mdot
.75603 .35643 Mdot
.69635 .38333 Mdot
.58546 .80552 Mdot
.64609 .5251 Mdot
.49002 .69352 Mdot
.36694 .38907 Mdot
.24698 .68223 Mdot
.3933 .71975 Mdot
.55194 .23993 Mdot
.74864 .43696 Mdot
.49536 .28177 Mdot
.60616 .79061 Mdot
.62675 .78066 Mdot
.39865 .17827 Mdot
.55007 .65903 Mdot
.28385 .71576 Mdot
.20864 .58888 Mdot
.47802 .66789 Mdot
.46114 .64512 Mdot
.73917 .60395 Mdot
.78724 .66811 Mdot
.62979 .49158 Mdot
.18311 .59776 Mdot
.25923 .34032 Mdot
.69103 .45238 Mdot
.56721 .22722 Mdot
.2068 .49094 Mdot
.57355 .80755 Mdot
.39277 .62167 Mdot
.46599 .73464 Mdot
.38728 .43544 Mdot
.29905 .47284 Mdot
.82583 .36154 Mdot
.55357 .33512 Mdot
.41507 .67936 Mdot
.60664 .70743 Mdot
.35228 .50146 Mdot
.85694 .42685 Mdot
.32005 .76625 Mdot
.72183 .27984 Mdot
.67311 .5732 Mdot
.37833 .46641 Mdot
.43282 .54643 Mdot
.28135 .47371 Mdot
.66346 .67486 Mdot
.80818 .55375 Mdot
.2066 .49554 Mdot
.60861 .74215 Mdot
.37802 .62613 Mdot
.77834 .47285 Mdot
.50036 .80551 Mdot
.37973 .80113 Mdot
.57105 .48987 Mdot
.76615 .4052 Mdot
.32209 .29452 Mdot
.19797 .6582 Mdot
.50145 .39925 Mdot
.5057 .54283 Mdot
.73157 .58725 Mdot
.6331 .68861 Mdot
.52303 .21261 Mdot
.41917 .49036 Mdot
.66543 .27218 Mdot
.49123 .82066 Mdot
.30489 .23745 Mdot
.52953 .18717 Mdot
.86036 .44082 Mdot
.42281 .75111 Mdot
.62032 .68493 Mdot
.52047 .77459 Mdot
.27275 .25172 Mdot
.49223 .39763 Mdot
.70312 .7355 Mdot
.32652 .28537 Mdot
.59576 .79861 Mdot
.6205 .53914 Mdot
.61284 .60419 Mdot
.78807 .57402 Mdot
.76988 .68809 Mdot
.34883 .7552 Mdot
.5294 .80601 Mdot
.57405 .58542 Mdot
.82022 .62788 Mdot
.76751 .55887 Mdot
.51808 .5094 Mdot
.62387 .3731 Mdot
.71709 .30094 Mdot
.61822 .76981 Mdot
.6934 .70895 Mdot
.22097 .51657 Mdot
.52323 .34956 Mdot
.35192 .4009 Mdot
.44509 .69008 Mdot
.34345 .32497 Mdot
.63206 .70148 Mdot
.26048 .4076 Mdot
.49579 .83081 Mdot
.49343 .38169 Mdot
.62082 .26473 Mdot
.77458 .47165 Mdot
.17897 .50036 Mdot
.66897 .66998 Mdot
.75003 .34602 Mdot
.41526 .80123 Mdot
.51159 .25916 Mdot
.22779 .46299 Mdot
.47352 .91248 Mdot
.19545 .54446 Mdot
.75374 .63662 Mdot
.7978 .63502 Mdot
.40585 .81248 Mdot
.74839 .65442 Mdot
.49321 .17746 Mdot
.26123 .52207 Mdot
.3456 .38526 Mdot
.38229 .51882 Mdot
.85746 .54404 Mdot
.32666 .3486 Mdot
.80616 .62917 Mdot
.37455 .82233 Mdot
.42143 .65218 Mdot
.34013 .46507 Mdot
.54723 .35839 Mdot
.64096 .31709 Mdot
.3535 .32702 Mdot
.48416 .75809 Mdot
.25683 .53359 Mdot
.75342 .41809 Mdot
.61048 .38703 Mdot
.49893 .34698 Mdot
.47916 .72798 Mdot
.74389 .37439 Mdot
.6497 .68974 Mdot
.37821 .35317 Mdot
.56719 .52617 Mdot
.26472 .4348 Mdot
.32975 .59378 Mdot
.45121 .72934 Mdot
.46393 .19493 Mdot
.53294 .44687 Mdot
.60448 .35057 Mdot
.45333 .76017 Mdot
.19295 .59387 Mdot
.63032 .71868 Mdot
.81862 .56883 Mdot
.7076 .28878 Mdot
.47114 .47838 Mdot
.26643 .451 Mdot
.45752 .1865 Mdot
.22777 .34637 Mdot
.7407 .67889 Mdot
.38639 .60743 Mdot
.21489 .42339 Mdot
.53086 .5952 Mdot
.70768 .75671 Mdot
.20721 .52592 Mdot
.22699 .57229 Mdot
.5978 .30705 Mdot
.38256 .68895 Mdot
.43364 .65635 Mdot
.30236 .32217 Mdot
.57233 .5468 Mdot
.6687 .19589 Mdot
.46881 .67325 Mdot
.85144 .38013 Mdot
.67527 .55745 Mdot
.66621 .23245 Mdot
.31953 .28017 Mdot
.53209 .49179 Mdot
.57386 .55945 Mdot
.6796 .68233 Mdot
.67928 .61687 Mdot
.21113 .66257 Mdot
.37453 .20397 Mdot
.5389 .35865 Mdot
.19683 .46754 Mdot
.17449 .46726 Mdot
.4766 .76956 Mdot
.33199 .50464 Mdot
.19251 .5447 Mdot
.52883 .35815 Mdot
.43965 .21911 Mdot
.38235 .81526 Mdot
.67541 .71085 Mdot
.31999 .46287 Mdot
.27933 .41346 Mdot
.69481 .74061 Mdot
.55466 .82456 Mdot
.56071 .18004 Mdot
.64056 .74664 Mdot
.63138 .5578 Mdot
.51103 .51651 Mdot
.55408 .79363 Mdot
.23556 .40517 Mdot
.60709 .63101 Mdot
.23692 .46268 Mdot
.78345 .2839 Mdot
.8019 .57053 Mdot
.80773 .55384 Mdot
.23536 .42754 Mdot
.5508 .69211 Mdot
.76241 .57543 Mdot
.24277 .49022 Mdot
.68558 .69841 Mdot
.21373 .64848 Mdot
.2405 .47077 Mdot
.38298 .17311 Mdot
.24718 .63629 Mdot
.53202 .40585 Mdot
.43847 .65387 Mdot
.25517 .63857 Mdot
.64304 .56959 Mdot
.36017 .37107 Mdot
.60576 .71691 Mdot
.68593 .56155 Mdot
.6371 .70082 Mdot
.62656 .66321 Mdot
.22899 .59654 Mdot
.40528 .72082 Mdot
.61748 .74185 Mdot
.4527 .7813 Mdot
.56019 .72316 Mdot
.48049 .21522 Mdot
.60355 .40066 Mdot
.59427 .72485 Mdot
.62668 .35121 Mdot
.45076 .57876 Mdot
.58608 .49975 Mdot
.43241 .41675 Mdot
.82502 .38758 Mdot
.42684 .35265 Mdot
.53467 .71222 Mdot
.68888 .23535 Mdot
.47949 .68918 Mdot
.85896 .50482 Mdot
.43549 .2056 Mdot
.40367 .6385 Mdot
.47846 .25747 Mdot
.47858 .3154 Mdot
.52241 .14026 Mdot
.45759 .6885 Mdot
.60977 .30509 Mdot
.5625 .70713 Mdot
.54611 .68736 Mdot
.76667 .44943 Mdot
.60272 .38857 Mdot
.28662 .54509 Mdot
.73296 .56269 Mdot
.48024 .50449 Mdot
.5485 .71511 Mdot
.56595 .44553 Mdot
.31565 .41675 Mdot
.78085 .6795 Mdot
.60615 .36115 Mdot
.74529 .26181 Mdot
.38735 .44137 Mdot
.3803 .75815 Mdot
.43443 .84323 Mdot
.58844 .18802 Mdot
.65554 .35623 Mdot
.16901 .41948 Mdot
.39329 .44692 Mdot
.6197 .74604 Mdot
.5096 .65873 Mdot
.22329 .56134 Mdot
.42654 .32656 Mdot
.26672 .37945 Mdot
.70234 .54567 Mdot
.52608 .20516 Mdot
.73767 .37246 Mdot
.55053 .70143 Mdot
.66885 .72731 Mdot
.26879 .68999 Mdot
.6251 .61535 Mdot
.51237 .38981 Mdot
.47204 .76407 Mdot
.39876 .71546 Mdot
.54692 .71678 Mdot
.8054 .58898 Mdot
.21257 .54973 Mdot
.67386 .79411 Mdot
.37499 .42521 Mdot
.58812 .28406 Mdot
.71938 .58803 Mdot
.65109 .70184 Mdot
.31248 .56997 Mdot
.44989 .84612 Mdot
.30171 .38315 Mdot
.74046 .5705 Mdot
.28873 .42331 Mdot
.46089 .51726 Mdot
.55742 .51851 Mdot
.68918 .34366 Mdot
.44419 .15906 Mdot
.28551 .50666 Mdot
.60621 .21074 Mdot
.40189 .6068 Mdot
.77982 .46119 Mdot
.4918 .72912 Mdot
.61144 .43344 Mdot
.39422 .69174 Mdot
.66305 .34641 Mdot
.69181 .77184 Mdot
.44633 .84475 Mdot
.6475 .57939 Mdot
.76135 .45874 Mdot
.58036 .71078 Mdot
.36769 .43149 Mdot
.58713 .59197 Mdot
.36267 .54926 Mdot
.47376 .71091 Mdot
.61279 .19217 Mdot
.67869 .69581 Mdot
.44289 .55757 Mdot
.69648 .75987 Mdot
.6442 .80333 Mdot
.81558 .63086 Mdot
.1992 .42463 Mdot
.50973 .63726 Mdot
.84152 .5152 Mdot
.29791 .58142 Mdot
.50667 .83573 Mdot
.72952 .68858 Mdot
.31944 .80635 Mdot
.47324 .74661 Mdot
.60445 .69337 Mdot
.38503 .20481 Mdot
.65829 .6305 Mdot
.35244 .79623 Mdot
.50708 .47382 Mdot
.6891 .40356 Mdot
.35342 .80107 Mdot
.42752 .1335 Mdot
.35053 .59371 Mdot
.61802 .65751 Mdot
.51779 .58225 Mdot
.59821 .72347 Mdot
.55333 .26423 Mdot
.42484 .54352 Mdot
.74608 .49501 Mdot
.58745 .23621 Mdot
.25755 .44395 Mdot
.35328 .39993 Mdot
.55055 .26519 Mdot
.35975 .33344 Mdot
.30234 .41751 Mdot
.20453 .51914 Mdot
.46955 .75186 Mdot
.29137 .54909 Mdot
.39788 .44372 Mdot
.48321 .7207 Mdot
.39228 .3105 Mdot
.63625 .40211 Mdot
.38039 .55023 Mdot
.65914 .35865 Mdot
.64657 .62039 Mdot
.86003 .45532 Mdot
.64866 .42931 Mdot
.287 .73571 Mdot
.47073 .6667 Mdot
.6663 .67969 Mdot
.45362 .79235 Mdot
.65643 .245 Mdot
.54156 .29013 Mdot
.25953 .48124 Mdot
.66643 .77293 Mdot
.79149 .40012 Mdot
.23353 .64748 Mdot
.81816 .43752 Mdot
.66002 .56849 Mdot
.30447 .517 Mdot
.50951 .57099 Mdot
.69272 .29906 Mdot
.54498 .63853 Mdot
.60716 .69463 Mdot
.56995 .30945 Mdot
.77317 .36936 Mdot
.29606 .75699 Mdot
.2602 .68287 Mdot
.45076 .67714 Mdot
.6343 .78056 Mdot
.56547 .38734 Mdot
.21392 .56171 Mdot
.59663 .62596 Mdot
.55349 .29188 Mdot
.7964 .49356 Mdot
.75305 .71879 Mdot
.5845 .58461 Mdot
.31128 .34154 Mdot
.36184 .4847 Mdot
.31204 .61663 Mdot
.68558 .68678 Mdot
.43503 .37814 Mdot
.73336 .39173 Mdot
.52518 .70498 Mdot
.71617 .37256 Mdot
.48023 .37753 Mdot
.34548 .37889 Mdot
.54885 .72114 Mdot
.24773 .53552 Mdot
.42719 .2973 Mdot
.7262 .55942 Mdot
.33938 .54566 Mdot
.29514 .35245 Mdot
.20453 .41247 Mdot
.30917 .53117 Mdot
.61325 .76617 Mdot
.46193 .75585 Mdot
.23197 .65863 Mdot
.64585 .71802 Mdot
.749 .66964 Mdot
.6828 .61901 Mdot
.40992 .69699 Mdot
.66386 .29487 Mdot
.35797 .55182 Mdot
.61457 .43471 Mdot
.49488 .70385 Mdot
.51801 .78545 Mdot
.41369 .74794 Mdot
.30766 .32554 Mdot
.54467 .47874 Mdot
.43926 .79123 Mdot
.53167 .46146 Mdot
.41572 .83117 Mdot
.66076 .63097 Mdot
.29691 .39467 Mdot
.62497 .51488 Mdot
.31747 .28507 Mdot
.47986 .1851 Mdot
.61737 .80683 Mdot
.43783 .19323 Mdot
.54691 .56023 Mdot
.60873 .20767 Mdot
.76007 .6086 Mdot
.36704 .81325 Mdot
.30471 .39755 Mdot
.58615 .58181 Mdot
.36243 .4018 Mdot
.6389 .57852 Mdot
.55595 .45526 Mdot
.58979 .43207 Mdot
.28626 .55998 Mdot
.7239 .4302 Mdot
.65618 .30698 Mdot
.42046 .44168 Mdot
.78901 .51992 Mdot
.65202 .77725 Mdot
.232 .56531 Mdot
.50825 .43936 Mdot
.45595 .2337 Mdot
.3421 .37294 Mdot
.1652 .64096 Mdot
.85819 .41888 Mdot
.36014 .48549 Mdot
.49422 .43004 Mdot
.28843 .37107 Mdot
.54641 .35336 Mdot
.27236 .55101 Mdot
.49209 .78003 Mdot
.65884 .55692 Mdot
.59517 .44371 Mdot
.76563 .35475 Mdot
.68969 .67577 Mdot
.33949 .3052 Mdot
.77673 .51617 Mdot
.86467 .46818 Mdot
.19205 .6195 Mdot
.66197 .7005 Mdot
.20689 .7066 Mdot
.68216 .31909 Mdot
.52466 .61882 Mdot
.399 .78441 Mdot
.79168 .64882 Mdot
.25821 .40413 Mdot
.5188 .21993 Mdot
.77146 .6349 Mdot
.30467 .38725 Mdot
.23647 .49148 Mdot
.77491 .46895 Mdot
.72156 .37728 Mdot
.53434 .5166 Mdot
.47951 .3167 Mdot
.8197 .47643 Mdot
.39743 .62666 Mdot
.66937 .76185 Mdot
.58851 .23412 Mdot
.35695 .18282 Mdot
.65465 .79916 Mdot
.37261 .36693 Mdot
.55543 .25807 Mdot
.3878 .78033 Mdot
.247 .36649 Mdot
.24582 .51983 Mdot
.47361 .20459 Mdot
.37993 .71464 Mdot
.46134 .28556 Mdot
.60273 .22281 Mdot
.26962 .43955 Mdot
.25346 .63076 Mdot
.58303 .57934 Mdot
.44886 .74295 Mdot
.76432 .42966 Mdot
.24072 .43036 Mdot
.55705 .43185 Mdot
.2676 .34492 Mdot
.45977 .76432 Mdot
.43611 .80019 Mdot
.59411 .65361 Mdot
.45379 .1314 Mdot
.74624 .68296 Mdot
.64967 .24235 Mdot
.36833 .5625 Mdot
.71691 .75653 Mdot
.59614 .64274 Mdot
.7665 .6511 Mdot
.25719 .70794 Mdot
.60238 .42016 Mdot
.68463 .6032 Mdot
.36085 .55292 Mdot
.67142 .74061 Mdot
.41846 .67995 Mdot
.26212 .65137 Mdot
.54345 .2154 Mdot
.26623 .40439 Mdot
.57108 .25117 Mdot
.29137 .32341 Mdot
.30977 .49267 Mdot
.50337 .71436 Mdot
.84907 .53483 Mdot
.54881 .57156 Mdot
.44587 .57862 Mdot
.32866 .44322 Mdot
.39822 .19582 Mdot
.16418 .54551 Mdot
.36586 .42907 Mdot
.79794 .42236 Mdot
.22878 .49424 Mdot
.46615 .48012 Mdot
.39619 .61394 Mdot
.09674 .4423 Mdot
.468 .86887 Mdot
.53266 .64099 Mdot
.25384 .56124 Mdot
.21589 .44878 Mdot
.78717 .65868 Mdot
.49527 .31202 Mdot
.62556 .39302 Mdot
.31485 .24652 Mdot
.23483 .38145 Mdot
.37456 .44834 Mdot
.27812 .7391 Mdot
.60211 .81142 Mdot
.55821 .21642 Mdot
.68605 .76886 Mdot
.4231 .59308 Mdot
.4442 .53007 Mdot
.108 .52164 Mdot
.55822 .79792 Mdot
.3959 .58049 Mdot
.40176 .19113 Mdot
.5306 .62477 Mdot
.37273 .52914 Mdot
.77232 .50414 Mdot
.2126 .50859 Mdot
.26982 .44294 Mdot
.77118 .68649 Mdot
.55519 .66454 Mdot
.66066 .34724 Mdot
.65043 .5565 Mdot
.57279 .55476 Mdot
.4231 .46246 Mdot
.66812 .51683 Mdot
.45682 .45661 Mdot
.59669 .70721 Mdot
.63801 .56972 Mdot
.19106 .48665 Mdot
.37119 .84118 Mdot
.42832 .74258 Mdot
.70071 .56827 Mdot
.40098 .42105 Mdot
.25018 .64148 Mdot
.35554 .3298 Mdot
.48824 .52515 Mdot
.34443 .80146 Mdot
.59016 .87657 Mdot
.69547 .40752 Mdot
.31902 .43329 Mdot
.55025 .71956 Mdot
.29763 .55794 Mdot
.44402 .70648 Mdot
.69472 .49675 Mdot
.584 .38704 Mdot
.33766 .46074 Mdot
.31025 .49442 Mdot
.69946 .54905 Mdot
.83754 .3656 Mdot
.42611 .52093 Mdot
.37267 .61113 Mdot
.51347 .83168 Mdot
.48401 .21458 Mdot
.35873 .74801 Mdot
.42042 .47708 Mdot
.75633 .57681 Mdot
.58876 .58333 Mdot
.56926 .7588 Mdot
.6232 .26666 Mdot
.73562 .7155 Mdot
.40953 .747 Mdot
.44384 .65735 Mdot
.41787 .52299 Mdot
.3867 .31064 Mdot
.62245 .64717 Mdot
.78169 .62737 Mdot
.3862 .60103 Mdot
.53328 .83547 Mdot
.59648 .419 Mdot
.73844 .44053 Mdot
.47217 .51511 Mdot
.82615 .59163 Mdot
.5741 .20231 Mdot
.42971 .67291 Mdot
.70064 .26206 Mdot
.72752 .32711 Mdot
.3422 .32749 Mdot
.54227 .36571 Mdot
.45159 .53936 Mdot
.55671 .67185 Mdot
.87114 .48075 Mdot
.78505 .61903 Mdot
.67621 .47182 Mdot
.71296 .39401 Mdot
.36055 .64157 Mdot
.58505 .60857 Mdot
.28311 .78571 Mdot
.50998 .32051 Mdot
.86474 .45828 Mdot
.22333 .5695 Mdot
.48695 .74015 Mdot
.61882 .69536 Mdot
.32909 .5632 Mdot
.59782 .35405 Mdot
.77151 .67605 Mdot
.31122 .504 Mdot
.6428 .25574 Mdot
.40023 .45917 Mdot
.73795 .2948 Mdot
.60263 .46579 Mdot
.76307 .47737 Mdot
.75228 .51116 Mdot
.4952 .17875 Mdot
.47555 .81025 Mdot
.61234 .49319 Mdot
.23414 .72895 Mdot
.53051 .77997 Mdot
.59892 .80249 Mdot
.54125 .23902 Mdot
.54442 .16688 Mdot
.70134 .70491 Mdot
.62146 .73554 Mdot
.64637 .46735 Mdot
.47592 .44071 Mdot
.70673 .2956 Mdot
.45779 .4623 Mdot
.63902 .646 Mdot
.62698 .57077 Mdot
.69609 .84023 Mdot
.38782 .38755 Mdot
.52125 .60451 Mdot
.66907 .28719 Mdot
.63395 .79096 Mdot
.42383 .39987 Mdot
.30817 .77421 Mdot
.49349 .40625 Mdot
.44622 .51923 Mdot
.40084 .72932 Mdot
.23043 .55691 Mdot
.72632 .30484 Mdot
.57283 .14409 Mdot
.19602 .62367 Mdot
.72404 .41781 Mdot
.57035 .51535 Mdot
.47869 .66644 Mdot
.4672 .62983 Mdot
.47828 .27617 Mdot
.25781 .73369 Mdot
.60202 .69687 Mdot
.55456 .79422 Mdot
.50626 .14153 Mdot
.22585 .61489 Mdot
.78887 .6599 Mdot
.73422 .66122 Mdot
.4705 .69264 Mdot
.36829 .34897 Mdot
.39967 .27171 Mdot
.74399 .49967 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0T?ooool2o`000;Oooooo000Looooo`03o`00
0?oooooooooo08Oooooo0_l00007ooooo`;o0000]oooool001cooooo00?o0000ooooooooool0Qooo
ool2o`000<3ooooo000Looooo`03o`000?oooooooooo0:Kooooo0_l0002Qooooo`007?ooool00ol0
003oooooooooo`1jooooo`;o00005_ooool2o`0000gooooo1?l000000ooooooo0000o`00000>oooo
o`;o0000TOooool001cooooo00?o0000ooooooooool0N_ooool2o`0001Kooooo0_l0000=ooooo`Co
00004Oooool2o`00097ooooo000Looooo`03o`000?oooooooooo0:gooooo0_l0002Jooooo`007?oo
ool2o`0008Sooooo0_l00004ooooo`;o00007_ooool2o`0009[ooooo000Looooo`03o`000?oooooo
oooo08?ooooo0_l00002ooooo`;o00001?ooool2o`0002gooooo0_l0002;ooooo`007?ooool00ol0
003oooooooooo`23ooooo`?o00001oooool2o`0002gooooo0_l0002;ooooo`007?ooool00ol0003o
ooooooooo`24ooooo`;o00001oooool2o`000;[ooooo000Looooo`03o`000?oooooooooo0:3ooooo
0_l0002Wooooo`007?ooool00ol0003oooooooooo`2<ooooo`;o00004_ooool2o`0000_ooooo0_l0
002Jooooo`007?ooool00ol0003oooooooooo`2<ooooo`;o00000oooool2o`0000_ooooo0_l0000:
ooooo`;o000000?oooooo`000?l00000V_ooool001cooooo00?o0000ooooooooool0NOooool2o`00
01?ooooo0_l000000ooooooo0000o`00000;ooooo`;o00002_ooool3o`0001oooooo0_l0001koooo
o`007?ooool00ol0003oooooooooo`1_ooooo`;o00002?ooool2o`0000?ooooo0_l00009ooooo`;o
00000oooool2o`0000cooooo0_l0000=ooooo`;o00007oooool2o`0007_ooooo000Looooo`03o`00
0?oooooooooo06oooooo0_l00008ooooo`;o00000oooool2o`000003ooooool0003o000000Kooooo
0_l0000<ooooo`;o00000_ooool4o`0001?ooooo0_l0002Eooooo`007?ooool00ol0003ooooooooo
o`1`ooooo`;o00001oooool2o`0000Kooooo0_l00007ooooo`;o00002oooool2o`0000;ooooo1?l0
0009ooooo`;o00002?ooool2o`0000?ooooo0_l0000Sooooo`;o0000Joooool001cooooo00?o0000
ooooooooool0L?ooool2o`0000kooooo0_l00008ooooo`;o00000oooool4o`0000Gooooo0_l00003
ooooo`;o00002Oooool2o`000004ooooool0003o0000ooooo`;o00001oooool2o`0001Oooooo0_l0
000:ooooo`;o0000Joooool001cooooo00?o0000ooooooooool0P?ooool2o`0000Cooooo0ol00006
ooooo`Go00001?ooool2o`0000gooooo1_l000000ooooooo0000o`00000;ooooo`;o00004oooool2
o`0007Oooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_oo
ool00ol0003oooooooooo`1oooooo`;o00001Oooool3o`000003ooooool0003o000000Kooooo0_l0
000?ooooo`;o00000_ooool4o`0000?ooooo1?l000000ooooooo0000o`000006ooooo`;o00001_oo
ool2o`0008Cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1nooooo`?o00000oooool2o`0000Co
oooo0_l00004ooooo`;o000000?oooooo`000?l000003_ooool2o`0000Wooooo1?l000001?oooooo
0000o`000?ooool4o`0000Wooooo0_l0000@ooooo`;o0000L_ooool00003ooooool@413ooooo00;o
oooo00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo07ko
oooo0_l00004ooooo`;o00001?ooool2o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`;o
00006oooool4o`0000;ooooo0_l00005ooooo`;o00004?ooool2o`0007;ooooo00000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0007_ooooo
1Ol0000Iooooo`;o00001Oooool2o`0001Gooooo0_l00003ooooo`;o00002Oooool2o`0000cooooo
0_l0001booooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomV
IVKooooo00Gooooo00?o0000ooooooooool0M_ooool2o`000003ooooool0003o000000Go00002_oo
ool2o`0000[ooooo0_l00002ooooo`;o00001?ooool2o`0000Cooooo0ol0000>ooooo`Co000000?o
ooooo`000?l000002Oooool2o`0000cooooo0_l0001booooo`0000?ooooooa0@4?ooool00_ooool0
0ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0M_ooool2
o`000003ooooool0003o000000oooooo0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o
000000;ooooo1?l00008ooooo`?o00004?ooool2o`000003ooooool0003o000000Cooooo0_l00006
ooooo`;o0000OOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooo
oonHV9So410@00Kooooo00?o0000ooooooooool0QOooool2o`0000Sooooo0_l00002ooooo`;o0000
1oooool2o`0000Cooooo0_l0000Mooooo`?o00001_ooool2o`0007gooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo
07Oooooo0_l0000<ooooo`;o00004?ooool4o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`00
00Gooooo0_l0000Booooo`;o0000Q_ooool001cooooo00?o0000ooooooooool0K?ooool2o`0000Wo
oooo0_l0000<ooooo`;o00004?ooool4o`0000?ooooo0_l00006ooooo`;o00001Oooool2o`000003
ooooool0003o000000;o00003?ooool2o`0000[ooooo0_l000000ooooooo0000o`00001hooooo`00
7?ooool00ol0003oooooooooo`1/ooooo`;o00005oooool2o`0000?ooooo0ol00004ooooo`;o0000
4_ooool4o`0000Oooooo1?l0000<ooooo`;o00001oooool2o`000004ooooool0003o0000ooooo`;o
0000N?ooool001cooooo00?o0000ooooooooool0KOooool2o`0001_ooooo1Ol000001?oooooo0000
o`000?l00007ooooo`;o00002Oooool4o`0001Oooooo0_l00007ooooo`;o00000oooool3o`0007So
oooo000Looooo`03o`000?oooooooooo06gooooo0_l0000Nooooo`;o000000?oooooo`000?l00000
2?ooool2o`00017ooooo0_l00003ooooo`Co00002?ooool4o`0000cooooo0ol0001hooooo`007?oo
ool00ol0003oooooooooo`20ooooo`;o000000?oooooo`000?l000000oooool2o`00017ooooo0_l0
00001?oooooo0000o`000?l0000<ooooo`Co000000?oooooo`000?l000000_l00008ooooo`;o0000
3oooool2o`0007Sooooo000Looooo`03o`000?oooooooooo06?ooooo0_l0000=ooooo`;o00003?oo
ool2o`000003ooooool0003o000000?ooooo0_l00006ooooo`;o00002?ooool3o`000004ooooool0
003o0000o`0000_ooooo0_l000000ooooooo0000o`00000Kooooo`;o00000oooool2o`0000;ooooo
0_l0001booooo`007?ooool00ol0003oooooooooo`1Sooooo`Co00002oooool2o`0001cooooo0_l0
0008ooooo`;o00004?ooool2o`0000?ooooo0_l00008ooooo`;o00002_ooool2o`000003ooooool0
003o000000;o00000_ooool4o`000003ooooool0003o000000Gooooo0_l0001[ooooo`007?ooool0
0ol0003oooooooooo`1Oooooo`;o00000oooool3o`0002Kooooo0_l0000Looooo`?o00000_ooool3
o`0000Sooooo0ol00007ooooo`Co000000?oooooo`000?l000001?ooool4o`0000Sooooo0_l0001[
ooooo`007?ooool00ol0003oooooooooo`1Oooooo`;o00007_ooool2o`0000cooooo0_l0000Aoooo
o`;o00001_ooool6o`000005ooooool0003o0000o`000?ooool00_l00004ooooo`;o000000?ooooo
o`000?l000000_l00005ooooo`;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`00001e
ooooo`007?ooool00ol0003oooooooooo`1oooooo`;o00000_ooool2o`0000Gooooo0_l00002oooo
o`?o00001?ooool2o`0000Wooooo0_l00006ooooo`?o00001?ooool3o`000004ooooool0003o0000
o`0000?ooooo0_l000000ooooooo0000o`000002o`0000_ooooo0_l00002ooooo`Co00003?ooool2
o`0006Sooooo000Looooo`03o`000?oooooooooo06;ooooo0ol0000Jooooo`;o00000_ooool2o`00
00Gooooo0_l00002ooooo`?o00001?ooool2o`0001gooooo1_l0000Gooooo`;o00000_ooool2o`00
00Sooooo0_l0001Xooooo`007?ooool2o`0005Kooooo0_l0000;ooooo`?o0000<?ooool2o`0000go
oooo0ol0000>ooooo`Oo00005oooool4o`0000oooooo0_l0001Qooooo`007?ooool00ol0003ooooo
ooooo`1Eooooo`;o00001oooool2o`000003ooooool0003o000003;ooooo0_l0000=ooooo`?o0000
3?ooool9o`0000;ooooo0_l00003ooooo`;o00002?ooool2o`0000Cooooo0ol00003ooooo`;o0000
2oooool2o`00067ooooo000Looooo`03o`000?oooooooooo04Sooooo0_l0000Dooooo`;o000000?o
ooooo`000?l00000=Oooool2o`00013ooooo0_l00005ooooo`Co00002?ooool5o`000003ooooool0
003o000000Sooooo0_l00004ooooo`Co00000_ooool4o`0006cooooo000Looooo`03o`000?oooooo
oooo04Sooooo0_l0000>ooooo`;o000000?oooooo`000?l00000>?ooool2o`000003ooooool0003o
000000Sooooo0_l00004ooooo`Co00001Oooool2o`0000[ooooo0_l000001?oooooo0000o`000?l0
000:ooooo`?o00000oooool4o`0000Cooooo0_l0001/ooooo`007?ooool00ol0003oooooooooo`1H
ooooo`;o000000?oooooo`000?l00000>?ooool2o`0000_ooooo0_l00004ooooo`Co00001?ooool2
o`0000oooooo0_l00003ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`;o00003Ooo
ool2o`0000cooooo0_l0001Iooooo`007?ooool00ol0003oooooooooo`1Eooooo`?o00008_ooool3
o`0000_ooooo0_l0000Hooooo`;o00001_ooool2o`0000?ooooo0ol0000?ooooo`;o00000oooool3
o`0000;ooooo1?l00002ooooo`;o00000_ooool2o`0000Wooooo0_l0000<ooooo`;o0000FOooool0
01cooooo00?o0000ooooooooool0EOooool3o`0000_ooooo0_l0000Eooooo`?o000000Coooooo`00
0?l0003o00001oooool2o`0001Sooooo0_l00006ooooo`;o00000oooool2o`0000;ooooo0_l0000?
ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Kooooo0_l0001booooo`007?ooool00ol0
003oooooooooo`15ooooo`;o00003_ooool2o`0000cooooo0_l0000?ooooo`;o00000oooool2o`00
00?ooooo0ol0000Vooooo`;o00002_ooool2o`0000oooooo0_l00003ooooo`;o00001_ooool2o`00
0003ooooool0003o000000?ooooo0_l00008ooooo`?o0000Hoooool001cooooo00?o0000oooooooo
ool0AOooool2o`0000kooooo0_l0000Cooooo`;o00002?ooool2o`0000?ooooo0_l00003ooooo`;o
00000oooool2o`0001?ooooo0_l00006ooooo`;o00001Oooool2o`0000Cooooo0_l0000Eooooo`;o
00000oooool2o`0000Kooooo1_l000001?oooooo0000o`000?l00006ooooo`Go00000_ooool2o`00
05oooooo000Looooo`03o`000?oooooooooo06[ooooo0_l0000Gooooo`Co00004Oooool2o`0000Ko
oooo0_l0000;ooooo`;o00002Oooool2o`0000Oooooo0_l000000ooooooo0000o`000002ooooo`;o
00002?ooool5o`000003ooooool0003o000000?ooooo1_l00004ooooo`Co00002oooool2o`00057o
oooo000Looooo`03o`000?oooooooooo06Cooooo0_l0000Jooooo`;o00000oooool2o`0001Kooooo
0_l0000Dooooo`;o00000oooool2o`0000Oooooo0_l000000ooooooo0000o`000005o`0000Kooooo
1_l00004ooooo`Ko00001_ooool4o`0000Cooooo0_l00005ooooo`;o0000DOooool001cooooo00?o
0000ooooooooool0B?ooool2o`0000gooooo0_l00007ooooo`;o000000?oooooo`000?l000000ol0
000Hooooo`;o00000oooool2o`0000_ooooo0_l00005ooooo`;o00000_ooool2o`0001Cooooo0_l0
0006ooooo`;o00001oooool7o`0000Kooooo0_l00002ooooo`;o00000oooool3o`0001;ooooo0_l0
000:ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0B?ooool4o`0000_ooooo0_l00007
ooooo`;o000000Coooooo`000?l0003ooooo0_l00007ooooo`;o00001Oooool3o`0000Sooooo0_l0
000?ooooo`;o00001Oooool2o`00023ooooo0_l00006ooooo`?o00000oooool2o`000003ooooool0
003o000000Sooooo0_l00002ooooo`?o00001Oooool6o`0001?ooooo0_l0001<ooooo`007?ooool0
0ol0003oooooooooo`1:ooooo`;o00004_ooool2o`0000?ooooo0_l0000:ooooo`Co00000oooool3
o`0000Sooooo0_l000000ooooooo0000o`00000Vooooo`;o00000_ooool2o`00017ooooo0_l00004
ooooo`;o000000?oooooo`000?l000002?ooool2o`0000;ooooo0ol00005ooooo`Ko0000HOooool0
01cooooo00?o0000ooooooooool0G_ooool2o`0000Gooooo0_l00008ooooo`Co00000_ooool4o`00
00_ooooo0_l000000ooooooo0000o`00000Sooooo`;o00000_ooool2o`0000gooooo0_l00007oooo
o`;o00002_ooool2o`0000Cooooo0_l00003ooooo`;o00002?ooool2o`000003ooooool0003o0000
00Kooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o00001oooool2o`000004
ooooool0003o0000o`0000;ooooo0_l00004ooooo`;o00001?ooool6o`0000;ooooo1_l000000ooo
oooo0000o`000005o`00027ooooo0_l0000@ooooo`?o00001oooool2o`0000[ooooo0_l00004oooo
o`;o00000_ooool3o`000003ooooool0003o000000Gooooo0_l000000ooooooo0000o`000006oooo
o`;o0000Doooool001cooooo0_l00017ooooo`;o00002oooool2o`0000?ooooo0_l00007ooooo`;o
000000?oooooo`000?l000001Ol0000>ooooo`;o00000_ooool>o`00027ooooo0_l0000@ooooo`;o
00000_ooool3o`000003ooooool0003o000001Gooooo0ol00002ooooo`;o000000?oooooo`000?l0
00000oooool3o`0005cooooo000Looooo`03o`000?oooooooooo04Kooooo0_l0000;ooooo`;o0000
2?ooool2o`000003ooooool0003o000000;ooooo1Ol0000:ooooo`;o00002Oooool;o`0000?ooooo
0_l0000Oooooo`;o00004oooool3o`000003ooooool0003o000001Gooooo0_l00006ooooo`;o0000
0oooool5o`0005[ooooo000Looooo`03o`000?oooooooooo04_ooooo0_l0000@ooooo`Wo000000?o
ooooo`000?l000000_ooool2o`0000Kooooo0_l00006ooooo`oo00000_ooool2o`0000kooooo0_l0
000?ooooo`;o00003oooool2o`0000;ooooo0_l0000=ooooo`;o00005Oooool2o`0000?ooooo0_l0
000=ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0Boooool2o`00013ooooo1?l00000
0ooooooo0000o`000006ooooo`Co00003?ooool@o`0001;ooooo0_l0000Gooooo`;o00000_ooool2
o`0000?ooooo0_l00002ooooo`;o00002Oooool2o`0000;ooooo0_l00002ooooo`?o00001Oooool2
o`0000Wooooo0_l00006ooooo`;o00000oooool2o`0000Gooooo0_l0001;ooooo`007?ooool00ol0
003oooooooooo`1Jooooo`;o00000oooool2o`0000Wooooo1?l0000<oooooaCo00003oooool2o`00
01Kooooo0_l00002ooooo`;o00004_ooool2o`000003ooooool0003o000000?ooooo0ol00005oooo
o`Co00003_ooool3o`0000?ooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`1Fooooo`;o
00000_ooool2o`0000Kooooo0_l0000>ooooo`;o000000?oooooo`000?l000000ooooolDo`0000[o
oooo0_l00003ooooo`;o00000oooool2o`0001gooooo0_l00009ooooo`;o00000_ooool2o`0000go
oooo0_l0000>ooooo`;o0000F?ooool001cooooo00?o0000ooooooooool0E_ooool2o`0000[ooooo
0_l00002ooooo`;o00001Oooool4o`000004ooooool0003o0000ooooo`;o00000oooool4o`000003
ooooool0003o000000co000000?oooooo`000?l000001?ooool3o`000003ooooool0003o000000?o
oooo0_l00003ooooo`;o00007Oooool2o`0000Wooooo0_l000000ooooooo0000o`000009ooooo`;o
00004oooool2o`0001cooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o0000
1_ooool2o`0000Gooooo1?l00009oooooa?o000000?oooooo`000?l000001?ooool3o`0000_ooooo
0_l0000Tooooo`;o00001Oooool2o`0000Cooooo0_l00003ooooo`;o00004oooool2o`0000?ooooo
1?l0000Eooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0Foooool2o`000003ooooool0
003o000000;o00002_ooool3o`0000Cooooo0_l00005oooooa?o00005Oooool2o`0000Sooooo0_l0
0006ooooo`;o00004_ooool2o`0000_ooooo0_l0000Looooo`Go0000DOooool001cooooo00?o0000
ooooooooool0COooool2o`0000cooooo0_l00002ooooo`?o00001Oooool2o`0000;ooooo1_l00002
ooooo`;o00000ooooolCo`000003ooooool0003o000001kooooo0_l00006ooooo`;o00000_ooool2
o`0000;ooooo1?l00002ooooo`Co00002Oooool2o`0001Sooooo0_l00008ooooo`;o000000?ooooo
o`000?l00000DOooool001cooooo00?o0000ooooooooool0COooool3o`0000oooooo0_l00006oooo
o`;o00000_ooool3o`000004ooooool0003o0000o`0000;ooooo0_l000000ooooooo0000o`000007
o`000003ooooool0003o000000So000000?oooooo`000?l000009_ooool2o`0000;ooooo2Ol00000
0ooooooo0000o`000007o`0000Cooooo0_l0000Hooooo`;o00002Oooool4o`00057ooooo000Loooo
o`03o`000?oooooooooo04Oooooo0_l00003ooooo`Co00008?ooool3o`000004ooooool0003o0000
oooooaOo00002Oooool2o`0000Oooooo0_l0000>ooooo`;o00001OoooolDo`0000Oooooo0_l00000
0ooooooo0000o`00000Mooooo`?o0000D_ooool001cooooo00?o0000ooooooooool0>?ooool2o`00
00gooooo0_l00003ooooo`;o00000oooool3o`0000;ooooo0_l00008ooooo`;o00003oooool2o`00
00;ooooo0_l00002oooooaGo00002Oooool2o`0000Kooooo0ol0000<ooooo`Co00000_ooool2o`00
0003ooooool0003o000001;o00000oooool6o`000004ooooool0003o0000ooooo`?o00001_ooool2
o`0000;ooooo0_l0000=ooooo`Co0000DOooool001cooooo00?o0000ooooooooool0>?ooool2o`00
00;ooooo0_l0000Booooo`Co00000_ooool2o`0000Sooooo0ol0000Booooo`;o00000_oooolEo`00
017ooooo0_l0000=ooooo`?o00000oooool5o`000003ooooool0003o000000oo00000oooool4o`00
00;ooooo0_l00002ooooo`?o00001_ooool2o`0000;ooooo0_l0000=ooooo`Ko0000Coooool001co
oooo00?o0000ooooooooool0??ooool4o`0000_ooooo0_l00003ooooo`;o00003oooool2o`0001Ko
oooo5?l000000ooooooo0000o`00000Qooooo`Wo000000?oooooo`000?l000004Ol00003ooooo`;o
000000?oooooo`000?l000001_ooool2o`0000Oooooo0_l0000>ooooo`;o000000?oooooo`000?l0
00000_l0001=ooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00001_ooool2o`0000?ooooo
0_l00003ooooo`;o000000?oooooo`000?l000009?ooool4o`000003ooooool0003o0000013o0000
3_ooool2o`0000oooooo7ol00003ooooo`Go00001_ooool2o`0000Oooooo0_l00008ooooo`?o0000
2?ooool2o`0004gooooo000Looooo`;o0000=Oooool2o`00013ooooo0ol00007ooooo`;o000000?o
ooooo`000?l000003Oooool2o`0000;ooooo0_l0000<ooooo`;o00000ooooolGo`0000kooooo0_l0
00000ooooooo0000o`000003ooooo`;o00001_oooolKo`000003ooooool0003o000000;o00001?oo
ool4o`0001Wooooo0ol00008ooooo`Co0000Boooool001cooooo00?o0000ooooooooool0;Oooool2
o`0000Gooooo0_l0000@ooooo`?o00001?ooool2o`0000Oooooo0_l00004ooooo`;o00001?ooool6
o`0000cooooo0_l000000ooooooo0000o`00000Do`000003ooooool0003o0000017ooooo0_l00003
ooooo`;o00001_oooolOo`0000Sooooo0_l0000Mooooo`Co00000_ooool4o`0004_ooooo000Loooo
o`03o`000?oooooooooo02gooooo0_l00005ooooo`;o000000?oooooo`000?l000005?ooool4o`00
00Gooooo0_l00004ooooo`;o00001_ooool2o`00017ooooo5ol0000?ooooo`;o00003_oooolGo`00
0003ooooool0003o000000Ko00001?ooool2o`000004ooooool0003o0000o`0000kooooo0_l0000;
ooooo`Ko00004_ooool2o`0003gooooo000Looooo`03o`000?oooooooooo03Cooooo0_l000000ooo
oooo0000o`00000;ooooo`;o00002Oooool2o`0000Oooooo0_l00002ooooo`;o00001?ooool4o`00
01Gooooo4?l000000ooooooo0000o`00000?ooooo`Co00001?ooool2o`000003ooooool0003o0000
02?o00001?ooool6o`0000?ooooo0_l00009ooooo`;o00002oooool5o`0001?ooooo0_l0000moooo
o`007?ooool00ol0003oooooooooo`0`ooooo`;o00002oooool4o`0000?ooooo0_l0000;ooooo`;o
00001Oooool2o`0000;ooooo0_l00004ooooo`Oo00004oooool9o`000003ooooool0003o000000?o
00005?ooool2o`0000Cooooo0_l000000ooooooo0000o`00000So`0000;ooooo0_l000001?oooooo
0000o`000?ooool2o`0000?ooooo0_l0000Fooooo`Co00004_ooool2o`0003oooooo000Looooo`03
o`000?oooooooooo033ooooo0_l0000;ooooo`Co00002_ooool3o`0000?ooooo0_l000000ooooooo
0000o`00000>ooooo`Go00000_ooool2o`0000oooooo2?l000001?oooooo0000o`000?ooool4o`00
01gooooo8ol00003ooooo`?o00002?ooool5o`0002Wooooo0_l00002ooooo`;o0000>oooool001co
oooo00?o0000ooooooooool0BOooool6o`0000Gooooo0_l0000<ooooo`Ko00000oooool2o`0000So
oooo0_l000000ooooooo0000o`000003ooooo`Ko00000_ooool2o`000003ooooool0003o000000;o
00004?ooool2o`0000[ooooo8?l000001?oooooo0000o`000?l00004ooooo`;o00002?ooool5o`00
013ooooo0_l00006ooooo`;o00000_ooool2o`0000oooooo0_l0000kooooo`007?ooool00ol0003o
ooooooooo`10ooooo`Co00001?ooool3o`0000;ooooo0_l00006ooooo`;o00000oooool2o`0000Ko
oooo0_l00007ooooo`;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`Co
00001Oooool2o`0001;ooooo0_l0000:ooooo`?o00000_ooool5o`000003ooooool0003o000000;o
000000?oooooo`000?l000001_l000000ooooooo0000o`000005o`000004ooooool0003o0000o`00
00kooooo0ol0000?ooooo`;o000000?oooooo`000?l000001?ooool4o`000005ooooool0003o0000
o`000?ooool00_l00019ooooo`007?ooool00ol0003oooooooooo`10ooooo`Co00001?ooool2o`00
00_ooooo0_l00003ooooo`;o00003Oooool4o`0000Cooooo0_l00002ooooo`;o00002?ooool4o`00
00Gooooo0_l0000Aooooo`;o00002_ooool4o`0000;ooooo1Ol000000ooooooo0000o`00000Fo`00
013ooooo0_l00008ooooo`;o00001Oooool4o`0000Gooooo0_l00003ooooo`;o00000_ooool2o`00
04Wooooo000Looooo`03o`000?oooooooooo04Sooooo0_l00004ooooo`Co00005oooool4o`0000So
oooo0_l00008ooooo`?o00002?ooool2o`0000cooooo0_l000000ooooooo0000o`00000:oooooaGo
000000?oooooo`000?l000002ol000000ooooooo0000o`00000Hooooo`Co00001Oooool2o`0000_o
oooo0_l0000:ooooo`Co0000?_ooool001cooooo00?o0000ooooooooool0@?ooool2o`0000Oooooo
0_l00003ooooo`Co000000?oooooo`000?l000001Oooool3o`0000Wooooo0_l00002ooooo`Co0000
1oooool2o`0000Wooooo0_l000001?oooooo0000o`000?l00004ooooo`;o00002_ooool4o`0000?o
oooo0_l00005oooooaOo00000_ooool<o`000004ooooool0003o0000o`0000Wooooo0_l0000?oooo
o`Co00004?ooool2o`0000?ooooo0_l00005ooooo`Co00001_ooool2o`0003Kooooo000Looooo`03
o`000?oooooooooo043ooooo0_l000000ooooooo0000o`000004ooooo`;o00002?ooool2o`0000Go
oooo0ol000000ooooooo0000o`000005ooooo`?o00000_ooool4o`0001Gooooo0ol0000@ooooo`?o
00001?ooool2o`0000Cooooo1ol000000ooooooo0000o`00000Go`000003ooooool0003o000000Go
00002_ooool2o`0000Kooooo0_l00009ooooo`;o00005Oooool2o`0000Sooooo0_l00005ooooo`;o
0000=_ooool001cooooo00?o0000ooooooooool0>_ooool2o`0000;ooooo0_l00003ooooo`;o0000
00Coooooo`000?l0003o00001_ooool4o`0000Sooooo0_l000000ooooooo0000o`000002o`0000?o
oooo0_l00006ooooo`;o00002oooool2o`000003ooooool0003o000000Cooooo0_l0000Nooooo`;o
00001oooool6o`000003ooooool0003o0000013o000000?oooooo`000?l000000ol00003ooooo`;o
00000_ooool2o`0000?ooooo0_l00005ooooo`;o00001?ooool2o`0002;ooooo1?l0000mooooo`00
7?ooool00ol0003oooooooooo`0fooooo`;o00000_ooool2o`0000;ooooo0_l00005ooooo`Co0000
1_ooool4o`0000Sooooo2?l00002ooooo`;o00001?ooool4o`0000Cooooo0ol00004ooooo`;o0000
00Coooooo`000?l0003o00003_ooool2o`0001?ooooo1?l00004oooooago00001_ooool2o`0000;o
oooo0_l00003ooooo`;o00002_ooool5o`0000Wooooo0_l00004ooooo`;o00003oooool2o`0003oo
oooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@oooo
ooooool01?ooool00ol0003oooooooooo`0fooooo`;o00003Oooool2o`0000gooooo0_l00007oooo
o`;o00000_ooool2o`0000;ooooo0_l00004ooooo`?o00001Oooool3o`0000Sooooo0_l0000=oooo
o`?o00004oooool5o`0000?ooooo7_l00008ooooo`;o00002oooool2o`0000?ooooo1Ol00002oooo
o`;o00001Oooool2o`0000Cooooo0_l0001@ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5
ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Sooooo0_l0000H
ooooo`Co00001Oooool4o`0000Oooooo0_l00009ooooo`;o00003?ooool2o`0000cooooo0_l0000F
ooooo`?o00000oooool<o`000003ooooool0003o000000[o00000oooool2o`0000Kooooo1?l0000;
ooooo`;o00000_ooool4o`0000Cooooo0_l0000Oooooo`;o0000??ooool00003ooooool@413ooooo
00;ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo00?o0000ooooooooool0>?ooool2o`00
01?ooooo0_l00003ooooo`;o00001oooool6o`0000Gooooo0_l00007ooooo`Oo00001Oooool2o`00
00;ooooo0_l00005ooooo`;o00003Oooool2o`0000?ooooo1?l000000ooooooo0000o`000004oooo
o`?o00000oooool<o`0000Sooooo0_l0000>ooooo`?o00003?ooool2o`0000;ooooo0_l00007oooo
o`;o000000?oooooo`000?l000003Oooool2o`0000cooooo0_l0000looooo`0000?oooooo`000?oo
ool00_ooool00ol0003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol00011oooo
o`?o00002Oooool2o`00013ooooo0ol0000=ooooo`;o000000?oooooo`000?l000000ol000001?oo
oooo0000o`000?ooool2o`0000;ooooo0_l00005ooooo`;o00003Oooool2o`0000?ooooo1?l00000
0ooooooo0000o`000004ooooo`;o00001?ooool2o`0000;ooooo0ol000000ooooooo0000o`00000;
ooooo`;o00002Oooool2o`0000;ooooo0_l0000Aooooo`;o00001oooool5o`0000?ooooo0_l00004
ooooo`;o00000_ooool2o`0004[ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`11ooooo`?o00001Oooool2
o`0000Gooooo1Ol00002ooooo`;o00000_ooool2o`0000?ooooo1?l00007ooooo`?o000000Cooooo
o`000?l0003ooooo0_l000001?oooooo0000o`000?ooool2o`0000Gooooo0_l0000Kooooo`?o0000
1_ooool3o`000004ooooool0003o0000ooooo`Ko00003_ooool2o`0000Wooooo0_l00002ooooo`?o
000000?oooooo`000?l000000_l00005ooooo`Co00001oooool2o`0000Cooooo0ol00003ooooo`Co
00000_ooool2o`0000Cooooo0_l00018ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooo
ooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0BOooool2o`0000Gooooo
1Ol00002ooooo`;o000000Coooooo`000?l0003o00001Oooool2o`0000Oooooo0ol00004ooooo`;o
00005oooool2o`0000oooooo0ol00006ooooo`?o000000Coooooo`000?l0003ooooo1_l0000>oooo
o`;o00003_ooool7o`0000Gooooo1?l00007ooooo`;o00001Oooool4o`0000?ooooo0_l00004oooo
o`;o00000_ooool2o`0004Sooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^
odA4A?l000001oooool00ol0003oooooooooo`0oooooo`;o000000?oooooo`000?l000000oooool2
o`0000Sooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo0_l0000:ooooo`;o00001_ooool2
o`0001;ooooo0_l00003ooooo`;o00003_ooool2o`0000Sooooo1_l00002ooooo`Co00000oooool2
o`0000Gooooo0_l00003ooooo`;o00003oooool4o`0000Wooooo0_l00006ooooo`;o00002?ooool2
o`0000Wooooo0ol0000=ooooo`;o0000??ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Ooo
ool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo03Kooooo0_l00007ooooo`;o000000?o
ooooo`000?l000000oooool2o`0000gooooo0ol00005ooooo`;o00000_ooool2o`0000Kooooo0ol0
000;ooooo`?o00002oooool2o`0000_ooooo0_l00006ooooo`;o00002?ooool4o`0000Cooooo0_l0
0005ooooo`;o00001Oooool2o`0000Sooooo0_l0000;ooooo`?o00002oooool2o`0000Cooooo0_l0
0008ooooo`;o00002_ooool2o`0000;ooooo0_l00009ooooo`;o0000??ooool001cooooo00?o0000
ooooooooool0=_ooool2o`0000Cooooo0_l000000ooooooo0000o`000007ooooo`;o00000_ooool2
o`0000Wooooo0_l00005ooooo`;o00000_ooool3o`0000Gooooo0ol00002ooooo`;o00001oooool3
o`0000kooooo0_l00008ooooo`;o00004?ooool2o`0000Kooooo0_l00005ooooo`;o00003oooool3
o`0000[ooooo0_l0000<ooooo`;o00001Oooool2o`0000Oooooo1?l00003ooooo`;o00000oooool2
o`0000;ooooo0_l0000Aooooo`?o0000<oooool001cooooo00?o0000ooooooooool0<oooool2o`00
00Oooooo0_l000000ooooooo0000o`000007ooooo`;o00000_ooool2o`0000Oooooo1Ol00002oooo
o`Co00000oooool2o`0000[ooooo0_l0000:ooooo`Ko00002?ooool2o`0000Kooooo1?l0000@oooo
o`;o00003Oooool2o`0000Sooooo1?l00004ooooo`;o00007Oooool4o`0000Sooooo0ol00003oooo
o`?o00002?ooool2o`0000oooooo0ol0000cooooo`007?ooool00ol0003oooooooooo`0cooooo`;o
00002?ooool2o`0000?ooooo0_l00002ooooo`Co00002oooool9o`0000?ooooo0_l000000ooooooo
0000o`00000Aooooo`;o00000_ooool6o`000003ooooool0003o000000gooooo1?l00006ooooo`;o
000000?oooooo`000?l000001Oooool5o`000004ooooool0003o0000ooooo`;o00003_ooool4o`00
00Gooooo0_l0000Looooo`;o00002Oooool2o`0000;ooooo0_l00002ooooo`;o00001Oooool2o`00
0003ooooool0003o000000oooooo0_l0000dooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o
00000oooool2o`0000Oooooo1ol00002ooooo`Ko00003Oooool3o`0000?ooooo1?l000000ooooooo
0000o`000006ooooo`;o00001?ooool2o`0000;ooooo0ol00002ooooo`;o00001Oooool3o`0000;o
oooo0_l00008ooooo`;o00001_ooool4o`000003ooooool0003o000000Gooooo1Ol000001?oooooo
0000o`000?ooool2o`0001Oooooo0_l0000Oooooo`;o00001_ooool2o`0000;ooooo0_l00007oooo
o`Ko00004?ooool2o`0003Cooooo000Looooo`03o`000?oooooooooo02oooooo0_l000000ooooooo
0000o`000002o`0000Sooooo1?l00004ooooo`;o000000Coooooo`000?l0003o00004?ooool2o`00
0003ooooool0003o000000?ooooo0_l00006ooooo`;o00001?ooool3o`000003ooooool0003o0000
00_ooooo0_l00002ooooo`;o00004?ooool2o`0000;ooooo0_l00007ooooo`Co00001Oooool3o`00
01gooooo0_l0000Fooooo`?o00002?ooool4o`0000Kooooo0ol00002ooooo`;o00001?ooool2o`00
00?ooooo0_l00005ooooo`;o0000=?ooool001cooooo00?o0000ooooooooool0<_ooool2o`0000;o
oooo0_l0000>ooooo`;o00000_ooool2o`00013ooooo0_l00006ooooo`;o00003Oooool3o`0000_o
oooo0_l0000=ooooo`;o00001_ooool2o`0000;ooooo0ol00003ooooo`?o00000oooool3o`0000Co
oooo1?l00009ooooo`;o00001Oooool2o`0000[ooooo0_l0000Fooooo`;o00000oooool2o`0000Co
oooo1?l00006ooooo`;o00002Oooool2o`0000?ooooo0_l0000kooooo`007?ooool00ol0003ooooo
ooooo`0fooooo`;o00002?ooool2o`00013ooooo0_l00008ooooo`;o000000?oooooo`000?l00000
0oooool2o`0000Kooooo0_l00005ooooo`?o00001?ooool2o`0000;ooooo1Ol00002ooooo`;o0000
1oooool4o`0000Gooooo0ol00002ooooo`?o00000oooool5o`0000;ooooo0_l00006ooooo`?o0000
2?ooool2o`0000Gooooo0ol00009ooooo`;o00003?ooool2o`0000gooooo1Ol0000Cooooo`;o0000
@oooool001cooooo00?o0000ooooooooool0?Oooool2o`000004ooooool0003o0000ooooo`;o0000
3Oooool4o`0000Kooooo0_l000000ooooooo0000o`00000;ooooo`;o00001Oooool4o`0000;ooooo
2Ol00003ooooo`Co00001Oooool2o`0000Oooooo0ol00003ooooo`;o00000_ooool2o`0000;ooooo
0_l00002ooooo`Co00001Oooool2o`00013ooooo0_l00003ooooo`;o00001_ooool2o`0000[ooooo
0_l0000?ooooo`?o00003_ooool2o`0000?ooooo1?l00003ooooo`;o0000??ooool001cooooo00?o
0000ooooooooool07?ooool2o`0001gooooo1?l00004ooooo`;o00000oooool3o`0000;ooooo1?l0
0003ooooo`Co00003oooool2o`0000?ooooo1?l000000ooooooo0000o`000004o`0000;ooooo1Ol0
00001?oooooo0000o`000?l00003ooooo`Co00003_ooool2o`0000;ooooo0_l00004ooooo`;o0000
1_ooool4o`000003ooooool0003o000001Wooooo0_l00006ooooo`;o00001oooool2o`00013ooooo
0_l0000Aooooo`Co000000?oooooo`000?l000000_l00003ooooo`;o00001oooool2o`0003?ooooo
000Looooo`03o`000?oooooooooo01cooooo0_l0000Mooooo`;o00001?ooool2o`0000Gooooo0ol0
0002ooooo`_o00003oooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`00
0003o`0000Cooooo1ol00002ooooo`Co00004?ooool2o`000004ooooool0003o0000o`0000Sooooo
0_l00002ooooo`Co000000?oooooo`000?l000001?ooool2o`0000Sooooo0_l00002ooooo`;o0000
5_ooool2o`00013ooooo0_l00007ooooo`;o00002Oooool3o`000003ooooool0003o000000kooooo
0_l00009ooooo`;o0000:?ooool001cooooo00?o0000ooooooooool0@Oooool3o`0000cooooo1?l0
000Dooooo`Ko00001Oooool=o`0000?ooooo0_l00004ooooo`;o00003oooool2o`0000Wooooo0_l0
00000ooooooo0000o`000003o`000003ooooool0003o000000Cooooo0_l00003ooooo`;o00000ooo
ool2o`0000;ooooo0_l0000Gooooo`;o00006?ooool3o`00027ooooo0_l00004ooooo`;o0000:?oo
ool001cooooo0_l0000kooooo`;o00000oooool5o`0000Gooooo0_l00006ooooo`Oo00004?ooool2
o`0000;ooooo0_l000000ooooooo0000o`000002o`0000;ooooo4?l00004ooooo`;o000000Cooooo
o`000?l0003o00006Oooool8o`0000Wooooo0_l0000<ooooo`;o00003oooool2o`000003ooooool0
003o000000;o00001?ooool2o`00013ooooo0ol0000=ooooo`;o00004_ooool2o`0002kooooo000L
ooooo`03o`000?oooooooooo03[ooooo0_l00003ooooo`;o000000?oooooo`000?l000001Oooool2
o`0000Kooooo1ol00002ooooo`;o00002_ooool2o`0000Cooooo1ol00002ooooo`Oo000000?ooooo
o`000?l000001_l00004ooooo`;o000000Coooooo`000?l0003o00007_ooool3o`000004ooooool0
003o0000o`0000?ooooo0_l00004ooooo`;o00002?ooool2o`0000Wooooo0_l00004ooooo`;o0000
0oooool2o`0000Cooooo0_l000000ooooooo0000o`000005ooooo`;o00000oooool2o`000003oooo
ool0003o000000[ooooo0_l00002ooooo`;o00001Oooool2o`0000Kooooo0_l0000cooooo`007?oo
ool00ol0003oooooooooo`0mooooo`?o00003Oooool2o`0000_ooooo0_l000000ooooooo0000o`00
0007ooooo`;o00000oooool7o`000003ooooool0003o000000ko00000_ooool2o`0000;ooooo0_l0
0002ooooo`;o00000_ooool2o`0001kooooo4Ol00004ooooo`Ko00001_ooool2o`0000;ooooo0_l0
000>ooooo`;o00001Oooool2o`0000?ooooo1Ol0000:ooooo`;o000000?oooooo`000?l000001_oo
ool2o`0000Kooooo0ol0000booooo`007?ooool00ol0003oooooooooo`0mooooo`?o00001oooool2
o`000003ooooool0003o000000?o00003_ooool2o`0000Gooooo0_l00004ooooo`So000000?ooooo
o`000?l000003ol000000ooooooo0000o`000002ooooo`;o00001_ooool2o`0001Kooooo0_l00000
1?oooooo0000o`000?l00003ooooo`Go00000_ooool9o`0000;ooooo2_l00002ooooo`Co00000_oo
ool2o`0000?ooooo0_l0000Booooo`;o00000_ooool4o`0000;ooooo0_l00002ooooo`;o00000_oo
ool2o`000003ooooool0003o000000oooooo0_l0000booooo`007?ooool00ol0003oooooooooo`0/
ooooo`;o00003_ooool3o`0000Oooooo2?l000000ooooooo0000o`00000Cooooo`Co000000?ooooo
o`000?l000005_l000001Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`000?l000000_l0
0004ooooo`;o00003?ooool2o`0000Cooooo0_l00002ooooo`;o000000Coooooo`000?l0003o0000
2oooool2o`000003ooooool0003o000000Gooooo1_l00002ooooo`;o00000_ooool4o`000003oooo
ool0003o000000;ooooo1Ol0000;ooooo`;o00000oooool3o`0000Cooooo0_l00002ooooo`;o0000
0_ooool2o`0004[ooooo000Looooo`03o`000?oooooooooo02cooooo0_l00007ooooo`;o00001Ooo
ool3o`0000Gooooo1ol00004ooooo`;o00002Oooool2o`0000Sooooo1?l000000ooooooo0000o`00
0002o`000003ooooool0003o000000Wo000000?oooooo`000?l000000_l000001?oooooo0000o`00
0?ooool3o`000005ooooool0003o0000o`000?ooool00ol00004ooooo`;o00001oooool2o`0000?o
oooo0ol00003ooooo`;o00004oooool2o`0000Cooooo0_l00004ooooo`;o00001_ooool2o`0000Go
oooo0ol000001?oooooo0000o`000?ooool4o`0000Wooooo0_l00003ooooo`;o00004_ooool2o`00
04Gooooo000Looooo`03o`000?oooooooooo03Gooooo0_l00005ooooo`;o00001Oooool3o`000004
ooooool0003o0000ooooo`;o00003_ooool2o`0000Wooooo0_l00003ooooo`Co000000?oooooo`00
0?l000005?l000000ooooooo0000o`000005o`0000gooooo0_l00004ooooo`;o00002_ooool2o`00
00Wooooo0_l00007ooooo`;o00001Oooool2o`0000Gooooo0_l00003ooooo`Go00001_ooool6o`00
00gooooo0_l00005ooooo`?o00001oooool2o`00017ooooo0_l0000booooo`007?ooool00ol0003o
ooooooooo`0gooooo`;o00002_ooool2o`0000Gooooo0_l0000<ooooo`;o00000oooool4o`0000_o
oooo0_l000000ooooooo0000o`00000Co`0000;ooooo1?l00007ooooo`;o00001oooool2o`0000Go
oooo0_l00009ooooo`Co00001oooool2o`0000Gooooo0_l00007ooooo`;o00001?ooool3o`0000?o
oooo1ol00003ooooo`[o00002_ooool2o`0000;ooooo0_l000001?oooooo0000o`000?l0000;oooo
o`;o00003Oooool2o`0003;ooooo000Looooo`03o`000?oooooooooo03Oooooo0_l0000Kooooo`?o
000000?oooooo`000?l000000oooool4o`0000?ooooo0_l00002ooooo`;o000000Coooooo`000?l0
003ooooo6Ol00005ooooo`;o00000oooool2o`0000Wooooo0_l00003ooooo`;o00002oooool4o`00
00Wooooo0_l000001?oooooo0000o`000?l0000<ooooo`?o00001_ooool4o`0000?ooooo0_l00002
ooooo`Oo00002Oooool2o`0000;ooooo0_l000000ooooooo0000o`000003o`0000Gooooo0_l00002
ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool09oooool2o`0002[ooooo1?l0000=oooo
o`;o00000_ooool2o`000003ooooool0003o000000Co00000_oooolGo`000004ooooool0003o0000
o`0000?ooooo0_l000001?oooooo0000o`000?l00005ooooo`;o00003oooool2o`000003ooooool0
003o000000Wooooo0_l00002ooooo`;o00008_ooool6o`000003ooooool0003o000000Co000000Co
ooooo`000?l0003ooooo0_l00005ooooo`;o00001Oooool2o`0000;ooooo0_l00011ooooo`007?oo
ool00ol0003oooooooooo`0Wooooo`;o0000:?ooool4o`0000Cooooo0_l0000@ooooo`So000000?o
ooooo`000?l000004?l000000ooooooo0000o`000004o`0000Cooooo0_l000001?oooooo0000o`00
0?l0000Fooooo`;o00004?ooool2o`000003ooooool0003o000000;o00004oooool2o`0000Sooooo
3Ol00004ooooo`;o00007Oooool2o`0000;ooooo0_l0000`ooooo`007?ooool00ol0003ooooooooo
o`18ooooo`;o00001oooool6o`0000;ooooo1_l00007ooooo`;o00000ooooolMo`000004ooooool0
003o0000o`00037ooooo1?l000000ooooooo0000o`000002o`0000[ooooo0_l00007ooooo`;o0000
00?oooooo`000?l000001Oooool2o`0000?ooooo1_l0000Uooooo`;o00000_ooool2o`00033ooooo
000Looooo`03o`000?oooooooooo03[ooooo0_l00008ooooo`;o00000_ooool2o`0000Wooooo1?l0
0004ooooo`Co00001oooool2o`0000?ooooo1Ol000000ooooooo0000o`00000Eo`000003ooooool0
003o000000;o00000oooool5o`0000?ooooo0_l0000<ooooo`;o00004oooool6o`0000oooooo0_l0
0008ooooo`Co00002_ooool3o`000003ooooool0003o000000Cooooo0_l0000:ooooo`;o0000BOoo
ool001cooooo00?o0000ooooooooool0>Oooool3o`0000?ooooo0_l00003ooooo`;o00000oooool4
o`0000Cooooo1_l00003ooooo`;o00001Oooool2o`0000?ooooo0_l000000ooooooo0000o`00000R
o`000003ooooool0003o000000Oo000000?oooooo`000?l000000_ooool2o`0000Sooooo0_l00000
0ooooooo0000o`000002o`0000Wooooo0_l00003ooooo`Go00002Oooool2o`0000oooooo0ol0000<
ooooo`Co00001?ooool3o`0000[ooooo0_l0000Gooooo`;o0000<?ooool001cooooo00?o0000oooo
ooooool0>Oooool2o`0000Cooooo0_l00006ooooo`Ko00001?ooool2o`0000Oooooo0_l00005oooo
o`;o00000_oooolWo`0000;ooooo0_l00005ooooo`;o00001Oooool2o`0000_ooooo1?l00009oooo
o`;o00001_ooool2o`0000?ooooo0_l00004ooooo`;o00007oooool9o`000003ooooool0003o0000
00Wooooo0_l00009ooooo`;o00002Oooool4o`00033ooooo000Looooo`03o`000?oooooooooo03oo
oooo0_l00006ooooo`;o000000Coooooo`000?l0003o00002_ooool2o`0000?ooooo0_l00003oooo
o`;o000000?oooooo`000?l000006_l000000ooooooo0000o`00000:o`000004ooooool0003o0000
o`0001Sooooo0_l00008ooooo`;o00002Oooool2o`0000?ooooo0_l0000Booooo`;o00001Oooool2
o`0000[ooooo2Ol000000ooooooo0000o`000002ooooo`;o00000oooool4o`0000?ooooo0_l00004
ooooo`;o00002Oooool2o`0003;ooooo000Looooo`;o0000=oooool2o`0000Sooooo0_l00009oooo
o`;o00002_ooool2o`0000?ooooo0_l00005ooooo`Go000000?oooooo`000?l000008_l000001?oo
oooo0000o`000?l0000Booooo`;o00001?ooool2o`0000Sooooo0_l00006ooooo`;o000000?ooooo
o`000?l000003_ooool2o`0000;ooooo0ol000001?oooooo0000o`000?l00005ooooo`?o00002_oo
ool8o`0000Gooooo0_l00003ooooo`?o00001?ooool2o`0004?ooooo000Looooo`03o`000?oooooo
oooo03Kooooo0_l00008ooooo`Go00003oooool2o`0000_ooooo3Ol000000ooooooo0000o`00000J
o`000003ooooool0003o000000[ooooo1?l00006ooooo`?o00004Oooool2o`0000?ooooo0ol00005
ooooo`Go00001_ooool2o`000003ooooool0003o000000[o00000_ooool2o`0000;ooooo0_l00003
ooooo`;o000000Coooooo`000?l0003ooooo0ol00004ooooo`Co00001oooool2o`00017ooooo0_l0
000dooooo`007?ooool00ol0003oooooooooo`0Vooooo`;o00003_ooool2o`0000[ooooo0ol00000
0ooooooo0000o`000002o`000003ooooool0003o000000Oooooo1?l000000ooooooo0000o`000004
ooooo`Co000000?oooooo`000?l000000_ooool6o`000003ooooool0003o000001go00000_ooool2
o`0000Kooooo1?l00006ooooo`;o00004_ooool2o`0000Cooooo0ol00004ooooo`Go00001?ooool3
o`0000;ooooo4?l00002ooooo`Co000000?oooooo`000?l000001?ooool4o`0000?ooooo1_l00005
ooooo`;o00004Oooool2o`0003Cooooo000Looooo`03o`000?oooooooooo02Kooooo0_l0000>oooo
o`;o00002Oooool3o`0000;ooooo1?l000000ooooooo0000o`000007ooooo`Co000000?oooooo`00
0?l000000oooool3o`0000;ooooo0_l00004ooooobCo00000_ooool3o`0000Gooooo0_l0000<oooo
o`;o00003oooool2o`0000Cooooo0ol00005ooooo`;o00001OoooolDo`0000Kooooo0ol00006oooo
o`Go00001_ooool2o`0004kooooo000Looooo`03o`000?oooooooooo03kooooo0_l000001?oooooo
0000o`000?l00002ooooo`;o00005_ooool2o`0000?ooooo0_l00004oooooa;o000000?oooooo`00
0?l000003ol00002ooooo`;o00000_ooool2o`000004ooooool0003o0000o`0000cooooo0_l0000?
ooooo`;o00001?ooool3o`0000Sooooo5_l000000ooooooo0000o`000006ooooo`;o00001oooool4
o`0005Kooooo000Looooo`03o`000?oooooooooo03kooooo0_l00004ooooo`Co00002?ooool2o`00
00gooooo0_l00003ooooo`;o000000?oooooo`000?l000008Ol000000ooooooo0000o`000004oooo
o`Co000000?oooooo`000?l000002_ooool2o`0000Kooooo0_l00009ooooo`;o00001?ooool3o`00
00Wooooo3Ol000000ooooooo0000o`00000;o`0000gooooo1?l00005ooooo`;o00000oooool2o`00
00Kooooo0_l00007ooooo`;o0000>Oooool001cooooo00?o0000ooooooooool0?oooool2o`0000?o
oooo0_l00006ooooo`;o00000_ooool2o`0000?ooooo0_l00008ooooo`Co000000Coooooo`000?l0
003ooooo8ol000000ooooooo0000o`000007o`0000;ooooo0_l0000:ooooo`;o00001_ooool2o`00
00Cooooo0ol00002ooooo`;o00001?ooool3o`0000Wooooo6?l000000ooooooo0000o`000004oooo
o`;o00001Oooool3o`000004ooooool0003o0000o`0000Cooooo0_l00002ooooo`?o00001_ooool4
o`0000Gooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`0Oooooo`;o00006_ooool2o`00
00;ooooo0_l0000;ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`;o00001_ooool2o`00
0004ooooool0003o0000ooooo`;o000000?oooooo`000?l000007ol000000ooooooo0000o`000004
o`0000Kooooo0_l0000=ooooo`;o00001oooool3o`0000Sooooo0_l00002ooooo`;o00001?ooool2
o`000003ooooool0003o000001Ko00000_ooool2o`0000;ooooo0_l00005ooooo`Oo00002?ooool2
o`0000Wooooo0_l00007ooooo`;o0000=oooool001cooooo00?o0000ooooooooool07oooool2o`00
01[ooooo0_l00002ooooo`?o00003oooool2o`0000Kooooo0_l0000<ooooo`_o000000?oooooo`00
0?l000006?l00003ooooo`Co00001?ooool2o`000003ooooool0003o000000[ooooo0_l0000;oooo
o`;o00002Oooool3o`0000;ooooo0ol000000ooooooo0000o`00000Jo`0000Wooooo1Ol00008oooo
o`;o000000?oooooo`000?l000004Oooool2o`0003Oooooo000Looooo`03o`000?oooooooooo02Ko
oooo0_l0000Hooooo`;o00002Oooool4o`0000[ooooo0_l00008ooooo`;o000000?oooooo`000?l0
00009_l00003ooooo`?o00001Oooool4o`0000Cooooo0_l0000Aooooo`;o00001Oooool2o`0000?o
oooo0_l00002ooooo`;o000000?oooooo`000?l000006Ol0000;ooooo`?o00002_ooool2o`000004
ooooool0003o0000ooooo`;o000000?oooooo`000?l000001_ooool2o`0003cooooo000Looooo`03
o`000?oooooooooo02Kooooo0_l0000Cooooo`;o00002_ooool2o`0000;ooooo1?l0000Booooobko
000000Coooooo`000?l0003o00001_ooool2o`0000Kooooo0_l00006ooooo`;o00004?ooool2o`00
00[ooooo3?l000000ooooooo0000o`00000<o`0000?ooooo0_l00005ooooo`?o00002?ooool2o`00
00Cooooo0_l000001?oooooo0000o`000?ooool2o`0000Kooooo0_l0000looooo`007?ooool00ol0
003oooooooooo`0eooooo`;o00001?ooool2o`0000[ooooo0_l00004ooooo`;o000000?oooooo`00
0?l000003oooool2o`0000;ooooo;_l00006ooooo`;o00003?ooool4o`0001Sooooo5_l000000ooo
oooo0000o`000007o`0000;ooooo0_l00005ooooo`?o00002?ooool2o`0000Cooooo0_l0000Aoooo
o`;o0000=oooool001cooooo00?o0000ooooooooool0=Oooool2o`0001Kooooo0_l000000ooooooo
0000o`00000Eooooo`;o000000?oooooo`000?l000009?l000001?oooooo0000o`000?ooool2o`00
00Gooooo0_l00005ooooo`;o00000oooool2o`0000Kooooo0_l0000Booooob3o00003?ooool2o`00
00_ooooo0ol0000Aooooo`;o0000=oooool001cooooo00?o0000ooooooooool0=_ooool2o`0001;o
oooo0_l0000Kooooo`;o00000_oooolVo`0000?ooooo0_l00005ooooo`;o00001Oooool2o`0000_o
oooo0_l0000Eoooooago00000oooool2o`0000?ooooo0_l00002ooooo`;o00001?ooool2o`0000Go
oooo0_l00002ooooo`Co0000AOooool001cooooo00?o0000ooooooooool0=_ooool2o`0000?ooooo
0ol0000<ooooo`;o00004Oooool2o`0000Oooooo0ol00002ooooobKo00004?ooool2o`0000_ooooo
0_l0000Foooooaco00001?ooool2o`0000?ooooo0_l00008ooooo`;o000000Coooooo`000?l0003o
00001Oooool4o`0000oooooo0ol0000cooooo`007?ooool00ol0003oooooooooo`0booooo`;o0000
1oooool3o`0000Cooooo0_l00009ooooo`;o00002_ooool2o`0000;ooooo0_l00003ooooo`;o0000
0_ooool9o`000003ooooool0003o000001go00004?ooool4o`0000_ooooo0_l00006ooooo`;o0000
1_ooool2o`0000Gooooo0_l000000ooooooo0000o`00000Ho`0000Oooooo0_l00009ooooo`;o0000
0_ooool3o`0000Kooooo0_l0000@ooooo`?o0000<oooool001cooooo0_l0000cooooo`;o00002Ooo
ool2o`0000;ooooo0ol00007ooooo`Co00001_ooool2o`0000;ooooo1?l00005ooooo`;o000000Go
ooooo`000?l0003o0000ooooo`0Vo`0000;ooooo0_l0000<ooooo`;o00000_ooool2o`0000Oooooo
1?l00005ooooo`?o00001_ooool2o`0000Gooooo7_l00006ooooo`;o00002?ooool3o`0005?ooooo
000Looooo`03o`000?oooooooooo03gooooo0_l00002ooooo`?o00001oooool2o`0000Sooooo0_l0
0004ooooo`;o00001oooool3o`0000;ooooo0_l00003oooooa_o000000Coooooo`000?l0003o0000
1?ooool2o`00013ooooo0_l00007ooooo`Co00001Oooool5o`0000_ooooo1ol000000ooooooo0000
o`00000Do`0000Oooooo0_l00005ooooo`Co00003_ooool2o`000003ooooool0003o0000047ooooo
000Looooo`03o`000?oooooooooo04;ooooo0_l00003ooooo`;o00006oooool3o`0000;ooooo1?l0
0002oooooago00002?ooool2o`0000;ooooo0_l0000<ooooo`;o00003_ooool4o`0000cooooo6ol0
0009ooooo`;o00001Oooool2o`00013ooooo0_l000000ooooooo0000o`00000Fooooo`;o0000:Ooo
ool001cooooo00?o0000ooooooooool0<oooool4o`000004ooooool0003o0000ooooo`;o00002_oo
ool2o`0000?ooooo0_l0000:ooooo`?o00000_ooool2o`000003ooooool0003o000000;ooooo2Ol0
0002oooooa;o000000?oooooo`000?l000001ol000000ooooooo0000o`000006ooooo`?o000000?o
ooooo`000?l000003?ooool2o`0000Kooooo0_l00003ooooo`;o000000Coooooo`000?l0003o0000
3OoooolLo`0000Kooooo0_l00007ooooo`;o00000_ooool2o`0002Oooooo0_l0000Yooooo`007?oo
ool00ol0003oooooooooo`0cooooo`Co000000Coooooo`000?l0003ooooo1?l00002ooooo`?o0000
00?oooooo`000?l000001Oooool2o`000004ooooool0003o0000o`0000Kooooo1ol000000ooooooo
0000o`000002ooooo`So000000?oooooo`000?l000000ol00002ooooo`go000000?oooooo`000?l0
00001?l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000Cooooo0_l000000ooo
oooo0000o`00000Dooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00004?oooolIo`00
00;ooooo0_l00002ooooo`Co00002Oooool2o`0000;ooooo0_l0000@ooooo`;o0000??ooool001co
oooo00?o0000ooooooooool0=?ooool2o`0000Oooooo0_l00002ooooo`?o000000Coooooo`000?l0
003ooooo0_l00005ooooo`?o00001?ooool2o`0000?ooooo0_l00003ooooo`;o00000oooool4o`00
0003ooooool0003o000000?o000000?oooooo`000?l000001ol00003ooooo`Oo000000?oooooo`00
0?l000002Oooool4o`0000?ooooo1?l0000Gooooo`?o00000_ooool3o`0001;ooooo3ol000001?oo
oooo0000o`000?l00006ooooo`;o00001?ooool2o`0000Cooooo0_l00007ooooo`;o00000oooool2
o`0000Wooooo1?l0000?ooooo`;o0000:oooool001cooooo00?o0000ooooooooool0@?ooool2o`00
00?ooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l00005ooooo`?o00001oooool2o`00
00Sooooo1Ol000000ooooooo0000o`000002o`000003ooooool0003o000000Co000000Goooooo`00
0?l0003o0000ooooo`03o`000003ooooool0003o000000?o00000_ooool8o`0000?ooooo0_l00004
ooooo`;o00005?ooool2o`0000;ooooo0_l00002ooooo`;o00004Oooool<o`000003ooooool0003o
000000;o00000_ooool3o`0000gooooo0_l0000<ooooo`;o00001_ooool2o`000003ooooool0003o
0000017ooooo0_l0000[ooooo`007?ooool00ol0003oooooooooo`0mooooo`;o000000?oooooo`00
0?l000000oooool3o`0000;ooooo0_l00003ooooo`;o00001_ooool2o`0000Wooooo0_l00007oooo
o`Co000000Goooooo`000?l0003o0000ooooo`02o`0000;ooooo0ol000000ooooooo0000o`000005
o`000003ooooool0003o000000?o00000_ooool8o`0000?ooooo0_l00004ooooo`;o00001?ooool2
o`0000Oooooo0_l00002ooooo`;o00000oooool2o`0000Cooooo0_l0000:ooooo`Co000000?ooooo
o`000?l000003?l000000ooooooo0000o`000002o`0000;ooooo0ol000000ooooooo0000o`000007
ooooo`Ko00003_ooool2o`0000?ooooo0ol00004ooooo`;o0000>_ooool001cooooo00?o0000oooo
ooooool0?Oooool2o`000003ooooool0003o000000Cooooo1?l0000Eooooo`;o000000?oooooo`00
0?l000001oooool4o`0000Gooooo1ol00003ooooo`Go00000oooool5o`0000Kooooo0_l00007oooo
o`Co00001?ooool2o`0000Oooooo0_l00002ooooo`;o00000oooool2o`00013ooooo1?l000000ooo
oooo0000o`000004ooooo`So00002oooool2o`0000Oooooo1_l000001?oooooo0000o`000?l00004
ooooo`?o00000oooool2o`0000Cooooo0_l00004ooooo`;o0000>_ooool001cooooo00?o0000oooo
ooooool0@?ooool2o`0000Kooooo0_l00005ooooo`;o00003_ooool2o`0000Sooooo1_l00004oooo
o`;o000000Coooooo`000?l0003ooooo1?l00003ooooo`?o000000?oooooo`000?l000001Ol00002
ooooo`Co00001oooool4o`00013ooooo1Ol0000<ooooo`;o00003Oooool2o`0000;ooooo1Ol00002
ooooo`;o00001oooool3o`0000oooooo1Ol00002ooooo`Go00007?ooool2o`0002gooooo000Loooo
o`03o`000?oooooooooo04;ooooo0_l0000;ooooo`;o00003?ooool2o`000004ooooool0003o0000
o`0000Kooooo0_l00002ooooo`Co00000_ooool2o`0000;ooooo0_l00002ooooo`Co000000?ooooo
o`000?l000000_ooool7o`0000;ooooo1?l00007ooooo`;o00004_ooool5o`0000Wooooo1Ol00000
0ooooooo0000o`00000:ooooo`;o000000?oooooo`000?l000000ol000000ooooooo0000o`000009
ooooo`?o00002Oooool2o`0000Cooooo0_l00005ooooo`;o000000?oooooo`000?l000002?ooool2
o`0001;ooooo0_l0000]ooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00002Oooool2o`00
01Gooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00002_ooool4o`0000Kooooo0_l00002
ooooo`Co000000Coooooo`000?l0003o00000oooool2o`0000Sooooo0_l00005ooooo`;o00002ooo
ool2o`0001?ooooo1?l00003ooooo`;o00001?ooool2o`0000Oooooo0_l00004ooooo`;o00002_oo
ool2o`0000Wooooo0_l00003ooooo`;o00004oooool3o`00043ooooo000Looooo`03o`000?oooooo
oooo03Oooooo0_l000001?oooooo0000o`000?ooool3o`0001Wooooo0_l00008ooooo`Co00001_oo
ool4o`0000Kooooo0_l000001?oooooo0000o`000?l00004ooooo`;o00000_ooool2o`000003oooo
ool0003o000000Kooooo1?l00003ooooo`;o00002oooool2o`00017ooooo1_l00005ooooo`;o0000
0_ooool2o`0000Cooooo0_l0000Fooooo`Co00000_ooool2o`0000Gooooo0_l0000Dooooo`;o0000
@?ooool001cooooo00?o0000ooooooooool0<?ooool2o`0000Gooooo0_l000001?oooooo0000o`00
0?ooool6o`00023ooooo1Ol00007ooooo`Co00001?ooool8o`0000Kooooo1Ol00008ooooo`;o0000
1?ooool4o`0001Cooooo0_l00005ooooo`;o00001Oooool2o`0000;ooooo0_l00008ooooo`;o0000
5_ooool4o`0000;ooooo0_l00008ooooo`;o00003?ooool2o`0004Gooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0
003oooooooooo`0`ooooo`;o00001Oooool6o`0000?ooooo0ol0000Eooooo`;o00003?ooool3o`00
00Gooooo0_l000000ooooooo0000o`000004ooooo`?o00000oooool4o`0000?ooooo1_l00004oooo
o`;o00000oooool2o`0000?ooooo1?l0000Dooooo`;o00002Oooool2o`000003ooooool0003o0000
00Kooooo0_l00004ooooo`;o00003oooool2o`0000;ooooo0_l0000Aooooo`;o00001_ooool2o`00
00Cooooo0_l00005ooooo`;o0000?_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo03Wooooo1?l0
000:ooooo`;o00003oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l0
0008ooooo`;o00000oooool6o`0000Cooooo0_l00003ooooo`;o000000?oooooo`000?l000000_oo
ool2o`0000Gooooo0ol00005ooooo`;o00004?ooool2o`0000Wooooo0_l0000:ooooo`;o00002Ooo
ool2o`0000;ooooo1?l00003ooooo`;o00004_ooool2o`0000_ooooo0_l0000nooooo`0000?ooooo
oa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`0hooooo`?o00003?ooool2o`000003ooooool0003o000001Cooooo0_l0
000Cooooo`;o00002?ooool2o`0000?ooooo0_l00005ooooo`Co00001oooool2o`0000;ooooo0_l0
0004ooooo`Co00001Oooool2o`0000gooooo1?l0000:ooooo`;o00000oooool2o`0000Gooooo0_l0
0002ooooo`;o000000?oooooo`000?l000002?ooool2o`0000?ooooo0_l00004ooooo`;o00006Ooo
ool2o`0003kooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000
oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000>?ooool2o`0000?ooooo0_l0000;ooooo`;o00006ooo
ool7o`0000cooooo0_l00004ooooo`;o00000_ooool2o`0000Gooooo1?l00003ooooo`;o00000_oo
ool2o`0000Sooooo1?l0000Booooo`Ko00002_ooool2o`0000?ooooo0_l00009ooooo`;o000000?o
ooooo`000?l000000ol0000@ooooo`;o00001?ooool2o`0005?ooooo00000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oo
oooooooo02gooooo0_l0000>ooooo`;o00002_ooool2o`0001_ooooo2?l0000<ooooo`;o00001?oo
ool2o`0000;ooooo0_l0000<ooooo`;o00000_ooool2o`0000?ooooo2Ol000001?oooooo0000o`00
0?l00003ooooo`;o00002?ooool3o`0000;ooooo1?l000000ooooooo0000o`000002ooooo`Go0000
4oooool6o`0000_ooooo0_l000000ooooooo0000o`000003ooooo`;o00001Oooool2o`0004cooooo
00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qoooool02?oo
ool00ol0003oooooooooo`0]ooooo`;o00003_ooool2o`0000;ooooo0_l00002ooooo`;o00000_oo
ool2o`000003ooooool0003o000001Sooooo0_l00002ooooo`;o00003_ooool2o`0000?ooooo0_l0
0002ooooo`?o00003?ooool2o`0000Oooooo1ol00003ooooo`?o00000oooool2o`0000Gooooo0_l0
00000ooooooo0000o`000003ooooo`Co000000?oooooo`000?l000000_ooool5o`0001Gooooo1?l0
000;ooooo`;o000000Coooooo`000?l0003ooooo0ol00006ooooo`;o00001?ooool2o`0004Kooooo
00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003o
ooooooooo`11ooooo`;o00000_ooool3o`0000Cooooo0ol0000=ooooo`;o00000oooool2o`0001;o
oooo0_l00003ooooo`;o00000oooool2o`0000;ooooo0_l0000Gooooo`;o00005?ooool2o`0000Ko
oooo0_l0000?ooooo`;o00009Oooool3o`0000cooooo0_l00016ooooo`0000Koooooonk^k_lb<S;o
0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0A_ooool2
o`0000Gooooo1?l00004ooooo`;o00001Oooool2o`0000?ooooo0_l0000@ooooo`Co00001_ooool2
o`0000Sooooo0ol0000;ooooo`;o00001Oooool2o`0000?ooooo0_l0000Looooo`;o00001_ooool2
o`0000;ooooo0_l00003ooooo`;o00002_ooool2o`00017ooooo1?l0001Fooooo`007?ooool00ol0
003oooooooooo`16ooooo`;o00001_ooool3o`0000Cooooo0_l0000:ooooo`?o00001_ooool2o`00
00Oooooo0_l00008ooooo`;o00002?ooool3o`0000_ooooo0_l00002ooooo`;o000000?oooooo`00
0?l000000oooool2o`0000Cooooo0_l0000>ooooo`;o00001_ooool2o`0000Kooooo0_l00007oooo
o`;o00001_ooool3o`000004ooooool0003o0000ooooo`;o00003_ooool6o`0000Oooooo0_l0001;
ooooo`007?ooool00ol0003oooooooooo`0kooooo`;o00004Oooool3o`00017ooooo0_l00006oooo
o`;o00001_ooool2o`0000;ooooo0_l00004ooooo`;o00006Oooool4o`0000;ooooo0_l00003oooo
o`;o00000oooool2o`0000Sooooo0_l00004ooooo`;o00001oooool2o`0000cooooo0_l00007oooo
o`Go00000oooool2o`0001;ooooo0_l00006ooooo`?o0000Boooool001cooooo00?o0000oooooooo
ool0=_ooool3o`0000;ooooo0ol0000@ooooo`?o00004Oooool2o`0000kooooo0_l00002ooooo`;o
00001?ooool2o`0001Oooooo1Ol000000ooooooo0000o`000007o`0000Gooooo0_l00006ooooo`;o
00002?ooool2o`0000?ooooo0_l0000<ooooo`;o00001oooool2o`000003ooooool0003o000000So
oooo0_l00007ooooo`;o00003?ooool2o`0004cooooo000Looooo`03o`000?oooooooooo03Kooooo
0ol00003ooooo`;o00001Oooool2o`0000oooooo0_l0000=ooooo`;o00001Oooool2o`0000Wooooo
1?l00004ooooo`;o00004_ooool6o`000004ooooool0003o0000ooooo`So00001Oooool4o`0000[o
oooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`Co00001_ooool2o`00
00Sooooo0_l00008ooooo`;o00000_ooool4o`000003ooooool0003o000000_ooooo0_l00003oooo
o`;o00001_ooool3o`0003oooooo000Looooo`03o`000?oooooooooo03?ooooo0_l00002ooooo`;o
000000?oooooo`000?l000001oooool2o`0000Sooooo1?l00003ooooo`;o00003Oooool2o`0000Co
oooo0ol000000ooooooo0000o`000004ooooo`Ko00001?ooool2o`0001;ooooo1Ol00002ooooo`_o
000000?oooooo`000?l000001_l0000:ooooo`;o00000oooool2o`000004ooooool0003o0000oooo
o`;o00000oooool4o`0000Kooooo1Ol00002ooooo`;o000000?oooooo`000?l000003?ooool4o`00
0003ooooool0003o000000_ooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo1Ol0000o
ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00000_ooool2o`000003ooooool0003o0000
00;ooooo0_l0000=ooooo`Co00006?ooool2o`0000;ooooo0_l00004ooooo`;o000000?oooooo`00
0?l000005?ooool2o`0000Kooooo0_l00002oooooa;o00000oooool3o`0000;ooooo0ol00002oooo
o`Ko00001?ooool2o`0000oooooo0ol00002ooooo`;o00005?ooool2o`0000Sooooo0_l000000ooo
oooo0000o`000006ooooo`;o000000?oooooo`000?l00000@_ooool001cooooo00?o0000oooooooo
ool0>?ooool2o`0000Cooooo0_l0000=ooooo`;o00008Oooool2o`0000;ooooo1?l0000Dooooo`;o
00001Oooool3o`0000;ooooo0ol000001?oooooo0000o`000?ooool;o`0000;ooooo1?l00002oooo
o`?o00000_ooool4o`000003ooooool0003o000002oooooo0_l00002ooooo`;o00001?ooool2o`00
00Kooooo0_l000000ooooooo0000o`000015ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o
00004oooool4o`0001oooooo0_l00002ooooo`;o00002Oooool2o`0000Kooooo0_l000001?oooooo
0000o`000?l00006ooooo`;o00000_oooolAo`0000;ooooo1ol00004ooooo`;o00001Oooool2o`00
023ooooo0_l0000:ooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`;o00001_ooool2
o`000003ooooool0003o000004Gooooo000Looooo`03o`000?oooooooooo03;ooooo0_l00004oooo
o`;o00003?ooool2o`0000Kooooo0ol000000ooooooo0000o`000004ooooo`;o00004?ooool2o`00
00Gooooo0_l00008ooooo`;o00000_ooool2o`000003ooooool0003o000000?ooooo0_l000001?oo
oooo0000o`000?l0000:oooooa[o00001?ooool2o`0000Oooooo0_l000000ooooooo0000o`000007
ooooo`;o00004_ooool2o`0000[ooooo0_l00008ooooo`;o00006oooool2o`0003Kooooo000Loooo
o`03o`000?oooooooooo03;ooooo0_l00004ooooo`;o00003?ooool2o`0000Kooooo0_l00002oooo
o`;o00001?ooool2o`00013ooooo0_l00005ooooo`;o00002?ooool2o`0000;ooooo1Ol0000>oooo
o`Co000000?oooooo`000?l000004_l00007ooooo`;o00001oooool2o`000003ooooool0003o0000
00?o00000oooool2o`0000;ooooo1?l0000?ooooo`Co00005?ooool2o`0000?ooooo0ol0000Doooo
o`;o0000=_ooool001cooooo00?o0000ooooooooool0@_ooool2o`0000Cooooo0_l0000gooooo`?o
00003_ooool4o`000003ooooool0003o0000013o00000oooool2o`0000Cooooo0_l00007ooooo`;o
00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`Co00003Oooool4o`0001Co
oooo0ol00002ooooo`Go0000B_ooool001cooooo0_l00013ooooo`;o00001?ooool2o`0000Oooooo
0_l00007ooooo`;o00006Oooool2o`0000Sooooo0_l000001?oooooo0000o`000?ooool2o`0000go
oooo0_l00003ooooo`Go000000?oooooo`000?l000003Ol00005ooooo`Co00001?ooool3o`0000Go
oooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool2o`0000_ooooo0_l00004ooooo`;o
00004_ooool3o`0000Gooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`17ooooo`;o0000
00?oooooo`000?l000001Oooool2o`0000Oooooo0_l0000Iooooo`;o00001Oooool2o`000003oooo
ool0003o000000Cooooo0_l00004ooooo`;o00001oooool2o`0000;ooooo6?l00003ooooo`Co0000
0oooool5o`0000Oooooo0ol000000ooooooo0000o`00000?ooooo`;o00001?ooool2o`0000Gooooo
0_l00005ooooo`;o00001?ooool2o`0000Kooooo0ol00019ooooo`007?ooool00ol0003ooooooooo
o`0jooooo`;o000000?oooooo`000?l000002?ooool5o`0000gooooo0_l0000Qooooo`;o00000ooo
ool2o`0000Kooooo1Ol00008oooooaco00002?ooool6o`0000Gooooo1?l0000Hooooo`;o00001Ooo
ool2o`0000Gooooo0_l0000;ooooo`Co0000BOooool001cooooo00?o0000ooooooooool0>_ooool2
o`000003ooooool0003o000000Wooooo0_l0000:ooooo`;o00000oooool2o`0001kooooo0_l00000
0ooooooo0000o`000003ooooo`;o00001_ooool2o`000003ooooool0003o000000Sooooo4_l00000
0ooooooo0000o`000007o`0000cooooo0_l00005ooooo`;o00009?ooool2o`000003ooooool0003o
000000cooooo0_l0000Booooo`;o0000=oooool001cooooo00?o0000ooooooooool0@Oooool2o`00
017ooooo0ol0000Rooooo`;o00006_ooool2o`000003ooooool0003o000001Wo00000_ooool2o`00
00oooooo1?l0000?ooooo`;o00004?ooool2o`000003ooooool0003o000000Kooooo0_l00004oooo
o`;o00003oooool2o`000003ooooool0003o000003Oooooo000Looooo`03o`000?oooooooooo047o
oooo0ol0000;ooooo`;o00001?ooool2o`0002Cooooo0_l0000Dooooo`;o00000_oooolNo`0000;o
oooo0_l00003ooooo`;o00002_ooool4o`0000oooooo1?l0000Iooooo`;o00001?ooool2o`0000oo
oooo0_l0000jooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00001_ooool3o`0000;ooooo
0_l0000<ooooo`;o00007?ooool2o`0001Cooooo0_l00002oooooaCo000000?oooooo`000?l00000
1ol00006ooooo`?o00003?ooool2o`0000cooooo0_l000000ooooooo0000o`000002o`0000oooooo
0_l000001?oooooo0000o`000?l0000:ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0
@_ooool2o`0000Kooooo0ol00007ooooo`;o00001oooool2o`0001kooooo0_l00009ooooo`;o0000
2oooool2o`000003ooooool0003o000000[o000000?oooooo`000?l000002?l000001?oooooo0000
o`000?l00006ooooo`?o00001Oooool2o`0000Cooooo0ol00003ooooo`;o00001oooool2o`0001?o
oooo0ol000001?oooooo0000o`000?l0001Gooooo`007?ooool00ol0003oooooooooo`12ooooo`Co
00003_ooool2o`0000?ooooo0_l0000Rooooo`;o00002Oooool2o`0000Gooooo0_l00004ooooo`;o
000000?oooooo`000?l000006Ol00002ooooo`;o000000?oooooo`000?l000001?l00003ooooo`;o
00001?ooool2o`0000Cooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l00006ooooo`;o
00000_ooool2o`0000Kooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o0000
2Oooool2o`0000Sooooo0_l00002ooooo`;o00008_ooool5o`0000Wooooo0_l00006ooooo`ko0000
00?oooooo`000?l000002ol00002ooooo`;o000000?oooooo`000?l000000_ooool4o`0000_ooooo
0_l00002ooooo`;o00000oooool3o`0000Gooooo0_l00005ooooo`;o00002?ooool2o`0000Sooooo
0_l000000ooooooo0000o`00001=ooooo`007?ooool00ol0003oooooooooo`1=ooooo`Ko00002_oo
ool2o`0001gooooo0_l00003ooooo`Go00004?ooool3o`000003ooooool0003o000001Go00003Ooo
ool2o`0000_ooooo0_l00002ooooo`;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`00
000?ooooo`Co00002Oooool2o`0004gooooo000Looooo`03o`000?oooooooooo04gooooo0_l00002
ooooo`;o000000?oooooo`000?l000009_ooool2o`0000Gooooo0_l0000=ooooo`;o00000_ooool3
o`000003ooooool0003o000001Oo00002?ooool2o`0000Wooooo0_l00008ooooo`;o00000oooool2
o`0000;ooooo0_l0000;ooooo`;o00001oooool2o`0000Kooooo0_l0001@ooooo`007?ooool00ol0
003oooooooooo`1<ooooo`;o00001_ooool2o`0002?ooooo0_l00008ooooo`;o00001Oooool2o`00
00Gooooo0ol00003oooooaco00002?ooool2o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`00
00?ooooo1Ol00002ooooo`;o00000oooool2o`0000Wooooo0_l000000ooooooo0000o`000005oooo
o`;o00001?ooool3o`0000kooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o
00001_ooool2o`0000cooooo0_l0000Eooooo`;o000000?oooooo`000?l000002oooool3o`000003
ooooool0003o000000;ooooo0_l00002oooooaco00002Oooool2o`0000?ooooo0_l00009ooooo`;o
00000_ooool3o`000003ooooool0003o000000;ooooo0_l00003ooooo`;o00002Oooool5o`0000Go
oooo0_l00004ooooo`;o00003_ooool3o`00043ooooo000Looooo`03o`000?oooooooooo04[ooooo
1?l00006ooooo`;o00002_ooool4o`0001Sooooo0_l0000;ooooo`;o00000_ooool2o`0000Kooooo
0ol00003oooooaOo00002?ooool2o`0000Gooooo0_l00002ooooo`;o00001oooool2o`0000Wooooo
1?l00009ooooo`?o00007Oooool2o`00047ooooo000Looooo`03o`000?oooooooooo04[ooooo0_l0
0003ooooo`?o00002?ooool2o`0000Cooooo0_l000000ooooooo0000o`00000Gooooo`;o00000ooo
ool2o`0001;ooooo6_l000000ooooooo0000o`00000>ooooo`?o00000_ooool2o`0000Gooooo0_l0
000;ooooo`Co00004oooool2o`0000Kooooo0_l0001?ooooo`007?ooool2o`0004cooooo0_l00002
ooooo`?o000000?oooooo`000?l000001Oooool2o`0000Kooooo0ol0000Kooooo`?o00001Oooool2
o`0000gooooo6_l0000?ooooo`;o00001_ooool6o`0000;ooooo0_l000000ooooooo0000o`000006
ooooo`;o00004oooool2o`0000Kooooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`1;oooo
o`;o00001_ooool2o`0000Kooooo0_l00005ooooo`;o00005?ooool2o`0000Kooooo0_l00006oooo
o`;o00003OoooolJo`0001Oooooo1Ol00003ooooo`;o000000?oooooo`000?l000000_ooool2o`00
00Oooooo0_l0001Wooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00001?ooool2o`0000Co
oooo0_l00002ooooo`;o00002Oooool2o`0000[ooooo0_l0000?ooooo`;o00002oooool2o`0000?o
oooo1_l00009oooooa3o000000?oooooo`000?l000000_l000001?oooooo0000o`000?ooool3o`00
00Wooooo0_l000000ooooooo0000o`00000Dooooo`;o00001oooool2o`0000?ooooo1?l0000Coooo
o`;o00000_ooool2o`0004Oooooo000Looooo`03o`000?oooooooooo043ooooo0_l00004ooooo`;o
00001?ooool2o`0000;ooooo0_l0000Eooooo`;o00007?ooool2o`0000?ooooo1_l00006ooooo`Ko
000000Goooooo`000?l0003o0000ooooo`0;o`0000Cooooo1Ol00003ooooo`?o00000oooool2o`00
0003ooooool0003o000000kooooo0_l00005ooooo`;o00000oooool2o`0000Kooooo1?l0000Coooo
o`;o00000_ooool2o`0004Oooooo000Looooo`03o`000?oooooooooo06Gooooo1?l0000]oooooaSo
00000_ooool2o`0000Kooooo0ol00008ooooo`Co00002_ooool2o`0000Gooooo0_l00003ooooo`;o
00003_ooool2o`0005[ooooo000Looooo`03o`000?oooooooooo04Wooooo0_l00007ooooo`;o0000
1?ooool2o`0000_ooooo1_l0000=ooooo`;o00001?ooool2o`0001_ooooo5ol0000?ooooo`Ko0000
9?ooool4o`00017ooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00001ooo
ool2o`0000?ooooo1Ol0000=ooooo`;o00003Oooool2o`0000;ooooo1?l00009ooooo`;o00004Ooo
ool7o`000003ooooool0003o000000Ko000000?oooooo`000?l000000_l000000ooooooo0000o`00
0003o`0000[ooooo0_l00002ooooo`?o000000?oooooo`000?l000000oooool2o`0001Sooooo0_l0
00000ooooooo0000o`000002o`0000;ooooo0_l0000=ooooo`;o0000Aoooool001cooooo00?o0000
ooooooooool0E_ooool3o`000003ooooool0003o000000?ooooo0_l0000Iooooo`So00001oooool2
o`0000kooooo0_l000000ooooooo0000o`000002o`0000?ooooo3_l000000ooooooo0000o`000004
o`0000Oooooo0_l00004ooooo`?o000000?oooooo`000?l000000oooool2o`00013ooooo0_l00006
ooooo`;o00000oooool2o`0000;ooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`1Foooo
o`;o00001oooool2o`0000Sooooo0_l0000?ooooo`;o00000_ooool4o`0001Oooooo0_l00003oooo
o`;o00000_ooool3o`0000?ooooo1_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00005
ooooo`Co00001_ooool2o`0000?ooooo0_l00006ooooo`;o00001_ooool2o`0000;ooooo0_l0000H
ooooo`;o0000COooool001cooooo00?o0000ooooooooool0B?ooool2o`0000;ooooo0_l0000Koooo
o`;o00004oooool2o`0000Gooooo1?l000000ooooooo0000o`000003ooooo`;o00001oooool2o`00
00;ooooo0_l00003ooooo`Co00000oooool2o`000004ooooool0003o0000o`0000kooooo0ol00008
ooooo`;o00000oooool2o`0000Kooooo0ol00004ooooo`?o00002?ooool2o`0001;ooooo0_l0001=
ooooo`007?ooool00ol0003oooooooooo`18ooooo`;o00000_ooool2o`0000gooooo0_l0000Qoooo
o`;o00001Oooool4o`000003ooooool0003o000000?ooooo0_l00004ooooo`;o000000?oooooo`00
0?l000000_ooool2o`0000?ooooo1_l00004ooooo`;o00003oooool2o`0000[ooooo0_l0000;oooo
o`;o00001?ooool2o`0000Wooooo0_l0001Qooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o
00002?ooool3o`0001;ooooo0_l0000Dooooo`;o00003Oooool3o`0000Gooooo0_l00002ooooo`;o
00000_ooool3o`0000Sooooo0_l0000Eooooo`Co00005oooool2o`0000;ooooo0_l00002ooooo`;o
0000G_ooool001cooooo00?o0000ooooooooool0D?ooool2o`0000Gooooo0_l000000ooooooo0000
o`000006ooooo`;o000000?oooooo`000?l000002?ooool2o`0000Sooooo0_l0000Iooooo`;o0000
1_ooool2o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0000Cooooo0_l0000Eooooo`;o0000
6Oooool2o`0000;ooooo0_l00002ooooo`;o00004Oooool2o`0004_ooooo000Looooo`03o`000?oo
oooooooo05?ooooo0_l00002ooooo`;o00002Oooool2o`000003ooooool0003o000001;ooooo0_l0
000Iooooo`;o00000_ooool4o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`Co00001?oo
ool2o`0000Kooooo0_l00009ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Kooooo1?l0
0006ooooo`;o00007?ooool2o`0004_ooooo000Looooo`03o`000?oooooooooo05?ooooo1?l00008
ooooo`;o00008?ooool2o`0000Cooooo0_l00005ooooo`;o00002?ooool4o`0000;ooooo0_l00000
0ooooooo0000o`000003ooooo`?o00001_ooool3o`0000Gooooo0_l00009ooooo`;o000000?ooooo
o`000?l000001Oooool2o`0000Kooooo1?l00006ooooo`;o00001_ooool4o`0005oooooo000Loooo
o`03o`000?oooooooooo05Gooooo0ol00002ooooo`;o000000?oooooo`000?l000000_l0000@oooo
o`;o00003?ooool6o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l000000oooool2o`00
00Oooooo0_l00005ooooo`;o00000_ooool2o`0000Cooooo0_l0000Dooooo`;o00000_ooool4o`00
01Sooooo1?l0001Oooooo`007?ooool2o`0005Kooooo0ol00002ooooo`;o000000?oooooo`000?l0
00004_ooool2o`0000cooooo1_l000000ooooooo0000o`000009ooooo`;o00000oooool2o`0000Oo
oooo0_l00009ooooo`;o00000_ooool2o`0000;ooooo0_l0000Booooo`;o00000_ooool4o`0000Ko
oooo0_l0000=ooooo`;o00005Oooool2o`0004gooooo000Looooo`03o`000?oooooooooo05Gooooo
1?l00002ooooo`;o00004Oooool2o`0000gooooo0_l00007ooooo`;o00002Oooool2o`0000;ooooo
0_l00009ooooo`;o00002oooool7o`0000[ooooo0_l0000Dooooo`?o00003?ooool3o`0001Cooooo
0_l0001=ooooo`007?ooool00ol0003oooooooooo`1Gooooo`;o00000_ooool3o`0000Oooooo0_l0
0007ooooo`;o00003Oooool2o`0000Gooooo0_l0000;ooooo`?o000000?oooooo`000?l000002Ooo
ool2o`0000_ooooo0_l000000ooooooo0000o`00000<ooooo`;o00000_ooool2o`0000Sooooo0_l0
0007ooooo`;o00002?ooool2o`000003ooooool0003o000000?o0000H_ooool001cooooo00?o0000
ooooooooool0G?ooool2o`0000Oooooo0_l00007ooooo`;o00002?ooool2o`0000Sooooo1?l0000:
ooooo`Co00001_ooool2o`0000;ooooo0_l0000Eooooo`;o00002oooool3o`0000Oooooo0_l0000?
ooooo`Co000000Coooooo`000?l0003ooooo0_l0001Rooooo`007?ooool00ol0003oooooooooo`1U
ooooo`;o00002_ooool2o`0000Gooooo0_l00002ooooo`;o00001?ooool2o`0000cooooo0_l00008
ooooo`;o00000_ooool4o`0000kooooo0_l00003ooooo`;o00002oooool3o`0000Gooooo0_l00007
ooooo`;o000000?oooooo`000?l000001Oooool4o`0006Sooooo000Looooo`03o`000?oooooooooo
05_ooooo0_l00007ooooo`?o00002_ooool2o`0000Wooooo0_l0000Dooooo`;o00000_ooool2o`00
00?ooooo0_l00003ooooo`;o00003_ooool2o`0000[ooooo0_l00004ooooo`?o00001Oooool2o`00
00Oooooo0_l000000ooooooo0000o`000005ooooo`Co0000J?ooool001cooooo00?o0000oooooooo
ool0Foooool3o`0000Kooooo0ol00008ooooo`;o00004?ooool2o`0000oooooo0_l00002ooooo`?o
00000_ooool2o`0001kooooo0ol00005ooooo`Co00005?ooool4o`0006[ooooo000Looooo`03o`00
0?oooooooooo05cooooo0_l0000=ooooo`;o00000_ooool3o`0000oooooo1?l0000<ooooo`;o0000
1?ooool4o`00023ooooo0_l00008ooooo`Co00003?ooool2o`0000Cooooo1?l0001Zooooo`007?oo
ool00ol0003oooooooooo`1Pooooo`;o00002Oooool2o`0000?ooooo0_l0000Aooooo`Co00002_oo
ool2o`0000Kooooo0_l0000:ooooo`;o00002_ooool2o`0000gooooo0_l00002ooooo`;o000000?o
ooooo`000?l000003?ooool2o`0000Kooooo0_l0001Zooooo`007?ooool00ol0003oooooooooo`1P
ooooo`;o00003_ooool2o`0000Cooooo0_l0000=ooooo`;o00007_ooool4o`0000Sooooo0_l0000=
ooooo`;o00000_ooool2o`0000[ooooo0_l0001gooooo`007?ooool00ol0003oooooooooo`1Uoooo
o`;o00002oooool2o`0000;ooooo0ol000000ooooooo0000o`000002ooooo`;o00003oooool2o`00
00_ooooo0_l00009ooooo`Co00006Oooool2o`0000;ooooo1?l00004ooooo`;o00000_ooool2o`00
01cooooo0ol0001Dooooo`007?ooool00ol0003oooooooooo`1Uooooo`?o00001_ooool2o`0000;o
oooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`0000oooooo0_l000000ooooooo
0000o`000008ooooo`Co00002Oooool2o`0001gooooo1?l00008ooooo`;o00007?ooool3o`0005Co
oooo000Looooo`03o`000?oooooooooo05Sooooo0_l00009ooooo`;o000000?oooooo`000?l00000
1_ooool2o`0000kooooo0_l00003ooooo`;o000000?oooooo`000?l000002_ooool2o`0000[ooooo
0_l00005ooooo`;o00001_ooool2o`0001[ooooo0_l0001nooooo`007?ooool00ol0003ooooooooo
o`1Hooooo`;o00000oooool2o`0000Cooooo0_l000000ooooooo0000o`000002o`0000Gooooo0_l0
000Booooo`;o000000?oooooo`000?l000000oooool2o`0000Gooooo0ol0000@ooooo`;o00001_oo
ool2o`0001;ooooo0_l00002ooooo`;o00000_ooool3o`0000Kooooo0_l0001eooooo`0000Kooooo
onk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Ko
oooo00?o0000ooooooooool0GOooool2o`0000Kooooo1Ol00005ooooo`Co00006?ooool2o`0000?o
oooo1Ol0000=ooooo`;o00003?ooool2o`0000_ooooo0_l00002ooooo`;o00000_ooool2o`0000?o
oooo0_l00006ooooo`;o000000?oooooo`000?l000000_l0001`ooooo`0000KoooooogMgMonHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000
ooooooooool0IOooool4o`0000Kooooo1?l0000:ooooo`;o00004Oooool2o`00013ooooo0_l0000<
ooooo`;o00002oooool2o`0001Kooooo1?l0001`ooooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`1_
ooooo`;o00003?ooool2o`0000;ooooo0_l00007ooooo`;o00009_ooool2o`0000[ooooo1?l0000>
ooooo`?o0000M_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Olb
<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0001/ooooo`;o000000?oooooo`000?l000001oooool2
o`0000Kooooo1Ol00005ooooo`;o00000oooool2o`0000Wooooo0_l0000Fooooo`;o00002_ooool4
o`0000_ooooo0_l000001?oooooo0000o`000?l0001fooooo`0000?oooooo`000?ooool00_ooool0
0ol0003oooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003ooooooooo
o`1Tooooo`;o00001_ooool2o`000003ooooool0003o000000Oooooo0_l00006ooooo`;o000000?o
ooooo`000?l000002_ooool2o`0000?ooooo0_l00004ooooo`;o00000oooool4o`0000Cooooo0ol0
000@ooooo`;o00000oooool2o`0000Cooooo0_l00006ooooo`?o0000NOooool00003ooooool@413o
oooo00;ooooo00?o410@ooooooooool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o
0000ooooooooool0I?ooool2o`0000Cooooo0ol00008ooooo`;o00001Oooool2o`00013ooooo1?l0
0002ooooo`;o00002Oooool5o`0000?ooooo0ol0000=ooooo`Go00002Oooool2o`0000Oooooo0_l0
001iooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l0
00001_ooool00ol0003oooooooooo`1Zooooo`Co00001oooool4o`0000?ooooo0_l00002ooooo`;o
00003?ooool4o`0000Gooooo0_l00006ooooo`;o000000?oooooo`000?l000001?ooool2o`0000go
oooo1?l00005ooooo`;o0000Qoooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnY
ZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0K?ooool2o`0000Gooooo0_l00002
ooooo`?o000000?oooooo`000?l000000oooool2o`0000?ooooo0_l00009ooooo`;o00001Oooool2
o`0000Oooooo0_l00006ooooo`;o00002?ooool3o`0000_ooooo0_l00027ooooo`007?ooool00ol0
003oooooooooo`1]ooooo`;o00001?ooool2o`0000?ooooo0_l000000ooooooo0000o`000004o`00
00Cooooo0_l0000>ooooo`;o00002Oooool2o`0000kooooo1Ol0002Dooooo`007?ooool00ol0003o
ooooooooo`1]ooooo`;o00003Oooool5o`0000?ooooo0_l00004ooooo`;o00001oooool4o`0000Co
oooo0ol00005ooooo`;o00001_ooool2o`0000?ooooo0ol00007ooooo`;o0000SOooool001cooooo
00?o0000ooooooooool0Loooool2o`000003ooooool0003o000000cooooo0_l00004ooooo`;o0000
1oooool3o`0000Gooooo0ol00005ooooo`;o00001_ooool2o`0000?ooooo0_l00008ooooo`;o0000
SOooool001cooooo00?o0000ooooooooool0L?ooool2o`000004ooooool0003o0000ooooo`;o0000
1_ooool2o`0000Kooooo0_l0000Dooooo`;o00001?ooool2o`0000cooooo0_l00008ooooo`;o0000
0_ooool2o`0008Wooooo000Looooo`03o`000?oooooooooo073ooooo0_l0000<ooooo`;o00000ooo
ool2o`000003ooooool0003o000000;ooooo0_l00006ooooo`;o00002Oooool2o`0000?ooooo0_l0
000=ooooo`;o00001oooool2o`0000;ooooo0_l00029ooooo`007?ooool00ol0003oooooooooo`23
ooooo`;o000000?oooooo`000?l000000_ooool3o`0000Gooooo0_l00009ooooo`;o00001?ooool2
o`0000cooooo0_l0002Fooooo`007?ooool00ol0003oooooooooo`2;ooooo`;o00003?ooool2o`00
00Cooooo1_l00004ooooo`;o00001Oooool2o`0009Oooooo000Looooo`03o`000?oooooooooo08Wo
oooo0_l0000>ooooo`?o00000oooool4o`0000Kooooo0_l00005ooooo`;o0000;?ooool2o`0006Wo
oooo000Looooo`03o`000?oooooooooo07Gooooo0_l0000Booooo`;o000000Coooooo`000?l0003o
00002Oooool4o`0004;ooooo0_l0001Yooooo`007?ooool00ol0003oooooooooo`1eooooo`;o0000
4_ooool7o`0000;ooooo2_l00009ooooo`Co0000X?ooool001cooooo00?o0000ooooooooool0R_oo
ool2o`000004ooooool0003o0000o`0000;ooooo1_l00008ooooo`;o00000oooool4o`000:3ooooo
000Looooo`;o0000O?ooool2o`0001cooooo0_l000000ooooooo0000o`000002ooooo`;o0000Yooo
ool001cooooo00?o0000ooooooooool0MOooool2o`0000Cooooo0_l0000Booooo`?o00001oooool2
o`000003ooooool0003o00000:_ooooo000Looooo`03o`000?oooooooooo07Gooooo0_l0000Hoooo
o`?o00000_ooool5o`000;3ooooo000Looooo`03o`000?oooooooooo09Cooooo1Ol0002`ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo093ooooo0_l0
0010ooooo`;o0000MOooool001cooooo00?o0000ooooooooool0T?ooool2o`0000;ooooo0_l0000l
ooooo`;o0000MOooool001cooooo00?o0000ooooooooool0U?ooool2o`000;?ooooo000Looooo`03
o`000?oooooooooo093ooooo0_l0000>ooooo`;o00006_ooool2o`0008_ooooo000Looooo`03o`00
0?oooooooooo093ooooo0_l0000>ooooo`;o00006_ooool2o`0008_ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0;_ooooo0_l0002<ooooo`007?ooool00ol0003oooooooooo`2kooooo`;o0000
S?ooool001cooooo00?o0000ooooooooool0U_ooool2o`000;7ooooo000Looooo`03o`000?oooooo
oooo09Kooooo0_l0000Aooooo`;o0000W_ooool001cooooo00?o0000ooooooooool0ZOooool2o`00
09kooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Booooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3o
oooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom:oooo
o`005?ooool00ol0003oooooooooo`05ooooo`?o0000oooooom:ooooo`005?ooool00ol0003ooooo
ooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000
ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Booooo`03
oeEEEOmVIVKo00000?ooooooE?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0:7ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0Fooooo`Co000000So410@
ooooooooooook^k^oc8b<_l0003o<S8bonk^kPCooooo00GoA4A4o`000?l0003o<S8bomgMg@02oooo
o`05onk^k_lb<S;o0000oa0@4?o<c<`0S?ooool00:;ooooo00Go0000ooooooooooooooooo`000009
ooooo`Ko00003?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01ooo
ool02OmgMgOo<S8booooooooooooEEEEogMgMoooooooV9RHob4Q8@2<ooooo`00X_ooool01Ol0003o
oooooooooooooooo000001_ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@00Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`2:ooooo`00X_ooool0
1Ol0003ooooooooooooooooo000000Wooooo1_l0000<ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000007ooooo`09ogMgMolb<S;oooooooooool0003oV9RHoooooonHV9So
8B4Q08cooooo002Rooooo`05o`000?n7QhOoooooojVYZOl000006oooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo
00Go0000oeEEEOl0003o410@olc<c02<ooooo`00XOooool00ol@413o0000ogMgM`02o`000003oiRH
V?oooooooooo01Wooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Co
oooo00?o0000ooooooooool01?ooool00omEEEGoQhN7ooooo`2>ooooo`00`_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`04ooooo`03
omgMgOl@413oV9RH08kooooo0030ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP04ooooo`Co00001?ooool01?o<c<coA4A4o`000?l@412<ooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1062) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.46246 .64122 Mdot
.47686 .68061 Mdot
.62336 .36354 Mdot
.38808 .46772 Mdot
.55593 .77943 Mdot
.60436 .3886 Mdot
.65201 .58612 Mdot
.64637 .53386 Mdot
.60528 .37019 Mdot
.55494 .61962 Mdot
.66396 .57869 Mdot
.34957 .42133 Mdot
.66372 .5606 Mdot
.39911 .48431 Mdot
.3324 .81043 Mdot
.38743 .55973 Mdot
.50332 .70886 Mdot
.43354 .28887 Mdot
.4398 .50433 Mdot
.58288 .39993 Mdot
.44405 .66606 Mdot
.38908 .4773 Mdot
.47976 .63665 Mdot
.39897 .4849 Mdot
.39645 .45646 Mdot
.49716 .69574 Mdot
.47378 .72493 Mdot
.35288 .46371 Mdot
.41831 .46787 Mdot
.63521 .5418 Mdot
.29279 .35893 Mdot
.40813 .83542 Mdot
.44933 .48662 Mdot
.79291 .57653 Mdot
.65588 .53361 Mdot
.38464 .75517 Mdot
.57903 .3765 Mdot
.64407 .54506 Mdot
.66075 .53639 Mdot
.6249 .57634 Mdot
.65843 .54342 Mdot
.49027 .69393 Mdot
.71166 .56529 Mdot
.59642 .60684 Mdot
.42482 .52734 Mdot
.61053 .71992 Mdot
.23344 .46831 Mdot
.36292 .51832 Mdot
.50048 .70811 Mdot
.55423 .40383 Mdot
.76327 .59766 Mdot
.65118 .58895 Mdot
.66315 .37174 Mdot
.83363 .68231 Mdot
.63727 .55244 Mdot
.43114 .51141 Mdot
.59298 .36257 Mdot
.3815 .48336 Mdot
.39578 .4883 Mdot
.24862 .63235 Mdot
.34671 .46333 Mdot
.44206 .33656 Mdot
.50001 .62961 Mdot
.49402 .38033 Mdot
.59191 .37268 Mdot
.66774 .54194 Mdot
.46714 .6853 Mdot
.65712 .56169 Mdot
.37469 .4211 Mdot
.56984 .35397 Mdot
.36178 .51625 Mdot
.67236 .55156 Mdot
.46586 .70764 Mdot
.35917 .50039 Mdot
.71102 .315 Mdot
.16878 .60268 Mdot
.42142 .35143 Mdot
.3093 .69355 Mdot
.26724 .67335 Mdot
.54113 .28011 Mdot
.41851 .49961 Mdot
.34936 .24673 Mdot
.25189 .72189 Mdot
.49139 .63961 Mdot
.44198 .54164 Mdot
.5958 .46859 Mdot
.36132 .49577 Mdot
.56714 .70458 Mdot
.42691 .50975 Mdot
.78283 .36941 Mdot
.61228 .374 Mdot
.49069 .66199 Mdot
.39133 .46844 Mdot
.36727 .44831 Mdot
.26289 .52381 Mdot
.33276 .50432 Mdot
.35934 .46471 Mdot
.45152 .68676 Mdot
.67284 .57835 Mdot
.30853 .4993 Mdot
.70373 .54341 Mdot
.6541 .3691 Mdot
.36767 .53428 Mdot
.56744 .36953 Mdot
.45695 .70153 Mdot
.35222 .50031 Mdot
.68122 .54453 Mdot
.38728 .53178 Mdot
.73759 .59134 Mdot
.47382 .6799 Mdot
.37463 .44624 Mdot
.43325 .3427 Mdot
.58562 .20136 Mdot
.48886 .65608 Mdot
.5637 .2646 Mdot
.41971 .51079 Mdot
.36231 .47255 Mdot
.47936 .68066 Mdot
.64001 .36356 Mdot
.55589 .71006 Mdot
.50923 .64429 Mdot
.62183 .57525 Mdot
.50363 .63527 Mdot
.45337 .48534 Mdot
.60562 .37892 Mdot
.71271 .50418 Mdot
.63603 .47937 Mdot
.29292 .33328 Mdot
.36449 .49224 Mdot
.64462 .65363 Mdot
.62335 .40038 Mdot
.49175 .67299 Mdot
.65628 .56564 Mdot
.3626 .56996 Mdot
.46978 .65741 Mdot
.64493 .57472 Mdot
.42009 .32454 Mdot
.72748 .45212 Mdot
.51683 .6843 Mdot
.63815 .62313 Mdot
.69676 .56569 Mdot
.63591 .58625 Mdot
.80985 .54871 Mdot
.47427 .69047 Mdot
.44118 .3089 Mdot
.64175 .56499 Mdot
.27002 .40504 Mdot
.43101 .46477 Mdot
.36072 .27709 Mdot
.3106 .23729 Mdot
.79341 .56215 Mdot
.74501 .41404 Mdot
.46658 .30931 Mdot
.65398 .59331 Mdot
.39754 .44733 Mdot
.49048 .70588 Mdot
.48419 .70034 Mdot
.33966 .4915 Mdot
.38928 .46159 Mdot
.35823 .51087 Mdot
.38796 .4421 Mdot
.22232 .62672 Mdot
.39165 .5367 Mdot
.24233 .32881 Mdot
.49465 .65809 Mdot
.37975 .45494 Mdot
.60546 .35406 Mdot
.38746 .42838 Mdot
.66374 .54414 Mdot
.37952 .47619 Mdot
.38442 .46536 Mdot
.35221 .45522 Mdot
.65526 .58885 Mdot
.39628 .81706 Mdot
.37681 .20578 Mdot
.4767 .80863 Mdot
.65299 .29624 Mdot
.60596 .39976 Mdot
.35881 .48736 Mdot
.45095 .3279 Mdot
.38779 .73486 Mdot
.41302 .50105 Mdot
.66457 .18927 Mdot
.36711 .46471 Mdot
.51918 .78281 Mdot
.46229 .50927 Mdot
.49715 .81631 Mdot
.34849 .26368 Mdot
.40491 .44609 Mdot
.28548 .52771 Mdot
.43048 .70937 Mdot
.62406 .61497 Mdot
.65831 .54542 Mdot
.61324 .35482 Mdot
.60786 .36191 Mdot
.60899 .53386 Mdot
.4904 .60688 Mdot
.38231 .58134 Mdot
.32634 .46856 Mdot
.62875 .34885 Mdot
.49347 .62306 Mdot
.44467 .29533 Mdot
.45306 .67773 Mdot
.128 .48367 Mdot
.75562 .57843 Mdot
.62381 .5131 Mdot
.42221 .34467 Mdot
.63545 .37468 Mdot
.65492 .36632 Mdot
.45572 .32232 Mdot
.38499 .52157 Mdot
.46976 .69064 Mdot
.77942 .65468 Mdot
.47983 .59696 Mdot
.80965 .61149 Mdot
.47188 .70836 Mdot
.56881 .61214 Mdot
.65334 .57559 Mdot
.57992 .38547 Mdot
.36013 .47104 Mdot
.3814 .5103 Mdot
.44192 .6707 Mdot
.3623 .51331 Mdot
.39997 .59913 Mdot
.35191 .47366 Mdot
.75169 .53645 Mdot
.42185 .35341 Mdot
.60898 .53431 Mdot
.28546 .33059 Mdot
.46333 .65143 Mdot
.42854 .25126 Mdot
.58332 .3527 Mdot
.36661 .7328 Mdot
.67528 .55651 Mdot
.4273 .33628 Mdot
.58591 .35067 Mdot
.44837 .29441 Mdot
.41199 .43614 Mdot
.64243 .40129 Mdot
.44328 .34506 Mdot
.3165 .74983 Mdot
.42545 .45694 Mdot
.21506 .6214 Mdot
.66855 .58765 Mdot
.51326 .64939 Mdot
.34699 .46366 Mdot
.58336 .39391 Mdot
.45046 .49762 Mdot
.7252 .37203 Mdot
.71562 .50682 Mdot
.6525 .39934 Mdot
.53887 .33449 Mdot
.42772 .33099 Mdot
.69906 .37332 Mdot
.65952 .64078 Mdot
.493 .71208 Mdot
.37404 .54007 Mdot
.47066 .83429 Mdot
.64231 .56512 Mdot
.39196 .5237 Mdot
.74681 .51519 Mdot
.64288 .5618 Mdot
.37996 .48474 Mdot
.68798 .57108 Mdot
.48138 .70068 Mdot
.48298 .20527 Mdot
.50156 .71006 Mdot
.4255 .50951 Mdot
.68537 .55135 Mdot
.65161 .38235 Mdot
.50181 .69383 Mdot
.38037 .52902 Mdot
.3484 .48642 Mdot
.55942 .46415 Mdot
.37698 .45188 Mdot
.4371 .81391 Mdot
.36609 .45224 Mdot
.60519 .35747 Mdot
.33248 .49711 Mdot
.76934 .30656 Mdot
.65734 .45983 Mdot
.46742 .68641 Mdot
.64214 .40715 Mdot
.60483 .36725 Mdot
.5195 .2337 Mdot
.66488 .35742 Mdot
.41507 .51578 Mdot
.59585 .39989 Mdot
.4003 .26735 Mdot
.62885 .55945 Mdot
.3552 .53212 Mdot
.58 .60241 Mdot
.54798 .40001 Mdot
.64026 .35352 Mdot
.39131 .56855 Mdot
.47143 .71883 Mdot
.39122 .46748 Mdot
.64168 .3583 Mdot
.47504 .61977 Mdot
.41654 .52636 Mdot
.47562 .54635 Mdot
.55922 .4648 Mdot
.64175 .57905 Mdot
.45133 .54189 Mdot
.37418 .53283 Mdot
.57208 .37363 Mdot
.4575 .67333 Mdot
.64036 .53357 Mdot
.49778 .68737 Mdot
.63893 .77292 Mdot
.73551 .57647 Mdot
.26698 .69544 Mdot
.4733 .29867 Mdot
.76421 .39771 Mdot
.5313 .82085 Mdot
.6746 .27292 Mdot
.36369 .34901 Mdot
.69363 .75638 Mdot
.62325 .35324 Mdot
.75906 .51287 Mdot
.60335 .36484 Mdot
.41165 .47023 Mdot
.59907 .37957 Mdot
.52215 .8243 Mdot
.35314 .47092 Mdot
.59268 .382 Mdot
.48961 .22047 Mdot
.38167 .45939 Mdot
.48654 .65366 Mdot
.3155 .78906 Mdot
.69782 .27079 Mdot
.77548 .56284 Mdot
.63546 .40082 Mdot
.33357 .38804 Mdot
.36042 .46101 Mdot
.33456 .46815 Mdot
.50869 .69301 Mdot
.33635 .51435 Mdot
.44909 .29609 Mdot
.41856 .33949 Mdot
.49875 .44663 Mdot
.39302 .21516 Mdot
.31898 .46755 Mdot
.50373 .69398 Mdot
.22172 .57322 Mdot
.7233 .3237 Mdot
.66463 .3107 Mdot
.6518 .59857 Mdot
.37305 .80271 Mdot
.44118 .59399 Mdot
.71603 .54916 Mdot
.58803 .59709 Mdot
.48143 .66576 Mdot
.41207 .8224 Mdot
.65366 .54616 Mdot
.31637 .59544 Mdot
.27849 .45905 Mdot
.38583 .51602 Mdot
.67345 .56869 Mdot
.34381 .42939 Mdot
.74858 .30346 Mdot
.2174 .46776 Mdot
.27454 .29875 Mdot
.41841 .53019 Mdot
.69591 .30725 Mdot
.3718 .47252 Mdot
.5404 .73243 Mdot
.36334 .45364 Mdot
.502 .68157 Mdot
.55438 .64888 Mdot
.52334 .44909 Mdot
.33075 .23424 Mdot
.75146 .58342 Mdot
.46613 .30837 Mdot
.35485 .4765 Mdot
.38661 .51523 Mdot
.43019 .30784 Mdot
.49415 .64568 Mdot
.3911 .44165 Mdot
.39812 .28781 Mdot
.36618 .50586 Mdot
.65306 .54124 Mdot
.2522 .34378 Mdot
.46593 .72805 Mdot
.32898 .51082 Mdot
.4753 .62426 Mdot
.638 .57704 Mdot
.65403 .5352 Mdot
.36323 .5578 Mdot
.61693 .55131 Mdot
.37468 .46625 Mdot
.20657 .42295 Mdot
.50867 .65769 Mdot
.43884 .57386 Mdot
.47659 .64066 Mdot
.30981 .70092 Mdot
.67966 .54042 Mdot
.7373 .53093 Mdot
.30511 .49743 Mdot
.65737 .54854 Mdot
.73016 .60755 Mdot
.31601 .48375 Mdot
.39249 .55359 Mdot
.79919 .40687 Mdot
.64316 .39427 Mdot
.53917 .45239 Mdot
.66677 .53316 Mdot
.37021 .52984 Mdot
.35147 .5337 Mdot
.63826 .57962 Mdot
.27356 .57515 Mdot
.57893 .23376 Mdot
.35492 .46411 Mdot
.50452 .67108 Mdot
.49275 .67521 Mdot
.40879 .54302 Mdot
.3947 .52833 Mdot
.62931 .38408 Mdot
.63625 .40918 Mdot
.60357 .41233 Mdot
.55752 .46404 Mdot
.74369 .53337 Mdot
.64569 .72762 Mdot
.62548 .57681 Mdot
.66855 .66681 Mdot
.76582 .34643 Mdot
.42668 .43675 Mdot
.6137 .40619 Mdot
.39257 .5084 Mdot
.38793 .4705 Mdot
.63841 .53404 Mdot
.76794 .54113 Mdot
.42004 .40925 Mdot
.51347 .6619 Mdot
.66207 .53078 Mdot
.31453 .5379 Mdot
.70074 .68115 Mdot
.4428 .34155 Mdot
.80741 .50796 Mdot
.67302 .54971 Mdot
.48035 .66095 Mdot
.6895 .55307 Mdot
.3786 .51112 Mdot
.43488 .509 Mdot
.48307 .67387 Mdot
.44644 .3486 Mdot
.36074 .44177 Mdot
.37692 .48283 Mdot
.46979 .14797 Mdot
.70416 .30328 Mdot
.70413 .50751 Mdot
.39574 .44436 Mdot
.35246 .53773 Mdot
.44284 .28985 Mdot
.37068 .50828 Mdot
.34434 .49554 Mdot
.52617 .18389 Mdot
.65988 .49636 Mdot
.41886 .29901 Mdot
.3239 .6034 Mdot
.47638 .71156 Mdot
.44519 .83922 Mdot
.58246 .38905 Mdot
.61636 .53358 Mdot
.5873 .22637 Mdot
.66073 .37568 Mdot
.73586 .37207 Mdot
.43382 .83883 Mdot
.54445 .45728 Mdot
.40611 .30332 Mdot
.39741 .40522 Mdot
.34556 .4738 Mdot
.36793 .47423 Mdot
.44882 .32183 Mdot
.47554 .69488 Mdot
.50908 .42536 Mdot
.18819 .55545 Mdot
.38134 .47363 Mdot
.39444 .59598 Mdot
.3249 .76489 Mdot
.53349 .38863 Mdot
.45496 .30057 Mdot
.43952 .35108 Mdot
.3579 .47592 Mdot
.54334 .19502 Mdot
.49748 .69675 Mdot
.3813 .52918 Mdot
.40588 .53103 Mdot
.63819 .40057 Mdot
.47113 .67449 Mdot
.62292 .35246 Mdot
.73504 .53286 Mdot
.50683 .79139 Mdot
.48452 .13993 Mdot
.66602 .53561 Mdot
.42109 .79093 Mdot
.6301 .55079 Mdot
.3363 .25986 Mdot
.6628 .37465 Mdot
.41563 .50444 Mdot
.45847 .66538 Mdot
.38273 .53133 Mdot
.40129 .5173 Mdot
.38613 .52108 Mdot
.34849 .44011 Mdot
.69552 .21891 Mdot
.45788 .33095 Mdot
.32913 .51789 Mdot
.61387 .36001 Mdot
.42279 .79812 Mdot
.19676 .64142 Mdot
.38547 .50591 Mdot
.35096 .4863 Mdot
.48156 .65055 Mdot
.33791 .49793 Mdot
.62998 .5589 Mdot
.45697 .67654 Mdot
.37283 .44611 Mdot
.39397 .8022 Mdot
.41732 .46013 Mdot
.49265 .80942 Mdot
.68935 .55013 Mdot
.71559 .61541 Mdot
.32023 .50093 Mdot
.70693 .50167 Mdot
.53899 .45223 Mdot
.5925 .40141 Mdot
.64568 .52297 Mdot
.58049 .37558 Mdot
.19099 .48821 Mdot
.44396 .48805 Mdot
.39777 .44939 Mdot
.35513 .53514 Mdot
.60121 .40003 Mdot
.56418 .72902 Mdot
.69743 .40705 Mdot
.33315 .55884 Mdot
.62195 .39175 Mdot
.49026 .62476 Mdot
.5097 .3721 Mdot
.46357 .65534 Mdot
.41217 .31885 Mdot
.66477 .5766 Mdot
.46321 .33279 Mdot
.78322 .56772 Mdot
.47567 .67902 Mdot
.44106 .68151 Mdot
.60222 .39568 Mdot
.59351 .5112 Mdot
.78092 .72759 Mdot
.52938 .41429 Mdot
.335 .30662 Mdot
.51049 .68537 Mdot
.42554 .49513 Mdot
.30252 .28873 Mdot
.58282 .53048 Mdot
.58215 .37351 Mdot
.41274 .48932 Mdot
.51257 .19986 Mdot
.62943 .38518 Mdot
.36004 .53504 Mdot
.64241 .37305 Mdot
.66963 .55299 Mdot
.63282 .39614 Mdot
.50821 .71167 Mdot
.353 .49724 Mdot
.76037 .74719 Mdot
.46302 .26943 Mdot
.37043 .45131 Mdot
.66681 .53201 Mdot
.49077 .50741 Mdot
.4018 .50616 Mdot
.42362 .30627 Mdot
.60827 .38294 Mdot
.5501 .43324 Mdot
.35637 .46117 Mdot
.6089 .39845 Mdot
.46607 .63979 Mdot
.64499 .52253 Mdot
.46228 .39203 Mdot
.72777 .51464 Mdot
.5063 .69766 Mdot
.71286 .58973 Mdot
.63773 .52908 Mdot
.34336 .52971 Mdot
.39161 .53822 Mdot
.50054 .66983 Mdot
.44135 .2195 Mdot
.33278 .48695 Mdot
.4184 .49947 Mdot
.61569 .35879 Mdot
.58533 .38213 Mdot
.45062 .2198 Mdot
.64268 .3665 Mdot
.43753 .49992 Mdot
.50056 .67219 Mdot
.39981 .47185 Mdot
.47872 .65469 Mdot
.34181 .50918 Mdot
.48929 .61428 Mdot
.50098 .64707 Mdot
.68794 .38172 Mdot
.40723 .47891 Mdot
.45768 .53227 Mdot
.39405 .52076 Mdot
.36169 .50911 Mdot
.6278 .37992 Mdot
.45645 .30774 Mdot
.35649 .56255 Mdot
.4131 .29935 Mdot
.43568 .29864 Mdot
.43663 .72063 Mdot
.63901 .39878 Mdot
.43883 .31887 Mdot
.23762 .67149 Mdot
.61601 .41171 Mdot
.44596 .33159 Mdot
.21865 .67046 Mdot
.6617 .53411 Mdot
.50213 .7126 Mdot
.38304 .45934 Mdot
.6968 .74908 Mdot
.224 .41545 Mdot
.65964 .38063 Mdot
.36906 .45086 Mdot
.3955 .50695 Mdot
.50094 .63901 Mdot
.19225 .36188 Mdot
.56013 .37205 Mdot
.40891 .46281 Mdot
.46634 .68096 Mdot
.21524 .31289 Mdot
.59766 .35782 Mdot
.44743 .32854 Mdot
.65568 .58955 Mdot
.52958 .68728 Mdot
.63464 .47857 Mdot
.64439 .58497 Mdot
.6593 .43051 Mdot
.76524 .58026 Mdot
.41937 .51178 Mdot
.6125 .40585 Mdot
.81922 .50587 Mdot
.46079 .59892 Mdot
.67211 .60625 Mdot
.32835 .39786 Mdot
.48303 .66342 Mdot
.63116 .56003 Mdot
.46671 .32225 Mdot
.46593 .70449 Mdot
.50108 .65346 Mdot
.63034 .53876 Mdot
.47575 .42657 Mdot
.56911 .59459 Mdot
.65242 .53836 Mdot
.7837 .38201 Mdot
.69102 .72945 Mdot
.60661 .40742 Mdot
.43688 .29984 Mdot
.7694 .64773 Mdot
.49119 .69371 Mdot
.37617 .80369 Mdot
.81684 .48819 Mdot
.35954 .46453 Mdot
.43533 .31629 Mdot
.58748 .74086 Mdot
.1875 .52806 Mdot
.64164 .56014 Mdot
.53986 .46678 Mdot
.46486 .34519 Mdot
.34284 .47242 Mdot
.27621 .43599 Mdot
.41457 .481 Mdot
.65724 .5785 Mdot
.24888 .64689 Mdot
.47989 .66013 Mdot
.64942 .52844 Mdot
.80663 .51061 Mdot
.37772 .46865 Mdot
.41149 .48406 Mdot
.27363 .35488 Mdot
.47837 .70493 Mdot
.58719 .39891 Mdot
.41793 .5128 Mdot
.378 .47982 Mdot
.40916 .55561 Mdot
.43576 .57112 Mdot
.57716 .1998 Mdot
.40947 .46602 Mdot
.74645 .5529 Mdot
.32842 .5114 Mdot
.40573 .48126 Mdot
.47711 .6231 Mdot
.53893 .14552 Mdot
.738 .53652 Mdot
.37821 .47677 Mdot
.42474 .4867 Mdot
.62909 .53854 Mdot
.55023 .57197 Mdot
.59395 .51513 Mdot
.58327 .46821 Mdot
.35177 .36451 Mdot
.35205 .43689 Mdot
.46203 .66945 Mdot
.43408 .34514 Mdot
.40084 .54362 Mdot
.46285 .66961 Mdot
.40146 .43727 Mdot
.62846 .38875 Mdot
.61872 .41179 Mdot
.65735 .62892 Mdot
.44099 .32575 Mdot
.24657 .38974 Mdot
.65832 .67645 Mdot
.62009 .35738 Mdot
.39611 .45194 Mdot
.62531 .52313 Mdot
.64411 .35922 Mdot
.60741 .47348 Mdot
.41421 .56838 Mdot
.49073 .70252 Mdot
.49086 .65942 Mdot
.36273 .27562 Mdot
.73732 .43684 Mdot
.46922 .1629 Mdot
.67131 .55678 Mdot
.35079 .45333 Mdot
.64507 .64514 Mdot
.48973 .6577 Mdot
.31641 .28394 Mdot
.43738 .32061 Mdot
.63995 .56058 Mdot
.6657 .31354 Mdot
.47275 .65562 Mdot
.51092 .69867 Mdot
.42862 .48804 Mdot
.37868 .49336 Mdot
.36748 .33974 Mdot
.41742 .37382 Mdot
.63451 .57305 Mdot
.43165 .30487 Mdot
.59107 .3494 Mdot
.41409 .46963 Mdot
.48526 .63683 Mdot
.74989 .67545 Mdot
.42452 .49554 Mdot
.63088 .38089 Mdot
.48536 .66556 Mdot
.42639 .31432 Mdot
.43116 .29984 Mdot
.36273 .50846 Mdot
.22898 .57685 Mdot
.64438 .55102 Mdot
.48627 .65476 Mdot
.73363 .64467 Mdot
.33137 .49447 Mdot
.37365 .49018 Mdot
.45337 .46097 Mdot
.62773 .54571 Mdot
.68083 .62865 Mdot
.45563 .34802 Mdot
.48208 .6921 Mdot
.41084 .45133 Mdot
.44031 .33421 Mdot
.6677 .63487 Mdot
.65506 .39292 Mdot
.6372 .39038 Mdot
.42533 .30424 Mdot
.43386 .30899 Mdot
.42218 .31229 Mdot
.36598 .80295 Mdot
.51478 .70675 Mdot
.45446 .56716 Mdot
.33375 .47693 Mdot
.35057 .27705 Mdot
.33883 .55677 Mdot
.68716 .54085 Mdot
.64482 .38978 Mdot
.39805 .51712 Mdot
.42432 .51215 Mdot
.45979 .51033 Mdot
.45535 .55191 Mdot
.46381 .72416 Mdot
.47281 .67806 Mdot
.43986 .46175 Mdot
.64468 .39676 Mdot
.13382 .45495 Mdot
.6204 .82049 Mdot
.32099 .50963 Mdot
.56942 .5595 Mdot
.48536 .63786 Mdot
.62074 .55507 Mdot
.60167 .48864 Mdot
.68844 .56094 Mdot
.48559 .68662 Mdot
.41284 .46887 Mdot
.6728 .67165 Mdot
.43087 .29642 Mdot
.36265 .52163 Mdot
.64735 .5721 Mdot
.35957 .51635 Mdot
.64583 .58563 Mdot
.6105 .77496 Mdot
.75684 .32941 Mdot
.36588 .46475 Mdot
.34381 .53381 Mdot
.344 .38883 Mdot
.38686 .50458 Mdot
.50015 .32806 Mdot
.4861 .63959 Mdot
.42279 .19004 Mdot
.42824 .47091 Mdot
.3523 .67896 Mdot
.33028 .49017 Mdot
.51727 .20524 Mdot
.37499 .49538 Mdot
.53164 .38073 Mdot
.34935 .46845 Mdot
.34732 .49898 Mdot
.68705 .55536 Mdot
.6306 .5378 Mdot
.44768 .66876 Mdot
.58475 .39553 Mdot
.47356 .81477 Mdot
.37514 .48479 Mdot
.72766 .51336 Mdot
.72415 .54384 Mdot
.43566 .30555 Mdot
.487 .68831 Mdot
.19765 .33088 Mdot
.67603 .58674 Mdot
.6308 .2698 Mdot
.44008 .23264 Mdot
.64337 .48022 Mdot
.59606 .4736 Mdot
.5552 .69369 Mdot
.43021 .33446 Mdot
.34198 .47191 Mdot
.78012 .59745 Mdot
.7095 .32237 Mdot
.38676 .57949 Mdot
.65073 .52663 Mdot
.37253 .72483 Mdot
.76162 .65729 Mdot
.45403 .3543 Mdot
.46224 .33695 Mdot
.65448 .58768 Mdot
.55603 .40135 Mdot
.37709 .41527 Mdot
.43572 .32305 Mdot
.63398 .36222 Mdot
.60748 .40951 Mdot
.65874 .32398 Mdot
.49247 .69791 Mdot
.79709 .53032 Mdot
.6201 .70285 Mdot
.64493 .58403 Mdot
.44487 .25874 Mdot
.52108 .70523 Mdot
.48955 .72428 Mdot
.58901 .39052 Mdot
.62901 .37699 Mdot
.49195 .71956 Mdot
.43474 .47964 Mdot
.45892 .46559 Mdot
.37855 .47392 Mdot
.45091 .3165 Mdot
.37871 .50151 Mdot
.62404 .38554 Mdot
.64755 .56073 Mdot
.62438 .37234 Mdot
.68392 .5795 Mdot
.65864 .71544 Mdot
.37657 .52463 Mdot
.34986 .49369 Mdot
.22228 .4132 Mdot
.45979 .64177 Mdot
.75063 .60822 Mdot
.75469 .53199 Mdot
.60553 .36356 Mdot
.34351 .49443 Mdot
.46564 .64484 Mdot
.43254 .35501 Mdot
.22108 .41152 Mdot
.37773 .53704 Mdot
.48239 .63852 Mdot
.40607 .45501 Mdot
.27006 .70936 Mdot
.67902 .24341 Mdot
.49705 .68321 Mdot
.30069 .24804 Mdot
.41738 .46855 Mdot
.54966 .66713 Mdot
.37345 .5432 Mdot
.3802 .28964 Mdot
.33276 .48958 Mdot
.47208 .7087 Mdot
.38414 .47839 Mdot
.46141 .69567 Mdot
.59707 .35549 Mdot
.62282 .57151 Mdot
.51296 .67953 Mdot
.39767 .53792 Mdot
.47916 .8775 Mdot
.66281 .57502 Mdot
.35771 .47337 Mdot
.67554 .57912 Mdot
.46461 .68703 Mdot
.5072 .70142 Mdot
.17935 .55659 Mdot
.68162 .49849 Mdot
.66855 .55201 Mdot
.40522 .46153 Mdot
.59114 .68249 Mdot
.40499 .47208 Mdot
.3543 .33009 Mdot
.42405 .53459 Mdot
.33231 .49499 Mdot
.16723 .59764 Mdot
.62779 .56098 Mdot
.48768 .16841 Mdot
.18801 .57465 Mdot
.35318 .79512 Mdot
.5289 .66168 Mdot
.45085 .35439 Mdot
.40752 .8201 Mdot
.73326 .52787 Mdot
.61713 .39612 Mdot
.39613 .51807 Mdot
.48714 .73679 Mdot
.64125 .54599 Mdot
.45704 .31053 Mdot
.36503 .46518 Mdot
.63077 .37642 Mdot
.5915 .24498 Mdot
.65121 .59395 Mdot
.48955 .69356 Mdot
.51088 .65575 Mdot
.26234 .26529 Mdot
.40629 .4463 Mdot
.34717 .49127 Mdot
.66058 .57894 Mdot
.46057 .59353 Mdot
.42572 .33046 Mdot
.52894 .21696 Mdot
.66918 .5539 Mdot
.57002 .50842 Mdot
.47203 .68684 Mdot
.39435 .5082 Mdot
.5547 .74731 Mdot
.65515 .303 Mdot
.37761 .62166 Mdot
.45083 .32481 Mdot
.34673 .33576 Mdot
.47301 .70952 Mdot
.65195 .56706 Mdot
.73886 .45885 Mdot
.45037 .51261 Mdot
.39446 .50142 Mdot
.34088 .33637 Mdot
.49459 .4298 Mdot
.26886 .30711 Mdot
.36201 .5332 Mdot
.50082 .42618 Mdot
.35181 .52241 Mdot
.44037 .53882 Mdot
.43544 .50063 Mdot
.36753 .4894 Mdot
.48359 .63831 Mdot
.39601 .57572 Mdot
.61652 .40021 Mdot
.26625 .52499 Mdot
.57432 .47824 Mdot
.36162 .45693 Mdot
.4112 .47322 Mdot
.40231 .66311 Mdot
.71657 .55469 Mdot
.50728 .66324 Mdot
.45023 .62741 Mdot
.61604 .55773 Mdot
.46199 .49935 Mdot
.57377 .38838 Mdot
.3949 .57046 Mdot
.62466 .37758 Mdot
.47349 .64018 Mdot
.60206 .36167 Mdot
.63248 .58599 Mdot
.61622 .40739 Mdot
.74675 .53533 Mdot
.63275 .55446 Mdot
.48661 .70792 Mdot
.36048 .50121 Mdot
.66222 .53124 Mdot
.28108 .3528 Mdot
.45055 .31723 Mdot
.17828 .56423 Mdot
.40937 .44441 Mdot
.63442 .48849 Mdot
.47609 .5433 Mdot
.62345 .37351 Mdot
.62148 .20931 Mdot
.50274 .64894 Mdot
.41471 .31782 Mdot
.4718 .64018 Mdot
.80805 .39841 Mdot
.44945 .30273 Mdot
.22527 .68133 Mdot
.76279 .44689 Mdot
.54832 .41527 Mdot
.43367 .47557 Mdot
.28088 .44254 Mdot
.59388 .34774 Mdot
.6402 .54702 Mdot
.74977 .4326 Mdot
.34794 .50194 Mdot
.67768 .28128 Mdot
.44608 .67489 Mdot
.59259 .39943 Mdot
.65853 .56306 Mdot
.65072 .52978 Mdot
.3935 .53304 Mdot
.48657 .24376 Mdot
.35933 .52503 Mdot
.72204 .4319 Mdot
.34887 .35801 Mdot
.42984 .41389 Mdot
.35207 .47435 Mdot
.57311 .36575 Mdot
.40563 .45516 Mdot
.40587 .38316 Mdot
.80232 .56067 Mdot
.34782 .44305 Mdot
.76242 .54244 Mdot
.46413 .27308 Mdot
.48021 .67673 Mdot
.31797 .51386 Mdot
.67224 .48763 Mdot
.40804 .45048 Mdot
.84468 .38036 Mdot
.4443 .33266 Mdot
.70119 .49243 Mdot
.32916 .50627 Mdot
.40412 .52803 Mdot
.30521 .43703 Mdot
.51287 .73644 Mdot
.65968 .30231 Mdot
.39168 .49524 Mdot
.30148 .38292 Mdot
.6745 .57078 Mdot
.36539 .53033 Mdot
.36482 .47364 Mdot
.45507 .75304 Mdot
.637 .53735 Mdot
.61727 .36532 Mdot
.66245 .37163 Mdot
.55276 .36626 Mdot
.44733 .28463 Mdot
.55208 .48385 Mdot
.33274 .28109 Mdot
.69452 .27269 Mdot
.4253 .34169 Mdot
.42197 .46368 Mdot
.38379 .39022 Mdot
.42261 .4881 Mdot
.46668 .31698 Mdot
.6336 .54107 Mdot
.50864 .6638 Mdot
.60962 .63099 Mdot
.57317 .3519 Mdot
.35572 .53287 Mdot
.45552 .29678 Mdot
.49074 .70504 Mdot
.44898 .36611 Mdot
.48006 .68455 Mdot
.66516 .55309 Mdot
.6133 .55225 Mdot
.4616 .31352 Mdot
.46644 .64989 Mdot
.72914 .57293 Mdot
.19324 .53071 Mdot
.42811 .53014 Mdot
.60996 .59849 Mdot
.45924 .64603 Mdot
.45763 .71288 Mdot
.45117 .67848 Mdot
.36514 .51603 Mdot
.56698 .56006 Mdot
.3976 .55761 Mdot
.63745 .57546 Mdot
.64161 .37294 Mdot
.40742 .27687 Mdot
.6952 .71466 Mdot
.41868 .26798 Mdot
.36948 .44003 Mdot
.3825 .47138 Mdot
.35816 .4756 Mdot
.42562 .52039 Mdot
.71479 .44696 Mdot
.38761 .52815 Mdot
.68657 .56218 Mdot
.61435 .38125 Mdot
.34597 .4635 Mdot
.6569 .38858 Mdot
.56722 .67746 Mdot
.43547 .347 Mdot
.54094 .47658 Mdot
.46401 .85146 Mdot
.49681 .70336 Mdot
.64328 .36582 Mdot
.61475 .39607 Mdot
.42029 .32501 Mdot
.64524 .54524 Mdot
.47613 .68874 Mdot
.38539 .29705 Mdot
.42584 .30805 Mdot
.38157 .47877 Mdot
.67876 .38803 Mdot
.66951 .28539 Mdot
.33815 .48479 Mdot
.40831 .50858 Mdot
.65368 .39797 Mdot
.55301 .40082 Mdot
.8165 .62128 Mdot
.2852 .30771 Mdot
.45938 .30983 Mdot
.44563 .34753 Mdot
.47465 .72015 Mdot
.34318 .53845 Mdot
.64033 .57813 Mdot
.24376 .35496 Mdot
.49165 .47936 Mdot
.247 .37848 Mdot
.46694 .39049 Mdot
.3822 .53566 Mdot
.24045 .54221 Mdot
.37746 .4673 Mdot
.50089 .64311 Mdot
.46922 .69669 Mdot
.50789 .68207 Mdot
.64017 .55086 Mdot
.32846 .71228 Mdot
.685 .55357 Mdot
.49429 .84791 Mdot
.47618 .71294 Mdot
.70636 .46999 Mdot
.57326 .36897 Mdot
.31954 .49255 Mdot
.42598 .32187 Mdot
.70083 .56922 Mdot
.37939 .41952 Mdot
.55486 .19438 Mdot
.60556 .40122 Mdot
.48638 .70889 Mdot
.55343 .69622 Mdot
.57204 .81238 Mdot
.599 .49878 Mdot
.30891 .5282 Mdot
.29715 .43596 Mdot
.43678 .30328 Mdot
.36918 .61719 Mdot
.46684 .30724 Mdot
.64163 .56821 Mdot
.35343 .49401 Mdot
.36181 .49466 Mdot
.34342 .51364 Mdot
.38386 .52689 Mdot
.62003 .54822 Mdot
.33719 .45993 Mdot
.76934 .30658 Mdot
.62125 .41204 Mdot
.29898 .73364 Mdot
.43673 .33604 Mdot
.65299 .52458 Mdot
.61688 .38128 Mdot
.63489 .41669 Mdot
.29286 .3184 Mdot
.35389 .46553 Mdot
.39686 .51931 Mdot
.6425 .28021 Mdot
.357 .53016 Mdot
.31163 .52697 Mdot
.61127 .39799 Mdot
.4158 .27071 Mdot
.4249 .34523 Mdot
.45966 .33674 Mdot
.64224 .53731 Mdot
.46818 .64528 Mdot
.44398 .31851 Mdot
.60012 .35592 Mdot
.38965 .43394 Mdot
.40946 .52995 Mdot
.45721 .64841 Mdot
.81889 .48086 Mdot
.45681 .35323 Mdot
.55876 .68136 Mdot
.4602 .68649 Mdot
.51983 .70124 Mdot
.39565 .50017 Mdot
.39727 .58156 Mdot
.50588 .73099 Mdot
.41741 .32538 Mdot
.64666 .52478 Mdot
.5803 .45979 Mdot
.64777 .5764 Mdot
.47824 .69835 Mdot
.41036 .53485 Mdot
.47685 .70106 Mdot
.39141 .4443 Mdot
.34789 .84219 Mdot
.36717 .49406 Mdot
.71463 .28087 Mdot
.35909 .29828 Mdot
.60759 .38923 Mdot
.73172 .56864 Mdot
.59046 .39403 Mdot
.46231 .69215 Mdot
.40344 .53993 Mdot
.45542 .34635 Mdot
.30928 .76953 Mdot
.51575 .71339 Mdot
.62968 .39137 Mdot
.56745 .39129 Mdot
.63067 .55298 Mdot
.34423 .46378 Mdot
.39214 .50577 Mdot
.59092 .38235 Mdot
.4512 .43147 Mdot
.47403 .65024 Mdot
.34934 .48604 Mdot
.39603 .47677 Mdot
.60671 .39076 Mdot
.1954 .51755 Mdot
.53712 .70597 Mdot
.35846 .48879 Mdot
.75002 .49015 Mdot
.68468 .5385 Mdot
.43256 .49589 Mdot
.32208 .47825 Mdot
.43221 .31554 Mdot
.35254 .76264 Mdot
.79816 .57369 Mdot
.68949 .54507 Mdot
.58173 .39059 Mdot
.41016 .4482 Mdot
.57197 .37068 Mdot
.40404 .53392 Mdot
.42707 .77865 Mdot
.59972 .40463 Mdot
.4115 .51776 Mdot
.326 .52122 Mdot
.47535 .70407 Mdot
.39175 .52966 Mdot
.416 .6778 Mdot
.6227 .35084 Mdot
.40378 .52514 Mdot
.23124 .58097 Mdot
.66256 .53894 Mdot
.32059 .51294 Mdot
.44431 .34359 Mdot
.38912 .28902 Mdot
.65426 .68791 Mdot
.73966 .51632 Mdot
.45199 .3409 Mdot
.35742 .51634 Mdot
.56944 .39449 Mdot
.64942 .58689 Mdot
.66781 .26156 Mdot
.34111 .49612 Mdot
.65787 .57784 Mdot
.64972 .56121 Mdot
.44765 .33866 Mdot
.41124 .16943 Mdot
.32626 .47251 Mdot
.38456 .5051 Mdot
.42866 .71709 Mdot
.49514 .6303 Mdot
.37467 .50146 Mdot
.42513 .47977 Mdot
.68462 .56753 Mdot
.30442 .51048 Mdot
.38862 .70669 Mdot
.49061 .21876 Mdot
.69263 .57272 Mdot
.53324 .42485 Mdot
.57827 .39593 Mdot
.43513 .33284 Mdot
.48576 .67356 Mdot
.47105 .33414 Mdot
.62972 .40249 Mdot
.42131 .46709 Mdot
.67293 .58597 Mdot
.41303 .61748 Mdot
.6486 .58803 Mdot
.72666 .50765 Mdot
.47446 .63339 Mdot
.6244 .65001 Mdot
.79024 .30256 Mdot
.62308 .7086 Mdot
.71255 .5463 Mdot
.43567 .30569 Mdot
.65416 .43025 Mdot
.39213 .47503 Mdot
.33255 .59765 Mdot
.35878 .5051 Mdot
.23724 .58367 Mdot
.64319 .36984 Mdot
.60216 .41218 Mdot
.35581 .492 Mdot
.35127 .35047 Mdot
.63989 .58475 Mdot
.62886 .56022 Mdot
.40228 .52282 Mdot
.65757 .5483 Mdot
.38161 .49344 Mdot
.62567 .38119 Mdot
.53079 .16763 Mdot
.37127 .46969 Mdot
.38589 .55294 Mdot
.59987 .52648 Mdot
.17728 .60272 Mdot
.7733 .49064 Mdot
.24308 .53064 Mdot
.60254 .80282 Mdot
.65779 .54915 Mdot
.37671 .56107 Mdot
.52856 .41905 Mdot
.65553 .39588 Mdot
.72774 .57426 Mdot
.36986 .50487 Mdot
.37042 .50915 Mdot
.34436 .49163 Mdot
.41214 .48375 Mdot
.34083 .60404 Mdot
.44618 .58932 Mdot
.26476 .63036 Mdot
.39969 .51888 Mdot
.26618 .4478 Mdot
.66762 .53391 Mdot
.44536 .65982 Mdot
.47337 .33115 Mdot
.38303 .53534 Mdot
.44167 .59762 Mdot
.67851 .53299 Mdot
.49664 .84769 Mdot
.63303 .54474 Mdot
.60341 .36755 Mdot
.621 .5628 Mdot
.37849 .45048 Mdot
.4932 .67437 Mdot
.57429 .46605 Mdot
.7023 .375 Mdot
.61814 .39586 Mdot
.3702 .45135 Mdot
.6858 .486 Mdot
.61929 .39842 Mdot
.56903 .67996 Mdot
.49132 .66942 Mdot
.29262 .38501 Mdot
.46941 .69752 Mdot
.41182 .5187 Mdot
.41724 .50821 Mdot
.66624 .61177 Mdot
.63395 .58368 Mdot
.46638 .69434 Mdot
.45367 .14718 Mdot
.46685 .30517 Mdot
.50549 .68547 Mdot
.44874 .47906 Mdot
.51938 .5444 Mdot
.49736 .66788 Mdot
.39654 .34548 Mdot
.63636 .55138 Mdot
.47693 .71671 Mdot
.44935 .47722 Mdot
.79692 .43783 Mdot
.41855 .31048 Mdot
.55425 .38379 Mdot
.61351 .33417 Mdot
.63715 .35536 Mdot
.63491 .5273 Mdot
.59958 .39663 Mdot
.67757 .56554 Mdot
.73864 .613 Mdot
.24243 .46737 Mdot
.61944 .52594 Mdot
.62317 .5352 Mdot
.6029 .39534 Mdot
.3473 .47948 Mdot
.62727 .34309 Mdot
.41157 .54906 Mdot
.40332 .42346 Mdot
.67801 .55611 Mdot
.47399 .70896 Mdot
.50861 .70865 Mdot
.27271 .44429 Mdot
.51028 .65375 Mdot
.62641 .37738 Mdot
.68503 .25246 Mdot
.77889 .57359 Mdot
.67035 .57208 Mdot
.62355 .53905 Mdot
.40695 .47234 Mdot
.58087 .37468 Mdot
.58279 .35732 Mdot
.63559 .56476 Mdot
.30876 .56605 Mdot
.3666 .55211 Mdot
.44707 .69735 Mdot
.47873 .71469 Mdot
.49955 .6776 Mdot
.45322 .68554 Mdot
.37656 .6756 Mdot
.63497 .55284 Mdot
.4687 .70558 Mdot
.40798 .5194 Mdot
.37112 .50816 Mdot
.5813 .46911 Mdot
.45634 .33955 Mdot
.39659 .43696 Mdot
.43746 .48934 Mdot
.39701 .50286 Mdot
.63505 .39255 Mdot
.43245 .43515 Mdot
.58889 .40065 Mdot
.55489 .37995 Mdot
.63965 .40537 Mdot
.73583 .52899 Mdot
.30449 .42419 Mdot
.63785 .79749 Mdot
.40897 .46249 Mdot
.47928 .59376 Mdot
.57766 .36756 Mdot
.5943 .20096 Mdot
.66218 .6328 Mdot
.34247 .49517 Mdot
.65356 .30484 Mdot
.59164 .38445 Mdot
.51488 .66009 Mdot
.369 .50153 Mdot
.55029 .36477 Mdot
.43142 .34309 Mdot
.44629 .50087 Mdot
.65368 .36364 Mdot
.46353 .65789 Mdot
.47034 .30014 Mdot
.46977 .71241 Mdot
.64738 .39747 Mdot
.32432 .51884 Mdot
.79952 .71199 Mdot
.5627 .35952 Mdot
.22578 .66138 Mdot
.5354 .6686 Mdot
.34846 .48566 Mdot
.64019 .36094 Mdot
.49727 .6324 Mdot
.63775 .525 Mdot
.50617 .47479 Mdot
.50905 .65918 Mdot
.60217 .41198 Mdot
.65003 .36149 Mdot
.6126 .39784 Mdot
.47458 .67302 Mdot
.4041 .54623 Mdot
.47415 .66296 Mdot
.62125 .56036 Mdot
.38795 .46501 Mdot
.52115 .8232 Mdot
.46949 .59179 Mdot
.46246 .69022 Mdot
.62674 .36726 Mdot
.43874 .29087 Mdot
.36931 .46239 Mdot
.21149 .62599 Mdot
.37566 .44646 Mdot
.66815 .57881 Mdot
.48609 .19121 Mdot
.40905 .61901 Mdot
.33245 .48176 Mdot
.40776 .47325 Mdot
.63123 .56784 Mdot
.35853 .46385 Mdot
.33382 .48214 Mdot
.71921 .52031 Mdot
.46949 .67587 Mdot
.38687 .47764 Mdot
.63093 .36382 Mdot
.76346 .61126 Mdot
.38277 .55744 Mdot
.57064 .26471 Mdot
.31351 .37017 Mdot
.45603 .18303 Mdot
.35556 .50347 Mdot
.26586 .33408 Mdot
.41264 .49229 Mdot
.36703 .52391 Mdot
.40469 .46557 Mdot
.24864 .5209 Mdot
.61289 .40413 Mdot
.61989 .38882 Mdot
.41757 .31376 Mdot
.31106 .37328 Mdot
.43404 .31713 Mdot
.63894 .54387 Mdot
.54452 .26893 Mdot
.60078 .40469 Mdot
.46273 .65811 Mdot
.35678 .51942 Mdot
.5664 .35565 Mdot
.39306 .51145 Mdot
.38314 .44863 Mdot
.56747 .36881 Mdot
.56251 .36724 Mdot
.71617 .50388 Mdot
.43983 .34604 Mdot
.51076 .67848 Mdot
.42071 .44513 Mdot
.43783 .29809 Mdot
.40084 .54579 Mdot
.35029 .27179 Mdot
.50946 .67537 Mdot
.47008 .6726 Mdot
.51785 .68843 Mdot
.42083 .46619 Mdot
.37003 .45485 Mdot
.68455 .55466 Mdot
.46404 .65108 Mdot
.65901 .53921 Mdot
.56059 .46314 Mdot
.55553 .25365 Mdot
.36989 .50504 Mdot
.55608 .65654 Mdot
.42933 .3248 Mdot
.61172 .3718 Mdot
.60686 .25856 Mdot
.41957 .3054 Mdot
.37875 .44645 Mdot
.57119 .3673 Mdot
.46529 .32019 Mdot
.29265 .50808 Mdot
.70552 .75606 Mdot
.44927 .28995 Mdot
.4066 .5194 Mdot
.3069 .45745 Mdot
.21179 .46316 Mdot
.44894 .28623 Mdot
.66968 .58427 Mdot
.42061 .46402 Mdot
.46578 .56472 Mdot
.45886 .35096 Mdot
.74603 .62253 Mdot
.60451 .38409 Mdot
.79442 .49536 Mdot
.4038 .41671 Mdot
.29692 .56856 Mdot
.47091 .32384 Mdot
.47888 .69032 Mdot
.46775 .62475 Mdot
.40192 .49512 Mdot
.45245 .28615 Mdot
.68555 .58334 Mdot
.6048 .37975 Mdot
.74514 .54186 Mdot
.47531 .67007 Mdot
.58117 .64177 Mdot
.63856 .37417 Mdot
.56151 .65731 Mdot
.49686 .20566 Mdot
.43933 .42289 Mdot
.23407 .51281 Mdot
.71979 .34292 Mdot
.42483 .46614 Mdot
.46211 .2992 Mdot
.68367 .53966 Mdot
.66405 .5887 Mdot
.66882 .55709 Mdot
.73552 .56284 Mdot
.59042 .48542 Mdot
.65355 .38375 Mdot
.69598 .3432 Mdot
.43938 .33258 Mdot
.26016 .41836 Mdot
.39179 .54415 Mdot
.38031 .47102 Mdot
.35383 .45173 Mdot
.36653 .53287 Mdot
.40777 .4895 Mdot
.65055 .5443 Mdot
.73807 .56052 Mdot
.55347 .43703 Mdot
.50402 .66767 Mdot
.4242 .26822 Mdot
.57363 .36867 Mdot
.64438 .40577 Mdot
.46006 .32444 Mdot
.54957 .71775 Mdot
.65452 .37452 Mdot
.60548 .36229 Mdot
.37522 .4435 Mdot
.47156 .65801 Mdot
.38716 .57504 Mdot
.41813 .49854 Mdot
.61605 .37569 Mdot
.4974 .37927 Mdot
.40144 .69385 Mdot
.44778 .53558 Mdot
.47793 .30579 Mdot
.56088 .55715 Mdot
.45056 .28716 Mdot
.38441 .54818 Mdot
.57632 .1942 Mdot
.62735 .4033 Mdot
.59002 .36953 Mdot
.46264 .30332 Mdot
.54691 .68094 Mdot
.4829 .66755 Mdot
.63462 .41711 Mdot
.6769 .57459 Mdot
.42166 .49815 Mdot
.57338 .24455 Mdot
.54432 .65741 Mdot
.50549 .24682 Mdot
.67019 .56397 Mdot
.58508 .358 Mdot
.34104 .4669 Mdot
.40714 .51768 Mdot
.43258 .3059 Mdot
.58141 .77818 Mdot
.44495 .48871 Mdot
.35625 .7978 Mdot
.76646 .33913 Mdot
.80996 .45808 Mdot
.39428 .50142 Mdot
.47082 .6768 Mdot
.66266 .37488 Mdot
.43569 .30081 Mdot
.37881 .43219 Mdot
.68462 .77096 Mdot
.45175 .65024 Mdot
.64593 .56818 Mdot
.52828 .4289 Mdot
.60298 .48851 Mdot
.40119 .44197 Mdot
.35967 .50438 Mdot
.37125 .52057 Mdot
.77597 .68068 Mdot
.63583 .38563 Mdot
.48649 .63561 Mdot
.45285 .3249 Mdot
.50829 .65084 Mdot
.61472 .3902 Mdot
.59766 .64714 Mdot
.3541 .46105 Mdot
.45304 .64939 Mdot
.48102 .6881 Mdot
.63119 .55164 Mdot
.62736 .52964 Mdot
.54805 .44792 Mdot
.36829 .49338 Mdot
.62545 .34773 Mdot
.47811 .70711 Mdot
.67557 .37988 Mdot
.44722 .3022 Mdot
.67757 .53945 Mdot
.39808 .52031 Mdot
.6235 .40207 Mdot
.33851 .45766 Mdot
.49332 .65738 Mdot
.60377 .36218 Mdot
.71238 .50309 Mdot
.44554 .34669 Mdot
.38119 .51724 Mdot
.47984 .32476 Mdot
.5802 .38949 Mdot
.39519 .47532 Mdot
.52958 .73831 Mdot
.4596 .28123 Mdot
.70059 .39982 Mdot
.65125 .38257 Mdot
.7241 .51193 Mdot
.51398 .6961 Mdot
.72515 .63642 Mdot
.59498 .36978 Mdot
.53111 .74073 Mdot
.63689 .74635 Mdot
.41755 .43989 Mdot
.49418 .69088 Mdot
.65066 .42293 Mdot
.42902 .84766 Mdot
.20461 .52966 Mdot
.35921 .47321 Mdot
.64603 .37006 Mdot
.45711 .29976 Mdot
.67124 .57112 Mdot
.57116 .26321 Mdot
.40607 .384 Mdot
.56367 .38355 Mdot
.40743 .46703 Mdot
.46734 .68888 Mdot
.64111 .55608 Mdot
.67748 .68035 Mdot
.6111 .35808 Mdot
.64405 .37779 Mdot
.33866 .47048 Mdot
.43816 .32149 Mdot
.21178 .58045 Mdot
.62667 .38409 Mdot
.65115 .28688 Mdot
.66226 .42877 Mdot
.45492 .29586 Mdot
.41172 .502 Mdot
.28219 .43318 Mdot
.42858 .51266 Mdot
.24228 .69186 Mdot
.58462 .38966 Mdot
.50259 .66096 Mdot
.35852 .51028 Mdot
.47864 .21864 Mdot
.61126 .37547 Mdot
.57068 .55745 Mdot
.52898 .34579 Mdot
.63565 .55272 Mdot
.61353 .25936 Mdot
.38025 .50683 Mdot
.64322 .58632 Mdot
.42956 .32415 Mdot
.36267 .48697 Mdot
.37282 .4548 Mdot
.50534 .64091 Mdot
.64114 .5695 Mdot
.65928 .75075 Mdot
.64713 .52874 Mdot
.6893 .55132 Mdot
.52255 .67709 Mdot
.39191 .48764 Mdot
.60682 .36672 Mdot
.58898 .38295 Mdot
.39718 .42626 Mdot
.60529 .19404 Mdot
.48127 .66601 Mdot
.44702 .2593 Mdot
.7882 .66196 Mdot
.42714 .41476 Mdot
.60209 .25578 Mdot
.57805 .77753 Mdot
.6825 .58554 Mdot
.40119 .52145 Mdot
.46042 .67209 Mdot
.62931 .41866 Mdot
.63834 .37151 Mdot
.40947 .54048 Mdot
.64835 .5571 Mdot
.42569 .33899 Mdot
.58544 .35119 Mdot
.48773 .24303 Mdot
.37609 .5267 Mdot
.68696 .30878 Mdot
.62959 .3552 Mdot
.34101 .80566 Mdot
.66237 .40368 Mdot
.4977 .68799 Mdot
.38387 .44975 Mdot
.51217 .65992 Mdot
.45368 .31762 Mdot
.5364 .43609 Mdot
.64763 .55914 Mdot
.41087 .39903 Mdot
.83832 .4021 Mdot
.60519 .39931 Mdot
.48643 .63929 Mdot
.33204 .48213 Mdot
.37559 .39656 Mdot
.38116 .50156 Mdot
.31407 .45193 Mdot
.47007 .27789 Mdot
.67576 .5495 Mdot
.66832 .581 Mdot
.39128 .47141 Mdot
.42275 .32066 Mdot
.58686 .35849 Mdot
.60324 .37786 Mdot
.13997 .58152 Mdot
.67887 .36511 Mdot
.36962 .33379 Mdot
.37354 .5121 Mdot
.59363 .40843 Mdot
.72314 .68702 Mdot
.6619 .57842 Mdot
.38448 .54362 Mdot
.57653 .39092 Mdot
.77802 .38798 Mdot
.39441 .26677 Mdot
.40852 .49347 Mdot
.33561 .44928 Mdot
.67562 .57731 Mdot
.26118 .3819 Mdot
.64457 .39916 Mdot
.42101 .54081 Mdot
.6192 .57412 Mdot
.45484 .2104 Mdot
.81162 .53144 Mdot
.51063 .67914 Mdot
.53683 .38485 Mdot
.64974 .54424 Mdot
.41936 .42926 Mdot
.43923 .33856 Mdot
.60932 .34808 Mdot
.63171 .3934 Mdot
.40006 .45853 Mdot
.33563 .4632 Mdot
.34728 .39099 Mdot
.489 .64218 Mdot
.66104 .5329 Mdot
.35125 .49748 Mdot
.57886 .62103 Mdot
.3464 .51712 Mdot
.68081 .54713 Mdot
.76076 .77041 Mdot
.42621 .44765 Mdot
.3831 .50154 Mdot
.20862 .57619 Mdot
.51025 .66126 Mdot
.5112 .65261 Mdot
.7314 .30303 Mdot
.37423 .51263 Mdot
.63753 .27119 Mdot
.51197 .6793 Mdot
.48392 .66299 Mdot
.66621 .46613 Mdot
.37105 .46568 Mdot
.22936 .403 Mdot
.65081 .58566 Mdot
.68758 .56716 Mdot
.47509 .66406 Mdot
.43782 .46023 Mdot
.67557 .5888 Mdot
.36196 .62858 Mdot
.57983 .37525 Mdot
.55968 .1884 Mdot
.49176 .65261 Mdot
.53025 .45261 Mdot
.66814 .57151 Mdot
.49039 .84815 Mdot
.66356 .31961 Mdot
.34705 .48449 Mdot
.3796 .51952 Mdot
.43052 .32871 Mdot
.42034 .4434 Mdot
.60448 .41281 Mdot
.6576 .54796 Mdot
.23446 .64065 Mdot
.5075 .6834 Mdot
.37355 .49345 Mdot
.56291 .67939 Mdot
.66406 .7034 Mdot
.77285 .45493 Mdot
.48069 .67738 Mdot
.49381 .69592 Mdot
.64679 .39517 Mdot
.64095 .36501 Mdot
.39841 .49017 Mdot
.63531 .57113 Mdot
.46076 .65942 Mdot
.68087 .55184 Mdot
.62936 .40203 Mdot
.61018 .36494 Mdot
.60157 .40591 Mdot
.42273 .54492 Mdot
.61346 .36087 Mdot
.47405 .24044 Mdot
.58464 .6489 Mdot
.48888 .72463 Mdot
.83945 .48164 Mdot
.6787 .67833 Mdot
.48236 .50499 Mdot
.45812 .3458 Mdot
.57926 .38887 Mdot
.62235 .54811 Mdot
.40543 .47412 Mdot
.3953 .51571 Mdot
.54563 .36944 Mdot
.62593 .56927 Mdot
.45578 .31157 Mdot
.62894 .57665 Mdot
.44623 .33982 Mdot
.66416 .30843 Mdot
.34657 .46095 Mdot
.4121 .52483 Mdot
.65615 .54455 Mdot
.60719 .36099 Mdot
.6156 .38385 Mdot
.45478 .28983 Mdot
.48978 .44178 Mdot
.61606 .39969 Mdot
.49206 .65374 Mdot
.36477 .66678 Mdot
.65702 .3674 Mdot
.37131 .50158 Mdot
.33043 .27877 Mdot
.34466 .59916 Mdot
.42297 .52842 Mdot
.6659 .48632 Mdot
.25306 .30566 Mdot
.35288 .51044 Mdot
.26702 .28029 Mdot
.72605 .51392 Mdot
.5081 .65605 Mdot
.64634 .3745 Mdot
.6272 .41752 Mdot
.30794 .503 Mdot
.43095 .37057 Mdot
.3924 .4286 Mdot
.51329 .66874 Mdot
.47846 .62134 Mdot
.79422 .40062 Mdot
.22712 .66494 Mdot
.46792 .31371 Mdot
.4616 .32784 Mdot
.59454 .37171 Mdot
.1735 .50308 Mdot
.44823 .52769 Mdot
.45884 .31081 Mdot
.24175 .45633 Mdot
.41101 .46897 Mdot
.34139 .32745 Mdot
.64356 .29525 Mdot
.47276 .67279 Mdot
.28051 .44085 Mdot
.60356 .37103 Mdot
.49565 .64467 Mdot
.59409 .62319 Mdot
.40119 .43942 Mdot
.50878 .67658 Mdot
.68287 .55587 Mdot
.73663 .37701 Mdot
.5078 .69999 Mdot
.33949 .27244 Mdot
.63487 .5654 Mdot
.66107 .44065 Mdot
.27399 .41375 Mdot
.71072 .20151 Mdot
.65067 .54678 Mdot
.56489 .3752 Mdot
.59002 .38296 Mdot
.60142 .37748 Mdot
.49984 .64523 Mdot
.57737 .3597 Mdot
.48445 .64135 Mdot
.20212 .47794 Mdot
.48931 .4431 Mdot
.46124 .31145 Mdot
.68659 .50186 Mdot
.48524 .69385 Mdot
.66133 .23521 Mdot
.80509 .33041 Mdot
.39892 .52493 Mdot
.63449 .53327 Mdot
.4655 .31408 Mdot
.29238 .76492 Mdot
.43114 .31964 Mdot
.53147 .39635 Mdot
.5178 .18042 Mdot
.37765 .48994 Mdot
.38159 .73943 Mdot
.45492 .3455 Mdot
.47376 .68636 Mdot
.39051 .47365 Mdot
.7203 .58392 Mdot
.43455 .32528 Mdot
.42683 .33868 Mdot
.39926 .48402 Mdot
.48577 .70895 Mdot
.61277 .3679 Mdot
.61953 .56849 Mdot
.42012 .29642 Mdot
.50196 .61275 Mdot
.42685 .46107 Mdot
.41546 .45225 Mdot
.59132 .51595 Mdot
.39619 .37497 Mdot
.65711 .54937 Mdot
.22519 .45154 Mdot
.64138 .36634 Mdot
.61345 .43795 Mdot
.73666 .31589 Mdot
.68114 .49514 Mdot
.5897 .3922 Mdot
.58574 .3928 Mdot
.40554 .49068 Mdot
.389 .37209 Mdot
.46829 .19087 Mdot
.69646 .52286 Mdot
.65992 .3721 Mdot
.60632 .37858 Mdot
.46641 .62826 Mdot
.79724 .39839 Mdot
.37301 .43462 Mdot
.69242 .5505 Mdot
.62553 .40032 Mdot
.42966 .78002 Mdot
.44132 .3239 Mdot
.6232 .21713 Mdot
.34414 .46547 Mdot
.34985 .49321 Mdot
.66139 .55986 Mdot
.68558 .55405 Mdot
.67384 .61424 Mdot
.78221 .36007 Mdot
.22654 .36957 Mdot
.71873 .66036 Mdot
.42715 .77227 Mdot
.44842 .65235 Mdot
.46313 .69157 Mdot
.73583 .54113 Mdot
.66211 .52873 Mdot
.35644 .51157 Mdot
.46107 .66078 Mdot
.75727 .43251 Mdot
.45164 .61158 Mdot
.35331 .3338 Mdot
.53373 .2309 Mdot
.38499 .44537 Mdot
.46677 .66533 Mdot
.50519 .65574 Mdot
.4556 .67239 Mdot
.72599 .5147 Mdot
.39121 .49565 Mdot
.35302 .47018 Mdot
.34722 .51116 Mdot
.41818 .5902 Mdot
.38437 .52946 Mdot
.69394 .51596 Mdot
.57068 .51397 Mdot
.29121 .71461 Mdot
.42938 .52079 Mdot
.68502 .57992 Mdot
.41535 .44701 Mdot
.42213 .3227 Mdot
.40572 .46801 Mdot
.35825 .33013 Mdot
.65605 .57374 Mdot
.54004 .68221 Mdot
.71792 .65581 Mdot
.35017 .46215 Mdot
.42597 .34367 Mdot
.47145 .5378 Mdot
.60515 .77899 Mdot
.41651 .37128 Mdot
.49118 .65363 Mdot
.57872 .3804 Mdot
.62291 .55593 Mdot
.60116 .36543 Mdot
.43117 .52794 Mdot
.65125 .48265 Mdot
.58848 .73361 Mdot
.52523 .43852 Mdot
.37719 .53561 Mdot
.43846 .43508 Mdot
.48798 .65742 Mdot
.57094 .3677 Mdot
.44615 .71034 Mdot
.36389 .51355 Mdot
.45123 .32172 Mdot
.43561 .32922 Mdot
.67351 .6244 Mdot
.46935 .80557 Mdot
.7221 .6302 Mdot
.66178 .55714 Mdot
.62888 .38512 Mdot
.47112 .31818 Mdot
.50413 .60327 Mdot
.66482 .5235 Mdot
.63018 .56646 Mdot
.63869 .56469 Mdot
.42149 .47553 Mdot
.58868 .40065 Mdot
.28106 .69997 Mdot
.59995 .41057 Mdot
.36246 .45789 Mdot
.63785 .38482 Mdot
.59233 .39975 Mdot
.43301 .33413 Mdot
.64073 .53775 Mdot
.63728 .39827 Mdot
.41127 .52014 Mdot
.50458 .69751 Mdot
.50306 .43872 Mdot
.37045 .28386 Mdot
.27498 .72515 Mdot
.29874 .74172 Mdot
.49337 .7135 Mdot
.46441 .82921 Mdot
.69642 .55188 Mdot
.30619 .56358 Mdot
.73272 .49057 Mdot
.41473 .52994 Mdot
.68048 .23636 Mdot
.65392 .38456 Mdot
.56656 .37056 Mdot
.41327 .49943 Mdot
.54733 .39368 Mdot
.37648 .49581 Mdot
.64175 .38771 Mdot
.42249 .27134 Mdot
.31478 .50178 Mdot
.59913 .35817 Mdot
.41145 .55233 Mdot
.37425 .46239 Mdot
.47154 .67233 Mdot
.63937 .35932 Mdot
.38065 .54332 Mdot
.20681 .68391 Mdot
.68253 .54599 Mdot
.69301 .49545 Mdot
.33005 .26524 Mdot
.64962 .54325 Mdot
.50477 .68293 Mdot
.40211 .42393 Mdot
.42866 .31536 Mdot
.47979 .6963 Mdot
.41004 .25234 Mdot
.45555 .34321 Mdot
.67742 .2406 Mdot
.48629 .65243 Mdot
.65536 .36669 Mdot
.43345 .33853 Mdot
.38788 .56077 Mdot
.59569 .34875 Mdot
.49502 .48724 Mdot
.58273 .38767 Mdot
.39161 .50673 Mdot
.74826 .54813 Mdot
.67529 .53645 Mdot
.36044 .4749 Mdot
.58068 .3533 Mdot
.73743 .53196 Mdot
.41881 .47164 Mdot
.40762 .47988 Mdot
.81837 .47196 Mdot
.63114 .23893 Mdot
.4397 .30289 Mdot
.48846 .63128 Mdot
.40824 .51941 Mdot
.43678 .34421 Mdot
.52746 .31172 Mdot
.42136 .45809 Mdot
.45127 .65606 Mdot
.43813 .56107 Mdot
.61152 .35144 Mdot
.6549 .53744 Mdot
.54879 .45651 Mdot
.43247 .34374 Mdot
.37789 .16482 Mdot
.60671 .40878 Mdot
.38088 .54727 Mdot
.37271 .53609 Mdot
.77649 .48275 Mdot
.49969 .64923 Mdot
.23098 .36812 Mdot
.38114 .5175 Mdot
.43731 .57393 Mdot
.36442 .48436 Mdot
.56364 .42197 Mdot
.48277 .66607 Mdot
.38576 .50533 Mdot
.55973 .63784 Mdot
.37755 .55397 Mdot
.42895 .3438 Mdot
.20372 .54698 Mdot
.42645 .46856 Mdot
.87099 .59906 Mdot
.62973 .27113 Mdot
.60254 .35829 Mdot
.74796 .55491 Mdot
.15302 .43804 Mdot
.73594 .61762 Mdot
.48237 .64022 Mdot
.57499 .77069 Mdot
.60802 .36632 Mdot
.74498 .63453 Mdot
.45529 .8363 Mdot
.3767 .46153 Mdot
.40037 .44185 Mdot
.53141 .39658 Mdot
.60484 .41419 Mdot
.64175 .35339 Mdot
.43326 .51591 Mdot
.43726 .54681 Mdot
.62295 .36376 Mdot
.40442 .52777 Mdot
.38699 .56874 Mdot
.61797 .56071 Mdot
.49498 .71081 Mdot
.67506 .56288 Mdot
.63109 .54526 Mdot
.28713 .58667 Mdot
.78101 .36681 Mdot
.67907 .54378 Mdot
.69604 .55327 Mdot
.3473 .32268 Mdot
.3273 .39774 Mdot
.45906 .3496 Mdot
.40919 .81096 Mdot
.59994 .37947 Mdot
.38982 .49306 Mdot
.49507 .71593 Mdot
.28488 .55585 Mdot
.59977 .27993 Mdot
.48324 .18407 Mdot
.36085 .5136 Mdot
.60649 .37405 Mdot
.72988 .51671 Mdot
.37984 .57494 Mdot
.62333 .44786 Mdot
.34719 .49267 Mdot
.56931 .35444 Mdot
.35938 .69637 Mdot
.55411 .70056 Mdot
.67453 .39973 Mdot
.44095 .6621 Mdot
.35647 .49739 Mdot
.49428 .65191 Mdot
.67239 .56079 Mdot
.42503 .32674 Mdot
.44066 .30357 Mdot
.39843 .47828 Mdot
.4607 .471 Mdot
.65084 .3068 Mdot
.36985 .46149 Mdot
.39831 .46253 Mdot
.72635 .51404 Mdot
.39618 .46344 Mdot
.36788 .53243 Mdot
.35682 .52355 Mdot
.34385 .53165 Mdot
.68956 .55482 Mdot
.56247 .67595 Mdot
.43524 .52651 Mdot
.38137 .57264 Mdot
.63305 .588 Mdot
.60483 .76575 Mdot
.63321 .53988 Mdot
.52537 .8235 Mdot
.67059 .57598 Mdot
.45174 .30456 Mdot
.75855 .52662 Mdot
.45064 .44665 Mdot
.46211 .70013 Mdot
.65682 .52381 Mdot
.45231 .33237 Mdot
.66478 .55154 Mdot
.6396 .37735 Mdot
.80624 .60901 Mdot
.46959 .61289 Mdot
.25217 .34024 Mdot
.68588 .62088 Mdot
.69264 .37187 Mdot
.62646 .4066 Mdot
.47898 .66492 Mdot
.4038 .70459 Mdot
.35627 .52569 Mdot
.43863 .34362 Mdot
.40118 .4878 Mdot
.68894 .5472 Mdot
.60099 .37304 Mdot
.19927 .54097 Mdot
.43087 .30869 Mdot
.82821 .45961 Mdot
.60705 .38517 Mdot
.34011 .50591 Mdot
.69245 .55193 Mdot
.84457 .45566 Mdot
.67676 .55555 Mdot
.4713 .44074 Mdot
.44753 .69033 Mdot
.23504 .52085 Mdot
.49057 .69131 Mdot
.66056 .39137 Mdot
.81114 .65165 Mdot
.3666 .79395 Mdot
.49232 .70638 Mdot
.6839 .34464 Mdot
.40579 .44588 Mdot
.41555 .45086 Mdot
.54587 .70545 Mdot
.47604 .63403 Mdot
.39595 .52754 Mdot
.70713 .50068 Mdot
.59669 .66837 Mdot
.62611 .2555 Mdot
.5742 .37995 Mdot
.37735 .5019 Mdot
.62781 .58507 Mdot
.62954 .57647 Mdot
.59779 .40858 Mdot
.63282 .53861 Mdot
.3538 .4707 Mdot
.48701 .69273 Mdot
.5946 .34498 Mdot
.44302 .30992 Mdot
.19847 .64732 Mdot
.4727 .32282 Mdot
.59172 .39302 Mdot
.32489 .51908 Mdot
.61016 .36463 Mdot
.17196 .33953 Mdot
.35054 .47883 Mdot
.51129 .67291 Mdot
.41531 .48334 Mdot
.35744 .4933 Mdot
.40605 .4429 Mdot
.63124 .36862 Mdot
.25137 .32143 Mdot
.40737 .5254 Mdot
.64611 .5595 Mdot
.32749 .74935 Mdot
.41269 .44449 Mdot
.41354 .28637 Mdot
.33299 .36896 Mdot
.6967 .34064 Mdot
.4794 .71919 Mdot
.57951 .363 Mdot
.50531 .69106 Mdot
.45055 .61815 Mdot
.50489 .68232 Mdot
.33533 .74006 Mdot
.39503 .70554 Mdot
.29182 .27287 Mdot
.23396 .5891 Mdot
.27786 .51485 Mdot
.48247 .63149 Mdot
.50457 .34134 Mdot
.45898 .68296 Mdot
.49872 .65103 Mdot
.51674 .92001 Mdot
.46504 .70041 Mdot
.37489 .50747 Mdot
.37788 .44031 Mdot
.63882 .70482 Mdot
.32037 .32722 Mdot
.39523 .46856 Mdot
.41322 .51029 Mdot
.42703 .32909 Mdot
.46592 .5073 Mdot
.65241 .48297 Mdot
.68927 .25947 Mdot
.68441 .70045 Mdot
.40114 .48546 Mdot
.41051 .51827 Mdot
.42254 .55506 Mdot
.86882 .5163 Mdot
.30734 .59256 Mdot
.47704 .62984 Mdot
.43082 .43739 Mdot
.26517 .72613 Mdot
.34529 .47413 Mdot
.42535 .47935 Mdot
.39109 .44435 Mdot
.60754 .3667 Mdot
.44893 .65626 Mdot
.43572 .44465 Mdot
.696 .30139 Mdot
.35504 .45776 Mdot
.68639 .499 Mdot
.18625 .40065 Mdot
.38085 .5079 Mdot
.4566 .69833 Mdot
.40683 .45516 Mdot
.4836 .65038 Mdot
.46811 .6814 Mdot
.34083 .53452 Mdot
.39406 .77054 Mdot
.44721 .67677 Mdot
.3639 .4565 Mdot
.62101 .36903 Mdot
.39524 .81597 Mdot
.39123 .50942 Mdot
.43648 .29924 Mdot
.379 .51795 Mdot
.42023 .33711 Mdot
.39085 .45957 Mdot
.59401 .40691 Mdot
.39855 .61716 Mdot
.59014 .37126 Mdot
.20342 .40937 Mdot
.58036 .39681 Mdot
.81928 .46635 Mdot
.46269 .64027 Mdot
.73915 .5379 Mdot
.43543 .1698 Mdot
.6813 .49091 Mdot
.56198 .57427 Mdot
.54219 .55121 Mdot
.63449 .5703 Mdot
.51529 .66621 Mdot
.24826 .41335 Mdot
.76765 .45008 Mdot
.76488 .48799 Mdot
.6025 .40276 Mdot
.44481 .15288 Mdot
.5258 .17188 Mdot
.41972 .50659 Mdot
.36599 .74144 Mdot
.27596 .64285 Mdot
.42354 .46339 Mdot
.40618 .42367 Mdot
.54907 .37075 Mdot
.37817 .53893 Mdot
.5718 .62045 Mdot
.60206 .39437 Mdot
.45136 .33555 Mdot
.50031 .65659 Mdot
.41797 .31818 Mdot
.76798 .46322 Mdot
.54206 .55727 Mdot
.63755 .39375 Mdot
.3675 .54857 Mdot
.41685 .49149 Mdot
.47229 .66345 Mdot
.47945 .73996 Mdot
.47519 .70358 Mdot
.46479 .30823 Mdot
.6022 .3917 Mdot
.30799 .58386 Mdot
.40812 .51185 Mdot
.4831 .68626 Mdot
.60943 .6145 Mdot
.40599 .51883 Mdot
.66232 .54501 Mdot
.37384 .44773 Mdot
.49918 .70411 Mdot
.39577 .46334 Mdot
.48795 .69447 Mdot
.57791 .3756 Mdot
.34224 .47593 Mdot
.41129 .49764 Mdot
.84041 .46501 Mdot
.45426 .31039 Mdot
.47081 .63611 Mdot
.53467 .37482 Mdot
.34778 .5207 Mdot
.70779 .42698 Mdot
.35741 .50173 Mdot
.43473 .65485 Mdot
.3847 .5498 Mdot
.73273 .52224 Mdot
.3603 .44212 Mdot
.39054 .5087 Mdot
.54165 .58878 Mdot
.29074 .67505 Mdot
.47615 .74285 Mdot
.69259 .56076 Mdot
.45303 .68195 Mdot
.56419 .24566 Mdot
.65754 .37473 Mdot
.57677 .35884 Mdot
.27837 .34429 Mdot
.32685 .50793 Mdot
.37941 .49052 Mdot
.61307 .55257 Mdot
.45752 .3351 Mdot
.48016 .67973 Mdot
.44761 .33871 Mdot
.719 .30558 Mdot
.46698 .32522 Mdot
.61816 .41783 Mdot
.66612 .30587 Mdot
.3592 .61432 Mdot
.42752 .32964 Mdot
.48366 .70957 Mdot
.52177 .23248 Mdot
.41362 .53706 Mdot
.46713 .35809 Mdot
.44998 .32122 Mdot
.4387 .14713 Mdot
.37248 .53387 Mdot
.56569 .57056 Mdot
.67154 .54082 Mdot
.43727 .33795 Mdot
.64468 .57512 Mdot
.39778 .47144 Mdot
.69893 .40609 Mdot
.4783 .63783 Mdot
.66123 .59581 Mdot
.43394 .47108 Mdot
.46467 .31555 Mdot
.62571 .39894 Mdot
.70343 .58634 Mdot
.68014 .58432 Mdot
.57013 .78772 Mdot
.20727 .51882 Mdot
.60094 .39056 Mdot
.53534 .20521 Mdot
.65677 .58543 Mdot
.42578 .47371 Mdot
.44896 .56472 Mdot
.3468 .48359 Mdot
.73451 .5674 Mdot
.57671 .36386 Mdot
.59915 .69495 Mdot
.41764 .48805 Mdot
.35806 .51802 Mdot
.50583 .72982 Mdot
.58842 .37849 Mdot
.49511 .67273 Mdot
.45536 .68619 Mdot
.57883 .37649 Mdot
.49662 .687 Mdot
.45111 .34717 Mdot
.60825 .66408 Mdot
.66421 .58641 Mdot
.64823 .56281 Mdot
.6052 .37793 Mdot
.61044 .35896 Mdot
.60522 .36282 Mdot
.37288 .44807 Mdot
.48113 .67276 Mdot
.38799 .45048 Mdot
.40469 .44282 Mdot
.48886 .75237 Mdot
.48383 .71657 Mdot
.40174 .44749 Mdot
.65141 .42438 Mdot
.4706 .3522 Mdot
.62548 .37038 Mdot
.67522 .54126 Mdot
.74052 .66632 Mdot
.6703 .59945 Mdot
.3749 .50005 Mdot
.77459 .38552 Mdot
.48576 .7067 Mdot
.43043 .32462 Mdot
.44169 .35659 Mdot
.43184 .31313 Mdot
.60808 .55475 Mdot
.46117 .65128 Mdot
.68783 .25777 Mdot
.37793 .49882 Mdot
.59238 .51547 Mdot
.23855 .42855 Mdot
.71939 .32538 Mdot
.67686 .54126 Mdot
.40899 .5173 Mdot
.54052 .4535 Mdot
.40441 .67999 Mdot
.34969 .49076 Mdot
.40794 .54799 Mdot
.69971 .48021 Mdot
.42114 .56942 Mdot
.44691 .68526 Mdot
.78045 .3496 Mdot
.38849 .43498 Mdot
.52297 .73883 Mdot
.1517 .56284 Mdot
.36808 .49645 Mdot
.36779 .52023 Mdot
.4 .50734 Mdot
.41194 .47217 Mdot
.45576 .69895 Mdot
.28068 .36966 Mdot
.68977 .5428 Mdot
.58926 .49635 Mdot
.66684 .58705 Mdot
.57629 .35183 Mdot
.56848 .65788 Mdot
.51774 .67869 Mdot
.43008 .32793 Mdot
.487 .77912 Mdot
.74006 .30026 Mdot
.64798 .39428 Mdot
.3595 .63817 Mdot
.44993 .31361 Mdot
.42857 .48439 Mdot
.41595 .33297 Mdot
.58371 .39777 Mdot
.63909 .55831 Mdot
.3228 .47726 Mdot
.46726 .69793 Mdot
.51035 .69588 Mdot
.39764 .52586 Mdot
.30264 .76227 Mdot
.65991 .54203 Mdot
.70368 .54758 Mdot
.41805 .46552 Mdot
.41332 .54706 Mdot
.498 .67137 Mdot
.62157 .38026 Mdot
.45228 .23586 Mdot
.45907 .32314 Mdot
.33888 .51531 Mdot
.40992 .46896 Mdot
.77837 .35445 Mdot
.64063 .54206 Mdot
.63812 .40843 Mdot
.4217 .47921 Mdot
.74606 .58659 Mdot
.42105 .47814 Mdot
.38276 .57805 Mdot
.61837 .36989 Mdot
.44456 .51993 Mdot
.41087 .52491 Mdot
.3791 .4075 Mdot
.64977 .58193 Mdot
.50943 .67152 Mdot
.48261 .72668 Mdot
.52774 .4145 Mdot
.66432 .54697 Mdot
.40459 .4505 Mdot
.64515 .54071 Mdot
.41898 .45111 Mdot
.3954 .53046 Mdot
.68044 .54666 Mdot
.4953 .67349 Mdot
.5959 .75145 Mdot
.56475 .6686 Mdot
.41391 .47508 Mdot
.37282 .43848 Mdot
.29642 .34087 Mdot
.34201 .22815 Mdot
.35999 .5094 Mdot
.50423 .70113 Mdot
.41102 .50765 Mdot
.65162 .57694 Mdot
.46369 .33396 Mdot
.50287 .69995 Mdot
.61963 .38647 Mdot
.63869 .40332 Mdot
.71912 .65322 Mdot
.58709 .39587 Mdot
.42125 .52283 Mdot
.45933 .60602 Mdot
.52076 .6973 Mdot
.16533 .59737 Mdot
.58129 .37821 Mdot
.44548 .3527 Mdot
.40483 .47782 Mdot
.79868 .44271 Mdot
.61402 .54765 Mdot
.88741 .57434 Mdot
.68082 .24623 Mdot
.4724 .31558 Mdot
.46526 .17804 Mdot
.59146 .34706 Mdot
.39376 .53642 Mdot
.42435 .32554 Mdot
.64925 .38676 Mdot
.42008 .51869 Mdot
.3281 .45772 Mdot
.23551 .3528 Mdot
.5311 .42624 Mdot
.64782 .53822 Mdot
.61243 .35389 Mdot
.41445 .33964 Mdot
.6144 .41707 Mdot
.51112 .69737 Mdot
.38899 .50458 Mdot
.4213 .41356 Mdot
.62235 .3835 Mdot
.60849 .41507 Mdot
.38059 .44719 Mdot
.51368 .66238 Mdot
.55017 .38485 Mdot
.39599 .48071 Mdot
.29298 .54092 Mdot
.44195 .65963 Mdot
.60758 .39515 Mdot
.35738 .52111 Mdot
.36617 .38426 Mdot
.61088 .38308 Mdot
.62761 .37136 Mdot
.39746 .5272 Mdot
.44846 .34797 Mdot
.34047 .46734 Mdot
.67436 .57183 Mdot
.22642 .3425 Mdot
.64874 .57436 Mdot
.55133 .25462 Mdot
.34936 .54601 Mdot
.68206 .41911 Mdot
.50945 .7035 Mdot
.41814 .35142 Mdot
.75397 .66155 Mdot
.42752 .53314 Mdot
.4574 .8186 Mdot
.54357 .467 Mdot
.25595 .72562 Mdot
.72895 .72233 Mdot
.44721 .32349 Mdot
.66822 .55526 Mdot
.36821 .51991 Mdot
.62533 .5373 Mdot
.42621 .31157 Mdot
.21481 .46828 Mdot
.36039 .52516 Mdot
.48406 .66417 Mdot
.3647 .4539 Mdot
.49086 .65302 Mdot
.4026 .52124 Mdot
.39758 .56978 Mdot
.74416 .52234 Mdot
.39168 .26943 Mdot
.41367 .53264 Mdot
.81169 .60052 Mdot
.61672 .29028 Mdot
.45422 .32357 Mdot
.37849 .45363 Mdot
.65844 .38601 Mdot
.62995 .5746 Mdot
.48501 .57708 Mdot
.61045 .36627 Mdot
.64827 .53123 Mdot
.50141 .67753 Mdot
.57519 .37749 Mdot
.62261 .41075 Mdot
.43244 .44705 Mdot
.4207 .33441 Mdot
.63469 .55805 Mdot
.38706 .51003 Mdot
.36818 .52995 Mdot
.54162 .21268 Mdot
.58035 .28144 Mdot
.49284 .73197 Mdot
.83454 .40427 Mdot
.50078 .72316 Mdot
.45887 .313 Mdot
.61585 .36706 Mdot
.36056 .50644 Mdot
.36195 .47259 Mdot
.74259 .5386 Mdot
.48103 .63509 Mdot
.53217 .43426 Mdot
.30939 .60936 Mdot
.55607 .39049 Mdot
.32236 .35794 Mdot
.51282 .67416 Mdot
.32182 .35634 Mdot
.41447 .33844 Mdot
.45232 .79715 Mdot
.38086 .29524 Mdot
.6688 .53895 Mdot
.31769 .36153 Mdot
.47391 .68953 Mdot
.41959 .50103 Mdot
.65372 .36694 Mdot
.59393 .40005 Mdot
.50114 .66427 Mdot
.55326 .36325 Mdot
.43573 .33471 Mdot
.37117 .52489 Mdot
.6662 .25433 Mdot
.66535 .67032 Mdot
.63033 .38172 Mdot
.36321 .57194 Mdot
.64092 .56682 Mdot
.38942 .53483 Mdot
.43957 .29805 Mdot
.6463 .54958 Mdot
.61193 .26258 Mdot
.59843 .67964 Mdot
.39715 .47515 Mdot
.80699 .43393 Mdot
.65772 .54559 Mdot
.43119 .1927 Mdot
.3951 .48659 Mdot
.65595 .58521 Mdot
.44056 .54936 Mdot
.71488 .34135 Mdot
.5193 .4367 Mdot
.45042 .83876 Mdot
.53906 .44469 Mdot
.63336 .35221 Mdot
.73504 .38813 Mdot
.74959 .46434 Mdot
.62205 .54276 Mdot
.61069 .41566 Mdot
.39423 .36428 Mdot
.64363 .57506 Mdot
.39982 .44116 Mdot
.36153 .49924 Mdot
.28544 .57738 Mdot
.54681 .47967 Mdot
.63816 .41613 Mdot
.70194 .63019 Mdot
.34693 .51911 Mdot
.4288 .44729 Mdot
.36893 .47366 Mdot
.47645 .62222 Mdot
.6377 .54953 Mdot
.82991 .52465 Mdot
.66812 .54852 Mdot
.61363 .21697 Mdot
.59942 .3782 Mdot
.58675 .35788 Mdot
.37811 .50539 Mdot
.68094 .39823 Mdot
.2918 .40421 Mdot
.35562 .46757 Mdot
.65916 .43865 Mdot
.19898 .55781 Mdot
.43189 .46048 Mdot
.44825 .69495 Mdot
.31608 .52122 Mdot
.47659 .61818 Mdot
.65909 .58834 Mdot
.4411 .32047 Mdot
.42011 .36045 Mdot
.63628 .55651 Mdot
.37925 .48872 Mdot
.66874 .44305 Mdot
.3574 .48702 Mdot
.4223 .49484 Mdot
.60962 .20745 Mdot
.47113 .31354 Mdot
.59145 .36242 Mdot
.43614 .30476 Mdot
.4977 .64935 Mdot
.74088 .79909 Mdot
.45569 .33749 Mdot
.28814 .41304 Mdot
.21064 .42176 Mdot
.3147 .36143 Mdot
.51347 .69023 Mdot
.4318 .29137 Mdot
.6575 .53877 Mdot
.32263 .79919 Mdot
.319 .2389 Mdot
.70287 .5777 Mdot
.3892 .4794 Mdot
.51743 .66663 Mdot
.48528 .71207 Mdot
.66343 .59436 Mdot
.46967 .6835 Mdot
.45176 .47174 Mdot
.41915 .48508 Mdot
.62706 .53777 Mdot
.65466 .69122 Mdot
.68 .58471 Mdot
.6008 .64647 Mdot
.37486 .45274 Mdot
.5122 .68352 Mdot
.3181 .52205 Mdot
.51011 .63013 Mdot
.6395 .40835 Mdot
.42786 .47277 Mdot
.43371 .33363 Mdot
.61329 .49479 Mdot
.60382 .38953 Mdot
.77366 .38774 Mdot
.47445 .6608 Mdot
.61047 .60494 Mdot
.47048 .67458 Mdot
.50348 .63712 Mdot
.62983 .54657 Mdot
.46875 .64723 Mdot
.36816 .52151 Mdot
.66449 .40818 Mdot
.47795 .64973 Mdot
.65996 .56717 Mdot
.43766 .31611 Mdot
.49575 .68345 Mdot
.53963 .38471 Mdot
.40967 .48666 Mdot
.64312 .37672 Mdot
.75004 .51553 Mdot
.51088 .65114 Mdot
.44171 .28893 Mdot
.57108 .36597 Mdot
.42096 .33008 Mdot
.1885 .57241 Mdot
.66229 .52827 Mdot
.49192 .18777 Mdot
.37175 .38505 Mdot
.4706 .7045 Mdot
.74729 .51812 Mdot
.36354 .5062 Mdot
.40946 .48403 Mdot
.41633 .31055 Mdot
.48478 .71208 Mdot
.36448 .79891 Mdot
.45871 .74671 Mdot
.60822 .67555 Mdot
.66125 .52626 Mdot
.82034 .50496 Mdot
.57997 .6341 Mdot
.17785 .47426 Mdot
.44319 .48653 Mdot
.60254 .34627 Mdot
.37194 .48918 Mdot
.74457 .67206 Mdot
.46498 .31262 Mdot
.47257 .26468 Mdot
.36395 .55113 Mdot
.57881 .3674 Mdot
.40222 .4978 Mdot
.5038 .54875 Mdot
.339 .55297 Mdot
.45542 .34697 Mdot
.67592 .49822 Mdot
.46001 .69693 Mdot
.44549 .31036 Mdot
.61509 .40689 Mdot
.30501 .38787 Mdot
.41178 .53117 Mdot
.43425 .52067 Mdot
.55736 .39332 Mdot
.48025 .66569 Mdot
.62827 .35266 Mdot
.66316 .58645 Mdot
.43949 .32981 Mdot
.40713 .47495 Mdot
.37919 .5504 Mdot
.70889 .42857 Mdot
.63278 .55699 Mdot
.55603 .38126 Mdot
.67559 .55573 Mdot
.63626 .35144 Mdot
.35613 .4475 Mdot
.58491 .358 Mdot
.39514 .54007 Mdot
.77262 .61002 Mdot
.60235 .20587 Mdot
.31074 .69357 Mdot
.57358 .3685 Mdot
.35016 .35205 Mdot
.65774 .57504 Mdot
.67155 .57292 Mdot
.24111 .50757 Mdot
.47045 .50962 Mdot
.58527 .23807 Mdot
.58466 .78888 Mdot
.6672 .58626 Mdot
.64775 .57014 Mdot
.64594 .38107 Mdot
.47277 .64463 Mdot
.51413 .65003 Mdot
.57324 .35229 Mdot
.32591 .27872 Mdot
.48023 .67986 Mdot
.44116 .8115 Mdot
.58761 .24711 Mdot
.42486 .43721 Mdot
.68394 .60963 Mdot
.43617 .32597 Mdot
.33811 .27742 Mdot
.50739 .5606 Mdot
.35957 .51705 Mdot
.78621 .36568 Mdot
.61678 .37775 Mdot
.2657 .36628 Mdot
.5286 .82233 Mdot
.36208 .52765 Mdot
.39141 .49181 Mdot
.37422 .48226 Mdot
.46674 .3019 Mdot
.41915 .61341 Mdot
.367 .52724 Mdot
.32549 .27619 Mdot
.34611 .52032 Mdot
.42323 .38347 Mdot
.43942 .30356 Mdot
.30383 .44679 Mdot
.70393 .4951 Mdot
.69738 .29139 Mdot
.31637 .46189 Mdot
.66553 .58423 Mdot
.59103 .47005 Mdot
.64616 .58275 Mdot
.32648 .73062 Mdot
.37698 .29819 Mdot
.45675 .71513 Mdot
.36217 .51765 Mdot
.59351 .39387 Mdot
.48801 .71161 Mdot
.73418 .42249 Mdot
.57294 .91507 Mdot
.65055 .58773 Mdot
.18846 .3294 Mdot
.67535 .56552 Mdot
.61634 .41167 Mdot
.49911 .6707 Mdot
.38894 .70394 Mdot
.58912 .52056 Mdot
.4948 .68673 Mdot
.59045 .7403 Mdot
.5286 .68764 Mdot
.33429 .359 Mdot
.51431 .70708 Mdot
.66005 .57009 Mdot
.62306 .58963 Mdot
.40081 .41583 Mdot
.37227 .50954 Mdot
.53872 .55622 Mdot
.31528 .39732 Mdot
.36776 .50835 Mdot
.60135 .3933 Mdot
.42047 .18944 Mdot
.52948 .40628 Mdot
.46103 .67147 Mdot
.69173 .5744 Mdot
.39386 .49345 Mdot
.41644 .47268 Mdot
.41645 .5222 Mdot
.8418 .40871 Mdot
.42555 .80221 Mdot
.40756 .5248 Mdot
.33505 .5038 Mdot
.5752 .37456 Mdot
.43224 .27771 Mdot
.72514 .69955 Mdot
.4241 .38976 Mdot
.34407 .49701 Mdot
.44734 .30594 Mdot
.47016 .33942 Mdot
.42015 .51949 Mdot
.68811 .30032 Mdot
.68383 .375 Mdot
.38751 .51023 Mdot
.46629 .44276 Mdot
.76186 .45604 Mdot
.60916 .41461 Mdot
.61913 .3839 Mdot
.4567 .69747 Mdot
.59567 .39838 Mdot
.58107 .39784 Mdot
.38889 .68147 Mdot
.56819 .46701 Mdot
.62668 .51108 Mdot
.46463 .30768 Mdot
.35922 .47585 Mdot
.51123 .71828 Mdot
.74078 .55399 Mdot
.63374 .56623 Mdot
.49216 .7015 Mdot
.6326 .57822 Mdot
.47311 .30564 Mdot
.2484 .35332 Mdot
.59545 .40228 Mdot
.67561 .5818 Mdot
.5982 .67805 Mdot
.44525 .30481 Mdot
.64383 .53484 Mdot
.68497 .42397 Mdot
.40772 .44213 Mdot
.42162 .75738 Mdot
.36035 .46202 Mdot
.3064 .77268 Mdot
.64516 .53514 Mdot
.73208 .52354 Mdot
.38266 .4958 Mdot
.6068 .38408 Mdot
.41261 .56761 Mdot
.34648 .49261 Mdot
.62247 .39005 Mdot
.41959 .50615 Mdot
.42699 .30466 Mdot
.45315 .62391 Mdot
.58363 .47396 Mdot
.61599 .16567 Mdot
.41877 .32951 Mdot
.72719 .42062 Mdot
.36001 .51088 Mdot
.20111 .53644 Mdot
.49432 .68398 Mdot
.38987 .54559 Mdot
.27293 .4584 Mdot
.48349 .64361 Mdot
.50125 .69481 Mdot
.40024 .45691 Mdot
.66966 .54126 Mdot
.60823 .3902 Mdot
.43998 .30491 Mdot
.17324 .55481 Mdot
.38121 .47212 Mdot
.41153 .50195 Mdot
.44845 .31233 Mdot
.64765 .57227 Mdot
.41441 .46767 Mdot
.77516 .53471 Mdot
.21673 .69175 Mdot
.62857 .5622 Mdot
.36629 .44696 Mdot
.44656 .7548 Mdot
.48944 .61419 Mdot
.24861 .27514 Mdot
.4289 .256 Mdot
.59037 .35991 Mdot
.42964 .56645 Mdot
.82414 .68551 Mdot
.43943 .32008 Mdot
.69298 .27321 Mdot
.42349 .49465 Mdot
.40465 .5117 Mdot
.47966 .70467 Mdot
.39377 .44795 Mdot
.49215 .64068 Mdot
.56947 .1548 Mdot
.80158 .37885 Mdot
.48172 .65808 Mdot
.46553 .69827 Mdot
.28115 .43253 Mdot
.72926 .69409 Mdot
.50341 .66692 Mdot
.33454 .46647 Mdot
.36871 .78103 Mdot
.36249 .41129 Mdot
.4153 .31273 Mdot
.75343 .49939 Mdot
.53521 .65938 Mdot
.51406 .36685 Mdot
.58139 .77443 Mdot
.54004 .67409 Mdot
.67344 .35077 Mdot
.6772 .56958 Mdot
.34979 .51751 Mdot
.59017 .39812 Mdot
.57781 .35894 Mdot
.34747 .55635 Mdot
.3547 .48273 Mdot
.48613 .64987 Mdot
.46987 .31906 Mdot
.62212 .56052 Mdot
.41354 .509 Mdot
.53331 .40821 Mdot
.45692 .33218 Mdot
.46484 .66497 Mdot
.24444 .48809 Mdot
.45014 .35138 Mdot
.31954 .53723 Mdot
.38503 .52 Mdot
.38558 .44526 Mdot
.41345 .40065 Mdot
.68582 .55016 Mdot
.76294 .53305 Mdot
.35117 .45618 Mdot
.72186 .30664 Mdot
.49057 .43589 Mdot
.4425 .53135 Mdot
.47512 .67946 Mdot
.61364 .54541 Mdot
.65385 .39666 Mdot
.25636 .42224 Mdot
.39047 .47321 Mdot
.41914 .79745 Mdot
.30514 .59631 Mdot
.65193 .39562 Mdot
.48127 .63209 Mdot
.43037 .32174 Mdot
.35474 .47064 Mdot
.34916 .75775 Mdot
.36571 .4987 Mdot
.39246 .38556 Mdot
.62387 .37288 Mdot
.67896 .56678 Mdot
.24599 .71804 Mdot
.57887 .35861 Mdot
.50437 .69221 Mdot
.46516 .85064 Mdot
.52007 .6864 Mdot
.45649 .67667 Mdot
.38465 .77082 Mdot
.68608 .55823 Mdot
.83896 .66522 Mdot
.30155 .24388 Mdot
.39755 .55722 Mdot
.65952 .57759 Mdot
.49499 .66076 Mdot
.38789 .53466 Mdot
.50199 .71389 Mdot
.46481 .64352 Mdot
.41291 .43673 Mdot
.39529 .52016 Mdot
.56659 .65063 Mdot
.48246 .82139 Mdot
.42968 .31673 Mdot
.5102 .66061 Mdot
.27016 .51436 Mdot
.37997 .53673 Mdot
.37851 .49933 Mdot
.7539 .43537 Mdot
.44882 .34886 Mdot
.54387 .60232 Mdot
.42245 .48405 Mdot
.81202 .40782 Mdot
.31461 .51845 Mdot
.45372 .69683 Mdot
.62873 .55982 Mdot
.68691 .28731 Mdot
.73127 .57131 Mdot
.48461 .63552 Mdot
.45104 .29698 Mdot
.48209 .72749 Mdot
.29079 .41195 Mdot
.68545 .57376 Mdot
.49911 .70416 Mdot
.54736 .45593 Mdot
.65229 .55395 Mdot
.64882 .53465 Mdot
.33058 .75194 Mdot
.55998 .38196 Mdot
.45159 .29205 Mdot
.63738 .56205 Mdot
.30686 .56341 Mdot
.66568 .56373 Mdot
.26844 .54153 Mdot
.34386 .47093 Mdot
.28267 .31671 Mdot
.57741 .585 Mdot
.44619 .44182 Mdot
.68018 .53895 Mdot
.42759 .31074 Mdot
.40636 .46102 Mdot
.46962 .68705 Mdot
.45048 .33961 Mdot
.6851 .6027 Mdot
.62174 .36426 Mdot
.46886 .67261 Mdot
.68716 .53726 Mdot
.51118 .66559 Mdot
.24984 .40512 Mdot
.21727 .35746 Mdot
.78772 .51202 Mdot
.58567 .52084 Mdot
.41856 .51794 Mdot
.63791 .76009 Mdot
.40774 .43084 Mdot
.35221 .48724 Mdot
.60729 .39439 Mdot
.27595 .34529 Mdot
.49556 .67247 Mdot
.25145 .72654 Mdot
.67604 .57838 Mdot
.78773 .35684 Mdot
.44536 .71679 Mdot
.39062 .54671 Mdot
.48068 .64782 Mdot
.51799 .69643 Mdot
.28385 .67023 Mdot
.61753 .41943 Mdot
.3451 .44255 Mdot
.37761 .42438 Mdot
.44185 .50596 Mdot
.65023 .53519 Mdot
.76569 .37616 Mdot
.61456 .34861 Mdot
.21817 .33365 Mdot
.62697 .37591 Mdot
.63404 .4622 Mdot
.46594 .65297 Mdot
.45297 .34201 Mdot
.37996 .50159 Mdot
.44988 .72797 Mdot
.48753 .6349 Mdot
.47994 .33185 Mdot
.43511 .33832 Mdot
.73554 .36837 Mdot
.68088 .54649 Mdot
.41032 .53785 Mdot
.35866 .52175 Mdot
.38687 .45269 Mdot
.35527 .4616 Mdot
.65167 .58833 Mdot
.41547 .45598 Mdot
.62358 .58174 Mdot
.30122 .56202 Mdot
.79566 .37889 Mdot
.56415 .46513 Mdot
.46776 .57062 Mdot
.46405 .68253 Mdot
.31284 .56481 Mdot
.31749 .53622 Mdot
.56957 .19251 Mdot
.22134 .64481 Mdot
.43082 .46376 Mdot
.64866 .38003 Mdot
.46726 .53024 Mdot
.57445 .39009 Mdot
.25328 .23694 Mdot
.70599 .4389 Mdot
.45414 .83114 Mdot
.37719 .53261 Mdot
.75681 .43816 Mdot
.4237 .58674 Mdot
.39476 .42655 Mdot
.73234 .44521 Mdot
.73552 .60761 Mdot
.61871 .71519 Mdot
.46481 .34509 Mdot
.40507 .48488 Mdot
.52445 .69155 Mdot
.36841 .52316 Mdot
.37463 .49516 Mdot
.42427 .49521 Mdot
.69268 .54819 Mdot
.32615 .47217 Mdot
.37094 .44783 Mdot
.58548 .30839 Mdot
.34606 .32959 Mdot
.61238 .35303 Mdot
.2354 .50151 Mdot
.45504 .33647 Mdot
.47845 .65293 Mdot
.55395 .7481 Mdot
.66916 .5388 Mdot
.27598 .65358 Mdot
.36773 .45093 Mdot
.58044 .66563 Mdot
.68536 .53461 Mdot
.43863 .33227 Mdot
.65456 .36456 Mdot
.41761 .83236 Mdot
.59006 .3904 Mdot
.54806 .45968 Mdot
.60146 .38559 Mdot
.30346 .49035 Mdot
.48753 .64966 Mdot
.42457 .50399 Mdot
.6398 .56291 Mdot
.61429 .3953 Mdot
.30901 .32972 Mdot
.36926 .47525 Mdot
.57903 .37481 Mdot
.42489 .50081 Mdot
.25591 .33714 Mdot
.49669 .20665 Mdot
.5873 .40327 Mdot
.60937 .54688 Mdot
.65527 .55881 Mdot
.452 .34588 Mdot
.46999 .66145 Mdot
.47892 .70231 Mdot
.64855 .54957 Mdot
.34835 .21695 Mdot
.34513 .49708 Mdot
.38372 .53518 Mdot
.72413 .30636 Mdot
.36951 .51595 Mdot
.32287 .37662 Mdot
.53619 .44959 Mdot
.46313 .67258 Mdot
.39745 .53239 Mdot
.41387 .47084 Mdot
.40124 .4765 Mdot
.24379 .40693 Mdot
.6253 .38123 Mdot
.34097 .50213 Mdot
.43047 .33776 Mdot
.66326 .38724 Mdot
.38595 .53665 Mdot
.44092 .51017 Mdot
.48083 .70285 Mdot
.78688 .33603 Mdot
.67902 .55777 Mdot
.62291 .40646 Mdot
.58106 .36067 Mdot
.7553 .49712 Mdot
.50552 .74734 Mdot
.53386 .44633 Mdot
.20677 .35609 Mdot
.72138 .51025 Mdot
.45358 .31604 Mdot
.63094 .47246 Mdot
.47988 .41714 Mdot
.64339 .39583 Mdot
.63878 .58485 Mdot
.34824 .4615 Mdot
.34246 .49235 Mdot
.66913 .23334 Mdot
.39248 .54774 Mdot
.43263 .32275 Mdot
.63584 .5907 Mdot
.47536 .6899 Mdot
.43657 .33194 Mdot
.67302 .5681 Mdot
.47881 .66755 Mdot
.40849 .44036 Mdot
.39655 .4371 Mdot
.49345 .69948 Mdot
.48503 .71047 Mdot
.38537 .51347 Mdot
.67198 .38086 Mdot
.45676 .6949 Mdot
.51073 .69132 Mdot
.59353 .40185 Mdot
.60022 .40119 Mdot
.44006 .4562 Mdot
.66484 .57463 Mdot
.39765 .44263 Mdot
.57985 .38481 Mdot
.46828 .32805 Mdot
.49241 .67824 Mdot
.41553 .47629 Mdot
.4172 .5023 Mdot
.44303 .30565 Mdot
.46998 .33478 Mdot
.43767 .3365 Mdot
.64742 .59654 Mdot
.37861 .45839 Mdot
.50372 .67329 Mdot
.68357 .55499 Mdot
.47014 .33967 Mdot
.42286 .34471 Mdot
.55385 .3514 Mdot
.35838 .50629 Mdot
.53869 .37171 Mdot
.73687 .79803 Mdot
.37265 .36188 Mdot
.6506 .40049 Mdot
.55867 .38978 Mdot
.31475 .34742 Mdot
.67762 .38605 Mdot
.65483 .54256 Mdot
.38638 .36842 Mdot
.41864 .3531 Mdot
.42664 .47065 Mdot
.37053 .44024 Mdot
.39999 .42065 Mdot
.44646 .33419 Mdot
.26106 .40542 Mdot
.50823 .70695 Mdot
.25374 .58084 Mdot
.45381 .33703 Mdot
.60458 .41449 Mdot
.55707 .3758 Mdot
.62692 .3753 Mdot
.36878 .44295 Mdot
.3054 .68394 Mdot
.29012 .51508 Mdot
.63542 .76823 Mdot
.6632 .53296 Mdot
.45761 .71817 Mdot
.19193 .55717 Mdot
.49781 .69622 Mdot
.56351 .36707 Mdot
.45157 .3335 Mdot
.499 .70608 Mdot
.63688 .57646 Mdot
.64621 .56819 Mdot
.62846 .37956 Mdot
.60381 .37671 Mdot
.64176 .38117 Mdot
.45756 .66159 Mdot
.46807 .64864 Mdot
.38333 .46991 Mdot
.48676 .6884 Mdot
.72573 .26767 Mdot
.46515 .29715 Mdot
.55316 .38179 Mdot
.66961 .55599 Mdot
.48876 .65289 Mdot
.36688 .47248 Mdot
.54231 .4253 Mdot
.70772 .65554 Mdot
.41979 .32376 Mdot
.52366 .209 Mdot
.2446 .24954 Mdot
.40379 .54363 Mdot
.64524 .53867 Mdot
.65793 .25194 Mdot
.37507 .48033 Mdot
.61149 .36908 Mdot
.77161 .62457 Mdot
.65795 .37521 Mdot
.4016 .44228 Mdot
.40254 .54889 Mdot
.63113 .54004 Mdot
.20466 .42996 Mdot
.37721 .46789 Mdot
.59614 .6231 Mdot
.6881 .58136 Mdot
.59253 .34951 Mdot
.22455 .70579 Mdot
.77431 .48486 Mdot
.33201 .28006 Mdot
.60006 .40392 Mdot
.35753 .49469 Mdot
.61075 .40218 Mdot
.42097 .32269 Mdot
.62497 .40161 Mdot
.44447 .68329 Mdot
.6137 .3517 Mdot
.41066 .50269 Mdot
.50427 .66596 Mdot
.65858 .54527 Mdot
.77204 .33674 Mdot
.57964 .30107 Mdot
.60674 .38335 Mdot
.60596 .4093 Mdot
.40645 .52922 Mdot
.55691 .61658 Mdot
.39103 .56421 Mdot
.37786 .53441 Mdot
.66862 .58764 Mdot
.47637 .6495 Mdot
.68188 .53681 Mdot
.35966 .53697 Mdot
.7853 .55945 Mdot
.67537 .55083 Mdot
.57681 .67036 Mdot
.45068 .31381 Mdot
.50957 .51463 Mdot
.35955 .47308 Mdot
.63742 .56721 Mdot
.37783 .45785 Mdot
.49659 .71732 Mdot
.53572 .4986 Mdot
.74927 .55974 Mdot
.64128 .56184 Mdot
.34578 .7903 Mdot
.59493 .33905 Mdot
.31715 .50667 Mdot
.65273 .58493 Mdot
.27379 .46072 Mdot
.61968 .41155 Mdot
.45812 .32119 Mdot
.46919 .34057 Mdot
.42287 .33522 Mdot
.43171 .51474 Mdot
.31126 .4919 Mdot
.442 .29435 Mdot
.62772 .56609 Mdot
.45861 .34501 Mdot
.4992 .76028 Mdot
.35628 .79749 Mdot
.46288 .30918 Mdot
.39524 .48385 Mdot
.38501 .41178 Mdot
.34173 .32794 Mdot
.54767 .3916 Mdot
.46242 .82169 Mdot
.46366 .58495 Mdot
.37122 .50708 Mdot
.49528 .61075 Mdot
.5042 .70848 Mdot
.65265 .25507 Mdot
.32867 .391 Mdot
.664 .29225 Mdot
.46214 .69488 Mdot
.74193 .54083 Mdot
.46562 .66685 Mdot
.40232 .54139 Mdot
.39109 .53116 Mdot
.51417 .6483 Mdot
.77837 .38141 Mdot
.70568 .40072 Mdot
.20215 .65045 Mdot
.51293 .68793 Mdot
.64877 .58136 Mdot
.65985 .59063 Mdot
.66665 .53462 Mdot
.57333 .24421 Mdot
.50848 .6508 Mdot
.38517 .46189 Mdot
.57345 .37484 Mdot
.34498 .50486 Mdot
.64423 .55491 Mdot
.25717 .73173 Mdot
.47701 .69829 Mdot
.38973 .50896 Mdot
.33843 .23328 Mdot
.60028 .37047 Mdot
.45169 .30662 Mdot
.24104 .35701 Mdot
.62001 .26304 Mdot
.68767 .56378 Mdot
.52056 .66633 Mdot
.68716 .4982 Mdot
.57173 .68324 Mdot
.44252 .4724 Mdot
.45078 .48465 Mdot
.17348 .50922 Mdot
.6041 .26121 Mdot
.4269 .50353 Mdot
.62634 .40734 Mdot
.74312 .53816 Mdot
.41474 .48175 Mdot
.51492 .68909 Mdot
.45648 .35412 Mdot
.43429 .34294 Mdot
.35087 .44307 Mdot
.59452 .51196 Mdot
.50569 .47402 Mdot
.40607 .45047 Mdot
.31845 .53611 Mdot
.5648 .36935 Mdot
.7116 .50402 Mdot
.7504 .32297 Mdot
.45651 .29859 Mdot
.42356 .48206 Mdot
.6271 .73258 Mdot
.46974 .64098 Mdot
.63722 .36073 Mdot
.68737 .57161 Mdot
.23733 .42338 Mdot
.6037 .34853 Mdot
.41578 .48231 Mdot
.4144 .46844 Mdot
.64245 .53501 Mdot
.45362 .69678 Mdot
.44819 .33314 Mdot
.57326 .36731 Mdot
.45449 .29725 Mdot
.48999 .64249 Mdot
.47704 .69543 Mdot
.35416 .41423 Mdot
.31877 .48316 Mdot
.61842 .38526 Mdot
.36113 .5357 Mdot
.55557 .40199 Mdot
.20196 .4282 Mdot
.65709 .52377 Mdot
.40241 .545 Mdot
.46046 .63479 Mdot
.63819 .55815 Mdot
.39982 .51335 Mdot
.16335 .53019 Mdot
.36988 .53602 Mdot
.73173 .56753 Mdot
.79675 .53701 Mdot
.42653 .32395 Mdot
.2245 .56846 Mdot
.54756 .65638 Mdot
.3732 .51925 Mdot
.61631 .35953 Mdot
.40559 .56754 Mdot
.66496 .54039 Mdot
.46193 .66501 Mdot
.25694 .26188 Mdot
.66324 .56367 Mdot
.37466 .52872 Mdot
.43914 .33071 Mdot
.52141 .68374 Mdot
.59976 .47184 Mdot
.71263 .308 Mdot
.33729 .54167 Mdot
.33161 .47097 Mdot
.40418 .44443 Mdot
.76109 .67383 Mdot
.62562 .40532 Mdot
.49246 .65652 Mdot
.6508 .53551 Mdot
.64749 .54761 Mdot
.62433 .37831 Mdot
.62019 .70342 Mdot
.51098 .51186 Mdot
.78244 .73595 Mdot
.62277 .39259 Mdot
.44018 .28838 Mdot
.56906 .6155 Mdot
.61907 .35896 Mdot
.5817 .37446 Mdot
.56514 .37007 Mdot
.66836 .50771 Mdot
.4797 .67069 Mdot
.41783 .50332 Mdot
.47882 .71923 Mdot
.35505 .49626 Mdot
.49369 .45423 Mdot
.63622 .55847 Mdot
.45997 .66857 Mdot
.16779 .52854 Mdot
.43998 .61101 Mdot
.38371 .48371 Mdot
.19043 .54101 Mdot
.36501 .55371 Mdot
.29675 .37683 Mdot
.32927 .51979 Mdot
.60183 .38108 Mdot
.43219 .57253 Mdot
.4189 .54916 Mdot
.75161 .30643 Mdot
.67075 .55775 Mdot
.62304 .41206 Mdot
.42762 .51398 Mdot
.31486 .52213 Mdot
.52063 .65443 Mdot
.50276 .70336 Mdot
.44941 .29431 Mdot
.39279 .26591 Mdot
.66114 .54511 Mdot
.22737 .34969 Mdot
.37584 .51268 Mdot
.80387 .46933 Mdot
.2354 .58629 Mdot
.39912 .51226 Mdot
.3782 .78711 Mdot
.29278 .67146 Mdot
.35565 .47214 Mdot
.28698 .44923 Mdot
.65051 .57257 Mdot
.78518 .55294 Mdot
.33261 .4996 Mdot
.60909 .36737 Mdot
.46867 .65081 Mdot
.51589 .69266 Mdot
.43417 .29853 Mdot
.56234 .17632 Mdot
.67479 .53349 Mdot
.46166 .66274 Mdot
.3675 .47853 Mdot
.687 .5603 Mdot
.58543 .39387 Mdot
.36617 .54365 Mdot
.33729 .37955 Mdot
.48384 .68848 Mdot
.33513 .50768 Mdot
.66757 .6455 Mdot
.3577 .27415 Mdot
.62492 .81482 Mdot
.66824 .53607 Mdot
.46212 .3343 Mdot
.42097 .55581 Mdot
.24955 .31904 Mdot
.43282 .46791 Mdot
.27747 .32471 Mdot
.50609 .75199 Mdot
.46149 .33643 Mdot
.38604 .49202 Mdot
.40008 .47094 Mdot
.57279 .57405 Mdot
.47075 .32532 Mdot
.35569 .52086 Mdot
.44117 .58413 Mdot
.48152 .66547 Mdot
.66213 .36997 Mdot
.48071 .68513 Mdot
.38963 .48004 Mdot
.32612 .45895 Mdot
.48212 .70706 Mdot
.18961 .38326 Mdot
.42786 .36851 Mdot
.67943 .55425 Mdot
.3151 .48761 Mdot
.34197 .47009 Mdot
.81374 .62269 Mdot
.63857 .40866 Mdot
.69692 .7167 Mdot
.53588 .3894 Mdot
.61026 .74705 Mdot
.77533 .47972 Mdot
.45434 .84736 Mdot
.78291 .36019 Mdot
.37889 .4246 Mdot
.48353 .5199 Mdot
.28423 .47433 Mdot
.68581 .54367 Mdot
.3825 .62353 Mdot
.37169 .50912 Mdot
.37297 .49253 Mdot
.64318 .36565 Mdot
.59585 .69608 Mdot
.68554 .29595 Mdot
.59474 .49523 Mdot
.44901 .32941 Mdot
.50313 .65355 Mdot
.4043 .52095 Mdot
.50714 .4029 Mdot
.61928 .354 Mdot
.80106 .45648 Mdot
.38913 .50316 Mdot
.56182 .19374 Mdot
.70156 .52017 Mdot
.68431 .54863 Mdot
.59608 .35654 Mdot
.64092 .27695 Mdot
.35416 .50317 Mdot
.67725 .58618 Mdot
.37246 .46808 Mdot
.62657 .32341 Mdot
.37307 .54158 Mdot
.4638 .31677 Mdot
.42204 .50879 Mdot
.59804 .48508 Mdot
.5553 .83513 Mdot
.39827 .37994 Mdot
.51669 .66648 Mdot
.56153 .39861 Mdot
.62352 .38184 Mdot
.49373 .70756 Mdot
.6195 .38213 Mdot
.26598 .62176 Mdot
.37122 .69816 Mdot
.45091 .32506 Mdot
.31552 .52935 Mdot
.45608 .30151 Mdot
.64014 .40823 Mdot
.36406 .50413 Mdot
.19721 .3671 Mdot
.61648 .3907 Mdot
.80975 .54913 Mdot
.66646 .55862 Mdot
.63254 .41045 Mdot
.34378 .51789 Mdot
.66996 .48024 Mdot
.58933 .35539 Mdot
.74166 .54711 Mdot
.39895 .47557 Mdot
.47236 .69219 Mdot
.40445 .47101 Mdot
.33209 .52722 Mdot
.63896 .35193 Mdot
.35676 .45689 Mdot
.67291 .56824 Mdot
.45302 .68144 Mdot
.39581 .8146 Mdot
.73357 .5663 Mdot
.35875 .51821 Mdot
.36969 .47906 Mdot
.52327 .68743 Mdot
.33768 .49487 Mdot
.65278 .58822 Mdot
.90031 .46195 Mdot
.45079 .31326 Mdot
.59592 .40873 Mdot
.77407 .49434 Mdot
.42951 .45796 Mdot
.40931 .45694 Mdot
.17167 .56034 Mdot
.78042 .50869 Mdot
.66285 .58281 Mdot
.39067 .56743 Mdot
.57116 .37358 Mdot
.4382 .32908 Mdot
.6245 .55931 Mdot
.3865 .44528 Mdot
.38066 .49836 Mdot
.46221 .33258 Mdot
.3382 .76243 Mdot
.63175 .25699 Mdot
.65338 .5314 Mdot
.4348 .57121 Mdot
.56302 .41584 Mdot
.34566 .49516 Mdot
.57436 .23989 Mdot
.50371 .70004 Mdot
.68214 .5759 Mdot
.67438 .74291 Mdot
.42634 .48006 Mdot
.63127 .56441 Mdot
.66403 .54679 Mdot
.4115 .55604 Mdot
.49366 .62296 Mdot
.4545 .66016 Mdot
.5095 .66262 Mdot
.74389 .27414 Mdot
.34351 .28797 Mdot
.64169 .38087 Mdot
.64896 .57229 Mdot
.5733 .39221 Mdot
.45118 .28565 Mdot
.50094 .42434 Mdot
.59004 .40536 Mdot
.48964 .71238 Mdot
.55045 .39009 Mdot
.40265 .47352 Mdot
.65653 .54433 Mdot
.64353 .39401 Mdot
.42789 .51628 Mdot
.54924 .6245 Mdot
.64146 .31366 Mdot
.43775 .35241 Mdot
.45473 .35782 Mdot
.39485 .52885 Mdot
.6548 .39517 Mdot
.38394 .51142 Mdot
.6165 .55462 Mdot
.573 .62198 Mdot
.43309 .4823 Mdot
.60943 .38199 Mdot
.51644 .6163 Mdot
.62005 .26333 Mdot
.37872 .56257 Mdot
.39419 .48453 Mdot
.34974 .49467 Mdot
.37187 .46748 Mdot
.59627 .72184 Mdot
.6567 .52533 Mdot
.53227 .58852 Mdot
.74343 .51662 Mdot
.49089 .69341 Mdot
.46696 .6339 Mdot
.53119 .23161 Mdot
.679 .35259 Mdot
.66238 .57592 Mdot
.34974 .48419 Mdot
.74152 .5612 Mdot
.26843 .7436 Mdot
.18018 .39604 Mdot
.48108 .31424 Mdot
.6526 .38666 Mdot
.5142 .65422 Mdot
.61308 .35499 Mdot
.36016 .4962 Mdot
.42429 .55348 Mdot
.44697 .85275 Mdot
.61866 .59001 Mdot
.45035 .33415 Mdot
.3514 .4946 Mdot
.34445 .27889 Mdot
.5748 .37447 Mdot
.55969 .37596 Mdot
.35693 .52426 Mdot
.44723 .6701 Mdot
.75405 .72085 Mdot
.68414 .54644 Mdot
.46806 .58096 Mdot
.3805 .58933 Mdot
.68281 .62747 Mdot
.63911 .55225 Mdot
.64368 .29715 Mdot
.65455 .3856 Mdot
.24854 .6481 Mdot
.48879 .6965 Mdot
.45275 .33548 Mdot
.44884 .51389 Mdot
.47081 .70048 Mdot
.63259 .35144 Mdot
.4625 .68055 Mdot
.42148 .51481 Mdot
.67327 .5306 Mdot
.59596 .35873 Mdot
.60837 .55364 Mdot
.4881 .62297 Mdot
.43663 .30088 Mdot
.55488 .57897 Mdot
.40542 .66004 Mdot
.28819 .66643 Mdot
.34147 .49858 Mdot
.50361 .39855 Mdot
.38371 .45841 Mdot
.51876 .64929 Mdot
.36869 .47086 Mdot
.48857 .60917 Mdot
.61022 .35858 Mdot
.33471 .50333 Mdot
.40976 .44868 Mdot
.33542 .60441 Mdot
.3947 .49751 Mdot
.32891 .50418 Mdot
.35272 .47464 Mdot
.46542 .73032 Mdot
.34159 .5567 Mdot
.47525 .67655 Mdot
.70902 .31272 Mdot
.58366 .37489 Mdot
.45929 .35368 Mdot
.43711 .34722 Mdot
.29063 .30959 Mdot
.40416 .33821 Mdot
.60814 .7038 Mdot
.48483 .67699 Mdot
.67365 .55454 Mdot
.36735 .46826 Mdot
.59443 .78631 Mdot
.75622 .47021 Mdot
.56977 .37618 Mdot
.73339 .56567 Mdot
.45557 .5096 Mdot
.7642 .67246 Mdot
.34402 .52079 Mdot
.66283 .22387 Mdot
.37786 .41855 Mdot
.38251 .54275 Mdot
.56052 .36765 Mdot
.41723 .37337 Mdot
.34171 .51032 Mdot
.52162 .65653 Mdot
.46054 .32668 Mdot
.4334 .63952 Mdot
.62029 .44195 Mdot
.65327 .30196 Mdot
.37855 .6532 Mdot
.37473 .46062 Mdot
.59702 .3596 Mdot
.46938 .67143 Mdot
.76097 .3325 Mdot
.6835 .55737 Mdot
.5979 .5241 Mdot
.28555 .53728 Mdot
.19084 .49798 Mdot
.45644 .33272 Mdot
.33197 .75496 Mdot
.41125 .50407 Mdot
.5548 .25493 Mdot
.41499 .43937 Mdot
.27247 .74635 Mdot
.43402 .29027 Mdot
.45104 .6545 Mdot
.65065 .58201 Mdot
.49048 .7182 Mdot
.30427 .68987 Mdot
.65718 .61995 Mdot
.54968 .52498 Mdot
.58482 .38643 Mdot
.53863 .58819 Mdot
.50053 .66008 Mdot
.41815 .47057 Mdot
.76779 .75789 Mdot
.50847 .69456 Mdot
.49038 .63837 Mdot
.2085 .40658 Mdot
.19953 .41668 Mdot
.44619 .54431 Mdot
.4689 .70283 Mdot
.58587 .38492 Mdot
.43096 .30985 Mdot
.40019 .46567 Mdot
.38567 .46869 Mdot
.47854 .70343 Mdot
.55927 .37121 Mdot
.45819 .57099 Mdot
.60187 .37767 Mdot
.4802 .66377 Mdot
.59044 .37076 Mdot
.75368 .53673 Mdot
.64361 .39845 Mdot
.34037 .47412 Mdot
.36813 .47012 Mdot
.57985 .42104 Mdot
.47703 .69519 Mdot
.40288 .45141 Mdot
.41793 .51211 Mdot
.50297 .67009 Mdot
.53246 .40197 Mdot
.45956 .75562 Mdot
.36105 .51411 Mdot
.4078 .48827 Mdot
.46385 .333 Mdot
.48693 .39912 Mdot
.4543 .2057 Mdot
.40605 .46081 Mdot
.45831 .29291 Mdot
.4577 .66321 Mdot
.3877 .51342 Mdot
.51861 .76147 Mdot
.74571 .54069 Mdot
.42591 .48199 Mdot
.62369 .41072 Mdot
.43471 .51698 Mdot
.67281 .78222 Mdot
.37377 .53401 Mdot
.49683 .66479 Mdot
.4795 .64343 Mdot
.22061 .40239 Mdot
.50677 .68895 Mdot
.59458 .40022 Mdot
.64909 .55451 Mdot
.30069 .76818 Mdot
.5842 .3929 Mdot
.41621 .54507 Mdot
.29996 .24455 Mdot
.34154 .52591 Mdot
.43089 .50267 Mdot
.7893 .63694 Mdot
.58289 .39083 Mdot
.48626 .6471 Mdot
.58868 .54717 Mdot
.36069 .43023 Mdot
.68713 .56657 Mdot
.42281 .55037 Mdot
.35582 .45409 Mdot
.79588 .52842 Mdot
.73813 .64766 Mdot
.63226 .5875 Mdot
.42806 .43759 Mdot
.40589 .45998 Mdot
.54039 .34517 Mdot
.36536 .47451 Mdot
.45548 .29947 Mdot
.49989 .64536 Mdot
.63686 .36583 Mdot
.44098 .30877 Mdot
.37322 .51478 Mdot
.445 .3349 Mdot
.64281 .37657 Mdot
.67861 .58307 Mdot
.35905 .50155 Mdot
.41554 .31051 Mdot
.44784 .33035 Mdot
.38742 .45563 Mdot
.46344 .66058 Mdot
.44226 .42946 Mdot
.39103 .51427 Mdot
.41999 .48295 Mdot
.47844 .70183 Mdot
.16454 .3984 Mdot
.37287 .53553 Mdot
.59926 .34057 Mdot
.48939 .63621 Mdot
.71331 .59469 Mdot
.6434 .37047 Mdot
.35347 .45594 Mdot
.67114 .58786 Mdot
.63507 .56228 Mdot
.56758 .38456 Mdot
.51598 .70434 Mdot
.55027 .40227 Mdot
.50934 .61276 Mdot
.32311 .47113 Mdot
.36326 .54591 Mdot
.34466 .21302 Mdot
.4383 .84015 Mdot
.51658 .68585 Mdot
.56107 .35821 Mdot
.59122 .49696 Mdot
.64751 .57475 Mdot
.56195 .39093 Mdot
.52245 .67757 Mdot
.51599 .65927 Mdot
.46428 .6793 Mdot
.44299 .34299 Mdot
.53364 .39109 Mdot
.45104 .69366 Mdot
.44763 .66991 Mdot
.40109 .47515 Mdot
.40547 .45773 Mdot
.31807 .41584 Mdot
.36342 .34431 Mdot
.43615 .29973 Mdot
.62248 .37514 Mdot
.86994 .44031 Mdot
.61676 .56126 Mdot
.33657 .60722 Mdot
.43271 .4801 Mdot
.64022 .87938 Mdot
.35242 .52742 Mdot
.3646 .47734 Mdot
.45457 .68615 Mdot
.41344 .324 Mdot
.45648 .30496 Mdot
.49879 .65619 Mdot
.50365 .63463 Mdot
.45892 .30142 Mdot
.25347 .69798 Mdot
.35524 .79976 Mdot
.58496 .59138 Mdot
.49894 .67518 Mdot
.40393 .68041 Mdot
.68836 .57032 Mdot
.47717 .61816 Mdot
.61966 .55106 Mdot
.57729 .37227 Mdot
.65526 .38083 Mdot
.65125 .53456 Mdot
.39571 .47503 Mdot
.63964 .39155 Mdot
.32571 .4743 Mdot
.29943 .74581 Mdot
.39135 .75706 Mdot
.76639 .42221 Mdot
.3738 .43669 Mdot
.69004 .30373 Mdot
.69486 .35767 Mdot
.37916 .52525 Mdot
.56292 .76861 Mdot
.4489 .33509 Mdot
.4527 .63815 Mdot
.65711 .58943 Mdot
.64101 .80977 Mdot
.3464 .49174 Mdot
.49486 .66844 Mdot
.67153 .56241 Mdot
.24238 .38764 Mdot
.59433 .62344 Mdot
.35274 .49677 Mdot
.80284 .71023 Mdot
.4576 .73083 Mdot
.63809 .36729 Mdot
.43385 .17786 Mdot
.47785 .72003 Mdot
.46834 .2786 Mdot
.71844 .50359 Mdot
.17932 .52907 Mdot
.47899 .65296 Mdot
.55045 .36523 Mdot
.5025 .65448 Mdot
.44577 .29717 Mdot
.44116 .66123 Mdot
.57916 .36294 Mdot
.39062 .49606 Mdot
.61523 .3783 Mdot
.43084 .30277 Mdot
.56522 .24559 Mdot
.66103 .58969 Mdot
.62422 .41161 Mdot
.65118 .56453 Mdot
.36697 .27246 Mdot
.78372 .56992 Mdot
.6795 .56499 Mdot
.23079 .37742 Mdot
.42838 .49389 Mdot
.46074 .71029 Mdot
.62874 .38975 Mdot
.70773 .49937 Mdot
.5635 .55448 Mdot
.49616 .69148 Mdot
.62309 .36952 Mdot
.28919 .53378 Mdot
.30602 .25841 Mdot
.3095 .50501 Mdot
.37696 .28278 Mdot
.50204 .67502 Mdot
.55542 .38349 Mdot
.72475 .30637 Mdot
.49398 .71256 Mdot
.6236 .39313 Mdot
.64212 .57706 Mdot
.64367 .54873 Mdot
.34664 .51365 Mdot
.63051 .51173 Mdot
.63376 .37616 Mdot
.70716 .35342 Mdot
.47046 .63986 Mdot
.24775 .38447 Mdot
.41773 .32815 Mdot
.58976 .37927 Mdot
.38624 .54895 Mdot
.50782 .62314 Mdot
.74818 .53732 Mdot
.47212 .52659 Mdot
.86449 .45104 Mdot
.62331 .37801 Mdot
.4955 .64187 Mdot
.4929 .67328 Mdot
.38477 .56244 Mdot
.58683 .52235 Mdot
.55327 .40608 Mdot
.30865 .26962 Mdot
.26909 .33718 Mdot
.64183 .35442 Mdot
.66554 .4232 Mdot
.40838 .54898 Mdot
.37133 .45737 Mdot
.64831 .57692 Mdot
.39424 .49176 Mdot
.45061 .67083 Mdot
.34002 .50484 Mdot
.63664 .55021 Mdot
.59813 .3932 Mdot
.36428 .50119 Mdot
.42679 .31422 Mdot
.65553 .59476 Mdot
.63308 .5381 Mdot
.59732 .38306 Mdot
.4664 .69736 Mdot
.45812 .36135 Mdot
.60445 .3764 Mdot
.3747 .46155 Mdot
.62837 .47743 Mdot
.41666 .52181 Mdot
.247 .67456 Mdot
.48752 .71368 Mdot
.6139 .35665 Mdot
.48531 .63248 Mdot
.65501 .56767 Mdot
.74216 .51639 Mdot
.38135 .47709 Mdot
.62053 .39443 Mdot
.59507 .42545 Mdot
.28226 .72202 Mdot
.52494 .68611 Mdot
.67543 .43829 Mdot
.46596 .63843 Mdot
.64878 .36078 Mdot
.22715 .47494 Mdot
.45664 .32476 Mdot
.56958 .37156 Mdot
.43121 .82307 Mdot
.61377 .38584 Mdot
.39771 .50006 Mdot
.40077 .51814 Mdot
.64582 .37525 Mdot
.44781 .34814 Mdot
.7969 .37172 Mdot
.65276 .32335 Mdot
.48238 .64877 Mdot
.22101 .54071 Mdot
.86268 .51852 Mdot
.63452 .51969 Mdot
.65466 .58096 Mdot
.36907 .42611 Mdot
.38377 .54426 Mdot
.62079 .56044 Mdot
.69224 .57351 Mdot
.42119 .30903 Mdot
.56541 .37096 Mdot
.43891 .68012 Mdot
.6731 .59157 Mdot
.3768 .40534 Mdot
.40417 .29928 Mdot
.36837 .56365 Mdot
.38328 .58625 Mdot
.38868 .43501 Mdot
.27156 .32322 Mdot
.64092 .54188 Mdot
.40266 .52619 Mdot
.35045 .55773 Mdot
.6755 .58339 Mdot
.44927 .29766 Mdot
.73555 .63947 Mdot
.59612 .36621 Mdot
.15514 .60549 Mdot
.39831 .53701 Mdot
.39625 .50457 Mdot
.66565 .53354 Mdot
.52308 .35406 Mdot
.4697 .69559 Mdot
.48727 .715 Mdot
.62947 .4039 Mdot
.54859 .57083 Mdot
.34168 .48241 Mdot
.38437 .5278 Mdot
.60599 .36252 Mdot
.63133 .41041 Mdot
.73454 .39021 Mdot
.41638 .50048 Mdot
.66959 .56472 Mdot
.58918 .46969 Mdot
.6382 .54505 Mdot
.40573 .53837 Mdot
.40036 .50179 Mdot
.33953 .47696 Mdot
.39365 .54738 Mdot
.63316 .53711 Mdot
.40515 .52317 Mdot
.35216 .42121 Mdot
.46024 .6801 Mdot
.35282 .46303 Mdot
.26482 .33485 Mdot
.40009 .48516 Mdot
.43548 .30342 Mdot
.44714 .41066 Mdot
.34911 .4965 Mdot
.34618 .46556 Mdot
.65058 .32429 Mdot
.38235 .48972 Mdot
.61676 .55406 Mdot
.49001 .6892 Mdot
.64822 .57179 Mdot
.64261 .53575 Mdot
.60611 .40525 Mdot
.43815 .29586 Mdot
.42645 .45272 Mdot
.42304 .33302 Mdot
.43641 .46017 Mdot
.42743 .49009 Mdot
.73961 .49785 Mdot
.65419 .21627 Mdot
.62597 .25301 Mdot
.38168 .47611 Mdot
.60444 .39764 Mdot
.63246 .36234 Mdot
.47965 .55115 Mdot
.31565 .51711 Mdot
.62202 .56259 Mdot
.63751 .56651 Mdot
.33764 .37228 Mdot
.79297 .5327 Mdot
.43933 .30049 Mdot
.50289 .41177 Mdot
.32563 .47246 Mdot
.42033 .49988 Mdot
.36263 .5415 Mdot
.5851 .40066 Mdot
.61859 .47608 Mdot
.57032 .37628 Mdot
.7329 .56021 Mdot
.63438 .55127 Mdot
.34522 .48389 Mdot
.42929 .77995 Mdot
.5011 .70617 Mdot
.48931 .68967 Mdot
.62636 .55559 Mdot
.56262 .39715 Mdot
.38463 .39079 Mdot
.20111 .31388 Mdot
.45385 .72232 Mdot
.41975 .34171 Mdot
.37364 .52435 Mdot
.60123 .39051 Mdot
.51485 .67477 Mdot
.45914 .34554 Mdot
.42483 .48507 Mdot
.54944 .40512 Mdot
.3822 .4734 Mdot
.28486 .47223 Mdot
.46565 .66179 Mdot
.29925 .77257 Mdot
.5187 .69116 Mdot
.65451 .59343 Mdot
.674 .5792 Mdot
.4012 .51136 Mdot
.37279 .19984 Mdot
.4669 .7155 Mdot
.69809 .52627 Mdot
.43053 .29319 Mdot
.66921 .48664 Mdot
.46503 .30656 Mdot
.62206 .36038 Mdot
.45919 .32899 Mdot
.59192 .35789 Mdot
.36689 .35852 Mdot
.48868 .73368 Mdot
.44697 .30989 Mdot
.58645 .32742 Mdot
.3148 .51395 Mdot
.46427 .34735 Mdot
.40862 .42248 Mdot
.23018 .60132 Mdot
.60836 .36407 Mdot
.44162 .34619 Mdot
.41744 .47022 Mdot
.55168 .81858 Mdot
.67154 .57293 Mdot
.6215 .56619 Mdot
.32138 .48808 Mdot
.56296 .37369 Mdot
.51746 .65317 Mdot
.56804 .71125 Mdot
.67197 .61169 Mdot
.39291 .52841 Mdot
.34096 .50875 Mdot
.46281 .63632 Mdot
.51457 .72783 Mdot
.40297 .50531 Mdot
.33047 .58711 Mdot
.41117 .51163 Mdot
.63801 .57581 Mdot
.50863 .70344 Mdot
.49198 .67996 Mdot
.63082 .37084 Mdot
.4645 .70277 Mdot
.4856 .60578 Mdot
.62925 .48245 Mdot
.39743 .41794 Mdot
.66142 .56351 Mdot
.62331 .49632 Mdot
.73434 .56432 Mdot
.47308 .81525 Mdot
.47197 .6281 Mdot
.34184 .46669 Mdot
.47567 .63654 Mdot
.43452 .32939 Mdot
.47772 .69274 Mdot
.5074 .64661 Mdot
.38457 .51785 Mdot
.35758 .49424 Mdot
.58721 .39186 Mdot
.59028 .51467 Mdot
.45795 .67202 Mdot
.39834 .5256 Mdot
.3352 .51484 Mdot
.32833 .50385 Mdot
.52054 .47108 Mdot
.51677 .68137 Mdot
.28469 .57934 Mdot
.2664 .42437 Mdot
.45789 .67425 Mdot
.70067 .76391 Mdot
.72431 .51136 Mdot
.61557 .4181 Mdot
.60997 .54325 Mdot
.41696 .49926 Mdot
.64696 .3731 Mdot
.36038 .49669 Mdot
.38334 .58637 Mdot
.37795 .49692 Mdot
.46828 .31549 Mdot
.3791 .4246 Mdot
.65583 .36889 Mdot
.60809 .37757 Mdot
.38222 .53452 Mdot
.36731 .50021 Mdot
.58938 .25075 Mdot
.49853 .63034 Mdot
.46821 .69236 Mdot
.52893 .34434 Mdot
.44394 .31802 Mdot
.68456 .57269 Mdot
.35908 .4716 Mdot
.61358 .40441 Mdot
.6129 .37732 Mdot
.49131 .71894 Mdot
.60948 .36888 Mdot
.67803 .54035 Mdot
.37727 .47655 Mdot
.62075 .56412 Mdot
.43705 .34386 Mdot
.50887 .65878 Mdot
.34719 .48768 Mdot
.40179 .47551 Mdot
.47968 .64351 Mdot
.42788 .46569 Mdot
.4648 .33129 Mdot
.6158 .38422 Mdot
.47522 .65873 Mdot
.64729 .55356 Mdot
.61002 .35799 Mdot
.4115 .4735 Mdot
.86523 .44093 Mdot
.4009 .49593 Mdot
.41616 .48562 Mdot
.40657 .82943 Mdot
.38498 .42283 Mdot
.63009 .38301 Mdot
.44935 .65612 Mdot
.33166 .46775 Mdot
.30238 .30761 Mdot
.17392 .40134 Mdot
.572 .38342 Mdot
.36883 .52432 Mdot
.48018 .82774 Mdot
.37403 .53029 Mdot
.23461 .34206 Mdot
.48223 .23724 Mdot
.51588 .56487 Mdot
.3285 .45209 Mdot
.66633 .53802 Mdot
.58889 .3933 Mdot
.61236 .35945 Mdot
.24042 .54242 Mdot
.38577 .52191 Mdot
.29898 .44439 Mdot
.41782 .45938 Mdot
.64008 .55037 Mdot
.3161 .39175 Mdot
.62009 .37664 Mdot
.69875 .27089 Mdot
.38362 .46144 Mdot
.51773 .67834 Mdot
.55008 .38903 Mdot
.73264 .52037 Mdot
.4162 .47675 Mdot
.4259 .33558 Mdot
.62552 .58908 Mdot
.35042 .44021 Mdot
.66076 .55809 Mdot
.42228 .49968 Mdot
.34749 .41677 Mdot
.47825 .17063 Mdot
.4625 .66869 Mdot
.64925 .58024 Mdot
.68481 .39245 Mdot
.4154 .43757 Mdot
.47631 .65568 Mdot
.48993 .69605 Mdot
.42056 .31401 Mdot
.56248 .50483 Mdot
.65389 .6521 Mdot
.42106 .73675 Mdot
.2277 .53156 Mdot
.5552 .39328 Mdot
.69939 .40899 Mdot
.40232 .46345 Mdot
.79753 .46115 Mdot
.61937 .57132 Mdot
.39424 .5019 Mdot
.243 .61469 Mdot
.51147 .66779 Mdot
.41054 .493 Mdot
.45552 .3008 Mdot
.78064 .40123 Mdot
.79108 .43271 Mdot
.72681 .71318 Mdot
.58101 .38296 Mdot
.42668 .54967 Mdot
.36685 .57992 Mdot
.60932 .41017 Mdot
.41875 .44829 Mdot
.62599 .38653 Mdot
.20125 .59923 Mdot
.45941 .34179 Mdot
.51283 .66265 Mdot
.72769 .51452 Mdot
.38347 .43956 Mdot
.33532 .52227 Mdot
.45279 .35509 Mdot
.37594 .45168 Mdot
.5666 .17958 Mdot
.76217 .4402 Mdot
.64104 .3952 Mdot
.46339 .6772 Mdot
.37103 .442 Mdot
.5618 .46556 Mdot
.39054 .52027 Mdot
.37709 .72334 Mdot
.34764 .46263 Mdot
.6464 .64305 Mdot
.46811 .65123 Mdot
.65881 .56091 Mdot
.44532 .50072 Mdot
.37384 .48952 Mdot
.55002 .42576 Mdot
.33411 .44516 Mdot
.38199 .53864 Mdot
.52367 .66509 Mdot
.51039 .69806 Mdot
.47626 .67646 Mdot
.60881 .35138 Mdot
.7926 .52442 Mdot
.66297 .57092 Mdot
.42843 .53761 Mdot
.67471 .59133 Mdot
.45582 .5676 Mdot
.43949 .35351 Mdot
.56177 .80584 Mdot
.36539 .45247 Mdot
.48254 .67327 Mdot
.6523 .71828 Mdot
.45814 .66025 Mdot
.53665 .43831 Mdot
.6602 .54472 Mdot
.51296 .67768 Mdot
.36844 .48163 Mdot
.60498 .49641 Mdot
.63505 .78169 Mdot
.64407 .56701 Mdot
.43472 .46419 Mdot
.65228 .39283 Mdot
.77164 .50757 Mdot
.88042 .46852 Mdot
.6644 .58223 Mdot
.68488 .39873 Mdot
.38401 .52511 Mdot
.49401 .70937 Mdot
.67035 .53809 Mdot
.67762 .56249 Mdot
.61456 .36769 Mdot
.35548 .49367 Mdot
.35199 .49145 Mdot
.649 .36293 Mdot
.63718 .56346 Mdot
.3424 .53589 Mdot
.362 .53728 Mdot
.44731 .85474 Mdot
.25809 .47299 Mdot
.12597 .50518 Mdot
.50343 .6078 Mdot
.25115 .63533 Mdot
.56033 .70194 Mdot
.50047 .64366 Mdot
.34956 .49812 Mdot
.38619 .43154 Mdot
.63226 .37542 Mdot
.39028 .4865 Mdot
.55912 .36208 Mdot
.66316 .57772 Mdot
.69521 .76434 Mdot
.70664 .66743 Mdot
.19689 .57887 Mdot
.38885 .48868 Mdot
.73351 .60169 Mdot
.43388 .3172 Mdot
.67783 .59365 Mdot
.47578 .66658 Mdot
.41987 .5209 Mdot
.59856 .25204 Mdot
.56983 .3729 Mdot
.4953 .70069 Mdot
.69481 .29733 Mdot
.66133 .29963 Mdot
.40661 .53782 Mdot
.62205 .35299 Mdot
.59409 .74628 Mdot
.34167 .5915 Mdot
.68873 .53521 Mdot
.46707 .3114 Mdot
.57299 .37594 Mdot
.63091 .54975 Mdot
.50755 .75492 Mdot
.51079 .68436 Mdot
.44943 .70369 Mdot
.55808 .22499 Mdot
.59271 .40892 Mdot
.43632 .30909 Mdot
.79031 .53159 Mdot
.80959 .47456 Mdot
.46796 .31535 Mdot
.65196 .37308 Mdot
.51345 .69054 Mdot
.48784 .65894 Mdot
.49089 .68811 Mdot
.70876 .28021 Mdot
.51488 .70457 Mdot
.35169 .63136 Mdot
.33686 .52069 Mdot
.32392 .42704 Mdot
.36941 .52619 Mdot
.62133 .5492 Mdot
.46943 .65633 Mdot
.56777 .59591 Mdot
.42801 .53006 Mdot
.70123 .74236 Mdot
.38755 .52909 Mdot
.6942 .54506 Mdot
.4143 .49304 Mdot
.37976 .63227 Mdot
.48207 .63396 Mdot
.3874 .48043 Mdot
.62597 .53325 Mdot
.44513 .32744 Mdot
.46107 .61255 Mdot
.35017 .49503 Mdot
.59527 .68784 Mdot
.3901 .42222 Mdot
.2329 .67292 Mdot
.25323 .39185 Mdot
.42026 .34246 Mdot
.43216 .58179 Mdot
.5594 .38581 Mdot
.32201 .42669 Mdot
.32441 .54886 Mdot
.64454 .56522 Mdot
.77034 .60678 Mdot
.58279 .37655 Mdot
.37315 .37492 Mdot
.39931 .56788 Mdot
.4429 .29548 Mdot
.52701 .69651 Mdot
.62587 .53881 Mdot
.42442 .52215 Mdot
.40682 .5565 Mdot
.20965 .61316 Mdot
.31224 .52442 Mdot
.33783 .49878 Mdot
.44597 .35389 Mdot
.28997 .59399 Mdot
.40174 .4823 Mdot
.53426 .43845 Mdot
.44662 .6969 Mdot
.31881 .49395 Mdot
.28557 .57591 Mdot
.39702 .5255 Mdot
.49474 .7047 Mdot
.48817 .73061 Mdot
.65891 .69302 Mdot
.42933 .29554 Mdot
.34891 .46178 Mdot
.22437 .43176 Mdot
.37959 .45907 Mdot
.66916 .56181 Mdot
.39131 .544 Mdot
.57497 .36825 Mdot
.69846 .27985 Mdot
.6401 .38161 Mdot
.35236 .50844 Mdot
.49441 .68323 Mdot
.65579 .53308 Mdot
.59471 .2348 Mdot
.50679 .25159 Mdot
.33922 .62397 Mdot
.16596 .53274 Mdot
.44729 .34681 Mdot
.47035 .31082 Mdot
.63186 .5349 Mdot
.38883 .47988 Mdot
.21372 .41786 Mdot
.36848 .42257 Mdot
.40895 .488 Mdot
.37753 .49789 Mdot
.77656 .54395 Mdot
.65296 .57642 Mdot
.60004 .36896 Mdot
.40251 .50275 Mdot
.4022 .52393 Mdot
.48732 .63982 Mdot
.44696 .32789 Mdot
.64042 .36733 Mdot
.45088 .31932 Mdot
.60842 .39361 Mdot
.68778 .77483 Mdot
.43991 .50677 Mdot
.44358 .32493 Mdot
.63035 .58782 Mdot
.47944 .70299 Mdot
.632 .47869 Mdot
.62011 .36032 Mdot
.62351 .37435 Mdot
.39009 .52813 Mdot
.49096 .70736 Mdot
.46032 .69482 Mdot
.43391 .33016 Mdot
.6818 .56555 Mdot
.35417 .50132 Mdot
.42667 .50019 Mdot
.49368 .55771 Mdot
.57985 .39632 Mdot
.29655 .54061 Mdot
.62939 .71095 Mdot
.38471 .47684 Mdot
.46729 .70059 Mdot
.37453 .50411 Mdot
.43415 .7962 Mdot
.48619 .7116 Mdot
.37312 .5376 Mdot
.8162 .4495 Mdot
.60732 .47321 Mdot
.6188 .6725 Mdot
.33554 .48542 Mdot
.1689 .60882 Mdot
.39933 .4574 Mdot
.47458 .84898 Mdot
.57012 .27148 Mdot
.34354 .48642 Mdot
.40388 .46892 Mdot
.44334 .76292 Mdot
.37093 .51689 Mdot
.65694 .36798 Mdot
.36865 .37474 Mdot
.51294 .65008 Mdot
.56782 .64573 Mdot
.47419 .42212 Mdot
.42246 .30089 Mdot
.63046 .40351 Mdot
.65431 .43637 Mdot
.46282 .31152 Mdot
.49961 .67207 Mdot
.37148 .46724 Mdot
.53421 .55857 Mdot
.61577 .34754 Mdot
.33581 .5338 Mdot
.66819 .55553 Mdot
.72248 .42839 Mdot
.54896 .3694 Mdot
.65276 .55624 Mdot
.38026 .44496 Mdot
.46059 .75827 Mdot
.4656 .22492 Mdot
.31506 .7886 Mdot
.65542 .53159 Mdot
.63435 .55809 Mdot
.73586 .3004 Mdot
.423 .29772 Mdot
.21144 .58205 Mdot
.62371 .6362 Mdot
.68523 .54552 Mdot
.23744 .44762 Mdot
.56778 .37845 Mdot
.59575 .6768 Mdot
.4529 .63777 Mdot
.36405 .54573 Mdot
.37038 .48361 Mdot
.68097 .56968 Mdot
.50366 .75973 Mdot
.46278 .17283 Mdot
.64985 .56386 Mdot
.37215 .41055 Mdot
.52168 .49636 Mdot
.7204 .50875 Mdot
.58786 .39967 Mdot
.42676 .299 Mdot
.45468 .27406 Mdot
.49341 .64545 Mdot
.42684 .30269 Mdot
.78464 .42142 Mdot
.37034 .45203 Mdot
.64242 .56003 Mdot
.73366 .52803 Mdot
.64833 .55049 Mdot
.46 .30814 Mdot
.41664 .33674 Mdot
.46056 .68124 Mdot
.46861 .69158 Mdot
.26463 .65044 Mdot
.30966 .37422 Mdot
.37749 .53255 Mdot
.6629 .74839 Mdot
.46771 .64237 Mdot
.40857 .58782 Mdot
.46534 .30254 Mdot
.44551 .32307 Mdot
.27326 .47203 Mdot
.35075 .47911 Mdot
.22176 .39394 Mdot
.35379 .47713 Mdot
.31602 .38578 Mdot
.41273 .43943 Mdot
.61238 .36819 Mdot
.34917 .47681 Mdot
.42947 .37323 Mdot
.40727 .54899 Mdot
.38918 .54066 Mdot
.56244 .37651 Mdot
.34431 .44581 Mdot
.57622 .36734 Mdot
.35274 .5122 Mdot
.45025 .286 Mdot
.61631 .40539 Mdot
.33303 .29812 Mdot
.6155 .33863 Mdot
.65394 .39528 Mdot
.42448 .31291 Mdot
.41947 .33108 Mdot
.32643 .27744 Mdot
.47631 .66488 Mdot
.47869 .61365 Mdot
.3921 .48275 Mdot
.5594 .37604 Mdot
.65185 .5785 Mdot
.40589 .52075 Mdot
.39516 .42702 Mdot
.3358 .50214 Mdot
.50343 .65067 Mdot
.55503 .40485 Mdot
.44143 .33003 Mdot
.61224 .35084 Mdot
.5399 .40665 Mdot
.57735 .35221 Mdot
.35379 .56187 Mdot
.45019 .48474 Mdot
.26878 .68018 Mdot
.71449 .696 Mdot
.78693 .34849 Mdot
.50801 .69062 Mdot
.6247 .41089 Mdot
.41678 .31915 Mdot
.46372 .4933 Mdot
.48102 .66734 Mdot
.57843 .36364 Mdot
.38082 .47293 Mdot
.43549 .46434 Mdot
.62988 .59989 Mdot
.31025 .43718 Mdot
.27308 .34648 Mdot
.57095 .35672 Mdot
.55059 .36467 Mdot
.80688 .47347 Mdot
.36565 .37916 Mdot
.5557 .56505 Mdot
.3867 .50585 Mdot
.42767 .33765 Mdot
.51485 .67497 Mdot
.50913 .21525 Mdot
.66271 .58709 Mdot
.58875 .5186 Mdot
.38821 .48735 Mdot
.59788 .61473 Mdot
.49406 .68538 Mdot
.44778 .2987 Mdot
.68108 .57076 Mdot
.41311 .33311 Mdot
.59585 .40789 Mdot
.18483 .44104 Mdot
.37883 .45553 Mdot
.37335 .5334 Mdot
.6533 .59068 Mdot
.50269 .65607 Mdot
.44291 .35769 Mdot
.25636 .69671 Mdot
.6445 .37683 Mdot
.21378 .3934 Mdot
.45463 .69187 Mdot
.38454 .65746 Mdot
.6078 .35047 Mdot
.62681 .55577 Mdot
.33978 .27253 Mdot
.63717 .54904 Mdot
.34551 .50164 Mdot
.48734 .67724 Mdot
.67086 .57177 Mdot
.55864 .44478 Mdot
.50811 .82559 Mdot
.39822 .67389 Mdot
.35906 .4643 Mdot
.59962 .80155 Mdot
.33424 .77492 Mdot
.45358 .73716 Mdot
.66959 .58925 Mdot
.39206 .51585 Mdot
.40554 .44254 Mdot
.38076 .46271 Mdot
.66771 .54573 Mdot
.72245 .4851 Mdot
.61313 .36321 Mdot
.37761 .5283 Mdot
.41991 .31257 Mdot
.57976 .36744 Mdot
.7373 .5196 Mdot
.62915 .37926 Mdot
.48792 .62652 Mdot
.3868 .54502 Mdot
.61766 .51099 Mdot
.56922 .83871 Mdot
.64711 .57071 Mdot
.65463 .39432 Mdot
.40617 .53024 Mdot
.76653 .57971 Mdot
.47767 .67495 Mdot
.64476 .37969 Mdot
.39571 .5049 Mdot
.69153 .48117 Mdot
.58478 .24771 Mdot
.6276 .37844 Mdot
.48365 .65764 Mdot
.51218 .77155 Mdot
.39343 .48943 Mdot
.39623 .45506 Mdot
.50243 .65895 Mdot
.45953 .40941 Mdot
.70713 .29947 Mdot
.37021 .50124 Mdot
.65755 .56018 Mdot
.22012 .31634 Mdot
.33064 .49953 Mdot
.27488 .43999 Mdot
.57995 .38676 Mdot
.61675 .69783 Mdot
.29986 .54641 Mdot
.43426 .57447 Mdot
.4596 .78093 Mdot
.50158 .43692 Mdot
.67352 .7766 Mdot
.55565 .36827 Mdot
.60024 .29155 Mdot
.66721 .7861 Mdot
.63953 .52822 Mdot
.54092 .69532 Mdot
.47521 .58114 Mdot
.68318 .2567 Mdot
.53555 .75738 Mdot
.54892 .31735 Mdot
.61631 .25487 Mdot
.52125 .53333 Mdot
.61519 .39003 Mdot
.41368 .38177 Mdot
.35671 .49939 Mdot
.32781 .77201 Mdot
.33761 .59491 Mdot
.43627 .17005 Mdot
.58937 .80464 Mdot
.22751 .43066 Mdot
.58552 .79374 Mdot
.4607 .82008 Mdot
.25039 .65866 Mdot
.69614 .70912 Mdot
.22542 .33379 Mdot
.80888 .44307 Mdot
.20417 .48529 Mdot
.45124 .51811 Mdot
.50751 .40413 Mdot
.18684 .6058 Mdot
.3624 .65637 Mdot
.35297 .21588 Mdot
.63696 .37393 Mdot
.44869 .6591 Mdot
.4828 .57839 Mdot
.52744 .66807 Mdot
.59821 .59094 Mdot
.47382 .79117 Mdot
.45764 .84073 Mdot
.37028 .62463 Mdot
.16847 .61618 Mdot
.24959 .59581 Mdot
.67934 .20097 Mdot
.63789 .31567 Mdot
.45998 .71338 Mdot
.50372 .32637 Mdot
.80679 .48937 Mdot
.69973 .65502 Mdot
.50595 .60528 Mdot
.76072 .50477 Mdot
.34234 .31842 Mdot
.49536 .66956 Mdot
.33249 .58203 Mdot
.67639 .33999 Mdot
.72498 .64536 Mdot
.43271 .25315 Mdot
.47507 .80601 Mdot
.54581 .54338 Mdot
.58722 .67223 Mdot
.70825 .40201 Mdot
.86494 .44444 Mdot
.26442 .40521 Mdot
.38194 .78273 Mdot
.59965 .57551 Mdot
.51156 .76362 Mdot
.63498 .22957 Mdot
.33165 .35588 Mdot
.80846 .48597 Mdot
.80793 .58496 Mdot
.30018 .76076 Mdot
.82449 .58978 Mdot
.47632 .61406 Mdot
.33652 .4976 Mdot
.37261 .7649 Mdot
.23892 .48851 Mdot
.46579 .28945 Mdot
.74642 .68953 Mdot
.43748 .34555 Mdot
.50827 .63263 Mdot
.69078 .28079 Mdot
.36104 .62939 Mdot
.21929 .38563 Mdot
.43986 .36066 Mdot
.37153 .43769 Mdot
.40699 .13216 Mdot
.66578 .7778 Mdot
.65335 .69111 Mdot
.44915 .85536 Mdot
.64486 .62412 Mdot
.24227 .39353 Mdot
.67261 .56668 Mdot
.62592 .8156 Mdot
.48803 .6643 Mdot
.76588 .73045 Mdot
.55481 .83134 Mdot
.44916 .1887 Mdot
.16461 .33076 Mdot
.78614 .45325 Mdot
.52997 .57932 Mdot
.49762 .44626 Mdot
.30189 .32415 Mdot
.5076 .18102 Mdot
.40722 .2004 Mdot
.76223 .56839 Mdot
.17756 .56561 Mdot
.63108 .80759 Mdot
.22856 .46761 Mdot
.19018 .45799 Mdot
.6722 .24948 Mdot
.51805 .43445 Mdot
.52753 .64948 Mdot
.65002 .34279 Mdot
.55391 .78182 Mdot
.77964 .66488 Mdot
.26722 .43962 Mdot
.18854 .32564 Mdot
.44295 .36779 Mdot
.56059 .2759 Mdot
.3906 .80648 Mdot
.35527 .29096 Mdot
.24695 .45606 Mdot
.75372 .32966 Mdot
.34972 .55057 Mdot
.78075 .36571 Mdot
.61065 .76637 Mdot
.66959 .43852 Mdot
.80347 .42765 Mdot
.58038 .73429 Mdot
.22268 .6429 Mdot
.37909 .75015 Mdot
.80853 .50044 Mdot
.50708 .63986 Mdot
.31804 .34932 Mdot
.25002 .42342 Mdot
.43953 .85277 Mdot
.68425 .39383 Mdot
.36564 .8401 Mdot
.67514 .28719 Mdot
.42525 .44327 Mdot
.31885 .54588 Mdot
.41168 .40778 Mdot
.29923 .37092 Mdot
.33606 .51412 Mdot
.73833 .59299 Mdot
.42485 .84525 Mdot
.23687 .59058 Mdot
.66709 .44683 Mdot
.77177 .61137 Mdot
.32083 .79263 Mdot
.29931 .7148 Mdot
.59746 .262 Mdot
.30786 .41311 Mdot
.78372 .31991 Mdot
.58545 .37185 Mdot
.22658 .46776 Mdot
.67584 .52881 Mdot
.51692 .22271 Mdot
.42119 .72643 Mdot
.48651 .19265 Mdot
.42371 .8451 Mdot
.71218 .31454 Mdot
.64837 .27131 Mdot
.37227 .25503 Mdot
.20785 .38509 Mdot
.76653 .63618 Mdot
.42675 .54599 Mdot
.54571 .6398 Mdot
.43829 .35018 Mdot
.29838 .68781 Mdot
.22498 .4953 Mdot
.51865 .28992 Mdot
.33899 .44453 Mdot
.43925 .23007 Mdot
.53737 .38049 Mdot
.59947 .50614 Mdot
.85598 .56823 Mdot
.32945 .53567 Mdot
.78291 .50599 Mdot
.26921 .72978 Mdot
.28422 .3631 Mdot
.39158 .8013 Mdot
.57721 .69806 Mdot
.81762 .59391 Mdot
.52516 .83558 Mdot
.5069 .2633 Mdot
.71887 .73715 Mdot
.42803 .85989 Mdot
.82833 .55877 Mdot
.30192 .50656 Mdot
.61488 .55147 Mdot
.87926 .58668 Mdot
.6311 .35151 Mdot
.79011 .57412 Mdot
.22802 .53164 Mdot
.69686 .4742 Mdot
.45255 .61653 Mdot
.45407 .48034 Mdot
.52674 .53971 Mdot
.47436 .7446 Mdot
.32912 .46975 Mdot
.85983 .50707 Mdot
.81797 .55111 Mdot
.84502 .54991 Mdot
.22303 .67741 Mdot
.71715 .74224 Mdot
.50188 .5391 Mdot
.36594 .6463 Mdot
.4741 .54448 Mdot
.40326 .54346 Mdot
.39664 .3502 Mdot
.78404 .44979 Mdot
.46989 .21596 Mdot
.68779 .65102 Mdot
.52136 .6521 Mdot
.69729 .73122 Mdot
.85299 .33809 Mdot
.26168 .614 Mdot
.26398 .55438 Mdot
.79705 .44656 Mdot
.29467 .383 Mdot
.57647 .77822 Mdot
.45351 .20258 Mdot
.41562 .83162 Mdot
.46062 .57444 Mdot
.21061 .51082 Mdot
.52938 .3187 Mdot
.26427 .31449 Mdot
.52925 .35415 Mdot
.49757 .81562 Mdot
.48948 .48294 Mdot
.55505 .20845 Mdot
.56329 .61289 Mdot
.45485 .18125 Mdot
.53705 .24557 Mdot
.72511 .42322 Mdot
.21562 .47188 Mdot
.74719 .55363 Mdot
.28737 .40052 Mdot
.53123 .50574 Mdot
.46282 .46516 Mdot
.50199 .43814 Mdot
.27883 .40754 Mdot
.27754 .30337 Mdot
.77007 .67693 Mdot
.43145 .87033 Mdot
.84397 .42131 Mdot
.17554 .63119 Mdot
.61001 .7607 Mdot
.35784 .544 Mdot
.37339 .81171 Mdot
.83068 .59961 Mdot
.52446 .84241 Mdot
.71634 .34178 Mdot
.61047 .4638 Mdot
.66865 .59602 Mdot
.84366 .43683 Mdot
.53608 .33712 Mdot
.43508 .81419 Mdot
.79145 .37024 Mdot
.60814 .54816 Mdot
.64235 .20958 Mdot
.81221 .54788 Mdot
.41672 .70227 Mdot
.29015 .49208 Mdot
.36159 .55289 Mdot
.38222 .6228 Mdot
.48033 .62956 Mdot
.6995 .39685 Mdot
.31756 .36372 Mdot
.59454 .37979 Mdot
.40276 .2936 Mdot
.53245 .62102 Mdot
.37692 .4252 Mdot
.48089 .42328 Mdot
.44946 .65248 Mdot
.71186 .69767 Mdot
.65576 .49441 Mdot
.75352 .72196 Mdot
.77204 .43447 Mdot
.33134 .44652 Mdot
.27929 .37394 Mdot
.67225 .31169 Mdot
.74234 .31569 Mdot
.67315 .53101 Mdot
.56762 .81374 Mdot
.52678 .42506 Mdot
.31622 .35281 Mdot
.38023 .61694 Mdot
.23386 .65354 Mdot
.45101 .48331 Mdot
.64239 .71289 Mdot
.35514 .71335 Mdot
.5929 .50856 Mdot
.52446 .64585 Mdot
.53265 .65941 Mdot
.27553 .77077 Mdot
.77192 .38612 Mdot
.71052 .41834 Mdot
.5547 .81591 Mdot
.65311 .54025 Mdot
.45747 .66831 Mdot
.39271 .36333 Mdot
.22753 .65629 Mdot
.36419 .69502 Mdot
.58643 .24779 Mdot
.75889 .47024 Mdot
.53184 .2856 Mdot
.57523 .80353 Mdot
.59686 .79631 Mdot
.42629 .16838 Mdot
.52489 .68967 Mdot
.26213 .69204 Mdot
.19769 .55802 Mdot
.46074 .64297 Mdot
.44425 .62315 Mdot
.71633 .63567 Mdot
.76717 .69365 Mdot
.64459 .50707 Mdot
.17293 .56909 Mdot
.28407 .31157 Mdot
.70473 .48535 Mdot
.60114 .23726 Mdot
.21006 .45507 Mdot
.54237 .81669 Mdot
.35783 .59561 Mdot
.42667 .71247 Mdot
.4216 .42851 Mdot
.31685 .42728 Mdot
.83896 .38614 Mdot
.60166 .33849 Mdot
.38551 .65288 Mdot
.57427 .72905 Mdot
.37106 .46078 Mdot
.86345 .45088 Mdot
.29695 .74515 Mdot
.74587 .30721 Mdot
.6363 .59359 Mdot
.40974 .45631 Mdot
.40157 .55052 Mdot
.29429 .4301 Mdot
.63654 .69868 Mdot
.79825 .58622 Mdot
.20918 .45965 Mdot
.57586 .7595 Mdot
.34402 .59718 Mdot
.78202 .50841 Mdot
.46729 .80345 Mdot
.3538 .78401 Mdot
.57063 .49722 Mdot
.77825 .43667 Mdot
.35426 .26985 Mdot
.18209 .63283 Mdot
.51705 .3956 Mdot
.49933 .55385 Mdot
.70793 .62182 Mdot
.60416 .71154 Mdot
.55538 .21722 Mdot
.42259 .50708 Mdot
.69515 .29744 Mdot
.46043 .81759 Mdot
.33269 .21792 Mdot
.55982 .19228 Mdot
.86515 .46492 Mdot
.39082 .73109 Mdot
.59095 .70824 Mdot
.48046 .77535 Mdot
.29806 .23025 Mdot
.50897 .39513 Mdot
.67799 .75688 Mdot
.35978 .26207 Mdot
.56491 .81019 Mdot
.6186 .53624 Mdot
.59063 .62042 Mdot
.77401 .60718 Mdot
.74824 .71242 Mdot
.32423 .73394 Mdot
.49605 .80941 Mdot
.56123 .59657 Mdot
.80493 .65456 Mdot
.75331 .59522 Mdot
.51551 .52024 Mdot
.62719 .40861 Mdot
.73929 .33009 Mdot
.58728 .78546 Mdot
.66715 .73193 Mdot
.21997 .47954 Mdot
.56049 .34411 Mdot
.37994 .37328 Mdot
.4155 .66084 Mdot
.37558 .29552 Mdot
.6023 .72376 Mdot
.2797 .37286 Mdot
.46556 .82913 Mdot
.51413 .37778 Mdot
.65611 .28345 Mdot
.77876 .50736 Mdot
.18053 .46805 Mdot
.64225 .6941 Mdot
.76729 .37536 Mdot
.38683 .78689 Mdot
.54659 .26255 Mdot
.23606 .42598 Mdot
.45628 .90969 Mdot
.19145 .51146 Mdot
.73196 .66446 Mdot
.78037 .66275 Mdot
.37828 .79818 Mdot
.72588 .68077 Mdot
.52282 .17893 Mdot
.25931 .479 Mdot
.37282 .35612 Mdot
.3771 .4962 Mdot
.85132 .56973 Mdot
.3554 .31872 Mdot
.78976 .6569 Mdot
.34897 .80609 Mdot
.39239 .62817 Mdot
.37391 .4266 Mdot
.58572 .35395 Mdot
.6744 .35164 Mdot
.38683 .29643 Mdot
.44257 .74652 Mdot
.25238 .49178 Mdot
.76487 .45039 Mdot
.60702 .41058 Mdot
.52976 .34555 Mdot
.43656 .70478 Mdot
.75902 .40584 Mdot
.6215 .71275 Mdot
.40568 .31905 Mdot
.56338 .53174 Mdot
.28126 .3976 Mdot
.30181 .55222 Mdot
.41519 .70547 Mdot
.49507 .19324 Mdot
.53497 .45245 Mdot
.63183 .3817 Mdot
.41747 .74352 Mdot
.18252 .56424 Mdot
.59986 .73976 Mdot
.80774 .59931 Mdot
.73183 .31716 Mdot
.47571 .49565 Mdot
.28087 .41203 Mdot
.48795 .18401 Mdot
.24957 .31756 Mdot
.71724 .7037 Mdot
.349 .57855 Mdot
.22848 .3896 Mdot
.5254 .60751 Mdot
.68283 .77713 Mdot
.20519 .4907 Mdot
.21701 .53847 Mdot
.64201 .32755 Mdot
.35352 .66201 Mdot
.40669 .63182 Mdot
.33032 .29386 Mdot
.5654 .55249 Mdot
.69478 .21336 Mdot
.44742 .64407 Mdot
.86208 .40283 Mdot
.64403 .58119 Mdot
.69593 .25385 Mdot
.3519 .25712 Mdot
.53079 .50084 Mdot
.56469 .56622 Mdot
.65287 .7066 Mdot
.64881 .64207 Mdot
.19435 .63653 Mdot
.40371 .19051 Mdot
.57678 .35188 Mdot
.20277 .43316 Mdot
.17983 .43589 Mdot
.43821 .75872 Mdot
.35063 .4511 Mdot
.18857 .51202 Mdot
.5648 .35024 Mdot
.47313 .2143 Mdot
.35623 .79912 Mdot
.64783 .73335 Mdot
.34674 .4193 Mdot
.30005 .37802 Mdot
.66918 .7615 Mdot
.52425 .83113 Mdot
.5902 .18844 Mdot
.61104 .76586 Mdot
.6148 .55584 Mdot
.50754 .52834 Mdot
.52016 .80097 Mdot
.25281 .37163 Mdot
.58423 .6529 Mdot
.24592 .42491 Mdot
.80216 .30763 Mdot
.78937 .6026 Mdot
.79776 .58635 Mdot
.25001 .39252 Mdot
.50727 .71617 Mdot
.74525 .61032 Mdot
.24723 .45034 Mdot
.65873 .72199 Mdot
.19759 .62142 Mdot
.24842 .43206 Mdot
.40897 .16196 Mdot
.22945 .60705 Mdot
.54006 .40226 Mdot
.41261 .62969 Mdot
.23662 .60943 Mdot
.61601 .57428 Mdot
.3867 .34101 Mdot
.57268 .73737 Mdot
.65143 .59184 Mdot
.60763 .72318 Mdot
.5993 .68727 Mdot
.21588 .5649 Mdot
.37523 .69633 Mdot
.58575 .75992 Mdot
.41915 .76831 Mdot
.51597 .74061 Mdot
.51289 .2158 Mdot
.59591 .41752 Mdot
.55906 .74402 Mdot
.64619 .39266 Mdot
.42489 .57751 Mdot
.58696 .5063 Mdot
.45407 .41884 Mdot
.83611 .41368 Mdot
.44139 .34895 Mdot
.48177 .71917 Mdot
.71645 .25815 Mdot
.45102 .65958 Mdot
.85701 .5306 Mdot
.46741 .19994 Mdot
.37165 .61391 Mdot
.51443 .25949 Mdot
.51306 .32167 Mdot
.54654 .14378 Mdot
.42896 .65722 Mdot
.65121 .32896 Mdot
.51963 .72961 Mdot
.50383 .71082 Mdot
.77474 .48329 Mdot
.59888 .40629 Mdot
.27876 .49681 Mdot
.71256 .60206 Mdot
.47765 .52158 Mdot
.49902 .73052 Mdot
.56576 .45493 Mdot
.34117 .38293 Mdot
.76012 .70434 Mdot
.62292 .39055 Mdot
.76776 .28604 Mdot
.42249 .43646 Mdot
.35323 .73739 Mdot
.40709 .83261 Mdot
.61823 .19922 Mdot
.67185 .39911 Mdot
.17952 .39061 Mdot
.42622 .44737 Mdot
.58831 .76387 Mdot
.49416 .66334 Mdot
.2154 .52675 Mdot
.45684 .33092 Mdot
.28939 .34746 Mdot
.67788 .59033 Mdot
.55786 .21005 Mdot
.75327 .40422 Mdot
.50363 .72223 Mdot
.64108 .74859 Mdot
.24782 .66493 Mdot
.60012 .63468 Mdot
.53055 .38261 Mdot
.43351 .75112 Mdot
.36924 .69042 Mdot
.49679 .73093 Mdot
.79141 .61939 Mdot
.20717 .51524 Mdot
.64835 .8115 Mdot
.40858 .40867 Mdot
.62774 .29815 Mdot
.69257 .62242 Mdot
.62227 .72435 Mdot
.29345 .52111 Mdot
.42239 .83765 Mdot
.32753 .35129 Mdot
.72038 .60754 Mdot
.30943 .387 Mdot
.45157 .53657 Mdot
.55434 .52503 Mdot
.70944 .38001 Mdot
.47104 .15514 Mdot
.28998 .45767 Mdot
.63773 .22452 Mdot
.36424 .58272 Mdot
.7854 .4956 Mdot
.44511 .70986 Mdot
.61158 .45272 Mdot
.36483 .66512 Mdot
.68362 .38779 Mdot
.66629 .79095 Mdot
.4188 .83572 Mdot
.61599 .58952 Mdot
.76869 .49363 Mdot
.54294 .73268 Mdot
.40297 .41189 Mdot
.57129 .60455 Mdot
.34015 .50012 Mdot
.43616 .68134 Mdot
.64221 .20566 Mdot
.65147 .71937 Mdot
.41312 .56184 Mdot
.671 .77974 Mdot
.61699 .81847 Mdot
.79977 .65777 Mdot
.21152 .39188 Mdot
.50623 .64849 Mdot
.8383 .54401 Mdot
.27862 .53821 Mdot
.47655 .83617 Mdot
.70545 .7128 Mdot
.29655 .78704 Mdot
.43246 .72944 Mdot
.57315 .71663 Mdot
.41487 .1924 Mdot
.62982 .6537 Mdot
.32778 .77757 Mdot
.5091 .48411 Mdot
.70088 .43753 Mdot
.3287 .78264 Mdot
.44966 .12793 Mdot
.31725 .55406 Mdot
.5914 .68167 Mdot
.51274 .59174 Mdot
.56372 .74289 Mdot
.58911 .27212 Mdot
.39215 .54383 Mdot
.74696 .53434 Mdot
.62177 .24919 Mdot
.27199 .40622 Mdot
.3812 .37257 Mdot
.58637 .27266 Mdot
.39267 .30128 Mdot
.32552 .3826 Mdot
.20354 .48391 Mdot
.42998 .73554 Mdot
.282 .49999 Mdot
.43008 .44599 Mdot
.44037 .69535 Mdot
.44016 .29126 Mdot
.6363 .43343 Mdot
.35026 .51248 Mdot
.67476 .40088 Mdot
.61851 .64178 Mdot
.86331 .47989 Mdot
.65623 .45783 Mdot
.26504 .71298 Mdot
.4525 .63935 Mdot
.6393 .70349 Mdot
.42119 .78096 Mdot
.68734 .26649 Mdot
.58031 .29579 Mdot
.26713 .43948 Mdot
.63952 .79121 Mdot
.80316 .43017 Mdot
.21624 .61947 Mdot
.8248 .4672 Mdot
.62697 .5806 Mdot
.30872 .46175 Mdot
.50339 .57987 Mdot
.71734 .32865 Mdot
.53148 .66673 Mdot
.57601 .71766 Mdot
.61639 .32067 Mdot
.78725 .39918 Mdot
.27356 .73527 Mdot
.23994 .65721 Mdot
.42443 .64769 Mdot
.6051 .7968 Mdot
.57371 .38594 Mdot
.20655 .52793 Mdot
.57581 .647 Mdot
.59363 .29937 Mdot
.79586 .52862 Mdot
.73038 .74139 Mdot
.57007 .59549 Mdot
.33937 .31208 Mdot
.38881 .4566 Mdot
.28664 .58083 Mdot
.65899 .71103 Mdot
.44841 .37659 Mdot
.74741 .42437 Mdot
.47619 .7057 Mdot
.73223 .4062 Mdot
.5009 .3767 Mdot
.37278 .34944 Mdot
.49978 .73518 Mdot
.24308 .49552 Mdot
.47326 .30351 Mdot
.70467 .60044 Mdot
.32693 .48769 Mdot
.32194 .32232 Mdot
.21861 .3801 Mdot
.30729 .47442 Mdot
.58176 .78155 Mdot
.42423 .73929 Mdot
.21419 .63149 Mdot
.61643 .73957 Mdot
.72625 .69508 Mdot
.65269 .64479 Mdot
.38 .67067 Mdot
.69289 .32344 Mdot
.33533 .50019 Mdot
.61552 .45481 Mdot
.45509 .67972 Mdot
.4807 .78609 Mdot
.38275 .72702 Mdot
.33591 .29706 Mdot
.5434 .48676 Mdot
.40816 .77789 Mdot
.53233 .4683 Mdot
.38829 .81841 Mdot
.63217 .65437 Mdot
.32141 .36177 Mdot
.63647 .52178 Mdot
.34949 .26129 Mdot
.5103 .18524 Mdot
.58829 .82008 Mdot
.4685 .188 Mdot
.53973 .56851 Mdot
.63985 .22157 Mdot
.74013 .63968 Mdot
.34176 .79599 Mdot
.32965 .36496 Mdot
.5718 .59199 Mdot
.39028 .37692 Mdot
.61036 .58628 Mdot
.55573 .46346 Mdot
.58771 .44544 Mdot
.27389 .51417 Mdot
.73567 .46322 Mdot
.68631 .33841 Mdot
.44539 .45148 Mdot
.78342 .55608 Mdot
.62427 .79475 Mdot
.22275 .53021 Mdot
.51451 .44381 Mdot
.49067 .23203 Mdot
.36971 .34307 Mdot
.15237 .61747 Mdot
.86562 .4424 Mdot
.3872 .45575 Mdot
.50442 .43326 Mdot
.31403 .33974 Mdot
.58737 .34996 Mdot
.26335 .50722 Mdot
.45416 .77432 Mdot
.63342 .56861 Mdot
.59538 .45818 Mdot
.78121 .38425 Mdot
.66345 .70061 Mdot
.37367 .27931 Mdot
.77139 .55399 Mdot
.86663 .49238 Mdot
.17911 .59199 Mdot
.63376 .72327 Mdot
.18952 .684 Mdot
.70652 .35264 Mdot
.52207 .63631 Mdot
.37118 .76719 Mdot
.7728 .67575 Mdot
.27752 .36976 Mdot
.5516 .22413 Mdot
.7517 .66295 Mdot
.33035 .35533 Mdot
.24041 .45243 Mdot
.77954 .50438 Mdot
.73709 .41049 Mdot
.53116 .52563 Mdot
.51382 .32278 Mdot
.82115 .50803 Mdot
.36342 .60159 Mdot
.64234 .78085 Mdot
.62267 .24717 Mdot
.38237 .16938 Mdot
.62799 .81527 Mdot
.39733 .33556 Mdot
.5906 .26628 Mdot
.36081 .76211 Mdot
.26877 .3358 Mdot
.24425 .47956 Mdot
.50543 .20427 Mdot
.35176 .68945 Mdot
.50028 .29117 Mdot
.63548 .23686 Mdot
.28609 .40169 Mdot
.23557 .60086 Mdot
.56952 .58905 Mdot
.41293 .72228 Mdot
.77427 .46222 Mdot
.25547 .39482 Mdot
.55726 .439 Mdot
.29277 .31586 Mdot
.42327 .74929 Mdot
.40605 .78752 Mdot
.56898 .67892 Mdot
.47624 .12858 Mdot
.72305 .70761 Mdot
.68106 .2627 Mdot
.33498 .51725 Mdot
.69262 .77722 Mdot
.57301 .66671 Mdot
.74547 .6778 Mdot
.23643 .68367 Mdot
.59692 .43653 Mdot
.65218 .62942 Mdot
.33629 .50269 Mdot
.64412 .76106 Mdot
.38902 .65343 Mdot
.24255 .62332 Mdot
.57651 .22223 Mdot
.28645 .36982 Mdot
.60617 .26183 Mdot
.31854 .29497 Mdot
.32624 .4408 Mdot
.45608 .69614 Mdot
.84363 .56212 Mdot
.54048 .58083 Mdot
.41725 .5762 Mdot
.35857 .40626 Mdot
.42775 .18528 Mdot
.16068 .51658 Mdot
.40038 .40824 Mdot
.80709 .45298 Mdot
.23202 .45601 Mdot
.47052 .49873 Mdot
.35986 .58841 Mdot
.10192 .42557 Mdot
.44235 .86414 Mdot
.52131 .66598 Mdot
.24367 .52264 Mdot
.2256 .41347 Mdot
.76737 .68493 Mdot
.53126 .3157 Mdot
.62179 .42325 Mdot
.34439 .22685 Mdot
.25411 .34975 Mdot
.41173 .43523 Mdot
.25645 .71629 Mdot
.57256 .82325 Mdot
.59146 .2251 Mdot
.66014 .78795 Mdot
.38607 .57831 Mdot
.4239 .54588 Mdot
.10675 .50273 Mdot
.5252 .80563 Mdot
.35358 .55212 Mdot
.43097 .18117 Mdot
.52553 .6455 Mdot
.36282 .49365 Mdot
.76971 .54249 Mdot
.21312 .47219 Mdot
.28585 .40472 Mdot
.74966 .71093 Mdot
.52654 .69543 Mdot
.68092 .38911 Mdot
.62848 .56264 Mdot
.56452 .56102 Mdot
.44126 .47999 Mdot
.67389 .55119 Mdot
.46917 .47156 Mdot
.56283 .72907 Mdot
.61282 .57324 Mdot
.1945 .45275 Mdot
.34704 .82623 Mdot
.39546 .72137 Mdot
.66763 .60453 Mdot
.43017 .41614 Mdot
.23189 .61269 Mdot
.38862 .29861 Mdot
.4819 .53962 Mdot
.32014 .78265 Mdot
.56985 .88435 Mdot
.70753 .44102 Mdot
.34552 .39698 Mdot
.50159 .73459 Mdot
.28478 .50884 Mdot
.41151 .67862 Mdot
.70255 .53883 Mdot
.58645 .39397 Mdot
.37109 .42224 Mdot
.32632 .44202 Mdot
.67251 .59158 Mdot
.84981 .38909 Mdot
.407 .53247 Mdot
.33724 .57939 Mdot
.48302 .83306 Mdot
.51634 .21553 Mdot
.3333 .72621 Mdot
.43187 .49543 Mdot
.73815 .61189 Mdot
.57375 .5938 Mdot
.5313 .77102 Mdot
.65835 .28594 Mdot
.71192 .73848 Mdot
.37905 .72575 Mdot
.41912 .63216 Mdot
.39824 .52771 Mdot
.43345 .28801 Mdot
.59672 .6708 Mdot
.76345 .65607 Mdot
.34768 .57129 Mdot
.50343 .83951 Mdot
.59072 .43339 Mdot
.74922 .47404 Mdot
.46568 .5331 Mdot
.81347 .61994 Mdot
.60569 .21249 Mdot
.40132 .64634 Mdot
.72765 .28787 Mdot
.74721 .35727 Mdot
.37379 .29788 Mdot
.5764 .35802 Mdot
.43142 .55303 Mdot
.52396 .70229 Mdot
.87178 .50423 Mdot
.76766 .64842 Mdot
.69146 .50315 Mdot
.72666 .42757 Mdot
.32897 .61132 Mdot
.56801 .62537 Mdot
.26184 .7654 Mdot
.54744 .32226 Mdot
.8677 .48223 Mdot
.21406 .53569 Mdot
.44211 .72388 Mdot
.58861 .71805 Mdot
.30879 .50973 Mdot
.62499 .38036 Mdot
.75013 .70124 Mdot
.32375 .44905 Mdot
.67519 .27648 Mdot
.42733 .46709 Mdot
.75959 .32264 Mdot
.60635 .47966 Mdot
.76713 .51457 Mdot
.74753 .55129 Mdot
.52494 .18047 Mdot
.44394 .80391 Mdot
.62021 .50393 Mdot
.2147 .70636 Mdot
.49224 .78332 Mdot
.56851 .81427 Mdot
.5756 .24523 Mdot
.57242 .1732 Mdot
.6757 .72826 Mdot
.59008 .75455 Mdot
.66002 .49102 Mdot
.4873 .4479 Mdot
.73025 .3246 Mdot
.46844 .47877 Mdot
.61235 .66974 Mdot
.60513 .5736 Mdot
.67721 .85445 Mdot
.40913 .3671 Mdot
.51888 .61776 Mdot
.69764 .31462 Mdot
.60509 .80634 Mdot
.44329 .39662 Mdot
.2854 .75315 Mdot
.50832 .40478 Mdot
.43203 .5388 Mdot
.37115 .70563 Mdot
.2228 .52115 Mdot
.74766 .33378 Mdot
.59666 .15201 Mdot
.18246 .59626 Mdot
.73606 .45059 Mdot
.56793 .52075 Mdot
.46221 .64236 Mdot
.45469 .61455 Mdot
.51541 .27978 Mdot
.23698 .71055 Mdot
.57002 .71987 Mdot
.52077 .8016 Mdot
.53071 .14347 Mdot
.2112 .58472 Mdot
.76915 .68604 Mdot
.7106 .68697 Mdot
.44055 .66123 Mdot
.39759 .31478 Mdot
.44555 .2605 Mdot
.74341 .53927 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
08kooooo0_l00007ooooo`;o0000/?ooool001cooooo00?o0000ooooooooool0P?ooool2o`0000co
oooo0_l00007ooooo`;o0000/?ooool001cooooo00?o0000ooooooooool0P?ooool2o`000<Oooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0V_ooool2
o`000:gooooo000Looooo`03o`000?oooooooooo09[ooooo0_l0000=ooooo`;o00000oooool2o`00
09Wooooo000Looooo`03o`000?oooooooooo08_ooooo0_l00003ooooo`;o00005oooool4o`000003
ooooool0003o000009Wooooo000Looooo`03o`000?oooooooooo08_ooooo0_l00003ooooo`;o0000
0oooool2o`0001Cooooo0_l0002Looooo`007?ooool2o`0008kooooo0_l00006ooooo`;o00009ooo
ool2o`0008Wooooo000Looooo`03o`000?oooooooooo08gooooo0_l00006ooooo`;o00007_ooool2
o`0000Oooooo0_l00029ooooo`007?ooool00ol0003oooooooooo`2Eooooo`;o00007_ooool2o`00
09;ooooo000Looooo`03o`000?oooooooooo087ooooo0_l0000Booooo`;o0000/_ooool001cooooo
00?o0000ooooooooool0Moooool2o`0000Sooooo0_l0000Booooo`;o0000;Oooool2o`0008?ooooo
000Looooo`03o`000?oooooooooo07Oooooo0_l0000>ooooo`;o00004_ooool2o`0000cooooo0_l0
000Iooooo`;o0000Poooool001cooooo00?o0000ooooooooool0N?ooool2o`0000Sooooo0_l00003
ooooo`;o000000?oooooo`000?l000003?ooool2o`000003ooooool0003o000000[ooooo1?l0002N
ooooo`007?ooool00ol0003oooooooooo`1hooooo`;o00002?ooool2o`0000Kooooo0_l00007oooo
o`;o00000oooool2o`0000gooooo0_l0000=ooooo`;o0000TOooool001cooooo00?o0000oooooooo
ool0ROooool2o`0000Sooooo0_l0000Nooooo`;o000000?oooooo`000?l00000TOooool001cooooo
00?o0000ooooooooool0R?ooool3o`0000Gooooo0_l000000ooooooo0000o`00000<ooooo`;o0000
00?oooooo`000?l000000ol0000:ooooo`?o0000Toooool001cooooo00?o0000ooooooooool0R?oo
ool2o`0000Kooooo0_l00007ooooo`Co00001?ooool2o`000003ooooool0003o000000?o00002ooo
ool2o`0009?ooooo000Looooo`03o`000?oooooooooo08Oooooo0_l00007ooooo`;o00001oooool4
o`0000Gooooo0_l00003ooooo`;o0000X?ooool001cooooo00?o0000ooooooooool0Ooooool2o`00
00Cooooo1?l00005ooooo`;o00001?ooool2o`0000Kooooo0_l00004ooooo`;o00003_ooool2o`00
00Sooooo0_l0000Fooooo`;o0000Loooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2
ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo07oooooo0_l00002ooooo`Oo00001?ooool2
o`0000Cooooo0_l00004ooooo`Go00004oooool5o`0000Gooooo0_l0000Fooooo`;o0000Loooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A006ooooo`03o`000?oooooooooo08?ooooo0_l00003ooooo`;o00002_ooool2o`0000Cooooo
0_l000000ooooooo0000o`00000>ooooo`;o000000?oooooo`000?l000001ol00008ooooo`;o0000
Q_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^
kP07ooooo`03o`000?oooooooooo07Gooooo0_l0000Mooooo`;o00003Oooool2o`0000Sooooo0_l0
00000ooooooo0000o`000005ooooo`?o00001oooool2o`0000;ooooo0_l00022ooooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0001e
ooooo`;o00002_ooool2o`0000gooooo0_l00002ooooo`;o00003Oooool2o`0001?ooooo1?l00000
0ooooooo0000o`000006ooooo`;o00004_ooool2o`0000Sooooo0_l0001Tooooo`0000?oooooo`00
0?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000oooo
ooooool0Moooool2o`0000Sooooo0_l0000=ooooo`;o00001oooool2o`0000?ooooo1?l00002oooo
o`;o00001?ooool2o`0000kooooo0_l000001?oooooo0000o`000?ooool2o`0000_ooooo0_l0000:
ooooo`;o00002?ooool2o`0006Cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo
00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1gooooo`;o00005oooool2o`00
00Oooooo0_l00003ooooo`Co00000_ooool4o`0000;ooooo0_l00005ooooo`;o00003Oooool4o`00
00Wooooo0_l0001jooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`2@ooooo`;o00003?ooool2o`0000Kooooo0_l0
0009ooooo`;o00003oooool2o`0000;ooooo0_l00005ooooo`;o0000N_ooool00006ooooooo^k^ko
<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000oooooooo
ool0K?ooool2o`0000kooooo0_l0000Booooo`;o00001?ooool2o`0000[ooooo0_l00008ooooo`;o
00000oooool2o`0000kooooo0_l00003ooooo`;o00001Oooool2o`0000oooooo0_l0001Yooooo`00
7?ooool00ol0003oooooooooo`1Xooooo`;o00000_ooool5o`0000_ooooo0_l0000Gooooo`?o0000
2_ooool4o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0000kooooo0_l000001?oooooo0000
o`000?ooool2o`0000Sooooo0_l0000;ooooo`;o0000JOooool001cooooo00?o0000ooooooooool0
J?ooool2o`0000?ooooo1?l0000Kooooo`;o000000?oooooo`000?l000001?ooool2o`000004oooo
ool0003o0000ooooo`?o00001Oooool3o`0000;ooooo0_l00007ooooo`;o00004Oooool2o`000003
ooooool0003o000000?ooooo0_l00003ooooo`;o00002oooool2o`0006Wooooo000Looooo`03o`00
0?oooooooooo08cooooo0_l000000ooooooo0000o`000007ooooo`;o000000Coooooo`000?l0003o
00001_ooool2o`0000Wooooo0_l00006ooooo`;o00004_ooool3o`0000Kooooo0_l00008ooooo`;o
0000JOooool001cooooo00?o0000ooooooooool0K?ooool2o`0002Gooooo0_l0000?ooooo`;o0000
2Oooool2o`000003ooooool0003o000000?ooooo0_l00002ooooo`?o00003Oooool2o`0000Oooooo
0_l0001cooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o00003?ooool3o`0001gooooo0_l0
0006ooooo`;o00007Oooool2o`0000Oooooo0ol0000<ooooo`;o0000OOooool001cooooo00?o0000
ooooooooool0GOooool2o`0000_ooooo0ol0000Nooooo`;o00003oooool2o`0000Oooooo0ol00000
1?oooooo0000o`000?l0000<ooooo`;o00004?ooool2o`0000[ooooo0_l0001aooooo`007?ooool0
0ol0003oooooooooo`1?ooooo`;o00005oooool4o`0001oooooo0_l00002ooooo`;o00002oooool2
o`0000Oooooo0ol000001?oooooo0000o`000?l0000<ooooo`;o00000oooool2o`0000cooooo0_l0
0006ooooo`;o000000Coooooo`000?l0003ooooo0_l0001^ooooo`007?ooool00ol0003ooooooooo
o`1?ooooo`;o00004?ooool2o`000003ooooool0003o000000;ooooo0_l0000Uooooo`;o00002?oo
ool2o`0001cooooo0_l000001?oooooo0000o`000?ooool4o`0000Sooooo1?l00006ooooo`;o0000
1?ooool2o`0006kooooo000Looooo`03o`000?oooooooooo067ooooo0_l000000ooooooo0000o`00
000`ooooo`;o000000?oooooo`000?l000000_l0000Jooooo`;o000000?oooooo`000?l000000ooo
ool2o`0000Sooooo0_l0000=ooooo`;o0000Koooool001cooooo00?o0000ooooooooool0G_ooool2
o`0003Kooooo0_l00002ooooo`?o00003_ooool2o`0000Kooooo1_l00003ooooo`;o00006_ooool3
o`0006kooooo000Looooo`03o`000?oooooooooo05kooooo0_l0000>ooooo`;o0000:_ooool2o`00
00Cooooo0_l00009ooooo`;o00001_ooool6o`000003ooooool0003o000000;o00002?ooool2o`00
017ooooo0_l0001^ooooo`007?ooool2o`0004gooooo0_l0000@ooooo`;o00003_ooool2o`00017o
oooo0_l00004ooooo`;o00005oooool3o`0001Oooooo1?l000000ooooooo0000o`000005ooooo`;o
00002_ooool2o`0000?ooooo0_l0001`ooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o0000
9oooool2o`0000[ooooo0_l00004ooooo`Co00005_ooool2o`0000cooooo1?l00009ooooo`;o0000
00?oooooo`000?l000000oooool2o`0000;ooooo0_l00006ooooo`Co000000?oooooo`000?l00000
0_l00002ooooo`;o000000?oooooo`000?l00000JOooool001cooooo00?o0000ooooooooool0H?oo
ool2o`0000gooooo0_l00004ooooo`;o00004Oooool3o`0002Cooooo1?l0000=ooooo`?o000000?o
ooooo`000?l000000_ooool3o`0000Gooooo0_l00003ooooo`;o00000oooool6o`0000Gooooo0_l0
001Rooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o00002?ooool2o`0000;ooooo0ol0000G
ooooo`;o00000oooool2o`0001Cooooo0_l0000Kooooo`?o000000?oooooo`000?l000000_ooool3
o`0000[ooooo0_l00003ooooo`Co00001oooool2o`0006;ooooo000Looooo`03o`000?oooooooooo
053ooooo0_l0000Hooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0001[ooooo0_l00007
ooooo`;o00002Oooool4o`0000Wooooo0_l00003ooooo`;o000000?oooooo`000?l000001_ooool:
o`0000gooooo0_l00002ooooo`;o000000?oooooo`000?l00000Joooool001cooooo00?o0000oooo
ooooool0D?ooool4o`0001?ooooo0_l00004ooooo`;o00000_ooool2o`0000Wooooo1?l0000Foooo
o`;o00002Oooool2o`0000_ooooo0_l00003ooooo`;o000000?oooooo`000?l000001?ooool4o`00
0003ooooool0003o000000;o000000?oooooo`000?l000004Oooool4o`0000_ooooo0_l0001Ooooo
o`007?ooool00ol0003oooooooooo`1Booooo`;o00003Oooool2o`0000Cooooo0_l00006ooooo`;o
00002_ooool5o`0000?ooooo1Ol0000;ooooo`;o00006?ooool2o`0000gooooo0_l0000;ooooo`;o
00004?ooool2o`0000;ooooo0_l00007ooooo`;o0000Goooool001cooooo00?o0000ooooooooool0
Foooool2o`0000Cooooo0_l00008ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0000Ko
oooo0_l00006ooooo`Go00002oooool2o`0001Sooooo0_l00006ooooo`;o00001?ooool3o`0000_o
oooo1?l00002ooooo`;o00001_ooool2o`0000Cooooo1?l0001Xooooo`007?ooool00ol0003ooooo
ooooo`1=ooooo`;o00003?ooool2o`0000Wooooo0_l00003ooooo`;o000000?oooooo`000?l00000
1Ol0000<ooooo`;o00000_ooool2o`0000Wooooo0_l000000ooooooo0000o`00000Mooooo`;o0000
00?oooooo`000?l000001?ooool3o`0000_ooooo1Ol000000ooooooo0000o`000006ooooo`?o0000
0oooool3o`0000kooooo0_l0001Iooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00005ooo
ool>o`0000;ooooo0_l00009ooooo`;o00001_ooool2o`0000Gooooo0_l00002ooooo`?o00003Ooo
ool2o`0000Kooooo0_l00004ooooo`;o00002oooool2o`0000_ooooo0_l0000:ooooo`;o00001Ooo
ool2o`0000gooooo0_l0001Iooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00004Oooool8
o`0000?ooooo0_l00003ooooo`?o00004?ooool2o`0000Oooooo1Ol0000=ooooo`;o00001_ooool2
o`0000_ooooo0_l00004ooooo`;o00003?ooool2o`0000Wooooo0_l00003ooooo`Co000000?ooooo
o`000?l000000_l0001Sooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00003_ooool2o`00
00?ooooo0_l0000;ooooo`Co00005Oooool3o`000003ooooool0003o000001Gooooo0_l0000>oooo
o`;o00004_ooool2o`0000;ooooo0ol00002ooooo`Co00000oooool2o`0000?ooooo1?l0000@oooo
o`;o0000DOooool001cooooo00?o0000ooooooooool0Goooool2o`0000;ooooo0_l00007ooooo`;o
00001oooool2o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`;o00001?ooool8o`0001So
oooo0_l0000Uooooo`Co00000_ooool4o`000003ooooool0003o000000cooooo0_l0000;ooooo`;o
0000DOooool001cooooo00?o0000ooooooooool0Goooool2o`0000_ooooo0_l00002ooooo`;o0000
1_ooool2o`000004ooooool0003o0000ooooo`;o00000oooool2o`0000Cooooo2Ol00002ooooo`;o
00002Oooool2o`0000Cooooo0_l0000Hooooo`;o00001?ooool2o`0000Wooooo0_l00002ooooo`;o
00000_ooool2o`000003ooooool0003o000000;ooooo0_l00008ooooo`;o0000G_ooool001cooooo
00?o0000ooooooooool0I?ooool2o`0000;ooooo0_l00006ooooo`;o00001?ooool4o`0000Gooooo
0_l00007ooooo`_o000000?oooooo`000?l000002Oooool2o`0000Cooooo0_l0000Hooooo`;o0000
1?ooool2o`0000Kooooo0_l00005ooooo`;o00002Oooool2o`0006Sooooo000Looooo`03o`000?oo
oooooooo06Cooooo0_l00002ooooo`?o00001_ooool2o`0000?ooooo1_l00003ooooo`;o00001?oo
ool@o`0002Cooooo0_l0000=ooooo`;o00000oooool2o`000003ooooool0003o000000Wooooo0_l0
00000ooooooo0000o`00001Yooooo`007?ooool2o`0005Kooooo0_l0000Aooooo`?o00001_ooool2
o`0000?ooooo2?l00002oooooaSo00008Oooool2o`0000;ooooo0_l00009ooooo`;o00000oooool2
o`000004ooooool0003o0000ooooo`;o00001_ooool5o`0000;ooooo0_l00007ooooo`Co0000F_oo
ool001cooooo00?o0000ooooooooool0EOooool3o`0002Cooooo0_l00002ooooo`go000000?ooooo
o`000?l000002?l0000Qooooo`;o00000_ooool2o`00017ooooo1Ol00007ooooo`Co000000Cooooo
o`000?l0003o00001_ooool7o`0000cooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`1>
ooooo`;o00001?ooool4o`000003ooooool0003o000000Cooooo0_l00008ooooo`;o00005Oooool2
o`0000?ooooo5?l0000gooooo`Co000000?oooooo`000?l000001Oooool4o`000003ooooool0003o
000000?ooooo1_l00002ooooo`Co00001?ooool2o`0000Gooooo0_l00002ooooo`;o0000A_ooool0
01cooooo00?o0000ooooooooool0C_ooool2o`0000Cooooo0_l00003ooooo`Co00000_ooool2o`00
00Sooooo0_l0000HoooooaKo00008Oooool2o`0001Cooooo0ol000001?oooooo0000o`000?l00004
ooooo`;o000000?oooooo`000?l000001?ooool6o`0000Cooooo1?l00004ooooo`;o00002Oooool2
o`0004Kooooo000Looooo`03o`000?oooooooooo03kooooo0_l00002ooooo`;o00005Oooool4o`00
00kooooo0_l0000FoooooaCo00004Oooool2o`00013ooooo0_l0000Aooooo`;o00001Oooool2o`00
0003ooooool0003o000000;ooooo0_l00006ooooo`?o0000Hoooool001cooooo00?o0000oooooooo
ool0?_ooool2o`0000;ooooo1?l0000<ooooo`;o00001?ooool5o`0000kooooo0_l0000@ooooo`;o
00001?ooool9o`0000;ooooo2_l000000ooooooo0000o`00000=ooooo`?o00008?ooool4o`0000Go
oooo0_l000000ooooooo0000o`000006ooooo`;o00000_ooool3o`0000Gooooo1?l0001Jooooo`00
7?ooool00ol0003oooooooooo`14ooooo`;o00001oooool2o`0000?ooooo0_l00004ooooo`;o0000
00?oooooo`000?l000003_ooool2o`0000?ooooo0_l0000;ooooo`;o000000?oooooo`000?l00000
1?l000000ooooooo0000o`000005o`000005ooooool0003o0000o`000?ooool01Ol000000ooooooo
0000o`00000=ooooo`?o00001?ooool2o`0001[ooooo0_l00007ooooo`;o00002Oooool2o`0000;o
oooo0ol00004ooooo`Go00003?ooool2o`0004cooooo000Looooo`03o`000?oooooooooo04gooooo
0ol00004ooooo`;o00001Oooool2o`0000Sooooo0_l00004ooooo`Co000000?oooooo`000?l00000
3_oooolHo`0000_ooooo0_l00003ooooo`;o00001?ooool3o`0001?ooooo0_l0000>ooooo`;o0000
3Oooool2o`0000Gooooo0_l00004ooooo`;o000000?oooooo`000?l000001_ooool2o`0004cooooo
000Looooo`03o`000?oooooooooo03[ooooo0_l0000Booooo`;o00001?ooool4o`0000Kooooo0_l0
0005ooooo`;o00001_ooool2o`0001Cooooo5ol00009ooooo`;o00002Oooool2o`0001Cooooo0_l0
0002ooooo`;o00001_ooool4o`0000Wooooo0_l00004ooooo`;o000000?oooooo`000?l000000ol0
0005ooooo`;o000000?oooooo`000?l00000E?ooool001cooooo00?o0000ooooooooool0>_ooool2
o`0000oooooo0_l00009ooooo`;o00001_ooool2o`0000Cooooo0_l00005ooooo`;o00005_oooolD
o`000003ooooool0003o000000Gooooo0ol0000Iooooo`;o00002oooool2o`0000?ooooo0_l00000
0ooooooo0000o`000002o`0000Wooooo0_l00006ooooo`Ko00001oooool2o`0005Gooooo000Loooo
o`03o`000?oooooooooo03;ooooo0_l00006ooooo`;o000000?oooooo`000?l000003?ooool2o`00
00cooooo0_l00006ooooo`;o000000?oooooo`000?l000001Oooool8o`00017ooooo5_l00005oooo
o`?o00006Oooool2o`00013ooooo0_l000000ooooooo0000o`00000Cooooo`;o00001Oooool2o`00
00?ooooo1?l0000=ooooo`;o0000AOooool001cooooo00?o0000ooooooooool0<_ooool2o`0000Wo
oooo0_l00004ooooo`;o000000?oooooo`000?l000002_ooool3o`0000Cooooo1?l00004ooooo`;o
00002_ooool6o`000003ooooool0003o000000Oooooo0_l00003oooooaSo00004Oooool2o`0001Oo
oooo0_l0000Vooooo`;o000000?oooooo`000?l000001?l0000=ooooo`;o0000AOooool001cooooo
00?o0000ooooooooool0@oooool2o`000003ooooool0003o000000Oooooo0_l000000ooooooo0000
o`000002o`0000Gooooo0_l0000>ooooo`Ko00000oooool2o`0000Oooooo0_l000000ooooooo0000
o`00000Eo`0001?ooooo0ol0000Cooooo`;o00000_ooool2o`0001Gooooo0_l0000Booooo`;o0000
1_ooool2o`0000?ooooo0_l0000Cooooo`;o0000=_ooool001cooooo00?o0000ooooooooool0=?oo
ool2o`0001Sooooo0ol00003ooooo`;o00001oooool2o`0000?ooooo0_l00007ooooo`Co00001Ooo
ool2o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l000003ol000000ooooooo0000o`00
0009ooooo`;o00002?ooool2o`00017ooooo1Ol00002ooooo`;o00004_ooool2o`000003ooooool0
003o000000;ooooo0_l00003ooooo`;o00003oooool4o`0000?ooooo0_l0000Cooooo`;o0000=_oo
ool001cooooo00?o0000ooooooooool0=?ooool2o`00013ooooo0_l000000ooooooo0000o`000003
ooooo`;o00001oooool2o`0000Cooooo0_l00003ooooo`;o00003_ooool4o`0000Cooooo0_l00007
oooooa3o00000_ooool2o`0000Wooooo0_l00006ooooo`;o00002?ooool2o`0000Wooooo1?l00007
ooooo`;o00001Oooool2o`0000Oooooo1?l00002ooooo`?o00000oooool4o`0000gooooo0_l0001B
ooooo`007?ooool00ol0003oooooooooo`16ooooo`;o000000?oooooo`000?l000000oooool2o`00
00Gooooo1?l000000ooooooo0000o`000007ooooo`;o00003Oooool4o`0000Oooooo0_l00006oooo
oa3o00004oooool2o`0000;ooooo0_l00004ooooo`;o00002?ooool3o`000003ooooool0003o0000
00;ooooo0_l000001?oooooo0000o`000?l00005ooooo`;o00002Oooool2o`0000;ooooo0_l00005
ooooo`?o00003Oooool2o`0005;ooooo000Looooo`;o0000Aoooool2o`0000Oooooo0_l00004oooo
o`?o00000_ooool2o`0000Oooooo0ol00008ooooo`;o00000_ooool2o`000003ooooool0003o0000
00Kooooo0_l00007ooooo`;o000000?oooooo`000?l000002_l0000Cooooo`;o00000_ooool2o`00
00Kooooo0_l00005ooooo`oo00003Oooool2o`0001cooooo0_l00003ooooo`Co0000Boooool001co
oooo00?o0000ooooooooool0A_ooool2o`000003ooooool0003o000000;ooooo1?l00007ooooo`;o
00002Oooool3o`000003ooooool0003o000000Gooooo0_l00002ooooo`;o000000?oooooo`000?l0
00001_ooool2o`0000Gooooo0ol00003ooooo`Wo00000_ooool2o`0000oooooo0_l00008ooooo`;o
00000_oooolKo`0000Sooooo1?l00007ooooo`;o00005_ooool4o`0004_ooooo000Looooo`03o`00
0?oooooooooo03oooooo0_l00008ooooo`Ko00001_ooool2o`000003ooooool0003o000000Wooooo
1ol00004ooooo`;o00001Oooool2o`0000gooooo0ol00002ooooo`[o00000_ooool2o`0000oooooo
1?l00006ooooo`;o00000_oooolKo`0000Sooooo1?l00007ooooo`;o00005Oooool2o`000003oooo
ool0003o000004_ooooo000Looooo`03o`000?oooooooooo03oooooo0_l00002ooooo`;o00001_oo
ool2o`0000Sooooo0_l00004ooooo`;o00002?ooool2o`000004ooooool0003o0000o`0000?ooooo
0_l00003ooooo`Co00004_ooool2o`000004ooooool0003o0000ooooo`Co000000?oooooo`000?l0
00004_ooool2o`0000Sooooo5_l000000ooooooo0000o`000004o`0000Gooooo0_l00008ooooo`;o
00003oooool2o`0000Sooooo1Ol0001;ooooo`007?ooool00ol0003oooooooooo`0kooooo`;o0000
1_ooool2o`0001Cooooo1?l00006ooooo`Co00000_ooool2o`0000?ooooo0_l00003ooooo`Co0000
3_ooool2o`0000Cooooo0ol00002ooooo`?o000000?oooooo`000?l000006_ooool5o`0000;ooooo
4Ol00002ooooo`Oo00000oooool2o`0000Sooooo0_l0000?ooooo`;o00002Oooool2o`0004gooooo
000Looooo`03o`000?oooooooooo03_ooooo0_l0000Fooooo`;o00001?ooool2o`0000Sooooo1_l0
0006ooooo`;o00001?ooool2o`0000Gooooo0_l00007ooooo`;o00001?ooool2o`000004ooooool0
003o0000ooooo`;o00007?ooool5o`0000;ooooo1Ol000000ooooooo0000o`00000Eo`0000Kooooo
0_l0000Oooooo`Co0000Boooool001cooooo00?o0000ooooooooool0??ooool2o`0000Wooooo0_l0
000:ooooo`;o00003_ooool2o`0000;ooooo0ol00005ooooo`;o00002Oooool4o`0000?ooooo0_l0
0004ooooo`;o00000oooool4o`0001?ooooo0_l00008ooooo`ko00000ooooolAo`0000;ooooo0ol0
0005ooooo`;o00004?ooool2o`0000gooooo1?l0001;ooooo`007?ooool00ol0003oooooooooo`0l
ooooo`;o00002?ooool3o`0000Gooooo0_l00006ooooo`Go00000_ooool2o`0000?ooooo0_l00004
ooooo`Co00003_ooool3o`0000Cooooo0_l000001?oooooo0000o`000?ooool3o`0000;ooooo0_l0
000Dooooo`?o00001_oooolUo`000003ooooool0003o000000?o00001oooool2o`0000Wooooo0_l0
00000ooooooo0000o`00000=ooooo`;o000000?oooooo`000?l000000_l00018ooooo`007?ooool0
0ol0003oooooooooo`16ooooo`;o00001_ooool2o`0000Kooooo1Ol00002ooooo`;o00000_ooool3
o`0000Kooooo0_l00008ooooo`?o000000Coooooo`000?l0003ooooo1?l00005ooooo`;o00000_oo
ool2o`0001Sooooo0_l00006ooooo`?o00000_ooool2o`000003ooooool0003o000002;o00001?oo
ool2o`000003ooooool0003o000000?o00001_ooool2o`000003ooooool0003o000000Sooooo0_l0
0006ooooo`Co0000B?ooool001cooooo00?o0000ooooooooool0Aoooool2o`0000Cooooo0_l00008
ooooo`;o00001?ooool3o`000003ooooool0003o000000;ooooo0_l0000=ooooo`?o000000Cooooo
o`000?l0003ooooo1?l00005ooooo`;o00000_ooool2o`0000Cooooo0_l0000?ooooo`;o00000_oo
ool2o`0000Gooooo0_l00005ooooo`go000000?oooooo`000?l000005Ol00004ooooo`;o00000ooo
ool3o`0000Wooooo0_l00008ooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0@oooool2
o`0000;ooooo0_l00004ooooo`;o00003_ooool3o`0000Gooooo0_l00003ooooo`;o00001oooool2
o`0000Kooooo0_l000000ooooooo0000o`000003ooooo`;o00002Oooool2o`0000gooooo1?l00002
ooooo`;o00001?ooool4o`0000?ooooo9Ol000000ooooooo0000o`000002o`0000;ooooo0_l00005
ooooo`;o00001_ooool2o`0000Sooooo0_l00002ooooo`;o00001?ooool4o`0000cooooo0_l0000h
ooooo`007?ooool00ol0003oooooooooo`0jooooo`;o00001oooool2o`0000Sooooo0_l00002oooo
o`;o00002Oooool4o`0000Kooooo0_l00002ooooo`?o00001_ooool2o`0000Wooooo1?l000001?oo
oooo0000o`000?ooool2o`0001Gooooo0ol00009ooooo`Go000000?oooooo`000?l000008ol00002
ooooo`Co00000_ooool2o`0000Gooooo0_l0000Dooooo`Co00000_ooool4o`0000cooooo0_l0000h
ooooo`007?ooool00ol0003oooooooooo`0jooooo`;o00001?ooool2o`0000;ooooo0_l00005oooo
o`Co00000_ooool2o`0000Sooooo2_l000000ooooooo0000o`000003ooooo`;o00001_ooool4o`00
00Gooooo0_l00002ooooo`;o00001?ooool2o`00027ooooo1Ol000000ooooooo0000o`00000Uo`00
00;ooooo1?l0000Kooooo`Ko00004?ooool2o`0003[ooooo000Looooo`03o`000?oooooooooo03Oo
oooo0_l00007ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo0ol0000=ooooo`;o
00000_ooool6o`0000;ooooo1?l000001?oooooo0000o`000?l00006ooooo`;o00000_ooool2o`00
0003ooooool0003o000000Sooooo0_l0000<ooooo`;o00005?ooool2o`0000?ooooo1_l00002oooo
o`Oo000000?oooooo`000?l000005Ol00002ooooo`Co00003oooool2o`0000[ooooo1?l0000Boooo
o`;o000000?oooooo`000?l00000=oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2
ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo03Oooooo0_l00008
ooooo`Go000000?oooooo`000?l000000_ooool6o`0001;ooooo0_l00002ooooo`Co000000Cooooo
o`000?l0003o00002_ooool2o`0000_ooooo0_l0000:ooooo`Co00005?ooool2o`0000;ooooo9ol0
0004ooooo`Co00003_ooool2o`0000cooooo0_l0000Eooooo`;o0000=oooool00006oooooomgMgOo
V9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0gooooo`;o00002?ooool5o`0000Gooooo0_l000001?oooooo0000o`000?l0000Booooo`;o
00002?ooool2o`0000Oooooo0_l0000Dooooo`;o00001?ooool2o`0000kooooo1?l00003ooooo`?o
00000_ooool2o`000003ooooool0003o000002;o00001Oooool3o`0000;ooooo0_l0001Xooooo`00
00?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`Go00001_ooool00ol0003ooooo
ooooo`0booooo`;o00000oooool2o`0001Kooooo0_l00007ooooo`;o00002Oooool2o`0000;ooooo
0_l00004ooooo`;o00001oooool2o`0000[ooooo0_l00008ooooo`;o00003?ooool2o`0000Cooooo
1_l00003ooooo`;o00000oooool2o`0000?ooooo1?l000000ooooooo0000o`00000?o`000003oooo
ool0003o000000Oo00000oooool7o`0000;ooooo0ol0000Booooo`;o00001_ooool2o`000003oooo
ool0003o000000;ooooo0_l00014ooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooooooo
o`09ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0000booooo`;o000000?oooooo`000?l00000
0_ooool2o`0000Wooooo0_l000000ooooooo0000o`00000?ooooo`Co00001oooool2o`0000;ooooo
0_l0000Iooooo`?o00005Oooool2o`0000Cooooo0ol00006ooooo`;o000000?oooooo`000?l00000
1ol00004oooooa[o00000oooool7o`0000?ooooo1?l0000@ooooo`;o00001?ooool7o`0000;ooooo
0_l00007ooooo`;o00001_ooool2o`0003?ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oo
oooooooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`0eooooo`;o0000
0_ooool2o`0000Wooooo0_l000000ooooooo0000o`000004ooooo`;o00000_ooool6o`0000;ooooo
1?l0000Dooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00007?ooool2o`0000Gooooo
0ol000001?oooooo0000o`000?ooool4o`0000Oooooo3?l000000ooooooo0000o`000009o`000003
ooooool0003o000000;ooooo0_l00006ooooo`Go00001_ooool2o`0000Gooooo1?l00005ooooo`;o
00000_ooool2o`0000_ooooo0ol00006ooooo`;o0000<oooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool02_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo03kooooo
1?l00009ooooo`Co00000_ooool<o`0001Cooooo0_l00004ooooo`;o00001?ooool3o`000005oooo
ool0003o0000o`000?ooool00_l0000;ooooo`;o00003Oooool2o`0000Gooooo0ol000001?oooooo
0000o`000?ooool4o`0000Wooooo2_l000000ooooooo0000o`000007o`0000?ooooo0ol00009oooo
o`;o00002Oooool2o`0000Gooooo1?l0000;ooooo`;o00000_ooool2o`0000Gooooo0_l000000ooo
oooo0000o`00000iooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co
000000Oooooo00?o0000ooooooooool0?_ooool4o`0000;ooooo0_l00005ooooo`;o00002_ooool3
o`000003ooooool0003o000001Gooooo0_l000000ooooooo0000o`000004o`0000?ooooo1_l00000
0ooooooo0000o`000006ooooo`;o00000oooool2o`0000cooooo0_l00007ooooo`;o000000?ooooo
o`000?l000003ooooolBo`0000Gooooo0_l00009ooooo`;o00002oooool2o`0001;ooooo0_l00002
ooooo`;o00002?ooool2o`0003Wooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPgooooo00?o
MgMgo`000?ooool01_ooool00ol0003oooooooooo`14ooooo`Co00001Oooool2o`0000Kooooo0_l0
00000ooooooo0000o`000003o`0000?ooooo0_l0000=ooooo`;o000000Coooooo`000?l0003ooooo
1_l00004ooooo`;o00001?ooool5o`0000?ooooo0_l0000Aooooo`;o00001_ooool2o`0000Cooooo
0_l0000?ooooo`go00008?ooool4o`0001cooooo0_l0000kooooo`007?ooool00ol0003ooooooooo
o`0mooooo`;o00000oooool6o`0000Gooooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo0_l0
0004ooooo`;o00000_ooool2o`0000Oooooo1?l00006ooooo`;o00001?ooool4o`0000Cooooo1Ol0
000>ooooo`;o00003_ooool2o`0000Cooooo0_l00003ooooo`;o00002Oooool2o`000003ooooool0
003o000000Co000000?oooooo`000?l000001?l0000Eooooo`;o00002Oooool2o`0001cooooo0_l0
000kooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00000_ooool3o`0000gooooo0_l0000A
ooooo`;o00001oooool4o`0000Gooooo1?l00003ooooo`Co00001oooool2o`0000Kooooo0_l00006
ooooo`;o00003_ooool2o`0000Wooooo0_l00004ooooo`;o00000oooool2o`0000Cooooo0ol00000
0ooooooo0000o`000004o`0000cooooo0_l00007ooooo`;o00000oooool2o`00017ooooo0_l0000A
ooooo`;o0000>Oooool001cooooo00?o0000ooooooooool0?oooool4o`0000Kooooo0_l000000ooo
oooo0000o`000004o`000003ooooool0003o000000[ooooo0_l0000<ooooo`Co00000oooool9o`00
0003ooooool0003o000000?o00002?ooool2o`0000?ooooo0_l00004ooooo`Co00001Oooool2o`00
00Oooooo0ol00008ooooo`;o00001?ooool2o`0000[ooooo0ol00008ooooo`;o00000_ooool2o`00
00Cooooo0ol0000;ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l00004oooo
o`;o00004Oooool2o`0003Wooooo000Looooo`03o`000?oooooooooo01gooooo0_l0000Pooooo`;o
00002?ooool2o`000003ooooool0003o000000Co000000?oooooo`000?l000002_ooool2o`0000;o
oooo1?l0000=ooooo`oo00002?ooool2o`0000Wooooo1?l00005ooooo`;o000000?oooooo`000?l0
00000oooool4o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000Wooooo0_l00006oooo
o`;o00002?ooool2o`0000;ooooo0_l00005ooooo`;o00001Oooool2o`0000Cooooo0_l000000ooo
oooo0000o`000002ooooo`;o00001?ooool2o`0000[ooooo0_l00016ooooo`007?ooool00ol0003o
ooooooooo`0Mooooo`;o00007oooool3o`0000Gooooo0_l000001?oooooo0000o`000?l0000@oooo
o`;o00001Oooool4o`0000Gooooo0_l00003ooooo`;o000000?oooooo`000?l000000ol000000ooo
oooo0000o`000003o`0000;ooooo0_l000001?oooooo0000o`000?l00005ooooo`;o00002Oooool2
o`0000Cooooo1?l000000ooooooo0000o`000003ooooo`Co000000Coooooo`000?l0003ooooo0_l0
000=ooooo`;o00004Oooool4o`0000gooooo0_l00003ooooo`?o00005oooool2o`0004Kooooo000L
ooooo`03o`000?oooooooooo03kooooo0ol00004ooooo`?o00000_ooool2o`000003ooooool0003o
000000Wooooo0_l00002ooooo`;o00003_ooool2o`0000?ooooo0_l00004ooooo`;o000000?ooooo
o`000?l000000_l00003ooooo`;o000000Coooooo`000?l0003o00001Oooool2o`000003ooooool0
003o000000cooooo0_l000000ooooooo0000o`000006ooooo`;o00001Oooool2o`0000_ooooo0_l0
000=ooooo`;o00001?ooool4o`0000gooooo0_l00003ooooo`;o00001oooool4o`0000Wooooo0_l0
0002ooooo`?o0000AOooool001cooooo00?o0000ooooooooool0=oooool2o`0000Gooooo0_l00005
ooooo`;o00001_ooool2o`0000Oooooo1?l00003ooooo`Ko00003?ooool2o`0000Cooooo1?l00000
0ooooooo0000o`000003o`0000?ooooo0_l000000ooooooo0000o`000006o`0000;ooooo0_l0000;
ooooo`;o000000Coooooo`000?l0003o00000oooool2o`0000;ooooo0ol00003ooooo`?o00002_oo
ool4o`0000_ooooo0_l00004ooooo`;o00005?ooool2o`0000?ooooo0_l00002ooooo`Co00000ooo
ool4o`0000;ooooo0_l00003ooooo`;o00002_ooool2o`0003Wooooo000Looooo`03o`000?oooooo
oooo02kooooo0_l00007ooooo`;o00006_ooool2o`000003ooooool0003o000000Gooooo1_l0000:
ooooo`Co00000oooool=o`000003ooooool0003o000000Wo00003oooool2o`000004ooooool0003o
0000o`0000?ooooo2?l00003ooooo`?o00002oooool2o`0000?ooooo0_l0000<ooooo`?o00000_oo
ool4o`0000Kooooo1?l00008ooooo`;o00000oooool5o`000003ooooool0003o000000;o00001?oo
ool2o`0000gooooo0_l00007ooooo`;o0000<?ooool001cooooo00?o0000ooooooooool0;_ooool2
o`0000Sooooo0_l0000Iooooo`;o000000?oooooo`000?l000000_l0000<ooooo`;o00001?ooool4
o`000004ooooool0003o0000oooooaKo00000oooool2o`0000Gooooo0ol00004ooooo`;o00000_oo
ool3o`0000Gooooo0_l000001?oooooo0000o`000?l00004ooooo`;o00004?ooool2o`000003oooo
ool0003o000000[ooooo2?l00006ooooo`Co00003_ooool4o`0000Wooooo0ol000000ooooooo0000
o`00000@ooooo`Co0000<?ooool001cooooo00?o0000ooooooooool0>?ooool2o`0001_ooooo1Ol0
0003ooooo`;o00001oooool2o`000003ooooool0003o000000Go000000Coooooo`000?l0003ooooo
4?l000000ooooooo0000o`000005o`000003ooooool0003o000000Gooooo0ol00004ooooo`;o0000
00?oooooo`000?l000000oooool2o`0000Gooooo0ol00005ooooo`;o00001oooool2o`0000Wooooo
0_l0000;ooooo`Co00002oooool2o`0000Kooooo0_l0000Dooooo`;o000000?oooooo`000?l00000
4?ooool2o`0003;ooooo000Looooo`03o`000?oooooooooo04Wooooo0_l00008ooooo`Co00000ooo
ool2o`000003ooooool0003o000000;o00001?ooool2o`000003ooooool0003o000000Co00000_oo
ool2o`000003ooooool0003o000001Oo00000oooool2o`0000[ooooo0_l000000ooooooo0000o`00
0003ooooo`;o000000?oooooo`000?l000000_ooool3o`000003ooooool0003o000000;ooooo0_l0
0007ooooo`;o00002_ooool2o`0000cooooo0_l0000=ooooo`;o00001?ooool2o`0000Sooooo0_l0
0009ooooo`;o00001?ooool2o`0000kooooo0_l0000booooo`007?ooool2o`0004Kooooo0_l00002
ooooo`?o000000?oooooo`000?l000001?ooool2o`0000Gooooo0_l00003ooooo`;o000000Cooooo
o`000?l0003ooooo1_l00003ooooo`Co000000?oooooo`000?l000004Ol000000ooooooo0000o`00
0002o`0000;ooooo1?l0000:ooooo`;o000000?oooooo`000?l000001_ooool7o`000003ooooool0
003o000001Oooooo0_l0000<ooooo`;o00003Oooool2o`0000?ooooo1?l00007ooooo`Co00000ooo
ool2o`0000;ooooo0_l00004ooooo`;o00003_ooool2o`0003;ooooo000Looooo`03o`000?oooooo
oooo02Sooooo0_l0000Aooooo`;o00001?ooool2o`0000;ooooo0_l00003ooooo`;o000000?ooooo
o`000?l000004oooool2o`0000?ooooo0_l00005ooooo`ko000000?oooooo`000?l000001ol00000
0ooooooo0000o`000004ooooo`;o00003_ooool2o`0000Wooooo1_l00006ooooo`;o00003Oooool3
o`0002?ooooo1?l00008ooooo`Co00000_ooool3o`0000Cooooo0_l0000;ooooo`;o00001?ooool2
o`0003;ooooo000Looooo`03o`000?oooooooooo02Sooooo0_l0000@ooooo`?o00001?ooool2o`00
00Gooooo0_l000000ooooooo0000o`000002o`0000Kooooo0_l00003ooooo`;o00001?ooool2o`00
00Gooooo0_l000000ooooooo0000o`000002oooooaco000000?oooooo`000?l000004?ooool2o`00
00gooooo1?l00004ooooo`;o00002?ooool2o`0000?ooooo0ol0000;ooooo`;o00008Oooool2o`00
0003ooooool0003o000000?ooooo0_l00002ooooo`Go00002_ooool2o`0003Sooooo000Looooo`03
o`000?oooooooooo03[ooooo0_l00004ooooo`;o00001_ooool2o`000003ooooool0003o000000;o
00001_ooool4o`000003ooooool0003o000000Cooooo0ol00003ooooo`?o000000Coooooo`000?l0
003ooooo8?l00003ooooo`;o00006oooool3o`0000Wooooo0_l00003ooooo`;o00004Oooool3o`00
01Sooooo0_l00006ooooo`;o00002Oooool3o`000003ooooool0003o000000Cooooo0_l0000noooo
o`007?ooool00ol0003oooooooooo`10ooooo`?o00004_ooool4o`0000Sooooo1?l000001?oooooo
0000o`000?oooolJo`000003ooooool0003o000000Oo00000oooool2o`0001cooooo0_l000001?oo
oooo0000o`000?l00005ooooo`;o00002?ooool2o`0000Gooooo0_l00006ooooo`;o00005oooool3
o`0000;ooooo0_l00004ooooo`Co00001Oooool2o`0000Sooooo0_l0000:ooooo`;o00002_ooool2
o`0002Kooooo000Looooo`03o`000?oooooooooo047ooooo1?l000001?oooooo0000o`000?l00002
ooooo`;o00005_ooool3o`0000;ooooo9?l00005ooooo`Co00005oooool3o`0000;ooooo2?l0000:
ooooo`;o00001Oooool2o`0000Wooooo0_l0000Dooooo`;o00000oooool2o`0000Cooooo1?l0000<
ooooo`Co00000oooool2o`0000Kooooo0_l0000:ooooo`;o00009_ooool001cooooo00?o0000oooo
ooooool0=oooool2o`0000Wooooo0ol000000ooooooo0000o`000002o`000003ooooool0003o0000
01Oooooo9ol00006ooooo`Co00004?ooool2o`0000;ooooo0_l000001?oooooo0000o`000?l00004
ooooo`go00005Oooool2o`0000_ooooo0_l0000>ooooo`?o00003?ooool2o`0000?ooooo1?l00003
ooooo`;o00002oooool2o`0002gooooo000Looooo`03o`000?oooooooooo03Oooooo0_l00009oooo
o`;o00001?ooool2o`0000Kooooo0_l00003ooooo`;o00000_ooool2o`0000[ooooo8Ol000000ooo
oooo0000o`000002o`000004ooooool0003o0000ooooo`;o000000Coooooo`000?l0003ooooo0_l0
000:ooooo`;o00000_ooool2o`0000;ooooo0_l0000>ooooo`_o00001Oooool2o`0001Cooooo0_l0
00000ooooooo0000o`00000<ooooo`Go00003?ooool3o`0000;ooooo0_l0000Booooo`;o0000;Ooo
ool001cooooo00?o0000ooooooooool0=_ooool2o`0000[ooooo0_l00002ooooo`;o00002?ooool2
o`0000?ooooo0_l00002ooooo`;o00001Oooool2o`0000?ooooo0ol000000ooooooo0000o`00000P
o`000003ooooool0003o000000?o00001?ooool2o`0000[ooooo0_l00009ooooo`;o00003?ooool2
o`0000;ooooo1_l000000ooooooo0000o`000002ooooo`;o00005?ooool2o`0000oooooo0_l0000@
ooooo`?o000000?oooooo`000?l00000@Oooool001cooooo00?o0000ooooooooool0=_ooool2o`00
00Kooooo0_l00004ooooo`Co00001?ooool2o`0000?ooooo0_l00006ooooo`;o00001Oooool2o`00
00?ooooo0ol000000ooooooo0000o`00000Po`000003ooooool0003o000000Co00000_ooool2o`00
00Kooooo0_l00003ooooo`;o00002Oooool4o`0000Oooooo0_l00008ooooo`;o00000_ooool2o`00
0003ooooool0003o000000Go00001oooool2o`0000Oooooo0_l0000Gooooo`;o00002Oooool2o`00
013ooooo0_l0000booooo`007?ooool00ol0003oooooooooo`0nooooo`;o00001?ooool2o`0000Ko
oooo0_l00003ooooo`;o00004Oooool3o`000003ooooool0003o000000Oo00000_oooolHo`000003
ooooool0003o000000Co00000_ooool2o`0000Gooooo0ol0000@ooooo`;o00001oooool2o`0000So
oooo0_l00005ooooo`Oo000000?oooooo`000?l000001?ooool2o`0000Gooooo1?l0000Gooooo`;o
00003?ooool2o`0000Gooooo0_l00006ooooo`?o0000<Oooool001cooooo00?o0000ooooooooool0
9_ooool2o`0001Kooooo0ol0000Rooooo`?o00000_ooool9o`0000;ooooo6?l00003ooooo`Co0000
2Oooool2o`0000Gooooo0_l0000<ooooo`;o00002_ooool4o`0000Wooooo0_l00005ooooo`;o0000
0oooool2o`0000Cooooo1?l00002ooooo`;o00001?ooool2o`0000oooooo0_l00009ooooo`;o0000
00?oooooo`000?l000001Oooool2o`0000Oooooo0_l0000aooooo`007?ooool00ol0003ooooooooo
o`0Vooooo`;o00004_ooool2o`0000;ooooo0ol00009ooooo`Co00005OoooolVo`000003ooooool0
003o000000Ko00002oooool2o`0000?ooooo0_l00009ooooo`;o000000?oooooo`000?l000002_oo
ool6o`0000Sooooo0_l00009ooooo`Co00000_ooool2o`0000Cooooo0_l00004ooooo`;o00003?oo
ool2o`000003ooooool0003o000000Sooooo0ol000000ooooooo0000o`000011ooooo`007?ooool0
0ol0003oooooooooo`0jooooo`;o00000oooool2o`0000Wooooo1_l0000;ooooo`;o00000_ooool;
o`000003ooooool0003o000001co000000?oooooo`000?l000001?l0000=ooooo`;o00003_ooool2
o`00017ooooo0_l00008ooooo`;o00001oooool2o`000005ooooool0003o0000o`000?ooool00_l0
0004ooooo`;o00002?ooool2o`0000Cooooo0_l00003ooooo`Co00002Oooool2o`0000;ooooo0_l0
000>ooooo`;o0000<Oooool001cooooo00?o0000ooooooooool0?oooool2o`0000Cooooo0_l00004
ooooo`;o000000?oooooo`000?l000002oooool2o`0000;ooooo1?l000000ooooooo0000o`000002
ooooob?o00002?ooool2o`0000;ooooo0_l0000Tooooo`;o00001?ooool2o`0000cooooo1?l00004
ooooo`?o000000Coooooo`000?l0003ooooo0ol00007ooooo`;o00001?ooool2o`0000Cooooo1?l0
00001?oooooo0000o`000?ooool2o`0001Kooooo0_l0000aooooo`007?ooool00ol0003ooooooooo
o`0jooooo`;o00002Oooool2o`0000Cooooo0_l0000:ooooo`;o00001_ooool2o`0000?ooooo0_l0
0002ooooob?o00001?ooool2o`0000;ooooo1_l0000=ooooo`;o00000_ooool2o`0000[ooooo0_l0
0004ooooo`Wo00000_ooool2o`0000Sooooo1?l00003ooooo`Oo00000_ooool2o`0000Wooooo0_l0
0004ooooo`;o00000_ooool4o`000004ooooool0003o0000ooooo`;o0000BOooool001cooooo0_l0
000kooooo`;o00003Oooool2o`0000cooooo0ol00005ooooo`?o000000Coooooo`000?l0003o0000
0_oooolIo`000003ooooool0003o000000So000000?oooooo`000?l000000_l000001?oooooo0000
o`000?ooool2o`0000oooooo0_l000001?oooooo0000o`000?l0000:ooooo`;o00001?ooool2o`00
0003ooooool0003o000000;o00001?ooool2o`0000[ooooo0_l00003ooooo`Go00001Oooool2o`00
00Sooooo0_l00003ooooo`?o00003oooool2o`0004Cooooo000Looooo`03o`000?oooooooooo01oo
oooo0_l0000Dooooo`;o00004_ooool2o`0000gooooo0_l00006ooooo`Ko000000?oooooo`000?l0
00006?l000000ooooooo0000o`00000;o`0000?ooooo0_l00005ooooo`;o00003_ooool2o`0000So
oooo0_l0000Aooooo`;o00004oooool4o`0000?ooooo1_l00009ooooo`Co00001?ooool2o`0000So
oooo0_l00002ooooo`;o00003_ooool2o`00033ooooo000Looooo`03o`000?oooooooooo01oooooo
0_l00004ooooo`;o00003_ooool2o`0001Cooooo0_l00005ooooo`;o00001oooool2o`000003oooo
ool0003o000000Go000000?oooooo`000?l000006Ol000000ooooooo0000o`000006o`000004oooo
ool0003o0000o`0000Kooooo0_l00003ooooo`;o000000?oooooo`000?l000002oooool2o`0000So
oooo0_l00006ooooo`;o00000_ooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Ko
oooo0_l00002ooooo`Wo00002Oooool2o`0000;ooooo1Ol00006ooooo`;o00000_ooool3o`0000[o
oooo0_l00002ooooo`;o0000<?ooool001cooooo00?o0000ooooooooool09Oooool2o`0000kooooo
0_l0000:ooooo`;o00002?ooool2o`0000Gooooo0_l00005ooooo`Co000000?oooooo`000?l00000
:Ol000000ooooooo0000o`000002o`0000;ooooo1ol00005ooooo`;o00002oooool2o`0000[ooooo
0_l00004ooooo`Ko00001?ooool2o`000003ooooool0003o000000Cooooo0_l00005ooooo`;o0000
2_ooool2o`0000;ooooo1Ol0000=ooooo`Go00001_ooool2o`0000;ooooo0ol0000:ooooo`;o0000
=?ooool001cooooo00?o0000ooooooooool0=Oooool2o`0000?ooooo0_l00005ooooo`;o00001Ooo
ool2o`0000_ooooo0_l00002ooooo`;o00001?ooool^o`000003ooooool0003o000000Co000000?o
ooooo`000?l000002oooool2o`00017ooooo0ol00005ooooo`;o00001_ooool6o`0001_ooooo1Ol0
0008ooooo`;o00001Oooool4o`0000Cooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`0a
ooooo`;o00001oooool2o`0000Cooooo0_l00006ooooo`;o00002_ooool5o`0000;ooooo0_l00006
ooooo`?o000000?oooooo`000?l000008_l00003ooooo`?o00004Oooool2o`0001;ooooo0_l00004
ooooo`?o00002?ooool4o`0001?ooooo0_l00007ooooo`Co000000?oooooo`000?l000001?l00000
0ooooooo0000o`000002o`0000Gooooo0_l0000Hooooo`;o0000<Oooool001cooooo00?o0000oooo
ooooool0<Oooool2o`0000Wooooo0_l00002ooooo`;o00004_ooool2o`000003ooooool0003o0000
00;ooooo0_l00005ooooo`?o000000?oooooo`000?l000008ol00002ooooo`Co00002?ooool2o`00
00Oooooo1?l0000Eooooo`Co00002oooool2o`0001;ooooo1?l00004ooooo`co00000oooool2o`00
01gooooo1?l0000aooooo`007?ooool00ol0003oooooooooo`0looooo`;o00000_ooool2o`0000?o
oooo0_l00002ooooo`Ko00003Oooool2o`0000Cooooo:Ol00002ooooo`Co00001_ooool4o`0000Wo
oooo0_l0000?ooooo`;o00000oooool4o`0000Wooooo0_l000001Ooooooo0000o`000?l0003ooooo
00;o00003_ooool4o`0000Cooooo0_l00002ooooo`Oo00008oooool2o`0003?ooooo000Looooo`03
o`000?oooooooooo04Gooooo0_l00002ooooo`Ko00000oooool3o`0000Oooooo0_l00004ooooo`Ko
000000?oooooo`000?l000008Ol0000;ooooo`;o00004?ooool2o`0000Cooooo0ol00003ooooo`;o
00000oooool7o`0000Cooooo1?l00002ooooo`;o000000?oooooo`000?l000001_l00008ooooo`?o
00002Oooool2o`0000;ooooo0_l0000>ooooo`;o00002_ooool2o`0003gooooo000Looooo`03o`00
0?oooooooooo03?ooooo0_l00002ooooo`Co00001?ooool2o`000003ooooool0003o000000kooooo
0ol00004ooooo`;o00001_ooool4o`0000?ooooo0_l000000ooooooo0000o`000002oooooago0000
0_ooool2o`0000Kooooo0_l00009ooooo`;o00001_ooool2o`0000Cooooo0ol0000<ooooo`?o0000
1?ooool2o`000003ooooool0003o000000co00000_ooool2o`0000Gooooo0_l00009ooooo`?o0000
1_ooool2o`0000Wooooo0ol00009ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0<Ooo
ool4o`0000;ooooo1_l00002ooooo`;o000000Coooooo`000?l0003ooooo0ol00003ooooo`;o0000
3?ooool2o`0000Kooooo1?l00003ooooo`;o00000_ooool2o`000003ooooool0003o000001Wo0000
0_ooool4o`000004ooooool0003o0000ooooo`Co00002Oooool2o`00013ooooo0_l00005ooooo`;o
00003?oooolBo`00013ooooo1?l00003ooooo`Co00002?ooool4o`0000?ooooo0_l0000=ooooo`;o
0000=?ooool001cooooo00?o0000ooooooooool0<Oooool3o`0000Oooooo0_l00002ooooo`;o0000
00Coooooo`000?l0003ooooo0ol00003ooooo`;o00003Oooool2o`0000_ooooo6?l000000ooooooo
0000o`000007o`0000?ooooo1?l000001?oooooo0000o`000?ooool2o`00013ooooo0_l0000;oooo
o`;o00001Oooool2o`0000Kooooo1?l000000ooooooo0000o`00000Eo`0000gooooo2?l000000ooo
oooo0000o`000002ooooo`;o00000oooool4o`0000?ooooo0_l0000=ooooo`;o0000=?ooool001co
oooo00?o0000ooooooooool0<_ooool2o`0000[ooooo0_l00002ooooo`?o00004_ooool5o`0000Ko
oooo1?l000000ooooooo0000o`00000Lo`000003ooooool0003o000000Go000000Coooooo`000?l0
003o00000oooool3o`0000oooooo0_l0000Joooooaco00000_ooool2o`0000Wooooo2?l000000ooo
oooo0000o`000002ooooo`;o00001Oooool2o`0004Sooooo000Looooo`03o`000?oooooooooo03[o
oooo0_l000001?oooooo0000o`000?l00003ooooo`?o00003Oooool2o`0000;ooooo2?l00003oooo
o`Co00001?ooool4o`000003ooooool0003o000001go000000?oooooo`000?l000001?ooool2o`00
00;ooooo0_l00004ooooo`;o00001_ooool2o`0001cooooo6?l00003ooooo`;o00002Oooool8o`00
00?ooooo0_l00007ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0>_ooool2o`000003
ooooool0003o000000Gooooo0_l00004ooooo`;o00001oooool2o`0000Kooooo1?l0000;ooooo`;o
00001OoooolBo`0000;ooooo0ol00004ooooo`Go00001Oooool5o`0000Cooooo0_l00004ooooo`Co
00001Oooool2o`0001;ooooo0_l00002oooooaSo00000oooool2o`0000Cooooo0_l00002ooooo`Go
00001?ooool6o`0001;ooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0nooooo`;o0000
2_ooool2o`0001;ooooo0_l00004ooooo`;o00002?ooool2o`000003ooooool0003o000000;o0000
00?oooooo`000?l000003Ol000001Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`000?l0
00001oooool3o`0000cooooo0_l00007ooooo`;o00002oooool2o`0000Gooooo5Ol00002ooooo`Oo
000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000004ooooo`Co00000oooool6o`00
00[ooooo0_l00006ooooo`;o0000>oooool001cooooo0_l0000oooooo`;o00007_ooool2o`0000Co
oooo1?l00006ooooo`;o00000_ooool4o`000003ooooool0003o0000013o000000Coooooo`000?l0
003o00002_ooool3o`0000Kooooo0_l0000:ooooo`;o00003Oooool2o`0000Gooooo7_l000001?oo
oooo0000o`000?ooool3o`0000Kooooo1?l0000Booooo`Go00001oooool2o`0003Sooooo000Loooo
o`03o`000?oooooooooo05kooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`00
00;ooooo0ol000000ooooooo0000o`000002o`000003ooooool0003o000000Go000000?oooooo`00
0?l000002Ol000000ooooooo0000o`000003ooooo`;o00001_ooool2o`0000Cooooo1?l0000:oooo
o`;o00001_ooool2o`0000cooooo1_l000000ooooooo0000o`00000Eo`0000Gooooo0_l00006oooo
o`Co00001_ooool2o`0000;ooooo0_l00006ooooo`;o000000?oooooo`000?l000001oooool2o`00
03Sooooo000Looooo`03o`000?oooooooooo03Gooooo2?l0000Eooooo`;o00001Oooool2o`0000?o
oooo0_l00003ooooo`;o00001Oooool7o`000004ooooool0003o0000o`0000;ooooo0_l000000ooo
oooo0000o`000003o`000003ooooool0003o000000;o000000?oooooo`000?l000000ol00006oooo
o`;o00003?ooool2o`0000_ooooo0ol00004ooooo`Co00003?ooool@o`000003ooooool0003o0000
00_o00001Oooool2o`0000Kooooo1?l00006ooooo`;o00000_ooool2o`0004cooooo000Looooo`03
o`000?oooooooooo03Cooooo2ol0000Cooooo`;o00001Oooool2o`0000gooooo2?l00002ooooo`;o
00001Oooool3o`000004ooooool0003o0000ooooo`Co000000Coooooo`000?l0003o00005Oooool2
o`0000_ooooo1?l00004ooooo`Ko00002_oooolLo`0000Oooooo0_l00003ooooo`;o00000oooool3
o`0000Wooooo0_l0000<ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0;_ooool2o`00
00Cooooo0_l00007ooooo`;o00007oooool4o`0000Kooooo0_l00004ooooo`Ko00000oooool5o`00
0003ooooool0003o000000?ooooo0_l00007ooooo`;o00004?ooool2o`0000;ooooo0_l00007oooo
o`;o00002?ooool4o`0000cooooo6ol0000;ooooo`Go000000?oooooo`000?l000001_ooool2o`00
0004ooooool0003o0000ooooo`;o000000?oooooo`000?l000001_ooool2o`0000?ooooo0_l0000i
ooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00001_ooool4o`0000Sooooo0_l0000Joooo
o`Ko00002oooool3o`0000;ooooo0_l000000ooooooo0000o`000004o`0000Gooooo0_l00004oooo
o`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o00002oooool2o`000003ooooool0003o
000000_ooooo0_l000000ooooooo0000o`00000?oooooaco00000_ooool2o`0000Gooooo1Ol00009
ooooo`;o00001?ooool2o`000003ooooool0003o000000_ooooo0_l0000iooooo`007?ooool00ol0
003oooooooooo`0dooooo`Ko00002?ooool2o`000003ooooool0003o000001Kooooo0_l000000ooo
oooo0000o`000002o`00013ooooo0_l00004ooooo`?o000000?oooooo`000?l000001ol000000ooo
oooo0000o`000004ooooo`Co00000_ooool2o`0000kooooo0_l00006ooooo`;o00000oooool2o`00
0003ooooool0003o000000oooooo6Ol000001Ooooooo0000o`000?l0003ooooo00;o00001Oooool3
o`0000Oooooo0_l00005ooooo`;o00005Oooool2o`0003Gooooo000Looooo`03o`000?oooooooooo
03Cooooo0_l00004ooooo`;o00002Oooool2o`0001Kooooo0_l0000>ooooo`;o00000oooool2o`00
00Cooooo3ol00002ooooo`?o00001?ooool3o`000003ooooool0003o000001Kooooo1Ol00003oooo
o`;o00003ooooolJo`000003ooooool0003o000000Sooooo0ol00007ooooo`;o00001Oooool2o`00
01Cooooo0ol0000eooooo`007?ooool00ol0003oooooooooo`0iooooo`?o00002?ooool2o`0000oo
oooo0_l0000Fooooo`;o00000oooool2o`0000Cooooo1?l000000ooooooo0000o`00000:ooooo`Co
00001?ooool5o`0001Sooooo0ol00002ooooo`Go00001ooooolPo`0000[ooooo0ol0000=ooooo`So
00004?ooool2o`0000Wooooo0_l0000[ooooo`007?ooool00ol0003oooooooooo`0iooooo`;o0000
00?oooooo`000?l000000_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000<ooooo`;o0000
0_ooool2o`0001?ooooo0_l00008ooooo`Co000000?oooooo`000?l000001Oooool4o`000003oooo
ool0003o000000;o00001Oooool2o`0000Gooooo0ol0000Gooooo`;o000000?oooooo`000?l00000
1ooooolPo`0000;ooooo0_l00006ooooo`Co00001Oooool2o`0000Gooooo0_l00002ooooo`Co0000
6oooool2o`0002_ooooo000Looooo`03o`000?oooooooooo02[ooooo0_l0000@ooooo`;o00000_oo
ool3o`0000Cooooo0_l00006ooooo`;o00002?ooool2o`0000oooooo0_l00002ooooo`;o00000ooo
ool2o`0000?ooooo1?l000000ooooooo0000o`000005ooooo`Co000000?oooooo`000?l000002Ooo
ool2o`000003ooooool0003o000000?o00001?ooool2o`0000Kooooo0_l00002ooooo`;o00000_oo
ool2o`0001Gooooo5ol00003ooooo`;o00002?ooool2o`0000Gooooo0_l000000ooooooo0000o`00
0007ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0:_ooool2o`0001Gooooo0_l00004
ooooo`Co00001?ooool2o`0000Sooooo0_l00005ooooo`;o00001_ooool4o`0000Oooooo0_l00003
ooooo`Co000000?oooooo`000?l000002_ooool2o`000003ooooool0003o000000Gooooo0ol00000
0ooooooo0000o`000007ooooo`;o00001_ooool2o`0000;ooooo0_l00002ooooo`;o00001_ooool2
o`0000gooooo3?l000000ooooooo0000o`000008o`0000Sooooo0_l00008ooooo`;o00000oooool2
o`0000cooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`11ooooo`;o00001_ooool2o`00
00oooooo0_l00004ooooo`;o00001_ooool2o`0000Wooooo0_l00004ooooo`;o00001_ooool2o`00
00?ooooo0_l00004ooooo`;o00001Oooool2o`0002?ooooo0_l00008ooooo`;o00001?oooolEo`00
00Cooooo0_l00003ooooo`;o00001oooool3o`0000gooooo0_l00002ooooo`;o00005Oooool2o`00
02gooooo000Looooo`03o`000?oooooooooo04Sooooo0ol0000?ooooo`;o00003?ooool2o`0000Oo
oooo0_l00005ooooo`?o00001_ooool2o`000003ooooool0003o000000;o00001Oooool2o`0001[o
oooo1Ol00007ooooo`;o00002?ooool2o`000003ooooool0003o000001So00001Oooool2o`000003
ooooool0003o000000Wooooo0_l0000>ooooo`;o00001oooool2o`00013ooooo0_l0000]ooooo`00
00Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413o
c<c<00Kooooo00?o0000ooooooooool0=_ooool2o`00013ooooo0ol0000?ooooo`;o00001?ooool2
o`0000Wooooo0_l00004ooooo`;o00001Oooool2o`0000[ooooo0_l00006ooooo`?o00000oooool2
o`000004ooooool0003o0000ooooo`;o00002Oooool2o`0000Cooooo1Ol00007ooooo`Co000000?o
ooooo`000?l000000oooool2o`0000?ooooo1Ol00002ooooo`;o00000oooool:o`0000[ooooo0_l0
0006ooooo`;o00006?ooool4o`0003oooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo
0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0booooo`;o
00000_ooool4o`0001?ooooo0_l0000;ooooo`;o00000oooool3o`000003ooooool0003o000000Go
oooo1?l00003ooooo`;o00002Oooool2o`0000kooooo0_l00004ooooo`;o000000Coooooo`000?l0
003ooooo0_l00009ooooo`;o00003_ooool6o`000004ooooool0003o0000o`0000kooooo0_l00002
ooooo`_o00002_ooool2o`0000Kooooo0_l00003ooooo`;o00004oooool2o`00047ooooo00000ooo
oooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo03;ooooo0ol00003ooooo`;o00001?ooool2o`0000gooooo0_l0000@
ooooo`;o00000_ooool2o`0000?ooooo1_l00003ooooo`;o00002Oooool4o`0000cooooo0_l00004
ooooo`;o00001?ooool2o`0001Wooooo1?l00004ooooo`;o00001Oooool2o`0000Gooooo0_l00004
ooooo`Wo00002Oooool2o`000003ooooool0003o000000_ooooo0_l000000ooooooo0000o`000004
ooooo`;o00001oooool2o`0000Gooooo0_l0000;ooooo`;o0000<?ooool00003ooooool0003ooooo
00;ooooo00?o0000ooooooooool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0000c
ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Oooooo1?l0000Jooooo`;o000000?ooooo
o`000?l000000_ooool2o`0000Cooooo0_l0000:ooooo`;o00003?ooool2o`0000Cooooo0_l0000<
ooooo`;o00002oooool2o`0000[ooooo0_l00007ooooo`;o00001Oooool2o`0000Gooooo0_l00004
ooooo`;o00000oooool2o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`;o00002?ooool2
o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`?o00001?ooool2o`0000_ooooo0_l0000`
ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?mEEEGo0000
oa0@4?o<c<`01_ooool00ol0003oooooooooo`0_ooooo`;o00000_ooool2o`000004ooooool0003o
0000ooooo`;o00003?ooool4o`0001[ooooo0_l00002ooooo`Co00001Oooool2o`0001gooooo0_l0
0007ooooo`;o00001?ooool3o`0000[ooooo0_l00007ooooo`;o000000?oooooo`000?l000002?oo
ool2o`00013ooooo1?l00002ooooo`;o00001oooool2o`0000Cooooo0_l0000Aooooo`;o00001Ooo
ool2o`0004?ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEE
ohN7Qoooool02?ooool00ol0003oooooooooo`0_ooooo`;o00000_ooool2o`0000Cooooo0_l0000<
ooooo`Co00005_ooool2o`0000Kooooo1?l0000Tooooo`;o00001oooool4o`0000;ooooo0ol00004
ooooo`;o00003Oooool2o`0000Kooooo0_l00003ooooo`;o00004?ooool4o`000003ooooool0003o
000000[ooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l00004ooooo`Co00002?ooool2
o`0004Gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?oo
ool00ol0003oooooooooo`0cooooo`;o00004_ooool4o`0001Kooooo0_l00004ooooo`;o000000?o
ooooo`000?l000007oooool2o`0000;ooooo0_l000000ooooooo0000o`000007ooooo`Wo00000ooo
ool2o`0000cooooo0_l00007ooooo`;o00005Oooool3o`0000;ooooo0_l0000:ooooo`;o000000?o
ooooo`000?l000001ol00002ooooo`Ko00002?ooool3o`0004Cooooo00001_ooooook^k^oc8b<_l0
003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`10ooooo`;o
00001_ooool2o`000003ooooool0003o000000Cooooo0_l0000Dooooo`;o00002?ooool2o`0000;o
oooo0_l0000=ooooo`;o00001Oooool2o`0000;ooooo1Ol000000ooooooo0000o`000003o`000003
ooooool0003o000000Co000000?oooooo`000?l000003oooool4o`0000Oooooo0_l00002ooooo`;o
00000oooool2o`0000cooooo1?l0000<ooooo`;o00001Oooool4o`0000Cooooo0_l000000ooooooo
0000o`00000:ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0;_ooool2o`0000?ooooo
0_l0000;ooooo`;o00002Oooool2o`0000Cooooo0_l0000Nooooo`;o000000Goooooo`000?l0003o
0000ooooo`02o`0000Cooooo0_l00002ooooo`Co00002Oooool3o`0000?ooooo1Ol000000ooooooo
0000o`000007ooooo`?o00002_ooool6o`0000Oooooo0_l00002ooooo`;o00000oooool2o`0000ko
oooo0_l0000<ooooo`;o00001?ooool3o`0005_ooooo000Looooo`03o`000?oooooooooo02kooooo
0_l00003ooooo`;o00001oooool2o`0000Cooooo0ol0000>ooooo`;o00007oooool2o`000004oooo
ool0003o0000o`0000Cooooo0_l000001?oooooo0000o`000?l0000;ooooo`;o00001_ooool3o`00
00[ooooo0ol00002ooooo`;o00001Oooool3o`0000?ooooo1?l00002ooooo`;o00005?ooool2o`00
00Oooooo0_l00005ooooo`;o00001oooool2o`00013ooooo0_l00005ooooo`?o0000@_ooool001co
oooo00?o0000ooooooooool0??ooool2o`0000Cooooo0ol00006ooooo`;o00001_ooool2o`0001Go
oooo0_l00009ooooo`Ko00001_ooool2o`0000[ooooo1?l00003ooooo`;o000000Goooooo`000?l0
003o0000ooooo`04o`0000;ooooo0_l00006ooooo`;o00001?ooool3o`0000Cooooo1?l00002oooo
o`Co00003?ooool4o`0000;ooooo0_l00003ooooo`;o00000_ooool4o`0000?ooooo0_l0000;oooo
o`;o00001_ooool2o`0000Cooooo0_l00005ooooo`?o0000@_ooool001cooooo00?o0000oooooooo
ool0@Oooool2o`0000;ooooo0_l00004ooooo`;o00007Oooool2o`0000Wooooo0_l000001Ooooooo
0000o`000?l0003ooooo00;o00003oooool4o`0000?ooooo1Ol00002ooooo`Co00000_ooool2o`00
00cooooo0_l00004ooooo`;o00001_ooool3o`0000cooooo1?l00007ooooo`;o000000Coooooo`00
0?l0003ooooo0_l0000@ooooo`;o00001_ooool2o`0000cooooo0_l00012ooooo`007?ooool00ol0
003oooooooooo`0eooooo`;o00002_ooool2o`0000;ooooo0_l0000;ooooo`;o00007_ooool2o`00
00Sooooo0_l00004ooooo`;o00002_ooool2o`0000Cooooo1_l000000ooooooo0000o`000004o`00
0003ooooool0003o0000017ooooo0_l0000;ooooo`;o00003?ooool4o`0000Gooooo0ol00004oooo
o`;o00001Oooool2o`00063ooooo000Looooo`03o`000?oooooooooo03Gooooo1?l00009ooooo`;o
00002Oooool2o`0000?ooooo0_l0000Kooooo`;o000000?oooooo`000?l000001?ooool2o`0000Ko
oooo1_l0000>oooooa3o00005Oooool2o`0000Oooooo0_l0000<ooooo`Go00001?ooool2o`0000Go
oooo0_l00005ooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0=oooool2o`0000;ooooo
0_l00005ooooo`;o00002Oooool3o`0001oooooo0_l00007ooooo`;o00001_ooool2o`0000;ooooo
0_l0000<ooooo`_o000000?oooooo`000?l000000ol00003ooooo`;o00004Oooool2o`0000Cooooo
0_l00006ooooo`;o00002_ooool4o`0000kooooo0_l000000ooooooo0000o`000004ooooo`;o0000
1Oooool2o`0000Kooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`0kooooo`;o00004Ooo
ool2o`00027ooooo0_l0000Fooooo`;o00001?ooool2o`000003ooooool0003o000000[o000000?o
ooooo`000?l000000_l00003ooooo`;o00001Oooool2o`0000?ooooo0_l0000;ooooo`;o00001_oo
ool2o`0000cooooo0_l0000>ooooo`;o000000Coooooo`000?l0003ooooo1Ol00005ooooo`;o0000
1_ooool2o`0004[ooooo000Looooo`03o`000?oooooooooo03cooooo0_l00007ooooo`;o000000?o
ooooo`000?l000003?ooool2o`0001Wooooo0_l0000Fooooo`;o00001?ooool2o`000003ooooool0
003o000000oo00002_ooool2o`0000?ooooo0_l00005ooooo`;o00002_ooool2o`0000Oooooo0ol0
00000ooooooo0000o`00000Gooooo`Co0000F_ooool001cooooo00?o0000ooooooooool0??ooool2
o`0000Kooooo0ol000000ooooooo0000o`00000<ooooo`;o00006oooool2o`0000[ooooo0_l0000=
ooooo`;o000000?oooooo`000?l000004Ol00003ooooo`;o00003?ooool2o`0000;ooooo0_l00004
ooooo`;o00001?ooool2o`0000Oooooo1_l000000ooooooo0000o`00000Aooooo`Co0000GOooool0
01cooooo00?o0000ooooooooool0?Oooool2o`0000Gooooo0_l00007ooooo`;o00009?ooool2o`00
00[ooooo0_l00005ooooo`;o00001_ooool5o`000003ooooool0003o000001Co00001_ooool2o`00
00?ooooo1?l000000ooooooo0000o`000002ooooo`?o00003Oooool4o`0000?ooooo0_l0000Aoooo
o`Ko00002?ooool2o`00057ooooo000Looooo`;o0000?_ooool3o`0000gooooo0_l00003ooooo`;o
0000<_ooool2o`0000Kooooo7?l00006ooooo`;o00000_ooool2o`000004ooooool0003o0000oooo
o`;o00000_ooool2o`0000Oooooo0_l00008ooooo`;o00002Oooool2o`0000kooooo0_l00008oooo
o`;o00003?ooool2o`0004?ooooo000Looooo`03o`000?oooooooooo03kooooo0_l00008ooooo`;o
00002?ooool2o`0000;ooooo0_l0000Oooooo`Ko00003?ooool2o`0000?ooooo0ol000000ooooooo
0000o`00000Do`0000cooooo0_l00004ooooo`;o00002oooool5o`0000;ooooo0_l000000ooooooo
0000o`000009ooooo`;o000000Coooooo`000?l0003ooooo0_l000001?oooooo0000o`000?l0000A
ooooo`;o00001oooool4o`0004?ooooo000Looooo`03o`000?oooooooooo04Kooooo1_l00002oooo
o`;o00001_ooool2o`0001[ooooo0_l00003ooooo`Ko00002oooool3o`0000?ooooo0ol00002oooo
oaGo00001Oooool3o`000003ooooool0003o000000Co00000oooool2o`0000gooooo0ol00002oooo
o`;o00003oooool2o`000004ooooool0003o0000ooooo`?o00003?ooool2o`0000?ooooo0_l00002
ooooo`;o000000?oooooo`000?l000000_l00015ooooo`007?ooool00ol0003oooooooooo`16oooo
o`;o00000_ooool2o`0000;ooooo0_l0000Oooooo`;o000000?oooooo`000?l000001Oooool2o`00
00Gooooo0_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000007ol000001Ooo
oooo0000o`000?l0003ooooo00Ko0000;oooool2o`0000Wooooo0_l000000ooooooo0000o`000006
ooooo`?o000000?oooooo`000?l00000Aoooool001cooooo00?o0000ooooooooool0A_ooool2o`00
00Gooooo0_l0000Pooooo`;o00000_ooool2o`0000[ooooo0ol000000ooooooo0000o`000006oooo
ob7o00005_ooool2o`0002;ooooo0_l00002ooooo`;o00001?ooool3o`0000Kooooo1Ol0001;oooo
o`007?ooool00ol0003oooooooooo`16ooooo`;o00001Oooool2o`0000_ooooo0_l0000Gooooo`;o
00002_ooool2o`0000_ooooo0_l00003oooooa[o00001?ooool2o`0000Gooooo0_l000000ooooooo
0000o`000007ooooo`;o00004Oooool2o`0000_ooooo0_l00006ooooo`;o000000Coooooo`000?l0
003ooooo0_l00007ooooo`?o00004Oooool2o`0003[ooooo000Looooo`03o`000?oooooooooo04?o
oooo0_l0000Cooooo`Co00005oooool2o`0000?ooooo0_l0000Booooo`[o000000?oooooo`000?l0
00004ol00003ooooo`;o00000oooool7o`0000?ooooo0_l00003ooooo`;o00003oooool3o`0000_o
oooo0_l00009ooooo`;o00007_ooool2o`0003[ooooo000Looooo`03o`000?oooooooooo04?ooooo
0_l00003ooooo`?o00002?ooool2o`0000?ooooo0_l000000ooooooo0000o`00000Kooooo`;o0000
1?ooool2o`0000cooooo6Ol00005ooooo`Co00001_ooool2o`0000;ooooo0_l000001?oooooo0000
o`000?ooool2o`0000?ooooo1?l0000=ooooo`;o000000?oooooo`000?l000005Oooool2o`0000?o
oooo0ol0001Cooooo`007?ooool00ol0003oooooooooo`15ooooo`;o000000Coooooo`000?l0003o
00000_ooool2o`0000Cooooo0_l00006ooooo`;o00006_ooool2o`0000Gooooo0_l0000=oooooaSo
000000?oooooo`000?l000001?ooool2o`0000Gooooo0ol00005ooooo`;o000000?oooooo`000?l0
00000_ooool2o`000003ooooool0003o000000_ooooo0_l00003ooooo`;o00005Oooool4o`000003
ooooool0003o000000Co0000D?ooool001cooooo00?o0000ooooooooool0AOooool2o`0000Kooooo
0_l00005ooooo`;o00001Oooool2o`0001;ooooo0_l00006ooooo`;o00001_ooool6o`0000Kooooo
5_l000000ooooooo0000o`000004o`0000_ooooo1?l00007ooooo`?o000000?oooooo`000?l00000
3_ooool2o`0000Cooooo0ol0000Cooooo`Co00001?ooool3o`00053ooooo000Looooo`03o`000?oo
oooooooo04Gooooo0_l00002ooooo`;o00002Oooool2o`0001Wooooo0_l0000:ooooo`;o00000_oo
ool6o`0000Gooooo4?l00002ooooo`co00001?ooool4o`0000;ooooo1_l00004ooooo`;o000000?o
ooooo`000?l000005oooool3o`0000Gooooo0_l00006ooooo`;o00001?ooool2o`0000Sooooo0_l0
000Aooooo`;o0000??ooool001cooooo00?o0000ooooooooool0>_ooool2o`0000?ooooo0_l00004
ooooo`;o00000_ooool2o`0001Cooooo0_l0000Jooooo`;o00003OoooolBo`000003ooooool0003o
000000[o00000oooool4o`0000;ooooo0_l00002ooooo`;o00001?ooool2o`0002;ooooo0_l00006
ooooo`;o00002oooool5o`0000kooooo0_l000000ooooooo0000o`00000looooo`007?ooool00ol0
003oooooooooo`0jooooo`;o00000oooool2o`0001cooooo1?l0000>ooooo`;o00007?oooolMo`00
01Cooooo0ol0000@ooooo`;o00004?ooool2o`0000;ooooo0_l00006ooooo`;o00001?ooool3o`00
013ooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00001_ooool2o`0000Co
oooo0_l0000:ooooo`Co00003_ooool2o`0000?ooooo0_l0000Hoooooaco00005?ooool3o`0000oo
oooo0ol0000@ooooo`;o00000_ooool2o`0000Kooooo0_l0001Hooooo`007?ooool00ol0003ooooo
ooooo`13ooooo`;o00001_ooool2o`0000Cooooo1?l0000:ooooo`Co00004?ooool3o`0000Wooooo
0_l0000:ooooo`;o000000?oooooo`000?l000006Ol00003ooooo`;o00000oooool2o`0000cooooo
0_l0000<ooooo`;o000000?oooooo`000?l000000_l0000Dooooo`?o00002_ooool2o`0005;ooooo
000Looooo`03o`000?oooooooooo04oooooo0ol000000ooooooo0000o`00000<ooooo`;o00003_oo
ool7o`0000Oooooo0_l0000:oooooako00000oooool2o`0000;ooooo0ol00005ooooo`;o00001?oo
ool3o`0000Cooooo0_l00004ooooo`Co00000oooool2o`0000oooooo0ol00002ooooo`?o00002_oo
ool2o`0005;ooooo000Looooo`;o0000D?ooool3o`0000Kooooo0_l00007ooooo`;o00003_ooool2
o`0000;ooooo0ol0000Eooooo`;o000000?oooooo`000?l000005ol00007ooooo`Co00001?ooool2
o`0000Cooooo0_l00005ooooo`;o00001?ooool2o`0000Oooooo0_l00005ooooo`;o00001_ooool3
o`0000;ooooo0_l00006ooooo`;o0000Eoooool001cooooo00?o0000ooooooooool0F?ooool2o`00
00Oooooo0_l0000Hooooo`;o00000_ooool2o`0000?ooooo0_l00004ooooo`;o00000_ooool2o`00
0003ooooool0003o000001Go00002?ooool6o`0000cooooo0_l00002ooooo`;o00001?ooool2o`00
00Kooooo0_l00005ooooo`;o00002?ooool2o`000003ooooool0003o000000Kooooo0_l000000ooo
oooo0000o`00001Dooooo`007?ooool00ol0003oooooooooo`12ooooo`;o000000?oooooo`000?l0
0000;_ooool2o`0000?ooooo1ol00002ooooo`?o00001?ooool2o`0000;ooooo0_l00003oooooaGo
00000oooool2o`000003ooooool0003o000000Cooooo0_l00006ooooo`;o00001?ooool2o`0000;o
oooo0_l00004ooooo`;o00000_ooool2o`0000;ooooo0_l0000?ooooo`Co00002_ooool2o`0005Co
oooo000Looooo`03o`000?oooooooooo04;ooooo0_l000000ooooooo0000o`000002ooooo`;o0000
2Oooool2o`0001oooooo0_l00003ooooo`;o000000?oooooo`000?l000001?ooool2o`0000?ooooo
0_l00003ooooo`;o00000ooooolCo`0000Kooooo0_l000001?oooooo0000o`000?ooool2o`0000;o
oooo0_l00005ooooo`;o00002Oooool4o`0000Gooooo1?l0000:ooooo`;o00001oooool2o`0000Oo
oooo0_l0000?ooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0BOooool2o`0000Oooooo
1?l0000Aooooo`;o00001oooool2o`0001Gooooo0ol00003ooooo`;o00000_ooool3o`000003oooo
ool0003o000000co000000?oooooo`000?l000002oooool2o`0000;ooooo0_l00009ooooo`;o0000
1?ooool5o`0000;ooooo0_l00003ooooo`;o00002_ooool2o`000003ooooool0003o000000Gooooo
0_l00005ooooo`?o00003_ooool3o`0004Kooooo000Looooo`03o`000?oooooooooo053ooooo1?l0
0007ooooo`;o000000?oooooo`000?l000001oooool2o`0000Oooooo0_l0000Eooooo`;o00001?oo
ool2o`0000;ooooo4_l000000ooooooo0000o`00000@ooooo`;o00002?ooool2o`0000?ooooo0ol0
0005ooooo`;o00000oooool2o`0000[ooooo1Ol00005ooooo`;o00001Oooool2o`0000oooooo0_l0
0017ooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00000_ooool2o`0000Wooooo0_l00000
0ooooooo0000o`00000Wooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o000000?o
ooooo`000?l000002_l000001?oooooo0000o`000?l0000;ooooo`;o00001?ooool4o`0000;ooooo
0_l00006ooooo`Co00002Oooool4o`0000[ooooo0ol0001Xooooo`007?ooool00ol0003ooooooooo
o`1<ooooo`Co00002?ooool2o`0001gooooo0_l00004ooooo`;o00000oooool2o`0000Kooooo0_l0
0004ooooo`?o00000_ooool6o`000004ooooool0003o0000ooooo`Go00002oooool2o`0000Cooooo
1?l00002ooooo`;o000000?oooooo`000?l000000_ooool3o`0000Gooooo0_l00004ooooo`Co0000
5Oooool2o`0000Kooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`1>ooooo`?o000000?o
ooooo`000?l000000_ooool4o`0000oooooo0_l0000:ooooo`Co00001?ooool2o`0000?ooooo0_l0
00000ooooooo0000o`000005ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o0000
00?oooooo`000?l000000_l00002ooooo`?o00007?ooool6o`0000;ooooo0_l00002ooooo`;o0000
1_ooool2o`0001Gooooo0_l00006ooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0C_oo
ool3o`000003ooooool0003o000000Co00004Oooool2o`0000[ooooo1_l0000:ooooo`;o00000_oo
ool2o`000003ooooool0003o000000;o00000oooool5o`000003ooooool0003o000000;o00001?oo
ool6o`0000cooooo0_l00002ooooo`;o00001oooool2o`0000Cooooo0_l00006ooooo`;o00002?oo
ool2o`0000?ooooo0_l0000Kooooo`;o0000COooool001cooooo00?o0000ooooooooool0D?ooool2
o`0000;ooooo0_l0000@ooooo`;o00002oooool2o`0000Cooooo1?l0000<ooooo`;o00000oooool2
o`000003ooooool0003o000000?o00000oooool7o`000003ooooool0003o000000Co00001Oooool3
o`0000Cooooo0_l00002ooooo`;o00003oooool2o`0000Cooooo0_l00005ooooo`;o000000?ooooo
o`000?l000000oooool4o`0001Cooooo0_l00003ooooo`;o0000COooool001cooooo00?o0000oooo
ooooool0D?ooool2o`0000?ooooo0_l00006ooooo`;o00001oooool2o`0000_ooooo0_l00005oooo
o`?o00002oooool2o`0000Oooooo1?l00006ooooo`So00002Oooool3o`0000[ooooo1?l0000;oooo
o`;o00001Oooool2o`0000Cooooo0_l00008ooooo`;o00005?ooool2o`0000?ooooo0_l0001=oooo
o`007?ooool00ol0003oooooooooo`1Eooooo`;o00001_ooool2o`0000Oooooo0_l00007ooooo`;o
00002Oooool2o`0000Wooooo0_l000000ooooooo0000o`000006ooooo`;o00002?ooool3o`0000;o
oooo0_l00002ooooo`;o000000?oooooo`000?l000000_l0000<ooooo`;o000000?oooooo`000?l0
00000_l0000Booooo`;o00004_ooool2o`000003ooooool0003o000001;ooooo0_l0001=ooooo`00
7?ooool00ol0003oooooooooo`1Mooooo`;o00002_ooool2o`0000Cooooo0_l00002ooooo`;o0000
0oooool2o`0000_ooooo0ol00008ooooo`;o00001_ooool4o`0000Oooooo2?l0000;ooooo`;o0000
0oooool3o`000003ooooool0003o000000?ooooo0_l0000Mooooo`;o000000Coooooo`000?l0003o
oooo0_l0001Nooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00002?ooool2o`0000[ooooo
0_l00008ooooo`;o00000oooool2o`0000[ooooo1?l0000>ooooo`Co00002_ooool2o`0000?ooooo
0_l00007ooooo`?o00001_ooool3o`000003ooooool0003o000000?ooooo0_l0000Aooooo`;o0000
1oooool2o`0000?ooooo0_l00002ooooo`;o0000G_ooool001cooooo00?o0000ooooooooool0Dooo
ool4o`0000Kooooo0ol0000Tooooo`;o00001_ooool2o`0000?ooooo0_l00003ooooo`?o00001ooo
ool2o`0000kooooo1Ol00008ooooo`;o00000oooool2o`0000Oooooo0_l0000:ooooo`;o00001ooo
ool2o`0000?ooooo0_l0000<ooooo`;o0000E?ooool001cooooo0_l0001Fooooo`;o00001oooool2
o`0000?ooooo0_l00002ooooo`;o00003_ooool2o`0000gooooo0_l000001?oooooo0000o`000?oo
ool2o`0000?ooooo0_l0000=ooooo`;o00003_ooool2o`0000_ooooo0_l00003ooooo`;o00001ooo
ool3o`0000Cooooo1?l00009ooooo`;o00004_ooool2o`0005Cooooo000Looooo`03o`000?oooooo
oooo05Wooooo0_l00008ooooo`;o00000_ooool3o`0000gooooo0_l0000=ooooo`;o000000?ooooo
o`000?l000001Oooool2o`0000Wooooo0_l00004ooooo`;o00006oooool2o`0000cooooo0_l00004
ooooo`Co00002Oooool2o`0006Sooooo000Looooo`03o`000?oooooooooo05Wooooo0_l0000=oooo
o`;o00003oooool4o`0000Sooooo0_l00006ooooo`;o000000?oooooo`000?l000000_l00007oooo
o`;o00001?ooool2o`0000Oooooo0_l0000@ooooo`Co00006?ooool2o`0000Cooooo0_l000000ooo
oooo0000o`00001Vooooo`007?ooool00ol0003oooooooooo`1Xooooo`;o00001?ooool2o`0000Wo
oooo1?l00008ooooo`;o00001?ooool4o`0000?ooooo0_l0000:ooooo`Go00001oooool2o`0000_o
oooo0_l000000ooooooo0000o`000002o`0000gooooo0_l0000;ooooo`;o00001?ooool2o`000003
ooooool0003o000001?ooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`1Nooooo`?o0000
2Oooool2o`0000;ooooo1Ol0000Hooooo`?o00001?ooool2o`0000[ooooo1_l000000ooooooo0000
o`00000@ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Oooooo1?l00007ooooo`;o0000
7_ooool2o`00057ooooo000Looooo`03o`000?oooooooooo057ooooo0_l00008ooooo`;o000000Co
ooooo`000?l0003o00001Oooool2o`0000;ooooo0_l00003ooooo`Co00000_ooool2o`0001Gooooo
0_l0000Dooooo`;o000000?oooooo`000?l000005?ooool2o`0000Cooooo1?l00008ooooo`;o0000
1oooool2o`0000Kooooo1?l0001Wooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o00002?oo
ool2o`000004ooooool0003o0000ooooo`;o00000oooool2o`0000gooooo0_l0000=ooooo`;o0000
;Oooool2o`0000Kooooo0_l00004ooooo`Co00001_ooool2o`00017ooooo1?l0001Wooooo`007?oo
ool00ol0003oooooooooo`1Fooooo`;o00001Oooool6o`0000Cooooo0_l0000<ooooo`;o00000_oo
ool2o`000003ooooool0003o000000Kooooo0_l000000ooooooo0000o`00000Jooooo`;o00001?oo
ool2o`0000Sooooo0_l00002ooooo`;o00004_ooool3o`0000gooooo0_l0000Fooooo`;o0000E?oo
ool001cooooo00?o0000ooooooooool0E_ooool2o`0000Gooooo0_l000000ooooooo0000o`000005
ooooo`Co00003_ooool2o`000003ooooool0003o000000Wooooo0_l00007ooooo`;o00001_ooool2
o`0000Wooooo0_l00004ooooo`;o00003?ooool4o`0000Sooooo0_l00007ooooo`;o00003Oooool3
o`0001Gooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`1Wooooo`Co00005_ooool2o`00
00Cooooo0_l00007ooooo`;o00001_ooool4o`0001_ooooo1?l00006ooooo`Co00003oooool2o`00
0004ooooool0003o0000ooooo`Go0000J_ooool001cooooo00?o0000ooooooooool0Ioooool2o`00
00_ooooo0_l0000;ooooo`;o00000_ooool5o`0000Sooooo0_l00006ooooo`;o00005?ooool3o`00
00Cooooo1?l00006ooooo`;o00001oooool2o`000003ooooool0003o000000Gooooo1Ol000001?oo
oooo0000o`000?ooool2o`0006[ooooo000Looooo`03o`000?oooooooooo06Cooooo0_l000000ooo
oooo0000o`000006ooooo`;o00000oooool2o`0000;ooooo0_l0000;ooooo`;o000000?oooooo`00
0?l000002?ooool2o`0000Sooooo0_l00007ooooo`;o00002Oooool3o`0000Kooooo0_l0000?oooo
o`;o000000?oooooo`000?l000001oooool3o`00073ooooo000Looooo`03o`000?oooooooooo05go
oooo0_l00005ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Kooooo1Ol00004ooooo`;o
00005_ooool2o`0000;ooooo0_l00007ooooo`;o00003_ooool2o`0000Cooooo1?l0000Dooooo`Co
0000L_ooool001cooooo00?o0000ooooooooool0GOooool2o`0000Cooooo0_l00008ooooo`;o0000
2?ooool2o`000003ooooool0003o000000Cooooo0_l00003ooooo`;o00003oooool4o`0000Oooooo
0_l0000Booooo`;o00000oooool5o`0000gooooo0_l00005ooooo`Co0000L_ooool00006ooooooo^
k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006oooo
o`03o`000?oooooooooo06?ooooo0ol00007ooooo`;o00001?ooool2o`00013ooooo0_l0000?oooo
o`;o00002Oooool2o`0001Oooooo0_l0000@ooooo`;o00001oooool2o`0007;ooooo00001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_oo
ool00ol0003oooooooooo`1Tooooo`;o00001Oooool2o`0000;ooooo0ol000000ooooooo0000o`00
000?ooooo`;o00000oooool2o`0000Cooooo0_l0000Yooooo`;o00000_ooool2o`000003ooooool0
003o000000Cooooo0_l00002ooooo`;o0000O?ooool00003ooooool@413ooooo00;ooooo00?o410@
ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0IOoo
ool2o`0000Cooooo0_l00002ooooo`?o000000?oooooo`000?l000000_ooool2o`0000_ooooo1?l0
00000ooooooo0000o`000004ooooo`;o0000;Oooool2o`000003ooooool0003o000000Cooooo0_l0
0002ooooo`;o00007oooool3o`0005[ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000IOooool2o`0000Wooooo0_l0
00000ooooooo0000o`000004o`0000;ooooo0ol00008ooooo`;o00003?ooool2o`0000oooooo0_l0
000@ooooo`;o00001_ooool3o`0002[ooooo0ol0001Jooooo`0000?oooooo`000?ooool00_ooool0
0ol0003oooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003ooooooooo
o`1[ooooo`;o000000?oooooo`000?l000000oooool5o`0000?ooooo0ol00008ooooo`;o00001?oo
ool2o`0000Kooooo1Ol0000<ooooo`Co00002_ooool2o`0000;ooooo0_l00003ooooo`;o000000?o
ooooo`000?l000000_l00026ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09
ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`1[ooooo`;o000000?o
ooooo`000?l000002oooool2o`0000oooooo0_l00007ooooo`Co00000oooool3o`0000Sooooo0_l0
000:ooooo`;o00001oooool2o`0000?ooooo0_l00006ooooo`;o000000?oooooo`000?l00000Nooo
ool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Ko
oooo00?o0000ooooooooool0J?ooool2o`0000cooooo0_l00009ooooo`;o00002Oooool2o`0000Wo
oooo0_l00003ooooo`?o00005Oooool4o`00017ooooo0_l000001?oooooo0000o`000?ooool2o`00
07Sooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o410@ojVY
Z@06ooooo`03o`000?oooooooooo06Sooooo0_l0000<ooooo`;o00001Oooool2o`0000;ooooo0_l0
0007ooooo`Co00002?ooool2o`0000Kooooo0_l0000@ooooo`;o00000_ooool4o`0000oooooo0ol0
0005ooooo`;o0000N?ooool001cooooo00?o0000ooooooooool0N_ooool2o`000003ooooool0003o
000000_ooooo0_l00005ooooo`?o00000_ooool2o`0000Kooooo0_l0000<ooooo`;o000000Cooooo
o`000?l0003o00000oooool2o`0000kooooo1Ol0001oooooo`007?ooool00ol0003oooooooooo`1j
ooooo`;o000000?oooooo`000?l000000_ooool2o`0000kooooo0ol00005ooooo`;o00000oooool2
o`0000Wooooo0_l000001?oooooo0000o`000?ooool2o`0000[ooooo0_l00008ooooo`?o0000POoo
ool001cooooo00?o0000ooooooooool0POooool3o`0000Cooooo0_l00008ooooo`;o00001Oooool2
o`0000_ooooo1Ol0000;ooooo`;o00000oooool2o`0000Wooooo0_l00021ooooo`007?ooool00ol0
003oooooooooo`1]ooooo`;o00004oooool2o`0000Cooooo0_l0000>ooooo`;o00001oooool2o`00
00?ooooo1?l0000<ooooo`;o0000TOooool001cooooo00?o0000ooooooooool0KOooool2o`00017o
oooo0_l0000>ooooo`;o000000?oooooo`000?l000000oooool2o`0000Oooooo0_l00004ooooo`;o
00001oooool2o`0009Oooooo000Looooo`03o`000?oooooooooo083ooooo0_l000001?oooooo0000
o`000?l0000:ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00003?ooool2o`0000Oo
oooo0_l0002Gooooo`007?ooool00ol0003oooooooooo`20ooooo`Oo00002Oooool2o`0000?ooooo
1_l0000<ooooo`;o00002?ooool2o`0009Kooooo000Looooo`03o`000?oooooooooo07?ooooo0_l0
000<ooooo`;o000000Coooooo`000?l0003o00000_ooool:o`0000Cooooo0_l00007ooooo`;o0000
1Oooool2o`0000Sooooo0_l00002ooooo`;o0000T_ooool001cooooo00?o0000ooooooooool0KOoo
ool2o`0000Cooooo0_l0000Dooooo`[o00003Oooool2o`0000Gooooo0_l0000<ooooo`;o0000T_oo
ool001cooooo00?o0000ooooooooool0KOooool2o`0001Oooooo0_l0000Oooooo`;o0000X?ooool0
01cooooo00?o0000ooooooooool0Q_ooool4o`0000Kooooo0_l00004ooooo`;o00001?ooool4o`00
0:Wooooo000Looooo`;o0000ROooool2o`000003ooooool0003o000000;o000000Coooooo`000?l0
003ooooo0_l000000ooooooo0000o`000004ooooo`Co0000ZOooool001cooooo00?o0000oooooooo
ool0Roooool5o`0000?ooooo0_l00013ooooo`;o0000Koooool001cooooo00?o0000ooooooooool0
S_ooool2o`0004Sooooo0_l0001_ooooo`007?ooool00ol0003oooooooooo`27ooooo`;o0000`?oo
ool001cooooo00?o0000ooooooooool0Qoooool2o`0000?ooooo0_l0002kooooo`007?ooool00ol0
003oooooooooo`2<ooooo`;o0000^oooool001cooooo00?o0000ooooooooool0R?ooool2o`000;oo
oooo000Looooo`03o`000?oooooooooo08Sooooo0_l0002oooooo`007?ooool00ol0003ooooooooo
o`2Hooooo`;o0000[oooool001cooooo00?o0000ooooooooool0V?ooool2o`0003;ooooo0_l0001k
ooooo`007?ooool00ol0003oooooooooo`3<ooooo`;o0000Noooool001cooooo00?o0000oooooooo
ool0]Oooool2o`0009;ooooo000Looooo`03o`000?oooooooooo0;Gooooo0_l0002Booooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo093ooooo0_l0002gooooo`007?ooool00ol0003oooooooooo`2@oooo
o`;o0000]oooool001cooooo00?o0000ooooooooool0]_ooool2o`00097ooooo000Looooo`03o`00
0?oooooooooo0:Cooooo0_l0000@ooooo`;o0000TOooool001cooooo00?o0000ooooooooool0Y?oo
ool2o`000:?ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`004_ooool4o`000003
oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Ooo
ool3o`000?ooooooB_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0
003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo
00?o0000ooooooooool0oooooomBooooo`004_ooool00omEEEGoIVIVo`00003ooooooeCooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo002Qooooo`04oa0@4?l0003o0000ooooo`;o
000000?o410@ooooooooool05_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h3ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool5o`0008cooooo002Rooooo`05o`000?oo
ooooooooooooool000002Oooool6o`0000cooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoEEEEogMgMoooooooV9RHob4Q8@03ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@0S?ooool00:;ooooo00Go0000ooooooooooooooooo`00000Kooooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05o`000?ooooooooooooooool00000
1?ooool00onHV9So8B4Qonk^kP2=ooooo`00X_ooool01Ol0003ooooooooooooooooo000000Wooooo
1_l0000<ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?nHV9SooooooiRHV?lQ8B401Oooool00onHV9So8B4Qonk^kP2<ooooo`00X_ooool01Ol0003o
QhN7oooooonYZJWo000001_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03ogMgMomVIVKooooo08_ooooo002Q
ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool06Oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41000oooool00omEEEGoQhN7ooooo`09ooooo`03o`000?oo
oooooooo08[ooooo0032ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`03omgMgOl@413oV9RH00Gooooo00Go0000okZj^_ooooooV9RHoa0@402<ooooo`00`?oo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool01?o<c<coA4A4
o`000?l@4103ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0S?ooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1068) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.45947 .62802 Mdot
.45001 .66688 Mdot
.65314 .39897 Mdot
.40635 .46218 Mdot
.52183 .78735 Mdot
.61732 .4012 Mdot
.61915 .59675 Mdot
.65648 .55974 Mdot
.63539 .39186 Mdot
.53783 .63428 Mdot
.63182 .60014 Mdot
.38884 .39289 Mdot
.64576 .58909 Mdot
.40037 .48218 Mdot
.30814 .79105 Mdot
.34948 .52752 Mdot
.45264 .71076 Mdot
.48511 .28364 Mdot
.4229 .52108 Mdot
.59035 .39669 Mdot
.42912 .63455 Mdot
.39969 .46944 Mdot
.4774 .63995 Mdot
.39984 .48249 Mdot
.41935 .45972 Mdot
.45284 .69533 Mdot
.42502 .70433 Mdot
.38724 .43101 Mdot
.42452 .48395 Mdot
.64295 .55661 Mdot
.32017 .32883 Mdot
.38054 .82211 Mdot
.44279 .50811 Mdot
.77964 .60999 Mdot
.6637 .56674 Mdot
.35567 .7328 Mdot
.60864 .37921 Mdot
.6475 .56532 Mdot
.66496 .57181 Mdot
.60734 .57332 Mdot
.65769 .57577 Mdot
.4497 .68775 Mdot
.69102 .6086 Mdot
.57364 .61541 Mdot
.39527 .52976 Mdot
.57922 .73765 Mdot
.24048 .43007 Mdot
.35192 .47247 Mdot
.45036 .70778 Mdot
.56416 .39928 Mdot
.74431 .63159 Mdot
.61673 .59862 Mdot
.67957 .41859 Mdot
.81757 .70368 Mdot
.63694 .56419 Mdot
.40876 .52303 Mdot
.63201 .37926 Mdot
.39073 .46763 Mdot
.39543 .48232 Mdot
.23217 .60392 Mdot
.38187 .42633 Mdot
.465 .3263 Mdot
.4947 .6472 Mdot
.5118 .38346 Mdot
.62342 .38468 Mdot
.66513 .57999 Mdot
.44053 .66144 Mdot
.64088 .58449 Mdot
.41462 .40537 Mdot
.61403 .36037 Mdot
.35283 .47042 Mdot
.65965 .58936 Mdot
.4258 .67916 Mdot
.36439 .45933 Mdot
.73421 .34556 Mdot
.15875 .57704 Mdot
.44423 .32775 Mdot
.2875 .66701 Mdot
.24823 .64699 Mdot
.57682 .2902 Mdot
.40272 .50753 Mdot
.38234 .22918 Mdot
.23225 .69778 Mdot
.48469 .65155 Mdot
.41723 .54648 Mdot
.59504 .48054 Mdot
.36943 .45856 Mdot
.53252 .72309 Mdot
.40457 .51984 Mdot
.7966 .39922 Mdot
.63648 .39861 Mdot
.47087 .66792 Mdot
.40772 .46517 Mdot
.40545 .42996 Mdot
.25857 .48048 Mdot
.34031 .44684 Mdot
.39155 .43686 Mdot
.4268 .65318 Mdot
.63889 .60675 Mdot
.31711 .44214 Mdot
.69377 .58957 Mdot
.67253 .41538 Mdot
.34393 .48785 Mdot
.60225 .36974 Mdot
.42274 .66873 Mdot
.35976 .45428 Mdot
.67234 .5893 Mdot
.3589 .50099 Mdot
.71551 .62719 Mdot
.44857 .66365 Mdot
.41164 .43373 Mdot
.45591 .32416 Mdot
.61614 .21328 Mdot
.47355 .66244 Mdot
.59805 .27538 Mdot
.39681 .51604 Mdot
.38777 .44483 Mdot
.45155 .6692 Mdot
.66508 .40722 Mdot
.51861 .72777 Mdot
.49498 .66697 Mdot
.60568 .57165 Mdot
.49534 .65544 Mdot
.44819 .50673 Mdot
.62753 .39697 Mdot
.7166 .541 Mdot
.6415 .50161 Mdot
.3213 .30589 Mdot
.37402 .45924 Mdot
.61265 .67326 Mdot
.62046 .42122 Mdot
.46414 .67584 Mdot
.63698 .58592 Mdot
.32994 .52905 Mdot
.45968 .64545 Mdot
.62234 .58217 Mdot
.45844 .30101 Mdot
.73352 .48632 Mdot
.47572 .70322 Mdot
.60415 .63756 Mdot
.67156 .60954 Mdot
.60864 .58799 Mdot
.8017 .58156 Mdot
.44185 .67109 Mdot
.48358 .30726 Mdot
.62895 .57441 Mdot
.29135 .36963 Mdot
.43645 .48657 Mdot
.39564 .25728 Mdot
.33859 .2178 Mdot
.78237 .59649 Mdot
.75507 .44829 Mdot
.49961 .32498 Mdot
.61672 .60478 Mdot
.42554 .45174 Mdot
.4431 .69662 Mdot
.44183 .68638 Mdot
.3576 .44025 Mdot
.41153 .4587 Mdot
.35488 .4648 Mdot
.42241 .43975 Mdot
.20778 .59868 Mdot
.3593 .50835 Mdot
.2662 .30081 Mdot
.47605 .6689 Mdot
.41011 .44565 Mdot
.64764 .38069 Mdot
.42538 .4225 Mdot
.66049 .57934 Mdot
.39495 .46127 Mdot
.4059 .45772 Mdot
.39041 .42419 Mdot
.61959 .60138 Mdot
.36814 .80176 Mdot
.40669 .19297 Mdot
.44403 .80476 Mdot
.68564 .32067 Mdot
.60869 .40888 Mdot
.37464 .45166 Mdot
.47594 .32873 Mdot
.35843 .70932 Mdot
.39764 .50471 Mdot
.68988 .20542 Mdot
.39615 .44331 Mdot
.48241 .78624 Mdot
.451 .52601 Mdot
.46516 .81617 Mdot
.38214 .24433 Mdot
.43068 .45493 Mdot
.27936 .47906 Mdot
.39809 .67558 Mdot
.59307 .62567 Mdot
.65589 .57679 Mdot
.65304 .38605 Mdot
.64421 .38839 Mdot
.61383 .53762 Mdot
.48816 .61378 Mdot
.34681 .55052 Mdot
.35585 .41957 Mdot
.66661 .38709 Mdot
.4908 .63455 Mdot
.49271 .29853 Mdot
.4335 .64671 Mdot
.13049 .46098 Mdot
.73796 .61503 Mdot
.63487 .52833 Mdot
.44779 .31993 Mdot
.65169 .41348 Mdot
.67533 .41271 Mdot
.48264 .32919 Mdot
.36402 .49278 Mdot
.43877 .66733 Mdot
.75933 .68233 Mdot
.47618 .59958 Mdot
.79419 .64076 Mdot
.42943 .68363 Mdot
.55019 .62392 Mdot
.6271 .58939 Mdot
.6012 .38522 Mdot
.38764 .44196 Mdot
.37015 .48389 Mdot
.42444 .63752 Mdot
.35562 .46898 Mdot
.36905 .57544 Mdot
.38043 .43713 Mdot
.74423 .57536 Mdot
.44382 .33061 Mdot
.61377 .53792 Mdot
.31324 .3032 Mdot
.45753 .6359 Mdot
.47153 .24351 Mdot
.62889 .3664 Mdot
.33982 .7071 Mdot
.65731 .59445 Mdot
.45629 .3148 Mdot
.63195 .36612 Mdot
.49567 .30041 Mdot
.4399 .44681 Mdot
.63767 .43428 Mdot
.46039 .33438 Mdot
.29387 .72652 Mdot
.43745 .47663 Mdot
.20127 .59332 Mdot
.6311 .61047 Mdot
.49505 .67343 Mdot
.38198 .42676 Mdot
.59616 .39261 Mdot
.43946 .51724 Mdot
.74044 .4079 Mdot
.71865 .54385 Mdot
.65053 .43744 Mdot
.57592 .34027 Mdot
.46006 .31094 Mdot
.71487 .41412 Mdot
.62544 .66191 Mdot
.44285 .70444 Mdot
.34498 .49725 Mdot
.44064 .83051 Mdot
.62919 .57489 Mdot
.36729 .50032 Mdot
.74623 .55337 Mdot
.63256 .5735 Mdot
.38878 .46735 Mdot
.65763 .61102 Mdot
.43985 .68411 Mdot
.51604 .20623 Mdot
.45062 .71025 Mdot
.40318 .51888 Mdot
.67002 .59588 Mdot
.65961 .42613 Mdot
.45716 .6984 Mdot
.35573 .49298 Mdot
.36851 .44293 Mdot
.55856 .47179 Mdot
.41053 .44099 Mdot
.40676 .80332 Mdot
.40284 .43258 Mdot
.64559 .3835 Mdot
.346 .4409 Mdot
.78906 .33398 Mdot
.66043 .48886 Mdot
.43998 .66243 Mdot
.63548 .43836 Mdot
.63763 .38981 Mdot
.55334 .24062 Mdot
.68903 .40211 Mdot
.38965 .5158 Mdot
.60095 .40232 Mdot
.44207 .25206 Mdot
.62507 .56175 Mdot
.33664 .47914 Mdot
.56119 .61107 Mdot
.56067 .39539 Mdot
.67218 .39623 Mdot
.35324 .54001 Mdot
.42473 .6952 Mdot
.40839 .46442 Mdot
.67028 .4021 Mdot
.47534 .61971 Mdot
.38633 .52333 Mdot
.46372 .55471 Mdot
.5583 .47242 Mdot
.61693 .58299 Mdot
.43107 .54879 Mdot
.3492 .49108 Mdot
.60392 .37418 Mdot
.44027 .64622 Mdot
.6519 .55481 Mdot
.45861 .69058 Mdot
.6107 .78892 Mdot
.7158 .6146 Mdot
.24757 .67017 Mdot
.51133 .31629 Mdot
.77537 .4297 Mdot
.50063 .82491 Mdot
.7044 .2968 Mdot
.39559 .3236 Mdot
.66792 .77579 Mdot
.66067 .38977 Mdot
.75782 .55051 Mdot
.63858 .38733 Mdot
.41834 .48194 Mdot
.62257 .39306 Mdot
.49149 .8273 Mdot
.38317 .43618 Mdot
.61549 .39026 Mdot
.52396 .22304 Mdot
.40834 .45091 Mdot
.47341 .65864 Mdot
.29197 .76785 Mdot
.72557 .29666 Mdot
.76285 .59899 Mdot
.63092 .42971 Mdot
.36464 .359 Mdot
.3945 .43506 Mdot
.36692 .42218 Mdot
.46341 .70367 Mdot
.33515 .45662 Mdot
.49571 .30287 Mdot
.44799 .31276 Mdot
.50495 .45514 Mdot
.42527 .20323 Mdot
.34586 .4172 Mdot
.45855 .70016 Mdot
.21188 .5415 Mdot
.74421 .35498 Mdot
.69494 .33943 Mdot
.61384 .60953 Mdot
.3458 .78493 Mdot
.42237 .58328 Mdot
.70377 .5924 Mdot
.56883 .60346 Mdot
.46267 .66161 Mdot
.38351 .80901 Mdot
.65253 .57353 Mdot
.29307 .55737 Mdot
.29262 .41475 Mdot
.36869 .49076 Mdot
.64587 .60102 Mdot
.38325 .39788 Mdot
.77019 .33207 Mdot
.22389 .43103 Mdot
.30207 .2735 Mdot
.38678 .52714 Mdot
.72148 .33683 Mdot
.3932 .45266 Mdot
.499 .7447 Mdot
.40017 .43152 Mdot
.46514 .6906 Mdot
.5317 .67084 Mdot
.52687 .45515 Mdot
.36057 .21614 Mdot
.73251 .61971 Mdot
.49984 .32397 Mdot
.38041 .4414 Mdot
.3698 .49108 Mdot
.47698 .29685 Mdot
.48324 .65878 Mdot
.42476 .44166 Mdot
.44034 .26837 Mdot
.36411 .46792 Mdot
.65632 .57032 Mdot
.27602 .31439 Mdot
.4194 .70502 Mdot
.33139 .45209 Mdot
.47525 .62419 Mdot
.61593 .57911 Mdot
.6615 .56698 Mdot
.33131 .51284 Mdot
.61771 .55107 Mdot
.39945 .4506 Mdot
.21859 .38904 Mdot
.48605 .67869 Mdot
.4151 .5678 Mdot
.47359 .64052 Mdot
.28785 .67483 Mdot
.67465 .58552 Mdot
.732 .56972 Mdot
.31396 .44125 Mdot
.65263 .57773 Mdot
.70525 .64091 Mdot
.33508 .4284 Mdot
.35452 .5244 Mdot
.8087 .43682 Mdot
.64226 .42979 Mdot
.54079 .45827 Mdot
.67124 .57195 Mdot
.34847 .48582 Mdot
.33296 .47962 Mdot
.61423 .58148 Mdot
.25857 .53693 Mdot
.6121 .24566 Mdot
.3887 .43287 Mdot
.47371 .68576 Mdot
.46327 .67817 Mdot
.37158 .52816 Mdot
.36624 .50555 Mdot
.63836 .41552 Mdot
.62866 .43632 Mdot
.5983 .41723 Mdot
.55672 .47158 Mdot
.73739 .57219 Mdot
.61611 .74658 Mdot
.60742 .57391 Mdot
.63787 .68908 Mdot
.78235 .37622 Mdot
.44899 .45232 Mdot
.60969 .41905 Mdot
.37869 .49275 Mdot
.40416 .46395 Mdot
.65012 .5537 Mdot
.75951 .5794 Mdot
.44777 .41102 Mdot
.48696 .68442 Mdot
.66955 .56723 Mdot
.30143 .48502 Mdot
.67304 .70444 Mdot
.46204 .3307 Mdot
.80522 .5409 Mdot
.66177 .58846 Mdot
.46504 .65755 Mdot
.67261 .59836 Mdot
.3677 .48172 Mdot
.41451 .52297 Mdot
.45829 .66831 Mdot
.46125 .34082 Mdot
.40238 .41869 Mdot
.38846 .4637 Mdot
.49563 .14672 Mdot
.72935 .3326 Mdot
.70811 .54442 Mdot
.42618 .44758 Mdot
.33127 .48439 Mdot
.49268 .29122 Mdot
.36488 .4731 Mdot
.35807 .44585 Mdot
.55645 .18966 Mdot
.67071 .52556 Mdot
.46771 .28225 Mdot
.29912 .56669 Mdot
.43076 .68985 Mdot
.41656 .83123 Mdot
.59997 .38886 Mdot
.62487 .53936 Mdot
.61987 .23914 Mdot
.67432 .42215 Mdot
.75079 .40629 Mdot
.40558 .82899 Mdot
.54489 .46382 Mdot
.44995 .28068 Mdot
.43077 .39665 Mdot
.37524 .43258 Mdot
.38972 .45066 Mdot
.47889 .3229 Mdot
.4398 .67516 Mdot
.5192 .4295 Mdot
.18221 .52509 Mdot
.39794 .46097 Mdot
.36218 .5707 Mdot
.3014 .74264 Mdot
.5528 .38474 Mdot
.49703 .31132 Mdot
.45563 .33774 Mdot
.38276 .44347 Mdot
.57418 .2026 Mdot
.45239 .69626 Mdot
.35627 .49389 Mdot
.37359 .51746 Mdot
.6336 .43132 Mdot
.45045 .65763 Mdot
.66091 .38877 Mdot
.72906 .57176 Mdot
.47096 .79251 Mdot
.50917 .14034 Mdot
.66909 .5739 Mdot
.38956 .77623 Mdot
.63179 .55806 Mdot
.36856 .23963 Mdot
.6773 .42129 Mdot
.39753 .50881 Mdot
.44556 .64175 Mdot
.35598 .49664 Mdot
.37811 .50517 Mdot
.36512 .49357 Mdot
.38992 .40949 Mdot
.72119 .23897 Mdot
.47822 .33658 Mdot
.32579 .45905 Mdot
.64988 .39087 Mdot
.39174 .78438 Mdot
.18243 .61546 Mdot
.37611 .48533 Mdot
.37042 .44478 Mdot
.47183 .65195 Mdot
.35089 .44338 Mdot
.62633 .56229 Mdot
.43797 .64794 Mdot
.41037 .43216 Mdot
.36545 .78596 Mdot
.42957 .47638 Mdot
.45973 .80845 Mdot
.67492 .59586 Mdot
.6872 .64706 Mdot
.33017 .44186 Mdot
.71181 .53811 Mdot
.54066 .45809 Mdot
.59727 .40235 Mdot
.65972 .54944 Mdot
.61082 .37947 Mdot
.19416 .45467 Mdot
.43559 .50954 Mdot
.42449 .45395 Mdot
.33467 .48223 Mdot
.60511 .40562 Mdot
.52776 .74359 Mdot
.70521 .44628 Mdot
.30972 .51079 Mdot
.62626 .4149 Mdot
.488 .63455 Mdot
.53122 .374 Mdot
.45591 .63872 Mdot
.4532 .29316 Mdot
.6338 .59941 Mdot
.4812 .34178 Mdot
.77045 .60269 Mdot
.45032 .66476 Mdot
.41868 .64571 Mdot
.60928 .4035 Mdot
.5944 .51836 Mdot
.76041 .74895 Mdot
.53993 .41495 Mdot
.36654 .28219 Mdot
.46922 .69995 Mdot
.41153 .50875 Mdot
.33181 .26438 Mdot
.57977 .5335 Mdot
.61402 .37925 Mdot
.40531 .49628 Mdot
.54448 .2047 Mdot
.6375 .4162 Mdot
.33817 .48388 Mdot
.65898 .41569 Mdot
.65642 .58874 Mdot
.63117 .42489 Mdot
.45641 .71669 Mdot
.36296 .45297 Mdot
.73868 .76728 Mdot
.50874 .27581 Mdot
.40649 .4353 Mdot
.67199 .5708 Mdot
.48516 .52092 Mdot
.38623 .49927 Mdot
.4713 .29052 Mdot
.62539 .40085 Mdot
.55364 .43745 Mdot
.39139 .4319 Mdot
.61173 .41007 Mdot
.46337 .62998 Mdot
.65918 .54852 Mdot
.47864 .39559 Mdot
.72822 .55247 Mdot
.45924 .70485 Mdot
.68541 .62718 Mdot
.65117 .54924 Mdot
.32932 .47332 Mdot
.3585 .50942 Mdot
.47178 .68167 Mdot
.47694 .21371 Mdot
.35417 .43389 Mdot
.40272 .50737 Mdot
.65198 .39094 Mdot
.60926 .38597 Mdot
.48626 .21571 Mdot
.66479 .41062 Mdot
.42221 .5171 Mdot
.4702 .68324 Mdot
.41012 .47401 Mdot
.46745 .652 Mdot
.34471 .45277 Mdot
.48823 .62172 Mdot
.48725 .66543 Mdot
.70113 .4252 Mdot
.40927 .48473 Mdot
.44047 .54282 Mdot
.37072 .50058 Mdot
.35869 .46606 Mdot
.64106 .41221 Mdot
.49314 .31844 Mdot
.32598 .51772 Mdot
.46017 .28003 Mdot
.48479 .29435 Mdot
.4002 .68974 Mdot
.63523 .43067 Mdot
.47546 .31172 Mdot
.21992 .64559 Mdot
.6084 .42499 Mdot
.47059 .32654 Mdot
.20197 .64476 Mdot
.66718 .57025 Mdot
.45023 .71273 Mdot
.40919 .45192 Mdot
.67102 .76891 Mdot
.2384 .38084 Mdot
.66953 .42635 Mdot
.40572 .43378 Mdot
.38156 .49439 Mdot
.49167 .65821 Mdot
.20908 .33386 Mdot
.59203 .36884 Mdot
.42231 .47407 Mdot
.44286 .65779 Mdot
.23653 .28777 Mdot
.63927 .37899 Mdot
.47352 .32592 Mdot
.61954 .60231 Mdot
.48925 .71008 Mdot
.63971 .50045 Mdot
.6149 .59055 Mdot
.65724 .46316 Mdot
.74867 .61588 Mdot
.39589 .51649 Mdot
.60908 .418 Mdot
.81699 .53738 Mdot
.45222 .59375 Mdot
.63176 .62972 Mdot
.35938 .36692 Mdot
.46519 .66165 Mdot
.62622 .56386 Mdot
.49136 .33572 Mdot
.42753 .6759 Mdot
.48334 .67061 Mdot
.64034 .55136 Mdot
.48904 .43511 Mdot
.55344 .60225 Mdot
.65818 .56799 Mdot
.7959 .41226 Mdot
.66436 .75003 Mdot
.60381 .41522 Mdot
.48556 .29654 Mdot
.74862 .67612 Mdot
.45041 .68847 Mdot
.34872 .78621 Mdot
.81694 .51932 Mdot
.3918 .43689 Mdot
.47514 .30687 Mdot
.5545 .75574 Mdot
.18535 .49606 Mdot
.63328 .57169 Mdot
.53919 .4735 Mdot
.47875 .35173 Mdot
.37359 .42983 Mdot
.29432 .3958 Mdot
.41237 .49181 Mdot
.62754 .5946 Mdot
.23175 .61953 Mdot
.4652 .65659 Mdot
.66131 .55747 Mdot
.8041 .54373 Mdot
.39952 .45474 Mdot
.40827 .4916 Mdot
.29884 .32473 Mdot
.4354 .68494 Mdot
.59471 .39774 Mdot
.39404 .51608 Mdot
.39137 .46254 Mdot
.37112 .53908 Mdot
.41007 .56474 Mdot
.60766 .2109 Mdot
.42024 .47709 Mdot
.73342 .59188 Mdot
.33038 .45256 Mdot
.40666 .48521 Mdot
.4774 .62452 Mdot
.56387 .15104 Mdot
.73064 .57552 Mdot
.39376 .46065 Mdot
.41597 .50221 Mdot
.63913 .55037 Mdot
.54021 .57795 Mdot
.59487 .52172 Mdot
.58218 .47782 Mdot
.38322 .33872 Mdot
.39377 .40854 Mdot
.44662 .64691 Mdot
.45499 .32706 Mdot
.3638 .52193 Mdot
.44725 .64763 Mdot
.43285 .44287 Mdot
.63365 .41757 Mdot
.61073 .42692 Mdot
.62146 .64857 Mdot
.47194 .31809 Mdot
.26658 .3565 Mdot
.62832 .69767 Mdot
.65593 .39229 Mdot
.42194 .45525 Mdot
.63725 .5369 Mdot
.67156 .40365 Mdot
.608 .48809 Mdot
.37883 .55315 Mdot
.44482 .69401 Mdot
.47271 .66645 Mdot
.39801 .25614 Mdot
.74471 .47109 Mdot
.49738 .16164 Mdot
.6542 .59218 Mdot
.38979 .42172 Mdot
.61235 .66413 Mdot
.47311 .6643 Mdot
.34662 .26002 Mdot
.47346 .31152 Mdot
.63179 .57068 Mdot
.69569 .34302 Mdot
.46274 .64703 Mdot
.46335 .70916 Mdot
.41892 .50483 Mdot
.38154 .47204 Mdot
.40007 .3142 Mdot
.43922 .35951 Mdot
.61702 .57438 Mdot
.47949 .296 Mdot
.63722 .36787 Mdot
.42028 .48322 Mdot
.4817 .64445 Mdot
.72618 .70093 Mdot
.41029 .50851 Mdot
.64236 .41475 Mdot
.46519 .6652 Mdot
.47029 .29799 Mdot
.4805 .29161 Mdot
.35991 .46642 Mdot
.21833 .54478 Mdot
.64296 .5689 Mdot
.47258 .65915 Mdot
.7083 .6729 Mdot
.34683 .4387 Mdot
.38096 .46578 Mdot
.45948 .48275 Mdot
.63293 .55364 Mdot
.64565 .65431 Mdot
.46871 .34791 Mdot
.44575 .67905 Mdot
.4314 .46408 Mdot
.46565 .32307 Mdot
.63255 .65743 Mdot
.65653 .43434 Mdot
.63888 .42434 Mdot
.4737 .29038 Mdot
.47918 .30077 Mdot
.46743 .29355 Mdot
.33921 .78467 Mdot
.46507 .71756 Mdot
.43708 .56743 Mdot
.36167 .42762 Mdot
.38416 .25646 Mdot
.31442 .50776 Mdot
.68062 .58677 Mdot
.64726 .42764 Mdot
.37602 .50222 Mdot
.40038 .52001 Mdot
.44741 .52691 Mdot
.43695 .55656 Mdot
.41844 .69867 Mdot
.44914 .66151 Mdot
.44602 .48493 Mdot
.64261 .43219 Mdot
.13904 .43146 Mdot
.59374 .83274 Mdot
.32465 .44983 Mdot
.56111 .56281 Mdot
.48141 .64555 Mdot
.62019 .55429 Mdot
.60335 .50049 Mdot
.66504 .60407 Mdot
.45145 .67877 Mdot
.42008 .48178 Mdot
.64275 .69413 Mdot
.48082 .28842 Mdot
.34916 .47452 Mdot
.62607 .58244 Mdot
.35125 .46901 Mdot
.61539 .59201 Mdot
.58049 .78942 Mdot
.77515 .35928 Mdot
.39541 .44233 Mdot
.32718 .4781 Mdot
.37643 .36132 Mdot
.37798 .48577 Mdot
.52863 .34081 Mdot
.48117 .64772 Mdot
.4527 .18195 Mdot
.43025 .49078 Mdot
.32765 .64894 Mdot
.34898 .43528 Mdot
.5494 .21079 Mdot
.37773 .47 Mdot
.5543 .37685 Mdot
.38168 .43171 Mdot
.35741 .45001 Mdot
.6682 .59946 Mdot
.64111 .5509 Mdot
.43239 .63772 Mdot
.59582 .39434 Mdot
.44175 .81061 Mdot
.38595 .4636 Mdot
.72849 .55112 Mdot
.71439 .58438 Mdot
.48256 .30008 Mdot
.45125 .68115 Mdot
.21645 .30525 Mdot
.63854 .61509 Mdot
.66379 .28926 Mdot
.47864 .22707 Mdot
.6498 .50458 Mdot
.5959 .48549 Mdot
.52004 .71462 Mdot
.45942 .3153 Mdot
.37312 .42891 Mdot
.76308 .63018 Mdot
.73195 .35387 Mdot
.35056 .55024 Mdot
.66298 .55659 Mdot
.34526 .69802 Mdot
.73975 .6847 Mdot
.46553 .35242 Mdot
.47823 .34387 Mdot
.61975 .59984 Mdot
.56695 .39607 Mdot
.41577 .39963 Mdot
.47083 .31159 Mdot
.66167 .4036 Mdot
.60296 .41742 Mdot
.69001 .35612 Mdot
.44855 .69232 Mdot
.79151 .56493 Mdot
.58996 .72182 Mdot
.61584 .5899 Mdot
.49073 .25664 Mdot
.47291 .72004 Mdot
.43685 .71381 Mdot
.60409 .39283 Mdot
.64466 .41125 Mdot
.43943 .71044 Mdot
.43033 .50062 Mdot
.46287 .48685 Mdot
.3961 .45901 Mdot
.48367 .32122 Mdot
.37518 .47684 Mdot
.63333 .41278 Mdot
.63629 .57648 Mdot
.64587 .40554 Mdot
.64893 .61486 Mdot
.62967 .73582 Mdot
.35619 .48693 Mdot
.36371 .44853 Mdot
.23686 .37885 Mdot
.45604 .6266 Mdot
.72895 .64136 Mdot
.74862 .57088 Mdot
.64117 .38794 Mdot
.35835 .4446 Mdot
.46198 .63338 Mdot
.45 .33782 Mdot
.23579 .37735 Mdot
.34921 .49711 Mdot
.4791 .64409 Mdot
.42622 .46511 Mdot
.25016 .68474 Mdot
.70799 .26514 Mdot
.4608 .68725 Mdot
.32823 .22721 Mdot
.42333 .48412 Mdot
.52119 .69151 Mdot
.34309 .50005 Mdot
.41782 .26867 Mdot
.35219 .43573 Mdot
.42938 .6841 Mdot
.396 .46633 Mdot
.42967 .66541 Mdot
.64012 .37678 Mdot
.60952 .56828 Mdot
.47506 .69743 Mdot
.36327 .51468 Mdot
.45541 .87553 Mdot
.63361 .59679 Mdot
.3845 .44156 Mdot
.64089 .60922 Mdot
.43762 .66054 Mdot
.45882 .70829 Mdot
.17364 .52699 Mdot
.68992 .53259 Mdot
.65657 .58744 Mdot
.42113 .47053 Mdot
.56097 .70226 Mdot
.41301 .47813 Mdot
.38702 .30497 Mdot
.39174 .53379 Mdot
.34744 .43935 Mdot
.15779 .57182 Mdot
.62298 .56187 Mdot
.51679 .16952 Mdot
.17956 .54542 Mdot
.32746 .7755 Mdot
.50149 .68853 Mdot
.46298 .35024 Mdot
.37903 .80606 Mdot
.72912 .56655 Mdot
.61914 .41424 Mdot
.37405 .50102 Mdot
.43621 .72722 Mdot
.64494 .56362 Mdot
.49158 .32121 Mdot
.39462 .44194 Mdot
.64649 .41197 Mdot
.62483 .25876 Mdot
.6143 .60355 Mdot
.44949 .68684 Mdot
.48909 .67821 Mdot
.2871 .2431 Mdot
.4314 .45591 Mdot
.36374 .44511 Mdot
.62939 .59759 Mdot
.45062 .58935 Mdot
.459 .3092 Mdot
.56151 .22406 Mdot
.6553 .58902 Mdot
.56784 .51426 Mdot
.44279 .66668 Mdot
.37995 .49413 Mdot
.51731 .75858 Mdot
.68745 .32897 Mdot
.34955 .5923 Mdot
.478 .32662 Mdot
.37885 .31008 Mdot
.42955 .68554 Mdot
.63322 .58324 Mdot
.74454 .49283 Mdot
.43417 .52864 Mdot
.38493 .4902 Mdot
.37274 .31039 Mdot
.50517 .43623 Mdot
.29588 .28104 Mdot
.34071 .48339 Mdot
.51158 .43135 Mdot
.34093 .46833 Mdot
.4147 .54413 Mdot
.41938 .51695 Mdot
.37799 .46014 Mdot
.48001 .64473 Mdot
.35907 .55061 Mdot
.61567 .41654 Mdot
.26153 .48093 Mdot
.57301 .48656 Mdot
.39743 .43286 Mdot
.41584 .48377 Mdot
.37817 .63245 Mdot
.70179 .5979 Mdot
.48113 .68198 Mdot
.44294 .61099 Mdot
.61282 .5553 Mdot
.45352 .51807 Mdot
.59272 .3848 Mdot
.35702 .54429 Mdot
.64112 .40881 Mdot
.47069 .63705 Mdot
.64014 .38446 Mdot
.60651 .58648 Mdot
.61066 .4216 Mdot
.73971 .57419 Mdot
.63177 .56192 Mdot
.43941 .69482 Mdot
.36455 .46076 Mdot
.66936 .56775 Mdot
.3073 .32307 Mdot
.48297 .3214 Mdot
.17161 .53519 Mdot
.43432 .4555 Mdot
.64198 .50974 Mdot
.4643 .55231 Mdot
.64415 .40568 Mdot
.65149 .22461 Mdot
.48738 .66817 Mdot
.45666 .29334 Mdot
.46903 .63545 Mdot
.81817 .42736 Mdot
.49231 .30946 Mdot
.20774 .65611 Mdot
.76928 .47999 Mdot
.55539 .41482 Mdot
.43192 .49691 Mdot
.29891 .40087 Mdot
.64028 .36785 Mdot
.64347 .56338 Mdot
.75782 .46637 Mdot
.35539 .45226 Mdot
.70709 .30644 Mdot
.42749 .64184 Mdot
.59861 .40044 Mdot
.64051 .58634 Mdot
.66175 .55966 Mdot
.36267 .50751 Mdot
.52397 .24831 Mdot
.34435 .47493 Mdot
.72931 .46697 Mdot
.38028 .33208 Mdot
.4551 .41981 Mdot
.38008 .43773 Mdot
.61142 .36987 Mdot
.42586 .46498 Mdot
.43243 .36952 Mdot
.79207 .59418 Mdot
.38905 .41157 Mdot
.75337 .5812 Mdot
.51017 .28085 Mdot
.45466 .66745 Mdot
.31816 .45507 Mdot
.68091 .51933 Mdot
.43016 .46151 Mdot
.85552 .40391 Mdot
.46894 .32569 Mdot
.70769 .52798 Mdot
.33517 .44798 Mdot
.37351 .514 Mdot
.33135 .39577 Mdot
.46402 .74066 Mdot
.6912 .32872 Mdot
.38784 .48374 Mdot
.3285 .35077 Mdot
.64507 .60308 Mdot
.34488 .48296 Mdot
.38839 .44767 Mdot
.41336 .73651 Mdot
.64742 .55509 Mdot
.64761 .39661 Mdot
.67892 .41846 Mdot
.58712 .36318 Mdot
.49722 .28829 Mdot
.54979 .49119 Mdot
.36444 .25841 Mdot
.72252 .29849 Mdot
.4515 .31841 Mdot
.43029 .48171 Mdot
.41604 .37192 Mdot
.41309 .50218 Mdot
.49479 .3315 Mdot
.64198 .55503 Mdot
.48179 .6832 Mdot
.58165 .64577 Mdot
.61828 .36034 Mdot
.33653 .48007 Mdot
.49961 .30799 Mdot
.44367 .69614 Mdot
.46068 .3624 Mdot
.4494 .67235 Mdot
.65331 .5859 Mdot
.61242 .55103 Mdot
.49279 .32639 Mdot
.46108 .63753 Mdot
.70944 .61213 Mdot
.19048 .49829 Mdot
.39859 .5333 Mdot
.58522 .60231 Mdot
.45444 .62932 Mdot
.41778 .6817 Mdot
.43116 .64641 Mdot
.35525 .47262 Mdot
.55857 .56388 Mdot
.35877 .53251 Mdot
.6169 .5777 Mdot
.65838 .41527 Mdot
.45202 .26135 Mdot
.66833 .73603 Mdot
.46466 .25678 Mdot
.40977 .42332 Mdot
.40031 .46036 Mdot
.38314 .44347 Mdot
.39854 .52589 Mdot
.72086 .48157 Mdot
.36138 .49897 Mdot
.66213 .60427 Mdot
.63085 .40397 Mdot
.38108 .42594 Mdot
.66119 .43204 Mdot
.53696 .6987 Mdot
.45484 .33001 Mdot
.53898 .48384 Mdot
.43579 .84722 Mdot
.44903 .70063 Mdot
.66584 .41016 Mdot
.61759 .41258 Mdot
.45831 .30149 Mdot
.64811 .56636 Mdot
.44418 .67156 Mdot
.42354 .27468 Mdot
.47286 .29344 Mdot
.39422 .4646 Mdot
.68832 .43243 Mdot
.69988 .31024 Mdot
.36141 .43495 Mdot
.38921 .50598 Mdot
.65259 .43704 Mdot
.56463 .39575 Mdot
.80091 .64921 Mdot
.31363 .28206 Mdot
.49363 .32212 Mdot
.46094 .33899 Mdot
.42654 .69863 Mdot
.32405 .48353 Mdot
.61664 .58125 Mdot
.26615 .32473 Mdot
.49141 .49334 Mdot
.2681 .34626 Mdot
.48281 .39432 Mdot
.35311 .49942 Mdot
.23311 .50538 Mdot
.40035 .45359 Mdot
.48942 .66193 Mdot
.43451 .6713 Mdot
.46921 .69573 Mdot
.64052 .5655 Mdot
.30537 .68605 Mdot
.66776 .59743 Mdot
.46584 .84764 Mdot
.43004 .69122 Mdot
.71306 .50459 Mdot
.60898 .37187 Mdot
.33476 .43519 Mdot
.46497 .30299 Mdot
.6749 .61273 Mdot
.41852 .4062 Mdot
.5854 .20301 Mdot
.6074 .40971 Mdot
.43881 .69549 Mdot
.51743 .71687 Mdot
.5418 .82092 Mdot
.60084 .50874 Mdot
.30094 .47375 Mdot
.32056 .39498 Mdot
.48445 .29941 Mdot
.3406 .58631 Mdot
.50112 .32328 Mdot
.62598 .57611 Mdot
.36592 .45138 Mdot
.37058 .45835 Mdot
.34199 .45707 Mdot
.35956 .49476 Mdot
.62366 .54993 Mdot
.37321 .41813 Mdot
.78906 .334 Mdot
.61285 .42881 Mdot
.27743 .70969 Mdot
.46238 .32138 Mdot
.66538 .55585 Mdot
.63246 .40567 Mdot
.62551 .44151 Mdot
.32167 .29224 Mdot
.38707 .43307 Mdot
.37365 .50232 Mdot
.67559 .30148 Mdot
.33916 .47791 Mdot
.30393 .47167 Mdot
.61372 .41142 Mdot
.46167 .25835 Mdot
.44928 .32187 Mdot
.47579 .34188 Mdot
.65152 .55909 Mdot
.46429 .63599 Mdot
.47853 .31623 Mdot
.64239 .37898 Mdot
.42556 .43094 Mdot
.37756 .51989 Mdot
.45118 .62971 Mdot
.81988 .51148 Mdot
.46831 .35336 Mdot
.52685 .70338 Mdot
.43468 .65704 Mdot
.47231 .71671 Mdot
.38657 .4904 Mdot
.36161 .55727 Mdot
.4546 .73232 Mdot
.4554 .30023 Mdot
.66016 .55189 Mdot
.57906 .46905 Mdot
.62288 .5855 Mdot
.43934 .67985 Mdot
.37626 .52375 Mdot
.43671 .68059 Mdot
.42367 .44466 Mdot
.32505 .82631 Mdot
.37412 .46251 Mdot
.74062 .30836 Mdot
.39297 .27553 Mdot
.61884 .40369 Mdot
.71358 .60799 Mdot
.60187 .39572 Mdot
.43258 .66293 Mdot
.36737 .52125 Mdot
.469 .34628 Mdot
.28645 .74717 Mdot
.46477 .72302 Mdot
.63236 .41992 Mdot
.58425 .38564 Mdot
.63088 .55963 Mdot
.37926 .425 Mdot
.38034 .49088 Mdot
.61372 .38937 Mdot
.46805 .44529 Mdot
.46663 .64471 Mdot
.36951 .44338 Mdot
.40418 .47448 Mdot
.6168 .4039 Mdot
.19461 .48431 Mdot
.4948 .7244 Mdot
.37332 .45223 Mdot
.7534 .52554 Mdot
.68038 .58408 Mdot
.41855 .51237 Mdot
.34603 .42492 Mdot
.47366 .30364 Mdot
.32713 .74055 Mdot
.78577 .60691 Mdot
.67929 .59117 Mdot
.59787 .38959 Mdot
.43274 .46022 Mdot
.60627 .37228 Mdot
.37061 .51771 Mdot
.39368 .76297 Mdot
.60076 .40838 Mdot
.38539 .51413 Mdot
.32061 .46223 Mdot
.43394 .68174 Mdot
.36335 .50369 Mdot
.39148 .64436 Mdot
.66163 .38689 Mdot
.37478 .5119 Mdot
.21997 .54902 Mdot
.66419 .57485 Mdot
.32165 .45342 Mdot
.46168 .33383 Mdot
.42876 .26854 Mdot
.62491 .70877 Mdot
.73943 .55471 Mdot
.46767 .33843 Mdot
.34975 .46766 Mdot
.58337 .38886 Mdot
.61693 .59563 Mdot
.69813 .28373 Mdot
.35515 .44401 Mdot
.6284 .59465 Mdot
.63709 .57842 Mdot
.46656 .33279 Mdot
.43813 .16071 Mdot
.35407 .42215 Mdot
.37614 .48408 Mdot
.3948 .6855 Mdot
.49084 .64444 Mdot
.37271 .47317 Mdot
.42145 .49684 Mdot
.65623 .6072 Mdot
.30606 .4543 Mdot
.36082 .67723 Mdot
.52472 .22135 Mdot
.66245 .61364 Mdot
.54088 .42739 Mdot
.59001 .39191 Mdot
.46364 .31768 Mdot
.46012 .67064 Mdot
.48864 .34687 Mdot
.62482 .42704 Mdot
.42735 .48457 Mdot
.63579 .61234 Mdot
.38858 .59475 Mdot
.61564 .5961 Mdot
.72906 .54507 Mdot
.47274 .63188 Mdot
.59418 .6679 Mdot
.8084 .3276 Mdot
.59284 .72739 Mdot
.70145 .59038 Mdot
.4825 .30019 Mdot
.65057 .46123 Mdot
.4032 .47027 Mdot
.3066 .56029 Mdot
.36014 .46172 Mdot
.22521 .55145 Mdot
.66243 .41361 Mdot
.59747 .41645 Mdot
.36912 .45201 Mdot
.38291 .32469 Mdot
.61215 .58783 Mdot
.62442 .56222 Mdot
.37502 .50917 Mdot
.65296 .57776 Mdot
.38321 .47444 Mdot
.63845 .41148 Mdot
.55915 .17326 Mdot
.39498 .45027 Mdot
.34912 .51888 Mdot
.60101 .53054 Mdot
.16676 .57641 Mdot
.77499 .52518 Mdot
.23778 .49231 Mdot
.57325 .81481 Mdot
.65234 .57839 Mdot
.34086 .52303 Mdot
.53795 .42075 Mdot
.65575 .43647 Mdot
.70747 .61346 Mdot
.36709 .47067 Mdot
.36403 .4733 Mdot
.36126 .44342 Mdot
.4089 .49188 Mdot
.31359 .56833 Mdot
.4288 .58136 Mdot
.24712 .6011 Mdot
.37587 .50464 Mdot
.28032 .40662 Mdot
.67136 .57315 Mdot
.43295 .63058 Mdot
.49274 .3453 Mdot
.35387 .49986 Mdot
.42389 .58613 Mdot
.67955 .57752 Mdot
.4682 .84769 Mdot
.63874 .55677 Mdot
.63641 .38907 Mdot
.61546 .55975 Mdot
.41231 .44091 Mdot
.46411 .67805 Mdot
.57314 .47474 Mdot
.71766 .41522 Mdot
.62002 .41476 Mdot
.40631 .43515 Mdot
.69359 .51965 Mdot
.61886 .4172 Mdot
.53832 .70091 Mdot
.46626 .6732 Mdot
.31845 .35212 Mdot
.43411 .6721 Mdot
.385 .51497 Mdot
.39643 .51251 Mdot
.62636 .63254 Mdot
.60885 .58421 Mdot
.4341 .66737 Mdot
.47904 .14389 Mdot
.50242 .32133 Mdot
.46514 .69617 Mdot
.44586 .50145 Mdot
.51239 .55227 Mdot
.47108 .67762 Mdot
.42718 .31764 Mdot
.63704 .56291 Mdot
.42909 .6959 Mdot
.44752 .49968 Mdot
.80384 .46886 Mdot
.46424 .29011 Mdot
.57748 .37714 Mdot
.65834 .36146 Mdot
.66888 .39769 Mdot
.64873 .54584 Mdot
.60661 .40215 Mdot
.65143 .60182 Mdot
.71483 .64557 Mdot
.25022 .42798 Mdot
.62938 .53575 Mdot
.63358 .54426 Mdot
.61005 .40378 Mdot
.37295 .43761 Mdot
.66718 .37866 Mdot
.37386 .53533 Mdot
.43704 .42504 Mdot
.6597 .59576 Mdot
.43046 .68559 Mdot
.45788 .71471 Mdot
.28865 .40296 Mdot
.48995 .67623 Mdot
.64247 .40984 Mdot
.71381 .27549 Mdot
.76472 .60853 Mdot
.64104 .60088 Mdot
.63294 .54707 Mdot
.41397 .47983 Mdot
.6119 .37917 Mdot
.62662 .36979 Mdot
.62502 .56994 Mdot
.28956 .52201 Mdot
.335 .50658 Mdot
.41695 .66143 Mdot
.43098 .69485 Mdot
.46599 .68591 Mdot
.42911 .65288 Mdot
.35099 .6451 Mdot
.63478 .56268 Mdot
.4288 .67861 Mdot
.3815 .51215 Mdot
.36525 .47344 Mdot
.5802 .47835 Mdot
.4717 .3413 Mdot
.42963 .43949 Mdot
.42745 .5091 Mdot
.38544 .49326 Mdot
.63547 .4242 Mdot
.45343 .45095 Mdot
.59474 .39995 Mdot
.58063 .37389 Mdot
.63337 .43566 Mdot
.73126 .56772 Mdot
.33113 .38603 Mdot
.61074 .81222 Mdot
.42259 .47384 Mdot
.47471 .59634 Mdot
.61449 .37329 Mdot
.62461 .21364 Mdot
.62669 .65398 Mdot
.35696 .44435 Mdot
.68613 .331 Mdot
.61224 .39092 Mdot
.48933 .68374 Mdot
.36924 .46819 Mdot
.58491 .36183 Mdot
.45457 .32334 Mdot
.43277 .51972 Mdot
.67618 .40981 Mdot
.45448 .64043 Mdot
.50823 .31727 Mdot
.42614 .68666 Mdot
.6454 .43391 Mdot
.32081 .45956 Mdot
.78041 .73376 Mdot
.60418 .36127 Mdot
.20918 .63499 Mdot
.50491 .69475 Mdot
.36916 .44248 Mdot
.6673 .4047 Mdot
.49181 .64847 Mdot
.65203 .54579 Mdot
.50636 .48565 Mdot
.48532 .68005 Mdot
.59761 .41626 Mdot
.67465 .40707 Mdot
.61475 .41225 Mdot
.45362 .65983 Mdot
.36625 .52697 Mdot
.45968 .65303 Mdot
.61746 .55795 Mdot
.40832 .46023 Mdot
.49036 .82609 Mdot
.46206 .59104 Mdot
.43394 .66149 Mdot
.65214 .40353 Mdot
.48922 .28932 Mdot
.39904 .44339 Mdot
.19758 .59833 Mdot
.41228 .43477 Mdot
.63475 .60351 Mdot
.51774 .19232 Mdot
.38397 .59537 Mdot
.35723 .4303 Mdot
.41375 .48114 Mdot
.61932 .56867 Mdot
.39149 .43558 Mdot
.35859 .43111 Mdot
.71796 .55824 Mdot
.44843 .65709 Mdot
.39815 .46795 Mdot
.65809 .40326 Mdot
.74333 .64367 Mdot
.34602 .52205 Mdot
.60488 .27617 Mdot
.34252 .34027 Mdot
.48646 .17976 Mdot
.35933 .45854 Mdot
.29158 .30571 Mdot
.40312 .49834 Mdot
.35046 .47914 Mdot
.41776 .47315 Mdot
.24531 .48044 Mdot
.61057 .41699 Mdot
.62738 .41184 Mdot
.46168 .29194 Mdot
.33965 .34287 Mdot
.47381 .30625 Mdot
.6447 .5606 Mdot
.57953 .27865 Mdot
.60153 .40901 Mdot
.45364 .63996 Mdot
.34677 .46926 Mdot
.60961 .36004 Mdot
.37679 .49485 Mdot
.41616 .4427 Mdot
.60288 .36928 Mdot
.59851 .36638 Mdot
.71985 .54078 Mdot
.45786 .33238 Mdot
.47379 .69536 Mdot
.44111 .46167 Mdot
.48672 .2957 Mdot
.36329 .52383 Mdot
.38402 .25176 Mdot
.47472 .69224 Mdot
.45096 .65548 Mdot
.47466 .70673 Mdot
.42762 .48358 Mdot
.40437 .43808 Mdot
.6664 .59805 Mdot
.4584 .63623 Mdot
.66169 .57322 Mdot
.55979 .47087 Mdot
.58963 .26334 Mdot
.36697 .47078 Mdot
.53119 .67923 Mdot
.46551 .30743 Mdot
.63817 .397 Mdot
.64026 .27463 Mdot
.46717 .28717 Mdot
.41447 .43721 Mdot
.60819 .36987 Mdot
.49144 .33349 Mdot
.29447 .45502 Mdot
.68032 .77593 Mdot
.49739 .2958 Mdot
.38046 .51096 Mdot
.33084 .41016 Mdot
.21888 .42708 Mdot
.49801 .29114 Mdot
.6334 .60866 Mdot
.42902 .48149 Mdot
.45241 .56805 Mdot
.47096 .35271 Mdot
.72289 .65388 Mdot
.62182 .39898 Mdot
.7944 .52896 Mdot
.43719 .41569 Mdot
.27944 .52628 Mdot
.49435 .33874 Mdot
.44489 .675 Mdot
.46699 .619 Mdot
.39418 .49221 Mdot
.50062 .29322 Mdot
.64962 .61833 Mdot
.62621 .39688 Mdot
.73575 .58081 Mdot
.45603 .6586 Mdot
.55668 .65935 Mdot
.65469 .41469 Mdot
.53619 .67905 Mdot
.52962 .20864 Mdot
.46092 .43375 Mdot
.23286 .47442 Mdot
.73878 .37677 Mdot
.43074 .48515 Mdot
.50262 .3138 Mdot
.67864 .58536 Mdot
.62669 .60791 Mdot
.65218 .59072 Mdot
.71932 .60229 Mdot
.59054 .49532 Mdot
.66055 .42777 Mdot
.71796 .37936 Mdot
.46627 .32113 Mdot
.27818 .38153 Mdot
.35595 .5144 Mdot
.3993 .45842 Mdot
.39317 .42255 Mdot
.34402 .48585 Mdot
.402 .49267 Mdot
.65223 .57005 Mdot
.72259 .59991 Mdot
.55603 .44225 Mdot
.47565 .68297 Mdot
.47131 .25888 Mdot
.6096 .37187 Mdot
.63855 .43844 Mdot
.48418 .33387 Mdot
.51031 .73378 Mdot
.66878 .42046 Mdot
.64217 .38708 Mdot
.413 .43132 Mdot
.46061 .64747 Mdot
.35025 .54529 Mdot
.40306 .50655 Mdot
.63729 .40206 Mdot
.5158 .38201 Mdot
.37407 .66242 Mdot
.426 .54376 Mdot
.51174 .32427 Mdot
.55313 .5616 Mdot
.499 .2933 Mdot
.3489 .51257 Mdot
.60636 .20509 Mdot
.62225 .42601 Mdot
.62429 .38166 Mdot
.5004 .31784 Mdot
.51335 .70474 Mdot
.46238 .66413 Mdot
.62516 .4417 Mdot
.64455 .60716 Mdot
.40614 .50866 Mdot
.60693 .25589 Mdot
.51928 .68272 Mdot
.54132 .25366 Mdot
.64731 .59581 Mdot
.62834 .37161 Mdot
.37467 .42502 Mdot
.38207 .51044 Mdot
.47991 .29755 Mdot
.54938 .78923 Mdot
.43648 .51012 Mdot
.33026 .77854 Mdot
.78364 .36872 Mdot
.81415 .48868 Mdot
.38482 .49005 Mdot
.44868 .6589 Mdot
.67699 .42149 Mdot
.48431 .29634 Mdot
.41844 .42109 Mdot
.65884 .7893 Mdot
.44369 .62746 Mdot
.62866 .57921 Mdot
.53565 .43238 Mdot
.60484 .50073 Mdot
.43074 .44836 Mdot
.36136 .4619 Mdot
.35569 .48004 Mdot
.75435 .70633 Mdot
.64193 .42058 Mdot
.48298 .64409 Mdot
.47914 .32844 Mdot
.49031 .67278 Mdot
.62263 .4091 Mdot
.57068 .66489 Mdot
.38963 .43004 Mdot
.44557 .62771 Mdot
.44767 .6755 Mdot
.63223 .55929 Mdot
.63963 .54288 Mdot
.54975 .45403 Mdot
.37531 .46307 Mdot
.66464 .38434 Mdot
.43402 .68665 Mdot
.68815 .42577 Mdot
.49143 .30733 Mdot
.67395 .58365 Mdot
.37375 .50396 Mdot
.61948 .42249 Mdot
.37544 .41729 Mdot
.47566 .66727 Mdot
.64104 .3859 Mdot
.71654 .53983 Mdot
.46108 .338 Mdot
.36473 .48711 Mdot
.50378 .34161 Mdot
.59759 .3881 Mdot
.40478 .47285 Mdot
.48587 .74779 Mdot
.50677 .29046 Mdot
.71018 .43969 Mdot
.6591 .4261 Mdot
.72539 .54946 Mdot
.46737 .70954 Mdot
.69862 .66523 Mdot
.62828 .38493 Mdot
.4882 .75016 Mdot
.60734 .76381 Mdot
.44175 .45406 Mdot
.45409 .68944 Mdot
.6449 .45403 Mdot
.40159 .8375 Mdot
.20154 .49607 Mdot
.38553 .44269 Mdot
.66464 .41466 Mdot
.4989 .31193 Mdot
.64241 .60095 Mdot
.60532 .27469 Mdot
.43271 .37074 Mdot
.58722 .37804 Mdot
.41827 .47629 Mdot
.43831 .66407 Mdot
.63666 .5691 Mdot
.64828 .70288 Mdot
.64944 .38762 Mdot
.65629 .41959 Mdot
.37049 .4259 Mdot
.47331 .31279 Mdot
.20154 .54984 Mdot
.63649 .41374 Mdot
.68386 .30982 Mdot
.66073 .4624 Mdot
.49965 .30659 Mdot
.39607 .50443 Mdot
.30201 .39323 Mdot
.40506 .52265 Mdot
.22374 .66679 Mdot
.60122 .39025 Mdot
.47932 .67723 Mdot
.35557 .46462 Mdot
.51331 .21945 Mdot
.63443 .39877 Mdot
.56279 .56044 Mdot
.56127 .34929 Mdot
.63543 .56313 Mdot
.64676 .27639 Mdot
.37205 .48109 Mdot
.61332 .59132 Mdot
.46612 .30714 Mdot
.37713 .45463 Mdot
.40617 .44026 Mdot
.49395 .66216 Mdot
.62451 .5765 Mdot
.63133 .76898 Mdot
.65933 .55597 Mdot
.67388 .59686 Mdot
.48574 .70057 Mdot
.3936 .4787 Mdot
.63945 .39078 Mdot
.61154 .38854 Mdot
.43242 .42567 Mdot
.6346 .20742 Mdot
.46241 .66162 Mdot
.4929 .25797 Mdot
.76849 .68882 Mdot
.45331 .42054 Mdot
.63553 .27112 Mdot
.54573 .78817 Mdot
.64556 .61829 Mdot
.37511 .50739 Mdot
.44367 .64742 Mdot
.6193 .43988 Mdot
.65692 .41273 Mdot
.37291 .52673 Mdot
.63998 .57524 Mdot
.45341 .3161 Mdot
.63136 .36631 Mdot
.52489 .24763 Mdot
.35447 .48794 Mdot
.71358 .3384 Mdot
.66385 .39496 Mdot
.31603 .78611 Mdot
.66175 .44363 Mdot
.45817 .6909 Mdot
.41587 .44422 Mdot
.48726 .68225 Mdot
.48451 .32442 Mdot
.54151 .44069 Mdot
.63775 .57572 Mdot
.43948 .39324 Mdot
.84749 .42747 Mdot
.60848 .40801 Mdot
.48154 .64768 Mdot
.35652 .43038 Mdot
.41009 .37684 Mdot
.37668 .47911 Mdot
.34216 .40649 Mdot
.51452 .28854 Mdot
.66389 .58989 Mdot
.63366 .60515 Mdot
.40545 .46715 Mdot
.46321 .29981 Mdot
.62959 .373 Mdot
.627 .39485 Mdot
.13308 .55849 Mdot
.69801 .40943 Mdot
.40274 .30832 Mdot
.3637 .47759 Mdot
.59374 .40987 Mdot
.69728 .71081 Mdot
.63063 .59831 Mdot
.35064 .50798 Mdot
.59295 .38761 Mdot
.78963 .4186 Mdot
.43498 .25083 Mdot
.3996 .49615 Mdot
.37339 .41007 Mdot
.64186 .60807 Mdot
.28355 .34913 Mdot
.64119 .43378 Mdot
.38617 .53586 Mdot
.60424 .57016 Mdot
.48891 .20685 Mdot
.80608 .56429 Mdot
.47324 .69578 Mdot
.55827 .3799 Mdot
.65177 .56938 Mdot
.44643 .44004 Mdot
.46207 .32534 Mdot
.65299 .37681 Mdot
.63223 .42247 Mdot
.42026 .46438 Mdot
.37014 .41948 Mdot
.38033 .36389 Mdot
.48168 .65195 Mdot
.66753 .56878 Mdot
.36151 .45188 Mdot
.55726 .63443 Mdot
.34121 .46116 Mdot
.66967 .59102 Mdot
.74042 .78874 Mdot
.44346 .46645 Mdot
.37794 .48082 Mdot
.199 .5456 Mdot
.4848 .68231 Mdot
.49141 .67569 Mdot
.7544 .33233 Mdot
.36373 .47848 Mdot
.67035 .29143 Mdot
.47432 .69668 Mdot
.46602 .66222 Mdot
.67155 .49665 Mdot
.39774 .44724 Mdot
.24602 .36908 Mdot
.61866 .59549 Mdot
.65969 .60813 Mdot
.45967 .6546 Mdot
.44505 .48332 Mdot
.63736 .61632 Mdot
.33473 .59695 Mdot
.61045 .37892 Mdot
.58962 .19735 Mdot
.47763 .6625 Mdot
.53251 .45876 Mdot
.6399 .59888 Mdot
.46191 .84744 Mdot
.6938 .35059 Mdot
.36904 .4407 Mdot
.36194 .48678 Mdot
.4636 .31114 Mdot
.44174 .45946 Mdot
.59859 .41812 Mdot
.65327 .57759 Mdot
.21852 .61311 Mdot
.46806 .69633 Mdot
.37836 .46763 Mdot
.53192 .70101 Mdot
.63523 .72461 Mdot
.77832 .48771 Mdot
.45452 .66832 Mdot
.45063 .69231 Mdot
.64588 .43209 Mdot
.66463 .40881 Mdot
.39566 .48581 Mdot
.61921 .57358 Mdot
.45104 .6394 Mdot
.66559 .59444 Mdot
.62468 .42645 Mdot
.64329 .39186 Mdot
.60124 .41053 Mdot
.38856 .53999 Mdot
.64891 .39123 Mdot
.51232 .24251 Mdot
.55892 .66744 Mdot
.43625 .71369 Mdot
.84001 .50979 Mdot
.64941 .70101 Mdot
.47636 .52003 Mdot
.47167 .34788 Mdot
.59735 .38725 Mdot
.62606 .55137 Mdot
.41173 .47994 Mdot
.37519 .49905 Mdot
.57594 .3656 Mdot
.61408 .56714 Mdot
.49001 .32128 Mdot
.61012 .5748 Mdot
.46498 .33233 Mdot
.69465 .33663 Mdot
.38285 .42458 Mdot
.38242 .51891 Mdot
.65536 .5746 Mdot
.64451 .38736 Mdot
.62916 .40621 Mdot
.50148 .29924 Mdot
.49812 .45096 Mdot
.61573 .41587 Mdot
.47715 .6636 Mdot
.3395 .63606 Mdot
.67646 .41397 Mdot
.37057 .47024 Mdot
.36198 .2561 Mdot
.31678 .563 Mdot
.39264 .52927 Mdot
.67466 .51654 Mdot
.27847 .27959 Mdot
.35154 .46095 Mdot
.29308 .25665 Mdot
.72675 .55163 Mdot
.48674 .67708 Mdot
.66121 .41842 Mdot
.61731 .43756 Mdot
.3142 .4459 Mdot
.44784 .35952 Mdot
.42869 .42591 Mdot
.48227 .68957 Mdot
.47918 .62386 Mdot
.80424 .43086 Mdot
.21027 .63873 Mdot
.49795 .32935 Mdot
.48312 .3373 Mdot
.62636 .38578 Mdot
.1749 .47225 Mdot
.42793 .53859 Mdot
.49259 .3226 Mdot
.25149 .4175 Mdot
.41891 .4805 Mdot
.37348 .30194 Mdot
.67741 .3182 Mdot
.45262 .65799 Mdot
.29875 .39952 Mdot
.63348 .39122 Mdot
.48484 .65911 Mdot
.56956 .63651 Mdot
.43197 .44547 Mdot
.47338 .69267 Mdot
.66381 .59822 Mdot
.75096 .41135 Mdot
.45981 .70771 Mdot
.37207 .2512 Mdot
.62397 .56981 Mdot
.66095 .47211 Mdot
.29492 .37716 Mdot
.73337 .21987 Mdot
.65023 .57152 Mdot
.5949 .37254 Mdot
.6124 .38914 Mdot
.62616 .39346 Mdot
.48752 .663 Mdot
.62029 .36844 Mdot
.47915 .64801 Mdot
.2067 .4428 Mdot
.49737 .45263 Mdot
.49389 .32451 Mdot
.69396 .53699 Mdot
.44661 .68306 Mdot
.691 .25493 Mdot
.82079 .35627 Mdot
.37129 .50737 Mdot
.64683 .55029 Mdot
.49565 .32859 Mdot
.27041 .7422 Mdot
.4702 .30544 Mdot
.54738 .39352 Mdot
.54805 .18523 Mdot
.38351 .469 Mdot
.35293 .71465 Mdot
.4688 .34513 Mdot
.44422 .66791 Mdot
.40329 .46807 Mdot
.69627 .62225 Mdot
.46859 .31199 Mdot
.45437 .31649 Mdot
.40066 .48209 Mdot
.43835 .69499 Mdot
.64245 .39541 Mdot
.60895 .5648 Mdot
.46958 .28102 Mdot
.49842 .62584 Mdot
.43572 .48131 Mdot
.43369 .4675 Mdot
.5917 .5221 Mdot
.42425 .35583 Mdot
.65176 .57798 Mdot
.23469 .4146 Mdot
.66387 .4101 Mdot
.60568 .45246 Mdot
.75761 .34613 Mdot
.6895 .52878 Mdot
.60302 .39417 Mdot
.59918 .39288 Mdot
.39973 .49183 Mdot
.4183 .35084 Mdot
.49983 .18935 Mdot
.69758 .56408 Mdot
.67598 .41885 Mdot
.62831 .39725 Mdot
.46516 .62092 Mdot
.80742 .42838 Mdot
.41365 .41987 Mdot
.67767 .59655 Mdot
.6222 .42265 Mdot
.39608 .76497 Mdot
.47342 .31724 Mdot
.65376 .23296 Mdot
.37837 .4261 Mdot
.36411 .44822 Mdot
.64495 .58689 Mdot
.6679 .598 Mdot
.63488 .63829 Mdot
.7971 .38953 Mdot
.24636 .33853 Mdot
.69178 .68606 Mdot
.39309 .75548 Mdot
.43892 .6268 Mdot
.43356 .66302 Mdot
.72684 .58045 Mdot
.67054 .56504 Mdot
.35306 .46407 Mdot
.45063 .64053 Mdot
.76541 .46589 Mdot
.44189 .59988 Mdot
.3858 .30848 Mdot
.56694 .23881 Mdot
.41916 .44103 Mdot
.45303 .64797 Mdot
.48477 .67515 Mdot
.43897 .64435 Mdot
.72644 .55245 Mdot
.38726 .48364 Mdot
.38357 .43559 Mdot
.34697 .45754 Mdot
.3891 .57315 Mdot
.35827 .49683 Mdot
.6977 .55464 Mdot
.5683 .51928 Mdot
.27017 .68999 Mdot
.40314 .52811 Mdot
.64994 .61573 Mdot
.43667 .46154 Mdot
.46138 .30087 Mdot
.41653 .47572 Mdot
.39118 .30506 Mdot
.63023 .59042 Mdot
.50444 .70651 Mdot
.69073 .68192 Mdot
.38572 .42789 Mdot
.45079 .32075 Mdot
.45852 .54786 Mdot
.57492 .79284 Mdot
.4383 .3555 Mdot
.47661 .66278 Mdot
.6051 .3813 Mdot
.62195 .55579 Mdot
.63652 .38628 Mdot
.40343 .53341 Mdot
.65897 .5093 Mdot
.5555 .74927 Mdot
.53084 .44364 Mdot
.34967 .49556 Mdot
.45766 .45116 Mdot
.47215 .66251 Mdot
.60761 .36999 Mdot
.41047 .67611 Mdot
.35646 .47024 Mdot
.48034 .32497 Mdot
.46648 .31546 Mdot
.63664 .64832 Mdot
.43668 .80008 Mdot
.69509 .65973 Mdot
.64757 .58572 Mdot
.63716 .41581 Mdot
.49812 .33427 Mdot
.49959 .61413 Mdot
.67454 .56025 Mdot
.6198 .56705 Mdot
.6272 .57208 Mdot
.42136 .49188 Mdot
.59457 .39985 Mdot
.26079 .67468 Mdot
.597 .4141 Mdot
.39755 .43433 Mdot
.6444 .42117 Mdot
.59817 .40062 Mdot
.46144 .31703 Mdot
.65018 .55822 Mdot
.63387 .4292 Mdot
.38374 .51536 Mdot
.45773 .70328 Mdot
.51075 .44549 Mdot
.40664 .26352 Mdot
.25439 .70123 Mdot
.27711 .71807 Mdot
.44264 .70605 Mdot
.43422 .82405 Mdot
.6807 .59804 Mdot
.28786 .51912 Mdot
.73762 .52669 Mdot
.38297 .52417 Mdot
.70899 .25758 Mdot
.66039 .42846 Mdot
.60043 .37007 Mdot
.39883 .50379 Mdot
.56382 .3883 Mdot
.37831 .47156 Mdot
.64558 .42487 Mdot
.47003 .26108 Mdot
.32299 .44316 Mdot
.64026 .38017 Mdot
.37374 .53794 Mdot
.40193 .4474 Mdot
.45213 .65659 Mdot
.66788 .40278 Mdot
.34802 .5049 Mdot
.19035 .65966 Mdot
.67217 .59084 Mdot
.69984 .53053 Mdot
.36169 .2439 Mdot
.65247 .5687 Mdot
.46624 .69388 Mdot
.43617 .42513 Mdot
.47129 .30054 Mdot
.44163 .67975 Mdot
.45103 .24028 Mdot
.47 .34368 Mdot
.70639 .26196 Mdot
.47397 .65757 Mdot
.67544 .41314 Mdot
.45873 .32078 Mdot
.34981 .52901 Mdot
.64168 .36988 Mdot
.49322 .5007 Mdot
.60152 .38805 Mdot
.37931 .49099 Mdot
.73678 .58705 Mdot
.67471 .57965 Mdot
.385 .44488 Mdot
.62613 .36541 Mdot
.73175 .57079 Mdot
.42207 .48747 Mdot
.40881 .48572 Mdot
.82058 .50231 Mdot
.66279 .25677 Mdot
.48689 .30184 Mdot
.48548 .64079 Mdot
.38169 .51238 Mdot
.45708 .32813 Mdot
.56339 .32159 Mdot
.43379 .47616 Mdot
.44153 .63092 Mdot
.41207 .55833 Mdot
.65335 .38163 Mdot
.66045 .56933 Mdot
.54913 .46335 Mdot
.45483 .32467 Mdot
.40215 .15378 Mdot
.60293 .41634 Mdot
.34667 .50918 Mdot
.34628 .49281 Mdot
.77901 .51668 Mdot
.48505 .66621 Mdot
.25131 .33708 Mdot
.36449 .48719 Mdot
.41283 .56733 Mdot
.38013 .45448 Mdot
.56568 .4228 Mdot
.46328 .66307 Mdot
.37673 .48526 Mdot
.53884 .6566 Mdot
.34249 .51479 Mdot
.45263 .32256 Mdot
.19792 .51487 Mdot
.43037 .48799 Mdot
.86094 .62066 Mdot
.66283 .29052 Mdot
.64292 .3824 Mdot
.73441 .59376 Mdot
.1605 .41136 Mdot
.71146 .64949 Mdot
.47842 .64562 Mdot
.54198 .78143 Mdot
.64063 .39133 Mdot
.72132 .66439 Mdot
.42598 .82992 Mdot
.40398 .44873 Mdot
.43033 .44777 Mdot
.54723 .39378 Mdot
.59795 .41955 Mdot
.67331 .3963 Mdot
.40973 .52687 Mdot
.41017 .54833 Mdot
.65267 .39891 Mdot
.37389 .5141 Mdot
.34927 .53779 Mdot
.61344 .55766 Mdot
.44486 .70512 Mdot
.65169 .59848 Mdot
.63651 .5557 Mdot
.26883 .54893 Mdot
.79514 .39656 Mdot
.67129 .58782 Mdot
.67929 .59928 Mdot
.37987 .29773 Mdot
.35812 .36666 Mdot
.47155 .35169 Mdot
.38014 .79669 Mdot
.62329 .39356 Mdot
.38835 .48074 Mdot
.44309 .70964 Mdot
.2714 .51234 Mdot
.63482 .29581 Mdot
.5142 .18472 Mdot
.35441 .46817 Mdot
.6327 .39486 Mdot
.72965 .55474 Mdot
.34377 .54177 Mdot
.61845 .4669 Mdot
.3626 .44603 Mdot
.61332 .36048 Mdot
.33405 .6672 Mdot
.51755 .7203 Mdot
.67896 .44201 Mdot
.42629 .63103 Mdot
.36514 .45562 Mdot
.47975 .66396 Mdot
.65145 .5954 Mdot
.46096 .30593 Mdot
.48698 .30316 Mdot
.40444 .47739 Mdot
.46255 .4922 Mdot
.68392 .333 Mdot
.39997 .44316 Mdot
.41628 .46624 Mdot
.72701 .55177 Mdot
.41435 .46534 Mdot
.34521 .48637 Mdot
.34362 .4723 Mdot
.32854 .47564 Mdot
.6712 .59977 Mdot
.53229 .69781 Mdot
.40948 .53428 Mdot
.34483 .53967 Mdot
.60575 .58915 Mdot
.57403 .7804 Mdot
.6425 .55406 Mdot
.49474 .82689 Mdot
.63841 .60354 Mdot
.49237 .31269 Mdot
.75391 .56538 Mdot
.46289 .46576 Mdot
.42739 .66965 Mdot
.66853 .55704 Mdot
.4736 .33286 Mdot
.65446 .58474 Mdot
.65267 .41729 Mdot
.79069 .63874 Mdot
.46708 .60961 Mdot
.27621 .31114 Mdot
.65023 .64832 Mdot
.70899 .41396 Mdot
.61989 .42785 Mdot
.4617 .65878 Mdot
.37491 .67366 Mdot
.34168 .47366 Mdot
.45849 .32905 Mdot
.39909 .48635 Mdot
.67699 .59319 Mdot
.62996 .39071 Mdot
.19463 .50871 Mdot
.47713 .29799 Mdot
.83187 .48843 Mdot
.62244 .40121 Mdot
.34613 .44969 Mdot
.67657 .5979 Mdot
.8483 .48215 Mdot
.65926 .59465 Mdot
.48212 .45328 Mdot
.42105 .65493 Mdot
.23217 .4829 Mdot
.45156 .68636 Mdot
.66403 .43459 Mdot
.79382 .67777 Mdot
.33993 .7751 Mdot
.44435 .69879 Mdot
.70774 .3825 Mdot
.43133 .45518 Mdot
.43461 .46603 Mdot
.50659 .72427 Mdot
.47422 .6339 Mdot
.3676 .50621 Mdot
.71216 .53706 Mdot
.56808 .68809 Mdot
.65871 .27389 Mdot
.60091 .37902 Mdot
.37402 .47582 Mdot
.60379 .58384 Mdot
.6107 .57487 Mdot
.59672 .41148 Mdot
.64293 .55296 Mdot
.38378 .43655 Mdot
.44844 .68396 Mdot
.64165 .36554 Mdot
.48389 .30959 Mdot
.18376 .62152 Mdot
.49687 .33847 Mdot
.60387 .39568 Mdot
.32114 .45978 Mdot
.64355 .39165 Mdot
.18776 .31564 Mdot
.37579 .43959 Mdot
.47788 .6915 Mdot
.4112 .49397 Mdot
.36912 .45406 Mdot
.43312 .452 Mdot
.65412 .40711 Mdot
.27644 .29394 Mdot
.37767 .51524 Mdot
.63656 .57473 Mdot
.30416 .72603 Mdot
.43633 .45727 Mdot
.46129 .27073 Mdot
.36372 .34136 Mdot
.71889 .37615 Mdot
.43008 .7004 Mdot
.61985 .3716 Mdot
.46147 .69966 Mdot
.4418 .60435 Mdot
.46671 .69357 Mdot
.31157 .71587 Mdot
.36676 .67551 Mdot
.31971 .24971 Mdot
.22159 .55762 Mdot
.27625 .46668 Mdot
.48072 .63694 Mdot
.531 .35043 Mdot
.43593 .65364 Mdot
.48328 .66683 Mdot
.50189 .92138 Mdot
.4293 .67154 Mdot
.36816 .4765 Mdot
.41584 .42982 Mdot
.60929 .72447 Mdot
.35138 .3009 Mdot
.40993 .46822 Mdot
.39184 .51088 Mdot
.46086 .30904 Mdot
.45615 .52419 Mdot
.6603 .50998 Mdot
.71783 .28352 Mdot
.65649 .72238 Mdot
.40078 .48462 Mdot
.38426 .51361 Mdot
.38867 .54722 Mdot
.86588 .54021 Mdot
.28553 .55435 Mdot
.47601 .63089 Mdot
.45149 .45386 Mdot
.24488 .70221 Mdot
.37482 .43262 Mdot
.42194 .49659 Mdot
.42345 .44448 Mdot
.63996 .39124 Mdot
.43859 .62961 Mdot
.45181 .46413 Mdot
.72214 .33029 Mdot
.39195 .42827 Mdot
.69395 .53369 Mdot
.19944 .37028 Mdot
.37162 .48218 Mdot
.4243 .66556 Mdot
.42657 .46574 Mdot
.47333 .65373 Mdot
.4438 .6596 Mdot
.32444 .47856 Mdot
.36444 .7507 Mdot
.42785 .64361 Mdot
.39925 .43439 Mdot
.64673 .40136 Mdot
.3671 .80055 Mdot
.37711 .49218 Mdot
.48535 .29562 Mdot
.36275 .48546 Mdot
.45072 .31134 Mdot
.41384 .45822 Mdot
.59496 .40847 Mdot
.37126 .59185 Mdot
.62309 .38275 Mdot
.21703 .37658 Mdot
.59103 .39336 Mdot
.82224 .49644 Mdot
.45989 .62751 Mdot
.73126 .57691 Mdot
.46347 .16391 Mdot
.68958 .52422 Mdot
.55079 .57966 Mdot
.5353 .55705 Mdot
.61938 .5725 Mdot
.48566 .68861 Mdot
.26536 .37764 Mdot
.77371 .48299 Mdot
.76736 .52261 Mdot
.60416 .40873 Mdot
.47081 .14846 Mdot
.55485 .17719 Mdot
.39948 .51314 Mdot
.33918 .71691 Mdot
.25706 .61421 Mdot
.43168 .48206 Mdot
.43884 .42664 Mdot
.57949 .36657 Mdot
.34848 .49905 Mdot
.55149 .63407 Mdot
.61033 .40264 Mdot
.47082 .33409 Mdot
.48075 .67237 Mdot
.46007 .2952 Mdot
.77273 .49648 Mdot
.53449 .56296 Mdot
.63676 .42655 Mdot
.33672 .50254 Mdot
.40645 .50085 Mdot
.45814 .6516 Mdot
.42998 .72718 Mdot
.43411 .68119 Mdot
.49886 .32329 Mdot
.6129 .40134 Mdot
.28679 .54404 Mdot
.38686 .5078 Mdot
.45016 .67624 Mdot
.58235 .62504 Mdot
.3804 .5101 Mdot
.65877 .57917 Mdot
.41051 .43462 Mdot
.45069 .70345 Mdot
.41419 .46496 Mdot
.44791 .68594 Mdot
.60826 .37811 Mdot
.37109 .43173 Mdot
.39851 .50119 Mdot
.84305 .4925 Mdot
.48988 .31923 Mdot
.4686 .63104 Mdot
.56001 .37127 Mdot
.3393 .46498 Mdot
.71442 .46301 Mdot
.36209 .45881 Mdot
.41909 .6249 Mdot
.34877 .51457 Mdot
.73062 .56063 Mdot
.40193 .41871 Mdot
.37722 .49119 Mdot
.53047 .59722 Mdot
.2704 .648 Mdot
.42787 .7296 Mdot
.66973 .60514 Mdot
.43107 .64989 Mdot
.59787 .25602 Mdot
.67166 .42103 Mdot
.62014 .36752 Mdot
.30478 .31543 Mdot
.33163 .44908 Mdot
.3841 .47078 Mdot
.61195 .55121 Mdot
.47504 .33908 Mdot
.45265 .66934 Mdot
.4665 .33279 Mdot
.7427 .3353 Mdot
.4896 .33823 Mdot
.60879 .43236 Mdot
.69636 .33369 Mdot
.33076 .58176 Mdot
.46083 .30978 Mdot
.43657 .69366 Mdot
.55545 .23953 Mdot
.37876 .52777 Mdot
.47851 .36294 Mdot
.47997 .32356 Mdot
.46363 .14205 Mdot
.34742 .49074 Mdot
.55503 .57533 Mdot
.66866 .58129 Mdot
.46139 .32328 Mdot
.62185 .58223 Mdot
.40924 .47217 Mdot
.70712 .4453 Mdot
.47574 .63961 Mdot
.62202 .61249 Mdot
.43495 .49329 Mdot
.49397 .32948 Mdot
.62335 .42188 Mdot
.67293 .6249 Mdot
.64337 .61604 Mdot
.53796 .79671 Mdot
.20593 .48434 Mdot
.61317 .39993 Mdot
.56702 .21246 Mdot
.62273 .59962 Mdot
.42629 .49212 Mdot
.42879 .56427 Mdot
.36954 .43993 Mdot
.71694 .6066 Mdot
.61648 .3706 Mdot
.56822 .71398 Mdot
.40938 .49898 Mdot
.34882 .46914 Mdot
.45435 .7312 Mdot
.61543 .38577 Mdot
.46639 .67873 Mdot
.43071 .6543 Mdot
.60845 .3791 Mdot
.45812 .68926 Mdot
.46514 .34337 Mdot
.57938 .6834 Mdot
.62779 .6061 Mdot
.63484 .5781 Mdot
.6282 .39617 Mdot
.64833 .38791 Mdot
.64156 .38725 Mdot
.40968 .43418 Mdot
.45785 .66576 Mdot
.41784 .44791 Mdot
.43235 .45121 Mdot
.44203 .74637 Mdot
.43414 .70085 Mdot
.42798 .45455 Mdot
.64612 .45549 Mdot
.48342 .35994 Mdot
.64846 .40495 Mdot
.67079 .58371 Mdot
.71599 .69236 Mdot
.62958 .62206 Mdot
.37396 .47261 Mdot
.78663 .41619 Mdot
.43936 .69292 Mdot
.46639 .30812 Mdot
.45596 .34611 Mdot
.47506 .30173 Mdot
.60447 .5518 Mdot
.45518 .63422 Mdot
.71648 .28153 Mdot
.37681 .47461 Mdot
.59298 .52182 Mdot
.2524 .39199 Mdot
.74044 .357 Mdot
.67192 .58466 Mdot
.38375 .51176 Mdot
.54183 .45952 Mdot
.37882 .648 Mdot
.366 .44662 Mdot
.36991 .53161 Mdot
.70686 .51502 Mdot
.3884 .55747 Mdot
.42311 .65029 Mdot
.79641 .37875 Mdot
.42449 .43142 Mdot
.47749 .74659 Mdot
.14622 .53695 Mdot
.37275 .46464 Mdot
.35368 .47712 Mdot
.38419 .49845 Mdot
.41707 .48359 Mdot
.42327 .66584 Mdot
.30589 .33803 Mdot
.68134 .58891 Mdot
.58966 .50501 Mdot
.62978 .60868 Mdot
.6218 .36186 Mdot
.54265 .67875 Mdot
.47995 .69953 Mdot
.46384 .31024 Mdot
.44825 .77538 Mdot
.76267 .32901 Mdot
.64771 .43204 Mdot
.33305 .60661 Mdot
.48513 .31831 Mdot
.42129 .50193 Mdot
.44956 .30591 Mdot
.59293 .39548 Mdot
.63326 .56882 Mdot
.34743 .42443 Mdot
.43241 .67084 Mdot
.46379 .70683 Mdot
.36982 .50675 Mdot
.2803 .73944 Mdot
.65984 .57579 Mdot
.69115 .59384 Mdot
.42609 .48172 Mdot
.37616 .535 Mdot
.46909 .68047 Mdot
.63653 .40823 Mdot
.49137 .23316 Mdot
.48436 .33225 Mdot
.33659 .4578 Mdot
.41828 .47965 Mdot
.79396 .38383 Mdot
.64721 .56086 Mdot
.63082 .43694 Mdot
.41881 .49497 Mdot
.72591 .62273 Mdot
.41904 .49386 Mdot
.34672 .54682 Mdot
.64423 .40024 Mdot
.42426 .53288 Mdot
.38117 .51793 Mdot
.4159 .39124 Mdot
.62041 .5915 Mdot
.47724 .68937 Mdot
.43111 .71174 Mdot
.5384 .41535 Mdot
.65832 .58162 Mdot
.42801 .45945 Mdot
.65149 .56364 Mdot
.43666 .46785 Mdot
.36551 .50755 Mdot
.66979 .59054 Mdot
.46599 .67938 Mdot
.56387 .76618 Mdot
.53648 .69033 Mdot
.41615 .48718 Mdot
.41263 .42403 Mdot
.32493 .31287 Mdot
.37234 .21145 Mdot
.35732 .46505 Mdot
.45615 .70562 Mdot
.39187 .50752 Mdot
.62498 .58892 Mdot
.48101 .34286 Mdot
.4553 .70356 Mdot
.62937 .41034 Mdot
.63302 .43357 Mdot
.69201 .67968 Mdot
.59741 .39557 Mdot
.39264 .52469 Mdot
.45186 .59882 Mdot
.47456 .71438 Mdot
.15602 .5717 Mdot
.60944 .38144 Mdot
.45956 .3445 Mdot
.40859 .48208 Mdot
.80497 .47376 Mdot
.61603 .54801 Mdot
.8802 .59425 Mdot
.70975 .26836 Mdot
.50093 .33256 Mdot
.49526 .17614 Mdot
.6382 .36587 Mdot
.36106 .51009 Mdot
.46125 .30457 Mdot
.65403 .42778 Mdot
.39282 .52139 Mdot
.36175 .41298 Mdot
.25729 .32289 Mdot
.53871 .42913 Mdot
.65512 .56417 Mdot
.65291 .38466 Mdot
.44459 .31162 Mdot
.6055 .4291 Mdot
.464 .7084 Mdot
.37929 .48756 Mdot
.44915 .41757 Mdot
.63404 .41052 Mdot
.6006 .42283 Mdot
.41542 .43943 Mdot
.48682 .68489 Mdot
.57248 .37824 Mdot
.40116 .47712 Mdot
.28191 .493 Mdot
.42834 .62953 Mdot
.61344 .40699 Mdot
.34586 .47081 Mdot
.39889 .36066 Mdot
.62691 .40266 Mdot
.64901 .40689 Mdot
.36889 .50739 Mdot
.46287 .34185 Mdot
.37392 .42493 Mdot
.64417 .60366 Mdot
.24791 .31374 Mdot
.62508 .58488 Mdot
.58556 .26403 Mdot
.32513 .49398 Mdot
.68528 .45699 Mdot
.46044 .71151 Mdot
.44211 .3267 Mdot
.73109 .6884 Mdot
.39679 .53486 Mdot
.42668 .81156 Mdot
.54277 .47388 Mdot
.23603 .70166 Mdot
.70384 .74428 Mdot
.47688 .32247 Mdot
.65341 .58923 Mdot
.3542 .47723 Mdot
.63557 .54707 Mdot
.47162 .29607 Mdot
.22113 .4318 Mdot
.345 .47567 Mdot
.46532 .66309 Mdot
.40106 .43288 Mdot
.47677 .66207 Mdot
.37626 .50853 Mdot
.35962 .54515 Mdot
.7417 .56092 Mdot
.43194 .25282 Mdot
.38072 .525 Mdot
.79749 .63042 Mdot
.65249 .3092 Mdot
.48086 .32876 Mdot
.41025 .44359 Mdot
.66462 .43036 Mdot
.61254 .57341 Mdot
.47745 .5822 Mdot
.64231 .39287 Mdot
.65918 .55905 Mdot
.46729 .68748 Mdot
.60397 .37791 Mdot
.61455 .42861 Mdot
.44819 .46695 Mdot
.45273 .3093 Mdot
.63042 .56539 Mdot
.37401 .48888 Mdot
.34703 .48454 Mdot
.5736 .22079 Mdot
.61595 .29452 Mdot
.4409 .72514 Mdot
.8436 .43019 Mdot
.44758 .72133 Mdot
.4911 .32443 Mdot
.64519 .39687 Mdot
.3602 .46371 Mdot
.38755 .44456 Mdot
.73438 .57752 Mdot
.47889 .63962 Mdot
.53805 .43859 Mdot
.28649 .57386 Mdot
.57445 .38408 Mdot
.35276 .3298 Mdot
.47838 .69333 Mdot
.35225 .32826 Mdot
.44524 .31041 Mdot
.4191 .78779 Mdot
.41818 .27321 Mdot
.66833 .57822 Mdot
.34757 .3327 Mdot
.44223 .67016 Mdot
.40274 .50925 Mdot
.6738 .41317 Mdot
.59928 .40162 Mdot
.47602 .67843 Mdot
.58997 .36109 Mdot
.46271 .31958 Mdot
.35248 .48282 Mdot
.69643 .27578 Mdot
.6349 .69222 Mdot
.64119 .41488 Mdot
.33036 .53182 Mdot
.62677 .57483 Mdot
.3587 .50504 Mdot
.48818 .29719 Mdot
.6453 .56963 Mdot
.64532 .27948 Mdot
.56874 .69944 Mdot
.40607 .47425 Mdot
.81414 .46406 Mdot
.65541 .57642 Mdot
.46182 .18567 Mdot
.39628 .48055 Mdot
.62234 .59886 Mdot
.41527 .55128 Mdot
.73453 .37543 Mdot
.52586 .44169 Mdot
.42151 .83166 Mdot
.54221 .45007 Mdot
.66802 .39283 Mdot
.74801 .4231 Mdot
.75473 .49821 Mdot
.6291 .54826 Mdot
.60244 .42504 Mdot
.42261 .34158 Mdot
.62122 .58143 Mdot
.43039 .44672 Mdot
.36676 .4606 Mdot
.26852 .53808 Mdot
.54465 .48703 Mdot
.62905 .44295 Mdot
.67102 .65857 Mdot
.33994 .46317 Mdot
.44545 .46662 Mdot
.39072 .45109 Mdot
.47686 .62316 Mdot
.63958 .56287 Mdot
.82555 .55483 Mdot
.65948 .58483 Mdot
.64456 .23197 Mdot
.62415 .39255 Mdot
.62985 .37249 Mdot
.3718 .47838 Mdot
.68742 .44054 Mdot
.3164 .3692 Mdot
.38718 .43584 Mdot
.6583 .46994 Mdot
.19204 .52694 Mdot
.43985 .48295 Mdot
.41924 .65955 Mdot
.31129 .46391 Mdot
.47686 .61919 Mdot
.62274 .60375 Mdot
.47565 .31486 Mdot
.44105 .3402 Mdot
.63287 .56573 Mdot
.38536 .46947 Mdot
.67046 .47567 Mdot
.37407 .45031 Mdot
.40863 .50676 Mdot
.63994 .22166 Mdot
.50096 .33041 Mdot
.63079 .37825 Mdot
.48333 .29996 Mdot
.48362 .66466 Mdot
.72117 .8157 Mdot
.47208 .33919 Mdot
.31152 .37661 Mdot
.22307 .38756 Mdot
.34433 .33234 Mdot
.46928 .70528 Mdot
.48288 .28467 Mdot
.66108 .57203 Mdot
.2987 .77871 Mdot
.34798 .21966 Mdot
.67428 .61898 Mdot
.39819 .47095 Mdot
.48723 .69001 Mdot
.43676 .69751 Mdot
.62433 .61264 Mdot
.44345 .66235 Mdot
.45289 .49419 Mdot
.41244 .49803 Mdot
.6373 .54851 Mdot
.62542 .71208 Mdot
.6431 .61624 Mdot
.57348 .66402 Mdot
.40873 .44012 Mdot
.47181 .69996 Mdot
.31272 .46446 Mdot
.50168 .65028 Mdot
.63223 .43773 Mdot
.42869 .4922 Mdot
.46222 .31719 Mdot
.61793 .5091 Mdot
.61606 .40131 Mdot
.78546 .41855 Mdot
.46111 .65194 Mdot
.58451 .61152 Mdot
.44994 .65712 Mdot
.49444 .65745 Mdot
.63438 .55556 Mdot
.46415 .63786 Mdot
.35298 .47827 Mdot
.66366 .44707 Mdot
.46973 .64803 Mdot
.6379 .58977 Mdot
.47663 .30886 Mdot
.45983 .68618 Mdot
.56138 .37924 Mdot
.40526 .49207 Mdot
.65639 .41846 Mdot
.74906 .55367 Mdot
.4921 .6742 Mdot
.49203 .28942 Mdot
.60914 .36902 Mdot
.45562 .30591 Mdot
.1803 .54303 Mdot
.67085 .56461 Mdot
.52325 .18962 Mdot
.40443 .36267 Mdot
.43065 .67893 Mdot
.74586 .55648 Mdot
.36229 .46579 Mdot
.40701 .49004 Mdot
.46147 .28912 Mdot
.43637 .69707 Mdot
.33788 .78025 Mdot
.41521 .729 Mdot
.57882 .69536 Mdot
.67088 .56185 Mdot
.8182 .53632 Mdot
.55657 .65031 Mdot
.18254 .44246 Mdot
.43544 .50825 Mdot
.64833 .3712 Mdot
.38072 .46373 Mdot
.72041 .69767 Mdot
.49616 .32716 Mdot
.51533 .27164 Mdot
.33348 .5043 Mdot
.61572 .37382 Mdot
.39239 .49433 Mdot
.49597 .55717 Mdot
.3155 .50249 Mdot
.46882 .34683 Mdot
.68503 .53154 Mdot
.42785 .6657 Mdot
.48493 .31211 Mdot
.61016 .42048 Mdot
.33222 .35549 Mdot
.37939 .52257 Mdot
.40961 .53025 Mdot
.57362 .38711 Mdot
.462 .66045 Mdot
.66438 .3915 Mdot
.62692 .60533 Mdot
.46827 .31935 Mdot
.41211 .48186 Mdot
.34436 .51147 Mdot
.71547 .46441 Mdot
.62991 .56335 Mdot
.58102 .37499 Mdot
.65823 .5941 Mdot
.6704 .39264 Mdot
.39669 .42066 Mdot
.62819 .3715 Mdot
.36021 .51394 Mdot
.75372 .6421 Mdot
.63281 .21938 Mdot
.28886 .66698 Mdot
.60969 .37174 Mdot
.38174 .32621 Mdot
.63032 .59263 Mdot
.64127 .60229 Mdot
.24077 .46783 Mdot
.46112 .52561 Mdot
.61853 .2509 Mdot
.55337 .79968 Mdot
.63041 .60831 Mdot
.62801 .58163 Mdot
.65525 .42264 Mdot
.46876 .63982 Mdot
.49533 .67437 Mdot
.61829 .36069 Mdot
.35702 .25574 Mdot
.45261 .6695 Mdot
.41039 .80135 Mdot
.62105 .26039 Mdot
.44762 .45253 Mdot
.64609 .63799 Mdot
.46907 .31385 Mdot
.37042 .25555 Mdot
.49953 .56827 Mdot
.35067 .46945 Mdot
.80031 .39526 Mdot
.63578 .40368 Mdot
.28939 .33485 Mdot
.49797 .82608 Mdot
.34441 .47869 Mdot
.39024 .48119 Mdot
.38732 .46119 Mdot
.50435 .31815 Mdot
.39552 .59255 Mdot
.34805 .48157 Mdot
.35659 .25342 Mdot
.3383 .46407 Mdot
.445 .37549 Mdot
.48629 .30207 Mdot
.3283 .40278 Mdot
.71001 .53096 Mdot
.72423 .31931 Mdot
.34371 .41323 Mdot
.62987 .60544 Mdot
.59026 .4811 Mdot
.61751 .58959 Mdot
.30347 .70585 Mdot
.41333 .27557 Mdot
.41633 .68426 Mdot
.35195 .47155 Mdot
.6045 .39708 Mdot
.43907 .69954 Mdot
.74308 .45738 Mdot
.55864 .92061 Mdot
.61712 .59713 Mdot
.20634 .30471 Mdot
.64977 .60036 Mdot
.6087 .42519 Mdot
.47025 .68101 Mdot
.36133 .67418 Mdot
.58868 .52556 Mdot
.45715 .68738 Mdot
.55772 .75548 Mdot
.48787 .71014 Mdot
.36534 .33202 Mdot
.46445 .71748 Mdot
.63559 .59153 Mdot
.59808 .58889 Mdot
.43493 .4131 Mdot
.36489 .47516 Mdot
.53124 .56217 Mdot
.34395 .36473 Mdot
.36306 .47054 Mdot
.61083 .40159 Mdot
.45021 .18105 Mdot
.54221 .40522 Mdot
.44456 .64747 Mdot
.6606 .61451 Mdot
.39049 .48432 Mdot
.41954 .48717 Mdot
.38787 .52074 Mdot
.85024 .43391 Mdot
.39467 .78923 Mdot
.37816 .51504 Mdot
.34304 .44675 Mdot
.60643 .3761 Mdot
.48304 .27181 Mdot
.69951 .7227 Mdot
.44703 .3846 Mdot
.35666 .44656 Mdot
.48897 .31032 Mdot
.4858 .35041 Mdot
.39258 .52192 Mdot
.71527 .32876 Mdot
.69915 .41926 Mdot
.37414 .48937 Mdot
.47734 .45708 Mdot
.76739 .48932 Mdot
.60135 .42287 Mdot
.63145 .4086 Mdot
.42489 .66482 Mdot
.60192 .40092 Mdot
.59071 .39441 Mdot
.36295 .65064 Mdot
.56702 .47523 Mdot
.63826 .52781 Mdot
.49909 .32272 Mdot
.3836 .44452 Mdot
.45911 .72399 Mdot
.72731 .59331 Mdot
.62245 .56949 Mdot
.44631 .69456 Mdot
.61141 .57754 Mdot
.50735 .3237 Mdot
.2713 .32317 Mdot
.59906 .40446 Mdot
.63981 .61116 Mdot
.56866 .69786 Mdot
.4886 .30785 Mdot
.65402 .55849 Mdot
.68855 .46098 Mdot
.43455 .45204 Mdot
.38725 .73677 Mdot
.39384 .43574 Mdot
.28361 .75042 Mdot
.65488 .55976 Mdot
.72951 .56198 Mdot
.38207 .47681 Mdot
.62333 .40048 Mdot
.37656 .55163 Mdot
.36211 .4455 Mdot
.62815 .41427 Mdot
.39965 .51274 Mdot
.47518 .292 Mdot
.44687 .60991 Mdot
.58277 .48352 Mdot
.64117 .17804 Mdot
.45413 .30419 Mdot
.736 .45605 Mdot
.3561 .46596 Mdot
.19709 .50366 Mdot
.4586 .68518 Mdot
.35395 .51415 Mdot
.28606 .41498 Mdot
.47721 .64899 Mdot
.45613 .69853 Mdot
.42148 .46303 Mdot
.66701 .58056 Mdot
.61835 .40464 Mdot
.48568 .30349 Mdot
.16796 .52572 Mdot
.399 .45986 Mdot
.39595 .50425 Mdot
.48519 .31611 Mdot
.62612 .58276 Mdot
.42199 .48172 Mdot
.76845 .57202 Mdot
.1994 .66749 Mdot
.62244 .56322 Mdot
.40518 .42789 Mdot
.40696 .737 Mdot
.48835 .62168 Mdot
.27236 .25216 Mdot
.47327 .24842 Mdot
.63172 .37603 Mdot
.40017 .55893 Mdot
.8072 .70751 Mdot
.47499 .31306 Mdot
.72111 .29893 Mdot
.40983 .50731 Mdot
.38442 .50486 Mdot
.43638 .68579 Mdot
.42291 .44981 Mdot
.48462 .65303 Mdot
.59516 .16331 Mdot
.81377 .40806 Mdot
.46759 .65701 Mdot
.43098 .66998 Mdot
.30085 .39273 Mdot
.70387 .71772 Mdot
.47572 .68201 Mdot
.36758 .42109 Mdot
.34202 .76119 Mdot
.40067 .3882 Mdot
.45942 .29016 Mdot
.75529 .5356 Mdot
.50926 .6861 Mdot
.5376 .36868 Mdot
.54917 .78573 Mdot
.50771 .69952 Mdot
.6981 .39205 Mdot
.64802 .60421 Mdot
.34337 .46341 Mdot
.59779 .3984 Mdot
.62113 .36815 Mdot
.32071 .50778 Mdot
.37569 .44541 Mdot
.47535 .65566 Mdot
.49634 .33456 Mdot
.61832 .55827 Mdot
.39295 .5103 Mdot
.5451 .40712 Mdot
.47668 .33665 Mdot
.45168 .64616 Mdot
.24823 .44756 Mdot
.46324 .34669 Mdot
.30586 .4832 Mdot
.36518 .492 Mdot
.41961 .44138 Mdot
.44176 .39642 Mdot
.67147 .59508 Mdot
.75643 .5719 Mdot
.3891 .42419 Mdot
.74519 .33643 Mdot
.50025 .44384 Mdot
.41879 .5398 Mdot
.44968 .66455 Mdot
.61685 .5464 Mdot
.65341 .43625 Mdot
.27319 .38514 Mdot
.4036 .46775 Mdot
.38836 .78319 Mdot
.28341 .55883 Mdot
.65164 .43472 Mdot
.47966 .63676 Mdot
.4683 .30616 Mdot
.38447 .43726 Mdot
.32402 .73517 Mdot
.36958 .46385 Mdot
.4225 .36869 Mdot
.64502 .40557 Mdot
.6515 .60357 Mdot
.2267 .69384 Mdot
.62233 .36849 Mdot
.46005 .69958 Mdot
.43683 .84655 Mdot
.47805 .70643 Mdot
.43743 .64776 Mdot
.35614 .7506 Mdot
.66481 .60123 Mdot
.82383 .68735 Mdot
.32897 .22347 Mdot
.35875 .53208 Mdot
.62964 .59581 Mdot
.47445 .67096 Mdot
.35768 .50354 Mdot
.44966 .71367 Mdot
.46147 .6317 Mdot
.44027 .44802 Mdot
.37198 .50137 Mdot
.54241 .67092 Mdot
.45118 .81922 Mdot
.4711 .3023 Mdot
.48521 .68179 Mdot
.26851 .46827 Mdot
.35097 .49853 Mdot
.37676 .47543 Mdot
.76172 .46891 Mdot
.46291 .34307 Mdot
.53099 .6134 Mdot
.41588 .49907 Mdot
.8213 .43657 Mdot
.31158 .46095 Mdot
.42285 .66314 Mdot
.62468 .56187 Mdot
.71507 .31406 Mdot
.71233 .61044 Mdot
.48162 .64265 Mdot
.49664 .3053 Mdot
.43069 .71245 Mdot
.31475 .37576 Mdot
.65324 .61183 Mdot
.45062 .70343 Mdot
.54786 .46262 Mdot
.645 .57666 Mdot
.65794 .56233 Mdot
.30698 .72881 Mdot
.58468 .37587 Mdot
.49863 .29995 Mdot
.62869 .56969 Mdot
.28843 .51884 Mdot
.64442 .59235 Mdot
.25949 .49897 Mdot
.37535 .42954 Mdot
.31072 .29032 Mdot
.56265 .58989 Mdot
.46109 .45984 Mdot
.67631 .58429 Mdot
.47325 .29665 Mdot
.42216 .4709 Mdot
.44105 .66474 Mdot
.46744 .336 Mdot
.64669 .63259 Mdot
.65144 .39855 Mdot
.4501 .65442 Mdot
.68329 .58273 Mdot
.48259 .68602 Mdot
.26833 .37018 Mdot
.23699 .32786 Mdot
.78525 .54706 Mdot
.58449 .52551 Mdot
.39159 .51982 Mdot
.60905 .7768 Mdot
.43844 .43742 Mdot
.37054 .44634 Mdot
.6139 .40634 Mdot
.30203 .31625 Mdot
.46684 .67896 Mdot
.23169 .70265 Mdot
.64172 .60909 Mdot
.80276 .38601 Mdot
.40775 .68465 Mdot
.35423 .51583 Mdot
.4728 .64933 Mdot
.47156 .71241 Mdot
.264 .64314 Mdot
.60802 .43364 Mdot
.38583 .40971 Mdot
.41759 .41108 Mdot
.42485 .52281 Mdot
.65873 .56392 Mdot
.77922 .40702 Mdot
.65662 .3801 Mdot
.23918 .30623 Mdot
.64427 .40933 Mdot
.6349 .48463 Mdot
.45927 .63907 Mdot
.46812 .34034 Mdot
.37589 .47803 Mdot
.40856 .70075 Mdot
.48394 .64409 Mdot
.50061 .34712 Mdot
.45987 .32189 Mdot
.7509 .40244 Mdot
.67031 .59061 Mdot
.37487 .52565 Mdot
.34628 .47206 Mdot
.41577 .44904 Mdot
.39031 .43135 Mdot
.61746 .59839 Mdot
.43128 .47143 Mdot
.60253 .57846 Mdot
.28404 .51769 Mdot
.80795 .40863 Mdot
.56312 .47309 Mdot
.45579 .57311 Mdot
.44018 .65698 Mdot
.29304 .52007 Mdot
.30461 .48229 Mdot
.5996 .20264 Mdot
.2058 .61777 Mdot
.43694 .48557 Mdot
.65865 .42326 Mdot
.45373 .54193 Mdot
.5918 .38631 Mdot
.27553 .21748 Mdot
.71178 .47402 Mdot
.42455 .82425 Mdot
.35139 .49315 Mdot
.76433 .47154 Mdot
.3956 .57218 Mdot
.43075 .4247 Mdot
.73889 .47944 Mdot
.71155 .64098 Mdot
.58799 .7335 Mdot
.47873 .35163 Mdot
.40365 .48726 Mdot
.48113 .71177 Mdot
.35193 .47957 Mdot
.37768 .46956 Mdot
.41024 .50815 Mdot
.67974 .59433 Mdot
.35407 .4219 Mdot
.40835 .4324 Mdot
.62623 .32314 Mdot
.37836 .30418 Mdot
.65329 .38377 Mdot
.2363 .46247 Mdot
.47239 .33795 Mdot
.46826 .6506 Mdot
.51648 .7592 Mdot
.66869 .5783 Mdot
.2569 .62578 Mdot
.40469 .43275 Mdot
.55259 .68584 Mdot
.68366 .57953 Mdot
.46606 .32024 Mdot
.67629 .41088 Mdot
.38948 .82005 Mdot
.60509 .39329 Mdot
.54804 .46658 Mdot
.61833 .39776 Mdot
.31536 .43543 Mdot
.47644 .65671 Mdot
.40551 .51445 Mdot
.62956 .57186 Mdot
.61791 .4118 Mdot
.3391 .303 Mdot
.38972 .45245 Mdot
.61001 .37824 Mdot
.40765 .51242 Mdot
.28048 .30831 Mdot
.52954 .20964 Mdot
.59182 .40197 Mdot
.61004 .54657 Mdot
.64235 .58152 Mdot
.46623 .34296 Mdot
.45767 .64825 Mdot
.43727 .68326 Mdot
.64665 .5714 Mdot
.378 .20149 Mdot
.35739 .44734 Mdot
.35444 .50031 Mdot
.74731 .33609 Mdot
.35813 .47595 Mdot
.35247 .34721 Mdot
.5386 .45533 Mdot
.44571 .64976 Mdot
.36593 .5107 Mdot
.41923 .48409 Mdot
.40745 .47835 Mdot
.26135 .37206 Mdot
.63816 .41125 Mdot
.3501 .44755 Mdot
.45738 .31811 Mdot
.66985 .43166 Mdot
.35519 .50327 Mdot
.422 .52556 Mdot
.43818 .6853 Mdot
.80361 .3642 Mdot
.65899 .59749 Mdot
.61665 .42535 Mdot
.62305 .37108 Mdot
.7573 .53296 Mdot
.4582 .74799 Mdot
.53712 .4519 Mdot
.22546 .3273 Mdot
.72321 .54759 Mdot
.48553 .32316 Mdot
.63396 .4936 Mdot
.49449 .42342 Mdot
.6416 .43096 Mdot
.61137 .58751 Mdot
.38425 .42609 Mdot
.35918 .44261 Mdot
.69824 .25348 Mdot
.35557 .51842 Mdot
.46911 .30873 Mdot
.60605 .59323 Mdot
.44292 .67166 Mdot
.46513 .31817 Mdot
.646 .60035 Mdot
.45987 .66028 Mdot
.43596 .45044 Mdot
.42957 .43965 Mdot
.44816 .69425 Mdot
.43714 .69572 Mdot
.37031 .48908 Mdot
.68366 .42709 Mdot
.42649 .6625 Mdot
.46613 .70406 Mdot
.59781 .40323 Mdot
.60361 .40583 Mdot
.44946 .4785 Mdot
.63525 .59819 Mdot
.42829 .44702 Mdot
.60177 .38474 Mdot
.48892 .34109 Mdot
.46106 .67979 Mdot
.4163 .48928 Mdot
.40009 .50845 Mdot
.48684 .30668 Mdot
.48712 .34698 Mdot
.4626 .32252 Mdot
.61089 .60464 Mdot
.40719 .44768 Mdot
.47168 .68659 Mdot
.66519 .59792 Mdot
.4857 .35059 Mdot
.4482 .32032 Mdot
.59378 .3532 Mdot
.35885 .46215 Mdot
.56617 .36799 Mdot
.71678 .81474 Mdot
.40386 .33737 Mdot
.64778 .4374 Mdot
.57747 .38338 Mdot
.34509 .31946 Mdot
.68778 .43093 Mdot
.65628 .57246 Mdot
.41606 .34599 Mdot
.44187 .32913 Mdot
.4291 .48989 Mdot
.4105 .4243 Mdot
.43502 .41959 Mdot
.46904 .32872 Mdot
.28103 .37008 Mdot
.45806 .71317 Mdot
.24047 .54645 Mdot
.4712 .33727 Mdot
.59759 .4197 Mdot
.58575 .37082 Mdot
.64482 .40893 Mdot
.40839 .42582 Mdot
.28405 .65695 Mdot
.28871 .46338 Mdot
.60676 .78437 Mdot
.66893 .5699 Mdot
.41581 .68839 Mdot
.18549 .52669 Mdot
.45295 .69624 Mdot
.59981 .36663 Mdot
.47238 .33293 Mdot
.44984 .70486 Mdot
.61569 .57812 Mdot
.62883 .57941 Mdot
.64186 .41243 Mdot
.62845 .3946 Mdot
.65121 .42075 Mdot
.44659 .63866 Mdot
.463 .63818 Mdot
.4019 .46001 Mdot
.45104 .68099 Mdot
.75074 .29353 Mdot
.50593 .31293 Mdot
.5776 .37535 Mdot
.65371 .59057 Mdot
.47539 .66011 Mdot
.39041 .44858 Mdot
.54838 .42763 Mdot
.6793 .68111 Mdot
.45865 .30024 Mdot
.55585 .21531 Mdot
.26669 .22907 Mdot
.36652 .52448 Mdot
.65292 .56239 Mdot
.68866 .27256 Mdot
.38928 .46059 Mdot
.64052 .39527 Mdot
.75177 .65522 Mdot
.67172 .42151 Mdot
.43082 .44892 Mdot
.36435 .52805 Mdot
.64034 .55271 Mdot
.2157 .39589 Mdot
.39977 .4538 Mdot
.57124 .63634 Mdot
.65318 .61816 Mdot
.63857 .3688 Mdot
.20644 .68192 Mdot
.77666 .51899 Mdot
.36367 .25741 Mdot
.60154 .40792 Mdot
.36805 .45492 Mdot
.6104 .41407 Mdot
.46038 .30014 Mdot
.62102 .42318 Mdot
.4216 .64794 Mdot
.65485 .38313 Mdot
.39485 .50408 Mdot
.47701 .68193 Mdot
.65618 .57691 Mdot
.78933 .36594 Mdot
.61855 .31447 Mdot
.62399 .40006 Mdot
.60203 .41623 Mdot
.37496 .51681 Mdot
.53986 .63028 Mdot
.35254 .53493 Mdot
.35082 .49509 Mdot
.63116 .61051 Mdot
.46872 .64639 Mdot
.67937 .58206 Mdot
.33676 .48572 Mdot
.77418 .59475 Mdot
.66243 .59059 Mdot
.54818 .69093 Mdot
.48541 .31909 Mdot
.50447 .5251 Mdot
.38582 .44288 Mdot
.62409 .57267 Mdot
.40709 .44663 Mdot
.44382 .71215 Mdot
.53257 .50668 Mdot
.7345 .59836 Mdot
.63151 .57235 Mdot
.32062 .77003 Mdot
.64262 .35951 Mdot
.32238 .44753 Mdot
.62042 .59627 Mdot
.28658 .41685 Mdot
.61164 .42735 Mdot
.48503 .33019 Mdot
.4844 .35083 Mdot
.45383 .31134 Mdot
.40813 .52544 Mdot
.32454 .43513 Mdot
.49094 .29537 Mdot
.61836 .56525 Mdot
.47236 .34757 Mdot
.45521 .75866 Mdot
.3303 .7782 Mdot
.49672 .32331 Mdot
.39836 .47872 Mdot
.42197 .39944 Mdot
.37383 .30242 Mdot
.56543 .38592 Mdot
.4318 .81574 Mdot
.45288 .5835 Mdot
.36617 .47299 Mdot
.49292 .62041 Mdot
.4536 .71119 Mdot
.68388 .27556 Mdot
.35922 .36092 Mdot
.69505 .31744 Mdot
.43071 .66514 Mdot
.73292 .57982 Mdot
.45122 .648 Mdot
.36582 .52139 Mdot
.362 .50406 Mdot
.49641 .6726 Mdot
.79079 .41178 Mdot
.71566 .43982 Mdot
.18711 .62452 Mdot
.46989 .70342 Mdot
.62012 .59025 Mdot
.62239 .60639 Mdot
.67022 .57333 Mdot
.60688 .25555 Mdot
.49049 .67284 Mdot
.40878 .45568 Mdot
.60436 .37552 Mdot
.35079 .45197 Mdot
.63958 .57088 Mdot
.23701 .70802 Mdot
.43858 .67877 Mdot
.37651 .49063 Mdot
.36893 .21587 Mdot
.63171 .38876 Mdot
.49095 .31428 Mdot
.26307 .32667 Mdot
.65311 .28101 Mdot
.66201 .60583 Mdot
.49027 .69119 Mdot
.69463 .53287 Mdot
.54055 .70378 Mdot
.44261 .49562 Mdot
.44543 .5063 Mdot
.17412 .47848 Mdot
.63766 .27697 Mdot
.40816 .51543 Mdot
.61941 .42832 Mdot
.73507 .57706 Mdot
.41195 .49245 Mdot
.47128 .7055 Mdot
.46774 .35393 Mdot
.45639 .32509 Mdot
.39242 .4134 Mdot
.59559 .51912 Mdot
.50602 .48489 Mdot
.42893 .46035 Mdot
.30547 .48195 Mdot
.59943 .36863 Mdot
.71562 .5408 Mdot
.76969 .35297 Mdot
.49924 .31047 Mdot
.41834 .49802 Mdot
.59652 .75039 Mdot
.46685 .63418 Mdot
.66528 .40355 Mdot
.6566 .61114 Mdot
.25182 .38737 Mdot
.64853 .37419 Mdot
.41223 .49361 Mdot
.42139 .4824 Mdot
.65288 .55755 Mdot
.42279 .66306 Mdot
.47072 .32963 Mdot
.61031 .37088 Mdot
.49871 .30785 Mdot
.48217 .65294 Mdot
.44041 .67682 Mdot
.39244 .38779 Mdot
.3391 .42806 Mdot
.62969 .40887 Mdot
.33852 .48512 Mdot
.56619 .39687 Mdot
.21306 .39446 Mdot
.66876 .55713 Mdot
.36493 .52449 Mdot
.45765 .62181 Mdot
.63277 .56808 Mdot
.37989 .5017 Mdot
.16132 .5013 Mdot
.34434 .49079 Mdot
.7139 .60699 Mdot
.79005 .57168 Mdot
.464 .30488 Mdot
.21506 .53619 Mdot
.52288 .68087 Mdot
.35794 .48087 Mdot
.65187 .39194 Mdot
.36791 .5476 Mdot
.66459 .57729 Mdot
.4491 .64395 Mdot
.28094 .24007 Mdot
.6429 .59043 Mdot
.35217 .48826 Mdot
.46744 .31964 Mdot
.48086 .70504 Mdot
.59962 .4845 Mdot
.73656 .3379 Mdot
.31805 .48722 Mdot
.36184 .42288 Mdot
.43116 .45271 Mdot
.73845 .6998 Mdot
.61973 .42632 Mdot
.47566 .66592 Mdot
.65899 .56466 Mdot
.64764 .56947 Mdot
.64021 .40899 Mdot
.59002 .72236 Mdot
.50625 .52228 Mdot
.76229 .75655 Mdot
.62616 .41596 Mdot
.49098 .28779 Mdot
.54991 .62808 Mdot
.65413 .39309 Mdot
.61285 .37953 Mdot
.59924 .36922 Mdot
.67923 .54133 Mdot
.45835 .66311 Mdot
.39997 .50958 Mdot
.42967 .70007 Mdot
.36516 .45392 Mdot
.49856 .46498 Mdot
.63112 .56678 Mdot
.4453 .64482 Mdot
.16593 .49901 Mdot
.42424 .59553 Mdot
.39175 .46958 Mdot
.1863 .50948 Mdot
.33347 .50804 Mdot
.32358 .34498 Mdot
.32446 .46098 Mdot
.62298 .39565 Mdot
.40502 .56446 Mdot
.38347 .54064 Mdot
.77271 .33515 Mdot
.65295 .59242 Mdot
.61448 .43 Mdot
.40334 .52298 Mdot
.30959 .46524 Mdot
.49785 .68063 Mdot
.45408 .70604 Mdot
.49646 .30106 Mdot
.43298 .2499 Mdot
.65791 .57857 Mdot
.24854 .32027 Mdot
.36473 .47998 Mdot
.80666 .50071 Mdot
.22322 .55446 Mdot
.38019 .50048 Mdot
.35065 .76848 Mdot
.2724 .64413 Mdot
.38403 .43903 Mdot
.30531 .40574 Mdot
.62765 .5852 Mdot
.77527 .58858 Mdot
.34419 .44272 Mdot
.64044 .39266 Mdot
.46242 .64014 Mdot
.4707 .70852 Mdot
.48348 .29296 Mdot
.59118 .18519 Mdot
.67659 .57664 Mdot
.45012 .64226 Mdot
.38628 .45326 Mdot
.66406 .60308 Mdot
.59792 .39348 Mdot
.33777 .49605 Mdot
.36834 .35176 Mdot
.44918 .67832 Mdot
.33985 .45013 Mdot
.63414 .66815 Mdot
.39229 .25452 Mdot
.59808 .82775 Mdot
.6702 .57545 Mdot
.47935 .34199 Mdot
.38653 .54687 Mdot
.27452 .29179 Mdot
.43595 .49011 Mdot
.30481 .29751 Mdot
.46028 .75281 Mdot
.47771 .34298 Mdot
.38689 .477 Mdot
.41097 .47357 Mdot
.56094 .57792 Mdot
.49322 .33989 Mdot
.34486 .46961 Mdot
.42026 .57596 Mdot
.46292 .66151 Mdot
.67966 .41684 Mdot
.44943 .67332 Mdot
.39796 .47171 Mdot
.35867 .41319 Mdot
.43673 .69001 Mdot
.20479 .35371 Mdot
.44555 .35524 Mdot
.66239 .59529 Mdot
.33202 .43128 Mdot
.37406 .42772 Mdot
.79783 .65075 Mdot
.63118 .43738 Mdot
.67019 .73802 Mdot
.55492 .38516 Mdot
.57911 .76325 Mdot
.77826 .5135 Mdot
.42594 .84138 Mdot
.79775 .38964 Mdot
.41871 .41215 Mdot
.47525 .53296 Mdot
.2963 .42644 Mdot
.67714 .58961 Mdot
.35482 .59497 Mdot
.36485 .47442 Mdot
.37874 .46659 Mdot
.6659 .40997 Mdot
.56465 .71504 Mdot
.71334 .32367 Mdot
.59585 .50495 Mdot
.4738 .32793 Mdot
.48474 .67212 Mdot
.3777 .50986 Mdot
.5219 .40424 Mdot
.6576 .3886 Mdot
.80551 .48768 Mdot
.38041 .48682 Mdot
.59213 .20306 Mdot
.70265 .5599 Mdot
.6714 .59343 Mdot
.63867 .377 Mdot
.67391 .29784 Mdot
.35863 .45738 Mdot
.63989 .61552 Mdot
.39684 .4501 Mdot
.66668 .35042 Mdot
.34358 .49813 Mdot
.49241 .33012 Mdot
.40017 .51624 Mdot
.59894 .49639 Mdot
.52665 .84143 Mdot
.42635 .36294 Mdot
.4867 .68951 Mdot
.57349 .39288 Mdot
.63638 .41038 Mdot
.44505 .70117 Mdot
.63337 .40788 Mdot
.24852 .59153 Mdot
.34512 .66874 Mdot
.47788 .32686 Mdot
.3062 .47389 Mdot
.49711 .31283 Mdot
.63293 .43804 Mdot
.36427 .46522 Mdot
.21428 .33814 Mdot
.62333 .41059 Mdot
.80153 .58199 Mdot
.64925 .58999 Mdot
.62449 .43493 Mdot
.33848 .46109 Mdot
.67784 .51125 Mdot
.6334 .37208 Mdot
.73043 .5863 Mdot
.4068 .47594 Mdot
.43949 .6706 Mdot
.4135 .47693 Mdot
.32169 .46933 Mdot
.67204 .39387 Mdot
.39371 .42893 Mdot
.64581 .60035 Mdot
.43136 .64948 Mdot
.36759 .79917 Mdot
.71625 .60567 Mdot
.34915 .46968 Mdot
.38713 .45542 Mdot
.48132 .70842 Mdot
.35306 .44133 Mdot
.61827 .59908 Mdot
.90283 .48011 Mdot
.48585 .31875 Mdot
.59526 .41098 Mdot
.77518 .52912 Mdot
.4397 .47943 Mdot
.42683 .46904 Mdot
.16576 .53168 Mdot
.77865 .54418 Mdot
.62846 .6022 Mdot
.3525 .53838 Mdot
.60299 .37377 Mdot
.46805 .3177 Mdot
.62145 .55857 Mdot
.42017 .44209 Mdot
.37889 .4768 Mdot
.48044 .34093 Mdot
.31388 .74018 Mdot
.66415 .27606 Mdot
.66307 .56307 Mdot
.40866 .56446 Mdot
.5668 .41471 Mdot
.35937 .44652 Mdot
.6078 .25129 Mdot
.45602 .70435 Mdot
.64875 .61145 Mdot
.64722 .76219 Mdot
.42232 .49758 Mdot
.62237 .56659 Mdot
.6583 .58134 Mdot
.37393 .54104 Mdot
.49097 .63455 Mdot
.44396 .63564 Mdot
.48327 .68286 Mdot
.7671 .29982 Mdot
.376 .26558 Mdot
.65141 .42053 Mdot
.62692 .58379 Mdot
.58883 .38764 Mdot
.49981 .29186 Mdot
.5121 .42923 Mdot
.59282 .40534 Mdot
.44009 .70174 Mdot
.56918 .38394 Mdot
.41053 .47735 Mdot
.65577 .57478 Mdot
.64285 .42979 Mdot
.40275 .52457 Mdot
.53248 .64122 Mdot
.67681 .34015 Mdot
.45406 .33792 Mdot
.46511 .35622 Mdot
.36604 .50602 Mdot
.65521 .43569 Mdot
.37094 .48677 Mdot
.61517 .55325 Mdot
.55228 .63589 Mdot
.42704 .50206 Mdot
.62703 .40112 Mdot
.5086 .63233 Mdot
.65316 .28131 Mdot
.34226 .52589 Mdot
.39724 .47836 Mdot
.36279 .44906 Mdot
.39692 .4492 Mdot
.56404 .73888 Mdot
.66797 .55868 Mdot
.52246 .5974 Mdot
.74276 .55496 Mdot
.45042 .68799 Mdot
.46497 .62595 Mdot
.56451 .23936 Mdot
.70213 .3936 Mdot
.63269 .59702 Mdot
.37121 .44251 Mdot
.72595 .60026 Mdot
.24759 .72027 Mdot
.19331 .36676 Mdot
.51072 .3325 Mdot
.65765 .42926 Mdot
.49272 .67831 Mdot
.65284 .38612 Mdot
.36844 .45783 Mdot
.39109 .54705 Mdot
.4194 .84577 Mdot
.59476 .58925 Mdot
.47123 .33226 Mdot
.36405 .4502 Mdot
.37734 .25749 Mdot
.6061 .37585 Mdot
.58863 .3715 Mdot
.34317 .47291 Mdot
.43121 .63853 Mdot
.73079 .74312 Mdot
.6732 .59165 Mdot
.45772 .58151 Mdot
.3466 .55902 Mdot
.64771 .65365 Mdot
.63855 .56548 Mdot
.67762 .32037 Mdot
.66038 .42938 Mdot
.23138 .62082 Mdot
.44714 .68801 Mdot
.47167 .3353 Mdot
.43173 .52943 Mdot
.43314 .67546 Mdot
.6679 .39162 Mdot
.44028 .65444 Mdot
.39599 .51999 Mdot
.67734 .5727 Mdot
.63725 .37859 Mdot
.60535 .55108 Mdot
.48662 .63119 Mdot
.48508 .29725 Mdot
.5434 .58528 Mdot
.38181 .62955 Mdot
.26817 .63896 Mdot
.35344 .44573 Mdot
.51924 .39998 Mdot
.41018 .45164 Mdot
.4994 .67474 Mdot
.39265 .44896 Mdot
.48687 .61562 Mdot
.64847 .38747 Mdot
.34309 .44629 Mdot
.43223 .46053 Mdot
.30896 .56839 Mdot
.38798 .48779 Mdot
.33658 .4461 Mdot
.38035 .43842 Mdot
.41891 .70804 Mdot
.31645 .50772 Mdot
.45169 .66276 Mdot
.73268 .34304 Mdot
.61434 .38094 Mdot
.47064 .3553 Mdot
.45568 .33142 Mdot
.31943 .28398 Mdot
.43607 .30934 Mdot
.57725 .72234 Mdot
.45729 .67195 Mdot
.65785 .59216 Mdot
.39377 .44604 Mdot
.56371 .79852 Mdot
.76073 .50411 Mdot
.59937 .3749 Mdot
.71625 .60511 Mdot
.44199 .52643 Mdot
.7419 .69862 Mdot
.33629 .46399 Mdot
.69164 .2429 Mdot
.41701 .4041 Mdot
.34961 .50571 Mdot
.59587 .36599 Mdot
.43901 .35879 Mdot
.34359 .45366 Mdot
.49742 .68294 Mdot
.48303 .33581 Mdot
.41847 .61415 Mdot
.61342 .45954 Mdot
.6859 .32746 Mdot
.35287 .62301 Mdot
.40344 .44645 Mdot
.63755 .37987 Mdot
.45122 .65412 Mdot
.77886 .36222 Mdot
.66305 .59957 Mdot
.59885 .52874 Mdot
.27638 .49021 Mdot
.19281 .46471 Mdot
.47596 .33663 Mdot
.30821 .73207 Mdot
.39439 .50541 Mdot
.58897 .26459 Mdot
.44042 .45235 Mdot
.25146 .72307 Mdot
.48523 .28528 Mdot
.44169 .62977 Mdot
.62094 .5922 Mdot
.43874 .70794 Mdot
.28285 .66329 Mdot
.6195 .63826 Mdot
.54538 .53102 Mdot
.60455 .38822 Mdot
.52793 .5967 Mdot
.47852 .67505 Mdot
.42238 .48623 Mdot
.74727 .77705 Mdot
.46251 .7045 Mdot
.48462 .64966 Mdot
.2229 .37354 Mdot
.21192 .38373 Mdot
.4236 .54937 Mdot
.43047 .67612 Mdot
.60695 .38789 Mdot
.47658 .29883 Mdot
.41502 .4699 Mdot
.4042 .46099 Mdot
.43637 .68384 Mdot
.59165 .36803 Mdot
.44285 .57115 Mdot
.62627 .39386 Mdot
.46323 .6592 Mdot
.62373 .38264 Mdot
.74613 .57564 Mdot
.64044 .43286 Mdot
.37037 .42931 Mdot
.39287 .44799 Mdot
.57796 .42072 Mdot
.44056 .67664 Mdot
.42643 .45937 Mdot
.39448 .51563 Mdot
.47326 .68385 Mdot
.54613 .39951 Mdot
.41737 .74087 Mdot
.35411 .46861 Mdot
.40291 .4918 Mdot
.48166 .34235 Mdot
.50275 .4025 Mdot
.48759 .20194 Mdot
.42213 .47051 Mdot
.50315 .30515 Mdot
.44591 .63981 Mdot
.37186 .49116 Mdot
.47716 .76576 Mdot
.73674 .57962 Mdot
.42054 .49893 Mdot
.61557 .42929 Mdot
.41128 .52814 Mdot
.64673 .7994 Mdot
.34821 .49178 Mdot
.47287 .67514 Mdot
.47451 .6453 Mdot
.23659 .36892 Mdot
.4639 .69953 Mdot
.5997 .40208 Mdot
.64269 .57447 Mdot
.27826 .74561 Mdot
.59779 .39228 Mdot
.37985 .53559 Mdot
.32725 .22403 Mdot
.33041 .46887 Mdot
.41301 .51675 Mdot
.77076 .66565 Mdot
.59863 .39027 Mdot
.47707 .65378 Mdot
.58371 .54743 Mdot
.40236 .40708 Mdot
.65953 .60758 Mdot
.38888 .54398 Mdot
.39405 .42595 Mdot
.79061 .56313 Mdot
.7134 .67571 Mdot
.60551 .58827 Mdot
.44956 .45369 Mdot
.42265 .46973 Mdot
.57652 .34807 Mdot
.38806 .44872 Mdot
.49806 .31066 Mdot
.48748 .66316 Mdot
.66076 .40788 Mdot
.48357 .30699 Mdot
.36141 .47862 Mdot
.46776 .32783 Mdot
.65625 .41822 Mdot
.6422 .61414 Mdot
.36334 .45988 Mdot
.46051 .28873 Mdot
.47248 .32748 Mdot
.41422 .45205 Mdot
.45296 .64217 Mdot
.46188 .44319 Mdot
.37339 .49455 Mdot
.41458 .49703 Mdot
.43725 .68248 Mdot
.17623 .37122 Mdot
.34672 .49245 Mdot
.64667 .36333 Mdot
.48484 .6468 Mdot
.68529 .63089 Mdot
.66207 .4142 Mdot
.39127 .42567 Mdot
.63336 .61254 Mdot
.6269 .56812 Mdot
.59027 .37987 Mdot
.46713 .7166 Mdot
.56148 .39777 Mdot
.50379 .62675 Mdot
.35033 .42045 Mdot
.33481 .49742 Mdot
.3736 .19747 Mdot
.41 .83107 Mdot
.47462 .70419 Mdot
.60225 .35975 Mdot
.5919 .50588 Mdot
.62398 .58418 Mdot
.57958 .38484 Mdot
.48536 .7009 Mdot
.49082 .6835 Mdot
.44245 .65498 Mdot
.46129 .33213 Mdot
.55181 .38742 Mdot
.42239 .65922 Mdot
.43178 .63855 Mdot
.40838 .47729 Mdot
.42403 .46742 Mdot
.34835 .38054 Mdot
.39561 .31883 Mdot
.48497 .29578 Mdot
.64196 .40603 Mdot
.87503 .46276 Mdot
.6117 .55788 Mdot
.30996 .57168 Mdot
.42813 .50019 Mdot
.62306 .88965 Mdot
.33768 .47323 Mdot
.38554 .45003 Mdot
.43001 .65393 Mdot
.45216 .29744 Mdot
.49506 .31606 Mdot
.48002 .67084 Mdot
.49562 .6547 Mdot
.49898 .31444 Mdot
.23452 .67297 Mdot
.32929 .78055 Mdot
.5677 .59662 Mdot
.46717 .68378 Mdot
.37826 .64846 Mdot
.65858 .61061 Mdot
.47756 .61958 Mdot
.62144 .55143 Mdot
.61036 .37584 Mdot
.66455 .42593 Mdot
.65985 .56427 Mdot
.40531 .47305 Mdot
.64036 .42638 Mdot
.35259 .42316 Mdot
.27768 .7223 Mdot
.36156 .73511 Mdot
.7754 .45489 Mdot
.41375 .42273 Mdot
.71667 .33271 Mdot
.71454 .3971 Mdot
.35747 .48951 Mdot
.52847 .77814 Mdot
.46975 .33156 Mdot
.44674 .61983 Mdot
.62069 .60325 Mdot
.61478 .82418 Mdot
.36276 .44489 Mdot
.46913 .67577 Mdot
.64951 .59579 Mdot
.26218 .35469 Mdot
.56972 .63682 Mdot
.36317 .45251 Mdot
.78402 .73194 Mdot
.4136 .70621 Mdot
.66045 .40956 Mdot
.46274 .17155 Mdot
.42873 .70034 Mdot
.51324 .28911 Mdot
.72204 .54056 Mdot
.17728 .498 Mdot
.46863 .65112 Mdot
.58481 .3622 Mdot
.48368 .67242 Mdot
.49308 .30144 Mdot
.42685 .63046 Mdot
.61956 .37137 Mdot
.3866 .48343 Mdot
.63426 .40295 Mdot
.47946 .29373 Mdot
.59888 .25606 Mdot
.62375 .60646 Mdot
.61574 .43038 Mdot
.635 .58129 Mdot
.40301 .25369 Mdot
.77061 .60468 Mdot
.65331 .60278 Mdot
.25038 .34559 Mdot
.41512 .50922 Mdot
.42106 .67964 Mdot
.63299 .41833 Mdot
.71295 .53568 Mdot
.55616 .55868 Mdot
.45495 .69168 Mdot
.64766 .40294 Mdot
.28078 .48526 Mdot
.33461 .23672 Mdot
.31479 .44754 Mdot
.41439 .26292 Mdot
.46936 .68635 Mdot
.5789 .3769 Mdot
.74788 .3361 Mdot
.44344 .70573 Mdot
.62633 .41684 Mdot
.61862 .58168 Mdot
.64441 .56709 Mdot
.34443 .45876 Mdot
.6434 .5301 Mdot
.649 .41352 Mdot
.72619 .39022 Mdot
.46775 .63394 Mdot
.26843 .35171 Mdot
.45402 .30257 Mdot
.61579 .38702 Mdot
.35017 .51474 Mdot
.50155 .64062 Mdot
.74043 .57621 Mdot
.4604 .53907 Mdot
.86844 .47455 Mdot
.63981 .40815 Mdot
.48627 .65659 Mdot
.46465 .67708 Mdot
.34714 .52909 Mdot
.58569 .52682 Mdot
.56255 .40238 Mdot
.33792 .2468 Mdot
.29493 .30866 Mdot
.67278 .39755 Mdot
.66442 .45853 Mdot
.37032 .53283 Mdot
.40361 .44115 Mdot
.62284 .58629 Mdot
.39197 .48347 Mdot
.43471 .64045 Mdot
.34696 .44892 Mdot
.63814 .56246 Mdot
.60874 .39941 Mdot
.36676 .46393 Mdot
.47069 .29823 Mdot
.61759 .60748 Mdot
.64345 .5528 Mdot
.61795 .39376 Mdot
.43217 .66981 Mdot
.46831 .36184 Mdot
.62916 .39484 Mdot
.40278 .44713 Mdot
.63218 .49756 Mdot
.38822 .52067 Mdot
.2288 .64877 Mdot
.43796 .70108 Mdot
.65235 .38811 Mdot
.48277 .6399 Mdot
.63451 .58602 Mdot
.74167 .55474 Mdot
.39534 .46329 Mdot
.62292 .41554 Mdot
.58916 .43038 Mdot
.2615 .69797 Mdot
.48389 .70811 Mdot
.67782 .47269 Mdot
.46339 .62879 Mdot
.67413 .40609 Mdot
.23269 .43713 Mdot
.4816 .33152 Mdot
.60295 .37186 Mdot
.40197 .8122 Mdot
.62608 .40607 Mdot
.38792 .49207 Mdot
.37715 .50518 Mdot
.6601 .4187 Mdot
.46234 .34147 Mdot
.80997 .4011 Mdot
.68557 .35472 Mdot
.47344 .65153 Mdot
.21514 .50648 Mdot
.85941 .54338 Mdot
.649 .53933 Mdot
.62423 .5944 Mdot
.41008 .40781 Mdot
.34986 .50809 Mdot
.61689 .5579 Mdot
.66163 .61406 Mdot
.46778 .29066 Mdot
.59882 .36991 Mdot
.41681 .64424 Mdot
.63406 .61688 Mdot
.4133 .38766 Mdot
.4479 .27751 Mdot
.33441 .52251 Mdot
.34855 .55651 Mdot
.42462 .4316 Mdot
.29846 .29592 Mdot
.64754 .56098 Mdot
.37333 .51152 Mdot
.32246 .51008 Mdot
.63909 .61222 Mdot
.49521 .30474 Mdot
.71048 .66843 Mdot
.63201 .38351 Mdot
.1455 .58151 Mdot
.3642 .51463 Mdot
.38375 .49364 Mdot
.67023 .57173 Mdot
.55205 .35643 Mdot
.43552 .67079 Mdot
.43731 .70215 Mdot
.62398 .4279 Mdot
.53885 .57684 Mdot
.36638 .43552 Mdot
.35931 .49576 Mdot
.64236 .38756 Mdot
.62325 .43411 Mdot
.74726 .42531 Mdot
.40055 .50666 Mdot
.64629 .59584 Mdot
.58831 .48039 Mdot
.64326 .56071 Mdot
.37015 .52216 Mdot
.38831 .49545 Mdot
.36802 .4306 Mdot
.35667 .51908 Mdot
.64404 .55218 Mdot
.37703 .51193 Mdot
.39176 .39379 Mdot
.43877 .65243 Mdot
.38753 .43049 Mdot
.29039 .30638 Mdot
.40034 .48357 Mdot
.48332 .29833 Mdot
.46735 .41728 Mdot
.3608 .44976 Mdot
.3803 .42751 Mdot
.68402 .35575 Mdot
.38642 .47256 Mdot
.61583 .55292 Mdot
.45256 .68451 Mdot
.62687 .58292 Mdot
.65261 .55822 Mdot
.60498 .4132 Mdot
.48753 .29382 Mdot
.44074 .47257 Mdot
.45534 .30961 Mdot
.44382 .48324 Mdot
.41639 .50599 Mdot
.74321 .5346 Mdot
.68293 .23427 Mdot
.6585 .27127 Mdot
.39627 .46289 Mdot
.60921 .40631 Mdot
.66047 .40292 Mdot
.46872 .55883 Mdot
.3135 .45923 Mdot
.61672 .5598 Mdot
.62477 .57232 Mdot
.36867 .34498 Mdot
.78692 .56779 Mdot
.48744 .29939 Mdot
.51628 .41476 Mdot
.35325 .42194 Mdot
.404 .50898 Mdot
.33625 .49186 Mdot
.59158 .39825 Mdot
.62066 .49349 Mdot
.59987 .37517 Mdot
.71738 .60006 Mdot
.63538 .56138 Mdot
.36809 .43899 Mdot
.39576 .76484 Mdot
.45158 .70678 Mdot
.45182 .68416 Mdot
.62533 .55798 Mdot
.57547 .39134 Mdot
.41685 .37289 Mdot
.2208 .28961 Mdot
.41207 .69325 Mdot
.44767 .31541 Mdot
.35447 .48436 Mdot
.61342 .4001 Mdot
.47976 .69495 Mdot
.47273 .34838 Mdot
.41725 .50099 Mdot
.55968 .40151 Mdot
.39861 .46148 Mdot
.2976 .42456 Mdot
.45418 .64472 Mdot
.27679 .75021 Mdot
.47439 .7091 Mdot
.61711 .60529 Mdot
.63946 .60817 Mdot
.38223 .50175 Mdot
.40165 .18696 Mdot
.42297 .68874 Mdot
.69754 .56882 Mdot
.48119 .28538 Mdot
.6779 .51761 Mdot
.50013 .32185 Mdot
.65495 .39589 Mdot
.48049 .33632 Mdot
.63437 .37552 Mdot
.39833 .33351 Mdot
.43714 .7244 Mdot
.48605 .31309 Mdot
.63257 .34324 Mdot
.31477 .45588 Mdot
.47762 .35302 Mdot
.44067 .42612 Mdot
.21684 .57107 Mdot
.6428 .39013 Mdot
.45888 .3341 Mdot
.42211 .48561 Mdot
.52143 .82482 Mdot
.64125 .60229 Mdot
.61287 .56301 Mdot
.33984 .43197 Mdot
.59393 .37091 Mdot
.49602 .67846 Mdot
.533 .72876 Mdot
.63233 .635 Mdot
.36493 .50397 Mdot
.34437 .45212 Mdot
.46036 .62457 Mdot
.46481 .7342 Mdot
.38761 .49972 Mdot
.3052 .5475 Mdot
.38933 .51011 Mdot
.61697 .57823 Mdot
.45963 .71086 Mdot
.45968 .68049 Mdot
.65178 .40839 Mdot
.42751 .67344 Mdot
.48369 .61073 Mdot
.63435 .50252 Mdot
.4327 .41441 Mdot
.64189 .58891 Mdot
.6305 .51346 Mdot
.71765 .60376 Mdot
.44134 .81101 Mdot
.47107 .62504 Mdot
.37555 .42541 Mdot
.4734 .63585 Mdot
.4657 .31467 Mdot
.44258 .67558 Mdot
.49226 .66856 Mdot
.36649 .49051 Mdot
.36845 .45472 Mdot
.6013 .39287 Mdot
.59051 .52091 Mdot
.44141 .64568 Mdot
.37046 .50723 Mdot
.33369 .45692 Mdot
.33627 .44573 Mdot
.52064 .4793 Mdot
.47736 .70104 Mdot
.26761 .54051 Mdot
.28456 .38648 Mdot
.44012 .64708 Mdot
.67545 .78331 Mdot
.72577 .54888 Mdot
.60643 .431 Mdot
.61287 .54417 Mdot
.40173 .50623 Mdot
.66292 .41755 Mdot
.36817 .45826 Mdot
.34863 .55668 Mdot
.37833 .47351 Mdot
.49712 .33101 Mdot
.41889 .41228 Mdot
.67427 .41541 Mdot
.63042 .39785 Mdot
.35374 .49855 Mdot
.36929 .46604 Mdot
.62287 .26431 Mdot
.49338 .64698 Mdot
.43662 .66724 Mdot
.56149 .34823 Mdot
.47884 .31586 Mdot
.65277 .61068 Mdot
.3866 .44147 Mdot
.61085 .41766 Mdot
.63372 .40087 Mdot
.43914 .70934 Mdot
.63938 .39384 Mdot
.67353 .58465 Mdot
.39337 .45978 Mdot
.61399 .5609 Mdot
.45745 .328 Mdot
.48546 .67964 Mdot
.36664 .44285 Mdot
.40852 .47809 Mdot
.47459 .64552 Mdot
.43342 .48606 Mdot
.48354 .34175 Mdot
.62894 .40655 Mdot
.46277 .65134 Mdot
.6425 .57255 Mdot
.64877 .38689 Mdot
.41582 .48421 Mdot
.87034 .46401 Mdot
.39294 .49194 Mdot
.41014 .49619 Mdot
.37862 .81567 Mdot
.42359 .41386 Mdot
.63985 .41544 Mdot
.43917 .62973 Mdot
.36336 .42075 Mdot
.33197 .28233 Mdot
.186 .37258 Mdot
.59567 .38049 Mdot
.35136 .48068 Mdot
.44946 .82537 Mdot
.35071 .48895 Mdot
.25697 .31306 Mdot
.51918 .24024 Mdot
.50801 .57229 Mdot
.36316 .40936 Mdot
.66741 .57609 Mdot
.60129 .39457 Mdot
.64928 .38949 Mdot
.23304 .50561 Mdot
.36429 .49368 Mdot
.3219 .40121 Mdot
.43045 .47589 Mdot
.64084 .56515 Mdot
.34477 .35992 Mdot
.63897 .40528 Mdot
.72642 .29682 Mdot
.40814 .4541 Mdot
.48016 .69925 Mdot
.56952 .38279 Mdot
.73119 .55868 Mdot
.41638 .49011 Mdot
.45577 .3134 Mdot
.60007 .58853 Mdot
.39208 .41066 Mdot
.64612 .58545 Mdot
.40581 .5101 Mdot
.38541 .3879 Mdot
.50754 .17058 Mdot
.4475 .64677 Mdot
.62114 .58961 Mdot
.69383 .43537 Mdot
.44148 .45025 Mdot
.4652 .65038 Mdot
.44814 .68878 Mdot
.46494 .29369 Mdot
.55983 .51099 Mdot
.62142 .67281 Mdot
.38642 .71102 Mdot
.22307 .49565 Mdot
.57162 .38713 Mdot
.70714 .44775 Mdot
.41795 .46984 Mdot
.80144 .49273 Mdot
.60652 .56748 Mdot
.38444 .49032 Mdot
.22783 .58504 Mdot
.48139 .68781 Mdot
.40125 .4973 Mdot
.49723 .31186 Mdot
.79082 .4322 Mdot
.79866 .46397 Mdot
.7014 .7356 Mdot
.60466 .38409 Mdot
.39437 .54564 Mdot
.3337 .54319 Mdot
.60382 .41916 Mdot
.43816 .46457 Mdot
.63384 .41465 Mdot
.18978 .57069 Mdot
.474 .34554 Mdot
.48593 .68467 Mdot
.72818 .55234 Mdot
.41995 .43322 Mdot
.32787 .4644 Mdot
.46429 .35231 Mdot
.41004 .44004 Mdot
.59563 .18898 Mdot
.76942 .4733 Mdot
.63929 .42943 Mdot
.44307 .65295 Mdot
.41036 .42651 Mdot
.56076 .47334 Mdot
.36869 .49716 Mdot
.34939 .69626 Mdot
.3831 .42648 Mdot
.61338 .66202 Mdot
.46178 .6399 Mdot
.64253 .58542 Mdot
.43157 .51951 Mdot
.38159 .46554 Mdot
.55455 .42808 Mdot
.3717 .40651 Mdot
.35132 .50164 Mdot
.49407 .69122 Mdot
.46303 .70834 Mdot
.45239 .66362 Mdot
.65132 .38 Mdot
.78798 .5594 Mdot
.63682 .59441 Mdot
.39666 .53818 Mdot
.63578 .61774 Mdot
.43905 .56806 Mdot
.45505 .34067 Mdot
.53072 .81331 Mdot
.4022 .4322 Mdot
.45837 .66742 Mdot
.62303 .73815 Mdot
.4479 .63816 Mdot
.54129 .44322 Mdot
.65764 .57777 Mdot
.47625 .69603 Mdot
.38448 .4561 Mdot
.60798 .50829 Mdot
.60701 .79704 Mdot
.62859 .5772 Mdot
.43979 .48741 Mdot
.65337 .43304 Mdot
.77062 .54362 Mdot
.88228 .49017 Mdot
.62995 .60302 Mdot
.69203 .44056 Mdot
.36086 .49384 Mdot
.44461 .70299 Mdot
.67005 .57834 Mdot
.65393 .59989 Mdot
.6438 .39646 Mdot
.36756 .45275 Mdot
.36704 .44875 Mdot
.67279 .40847 Mdot
.62728 .57035 Mdot
.32483 .48034 Mdot
.33816 .48712 Mdot
.41991 .84791 Mdot
.26608 .43072 Mdot
.12629 .48287 Mdot
.49935 .61975 Mdot
.23438 .60705 Mdot
.52486 .72108 Mdot
.48883 .6621 Mdot
.35976 .45107 Mdot
.42373 .42551 Mdot
.64853 .41223 Mdot
.39348 .47662 Mdot
.59857 .36175 Mdot
.63196 .59886 Mdot
.66976 .78349 Mdot
.67873 .69193 Mdot
.18752 .54924 Mdot
.39102 .47698 Mdot
.70962 .63603 Mdot
.47366 .30615 Mdot
.63832 .62161 Mdot
.45858 .65683 Mdot
.39178 .52256 Mdot
.63196 .26683 Mdot
.60212 .37282 Mdot
.44884 .69701 Mdot
.72146 .32573 Mdot
.69264 .3257 Mdot
.37125 .52254 Mdot
.66003 .38891 Mdot
.56178 .76124 Mdot
.31419 .5535 Mdot
.6859 .58031 Mdot
.49869 .32701 Mdot
.60297 .37602 Mdot
.63325 .55807 Mdot
.46281 .75619 Mdot
.47011 .6995 Mdot
.41576 .6686 Mdot
.59061 .23465 Mdot
.59276 .41005 Mdot
.48062 .30304 Mdot
.78441 .56697 Mdot
.81162 .50568 Mdot
.49694 .33074 Mdot
.66747 .41877 Mdot
.46912 .70548 Mdot
.4711 .66337 Mdot
.4538 .68464 Mdot
.7353 .3075 Mdot
.46583 .71607 Mdot
.32507 .59896 Mdot
.33035 .46289 Mdot
.35698 .39031 Mdot
.35039 .48242 Mdot
.62439 .55127 Mdot
.46001 .64443 Mdot
.55206 .60395 Mdot
.39848 .53319 Mdot
.67544 .76264 Mdot
.36076 .49951 Mdot
.68359 .59138 Mdot
.40366 .50011 Mdot
.35284 .60299 Mdot
.47995 .63923 Mdot
.39638 .47024 Mdot
.63733 .54465 Mdot
.47302 .32306 Mdot
.45603 .60477 Mdot
.3628 .44959 Mdot
.5647 .70733 Mdot
.42764 .41623 Mdot
.21535 .64711 Mdot
.27377 .35824 Mdot
.44764 .31646 Mdot
.40655 .57127 Mdot
.58126 .37931 Mdot
.35436 .3897 Mdot
.30557 .49784 Mdot
.63048 .57658 Mdot
.75144 .63933 Mdot
.6122 .38137 Mdot
.40467 .35165 Mdot
.36109 .54417 Mdot
.49135 .29728 Mdot
.48281 .71609 Mdot
.63557 .54842 Mdot
.39653 .5263 Mdot
.36837 .53819 Mdot
.19674 .58483 Mdot
.30584 .46849 Mdot
.3501 .44391 Mdot
.45962 .34619 Mdot
.27059 .55724 Mdot
.40345 .48281 Mdot
.53909 .44342 Mdot
.4168 .66086 Mdot
.33293 .43626 Mdot
.26883 .53631 Mdot
.36961 .50597 Mdot
.44689 .69974 Mdot
.43618 .7204 Mdot
.62977 .71415 Mdot
.47948 .28653 Mdot
.38474 .42675 Mdot
.23652 .39598 Mdot
.40733 .44901 Mdot
.64837 .59378 Mdot
.35559 .51382 Mdot
.6113 .37228 Mdot
.72593 .30668 Mdot
.64927 .42028 Mdot
.35287 .45933 Mdot
.45913 .68479 Mdot
.66393 .56619 Mdot
.62767 .24881 Mdot
.54293 .259 Mdot
.31288 .59032 Mdot
.1636 .50358 Mdot
.4623 .33964 Mdot
.5019 .32779 Mdot
.64365 .54971 Mdot
.39762 .47098 Mdot
.2269 .38368 Mdot
.40907 .4035 Mdot
.40384 .49248 Mdot
.37731 .4737 Mdot
.76792 .58098 Mdot
.62623 .58964 Mdot
.63282 .38772 Mdot
.38901 .49783 Mdot
.37429 .50974 Mdot
.48186 .64879 Mdot
.47371 .32507 Mdot
.66227 .41065 Mdot
.48176 .32311 Mdot
.61536 .40669 Mdot
.66226 .79316 Mdot
.42197 .5229 Mdot
.47391 .32 Mdot
.60404 .58802 Mdot
.43721 .68422 Mdot
.63667 .4998 Mdot
.65373 .39477 Mdot
.64339 .40622 Mdot
.36314 .50123 Mdot
.44292 .69838 Mdot
.42939 .66404 Mdot
.46476 .31477 Mdot
.65477 .60451 Mdot
.36023 .45628 Mdot
.4098 .51294 Mdot
.48486 .5652 Mdot
.59104 .39277 Mdot
.28511 .49189 Mdot
.59933 .72991 Mdot
.39749 .46573 Mdot
.43075 .67302 Mdot
.37054 .47446 Mdot
.40199 .78387 Mdot
.43764 .69788 Mdot
.34569 .49439 Mdot
.82146 .47941 Mdot
.60786 .48781 Mdot
.58918 .69228 Mdot
.35828 .43404 Mdot
.15824 .58356 Mdot
.42058 .46279 Mdot
.44604 .84625 Mdot
.60469 .28309 Mdot
.36485 .43944 Mdot
.41475 .47498 Mdot
.40546 .74673 Mdot
.3583 .47764 Mdot
.67598 .41456 Mdot
.40036 .35082 Mdot
.49437 .67397 Mdot
.54442 .66512 Mdot
.48852 .42997 Mdot
.4715 .28584 Mdot
.62509 .42829 Mdot
.65182 .46642 Mdot
.4951 .32532 Mdot
.46965 .68235 Mdot
.39687 .44871 Mdot
.52645 .56489 Mdot
.65787 .37948 Mdot
.32089 .47739 Mdot
.65314 .58938 Mdot
.73014 .46365 Mdot
.58018 .3655 Mdot
.64323 .57823 Mdot
.41609 .43682 Mdot
.41875 .7445 Mdot
.50181 .22397 Mdot
.29156 .76736 Mdot
.66442 .56452 Mdot
.63015 .56516 Mdot
.7588 .32932 Mdot
.47262 .28381 Mdot
.20104 .55156 Mdot
.59335 .65208 Mdot
.67501 .59113 Mdot
.24828 .40974 Mdot
.59546 .37562 Mdot
.56631 .69666 Mdot
.44704 .61968 Mdot
.33543 .49753 Mdot
.38409 .45896 Mdot
.6512 .60671 Mdot
.45988 .75957 Mdot
.49208 .17062 Mdot
.63483 .57991 Mdot
.41019 .39166 Mdot
.51889 .50567 Mdot
.72267 .54599 Mdot
.59456 .39855 Mdot
.47637 .28749 Mdot
.50309 .2789 Mdot
.48286 .658 Mdot
.47563 .29043 Mdot
.79329 .45279 Mdot
.40609 .43589 Mdot
.63388 .57221 Mdot
.72947 .56672 Mdot
.64575 .57172 Mdot
.49521 .32104 Mdot
.44801 .30952 Mdot
.43833 .65342 Mdot
.43739 .66703 Mdot
.24635 .62289 Mdot
.33805 .34361 Mdot
.35164 .49333 Mdot
.63511 .76692 Mdot
.46459 .63343 Mdot
.37623 .56777 Mdot
.50289 .31824 Mdot
.47624 .32062 Mdot
.28347 .42681 Mdot
.37574 .43995 Mdot
.23889 .36106 Mdot
.37927 .44097 Mdot
.3446 .35465 Mdot
.439 .45138 Mdot
.64192 .39533 Mdot
.37627 .43718 Mdot
.44736 .3628 Mdot
.36909 .53195 Mdot
.35536 .50908 Mdot
.59123 .37263 Mdot
.38469 .41191 Mdot
.61328 .37238 Mdot
.34996 .46197 Mdot
.49903 .2917 Mdot
.61207 .42018 Mdot
.36439 .27419 Mdot
.65985 .36821 Mdot
.65416 .43539 Mdot
.46937 .29561 Mdot
.45378 .30584 Mdot
.35761 .25462 Mdot
.45998 .65625 Mdot
.47845 .61596 Mdot
.39736 .47547 Mdot
.58824 .3715 Mdot
.62404 .59028 Mdot
.37904 .51113 Mdot
.43092 .42555 Mdot
.3452 .44561 Mdot
.48682 .67005 Mdot
.56447 .40055 Mdot
.4692 .32128 Mdot
.65411 .38138 Mdot
.55124 .40443 Mdot
.62293 .36273 Mdot
.32415 .51636 Mdot
.44468 .50642 Mdot
.24955 .65411 Mdot
.68819 .71888 Mdot
.80274 .37731 Mdot
.46395 .7016 Mdot
.61647 .4301 Mdot
.4583 .29528 Mdot
.4576 .51279 Mdot
.46137 .66223 Mdot
.61831 .3714 Mdot
.39817 .46011 Mdot
.44036 .48768 Mdot
.59851 .60413 Mdot
.33828 .39608 Mdot
.29877 .31723 Mdot
.61483 .36295 Mdot
.58538 .36177 Mdot
.8091 .50477 Mdot
.39776 .35511 Mdot
.54659 .57026 Mdot
.37693 .48636 Mdot
.45563 .31612 Mdot
.47963 .6951 Mdot
.54216 .22017 Mdot
.62625 .60551 Mdot
.58846 .52398 Mdot
.39164 .47556 Mdot
.57349 .62579 Mdot
.45754 .68583 Mdot
.4938 .30471 Mdot
.6506 .60746 Mdot
.44683 .30509 Mdot
.59573 .41012 Mdot
.19354 .40899 Mdot
.40918 .44544 Mdot
.3483 .49097 Mdot
.61719 .60162 Mdot
.48274 .67375 Mdot
.45658 .34831 Mdot
.23735 .67162 Mdot
.65756 .41915 Mdot
.23029 .36098 Mdot
.42652 .65898 Mdot
.35919 .62733 Mdot
.65092 .37848 Mdot
.62563 .55838 Mdot
.37239 .25131 Mdot
.63947 .5622 Mdot
.35386 .45038 Mdot
.45864 .67446 Mdot
.64165 .60107 Mdot
.55972 .4512 Mdot
.47727 .82688 Mdot
.37297 .64273 Mdot
.39159 .43634 Mdot
.57003 .81338 Mdot
.30996 .75348 Mdot
.41069 .71452 Mdot
.63144 .61253 Mdot
.37291 .49627 Mdot
.43301 .45133 Mdot
.40557 .45286 Mdot
.66169 .58264 Mdot
.72834 .52089 Mdot
.64671 .3926 Mdot
.35439 .49024 Mdot
.46494 .29229 Mdot
.6166 .37436 Mdot
.73607 .55803 Mdot
.64262 .4127 Mdot
.48587 .63507 Mdot
.35177 .51114 Mdot
.62638 .52406 Mdot
.54164 .84622 Mdot
.62712 .58146 Mdot
.6554 .43506 Mdot
.37422 .51721 Mdot
.75019 .61527 Mdot
.45427 .66395 Mdot
.65528 .4212 Mdot
.38317 .49338 Mdot
.69897 .51532 Mdot
.61826 .26061 Mdot
.64229 .41122 Mdot
.46914 .65855 Mdot
.47227 .7739 Mdot
.39319 .48119 Mdot
.42008 .45826 Mdot
.4806 .67568 Mdot
.4772 .41587 Mdot
.73249 .32849 Mdot
.37018 .4691 Mdot
.64242 .58402 Mdot
.24194 .29056 Mdot
.34219 .44234 Mdot
.29205 .39918 Mdot
.59998 .3861 Mdot
.58663 .71699 Mdot
.2864 .49839 Mdot
.40839 .56664 Mdot
.42287 .77117 Mdot
.50985 .4436 Mdot
.64731 .79407 Mdot
.5894 .36514 Mdot
.63705 .30812 Mdot
.64097 .80283 Mdot
.65301 .5498 Mdot
.50177 .71684 Mdot
.46661 .58353 Mdot
.71218 .27992 Mdot
.49602 .76523 Mdot
.58801 .32648 Mdot
.64932 .27211 Mdot
.51513 .54161 Mdot
.62309 .40932 Mdot
.43787 .36996 Mdot
.36362 .45694 Mdot
.30396 .75025 Mdot
.31085 .55729 Mdot
.46437 .16426 Mdot
.55928 .81529 Mdot
.24007 .39473 Mdot
.55452 .80437 Mdot
.43 .81372 Mdot
.23264 .63202 Mdot
.66917 .73075 Mdot
.24726 .30594 Mdot
.81499 .47336 Mdot
.20768 .45003 Mdot
.43402 .53257 Mdot
.52203 .40557 Mdot
.17554 .5789 Mdot
.33687 .62538 Mdot
.38283 .20087 Mdot
.65359 .41376 Mdot
.43752 .63136 Mdot
.47522 .58298 Mdot
.49632 .69426 Mdot
.57877 .5936 Mdot
.43834 .78543 Mdot
.42849 .83502 Mdot
.34258 .59409 Mdot
.15711 .59141 Mdot
.23529 .56386 Mdot
.70479 .21867 Mdot
.67424 .34214 Mdot
.41919 .68303 Mdot
.53351 .33847 Mdot
.80706 .52153 Mdot
.67033 .6802 Mdot
.50112 .61684 Mdot
.76092 .54127 Mdot
.37458 .29352 Mdot
.46869 .67693 Mdot
.30703 .54125 Mdot
.70243 .37719 Mdot
.6985 .67306 Mdot
.47659 .24664 Mdot
.44217 .80168 Mdot
.53984 .5492 Mdot
.55829 .69225 Mdot
.71831 .44064 Mdot
.86965 .46767 Mdot
.28492 .36983 Mdot
.35401 .76383 Mdot
.58565 .57312 Mdot
.46965 .76595 Mdot
.66585 .24708 Mdot
.36266 .32873 Mdot
.80909 .51778 Mdot
.79508 .61639 Mdot
.27798 .73785 Mdot
.81238 .61904 Mdot
.47563 .61483 Mdot
.34978 .44259 Mdot
.34527 .74349 Mdot
.2423 .44899 Mdot
.50951 .30358 Mdot
.72225 .71397 Mdot
.45676 .32999 Mdot
.49962 .65321 Mdot
.71888 .30713 Mdot
.3339 .59768 Mdot
.23716 .35351 Mdot
.45369 .34979 Mdot
.41183 .42223 Mdot
.42783 .12462 Mdot
.63921 .7948 Mdot
.62409 .71188 Mdot
.42175 .84886 Mdot
.60967 .63992 Mdot
.26138 .36001 Mdot
.64685 .59917 Mdot
.5992 .82857 Mdot
.46766 .66692 Mdot
.74402 .75185 Mdot
.52579 .83766 Mdot
.48006 .18434 Mdot
.1801 .30841 Mdot
.79141 .48529 Mdot
.52085 .58698 Mdot
.50402 .45488 Mdot
.33136 .29777 Mdot
.53816 .18466 Mdot
.43786 .19032 Mdot
.74713 .60541 Mdot
.17076 .53671 Mdot
.60415 .82142 Mdot
.23553 .42984 Mdot
.19717 .42459 Mdot
.70185 .27108 Mdot
.52523 .43915 Mdot
.50681 .67595 Mdot
.68264 .3822 Mdot
.51992 .78944 Mdot
.75906 .69175 Mdot
.28302 .39943 Mdot
.20657 .30128 Mdot
.45619 .36135 Mdot
.59558 .28676 Mdot
.36237 .79024 Mdot
.3889 .26898 Mdot
.25718 .41655 Mdot
.77209 .35975 Mdot
.32386 .50015 Mdot
.79503 .39542 Mdot
.58028 .78137 Mdot
.67085 .47182 Mdot
.81125 .45782 Mdot
.54646 .74929 Mdot
.20719 .61573 Mdot
.35072 .72696 Mdot
.80732 .53296 Mdot
.49579 .66165 Mdot
.34855 .32141 Mdot
.26581 .38655 Mdot
.41224 .84456 Mdot
.69273 .43661 Mdot
.3412 .8247 Mdot
.70468 .31288 Mdot
.44505 .4606 Mdot
.30208 .49464 Mdot
.44166 .40604 Mdot
.32673 .33983 Mdot
.33508 .45636 Mdot
.71616 .62857 Mdot
.39734 .83434 Mdot
.22412 .55904 Mdot
.66913 .47877 Mdot
.75266 .64336 Mdot
.29697 .77171 Mdot
.27783 .68994 Mdot
.63121 .27685 Mdot
.33543 .37743 Mdot
.80157 .34719 Mdot
.61837 .38025 Mdot
.23344 .43018 Mdot
.68018 .57181 Mdot
.55017 .22887 Mdot
.38726 .6979 Mdot
.51829 .19383 Mdot
.39622 .83402 Mdot
.73532 .34505 Mdot
.68065 .29258 Mdot
.40848 .23868 Mdot
.2247 .35371 Mdot
.74574 .6658 Mdot
.39433 .54311 Mdot
.52646 .66147 Mdot
.45513 .33568 Mdot
.27734 .6613 Mdot
.22689 .45766 Mdot
.55499 .30099 Mdot
.37814 .40816 Mdot
.47717 .22421 Mdot
.56088 .37558 Mdot
.60147 .51497 Mdot
.84773 .59349 Mdot
.31475 .47983 Mdot
.78157 .54109 Mdot
.24867 .706 Mdot
.31026 .33228 Mdot
.36318 .78481 Mdot
.54446 .71712 Mdot
.80458 .62369 Mdot
.49559 .83884 Mdot
.54377 .27212 Mdot
.69367 .75823 Mdot
.40187 .85038 Mdot
.8197 .58871 Mdot
.30551 .4507 Mdot
.61493 .5508 Mdot
.87062 .6075 Mdot
.66688 .39117 Mdot
.77693 .608 Mdot
.22336 .4957 Mdot
.70404 .5086 Mdot
.44438 .60402 Mdot
.45132 .50222 Mdot
.5204 .54726 Mdot
.42682 .73124 Mdot
.35911 .4212 Mdot
.85775 .53229 Mdot
.80983 .58278 Mdot
.83825 .5775 Mdot
.2058 .65201 Mdot
.69205 .76304 Mdot
.49425 .54841 Mdot
.33989 .61539 Mdot
.46184 .55316 Mdot
.36607 .52389 Mdot
.4263 .32345 Mdot
.78979 .48187 Mdot
.50454 .21524 Mdot
.65664 .6758 Mdot
.49989 .67835 Mdot
.67098 .75188 Mdot
.86543 .35797 Mdot
.24496 .58314 Mdot
.25303 .51443 Mdot
.80286 .47781 Mdot
.32087 .35042 Mdot
.54406 .7886 Mdot
.48629 .19863 Mdot
.3875 .81904 Mdot
.44675 .5744 Mdot
.21047 .47558 Mdot
.56522 .32764 Mdot
.29076 .28769 Mdot
.55999 .35545 Mdot
.46549 .81552 Mdot
.48849 .49749 Mdot
.58644 .21758 Mdot
.54557 .62519 Mdot
.48502 .17784 Mdot
.57108 .25407 Mdot
.7335 .45864 Mdot
.22133 .43528 Mdot
.73396 .59256 Mdot
.31154 .36584 Mdot
.52762 .51406 Mdot
.46687 .4853 Mdot
.50993 .44494 Mdot
.30119 .37183 Mdot
.3054 .27782 Mdot
.74807 .70285 Mdot
.40668 .86204 Mdot
.85123 .44665 Mdot
.16277 .60656 Mdot
.57935 .77602 Mdot
.33186 .49317 Mdot
.3462 .79447 Mdot
.81806 .62753 Mdot
.49573 .84551 Mdot
.73579 .3758 Mdot
.60943 .47942 Mdot
.62865 .61779 Mdot
.84949 .46264 Mdot
.5721 .3424 Mdot
.40485 .80334 Mdot
.80484 .39987 Mdot
.60768 .54721 Mdot
.67133 .2264 Mdot
.80428 .58042 Mdot
.38737 .66922 Mdot
.2981 .4403 Mdot
.33134 .50577 Mdot
.35443 .59421 Mdot
.47938 .63355 Mdot
.70963 .43717 Mdot
.34731 .33472 Mdot
.61906 .39027 Mdot
.44634 .27328 Mdot
.5198 .63867 Mdot
.41705 .41162 Mdot
.49425 .43049 Mdot
.44023 .62749 Mdot
.68543 .72033 Mdot
.66641 .52245 Mdot
.73024 .74413 Mdot
.77983 .46695 Mdot
.36787 .40643 Mdot
.30411 .34183 Mdot
.70107 .34127 Mdot
.76296 .34571 Mdot
.67701 .57308 Mdot
.53738 .82175 Mdot
.53511 .42793 Mdot
.34642 .32451 Mdot
.35148 .58807 Mdot
.2173 .6267 Mdot
.44634 .5051 Mdot
.61277 .73244 Mdot
.3298 .68579 Mdot
.59371 .51604 Mdot
.50592 .67185 Mdot
.50661 .6863 Mdot
.25446 .7487 Mdot
.78399 .41696 Mdot
.7184 .45509 Mdot
.5243 .82251 Mdot
.65717 .56978 Mdot
.44299 .64296 Mdot
.42141 .34024 Mdot
.21113 .62964 Mdot
.33859 .6656 Mdot
.61989 .26091 Mdot
.7633 .50406 Mdot
.56797 .29584 Mdot
.54442 .81258 Mdot
.56678 .80816 Mdot
.45384 .16138 Mdot
.4824 .71061 Mdot
.24299 .66669 Mdot
.1908 .52724 Mdot
.45709 .62808 Mdot
.43325 .60549 Mdot
.68836 .66409 Mdot
.74462 .71819 Mdot
.65795 .53193 Mdot
.16596 .54082 Mdot
.31235 .28561 Mdot
.71152 .52068 Mdot
.63404 .25209 Mdot
.21828 .41942 Mdot
.51166 .822 Mdot
.32775 .56066 Mdot
.39417 .67986 Mdot
.44803 .43951 Mdot
.34743 .38935 Mdot
.84958 .41072 Mdot
.64891 .36209 Mdot
.36012 .62303 Mdot
.53947 .74425 Mdot
.40117 .44361 Mdot
.86744 .47451 Mdot
.27529 .72164 Mdot
.76729 .33633 Mdot
.60474 .59685 Mdot
.42752 .46865 Mdot
.36317 .52875 Mdot
.31749 .39047 Mdot
.60706 .7184 Mdot
.7843 .61841 Mdot
.21671 .42394 Mdot
.54225 .77134 Mdot
.3162 .56057 Mdot
.78027 .54375 Mdot
.43445 .79743 Mdot
.32826 .76372 Mdot
.56898 .5041 Mdot
.7857 .46882 Mdot
.38852 .25043 Mdot
.16893 .60763 Mdot
.53339 .39505 Mdot
.49097 .56182 Mdot
.67781 .652 Mdot
.57271 .72949 Mdot
.58734 .22663 Mdot
.40174 .5154 Mdot
.72174 .32587 Mdot
.42948 .81104 Mdot
.36115 .20115 Mdot
.59007 .20136 Mdot
.86748 .48875 Mdot
.36117 .70488 Mdot
.55872 .72621 Mdot
.44089 .76955 Mdot
.32427 .211 Mdot
.52532 .39586 Mdot
.65158 .77552 Mdot
.39479 .244 Mdot
.53432 .81794 Mdot
.62778 .54218 Mdot
.56702 .63324 Mdot
.75549 .63946 Mdot
.72434 .73532 Mdot
.30134 .70948 Mdot
.46311 .80897 Mdot
.54636 .60517 Mdot
.78696 .68098 Mdot
.73316 .62994 Mdot
.5102 .52975 Mdot
.61977 .42992 Mdot
.75821 .36113 Mdot
.55601 .79682 Mdot
.63904 .75167 Mdot
.22438 .44247 Mdot
.6041 .34976 Mdot
.41072 .35082 Mdot
.39334 .62955 Mdot
.41189 .27336 Mdot
.57046 .74092 Mdot
.30463 .34087 Mdot
.43533 .82418 Mdot
.53516 .37791 Mdot
.68823 .30659 Mdot
.77732 .54289 Mdot
.186 .43588 Mdot
.61291 .71415 Mdot
.78086 .40605 Mdot
.35852 .76876 Mdot
.58127 .27205 Mdot
.25005 .38983 Mdot
.43875 .90579 Mdot
.19164 .47848 Mdot
.70651 .69036 Mdot
.75997 .68976 Mdot
.35071 .7805 Mdot
.70014 .70505 Mdot
.55279 .18423 Mdot
.26615 .43609 Mdot
.40428 .33118 Mdot
.37838 .47233 Mdot
.84265 .59567 Mdot
.38863 .29429 Mdot
.77042 .68408 Mdot
.32342 .78697 Mdot
.36601 .60082 Mdot
.41456 .41137 Mdot
.63072 .3688 Mdot
.69865 .39308 Mdot
.42534 .27421 Mdot
.40311 .7255 Mdot
.25584 .44964 Mdot
.77094 .48343 Mdot
.60189 .41794 Mdot
.56233 .34901 Mdot
.40466 .66936 Mdot
.76972 .43862 Mdot
.59102 .73128 Mdot
.44521 .29184 Mdot
.55914 .53628 Mdot
.3048 .36311 Mdot
.28658 .50531 Mdot
.38532 .67306 Mdot
.52685 .19562 Mdot
.53689 .45844 Mdot
.64231 .41581 Mdot
.38338 .71947 Mdot
.17566 .53482 Mdot
.56786 .75574 Mdot
.79329 .62964 Mdot
.75294 .34763 Mdot
.47076 .51276 Mdot
.3031 .37568 Mdot
.51893 .18528 Mdot
.27456 .29044 Mdot
.69119 .72631 Mdot
.31987 .53794 Mdot
.24671 .35679 Mdot
.5159 .62125 Mdot
.65711 .79509 Mdot
.20794 .45545 Mdot
.21175 .50441 Mdot
.67816 .35919 Mdot
.32856 .63106 Mdot
.3827 .60576 Mdot
.36153 .27007 Mdot
.55836 .55644 Mdot
.72003 .23277 Mdot
.43905 .62087 Mdot
.87048 .42513 Mdot
.61708 .5866 Mdot
.72383 .27793 Mdot
.38579 .2388 Mdot
.52754 .5093 Mdot
.555 .57081 Mdot
.62369 .72704 Mdot
.6155 .66131 Mdot
.18045 .6105 Mdot
.43287 .18025 Mdot
.62234 .36216 Mdot
.21333 .39915 Mdot
.18883 .4047 Mdot
.40081 .74054 Mdot
.39034 .41985 Mdot
.18872 .47938 Mdot
.60858 .35548 Mdot
.50748 .21407 Mdot
.33022 .77993 Mdot
.61847 .75208 Mdot
.38507 .38999 Mdot
.32719 .34626 Mdot
.64235 .7795 Mdot
.49426 .83433 Mdot
.61939 .20038 Mdot
.58067 .78092 Mdot
.61235 .55378 Mdot
.5011 .53809 Mdot
.48675 .80413 Mdot
.27497 .33987 Mdot
.55808 .67196 Mdot
.26104 .38816 Mdot
.81911 .33187 Mdot
.77276 .63415 Mdot
.78373 .61857 Mdot
.2701 .35891 Mdot
.45413 .71953 Mdot
.72262 .64324 Mdot
.25847 .41115 Mdot
.62981 .74201 Mdot
.18464 .59439 Mdot
.26271 .39437 Mdot
.4347 .15337 Mdot
.21569 .5773 Mdot
.55277 .39886 Mdot
.38969 .60463 Mdot
.22221 .57958 Mdot
.60119 .57004 Mdot
.41889 .31377 Mdot
.53766 .7514 Mdot
.61525 .60144 Mdot
.57611 .74062 Mdot
.56895 .70677 Mdot
.20724 .53315 Mdot
.34898 .66669 Mdot
.55322 .77287 Mdot
.38597 .74981 Mdot
.46896 .74581 Mdot
.54581 .2212 Mdot
.5902 .42005 Mdot
.5222 .7561 Mdot
.64668 .43014 Mdot
.39528 .5654 Mdot
.58681 .51326 Mdot
.47246 .42785 Mdot
.8442 .43974 Mdot
.45759 .33688 Mdot
.43177 .70201 Mdot
.74231 .28316 Mdot
.44019 .63297 Mdot
.85248 .55641 Mdot
.49994 .19825 Mdot
.34258 .58339 Mdot
.55045 .26799 Mdot
.5457 .3322 Mdot
.57102 .14994 Mdot
.41077 .62617 Mdot
.68453 .36229 Mdot
.47156 .73797 Mdot
.45241 .71269 Mdot
.77727 .5173 Mdot
.59901 .40964 Mdot
.28322 .44796 Mdot
.6837 .63648 Mdot
.46791 .53478 Mdot
.44687 .72764 Mdot
.56533 .46297 Mdot
.37273 .3554 Mdot
.73706 .728 Mdot
.62803 .41486 Mdot
.78845 .31137 Mdot
.44638 .45106 Mdot
.32783 .71253 Mdot
.37933 .81905 Mdot
.6475 .2138 Mdot
.67559 .44129 Mdot
.19313 .36179 Mdot
.44362 .4661 Mdot
.55617 .77683 Mdot
.47214 .6719 Mdot
.21232 .49191 Mdot
.47751 .33574 Mdot
.31688 .31857 Mdot
.63926 .61907 Mdot
.58932 .2195 Mdot
.7643 .43746 Mdot
.45055 .72246 Mdot
.61189 .76609 Mdot
.22994 .63867 Mdot
.57357 .65032 Mdot
.55235 .37881 Mdot
.39643 .73023 Mdot
.34352 .6606 Mdot
.44462 .7266 Mdot
.77378 .64939 Mdot
.20642 .48061 Mdot
.62272 .82624 Mdot
.43956 .40613 Mdot
.66373 .3193 Mdot
.65872 .65089 Mdot
.59145 .74236 Mdot
.28948 .46919 Mdot
.39443 .82612 Mdot
.3585 .32397 Mdot
.69349 .64083 Mdot
.33719 .35509 Mdot
.43145 .54514 Mdot
.55023 .53064 Mdot
.72371 .41901 Mdot
.49806 .1541 Mdot
.30748 .41202 Mdot
.6681 .24193 Mdot
.33184 .54607 Mdot
.78573 .52984 Mdot
.40984 .67541 Mdot
.60805 .46834 Mdot
.33954 .63436 Mdot
.69407 .43149 Mdot
.64021 .80743 Mdot
.39085 .82367 Mdot
.59303 .58877 Mdot
.77023 .52855 Mdot
.50217 .74515 Mdot
.43595 .40844 Mdot
.55352 .61436 Mdot
.35114 .4458 Mdot
.41319 .64531 Mdot
.67085 .2222 Mdot
.62215 .73913 Mdot
.37631 .54687 Mdot
.64475 .79693 Mdot
.58989 .83056 Mdot
.78123 .68432 Mdot
.22801 .35971 Mdot
.49024 .66974 Mdot
.83196 .57276 Mdot
.2697 .49286 Mdot
.44658 .83345 Mdot
.67902 .73452 Mdot
.27422 .76562 Mdot
.39582 .70164 Mdot
.53859 .73346 Mdot
.44476 .18326 Mdot
.59912 .67226 Mdot
.3038 .75611 Mdot
.50784 .49493 Mdot
.70634 .47284 Mdot
.30455 .76144 Mdot
.47162 .12435 Mdot
.29862 .50561 Mdot
.56133 .70146 Mdot
.50597 .60084 Mdot
.52755 .75549 Mdot
.62356 .28613 Mdot
.35635 .51442 Mdot
.74026 .5732 Mdot
.65439 .26682 Mdot
.29348 .37066 Mdot
.41176 .35019 Mdot
.62089 .28632 Mdot
.43219 .278 Mdot
.3553 .35299 Mdot
.20725 .44869 Mdot
.39351 .70966 Mdot
.28586 .45005 Mdot
.44704 .46521 Mdot
.41189 .65864 Mdot
.49027 .29075 Mdot
.62895 .45736 Mdot
.34798 .46047 Mdot
.67897 .44287 Mdot
.58897 .65843 Mdot
.86406 .50432 Mdot
.65875 .48664 Mdot
.24524 .68854 Mdot
.44644 .62057 Mdot
.60981 .7232 Mdot
.38879 .7649 Mdot
.71603 .29101 Mdot
.61811 .3092 Mdot
.28294 .39932 Mdot
.61217 .80629 Mdot
.81073 .46047 Mdot
.20252 .59122 Mdot
.82752 .49667 Mdot
.60571 .57796 Mdot
.33254 .41308 Mdot
.49661 .58745 Mdot
.73817 .36075 Mdot
.50149 .69318 Mdot
.54182 .73443 Mdot
.65834 .34433 Mdot
.79748 .42977 Mdot
.25273 .71164 Mdot
.22284 .63056 Mdot
.40559 .61915 Mdot
.57567 .80943 Mdot
.59493 .38296 Mdot
.20369 .49403 Mdot
.5513 .66585 Mdot
.63224 .31529 Mdot
.79056 .56333 Mdot
.70604 .76231 Mdot
.5541 .60326 Mdot
.37134 .28747 Mdot
.41444 .45398 Mdot
.2691 .54207 Mdot
.63001 .73165 Mdot
.46255 .37495 Mdot
.75634 .45838 Mdot
.43356 .68386 Mdot
.74302 .44166 Mdot
.52017 .37934 Mdot
.40466 .32409 Mdot
.44842 .73287 Mdot
.24528 .45513 Mdot
.50867 .32148 Mdot
.6732 .63508 Mdot
.34684 .43257 Mdot
.35297 .29638 Mdot
.23693 .34848 Mdot
.32678 .42213 Mdot
.54993 .79244 Mdot
.38886 .71432 Mdot
.19976 .60403 Mdot
.5854 .75654 Mdot
.70067 .71853 Mdot
.61944 .66494 Mdot
.35449 .64013 Mdot
.71742 .35558 Mdot
.34644 .44398 Mdot
.61253 .47173 Mdot
.43435 .64919 Mdot
.44383 .78144 Mdot
.35429 .70037 Mdot
.36751 .27337 Mdot
.54085 .4942 Mdot
.3772 .75998 Mdot
.53199 .47554 Mdot
.36056 .80251 Mdot
.60128 .67314 Mdot
.35156 .33329 Mdot
.65099 .54222 Mdot
.38322 .2423 Mdot
.54113 .18934 Mdot
.55942 .83 Mdot
.49972 .18653 Mdot
.5308 .5749 Mdot
.66989 .23896 Mdot
.7157 .66879 Mdot
.31674 .77584 Mdot
.36026 .33721 Mdot
.55625 .59896 Mdot
.41962 .3571 Mdot
.59017 .58473 Mdot
.55503 .4709 Mdot
.58456 .45428 Mdot
.27239 .46705 Mdot
.74125 .4974 Mdot
.7106 .37427 Mdot
.45658 .47226 Mdot
.77279 .59178 Mdot
.59629 .80884 Mdot
.21866 .4949 Mdot
.51993 .44989 Mdot
.52623 .23577 Mdot
.4021 .31751 Mdot
.14182 .59464 Mdot
.87055 .46548 Mdot
.414 .45199 Mdot
.51324 .4391 Mdot
.34453 .31236 Mdot
.63354 .36632 Mdot
.26355 .46262 Mdot
.41656 .76251 Mdot
.62014 .57071 Mdot
.59335 .46998 Mdot
.7932 .41464 Mdot
.63457 .72188 Mdot
.41064 .25988 Mdot
.76017 .59127 Mdot
.86612 .51646 Mdot
.16943 .56477 Mdot
.60356 .74186 Mdot
.17417 .66127 Mdot
.72574 .3894 Mdot
.50825 .66013 Mdot
.34405 .746 Mdot
.75107 .70179 Mdot
.30233 .33807 Mdot
.5841 .23326 Mdot
.72851 .68962 Mdot
.36133 .32809 Mdot
.25071 .41396 Mdot
.77858 .53964 Mdot
.74746 .44542 Mdot
.5261 .53337 Mdot
.54639 .33299 Mdot
.81862 .53936 Mdot
.33327 .56866 Mdot
.61465 .79655 Mdot
.65518 .26478 Mdot
.40754 .15841 Mdot
.60138 .82842 Mdot
.43045 .30673 Mdot
.62465 .28031 Mdot
.33465 .74007 Mdot
.29467 .30738 Mdot
.24975 .43935 Mdot
.53783 .20835 Mdot
.32708 .66011 Mdot
.53734 .30475 Mdot
.66676 .2549 Mdot
.31 .36683 Mdot
.22189 .5703 Mdot
.55483 .59576 Mdot
.38074 .69331 Mdot
.77897 .49521 Mdot
.27594 .36082 Mdot
.5591 .44471 Mdot
.32162 .28988 Mdot
.38821 .72688 Mdot
.37594 .77076 Mdot
.53849 .69992 Mdot
.49884 .12791 Mdot
.69735 .73023 Mdot
.71026 .28624 Mdot
.33146 .45922 Mdot
.66745 .79563 Mdot
.54512 .68755 Mdot
.72131 .70297 Mdot
.21828 .65837 Mdot
.59067 .44541 Mdot
.6169 .64784 Mdot
.34521 .44618 Mdot
.61567 .77796 Mdot
.36387 .62367 Mdot
.22693 .5944 Mdot
.6089 .23368 Mdot
.31241 .33831 Mdot
.63969 .2779 Mdot
.34892 .27052 Mdot
.36088 .401 Mdot
.42518 .66338 Mdot
.83536 .58958 Mdot
.53016 .5882 Mdot
.38458 .56121 Mdot
.39538 .38154 Mdot
.45726 .17795 Mdot
.16038 .48781 Mdot
.43356 .40212 Mdot
.81197 .48366 Mdot
.24115 .4183 Mdot
.46393 .51638 Mdot
.32877 .55226 Mdot
.1084 .40831 Mdot
.41612 .85699 Mdot
.49122 .69117 Mdot
.24005 .48344 Mdot
.24044 .37893 Mdot
.74493 .71016 Mdot
.56755 .32494 Mdot
.61157 .44021 Mdot
.3748 .21046 Mdot
.27771 .31985 Mdot
.44005 .44547 Mdot
.23683 .69195 Mdot
.54337 .83157 Mdot
.62386 .23831 Mdot
.63363 .80424 Mdot
.34972 .54858 Mdot
.39026 .5414 Mdot
.1071 .48392 Mdot
.49262 .80936 Mdot
.32608 .50294 Mdot
.46012 .17439 Mdot
.50702 .67142 Mdot
.37196 .45863 Mdot
.76104 .58048 Mdot
.21873 .43585 Mdot
.30951 .36948 Mdot
.72585 .73397 Mdot
.48248 .71522 Mdot
.69043 .43304 Mdot
.62199 .56343 Mdot
.55594 .56528 Mdot
.4367 .50279 Mdot
.66106 .58998 Mdot
.47098 .49058 Mdot
.52616 .74356 Mdot
.59896 .5686 Mdot
.2023 .41891 Mdot
.3226 .80885 Mdot
.36572 .6934 Mdot
.62696 .62568 Mdot
.45548 .42304 Mdot
.21759 .58329 Mdot
.42735 .27591 Mdot
.47149 .5495 Mdot
.29645 .76122 Mdot
.55028 .89037 Mdot
.71338 .47599 Mdot
.3792 .36919 Mdot
.45027 .73331 Mdot
.28565 .45826 Mdot
.3865 .64577 Mdot
.69524 .58459 Mdot
.59866 .39399 Mdot
.41148 .40461 Mdot
.36097 .40188 Mdot
.63345 .6165 Mdot
.85974 .41242 Mdot
.37401 .51936 Mdot
.31086 .53805 Mdot
.45273 .83127 Mdot
.54915 .22131 Mdot
.30981 .70084 Mdot
.41804 .51177 Mdot
.71432 .64461 Mdot
.55755 .6009 Mdot
.4935 .77704 Mdot
.69024 .30964 Mdot
.68645 .7593 Mdot
.35107 .69898 Mdot
.39815 .60725 Mdot
.36915 .50844 Mdot
.48522 .28278 Mdot
.56788 .69059 Mdot
.74183 .68363 Mdot
.31903 .52819 Mdot
.47392 .84027 Mdot
.58567 .44012 Mdot
.7538 .5083 Mdot
.45135 .54402 Mdot
.79769 .64824 Mdot
.63658 .22653 Mdot
.37729 .61771 Mdot
.75218 .31583 Mdot
.76319 .38913 Mdot
.40963 .27531 Mdot
.62014 .36673 Mdot
.40157 .55014 Mdot
.47738 .71905 Mdot
.87009 .52764 Mdot
.74669 .67676 Mdot
.69781 .53892 Mdot
.73462 .46267 Mdot
.30339 .57598 Mdot
.54771 .64042 Mdot
.24157 .74353 Mdot
.58662 .33048 Mdot
.8682 .50604 Mdot
.20944 .50167 Mdot
.40357 .69417 Mdot
.55587 .73514 Mdot
.31119 .45249 Mdot
.63874 .41056 Mdot
.72625 .72501 Mdot
.35673 .40611 Mdot
.70493 .3008 Mdot
.43205 .48708 Mdot
.77856 .35204 Mdot
.60771 .49357 Mdot
.76503 .55169 Mdot
.73505 .59022 Mdot
.55497 .18603 Mdot
.41217 .79372 Mdot
.62827 .51901 Mdot
.1972 .68314 Mdot
.4544 .78113 Mdot
.53833 .82238 Mdot
.60914 .25687 Mdot
.60058 .18289 Mdot
.6481 .74849 Mdot
.55769 .76841 Mdot
.66982 .52001 Mdot
.49437 .45881 Mdot
.75047 .3557 Mdot
.46782 .49817 Mdot
.58303 .6894 Mdot
.59172 .56962 Mdot
.65883 .86723 Mdot
.43332 .34762 Mdot
.51016 .63461 Mdot
.72227 .34514 Mdot
.57619 .8183 Mdot
.46314 .39859 Mdot
.26391 .72997 Mdot
.52268 .4062 Mdot
.40197 .54069 Mdot
.34476 .67678 Mdot
.22045 .48509 Mdot
.76576 .36445 Mdot
.62076 .16236 Mdot
.17219 .56908 Mdot
.74224 .48461 Mdot
.56488 .52558 Mdot
.45899 .62867 Mdot
.4471 .60347 Mdot
.55199 .29025 Mdot
.21823 .68632 Mdot
.53485 .73614 Mdot
.48747 .80484 Mdot
.55552 .14813 Mdot
.20053 .55439 Mdot
.74684 .7112 Mdot
.68384 .71022 Mdot
.42601 .63032 Mdot
.43625 .28821 Mdot
.49189 .25885 Mdot
.73495 .57819 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`27ooooo`;o00003?ooool2o`000;;ooooo000Loooo
o`03o`000?oooooooooo08Oooooo0_l0000<ooooo`;o00001oooool2o`000:Wooooo000Looooo`03
o`000?oooooooooo09kooooo0_l0002Yooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0X_ooool2
o`000:Gooooo000Looooo`03o`000?oooooooooo09?ooooo0_l00003ooooo`;o00002?ooool2o`00
0:Gooooo000Looooo`03o`000?oooooooooo09?ooooo0_l00003ooooo`;o00000oooool2o`000:[o
oooo000Looooo`03o`000?oooooooooo09Gooooo0_l00006ooooo`;o00004_ooool2o`0000?ooooo
0_l0002Aooooo`007?ooool2o`00083ooooo0_l00008ooooo`;o00002_ooool2o`0001[ooooo1?l0
00000ooooooo0000o`00002Aooooo`007?ooool00ol0003oooooooooo`1oooooo`;o00002?ooool2
o`0001?ooooo0_l0000Cooooo`;o0000U?ooool001cooooo00?o0000ooooooooool0POooool2o`00
01_ooooo0_l0002Yooooo`007?ooool00ol0003oooooooooo`21ooooo`;o00002?ooool2o`0000?o
oooo0_l0000<ooooo`;o00009_ooool2o`00087ooooo000Looooo`03o`000?oooooooooo08_ooooo
0_l00003ooooo`;o000000?oooooo`000?l000002Oooool2o`0001kooooo0_l00006ooooo`;o0000
POooool001cooooo00?o0000ooooooooool0Toooool2o`0002Wooooo0_l00029ooooo`007?ooool0
0ol0003oooooooooo`2Cooooo`;o00001oooool2o`0000?ooooo0_l000000ooooooo0000o`00002S
ooooo`007?ooool00ol0003oooooooooo`2Booooo`?o00001oooool2o`0000?ooooo0_l000000ooo
oooo0000o`00000<ooooo`;o0000UOooool001cooooo00?o0000ooooooooool0TOooool3o`0000Ko
oooo0_l000000ooooooo0000o`00000Aooooo`Co00006?ooool2o`0007_ooooo000Looooo`03o`00
0?oooooooooo08Wooooo0_l00003ooooo`;o000000?oooooo`000?l000001oooool2o`000003oooo
ool0003o0000017ooooo0_l0000Jooooo`;o0000Noooool001cooooo00?o0000ooooooooool0ROoo
ool2o`0000;ooooo1?l00007ooooo`Co00005?ooool2o`0000gooooo0_l00028ooooo`007?ooool0
0ol0003oooooooooo`1oooooo`;o00003?ooool4o`000003ooooool0003o000000Cooooo0_l00005
ooooo`;o00000_ooool4o`0000Cooooo0_l000000ooooooo0000o`000003o`0000Wooooo0_l00000
0ooooooo0000o`000028ooooo`007?ooool00ol0003oooooooooo`1oooooo`;o00002Oooool2o`00
00Kooooo0_l0000;ooooo`;o00000_ooool5o`0000?ooooo1Ol000000ooooooo0000o`000009oooo
o`Co0000ROooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006
ooooo`03o`000?oooooooooo083ooooo0_l00008ooooo`;o00004oooool2o`0000?ooooo1?l00004
ooooo`;o00000oooool2o`0000_ooooo0_l00029ooooo`0000KoooooogMgMonHV9SooooooiRHV?mg
MgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0
P?ooool2o`0002;ooooo1Ol0002Pooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0M_ooool2o`0002;ooooo0_l0
0003ooooo`;o00001_ooool2o`0001?ooooo0_l0002;ooooo`0000?oooooo`000?ooool00_ooool0
0ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0001booooo`;o00000_ooool5
o`0001oooooo0ol00002ooooo`;o00005_ooool2o`000003ooooool0003o000000Go00001?ooool2
o`0008;ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIV
I_ooool01Oooool00ol0003oooooooooo`1booooo`;o00000oooool4o`0000_ooooo0_l0000Coooo
o`;o00004?ooool2o`0000Sooooo0_l000000ooooooo0000o`000007o`0000;ooooo0_l0000Eoooo
o`;o0000Joooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool03Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo08Kooooo0_l0000Cooooo`;o00001oooool2o`0000;o
oooo0_l000000ooooooo0000o`000002o`0001;ooooo0_l00007ooooo`;o00004?ooool2o`0006_o
oooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4006
ooooo`03o`000?oooooooooo06Kooooo0_l0000=ooooo`?o00008oooool2o`0000Oooooo0_l00002
ooooo`;o000000?oooooo`000?l000000_ooool2o`00017ooooo0_l00006ooooo`;o0000OOooool0
0006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo
00?o0000ooooooooool0I_ooool2o`0000gooooo0ol0000Oooooo`;o00001oooool3o`0000Gooooo
0_l00005ooooo`Co000000?oooooo`000?l000003?ooool4o`000003ooooool0003o000000Kooooo
0_l0001hooooo`007?ooool00ol0003oooooooooo`1Fooooo`;o00004_ooool2o`0000Gooooo0_l0
00000ooooooo0000o`00000Qooooo`;o000000?oooooo`000?l000001?ooool3o`0000kooooo0_l0
00000ooooooo0000o`000005ooooo`;o00001oooool2o`000003ooooool0003o000000Kooooo0_l0
001hooooo`007?ooool00ol0003oooooooooo`1Fooooo`;o00004_ooool2o`000003ooooool0003o
000000;ooooo0_l000000ooooooo0000o`00000Tooooo`;o00001oooool2o`0000;ooooo0_l00003
ooooo`Go00001_ooool2o`0000;ooooo0ol0000<ooooo`;o00005Oooool2o`0000Oooooo0_l0001M
ooooo`007?ooool00ol0003oooooooooo`1Wooooo`;o00001?ooool2o`0002Sooooo0_l00006oooo
o`;o00000_ooool2o`000004ooooool0003o0000o`0000?ooooo1Ol00002ooooo`;o00000_ooool2
o`0000?ooooo0_l0000<ooooo`Co00000_ooool2o`0000Cooooo0_l00009ooooo`;o00001oooool2
o`0005gooooo000Looooo`03o`000?oooooooooo06Oooooo0_l0000^ooooo`?o00001Oooool2o`00
00Gooooo0_l0000;ooooo`;o00001_ooool2o`0000kooooo0ol00002ooooo`;o00001?ooool2o`00
077ooooo000Looooo`03o`000?oooooooooo05?ooooo0_l0000Booooo`;o00003oooool2o`0001ko
oooo0_l0000Eooooo`;o00002_ooool2o`0000kooooo0_l00009ooooo`;o0000LOooool001cooooo
00?o0000ooooooooool0Doooool2o`0002?ooooo0_l0000Rooooo`;o00004Oooool2o`0000Wooooo
0_l00006ooooo`;o00002_ooool2o`000003ooooool0003o000001?ooooo0_l0001Qooooo`007?oo
ool00ol0003oooooooooo`1Yooooo`;o0000<Oooool2o`0000Wooooo0_l0000Aooooo`Co00001?oo
ool2o`0000[ooooo0_l000000ooooooo0000o`000007ooooo`;o00002_ooool2o`00067ooooo000L
ooooo`03o`000?oooooooooo05Sooooo0_l0000?ooooo`;o00002Oooool2o`0000Cooooo0_l00005
ooooo`;o00009?ooool2o`0000Sooooo0_l000000ooooooo0000o`000006ooooo`;o00002?ooool3
o`0000gooooo0_l00002ooooo`;o00002_ooool2o`00067ooooo000Looooo`03o`000?oooooooooo
05Sooooo1?l0000Hooooo`;o00000oooool3o`0000Gooooo0_l0000<ooooo`;o00004_ooool4o`00
00Wooooo0ol000000ooooooo0000o`00000@ooooo`?o00003?ooool3o`0000Gooooo0_l00007oooo
o`;o0000HOooool001cooooo00?o0000ooooooooool0F_ooool2o`0001Kooooo0_l00004ooooo`?o
00000_ooool2o`00013ooooo0_l00004ooooo`;o00003?ooool4o`0000Wooooo0_l0000Aooooo`;o
00004?ooool2o`0000Kooooo0_l0001Zooooo`007?ooool00ol0003oooooooooo`1Zooooo`;o0000
1_ooool2o`0000Cooooo0_l00003ooooo`;o00005_ooool4o`0000gooooo0ol0000Jooooo`;o0000
0oooool2o`0000[ooooo0_l0001cooooo`007?ooool2o`0005Kooooo0_l0000=ooooo`;o00001?oo
ool2o`0000Wooooo0_l00002ooooo`?o00003Oooool5o`0000Sooooo0ol0000=ooooo`?o00006Ooo
ool2o`000004ooooool0003o0000ooooo`Co00002?ooool2o`0007?ooooo000Looooo`03o`000?oo
oooooooo05Gooooo0_l0000=ooooo`;o00002_ooool2o`0000?ooooo0_l00002ooooo`Go000000?o
ooooo`000?l000002?ooool5o`0001kooooo0_l00008ooooo`;o00002_ooool2o`000003ooooool0
003o000000?ooooo0_l00009ooooo`;o00001_ooool4o`0006Sooooo000Looooo`03o`000?oooooo
oooo05_ooooo0_l0000Cooooo`_o000000?oooooo`000?l000000ol00008ooooo`;o00001oooool3
o`0000Oooooo0_l0000>ooooo`;o00002?ooool2o`0000Kooooo1_l0000@ooooo`?o00001_ooool4
o`0000;ooooo0_l0001Tooooo`007?ooool00ol0003oooooooooo`1Kooooo`;o00004?ooool2o`00
0003ooooool0003o000000Wo00000_ooool3o`0000;ooooo0_l0000;ooooo`;o000000?oooooo`00
0?l000000ol00005ooooo`;o00003oooool2o`0000oooooo1_l000000ooooooo0000o`000002o`00
00_ooooo0_l0000=ooooo`;o0000I?ooool001cooooo00?o0000ooooooooool0J?ooool2o`0000?o
oooo0_l0000Aooooo`Go00002_ooool2o`0000Cooooo0_l00005ooooo`;o00003oooool2o`0000_o
oooo1?l00007ooooo`Co00006Oooool2o`0006Gooooo000Looooo`03o`000?oooooooooo06Sooooo
0_l0000<ooooo`;o00002?ooool2o`000003ooooool0003o000003Gooooo1?l00009ooooo`Co0000
1_ooool2o`0000oooooo0_l0001Uooooo`007?ooool00ol0003oooooooooo`1^ooooo`;o00000_oo
ool2o`0000;ooooo0_l00003ooooo`;o00001oooool2o`0000;ooooo0_l000000ooooooo0000o`00
0005ooooo`;o00006oooool2o`0001Sooooo0_l00006ooooo`;o00003oooool3o`0006Cooooo000L
ooooo`03o`000?oooooooooo05kooooo0_l0000>ooooo`;o00000_ooool4o`0000Gooooo0_l00005
ooooo`Co00000_ooool2o`000003ooooool0003o000000;o00000oooool2o`0000Gooooo0_l00009
ooooo`;o00001oooool4o`0000Sooooo0_l0000@ooooo`;o00000_ooool2o`000003ooooool0003o
000000Sooooo0_l00002ooooo`;o000000?oooooo`000?l00000I?ooool001cooooo00?o0000oooo
ooooool0G_ooool2o`0001?ooooo0ol00006ooooo`;o00000oooool8o`0000Cooooo0_l0000:oooo
o`;o00001_ooool2o`000003ooooool0003o000000Oooooo0_l0000:ooooo`;o00000oooool2o`00
0003ooooool0003o000000Kooooo2?l000000ooooooo0000o`000002o`0000Cooooo2?l00002oooo
o`;o0000Hoooool001cooooo00?o0000ooooooooool0Eoooool2o`0000Kooooo0_l0000Booooo`;o
00001oooool2o`0000?ooooo1?l000000ooooooo0000o`000003o`0000?ooooo0_l00002ooooo`;o
00003?ooool3o`0001Gooooo0_l00004ooooo`;o000000?oooooo`000?l000001_ooool7o`0000Co
oooo0_l00004ooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`00001Pooooo`00
7?ooool00ol0003oooooooooo`1Gooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`;o
00001?ooool2o`0000Wooooo0_l0000Dooooo`;o00000oooool2o`0000;ooooo1Ol00003ooooo`;o
00001?ooool4o`0001Cooooo0_l00007ooooo`;o00001?ooool2o`0000?ooooo1_l0000Booooo`Go
00001?ooool2o`0005[ooooo000Looooo`03o`000?oooooooooo05cooooo0_l00004ooooo`Co0000
0_ooool2o`0000Wooooo0_l0000Iooooo`;o00001?ooool4o`000004ooooool0003o0000o`0000Ko
oooo0_l0000Mooooo`;o00001?ooool2o`0000Oooooo0_l0000=ooooo`;o00000_ooool4o`0000Ko
oooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00004?ooool2o`0000Gooooo
1?l0000?ooooo`;o00004oooool2o`0000Kooooo3_l00003ooooo`;o00006Oooool2o`0000Kooooo
0ol0000;ooooo`;o00002Oooool2o`0000;ooooo1?l0001Rooooo`007?ooool00ol0003ooooooooo
o`14ooooo`;o00000oooool4o`0000Sooooo0_l00004ooooo`;o00001?ooool2o`0000;ooooo0_l0
000>ooooo`;o00004oooool2o`000003ooooool0003o000000;ooooo2Ol000000ooooooo0000o`00
0008o`0000_ooooo0_l00006ooooo`;o00001?ooool2o`0000Kooooo0_l0000<ooooo`Co00003Ooo
ool2o`0006;ooooo000Looooo`03o`000?oooooooooo04Cooooo0_l00005ooooo`;o00002?ooool3
o`0000Wooooo0_l00002ooooo`;o00003oooool2o`0000?ooooo0_l0000@oooooaKo00003Oooool2
o`0000Kooooo0_l0000:ooooo`;o00003_ooool4o`000003ooooool0003o000000[ooooo0_l00009
ooooo`;o0000Eoooool001cooooo00?o0000ooooooooool0E_ooool2o`0000Gooooo1?l00007oooo
o`;o00001Oooool2o`0000Gooooo1?l000000ooooooo0000o`00000Boooooa;o00005?ooool2o`00
00gooooo0_l00004ooooo`;o00002oooool4o`0000Kooooo0_l00004ooooo`?o00001_ooool2o`00
05Oooooo000Looooo`;o0000@?ooool2o`0001;ooooo0_l00008ooooo`Co00001oooool2o`0000Co
oooo0ol00007ooooo`;o00005OoooolBo`00013ooooo0_l00002ooooo`;o00004oooool2o`0000_o
oooo0ol00007ooooo`;o00000oooool4o`0000_ooooo0_l0001Booooo`007?ooool00ol0003ooooo
ooooo`0oooooo`;o00004_ooool2o`0000gooooo0_l00006ooooo`;o00000_ooool2o`0000Kooooo
0ol0000Goooooa7o000000?oooooo`000?l000001oooool2o`0000Cooooo0_l0000Uooooo`;o0000
1oooool2o`0000?ooooo0_l0000=ooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0?ooo
ool2o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l000003?ooool3o`0000Cooooo0_l0
00000ooooooo0000o`000003ooooo`;o00002_ooool3o`000004ooooool0003o0000o`0000_ooooo
0_l00003oooooaOo00001oooool2o`0002oooooo0_l00004ooooo`;o00000_ooool4o`000003oooo
ool0003o000005cooooo000Looooo`03o`000?oooooooooo03Oooooo0_l0000:ooooo`;o00001Ooo
ool2o`000003ooooool0003o000000Sooooo0_l00002ooooo`?o00001oooool2o`0000kooooo1?l0
00001?oooooo0000o`000?l00002ooooo`;o00001oooool4o`000003ooooool0003o000001?o0000
8oooool2o`0000Cooooo0_l00003ooooo`;o00002?ooool4o`0000;ooooo1?l00002ooooo`Co0000
00?oooooo`000?l000000_l0001Jooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00005?oo
ool2o`000003ooooool0003o000000Cooooo0ol00003ooooo`;o00002?ooool2o`0000Cooooo0_l0
0007ooooo`Co000000?oooooo`000?l000000oooool2o`0000?ooooo0_l00004ooooo`;o000000?o
ooooo`000?l000005?l0000Rooooo`;o00001?ooool2o`0000?ooooo0_l00008ooooo`Co00000_oo
ool3o`0000[ooooo0_l0000=ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0>Oooool2
o`0001;ooooo0_l000000ooooooo0000o`000004ooooo`;o00001_ooool3o`0000Gooooo0_l00004
ooooo`;o00004?ooool2o`0000Cooooo0_l00007oooooaOo00008Oooool2o`0000?ooooo0_l0000E
ooooo`;o000000?oooooo`000?l000002oooool2o`0000Wooooo0_l0001;ooooo`007?ooool00ol0
003oooooooooo`0iooooo`;o00006oooool2o`0000Gooooo1?l00002ooooo`;o00001oooool2o`00
00oooooo1?l00006ooooo`;o00001OoooolFo`00027ooooo0_l00003ooooo`;o00002?ooool2o`00
00;ooooo0_l00004ooooo`;o00001?ooool2o`000003ooooool0003o000000Sooooo0_l0001Foooo
o`007?ooool00ol0003oooooooooo`1=ooooo`;o000000?oooooo`000?l000000_ooool4o`0000Go
oooo0_l000001?oooooo0000o`000?ooool2o`0000Oooooo0ol0000>ooooo`Co00001_ooool2o`00
00Gooooo5Ol0000@ooooo`;o00004oooool2o`0000[ooooo0_l00002ooooo`;o000000Coooooo`00
0?l0003ooooo0_l00007ooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0COooool2o`00
0004ooooool0003o0000ooooo`?o00001oooool2o`000003ooooool0003o000000_ooooo0_l00002
ooooo`;o00001Oooool3o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`;o00001OoooolF
o`0000oooooo1?l0000Aooooo`;o00003_ooool2o`000003ooooool0003o000000;o00001Oooool2
o`000003ooooool0003o0000063ooooo000Looooo`03o`000?oooooooooo04Kooooo0_l000000ooo
oooo0000o`000007ooooo`?o00002?ooool2o`0000Gooooo0_l00007ooooo`Oo00001?ooool3o`00
00;ooooo0_l000000ooooooo0000o`000005ooooo`;o00000oooool3o`000003ooooool0003o0000
01;o00004?ooool3o`0000Cooooo0_l0000Nooooo`Co00001Oooool5o`000003ooooool0003o0000
00Oooooo0ol0000=ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0A_ooool2o`000003
ooooool0003o000000Oooooo0_l0000=ooooo`;o000000?oooooo`000?l000001_ooool2o`000004
ooooool0003o0000ooooo`?o00000oooool2o`0000Kooooo0_l0000:ooooo`?o000000?oooooo`00
0?l000003ol000000ooooooo0000o`000009ooooo`;o00001Oooool2o`0000Gooooo0_l0000Noooo
o`Co00001_ooool4o`000003ooooool0003o000000Gooooo1ol0000;ooooo`;o000000?oooooo`00
0?l00000@Oooool001cooooo00?o0000ooooooooool0@?ooool2o`0001Sooooo0_l00005ooooo`;o
00002Oooool5o`0000;ooooo0_l00003ooooo`;o00001?ooool4o`0000[ooooo0_l00002ooooo`So
000000?oooooo`000?l000001_l000000ooooooo0000o`000009ooooo`?o00002oooool2o`0001go
oooo0ol000000ooooooo0000o`000005ooooo`Ko00000_ooool2o`0000;ooooo0_l00003ooooo`?o
00000oooool2o`0000Sooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`10ooooo`Co0000
2?ooool4o`0000[ooooo0_l00002ooooo`Ko00002Oooool3o`000003ooooool0003o000000_ooooo
0ol0000=oooooa?o00002Oooool2o`0000;ooooo0_l0000Zooooo`;o00000_ooool2o`0000Cooooo
3Ol00004ooooo`Co00000oooool2o`0004_ooooo000Looooo`03o`000?oooooooooo04;ooooo0_l0
0008ooooo`Co00001_ooool2o`0000Kooooo1_l00002ooooo`;o00001?ooool2o`0000?ooooo0ol0
0005ooooo`;o00001?ooool2o`0000Cooooo0ol00004oooooaKo00001_ooool4o`0000_ooooo0_l0
000Oooooo`;o00001?ooool4o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o000000Co
ooooo`000?l0003o00001?ooool2o`0005;ooooo000Looooo`03o`000?oooooooooo05Kooooo0_l0
0007ooooo`;o00001Oooool2o`0000;ooooo1?l00004ooooo`;o00001Oooool2o`0000[ooooo0ol0
0004ooooo`;o00000_ooool?o`000003ooooool0003o000000Kooooo0_l0000<ooooo`?o00004Ooo
ool2o`0000Kooooo0_l00003ooooo`?o00001?ooool4o`0000Sooooo0_l0001Mooooo`007?ooool0
0ol0003oooooooooo`1>ooooo`;o00000oooool2o`0000[ooooo0_l00004ooooo`Co000000Cooooo
o`000?l0003o00000_ooool2o`0000?ooooo0_l0000=ooooo`;o00001?ooool2o`0000Gooooo3_l0
00000ooooooo0000o`00000Eooooo`;o00004_ooool2o`0000Kooooo0_l00003ooooo`;o00001Ooo
ool2o`0000Oooooo0_l000001?oooooo0000o`000?l00004ooooo`Go00002oooool2o`0004Kooooo
000Looooo`;o0000B_ooool2o`0000?ooooo0_l00003ooooo`;o00000oooool2o`0000_ooooo1?l0
0006ooooo`;o00000oooool2o`0000Sooooo0_l00002ooooo`Co00000oooool2o`0000Gooooo2?l0
0002ooooo`Co000000?oooooo`000?l000002?ooool2o`0000Sooooo0_l00002ooooo`;o00001ooo
ool2o`0001?ooooo0_l00007ooooo`;o00001oooool2o`0000;ooooo0_l00004ooooo`Go00002ooo
ool2o`0004Kooooo000Looooo`03o`000?oooooooooo03oooooo0_l00004ooooo`;o00000_ooool2
o`0000Sooooo0_l00003ooooo`;o00002_ooool5o`0000Oooooo0_l00002ooooo`;o00002?ooool8
o`0000[ooooo3?l0000=ooooo`;o00002?ooool2o`0000;ooooo0_l00004ooooo`;o000000?ooooo
o`000?l000004oooool2o`0000Oooooo0_l0000:ooooo`;o00002_ooool2o`000003ooooool0003o
000004kooooo000Looooo`03o`000?oooooooooo03oooooo0_l00004ooooo`;o00000_ooool2o`00
0003ooooool0003o000000?ooooo1?l0000?ooooo`;o00000_ooool6o`0000;ooooo0_l00002oooo
o`?o00001_ooool2o`000003ooooool0003o000000?ooooo0ol00003ooooo`Co00001?ooool7o`00
01Kooooo1?l00009ooooo`;o00000oooool2o`0001Kooooo1?l00007ooooo`;o00000oooool2o`00
0003ooooool0003o000000?o00001?ooool2o`000003ooooool0003o000000cooooo0_l00010oooo
o`007?ooool00ol0003oooooooooo`16ooooo`;o00001?ooool2o`0000?ooooo1_l0000Aooooo`Ko
00001Oooool4o`0000Kooooo0_l00006ooooo`?o00000oooool5o`0000?ooooo1?l00002ooooo`;o
00005Oooool4o`0000cooooo1?l00009ooooo`;o00002Oooool6o`0000Oooooo0_l00006ooooo`Go
00001Oooool3o`0000gooooo0_l0000<ooooo`;o0000<_ooool001cooooo00?o0000ooooooooool0
>oooool2o`0000Wooooo0ol000000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l00000
0_l00007ooooo`;o00002oooool2o`0000?ooooo1?l00002ooooo`;o00001Oooool4o`0000Gooooo
0_l00002ooooo`;o000000?oooooo`000?l000001_l00002ooooo`?o00007oooool4o`000003oooo
ool0003o000000So00001?ooool4o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000
o`00000?ooooo`;o00001?ooool2o`0000?ooooo1?l0000Jooooo`;o0000<_ooool001cooooo00?o
0000ooooooooool0>oooool2o`0000[ooooo0_l000000ooooooo0000o`00000:ooooo`;o00001ooo
ool4o`0000Wooooo0_l00003ooooo`;o00001?ooool3o`0000Cooooo1?l00005ooooo`;o00001Ooo
ool8o`0000;ooooo0_l0000Mooooo`_o000000?oooooo`000?l000003?l000000ooooooo0000o`00
0007ooooo`;o00003oooool2o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o00000_oo
ool2o`0000;ooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`0kooooo`;o00003?ooool2
o`000003ooooool0003o000001?ooooo1?l00007ooooo`;o00000oooool2o`0000Cooooo0ol0000;
ooooo`;o00009?ooool2o`0000Oooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o
000000Ko00000_ooool:o`0000?ooooo0_l0000Pooooo`;o00001?ooool4o`0000;ooooo0_l00016
ooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00000oooool4o`0000[ooooo0_l000000ooo
oooo0000o`000003ooooo`Co00000oooool8o`000003ooooool0003o000000;o00003?ooool2o`00
00Cooooo0_l0000:ooooo`Co00000_ooool3o`0001oooooo0_l00005ooooo`Co00000_oooolIo`00
00;ooooo0_l0000Vooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0=_ooool2o`000003
ooooool0003o000000;ooooo0_l00006ooooo`;o00002_ooool4o`0000?ooooo2?l000000ooooooo
0000o`00000Pooooo`?o00000oooool3o`000003ooooool0003o000000?ooooo0_l0000Eooooo`;o
00001oooool2o`0000Cooooo5?l000000ooooooo0000o`000002o`0001;ooooo0_l00006ooooo`;o
0000G?ooool001cooooo00?o0000ooooooooool0>Oooool2o`0000Sooooo1?l00002ooooo`;o0000
1oooool2o`0000Sooooo0_l000000ooooooo0000o`000004o`0000Cooooo0_l0000Fooooo`;o0000
00?oooooo`000?l000001oooool2o`0000?ooooo0_l0000Eooooo`?o00001?ooool4o`0000;ooooo
4Ol00002ooooo`Go000000Coooooo`000?l0003o00000oooool2o`0000Wooooo0_l000001?oooooo
0000o`000?ooool2o`0000?ooooo0ol0000<ooooo`;o00001Oooool2o`0004Kooooo000Looooo`03
o`000?oooooooooo04?ooooo0_l00004ooooo`?o00001_ooool2o`0000?ooooo0_l00003ooooo`;o
000000?oooooo`000?l000001?l00004ooooo`;o00000_ooool2o`0000kooooo0_l00002ooooo`;o
00008_ooool2o`0000?ooooo0_l00004ooooo`Go000000?oooooo`000?l000007?l000000ooooooo
0000o`000009ooooo`;o00000oooool3o`0000?ooooo0ol0000<ooooo`;o00000oooool4o`0004Ko
oooo000Looooo`03o`000?oooooooooo047ooooo0_l00003ooooo`;o000000Coooooo`000?l0003o
00002oooool2o`0001Cooooo0_l0000>ooooo`;o00003_ooool2o`0001?ooooo1Ol00009ooooo`_o
000000?oooooo`000?l000002ol000000ooooooo0000o`00000:o`0000Cooooo0_l00006ooooo`;o
000000?oooooo`000?l000005oooool3o`0004Sooooo000Looooo`03o`000?oooooooooo047ooooo
0_l00002ooooo`?o00001_ooool2o`0000?ooooo1?l00002ooooo`;o00003Oooool2o`0000oooooo
0_l000000ooooooo0000o`000005ooooo`;o00002?ooool2o`0001?ooooo1?l00009ooooo`?o0000
0_oooolBo`000003ooooool0003o000000ko00000oooool2o`0000Kooooo0_l0000Jooooo`;o0000
00?oooooo`000?l00000A_ooool001cooooo00?o0000ooooooooool0@oooool4o`0000Oooooo0_l0
00000ooooooo0000o`000004o`0000;ooooo0_l00008ooooo`;o00000oooool2o`0000?ooooo1Ol0
0007ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o0000:_ooool3o`000003ooooool0
003o000000Co000000?oooooo`000?l000002ol000000ooooooo0000o`00000=o`00017ooooo0_l0
000:ooooo`;o00002Oooool4o`0004Kooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo
0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`13ooooo`;o0000
2Oooool2o`000003ooooool0003o000000_ooooo0_l00003ooooo`;o00002?ooool5o`0000Oooooo
1ol00002ooooo`?o00001_ooool2o`00027ooooo0_l00003ooooo`;o00000_ooool2o`000003oooo
ool0003o000001go00001_ooool3o`0000Kooooo0_l0000:ooooo`;o00002Oooool2o`0004Sooooo
00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0@_ooool2o`0000Gooooo0ol00002ooooo`;o00000_ooool2o`0000So
oooo1?l00004ooooo`;o00000_ooool4o`0000oooooo0ol00004ooooo`?o00000oooool2o`000004
ooooool0003o0000o`0000[ooooo0ol0000<ooooo`Co00000oooool2o`0000;ooooo1?l000000ooo
oooo0000o`000003ooooo`Oo00000_ooool>o`000003ooooool0003o000000?o00001_ooool3o`00
00;ooooo0_l0000Hooooo`Co0000Aoooool00003ooooool@413ooooo00;ooooo00?o410@oooooooo
ool02Oooool5o`0000Kooooo00?o0000ooooooooool0@_ooool2o`0000Gooooo0ol00006ooooo`;o
00001?ooool2o`000003ooooool0003o000000;o00001Oooool2o`0000;ooooo1?l0000=ooooo`;o
00002?ooool4o`000003ooooool0003o000000;ooooo0_l00005ooooo`;o00000oooool3o`0000[o
oooo1_l00003ooooo`So00001_oooolGo`000003ooooool0003o000000?o00002oooool2o`0001So
oooo1_l00015ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04odA4
A?oMgMgoooooo`0000Oooooo0ol00012ooooo`;o00005?ooool7o`0000Kooooo1?l00008ooooo`?o
00001Oooool2o`0000Sooooo1?l00002ooooo`;o00002?ooool2o`0000_ooooo0_l00003ooooo`;o
00001oooool8o`0000Kooooo7Ol00003ooooo`;o00004_ooool2o`0000gooooo0_l000001?oooooo
0000o`000?l00014ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04
omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0>_ooool2o`0001kooooo0_l000000ooo
oooo0000o`000002o`0000Cooooo1?l00007ooooo`Ko00002oooool5o`0000?ooooo1Ol0000Boooo
o`;o00001?ooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool4o`0000Kooooo7Ol00003
ooooo`;o00004_ooool2o`0000Sooooo0_l00007ooooo`;o00003Oooool2o`0003Gooooo00000ooo
oooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oMgMgolc<c?l000001oooool00ol0
003oooooooooo`0Pooooo`;o00006?ooool3o`0001[ooooo0_l00006ooooo`;o00002_ooool2o`00
00?ooooo2Ol00002ooooo`?o000000?oooooo`000?l000001Ol00004ooooo`Co00006?ooool2o`00
00Cooooo1Ol0000<oooooaco00001_ooool2o`0000cooooo0_l000000ooooooo0000o`000007oooo
o`?o00001oooool4o`0000_ooooo0_l0000eooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<
ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool08?ooool2o`0000kooooo0_l00009
ooooo`;o00004?ooool2o`000003ooooool0003o000000Gooooo0_l00007ooooo`;o00001_ooool2
o`000003ooooool0003o000000Gooooo0_l000000ooooooo0000o`000007o`000003ooooool0003o
000000Go00001?ooool2o`0000;ooooo0_l0000Mooooo`;o00003_oooolMo`0000Gooooo0_l0000<
ooooo`;o000000?oooooo`000?l000001oooool2o`0000;ooooo1?l00002ooooo`Co00002Oooool2
o`000003ooooool0003o000003Cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPgooooo00?o
MgMgo`000?ooool01_ooool00ol0003oooooooooo`0`ooooo`;o00005oooool2o`0000;ooooo1Ol0
0007ooooo`Co00000oooool2o`0000Kooooo0_l00002ooooo`;o00000oooool3o`0000;ooooo0_l0
00000ooooooo0000o`000003o`0000Gooooo1Ol000001?oooooo0000o`000?l00002ooooo`;o0000
5?ooool2o`0000Gooooo0ol00003ooooo`;o000000?oooooo`000?l000001ooooolMo`0000Wooooo
1?l00009ooooo`;o00002oooool4o`0000oooooo0_l000000ooooooo0000o`00000dooooo`007?oo
ool00ol0003oooooooooo`19ooooo`Co000000?oooooo`000?l000000_l00007ooooo`Co00002ooo
ool2o`0000;ooooo0ol00002ooooo`?o000000Coooooo`000?l0003o00001?ooool2o`000003oooo
ool0003o000000Gooooo1_l00002ooooo`;o00001?ooool2o`000003ooooool0003o000000_ooooo
0_l00005ooooo`?o00000oooool2o`000003ooooool0003o000000Sooooo6?l000000ooooooo0000
o`000002o`0000Sooooo1?l0000Dooooo`Go0000BOooool001cooooo00?o0000ooooooooool0?_oo
ool2o`0000?ooooo0_l00006ooooo`;o000000?oooooo`000?l000000_l00007ooooo`;o00004_oo
ool;o`0000?ooooo1_l00002ooooo`?o000000Coooooo`000?l0003ooooo0_l00002ooooo`Co0000
0_ooool2o`000003ooooool0003o000001;ooooo0_l0000;ooooo`;o00000_oooolOo`0000Cooooo
0_l00006ooooo`;o00004_ooool4o`0004[ooooo000Looooo`03o`000?oooooooooo03cooooo1?l0
0003ooooo`;o00006?ooool2o`0000Oooooo0_l00005ooooo`Wo00000oooool6o`0000;ooooo2ol0
0003ooooo`?o00002oooool2o`0000cooooo0_l00007ooooo`;o00000_ooool2o`0000;ooooo6?l0
00000ooooooo0000o`000003o`0000Gooooo0_l00006ooooo`;o00001_ooool2o`0005Sooooo000L
ooooo`03o`000?oooooooooo03cooooo0_l00005ooooo`;o00002Oooool2o`0000Sooooo0_l00003
ooooo`;o00001oooool2o`0000Gooooo1?l000000ooooooo0000o`00000:o`0000;ooooo1Ol00000
0ooooooo0000o`000005o`0000?ooooo0_l00004ooooo`;o00001Oooool2o`0000_ooooo1_l00004
ooooo`;o00002OoooolAo`000003ooooool0003o000000Ko000000?oooooo`000?l000000_l00002
ooooo`;o00003Oooool2o`0001Gooooo0_l00007ooooo`;o00001_ooool2o`00033ooooo000Loooo
o`03o`000?oooooooooo04?ooooo1?l000000ooooooo0000o`000002o`0000;ooooo0_l00003oooo
o`;o00000oooool2o`0000?ooooo0_l0000:ooooo`?o00001?ooool>o`0000;ooooo1Ol000000ooo
oooo0000o`000005o`0000Wooooo0_l00003ooooo`Co00001?ooool4o`0000?ooooo2?l0000:oooo
o`;o00000_ooool@o`000003ooooool0003o000000Go00000_ooool4o`0000;ooooo0_l0000=oooo
o`;o00001oooool2o`0000Gooooo1Ol00002ooooo`;o00001_ooool3o`0000Kooooo0_l0000`oooo
o`007?ooool00ol0003oooooooooo`0Yooooo`;o00006Oooool3o`000003ooooool0003o000000;o
00001oooool2o`0001?ooooo2ol000000ooooooo0000o`00000Bo`0000[ooooo0_l00007ooooo`Co
00000oooool5o`0000?ooooo0ol00003ooooo`;o00002_ooool2o`0000?ooooo5ol00004ooooo`Co
00006?ooool2o`0000?ooooo1ol0000:ooooo`Co0000=oooool001cooooo00?o0000ooooooooool0
:Oooool2o`0000kooooo0_l00008ooooo`?o00000_ooool2o`0000Wooooo0_l0000>ooooo`;o0000
00?oooooo`000?l000008?l0000:ooooo`;o00001oooool2o`0000?ooooo1?l00006ooooo`;o0000
5_ooool2o`0000?ooooo4Ol00004ooooo`Co00000oooool2o`0001Sooooo0_l00004ooooo`;o0000
0_ooool2o`0000Oooooo0_l0000gooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00002?oo
ool3o`0000;ooooo0_l00003ooooo`;o00001?ooool2o`0000Sooooo0_l00004ooooo`;o000000?o
ooooo`000?l000000ol00002oooooa[o000000Coooooo`000?l0003ooooo1Ol0000;ooooo`;o0000
0oooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o00000oooool2o`0000Sooooo
0_l00007ooooo`_o000000?oooooo`000?l000000_l000000ooooooo0000o`000007ooooo`?o0000
0oooool4o`0000gooooo1?l0000;ooooo`;o00000_ooool2o`0000Gooooo0_l0000iooooo`007?oo
ool00ol0003oooooooooo`0hooooo`;o00001Oooool2o`0000Cooooo0_l00006ooooo`;o00003_oo
ool2o`0000?ooooo1Ol000001?oooooo0000o`000?oooolUo`0000;ooooo0_l0000?ooooo`;o0000
0_ooool2o`0000;ooooo0ol00002ooooo`?o00001oooool2o`0000Oooooo2ol000001?oooooo0000
o`000?l00006ooooo`Oo00001?ooool5o`0000Kooooo0_l00004ooooo`Co00005_ooool2o`0003Wo
oooo000Looooo`03o`000?oooooooooo03Sooooo0_l00005ooooo`;o00001?ooool2o`0001_ooooo
1Ol000000ooooooo0000o`00000No`000003ooooool0003o000000;o00001Oooool4o`0000Wooooo
0_l000000ooooooo0000o`000003ooooo`Oo00000oooool3o`0000Sooooo0_l00009ooooo`Co0000
2?ooool2o`0000?ooooo1ol00002ooooo`?o00000_ooool2o`0000Kooooo0ol0001Hooooo`007?oo
ool00ol0003oooooooooo`10ooooo`;o00002Oooool4o`0000Wooooo0_l00008ooooo`Go000000?o
ooooo`000?l000003_l000000ooooooo0000o`00000Bo`0000Oooooo0_l00009ooooo`;o000000?o
ooooo`000?l000001Oooool4o`0000Gooooo0_l00008ooooo`;o00005Oooool3o`0000_ooooo0ol0
000;ooooo`Co00007_ooool2o`0003Kooooo000Looooo`;o0000@Oooool2o`0000Wooooo1_l00007
ooooo`?o00001OoooolHo`000003ooooool0003o000001So00002oooool2o`0000Gooooo0_l00004
ooooo`?o00001?ooool2o`0000gooooo0_l0000Aooooo`;o00003?ooool2o`0000gooooo0_l0000N
ooooo`;o0000=_ooool001cooooo00?o0000ooooooooool0>oooool2o`0000?ooooo0_l0000:oooo
o`;o000000?oooooo`000?l000002?ooool2o`000003ooooool0003o000000;ooooo0ol000000ooo
oooo0000o`000004o`000003ooooool0003o000002Ko00001_ooool2o`0000?ooooo1?l00003oooo
o`Co00000_ooool3o`000004ooooool0003o0000ooooo`;o00001_ooool2o`0000Gooooo0_l0000;
ooooo`;o00005_ooool2o`00013ooooo0_l00004ooooo`;o0000BOooool001cooooo00?o0000oooo
ooooool0>oooool2o`0000?ooooo0_l00004ooooo`;o00001?ooool2o`0000_ooooo0_l000000ooo
oooo0000o`000002ooooo`;o000000?oooooo`000?l000000_l00002ooooo`Ko00000_oooolPo`00
00Kooooo1?l00005ooooo`;o00001Oooool7o`000003ooooool0003o000000Wooooo0_l0000=oooo
o`;o00000oooool2o`0000Cooooo0_l00005ooooo`;o00002Oooool2o`0000;ooooo0ol000000ooo
oooo0000o`000002ooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`;o0000@oooool001co
oooo00?o0000ooooooooool09oooool2o`0001gooooo0_l0000Aooooo`;o00001_ooool^o`0000?o
oooo0_l00003ooooo`;o00001?ooool2o`0000[ooooo1Ol0000Eooooo`;o00001?ooool2o`0000Go
oooo0_l00002ooooo`;o00001Oooool3o`0000cooooo0ol000000ooooooo0000o`000002ooooo`;o
00004?ooool2o`0004?ooooo000Looooo`03o`000?oooooooooo02Oooooo0_l0000Booooo`;o0000
3?ooool2o`0000Oooooo0_l00006ooooo`;o00001Oooool`o`000003ooooool0003o000000Wooooo
0_l0000=ooooo`Go00000oooool2o`0000gooooo0_l0000;ooooo`Go00001oooool2o`0000Kooooo
0ol00002ooooo`Co00004oooool2o`0000;ooooo0ol00009ooooo`;o00001Oooool3o`0002oooooo
000Looooo`03o`000?oooooooooo03_ooooo0_l0000<ooooo`Co00001Oooool2o`000004ooooool0
003o0000o`0000;ooooo0_l00005ooooo`Go000000?oooooo`000?l00000:?l00002ooooo`;o0000
2Oooool2o`0000gooooo1?l00003ooooo`;o00003oooool2o`0000Wooooo1Ol0000?ooooo`?o0000
0_ooool4o`0000Gooooo0_l000000ooooooo0000o`000002ooooo`;o00001Oooool2o`0000?ooooo
0_l00009ooooo`;o00001Oooool3o`0002oooooo000Looooo`03o`000?oooooooooo04_ooooo0_l0
0007ooooo`Co00000_ooool2o`0000Cooooo0ol00002ooooo`;o000000?oooooo`000?l000009_l0
0003ooooo`;o00002Oooool2o`0000kooooo0_l000001?oooooo0000o`000?l00004ooooo`;o0000
0oooool2o`0000?ooooo0_l000000ooooooo0000o`000009ooooo`Co00005Oooool2o`0000?ooooo
0_l00002ooooo`Go00000_ooool4o`0000Cooooo0_l0000Dooooo`;o0000<?ooool001cooooo00?o
0000ooooooooool0=Oooool2o`0001gooooo0_l00004ooooo`;o00000_ooool4o`0000?ooooo9Ol0
00000ooooooo0000o`000004ooooo`;o00006?ooool4o`0000;ooooo1?l00003ooooo`;o00000ooo
ool2o`0000?ooooo0ol0000=ooooo`?o000000?oooooo`000?l000000_l00008ooooo`?o00002Ooo
ool2o`0000Cooooo1?l00003ooooo`;o00001?ooool3o`000003ooooool0003o000004;ooooo000L
ooooo`03o`000?oooooooooo03Gooooo0_l0000:ooooo`;o00001Oooool2o`0001Cooooo1?l00005
ooooo`;o000000?oooooo`000?l000008Ol00004ooooo`;o00005_ooool6o`0000;ooooo1ol0000;
ooooo`;o00003_ooool2o`000003ooooool0003o000000;o00002?ooool4o`0000kooooo1?l0000:
ooooo`;o000000?oooooo`000?l000003oooool2o`00037ooooo000Looooo`03o`000?oooooooooo
03Gooooo0_l00003ooooo`?o00001?ooool2o`0000Gooooo0_l0000=ooooo`;o00002_oooolTo`00
0003ooooool0003o000000?o000000?oooooo`000?l000005Oooool2o`0000;ooooo0_l00009oooo
o`Co000000?oooooo`000?l000001oooool2o`0001;ooooo0_l0000<ooooo`;o00001_ooool2o`00
00Sooooo0_l00009ooooo`;o00001?ooool2o`0000gooooo0_l00009ooooo`;o00009_ooool001co
oooo00?o0000ooooooooool09Oooool2o`0000kooooo0_l00003ooooo`?o00000_ooool2o`0000Oo
oooo1_l00002ooooo`?o00001?ooool2o`0000Kooooo0ol000000ooooooo0000o`00000Do`000003
ooooool0003o000001Co00000_ooool2o`00017ooooo0_l0000Booooo`Oo00000_ooool2o`0001;o
oooo0_l0000>ooooo`;o00001?ooool2o`0000Sooooo1?l00003ooooo`;o00000_ooool2o`0000Co
oooo0_l00007ooooo`;o00003oooool2o`0002Kooooo000Looooo`03o`000?oooooooooo01oooooo
0_l00004ooooo`;o00005Oooool2o`000003ooooool0003o000000?ooooo0_l00002ooooo`Ko0000
0_ooool3o`0000Cooooo0_l00005ooooo`Co00001?oooolCo`000003ooooool0003o000001?o0000
0oooool4o`0000_ooooo0_l00008ooooo`;o00003Oooool7o`0000Wooooo0_l0000Jooooo`;o0000
0_ooool2o`000003ooooool0003o000000Sooooo0ol00003ooooo`;o00001Oooool2o`0000[ooooo
0_l0000gooooo`007?ooool00ol0003oooooooooo`0Oooooo`;o00003oooool2o`0000[ooooo0_l0
00000ooooooo0000o`000003ooooo`;o00004Oooool2o`0000Gooooo0_l00004ooooob_o00001?oo
ool3o`0000_ooooo0_l00008ooooo`Co00001oooool2o`0000;ooooo0_l00002ooooo`?o000000?o
ooooo`000?l000001_ooool2o`0000Kooooo0ol0000Eooooo`;o000000?oooooo`000?l000001_oo
ool2o`0000;ooooo0_l00002ooooo`;o00000oooool5o`0000?ooooo0_l0000:ooooo`;o0000<Ooo
ool001cooooo00?o0000ooooooooool0<?ooool2o`0000oooooo0_l00007ooooo`;o00002_ooool2
o`000003ooooool0003o000000Wooooo0_l00003ooooobCo00001Oooool5o`0001Kooooo1?l00005
ooooo`;o00002_ooool2o`0000kooooo0ol0000Pooooo`;o00000_ooool2o`0000Oooooo0_l00000
0ooooooo0000o`000003ooooo`;o00000_ooool2o`0000Kooooo0_l00003ooooo`;o0000;?ooool0
01cooooo00?o0000ooooooooool0?_ooool2o`000003ooooool0003o000000Co00000oooool2o`00
00Sooooo1ol00003ooooo`;o00001_ooool5o`000003ooooool0003o0000023o000000Coooooo`00
0?l0003ooooo0_l000000ooooooo0000o`000005ooooo`;o00000oooool2o`0000Wooooo0_l00000
0ooooooo0000o`00000;ooooo`;o00001?ooool2o`0000;ooooo0_l00002ooooo`;o00008_ooool2
o`0000Wooooo0_l00006ooooo`;o00002oooool2o`0000_ooooo0_l0000/ooooo`007?ooool00ol0
003oooooooooo`0fooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0000?ooooo1?l0000=
ooooo`;o00000_ooool3o`0000?ooooo1?l00004ooooob7o00000_ooool5o`000003ooooool0003o
000000?ooooo0_l00005ooooo`?o00000oooool2o`0000Wooooo0_l0000>ooooo`;o000000Cooooo
o`000?l0003ooooo0_l00002ooooo`;o00000_ooool2o`0000[ooooo0_l0000Eooooo`?o000000?o
ooooo`000?l000001?ooool4o`0000Kooooo0_l00004ooooo`Co0000?_ooool001cooooo0_l0000b
ooooo`?o00000_ooool2o`000004ooooool0003o0000o`0000;ooooo1?l0000?ooooo`;o00001_oo
ool2o`0000Gooooo0_l00003ooooo`;o00000_oooolDo`000003ooooool0003o000000_o00000_oo
ool3o`0000Cooooo0_l00005ooooo`?o00008Oooool4o`0000Oooooo1Ol00007ooooo`;o00005Ooo
ool2o`0000;ooooo0_l00004ooooo`;o00002Oooool2o`0000?ooooo1?l0000nooooo`007?ooool0
0ol0003oooooooooo`0aooooo`?o00002?ooool2o`0000;ooooo0ol0000>ooooo`;o00004?ooool5
o`000003ooooool0003o0000017o000000?oooooo`000?l000003Ol000000ooooooo0000o`000002
o`0000_ooooo0_l0000Gooooo`;o00001Oooool7o`0000Oooooo1ol0000Cooooo`;o00003Oooool3
o`0000cooooo0ol00002ooooo`;o00003?ooool2o`0003;ooooo000Looooo`03o`000?oooooooooo
037ooooo0_l00009ooooo`;o00000oooool3o`0000Cooooo0_l0000?ooooo`;o00000_ooool2o`00
00?ooooo2_l000000ooooooo0000o`00000Go`000004ooooool0003o0000ooooo`;o000000?ooooo
o`000?l000000_l0000Dooooo`;o00000_ooool2o`0000[ooooo0_l00005ooooo`Co00002_ooool2
o`0000?ooooo0_l0000Cooooo`;o00003Oooool3o`0000gooooo0ol000000ooooooo0000o`00000<
ooooo`?o0000<Oooool001cooooo00?o0000ooooooooool0>Oooool2o`000003ooooool0003o0000
00Cooooo0_l00004ooooo`;o00003oooool2o`0000;ooooo0_l00002ooooo`Ko000000Coooooo`00
0?l0003o00000_oooolIo`000004ooooool0003o0000ooooo`Ko00005Oooool2o`000004ooooool0
003o0000o`0000Oooooo0_l00008ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo
0000o`000006ooooo`;o00000oooool3o`0000cooooo0_l0000>ooooo`;o00004Oooool2o`0000Oo
oooo0_l00007ooooo`;o0000<Oooool001cooooo00?o0000ooooooooool0>Oooool2o`000003oooo
ool0003o000001Kooooo0_l0000;ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo
6_l000001?oooooo0000o`000?ooool4o`0000?ooooo0_l00002ooooo`;o00004Oooool2o`0000So
oooo0_l00007ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`00
00;ooooo0_l00003ooooo`?o00000oooool2o`0000Oooooo0_l0000>ooooo`;o00001_ooool2o`00
00_ooooo0_l00005ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0?Oooool2o`0000oo
oooo0_l00004ooooo`;o00004?ooool4o`0000;ooooo2Ol000000ooooooo0000o`00000?o`0000Co
oooo0_l00004ooooo`Ko00004Oooool2o`0000_ooooo0_l00004ooooo`Co000000?oooooo`000?l0
00001oooool2o`0000cooooo0ol00005ooooo`;o000000?oooooo`000?l000005Oooool2o`0000_o
oooo0_l0000>ooooo`;o0000<Oooool001cooooo00?o0000ooooooooool0?Oooool2o`0000oooooo
0_l00009ooooo`Co00002Oooool2o`0000Cooooo6ol000000ooooooo0000o`000003o`0000?ooooo
0_l000000ooooooo0000o`000002ooooo`;o00007?ooool2o`0000Kooooo1Ol00006ooooo`;o0000
3?ooool5o`0000?ooooo0ol000000ooooooo0000o`00000Dooooo`?o00002?ooool2o`000003oooo
ool0003o000000kooooo0_l0000aooooo`007?ooool00ol0003oooooooooo`1Iooooo`Co00002Ooo
ool2o`000003ooooool0003o0000023o00001Oooool2o`0000Gooooo0_l000000ooooooo0000o`00
0005ooooo`;o00004_ooool2o`0000Gooooo1?l00008ooooo`;o00002oooool6o`0000?ooooo0_l0
0003ooooo`;o00001?ooool2o`0000[ooooo0_l000000ooooooo0000o`000008ooooo`?o000000?o
ooooo`000?l00000@Oooool001cooooo00?o0000ooooooooool0<oooool2o`0000;ooooo0_l0000N
ooooo`;o000000?oooooo`000?l000003Oooool8o`000003ooooool0003o000001Co00001?ooool2
o`000003ooooool0003o000000?o00001_ooool2o`0000Cooooo0ol0000Aooooo`;o00001?ooool5
o`0000Wooooo0_l0000;ooooo`?o00001?ooool2o`0000Gooooo0_l00004ooooo`;o00001_ooool2
o`0000;ooooo0_l000000ooooooo0000o`000008ooooo`;o0000AOooool001cooooo00?o0000oooo
ooooool0<oooool:o`0001[ooooo0_l0000;ooooo`;o000000?oooooo`000?l000000_ooool6o`00
0003ooooool0003o0000013o000000Coooooo`000?l0003ooooo0ol000000ooooooo0000o`000006
o`0000cooooo0_l0000Booooo`;o00001?ooool3o`0000;ooooo0_l00007ooooo`Ko00002?ooool2
o`0000Cooooo0_l00004ooooo`;o00002?ooool2o`0000?ooooo0_l00003ooooo`Co00001?ooool2
o`0001Oooooo0_l0000`ooooo`007?ooool00ol0003oooooooooo`0booooo`;o000000?oooooo`00
0?l000000_ooool4o`0002Oooooo0_l000001?oooooo0000o`000?l00003ooooo`?o000000?ooooo
o`000?l000001_l000000ooooooo0000o`000008o`0000Cooooo0ol00003ooooo`;o00004_ooool2
o`0000Wooooo1?l00009ooooo`;o00000oooool2o`0000Wooooo1Ol00003ooooo`;o00001oooool3
o`0000;ooooo1Ol00007ooooo`;o00002?ooool4o`000004ooooool0003o0000ooooo`;o00004ooo
ool2o`0000;ooooo0_l0000`ooooo`007?ooool00ol0003oooooooooo`0booooo`Go00002Oooool2
o`0002Kooooo0_l00005ooooo`Co000000?oooooo`000?l000001?l00002ooooo`Oo00000oooool2
o`000003ooooool0003o000000Wooooo0_l000000ooooooo0000o`000009ooooo`;o00000oooool2
o`0000Cooooo1?l00008ooooo`;o00001?ooool2o`0000Sooooo0_l00002ooooo`;o00000oooool2
o`0000Oooooo1ol000001?oooooo0000o`000?l00008ooooo`;o00000_ooool2o`0000Oooooo0_l0
0005ooooo`;o00003oooool2o`0003Cooooo000Looooo`03o`000?oooooooooo02cooooo0_l00006
ooooo`?o00002Oooool4o`0000cooooo0_l00002ooooo`;o00002oooool2o`000003ooooool0003o
000000Sooooo0ol00003ooooo`oo00000oooool3o`0000_ooooo0_l000000ooooooo0000o`000006
ooooo`;o00001_ooool2o`0000Wooooo0_l00005ooooo`;o00002Oooool2o`0000?ooooo1?l0000A
ooooo`;o00000oooool3o`0000Sooooo0_l00002ooooo`;o00003_ooool2o`0000;ooooo0_l00011
ooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00001?ooool4o`0000_ooooo0ol0000<oooo
o`;o000000Coooooo`000?l0003o00002_ooool3o`000003ooooool0003o000000Kooooo1Ol00003
ooooo`Co000000?oooooo`000?l000001_l00003ooooo`;o000000?oooooo`000?l000001oooool4
o`0000_ooooo0_l00003ooooo`;o00003?ooool2o`00013ooooo0_l000000ooooooo0000o`000002
ooooo`;o00000_ooool2o`0000Sooooo0_l00003ooooo`?o00000_ooool6o`0000[ooooo0_l00004
ooooo`?o00001_ooool2o`0000;ooooo0_l0000=ooooo`;o0000<_ooool001cooooo00?o0000oooo
ooooool0<_ooool2o`0000?ooooo0_l00008ooooo`Co00003_ooool3o`0000?ooooo0_l00005oooo
o`;o00001oooool2o`000004ooooool0003o0000ooooo`Go000000Goooooo`000?l0003o0000oooo
o`05o`000003ooooool0003o000000;ooooo0ol000000ooooooo0000o`000002ooooo`;o00000_oo
ool5o`00013ooooo0_l0000Mooooo`;o00000_ooool7o`000004ooooool0003o0000o`0000Oooooo
0_l00004ooooo`;o000000Coooooo`000?l0003ooooo1?l0000:ooooo`;o00000_ooool5o`0000Go
oooo0ol00002ooooo`;o00002oooool4o`0003;ooooo000Looooo`03o`000?oooooooooo03Oooooo
0_l00004ooooo`;o00001?ooool2o`0000Gooooo0_l00008ooooo`;o00000oooool2o`0000Cooooo
0_l00007ooooo`?o00000_ooool9o`000004ooooool0003o0000ooooo`Co00001Oooool3o`000005
ooooool0003o0000o`000?ooool00_l00002ooooo`Co00004_ooool2o`0001?ooooo0_l00006oooo
o`Go000000?oooooo`000?l000001?l000001?oooooo0000o`000?l0000@ooooo`;o00000_ooool5
o`0000cooooo1_l00004ooooo`;o00004?ooool2o`0003Cooooo000Looooo`;o0000>?ooool4o`00
00;ooooo0ol00004ooooo`;o00001?ooool2o`0000Sooooo0_l00009ooooo`;o00001oooool2o`00
00?ooooo0ol000001?oooooo0000o`000?ooool2o`000004ooooool0003o0000ooooo`Co000000?o
ooooo`000?l000000_l000000ooooooo0000o`000004o`0000Oooooo0_l00002ooooo`;o00001_oo
ool2o`0000Kooooo0_l00005ooooo`;o00003?ooool2o`0000Gooooo5?l0000Booooo`Co00001ooo
ool2o`0000Oooooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00000oooool2
o`0000Cooooo0ol0000=ooooo`;o00003?ooool2o`0000?ooooo0_l00004ooooo`?o000000?ooooo
o`000?l000001?ooool2o`0000Kooooo1_l000000ooooooo0000o`000002o`0000Sooooo1Ol00006
ooooo`;o00001?ooool2o`0000Oooooo0_l0000CoooooaCo00004oooool3o`0000Cooooo1Ol00000
0ooooooo0000o`00001Booooo`007?ooool00ol0003oooooooooo`0mooooo`?o00001Oooool2o`00
00gooooo0_l00003ooooo`Co00001?ooool3o`0000?ooooo0_l00004ooooo`?o00000_ooool2o`00
00?ooooo0_l0000:ooooo`;o00001Oooool2o`0000Kooooo0ol00008ooooo`;o00001?ooool2o`00
00Gooooo0_l00006ooooo`;o00003OoooolFo`0000Sooooo0_l00007ooooo`?o000000?oooooo`00
0?l000001?l00003ooooo`;o00004Oooool2o`0000Oooooo0_l0000fooooo`007?ooool00ol0003o
ooooooooo`0Xooooo`;o00004oooool2o`0000Gooooo0ol0000=ooooo`;o00000_ooool5o`0000?o
oooo0ol0000:ooooo`?o00000_ooool2o`0000Kooooo0_l00002ooooo`;o00000_ooool2o`0000Ko
oooo0_l00007ooooo`Co00001_ooool2o`0000_ooooo0_l00005ooooo`Co00003_oooolFo`0000Ko
oooo0ol00003ooooo`;o00000_ooool7o`0000cooooo0_l0000:ooooo`;o00001oooool2o`0003Ko
oooo000Looooo`03o`000?oooooooooo02Sooooo0_l0000Jooooo`?o00004Oooool2o`0000Kooooo
0_l000000ooooooo0000o`000002ooooo`;o00001?ooool2o`0000[ooooo0ol00002ooooo`;o0000
0_ooool2o`00017ooooo0_l00005ooooo`;o00002oooool3o`0000Cooooo1Ol0000>oooooaKo0000
1oooool2o`0000?ooooo0_l00002ooooo`Ko00003Oooool3o`0004[ooooo000Looooo`03o`000?oo
oooooooo03?ooooo0_l0000Dooooo`;o00006?ooool2o`0000;ooooo0_l0000@ooooo`;o00000_oo
ool2o`000004ooooool0003o0000o`0000Gooooo0_l0000@ooooo`Co00002Oooool5o`0000Cooooo
1?l0000>oooooaKo00001oooool2o`0000Sooooo0ol000000ooooooo0000o`000002ooooo`;o0000
2_ooool2o`0000?ooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`0cooooo`?o00004ooo
ool2o`0001;ooooo0_l00002ooooo`?o00001Oooool2o`0000_ooooo0_l00005ooooo`;o000000?o
ooooo`000?l000000ol00003ooooo`Go00000_ooool2o`0000Wooooo0_l00003ooooo`;o00001_oo
ool2o`0000Sooooo0ol00008ooooo`;o000000?oooooo`000?l000005ol00007ooooo`;o00002?oo
ool3o`0000Gooooo0_l00008ooooo`Co00000oooool2o`0004Gooooo000Looooo`03o`000?oooooo
oooo02oooooo0ol00002ooooo`;o00001?ooool2o`0000Oooooo0ol0000Gooooo`;o00000_ooool3
o`0000Gooooo0_l00007ooooo`;o00000_ooool2o`0000Gooooo0_l000000ooooooo0000o`000003
o`0000Gooooo1?l000000ooooooo0000o`00000>ooooo`Co00002oooool2o`000003ooooool0003o
000000Wooooo0_l000000ooooooo0000o`00000Jo`0000Cooooo0_l00008ooooo`Go000000Cooooo
o`000?l0003ooooo0_l00002ooooo`;o00000oooool4o`0000_ooooo0_l0000mooooo`007?ooool0
0ol0003oooooooooo`0_ooooo`?o00002?ooool2o`0000Oooooo0ol0000Cooooo`;o00001_ooool2
o`0000oooooo1?l00005ooooo`Co000000?oooooo`000?l000002_ooool3o`000003ooooool0003o
000000oooooo0_l00006ooooo`;o00000oooool2o`000003ooooool0003o000000Oooooo0_l00004
oooooa_o00003_ooool8o`000003ooooool0003o000000;ooooo0_l00005ooooo`;o00002oooool2
o`0003gooooo000Looooo`03o`000?oooooooooo033ooooo1?l000000ooooooo0000o`00000;oooo
o`;o00005Oooool2o`0000Cooooo0_l0000Cooooo`;o00001Oooool2o`0000Sooooo0_l00006oooo
o`;o000000?oooooo`000?l000005oooool5o`0000?ooooo0ol00006ooooo`;o00001?oooolKo`00
00oooooo1ol0000Kooooo`;o0000>oooool001cooooo00?o0000ooooooooool0;?ooool2o`0000;o
oooo1?l000000ooooooo0000o`00000;ooooo`Co00006Oooool2o`0000Oooooo0_l0000Kooooo`;o
000000?oooooo`000?l000001oooool2o`0001Sooooo0ol000001?oooooo0000o`000?ooool2o`00
00cooooo7Ol0000;ooooo`Oo00000_ooool4o`000003ooooool0003o000000Wooooo0_l00009oooo
o`;o0000>oooool001cooooo00?o0000ooooooooool0;?ooool2o`0000;ooooo0_l0000:ooooo`;o
00001Oooool5o`0000Cooooo0_l0000Jooooo`;o00000_ooool2o`0001Oooooo0_l000000ooooooo
0000o`000005ooooo`Co000000Coooooo`000?l0003ooooo0_l0000Fooooo`;o00002oooool2o`00
00;ooooo3ol00002ooooo`co000000?oooooo`000?l000001?ooool2o`0000;ooooo1_l00003oooo
o`Co000000?oooooo`000?l000002Oooool4o`0004Cooooo000Looooo`03o`000?oooooooooo033o
oooo0_l0000:ooooo`;o00001Oooool2o`000003ooooool0003o000000Cooooo0_l0000Mooooo`Go
00005Oooool3o`0000Oooooo0_l00003ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Go
oooo0_l00006ooooo`;o00003Oooool2o`0000;ooooo5Ol000000ooooooo0000o`000004o`0000;o
oooo0_l00004ooooo`;o00000oooool2o`000003ooooool0003o000001Gooooo0_l00014ooooo`00
7?ooool00ol0003oooooooooo`0nooooo`;o00008_ooool2o`0000Oooooo0_l000000ooooooo0000
o`00000Fooooo`;o00001oooool2o`000003ooooool0003o000000[ooooo0_l00005ooooo`;o0000
00?oooooo`000?l000000oooool2o`0000Cooooo0_l00008oooooaoo00000_ooool4o`0000Oooooo
1Ol0000:ooooo`;o00003?ooool2o`0000Cooooo0_l0000kooooo`0000Koooooonk^k_lb<S;o0000
oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000oooo
ooooool0;oooool2o`0000gooooo0_l0000=ooooo`;o00004oooool2o`0000Sooooo1Ol00004oooo
o`;o00001_ooool2o`00013ooooo0_l000000ooooooo0000o`00000Dooooo`;o00002Oooool2o`00
00?ooooo0_l00003oooooaoo000000?oooooo`000?l000001?l00005ooooo`Go00001_ooool2o`00
00;ooooo0ol00003ooooo`;o00001oooool2o`0000Cooooo0_l00002ooooo`;o00002?ooool2o`00
02gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOo
oooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0Zooooo`;o00000oooool2o`0000Oooooo0_l0
0004ooooo`;o00001_ooool2o`0000Gooooo0_l0000Jooooo`;o000000?oooooo`000?l000001?l0
0003ooooo`;o00000_ooool3o`000003ooooool0003o000000Oooooo0_l00007ooooo`;o00001Ooo
ool2o`0000kooooo1Ol00005ooooo`;o00000oooool2o`000003ooooool0003o000000Oooooo3?l0
00000ooooooo0000o`00000<o`000003ooooool0003o000000;ooooo0_l00005ooooo`Go00001_oo
ool2o`0000;ooooo1Ol000000ooooooo0000o`00000?ooooo`Co00002?ooool2o`0002gooooo0000
0ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo02[ooooo0_l0000<ooooo`;o00000_ooool2o`0000;ooooo0_l0
0004ooooo`;o00007_ooool2o`000003ooooool0003o000000Gooooo0_l00007ooooo`?o00002_oo
ool2o`0000Cooooo0_l000000ooooooo0000o`000005ooooo`?o00003Oooool5o`0000Gooooo0ol0
0002ooooo`;o00002_ooool2o`000003ooooool0003o000001Go00001Oooool2o`0000?ooooo1Ol0
00000ooooooo0000o`000007ooooo`;o00000_ooool4o`0001;ooooo0_l0000iooooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_oo
ool3o`0003cooooo0_l00002ooooo`;o00002oooool2o`0001Oooooo0_l000000ooooooo0000o`00
0004ooooo`;o00000_ooool2o`0001Oooooo1Ol00006ooooo`;o00002?ooool2o`0000gooooo0ol0
0002ooooo`;o00000oooool2o`0000Sooooo5ol00005ooooo`;o00000oooool5o`000003ooooool0
003o000000Oooooo1?l0001Aooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09
ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0aooooo`;o00002_oo
ool2o`0000Wooooo0_l00003ooooo`;o00006Oooool2o`0000Gooooo0_l00002ooooo`;o00001?oo
ool4o`0000cooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00003oooool2o`0000_ooooo
1Ol00002ooooo`;o00000oooool2o`0000?ooooo0_l00002oooooaGo00003Oooool3o`0000Oooooo
0_l00005ooooo`?o0000D?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Ooo
ool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo037ooooo1?l00008ooooo`;o00002Ooo
ool2o`0001kooooo0_l0000?ooooo`Co000000?oooooo`000?l000002Oooool2o`000005ooooool0
003o0000o`000?ooool00_l00002ooooo`;o00006?ooool4o`0000gooooo0_l00002oooooaGo0000
1Oooool2o`0000Gooooo0ol00008ooooo`;o00001?ooool8o`0001[ooooo0_l0000`ooooo`0000Ko
ooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000oooooooo
ool0<oooool2o`0000;ooooo0_l0000?ooooo`;o0000=?ooool2o`0000cooooo0ol00005ooooo`;o
00000oooool2o`0001Sooooo0_l00005ooooo`;o00002?ooool@o`0000;ooooo0ol00004ooooo`;o
00001?ooool3o`0000oooooo0_l00002ooooo`Co00006_ooool2o`00033ooooo00001_ooooook^k^
oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`0g
ooooo`?o00001_ooool2o`000003ooooool0003o000000_ooooo0_l0000Iooooo`;o00005oooool2
o`0000Kooooo0ol00008ooooo`Ko00000_ooool2o`0000Sooooo0_l00005ooooo`;o000000?ooooo
o`000?l000000_ooool2o`000003ooooool0003o000000[ooooo3ol00002ooooo`;o00002Oooool5
o`0000Gooooo0_l000001?oooooo0000o`000?l00007ooooo`;o0000C_ooool001cooooo00?o0000
ooooooooool0>?ooool2o`0000Gooooo0ol000000ooooooo0000o`00000;ooooo`;o00006Oooool2
o`0000[ooooo0_l0000;ooooo`;o00004Oooool6o`0000;ooooo0_l00008ooooo`;o00001Oooool2
o`0000Gooooo0_l0000?ooooo`[o000000?oooooo`000?l000000_ooool2o`0000Wooooo0_l00000
0ooooooo0000o`000005ooooo`;o000000Coooooo`000?l0003o00002Oooool2o`000003ooooool0
003o000004Wooooo000Looooo`03o`000?oooooooooo03Sooooo0_l00005ooooo`;o00001_ooool3
o`0002gooooo0_l00007ooooo`;o00002Oooool4o`0000;ooooo1Ol000001Ooooooo0000o`000?l0
003ooooo00Ko00000oooool2o`0002;ooooo2_l00005ooooo`;o00004Oooool2o`0000oooooo0_l0
00000ooooooo0000o`000004ooooo`;o00003_ooool2o`0003?ooooo000Looooo`03o`000?oooooo
oooo03Sooooo0ol0000<ooooo`?o00000_ooool2o`00027ooooo1Ol0000<ooooo`;o00000_ooool2
o`0000Gooooo1?l00002ooooo`Wo000000?oooooo`000?l000000ol00004ooooo`;o00002Oooool2
o`0000Sooooo0_l0000>ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Gooooo0_l00008
ooooo`Co00005_ooool4o`0000kooooo0_l0000cooooo`007?ooool00ol0003oooooooooo`0ioooo
o`;o00002?ooool2o`0000Oooooo0_l00002ooooo`;o00006?ooool2o`0000?ooooo1Ol0000>oooo
o`Co00001Oooool4o`000003ooooool0003o000000So00001?ooool4o`0000_ooooo1?l00006oooo
o`Co00000_ooool2o`0000Wooooo0_l0000=ooooo`;o00000_ooool2o`000003ooooool0003o0000
00Gooooo0_l000000ooooooo0000o`00000Hooooo`;o00000_ooool2o`00047ooooo000Looooo`03
o`000?oooooooooo047ooooo1_l00009ooooo`;o00005Oooool2o`000003ooooool0003o000000Go
oooo0_l00005ooooo`;o00000_ooool2o`0000Cooooo0_l00003ooooo`oo000000Coooooo`000?l0
003ooooo0_l00002ooooo`Co00002_ooool5o`0000Kooooo0_l00004ooooo`;o00002Oooool3o`00
013ooooo0_l00008ooooo`;o00000oooool2o`0000Sooooo0_l00008ooooo`?o00001Oooool2o`00
047ooooo000Looooo`03o`000?oooooooooo047ooooo0_l00002ooooo`;o000000?oooooo`000?l0
00007Oooool2o`0000;ooooo0_l0000:ooooo`?o00000_ooool2o`0000Wooooo1ol000000ooooooo
0000o`00000;o`0000Gooooo0_l00008ooooo`?o000000?oooooo`000?l000000oooool2o`0001;o
oooo0ol00003ooooo`;o00002oooool2o`0000Sooooo0_l00003ooooo`;o00000_ooool2o`0000Co
oooo0_l000000ooooooo0000o`000005ooooo`?o0000B?ooool001cooooo00?o0000ooooooooool0
@?ooool2o`0000Kooooo0_l0000Qooooo`;o00002_ooool2o`0000oooooo1_l00002ooooo`ko0000
0oooool3o`0000Oooooo0_l00002ooooo`Co000000?oooooo`000?l000000_l0000@ooooo`Co0000
0_ooool2o`0000Oooooo0_l000000ooooooo0000o`000007ooooo`;o00002Oooool2o`0000Oooooo
0_l0001@ooooo`007?ooool00ol0003oooooooooo`10ooooo`?o00001?ooool2o`0000[ooooo0_l0
000Fooooo`;o00000_ooool2o`0001Gooooo1Ol000000ooooooo0000o`00000@o`0000Cooooo0_l0
00000ooooooo0000o`000007ooooo`Go00000_ooool3o`0000Sooooo1?l000000ooooooo0000o`00
0003ooooo`;o00000_ooool2o`0000Oooooo0_l000000ooooooo0000o`000007ooooo`;o00002ooo
ool4o`0000Wooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`11ooooo`;o00001?ooool2
o`0000Wooooo0ol0000Jooooo`;o00001?ooool2o`0000oooooo1Ol000000ooooooo0000o`00000>
o`0000?ooooo0_l00004ooooo`;o00000_ooool2o`0000?ooooo0_l0000@ooooo`Co000000?ooooo
o`000?l000000oooool2o`0000;ooooo0_l0000=ooooo`;o00000_ooool4o`0000;ooooo1?l00005
ooooo`Co00002Oooool3o`0004Wooooo000Looooo`03o`000?oooooooooo03kooooo0_l00004oooo
o`;o00003?ooool2o`000003ooooool0003o000001Oooooo0_l00005ooooo`;o00000oooool3o`00
00Gooooo1?l000000ooooooo0000o`00000Eo`000003ooooool0003o000000Sooooo0_l0000>oooo
o`;o00008_ooool2o`0000;ooooo1Ol000000ooooooo0000o`000002o`0000?ooooo0_l000000ooo
oooo0000o`00000;ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0?_ooool2o`0000;o
oooo1?l000000ooooooo0000o`000004ooooo`;o00001Oooool3o`00013ooooo0_l00005ooooo`;o
00001oooool2o`000004ooooool0003o0000o`0000Gooooo1Ol000000ooooooo0000o`00000Eo`00
01[ooooo0_l0000:ooooo`?o00000oooool2o`0000;ooooo0_l0000:ooooo`;o00001_ooool3o`00
00Sooooo0_l00008ooooo`;o00001Oooool3o`0004Oooooo000Looooo`;o0000@?ooool2o`000003
ooooool0003o000000?ooooo0_l00004ooooo`;o00001Oooool2o`00017ooooo0_l00009ooooo`;o
00000oooool2o`0000cooooo7?l0000@ooooo`;o00001?ooool2o`0000Cooooo0_l00006ooooo`?o
00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l0
00001_ooool2o`0001?ooooo0_l00005ooooo`?o0000Aoooool001cooooo00?o0000ooooooooool0
?oooool2o`0000cooooo0_l0000Sooooo`;o00004OoooolGo`000003ooooool0003o000000;o0000
4?ooool2o`0000Cooooo0_l00004ooooo`;o00002Oooool2o`0000Cooooo0ol000000ooooooo0000
o`000004ooooo`;o00003Oooool2o`0000Oooooo0_l0000=ooooo`;o0000B?ooool001cooooo00?o
0000ooooooooool0@?ooool2o`000003ooooool0003o000000Sooooo0_l0000:ooooo`;o00009ooo
ool2o`000003ooooool0003o000001[o00002_ooool2o`0000oooooo0_l0000:ooooo`Co00000_oo
ool3o`0000Gooooo0_l0000?ooooo`;o00001oooool2o`0005Oooooo000Looooo`03o`000?oooooo
oooo03Gooooo0_l00003ooooo`;o00001?ooool2o`000003ooooool0003o0000017ooooo0_l00000
0ooooooo0000o`00000<ooooo`;o00000oooool2o`0001Cooooo7Ol00002ooooo`;o00001?ooool2
o`0000;ooooo0_l00004ooooo`;o00002Oooool2o`0000Gooooo0ol000001?oooooo0000o`000?oo
ool2o`0000[ooooo0_l00006ooooo`;o0000JOooool001cooooo00?o0000ooooooooool0=Oooool2
o`0000?ooooo0_l0000Jooooo`Co00003Oooool2o`0000?ooooo0_l00008ooooo`;o00003?oooolK
o`0000;ooooo0_l00004ooooo`;o00001?ooool2o`0000;ooooo0_l00003ooooo`?o00002_ooool6
o`0001?ooooo1?l00007ooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0?Oooool2o`00
00Kooooo0_l00004ooooo`;o00002oooool4o`0000gooooo0ol00002ooooo`;o00001_ooool2o`00
00kooooo6Ol0000>ooooo`Co000000?oooooo`000?l000000_ooool3o`0000Cooooo0_l00004oooo
o`Co00000oooool2o`00013ooooo0_l000000ooooooo0000o`000006ooooo`;o00001Oooool2o`00
00Oooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00001_ooool2o`0000Co
oooo1?l0000;ooooo`;o00003Oooool7o`0000[ooooo0_l00004ooooo`;o000000Coooooo`000?l0
003ooooo6Ol0000:ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000009
ooooo`;o00002oooool2o`0001?ooooo0_l00002ooooo`Co00001oooool2o`0000Oooooo0_l0001@
ooooo`007?ooool00ol0003oooooooooo`18ooooo`?o00000_ooool2o`0001gooooo0_l00004oooo
o`;o00000_ooool2o`000004ooooool0003o0000o`0000Cooooo0_l000001?oooooo0000o`000?oo
oolIo`0000;ooooo0_l00006ooooo`;o000000?oooooo`000?l000001?ooool2o`0000_ooooo0ol0
00001?oooooo0000o`000?ooool2o`0001Oooooo0_l000000ooooooo0000o`000003o`0006;ooooo
000Looooo`03o`000?oooooooooo04Sooooo0ol00006ooooo`;o00001oooool2o`00013ooooo0_l0
0003ooooo`Co000000Coooooo`000?l0003ooooo0_l00003ooooo`;o000000Coooooo`000?l0003o
00000oooool9o`000003ooooool0003o000000go000000?oooooo`000?l000003oooool2o`0000_o
oooo0ol000001?oooooo0000o`000?ooool2o`0000[ooooo0_l0000;ooooo`;o000000?oooooo`00
0?l000000_l00009ooooo`;o0000F?ooool001cooooo00?o0000ooooooooool0DOooool2o`0000Oo
oooo0_l0000@ooooo`;o00000oooool4o`0000Oooooo1?l000001Ooooooo0000o`000?l0003ooooo
01ko00001_ooool3o`000003ooooool0003o000002?ooooo0_l00002ooooo`;o00001Oooool2o`00
00Gooooo0_l00009ooooo`;o00003Oooool2o`0004Wooooo000Looooo`03o`000?oooooooooo03co
oooo0_l000000ooooooo0000o`00000kooooo`;o00001_ooool=o`000003ooooool0003o000000go
00001?ooool3o`000005ooooool0003o0000o`000?ooool00_l00009ooooo`;o00007?ooool2o`00
0003ooooool0003o000000;ooooo0_l0000>ooooo`;o00001?ooool2o`0000Oooooo1?l00019oooo
o`007?ooool00ol0003oooooooooo`0looooo`;o000000?oooooo`000?l000000_ooool2o`0000Wo
oooo0_l0000?ooooo`;o00001_ooool2o`0001Cooooo0_l00002ooooo`Go000000?oooooo`000?l0
00005ol000001Ooooooo0000o`000?l0003ooooo00?o00002?ooool2o`0000Kooooo0_l0000Ooooo
o`;o00000_ooool2o`0000gooooo0ol00004ooooo`;o000000?oooooo`000?l000000_ooool4o`00
04_ooooo000Looooo`03o`000?oooooooooo04?ooooo0_l00007ooooo`Co00003oooool2o`0000Ko
oooo0_l0000Dooooo`?o000000?oooooo`000?l000000_l000000ooooooo0000o`00000Eo`0000;o
oooo1Ol00009ooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo0_l0000?ooooo`;o
00004?ooool2o`0000[ooooo1Ol00005ooooo`;o000000?oooooo`000?l000000_ooool2o`0000co
oooo0_l0000oooooo`007?ooool00ol0003oooooooooo`19ooooo`;o000000?oooooo`000?l00000
1_ooool2o`000003ooooool0003o000002Gooooo0_l00003ooooo`;o000000?oooooo`000?l00000
1?l000000ooooooo0000o`00000Bo`0000Gooooo0_l00002ooooo`;o000000Coooooo`000?l0003o
00000_ooool2o`000003ooooool0003o000000?ooooo1?l0000<ooooo`?o00003?ooool2o`0000Oo
oooo0_l000000ooooooo0000o`000002ooooo`?o00001oooool2o`000003ooooool0003o0000013o
oooo0_l0000oooooo`007?ooool00ol0003oooooooooo`16ooooo`;o000000?oooooo`000?l00000
2Oooool2o`000003ooooool0003o000001[ooooo0_l00003ooooo`;o00001Oooool2o`000003oooo
ool0003o000000;ooooo5?l000000ooooooo0000o`000005o`0000Cooooo0_l00002ooooo`;o0000
0_ooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l0000<ooooo`;o
000000?oooooo`000?l000002_ooool2o`0000Oooooo0_l000000ooooooo0000o`00000<ooooo`;o
0000E?ooool001cooooo00?o0000ooooooooool0A_ooool4o`0000Oooooo0_l0000Iooooo`Co0000
0oooool2o`0000?ooooo1?l00003ooooo`;o000000?oooooo`000?l000005_l00003ooooo`Go0000
1oooool4o`0000Oooooo0ol000000ooooooo0000o`00000>ooooo`;o00000oooool2o`0001Oooooo
0_l00005ooooo`;o0000F_ooool001cooooo0_l00019ooooo`?o00001?ooool4o`0000kooooo0_l0
0009ooooo`Go00002Oooool2o`000003ooooool0003o000000;ooooo0_l000001?oooooo0000o`00
0?oooolEo`0000Gooooo0_l00006ooooo`Co00001_ooool4o`00017ooooo0_l00005ooooo`;o0000
5Oooool4o`0000;ooooo0ol000000ooooooo0000o`00001Gooooo`007?ooool00ol0003ooooooooo
o`18ooooo`?o000000Coooooo`000?l0003ooooo0_l0000@ooooo`;o00003?ooool2o`000003oooo
ool0003o000000Wooooo0_l00002ooooo`;o000000?oooooo`000?l000005_l00005ooooo`Co0000
0_ooool7o`0000Cooooo1Ol0000Hooooo`;o00001_ooool2o`0000Oooooo0_l00004ooooo`Co0000
0_ooool2o`000004ooooool0003o0000o`0001Cooooo0_l00011ooooo`007?ooool00ol0003ooooo
ooooo`18ooooo`?o000000Coooooo`000?l0003o00004?ooool2o`0000[ooooo0_l00005ooooo`;o
00003oooool5o`0000?ooooo4?l00005ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?o
oooo0_l00004ooooo`Go00006?ooool2o`0000Kooooo0_l00007ooooo`;o00001?ooool2o`0000Oo
oooo1?l0000?ooooo`;o00000_ooool2o`00047ooooo000Looooo`03o`000?oooooooooo04Wooooo
0_l00002ooooo`;o00001oooool2o`0000Kooooo0ol0000:ooooo`;o00001?ooool2o`0000Oooooo
1?l00005ooooo`?o00001Oooool3o`000003ooooool0003o000000co00000oooool2o`0001;ooooo
0ol0000@ooooo`;o00004Oooool2o`0000?ooooo0_l0000=ooooo`Go00003oooool2o`0004Gooooo
000Looooo`03o`000?oooooooooo04kooooo0_l00006ooooo`;o00001_ooool2o`0000Oooooo0_l0
0008ooooo`;o00001oooool4o`0000[ooooo4?l000000ooooooo0000o`000002o`0001Sooooo0_l0
000<ooooo`;o00000_ooool4o`0000oooooo0_l00003ooooo`;o00001_ooool2o`0000Gooooo0ol0
001Hooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o00004Oooool2o`0000Cooooo0_l00000
0ooooooo0000o`000003ooooo`;o00002_ooool2o`0000Gooooo0_l00004oooooa3o000000?ooooo
o`000?l000001?ooool2o`0000?ooooo0ol00006ooooo`;o00001Oooool3o`0000Cooooo0_l00006
ooooo`;o00000_ooool4o`0001cooooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`1=oooo
o`;o00001oooool2o`0000Wooooo0_l00007ooooo`;o00000oooool2o`0000Sooooo0_l00007oooo
o`;o00001_ooool2o`0000Cooooo2ol00004ooooo`;o00000oooool3o`0000Kooooo0_l00005oooo
o`;o00001Oooool2o`0000Cooooo0_l0000Hooooo`?o00000_ooool3o`0000_ooooo0_l0001Ioooo
o`007?ooool00ol0003oooooooooo`1=ooooo`?o00001_ooool2o`00027ooooo0_l0000?ooooo`;o
00000_ooool4o`000004ooooool0003o0000ooooo`?o00002oooool2o`000003ooooool0003o0000
00;o00003Oooool2o`0000;ooooo0_l00003ooooo`?o00001_ooool2o`0000Gooooo0_l00008oooo
o`?o000000?oooooo`000?l000000_l0000;ooooo`;o0000FOooool001cooooo00?o0000oooooooo
ool0C_ooool2o`0000Kooooo0_l00004ooooo`;o000000?oooooo`000?l000007_ooool2o`0000Wo
oooo2ol00008ooooo`;o00000_ooool2o`0000Cooooo1?l00007ooooo`;o00001?ooool2o`0000;o
oooo0_l00004ooooo`;o00001_ooool3o`0000Cooooo0_l0000:ooooo`Co00001oooool2o`0005oo
oooo000Looooo`03o`000?oooooooooo05cooooo0_l000001?oooooo0000o`000?l0000<ooooo`;o
00002_ooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool8o`0000;ooooo0_l0000:ooooo`;o
00000_ooool2o`0000;ooooo0_l00002ooooo`;o00001oooool2o`0000;ooooo0_l00005ooooo`;o
00000oooool2o`0000?ooooo0_l00002ooooo`;o00004?ooool2o`0000Wooooo0_l00002ooooo`;o
0000Foooool001cooooo00?o0000ooooooooool0D_ooool2o`0000cooooo0_l0000<ooooo`Co0000
2?ooool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`Go000000?oooooo`000?l00000
0ol0000Cooooo`;o00000_ooool2o`0000_ooooo0_l00004ooooo`Go00000_ooool2o`0000;ooooo
1?l0000;ooooo`;o00001oooool2o`0000_ooooo0_l0000=ooooo`;o0000C?ooool001cooooo00?o
0000ooooooooool0D_ooool2o`0000cooooo0_l00004ooooo`;o00002?ooool4o`0000Wooooo0_l0
0008ooooo`;o00001Oooool4o`000003ooooool0003o000000gooooo0_l00007ooooo`?o00000ooo
ool2o`0000Sooooo0ol000000ooooooo0000o`000002ooooo`;o00001?ooool2o`0000[ooooo0ol0
00000ooooooo0000o`000004ooooo`?o00001Oooool3o`00013ooooo0ol0001<ooooo`007?ooool0
0ol0003oooooooooo`1Gooooo`;o00003Oooool2o`0000[ooooo0_l00006ooooo`;o00001?ooool2
o`000003ooooool0003o000000[ooooo0_l00002ooooo`Co00002oooool2o`0000Kooooo1?l00003
ooooo`Co00000oooool2o`000003ooooool0003o000000[ooooo1?l0000:ooooo`?o000000?ooooo
o`000?l000001Oooool2o`0000Gooooo0ol0000@ooooo`;o0000COooool001cooooo00?o0000oooo
ooooool0E?ooool2o`000003ooooool0003o000000Wooooo0_l00003ooooo`Co00003oooool2o`00
00;ooooo1?l000001?oooooo0000o`000?l0000=ooooo`Co00004oooool2o`0000Oooooo0_l00000
0ooooooo0000o`000002o`0000Kooooo0_l00004ooooo`Go00002oooool2o`00077ooooo000Loooo
o`03o`000?oooooooooo04_ooooo0_l00007ooooo`;o000000?oooooo`000?l000001Oooool2o`00
00;ooooo0_l00003ooooo`Co000000?oooooo`000?l000004?ooool2o`0000Cooooo0_l0000=oooo
o`;o00002Oooool3o`0000Kooooo0ol000000ooooooo0000o`000009ooooo`?o00000oooool2o`00
00;ooooo0_l00004ooooo`;o000000?oooooo`000?l000005_ooool2o`0000Kooooo0ol0001Moooo
o`007?ooool00ol0003oooooooooo`1;ooooo`;o00002_ooool4o`0000?ooooo0_l0000<ooooo`;o
00004_ooool2o`0000;ooooo0_l00006ooooo`;o00000oooool2o`0000;ooooo1?l000000ooooooo
0000o`000002ooooo`?o00001_ooool3o`000003ooooool0003o000000oooooo0_l00006ooooo`;o
00006oooool2o`0000Kooooo0ol0001Mooooo`007?ooool2o`00053ooooo0_l00005ooooo`Go0000
1?ooool2o`0000_ooooo0_l00002ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Cooooo
0_l0000:ooooo`;o00000oooool2o`0000;ooooo1?l000001?oooooo0000o`000?l0000>ooooo`;o
000000Coooooo`000?l0003ooooo0_l0000;ooooo`;o00001?ooool2o`0000Wooooo0_l00003oooo
o`;o00007Oooool2o`0005Cooooo000Looooo`03o`000?oooooooooo04oooooo0_l00005ooooo`Co
00001Oooool4o`0000gooooo0_l000000ooooooo0000o`000005ooooo`;o00005_ooool2o`0000Oo
oooo0_l0000>ooooo`;o000000Coooooo`000?l0003ooooo0_l0000;ooooo`;o00001Oooool2o`00
00Gooooo0_l000000ooooooo0000o`000003ooooo`Co00005_ooool2o`0000?ooooo0_l0001Doooo
o`007?ooool00ol0003oooooooooo`1Oooooo`Co00006Oooool2o`0001Cooooo0ol0000Aooooo`Co
00001_ooool3o`0000;ooooo0_l00003ooooo`;o00002Oooool2o`0000Gooooo0_l00008ooooo`;o
00005_ooool2o`0000Cooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`1Oooooo`;o0000
5_ooool2o`0000?ooooo0_l0000Booooo`Go00003oooool6o`0000Kooooo0ol00002ooooo`;o0000
0oooool2o`0001oooooo0_l000000ooooooo0000o`00000Dooooo`;o0000Doooool001cooooo00?o
0000ooooooooool0GOooool4o`0000Kooooo0_l00002ooooo`;o00002_ooool2o`0000?ooooo0_l0
0006ooooo`;o00002_ooool4o`00013ooooo0_l0000=ooooo`;o00000oooool2o`0001Cooooo0_l0
0008ooooo`;o000000?oooooo`000?l000000ol00002ooooo`;o0000IOooool001cooooo00?o0000
ooooooooool0EOooool2o`0000Kooooo1?l00006ooooo`;o00000_ooool2o`0000;ooooo0_l0000:
ooooo`Co00001Oooool2o`0000oooooo1?l00004ooooo`;o00005?ooool2o`0000?ooooo0_l00008
ooooo`?o00002Oooool2o`0000Sooooo0_l00003ooooo`;o00000oooool2o`0006Gooooo000Loooo
o`03o`000?oooooooooo05Gooooo0_l00004ooooo`;o00004Oooool5o`0000Sooooo1?l0000<oooo
o`;o00002?ooool4o`0000Cooooo0_l0000Booooo`Co00003Oooool3o`0000Cooooo1?l00009oooo
o`;o00005?ooool2o`0005_ooooo000Looooo`03o`000?oooooooooo05_ooooo1?l00005ooooo`;o
00002?ooool2o`000003ooooool0003o000000?ooooo0_l0000>ooooo`;o00000oooool2o`0001oo
oooo0_l00002ooooo`?o00005_ooool4o`0000Wooooo0_l0000Dooooo`;o0000Foooool001cooooo
00?o0000ooooooooool0GOooool2o`0000Cooooo0ol000000ooooooo0000o`000002ooooo`;o0000
2Oooool2o`0000kooooo0_l00006ooooo`;o00001_ooool2o`0001Cooooo0_l00002ooooo`;o0000
1_ooool2o`0001Kooooo0_l00003ooooo`;o00000_ooool2o`0006kooooo000Looooo`03o`000?oo
oooooooo05gooooo0_l00004ooooo`;o00000_ooool3o`000003ooooool0003o000000kooooo0_l0
000Aooooo`;o00001_ooool2o`0000Gooooo0_l00009ooooo`;o00001oooool2o`0000Gooooo0_l0
0008ooooo`Co00002_ooool2o`0000?ooooo0_l00002ooooo`;o00005?ooool2o`0005Sooooo000L
ooooo`03o`000?oooooooooo05gooooo0_l00008ooooo`Go00000_ooool2o`0000_ooooo0_l0000?
ooooo`;o00000_ooool2o`0000_ooooo0_l00009ooooo`;o00000_ooool2o`0000?ooooo0_l00004
ooooo`Co00001oooool4o`0000Oooooo0_l0000Pooooo`;o0000F?ooool001cooooo00?o0000oooo
ooooool0Ioooool5o`000004ooooool0003o0000o`0000;ooooo0_l00006ooooo`Co000000?ooooo
o`000?l000002oooool2o`0000;ooooo0_l0000Jooooo`;o00002Oooool4o`0000Kooooo0_l0000:
ooooo`;o00001oooool4o`0006oooooo000Looooo`03o`000?oooooooooo06?ooooo1?l00003oooo
o`;o000000Coooooo`000?l0003o00000_ooool3o`0000Gooooo1?l000000ooooooo0000o`000003
ooooo`;o00001Oooool2o`0000cooooo0_l0000;ooooo`;o00001_ooool3o`00013ooooo0_l0000C
ooooo`Co0000Koooool001cooooo00?o0000ooooooooool0H?ooool2o`000003ooooool0003o0000
00;o00001oooool2o`0000;ooooo0ol00007ooooo`;o00001_ooool2o`0000Gooooo0_l0000<oooo
o`;o00002_ooool3o`0000Gooooo1?l00008ooooo`;o00002?ooool2o`0000gooooo0_l0000Ioooo
o`;o0000F_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<
ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo063ooooo0_l0000;ooooo`;o00000ooo
ool2o`0000Sooooo0_l00004ooooo`;o00004Oooool2o`0000kooooo0_l00006ooooo`Co00001_oo
ool4o`0000Sooooo0_l00009ooooo`;o00000_ooool3o`0001Sooooo0_l0001Jooooo`0000Kooooo
ogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Ko
oooo00?o0000ooooooooool0KOooool2o`0000Wooooo0_l00008ooooo`;o00001Oooool2o`0000[o
oooo0_l0000Dooooo`;o00000_ooool4o`0000Cooooo0_l00008ooooo`;o000000?oooooo`000?l0
00001_ooool4o`0000;ooooo1Ol0001booooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooo
ooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`1dooooo`;o
00000_ooool2o`0000oooooo0ol0000Oooooo`;o00000oooool5o`0000cooooo0_l000000ooooooo
0000o`000006ooooo`Co00000_ooool2o`000003ooooool0003o000007;ooooo00000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o
0000LOooool2o`000003ooooool0003o000000[ooooo1?l00006ooooo`Co00008_ooool2o`000003
ooooool0003o000001Oooooo1?l0001iooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooo
ooooo`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`1aooooo`;o
000000Coooooo`000?l0003ooooo0_l00007ooooo`Co00002?ooool2o`0000cooooo0ol0000Coooo
o`;o00004Oooool2o`0000Gooooo1?l0001kooooo`0000?ooooooa0@4?ooool00_ooool00ol@413o
ooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`1Uoooo
o`;o00004?ooool4o`00017ooooo0_l00004ooooo`?o00001Oooool4o`0001;ooooo0_l00002oooo
o`;o000000?oooooo`000?l000001Oooool2o`0000?ooooo0_l00005ooooo`Co0000Noooool00006
oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o
0000ooooooooool0IOooool2o`0001;ooooo0_l00004ooooo`;o00001_ooool3o`0000;ooooo0_l0
0004ooooo`?o00001oooool2o`0000oooooo0_l00005ooooo`;o000000?oooooo`000?l000001Ooo
ool2o`0000?ooooo0_l00007ooooo`;o0000Noooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^
2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0Moooool2o`0000Ko
oooo0_l00006ooooo`Co000000?oooooo`000?l000001Oooool2o`0001Cooooo0_l00002ooooo`;o
00000oooool2o`000004ooooool0003o0000o`0000_ooooo0_l0000Pooooo`?o0000HOooool001co
oooo00?o0000ooooooooool0Moooool2o`000003ooooool0003o000000cooooo0ol00008ooooo`;o
00005?ooool3o`0000Kooooo0_l000000ooooooo0000o`000002o`0002cooooo0ol0001Qooooo`00
7?ooool00ol0003oooooooooo`1gooooo`Ko00004_ooool2o`0000;ooooo0_l0000=ooooo`;o0000
1_ooool4o`0000Wooooo0_l00007ooooo`;o0000Qoooool001cooooo00?o0000ooooooooool0Jooo
ool2o`0000_ooooo0_l000000ooooooo0000o`000009ooooo`;o000000Coooooo`000?l0003o0000
0_ooool3o`0000kooooo0_l000000ooooooo0000o`000002ooooo`?o00000_ooool3o`0001;ooooo
0_l00002ooooo`;o0000Poooool001cooooo00?o0000ooooooooool0I_ooool2o`0000?ooooo0_l0
000>ooooo`?o00002?ooool2o`000004ooooool0003o0000o`0000;ooooo0_l00007ooooo`;o0000
0oooool5o`0000Gooooo0ol00002ooooo`;o00004Oooool4o`0000;ooooo1?l00021ooooo`007?oo
ool00ol0003oooooooooo`1Vooooo`;o00005?ooool2o`0000;ooooo0ol000001?oooooo0000o`00
0?ooool2o`0000;ooooo0_l00002ooooo`;o00001_ooool2o`0000?ooooo1?l0000Booooo`;o0000
2?ooool6o`0000Cooooo0_l00021ooooo`007?ooool00ol0003oooooooooo`1mooooo`;o000000Go
ooooo`000?l0003o0000ooooo`05o`0000;ooooo1_l0000<ooooo`;o00003_ooool2o`0000?ooooo
0_l00008ooooo`Go0000R?ooool001cooooo00?o0000ooooooooool0OOooool4o`0000Cooooo1?l0
0004ooooo`;o00003_ooool2o`0000Sooooo0_l00004ooooo`;o00003_ooool2o`0008[ooooo000L
ooooo`03o`000?oooooooooo07oooooo0_l00006ooooo`;o00003Oooool2o`0000Gooooo0_l00008
ooooo`;o0000X?ooool001cooooo00?o0000ooooooooool0Qoooool2o`0000gooooo0_l00005oooo
o`;o00002?ooool2o`000:3ooooo000Looooo`03o`000?oooooooooo08;ooooo1?l000001?oooooo
0000o`000?ooool2o`000003ooooool0003o000000kooooo0_l00008ooooo`;o00000oooool2o`00
09_ooooo000Looooo`03o`000?oooooooooo08;ooooo1Ol00003ooooo`;o000000?oooooo`000?l0
00000oooool4o`0000Oooooo0_l0000=ooooo`;o0000Voooool001cooooo0_l00020ooooo`;o0000
1?ooool2o`0000?ooooo0_l00006ooooo`Co0000/oooool001cooooo00?o0000ooooooooool0Oooo
ool2o`000<Sooooo000Looooo`03o`000?oooooooooo08?ooooo0_l00034ooooo`007?ooool00ol0
003oooooooooo`20ooooo`;o000000?oooooo`000?l00000a?ooool001cooooo00?o0000oooooooo
ool0P?ooool2o`000<Oooooo000Looooo`03o`000?oooooooooo0=;ooooo0_l0001eooooo`007?oo
ool00ol0003oooooooooo`3Booooo`;o0000MOooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`2@ooooo`;o0000]oooool001cooooo00?o0000oooooooo
ool0T?ooool2o`000;Oooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`37ooooo`;o0000P?ooool0
01cooooo00?o0000ooooooooool0[oooool2o`0001Kooooo0_l00020ooooo`007?ooool00ol0003o
ooooooooo`2_ooooo`;o0000V?ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`2;ooooo`;o0000_?ooool001cooooo00?o0000ooooooooool0Roooool2o`000;co
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`2booooo`;o0000UOooool001cooooo00?o0000oooo
ooooool0Woooool2o`00017ooooo0_l0002Eooooo`007?ooool00ol0003oooooooooo`2Oooooo`;o
0000Z?ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2
o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooo
oom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool0
01Cooooo00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o0000oooooooo
ool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oo
oooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`004_ooool00omE
EEGoIVIVo`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Q
ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05_ooool4o`000008oa0@4?oo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool0
1Oo<c<co8B4Qo`000?lQ8B7oc<c<08cooooo002Rooooo`05o`000?ooooooooooooooool000002Ooo
ool6o`0000cooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00GoEEEEogMgMoooooooV9RHob4Q8@03ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40S?ooool00:;o
oooo00Go0000ooooooooooooooooo`00000Kooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@4003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000008cooooo002Rooooo`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oiRHV?oo
ooooV9RHob4Q8@03ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80S?ooool00:;ooooo00Go0000ohN7
QoooooooZJVYo`00000Kooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?mEEEGo0000oa0@4?o<c<`00oooool01Oo<c<co0000o`000?l0003oc<c<08co
oooo002Qooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool06Oooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool00omEEEGoQhN7ooooo`05ooooo`05
oa0@4?nj^[[ooooookZj^_l@4100S?ooool00<;ooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00?ogMgMoa0@4?nHV9P01Oooool01Ol0003o^[Zjoooooonj^[[o
000008cooooo0030ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04
ooooo`04olc<c?m4A4Co0000oa0@40?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2<ooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1074) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.45813 .63037 Mdot
.43112 .65233 Mdot
.66323 .44081 Mdot
.41057 .46506 Mdot
.48795 .79037 Mdot
.63392 .41508 Mdot
.59817 .59402 Mdot
.65293 .59925 Mdot
.65595 .42459 Mdot
.5168 .6476 Mdot
.6038 .60464 Mdot
.42937 .38137 Mdot
.62081 .60775 Mdot
.39123 .47311 Mdot
.28422 .76927 Mdot
.32946 .47509 Mdot
.40553 .68887 Mdot
.53306 .29623 Mdot
.39158 .51727 Mdot
.61377 .39586 Mdot
.42592 .61282 Mdot
.40079 .46473 Mdot
.46532 .65457 Mdot
.39067 .4729 Mdot
.42113 .47257 Mdot
.4135 .67447 Mdot
.39029 .66676 Mdot
.42264 .42768 Mdot
.40768 .49255 Mdot
.64567 .58741 Mdot
.35218 .3032 Mdot
.35269 .80591 Mdot
.42034 .51749 Mdot
.76222 .64254 Mdot
.65276 .60827 Mdot
.32882 .70552 Mdot
.64442 .39821 Mdot
.64225 .59651 Mdot
.64944 .61226 Mdot
.60482 .57115 Mdot
.64034 .60977 Mdot
.4166 .66594 Mdot
.65779 .64442 Mdot
.55153 .61934 Mdot
.36134 .50496 Mdot
.54656 .75024 Mdot
.25354 .39255 Mdot
.37045 .42784 Mdot
.40527 .68391 Mdot
.58139 .39697 Mdot
.7205 .66355 Mdot
.59496 .59467 Mdot
.67915 .46435 Mdot
.80005 .72507 Mdot
.6361 .58797 Mdot
.37532 .50921 Mdot
.66347 .41496 Mdot
.39673 .45656 Mdot
.38811 .46933 Mdot
.21967 .57496 Mdot
.42237 .4196 Mdot
.49578 .3162 Mdot
.47364 .66909 Mdot
.52684 .38974 Mdot
.65247 .41207 Mdot
.64236 .61713 Mdot
.42846 .64047 Mdot
.62171 .60143 Mdot
.44847 .4091 Mdot
.65792 .38696 Mdot
.37271 .42724 Mdot
.62998 .61857 Mdot
.40539 .64271 Mdot
.38843 .42994 Mdot
.75316 .37817 Mdot
.15158 .55193 Mdot
.47949 .30613 Mdot
.26916 .63813 Mdot
.23262 .6194 Mdot
.61125 .30634 Mdot
.3757 .49235 Mdot
.41609 .21614 Mdot
.21479 .67252 Mdot
.46298 .66995 Mdot
.38733 .5345 Mdot
.59265 .49052 Mdot
.39188 .43363 Mdot
.4952 .73396 Mdot
.37211 .50335 Mdot
.80674 .42963 Mdot
.65092 .42868 Mdot
.44244 .67178 Mdot
.40915 .46803 Mdot
.43392 .43834 Mdot
.26279 .43724 Mdot
.3771 .40458 Mdot
.42112 .43596 Mdot
.41969 .62414 Mdot
.6039 .61541 Mdot
.34743 .39427 Mdot
.66907 .6313 Mdot
.67214 .45956 Mdot
.35232 .43321 Mdot
.644 .38715 Mdot
.4084 .6332 Mdot
.38972 .42301 Mdot
.6417 .62653 Mdot
.3525 .45243 Mdot
.68743 .65938 Mdot
.4324 .64896 Mdot
.43533 .4461 Mdot
.49152 .30779 Mdot
.64611 .2289 Mdot
.44797 .67053 Mdot
.63093 .29165 Mdot
.36695 .49403 Mdot
.41319 .43951 Mdot
.43045 .6552 Mdot
.66869 .4512 Mdot
.47846 .73644 Mdot
.46193 .68688 Mdot
.60392 .56916 Mdot
.46945 .6774 Mdot
.42828 .51813 Mdot
.64559 .4211 Mdot
.71284 .57827 Mdot
.64338 .52579 Mdot
.35334 .2826 Mdot
.39388 .43783 Mdot
.57894 .6878 Mdot
.62021 .42793 Mdot
.43292 .67096 Mdot
.61815 .59906 Mdot
.31483 .4756 Mdot
.45113 .64666 Mdot
.61268 .58553 Mdot
.50694 .29288 Mdot
.73335 .52131 Mdot
.42563 .70115 Mdot
.57184 .64487 Mdot
.631 .63939 Mdot
.5972 .58217 Mdot
.78959 .61396 Mdot
.42319 .64783 Mdot
.51938 .31858 Mdot
.62321 .5862 Mdot
.31908 .33755 Mdot
.41834 .50078 Mdot
.43203 .24349 Mdot
.36729 .20134 Mdot
.76705 .6301 Mdot
.75981 .48346 Mdot
.51872 .34218 Mdot
.59076 .60136 Mdot
.43193 .46914 Mdot
.40688 .66788 Mdot
.41283 .65836 Mdot
.39754 .41217 Mdot
.41653 .46663 Mdot
.37845 .42544 Mdot
.43829 .45741 Mdot
.19692 .57051 Mdot
.34733 .45867 Mdot
.29314 .27492 Mdot
.44493 .67673 Mdot
.42564 .45593 Mdot
.67386 .42433 Mdot
.45037 .43751 Mdot
.63919 .61373 Mdot
.40426 .45597 Mdot
.41369 .46179 Mdot
.429 .42346 Mdot
.59495 .5983 Mdot
.33996 .78334 Mdot
.43663 .18368 Mdot
.41189 .79715 Mdot
.71379 .3491 Mdot
.62049 .4131 Mdot
.40039 .43358 Mdot
.49967 .32742 Mdot
.33265 .67826 Mdot
.37358 .48615 Mdot
.71454 .22359 Mdot
.41919 .44474 Mdot
.44652 .78454 Mdot
.43143 .53232 Mdot
.43369 .81254 Mdot
.41692 .23018 Mdot
.43359 .47432 Mdot
.28575 .43073 Mdot
.37737 .63641 Mdot
.56506 .62935 Mdot
.63818 .60903 Mdot
.67395 .43134 Mdot
.66534 .42865 Mdot
.62289 .54997 Mdot
.48212 .62543 Mdot
.32152 .50656 Mdot
.40196 .39416 Mdot
.68488 .43631 Mdot
.47738 .65379 Mdot
.53133 .31764 Mdot
.42881 .62494 Mdot
.13507 .43816 Mdot
.71456 .64934 Mdot
.64427 .5528 Mdot
.48726 .30005 Mdot
.65039 .44693 Mdot
.67707 .45913 Mdot
.50301 .33339 Mdot
.36219 .44991 Mdot
.42343 .64285 Mdot
.73634 .70878 Mdot
.47219 .60466 Mdot
.77557 .66956 Mdot
.40571 .64822 Mdot
.52969 .63315 Mdot
.60947 .59361 Mdot
.63354 .39564 Mdot
.41525 .43725 Mdot
.3722 .44955 Mdot
.4201 .61182 Mdot
.37573 .42849 Mdot
.34145 .54288 Mdot
.41438 .42775 Mdot
.72981 .6129 Mdot
.47765 .3089 Mdot
.62282 .55018 Mdot
.34455 .27961 Mdot
.45413 .6365 Mdot
.5143 .24318 Mdot
.66794 .40141 Mdot
.31616 .67702 Mdot
.62435 .61976 Mdot
.49798 .30117 Mdot
.67042 .40263 Mdot
.53211 .32072 Mdot
.44702 .46931 Mdot
.62665 .45065 Mdot
.48767 .31957 Mdot
.27307 .70064 Mdot
.42482 .49419 Mdot
.19112 .56523 Mdot
.59665 .61389 Mdot
.45826 .69176 Mdot
.42227 .42012 Mdot
.62309 .39612 Mdot
.41428 .52246 Mdot
.75005 .44517 Mdot
.71411 .58112 Mdot
.63776 .46194 Mdot
.61463 .3531 Mdot
.5036 .30115 Mdot
.72285 .45634 Mdot
.58964 .67661 Mdot
.4021 .67494 Mdot
.34589 .44073 Mdot
.41083 .82364 Mdot
.623 .58665 Mdot
.35811 .45777 Mdot
.73868 .59135 Mdot
.62616 .58889 Mdot
.39577 .45481 Mdot
.61601 .6323 Mdot
.41314 .65503 Mdot
.54964 .21159 Mdot
.40443 .68683 Mdot
.37125 .5015 Mdot
.63467 .6293 Mdot
.65132 .45992 Mdot
.41427 .6807 Mdot
.35667 .44451 Mdot
.40336 .42275 Mdot
.55725 .47862 Mdot
.42943 .45242 Mdot
.37647 .78928 Mdot
.43071 .43963 Mdot
.67021 .42572 Mdot
.38616 .40427 Mdot
.80622 .36229 Mdot
.65869 .51819 Mdot
.42744 .64066 Mdot
.62377 .45319 Mdot
.65934 .42515 Mdot
.58711 .25299 Mdot
.69892 .45036 Mdot
.36162 .48786 Mdot
.6198 .40447 Mdot
.48451 .24447 Mdot
.62901 .57609 Mdot
.35227 .42357 Mdot
.54191 .6161 Mdot
.57934 .39417 Mdot
.68418 .44588 Mdot
.32758 .4934 Mdot
.39501 .65664 Mdot
.41015 .46805 Mdot
.67818 .45019 Mdot
.47188 .62934 Mdot
.35531 .49143 Mdot
.4509 .55751 Mdot
.55689 .47924 Mdot
.60787 .58292 Mdot
.40665 .5429 Mdot
.35363 .43893 Mdot
.64346 .39151 Mdot
.43607 .62998 Mdot
.6531 .59192 Mdot
.41991 .67611 Mdot
.58202 .80134 Mdot
.68933 .64905 Mdot
.231 .64354 Mdot
.53708 .33885 Mdot
.78207 .46246 Mdot
.47048 .82532 Mdot
.73119 .32354 Mdot
.43128 .30407 Mdot
.64124 .7925 Mdot
.67762 .43742 Mdot
.75039 .58741 Mdot
.66208 .42442 Mdot
.40389 .48691 Mdot
.64504 .41556 Mdot
.46139 .82676 Mdot
.41662 .42906 Mdot
.64167 .4089 Mdot
.55878 .23071 Mdot
.42045 .45884 Mdot
.45057 .66798 Mdot
.2693 .74434 Mdot
.75041 .32466 Mdot
.74499 .63377 Mdot
.62266 .44183 Mdot
.40035 .33726 Mdot
.42415 .43656 Mdot
.41183 .40413 Mdot
.41546 .69071 Mdot
.36606 .40796 Mdot
.53035 .32306 Mdot
.49128 .29479 Mdot
.50763 .46553 Mdot
.45737 .19541 Mdot
.39009 .38632 Mdot
.41406 .68332 Mdot
.20644 .50978 Mdot
.76086 .38792 Mdot
.71979 .37201 Mdot
.58594 .60661 Mdot
.31895 .76404 Mdot
.40413 .56809 Mdot
.68084 .63223 Mdot
.55063 .60546 Mdot
.44208 .6606 Mdot
.35485 .79246 Mdot
.63873 .60484 Mdot
.27828 .51591 Mdot
.31713 .37456 Mdot
.36619 .45263 Mdot
.61201 .61564 Mdot
.42578 .38562 Mdot
.78891 .36195 Mdot
.23555 .39487 Mdot
.33206 .25132 Mdot
.35444 .49559 Mdot
.74288 .36889 Mdot
.4101 .4489 Mdot
.45641 .74761 Mdot
.42982 .4369 Mdot
.424 .6821 Mdot
.50214 .68908 Mdot
.52923 .46238 Mdot
.39102 .20146 Mdot
.70785 .65341 Mdot
.51959 .34158 Mdot
.41144 .43112 Mdot
.36654 .45378 Mdot
.52297 .3052 Mdot
.45698 .67522 Mdot
.43862 .46012 Mdot
.48494 .2587 Mdot
.38145 .43485 Mdot
.64413 .60576 Mdot
.30349 .28748 Mdot
.38578 .6667 Mdot
.3635 .40381 Mdot
.4705 .63491 Mdot
.61004 .57966 Mdot
.65074 .60739 Mdot
.32342 .4551 Mdot
.62689 .56262 Mdot
.41537 .45215 Mdot
.235 .35591 Mdot
.44617 .69078 Mdot
.38996 .55205 Mdot
.46268 .65261 Mdot
.26913 .64635 Mdot
.64699 .62538 Mdot
.71901 .60699 Mdot
.34314 .39347 Mdot
.63508 .60714 Mdot
.67462 .67013 Mdot
.37567 .38965 Mdot
.3342 .47257 Mdot
.81421 .46706 Mdot
.63225 .45002 Mdot
.54218 .46479 Mdot
.65503 .61495 Mdot
.35726 .43458 Mdot
.34781 .42294 Mdot
.60705 .58018 Mdot
.25083 .49758 Mdot
.64414 .2622 Mdot
.42221 .43036 Mdot
.43256 .68613 Mdot
.43081 .67167 Mdot
.34337 .48609 Mdot
.35356 .461 Mdot
.63776 .43787 Mdot
.61815 .44624 Mdot
.60544 .41344 Mdot
.55544 .47837 Mdot
.72371 .60963 Mdot
.58518 .76134 Mdot
.6046 .57157 Mdot
.6048 .70657 Mdot
.79532 .407 Mdot
.45219 .47532 Mdot
.61308 .42026 Mdot
.37016 .46247 Mdot
.40783 .46458 Mdot
.65246 .58962 Mdot
.74526 .61624 Mdot
.46916 .4238 Mdot
.44384 .69536 Mdot
.65739 .61057 Mdot
.30785 .43072 Mdot
.6426 .72418 Mdot
.49113 .31739 Mdot
.79871 .5735 Mdot
.63233 .61961 Mdot
.44627 .66007 Mdot
.6364 .63221 Mdot
.37258 .44614 Mdot
.38159 .51328 Mdot
.43489 .66085 Mdot
.48384 .32662 Mdot
.43842 .42367 Mdot
.39852 .4523 Mdot
.52167 .14809 Mdot
.75072 .36412 Mdot
.70322 .58188 Mdot
.43543 .46597 Mdot
.34239 .4266 Mdot
.53557 .30959 Mdot
.3778 .43857 Mdot
.39474 .41631 Mdot
.587 .19933 Mdot
.6738 .5604 Mdot
.51995 .28377 Mdot
.28219 .52641 Mdot
.40283 .65429 Mdot
.38786 .82021 Mdot
.62967 .39654 Mdot
.63527 .5584 Mdot
.65139 .25616 Mdot
.67088 .46458 Mdot
.76068 .44177 Mdot
.37718 .81612 Mdot
.54509 .47041 Mdot
.49946 .27204 Mdot
.45952 .40037 Mdot
.4144 .42017 Mdot
.4097 .44491 Mdot
.50525 .32569 Mdot
.41913 .64875 Mdot
.52826 .43575 Mdot
.17998 .49507 Mdot
.40626 .45804 Mdot
.33438 .53565 Mdot
.27935 .71771 Mdot
.57497 .38584 Mdot
.52536 .33086 Mdot
.48254 .3203 Mdot
.41131 .43455 Mdot
.60504 .21435 Mdot
.41266 .67486 Mdot
.35631 .44553 Mdot
.34994 .47642 Mdot
.62415 .44511 Mdot
.4374 .64675 Mdot
.67858 .43668 Mdot
.71531 .6089 Mdot
.43602 .78905 Mdot
.53414 .14319 Mdot
.65134 .61553 Mdot
.3584 .75741 Mdot
.63657 .57986 Mdot
.40187 .22402 Mdot
.675 .46535 Mdot
.37119 .48907 Mdot
.44232 .63109 Mdot
.35392 .44736 Mdot
.36056 .47024 Mdot
.36217 .45135 Mdot
.43178 .40398 Mdot
.74552 .26078 Mdot
.49543 .33539 Mdot
.35252 .40689 Mdot
.66757 .43358 Mdot
.36092 .76686 Mdot
.17108 .58958 Mdot
.37428 .45554 Mdot
.40319 .4256 Mdot
.45425 .66167 Mdot
.38994 .40923 Mdot
.62962 .57748 Mdot
.43305 .62938 Mdot
.43557 .44368 Mdot
.33716 .76632 Mdot
.41723 .49039 Mdot
.42743 .80381 Mdot
.64046 .63178 Mdot
.6528 .67328 Mdot
.36617 .39679 Mdot
.70871 .5753 Mdot
.5421 .46461 Mdot
.61656 .40237 Mdot
.66162 .59031 Mdot
.64608 .40002 Mdot
.20151 .42136 Mdot
.41012 .51556 Mdot
.4295 .47043 Mdot
.34777 .42535 Mdot
.62038 .40904 Mdot
.49008 .75098 Mdot
.70523 .4856 Mdot
.30472 .4565 Mdot
.62924 .42834 Mdot
.47538 .65331 Mdot
.55127 .37988 Mdot
.45195 .63773 Mdot
.503 .28352 Mdot
.60553 .60546 Mdot
.4949 .34253 Mdot
.75296 .63655 Mdot
.43273 .65126 Mdot
.41139 .61535 Mdot
.62554 .41034 Mdot
.59454 .5267 Mdot
.73857 .7694 Mdot
.55148 .41773 Mdot
.40084 .26326 Mdot
.4211 .69264 Mdot
.38287 .50019 Mdot
.36325 .244 Mdot
.57736 .5371 Mdot
.6489 .40226 Mdot
.38438 .48642 Mdot
.57672 .21386 Mdot
.63662 .43762 Mdot
.35028 .42758 Mdot
.65579 .45341 Mdot
.62825 .61578 Mdot
.62598 .4386 Mdot
.40653 .69854 Mdot
.39259 .42481 Mdot
.71586 .78611 Mdot
.55105 .29299 Mdot
.4311 .44472 Mdot
.65667 .61424 Mdot
.47535 .53091 Mdot
.3697 .47308 Mdot
.5207 .29424 Mdot
.64053 .42113 Mdot
.55889 .44188 Mdot
.42449 .43144 Mdot
.62186 .41548 Mdot
.46049 .63495 Mdot
.66169 .5891 Mdot
.49424 .40285 Mdot
.72115 .58986 Mdot
.41212 .6881 Mdot
.64861 .65697 Mdot
.65554 .58583 Mdot
.34795 .41762 Mdot
.34607 .45913 Mdot
.43366 .68158 Mdot
.51275 .21259 Mdot
.397 .40482 Mdot
.37578 .49223 Mdot
.66917 .43475 Mdot
.63989 .40206 Mdot
.52221 .21637 Mdot
.66584 .45317 Mdot
.39121 .5138 Mdot
.4317 .6813 Mdot
.40382 .47555 Mdot
.4515 .65816 Mdot
.37859 .41098 Mdot
.48031 .63626 Mdot
.45547 .68244 Mdot
.70457 .46909 Mdot
.3953 .48179 Mdot
.41838 .54167 Mdot
.3598 .46072 Mdot
.37991 .42922 Mdot
.64255 .43828 Mdot
.51737 .3337 Mdot
.31639 .46113 Mdot
.51212 .27671 Mdot
.52905 .30863 Mdot
.375 .65005 Mdot
.62582 .44575 Mdot
.51161 .31498 Mdot
.20529 .61905 Mdot
.60869 .4255 Mdot
.49853 .32109 Mdot
.18811 .61869 Mdot
.65275 .61221 Mdot
.40326 .68938 Mdot
.42018 .46018 Mdot
.64413 .78604 Mdot
.25754 .34754 Mdot
.66301 .46515 Mdot
.43167 .44267 Mdot
.37056 .46599 Mdot
.46438 .67867 Mdot
.22869 .30646 Mdot
.63313 .37981 Mdot
.41231 .48475 Mdot
.43241 .64004 Mdot
.26002 .26377 Mdot
.66898 .41888 Mdot
.50042 .32319 Mdot
.59432 .5993 Mdot
.43924 .71541 Mdot
.6413 .52396 Mdot
.60004 .58727 Mdot
.64847 .49049 Mdot
.72676 .64966 Mdot
.36601 .49361 Mdot
.61339 .41919 Mdot
.81091 .56859 Mdot
.44653 .58958 Mdot
.5918 .63883 Mdot
.39591 .34411 Mdot
.44351 .6629 Mdot
.62851 .57824 Mdot
.50501 .34513 Mdot
.40894 .64104 Mdot
.44873 .68356 Mdot
.64643 .58099 Mdot
.49811 .4469 Mdot
.53701 .60669 Mdot
.64742 .60576 Mdot
.80417 .4431 Mdot
.63622 .76747 Mdot
.6115 .4146 Mdot
.52827 .31137 Mdot
.72468 .70295 Mdot
.41652 .66709 Mdot
.32163 .76557 Mdot
.81297 .55021 Mdot
.42124 .43618 Mdot
.51508 .31132 Mdot
.52071 .76499 Mdot
.18704 .46437 Mdot
.62803 .58859 Mdot
.53748 .48014 Mdot
.4903 .3515 Mdot
.41465 .41648 Mdot
.32092 .3596 Mdot
.39256 .48886 Mdot
.60535 .59746 Mdot
.21834 .59149 Mdot
.44701 .65954 Mdot
.65813 .59971 Mdot
.79722 .57648 Mdot
.41215 .45503 Mdot
.38975 .48558 Mdot
.32833 .29801 Mdot
.40944 .65278 Mdot
.61767 .39832 Mdot
.36482 .49175 Mdot
.40119 .45394 Mdot
.34003 .49922 Mdot
.38267 .5471 Mdot
.63769 .22579 Mdot
.40854 .48529 Mdot
.71368 .62852 Mdot
.3619 .40384 Mdot
.39313 .48007 Mdot
.47192 .63657 Mdot
.58936 .15919 Mdot
.71566 .61262 Mdot
.40406 .45464 Mdot
.38927 .4987 Mdot
.6459 .57926 Mdot
.5296 .58144 Mdot
.59529 .52958 Mdot
.5802 .48587 Mdot
.41819 .3189 Mdot
.43456 .40467 Mdot
.44132 .63598 Mdot
.48896 .30956 Mdot
.34133 .47412 Mdot
.44148 .63705 Mdot
.44377 .46424 Mdot
.6328 .43556 Mdot
.60945 .42863 Mdot
.5851 .66044 Mdot
.50514 .31619 Mdot
.29146 .32543 Mdot
.59614 .71428 Mdot
.67139 .43762 Mdot
.42656 .47026 Mdot
.64767 .56394 Mdot
.67852 .45174 Mdot
.60604 .50123 Mdot
.34613 .52038 Mdot
.40959 .66686 Mdot
.44458 .67243 Mdot
.43467 .24272 Mdot
.74623 .50619 Mdot
.52576 .16342 Mdot
.62396 .61607 Mdot
.42955 .42017 Mdot
.57833 .67755 Mdot
.44636 .67136 Mdot
.37881 .24059 Mdot
.51074 .31309 Mdot
.62786 .58678 Mdot
.71995 .37652 Mdot
.45197 .6505 Mdot
.41348 .69595 Mdot
.39132 .50273 Mdot
.38766 .45182 Mdot
.43675 .29502 Mdot
.46372 .34583 Mdot
.61388 .57738 Mdot
.52498 .30649 Mdot
.67378 .40686 Mdot
.40452 .48918 Mdot
.46528 .66176 Mdot
.69973 .72442 Mdot
.38179 .49907 Mdot
.64148 .44048 Mdot
.44101 .66512 Mdot
.51777 .30035 Mdot
.52759 .30281 Mdot
.38034 .43044 Mdot
.21227 .51267 Mdot
.63629 .59538 Mdot
.4497 .66762 Mdot
.67906 .6981 Mdot
.38792 .40325 Mdot
.39242 .4475 Mdot
.44939 .50213 Mdot
.63979 .57769 Mdot
.60729 .67224 Mdot
.48439 .34008 Mdot
.42029 .65635 Mdot
.42734 .48199 Mdot
.49837 .31432 Mdot
.59555 .67287 Mdot
.64496 .46345 Mdot
.63215 .44366 Mdot
.52267 .29602 Mdot
.52178 .31038 Mdot
.51666 .29394 Mdot
.31286 .76338 Mdot
.41334 .70596 Mdot
.41943 .56026 Mdot
.40592 .40528 Mdot
.41935 .24148 Mdot
.31055 .45158 Mdot
.65306 .62856 Mdot
.63795 .45201 Mdot
.36151 .4664 Mdot
.36829 .50017 Mdot
.42643 .53202 Mdot
.41646 .55136 Mdot
.38799 .65915 Mdot
.43414 .64811 Mdot
.4308 .50297 Mdot
.63162 .45219 Mdot
.14643 .40778 Mdot
.56729 .84196 Mdot
.3553 .40065 Mdot
.5536 .56451 Mdot
.46441 .66266 Mdot
.62874 .56705 Mdot
.603 .51233 Mdot
.6256 .63175 Mdot
.42377 .66132 Mdot
.40531 .48812 Mdot
.61022 .71212 Mdot
.52872 .29939 Mdot
.36677 .42721 Mdot
.61483 .58832 Mdot
.37262 .42525 Mdot
.59923 .58864 Mdot
.5502 .79978 Mdot
.79004 .39034 Mdot
.41953 .44353 Mdot
.34207 .421 Mdot
.41254 .34155 Mdot
.37498 .45741 Mdot
.55261 .3559 Mdot
.46289 .66454 Mdot
.48236 .1774 Mdot
.40895 .50055 Mdot
.30765 .61579 Mdot
.39131 .40225 Mdot
.58179 .22078 Mdot
.3871 .44744 Mdot
.57978 .37904 Mdot
.41887 .42423 Mdot
.39137 .41844 Mdot
.63084 .63048 Mdot
.64718 .58101 Mdot
.42979 .61751 Mdot
.62139 .39694 Mdot
.41027 .80292 Mdot
.39712 .45018 Mdot
.72184 .58853 Mdot
.69615 .62281 Mdot
.52418 .31249 Mdot
.42201 .66271 Mdot
.23755 .28031 Mdot
.59899 .62307 Mdot
.69382 .31299 Mdot
.51722 .22704 Mdot
.65217 .53168 Mdot
.59387 .49565 Mdot
.48007 .72602 Mdot
.5 .30379 Mdot
.4147 .41526 Mdot
.74183 .66164 Mdot
.74975 .38746 Mdot
.32418 .50693 Mdot
.65997 .59897 Mdot
.32172 .66658 Mdot
.71481 .71043 Mdot
.48127 .34436 Mdot
.49198 .34236 Mdot
.59613 .59677 Mdot
.58622 .39367 Mdot
.44985 .40073 Mdot
.5093 .31082 Mdot
.66758 .44764 Mdot
.6091 .41565 Mdot
.71375 .39371 Mdot
.4129 .66846 Mdot
.78134 .5988 Mdot
.55807 .73592 Mdot
.60127 .58732 Mdot
.53554 .26377 Mdot
.42014 .71406 Mdot
.39425 .68263 Mdot
.63022 .40144 Mdot
.64625 .44058 Mdot
.3972 .67973 Mdot
.40538 .50696 Mdot
.45261 .50523 Mdot
.40673 .45533 Mdot
.50918 .3285 Mdot
.38023 .44951 Mdot
.63628 .43272 Mdot
.62593 .59356 Mdot
.65201 .43886 Mdot
.60732 .62989 Mdot
.59905 .75214 Mdot
.36186 .44033 Mdot
.3964 .4226 Mdot
.25608 .34576 Mdot
.4555 .62606 Mdot
.70232 .67186 Mdot
.73582 .60869 Mdot
.66351 .42653 Mdot
.3957 .4157 Mdot
.45856 .63783 Mdot
.47864 .31827 Mdot
.25509 .34443 Mdot
.34896 .44333 Mdot
.46382 .65967 Mdot
.42232 .48021 Mdot
.23288 .65866 Mdot
.73476 .28936 Mdot
.42333 .67569 Mdot
.35677 .20946 Mdot
.40648 .49189 Mdot
.48462 .70823 Mdot
.34227 .44211 Mdot
.45758 .25548 Mdot
.39442 .40479 Mdot
.40537 .64859 Mdot
.40098 .46 Mdot
.41734 .63434 Mdot
.67106 .41734 Mdot
.6099 .56922 Mdot
.42653 .69575 Mdot
.34544 .46674 Mdot
.43181 .87146 Mdot
.60725 .60323 Mdot
.41369 .43449 Mdot
.60353 .61886 Mdot
.42671 .6375 Mdot
.41048 .6912 Mdot
.17136 .49781 Mdot
.68922 .56969 Mdot
.62943 .61519 Mdot
.41392 .48161 Mdot
.52817 .71648 Mdot
.40255 .48041 Mdot
.42328 .28618 Mdot
.35751 .5063 Mdot
.38836 .40411 Mdot
.15119 .54656 Mdot
.62734 .57437 Mdot
.54634 .17398 Mdot
.17462 .51648 Mdot
.30238 .75294 Mdot
.45881 .70491 Mdot
.4803 .33982 Mdot
.35045 .78888 Mdot
.71718 .60375 Mdot
.62417 .42231 Mdot
.36131 .46389 Mdot
.391 .70125 Mdot
.64185 .59366 Mdot
.51432 .33461 Mdot
.41938 .44268 Mdot
.64712 .44231 Mdot
.65663 .27724 Mdot
.58974 .59922 Mdot
.41708 .66509 Mdot
.44936 .69233 Mdot
.31334 .22309 Mdot
.43345 .47548 Mdot
.39893 .42038 Mdot
.60402 .60075 Mdot
.44331 .58462 Mdot
.50403 .2991 Mdot
.59403 .23594 Mdot
.62724 .61508 Mdot
.56483 .51953 Mdot
.42672 .64579 Mdot
.36983 .46445 Mdot
.47936 .7629 Mdot
.71474 .35903 Mdot
.32614 .55781 Mdot
.5022 .32762 Mdot
.41454 .29048 Mdot
.40459 .64989 Mdot
.61828 .5945 Mdot
.74409 .52738 Mdot
.40778 .52859 Mdot
.37564 .46607 Mdot
.40819 .29034 Mdot
.51327 .44501 Mdot
.32563 .2579 Mdot
.35311 .42822 Mdot
.5205 .4387 Mdot
.36459 .41825 Mdot
.38351 .53104 Mdot
.38806 .51189 Mdot
.39535 .44161 Mdot
.46399 .66096 Mdot
.33015 .50953 Mdot
.6196 .42161 Mdot
.26583 .43699 Mdot
.57071 .49372 Mdot
.42734 .43645 Mdot
.40077 .4862 Mdot
.35901 .60048 Mdot
.67633 .63689 Mdot
.44019 .68949 Mdot
.4407 .60148 Mdot
.62032 .56252 Mdot
.43468 .52714 Mdot
.6256 .3899 Mdot
.32937 .50037 Mdot
.64549 .43675 Mdot
.46295 .64728 Mdot
.66548 .42352 Mdot
.59653 .58011 Mdot
.6124 .42327 Mdot
.72544 .61165 Mdot
.63402 .5821 Mdot
.4057 .6637 Mdot
.38738 .43095 Mdot
.65681 .61099 Mdot
.33784 .29714 Mdot
.50862 .32807 Mdot
.16831 .50651 Mdot
.43605 .47659 Mdot
.64608 .53471 Mdot
.45136 .55565 Mdot
.65055 .43763 Mdot
.68048 .24318 Mdot
.45373 .68453 Mdot
.50683 .28573 Mdot
.46269 .64451 Mdot
.8247 .45674 Mdot
.52312 .32675 Mdot
.19296 .63037 Mdot
.77044 .51352 Mdot
.56612 .4154 Mdot
.40838 .50538 Mdot
.32632 .36386 Mdot
.67604 .40807 Mdot
.64106 .59253 Mdot
.76043 .5009 Mdot
.38833 .41822 Mdot
.73322 .33447 Mdot
.42355 .61699 Mdot
.61941 .40185 Mdot
.61988 .60212 Mdot
.65698 .60203 Mdot
.35002 .46011 Mdot
.56151 .25936 Mdot
.36256 .42454 Mdot
.73035 .50295 Mdot
.41539 .31211 Mdot
.47232 .43547 Mdot
.41377 .42796 Mdot
.65204 .39374 Mdot
.42213 .47993 Mdot
.45836 .35994 Mdot
.77777 .62711 Mdot
.4308 .40628 Mdot
.73806 .61826 Mdot
.55127 .30023 Mdot
.43343 .65695 Mdot
.3439 .4031 Mdot
.68243 .55439 Mdot
.42828 .47934 Mdot
.86407 .42727 Mdot
.49828 .31901 Mdot
.70664 .56478 Mdot
.37039 .40263 Mdot
.35199 .47336 Mdot
.36829 .3638 Mdot
.4157 .73159 Mdot
.71785 .35892 Mdot
.38232 .46423 Mdot
.36128 .32389 Mdot
.6102 .61669 Mdot
.35677 .43035 Mdot
.41131 .44191 Mdot
.37523 .7101 Mdot
.64974 .5891 Mdot
.66094 .43594 Mdot
.67837 .46419 Mdot
.62866 .37359 Mdot
.53992 .30795 Mdot
.54637 .49783 Mdot
.39796 .24078 Mdot
.74754 .32658 Mdot
.49157 .30082 Mdot
.41464 .49445 Mdot
.44713 .3605 Mdot
.38663 .49653 Mdot
.51021 .34419 Mdot
.64592 .58544 Mdot
.44005 .69083 Mdot
.55296 .65612 Mdot
.6615 .38939 Mdot
.35144 .42422 Mdot
.52984 .32921 Mdot
.40753 .66786 Mdot
.47601 .35647 Mdot
.42705 .65526 Mdot
.62847 .61188 Mdot
.62014 .55919 Mdot
.51168 .33919 Mdot
.45666 .64145 Mdot
.68212 .64713 Mdot
.19168 .46616 Mdot
.36401 .51095 Mdot
.56585 .59934 Mdot
.4533 .6274 Mdot
.39625 .64188 Mdot
.42642 .62293 Mdot
.37265 .43039 Mdot
.55073 .56576 Mdot
.3335 .48466 Mdot
.61175 .57936 Mdot
.65545 .45276 Mdot
.49811 .25573 Mdot
.63962 .75418 Mdot
.51114 .25525 Mdot
.44041 .433 Mdot
.40817 .45942 Mdot
.41153 .43486 Mdot
.36502 .50388 Mdot
.72049 .51695 Mdot
.35565 .45251 Mdot
.62272 .62997 Mdot
.642 .42671 Mdot
.42196 .41861 Mdot
.65078 .46485 Mdot
.50218 .71339 Mdot
.48696 .31201 Mdot
.536 .49068 Mdot
.40751 .84018 Mdot
.40801 .67568 Mdot
.6674 .45335 Mdot
.62431 .4204 Mdot
.50667 .29315 Mdot
.64182 .59755 Mdot
.42443 .65011 Mdot
.46447 .26106 Mdot
.52113 .29832 Mdot
.40126 .45753 Mdot
.68594 .4745 Mdot
.72668 .33822 Mdot
.40298 .41113 Mdot
.36705 .48015 Mdot
.64005 .46299 Mdot
.58365 .39375 Mdot
.78256 .67683 Mdot
.34486 .25999 Mdot
.51531 .33662 Mdot
.48488 .32445 Mdot
.39441 .66074 Mdot
.33478 .42542 Mdot
.60914 .58149 Mdot
.29243 .29673 Mdot
.48548 .50622 Mdot
.29377 .31631 Mdot
.49787 .40127 Mdot
.34984 .44759 Mdot
.23165 .46844 Mdot
.41355 .45485 Mdot
.45987 .68075 Mdot
.41773 .64202 Mdot
.42358 .68946 Mdot
.63742 .59173 Mdot
.28543 .65685 Mdot
.63144 .62892 Mdot
.43771 .8444 Mdot
.40141 .65517 Mdot
.71309 .5402 Mdot
.64903 .39357 Mdot
.37425 .39414 Mdot
.51206 .29973 Mdot
.63431 .64309 Mdot
.4508 .41166 Mdot
.61578 .21569 Mdot
.61879 .41292 Mdot
.40488 .66395 Mdot
.47664 .72756 Mdot
.51178 .82571 Mdot
.60107 .51946 Mdot
.31241 .42011 Mdot
.35414 .36127 Mdot
.52573 .31342 Mdot
.31753 .54997 Mdot
.52132 .34171 Mdot
.62004 .58444 Mdot
.39558 .42624 Mdot
.39269 .43445 Mdot
.37341 .41184 Mdot
.35783 .44821 Mdot
.63296 .56652 Mdot
.41787 .40428 Mdot
.80622 .36231 Mdot
.61 .43151 Mdot
.25808 .68358 Mdot
.49768 .31043 Mdot
.66224 .59846 Mdot
.64171 .42871 Mdot
.61487 .4506 Mdot
.35362 .27003 Mdot
.4211 .42934 Mdot
.36011 .46443 Mdot
.70514 .32686 Mdot
.35581 .42372 Mdot
.31702 .41756 Mdot
.62225 .41739 Mdot
.50843 .25585 Mdot
.48749 .30227 Mdot
.4908 .3381 Mdot
.64989 .59516 Mdot
.45946 .64214 Mdot
.50981 .32075 Mdot
.67122 .4204 Mdot
.44622 .44884 Mdot
.35106 .48153 Mdot
.4503 .62511 Mdot
.81681 .54194 Mdot
.48269 .34714 Mdot
.48977 .71748 Mdot
.4259 .63284 Mdot
.42012 .7105 Mdot
.37648 .46754 Mdot
.33223 .51894 Mdot
.40486 .71701 Mdot
.50402 .29019 Mdot
.66071 .59334 Mdot
.57757 .47628 Mdot
.61013 .58815 Mdot
.41567 .65156 Mdot
.34824 .48434 Mdot
.41332 .65026 Mdot
.43566 .46226 Mdot
.30197 .80842 Mdot
.39124 .43991 Mdot
.76362 .33772 Mdot
.42934 .25947 Mdot
.63297 .41736 Mdot
.68809 .64371 Mdot
.62605 .40126 Mdot
.42117 .6349 Mdot
.34394 .4757 Mdot
.485 .33813 Mdot
.26495 .7225 Mdot
.41247 .71172 Mdot
.63014 .43601 Mdot
.6148 .38687 Mdot
.6349 .58003 Mdot
.4209 .41621 Mdot
.37248 .46269 Mdot
.64097 .40714 Mdot
.47435 .46429 Mdot
.4559 .65179 Mdot
.40364 .42387 Mdot
.39966 .47129 Mdot
.63118 .4159 Mdot
.19802 .45122 Mdot
.44747 .72922 Mdot
.39919 .43286 Mdot
.75041 .56079 Mdot
.65452 .62679 Mdot
.38863 .50794 Mdot
.39037 .39263 Mdot
.51671 .30779 Mdot
.30325 .71506 Mdot
.76943 .63939 Mdot
.64848 .63082 Mdot
.62712 .39551 Mdot
.43135 .47962 Mdot
.64652 .39196 Mdot
.34796 .47448 Mdot
.36106 .7423 Mdot
.61457 .40833 Mdot
.35953 .48301 Mdot
.34372 .40834 Mdot
.4105 .64935 Mdot
.35325 .45748 Mdot
.37463 .61083 Mdot
.6806 .43526 Mdot
.35403 .47258 Mdot
.21329 .51705 Mdot
.64613 .61365 Mdot
.3495 .40244 Mdot
.48876 .32004 Mdot
.47065 .25677 Mdot
.59353 .72519 Mdot
.73165 .5927 Mdot
.48877 .32869 Mdot
.37251 .42338 Mdot
.61129 .38865 Mdot
.59747 .59219 Mdot
.72568 .30886 Mdot
.39356 .41282 Mdot
.60583 .59806 Mdot
.62474 .5952 Mdot
.49207 .32287 Mdot
.46477 .15477 Mdot
.39987 .39526 Mdot
.37522 .45479 Mdot
.37088 .64656 Mdot
.47206 .66531 Mdot
.38181 .44521 Mdot
.39632 .49894 Mdot
.61623 .62808 Mdot
.32734 .4029 Mdot
.33836 .64317 Mdot
.55931 .22895 Mdot
.61992 .63763 Mdot
.54952 .43144 Mdot
.61695 .39288 Mdot
.50096 .30887 Mdot
.43428 .66401 Mdot
.49987 .35289 Mdot
.61975 .4355 Mdot
.40995 .4947 Mdot
.59837 .61848 Mdot
.36557 .56791 Mdot
.59615 .59213 Mdot
.72409 .58249 Mdot
.46649 .64278 Mdot
.56237 .68111 Mdot
.82446 .35302 Mdot
.56097 .74135 Mdot
.67876 .63095 Mdot
.52406 .31253 Mdot
.64047 .48564 Mdot
.40234 .46789 Mdot
.2894 .5183 Mdot
.38416 .42785 Mdot
.21797 .51915 Mdot
.66103 .45395 Mdot
.60531 .41262 Mdot
.39694 .42926 Mdot
.41823 .30488 Mdot
.60018 .58363 Mdot
.62821 .57579 Mdot
.35598 .47059 Mdot
.63528 .6074 Mdot
.38673 .45466 Mdot
.64111 .43595 Mdot
.5879 .1823 Mdot
.41303 .44862 Mdot
.33367 .46411 Mdot
.60369 .53835 Mdot
.15934 .55046 Mdot
.7712 .5593 Mdot
.23883 .45393 Mdot
.54403 .82326 Mdot
.63431 .60725 Mdot
.3255 .4678 Mdot
.54828 .42429 Mdot
.6437 .46462 Mdot
.6794 .6482 Mdot
.38086 .43899 Mdot
.3772 .43797 Mdot
.39855 .41723 Mdot
.39 .48625 Mdot
.29432 .52779 Mdot
.41228 .56882 Mdot
.2339 .57102 Mdot
.35964 .46793 Mdot
.3026 .36826 Mdot
.65413 .61588 Mdot
.43086 .61242 Mdot
.50391 .35399 Mdot
.35001 .4484 Mdot
.40707 .57102 Mdot
.65872 .62153 Mdot
.44009 .8447 Mdot
.64264 .58481 Mdot
.65905 .42385 Mdot
.62212 .56729 Mdot
.43061 .45336 Mdot
.43137 .67234 Mdot
.57132 .48218 Mdot
.72555 .45682 Mdot
.62447 .42326 Mdot
.4311 .44446 Mdot
.69414 .55554 Mdot
.62163 .42384 Mdot
.50346 .71524 Mdot
.436 .67115 Mdot
.35011 .32401 Mdot
.41692 .64229 Mdot
.35878 .48333 Mdot
.36844 .49096 Mdot
.58767 .64091 Mdot
.60049 .57893 Mdot
.41984 .63904 Mdot
.50436 .1431 Mdot
.52391 .34082 Mdot
.42065 .6862 Mdot
.42592 .51404 Mdot
.504 .55786 Mdot
.43569 .67818 Mdot
.46543 .29556 Mdot
.63712 .58739 Mdot
.39788 .65912 Mdot
.42854 .51332 Mdot
.80639 .50004 Mdot
.51488 .28841 Mdot
.61066 .37926 Mdot
.69033 .40301 Mdot
.67983 .44656 Mdot
.65476 .58031 Mdot
.62455 .40784 Mdot
.61515 .62032 Mdot
.68589 .67479 Mdot
.26457 .38966 Mdot
.63991 .55794 Mdot
.64344 .5696 Mdot
.6259 .41099 Mdot
.40963 .42236 Mdot
.69025 .42687 Mdot
.34282 .49616 Mdot
.45705 .44307 Mdot
.6251 .62238 Mdot
.40528 .65041 Mdot
.408 .69737 Mdot
.31329 .3652 Mdot
.45127 .69153 Mdot
.64566 .43825 Mdot
.74022 .30098 Mdot
.74573 .64214 Mdot
.60906 .61197 Mdot
.64217 .57187 Mdot
.40206 .48224 Mdot
.64718 .40063 Mdot
.66484 .40373 Mdot
.62364 .58043 Mdot
.28229 .47471 Mdot
.33032 .4483 Mdot
.40464 .6259 Mdot
.39989 .65911 Mdot
.42736 .67946 Mdot
.42215 .6257 Mdot
.33047 .61148 Mdot
.63577 .58526 Mdot
.40839 .64381 Mdot
.35807 .47821 Mdot
.37772 .43908 Mdot
.57826 .48617 Mdot
.48885 .33427 Mdot
.44368 .45991 Mdot
.39975 .51117 Mdot
.37369 .46849 Mdot
.62961 .44118 Mdot
.45727 .47414 Mdot
.61606 .39957 Mdot
.61623 .37805 Mdot
.62248 .44895 Mdot
.71894 .605 Mdot
.36671 .35576 Mdot
.58352 .82375 Mdot
.41271 .48476 Mdot
.4704 .60046 Mdot
.65294 .39856 Mdot
.65429 .22988 Mdot
.58995 .66783 Mdot
.39478 .41444 Mdot
.7135 .36138 Mdot
.63851 .4067 Mdot
.44662 .69629 Mdot
.38395 .43931 Mdot
.62615 .37179 Mdot
.49105 .3063 Mdot
.40486 .52134 Mdot
.67983 .4575 Mdot
.45029 .638 Mdot
.53293 .33913 Mdot
.40113 .64912 Mdot
.63366 .45554 Mdot
.34547 .40639 Mdot
.75989 .75495 Mdot
.64865 .38182 Mdot
.19568 .60823 Mdot
.46183 .70997 Mdot
.40406 .42297 Mdot
.673 .45062 Mdot
.47053 .66973 Mdot
.65732 .58234 Mdot
.50292 .4963 Mdot
.44473 .69123 Mdot
.60557 .4125 Mdot
.67973 .45518 Mdot
.62236 .41846 Mdot
.43794 .65112 Mdot
.34041 .48132 Mdot
.44605 .65201 Mdot
.62501 .56749 Mdot
.41332 .46526 Mdot
.46014 .82543 Mdot
.4569 .59125 Mdot
.42308 .63509 Mdot
.65856 .44262 Mdot
.53416 .30554 Mdot
.42078 .44689 Mdot
.18714 .57075 Mdot
.43503 .44755 Mdot
.60348 .60979 Mdot
.54993 .19738 Mdot
.36065 .56739 Mdot
.40103 .40421 Mdot
.40102 .48291 Mdot
.61992 .57519 Mdot
.42198 .43479 Mdot
.40204 .40588 Mdot
.70878 .59575 Mdot
.4365 .64455 Mdot
.401 .46264 Mdot
.66407 .44594 Mdot
.71888 .67412 Mdot
.32972 .46727 Mdot
.63749 .29307 Mdot
.37647 .31591 Mdot
.51702 .17997 Mdot
.38618 .42526 Mdot
.3208 .28032 Mdot
.38142 .4861 Mdot
.36412 .431 Mdot
.4095 .48091 Mdot
.24902 .44 Mdot
.61533 .41928 Mdot
.63258 .42764 Mdot
.51212 .28805 Mdot
.3734 .31797 Mdot
.51485 .30975 Mdot
.64411 .5916 Mdot
.61339 .29421 Mdot
.61467 .40919 Mdot
.44972 .63679 Mdot
.36892 .42236 Mdot
.65411 .38409 Mdot
.36752 .46219 Mdot
.43177 .45696 Mdot
.64478 .38726 Mdot
.64136 .38211 Mdot
.7162 .57804 Mdot
.48747 .31598 Mdot
.42691 .69313 Mdot
.43775 .48408 Mdot
.52946 .31118 Mdot
.34006 .47595 Mdot
.41918 .23724 Mdot
.4294 .69167 Mdot
.4391 .64576 Mdot
.42405 .70331 Mdot
.41085 .49421 Mdot
.42788 .44615 Mdot
.6297 .62845 Mdot
.45478 .63764 Mdot
.6455 .61123 Mdot
.55865 .47772 Mdot
.62267 .27846 Mdot
.38071 .43895 Mdot
.4995 .69696 Mdot
.50947 .3033 Mdot
.65358 .42919 Mdot
.67151 .29531 Mdot
.51816 .28797 Mdot
.4347 .45123 Mdot
.64925 .39147 Mdot
.50608 .34352 Mdot
.31177 .40518 Mdot
.6541 .79338 Mdot
.5363 .31675 Mdot
.35813 .47643 Mdot
.36934 .37496 Mdot
.23083 .39153 Mdot
.5392 .31176 Mdot
.59926 .61357 Mdot
.41351 .49362 Mdot
.43963 .56598 Mdot
.48452 .34779 Mdot
.69523 .6825 Mdot
.63938 .41758 Mdot
.78963 .56213 Mdot
.46071 .42997 Mdot
.27207 .48173 Mdot
.50689 .34945 Mdot
.42255 .65295 Mdot
.466 .62428 Mdot
.37992 .47485 Mdot
.54003 .31496 Mdot
.60712 .634 Mdot
.64464 .42004 Mdot
.71926 .61787 Mdot
.44016 .65249 Mdot
.529 .67368 Mdot
.65229 .44975 Mdot
.50504 .69611 Mdot
.56284 .2161 Mdot
.47244 .45236 Mdot
.23756 .43613 Mdot
.75288 .41251 Mdot
.413 .49702 Mdot
.52887 .335 Mdot
.65161 .62695 Mdot
.5955 .60875 Mdot
.62372 .61366 Mdot
.69616 .63862 Mdot
.589 .50442 Mdot
.65163 .4616 Mdot
.73348 .41834 Mdot
.50004 .31346 Mdot
.30266 .34734 Mdot
.34103 .46209 Mdot
.4091 .45735 Mdot
.43153 .42347 Mdot
.35392 .43183 Mdot
.38468 .48141 Mdot
.64154 .60267 Mdot
.70028 .63639 Mdot
.56013 .44721 Mdot
.43558 .68577 Mdot
.51853 .25992 Mdot
.64955 .39401 Mdot
.62641 .45527 Mdot
.50076 .33814 Mdot
.4685 .74009 Mdot
.66471 .46107 Mdot
.66491 .42656 Mdot
.43776 .44418 Mdot
.45036 .64894 Mdot
.32462 .50001 Mdot
.37644 .49189 Mdot
.64849 .43085 Mdot
.53161 .38816 Mdot
.35334 .6274 Mdot
.3985 .5366 Mdot
.53368 .34509 Mdot
.54555 .56408 Mdot
.53881 .3146 Mdot
.33761 .45694 Mdot
.63603 .21963 Mdot
.61855 .43306 Mdot
.65554 .41107 Mdot
.52395 .33749 Mdot
.47217 .71809 Mdot
.44014 .66193 Mdot
.61457 .45068 Mdot
.60719 .61958 Mdot
.37794 .49595 Mdot
.6393 .27222 Mdot
.48447 .70139 Mdot
.57699 .26677 Mdot
.61654 .61299 Mdot
.66547 .40653 Mdot
.41733 .41267 Mdot
.35952 .47742 Mdot
.52437 .30829 Mdot
.51738 .79574 Mdot
.41118 .51633 Mdot
.30483 .75632 Mdot
.79744 .39931 Mdot
.8141 .51929 Mdot
.37569 .46588 Mdot
.43552 .64598 Mdot
.67451 .46534 Mdot
.52764 .31042 Mdot
.44674 .43376 Mdot
.63235 .80496 Mdot
.44385 .61743 Mdot
.61913 .58844 Mdot
.54359 .43749 Mdot
.60461 .51301 Mdot
.43833 .46887 Mdot
.38471 .42898 Mdot
.36711 .43524 Mdot
.73045 .7307 Mdot
.63675 .44333 Mdot
.46639 .66207 Mdot
.50155 .32994 Mdot
.4536 .68935 Mdot
.63122 .42263 Mdot
.54134 .67862 Mdot
.42473 .42852 Mdot
.44573 .61901 Mdot
.42387 .65575 Mdot
.63616 .58103 Mdot
.64867 .57182 Mdot
.55182 .46046 Mdot
.39143 .44122 Mdot
.68496 .4333 Mdot
.40729 .65343 Mdot
.68768 .4697 Mdot
.5241 .32455 Mdot
.64781 .62392 Mdot
.35893 .46565 Mdot
.61872 .4286 Mdot
.41977 .40486 Mdot
.44585 .67535 Mdot
.665 .42504 Mdot
.71309 .57708 Mdot
.48562 .32362 Mdot
.36689 .44693 Mdot
.51752 .35552 Mdot
.628 .39458 Mdot
.40132 .47071 Mdot
.44171 .74733 Mdot
.54591 .31288 Mdot
.71209 .47997 Mdot
.6508 .45955 Mdot
.71929 .58675 Mdot
.4169 .69985 Mdot
.66772 .69034 Mdot
.65612 .41569 Mdot
.44497 .75022 Mdot
.57687 .77718 Mdot
.44394 .47671 Mdot
.418 .67113 Mdot
.63263 .47528 Mdot
.37392 .82449 Mdot
.20278 .46269 Mdot
.41349 .43617 Mdot
.66303 .45559 Mdot
.52651 .33222 Mdot
.60987 .61301 Mdot
.63786 .29156 Mdot
.45864 .36184 Mdot
.62392 .38323 Mdot
.40762 .48331 Mdot
.42512 .64036 Mdot
.63215 .59022 Mdot
.6166 .72129 Mdot
.66987 .4309 Mdot
.65091 .45355 Mdot
.41372 .41039 Mdot
.50972 .31382 Mdot
.19537 .51934 Mdot
.63783 .4356 Mdot
.71259 .33662 Mdot
.65209 .49115 Mdot
.53083 .32802 Mdot
.37268 .48465 Mdot
.33059 .35798 Mdot
.37175 .5061 Mdot
.20793 .64088 Mdot
.6297 .39811 Mdot
.44152 .68481 Mdot
.37904 .42588 Mdot
.54843 .22517 Mdot
.64927 .4272 Mdot
.55592 .56208 Mdot
.59518 .35866 Mdot
.63587 .58606 Mdot
.67765 .29789 Mdot
.37533 .44944 Mdot
.59824 .58702 Mdot
.51002 .30364 Mdot
.3994 .43749 Mdot
.42734 .44922 Mdot
.46387 .68276 Mdot
.61883 .5834 Mdot
.60245 .78366 Mdot
.65765 .59777 Mdot
.63871 .63188 Mdot
.43617 .70621 Mdot
.3898 .46562 Mdot
.65988 .427 Mdot
.63984 .40506 Mdot
.45359 .44337 Mdot
.66335 .22402 Mdot
.44192 .66038 Mdot
.53763 .26602 Mdot
.74619 .71467 Mdot
.47068 .43663 Mdot
.667 .29112 Mdot
.51346 .7942 Mdot
.60376 .63138 Mdot
.35727 .46932 Mdot
.43871 .63375 Mdot
.61015 .44591 Mdot
.65563 .4504 Mdot
.34481 .48535 Mdot
.62915 .59602 Mdot
.4948 .30012 Mdot
.66989 .40254 Mdot
.56222 .25865 Mdot
.35983 .43996 Mdot
.73566 .37075 Mdot
.67676 .44253 Mdot
.29146 .76397 Mdot
.65028 .47429 Mdot
.41944 .67594 Mdot
.43043 .45811 Mdot
.44535 .69401 Mdot
.50747 .33146 Mdot
.54712 .4462 Mdot
.62743 .59441 Mdot
.46499 .39709 Mdot
.85391 .45283 Mdot
.62105 .41244 Mdot
.46317 .66473 Mdot
.40033 .40376 Mdot
.44328 .36619 Mdot
.37928 .45217 Mdot
.38404 .37582 Mdot
.55266 .31072 Mdot
.63288 .62193 Mdot
.60171 .61053 Mdot
.40618 .4676 Mdot
.51161 .29575 Mdot
.66567 .40846 Mdot
.64699 .41973 Mdot
.12846 .53609 Mdot
.70587 .4558 Mdot
.43997 .28949 Mdot
.37367 .44024 Mdot
.60701 .40642 Mdot
.66877 .73187 Mdot
.60429 .6022 Mdot
.34192 .45297 Mdot
.62361 .39165 Mdot
.79723 .44998 Mdot
.47623 .24213 Mdot
.38062 .48183 Mdot
.41888 .39542 Mdot
.6049 .61854 Mdot
.31094 .31922 Mdot
.62984 .45259 Mdot
.3523 .50452 Mdot
.60309 .56741 Mdot
.52332 .20758 Mdot
.79651 .59674 Mdot
.42629 .69296 Mdot
.58398 .38082 Mdot
.64181 .60196 Mdot
.45694 .46206 Mdot
.49479 .31312 Mdot
.68039 .42253 Mdot
.62837 .43768 Mdot
.41809 .47668 Mdot
.41516 .4037 Mdot
.41659 .34485 Mdot
.46052 .66865 Mdot
.65432 .61122 Mdot
.3926 .42294 Mdot
.53365 .64506 Mdot
.37004 .41384 Mdot
.63757 .62612 Mdot
.71937 .806 Mdot
.4372 .48843 Mdot
.37866 .45429 Mdot
.19342 .51514 Mdot
.44308 .6924 Mdot
.45303 .69195 Mdot
.77413 .36322 Mdot
.373 .44079 Mdot
.70006 .31572 Mdot
.42648 .69456 Mdot
.44359 .66399 Mdot
.67169 .52867 Mdot
.41702 .4486 Mdot
.26741 .33669 Mdot
.59883 .59286 Mdot
.6189 .63134 Mdot
.445 .65308 Mdot
.43019 .50164 Mdot
.59778 .62375 Mdot
.31285 .5611 Mdot
.64615 .39942 Mdot
.61949 .21011 Mdot
.45048 .67384 Mdot
.53394 .46572 Mdot
.60967 .60953 Mdot
.43373 .84377 Mdot
.71749 .38624 Mdot
.40525 .42162 Mdot
.36568 .44434 Mdot
.50561 .30426 Mdot
.44007 .482 Mdot
.60499 .41421 Mdot
.63564 .60755 Mdot
.20614 .58522 Mdot
.42244 .68891 Mdot
.3894 .44653 Mdot
.4961 .7155 Mdot
.6045 .74174 Mdot
.77863 .52077 Mdot
.43275 .65737 Mdot
.41412 .6702 Mdot
.63474 .45438 Mdot
.66701 .45198 Mdot
.38558 .47178 Mdot
.6165 .57814 Mdot
.44764 .63391 Mdot
.63106 .62568 Mdot
.62002 .43496 Mdot
.66179 .4303 Mdot
.6132 .41004 Mdot
.35392 .51058 Mdot
.66651 .43333 Mdot
.5508 .2511 Mdot
.5301 .68224 Mdot
.3939 .6822 Mdot
.83727 .53782 Mdot
.61761 .71952 Mdot
.46474 .5304 Mdot
.48628 .34204 Mdot
.62842 .39399 Mdot
.63478 .56973 Mdot
.40037 .48057 Mdot
.36344 .46356 Mdot
.61238 .37147 Mdot
.61552 .57114 Mdot
.51317 .33353 Mdot
.60688 .57366 Mdot
.49157 .32123 Mdot
.71988 .36855 Mdot
.42375 .41851 Mdot
.35476 .48439 Mdot
.63976 .60748 Mdot
.6664 .42811 Mdot
.63874 .42639 Mdot
.53731 .3217 Mdot
.50207 .46234 Mdot
.62014 .42118 Mdot
.44938 .6742 Mdot
.31905 .60226 Mdot
.67772 .46042 Mdot
.38301 .44166 Mdot
.39527 .23833 Mdot
.2975 .52126 Mdot
.35905 .5024 Mdot
.67694 .55047 Mdot
.30638 .25584 Mdot
.37897 .42063 Mdot
.32107 .23556 Mdot
.71996 .58895 Mdot
.44774 .69011 Mdot
.65657 .45622 Mdot
.60895 .44229 Mdot
.34198 .39664 Mdot
.46901 .34779 Mdot
.45096 .44299 Mdot
.43671 .69574 Mdot
.47337 .63677 Mdot
.81029 .4614 Mdot
.19646 .61208 Mdot
.51454 .34437 Mdot
.49784 .33988 Mdot
.65394 .41477 Mdot
.17987 .44152 Mdot
.40019 .53333 Mdot
.51416 .33629 Mdot
.26757 .38 Mdot
.40527 .48643 Mdot
.40893 .28237 Mdot
.70681 .34567 Mdot
.4385 .64897 Mdot
.3262 .36279 Mdot
.65505 .42283 Mdot
.45801 .67633 Mdot
.54384 .64631 Mdot
.44129 .46668 Mdot
.42825 .69082 Mdot
.62709 .62685 Mdot
.76016 .44692 Mdot
.41135 .69143 Mdot
.40614 .23509 Mdot
.62294 .57945 Mdot
.65499 .50092 Mdot
.32288 .34418 Mdot
.75527 .23945 Mdot
.63891 .60207 Mdot
.63538 .384 Mdot
.64006 .40601 Mdot
.64753 .41844 Mdot
.45742 .68072 Mdot
.66014 .39845 Mdot
.46139 .66344 Mdot
.21574 .40801 Mdot
.50085 .46433 Mdot
.51389 .33851 Mdot
.69185 .57453 Mdot
.418 .65984 Mdot
.71874 .27754 Mdot
.83408 .38241 Mdot
.35513 .46623 Mdot
.65178 .58407 Mdot
.51265 .34259 Mdot
.24984 .71748 Mdot
.5135 .30607 Mdot
.56526 .39473 Mdot
.57857 .1938 Mdot
.39129 .45154 Mdot
.32734 .68473 Mdot
.48535 .33656 Mdot
.42688 .64781 Mdot
.4041 .46656 Mdot
.66343 .65456 Mdot
.50782 .30911 Mdot
.49538 .30101 Mdot
.39148 .47329 Mdot
.40488 .66324 Mdot
.65813 .43157 Mdot
.61133 .56669 Mdot
.52191 .28381 Mdot
.48632 .64314 Mdot
.42047 .49673 Mdot
.42691 .48573 Mdot
.59157 .52926 Mdot
.45368 .33918 Mdot
.63428 .60661 Mdot
.24951 .3786 Mdot
.66516 .45245 Mdot
.59934 .45846 Mdot
.77499 .3778 Mdot
.68946 .56538 Mdot
.62824 .40133 Mdot
.62582 .398 Mdot
.38377 .47903 Mdot
.44971 .3326 Mdot
.53178 .19157 Mdot
.68625 .60595 Mdot
.67449 .46326 Mdot
.64595 .42181 Mdot
.46427 .62566 Mdot
.81377 .45867 Mdot
.44454 .4305 Mdot
.64352 .63343 Mdot
.62065 .43025 Mdot
.36321 .74494 Mdot
.5065 .31691 Mdot
.6831 .25221 Mdot
.41985 .41667 Mdot
.39687 .42273 Mdot
.62214 .60593 Mdot
.63129 .62936 Mdot
.59464 .65092 Mdot
.8085 .41967 Mdot
.27005 .30908 Mdot
.66139 .7084 Mdot
.36015 .73311 Mdot
.4385 .6135 Mdot
.42198 .63574 Mdot
.71023 .61756 Mdot
.65999 .60879 Mdot
.37773 .42363 Mdot
.44699 .63454 Mdot
.76823 .49989 Mdot
.43635 .59064 Mdot
.4219 .28937 Mdot
.59986 .25192 Mdot
.43505 .45703 Mdot
.44525 .64242 Mdot
.44709 .68755 Mdot
.43539 .62758 Mdot
.71939 .58975 Mdot
.38204 .4637 Mdot
.41725 .42887 Mdot
.37782 .41531 Mdot
.36066 .54654 Mdot
.35532 .44893 Mdot
.69002 .59471 Mdot
.56527 .52417 Mdot
.25178 .66341 Mdot
.36898 .50949 Mdot
.60792 .63145 Mdot
.43356 .48261 Mdot
.50973 .29506 Mdot
.40676 .4816 Mdot
.42772 .28647 Mdot
.61045 .59654 Mdot
.45969 .71808 Mdot
.65993 .7045 Mdot
.42391 .42388 Mdot
.4895 .30221 Mdot
.44353 .55071 Mdot
.54453 .80253 Mdot
.4639 .33945 Mdot
.44963 .67323 Mdot
.63984 .39659 Mdot
.62977 .56965 Mdot
.66137 .42233 Mdot
.36888 .51457 Mdot
.6619 .53969 Mdot
.52155 .75914 Mdot
.53619 .45 Mdot
.35047 .44249 Mdot
.46127 .47413 Mdot
.44705 .66943 Mdot
.6487 .39116 Mdot
.3912 .63616 Mdot
.3753 .42989 Mdot
.50459 .32842 Mdot
.50412 .30972 Mdot
.59779 .66352 Mdot
.4043 .7907 Mdot
.6633 .68509 Mdot
.62481 .60737 Mdot
.63667 .43715 Mdot
.51244 .34802 Mdot
.49018 .62728 Mdot
.66669 .60472 Mdot
.62154 .57453 Mdot
.62378 .58344 Mdot
.39949 .49557 Mdot
.61595 .39944 Mdot
.24344 .6477 Mdot
.60671 .41064 Mdot
.42643 .43796 Mdot
.63857 .44553 Mdot
.61887 .40171 Mdot
.50012 .30659 Mdot
.64959 .59357 Mdot
.62537 .44359 Mdot
.35767 .48257 Mdot
.4119 .68533 Mdot
.51606 .45405 Mdot
.44455 .24996 Mdot
.23608 .67573 Mdot
.25745 .69226 Mdot
.40119 .67654 Mdot
.40424 .81575 Mdot
.6466 .63564 Mdot
.28149 .47171 Mdot
.73556 .56307 Mdot
.35259 .48968 Mdot
.73551 .28116 Mdot
.6512 .46196 Mdot
.64214 .38608 Mdot
.37494 .48646 Mdot
.58661 .38745 Mdot
.38615 .44888 Mdot
.63768 .44885 Mdot
.51785 .26187 Mdot
.35555 .39595 Mdot
.66889 .42041 Mdot
.3422 .49928 Mdot
.41934 .45172 Mdot
.4391 .64757 Mdot
.67504 .44964 Mdot
.34237 .44872 Mdot
.1763 .63522 Mdot
.64043 .62734 Mdot
.69836 .5673 Mdot
.39462 .22709 Mdot
.64285 .60204 Mdot
.42273 .68549 Mdot
.4564 .44314 Mdot
.51763 .30354 Mdot
.41724 .65327 Mdot
.49217 .23506 Mdot
.48668 .33563 Mdot
.73324 .28582 Mdot
.45168 .66765 Mdot
.67696 .45945 Mdot
.49577 .30719 Mdot
.32909 .47721 Mdot
.67604 .41081 Mdot
.4865 .51253 Mdot
.63166 .39725 Mdot
.37183 .46188 Mdot
.71853 .62386 Mdot
.65192 .62168 Mdot
.41155 .43737 Mdot
.6662 .39906 Mdot
.71838 .60802 Mdot
.40313 .4932 Mdot
.39428 .48209 Mdot
.81866 .53256 Mdot
.69259 .27832 Mdot
.52535 .31701 Mdot
.47016 .65978 Mdot
.35805 .47854 Mdot
.48975 .31177 Mdot
.59859 .33657 Mdot
.42145 .49219 Mdot
.44134 .6188 Mdot
.38353 .54229 Mdot
.67754 .42767 Mdot
.6479 .60814 Mdot
.54937 .47002 Mdot
.49038 .30753 Mdot
.42605 .14518 Mdot
.60992 .41489 Mdot
.3383 .45244 Mdot
.3502 .43834 Mdot
.77622 .55034 Mdot
.45305 .68182 Mdot
.27557 .30776 Mdot
.36671 .44678 Mdot
.38691 .55066 Mdot
.40121 .43982 Mdot
.57315 .42198 Mdot
.4414 .66207 Mdot
.37467 .45603 Mdot
.51274 .67308 Mdot
.33138 .458 Mdot
.48994 .30464 Mdot
.19638 .48303 Mdot
.4108 .49876 Mdot
.84912 .64273 Mdot
.69293 .31426 Mdot
.66911 .4235 Mdot
.71425 .63029 Mdot
.17062 .38461 Mdot
.68201 .6779 Mdot
.46244 .66066 Mdot
.50893 .78725 Mdot
.66028 .42813 Mdot
.69362 .6916 Mdot
.39676 .82044 Mdot
.41953 .45411 Mdot
.43843 .46817 Mdot
.56501 .39498 Mdot
.60336 .41526 Mdot
.68528 .44602 Mdot
.37596 .51324 Mdot
.37858 .53228 Mdot
.6629 .44052 Mdot
.35216 .47374 Mdot
.32558 .48924 Mdot
.62058 .56459 Mdot
.40306 .6771 Mdot
.61759 .61815 Mdot
.64154 .58232 Mdot
.25808 .50944 Mdot
.80568 .42696 Mdot
.64161 .62511 Mdot
.64414 .63585 Mdot
.41568 .27896 Mdot
.39455 .3436 Mdot
.48517 .34682 Mdot
.35108 .77905 Mdot
.64519 .41633 Mdot
.38497 .46273 Mdot
.39987 .68092 Mdot
.26779 .46768 Mdot
.66723 .31722 Mdot
.54566 .18914 Mdot
.37552 .42708 Mdot
.65139 .42407 Mdot
.72186 .59218 Mdot
.32085 .49378 Mdot
.61138 .48029 Mdot
.39761 .42007 Mdot
.65728 .38665 Mdot
.31317 .63445 Mdot
.47683 .73031 Mdot
.67206 .47989 Mdot
.42224 .60831 Mdot
.39181 .42826 Mdot
.45079 .6765 Mdot
.61961 .61593 Mdot
.50748 .29839 Mdot
.52443 .3181 Mdot
.39752 .4733 Mdot
.45088 .50937 Mdot
.71157 .36371 Mdot
.42149 .44741 Mdot
.41385 .47524 Mdot
.72017 .5891 Mdot
.41329 .47316 Mdot
.35442 .43295 Mdot
.36395 .42238 Mdot
.3454 .41917 Mdot
.63393 .63243 Mdot
.49694 .71284 Mdot
.37585 .51946 Mdot
.32204 .49096 Mdot
.59355 .58262 Mdot
.54284 .79055 Mdot
.64678 .5849 Mdot
.46466 .82669 Mdot
.60573 .61234 Mdot
.52083 .32911 Mdot
.74292 .603 Mdot
.4601 .48759 Mdot
.41273 .63609 Mdot
.66391 .60022 Mdot
.49561 .32862 Mdot
.63022 .61214 Mdot
.64875 .44962 Mdot
.77182 .66792 Mdot
.46528 .61331 Mdot
.3038 .28452 Mdot
.61062 .667 Mdot
.7165 .45754 Mdot
.61574 .43361 Mdot
.44343 .65784 Mdot
.35282 .63808 Mdot
.36121 .42223 Mdot
.49009 .31345 Mdot
.38731 .47485 Mdot
.64439 .63103 Mdot
.65279 .41996 Mdot
.19408 .47674 Mdot
.52248 .30641 Mdot
.83183 .5172 Mdot
.63792 .41902 Mdot
.3819 .41002 Mdot
.64144 .63379 Mdot
.84898 .50853 Mdot
.62558 .62136 Mdot
.48542 .46919 Mdot
.41206 .62262 Mdot
.23524 .44497 Mdot
.41861 .66661 Mdot
.65354 .46827 Mdot
.77408 .70337 Mdot
.31389 .75309 Mdot
.40628 .67064 Mdot
.7236 .42388 Mdot
.43393 .47484 Mdot
.4287 .48504 Mdot
.46297 .73194 Mdot
.46661 .64604 Mdot
.35385 .4625 Mdot
.70933 .57422 Mdot
.53684 .70306 Mdot
.68891 .29644 Mdot
.63801 .3923 Mdot
.38042 .44791 Mdot
.59572 .57714 Mdot
.60742 .57403 Mdot
.60854 .40856 Mdot
.64762 .58415 Mdot
.41672 .42983 Mdot
.41844 .66211 Mdot
.67773 .40557 Mdot
.51779 .32053 Mdot
.17192 .59574 Mdot
.50965 .3506 Mdot
.62778 .40266 Mdot
.34581 .40658 Mdot
.66215 .43034 Mdot
.20546 .29187 Mdot
.41001 .42613 Mdot
.43208 .69378 Mdot
.39018 .4894 Mdot
.39533 .43055 Mdot
.4376 .4731 Mdot
.65719 .44573 Mdot
.30439 .26881 Mdot
.35379 .47759 Mdot
.62756 .59292 Mdot
.28273 .69985 Mdot
.43639 .47903 Mdot
.51109 .26802 Mdot
.39869 .31987 Mdot
.7349 .41448 Mdot
.39594 .66397 Mdot
.6583 .40094 Mdot
.4162 .68554 Mdot
.43771 .5947 Mdot
.42322 .68569 Mdot
.29006 .68851 Mdot
.34439 .64085 Mdot
.34934 .22987 Mdot
.21371 .52607 Mdot
.28619 .41965 Mdot
.4691 .6536 Mdot
.55432 .36226 Mdot
.42858 .63161 Mdot
.45125 .68103 Mdot
.48741 .92163 Mdot
.41331 .63865 Mdot
.37685 .44336 Mdot
.44049 .44394 Mdot
.578 .73955 Mdot
.38581 .27967 Mdot
.40821 .47167 Mdot
.36595 .48593 Mdot
.50548 .30048 Mdot
.43853 .53205 Mdot
.66329 .54068 Mdot
.74381 .30996 Mdot
.62649 .74061 Mdot
.38965 .47504 Mdot
.35904 .48164 Mdot
.35438 .51858 Mdot
.86053 .5642 Mdot
.27214 .51322 Mdot
.469 .64366 Mdot
.45377 .47698 Mdot
.22677 .67687 Mdot
.41411 .41988 Mdot
.39694 .49911 Mdot
.43563 .462 Mdot
.65986 .42762 Mdot
.43804 .61561 Mdot
.44815 .48665 Mdot
.74439 .36164 Mdot
.42723 .42838 Mdot
.69256 .57081 Mdot
.2159 .34034 Mdot
.37428 .44975 Mdot
.41175 .63152 Mdot
.4221 .48089 Mdot
.45397 .66425 Mdot
.43194 .64206 Mdot
.33849 .4212 Mdot
.33614 .72621 Mdot
.42357 .6185 Mdot
.42739 .43921 Mdot
.65619 .43761 Mdot
.33895 .78197 Mdot
.36971 .46075 Mdot
.52868 .31029 Mdot
.36711 .44422 Mdot
.4949 .29517 Mdot
.41838 .46803 Mdot
.60932 .40567 Mdot
.34683 .56114 Mdot
.65373 .41082 Mdot
.23468 .34453 Mdot
.61701 .39417 Mdot
.82111 .52643 Mdot
.45865 .63021 Mdot
.71585 .61399 Mdot
.49143 .1611 Mdot
.69002 .56033 Mdot
.53965 .58211 Mdot
.52764 .56104 Mdot
.61738 .57757 Mdot
.44029 .69742 Mdot
.28811 .34405 Mdot
.77456 .51627 Mdot
.76411 .55692 Mdot
.61703 .4105 Mdot
.49669 .14664 Mdot
.58426 .18605 Mdot
.37043 .494 Mdot
.315 .68814 Mdot
.24253 .58435 Mdot
.41582 .49543 Mdot
.45763 .44539 Mdot
.61705 .37301 Mdot
.34697 .44432 Mdot
.52872 .6453 Mdot
.62712 .41062 Mdot
.49335 .32734 Mdot
.44557 .68281 Mdot
.50987 .28951 Mdot
.77206 .52989 Mdot
.52603 .56692 Mdot
.62916 .44369 Mdot
.3346 .44419 Mdot
.38205 .49041 Mdot
.44604 .6496 Mdot
.38691 .69942 Mdot
.411 .64903 Mdot
.5191 .34056 Mdot
.63029 .41184 Mdot
.27505 .50113 Mdot
.36434 .47951 Mdot
.4248 .65847 Mdot
.55671 .63023 Mdot
.35863 .47574 Mdot
.6381 .6124 Mdot
.43403 .44642 Mdot
.40752 .67969 Mdot
.41348 .47279 Mdot
.41678 .66303 Mdot
.64488 .3973 Mdot
.41188 .41619 Mdot
.37635 .48435 Mdot
.84248 .51994 Mdot
.51446 .332 Mdot
.46386 .63921 Mdot
.5887 .37446 Mdot
.36547 .41514 Mdot
.71435 .49974 Mdot
.38755 .42771 Mdot
.41143 .6006 Mdot
.33616 .45907 Mdot
.72082 .59804 Mdot
.43814 .42347 Mdot
.37051 .4602 Mdot
.51742 .60338 Mdot
.2538 .6192 Mdot
.3854 .70243 Mdot
.63036 .6353 Mdot
.42524 .62524 Mdot
.63053 .27139 Mdot
.66805 .46271 Mdot
.66042 .39753 Mdot
.33514 .29008 Mdot
.36532 .40192 Mdot
.3902 .45312 Mdot
.61945 .55906 Mdot
.49201 .3348 Mdot
.43099 .65629 Mdot
.49204 .32283 Mdot
.76277 .36684 Mdot
.50254 .34582 Mdot
.6051 .43343 Mdot
.72162 .36503 Mdot
.30863 .54394 Mdot
.50492 .30098 Mdot
.40452 .66106 Mdot
.58902 .25195 Mdot
.34826 .49042 Mdot
.48883 .36453 Mdot
.50536 .32709 Mdot
.48842 .13938 Mdot
.35263 .43755 Mdot
.54478 .57719 Mdot
.64449 .61987 Mdot
.4958 .31103 Mdot
.61229 .58526 Mdot
.40469 .4737 Mdot
.70764 .48474 Mdot
.46453 .65314 Mdot
.58975 .61202 Mdot
.41342 .50459 Mdot
.51057 .34222 Mdot
.62204 .43057 Mdot
.63153 .65183 Mdot
.60248 .62739 Mdot
.50602 .80126 Mdot
.20918 .45 Mdot
.63171 .41138 Mdot
.59876 .22416 Mdot
.59825 .59807 Mdot
.4039 .49907 Mdot
.40726 .55462 Mdot
.40609 .42148 Mdot
.6924 .64242 Mdot
.65594 .39777 Mdot
.53513 .72753 Mdot
.38534 .49137 Mdot
.37069 .42362 Mdot
.40445 .71545 Mdot
.64522 .40678 Mdot
.4322 .6748 Mdot
.42325 .62789 Mdot
.64433 .398 Mdot
.42046 .67469 Mdot
.4843 .33199 Mdot
.54824 .69812 Mdot
.59736 .60763 Mdot
.62371 .59315 Mdot
.64681 .42125 Mdot
.6688 .43055 Mdot
.66432 .4263 Mdot
.43381 .44551 Mdot
.43642 .65884 Mdot
.42902 .46224 Mdot
.43756 .47206 Mdot
.39753 .72973 Mdot
.39847 .66635 Mdot
.43176 .47267 Mdot
.63416 .47742 Mdot
.49303 .3631 Mdot
.65451 .44053 Mdot
.6445 .62243 Mdot
.68836 .71602 Mdot
.59121 .62716 Mdot
.38291 .44591 Mdot
.79464 .4477 Mdot
.40688 .66203 Mdot
.50944 .30456 Mdot
.47792 .33036 Mdot
.51887 .30764 Mdot
.60888 .55545 Mdot
.45257 .63275 Mdot
.74262 .30772 Mdot
.38283 .44951 Mdot
.59307 .52929 Mdot
.27185 .35707 Mdot
.75707 .39037 Mdot
.64485 .62355 Mdot
.3598 .47981 Mdot
.54293 .46607 Mdot
.35973 .61412 Mdot
.39919 .42322 Mdot
.34095 .48918 Mdot
.70714 .55113 Mdot
.35592 .52966 Mdot
.41625 .62014 Mdot
.80911 .40868 Mdot
.44522 .44916 Mdot
.43179 .74353 Mdot
.14343 .51154 Mdot
.38873 .44006 Mdot
.36808 .43192 Mdot
.36908 .47085 Mdot
.40182 .48701 Mdot
.41047 .63125 Mdot
.3361 .31031 Mdot
.65259 .6301 Mdot
.58848 .51337 Mdot
.59697 .61138 Mdot
.66391 .39292 Mdot
.51204 .69503 Mdot
.43014 .70147 Mdot
.50641 .30383 Mdot
.41044 .76579 Mdot
.78224 .35913 Mdot
.63656 .45562 Mdot
.31176 .57141 Mdot
.51205 .32767 Mdot
.39456 .50233 Mdot
.49584 .29072 Mdot
.6175 .39621 Mdot
.63022 .58712 Mdot
.39209 .39306 Mdot
.4164 .64014 Mdot
.41456 .69405 Mdot
.35472 .4646 Mdot
.25945 .71441 Mdot
.64183 .61136 Mdot
.66328 .63451 Mdot
.41056 .49208 Mdot
.34454 .49711 Mdot
.43262 .67836 Mdot
.6425 .43301 Mdot
.53058 .23647 Mdot
.50194 .33707 Mdot
.36717 .40927 Mdot
.40535 .48542 Mdot
.80611 .41401 Mdot
.64559 .59345 Mdot
.61989 .4484 Mdot
.39519 .4958 Mdot
.70001 .65591 Mdot
.39617 .49522 Mdot
.32193 .50143 Mdot
.65527 .43522 Mdot
.39458 .52723 Mdot
.35449 .4826 Mdot
.44908 .38845 Mdot
.60333 .59089 Mdot
.43289 .69169 Mdot
.39132 .67802 Mdot
.54994 .41835 Mdot
.6356 .61341 Mdot
.42813 .47664 Mdot
.64634 .59825 Mdot
.42933 .48739 Mdot
.35168 .46209 Mdot
.63804 .6259 Mdot
.43151 .67487 Mdot
.53131 .77591 Mdot
.50296 .70616 Mdot
.39865 .48866 Mdot
.44172 .43526 Mdot
.3574 .28917 Mdot
.40318 .1983 Mdot
.37984 .42752 Mdot
.40984 .68627 Mdot
.36792 .48347 Mdot
.60855 .59188 Mdot
.49447 .3435 Mdot
.41028 .68357 Mdot
.63534 .42847 Mdot
.62277 .44667 Mdot
.66118 .70258 Mdot
.62204 .39845 Mdot
.36015 .49795 Mdot
.44767 .5944 Mdot
.42261 .71002 Mdot
.1495 .54663 Mdot
.64343 .39996 Mdot
.48076 .32998 Mdot
.39667 .47952 Mdot
.80693 .50492 Mdot
.62509 .55914 Mdot
.87136 .61465 Mdot
.73643 .29297 Mdot
.51641 .34804 Mdot
.52554 .17763 Mdot
.67515 .40484 Mdot
.34721 .46127 Mdot
.50836 .29767 Mdot
.64484 .4571 Mdot
.36136 .49508 Mdot
.40788 .39153 Mdot
.28276 .2949 Mdot
.54716 .4336 Mdot
.64841 .60115 Mdot
.67493 .43013 Mdot
.48796 .29239 Mdot
.60427 .42842 Mdot
.41422 .69577 Mdot
.37437 .45967 Mdot
.46849 .43286 Mdot
.63869 .43216 Mdot
.60347 .41889 Mdot
.4337 .4538 Mdot
.44345 .69559 Mdot
.60327 .37928 Mdot
.39566 .47059 Mdot
.28382 .44428 Mdot
.42484 .60851 Mdot
.62584 .4149 Mdot
.36699 .42275 Mdot
.43306 .34356 Mdot
.64012 .42307 Mdot
.65331 .44182 Mdot
.35373 .46442 Mdot
.48403 .3288 Mdot
.41678 .41202 Mdot
.60927 .61649 Mdot
.27262 .28665 Mdot
.6121 .58922 Mdot
.61877 .27901 Mdot
.32922 .43498 Mdot
.6802 .49323 Mdot
.4106 .6959 Mdot
.47807 .3046 Mdot
.70512 .71333 Mdot
.36216 .51114 Mdot
.39613 .80113 Mdot
.54096 .48041 Mdot
.21823 .67645 Mdot
.67694 .764 Mdot
.50449 .32361 Mdot
.62577 .61377 Mdot
.36834 .43237 Mdot
.64431 .57373 Mdot
.5194 .29975 Mdot
.23249 .39584 Mdot
.36252 .42541 Mdot
.44256 .66391 Mdot
.42946 .43883 Mdot
.45024 .67287 Mdot
.35712 .47111 Mdot
.33098 .50229 Mdot
.73195 .59895 Mdot
.473 .24346 Mdot
.35068 .48885 Mdot
.78 .65995 Mdot
.68451 .33383 Mdot
.50227 .33162 Mdot
.42729 .45436 Mdot
.65536 .46561 Mdot
.61008 .57417 Mdot
.47031 .58596 Mdot
.66021 .43015 Mdot
.65538 .60062 Mdot
.42725 .68176 Mdot
.64133 .39392 Mdot
.61138 .43206 Mdot
.44241 .48903 Mdot
.49803 .29488 Mdot
.6307 .58278 Mdot
.37048 .45599 Mdot
.35721 .43275 Mdot
.60541 .23347 Mdot
.64944 .31352 Mdot
.39425 .70003 Mdot
.84977 .45616 Mdot
.39928 .69832 Mdot
.51178 .33658 Mdot
.6589 .43429 Mdot
.38262 .42908 Mdot
.41327 .43914 Mdot
.71887 .61466 Mdot
.46643 .65522 Mdot
.54445 .44415 Mdot
.27052 .53578 Mdot
.60295 .38356 Mdot
.3875 .30728 Mdot
.43135 .69551 Mdot
.387 .30573 Mdot
.48916 .29182 Mdot
.38617 .77418 Mdot
.45803 .25932 Mdot
.64683 .61788 Mdot
.38197 .30942 Mdot
.42406 .64755 Mdot
.3749 .49366 Mdot
.67496 .45875 Mdot
.61898 .403 Mdot
.43848 .68289 Mdot
.63286 .37356 Mdot
.49913 .30939 Mdot
.36261 .43492 Mdot
.72412 .30017 Mdot
.60218 .70942 Mdot
.64042 .43965 Mdot
.31424 .47935 Mdot
.62151 .58448 Mdot
.34934 .45556 Mdot
.52943 .31356 Mdot
.63723 .5975 Mdot
.6763 .30097 Mdot
.53659 .71405 Mdot
.40103 .47258 Mdot
.8172 .49435 Mdot
.63816 .60849 Mdot
.49231 .18231 Mdot
.38999 .46887 Mdot
.59861 .5973 Mdot
.38589 .53765 Mdot
.74912 .41156 Mdot
.53184 .4483 Mdot
.3926 .82149 Mdot
.54553 .45621 Mdot
.68242 .4422 Mdot
.7556 .45931 Mdot
.75395 .53239 Mdot
.63844 .56972 Mdot
.60387 .42236 Mdot
.45495 .32115 Mdot
.61254 .58432 Mdot
.43921 .4673 Mdot
.38874 .43268 Mdot
.25977 .49715 Mdot
.54142 .4937 Mdot
.61767 .45429 Mdot
.63516 .681 Mdot
.36743 .41429 Mdot
.43941 .48866 Mdot
.40993 .44596 Mdot
.47194 .63453 Mdot
.63887 .58961 Mdot
.81767 .58482 Mdot
.63364 .61599 Mdot
.67435 .25056 Mdot
.64671 .41652 Mdot
.66616 .40814 Mdot
.37729 .44757 Mdot
.6832 .48036 Mdot
.34792 .33917 Mdot
.41922 .4318 Mdot
.65159 .49777 Mdot
.18915 .49628 Mdot
.42407 .49968 Mdot
.40826 .62524 Mdot
.33019 .40977 Mdot
.4731 .62948 Mdot
.59557 .60239 Mdot
.50938 .31728 Mdot
.47084 .31882 Mdot
.63222 .58516 Mdot
.39201 .45333 Mdot
.6663 .50705 Mdot
.40112 .43224 Mdot
.38088 .4965 Mdot
.66939 .23935 Mdot
.51737 .34655 Mdot
.66326 .41343 Mdot
.5247 .31299 Mdot
.45303 .67981 Mdot
.7012 .83108 Mdot
.49045 .3326 Mdot
.34235 .34508 Mdot
.24001 .35429 Mdot
.37854 .30867 Mdot
.41942 .69747 Mdot
.53124 .29629 Mdot
.64605 .61014 Mdot
.27538 .75581 Mdot
.37769 .20372 Mdot
.63278 .64752 Mdot
.39868 .46452 Mdot
.44095 .69946 Mdot
.40224 .66465 Mdot
.59113 .61298 Mdot
.42997 .64356 Mdot
.43717 .51051 Mdot
.38824 .49305 Mdot
.64524 .57631 Mdot
.59418 .72856 Mdot
.60221 .62742 Mdot
.54398 .67748 Mdot
.42899 .45063 Mdot
.42299 .69489 Mdot
.33182 .41008 Mdot
.47806 .67333 Mdot
.62102 .4503 Mdot
.40642 .50059 Mdot
.50048 .30733 Mdot
.62087 .52547 Mdot
.63282 .41418 Mdot
.7932 .4502 Mdot
.44765 .65254 Mdot
.56197 .61191 Mdot
.43742 .64595 Mdot
.46741 .67892 Mdot
.63999 .58047 Mdot
.45862 .64405 Mdot
.36666 .43216 Mdot
.65281 .47821 Mdot
.45557 .65683 Mdot
.61539 .60195 Mdot
.51437 .314 Mdot
.42344 .67403 Mdot
.58814 .38012 Mdot
.38732 .48355 Mdot
.65167 .45301 Mdot
.74132 .59144 Mdot
.45465 .69113 Mdot
.53598 .30716 Mdot
.65044 .39145 Mdot
.50244 .29444 Mdot
.17562 .51391 Mdot
.66059 .60845 Mdot
.55507 .19536 Mdot
.4377 .34656 Mdot
.40972 .64515 Mdot
.73744 .59454 Mdot
.38214 .43206 Mdot
.38997 .48356 Mdot
.51264 .28557 Mdot
.40225 .66403 Mdot
.31178 .75857 Mdot
.37681 .69968 Mdot
.54713 .71037 Mdot
.66263 .60575 Mdot
.81224 .56739 Mdot
.5302 .66364 Mdot
.19089 .41091 Mdot
.41021 .51464 Mdot
.68006 .41452 Mdot
.39396 .44604 Mdot
.69335 .72111 Mdot
.51397 .34187 Mdot
.55616 .28787 Mdot
.33045 .44582 Mdot
.65369 .39984 Mdot
.37722 .47484 Mdot
.48676 .56277 Mdot
.31426 .44531 Mdot
.48474 .33873 Mdot
.68507 .56856 Mdot
.41542 .63343 Mdot
.51648 .32317 Mdot
.61262 .42188 Mdot
.36545 .32869 Mdot
.35084 .48541 Mdot
.37574 .51611 Mdot
.59986 .38588 Mdot
.4425 .65926 Mdot
.67988 .44001 Mdot
.59731 .60631 Mdot
.50237 .3139 Mdot
.39933 .48211 Mdot
.33502 .4545 Mdot
.71546 .50099 Mdot
.63166 .58121 Mdot
.61642 .37888 Mdot
.62527 .62024 Mdot
.6848 .44232 Mdot
.43439 .4232 Mdot
.66539 .40634 Mdot
.34407 .46412 Mdot
.73071 .67261 Mdot
.6625 .23645 Mdot
.27046 .63801 Mdot
.64969 .39398 Mdot
.41698 .30633 Mdot
.60864 .59804 Mdot
.60831 .61331 Mdot
.24691 .42819 Mdot
.4454 .53391 Mdot
.65047 .26839 Mdot
.52224 .80638 Mdot
.59761 .61139 Mdot
.61667 .58931 Mdot
.64835 .45462 Mdot
.46029 .64889 Mdot
.45805 .69256 Mdot
.6614 .38975 Mdot
.38991 .23743 Mdot
.43085 .65636 Mdot
.3797 .78766 Mdot
.65296 .27848 Mdot
.45074 .47546 Mdot
.60431 .65441 Mdot
.50672 .3108 Mdot
.40439 .23888 Mdot
.49062 .57378 Mdot
.37184 .42512 Mdot
.81091 .42538 Mdot
.64594 .43042 Mdot
.31768 .30656 Mdot
.46788 .82622 Mdot
.35967 .42712 Mdot
.38579 .4645 Mdot
.39989 .44981 Mdot
.52799 .33894 Mdot
.37288 .56763 Mdot
.36032 .43126 Mdot
.38938 .23524 Mdot
.36509 .41405 Mdot
.46706 .37159 Mdot
.52482 .31678 Mdot
.36517 .36874 Mdot
.70845 .56791 Mdot
.74768 .34961 Mdot
.38691 .38197 Mdot
.59913 .6083 Mdot
.58803 .49031 Mdot
.60278 .58798 Mdot
.28295 .67812 Mdot
.45234 .26088 Mdot
.39346 .64408 Mdot
.37119 .4273 Mdot
.62715 .40378 Mdot
.40249 .66773 Mdot
.74622 .49329 Mdot
.54511 .92502 Mdot
.59641 .59354 Mdot
.2263 .28048 Mdot
.61496 .61799 Mdot
.60882 .42586 Mdot
.43304 .67977 Mdot
.33916 .64004 Mdot
.5881 .53158 Mdot
.42112 .67244 Mdot
.52417 .76513 Mdot
.43752 .71481 Mdot
.40039 .31088 Mdot
.41282 .70541 Mdot
.61258 .60122 Mdot
.58563 .58229 Mdot
.45998 .42597 Mdot
.37619 .4398 Mdot
.5228 .56635 Mdot
.37887 .33905 Mdot
.37884 .43552 Mdot
.62842 .41046 Mdot
.47969 .17617 Mdot
.55623 .40705 Mdot
.43942 .63458 Mdot
.61777 .63727 Mdot
.38351 .46671 Mdot
.40127 .49117 Mdot
.35771 .49039 Mdot
.85596 .45905 Mdot
.36396 .77256 Mdot
.3542 .47779 Mdot
.38015 .40621 Mdot
.64457 .39468 Mdot
.53254 .28029 Mdot
.67158 .74332 Mdot
.46923 .38559 Mdot
.39325 .41566 Mdot
.52026 .325 Mdot
.49666 .3545 Mdot
.36096 .49534 Mdot
.73842 .35987 Mdot
.70396 .46449 Mdot
.37018 .45642 Mdot
.47932 .47461 Mdot
.76745 .52292 Mdot
.60407 .41932 Mdot
.6384 .42926 Mdot
.41276 .63126 Mdot
.6218 .4042 Mdot
.61586 .39466 Mdot
.34251 .61684 Mdot
.56517 .48239 Mdot
.64733 .55372 Mdot
.51966 .34029 Mdot
.41101 .43599 Mdot
.4077 .70911 Mdot
.70693 .63009 Mdot
.622 .57799 Mdot
.41014 .66843 Mdot
.60668 .57609 Mdot
.5283 .34398 Mdot
.29809 .29541 Mdot
.61639 .40474 Mdot
.60158 .61981 Mdot
.53662 .71257 Mdot
.52189 .32291 Mdot
.65207 .59646 Mdot
.68444 .49696 Mdot
.43869 .47382 Mdot
.35531 .70932 Mdot
.42328 .43671 Mdot
.26207 .72593 Mdot
.65176 .59809 Mdot
.71923 .59929 Mdot
.38414 .45522 Mdot
.63925 .41939 Mdot
.34398 .51757 Mdot
.39768 .41932 Mdot
.63118 .42949 Mdot
.37076 .49383 Mdot
.52338 .29887 Mdot
.44479 .60268 Mdot
.58076 .49147 Mdot
.6663 .19283 Mdot
.5015 .29223 Mdot
.73891 .49255 Mdot
.37836 .42708 Mdot
.1972 .47115 Mdot
.4234 .67219 Mdot
.3399 .46068 Mdot
.30875 .37486 Mdot
.45955 .66297 Mdot
.41357 .67986 Mdot
.42014 .4762 Mdot
.64359 .61853 Mdot
.63176 .41739 Mdot
.5234 .31742 Mdot
.16598 .49701 Mdot
.40777 .4581 Mdot
.3727 .48443 Mdot
.51366 .32618 Mdot
.61457 .58857 Mdot
.40691 .48944 Mdot
.75645 .60837 Mdot
.18448 .64285 Mdot
.62606 .57466 Mdot
.43504 .4359 Mdot
.37054 .71018 Mdot
.48041 .63623 Mdot
.29773 .23102 Mdot
.51745 .24903 Mdot
.66545 .41231 Mdot
.36901 .53695 Mdot
.78869 .72937 Mdot
.51038 .31547 Mdot
.74623 .327 Mdot
.38178 .49783 Mdot
.36464 .47538 Mdot
.40958 .6541 Mdot
.43134 .46627 Mdot
.46197 .67121 Mdot
.6211 .17458 Mdot
.82253 .43776 Mdot
.44818 .66196 Mdot
.41575 .63854 Mdot
.32917 .3575 Mdot
.67604 .7389 Mdot
.4362 .68514 Mdot
.41266 .40353 Mdot
.31631 .73784 Mdot
.43781 .37921 Mdot
.51044 .28501 Mdot
.75086 .57146 Mdot
.47031 .70438 Mdot
.56022 .37499 Mdot
.51691 .79238 Mdot
.46494 .7138 Mdot
.71191 .43759 Mdot
.6114 .61969 Mdot
.37037 .41657 Mdot
.62025 .40023 Mdot
.66096 .3987 Mdot
.31673 .44985 Mdot
.4058 .4303 Mdot
.4539 .66731 Mdot
.51036 .34735 Mdot
.62572 .56836 Mdot
.36707 .48641 Mdot
.55857 .40868 Mdot
.49455 .33418 Mdot
.44557 .63995 Mdot
.25887 .4077 Mdot
.48165 .33504 Mdot
.31374 .4278 Mdot
.36341 .45041 Mdot
.4351 .45754 Mdot
.46678 .40212 Mdot
.63681 .62955 Mdot
.74379 .60927 Mdot
.42824 .42262 Mdot
.76492 .36798 Mdot
.50633 .45411 Mdot
.38808 .52968 Mdot
.43248 .65055 Mdot
.62618 .55848 Mdot
.64113 .46288 Mdot
.29638 .35045 Mdot
.40454 .46659 Mdot
.3578 .76516 Mdot
.26956 .51868 Mdot
.63965 .46044 Mdot
.46854 .65274 Mdot
.51191 .30489 Mdot
.41664 .43094 Mdot
.30061 .70919 Mdot
.38765 .43698 Mdot
.4515 .357 Mdot
.65132 .43823 Mdot
.6141 .62166 Mdot
.20963 .66865 Mdot
.66179 .39975 Mdot
.41534 .68422 Mdot
.40844 .83965 Mdot
.42732 .70571 Mdot
.43256 .62881 Mdot
.32892 .72606 Mdot
.62653 .62957 Mdot
.80705 .70957 Mdot
.35728 .20605 Mdot
.33365 .48408 Mdot
.6056 .59966 Mdot
.44245 .67675 Mdot
.34977 .45372 Mdot
.40256 .69006 Mdot
.45866 .63571 Mdot
.44656 .47058 Mdot
.3599 .46234 Mdot
.51334 .68742 Mdot
.42022 .81365 Mdot
.51632 .30466 Mdot
.44371 .69234 Mdot
.27696 .42295 Mdot
.34907 .44553 Mdot
.38215 .44998 Mdot
.76409 .5031 Mdot
.48334 .33027 Mdot
.5153 .6231 Mdot
.39026 .49636 Mdot
.82688 .46557 Mdot
.33205 .40744 Mdot
.41124 .62912 Mdot
.62864 .57583 Mdot
.73986 .34351 Mdot
.68601 .64571 Mdot
.46632 .65992 Mdot
.52932 .32566 Mdot
.39079 .67882 Mdot
.34614 .34468 Mdot
.61183 .62992 Mdot
.40749 .67961 Mdot
.54826 .46927 Mdot
.63101 .60077 Mdot
.65191 .60207 Mdot
.28521 .70276 Mdot
.62129 .38082 Mdot
.5346 .32153 Mdot
.62651 .58352 Mdot
.2821 .47126 Mdot
.6173 .60858 Mdot
.25921 .45607 Mdot
.4161 .41759 Mdot
.34184 .2675 Mdot
.54862 .59136 Mdot
.46068 .48241 Mdot
.64981 .62534 Mdot
.52052 .30172 Mdot
.41448 .48249 Mdot
.42677 .64306 Mdot
.49031 .32637 Mdot
.60397 .64855 Mdot
.66221 .43956 Mdot
.43925 .64427 Mdot
.65916 .62621 Mdot
.4391 .69341 Mdot
.2923 .33751 Mdot
.26008 .29957 Mdot
.77783 .58142 Mdot
.5831 .53073 Mdot
.361 .49269 Mdot
.57951 .78971 Mdot
.4518 .45889 Mdot
.4021 .42674 Mdot
.62677 .4149 Mdot
.33208 .29062 Mdot
.4323 .67535 Mdot
.21399 .67759 Mdot
.60414 .6193 Mdot
.81441 .41573 Mdot
.38461 .64422 Mdot
.33897 .46253 Mdot
.4566 .66022 Mdot
.42021 .70593 Mdot
.24792 .61449 Mdot
.60388 .43449 Mdot
.42893 .4021 Mdot
.44943 .41892 Mdot
.39429 .51975 Mdot
.65117 .60363 Mdot
.78867 .43869 Mdot
.68118 .42738 Mdot
.263 .28014 Mdot
.64751 .43939 Mdot
.63187 .50542 Mdot
.4547 .64129 Mdot
.48767 .33074 Mdot
.37968 .45083 Mdot
.3786 .66166 Mdot
.46707 .66255 Mdot
.51251 .35868 Mdot
.49581 .30881 Mdot
.76132 .4378 Mdot
.63856 .62622 Mdot
.34653 .48546 Mdot
.36639 .42379 Mdot
.42671 .46207 Mdot
.42423 .43017 Mdot
.59566 .59474 Mdot
.42209 .48754 Mdot
.59713 .57266 Mdot
.27838 .47093 Mdot
.81666 .43869 Mdot
.56158 .48005 Mdot
.44492 .5715 Mdot
.43087 .63723 Mdot
.28597 .47163 Mdot
.31274 .42723 Mdot
.62935 .21651 Mdot
.1936 .59052 Mdot
.41947 .50026 Mdot
.65154 .45746 Mdot
.43637 .54486 Mdot
.62337 .39032 Mdot
.29853 .19955 Mdot
.71099 .50974 Mdot
.39508 .8142 Mdot
.35355 .44184 Mdot
.76643 .50549 Mdot
.36754 .54801 Mdot
.45288 .44174 Mdot
.73935 .5145 Mdot
.68205 .67065 Mdot
.5558 .74689 Mdot
.49031 .35137 Mdot
.38961 .47908 Mdot
.4296 .71231 Mdot
.36487 .43225 Mdot
.38744 .44714 Mdot
.38187 .49876 Mdot
.6472 .63299 Mdot
.3999 .39505 Mdot
.43418 .44278 Mdot
.66382 .34664 Mdot
.41409 .28486 Mdot
.67591 .42954 Mdot
.24321 .42368 Mdot
.49146 .3318 Mdot
.45294 .65775 Mdot
.47851 .76336 Mdot
.6471 .61811 Mdot
.24192 .59673 Mdot
.43171 .44095 Mdot
.52116 .70115 Mdot
.66198 .62376 Mdot
.50055 .31267 Mdot
.67931 .45834 Mdot
.36112 .80472 Mdot
.63072 .40239 Mdot
.54768 .47322 Mdot
.63768 .41436 Mdot
.3464 .38962 Mdot
.45385 .66893 Mdot
.37511 .49988 Mdot
.62553 .58542 Mdot
.62525 .42027 Mdot
.37274 .28098 Mdot
.40828 .4461 Mdot
.64625 .39869 Mdot
.37788 .49999 Mdot
.30856 .28208 Mdot
.56283 .21713 Mdot
.61147 .39968 Mdot
.61708 .55468 Mdot
.62517 .60107 Mdot
.48509 .33225 Mdot
.44798 .64681 Mdot
.41191 .65269 Mdot
.63663 .59945 Mdot
.40798 .18939 Mdot
.39334 .41673 Mdot
.35005 .44912 Mdot
.76696 .36756 Mdot
.37192 .43459 Mdot
.38705 .32394 Mdot
.54075 .46181 Mdot
.43925 .6372 Mdot
.34972 .46504 Mdot
.40313 .48894 Mdot
.39867 .47622 Mdot
.28417 .33918 Mdot
.64108 .43562 Mdot
.38714 .41135 Mdot
.49658 .30432 Mdot
.66172 .46886 Mdot
.34833 .45195 Mdot
.39085 .52025 Mdot
.41117 .65488 Mdot
.81733 .39299 Mdot
.62338 .62296 Mdot
.61484 .42988 Mdot
.66123 .40259 Mdot
.75312 .56844 Mdot
.41219 .73756 Mdot
.54018 .45828 Mdot
.24722 .29953 Mdot
.71767 .58483 Mdot
.50898 .33139 Mdot
.63345 .51476 Mdot
.50588 .43274 Mdot
.63116 .45047 Mdot
.59984 .58292 Mdot
.42421 .42121 Mdot
.39753 .41502 Mdot
.72545 .27623 Mdot
.33822 .46592 Mdot
.51048 .30736 Mdot
.59056 .58682 Mdot
.42354 .64911 Mdot
.50145 .31047 Mdot
.61252 .61521 Mdot
.44135 .65716 Mdot
.44104 .47258 Mdot
.44352 .46006 Mdot
.41143 .66969 Mdot
.40361 .66324 Mdot
.36833 .45295 Mdot
.68129 .47044 Mdot
.41566 .63039 Mdot
.41726 .69353 Mdot
.61632 .40323 Mdot
.61899 .40831 Mdot
.438 .49869 Mdot
.60727 .6055 Mdot
.43742 .46653 Mdot
.6344 .39583 Mdot
.50131 .34781 Mdot
.42844 .67072 Mdot
.39729 .49015 Mdot
.37322 .49091 Mdot
.5217 .32068 Mdot
.49856 .35201 Mdot
.49703 .31142 Mdot
.58653 .59979 Mdot
.42226 .45564 Mdot
.4307 .68498 Mdot
.62854 .62759 Mdot
.49654 .35462 Mdot
.48743 .30051 Mdot
.63842 .36913 Mdot
.38305 .42705 Mdot
.59801 .37211 Mdot
.69643 .83013 Mdot
.43837 .3177 Mdot
.63501 .46012 Mdot
.60752 .38338 Mdot
.37952 .29665 Mdot
.68562 .47338 Mdot
.64226 .60694 Mdot
.4485 .32684 Mdot
.47666 .30694 Mdot
.40825 .49931 Mdot
.44029 .43453 Mdot
.45789 .43524 Mdot
.49621 .32149 Mdot
.30701 .33757 Mdot
.40843 .69579 Mdot
.23274 .5115 Mdot
.49133 .33029 Mdot
.60294 .41534 Mdot
.62441 .378 Mdot
.64828 .43961 Mdot
.43816 .4353 Mdot
.26638 .62776 Mdot
.30187 .41351 Mdot
.57761 .79678 Mdot
.65463 .61256 Mdot
.39086 .64808 Mdot
.18289 .4965 Mdot
.413 .67531 Mdot
.64272 .38316 Mdot
.49495 .32767 Mdot
.40629 .68044 Mdot
.61039 .57891 Mdot
.61905 .58869 Mdot
.64301 .439 Mdot
.64835 .42071 Mdot
.64532 .45048 Mdot
.44399 .62936 Mdot
.45774 .64359 Mdot
.40942 .46037 Mdot
.42201 .66241 Mdot
.77333 .32092 Mdot
.53291 .33505 Mdot
.61145 .37813 Mdot
.62487 .61475 Mdot
.45076 .67053 Mdot
.41174 .44405 Mdot
.55629 .43095 Mdot
.64725 .70263 Mdot
.50738 .29246 Mdot
.58823 .22621 Mdot
.28975 .21004 Mdot
.34177 .47867 Mdot
.64834 .59848 Mdot
.7169 .2964 Mdot
.40153 .45102 Mdot
.65682 .4301 Mdot
.72819 .68427 Mdot
.66791 .46304 Mdot
.43799 .46938 Mdot
.33874 .48149 Mdot
.64583 .58227 Mdot
.23115 .36252 Mdot
.41304 .45457 Mdot
.5453 .64594 Mdot
.61023 .63604 Mdot
.67441 .40851 Mdot
.19057 .65745 Mdot
.77365 .5528 Mdot
.39712 .23975 Mdot
.61557 .40848 Mdot
.39404 .43022 Mdot
.61754 .41731 Mdot
.50908 .29369 Mdot
.61943 .42996 Mdot
.41489 .61787 Mdot
.67763 .42964 Mdot
.37205 .48341 Mdot
.43715 .68617 Mdot
.63827 .60931 Mdot
.80343 .39608 Mdot
.65503 .3355 Mdot
.64014 .41971 Mdot
.60929 .41433 Mdot
.35118 .47686 Mdot
.51944 .64243 Mdot
.32865 .48612 Mdot
.35164 .44289 Mdot
.59667 .61397 Mdot
.45605 .65472 Mdot
.65497 .62503 Mdot
.34745 .42854 Mdot
.75836 .62913 Mdot
.63117 .62128 Mdot
.51571 .70605 Mdot
.51168 .32844 Mdot
.49691 .53321 Mdot
.41351 .43654 Mdot
.62117 .58102 Mdot
.42301 .45477 Mdot
.39932 .68431 Mdot
.5279 .51378 Mdot
.71333 .63455 Mdot
.6264 .58738 Mdot
.29626 .74689 Mdot
.68008 .39794 Mdot
.3531 .39867 Mdot
.59943 .59433 Mdot
.30918 .37633 Mdot
.60991 .42949 Mdot
.50376 .33608 Mdot
.49536 .35407 Mdot
.49811 .29698 Mdot
.37435 .51083 Mdot
.35978 .39097 Mdot
.53224 .31342 Mdot
.62135 .57251 Mdot
.48681 .34214 Mdot
.41258 .74872 Mdot
.30488 .75597 Mdot
.51711 .33938 Mdot
.39269 .46937 Mdot
.45391 .40228 Mdot
.4093 .28285 Mdot
.58994 .38528 Mdot
.4013 .80651 Mdot
.4441 .57989 Mdot
.37855 .43959 Mdot
.48401 .63499 Mdot
.40599 .69009 Mdot
.71251 .29946 Mdot
.39493 .3382 Mdot
.72209 .34604 Mdot
.41844 .63485 Mdot
.71661 .61686 Mdot
.44408 .64083 Mdot
.34288 .47479 Mdot
.35214 .45688 Mdot
.46019 .69171 Mdot
.79926 .44289 Mdot
.71859 .47969 Mdot
.17497 .59858 Mdot
.42042 .6963 Mdot
.60417 .58982 Mdot
.59368 .60516 Mdot
.6529 .61559 Mdot
.63925 .27186 Mdot
.45375 .68946 Mdot
.41705 .46251 Mdot
.6431 .39272 Mdot
.38489 .41457 Mdot
.63253 .59358 Mdot
.21886 .68305 Mdot
.41589 .65024 Mdot
.37054 .45924 Mdot
.40003 .20209 Mdot
.65572 .42023 Mdot
.51869 .32925 Mdot
.28898 .29843 Mdot
.68362 .30345 Mdot
.62205 .63108 Mdot
.44368 .70208 Mdot
.69331 .56989 Mdot
.50567 .71767 Mdot
.4227 .50924 Mdot
.42445 .51711 Mdot
.17833 .44785 Mdot
.66905 .29743 Mdot
.3772 .50268 Mdot
.61511 .43384 Mdot
.71973 .61424 Mdot
.3918 .48897 Mdot
.4212 .69938 Mdot
.4822 .34764 Mdot
.49126 .30884 Mdot
.43283 .41067 Mdot
.59597 .5276 Mdot
.50268 .49562 Mdot
.42819 .47782 Mdot
.3139 .42668 Mdot
.64172 .38436 Mdot
.7119 .57806 Mdot
.78554 .38423 Mdot
.52779 .33121 Mdot
.39287 .49748 Mdot
.56481 .76363 Mdot
.46175 .64174 Mdot
.6716 .44905 Mdot
.61504 .63167 Mdot
.27175 .35299 Mdot
.67865 .41807 Mdot
.39118 .48995 Mdot
.40596 .48946 Mdot
.65194 .5949 Mdot
.41121 .62904 Mdot
.49642 .32364 Mdot
.65063 .39375 Mdot
.52918 .32875 Mdot
.46021 .66981 Mdot
.41845 .65032 Mdot
.43135 .37595 Mdot
.38117 .39124 Mdot
.63684 .42803 Mdot
.34973 .42859 Mdot
.5849 .39448 Mdot
.22845 .36138 Mdot
.66403 .60036 Mdot
.34077 .47768 Mdot
.45833 .62252 Mdot
.63044 .5863 Mdot
.36412 .46938 Mdot
.16251 .47271 Mdot
.35035 .43565 Mdot
.68872 .64288 Mdot
.77876 .60559 Mdot
.51041 .30023 Mdot
.21017 .50386 Mdot
.48948 .6995 Mdot
.3679 .43748 Mdot
.66826 .43543 Mdot
.33678 .50868 Mdot
.64431 .61527 Mdot
.44457 .63597 Mdot
.3063 .22021 Mdot
.61787 .60625 Mdot
.35796 .43872 Mdot
.50172 .3134 Mdot
.43032 .70662 Mdot
.59752 .4953 Mdot
.75662 .36977 Mdot
.32565 .42872 Mdot
.40742 .40117 Mdot
.43557 .47272 Mdot
.71316 .72409 Mdot
.61654 .43214 Mdot
.44681 .67448 Mdot
.65075 .60429 Mdot
.63892 .59908 Mdot
.64461 .43615 Mdot
.55812 .73644 Mdot
.49899 .53053 Mdot
.741 .77634 Mdot
.62835 .42885 Mdot
.53594 .30458 Mdot
.52858 .63826 Mdot
.66919 .43735 Mdot
.64773 .40155 Mdot
.64128 .38465 Mdot
.67806 .58139 Mdot
.43855 .65761 Mdot
.37257 .49167 Mdot
.39583 .66343 Mdot
.39314 .4272 Mdot
.49885 .47706 Mdot
.63027 .58416 Mdot
.44109 .63327 Mdot
.16738 .4698 Mdot
.41061 .57898 Mdot
.39582 .45858 Mdot
.18604 .4783 Mdot
.32805 .44973 Mdot
.35585 .31805 Mdot
.34961 .40796 Mdot
.64316 .41703 Mdot
.37627 .54451 Mdot
.34941 .50811 Mdot
.79095 .36512 Mdot
.62294 .61526 Mdot
.61055 .43339 Mdot
.37005 .50505 Mdot
.32731 .41099 Mdot
.45761 .69818 Mdot
.40837 .68503 Mdot
.53222 .32167 Mdot
.47387 .24099 Mdot
.63803 .61144 Mdot
.27313 .29252 Mdot
.37236 .44254 Mdot
.80503 .53203 Mdot
.21568 .52257 Mdot
.36518 .46881 Mdot
.32385 .74626 Mdot
.25591 .61503 Mdot
.41519 .43209 Mdot
.33441 .36807 Mdot
.61338 .59127 Mdot
.76058 .62336 Mdot
.38337 .40434 Mdot
.659 .42871 Mdot
.45642 .64506 Mdot
.42012 .70166 Mdot
.52896 .3063 Mdot
.61995 .19745 Mdot
.65636 .6201 Mdot
.44604 .63555 Mdot
.4057 .44395 Mdot
.62504 .63039 Mdot
.62415 .39757 Mdot
.34042 .43777 Mdot
.40367 .33068 Mdot
.42279 .65895 Mdot
.37501 .40634 Mdot
.59847 .68482 Mdot
.42829 .24071 Mdot
.57146 .83761 Mdot
.65103 .61703 Mdot
.49334 .34126 Mdot
.35228 .517 Mdot
.30228 .26682 Mdot
.41598 .503 Mdot
.33543 .27372 Mdot
.41567 .74381 Mdot
.49181 .34095 Mdot
.38698 .45923 Mdot
.40471 .47592 Mdot
.55017 .57891 Mdot
.50544 .3497 Mdot
.36707 .42136 Mdot
.39911 .56114 Mdot
.44229 .66077 Mdot
.68014 .46307 Mdot
.4264 .6559 Mdot
.39794 .4648 Mdot
.40461 .38985 Mdot
.407 .65788 Mdot
.22306 .32471 Mdot
.46856 .3405 Mdot
.6276 .62402 Mdot
.37095 .39047 Mdot
.41592 .41487 Mdot
.77909 .67842 Mdot
.62014 .44916 Mdot
.64165 .75619 Mdot
.57736 .3859 Mdot
.54722 .77472 Mdot
.77584 .54708 Mdot
.39736 .83247 Mdot
.80913 .41974 Mdot
.44997 .42092 Mdot
.46314 .54081 Mdot
.32061 .38326 Mdot
.64701 .62892 Mdot
.33136 .56146 Mdot
.37675 .43933 Mdot
.39047 .44619 Mdot
.66761 .45326 Mdot
.53125 .72834 Mdot
.73734 .35414 Mdot
.59526 .51465 Mdot
.49916 .32496 Mdot
.4489 .68553 Mdot
.35706 .47329 Mdot
.53564 .40865 Mdot
.67577 .43533 Mdot
.80558 .51894 Mdot
.37555 .46016 Mdot
.6222 .21631 Mdot
.69279 .59958 Mdot
.63776 .62848 Mdot
.66988 .41683 Mdot
.70353 .32279 Mdot
.38663 .42399 Mdot
.59988 .62443 Mdot
.41424 .44989 Mdot
.69752 .38677 Mdot
.34419 .44059 Mdot
.50881 .34168 Mdot
.36966 .497 Mdot
.598 .50718 Mdot
.49844 .84441 Mdot
.45441 .34933 Mdot
.44071 .69877 Mdot
.59606 .39038 Mdot
.64052 .43386 Mdot
.40526 .67329 Mdot
.64046 .43041 Mdot
.23576 .56051 Mdot
.32377 .63549 Mdot
.50198 .32769 Mdot
.3187 .41905 Mdot
.52436 .33211 Mdot
.62158 .45111 Mdot
.38367 .43338 Mdot
.23438 .30991 Mdot
.63049 .42385 Mdot
.78936 .61439 Mdot
.62237 .611 Mdot
.61512 .4423 Mdot
.36733 .4122 Mdot
.67953 .54522 Mdot
.66899 .40965 Mdot
.71212 .62321 Mdot
.40017 .47421 Mdot
.42189 .64554 Mdot
.40375 .48004 Mdot
.34105 .41374 Mdot
.68558 .44361 Mdot
.4278 .43018 Mdot
.61239 .61507 Mdot
.4257 .62519 Mdot
.33937 .78055 Mdot
.69183 .64168 Mdot
.37052 .42418 Mdot
.40445 .44601 Mdot
.4303 .70968 Mdot
.39304 .40945 Mdot
.59569 .59561 Mdot
.90376 .49815 Mdot
.51217 .32857 Mdot
.60757 .40772 Mdot
.77085 .56341 Mdot
.42565 .49717 Mdot
.41983 .4836 Mdot
.16309 .50338 Mdot
.77178 .57896 Mdot
.60034 .6043 Mdot
.3275 .49089 Mdot
.64285 .39053 Mdot
.50342 .31258 Mdot
.62819 .57116 Mdot
.43497 .45844 Mdot
.38225 .4526 Mdot
.49447 .34104 Mdot
.29107 .7149 Mdot
.69403 .2991 Mdot
.65531 .60529 Mdot
.38081 .5462 Mdot
.57727 .41254 Mdot
.39526 .41779 Mdot
.64009 .26756 Mdot
.41034 .68491 Mdot
.60825 .62641 Mdot
.61897 .77817 Mdot
.39694 .50001 Mdot
.62383 .57641 Mdot
.63583 .61323 Mdot
.34185 .50323 Mdot
.47751 .65381 Mdot
.44239 .62462 Mdot
.44149 .69167 Mdot
.788 .32666 Mdot
.41052 .24881 Mdot
.64563 .45049 Mdot
.61416 .58982 Mdot
.61887 .38983 Mdot
.54011 .31317 Mdot
.52145 .43631 Mdot
.60975 .40258 Mdot
.40187 .67044 Mdot
.59599 .38345 Mdot
.40145 .47799 Mdot
.63988 .60786 Mdot
.63277 .45043 Mdot
.36916 .50599 Mdot
.5104 .65695 Mdot
.70547 .37261 Mdot
.48139 .31984 Mdot
.48007 .34953 Mdot
.3531 .46123 Mdot
.64321 .46363 Mdot
.37043 .45203 Mdot
.62367 .56247 Mdot
.52906 .64737 Mdot
.40106 .50607 Mdot
.64157 .4225 Mdot
.49195 .65132 Mdot
.68367 .30377 Mdot
.32514 .4716 Mdot
.3923 .46828 Mdot
.39545 .42219 Mdot
.415 .44934 Mdot
.53047 .75026 Mdot
.66248 .602 Mdot
.51045 .60436 Mdot
.73487 .59306 Mdot
.41685 .66676 Mdot
.46274 .6313 Mdot
.59756 .25234 Mdot
.71535 .43825 Mdot
.6065 .60273 Mdot
.40527 .42465 Mdot
.70379 .63655 Mdot
.22853 .6954 Mdot
.20945 .33778 Mdot
.529 .35095 Mdot
.64801 .46064 Mdot
.45298 .69442 Mdot
.67374 .43132 Mdot
.39192 .43235 Mdot
.35679 .51983 Mdot
.39147 .83599 Mdot
.5817 .58294 Mdot
.49483 .32618 Mdot
.39534 .42396 Mdot
.4119 .24158 Mdot
.64442 .39427 Mdot
.6281 .37965 Mdot
.36309 .42254 Mdot
.42834 .61728 Mdot
.7058 .76378 Mdot
.64101 .62835 Mdot
.44914 .57977 Mdot
.32088 .51802 Mdot
.60921 .67199 Mdot
.63618 .59005 Mdot
.70694 .34822 Mdot
.65083 .46256 Mdot
.2179 .59287 Mdot
.41493 .66389 Mdot
.49294 .32903 Mdot
.40446 .52812 Mdot
.41402 .64407 Mdot
.68312 .44101 Mdot
.43231 .63566 Mdot
.36456 .49651 Mdot
.66026 .617 Mdot
.66779 .41748 Mdot
.61016 .55541 Mdot
.47595 .64884 Mdot
.52755 .31182 Mdot
.53127 .58906 Mdot
.36301 .59821 Mdot
.2521 .60985 Mdot
.39108 .41266 Mdot
.53356 .40454 Mdot
.42101 .46067 Mdot
.46243 .69436 Mdot
.41272 .44599 Mdot
.48092 .62772 Mdot
.66925 .43029 Mdot
.38044 .40595 Mdot
.4307 .47961 Mdot
.29041 .52795 Mdot
.3793 .46697 Mdot
.373 .40211 Mdot
.41346 .42873 Mdot
.38418 .67052 Mdot
.31255 .45097 Mdot
.43486 .65125 Mdot
.75217 .37546 Mdot
.64797 .40345 Mdot
.48363 .35103 Mdot
.48666 .31372 Mdot
.35109 .26216 Mdot
.47813 .28879 Mdot
.54461 .73573 Mdot
.43177 .66224 Mdot
.62652 .61882 Mdot
.41567 .44485 Mdot
.53302 .80674 Mdot
.75946 .53812 Mdot
.63895 .38863 Mdot
.69196 .64121 Mdot
.41866 .53001 Mdot
.71694 .72319 Mdot
.3629 .41316 Mdot
.71883 .26455 Mdot
.45017 .40794 Mdot
.34285 .45036 Mdot
.63845 .38015 Mdot
.46374 .34468 Mdot
.37693 .41083 Mdot
.45598 .69967 Mdot
.4988 .33867 Mdot
.40815 .59219 Mdot
.60585 .46983 Mdot
.71356 .35715 Mdot
.33183 .58978 Mdot
.42097 .45213 Mdot
.66712 .4187 Mdot
.44014 .64507 Mdot
.79337 .39306 Mdot
.62562 .62721 Mdot
.60062 .53608 Mdot
.27894 .4428 Mdot
.19895 .43162 Mdot
.49419 .33357 Mdot
.28619 .70624 Mdot
.37094 .484 Mdot
.62206 .27974 Mdot
.44379 .47499 Mdot
.2322 .69817 Mdot
.53269 .2983 Mdot
.44165 .61797 Mdot
.60311 .5917 Mdot
.39781 .67639 Mdot
.2649 .6345 Mdot
.58296 .64712 Mdot
.5403 .53594 Mdot
.63413 .39958 Mdot
.51526 .60303 Mdot
.44228 .68274 Mdot
.40424 .49261 Mdot
.72587 .7952 Mdot
.41449 .69068 Mdot
.46413 .66822 Mdot
.24142 .34144 Mdot
.22832 .35147 Mdot
.39654 .54017 Mdot
.41139 .64287 Mdot
.63646 .40122 Mdot
.52167 .30671 Mdot
.41021 .47667 Mdot
.41012 .4627 Mdot
.41087 .65255 Mdot
.63289 .37906 Mdot
.42832 .56551 Mdot
.64728 .41872 Mdot
.44407 .65954 Mdot
.65433 .41123 Mdot
.73174 .61321 Mdot
.62946 .45127 Mdot
.41238 .41347 Mdot
.41362 .4455 Mdot
.5854 .41646 Mdot
.41866 .65034 Mdot
.42695 .47579 Mdot
.36538 .49176 Mdot
.43338 .6844 Mdot
.56193 .40042 Mdot
.37815 .71671 Mdot
.37498 .42711 Mdot
.38591 .48154 Mdot
.49514 .34347 Mdot
.51649 .40889 Mdot
.52118 .20223 Mdot
.41475 .48221 Mdot
.53496 .32767 Mdot
.44316 .6298 Mdot
.36759 .4556 Mdot
.43671 .76277 Mdot
.72066 .61674 Mdot
.3946 .49971 Mdot
.61175 .43316 Mdot
.37769 .51544 Mdot
.62018 .81374 Mdot
.35238 .43882 Mdot
.43853 .67809 Mdot
.46023 .65769 Mdot
.25699 .33673 Mdot
.41783 .68761 Mdot
.61896 .40354 Mdot
.63144 .59787 Mdot
.25719 .72092 Mdot
.62497 .39683 Mdot
.34718 .50007 Mdot
.35544 .20647 Mdot
.35248 .41464 Mdot
.38149 .50728 Mdot
.74911 .69337 Mdot
.62731 .39635 Mdot
.45628 .66709 Mdot
.58127 .54878 Mdot
.4404 .40666 Mdot
.61898 .63079 Mdot
.35422 .51514 Mdot
.42993 .42746 Mdot
.78069 .59711 Mdot
.68493 .70099 Mdot
.59404 .5817 Mdot
.45195 .47671 Mdot
.41577 .48195 Mdot
.61565 .35925 Mdot
.41029 .44236 Mdot
.52667 .33082 Mdot
.45728 .68081 Mdot
.66328 .44981 Mdot
.51957 .31837 Mdot
.37166 .4389 Mdot
.49617 .31968 Mdot
.65167 .45278 Mdot
.60208 .62448 Mdot
.3874 .42941 Mdot
.51184 .28459 Mdot
.49882 .32346 Mdot
.42334 .46359 Mdot
.44844 .63808 Mdot
.46925 .46367 Mdot
.36587 .45909 Mdot
.39052 .494 Mdot
.41242 .65208 Mdot
.19045 .34405 Mdot
.35079 .43836 Mdot
.68191 .40405 Mdot
.46608 .66561 Mdot
.64871 .65978 Mdot
.66023 .45415 Mdot
.42854 .42543 Mdot
.59675 .6172 Mdot
.62624 .58112 Mdot
.6268 .38577 Mdot
.41533 .70656 Mdot
.57913 .39614 Mdot
.48995 .64462 Mdot
.39572 .39154 Mdot
.33648 .43891 Mdot
.40279 .18507 Mdot
.38156 .81897 Mdot
.42446 .70107 Mdot
.64721 .37942 Mdot
.59098 .51467 Mdot
.61201 .588 Mdot
.60935 .38483 Mdot
.43571 .70624 Mdot
.44828 .69698 Mdot
.43383 .63782 Mdot
.48972 .31811 Mdot
.57265 .38843 Mdot
.41232 .62613 Mdot
.42898 .61769 Mdot
.40011 .47628 Mdot
.4187 .48095 Mdot
.38626 .35476 Mdot
.43167 .29947 Mdot
.52836 .31024 Mdot
.64856 .43614 Mdot
.87783 .48499 Mdot
.61831 .56373 Mdot
.29094 .53182 Mdot
.4028 .50541 Mdot
.60672 .89854 Mdot
.35771 .41997 Mdot
.40784 .44127 Mdot
.42268 .6271 Mdot
.50094 .28611 Mdot
.52045 .33329 Mdot
.44603 .68129 Mdot
.47016 .67676 Mdot
.52487 .33424 Mdot
.21825 .64689 Mdot
.30385 .75844 Mdot
.55151 .59763 Mdot
.4294 .67898 Mdot
.35908 .61454 Mdot
.617 .6326 Mdot
.4735 .63035 Mdot
.63056 .56589 Mdot
.64803 .39739 Mdot
.65694 .46265 Mdot
.65169 .60469 Mdot
.40149 .47125 Mdot
.6322 .44612 Mdot
.39816 .39517 Mdot
.25783 .69662 Mdot
.33387 .708 Mdot
.77964 .4882 Mdot
.4431 .43421 Mdot
.73915 .3643 Mdot
.72647 .43889 Mdot
.36064 .44308 Mdot
.4939 .78229 Mdot
.49458 .32439 Mdot
.44659 .61249 Mdot
.59452 .60086 Mdot
.58871 .83559 Mdot
.3985 .41943 Mdot
.43586 .67531 Mdot
.61802 .61469 Mdot
.28663 .32374 Mdot
.54393 .64666 Mdot
.39308 .42469 Mdot
.76378 .75313 Mdot
.38069 .6682 Mdot
.66164 .45069 Mdot
.49153 .16853 Mdot
.39503 .66337 Mdot
.55142 .31153 Mdot
.71847 .57783 Mdot
.17887 .46727 Mdot
.45282 .65846 Mdot
.62588 .372 Mdot
.44784 .68498 Mdot
.52951 .32048 Mdot
.42295 .60825 Mdot
.65817 .40056 Mdot
.38179 .46304 Mdot
.64546 .42892 Mdot
.52603 .3042 Mdot
.63151 .27153 Mdot
.59453 .60583 Mdot
.61126 .43429 Mdot
.62104 .59495 Mdot
.44026 .24106 Mdot
.75287 .63832 Mdot
.61595 .62241 Mdot
.27412 .31546 Mdot
.3862 .50318 Mdot
.40064 .64105 Mdot
.63175 .43552 Mdot
.71046 .57283 Mdot
.54928 .56102 Mdot
.41706 .67357 Mdot
.65557 .43903 Mdot
.28521 .4366 Mdot
.3644 .2185 Mdot
.34224 .39779 Mdot
.45347 .2502 Mdot
.4293 .68277 Mdot
.61277 .37943 Mdot
.76749 .36754 Mdot
.40185 .67674 Mdot
.6278 .42949 Mdot
.61035 .58295 Mdot
.63876 .59545 Mdot
.3747 .41437 Mdot
.65208 .55857 Mdot
.64796 .44494 Mdot
.73906 .42917 Mdot
.46245 .64203 Mdot
.29384 .32119 Mdot
.50189 .291 Mdot
.64454 .40766 Mdot
.33701 .45969 Mdot
.4826 .6624 Mdot
.72556 .61359 Mdot
.44483 .54401 Mdot
.86988 .49784 Mdot
.64504 .43547 Mdot
.46087 .67508 Mdot
.43235 .67221 Mdot
.32725 .47674 Mdot
.58453 .53209 Mdot
.57821 .40023 Mdot
.36868 .22784 Mdot
.32441 .28322 Mdot
.6839 .44715 Mdot
.65529 .48878 Mdot
.34084 .49092 Mdot
.42516 .44832 Mdot
.60942 .58868 Mdot
.38509 .46733 Mdot
.43187 .62132 Mdot
.3832 .4101 Mdot
.63821 .58814 Mdot
.62863 .40789 Mdot
.38605 .43469 Mdot
.51804 .30093 Mdot
.58975 .60482 Mdot
.64809 .58434 Mdot
.64077 .41234 Mdot
.41686 .63922 Mdot
.48077 .35889 Mdot
.64869 .42137 Mdot
.42006 .45214 Mdot
.63271 .51838 Mdot
.35801 .49062 Mdot
.21369 .62213 Mdot
.40086 .66863 Mdot
.67177 .43269 Mdot
.46878 .65777 Mdot
.61663 .59712 Mdot
.73388 .59282 Mdot
.40292 .45759 Mdot
.62615 .42601 Mdot
.59095 .42832 Mdot
.24314 .67215 Mdot
.43315 .71105 Mdot
.67378 .50602 Mdot
.46083 .63363 Mdot
.67978 .45435 Mdot
.24387 .3999 Mdot
.50084 .33428 Mdot
.64373 .38917 Mdot
.37263 .79807 Mdot
.6365 .42394 Mdot
.37607 .46974 Mdot
.35999 .46942 Mdot
.65517 .45577 Mdot
.484 .32805 Mdot
.81963 .43089 Mdot
.71054 .39216 Mdot
.45553 .66259 Mdot
.21405 .47228 Mdot
.8536 .56832 Mdot
.65675 .57274 Mdot
.60346 .59518 Mdot
.44519 .41114 Mdot
.34133 .45257 Mdot
.62446 .56704 Mdot
.61895 .63749 Mdot
.51772 .29162 Mdot
.64056 .38485 Mdot
.40885 .61378 Mdot
.59516 .62229 Mdot
.44689 .38245 Mdot
.49614 .26844 Mdot
.32087 .4669 Mdot
.32236 .51502 Mdot
.4452 .44942 Mdot
.32853 .27179 Mdot
.64573 .59375 Mdot
.35342 .47113 Mdot
.31721 .45222 Mdot
.6005 .62035 Mdot
.52865 .32449 Mdot
.68136 .69434 Mdot
.66013 .41753 Mdot
.13835 .55804 Mdot
.34605 .46728 Mdot
.37239 .46733 Mdot
.65426 .61443 Mdot
.582 .3642 Mdot
.41882 .64247 Mdot
.39984 .66937 Mdot
.6186 .43565 Mdot
.52845 .5804 Mdot
.4065 .4156 Mdot
.35686 .44879 Mdot
.66467 .42702 Mdot
.61446 .44081 Mdot
.75454 .46164 Mdot
.37453 .48996 Mdot
.61584 .61222 Mdot
.5861 .48931 Mdot
.64304 .59069 Mdot
.34522 .47854 Mdot
.37382 .47228 Mdot
.40998 .41276 Mdot
.3385 .46709 Mdot
.64882 .58412 Mdot
.35539 .47439 Mdot
.43187 .38371 Mdot
.43189 .63309 Mdot
.42318 .42743 Mdot
.31948 .28086 Mdot
.39016 .47401 Mdot
.52584 .31164 Mdot
.48286 .43047 Mdot
.39375 .42101 Mdot
.42073 .41958 Mdot
.70921 .39368 Mdot
.39018 .45611 Mdot
.62451 .56267 Mdot
.42044 .66621 Mdot
.61489 .58923 Mdot
.65128 .59525 Mdot
.61403 .41388 Mdot
.53101 .30967 Mdot
.43044 .49267 Mdot
.50042 .29682 Mdot
.42868 .50126 Mdot
.3885 .50174 Mdot
.73985 .57139 Mdot
.71028 .25494 Mdot
.68873 .29364 Mdot
.40377 .45805 Mdot
.62306 .41179 Mdot
.6668 .44677 Mdot
.45725 .56198 Mdot
.33553 .40604 Mdot
.62342 .56818 Mdot
.62189 .58143 Mdot
.40379 .32404 Mdot
.77613 .60207 Mdot
.52751 .31523 Mdot
.52837 .42023 Mdot
.39901 .39456 Mdot
.37602 .49448 Mdot
.34219 .43369 Mdot
.61396 .39729 Mdot
.61985 .51049 Mdot
.63932 .38917 Mdot
.6945 .63688 Mdot
.63717 .58512 Mdot
.40583 .41963 Mdot
.36293 .74475 Mdot
.40648 .68376 Mdot
.42026 .66529 Mdot
.63154 .57408 Mdot
.59954 .38917 Mdot
.44783 .36205 Mdot
.24246 .26604 Mdot
.38503 .65302 Mdot
.48967 .29653 Mdot
.36277 .43732 Mdot
.63176 .41164 Mdot
.43138 .69782 Mdot
.48684 .34341 Mdot
.39082 .49875 Mdot
.57548 .39997 Mdot
.40627 .45889 Mdot
.3226 .38182 Mdot
.44811 .64116 Mdot
.25558 .72579 Mdot
.42339 .70518 Mdot
.59072 .60207 Mdot
.60332 .617 Mdot
.36547 .4714 Mdot
.43052 .17737 Mdot
.39724 .64961 Mdot
.6841 .61126 Mdot
.52985 .29611 Mdot
.67971 .55221 Mdot
.52117 .34026 Mdot
.6675 .43968 Mdot
.4969 .33704 Mdot
.66774 .41338 Mdot
.43331 .31387 Mdot
.39178 .69743 Mdot
.51643 .32472 Mdot
.67312 .37299 Mdot
.33879 .4036 Mdot
.48906 .35225 Mdot
.45918 .44477 Mdot
.20767 .54071 Mdot
.66287 .42892 Mdot
.48697 .31825 Mdot
.40443 .49202 Mdot
.49154 .8273 Mdot
.6083 .6133 Mdot
.61692 .56782 Mdot
.38148 .39434 Mdot
.63486 .38229 Mdot
.45663 .69585 Mdot
.49572 .73876 Mdot
.59221 .64602 Mdot
.35398 .45883 Mdot
.37864 .41038 Mdot
.45985 .62738 Mdot
.41478 .72469 Mdot
.37022 .47452 Mdot
.29041 .50268 Mdot
.3646 .48326 Mdot
.6115 .57973 Mdot
.4102 .69457 Mdot
.42718 .66994 Mdot
.65429 .44459 Mdot
.41048 .6391 Mdot
.47905 .62096 Mdot
.63636 .52435 Mdot
.45819 .42748 Mdot
.61852 .60461 Mdot
.63551 .5345 Mdot
.69391 .64 Mdot
.40992 .80327 Mdot
.4673 .63358 Mdot
.41788 .41374 Mdot
.46519 .6477 Mdot
.50424 .30852 Mdot
.42068 .65136 Mdot
.45821 .68702 Mdot
.36523 .45059 Mdot
.39443 .43042 Mdot
.62774 .39947 Mdot
.59013 .52802 Mdot
.43739 .63052 Mdot
.35475 .46548 Mdot
.36406 .40764 Mdot
.37277 .40171 Mdot
.51848 .48765 Mdot
.42748 .70063 Mdot
.25849 .50006 Mdot
.30985 .35163 Mdot
.43561 .63048 Mdot
.64941 .80024 Mdot
.71985 .58619 Mdot
.60402 .43093 Mdot
.62128 .5544 Mdot
.37563 .49059 Mdot
.65913 .4566 Mdot
.39141 .4324 Mdot
.32242 .51525 Mdot
.38458 .4501 Mdot
.51281 .34514 Mdot
.45006 .42117 Mdot
.67424 .46035 Mdot
.64705 .4237 Mdot
.35093 .44734 Mdot
.38571 .43806 Mdot
.65473 .2827 Mdot
.47267 .66857 Mdot
.42184 .64105 Mdot
.59553 .35787 Mdot
.51024 .32078 Mdot
.61186 .62856 Mdot
.41499 .43605 Mdot
.61501 .41986 Mdot
.64688 .42759 Mdot
.39747 .67826 Mdot
.65722 .42854 Mdot
.64653 .62432 Mdot
.40454 .45377 Mdot
.61966 .56713 Mdot
.49008 .3119 Mdot
.44507 .69106 Mdot
.40227 .42118 Mdot
.39956 .47689 Mdot
.46014 .65795 Mdot
.41527 .49906 Mdot
.49682 .34435 Mdot
.63828 .42637 Mdot
.44907 .65362 Mdot
.63295 .5968 Mdot
.66995 .43001 Mdot
.40046 .48647 Mdot
.87299 .48687 Mdot
.37932 .47369 Mdot
.38784 .49008 Mdot
.35052 .79896 Mdot
.45263 .42481 Mdot
.63888 .43891 Mdot
.43876 .61614 Mdot
.40926 .40026 Mdot
.36433 .26125 Mdot
.20097 .34401 Mdot
.63205 .38943 Mdot
.36356 .43263 Mdot
.41909 .81976 Mdot
.35638 .4383 Mdot
.28271 .28598 Mdot
.55641 .24934 Mdot
.49887 .57772 Mdot
.40898 .3887 Mdot
.64787 .61611 Mdot
.62643 .40029 Mdot
.66824 .43222 Mdot
.23155 .46869 Mdot
.36164 .45072 Mdot
.3564 .3664 Mdot
.41839 .49045 Mdot
.63791 .5918 Mdot
.37931 .3347 Mdot
.6469 .43356 Mdot
.75118 .32488 Mdot
.41786 .46095 Mdot
.4304 .7014 Mdot
.59716 .38253 Mdot
.72208 .59615 Mdot
.39677 .49077 Mdot
.49853 .29977 Mdot
.58816 .5817 Mdot
.43307 .40675 Mdot
.62411 .60609 Mdot
.37709 .49678 Mdot
.42555 .37375 Mdot
.5372 .17382 Mdot
.44208 .63666 Mdot
.60541 .58998 Mdot
.69274 .47705 Mdot
.44624 .47288 Mdot
.45121 .65505 Mdot
.41499 .66532 Mdot
.51454 .29203 Mdot
.5562 .51636 Mdot
.58695 .68811 Mdot
.35705 .67725 Mdot
.22376 .45985 Mdot
.59724 .3859 Mdot
.70731 .48672 Mdot
.41218 .4789 Mdot
.80082 .52432 Mdot
.60703 .56701 Mdot
.37526 .46575 Mdot
.21681 .55505 Mdot
.437 .69384 Mdot
.38089 .48392 Mdot
.52514 .33139 Mdot
.79684 .46379 Mdot
.80177 .49547 Mdot
.674 .75566 Mdot
.63737 .39764 Mdot
.36 .52035 Mdot
.31348 .495 Mdot
.60842 .41729 Mdot
.43278 .48562 Mdot
.63516 .43407 Mdot
.1819 .54234 Mdot
.48846 .34087 Mdot
.44275 .69484 Mdot
.72116 .58973 Mdot
.44105 .44982 Mdot
.35212 .41095 Mdot
.48056 .34352 Mdot
.42984 .45136 Mdot
.62458 .20182 Mdot
.7714 .50689 Mdot
.62982 .44764 Mdot
.43547 .63701 Mdot
.43895 .4371 Mdot
.55921 .48021 Mdot
.36132 .45673 Mdot
.32566 .66436 Mdot
.42321 .42071 Mdot
.57917 .67526 Mdot
.45615 .64436 Mdot
.6219 .60324 Mdot
.40317 .52061 Mdot
.39297 .44785 Mdot
.56181 .43084 Mdot
.41697 .39041 Mdot
.34696 .44818 Mdot
.44816 .70406 Mdot
.4135 .69486 Mdot
.43471 .65245 Mdot
.67713 .42528 Mdot
.77856 .59366 Mdot
.611 .60398 Mdot
.36181 .51432 Mdot
.59625 .62448 Mdot
.42231 .56151 Mdot
.48032 .3233 Mdot
.49994 .81681 Mdot
.43057 .43884 Mdot
.43555 .66036 Mdot
.59217 .75386 Mdot
.44523 .63003 Mdot
.54632 .44893 Mdot
.63854 .61082 Mdot
.4282 .69573 Mdot
.4024 .44432 Mdot
.60912 .52137 Mdot
.57868 .80887 Mdot
.62078 .58732 Mdot
.42184 .50276 Mdot
.6421 .46038 Mdot
.76404 .57895 Mdot
.88196 .51176 Mdot
.60077 .60605 Mdot
.68935 .48076 Mdot
.35941 .4484 Mdot
.40396 .67471 Mdot
.64836 .61879 Mdot
.61815 .62076 Mdot
.65822 .43307 Mdot
.39546 .42845 Mdot
.39822 .42547 Mdot
.67666 .45531 Mdot
.62507 .58261 Mdot
.33778 .42269 Mdot
.34786 .42998 Mdot
.39217 .83835 Mdot
.28234 .39002 Mdot
.12866 .46057 Mdot
.48871 .63486 Mdot
.22158 .57816 Mdot
.48602 .73167 Mdot
.45921 .68063 Mdot
.39215 .42099 Mdot
.44788 .44125 Mdot
.64857 .44397 Mdot
.39135 .46425 Mdot
.64272 .37871 Mdot
.60475 .60364 Mdot
.64348 .80009 Mdot
.64762 .71272 Mdot
.18183 .51982 Mdot
.38956 .46251 Mdot
.67984 .66637 Mdot
.51484 .30955 Mdot
.5976 .63102 Mdot
.44285 .65361 Mdot
.36004 .49524 Mdot
.66356 .2863 Mdot
.64252 .38923 Mdot
.41011 .67252 Mdot
.74435 .35662 Mdot
.71933 .35545 Mdot
.34571 .47968 Mdot
.67766 .43653 Mdot
.52882 .77101 Mdot
.2967 .50939 Mdot
.66419 .6245 Mdot
.51661 .3431 Mdot
.64162 .392 Mdot
.6377 .58119 Mdot
.41922 .74846 Mdot
.42195 .69304 Mdot
.40042 .63075 Mdot
.62255 .24907 Mdot
.60593 .40631 Mdot
.52087 .31319 Mdot
.77367 .60151 Mdot
.80935 .53672 Mdot
.51275 .34486 Mdot
.66394 .45941 Mdot
.41924 .69751 Mdot
.44579 .66911 Mdot
.42105 .66743 Mdot
.75878 .33681 Mdot
.41428 .70502 Mdot
.30409 .56271 Mdot
.35625 .41052 Mdot
.39825 .36655 Mdot
.36141 .4333 Mdot
.63332 .56824 Mdot
.45203 .64623 Mdot
.53542 .6089 Mdot
.36391 .51077 Mdot
.64837 .78023 Mdot
.35484 .45248 Mdot
.65391 .63237 Mdot
.38054 .48772 Mdot
.33033 .56959 Mdot
.46731 .65555 Mdot
.39814 .46265 Mdot
.6464 .57238 Mdot
.50216 .32061 Mdot
.45382 .60267 Mdot
.39506 .42254 Mdot
.53174 .72127 Mdot
.45441 .42913 Mdot
.2008 .62073 Mdot
.29947 .32709 Mdot
.48913 .29726 Mdot
.38012 .55156 Mdot
.61529 .38172 Mdot
.39518 .36509 Mdot
.30632 .44292 Mdot
.62242 .58865 Mdot
.72823 .67019 Mdot
.64585 .40207 Mdot
.43798 .33338 Mdot
.33214 .50143 Mdot
.5313 .31561 Mdot
.43076 .71687 Mdot
.64392 .57507 Mdot
.36315 .50264 Mdot
.33818 .49662 Mdot
.18746 .55665 Mdot
.32094 .41433 Mdot
.38894 .40901 Mdot
.47993 .33219 Mdot
.25836 .51867 Mdot
.39269 .47595 Mdot
.54423 .44922 Mdot
.40466 .62544 Mdot
.37158 .39416 Mdot
.26039 .49508 Mdot
.35516 .46382 Mdot
.40724 .67326 Mdot
.39178 .69132 Mdot
.59863 .73102 Mdot
.52829 .29637 Mdot
.42412 .42218 Mdot
.25371 .36138 Mdot
.42131 .45672 Mdot
.6188 .61255 Mdot
.34118 .46136 Mdot
.65077 .39552 Mdot
.75022 .33574 Mdot
.64367 .44871 Mdot
.38121 .42064 Mdot
.42395 .6724 Mdot
.65343 .608 Mdot
.6592 .26718 Mdot
.57866 .27289 Mdot
.29287 .55306 Mdot
.16449 .47474 Mdot
.48516 .32608 Mdot
.5197 .34516 Mdot
.64953 .58138 Mdot
.39831 .46408 Mdot
.24459 .35053 Mdot
.44523 .40418 Mdot
.38606 .48272 Mdot
.38384 .44936 Mdot
.7541 .617 Mdot
.60872 .59321 Mdot
.65741 .42048 Mdot
.37252 .47442 Mdot
.35517 .47046 Mdot
.46269 .66595 Mdot
.50111 .32272 Mdot
.6629 .45208 Mdot
.50672 .32828 Mdot
.62763 .41609 Mdot
.63609 .80894 Mdot
.39054 .51815 Mdot
.50475 .31921 Mdot
.59278 .58128 Mdot
.41121 .6534 Mdot
.63799 .52224 Mdot
.66742 .43832 Mdot
.64951 .4373 Mdot
.35498 .45541 Mdot
.40565 .66926 Mdot
.41778 .63321 Mdot
.50364 .3078 Mdot
.61623 .62484 Mdot
.38846 .42462 Mdot
.3797 .50204 Mdot
.47583 .57029 Mdot
.61746 .39382 Mdot
.2875 .44226 Mdot
.56769 .74415 Mdot
.40232 .46076 Mdot
.41362 .64066 Mdot
.37968 .44415 Mdot
.37011 .76745 Mdot
.40259 .66546 Mdot
.34856 .43913 Mdot
.8227 .5093 Mdot
.60586 .50089 Mdot
.55744 .7074 Mdot
.40066 .40797 Mdot
.1504 .55882 Mdot
.41962 .47558 Mdot
.41756 .84066 Mdot
.63766 .30032 Mdot
.40339 .41735 Mdot
.40605 .47976 Mdot
.36957 .72308 Mdot
.37068 .43575 Mdot
.67681 .46057 Mdot
.43422 .3323 Mdot
.45723 .69189 Mdot
.51646 .68118 Mdot
.49891 .44125 Mdot
.52221 .28987 Mdot
.61914 .43665 Mdot
.64354 .49166 Mdot
.51434 .33987 Mdot
.43186 .68019 Mdot
.41536 .44896 Mdot
.51759 .56939 Mdot
.68256 .42715 Mdot
.33494 .42008 Mdot
.62546 .61365 Mdot
.7316 .49986 Mdot
.61838 .37251 Mdot
.62855 .60013 Mdot
.43603 .45168 Mdot
.37944 .72183 Mdot
.53843 .22824 Mdot
.26893 .74382 Mdot
.65525 .60693 Mdot
.63065 .58241 Mdot
.7786 .35972 Mdot
.5237 .28864 Mdot
.19468 .52117 Mdot
.56229 .66304 Mdot
.64347 .62889 Mdot
.26505 .3732 Mdot
.63469 .38638 Mdot
.53428 .71138 Mdot
.44688 .61254 Mdot
.33699 .43905 Mdot
.39983 .4458 Mdot
.61226 .62397 Mdot
.41735 .75125 Mdot
.52156 .17166 Mdot
.62214 .59407 Mdot
.44513 .38731 Mdot
.51384 .51395 Mdot
.71758 .58323 Mdot
.61691 .39871 Mdot
.52562 .29514 Mdot
.54657 .29675 Mdot
.45724 .67439 Mdot
.52419 .29763 Mdot
.79754 .48456 Mdot
.43046 .44508 Mdot
.62799 .58938 Mdot
.71747 .60393 Mdot
.63576 .59894 Mdot
.51725 .33689 Mdot
.4927 .29249 Mdot
.43099 .63341 Mdot
.42257 .64153 Mdot
.23201 .59437 Mdot
.37168 .31844 Mdot
.35358 .44212 Mdot
.60636 .78194 Mdot
.46039 .6395 Mdot
.34642 .53627 Mdot
.5263 .33865 Mdot
.50546 .32171 Mdot
.30397 .38446 Mdot
.40974 .42636 Mdot
.26037 .32953 Mdot
.41108 .4299 Mdot
.37888 .32973 Mdot
.44311 .47391 Mdot
.65781 .43115 Mdot
.41189 .42461 Mdot
.46811 .3528 Mdot
.34031 .48912 Mdot
.34426 .45699 Mdot
.631 .38184 Mdot
.42775 .40429 Mdot
.6524 .39703 Mdot
.37702 .42007 Mdot
.53964 .31274 Mdot
.61431 .42263 Mdot
.3982 .25553 Mdot
.68935 .41286 Mdot
.64216 .46269 Mdot
.51768 .29739 Mdot
.50054 .29315 Mdot
.39052 .23645 Mdot
.44408 .65451 Mdot
.47488 .6261 Mdot
.39462 .4666 Mdot
.62761 .37944 Mdot
.60681 .59219 Mdot
.35712 .47538 Mdot
.45261 .44298 Mdot
.38304 .40685 Mdot
.45203 .68548 Mdot
.5811 .39804 Mdot
.50151 .316 Mdot
.67831 .42776 Mdot
.56559 .40484 Mdot
.6645 .39442 Mdot
.3155 .45972 Mdot
.42336 .51696 Mdot
.23357 .62672 Mdot
.65948 .73884 Mdot
.81536 .40674 Mdot
.41675 .68936 Mdot
.61195 .43432 Mdot
.5081 .28832 Mdot
.44069 .52394 Mdot
.44091 .65981 Mdot
.65709 .3997 Mdot
.40708 .45764 Mdot
.42241 .50317 Mdot
.57672 .5984 Mdot
.37716 .36582 Mdot
.32843 .29126 Mdot
.65766 .38985 Mdot
.62682 .37192 Mdot
.80697 .536 Mdot
.4319 .337 Mdot
.5372 .57325 Mdot
.37396 .45689 Mdot
.49659 .30164 Mdot
.4312 .69782 Mdot
.57551 .22992 Mdot
.59676 .60607 Mdot
.5878 .53019 Mdot
.39104 .46213 Mdot
.54919 .63252 Mdot
.42237 .67169 Mdot
.52764 .32378 Mdot
.61143 .62417 Mdot
.49284 .28879 Mdot
.60871 .40719 Mdot
.20601 .37711 Mdot
.42521 .4552 Mdot
.35307 .43828 Mdot
.59308 .59778 Mdot
.44625 .68519 Mdot
.47727 .33357 Mdot
.22105 .64541 Mdot
.65239 .45423 Mdot
.25089 .32969 Mdot
.41723 .62793 Mdot
.33849 .59449 Mdot
.67782 .42356 Mdot
.63158 .57461 Mdot
.40649 .23524 Mdot
.63932 .58914 Mdot
.38855 .41587 Mdot
.43078 .66509 Mdot
.60932 .61255 Mdot
.56188 .45722 Mdot
.44697 .82477 Mdot
.35339 .60942 Mdot
.42151 .43554 Mdot
.54051 .82161 Mdot
.28687 .72924 Mdot
.376 .67919 Mdot
.59555 .6161 Mdot
.3643 .45979 Mdot
.43798 .47249 Mdot
.41727 .45817 Mdot
.6372 .61636 Mdot
.72738 .55719 Mdot
.66369 .43298 Mdot
.35794 .44162 Mdot
.51491 .29083 Mdot
.6541 .40084 Mdot
.72722 .59579 Mdot
.6434 .43972 Mdot
.4736 .65345 Mdot
.34053 .45661 Mdot
.63424 .54365 Mdot
.51456 .85065 Mdot
.6163 .58851 Mdot
.64356 .46326 Mdot
.35048 .47664 Mdot
.72856 .64904 Mdot
.4356 .65439 Mdot
.64906 .45375 Mdot
.37225 .46668 Mdot
.69947 .55131 Mdot
.65026 .27838 Mdot
.64436 .43876 Mdot
.44803 .66438 Mdot
.43348 .77001 Mdot
.38761 .46685 Mdot
.42282 .4718 Mdot
.4434 .6848 Mdot
.4915 .42728 Mdot
.7542 .35965 Mdot
.38372 .44064 Mdot
.62304 .60242 Mdot
.26612 .26608 Mdot
.38129 .40281 Mdot
.31786 .36225 Mdot
.63182 .39518 Mdot
.55468 .73122 Mdot
.28654 .44875 Mdot
.38109 .54809 Mdot
.38683 .75582 Mdot
.51572 .45217 Mdot
.62054 .80864 Mdot
.63094 .37598 Mdot
.6707 .33109 Mdot
.61436 .81666 Mdot
.6567 .58769 Mdot
.45564 .72509 Mdot
.4596 .58486 Mdot
.73869 .30569 Mdot
.45687 .76607 Mdot
.62729 .34298 Mdot
.6801 .29369 Mdot
.50746 .54779 Mdot
.63138 .42309 Mdot
.46203 .36163 Mdot
.3899 .42783 Mdot
.28137 .72581 Mdot
.29338 .51436 Mdot
.49238 .16156 Mdot
.52932 .82232 Mdot
.25777 .36008 Mdot
.52372 .81112 Mdot
.39943 .80402 Mdot
.2184 .60456 Mdot
.64023 .74911 Mdot
.27207 .27967 Mdot
.81702 .50376 Mdot
.21575 .41506 Mdot
.40795 .53144 Mdot
.53554 .41003 Mdot
.16755 .55229 Mdot
.3162 .59123 Mdot
.41297 .1893 Mdot
.65191 .44847 Mdot
.43659 .61627 Mdot
.46821 .58628 Mdot
.45011 .70722 Mdot
.5632 .59128 Mdot
.4035 .775 Mdot
.39944 .82624 Mdot
.31986 .55878 Mdot
.14851 .56716 Mdot
.22575 .53144 Mdot
.7293 .23825 Mdot
.70339 .37527 Mdot
.39696 .64331 Mdot
.55969 .35337 Mdot
.80297 .55344 Mdot
.63735 .70094 Mdot
.4907 .63109 Mdot
.75509 .57714 Mdot
.40993 .27458 Mdot
.43478 .67567 Mdot
.29319 .49464 Mdot
.7201 .41864 Mdot
.66801 .69729 Mdot
.52015 .24803 Mdot
.40972 .7935 Mdot
.53311 .55339 Mdot
.52629 .70716 Mdot
.72154 .48017 Mdot
.87189 .49068 Mdot
.31157 .33748 Mdot
.32694 .74113 Mdot
.57836 .56919 Mdot
.42892 .76103 Mdot
.69507 .26801 Mdot
.39772 .30738 Mdot
.80543 .54937 Mdot
.77865 .64735 Mdot
.25731 .71278 Mdot
.79721 .64819 Mdot
.47285 .62328 Mdot
.38928 .40792 Mdot
.31947 .71805 Mdot
.25212 .40988 Mdot
.54186 .32736 Mdot
.69562 .73639 Mdot
.48831 .31315 Mdot
.47462 .67631 Mdot
.74374 .33599 Mdot
.31213 .56182 Mdot
.25905 .32273 Mdot
.475 .3345 Mdot
.44223 .43267 Mdot
.44812 .11896 Mdot
.61212 .80875 Mdot
.59284 .72826 Mdot
.39406 .83966 Mdot
.57591 .64815 Mdot
.28537 .32849 Mdot
.61385 .61496 Mdot
.5727 .83849 Mdot
.44123 .66839 Mdot
.72075 .77202 Mdot
.49705 .8406 Mdot
.51109 .18357 Mdot
.19718 .28603 Mdot
.79188 .5175 Mdot
.51007 .59278 Mdot
.50678 .46543 Mdot
.36417 .27572 Mdot
.56906 .19207 Mdot
.46835 .18381 Mdot
.72623 .64043 Mdot
.16729 .50817 Mdot
.57734 .83208 Mdot
.24819 .39279 Mdot
.20822 .39139 Mdot
.72913 .29543 Mdot
.5319 .44567 Mdot
.47101 .69673 Mdot
.7014 .42963 Mdot
.48623 .79219 Mdot
.73581 .71745 Mdot
.3067 .3623 Mdot
.22661 .27737 Mdot
.4735 .35313 Mdot
.62911 .30347 Mdot
.33432 .77069 Mdot
.42469 .25323 Mdot
.27412 .37862 Mdot
.78695 .39105 Mdot
.32411 .44082 Mdot
.80573 .42579 Mdot
.54949 .79208 Mdot
.66589 .5034 Mdot
.81494 .48821 Mdot
.51165 .75819 Mdot
.19509 .58834 Mdot
.32469 .69898 Mdot
.80183 .56519 Mdot
.46598 .68295 Mdot
.3832 .2988 Mdot
.28765 .35181 Mdot
.38457 .83354 Mdot
.69101 .47788 Mdot
.31655 .80696 Mdot
.73075 .34154 Mdot
.44282 .48322 Mdot
.30413 .4405 Mdot
.46567 .41628 Mdot
.35936 .31367 Mdot
.36611 .40777 Mdot
.68806 .66054 Mdot
.36963 .82066 Mdot
.21593 .52738 Mdot
.66552 .5098 Mdot
.72948 .67374 Mdot
.27389 .7484 Mdot
.25907 .66292 Mdot
.66288 .29654 Mdot
.37078 .34908 Mdot
.81677 .37515 Mdot
.65187 .40607 Mdot
.24589 .39328 Mdot
.66369 .61686 Mdot
.58353 .24006 Mdot
.36033 .66155 Mdot
.55062 .19901 Mdot
.36852 .82019 Mdot
.75427 .37758 Mdot
.70971 .31754 Mdot
.44534 .22796 Mdot
.24524 .32333 Mdot
.72144 .69368 Mdot
.35966 .51768 Mdot
.49912 .68083 Mdot
.48354 .31782 Mdot
.25974 .63272 Mdot
.23432 .42025 Mdot
.58963 .3179 Mdot
.42299 .39594 Mdot
.51512 .22363 Mdot
.58857 .37752 Mdot
.60246 .5255 Mdot
.83713 .61891 Mdot
.32594 .4225 Mdot
.77517 .57555 Mdot
.23025 .68071 Mdot
.34106 .30552 Mdot
.33507 .76492 Mdot
.50901 .72943 Mdot
.7884 .65328 Mdot
.46653 .83875 Mdot
.57972 .2879 Mdot
.66703 .77695 Mdot
.37534 .83828 Mdot
.80782 .61845 Mdot
.32787 .40029 Mdot
.62354 .5605 Mdot
.86033 .62885 Mdot
.68245 .4404 Mdot
.75945 .64092 Mdot
.22402 .45985 Mdot
.70449 .54431 Mdot
.44071 .59571 Mdot
.43345 .5158 Mdot
.5127 .55282 Mdot
.38463 .70461 Mdot
.40531 .39775 Mdot
.85299 .55757 Mdot
.79804 .61415 Mdot
.82868 .60504 Mdot
.19134 .62615 Mdot
.66562 .78149 Mdot
.48496 .55474 Mdot
.31862 .58105 Mdot
.44842 .55581 Mdot
.34178 .47771 Mdot
.46299 .30108 Mdot
.79074 .51416 Mdot
.53963 .21918 Mdot
.62221 .69538 Mdot
.46119 .6972 Mdot
.64318 .76961 Mdot
.87634 .37746 Mdot
.23303 .55169 Mdot
.24957 .47397 Mdot
.80428 .50918 Mdot
.35282 .32271 Mdot
.51173 .79438 Mdot
.51937 .19865 Mdot
.35917 .80344 Mdot
.4343 .56968 Mdot
.21507 .44048 Mdot
.60084 .34183 Mdot
.32012 .26373 Mdot
.59293 .36319 Mdot
.43393 .81192 Mdot
.48162 .51042 Mdot
.61754 .23108 Mdot
.52544 .63533 Mdot
.5153 .17786 Mdot
.60451 .26809 Mdot
.73584 .49509 Mdot
.23211 .39916 Mdot
.71407 .62916 Mdot
.34229 .33573 Mdot
.52234 .5212 Mdot
.45814 .50356 Mdot
.51541 .45361 Mdot
.33037 .34003 Mdot
.33587 .25551 Mdot
.72361 .72734 Mdot
.3814 .85163 Mdot
.85568 .47185 Mdot
.15264 .58231 Mdot
.54819 .7869 Mdot
.33666 .43465 Mdot
.31922 .77422 Mdot
.80271 .65537 Mdot
.46757 .84542 Mdot
.75023 .41181 Mdot
.60604 .49244 Mdot
.59112 .62072 Mdot
.85231 .4883 Mdot
.60971 .35416 Mdot
.37467 .78904 Mdot
.81475 .42988 Mdot
.61369 .55392 Mdot
.69913 .24604 Mdot
.79247 .61258 Mdot
.3669 .63219 Mdot
.32078 .39327 Mdot
.32759 .44721 Mdot
.3309 .5606 Mdot
.47 .64895 Mdot
.71191 .47791 Mdot
.38165 .3113 Mdot
.64456 .41165 Mdot
.49333 .26434 Mdot
.49961 .6569 Mdot
.449 .41957 Mdot
.50418 .44061 Mdot
.4402 .61501 Mdot
.65664 .74003 Mdot
.67028 .55599 Mdot
.70525 .7647 Mdot
.78274 .49989 Mdot
.41326 .38824 Mdot
.33407 .31358 Mdot
.72458 .37427 Mdot
.78018 .37704 Mdot
.65964 .61725 Mdot
.50738 .82601 Mdot
.54405 .4326 Mdot
.38089 .30152 Mdot
.32748 .55353 Mdot
.20406 .59943 Mdot
.42596 .51656 Mdot
.58154 .74757 Mdot
.30821 .65446 Mdot
.59358 .52452 Mdot
.47173 .69346 Mdot
.46661 .7043 Mdot
.23459 .72501 Mdot
.79199 .44866 Mdot
.71967 .49269 Mdot
.49425 .82527 Mdot
.64519 .60607 Mdot
.43978 .62987 Mdot
.45422 .31968 Mdot
.19794 .60262 Mdot
.3176 .63255 Mdot
.65184 .27888 Mdot
.762 .53797 Mdot
.60282 .31218 Mdot
.51378 .81779 Mdot
.53678 .81633 Mdot
.48125 .15732 Mdot
.43112 .71217 Mdot
.22673 .64011 Mdot
.18792 .49668 Mdot
.456 .6284 Mdot
.42641 .59135 Mdot
.65582 .68817 Mdot
.71988 .74129 Mdot
.66425 .56662 Mdot
.1622 .51288 Mdot
.34355 .26322 Mdot
.71132 .55718 Mdot
.6654 .27128 Mdot
.23126 .38435 Mdot
.48142 .82351 Mdot
.30644 .51842 Mdot
.37182 .64106 Mdot
.45858 .46148 Mdot
.38709 .36262 Mdot
.85766 .43524 Mdot
.68381 .40283 Mdot
.33921 .59041 Mdot
.50356 .75291 Mdot
.42185 .44856 Mdot
.86888 .49794 Mdot
.25554 .69601 Mdot
.78571 .3668 Mdot
.58666 .59037 Mdot
.4207 .48364 Mdot
.33769 .48168 Mdot
.34993 .35727 Mdot
.57578 .73346 Mdot
.76645 .64987 Mdot
.22898 .38873 Mdot
.50841 .77784 Mdot
.29728 .51827 Mdot
.77344 .57839 Mdot
.4018 .78738 Mdot
.30365 .74034 Mdot
.56608 .51018 Mdot
.78835 .50133 Mdot
.4241 .23663 Mdot
.15853 .58275 Mdot
.54957 .39811 Mdot
.4818 .56723 Mdot
.64204 .67614 Mdot
.53964 .74207 Mdot
.6189 .24057 Mdot
.37139 .49761 Mdot
.7446 .35678 Mdot
.39873 .80109 Mdot
.38991 .18737 Mdot
.62015 .21435 Mdot
.8673 .51246 Mdot
.33552 .67299 Mdot
.52465 .73824 Mdot
.4024 .75744 Mdot
.35105 .19433 Mdot
.54066 .39984 Mdot
.62429 .79113 Mdot
.43079 .23153 Mdot
.50396 .82185 Mdot
.63818 .56308 Mdot
.54224 .64261 Mdot
.7328 .67022 Mdot
.69848 .7564 Mdot
.28081 .68215 Mdot
.4308 .80486 Mdot
.53011 .61109 Mdot
.76653 .70673 Mdot
.70773 .66214 Mdot
.50283 .53708 Mdot
.61442 .43546 Mdot
.77323 .39354 Mdot
.52483 .804 Mdot
.60964 .76775 Mdot
.23414 .40578 Mdot
.6495 .37063 Mdot
.44333 .33258 Mdot
.37662 .59906 Mdot
.45067 .25889 Mdot
.53734 .75268 Mdot
.33466 .31275 Mdot
.4053 .81609 Mdot
.55558 .3824 Mdot
.71654 .33332 Mdot
.77071 .57771 Mdot
.19518 .40397 Mdot
.58167 .72969 Mdot
.7904 .43758 Mdot
.33091 .74686 Mdot
.61485 .28727 Mdot
.26948 .35525 Mdot
.42097 .90074 Mdot
.19592 .44564 Mdot
.67783 .71358 Mdot
.73685 .71562 Mdot
.32359 .75955 Mdot
.67159 .72665 Mdot
.58298 .19325 Mdot
.28153 .39465 Mdot
.43942 .31129 Mdot
.38557 .44942 Mdot
.8315 .62173 Mdot
.42508 .27642 Mdot
.74841 .71028 Mdot
.29826 .7651 Mdot
.34306 .56933 Mdot
.44748 .41831 Mdot
.66848 .40493 Mdot
.71211 .43861 Mdot
.46665 .26087 Mdot
.36832 .69441 Mdot
.2669 .40845 Mdot
.7717 .51686 Mdot
.60785 .41545 Mdot
.5966 .35847 Mdot
.38699 .6303 Mdot
.77553 .47227 Mdot
.559 .74496 Mdot
.49329 .27864 Mdot
.55473 .54001 Mdot
.33465 .33272 Mdot
.28443 .45628 Mdot
.36393 .63608 Mdot
.55915 .20205 Mdot
.53832 .46511 Mdot
.6406 .44099 Mdot
.35329 .68795 Mdot
.17226 .50577 Mdot
.535 .76649 Mdot
.77543 .65951 Mdot
.77029 .37963 Mdot
.45826 .52478 Mdot
.33251 .34351 Mdot
.55041 .19035 Mdot
.30231 .2656 Mdot
.66294 .74617 Mdot
.30429 .4886 Mdot
.26932 .32557 Mdot
.50118 .63547 Mdot
.63081 .81041 Mdot
.21532 .42044 Mdot
.21114 .47044 Mdot
.70428 .39898 Mdot
.30844 .59706 Mdot
.36132 .57701 Mdot
.39501 .25136 Mdot
.55185 .55877 Mdot
.74411 .25389 Mdot
.43804 .60837 Mdot
.87675 .44714 Mdot
.60493 .58559 Mdot
.74937 .30407 Mdot
.42058 .22554 Mdot
.52257 .51666 Mdot
.54564 .57281 Mdot
.59271 .74323 Mdot
.58096 .67468 Mdot
.16954 .58462 Mdot
.46182 .17329 Mdot
.66424 .39351 Mdot
.22826 .36577 Mdot
.20135 .37372 Mdot
.36582 .71454 Mdot
.43033 .41814 Mdot
.19288 .44688 Mdot
.65376 .3789 Mdot
.54228 .21845 Mdot
.30474 .75782 Mdot
.58783 .76675 Mdot
.42571 .37624 Mdot
.35983 .31961 Mdot
.61478 .79432 Mdot
.4648 .83409 Mdot
.64824 .21571 Mdot
.54987 .79169 Mdot
.61982 .56114 Mdot
.49255 .54514 Mdot
.45398 .80315 Mdot
.30166 .31067 Mdot
.52873 .68709 Mdot
.28202 .35337 Mdot
.83411 .35634 Mdot
.75225 .66471 Mdot
.7658 .65004 Mdot
.29527 .32762 Mdot
.40431 .70024 Mdot
.69496 .67327 Mdot
.27632 .37369 Mdot
.59939 .75802 Mdot
.17499 .56755 Mdot
.28321 .35868 Mdot
.46004 .14736 Mdot
.20604 .54743 Mdot
.56917 .39878 Mdot
.36894 .57735 Mdot
.21196 .54952 Mdot
.59962 .56605 Mdot
.457 .29318 Mdot
.50181 .75906 Mdot
.59177 .59706 Mdot
.5433 .75284 Mdot
.53631 .7209 Mdot
.20299 .50148 Mdot
.32765 .6332 Mdot
.52035 .78077 Mdot
.35424 .72559 Mdot
.42236 .73943 Mdot
.57902 .23142 Mdot
.59638 .41557 Mdot
.4846 .76129 Mdot
.63622 .45339 Mdot
.36526 .54108 Mdot
.58562 .52045 Mdot
.48453 .44244 Mdot
.84937 .46582 Mdot
.48434 .32032 Mdot
.3962 .66646 Mdot
.76591 .30985 Mdot
.43956 .61951 Mdot
.84537 .58226 Mdot
.53294 .20053 Mdot
.31906 .54696 Mdot
.5857 .28303 Mdot
.57659 .34669 Mdot
.59601 .15865 Mdot
.39945 .59902 Mdot
.70851 .4026 Mdot
.42285 .73217 Mdot
.40471 .6909 Mdot
.77445 .55104 Mdot
.61207 .40819 Mdot
.29968 .40156 Mdot
.64716 .66388 Mdot
.45423 .54181 Mdot
.39841 .70662 Mdot
.56514 .46976 Mdot
.40833 .33491 Mdot
.71196 .75008 Mdot
.63063 .42971 Mdot
.80702 .33737 Mdot
.45044 .47389 Mdot
.30505 .68388 Mdot
.35138 .80258 Mdot
.67602 .23149 Mdot
.66769 .47811 Mdot
.20965 .33324 Mdot
.4376 .48815 Mdot
.52373 .78491 Mdot
.44039 .6754 Mdot
.21403 .45721 Mdot
.49563 .33414 Mdot
.34854 .29381 Mdot
.59863 .6283 Mdot
.6204 .2333 Mdot
.77029 .47167 Mdot
.40131 .7017 Mdot
.58177 .77965 Mdot
.21538 .61161 Mdot
.54532 .66209 Mdot
.57684 .38072 Mdot
.36282 .70085 Mdot
.32262 .62722 Mdot
.39679 .70397 Mdot
.75276 .67847 Mdot
.21029 .4461 Mdot
.59725 .83816 Mdot
.46423 .41624 Mdot
.6951 .34609 Mdot
.62006 .6716 Mdot
.55944 .7556 Mdot
.30068 .41865 Mdot
.36624 .81167 Mdot
.39355 .30228 Mdot
.66008 .66883 Mdot
.37089 .329 Mdot
.40633 .54008 Mdot
.54547 .53528 Mdot
.73113 .45941 Mdot
.52529 .15589 Mdot
.33714 .37291 Mdot
.69692 .26258 Mdot
.31156 .49893 Mdot
.78103 .5636 Mdot
.39081 .63551 Mdot
.60295 .47938 Mdot
.31905 .60053 Mdot
.69395 .47418 Mdot
.61381 .82108 Mdot
.36264 .80868 Mdot
.58009 .58256 Mdot
.76611 .56303 Mdot
.46024 .74861 Mdot
.46153 .41919 Mdot
.53452 .6211 Mdot
.38898 .411 Mdot
.40354 .61339 Mdot
.69842 .24148 Mdot
.59128 .75472 Mdot
.34337 .5117 Mdot
.61799 .81121 Mdot
.56306 .83955 Mdot
.76021 .7101 Mdot
.24848 .32862 Mdot
.45543 .68707 Mdot
.82252 .6014 Mdot
.27119 .44719 Mdot
.41687 .82762 Mdot
.65062 .75328 Mdot
.25278 .74227 Mdot
.36714 .66436 Mdot
.50217 .74328 Mdot
.4744 .17763 Mdot
.5667 .68599 Mdot
.28095 .73201 Mdot
.50316 .50512 Mdot
.70513 .50862 Mdot
.28142 .73764 Mdot
.49347 .12271 Mdot
.29609 .45338 Mdot
.52863 .71576 Mdot
.49636 .6099 Mdot
.49058 .76144 Mdot
.65592 .30545 Mdot
.34127 .46235 Mdot
.72633 .61072 Mdot
.68489 .28859 Mdot
.3215 .33854 Mdot
.44428 .33185 Mdot
.65339 .30534 Mdot
.47538 .26477 Mdot
.39023 .32988 Mdot
.2155 .41378 Mdot
.36325 .67453 Mdot
.30238 .40277 Mdot
.44209 .48745 Mdot
.39903 .62226 Mdot
.53425 .30782 Mdot
.61824 .47182 Mdot
.37653 .41779 Mdot
.67206 .48056 Mdot
.55818 .67049 Mdot
.86224 .52874 Mdot
.65648 .51531 Mdot
.22792 .66273 Mdot
.44638 .613 Mdot
.57855 .73835 Mdot
.35709 .74412 Mdot
.74192 .31801 Mdot
.65362 .32963 Mdot
.30662 .36221 Mdot
.58464 .81812 Mdot
.81418 .49095 Mdot
.19249 .56293 Mdot
.82637 .52606 Mdot
.60089 .57313 Mdot
.37191 .37761 Mdot
.48863 .59385 Mdot
.75444 .3947 Mdot
.45734 .70819 Mdot
.50589 .74442 Mdot
.69191 .37789 Mdot
.80361 .46082 Mdot
.23391 .68641 Mdot
.20911 .60333 Mdot
.39119 .59258 Mdot
.54628 .81836 Mdot
.6294 .39023 Mdot
.20524 .46033 Mdot
.52298 .68122 Mdot
.66755 .33857 Mdot
.7806 .59732 Mdot
.68032 .78121 Mdot
.53739 .6078 Mdot
.40621 .26865 Mdot
.42202 .46523 Mdot
.25954 .5016 Mdot
.5993 .74818 Mdot
.47876 .37492 Mdot
.7599 .49325 Mdot
.40877 .65085 Mdot
.74813 .4783 Mdot
.53708 .38537 Mdot
.44057 .30421 Mdot
.39994 .71457 Mdot
.25421 .41518 Mdot
.53111 .34255 Mdot
.63336 .6604 Mdot
.38982 .39887 Mdot
.38725 .27551 Mdot
.25915 .31819 Mdot
.36427 .38264 Mdot
.51818 .79889 Mdot
.35858 .68102 Mdot
.18878 .57657 Mdot
.55343 .76881 Mdot
.67266 .73945 Mdot
.58455 .6792 Mdot
.33399 .60663 Mdot
.73661 .39055 Mdot
.38516 .40658 Mdot
.60737 .48462 Mdot
.42886 .62733 Mdot
.40777 .77166 Mdot
.32975 .66851 Mdot
.40152 .2551 Mdot
.53693 .50107 Mdot
.3471 .73749 Mdot
.53007 .48283 Mdot
.33283 .78355 Mdot
.56864 .68699 Mdot
.38617 .31048 Mdot
.65758 .57739 Mdot
.41801 .22845 Mdot
.57235 .19734 Mdot
.53086 .83658 Mdot
.53134 .18872 Mdot
.52084 .57904 Mdot
.69844 .25948 Mdot
.68732 .69507 Mdot
.29237 .75295 Mdot
.39515 .31539 Mdot
.5403 .60231 Mdot
.45009 .34074 Mdot
.57932 .57861 Mdot
.55387 .47766 Mdot
.58303 .45962 Mdot
.28168 .4209 Mdot
.74054 .5321 Mdot
.7279 .41356 Mdot
.44976 .49375 Mdot
.75735 .62653 Mdot
.56819 .81945 Mdot
.2196 .4597 Mdot
.52381 .45733 Mdot
.56213 .24504 Mdot
.4386 .29806 Mdot
.13353 .5724 Mdot
.87304 .48833 Mdot
.42324 .46341 Mdot
.52025 .44678 Mdot
.37885 .28998 Mdot
.67155 .40357 Mdot
.27283 .41875 Mdot
.37999 .74456 Mdot
.61933 .57691 Mdot
.59034 .47877 Mdot
.8012 .44569 Mdot
.60373 .73902 Mdot
.44907 .24718 Mdot
.74336 .62703 Mdot
.86312 .54057 Mdot
.16303 .53794 Mdot
.57207 .7559 Mdot
.16094 .63862 Mdot
.73878 .42836 Mdot
.47988 .68308 Mdot
.31837 .72088 Mdot
.72689 .72647 Mdot
.3321 .3101 Mdot
.61612 .24723 Mdot
.70226 .71429 Mdot
.39637 .3066 Mdot
.26718 .37685 Mdot
.7725 .57424 Mdot
.75227 .48143 Mdot
.51968 .53949 Mdot
.57737 .34722 Mdot
.81231 .57039 Mdot
.31051 .52877 Mdot
.58661 .80886 Mdot
.68564 .28648 Mdot
.4324 .15004 Mdot
.57497 .83853 Mdot
.47157 .28639 Mdot
.65667 .29942 Mdot
.31007 .71438 Mdot
.32415 .28204 Mdot
.26207 .40003 Mdot
.57063 .21688 Mdot
.3068 .62748 Mdot
.57075 .32434 Mdot
.69618 .27649 Mdot
.34054 .33646 Mdot
.21252 .5396 Mdot
.53975 .59896 Mdot
.35522 .65755 Mdot
.77841 .52833 Mdot
.30179 .32941 Mdot
.56247 .4498 Mdot
.35353 .26782 Mdot
.35653 .69683 Mdot
.34628 .75001 Mdot
.50376 .71439 Mdot
.52165 .12932 Mdot
.66955 .75034 Mdot
.73678 .31243 Mdot
.35992 .40843 Mdot
.64168 .81162 Mdot
.51298 .70304 Mdot
.69442 .72604 Mdot
.203 .63237 Mdot
.58835 .44797 Mdot
.58147 .65886 Mdot
.38277 .40722 Mdot
.58651 .79121 Mdot
.34316 .59136 Mdot
.21533 .56511 Mdot
.64049 .24947 Mdot
.34344 .31104 Mdot
.67099 .29866 Mdot
.38164 .25072 Mdot
.40524 .37884 Mdot
.4138 .63035 Mdot
.82435 .61702 Mdot
.5184 .59339 Mdot
.35286 .53199 Mdot
.43259 .36875 Mdot
.48659 .17408 Mdot
.16324 .45928 Mdot
.46094 .40923 Mdot
.81261 .51441 Mdot
.25608 .38157 Mdot
.44921 .52733 Mdot
.30821 .5073 Mdot
.11619 .39049 Mdot
.3897 .84747 Mdot
.44481 .70257 Mdot
.24294 .44425 Mdot
.26004 .34573 Mdot
.72015 .73392 Mdot
.60353 .3395 Mdot
.60424 .44356 Mdot
.4057 .19763 Mdot
.30517 .29254 Mdot
.44803 .46792 Mdot
.21956 .66642 Mdot
.51439 .83645 Mdot
.65514 .25566 Mdot
.60682 .81756 Mdot
.32376 .50447 Mdot
.35543 .51323 Mdot
.10901 .46513 Mdot
.46064 .80902 Mdot
.32454 .44391 Mdot
.48915 .17096 Mdot
.47328 .69323 Mdot
.39323 .43575 Mdot
.74669 .61715 Mdot
.22927 .39994 Mdot
.33998 .33872 Mdot
.70006 .7552 Mdot
.43054 .71596 Mdot
.68864 .47509 Mdot
.62559 .57439 Mdot
.54772 .56737 Mdot
.41312 .51159 Mdot
.63057 .61996 Mdot
.46191 .5072 Mdot
.48823 .75075 Mdot
.5974 .565 Mdot
.2143 .38544 Mdot
.29818 .78913 Mdot
.34109 .65974 Mdot
.58892 .63121 Mdot
.47156 .43974 Mdot
.20732 .55373 Mdot
.46918 .26247 Mdot
.4596 .55443 Mdot
.27376 .73735 Mdot
.53137 .89462 Mdot
.71269 .5116 Mdot
.41625 .35038 Mdot
.40148 .7161 Mdot
.29986 .40973 Mdot
.36863 .61207 Mdot
.67355 .62729 Mdot
.62447 .39827 Mdot
.44659 .40678 Mdot
.4055 .37979 Mdot
.59481 .62144 Mdot
.86742 .43551 Mdot
.34912 .47846 Mdot
.29708 .49005 Mdot
.42281 .82626 Mdot
.58217 .2319 Mdot
.28907 .67228 Mdot
.3883 .50714 Mdot
.68529 .67394 Mdot
.54104 .60442 Mdot
.4564 .7771 Mdot
.71825 .33686 Mdot
.65958 .77763 Mdot
.32695 .66722 Mdot
.37944 .58139 Mdot
.35316 .46547 Mdot
.53337 .29523 Mdot
.5364 .70554 Mdot
.71712 .70954 Mdot
.30634 .476 Mdot
.44485 .83784 Mdot
.58511 .44112 Mdot
.75234 .5427 Mdot
.43354 .54593 Mdot
.77906 .67615 Mdot
.6665 .24424 Mdot
.357 .58716 Mdot
.77383 .34537 Mdot
.77498 .42221 Mdot
.44807 .26038 Mdot
.66072 .39677 Mdot
.36858 .52913 Mdot
.42459 .71614 Mdot
.86606 .55111 Mdot
.72255 .70348 Mdot
.69476 .57637 Mdot
.73658 .49877 Mdot
.28501 .53704 Mdot
.52417 .65325 Mdot
.22257 .7203 Mdot
.62653 .34653 Mdot
.86624 .52985 Mdot
.2094 .46778 Mdot
.37668 .65442 Mdot
.52156 .74619 Mdot
.33512 .40128 Mdot
.6421 .43574 Mdot
.70018 .7469 Mdot
.40156 .38195 Mdot
.73154 .32801 Mdot
.41318 .49905 Mdot
.79432 .38259 Mdot
.60661 .50679 Mdot
.75706 .58802 Mdot
.7158 .6269 Mdot
.58523 .19537 Mdot
.38052 .77967 Mdot
.6348 .53937 Mdot
.1818 .65951 Mdot
.41761 .77365 Mdot
.5084 .82674 Mdot
.64144 .27347 Mdot
.62868 .19575 Mdot
.6191 .76523 Mdot
.52486 .77721 Mdot
.67297 .55362 Mdot
.49613 .47178 Mdot
.76661 .38832 Mdot
.45656 .51371 Mdot
.55151 .70442 Mdot
.58743 .56609 Mdot
.64105 .87859 Mdot
.46224 .328 Mdot
.49248 .65396 Mdot
.74235 .37822 Mdot
.54744 .82681 Mdot
.48179 .40661 Mdot
.24407 .70493 Mdot
.53611 .4106 Mdot
.36754 .52023 Mdot
.32288 .64384 Mdot
.2233 .44912 Mdot
.78015 .39637 Mdot
.64511 .17511 Mdot
.16524 .54225 Mdot
.74237 .51939 Mdot
.56131 .52987 Mdot
.45751 .63062 Mdot
.44364 .59655 Mdot
.58696 .30728 Mdot
.20178 .6613 Mdot
.4979 .74524 Mdot
.4548 .80394 Mdot
.58086 .1554 Mdot
.19386 .52416 Mdot
.72223 .73494 Mdot
.65443 .7303 Mdot
.42184 .6076 Mdot
.48118 .27334 Mdot
.53698 .26686 Mdot
.71925 .61532 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo08kooooo0_l0002iooooo`007?ooool00ol0003ooooooooo
o`2>ooooo`;o00003Oooool2o`000:[ooooo000Looooo`03o`000?oooooooooo09gooooo0_l0002Z
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0:Ko
oooo0_l0002Qooooo`007?ooool00ol0003oooooooooo`2Vooooo`;o0000XOooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Kooooo`;o0000[?ooool0
01cooooo00?o0000ooooooooool0Voooool2o`0000?ooooo0_l00008ooooo`;o0000WOooool001co
oooo00?o0000ooooooooool0Qoooool2o`0000Wooooo0_l0000:ooooo`Co00002?ooool2o`0009go
oooo000Looooo`03o`000?oooooooooo08Oooooo1?l00007ooooo`;o00002_ooool2o`0000Kooooo
0_l0002Qooooo`007?ooool2o`0008[ooooo0_l0000Kooooo`;o0000XOooool001cooooo00?o0000
ooooooooool0Toooool2o`0001;ooooo0_l0000@ooooo`;o0000S_ooool001cooooo00?o0000oooo
ooooool0Toooool2o`0000Cooooo0_l0000<ooooo`;o00004?ooool2o`000003ooooool0003o0000
00;o0000ROooool001cooooo00?o0000ooooooooool0VOooool2o`000003ooooool0003o000001ko
oooo1?l00029ooooo`007?ooool00ol0003oooooooooo`2Looooo`;o00002Oooool2o`000:3ooooo
000Looooo`03o`000?oooooooooo09cooooo0_l00009ooooo`;o0000X?ooool001cooooo00?o0000
ooooooooool0Voooool3o`0000Sooooo0_l0002Qooooo`007?ooool00ol0003oooooooooo`2Boooo
o`;o00001_ooool3o`0000Wooooo0_l00003ooooo`;o000000?oooooo`000?l000005_ooool2o`00
00Kooooo0_l0001iooooo`007?ooool00ol0003oooooooooo`28ooooo`;o00002?ooool2o`0000;o
oooo1_l00008ooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000001Ko
oooo0_l00006ooooo`;o0000NOooool001cooooo00?o0000ooooooooool0R?ooool2o`0000cooooo
1Ol00009ooooo`;o000000?oooooo`000?l00000X?ooool001cooooo00?o0000ooooooooool0R_oo
ool2o`0000Sooooo0_l00006ooooo`;o00001?ooool4o`0001Gooooo0_l0002<ooooo`007?ooool0
0ol0003oooooooooo`1kooooo`;o00000_ooool2o`0000Wooooo0_l00008ooooo`;o00001_ooool2
o`0000Cooooo0_l0000Fooooo`?o0000S?ooool001cooooo00?o0000ooooooooool0Noooool2o`00
00;ooooo1Ol0000Uooooo`;o00000_ooool4o`0000Wooooo0_l0002=ooooo`0000Koooooonk^k_lb
<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0POooool3
o`0002Gooooo0_l00002ooooo`Co00001?ooool2o`000003ooooool0003o000000;o00006Oooool2
o`0007;ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1^ooooo`;o00008Oooool2o`0001Kooooo
0_l00006ooooo`;o00000_ooool2o`000003ooooool0003o000000;o00003?ooool2o`0000_ooooo
0_l0001booooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ
8B7ok^k^00Oooooo00?o0000ooooooooool0GOooool2o`0000oooooo0_l0000?ooooo`?o00003ooo
ool2o`0001;ooooo0_l00008ooooo`Co00000oooool2o`0000;ooooo0ol00009ooooo`Co0000Oooo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06
ooooo`?o0000GOooool2o`0001Gooooo0_l00005ooooo`;o000000?oooooo`000?l000000_l0000S
ooooo`?o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000;ooooo0_l00003
ooooo`;o00002Oooool3o`00083ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`1`ooooo`;o00000_ooool2o`00
0003ooooool0003o000000;ooooo0_l000000ooooooo0000o`00000Vooooo`;o000000?oooooo`00
0?l000001oooool2o`0001?ooooo0_l00020ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413o
ooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0L?ooool2o`0000Go
oooo0_l0000]ooooo`;o0000XOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0
003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0F_ooool2o`0001Cooooo0_l0000d
ooooo`;o00001oooool2o`0001Cooooo0_l00022ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^
k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Jooooo`;o0000
5?ooool2o`00037ooooo0_l0000:ooooo`;o00001oooool2o`0000Oooooo0_l00002ooooo`?o0000
POooool001cooooo00?o0000ooooooooool0Loooool2o`0000kooooo0_l0000Nooooo`;o000000?o
ooooo`000?l000001?ooool2o`0000Gooooo0_l000000ooooooo0000o`000002o`0000Oooooo0_l0
00000ooooooo0000o`000002o`000003ooooool0003o000000Cooooo0_l0001hooooo`007?ooool0
0ol0003oooooooooo`1Pooooo`;o00004Oooool2o`0000kooooo0_l0000Qooooo`;o00001?ooool2
o`0000Gooooo0_l000001?oooooo0000o`000?ooool2o`0000Wooooo1?l000000ooooooo0000o`00
0002o`0000;ooooo0_l0001hooooo`007?ooool00ol0003oooooooooo`1Pooooo`Co00006oooool2
o`0002?ooooo0_l00006ooooo`;o00002oooool2o`0000Cooooo0_l0000:ooooo`;o00001oooool2
o`0000kooooo0_l0001Sooooo`007?ooool00ol0003oooooooooo`1Rooooo`;o00006?ooool2o`00
0003ooooool0003o000000Cooooo0_l0000Mooooo`;o00002?ooool2o`0000_ooooo0_l00002oooo
o`;o00002_ooool2o`0000Oooooo0_l0000>ooooo`;o0000Hoooool001cooooo00?o0000oooooooo
ool0K_ooool2o`0000Cooooo0_l00006ooooo`;o00001_ooool3o`0000Kooooo0_l0000Eooooo`;o
00001Oooool2o`000003ooooool0003o000000;ooooo0_l00003ooooo`;o00000_ooool2o`0000ko
oooo0_l000001?oooooo0000o`000?ooool2o`0007Kooooo000Looooo`03o`000?oooooooooo05go
oooo0_l0000?ooooo`;o00001?ooool2o`0000kooooo0_l00002ooooo`;o00000oooool2o`0001co
oooo0_l00005ooooo`;o00000oooool4o`0000Kooooo0_l00002ooooo`?o00001_ooool2o`000003
ooooool0003o000000Gooooo0_l0001_ooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o0000
1_ooool2o`0001Cooooo0_l00003ooooo`;o00001?ooool4o`0001;ooooo0_l0000;ooooo`;o0000
3Oooool3o`0000;ooooo0_l00002ooooo`;o00000_ooool3o`0000_ooooo0_l00003ooooo`;o0000
Koooool001cooooo00?o0000ooooooooool0IOooool2o`0001Cooooo1?l000000ooooooo0000o`00
0002ooooo`Co00005?ooool2o`0000_ooooo0_l0000?ooooo`;o000000?oooooo`000?l000005?oo
ool2o`000003ooooool0003o0000017ooooo0_l00007ooooo`;o0000EOooool001cooooo00?o0000
ooooooooool0Moooool2o`0000;ooooo2ol000000ooooooo0000o`000004o`0000Wooooo0ol0000Q
ooooo`;o00002Oooool2o`0000oooooo0_l00007ooooo`;o00002?ooool2o`0000Oooooo0_l0001E
ooooo`007?ooool00ol0003oooooooooo`1booooo`;o00000oooool2o`0000Gooooo0_l00002oooo
o`Co000000?oooooo`000?l000001?l00009ooooo`?o000000?oooooo`000?l000001oooool2o`00
00kooooo0_l0000@ooooo`;o00003_ooool2o`0000;ooooo0_l00004ooooo`;o0000J?ooool001co
oooo00?o0000ooooooooool0L_ooool2o`0000kooooo0_l00005ooooo`;o00000oooool2o`0000Ko
oooo0_l00002ooooo`;o00001oooool4o`0000cooooo0_l0000?ooooo`Co00003Oooool2o`0000;o
oooo0_l00004ooooo`;o0000J?ooool001cooooo0_l0001Yooooo`;o00003_ooool2o`0000?ooooo
0_l00003ooooo`;o00002Oooool5o`0001;ooooo0ol00008ooooo`Co00002Oooool5o`0000?ooooo
1?l00004ooooo`;o00002Oooool2o`000003ooooool0003o000006gooooo000Looooo`03o`000?oo
oooooooo06Sooooo0_l0000>ooooo`;o00000oooool4o`0000Gooooo0_l00005ooooo`;o000000Co
ooooo`000?l0003o00003oooool2o`0000_ooooo1?l00008ooooo`Ko00002oooool2o`0000Wooooo
0_l000000ooooooo0000o`000007ooooo`;o00002Oooool2o`0005Wooooo000Looooo`03o`000?oo
oooooooo063ooooo0_l00004ooooo`;o000000?oooooo`000?l000004oooool3o`0000Gooooo0_l0
0009ooooo`;o00000_ooool2o`0000Oooooo0_l000001?oooooo0000o`000?l0000Gooooo`;o0000
4oooool3o`00013ooooo0_l00009ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0H?oo
ool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0000Gooooo0_l00009ooooo`;o0000
2?ooool2o`0000Cooooo2Ol00003ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo
0_l0000<ooooo`;o00006oooool3o`0000cooooo0_l0000=ooooo`;o0000FOooool001cooooo00?o
0000ooooooooool0DOooool2o`00017ooooo0_l00006ooooo`Co00000oooool2o`0000Wooooo0_l0
0008ooooo`;o00001?ooool9o`0000?ooooo1?l00006ooooo`?o00000oooool2o`0000Oooooo0_l0
000Hooooo`;o00004?ooool2o`0000Gooooo0_l00006ooooo`;o0000FOooool001cooooo00?o0000
ooooooooool0Boooool2o`0000Cooooo1?l00009ooooo`;o00001?ooool2o`0000Gooooo1Ol0000>
ooooo`;o00005Oooool4o`0000?ooooo0_l00006ooooo`;o00001?ooool3o`0000_ooooo0_l0000B
ooooo`?o00000oooool2o`0000_ooooo0_l00005ooooo`;o0000HOooool001cooooo00?o0000oooo
ooooool0Boooool2o`0000Kooooo0_l00009ooooo`?o00002_ooool2o`0000;ooooo0_l0000?oooo
o`;o00005Oooool2o`0000Cooooo0_l00003ooooo`;o00001oooool2o`0000_ooooo0_l00007oooo
o`;o00002Oooool2o`0000;ooooo1?l0000:ooooo`;o0000JOooool001cooooo00?o0000oooooooo
ool0Goooool2o`0000Kooooo1?l00004ooooo`;o00003oooool2o`0001Oooooo0_l00002ooooo`?o
00000_ooool2o`0001Cooooo0_l00007ooooo`;o00001_ooool2o`000005ooooool0003o0000o`00
0?ooool00_l00002ooooo`;o00002?ooool2o`0006Wooooo000Looooo`03o`000?oooooooooo05co
oooo0_l00009ooooo`Co00002?ooool2o`0000Gooooo0_l00005ooooo`;o00000oooool2o`00017o
oooo0_l00003ooooo`;o00000oooool2o`0001?ooooo0_l0000?ooooo`;o000000Coooooo`000?l0
003o00001Oooool2o`0000Sooooo0_l00008ooooo`;o0000Goooool001cooooo00?o0000oooooooo
ool0A_ooool2o`0000[ooooo0_l000000ooooooo0000o`000005ooooo`;o00003_ooool2o`0000Go
oooo0_l00005ooooo`;o00001Oooool4o`000003ooooool0003o000001Cooooo0_l00005ooooo`;o
00008?ooool3o`0000Oooooo1Ol00009ooooo`?o00001_ooool4o`0005oooooo000Looooo`03o`00
0?oooooooooo04Kooooo0_l000000ooooooo0000o`000007ooooo`;o000000?oooooo`000?l00000
2_ooool2o`000003ooooool0003o000000;o00001?ooool2o`000003ooooool0003o000000Cooooo
0_l00003ooooo`;o00001Oooool4o`0001Oooooo0_l0000;ooooo`;o00003oooool2o`0000Wooooo
0ol00007ooooo`Go00002Oooool2o`0000Oooooo0_l00003ooooo`;o0000G?ooool001cooooo00?o
0000ooooooooool0??ooool2o`0000Sooooo0_l000000ooooooo0000o`00000=ooooo`;o00001Ooo
ool4o`000003ooooool0003o000000;o00001oooool2o`0000Cooooo0_l0000:ooooo`Co000000?o
ooooo`000?l000005oooool9o`000003ooooool0003o000000oooooo0_l0000Eooooo`;o000000?o
ooooo`000?l000005?ooool3o`0005cooooo000Looooo`03o`000?oooooooooo03cooooo0_l0000G
ooooo`;o000000?oooooo`000?l000001Oooool2o`0000oooooo0_l0000Aooooo`Ko00003?ooool2
o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000007o`0000Wooooo0_l00006
ooooo`;o00002Oooool2o`0000kooooo0_l00005ooooo`;o00003Oooool3o`0005cooooo000Loooo
o`03o`000?oooooooooo03oooooo0_l0000Dooooo`;o00002?ooool2o`0000Kooooo1?l00005oooo
o`;o00001Oooool2o`0000Sooooo2?l00002ooooo`;o00002?ooool2o`000004ooooool0003o0000
ooooo`go00002Oooool2o`0000Kooooo0_l00009ooooo`;o00000oooool4o`0000Sooooo0_l00004
ooooo`;o00003_ooool2o`0005cooooo000Looooo`03o`000?oooooooooo03oooooo0_l0000Doooo
o`;o000000?oooooo`000?l000000oooool4o`0000Kooooo1?l00002ooooo`;o00002?ooool2o`00
00Sooooo1?l00005ooooo`?o00001?ooool2o`0000Sooooo4?l00004ooooo`;o00004_ooool2o`00
00Cooooo1?l00008ooooo`?o000000Coooooo`000?l0003ooooo0_l0000;ooooo`Co0000G?ooool0
01cooooo00?o0000ooooooooool0EOooool2o`000003ooooool0003o000000Oo00001_ooool2o`00
0004ooooool0003o0000ooooo`;o00002Oooool2o`00013ooooo0ol00004ooooo`Co00001_ooool@
o`0000?ooooo0ol0000Booooo`;o00001_ooool2o`0000Oooooo1ol000000ooooooo0000o`000007
ooooo`;o00000_ooool4o`0005cooooo000Looooo`;o0000C_ooool2o`0000;ooooo0_l00007oooo
o`?o00002_ooool2o`000003ooooool0003o000000cooooo0ol0000=ooooo`;o000000?oooooo`00
0?l000001_ooool2o`0000Kooooo4?l00003ooooo`?o00006_ooool2o`0000Gooooo2?l00002oooo
o`Co00001?ooool5o`0000Cooooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o
00000_ooool2o`0001cooooo0_l00007ooooo`?o000000?oooooo`000?l000002_ooool2o`000003
ooooool0003o000000Kooooo0_l00003ooooo`;o000000?oooooo`000?l000003ol00003ooooo`;o
00006?ooool4o`0000Gooooo0_l00002ooooo`Ko00000_ooool2o`0000Cooooo0_l000000ooooooo
0000o`000004ooooo`;o000000?oooooo`000?l00000Eoooool001cooooo00?o0000ooooooooool0
Aoooool2o`0000gooooo0_l0000;ooooo`;o00001_ooool2o`0000;ooooo0_l00009ooooo`Go0000
1Oooool2o`0000;ooooo0_l000000ooooooo0000o`00000:ooooo`?o000000?oooooo`000?l00000
3ol0000?ooooo`;o00001_ooool2o`0000Cooooo0_l00005ooooo`?o00001oooool2o`00013ooooo
0ol000000ooooooo0000o`00001Gooooo`007?ooool00ol0003oooooooooo`17ooooo`?o00002_oo
ool4o`0000Kooooo0_l00003ooooo`;o00000oooool5o`0000[ooooo1Ol000001?oooooo0000o`00
0?l00004ooooo`;o00004Oooool3o`000003ooooool0003o0000017o00000_ooool2o`0000Wooooo
0_l00006ooooo`;o00002oooool3o`0001Gooooo0_l00002ooooo`Co00001Oooool2o`0005;ooooo
000Looooo`03o`000?oooooooooo04Sooooo0_l0000:ooooo`;o00002?ooool2o`0000Sooooo0ol0
00000ooooooo0000o`000003ooooo`;o00001?ooool5o`0000;ooooo0_l00003ooooo`;o00001?oo
ool4o`0000[ooooo0_l000000ooooooo0000o`00000Fo`0000kooooo0_l0000=ooooo`;o00003Ooo
ool2o`0000Sooooo0_l00002ooooo`Co00001Oooool2o`0005;ooooo000Looooo`03o`000?oooooo
oooo05Gooooo0_l00005ooooo`;o00002oooool2o`000003ooooool0003o000000?ooooo0_l00004
ooooo`?o00000oooool2o`0000Cooooo0_l00004ooooo`Co00003OoooolGo`0000oooooo0_l0000=
ooooo`;o00003?ooool5o`0000[ooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`1@oooo
o`;o00000oooool2o`0000Gooooo0_l00003ooooo`;o00003Oooool3o`0000;ooooo1?l00004oooo
o`?o00001?ooool2o`0000Gooooo0_l00003ooooo`;o00000oooool2o`000003ooooool0003o0000
00[o000000?oooooo`000?l000001ol0000>ooooo`;o00005oooool2o`0000Kooooo0_l000001?oo
oooo0000o`000?ooool2o`0000Sooooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`1@oooo
o`;o00002_ooool2o`0000?ooooo0_l0000<ooooo`Co00000_ooool3o`0000Kooooo0_l00004oooo
o`;o00001Oooool2o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000004ol0000?oooo
o`;o00005oooool2o`0000[ooooo1?l00008ooooo`;o00002?ooool2o`00053ooooo000Looooo`03
o`000?oooooooooo04Gooooo0_l00005ooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`Go
00004?ooool3o`000003ooooool0003o000000Kooooo0_l00003ooooo`;o00003oooool2o`0000Ko
oooo5Ol00009ooooo`;o0000:Oooool2o`0000Oooooo0_l00004ooooo`;o00001Oooool2o`00053o
oooo000Looooo`03o`000?oooooooooo04Gooooo0_l00005ooooo`?o00001Oooool2o`0000?ooooo
1ol0000>ooooo`;o00000_ooool5o`0000?ooooo0_l00003ooooo`;o00003Oooool2o`0000;ooooo
0_l00004oooooaKo00002?ooool2o`0002Wooooo0_l00007ooooo`;o00000oooool3o`0000[ooooo
0_l0001;ooooo`007?ooool00ol0003oooooooooo`1=ooooo`?o000000?oooooo`000?l000001_oo
ool2o`000003ooooool0003o000000;o00004oooool6o`0000;ooooo0_l00002ooooo`;o00002?oo
ool2o`0000;ooooo0ol00002ooooo`;o00000ooooolGo`0002?ooooo0_l00003ooooo`;o00002Ooo
ool2o`0000Oooooo0_l00003ooooo`;o00002oooool2o`0004_ooooo000Looooo`03o`000?oooooo
oooo043ooooo0_l0000<ooooo`;o000000?oooooo`000?l000005_ooool2o`0000cooooo0_l00002
ooooo`;o00000_ooool4o`0000Kooooo1ol00007oooooaCo00009_ooool2o`0000?ooooo0_l00003
ooooo`;o00002?ooool2o`0000?ooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`10oooo
o`;o00003_ooool2o`000003ooooool0003o000000Kooooo0_l00003ooooo`?o000000Coooooo`00
0?l0003o00000_ooool4o`0000[ooooo0_l00004ooooo`?o000000?oooooo`000?l000001_ooool7
o`0000Oooooo5?l0000Dooooo`;o00004?ooool2o`0000;ooooo0_l00004ooooo`;o00001oooool8
o`0000;ooooo1?l000001?oooooo0000o`000?l0000<ooooo`;o0000AOooool001cooooo00?o0000
ooooooooool0@?ooool4o`0000Oooooo0_l00003ooooo`;o000000?oooooo`000?l000001?ooool4
o`0000?ooooo0ol000001Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`000?l000000_l0
0008ooooo`;o00001?ooool3o`0000;ooooo0_l00005ooooo`;o00000oooool4o`000004ooooool0
003o0000o`0000;ooooo5Ol0000Booooo`?o00004oooool2o`0000gooooo2?l00002ooooo`Co0000
00Coooooo`000?l0003o00003?ooool2o`0004Gooooo000Looooo`03o`000?oooooooooo03[ooooo
0_l00002ooooo`;o00000_ooool2o`0000Gooooo1?l00002ooooo`;o00002?ooool3o`0000Wooooo
0_l000001?oooooo0000o`000?ooool4o`0000Sooooo0_l00003ooooo`?o00000oooool2o`0000Go
oooo0_l00003ooooo`Co000000Coooooo`000?l0003o00000_ooool8o`000003ooooool0003o0000
00[o00004_ooool3o`0000Kooooo0_l0000Pooooo`;o000000?oooooo`000?l00000F_ooool001co
oooo00?o0000ooooooooool0>_ooool2o`0000;ooooo0_l00009ooooo`;o00001?ooool4o`0000Oo
oooo0_l00003ooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`Co00003Oooool3o`00
00Gooooo0_l00003ooooo`?o00001oooool4o`000003ooooool0003o000000go000000?oooooo`00
0?l000000_l0000<ooooo`;o00001Oooool2o`0000Oooooo0_l0000:ooooo`;o00002?ooool2o`00
00;ooooo0_l00003ooooo`;o00001?ooool2o`0000Wooooo0_l0001?ooooo`007?ooool2o`0004go
oooo0_l000000ooooooo0000o`000002o`0000[ooooo1?l0000:ooooo`;o00002?ooool2o`0000co
oooo0ol00004ooooo`;o00001?ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l0
00000_l00003ooooo`So000000?oooooo`000?l000000_l0000<ooooo`;o00003_ooool2o`0000[o
oooo0_l00008ooooo`;o00000_ooool4o`000003ooooool0003o000000Kooooo0_l00007ooooo`;o
0000Coooool001cooooo00?o0000ooooooooool0A_ooool2o`0000Cooooo0_l00007ooooo`;o0000
00?oooooo`000?l000000_l000000ooooooo0000o`000002ooooo`;o00004_ooool2o`0000cooooo
0_l0000;ooooo`;o00000_oooolBo`0000;ooooo0_l00008ooooo`;o00004?ooool2o`0001cooooo
1?l00009ooooo`;o00005oooool2o`0003oooooo000Looooo`03o`000?oooooooooo04Kooooo0_l0
00001?oooooo0000o`000?l00008ooooo`?o000000?oooooo`000?l000000_l00005ooooo`;o0000
4?ooool2o`0000Gooooo0_l0000Cooooo`;o00000oooool>o`0000;ooooo0_l0000:ooooo`Co0000
3_ooool4o`0001kooooo1?l00004ooooo`Co00006?ooool2o`000003ooooool0003o000003cooooo
000Looooo`03o`000?oooooooooo04Wooooo0ol00004ooooo`;o00000_ooool3o`000003ooooool0
003o000000_ooooo1Ol00004ooooo`;o00000oooool2o`0000Gooooo0_l0000Cooooo`Co00001?oo
ool3o`0000Cooooo0_l00003ooooo`?o00002_ooool2o`0000cooooo0_l00002ooooo`Co00007_oo
ool4o`0000Cooooo1?l000000ooooooo0000o`000006ooooo`?o00003oooool2o`0003cooooo000L
ooooo`03o`000?oooooooooo04Oooooo0_l00006ooooo`?o00001_ooool2o`0000Kooooo0_l00002
ooooo`Ko00001?ooool3o`0000Wooooo0_l0000Aooooo`?o000000Coooooo`000?l0003o00001?oo
ool2o`0000;ooooo0_l00005ooooo`;o00002oooool2o`0000_ooooo0ol00004ooooo`;o00007_oo
ool3o`0000Gooooo1?l000000ooooooo0000o`000005ooooo`Ko00001?ooool2o`0004Gooooo000L
ooooo`03o`000?oooooooooo04Kooooo0ol00006ooooo`;o00003oooool8o`0000Oooooo0_l00003
ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00000=ooooo`Co000000Co
ooooo`000?l0003o00001oooool3o`0001;ooooo0_l00007ooooo`;o00000_ooool2o`0002Cooooo
0ol000000ooooooo0000o`000003ooooo`Ko00001_ooool2o`0000;ooooo0ol00003ooooo`;o0000
AOooool001cooooo00?o0000ooooooooool0A_ooool2o`0001Oooooo0_l000000ooooooo0000o`00
0002ooooo`;o000000?oooooo`000?l000001Oooool2o`000005ooooool0003o0000o`000?ooool0
0_l00004ooooo`?o00002Oooool2o`000003ooooool0003o000000gooooo0_l0000Looooo`;o0000
4Oooool2o`0001Gooooo0_l000001?oooooo0000o`000?l00003ooooo`Ko00000_ooool3o`0000Co
oooo1?l0001:ooooo`007?ooool00ol0003oooooooooo`1Oooooo`;o00002?ooool2o`0000Gooooo
0_l000000ooooooo0000o`000009ooooo`;o00002Oooool2o`0000Wooooo0_l0000Xooooo`;o0000
0oooool4o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`00000Eooooo`;o0000
0oooool2o`000003ooooool0003o000000;ooooo1Ol00004ooooo`;o0000C?ooool001cooooo00?o
0000ooooooooool0?_ooool2o`0001;ooooo0_l00002ooooo`;o00002Oooool4o`0000Gooooo0_l0
0008ooooo`;o00004?ooool2o`0000cooooo0_l00002ooooo`;o00006?ooool2o`0000Oooooo0_l0
00000ooooooo0000o`000003ooooo`Co000000?oooooo`000?l000000_l00003ooooo`;o00001_oo
ool2o`0000Sooooo0_l00003ooooo`Co000000?oooooo`000?l000001?ooool3o`00017ooooo0_l0
0012ooooo`007?ooool00ol0003oooooooooo`0nooooo`?o00003?ooool2o`0000?ooooo1_l00009
ooooo`Co00001Oooool2o`0000Sooooo0ol00002ooooo`;o00002oooool4o`0000kooooo0_l0000H
ooooo`;o00001oooool2o`0000Kooooo2Ol000000ooooooo0000o`000008ooooo`;o00001?ooool2
o`0000;ooooo0_l00003ooooo`Co00000oooool2o`0000;ooooo0_l00005ooooo`Co00002Oooool2
o`0001;ooooo0_l0000^ooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00003?ooool4o`00
00;ooooo1?l0000:ooooo`;o00004_ooool2o`0000;ooooo0_l00005ooooo`;o00001Oooool5o`00
02?ooooo0_l00007ooooo`Go00000oooool2o`000003ooooool0003o000000_o000000?oooooo`00
0?l000002_ooool2o`0000Oooooo0_l00005ooooo`;o00000_ooool2o`0000?ooooo1_l0000Moooo
o`;o0000;_ooool001cooooo00?o0000ooooooooool0=?ooool2o`00017ooooo0_l00006ooooo`;o
00000_ooool2o`0000[ooooo0_l00003ooooo`?o00003?ooool2o`0000Gooooo0_l00003ooooo`?o
00001_ooool4o`000003ooooool0003o0000023ooooo1?l00005ooooo`Go000000?oooooo`000?l0
00004ol0000Sooooo`;o00000oooool2o`000003ooooool0003o000000_ooooo0_l0000looooo`00
7?ooool00ol0003oooooooooo`0dooooo`;o00003?ooool2o`0000?ooooo0_l0000Fooooo`;o0000
0oooool3o`0000cooooo0_l00005ooooo`?o00000_ooool2o`0000Kooooo1?l00002ooooo`;o0000
1_ooool2o`0001Cooooo0_l00004ooooo`;o00001?ooool3o`000003ooooool0003o000000Wo0000
00?oooooo`000?l000002ol0000;ooooo`;o00001?ooool2o`0000Wooooo0_l000000ooooooo0000
o`000006ooooo`;o000000?oooooo`000?l000002oooool2o`0003cooooo000Looooo`03o`000?oo
oooooooo02;ooooo0_l0000Nooooo`;o00000oooool2o`0000Wooooo0_l00004ooooo`;o00004ooo
ool2o`0000;ooooo0_l00002ooooo`?o00000oooool2o`0000?ooooo1_l000000ooooooo0000o`00
0004ooooo`?o00001Oooool2o`00013ooooo1_l00009ooooo`Co000000?oooooo`000?l000001?l0
0002ooooo`go00000_ooool3o`0000[ooooo0_l00004ooooo`;o00001?ooool2o`0000?ooooo1ol0
0006ooooo`;o0000B_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo
0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo02;ooooo0_l0000Looooo`;o0000
1Oooool2o`0000?ooooo1Ol000000ooooooo0000o`000004ooooo`;o00002_ooool2o`0000Kooooo
0ol00002ooooo`;o00000_ooool5o`000003ooooool0003o000000;o000000?oooooo`000?l00000
1?l00008ooooo`;o00005oooool4o`0000_ooooo0_l00002ooooo`?o000000Coooooo`000?l0003o
00000_oooolCo`0000gooooo0ol00005ooooo`;o00001Oooool2o`000003ooooool0003o000000;o
00000oooool4o`0000Kooooo0_l00011ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5oooo
o`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo043ooooo0_l00005oooo
o`Co000000?oooooo`000?l000000ol00007ooooo`;o00002_ooool2o`0000Gooooo1?l000001?oo
oooo0000o`000?ooool7o`000003ooooool0003o000000Ko000000?oooooo`000?l000000_l0000;
ooooo`;o00007oooool2o`0000;ooooo1Ol00007ooooo`ko000000Coooooo`000?l0003o00003Ooo
ool3o`0000_ooooo0_l00004ooooo`;o000000?oooooo`000?l000001?l000000ooooooo0000o`00
0003ooooo`;o0000@Oooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool5
o`0000Kooooo00?o0000ooooooooool0Aoooool4o`000003ooooool0003o000000?ooooo0_l00005
ooooo`;o00004Oooool7o`000003ooooool0003o000000Go000000Coooooo`000?l0003ooooo1Ol0
00000ooooooo0000o`000002o`0000_ooooo0_l0000Gooooo`;o000000?oooooo`000?l000000ooo
ool8o`0000Oooooo5?l00002ooooo`;o00001_ooool2o`0000kooooo0_l00007ooooo`;o00000ooo
ool4o`0004Kooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CoA4A4
omgMgOoooooo00001oooool3o`0004Oooooo0ol00002ooooo`;o00000oooool2o`0000_ooooo0ol0
0006ooooo`_o000000?oooooo`000?l000000_l000000ooooooo0000o`000003o`0000?ooooo0ol0
0005ooooo`;o00001?ooool8o`0000Oooooo0ol0000<ooooo`;o000000?oooooo`000?l000000_oo
ool8o`0000Oooooo5_l000000ooooooo0000o`000003o`0000?ooooo0ol0000Kooooo`;o0000B?oo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?oMgMgoEEEEooooool0
0007ooooo`03o`000?oooooooooo03cooooo0_l0000:ooooo`;o00005?ooool3o`000003ooooool0
003o000000?ooooo9?l00002ooooo`Wo00001oooool3o`0000[ooooo0_l00007ooooo`?o00002ooo
oolMo`0000Cooooo0_l0001Uooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:
ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0;?ooool2o`0000kooooo0_l00004
ooooo`;o00001?ooool2o`0000Kooooo0_l000000ooooooo0000o`00000=ooooo`;o00001?oooolX
o`0000;ooooo0_l00005ooooo`;o00002Oooool2o`0000Cooooo0_l00005ooooo`Go00002oooool9
o`0000;ooooo1_l00002ooooo`So00008oooool2o`0000;ooooo1?l00012ooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0;?oo
ool2o`0000cooooo0_l00006ooooo`;o00002_ooool4o`000003ooooool0003o000000Wooooo0_l0
0007ooooo`?o00000_oooolEo`0000;ooooo0ol00003ooooo`So000000?oooooo`000?l000001Ooo
ool2o`0000Wooooo0_l00004ooooo`;o00001Oooool3o`0000Cooooo0_l00007ooooo`[o000000?o
ooooo`000?l000001Ol000000ooooooo0000o`000004o`0001Kooooo0ol0000<ooooo`;o00000_oo
ool4o`0004;ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool0
1_ooool00ol0003oooooooooo`0jooooo`;o00001_ooool2o`0000[ooooo0ol0000=ooooo`;o0000
1Oooool5o`000003ooooool0003o000000;ooooo5ol00003ooooo`;o00000_ooool4o`0001Wooooo
0_l00008ooooo`;o00000_ooool2o`0000Cooooo5Ol000000ooooooo0000o`000005o`000003oooo
ool0003o000000_ooooo1?l00003ooooo`?o00003oooool2o`0004Gooooo000Looooo`03o`000?oo
oooooooo04;ooooo0_l0000;ooooo`;o00001?ooool2o`0000Oooooo0_l00003ooooo`Co00001?oo
ool6o`000003ooooool0003o000001Ko00001?ooool2o`0000?ooooo0ol0000Iooooo`;o00000ooo
ool2o`0000Cooooo0_l00002oooooa[o000000Coooooo`000?l0003ooooo0_l00008ooooo`;o0000
00?oooooo`000?l000000_l0000Eooooo`;o000000?oooooo`000?l00000@_ooool001cooooo00?o
0000ooooooooool0?_ooool2o`0000;ooooo0_l00004ooooo`;o00002oooool2o`000004ooooool0
003o0000o`0000?ooooo0_l00002ooooo`Co00000oooool6o`000004ooooool0003o0000oooooaOo
00001?ooool2o`0000;ooooo1?l0000Booooo`;o00001Oooool2o`0000Wooooo0_l00004oooooaSo
000000?oooooo`000?l000002oooool2o`0000;ooooo0_l0000Gooooo`Co0000@_ooool001cooooo
00?o0000ooooooooool0?_ooool2o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l00000
2Oooool5o`0000Oooooo1_l000000ooooooo0000o`00000Ro`000005ooooool0003o0000o`000?oo
ool00_l000000ooooooo0000o`00000Aooooo`;o00001?ooool2o`0000Kooooo0_l00008ooooo`;o
000000?oooooo`000?l000005_l0000<ooooo`;o00003oooool2o`0000Wooooo0_l00014ooooo`00
7?ooool00ol0003oooooooooo`1;ooooo`;o00002Oooool2o`0000[ooooo0_l00002ooooo`;o0000
00?oooooo`000?l000008_l00002ooooo`Go000000?oooooo`000?l000001Oooool2o`00013ooooo
0_l00006ooooo`;o00002?oooolNo`0000Wooooo0_l0000?ooooo`;o00002?ooool4o`0000oooooo
0_l0000booooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00002oooool2o`0000Gooooo1?l0
0002ooooo`;o000000?oooooo`000?l000007ol00003ooooo`;o000000?oooooo`000?l000000_l0
0005ooooo`;o000000?oooooo`000?l000004oooool4o`0000Oooooo0_l00002oooooako00000_oo
ool2o`0000[ooooo0_l0000Dooooo`Ko00003Oooool2o`0003;ooooo000Looooo`03o`000?oooooo
oooo03gooooo0_l0000=ooooo`;o00002oooool2o`0000Gooooo0_l00004ooooo`;o00000ooooolN
o`0000;ooooo1?l000000ooooooo0000o`000004o`0000?ooooo0_l00006ooooo`;o00002_ooool8
o`0000Oooooo0_l00002oooooa[o000000?oooooo`000?l000000oooool2o`0000[ooooo0_l0000D
ooooo`;o000000Coooooo`000?l0003o0000@Oooool001cooooo00?o0000ooooooooool0?Oooool2
o`0000[ooooo0_l00007ooooo`?o00001?ooool2o`0000cooooo0_l000001Ooooooo0000o`000?l0
003ooooo01?o000000?oooooo`000?l000002ol00002ooooo`;o000000?oooooo`000?l000000_l0
0009ooooo`;o00000oooool4o`0000?ooooo1?l0000?ooooo`So000000?oooooo`000?l000004_l0
000fooooo`;o000000?oooooo`000?l00000<Oooool001cooooo00?o0000ooooooooool0:?ooool2
o`0001oooooo0_l00002ooooo`;o00000oooool3o`0000Cooooo0_l0000<ooooo`;o000000?ooooo
o`000?l000005Ol000000ooooooo0000o`00000:o`000003ooooool0003o000000;o00000_ooool3
o`0000gooooo1Ol00003ooooo`;o00004Oooool2o`000003ooooool0003o000001So00001_ooool4
o`000003ooooool0003o000000Wooooo0_l00007ooooo`?o00001_ooool4o`0000[ooooo0_l00000
0ooooooo0000o`00000aooooo`007?ooool00ol0003oooooooooo`0Xooooo`;o00003Oooool2o`00
00Wooooo0_l00009ooooo`;o00002?ooool2o`000003ooooool0003o000000?ooooo0ol00004oooo
o`;o00000_oooolLo`000003ooooool0003o000000;o00000oooool5o`0000;ooooo0_l00003oooo
o`;o00000_ooool4o`0000?ooooo0_l00006ooooo`;o00000oooool2o`0000Kooooo0_l00006oooo
oa_o00001_ooool4o`000003ooooool0003o000000Wooooo0_l00007ooooo`?o000000Coooooo`00
0?l0003o00000_ooool4o`00043ooooo000Looooo`03o`000?oooooooooo03Oooooo0_l00003oooo
o`;o00000oooool3o`0000Gooooo1?l0000:ooooo`Go00000oooool5o`0000;ooooo9ol000000ooo
oooo0000o`000003o`0000Oooooo0_l00002ooooo`Co000000?oooooo`000?l000001?ooool2o`00
00;ooooo0ol00002ooooo`;o00001_ooool2o`0000Cooooo5_l00002ooooo`Go00004oooool2o`00
0003ooooool0003o000000_ooooo0ol00016ooooo`007?ooool00ol0003oooooooooo`0fooooo`;o
00000oooool3o`0000?ooooo0_l00002ooooo`;o00000_ooool4o`0000Oooooo0_l00002ooooo`?o
00001oooool2o`0000;ooooo:Ol00002ooooo`;o00002oooool2o`0000?ooooo1?l00002ooooo`;o
00000_ooool3o`0000;ooooo0_l00007ooooo`;o00000oooool4o`000003ooooool0003o0000017o
000000?oooooo`000?l000000_l0000Cooooo`;o000000?oooooo`000?l000002?ooool5o`0001Oo
oooo0_l0000^ooooo`007?ooool2o`0003Oooooo0_l00003ooooo`Co000000?oooooo`000?l00000
0oooool2o`0000gooooo0_l00003ooooo`;o00001_ooool4o`0000;ooooo:?l00007ooooo`;o0000
1_ooool2o`0000Cooooo0ol00002ooooo`?o000000Coooooo`000?l0003o00000_ooool3o`0000Ko
oooo0_l00007oooooaSo00000oooool2o`0001;ooooo0_l00008ooooo`Co00006?ooool2o`0002ko
oooo000Looooo`03o`000?oooooooooo03gooooo0_l000000ooooooo0000o`000008ooooo`;o0000
4?ooool2o`0000?ooooo;Ol00008ooooo`;o00002Oooool2o`000003ooooool0003o000000Cooooo
0_l00007ooooo`;o00003oooool9o`000003ooooool0003o000000_o00001?ooool2o`0001gooooo
0ol0000Aooooo`;o0000=Oooool001cooooo00?o0000ooooooooool0@_ooool2o`0000Kooooo0_l0
0004ooooo`;o00001oooool2o`000004ooooool0003o0000ooooo`;o00001?ooool2o`000003oooo
ool0003o000002?o00005?ooool2o`000003ooooool0003o000000;o00001?ooool3o`0000Cooooo
0_l0000:ooooo`;o00001?ooool8o`000003ooooool0003o000000_o00001_ooool2o`0000;ooooo
1Ol0000Kooooo`;o000000?oooooo`000?l000001_ooool4o`0003Gooooo000Looooo`03o`000?oo
oooooooo02Kooooo0_l00009ooooo`;o00003?ooool2o`000003ooooool0003o000000?o00002Ooo
ool2o`0000Oooooo0_l00004ooooo`;o00000_ooool2o`0000?ooooo4?l00002oooooaCo000000?o
ooooo`000?l000000_l0000Cooooo`;o00001?ooool5o`0000;ooooo0_l00005ooooo`;o00000ooo
ool2o`0000Wooooo3?l000000ooooooo0000o`000002o`0000Kooooo0_l00002ooooo`Oo00001Ooo
ool3o`0000gooooo1_l000000ooooooo0000o`000006ooooo`Co0000=Oooool001cooooo00?o0000
ooooooooool09_ooool2o`0000Wooooo0_l00006ooooo`;o00000oooool3o`0000?ooooo0ol0000L
ooooo`;o00001?oooolDo`000003ooooool0003o000000ko000000?oooooo`000?l000000_l00002
ooooo`?o00001oooool2o`0000Oooooo0_l00002ooooo`;o000000?oooooo`000?l000002Oooool2
o`0000kooooo4Ol00006ooooo`;o00001oooool2o`0000Gooooo0ol00006ooooo`;o00000oooool6
o`0000gooooo0_l0000eooooo`007?ooool00ol0003oooooooooo`0Pooooo`;o00005?ooool2o`00
0003ooooool0003o000000;o000000?oooooo`000?l000000_l0000Aooooo`;o00004?ooool[o`00
0003ooooool0003o000000;ooooo0ol00007ooooo`Co00001Oooool7o`0001cooooo4?l00006oooo
o`;o00005oooool2o`0000?ooooo0_l00004ooooo`;o00000_ooool2o`0000Gooooo0_l0000goooo
o`007?ooool00ol0003oooooooooo`0Pooooo`;o00004Oooool2o`000003ooooool0003o000000?o
oooo0_l00003ooooo`?o00001Oooool2o`0000Wooooo0_l00002ooooo`;o00003?ooool4o`000003
ooooool0003o000002Co00002_ooool2o`0000Gooooo0_l00007ooooo`Oo00000oooool2o`0000_o
oooo0_l0000=ooooo`Ko000000Coooooo`000?l0003ooooo1?l00003ooooo`;o00008_ooool2o`00
00;ooooo0_l00005ooooo`;o0000=oooool001cooooo00?o0000ooooooooool0<Oooool4o`0000Oo
oooo0_l00003ooooo`?o00001?ooool2o`0000?ooooo0_l00008ooooo`Co00002oooool2o`000003
ooooool0003o000000;o00000_ooool:o`000003ooooool0003o000001So00001_ooool2o`000003
ooooool0003o000000kooooo1?l00003ooooo`;o00002oooool2o`0000;ooooo0_l00009ooooo`;o
000000?oooooo`000?l000001Oooool6o`000003ooooool0003o000001?ooooo1?l0000Hooooo`;o
0000=Oooool001cooooo00?o0000ooooooooool0<Oooool3o`0000Oooooo0ol00004ooooo`;o0000
2Oooool2o`0000Wooooo0ol00005ooooo`;o000000Coooooo`000?l0003ooooo;_l00004ooooo`;o
00000oooool3o`0000kooooo0_l00008ooooo`;o00002oooool2o`0000?ooooo0_l00003ooooo`;o
00002_ooool5o`0001Kooooo1?l0000Hooooo`;o0000=Oooool001cooooo00?o0000ooooooooool0
<_ooool2o`0000Gooooo1?l0000Kooooo`;o00001_ooool5o`0000;ooooo0_l00002ooooob?o0000
00Coooooo`000?l0003o00001_ooool2o`0000Cooooo0_l0000;ooooo`;o00000oooool5o`0000?o
oooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000Gooooo0_l00003ooooo`?o
00000oooool4o`000003ooooool0003o000000?o00001?ooool6o`0000Kooooo0_l0001Hooooo`00
7?ooool00ol0003oooooooooo`0iooooo`;o000000?oooooo`000?l000005oooool2o`0000_ooooo
0_l00006ooooo`go000000?oooooo`000?l000005?l00004ooooo`;o00005?ooool2o`000004oooo
ool0003o0000o`0000;ooooo2?l00004ooooo`;o00000_ooool2o`000003ooooool0003o000000Go
oooo0_l00004ooooo`;o00000oooool4o`000003ooooool0003o000000?o00001?ooool6o`0000Ko
oooo1?l0001Fooooo`007?ooool00ol0003oooooooooo`0looooo`;o00005oooool2o`00013ooooo
9ol00004ooooo`;o00005?ooool2o`0000;ooooo0_l00006ooooo`Oo00001oooool2o`0000Sooooo
0_l00009ooooo`;o00000oooool2o`0000?ooooo0ol0000=ooooo`Co00002_ooool2o`0001Sooooo
0_l0000^ooooo`007?ooool00ol0003oooooooooo`1Oooooo`;o00001OoooolNo`000003ooooool0
003o000000Wo00000_ooool2o`00017ooooo0_l0000Aooooo`Go00001Oooool2o`0000Sooooo0_l0
0003ooooo`;o00003_ooool3o`0000oooooo0_l00004ooooo`;o00001?ooool2o`0000Cooooo0_l0
000:ooooo`;o00001Oooool3o`0002kooooo000Looooo`03o`000?oooooooooo05gooooo1?l00004
ooooo`Co00000_oooolLo`000003ooooool0003o000000Ko00000_ooool2o`00017ooooo0_l00003
ooooo`;o00003Oooool6o`0000;ooooo0_l0000:ooooo`Ko00003oooool2o`0000;ooooo0_l00004
ooooo`;o00002oooool2o`0000[ooooo0_l0000:ooooo`;o00001?ooool3o`0002oooooo000Loooo
o`03o`000?oooooooooo03Oooooo0_l0000Hooooo`;o00002Oooool3o`0000?ooooo1ol00002oooo
oaoo00001?ooool2o`00013ooooo0_l00008ooooo`Co00002?ooool2o`000003ooooool0003o0000
00Go000000?oooooo`000?l000002_ooool5o`0000Oooooo0_l0000;ooooo`;o00000oooool3o`00
0003ooooool0003o000000;ooooo0_l0000<ooooo`;o00000_ooool3o`0000oooooo0_l0000`oooo
o`007?ooool00ol0003oooooooooo`0booooo`Co000000?oooooo`000?l000000ol0000Booooo`;o
000000?oooooo`000?l000002Oooool2o`0000Cooooo1?l000001?oooooo0000o`000?ooool4o`00
0003ooooool0003o000001So00000_ooool2o`000003ooooool0003o0000013ooooo0_l0000:oooo
o`Co00001_ooool2o`0000Gooooo0ol0000@ooooo`;o00001oooool4o`0000kooooo0_l00002oooo
o`;o00000_ooool2o`0000cooooo0_l00003ooooo`;o00003_ooool3o`0000Wooooo0_l0000Uoooo
o`007?ooool2o`0003?ooooo1?l00002ooooo`Co00000_ooool2o`0000kooooo1Ol00003ooooo`;o
00002Oooool2o`0000;ooooo2_l00002oooooaWo000000?oooooo`000?l000004oooool2o`0000Wo
oooo0_l000000ooooooo0000o`00000Aooooo`;o00003Oooool3o`0000Sooooo0_l00007ooooo`?o
00000oooool3o`0000Kooooo0_l000000ooooooo0000o`000002ooooo`Co00001?ooool2o`0001;o
oooo0ol00009ooooo`;o00009Oooool001cooooo00?o0000ooooooooool0<Oooool2o`0000_ooooo
0_l000000ooooooo0000o`00000=ooooo`?o00000oooool2o`0000?ooooo0_l00004ooooo`;o0000
0_ooool5o`000003ooooool0003o000001go00001?ooool2o`000003ooooool0003o000001Sooooo
0_l0000?ooooo`;o00000oooool2o`0000kooooo0_l00002ooooo`;o00003Oooool3o`0000;ooooo
0ol00007ooooo`Go00000_ooool4o`0000Cooooo0_l00002ooooo`;o0000@Oooool001cooooo00?o
0000ooooooooool0<Oooool5o`0000_ooooo0_l0000Hooooo`;o00000oooool2o`0000?ooooo1Ol0
00000ooooooo0000o`000002ooooo`oo000000?oooooo`000?l000001_l000000ooooooo0000o`00
0004ooooo`Ko00001_ooool2o`0000Cooooo0_l0000Jooooo`Co000000?oooooo`000?l000001_oo
ool2o`0000[ooooo1?l0000@ooooo`;o00001?ooool2o`0000?ooooo1Ol00009ooooo`;o00000_oo
ool2o`00047ooooo000Looooo`03o`000?oooooooooo03?ooooo0ol00009ooooo`;o00003oooool2
o`0000_ooooo0_l000000ooooooo0000o`000003ooooo`Oo00000_ooool?o`000003ooooool0003o
000000?o00000oooool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000001Oooool3
o`0000Cooooo0_l0000Booooo`;o00002?ooool2o`000003ooooool0003o000000?ooooo0_l00000
0ooooooo0000o`000009ooooo`Go00002?ooool4o`0000[ooooo0_l00004ooooo`Co00002?ooool2
o`0000Cooooo0_l00007ooooo`;o0000=oooool001cooooo00?o0000ooooooooool0:oooool2o`00
00Cooooo1_l00008ooooo`Co00001Oooool2o`0000Kooooo0_l00003ooooo`;o00001_ooool2o`00
00Wooooo5Ol000000ooooooo0000o`000002ooooo`;o00000_ooool3o`000003ooooool0003o0000
00?ooooo1?l00006ooooo`?o00001oooool2o`0000?ooooo0_l0000:ooooo`;o00001Oooool2o`00
00?ooooo0ol00003ooooo`;o00003?ooool2o`0000_ooooo1Ol0000@ooooo`;o00001Oooool2o`00
00;ooooo0_l00004ooooo`;o00001oooool2o`0000Cooooo0_l00003ooooo`;o0000;?ooool001co
oooo00?o0000ooooooooool0:oooool2o`0000Cooooo0_l00002ooooo`;o00001?ooool2o`0000Co
oooo0ol00004ooooo`;o00002oooool4o`0000?ooooo0_l00007ooooo`;o00001Oooool2o`000003
ooooool0003o000000co00001?ooool3o`0000;ooooo1Ol00006ooooo`;o00001oooool2o`0000Oo
oooo0_l000000ooooooo0000o`000002o`0000Oooooo0_l00008ooooo`So00001oooool2o`0000Go
oooo0_l0000Aooooo`Co00001?ooool2o`0000Sooooo1?l00003ooooo`;o00001Oooool2o`0000Co
oooo0_l0000:ooooo`;o00000oooool2o`0002cooooo000Looooo`03o`000?oooooooooo03Gooooo
1?l00002ooooo`?o00001?ooool3o`0000_ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o
oooo1Ol000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000000_ooool=o`0000;o
oooo0ol00003ooooo`?o000000?oooooo`000?l000001?l0000Kooooo`;o00002Oooool2o`000003
ooooool0003o000000Kooooo1Ol00009ooooo`;o00001Oooool3o`0001;ooooo0_l00004ooooo`?o
00002?ooool3o`0000?ooooo0_l00003ooooo`Go00000oooool2o`0000;ooooo0_l0000iooooo`00
7?ooool00ol0003oooooooooo`0gooooo`;o00000oooool2o`0000Cooooo0ol0000;ooooo`;o0000
0_ooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l000000ooooooo
0000o`000002ooooo`Oo000000?oooooo`000?l000000_l00003ooooo`?o000000Goooooo`000?l0
003o0000ooooo`06o`0001gooooo0_l0000<ooooo`;o00001?ooool2o`0000?ooooo0_l000000ooo
oooo0000o`000006ooooo`?o00001Oooool2o`0001Kooooo0_l000000ooooooo0000o`000006oooo
o`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000001oooool2o`00
03Wooooo000Looooo`03o`000?oooooooooo03_ooooo0ol00004ooooo`;o00005?ooool2o`0000?o
oooo0_l0000Pooooo`?o000000?oooooo`000?l000001_ooool2o`0000Cooooo0_l0000Cooooo`;o
00003?ooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool4o`0000;ooooo0_l00003oooo
o`Co00006oooool2o`0000Wooooo0_l00002ooooo`;o00001Oooool2o`0000Gooooo1?l0000noooo
o`007?ooool00ol0003oooooooooo`0kooooo`;o00001Oooool2o`0001Cooooo0_l000001?oooooo
0000o`000?l00003ooooo`;o00004Oooool2o`0000Kooooo0_l00002ooooo`?o00001_ooool4o`00
0004ooooool0003o0000ooooo`;o00008Oooool2o`0000Kooooo1_l00004ooooo`;o00000oooool4
o`0000Oooooo0_l0000Fooooo`;o00002Oooool2o`0000Gooooo0_l00005ooooo`Co00002Oooool2
o`0003?ooooo000Looooo`03o`000?oooooooooo04;ooooo0_l00002ooooo`;o00004oooool3o`00
00?ooooo0_l0000<ooooo`?o00000_ooool2o`000003ooooool0003o000000Go00000_ooool3o`00
0004ooooool0003o0000ooooo`Ko000000?oooooo`000?l000000oooool2o`0000;ooooo0_l00005
ooooo`;o00004oooool2o`0000Gooooo1_l0000@ooooo`;o00001?ooool2o`0001Gooooo0ol00000
0ooooooo0000o`000004ooooo`Co00001oooool2o`0000;ooooo0_l0000<ooooo`Co0000<Oooool0
01cooooo00?o0000ooooooooool0A_ooool2o`0000cooooo0_l00005ooooo`;o00003?ooool2o`00
00Cooooo0ol00005ooooo`Go00000_ooool2o`000004ooooool0003o0000ooooo`;o000000Gooooo
o`000?l0003o0000ooooo`04o`0000Cooooo0_l00002ooooo`;o00001Oooool2o`0000gooooo0_l0
0004ooooo`;o00001Oooool3o`0000kooooo0_l000000ooooooo0000o`000002o`0001_ooooo0_l0
0002ooooo`;o00001?ooool2o`0000Wooooo0_l00002ooooo`;o00003_ooool2o`00037ooooo000L
ooooo`03o`000?oooooooooo02Kooooo0_l00009ooooo`;o00008Oooool2o`0000?ooooo0_l0000>
ooooo`;o00000_ooool2o`0000Gooooo0_l00004ooooo`;o00000_ooool2o`0000gooooo0_l0000?
ooooo`Co00002_ooool3o`0000Wooooo0_l00005ooooo`?o00002Oooool2o`000003ooooool0003o
000002?ooooo0ol0000<ooooo`?o00001oooool2o`0003_ooooo000Looooo`03o`000?oooooooooo
02Kooooo0_l00009ooooo`;o00003Oooool3o`0001Kooooo0_l0000Booooo`;o00001?ooool3o`00
00Cooooo0_l000000ooooooo0000o`000003o`0000;ooooo0_l0000:ooooo`;o000000?oooooo`00
0?l000002oooool2o`0000?ooooo0_l00005ooooo`;o00000_ooool2o`0000Kooooo0_l00005oooo
o`?o00002?ooool2o`0000Oooooo0ol0000>ooooo`;o00003Oooool3o`0000cooooo0ol000000ooo
oooo0000o`000004ooooo`;o00001oooool2o`0003;ooooo000Looooo`03o`000?oooooooooo03;o
oooo0_l00003ooooo`;o00001oooool3o`0001kooooo0_l00008ooooo`;o00001_ooool2o`000004
ooooool0003o0000ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo0_l00004oooo
o`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00000@ooooo`;o00002Oooool2
o`0001Sooooo0_l00007ooooo`?o00002oooool2o`000003ooooool0003o000000_ooooo0_l0000C
ooooo`;o00003Oooool2o`0003;ooooo000Looooo`03o`000?oooooooooo02gooooo0_l00003oooo
o`;o00000oooool2o`0000Kooooo0_l0000Pooooo`;o000000?oooooo`000?l000001Oooool2o`00
00Cooooo0_l000000ooooooo0000o`000005o`0000Gooooo0_l00007ooooo`?o000000?oooooo`00
0?l000003Oooool2o`0000?ooooo0_l0000Wooooo`;o00003Oooool2o`0000Kooooo0_l0000>oooo
o`;o00001Oooool2o`0004oooooo000Looooo`;o0000;_ooool2o`000003ooooool0003o000000go
oooo1?l0000Pooooo`?o00002oooool2o`000003ooooool0003o000000;ooooo1?l0000=ooooo`;o
000000?oooooo`000?l000003_ooool2o`0000?ooooo0_l0000Fooooo`;o00003?ooool2o`0000oo
oooo0ol00007ooooo`;o00005?ooool2o`0000Sooooo1?l0000?ooooo`;o0000<_ooool001cooooo
00?o0000ooooooooool0;_ooool4o`000003ooooool0003o000000_ooooo0ol00005ooooo`;o0000
4Oooool2o`0000Kooooo0_l00002ooooo`;o00003oooool5o`0000Oooooo0_l00006ooooo`;o0000
5Oooool2o`0000Cooooo0_l0000>ooooo`;o00002Oooool2o`000003ooooool0003o000000Cooooo
0ol00007ooooo`Co00001?ooool2o`000003ooooool0003o000001?ooooo0ol00007ooooo`Go0000
3oooool2o`0003;ooooo000Looooo`03o`000?oooooooooo02kooooo0_l00003ooooo`;o00001?oo
ool2o`0000Gooooo0_l000000ooooooo0000o`000003ooooo`;o00004Oooool2o`0000[ooooo0_l0
000?ooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000Sooooo0ol0
00000ooooooo0000o`000006ooooo`;o00001oooool2o`0000Cooooo0_l0000Gooooo`Ko00001Ooo
ool3o`0000Kooooo1_l00002ooooo`?o00000_ooool2o`0000?ooooo0_l0000:ooooo`;o000000?o
ooooo`000?l000002?ooool2o`0004Kooooo000Looooo`03o`000?oooooooooo02Wooooo0_l00002
ooooo`;o00002_ooool2o`0000Sooooo0_l0000Oooooo`Co00006Oooool2o`0000;ooooo0_l00007
ooooo`?o000000?oooooo`000?l000001_ooool2o`0000Cooooo0_l0000=ooooo`;o00004Oooool2
o`000003ooooool0003o000000?o000000Coooooo`000?l0003o00000_ooool2o`0000Cooooo0ol0
00000ooooooo0000o`000004o`0000?ooooo0_l00003ooooo`;o00002_ooool2o`000003ooooool0
003o000001Sooooo0_l0000fooooo`007?ooool00ol0003oooooooooo`0Yooooo`;o00000_ooool2
o`0000cooooo0_l0000<ooooo`;o00005?ooool2o`000003ooooool0003o000000Ko00000oooool2
o`0000oooooo0_l00005ooooo`;o00002?ooool4o`0000Oooooo0_l00004ooooo`;o00001_ooool2
o`0000Gooooo1?l0000Booooo`Go000000Coooooo`000?l0003o00000_ooool2o`0000Gooooo0_l0
0003ooooo`;o00003Oooool2o`0000?ooooo0_l00003ooooo`Co00001?ooool2o`0001;ooooo0_l0
000fooooo`007?ooool00ol0003oooooooooo`0jooooo`?o00001Oooool2o`0000Gooooo0_l0000D
ooooo`;o000000?oooooo`000?l000001?ooool2o`0000?ooooo0_l0000?ooooo`;o00001Oooool4
o`0000;ooooo0_l00004ooooo`;o00001oooool2o`0000[ooooo1?l00003ooooo`Ko00002?ooool2
o`000004ooooool0003o0000o`0000Cooooo2Ol000000ooooooo0000o`000003ooooo`;o00001_oo
ool2o`0000Cooooo0_l00007ooooo`;o00000oooool2o`0000?ooooo1?l000001?oooooo0000o`00
0?ooool2o`0000;ooooo0_l0000Aooooo`;o0000<oooool001cooooo00?o0000ooooooooool0;Ooo
ool2o`0000Kooooo0_l00003ooooo`;o00001_ooool2o`0002Cooooo0_l00002ooooo`;o00000ooo
ool6o`0000Wooooo1?l00003ooooo`Ko00003?ooool2o`0000Wooooo1Ol00004ooooo`Go00001_oo
ool2o`000004ooooool0003o0000ooooo`ko000000?oooooo`000?l000000_l00003ooooo`;o0000
1Oooool3o`000004ooooool0003o0000ooooo`;o00003Oooool2o`0000Oooooo0_l00005ooooo`;o
000000?oooooo`000?l000002oooool2o`000003ooooool0003o000003?ooooo000Looooo`03o`00
0?oooooooooo02Sooooo0_l00003ooooo`;o00001_ooool2o`0000;ooooo0_l000000ooooooo0000
o`00000:ooooo`;o00006?ooool2o`0000Cooooo0_l00002ooooo`;o00000oooool6o`0000Wooooo
1?l00005ooooo`;o00000_ooool2o`0000Sooooo1?l00009ooooo`;o000000?oooooo`000?l00000
1Oooool2o`0000Sooooo0_l00004oooooa?o000000?oooooo`000?l000001oooool6o`000003oooo
ool0003o000000Wooooo0_l000001?oooooo0000o`000?l0000Aooooo`;o00002oooool2o`0003Ko
oooo000Looooo`03o`000?oooooooooo02Sooooo0_l0000?ooooo`;o000000?oooooo`000?l00000
1_ooool2o`0000;ooooo0_l0000Hooooo`;o00007?ooool2o`0000_ooooo0_l00008ooooo`;o0000
0oooool2o`0000gooooo1?l0000?oooooa?o000000?oooooo`000?l000002Oooool2o`0000?ooooo
0ol00008ooooo`;o000000?oooooo`000?l000001Oooool3o`0000Kooooo0_l00002ooooo`;o0000
@oooool001cooooo00?o0000ooooooooool0>_ooool2o`0000Sooooo0_l0000/ooooo`Co00009_oo
ool4o`0000_ooooo1_l00007ooooo`;o00001?ooool=o`000003ooooool0003o000000;o00000_oo
ool2o`0000Wooooo0ol00002ooooo`Ko00002Oooool2o`0000Cooooo0ol00005ooooo`?o0000Aooo
ool001cooooo00?o0000ooooooooool0>_ooool2o`0000Sooooo0_l0000Nooooo`;o00003?ooool4
o`0000;ooooo0_l00008ooooo`;o00002Oooool3o`0000kooooo0_l00005ooooo`;o000000?ooooo
o`000?l000000oooool4o`0000Oooooo0_l000000ooooooo0000o`00000Go`0000Cooooo0_l00004
ooooo`;o000000?oooooo`000?l000001Ol00009ooooo`;o000000Coooooo`000?l0003ooooo1?l0
0004ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0;_ooool4o`000003ooooool0003o
000001Kooooo0_l0000Gooooo`;o00004_ooool2o`0000Sooooo0_l00008ooooo`Co00000_ooool2
o`00017ooooo0_l000000ooooooo0000o`000002ooooo`;o00002ooooolKo`0000Cooooo0_l00007
ooooo`;o000000?oooooo`000?l000000ol0000;ooooo`;o000000?oooooo`000?l000000_l0000;
ooooo`;o00001oooool2o`0003Sooooo000Looooo`03o`000?oooooooooo02kooooo1?l000000ooo
oooo0000o`00000:ooooo`;o00002_ooool2o`0002?ooooo0_l0000Jooooo`;o00001?ooool5o`00
01Gooooo0_l0000;oooooa_o00004Oooool4o`0000Oooooo1?l0000Booooo`;o00001oooool2o`00
03Sooooo000Looooo`03o`000?oooooooooo03Cooooo0_l00005ooooo`?o000000?oooooo`000?l0
00008_ooool2o`0000?ooooo1?l00004ooooo`;o00006?ooool2o`000003ooooool0003o000000;o
oooo0_l000001?oooooo0000o`000?l0000Booooo`;o00004?ooool3o`000003ooooool0003o0000
01Co00004Oooool3o`0000Oooooo1?l0001Eooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5
ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0=?oo
ool2o`0000Gooooo0ol00005ooooo`;o00007_ooool2o`0000?ooooo1_l0000=ooooo`;o00001?oo
ool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00008ooooo`;o0000
1Oooool2o`000003ooooool0003o000000;ooooo0_l00003ooooo`;o00000oooool2o`0000Kooooo
0_l000000ooooooo0000o`00000Bo`000003ooooool0003o0000017ooooo0ol000000ooooooo0000
o`000003o`0000[ooooo0_l0001>ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o
8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0=?ooool2o`00
00gooooo0_l00003ooooo`;o000000?oooooo`000?l000004oooool2o`0000Sooooo1?l0000=oooo
o`;o00001?ooool2o`0000Cooooo0_l000000ooooooo0000o`000004o`0000_ooooo0_l00005oooo
o`;o000000?oooooo`000?l000001oooool2o`0000?ooooo0_l00007oooooaKo000000?oooooo`00
0?l000001oooool2o`0000Cooooo0_l00003ooooo`So00002_ooool3o`0000?ooooo0_l00018oooo
o`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooooooo`0dooooo`?o00002?ooool2o`0000Oooooo0_l000000ooo
oooo0000o`00000Cooooo`;o00002?ooool2o`0000Gooooo0ol00003ooooo`;o00001Oooool2o`00
00[ooooo1_l00005ooooo`;o00005Oooool2o`000003ooooool0003o000000?ooooo0_l00002oooo
o`;o000000?oooooo`000?l000006Ol00006ooooo`?o00000oooool2o`0000;ooooo2?l0000<oooo
o`;o00000oooool2o`0004Sooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wo
oooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000=Oooool2o`0000Kooooo1Ol0000Roooo
o`;o00002oooool3o`0000?ooooo0_l00005ooooo`;o00000_ooool2o`0000Oooooo1?l000000ooo
oooo0000o`000003ooooo`;o00003Oooool2o`0000Kooooo0_l000000ooooooo0000o`000003oooo
o`;o00000_ooool2o`000003ooooool0003o000001Wo00001oooool2o`0000Oooooo0_l00002oooo
o`;o00000_ooool2o`0000Oooooo1Ol0000;ooooo`;o0000@?ooool00003ooooool0003ooooo00;o
oooo00?o0000ooooooooool02Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000oooo
ooooool0?Oooool2o`000004ooooool0003o0000ooooo`;o00007oooool2o`0000?ooooo0_l0000G
ooooo`;o00001oooool4o`000003ooooool0003o000000Cooooo0_l0000:ooooo`Co00001_ooool2
o`000003ooooool0003o000000[ooooo7?l00004ooooo`;o00002?ooool3o`0000Kooooo0_l00007
ooooo`Co00003?ooool4o`0003kooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo
00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`0looooo`;o00001Oooool2o`00
02Cooooo0_l00004ooooo`;o00005?ooool3o`0000?ooooo0_l00009ooooo`;o00002_ooool2o`00
00Kooooo1?l000000ooooooo0000o`00000:ooooo`ko000000?oooooo`000?l000002ol00004oooo
o`;o00002?ooool4o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00001Oooool2o`00
00kooooo0_l0000nooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413o
V9RH00Sooooo00?o0000ooooooooool0??ooool2o`0000Cooooo0_l0000:ooooo`;o00006?ooool2
o`0000Gooooo0_l00003ooooo`Co00003Oooool5o`000003ooooool0003o000000;o00003_ooool2
o`0000Wooooo1Ol00006ooooo`;o00001ooooolIo`0000Gooooo0_l00009ooooo`Go000000Cooooo
o`000?l0003ooooo0_l00002ooooo`;o00002_ooool2o`0004Wooooo00001_ooooook^k^oc8b<_l0
003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`0looooo`;o
00001?ooool2o`0000Wooooo1?l0000?ooooo`;o00001_ooool2o`0000Oooooo0_l000000ooooooo
0000o`000002o`0000Oooooo1Ol000000ooooooo0000o`000003o`000003ooooool0003o000000;o
00001?ooool2o`0000Sooooo0_l00009ooooo`;o00002Oooool2o`0000Oooooo6?l00006ooooo`;o
00002Oooool7o`00017ooooo1?l0000Fooooo`;o0000<?ooool001cooooo00?o0000ooooooooool0
>Oooool2o`0001;ooooo1?l0000?ooooo`;o00002_ooool2o`0000?ooooo0_l0000<ooooo`Ko0000
00?oooooo`000?l000001ol00004ooooo`;o00005oooool2o`0000kooooo6_l0000=oooooa3o0000
2_ooool4o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000Wooooo0_l0000`ooooo`007?oo
ool00ol0003oooooooooo`0iooooo`;o00000oooool3o`0000Oooooo0_l00005ooooo`;o00006ooo
ool2o`0001Gooooo0_l000000ooooooo0000o`000007o`0000Wooooo0_l0000@ooooo`Co000000?o
ooooo`000?l000002ooooolJo`0000gooooo1Ol00004ooooo`Oo00004?ooool2o`0000?ooooo1_l0
000kooooo`007?ooool00ol0003oooooooooo`0nooooo`?o000000?oooooo`000?l000001?ooool2
o`0000Gooooo0_l0000]ooooo`;o00000_oooolAo`000003ooooool0003o000000Co00002_ooool2
o`0000Cooooo0_l00003ooooo`;o00002oooool@o`000003ooooool0003o000000Oo00002?ooool2
o`0000Cooooo1?l0000;ooooo`;o00005Oooool2o`0003gooooo000Looooo`03o`000?oooooooooo
03[ooooo0_l00006ooooo`;o00001?ooool2o`0000Wooooo0_l0000;ooooo`;o00000oooool2o`00
00Sooooo0_l0000=oooooa3o000000?oooooo`000?l000003?l00007ooooo`;o00005_ooool:o`00
0003ooooool0003o000000go000000?oooooo`000?l000001Oooool2o`0000Cooooo1?l00006oooo
o`;o00000_ooool3o`0000Cooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`0jooooo`?o
00002oooool2o`0000Wooooo0_l0000;ooooo`;o00000oooool2o`0000Sooooo0_l00009ooooo`;o
00000_oooolGo`000003ooooool0003o000000Ko00004oooool2o`000003ooooool0003o000000Ko
oooo6?l00002ooooo`Go00001oooool5o`0000Oooooo0_l00002ooooo`Go00000_ooool2o`0001Wo
oooo0_l0000cooooo`007?ooool00ol0003oooooooooo`0kooooo`;o000000?oooooo`000?l00000
4Oooool2o`00013ooooo0_l00002ooooo`;o00002_ooool2o`0000Gooooo0_l00002ooooo`;o0000
00?oooooo`000?l000000ol000000ooooooo0000o`00000?o`0000Cooooo0_l0000:ooooo`;o0000
1Oooool4o`000003ooooool0003o000000Kooooo5ol00003ooooo`;o000000?oooooo`000?l00000
1oooool4o`0000Sooooo0_l00003ooooo`Co00007Oooool2o`0003?ooooo000Looooo`03o`000?oo
oooooooo03Kooooo0_l00006ooooo`;o00004Oooool3o`0000kooooo1ol00009ooooo`?o00000_oo
ool2o`0000;ooooo0_l00004oooooaco00000_ooool2o`0000Kooooo0ol00005ooooo`;o00003ooo
ool@o`000004ooooool0003o0000ooooo`;o00000_ooool3o`0000?ooooo1Ol000000ooooooo0000
o`000008ooooo`;o000000?oooooo`000?l00000E_ooool001cooooo00?o0000ooooooooool0<Ooo
ool2o`0000?ooooo0_l0000>ooooo`;o00002_ooool4o`0000cooooo0_l000000ooooooo0000o`00
0003ooooo`;o00000oooool2o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o00001Ooo
oolKo`0000;ooooo0_l00006ooooo`?o00004_ooool2o`0000Cooooo0_l000001Ooooooo0000o`00
0?l0003ooooo00;o00000_ooool3o`0000Cooooo0_l00002ooooo`;o00001?ooool5o`000003oooo
ool0003o000000;ooooo0_l00007ooooo`;o00000oooool2o`00057ooooo000Looooo`03o`000?oo
oooooooo037ooooo0_l00005ooooo`;o00001_ooool2o`0000Cooooo0ol0000;ooooo`;o00005?oo
ool4o`000003ooooool0003o000000Cooooo0_l00006ooooo`ko00000_ooool9o`0000Cooooo0_l0
0009ooooo`;o000000?oooooo`000?l000000_ooool2o`0000gooooo0ol00007ooooo`?o000000Co
ooooo`000?l0003o00004?ooool4o`0000Sooooo0_l00004ooooo`;o000000?oooooo`000?l00000
1Ol0000Hooooo`;o0000=oooool001cooooo00?o0000ooooooooool0>?ooool2o`0000Kooooo0_l0
0002ooooo`;o000000?oooooo`000?l000002oooool2o`0000oooooo0_l00003ooooo`Co00001ooo
ool2o`0000;ooooo0_l000000ooooooo0000o`00000Io`0000?ooooo0ol00008ooooo`;o000000?o
ooooo`000?l000001Ol00007ooooo`;o00000oooool4o`0000_ooooo0_l00006ooooo`;o00001ooo
ool4o`0000oooooo0_l00003ooooo`?o00006_ooool2o`0003Oooooo000Looooo`03o`000?oooooo
oooo04?ooooo0ol00005ooooo`;o00001oooool2o`0000oooooo0_l0000>ooooo`;o00000_oooolP
o`0000;ooooo0_l00007ooooo`;o00000_ooool4o`000003ooooool0003o000000Oooooo0ol00000
1?oooooo0000o`000?ooool2o`000003ooooool0003o000000Sooooo0_l00006ooooo`;o00001Ooo
ool5o`0000Kooooo0_l00002ooooo`?o00003_ooool2o`0000Cooooo0_l00018ooooo`007?ooool2
o`0004Cooooo0_l00006ooooo`;o0000:Oooool2o`0000?ooooo7_l00003ooooo`;o00001_ooool2
o`0000;ooooo0_l0000=ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00
0007ooooo`?o00003Oooool5o`0000Kooooo0_l00002ooooo`?o00002_ooool2o`0000;ooooo0_l0
0004ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0H?ooool2o`0001Cooooo1Ol00004
oooooa?o000000?oooooo`000?l000001?l00003ooooo`;o00002Oooool2o`0001Cooooo0_l00002
ooooo`;o00001_ooool2o`0000Wooooo0_l0000:ooooo`Co00004Oooool2o`0000Gooooo0_l00003
ooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0>_ooool2o`0000cooooo0_l0000?oooo
o`;o00001Oooool2o`0000kooooo0_l00005ooooo`Co00000_oooolLo`0000?ooooo0_l000001?oo
oooo0000o`000?ooool2o`0000?ooooo0_l00007ooooo`;o00001oooool2o`0000Kooooo0_l0000<
ooooo`;o00000oooool2o`0000[ooooo1?l0000Hooooo`;o00000oooool2o`0004Kooooo000Loooo
o`03o`000?oooooooooo03Oooooo0_l000000ooooooo0000o`000002ooooo`;o00002?ooool2o`00
00oooooo0_l0000@ooooo`;o00000oooool3o`0000Cooooo0_l000000ooooooo0000o`00000Ko`00
00Sooooo0_l000000ooooooo0000o`000009ooooo`;o000000?oooooo`000?l000001oooool3o`00
00kooooo0_l00003ooooo`;o00002oooool2o`0000oooooo0_l00009ooooo`Co0000COooool001co
oooo00?o0000ooooooooool0=oooool2o`0000Gooooo0_l00006ooooo`;o00001_ooool4o`0001Co
oooo0_l00003ooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`00
0?l000001_l000000ooooooo0000o`00000Bo`0000;ooooo0_l0000=ooooo`;o00000oooool2o`00
00Cooooo0_l00005ooooo`;o00000_ooool2o`0000[ooooo0_l00002ooooo`?o00002oooool2o`00
00Cooooo0_l00002ooooo`;o00001Oooool2o`0000;ooooo0_l00005ooooo`Co0000COooool001co
oooo00?o0000ooooooooool0A?ooool4o`0000Kooooo1?l0000Cooooo`?o00003?ooool2o`0000;o
oooo3ol000001Ooooooo0000o`000?l0003ooooo00co000000?oooooo`000?l000003Oooool2o`00
00Wooooo0_l00007ooooo`Co00000oooool2o`0000Wooooo0_l00009ooooo`;o00001oooool2o`00
00;ooooo0_l00009ooooo`;o00001?ooool2o`00053ooooo000Looooo`03o`000?oooooooooo043o
oooo0_l00002ooooo`;o00007oooool4o`0000oooooo8?l0000Jooooo`;o00002?ooool2o`0000Go
oooo0_l0000>ooooo`;o00000_ooool5o`0000gooooo0ol0000;ooooo`?o0000Coooool001cooooo
00?o0000ooooooooool0@?ooool4o`0000Oooooo0_l0000=ooooo`;o00002oooool4o`0000kooooo
0_l00003oooooaco00002Oooool2o`0000?ooooo0_l00008ooooo`;o00002_ooool2o`000004oooo
ool0003o0000o`0000;ooooo0_l00008ooooo`;o000000?oooooo`000?l000000_ooool2o`000005
ooooool0003o0000o`000?ooool01?l00004ooooo`;o000000Coooooo`000?l0003o00003?ooool2
o`0004oooooo000Looooo`03o`000?oooooooooo04;ooooo0ol000001?oooooo0000o`000?ooool4
o`0000gooooo0_l00007ooooo`;o00001?ooool2o`0000Gooooo1?l00009oooooaOo000000?ooooo
o`000?l000000ol00009ooooo`;o00000oooool2o`0000?ooooo0_l00009ooooo`?o000000?ooooo
o`000?l000000_l000001?oooooo0000o`000?l00002ooooo`;o00001Oooool2o`000003ooooool0
003o000000Wooooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l000001?oooooo0000o`00
0?l0000=ooooo`?o0000COooool001cooooo00?o0000ooooooooool0@_ooool3o`000004ooooool0
003o0000ooooo`;o00003Oooool2o`0000Wooooo0_l00003ooooo`;o00001_ooool4o`0000;ooooo
0_l00003oooooago00005?ooool3o`0000Wooooo1_l0000?ooooo`;o00002oooool3o`0001Cooooo
0_l00006ooooo`?o0000COooool001cooooo00?o0000ooooooooool0@_ooool3o`0000;ooooo0_l0
0007ooooo`;o00001_ooool2o`0000kooooo0_l00007ooooo`;o00000oooool2o`0000?ooooo2_l0
00000ooooooo0000o`00000>o`0000;ooooo0_l00004ooooo`;o00001?ooool6o`0000;ooooo0_l0
0005ooooo`;o00000oooool4o`0000oooooo0_l0000=ooooo`;o00000_ooool2o`00017ooooo0_l0
0006ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0@oooool2o`0000;ooooo0ol00006
ooooo`;o00001_ooool2o`0000Gooooo0_l00006ooooo`;o00002?ooool2o`0000Wooooo6_l00002
ooooo`;o00001?ooool2o`0000Cooooo1_l00009ooooo`?o00002Oooool2o`0000[ooooo0_l00007
ooooo`;o00002?ooool2o`0000Wooooo0_l0001Nooooo`007?ooool00ol0003oooooooooo`18oooo
o`;o00004Oooool2o`0000;ooooo0_l00002ooooo`;o00000_ooool2o`0000Kooooo0_l0000=oooo
oaKo00002oooool2o`0000;ooooo0_l00003ooooo`;o00002_ooool3o`000004ooooool0003o0000
ooooo`;o00000_ooool2o`00013ooooo0_l000000ooooooo0000o`00000Cooooo`;o0000G_ooool0
01cooooo00?o0000ooooooooool0D?ooool2o`0000Wooooo0_l00006ooooo`;o00002_ooool2o`00
00_ooooo0_l000000ooooooo0000o`00000Co`0000_ooooo0_l00002ooooo`;o00000oooool2o`00
00_ooooo0_l000001?oooooo0000o`000?ooool2o`0001Cooooo0_l00002ooooo`;o00001oooool2
o`0006Wooooo000Looooo`03o`000?oooooooooo04Oooooo0_l00007ooooo`;o00008_ooool2o`00
00Kooooo0_l000000ooooooo0000o`00000Co`000004ooooool0003o0000o`0000_ooooo0_l0000Q
ooooo`;o00003Oooool2o`0000?ooooo0ol000000ooooooo0000o`000007ooooo`;o00001oooool2
o`0005Oooooo000Looooo`03o`000?oooooooooo04Oooooo0ol00005ooooo`?o00005?ooool2o`00
00Sooooo0_l00002ooooo`;o00001_oooolHo`000004ooooool0003o0000o`0000Kooooo1?l00000
0ooooooo0000o`000009ooooo`;o00005_ooool2o`0000gooooo0_l00002ooooo`Co00002_ooool2
o`0000Oooooo0_l0001Gooooo`007?ooool2o`0004Wooooo0_l00005ooooo`?o00000oooool2o`00
0003ooooool0003o000000cooooo0_l00008ooooo`Co00000oooool2o`000003ooooool0003o0000
00Oo000000?oooooo`000?l000001?l000000ooooooo0000o`000007o`000003ooooool0003o0000
00?ooooo0ol000000ooooooo0000o`000002o`0000Cooooo0_l00006ooooo`;o00006oooool2o`00
00Sooooo0_l00002ooooo`Co0000K?ooool001cooooo00?o0000ooooooooool0C?ooool2o`0000Oo
oooo0_l000001?oooooo0000o`000?l0000Gooooo`;o00000oooool;o`000003ooooool0003o0000
00Go000000?oooooo`000?l000001_l000001?oooooo0000o`000?l00003ooooo`?o00001_ooool2
o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o00006_ooool2o`000003ooooool0003o
000000?ooooo0_l00006ooooo`;o00002_ooool3o`0000kooooo0_l0001?ooooo`007?ooool00ol0
003oooooooooo`1<ooooo`;o00002oooool2o`0000cooooo1?l0000>ooooo`;o00000_ooool3o`00
00;ooooo2_l000001Ooooooo0000o`000?l0003ooooo00;o000000Coooooo`000?l0003o00000ooo
ool2o`0000Cooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o000000Coooooo`000?l0003o
00000_ooool4o`0000kooooo0_l0000;ooooo`;o00000oooool2o`0001;ooooo0ol0000;ooooo`;o
000000?oooooo`000?l00000Coooool001cooooo00?o0000ooooooooool0FOooool2o`0000?ooooo
0_l00007ooooo`Co00001Oooool2o`0000?ooooo0ol00006ooooo`;o000000?oooooo`000?l00000
2Ol00002ooooo`;o000000Coooooo`000?l0003o00001_ooool2o`0000Cooooo0_l00002ooooo`;o
000000Coooooo`000?l0003ooooo0_l00002ooooo`;o000000?oooooo`000?l000003Oooool3o`00
013ooooo0_l0000?ooooo`?o00001?ooool2o`0000;ooooo0_l00002ooooo`Co00002oooool2o`00
04Gooooo000Looooo`03o`000?oooooooooo053ooooo0ol0000;ooooo`;o000000?oooooo`000?l0
00003Oooool2o`0000?ooooo0ol00009ooooo`?o000000?oooooo`000?l000001?l00007ooooo`?o
00002Oooool4o`0000Sooooo0ol000000ooooooo0000o`00000>ooooo`Ko00002oooool2o`0000;o
oooo0_l00003ooooo`;o00001_ooool3o`000004ooooool0003o0000o`0000Cooooo0_l00002oooo
o`;o00000_ooool2o`0000gooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o
000000Coooooo`000?l0003o00002?ooool2o`0000;ooooo1?l0000@ooooo`;o00000_ooool2o`00
00Gooooo1_l000000ooooooo0000o`000006o`0000Kooooo0_l00006ooooo`Oo00001_ooool2o`00
0003ooooool0003o0000017ooooo0_l00002ooooo`;o00002oooool2o`0000Oooooo0_l00002oooo
o`;o00000_ooool3o`0000Sooooo0ol000000ooooooo0000o`00001Hooooo`007?ooool00ol0003o
ooooooooo`15ooooo`;o00001_ooool2o`0000Sooooo0_l00002ooooo`;o00000_ooool2o`0000?o
oooo0_l0000=ooooo`;o00000_ooool2o`0000Gooooo1?l00004ooooo`Oo00001Oooool2o`0000;o
oooo0_l00003ooooo`Co000000?oooooo`000?l000001_ooool2o`0001_ooooo0_l0000Eooooo`;o
00003Oooool3o`000003ooooool0003o000005Sooooo000Looooo`03o`000?oooooooooo04Gooooo
0_l00009ooooo`Co00000oooool2o`0000_ooooo0_l0000>ooooo`;o00000_ooool2o`0001Sooooo
0_l00002ooooo`;o00002?ooool2o`0000Oooooo0ol0000Iooooo`;o00005_ooool2o`0000Kooooo
0_l0001Rooooo`007?ooool00ol0003oooooooooo`18ooooo`;o00001Oooool5o`0000Cooooo0_l0
000:ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o00000oooool2o`0000;ooooo0_l0
0009ooooo`;o00002oooool2o`0000Kooooo0_l0000?ooooo`?o00004Oooool2o`0000Kooooo0_l0
0006ooooo`;o00001oooool2o`0000Gooooo1?l00003ooooo`?o000000?oooooo`000?l000005_oo
ool2o`0004Oooooo000Looooo`03o`000?oooooooooo04Sooooo0_l00005ooooo`Co00001Oooool3
o`0000cooooo1?l00004ooooo`;o00003?ooool2o`0000Cooooo0_l00009ooooo`Co00001Oooool3
o`0000Sooooo0_l00005ooooo`?o00003Oooool2o`0000;ooooo0_l0000>ooooo`;o00001oooool2
o`0000Kooooo0ol00003ooooo`;o000000Coooooo`000?l0003o00004_ooool2o`0000;ooooo0_l0
0017ooooo`007?ooool00ol0003oooooooooo`1Hooooo`?o00008_ooool2o`0000Cooooo0_l00000
0ooooooo0000o`000006ooooo`;o00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000006
ooooo`;o00001Oooool3o`0000Cooooo0_l00007ooooo`;o00000_ooool4o`00013ooooo0_l00002
ooooo`;o00004?ooool4o`00017ooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`1Hoooo
o`;o00005oooool2o`00013ooooo0_l000000ooooooo0000o`00000;ooooo`;o00000_ooool2o`00
0004ooooool0003o0000ooooo`;o00003_ooool2o`000003ooooool0003o000000;o00000oooool2
o`0000Kooooo0_l0000@ooooo`;o00000_ooool2o`0000oooooo1Ol0001Nooooo`007?ooool00ol0
003oooooooooo`1Eooooo`;o000000?oooooo`000?l000002Oooool2o`0000Sooooo0_l00002oooo
o`;o00003oooool2o`0001Cooooo0_l00003ooooo`;o00002?ooool2o`0000Cooooo0_l00003oooo
o`;o00000oooool3o`0000Kooooo0_l0000@ooooo`;o00001?ooool2o`0000Cooooo0_l00006oooo
o`?o0000H?ooool001cooooo00?o0000ooooooooool0EOooool2o`000003ooooool0003o000000Go
oooo0_l00002ooooo`;o000000?oooooo`000?l000001Oooool2o`0001?ooooo0_l000000ooooooo
0000o`00000=ooooo`;o00000_ooool2o`0000?ooooo0_l00008ooooo`;o00000oooool2o`0000Co
oooo0_l00004ooooo`;o00001_ooool3o`0000Gooooo0_l00008ooooo`;o00000oooool3o`0000Co
oooo0_l00006ooooo`;o0000HOooool001cooooo00?o0000ooooooooool0C_ooool2o`0000Cooooo
0_l00009ooooo`;o00001Oooool2o`0000Sooooo1?l00004ooooo`;o00002Oooool4o`0000;ooooo
0_l00009ooooo`;o00002?ooool5o`0000Wooooo0_l00004ooooo`;o000000Coooooo`000?l0003o
oooo0_l00003ooooo`;o00000_ooool2o`0000Gooooo0_l00008ooooo`;o00000_ooool3o`0000go
oooo0_l0001Qooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o00001?ooool2o`0000Oooooo
0_l00006ooooo`;o000000?oooooo`000?l000001_ooool4o`0000Cooooo0_l00009ooooo`;o0000
1?ooool2o`000003ooooool0003o000000?ooooo0_l0000;ooooo`Go00000oooool2o`0000Wooooo
0ol000000ooooooo0000o`000002ooooo`;o00000_ooool4o`0001?ooooo1?l00008ooooo`;o0000
Ioooool001cooooo0_l0001Fooooo`;o00001_ooool2o`0000Kooooo0_l000000ooooooo0000o`00
0003ooooo`;o00004oooool4o`0000Kooooo0ol00002ooooo`?o00001oooool2o`0000Wooooo0_l0
00000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Cooooo0_l0
000;ooooo`;o00001_ooool4o`0000Sooooo0_l000000ooooooo0000o`00001Tooooo`007?ooool0
0ol0003oooooooooo`1Eooooo`;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000009
ooooo`;o00004oooool4o`0000Oooooo0_l00003ooooo`;o00001oooool2o`0000?ooooo0_l00007
ooooo`Oo00003Oooool4o`0000_ooooo0_l00002ooooo`;o00001?ooool2o`0000_ooooo0_l0000?
ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0E_ooool2o`0000?ooooo0_l00002oooo
o`;o000000?oooooo`000?l000003Oooool2o`0000Oooooo0_l00003ooooo`;o00007oooool2o`00
00Wooooo1?l00003ooooo`;o00000_ooool2o`0000Cooooo1Ol0000;ooooo`?o000000?oooooo`00
0?l000001Oooool2o`0000Kooooo0ol0000Aooooo`?o0000Doooool001cooooo00?o0000oooooooo
ool0E_ooool2o`0000Oooooo0_l000001?oooooo0000o`000?ooool2o`0000[ooooo0_l00007oooo
o`;o00000oooool2o`0001kooooo0_l000000ooooooo0000o`000002ooooo`;o00002_ooool2o`00
00;ooooo0_l00004ooooo`;o000000?oooooo`000?l000003?ooool2o`0000Sooooo0_l00006oooo
o`?o00004Oooool2o`0005Cooooo000Looooo`03o`000?oooooooooo05oooooo0_l000001?oooooo
0000o`000?ooool2o`00027ooooo1?l0000<ooooo`Ko000000Coooooo`000?l0003ooooo0_l00002
ooooo`;o00003?ooool2o`0000Cooooo0_l00003ooooo`;o0000R?ooool001cooooo00?o0000oooo
ooooool0Foooool4o`0000?ooooo1Ol00002ooooo`?o00001?ooool2o`00013ooooo0_l00004oooo
o`Co00001Oooool2o`0000Gooooo1_l00007ooooo`Co000000?oooooo`000?l000002?ooool2o`00
00Cooooo0ol00008ooooo`;o00004Oooool2o`0000Oooooo0_l0001Vooooo`007?ooool00ol0003o
ooooooooo`1Iooooo`Ko00001Oooool3o`0000;ooooo0ol00004ooooo`Ko00003?ooool2o`0000go
oooo0_l0000Booooo`Co000000?oooooo`000?l000001?ooool2o`0000Wooooo0_l00005ooooo`;o
000000?oooooo`000?l000001?ooool4o`0000Wooooo0_l00007ooooo`;o00002Oooool2o`0005_o
oooo000Looooo`03o`000?oooooooooo05Wooooo0_l0000>ooooo`;o00001oooool4o`0000_ooooo
0_l00006ooooo`;o00007Oooool2o`0000Kooooo0_l0000@ooooo`;o00001oooool4o`0001Oooooo
0_l00004ooooo`;o0000Foooool001cooooo00?o0000ooooooooool0I?ooool2o`0000?ooooo0_l0
0007ooooo`;o00001_ooool2o`0000?ooooo1?l000000ooooooo0000o`000003ooooo`;o00007Ooo
ool3o`0000?ooooo0_l0000fooooo`;o0000HOooool001cooooo00?o0000ooooooooool0I?ooool2
o`0000Sooooo0_l0000:ooooo`;o00000oooool2o`0000?ooooo0_l0000;ooooo`;o00003_ooool2
o`0000Cooooo1?l00003ooooo`;o00002?ooool2o`0000_ooooo0_l0000;ooooo`;o000000?ooooo
o`000?l000005_ooool2o`0005[ooooo000Looooo`03o`000?oooooooooo06[ooooo0ol000000ooo
oooo0000o`000008ooooo`;o00005oooool2o`0000kooooo0_l00002ooooo`Co00003oooool3o`00
00Kooooo0_l00002ooooo`;o00002?ooool2o`000003ooooool0003o000000?o00000_ooool2o`00
01;ooooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`1Xooooo`Go00002oooool2o`0001?o
oooo0_l0000>ooooo`;o00001_ooool3o`00017ooooo0_l00005ooooo`?o00003?ooool2o`0000?o
oooo0_l00003ooooo`;o0000K_ooool001cooooo00?o0000ooooooooool0J?ooool2o`000003oooo
ool0003o000000_ooooo0_l00005ooooo`;o00003?ooool2o`0000kooooo0_l00003ooooo`;o0000
0_ooool2o`0000Kooooo0_l0000@ooooo`;o00002oooool2o`0001Kooooo0_l0001Rooooo`007?oo
ool00ol0003oooooooooo`1Mooooo`;o00003oooool2o`0000Kooooo1?l00005ooooo`?o00002?oo
ool2o`0000oooooo0_l00005ooooo`;o00002Oooool3o`0000Sooooo0_l000000ooooooo0000o`00
000:ooooo`;o00001?ooool2o`0001Kooooo0_l0001Rooooo`0000Koooooonk^k_lb<S;o0000oc8b
<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000oooooooo
ool0GOooool2o`0000oooooo1?l00004ooooo`?o00001oooool3o`0000Oooooo0_l0000>ooooo`?o
00001Oooool4o`0000Oooooo1?l00007ooooo`;o000000?oooooo`000?l000001oooool2o`000003
ooooool0003o000000Cooooo0_l00002ooooo`;o0000M_ooool00006oooooomgMgOoV9RHoooooonH
V9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooo
oooo073ooooo0_l0000?ooooo`?o00005_ooool2o`0000Kooooo1?l00009ooooo`;o00001oooool2
o`0000[ooooo0_l00007ooooo`;o00000_ooool2o`0001Gooooo0_l0001Oooooo`0000?ooooooa0@
4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`1^ooooo`;o00001Oooool2o`0000_ooooo0_l0000Pooooo`?o00002?ooool2
o`0000Oooooo0_l0000Cooooo`Co00005oooool2o`0005oooooo00000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000K_ooool2
o`000003ooooool0003o000000;ooooo0_l00006ooooo`?o000000Coooooo`000?l0003o00000ooo
ool2o`0000Oooooo0_l0000?ooooo`;o00000_ooool2o`0000Kooooo1?l00008ooooo`;o00004_oo
ool4o`0007Sooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Goc<c<
o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo06kooooo1_l00009ooooo`Oo00000ooo
ool3o`0000Kooooo0_l0000?ooooo`;o00000oooool5o`0000;ooooo0_l0000:ooooo`;o00003ooo
ool2o`0001[ooooo0_l0001Qooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09
ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`1Nooooo`;o00000ooo
ool2o`0000[ooooo0_l000000ooooooo0000o`00000:ooooo`?o00001oooool2o`0000Kooooo1?l0
000Booooo`Go00003Oooool2o`000003ooooool0003o000000Kooooo0_l000000ooooooo0000o`00
0002ooooo`?o00006Oooool2o`00067ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo
00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo05kooooo0_l00003ooooo`;o
00003Oooool3o`0001Cooooo0_l00007ooooo`;o00004_ooool2o`00013ooooo0_l000000ooooooo
0000o`000006ooooo`Go000000?oooooo`000?l000001?l0001jooooo`0000Koooooonk^k_lb<S;o
0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`1c
ooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`;o00000_ooool2
o`0001_ooooo0_l0000Mooooo`?o000000?oooooo`000?l000000_ooool2o`0007[ooooo000Loooo
o`03o`000?oooooooooo07Oooooo0ol00003ooooo`;o000000?oooooo`000?l000000oooool2o`00
01Sooooo0_l00002ooooo`;o00001_ooool2o`000003ooooool0003o000000[ooooo0_l00005oooo
o`;o000000?oooooo`000?l000000_l00021ooooo`007?ooool00ol0003oooooooooo`1dooooo`;o
00000_ooool7o`0000Gooooo0_l0000Iooooo`?o000000?oooooo`000?l000001_ooool5o`0000Go
oooo0_l00003ooooo`;o00001Oooool2o`000003ooooool0003o000008?ooooo000Looooo`03o`00
0?oooooooooo07Cooooo1?l00002ooooo`Go00000oooool4o`0000Oooooo0_l00006ooooo`;o0000
0_ooool2o`0000;ooooo0_l000000ooooooo0000o`000006ooooo`;o00000_ooool3o`0000Kooooo
0_l00003ooooo`;o00002?ooool2o`0008?ooooo000Looooo`03o`000?oooooooooo07Kooooo0_l0
0006ooooo`;o00000_ooool6o`0000Gooooo0_l00003ooooo`Go00000_ooool2o`000004ooooool0
003o0000o`0000;ooooo0ol00004ooooo`;o00000oooool3o`0000[ooooo0_l0002=ooooo`007?oo
ool00ol0003oooooooooo`1nooooo`;o00001?ooool4o`0000[ooooo1?l00006ooooo`;o00000ooo
ool3o`0000[ooooo0_l0000^ooooo`Co0000Ioooool001cooooo00?o0000ooooooooool0NOooool2
o`0000;ooooo0_l0000Dooooo`;o00008oooool2o`0002Cooooo1?l0001Wooooo`007?ooool00ol0
003oooooooooo`1iooooo`Ko00005?ooool2o`0000kooooo0_l00004ooooo`;o00002oooool4o`00
0003ooooool0003o000008cooooo000Looooo`03o`000?oooooooooo07Kooooo0_l00003ooooo`?o
00000oooool2o`000003ooooool0003o000000Oooooo0_l00005ooooo`;o00002?ooool2o`0000?o
oooo0_l00004ooooo`;o00002?ooool2o`000004ooooool0003o0000o`0000;ooooo0_l000000ooo
oooo0000o`000029ooooo`007?ooool00ol0003oooooooooo`1fooooo`;o00001?ooool2o`0000?o
oooo0_l000000ooooooo0000o`000003ooooo`;o00000_ooool2o`0000Gooooo0_l00008ooooo`;o
00004oooool6o`0000Gooooo0_l00029ooooo`007?ooool00ol0003oooooooooo`29ooooo`Co0000
1oooool2o`0000Sooooo0_l0000Eooooo`;o0000T_ooool001cooooo00?o0000ooooooooool0Nooo
ool2o`0000gooooo0ol00007ooooo`;o00002?ooool2o`000:Wooooo000Looooo`;o0000NOooool2
o`000003ooooool0003o000002Kooooo0_l0002Tooooo`007?ooool00ol0003oooooooooo`1hoooo
o`;o0000:Oooool2o`000:Cooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0ROooool2o`00
0;kooooo000Looooo`03o`000?oooooooooo08Wooooo0_l0002nooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0<cooooo0_l0001kooooo`007?ooool0
0ol0003oooooooooo`3<ooooo`;o0000Noooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0ZOooool2o`0009kooooo000Looooo`03o`000?oooooo
oooo0:Wooooo0_l0000Fooooo`;o0000Q_ooool001cooooo0_l00026ooooo`;o0000>_ooool2o`00
08Kooooo000Looooo`03o`000?oooooooooo08Gooooo0_l00032ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0Voooool2o`000:cooooo
000Looooo`03o`000?oooooooooo09_ooooo0_l0000@ooooo`;o0000V_ooool001cooooo00?o0000
ooooooooool0[Oooool2o`0009[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Boooo
o`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003ooooo
ooooo`05ooooo`?o0000oooooom:ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000D
ooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBoooo
o`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Booooo`03oeEEEOmVIVKo00000?oooooo
E?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:7ooooo00Co410@o`000?l0
003ooooo0_l000000ol@413oooooooooo`0Fooooo`Co000000So410@ooooooooooook^k^oc8b<_l0
003o<S8bonk^kPGooooo00?o0000onk^k_ooool01Oooool2o`000003oa0@4?oooooooooo08[ooooo
002Rooooo`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?oEEEEojVYZOooool01_ooool00ol0003o
ooooooooo`2;ooooo`00X_ooool01Ol0003ooooooooooooooooo000001_ooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@00Gooooo00?oZJVYoeEEEOooool00oooool5o`00
08cooooo002Rooooo`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o8B4Qooooooooool00_ooool0
1?m4A4CogMgMooooool0002=ooooo`00X_ooool01Ol0003oQhN7oooooonYZJWo000001_ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?oEEEEolc<c?ooool0
0_ooool01?oMgMgoEEEEooooool0002=ooooo`00XOooool00ol@413o0000ogMgM`02o`000003oiRH
V?oooooooooo01Wooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Ko
oooo00?oZJVYogMgMoooool00oooool00omgMgOoc<c<o`00002=ooooo`00`_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Ol@413ooooooooooooooooo<S8b
00Cooooo00?ok^k^odA4A?l00000SOooool00<3ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo1Ol00005ooooo`03ogMgMol0003ooooo08cooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1080) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.44684 .64294 Mdot
.41534 .64207 Mdot
.65636 .47412 Mdot
.40156 .45985 Mdot
.4545 .78871 Mdot
.65265 .4356 Mdot
.59266 .59241 Mdot
.62756 .63722 Mdot
.66151 .45985 Mdot
.49168 .65864 Mdot
.59 .60253 Mdot
.46373 .38449 Mdot
.59779 .61668 Mdot
.38313 .44962 Mdot
.26106 .74535 Mdot
.33764 .41666 Mdot
.37459 .64985 Mdot
.57094 .32359 Mdot
.36153 .48763 Mdot
.64904 .40852 Mdot
.42711 .60316 Mdot
.39575 .45189 Mdot
.43566 .66933 Mdot
.38293 .44904 Mdot
.40338 .47289 Mdot
.3895 .64238 Mdot
.37506 .62395 Mdot
.43849 .44332 Mdot
.38155 .47611 Mdot
.63051 .62557 Mdot
.38786 .2831 Mdot
.32507 .78708 Mdot
.39105 .50692 Mdot
.74099 .67364 Mdot
.6205 .64246 Mdot
.30531 .67358 Mdot
.67206 .43453 Mdot
.62068 .62882 Mdot
.61428 .64258 Mdot
.61047 .58088 Mdot
.60866 .63411 Mdot
.39738 .63837 Mdot
.61434 .66882 Mdot
.53098 .61858 Mdot
.34232 .45672 Mdot
.51323 .75756 Mdot
.2723 .3566 Mdot
.40729 .40458 Mdot
.37761 .64474 Mdot
.60394 .40102 Mdot
.69258 .69257 Mdot
.5889 .59136 Mdot
.66525 .50079 Mdot
.78126 .74618 Mdot
.62332 .61893 Mdot
.34995 .46865 Mdot
.67465 .45913 Mdot
.39935 .44349 Mdot
.38402 .44477 Mdot
.21128 .54578 Mdot
.44468 .43651 Mdot
.53424 .31399 Mdot
.43534 .68388 Mdot
.53894 .39822 Mdot
.6681 .44978 Mdot
.60495 .63975 Mdot
.4213 .6313 Mdot
.60363 .61408 Mdot
.46956 .42775 Mdot
.68814 .43167 Mdot
.4092 .40597 Mdot
.59524 .63043 Mdot
.40257 .61317 Mdot
.41615 .42047 Mdot
.7674 .41224 Mdot
.14726 .52726 Mdot
.52671 .29574 Mdot
.25483 .60746 Mdot
.22065 .59097 Mdot
.64342 .3279 Mdot
.3589 .45158 Mdot
.45021 .20788 Mdot
.19977 .64642 Mdot
.42352 .6799 Mdot
.35936 .5052 Mdot
.58939 .49792 Mdot
.4149 .42539 Mdot
.45662 .737 Mdot
.35024 .4602 Mdot
.81301 .46046 Mdot
.65487 .45729 Mdot
.40792 .66506 Mdot
.3985 .46059 Mdot
.43821 .45832 Mdot
.2753 .3952 Mdot
.42466 .39192 Mdot
.43082 .44842 Mdot
.42133 .61013 Mdot
.58071 .61066 Mdot
.39303 .36416 Mdot
.63151 .66344 Mdot
.65727 .49275 Mdot
.38982 .39443 Mdot
.67811 .42469 Mdot
.40776 .60857 Mdot
.42243 .41716 Mdot
.59926 .64524 Mdot
.37627 .40706 Mdot
.65428 .68667 Mdot
.4185 .64095 Mdot
.43352 .46476 Mdot
.53715 .30467 Mdot
.67509 .24799 Mdot
.4122 .66898 Mdot
.66158 .31285 Mdot
.35227 .44779 Mdot
.42257 .44549 Mdot
.41291 .64333 Mdot
.65601 .48451 Mdot
.43727 .73629 Mdot
.41543 .69113 Mdot
.6097 .57855 Mdot
.42702 .68841 Mdot
.40098 .51222 Mdot
.65652 .4489 Mdot
.70174 .61451 Mdot
.64099 .55164 Mdot
.38825 .26429 Mdot
.41244 .42944 Mdot
.54423 .69683 Mdot
.63254 .43137 Mdot
.40309 .65597 Mdot
.60355 .60989 Mdot
.32192 .41842 Mdot
.43129 .65447 Mdot
.60998 .59767 Mdot
.55527 .30482 Mdot
.72693 .55625 Mdot
.38015 .67524 Mdot
.54193 .64595 Mdot
.58606 .64927 Mdot
.59993 .58367 Mdot
.77369 .64543 Mdot
.41355 .63189 Mdot
.54493 .33539 Mdot
.61665 .60727 Mdot
.35251 .31021 Mdot
.38832 .49075 Mdot
.46926 .23598 Mdot
.39642 .18819 Mdot
.74784 .66239 Mdot
.75899 .51893 Mdot
.53001 .35233 Mdot
.5808 .59384 Mdot
.41497 .47834 Mdot
.38969 .63263 Mdot
.40005 .63007 Mdot
.43434 .4141 Mdot
.40437 .46552 Mdot
.41409 .4094 Mdot
.42862 .47432 Mdot
.1897 .54252 Mdot
.36724 .40811 Mdot
.32261 .25181 Mdot
.40589 .67063 Mdot
.41854 .46549 Mdot
.67718 .47246 Mdot
.45391 .46071 Mdot
.60495 .63524 Mdot
.40444 .44908 Mdot
.40588 .46027 Mdot
.44623 .44253 Mdot
.58669 .59379 Mdot
.31231 .76197 Mdot
.46653 .17806 Mdot
.3804 .78592 Mdot
.73702 .38051 Mdot
.64419 .4231 Mdot
.41972 .43206 Mdot
.52797 .32537 Mdot
.31208 .64261 Mdot
.36193 .44512 Mdot
.73826 .24352 Mdot
.42243 .45339 Mdot
.41179 .77799 Mdot
.40863 .52621 Mdot
.4029 .80542 Mdot
.45237 .22142 Mdot
.41358 .48274 Mdot
.30388 .38524 Mdot
.36783 .59922 Mdot
.54049 .62723 Mdot
.60776 .63191 Mdot
.6728 .47662 Mdot
.66652 .46891 Mdot
.62891 .57233 Mdot
.46734 .64037 Mdot
.31264 .45399 Mdot
.44475 .39561 Mdot
.68202 .48436 Mdot
.44768 .67174 Mdot
.55494 .34184 Mdot
.42893 .61855 Mdot
.14173 .41517 Mdot
.68634 .68009 Mdot
.64583 .58641 Mdot
.5366 .29578 Mdot
.64218 .46621 Mdot
.66342 .49569 Mdot
.52464 .33287 Mdot
.38467 .41229 Mdot
.41669 .62862 Mdot
.71088 .73348 Mdot
.46452 .61302 Mdot
.75415 .69737 Mdot
.40068 .61721 Mdot
.50751 .63956 Mdot
.60234 .59955 Mdot
.66604 .42427 Mdot
.42574 .44544 Mdot
.39043 .41985 Mdot
.42203 .59803 Mdot
.41013 .40918 Mdot
.32186 .50199 Mdot
.43296 .43839 Mdot
.70902 .64782 Mdot
.52358 .29722 Mdot
.62888 .57256 Mdot
.3787 .26055 Mdot
.44064 .64734 Mdot
.55618 .25 Mdot
.68749 .45015 Mdot
.29681 .64325 Mdot
.59068 .62699 Mdot
.54616 .3051 Mdot
.68872 .45199 Mdot
.55349 .34452 Mdot
.43144 .48625 Mdot
.62227 .45266 Mdot
.52662 .31077 Mdot
.25467 .67246 Mdot
.39714 .4906 Mdot
.18453 .53743 Mdot
.57652 .60641 Mdot
.40981 .69229 Mdot
.44421 .43696 Mdot
.65759 .41574 Mdot
.38459 .50763 Mdot
.7535 .4832 Mdot
.70233 .61725 Mdot
.62601 .47089 Mdot
.65338 .37478 Mdot
.54931 .30983 Mdot
.72239 .49836 Mdot
.55357 .68509 Mdot
.38129 .63535 Mdot
.379 .39541 Mdot
.38134 .81376 Mdot
.61618 .60735 Mdot
.37578 .41424 Mdot
.72463 .62778 Mdot
.61642 .61135 Mdot
.40005 .44162 Mdot
.5773 .6334 Mdot
.40229 .62812 Mdot
.58334 .22124 Mdot
.37513 .64722 Mdot
.35059 .45769 Mdot
.59192 .64179 Mdot
.63687 .477 Mdot
.3856 .64784 Mdot
.38559 .40472 Mdot
.43041 .42762 Mdot
.5555 .48498 Mdot
.42422 .46546 Mdot
.34655 .77187 Mdot
.43487 .4572 Mdot
.67293 .47069 Mdot
.43196 .39854 Mdot
.82051 .39105 Mdot
.65258 .54733 Mdot
.42053 .63055 Mdot
.61872 .45354 Mdot
.66379 .46271 Mdot
.62012 .27076 Mdot
.69494 .49663 Mdot
.35311 .4393 Mdot
.64953 .41792 Mdot
.52665 .24443 Mdot
.62732 .60505 Mdot
.39453 .38827 Mdot
.52289 .61719 Mdot
.60199 .3991 Mdot
.67659 .49108 Mdot
.32428 .43675 Mdot
.38503 .61806 Mdot
.39914 .46139 Mdot
.6675 .49057 Mdot
.45767 .64527 Mdot
.34651 .43974 Mdot
.43918 .55589 Mdot
.55504 .48558 Mdot
.60828 .59206 Mdot
.38145 .52416 Mdot
.38732 .39899 Mdot
.67552 .42847 Mdot
.43161 .6291 Mdot
.63337 .6323 Mdot
.39222 .64837 Mdot
.55312 .8101 Mdot
.65735 .67847 Mdot
.21761 .61592 Mdot
.55071 .35928 Mdot
.78406 .49579 Mdot
.4408 .82215 Mdot
.75445 .35252 Mdot
.46992 .29165 Mdot
.61386 .8063 Mdot
.67287 .48272 Mdot
.73725 .62318 Mdot
.66664 .46417 Mdot
.38158 .46886 Mdot
.66022 .4457 Mdot
.43183 .82271 Mdot
.43332 .44073 Mdot
.66271 .4392 Mdot
.59356 .2434 Mdot
.4123 .46373 Mdot
.41569 .66935 Mdot
.24793 .71876 Mdot
.77193 .35429 Mdot
.72226 .66639 Mdot
.62433 .44193 Mdot
.43851 .32334 Mdot
.43252 .45073 Mdot
.44771 .41391 Mdot
.37973 .65763 Mdot
.41361 .38666 Mdot
.55029 .34533 Mdot
.54129 .2942 Mdot
.50645 .47627 Mdot
.48935 .19172 Mdot
.43706 .37869 Mdot
.38367 .6499 Mdot
.20526 .47836 Mdot
.77291 .42212 Mdot
.73868 .4075 Mdot
.57259 .59711 Mdot
.29301 .74028 Mdot
.38695 .54789 Mdot
.64879 .66522 Mdot
.53438 .60364 Mdot
.41567 .65718 Mdot
.32653 .77294 Mdot
.61143 .63028 Mdot
.2723 .47295 Mdot
.35071 .34077 Mdot
.38459 .41711 Mdot
.58581 .61548 Mdot
.46099 .39049 Mdot
.80436 .39263 Mdot
.25207 .35978 Mdot
.36405 .23275 Mdot
.34307 .44345 Mdot
.75963 .40269 Mdot
.41336 .44919 Mdot
.41426 .74183 Mdot
.43634 .45463 Mdot
.39035 .65621 Mdot
.46693 .69995 Mdot
.53016 .47018 Mdot
.42182 .19051 Mdot
.67844 .68337 Mdot
.53098 .35237 Mdot
.42833 .43871 Mdot
.3838 .41812 Mdot
.55768 .32755 Mdot
.41503 .67952 Mdot
.42722 .47633 Mdot
.52989 .25837 Mdot
.40816 .41775 Mdot
.61465 .63516 Mdot
.33408 .26387 Mdot
.37009 .62329 Mdot
.41208 .38131 Mdot
.45353 .65167 Mdot
.61205 .59191 Mdot
.61918 .64064 Mdot
.34345 .39905 Mdot
.63148 .58983 Mdot
.41409 .45552 Mdot
.25549 .32414 Mdot
.39936 .68227 Mdot
.36603 .52615 Mdot
.43476 .66657 Mdot
.25419 .616 Mdot
.60481 .64853 Mdot
.69938 .64161 Mdot
.38731 .36167 Mdot
.60717 .62834 Mdot
.63913 .69387 Mdot
.42467 .37495 Mdot
.34442 .41414 Mdot
.81569 .49762 Mdot
.62681 .45565 Mdot
.54308 .4716 Mdot
.61847 .64767 Mdot
.39329 .39879 Mdot
.38983 .38506 Mdot
.60951 .58973 Mdot
.25003 .45789 Mdot
.67451 .28287 Mdot
.43605 .44506 Mdot
.39251 .66666 Mdot
.40142 .65456 Mdot
.34219 .42875 Mdot
.37005 .41332 Mdot
.63872 .45007 Mdot
.61815 .44486 Mdot
.62824 .41476 Mdot
.55366 .48472 Mdot
.70345 .64436 Mdot
.55346 .77162 Mdot
.6102 .58105 Mdot
.57018 .71866 Mdot
.80445 .43841 Mdot
.43582 .49184 Mdot
.63222 .4222 Mdot
.37851 .42657 Mdot
.40017 .45736 Mdot
.63452 .63027 Mdot
.72558 .65116 Mdot
.47991 .44366 Mdot
.3955 .68406 Mdot
.62389 .64648 Mdot
.33244 .38187 Mdot
.60994 .7397 Mdot
.53039 .31147 Mdot
.78802 .60539 Mdot
.59616 .63301 Mdot
.41852 .66033 Mdot
.59223 .64553 Mdot
.39357 .41794 Mdot
.3536 .47695 Mdot
.41142 .651 Mdot
.51927 .31472 Mdot
.45311 .44518 Mdot
.40367 .44218 Mdot
.54783 .15208 Mdot
.76779 .39723 Mdot
.6904 .61793 Mdot
.42047 .47832 Mdot
.38181 .38452 Mdot
.56448 .33729 Mdot
.40294 .41717 Mdot
.42995 .41586 Mdot
.61766 .21279 Mdot
.66731 .59852 Mdot
.56682 .30306 Mdot
.27375 .48436 Mdot
.39472 .61991 Mdot
.35929 .80625 Mdot
.66256 .42158 Mdot
.63867 .59094 Mdot
.68131 .27704 Mdot
.65519 .4959 Mdot
.76505 .47805 Mdot
.3489 .8004 Mdot
.54468 .47695 Mdot
.54972 .27718 Mdot
.48061 .41462 Mdot
.43911 .433 Mdot
.41617 .4463 Mdot
.532 .32872 Mdot
.41024 .62896 Mdot
.536 .44378 Mdot
.18138 .4654 Mdot
.40409 .45199 Mdot
.31631 .49227 Mdot
.25927 .6904 Mdot
.59853 .39317 Mdot
.54086 .34794 Mdot
.52214 .30867 Mdot
.42538 .44083 Mdot
.63563 .22999 Mdot
.3887 .64208 Mdot
.38452 .40514 Mdot
.35432 .42333 Mdot
.62359 .44599 Mdot
.42296 .64376 Mdot
.67428 .48297 Mdot
.69492 .64321 Mdot
.40225 .7812 Mdot
.5594 .14844 Mdot
.61402 .64573 Mdot
.32834 .73453 Mdot
.62967 .61421 Mdot
.43591 .21323 Mdot
.66009 .4991 Mdot
.3583 .44577 Mdot
.43537 .63532 Mdot
.38132 .4047 Mdot
.36671 .42432 Mdot
.38345 .4132 Mdot
.46018 .41936 Mdot
.76817 .28398 Mdot
.51932 .3294 Mdot
.39967 .37679 Mdot
.66522 .47332 Mdot
.33092 .74553 Mdot
.16271 .56402 Mdot
.38649 .42534 Mdot
.42798 .42931 Mdot
.42253 .66771 Mdot
.43182 .40602 Mdot
.62683 .60664 Mdot
.42987 .62598 Mdot
.43541 .46321 Mdot
.30968 .74348 Mdot
.39111 .48212 Mdot
.39601 .79566 Mdot
.59602 .64826 Mdot
.61343 .69244 Mdot
.41545 .37664 Mdot
.69816 .61161 Mdot
.54303 .47143 Mdot
.64799 .41432 Mdot
.64246 .63343 Mdot
.67202 .43703 Mdot
.21286 .38845 Mdot
.37922 .49819 Mdot
.41183 .47758 Mdot
.38881 .38659 Mdot
.6469 .42085 Mdot
.45211 .7515 Mdot
.6977 .52392 Mdot
.31894 .40308 Mdot
.63918 .4384 Mdot
.44596 .67093 Mdot
.56851 .38977 Mdot
.43842 .64743 Mdot
.55384 .29186 Mdot
.59047 .60417 Mdot
.51364 .33609 Mdot
.73108 .66862 Mdot
.41703 .6428 Mdot
.41192 .59557 Mdot
.6501 .42589 Mdot
.59333 .53578 Mdot
.71574 .78866 Mdot
.56299 .4231 Mdot
.43688 .2503 Mdot
.38194 .66329 Mdot
.35909 .46359 Mdot
.3963 .22807 Mdot
.57521 .54162 Mdot
.67249 .44062 Mdot
.3688 .45329 Mdot
.6089 .22728 Mdot
.63803 .44911 Mdot
.3907 .38957 Mdot
.64326 .47546 Mdot
.596 .62724 Mdot
.62903 .44185 Mdot
.36965 .66123 Mdot
.42272 .42086 Mdot
.69221 .80345 Mdot
.58696 .32044 Mdot
.43124 .4611 Mdot
.62076 .64823 Mdot
.46328 .53622 Mdot
.36969 .4332 Mdot
.56347 .31614 Mdot
.65285 .44435 Mdot
.56509 .44712 Mdot
.4368 .4472 Mdot
.6435 .42555 Mdot
.44588 .64909 Mdot
.64331 .63234 Mdot
.50757 .4138 Mdot
.70724 .62577 Mdot
.3793 .65291 Mdot
.60469 .67606 Mdot
.63994 .62789 Mdot
.39168 .38164 Mdot
.36586 .40771 Mdot
.39605 .66403 Mdot
.54829 .21617 Mdot
.43862 .40658 Mdot
.35904 .45154 Mdot
.66602 .47514 Mdot
.6663 .43368 Mdot
.55802 .22177 Mdot
.65216 .48358 Mdot
.36151 .48357 Mdot
.39515 .6621 Mdot
.38945 .46117 Mdot
.42312 .66315 Mdot
.42378 .39899 Mdot
.46073 .65379 Mdot
.41067 .68346 Mdot
.69846 .51085 Mdot
.37923 .45841 Mdot
.3949 .52852 Mdot
.37429 .41741 Mdot
.41201 .41303 Mdot
.64198 .45414 Mdot
.53239 .34442 Mdot
.33137 .40446 Mdot
.56173 .28944 Mdot
.55965 .33361 Mdot
.36265 .60961 Mdot
.62453 .44776 Mdot
.54345 .32677 Mdot
.19387 .5921 Mdot
.6237 .42402 Mdot
.53256 .31959 Mdot
.17723 .59245 Mdot
.61765 .64472 Mdot
.37274 .64943 Mdot
.4112 .46435 Mdot
.61639 .8002 Mdot
.28112 .31625 Mdot
.64661 .49099 Mdot
.43324 .45998 Mdot
.37587 .42917 Mdot
.42083 .68675 Mdot
.2508 .28012 Mdot
.67307 .41065 Mdot
.38912 .47411 Mdot
.42414 .63447 Mdot
.28539 .24132 Mdot
.67652 .46561 Mdot
.53183 .32271 Mdot
.58547 .59415 Mdot
.3885 .70111 Mdot
.63872 .54878 Mdot
.59942 .58856 Mdot
.6357 .51098 Mdot
.70014 .68054 Mdot
.35195 .44689 Mdot
.6333 .42175 Mdot
.80101 .59932 Mdot
.44249 .5882 Mdot
.55817 .63602 Mdot
.43485 .32994 Mdot
.41487 .65998 Mdot
.62564 .60633 Mdot
.51874 .34596 Mdot
.40636 .61486 Mdot
.40445 .67886 Mdot
.63598 .62098 Mdot
.5015 .46009 Mdot
.52067 .60771 Mdot
.61743 .63752 Mdot
.80856 .47426 Mdot
.60694 .78144 Mdot
.63436 .41815 Mdot
.55701 .33539 Mdot
.698 .72764 Mdot
.39653 .63914 Mdot
.29541 .74204 Mdot
.80503 .58079 Mdot
.43074 .44866 Mdot
.54807 .327 Mdot
.48689 .76875 Mdot
.19237 .43299 Mdot
.6178 .61277 Mdot
.53474 .48661 Mdot
.50692 .34584 Mdot
.44213 .42994 Mdot
.35504 .32932 Mdot
.37265 .46135 Mdot
.59687 .59854 Mdot
.20876 .56309 Mdot
.41934 .66058 Mdot
.63237 .64008 Mdot
.78618 .60848 Mdot
.40993 .45477 Mdot
.37294 .45673 Mdot
.36141 .27558 Mdot
.40101 .62346 Mdot
.65171 .41281 Mdot
.35244 .44453 Mdot
.40409 .44535 Mdot
.33055 .44417 Mdot
.35756 .51762 Mdot
.66688 .2443 Mdot
.38593 .47146 Mdot
.68818 .66149 Mdot
.41049 .38027 Mdot
.37908 .45555 Mdot
.45365 .65367 Mdot
.61526 .16989 Mdot
.69416 .6467 Mdot
.40532 .44807 Mdot
.36449 .46687 Mdot
.63677 .61924 Mdot
.51886 .58248 Mdot
.5945 .53885 Mdot
.57816 .49205 Mdot
.45553 .30567 Mdot
.46172 .42088 Mdot
.43224 .63898 Mdot
.53397 .30415 Mdot
.35008 .41697 Mdot
.43181 .64007 Mdot
.43009 .48166 Mdot
.63652 .44507 Mdot
.62209 .42688 Mdot
.55028 .66542 Mdot
.53941 .32195 Mdot
.32071 .29752 Mdot
.56257 .72579 Mdot
.66638 .47837 Mdot
.40936 .47544 Mdot
.64577 .60179 Mdot
.66725 .49174 Mdot
.60205 .51208 Mdot
.32641 .47293 Mdot
.39233 .63367 Mdot
.40874 .66738 Mdot
.4721 .23561 Mdot
.74186 .54141 Mdot
.55424 .16822 Mdot
.59295 .62404 Mdot
.44913 .4394 Mdot
.54375 .68545 Mdot
.4106 .66819 Mdot
.41235 .22594 Mdot
.54444 .32474 Mdot
.61907 .6115 Mdot
.73797 .41302 Mdot
.42896 .65794 Mdot
.37542 .66172 Mdot
.36397 .47203 Mdot
.39731 .43339 Mdot
.47627 .28362 Mdot
.49187 .33257 Mdot
.61624 .59361 Mdot
.55817 .32967 Mdot
.6888 .45698 Mdot
.38071 .47102 Mdot
.43098 .67505 Mdot
.67103 .74539 Mdot
.359 .46182 Mdot
.63968 .45437 Mdot
.41182 .65927 Mdot
.55778 .3203 Mdot
.5627 .32797 Mdot
.41126 .41415 Mdot
.21052 .48074 Mdot
.61755 .62341 Mdot
.41538 .66839 Mdot
.64646 .71951 Mdot
.43353 .39877 Mdot
.40357 .43429 Mdot
.42771 .50956 Mdot
.63324 .6152 Mdot
.56841 .68216 Mdot
.50955 .32868 Mdot
.40617 .63504 Mdot
.40408 .48372 Mdot
.53705 .31479 Mdot
.55849 .68138 Mdot
.63101 .47651 Mdot
.63071 .45045 Mdot
.56376 .31908 Mdot
.55293 .33098 Mdot
.56103 .31329 Mdot
.28745 .73932 Mdot
.37043 .67373 Mdot
.40259 .54658 Mdot
.44356 .41237 Mdot
.45547 .23239 Mdot
.32834 .39763 Mdot
.61034 .65483 Mdot
.62967 .46058 Mdot
.37046 .42245 Mdot
.3493 .45459 Mdot
.40208 .52359 Mdot
.39585 .53685 Mdot
.37606 .61722 Mdot
.42011 .64187 Mdot
.40283 .50132 Mdot
.62504 .45708 Mdot
.15596 .38392 Mdot
.5412 .84816 Mdot
.40343 .37355 Mdot
.5475 .5651 Mdot
.42961 .67528 Mdot
.63135 .59603 Mdot
.60032 .5235 Mdot
.58401 .63798 Mdot
.4048 .64135 Mdot
.38191 .47089 Mdot
.57608 .72494 Mdot
.56593 .32544 Mdot
.40528 .40132 Mdot
.60962 .60114 Mdot
.41064 .4046 Mdot
.59751 .58917 Mdot
.51991 .80611 Mdot
.80129 .42224 Mdot
.42365 .45276 Mdot
.38338 .38072 Mdot
.44983 .32913 Mdot
.38533 .42707 Mdot
.57148 .37249 Mdot
.42707 .67582 Mdot
.51182 .17641 Mdot
.37937 .48327 Mdot
.29296 .58037 Mdot
.43626 .40004 Mdot
.61405 .23517 Mdot
.40052 .43012 Mdot
.60703 .38813 Mdot
.43872 .43859 Mdot
.42658 .41501 Mdot
.58837 .64012 Mdot
.63655 .62128 Mdot
.43037 .6114 Mdot
.65574 .41488 Mdot
.37951 .79183 Mdot
.40437 .43971 Mdot
.70837 .62456 Mdot
.67044 .65692 Mdot
.55303 .334 Mdot
.40281 .64076 Mdot
.26067 .25649 Mdot
.57134 .61585 Mdot
.72032 .3401 Mdot
.55537 .23257 Mdot
.64975 .56133 Mdot
.59049 .50377 Mdot
.4381 .72766 Mdot
.5455 .3087 Mdot
.44305 .42876 Mdot
.71679 .69107 Mdot
.76248 .42264 Mdot
.31464 .45417 Mdot
.63478 .6404 Mdot
.30322 .63144 Mdot
.68725 .73381 Mdot
.50485 .33258 Mdot
.51219 .33444 Mdot
.5888 .59333 Mdot
.61171 .39861 Mdot
.47365 .41558 Mdot
.54538 .32191 Mdot
.65671 .48146 Mdot
.63105 .4176 Mdot
.72901 .43545 Mdot
.39337 .63731 Mdot
.76692 .63166 Mdot
.52514 .74472 Mdot
.60058 .58924 Mdot
.57795 .2802 Mdot
.37318 .68801 Mdot
.36982 .63979 Mdot
.65988 .42506 Mdot
.64309 .45877 Mdot
.37416 .63745 Mdot
.37462 .48631 Mdot
.43247 .51279 Mdot
.40642 .45064 Mdot
.53157 .33406 Mdot
.39484 .4261 Mdot
.64122 .44597 Mdot
.61257 .61366 Mdot
.64849 .46316 Mdot
.573 .62684 Mdot
.56728 .76407 Mdot
.39232 .40594 Mdot
.4266 .42247 Mdot
.27964 .31466 Mdot
.44696 .63674 Mdot
.67162 .69885 Mdot
.71678 .64431 Mdot
.66634 .46642 Mdot
.43092 .41604 Mdot
.4427 .65097 Mdot
.51975 .30533 Mdot
.27865 .31346 Mdot
.38013 .39893 Mdot
.43101 .67272 Mdot
.39965 .47882 Mdot
.21849 .63141 Mdot
.75897 .31561 Mdot
.39443 .65086 Mdot
.38599 .19497 Mdot
.38083 .47464 Mdot
.4431 .71427 Mdot
.37443 .39434 Mdot
.49814 .24991 Mdot
.43717 .40488 Mdot
.40023 .61718 Mdot
.39945 .44905 Mdot
.41626 .61681 Mdot
.67938 .46602 Mdot
.61607 .58342 Mdot
.38344 .67042 Mdot
.35918 .41312 Mdot
.40827 .86529 Mdot
.59361 .60368 Mdot
.42695 .44249 Mdot
.57758 .61314 Mdot
.42159 .62734 Mdot
.37633 .65492 Mdot
.1725 .46902 Mdot
.67919 .60724 Mdot
.59723 .62787 Mdot
.39204 .47314 Mdot
.49363 .72457 Mdot
.38495 .46327 Mdot
.46193 .27466 Mdot
.33913 .45677 Mdot
.43364 .40006 Mdot
.14746 .52174 Mdot
.62708 .60211 Mdot
.57625 .18167 Mdot
.1732 .48791 Mdot
.2785 .72769 Mdot
.40849 .7031 Mdot
.50726 .3268 Mdot
.32226 .76871 Mdot
.69852 .6385 Mdot
.63995 .4312 Mdot
.37245 .42064 Mdot
.3578 .66132 Mdot
.62268 .62695 Mdot
.52955 .34275 Mdot
.42423 .45206 Mdot
.64258 .46054 Mdot
.68627 .29985 Mdot
.58096 .59196 Mdot
.39826 .63817 Mdot
.4014 .68605 Mdot
.34075 .20556 Mdot
.4129 .4834 Mdot
.42972 .42277 Mdot
.5936 .59987 Mdot
.43837 .58121 Mdot
.55088 .30853 Mdot
.62607 .25246 Mdot
.59583 .62598 Mdot
.56112 .52414 Mdot
.41713 .63374 Mdot
.3767 .42761 Mdot
.4417 .76087 Mdot
.73661 .39206 Mdot
.30959 .51867 Mdot
.529 .32759 Mdot
.45266 .27788 Mdot
.39887 .6176 Mdot
.60732 .60759 Mdot
.73766 .5618 Mdot
.37861 .50996 Mdot
.37875 .43312 Mdot
.44609 .27709 Mdot
.51807 .45509 Mdot
.35751 .23834 Mdot
.39335 .39183 Mdot
.52736 .44767 Mdot
.40885 .39358 Mdot
.35521 .49915 Mdot
.35908 .4794 Mdot
.41007 .43287 Mdot
.43033 .67378 Mdot
.31825 .45733 Mdot
.63694 .42724 Mdot
.27882 .39439 Mdot
.56763 .49974 Mdot
.4349 .45271 Mdot
.37983 .46583 Mdot
.34437 .56734 Mdot
.64136 .66814 Mdot
.39525 .6761 Mdot
.44017 .60021 Mdot
.62681 .58513 Mdot
.41148 .52321 Mdot
.66273 .41353 Mdot
.32176 .44538 Mdot
.64518 .45609 Mdot
.43877 .66197 Mdot
.67022 .46605 Mdot
.60035 .58187 Mdot
.62917 .42388 Mdot
.70466 .64636 Mdot
.6264 .61355 Mdot
.39156 .62871 Mdot
.41473 .42021 Mdot
.62295 .64639 Mdot
.37188 .27587 Mdot
.53165 .33327 Mdot
.16834 .47819 Mdot
.4153 .48573 Mdot
.64535 .56327 Mdot
.4393 .55431 Mdot
.64828 .46121 Mdot
.70801 .26462 Mdot
.40836 .68362 Mdot
.55655 .29689 Mdot
.44066 .65926 Mdot
.82739 .48628 Mdot
.54147 .34362 Mdot
.18111 .60435 Mdot
.76623 .54711 Mdot
.57907 .41862 Mdot
.3777 .48711 Mdot
.36185 .33381 Mdot
.68998 .45861 Mdot
.62301 .62569 Mdot
.75747 .53561 Mdot
.42497 .41239 Mdot
.75562 .36464 Mdot
.42496 .60587 Mdot
.65099 .41616 Mdot
.60199 .61291 Mdot
.62948 .64107 Mdot
.36818 .4106 Mdot
.59798 .27712 Mdot
.40396 .39631 Mdot
.72502 .53902 Mdot
.45301 .29892 Mdot
.47776 .4558 Mdot
.4324 .43813 Mdot
.68031 .43603 Mdot
.39956 .47848 Mdot
.48404 .35352 Mdot
.75977 .65891 Mdot
.45857 .42247 Mdot
.71694 .653 Mdot
.58478 .32901 Mdot
.41336 .64715 Mdot
.38882 .36932 Mdot
.67606 .59114 Mdot
.40591 .48254 Mdot
.87036 .45049 Mdot
.53382 .31796 Mdot
.69826 .60137 Mdot
.41891 .38501 Mdot
.3583 .42192 Mdot
.4115 .34419 Mdot
.37123 .71024 Mdot
.73926 .39188 Mdot
.38421 .43707 Mdot
.39839 .3036 Mdot
.58379 .61509 Mdot
.39562 .39571 Mdot
.41948 .44564 Mdot
.34337 .67376 Mdot
.63256 .62874 Mdot
.65742 .46972 Mdot
.66432 .50021 Mdot
.67025 .40142 Mdot
.56967 .33675 Mdot
.54177 .50364 Mdot
.43264 .22839 Mdot
.76917 .35636 Mdot
.54093 .29948 Mdot
.3871 .48307 Mdot
.47637 .35405 Mdot
.36394 .46312 Mdot
.52252 .34835 Mdot
.6322 .62425 Mdot
.39454 .67709 Mdot
.52354 .66231 Mdot
.68944 .43545 Mdot
.39335 .38816 Mdot
.54597 .34951 Mdot
.39019 .63302 Mdot
.49637 .34954 Mdot
.41092 .6403 Mdot
.59908 .6252 Mdot
.62713 .58151 Mdot
.52536 .34448 Mdot
.43879 .65334 Mdot
.6485 .6763 Mdot
.19666 .43435 Mdot
.34161 .46522 Mdot
.55293 .5931 Mdot
.44481 .63716 Mdot
.39213 .6078 Mdot
.42726 .61451 Mdot
.40678 .40795 Mdot
.54407 .56638 Mdot
.33475 .42678 Mdot
.61349 .59316 Mdot
.64328 .4747 Mdot
.5437 .25926 Mdot
.60948 .76868 Mdot
.55622 .26287 Mdot
.44792 .455 Mdot
.4042 .45438 Mdot
.42526 .44119 Mdot
.34528 .45712 Mdot
.71366 .55231 Mdot
.3785 .40918 Mdot
.58319 .63472 Mdot
.64981 .44823 Mdot
.44517 .43539 Mdot
.63513 .48168 Mdot
.46462 .72 Mdot
.53079 .3046 Mdot
.53186 .49709 Mdot
.37939 .83037 Mdot
.38508 .63954 Mdot
.65371 .4849 Mdot
.64154 .43022 Mdot
.555 .30487 Mdot
.61951 .62904 Mdot
.4129 .63455 Mdot
.50647 .25603 Mdot
.5613 .32052 Mdot
.40146 .4477 Mdot
.67301 .51152 Mdot
.74947 .36855 Mdot
.4383 .41681 Mdot
.36239 .43594 Mdot
.62746 .47328 Mdot
.60806 .39866 Mdot
.76165 .70368 Mdot
.37825 .24208 Mdot
.5292 .34512 Mdot
.52142 .3134 Mdot
.38244 .62076 Mdot
.37225 .38044 Mdot
.61016 .59227 Mdot
.3221 .27173 Mdot
.47521 .51549 Mdot
.3235 .28955 Mdot
.51091 .41155 Mdot
.37784 .40225 Mdot
.23591 .43181 Mdot
.41091 .45578 Mdot
.41534 .68546 Mdot
.41298 .623 Mdot
.38533 .66224 Mdot
.62123 .62225 Mdot
.2694 .62526 Mdot
.58976 .63928 Mdot
.4099 .83813 Mdot
.39278 .61986 Mdot
.70652 .57582 Mdot
.67824 .43397 Mdot
.42348 .3789 Mdot
.55484 .3156 Mdot
.58864 .6555 Mdot
.47012 .43115 Mdot
.64576 .23215 Mdot
.6428 .42174 Mdot
.39073 .6284 Mdot
.43394 .72824 Mdot
.48208 .82685 Mdot
.59933 .53037 Mdot
.34164 .37382 Mdot
.39518 .33768 Mdot
.55351 .33556 Mdot
.30222 .50927 Mdot
.53265 .35355 Mdot
.61592 .60346 Mdot
.42316 .42406 Mdot
.41465 .42651 Mdot
.41911 .39551 Mdot
.3835 .40795 Mdot
.63448 .59875 Mdot
.45128 .41645 Mdot
.82051 .39107 Mdot
.6205 .42951 Mdot
.24138 .65563 Mdot
.53935 .31148 Mdot
.63768 .64047 Mdot
.64816 .44886 Mdot
.61334 .44949 Mdot
.38801 .25251 Mdot
.43609 .44367 Mdot
.37134 .42007 Mdot
.73061 .35539 Mdot
.39816 .39076 Mdot
.34862 .37208 Mdot
.64232 .42694 Mdot
.55383 .26268 Mdot
.53648 .29767 Mdot
.51473 .32947 Mdot
.628 .63297 Mdot
.44012 .65549 Mdot
.53809 .32912 Mdot
.6774 .46822 Mdot
.44229 .47022 Mdot
.35096 .42831 Mdot
.44377 .63322 Mdot
.80976 .57219 Mdot
.50414 .33683 Mdot
.44953 .72204 Mdot
.4234 .62283 Mdot
.37371 .68318 Mdot
.3781 .43471 Mdot
.31666 .47005 Mdot
.36268 .68626 Mdot
.55363 .29958 Mdot
.63955 .6359 Mdot
.57638 .48228 Mdot
.60642 .59702 Mdot
.4061 .62794 Mdot
.34691 .42937 Mdot
.40522 .62504 Mdot
.42312 .47596 Mdot
.27897 .78869 Mdot
.40919 .42862 Mdot
.78322 .36834 Mdot
.46719 .25028 Mdot
.65027 .43587 Mdot
.65647 .67414 Mdot
.65672 .42136 Mdot
.41923 .62052 Mdot
.3507 .4196 Mdot
.51137 .3269 Mdot
.24525 .69582 Mdot
.36851 .68134 Mdot
.63412 .44337 Mdot
.65344 .40331 Mdot
.62848 .61294 Mdot
.44625 .43252 Mdot
.37963 .42852 Mdot
.66348 .4376 Mdot
.46819 .48245 Mdot
.43051 .66167 Mdot
.42965 .42853 Mdot
.38995 .45516 Mdot
.65009 .4336 Mdot
.20544 .4184 Mdot
.39959 .72029 Mdot
.41964 .4307 Mdot
.74154 .59524 Mdot
.61273 .65457 Mdot
.36024 .47545 Mdot
.4367 .38697 Mdot
.5517 .32556 Mdot
.28168 .68639 Mdot
.74944 .67064 Mdot
.60447 .65337 Mdot
.66113 .41872 Mdot
.40905 .48479 Mdot
.67739 .43084 Mdot
.35455 .42071 Mdot
.33029 .71661 Mdot
.64183 .41637 Mdot
.35539 .43392 Mdot
.38825 .37299 Mdot
.40368 .62201 Mdot
.37273 .4108 Mdot
.36339 .5788 Mdot
.67735 .48302 Mdot
.36037 .42238 Mdot
.2109 .48524 Mdot
.61035 .64084 Mdot
.39618 .3717 Mdot
.52715 .31174 Mdot
.51311 .25326 Mdot
.5607 .73675 Mdot
.71715 .62905 Mdot
.52107 .31919 Mdot
.41187 .40326 Mdot
.6487 .40233 Mdot
.59312 .59084 Mdot
.75005 .3364 Mdot
.43158 .41187 Mdot
.59684 .59923 Mdot
.61053 .61346 Mdot
.5275 .31611 Mdot
.49105 .15178 Mdot
.44319 .39607 Mdot
.38763 .4256 Mdot
.35811 .60682 Mdot
.43559 .68046 Mdot
.3994 .42456 Mdot
.36951 .47227 Mdot
.58003 .62928 Mdot
.36519 .3634 Mdot
.32227 .6063 Mdot
.59388 .24153 Mdot
.57723 .64094 Mdot
.5581 .43727 Mdot
.6536 .40884 Mdot
.54237 .31314 Mdot
.40882 .65253 Mdot
.51232 .35198 Mdot
.62643 .43548 Mdot
.38269 .47957 Mdot
.57425 .61101 Mdot
.34579 .53566 Mdot
.59177 .59017 Mdot
.71243 .61893 Mdot
.44491 .65892 Mdot
.52942 .68927 Mdot
.8383 .37852 Mdot
.52817 .75017 Mdot
.64608 .66423 Mdot
.55291 .33397 Mdot
.62762 .50192 Mdot
.39429 .45511 Mdot
.28187 .47398 Mdot
.41549 .41565 Mdot
.21514 .487 Mdot
.6474 .48026 Mdot
.6286 .4142 Mdot
.42139 .42686 Mdot
.45613 .29198 Mdot
.60218 .58623 Mdot
.62693 .60411 Mdot
.36343 .42178 Mdot
.6071 .62864 Mdot
.39449 .43448 Mdot
.64256 .45162 Mdot
.61689 .19459 Mdot
.41538 .45136 Mdot
.35015 .40687 Mdot
.6057 .55028 Mdot
.15497 .52492 Mdot
.76231 .59269 Mdot
.24605 .416 Mdot
.51505 .82817 Mdot
.60657 .62774 Mdot
.33843 .40965 Mdot
.55832 .43007 Mdot
.62977 .47714 Mdot
.64477 .67678 Mdot
.40424 .41985 Mdot
.40313 .41632 Mdot
.43161 .41961 Mdot
.37265 .45742 Mdot
.28425 .48456 Mdot
.39701 .55181 Mdot
.22517 .5405 Mdot
.36809 .42209 Mdot
.33236 .33441 Mdot
.61692 .64766 Mdot
.43142 .60643 Mdot
.51469 .35558 Mdot
.37739 .40289 Mdot
.39152 .55186 Mdot
.61969 .65369 Mdot
.41231 .83869 Mdot
.63014 .62202 Mdot
.6645 .46175 Mdot
.62666 .59129 Mdot
.42454 .46685 Mdot
.40125 .65552 Mdot
.56943 .48837 Mdot
.72528 .49838 Mdot
.63944 .43196 Mdot
.43144 .46091 Mdot
.68732 .59222 Mdot
.63679 .43011 Mdot
.466 .72165 Mdot
.40468 .65887 Mdot
.38642 .30205 Mdot
.41222 .6225 Mdot
.35466 .43384 Mdot
.35527 .44579 Mdot
.55471 .63881 Mdot
.60499 .58348 Mdot
.41615 .62257 Mdot
.52969 .14486 Mdot
.53545 .35438 Mdot
.3857 .65703 Mdot
.39763 .50746 Mdot
.49468 .56124 Mdot
.39956 .66345 Mdot
.50963 .28464 Mdot
.62442 .61941 Mdot
.38694 .62116 Mdot
.40089 .50843 Mdot
.80471 .53125 Mdot
.56215 .30574 Mdot
.65023 .3958 Mdot
.70539 .4529 Mdot
.67089 .48953 Mdot
.64302 .62237 Mdot
.65113 .42371 Mdot
.58417 .62112 Mdot
.65266 .69965 Mdot
.28523 .35336 Mdot
.64211 .59244 Mdot
.64066 .60812 Mdot
.64991 .42655 Mdot
.43443 .43159 Mdot
.69336 .47728 Mdot
.33456 .44058 Mdot
.45702 .4667 Mdot
.58957 .62967 Mdot
.3992 .61846 Mdot
.37122 .66051 Mdot
.34571 .3328 Mdot
.4034 .68692 Mdot
.64427 .45701 Mdot
.76379 .32837 Mdot
.72224 .6737 Mdot
.5871 .61099 Mdot
.63856 .61051 Mdot
.38332 .4641 Mdot
.67238 .43825 Mdot
.68351 .45135 Mdot
.62109 .604 Mdot
.28699 .42686 Mdot
.35644 .39451 Mdot
.40451 .60002 Mdot
.3891 .62203 Mdot
.39403 .657 Mdot
.42321 .61359 Mdot
.31537 .57574 Mdot
.62516 .61698 Mdot
.40488 .61635 Mdot
.3583 .42912 Mdot
.40246 .41744 Mdot
.57615 .49235 Mdot
.51661 .32469 Mdot
.43258 .47859 Mdot
.36911 .48648 Mdot
.37571 .4332 Mdot
.63032 .44666 Mdot
.44299 .49169 Mdot
.64944 .41238 Mdot
.65712 .398 Mdot
.62007 .44854 Mdot
.69996 .63976 Mdot
.40801 .33564 Mdot
.55637 .83198 Mdot
.38944 .47444 Mdot
.46335 .60744 Mdot
.6779 .44065 Mdot
.68295 .2494 Mdot
.5539 .67465 Mdot
.43122 .41421 Mdot
.73522 .39493 Mdot
.66207 .43525 Mdot
.39737 .68706 Mdot
.40567 .4225 Mdot
.66797 .39813 Mdot
.53782 .30323 Mdot
.37403 .50035 Mdot
.66721 .49637 Mdot
.43717 .64684 Mdot
.54528 .35807 Mdot
.39578 .6151 Mdot
.62463 .46119 Mdot
.39078 .37252 Mdot
.73823 .77525 Mdot
.68392 .42177 Mdot
.18541 .58135 Mdot
.41264 .70885 Mdot
.43064 .42826 Mdot
.66125 .48726 Mdot
.43138 .68354 Mdot
.64378 .62499 Mdot
.49592 .50541 Mdot
.39801 .68143 Mdot
.62901 .41422 Mdot
.66772 .49478 Mdot
.64156 .42762 Mdot
.42012 .6472 Mdot
.34349 .42318 Mdot
.42421 .65461 Mdot
.62857 .59363 Mdot
.40321 .46214 Mdot
.43047 .82123 Mdot
.45184 .59376 Mdot
.42041 .6223 Mdot
.6513 .47114 Mdot
.56595 .33321 Mdot
.42185 .45596 Mdot
.18018 .54339 Mdot
.43226 .46559 Mdot
.58521 .60617 Mdot
.58239 .20621 Mdot
.34108 .53403 Mdot
.4413 .40835 Mdot
.38217 .46373 Mdot
.62181 .59698 Mdot
.43237 .44812 Mdot
.44091 .41072 Mdot
.69219 .63079 Mdot
.42402 .64148 Mdot
.39748 .45075 Mdot
.65425 .47773 Mdot
.69073 .70171 Mdot
.34352 .40907 Mdot
.66774 .31472 Mdot
.414 .29816 Mdot
.54761 .18366 Mdot
.41867 .41568 Mdot
.35289 .25865 Mdot
.3671 .45086 Mdot
.40067 .40173 Mdot
.38926 .46913 Mdot
.25954 .40027 Mdot
.6351 .42292 Mdot
.64223 .44052 Mdot
.56032 .30338 Mdot
.41087 .2997 Mdot
.54913 .32568 Mdot
.62602 .62734 Mdot
.64513 .31505 Mdot
.64135 .41692 Mdot
.43757 .64535 Mdot
.41014 .39979 Mdot
.68683 .42689 Mdot
.37728 .42434 Mdot
.42305 .47003 Mdot
.67863 .4253 Mdot
.67844 .41803 Mdot
.70536 .6144 Mdot
.52869 .3079 Mdot
.38511 .66819 Mdot
.41487 .49174 Mdot
.55811 .33586 Mdot
.34753 .41805 Mdot
.45508 .22838 Mdot
.38742 .66878 Mdot
.42464 .64456 Mdot
.37828 .67657 Mdot
.38371 .47991 Mdot
.42773 .46005 Mdot
.58886 .63776 Mdot
.44033 .64881 Mdot
.6116 .63906 Mdot
.55709 .48412 Mdot
.65392 .29848 Mdot
.40419 .4197 Mdot
.4627 .70646 Mdot
.55087 .31636 Mdot
.65644 .45998 Mdot
.69995 .31989 Mdot
.56452 .30732 Mdot
.42947 .46793 Mdot
.67961 .43216 Mdot
.52003 .34488 Mdot
.34296 .36309 Mdot
.62714 .8082 Mdot
.56031 .34336 Mdot
.35982 .42769 Mdot
.41537 .35596 Mdot
.2474 .357 Mdot
.56655 .34011 Mdot
.57886 .60701 Mdot
.38638 .48157 Mdot
.42879 .56029 Mdot
.50491 .33841 Mdot
.66378 .70748 Mdot
.65467 .44165 Mdot
.78032 .59466 Mdot
.46859 .45247 Mdot
.27464 .43662 Mdot
.5184 .35198 Mdot
.40986 .63476 Mdot
.45539 .63842 Mdot
.37459 .44199 Mdot
.56535 .34307 Mdot
.57056 .63172 Mdot
.65661 .44753 Mdot
.69646 .65171 Mdot
.4204 .65006 Mdot
.49826 .68369 Mdot
.64213 .46977 Mdot
.46945 .70575 Mdot
.59607 .22797 Mdot
.47037 .47229 Mdot
.24799 .39849 Mdot
.7615 .44953 Mdot
.38453 .48372 Mdot
.54225 .35309 Mdot
.60929 .65284 Mdot
.57975 .60162 Mdot
.59461 .62233 Mdot
.66688 .67035 Mdot
.58606 .51206 Mdot
.63666 .47895 Mdot
.74168 .45906 Mdot
.53863 .31555 Mdot
.33297 .3171 Mdot
.35923 .40754 Mdot
.40632 .45382 Mdot
.44803 .44339 Mdot
.39211 .39466 Mdot
.37265 .44992 Mdot
.61514 .63153 Mdot
.6721 .66848 Mdot
.56513 .45268 Mdot
.39443 .66897 Mdot
.56388 .27089 Mdot
.67836 .4347 Mdot
.61947 .45675 Mdot
.51978 .3354 Mdot
.42614 .73735 Mdot
.64877 .4886 Mdot
.66758 .46743 Mdot
.43687 .46475 Mdot
.42911 .65563 Mdot
.31823 .44502 Mdot
.3597 .45174 Mdot
.65154 .45606 Mdot
.54408 .39686 Mdot
.33927 .59124 Mdot
.37074 .51341 Mdot
.54483 .36262 Mdot
.53853 .56525 Mdot
.56431 .34247 Mdot
.35969 .40243 Mdot
.66503 .23775 Mdot
.62725 .43333 Mdot
.67111 .45133 Mdot
.53657 .3518 Mdot
.42676 .7188 Mdot
.4136 .65637 Mdot
.61308 .44955 Mdot
.57943 .61555 Mdot
.3582 .45629 Mdot
.66984 .29297 Mdot
.44296 .70918 Mdot
.61137 .28617 Mdot
.59083 .61668 Mdot
.68213 .45403 Mdot
.44641 .42707 Mdot
.35991 .4292 Mdot
.55638 .3308 Mdot
.48557 .79783 Mdot
.38047 .49969 Mdot
.28052 .73139 Mdot
.80755 .43062 Mdot
.80989 .54989 Mdot
.37892 .43303 Mdot
.42244 .64161 Mdot
.65949 .4988 Mdot
.55724 .33428 Mdot
.45311 .45657 Mdot
.60544 .81772 Mdot
.44226 .62183 Mdot
.61242 .60496 Mdot
.55102 .444 Mdot
.6019 .52468 Mdot
.42151 .48195 Mdot
.41489 .41681 Mdot
.39947 .40674 Mdot
.70463 .75333 Mdot
.63439 .45328 Mdot
.43182 .67583 Mdot
.52678 .3289 Mdot
.40637 .68706 Mdot
.64504 .43692 Mdot
.50984 .68774 Mdot
.43928 .44515 Mdot
.44329 .62454 Mdot
.40875 .63776 Mdot
.62855 .61464 Mdot
.64324 .61174 Mdot
.55391 .46718 Mdot
.40819 .42957 Mdot
.68377 .48204 Mdot
.3991 .62214 Mdot
.67555 .50849 Mdot
.54375 .34275 Mdot
.60626 .64817 Mdot
.36959 .42006 Mdot
.63082 .43071 Mdot
.45217 .41791 Mdot
.40742 .67049 Mdot
.6687 .46662 Mdot
.70232 .61339 Mdot
.52249 .31308 Mdot
.38982 .414 Mdot
.52471 .36376 Mdot
.66238 .41884 Mdot
.39146 .45612 Mdot
.39909 .73776 Mdot
.57334 .34155 Mdot
.70624 .51929 Mdot
.63658 .47627 Mdot
.70619 .62276 Mdot
.37528 .66791 Mdot
.63315 .71071 Mdot
.66821 .45475 Mdot
.40305 .7417 Mdot
.54582 .78627 Mdot
.4246 .48993 Mdot
.39459 .64322 Mdot
.62021 .48535 Mdot
.34626 .80882 Mdot
.20817 .42961 Mdot
.42544 .44346 Mdot
.64849 .48305 Mdot
.54122 .34966 Mdot
.58671 .61226 Mdot
.6681 .31315 Mdot
.48382 .35644 Mdot
.66388 .40711 Mdot
.38642 .46931 Mdot
.41917 .6283 Mdot
.61907 .61708 Mdot
.5832 .7349 Mdot
.66915 .47345 Mdot
.63901 .47116 Mdot
.44554 .42269 Mdot
.54339 .32435 Mdot
.1931 .48919 Mdot
.64035 .44872 Mdot
.73704 .36631 Mdot
.63928 .51333 Mdot
.54771 .34914 Mdot
.36247 .44336 Mdot
.36667 .32962 Mdot
.34867 .46307 Mdot
.19503 .61434 Mdot
.66163 .42262 Mdot
.3986 .67352 Mdot
.4141 .41017 Mdot
.58365 .23591 Mdot
.65473 .45508 Mdot
.55047 .56292 Mdot
.62993 .37492 Mdot
.62462 .61757 Mdot
.70562 .32315 Mdot
.39219 .42224 Mdot
.59756 .5876 Mdot
.55093 .31708 Mdot
.41586 .43357 Mdot
.42492 .4619 Mdot
.419 .68928 Mdot
.61578 .60176 Mdot
.57291 .79468 Mdot
.63331 .63849 Mdot
.59439 .64702 Mdot
.38603 .68864 Mdot
.38794 .44379 Mdot
.66285 .46415 Mdot
.66416 .43544 Mdot
.45333 .46647 Mdot
.69116 .24358 Mdot
.41575 .6569 Mdot
.5798 .28353 Mdot
.7217 .73905 Mdot
.4755 .45738 Mdot
.69581 .31508 Mdot
.48143 .79573 Mdot
.56982 .62751 Mdot
.36537 .4216 Mdot
.43153 .63471 Mdot
.61181 .44358 Mdot
.64456 .4732 Mdot
.34383 .42852 Mdot
.61253 .61772 Mdot
.54418 .30149 Mdot
.68835 .45176 Mdot
.59855 .27629 Mdot
.39134 .40415 Mdot
.75269 .40509 Mdot
.66919 .48506 Mdot
.26776 .73944 Mdot
.63428 .49191 Mdot
.39206 .64789 Mdot
.42111 .46997 Mdot
.39731 .68419 Mdot
.52833 .33488 Mdot
.55251 .45277 Mdot
.61279 .6154 Mdot
.48535 .40957 Mdot
.85761 .47821 Mdot
.64512 .4232 Mdot
.42718 .67613 Mdot
.44116 .40748 Mdot
.47331 .36247 Mdot
.39207 .42707 Mdot
.43005 .36305 Mdot
.58199 .33939 Mdot
.5951 .63506 Mdot
.58326 .60584 Mdot
.39691 .45795 Mdot
.557 .3115 Mdot
.68098 .4558 Mdot
.65854 .44951 Mdot
.12609 .51415 Mdot
.70231 .50039 Mdot
.48001 .27887 Mdot
.39926 .41502 Mdot
.63465 .41118 Mdot
.63808 .74971 Mdot
.59256 .60105 Mdot
.36676 .40141 Mdot
.66027 .41316 Mdot
.80065 .48165 Mdot
.51737 .24069 Mdot
.36972 .44718 Mdot
.45542 .40435 Mdot
.57879 .61354 Mdot
.3428 .29333 Mdot
.6235 .45635 Mdot
.33641 .45288 Mdot
.60897 .57652 Mdot
.55774 .21269 Mdot
.78309 .62836 Mdot
.38484 .66757 Mdot
.61236 .38962 Mdot
.61592 .63137 Mdot
.44712 .48253 Mdot
.53571 .31103 Mdot
.68494 .47298 Mdot
.63156 .44308 Mdot
.39829 .47312 Mdot
.44993 .41474 Mdot
.45345 .33304 Mdot
.42232 .67733 Mdot
.61999 .64514 Mdot
.42416 .4196 Mdot
.50825 .6525 Mdot
.4154 .39448 Mdot
.59588 .64167 Mdot
.69787 .82204 Mdot
.41288 .49439 Mdot
.38996 .42795 Mdot
.19176 .48503 Mdot
.39619 .68099 Mdot
.40482 .68858 Mdot
.79014 .39523 Mdot
.39842 .41484 Mdot
.72611 .34321 Mdot
.38404 .66922 Mdot
.41414 .66078 Mdot
.66634 .56183 Mdot
.41784 .45456 Mdot
.29306 .30665 Mdot
.59414 .5919 Mdot
.57979 .63388 Mdot
.42281 .6545 Mdot
.40192 .49987 Mdot
.57002 .61645 Mdot
.29788 .52181 Mdot
.67247 .43663 Mdot
.649 .22647 Mdot
.41147 .67337 Mdot
.53427 .473 Mdot
.58959 .60968 Mdot
.40585 .83709 Mdot
.73394 .42546 Mdot
.43243 .42815 Mdot
.39132 .41141 Mdot
.54814 .31386 Mdot
.41821 .49158 Mdot
.62723 .41508 Mdot
.60721 .62901 Mdot
.19751 .5572 Mdot
.38501 .66085 Mdot
.4026 .43131 Mdot
.45728 .7212 Mdot
.57243 .7544 Mdot
.77373 .55375 Mdot
.41267 .64682 Mdot
.3929 .63956 Mdot
.626 .46074 Mdot
.6539 .48373 Mdot
.38052 .44432 Mdot
.61775 .59646 Mdot
.43776 .64131 Mdot
.59154 .63652 Mdot
.62707 .43532 Mdot
.66217 .4673 Mdot
.63924 .4165 Mdot
.33494 .46123 Mdot
.66437 .47241 Mdot
.58857 .26625 Mdot
.49843 .69212 Mdot
.36977 .63928 Mdot
.83123 .56576 Mdot
.58405 .73319 Mdot
.4508 .5349 Mdot
.50926 .33162 Mdot
.66305 .41879 Mdot
.63448 .60376 Mdot
.38341 .46164 Mdot
.3739 .42208 Mdot
.65291 .39052 Mdot
.62053 .58999 Mdot
.52952 .34101 Mdot
.61211 .58466 Mdot
.52826 .31455 Mdot
.73937 .4033 Mdot
.44643 .43587 Mdot
.3512 .43278 Mdot
.61004 .63246 Mdot
.66786 .46935 Mdot
.6477 .44514 Mdot
.55844 .34729 Mdot
.50132 .47424 Mdot
.63771 .4274 Mdot
.4105 .67269 Mdot
.30411 .56621 Mdot
.66393 .49701 Mdot
.40313 .42323 Mdot
.42966 .2257 Mdot
.28828 .47636 Mdot
.34201 .4527 Mdot
.67172 .58689 Mdot
.33626 .23507 Mdot
.41788 .40655 Mdot
.35057 .21742 Mdot
.70625 .62486 Mdot
.40092 .68304 Mdot
.6427 .47825 Mdot
.61252 .43924 Mdot
.38597 .36363 Mdot
.49491 .33538 Mdot
.4509 .46577 Mdot
.39002 .67853 Mdot
.45471 .65407 Mdot
.81229 .49228 Mdot
.18586 .58528 Mdot
.52566 .35149 Mdot
.517 .33502 Mdot
.66722 .45261 Mdot
.18831 .41093 Mdot
.37166 .51072 Mdot
.52849 .34394 Mdot
.28968 .34478 Mdot
.38286 .46963 Mdot
.44664 .26952 Mdot
.73125 .37653 Mdot
.42199 .64623 Mdot
.36163 .33289 Mdot
.66211 .45818 Mdot
.41534 .68105 Mdot
.5173 .65225 Mdot
.42592 .48218 Mdot
.38723 .66708 Mdot
.58807 .63467 Mdot
.76378 .48324 Mdot
.37675 .65572 Mdot
.44109 .22433 Mdot
.62127 .60272 Mdot
.64485 .52608 Mdot
.35703 .31649 Mdot
.77613 .26002 Mdot
.61378 .62907 Mdot
.67311 .416 Mdot
.66365 .4362 Mdot
.65987 .44937 Mdot
.41304 .68369 Mdot
.68333 .44475 Mdot
.42653 .6741 Mdot
.22915 .37384 Mdot
.49948 .47638 Mdot
.52725 .34559 Mdot
.68053 .61198 Mdot
.40241 .63542 Mdot
.74418 .30253 Mdot
.84484 .40871 Mdot
.36661 .41801 Mdot
.63801 .62528 Mdot
.52487 .34847 Mdot
.23109 .69107 Mdot
.5511 .32185 Mdot
.58379 .40057 Mdot
.60933 .20612 Mdot
.39972 .43602 Mdot
.30626 .65034 Mdot
.51275 .32541 Mdot
.41594 .63526 Mdot
.39639 .45565 Mdot
.62316 .67864 Mdot
.54582 .31939 Mdot
.54441 .30273 Mdot
.38316 .44993 Mdot
.39118 .62786 Mdot
.65809 .46527 Mdot
.61788 .58236 Mdot
.56821 .304 Mdot
.46248 .66101 Mdot
.39174 .48928 Mdot
.40235 .48605 Mdot
.59038 .53747 Mdot
.48619 .32482 Mdot
.60707 .62739 Mdot
.26944 .34421 Mdot
.65188 .48259 Mdot
.59827 .45824 Mdot
.78842 .4106 Mdot
.68058 .6027 Mdot
.6584 .42328 Mdot
.65866 .41925 Mdot
.37384 .44762 Mdot
.48459 .31772 Mdot
.56391 .19751 Mdot
.66362 .6443 Mdot
.65965 .49715 Mdot
.65625 .44956 Mdot
.45349 .63983 Mdot
.81606 .48933 Mdot
.45342 .45302 Mdot
.59862 .65191 Mdot
.63112 .43305 Mdot
.33208 .71992 Mdot
.53953 .32364 Mdot
.71072 .27442 Mdot
.44524 .43265 Mdot
.42677 .42292 Mdot
.60012 .6168 Mdot
.58937 .63953 Mdot
.55822 .65327 Mdot
.81611 .45027 Mdot
.29715 .28192 Mdot
.62812 .72661 Mdot
.32965 .70507 Mdot
.43809 .61393 Mdot
.41935 .62187 Mdot
.68717 .65125 Mdot
.62799 .64685 Mdot
.41498 .4076 Mdot
.43699 .64158 Mdot
.76571 .53409 Mdot
.43298 .58478 Mdot
.46044 .27753 Mdot
.63183 .27005 Mdot
.42591 .4721 Mdot
.43075 .64721 Mdot
.40146 .68051 Mdot
.43233 .62642 Mdot
.70541 .62558 Mdot
.38444 .43651 Mdot
.4339 .44099 Mdot
.42063 .40172 Mdot
.33775 .50967 Mdot
.38114 .40667 Mdot
.67183 .63279 Mdot
.56164 .52851 Mdot
.23649 .63526 Mdot
.34551 .46572 Mdot
.5725 .62894 Mdot
.41056 .48826 Mdot
.55622 .30933 Mdot
.38692 .46743 Mdot
.46669 .27535 Mdot
.60106 .602 Mdot
.41071 .7145 Mdot
.62612 .72274 Mdot
.44239 .44094 Mdot
.53855 .29905 Mdot
.42911 .54737 Mdot
.51419 .80826 Mdot
.49482 .32464 Mdot
.41135 .67224 Mdot
.66992 .42997 Mdot
.63098 .59953 Mdot
.66756 .46246 Mdot
.34382 .47198 Mdot
.65857 .5735 Mdot
.4874 .7633 Mdot
.54065 .4574 Mdot
.38207 .39931 Mdot
.44836 .49217 Mdot
.4124 .66744 Mdot
.67939 .43155 Mdot
.38629 .60174 Mdot
.40878 .40974 Mdot
.52946 .3302 Mdot
.54344 .31653 Mdot
.56005 .67019 Mdot
.3726 .77763 Mdot
.62759 .70518 Mdot
.60049 .61977 Mdot
.63839 .44884 Mdot
.52272 .35366 Mdot
.47351 .64163 Mdot
.63902 .64589 Mdot
.62319 .59768 Mdot
.61905 .60611 Mdot
.37355 .4719 Mdot
.64942 .41223 Mdot
.22937 .61943 Mdot
.63152 .41359 Mdot
.43306 .45322 Mdot
.63427 .45606 Mdot
.65059 .41568 Mdot
.54355 .3108 Mdot
.62898 .6318 Mdot
.62547 .44556 Mdot
.35453 .43264 Mdot
.38098 .65017 Mdot
.51842 .46349 Mdot
.48333 .24334 Mdot
.22036 .64886 Mdot
.24022 .6646 Mdot
.37953 .63615 Mdot
.37456 .80434 Mdot
.60122 .65583 Mdot
.28704 .42404 Mdot
.72701 .59865 Mdot
.34591 .43668 Mdot
.7597 .30665 Mdot
.63623 .479 Mdot
.67726 .42249 Mdot
.36259 .44637 Mdot
.6141 .39432 Mdot
.39879 .43031 Mdot
.63147 .45799 Mdot
.56377 .27312 Mdot
.40343 .36965 Mdot
.67537 .46656 Mdot
.33214 .44441 Mdot
.41687 .45841 Mdot
.42335 .6458 Mdot
.66406 .48809 Mdot
.3702 .39881 Mdot
.16478 .61077 Mdot
.5977 .6448 Mdot
.6892 .60417 Mdot
.42838 .21504 Mdot
.61663 .63222 Mdot
.38737 .65805 Mdot
.45632 .46667 Mdot
.55541 .32283 Mdot
.40614 .63044 Mdot
.53266 .23639 Mdot
.51426 .32503 Mdot
.75759 .31171 Mdot
.41667 .66997 Mdot
.6632 .49584 Mdot
.54043 .30761 Mdot
.33579 .41877 Mdot
.68828 .46141 Mdot
.47611 .5207 Mdot
.66366 .42378 Mdot
.37992 .42748 Mdot
.6943 .65725 Mdot
.61146 .64972 Mdot
.42321 .44284 Mdot
.68757 .44731 Mdot
.69839 .64253 Mdot
.37753 .47291 Mdot
.37835 .45779 Mdot
.81272 .56273 Mdot
.71998 .30294 Mdot
.55044 .33808 Mdot
.43689 .67537 Mdot
.35801 .42939 Mdot
.53309 .30635 Mdot
.63259 .35688 Mdot
.39444 .4867 Mdot
.44021 .62245 Mdot
.35732 .51247 Mdot
.67861 .47675 Mdot
.61596 .63917 Mdot
.54917 .47656 Mdot
.53648 .30362 Mdot
.44963 .13899 Mdot
.63246 .41752 Mdot
.3635 .39947 Mdot
.3847 .39638 Mdot
.76831 .58342 Mdot
.40879 .68109 Mdot
.30329 .28088 Mdot
.38985 .41376 Mdot
.36257 .52338 Mdot
.41496 .43636 Mdot
.58471 .4235 Mdot
.41422 .65757 Mdot
.3863 .42595 Mdot
.48147 .68506 Mdot
.35176 .40176 Mdot
.53812 .30117 Mdot
.19884 .45155 Mdot
.38178 .48332 Mdot
.83556 .66508 Mdot
.71947 .34142 Mdot
.67343 .46861 Mdot
.68841 .66313 Mdot
.18324 .35785 Mdot
.64833 .70181 Mdot
.42923 .67265 Mdot
.47613 .78828 Mdot
.66237 .46506 Mdot
.66247 .71538 Mdot
.3677 .808 Mdot
.41508 .46012 Mdot
.42202 .48155 Mdot
.58342 .40078 Mdot
.62465 .41517 Mdot
.67797 .49146 Mdot
.34931 .47384 Mdot
.35103 .49841 Mdot
.65623 .47369 Mdot
.35809 .42232 Mdot
.32506 .43166 Mdot
.62643 .58744 Mdot
.38056 .63766 Mdot
.58724 .62087 Mdot
.63124 .61972 Mdot
.25466 .46928 Mdot
.81232 .4578 Mdot
.59983 .64418 Mdot
.59866 .65436 Mdot
.45358 .26706 Mdot
.43352 .32918 Mdot
.50575 .33728 Mdot
.32252 .75821 Mdot
.65975 .44621 Mdot
.38706 .43819 Mdot
.37563 .63939 Mdot
.27366 .4233 Mdot
.69606 .34313 Mdot
.57735 .19711 Mdot
.41108 .4081 Mdot
.65853 .45558 Mdot
.70725 .62799 Mdot
.31834 .43764 Mdot
.60481 .4877 Mdot
.42917 .4215 Mdot
.68785 .43111 Mdot
.29755 .59916 Mdot
.43455 .73066 Mdot
.65658 .51003 Mdot
.42363 .59589 Mdot
.4194 .42221 Mdot
.40978 .67546 Mdot
.59022 .62069 Mdot
.55316 .31078 Mdot
.54891 .33831 Mdot
.38703 .45474 Mdot
.43042 .51534 Mdot
.73325 .39785 Mdot
.42197 .45679 Mdot
.39638 .46888 Mdot
.70643 .62501 Mdot
.39751 .46711 Mdot
.39199 .39569 Mdot
.4063 .39597 Mdot
.38815 .38124 Mdot
.59008 .644 Mdot
.45844 .71913 Mdot
.3483 .48141 Mdot
.32105 .43384 Mdot
.59527 .58238 Mdot
.51164 .79646 Mdot
.63331 .62425 Mdot
.43509 .82297 Mdot
.58458 .60932 Mdot
.53805 .34365 Mdot
.72607 .63906 Mdot
.44373 .50149 Mdot
.41139 .61429 Mdot
.63848 .6421 Mdot
.52498 .32327 Mdot
.60004 .62681 Mdot
.6392 .46633 Mdot
.75003 .69599 Mdot
.45868 .62431 Mdot
.33439 .26116 Mdot
.57063 .67636 Mdot
.71482 .50037 Mdot
.62431 .43251 Mdot
.41845 .65646 Mdot
.33806 .60068 Mdot
.40407 .39374 Mdot
.53222 .30783 Mdot
.3793 .44762 Mdot
.60015 .65062 Mdot
.66256 .45477 Mdot
.19748 .44517 Mdot
.55643 .32828 Mdot
.8282 .54601 Mdot
.65256 .44103 Mdot
.42676 .40085 Mdot
.59644 .6507 Mdot
.84661 .53494 Mdot
.59051 .62917 Mdot
.48032 .48439 Mdot
.41309 .60269 Mdot
.24406 .40759 Mdot
.39811 .64048 Mdot
.63718 .48714 Mdot
.75219 .72803 Mdot
.28904 .72816 Mdot
.3874 .63437 Mdot
.73046 .46718 Mdot
.41369 .48329 Mdot
.40449 .48679 Mdot
.41794 .72851 Mdot
.44262 .66215 Mdot
.36897 .41454 Mdot
.69907 .6106 Mdot
.50364 .71237 Mdot
.71618 .32232 Mdot
.67118 .42525 Mdot
.3963 .42522 Mdot
.59961 .5793 Mdot
.61251 .58543 Mdot
.63506 .41315 Mdot
.63456 .624 Mdot
.43275 .44133 Mdot
.40114 .6373 Mdot
.69303 .45617 Mdot
.54247 .33554 Mdot
.16303 .57024 Mdot
.51986 .35479 Mdot
.65714 .42362 Mdot
.39121 .37284 Mdot
.66247 .46758 Mdot
.22487 .26854 Mdot
.43158 .43441 Mdot
.38791 .67293 Mdot
.37071 .45996 Mdot
.4194 .42634 Mdot
.41856 .48429 Mdot
.64846 .47172 Mdot
.33476 .24679 Mdot
.35596 .42636 Mdot
.61408 .61475 Mdot
.26381 .67108 Mdot
.41481 .48754 Mdot
.55945 .27804 Mdot
.43639 .30533 Mdot
.74388 .45468 Mdot
.38227 .62391 Mdot
.68033 .44587 Mdot
.38348 .65329 Mdot
.43553 .59032 Mdot
.38751 .65861 Mdot
.27157 .65835 Mdot
.32873 .60371 Mdot
.38022 .21373 Mdot
.21006 .49468 Mdot
.30704 .376 Mdot
.43971 .66975 Mdot
.57368 .37687 Mdot
.42578 .62407 Mdot
.40756 .67906 Mdot
.47312 .92071 Mdot
.41109 .61671 Mdot
.39825 .4195 Mdot
.43967 .46518 Mdot
.54564 .74976 Mdot
.42258 .26439 Mdot
.39522 .46216 Mdot
.35728 .43987 Mdot
.55076 .31087 Mdot
.41789 .52906 Mdot
.65984 .57483 Mdot
.76672 .33814 Mdot
.59486 .75472 Mdot
.38065 .44958 Mdot
.35614 .4325 Mdot
.33267 .47211 Mdot
.85274 .58837 Mdot
.26714 .47095 Mdot
.44633 .66051 Mdot
.43741 .49327 Mdot
.21114 .6504 Mdot
.43916 .43261 Mdot
.36986 .47287 Mdot
.42326 .47577 Mdot
.66238 .46449 Mdot
.43764 .61618 Mdot
.42732 .49822 Mdot
.76233 .39472 Mdot
.44114 .44645 Mdot
.68234 .60813 Mdot
.2354 .31124 Mdot
.39137 .42161 Mdot
.41157 .60992 Mdot
.39921 .47914 Mdot
.42059 .66931 Mdot
.42275 .63565 Mdot
.37855 .37921 Mdot
.31009 .69723 Mdot
.425 .60752 Mdot
.43278 .45475 Mdot
.65253 .46637 Mdot
.31134 .76044 Mdot
.37968 .4251 Mdot
.55813 .33477 Mdot
.39223 .41244 Mdot
.54489 .29718 Mdot
.40464 .46785 Mdot
.63789 .41187 Mdot
.32776 .52458 Mdot
.66994 .44987 Mdot
.25604 .31382 Mdot
.65312 .40971 Mdot
.81601 .55646 Mdot
.44729 .64303 Mdot
.69396 .64799 Mdot
.51918 .16134 Mdot
.68237 .59733 Mdot
.52914 .58232 Mdot
.51967 .56319 Mdot
.61873 .59682 Mdot
.39181 .68292 Mdot
.31599 .31363 Mdot
.77012 .54955 Mdot
.75552 .59055 Mdot
.64282 .41916 Mdot
.52248 .14748 Mdot
.61389 .19832 Mdot
.3545 .44973 Mdot
.2946 .65556 Mdot
.23259 .55387 Mdot
.38782 .48471 Mdot
.45636 .46879 Mdot
.65837 .39418 Mdot
.37761 .39841 Mdot
.50363 .65361 Mdot
.65108 .42739 Mdot
.52484 .32066 Mdot
.40242 .67557 Mdot
.55833 .30337 Mdot
.76607 .56315 Mdot
.51718 .56882 Mdot
.62839 .44839 Mdot
.36435 .39248 Mdot
.36454 .45465 Mdot
.42597 .65291 Mdot
.35557 .6585 Mdot
.40422 .62221 Mdot
.53082 .35117 Mdot
.65249 .43078 Mdot
.27277 .45697 Mdot
.36124 .43357 Mdot
.40738 .64038 Mdot
.53268 .63055 Mdot
.36073 .42738 Mdot
.60518 .6336 Mdot
.43225 .46416 Mdot
.38196 .64246 Mdot
.3979 .46702 Mdot
.39951 .63653 Mdot
.67298 .43417 Mdot
.44061 .42795 Mdot
.36506 .44584 Mdot
.83871 .54741 Mdot
.53146 .34091 Mdot
.44546 .65471 Mdot
.62025 .38565 Mdot
.41083 .39194 Mdot
.70752 .5362 Mdot
.41752 .41841 Mdot
.40818 .58194 Mdot
.35667 .40351 Mdot
.70423 .6334 Mdot
.45304 .44492 Mdot
.38056 .42536 Mdot
.50298 .60706 Mdot
.24129 .58912 Mdot
.35331 .66259 Mdot
.58621 .64434 Mdot
.4259 .61576 Mdot
.66147 .29145 Mdot
.65215 .49241 Mdot
.6841 .44396 Mdot
.36875 .26913 Mdot
.4142 .38089 Mdot
.39783 .43619 Mdot
.62658 .58092 Mdot
.51798 .32685 Mdot
.41243 .64453 Mdot
.52751 .31606 Mdot
.77871 .39966 Mdot
.51686 .34508 Mdot
.61448 .43044 Mdot
.74144 .39903 Mdot
.29487 .5023 Mdot
.55012 .3108 Mdot
.39224 .62601 Mdot
.62183 .26968 Mdot
.34251 .43526 Mdot
.50255 .36422 Mdot
.53091 .32985 Mdot
.51305 .13917 Mdot
.38743 .39739 Mdot
.53554 .5772 Mdot
.60488 .64305 Mdot
.53776 .31037 Mdot
.60988 .59717 Mdot
.39141 .46068 Mdot
.7006 .52324 Mdot
.43594 .66779 Mdot
.57217 .60304 Mdot
.38284 .49029 Mdot
.52349 .34661 Mdot
.63195 .43427 Mdot
.58599 .66406 Mdot
.5712 .62211 Mdot
.47441 .80155 Mdot
.21682 .41604 Mdot
.65384 .43179 Mdot
.63012 .2401 Mdot
.59011 .59517 Mdot
.37547 .4781 Mdot
.38598 .53607 Mdot
.43304 .42861 Mdot
.66185 .67333 Mdot
.68062 .44185 Mdot
.50089 .73516 Mdot
.36618 .45788 Mdot
.41047 .402 Mdot
.36264 .68384 Mdot
.6667 .44078 Mdot
.39998 .65797 Mdot
.42364 .61649 Mdot
.67214 .43432 Mdot
.39352 .64777 Mdot
.51562 .32018 Mdot
.51533 .70766 Mdot
.58225 .60157 Mdot
.61156 .61149 Mdot
.65728 .45007 Mdot
.66838 .47248 Mdot
.66723 .46687 Mdot
.43273 .46339 Mdot
.41372 .65105 Mdot
.41706 .47189 Mdot
.41901 .48359 Mdot
.35754 .70293 Mdot
.38351 .62681 Mdot
.41248 .48053 Mdot
.62157 .48883 Mdot
.50526 .36314 Mdot
.64934 .46632 Mdot
.60365 .64468 Mdot
.65804 .73674 Mdot
.5633 .61999 Mdot
.39942 .42587 Mdot
.79841 .47959 Mdot
.39357 .62819 Mdot
.54996 .3173 Mdot
.51228 .31569 Mdot
.55311 .32699 Mdot
.61596 .56995 Mdot
.44177 .64264 Mdot
.76572 .33569 Mdot
.39635 .42813 Mdot
.59203 .53793 Mdot
.29654 .32471 Mdot
.76883 .42507 Mdot
.60349 .64569 Mdot
.3581 .43131 Mdot
.54353 .47281 Mdot
.34618 .57983 Mdot
.42764 .42497 Mdot
.33795 .432 Mdot
.70054 .58745 Mdot
.33265 .48731 Mdot
.41795 .6036 Mdot
.81814 .43916 Mdot
.44101 .47037 Mdot
.38841 .73051 Mdot
.14326 .48652 Mdot
.40766 .42674 Mdot
.40267 .40537 Mdot
.37112 .43124 Mdot
.38005 .46725 Mdot
.41029 .60868 Mdot
.37045 .28758 Mdot
.6093 .65555 Mdot
.58581 .52106 Mdot
.57881 .60433 Mdot
.68936 .44008 Mdot
.47759 .70477 Mdot
.38311 .67891 Mdot
.54886 .31421 Mdot
.37412 .75074 Mdot
.79844 .39017 Mdot
.62684 .46302 Mdot
.29675 .53325 Mdot
.53368 .33584 Mdot
.3666 .47397 Mdot
.54641 .29388 Mdot
.65265 .41139 Mdot
.62027 .61364 Mdot
.43794 .38856 Mdot
.41294 .62047 Mdot
.37717 .66037 Mdot
.36776 .41656 Mdot
.24059 .68749 Mdot
.60861 .63617 Mdot
.62224 .66371 Mdot
.38433 .47808 Mdot
.3352 .44197 Mdot
.39772 .66083 Mdot
.64565 .45152 Mdot
.56931 .24572 Mdot
.52119 .3353 Mdot
.4143 .38858 Mdot
.38351 .46897 Mdot
.81445 .4447 Mdot
.62574 .6294 Mdot
.61838 .44741 Mdot
.37036 .46883 Mdot
.66923 .68502 Mdot
.37136 .46909 Mdot
.31529 .44721 Mdot
.65342 .46437 Mdot
.36489 .50067 Mdot
.35242 .43103 Mdot
.47561 .3973 Mdot
.59977 .59294 Mdot
.3895 .67173 Mdot
.36993 .63452 Mdot
.56126 .42388 Mdot
.60273 .63203 Mdot
.40681 .48065 Mdot
.6225 .63266 Mdot
.40437 .48885 Mdot
.36779 .41293 Mdot
.59638 .64189 Mdot
.39955 .6574 Mdot
.49866 .78067 Mdot
.46612 .71409 Mdot
.37685 .46591 Mdot
.44743 .45734 Mdot
.39293 .27077 Mdot
.4343 .1889 Mdot
.41332 .4119 Mdot
.37906 .64974 Mdot
.36036 .43903 Mdot
.60283 .5978 Mdot
.51282 .33703 Mdot
.38114 .64756 Mdot
.64367 .44315 Mdot
.62158 .44639 Mdot
.62726 .72109 Mdot
.65541 .41636 Mdot
.34534 .44833 Mdot
.4445 .5943 Mdot
.37554 .68408 Mdot
.14581 .522 Mdot
.67021 .43505 Mdot
.51475 .31641 Mdot
.38179 .45802 Mdot
.80462 .53608 Mdot
.63104 .58471 Mdot
.86089 .63544 Mdot
.76047 .31957 Mdot
.52586 .35613 Mdot
.55594 .18256 Mdot
.69126 .45515 Mdot
.36507 .40982 Mdot
.55407 .31087 Mdot
.63264 .46953 Mdot
.34798 .446 Mdot
.44894 .3944 Mdot
.3114 .26956 Mdot
.55532 .43968 Mdot
.62193 .63565 Mdot
.6745 .4766 Mdot
.53797 .29006 Mdot
.617 .42579 Mdot
.37598 .66195 Mdot
.38313 .42802 Mdot
.47503 .45391 Mdot
.64347 .44765 Mdot
.62262 .41767 Mdot
.42686 .46908 Mdot
.39509 .68393 Mdot
.64023 .39252 Mdot
.38791 .45153 Mdot
.29787 .3973 Mdot
.42615 .59779 Mdot
.64695 .42854 Mdot
.40854 .39857 Mdot
.46752 .33166 Mdot
.65113 .44489 Mdot
.6476 .46593 Mdot
.36723 .41584 Mdot
.51789 .31685 Mdot
.44647 .42604 Mdot
.58335 .61442 Mdot
.30011 .26178 Mdot
.6071 .5993 Mdot
.65021 .29892 Mdot
.36117 .38523 Mdot
.66822 .52614 Mdot
.37366 .66017 Mdot
.52532 .29406 Mdot
.67662 .73571 Mdot
.3403 .46468 Mdot
.36598 .78743 Mdot
.53831 .4866 Mdot
.20283 .65031 Mdot
.64869 .78116 Mdot
.53334 .32656 Mdot
.59584 .62399 Mdot
.40248 .40586 Mdot
.6391 .61308 Mdot
.55921 .32087 Mdot
.2486 .36088 Mdot
.40344 .39686 Mdot
.41359 .65983 Mdot
.43458 .45581 Mdot
.41199 .67251 Mdot
.36374 .42285 Mdot
.32202 .44786 Mdot
.71555 .63503 Mdot
.51409 .24137 Mdot
.34522 .43489 Mdot
.75963 .68857 Mdot
.71208 .36281 Mdot
.52574 .33084 Mdot
.42106 .46545 Mdot
.63921 .48582 Mdot
.61475 .58782 Mdot
.46272 .59004 Mdot
.66085 .46613 Mdot
.62887 .63943 Mdot
.3924 .65866 Mdot
.6726 .42901 Mdot
.62141 .4302 Mdot
.41903 .4975 Mdot
.54787 .29941 Mdot
.6238 .61127 Mdot
.38405 .42263 Mdot
.39445 .39757 Mdot
.63659 .25053 Mdot
.67981 .33757 Mdot
.36061 .6601 Mdot
.85305 .4822 Mdot
.36498 .6586 Mdot
.52666 .34229 Mdot
.65682 .46724 Mdot
.41364 .41516 Mdot
.42292 .44529 Mdot
.69691 .64871 Mdot
.43622 .67029 Mdot
.55034 .45082 Mdot
.26168 .49665 Mdot
.6387 .39513 Mdot
.42524 .29135 Mdot
.38655 .67393 Mdot
.42474 .28975 Mdot
.53935 .29033 Mdot
.35395 .75635 Mdot
.49893 .25344 Mdot
.60818 .64374 Mdot
.4196 .29264 Mdot
.41429 .63249 Mdot
.35755 .4522 Mdot
.66094 .49405 Mdot
.6498 .41649 Mdot
.3979 .66932 Mdot
.6741 .40378 Mdot
.54097 .31193 Mdot
.3968 .40307 Mdot
.74887 .32702 Mdot
.56798 .72135 Mdot
.63948 .45305 Mdot
.31933 .42248 Mdot
.61686 .60479 Mdot
.37132 .40716 Mdot
.5563 .33775 Mdot
.61641 .62532 Mdot
.70427 .32631 Mdot
.50277 .72287 Mdot
.38985 .45708 Mdot
.81625 .52472 Mdot
.60817 .63163 Mdot
.52255 .18263 Mdot
.38558 .44597 Mdot
.59097 .59481 Mdot
.35861 .50817 Mdot
.75805 .44913 Mdot
.53655 .45608 Mdot
.36383 .8084 Mdot
.54856 .46319 Mdot
.67587 .48816 Mdot
.75736 .49609 Mdot
.74743 .56639 Mdot
.63712 .60686 Mdot
.62093 .42028 Mdot
.49303 .30584 Mdot
.61069 .59683 Mdot
.42333 .48144 Mdot
.41399 .42232 Mdot
.25897 .45565 Mdot
.53702 .49972 Mdot
.61369 .45394 Mdot
.59594 .69625 Mdot
.41287 .39279 Mdot
.41537 .49582 Mdot
.41551 .44716 Mdot
.45492 .65142 Mdot
.62385 .62221 Mdot
.80651 .61438 Mdot
.59952 .63185 Mdot
.70252 .27232 Mdot
.66072 .44767 Mdot
.68158 .45575 Mdot
.39485 .42256 Mdot
.66983 .51533 Mdot
.38498 .31602 Mdot
.43282 .4443 Mdot
.64078 .52108 Mdot
.19015 .46594 Mdot
.39449 .49413 Mdot
.40866 .60211 Mdot
.36879 .36876 Mdot
.45857 .64546 Mdot
.58479 .59683 Mdot
.54059 .32639 Mdot
.51131 .30375 Mdot
.62299 .61402 Mdot
.39879 .43774 Mdot
.65696 .53681 Mdot
.42127 .43184 Mdot
.35991 .45889 Mdot
.69755 .26007 Mdot
.52726 .35535 Mdot
.67557 .45796 Mdot
.55304 .33467 Mdot
.4095 .67964 Mdot
.68116 .84517 Mdot
.51887 .32389 Mdot
.37929 .32046 Mdot
.26112 .32248 Mdot
.41606 .29142 Mdot
.37817 .66704 Mdot
.56958 .32298 Mdot
.61286 .63892 Mdot
.25316 .73083 Mdot
.40781 .19134 Mdot
.587 .65973 Mdot
.39455 .4501 Mdot
.39144 .68526 Mdot
.38801 .62743 Mdot
.57266 .60421 Mdot
.42059 .63502 Mdot
.41183 .51084 Mdot
.36709 .46137 Mdot
.63819 .61603 Mdot
.56154 .74027 Mdot
.571 .62207 Mdot
.51246 .68637 Mdot
.42516 .46394 Mdot
.38178 .66691 Mdot
.37111 .36947 Mdot
.43903 .68809 Mdot
.61824 .44968 Mdot
.37707 .48131 Mdot
.54321 .31164 Mdot
.62073 .54347 Mdot
.65254 .43419 Mdot
.79661 .48227 Mdot
.42479 .65623 Mdot
.54378 .6074 Mdot
.42355 .64323 Mdot
.42409 .68858 Mdot
.63147 .61747 Mdot
.43815 .65677 Mdot
.40155 .40443 Mdot
.63694 .498 Mdot
.42673 .66517 Mdot
.59953 .60914 Mdot
.54559 .32839 Mdot
.39566 .64974 Mdot
.61842 .38948 Mdot
.37274 .4534 Mdot
.63991 .47146 Mdot
.72728 .62789 Mdot
.4066 .68921 Mdot
.56649 .33519 Mdot
.68047 .43287 Mdot
.55169 .30262 Mdot
.1745 .48518 Mdot
.62895 .64687 Mdot
.58717 .20482 Mdot
.47105 .33502 Mdot
.4053 .61843 Mdot
.72254 .63091 Mdot
.41091 .41661 Mdot
.37448 .45544 Mdot
.56109 .30074 Mdot
.38839 .62697 Mdot
.28673 .73407 Mdot
.3475 .65962 Mdot
.51393 .71988 Mdot
.6331 .64606 Mdot
.80251 .59799 Mdot
.50112 .67323 Mdot
.20278 .3797 Mdot
.37925 .49737 Mdot
.68964 .46559 Mdot
.40564 .43456 Mdot
.66385 .74183 Mdot
.52611 .34873 Mdot
.59243 .31336 Mdot
.35798 .39278 Mdot
.67762 .44219 Mdot
.37292 .43999 Mdot
.47703 .56629 Mdot
.33608 .39212 Mdot
.51076 .32741 Mdot
.67532 .60651 Mdot
.41475 .61447 Mdot
.53969 .33629 Mdot
.6305 .42303 Mdot
.40302 .3089 Mdot
.34783 .43169 Mdot
.34866 .47723 Mdot
.63366 .39545 Mdot
.41689 .65663 Mdot
.67383 .48577 Mdot
.58331 .60052 Mdot
.53957 .31789 Mdot
.38162 .46183 Mdot
.35834 .39996 Mdot
.70871 .53734 Mdot
.62557 .61106 Mdot
.65718 .39876 Mdot
.59099 .62805 Mdot
.67889 .48879 Mdot
.45035 .44386 Mdot
.68219 .45384 Mdot
.3602 .41046 Mdot
.70416 .70074 Mdot
.691 .25668 Mdot
.25609 .60722 Mdot
.67848 .43477 Mdot
.45481 .29333 Mdot
.59885 .6013 Mdot
.58545 .61153 Mdot
.25936 .38944 Mdot
.42731 .53317 Mdot
.68052 .28998 Mdot
.49125 .80905 Mdot
.57932 .60461 Mdot
.61021 .60332 Mdot
.63641 .46984 Mdot
.4356 .66216 Mdot
.40931 .69273 Mdot
.68919 .43585 Mdot
.42392 .22416 Mdot
.41231 .64445 Mdot
.34942 .7705 Mdot
.68273 .30081 Mdot
.43384 .49156 Mdot
.56468 .65946 Mdot
.54403 .31961 Mdot
.43939 .22761 Mdot
.48089 .57739 Mdot
.41022 .4039 Mdot
.81772 .45595 Mdot
.65 .45351 Mdot
.34988 .28232 Mdot
.43827 .82281 Mdot
.40013 .3958 Mdot
.38622 .43995 Mdot
.40638 .44167 Mdot
.54 .35542 Mdot
.35279 .53716 Mdot
.39787 .39896 Mdot
.42324 .22203 Mdot
.41083 .3908 Mdot
.48848 .37223 Mdot
.55021 .33759 Mdot
.40939 .34811 Mdot
.69955 .60449 Mdot
.76719 .38159 Mdot
.4338 .37179 Mdot
.58317 .60286 Mdot
.58512 .49723 Mdot
.60127 .59082 Mdot
.26564 .64786 Mdot
.49259 .25404 Mdot
.388 .6083 Mdot
.40818 .40482 Mdot
.65592 .42371 Mdot
.38628 .62991 Mdot
.74336 .52935 Mdot
.53221 .92831 Mdot
.59112 .59127 Mdot
.24807 .25709 Mdot
.58563 .619 Mdot
.62356 .42435 Mdot
.39696 .66218 Mdot
.32336 .60327 Mdot
.58678 .53875 Mdot
.39547 .64666 Mdot
.49057 .76934 Mdot
.38688 .69938 Mdot
.43817 .29658 Mdot
.3703 .67277 Mdot
.59854 .60639 Mdot
.58553 .57875 Mdot
.47011 .44808 Mdot
.40101 .4167 Mdot
.51383 .56847 Mdot
.41772 .32148 Mdot
.40614 .41609 Mdot
.65216 .42843 Mdot
.50899 .17483 Mdot
.57027 .41246 Mdot
.43161 .63608 Mdot
.57567 .63945 Mdot
.38307 .43954 Mdot
.37719 .46986 Mdot
.3488 .43982 Mdot
.85899 .48421 Mdot
.33395 .75219 Mdot
.35607 .42675 Mdot
.42685 .39594 Mdot
.67442 .4319 Mdot
.57609 .30247 Mdot
.64176 .76097 Mdot
.48933 .39314 Mdot
.4295 .41413 Mdot
.5406 .34044 Mdot
.50959 .35248 Mdot
.34755 .44608 Mdot
.75716 .39289 Mdot
.69835 .50733 Mdot
.38353 .42267 Mdot
.47159 .4903 Mdot
.76211 .5565 Mdot
.62306 .41807 Mdot
.64536 .44611 Mdot
.41268 .61054 Mdot
.65137 .41941 Mdot
.65177 .4092 Mdot
.32767 .58129 Mdot
.56316 .48862 Mdot
.64788 .58828 Mdot
.53142 .35131 Mdot
.424 .44154 Mdot
.36595 .6756 Mdot
.68068 .66289 Mdot
.62156 .60087 Mdot
.39162 .63525 Mdot
.61118 .58646 Mdot
.53904 .35938 Mdot
.32829 .27083 Mdot
.64622 .41549 Mdot
.5755 .61317 Mdot
.50287 .72147 Mdot
.54335 .34014 Mdot
.62894 .63497 Mdot
.6734 .53084 Mdot
.41946 .48536 Mdot
.32768 .67496 Mdot
.43178 .4503 Mdot
.24225 .69951 Mdot
.62739 .63583 Mdot
.70213 .63447 Mdot
.39246 .43283 Mdot
.65324 .44239 Mdot
.3256 .46879 Mdot
.42971 .42087 Mdot
.63977 .44048 Mdot
.35481 .44976 Mdot
.56247 .3223 Mdot
.44335 .60329 Mdot
.57828 .49774 Mdot
.69118 .20993 Mdot
.55125 .29964 Mdot
.73558 .52914 Mdot
.41277 .4104 Mdot
.20132 .439 Mdot
.39693 .64839 Mdot
.35934 .40598 Mdot
.34002 .34012 Mdot
.4254 .67252 Mdot
.38574 .64667 Mdot
.40007 .47444 Mdot
.60497 .64155 Mdot
.64938 .43483 Mdot
.54866 .33719 Mdot
.16729 .46868 Mdot
.40496 .45323 Mdot
.36265 .44322 Mdot
.53574 .33611 Mdot
.60927 .60106 Mdot
.38244 .47317 Mdot
.73949 .64315 Mdot
.17215 .61795 Mdot
.62608 .60133 Mdot
.44106 .45658 Mdot
.33978 .67432 Mdot
.46083 .65375 Mdot
.32436 .21208 Mdot
.56041 .25752 Mdot
.67817 .45857 Mdot
.34347 .50041 Mdot
.76885 .75076 Mdot
.54247 .32604 Mdot
.76794 .3568 Mdot
.35975 .46072 Mdot
.36482 .43088 Mdot
.40038 .62447 Mdot
.41639 .47606 Mdot
.42179 .68016 Mdot
.64724 .18846 Mdot
.82761 .46754 Mdot
.41838 .6632 Mdot
.41317 .61869 Mdot
.36493 .32895 Mdot
.64619 .75714 Mdot
.39518 .66903 Mdot
.44851 .41356 Mdot
.2922 .71123 Mdot
.46926 .38234 Mdot
.55946 .29856 Mdot
.74058 .60639 Mdot
.42344 .70803 Mdot
.58102 .38566 Mdot
.48484 .79449 Mdot
.41698 .71318 Mdot
.71415 .48369 Mdot
.58206 .61802 Mdot
.41453 .39683 Mdot
.65283 .41594 Mdot
.68379 .4453 Mdot
.33738 .39534 Mdot
.42562 .43416 Mdot
.41844 .67142 Mdot
.52148 .35172 Mdot
.62877 .59508 Mdot
.35761 .44094 Mdot
.57251 .41366 Mdot
.51984 .32774 Mdot
.43277 .6456 Mdot
.27617 .36954 Mdot
.51162 .32208 Mdot
.34148 .37928 Mdot
.38494 .41353 Mdot
.42563 .47247 Mdot
.48549 .41637 Mdot
.59358 .6436 Mdot
.72548 .6449 Mdot
.44634 .44143 Mdot
.78055 .40079 Mdot
.50807 .46549 Mdot
.35919 .49992 Mdot
.41741 .64211 Mdot
.63193 .58466 Mdot
.62828 .47373 Mdot
.3253 .31932 Mdot
.39664 .45602 Mdot
.32809 .7434 Mdot
.26356 .47747 Mdot
.6277 .47001 Mdot
.43975 .66883 Mdot
.55106 .31963 Mdot
.43178 .44206 Mdot
.27967 .6801 Mdot
.40971 .424 Mdot
.47999 .34902 Mdot
.64843 .46222 Mdot
.58264 .62176 Mdot
.19501 .64268 Mdot
.68377 .44661 Mdot
.38384 .65154 Mdot
.38026 .82996 Mdot
.37979 .68172 Mdot
.42982 .62508 Mdot
.30387 .6974 Mdot
.58599 .6366 Mdot
.78883 .73156 Mdot
.3862 .19181 Mdot
.33528 .42614 Mdot
.5956 .60013 Mdot
.40441 .66847 Mdot
.37312 .40622 Mdot
.37184 .64989 Mdot
.44418 .6489 Mdot
.43031 .48695 Mdot
.37298 .41854 Mdot
.48002 .69798 Mdot
.38983 .80484 Mdot
.55381 .32279 Mdot
.39671 .68147 Mdot
.29497 .38019 Mdot
.3787 .40044 Mdot
.39557 .4279 Mdot
.76101 .53747 Mdot
.51633 .31794 Mdot
.49696 .63054 Mdot
.36656 .46564 Mdot
.8287 .49475 Mdot
.37175 .36775 Mdot
.41152 .60759 Mdot
.6272 .6045 Mdot
.76071 .37487 Mdot
.65369 .67558 Mdot
.43308 .67419 Mdot
.54758 .34668 Mdot
.36897 .63522 Mdot
.38353 .3208 Mdot
.57595 .62883 Mdot
.38199 .64237 Mdot
.5482 .47584 Mdot
.60975 .62171 Mdot
.62442 .63836 Mdot
.2659 .67406 Mdot
.66209 .40337 Mdot
.55555 .34617 Mdot
.62066 .60835 Mdot
.28782 .42341 Mdot
.59502 .61444 Mdot
.26719 .41384 Mdot
.44223 .43179 Mdot
.37541 .24889 Mdot
.53625 .58999 Mdot
.44564 .49797 Mdot
.60784 .65053 Mdot
.55852 .32328 Mdot
.39198 .47422 Mdot
.41879 .63182 Mdot
.52389 .31788 Mdot
.56491 .65099 Mdot
.6562 .47262 Mdot
.42581 .64368 Mdot
.61878 .6568 Mdot
.3927 .67843 Mdot
.32115 .3081 Mdot
.28621 .27321 Mdot
.76586 .61482 Mdot
.58124 .53652 Mdot
.34936 .44352 Mdot
.54959 .79865 Mdot
.44261 .47936 Mdot
.4264 .42927 Mdot
.64764 .42931 Mdot
.3654 .26927 Mdot
.39965 .65844 Mdot
.19862 .65166 Mdot
.57764 .61377 Mdot
.82255 .44595 Mdot
.3764 .60543 Mdot
.35703 .407 Mdot
.42515 .66837 Mdot
.37489 .67727 Mdot
.23587 .58474 Mdot
.61265 .43121 Mdot
.45915 .41612 Mdot
.46509 .44073 Mdot
.36382 .49204 Mdot
.62251 .63881 Mdot
.79377 .47104 Mdot
.68281 .47698 Mdot
.28925 .25589 Mdot
.64483 .4593 Mdot
.62534 .52387 Mdot
.43762 .65217 Mdot
.51874 .32059 Mdot
.39342 .42652 Mdot
.36371 .61885 Mdot
.43216 .67652 Mdot
.52013 .36478 Mdot
.53932 .3088 Mdot
.76626 .47401 Mdot
.59662 .64251 Mdot
.34491 .4295 Mdot
.40742 .3988 Mdot
.41516 .47024 Mdot
.43762 .4461 Mdot
.58959 .59173 Mdot
.39681 .48384 Mdot
.60186 .57654 Mdot
.28393 .42408 Mdot
.82152 .46916 Mdot
.55979 .48639 Mdot
.43637 .56796 Mdot
.42448 .63074 Mdot
.29187 .42271 Mdot
.34024 .37892 Mdot
.65856 .23399 Mdot
.1848 .56332 Mdot
.38952 .49119 Mdot
.6379 .47492 Mdot
.41852 .53924 Mdot
.66063 .41201 Mdot
.32204 .18333 Mdot
.70369 .54531 Mdot
.36581 .80111 Mdot
.38518 .40085 Mdot
.76313 .53961 Mdot
.34393 .51339 Mdot
.4536 .46495 Mdot
.73369 .54954 Mdot
.64802 .69551 Mdot
.5228 .75511 Mdot
.50697 .34566 Mdot
.37756 .45214 Mdot
.38031 .69139 Mdot
.40028 .40311 Mdot
.40097 .43018 Mdot
.35924 .4616 Mdot
.60252 .65416 Mdot
.44324 .39579 Mdot
.43502 .46167 Mdot
.69586 .37736 Mdot
.45215 .27247 Mdot
.67582 .47694 Mdot
.25608 .38575 Mdot
.52011 .32365 Mdot
.42434 .66396 Mdot
.44085 .76119 Mdot
.60832 .64407 Mdot
.23124 .56689 Mdot
.43459 .45878 Mdot
.48713 .71027 Mdot
.62338 .65657 Mdot
.53947 .31543 Mdot
.66636 .49658 Mdot
.33297 .78657 Mdot
.65956 .42602 Mdot
.54666 .47966 Mdot
.65586 .43857 Mdot
.39124 .35996 Mdot
.41727 .67254 Mdot
.354 .4582 Mdot
.61868 .6088 Mdot
.64237 .43086 Mdot
.40899 .26449 Mdot
.41438 .44593 Mdot
.67302 .43616 Mdot
.35578 .46003 Mdot
.33953 .25924 Mdot
.59614 .22909 Mdot
.64459 .40943 Mdot
.62459 .57453 Mdot
.60596 .61682 Mdot
.51592 .32081 Mdot
.42921 .65238 Mdot
.40281 .62549 Mdot
.61443 .62583 Mdot
.4381 .18078 Mdot
.42883 .41512 Mdot
.37688 .40338 Mdot
.78257 .40025 Mdot
.40296 .41005 Mdot
.42481 .30778 Mdot
.54236 .46878 Mdot
.43018 .63822 Mdot
.36385 .41397 Mdot
.37983 .46972 Mdot
.38557 .45751 Mdot
.31177 .30926 Mdot
.64277 .45144 Mdot
.42883 .4058 Mdot
.54302 .30619 Mdot
.64512 .49358 Mdot
.37325 .40423 Mdot
.36074 .49049 Mdot
.40105 .62634 Mdot
.82798 .42232 Mdot
.58807 .62899 Mdot
.62635 .42952 Mdot
.68146 .44884 Mdot
.74321 .60306 Mdot
.36974 .71702 Mdot
.54266 .46543 Mdot
.27176 .27332 Mdot
.70502 .62088 Mdot
.52911 .33604 Mdot
.62917 .53531 Mdot
.51376 .44434 Mdot
.62574 .45535 Mdot
.60234 .58558 Mdot
.44465 .43864 Mdot
.43247 .41678 Mdot
.75039 .30118 Mdot
.35374 .40928 Mdot
.54851 .3203 Mdot
.58899 .58399 Mdot
.41299 .63308 Mdot
.5415 .3147 Mdot
.58649 .6155 Mdot
.41773 .65424 Mdot
.4227 .48585 Mdot
.43232 .47864 Mdot
.39158 .63715 Mdot
.39011 .6271 Mdot
.38547 .41899 Mdot
.66732 .5065 Mdot
.41587 .61222 Mdot
.37911 .66161 Mdot
.64717 .41462 Mdot
.64617 .41937 Mdot
.41166 .50211 Mdot
.59161 .60527 Mdot
.42203 .47988 Mdot
.66657 .42512 Mdot
.51528 .34661 Mdot
.40077 .6518 Mdot
.37504 .46598 Mdot
.3583 .44867 Mdot
.54489 .33846 Mdot
.5118 .35015 Mdot
.53826 .31165 Mdot
.5773 .59129 Mdot
.416 .46304 Mdot
.39218 .66414 Mdot
.5886 .63628 Mdot
.50947 .35258 Mdot
.53671 .29625 Mdot
.67882 .40127 Mdot
.41551 .41423 Mdot
.63349 .38572 Mdot
.67599 .84413 Mdot
.47606 .3042 Mdot
.62427 .46712 Mdot
.64514 .39695 Mdot
.41693 .27998 Mdot
.67261 .51054 Mdot
.6123 .63426 Mdot
.48486 .31187 Mdot
.523 .2954 Mdot
.37923 .48173 Mdot
.44666 .45647 Mdot
.46258 .45883 Mdot
.53097 .31807 Mdot
.33839 .30911 Mdot
.37239 .65892 Mdot
.2303 .47644 Mdot
.52129 .32212 Mdot
.6241 .41513 Mdot
.66587 .40319 Mdot
.64524 .46012 Mdot
.44419 .45681 Mdot
.25293 .59696 Mdot
.32841 .36945 Mdot
.54819 .80537 Mdot
.61946 .64608 Mdot
.38359 .61011 Mdot
.18403 .46666 Mdot
.3886 .64267 Mdot
.679 .41989 Mdot
.52543 .32198 Mdot
.38063 .64229 Mdot
.61277 .59171 Mdot
.61218 .60503 Mdot
.64181 .45494 Mdot
.65879 .45122 Mdot
.636 .46409 Mdot
.43739 .6347 Mdot
.43791 .65586 Mdot
.40424 .45599 Mdot
.40302 .64055 Mdot
.79315 .34936 Mdot
.54664 .35514 Mdot
.65144 .39541 Mdot
.59452 .62388 Mdot
.41399 .67131 Mdot
.4181 .44738 Mdot
.56498 .43603 Mdot
.61221 .71925 Mdot
.5557 .30473 Mdot
.62035 .24152 Mdot
.3135 .19271 Mdot
.3468 .4209 Mdot
.62402 .63408 Mdot
.74225 .32282 Mdot
.40648 .44374 Mdot
.65816 .46339 Mdot
.70146 .71102 Mdot
.65195 .49257 Mdot
.42086 .4821 Mdot
.34182 .4233 Mdot
.63455 .62178 Mdot
.25072 .33035 Mdot
.41082 .45519 Mdot
.5187 .65159 Mdot
.5714 .63524 Mdot
.68829 .45876 Mdot
.17714 .63259 Mdot
.7655 .586 Mdot
.4317 .22729 Mdot
.64278 .41707 Mdot
.41897 .42512 Mdot
.63855 .42327 Mdot
.55639 .30738 Mdot
.63037 .43198 Mdot
.41632 .60036 Mdot
.67745 .47816 Mdot
.36302 .44201 Mdot
.39514 .67069 Mdot
.60761 .63213 Mdot
.81396 .4269 Mdot
.68725 .363 Mdot
.65362 .44334 Mdot
.63211 .41691 Mdot
.3548 .42436 Mdot
.49569 .65225 Mdot
.32955 .42826 Mdot
.38282 .40029 Mdot
.57647 .60648 Mdot
.42851 .66398 Mdot
.61385 .6537 Mdot
.38711 .38846 Mdot
.73825 .66192 Mdot
.59431 .63325 Mdot
.48066 .71449 Mdot
.53287 .33609 Mdot
.4876 .53853 Mdot
.42516 .44373 Mdot
.61908 .6024 Mdot
.41726 .46299 Mdot
.37301 .64264 Mdot
.52198 .51961 Mdot
.68661 .66703 Mdot
.61772 .61069 Mdot
.27325 .72116 Mdot
.69922 .4479 Mdot
.40065 .37063 Mdot
.59377 .59316 Mdot
.34057 .34131 Mdot
.62189 .42772 Mdot
.5228 .33574 Mdot
.50896 .35136 Mdot
.54764 .30144 Mdot
.34869 .47006 Mdot
.40794 .36744 Mdot
.55884 .33898 Mdot
.62404 .59573 Mdot
.50949 .33196 Mdot
.37254 .73103 Mdot
.28058 .73101 Mdot
.52947 .34878 Mdot
.38694 .44841 Mdot
.47601 .41771 Mdot
.44705 .27002 Mdot
.6195 .39309 Mdot
.37128 .79404 Mdot
.43785 .57624 Mdot
.40246 .41842 Mdot
.46466 .65208 Mdot
.37414 .65133 Mdot
.73811 .32607 Mdot
.43341 .32354 Mdot
.74459 .37717 Mdot
.41704 .61814 Mdot
.69398 .65069 Mdot
.43119 .64521 Mdot
.35067 .41832 Mdot
.37241 .40972 Mdot
.41176 .69358 Mdot
.80373 .47431 Mdot
.71404 .51898 Mdot
.16582 .57285 Mdot
.37944 .6665 Mdot
.60107 .59301 Mdot
.58111 .59791 Mdot
.61572 .64673 Mdot
.66979 .29259 Mdot
.40645 .68727 Mdot
.40756 .46336 Mdot
.67455 .42927 Mdot
.42541 .40674 Mdot
.61662 .61934 Mdot
.20297 .65707 Mdot
.40704 .62722 Mdot
.38137 .42476 Mdot
.43149 .19218 Mdot
.66454 .45724 Mdot
.53632 .3422 Mdot
.3183 .27309 Mdot
.71103 .32945 Mdot
.58205 .63533 Mdot
.39275 .68985 Mdot
.68337 .60714 Mdot
.46846 .72394 Mdot
.39323 .50131 Mdot
.39601 .50916 Mdot
.18597 .41735 Mdot
.69756 .3219 Mdot
.35394 .46238 Mdot
.62356 .4325 Mdot
.69791 .64836 Mdot
.37207 .46085 Mdot
.37821 .67022 Mdot
.5036 .33739 Mdot
.53624 .30523 Mdot
.45768 .42887 Mdot
.595 .53707 Mdot
.49571 .50482 Mdot
.40637 .48146 Mdot
.34202 .37848 Mdot
.67775 .42055 Mdot
.7008 .61429 Mdot
.79773 .4164 Mdot
.54292 .34976 Mdot
.3678 .4685 Mdot
.53252 .7721 Mdot
.44203 .65627 Mdot
.6603 .48528 Mdot
.57703 .63227 Mdot
.29673 .32114 Mdot
.686 .46886 Mdot
.37103 .46114 Mdot
.38169 .4724 Mdot
.63002 .63391 Mdot
.4115 .6075 Mdot
.52953 .31983 Mdot
.67929 .43516 Mdot
.5456 .34881 Mdot
.42125 .67797 Mdot
.40879 .62946 Mdot
.46519 .37651 Mdot
.42985 .37987 Mdot
.64511 .4442 Mdot
.38965 .38985 Mdot
.6096 .39916 Mdot
.24784 .32946 Mdot
.63854 .64222 Mdot
.34675 .41976 Mdot
.45053 .63405 Mdot
.62102 .61329 Mdot
.36946 .42645 Mdot
.16676 .44451 Mdot
.38662 .39467 Mdot
.65735 .67352 Mdot
.7633 .63838 Mdot
.55356 .31475 Mdot
.20969 .47174 Mdot
.4497 .70822 Mdot
.39823 .40877 Mdot
.66471 .47486 Mdot
.32346 .45638 Mdot
.6077 .64028 Mdot
.43455 .6414 Mdot
.3327 .20259 Mdot
.59734 .61349 Mdot
.39087 .40197 Mdot
.53958 .31697 Mdot
.38173 .68494 Mdot
.59395 .50393 Mdot
.77232 .40306 Mdot
.35823 .38055 Mdot
.44667 .40823 Mdot
.41648 .48292 Mdot
.6857 .74614 Mdot
.62617 .43179 Mdot
.40864 .67071 Mdot
.62162 .6389 Mdot
.61623 .62755 Mdot
.64496 .45497 Mdot
.5252 .74522 Mdot
.48995 .53611 Mdot
.71886 .79503 Mdot
.63811 .43802 Mdot
.56812 .33275 Mdot
.50524 .64572 Mdot
.66438 .47662 Mdot
.67214 .43927 Mdot
.67731 .42059 Mdot
.66417 .6222 Mdot
.41581 .65213 Mdot
.35736 .44889 Mdot
.38246 .62346 Mdot
.42101 .42267 Mdot
.49411 .48877 Mdot
.62251 .61179 Mdot
.43342 .63639 Mdot
.17202 .44093 Mdot
.39882 .5609 Mdot
.39723 .44407 Mdot
.18947 .44753 Mdot
.35262 .39525 Mdot
.39236 .29724 Mdot
.39591 .37589 Mdot
.65778 .44475 Mdot
.35111 .51217 Mdot
.3328 .45687 Mdot
.80586 .39586 Mdot
.59288 .62273 Mdot
.61966 .43124 Mdot
.34803 .46097 Mdot
.36443 .36896 Mdot
.40673 .69665 Mdot
.37892 .64764 Mdot
.55302 .34524 Mdot
.51468 .23919 Mdot
.60582 .63303 Mdot
.3007 .26707 Mdot
.39656 .41546 Mdot
.79907 .56318 Mdot
.21244 .49083 Mdot
.37053 .42689 Mdot
.29845 .72072 Mdot
.24363 .58463 Mdot
.42989 .4419 Mdot
.37239 .33884 Mdot
.60663 .60158 Mdot
.7416 .65663 Mdot
.42985 .39652 Mdot
.66087 .46446 Mdot
.43593 .65649 Mdot
.37639 .672 Mdot
.56126 .33162 Mdot
.64864 .21301 Mdot
.61734 .65148 Mdot
.43579 .64197 Mdot
.41441 .44248 Mdot
.58448 .63645 Mdot
.6576 .41756 Mdot
.37479 .39057 Mdot
.44133 .31674 Mdot
.40589 .63892 Mdot
.42234 .39195 Mdot
.56184 .69506 Mdot
.46506 .23292 Mdot
.545 .84434 Mdot
.61277 .64641 Mdot
.51368 .3339 Mdot
.33164 .46945 Mdot
.33237 .24485 Mdot
.38562 .49083 Mdot
.36875 .25404 Mdot
.37403 .72583 Mdot
.51309 .33281 Mdot
.39105 .43756 Mdot
.38975 .46211 Mdot
.5413 .578 Mdot
.51734 .35142 Mdot
.40944 .39769 Mdot
.37871 .53914 Mdot
.41567 .65747 Mdot
.6666 .50046 Mdot
.41009 .64013 Mdot
.39385 .44969 Mdot
.44704 .39059 Mdot
.39628 .62518 Mdot
.24421 .29667 Mdot
.49812 .32593 Mdot
.59023 .63279 Mdot
.41995 .37313 Mdot
.44407 .4289 Mdot
.75774 .70524 Mdot
.61817 .44829 Mdot
.61171 .77079 Mdot
.60171 .39312 Mdot
.51506 .78152 Mdot
.76825 .58016 Mdot
.369 .82079 Mdot
.81673 .45032 Mdot
.46429 .44322 Mdot
.45008 .54354 Mdot
.35559 .34806 Mdot
.60353 .65099 Mdot
.31425 .52325 Mdot
.40171 .41684 Mdot
.4035 .43193 Mdot
.65396 .485 Mdot
.49672 .73559 Mdot
.7571 .38657 Mdot
.59279 .52398 Mdot
.52977 .32302 Mdot
.40379 .68047 Mdot
.36181 .42456 Mdot
.5476 .41575 Mdot
.67218 .4802 Mdot
.80134 .55014 Mdot
.38339 .42925 Mdot
.65182 .23328 Mdot
.67333 .63673 Mdot
.59488 .64354 Mdot
.67873 .46484 Mdot
.7292 .35092 Mdot
.4199 .4152 Mdot
.57111 .61764 Mdot
.41514 .45315 Mdot
.71747 .43004 Mdot
.37738 .39439 Mdot
.52246 .34478 Mdot
.35208 .45216 Mdot
.59507 .51674 Mdot
.47056 .84412 Mdot
.48372 .33752 Mdot
.39155 .68445 Mdot
.62698 .39723 Mdot
.6436 .45007 Mdot
.38483 .63583 Mdot
.64602 .44847 Mdot
.22768 .52911 Mdot
.30798 .59964 Mdot
.52884 .32746 Mdot
.35077 .37324 Mdot
.53936 .34813 Mdot
.61823 .45069 Mdot
.41064 .41865 Mdot
.25719 .28291 Mdot
.64356 .43694 Mdot
.77339 .64586 Mdot
.59597 .61972 Mdot
.61774 .44006 Mdot
.41349 .39107 Mdot
.67423 .58105 Mdot
.68291 .45837 Mdot
.68775 .65653 Mdot
.38807 .45743 Mdot
.41408 .62912 Mdot
.38602 .46398 Mdot
.38384 .3754 Mdot
.67933 .48982 Mdot
.44013 .44829 Mdot
.58652 .61533 Mdot
.42629 .61611 Mdot
.31171 .75894 Mdot
.66127 .67271 Mdot
.40998 .40224 Mdot
.41207 .44282 Mdot
.38116 .68861 Mdot
.43347 .40842 Mdot
.58907 .59233 Mdot
.90312 .51628 Mdot
.53301 .33659 Mdot
.63447 .41221 Mdot
.76141 .5969 Mdot
.39692 .49333 Mdot
.39607 .4793 Mdot
.16363 .47542 Mdot
.76006 .61269 Mdot
.58766 .60039 Mdot
.3257 .43373 Mdot
.67567 .42724 Mdot
.54105 .3179 Mdot
.62924 .59979 Mdot
.42493 .47299 Mdot
.39345 .42967 Mdot
.51443 .33422 Mdot
.27044 .68686 Mdot
.72088 .3254 Mdot
.62532 .64218 Mdot
.35559 .51583 Mdot
.59268 .41403 Mdot
.42927 .41757 Mdot
.67065 .28815 Mdot
.38026 .64879 Mdot
.57564 .62317 Mdot
.58991 .79055 Mdot
.36936 .47361 Mdot
.62367 .60105 Mdot
.60301 .63214 Mdot
.32966 .44938 Mdot
.44779 .67178 Mdot
.43857 .62915 Mdot
.39528 .67904 Mdot
.80627 .35422 Mdot
.44636 .23792 Mdot
.63623 .46434 Mdot
.60814 .60142 Mdot
.65675 .4082 Mdot
.56658 .34154 Mdot
.52891 .44517 Mdot
.64054 .41024 Mdot
.38403 .63166 Mdot
.62873 .39282 Mdot
.38606 .46085 Mdot
.60982 .63276 Mdot
.62694 .4563 Mdot
.34699 .4616 Mdot
.48262 .67003 Mdot
.72691 .40953 Mdot
.52148 .30768 Mdot
.5015 .33953 Mdot
.36954 .41318 Mdot
.62966 .47573 Mdot
.38738 .42004 Mdot
.62918 .58736 Mdot
.50343 .65588 Mdot
.37097 .48228 Mdot
.65259 .44592 Mdot
.46453 .66864 Mdot
.71106 .3298 Mdot
.33556 .41325 Mdot
.38752 .44741 Mdot
.42638 .42142 Mdot
.41603 .45341 Mdot
.49639 .75596 Mdot
.63554 .64327 Mdot
.4964 .60927 Mdot
.72032 .62943 Mdot
.39696 .63915 Mdot
.44962 .64606 Mdot
.6297 .27042 Mdot
.71794 .48341 Mdot
.59358 .60283 Mdot
.42997 .43018 Mdot
.67602 .66867 Mdot
.21161 .66931 Mdot
.22835 .30948 Mdot
.53836 .36502 Mdot
.63405 .47534 Mdot
.40377 .69044 Mdot
.6726 .47645 Mdot
.416 .42467 Mdot
.33412 .47437 Mdot
.3637 .82357 Mdot
.58018 .57767 Mdot
.52662 .32063 Mdot
.42492 .42252 Mdot
.44751 .23134 Mdot
.67456 .43145 Mdot
.66888 .40714 Mdot
.4055 .39541 Mdot
.42911 .60995 Mdot
.6794 .78248 Mdot
.59777 .64598 Mdot
.44269 .57767 Mdot
.30822 .4694 Mdot
.57006 .68217 Mdot
.62177 .62028 Mdot
.73118 .37947 Mdot
.63578 .47935 Mdot
.20823 .56453 Mdot
.39781 .63556 Mdot
.5232 .32196 Mdot
.37485 .50743 Mdot
.40911 .6213 Mdot
.67729 .4876 Mdot
.42624 .63068 Mdot
.34912 .44897 Mdot
.62373 .65181 Mdot
.67648 .46382 Mdot
.61741 .57076 Mdot
.44913 .66691 Mdot
.55613 .33533 Mdot
.51899 .59004 Mdot
.34836 .56573 Mdot
.24027 .57961 Mdot
.43024 .40985 Mdot
.5458 .41193 Mdot
.41147 .46529 Mdot
.41334 .69683 Mdot
.41721 .44942 Mdot
.46548 .64343 Mdot
.66898 .47265 Mdot
.42716 .39592 Mdot
.40837 .48436 Mdot
.28079 .48517 Mdot
.38023 .43646 Mdot
.42143 .38635 Mdot
.43157 .43846 Mdot
.36657 .62661 Mdot
.33125 .3968 Mdot
.41827 .64464 Mdot
.767 .40938 Mdot
.67098 .44072 Mdot
.50309 .34294 Mdot
.52947 .3057 Mdot
.38495 .24477 Mdot
.52648 .2823 Mdot
.51091 .74349 Mdot
.40866 .64912 Mdot
.59275 .62792 Mdot
.41994 .45102 Mdot
.50244 .81092 Mdot
.75262 .57189 Mdot
.67373 .42276 Mdot
.66149 .67233 Mdot
.39162 .51769 Mdot
.6898 .74561 Mdot
.40908 .38848 Mdot
.74405 .28843 Mdot
.47131 .42607 Mdot
.36948 .40017 Mdot
.67712 .41432 Mdot
.49235 .33106 Mdot
.42253 .39754 Mdot
.40475 .69675 Mdot
.51842 .33454 Mdot
.4008 .57238 Mdot
.60151 .47329 Mdot
.73588 .38985 Mdot
.31604 .55386 Mdot
.41774 .45983 Mdot
.67506 .46418 Mdot
.42574 .645 Mdot
.80426 .42471 Mdot
.58686 .63404 Mdot
.60164 .54686 Mdot
.29254 .39707 Mdot
.20909 .39882 Mdot
.52014 .32696 Mdot
.26655 .67775 Mdot
.36186 .44161 Mdot
.65332 .29981 Mdot
.42505 .48874 Mdot
.21503 .67195 Mdot
.56949 .32574 Mdot
.44057 .62156 Mdot
.59904 .59331 Mdot
.37684 .63453 Mdot
.25097 .60407 Mdot
.55035 .64764 Mdot
.53489 .53966 Mdot
.66401 .42742 Mdot
.50106 .60698 Mdot
.40028 .6726 Mdot
.37869 .47336 Mdot
.70386 .81216 Mdot
.37915 .65695 Mdot
.42568 .67935 Mdot
.26374 .3108 Mdot
.24846 .32043 Mdot
.36965 .51632 Mdot
.40768 .6182 Mdot
.66451 .43036 Mdot
.55564 .32809 Mdot
.39285 .46693 Mdot
.40296 .45801 Mdot
.40216 .62452 Mdot
.6731 .40974 Mdot
.41522 .55525 Mdot
.65949 .44928 Mdot
.41758 .65815 Mdot
.6701 .45057 Mdot
.71106 .64822 Mdot
.62401 .45498 Mdot
.44282 .42551 Mdot
.41815 .44982 Mdot
.60111 .41563 Mdot
.40893 .62965 Mdot
.40601 .47927 Mdot
.35279 .44484 Mdot
.39404 .66593 Mdot
.57844 .40566 Mdot
.34443 .68289 Mdot
.41073 .40769 Mdot
.37334 .45093 Mdot
.5132 .33734 Mdot
.52791 .41763 Mdot
.55481 .20668 Mdot
.39234 .47423 Mdot
.55247 .35067 Mdot
.4366 .63465 Mdot
.38283 .42012 Mdot
.39786 .75317 Mdot
.69821 .65074 Mdot
.36784 .47164 Mdot
.62095 .43122 Mdot
.35026 .47743 Mdot
.59336 .82515 Mdot
.38634 .39808 Mdot
.40119 .66592 Mdot
.4294 .66911 Mdot
.28142 .30654 Mdot
.38311 .65627 Mdot
.64941 .41677 Mdot
.61242 .62064 Mdot
.23792 .69438 Mdot
.65867 .41778 Mdot
.33529 .44606 Mdot
.38426 .19207 Mdot
.39777 .38235 Mdot
.35494 .47 Mdot
.72478 .71955 Mdot
.66081 .41944 Mdot
.42022 .6731 Mdot
.58073 .55222 Mdot
.46486 .42439 Mdot
.58018 .63337 Mdot
.33357 .46742 Mdot
.44379 .44678 Mdot
.76647 .63008 Mdot
.65321 .72287 Mdot
.59651 .58194 Mdot
.43504 .49273 Mdot
.39329 .47486 Mdot
.6556 .38095 Mdot
.4185 .44512 Mdot
.54205 .3488 Mdot
.41287 .68366 Mdot
.65143 .47941 Mdot
.54521 .33539 Mdot
.39927 .41259 Mdot
.53217 .31674 Mdot
.64002 .47128 Mdot
.57259 .61838 Mdot
.41604 .41931 Mdot
.56063 .29903 Mdot
.53085 .32159 Mdot
.41131 .46886 Mdot
.4359 .64584 Mdot
.46198 .48303 Mdot
.37895 .42105 Mdot
.36812 .46388 Mdot
.40352 .62551 Mdot
.20705 .31718 Mdot
.38525 .39676 Mdot
.69757 .4547 Mdot
.42926 .67837 Mdot
.60547 .67876 Mdot
.64662 .47973 Mdot
.44438 .44431 Mdot
.574 .60946 Mdot
.62224 .60655 Mdot
.66557 .41137 Mdot
.37153 .67543 Mdot
.60115 .40058 Mdot
.46544 .662 Mdot
.44074 .38856 Mdot
.36946 .38956 Mdot
.4321 .17594 Mdot
.35325 .80397 Mdot
.37938 .67427 Mdot
.68376 .4182 Mdot
.58841 .52297 Mdot
.60784 .59852 Mdot
.64721 .39877 Mdot
.38567 .68832 Mdot
.39846 .68891 Mdot
.42617 .63385 Mdot
.52896 .31101 Mdot
.59474 .39523 Mdot
.41308 .60594 Mdot
.42967 .61095 Mdot
.38646 .4587 Mdot
.39613 .4765 Mdot
.42748 .33968 Mdot
.47056 .28746 Mdot
.55792 .33455 Mdot
.64786 .45864 Mdot
.87836 .50723 Mdot
.62503 .58498 Mdot
.28063 .48959 Mdot
.37262 .48294 Mdot
.59112 .90608 Mdot
.40175 .38963 Mdot
.4178 .44244 Mdot
.42335 .61529 Mdot
.55172 .29309 Mdot
.5352 .34635 Mdot
.40353 .67482 Mdot
.42807 .68827 Mdot
.53877 .35 Mdot
.2049 .62 Mdot
.27946 .73364 Mdot
.53766 .59531 Mdot
.39548 .65841 Mdot
.34549 .58014 Mdot
.57777 .6342 Mdot
.45844 .64655 Mdot
.63302 .59618 Mdot
.67512 .43643 Mdot
.64106 .48412 Mdot
.62219 .63973 Mdot
.39116 .4566 Mdot
.62919 .45244 Mdot
.44201 .39495 Mdot
.24031 .66906 Mdot
.30953 .67591 Mdot
.77895 .52176 Mdot
.44948 .45648 Mdot
.75704 .39778 Mdot
.7298 .48157 Mdot
.38936 .40675 Mdot
.45967 .78144 Mdot
.52795 .31901 Mdot
.44452 .61665 Mdot
.58475 .59528 Mdot
.56268 .84413 Mdot
.43014 .42163 Mdot
.40167 .66161 Mdot
.59027 .61879 Mdot
.3153 .29576 Mdot
.51731 .65263 Mdot
.42308 .42119 Mdot
.74241 .77348 Mdot
.36364 .62447 Mdot
.6495 .47862 Mdot
.52011 .16877 Mdot
.38167 .62303 Mdot
.58025 .34022 Mdot
.70781 .61426 Mdot
.18393 .43683 Mdot
.42376 .66438 Mdot
.66772 .3982 Mdot
.40314 .67918 Mdot
.55121 .34305 Mdot
.42429 .59628 Mdot
.68048 .4455 Mdot
.38479 .43591 Mdot
.65073 .45239 Mdot
.56057 .32838 Mdot
.66241 .29165 Mdot
.58135 .59881 Mdot
.61968 .43214 Mdot
.60858 .61013 Mdot
.47809 .23476 Mdot
.73076 .67017 Mdot
.58341 .62364 Mdot
.30153 .28777 Mdot
.36001 .46885 Mdot
.39806 .60887 Mdot
.63573 .44427 Mdot
.70058 .60928 Mdot
.54321 .56233 Mdot
.39231 .64431 Mdot
.65113 .46651 Mdot
.3017 .39029 Mdot
.39505 .20407 Mdot
.38644 .36461 Mdot
.4932 .24461 Mdot
.39285 .66118 Mdot
.65286 .39704 Mdot
.78308 .40021 Mdot
.3799 .63669 Mdot
.63721 .43796 Mdot
.61004 .59415 Mdot
.61911 .62547 Mdot
.41903 .39856 Mdot
.65039 .59564 Mdot
.64148 .46279 Mdot
.74496 .46921 Mdot
.44233 .65682 Mdot
.32351 .29392 Mdot
.55177 .29873 Mdot
.6656 .44081 Mdot
.35719 .40418 Mdot
.4491 .67983 Mdot
.70424 .64815 Mdot
.42895 .54167 Mdot
.86882 .52113 Mdot
.64576 .45505 Mdot
.4186 .68217 Mdot
.40189 .65631 Mdot
.33431 .4183 Mdot
.58289 .53822 Mdot
.59859 .40374 Mdot
.40052 .21312 Mdot
.35687 .26168 Mdot
.67574 .49181 Mdot
.64166 .51195 Mdot
.33666 .4341 Mdot
.42398 .45984 Mdot
.60556 .59672 Mdot
.38361 .44116 Mdot
.43213 .61759 Mdot
.42746 .40188 Mdot
.62455 .62078 Mdot
.65416 .42723 Mdot
.41081 .42135 Mdot
.55752 .32096 Mdot
.5777 .59605 Mdot
.6348 .62434 Mdot
.65954 .44026 Mdot
.41373 .62016 Mdot
.4984 .35423 Mdot
.65855 .45184 Mdot
.41703 .45921 Mdot
.62948 .5393 Mdot
.34883 .44018 Mdot
.20189 .59488 Mdot
.38431 .62972 Mdot
.66983 .47584 Mdot
.43676 .6733 Mdot
.60427 .60761 Mdot
.71938 .62919 Mdot
.40241 .44905 Mdot
.63861 .43477 Mdot
.60228 .42533 Mdot
.22754 .64486 Mdot
.38314 .69216 Mdot
.66418 .53752 Mdot
.44692 .64787 Mdot
.66801 .49427 Mdot
.2605 .36384 Mdot
.52288 .33199 Mdot
.67698 .42653 Mdot
.34354 .78081 Mdot
.6479 .44206 Mdot
.37615 .43581 Mdot
.36706 .42336 Mdot
.64167 .47666 Mdot
.51839 .31612 Mdot
.82562 .46093 Mdot
.72665 .4342 Mdot
.42281 .66928 Mdot
.21758 .43837 Mdot
.84527 .59335 Mdot
.64877 .61449 Mdot
.59693 .59584 Mdot
.46618 .43061 Mdot
.36649 .40084 Mdot
.62835 .59276 Mdot
.57652 .6403 Mdot
.56282 .31138 Mdot
.67671 .42037 Mdot
.40848 .59253 Mdot
.56905 .61433 Mdot
.47475 .38803 Mdot
.54512 .27179 Mdot
.33371 .40901 Mdot
.31029 .46522 Mdot
.44084 .47058 Mdot
.36121 .25151 Mdot
.6256 .62967 Mdot
.3612 .42086 Mdot
.33684 .39716 Mdot
.57435 .61329 Mdot
.5477 .34548 Mdot
.64873 .71643 Mdot
.67002 .45871 Mdot
.13365 .53517 Mdot
.3592 .41386 Mdot
.37587 .43146 Mdot
.61791 .6469 Mdot
.61198 .37766 Mdot
.41357 .62426 Mdot
.38297 .62975 Mdot
.62532 .43502 Mdot
.51789 .58152 Mdot
.43768 .42385 Mdot
.38237 .40764 Mdot
.66704 .46751 Mdot
.61801 .43837 Mdot
.75594 .4985 Mdot
.35981 .44879 Mdot
.59106 .6157 Mdot
.5834 .49598 Mdot
.62591 .62608 Mdot
.34934 .42258 Mdot
.37282 .43578 Mdot
.44177 .42323 Mdot
.35316 .41025 Mdot
.63555 .62446 Mdot
.35974 .42456 Mdot
.46502 .3886 Mdot
.42724 .62815 Mdot
.43906 .44344 Mdot
.35144 .25901 Mdot
.38176 .44934 Mdot
.55496 .33422 Mdot
.49075 .44774 Mdot
.42621 .41908 Mdot
.44362 .43584 Mdot
.72512 .4364 Mdot
.39551 .43809 Mdot
.62973 .58817 Mdot
.39947 .64174 Mdot
.60905 .60172 Mdot
.62916 .63377 Mdot
.63751 .41914 Mdot
.5605 .33539 Mdot
.40378 .49328 Mdot
.54955 .30323 Mdot
.39996 .49861 Mdot
.36239 .4691 Mdot
.73 .60715 Mdot
.7359 .2779 Mdot
.7161 .31932 Mdot
.40259 .45001 Mdot
.64714 .42457 Mdot
.65642 .48034 Mdot
.44697 .56179 Mdot
.37685 .36792 Mdot
.62723 .59315 Mdot
.61928 .60327 Mdot
.44136 .31 Mdot
.76102 .63522 Mdot
.55353 .33795 Mdot
.53878 .42785 Mdot
.44268 .39459 Mdot
.35781 .4537 Mdot
.37861 .38895 Mdot
.64859 .40954 Mdot
.61588 .52632 Mdot
.67375 .42353 Mdot
.66524 .66887 Mdot
.62616 .61804 Mdot
.43436 .42709 Mdot
.33185 .71968 Mdot
.37853 .6453 Mdot
.40001 .64097 Mdot
.63011 .60533 Mdot
.63237 .39741 Mdot
.47663 .35634 Mdot
.26582 .24359 Mdot
.37473 .61206 Mdot
.53938 .29457 Mdot
.39512 .40473 Mdot
.65369 .43197 Mdot
.38549 .67615 Mdot
.50867 .33346 Mdot
.36561 .46807 Mdot
.59516 .40381 Mdot
.40346 .45253 Mdot
.35823 .34732 Mdot
.43347 .64823 Mdot
.23606 .69957 Mdot
.37726 .67842 Mdot
.58035 .59431 Mdot
.57897 .6116 Mdot
.36857 .42884 Mdot
.45938 .17122 Mdot
.39088 .61386 Mdot
.65918 .6494 Mdot
.56868 .32223 Mdot
.6739 .58882 Mdot
.5329 .35224 Mdot
.6612 .47671 Mdot
.51877 .3318 Mdot
.67934 .46088 Mdot
.47125 .30081 Mdot
.36005 .65645 Mdot
.53844 .33732 Mdot
.70285 .41376 Mdot
.38161 .36744 Mdot
.50587 .34647 Mdot
.45839 .46824 Mdot
.20257 .51054 Mdot
.66412 .4673 Mdot
.52687 .30936 Mdot
.37915 .47306 Mdot
.46197 .82619 Mdot
.58545 .61152 Mdot
.62282 .58803 Mdot
.42972 .38366 Mdot
.67344 .41407 Mdot
.40661 .69419 Mdot
.4574 .74127 Mdot
.55714 .64612 Mdot
.37215 .41213 Mdot
.42409 .39853 Mdot
.44946 .64045 Mdot
.36944 .70057 Mdot
.36887 .43455 Mdot
.28682 .45536 Mdot
.35845 .43685 Mdot
.61307 .59318 Mdot
.37419 .65846 Mdot
.40063 .65016 Mdot
.64675 .46843 Mdot
.4084 .61472 Mdot
.46666 .63442 Mdot
.63441 .54751 Mdot
.46754 .45013 Mdot
.5991 .61313 Mdot
.63639 .55946 Mdot
.664 .67142 Mdot
.37921 .79214 Mdot
.45179 .64968 Mdot
.44604 .42853 Mdot
.44027 .66321 Mdot
.54436 .31579 Mdot
.40969 .63207 Mdot
.41151 .68882 Mdot
.38581 .41504 Mdot
.41902 .42554 Mdot
.65925 .42177 Mdot
.58869 .53586 Mdot
.43224 .63072 Mdot
.36701 .41723 Mdot
.41179 .38494 Mdot
.4213 .38581 Mdot
.51406 .49561 Mdot
.38161 .67603 Mdot
.25706 .45902 Mdot
.3416 .32125 Mdot
.43105 .62913 Mdot
.62277 .81453 Mdot
.70694 .62226 Mdot
.61507 .428 Mdot
.62804 .57674 Mdot
.36008 .45009 Mdot
.64472 .48066 Mdot
.41568 .4243 Mdot
.31026 .46553 Mdot
.39687 .42989 Mdot
.52405 .35105 Mdot
.46421 .44352 Mdot
.65968 .49473 Mdot
.65566 .45143 Mdot
.37892 .40278 Mdot
.40772 .42312 Mdot
.68432 .30534 Mdot
.43444 .68327 Mdot
.41657 .62584 Mdot
.63039 .37437 Mdot
.53827 .32951 Mdot
.5768 .62739 Mdot
.42654 .44443 Mdot
.63435 .42308 Mdot
.65271 .45308 Mdot
.37535 .63612 Mdot
.65956 .463 Mdot
.60477 .64749 Mdot
.40627 .44789 Mdot
.62508 .58936 Mdot
.53325 .30667 Mdot
.39836 .68158 Mdot
.43105 .42584 Mdot
.38565 .45865 Mdot
.42916 .66926 Mdot
.38583 .487 Mdot
.51372 .33942 Mdot
.64739 .44472 Mdot
.42486 .65808 Mdot
.61425 .62138 Mdot
.66982 .47299 Mdot
.37944 .46577 Mdot
.87322 .50972 Mdot
.37512 .4408 Mdot
.3687 .45871 Mdot
.3227 .77947 Mdot
.4641 .4477 Mdot
.63885 .45153 Mdot
.43827 .61748 Mdot
.44817 .40789 Mdot
.39875 .24496 Mdot
.21863 .31596 Mdot
.66817 .41829 Mdot
.39914 .40234 Mdot
.38915 .81103 Mdot
.38998 .40054 Mdot
.31132 .26146 Mdot
.5931 .2647 Mdot
.48874 .58104 Mdot
.45 .39057 Mdot
.61022 .64355 Mdot
.65768 .42114 Mdot
.66674 .47304 Mdot
.23576 .43208 Mdot
.38367 .4124 Mdot
.39893 .34303 Mdot
.39216 .48308 Mdot
.62149 .6227 Mdot
.41767 .31717 Mdot
.64847 .45587 Mdot
.77263 .35454 Mdot
.40916 .46302 Mdot
.38332 .67904 Mdot
.63066 .39253 Mdot
.70618 .63171 Mdot
.37432 .46604 Mdot
.54724 .3044 Mdot
.58903 .57941 Mdot
.45987 .4236 Mdot
.60114 .61851 Mdot
.35712 .45648 Mdot
.46136 .37228 Mdot
.56717 .18038 Mdot
.43244 .64021 Mdot
.60185 .59411 Mdot
.68201 .51521 Mdot
.42894 .48838 Mdot
.42511 .66076 Mdot
.39685 .63664 Mdot
.56058 .30969 Mdot
.5519 .52106 Mdot
.55152 .69762 Mdot
.33582 .63747 Mdot
.22955 .42432 Mdot
.62988 .3947 Mdot
.70008 .52486 Mdot
.39254 .46991 Mdot
.7958 .55582 Mdot
.61324 .57917 Mdot
.37878 .43262 Mdot
.21007 .52504 Mdot
.39104 .67706 Mdot
.36835 .44886 Mdot
.54041 .34816 Mdot
.79851 .49569 Mdot
.80058 .52703 Mdot
.64505 .77298 Mdot
.66753 .42877 Mdot
.3363 .47592 Mdot
.31081 .44086 Mdot
.62927 .41824 Mdot
.40873 .48983 Mdot
.63939 .44592 Mdot
.1776 .51433 Mdot
.51131 .33124 Mdot
.39487 .68273 Mdot
.70729 .62565 Mdot
.43615 .47023 Mdot
.39823 .3795 Mdot
.50496 .33125 Mdot
.42533 .46499 Mdot
.65327 .21797 Mdot
.76808 .54063 Mdot
.62646 .45212 Mdot
.42769 .63463 Mdot
.44348 .45869 Mdot
.55732 .48653 Mdot
.37849 .416 Mdot
.30726 .62869 Mdot
.44437 .43783 Mdot
.54453 .68287 Mdot
.43628 .65571 Mdot
.60223 .61518 Mdot
.37226 .49852 Mdot
.40363 .43495 Mdot
.57056 .4349 Mdot
.45493 .39596 Mdot
.37487 .40096 Mdot
.39654 .6952 Mdot
.37605 .66056 Mdot
.41732 .64532 Mdot
.67973 .47479 Mdot
.76477 .62689 Mdot
.59525 .60684 Mdot
.33901 .46861 Mdot
.56847 .61708 Mdot
.40654 .54897 Mdot
.51858 .31014 Mdot
.46948 .81646 Mdot
.43538 .45653 Mdot
.41214 .65128 Mdot
.56028 .76506 Mdot
.43794 .63607 Mdot
.55108 .45565 Mdot
.60662 .63313 Mdot
.38449 .67166 Mdot
.41206 .4401 Mdot
.60768 .53491 Mdot
.55025 .81711 Mdot
.6143 .60575 Mdot
.39188 .4951 Mdot
.62955 .4713 Mdot
.75224 .61316 Mdot
.87944 .5335 Mdot
.58645 .60194 Mdot
.67748 .51753 Mdot
.38436 .40922 Mdot
.38287 .63623 Mdot
.60916 .64541 Mdot
.58591 .62347 Mdot
.65713 .46605 Mdot
.42124 .42523 Mdot
.42526 .4256 Mdot
.66394 .49283 Mdot
.62042 .60659 Mdot
.37715 .37986 Mdot
.3869 .38962 Mdot
.36454 .82619 Mdot
.30633 .35249 Mdot
.13307 .43821 Mdot
.46906 .65124 Mdot
.21287 .54902 Mdot
.44584 .73361 Mdot
.41475 .6849 Mdot
.42531 .41774 Mdot
.44894 .4638 Mdot
.64258 .46279 Mdot
.39 .44415 Mdot
.68075 .41504 Mdot
.59157 .60238 Mdot
.61661 .81395 Mdot
.61391 .72907 Mdot
.17973 .4907 Mdot
.39017 .44165 Mdot
.64521 .69151 Mdot
.54928 .32552 Mdot
.56587 .62581 Mdot
.42116 .65311 Mdot
.34702 .44552 Mdot
.69268 .30979 Mdot
.67607 .4258 Mdot
.38872 .63842 Mdot
.76313 .38927 Mdot
.74103 .38782 Mdot
.34878 .42383 Mdot
.6734 .48224 Mdot
.49578 .7756 Mdot
.29064 .46198 Mdot
.62624 .65794 Mdot
.52783 .35174 Mdot
.67396 .42767 Mdot
.62944 .61602 Mdot
.37819 .73249 Mdot
.38222 .66431 Mdot
.39925 .60105 Mdot
.65332 .26792 Mdot
.63339 .41065 Mdot
.55012 .33252 Mdot
.75852 .63488 Mdot
.80285 .56755 Mdot
.5241 .35073 Mdot
.64827 .48664 Mdot
.37803 .66696 Mdot
.41184 .66616 Mdot
.39896 .6431 Mdot
.7788 .36752 Mdot
.37133 .6729 Mdot
.28996 .52361 Mdot
.40299 .38181 Mdot
.44054 .35649 Mdot
.39721 .40111 Mdot
.63404 .60091 Mdot
.43219 .65472 Mdot
.5186 .61043 Mdot
.34161 .46495 Mdot
.62033 .79487 Mdot
.37794 .40862 Mdot
.61026 .65792 Mdot
.36536 .45143 Mdot
.31361 .53223 Mdot
.4368 .67089 Mdot
.39563 .4485 Mdot
.64132 .61193 Mdot
.53471 .32237 Mdot
.45035 .60679 Mdot
.42589 .42136 Mdot
.49738 .72919 Mdot
.46299 .45254 Mdot
.18937 .594 Mdot
.32978 .29947 Mdot
.53873 .2948 Mdot
.35612 .52165 Mdot
.65521 .4001 Mdot
.43764 .35389 Mdot
.32634 .39142 Mdot
.61431 .60795 Mdot
.70136 .69856 Mdot
.67044 .43826 Mdot
.47331 .31993 Mdot
.32333 .44681 Mdot
.5564 .34026 Mdot
.38126 .69779 Mdot
.63802 .61448 Mdot
.34464 .45482 Mdot
.33069 .44093 Mdot
.18176 .52878 Mdot
.35472 .37022 Mdot
.43139 .4051 Mdot
.51264 .31819 Mdot
.25313 .47942 Mdot
.38191 .45259 Mdot
.54893 .45608 Mdot
.40457 .59967 Mdot
.42087 .37729 Mdot
.26006 .45332 Mdot
.36872 .4163 Mdot
.38624 .63709 Mdot
.36303 .649 Mdot
.56607 .74321 Mdot
.56743 .32194 Mdot
.44384 .43951 Mdot
.27564 .32863 Mdot
.41445 .46306 Mdot
.59255 .61795 Mdot
.35993 .40706 Mdot
.67828 .43674 Mdot
.77098 .36644 Mdot
.6358 .46157 Mdot
.41922 .40837 Mdot
.39709 .64902 Mdot
.62135 .64273 Mdot
.68878 .28943 Mdot
.61285 .29316 Mdot
.2802 .51348 Mdot
.16852 .4463 Mdot
.52055 .31495 Mdot
.52993 .35553 Mdot
.63813 .62218 Mdot
.39465 .44954 Mdot
.26648 .31898 Mdot
.46922 .42071 Mdot
.37256 .45186 Mdot
.39706 .42882 Mdot
.73542 .65137 Mdot
.60208 .59868 Mdot
.66566 .45865 Mdot
.37035 .43621 Mdot
.36299 .42124 Mdot
.42594 .67678 Mdot
.53253 .32296 Mdot
.64996 .48055 Mdot
.53057 .33187 Mdot
.64737 .43064 Mdot
.60951 .82198 Mdot
.36056 .48795 Mdot
.53698 .32365 Mdot
.5952 .58108 Mdot
.40191 .62537 Mdot
.6353 .54558 Mdot
.66201 .47588 Mdot
.64774 .46009 Mdot
.37565 .41059 Mdot
.38784 .63291 Mdot
.41711 .6163 Mdot
.54457 .31475 Mdot
.58206 .62613 Mdot
.42047 .41719 Mdot
.35593 .46326 Mdot
.46667 .57334 Mdot
.65371 .40983 Mdot
.30283 .3947 Mdot
.53511 .75339 Mdot
.39969 .45059 Mdot
.41051 .61848 Mdot
.3991 .42222 Mdot
.33907 .74699 Mdot
.38784 .62823 Mdot
.38263 .39591 Mdot
.81996 .53921 Mdot
.60186 .51167 Mdot
.52428 .71712 Mdot
.43884 .41208 Mdot
.14535 .53452 Mdot
.40014 .47364 Mdot
.38936 .83217 Mdot
.66802 .32241 Mdot
.43454 .42337 Mdot
.38775 .46564 Mdot
.33732 .69197 Mdot
.4013 .40982 Mdot
.66278 .49654 Mdot
.46996 .319 Mdot
.40876 .69166 Mdot
.48428 .69211 Mdot
.50411 .45435 Mdot
.5665 .31194 Mdot
.62503 .43591 Mdot
.63165 .51055 Mdot
.52705 .34713 Mdot
.39601 .66143 Mdot
.41654 .45346 Mdot
.50807 .5717 Mdot
.68451 .47685 Mdot
.37401 .37704 Mdot
.59574 .62366 Mdot
.72667 .53613 Mdot
.6599 .39444 Mdot
.60877 .61926 Mdot
.43031 .46906 Mdot
.3447 .69015 Mdot
.57502 .23779 Mdot
.2476 .71822 Mdot
.62402 .64312 Mdot
.62405 .611 Mdot
.79493 .39112 Mdot
.56795 .31103 Mdot
.19219 .49112 Mdot
.53104 .66911 Mdot
.60001 .64833 Mdot
.2874 .3389 Mdot
.67161 .41773 Mdot
.50045 .72021 Mdot
.44475 .61684 Mdot
.37003 .38987 Mdot
.40934 .43903 Mdot
.57991 .62284 Mdot
.37721 .7353 Mdot
.55112 .17597 Mdot
.60992 .61061 Mdot
.47313 .39541 Mdot
.50679 .52053 Mdot
.70539 .61938 Mdot
.65077 .41249 Mdot
.56624 .31963 Mdot
.58189 .32536 Mdot
.41577 .67914 Mdot
.56381 .32157 Mdot
.79732 .51651 Mdot
.43049 .46094 Mdot
.61717 .61319 Mdot
.69877 .63868 Mdot
.61427 .62484 Mdot
.53062 .34683 Mdot
.54304 .29321 Mdot
.42648 .62763 Mdot
.41681 .62686 Mdot
.22176 .56522 Mdot
.4091 .2999 Mdot
.385 .40105 Mdot
.57689 .79332 Mdot
.44274 .65356 Mdot
.32546 .49419 Mdot
.53844 .35417 Mdot
.53531 .32602 Mdot
.33382 .34744 Mdot
.43123 .43438 Mdot
.28572 .3001 Mdot
.42912 .43765 Mdot
.41684 .31214 Mdot
.42463 .48773 Mdot
.65814 .46478 Mdot
.43398 .43459 Mdot
.4925 .34295 Mdot
.33748 .43187 Mdot
.36601 .40529 Mdot
.67054 .41106 Mdot
.45745 .41901 Mdot
.67849 .43902 Mdot
.41706 .40458 Mdot
.56637 .34106 Mdot
.63152 .42443 Mdot
.43362 .24252 Mdot
.69965 .46417 Mdot
.62909 .47405 Mdot
.55972 .31752 Mdot
.55032 .29978 Mdot
.42451 .2233 Mdot
.42123 .65473 Mdot
.46145 .64117 Mdot
.39031 .4482 Mdot
.66853 .40662 Mdot
.6014 .59652 Mdot
.36004 .4263 Mdot
.45258 .46599 Mdot
.4289 .39883 Mdot
.40651 .68296 Mdot
.60321 .40181 Mdot
.53765 .31859 Mdot
.67937 .477 Mdot
.58145 .40919 Mdot
.68896 .44186 Mdot
.33099 .40337 Mdot
.39466 .50836 Mdot
.22111 .59841 Mdot
.62881 .75548 Mdot
.8246 .43672 Mdot
.38134 .65718 Mdot
.6203 .43227 Mdot
.55712 .30069 Mdot
.41879 .52315 Mdot
.41557 .65565 Mdot
.68025 .44418 Mdot
.40489 .45238 Mdot
.39252 .49588 Mdot
.56625 .59058 Mdot
.42112 .34916 Mdot
.36139 .26946 Mdot
.68648 .43486 Mdot
.66858 .39863 Mdot
.80054 .567 Mdot
.46724 .32434 Mdot
.52812 .57415 Mdot
.3852 .42594 Mdot
.54495 .30426 Mdot
.38536 .67601 Mdot
.60869 .24442 Mdot
.58305 .60008 Mdot
.58634 .53732 Mdot
.39142 .44258 Mdot
.52526 .63504 Mdot
.3967 .64715 Mdot
.54728 .34439 Mdot
.57922 .62257 Mdot
.54366 .29008 Mdot
.63616 .41245 Mdot
.22198 .34582 Mdot
.41872 .46471 Mdot
.3873 .39817 Mdot
.58512 .59256 Mdot
.40178 .67799 Mdot
.50954 .31889 Mdot
.20775 .61835 Mdot
.63997 .47304 Mdot
.27515 .30018 Mdot
.4181 .61148 Mdot
.3228 .55921 Mdot
.68157 .47355 Mdot
.62986 .60587 Mdot
.44147 .22452 Mdot
.62451 .6223 Mdot
.42663 .41063 Mdot
.40608 .65011 Mdot
.58676 .61157 Mdot
.56465 .46322 Mdot
.41726 .81919 Mdot
.33904 .57501 Mdot
.43144 .44837 Mdot
.51123 .82625 Mdot
.26553 .7025 Mdot
.35417 .6355 Mdot
.57391 .60819 Mdot
.37751 .42027 Mdot
.41928 .48411 Mdot
.41068 .46084 Mdot
.6017 .63504 Mdot
.71983 .59308 Mdot
.66199 .47016 Mdot
.38874 .4038 Mdot
.56132 .3086 Mdot
.67724 .44321 Mdot
.71163 .63176 Mdot
.6416 .45567 Mdot
.44411 .67074 Mdot
.3629 .40333 Mdot
.63729 .57053 Mdot
.48786 .85204 Mdot
.61052 .60254 Mdot
.63001 .47551 Mdot
.3545 .4238 Mdot
.70223 .67999 Mdot
.41644 .64741 Mdot
.63736 .46969 Mdot
.3763 .43092 Mdot
.693 .58775 Mdot
.68015 .30046 Mdot
.64297 .45607 Mdot
.4166 .66475 Mdot
.39625 .76032 Mdot
.3856 .44283 Mdot
.40522 .47369 Mdot
.3999 .6752 Mdot
.50053 .4419 Mdot
.77184 .39231 Mdot
.4044 .42315 Mdot
.60358 .6157 Mdot
.29232 .24337 Mdot
.42855 .3933 Mdot
.35134 .33102 Mdot
.66501 .42252 Mdot
.52157 .74001 Mdot
.29974 .40069 Mdot
.35627 .51808 Mdot
.35233 .73501 Mdot
.51859 .46171 Mdot
.59346 .82019 Mdot
.67223 .40535 Mdot
.70006 .35913 Mdot
.58758 .82751 Mdot
.63964 .62982 Mdot
.40745 .71935 Mdot
.45329 .587 Mdot
.76218 .33342 Mdot
.41867 .76048 Mdot
.66427 .36736 Mdot
.70807 .31888 Mdot
.49869 .55178 Mdot
.64481 .43728 Mdot
.486 .35634 Mdot
.41872 .42043 Mdot
.26058 .69898 Mdot
.28632 .46866 Mdot
.52019 .16194 Mdot
.49967 .82568 Mdot
.28029 .32742 Mdot
.49307 .81394 Mdot
.36934 .79107 Mdot
.20782 .57661 Mdot
.60973 .76375 Mdot
.29942 .25552 Mdot
.81496 .53418 Mdot
.2283 .38068 Mdot
.37953 .51308 Mdot
.54736 .41708 Mdot
.16277 .52601 Mdot
.30116 .55469 Mdot
.44327 .18128 Mdot
.64251 .46858 Mdot
.43636 .61572 Mdot
.46092 .59027 Mdot
.39878 .69961 Mdot
.55258 .58667 Mdot
.36956 .75999 Mdot
.37054 .81457 Mdot
.30409 .51945 Mdot
.14261 .54335 Mdot
.22094 .49918 Mdot
.75257 .25943 Mdot
.72479 .41326 Mdot
.3927 .60914 Mdot
.58201 .37047 Mdot
.79461 .58495 Mdot
.60162 .71639 Mdot
.47252 .64633 Mdot
.74377 .61202 Mdot
.44725 .26224 Mdot
.40082 .66089 Mdot
.29189 .44534 Mdot
.72834 .46247 Mdot
.63418 .71716 Mdot
.56258 .25707 Mdot
.37795 .7816 Mdot
.52617 .55596 Mdot
.49222 .71589 Mdot
.71746 .51931 Mdot
.87167 .51368 Mdot
.34378 .3094 Mdot
.30142 .71485 Mdot
.57729 .56796 Mdot
.38997 .74945 Mdot
.72217 .29182 Mdot
.43554 .29278 Mdot
.79751 .58063 Mdot
.759 .67735 Mdot
.23864 .68586 Mdot
.77923 .67673 Mdot
.46103 .63742 Mdot
.43229 .40439 Mdot
.29611 .68877 Mdot
.26813 .37215 Mdot
.56126 .35255 Mdot
.667 .75626 Mdot
.53109 .30638 Mdot
.43368 .6895 Mdot
.76502 .36664 Mdot
.29722 .52261 Mdot
.28467 .29398 Mdot
.50711 .31929 Mdot
.4498 .45488 Mdot
.46801 .11515 Mdot
.58477 .81961 Mdot
.5602 .73982 Mdot
.36641 .82787 Mdot
.54466 .6497 Mdot
.31368 .29989 Mdot
.58752 .61619 Mdot
.54638 .84532 Mdot
.40962 .66169 Mdot
.69635 .79068 Mdot
.46861 .84017 Mdot
.54204 .18639 Mdot
.21568 .26391 Mdot
.78763 .54966 Mdot
.49783 .59629 Mdot
.50556 .47634 Mdot
.39949 .25881 Mdot
.60022 .20316 Mdot
.49856 .18113 Mdot
.70007 .67242 Mdot
.16714 .47999 Mdot
.55059 .83957 Mdot
.26629 .35713 Mdot
.22309 .35883 Mdot
.75365 .32206 Mdot
.53729 .45343 Mdot
.42409 .70261 Mdot
.70478 .47903 Mdot
.45299 .79033 Mdot
.71035 .74141 Mdot
.33755 .32984 Mdot
.24838 .25429 Mdot
.49597 .34394 Mdot
.66018 .32533 Mdot
.30701 .74808 Mdot
.46183 .24401 Mdot
.29744 .34334 Mdot
.79807 .42322 Mdot
.35164 .38853 Mdot
.81252 .45662 Mdot
.51864 .79859 Mdot
.65567 .53263 Mdot
.81455 .51872 Mdot
.47658 .76114 Mdot
.18645 .56101 Mdot
.30229 .66659 Mdot
.79211 .59685 Mdot
.4213 .6906 Mdot
.42077 .28249 Mdot
.31502 .32026 Mdot
.357 .81988 Mdot
.67967 .51554 Mdot
.29203 .78705 Mdot
.75276 .37241 Mdot
.42128 .49375 Mdot
.32431 .38986 Mdot
.48014 .43521 Mdot
.39598 .2936 Mdot
.41371 .38654 Mdot
.65499 .68771 Mdot
.34192 .80427 Mdot
.21204 .49588 Mdot
.65688 .53967 Mdot
.70277 .70171 Mdot
.25206 .72296 Mdot
.24351 .63414 Mdot
.69175 .32039 Mdot
.41098 .32996 Mdot
.82914 .40354 Mdot
.67194 .44534 Mdot
.26366 .35771 Mdot
.62842 .65319 Mdot
.61649 .25624 Mdot
.34285 .62103 Mdot
.5832 .20802 Mdot
.34084 .80366 Mdot
.76857 .41153 Mdot
.73507 .34535 Mdot
.48232 .22296 Mdot
.26919 .29451 Mdot
.69416 .71914 Mdot
.33657 .47224 Mdot
.46452 .6935 Mdot
.52435 .30722 Mdot
.24609 .60264 Mdot
.24699 .38365 Mdot
.62193 .33999 Mdot
.45778 .40606 Mdot
.55268 .22842 Mdot
.61962 .38776 Mdot
.60164 .53694 Mdot
.8242 .64436 Mdot
.36041 .37645 Mdot
.76403 .60906 Mdot
.21425 .6542 Mdot
.37574 .28386 Mdot
.30778 .74187 Mdot
.47228 .73467 Mdot
.76933 .68213 Mdot
.43789 .8354 Mdot
.61334 .3102 Mdot
.63927 .79309 Mdot
.34874 .82387 Mdot
.79281 .6477 Mdot
.3661 .36169 Mdot
.62967 .58519 Mdot
.84833 .65057 Mdot
.67674 .48701 Mdot
.73801 .67228 Mdot
.22982 .42428 Mdot
.69817 .58033 Mdot
.43879 .59332 Mdot
.40747 .51309 Mdot
.50416 .55622 Mdot
.35198 .66555 Mdot
.44653 .40264 Mdot
.84554 .58292 Mdot
.78273 .64474 Mdot
.81637 .63233 Mdot
.17983 .60003 Mdot
.63817 .79741 Mdot
.47504 .55837 Mdot
.30319 .54395 Mdot
.43606 .55367 Mdot
.34757 .42011 Mdot
.50641 .28862 Mdot
.78691 .54643 Mdot
.5748 .22789 Mdot
.5856 .70899 Mdot
.41091 .69823 Mdot
.61425 .78406 Mdot
.88573 .39649 Mdot
.22577 .51995 Mdot
.25335 .43378 Mdot
.80137 .54053 Mdot
.38929 .30122 Mdot
.47967 .79564 Mdot
.55244 .20263 Mdot
.33107 .78501 Mdot
.42381 .56178 Mdot
.22432 .4058 Mdot
.63566 .36173 Mdot
.35181 .24325 Mdot
.62681 .37795 Mdot
.40308 .80481 Mdot
.47039 .51908 Mdot
.64787 .2487 Mdot
.50311 .64297 Mdot
.54557 .1813 Mdot
.63655 .28738 Mdot
.73187 .5316 Mdot
.24773 .36399 Mdot
.68846 .66209 Mdot
.3785 .31183 Mdot
.51576 .52677 Mdot
.44008 .51269 Mdot
.51786 .46319 Mdot
.36544 .31389 Mdot
.36845 .237 Mdot
.6971 .74989 Mdot
.35588 .83908 Mdot
.85729 .49702 Mdot
.14521 .55851 Mdot
.51692 .79344 Mdot
.37145 .38698 Mdot
.29295 .7512 Mdot
.78486 .6828 Mdot
.43972 .84225 Mdot
.75907 .44922 Mdot
.60131 .50202 Mdot
.56698 .61211 Mdot
.85213 .51392 Mdot
.64788 .37446 Mdot
.34486 .7714 Mdot
.82088 .46034 Mdot
.6212 .57154 Mdot
.72542 .26815 Mdot
.77693 .64384 Mdot
.35468 .59547 Mdot
.35597 .35545 Mdot
.35339 .39339 Mdot
.31382 .52223 Mdot
.44356 .66582 Mdot
.70624 .51762 Mdot
.41927 .29444 Mdot
.66276 .44319 Mdot
.54082 .2665 Mdot
.47104 .67244 Mdot
.46436 .44156 Mdot
.50984 .45262 Mdot
.43952 .61717 Mdot
.62595 .75634 Mdot
.66517 .59347 Mdot
.67887 .7833 Mdot
.78072 .53299 Mdot
.45283 .39146 Mdot
.36834 .29031 Mdot
.74231 .40983 Mdot
.79363 .40944 Mdot
.62282 .65164 Mdot
.47769 .8266 Mdot
.55244 .43893 Mdot
.41844 .28483 Mdot
.31069 .51379 Mdot
.19434 .57194 Mdot
.39789 .50959 Mdot
.54928 .75789 Mdot
.29136 .62019 Mdot
.59206 .53338 Mdot
.42543 .7005 Mdot
.41846 .70651 Mdot
.21623 .69994 Mdot
.79563 .48083 Mdot
.71404 .53007 Mdot
.4645 .82442 Mdot
.61529 .63609 Mdot
.43419 .63225 Mdot
.4926 .30459 Mdot
.18809 .57549 Mdot
.30204 .59701 Mdot
.68165 .30113 Mdot
.75521 .57165 Mdot
.63545 .33395 Mdot
.48342 .81918 Mdot
.50693 .82074 Mdot
.50836 .15619 Mdot
.38152 .6922 Mdot
.21365 .61264 Mdot
.1889 .46645 Mdot
.44625 .63962 Mdot
.42279 .58029 Mdot
.61955 .70677 Mdot
.69337 .76252 Mdot
.65717 .60751 Mdot
.1616 .4853 Mdot
.37704 .24503 Mdot
.70413 .59362 Mdot
.69465 .29421 Mdot
.24876 .35035 Mdot
.45156 .82137 Mdot
.29659 .47162 Mdot
.36016 .60251 Mdot
.44938 .48227 Mdot
.42988 .34877 Mdot
.86332 .45968 Mdot
.69988 .45332 Mdot
.32326 .55514 Mdot
.46728 .75522 Mdot
.42131 .45784 Mdot
.8678 .52136 Mdot
.23812 .66857 Mdot
.80065 .39813 Mdot
.58249 .58469 Mdot
.39689 .48001 Mdot
.3407 .42354 Mdot
.38957 .33303 Mdot
.54333 .74361 Mdot
.7451 .67999 Mdot
.24575 .35453 Mdot
.4747 .77908 Mdot
.28876 .47275 Mdot
.76184 .61203 Mdot
.36989 .77359 Mdot
.28059 .71412 Mdot
.56243 .51537 Mdot
.78624 .53396 Mdot
.46033 .22851 Mdot
.15094 .55828 Mdot
.5645 .4048 Mdot
.47228 .57069 Mdot
.6021 .69281 Mdot
.50575 .74907 Mdot
.64945 .25884 Mdot
.35285 .45374 Mdot
.76334 .38943 Mdot
.36842 .78782 Mdot
.41884 .1768 Mdot
.64981 .23103 Mdot
.86462 .53625 Mdot
.31559 .63659 Mdot
.48961 .7441 Mdot
.36559 .73931 Mdot
.37817 .18043 Mdot
.55416 .40698 Mdot
.59642 .80344 Mdot
.4672 .22463 Mdot
.4739 .82201 Mdot
.63947 .59872 Mdot
.51665 .64826 Mdot
.70652 .69867 Mdot
.67104 .77521 Mdot
.26333 .65232 Mdot
.39939 .7972 Mdot
.51312 .61378 Mdot
.74395 .73138 Mdot
.67789 .69084 Mdot
.49404 .54197 Mdot
.62172 .43362 Mdot
.7839 .42691 Mdot
.49376 .80709 Mdot
.57928 .77992 Mdot
.24895 .37001 Mdot
.68727 .40749 Mdot
.4785 .31847 Mdot
.36386 .56896 Mdot
.4906 .25206 Mdot
.50368 .75897 Mdot
.36896 .28962 Mdot
.37559 .80488 Mdot
.57377 .3916 Mdot
.74077 .36273 Mdot
.75917 .61149 Mdot
.20795 .37243 Mdot
.54915 .74027 Mdot
.79567 .46973 Mdot
.30465 .72144 Mdot
.64648 .30766 Mdot
.29397 .32311 Mdot
.40294 .89447 Mdot
.20421 .41302 Mdot
.64636 .73346 Mdot
.71148 .73978 Mdot
.29748 .73561 Mdot
.64069 .74502 Mdot
.61341 .20596 Mdot
.30487 .35633 Mdot
.47812 .29821 Mdot
.39801 .4302 Mdot
.81791 .64774 Mdot
.46351 .26568 Mdot
.72411 .73501 Mdot
.27398 .74074 Mdot
.32517 .53327 Mdot
.46392 .43999 Mdot
.68566 .45378 Mdot
.71408 .48458 Mdot
.50897 .25627 Mdot
.34193 .65442 Mdot
.28543 .3693 Mdot
.76711 .5503 Mdot
.62978 .41692 Mdot
.63179 .37503 Mdot
.38096 .59605 Mdot
.7764 .50639 Mdot
.52612 .75351 Mdot
.5448 .28099 Mdot
.55032 .54311 Mdot
.36987 .30787 Mdot
.29499 .40812 Mdot
.35086 .59863 Mdot
.59161 .21246 Mdot
.53903 .47205 Mdot
.63873 .45409 Mdot
.32983 .64987 Mdot
.17231 .4771 Mdot
.50194 .77205 Mdot
.75452 .68833 Mdot
.78351 .41278 Mdot
.44205 .52905 Mdot
.36803 .31733 Mdot
.58213 .19899 Mdot
.33236 .24374 Mdot
.63291 .76294 Mdot
.30493 .43551 Mdot
.29587 .29672 Mdot
.48051 .64908 Mdot
.60414 .82291 Mdot
.22721 .38595 Mdot
.21503 .43678 Mdot
.71931 .44437 Mdot
.2939 .56077 Mdot
.34337 .54443 Mdot
.43 .23806 Mdot
.54638 .56026 Mdot
.76665 .27637 Mdot
.43779 .60713 Mdot
.88092 .46905 Mdot
.60438 .5912 Mdot
.77205 .33181 Mdot
.45602 .2176 Mdot
.51618 .52257 Mdot
.5372 .57313 Mdot
.56056 .75473 Mdot
.5461 .68227 Mdot
.1616 .55908 Mdot
.49058 .16985 Mdot
.68927 .44081 Mdot
.24728 .33349 Mdot
.21715 .34325 Mdot
.3355 .68063 Mdot
.45118 .43745 Mdot
.20094 .41462 Mdot
.68851 .42016 Mdot
.57717 .22751 Mdot
.28032 .73301 Mdot
.55649 .77709 Mdot
.46152 .37603 Mdot
.39668 .29927 Mdot
.58672 .80582 Mdot
.4358 .8305 Mdot
.67641 .23421 Mdot
.51901 .79824 Mdot
.62666 .58338 Mdot
.48282 .54948 Mdot
.42209 .79818 Mdot
.3323 .28495 Mdot
.49656 .69695 Mdot
.30844 .32152 Mdot
.84704 .38077 Mdot
.7283 .69359 Mdot
.74435 .68016 Mdot
.32495 .29965 Mdot
.36733 .66261 Mdot
.66312 .69937 Mdot
.3004 .33903 Mdot
.56792 .76978 Mdot
.16856 .54108 Mdot
.30949 .32609 Mdot
.48504 .14408 Mdot
.20039 .51774 Mdot
.58761 .40346 Mdot
.35101 .54636 Mdot
.20587 .51953 Mdot
.60532 .57295 Mdot
.49928 .28235 Mdot
.46578 .76058 Mdot
.58421 .59147 Mdot
.5099 .75974 Mdot
.50227 .72919 Mdot
.20299 .47014 Mdot
.312 .59721 Mdot
.48757 .78373 Mdot
.32517 .69571 Mdot
.37863 .72249 Mdot
.612 .2464 Mdot
.61575 .41424 Mdot
.44713 .76011 Mdot
.62762 .46073 Mdot
.34086 .50425 Mdot
.58329 .52735 Mdot
.48808 .45956 Mdot
.85156 .49192 Mdot
.52355 .30966 Mdot
.38123 .62587 Mdot
.78685 .33768 Mdot
.43881 .62247 Mdot
.83566 .60811 Mdot
.56615 .20688 Mdot
.30361 .50577 Mdot
.61906 .30423 Mdot
.60579 .36462 Mdot
.62146 .16987 Mdot
.39212 .57513 Mdot
.7219 .44764 Mdot
.37713 .71362 Mdot
.37279 .65165 Mdot
.76648 .5842 Mdot
.63931 .41479 Mdot
.32718 .36051 Mdot
.60473 .68225 Mdot
.43975 .54242 Mdot
.3608 .66956 Mdot
.56522 .4759 Mdot
.44588 .32169 Mdot
.68523 .77014 Mdot
.63918 .44019 Mdot
.82322 .3637 Mdot
.43398 .49041 Mdot
.28588 .65188 Mdot
.32367 .78342 Mdot
.70341 .25195 Mdot
.65152 .50614 Mdot
.22881 .30538 Mdot
.41343 .49442 Mdot
.49138 .78828 Mdot
.40416 .66572 Mdot
.22029 .4229 Mdot
.52043 .32835 Mdot
.3835 .27412 Mdot
.56804 .6224 Mdot
.65063 .25122 Mdot
.77108 .50637 Mdot
.36472 .66352 Mdot
.5511 .78906 Mdot
.20434 .58399 Mdot
.51571 .66977 Mdot
.60251 .38932 Mdot
.33554 .66332 Mdot
.30726 .59148 Mdot
.3607 .66566 Mdot
.7287 .70596 Mdot
.2186 .41199 Mdot
.57186 .84735 Mdot
.47894 .43539 Mdot
.72114 .37708 Mdot
.57952 .68358 Mdot
.52661 .76384 Mdot
.32591 .37341 Mdot
.33818 .79443 Mdot
.43137 .28722 Mdot
.62132 .69001 Mdot
.40869 .31009 Mdot
.38021 .52114 Mdot
.54047 .53891 Mdot
.73102 .49986 Mdot
.5527 .16051 Mdot
.37658 .34342 Mdot
.72378 .28597 Mdot
.30732 .44608 Mdot
.77157 .59666 Mdot
.38582 .60113 Mdot
.5986 .48566 Mdot
.30408 .56442 Mdot
.68374 .51319 Mdot
.58736 .83181 Mdot
.3346 .79089 Mdot
.57812 .57742 Mdot
.75672 .59671 Mdot
.4186 .74372 Mdot
.47521 .43955 Mdot
.51486 .62436 Mdot
.43011 .40684 Mdot
.40167 .58896 Mdot
.72462 .26321 Mdot
.5594 .76581 Mdot
.32712 .46073 Mdot
.59096 .82248 Mdot
.53653 .84538 Mdot
.73707 .73466 Mdot
.27252 .29922 Mdot
.40889 .68679 Mdot
.81014 .62968 Mdot
.28249 .40275 Mdot
.38755 .8188 Mdot
.6207 .76869 Mdot
.23258 .71723 Mdot
.34958 .62247 Mdot
.46504 .74627 Mdot
.50382 .17562 Mdot
.53318 .69455 Mdot
.25975 .70556 Mdot
.4956 .51324 Mdot
.69739 .54415 Mdot
.25981 .71148 Mdot
.51525 .12303 Mdot
.30951 .40256 Mdot
.49417 .72393 Mdot
.48335 .6181 Mdot
.45366 .76117 Mdot
.68532 .32928 Mdot
.35924 .40784 Mdot
.70588 .64557 Mdot
.71271 .31373 Mdot
.3553 .31137 Mdot
.47957 .31754 Mdot
.68296 .32896 Mdot
.51973 .2615 Mdot
.42818 .31421 Mdot
.22819 .37946 Mdot
.3428 .63325 Mdot
.3306 .36134 Mdot
.41911 .49628 Mdot
.39736 .59406 Mdot
.56447 .33536 Mdot
.60997 .47703 Mdot
.41821 .40254 Mdot
.6567 .5107 Mdot
.52645 .67776 Mdot
.85788 .55329 Mdot
.64997 .54329 Mdot
.21337 .63583 Mdot
.44435 .61722 Mdot
.54619 .74863 Mdot
.32703 .71869 Mdot
.76456 .34684 Mdot
.68527 .35607 Mdot
.33745 .32976 Mdot
.55711 .82653 Mdot
.81352 .52154 Mdot
.18606 .53496 Mdot
.82144 .55551 Mdot
.60613 .57936 Mdot
.41868 .35985 Mdot
.47849 .59952 Mdot
.76562 .43003 Mdot
.40703 .70502 Mdot
.46929 .7478 Mdot
.71543 .4186 Mdot
.80561 .49216 Mdot
.21744 .65986 Mdot
.19892 .57576 Mdot
.3796 .56665 Mdot
.517 .82369 Mdot
.66574 .41687 Mdot
.21101 .42694 Mdot
.49125 .69161 Mdot
.69803 .36769 Mdot
.76635 .63029 Mdot
.65359 .79785 Mdot
.52075 .60887 Mdot
.44296 .25614 Mdot
.40914 .46892 Mdot
.25775 .46048 Mdot
.56739 .76024 Mdot
.49606 .37812 Mdot
.75789 .52835 Mdot
.40164 .62159 Mdot
.74717 .51519 Mdot
.55045 .39448 Mdot
.48007 .29177 Mdot
.35981 .68131 Mdot
.26961 .37664 Mdot
.54233 .35975 Mdot
.58935 .67422 Mdot
.43562 .39474 Mdot
.42371 .26054 Mdot
.28493 .28991 Mdot
.41163 .36167 Mdot
.48662 .80102 Mdot
.33642 .64119 Mdot
.18125 .54929 Mdot
.5211 .77626 Mdot
.64267 .75736 Mdot
.54918 .68761 Mdot
.31885 .57105 Mdot
.74991 .4277 Mdot
.43055 .40021 Mdot
.60204 .49258 Mdot
.42809 .62072 Mdot
.37283 .75698 Mdot
.31068 .63257 Mdot
.43712 .24257 Mdot
.53189 .50712 Mdot
.31884 .71045 Mdot
.52676 .48986 Mdot
.30565 .76181 Mdot
.53492 .69567 Mdot
.42389 .29431 Mdot
.64696 .6199 Mdot
.45345 .21997 Mdot
.60377 .2092 Mdot
.50255 .83977 Mdot
.56313 .19457 Mdot
.51036 .58077 Mdot
.72512 .28265 Mdot
.65549 .71783 Mdot
.26918 .72758 Mdot
.43293 .30046 Mdot
.52499 .60237 Mdot
.48257 .32699 Mdot
.57765 .57463 Mdot
.55214 .48402 Mdot
.58406 .46274 Mdot
.30119 .37771 Mdot
.73373 .56656 Mdot
.7373 .45522 Mdot
.42805 .5036 Mdot
.73752 .65965 Mdot
.54022 .82652 Mdot
.22538 .42479 Mdot
.52572 .46575 Mdot
.59766 .26017 Mdot
.47819 .28634 Mdot
.12751 .55081 Mdot
.8731 .51118 Mdot
.41135 .46867 Mdot
.52488 .45569 Mdot
.41603 .27356 Mdot
.68907 .45323 Mdot
.2908 .37726 Mdot
.34557 .72052 Mdot
.62048 .59793 Mdot
.58768 .48483 Mdot
.80523 .47705 Mdot
.57153 .75166 Mdot
.48817 .24138 Mdot
.72144 .66061 Mdot
.8576 .56487 Mdot
.1598 .51149 Mdot
.53966 .76516 Mdot
.14987 .61609 Mdot
.74484 .46843 Mdot
.43897 .69541 Mdot
.29493 .69204 Mdot
.70068 .74927 Mdot
.366 .28693 Mdot
.64705 .26573 Mdot
.67346 .73634 Mdot
.43419 .29186 Mdot
.28952 .34205 Mdot
.76152 .60787 Mdot
.75121 .51772 Mdot
.51226 .54371 Mdot
.6068 .36501 Mdot
.80227 .60094 Mdot
.29798 .48419 Mdot
.55844 .8177 Mdot
.71346 .31151 Mdot
.45697 .14432 Mdot
.54873 .8456 Mdot
.51787 .27877 Mdot
.68586 .32286 Mdot
.28792 .68524 Mdot
.35658 .26057 Mdot
.28102 .36256 Mdot
.60338 .22983 Mdot
.2917 .59248 Mdot
.60005 .34788 Mdot
.72327 .30104 Mdot
.3766 .31222 Mdot
.20733 .50902 Mdot
.52531 .59887 Mdot
.33809 .61809 Mdot
.77266 .56126 Mdot
.3324 .30166 Mdot
.56683 .45508 Mdot
.38781 .2504 Mdot
.33094 .65953 Mdot
.31794 .72533 Mdot
.46639 .72096 Mdot
.54466 .1328 Mdot
.64005 .76755 Mdot
.76013 .34062 Mdot
.40751 .38268 Mdot
.6155 .82505 Mdot
.47787 .71177 Mdot
.66526 .74649 Mdot
.19069 .60588 Mdot
.59184 .44771 Mdot
.5475 .66346 Mdot
.42856 .39898 Mdot
.55698 .80065 Mdot
.3272 .55648 Mdot
.20786 .53574 Mdot
.67073 .26924 Mdot
.37858 .28917 Mdot
.69936 .32337 Mdot
.41601 .23596 Mdot
.44779 .37493 Mdot
.41396 .61065 Mdot
.81063 .64426 Mdot
.50563 .59596 Mdot
.33031 .48971 Mdot
.46609 .36564 Mdot
.51573 .17366 Mdot
.16903 .43099 Mdot
.47901 .42689 Mdot
.80907 .54514 Mdot
.27645 .34662 Mdot
.43085 .52898 Mdot
.30136 .45716 Mdot
.12529 .37214 Mdot
.36308 .83559 Mdot
.39358 .69119 Mdot
.25227 .40551 Mdot
.28406 .31465 Mdot
.69344 .75574 Mdot
.63848 .36001 Mdot
.60794 .44008 Mdot
.43686 .18857 Mdot
.33594 .26862 Mdot
.43334 .48562 Mdot
.2049 .63996 Mdot
.48568 .83791 Mdot
.68483 .27678 Mdot
.5799 .82779 Mdot
.31535 .45092 Mdot
.33504 .46514 Mdot
.11251 .44626 Mdot
.42941 .80477 Mdot
.35084 .39076 Mdot
.51797 .17089 Mdot
.4276 .70089 Mdot
.41384 .4277 Mdot
.72703 .65191 Mdot
.24456 .36493 Mdot
.37612 .31423 Mdot
.67267 .77418 Mdot
.38099 .69654 Mdot
.67652 .51282 Mdot
.62591 .60071 Mdot
.54042 .56803 Mdot
.38228 .49656 Mdot
.5947 .63182 Mdot
.44545 .51596 Mdot
.45003 .751 Mdot
.60283 .57088 Mdot
.23027 .35263 Mdot
.27421 .76732 Mdot
.32306 .6222 Mdot
.55964 .62543 Mdot
.47497 .46035 Mdot
.20109 .52429 Mdot
.51209 .25821 Mdot
.4482 .55523 Mdot
.25256 .71128 Mdot
.51295 .89711 Mdot
.70552 .54709 Mdot
.4534 .33957 Mdot
.3606 .68393 Mdot
.32634 .3667 Mdot
.35624 .57893 Mdot
.63927 .66147 Mdot
.65744 .41828 Mdot
.4692 .42453 Mdot
.44809 .37631 Mdot
.56935 .61332 Mdot
.87286 .45847 Mdot
.3521 .42461 Mdot
.29727 .43909 Mdot
.3933 .81823 Mdot
.61494 .24719 Mdot
.27186 .64105 Mdot
.36017 .47438 Mdot
.65194 .69882 Mdot
.52515 .60455 Mdot
.42029 .7717 Mdot
.74209 .36672 Mdot
.63162 .79325 Mdot
.30815 .63154 Mdot
.36298 .553 Mdot
.36593 .41626 Mdot
.57169 .32241 Mdot
.50305 .71474 Mdot
.68978 .73316 Mdot
.31236 .42131 Mdot
.41632 .8322 Mdot
.59082 .4403 Mdot
.74505 .57671 Mdot
.41526 .53909 Mdot
.75777 .7032 Mdot
.69504 .26515 Mdot
.34069 .55412 Mdot
.79205 .37598 Mdot
.78205 .45604 Mdot
.48777 .25308 Mdot
.68478 .44331 Mdot
.34231 .49052 Mdot
.37627 .6933 Mdot
.85962 .57479 Mdot
.69565 .72801 Mdot
.68303 .61352 Mdot
.73228 .53494 Mdot
.27459 .49616 Mdot
.49733 .66328 Mdot
.2051 .69593 Mdot
.66435 .37106 Mdot
.86182 .55382 Mdot
.21377 .43421 Mdot
.36373 .61304 Mdot
.48668 .75121 Mdot
.37647 .36446 Mdot
.64343 .45245 Mdot
.67237 .76642 Mdot
.44552 .37791 Mdot
.75451 .35745 Mdot
.38387 .48538 Mdot
.80669 .41397 Mdot
.60307 .5184 Mdot
.74376 .6231 Mdot
.69079 .66002 Mdot
.6157 .20843 Mdot
.34944 .76179 Mdot
.637 .56523 Mdot
.16861 .6356 Mdot
.38208 .76115 Mdot
.47877 .82747 Mdot
.67185 .29448 Mdot
.65665 .21171 Mdot
.58906 .77811 Mdot
.49204 .78098 Mdot
.66789 .59055 Mdot
.49208 .48447 Mdot
.77837 .42207 Mdot
.43843 .51985 Mdot
.51843 .71401 Mdot
.58955 .56806 Mdot
.62388 .88853 Mdot
.49856 .31178 Mdot
.46404 .67115 Mdot
.75738 .41307 Mdot
.51894 .83184 Mdot
.49656 .42027 Mdot
.22629 .6783 Mdot
.5479 .41759 Mdot
.34184 .47864 Mdot
.30656 .60801 Mdot
.23119 .41345 Mdot
.79041 .42917 Mdot
.66962 .19013 Mdot
.16153 .5158 Mdot
.73646 .55411 Mdot
.55739 .53359 Mdot
.44629 .6429 Mdot
.44153 .59544 Mdot
.61936 .32995 Mdot
.18782 .63566 Mdot
.46039 .74746 Mdot
.42301 .79906 Mdot
.60662 .16513 Mdot
.191 .49428 Mdot
.69573 .75682 Mdot
.62288 .74671 Mdot
.42312 .59491 Mdot
.52856 .27044 Mdot
.57938 .28454 Mdot
.69712 .64935 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Dooooo`;o
0000/oooool001cooooo00?o0000ooooooooool0U?ooool2o`000;?ooooo000Looooo`03o`000?oo
oooooooo0:Cooooo0_l0002Sooooo`007?ooool00ol0003oooooooooo`2Tooooo`;o0000Xoooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0:gooooo0_l0002Jooooo`007?ooool00ol0003ooooooooo
o`2]ooooo`;o0000V_ooool001cooooo00?o0000ooooooooool0S_ooool2o`0001?ooooo0_l0002T
ooooo`007?ooool00ol0003oooooooooo`2>ooooo`;o000000?oooooo`000?l000001oooool2o`00
00Oooooo0_l0002Tooooo`007?ooool00ol0003oooooooooo`2Aooooo`;o00001oooool2o`0000[o
oooo1?l0002Oooooo`007?ooool00ol0003oooooooooo`2Vooooo`Co00002?ooool2o`0009Gooooo
000Looooo`;o0000WOooool2o`00013ooooo0_l00002ooooo`;o0000UOooool001cooooo00?o0000
ooooooooool0W?ooool2o`0000?ooooo0_l0000;ooooo`;o0000VOooool001cooooo00?o0000oooo
ooooool0XOooool2o`000:Kooooo000Looooo`03o`000?oooooooooo0:Gooooo0_l00009ooooo`;o
0000Uoooool001cooooo00?o0000ooooooooool0YOooool2o`0000Wooooo0_l0000?ooooo`;o0000
Q_ooool001cooooo00?o0000ooooooooool0YOooool2o`0000Wooooo0_l0000?ooooo`;o0000Q_oo
ool001cooooo00?o0000ooooooooool0TOooool2o`0000Wooooo0_l00006ooooo`?o00002Oooool2
o`0001;ooooo1?l00021ooooo`007?ooool00ol0003oooooooooo`2Aooooo`;o00002Oooool2o`00
00Cooooo1?l0000Nooooo`Co0000POooool001cooooo00?o0000ooooooooool0Q?ooool2o`0000?o
oooo0_l00009ooooo`;o00002_ooool6o`0000Wooooo0_l0002Hooooo`007?ooool00ol0003ooooo
ooooo`1gooooo`;o00002oooool2o`0000?ooooo1Ol00006ooooo`;o00002?ooool6o`0000Wooooo
1?l00003ooooo`;o0000Toooool001cooooo00?o0000ooooooooool0IOooool2o`00013ooooo0_l0
000Booooo`?o00004?ooool2o`0000Kooooo0_l00005ooooo`?o000000Coooooo`000?l0003ooooo
0_l000000ooooooo0000o`00002@ooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o0000?ooo
ool2o`0000Cooooo1?l000000ooooooo0000o`000004ooooo`;o0000T?ooool001cooooo00?o0000
ooooooooool0OOooool2o`0000Kooooo0_l00002ooooo`?o00008?ooool2o`00023ooooo0_l00006
ooooo`;o0000LOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol0
0006ooooo`03o`000?oooooooooo06;ooooo0_l0000Eooooo`?o000000?oooooo`000?l000000_oo
ool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000oooooo0_l0000aooooo`;o00001_oo
ool2o`00077ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1Rooooo`;o00005Oooool3o`0000Go
oooo0_l00005ooooo`;o00004Oooool2o`0001Kooooo0_l0000@ooooo`;o0000P_ooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`00
0?oooooooooo07[ooooo0_l0000gooooo`;o00000oooool3o`0000Wooooo0ol00022ooooo`0000?o
ooooo`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0
001Xooooo`;o0000A_ooool2o`000003ooooool0003o000000?ooooo0ol00009ooooo`;o0000Pooo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`05
ooooo`03o`000?oooooooooo06Sooooo0_l000000ooooooo0000o`00000@ooooo`;o0000<Oooool2
o`0000Oooooo1?l00002ooooo`;o000000Coooooo`000?l0003o0000Q?ooool00003ooooool@413o
oooo00;ooooo00?o410@ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06_ooooo0_l0000@ooooo`;o00003oooool2o`00023ooooo0_l00002ooooo`;o00000oooool4
o`0000;ooooo1ol00023ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj
^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`1Vooooo`;o00009_ooool2o`00023ooooo
0_l00002ooooo`;o00001?ooool2o`0000Cooooo0_l00002ooooo`;o00003?ooool2o`0000Wooooo
0_l0001Zooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01_ooool00ol0003oooooooooo`1Vooooo`;o00004?ooool2o`0000Cooooo0_l00007oooo
o`;o000000?oooooo`000?l000009Oooool2o`0000Wooooo0_l00007ooooo`;o00002?ooool2o`00
0003ooooool0003o000000Wooooo0_l0001Zooooo`007?ooool00ol0003oooooooooo`1^ooooo`;o
00002?ooool2o`0000Cooooo0_l00007ooooo`;o000000?oooooo`000?l000001?ooool2o`0001co
oooo0_l000000ooooooo0000o`000009ooooo`;o00001oooool2o`0000Sooooo0ol0001gooooo`00
7?ooool00ol0003oooooooooo`1^ooooo`;o00007oooool3o`0001cooooo0_l0000:ooooo`;o0000
5?ooool2o`0007Oooooo000Looooo`03o`000?oooooooooo08Kooooo0_l00004ooooo`;o000000Co
ooooo`000?l0003o00000_ooool2o`0000?ooooo0_l0000Fooooo`;o00001oooool2o`0008gooooo
000Looooo`03o`000?oooooooooo08;ooooo0_l00002ooooo`Co000000Coooooo`000?l0003o0000
1_ooool2o`0000?ooooo0_l0000Fooooo`;o00001Oooool2o`0000Sooooo0_l0000;ooooo`;o0000
N?ooool001cooooo00?o0000ooooooooool0OOooool2o`0000?ooooo0_l00004ooooo`Go00000ooo
ool4o`0001cooooo0_l00005ooooo`?o00001?ooool6o`0000Oooooo0_l00002ooooo`;o0000N?oo
ool001cooooo00?o0000ooooooooool0Loooool2o`0000Sooooo0_l0000:ooooo`;o00000oooool7
o`0001_ooooo0ol00004ooooo`;o00001Oooool4o`0000Wooooo0_l000000ooooooo0000o`000002
o`0007Oooooo000Looooo`03o`000?oooooooooo06[ooooo0_l00007ooooo`?o00003Oooool2o`00
00Wooooo1?l000000ooooooo0000o`000005o`0000oooooo0_l00006ooooo`;o00001oooool2o`00
00Sooooo0_l00008ooooo`Ko00001?ooool2o`0006oooooo000Looooo`03o`000?oooooooooo06[o
oooo0_l00004ooooo`;o00000_ooool2o`0000gooooo0_l00003ooooo`;o00000oooool2o`0000Ko
oooo1Ol00009ooooo`;o00001?ooool2o`0000cooooo0_l000000ooooooo0000o`000008ooooo`;o
00003?ooool4o`0000;ooooo0_l0001_ooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o0000
5Oooool2o`0000Gooooo0_l0000?ooooo`Co000000?oooooo`000?l000003?ooool2o`0000Kooooo
0ol0000Aooooo`;o00001?ooool2o`0000Oooooo0_l000000ooooooo0000o`000009ooooo`;o0000
Loooool001cooooo00?o0000ooooooooool0Doooool2o`0000Cooooo1?l0000;ooooo`;o00001Ooo
ool2o`0000Kooooo1?l00003ooooo`;o00002Oooool3o`0000Kooooo0_l00005ooooo`Go00001Ooo
ool3o`000003ooooool0003o000000cooooo0_l00006ooooo`;o00000oooool2o`0000;ooooo0_l0
00000ooooooo0000o`00000:ooooo`;o00001_ooool2o`0000gooooo0_l0001Kooooo`007?ooool0
0ol0003oooooooooo`1Cooooo`;o00001_ooool2o`0000_ooooo0ol00004ooooo`;o00001Oooool5
o`0000?ooooo0_l0000Booooo`;o00001Oooool2o`000003ooooool0003o000000Wooooo0_l0000<
ooooo`;o00001_ooool2o`0000?ooooo1?l00009ooooo`;o00001?ooool4o`0000Cooooo0_l0000=
ooooo`;o0000Foooool001cooooo0_l0001Vooooo`;o00000_ooool2o`0000Oooooo0_l00002oooo
o`;o00000_ooool2o`0000kooooo0_l00008ooooo`;o00001_ooool4o`00017ooooo0_l0000@oooo
o`?o00001Oooool2o`0000;ooooo0ol00005ooooo`;o000000?oooooo`000?l000001Oooool2o`00
06Kooooo000Looooo`03o`000?oooooooooo04gooooo0_l0000Fooooo`;o00002oooool4o`0000Co
oooo0_l0000>ooooo`;o00002?ooool2o`0000Gooooo1Ol00003ooooo`;o00003?ooool2o`0001Go
oooo0_l000000ooooooo0000o`000003ooooo`;o00002?ooool2o`0000Gooooo0_l0001Vooooo`00
7?ooool00ol0003oooooooooo`1=ooooo`;o00000_ooool2o`0000Oooooo0_l00002ooooo`;o0000
5?ooool2o`0000Cooooo0_l0000@ooooo`;o00003Oooool5o`000003ooooool0003o000000;o0000
0oooool2o`0000Sooooo0ol0000?ooooo`;o00000_ooool2o`0001?ooooo0_l0001Zooooo`007?oo
ool00ol0003oooooooooo`1=ooooo`;o00000_ooool2o`0000Oooooo0_l00002ooooo`;o000000?o
ooooo`000?l000001_ooool4o`000003ooooool0003o000000;o00001Oooool2o`0000Gooooo0_l0
0006ooooo`;o00001?ooool2o`0001?ooooo1_l000000ooooooo0000o`000003ooooo`;o00000ooo
ool3o`0000Wooooo0_l00004ooooo`;o00002Oooool2o`0000cooooo1?l0000@ooooo`;o00001Ooo
ool2o`0004oooooo000Looooo`03o`000?oooooooooo04;ooooo0_l0000Jooooo`;o000000?ooooo
o`000?l000001_ooool4o`000003ooooool0003o000000;o00001Oooool2o`000003ooooool0003o
000000;ooooo0_l000000ooooooo0000o`000003ooooo`;o00001_ooool2o`0001Gooooo0_l00006
ooooo`;o000000Coooooo`000?l0003o00002_ooool3o`0000oooooo0_l0000>ooooo`;o000000?o
ooooo`000?l000001?ooool2o`0000Oooooo0_l00005ooooo`;o0000Coooool001cooooo00?o0000
ooooooooool0@_ooool2o`0001[ooooo0_l00009ooooo`;o00001Oooool2o`0000Sooooo0_l00005
ooooo`;o00000oooool2o`0000Kooooo1?l000000ooooooo0000o`00000Gooooo`;o00000_ooool3
o`0000Sooooo1?l0000?ooooo`;o00003_ooool2o`0000;ooooo0_l00004ooooo`;o0000Goooool0
01cooooo00?o0000ooooooooool0AOooool2o`0001Oooooo0_l000000ooooooo0000o`000004oooo
o`Co00001oooool4o`0000Kooooo0_l0000?ooooo`;o000000Coooooo`000?l0003ooooo0_l0000C
ooooo`;o00000_ooool2o`0000Gooooo0_l00006ooooo`;o00002Oooool2o`000003ooooool0003o
000000?ooooo1?l00004ooooo`;o00001_ooool2o`0000Sooooo0_l0001Oooooo`007?ooool00ol0
003oooooooooo`15ooooo`;o00003_ooool2o`0000;ooooo0_l00006ooooo`;o000000?oooooo`00
0?l000001Ol00007ooooo`Co00001_ooool2o`0000Gooooo0_l00008ooooo`Co00005oooool2o`00
00?ooooo0_l00004ooooo`;o00004Oooool2o`000003ooooool0003o000000Gooooo0_l00004oooo
o`;o00002?ooool2o`0000Kooooo0_l0001Oooooo`007?ooool00ol0003oooooooooo`1Eooooo`;o
00000_ooool2o`0000Wooooo0ol0000;ooooo`;o000000?oooooo`000?l000000_ooool2o`0000So
oooo0_l0000:ooooo`;o000000?oooooo`000?l000000_l0000Gooooo`;o00001?ooool2o`0000[o
oooo0_l0000Iooooo`?o00000oooool2o`000003ooooool0003o0000013ooooo0_l0001Booooo`00
7?ooool00ol0003oooooooooo`1>ooooo`;o00008_ooool2o`000003ooooool0003o000000;ooooo
0_l00009ooooo`;o00001oooool4o`000003ooooool0003o000000;o00000_ooool2o`0000[ooooo
0_l00009ooooo`;o000000?oooooo`000?l000002_ooool3o`0001Wooooo0ol00006ooooo`;o0000
1_ooool2o`0000Sooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`1>ooooo`Co00002ooo
ool4o`0000gooooo0_l0000:ooooo`;o00002?ooool3o`0000Kooooo1?l000000ooooooo0000o`00
0004ooooo`;o00001?ooool2o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`Co000000?o
ooooo`000?l000001?ooool2o`0000Cooooo0_l0000Gooooo`;o00003oooool2o`000003ooooool0
003o000005cooooo000Looooo`03o`000?oooooooooo053ooooo0_l0000;ooooo`Co00001oooool2
o`0000Cooooo0_l00006ooooo`;o00000_ooool2o`0000Sooooo0ol0000@ooooo`;o00001Oooool2
o`0000;ooooo0_l00003ooooo`;o00001?ooool2o`0000Wooooo0ol00008ooooo`;o00004_ooool2
o`0000kooooo0ol0000<ooooo`;o0000DOooool001cooooo00?o0000ooooooooool0G_ooool2o`00
00Sooooo0_l00009ooooo`Ko00002oooool2o`0000;ooooo0_l0000;ooooo`Go00001oooool3o`00
01Cooooo0ol00008ooooo`;o00001_ooool2o`0000Wooooo0_l0000?ooooo`;o00001Oooool2o`00
00Kooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o00000oooool2o`0000Go
oooo0_l0000<ooooo`Ko00002_ooool2o`000003ooooool0003o000000?o00001Oooool2o`0000?o
oooo0_l000000ooooooo0000o`000007ooooo`;o00002?ooool4o`000004ooooool0003o0000oooo
o`;o00005_ooool2o`0000Kooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o
000000Wooooo0_l00005ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0E?ooool2o`00
00?ooooo0_l0000:ooooo`;o00001Oooool2o`0000Kooooo0_l00007ooooo`;o00001?ooool5o`00
0004ooooool0003o0000o`0000Cooooo0_l00003ooooo`;o000000?oooooo`000?l000003?ooool3
o`0000;ooooo1ol000000ooooooo0000o`00000>ooooo`;o00003_ooool2o`000004ooooool0003o
0000ooooo`;o000000?oooooo`000?l000000_l00007ooooo`;o0000H?ooool001cooooo00?o0000
ooooooooool0C?ooool2o`0000Kooooo0_l00003ooooo`;o000000?oooooo`000?l000001Oooool4
o`0000Gooooo0_l0000>ooooo`?o00001?ooool5o`0000;ooooo0ol00003ooooo`;o00001_ooool2
o`0000cooooo0ol000000ooooooo0000o`000008o`0000oooooo0_l0000<ooooo`;o00000oooool2
o`0000Kooooo0_l0001Yooooo`007?ooool2o`0004gooooo0_l00007ooooo`?o000000Coooooo`00
0?l0003ooooo0_l00004ooooo`So00004Oooool4o`0000;ooooo1?l00004ooooo`Co00000_ooool2
o`0000Cooooo0_l000000ooooooo0000o`00000<ooooo`?o000000?oooooo`000?l000002?l0000K
ooooo`Co00001_ooool4o`0000[ooooo0_l00007ooooo`;o0000Eoooool001cooooo00?o0000oooo
ooooool0EOooool3o`000003ooooool0003o000000Oooooo0_l00002ooooo`Co00004?ooool6o`00
0004ooooool0003o0000o`0000Gooooo0_l00004ooooo`;o00001?ooool4o`0000?ooooo0_l00004
ooooo`;o00001Oooool@o`0000cooooo0_l00008ooooo`?o00001oooool4o`0000Wooooo0ol00005
ooooo`Co0000Eoooool001cooooo00?o0000ooooooooool0Aoooool2o`0000oooooo0_l000000ooo
oooo0000o`00000Mooooo`;o00000_ooool2o`0000Kooooo0_l00002ooooo`;o00001?ooool2o`00
00Gooooo0_l00003ooooo`;o00001?ooool2o`000003ooooool0003o000001;o00003?ooool2o`00
00Oooooo0_l0000:ooooo`;o00002_ooool2o`0000Kooooo0_l00003ooooo`;o0000E?ooool001co
oooo00?o0000ooooooooool0A_ooool3o`0000Wooooo0_l00004ooooo`;o000000?oooooo`000?l0
00001Oooool2o`000003ooooool0003o000000?ooooo1?l000000ooooooo0000o`000003ooooo`;o
00002Oooool4o`0000?ooooo0_l00002ooooo`Co00000_ooool2o`0000[ooooo0_l00007oooooa7o
00003Oooool2o`0000Wooooo0_l0000:ooooo`;o000000?oooooo`000?l000005?ooool2o`0005Co
oooo000Looooo`03o`000?oooooooooo04Kooooo0_l000000ooooooo0000o`000004ooooo`;o0000
00?oooooo`000?l000000oooool2o`0000Wooooo1Ol00003ooooo`Co000000Goooooo`000?l0003o
0000ooooo`03o`000003ooooool0003o000000Kooooo1?l000000ooooooo0000o`000006ooooo`;o
00003?ooool2o`0000;ooooo0_l00005oooooa;o00001_ooool2o`0000Cooooo0_l0000>ooooo`Co
00001_ooool2o`0000Gooooo0_l0000<ooooo`;o0000EOooool001cooooo00?o0000ooooooooool0
@oooool2o`0000Cooooo0_l00004ooooo`;o00001_ooool4o`0000Sooooo0_l00003ooooo`;o0000
1_ooool2o`000004ooooool0003o0000ooooo`Go00002Oooool2o`000003ooooool0003o000000?o
oooo0_l0000<ooooo`;o00000_ooool2o`0000?ooooo5?l00006ooooo`;o00003oooool2o`0000?o
oooo1?l00007ooooo`;o00001?ooool2o`0000cooooo0ol0001Dooooo`007?ooool00ol0003ooooo
ooooo`10ooooo`;o000000?oooooo`000?l000003_ooool2o`0000;ooooo1?l0000;ooooo`Co0000
1_ooool2o`0000;ooooo1?l000000ooooooo0000o`000009ooooo`;o000000?oooooo`000?l00000
0oooool2o`0000Oooooo1ol00005oooooaGo00006?ooool2o`0000Gooooo0_l00007ooooo`Ko0000
00?oooooo`000?l000003?ooool2o`0005Cooooo000Looooo`03o`000?oooooooooo043ooooo0_l0
000;ooooo`;o00000_ooool4o`0000Oooooo0ol000001?oooooo0000o`000?ooool2o`000003oooo
ool0003o000000?ooooo0_l00007ooooo`;o000000?oooooo`000?l000000_l00009ooooo`;o0000
1oooool2o`0000Kooooo1ol00005oooooaOo00000oooool2o`0001Sooooo0_l00004ooooo`Wo0000
00?oooooo`000?l000001_ooool2o`0000;ooooo1?l0001Dooooo`007?ooool00ol0003ooooooooo
o`1=ooooo`Ko00002Oooool3o`000003ooooool0003o000000?o00001_ooool2o`0000[ooooo1?l0
0009ooooo`;o00000oooool6o`0000Gooooo0_l00004ooooo`;o000000Coooooo`000?l0003o0000
0_oooolFo`000003ooooool0003o000000;o00005_ooool4o`0000Cooooo2?l00002ooooo`?o0000
1?ooool3o`0000;ooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`1?ooooo`;o00001Ooo
ool3o`0000Cooooo0_l00002ooooo`;o00003Oooool2o`000003ooooool0003o000001Cooooo1?l0
00000ooooooo0000o`000004ooooo`;o00000oooool3o`000005ooooool0003o0000o`000?ooool0
5ol000001?oooooo0000o`000?l0000Aooooo`;o00001?ooool2o`0000Gooooo0ol00002ooooo`Co
00000oooool2o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`;o0000Doooool001cooooo
00?o0000ooooooooool0COooool3o`0000Kooooo0ol0000Aooooo`;o00000_ooool4o`000003oooo
ool0003o000000gooooo0_l00005ooooo`?o00000_ooool2o`0000Cooooo0_l00003ooooo`;o0000
00?oooooo`000?l000000_oooolEo`0000Gooooo0_l00009ooooo`;o00001_ooool2o`0000_ooooo
0ol00006ooooo`;o00002_ooool2o`0000?ooooo0_l000000ooooooo0000o`00001@ooooo`007?oo
ool00ol0003oooooooooo`1=ooooo`?o00006?ooool4o`000004ooooool0003o0000o`0000;ooooo
0ol00006ooooo`;o00001Oooool2o`0000Kooooo0_l00004ooooo`;o00000_ooool3o`0000Gooooo
0ol000000ooooooo0000o`00000Eo`0000kooooo0_l00004ooooo`;o00005_ooool2o`0000oooooo
0_l000000ooooooo0000o`00001@ooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00006Ooo
ool2o`0000?ooooo0_l00003ooooo`;o00001oooool4o`0000;ooooo0_l0000=ooooo`;o00000ooo
ool2o`0000;ooooo0_l000001Ooooooo0000o`000?l0003ooooo01Oo00005?ooool2o`0000cooooo
0_l0000Eooooo`;o00000_ooool3o`0000Gooooo0_l0001;ooooo`007?ooool00ol0003ooooooooo
o`1Jooooo`;o00000_ooool2o`0000_ooooo0_l000000ooooooo0000o`000005ooooo`;o00001_oo
ool2o`0000;ooooo0_l00004ooooo`;o00001oooool2o`0000Oooooo0_l00004ooooo`Ko000000?o
ooooo`000?l000004?l000000ooooooo0000o`00000;ooooo`;o00004Oooool2o`0000_ooooo0_l0
0008ooooo`;o000000?oooooo`000?l000000_l00005ooooo`;o0000Boooool001cooooo00?o0000
ooooooooool0@oooool2o`0000oooooo0_l00004ooooo`;o000000Coooooo`000?l0003o00002ooo
ool2o`000003ooooool0003o000000Gooooo1?l00005ooooo`;o00000_ooool2o`0000?ooooo0_l0
0007ooooo`;o00002_ooool6o`000004ooooool0003o0000oooooa;o000000?oooooo`000?l00000
2oooool2o`0001Kooooo0_l00006ooooo`Co00002Oooool2o`0005Cooooo000Looooo`03o`000?oo
oooooooo04?ooooo0ol0000>ooooo`Co00000_ooool2o`000003ooooool0003o000000[ooooo0_l0
0006ooooo`;o00001?ooool2o`0000Gooooo0_l00002ooooo`;o00006?ooool3o`000005ooooool0
003o0000o`000?ooool04_l00009ooooo`;o00007Oooool2o`0000Sooooo0_l000000ooooooo0000
o`000008ooooo`;o0000D_ooool001cooooo0_l00015ooooo`;o00001oooool2o`0000Oooooo0_l0
000Aooooo`;o00001Oooool3o`0000kooooo0_l00002ooooo`;o000000?oooooo`000?l000003_oo
ool2o`0000?ooooo0_l00002oooooa?o00002oooool2o`0002Sooooo1?l00008ooooo`;o00001ooo
ool2o`0004Wooooo000Looooo`03o`000?oooooooooo04Oooooo0_l00004ooooo`;o00002_ooool2
o`0000Gooooo0_l0000>ooooo`;o00003oooool2o`0000;ooooo0_l000000ooooooo0000o`000002
o`0000_ooooo1?l00002ooooo`;o00000oooool@o`000003ooooool0003o000003Cooooo0_l00006
ooooo`;o00002oooool2o`0004Wooooo000Looooo`03o`000?oooooooooo04Oooooo0_l00003oooo
o`?o00001?ooool4o`0000;ooooo0_l00004ooooo`?o00003_ooool2o`00017ooooo0_l00005oooo
o`?o00002_ooool5o`0000;ooooo0_l00002ooooo`ko00000oooool2o`0001Gooooo0_l0000?oooo
o`;o00003Oooool2o`0000Gooooo0_l00003ooooo`?o00002Oooool2o`0004Gooooo000Looooo`03
o`000?oooooooooo03Sooooo0_l0000;ooooo`;o00001Oooool4o`0000;ooooo1Ol00008ooooo`;o
00003oooool2o`0000Wooooo0_l00006ooooo`?o00001Oooool2o`0000[ooooo1Ol00002ooooo`;o
00000oooool>o`0001Wooooo1?l0000=ooooo`;o00000oooool2o`0000Sooooo0_l00005ooooo`;o
00000oooool3o`0000Wooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o0000
2oooool2o`0000Kooooo0ol00002ooooo`;o00001?ooool2o`0000gooooo0ol00002ooooo`;o0000
1Oooool2o`0000Gooooo0ol00005ooooo`Co00000_ooool2o`0000cooooo0_l00008ooooo`;o0000
2Oooool6o`0001[ooooo0ol0000=ooooo`;o00000oooool2o`0000;ooooo0_l00007ooooo`;o0000
0_ooool2o`0005Kooooo000Looooo`03o`000?oooooooooo04cooooo0ol00002ooooo`;o00001Ooo
ool2o`0000gooooo0ol00002ooooo`;o00001Oooool2o`0000;ooooo0_l000000ooooooo0000o`00
0002o`0000Cooooo0_l00004ooooo`;o00002_ooool4o`0000Oooooo0ol00003ooooo`Co00000_oo
ool4o`0001;ooooo0_l00008ooooo`;o00003_ooool2o`0000Oooooo0_l00006ooooo`?o00000ooo
ool2o`0001Cooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`1<ooooo`?o00000_ooool2
o`0000Kooooo0_l0000;ooooo`?o00002_ooool;o`0000?ooooo0_l0000Aooooo`;o00002Oooool2
o`0000Cooooo1?l00002ooooo`;o00005?ooool2o`00017ooooo0_l00009ooooo`;o00002oooool3
o`000003ooooool0003o000000;o000000?oooooo`000?l000001_l0000;ooooo`;o0000?oooool0
01cooooo00?o0000ooooooooool09Oooool2o`0001Wooooo0_l0000;ooooo`;o00001?ooool2o`00
0004ooooool0003o0000ooooo`;o00002oooool3o`0000Gooooo0ol00002ooooo`Oo000000?ooooo
o`000?l000001_l00006ooooo`;o00001oooool2o`0000Oooooo0_l0000Iooooo`;o000000?ooooo
o`000?l000006Oooool2o`0000Wooooo0_l0000<ooooo`;o000000Coooooo`000?l0003o00000_oo
ool8o`0004cooooo000Looooo`03o`000?oooooooooo02Gooooo0_l0000Iooooo`;o00001Oooool2
o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l000003_ooool2o`0000?ooooo0_l00000
1?oooooo0000o`000?l00008ooooo`So00001?ooool3o`000003ooooool0003o000000?ooooo0_l0
0002ooooo`;o00001oooool2o`0001Wooooo0_l000000ooooooo0000o`00000>ooooo`;o00001?oo
ool3o`0000;ooooo0_l0000Kooooo`Co0000E?ooool001cooooo00?o0000ooooooooool0Aoooool2
o`0000_ooooo0_l00005ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o00000oooool2
o`000004ooooool0003o0000ooooo`;o00000oooool2o`000003ooooool0003o000000Ko00000_oo
ool5o`0000;ooooo0_l000001?oooooo0000o`000?l00002ooooo`?o00002?ooool2o`0001Sooooo
0_l0000:ooooo`;o00000oooool3o`0000Cooooo0ol0000<ooooo`;o00001_ooool2o`0000;ooooo
0_l00002ooooo`;o00000oooool2o`0000Sooooo0_l0000=ooooo`;o0000>oooool001cooooo00?o
0000ooooooooool0?_ooool2o`0000Kooooo0_l0000<ooooo`;o00001Oooool7o`0000Wooooo0_l0
0004ooooo`;o00000_ooool;o`0000;ooooo2_l000001?oooooo0000o`000?l00002ooooo`?o0000
2?ooool2o`0001Sooooo0_l0000:ooooo`;o00000oooool2o`0000Oooooo0_l0000;ooooo`;o0000
1_ooool2o`0000;ooooo1_l00005ooooo`;o00001_ooool2o`0000gooooo0_l000000ooooooo0000
o`00000hooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00003Oooool2o`0000Kooooo0_l0
0005ooooo`;o00003Oooool2o`0000[ooooo0_l000000ooooooo0000o`000004ooooo`;o00000_oo
ool@o`000003ooooool0003o000000;o00002Oooool4o`0003[ooooo0_l0000Gooooo`Co00001ooo
ool2o`0001Sooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00005Oooool2
o`0000Gooooo1?l0000>ooooo`;o00001oooool2o`0000Sooooo0_l000001?oooooo0000o`000?oo
ool2o`000003ooooool0003o000000[o000000?oooooo`000?l000000_l00007ooooo`Co00008_oo
ool2o`0000[ooooo0ol00002ooooo`;o00008Oooool2o`0000?ooooo0_l0001Eooooo`007?ooool0
0ol0003oooooooooo`11ooooo`;o00000oooool2o`0000Oooooo1?l0000;ooooo`?o00001Oooool2
o`0000Kooooo0_l00002ooooo`Oo000000?oooooo`000?l000002ol00003ooooo`Ko00000_ooool3
o`000003ooooool0003o000001gooooo0_l00002ooooo`;o00001Oooool8o`0000;ooooo0_l00004
ooooo`;o00006Oooool4o`0000?ooooo1?l0000:ooooo`;o0000Aoooool00006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oo
oooooooo047ooooo0_l0000>ooooo`;o00002oooool2o`0000Kooooo0_l000000ooooooo0000o`00
0003ooooo`_o000000?oooooo`000?l000003Ol00002ooooo`Ko000000Goooooo`000?l0003o0000
ooooo`02o`0000?ooooo0_l0000Hooooo`Co00001_ooool8o`000005ooooool0003o0000o`000?oo
ool00_l00002ooooo`;o00006Oooool3o`0000Cooooo1?l000000ooooooo0000o`000005ooooo`Go
00001?ooool2o`00043ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0E_ooool3o`0000;ooooo0_l00002oooo
o`;o00001Oooool6o`0000?ooooo1_l000000ooooooo0000o`00000Jo`0000Cooooo0_l00003oooo
o`;o00004?ooool4o`0000Kooooo0_l00004ooooo`Go00000_ooool3o`000003ooooool0003o0000
00_o00005_ooool3o`0000Cooooo1?l000000ooooooo0000o`000004ooooo`?o000000Coooooo`00
0?l0003o00000oooool2o`0001?ooooo0_l0000[ooooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`09ooooo`Go00001_ooool00ol0003oooooooooo`10ooooo`;o00002oooool2o`00
00;ooooo0_l00003ooooo`?o00000_ooool6o`0000Kooooo1ol000000ooooooo0000o`00000Qo`00
00Cooooo0ol0000Booooo`Ko00003?ooool2o`000003ooooool0003o000000Co00000_ooool?o`00
01?ooooo1Ol00003ooooo`Ko000000?oooooo`000?l000001?l000000ooooooo0000o`000002o`00
01Sooooo0_l0000[ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04
odA4A?oMgMgoooooo`0000Oooooo0ol00010ooooo`;o00002oooool2o`0000;ooooo0_l00005oooo
o`;o00000oooool3o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000000oooool2
o`000003ooooool0003o000001_o000000?oooooo`000?l000002?ooool2o`0001;ooooo0_l0000=
ooooo`;o00000oooool6o`0000?ooooo1?l00002ooooo`Ko000000Goooooo`000?l0003o0000oooo
o`02o`0000oooooo1Ol00003ooooo`?o000000?oooooo`000?l000001Ol00003ooooo`;o0000Aooo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?oMgMgoEEEEooooool0
0007ooooo`03o`000?oooooooooo04Gooooo0_l00007ooooo`;o00002?ooool2o`0000Cooooo0_l0
00001?oooooo0000o`000?ooool2o`0000;ooooo0_l00005oooooago000000Coooooo`000?l0003o
oooo0ol0000Qooooo`;o00000_ooool5o`000003ooooool0003o000000;o00003Oooool3o`000003
ooooool0003o000000Ko00004Oooool2o`0000?ooooo1?l00002ooooo`;o000000?oooooo`000?l0
00003_ooool2o`0003gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo
00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`15ooooo`;o00001Oooool4o`0000cooooo
0_l0000:ooooo`?o000000?oooooo`000?l000009Ol0000Mooooo`;o00000_ooool2o`0000;ooooo
1Ol000001?oooooo0000o`000?l0000=ooooo`_o00000_ooool2o`0000oooooo0_l00003ooooo`;o
00000_ooool2o`0000Oooooo0_l0000:ooooo`;o00000oooool2o`0003Sooooo00001_ooooooMgMg
oiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0ioooo
o`;o00002?ooool2o`0000Oooooo0_l0000>ooooo`;o00002ooooolWo`0000[ooooo0_l00006oooo
o`;o00002_ooool4o`0000?ooooo0_l00002ooooo`;o00003oooool?o`0000;ooooo0_l0000;oooo
o`;o00000_ooool3o`0000Kooooo0ol00004ooooo`Co00003oooool2o`0003Sooooo00001_oooooo
k^k^oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`0Z
ooooo`;o00003Oooool2o`0000?ooooo0ol00002ooooo`;o00000_ooool2o`0000[ooooo0_l0000D
ooooo`Go000000?oooooo`000?l000001ol000000ooooooo0000o`00000Eo`0000Kooooo1_l00005
ooooo`?o00002_ooool2o`0000Gooooo0ol00005ooooo`Co00000oooool2o`000003ooooool0003o
000001;o00001_ooool2o`0000Gooooo0_l00002ooooo`?o00000oooool2o`000004ooooool0003o
0000o`0000?ooooo0ol00004ooooo`;o0000AOooool001cooooo00?o0000ooooooooool0:_ooool2
o`0000gooooo0_l00003ooooo`?o00000_ooool2o`0000;ooooo0_l00003ooooo`;o00001Oooool2
o`00013ooooo0_l00002ooooo`Oo000000?oooooo`000?l000006_l000000ooooooo0000o`000003
o`0000?ooooo1_l00005ooooo`;o00001Oooool2o`0000Cooooo0_l00006ooooo`Co00000oooool4
o`0000?ooooo6?l00005ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo0_l00004
ooooo`;o00001oooool2o`0000;ooooo0_l000000ooooooo0000o`000015ooooo`007?ooool00ol0
003oooooooooo`0iooooo`;o00001?ooool2o`0000;ooooo0_l00007ooooo`;o00005?ooool2o`00
0003ooooool0003o000000;ooooo0ol000000ooooooo0000o`000002o`000003ooooool0003o0000
01Wo00000_ooool5o`000003ooooool0003o000000;o000000?oooooo`000?l000000_ooool2o`00
00Sooooo0_l00004ooooo`;o00002?ooool2o`0000cooooo6?l00007ooooo`;o00006?ooool2o`00
04Sooooo000Looooo`03o`000?oooooooooo04Cooooo1Ol0000<ooooo`;o00000_ooool4o`0000Go
oooo1?l00003ooooobKo00000_ooool6o`0000Oooooo0_l0000Cooooo`;o00001Oooool2o`0000[o
oooo6?l0000Fooooo`;o000000?oooooo`000?l000000_l00004ooooo`Co00001_ooool2o`0003ko
oooo000Looooo`03o`000?oooooooooo047ooooo0_l000000ooooooo0000o`000003o`0000cooooo
0_l00002ooooo`Co00001oooool2o`0000?ooooo9_l00002ooooo`Ko000000?oooooo`000?l00000
4Oooool2o`0000Kooooo0_l00005ooooo`;o00001?ooool2o`0000;ooooo6Ol0000>ooooo`;o0000
0oooool2o`0000;ooooo2Ol00002ooooo`Co00000_ooool2o`0000;ooooo0_l0000nooooo`007?oo
ool00ol0003oooooooooo`0cooooo`;o00002oooool3o`0001Oooooo0_l0000;ooooobSo00000_oo
ool2o`000005ooooool0003o0000o`000?ooool00_l0000Aooooo`;o00001Oooool2o`0000cooooo
0_l00002oooooaWo00002?ooool2o`0000Cooooo0_l00003ooooo`;o00000oooool3o`0000?ooooo
1?l00003ooooo`;o000000?oooooo`000?l00000@_ooool001cooooo00?o0000ooooooooool0<ooo
ool2o`0000Kooooo0_l00003ooooo`;o00001oooool2o`0000Cooooo0_l0000Dooooo`Co000000?o
ooooo`000?l000003ol000000ooooooo0000o`00000Ao`0000;ooooo0_l000001?oooooo0000o`00
0?l0000Kooooo`;o00003oooool@o`000003ooooool0003o000000Go000000?oooooo`000?l00000
1oooool2o`0000kooooo0_l00006ooooo`;o00000oooool2o`0004Gooooo000Looooo`03o`000?oo
oooooooo03Sooooo0_l000001?oooooo0000o`000?l00004ooooo`;o00001Oooool2o`0000Cooooo
0_l00004ooooo`;o00002?ooool2o`0000Cooooo0ol00002oooooa7o000000?oooooo`000?l00000
4Ol00006ooooo`;o000000?oooooo`000?l000006_ooool4o`0000_ooooo0_l000000ooooooo0000
o`00000Fo`0000[ooooo0ol0000Mooooo`;o0000?oooool001cooooo00?o0000ooooooooool0:?oo
ool2o`0000kooooo0_l00002ooooo`Co00000_ooool3o`00013ooooo0_l00006ooooo`Co00000ooo
ool4o`0000Cooooo6Ol00002ooooo`[o00000_ooool2o`0000;ooooo0ol0000Fooooo`So00001?oo
ool2o`0000Cooooo7?l0000:ooooo`?o00005_ooool2o`0000?ooooo1?l0000oooooo`007?ooool0
0ol0003oooooooooo`0Xooooo`;o00002_ooool2o`0000Sooooo0_l00003ooooo`;o00006?ooool2
o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`?o00000_ooool7o`000005ooooool0003o
0000o`000?ooool06?l00002ooooo`;o00000_ooool2o`0000Kooooo0_l0000?ooooo`Co00002?oo
ool2o`0000Cooooo7?l0000Sooooo`;o00000oooool2o`00047ooooo000Looooo`03o`000?oooooo
oooo027ooooo0_l0000?ooooo`Co00001_ooool2o`0001gooooo0_l00003ooooo`?o000000Gooooo
o`000?l0003o0000ooooo`03o`000003ooooool0003o000000Oo000000?oooooo`000?l000006Ol0
0002ooooo`;o00000oooool2o`0000Gooooo0_l00002ooooo`;o00000oooool4o`0000?ooooo0_l0
000Boooooa_o00002?ooool2o`0001gooooo1?l00010ooooo`007?ooool00ol0003oooooooooo`0Q
ooooo`;o00003oooool3o`0000Gooooo1?l0000Mooooo`;o00000oooool2o`000003ooooool0003o
000000Ko000000?oooooo`000?l000005?l000000ooooooo0000o`00000<o`0000;ooooo1?l00000
0ooooooo0000o`000002ooooo`;o00001Oooool2o`0000?ooooo1?l00003ooooo`;o00000oooool2
o`0000Kooooo0_l00005oooooa;o000000Coooooo`000?l0003ooooo1Ol000000ooooooo0000o`00
0005ooooo`?o00002Oooool4o`0000oooooo1?l00010ooooo`007?ooool2o`0003_ooooo0_l00000
0ooooooo0000o`00000Tooooo`Ko00000ooooolFo`000003ooooool0003o000000Wo00001Oooool4
o`0000Gooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo0_l00003ooooo`;o00001_ooool2
o`0000Gooooo5Ol00002ooooo`Co000000?oooooo`000?l000001_ooool2o`0000Wooooo1?l0000?
ooooo`;o00004?ooool2o`00033ooooo000Looooo`03o`000?oooooooooo03gooooo0_l0000Aoooo
o`?o00001_ooool2o`0000Oooooo0ol00005oooooako000000Coooooo`000?l0003o00000_ooool4
o`000005ooooool0003o0000o`000?ooool00_l00007ooooo`Co000000?oooooo`000?l000000_l0
0002ooooo`;o00000_ooool3o`0000;ooooo0_l0000>oooooaCo00000_ooool9o`0000Wooooo1?l0
000Eooooo`;o00004?ooool2o`00033ooooo000Looooo`03o`000?oooooooooo04kooooo1Ol00002
ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`Go000000?oooooo`000?l000007_l00000
0ooooooo0000o`000007o`0000Gooooo0_l00007ooooo`;o00000oooool4o`0000;ooooo0ol00000
1?oooooo0000o`000?l00002ooooo`;o00002Oooool2o`0000?ooooo7ol00009ooooo`Co00002_oo
ool2o`0000Sooooo1?l0000@ooooo`;o0000;oooool001cooooo00?o0000ooooooooool0C_ooool4
o`0000?ooooo0_l00007ooooo`;o00001?ooool^o`000003ooooool0003o000000;ooooo0_l00002
ooooo`;o00000_ooool2o`0000Cooooo0_l00004ooooo`?o000000?oooooo`000?l000003_ooool2
o`0000Cooooo6_l0000>ooooo`;o00002oooool2o`0000Sooooo1_l0000;ooooo`;o000000?ooooo
o`000?l00000;oooool001cooooo00?o0000ooooooooool0D?ooool2o`0000Wooooo0_l0000:oooo
oa3o000000?oooooo`000?l000004_l00002ooooo`Co000000?oooooo`000?l000000_ooool2o`00
00;ooooo0_l00002ooooo`;o00000oooool3o`0000Oooooo0_l00004ooooo`;o00001?ooool2o`00
00_ooooo5?l000001?oooooo0000o`000?ooool2o`0000Sooooo0_l00002ooooo`;o00005Oooool2
o`000004ooooool0003o0000o`0000_ooooo0_l0000booooo`007?ooool00ol0003oooooooooo`0g
ooooo`Go00007oooool2o`0000Cooooo0_l00006ooooobCo000000?oooooo`000?l000000ol0000>
ooooo`;o000000?oooooo`000?l000000ol00004ooooo`Go00000_ooool2o`0000Cooooo0_l0000;
ooooo`?o000000?oooooo`000?l000003_l000001?oooooo0000o`000?ooool2o`0000Sooooo0_l0
000Nooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0<oooool3o`000003ooooool0003o
000000?o00000_ooool2o`0000oooooo0_l00002ooooo`;o00001?ooool2o`0000Gooooo1Ol00000
0ooooooo0000o`00000Vo`000003ooooool0003o000000;o00003_ooool2o`0000Cooooo0ol00002
ooooo`?o000000?oooooo`000?l000005OoooolGo`0000_ooooo0_l00003ooooo`;o00003_ooool3
o`0000Kooooo1?l0000?ooooo`;o0000;Oooool001cooooo00?o0000ooooooooool0<oooool3o`00
00Sooooo1?l0000=ooooo`;o00000_ooool4o`000003ooooool0003o000000;o000000Coooooo`00
0?l0003ooooo0_l000001?oooooo0000o`000?oooolXo`0000;ooooo0ol00002ooooo`;o00004Ooo
ool7o`00017ooooo0_l00006oooooaGo00004Oooool2o`0000Gooooo0_l00007ooooo`?o00001_oo
ool2o`00017ooooo0_l0000]ooooo`007?ooool00ol0003oooooooooo`0aooooo`;o000000?ooooo
o`000?l000002_ooool2o`0000Gooooo0_l0000<ooooo`;o000000?oooooo`000?l000000_l00000
0ooooooo0000o`000007oooooago000000?oooooo`000?l000000ol0000<ooooo`;o00001oooool5
o`0000Oooooo1ol00003ooooo`;o00002_ooool4o`0000Cooooo5ol0000Fooooo`;o00002_ooool4
o`0004Cooooo000Looooo`03o`000?oooooooooo037ooooo1Ol00009ooooo`;o00001_ooool2o`00
00Kooooo0_l000000ooooooo0000o`000006ooooo`;o00003Oooool4o`000003ooooool0003o0000
00?o00000ooooolEo`000003ooooool0003o0000013ooooo1Ol0000:ooooo`Co00000oooool2o`00
00cooooo0_l00005oooooaKo00000_ooool2o`0001;ooooo0_l00009ooooo`Go00003_ooool2o`00
03Cooooo000Looooo`03o`000?oooooooooo03?ooooo0_l0000:ooooo`Co00003?ooool2o`000003
ooooool0003o000001Oooooo1Ol000000ooooooo0000o`000002oooooaKo000000?oooooo`000?l0
00000_l00002ooooo`Co00006?ooool2o`0000Oooooo0_l0000Booooo`Wo000000?oooooo`000?l0
00001Ol00005ooooo`;o00000_ooool2o`0000;ooooo0_l00006ooooo`;o000000Coooooo`000?l0
003o00002?ooool3o`0000oooooo1?l0000dooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o
00001?ooool2o`0000;ooooo0_l00004ooooo`;o00001?ooool2o`0001;ooooo1_l00002ooooo`;o
00003_ooool2o`0000?ooooo6Ol00002ooooo`?o00000_ooool4o`0000;ooooo0_l00002ooooo`;o
00004_ooool4o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`0000Gooooo0_l00003ooooo`[o
000000?oooooo`000?l000001?l00008ooooo`?o00000_ooool2o`0000Kooooo0_l000000ooooooo
0000o`000009ooooo`?o00001oooool2o`0000Kooooo1?l0000dooooo`007?ooool00ol0003ooooo
ooooo`0[ooooo`;o00001?ooool2o`0000;ooooo0_l00004ooooo`;o00001?ooool3o`00017ooooo
1_l00002ooooo`;o00002Oooool2o`0000Oooooo6_l0000=ooooo`;o00000_ooool3o`0000_ooooo
0ol00003ooooo`Oo00001?ooool2o`0000;ooooo1?l00003ooooo`;o00000oooool3o`000003oooo
ool0003o000000_o00002?ooool2o`0001oooooo0_l00002ooooo`;o00002?ooool2o`0003Cooooo
000Looooo`03o`000?oooooooooo03Gooooo1?l00002ooooo`;o00001?ooool3o`0001?ooooo0_l0
000:ooooo`;o00000oooool2o`000003ooooool0003o000000Cooooo0ol00003ooooo`So000000?o
ooooo`000?l000003_l00005ooooo`;o00001_ooool2o`0000Sooooo0_l000001?oooooo0000o`00
0?l00004ooooo`Wo00001_ooool3o`0000?ooooo0_l00002ooooo`?o000000?oooooo`000?l00000
0_l000000ooooooo0000o`000006o`0002Oooooo1Ol0000:ooooo`;o0000=_ooool001cooooo00?o
0000ooooooooool0=oooool2o`000004ooooool0003o0000o`0000Cooooo0_l0000Pooooo`;o0000
00?oooooo`000?l000000_l000000ooooooo0000o`000004ooooo`?o00001Oooool?o`000003oooo
ool0003o000000Go00001Oooool2o`0000cooooo0_l00002ooooo`;o00003_ooool3o`0000Kooooo
0_l00008ooooo`;o00000_ooool9o`000004ooooool0003o0000o`0002Gooooo1_l00003ooooo`;o
00001_ooool2o`0003Kooooo000Looooo`03o`000?oooooooooo03[ooooo0_l00005ooooo`;o0000
3_ooool2o`0000;ooooo0_l0000?ooooo`;o00001_ooool2o`0000Gooooo1Ol00002ooooo`Go0000
00?oooooo`000?l000001Ol000001?oooooo0000o`000?ooool2o`0001Cooooo0_l00004ooooo`;o
00003Oooool6o`0000gooooo0_l000001?oooooo0000o`000?ooool6o`0000Oooooo0_l00007oooo
o`?o00002?ooool2o`0000Oooooo0_l00003ooooo`;o00000oooool2o`0000;ooooo0_l00008oooo
o`;o0000=?ooool001cooooo0_l00012ooooo`;o000000?oooooo`000?l000002oooool2o`0000;o
oooo0_l0000Eooooo`ko00000_ooool5o`0000;ooooo0ol000000ooooooo0000o`000003ooooo`?o
00006_ooool4o`0000Sooooo0_l000000ooooooo0000o`000004o`0000[ooooo0_l000000ooooooo
0000o`000004ooooo`Ko00001oooool4o`0000;ooooo0_l000000ooooooo0000o`000003o`0000Ko
oooo0_l00007ooooo`;o00002?ooool2o`0000cooooo0_l0000dooooo`007?ooool00ol0003ooooo
ooooo`14ooooo`;o00005_ooool2o`0000Oooooo0_l00004ooooo`?o00000_ooool5o`000003oooo
ool0003o000000;o00000_ooool2o`000004ooooool0003o0000ooooo`;o00000oooool2o`0000?o
oooo0_l0000?ooooo`;o00003?ooool3o`0000Oooooo0_l00005ooooo`?o000000?oooooo`000?l0
00001_ooool2o`0000Wooooo1?l00009ooooo`;o00000_ooool2o`0000Cooooo0_l0001Mooooo`00
7?ooool00ol0003oooooooooo`1Looooo`;o000000?oooooo`000?l000001?ooool2o`0000Cooooo
0_l00004ooooo`;o00000oooool2o`000003ooooool0003o000000Co00000oooool2o`0000?ooooo
0_l0000Dooooo`;o00002_ooool2o`000003ooooool0003o000000kooooo0ol000000ooooooo0000
o`00000>ooooo`;o00000oooool2o`0000Sooooo0_l0000Fooooo`?o00007oooool2o`0002kooooo
000Looooo`03o`000?oooooooooo03kooooo1?l0000Looooo`?o00002Oooool2o`0000Gooooo0_l0
0002ooooo`_o00000_ooool2o`0000?ooooo0_l0000Dooooo`;o00002_ooool2o`0001kooooo1?l0
0003ooooo`Co000000?oooooo`000?l000000ol00005ooooo`;o00005_ooool3o`0001kooooo0ol0
000^ooooo`007?ooool00ol0003oooooooooo`0Uooooo`;o00002Oooool2o`0000cooooo1?l0000E
ooooo`;o00001Oooool2o`000003ooooool0003o000000Oooooo2Ol00002ooooo`Go00000_ooool8
o`0000?ooooo1_l0000@ooooo`;o00007?ooool2o`0000?ooooo0_l00007ooooo`Ko00000_ooool3
o`0000?ooooo1Ol00003ooooo`;o0000<?ooool2o`0000Cooooo0ol0000_ooooo`007?ooool00ol0
003oooooooooo`0Uooooo`;o00002Oooool3o`0000?ooooo0_l0000Oooooo`;o00002?ooool2o`00
00Wooooo1_l00002ooooo`?o000000?oooooo`000?l000001Oooool4o`0000Gooooo1ol00008oooo
o`;o00001?ooool2o`0001Cooooo0_l00006ooooo`;o000000?oooooo`000?l000000_l0000:oooo
o`?o00001oooool6o`0001?ooooo0_l0000>ooooo`;o00004?ooool2o`0000Cooooo0ol00008oooo
o`;o00009Oooool001cooooo00?o0000ooooooooool0<Oooool2o`0000?ooooo0_l00005ooooo`Co
00001Oooool2o`0001Oooooo1?l0000=ooooo`;o00000_ooool2o`0000Gooooo0_l0000;ooooo`;o
000000?oooooo`000?l000000_l00006ooooo`Co00003Oooool2o`0000_ooooo0_l00009ooooo`Co
00005?ooool6o`0000Kooooo1Ol00008ooooo`?o000000?oooooo`000?l000002_ooool2o`0000Co
oooo0_l0000Kooooo`;o00009Oooool001cooooo00?o0000ooooooooool0;?ooool2o`0000oooooo
1?l00005ooooo`;o00005Oooool7o`0000cooooo1?l00004ooooo`;o000000?oooooo`000?l00000
1Oooool4o`0000Gooooo0_l00008ooooo`Co00002?ooool2o`000003ooooool0003o000000;o0000
2?ooool2o`0000Wooooo0_l00003ooooo`;o00002_ooool2o`0000[ooooo0_l00006ooooo`Oo0000
2Oooool2o`000003ooooool0003o000000Cooooo0_l00009ooooo`?o00003oooool2o`00037ooooo
000Looooo`03o`000?oooooooooo02cooooo0_l000000ooooooo0000o`000002o`0000_ooooo0_l0
00000ooooooo0000o`00000Gooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo0_l0
0007ooooo`Go00000oooool2o`0000Gooooo1ol0000Aooooo`;o00002?ooool2o`000003ooooool0
003o000000[ooooo1?l00007ooooo`Oo00000_ooool2o`000003ooooool0003o000000?ooooo1?l0
0005ooooo`;o00002?ooool3o`0001Oooooo0_l00009ooooo`?o00003oooool2o`00037ooooo000L
ooooo`03o`000?oooooooooo02cooooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l00005
ooooo`;o000000?oooooo`000?l000000oooool2o`0001;ooooo0_l0000;ooooo`;o00002_ooool2
o`0000?ooooo0_l00003ooooo`Ko000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l0000F
ooooo`;o00003?ooool3o`0000Gooooo0_l000000ooooooo0000o`000003o`0000;ooooo0_l00000
0ooooooo0000o`000005ooooo`;o00001Oooool2o`0000Sooooo0ol00009ooooo`;o000000?ooooo
o`000?l000000_ooool2o`0000cooooo0_l00003ooooo`;o0000@_ooool001cooooo00?o0000oooo
ooooool0;?ooool2o`0000Wooooo0_l0000=ooooo`;o00006_ooool2o`0001Wooooo0_l00005oooo
o`;o00000_ooool2o`0000;ooooo0_l0000Fooooo`;o00003Oooool2o`0000Gooooo0_l00003oooo
o`;o00004?ooool2o`0000Cooooo0_l0000;ooooo`;o00001?ooool3o`000003ooooool0003o0000
00;ooooo0_l0000<ooooo`Co0000AOooool001cooooo00?o0000ooooooooool0:?ooool2o`0000;o
oooo0_l0000;ooooo`;o00001Oooool2o`0001_ooooo0_l00003ooooo`;o00000_ooool2o`0000?o
oooo1?l0000Hooooo`;o00001_ooool2o`00023ooooo0_l0000:ooooo`Co000000?oooooo`000?l0
00001Oooool2o`0000Kooooo0_l00004ooooo`;o00002oooool2o`0000Cooooo0_l00006ooooo`;o
000000?oooooo`000?l000000oooool4o`0000Cooooo0_l000000ooooooo0000o`000008ooooo`;o
00002Oooool2o`0002gooooo000Looooo`03o`000?oooooooooo02Sooooo0_l00002ooooo`;o0000
2_ooool3o`0000Gooooo0_l0000Kooooo`;o00001oooool2o`0000?ooooo1_l00009ooooo`;o0000
00?oooooo`000?l000002?ooool2o`0000Kooooo0_l00002ooooo`;o00001_ooool2o`0001Cooooo
0_l00006ooooo`Ko000000?oooooo`000?l000000_l00005ooooo`;o00001oooool4o`0000cooooo
0_l00004ooooo`Co00001_ooool5o`0000?ooooo1?l00004ooooo`;o000000?oooooo`000?l00000
2?ooool2o`0000Cooooo0_l00003ooooo`;o0000;Oooool001cooooo00?o0000ooooooooool0<ooo
ool2o`0000?ooooo0_l0000;ooooo`;o0000:?ooool2o`0000Kooooo0_l000001?oooooo0000o`00
0?ooool2o`0000Cooooo0ol00002ooooo`;o00002Oooool2o`0000Kooooo1?l0000;ooooo`Co0000
2Oooool8o`000003ooooool0003o000000Oooooo0_l00007ooooo`Co00003?ooool2o`0000Cooooo
0_l00003ooooo`;o00001?ooool5o`0000Sooooo1?l00003ooooo`;o00003?ooool2o`0003;ooooo
000Looooo`03o`000?oooooooooo02_ooooo0_l00006ooooo`;o00000_ooool2o`000003ooooool0
003o000000Wooooo0_l0000Hooooo`;o00002oooool2o`0000Wooooo0_l0000:ooooo`?o00000_oo
ool2o`000004ooooool0003o0000ooooo`;o00003Oooool2o`0000Cooooo0_l00005ooooo`Co0000
00?oooooo`000?l000001_ooool2o`0000gooooo0_l000000ooooooo0000o`000004ooooo`;o0000
00?oooooo`000?l000002oooool2o`0000Oooooo0_l00003ooooo`;o00001Oooool4o`0000Sooooo
0_l00005ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0:oooool2o`0000[ooooo0_l0
00000ooooooo0000o`000005ooooo`;o00007?ooool2o`0000_ooooo1?l0000:ooooo`;o00000ooo
ool2o`0000Oooooo0_l000001?oooooo0000o`000?ooool2o`0001?ooooo0_l0000:ooooo`;o0000
3oooool2o`0000Cooooo0_l00002ooooo`?o00000_ooool3o`0000gooooo1?l0000Booooo`;o0000
1Oooool2o`0000Gooooo0_l00004ooooo`;o00000_ooool2o`0003[ooooo000Looooo`;o00009ooo
ool2o`0000oooooo0_l00008ooooo`;o0000:oooool2o`0000[ooooo0_l00003ooooo`?o00001_oo
ool2o`0000oooooo0_l0000Uooooo`?o00001oooool4o`0000;ooooo0_l0000?ooooo`;o00002?oo
ool2o`0000Sooooo0ol00004ooooo`;o00000_ooool2o`000003ooooool0003o000000Cooooo0_l0
0002ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool09_ooool2o`0000oooooo0_l00008
ooooo`;o00001Oooool2o`0001Wooooo0_l00006ooooo`;o00001Oooool2o`0000Oooooo1?l00000
0ooooooo0000o`000008ooooo`;o00003Oooool2o`0000?ooooo0_l0000Iooooo`;o00001_ooool2
o`0000Wooooo0_l0000Fooooo`;o00001Oooool2o`0000Sooooo1Ol00002ooooo`;o00000_ooool2
o`000003ooooool0003o000000kooooo0ol0000cooooo`007?ooool00ol0003oooooooooo`0loooo
o`;o00002_ooool2o`0001Cooooo0_l00003ooooo`Ko00000_ooool2o`0000Gooooo0_l00007oooo
o`Co00001?ooool2o`0000Gooooo0ol000000ooooooo0000o`00000>ooooo`Co00001Oooool2o`00
013ooooo0_l0000Aooooo`;o00005_ooool2o`0000;ooooo0_l000000ooooooo0000o`000007oooo
o`;o00000_ooool2o`0000Gooooo0_l00004ooooo`Co00002_ooool3o`0003?ooooo000Looooo`03
o`000?oooooooooo02_ooooo1?l00002ooooo`;o00002Oooool2o`00023ooooo0_l00005ooooo`Co
00006_ooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0000Oooooo0_l00007oooo
o`;o00001Oooool2o`0000Gooooo0_l0000Kooooo`;o00006oooool2o`0000[ooooo0_l00009oooo
o`;o00001?ooool4o`00043ooooo000Looooo`03o`000?oooooooooo02_ooooo1?l00002ooooo`;o
00001Oooool3o`0000Gooooo0_l0000Jooooo`;o00001oooool2o`0001Oooooo0_l00006ooooo`Co
00000oooool2o`0000Sooooo0_l00004ooooo`;o00001_ooool2o`0000Kooooo1?l0000Jooooo`;o
000000Coooooo`000?l0003o00001?ooool2o`0001Gooooo0_l00007ooooo`Co00001oooool2o`00
00;ooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00001Oooool3o`0000Go
oooo0_l00002ooooo`;o00005_ooool2o`000003ooooool0003o000000cooooo0_l0000?ooooo`;o
00001_ooool2o`0000Gooooo0_l00008ooooo`;o00001?ooool2o`0000Kooooo0_l00004ooooo`Ko
00006_ooool2o`000004ooooool0003o0000o`0000Cooooo0_l0000Dooooo`?o000000?oooooo`00
0?l000001?ooool4o`0000Oooooo0_l00002ooooo`;o00001?ooool2o`0000Oooooo0_l0000doooo
o`007?ooool00ol0003oooooooooo`0aooooo`;o00003Oooool2o`0000;ooooo0_l000000ooooooo
0000o`00000Fooooo`;o00002oooool3o`0000?ooooo0_l00004ooooo`;o00004?ooool2o`0000_o
oooo0_l0000:ooooo`?o00001Oooool5o`0000Sooooo0_l00002ooooo`;o00003Oooool2o`0001ko
oooo0_l00002ooooo`;o00003oooool3o`0000Oooooo0_l00007ooooo`;o0000=?ooool001cooooo
00?o0000ooooooooool0<Oooool2o`0000Sooooo0_l0000:ooooo`;o00006oooool2o`0000Kooooo
0_l00004ooooo`;o00001?ooool2o`0000Cooooo0_l0000:ooooo`;o00002_ooool2o`0000Wooooo
1Ol00006ooooo`;o00002_ooool2o`0000;ooooo0_l00002ooooo`;o00000_ooool9o`0002Cooooo
0ol0000<ooooo`Go0000A?ooool001cooooo00?o0000ooooooooool0<Oooool3o`0000Gooooo1_l0
000Tooooo`?o00001?ooool2o`00013ooooo1?l0000Dooooo`Co00002Oooool2o`0000Gooooo0_l0
00000ooooooo0000o`00000;ooooo`;o00001_ooool3o`000003ooooool0003o000000Oo00001Ooo
ool3o`0000gooooo0_l0000=ooooo`?o00003oooool2o`0000kooooo0_l0000dooooo`007?ooool0
0ol0003oooooooooo`0booooo`;o00001Oooool2o`0000;ooooo0_l000000ooooooo0000o`00000Q
ooooo`;o00001Oooool2o`0000Cooooo1?l00008ooooo`;o00003?ooool4o`0000Kooooo0_l00002
ooooo`;o00003_ooool6o`0000[ooooo1?l00004ooooo`Co00000oooool3o`0000Sooooo0ol0000=
ooooo`;o00002_ooool2o`0002?ooooo0_l0000dooooo`007?ooool00ol0003oooooooooo`0ioooo
o`;o00001Oooool2o`0000Sooooo0_l0000?ooooo`;o00002_ooool2o`0000?ooooo0ol000000ooo
oooo0000o`000002o`0000gooooo0_l00003ooooo`;o00000_ooool4o`0000[ooooo0_l000000ooo
oooo0000o`000005ooooo`Co00001?ooool4o`0000[ooooo3Ol00003ooooo`;o00003Oooool2o`00
00Kooooo0_l0000=ooooo`;o00001_ooool2o`0000Oooooo0_l000000ooooooo0000o`000015oooo
o`007?ooool00ol0003oooooooooo`0iooooo`;o00001?ooool2o`0000Sooooo1?l0000>ooooo`;o
00002_ooool2o`0000?ooooo0ol0000Booooo`;o00000oooool2o`000003ooooool0003o000000;o
00003_ooool2o`0000Gooooo1Ol000000ooooooo0000o`00000?ooooo`;o000000?oooooo`000?l0
00003Ol0000<ooooo`;o00001_ooool2o`0001Cooooo0ol00006ooooo`?o000000?oooooo`000?l0
00002oooool2o`0003Sooooo000Looooo`03o`000?oooooooooo03Wooooo0_l00004ooooo`;o0000
2?ooool4o`0003cooooo0_l00004ooooo`;o00005?ooool2o`000003ooooool0003o000000Kooooo
0_l00007ooooo`;o000000?oooooo`000?l000003Ol00003ooooo`;o00001_ooool2o`0000Gooooo
0_l000000ooooooo0000o`00000Cooooo`?o00001_ooool2o`0000oooooo0_l0000hooooo`007?oo
ool00ol0003oooooooooo`0iooooo`;o00002Oooool2o`0000Gooooo0_l0000Mooooo`;o00004ooo
ool2o`0000Wooooo1?l000001?oooooo0000o`000?ooool3o`00013ooooo0_l00003ooooo`;o0000
1?ooool2o`0000;ooooo0_l00006ooooo`oo000000?oooooo`000?l000000ol00004ooooo`Go0000
0oooool2o`000003ooooool0003o0000013ooooo0_l000000ooooooo0000o`00000Jooooo`;o0000
=_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0
003o410@olc<c006ooooo`03o`000?oooooooooo03Kooooo0_l00002ooooo`?o00001oooool2o`00
00Gooooo0_l0000>ooooo`;o00000oooool2o`0000Sooooo0_l0000Aooooo`Ko00001oooool7o`00
0004ooooool0003o0000o`00013ooooo0_l00003ooooo`;o00001?ooool2o`0000;ooooo0_l00002
oooooa?o000000?oooooo`000?l000000ol00003ooooo`Ko000000?oooooo`000?l000001?ooool2
o`0000?ooooo0_l0000:ooooo`Co00006Oooool4o`0003Kooooo00001_ooooooMgMgoiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`0fooooo`;o00000_ooool3o`000003ooooool0003o000000kooooo0_l0000;ooooo`;o0000
00?oooooo`000?l000001?l0000;ooooo`;o00001oooool2o`0000?ooooo0_l00002ooooo`?o0000
0_ooool2o`0000?ooooo1_l0000=ooooo`Co00002Oooool2o`0000?ooooo0_l00004oooooaKo0000
00?oooooo`000?l000000_l00003ooooo`;o00001?ooool3o`0000Cooooo0_l00003ooooo`;o0000
1Oooool2o`0000?ooooo1?l000001?oooooo0000o`000?ooool2o`000003ooooool0003o0000013o
oooo0_l0000hooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`0gooooo`;o00001Oooool2o`0000Co
oooo0_l00008ooooo`;o00003Oooool7o`0000[ooooo0ol00003ooooo`;o00000_ooool2o`0000Ko
oooo2Ol00002ooooo`?o00002_ooool2o`0000Cooooo1?l00005ooooo`;o00000_ooool2o`0000Wo
oooo6?l000000ooooooo0000o`000004ooooo`;o00000oooool2o`0000cooooo0_l00003ooooo`;o
00000oooool4o`000004ooooool0003o0000ooooo`;o000000Coooooo`000?l0003ooooo0ol00016
ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9Sooooo
oiRHV?lQ8B401_ooool3o`0003Oooooo0_l0000;ooooo`;o00001_ooool2o`0000oooooo0_l00000
0ooooooo0000o`000003ooooo`;o00000oooool2o`0000;ooooo0_l000001?oooooo0000o`000?oo
ool2o`0000Cooooo0_l00002ooooo`_o00000_ooool3o`0000[ooooo0_l0000=ooooo`;o00003Ooo
ool2o`000003ooooool0003o000001Go00001Oooool2o`0000;ooooo0_l00004ooooo`;o00001ooo
ool2o`0000Cooooo0_l0000@ooooo`?o0000A_ooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool02Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0=ooo
ool2o`000003ooooool0003o0000013ooooo1?l0000Eooooo`Co000000?oooooo`000?l000001Ooo
ool2o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000001ol0
0002ooooo`;o00006Oooool2o`000003ooooool0003o000000[ooooo5_l00002ooooo`;o00002?oo
ool3o`000004ooooool0003o0000ooooo`;o00003?ooool3o`0000cooooo0_l00003ooooo`;o0000
A_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7oooo
o`08ooooo`03o`000?oooooooooo03Oooooo0_l000000ooooooo0000o`00000Booooo`?o00003ooo
ool2o`0000?ooooo1?l00008ooooo`?o00000oooool2o`000003ooooool0003o000000Co000000?o
ooooo`000?l000002Ol00003ooooo`;o00000_ooool2o`0000Sooooo1Ol00003ooooo`Co000000Co
ooooo`000?l0003ooooo0_l00007oooooaSo00001?ooool2o`0000Cooooo1_l000001?oooooo0000
o`000?l00007ooooo`;o00000_ooool2o`0000Gooooo0_l00006ooooo`;o00003_ooool2o`0003_o
oooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0
003oooooooooo`0booooo`;o00003_ooool2o`0000_ooooo0_l0000?ooooo`;o00003oooool3o`00
00;ooooo0_l000000ooooooo0000o`000005o`000003ooooool0003o000000Wo00000oooool2o`00
00;ooooo0_l00008ooooo`Go00000oooool2o`0000Kooooo0_l00005ooooo`;o000000?oooooo`00
0?l000004?l00002ooooo`Co00000oooool2o`0000Gooooo0ol00003ooooo`?o00001oooool2o`00
00?ooooo0_l00003ooooo`?o00001_ooool2o`0000kooooo0_l0000kooooo`0000Koooooonk^k_lb
<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0<_oo
ool2o`0000Sooooo0_l00004ooooo`;o0000;_ooool2o`0000;ooooo0_l000000ooooooo0000o`00
000Bo`0000Kooooo0_l0000>ooooo`Co00003OoooolMo`0000Sooooo0ol00003ooooo`Go00002_oo
ool2o`000003ooooool0003o000000Co00002oooool2o`0004Gooooo000Looooo`03o`000?oooooo
oooo02gooooo0_l00005ooooo`;o00001_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000:
ooooo`;o00006Oooool2o`0000Kooooo0_l00002ooooo`;o000000?oooooo`000?l000005?l00004
ooooo`;o00001?ooool2o`0000Sooooo0_l000001?oooooo0000o`000?ooool2o`0000[ooooo6Ol0
00000ooooooo0000o`000009ooooo`Co00000_ooool6o`0000_ooooo0_l00002ooooo`;o00002ooo
ool2o`0004Gooooo000Looooo`03o`000?oooooooooo02gooooo0_l00005ooooo`;o00002Oooool3
o`000003ooooool0003o000000;ooooo0_l00006ooooo`;o00002_ooool2o`0000gooooo1?l00004
ooooo`;o00000_oooolIo`0000[ooooo0_l0000;ooooo`;o000000?oooooo`000?l000002?ooool5
o`000003ooooool0003o000001Go00003?ooool2o`0000;ooooo0ol000000ooooooo0000o`00001S
ooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00001_ooool2o`0001;ooooo0_l00008oooo
o`;o00001Oooool4o`0000;ooooo6?l000001?oooooo0000o`000?l00003ooooo`;o00004?ooool2
o`0000kooooo3_l000000ooooooo0000o`00000<o`0000Cooooo0_l0000;ooooo`?o00002?ooool4
o`0005Wooooo000Looooo`03o`000?oooooooooo05Cooooo0_l0000?ooooo`;o00001oooool2o`00
00;ooooo7?l00003ooooo`;o00004?ooool2o`0000Oooooo0_l00004oooooa7o000000?oooooo`00
0?l000002Ol00005ooooo`;o00002oooool3o`0000Cooooo0_l00002ooooo`Co00001Oooool2o`00
05;ooooo000Looooo`03o`000?oooooooooo05Cooooo0_l0000:ooooo`;o00004Oooool2o`0000?o
oooo5Ol0000Aooooo`;o00002Oooool2o`000003ooooool0003o000000Cooooo7?l0000?ooooo`;o
00000_ooool3o`000003ooooool0003o000000?o00002oooool2o`0000Cooooo0_l00006ooooo`;o
0000A?ooool001cooooo00?o0000ooooooooool0=_ooool2o`0000_ooooo0_l00006ooooo`;o0000
4_ooool4o`0000Wooooo0_l0000;oooooaGo000000?oooooo`000?l000003Oooool2o`0000Wooooo
0_l0000;oooooaWo00001oooool2o`0000Gooooo0_l00002ooooo`So00003?ooool2o`0000Cooooo
0_l00006ooooo`Co0000@_ooool001cooooo00?o0000ooooooooool0<oooool2o`000004ooooool0
003o0000ooooo`;o00001oooool3o`0000Cooooo1?l0000Booooo`Ko00001oooool2o`000003oooo
ool0003o000000?ooooo7Ol000000ooooooo0000o`000002o`00017ooooo0_l00009ooooo`;o0000
0_oooolIo`0000Oooooo0ol00007ooooo`Oo00003?ooool4o`0000kooooo0_l0000=ooooo`;o0000
<oooool001cooooo00?o0000ooooooooool0<oooool2o`0000Cooooo0_l00004ooooo`;o000000?o
ooooo`000?l000001Oooool2o`0001Sooooo0_l00004ooooo`;o00001?ooool2o`0000?ooooo8_l0
000;ooooo`;o00001?ooool2o`0000Oooooo1?l00002oooooaSo00002Oooool2o`0000Kooooo0ol0
0003ooooo`;o000000?oooooo`000?l000002Oooool3o`0001kooooo0_l0000cooooo`007?ooool0
0ol0003oooooooooo`0looooo`;o000000?oooooo`000?l000005?ooool2o`0000Kooooo0_l00003
ooooo`;o00001Oooool3o`0000Sooooo9?l00008ooooo`?o00003Oooool2o`0000Gooooo2Ol00000
0ooooooo0000o`00000;o`00013ooooo1?l00006ooooo`;o00000_ooool2o`0000Kooooo0_l0001C
ooooo`007?ooool00ol0003oooooooooo`0looooo`?o00001oooool2o`0000gooooo0_l00006oooo
o`;o00000oooool2o`0000Kooooo0_l00009oooooa_o000000?oooooo`000?l000000_l000000ooo
oooo0000o`000008ooooo`;o00002_ooool2o`0000?ooooo0_l00005ooooo`;o000000?oooooo`00
0?l000004Ol00006ooooo`;o00002?ooool5o`0000;ooooo0_l000000ooooooo0000o`000002oooo
o`;o00002Oooool5o`0000Oooooo0_l00003ooooo`;o0000?oooool001cooooo00?o0000oooooooo
ool0?Oooool2o`0000Gooooo1?l0000;ooooo`;o00007Oooool2o`000003ooooool0003o000000So
00000_oooolBo`0000?ooooo1?l00006ooooo`;o00000_ooool2o`0000Kooooo1ol00008oooooa?o
00001?ooool4o`0000Sooooo2Ol000000ooooooo0000o`00000=ooooo`Go00000_ooool2o`0000?o
oooo0_l000000ooooooo0000o`000002o`0003oooooo000Looooo`;o0000?_ooool3o`000004oooo
ool0003o0000ooooo`;o00003?ooool3o`0000Cooooo0_l00005ooooo`;o00001Oooool2o`0000Wo
oooo0_l000000ooooooo0000o`00000@o`000003ooooool0003o000000So000000?oooooo`000?l0
00000_l000000ooooooo0000o`000003ooooo`;o00000_ooool2o`000004ooooool0003o0000o`00
00Kooooo1?l00003ooooo`;o00001Oooool@o`0000Oooooo0_l00007ooooo`;o000000?oooooo`00
0?l000001Ol00003ooooo`;o000000?oooooo`000?l000004Oooool2o`0000Kooooo0_l00008oooo
o`;o0000=oooool001cooooo00?o0000ooooooooool0?Oooool3o`000004ooooool0003o0000o`00
00Oooooo0_l00005ooooo`;o00001Oooool2o`000003ooooool0003o000000;ooooo0_l00005oooo
o`;o00000_ooool2o`0000Sooooo1_l000000ooooooo0000o`00000Ao`000003ooooool0003o0000
00Go00001_ooool2o`000005ooooool0003o0000o`000?ooool00ol0000;ooooo`Co00001Oooool2
o`000003ooooool0003o000000[o00004Oooool2o`000004ooooool0003o0000o`0000Cooooo0_l0
00001?oooooo0000o`000?ooool2o`0002?ooooo0_l0000gooooo`007?ooool00ol0003ooooooooo
o`0nooooo`;o00000_ooool2o`0000Oooooo0_l00008ooooo`;o00001Oooool2o`0000gooooo0_l0
0003oooooa;o000000?oooooo`000?l000002_l000000ooooooo0000o`000002o`0000Sooooo0_l0
0002ooooo`;o00004?ooool2o`0000Oooooo0_l00002ooooo`_o00003?ooool2o`0000Cooooo1?l0
0005ooooo`;o00001_ooool2o`0000Cooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`0n
ooooo`;o00000oooool2o`00013ooooo0_l0000Aooooo`;o00000oooool2o`000003ooooool0003o
000001go00000oooool3o`0000Oooooo0_l0000Fooooo`;o00001Oooool2o`0000Gooooo0_l00000
0ooooooo0000o`000003o`0000;ooooo0_l00008ooooo`;o00001?ooool4o`0000Oooooo0_l00003
ooooo`?o00001?ooool2o`0005Cooooo000Looooo`03o`000?oooooooooo04?ooooo0_l00005oooo
o`;o00007?ooool3o`0000;ooooo3_l000000ooooooo0000o`00000Ao`0000?ooooo0ol00009oooo
o`;o00001_ooool2o`0000Kooooo0_l00004ooooo`;o00001Oooool2o`0000Wooooo0_l000001?oo
oooo0000o`000?ooool4o`0000Wooooo0_l000001?oooooo0000o`000?l00008ooooo`;o00000ooo
ool2o`000003ooooool0003o000001_ooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`1:
ooooo`;o00004_ooool2o`0000Wooooo0_l00004ooooob7o00003_ooool2o`0000Kooooo0_l00006
ooooo`?o00002_ooool2o`0000Wooooo0_l000000ooooooo0000o`000002ooooo`Co00002?ooool5
o`0000Wooooo0_l00006ooooo`;o00006oooool2o`0003_ooooo000Looooo`03o`000?oooooooooo
047ooooo0_l00007ooooo`;o00001_ooool2o`0000[ooooo0_l0000?ooooo`Co00000ooooolJo`00
00?ooooo0_l00004ooooo`;o00002Oooool2o`0000?ooooo0_l00004ooooo`;o000000?oooooo`00
0?l000004?ooool2o`0000Oooooo1?l00003ooooo`Ko000000?oooooo`000?l000002_ooool2o`00
0003ooooool0003o000000Cooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`11ooooo`?o
00001_ooool2o`0000?ooooo0_l000001?oooooo0000o`000?l0000:ooooo`;o00002_ooool3o`00
00?ooooo0_l00002oooooa_o00000oooool4o`0000;ooooo0_l00004ooooo`;o00000oooool2o`00
00?ooooo0_l00007ooooo`;o00002?ooool2o`0000Kooooo0_l0000;ooooo`Wo00001_ooool2o`00
00Gooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000005Oooooo000Looooo`03
o`000?oooooooooo04;ooooo0_l0000;ooooo`;o00000_ooool2o`0000[ooooo1?l00004ooooo`;o
00000_ooool3o`0000Gooooo6Ol00002ooooo`;o00001Oooool2o`0000Sooooo0_l0000?ooooo`;o
00001?ooool2o`0000Cooooo0_l00003ooooo`;o00002oooool8o`0000[ooooo0_l00005ooooo`;o
00000oooool3o`0000Cooooo0_l00004ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0
A_ooool2o`0000_ooooo0_l00002ooooo`;o00002?ooool2o`0000Cooooo0_l0000:oooooaWo0000
0_ooool2o`0001Oooooo0_l00007ooooo`;o00001?ooool2o`0000Wooooo0_l00004ooooo`;o0000
1Oooool6o`0000Oooooo0_l00003ooooo`;o00003?ooool2o`0000?ooooo0_l00004ooooo`;o0000
C_ooool001cooooo00?o0000ooooooooool0A_ooool2o`0000_ooooo0_l00002ooooo`;o00004?oo
ool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`00000Fo`0000;ooooo0_l0
000Gooooo`;o00001?ooool3o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000Oooooo
0_l00004ooooo`;o00002Oooool2o`0000Gooooo1?l00003ooooo`;o00003?ooool2o`0000Kooooo
0_l00003ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0B_ooool2o`0000cooooo1?l0
000=ooooo`;o000000?oooooo`000?l000000oooool9o`000003ooooool0003o000000[o000000?o
ooooo`000?l000000_l0000=ooooo`;o00000oooool2o`0000?ooooo0_l00008ooooo`Oo000000Co
ooooo`000?l0003ooooo0_l00007ooooo`;o00003_ooool2o`0000?ooooo0_l000000ooooooo0000
o`00000Kooooo`;o00000oooool2o`0004cooooo000Looooo`03o`000?oooooooooo04[ooooo0_l0
0008ooooo`;o00000_ooool6o`0001?ooooo0ol000000ooooooo0000o`00000Fo`0000cooooo0_l0
0003ooooo`;o00000_ooool3o`0000?ooooo0_l00003ooooo`Go00007oooool2o`0000?ooooo0_l0
000Iooooo`Co0000E?ooool001cooooo00?o0000ooooooooool0Aoooool2o`000003ooooool0003o
000000Gooooo0_l000000ooooooo0000o`000006ooooo`;o00003?ooool4o`0000Oooooo0_l00000
0ooooooo0000o`00000Co`0000gooooo1_l00002ooooo`;o00001?ooool2o`0000Gooooo0_l0000?
ooooo`;o000000Coooooo`000?l0003ooooo0_l00006ooooo`;o000000?oooooo`000?l000001Ooo
ool2o`0000?ooooo0_l00006ooooo`;o00002_ooool4o`0005Cooooo000Looooo`03o`000?oooooo
oooo03oooooo0_l00006ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o00002Oooool2
o`0000Sooooo0_l00002ooooo`Co00002?ooool5o`000003ooooool0003o000000Wo00001?ooool2
o`0000Kooooo0_l00005ooooo`Ko00002Oooool3o`0000Oooooo0_l0000;ooooo`;o000000Cooooo
o`000?l0003ooooo0_l00004ooooo`Go00001oooool2o`0000?ooooo0_l00006ooooo`;o00000_oo
ool2o`0000Gooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00002Oooool4
o`0000?ooooo0_l0000<ooooo`Co00000oooool2o`0000kooooo1?l00003ooooo`;o000000?ooooo
o`000?l000000ol00006ooooo`;o00001_ooool2o`0000?ooooo0_l00004ooooo`;o00002Oooool3
o`000003ooooool0003o000000;o00000_ooool2o`0000Wooooo0_l0000<ooooo`;o000000Cooooo
o`000?l0003o00001?ooool2o`0000Sooooo1?l00005ooooo`;o00001Oooool3o`0005Kooooo000L
ooooo`;o0000A?ooool2o`0000Cooooo1?l00004ooooo`;o00003?ooool4o`00017ooooo0_l00002
ooooo`Co00000_ooool7o`000004ooooool0003o0000o`0000_ooooo0_l00002ooooo`;o00001?oo
ool2o`0000gooooo1?l0000=ooooo`;o00003oooool3o`0000;ooooo1?l00005ooooo`;o000000?o
ooooo`000?l000000_l0000=ooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0@oooool2
o`0000Cooooo1?l00006ooooo`;o00004_ooool2o`0000Oooooo0_l00002ooooo`;o00001?ooool2
o`0000;ooooo1Ol00003ooooo`?o00002oooool2o`000003ooooool0003o000002oooooo0_l00005
ooooo`?o00000_ooool2o`0000Oooooo0_l000001?oooooo0000o`000?l0000?ooooo`Co0000Dooo
ool001cooooo00?o0000ooooooooool0DOooool4o`0001;ooooo0_l00007ooooo`;o00003_ooool3
o`000003ooooool0003o000000;o00001_ooool2o`0000?ooooo1_l0000;ooooo`;o00007oooool2
o`000003ooooool0003o000000[ooooo0_l0000Cooooo`;o00001oooool4o`0005?ooooo000Loooo
o`03o`000?oooooooooo04kooooo0_l000000ooooooo0000o`000008ooooo`;o00001oooool2o`00
00oooooo0_l0000;ooooo`Ko00001?ooool4o`0000?ooooo1?l00003ooooo`;o00002?ooool2o`00
01Cooooo0_l00009ooooo`;o00000oooool2o`0000Sooooo0_l0000:ooooo`;o00001oooool2o`00
00Oooooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o000000?oooooo`000?l0
00001?ooool2o`0000;ooooo0_l00007ooooo`;o00003oooool4o`0000Wooooo1?l00006ooooo`;o
00001_ooool2o`000004ooooool0003o0000ooooo`;o00001?ooool2o`0000?ooooo0_l0000Coooo
o`;o00003_ooool2o`0001Cooooo0_l0001Wooooo`007?ooool00ol0003oooooooooo`18ooooo`;o
00001oooool2o`0000Cooooo0_l00005ooooo`;o00002?ooool2o`0000[ooooo0_l000000ooooooo
0000o`000009ooooo`Co00001_ooool2o`0000Kooooo0_l000001?oooooo0000o`000?l00002oooo
o`;o00000_ooool2o`0000?ooooo1?l0000Gooooo`;o00002?ooool2o`0000?ooooo0_l00002oooo
o`;o0000M?ooool001cooooo00?o0000ooooooooool0B?ooool2o`0000?ooooo0_l0000?ooooo`;o
00001oooool3o`0000?ooooo0_l00005ooooo`;o00002?ooool2o`000004ooooool0003o0000o`00
00?ooooo0_l00008ooooo`Co00000oooool2o`0000;ooooo0_l000001Ooooooo0000o`000?l0003o
oooo00;o00000_ooool2o`0000cooooo0_l00009ooooo`;o000000?oooooo`000?l000001Oooool2
o`0000;ooooo1ol00009ooooo`;o00002?ooool2o`0005oooooo000Looooo`03o`000?oooooooooo
04gooooo0ol00005ooooo`;o00001_ooool4o`0000Kooooo0ol00003ooooo`;o00002?ooool2o`00
00Gooooo0_l000000ooooooo0000o`000004ooooo`;o00001Oooool2o`000003ooooool0003o0000
00?o00002Oooool3o`000003ooooool0003o0000013ooooo0_l0000<ooooo`;o00000oooool2o`00
00Cooooo1Ol0000;ooooo`;o00002?ooool2o`0005oooooo000Looooo`03o`000?oooooooooo04ko
oooo0_l00005ooooo`;o00001_ooool4o`0000?ooooo0_l0000@ooooo`?o00005Oooool2o`000004
ooooool0003o0000ooooo`;o00001oooool2o`000003ooooool0003o0000017ooooo1_l0000?oooo
o`;o00001_ooool2o`0007Oooooo000Looooo`03o`000?oooooooooo05Cooooo0_l000001?oooooo
0000o`000?ooool2o`0000Sooooo0_l0000@ooooo`;o00003?ooool2o`0000?ooooo1?l00007oooo
o`;o00001oooool4o`0001;ooooo0_l00002ooooo`;o00002oooool2o`0000;ooooo0_l0000Doooo
o`?o00004?ooool2o`0005Kooooo000Looooo`03o`000?oooooooooo04oooooo0_l00003ooooo`;o
000000Coooooo`000?l0003ooooo0_l0000Iooooo`Co000000?oooooo`000?l000002?ooool2o`00
00?ooooo1?l0000Aooooo`?o00008oooool2o`0001Sooooo0ol0000=ooooo`;o000000?oooooo`00
0?l000002Oooool2o`0004_ooooo000Looooo`03o`000?oooooooooo04oooooo0_l00006ooooo`Co
00000_ooool2o`0000Sooooo0_l00006ooooo`;o00001?ooool4o`000003ooooool0003o000000go
oooo0_l00002ooooo`;o00001oooool2o`0000Kooooo0ol0000Iooooo`;o00004_ooool2o`0000So
oooo0_l000001?oooooo0000o`000?l00005ooooo`;o00000_ooool2o`0000?ooooo1?l0000<oooo
o`;o0000Boooool001cooooo00?o0000ooooooooool0Eoooool4o`0000;ooooo0_l00008ooooo`;o
00001_ooool2o`0000Kooooo0_l00005ooooo`;o00001oooool2o`000004ooooool0003o0000oooo
o`;o00000_ooool2o`0000?ooooo0_l00006ooooo`?o00004Oooool2o`0000Kooooo0_l0000Boooo
o`;o00000_ooool2o`0000?ooooo0ol000001?oooooo0000o`000?l00005ooooo`;o00000_ooool2
o`0000?ooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`1Cooooo`Co00000oooool4o`00
00;ooooo0_l0000Aooooo`;o00002Oooool3o`0000;ooooo0_l00002ooooo`;o000000?oooooo`00
0?l000001Oooool2o`0001?ooooo0_l00007ooooo`;o000000Coooooo`000?l0003o00003Oooool2
o`0000kooooo1?l000000ooooooo0000o`00000:ooooo`;o00000_ooool2o`00063ooooo000Loooo
o`03o`000?oooooooooo05?ooooo1?l00003ooooo`Co00000_ooool3o`0000Cooooo0_l0000:oooo
o`;o00002_ooool2o`0000;ooooo0ol0000;ooooo`;o00002?ooool2o`0000Gooooo0_l00002oooo
o`?o00001?ooool4o`000003ooooool0003o000000;o00003?ooool2o`0000Sooooo0_l00006oooo
o`;o00003Oooool2o`0006Cooooo000Looooo`03o`000?oooooooooo057ooooo0_l0000=ooooo`?o
00001?ooool5o`0001Sooooo0_l0000<ooooo`Go00001?ooool2o`0000Gooooo0_l00003ooooo`;o
00001?ooool2o`0000Gooooo0_l0000Aooooo`;o00000oooool2o`0000Kooooo1?l00003ooooo`?o
00007?ooool2o`0004gooooo000Looooo`;o0000D_ooool2o`0000Sooooo0_l00003ooooo`;o0000
1_ooool4o`0000[ooooo0_l00003ooooo`;o00004Oooool2o`0000;ooooo1Ol00003ooooo`;o0000
1Oooool2o`0000Gooooo0_l00003ooooo`?o00005oooool2o`0000;ooooo0_l00007ooooo`Co0000
0oooool3o`000004ooooool0003o0000o`0001Cooooo0_l00002ooooo`;o0000COooool001cooooo
00?o0000ooooooooool0Foooool2o`0000cooooo0_l0000;ooooo`;o00000oooool4o`0000oooooo
0ol00009ooooo`;o00001Oooool2o`0000Cooooo1Ol000001?oooooo0000o`000?l00006ooooo`;o
00004oooool2o`0001;ooooo1?l0000Cooooo`;o0000DOooool001cooooo00?o0000ooooooooool0
JOooool2o`0000Cooooo0_l00004ooooo`;o00001_ooool2o`00013ooooo0_l00003ooooo`;o0000
1oooool2o`0000Cooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00001_ooool2o`0000;o
oooo0_l00005ooooo`;o00002Oooool2o`0000?ooooo0ol00005ooooo`;o00001_ooool3o`000003
ooooool0003o000006Kooooo000Looooo`03o`000?oooooooooo067ooooo0ol000000ooooooo0000
o`000008ooooo`;o00000oooool3o`0000Kooooo0_l00005ooooo`;o00001oooool2o`0000Gooooo
0_l00007ooooo`;o000000?oooooo`000?l000000ol000000ooooooo0000o`000007ooooo`;o0000
00Coooooo`000?l0003ooooo0_l00006ooooo`;o00002Oooool2o`0000?ooooo0ol00005ooooo`;o
00001_ooool3o`0006Wooooo000Looooo`03o`000?oooooooooo063ooooo1?l000000ooooooo0000
o`000007ooooo`;o00001?ooool2o`0000;ooooo0_l00003ooooo`;o00001Oooool2o`0000Gooooo
1?l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo
1?l0000;ooooo`;o00001?ooool2o`0000_ooooo0_l00006ooooo`;o000000?oooooo`000?l00000
3_ooool2o`0006[ooooo000Looooo`03o`000?oooooooooo063ooooo1?l0000:ooooo`;o00002?oo
ool2o`00017ooooo0ol00002ooooo`;o00001Oooool2o`0000;ooooo0_l0000:ooooo`;o00000ooo
ool2o`0000Cooooo1?l0000<ooooo`;o00001_ooool2o`000003ooooool0003o000000Sooooo0_l0
0004ooooo`;o0000J_ooool001cooooo00?o0000ooooooooool0EOooool2o`0000kooooo0_l0000c
ooooo`Co00002Oooool2o`0000?ooooo0_l00004ooooo`Go00002oooool2o`0000;ooooo0_l00004
ooooo`;o00002Oooool2o`00073ooooo000Looooo`03o`000?oooooooooo05Gooooo0_l0000>oooo
o`?o00001?ooool4o`0001Gooooo0_l0000Cooooo`Co000000?oooooo`000?l000002?ooool2o`00
00Gooooo0_l00003ooooo`;o00002oooool3o`000003ooooool0003o000000Cooooo1?l0000;oooo
o`;o0000K?ooool001cooooo00?o0000ooooooooool0I_ooool2o`0000Cooooo1?l00004ooooo`;o
00003oooool2o`0001Kooooo1?l00008ooooo`;o00001Oooool2o`00017ooooo0_l00009ooooo`;o
00001_ooool3o`0000;ooooo0_l0000?ooooo`?o0000F_ooool001cooooo00?o0000ooooooooool0
M?ooool3o`0000_ooooo0_l0000Booooo`;o00001Oooool2o`0000Oooooo0_l00009ooooo`;o0000
2Oooool2o`0001Sooooo0ol0000Cooooo`?o0000F_ooool001cooooo00?o0000ooooooooool0IOoo
ool2o`0000Gooooo0_l00007ooooo`Co00001_ooool2o`000003ooooool0003o000000kooooo0_l0
0002ooooo`;o00001?ooool4o`0000Cooooo1?l00009ooooo`;o00001Oooool2o`0000;ooooo0_l0
0003ooooo`;o00003?ooool2o`0007Sooooo000Looooo`03o`000?oooooooooo06Gooooo0_l00000
0ooooooo0000o`000002ooooo`;o00002Oooool2o`0000Kooooo0_l0000Aooooo`;o00001oooool5
o`0000Cooooo0_l0000Booooo`;o00001oooool2o`000003ooooool0003o000000Wooooo0_l00008
ooooo`;o0000K_ooool001cooooo00?o0000ooooooooool0Foooool2o`0000Sooooo1Ol00009oooo
o`?o00000_ooool2o`0001gooooo0_l00002ooooo`?o00004?ooool2o`0001Cooooo0_l0000Coooo
o`;o0000K_ooool001cooooo00?o0000ooooooooool0Eoooool2o`0000;ooooo0_l00009ooooo`Go
00002?ooool3o`0000;ooooo0_l0000Eooooo`?o00001Oooool2o`0000?ooooo0_l0000@ooooo`?o
00002oooool2o`00023ooooo0_l00005ooooo`;o0000H_ooool00006ooooooo^k^ko<S8bo`000?lb
<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooo
oooo05Oooooo0_l0000@ooooo`?o00002?ooool6o`0001Gooooo0ol00008ooooo`;o00002?ooool2
o`0000Wooooo0_l00007ooooo`;o00000_ooool2o`0000_ooooo0_l000000ooooooo0000o`00000@
ooooo`;o00001Oooool2o`0006;ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ
8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1Zooooo`;o0000
2Oooool5o`0000?ooooo0ol0000Hooooo`Co00001_ooool4o`00013ooooo1?l0000<ooooo`;o0000
00Coooooo`000?l0003ooooo0_l0000Hooooo`;o0000HOooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool0K_ooool2o`0000gooooo0ol00005ooooo`?o00004?ooool4o`0000Kooooo0_l000000ooooooo
0000o`000008ooooo`Co00000oooool2o`0000cooooo1?l00004ooooo`;o00000oooool2o`0001?o
oooo0_l0001Qooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05oc8b
<_nHV9SooooooiRHV?lb<S801_ooool3o`0006_ooooo0_l000000ooooooo0000o`000003ooooo`;o
00004?ooool3o`0000kooooo0_l00002ooooo`;o00002Oooool2o`0000Sooooo1?l0000;ooooo`;o
00001?ooool2o`0000_ooooo0_l0000:ooooo`;o0000J_ooool00003ooooool0003ooooo00;ooooo
00?o0000ooooooooool02Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000oooooooo
ool0Joooool2o`0000;ooooo1_l000000ooooooo0000o`000003ooooo`;o00000_ooool2o`0000Oo
oooo0_l0000<ooooo`;o00000_ooool2o`0000Wooooo0_l00007ooooo`;o00002oooool2o`000003
ooooool0003o000000Cooooo0_l0000Gooooo`;o0000J_ooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000oooooooo
ool0Joooool=o`0000?ooooo0_l00002ooooo`;o00001oooool2o`0001;ooooo0ol00004ooooo`Co
00001oooool2o`0000_ooooo0_l00007ooooo`;o00000_ooool2o`0007oooooo00001_ooooooMgMg
oiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooo
oooo06gooooo0_l00003ooooo`Co00001Oooool2o`0001oooooo1Ol00002ooooo`;o00002oooool2
o`0001Kooooo0_l0000Gooooo`;o0000I_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2ooo
ool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0MOooool2o`000004oooo
ool0003o0000ooooo`;o00007oooool2o`000003ooooool0003o000000oooooo0_l0000Cooooo`Co
00006?ooool2o`0006Kooooo000Looooo`03o`000?oooooooooo07Gooooo0_l000000ooooooo0000
o`000004o`0000Kooooo0_l0000?ooooo`;o00000_ooool2o`000003ooooool0003o0000017ooooo
0_l000000ooooooo0000o`00000=ooooo`;o00000_ooool4o`00083ooooo000Looooo`03o`000?oo
oooooooo073ooooo0_l00002ooooo`;o00001?ooool4o`0000Kooooo0_l00002ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0000Cooooo0ol000000ooooooo0000o`000006ooooo`;o00003?oo
ool2o`000003ooooool0003o000000Kooooo0_l000000ooooooo0000o`000002ooooo`?o00006ooo
ool2o`0006Sooooo000Looooo`03o`000?oooooooooo06kooooo2?l0000Booooo`Go00000_ooool2
o`0000;ooooo0_l000000ooooooo0000o`000009ooooo`;o000000?oooooo`000?l000005?ooool5
o`000003ooooool0003o000000Co00006Oooool2o`0006Sooooo000Looooo`03o`000?oooooooooo
06kooooo0_l00002ooooo`?o00005?ooool4o`0000Gooooo0ol00002ooooo`Co00001?ooool2o`00
0003ooooool0003o000000;o00001_ooool2o`0000?ooooo0_l00006ooooo`Ko000000?oooooo`00
0?l000000_ooool2o`0008?ooooo000Looooo`03o`000?oooooooooo07?ooooo0_l00003ooooo`;o
00004?ooool2o`0000Kooooo0_l00003ooooo`Co00001?ooool2o`000003ooooool0003o000000;o
00001_ooool2o`0000?ooooo0_l00006ooooo`Co0000S?ooool001cooooo00?o0000ooooooooool0
N?ooool2o`000003ooooool0003o000000Kooooo0_l00005ooooo`;o00006Oooool2o`0000[ooooo
0_l00008ooooo`;o0000S?ooool001cooooo00?o0000ooooooooool0L_ooool2o`0000Oooooo0_l0
0003ooooo`;o000000?oooooo`000?l000001Oooool2o`0001Wooooo0_l0000:ooooo`;o00002?oo
ool2o`0008cooooo000Looooo`03o`000?oooooooooo073ooooo1?l0000<ooooo`Co00001_ooool2
o`0000Sooooo0_l00004ooooo`;o00000oooool2o`0000kooooo0_l0002Hooooo`007?ooool00ol0
003oooooooooo`1`ooooo`;o00003oooool3o`0000Oooooo0_l00007ooooo`;o00001?ooool2o`00
00?ooooo0_l0000>ooooo`;o0000V?ooool001cooooo00?o0000ooooooooool0Roooool2o`0000So
oooo0_l0000Dooooo`Go00000oooool2o`0002?ooooo0ol0001^ooooo`007?ooool00ol0003ooooo
ooooo`2Eooooo`;o00005?ooool5o`0000?ooooo0_l000000ooooooo0000o`00000Pooooo`?o0000
K_ooool001cooooo0_l0002Looooo`;o00003oooool2o`0000Sooooo0_l0002Aooooo`007?ooool0
0ol0003oooooooooo`2Kooooo`;o0000[?ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo087ooooo
0_l00036ooooo`007?ooool00ol0003oooooooooo`21ooooo`;o0000a_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0aoooool2o`00083ooooo000Looooo`03o`000?oooooooooo0<Oo
oooo0_l00020ooooo`007?ooool00ol0003oooooooooo`1oooooo`;o0000b?ooool001cooooo00?o
0000ooooooooool0Ooooool2o`0002;ooooo0_l0002Tooooo`007?ooool2o`000:Cooooo0_l0002T
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0;co
oooo0_l0002;ooooo`007?ooool00ol0003oooooooooo`2looooo`;o0000Roooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo09Kooooo0_l0002aooooo`007?ooool00ol0003oooooooooo`2Fooooo`;o
0000/Oooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`2Yooooo`;o0000W_ooool001cooooo00?o0000ooooooooool0ZOooool2o`0009kooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`004_ooool4
o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000oooooooo
ool01Oooool3o`000?ooooooB_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?oo
ool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool0
01Cooooo00?o0000ooooooooool0oooooomBooooo`004_ooool00omEEEGoIVIVo`00003ooooooeCo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Qooooo`04oa0@4?l0003o0000
ooooo`;o000000?o410@ooooooooool05_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h3ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^08cooooo002Rooooo`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go8B4QoiRHV?ooooooV9RH
ob4Q8@03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0S?ooool00:;ooooo00Go0000oooooooooooo
ooooo`00000Kooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003oooo
o`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@08cooooo002R
ooooo`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P03ooooo`05
o`000?ooooooooooooooool00000S?ooool00:;ooooo00Go0000ohN7QoooooooZJVYo`00000Koooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05olc<c?l0003o
0000o`000?o<c<`00oooool01Ol0003ooooooooooooooooo000008cooooo002Qooooo`03oa0@4?l0
003oMgMg00;o000000?oV9RHooooooooool06Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41000oooool01Ol@413o^[Zjoooooonj^[[o410@00?ooooo00Go410@oooooooo
oooooooooa0@402<ooooo`00`_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01Ol0003o^[Zjoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`2<ooooo`00`?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP2<ooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1086) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.41887 .65505 Mdot
.39635 .63455 Mdot
.64449 .49242 Mdot
.39221 .43752 Mdot
.42172 .78259 Mdot
.66775 .46383 Mdot
.59421 .60306 Mdot
.58542 .66008 Mdot
.65617 .4875 Mdot
.4626 .66596 Mdot
.58664 .60793 Mdot
.48836 .39949 Mdot
.58142 .6226 Mdot
.38863 .41684 Mdot
.2391 .7196 Mdot
.37325 .36852 Mdot
.36486 .60865 Mdot
.59402 .3559 Mdot
.34784 .43766 Mdot
.68217 .4415 Mdot
.42569 .60513 Mdot
.39455 .42789 Mdot
.39252 .66934 Mdot
.38896 .41632 Mdot
.38483 .44793 Mdot
.38156 .61236 Mdot
.37625 .58936 Mdot
.42894 .45571 Mdot
.3678 .43449 Mdot
.59532 .65514 Mdot
.42616 .26945 Mdot
.29812 .76577 Mdot
.36563 .47503 Mdot
.7164 .70261 Mdot
.57692 .65775 Mdot
.28657 .63761 Mdot
.67974 .47991 Mdot
.58536 .64927 Mdot
.57261 .65251 Mdot
.61202 .60601 Mdot
.57412 .64142 Mdot
.38908 .61635 Mdot
.56675 .67844 Mdot
.51285 .61412 Mdot
.3518 .4005 Mdot
.47978 .7595 Mdot
.29636 .32305 Mdot
.44022 .40818 Mdot
.37058 .60627 Mdot
.62948 .41278 Mdot
.6613 .71761 Mdot
.59095 .59906 Mdot
.64437 .52551 Mdot
.76142 .76667 Mdot
.5943 .64605 Mdot
.34938 .41376 Mdot
.66563 .49816 Mdot
.40335 .42513 Mdot
.39298 .41435 Mdot
.20702 .51665 Mdot
.43959 .45452 Mdot
.57498 .32634 Mdot
.3871 .68042 Mdot
.5486 .40808 Mdot
.66687 .48644 Mdot
.568 .64239 Mdot
.4073 .6317 Mdot
.58705 .62608 Mdot
.47284 .45084 Mdot
.69524 .48378 Mdot
.44017 .41047 Mdot
.56875 .62901 Mdot
.40571 .59995 Mdot
.43196 .42486 Mdot
.77668 .44732 Mdot
.14581 .50291 Mdot
.57771 .30439 Mdot
.24493 .57547 Mdot
.2125 .56189 Mdot
.67229 .35418 Mdot
.37021 .40193 Mdot
.48457 .20442 Mdot
.1874 .61964 Mdot
.37649 .66861 Mdot
.34235 .46063 Mdot
.5861 .50282 Mdot
.42724 .42666 Mdot
.41809 .7326 Mdot
.35583 .40586 Mdot
.81517 .49166 Mdot
.65376 .47956 Mdot
.37574 .6442 Mdot
.38967 .43559 Mdot
.41951 .4652 Mdot
.29538 .35563 Mdot
.45917 .4061 Mdot
.41986 .45328 Mdot
.41934 .6115 Mdot
.57332 .60635 Mdot
.44296 .35556 Mdot
.58498 .68199 Mdot
.63846 .51053 Mdot
.43498 .38641 Mdot
.69163 .47442 Mdot
.41098 .59926 Mdot
.43853 .42785 Mdot
.561 .64347 Mdot
.41802 .38546 Mdot
.61725 .70783 Mdot
.39891 .63643 Mdot
.41257 .46654 Mdot
.58226 .32074 Mdot
.70267 .2702 Mdot
.37535 .65072 Mdot
.6891 .33821 Mdot
.36784 .39616 Mdot
.41632 .445 Mdot
.39411 .63332 Mdot
.63966 .50107 Mdot
.39672 .728 Mdot
.36681 .67283 Mdot
.61203 .60273 Mdot
.37784 .67881 Mdot
.37493 .48713 Mdot
.6606 .47578 Mdot
.68441 .64857 Mdot
.63365 .57905 Mdot
.42518 .25162 Mdot
.4225 .427 Mdot
.509 .70026 Mdot
.65679 .44415 Mdot
.37973 .63365 Mdot
.59025 .62364 Mdot
.35085 .36818 Mdot
.39721 .65554 Mdot
.60294 .62135 Mdot
.59309 .33337 Mdot
.71441 .59038 Mdot
.35217 .63299 Mdot
.51512 .64158 Mdot
.54959 .64167 Mdot
.60331 .60123 Mdot
.7544 .67559 Mdot
.40262 .62564 Mdot
.56299 .34903 Mdot
.59963 .63329 Mdot
.39038 .2891 Mdot
.3656 .45345 Mdot
.50673 .23463 Mdot
.42587 .17845 Mdot
.72519 .69272 Mdot
.75246 .55411 Mdot
.54275 .35435 Mdot
.58258 .59459 Mdot
.3907 .46163 Mdot
.38721 .60565 Mdot
.39619 .61278 Mdot
.44876 .43315 Mdot
.39014 .4435 Mdot
.44013 .41641 Mdot
.40378 .46989 Mdot
.18621 .51476 Mdot
.41039 .37929 Mdot
.35416 .23206 Mdot
.37074 .64669 Mdot
.39992 .45496 Mdot
.66145 .50956 Mdot
.43614 .47507 Mdot
.57102 .63903 Mdot
.40208 .43291 Mdot
.39477 .44121 Mdot
.43666 .45965 Mdot
.58819 .59912 Mdot
.28572 .73796 Mdot
.49646 .17616 Mdot
.34999 .77131 Mdot
.75515 .41397 Mdot
.67107 .44863 Mdot
.42474 .43439 Mdot
.5624 .32955 Mdot
.29816 .6037 Mdot
.37777 .39926 Mdot
.76077 .2649 Mdot
.41052 .45007 Mdot
.37835 .76706 Mdot
.38655 .50742 Mdot
.3729 .79507 Mdot
.48821 .21827 Mdot
.38773 .46415 Mdot
.33268 .34524 Mdot
.36594 .56719 Mdot
.52009 .62039 Mdot
.57526 .63935 Mdot
.65587 .50913 Mdot
.65442 .49809 Mdot
.62641 .60405 Mdot
.44239 .65356 Mdot
.3223 .40006 Mdot
.46978 .41634 Mdot
.66326 .52225 Mdot
.4043 .67715 Mdot
.56628 .36113 Mdot
.42064 .6254 Mdot
.15043 .39201 Mdot
.65421 .70627 Mdot
.63391 .62627 Mdot
.58587 .31124 Mdot
.64001 .47345 Mdot
.64304 .5186 Mdot
.55391 .33283 Mdot
.42003 .39542 Mdot
.40658 .62586 Mdot
.68347 .75585 Mdot
.45041 .62357 Mdot
.73021 .72364 Mdot
.40287 .60239 Mdot
.48404 .64244 Mdot
.59715 .61658 Mdot
.68369 .46768 Mdot
.4185 .44744 Mdot
.41746 .40403 Mdot
.42293 .59629 Mdot
.43801 .41323 Mdot
.31404 .45527 Mdot
.42851 .44847 Mdot
.68292 .67909 Mdot
.57475 .30381 Mdot
.62638 .60437 Mdot
.41492 .24676 Mdot
.40979 .65616 Mdot
.59628 .26343 Mdot
.6826 .49909 Mdot
.28295 .60653 Mdot
.56846 .62363 Mdot
.58757 .32813 Mdot
.68287 .50094 Mdot
.56357 .36226 Mdot
.40416 .48178 Mdot
.63275 .45257 Mdot
.57155 .31766 Mdot
.23918 .64237 Mdot
.37236 .45909 Mdot
.18166 .50987 Mdot
.57229 .60145 Mdot
.36221 .66985 Mdot
.43875 .45469 Mdot
.6845 .45468 Mdot
.36044 .4726 Mdot
.7503 .52137 Mdot
.68431 .65107 Mdot
.625 .47007 Mdot
.68788 .40581 Mdot
.58606 .33481 Mdot
.7134 .5387 Mdot
.5181 .68722 Mdot
.37932 .60091 Mdot
.42691 .37913 Mdot
.35248 .801 Mdot
.59931 .63295 Mdot
.41245 .38955 Mdot
.70503 .66213 Mdot
.59629 .63571 Mdot
.40529 .42447 Mdot
.55315 .62239 Mdot
.39884 .61333 Mdot
.61678 .23517 Mdot
.3669 .60688 Mdot
.35813 .40376 Mdot
.55765 .63544 Mdot
.62928 .48056 Mdot
.37543 .61331 Mdot
.4262 .39138 Mdot
.4349 .44015 Mdot
.55354 .49087 Mdot
.40432 .45977 Mdot
.31756 .75133 Mdot
.41705 .4621 Mdot
.65844 .50485 Mdot
.45934 .41703 Mdot
.8318 .42007 Mdot
.64215 .5763 Mdot
.40737 .63051 Mdot
.62872 .45167 Mdot
.656 .49143 Mdot
.65147 .29375 Mdot
.67888 .53642 Mdot
.37557 .39024 Mdot
.67795 .44973 Mdot
.56748 .25142 Mdot
.60801 .63965 Mdot
.44164 .38426 Mdot
.50488 .61468 Mdot
.62695 .41122 Mdot
.65614 .5241 Mdot
.34551 .38216 Mdot
.38852 .59087 Mdot
.38951 .43662 Mdot
.64744 .51671 Mdot
.42903 .65881 Mdot
.36902 .38777 Mdot
.42961 .55149 Mdot
.55294 .49143 Mdot
.60536 .61541 Mdot
.35988 .49254 Mdot
.43083 .38837 Mdot
.6868 .47675 Mdot
.41562 .63672 Mdot
.59387 .66121 Mdot
.37914 .61892 Mdot
.52408 .81514 Mdot
.6208 .70146 Mdot
.20759 .5875 Mdot
.55712 .37289 Mdot
.78106 .52937 Mdot
.4116 .81551 Mdot
.77383 .38299 Mdot
.51035 .28717 Mdot
.58593 .81706 Mdot
.65409 .51409 Mdot
.71908 .65684 Mdot
.65715 .4949 Mdot
.37269 .42868 Mdot
.66496 .477 Mdot
.40275 .81521 Mdot
.42711 .45021 Mdot
.67099 .47487 Mdot
.62759 .2611 Mdot
.39669 .44859 Mdot
.37712 .65399 Mdot
.22832 .69145 Mdot
.78978 .38495 Mdot
.69537 .6961 Mdot
.64207 .44564 Mdot
.47703 .31681 Mdot
.41938 .45606 Mdot
.45943 .43786 Mdot
.36422 .61742 Mdot
.45484 .39423 Mdot
.56067 .36076 Mdot
.58957 .31255 Mdot
.50103 .48593 Mdot
.52112 .19227 Mdot
.47288 .39079 Mdot
.37263 .61364 Mdot
.20811 .44744 Mdot
.77996 .45715 Mdot
.7512 .4451 Mdot
.57165 .59333 Mdot
.26858 .71396 Mdot
.37179 .52211 Mdot
.60935 .68945 Mdot
.52118 .59896 Mdot
.38556 .64519 Mdot
.29908 .75065 Mdot
.57863 .64174 Mdot
.27497 .43019 Mdot
.39146 .31608 Mdot
.41611 .39806 Mdot
.57393 .61257 Mdot
.48413 .40886 Mdot
.81632 .42379 Mdot
.27316 .32636 Mdot
.39748 .21827 Mdot
.36282 .38954 Mdot
.77142 .43763 Mdot
.40767 .44008 Mdot
.37411 .72842 Mdot
.41965 .4614 Mdot
.37239 .62338 Mdot
.42803 .7017 Mdot
.52924 .47784 Mdot
.45274 .18329 Mdot
.64528 .70847 Mdot
.54332 .35487 Mdot
.4251 .44509 Mdot
.41477 .39801 Mdot
.57794 .35305 Mdot
.37073 .66143 Mdot
.40158 .47029 Mdot
.57345 .26669 Mdot
.4296 .4168 Mdot
.57722 .64754 Mdot
.36715 .2442 Mdot
.36985 .58669 Mdot
.4564 .38705 Mdot
.42036 .66369 Mdot
.60779 .61828 Mdot
.57692 .65531 Mdot
.38677 .35934 Mdot
.62167 .62716 Mdot
.40358 .44473 Mdot
.27961 .29427 Mdot
.35922 .65138 Mdot
.34739 .48994 Mdot
.39311 .66668 Mdot
.24356 .58422 Mdot
.56303 .65053 Mdot
.67405 .67244 Mdot
.4372 .34989 Mdot
.57775 .63694 Mdot
.60003 .71086 Mdot
.46606 .38298 Mdot
.38308 .3694 Mdot
.813 .52837 Mdot
.63501 .4569 Mdot
.54297 .47846 Mdot
.57263 .6599 Mdot
.43505 .39284 Mdot
.43925 .37771 Mdot
.60742 .61428 Mdot
.25573 .41872 Mdot
.70259 .30715 Mdot
.42598 .455 Mdot
.36605 .63316 Mdot
.37984 .63122 Mdot
.37237 .3782 Mdot
.40894 .38464 Mdot
.64886 .46007 Mdot
.63357 .44495 Mdot
.6606 .4308 Mdot
.5516 .49063 Mdot
.67769 .67536 Mdot
.52123 .77731 Mdot
.61176 .60598 Mdot
.53473 .72493 Mdot
.80951 .47036 Mdot
.40943 .48935 Mdot
.66147 .43834 Mdot
.40435 .39875 Mdot
.39314 .43485 Mdot
.59636 .66057 Mdot
.70115 .68315 Mdot
.47739 .46351 Mdot
.35581 .65038 Mdot
.57799 .66343 Mdot
.37229 .34428 Mdot
.57562 .75058 Mdot
.57402 .32116 Mdot
.77347 .63639 Mdot
.56729 .63132 Mdot
.38482 .64977 Mdot
.55574 .63963 Mdot
.42096 .40542 Mdot
.34694 .42339 Mdot
.38774 .63731 Mdot
.56377 .31554 Mdot
.44274 .46387 Mdot
.407 .42775 Mdot
.57402 .15871 Mdot
.78036 .43132 Mdot
.67088 .65105 Mdot
.39495 .46622 Mdot
.43249 .3713 Mdot
.57874 .36333 Mdot
.4271 .41233 Mdot
.4443 .43226 Mdot
.648 .22983 Mdot
.65032 .63619 Mdot
.6023 .33551 Mdot
.27371 .44221 Mdot
.39726 .60002 Mdot
.33126 .78959 Mdot
.68357 .46311 Mdot
.62606 .6305 Mdot
.70905 .30121 Mdot
.63636 .5125 Mdot
.76347 .51474 Mdot
.32114 .782 Mdot
.54334 .4834 Mdot
.59605 .29491 Mdot
.49101 .4352 Mdot
.43677 .44969 Mdot
.41157 .44044 Mdot
.56152 .33478 Mdot
.4029 .62073 Mdot
.54197 .45251 Mdot
.18629 .43612 Mdot
.39968 .43453 Mdot
.31115 .44409 Mdot
.24175 .66099 Mdot
.62262 .40671 Mdot
.55259 .35654 Mdot
.56907 .31272 Mdot
.42158 .44414 Mdot
.66551 .24936 Mdot
.38124 .61147 Mdot
.42517 .39079 Mdot
.38884 .38007 Mdot
.63844 .44829 Mdot
.39947 .64202 Mdot
.6554 .51545 Mdot
.66891 .67354 Mdot
.36983 .76938 Mdot
.58486 .1561 Mdot
.57075 .65487 Mdot
.30032 .70789 Mdot
.60268 .64745 Mdot
.47024 .20734 Mdot
.63997 .51993 Mdot
.37457 .39748 Mdot
.41417 .64418 Mdot
.42326 .3879 Mdot
.39813 .38888 Mdot
.4185 .39498 Mdot
.46744 .44403 Mdot
.78883 .30824 Mdot
.55383 .32672 Mdot
.44821 .37465 Mdot
.65116 .50009 Mdot
.30251 .72074 Mdot
.15736 .53857 Mdot
.41044 .40405 Mdot
.43205 .43924 Mdot
.38255 .65851 Mdot
.45357 .4246 Mdot
.60641 .64049 Mdot
.4165 .63302 Mdot
.41495 .46679 Mdot
.28365 .7178 Mdot
.37095 .44611 Mdot
.36546 .78402 Mdot
.5571 .64477 Mdot
.57122 .70329 Mdot
.45972 .38224 Mdot
.6812 .64577 Mdot
.54297 .4783 Mdot
.67889 .44566 Mdot
.60438 .6667 Mdot
.67792 .48149 Mdot
.22796 .35624 Mdot
.35732 .45757 Mdot
.38861 .45843 Mdot
.43805 .37855 Mdot
.67437 .44952 Mdot
.41471 .74558 Mdot
.68314 .55942 Mdot
.3507 .3576 Mdot
.65736 .45374 Mdot
.40262 .67588 Mdot
.58163 .40256 Mdot
.40786 .655 Mdot
.59825 .31668 Mdot
.58575 .60928 Mdot
.54389 .32977 Mdot
.70542 .69814 Mdot
.39675 .63649 Mdot
.41426 .58684 Mdot
.67306 .45554 Mdot
.58983 .54499 Mdot
.69225 .80643 Mdot
.57336 .43105 Mdot
.47387 .24355 Mdot
.3618 .62329 Mdot
.36042 .41136 Mdot
.43047 .21686 Mdot
.57256 .5465 Mdot
.67568 .48421 Mdot
.37594 .40937 Mdot
.64064 .24474 Mdot
.64903 .45897 Mdot
.43829 .38275 Mdot
.63458 .48199 Mdot
.57182 .62746 Mdot
.64671 .44821 Mdot
.35359 .61595 Mdot
.43565 .43024 Mdot
.66802 .81911 Mdot
.61412 .35349 Mdot
.41217 .46217 Mdot
.57432 .6622 Mdot
.45095 .53718 Mdot
.39308 .39645 Mdot
.5913 .34777 Mdot
.66163 .46945 Mdot
.57152 .45355 Mdot
.42499 .45692 Mdot
.66907 .44959 Mdot
.41345 .65988 Mdot
.606 .66634 Mdot
.51753 .42764 Mdot
.68706 .65913 Mdot
.36718 .61344 Mdot
.55887 .68283 Mdot
.60379 .66206 Mdot
.44137 .37529 Mdot
.40954 .37804 Mdot
.37001 .63377 Mdot
.58319 .22438 Mdot
.45775 .42803 Mdot
.37036 .40197 Mdot
.65083 .50214 Mdot
.677 .47441 Mdot
.59329 .23197 Mdot
.63734 .49684 Mdot
.3494 .43257 Mdot
.3709 .63162 Mdot
.38353 .42889 Mdot
.3856 .65562 Mdot
.45408 .41383 Mdot
.42788 .66638 Mdot
.36589 .66135 Mdot
.6837 .54829 Mdot
.37914 .41972 Mdot
.37342 .50334 Mdot
.40897 .39028 Mdot
.43584 .41707 Mdot
.64816 .46532 Mdot
.54946 .34753 Mdot
.36836 .35932 Mdot
.60393 .31639 Mdot
.57565 .35821 Mdot
.36022 .57362 Mdot
.63814 .45004 Mdot
.56894 .34226 Mdot
.18582 .56488 Mdot
.65115 .43397 Mdot
.56983 .32911 Mdot
.16935 .56622 Mdot
.57374 .65702 Mdot
.36344 .60733 Mdot
.39555 .44813 Mdot
.58805 .81123 Mdot
.30868 .2877 Mdot
.63071 .50102 Mdot
.41436 .46285 Mdot
.4005 .3984 Mdot
.37204 .67263 Mdot
.27508 .2553 Mdot
.69727 .45798 Mdot
.37427 .43788 Mdot
.40683 .63628 Mdot
.31224 .22087 Mdot
.66375 .50417 Mdot
.56673 .33056 Mdot
.58694 .5984 Mdot
.34546 .66863 Mdot
.63143 .5746 Mdot
.60142 .60555 Mdot
.62209 .52411 Mdot
.66961 .70753 Mdot
.36832 .39533 Mdot
.66281 .43885 Mdot
.78745 .62944 Mdot
.43746 .5911 Mdot
.5341 .62527 Mdot
.47377 .32411 Mdot
.3831 .64645 Mdot
.60583 .63951 Mdot
.54 .34179 Mdot
.40747 .60461 Mdot
.36441 .65222 Mdot
.60364 .65543 Mdot
.49921 .47284 Mdot
.50514 .60558 Mdot
.57754 .65162 Mdot
.80872 .5058 Mdot
.57681 .79172 Mdot
.66585 .43731 Mdot
.57193 .3578 Mdot
.66913 .74956 Mdot
.38805 .61615 Mdot
.27067 .71593 Mdot
.7932 .61094 Mdot
.41963 .45337 Mdot
.57136 .34599 Mdot
.4534 .76717 Mdot
.20129 .40208 Mdot
.59592 .63775 Mdot
.53093 .49273 Mdot
.53167 .33822 Mdot
.44211 .44861 Mdot
.39506 .30693 Mdot
.37213 .41739 Mdot
.59422 .61129 Mdot
.20314 .53455 Mdot
.38508 .65064 Mdot
.58895 .66544 Mdot
.77125 .63954 Mdot
.40142 .44093 Mdot
.37606 .41444 Mdot
.39726 .25834 Mdot
.4005 .60841 Mdot
.68238 .4475 Mdot
.37073 .39375 Mdot
.40474 .43016 Mdot
.34856 .38824 Mdot
.34034 .47689 Mdot
.69481 .26608 Mdot
.37378 .43352 Mdot
.658 .68965 Mdot
.45575 .38496 Mdot
.38136 .41771 Mdot
.4194 .66529 Mdot
.64144 .18304 Mdot
.66728 .67665 Mdot
.40339 .43295 Mdot
.36204 .41613 Mdot
.6056 .65469 Mdot
.50875 .58143 Mdot
.59145 .5487 Mdot
.57636 .4969 Mdot
.4944 .29958 Mdot
.46815 .44528 Mdot
.40925 .64521 Mdot
.58031 .31771 Mdot
.3887 .37362 Mdot
.40817 .64572 Mdot
.40262 .47687 Mdot
.65074 .45545 Mdot
.64782 .43479 Mdot
.51765 .664 Mdot
.57106 .33603 Mdot
.35361 .27371 Mdot
.5281 .73177 Mdot
.64974 .50495 Mdot
.3877 .45469 Mdot
.62603 .64288 Mdot
.64701 .51763 Mdot
.59691 .5197 Mdot
.32634 .41855 Mdot
.38858 .60866 Mdot
.37454 .6466 Mdot
.50967 .23466 Mdot
.73156 .57592 Mdot
.58262 .17599 Mdot
.57241 .62318 Mdot
.44218 .45831 Mdot
.50943 .6876 Mdot
.37499 .64876 Mdot
.4468 .21621 Mdot
.57122 .34177 Mdot
.59764 .63802 Mdot
.74922 .45176 Mdot
.39294 .65642 Mdot
.3581 .61852 Mdot
.35802 .42081 Mdot
.41038 .4171 Mdot
.51764 .28064 Mdot
.52633 .32273 Mdot
.60934 .62319 Mdot
.57688 .35472 Mdot
.68011 .50505 Mdot
.37054 .42976 Mdot
.38534 .67042 Mdot
.64055 .76336 Mdot
.36175 .40976 Mdot
.64659 .46333 Mdot
.38198 .64339 Mdot
.58333 .34857 Mdot
.58232 .35624 Mdot
.43446 .41717 Mdot
.21298 .44934 Mdot
.58738 .64356 Mdot
.37754 .653 Mdot
.61133 .73631 Mdot
.46014 .41797 Mdot
.41336 .42275 Mdot
.40238 .50054 Mdot
.60498 .65016 Mdot
.53067 .68424 Mdot
.54677 .32139 Mdot
.39644 .62168 Mdot
.37981 .45729 Mdot
.57587 .32929 Mdot
.52245 .68301 Mdot
.62547 .47766 Mdot
.64206 .45498 Mdot
.58947 .35026 Mdot
.57158 .3521 Mdot
.59121 .34444 Mdot
.26354 .7128 Mdot
.34589 .62865 Mdot
.38756 .52696 Mdot
.45719 .43507 Mdot
.49208 .22924 Mdot
.36532 .35445 Mdot
.56353 .66015 Mdot
.63428 .46211 Mdot
.40231 .39043 Mdot
.35956 .40075 Mdot
.3789 .5011 Mdot
.37709 .51329 Mdot
.37833 .58474 Mdot
.39914 .63845 Mdot
.37534 .47511 Mdot
.63252 .4571 Mdot
.16753 .35996 Mdot
.51537 .85139 Mdot
.45125 .37249 Mdot
.54282 .56546 Mdot
.384 .66964 Mdot
.61771 .63382 Mdot
.59563 .53287 Mdot
.55489 .62846 Mdot
.39118 .62487 Mdot
.37145 .43042 Mdot
.54085 .73218 Mdot
.58737 .35574 Mdot
.44174 .40455 Mdot
.60032 .6235 Mdot
.44216 .41063 Mdot
.59968 .60459 Mdot
.48962 .80838 Mdot
.80856 .45474 Mdot
.41178 .45062 Mdot
.43436 .3685 Mdot
.48695 .32354 Mdot
.40827 .40416 Mdot
.58419 .38983 Mdot
.38157 .6682 Mdot
.54102 .17909 Mdot
.36224 .43988 Mdot
.28418 .54356 Mdot
.461 .42038 Mdot
.64568 .25377 Mdot
.41495 .4177 Mdot
.63509 .40437 Mdot
.43239 .45296 Mdot
.44289 .42946 Mdot
.55634 .632 Mdot
.60403 .65592 Mdot
.4247 .6172 Mdot
.68387 .45258 Mdot
.34963 .77753 Mdot
.40943 .42674 Mdot
.68863 .65816 Mdot
.63852 .68513 Mdot
.56951 .35418 Mdot
.39053 .62272 Mdot
.28547 .23422 Mdot
.56015 .60582 Mdot
.74279 .36969 Mdot
.59248 .24344 Mdot
.64139 .59369 Mdot
.58679 .50923 Mdot
.39616 .71982 Mdot
.58477 .33111 Mdot
.44394 .44803 Mdot
.68847 .71766 Mdot
.76984 .45897 Mdot
.32441 .39976 Mdot
.59167 .66725 Mdot
.29082 .59377 Mdot
.6577 .75424 Mdot
.53918 .32409 Mdot
.54411 .32774 Mdot
.59032 .6005 Mdot
.64131 .41277 Mdot
.48368 .43798 Mdot
.57415 .34072 Mdot
.64137 .49887 Mdot
.66266 .43455 Mdot
.73491 .4799 Mdot
.38718 .61214 Mdot
.74853 .66299 Mdot
.49181 .74822 Mdot
.60192 .60705 Mdot
.61645 .30549 Mdot
.33967 .64598 Mdot
.36511 .59855 Mdot
.67945 .46341 Mdot
.64566 .46923 Mdot
.37069 .59896 Mdot
.35752 .4406 Mdot
.40926 .50629 Mdot
.40216 .4355 Mdot
.55665 .3382 Mdot
.41495 .41086 Mdot
.65333 .45993 Mdot
.59234 .63375 Mdot
.64597 .4773 Mdot
.5543 .61523 Mdot
.53481 .77136 Mdot
.42998 .39764 Mdot
.43674 .43419 Mdot
.30709 .28622 Mdot
.4232 .64985 Mdot
.63771 .7213 Mdot
.69243 .67676 Mdot
.65569 .4962 Mdot
.44479 .43295 Mdot
.40899 .65991 Mdot
.56864 .30851 Mdot
.30604 .28511 Mdot
.42593 .38274 Mdot
.38661 .66868 Mdot
.37872 .44947 Mdot
.20726 .60328 Mdot
.78034 .34331 Mdot
.37862 .62262 Mdot
.4157 .18398 Mdot
.36821 .43278 Mdot
.39955 .70903 Mdot
.42327 .3747 Mdot
.53858 .2518 Mdot
.45802 .42578 Mdot
.4026 .60201 Mdot
.39901 .42891 Mdot
.41313 .61514 Mdot
.66595 .50676 Mdot
.61473 .61302 Mdot
.35774 .63009 Mdot
.4002 .37679 Mdot
.3848 .85707 Mdot
.58824 .61162 Mdot
.42147 .44645 Mdot
.56825 .60675 Mdot
.4102 .62897 Mdot
.36339 .61348 Mdot
.17692 .44057 Mdot
.66085 .64239 Mdot
.57212 .62872 Mdot
.37683 .43919 Mdot
.45835 .72619 Mdot
.37912 .42685 Mdot
.50161 .2707 Mdot
.3488 .39982 Mdot
.45927 .41942 Mdot
.14661 .49727 Mdot
.61015 .63737 Mdot
.6061 .19247 Mdot
.17509 .45973 Mdot
.25643 .70014 Mdot
.35997 .68142 Mdot
.54618 .31899 Mdot
.29504 .74576 Mdot
.67396 .66955 Mdot
.66296 .45001 Mdot
.40516 .3908 Mdot
.3417 .61442 Mdot
.58803 .64995 Mdot
.54885 .34412 Mdot
.41267 .45062 Mdot
.64415 .46991 Mdot
.71307 .32585 Mdot
.58321 .5934 Mdot
.38976 .61697 Mdot
.35854 .65675 Mdot
.36902 .19076 Mdot
.38698 .46421 Mdot
.4384 .4368 Mdot
.59106 .60938 Mdot
.43433 .58016 Mdot
.58791 .33464 Mdot
.65697 .27344 Mdot
.57273 .62652 Mdot
.55689 .52786 Mdot
.40327 .62999 Mdot
.40233 .39805 Mdot
.40503 .75305 Mdot
.75281 .42713 Mdot
.30155 .4762 Mdot
.56096 .33185 Mdot
.49195 .27275 Mdot
.4015 .60135 Mdot
.5942 .62561 Mdot
.72549 .59535 Mdot
.35592 .47299 Mdot
.39912 .40296 Mdot
.48519 .27122 Mdot
.51972 .46526 Mdot
.391 .22287 Mdot
.43888 .38667 Mdot
.53176 .45733 Mdot
.44842 .39934 Mdot
.34023 .4517 Mdot
.34972 .42721 Mdot
.41834 .42713 Mdot
.38545 .66901 Mdot
.32662 .40215 Mdot
.66317 .44504 Mdot
.29975 .35453 Mdot
.56424 .50457 Mdot
.41965 .45911 Mdot
.37371 .42525 Mdot
.33424 .53249 Mdot
.59902 .68959 Mdot
.36093 .64294 Mdot
.43492 .60681 Mdot
.6209 .62014 Mdot
.3885 .50557 Mdot
.689 .45602 Mdot
.33759 .39003 Mdot
.64876 .46954 Mdot
.39907 .66577 Mdot
.65873 .49926 Mdot
.60409 .59974 Mdot
.65736 .43727 Mdot
.67852 .6773 Mdot
.60063 .64495 Mdot
.39065 .60436 Mdot
.43134 .42355 Mdot
.57709 .66261 Mdot
.40862 .2602 Mdot
.55738 .33769 Mdot
.17154 .45024 Mdot
.38831 .46839 Mdot
.6379 .59576 Mdot
.42934 .5499 Mdot
.64714 .4758 Mdot
.73368 .2885 Mdot
.36427 .65967 Mdot
.59841 .32487 Mdot
.40217 .66484 Mdot
.8263 .51603 Mdot
.55571 .35313 Mdot
.17218 .57812 Mdot
.75684 .58032 Mdot
.59248 .42592 Mdot
.35932 .44309 Mdot
.40341 .3128 Mdot
.68064 .50667 Mdot
.58916 .64952 Mdot
.74895 .56983 Mdot
.4441 .42639 Mdot
.77384 .39625 Mdot
.42333 .60769 Mdot
.67998 .44965 Mdot
.587 .624 Mdot
.58549 .66401 Mdot
.40943 .38155 Mdot
.63219 .30151 Mdot
.44374 .39877 Mdot
.71336 .57432 Mdot
.49211 .293 Mdot
.46994 .47343 Mdot
.4283 .44788 Mdot
.68493 .48526 Mdot
.37886 .44913 Mdot
.51053 .34962 Mdot
.73845 .68912 Mdot
.46364 .44721 Mdot
.69077 .68437 Mdot
.60865 .36112 Mdot
.39157 .63634 Mdot
.43967 .35923 Mdot
.66176 .62763 Mdot
.3817 .4577 Mdot
.87441 .47366 Mdot
.57182 .32898 Mdot
.68348 .63632 Mdot
.45893 .39476 Mdot
.39347 .38165 Mdot
.45535 .33731 Mdot
.33352 .67789 Mdot
.75519 .42676 Mdot
.39933 .40947 Mdot
.43819 .29094 Mdot
.57258 .6111 Mdot
.43828 .39187 Mdot
.41417 .44265 Mdot
.32171 .62967 Mdot
.59521 .65842 Mdot
.64759 .49023 Mdot
.64349 .52421 Mdot
.6997 .44536 Mdot
.58528 .36528 Mdot
.53651 .50842 Mdot
.46804 .22147 Mdot
.78704 .38723 Mdot
.58752 .31858 Mdot
.36769 .44439 Mdot
.50464 .35152 Mdot
.36452 .41289 Mdot
.54081 .34646 Mdot
.59782 .65535 Mdot
.35982 .64326 Mdot
.49398 .66414 Mdot
.69392 .48755 Mdot
.44089 .38332 Mdot
.55522 .36141 Mdot
.38737 .60636 Mdot
.52166 .34233 Mdot
.39523 .6295 Mdot
.57545 .62845 Mdot
.62279 .61577 Mdot
.54513 .34345 Mdot
.40379 .65954 Mdot
.60949 .69788 Mdot
.20539 .40301 Mdot
.34493 .40816 Mdot
.54657 .58758 Mdot
.42087 .64968 Mdot
.39672 .58707 Mdot
.42143 .61977 Mdot
.43709 .40991 Mdot
.53864 .56642 Mdot
.36455 .37474 Mdot
.60793 .62055 Mdot
.63503 .4813 Mdot
.58716 .27127 Mdot
.57821 .77927 Mdot
.59876 .27885 Mdot
.431 .46878 Mdot
.39797 .43615 Mdot
.42125 .44428 Mdot
.35406 .40171 Mdot
.70065 .58664 Mdot
.41813 .38858 Mdot
.5568 .62523 Mdot
.65704 .46905 Mdot
.44096 .45385 Mdot
.62622 .48522 Mdot
.42592 .71843 Mdot
.57778 .31568 Mdot
.52631 .50262 Mdot
.35165 .81807 Mdot
.38028 .60664 Mdot
.63786 .4994 Mdot
.66468 .45078 Mdot
.59288 .3333 Mdot
.58443 .64836 Mdot
.40039 .62703 Mdot
.54821 .25913 Mdot
.58611 .35048 Mdot
.40129 .42961 Mdot
.65328 .5413 Mdot
.76789 .40051 Mdot
.44947 .43714 Mdot
.38575 .39318 Mdot
.62474 .47305 Mdot
.63594 .41199 Mdot
.73857 .72925 Mdot
.41325 .22889 Mdot
.54706 .34629 Mdot
.56622 .31592 Mdot
.38559 .59109 Mdot
.42381 .36074 Mdot
.60641 .61708 Mdot
.35452 .25041 Mdot
.4621 .51971 Mdot
.35658 .26685 Mdot
.52108 .42448 Mdot
.42227 .3834 Mdot
.2455 .39593 Mdot
.40133 .44235 Mdot
.36826 .66707 Mdot
.40826 .6185 Mdot
.36484 .62455 Mdot
.59047 .64613 Mdot
.25794 .59181 Mdot
.55796 .63209 Mdot
.38254 .82903 Mdot
.39566 .59837 Mdot
.69372 .61045 Mdot
.68472 .48272 Mdot
.46437 .38828 Mdot
.58487 .34339 Mdot
.54864 .65045 Mdot
.47161 .45391 Mdot
.6749 .2522 Mdot
.671 .44655 Mdot
.39016 .60342 Mdot
.39157 .7193 Mdot
.45262 .82449 Mdot
.59502 .54062 Mdot
.38458 .34069 Mdot
.4396 .32584 Mdot
.56883 .35557 Mdot
.29626 .46584 Mdot
.54358 .35692 Mdot
.60215 .63019 Mdot
.43333 .43241 Mdot
.42617 .4271 Mdot
.45373 .40777 Mdot
.4225 .39182 Mdot
.61815 .63752 Mdot
.46066 .44119 Mdot
.83179 .4201 Mdot
.64467 .43551 Mdot
.22781 .62614 Mdot
.57948 .32858 Mdot
.59545 .66895 Mdot
.65559 .46789 Mdot
.6251 .4475 Mdot
.42413 .24024 Mdot
.42699 .45415 Mdot
.40483 .38964 Mdot
.75173 .38612 Mdot
.44277 .38915 Mdot
.39384 .34172 Mdot
.66739 .44944 Mdot
.59677 .27801 Mdot
.58523 .31329 Mdot
.55044 .3243 Mdot
.58833 .65777 Mdot
.40358 .66186 Mdot
.56416 .33956 Mdot
.66339 .50671 Mdot
.41874 .4765 Mdot
.38199 .38161 Mdot
.42244 .64589 Mdot
.79887 .6021 Mdot
.53543 .32817 Mdot
.40856 .71729 Mdot
.41436 .62673 Mdot
.3425 .64007 Mdot
.3974 .40349 Mdot
.31863 .41684 Mdot
.33292 .64256 Mdot
.5953 .32677 Mdot
.5995 .66702 Mdot
.57618 .48717 Mdot
.60126 .61803 Mdot
.40125 .61646 Mdot
.37707 .38051 Mdot
.40233 .61335 Mdot
.39827 .46664 Mdot
.25645 .76736 Mdot
.42125 .42386 Mdot
.79911 .39967 Mdot
.50567 .24805 Mdot
.66616 .46187 Mdot
.6197 .69777 Mdot
.68021 .45829 Mdot
.41342 .62197 Mdot
.3878 .3756 Mdot
.54988 .32061 Mdot
.22781 .66744 Mdot
.3397 .63678 Mdot
.65005 .45264 Mdot
.68746 .43944 Mdot
.6027 .64588 Mdot
.44422 .45208 Mdot
.40346 .40075 Mdot
.67257 .4745 Mdot
.45177 .49323 Mdot
.39189 .66022 Mdot
.4337 .4401 Mdot
.38847 .42551 Mdot
.66768 .46033 Mdot
.21661 .38608 Mdot
.35545 .69921 Mdot
.42578 .43354 Mdot
.72734 .62812 Mdot
.56558 .66157 Mdot
.35296 .42316 Mdot
.46919 .40327 Mdot
.57485 .34778 Mdot
.26316 .65492 Mdot
.72628 .69999 Mdot
.5602 .65501 Mdot
.68466 .45976 Mdot
.38344 .46235 Mdot
.68644 .47965 Mdot
.39088 .37856 Mdot
.30262 .68619 Mdot
.67317 .44206 Mdot
.38185 .38768 Mdot
.43898 .36305 Mdot
.40283 .60937 Mdot
.41279 .38511 Mdot
.35627 .54751 Mdot
.65851 .51783 Mdot
.39489 .3833 Mdot
.21272 .45396 Mdot
.57099 .64784 Mdot
.44572 .36625 Mdot
.57147 .31885 Mdot
.55494 .25771 Mdot
.52713 .74307 Mdot
.69671 .66308 Mdot
.5633 .32008 Mdot
.44399 .41063 Mdot
.68406 .43532 Mdot
.59513 .60218 Mdot
.7709 .36562 Mdot
.44871 .42987 Mdot
.59372 .61172 Mdot
.59138 .63182 Mdot
.56957 .32251 Mdot
.51717 .15173 Mdot
.4684 .41684 Mdot
.41094 .40506 Mdot
.35431 .57076 Mdot
.38736 .67779 Mdot
.4189 .41358 Mdot
.3618 .42365 Mdot
.55866 .61937 Mdot
.41343 .34108 Mdot
.31281 .56839 Mdot
.62776 .259 Mdot
.54758 .62995 Mdot
.56602 .4447 Mdot
.68556 .44532 Mdot
.57983 .3323 Mdot
.38525 .63614 Mdot
.53186 .3473 Mdot
.64845 .44247 Mdot
.36648 .43822 Mdot
.56642 .60373 Mdot
.33182 .49756 Mdot
.59402 .60048 Mdot
.69448 .65333 Mdot
.4067 .66671 Mdot
.49588 .69219 Mdot
.84982 .40385 Mdot
.49498 .75377 Mdot
.60547 .68809 Mdot
.56944 .35406 Mdot
.61633 .50927 Mdot
.39117 .42882 Mdot
.28417 .42956 Mdot
.43564 .42147 Mdot
.21665 .45538 Mdot
.63532 .4896 Mdot
.66121 .43065 Mdot
.42997 .43267 Mdot
.49552 .28657 Mdot
.60421 .60538 Mdot
.60847 .63876 Mdot
.39764 .38508 Mdot
.57747 .63703 Mdot
.40779 .41555 Mdot
.65025 .46436 Mdot
.64587 .21001 Mdot
.40741 .44309 Mdot
.3933 .36749 Mdot
.60463 .5653 Mdot
.15367 .49973 Mdot
.74862 .62494 Mdot
.25913 .37888 Mdot
.48632 .82951 Mdot
.57788 .63609 Mdot
.37687 .36436 Mdot
.5673 .43786 Mdot
.62424 .47775 Mdot
.60464 .69736 Mdot
.42559 .41484 Mdot
.42792 .41201 Mdot
.44221 .43609 Mdot
.3753 .41471 Mdot
.2838 .44072 Mdot
.38361 .53038 Mdot
.221 .51001 Mdot
.40087 .38852 Mdot
.3686 .30682 Mdot
.57159 .65868 Mdot
.42722 .61122 Mdot
.53132 .35245 Mdot
.42154 .3835 Mdot
.37784 .52819 Mdot
.57182 .66586 Mdot
.38495 .82981 Mdot
.5974 .65269 Mdot
.65705 .4914 Mdot
.61753 .62737 Mdot
.40392 .46105 Mdot
.37906 .63175 Mdot
.56779 .49361 Mdot
.71679 .53853 Mdot
.66207 .45005 Mdot
.41242 .46218 Mdot
.67346 .62773 Mdot
.66126 .44671 Mdot
.42758 .72017 Mdot
.37848 .63703 Mdot
.42591 .28746 Mdot
.40803 .61735 Mdot
.38129 .38722 Mdot
.37209 .39597 Mdot
.5294 .62948 Mdot
.6072 .60471 Mdot
.41041 .62096 Mdot
.55499 .1492 Mdot
.54477 .3592 Mdot
.36886 .62068 Mdot
.37124 .47936 Mdot
.48508 .56247 Mdot
.37241 .63606 Mdot
.55672 .28647 Mdot
.5947 .64716 Mdot
.38989 .59477 Mdot
.37423 .48247 Mdot
.79875 .5624 Mdot
.59723 .33726 Mdot
.68688 .42925 Mdot
.70219 .50345 Mdot
.65076 .51845 Mdot
.61067 .6596 Mdot
.67517 .45505 Mdot
.56828 .61545 Mdot
.61613 .71904 Mdot
.31166 .32015 Mdot
.62793 .63303 Mdot
.61672 .64806 Mdot
.6725 .45579 Mdot
.43441 .44554 Mdot
.6786 .52162 Mdot
.35572 .38543 Mdot
.43833 .48003 Mdot
.5655 .62479 Mdot
.40142 .60241 Mdot
.35547 .61574 Mdot
.38456 .30787 Mdot
.35948 .65914 Mdot
.64757 .46924 Mdot
.78418 .35702 Mdot
.69481 .70236 Mdot
.5784 .61047 Mdot
.61315 .64933 Mdot
.37741 .42633 Mdot
.67726 .48259 Mdot
.67738 .49899 Mdot
.60469 .63481 Mdot
.30283 .38091 Mdot
.40443 .36251 Mdot
.40839 .58735 Mdot
.39167 .59714 Mdot
.37396 .62687 Mdot
.41912 .61672 Mdot
.30612 .53851 Mdot
.59713 .64619 Mdot
.40588 .60489 Mdot
.38808 .38615 Mdot
.4266 .4121 Mdot
.57419 .49725 Mdot
.55616 .32141 Mdot
.40552 .47617 Mdot
.35364 .43847 Mdot
.39708 .40078 Mdot
.64441 .45216 Mdot
.41837 .49331 Mdot
.6809 .44526 Mdot
.69174 .4354 Mdot
.63324 .44848 Mdot
.67515 .6708 Mdot
.45101 .32662 Mdot
.52922 .83696 Mdot
.37427 .43836 Mdot
.45078 .61674 Mdot
.6792 .48833 Mdot
.71012 .27184 Mdot
.51928 .67498 Mdot
.44653 .43165 Mdot
.75101 .43058 Mdot
.67343 .47179 Mdot
.35543 .65494 Mdot
.42418 .41744 Mdot
.69911 .44011 Mdot
.58346 .3199 Mdot
.35334 .45833 Mdot
.64628 .52221 Mdot
.40732 .65378 Mdot
.55203 .36888 Mdot
.3997 .59658 Mdot
.62966 .46002 Mdot
.44119 .36404 Mdot
.71576 .79434 Mdot
.69829 .47329 Mdot
.17843 .55435 Mdot
.36433 .6908 Mdot
.43452 .4407 Mdot
.64281 .50827 Mdot
.38267 .67752 Mdot
.61021 .66162 Mdot
.48611 .5117 Mdot
.35893 .64961 Mdot
.66168 .43091 Mdot
.64692 .52096 Mdot
.66643 .44919 Mdot
.39525 .64213 Mdot
.37734 .37487 Mdot
.3923 .65048 Mdot
.61735 .63049 Mdot
.39166 .44031 Mdot
.4013 .81357 Mdot
.4446 .59928 Mdot
.41291 .62431 Mdot
.64255 .48527 Mdot
.58258 .36135 Mdot
.40829 .45128 Mdot
.1768 .51626 Mdot
.41108 .46622 Mdot
.58069 .60607 Mdot
.61462 .21888 Mdot
.32774 .49505 Mdot
.4584 .43065 Mdot
.37694 .4253 Mdot
.61045 .63035 Mdot
.42117 .45423 Mdot
.45632 .43276 Mdot
.66925 .66229 Mdot
.4018 .64128 Mdot
.3965 .42849 Mdot
.64125 .49329 Mdot
.65958 .72554 Mdot
.38397 .36584 Mdot
.69477 .3404 Mdot
.45353 .28792 Mdot
.57795 .19082 Mdot
.43751 .42401 Mdot
.38723 .24142 Mdot
.37672 .4066 Mdot
.4385 .40127 Mdot
.37757 .43408 Mdot
.27635 .36212 Mdot
.66395 .44092 Mdot
.65781 .45763 Mdot
.59729 .33415 Mdot
.45045 .28898 Mdot
.5731 .34597 Mdot
.59028 .6529 Mdot
.67371 .34059 Mdot
.67254 .44206 Mdot
.40871 .65296 Mdot
.44573 .40675 Mdot
.69727 .47894 Mdot
.40542 .39651 Mdot
.40113 .46216 Mdot
.69158 .47516 Mdot
.69651 .46812 Mdot
.68829 .64869 Mdot
.57453 .31691 Mdot
.36042 .62924 Mdot
.38689 .47393 Mdot
.5727 .35879 Mdot
.3851 .37316 Mdot
.49145 .22537 Mdot
.36144 .63126 Mdot
.39997 .64384 Mdot
.34991 .63374 Mdot
.367 .43918 Mdot
.40971 .45868 Mdot
.55853 .63044 Mdot
.40841 .65711 Mdot
.57281 .64747 Mdot
.5554 .49008 Mdot
.68252 .3228 Mdot
.42568 .41472 Mdot
.42305 .70665 Mdot
.58184 .34123 Mdot
.65287 .48278 Mdot
.72492 .3475 Mdot
.5981 .33952 Mdot
.40756 .46582 Mdot
.68726 .48166 Mdot
.54155 .34107 Mdot
.38513 .33274 Mdot
.59963 .82025 Mdot
.57131 .3653 Mdot
.39041 .38623 Mdot
.45999 .35359 Mdot
.26825 .32404 Mdot
.57998 .36624 Mdot
.57434 .60291 Mdot
.36798 .44249 Mdot
.42029 .55252 Mdot
.53498 .32987 Mdot
.62939 .72804 Mdot
.66461 .46942 Mdot
.7667 .62628 Mdot
.45895 .47171 Mdot
.28642 .39266 Mdot
.53591 .34899 Mdot
.39861 .62463 Mdot
.43074 .65252 Mdot
.38918 .40565 Mdot
.57763 .36757 Mdot
.54851 .61976 Mdot
.6616 .47499 Mdot
.66855 .68138 Mdot
.39334 .64429 Mdot
.46528 .68842 Mdot
.63753 .47641 Mdot
.43119 .70694 Mdot
.6289 .24415 Mdot
.4555 .48597 Mdot
.26385 .36199 Mdot
.76426 .48744 Mdot
.36559 .4434 Mdot
.55055 .36217 Mdot
.56369 .65755 Mdot
.5793 .59939 Mdot
.5749 .62329 Mdot
.63279 .69616 Mdot
.58237 .5178 Mdot
.62826 .48256 Mdot
.7419 .50059 Mdot
.57606 .33116 Mdot
.36826 .29224 Mdot
.4035 .37328 Mdot
.39977 .43747 Mdot
.43803 .46091 Mdot
.43645 .3883 Mdot
.38142 .40962 Mdot
.57998 .64583 Mdot
.63908 .69499 Mdot
.57048 .45899 Mdot
.36549 .63644 Mdot
.60591 .29084 Mdot
.68425 .48341 Mdot
.62758 .45431 Mdot
.54885 .33186 Mdot
.38504 .7265 Mdot
.63304 .4996 Mdot
.65602 .49797 Mdot
.41561 .46895 Mdot
.39477 .65488 Mdot
.33366 .39015 Mdot
.37072 .40242 Mdot
.65261 .47559 Mdot
.55399 .40697 Mdot
.33103 .55503 Mdot
.35017 .47472 Mdot
.55138 .37329 Mdot
.53247 .56541 Mdot
.57654 .36665 Mdot
.40618 .37015 Mdot
.69293 .25904 Mdot
.65042 .44169 Mdot
.6678 .48999 Mdot
.54719 .35729 Mdot
.38135 .70785 Mdot
.38503 .64289 Mdot
.62476 .44755 Mdot
.56829 .60921 Mdot
.36566 .40505 Mdot
.6978 .31761 Mdot
.39839 .7046 Mdot
.64327 .31161 Mdot
.57674 .61687 Mdot
.67434 .50034 Mdot
.44846 .448 Mdot
.38932 .38723 Mdot
.57448 .35433 Mdot
.45413 .79565 Mdot
.35798 .4601 Mdot
.25792 .70414 Mdot
.81382 .46249 Mdot
.80163 .58031 Mdot
.3993 .40303 Mdot
.40071 .64015 Mdot
.63953 .51916 Mdot
.57291 .35719 Mdot
.43667 .47195 Mdot
.5782 .82749 Mdot
.42791 .6342 Mdot
.59906 .62829 Mdot
.55744 .45182 Mdot
.5971 .53461 Mdot
.3944 .47011 Mdot
.4343 .42168 Mdot
.43387 .40368 Mdot
.67731 .77377 Mdot
.64326 .45893 Mdot
.38567 .67159 Mdot
.5586 .33127 Mdot
.36145 .66162 Mdot
.66222 .45789 Mdot
.47694 .69163 Mdot
.42823 .45744 Mdot
.42721 .63724 Mdot
.39587 .62583 Mdot
.60147 .64702 Mdot
.6171 .65169 Mdot
.55554 .4742 Mdot
.41989 .42362 Mdot
.66568 .52149 Mdot
.39976 .60564 Mdot
.65562 .53951 Mdot
.55776 .35404 Mdot
.56421 .65117 Mdot
.40358 .38837 Mdot
.65549 .4425 Mdot
.4604 .44274 Mdot
.37168 .64786 Mdot
.65729 .49838 Mdot
.68531 .64759 Mdot
.56726 .3164 Mdot
.42198 .4004 Mdot
.53493 .36657 Mdot
.68533 .46074 Mdot
.38866 .42727 Mdot
.35911 .72022 Mdot
.5888 .36942 Mdot
.69307 .55626 Mdot
.6295 .47974 Mdot
.68686 .65633 Mdot
.35366 .6242 Mdot
.59583 .72545 Mdot
.66376 .48982 Mdot
.36356 .7257 Mdot
.51451 .79105 Mdot
.39648 .4799 Mdot
.38413 .61733 Mdot
.61412 .4857 Mdot
.319 .79063 Mdot
.21755 .39703 Mdot
.41973 .44591 Mdot
.63504 .49348 Mdot
.55176 .35835 Mdot
.57714 .611 Mdot
.69516 .33876 Mdot
.50939 .35386 Mdot
.69319 .4497 Mdot
.37557 .4322 Mdot
.40817 .62771 Mdot
.59318 .6414 Mdot
.54862 .74343 Mdot
.65402 .50364 Mdot
.63445 .47614 Mdot
.45095 .44433 Mdot
.571 .34069 Mdot
.19463 .45953 Mdot
.65088 .46072 Mdot
.75681 .39808 Mdot
.6249 .52833 Mdot
.55677 .36223 Mdot
.37963 .39839 Mdot
.40817 .31019 Mdot
.35234 .40806 Mdot
.18526 .58739 Mdot
.68227 .46323 Mdot
.36466 .64318 Mdot
.43949 .41691 Mdot
.61828 .25141 Mdot
.65519 .47802 Mdot
.54642 .56377 Mdot
.66404 .39931 Mdot
.59628 .64617 Mdot
.73003 .35127 Mdot
.41655 .40668 Mdot
.60032 .60326 Mdot
.58129 .34178 Mdot
.4212 .4322 Mdot
.40659 .45775 Mdot
.37005 .6737 Mdot
.60337 .62899 Mdot
.54304 .80184 Mdot
.59065 .66511 Mdot
.55657 .64247 Mdot
.34771 .65054 Mdot
.39618 .41662 Mdot
.6545 .49157 Mdot
.67451 .47369 Mdot
.43346 .47883 Mdot
.71765 .26578 Mdot
.38581 .64506 Mdot
.61745 .31029 Mdot
.69547 .76146 Mdot
.4664 .47482 Mdot
.72129 .3422 Mdot
.44981 .79294 Mdot
.55083 .61536 Mdot
.39926 .38629 Mdot
.41169 .64153 Mdot
.62673 .4425 Mdot
.63679 .48081 Mdot
.37435 .37866 Mdot
.58909 .63597 Mdot
.58851 .32305 Mdot
.68258 .50066 Mdot
.63269 .30048 Mdot
.4305 .39558 Mdot
.76437 .44075 Mdot
.65017 .51307 Mdot
.24544 .71289 Mdot
.62217 .49754 Mdot
.3794 .61845 Mdot
.3996 .46047 Mdot
.35682 .65179 Mdot
.55424 .33663 Mdot
.55733 .46038 Mdot
.59107 .63492 Mdot
.49742 .42822 Mdot
.85865 .50377 Mdot
.67164 .4495 Mdot
.38148 .66852 Mdot
.45894 .42977 Mdot
.50044 .36421 Mdot
.41246 .40927 Mdot
.47069 .36634 Mdot
.60183 .36905 Mdot
.56494 .6321 Mdot
.57958 .60432 Mdot
.39064 .43267 Mdot
.58955 .34098 Mdot
.67221 .50093 Mdot
.66133 .47806 Mdot
.12596 .49252 Mdot
.68863 .54036 Mdot
.52158 .27667 Mdot
.4268 .40825 Mdot
.66877 .43259 Mdot
.60575 .76383 Mdot
.58947 .6092 Mdot
.41366 .37445 Mdot
.68767 .45417 Mdot
.79977 .51362 Mdot
.55753 .24597 Mdot
.38158 .40579 Mdot
.47251 .42774 Mdot
.56916 .60753 Mdot
.37823 .27246 Mdot
.63157 .45585 Mdot
.34892 .39614 Mdot
.61177 .59972 Mdot
.59174 .22209 Mdot
.76608 .6589 Mdot
.36069 .62855 Mdot
.64266 .40654 Mdot
.58058 .64645 Mdot
.42324 .48812 Mdot
.57775 .32517 Mdot
.6692 .51544 Mdot
.6481 .45066 Mdot
.38113 .44405 Mdot
.4607 .43925 Mdot
.48979 .32785 Mdot
.37703 .66566 Mdot
.57514 .65929 Mdot
.43757 .43064 Mdot
.48127 .65624 Mdot
.45212 .40448 Mdot
.56054 .6377 Mdot
.67617 .83674 Mdot
.38479 .47507 Mdot
.41044 .40815 Mdot
.19383 .45538 Mdot
.35812 .64787 Mdot
.35982 .66206 Mdot
.80231 .42795 Mdot
.42645 .40749 Mdot
.74811 .37302 Mdot
.35898 .62944 Mdot
.38213 .64641 Mdot
.65508 .59597 Mdot
.4067 .44713 Mdot
.32252 .27977 Mdot
.59566 .60393 Mdot
.55485 .62334 Mdot
.39154 .64927 Mdot
.3746 .47281 Mdot
.55844 .60576 Mdot
.29078 .48038 Mdot
.67846 .48162 Mdot
.67778 .24621 Mdot
.37207 .6535 Mdot
.53301 .48014 Mdot
.58108 .61173 Mdot
.37845 .8276 Mdot
.74244 .46724 Mdot
.43571 .44203 Mdot
.42509 .40017 Mdot
.58231 .33736 Mdot
.38995 .47644 Mdot
.6593 .4304 Mdot
.57724 .63733 Mdot
.19258 .52926 Mdot
.36564 .62322 Mdot
.4152 .42013 Mdot
.41754 .71818 Mdot
.53944 .76233 Mdot
.76381 .58632 Mdot
.39144 .63551 Mdot
.38551 .61331 Mdot
.63111 .46032 Mdot
.63849 .49847 Mdot
.39119 .41147 Mdot
.60837 .62681 Mdot
.41183 .65007 Mdot
.56138 .63095 Mdot
.6492 .44276 Mdot
.65222 .49309 Mdot
.671 .44002 Mdot
.34121 .40425 Mdot
.65101 .49868 Mdot
.62461 .28787 Mdot
.46483 .69631 Mdot
.36524 .59816 Mdot
.82189 .59375 Mdot
.54928 .74172 Mdot
.43706 .53372 Mdot
.54398 .32416 Mdot
.68577 .46113 Mdot
.61449 .6422 Mdot
.3794 .42469 Mdot
.40502 .39271 Mdot
.68936 .42434 Mdot
.61426 .62337 Mdot
.55 .34238 Mdot
.61155 .61126 Mdot
.57093 .32192 Mdot
.7528 .44003 Mdot
.4419 .45468 Mdot
.37888 .3848 Mdot
.57617 .64169 Mdot
.65518 .49957 Mdot
.65794 .46521 Mdot
.56764 .36719 Mdot
.49542 .48483 Mdot
.6637 .44578 Mdot
.37195 .65215 Mdot
.2952 .52842 Mdot
.64336 .52043 Mdot
.42213 .4158 Mdot
.46479 .21835 Mdot
.28963 .43086 Mdot
.35464 .39699 Mdot
.65813 .6237 Mdot
.36771 .21768 Mdot
.44471 .41714 Mdot
.3812 .20254 Mdot
.68629 .65821 Mdot
.35966 .65323 Mdot
.63283 .48443 Mdot
.62992 .43934 Mdot
.43631 .35144 Mdot
.52786 .32559 Mdot
.43059 .47746 Mdot
.35609 .64141 Mdot
.42047 .6658 Mdot
.81009 .52338 Mdot
.17851 .55831 Mdot
.54069 .35154 Mdot
.54728 .33013 Mdot
.6645 .48756 Mdot
.19991 .38072 Mdot
.35079 .47144 Mdot
.54742 .34466 Mdot
.31732 .31295 Mdot
.373 .43008 Mdot
.48545 .26386 Mdot
.75055 .40969 Mdot
.39709 .64295 Mdot
.40303 .3119 Mdot
.65766 .48693 Mdot
.3701 .66297 Mdot
.49021 .65427 Mdot
.39835 .47398 Mdot
.36254 .62975 Mdot
.56041 .62767 Mdot
.76142 .51988 Mdot
.36318 .61433 Mdot
.47664 .21904 Mdot
.60579 .63411 Mdot
.63137 .5471 Mdot
.39595 .29563 Mdot
.79569 .28133 Mdot
.58092 .64321 Mdot
.69408 .46394 Mdot
.67367 .47374 Mdot
.6622 .47914 Mdot
.36737 .6635 Mdot
.68163 .49344 Mdot
.38209 .66647 Mdot
.24658 .34074 Mdot
.49273 .48688 Mdot
.54554 .34569 Mdot
.66103 .64644 Mdot
.39412 .61865 Mdot
.7669 .32936 Mdot
.85311 .43501 Mdot
.40287 .385 Mdot
.60315 .65931 Mdot
.54217 .34767 Mdot
.21453 .66325 Mdot
.57746 .34505 Mdot
.60121 .41138 Mdot
.63984 .22187 Mdot
.40967 .42069 Mdot
.29112 .61246 Mdot
.55242 .31995 Mdot
.40155 .63011 Mdot
.39206 .43081 Mdot
.57774 .69214 Mdot
.57654 .33947 Mdot
.58803 .32456 Mdot
.38841 .41706 Mdot
.39077 .6034 Mdot
.65065 .48784 Mdot
.61648 .61331 Mdot
.60288 .33686 Mdot
.42726 .67204 Mdot
.36854 .45395 Mdot
.37761 .45811 Mdot
.58723 .54593 Mdot
.52384 .31542 Mdot
.57843 .63635 Mdot
.29403 .31216 Mdot
.63753 .4956 Mdot
.60447 .457 Mdot
.79765 .44407 Mdot
.66372 .63809 Mdot
.67988 .461 Mdot
.68284 .45841 Mdot
.38413 .40886 Mdot
.52386 .30959 Mdot
.59587 .20714 Mdot
.632 .67572 Mdot
.6398 .51736 Mdot
.65997 .47595 Mdot
.42789 .6536 Mdot
.81426 .52023 Mdot
.43872 .46953 Mdot
.55702 .65013 Mdot
.65446 .44414 Mdot
.30386 .69027 Mdot
.56965 .33719 Mdot
.73621 .29912 Mdot
.4431 .4518 Mdot
.43647 .43457 Mdot
.5828 .62459 Mdot
.5575 .63208 Mdot
.52717 .64717 Mdot
.81981 .4813 Mdot
.32715 .25776 Mdot
.59266 .74 Mdot
.30303 .67176 Mdot
.42893 .62401 Mdot
.41261 .62311 Mdot
.65876 .68033 Mdot
.58215 .66687 Mdot
.44218 .41589 Mdot
.41102 .64983 Mdot
.75794 .56795 Mdot
.43027 .58291 Mdot
.50012 .27327 Mdot
.66213 .29294 Mdot
.40252 .46606 Mdot
.4022 .65001 Mdot
.36156 .65126 Mdot
.41792 .63455 Mdot
.68516 .65876 Mdot
.39993 .40928 Mdot
.42733 .45081 Mdot
.45014 .41481 Mdot
.32565 .46442 Mdot
.42177 .38906 Mdot
.64484 .6657 Mdot
.55755 .53202 Mdot
.22464 .60576 Mdot
.3478 .40966 Mdot
.55234 .61711 Mdot
.38377 .46698 Mdot
.59062 .33847 Mdot
.37727 .43117 Mdot
.50675 .2719 Mdot
.59452 .61692 Mdot
.36379 .69662 Mdot
.59003 .73588 Mdot
.43391 .45667 Mdot
.58612 .31634 Mdot
.41654 .53901 Mdot
.48392 .80994 Mdot
.53377 .31503 Mdot
.37272 .6525 Mdot
.68182 .47486 Mdot
.61495 .63712 Mdot
.65874 .49451 Mdot
.34237 .41572 Mdot
.64824 .6097 Mdot
.45353 .76193 Mdot
.5441 .46536 Mdot
.42709 .38457 Mdot
.42533 .49592 Mdot
.3765 .64975 Mdot
.68755 .48103 Mdot
.38974 .57755 Mdot
.43675 .41255 Mdot
.5589 .33403 Mdot
.57768 .33568 Mdot
.52498 .66905 Mdot
.34194 .76102 Mdot
.58892 .71903 Mdot
.58065 .62654 Mdot
.64948 .45911 Mdot
.53755 .35287 Mdot
.44857 .65341 Mdot
.59619 .67314 Mdot
.61085 .63175 Mdot
.60187 .63451 Mdot
.36493 .42596 Mdot
.68095 .44512 Mdot
.21889 .5902 Mdot
.66471 .43214 Mdot
.41795 .45811 Mdot
.64122 .46077 Mdot
.68001 .44894 Mdot
.58221 .33135 Mdot
.58992 .65784 Mdot
.6406 .44887 Mdot
.38211 .38634 Mdot
.3703 .61225 Mdot
.51793 .47282 Mdot
.52221 .24352 Mdot
.20756 .62096 Mdot
.22588 .6354 Mdot
.3771 .60061 Mdot
.34562 .79003 Mdot
.55677 .65568 Mdot
.30362 .37844 Mdot
.71255 .63273 Mdot
.37078 .38528 Mdot
.78122 .33354 Mdot
.62793 .48243 Mdot
.69258 .47209 Mdot
.37721 .40055 Mdot
.64512 .41037 Mdot
.41379 .41641 Mdot
.63753 .46084 Mdot
.60603 .29379 Mdot
.45148 .36741 Mdot
.66239 .50389 Mdot
.35026 .38849 Mdot
.4033 .44881 Mdot
.39823 .64371 Mdot
.64497 .5115 Mdot
.41791 .37507 Mdot
.15585 .58623 Mdot
.56012 .64209 Mdot
.67302 .63886 Mdot
.46252 .20791 Mdot
.58041 .64758 Mdot
.36921 .62262 Mdot
.43737 .47984 Mdot
.57959 .34866 Mdot
.39969 .61838 Mdot
.57188 .24399 Mdot
.55412 .32029 Mdot
.77917 .33909 Mdot
.37731 .65531 Mdot
.64284 .51859 Mdot
.58272 .32611 Mdot
.36996 .36936 Mdot
.6772 .50851 Mdot
.46355 .52431 Mdot
.68264 .46556 Mdot
.4045 .40034 Mdot
.66517 .68624 Mdot
.56685 .65628 Mdot
.41867 .44376 Mdot
.68446 .49679 Mdot
.67277 .67319 Mdot
.36702 .42928 Mdot
.37902 .41873 Mdot
.80294 .59263 Mdot
.7445 .33007 Mdot
.56491 .35516 Mdot
.39059 .67466 Mdot
.38764 .38614 Mdot
.57857 .31897 Mdot
.66425 .38277 Mdot
.37132 .45296 Mdot
.42597 .63414 Mdot
.34026 .47 Mdot
.66142 .51386 Mdot
.5756 .65141 Mdot
.54825 .48306 Mdot
.58235 .31923 Mdot
.47305 .13521 Mdot
.66418 .4355 Mdot
.41122 .3707 Mdot
.43044 .38421 Mdot
.75557 .61564 Mdot
.3658 .65763 Mdot
.33395 .25724 Mdot
.4222 .40029 Mdot
.34438 .48551 Mdot
.41842 .43314 Mdot
.59844 .42926 Mdot
.38449 .64424 Mdot
.40981 .40425 Mdot
.4464 .69039 Mdot
.39713 .36501 Mdot
.58473 .31815 Mdot
.20521 .42054 Mdot
.3639 .44137 Mdot
.8203 .68748 Mdot
.74194 .37111 Mdot
.65987 .50376 Mdot
.65804 .69116 Mdot
.19821 .33133 Mdot
.61144 .72018 Mdot
.3851 .66739 Mdot
.44379 .78476 Mdot
.65363 .49174 Mdot
.62863 .73501 Mdot
.33927 .79275 Mdot
.40092 .44845 Mdot
.39494 .47017 Mdot
.60069 .41155 Mdot
.6562 .42891 Mdot
.65765 .52534 Mdot
.34555 .41905 Mdot
.33738 .45005 Mdot
.64462 .49196 Mdot
.393 .38177 Mdot
.34917 .37809 Mdot
.61951 .62282 Mdot
.37743 .60228 Mdot
.57092 .61711 Mdot
.6 .65193 Mdot
.25813 .42947 Mdot
.81487 .48903 Mdot
.56199 .64273 Mdot
.5558 .65279 Mdot
.49253 .2624 Mdot
.4726 .32313 Mdot
.53651 .32888 Mdot
.29516 .73441 Mdot
.66433 .47694 Mdot
.40017 .41229 Mdot
.37144 .60116 Mdot
.28824 .38053 Mdot
.72061 .3725 Mdot
.60894 .20866 Mdot
.43947 .41325 Mdot
.65712 .48198 Mdot
.68641 .66112 Mdot
.33771 .38359 Mdot
.60161 .48983 Mdot
.43909 .43563 Mdot
.69536 .48316 Mdot
.28788 .5623 Mdot
.39269 .72185 Mdot
.63783 .53115 Mdot
.42392 .59409 Mdot
.4325 .42844 Mdot
.36975 .65375 Mdot
.57329 .61898 Mdot
.58756 .3382 Mdot
.56369 .35421 Mdot
.38702 .42301 Mdot
.40754 .50766 Mdot
.74866 .43423 Mdot
.40777 .45191 Mdot
.38254 .43948 Mdot
.68643 .65836 Mdot
.38446 .43914 Mdot
.43578 .38911 Mdot
.44555 .40021 Mdot
.43839 .37238 Mdot
.55498 .63674 Mdot
.41872 .71661 Mdot
.34057 .4274 Mdot
.34292 .38012 Mdot
.59965 .59663 Mdot
.48055 .79801 Mdot
.59889 .65602 Mdot
.40601 .81579 Mdot
.57782 .60758 Mdot
.55345 .35066 Mdot
.7041 .67255 Mdot
.42053 .50159 Mdot
.411 .60816 Mdot
.59615 .67043 Mdot
.56266 .32594 Mdot
.57478 .63014 Mdot
.63784 .47198 Mdot
.72561 .72238 Mdot
.44104 .63757 Mdot
.36736 .24171 Mdot
.53259 .67719 Mdot
.70405 .54058 Mdot
.64759 .43947 Mdot
.38759 .64704 Mdot
.33007 .56348 Mdot
.44522 .39632 Mdot
.5772 .31956 Mdot
.38782 .41272 Mdot
.55873 .64956 Mdot
.66014 .48503 Mdot
.20468 .41409 Mdot
.57635 .35273 Mdot
.821 .57491 Mdot
.66382 .46712 Mdot
.4544 .41706 Mdot
.55613 .64766 Mdot
.84118 .56146 Mdot
.56656 .62505 Mdot
.46787 .49484 Mdot
.41608 .59671 Mdot
.25837 .3711 Mdot
.38807 .61847 Mdot
.62575 .49265 Mdot
.72852 .75133 Mdot
.26606 .70065 Mdot
.3846 .60496 Mdot
.72766 .5106 Mdot
.38765 .46475 Mdot
.37915 .46059 Mdot
.37456 .71496 Mdot
.4029 .6679 Mdot
.40725 .38457 Mdot
.68244 .64489 Mdot
.46934 .71562 Mdot
.73997 .35083 Mdot
.68623 .47175 Mdot
.41654 .4115 Mdot
.60419 .59664 Mdot
.61145 .61236 Mdot
.66851 .43434 Mdot
.60028 .65662 Mdot
.42629 .45016 Mdot
.39205 .61884 Mdot
.68561 .50541 Mdot
.5614 .34725 Mdot
.15711 .54482 Mdot
.5351 .35299 Mdot
.67888 .46016 Mdot
.44153 .36467 Mdot
.65227 .49355 Mdot
.24573 .24598 Mdot
.43042 .44501 Mdot
.35878 .63508 Mdot
.37186 .41513 Mdot
.42916 .43081 Mdot
.39134 .46976 Mdot
.64026 .4829 Mdot
.36705 .22838 Mdot
.38817 .38296 Mdot
.59229 .63569 Mdot
.24806 .64017 Mdot
.3875 .46973 Mdot
.60332 .29942 Mdot
.47548 .29819 Mdot
.7452 .49591 Mdot
.38474 .59328 Mdot
.67769 .4935 Mdot
.3701 .61621 Mdot
.43235 .59145 Mdot
.36889 .62316 Mdot
.25686 .62584 Mdot
.31982 .56596 Mdot
.41206 .2015 Mdot
.21064 .46377 Mdot
.33767 .33813 Mdot
.39622 .67209 Mdot
.58775 .39331 Mdot
.41505 .62916 Mdot
.36613 .65485 Mdot
.45885 .91861 Mdot
.40978 .61045 Mdot
.42245 .4099 Mdot
.41808 .47117 Mdot
.51262 .75479 Mdot
.46082 .25559 Mdot
.3864 .43402 Mdot
.37867 .39276 Mdot
.5861 .33671 Mdot
.39768 .51517 Mdot
.64912 .6113 Mdot
.78629 .36752 Mdot
.56207 .76437 Mdot
.38715 .41498 Mdot
.38364 .38712 Mdot
.33235 .41686 Mdot
.84257 .6127 Mdot
.27029 .42895 Mdot
.40759 .66841 Mdot
.41142 .49152 Mdot
.19825 .623 Mdot
.43712 .44945 Mdot
.36164 .42437 Mdot
.39848 .46662 Mdot
.65398 .49137 Mdot
.42762 .62648 Mdot
.39949 .48925 Mdot
.7757 .42888 Mdot
.42877 .45954 Mdot
.6642 .6428 Mdot
.25758 .28346 Mdot
.41657 .4057 Mdot
.41297 .60365 Mdot
.37822 .44937 Mdot
.38025 .65813 Mdot
.40514 .63608 Mdot
.43011 .36366 Mdot
.28754 .66418 Mdot
.42271 .60981 Mdot
.41663 .45893 Mdot
.64631 .48324 Mdot
.28481 .73626 Mdot
.40632 .39876 Mdot
.57343 .35806 Mdot
.42478 .40142 Mdot
.59092 .31853 Mdot
.38881 .44531 Mdot
.67163 .43553 Mdot
.31671 .48285 Mdot
.66798 .48805 Mdot
.2807 .28503 Mdot
.68489 .44587 Mdot
.80705 .58629 Mdot
.41925 .65525 Mdot
.66676 .6778 Mdot
.54677 .16473 Mdot
.66708 .63294 Mdot
.52001 .58062 Mdot
.5118 .5636 Mdot
.60868 .62789 Mdot
.35429 .64691 Mdot
.34828 .28744 Mdot
.76058 .58245 Mdot
.74194 .62295 Mdot
.67256 .44486 Mdot
.54823 .15101 Mdot
.64343 .21384 Mdot
.36812 .39856 Mdot
.27914 .61978 Mdot
.22728 .52302 Mdot
.36743 .4465 Mdot
.43672 .48135 Mdot
.69334 .43119 Mdot
.42436 .38041 Mdot
.47637 .65832 Mdot
.67263 .45735 Mdot
.56496 .32395 Mdot
.36542 .64786 Mdot
.59596 .33328 Mdot
.755 .59586 Mdot
.50852 .56887 Mdot
.64139 .45235 Mdot
.41372 .36591 Mdot
.37178 .40746 Mdot
.39467 .65066 Mdot
.3407 .61174 Mdot
.40309 .61001 Mdot
.54402 .35351 Mdot
.67109 .4607 Mdot
.27956 .41332 Mdot
.3868 .39091 Mdot
.39327 .62647 Mdot
.5109 .62649 Mdot
.39134 .38665 Mdot
.57245 .63824 Mdot
.4117 .46517 Mdot
.37604 .60677 Mdot
.38479 .43939 Mdot
.39163 .61689 Mdot
.68059 .48026 Mdot
.44222 .4466 Mdot
.3794 .40179 Mdot
.83174 .57489 Mdot
.55122 .34353 Mdot
.40942 .66388 Mdot
.65325 .40567 Mdot
.45054 .39884 Mdot
.69422 .57123 Mdot
.4345 .42475 Mdot
.40748 .56836 Mdot
.40232 .36901 Mdot
.68153 .66558 Mdot
.44282 .46366 Mdot
.40667 .39958 Mdot
.48755 .60799 Mdot
.2332 .55822 Mdot
.3363 .6157 Mdot
.55208 .63558 Mdot
.42001 .62073 Mdot
.68994 .31557 Mdot
.63448 .50617 Mdot
.68297 .49302 Mdot
.40483 .25341 Mdot
.45791 .38745 Mdot
.40839 .41927 Mdot
.6227 .61487 Mdot
.55518 .32394 Mdot
.39298 .63373 Mdot
.5696 .32248 Mdot
.79036 .43331 Mdot
.53933 .33994 Mdot
.63632 .43404 Mdot
.75563 .43483 Mdot
.29044 .4588 Mdot
.58579 .33622 Mdot
.39251 .60288 Mdot
.65302 .29252 Mdot
.36825 .38302 Mdot
.5199 .36397 Mdot
.55999 .33477 Mdot
.53762 .14146 Mdot
.43174 .38713 Mdot
.52794 .57587 Mdot
.56614 .6454 Mdot
.57937 .32634 Mdot
.60321 .6209 Mdot
.38512 .4301 Mdot
.6865 .55918 Mdot
.39358 .66834 Mdot
.56943 .59719 Mdot
.3618 .44968 Mdot
.54256 .34487 Mdot
.65451 .4455 Mdot
.54459 .66139 Mdot
.55585 .61061 Mdot
.44324 .79775 Mdot
.22858 .38265 Mdot
.67116 .46251 Mdot
.66061 .26007 Mdot
.59096 .60304 Mdot
.36219 .43245 Mdot
.36711 .50842 Mdot
.43575 .44276 Mdot
.62649 .698 Mdot
.68089 .49028 Mdot
.46617 .73675 Mdot
.37032 .41072 Mdot
.44424 .40875 Mdot
.334 .63941 Mdot
.67218 .47934 Mdot
.37661 .63241 Mdot
.4182 .62059 Mdot
.67994 .47981 Mdot
.38031 .61963 Mdot
.55806 .31755 Mdot
.48144 .71146 Mdot
.58193 .60093 Mdot
.59351 .63161 Mdot
.66022 .47726 Mdot
.65395 .50227 Mdot
.65608 .49728 Mdot
.41247 .46496 Mdot
.38895 .63932 Mdot
.39549 .4584 Mdot
.39186 .46949 Mdot
.32453 .66661 Mdot
.38511 .59632 Mdot
.38772 .46132 Mdot
.61419 .49047 Mdot
.52187 .36224 Mdot
.64434 .48017 Mdot
.56438 .64603 Mdot
.62574 .75395 Mdot
.54883 .60808 Mdot
.41783 .41433 Mdot
.7978 .51177 Mdot
.39246 .60569 Mdot
.58055 .34122 Mdot
.55657 .31259 Mdot
.57474 .34966 Mdot
.6175 .59566 Mdot
.41418 .65321 Mdot
.78554 .36489 Mdot
.41416 .41319 Mdot
.58889 .54693 Mdot
.32595 .29592 Mdot
.77551 .46076 Mdot
.5637 .64688 Mdot
.38624 .3874 Mdot
.54313 .47957 Mdot
.33757 .54507 Mdot
.43535 .43644 Mdot
.36534 .37919 Mdot
.68753 .62259 Mdot
.32585 .43581 Mdot
.41988 .6016 Mdot
.82357 .4701 Mdot
.41731 .47584 Mdot
.34856 .70886 Mdot
.14567 .46186 Mdot
.42187 .42149 Mdot
.43687 .40524 Mdot
.39566 .39623 Mdot
.37282 .42647 Mdot
.41264 .60131 Mdot
.40793 .27093 Mdot
.56251 .6602 Mdot
.58207 .52728 Mdot
.57648 .60094 Mdot
.69089 .49143 Mdot
.44077 .7069 Mdot
.35154 .63802 Mdot
.58243 .33814 Mdot
.33985 .73066 Mdot
.81103 .4218 Mdot
.63037 .46293 Mdot
.28887 .4932 Mdot
.55621 .3409 Mdot
.35859 .42369 Mdot
.59295 .31532 Mdot
.68379 .44704 Mdot
.59661 .64037 Mdot
.46919 .40578 Mdot
.40944 .61606 Mdot
.36038 .61826 Mdot
.40481 .38494 Mdot
.22409 .65895 Mdot
.57267 .64276 Mdot
.57424 .67735 Mdot
.3685 .43794 Mdot
.35549 .38665 Mdot
.37329 .63266 Mdot
.65221 .46718 Mdot
.60691 .26077 Mdot
.5498 .33258 Mdot
.45437 .3969 Mdot
.37391 .43001 Mdot
.81897 .47588 Mdot
.58862 .65387 Mdot
.63217 .44695 Mdot
.36483 .42142 Mdot
.6348 .70894 Mdot
.36535 .42228 Mdot
.329 .3927 Mdot
.64816 .48277 Mdot
.34682 .45573 Mdot
.38136 .38419 Mdot
.49303 .41556 Mdot
.59965 .60968 Mdot
.3606 .63515 Mdot
.36717 .59472 Mdot
.57136 .43187 Mdot
.57224 .63538 Mdot
.3832 .45676 Mdot
.58409 .65306 Mdot
.37849 .46259 Mdot
.40752 .38273 Mdot
.56075 .63823 Mdot
.37678 .63164 Mdot
.46619 .78064 Mdot
.42745 .71364 Mdot
.37157 .42341 Mdot
.42938 .47013 Mdot
.43058 .2584 Mdot
.46555 .18332 Mdot
.43756 .4174 Mdot
.36894 .61087 Mdot
.38174 .39401 Mdot
.59866 .61583 Mdot
.54249 .33039 Mdot
.37215 .61029 Mdot
.65686 .46044 Mdot
.63616 .44764 Mdot
.591 .73445 Mdot
.68275 .45353 Mdot
.36118 .39424 Mdot
.43889 .59965 Mdot
.34327 .64155 Mdot
.14496 .49771 Mdot
.67829 .47866 Mdot
.55874 .31434 Mdot
.38122 .42115 Mdot
.79809 .56716 Mdot
.62388 .62088 Mdot
.84871 .6565 Mdot
.78157 .34758 Mdot
.5379 .3571 Mdot
.58618 .1908 Mdot
.68402 .50417 Mdot
.40742 .37882 Mdot
.58807 .33882 Mdot
.63084 .47184 Mdot
.36553 .39309 Mdot
.47346 .41486 Mdot
.34269 .24751 Mdot
.56268 .44729 Mdot
.58179 .65436 Mdot
.65747 .51053 Mdot
.58778 .30538 Mdot
.64194 .43177 Mdot
.35838 .61896 Mdot
.40609 .40307 Mdot
.46695 .47222 Mdot
.65356 .46287 Mdot
.65289 .42935 Mdot
.40477 .4646 Mdot
.35564 .64995 Mdot
.67759 .42019 Mdot
.39005 .42164 Mdot
.32299 .3549 Mdot
.42587 .59767 Mdot
.66931 .45446 Mdot
.44555 .40443 Mdot
.5027 .32486 Mdot
.66021 .46819 Mdot
.64354 .47827 Mdot
.40493 .38412 Mdot
.56154 .31635 Mdot
.44928 .44723 Mdot
.57274 .61038 Mdot
.32989 .23971 Mdot
.60013 .62023 Mdot
.67899 .3233 Mdot
.41135 .35806 Mdot
.65132 .55519 Mdot
.35776 .61636 Mdot
.57631 .30175 Mdot
.64611 .75495 Mdot
.3441 .40752 Mdot
.33669 .77065 Mdot
.53476 .49254 Mdot
.19005 .6234 Mdot
.61939 .7955 Mdot
.56409 .33427 Mdot
.57435 .62526 Mdot
.43636 .40541 Mdot
.61189 .65155 Mdot
.58402 .34974 Mdot
.26919 .32749 Mdot
.44308 .3989 Mdot
.38252 .64527 Mdot
.41751 .46094 Mdot
.37293 .65326 Mdot
.39704 .38595 Mdot
.33645 .39228 Mdot
.69334 .66841 Mdot
.5543 .24611 Mdot
.37137 .38372 Mdot
.7367 .7158 Mdot
.73457 .39491 Mdot
.55634 .33196 Mdot
.40178 .45709 Mdot
.6276 .49171 Mdot
.61175 .61658 Mdot
.45333 .59508 Mdot
.65196 .49106 Mdot
.58546 .6625 Mdot
.37182 .62682 Mdot
.6843 .47575 Mdot
.6454 .43644 Mdot
.39063 .48276 Mdot
.59183 .32314 Mdot
.6007 .64158 Mdot
.41117 .40068 Mdot
.43648 .39265 Mdot
.66658 .27175 Mdot
.70604 .36561 Mdot
.34542 .61331 Mdot
.85347 .50842 Mdot
.35085 .61239 Mdot
.54741 .34187 Mdot
.64861 .48794 Mdot
.43498 .41967 Mdot
.41669 .44514 Mdot
.6697 .67869 Mdot
.39256 .67042 Mdot
.55546 .45857 Mdot
.25997 .45742 Mdot
.67601 .4219 Mdot
.46465 .28272 Mdot
.35726 .63501 Mdot
.46416 .28104 Mdot
.58884 .30656 Mdot
.32309 .7347 Mdot
.53978 .25528 Mdot
.56799 .64854 Mdot
.45905 .2832 Mdot
.40259 .6267 Mdot
.36859 .40176 Mdot
.64122 .51493 Mdot
.679 .4489 Mdot
.36724 .6393 Mdot
.70136 .44992 Mdot
.58002 .33024 Mdot
.43497 .3992 Mdot
.77033 .35562 Mdot
.53289 .72757 Mdot
.64736 .46239 Mdot
.34582 .37123 Mdot
.60166 .63183 Mdot
.41425 .38172 Mdot
.56985 .35899 Mdot
.58529 .64356 Mdot
.72857 .35455 Mdot
.46818 .72548 Mdot
.38693 .42664 Mdot
.81117 .55506 Mdot
.57572 .63956 Mdot
.55254 .18676 Mdot
.393 .4163 Mdot
.59182 .6035 Mdot
.3415 .4645 Mdot
.76085 .48763 Mdot
.54006 .46436 Mdot
.33563 .79255 Mdot
.55089 .47053 Mdot
.6559 .52107 Mdot
.7529 .53289 Mdot
.73548 .59944 Mdot
.61432 .64591 Mdot
.6498 .43003 Mdot
.53704 .30059 Mdot
.60392 .62131 Mdot
.39609 .47116 Mdot
.42918 .42415 Mdot
.26555 .41476 Mdot
.53157 .50488 Mdot
.62297 .45126 Mdot
.55535 .7037 Mdot
.45144 .40111 Mdot
.38714 .47839 Mdot
.41052 .44047 Mdot
.42213 .66373 Mdot
.59223 .6483 Mdot
.79202 .64334 Mdot
.57042 .63286 Mdot
.7286 .29675 Mdot
.66388 .47873 Mdot
.67279 .50128 Mdot
.41788 .40891 Mdot
.6506 .54381 Mdot
.42572 .30111 Mdot
.42424 .4521 Mdot
.62724 .53928 Mdot
.19487 .43604 Mdot
.36956 .46132 Mdot
.41223 .5927 Mdot
.41875 .34776 Mdot
.42991 .65905 Mdot
.5856 .59979 Mdot
.56778 .33977 Mdot
.56045 .30326 Mdot
.59795 .64277 Mdot
.40771 .42101 Mdot
.64388 .56439 Mdot
.42588 .43547 Mdot
.36489 .40764 Mdot
.72396 .28346 Mdot
.53921 .35673 Mdot
.66694 .49813 Mdot
.56906 .35464 Mdot
.36706 .65692 Mdot
.66121 .8579 Mdot
.55851 .32216 Mdot
.42036 .30436 Mdot
.28597 .29276 Mdot
.45553 .28145 Mdot
.3565 .62441 Mdot
.59289 .35507 Mdot
.5737 .64841 Mdot
.23246 .70408 Mdot
.43819 .18258 Mdot
.54577 .65558 Mdot
.39521 .4258 Mdot
.35273 .64929 Mdot
.38847 .60042 Mdot
.56946 .59819 Mdot
.4043 .63385 Mdot
.38508 .49217 Mdot
.36816 .41372 Mdot
.60911 .65324 Mdot
.52808 .74677 Mdot
.55568 .61054 Mdot
.47964 .6901 Mdot
.40581 .45944 Mdot
.35914 .62614 Mdot
.42157 .34962 Mdot
.39141 .68589 Mdot
.63058 .44862 Mdot
.36156 .43651 Mdot
.58142 .33179 Mdot
.61618 .56239 Mdot
.66869 .46286 Mdot
.79557 .51465 Mdot
.39147 .65204 Mdot
.53078 .60037 Mdot
.40023 .64211 Mdot
.37476 .67686 Mdot
.60179 .65066 Mdot
.40105 .66161 Mdot
.43702 .40385 Mdot
.62285 .50631 Mdot
.38704 .65998 Mdot
.58823 .61976 Mdot
.56878 .34494 Mdot
.38011 .62289 Mdot
.65106 .40812 Mdot
.37864 .41206 Mdot
.6349 .47676 Mdot
.70783 .66218 Mdot
.36081 .66409 Mdot
.58202 .36299 Mdot
.68748 .48255 Mdot
.59225 .3292 Mdot
.1767 .45681 Mdot
.58321 .66758 Mdot
.61904 .21799 Mdot
.50515 .3281 Mdot
.40536 .60732 Mdot
.70205 .66508 Mdot
.43216 .41835 Mdot
.37821 .4146 Mdot
.59945 .33144 Mdot
.38899 .60039 Mdot
.26337 .70709 Mdot
.33151 .61351 Mdot
.4798 .72355 Mdot
.58834 .66985 Mdot
.78911 .62802 Mdot
.46958 .67819 Mdot
.21795 .3491 Mdot
.3575 .45652 Mdot
.67726 .51203 Mdot
.41436 .42459 Mdot
.63246 .75936 Mdot
.54275 .34854 Mdot
.622 .34556 Mdot
.40659 .3621 Mdot
.67785 .4894 Mdot
.38966 .40315 Mdot
.46716 .56784 Mdot
.37707 .35227 Mdot
.54892 .32078 Mdot
.65665 .64225 Mdot
.41314 .61124 Mdot
.55918 .34567 Mdot
.65925 .43763 Mdot
.4431 .29707 Mdot
.37633 .38254 Mdot
.34297 .42258 Mdot
.67054 .4195 Mdot
.38662 .64584 Mdot
.65439 .51747 Mdot
.58328 .60115 Mdot
.57462 .33358 Mdot
.37806 .42362 Mdot
.40566 .3676 Mdot
.69551 .57235 Mdot
.60204 .64273 Mdot
.69159 .43635 Mdot
.5678 .62457 Mdot
.65906 .52374 Mdot
.44032 .46205 Mdot
.67452 .50024 Mdot
.40283 .37578 Mdot
.67464 .72569 Mdot
.71782 .27971 Mdot
.24622 .57509 Mdot
.68431 .48351 Mdot
.49411 .28776 Mdot
.59355 .61465 Mdot
.57675 .60965 Mdot
.27765 .35244 Mdot
.40982 .52386 Mdot
.70801 .31508 Mdot
.46059 .80779 Mdot
.57682 .60136 Mdot
.59904 .6254 Mdot
.63343 .47383 Mdot
.3961 .66391 Mdot
.36171 .66996 Mdot
.69341 .48782 Mdot
.45868 .21598 Mdot
.39297 .63358 Mdot
.32009 .75013 Mdot
.70963 .32666 Mdot
.40705 .48787 Mdot
.53033 .65467 Mdot
.5754 .33824 Mdot
.47504 .22189 Mdot
.47062 .57934 Mdot
.4425 .40985 Mdot
.82055 .48687 Mdot
.65345 .47251 Mdot
.38521 .26307 Mdot
.40914 .81594 Mdot
.44137 .39538 Mdot
.39822 .41281 Mdot
.40903 .42958 Mdot
.54768 .36299 Mdot
.33791 .50053 Mdot
.43812 .3966 Mdot
.45779 .21383 Mdot
.45109 .39757 Mdot
.50874 .37767 Mdot
.56505 .35463 Mdot
.45419 .3417 Mdot
.68425 .63925 Mdot
.7825 .41463 Mdot
.47235 .38003 Mdot
.58173 .60246 Mdot
.58229 .50209 Mdot
.60164 .60897 Mdot
.25221 .61552 Mdot
.53303 .2549 Mdot
.39216 .58466 Mdot
.44054 .40897 Mdot
.67808 .45918 Mdot
.38596 .60082 Mdot
.73436 .56474 Mdot
.51974 .9305 Mdot
.5931 .60083 Mdot
.27135 .23491 Mdot
.57107 .61487 Mdot
.65082 .43408 Mdot
.37187 .63308 Mdot
.31405 .56554 Mdot
.58394 .5462 Mdot
.38219 .62054 Mdot
.45723 .76827 Mdot
.34475 .66558 Mdot
.47737 .28962 Mdot
.34642 .62763 Mdot
.58958 .61735 Mdot
.59092 .58651 Mdot
.46283 .46814 Mdot
.42639 .41054 Mdot
.50491 .56869 Mdot
.45799 .3125 Mdot
.42985 .41425 Mdot
.67254 .45894 Mdot
.53806 .17712 Mdot
.5828 .42132 Mdot
.4108 .64266 Mdot
.54738 .6283 Mdot
.3966 .41023 Mdot
.36893 .42666 Mdot
.37118 .38871 Mdot
.85938 .50952 Mdot
.30532 .72842 Mdot
.38798 .38327 Mdot
.45801 .4119 Mdot
.68336 .47921 Mdot
.60997 .33587 Mdot
.61054 .77526 Mdot
.50541 .4073 Mdot
.44547 .4306 Mdot
.55702 .34967 Mdot
.52968 .34747 Mdot
.36508 .39299 Mdot
.77119 .42711 Mdot
.6835 .54537 Mdot
.41081 .4003 Mdot
.45615 .49923 Mdot
.7515 .58952 Mdot
.65329 .42986 Mdot
.65581 .46367 Mdot
.41344 .60521 Mdot
.67825 .45239 Mdot
.68405 .4443 Mdot
.31847 .54458 Mdot
.56113 .49412 Mdot
.63496 .62838 Mdot
.54429 .35395 Mdot
.42014 .44352 Mdot
.34108 .62978 Mdot
.6496 .6905 Mdot
.6074 .63309 Mdot
.38719 .60917 Mdot
.6101 .61238 Mdot
.54599 .36665 Mdot
.3612 .25014 Mdot
.67698 .44509 Mdot
.56613 .60584 Mdot
.46828 .72418 Mdot
.55897 .35149 Mdot
.58795 .65972 Mdot
.65739 .56179 Mdot
.39187 .47151 Mdot
.30685 .63472 Mdot
.41917 .45523 Mdot
.22457 .67145 Mdot
.58604 .65906 Mdot
.67897 .66629 Mdot
.40793 .41295 Mdot
.66325 .46858 Mdot
.3276 .41367 Mdot
.43993 .4357 Mdot
.65628 .45546 Mdot
.36836 .39871 Mdot
.58597 .35221 Mdot
.43619 .61165 Mdot
.57558 .50264 Mdot
.71554 .22915 Mdot
.59384 .32563 Mdot
.72578 .56494 Mdot
.43852 .41602 Mdot
.2093 .40732 Mdot
.38178 .62302 Mdot
.40437 .37232 Mdot
.37844 .31295 Mdot
.38208 .6644 Mdot
.37632 .61251 Mdot
.38156 .44644 Mdot
.56703 .64406 Mdot
.66638 .46045 Mdot
.5642 .35318 Mdot
.17174 .44075 Mdot
.39931 .43602 Mdot
.37987 .39841 Mdot
.55709 .34257 Mdot
.60017 .62317 Mdot
.37026 .43258 Mdot
.71828 .6757 Mdot
.16247 .59295 Mdot
.61004 .63624 Mdot
.42287 .46597 Mdot
.31817 .63109 Mdot
.42802 .66635 Mdot
.35191 .19566 Mdot
.60123 .27327 Mdot
.66853 .50067 Mdot
.33129 .45224 Mdot
.74792 .77133 Mdot
.56906 .34103 Mdot
.78585 .38772 Mdot
.36324 .40903 Mdot
.39156 .39161 Mdot
.3996 .60873 Mdot
.39292 .46104 Mdot
.37504 .66745 Mdot
.67331 .20486 Mdot
.82898 .49748 Mdot
.38271 .65173 Mdot
.41032 .61439 Mdot
.40615 .3091 Mdot
.61485 .77204 Mdot
.36589 .63703 Mdot
.46035 .43779 Mdot
.27043 .68167 Mdot
.49297 .39548 Mdot
.59947 .32824 Mdot
.725 .63954 Mdot
.37482 .69554 Mdot
.59838 .40029 Mdot
.45316 .79222 Mdot
.36942 .69797 Mdot
.70492 .5271 Mdot
.56882 .6122 Mdot
.45021 .40659 Mdot
.68132 .45102 Mdot
.68173 .49403 Mdot
.37877 .35484 Mdot
.4267 .44025 Mdot
.37759 .65792 Mdot
.53801 .34999 Mdot
.61651 .6321 Mdot
.37806 .39369 Mdot
.5853 .42225 Mdot
.55566 .32574 Mdot
.40484 .65021 Mdot
.29965 .33403 Mdot
.55334 .31695 Mdot
.38493 .3448 Mdot
.41923 .39634 Mdot
.40209 .4661 Mdot
.49522 .43584 Mdot
.55775 .63823 Mdot
.70225 .67769 Mdot
.43761 .45886 Mdot
.79193 .43438 Mdot
.50544 .47634 Mdot
.34292 .45344 Mdot
.39746 .63632 Mdot
.62449 .62108 Mdot
.62509 .47384 Mdot
.35924 .29328 Mdot
.39194 .43124 Mdot
.30002 .71821 Mdot
.26521 .43646 Mdot
.62681 .47001 Mdot
.3967 .67143 Mdot
.57925 .34364 Mdot
.4251 .44989 Mdot
.262 .64825 Mdot
.42529 .42159 Mdot
.50889 .34375 Mdot
.64656 .47661 Mdot
.56651 .61509 Mdot
.18304 .61616 Mdot
.6808 .49512 Mdot
.37162 .61504 Mdot
.35245 .81775 Mdot
.34759 .63978 Mdot
.41707 .63217 Mdot
.28208 .66503 Mdot
.55741 .62799 Mdot
.7694 .753 Mdot
.41553 .18096 Mdot
.36559 .37433 Mdot
.59223 .61122 Mdot
.37144 .64382 Mdot
.4163 .38247 Mdot
.36237 .60721 Mdot
.41188 .65905 Mdot
.40287 .48156 Mdot
.40718 .38994 Mdot
.4438 .70114 Mdot
.36022 .79289 Mdot
.57849 .34754 Mdot
.35813 .64871 Mdot
.32168 .34177 Mdot
.42404 .38278 Mdot
.41388 .41246 Mdot
.75253 .57141 Mdot
.5596 .31631 Mdot
.47609 .63509 Mdot
.36448 .41648 Mdot
.8267 .52413 Mdot
.42201 .3483 Mdot
.41391 .60109 Mdot
.60836 .63919 Mdot
.77743 .40748 Mdot
.61614 .6984 Mdot
.38768 .67121 Mdot
.55802 .36007 Mdot
.36581 .59478 Mdot
.42479 .30563 Mdot
.55553 .61771 Mdot
.37612 .60672 Mdot
.54738 .48238 Mdot
.58442 .63566 Mdot
.58218 .65824 Mdot
.24973 .64312 Mdot
.69355 .44441 Mdot
.5648 .36478 Mdot
.60105 .63729 Mdot
.30472 .37774 Mdot
.58126 .61901 Mdot
.28277 .37318 Mdot
.44076 .45002 Mdot
.4108 .23512 Mdot
.52643 .58674 Mdot
.42218 .49933 Mdot
.56397 .65443 Mdot
.58173 .35089 Mdot
.3761 .43999 Mdot
.40553 .62998 Mdot
.56609 .3211 Mdot
.53334 .64293 Mdot
.64515 .49113 Mdot
.40136 .64411 Mdot
.57062 .66813 Mdot
.35778 .64314 Mdot
.35421 .28311 Mdot
.31484 .2494 Mdot
.74958 .64682 Mdot
.57831 .5423 Mdot
.3688 .39171 Mdot
.51943 .80363 Mdot
.41722 .48351 Mdot
.43112 .43799 Mdot
.66921 .45554 Mdot
.40122 .25305 Mdot
.37609 .63248 Mdot
.1858 .62507 Mdot
.56784 .60721 Mdot
.82696 .47642 Mdot
.3785 .57563 Mdot
.40138 .37154 Mdot
.38413 .6611 Mdot
.34694 .63355 Mdot
.22819 .55427 Mdot
.63348 .43411 Mdot
.46853 .44075 Mdot
.46 .46281 Mdot
.34809 .44389 Mdot
.58043 .65691 Mdot
.79433 .50376 Mdot
.66569 .5171 Mdot
.31749 .234 Mdot
.64635 .47124 Mdot
.61608 .5389 Mdot
.40374 .65795 Mdot
.56071 .31961 Mdot
.41374 .40999 Mdot
.36176 .58082 Mdot
.38561 .67235 Mdot
.53152 .36642 Mdot
.58129 .32627 Mdot
.76532 .51065 Mdot
.56058 .63903 Mdot
.37485 .37979 Mdot
.44472 .40388 Mdot
.39483 .45555 Mdot
.42636 .45682 Mdot
.59151 .59991 Mdot
.37415 .45172 Mdot
.60629 .59504 Mdot
.29997 .37912 Mdot
.82243 .49981 Mdot
.55792 .49217 Mdot
.42983 .56382 Mdot
.40965 .63366 Mdot
.30979 .37635 Mdot
.38314 .34411 Mdot
.6868 .25477 Mdot
.17946 .53621 Mdot
.3664 .45471 Mdot
.63126 .47906 Mdot
.40212 .52613 Mdot
.68853 .45321 Mdot
.34584 .16898 Mdot
.69019 .57972 Mdot
.33723 .78518 Mdot
.42833 .38819 Mdot
.75452 .57333 Mdot
.33013 .46933 Mdot
.43435 .47787 Mdot
.72203 .58383 Mdot
.61048 .71435 Mdot
.48956 .75813 Mdot
.53182 .338 Mdot
.38307 .41444 Mdot
.34284 .65192 Mdot
.43733 .40206 Mdot
.41516 .4181 Mdot
.36212 .40963 Mdot
.55848 .65461 Mdot
.46861 .41647 Mdot
.41522 .46539 Mdot
.72065 .41322 Mdot
.49124 .26745 Mdot
.65863 .51184 Mdot
.27445 .34945 Mdot
.5596 .32273 Mdot
.38591 .65721 Mdot
.40421 .75323 Mdot
.56789 .64894 Mdot
.22502 .53658 Mdot
.41606 .46301 Mdot
.45149 .71256 Mdot
.57534 .6712 Mdot
.57657 .33175 Mdot
.6455 .5218 Mdot
.30551 .76584 Mdot
.67858 .46377 Mdot
.54493 .48592 Mdot
.66748 .46854 Mdot
.4406 .34977 Mdot
.37618 .65778 Mdot
.36056 .40521 Mdot
.59957 .63595 Mdot
.66479 .4519 Mdot
.44689 .25417 Mdot
.41068 .43877 Mdot
.67912 .48178 Mdot
.36055 .4073 Mdot
.37282 .24043 Mdot
.62903 .24539 Mdot
.67823 .43878 Mdot
.62342 .60584 Mdot
.5862 .62964 Mdot
.55806 .31817 Mdot
.39726 .65263 Mdot
.4006 .61165 Mdot
.58375 .64206 Mdot
.46827 .17578 Mdot
.44421 .431 Mdot
.42086 .38344 Mdot
.79401 .4337 Mdot
.43312 .40828 Mdot
.46418 .29928 Mdot
.54294 .47586 Mdot
.40829 .64336 Mdot
.40361 .38058 Mdot
.37088 .42821 Mdot
.38397 .42363 Mdot
.34352 .28328 Mdot
.65051 .46446 Mdot
.45183 .42292 Mdot
.5851 .32689 Mdot
.62903 .50336 Mdot
.41765 .38121 Mdot
.34635 .44117 Mdot
.39905 .61084 Mdot
.83529 .45191 Mdot
.56497 .62343 Mdot
.65136 .43887 Mdot
.67686 .49618 Mdot
.72809 .63595 Mdot
.33267 .68733 Mdot
.54414 .47276 Mdot
.29865 .24917 Mdot
.68616 .65454 Mdot
.55366 .33799 Mdot
.6211 .55465 Mdot
.5175 .45631 Mdot
.63424 .45617 Mdot
.60458 .60487 Mdot
.43793 .45613 Mdot
.44519 .43443 Mdot
.77271 .32778 Mdot
.39664 .37097 Mdot
.57719 .34218 Mdot
.59306 .59324 Mdot
.40148 .62603 Mdot
.57817 .33282 Mdot
.57444 .61303 Mdot
.38881 .64491 Mdot
.39474 .47467 Mdot
.40524 .47601 Mdot
.38606 .61049 Mdot
.3903 .60192 Mdot
.4151 .39976 Mdot
.64688 .53312 Mdot
.41484 .60974 Mdot
.36098 .62028 Mdot
.67812 .4452 Mdot
.6748 .44789 Mdot
.38355 .48223 Mdot
.5857 .61087 Mdot
.39544 .46871 Mdot
.6834 .46872 Mdot
.53724 .34128 Mdot
.38148 .62871 Mdot
.37025 .42229 Mdot
.37213 .39954 Mdot
.56098 .35131 Mdot
.5326 .34481 Mdot
.57877 .32781 Mdot
.57916 .59102 Mdot
.39961 .45114 Mdot
.36769 .63091 Mdot
.55951 .62918 Mdot
.52953 .34759 Mdot
.58583 .31187 Mdot
.70548 .44743 Mdot
.43687 .42061 Mdot
.66961 .41048 Mdot
.65562 .8567 Mdot
.51677 .29851 Mdot
.62581 .46558 Mdot
.68227 .42751 Mdot
.45607 .27022 Mdot
.65271 .54012 Mdot
.5763 .64481 Mdot
.52549 .30486 Mdot
.57408 .30165 Mdot
.3629 .43823 Mdot
.42884 .46917 Mdot
.44847 .47592 Mdot
.57027 .32679 Mdot
.37423 .28605 Mdot
.35755 .6147 Mdot
.2329 .44185 Mdot
.56172 .32238 Mdot
.65552 .42857 Mdot
.69611 .44584 Mdot
.64604 .47215 Mdot
.42594 .46806 Mdot
.244 .56499 Mdot
.3664 .33442 Mdot
.5186 .81008 Mdot
.57424 .65954 Mdot
.38734 .58331 Mdot
.18873 .43721 Mdot
.3808 .61179 Mdot
.6957 .47024 Mdot
.56407 .32534 Mdot
.37492 .6059 Mdot
.60835 .61869 Mdot
.59888 .62814 Mdot
.64751 .46564 Mdot
.6603 .47942 Mdot
.63696 .4685 Mdot
.41616 .64468 Mdot
.40136 .66081 Mdot
.39682 .43719 Mdot
.39079 .62276 Mdot
.80988 .37841 Mdot
.55379 .36685 Mdot
.68791 .42943 Mdot
.57358 .62422 Mdot
.37487 .65403 Mdot
.41203 .44268 Mdot
.57355 .4428 Mdot
.57512 .73027 Mdot
.59342 .33349 Mdot
.65165 .26112 Mdot
.33769 .17723 Mdot
.38261 .37468 Mdot
.58432 .65521 Mdot
.76436 .35121 Mdot
.40744 .43102 Mdot
.65182 .48666 Mdot
.67211 .73473 Mdot
.6343 .50623 Mdot
.39381 .46969 Mdot
.37534 .37426 Mdot
.60165 .65521 Mdot
.27398 .29995 Mdot
.4017 .4419 Mdot
.49174 .65327 Mdot
.54676 .62359 Mdot
.67851 .50639 Mdot
.16626 .60746 Mdot
.75248 .61827 Mdot
.467 .22024 Mdot
.67361 .44338 Mdot
.42989 .42977 Mdot
.66685 .4439 Mdot
.59212 .33661 Mdot
.65438 .44294 Mdot
.41876 .59625 Mdot
.65983 .51403 Mdot
.38113 .3978 Mdot
.36467 .63836 Mdot
.57501 .63934 Mdot
.82099 .45828 Mdot
.71379 .39539 Mdot
.6628 .46954 Mdot
.66408 .43484 Mdot
.38859 .38099 Mdot
.46859 .65867 Mdot
.35694 .37541 Mdot
.42706 .38593 Mdot
.57218 .60148 Mdot
.3891 .66042 Mdot
.56671 .66156 Mdot
.43613 .37917 Mdot
.7144 .69245 Mdot
.56585 .63036 Mdot
.44408 .71571 Mdot
.55559 .34051 Mdot
.47745 .54101 Mdot
.41935 .44587 Mdot
.60475 .63213 Mdot
.4005 .45214 Mdot
.36715 .60229 Mdot
.515 .52388 Mdot
.65562 .69458 Mdot
.59754 .63637 Mdot
.25215 .69319 Mdot
.69708 .50026 Mdot
.44933 .36732 Mdot
.59483 .60464 Mdot
.37925 .31408 Mdot
.64718 .4352 Mdot
.55039 .33388 Mdot
.52988 .34588 Mdot
.59067 .32529 Mdot
.34747 .4149 Mdot
.45491 .36646 Mdot
.5716 .36141 Mdot
.61281 .63056 Mdot
.54391 .32455 Mdot
.33602 .70634 Mdot
.25802 .70373 Mdot
.54478 .35028 Mdot
.39189 .4189 Mdot
.48504 .43976 Mdot
.48589 .26441 Mdot
.65258 .41127 Mdot
.34204 .77855 Mdot
.43296 .57407 Mdot
.42578 .41264 Mdot
.43351 .66501 Mdot
.3636 .60956 Mdot
.76033 .35471 Mdot
.47238 .31669 Mdot
.76243 .41007 Mdot
.41307 .61733 Mdot
.66617 .68025 Mdot
.40397 .64892 Mdot
.38857 .37478 Mdot
.41329 .38418 Mdot
.36347 .67268 Mdot
.80393 .50611 Mdot
.70211 .55627 Mdot
.15966 .5472 Mdot
.35783 .62444 Mdot
.60044 .61071 Mdot
.58186 .5976 Mdot
.5713 .65701 Mdot
.69777 .3172 Mdot
.36144 .6619 Mdot
.39374 .44457 Mdot
.68549 .47699 Mdot
.44899 .42191 Mdot
.59003 .6405 Mdot
.18955 .63029 Mdot
.40224 .61671 Mdot
.40768 .39985 Mdot
.46309 .18618 Mdot
.65983 .48838 Mdot
.5533 .34812 Mdot
.35042 .25132 Mdot
.73467 .35819 Mdot
.55546 .62541 Mdot
.35136 .6555 Mdot
.66565 .64181 Mdot
.43047 .72262 Mdot
.36748 .46913 Mdot
.37008 .48058 Mdot
.19676 .38726 Mdot
.72255 .34949 Mdot
.35719 .4089 Mdot
.64674 .43904 Mdot
.67085 .67845 Mdot
.37211 .41666 Mdot
.35428 .6274 Mdot
.53458 .32863 Mdot
.58134 .32052 Mdot
.4584 .45325 Mdot
.59163 .54691 Mdot
.48587 .5112 Mdot
.3825 .4571 Mdot
.38562 .34436 Mdot
.69432 .47044 Mdot
.68345 .64832 Mdot
.80587 .44925 Mdot
.55291 .35959 Mdot
.36325 .41949 Mdot
.50004 .7758 Mdot
.40503 .66342 Mdot
.64263 .50559 Mdot
.55379 .62123 Mdot
.32626 .29281 Mdot
.67172 .513 Mdot
.37115 .41617 Mdot
.37024 .43147 Mdot
.58957 .6599 Mdot
.41393 .60098 Mdot
.56813 .3269 Mdot
.68469 .48416 Mdot
.55537 .36056 Mdot
.37587 .6653 Mdot
.40179 .61988 Mdot
.49188 .38714 Mdot
.46794 .39126 Mdot
.65701 .46232 Mdot
.43741 .38227 Mdot
.63814 .41264 Mdot
.2708 .29923 Mdot
.5962 .67053 Mdot
.38329 .37389 Mdot
.42836 .64801 Mdot
.59733 .64074 Mdot
.39841 .39211 Mdot
.17397 .41667 Mdot
.43264 .38423 Mdot
.62086 .69744 Mdot
.74394 .66956 Mdot
.58471 .34191 Mdot
.21338 .44011 Mdot
.40681 .70559 Mdot
.43143 .40394 Mdot
.64999 .50075 Mdot
.33267 .40049 Mdot
.56955 .6451 Mdot
.40923 .64833 Mdot
.35987 .18745 Mdot
.58352 .62042 Mdot
.43155 .39355 Mdot
.57538 .33294 Mdot
.34692 .64426 Mdot
.58994 .50957 Mdot
.78344 .43724 Mdot
.40772 .35269 Mdot
.46266 .43189 Mdot
.39002 .46674 Mdot
.65654 .76544 Mdot
.65002 .44011 Mdot
.37221 .64905 Mdot
.57968 .65621 Mdot
.58351 .64461 Mdot
.6494 .46864 Mdot
.49188 .74871 Mdot
.47994 .53887 Mdot
.6962 .81238 Mdot
.65689 .45261 Mdot
.58539 .36191 Mdot
.48015 .64958 Mdot
.64892 .50181 Mdot
.67641 .48304 Mdot
.69396 .47032 Mdot
.6383 .65869 Mdot
.3893 .64183 Mdot
.37119 .39923 Mdot
.38503 .59309 Mdot
.43313 .42996 Mdot
.48469 .49769 Mdot
.59944 .64096 Mdot
.41195 .64395 Mdot
.17978 .4124 Mdot
.38898 .54098 Mdot
.4016 .42386 Mdot
.19648 .41727 Mdot
.39956 .36098 Mdot
.43175 .28371 Mdot
.44522 .37121 Mdot
.66421 .47423 Mdot
.33572 .46848 Mdot
.34211 .39994 Mdot
.81732 .42709 Mdot
.57344 .62227 Mdot
.64275 .43629 Mdot
.3534 .40593 Mdot
.4136 .34575 Mdot
.35897 .67264 Mdot
.37016 .60916 Mdot
.56282 .3625 Mdot
.55459 .24404 Mdot
.57328 .6384 Mdot
.33073 .24452 Mdot
.42484 .4064 Mdot
.78888 .59405 Mdot
.21348 .45959 Mdot
.39879 .39314 Mdot
.27521 .6922 Mdot
.23596 .55344 Mdot
.42391 .44833 Mdot
.41619 .32059 Mdot
.59825 .62137 Mdot
.71881 .68777 Mdot
.45945 .41384 Mdot
.65296 .48997 Mdot
.39927 .66003 Mdot
.35166 .62856 Mdot
.57854 .35781 Mdot
.67683 .23164 Mdot
.57024 .66216 Mdot
.40977 .64947 Mdot
.41324 .43652 Mdot
.55641 .62722 Mdot
.68333 .45622 Mdot
.4247 .37177 Mdot
.47984 .31018 Mdot
.39351 .62415 Mdot
.45775 .40511 Mdot
.52504 .69891 Mdot
.50212 .23114 Mdot
.51881 .84799 Mdot
.56957 .65446 Mdot
.54576 .32769 Mdot
.33282 .41377 Mdot
.36432 .22639 Mdot
.36356 .45189 Mdot
.40406 .23914 Mdot
.33656 .6999 Mdot
.54622 .32647 Mdot
.40314 .41485 Mdot
.38301 .42972 Mdot
.53433 .57641 Mdot
.53558 .3479 Mdot
.44661 .40413 Mdot
.36116 .50948 Mdot
.38535 .6454 Mdot
.64559 .52604 Mdot
.39491 .62867 Mdot
.39511 .42499 Mdot
.47418 .4094 Mdot
.39608 .6057 Mdot
.2678 .27012 Mdot
.53697 .31646 Mdot
.56345 .62746 Mdot
.46307 .37891 Mdot
.44481 .44852 Mdot
.73421 .73069 Mdot
.63138 .44754 Mdot
.58067 .78159 Mdot
.62721 .40706 Mdot
.4829 .78356 Mdot
.7558 .61244 Mdot
.34101 .80647 Mdot
.82043 .48131 Mdot
.45767 .46487 Mdot
.43809 .54185 Mdot
.39854 .32386 Mdot
.56083 .65206 Mdot
.30518 .48138 Mdot
.42668 .41117 Mdot
.41522 .42124 Mdot
.638 .49972 Mdot
.46174 .73672 Mdot
.77227 .42025 Mdot
.58865 .53179 Mdot
.56543 .3292 Mdot
.36297 .65307 Mdot
.39429 .38565 Mdot
.5576 .42486 Mdot
.65412 .51141 Mdot
.79281 .58115 Mdot
.40523 .40398 Mdot
.68052 .25369 Mdot
.64577 .66866 Mdot
.55874 .639 Mdot
.66584 .50543 Mdot
.75065 .38129 Mdot
.43865 .42469 Mdot
.55876 .60701 Mdot
.40597 .44406 Mdot
.72534 .47735 Mdot
.4259 .37701 Mdot
.54315 .34224 Mdot
.36401 .39953 Mdot
.59051 .52413 Mdot
.44284 .84068 Mdot
.51609 .32896 Mdot
.35323 .64843 Mdot
.66239 .41768 Mdot
.65196 .46442 Mdot
.38199 .60385 Mdot
.65456 .46568 Mdot
.22433 .49785 Mdot
.29834 .56222 Mdot
.561 .33164 Mdot
.39685 .34342 Mdot
.55143 .35568 Mdot
.62994 .44937 Mdot
.43026 .4193 Mdot
.28235 .25764 Mdot
.66126 .45663 Mdot
.75404 .67601 Mdot
.57786 .62277 Mdot
.6362 .44122 Mdot
.45267 .39944 Mdot
.66174 .61726 Mdot
.67272 .50392 Mdot
.65834 .68511 Mdot
.38556 .42549 Mdot
.40482 .62405 Mdot
.37927 .42809 Mdot
.43504 .363 Mdot
.65937 .5249 Mdot
.42663 .46003 Mdot
.57461 .61294 Mdot
.42013 .62135 Mdot
.28517 .73466 Mdot
.62581 .69741 Mdot
.44374 .40856 Mdot
.41155 .43488 Mdot
.34469 .64862 Mdot
.45276 .42766 Mdot
.59084 .59996 Mdot
.9009 .53465 Mdot
.55524 .34096 Mdot
.66827 .43323 Mdot
.74724 .62914 Mdot
.3716 .46201 Mdot
.37589 .4471 Mdot
.16722 .44788 Mdot
.7439 .64493 Mdot
.58663 .60473 Mdot
.34888 .37971 Mdot
.68784 .47574 Mdot
.57533 .33478 Mdot
.61347 .63659 Mdot
.40125 .46592 Mdot
.41115 .41182 Mdot
.54608 .32824 Mdot
.25264 .65641 Mdot
.74417 .35416 Mdot
.58093 .66156 Mdot
.33889 .47411 Mdot
.61089 .42129 Mdot
.44241 .43314 Mdot
.69876 .31256 Mdot
.37062 .61075 Mdot
.55932 .6129 Mdot
.56029 .79925 Mdot
.36078 .42467 Mdot
.60862 .6346 Mdot
.57232 .63566 Mdot
.3441 .39285 Mdot
.40442 .67722 Mdot
.42071 .63999 Mdot
.35888 .64545 Mdot
.82172 .38213 Mdot
.48284 .23303 Mdot
.63697 .46883 Mdot
.59924 .62248 Mdot
.68805 .44683 Mdot
.5796 .36717 Mdot
.534 .45476 Mdot
.6746 .43629 Mdot
.38341 .60025 Mdot
.66461 .41486 Mdot
.38168 .42607 Mdot
.57582 .64166 Mdot
.6347 .45744 Mdot
.35205 .40622 Mdot
.44992 .67759 Mdot
.74047 .44972 Mdot
.569 .31149 Mdot
.53138 .33031 Mdot
.40866 .38417 Mdot
.62495 .47635 Mdot
.41541 .40179 Mdot
.62138 .62356 Mdot
.47554 .66076 Mdot
.35674 .43421 Mdot
.66036 .47019 Mdot
.42745 .6778 Mdot
.73468 .35856 Mdot
.37168 .36581 Mdot
.39304 .41869 Mdot
.43745 .4334 Mdot
.40636 .44493 Mdot
.46235 .75598 Mdot
.59195 .66959 Mdot
.48068 .6117 Mdot
.70002 .66361 Mdot
.38831 .61654 Mdot
.41961 .65829 Mdot
.66018 .29335 Mdot
.70977 .52652 Mdot
.58885 .6111 Mdot
.43256 .44131 Mdot
.64356 .6954 Mdot
.19705 .6422 Mdot
.24972 .28229 Mdot
.54501 .37276 Mdot
.6283 .47783 Mdot
.3584 .66331 Mdot
.65576 .50884 Mdot
.42847 .42713 Mdot
.33239 .41943 Mdot
.33614 .80864 Mdot
.5853 .58218 Mdot
.56595 .32522 Mdot
.43567 .4329 Mdot
.48371 .22693 Mdot
.68381 .47889 Mdot
.69636 .45211 Mdot
.44531 .39906 Mdot
.42442 .61475 Mdot
.65198 .7989 Mdot
.55954 .64336 Mdot
.43727 .57731 Mdot
.31083 .41824 Mdot
.53202 .68433 Mdot
.59229 .6455 Mdot
.7501 .41304 Mdot
.62747 .48265 Mdot
.2025 .53606 Mdot
.39117 .61476 Mdot
.5629 .32368 Mdot
.35327 .46818 Mdot
.40661 .61342 Mdot
.65754 .5216 Mdot
.41083 .63484 Mdot
.36407 .39591 Mdot
.57635 .66739 Mdot
.66462 .50289 Mdot
.61867 .59779 Mdot
.40822 .67403 Mdot
.57119 .35719 Mdot
.50737 .58859 Mdot
.33803 .5315 Mdot
.23303 .54865 Mdot
.44948 .42738 Mdot
.55585 .42132 Mdot
.39513 .44899 Mdot
.36433 .67734 Mdot
.40999 .4433 Mdot
.43882 .65682 Mdot
.65431 .50292 Mdot
.45821 .41201 Mdot
.38301 .46138 Mdot
.2804 .44197 Mdot
.39733 .40616 Mdot
.45988 .39753 Mdot
.4275 .44745 Mdot
.36486 .58756 Mdot
.36969 .35434 Mdot
.39607 .63883 Mdot
.77693 .4443 Mdot
.67473 .48299 Mdot
.5305 .33416 Mdot
.57623 .31564 Mdot
.4204 .23232 Mdot
.57578 .29056 Mdot
.47695 .74573 Mdot
.38763 .63363 Mdot
.56911 .62564 Mdot
.41059 .44653 Mdot
.4721 .81125 Mdot
.74047 .60466 Mdot
.68982 .47086 Mdot
.62611 .69714 Mdot
.36756 .48894 Mdot
.66095 .76534 Mdot
.4511 .39385 Mdot
.7669 .31403 Mdot
.47577 .44903 Mdot
.41678 .37557 Mdot
.69789 .46364 Mdot
.52769 .32117 Mdot
.4544 .41171 Mdot
.35745 .67141 Mdot
.54867 .33044 Mdot
.39587 .55419 Mdot
.60263 .47279 Mdot
.75259 .42464 Mdot
.30631 .51566 Mdot
.40285 .45042 Mdot
.66335 .50197 Mdot
.40037 .64496 Mdot
.81125 .45692 Mdot
.56005 .62651 Mdot
.6002 .55997 Mdot
.31624 .35525 Mdot
.22296 .36662 Mdot
.55657 .32532 Mdot
.24994 .64698 Mdot
.38064 .39678 Mdot
.68191 .32421 Mdot
.397 .47918 Mdot
.20025 .64468 Mdot
.59114 .35713 Mdot
.42674 .63338 Mdot
.59891 .60936 Mdot
.37491 .59808 Mdot
.24139 .57242 Mdot
.52217 .64152 Mdot
.5293 .54215 Mdot
.68021 .4684 Mdot
.48569 .60827 Mdot
.36626 .64373 Mdot
.36754 .43036 Mdot
.68154 .82774 Mdot
.36425 .61658 Mdot
.3785 .66985 Mdot
.28944 .28234 Mdot
.27194 .29111 Mdot
.34947 .47823 Mdot
.40697 .60908 Mdot
.67838 .47072 Mdot
.5758 .3521 Mdot
.38148 .43532 Mdot
.3945 .43746 Mdot
.40069 .61027 Mdot
.6978 .45693 Mdot
.40441 .5417 Mdot
.66204 .47875 Mdot
.38589 .64748 Mdot
.66764 .48864 Mdot
.68508 .67966 Mdot
.6329 .45508 Mdot
.44625 .4455 Mdot
.4103 .44431 Mdot
.62255 .42229 Mdot
.40173 .62014 Mdot
.38321 .45497 Mdot
.37077 .39414 Mdot
.36747 .63372 Mdot
.5935 .41545 Mdot
.31941 .64064 Mdot
.43961 .41272 Mdot
.38108 .41078 Mdot
.54253 .33081 Mdot
.53712 .42813 Mdot
.58813 .21535 Mdot
.37634 .44027 Mdot
.56023 .36644 Mdot
.41556 .64428 Mdot
.41249 .39835 Mdot
.36112 .73764 Mdot
.67061 .68063 Mdot
.36103 .42202 Mdot
.64435 .43683 Mdot
.3441 .42317 Mdot
.56643 .83358 Mdot
.43065 .38686 Mdot
.37152 .63924 Mdot
.38715 .66485 Mdot
.30948 .27907 Mdot
.36765 .61838 Mdot
.67857 .44878 Mdot
.58672 .63746 Mdot
.22087 .66631 Mdot
.68381 .45718 Mdot
.35278 .39004 Mdot
.41352 .18102 Mdot
.44635 .38038 Mdot
.35248 .41646 Mdot
.69824 .74362 Mdot
.68398 .46014 Mdot
.37786 .6607 Mdot
.58025 .55825 Mdot
.46944 .44823 Mdot
.55555 .62299 Mdot
.33577 .41116 Mdot
.43102 .46133 Mdot
.74826 .6615 Mdot
.6191 .74049 Mdot
.60095 .59717 Mdot
.40852 .4896 Mdot
.37662 .44148 Mdot
.69071 .41375 Mdot
.41392 .44152 Mdot
.5529 .35813 Mdot
.36727 .66333 Mdot
.63847 .49204 Mdot
.56317 .34924 Mdot
.42884 .40691 Mdot
.5719 .32677 Mdot
.63509 .47665 Mdot
.5597 .60815 Mdot
.43285 .4241 Mdot
.60002 .32921 Mdot
.56723 .32907 Mdot
.39284 .45137 Mdot
.40707 .65229 Mdot
.4433 .49283 Mdot
.40922 .3959 Mdot
.36694 .41622 Mdot
.40104 .61228 Mdot
.2258 .29096 Mdot
.43061 .38493 Mdot
.69177 .50533 Mdot
.38203 .67174 Mdot
.5601 .68616 Mdot
.63498 .48849 Mdot
.4334 .45999 Mdot
.56729 .60251 Mdot
.60341 .63734 Mdot
.69201 .45529 Mdot
.34563 .63073 Mdot
.62545 .41209 Mdot
.43078 .67281 Mdot
.47099 .40618 Mdot
.41959 .36704 Mdot
.46138 .17021 Mdot
.32543 .78634 Mdot
.35231 .63176 Mdot
.70043 .46967 Mdot
.58455 .52979 Mdot
.6011 .62026 Mdot
.6838 .43073 Mdot
.34765 .65 Mdot
.35539 .65782 Mdot
.40858 .63727 Mdot
.57319 .31967 Mdot
.61702 .40787 Mdot
.41564 .6005 Mdot
.42441 .6163 Mdot
.3836 .42505 Mdot
.37759 .44491 Mdot
.4679 .33476 Mdot
.5112 .28349 Mdot
.57337 .35778 Mdot
.64863 .47371 Mdot
.8766 .52966 Mdot
.61983 .61943 Mdot
.2793 .4468 Mdot
.35762 .43575 Mdot
.57617 .91234 Mdot
.44582 .39057 Mdot
.41539 .4392 Mdot
.41851 .61894 Mdot
.59657 .31736 Mdot
.54991 .3512 Mdot
.36656 .64813 Mdot
.37896 .67941 Mdot
.54982 .357 Mdot
.19474 .5925 Mdot
.25672 .70656 Mdot
.5269 .59107 Mdot
.37377 .62909 Mdot
.33686 .54527 Mdot
.55294 .62324 Mdot
.4291 .66003 Mdot
.61882 .63447 Mdot
.6803 .4834 Mdot
.6295 .49041 Mdot
.57964 .65724 Mdot
.38811 .42735 Mdot
.63929 .4557 Mdot
.46828 .41525 Mdot
.22555 .63996 Mdot
.29006 .6395 Mdot
.77317 .55516 Mdot
.43216 .4705 Mdot
.77006 .43242 Mdot
.72412 .52347 Mdot
.42739 .3958 Mdot
.42604 .77579 Mdot
.56799 .32507 Mdot
.43245 .62914 Mdot
.58597 .59865 Mdot
.53691 .8496 Mdot
.43957 .43646 Mdot
.37489 .63646 Mdot
.57475 .61781 Mdot
.34751 .27159 Mdot
.49012 .65469 Mdot
.43561 .43071 Mdot
.72021 .7927 Mdot
.36126 .5848 Mdot
.63747 .48962 Mdot
.54847 .17241 Mdot
.38438 .59219 Mdot
.59912 .3695 Mdot
.69089 .64871 Mdot
.19231 .40691 Mdot
.38528 .65705 Mdot
.69892 .44012 Mdot
.36342 .65144 Mdot
.56263 .35956 Mdot
.42444 .59488 Mdot
.67811 .49328 Mdot
.40065 .40916 Mdot
.65467 .4725 Mdot
.57997 .35534 Mdot
.69082 .31582 Mdot
.58187 .59841 Mdot
.64233 .43688 Mdot
.59294 .62819 Mdot
.51587 .23461 Mdot
.7049 .69947 Mdot
.56576 .61683 Mdot
.33207 .26334 Mdot
.35725 .41648 Mdot
.40294 .5924 Mdot
.65069 .45438 Mdot
.68438 .64373 Mdot
.538 .56295 Mdot
.38206 .61611 Mdot
.64531 .48199 Mdot
.3291 .3492 Mdot
.42633 .19363 Mdot
.43691 .35276 Mdot
.53281 .24602 Mdot
.37024 .62912 Mdot
.68877 .43208 Mdot
.79452 .43362 Mdot
.37724 .60119 Mdot
.65629 .45183 Mdot
.60522 .61861 Mdot
.58675 .64605 Mdot
.45165 .411 Mdot
.63407 .63633 Mdot
.64195 .47038 Mdot
.7433 .50963 Mdot
.40504 .66396 Mdot
.35669 .27079 Mdot
.59459 .32481 Mdot
.67153 .47841 Mdot
.40265 .36977 Mdot
.40418 .68358 Mdot
.67762 .67887 Mdot
.41449 .53307 Mdot
.86522 .54462 Mdot
.64983 .46944 Mdot
.37179 .66662 Mdot
.37884 .63285 Mdot
.36813 .36873 Mdot
.58012 .54449 Mdot
.62112 .41403 Mdot
.43314 .20283 Mdot
.39166 .24476 Mdot
.65512 .52415 Mdot
.62642 .52711 Mdot
.36242 .3806 Mdot
.407 .45551 Mdot
.60095 .61713 Mdot
.39563 .41168 Mdot
.42325 .62569 Mdot
.45403 .41841 Mdot
.59375 .64807 Mdot
.67456 .45992 Mdot
.42809 .42098 Mdot
.58263 .34884 Mdot
.57834 .59461 Mdot
.6003 .65697 Mdot
.66839 .47286 Mdot
.41009 .61648 Mdot
.5209 .34909 Mdot
.65974 .47961 Mdot
.40284 .44945 Mdot
.62221 .55973 Mdot
.37094 .38898 Mdot
.19354 .56732 Mdot
.38447 .59908 Mdot
.6536 .50602 Mdot
.39152 .67302 Mdot
.59242 .62295 Mdot
.69906 .66334 Mdot
.40085 .43127 Mdot
.65952 .45108 Mdot
.62128 .42909 Mdot
.21505 .61644 Mdot
.34441 .65403 Mdot
.65009 .56717 Mdot
.41544 .65915 Mdot
.64727 .52069 Mdot
.28219 .3297 Mdot
.55368 .33103 Mdot
.68937 .47566 Mdot
.31523 .76068 Mdot
.66027 .46352 Mdot
.39523 .40276 Mdot
.39913 .38855 Mdot
.63285 .48227 Mdot
.56234 .31608 Mdot
.82788 .49109 Mdot
.73296 .47924 Mdot
.3819 .6599 Mdot
.22544 .40498 Mdot
.83437 .61844 Mdot
.62213 .65426 Mdot
.59593 .60945 Mdot
.46727 .45388 Mdot
.41364 .37385 Mdot
.61775 .62946 Mdot
.54746 .62922 Mdot
.59405 .34324 Mdot
.69367 .46991 Mdot
.41079 .58088 Mdot
.55884 .60381 Mdot
.49534 .40312 Mdot
.59147 .28639 Mdot
.37046 .36271 Mdot
.3145 .41279 Mdot
.41703 .4759 Mdot
.39588 .23575 Mdot
.58832 .65392 Mdot
.39662 .38296 Mdot
.37772 .35588 Mdot
.56489 .6054 Mdot
.5588 .35915 Mdot
.61345 .73382 Mdot
.66263 .49401 Mdot
.13139 .51272 Mdot
.39975 .37726 Mdot
.39861 .3998 Mdot
.57267 .65886 Mdot
.64197 .39736 Mdot
.4079 .62005 Mdot
.38338 .59801 Mdot
.64748 .44154 Mdot
.5079 .58059 Mdot
.44303 .44237 Mdot
.42194 .3907 Mdot
.65558 .49757 Mdot
.63732 .44023 Mdot
.7511 .53532 Mdot
.37322 .40042 Mdot
.57764 .61645 Mdot
.58088 .5008 Mdot
.59105 .6521 Mdot
.38428 .37698 Mdot
.39306 .40033 Mdot
.44709 .44343 Mdot
.39544 .37126 Mdot
.60101 .65746 Mdot
.39271 .38422 Mdot
.48788 .40549 Mdot
.41324 .63342 Mdot
.42927 .45621 Mdot
.38568 .24158 Mdot
.38802 .41564 Mdot
.57094 .35566 Mdot
.48939 .46456 Mdot
.43926 .43194 Mdot
.439 .45361 Mdot
.7307 .48212 Mdot
.40544 .41863 Mdot
.62136 .6247 Mdot
.38795 .62051 Mdot
.59957 .62341 Mdot
.58887 .65916 Mdot
.66822 .44044 Mdot
.57537 .35989 Mdot
.37708 .46681 Mdot
.59064 .32842 Mdot
.37316 .47007 Mdot
.35888 .41742 Mdot
.71439 .64126 Mdot
.75942 .30272 Mdot
.74009 .34766 Mdot
.40022 .43204 Mdot
.6721 .45214 Mdot
.64162 .49757 Mdot
.43851 .55986 Mdot
.4278 .3512 Mdot
.61673 .62955 Mdot
.60419 .63285 Mdot
.48015 .30335 Mdot
.74189 .66669 Mdot
.56734 .35728 Mdot
.54715 .43687 Mdot
.46897 .41481 Mdot
.36753 .40297 Mdot
.42873 .37322 Mdot
.68142 .44208 Mdot
.60871 .53982 Mdot
.68927 .47156 Mdot
.63097 .69477 Mdot
.59704 .64756 Mdot
.43776 .44289 Mdot
.30369 .68998 Mdot
.37117 .60716 Mdot
.38882 .62043 Mdot
.60985 .64138 Mdot
.66901 .42052 Mdot
.50423 .35473 Mdot
.29055 .22268 Mdot
.37657 .58022 Mdot
.5882 .31177 Mdot
.43272 .39906 Mdot
.67094 .46249 Mdot
.355 .63649 Mdot
.54194 .32582 Mdot
.36198 .41772 Mdot
.61622 .41394 Mdot
.39888 .43437 Mdot
.4016 .32403 Mdot
.40344 .65253 Mdot
.2186 .67184 Mdot
.34792 .63534 Mdot
.58204 .59458 Mdot
.57083 .60624 Mdot
.39586 .39294 Mdot
.48826 .16856 Mdot
.39497 .59167 Mdot
.62511 .67946 Mdot
.5924 .35422 Mdot
.66002 .62551 Mdot
.54459 .35566 Mdot
.6466 .49898 Mdot
.55132 .32833 Mdot
.66825 .5032 Mdot
.51154 .29539 Mdot
.34673 .60996 Mdot
.55772 .34549 Mdot
.7185 .4619 Mdot
.43266 .35326 Mdot
.53049 .33883 Mdot
.4397 .48143 Mdot
.20155 .48075 Mdot
.6536 .49485 Mdot
.57243 .31673 Mdot
.36805 .4304 Mdot
.43275 .82158 Mdot
.57676 .60965 Mdot
.61683 .6223 Mdot
.46623 .39672 Mdot
.69553 .46201 Mdot
.35935 .66968 Mdot
.41928 .73669 Mdot
.52855 .63776 Mdot
.41139 .3855 Mdot
.4546 .41348 Mdot
.42328 .65354 Mdot
.33321 .6634 Mdot
.39141 .39674 Mdot
.29441 .40824 Mdot
.38207 .39135 Mdot
.60766 .62023 Mdot
.35933 .61512 Mdot
.38258 .62742 Mdot
.64132 .4791 Mdot
.40887 .60612 Mdot
.44439 .64768 Mdot
.62788 .57163 Mdot
.45856 .47 Mdot
.585 .62168 Mdot
.63133 .5882 Mdot
.62924 .69672 Mdot
.34936 .77782 Mdot
.41953 .66177 Mdot
.447 .44898 Mdot
.39996 .66751 Mdot
.57876 .33587 Mdot
.40043 .62253 Mdot
.36445 .6674 Mdot
.41858 .39787 Mdot
.42958 .43005 Mdot
.68146 .46072 Mdot
.58539 .5437 Mdot
.41496 .63849 Mdot
.40374 .38482 Mdot
.45453 .39128 Mdot
.46005 .39677 Mdot
.50712 .50222 Mdot
.35259 .63443 Mdot
.26281 .41851 Mdot
.3787 .29708 Mdot
.4152 .63643 Mdot
.59566 .82613 Mdot
.6878 .65594 Mdot
.63824 .43263 Mdot
.62504 .60983 Mdot
.37236 .40147 Mdot
.6333 .48826 Mdot
.42858 .42666 Mdot
.31434 .41315 Mdot
.41301 .41463 Mdot
.54 .35033 Mdot
.4574 .46511 Mdot
.64008 .51465 Mdot
.65829 .47658 Mdot
.42275 .38462 Mdot
.42484 .41943 Mdot
.71089 .33144 Mdot
.38608 .67933 Mdot
.40842 .62372 Mdot
.66449 .39892 Mdot
.56391 .33996 Mdot
.55734 .61667 Mdot
.41978 .4474 Mdot
.66312 .44046 Mdot
.65538 .47482 Mdot
.37255 .59855 Mdot
.65297 .48775 Mdot
.56358 .64951 Mdot
.40412 .43359 Mdot
.61763 .62472 Mdot
.57851 .31939 Mdot
.35905 .65001 Mdot
.43673 .43961 Mdot
.38314 .4244 Mdot
.38687 .66478 Mdot
.36513 .44773 Mdot
.54125 .33293 Mdot
.65805 .46467 Mdot
.39015 .65338 Mdot
.58714 .6395 Mdot
.65478 .50388 Mdot
.37348 .42496 Mdot
.87104 .53277 Mdot
.39049 .40523 Mdot
.37144 .41296 Mdot
.29565 .75739 Mdot
.45516 .46825 Mdot
.64796 .46101 Mdot
.42741 .62821 Mdot
.46411 .4317 Mdot
.43457 .23399 Mdot
.23869 .28879 Mdot
.68932 .46382 Mdot
.43707 .40055 Mdot
.3599 .79923 Mdot
.4318 .39173 Mdot
.34231 .2401 Mdot
.62824 .28619 Mdot
.47781 .58259 Mdot
.47622 .40948 Mdot
.56946 .65005 Mdot
.68095 .45895 Mdot
.65242 .50123 Mdot
.2453 .39621 Mdot
.41928 .3947 Mdot
.44425 .33277 Mdot
.37124 .44775 Mdot
.5903 .6466 Mdot
.45774 .30799 Mdot
.65089 .47253 Mdot
.79041 .38521 Mdot
.39504 .44561 Mdot
.35159 .63825 Mdot
.66694 .41549 Mdot
.68414 .66432 Mdot
.36969 .42187 Mdot
.5886 .32811 Mdot
.59434 .58943 Mdot
.46429 .44817 Mdot
.58205 .6264 Mdot
.3646 .40478 Mdot
.49032 .38103 Mdot
.59705 .19005 Mdot
.40852 .64621 Mdot
.60031 .61221 Mdot
.66396 .54841 Mdot
.40131 .4818 Mdot
.38839 .65546 Mdot
.38986 .61468 Mdot
.59343 .34085 Mdot
.54707 .52488 Mdot
.51566 .70135 Mdot
.32473 .59543 Mdot
.24025 .38944 Mdot
.66612 .41699 Mdot
.68594 .56055 Mdot
.37925 .43714 Mdot
.78636 .58706 Mdot
.61459 .60611 Mdot
.39954 .40267 Mdot
.20753 .49526 Mdot
.35774 .6408 Mdot
.37924 .40604 Mdot
.55213 .35643 Mdot
.79569 .52782 Mdot
.79497 .55856 Mdot
.6149 .78725 Mdot
.68129 .47219 Mdot
.33344 .42105 Mdot
.32676 .38781 Mdot
.66044 .43377 Mdot
.38191 .46711 Mdot
.65219 .4583 Mdot
.17689 .48661 Mdot
.54609 .3244 Mdot
.35624 .64862 Mdot
.68714 .65903 Mdot
.41259 .47246 Mdot
.44699 .37721 Mdot
.5403 .32282 Mdot
.40545 .46033 Mdot
.68139 .23721 Mdot
.75959 .57403 Mdot
.63701 .45416 Mdot
.40905 .63896 Mdot
.42444 .46892 Mdot
.55524 .4923 Mdot
.41296 .39268 Mdot
.2952 .59061 Mdot
.43825 .45541 Mdot
.51032 .68471 Mdot
.40003 .65972 Mdot
.58536 .62549 Mdot
.35238 .45519 Mdot
.41285 .4232 Mdot
.5797 .4412 Mdot
.47701 .41698 Mdot
.42086 .38019 Mdot
.35208 .66437 Mdot
.35938 .61782 Mdot
.39505 .63848 Mdot
.66311 .51331 Mdot
.74688 .65853 Mdot
.587 .61484 Mdot
.34015 .41188 Mdot
.55638 .60592 Mdot
.39265 .53123 Mdot
.56522 .31164 Mdot
.4394 .81242 Mdot
.41783 .462 Mdot
.38793 .63813 Mdot
.52779 .77159 Mdot
.41566 .64612 Mdot
.55528 .46327 Mdot
.57366 .63912 Mdot
.35754 .63174 Mdot
.41369 .43311 Mdot
.60293 .54817 Mdot
.52177 .82176 Mdot
.59949 .63035 Mdot
.36737 .46082 Mdot
.62745 .47209 Mdot
.73584 .64568 Mdot
.87476 .55552 Mdot
.58465 .60463 Mdot
.65919 .54904 Mdot
.42216 .39332 Mdot
.38033 .60253 Mdot
.5677 .65078 Mdot
.56788 .61814 Mdot
.64954 .48744 Mdot
.4312 .43161 Mdot
.43338 .43495 Mdot
.64392 .51605 Mdot
.60229 .63596 Mdot
.42879 .36344 Mdot
.43556 .38012 Mdot
.3371 .81156 Mdot
.33729 .31972 Mdot
.1395 .4158 Mdot
.43916 .66369 Mdot
.20831 .51986 Mdot
.40579 .72732 Mdot
.36806 .66606 Mdot
.43982 .43042 Mdot
.42887 .47528 Mdot
.64262 .47143 Mdot
.39715 .4184 Mdot
.70005 .46555 Mdot
.58781 .60915 Mdot
.5893 .82495 Mdot
.57829 .74042 Mdot
.18115 .462 Mdot
.39926 .41688 Mdot
.60684 .71014 Mdot
.57332 .34598 Mdot
.54802 .61344 Mdot
.39157 .64699 Mdot
.36504 .39237 Mdot
.71864 .33652 Mdot
.68923 .47468 Mdot
.3834 .60894 Mdot
.77747 .42298 Mdot
.7575 .42208 Mdot
.38285 .37756 Mdot
.6547 .5141 Mdot
.46295 .77518 Mdot
.29622 .41431 Mdot
.5785 .67436 Mdot
.54183 .35275 Mdot
.68627 .47531 Mdot
.60114 .64847 Mdot
.34065 .70915 Mdot
.36126 .62429 Mdot
.40384 .58503 Mdot
.68232 .29079 Mdot
.6676 .43132 Mdot
.56842 .35106 Mdot
.73932 .66652 Mdot
.79227 .59808 Mdot
.54024 .34998 Mdot
.63347 .49716 Mdot
.35645 .62428 Mdot
.37708 .64832 Mdot
.3867 .62103 Mdot
.79502 .39905 Mdot
.34714 .62806 Mdot
.28336 .48292 Mdot
.45036 .38298 Mdot
.47832 .35792 Mdot
.43645 .39795 Mdot
.61628 .63952 Mdot
.39769 .65631 Mdot
.50232 .60868 Mdot
.34512 .4079 Mdot
.59162 .80632 Mdot
.41813 .38778 Mdot
.56301 .66343 Mdot
.37502 .40585 Mdot
.30412 .49167 Mdot
.3928 .67123 Mdot
.39712 .42557 Mdot
.6149 .6515 Mdot
.56845 .33257 Mdot
.44055 .61656 Mdot
.4372 .43299 Mdot
.46242 .73084 Mdot
.45145 .47163 Mdot
.18119 .56703 Mdot
.36393 .2765 Mdot
.58769 .31162 Mdot
.33933 .48188 Mdot
.68984 .43697 Mdot
.47624 .35427 Mdot
.36308 .35003 Mdot
.59781 .63179 Mdot
.6714 .72355 Mdot
.67613 .48093 Mdot
.51096 .31225 Mdot
.33858 .39114 Mdot
.56845 .36085 Mdot
.34155 .66133 Mdot
.60994 .65205 Mdot
.3553 .39957 Mdot
.35086 .3855 Mdot
.17979 .50118 Mdot
.40157 .34252 Mdot
.45401 .42351 Mdot
.55597 .31457 Mdot
.25459 .44051 Mdot
.38558 .41782 Mdot
.55297 .46377 Mdot
.40839 .58697 Mdot
.46317 .38517 Mdot
.2672 .41221 Mdot
.40575 .38546 Mdot
.38242 .6059 Mdot
.35373 .60361 Mdot
.53261 .75025 Mdot
.59127 .35363 Mdot
.43642 .45642 Mdot
.30187 .29847 Mdot
.39856 .44987 Mdot
.57699 .61899 Mdot
.40447 .37342 Mdot
.6826 .48514 Mdot
.78779 .39818 Mdot
.63856 .46617 Mdot
.44399 .41945 Mdot
.38143 .62361 Mdot
.57744 .65866 Mdot
.71578 .31491 Mdot
.64418 .31943 Mdot
.27531 .47273 Mdot
.1756 .41823 Mdot
.56478 .31654 Mdot
.54067 .35798 Mdot
.60513 .65737 Mdot
.39571 .4255 Mdot
.29212 .28969 Mdot
.47641 .44413 Mdot
.37977 .4109 Mdot
.414 .41415 Mdot
.7125 .68327 Mdot
.5976 .61581 Mdot
.65969 .49029 Mdot
.39104 .39886 Mdot
.39773 .38443 Mdot
.38015 .66806 Mdot
.56685 .33126 Mdot
.63699 .49191 Mdot
.55804 .33597 Mdot
.66811 .45613 Mdot
.58271 .8321 Mdot
.34704 .43785 Mdot
.56841 .33519 Mdot
.59996 .59539 Mdot
.4001 .61079 Mdot
.62817 .5694 Mdot
.64756 .49907 Mdot
.64757 .47453 Mdot
.4151 .38723 Mdot
.38568 .60429 Mdot
.41391 .61535 Mdot
.57971 .33527 Mdot
.56276 .61796 Mdot
.43731 .42636 Mdot
.35813 .41024 Mdot
.45749 .57543 Mdot
.68527 .44642 Mdot
.32998 .35247 Mdot
.50205 .7575 Mdot
.39798 .43011 Mdot
.40869 .61181 Mdot
.42068 .41205 Mdot
.30966 .72276 Mdot
.38796 .60087 Mdot
.42927 .38227 Mdot
.81336 .56913 Mdot
.59677 .51919 Mdot
.49025 .72141 Mdot
.45368 .43326 Mdot
.1431 .51052 Mdot
.38211 .4459 Mdot
.36162 .82105 Mdot
.69494 .34861 Mdot
.44102 .44047 Mdot
.37912 .43049 Mdot
.31115 .65371 Mdot
.43234 .40687 Mdot
.64243 .51905 Mdot
.50758 .31168 Mdot
.36162 .66838 Mdot
.44917 .69636 Mdot
.50376 .46739 Mdot
.59685 .34478 Mdot
.64672 .44192 Mdot
.6192 .52237 Mdot
.54439 .34724 Mdot
.37187 .63178 Mdot
.40665 .44537 Mdot
.49837 .57198 Mdot
.66763 .51803 Mdot
.42575 .35854 Mdot
.57454 .62498 Mdot
.71539 .57166 Mdot
.69444 .43221 Mdot
.58581 .63346 Mdot
.40776 .46731 Mdot
.31753 .65004 Mdot
.61084 .25239 Mdot
.22806 .69089 Mdot
.5794 .66115 Mdot
.60107 .64158 Mdot
.80755 .42317 Mdot
.59867 .34434 Mdot
.19348 .46156 Mdot
.49986 .67042 Mdot
.55985 .64709 Mdot
.31487 .3078 Mdot
.69195 .46507 Mdot
.4657 .72279 Mdot
.43254 .62937 Mdot
.42012 .36771 Mdot
.41294 .4303 Mdot
.5634 .61447 Mdot
.34027 .71251 Mdot
.58051 .18353 Mdot
.59331 .62965 Mdot
.49167 .41359 Mdot
.4983 .52495 Mdot
.68699 .65322 Mdot
.68186 .44645 Mdot
.59155 .35147 Mdot
.60635 .35843 Mdot
.37143 .66172 Mdot
.58783 .35214 Mdot
.79264 .54851 Mdot
.4116 .46147 Mdot
.59523 .63747 Mdot
.67418 .66973 Mdot
.58444 .64139 Mdot
.54679 .34887 Mdot
.59097 .31244 Mdot
.41309 .63252 Mdot
.40786 .62467 Mdot
.21573 .5358 Mdot
.4487 .28891 Mdot
.42808 .38821 Mdot
.54705 .80087 Mdot
.40726 .66184 Mdot
.31847 .44513 Mdot
.5469 .36074 Mdot
.56553 .33538 Mdot
.37156 .31789 Mdot
.4302 .44472 Mdot
.3145 .27354 Mdot
.4264 .44506 Mdot
.4567 .30264 Mdot
.39655 .47795 Mdot
.65097 .48757 Mdot
.43191 .44695 Mdot
.52167 .33383 Mdot
.36487 .37899 Mdot
.41107 .37655 Mdot
.69539 .4574 Mdot
.46479 .44394 Mdot
.68098 .48719 Mdot
.44583 .41506 Mdot
.57949 .36676 Mdot
.65956 .4392 Mdot
.46981 .23542 Mdot
.69063 .51295 Mdot
.62549 .4745 Mdot
.58696 .34751 Mdot
.59322 .32526 Mdot
.45923 .21525 Mdot
.39043 .64816 Mdot
.43558 .65521 Mdot
.39411 .4213 Mdot
.6964 .45133 Mdot
.59862 .61375 Mdot
.39163 .38551 Mdot
.43266 .47824 Mdot
.45723 .41602 Mdot
.36335 .65756 Mdot
.62826 .41319 Mdot
.57311 .33251 Mdot
.66209 .51466 Mdot
.59691 .41815 Mdot
.68936 .49276 Mdot
.36804 .35854 Mdot
.3688 .47881 Mdot
.21236 .56938 Mdot
.59667 .76826 Mdot
.8303 .46697 Mdot
.36572 .61803 Mdot
.64304 .43722 Mdot
.59684 .32977 Mdot
.39647 .50936 Mdot
.38662 .64405 Mdot
.67881 .49213 Mdot
.3999 .43542 Mdot
.36774 .46215 Mdot
.56502 .58662 Mdot
.46368 .34589 Mdot
.39689 .25264 Mdot
.69155 .48608 Mdot
.6994 .441 Mdot
.78997 .5977 Mdot
.50399 .31698 Mdot
.51994 .57332 Mdot
.40913 .40341 Mdot
.58742 .3265 Mdot
.35502 .6363 Mdot
.64112 .26353 Mdot
.58317 .60065 Mdot
.58331 .54457 Mdot
.39927 .41844 Mdot
.50228 .63337 Mdot
.38253 .62196 Mdot
.55915 .35794 Mdot
.56297 .61398 Mdot
.59196 .30881 Mdot
.66981 .43465 Mdot
.24112 .31552 Mdot
.40049 .45457 Mdot
.43125 .38768 Mdot
.58702 .59696 Mdot
.36342 .64934 Mdot
.55247 .31382 Mdot
.19769 .59065 Mdot
.6339 .47817 Mdot
.30269 .27313 Mdot
.41664 .61083 Mdot
.31281 .5217 Mdot
.66533 .51378 Mdot
.60924 .64165 Mdot
.47705 .21929 Mdot
.59264 .64889 Mdot
.44658 .42601 Mdot
.38555 .63208 Mdot
.5777 .61059 Mdot
.56774 .46948 Mdot
.38806 .81031 Mdot
.32965 .53947 Mdot
.42033 .4537 Mdot
.48223 .82731 Mdot
.24651 .6736 Mdot
.34736 .59241 Mdot
.56813 .60156 Mdot
.4089 .39437 Mdot
.39198 .47019 Mdot
.39754 .44538 Mdot
.56923 .63646 Mdot
.70608 .6275 Mdot
.65048 .49488 Mdot
.42896 .39324 Mdot
.59473 .34002 Mdot
.67685 .48987 Mdot
.68998 .66503 Mdot
.64688 .46588 Mdot
.4006 .67491 Mdot
.40912 .37298 Mdot
.63207 .60408 Mdot
.46139 .85048 Mdot
.5998 .62514 Mdot
.62533 .47629 Mdot
.38869 .38047 Mdot
.67195 .70716 Mdot
.39306 .63914 Mdot
.63422 .47414 Mdot
.39933 .39978 Mdot
.67988 .62309 Mdot
.70718 .32615 Mdot
.64744 .46742 Mdot
.38066 .65134 Mdot
.36096 .74541 Mdot
.39551 .41425 Mdot
.38567 .45 Mdot
.36426 .64555 Mdot
.50316 .45712 Mdot
.78518 .42591 Mdot
.42292 .41677 Mdot
.58574 .62694 Mdot
.32015 .2229 Mdot
.46072 .40942 Mdot
.391 .30757 Mdot
.68435 .46555 Mdot
.48804 .74336 Mdot
.32479 .35732 Mdot
.33938 .47725 Mdot
.32026 .70921 Mdot
.5186 .47118 Mdot
.56616 .82865 Mdot
.69941 .4512 Mdot
.72428 .39087 Mdot
.5607 .83537 Mdot
.6024 .66317 Mdot
.36206 .70098 Mdot
.44604 .59063 Mdot
.78239 .36245 Mdot
.38201 .74916 Mdot
.69579 .399 Mdot
.7326 .34687 Mdot
.48946 .55354 Mdot
.66181 .45792 Mdot
.511 .35342 Mdot
.43354 .42689 Mdot
.24216 .67009 Mdot
.28995 .42273 Mdot
.54784 .16547 Mdot
.47034 .82554 Mdot
.3072 .29754 Mdot
.46274 .81296 Mdot
.34006 .77508 Mdot
.20099 .54839 Mdot
.578 .77439 Mdot
.32884 .23405 Mdot
.80887 .56453 Mdot
.24497 .34729 Mdot
.35686 .47744 Mdot
.55725 .42613 Mdot
.16125 .50005 Mdot
.29242 .51628 Mdot
.4736 .17695 Mdot
.6386 .47562 Mdot
.42698 .62539 Mdot
.45187 .59535 Mdot
.35249 .67126 Mdot
.54748 .58291 Mdot
.33713 .74076 Mdot
.34221 .80014 Mdot
.29667 .47731 Mdot
.13937 .51985 Mdot
.22069 .46748 Mdot
.77433 .28187 Mdot
.73767 .45495 Mdot
.39732 .58874 Mdot
.59966 .38959 Mdot
.7822 .61582 Mdot
.56413 .72591 Mdot
.44544 .6583 Mdot
.72742 .64503 Mdot
.48572 .25682 Mdot
.37495 .63523 Mdot
.30297 .3967 Mdot
.72635 .50683 Mdot
.59783 .73185 Mdot
.60292 .27313 Mdot
.34729 .7662 Mdot
.51941 .55694 Mdot
.45688 .71806 Mdot
.70605 .55664 Mdot
.86898 .53688 Mdot
.38044 .28705 Mdot
.2783 .68534 Mdot
.57969 .57207 Mdot
.35339 .73187 Mdot
.74673 .31798 Mdot
.47482 .28553 Mdot
.78555 .61133 Mdot
.73656 .70582 Mdot
.22235 .65737 Mdot
.75871 .70424 Mdot
.43711 .65163 Mdot
.45514 .42323 Mdot
.27612 .65608 Mdot
.28997 .33663 Mdot
.56983 .37232 Mdot
.63683 .77323 Mdot
.5771 .31745 Mdot
.38518 .68401 Mdot
.78225 .39847 Mdot
.2901 .48132 Mdot
.3134 .268 Mdot
.54976 .31317 Mdot
.4333 .46956 Mdot
.48767 .11321 Mdot
.55724 .82722 Mdot
.52677 .74618 Mdot
.33901 .81363 Mdot
.51658 .64554 Mdot
.34572 .27513 Mdot
.5747 .61417 Mdot
.52033 .8491 Mdot
.37906 .64323 Mdot
.6712 .80753 Mdot
.4404 .83645 Mdot
.57271 .19286 Mdot
.23538 .24235 Mdot
.77871 .5816 Mdot
.48469 .59743 Mdot
.5 .4861 Mdot
.43649 .24761 Mdot
.63117 .21774 Mdot
.52854 .1822 Mdot
.66979 .70031 Mdot
.17011 .45217 Mdot
.52399 .84386 Mdot
.28944 .32363 Mdot
.24144 .32729 Mdot
.77508 .35031 Mdot
.54148 .46176 Mdot
.37451 .69018 Mdot
.69365 .52429 Mdot
.42041 .7841 Mdot
.68315 .76312 Mdot
.37452 .30376 Mdot
.27158 .2324 Mdot
.52414 .33472 Mdot
.68778 .35156 Mdot
.28105 .72273 Mdot
.4995 .24125 Mdot
.32653 .31197 Mdot
.80509 .45598 Mdot
.39915 .35566 Mdot
.81525 .48784 Mdot
.48782 .80085 Mdot
.64183 .5589 Mdot
.81 .54925 Mdot
.44188 .75837 Mdot
.1813 .53377 Mdot
.28481 .63037 Mdot
.77853 .62774 Mdot
.37186 .67669 Mdot
.46009 .27321 Mdot
.34715 .29313 Mdot
.32969 .80381 Mdot
.66133 .54791 Mdot
.26807 .76525 Mdot
.77045 .40479 Mdot
.39297 .48088 Mdot
.36034 .34876 Mdot
.48146 .45611 Mdot
.43528 .28068 Mdot
.45496 .39413 Mdot
.61814 .70887 Mdot
.31467 .78532 Mdot
.21243 .46484 Mdot
.64438 .56787 Mdot
.67313 .72646 Mdot
.23191 .69568 Mdot
.23161 .60392 Mdot
.71715 .34753 Mdot
.45277 .32071 Mdot
.83855 .43214 Mdot
.67213 .48679 Mdot
.2864 .32419 Mdot
.58141 .67189 Mdot
.64827 .27725 Mdot
.33499 .58075 Mdot
.61556 .2209 Mdot
.31362 .78458 Mdot
.77795 .44646 Mdot
.75643 .37524 Mdot
.51913 .22379 Mdot
.29603 .26794 Mdot
.66447 .74149 Mdot
.33577 .41658 Mdot
.42502 .69641 Mdot
.57158 .31309 Mdot
.23665 .57146 Mdot
.26466 .34839 Mdot
.65116 .36636 Mdot
.47355 .4296 Mdot
.58933 .23844 Mdot
.65257 .40717 Mdot
.59801 .54881 Mdot
.80905 .66953 Mdot
.40993 .35031 Mdot
.74844 .6412 Mdot
.20098 .62668 Mdot
.41333 .2683 Mdot
.28199 .71599 Mdot
.43517 .73298 Mdot
.7477 .70975 Mdot
.40972 .82879 Mdot
.64332 .33803 Mdot
.6107 .80641 Mdot
.32225 .80716 Mdot
.77491 .67613 Mdot
.41415 .33992 Mdot
.62273 .62106 Mdot
.83466 .67245 Mdot
.65705 .5207 Mdot
.71309 .7014 Mdot
.24054 .38937 Mdot
.68549 .61537 Mdot
.43475 .59689 Mdot
.38128 .49207 Mdot
.49525 .5576 Mdot
.33351 .61895 Mdot
.46646 .42545 Mdot
.83545 .60838 Mdot
.76424 .67431 Mdot
.80135 .65917 Mdot
.17127 .57379 Mdot
.60998 .81057 Mdot
.46519 .55954 Mdot
.29442 .50464 Mdot
.42582 .54809 Mdot
.38399 .3745 Mdot
.55331 .28899 Mdot
.7784 .57852 Mdot
.60957 .24126 Mdot
.54786 .71608 Mdot
.36219 .67726 Mdot
.58448 .79501 Mdot
.89371 .41505 Mdot
.22323 .48852 Mdot
.26393 .39464 Mdot
.79417 .57175 Mdot
.42881 .28712 Mdot
.44802 .79259 Mdot
.58526 .21077 Mdot
.30367 .76401 Mdot
.41573 .5523 Mdot
.23794 .3718 Mdot
.6682 .3879 Mdot
.38527 .22686 Mdot
.66076 .4012 Mdot
.37303 .79447 Mdot
.45673 .52245 Mdot
.67698 .27016 Mdot
.47881 .64711 Mdot
.5756 .1882 Mdot
.6663 .31148 Mdot
.72147 .56735 Mdot
.26789 .33034 Mdot
.65823 .69021 Mdot
.41852 .29559 Mdot
.50819 .53051 Mdot
.41877 .50987 Mdot
.51736 .47264 Mdot
.40489 .29492 Mdot
.40251 .2228 Mdot
.66899 .76999 Mdot
.33037 .8246 Mdot
.85612 .52239 Mdot
.14039 .53498 Mdot
.48569 .79557 Mdot
.42213 .36618 Mdot
.26798 .72576 Mdot
.76474 .70932 Mdot
.41207 .83597 Mdot
.76186 .48754 Mdot
.5967 .5077 Mdot
.55805 .60155 Mdot
.84891 .5397 Mdot
.68272 .40399 Mdot
.316 .75064 Mdot
.8231 .49099 Mdot
.62136 .60051 Mdot
.74978 .29229 Mdot
.75804 .67388 Mdot
.349 .56083 Mdot
.4004 .33043 Mdot
.40082 .36004 Mdot
.30488 .48021 Mdot
.40226 .67103 Mdot
.69311 .55483 Mdot
.45873 .28496 Mdot
.6682 .47751 Mdot
.58643 .27874 Mdot
.43482 .6806 Mdot
.45862 .46355 Mdot
.51085 .46471 Mdot
.42842 .62841 Mdot
.59381 .76874 Mdot
.6497 .63156 Mdot
.65148 .79964 Mdot
.77374 .56589 Mdot
.47779 .41076 Mdot
.40589 .27314 Mdot
.75391 .44738 Mdot
.80306 .44252 Mdot
.57543 .66656 Mdot
.44824 .82372 Mdot
.55983 .44674 Mdot
.45782 .2752 Mdot
.30302 .47045 Mdot
.18811 .54442 Mdot
.37175 .48216 Mdot
.51642 .76332 Mdot
.28014 .58386 Mdot
.58836 .54198 Mdot
.37577 .68884 Mdot
.36937 .69125 Mdot
.19969 .67378 Mdot
.79477 .51332 Mdot
.70165 .56595 Mdot
.4351 .82002 Mdot
.57702 .64872 Mdot
.41535 .64096 Mdot
.5368 .29959 Mdot
.1816 .54831 Mdot
.29245 .55986 Mdot
.70858 .32693 Mdot
.74316 .6044 Mdot
.66494 .36042 Mdot
.45333 .81693 Mdot
.47734 .8215 Mdot
.53532 .15808 Mdot
.34334 .65345 Mdot
.20391 .58445 Mdot
.19357 .43665 Mdot
.42059 .65217 Mdot
.42112 .57349 Mdot
.58059 .719 Mdot
.66555 .7814 Mdot
.63557 .64726 Mdot
.16403 .45809 Mdot
.41223 .2316 Mdot
.69071 .62873 Mdot
.72122 .3203 Mdot
.27039 .31802 Mdot
.42214 .8157 Mdot
.29902 .42369 Mdot
.35647 .56758 Mdot
.42617 .48883 Mdot
.47032 .3467 Mdot
.8665 .48417 Mdot
.69517 .50472 Mdot
.31309 .51735 Mdot
.43131 .75151 Mdot
.40658 .45206 Mdot
.86415 .54497 Mdot
.22344 .63962 Mdot
.81196 .43008 Mdot
.58653 .58923 Mdot
.37608 .4483 Mdot
.3739 .37396 Mdot
.43302 .31945 Mdot
.51021 .74842 Mdot
.72065 .70819 Mdot
.26666 .32189 Mdot
.44147 .77544 Mdot
.29112 .42673 Mdot
.74581 .64421 Mdot
.33904 .75618 Mdot
.25964 .6854 Mdot
.55817 .51954 Mdot
.77935 .56643 Mdot
.49691 .22629 Mdot
.14615 .53409 Mdot
.57668 .41483 Mdot
.46265 .57252 Mdot
.56028 .70109 Mdot
.47174 .75052 Mdot
.67852 .28109 Mdot
.36333 .40109 Mdot
.77764 .42315 Mdot
.339 .77145 Mdot
.44771 .16954 Mdot
.67863 .25118 Mdot
.85936 .56024 Mdot
.30279 .59736 Mdot
.45452 .74391 Mdot
.33134 .71571 Mdot
.40551 .16939 Mdot
.56483 .41664 Mdot
.56799 .81245 Mdot
.50378 .22357 Mdot
.44414 .81863 Mdot
.62207 .63899 Mdot
.49061 .64999 Mdot
.6772 .72398 Mdot
.64243 .79147 Mdot
.24954 .62047 Mdot
.36881 .78608 Mdot
.49598 .61314 Mdot
.71961 .7545 Mdot
.64464 .71491 Mdot
.48448 .54436 Mdot
.64408 .43874 Mdot
.79009 .46095 Mdot
.46302 .80618 Mdot
.54835 .78797 Mdot
.26852 .33575 Mdot
.70872 .45612 Mdot
.51683 .3106 Mdot
.35447 .53789 Mdot
.53072 .25275 Mdot
.47001 .75976 Mdot
.40649 .2726 Mdot
.34661 .79076 Mdot
.58854 .40429 Mdot
.76054 .39407 Mdot
.74315 .64376 Mdot
.22404 .34163 Mdot
.51594 .74557 Mdot
.79648 .5022 Mdot
.28059 .69286 Mdot
.67516 .3327 Mdot
.32304 .29439 Mdot
.38462 .88692 Mdot
.21612 .38093 Mdot
.61281 .74937 Mdot
.68433 .76168 Mdot
.27306 .70892 Mdot
.60801 .75964 Mdot
.6436 .22209 Mdot
.3355 .32278 Mdot
.51944 .29339 Mdot
.41342 .41572 Mdot
.80201 .67338 Mdot
.50292 .26235 Mdot
.69798 .75779 Mdot
.25105 .71424 Mdot
.3143 .49301 Mdot
.45894 .46233 Mdot
.67828 .50161 Mdot
.70472 .52783 Mdot
.55092 .25986 Mdot
.32732 .60961 Mdot
.31083 .33346 Mdot
.75737 .58332 Mdot
.66159 .43322 Mdot
.66621 .39992 Mdot
.38204 .56923 Mdot
.77206 .54055 Mdot
.49293 .75687 Mdot
.59264 .29782 Mdot
.54601 .54558 Mdot
.40904 .29005 Mdot
.31721 .36379 Mdot
.34477 .56294 Mdot
.62385 .2267 Mdot
.5385 .47895 Mdot
.64612 .46237 Mdot
.31533 .60778 Mdot
.17562 .44878 Mdot
.46899 .77255 Mdot
.73096 .7156 Mdot
.79232 .44664 Mdot
.4257 .52566 Mdot
.40805 .29875 Mdot
.61372 .21123 Mdot
.36422 .22536 Mdot
.60156 .77613 Mdot
.32181 .38443 Mdot
.3258 .27104 Mdot
.45334 .65918 Mdot
.57728 .83246 Mdot
.24328 .3524 Mdot
.22316 .40366 Mdot
.72189 .49208 Mdot
.28554 .52306 Mdot
.33058 .50756 Mdot
.46584 .23052 Mdot
.54181 .56135 Mdot
.78737 .29991 Mdot
.43114 .61499 Mdot
.88299 .49092 Mdot
.60343 .61166 Mdot
.79163 .36062 Mdot
.49159 .21505 Mdot
.50863 .52667 Mdot
.5302 .57227 Mdot
.52759 .76141 Mdot
.51176 .68401 Mdot
.15673 .5337 Mdot
.51922 .16986 Mdot
.69035 .492 Mdot
.26996 .30288 Mdot
.23594 .31364 Mdot
.31234 .63972 Mdot
.4458 .45757 Mdot
.21256 .3828 Mdot
.70298 .47248 Mdot
.61168 .24118 Mdot
.25757 .70588 Mdot
.5246 .78301 Mdot
.48954 .38681 Mdot
.43626 .28637 Mdot
.55823 .81389 Mdot
.40728 .82357 Mdot
.70352 .25562 Mdot
.48817 .80054 Mdot
.62167 .61797 Mdot
.47264 .55126 Mdot
.39099 .78945 Mdot
.36615 .26359 Mdot
.46246 .70082 Mdot
.33962 .2938 Mdot
.85787 .40492 Mdot
.70132 .72013 Mdot
.71978 .70833 Mdot
.35845 .27611 Mdot
.35057 .61669 Mdot
.62803 .72066 Mdot
.33013 .30843 Mdot
.5358 .77702 Mdot
.16545 .51487 Mdot
.34082 .2978 Mdot
.5099 .14352 Mdot
.19875 .48838 Mdot
.60584 .41357 Mdot
.33763 .51099 Mdot
.20393 .48984 Mdot
.60913 .59287 Mdot
.54389 .28227 Mdot
.4302 .75636 Mdot
.58643 .59546 Mdot
.47644 .76127 Mdot
.46764 .73133 Mdot
.20698 .43922 Mdot
.30254 .55983 Mdot
.45517 .78197 Mdot
.30062 .66048 Mdot
.33956 .69632 Mdot
.64414 .26597 Mdot
.6447 .42391 Mdot
.41051 .75313 Mdot
.63248 .46117 Mdot
.32873 .45732 Mdot
.57993 .53333 Mdot
.48232 .47493 Mdot
.85077 .51821 Mdot
.56973 .31448 Mdot
.38329 .5939 Mdot
.80488 .36626 Mdot
.42496 .63351 Mdot
.82335 .63388 Mdot
.59913 .21729 Mdot
.29802 .46171 Mdot
.64924 .33089 Mdot
.63316 .3866 Mdot
.64721 .18344 Mdot
.38731 .55348 Mdot
.72358 .49452 Mdot
.33766 .6837 Mdot
.36223 .60908 Mdot
.75364 .61646 Mdot
.6718 .43883 Mdot
.36428 .32742 Mdot
.56024 .68988 Mdot
.42675 .53773 Mdot
.34013 .62275 Mdot
.56554 .48194 Mdot
.48385 .31531 Mdot
.65725 .78783 Mdot
.65608 .45479 Mdot
.83687 .39007 Mdot
.40719 .487 Mdot
.27128 .61714 Mdot
.29668 .76172 Mdot
.72926 .27483 Mdot
.63326 .5234 Mdot
.25033 .2786 Mdot
.38531 .47553 Mdot
.45934 .78707 Mdot
.37326 .64155 Mdot
.23097 .38907 Mdot
.55548 .3266 Mdot
.42088 .26032 Mdot
.55247 .61037 Mdot
.67956 .27296 Mdot
.76648 .54109 Mdot
.34752 .61709 Mdot
.52014 .79429 Mdot
.19689 .55614 Mdot
.48496 .67297 Mdot
.6286 .40449 Mdot
.31762 .6199 Mdot
.2979 .5542 Mdot
.34226 .61879 Mdot
.70205 .73131 Mdot
.23108 .37848 Mdot
.54672 .8536 Mdot
.47996 .45656 Mdot
.74155 .4109 Mdot
.53966 .68668 Mdot
.49373 .76709 Mdot
.36311 .33709 Mdot
.31071 .7746 Mdot
.47076 .27942 Mdot
.57891 .70284 Mdot
.44873 .29922 Mdot
.35832 .48822 Mdot
.53545 .54146 Mdot
.72319 .53927 Mdot
.58008 .16792 Mdot
.42187 .32638 Mdot
.74825 .31163 Mdot
.32024 .39347 Mdot
.75758 .62861 Mdot
.38913 .57671 Mdot
.59679 .48785 Mdot
.29517 .52653 Mdot
.66573 .54712 Mdot
.5608 .83964 Mdot
.3072 .77057 Mdot
.58291 .58086 Mdot
.74252 .62905 Mdot
.37879 .73143 Mdot
.47338 .46067 Mdot
.49504 .62406 Mdot
.45182 .42458 Mdot
.4035 .57297 Mdot
.74899 .28693 Mdot
.52694 .77223 Mdot
.33369 .40458 Mdot
.56378 .83068 Mdot
.51028 .84818 Mdot
.7122 .75753 Mdot
.29974 .2722 Mdot
.36329 .66328 Mdot
.7948 .65738 Mdot
.30282 .36108 Mdot
.35876 .80708 Mdot
.58959 .7804 Mdot
.21404 .69081 Mdot
.34324 .58204 Mdot
.42804 .74271 Mdot
.53305 .17723 Mdot
.49897 .69777 Mdot
.24075 .6771 Mdot
.48572 .51847 Mdot
.68361 .57829 Mdot
.24026 .68332 Mdot
.53703 .12533 Mdot
.33764 .35774 Mdot
.45892 .72565 Mdot
.46626 .62481 Mdot
.41745 .75515 Mdot
.71092 .35673 Mdot
.40336 .37349 Mdot
.68003 .67673 Mdot
.73727 .34159 Mdot
.39359 .29063 Mdot
.51819 .30975 Mdot
.70876 .35627 Mdot
.56354 .26731 Mdot
.46751 .30641 Mdot
.24498 .34615 Mdot
.33353 .59095 Mdot
.3688 .32855 Mdot
.39073 .48165 Mdot
.40057 .57618 Mdot
.57972 .36203 Mdot
.60852 .4761 Mdot
.44812 .41412 Mdot
.63804 .53204 Mdot
.49404 .68013 Mdot
.85088 .57806 Mdot
.63931 .57058 Mdot
.20183 .60809 Mdot
.43203 .62977 Mdot
.51314 .75371 Mdot
.29981 .68889 Mdot
.78359 .37692 Mdot
.7118 .38699 Mdot
.37439 .30367 Mdot
.52954 .83165 Mdot
.8087 .55213 Mdot
.18337 .50723 Mdot
.81275 .58497 Mdot
.60913 .60113 Mdot
.46289 .35963 Mdot
.46592 .60428 Mdot
.77151 .46647 Mdot
.35887 .683 Mdot
.4328 .74479 Mdot
.72772 .46435 Mdot
.80332 .52373 Mdot
.20362 .63222 Mdot
.19228 .54806 Mdot
.37042 .53996 Mdot
.48793 .82534 Mdot
.6887 .46102 Mdot
.22083 .39406 Mdot
.45708 .69596 Mdot
.72257 .40113 Mdot
.7481 .66171 Mdot
.6261 .81201 Mdot
.50492 .60672 Mdot
.48073 .25021 Mdot
.39129 .44967 Mdot
.26321 .41984 Mdot
.5347 .76762 Mdot
.51286 .38586 Mdot
.75024 .563 Mdot
.40172 .60726 Mdot
.73994 .55157 Mdot
.56058 .40508 Mdot
.52177 .28797 Mdot
.33294 .63613 Mdot
.29113 .34037 Mdot
.54905 .36894 Mdot
.54676 .67629 Mdot
.46421 .4138 Mdot
.46157 .25193 Mdot
.31372 .26436 Mdot
.45783 .36003 Mdot
.4554 .79898 Mdot
.32468 .5986 Mdot
.17727 .52218 Mdot
.48868 .77894 Mdot
.6112 .77185 Mdot
.51413 .69001 Mdot
.30941 .53387 Mdot
.75692 .4665 Mdot
.45722 .41819 Mdot
.59847 .49614 Mdot
.41877 .62725 Mdot
.33958 .73775 Mdot
.29824 .59403 Mdot
.47343 .23599 Mdot
.52597 .51201 Mdot
.29366 .67921 Mdot
.52191 .49613 Mdot
.27953 .73752 Mdot
.50049 .69896 Mdot
.46329 .28551 Mdot
.61695 .65856 Mdot
.48919 .21701 Mdot
.63494 .22462 Mdot
.4745 .83973 Mdot
.59477 .204 Mdot
.49997 .58038 Mdot
.7495 .30801 Mdot
.62109 .7362 Mdot
.2477 .70009 Mdot
.47215 .29292 Mdot
.5111 .59956 Mdot
.51914 .31788 Mdot
.58169 .57812 Mdot
.55008 .48998 Mdot
.58811 .46552 Mdot
.32989 .33959 Mdot
.72116 .60011 Mdot
.73813 .49777 Mdot
.40099 .49483 Mdot
.7138 .69049 Mdot
.51225 .83006 Mdot
.23587 .39037 Mdot
.5255 .47415 Mdot
.63193 .28093 Mdot
.51973 .28317 Mdot
.12373 .52963 Mdot
.87075 .53423 Mdot
.39298 .45127 Mdot
.52717 .4651 Mdot
.45478 .26382 Mdot
.68254 .50205 Mdot
.31672 .33965 Mdot
.31466 .69082 Mdot
.60892 .63019 Mdot
.58676 .48845 Mdot
.80501 .50877 Mdot
.53838 .75946 Mdot
.52717 .2423 Mdot
.69491 .69114 Mdot
.84954 .5894 Mdot
.15974 .48541 Mdot
.50701 .76956 Mdot
.14101 .59373 Mdot
.74332 .50892 Mdot
.39139 .69162 Mdot
.2747 .65988 Mdot
.67285 .76973 Mdot
.40307 .26962 Mdot
.67634 .2884 Mdot
.64266 .75522 Mdot
.47351 .28445 Mdot
.31723 .31059 Mdot
.74602 .64009 Mdot
.74409 .55358 Mdot
.50432 .54599 Mdot
.6345 .38696 Mdot
.78862 .6309 Mdot
.29681 .43786 Mdot
.53019 .82304 Mdot
.7381 .33924 Mdot
.48143 .14121 Mdot
.52276 .84963 Mdot
.56558 .2837 Mdot
.71153 .34983 Mdot
.26906 .65304 Mdot
.3913 .24368 Mdot
.30604 .32799 Mdot
.63569 .24698 Mdot
.28242 .55597 Mdot
.62558 .37388 Mdot
.74758 .32798 Mdot
.41657 .29559 Mdot
.20633 .4788 Mdot
.51227 .59616 Mdot
.32971 .57851 Mdot
.76194 .59369 Mdot
.36699 .27875 Mdot
.57178 .46111 Mdot
.42378 .23817 Mdot
.31405 .61701 Mdot
.2918 .69711 Mdot
.428 .71959 Mdot
.56787 .1384 Mdot
.6093 .78147 Mdot
.77998 .37019 Mdot
.45292 .3864 Mdot
.58916 .83565 Mdot
.44097 .71304 Mdot
.63433 .76385 Mdot
.18152 .57906 Mdot
.60068 .44859 Mdot
.51562 .66198 Mdot
.45692 .41604 Mdot
.52716 .80623 Mdot
.31684 .51908 Mdot
.20448 .50654 Mdot
.69901 .29252 Mdot
.41677 .27375 Mdot
.72416 .35117 Mdot
.45138 .22661 Mdot
.48083 .38564 Mdot
.41424 .60639 Mdot
.79432 .67096 Mdot
.49244 .59593 Mdot
.32337 .43908 Mdot
.49481 .37009 Mdot
.54461 .17681 Mdot
.17774 .40299 Mdot
.48394 .44849 Mdot
.80144 .57572 Mdot
.30183 .31429 Mdot
.41249 .5212 Mdot
.30884 .40626 Mdot
.13572 .35329 Mdot
.33665 .82153 Mdot
.35144 .65767 Mdot
.26749 .36796 Mdot
.31209 .28643 Mdot
.66527 .77509 Mdot
.67082 .38667 Mdot
.62362 .43944 Mdot
.46814 .18334 Mdot
.36936 .2488 Mdot
.40634 .48259 Mdot
.19308 .61276 Mdot
.45719 .83603 Mdot
.7123 .30106 Mdot
.5529 .83496 Mdot
.327 .39635 Mdot
.33864 .40849 Mdot
.11761 .42725 Mdot
.39901 .79691 Mdot
.39788 .35689 Mdot
.54656 .17428 Mdot
.37817 .69044 Mdot
.42474 .42713 Mdot
.70271 .68383 Mdot
.26429 .33136 Mdot
.41628 .29747 Mdot
.64409 .79062 Mdot
.34169 .65943 Mdot
.65731 .54408 Mdot
.6104 .63567 Mdot
.5343 .56782 Mdot
.35988 .45707 Mdot
.56727 .6296 Mdot
.42631 .51475 Mdot
.41245 .74474 Mdot
.60709 .58882 Mdot
.24978 .32102 Mdot
.25111 .74371 Mdot
.31248 .58306 Mdot
.54157 .61335 Mdot
.46477 .47707 Mdot
.19886 .49515 Mdot
.55457 .2624 Mdot
.43844 .55334 Mdot
.23337 .68338 Mdot
.49482 .89787 Mdot
.69212 .58149 Mdot
.48906 .33527 Mdot
.33239 .63953 Mdot
.36351 .33211 Mdot
.34841 .54616 Mdot
.59531 .68388 Mdot
.68276 .45667 Mdot
.47422 .44783 Mdot
.48065 .38774 Mdot
.55983 .60315 Mdot
.87608 .48142 Mdot
.38582 .37964 Mdot
.31128 .3894 Mdot
.36435 .80714 Mdot
.64681 .26704 Mdot
.2589 .60765 Mdot
.3536 .42203 Mdot
.61525 .71816 Mdot
.51066 .60167 Mdot
.38549 .76133 Mdot
.76137 .39848 Mdot
.60293 .80584 Mdot
.29578 .59331 Mdot
.34987 .52076 Mdot
.4036 .38345 Mdot
.59557 .35513 Mdot
.46861 .71785 Mdot
.66043 .75388 Mdot
.33675 .37133 Mdot
.38825 .8235 Mdot
.60181 .44183 Mdot
.73235 .60952 Mdot
.39845 .52449 Mdot
.73423 .72886 Mdot
.72166 .28886 Mdot
.32917 .51802 Mdot
.80674 .40722 Mdot
.78423 .49047 Mdot
.5278 .25334 Mdot
.68411 .49269 Mdot
.33268 .43915 Mdot
.33959 .65374 Mdot
.85078 .59875 Mdot
.66659 .7497 Mdot
.66351 .64751 Mdot
.72165 .57037 Mdot
.27231 .45487 Mdot
.46761 .66923 Mdot
.18939 .67069 Mdot
.69639 .40346 Mdot
.85488 .57804 Mdot
.22234 .40118 Mdot
.36177 .5766 Mdot
.45191 .7503 Mdot
.42674 .3475 Mdot
.65021 .46566 Mdot
.64321 .78327 Mdot
.47851 .39012 Mdot
.77349 .38835 Mdot
.36435 .44472 Mdot
.81534 .44595 Mdot
.5978 .52743 Mdot
.72573 .65614 Mdot
.66099 .68849 Mdot
.6459 .22498 Mdot
.31954 .74044 Mdot
.63198 .59651 Mdot
.15774 .61151 Mdot
.34835 .74399 Mdot
.44938 .82471 Mdot
.69963 .31933 Mdot
.68413 .23053 Mdot
.5583 .78697 Mdot
.4595 .77993 Mdot
.65334 .62805 Mdot
.48264 .49434 Mdot
.78533 .45654 Mdot
.41865 .51551 Mdot
.48441 .718 Mdot
.59347 .57806 Mdot
.60731 .89713 Mdot
.54223 .30565 Mdot
.42596 .67967 Mdot
.76693 .44914 Mdot
.49065 .8334 Mdot
.50507 .43711 Mdot
.21089 .65036 Mdot
.55778 .42659 Mdot
.33678 .42381 Mdot
.29643 .57046 Mdot
.24385 .37855 Mdot
.79633 .46256 Mdot
.69406 .20727 Mdot
.16103 .48969 Mdot
.72467 .58803 Mdot
.55321 .53675 Mdot
.41835 .65486 Mdot
.43669 .60077 Mdot
.64837 .357 Mdot
.17648 .60952 Mdot
.42314 .7431 Mdot
.39202 .79046 Mdot
.63263 .17731 Mdot
.19191 .46487 Mdot
.66779 .77629 Mdot
.58965 .75892 Mdot
.42348 .59257 Mdot
.57528 .27895 Mdot
.61702 .31167 Mdot
.66977 .67928 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0Voooool2o`000:cooooo000Looooo`03o`000?oooooooooo09_o
oooo0_l0002/ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0Zoooool2o`0009cooooo000Loooo
o`03o`000?oooooooooo0:_ooooo0_l0002Looooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo09Kooooo0_l0002aooooo`007?ooool00ol0003ooooooooo
o`2Fooooo`;o00007Oooool2o`0009;ooooo000Looooo`03o`000?oooooooooo09Wooooo0_l0000@
ooooo`;o00002?ooool2o`0009;ooooo000Looooo`03o`000?oooooooooo09Wooooo0_l00007oooo
o`;o00001oooool2o`0009cooooo000Looooo`03o`000?oooooooooo0:;ooooo0_l0002Uooooo`00
7?ooool00ol0003oooooooooo`2aooooo`;o0000U_ooool001cooooo0_l0002Uooooo`;o00002?oo
ool2o`000003ooooool0003o000009Kooooo000Looooo`03o`000?oooooooooo0:Cooooo0_l00008
ooooo`;o00002_ooool2o`0008gooooo000Looooo`03o`000?oooooooooo0:[ooooo0_l0000;oooo
o`;o000000?oooooo`000?l00000SOooool001cooooo00?o0000ooooooooool0Z_ooool2o`0000_o
oooo0_l0002@ooooo`007?ooool00ol0003oooooooooo`2^ooooo`;o0000VOooool001cooooo00?o
0000ooooooooool0KOooool2o`0002cooooo0_l0000Aooooo`;o00002Oooool2o`0008kooooo000L
ooooo`03o`000?oooooooooo06gooooo0_l0000Aooooo`;o00003?ooool2o`0000;ooooo0_l00007
ooooo`;o00002?ooool2o`0001;ooooo0_l0002>ooooo`007?ooool00ol0003oooooooooo`20oooo
o`;o00003?ooool2o`0000;ooooo0_l0000Aooooo`;o00001oooool2o`0009Wooooo000Looooo`03
o`000?oooooooooo06[ooooo0_l0000Kooooo`;o00002oooool4o`0000Kooooo0_l00009ooooo`Oo
00002Oooool2o`0000oooooo0_l0001mooooo`007?ooool00ol0003oooooooooo`1Zooooo`;o0000
5oooool2o`0000;ooooo0_l0000;ooooo`Co00001_ooool2o`0000Wooooo1_l0000:ooooo`;o0000
3oooool2o`0007gooooo000Looooo`03o`000?oooooooooo08?ooooo0_l00006ooooo`;o00000_oo
ool2o`0000;ooooo0ol0000Booooo`;o00000_ooool2o`0000_ooooo0_l0000Booooo`?o0000NOoo
ool001cooooo00?o0000ooooooooool0LOooool2o`00013ooooo0_l00006ooooo`;o00000_ooool2
o`0000;ooooo0ol0000Booooo`;o00001_ooool2o`0000Oooooo0_l0000Booooo`?o0000NOooool0
01cooooo00?o0000ooooooooool0LOooool2o`000003ooooool0003o000001gooooo0_l0000Koooo
o`;o00001Oooool2o`0000;ooooo0_l000000ooooooo0000o`000029ooooo`0000Koooooonk^k_lb
<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0M?ooool2
o`00017ooooo0_l0000Mooooo`;o00003_ooool4o`000004ooooool0003o0000ooooo`;o000000?o
ooooo`000?l00000Q_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo
00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo06oooooo0_l0000Fooooo`;o
00007Oooool2o`0000kooooo1?l00007ooooo`;o0000Q_ooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo06oooooo
0_l0003Hooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ
8B7ok^k^00Kooooo0ol0001hooooo`;o00002?ooool2o`0000Gooooo0_l0002nooooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000
ooooooooool0N?ooool2o`0000Sooooo0_l00005ooooo`;o00003oooool2o`00027ooooo0_l0000H
ooooo`;o0000L?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool03Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo09;ooooo0_l000000ooooooo0000o`000003oooo
o`;o00008Oooool3o`0000;ooooo0_l0000Cooooo`;o00001Oooool2o`0006Wooooo00001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oo
oooooooo09;ooooo0_l000000ooooooo0000o`00000Sooooo`;o00000_ooool2o`0000;ooooo1?l0
0008ooooo`;o00003_ooool2o`0006Wooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo097ooooo0_l00009ooooo`;o
00007?ooool3o`0000Oooooo0_l00007ooooo`?o0000NOooool001cooooo00?o0000ooooooooool0
M?ooool2o`0000Oooooo0_l00009ooooo`;o00000oooool2o`0000;ooooo1?l00006ooooo`?o0000
7Oooool2o`0000;ooooo0_l00004ooooo`;o00000_ooool2o`0000;ooooo0_l0001jooooo`007?oo
ool00ol0003oooooooooo`1Rooooo`;o00004?ooool2o`0000Oooooo0_l00009ooooo`;o00000ooo
ool2o`0000;ooooo1Ol000000ooooooo0000o`000002ooooo`;o00008_ooool2o`0000?ooooo0ol0
0002ooooo`;o0000O_ooool001cooooo00?o0000ooooooooool0Foooool2o`0000Gooooo1?l0000E
ooooo`;o00000_ooool2o`0001?ooooo0_l000000ooooooo0000o`000007ooooo`;o00000oooool2
o`0001?ooooo1?l00006ooooo`;o00001?ooool5o`0007[ooooo000Looooo`03o`000?oooooooooo
05_ooooo0_l00007ooooo`;o00003Oooool2o`0000Cooooo1?l00002ooooo`;o00003_ooool2o`00
00Kooooo1?l000000ooooooo0000o`000004o`0000?ooooo0_l0000Cooooo`Co00002Oooool2o`00
0003ooooool0003o000000Co0000NOooool001cooooo00?o0000ooooooooool0Loooool2o`0000Co
oooo0_l00007ooooo`;o00002oooool2o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l0
00000_l0000Wooooo`;o00001Oooool3o`0000Wooooo0_l00009ooooo`;o0000H_ooool001cooooo
00?o0000ooooooooool0EOooool2o`0001Sooooo0_l00002ooooo`;o00003Oooool2o`000003oooo
ool0003o000000gooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Looooo`;o
00004?ooool2o`0000Oooooo1?l00009ooooo`;o0000H_ooool001cooooo00?o0000ooooooooool0
E?ooool3o`0000;ooooo0_l00008ooooo`;o00000_ooool2o`0000Kooooo0_l0000<ooooo`;o0000
0oooool2o`000003ooooool0003o000000;ooooo0_l0000:ooooo`?o000000?oooooo`000?l00000
1?ooool7o`0001Oooooo0_l00006ooooo`;o00004Oooool2o`0006oooooo000Looooo`03o`000?oo
oooooooo05Cooooo0_l00003ooooo`;o00002?ooool2o`0000;ooooo0_l0000Dooooo`;o000000?o
ooooo`000?l000000_l00002ooooo`;o000000?oooooo`000?l000002_ooool3o`0000Wooooo1Ol0
000Fooooo`;o00001oooool2o`0001?ooooo0_l0001]ooooo`007?ooool00ol0003oooooooooo`19
ooooo`;o00007?ooool2o`0000;ooooo0_l00007ooooo`?o00000oooool2o`0000Cooooo0_l00004
ooooo`;o00005_ooool2o`0000Oooooo0_l0000Cooooo`;o00001?ooool3o`0001Gooooo0_l0001]
ooooo`007?ooool00ol0003oooooooooo`19ooooo`;o000000?oooooo`000?l000006_ooool2o`00
0003ooooool0003o000000Oooooo0ol00003ooooo`?o00002Oooool2o`0000kooooo0_l00006oooo
o`;o00001_ooool5o`0000Gooooo0ol00003ooooo`;o00001Oooool2o`0000?ooooo0ol00004oooo
o`;o000000?oooooo`000?l000002_ooool2o`0006oooooo000Looooo`03o`000?oooooooooo04co
oooo0_l0000?ooooo`;o00002Oooool2o`0000;ooooo0_l00006ooooo`;o00001Oooool2o`0000Ko
oooo0_l00005ooooo`;o00002_ooool2o`0000Sooooo0_l00004ooooo`;o000000?oooooo`000?l0
00001Oooool3o`0000?ooooo0_l00005ooooo`;o00002_ooool5o`0000[ooooo0_l0001_ooooo`00
7?ooool2o`0005kooooo0_l00004ooooo`;o00001oooool5o`000003ooooool0003o000000;o0000
3Oooool2o`000003ooooool0003o000000;ooooo0_l00006ooooo`;o00001?ooool2o`0000Kooooo
0_l00009ooooo`;o00002?ooool2o`0000cooooo1?l00004ooooo`;o00001oooool2o`000003oooo
ool0003o000000;o0000K_ooool001cooooo00?o0000ooooooooool0E_ooool2o`0000_ooooo0_l0
0009ooooo`?o000000?oooooo`000?l000002Oooool5o`0000Cooooo0_l00005ooooo`;o00000ooo
ool2o`0000Cooooo0_l0000>ooooo`Ko00001oooool2o`0000cooooo1?l00007ooooo`;o00001?oo
ool2o`000003ooooool0003o000000Co0000K?ooool001cooooo00?o0000ooooooooool0E_ooool4
o`0000gooooo1?l0000Booooo`Go00001_ooool2o`0000?ooooo0_l00003ooooo`;o00001_ooool2
o`0000cooooo0ol000000ooooooo0000o`000002ooooo`;o00007?ooool2o`0000Wooooo1?l00004
ooooo`;o0000I_ooool001cooooo00?o0000ooooooooool0F?ooool2o`0000gooooo1?l0000Boooo
o`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000008ooooo`;o00001_ooool2o`00
01;ooooo1?l0000?ooooo`;o00001Oooool2o`0000Kooooo0_l000000ooooooo0000o`000008oooo
o`;o00000_ooool2o`0006Kooooo000Looooo`03o`000?oooooooooo06;ooooo0_l00004ooooo`;o
00002Oooool2o`0000Cooooo0_l00006ooooo`;o00000_ooool2o`0000Wooooo0_l00008ooooo`Co
00000_ooool2o`0000cooooo1?l0000<ooooo`;o000000?oooooo`000?l000001Oooool2o`0000;o
oooo0_l00002ooooo`;o000000?oooooo`000?l000002?ooool2o`0006[ooooo000Looooo`03o`00
0?oooooooooo06;ooooo0_l00004ooooo`;o00001_ooool2o`000003ooooool0003o000000Cooooo
0_l0000Eooooo`;o00002?ooool4o`0000;ooooo0_l0000>ooooo`;o000000?oooooo`000?l00000
0_ooool2o`0000Gooooo0_l0000<ooooo`Co00003_ooool2o`0000Gooooo0_l0000<ooooo`;o0000
E?ooool001cooooo00?o0000ooooooooool0Doooool2o`0000Oooooo0_l00004ooooo`;o00003?oo
ool2o`0000gooooo0_l00002ooooo`;o00000_ooool2o`0000Oooooo0_l0000:ooooo`;o000000?o
ooooo`000?l000004_ooool2o`0000;ooooo0_l0000Dooooo`?o00002?ooool2o`0000Cooooo1?l0
0003ooooo`;o00003?ooool2o`0005Cooooo000Looooo`03o`000?oooooooooo05?ooooo0_l00007
ooooo`Go000000?oooooo`000?l000000_ooool2o`0000Gooooo1Ol00005ooooo`;o00001_ooool7
o`000003ooooool0003o000000Oooooo1?l00006ooooo`Co000000?oooooo`000?l000000_l0000H
ooooo`;o00000oooool2o`00013ooooo0_l000001?oooooo0000o`000?ooool3o`0000Gooooo0_l0
00000ooooooo0000o`00001Tooooo`007?ooool00ol0003oooooooooo`1Nooooo`?o000000?ooooo
o`000?l000000_ooool2o`0000Gooooo1ol00003ooooo`;o00001oooool3o`000003ooooool0003o
000000_ooooo0ol00006ooooo`Co000000?oooooo`000?l000000_l00003ooooo`;o00004oooool2
o`0000?ooooo0_l0000@ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Sooooo0_l00004
ooooo`;o0000G_ooool001cooooo00?o0000ooooooooool0C_ooool2o`00017ooooo0_l00002oooo
o`;o00001_ooool2o`0000;ooooo1?l0000Looooo`;o00000_ooool2o`0000oooooo0_l0000?oooo
o`;o00000_ooool2o`000004ooooool0003o0000o`0000kooooo0_l0000Dooooo`;o00000_ooool2
o`0005kooooo000Looooo`03o`000?oooooooooo04gooooo0ol0000:ooooo`;o00001Oooool2o`00
00;ooooo0_l00008ooooo`;o00000_ooool2o`0001Gooooo0_l00004ooooo`Oo00003Oooool3o`00
00Kooooo0_l00008ooooo`;o00000_ooool2o`000004ooooool0003o0000o`0000Sooooo0_l00004
ooooo`;o00002?ooool2o`0000[ooooo0_l0000Aooooo`;o00001Oooool2o`0004Sooooo000Loooo
o`03o`000?oooooooooo04gooooo0_l000000ooooooo0000o`000005ooooo`;o000000?oooooo`00
0?l000001?ooool2o`0000[ooooo0_l000000ooooooo0000o`000005ooooo`;o00004?ooool4o`00
00Cooooo1Ol000000ooooooo0000o`00000:ooooo`Go00001_ooool2o`0000Gooooo0_l0000Boooo
o`?o00003_ooool2o`0000cooooo0_l0000?ooooo`;o00001Oooool2o`0004Sooooo000Looooo`03
o`000?oooooooooo04[ooooo0_l00004ooooo`;o00001Oooool2o`0000Oooooo1?l00008ooooo`?o
00001oooool4o`000003ooooool0003o000000[ooooo1Ol00002ooooo`Oo000000?oooooo`000?l0
00001Oooool2o`0000?ooooo0_l00002ooooo`;o00002?ooool3o`000003ooooool0003o000000Ko
oooo0_l00009ooooo`?o00003_ooool2o`0000gooooo0_l00002ooooo`;o00000_ooool2o`0005So
oooo000Looooo`03o`000?oooooooooo04Kooooo0_l00002ooooo`;o00002Oooool2o`0000Cooooo
0_l00004ooooo`?o00002Oooool2o`0000Gooooo0_l00002ooooo`;o000000Coooooo`000?l0003o
00000oooool2o`0000Cooooo1_l000000ooooooo0000o`000002o`0000Gooooo0_l00004ooooo`;o
00000oooool2o`0000;ooooo0_l00008ooooo`?o00001?ooool2o`0000?ooooo0_l00003ooooo`;o
00001?ooool2o`0000oooooo1?l0000;ooooo`;o00000_ooool2o`0000;ooooo0ol0001Gooooo`00
7?ooool00ol0003oooooooooo`16ooooo`;o00003Oooool8o`0000Sooooo0ol00003ooooo`Co0000
0_ooool2o`000003ooooool0003o000000Kooooo0_l00002ooooo`?o00002?ooool2o`0000Wooooo
0ol00003ooooo`;o00001?ooool2o`000003ooooool0003o0000013ooooo0_l00005ooooo`;o0000
00?oooooo`000?l000003Oooool2o`000003ooooool0003o000000Gooooo0_l00003ooooo`;o0000
3oooool2o`0005Oooooo000Looooo`03o`000?oooooooooo05Oooooo1?l00003ooooo`Co00000ooo
ool3o`0000?ooooo1?l00002ooooo`;o00001?ooool2o`0000Cooooo0_l000001?oooooo0000o`00
0?ooool3o`0000Kooooo0_l00008ooooo`?o00000oooool2o`0000Cooooo1Ol0000Fooooo`?o0000
00?oooooo`000?l000003Oooool2o`000003ooooool0003o000000[ooooo0_l00008ooooo`;o0000
G_ooool001cooooo0_l0001Eooooo`?o00001oooool4o`0000Cooooo0_l00003ooooo`;o00002_oo
ool2o`0000Cooooo0_l00002ooooo`Go000000?oooooo`000?l000000oooool4o`0000?ooooo0_l0
0002ooooo`;o00001?ooool2o`0000Gooooo0_l00005ooooo`;o00002_ooool2o`0000Cooooo0_l0
00000ooooooo0000o`000008ooooo`;o00005oooool3o`0000?ooooo1?l0000?ooooo`;o0000Booo
ool001cooooo00?o0000ooooooooool0E?ooool3o`0001oooooo0_l00009ooooo`;o00000_ooool4
o`0000Gooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l00003ooooo`;o00003?ooool2
o`0000Gooooo0_l00003ooooo`?o00001_ooool2o`0000Sooooo0_l0000Gooooo`?o00001Oooool2
o`0000Kooooo0_l00007ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0E?ooool2o`00
00gooooo0_l0000?ooooo`Co00000oooool4o`0000Kooooo0ol00009ooooo`;o000000?oooooo`00
0?l000000_ooool2o`0000gooooo0_l00003ooooo`;o00001?ooool2o`0000?ooooo0ol000000ooo
oooo0000o`000007ooooo`;o00006_ooool2o`00017ooooo0_l0001Dooooo`007?ooool00ol0003o
ooooooooo`1Sooooo`;o00000oooool2o`0000[ooooo0_l00003ooooo`Ko000000Coooooo`000?l0
003o00000oooool2o`0000Wooooo0_l000000ooooooo0000o`000002ooooo`;o00002_ooool5o`00
00?ooooo0_l00007ooooo`;o00001?ooool4o`0000Gooooo0ol0000Iooooo`;o00003_ooool2o`00
00[ooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00004Oooool2o`0000Go
oooo0_l000000ooooooo0000o`000002o`0000gooooo1?l00004ooooo`Co00003_ooool2o`0000Go
oooo0_l00007ooooo`Oo00001oooool4o`000003ooooool0003o000000;o00000_ooool5o`0000Ko
oooo0_l00006ooooo`;o00001_ooool2o`0000Sooooo0_l0000>ooooo`?o00002_ooool2o`0004_o
oooo000Looooo`03o`000?oooooooooo04Wooooo1?l0000?ooooo`Co00000oooool2o`000003oooo
ool0003o000000oooooo0_l00002ooooo`;o00000_ooool2o`00013ooooo0_l00003ooooo`Go0000
1Oooool4o`0000;ooooo0_l00002ooooo`?o00000_oooolCo`0000?ooooo0_l00006ooooo`;o0000
1_ooool2o`0000Gooooo1Ol000001?oooooo0000o`000?ooool2o`0000Sooooo0_l00004ooooo`;o
0000D_ooool001cooooo00?o0000ooooooooool0Boooool2o`0000Oooooo0_l00008ooooo`;o0000
0_ooool2o`0000Kooooo0_l00009ooooo`Co00000_ooool2o`0000cooooo0_l0000;ooooo`Go0000
1Oooool2o`0000?ooooo0ol00002ooooo`?o000000?oooooo`000?l000004_l0000;ooooo`;o0000
3Oooool5o`000004ooooool0003o0000ooooo`;o00002?ooool2o`0000Cooooo0_l0001Booooo`00
7?ooool00ol0003oooooooooo`1=ooooo`;o00001?ooool3o`0000Oooooo0_l00003ooooo`;o0000
1Oooool3o`0000Wooooo0_l0000<ooooo`;o00001?ooool2o`0000Cooooo0_l00005ooooo`;o0000
3Oooool5o`0000;ooooo5?l0000=ooooo`;o00002oooool2o`0000?ooooo0_l00005ooooo`;o0000
1oooool2o`0005Sooooo000Looooo`03o`000?oooooooooo04gooooo0_l00004ooooo`;o00001?oo
ool3o`000003ooooool0003o000000[ooooo0_l0000Cooooo`?o00000_ooool2o`0000Kooooo0_l0
0002ooooo`;o00001Oooool2o`0000;ooooo0_l00004ooooo`;o00001Oooool3o`000003ooooool0
003o000001Co00006?ooool3o`0000Kooooo1_l0001Qooooo`007?ooool00ol0003oooooooooo`1;
ooooo`;o00001_ooool4o`0000;ooooo0ol00004ooooo`;o00004Oooool3o`0000Sooooo0ol00004
ooooo`;o00001?ooool2o`0000;ooooo0_l00005ooooo`;o00000_ooool3o`0000?ooooo0_l00002
ooooo`;o00000_oooolIo`0001Sooooo0ol00006ooooo`Co00002Oooool2o`0000Cooooo1?l0001@
ooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00003?ooool2o`0000Gooooo1Ol000000ooo
oooo0000o`000006ooooo`;o00004?ooool4o`0000Sooooo0_l00005ooooo`;o00002?ooool2o`00
00[ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo6?l0000>ooooo`;o00004Oooool3o`00
00Wooooo0ol00004ooooo`Co0000D?ooool001cooooo00?o0000ooooooooool0?Oooool2o`0001?o
oooo0ol00003ooooo`;o00001?ooool2o`000003ooooool0003o000000oooooo0ol00004ooooo`;o
00000oooool2o`0000gooooo0_l00005ooooo`;o00001Oooool2o`0000Wooooo0_l000000ooooooo
0000o`00000Go`0000gooooo0_l00007ooooo`;o00002Oooool2o`0000Wooooo0_l0000:ooooo`;o
0000COooool001cooooo00?o0000ooooooooool0E?ooool2o`0000Cooooo0_l00002ooooo`;o0000
00?oooooo`000?l000001oooool2o`0000Kooooo0ol00004ooooo`;o00004_ooool2o`000003oooo
ool0003o000000;ooooo0_l00005ooooo`;o00002Oooool2o`000004ooooool0003o0000ooooo`;o
000000?oooooo`000?l000004ol00009ooooo`;o00002Oooool2o`0000;ooooo0_l00008ooooo`;o
00004_ooool2o`0004gooooo000Looooo`03o`000?oooooooooo04Gooooo0_l00005ooooo`;o0000
1_ooool2o`0000Cooooo0ol00006ooooo`;o00000_ooool2o`000003ooooool0003o000000Kooooo
0_l00005ooooo`;o000000?oooooo`000?l000001Oooool2o`0000_ooooo0_l0000Gooooo`Go0000
0_oooolDo`0000Wooooo0_l00008ooooo`;o00000oooool4o`0000Kooooo0_l00004ooooo`;o0000
2oooool2o`0004kooooo000Looooo`03o`000?oooooooooo04Gooooo0_l00005ooooo`;o00003Ooo
ool2o`0000Kooooo1_l0000<ooooo`;o00000_ooool8o`0000;ooooo0_l0000;ooooo`;o00004?oo
ool2o`0000;ooooo0_l000000ooooooo0000o`00000Fo`0001Kooooo0_l00005ooooo`;o00001_oo
ool2o`0000Cooooo0_l0000;ooooo`?o0000COooool001cooooo00?o0000ooooooooool0C?ooool2
o`0001Oooooo0_l000000ooooooo0000o`00000;ooooo`;o00000_ooool3o`000003ooooool0003o
000000;o00000_ooool3o`000003ooooool0003o000000[ooooo1?l0000;ooooo`;o00000_oooolK
o`0000Gooooo0_l0000Mooooo`Oo000000?oooooo`000?l000002oooool2o`0004gooooo000Loooo
o`;o0000A?ooool2o`0000Oooooo0_l00004ooooo`;o000000?oooooo`000?l000004?ooool3o`00
00Oooooo0ol0000=ooooo`So000000Coooooo`000?l0003o00001_ooool4o`0000_ooooo0_l00000
1?oooooo0000o`000?oooolFo`0000Sooooo0_l0000Fooooo`;o00000oooool9o`000003ooooool0
003o000000Wooooo1?l0001=ooooo`007?ooool00ol0003oooooooooo`0Xooooo`;o00006Oooool2
o`0000Kooooo0_l00005ooooo`;o000000Coooooo`000?l0003o00003oooool2o`0000Sooooo0ol0
0003ooooo`;o00002?ooool2o`0000;ooooo2?l00005ooooo`;o00003?ooool4o`000003ooooool0
003o000000;ooooo5Ol00006ooooo`;o00005_ooool4o`0000?ooooo0_l00002ooooo`Co00000_oo
ool2o`0000Gooooo0_l00002ooooo`;o0000Coooool001cooooo00?o0000ooooooooool0:?ooool2
o`0001cooooo0_l00003ooooo`;o00002Oooool2o`0000Cooooo1?l00003ooooo`Ko00002_ooool3
o`000003ooooool0003o000000Gooooo0_l000000ooooooo0000o`000004ooooo`Oo00001?ooool2
o`0000?ooooo0_l00007ooooo`Co00001OoooolGo`0000Cooooo0_l00009ooooo`;o00001_ooool2
o`0000?ooooo0_l00004ooooo`?o00000_ooool4o`0000?ooooo0_l00003ooooo`Go00000oooool2
o`0004cooooo000Looooo`03o`000?oooooooooo03?ooooo0_l0000Aooooo`;o00005?ooool4o`00
00?ooooo1Ol00002ooooo`;o00000_ooool2o`0000?ooooo0ol000001?oooooo0000o`000?ooool2
o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0ol00003ooooo`Co00000_ooool3
o`0000Kooooo0_l00009oooooaGo000000?oooooo`000?l000003?ooool2o`0000Kooooo0_l00009
ooooo`?o00001?ooool4o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000003
ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0<oooool2o`0001gooooo0_l00002oooo
o`;o00001oooool2o`0000Gooooo0_l00002ooooo`;o00000_ooool2o`0000Cooooo0ol00003oooo
o`;o00000_ooool6o`0000;ooooo0ol000001?oooooo0000o`000?l00004ooooo`Co00000oooool2
o`0000cooooo0_l00004oooooa3o00001Oooool3o`00013ooooo0_l0000Eooooo`;o00003Oooool2
o`000003ooooool0003o000004[ooooo000Looooo`03o`000?oooooooooo05;ooooo0_l00002oooo
o`;o00001oooool2o`0000;ooooo0_l0000@ooooo`Ko00000_ooool5o`000003ooooool0003o0000
00[o00001_ooool2o`0000Sooooo0_l00004ooooo`?o00001_ooool>o`0000Kooooo0_l0000<oooo
o`;o00000_ooool2o`0000cooooo0_l0000Cooooo`;o000000?oooooo`000?l000000ol00003oooo
o`;o0000AOooool001cooooo00?o0000ooooooooool0AOooool2o`0000cooooo0_l0000>ooooo`;o
00002Oooool2o`0000Cooooo1ol000000ooooooo0000o`000004o`000003ooooool0003o000000;o
000000Goooooo`000?l0003o0000ooooo`06o`0000?ooooo0_l00008ooooo`;o00001?ooool2o`00
00;ooooo0ol00002ooooo`oo00000oooool2o`0000kooooo0_l0000@ooooo`;o00004oooool2o`00
00;ooooo0ol00004ooooo`;o0000AOooool001cooooo00?o0000ooooooooool0AOooool2o`0000?o
oooo0_l00004ooooo`;o000000?oooooo`000?l000005Oooool2o`000004ooooool0003o0000o`00
00Cooooo1?l000001?oooooo0000o`000?ooool8o`000005ooooool0003o0000o`000?ooool02Ol0
000;ooooo`;o00002_ooool3o`0000;ooooo1_l000001?oooooo0000o`000?ooool2o`000003oooo
ool0003o000000;ooooo0ol0000Tooooo`;o00001Oooool2o`0000_ooooo1?l0001;ooooo`007?oo
ool00ol0003oooooooooo`1:ooooo`;o00001?ooool2o`0000Kooooo0_l0000@ooooo`;o000000Co
ooooo`000?l0003ooooo0_l000001?oooooo0000o`000?oooolKo`0000cooooo0_l0000>ooooo`Ko
00000_ooool2o`0000Sooooo0_l00006ooooo`;o00007Oooool2o`0000Gooooo1?l000000ooooooo
0000o`000006ooooo`;o0000COooool001cooooo00?o0000ooooooooool0Aoooool2o`0000?ooooo
0_l0000:ooooo`;o00001Oooool4o`0000_ooooo1?l000000ooooooo0000o`000008o`000003oooo
ool0003o000000[o000000?oooooo`000?l000000ol0000Aooooo`;o00002_ooool6o`0001Cooooo
0_l0000Vooooo`;o000000?oooooo`000?l000001oooool2o`0000Kooooo0_l00014ooooo`007?oo
ool00ol0003oooooooooo`0mooooo`;o00000oooool2o`0000?ooooo0_l00003ooooo`;o00000_oo
ool2o`0000Sooooo0_l00002ooooo`Go00002Oooool4o`0000;ooooo5ol000000ooooooo0000o`00
0003o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`;o00000oooool2o`0004gooooo0_l0
0009ooooo`;o00001_ooool2o`0004Cooooo000Looooo`03o`000?oooooooooo03gooooo0_l00002
ooooo`?o00000oooool2o`0000Oooooo0_l00008ooooo`;o00000_ooool3o`0000Cooooo0_l00003
ooooo`Ko00000_oooolOo`000003ooooool0003o000000Co00001?ooool2o`0003Kooooo0_l0000J
ooooo`;o00001_ooool2o`0000gooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0loooo
o`;o00000oooool4o`0000;ooooo0_l0000Looooo`?o00000_ooool2o`000003ooooool0003o0000
00?o00000_oooolJo`000003ooooool0003o000000Go00000_ooool2o`000004ooooool0003o0000
o`0000Gooooo0_l0000Uooooo`;o00002?ooool4o`0000_ooooo0_l0000;ooooo`;o00001_ooool2
o`000003ooooool0003o000000;o00002?ooool2o`00043ooooo000Looooo`03o`000?oooooooooo
03cooooo0_l00005ooooo`;o00000_ooool5o`0001Gooooo0_l00003ooooo`;o000000Goooooo`00
0?l0003o0000ooooo`0Xo`000003ooooool0003o000000;o000000Coooooo`000?l0003o00001Ooo
ool2o`0001Gooooo0_l00003ooooo`;o00002Oooool2o`0000Wooooo0ol0000;ooooo`;o00000_oo
ool2o`0000Oooooo0_l00005ooooo`;o00000_ooool4o`0000gooooo0_l0000kooooo`0000Kooooo
onk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo
00?o0000ooooooooool0;Oooool2o`0001Gooooo0_l000000ooooooo0000o`000003o`0000gooooo
0_l00006ooooo`;o000000Coooooo`000?l0003ooooo2_l000000ooooooo0000o`00000No`000003
ooooool0003o000000Go00008?ooool3o`0000;ooooo0_l0000Vooooo`;o00002_ooool2o`0000;o
oooo0_l0000Cooooo`;o0000>oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q
8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0]ooooo`;o00005?ooool3o`00
00Kooooo0_l00004ooooo`;o00001Oooool2o`0000Cooooo0_l00003ooooo`Go000000?oooooo`00
0?l000001Ol000000ooooooo0000o`00000Ro`0000Kooooo0_l0000Mooooo`;o00009oooool2o`00
00Gooooo0_l00006ooooo`;o00000oooool2o`0004oooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00Wooooo1Ol00006ooooo`03o`000?oooooooooo04?ooooo0_l00007ooooo`;o
00001?ooool2o`0000_ooooo0_l00004ooooo`?o00000oooool2o`000003ooooool0003o000000[o
000000?oooooo`000?l000006Ol00005ooooo`?o0000;oooool2o`0000Gooooo0ol00007ooooo`;o
00001?ooool2o`0000Gooooo0_l00005ooooo`Co00000_ooool:o`0004Oooooo00000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`0003Ko
oooo0_l00006ooooo`?o00001?ooool2o`0001kooooo1Ol000001?oooooo0000o`000?ooool<o`00
0003ooooool0003o000001Co000000Coooooo`000?l0003ooooo0_l00004ooooo`Co00006_ooool2
o`0000Cooooo0_l0000<ooooo`;o00001?ooool4o`0000Oooooo0_l00007ooooo`;o00002Oooool6
o`0000;ooooo2?l00017ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09oooo
o`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0=_ooool2o`0000Kooooo0ol00004
ooooo`?o00006Oooool2o`0000?ooooo1ol00002ooooo`_o000000?oooooo`000?l000005_l00002
ooooo`;o00001?ooool4o`0001?ooooo0_l00005ooooo`Co00000_ooool2o`0000Oooooo0_l00000
0ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000001Oooool6o`0000Oooooo0_l0000=
ooooo`;o00006?ooool2o`000003ooooool0003o000003Cooooo00000ooooooo410@ooooo`02oooo
o`03oa0@4?oooooooooo00[ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0koooo
o`;o00000oooool2o`0000?ooooo0ol0000Dooooo`;o00000oooool2o`0000Kooooo1Ol000000ooo
oooo0000o`00000So`000003ooooool0003o000000;o000000Coooooo`000?l0003o00000oooool2
o`0000cooooo1_l00007ooooo`;o00002?ooool5o`000003ooooool0003o000000;o000000?ooooo
o`000?l000002?ooool6o`0001Kooooo0_l000000ooooooo0000o`000007ooooo`;o00003?ooool2
o`000003ooooool0003o000003Cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?o
k^k^odA4A?l000001oooool00ol0003oooooooooo`0gooooo`;o00000_ooool2o`0000?ooooo0_l0
000Aooooo`;o00001oooool2o`0000_ooooo5ol00002oooooa;o00000_ooool3o`000003ooooool0
003o000000Cooooo0_l0000<ooooo`Co00003Oooool3o`0000?ooooo1Ol000000ooooooo0000o`00
0005o`0000Cooooo0_l0000Eooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l0
0007ooooo`;o0000AOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000
ooooo`06ooooo`03o`000?oooooooooo03Oooooo0_l00006ooooo`;o00004_ooool2o`0000;ooooo
0_l00004ooooo`;o00000oooool2o`0000?ooooo2Ol000000ooooooo0000o`00000Vo`0000?ooooo
0_l0000Jooooo`;o00000oooool6o`000003ooooool0003o000000co00000_ooool4o`0000Gooooo
0_l00007ooooo`;o00001Oooool2o`000005ooooool0003o0000o`000?ooool00_l00004ooooo`;o
00008_ooool2o`0002Wooooo000Looooo`03o`000?oooooooooo02[ooooo0_l00009ooooo`;o0000
1Oooool2o`000003ooooool0003o000000kooooo0_l000001?oooooo0000o`000?l00002ooooo`;o
00001?ooool2o`0000;ooooo>?l00003ooooo`;o00005_ooool2o`0000;ooooo0_l00003ooooo`?o
000000Coooooo`000?l0003ooooo1ol000001?oooooo0000o`000?l00004ooooo`Co00001_ooool2
o`0000Oooooo0_l00008ooooo`?o00001oooool2o`0002;ooooo0_l0000Yooooo`007?ooool00ol0
003oooooooooo`0Zooooo`;o00002Oooool2o`0000Gooooo0_l000000ooooooo0000o`00000>oooo
o`;o000000?oooooo`000?l000003Oooool2o`000003ooooool0003o000002Wo000000?oooooo`00
0?l000001ol0000Hooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo0_l00003oooo
o`;o00003_ooool7o`0001gooooo0_l0000;ooooo`;o00001?ooool2o`0003gooooo000Looooo`03
o`000?oooooooooo03oooooo0_l0000Aooooo`;o00001_ooool2o`000003ooooool0003o000000Wo
oooo5_l000000ooooooo0000o`00000Co`00017ooooo0_l0000:ooooo`;o00001oooool2o`0000Oo
oooo0_l000000ooooooo0000o`000006ooooo`;o00001_ooool4o`0000;ooooo0_l0000Cooooo`?o
00000oooool4o`0000Oooooo1Ol00003ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0
8oooool2o`0003Gooooo1Ol0000;ooooobWo000000?oooooo`000?l000000_l0000<ooooo`?o0000
2_ooool2o`0000Oooooo0_l000000ooooooo0000o`000007ooooo`;o00001_ooool2o`0000Sooooo
1_l0000Cooooo`?o00000oooool6o`0000Cooooo0ol000001?oooooo0000o`000?l00011ooooo`00
7?ooool00ol0003oooooooooo`0Sooooo`;o0000:oooool2o`0000;ooooo1?l000000ooooooo0000
o`000002o`0000kooooo0_l000000ooooooo0000o`000003ooooob3o000000?oooooo`000?l00000
0_l00006ooooo`;o00001?ooool2o`0000Gooooo0_l00004ooooo`;o00000oooool2o`0000Gooooo
1?l00005ooooo`;o00001oooool6o`0000Gooooo1?l0000Booooo`?o00001?ooool3o`000003oooo
ool0003o000000Cooooo0_l000000ooooooo0000o`000002o`00047ooooo000Looooo`03o`000?oo
oooooooo053ooooo0_l00002ooooo`Co000000Coooooo`000?l0003o00004_ooool2o`0000;ooooo
8ol000000ooooooo0000o`000006ooooo`;o00002oooool2o`0000Wooooo0_l00007ooooo`;o0000
1Oooool2o`0000;ooooo3Ol00003ooooo`Ko00004?ooool2o`0000Cooooo1_l000001?oooooo0000
o`000?l00004ooooo`;o00001oooool2o`0003[ooooo000Looooo`03o`000?oooooooooo03Wooooo
1Ol0000Dooooo`;o00004_ooool2o`0000Kooooo9ol00007ooooo`?o000000?oooooo`000?l00000
3?ooool2o`0000Kooooo0_l0000Booooo`So000000?oooooo`000?l000001?l000000ooooooo0000
o`000004o`0000oooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool6o`0000gooooo
0_l00002ooooo`;o0000=_ooool001cooooo00?o0000ooooooooool0>Oooool5o`0000;ooooo1?l0
000>ooooo`;o00002Oooool2o`0000Kooooo1Ol00003oooooaSo000000?oooooo`000?l000002?l0
00001?oooooo0000o`000?l00005ooooo`Ko000000?oooooo`000?l000003?ooool2o`0000Gooooo
0_l0000@oooooa[o00003_ooool5o`0000?ooooo0_l00002ooooo`Co00004_ooool2o`0003Kooooo
000Looooo`03o`000?oooooooooo03Cooooo1?l00008ooooo`Co00001?ooool2o`0000Gooooo0_l0
0004ooooo`Go00000oooool2o`0000Kooooo0_l000000ooooooo0000o`000003oooooaSo00000_oo
ool7o`0000?ooooo1Ol00003ooooo`?o00006Oooool6o`0000Gooooo0_l00005oooooaOo000000?o
ooooo`000?l000004?ooool2o`000004ooooool0003o0000ooooo`;o00002?ooool2o`0004Kooooo
000Looooo`03o`000?oooooooooo03Cooooo1?l0000@ooooo`;o00001Oooool2o`0000Cooooo1Ol0
0007ooooo`;o000000?oooooo`000?l000001oooool2o`000003ooooool0003o000000So000000?o
ooooo`000?l000005?l000000ooooooo0000o`000002o`000003ooooool0003o000001_ooooo0_l0
00000ooooooo0000o`000002o`0000Gooooo0_l00006oooooaWo00003oooool2o`0000;ooooo0_l0
0003ooooo`;o00001?ooool4o`0000;ooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`0c
ooooo`Co00002Oooool3o`0001Cooooo0_l00008ooooo`;o000000?oooooo`000?l000001oooool2
o`0000Cooooo7_l00002ooooo`So00005oooool4o`0000Wooooo0_l00006ooooo`Wo000000?ooooo
o`000?l000004?l0000=ooooo`?o00000_ooool2o`000004ooooool0003o0000o`0000?ooooo0ol0
00001?oooooo0000o`000?ooool2o`0004;ooooo000Looooo`;o0000=?ooool4o`0000Wooooo0ol0
000Dooooo`;o00003oooool5o`0000Gooooo7_l00003ooooo`So00004Oooool2o`0000?ooooo1?l0
000:ooooo`;o00001_oooolLo`0000[ooooo0_l000001?oooooo0000o`000?l00002ooooo`;o0000
00?oooooo`000?l000001?ooool2o`0000;ooooo0_l00008ooooo`;o0000>oooool001cooooo00?o
0000ooooooooool0=?ooool2o`0000Gooooo0_l00004ooooo`Co00004?ooool2o`0000_ooooo0_l0
0004ooooo`Ko000000Coooooo`000?l0003ooooo1_l000000ooooooo0000o`00000Do`0000;ooooo
0_l000000ooooooo0000o`000002o`0001;ooooo1?l00003ooooo`;o00000oooool2o`0000oooooo
6ol0000:ooooo`?o000000?oooooo`000?l000004Oooool2o`0000Oooooo0_l0000kooooo`007?oo
ool00ol0003oooooooooo`0booooo`;o00000_ooool2o`0000?ooooo0_l00004ooooo`Co00003?oo
ool2o`0000;ooooo0_l00004ooooo`;o00001Oooool2o`0000?ooooo0_l00003oooooa3o000000?o
ooooo`000?l000001?l000000ooooooo0000o`000009o`0000;ooooo0_l000001Ooooooo0000o`00
0?l0003ooooo00?o00001Oooool2o`0000;ooooo0_l00003ooooo`?o00001Oooool2o`0000?ooooo
0_l00009ooooo`;o00001Oooool7o`000003ooooool0003o000000oo000000?oooooo`000?l00000
2?ooool2o`0000cooooo0ol00005ooooo`Co000000?oooooo`000?l00000@?ooool001cooooo00?o
0000ooooooooool0;?ooool2o`0000Cooooo0_l000001?oooooo0000o`000?l00003ooooo`?o0000
1?ooool2o`0000gooooo0_l00008ooooo`Co00002?ooool2o`0000;ooooo2?l000000ooooooo0000
o`00000Io`0000Oooooo1Ol00005ooooo`;o00000_ooool2o`0000?ooooo0_l000000ooooooo0000
o`000003ooooo`;o00000oooool2o`0000Wooooo0_l00006oooooaSo000000?oooooo`000?l00000
4_ooool9o`0000?ooooo1?l000000ooooooo0000o`000010ooooo`007?ooool00ol0003ooooooooo
o`0/ooooo`;o00001oooool4o`0000;ooooo0ol00003ooooo`?o00006Oooool2o`0000Oooooo0_l0
0003ooooo`;o00001?ooool2o`000003ooooool0003o000001So00000oooool3o`0000;ooooo0ol0
0002ooooo`;o00001Oooool2o`0000Sooooo0_l00002ooooo`?o00000oooool2o`00017ooooo6?l0
0005ooooo`;o000000?oooooo`000?l000002oooool4o`0000?ooooo1?l00004ooooo`;o0000@_oo
ool001cooooo00?o0000ooooooooool0=oooool2o`0000;ooooo0_l00004ooooo`;o000000?ooooo
o`000?l000005oooool2o`0000Oooooo0_l00003ooooo`;o00001ooooolDo`0000?ooooo0ol00003
ooooo`?o00000oooool2o`0000;ooooo0_l00003ooooo`Co000000?oooooo`000?l000000_l00003
ooooo`?o000000Coooooo`000?l0003o00002?ooool2o`0000[ooooo4Ol000000ooooooo0000o`00
0007o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool2o`0000?ooooo0_l0
0006ooooo`;o00001?ooool2o`0000?ooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`14
ooooo`;o00005oooool4o`0000Oooooo1Ol00002ooooo`;o00000ooooolIo`0000?ooooo1Ol0000;
ooooo`;o00000oooool4o`0000Cooooo1?l00004ooooo`;o00001?ooool2o`0000[ooooo0ol00000
0ooooooo0000o`00000:o`0000;ooooo2Ol0000;ooooo`;o00000oooool2o`0000?ooooo0_l0000:
ooooo`;o00000oooool4o`0003gooooo000Looooo`03o`000?oooooooooo05Kooooo0_l00007oooo
o`;o00001oooool5o`000003ooooool0003o000000?o000000?oooooo`000?l000000_l00002oooo
o`Oo000000?oooooo`000?l000002Ol00002ooooo`So00001oooool2o`0000Cooooo1Ol00004oooo
o`Ko00000_ooool2o`0000Wooooo0_l00005oooooaco00008?ooool2o`0000?ooooo0_l0000>oooo
o`;o0000;oooool001cooooo00?o0000ooooooooool0E_ooool2o`0000Kooooo0_l0000:ooooo`?o
000000?oooooo`000?l000001Ol000001?oooooo0000o`000?ooool=o`0000;ooooo1?l00002oooo
o`Wo00000_ooool2o`0000?ooooo1?l00002ooooo`Go00001?ooool2o`0000;ooooo0_l0000=oooo
o`Co00000ooooolLo`0002?ooooo0_l000000ooooooo0000o`00000=ooooo`;o0000;oooool001co
oooo00?o0000ooooooooool0?oooool2o`0001cooooo1?l0000:ooooo`;o000000?oooooo`000?l0
00000_l000000ooooooo0000o`000003o`000003ooooool0003o000000Oo00000_ooool2o`0000;o
oooo1Ol000000ooooooo0000o`000003ooooo`?o00000oooool2o`0000Gooooo0_l00006ooooo`Oo
00004oooool2o`0000?ooooo6_l00007ooooo`Go00006Oooool2o`000003ooooool0003o000003ko
oooo000Looooo`03o`000?oooooooooo03kooooo0ol0000Gooooo`;o000000?oooooo`000?l00000
1?l00002ooooo`;o00001Oooool2o`0000;ooooo1?l00002ooooo`Co000000?oooooo`000?l00000
1ol00006ooooo`Go00006oooool8o`0000Cooooo0_l0000Aoooooa[o00001oooool5o`0001Wooooo
0ol0000@ooooo`;o0000;_ooool001cooooo00?o0000ooooooooool0<?ooool2o`0000cooooo0_l0
000Hooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00005ooooo`Co00001_oo
ool4o`000003ooooool0003o000000?o000000Coooooo`000?l0003o00000_ooool2o`0000Cooooo
0ol00003ooooo`;o00002oooool4o`0000cooooo0ol00004ooooo`;o00003_ooool2o`0000;ooooo
6?l0000:ooooo`;o00006_ooool3o`0000gooooo0_l000000ooooooo0000o`00000^ooooo`007?oo
ool00ol0003oooooooooo`0`ooooo`;o00001?ooool2o`0000Gooooo0_l00006ooooo`;o00009Ooo
ool2o`0000?ooooo0_l000000ooooooo0000o`000002o`0000Kooooo1Ol000000ooooooo0000o`00
0003o`0000Oooooo0_l0000:ooooo`Go00003?ooool2o`0000Sooooo0_l00002ooooo`;o000000?o
ooooo`000?l000001?ooool2o`0000;ooooo6?l0000Cooooo`?o00003oooool4o`0000gooooo0_l0
000aooooo`007?ooool00ol0003oooooooooo`0Uooooo`;o00002_ooool2o`0000?ooooo0_l00005
ooooo`Co00001?ooool2o`0001Sooooo0_l0000<ooooo`;o00000_ooool2o`000003ooooool0003o
000000Go00000oooool6o`0000;ooooo0ol0000Cooooo`;o00003?ooool2o`0000?ooooo1?l00004
ooooo`;o00000_ooool2o`000003ooooool0003o000000;o00000_ooool2o`000003ooooool0003o
000001Oo00001oooool2o`0000[ooooo0ol00005ooooo`;o00002?ooool6o`00013ooooo0_l0000/
ooooo`007?ooool00ol0003oooooooooo`0Uooooo`;o00002_ooool2o`0000[ooooo1Ol0000Hoooo
o`;o00000oooool2o`000003ooooool0003o000000?ooooo0_l00004ooooo`;o00000_ooool2o`00
00Gooooo0ol00004ooooo`;o000000?oooooo`000?l000000_l00006ooooo`;o000000?oooooo`00
0?l000000oooool2o`0000?ooooo0_l0000>ooooo`?o00000oooool8o`0000Wooooo0_l00002oooo
o`;o000000?oooooo`000?l000003_l000000ooooooo0000o`000005o`0000Sooooo0_l0000Boooo
o`;o00002?ooool2o`000004ooooool0003o0000o`00013ooooo0_l0000/ooooo`007?ooool00ol0
003oooooooooo`0[ooooo`?o00003oooool2o`000003ooooool0003o000000?ooooo0_l0000Coooo
o`;o00001_ooool2o`0000?ooooo0ol0000Eooooo`;o00000oooool4o`0000Cooooo0_l000000ooo
oooo0000o`000003ooooo`;o00000oooool3o`0000[ooooo0_l000000ooooooo0000o`000008oooo
o`Ko00001_ooool2o`0000Gooooo0_l00002ooooo`Go000000?oooooo`000?l000001Ol000000ooo
oooo0000o`000004o`0000Wooooo0_l00003ooooo`Co00006Oooool2o`0003kooooo000Looooo`;o
0000;?ooool5o`000003ooooool0003o000000Cooooo0_l0000<ooooo`;o00008Oooool4o`0000_o
oooo0_l00006ooooo`;o00001?ooool3o`0000Sooooo0_l00008ooooo`;o00002_ooool2o`0000oo
oooo1?l00004ooooo`;o00001Oooool2o`000003ooooool0003o000001;o00000_ooool2o`0000_o
oooo1?l0000Gooooo`Co0000?_ooool001cooooo00?o0000ooooooooool0;?ooool4o`000003oooo
ool0003o000000Cooooo0_l0000Sooooo`;o00003?ooool2o`0000[ooooo0ol00006ooooo`;o0000
1?ooool2o`0000Wooooo0_l0000?ooooo`;o00001?ooool4o`0000Wooooo0_l000000ooooooo0000
o`000004o`0000cooooo4ol00002ooooo`Co00002oooool2o`0000oooooo0ol00006ooooo`;o0000
2_ooool2o`0003Cooooo000Looooo`03o`000?oooooooooo02cooooo0_l0000:ooooo`;o00001Ooo
ool2o`0001_ooooo0_l0000:ooooo`;o00003?ooool2o`0000;ooooo0_l00005ooooo`;o00007_oo
ool2o`0000Cooooo1?l00009ooooo`;o000000?oooooo`000?l000001?l000000ooooooo0000o`00
0007ooooo`Go000000?oooooo`000?l000004ol00006ooooo`;o00005?ooool7o`0000kooooo0_l0
000dooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o00002_ooool3o`0000Gooooo0_l00003
ooooo`;o00008_ooool4o`0000Kooooo1?l00004ooooo`;o000000?oooooo`000?l000000_ooool2
o`000003ooooool0003o000002Gooooo0_l0000>ooooo`Go00001?ooool2o`000004ooooool0003o
0000ooooo`Go00000_ooool6o`000003ooooool0003o000000Go00002Oooool3o`0000?ooooo0_l0
0005ooooo`;o00002_ooool4o`0000cooooo1?l0000dooooo`007?ooool00ol0003oooooooooo`0W
ooooo`;o00000_ooool2o`0000[ooooo0_l0000;ooooo`;o00009?ooool2o`0000Kooooo1?l00000
0ooooooo0000o`000004ooooo`;o00001Oooool2o`0001Cooooo0_l0000;ooooo`;o00000_ooool2
o`0000kooooo0ol00006ooooo`;o00001Oooool?o`0000?ooooo0_l0000:ooooo`;o00000oooool2
o`0000Gooooo0_l00007ooooo`Ko00003Oooool4o`0003Cooooo000Looooo`03o`000?oooooooooo
02Oooooo0_l00009ooooo`;o00000_ooool2o`000003ooooool0003o000000Gooooo0_l0000Ioooo
o`;o00000oooool2o`0001Gooooo0_l00004ooooo`;o00001Oooool2o`000003ooooool0003o0000
017ooooo0_l0000;ooooo`;o00008_ooool?o`0000?ooooo0_l0000Eooooo`;o00002?ooool4o`00
00Oooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0Zooooo`;o00001_ooool2o`0000;o
oooo0_l000000ooooooo0000o`000005ooooo`;o00006Oooool2o`0000?ooooo1Ol00002ooooo`;o
00005?ooool2o`0000Gooooo0_l000000ooooooo0000o`000009ooooo`;o00001_ooool2o`0001Ko
oooo0_l00005ooooo`;o00000oooool2o`0000cooooo3?l0000Looooo`;o00002Oooool2o`0000Co
oooo0_l00002ooooo`;o00001_ooool2o`0003Kooooo000Looooo`03o`000?oooooooooo02[ooooo
0_l0000:ooooo`;o00002?ooool2o`0000Cooooo0_l0000Aooooo`;o00001oooool3o`0000;ooooo
0_l00005ooooo`;o00001Oooool2o`0000_ooooo0_l0000=ooooo`?o00001_ooool2o`0001Kooooo
0_l00005ooooo`;o00000oooool2o`0000Gooooo0_l00003ooooo`go00000_ooool2o`0000cooooo
0_l00007ooooo`;o00000_ooool2o`0000gooooo1?l0000:ooooo`?o0000=Oooool001cooooo00?o
0000ooooooooool0=_ooool2o`0000kooooo0_l0000Aooooo`;o000000?oooooo`000?l000001?oo
ool2o`0000[ooooo0_l00005ooooo`;o00001oooool6o`0000?ooooo0_l00008ooooo`Co00002Ooo
ool2o`0000Cooooo0_l00008ooooo`;o00003?ooool2o`0000Oooooo0ol00002ooooo`;o000000Go
ooooo`000?l0003o0000ooooo`05o`0000?ooooo0_l00003ooooo`;o00000oooool2o`0000;ooooo
0_l00007ooooo`;o00003oooool4o`0000Cooooo0_l00007ooooo`;o0000=Oooool001cooooo00?o
0000ooooooooool09Oooool2o`0001Cooooo0_l0000Oooooo`;o00006Oooool2o`000003ooooool0
003o000000;ooooo1Ol00004ooooo`;o00002_ooool2o`0000Wooooo0_l000001?oooooo0000o`00
0?ooool2o`0000Sooooo0_l000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l00000
0_l00006ooooo`Co00000oooool3o`000004ooooool0003o0000o`0000[ooooo0_l000000ooooooo
0000o`000002o`0001Gooooo0_l00003ooooo`Co000000?oooooo`000?l000000oooool2o`0003ko
oooo000Looooo`03o`000?oooooooooo02Gooooo0_l0000Dooooo`;o00007oooool2o`0000_ooooo
0ol0000;ooooo`Oo00008oooool2o`0000kooooo0_l00006ooooo`Co000000?oooooo`000?l00000
1oooool3o`000003ooooool0003o000001Cooooo0_l0000Gooooo`;o00000oooool2o`0000?ooooo
0_l0000Cooooo`;o0000;_ooool001cooooo00?o0000ooooooooool0:_ooool4o`000003ooooool0
003o000000Kooooo0_l00005ooooo`;o00000_ooool2o`0001gooooo0_l00006ooooo`?o00003Ooo
ool2o`000003ooooool0003o000000Gooooo0_l00005ooooo`;o00005Oooool2o`0000kooooo0_l0
0006ooooo`Co000000?oooooo`000?l000002oooool2o`000003ooooool0003o0000023ooooo0ol0
000Tooooo`Co00001_ooool2o`0002Kooooo000Looooo`03o`000?oooooooooo02[ooooo1?l00000
0ooooooo0000o`000006ooooo`;o00001Oooool2o`0000;ooooo0_l000000ooooooo0000o`00000I
ooooo`?o00003?ooool2o`0001;ooooo0_l00002ooooo`;o000000?oooooo`000?l000000oooool2
o`0000Oooooo0_l0000Fooooo`;o00001oooool2o`0000?ooooo0_l0000>ooooo`;o00002Oooool2
o`0000Wooooo0ol00009ooooo`?o00008oooool3o`0000Sooooo0_l0000Vooooo`007?ooool00ol0
003oooooooooo`0_ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00006Oooool2o`00
00Gooooo0_l00006ooooo`;o00001?ooool2o`0000Cooooo0_l00003ooooo`;o00000_ooool2o`00
0003ooooool0003o000000;ooooo0_l00002ooooo`;o00001_ooool3o`00013ooooo0_l00004oooo
o`;o00003?ooool2o`0000;ooooo1?l00002ooooo`;o00001_ooool3o`0000Kooooo0_l000000ooo
oooo0000o`000003ooooo`;o000000?oooooo`000?l000000ol0000<ooooo`Co00005oooool2o`00
00Cooooo0_l0000aooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00002?ooool2o`0001ko
oooo0_l00009ooooo`;o000000?oooooo`000?l000003?ooool2o`0000Cooooo0_l00003ooooo`;o
00000_ooool2o`0000Gooooo0_l0000:ooooo`;o000000?oooooo`000?l000003?ooool4o`0000co
oooo2?l00002ooooo`Co00000_ooool2o`0000Kooooo1?l00008ooooo`;o00000oooool2o`0000Co
oooo0_l0000<ooooo`Co00005oooool2o`0000?ooooo0_l0000booooo`007?ooool00ol0003ooooo
ooooo`0_ooooo`?o00001oooool4o`0001cooooo0_l00009ooooo`;o00001?ooool2o`000004oooo
ool0003o0000ooooo`;o00005Oooool2o`00017ooooo0_l00004ooooo`;o00001_ooool2o`0000Co
oooo0_l00006ooooo`So00002oooool2o`0000Gooooo1_l00004ooooo`;o0000>Oooool2o`0003;o
oooo000Looooo`;o0000<Oooool2o`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l00000
2?ooool2o`00023ooooo0_l000001?oooooo0000o`000?ooool2o`0001Gooooo0ol0000Fooooo`;o
00003?ooool2o`0000Kooooo0_l00002ooooo`So00001oooool2o`0000Oooooo1?l00004ooooo`;o
00008_ooool2o`0000?ooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0gooooo`;o0000
1Oooool2o`0000Kooooo1Ol0000Booooo`;o00006oooool2o`000003ooooool0003o000000Cooooo
1?l000001?oooooo0000o`000?ooool2o`0000Wooooo0_l00003ooooo`;o00007oooool6o`00013o
oooo1?l00004ooooo`;o00004Oooool3o`000003ooooool0003o000000_ooooo0_l00003ooooo`;o
0000A?ooool001cooooo00?o0000ooooooooool0=_ooool2o`0000Cooooo0_l00008ooooo`;o0000
00?oooooo`000?l000003Oooool2o`0000?ooooo0_l00009ooooo`;o00004?ooool2o`000003oooo
ool0003o000000Cooooo1?l000001?oooooo0000o`000?ooool2o`0000Wooooo0_l00003ooooo`;o
00002?ooool2o`0001oooooo0_l00008ooooo`;o00002oooool2o`000003ooooool0003o000000;o
00002Oooool3o`000003ooooool0003o000000Cooooo0_l0000:ooooo`?o00004_ooool2o`0002oo
oooo000Looooo`03o`000?oooooooooo03Kooooo0_l00004ooooo`;o00002_ooool2o`0000kooooo
0_l000000ooooooo0000o`000002ooooo`;o00001oooool2o`00027ooooo0_l00006ooooo`;o0000
2?ooool2o`0000Kooooo0_l0000Booooo`;o00001?ooool2o`0000Gooooo0_l00005ooooo`;o0000
00?oooooo`000?l000002?ooool5o`000003ooooool0003o000000;o00004oooool2o`0000Gooooo
0_l00004ooooo`;o00003Oooool2o`0000?ooooo0_l0000_ooooo`007?ooool00ol0003ooooooooo
o`0fooooo`;o00002Oooool2o`0000Gooooo0_l0000@ooooo`Oo00001_ooool2o`0000?ooooo1?l0
000Kooooo`;o00001_ooool2o`0000Gooooo0_l000000ooooooo0000o`00000<ooooo`?o00002ooo
ool2o`0000Cooooo0_l00003ooooo`Co00001Oooool2o`0000?ooooo0_l00006ooooo`?o00004ooo
ool2o`0000cooooo1?l0000;ooooo`;o00001?ooool2o`0003Cooooo000Looooo`03o`000?oooooo
oooo03?ooooo0_l00004ooooo`;o00001_ooool2o`0000Wooooo0_l0000<ooooo`;o000000?ooooo
o`000?l000000oooool4o`000003ooooool0003o000000?ooooo1?l0000Hooooo`;o00004?ooool2
o`0000Kooooo0_l00005ooooo`Oo00004Oooool2o`000003ooooool0003o000000Oooooo0_l00003
ooooo`;o00001oooool2o`0000?ooooo0_l00006ooooo`;o000000?oooooo`000?l000000oooool2
o`0000Kooooo0ol00005ooooo`;o000000?oooooo`000?l000002?ooool2o`0003[ooooo000Loooo
o`03o`000?oooooooooo03?ooooo0_l00002ooooo`Ko00001?ooool2o`0000Wooooo0_l0000Doooo
o`Co00002_ooool2o`000003ooooool0003o000000?ooooo0_l00007ooooo`;o00001Oooool2o`00
00[ooooo0_l0000:ooooo`Co00001Oooool7o`00017ooooo0_l00005ooooo`;o00000oooool4o`00
00oooooo0_l00005ooooo`?o000000?oooooo`000?l000001Oooool2o`0000Cooooo0ol00004oooo
o`;o00000_ooool3o`0004?ooooo000Looooo`03o`000?oooooooooo03Oooooo0_l00002ooooo`;o
00001?ooool2o`0000Kooooo1?l0000@ooooo`;o00000oooool2o`0000_ooooo0ol000000ooooooo
0000o`000003ooooo`;o00001oooool2o`00013ooooo0ol00008ooooo`Go00001Oooool4o`0000go
oooo0_l0000=ooooo`;o00000_ooool5o`0000gooooo0_l00005ooooo`Co00001_ooool5o`0000[o
oooo0ol00003ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0=?ooool2o`0001?ooooo
1Ol0000?ooooo`;o00004?ooool4o`0000Cooooo0_l00006ooooo`;o00001?ooool2o`0000;ooooo
0_l00006ooooo`Co00002Oooool2o`0000Gooooo0_l000000ooooooo0000o`00000?ooooo`;o0000
3Oooool3o`000003ooooool0003o0000013ooooo0_l00004ooooo`Go00001_ooool6o`0000Wooooo
0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l00000?Oooool001cooooo00?o
0000ooooooooool0=?ooool2o`0001Kooooo0_l0000Iooooo`;o00002?ooool3o`0000?ooooo0_l0
0002ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`0000;ooooo0ol00005ooooo`;o0000
4_ooool2o`000003ooooool0003o000000;o00003Oooool2o`0000;ooooo0_l0000:ooooo`;o0000
0_ooool2o`0000_ooooo0_l00008ooooo`;o00001?ooool2o`0000Gooooo1?l00004ooooo`;o0000
1_ooool2o`0000Cooooo0_l000000ooooooo0000o`000005ooooo`?o0000=Oooool001cooooo00?o
0000ooooooooool0=?ooool2o`000003ooooool0003o000002kooooo1?l00007ooooo`;o00000ooo
ool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00001Oooool3o`0000Wooooo0_l0
0008ooooo`Co00000_ooool2o`000003ooooool0003o000000;o00003Oooool3o`000003ooooool0
003o000000_ooooo0_l000000ooooooo0000o`00000;ooooo`Go00002oooool2o`0000Kooooo0_l0
0005ooooo`;o00000oooool2o`000003ooooool0003o000000kooooo0ol0000eooooo`007?ooool0
0ol0003oooooooooo`0gooooo`;o00001_ooool2o`0000[ooooo0_l0000:ooooo`;o00002Oooool2
o`0000Gooooo0_l000000ooooooo0000o`000004ooooo`;o00000oooool2o`000003ooooool0003o
000000;o000000Coooooo`000?l0003ooooo0_l00004ooooo`?o00002_ooool4o`0000Kooooo1?l0
0002ooooo`;o00001oooool2o`0000[ooooo0_l0000>ooooo`;o00004?ooool3o`0000Sooooo0_l0
0009ooooo`?o00001?ooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0004?ooooo
000Looooo`03o`000?oooooooooo02oooooo0_l00007ooooo`;o00001Oooool3o`0000Wooooo0_l0
000:ooooo`;o00002Oooool2o`0000Sooooo0_l00004ooooo`Co000000Coooooo`000?l0003ooooo
2ol00003ooooo`;o00003Oooool2o`0000kooooo0_l00005ooooo`;o00001?ooool2o`0000Cooooo
1?l0000Rooooo`;o00001Oooool3o`0000Sooooo1?l00006ooooo`;o00001?ooool4o`0004?ooooo
000Looooo`03o`000?oooooooooo02oooooo0_l00007ooooo`;o00000oooool2o`000004ooooool0
003o0000ooooo`;o00005oooool2o`0000_ooooo0_l00008ooooo`Go00000_ooool2o`000003oooo
ool0003o000000;ooooo1?l00005ooooo`;o000000?oooooo`000?l000004_ooool2o`0000Cooooo
0_l00005ooooo`;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000;ooooo
0_l00006ooooo`;o00005Oooool2o`0000;ooooo0_l00002ooooo`;o00001_ooool2o`0000;ooooo
0_l00006ooooo`;o00001?ooool2o`0000cooooo0_l0000gooooo`0000Koooooonk^k_lb<S;o0000
oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000oooo
ooooool0:_ooool2o`0000Gooooo0_l00009ooooo`?o00001?ooool2o`0000_ooooo0_l00009oooo
o`Co00002_ooool2o`0000;ooooo0_l00007ooooo`;o000000Goooooo`000?l0003o0000ooooo`04
o`000003ooooool0003o000000;ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00004_oo
ool2o`0000Cooooo0_l0000=ooooo`Wo00000_ooool3o`0000Gooooo0_l00002ooooo`;o00005Ooo
ool2o`0000[ooooo0_l00002ooooo`;o00001_ooool2o`0000?ooooo0_l00004ooooo`;o00001ooo
ool2o`0003Oooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEE
EOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0Zooooo`;o00001Oooool2o`0000Wo
oooo0_l0000Booooo`;o00002Oooool6o`0000Gooooo0_l00005ooooo`;o00001?ooool3o`0000?o
oooo2?l000000ooooooo0000o`000004o`000003ooooool0003o000000Cooooo0ol0000:ooooo`;o
00001Oooool2o`00013ooooo3ol000000ooooooo0000o`000003ooooo`Go00000_ooool2o`0001Go
oooo0_l00007ooooo`;o000000?oooooo`000?l000001_ooool2o`0000?ooooo0_l00004ooooo`;o
0000@?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool0Goooool2o`0000Gooooo0_l0000;ooooo`Go
000000?oooooo`000?l000005ol00008ooooo`Co00001?ooool3o`000004ooooool0003o0000oooo
o`;o00002_ooool2o`000003ooooool0003o000000go00000oooool3o`0000Cooooo0_l0000Coooo
o`Co000000?oooooo`000?l000001?ooool2o`0000[ooooo0ol0000Aooooo`;o0000=_ooool00003
ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q
00Kooooo0ol00010ooooo`;o00009?ooool2o`0000_ooooo5_l000000ooooooo0000o`000003o`00
00_ooooo0_l00006ooooo`;o00000_ooool2o`000003ooooool0003o000000Oooooo0_l000000ooo
oooo0000o`00000Ao`0001kooooo0_l00003ooooo`;o00004?ooool5o`0000oooooo0_l0000foooo
o`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`01_ooool00ol0003oooooooooo`10ooooo`;o00000oooool2o`000003ooooool0003o0000
00kooooo0_l00003ooooo`;o00004?ooool2o`0000?ooooo5Ol000000ooooooo0000o`000008oooo
o`;o00002_ooool4o`0000gooooo6ol0000Qooooo`?o00004?ooool2o`0004Oooooo00000ooooooo
410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003o
ooooooooo`0booooo`;o00000_ooool2o`0000Kooooo0_l00005ooooo`;o000000?oooooo`000?l0
00001_ooool2o`0000Kooooo0_l00003ooooo`;o00001?ooool2o`0000;ooooo0_l00006ooooo`;o
000000?oooooo`000?l000004Ol000001Ooooooo0000o`000?l0003ooooo00;o00002?ooool2o`00
00Cooooo0ol00002ooooo`?o00003OoooolGo`000003ooooool0003o000000?o00000oooool2o`00
01Wooooo0_l000001?oooooo0000o`000?l0000Looooo`;o0000>oooool00006oooooomgMgOoV9RH
oooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo033ooooo1?l0
0002ooooo`;o00000oooool2o`000003ooooool0003o0000013ooooo0_l00009ooooo`;o00001_oo
ool2o`0000;ooooo0_l00002ooooo`Go00000_ooool:o`000003ooooool0003o000000[o000000?o
ooooo`000?l000003?ooool5o`0000;ooooo0ol0000=ooooo`Go000000?oooooo`000?l000003_l0
0002ooooo`;o00001_ooool2o`0000gooooo0_l0000:ooooo`;o00001_ooool2o`0000Oooooo0_l0
00000ooooooo0000o`00000<ooooo`Co0000>Oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^
3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo033ooooo0_l00009ooooo`;o
00004Oooool2o`0000_ooooo0_l0000;ooooobCo00003?ooool2o`0000?ooooo0_l000001?oooooo
0000o`000?ooool2o`0000Oooooo7Ol00006ooooo`;o00002_ooool2o`000003ooooool0003o0000
01;ooooo0_l00006ooooo`?o000000?oooooo`000?l000003_ooool2o`0003Wooooo000Looooo`03
o`000?oooooooooo03Sooooo0_l00008ooooo`;o00002_ooool2o`0000Cooooo0_l0000<ooooo`;o
00001?oooolRo`000003ooooool0003o000000;ooooo0_l0000<ooooo`;o000000Coooooo`000?l0
003ooooo0_l00007ooooo`ko000000?oooooo`000?l000003?l0000:ooooo`;o00001_ooool2o`00
01Cooooo0ol00006ooooo`;o00003oooool2o`0003cooooo000Looooo`03o`000?oooooooooo03So
oooo0ol00005ooooo`Co00002Oooool2o`0000Gooooo0_l000000ooooooo0000o`000009ooooo`?o
00001?ooool=o`000003ooooool0003o000000oo00000oooool2o`0000;ooooo0_l0000Dooooo`;o
00001ooooolGo`000004ooooool0003o0000o`0000[ooooo0_l0000Looooo`;o00006?ooool2o`00
03cooooo000Looooo`03o`000?oooooooooo03Wooooo0ol000001?oooooo0000o`000?ooool2o`00
00_ooooo0_l00008ooooo`;o00002_ooool2o`0000Kooooo0_l00002oooooaSo000000?oooooo`00
0?l000001Oooool2o`0000?ooooo0_l00007ooooo`;o00001_ooool2o`0000Oooooo6ol00009oooo
o`;o00001Oooool2o`000003ooooool0003o000000oooooo1?l0001Hooooo`007?ooool00ol0003o
ooooooooo`0iooooo`?o000000Coooooo`000?l0003o00001_ooool2o`0000Sooooo0_l0000Ioooo
oaoo00001Oooool2o`0000?ooooo0_l00007ooooo`;o00000oooool2o`0000Kooooo0_l00002oooo
oa?o000000?oooooo`000?l000001?l00002ooooo`;o00001?ooool5o`0000;ooooo1?l000000ooo
oooo0000o`000004ooooo`;o00001?ooool2o`0000?ooooo1?l00004ooooo`;o00000_ooool2o`00
00;ooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`0jooooo`;o00000_ooool2o`0000Ko
oooo0_l00008ooooo`;o00001oooool2o`0000Wooooo0ol00004oooooa3o000000?oooooo`000?l0
00003Ol0000Gooooo`;o00001?ooool4o`0000;ooooo7_l00004ooooo`;o000000?oooooo`000?l0
00000_ooool2o`0000Cooooo0_l00003ooooo`;o00001?ooool2o`0000?ooooo1?l000001?oooooo
0000o`000?ooool2o`0000;ooooo0_l000001?oooooo0000o`000?l0001:ooooo`007?ooool00ol0
003oooooooooo`0jooooo`;o00000_ooool2o`0001Wooooo0_l00009ooooo`?o00001?oooolPo`00
01Cooooo0_l00007ooooo`;o00001?ooool;o`0000;ooooo3?l000000ooooooo0000o`000002o`00
00?ooooo0_l00004ooooo`;o00001_ooool2o`0000Gooooo0_l00007ooooo`Co000000?oooooo`00
0?l000002?ooool2o`0000[ooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0nooooo`;o
00001_ooool2o`0001Sooooo0_l00006ooooo`;o000000?oooooo`000?l000007?l0000>ooooo`;o
00001_ooool2o`0000oooooo0ol000000ooooooo0000o`00000Ao`000003ooooool0003o000000;o
00000oooool2o`0000Cooooo0_l00003ooooo`;o00002?ooool2o`0000?ooooo0_l0000<ooooo`;o
00003oooool2o`0003oooooo000Looooo`03o`000?oooooooooo04Gooooo0ol00005ooooo`;o0000
2_ooool4o`0000?ooooo1?l00004ooooob7o00000oooool2o`0000Wooooo0_l0000?ooooo`;o0000
1_ooool4o`000003ooooool0003o0000017o00000_ooool2o`0000?ooooo0_l00003ooooo`;o0000
00Coooooo`000?l0003ooooo0_l0000<ooooo`?o00001?ooool2o`0000Kooooo0_l0001@ooooo`00
7?ooool00ol0003oooooooooo`0looooo`;o00001oooool3o`0000;ooooo0_l000000ooooooo0000
o`00000:ooooo`Co00001Oooool4o`0000;ooooo0ol000000ooooooo0000o`00000Io`0000Gooooo
0_l0000;ooooo`;o00002Oooool7o`0000Cooooo6ol00008ooooo`Co000000Coooooo`000?l0003o
oooo0_l00008ooooo`;o00000_ooool2o`0000Gooooo0_l00006ooooo`;o00001?ooool2o`0004[o
oooo000Looooo`03o`000?oooooooooo03cooooo0ol0000;ooooo`;o000000?oooooo`000?l00000
5Oooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000001Go0000
4_ooool2o`0000Wooooo1?l000000ooooooo0000o`000004oooooaOo00000_ooool2o`0000Sooooo
1?l00003ooooo`Co00001oooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool3o`0000co
oooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00003_ooool2o`0000;ooooo
0_l0000Hoooooako00001?ooool2o`0000Wooooo0_l0000:ooooo`;o000000?oooooo`000?l00000
2?oooolAo`000003ooooool0003o000000;o00001?ooool2o`0000Kooooo0ol00003ooooo`Ko0000
2Oooool2o`000004ooooool0003o0000ooooo`Co0000Eoooool001cooooo0_l00012ooooo`;o0000
2_ooool2o`0000;ooooo0_l0000@ooooo`;o00001ooooolHo`000003ooooool0003o000000Go0000
00?oooooo`000?l000002Oooool2o`0000;ooooo0_l00009ooooo`;o00001Oooool2o`000003oooo
ool0003o000001Co00001?ooool2o`0000Oooooo1?l00002ooooo`Go00004Oooool2o`0005Oooooo
000Looooo`03o`000?oooooooooo047ooooo0_l0000?ooooo`Co00002oooool4o`0000Kooooo9Ol0
000;ooooo`?o00002oooool2o`0000?ooooo0_l000000ooooooo0000o`00000Eo`0000kooooo0_l0
0002ooooo`Ko0000JOooool001cooooo00?o0000ooooooooool0AOooool2o`0000Oooooo0_l00002
ooooo`Ko00002Oooool2o`0000Sooooo9Ol00004ooooo`;o000000?oooooo`000?l000001Ol0000;
ooooo`;o00000oooool2o`000003ooooool0003o0000017o000000Coooooo`000?l0003o00001?oo
ool2o`0000gooooo1Ol00006ooooo`Co00001Oooool2o`0000Cooooo0_l00007ooooo`;o00004?oo
ool2o`0003Oooooo000Looooo`03o`000?oooooooooo04Gooooo0_l00004ooooo`;o000000?ooooo
o`000?l000001_ooool2o`0000Kooooo0_l0000;ooooo`;o000000?oooooo`000?l000005ol00000
1?oooooo0000o`000?ooool4o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`00
0002o`0000Wooooo0_l00007ooooo`;o00001?oooolDo`0000Gooooo0_l0000=ooooo`?o00002?oo
ool4o`0000Gooooo0_l00004ooooo`;o00001oooool4o`0000kooooo0_l0000gooooo`007?ooool0
0ol0003oooooooooo`12ooooo`;o00001oooool2o`0000Wooooo1_l00002ooooo`;o00002Oooool4
o`0000;ooooo6?l000000ooooooo0000o`000003o`0000?ooooo0_l00005ooooo`;o00001?ooool2
o`0000Gooooo0_l00007ooooo`;o00001?oooolBo`00017ooooo0_l00002ooooo`Co000000?ooooo
o`000?l000000ol0000;ooooo`;o00003oooool2o`0004Oooooo000Looooo`03o`000?oooooooooo
04;ooooo1_l0000@ooooo`Co00002_ooool2o`000004ooooool0003o0000ooooo`;o000000?ooooo
o`000?l000004_l000000ooooooo0000o`000007o`0000Kooooo0_l00008ooooo`;o00001Oooool2
o`0000gooooo2ol000000ooooooo0000o`000002o`0000_ooooo0_l00006ooooo`;o000000?ooooo
o`000?l000000ol000000ooooooo0000o`000003o`0000Sooooo1Ol0001Hooooo`007?ooool00ol0
003oooooooooo`0jooooo`;o00002?ooool4o`0000?ooooo0_l0000Iooooo`;o00001?ooool2o`00
0003ooooool0003o000001;o000000?oooooo`000?l000000ol0000:ooooo`?o00002Oooool2o`00
00Kooooo0_l0000=ooooo`go00002oooool2o`0000Oooooo1Ol000000ooooooo0000o`00000=oooo
o`Co00003_ooool2o`0000?ooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0jooooo`;o
000000?oooooo`000?l000001?ooool4o`0000Cooooo0ol0000Aooooo`;o00002oooool2o`000003
ooooool0003o000001;o00001?ooool3o`0000[ooooo0_l00004ooooo`;o00000oooool2o`0000Ko
oooo0_l0000>ooooo`Wo00003_ooool2o`0000Gooooo1Ol00003ooooo`;o00000_ooool2o`0000_o
oooo0_l00002ooooo`Co00002?ooool2o`000003ooooool0003o000000;o00001_ooool2o`0003co
oooo000Looooo`03o`000?oooooooooo03gooooo0_l00004ooooo`Co00000oooool4o`00017ooooo
0_l0000?oooooa?o00001?ooool3o`00013ooooo0_l00009ooooo`;o00000_ooool2o`0000?ooooo
0_l00007ooooo`Co00000oooool2o`0000[ooooo0_l00009ooooo`Ko00000_ooool2o`0000;ooooo
0_l00003ooooo`;o00002Oooool5o`0000;ooooo0_l00007ooooo`;o00002?ooool2o`0003cooooo
000Looooo`03o`000?oooooooooo04[ooooo0_l0000@ooooo`;o00002oooool2o`0000Oooooo2ol0
00000ooooooo0000o`000002o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l0
0006ooooo`;o00000_ooool2o`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l000003_oo
ool2o`000003ooooool0003o000000Kooooo0_l000000ooooooo0000o`000008o`000003ooooool0
003o000000Cooooo0_l00009ooooo`;o00001Oooool2o`0004oooooo000Looooo`03o`000?oooooo
oooo04Sooooo1?l00008ooooo`;o00001_ooool2o`0000_ooooo0_l00006ooooo`;o00001?ooool5
o`0000Cooooo0_l00005ooooo`Co00000oooool2o`0000Gooooo0_l00006ooooo`;o00001oooool2
o`0000[ooooo1?l00004ooooo`;o00002oooool2o`0000Wooooo0_l000000ooooooo0000o`000006
o`0000?ooooo0_l00002ooooo`;o0000Hoooool001cooooo00?o0000ooooooooool0B?ooool4o`00
00Gooooo0_l000001?oooooo0000o`000?ooool2o`0000Kooooo0_l00009ooooo`;o00001Oooool2
o`0000Kooooo1?l00003ooooo`;o00001oooool2o`0001Oooooo0_l00002ooooo`;o000000Cooooo
o`000?l0003ooooo0_l00004ooooo`;o00001_ooool2o`0000;ooooo0_l0000<ooooo`;o00001?oo
ool6o`0000Gooooo0_l000000ooooooo0000o`000002ooooo`;o0000Hoooool001cooooo00?o0000
ooooooooool0DOooool2o`0000Cooooo0_l00005ooooo`?o00001oooool4o`0000[ooooo0_l00000
0ooooooo0000o`000002o`0001Kooooo0_l0000=ooooo`;o000000?oooooo`000?l000000_ooool2
o`000003ooooool0003o000000Cooooo0_l0000:ooooo`Ko00002?ooool2o`0000Cooooo1?l00007
ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Cooooo0_l0000Iooooo`;o0000@?ooool0
01cooooo00?o0000ooooooooool0@_ooool2o`0000;ooooo0_l0000>ooooo`?o00001Oooool3o`00
0003ooooool0003o000000Cooooo0_l00009ooooo`Ko00000_ooool2o`00013ooooo0_l00004oooo
o`;o00000_ooool3o`0000?ooooo0_l00003ooooo`Go00002oooool2o`0000Cooooo0_l00005oooo
o`Go00002oooool2o`000004ooooool0003o0000o`0000Wooooo0_l00004ooooo`Ko00000_ooool2
o`0001Wooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00000_ooool4o`00
00Cooooo0_l00006ooooo`?o00001_ooool2o`000003ooooool0003o000000oooooo1_l00002oooo
o`;o00004?ooool2o`0000;ooooo0_l00004ooooo`?o00000oooool2o`0000Cooooo0_l0000=oooo
o`;o00001?ooool2o`0000oooooo0_l000000ooooooo0000o`000006o`0000[ooooo0_l00004oooo
o`;o00000_ooool2o`0005oooooo000Looooo`03o`000?oooooooooo04Sooooo0_l00004ooooo`;o
00002oooool2o`0000kooooo0_l00005ooooo`Ko00003_ooool2o`0000Kooooo0_l000000ooooooo
0000o`000002o`0000Wooooo0ol00006ooooo`;o00006?ooool>o`0000;ooooo0_l0000;ooooo`;o
000000?oooooo`000?l00000I_ooool001cooooo0_l0001>ooooo`;o000000Coooooo`000?l0003o
oooo0_l00006ooooo`;o00003Oooool3o`0000?ooooo1_l0000@ooooo`?o00000oooool4o`0000;o
oooo0ol00009ooooo`?o000000?oooooo`000?l000000_l000000ooooooo0000o`000009ooooo`;o
00003Oooool;o`0000[ooooo0_l00006ooooo`;o000000Coooooo`000?l0003ooooo0_l00002oooo
o`;o0000Goooool001cooooo00?o0000ooooooooool0B?ooool2o`0000?ooooo0_l000001?oooooo
0000o`000?ooool2o`0001Gooooo0_l00004ooooo`Co00002_ooool2o`0000Oooooo0_l00003oooo
o`;o00001?ooool2o`0000kooooo1?l0000;ooooo`?o00000_ooool4o`0000cooooo0_l0000>oooo
o`;o00001_ooool2o`000004ooooool0003o0000ooooo`?o000000?oooooo`000?l000002Oooool2
o`0005Cooooo000Looooo`03o`000?oooooooooo04Sooooo0_l00006ooooo`Co00002_ooool2o`00
00Wooooo0_l0000=ooooo`;o00001?ooool4o`0000Cooooo1?l000000ooooooo0000o`00000Toooo
o`;o00000oooool4o`0000_ooooo0_l0000:ooooo`;o00000oooool2o`0000Kooooo0_l00005oooo
o`?o00000oooool2o`0000Kooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`1@ooooo`Co
000000?oooooo`000?l000001oooool2o`0000Cooooo0_l00003ooooo`Ko00002Oooool2o`0000Co
oooo1?l00004ooooo`Co000000?oooooo`000?l00000<_ooool4o`0000;ooooo0_l00003ooooo`;o
00000_ooool2o`000003ooooool0003o000000?ooooo0_l0000>ooooo`;o00000oooool2o`0000;o
oooo0_l00004ooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0C?ooool4o`0000;ooooo
1Ol0000=ooooo`;o00001Oooool4o`0000oooooo0_l00007ooooo`;o00000_ooool2o`0000;ooooo
0_l00008ooooo`;o00009?ooool8o`0000?ooooo0_l00002ooooo`;o00005_ooool2o`0000Oooooo
0_l00004ooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0C?ooool4o`0000;ooooo1?l0
0002ooooo`;o00003_ooool2o`000003ooooool0003o000000Wooooo0_l00009ooooo`;o000000Co
ooooo`000?l0003ooooo0_l00002ooooo`Ko00001?ooool2o`0000;ooooo0_l0000Cooooo`;o0000
4oooool2o`0000Wooooo0_l0000Jooooo`?o0000G?ooool001cooooo00?o0000ooooooooool0B_oo
ool2o`0000Sooooo0_l00002ooooo`;o00001?ooool2o`0000Sooooo0_l00007ooooo`;o00000ooo
ool2o`0000?ooooo1?l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o0000
0_ooool2o`000004ooooool0003o0000o`0000?ooooo0_l0000Booooo`;o00002Oooool2o`000003
ooooool0003o000000Gooooo0ol00008ooooo`;o00000oooool2o`0000Oooooo0_l00002ooooo`;o
00002?ooool3o`0005cooooo000Looooo`03o`000?oooooooooo04[ooooo0_l0000<ooooo`;o0000
1?ooool5o`0000kooooo0_l00008ooooo`Co00001Oooool2o`000004ooooool0003o0000o`0000Oo
oooo0_l000000ooooooo0000o`000002ooooo`Go00007?ooool2o`000003ooooool0003o000000Go
oooo0ol00002ooooo`;o000000?oooooo`000?l000001_ooool2o`000003ooooool0003o000000Co
oooo0_l00002ooooo`;o00001_ooool3o`0005kooooo000Looooo`03o`000?oooooooooo05?ooooo
0_l00003ooooo`;o00001Oooool4o`0000oooooo0_l00005ooooo`;o000000?oooooo`000?l00000
2_ooool2o`0000Oooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l00000
3Oooool2o`0000Oooooo0_l00009ooooo`;o00002?ooool2o`000003ooooool0003o000000Gooooo
0_l00002ooooo`Co00003_ooool3o`0005kooooo000Looooo`03o`000?oooooooooo05?ooooo0_l0
000:ooooo`;o00004Oooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o000000?o
ooooo`000?l000003oooool2o`000003ooooool0003o000001?ooooo0ol00007ooooo`;o00002Ooo
ool2o`0000Wooooo0_l00007ooooo`;o00000oooool3o`00017ooooo0ol0001Kooooo`007?ooool0
0ol0003oooooooooo`1Oooooo`;o00002_ooool2o`0000;ooooo0_l00005ooooo`?o00001?ooool2
o`000003ooooool0003o000000;ooooo0_l0000<ooooo`Co00004_ooool3o`000003ooooool0003o
000000Wooooo0_l00005ooooo`;o00002Oooool2o`0001Gooooo0_l00009ooooo`?o0000Foooool0
01cooooo00?o0000ooooooooool0FOooool2o`000003ooooool0003o000000Oooooo0_l00004oooo
o`;o00000_ooool2o`0000Kooooo0_l0000;ooooo`;o00001?ooool2o`0000Kooooo1?l0000Boooo
o`;o00000_ooool2o`0000Wooooo0_l00003ooooo`Co00000oooool2o`0000?ooooo0_l0000=oooo
o`;o00001oooool2o`0000Wooooo0_l0001Looooo`007?ooool00ol0003oooooooooo`1Gooooo`Co
000000?oooooo`000?l000001oooool2o`0000Cooooo0_l00005ooooo`;o00004?ooool2o`0000Co
oooo0_l00006ooooo`Co00009_ooool2o`0000Gooooo0_l000000ooooooo0000o`000002o`0000go
oooo0_l0001`ooooo`007?ooool00ol0003oooooooooo`1Gooooo`Co00002Oooool2o`0000Cooooo
0ol00005ooooo`;o00004?ooool2o`0000cooooo1?l0000Iooooo`;o00001oooool2o`0000?ooooo
0_l00004ooooo`Go00003?ooool2o`0007?ooooo000Looooo`03o`000?oooooooooo04kooooo0_l0
000Dooooo`;o00001?ooool2o`000003ooooool0003o000001?ooooo0_l00002ooooo`Go00001Ooo
ool2o`0000Wooooo0_l0000:ooooo`;o00001Oooool3o`0000Oooooo0_l00003ooooo`;o00001_oo
ool2o`0000gooooo0_l00009ooooo`;o0000J?ooool001cooooo00?o0000ooooooooool0C_ooool2
o`0000cooooo0_l0000?ooooo`;o00000oooool2o`0000kooooo0ol000000ooooooo0000o`000003
o`0000Gooooo0_l00005ooooo`;o00000_ooool3o`0000Kooooo0_l000001?oooooo0000o`000?l0
0004ooooo`;o0000;oooool2o`0006Sooooo000Looooo`;o0000GOooool3o`0000Cooooo0ol0000<
ooooo`;o00001?ooool2o`0000Wooooo0_l0000:ooooo`;o00001?ooool4o`0000?ooooo0_l00004
ooooo`Co000000?oooooo`000?l000000_l0000<ooooo`;o00002_ooool2o`00013ooooo0ol0000A
ooooo`;o0000G_ooool001cooooo00?o0000ooooooooool0GOooool2o`0000Cooooo0ol0000Boooo
o`;o00001_ooool4o`0000Cooooo0_l00005ooooo`;o00001?ooool2o`0000Gooooo0ol00003oooo
o`?o00001?ooool2o`0000cooooo0_l0000:ooooo`;o00000_ooool2o`0000Wooooo1_l0000>oooo
o`;o000000?oooooo`000?l000002oooool2o`00057ooooo000Looooo`03o`000?oooooooooo05co
oooo0_l0000<ooooo`;o00005?ooool6o`0000;ooooo0_l00008ooooo`;o00002?ooool5o`0000;o
oooo0_l0000Rooooo`;o00001?ooool3o`0000;ooooo0ol00005ooooo`;o00002?ooool4o`0000ko
oooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`1Looooo`;o00001Oooool2o`0000Gooooo
0_l0000Hooooo`;o00000_ooool2o`0000;ooooo0_l00004ooooo`;o000000Coooooo`000?l0003o
oooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00000_ooool2o`0000Kooooo0_l0000?oooo
o`;o00001?ooool2o`0000Kooooo0_l000001?oooooo0000o`000?l0000:ooooo`;o00000oooool2
o`0000?ooooo0_l0001Sooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o00001?ooool2o`00
00Kooooo0_l0000<ooooo`;o00004Oooool2o`0000;ooooo0_l00003ooooo`Go000000?oooooo`00
0?l000001oooool2o`0000;ooooo0_l000000ooooooo0000o`00000?ooooo`;o00001?ooool2o`00
00Kooooo1?l0000<ooooo`;o00000_ooool3o`0006Sooooo000Looooo`03o`000?oooooooooo05?o
oooo0_l00008ooooo`Go00002Oooool4o`0000[ooooo0_l0000Eooooo`;o00001Oooool2o`0000_o
oooo0_l00002ooooo`;o000000?oooooo`000?l000001_ooool2o`0000cooooo0_l00007ooooo`Co
00000oooool4o`0000Gooooo0_l00002ooooo`;o00005?ooool2o`0005?ooooo000Looooo`03o`00
0?oooooooooo053ooooo0_l000000ooooooo0000o`000008ooooo`Go00002oooool2o`0000Gooooo
0_l000000ooooooo0000o`00000Gooooo`?o00002_ooool2o`0000;ooooo0_l00007ooooo`;o0000
1oooool2o`0000Sooooo0ol000000ooooooo0000o`000007ooooo`;o00001Oooool4o`0000;ooooo
0_l0000Kooooo`;o0000Doooool001cooooo00?o0000ooooooooool0D?ooool2o`0000kooooo0_l0
0008ooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`00000Gooooo`?o00000_oo
ool2o`0000Kooooo0_l00002ooooo`;o00001?ooool5o`00017ooooo0ol00003ooooo`?o00004?oo
ool3o`0001Kooooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`1Pooooo`?o00001oooool3
o`000003ooooool0003o000001Oooooo0_l00003ooooo`;o00001Oooool4o`0000Sooooo0_l00006
ooooo`Go00003?ooool2o`0000Wooooo0ol00005ooooo`;o00001oooool6o`0001Gooooo0_l0001H
ooooo`007?ooool00ol0003oooooooooo`1Qooooo`;o00002?ooool2o`000003ooooool0003o0000
01Oooooo0_l00003ooooo`;o00001Oooool2o`0000Kooooo0_l00002ooooo`;o00001Oooool2o`00
00;ooooo0_l0000<ooooo`;o00001_ooool2o`000003ooooool0003o000000Kooooo0_l00007oooo
o`?o000000?oooooo`000?l00000Koooool001cooooo00?o0000ooooooooool0IOooool2o`0000Co
oooo0_l000000ooooooo0000o`00000Pooooo`Ko00001Oooool2o`0000Wooooo0_l00002ooooo`;o
00003?ooool3o`000003ooooool0003o000000;ooooo1?l0000@ooooo`?o0000L_ooool001cooooo
00?o0000ooooooooool0H_ooool2o`000003ooooool0003o000000?ooooo0_l00007ooooo`;o0000
4?ooool2o`0000Gooooo0_l00002ooooo`Ko00000oooool2o`0000cooooo0_l0000?ooooo`?o0000
00?oooooo`000?l000001?ooool2o`0000Wooooo0_l00005ooooo`;o0000Loooool001cooooo00?o
0000ooooooooool0H_ooool2o`0000;ooooo0_l00002ooooo`;o00001oooool3o`0000oooooo0_l0
0005ooooo`;o00000oooool2o`0000Kooooo0_l0000<ooooo`;o00001Oooool2o`0000;ooooo0_l0
000@ooooo`;o00001oooool2o`0000?ooooo0_l0001eooooo`007?ooool00ol0003oooooooooo`1T
ooooo`Ko00000oooool2o`0000Gooooo0_l00005ooooo`?o00004oooool2o`00013ooooo0_l00009
ooooo`;o00000_ooool2o`00013ooooo0_l00007ooooo`;o00000oooool2o`0007Gooooo00001_oo
ooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0
1_ooool00ol0003oooooooooo`1Tooooo`;o00000_ooool4o`000003ooooool0003o000000;ooooo
0_l00002ooooo`;o00001?ooool3o`00013ooooo0ol0000Booooo`Co00004Oooool2o`0001?ooooo
0_l0000Fooooo`?o0000HOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Co
oooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo06Wooooo0ol00005oooo
o`;o00000_ooool2o`0000Oooooo0_l0000>ooooo`Co00002?ooool2o`0000Wooooo0_l0000Aoooo
o`Co00002Oooool2o`0001kooooo0ol0001Qooooo`0000?ooooooa0@4?ooool00_ooool00ol@413o
ooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`1[oooo
o`;o00001?ooool2o`0000;ooooo0_l00007ooooo`;o00003?ooool2o`0000;ooooo0_l00006oooo
o`Go00005Oooool2o`0000Kooooo0_l00009ooooo`;o00002Oooool2o`0007Oooooo00000ooooooo
0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06oooo
o`?o0000Ioooool2o`0000;ooooo0_l00002ooooo`Co00006Oooool2o`0000;ooooo0_l00006oooo
o`;o000000?oooooo`000?l000002?ooool2o`0000Kooooo0ol00002ooooo`;o00007?ooool2o`00
07Oooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Goc<c<o`000?l0
003o0000olc<c006ooooo`03o`000?oooooooooo06Oooooo0_l00002ooooo`;o00000_ooool2o`00
02;ooooo0_l00006ooooo`;o00002?ooool4o`0000Cooooo0ol0000<ooooo`;o00000_ooool2o`00
0003ooooool0003o000001Sooooo0_l0001Zooooo`0000?ooooooa0@4?ooool00_ooool00ol@413o
ooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`1Uoooo
o`;o00000_ooool4o`0000Cooooo1?l0000Mooooo`?o00001?ooool4o`0000[ooooo0_l0000Coooo
o`;o00000_ooool2o`000003ooooool0003o0000017ooooo0_l00005ooooo`;o0000J_ooool00006
oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o
0000ooooooooool0IOooool2o`0000;ooooo0ol00005ooooo`Co00001Oooool2o`0000oooooo0_l0
0005ooooo`?o000000Coooooo`000?l0003ooooo1?l00008ooooo`;o00003_ooool2o`0000Cooooo
0_l00005ooooo`;o00001?ooool2o`0000cooooo0_l00006ooooo`;o0000JOooool00006ooooooo^
k^ko<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000oooo
ooooool0J_ooool2o`0000kooooo0_l00003ooooo`Go000000?oooooo`000?l000001?ooool2o`00
00Kooooo0_l000000ooooooo0000o`00000=ooooo`?o00002_ooool2o`000003ooooool0003o0000
00Cooooo0_l00005ooooo`;o00001?ooool2o`0001Cooooo0_l0001Yooooo`007?ooool00ol0003o
ooooooooo`1Zooooo`;o00000_ooool3o`0000kooooo1Ol000000ooooooo0000o`000006ooooo`;o
000000?oooooo`000?l000005?ooool2o`0000[ooooo0_l00007ooooo`;o00006?ooool2o`0007;o
oooo000Looooo`03o`000?oooooooooo06[ooooo0_l00002ooooo`?o000000?oooooo`000?l00000
5Oooool3o`000004ooooool0003o0000ooooo`;o00001Oooool2o`0000gooooo0_l0000Cooooo`;o
00000_ooool2o`0001Cooooo0_l0001booooo`007?ooool00ol0003oooooooooo`1Xooooo`Co0000
1_ooool2o`0000Kooooo0_l00005ooooo`;o00001_ooool3o`0000;ooooo0ol00006ooooo`;o0000
0_ooool2o`0000Wooooo1?l0000Booooo`;o000000?oooooo`000?l00000R?ooool001cooooo00?o
0000ooooooooool0J?ooool2o`0000gooooo0_l000000ooooooo0000o`000005ooooo`;o00002ooo
ool3o`0000Cooooo0_l00002ooooo`Co00002oooool2o`0000Oooooo0_l00005ooooo`;o00000_oo
ool4o`0001[ooooo0_l0001]ooooo`007?ooool00ol0003oooooooooo`1gooooo`Co00001_ooool2
o`0001;ooooo0_l00002ooooo`?o00001oooool2o`0000cooooo1Ol00002ooooo`;o00001?ooool2
o`0001[ooooo0_l0001]ooooo`007?ooool00ol0003oooooooooo`1iooooo`;o00001_ooool2o`00
01Oooooo1?l00005ooooo`;o00000oooool2o`0000Wooooo0ol00002ooooo`Co0000SOooool001co
oooo00?o0000ooooooooool0P_ooool2o`0000Oooooo0_l00004ooooo`;o00002Oooool2o`0000[o
oooo0_l00006ooooo`Ko00000_ooool6o`0001[ooooo0_l0001_ooooo`007?ooool00ol0003ooooo
ooooo`22ooooo`;o00001oooool3o`0000?ooooo0_l00003ooooo`;o00004?ooool2o`0000Kooooo
1?l00008ooooo`;o00006_ooool2o`0006oooooo000Looooo`03o`000?oooooooooo08cooooo0_l0
0008ooooo`;o00006_ooool2o`0009Gooooo000Looooo`03o`000?oooooooooo0:Kooooo0_l0002Q
ooooo`007?ooool00ol0003oooooooooo`2Rooooo`;o000000Coooooo`000?l0003o00000oooool2
o`0009cooooo000Looooo`;o0000Toooool2o`0000kooooo1_l00003ooooo`;o0000W?ooool001co
oooo00?o0000ooooooooool0T_ooool2o`00013ooooo0_l00008ooooo`;o0000VOooool001cooooo
00?o0000ooooooooool0NOooool2o`0003?ooooo0_l0000Qooooo`Co0000M?ooool001cooooo00?o
0000ooooooooool0NOooool2o`0005Kooooo1?l0001dooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo07Wooooo0_l0003>ooooo`00
7?ooool00ol0003oooooooooo`1iooooo`;o0000c_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
09gooooo0_l0000Rooooo`;o0000Q_ooool001cooooo0_l0002Nooooo`;o00008_ooool2o`0008Ko
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0;Oooooo0_l0002@ooooo`007?ooool00ol0003oooooooooo`2gooooo`;o0000T?ooool001cooooo
00?o0000ooooooooool0TOooool2o`000;Kooooo000Looooo`03o`000?oooooooooo097ooooo0_l0
002fooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0YOooool2o`000:;ooooo000Looooo`03o`00
0?oooooooooo0:Gooooo0_l0002Rooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Booooo`Co
000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003ooooooooo
o`05ooooo`?o0000oooooom:ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Doooo
o`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`00
5?ooool00ol0003oooooooooo`3ooooooe;ooooo000Booooo`03oeEEEOmVIVKo00000?ooooooE?oo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:7ooooo00Co410@o`000?l0003o
oooo0_l000000ol@413oooooooooo`0Fooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o
<S8bonk^kP?ooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oa0@4?o<
c<`0S?ooool00:;ooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00003?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OlQ8B7oV9RHoooooonHV9So
8B4Q00?ooooo00GoEEEEogMgMoooooooV9RHob4Q8@2<ooooo`00X_ooool01Ol0003ooooooooooooo
oooo000001_ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000S?ooool00:;o
oooo00Go0000ooooooooooooooooo`000009ooooo`Ko00003?ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000000oooool01Olb<S;oV9RHoooooonHV9So<S8b00?ooooo00Go
0000oiRHV?ooooooV9RHob4Q8@2<ooooo`00X_ooool01Ol0003oQhN7oooooonYZJWo000001_ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Goc<c<o`000?l0
003o0000olc<c003ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0S?ooool00:7ooooo00?o410@o`00
0?mgMgL00_l000000onHV9Soooooooooo`0Iooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@4003ooooo`05oa0@4?nj^[[ooooookZj^_l@41000oooool00omEEEGoQhN7oooo
o`2>ooooo`00`_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool01Ol0003o^[Zjoooooonj^[[o000000?ooooo00?ogMgMoa0@4?nHV9P0S_ooool00<3ooooo00?o
EEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@04ooooo`04olc<c?m4A4Co0000oa0@48cooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1092) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.37703 .6538 Mdot
.37243 .62351 Mdot
.64026 .49871 Mdot
.39804 .40324 Mdot
.38986 .77231 Mdot
.67306 .49802 Mdot
.58859 .62771 Mdot
.54121 .66004 Mdot
.64941 .50467 Mdot
.43044 .6674 Mdot
.58115 .62632 Mdot
.50086 .42173 Mdot
.56783 .63244 Mdot
.41168 .3883 Mdot
.21878 .69251 Mdot
.4253 .34479 Mdot
.3701 .57865 Mdot
.60282 .38457 Mdot
.3607 .38204 Mdot
.69863 .48976 Mdot
.41294 .61466 Mdot
.4071 .3994 Mdot
.34786 .6469 Mdot
.41231 .38825 Mdot
.38526 .40433 Mdot
.38067 .59497 Mdot
.38437 .56938 Mdot
.40837 .44534 Mdot
.38189 .38478 Mdot
.55072 .66431 Mdot
.46602 .26294 Mdot
.27238 .74236 Mdot
.35634 .42567 Mdot
.68906 .72886 Mdot
.53745 .65176 Mdot
.27393 .59857 Mdot
.66725 .51901 Mdot
.54883 .65189 Mdot
.53903 .64483 Mdot
.59836 .64034 Mdot
.54884 .63773 Mdot
.38215 .60411 Mdot
.52271 .673 Mdot
.49777 .60711 Mdot
.38965 .35526 Mdot
.4467 .75633 Mdot
.32504 .29285 Mdot
.4509 .42312 Mdot
.37575 .58112 Mdot
.65639 .43302 Mdot
.62746 .73795 Mdot
.5885 .62134 Mdot
.62463 .53834 Mdot
.74082 .78626 Mdot
.55623 .65737 Mdot
.37806 .36317 Mdot
.64758 .52195 Mdot
.41494 .40458 Mdot
.41656 .39012 Mdot
.20692 .48758 Mdot
.41685 .45285 Mdot
.6083 .35235 Mdot
.34073 .65514 Mdot
.55642 .41879 Mdot
.65557 .51307 Mdot
.54412 .63398 Mdot
.38109 .62995 Mdot
.56818 .63937 Mdot
.45876 .46636 Mdot
.67907 .53086 Mdot
.449 .42458 Mdot
.55538 .62573 Mdot
.40322 .6016 Mdot
.43223 .42735 Mdot
.78085 .48291 Mdot
.14722 .47873 Mdot
.62234 .33094 Mdot
.23985 .54259 Mdot
.20833 .5324 Mdot
.69665 .38433 Mdot
.40875 .3662 Mdot
.51895 .20577 Mdot
.17786 .59223 Mdot
.33733 .63441 Mdot
.34424 .40722 Mdot
.5843 .5059 Mdot
.42819 .42452 Mdot
.38071 .72142 Mdot
.39135 .36032 Mdot
.81315 .52312 Mdot
.65391 .49671 Mdot
.35409 .61344 Mdot
.39775 .4001 Mdot
.3965 .44512 Mdot
.32209 .31982 Mdot
.46731 .43075 Mdot
.40366 .4359 Mdot
.40392 .6197 Mdot
.57234 .61423 Mdot
.48488 .36589 Mdot
.53643 .68431 Mdot
.62579 .51571 Mdot
.46481 .40337 Mdot
.68079 .52206 Mdot
.40675 .60303 Mdot
.43337 .43462 Mdot
.53813 .63054 Mdot
.45493 .39157 Mdot
.57747 .72189 Mdot
.37236 .62697 Mdot
.39127 .44077 Mdot
.61704 .35239 Mdot
.72833 .29512 Mdot
.3489 .61794 Mdot
.71266 .36703 Mdot
.41005 .36101 Mdot
.40753 .42709 Mdot
.37216 .62078 Mdot
.63159 .50502 Mdot
.35832 .71241 Mdot
.32943 .63361 Mdot
.60035 .63672 Mdot
.33434 .64729 Mdot
.35946 .44453 Mdot
.66009 .49975 Mdot
.66168 .67931 Mdot
.62113 .60841 Mdot
.46345 .24515 Mdot
.4253 .42079 Mdot
.47392 .69792 Mdot
.681 .47491 Mdot
.36434 .60914 Mdot
.57183 .64063 Mdot
.39703 .33363 Mdot
.35816 .63899 Mdot
.58086 .64906 Mdot
.61486 .36837 Mdot
.69626 .6226 Mdot
.34606 .58947 Mdot
.49188 .63262 Mdot
.52895 .62601 Mdot
.59548 .63223 Mdot
.73209 .70392 Mdot
.38267 .62205 Mdot
.58181 .35869 Mdot
.56913 .65423 Mdot
.43138 .27547 Mdot
.36725 .40057 Mdot
.54402 .23942 Mdot
.45555 .17219 Mdot
.6997 .7205 Mdot
.74003 .5884 Mdot
.56378 .35286 Mdot
.58437 .61053 Mdot
.38016 .41977 Mdot
.38816 .59397 Mdot
.38863 .60708 Mdot
.43713 .44521 Mdot
.39212 .40541 Mdot
.4441 .42842 Mdot
.38399 .43749 Mdot
.18648 .4871 Mdot
.45438 .38118 Mdot
.3873 .21619 Mdot
.34941 .61142 Mdot
.39041 .42109 Mdot
.6399 .52996 Mdot
.40935 .46717 Mdot
.54879 .63385 Mdot
.4082 .40821 Mdot
.39698 .4075 Mdot
.41175 .45435 Mdot
.58659 .61934 Mdot
.26082 .71169 Mdot
.52646 .17798 Mdot
.32094 .75357 Mdot
.76806 .44851 Mdot
.68665 .48976 Mdot
.42074 .42727 Mdot
.59872 .34504 Mdot
.29196 .56334 Mdot
.41702 .36967 Mdot
.78178 .28742 Mdot
.40022 .42567 Mdot
.34659 .75218 Mdot
.36928 .47637 Mdot
.34383 .78163 Mdot
.52403 .22056 Mdot
.37678 .42055 Mdot
.37056 .31325 Mdot
.36807 .5401 Mdot
.50465 .61093 Mdot
.55116 .63729 Mdot
.63656 .5248 Mdot
.6418 .51224 Mdot
.61035 .64152 Mdot
.4076 .65916 Mdot
.34908 .35189 Mdot
.47118 .44102 Mdot
.63814 .54581 Mdot
.35669 .66269 Mdot
.57554 .37102 Mdot
.39571 .63307 Mdot
.1611 .36874 Mdot
.61916 .72694 Mdot
.60697 .6631 Mdot
.62522 .34386 Mdot
.65065 .48101 Mdot
.62538 .52788 Mdot
.59046 .34109 Mdot
.44859 .39988 Mdot
.38498 .6251 Mdot
.65462 .77551 Mdot
.42798 .63205 Mdot
.70433 .74787 Mdot
.40002 .60298 Mdot
.45951 .64139 Mdot
.58126 .64137 Mdot
.67908 .51284 Mdot
.40699 .43059 Mdot
.44021 .40306 Mdot
.41581 .60394 Mdot
.44533 .42489 Mdot
.31955 .4066 Mdot
.41269 .43977 Mdot
.65239 .70603 Mdot
.62041 .32869 Mdot
.61017 .64188 Mdot
.45259 .23879 Mdot
.36759 .64885 Mdot
.6338 .28291 Mdot
.65955 .5361 Mdot
.2755 .56798 Mdot
.5595 .62214 Mdot
.61458 .36139 Mdot
.65927 .53784 Mdot
.5731 .37043 Mdot
.38041 .45137 Mdot
.65602 .46235 Mdot
.61284 .34287 Mdot
.22713 .61074 Mdot
.36895 .40893 Mdot
.18245 .48246 Mdot
.57397 .60964 Mdot
.32807 .62794 Mdot
.41611 .45233 Mdot
.69011 .50268 Mdot
.3535 .42205 Mdot
.74019 .559 Mdot
.66098 .68148 Mdot
.63805 .47157 Mdot
.71333 .4444 Mdot
.60789 .36578 Mdot
.69618 .57586 Mdot
.48365 .68327 Mdot
.38479 .58312 Mdot
.46491 .39224 Mdot
.32446 .78555 Mdot
.56922 .65376 Mdot
.44847 .39019 Mdot
.68093 .69337 Mdot
.5654 .65285 Mdot
.41669 .40566 Mdot
.5456 .6124 Mdot
.38967 .60966 Mdot
.64917 .25311 Mdot
.3725 .57877 Mdot
.39537 .36017 Mdot
.54134 .62339 Mdot
.63672 .481 Mdot
.37594 .59073 Mdot
.45554 .40167 Mdot
.42205 .43924 Mdot
.55113 .49615 Mdot
.3898 .42814 Mdot
.29003 .72796 Mdot
.39633 .44027 Mdot
.64007 .52241 Mdot
.45872 .44046 Mdot
.84 .44908 Mdot
.62734 .60571 Mdot
.38204 .62911 Mdot
.65123 .45972 Mdot
.64672 .50768 Mdot
.68024 .32142 Mdot
.65506 .56813 Mdot
.42059 .36226 Mdot
.68976 .49511 Mdot
.60631 .26504 Mdot
.57008 .66451 Mdot
.47064 .40408 Mdot
.48864 .60921 Mdot
.65273 .43104 Mdot
.63261 .54342 Mdot
.38794 .34155 Mdot
.39455 .57961 Mdot
.39685 .40058 Mdot
.62864 .52789 Mdot
.38803 .66089 Mdot
.41574 .35625 Mdot
.42228 .5459 Mdot
.55035 .49663 Mdot
.58717 .64627 Mdot
.34811 .44913 Mdot
.46073 .40254 Mdot
.67475 .52159 Mdot
.38347 .6393 Mdot
.54742 .66828 Mdot
.37487 .59801 Mdot
.49499 .81646 Mdot
.58093 .7171 Mdot
.20118 .55853 Mdot
.56313 .37859 Mdot
.77301 .56297 Mdot
.3829 .80561 Mdot
.78914 .41438 Mdot
.55142 .29088 Mdot
.55773 .82465 Mdot
.63362 .52923 Mdot
.69667 .68781 Mdot
.64512 .51168 Mdot
.39049 .3835 Mdot
.66126 .50438 Mdot
.37429 .80462 Mdot
.41061 .43984 Mdot
.66598 .50812 Mdot
.66004 .28334 Mdot
.39283 .41393 Mdot
.34742 .62179 Mdot
.21091 .66276 Mdot
.8038 .41615 Mdot
.66488 .72197 Mdot
.66855 .46393 Mdot
.51493 .31767 Mdot
.40156 .43755 Mdot
.44576 .4541 Mdot
.36574 .58499 Mdot
.473 .41841 Mdot
.57167 .36691 Mdot
.62701 .34689 Mdot
.4922 .4931 Mdot
.55264 .19708 Mdot
.49085 .41477 Mdot
.37372 .58871 Mdot
.21498 .41719 Mdot
.7819 .49271 Mdot
.75709 .48407 Mdot
.57532 .60154 Mdot
.24631 .68553 Mdot
.3606 .49044 Mdot
.56486 .7029 Mdot
.51125 .59307 Mdot
.35856 .62212 Mdot
.27311 .72597 Mdot
.55125 .64152 Mdot
.28578 .38893 Mdot
.43667 .30232 Mdot
.4441 .39839 Mdot
.56972 .61938 Mdot
.49172 .43283 Mdot
.82468 .45512 Mdot
.29817 .29537 Mdot
.4319 .20822 Mdot
.40826 .35362 Mdot
.77817 .47319 Mdot
.40614 .41688 Mdot
.33717 .70844 Mdot
.39841 .44188 Mdot
.36782 .59585 Mdot
.38783 .69419 Mdot
.52656 .48472 Mdot
.48377 .17997 Mdot
.60933 .72787 Mdot
.56376 .35352 Mdot
.41272 .43453 Mdot
.4433 .39727 Mdot
.58836 .37218 Mdot
.33835 .62328 Mdot
.38236 .43632 Mdot
.61438 .28276 Mdot
.43738 .42048 Mdot
.54572 .64437 Mdot
.40212 .22914 Mdot
.37753 .5624 Mdot
.47937 .41081 Mdot
.37614 .66088 Mdot
.58658 .64986 Mdot
.53936 .6499 Mdot
.44035 .34526 Mdot
.59182 .66302 Mdot
.40007 .41648 Mdot
.30682 .26696 Mdot
.33868 .60738 Mdot
.33918 .44472 Mdot
.3493 .64477 Mdot
.23751 .55143 Mdot
.53429 .63761 Mdot
.64432 .69869 Mdot
.48155 .35682 Mdot
.55453 .63781 Mdot
.55866 .72007 Mdot
.48957 .40573 Mdot
.43589 .35222 Mdot
.80618 .5592 Mdot
.65679 .46664 Mdot
.54193 .48508 Mdot
.53335 .65103 Mdot
.46003 .40897 Mdot
.47337 .39606 Mdot
.58944 .64647 Mdot
.26746 .38093 Mdot
.72772 .33444 Mdot
.40674 .44238 Mdot
.35711 .5979 Mdot
.36625 .60749 Mdot
.42267 .35174 Mdot
.45011 .38437 Mdot
.66562 .47928 Mdot
.65925 .45782 Mdot
.69 .46588 Mdot
.54903 .49592 Mdot
.64752 .70188 Mdot
.48874 .77833 Mdot
.5982 .64023 Mdot
.499 .72516 Mdot
.81043 .50272 Mdot
.38484 .46435 Mdot
.68751 .47392 Mdot
.43616 .38936 Mdot
.40075 .40237 Mdot
.54954 .66974 Mdot
.67282 .71155 Mdot
.46306 .47566 Mdot
.33696 .60492 Mdot
.5347 .65799 Mdot
.42191 .32282 Mdot
.54021 .75638 Mdot
.6119 .34766 Mdot
.75525 .66606 Mdot
.55252 .62618 Mdot
.35471 .62474 Mdot
.53645 .62556 Mdot
.44125 .40676 Mdot
.36869 .36954 Mdot
.36574 .61835 Mdot
.60892 .33533 Mdot
.41724 .46238 Mdot
.41527 .40894 Mdot
.60023 .16804 Mdot
.78829 .46596 Mdot
.64595 .67998 Mdot
.38014 .42727 Mdot
.47269 .38555 Mdot
.58411 .38057 Mdot
.43944 .41583 Mdot
.43371 .44171 Mdot
.67748 .25012 Mdot
.62407 .66915 Mdot
.62303 .37319 Mdot
.28173 .40109 Mdot
.39765 .5971 Mdot
.30411 .7705 Mdot
.68265 .50913 Mdot
.59483 .66659 Mdot
.73399 .32815 Mdot
.62351 .51726 Mdot
.75571 .55148 Mdot
.29435 .76118 Mdot
.54134 .48946 Mdot
.63608 .32319 Mdot
.48886 .4548 Mdot
.41774 .44725 Mdot
.40823 .42026 Mdot
.594 .34786 Mdot
.38646 .6187 Mdot
.54629 .46156 Mdot
.19454 .40741 Mdot
.40545 .4073 Mdot
.31992 .39539 Mdot
.22727 .62997 Mdot
.64625 .42652 Mdot
.56879 .35832 Mdot
.61369 .33608 Mdot
.4113 .43092 Mdot
.69411 .27205 Mdot
.38102 .59399 Mdot
.45534 .40048 Mdot
.43755 .36508 Mdot
.66394 .46305 Mdot
.36838 .63145 Mdot
.63402 .5319 Mdot
.63855 .69892 Mdot
.339 .75392 Mdot
.61039 .16626 Mdot
.53603 .64556 Mdot
.27515 .67798 Mdot
.5608 .66531 Mdot
.50473 .20645 Mdot
.62315 .52825 Mdot
.41547 .36629 Mdot
.37821 .64349 Mdot
.45631 .397 Mdot
.43985 .37853 Mdot
.44799 .39839 Mdot
.45337 .46085 Mdot
.80729 .3332 Mdot
.59444 .33693 Mdot
.48107 .39418 Mdot
.63894 .51131 Mdot
.27645 .69293 Mdot
.1551 .51327 Mdot
.43578 .39732 Mdot
.42088 .4363 Mdot
.34715 .6295 Mdot
.4478 .44257 Mdot
.56817 .66389 Mdot
.38695 .63694 Mdot
.39277 .44291 Mdot
.25983 .68962 Mdot
.37606 .39581 Mdot
.33613 .76933 Mdot
.53383 .63026 Mdot
.52859 .70514 Mdot
.48493 .40536 Mdot
.65883 .67654 Mdot
.54197 .48494 Mdot
.69347 .49203 Mdot
.55544 .68092 Mdot
.66518 .51867 Mdot
.24643 .32519 Mdot
.35808 .40361 Mdot
.38082 .41539 Mdot
.47208 .39659 Mdot
.68781 .49275 Mdot
.37857 .73375 Mdot
.66293 .59135 Mdot
.3963 .32582 Mdot
.67533 .48222 Mdot
.3551 .66047 Mdot
.58991 .41665 Mdot
.36654 .64672 Mdot
.63066 .35415 Mdot
.57983 .6268 Mdot
.58371 .33335 Mdot
.67646 .72438 Mdot
.37114 .62523 Mdot
.41289 .58792 Mdot
.68232 .49686 Mdot
.58417 .5527 Mdot
.66845 .82249 Mdot
.58177 .44115 Mdot
.51115 .24315 Mdot
.36093 .58745 Mdot
.39272 .36598 Mdot
.46532 .21078 Mdot
.56863 .55122 Mdot
.66212 .51886 Mdot
.40838 .37456 Mdot
.67125 .26597 Mdot
.6665 .47869 Mdot
.46944 .4012 Mdot
.64051 .48431 Mdot
.55848 .6272 Mdot
.67137 .46944 Mdot
.35637 .57737 Mdot
.42991 .4337 Mdot
.64358 .83287 Mdot
.63204 .38713 Mdot
.39312 .43632 Mdot
.53294 .6543 Mdot
.4397 .53449 Mdot
.43058 .37917 Mdot
.6037 .37763 Mdot
.66559 .4964 Mdot
.57758 .46146 Mdot
.40483 .44297 Mdot
.68484 .48911 Mdot
.36887 .65388 Mdot
.55739 .68168 Mdot
.52293 .4424 Mdot
.66191 .68896 Mdot
.36978 .58423 Mdot
.51667 .67751 Mdot
.55592 .67675 Mdot
.47618 .39363 Mdot
.4543 .37925 Mdot
.35894 .60137 Mdot
.61707 .2372 Mdot
.4494 .44714 Mdot
.40886 .36632 Mdot
.63761 .51326 Mdot
.66952 .51292 Mdot
.62731 .24672 Mdot
.63238 .49955 Mdot
.36551 .37738 Mdot
.36104 .60056 Mdot
.39858 .39133 Mdot
.35092 .62965 Mdot
.45646 .43577 Mdot
.38572 .66592 Mdot
.33556 .62002 Mdot
.66239 .58074 Mdot
.40267 .38278 Mdot
.35839 .46662 Mdot
.44579 .38797 Mdot
.44074 .42579 Mdot
.66137 .48218 Mdot
.57477 .34948 Mdot
.41981 .33439 Mdot
.6354 .35405 Mdot
.58367 .37437 Mdot
.36379 .54405 Mdot
.66296 .46404 Mdot
.59118 .35839 Mdot
.18118 .53738 Mdot
.68102 .46206 Mdot
.60325 .35054 Mdot
.16458 .53983 Mdot
.53618 .64911 Mdot
.36949 .57652 Mdot
.39242 .41274 Mdot
.5593 .81905 Mdot
.33959 .2627 Mdot
.62517 .50142 Mdot
.39419 .43871 Mdot
.43398 .3861 Mdot
.33283 .63632 Mdot
.30108 .2324 Mdot
.69679 .51185 Mdot
.38458 .39042 Mdot
.37729 .63303 Mdot
.34021 .20278 Mdot
.64355 .52622 Mdot
.60035 .34912 Mdot
.58605 .61768 Mdot
.31749 .62219 Mdot
.61935 .60186 Mdot
.59156 .63545 Mdot
.61061 .52898 Mdot
.63609 .72978 Mdot
.41101 .36078 Mdot
.68807 .47532 Mdot
.77043 .65857 Mdot
.42848 .59707 Mdot
.52033 .61215 Mdot
.51125 .32567 Mdot
.35629 .62097 Mdot
.56832 .66289 Mdot
.57288 .34013 Mdot
.40115 .60715 Mdot
.34143 .61121 Mdot
.55772 .67149 Mdot
.49121 .48252 Mdot
.49123 .60081 Mdot
.54263 .64756 Mdot
.80465 .53748 Mdot
.54605 .79816 Mdot
.69083 .47601 Mdot
.58111 .37155 Mdot
.63868 .76821 Mdot
.38174 .60313 Mdot
.24806 .68763 Mdot
.77768 .64041 Mdot
.40345 .43577 Mdot
.58908 .36263 Mdot
.4205 .76052 Mdot
.21343 .3719 Mdot
.56359 .65376 Mdot
.52584 .49786 Mdot
.56642 .33499 Mdot
.42241 .45061 Mdot
.4387 .29408 Mdot
.39897 .37657 Mdot
.58344 .63495 Mdot
.20149 .50595 Mdot
.35422 .62558 Mdot
.54234 .66853 Mdot
.75269 .66921 Mdot
.40162 .41242 Mdot
.40453 .37759 Mdot
.4351 .24696 Mdot
.39421 .60712 Mdot
.69427 .49538 Mdot
.41418 .36132 Mdot
.41198 .40864 Mdot
.39057 .3464 Mdot
.33651 .42772 Mdot
.72097 .29075 Mdot
.38758 .38721 Mdot
.62412 .71223 Mdot
.48024 .40832 Mdot
.40589 .3833 Mdot
.37479 .66159 Mdot
.66751 .19854 Mdot
.63616 .70145 Mdot
.40899 .40925 Mdot
.39082 .36969 Mdot
.55994 .67246 Mdot
.49979 .57858 Mdot
.58572 .5575 Mdot
.57522 .50091 Mdot
.53379 .30102 Mdot
.45386 .46182 Mdot
.37325 .64111 Mdot
.61805 .34849 Mdot
.44035 .35997 Mdot
.37209 .64067 Mdot
.38066 .4445 Mdot
.67002 .47774 Mdot
.67763 .46026 Mdot
.48766 .65684 Mdot
.59787 .35601 Mdot
.38936 .25493 Mdot
.49339 .732 Mdot
.63543 .51549 Mdot
.3827 .41171 Mdot
.58901 .67512 Mdot
.6281 .52884 Mdot
.59141 .52331 Mdot
.34625 .36646 Mdot
.38737 .5977 Mdot
.3516 .61425 Mdot
.54701 .23986 Mdot
.71551 .60896 Mdot
.61079 .18681 Mdot
.56214 .6252 Mdot
.4171 .45754 Mdot
.47566 .68413 Mdot
.35019 .61619 Mdot
.48167 .21185 Mdot
.59281 .35981 Mdot
.5643 .65537 Mdot
.75345 .49214 Mdot
.35475 .63614 Mdot
.36005 .58165 Mdot
.38329 .37052 Mdot
.4256 .4051 Mdot
.55933 .28602 Mdot
.56837 .32206 Mdot
.58384 .65425 Mdot
.58651 .37261 Mdot
.65562 .53971 Mdot
.38786 .3829 Mdot
.34238 .64273 Mdot
.60884 .7778 Mdot
.39518 .36581 Mdot
.66173 .47961 Mdot
.35804 .6179 Mdot
.59598 .37292 Mdot
.59064 .37745 Mdot
.43983 .42476 Mdot
.21959 .41872 Mdot
.55448 .64996 Mdot
.34839 .62136 Mdot
.57443 .74784 Mdot
.45885 .44138 Mdot
.42315 .41081 Mdot
.3808 .47467 Mdot
.56135 .66889 Mdot
.49491 .67917 Mdot
.59182 .32897 Mdot
.38225 .61421 Mdot
.37554 .40988 Mdot
.60631 .35515 Mdot
.48796 .67824 Mdot
.63451 .47751 Mdot
.66411 .4704 Mdot
.60047 .37821 Mdot
.58435 .36687 Mdot
.60554 .37533 Mdot
.24176 .68431 Mdot
.34261 .58295 Mdot
.37567 .50146 Mdot
.44472 .45118 Mdot
.52871 .23198 Mdot
.41519 .32866 Mdot
.52757 .64752 Mdot
.65297 .46974 Mdot
.44148 .38279 Mdot
.39881 .35909 Mdot
.36222 .46525 Mdot
.36301 .48085 Mdot
.38612 .56579 Mdot
.37091 .62862 Mdot
.36306 .42849 Mdot
.65407 .46527 Mdot
.18108 .33604 Mdot
.48963 .85163 Mdot
.48423 .3918 Mdot
.53952 .56606 Mdot
.34182 .64092 Mdot
.58327 .66616 Mdot
.58896 .53914 Mdot
.54396 .61724 Mdot
.37706 .61229 Mdot
.3881 .38385 Mdot
.50525 .73356 Mdot
.59582 .38047 Mdot
.45489 .42166 Mdot
.57749 .64862 Mdot
.45026 .42593 Mdot
.59106 .63335 Mdot
.4595 .80675 Mdot
.81187 .48765 Mdot
.40059 .42712 Mdot
.47509 .38237 Mdot
.52356 .32426 Mdot
.43433 .39566 Mdot
.59085 .40623 Mdot
.3408 .63759 Mdot
.57006 .18544 Mdot
.37328 .38641 Mdot
.28159 .5059 Mdot
.45797 .44347 Mdot
.67603 .27615 Mdot
.42799 .40904 Mdot
.66303 .42799 Mdot
.41256 .44613 Mdot
.43485 .43896 Mdot
.54275 .62041 Mdot
.55792 .67215 Mdot
.40456 .62726 Mdot
.69136 .50057 Mdot
.32094 .76025 Mdot
.41759 .4102 Mdot
.66387 .68833 Mdot
.60177 .70639 Mdot
.58154 .36698 Mdot
.37833 .61017 Mdot
.31154 .21387 Mdot
.56198 .60397 Mdot
.76088 .40092 Mdot
.62796 .25945 Mdot
.62593 .62842 Mdot
.5839 .51244 Mdot
.35627 .70366 Mdot
.61013 .36224 Mdot
.42432 .45155 Mdot
.65753 .74071 Mdot
.7716 .49603 Mdot
.35205 .35151 Mdot
.54395 .67236 Mdot
.28533 .55485 Mdot
.62663 .77123 Mdot
.58272 .32699 Mdot
.58522 .332 Mdot
.58743 .62232 Mdot
.67184 .43746 Mdot
.47829 .45821 Mdot
.5953 .36137 Mdot
.63402 .50321 Mdot
.69006 .47108 Mdot
.73039 .525 Mdot
.38418 .59932 Mdot
.72677 .6923 Mdot
.45857 .74639 Mdot
.5909 .63711 Mdot
.64894 .33899 Mdot
.3257 .59665 Mdot
.37271 .57039 Mdot
.67936 .50732 Mdot
.65706 .48275 Mdot
.37823 .57483 Mdot
.36852 .38549 Mdot
.3888 .48563 Mdot
.40627 .40979 Mdot
.58821 .34659 Mdot
.43327 .40499 Mdot
.66856 .48291 Mdot
.56487 .64839 Mdot
.65153 .48853 Mdot
.5501 .60815 Mdot
.502 .77389 Mdot
.45304 .40905 Mdot
.42733 .437 Mdot
.33781 .26125 Mdot
.38458 .65236 Mdot
.60156 .73844 Mdot
.66355 .70527 Mdot
.64357 .51157 Mdot
.43362 .44247 Mdot
.36466 .65092 Mdot
.61489 .33106 Mdot
.33663 .26017 Mdot
.46174 .3948 Mdot
.34397 .64187 Mdot
.37979 .40215 Mdot
.19947 .57435 Mdot
.79853 .37193 Mdot
.37193 .60032 Mdot
.44581 .17647 Mdot
.38356 .3837 Mdot
.35738 .69327 Mdot
.4653 .38535 Mdot
.57811 .2607 Mdot
.45111 .4459 Mdot
.40012 .60249 Mdot
.40929 .4035 Mdot
.39709 .62044 Mdot
.64401 .53072 Mdot
.59576 .64858 Mdot
.35287 .59042 Mdot
.44818 .37105 Mdot
.36143 .8468 Mdot
.5798 .63065 Mdot
.40951 .4324 Mdot
.5681 .61055 Mdot
.38514 .62988 Mdot
.36688 .58133 Mdot
.18459 .41246 Mdot
.63586 .67281 Mdot
.55766 .62821 Mdot
.38562 .39274 Mdot
.42323 .7215 Mdot
.397 .38677 Mdot
.54141 .27431 Mdot
.38609 .35382 Mdot
.45672 .44238 Mdot
.14861 .47297 Mdot
.57345 .66458 Mdot
.63564 .2063 Mdot
.18022 .43184 Mdot
.23665 .67073 Mdot
.32226 .64293 Mdot
.59262 .32684 Mdot
.26936 .72048 Mdot
.6449 .69612 Mdot
.68115 .48449 Mdot
.44299 .38527 Mdot
.34324 .57085 Mdot
.54971 .65455 Mdot
.57749 .34643 Mdot
.40113 .42787 Mdot
.65563 .482 Mdot
.73637 .35457 Mdot
.58508 .6096 Mdot
.38207 .60514 Mdot
.33421 .61181 Mdot
.39788 .17887 Mdot
.37626 .42021 Mdot
.42634 .43993 Mdot
.58288 .63093 Mdot
.4289 .58219 Mdot
.60946 .36672 Mdot
.68597 .29838 Mdot
.55972 .62742 Mdot
.55224 .5307 Mdot
.3798 .62572 Mdot
.43543 .38733 Mdot
.36988 .73996 Mdot
.76316 .46325 Mdot
.30285 .43219 Mdot
.59608 .34549 Mdot
.53145 .27518 Mdot
.39996 .60137 Mdot
.5724 .64511 Mdot
.70787 .62717 Mdot
.34989 .42255 Mdot
.4295 .38776 Mdot
.52456 .27283 Mdot
.5182 .47447 Mdot
.4257 .21188 Mdot
.46711 .40552 Mdot
.53398 .4667 Mdot
.46383 .42156 Mdot
.34631 .39706 Mdot
.36944 .37285 Mdot
.42284 .41741 Mdot
.34305 .64134 Mdot
.3541 .35316 Mdot
.68451 .48084 Mdot
.32758 .31878 Mdot
.56098 .50855 Mdot
.3998 .44007 Mdot
.39402 .3821 Mdot
.32924 .49581 Mdot
.55234 .699 Mdot
.34615 .60189 Mdot
.41987 .6167 Mdot
.59593 .65713 Mdot
.37042 .47474 Mdot
.69212 .50617 Mdot
.37406 .3451 Mdot
.65871 .48549 Mdot
.35393 .64848 Mdot
.64332 .51709 Mdot
.59685 .63093 Mdot
.68514 .46982 Mdot
.64798 .70375 Mdot
.56078 .6621 Mdot
.39114 .59571 Mdot
.43293 .42603 Mdot
.53444 .65641 Mdot
.44716 .25079 Mdot
.58909 .34676 Mdot
.17788 .42263 Mdot
.37483 .42552 Mdot
.62278 .63111 Mdot
.42172 .54397 Mdot
.65325 .48844 Mdot
.75704 .31436 Mdot
.33574 .61744 Mdot
.62562 .36302 Mdot
.3568 .65002 Mdot
.82123 .5461 Mdot
.57387 .35714 Mdot
.16637 .55168 Mdot
.74232 .61255 Mdot
.60422 .43719 Mdot
.3686 .38813 Mdot
.44818 .30261 Mdot
.65572 .54149 Mdot
.55066 .65521 Mdot
.73485 .603 Mdot
.43846 .43776 Mdot
.78781 .42865 Mdot
.40942 .6171 Mdot
.69107 .49618 Mdot
.56978 .63809 Mdot
.54012 .66435 Mdot
.45256 .38254 Mdot
.66277 .33196 Mdot
.461 .41887 Mdot
.69564 .60757 Mdot
.53153 .29469 Mdot
.45146 .4814 Mdot
.41293 .43918 Mdot
.6678 .52684 Mdot
.38011 .4019 Mdot
.53867 .34813 Mdot
.71436 .71704 Mdot
.44696 .4618 Mdot
.66057 .71158 Mdot
.62318 .39209 Mdot
.3685 .62083 Mdot
.48187 .37057 Mdot
.64018 .66058 Mdot
.37663 .41104 Mdot
.87628 .49686 Mdot
.60443 .35199 Mdot
.66324 .66833 Mdot
.47601 .41968 Mdot
.44052 .36978 Mdot
.49554 .34147 Mdot
.30533 .63616 Mdot
.76544 .46258 Mdot
.4245 .39192 Mdot
.47913 .28654 Mdot
.5694 .61717 Mdot
.46288 .41014 Mdot
.40806 .42378 Mdot
.31316 .58271 Mdot
.54932 .6669 Mdot
.64329 .4996 Mdot
.62438 .53603 Mdot
.70868 .49817 Mdot
.5908 .38611 Mdot
.53072 .5122 Mdot
.50375 .22007 Mdot
.801 .41868 Mdot
.62195 .35295 Mdot
.37464 .39279 Mdot
.53252 .35221 Mdot
.3956 .36925 Mdot
.56926 .34469 Mdot
.55257 .66662 Mdot
.34513 .60146 Mdot
.46444 .66137 Mdot
.67588 .53327 Mdot
.47076 .40282 Mdot
.56744 .36443 Mdot
.38789 .59472 Mdot
.55362 .33788 Mdot
.37568 .61894 Mdot
.5598 .63087 Mdot
.60065 .65346 Mdot
.57537 .34403 Mdot
.36056 .64692 Mdot
.56677 .71047 Mdot
.21743 .37244 Mdot
.3759 .35844 Mdot
.54535 .5854 Mdot
.38203 .65111 Mdot
.40159 .58111 Mdot
.4001 .62852 Mdot
.44744 .42212 Mdot
.53475 .5665 Mdot
.41433 .34438 Mdot
.58492 .65158 Mdot
.64143 .48381 Mdot
.62717 .29077 Mdot
.54617 .78565 Mdot
.63744 .30217 Mdot
.40487 .4579 Mdot
.40305 .40689 Mdot
.41099 .43073 Mdot
.39175 .35697 Mdot
.68189 .61895 Mdot
.45266 .39383 Mdot
.54806 .61609 Mdot
.66363 .49212 Mdot
.41837 .4534 Mdot
.63077 .4844 Mdot
.3875 .7093 Mdot
.61788 .34493 Mdot
.51988 .50688 Mdot
.32457 .80333 Mdot
.38298 .58913 Mdot
.63122 .50243 Mdot
.6816 .48654 Mdot
.61473 .36823 Mdot
.54906 .65055 Mdot
.38035 .62132 Mdot
.58873 .26987 Mdot
.59726 .37609 Mdot
.41022 .40566 Mdot
.63125 .56373 Mdot
.7818 .43338 Mdot
.43537 .44817 Mdot
.4273 .3716 Mdot
.63614 .47378 Mdot
.66513 .4346 Mdot
.71378 .75309 Mdot
.44932 .22081 Mdot
.57418 .3473 Mdot
.61031 .33738 Mdot
.39225 .57773 Mdot
.47128 .36773 Mdot
.58657 .64814 Mdot
.38907 .23344 Mdot
.44831 .5187 Mdot
.39226 .24905 Mdot
.52739 .43869 Mdot
.45903 .39293 Mdot
.26013 .36119 Mdot
.40048 .41323 Mdot
.33327 .6275 Mdot
.39138 .62066 Mdot
.36231 .59069 Mdot
.55404 .65415 Mdot
.25159 .55706 Mdot
.54421 .62124 Mdot
.35563 .81715 Mdot
.39702 .59373 Mdot
.67522 .64288 Mdot
.66908 .52482 Mdot
.48504 .4126 Mdot
.60063 .3707 Mdot
.52223 .63459 Mdot
.4562 .46832 Mdot
.70268 .27542 Mdot
.68814 .48795 Mdot
.39124 .59439 Mdot
.35163 .70198 Mdot
.42347 .81871 Mdot
.58832 .54848 Mdot
.43512 .32497 Mdot
.48276 .32565 Mdot
.58019 .36766 Mdot
.29987 .42168 Mdot
.56226 .3557 Mdot
.57315 .65432 Mdot
.42693 .43312 Mdot
.42725 .42392 Mdot
.46096 .43098 Mdot
.4529 .39933 Mdot
.58151 .66886 Mdot
.44566 .45679 Mdot
.83999 .4491 Mdot
.67433 .45853 Mdot
.21779 .5955 Mdot
.60892 .35712 Mdot
.54649 .67678 Mdot
.66377 .4901 Mdot
.64747 .4555 Mdot
.46137 .23366 Mdot
.40799 .4426 Mdot
.44371 .38433 Mdot
.76818 .41822 Mdot
.46792 .40949 Mdot
.44509 .33044 Mdot
.68405 .48772 Mdot
.63581 .30079 Mdot
.62383 .34613 Mdot
.59317 .33316 Mdot
.54424 .66029 Mdot
.35916 .64855 Mdot
.59112 .35302 Mdot
.64225 .52854 Mdot
.39274 .45576 Mdot
.43097 .36102 Mdot
.38561 .6493 Mdot
.78422 .63155 Mdot
.57609 .32858 Mdot
.36856 .70415 Mdot
.38982 .63077 Mdot
.33248 .5914 Mdot
.42797 .38676 Mdot
.33771 .36648 Mdot
.3204 .59319 Mdot
.62159 .36396 Mdot
.5505 .67789 Mdot
.57697 .49187 Mdot
.5825 .64558 Mdot
.38868 .61408 Mdot
.42694 .35668 Mdot
.39161 .6124 Mdot
.38198 .43009 Mdot
.23479 .74472 Mdot
.42706 .41779 Mdot
.81109 .43138 Mdot
.54408 .25253 Mdot
.67384 .49535 Mdot
.57923 .71352 Mdot
.68423 .50358 Mdot
.3925 .62646 Mdot
.43868 .36086 Mdot
.59516 .33022 Mdot
.21303 .63771 Mdot
.33129 .5883 Mdot
.67134 .47526 Mdot
.7035 .48973 Mdot
.56177 .66434 Mdot
.42227 .45452 Mdot
.43401 .38984 Mdot
.66708 .50922 Mdot
.43043 .49195 Mdot
.35172 .63817 Mdot
.42129 .43823 Mdot
.40476 .39323 Mdot
.67582 .49566 Mdot
.2313 .35454 Mdot
.31805 .66818 Mdot
.42198 .4276 Mdot
.70837 .65884 Mdot
.52798 .6497 Mdot
.37592 .37052 Mdot
.47931 .42928 Mdot
.5898 .36639 Mdot
.24855 .62118 Mdot
.70049 .72693 Mdot
.52889 .6411 Mdot
.68612 .50702 Mdot
.375 .4165 Mdot
.67248 .52358 Mdot
.43994 .36544 Mdot
.2793 .65155 Mdot
.69256 .48536 Mdot
.42757 .36508 Mdot
.48007 .37599 Mdot
.39488 .60943 Mdot
.45207 .38758 Mdot
.35249 .51611 Mdot
.63538 .53717 Mdot
.44078 .37213 Mdot
.21869 .42344 Mdot
.54174 .6401 Mdot
.48327 .38207 Mdot
.61205 .34392 Mdot
.59521 .26964 Mdot
.49318 .74391 Mdot
.67153 .69374 Mdot
.60603 .33899 Mdot
.45156 .42708 Mdot
.70365 .48364 Mdot
.58968 .62761 Mdot
.78792 .39596 Mdot
.43942 .44306 Mdot
.58286 .63492 Mdot
.56592 .64646 Mdot
.60833 .34551 Mdot
.5433 .15463 Mdot
.46928 .44127 Mdot
.43529 .39832 Mdot
.35619 .53933 Mdot
.34155 .65229 Mdot
.43359 .4098 Mdot
.38493 .37415 Mdot
.5533 .61305 Mdot
.46321 .33788 Mdot
.31001 .5305 Mdot
.66012 .28094 Mdot
.53514 .61552 Mdot
.57271 .45354 Mdot
.69802 .49496 Mdot
.60589 .36008 Mdot
.36534 .61545 Mdot
.56051 .34347 Mdot
.67553 .46672 Mdot
.378 .38703 Mdot
.56808 .60696 Mdot
.32613 .4547 Mdot
.58998 .6252 Mdot
.67138 .6847 Mdot
.36038 .65493 Mdot
.4622 .68967 Mdot
.85897 .42887 Mdot
.46188 .75215 Mdot
.55972 .70024 Mdot
.58157 .36685 Mdot
.6103 .50963 Mdot
.40405 .39727 Mdot
.29569 .38667 Mdot
.43698 .42836 Mdot
.22241 .42456 Mdot
.63564 .49193 Mdot
.69051 .46612 Mdot
.42492 .43051 Mdot
.53525 .28888 Mdot
.59349 .63677 Mdot
.57108 .66431 Mdot
.44193 .37561 Mdot
.5543 .63763 Mdot
.42516 .40217 Mdot
.6634 .48324 Mdot
.67439 .22834 Mdot
.40365 .41853 Mdot
.44658 .35803 Mdot
.59918 .58245 Mdot
.1554 .4747 Mdot
.73054 .65553 Mdot
.27747 .34349 Mdot
.45776 .82744 Mdot
.55528 .63741 Mdot
.42981 .3436 Mdot
.57487 .44725 Mdot
.63319 .4772 Mdot
.5609 .70838 Mdot
.43659 .41605 Mdot
.44018 .41633 Mdot
.42946 .44249 Mdot
.40371 .37722 Mdot
.29255 .39784 Mdot
.37315 .50419 Mdot
.22136 .47969 Mdot
.44209 .38052 Mdot
.40976 .28718 Mdot
.53365 .6494 Mdot
.41043 .62178 Mdot
.55605 .34904 Mdot
.45852 .39253 Mdot
.36737 .49972 Mdot
.52971 .65759 Mdot
.35805 .81816 Mdot
.55354 .66431 Mdot
.64727 .50858 Mdot
.58757 .66146 Mdot
.38874 .42894 Mdot
.36542 .60725 Mdot
.56638 .49827 Mdot
.7002 .57575 Mdot
.6806 .48374 Mdot
.39327 .43653 Mdot
.65352 .66023 Mdot
.68232 .48063 Mdot
.3895 .71124 Mdot
.36107 .61055 Mdot
.46713 .2809 Mdot
.39209 .61953 Mdot
.42737 .36435 Mdot
.41412 .36365 Mdot
.51262 .61665 Mdot
.5959 .63736 Mdot
.39108 .62393 Mdot
.58039 .15615 Mdot
.56124 .35832 Mdot
.36727 .59108 Mdot
.35867 .43261 Mdot
.47537 .56167 Mdot
.35853 .60493 Mdot
.60314 .30041 Mdot
.55555 .65839 Mdot
.39415 .58492 Mdot
.35994 .43784 Mdot
.78848 .59328 Mdot
.61636 .37292 Mdot
.70848 .47646 Mdot
.68216 .5473 Mdot
.63025 .5324 Mdot
.56389 .67942 Mdot
.68388 .49792 Mdot
.56396 .61674 Mdot
.57741 .73216 Mdot
.34315 .29118 Mdot
.59585 .66866 Mdot
.57496 .67504 Mdot
.68182 .49663 Mdot
.41858 .44251 Mdot
.65273 .55397 Mdot
.40105 .34736 Mdot
.41114 .47291 Mdot
.5567 .6206 Mdot
.39917 .60241 Mdot
.3585 .57811 Mdot
.4278 .29208 Mdot
.33309 .61453 Mdot
.65822 .48431 Mdot
.80115 .3865 Mdot
.66411 .72737 Mdot
.57423 .62163 Mdot
.57017 .67395 Mdot
.39611 .38524 Mdot
.66409 .51894 Mdot
.65524 .53224 Mdot
.5711 .65912 Mdot
.32841 .33941 Mdot
.45705 .36006 Mdot
.40896 .58626 Mdot
.39458 .58897 Mdot
.36622 .59965 Mdot
.40026 .62479 Mdot
.30297 .50034 Mdot
.55765 .6599 Mdot
.4 .60676 Mdot
.4336 .36878 Mdot
.43933 .41528 Mdot
.57275 .50133 Mdot
.59983 .33482 Mdot
.38288 .44573 Mdot
.36608 .38295 Mdot
.42988 .38487 Mdot
.66748 .47034 Mdot
.39361 .47496 Mdot
.69504 .4927 Mdot
.70887 .48555 Mdot
.6578 .45995 Mdot
.64588 .69741 Mdot
.49205 .32792 Mdot
.5021 .83861 Mdot
.38422 .39075 Mdot
.43083 .62532 Mdot
.66168 .52496 Mdot
.73533 .29681 Mdot
.48674 .66925 Mdot
.43608 .44285 Mdot
.76071 .46741 Mdot
.66956 .50813 Mdot
.33328 .60899 Mdot
.43374 .4164 Mdot
.71171 .49187 Mdot
.61844 .35227 Mdot
.35436 .40452 Mdot
.62657 .53475 Mdot
.36679 .6455 Mdot
.56145 .37242 Mdot
.40044 .59462 Mdot
.64948 .46574 Mdot
.48113 .37794 Mdot
.6928 .81196 Mdot
.68778 .52409 Mdot
.17481 .5273 Mdot
.32391 .65817 Mdot
.42149 .43931 Mdot
.62966 .5149 Mdot
.33814 .64884 Mdot
.56295 .68065 Mdot
.47446 .51452 Mdot
.33979 .60582 Mdot
.6908 .46669 Mdot
.62723 .53335 Mdot
.68371 .48677 Mdot
.36603 .62802 Mdot
.42877 .35262 Mdot
.35837 .6314 Mdot
.58516 .66365 Mdot
.39553 .40452 Mdot
.37278 .80282 Mdot
.4317 .60697 Mdot
.39047 .62802 Mdot
.64408 .49165 Mdot
.58872 .38145 Mdot
.39801 .42468 Mdot
.17695 .48926 Mdot
.39041 .43927 Mdot
.57827 .62015 Mdot
.64615 .23517 Mdot
.32306 .4517 Mdot
.44849 .44911 Mdot
.39656 .38433 Mdot
.57909 .65988 Mdot
.40394 .43774 Mdot
.44507 .44927 Mdot
.64144 .68916 Mdot
.37028 .63282 Mdot
.40796 .40129 Mdot
.63766 .49762 Mdot
.62622 .74495 Mdot
.43728 .3497 Mdot
.71781 .36933 Mdot
.4937 .28558 Mdot
.60787 .20143 Mdot
.43593 .43145 Mdot
.42319 .22919 Mdot
.41106 .37347 Mdot
.45545 .41739 Mdot
.39015 .3899 Mdot
.29868 .32649 Mdot
.68757 .47799 Mdot
.67288 .48523 Mdot
.61836 .37068 Mdot
.49075 .28624 Mdot
.59015 .36392 Mdot
.54858 .65831 Mdot
.69819 .36998 Mdot
.69218 .48497 Mdot
.36849 .64591 Mdot
.45586 .42563 Mdot
.68358 .528 Mdot
.43859 .38888 Mdot
.38636 .42787 Mdot
.68022 .52264 Mdot
.68945 .5193 Mdot
.66581 .67983 Mdot
.61515 .34409 Mdot
.35587 .59123 Mdot
.37124 .43134 Mdot
.58118 .37287 Mdot
.43708 .35691 Mdot
.52781 .2281 Mdot
.35531 .59337 Mdot
.36738 .63313 Mdot
.3436 .58876 Mdot
.37773 .38804 Mdot
.39376 .43143 Mdot
.54605 .62039 Mdot
.36578 .64857 Mdot
.54314 .64114 Mdot
.55334 .49547 Mdot
.70764 .35077 Mdot
.43673 .41605 Mdot
.38282 .69752 Mdot
.59978 .36727 Mdot
.65114 .49838 Mdot
.74585 .37743 Mdot
.61597 .37485 Mdot
.38829 .43613 Mdot
.67192 .5256 Mdot
.57473 .3403 Mdot
.43367 .31702 Mdot
.57183 .82941 Mdot
.57739 .37801 Mdot
.43547 .37063 Mdot
.49673 .36412 Mdot
.29282 .29334 Mdot
.5844 .38369 Mdot
.5749 .61239 Mdot
.37618 .39124 Mdot
.41428 .54461 Mdot
.57464 .32964 Mdot
.59294 .74339 Mdot
.66706 .49897 Mdot
.74901 .65658 Mdot
.43685 .4769 Mdot
.30637 .3516 Mdot
.56288 .34574 Mdot
.38117 .61815 Mdot
.39257 .657 Mdot
.42078 .38191 Mdot
.58153 .38336 Mdot
.54139 .60851 Mdot
.6612 .50009 Mdot
.63671 .70587 Mdot
.3634 .62796 Mdot
.43106 .68705 Mdot
.64697 .48118 Mdot
.39213 .69966 Mdot
.66059 .26437 Mdot
.43361 .48698 Mdot
.28457 .32748 Mdot
.76076 .52576 Mdot
.37364 .39096 Mdot
.56365 .36353 Mdot
.52953 .64486 Mdot
.58061 .61334 Mdot
.56349 .62736 Mdot
.59483 .71507 Mdot
.57851 .52138 Mdot
.63438 .48258 Mdot
.73369 .54179 Mdot
.6048 .35661 Mdot
.40742 .27407 Mdot
.45218 .37022 Mdot
.40324 .40907 Mdot
.41261 .45649 Mdot
.46438 .40588 Mdot
.4123 .37862 Mdot
.5487 .64532 Mdot
.60227 .71499 Mdot
.57569 .46645 Mdot
.35422 .59997 Mdot
.64312 .31877 Mdot
.66826 .52501 Mdot
.64911 .46091 Mdot
.5869 .33733 Mdot
.34677 .7084 Mdot
.62758 .50069 Mdot
.64269 .51352 Mdot
.39239 .44557 Mdot
.35693 .63653 Mdot
.36832 .34473 Mdot
.40887 .36684 Mdot
.65628 .49289 Mdot
.56147 .41746 Mdot
.32826 .51906 Mdot
.34488 .42469 Mdot
.55895 .37813 Mdot
.52768 .56511 Mdot
.58078 .38196 Mdot
.45551 .36904 Mdot
.71928 .28322 Mdot
.67757 .46775 Mdot
.65375 .51672 Mdot
.56444 .35701 Mdot
.33949 .68634 Mdot
.36003 .62006 Mdot
.64699 .45541 Mdot
.56695 .61236 Mdot
.40228 .3653 Mdot
.72252 .34544 Mdot
.35505 .68823 Mdot
.67139 .34245 Mdot
.56935 .6249 Mdot
.65238 .53111 Mdot
.42863 .45461 Mdot
.43397 .37045 Mdot
.58491 .37059 Mdot
.42315 .78942 Mdot
.35728 .40658 Mdot
.23752 .67501 Mdot
.81618 .49479 Mdot
.78933 .61045 Mdot
.42956 .38794 Mdot
.37048 .63113 Mdot
.62307 .52701 Mdot
.58211 .37167 Mdot
.41017 .46484 Mdot
.55076 .83424 Mdot
.39725 .64286 Mdot
.57287 .65072 Mdot
.56267 .46042 Mdot
.59005 .54144 Mdot
.37772 .431 Mdot
.43607 .42736 Mdot
.45053 .4158 Mdot
.64897 .79162 Mdot
.66254 .47405 Mdot
.34217 .64422 Mdot
.59501 .34333 Mdot
.33264 .61799 Mdot
.67498 .48925 Mdot
.44326 .68984 Mdot
.40676 .44602 Mdot
.39494 .64508 Mdot
.37881 .61679 Mdot
.56006 .66407 Mdot
.57406 .67765 Mdot
.55662 .48144 Mdot
.42646 .41652 Mdot
.64023 .54652 Mdot
.39584 .60435 Mdot
.6329 .56243 Mdot
.57432 .359 Mdot
.53463 .63874 Mdot
.44393 .38257 Mdot
.68109 .4726 Mdot
.4447 .45765 Mdot
.34905 .61299 Mdot
.64311 .51501 Mdot
.66287 .67854 Mdot
.61073 .33857 Mdot
.4459 .40464 Mdot
.55047 .36654 Mdot
.68581 .50816 Mdot
.4035 .39439 Mdot
.32304 .69605 Mdot
.59465 .39117 Mdot
.6734 .58958 Mdot
.63747 .48033 Mdot
.66243 .68645 Mdot
.35253 .58374 Mdot
.55678 .73378 Mdot
.6517 .51307 Mdot
.32753 .70335 Mdot
.48308 .7915 Mdot
.37546 .44413 Mdot
.37877 .60089 Mdot
.61834 .48323 Mdot
.2926 .7702 Mdot
.23057 .36528 Mdot
.40886 .43057 Mdot
.63282 .49552 Mdot
.56665 .35951 Mdot
.57298 .62095 Mdot
.71827 .3676 Mdot
.53575 .35375 Mdot
.69981 .50269 Mdot
.39005 .38748 Mdot
.38468 .62755 Mdot
.55927 .6536 Mdot
.51344 .74642 Mdot
.63842 .51746 Mdot
.6444 .47934 Mdot
.43317 .45373 Mdot
.59365 .35895 Mdot
.19986 .4304 Mdot
.66644 .48137 Mdot
.77183 .43099 Mdot
.61175 .53557 Mdot
.56816 .36612 Mdot
.4191 .37042 Mdot
.45234 .30114 Mdot
.38565 .36025 Mdot
.17863 .56 Mdot
.68159 .50856 Mdot
.34848 .60446 Mdot
.44324 .42832 Mdot
.65148 .27144 Mdot
.65576 .4968 Mdot
.54345 .56504 Mdot
.6936 .43202 Mdot
.55721 .65915 Mdot
.75033 .38151 Mdot
.43754 .40385 Mdot
.59228 .6326 Mdot
.59896 .36723 Mdot
.42051 .42297 Mdot
.39252 .42827 Mdot
.33117 .63655 Mdot
.57488 .65447 Mdot
.51288 .80511 Mdot
.5438 .66948 Mdot
.53508 .62809 Mdot
.33032 .60231 Mdot
.41688 .39394 Mdot
.64587 .5065 Mdot
.66869 .51031 Mdot
.40627 .46873 Mdot
.74238 .29025 Mdot
.35879 .62224 Mdot
.64868 .34533 Mdot
.66798 .78141 Mdot
.44663 .48153 Mdot
.74291 .37179 Mdot
.41869 .78606 Mdot
.54586 .60668 Mdot
.44243 .37778 Mdot
.37735 .6402 Mdot
.65097 .45287 Mdot
.64333 .48415 Mdot
.42466 .35342 Mdot
.56142 .64689 Mdot
.61927 .35759 Mdot
.65907 .5374 Mdot
.66333 .33065 Mdot
.45501 .40792 Mdot
.77066 .47717 Mdot
.63154 .52506 Mdot
.22503 .68476 Mdot
.62037 .49475 Mdot
.37536 .59785 Mdot
.38649 .42524 Mdot
.33665 .60662 Mdot
.58798 .34387 Mdot
.56123 .46849 Mdot
.56328 .64798 Mdot
.49932 .44773 Mdot
.85705 .5296 Mdot
.6863 .4909 Mdot
.34061 .63787 Mdot
.44956 .44886 Mdot
.52443 .37078 Mdot
.43296 .40205 Mdot
.50066 .38156 Mdot
.6128 .39579 Mdot
.55016 .62514 Mdot
.57835 .6178 Mdot
.40068 .39912 Mdot
.60617 .37209 Mdot
.65061 .52998 Mdot
.65868 .50198 Mdot
.12814 .47099 Mdot
.66687 .57426 Mdot
.5633 .28291 Mdot
.44252 .4132 Mdot
.69503 .47298 Mdot
.57222 .77388 Mdot
.58207 .62956 Mdot
.45883 .37854 Mdot
.69265 .50391 Mdot
.79437 .54584 Mdot
.59613 .2576 Mdot
.41537 .37643 Mdot
.46777 .45021 Mdot
.56845 .61183 Mdot
.41634 .25755 Mdot
.65352 .46388 Mdot
.388 .35146 Mdot
.60183 .6332 Mdot
.62483 .23577 Mdot
.74584 .68793 Mdot
.35658 .59087 Mdot
.6726 .43243 Mdot
.54852 .64622 Mdot
.39709 .47192 Mdot
.61079 .35332 Mdot
.64389 .54229 Mdot
.67112 .47228 Mdot
.38538 .39878 Mdot
.44656 .4556 Mdot
.52545 .32856 Mdot
.33926 .63174 Mdot
.53525 .65178 Mdot
.43061 .43552 Mdot
.45295 .65563 Mdot
.46234 .42752 Mdot
.54216 .62633 Mdot
.65454 .84997 Mdot
.36941 .43179 Mdot
.43254 .39977 Mdot
.19961 .42628 Mdot
.34048 .604 Mdot
.3313 .61777 Mdot
.81037 .46095 Mdot
.44291 .41247 Mdot
.76572 .40431 Mdot
.35445 .5906 Mdot
.35582 .62015 Mdot
.63789 .63004 Mdot
.40012 .42053 Mdot
.35511 .25693 Mdot
.58902 .62967 Mdot
.54701 .61387 Mdot
.35879 .62993 Mdot
.36354 .42538 Mdot
.55997 .60312 Mdot
.29189 .4381 Mdot
.66542 .51922 Mdot
.70533 .26897 Mdot
.34499 .61764 Mdot
.53039 .48667 Mdot
.57544 .62492 Mdot
.35151 .81536 Mdot
.74249 .51056 Mdot
.42154 .44117 Mdot
.448 .40696 Mdot
.60309 .36518 Mdot
.37231 .4361 Mdot
.68906 .46462 Mdot
.55393 .63762 Mdot
.19144 .5013 Mdot
.36364 .59037 Mdot
.42628 .41066 Mdot
.37838 .7072 Mdot
.50599 .76531 Mdot
.7491 .61803 Mdot
.36907 .62014 Mdot
.38242 .5989 Mdot
.65089 .46668 Mdot
.63222 .50161 Mdot
.41761 .387 Mdot
.58023 .65619 Mdot
.37279 .64611 Mdot
.54823 .62223 Mdot
.67601 .46754 Mdot
.64373 .5058 Mdot
.69258 .48212 Mdot
.37317 .35502 Mdot
.63969 .50981 Mdot
.65766 .31546 Mdot
.43033 .69427 Mdot
.37285 .57012 Mdot
.80929 .62165 Mdot
.51391 .74466 Mdot
.42537 .52787 Mdot
.58745 .32934 Mdot
.68584 .50869 Mdot
.57506 .67005 Mdot
.39892 .38578 Mdot
.44137 .3863 Mdot
.712 .47002 Mdot
.5877 .65693 Mdot
.57996 .34563 Mdot
.59459 .64569 Mdot
.60955 .34604 Mdot
.75993 .47787 Mdot
.41866 .45467 Mdot
.4266 .36095 Mdot
.54985 .63954 Mdot
.64132 .51432 Mdot
.66711 .49037 Mdot
.57381 .37782 Mdot
.48525 .49226 Mdot
.68434 .48185 Mdot
.34592 .61648 Mdot
.29266 .4898 Mdot
.62513 .5306 Mdot
.4338 .41376 Mdot
.50015 .21644 Mdot
.30115 .38696 Mdot
.39521 .35424 Mdot
.63687 .6575 Mdot
.40029 .20414 Mdot
.44681 .43188 Mdot
.41268 .19119 Mdot
.66131 .68803 Mdot
.33762 .60912 Mdot
.63718 .48604 Mdot
.65619 .45219 Mdot
.48084 .35878 Mdot
.56873 .32458 Mdot
.4036 .46554 Mdot
.34366 .59796 Mdot
.37608 .66249 Mdot
.80371 .55459 Mdot
.17449 .53126 Mdot
.56467 .34937 Mdot
.58663 .33529 Mdot
.65357 .51188 Mdot
.21451 .35107 Mdot
.34658 .42052 Mdot
.57597 .34611 Mdot
.34976 .28549 Mdot
.38964 .38455 Mdot
.5246 .26543 Mdot
.76452 .44413 Mdot
.36641 .63012 Mdot
.44765 .30154 Mdot
.65054 .5055 Mdot
.3369 .62428 Mdot
.46286 .65204 Mdot
.37872 .43814 Mdot
.35724 .59289 Mdot
.5501 .61944 Mdot
.75282 .55646 Mdot
.36634 .58182 Mdot
.51233 .21922 Mdot
.57245 .65948 Mdot
.61587 .56417 Mdot
.43806 .28307 Mdot
.81376 .30309 Mdot
.55134 .64434 Mdot
.69014 .51499 Mdot
.66821 .50964 Mdot
.65827 .50349 Mdot
.33497 .62307 Mdot
.6609 .53081 Mdot
.34196 .63621 Mdot
.26754 .30929 Mdot
.48179 .49392 Mdot
.57358 .34613 Mdot
.63522 .67597 Mdot
.38321 .60997 Mdot
.78664 .35747 Mdot
.85886 .46127 Mdot
.44596 .37989 Mdot
.55594 .67407 Mdot
.56922 .34637 Mdot
.20046 .6343 Mdot
.59371 .36655 Mdot
.61599 .42658 Mdot
.66964 .24095 Mdot
.42241 .40672 Mdot
.28319 .57252 Mdot
.59782 .33128 Mdot
.3787 .62447 Mdot
.40312 .39913 Mdot
.5321 .6936 Mdot
.59771 .36237 Mdot
.61776 .35863 Mdot
.41135 .38826 Mdot
.39167 .59489 Mdot
.64645 .50031 Mdot
.59693 .6494 Mdot
.62304 .3743 Mdot
.38435 .66976 Mdot
.36919 .40227 Mdot
.37341 .40992 Mdot
.58203 .55326 Mdot
.56646 .31602 Mdot
.5554 .63801 Mdot
.32266 .28328 Mdot
.63332 .49845 Mdot
.61694 .46023 Mdot
.80264 .47797 Mdot
.64029 .66931 Mdot
.68171 .50562 Mdot
.68597 .50495 Mdot
.41478 .38016 Mdot
.56704 .31153 Mdot
.62728 .22046 Mdot
.59333 .69834 Mdot
.62372 .52462 Mdot
.65966 .49933 Mdot
.38846 .65683 Mdot
.80831 .55125 Mdot
.41246 .46423 Mdot
.52984 .63537 Mdot
.67938 .47293 Mdot
.27981 .65643 Mdot
.5961 .35568 Mdot
.75912 .3258 Mdot
.4214 .45353 Mdot
.42688 .43702 Mdot
.56704 .63481 Mdot
.54378 .62101 Mdot
.50252 .6348 Mdot
.81948 .51263 Mdot
.35951 .23732 Mdot
.55573 .74793 Mdot
.28215 .6337 Mdot
.40459 .63409 Mdot
.39109 .62692 Mdot
.62608 .70383 Mdot
.53668 .66502 Mdot
.44601 .42939 Mdot
.37223 .6454 Mdot
.74471 .60095 Mdot
.42521 .58566 Mdot
.53994 .27665 Mdot
.68993 .32006 Mdot
.38491 .43255 Mdot
.365 .6391 Mdot
.34033 .60868 Mdot
.38694 .63905 Mdot
.65994 .68834 Mdot
.42503 .39226 Mdot
.41038 .44046 Mdot
.4527 .4339 Mdot
.32771 .41457 Mdot
.45453 .39683 Mdot
.61104 .69153 Mdot
.55303 .53475 Mdot
.21667 .57527 Mdot
.37874 .36005 Mdot
.54694 .60853 Mdot
.37261 .4217 Mdot
.60889 .37091 Mdot
.39219 .38797 Mdot
.54693 .27613 Mdot
.57952 .63959 Mdot
.32377 .66643 Mdot
.55248 .74329 Mdot
.41133 .45 Mdot
.62255 .34998 Mdot
.40702 .52722 Mdot
.45387 .80778 Mdot
.57908 .31816 Mdot
.3461 .61735 Mdot
.67213 .51708 Mdot
.57838 .66699 Mdot
.64617 .51272 Mdot
.36792 .36325 Mdot
.62916 .64583 Mdot
.42026 .7553 Mdot
.54607 .47326 Mdot
.46113 .39699 Mdot
.40131 .4822 Mdot
.35026 .6181 Mdot
.67255 .5253 Mdot
.39488 .56407 Mdot
.44507 .42357 Mdot
.59309 .34539 Mdot
.60169 .36082 Mdot
.4932 .66128 Mdot
.3128 .74123 Mdot
.54875 .72572 Mdot
.56431 .63412 Mdot
.66669 .47915 Mdot
.56108 .35009 Mdot
.41571 .65876 Mdot
.54614 .6812 Mdot
.57834 .66109 Mdot
.56953 .65674 Mdot
.386 .37725 Mdot
.69518 .4926 Mdot
.21227 .56015 Mdot
.69244 .46995 Mdot
.39931 .43785 Mdot
.65977 .47372 Mdot
.69163 .49556 Mdot
.60822 .36089 Mdot
.54541 .66172 Mdot
.66587 .46502 Mdot
.42858 .36438 Mdot
.37273 .58576 Mdot
.5144 .48092 Mdot
.56066 .25027 Mdot
.19792 .59221 Mdot
.21484 .60501 Mdot
.38329 .58118 Mdot
.31763 .773 Mdot
.52574 .6412 Mdot
.32983 .33741 Mdot
.69302 .66428 Mdot
.4186 .35569 Mdot
.79984 .36133 Mdot
.63416 .48233 Mdot
.68327 .52062 Mdot
.41569 .37009 Mdot
.67596 .43693 Mdot
.42825 .40735 Mdot
.65683 .47099 Mdot
.64309 .32278 Mdot
.48666 .3845 Mdot
.64282 .52479 Mdot
.39281 .34717 Mdot
.39687 .41905 Mdot
.36649 .6316 Mdot
.62917 .51983 Mdot
.46155 .38222 Mdot
.14958 .56167 Mdot
.53848 .62904 Mdot
.65115 .6701 Mdot
.49685 .2058 Mdot
.54752 .64685 Mdot
.36629 .59277 Mdot
.41016 .47213 Mdot
.59265 .3704 Mdot
.3864 .61433 Mdot
.60933 .25746 Mdot
.59896 .33265 Mdot
.79769 .36743 Mdot
.34656 .62296 Mdot
.62526 .52777 Mdot
.61298 .35715 Mdot
.42138 .34346 Mdot
.65232 .54084 Mdot
.45057 .52344 Mdot
.67997 .51061 Mdot
.435 .39042 Mdot
.6324 .70987 Mdot
.53257 .64476 Mdot
.40988 .42823 Mdot
.66221 .53539 Mdot
.64278 .69917 Mdot
.38525 .38058 Mdot
.40337 .38214 Mdot
.78929 .62223 Mdot
.76571 .35903 Mdot
.57782 .36468 Mdot
.34478 .651 Mdot
.43325 .36843 Mdot
.61613 .34867 Mdot
.69151 .41411 Mdot
.37194 .40245 Mdot
.3951 .64237 Mdot
.33878 .41896 Mdot
.63844 .53474 Mdot
.54166 .64608 Mdot
.54683 .48922 Mdot
.61823 .35104 Mdot
.49646 .13382 Mdot
.69068 .47309 Mdot
.45878 .37287 Mdot
.46351 .3988 Mdot
.73838 .64644 Mdot
.33821 .61654 Mdot
.36694 .23747 Mdot
.44612 .40476 Mdot
.33762 .43877 Mdot
.41814 .42129 Mdot
.61187 .43994 Mdot
.35872 .62057 Mdot
.43522 .39694 Mdot
.40904 .68796 Mdot
.45048 .35815 Mdot
.62047 .35115 Mdot
.21521 .39019 Mdot
.37364 .38846 Mdot
.80339 .70968 Mdot
.75997 .40244 Mdot
.6414 .52252 Mdot
.62401 .71362 Mdot
.21528 .30532 Mdot
.57243 .73214 Mdot
.34351 .63942 Mdot
.41212 .77689 Mdot
.64531 .50589 Mdot
.59291 .74977 Mdot
.3117 .77495 Mdot
.39566 .417 Mdot
.37801 .43141 Mdot
.61527 .42664 Mdot
.68672 .46098 Mdot
.63364 .54593 Mdot
.3698 .36607 Mdot
.34423 .39565 Mdot
.64063 .49847 Mdot
.44008 .36949 Mdot
.39385 .33996 Mdot
.59274 .65886 Mdot
.38287 .58298 Mdot
.56519 .62006 Mdot
.55597 .66607 Mdot
.26803 .3909 Mdot
.81324 .52055 Mdot
.53945 .63056 Mdot
.52693 .63792 Mdot
.53168 .26495 Mdot
.51031 .32454 Mdot
.57685 .3295 Mdot
.26958 .70805 Mdot
.661 .50379 Mdot
.42283 .39432 Mdot
.37848 .57738 Mdot
.31051 .34086 Mdot
.74021 .40423 Mdot
.63996 .22364 Mdot
.44628 .42591 Mdot
.65378 .5013 Mdot
.66066 .69062 Mdot
.37612 .34092 Mdot
.60328 .48997 Mdot
.42753 .43979 Mdot
.67946 .53044 Mdot
.28448 .52464 Mdot
.35322 .70499 Mdot
.61956 .54364 Mdot
.41736 .6011 Mdot
.42965 .43 Mdot
.34347 .61614 Mdot
.56582 .62339 Mdot
.60642 .36902 Mdot
.57773 .36307 Mdot
.4057 .39067 Mdot
.38763 .48645 Mdot
.75769 .47206 Mdot
.39726 .42474 Mdot
.38973 .3968 Mdot
.66143 .68819 Mdot
.39136 .39812 Mdot
.46336 .4063 Mdot
.46105 .42096 Mdot
.47584 .38905 Mdot
.53793 .62309 Mdot
.37943 .70598 Mdot
.35889 .3726 Mdot
.38459 .33961 Mdot
.59554 .62542 Mdot
.44974 .79543 Mdot
.55315 .66806 Mdot
.37749 .80547 Mdot
.57526 .6189 Mdot
.57464 .35399 Mdot
.67791 .70267 Mdot
.39816 .48601 Mdot
.40081 .61233 Mdot
.54663 .67865 Mdot
.60153 .34275 Mdot
.55809 .63127 Mdot
.64988 .47853 Mdot
.69912 .7466 Mdot
.41152 .64668 Mdot
.40217 .22681 Mdot
.4978 .67029 Mdot
.68516 .57682 Mdot
.67607 .46383 Mdot
.35825 .6251 Mdot
.32808 .52725 Mdot
.46406 .41739 Mdot
.61492 .34834 Mdot
.41434 .38523 Mdot
.53169 .63517 Mdot
.65307 .50614 Mdot
.2154 .38371 Mdot
.58728 .3708 Mdot
.81025 .60372 Mdot
.66851 .49676 Mdot
.45425 .43812 Mdot
.53085 .63278 Mdot
.8327 .58812 Mdot
.55721 .62153 Mdot
.45059 .49763 Mdot
.41108 .60209 Mdot
.27756 .33636 Mdot
.38009 .60494 Mdot
.6259 .49133 Mdot
.70345 .77286 Mdot
.24551 .67106 Mdot
.3867 .59115 Mdot
.71497 .55212 Mdot
.37638 .42113 Mdot
.37302 .41294 Mdot
.33509 .69287 Mdot
.35652 .65328 Mdot
.44915 .38305 Mdot
.66038 .67589 Mdot
.43483 .71273 Mdot
.75982 .38116 Mdot
.67793 .51739 Mdot
.43376 .40666 Mdot
.59842 .62725 Mdot
.59375 .64666 Mdot
.69414 .47474 Mdot
.55413 .6697 Mdot
.41008 .43913 Mdot
.38196 .60845 Mdot
.66104 .54318 Mdot
.58256 .35628 Mdot
.15425 .51952 Mdot
.55894 .34989 Mdot
.68179 .50439 Mdot
.48113 .37892 Mdot
.64347 .50624 Mdot
.26769 .22452 Mdot
.41618 .43891 Mdot
.35041 .59471 Mdot
.40056 .37511 Mdot
.42595 .4287 Mdot
.37603 .42876 Mdot
.64447 .48793 Mdot
.40078 .21417 Mdot
.43546 .36664 Mdot
.5633 .64947 Mdot
.23609 .60752 Mdot
.37364 .42665 Mdot
.64055 .33051 Mdot
.51459 .29864 Mdot
.73844 .53712 Mdot
.39107 .57946 Mdot
.65788 .52783 Mdot
.37056 .58869 Mdot
.42451 .5975 Mdot
.36575 .5929 Mdot
.24664 .59143 Mdot
.31731 .52847 Mdot
.44455 .19338 Mdot
.2153 .43355 Mdot
.37658 .30837 Mdot
.34979 .65241 Mdot
.59607 .41014 Mdot
.3886 .63305 Mdot
.34052 .61448 Mdot
.44442 .9153 Mdot
.39838 .6141 Mdot
.4386 .41059 Mdot
.3934 .44976 Mdot
.47943 .75471 Mdot
.4996 .25355 Mdot
.39665 .39659 Mdot
.42185 .36611 Mdot
.60644 .3671 Mdot
.3811 .49114 Mdot
.62972 .64729 Mdot
.80224 .39761 Mdot
.52848 .76924 Mdot
.41211 .38607 Mdot
.42937 .36604 Mdot
.35456 .36422 Mdot
.82992 .6372 Mdot
.28106 .38847 Mdot
.36094 .657 Mdot
.38692 .46836 Mdot
.18836 .59491 Mdot
.41814 .44736 Mdot
.38422 .37458 Mdot
.38212 .43021 Mdot
.64573 .50588 Mdot
.40174 .63605 Mdot
.37663 .45805 Mdot
.78429 .46364 Mdot
.40582 .44802 Mdot
.63986 .67307 Mdot
.28201 .25743 Mdot
.43832 .4033 Mdot
.40513 .60855 Mdot
.37948 .40187 Mdot
.34612 .6274 Mdot
.37633 .63164 Mdot
.47417 .37408 Mdot
.26982 .62764 Mdot
.40755 .61926 Mdot
.39793 .43732 Mdot
.64747 .49325 Mdot
.26003 .70981 Mdot
.4374 .39093 Mdot
.58207 .37274 Mdot
.44679 .40748 Mdot
.62425 .35443 Mdot
.38987 .40557 Mdot
.69551 .47786 Mdot
.31535 .43784 Mdot
.65511 .51531 Mdot
.30813 .25876 Mdot
.69716 .4951 Mdot
.79428 .61588 Mdot
.37732 .65417 Mdot
.63539 .7024 Mdot
.57426 .17129 Mdot
.64539 .66495 Mdot
.51261 .57788 Mdot
.50452 .56257 Mdot
.57961 .65713 Mdot
.33833 .6012 Mdot
.38419 .26662 Mdot
.74607 .61446 Mdot
.72385 .65357 Mdot
.69025 .48755 Mdot
.57406 .15726 Mdot
.67244 .2324 Mdot
.40891 .36272 Mdot
.26965 .5817 Mdot
.22664 .49211 Mdot
.37303 .39459 Mdot
.40963 .47321 Mdot
.71207 .47995 Mdot
.46246 .39193 Mdot
.44709 .6585 Mdot
.68063 .49793 Mdot
.60445 .34312 Mdot
.34537 .60851 Mdot
.6176 .36953 Mdot
.73906 .62739 Mdot
.50048 .56727 Mdot
.66496 .46806 Mdot
.46258 .36917 Mdot
.40634 .37062 Mdot
.35966 .63348 Mdot
.34248 .56861 Mdot
.39455 .61014 Mdot
.56542 .35245 Mdot
.67719 .49889 Mdot
.29463 .37184 Mdot
.42964 .37093 Mdot
.37695 .61515 Mdot
.49213 .6189 Mdot
.43597 .37163 Mdot
.55033 .63438 Mdot
.3913 .43873 Mdot
.37981 .58588 Mdot
.3914 .39852 Mdot
.38314 .60658 Mdot
.66755 .51998 Mdot
.42364 .44934 Mdot
.41662 .3724 Mdot
.82156 .60248 Mdot
.57974 .34718 Mdot
.36367 .65439 Mdot
.68427 .43557 Mdot
.46586 .42185 Mdot
.67503 .60378 Mdot
.4337 .4294 Mdot
.40764 .56011 Mdot
.45333 .36542 Mdot
.65413 .6938 Mdot
.41734 .46226 Mdot
.43697 .39169 Mdot
.47177 .60607 Mdot
.22972 .52669 Mdot
.33603 .57121 Mdot
.53598 .6212 Mdot
.3983 .62879 Mdot
.71521 .34315 Mdot
.62533 .50905 Mdot
.66225 .53141 Mdot
.44265 .24353 Mdot
.48028 .41149 Mdot
.42269 .40488 Mdot
.60112 .65261 Mdot
.59735 .33594 Mdot
.37125 .62014 Mdot
.60837 .34551 Mdot
.79767 .46748 Mdot
.57338 .33851 Mdot
.66549 .45177 Mdot
.7639 .4715 Mdot
.29547 .41515 Mdot
.60659 .36658 Mdot
.39312 .5959 Mdot
.68168 .31995 Mdot
.41675 .35254 Mdot
.54011 .36455 Mdot
.59315 .34667 Mdot
.5622 .14627 Mdot
.46223 .40213 Mdot
.52218 .57399 Mdot
.54047 .63497 Mdot
.61076 .35532 Mdot
.5814 .64894 Mdot
.39877 .39327 Mdot
.66647 .59155 Mdot
.34896 .64672 Mdot
.573 .60377 Mdot
.36655 .39517 Mdot
.57207 .34404 Mdot
.67864 .47397 Mdot
.51258 .64741 Mdot
.55418 .60559 Mdot
.41255 .79008 Mdot
.24421 .35027 Mdot
.67577 .50013 Mdot
.68961 .28366 Mdot
.58659 .62521 Mdot
.3786 .38068 Mdot
.35415 .47172 Mdot
.42114 .44168 Mdot
.58744 .71544 Mdot
.66189 .52778 Mdot
.43175 .73256 Mdot
.40256 .37158 Mdot
.45322 .42599 Mdot
.32325 .5904 Mdot
.66338 .51226 Mdot
.36357 .60575 Mdot
.39702 .62779 Mdot
.66742 .51912 Mdot
.37505 .59947 Mdot
.60372 .33311 Mdot
.44731 .70947 Mdot
.58158 .61657 Mdot
.56721 .64812 Mdot
.65877 .50047 Mdot
.63915 .51599 Mdot
.64313 .51292 Mdot
.3919 .43915 Mdot
.36483 .62078 Mdot
.38528 .42056 Mdot
.37649 .42877 Mdot
.30167 .62224 Mdot
.39026 .58291 Mdot
.37845 .41758 Mdot
.61604 .48835 Mdot
.54233 .36152 Mdot
.6486 .48926 Mdot
.53872 .63438 Mdot
.592 .76712 Mdot
.54645 .60095 Mdot
.43235 .40936 Mdot
.79259 .54423 Mdot
.39164 .59845 Mdot
.59884 .36637 Mdot
.60438 .3276 Mdot
.58826 .36754 Mdot
.60733 .62975 Mdot
.37331 .64972 Mdot
.80177 .39483 Mdot
.43096 .40573 Mdot
.58348 .55479 Mdot
.35934 .27161 Mdot
.77679 .49702 Mdot
.53758 .63465 Mdot
.43134 .3682 Mdot
.54188 .48607 Mdot
.33374 .50974 Mdot
.4248 .43725 Mdot
.41462 .3481 Mdot
.66882 .6552 Mdot
.33824 .38313 Mdot
.41076 .60939 Mdot
.82509 .50131 Mdot
.39166 .45398 Mdot
.31363 .68003 Mdot
.15066 .43748 Mdot
.42926 .41686 Mdot
.45114 .41893 Mdot
.4325 .38102 Mdot
.39233 .38224 Mdot
.40648 .60597 Mdot
.44749 .26115 Mdot
.52686 .64728 Mdot
.57764 .53157 Mdot
.57763 .61252 Mdot
.67088 .53479 Mdot
.40313 .7014 Mdot
.34246 .59272 Mdot
.60256 .36577 Mdot
.30829 .7061 Mdot
.81985 .45359 Mdot
.6484 .46814 Mdot
.28851 .45226 Mdot
.58548 .34814 Mdot
.38178 .3727 Mdot
.62763 .35144 Mdot
.69554 .49563 Mdot
.56189 .65592 Mdot
.47764 .4316 Mdot
.39396 .61926 Mdot
.36248 .58269 Mdot
.44738 .38143 Mdot
.21035 .62916 Mdot
.54686 .63758 Mdot
.52801 .67395 Mdot
.37987 .38774 Mdot
.4004 .34806 Mdot
.36156 .60323 Mdot
.66245 .48674 Mdot
.64241 .28107 Mdot
.58724 .33838 Mdot
.47053 .42104 Mdot
.39043 .38508 Mdot
.81949 .50739 Mdot
.54691 .65755 Mdot
.65692 .45836 Mdot
.38944 .37437 Mdot
.59753 .72675 Mdot
.38924 .3752 Mdot
.36085 .34635 Mdot
.64877 .49445 Mdot
.35018 .40152 Mdot
.42909 .36234 Mdot
.49868 .43733 Mdot
.58773 .63782 Mdot
.35181 .59581 Mdot
.37493 .56834 Mdot
.57961 .44185 Mdot
.55245 .63244 Mdot
.37828 .4108 Mdot
.54512 .65348 Mdot
.37139 .41485 Mdot
.45058 .38195 Mdot
.54193 .62681 Mdot
.36424 .60534 Mdot
.43415 .77603 Mdot
.38863 .70512 Mdot
.39372 .37964 Mdot
.40317 .45787 Mdot
.46957 .25265 Mdot
.49682 .18171 Mdot
.44155 .42729 Mdot
.37241 .5836 Mdot
.42358 .36914 Mdot
.58271 .64199 Mdot
.58202 .33309 Mdot
.37514 .58568 Mdot
.67024 .48626 Mdot
.66156 .46112 Mdot
.55325 .742 Mdot
.68986 .50083 Mdot
.40433 .35577 Mdot
.42676 .60794 Mdot
.33235 .59284 Mdot
.14692 .47359 Mdot
.66725 .51693 Mdot
.60569 .3307 Mdot
.40304 .38517 Mdot
.78725 .59793 Mdot
.59845 .65829 Mdot
.8348 .67771 Mdot
.79939 .37647 Mdot
.55807 .35459 Mdot
.61602 .20238 Mdot
.65965 .54128 Mdot
.45245 .37838 Mdot
.60635 .36976 Mdot
.64342 .47468 Mdot
.40945 .35757 Mdot
.47631 .44019 Mdot
.37601 .22939 Mdot
.56882 .45601 Mdot
.54283 .6526 Mdot
.63697 .52767 Mdot
.62856 .33631 Mdot
.67219 .4536 Mdot
.36013 .58215 Mdot
.43383 .39329 Mdot
.44751 .47982 Mdot
.66651 .48504 Mdot
.68366 .45913 Mdot
.3871 .43279 Mdot
.33715 .60447 Mdot
.70497 .46202 Mdot
.40888 .39223 Mdot
.35771 .3195 Mdot
.41741 .60594 Mdot
.68127 .49312 Mdot
.45757 .42394 Mdot
.53934 .32392 Mdot
.66591 .49432 Mdot
.64952 .48718 Mdot
.44799 .38095 Mdot
.607 .33453 Mdot
.4299 .45462 Mdot
.56987 .61678 Mdot
.36144 .22102 Mdot
.58008 .6463 Mdot
.70425 .35138 Mdot
.46253 .35843 Mdot
.63219 .58039 Mdot
.36068 .57974 Mdot
.62195 .3268 Mdot
.61418 .7705 Mdot
.37519 .35783 Mdot
.30859 .75106 Mdot
.53007 .49764 Mdot
.1801 .59584 Mdot
.58944 .80668 Mdot
.59582 .3495 Mdot
.56164 .62806 Mdot
.45067 .41869 Mdot
.56789 .67462 Mdot
.59585 .37417 Mdot
.29362 .2964 Mdot
.46045 .4186 Mdot
.35689 .61967 Mdot
.39725 .43965 Mdot
.34565 .61809 Mdot
.44093 .37572 Mdot
.37165 .34643 Mdot
.66646 .69807 Mdot
.59305 .25727 Mdot
.41982 .35501 Mdot
.71166 .74106 Mdot
.75166 .42888 Mdot
.59291 .34215 Mdot
.39011 .42416 Mdot
.62798 .4911 Mdot
.59083 .65051 Mdot
.44097 .60024 Mdot
.64492 .50391 Mdot
.54057 .6627 Mdot
.36505 .59788 Mdot
.67339 .51935 Mdot
.67485 .45981 Mdot
.37082 .44466 Mdot
.62158 .35922 Mdot
.56329 .66009 Mdot
.43893 .39593 Mdot
.46111 .40974 Mdot
.69472 .29665 Mdot
.72739 .39663 Mdot
.34787 .57166 Mdot
.85103 .53495 Mdot
.3545 .57336 Mdot
.57857 .34386 Mdot
.64537 .49871 Mdot
.43807 .42672 Mdot
.40764 .4275 Mdot
.63837 .7036 Mdot
.34752 .64801 Mdot
.55958 .46683 Mdot
.26509 .41894 Mdot
.7035 .46381 Mdot
.50457 .2818 Mdot
.34921 .5938 Mdot
.50413 .28001 Mdot
.62887 .33832 Mdot
.29433 .70953 Mdot
.57972 .26442 Mdot
.53925 .63864 Mdot
.49912 .28148 Mdot
.38187 .6228 Mdot
.40739 .36505 Mdot
.6254 .52205 Mdot
.69104 .49496 Mdot
.3531 .60335 Mdot
.70703 .50311 Mdot
.60778 .35874 Mdot
.4549 .41367 Mdot
.78821 .38543 Mdot
.49752 .72787 Mdot
.66293 .47959 Mdot
.3898 .33433 Mdot
.57153 .65493 Mdot
.45547 .38625 Mdot
.57906 .37127 Mdot
.55339 .6482 Mdot
.74862 .38492 Mdot
.43363 .72202 Mdot
.40278 .39268 Mdot
.80209 .58529 Mdot
.55127 .63778 Mdot
.58228 .19466 Mdot
.41505 .39131 Mdot
.58686 .62629 Mdot
.34195 .41186 Mdot
.75713 .52657 Mdot
.54196 .47238 Mdot
.30828 .77423 Mdot
.5523 .478 Mdot
.63294 .53936 Mdot
.74201 .56908 Mdot
.71836 .63098 Mdot
.5731 .67239 Mdot
.68056 .45755 Mdot
.58401 .30793 Mdot
.58154 .64967 Mdot
.37834 .43332 Mdot
.43126 .4246 Mdot
.27895 .37562 Mdot
.5255 .50893 Mdot
.64367 .45724 Mdot
.51516 .70313 Mdot
.46462 .4243 Mdot
.36972 .43715 Mdot
.40757 .41943 Mdot
.37842 .66171 Mdot
.55327 .65698 Mdot
.77447 .67137 Mdot
.55334 .62945 Mdot
.75214 .32333 Mdot
.65942 .50466 Mdot
.65091 .53077 Mdot
.43661 .40625 Mdot
.62951 .56589 Mdot
.46782 .2954 Mdot
.40741 .43879 Mdot
.61252 .55207 Mdot
.20316 .40675 Mdot
.36563 .41022 Mdot
.40982 .59498 Mdot
.46806 .34844 Mdot
.38919 .66133 Mdot
.58457 .61812 Mdot
.59281 .3559 Mdot
.60915 .32045 Mdot
.56078 .65852 Mdot
.42091 .40541 Mdot
.62757 .5904 Mdot
.42051 .42888 Mdot
.39976 .36641 Mdot
.74814 .30905 Mdot
.55934 .35443 Mdot
.64834 .52304 Mdot
.58093 .36705 Mdot
.3395 .61682 Mdot
.64149 .86928 Mdot
.60116 .33698 Mdot
.4631 .29782 Mdot
.31397 .2658 Mdot
.49571 .27914 Mdot
.35521 .58542 Mdot
.60173 .38344 Mdot
.54292 .64252 Mdot
.21366 .67585 Mdot
.46878 .1776 Mdot
.51667 .64019 Mdot
.40916 .39869 Mdot
.33538 .60268 Mdot
.39128 .58995 Mdot
.57285 .60474 Mdot
.3775 .62935 Mdot
.36604 .45506 Mdot
.39838 .37191 Mdot
.56415 .67397 Mdot
.49424 .74789 Mdot
.55401 .60546 Mdot
.44613 .68828 Mdot
.39092 .42901 Mdot
.3568 .58815 Mdot
.47026 .35193 Mdot
.34437 .66429 Mdot
.65442 .45863 Mdot
.37509 .3834 Mdot
.60732 .36074 Mdot
.60703 .58134 Mdot
.67429 .49821 Mdot
.78984 .54727 Mdot
.35679 .63182 Mdot
.52352 .59357 Mdot
.36874 .63214 Mdot
.33302 .6431 Mdot
.55821 .6667 Mdot
.35727 .64645 Mdot
.45238 .41811 Mdot
.61697 .50531 Mdot
.34871 .63411 Mdot
.57382 .63657 Mdot
.58865 .36002 Mdot
.37259 .6017 Mdot
.68227 .4372 Mdot
.40838 .37805 Mdot
.64445 .47999 Mdot
.68397 .69341 Mdot
.33059 .62047 Mdot
.58759 .38238 Mdot
.67156 .5264 Mdot
.61725 .36471 Mdot
.18219 .42876 Mdot
.53725 .66656 Mdot
.65023 .2347 Mdot
.54104 .32666 Mdot
.39794 .60897 Mdot
.67705 .69595 Mdot
.43759 .42355 Mdot
.40608 .3792 Mdot
.6223 .36935 Mdot
.39166 .59035 Mdot
.24224 .67814 Mdot
.33013 .56934 Mdot
.44563 .72139 Mdot
.54048 .67268 Mdot
.77227 .6571 Mdot
.43629 .6775 Mdot
.2361 .31944 Mdot
.35881 .40239 Mdot
.65155 .54423 Mdot
.42238 .41271 Mdot
.59977 .7731 Mdot
.56887 .3474 Mdot
.64403 .38057 Mdot
.45879 .36079 Mdot
.66018 .52469 Mdot
.42306 .38071 Mdot
.45718 .5677 Mdot
.4293 .3326 Mdot
.59417 .32977 Mdot
.63063 .67308 Mdot
.39997 .61647 Mdot
.58277 .35361 Mdot
.68631 .47158 Mdot
.48388 .29376 Mdot
.42536 .35757 Mdot
.36446 .36851 Mdot
.6998 .45834 Mdot
.35863 .62345 Mdot
.63282 .53369 Mdot
.58236 .61772 Mdot
.60189 .35718 Mdot
.39875 .38419 Mdot
.4563 .36616 Mdot
.67639 .60491 Mdot
.56331 .66189 Mdot
.70824 .48678 Mdot
.55837 .62218 Mdot
.63474 .54485 Mdot
.41472 .4592 Mdot
.65256 .53115 Mdot
.45053 .37205 Mdot
.64285 .74677 Mdot
.74249 .3051 Mdot
.24122 .54206 Mdot
.66824 .52513 Mdot
.53373 .28989 Mdot
.58067 .63711 Mdot
.57336 .61959 Mdot
.30111 .31804 Mdot
.39537 .50709 Mdot
.73235 .34307 Mdot
.4303 .80265 Mdot
.57769 .61313 Mdot
.5752 .64891 Mdot
.64481 .47725 Mdot
.35252 .64453 Mdot
.32771 .62787 Mdot
.6752 .53325 Mdot
.49368 .21315 Mdot
.37136 .62002 Mdot
.29228 .72683 Mdot
.73302 .35531 Mdot
.38268 .46096 Mdot
.50265 .64262 Mdot
.59817 .36074 Mdot
.51091 .22177 Mdot
.45997 .57961 Mdot
.45112 .42564 Mdot
.81935 .51805 Mdot
.65905 .49144 Mdot
.4228 .24962 Mdot
.38055 .80586 Mdot
.46216 .41484 Mdot
.42117 .39315 Mdot
.41515 .41161 Mdot
.56122 .36382 Mdot
.33086 .4584 Mdot
.45904 .41385 Mdot
.49257 .21091 Mdot
.46736 .42084 Mdot
.52644 .388 Mdot
.57828 .36434 Mdot
.49427 .34734 Mdot
.66353 .67103 Mdot
.79348 .44821 Mdot
.49624 .40077 Mdot
.58073 .61781 Mdot
.58071 .50564 Mdot
.58943 .63863 Mdot
.24324 .58157 Mdot
.57282 .26295 Mdot
.39815 .57494 Mdot
.45048 .42384 Mdot
.68212 .50314 Mdot
.38938 .58829 Mdot
.71928 .5987 Mdot
.50752 .93165 Mdot
.5892 .62481 Mdot
.29576 .21427 Mdot
.56639 .61863 Mdot
.68069 .46191 Mdot
.36047 .60238 Mdot
.31128 .52785 Mdot
.57928 .55288 Mdot
.37545 .60169 Mdot
.42445 .76217 Mdot
.31846 .61823 Mdot
.51676 .2903 Mdot
.34364 .5825 Mdot
.57644 .63608 Mdot
.59155 .60602 Mdot
.44236 .47578 Mdot
.44044 .41421 Mdot
.49648 .5671 Mdot
.49778 .3122 Mdot
.43953 .41922 Mdot
.67931 .49899 Mdot
.56696 .18301 Mdot
.59281 .43293 Mdot
.37596 .64041 Mdot
.53589 .61417 Mdot
.42215 .39031 Mdot
.38894 .37998 Mdot
.4174 .35825 Mdot
.85713 .53514 Mdot
.27878 .70169 Mdot
.43514 .36671 Mdot
.46151 .43577 Mdot
.67023 .52127 Mdot
.63189 .37382 Mdot
.57837 .78588 Mdot
.51488 .42559 Mdot
.43593 .4415 Mdot
.57782 .35525 Mdot
.55825 .34355 Mdot
.40905 .35723 Mdot
.78036 .462 Mdot
.66175 .57793 Mdot
.439 .39542 Mdot
.43685 .49843 Mdot
.73589 .62142 Mdot
.68395 .45992 Mdot
.66717 .4875 Mdot
.40438 .61038 Mdot
.68786 .49757 Mdot
.69781 .49326 Mdot
.31505 .50715 Mdot
.5589 .49903 Mdot
.60725 .66482 Mdot
.56523 .35296 Mdot
.41092 .4293 Mdot
.33669 .58253 Mdot
.61464 .71219 Mdot
.57447 .65992 Mdot
.38616 .59697 Mdot
.59273 .64611 Mdot
.55831 .36837 Mdot
.39621 .23402 Mdot
.69273 .49044 Mdot
.56684 .60829 Mdot
.43372 .72079 Mdot
.57732 .35785 Mdot
.54323 .66181 Mdot
.63835 .58979 Mdot
.37548 .43108 Mdot
.2951 .59087 Mdot
.40195 .43675 Mdot
.20942 .64209 Mdot
.54203 .65955 Mdot
.65115 .69401 Mdot
.42724 .4007 Mdot
.66707 .49723 Mdot
.3501 .36218 Mdot
.42804 .44049 Mdot
.6735 .48245 Mdot
.40906 .36298 Mdot
.59623 .37714 Mdot
.41841 .62242 Mdot
.57349 .50648 Mdot
.73906 .25022 Mdot
.62123 .36232 Mdot
.70978 .59905 Mdot
.44334 .42706 Mdot
.22079 .37642 Mdot
.37342 .60316 Mdot
.45325 .36991 Mdot
.42197 .29523 Mdot
.34301 .63417 Mdot
.37702 .59082 Mdot
.38398 .40082 Mdot
.54213 .63456 Mdot
.67508 .4946 Mdot
.57883 .36262 Mdot
.17928 .41313 Mdot
.40406 .40787 Mdot
.41929 .37061 Mdot
.58443 .34995 Mdot
.57767 .64829 Mdot
.38544 .3846 Mdot
.69349 .70541 Mdot
.15553 .5677 Mdot
.57411 .66378 Mdot
.39867 .44869 Mdot
.30867 .58475 Mdot
.38591 .66593 Mdot
.38013 .18198 Mdot
.63888 .29555 Mdot
.64811 .52673 Mdot
.33732 .39947 Mdot
.72621 .7908 Mdot
.59234 .35768 Mdot
.79984 .41924 Mdot
.39716 .36627 Mdot
.43296 .37502 Mdot
.39347 .60666 Mdot
.38194 .42088 Mdot
.33702 .63215 Mdot
.69901 .22356 Mdot
.82658 .52764 Mdot
.35213 .62446 Mdot
.3958 .61824 Mdot
.45019 .29941 Mdot
.58249 .78325 Mdot
.35402 .60069 Mdot
.44684 .45452 Mdot
.25181 .6496 Mdot
.50707 .41574 Mdot
.62426 .36664 Mdot
.70496 .67024 Mdot
.33171 .66864 Mdot
.61125 .41783 Mdot
.42196 .78581 Mdot
.32794 .67006 Mdot
.68568 .56558 Mdot
.56593 .61491 Mdot
.45914 .42842 Mdot
.69088 .498 Mdot
.66077 .53136 Mdot
.4316 .33593 Mdot
.41722 .43256 Mdot
.34479 .62524 Mdot
.56383 .34718 Mdot
.5832 .66438 Mdot
.42074 .36628 Mdot
.59574 .43386 Mdot
.59651 .33752 Mdot
.36685 .64127 Mdot
.32854 .30213 Mdot
.60005 .32945 Mdot
.4365 .32936 Mdot
.44738 .39984 Mdot
.38462 .43229 Mdot
.49413 .45455 Mdot
.53933 .62532 Mdot
.67486 .70704 Mdot
.41282 .45447 Mdot
.79899 .4685 Mdot
.49859 .48497 Mdot
.3479 .39896 Mdot
.37166 .6257 Mdot
.59899 .65854 Mdot
.6361 .47449 Mdot
.39709 .27343 Mdot
.4027 .39929 Mdot
.27437 .69002 Mdot
.27409 .3967 Mdot
.64011 .47204 Mdot
.35034 .65209 Mdot
.59608 .36695 Mdot
.40944 .43793 Mdot
.24842 .6142 Mdot
.43115 .41976 Mdot
.53986 .3413 Mdot
.65234 .48853 Mdot
.56277 .61507 Mdot
.17387 .58909 Mdot
.65954 .53157 Mdot
.37227 .589 Mdot
.32531 .80308 Mdot
.3379 .59219 Mdot
.38801 .63663 Mdot
.26468 .62948 Mdot
.54686 .61818 Mdot
.74902 .77357 Mdot
.44522 .1735 Mdot
.41562 .34468 Mdot
.58235 .63336 Mdot
.35203 .60981 Mdot
.45613 .38822 Mdot
.3686 .57563 Mdot
.36783 .65226 Mdot
.37952 .45025 Mdot
.44495 .38637 Mdot
.40634 .6967 Mdot
.33159 .7781 Mdot
.5926 .36889 Mdot
.33988 .60467 Mdot
.35596 .30943 Mdot
.46055 .3936 Mdot
.43136 .40507 Mdot
.73856 .60435 Mdot
.60554 .3331 Mdot
.45293 .63607 Mdot
.39292 .37125 Mdot
.8208 .55383 Mdot
.47057 .35031 Mdot
.40739 .60628 Mdot
.5707 .66449 Mdot
.78972 .44075 Mdot
.57493 .71303 Mdot
.34371 .64526 Mdot
.57007 .36441 Mdot
.37349 .56746 Mdot
.46739 .30012 Mdot
.55042 .61042 Mdot
.37991 .58591 Mdot
.54599 .48861 Mdot
.55925 .64269 Mdot
.53999 .65564 Mdot
.23731 .61039 Mdot
.70421 .49692 Mdot
.57281 .37377 Mdot
.56681 .65779 Mdot
.33138 .33678 Mdot
.57055 .63015 Mdot
.30497 .33533 Mdot
.4205 .45057 Mdot
.44736 .22664 Mdot
.51942 .58294 Mdot
.39913 .4843 Mdot
.532 .64179 Mdot
.59307 .37335 Mdot
.38443 .39291 Mdot
.38124 .62738 Mdot
.60715 .34185 Mdot
.51079 .62853 Mdot
.64146 .49827 Mdot
.36806 .63444 Mdot
.52822 .66002 Mdot
.34368 .60022 Mdot
.39057 .26355 Mdot
.34553 .22866 Mdot
.72948 .67689 Mdot
.57383 .54746 Mdot
.41343 .35871 Mdot
.48914 .80457 Mdot
.39105 .46237 Mdot
.42135 .43475 Mdot
.68037 .49381 Mdot
.43883 .24254 Mdot
.36323 .60538 Mdot
.17567 .59785 Mdot
.56755 .61057 Mdot
.8276 .50716 Mdot
.38456 .5554 Mdot
.45148 .36714 Mdot
.34628 .63282 Mdot
.34104 .58701 Mdot
.22497 .52328 Mdot
.66181 .4503 Mdot
.45617 .45897 Mdot
.43896 .47099 Mdot
.35738 .3884 Mdot
.54008 .65344 Mdot
.79015 .53677 Mdot
.64075 .54164 Mdot
.3473 .21493 Mdot
.65608 .48465 Mdot
.60457 .54959 Mdot
.36148 .64576 Mdot
.60454 .33668 Mdot
.43319 .4035 Mdot
.36758 .55194 Mdot
.34188 .64501 Mdot
.54798 .36646 Mdot
.61197 .35644 Mdot
.75828 .54744 Mdot
.54117 .62723 Mdot
.42492 .35461 Mdot
.45744 .42304 Mdot
.38679 .41782 Mdot
.40584 .44404 Mdot
.58853 .62267 Mdot
.37486 .40242 Mdot
.60042 .62581 Mdot
.32504 .33829 Mdot
.8193 .53067 Mdot
.55572 .49732 Mdot
.42463 .5606 Mdot
.38125 .63304 Mdot
.33821 .33537 Mdot
.43441 .32777 Mdot
.71361 .2785 Mdot
.17766 .50907 Mdot
.36708 .40215 Mdot
.63957 .48036 Mdot
.3888 .50649 Mdot
.69399 .50354 Mdot
.36973 .15658 Mdot
.67103 .61186 Mdot
.30962 .76664 Mdot
.45926 .40072 Mdot
.74051 .60607 Mdot
.33016 .41974 Mdot
.40726 .46845 Mdot
.7047 .61642 Mdot
.57065 .72624 Mdot
.45653 .75601 Mdot
.5667 .33486 Mdot
.40967 .38269 Mdot
.32504 .60282 Mdot
.45405 .41712 Mdot
.42781 .40943 Mdot
.39563 .36596 Mdot
.52785 .64031 Mdot
.46976 .44099 Mdot
.39354 .44177 Mdot
.73755 .45225 Mdot
.53054 .2698 Mdot
.6372 .53012 Mdot
.29769 .31563 Mdot
.60159 .33816 Mdot
.35 .63112 Mdot
.3691 .74004 Mdot
.53887 .63889 Mdot
.22331 .50604 Mdot
.39523 .44026 Mdot
.41545 .70805 Mdot
.53051 .66625 Mdot
.60456 .35739 Mdot
.62617 .53373 Mdot
.27924 .74283 Mdot
.67846 .50712 Mdot
.54259 .49171 Mdot
.66915 .50088 Mdot
.48392 .35734 Mdot
.3441 .62409 Mdot
.39706 .36239 Mdot
.56697 .65577 Mdot
.68085 .48742 Mdot
.48557 .25041 Mdot
.409 .41852 Mdot
.6657 .51988 Mdot
.39565 .36364 Mdot
.40787 .22629 Mdot
.66075 .26576 Mdot
.6979 .48507 Mdot
.60691 .64331 Mdot
.56493 .64074 Mdot
.6034 .33364 Mdot
.35996 .63698 Mdot
.39187 .60977 Mdot
.55378 .64598 Mdot
.49847 .17444 Mdot
.43455 .44089 Mdot
.45814 .39205 Mdot
.80118 .46767 Mdot
.4463 .4182 Mdot
.50358 .29863 Mdot
.54248 .48277 Mdot
.37347 .63922 Mdot
.44893 .37701 Mdot
.38937 .38207 Mdot
.40305 .38867 Mdot
.37866 .26229 Mdot
.66349 .48351 Mdot
.44763 .44037 Mdot
.61392 .35902 Mdot
.62285 .5035 Mdot
.45786 .38827 Mdot
.35718 .3856 Mdot
.39161 .60788 Mdot
.83929 .48181 Mdot
.55736 .61935 Mdot
.67973 .46635 Mdot
.65599 .52945 Mdot
.70849 .66654 Mdot
.30281 .64977 Mdot
.54448 .47999 Mdot
.32742 .22757 Mdot
.66215 .68477 Mdot
.58649 .34442 Mdot
.60941 .57199 Mdot
.51733 .46732 Mdot
.65634 .46565 Mdot
.59404 .63644 Mdot
.41464 .45271 Mdot
.433 .44364 Mdot
.79214 .35552 Mdot
.44825 .36348 Mdot
.59584 .36456 Mdot
.59196 .6162 Mdot
.38172 .62145 Mdot
.60449 .35927 Mdot
.56988 .62014 Mdot
.3605 .62463 Mdot
.37612 .43663 Mdot
.38274 .44535 Mdot
.38465 .59712 Mdot
.39197 .59303 Mdot
.44213 .39859 Mdot
.62561 .55016 Mdot
.40215 .61571 Mdot
.36203 .58465 Mdot
.69334 .49118 Mdot
.68931 .49162 Mdot
.36626 .4407 Mdot
.57881 .62809 Mdot
.3791 .43019 Mdot
.67799 .51353 Mdot
.57053 .3388 Mdot
.36904 .60703 Mdot
.3935 .37815 Mdot
.41202 .36599 Mdot
.57863 .35902 Mdot
.56327 .34093 Mdot
.60917 .35607 Mdot
.58254 .60429 Mdot
.3929 .41798 Mdot
.35978 .59746 Mdot
.54802 .62 Mdot
.55803 .34367 Mdot
.6249 .34463 Mdot
.71279 .49969 Mdot
.43835 .42886 Mdot
.69952 .44663 Mdot
.63546 .8678 Mdot
.5592 .30183 Mdot
.64157 .4683 Mdot
.70609 .47315 Mdot
.49591 .26781 Mdot
.63062 .56199 Mdot
.54739 .64178 Mdot
.56951 .30824 Mdot
.62038 .32557 Mdot
.375 .38536 Mdot
.40274 .45656 Mdot
.42314 .47526 Mdot
.60543 .34928 Mdot
.4135 .26954 Mdot
.36122 .5783 Mdot
.24032 .40815 Mdot
.60331 .33949 Mdot
.6862 .46019 Mdot
.70519 .49877 Mdot
.65526 .48501 Mdot
.40047 .45319 Mdot
.24006 .53232 Mdot
.41252 .3116 Mdot
.48893 .81092 Mdot
.53454 .65144 Mdot
.39385 .56993 Mdot
.19686 .40834 Mdot
.38054 .5939 Mdot
.68732 .52057 Mdot
.6029 .34343 Mdot
.37937 .58424 Mdot
.58667 .65047 Mdot
.57288 .65047 Mdot
.66072 .48187 Mdot
.65718 .50207 Mdot
.65131 .47569 Mdot
.3798 .64505 Mdot
.3579 .64605 Mdot
.40145 .40662 Mdot
.37844 .61042 Mdot
.8234 .40763 Mdot
.56368 .37031 Mdot
.70911 .47687 Mdot
.562 .62679 Mdot
.34615 .62014 Mdot
.40675 .42205 Mdot
.581 .45169 Mdot
.53694 .73511 Mdot
.61507 .36861 Mdot
.68146 .28453 Mdot
.36209 .16374 Mdot
.43418 .35625 Mdot
.54353 .65515 Mdot
.78291 .38094 Mdot
.41304 .41124 Mdot
.64785 .5004 Mdot
.6408 .75479 Mdot
.62518 .50905 Mdot
.37758 .43018 Mdot
.42669 .35073 Mdot
.55593 .66976 Mdot
.3004 .27194 Mdot
.40105 .41322 Mdot
.46471 .65073 Mdot
.53765 .61046 Mdot
.65393 .53979 Mdot
.15796 .58201 Mdot
.73503 .64902 Mdot
.50258 .21867 Mdot
.69192 .48685 Mdot
.42717 .42865 Mdot
.68745 .48268 Mdot
.61158 .37034 Mdot
.68002 .47199 Mdot
.41298 .60269 Mdot
.63729 .53366 Mdot
.42068 .37113 Mdot
.35221 .60085 Mdot
.55101 .63709 Mdot
.82423 .49 Mdot
.73374 .43103 Mdot
.66609 .49748 Mdot
.69091 .47236 Mdot
.43686 .36556 Mdot
.43844 .66011 Mdot
.40477 .34102 Mdot
.46013 .39807 Mdot
.57386 .60958 Mdot
.34978 .63613 Mdot
.52873 .65001 Mdot
.47048 .39655 Mdot
.68739 .72 Mdot
.5523 .62455 Mdot
.4073 .70992 Mdot
.58547 .34743 Mdot
.46721 .54078 Mdot
.40867 .43021 Mdot
.57329 .6575 Mdot
.39275 .41939 Mdot
.37418 .57512 Mdot
.50735 .5264 Mdot
.62105 .7165 Mdot
.56554 .6543 Mdot
.23351 .6634 Mdot
.67566 .54382 Mdot
.48527 .38416 Mdot
.58809 .62967 Mdot
.42309 .29654 Mdot
.67689 .46011 Mdot
.58689 .3396 Mdot
.5597 .34182 Mdot
.61908 .36052 Mdot
.3749 .36354 Mdot
.48934 .38329 Mdot
.57924 .37455 Mdot
.58092 .66139 Mdot
.58712 .32959 Mdot
.30403 .67561 Mdot
.23767 .67456 Mdot
.56884 .34975 Mdot
.41228 .39203 Mdot
.4795 .45934 Mdot
.52504 .26604 Mdot
.68434 .44106 Mdot
.31392 .76027 Mdot
.42779 .57429 Mdot
.43843 .41492 Mdot
.39339 .66652 Mdot
.36871 .57842 Mdot
.77883 .38478 Mdot
.51061 .31749 Mdot
.77543 .44398 Mdot
.39547 .6225 Mdot
.63432 .7045 Mdot
.36693 .63973 Mdot
.43969 .36078 Mdot
.45307 .3873 Mdot
.32739 .63202 Mdot
.79979 .53809 Mdot
.68343 .59057 Mdot
.1566 .52159 Mdot
.35649 .58617 Mdot
.5875 .63932 Mdot
.58298 .6133 Mdot
.53472 .6477 Mdot
.72253 .34501 Mdot
.33244 .6183 Mdot
.39379 .40889 Mdot
.67345 .521 Mdot
.44616 .43788 Mdot
.5583 .65037 Mdot
.17885 .60284 Mdot
.38906 .61502 Mdot
.4374 .39265 Mdot
.49472 .18423 Mdot
.65064 .50849 Mdot
.57688 .35191 Mdot
.38469 .23381 Mdot
.75408 .38886 Mdot
.54651 .61553 Mdot
.32978 .60822 Mdot
.64182 .6723 Mdot
.39285 .71409 Mdot
.36021 .41845 Mdot
.35752 .43399 Mdot
.21056 .35773 Mdot
.7434 .37944 Mdot
.39089 .36284 Mdot
.6754 .46285 Mdot
.63963 .70356 Mdot
.39955 .37615 Mdot
.35142 .58649 Mdot
.57491 .32859 Mdot
.61665 .35175 Mdot
.43807 .4636 Mdot
.58578 .55539 Mdot
.47415 .51407 Mdot
.37757 .4108 Mdot
.43713 .32926 Mdot
.68596 .52011 Mdot
.6607 .67898 Mdot
.81005 .48244 Mdot
.56664 .36129 Mdot
.38947 .3723 Mdot
.46759 .77472 Mdot
.35976 .65091 Mdot
.63102 .51169 Mdot
.54687 .61195 Mdot
.35962 .2689 Mdot
.64654 .5415 Mdot
.39914 .37523 Mdot
.38628 .38385 Mdot
.54441 .66335 Mdot
.40748 .60617 Mdot
.60414 .34771 Mdot
.66815 .52587 Mdot
.56794 .36352 Mdot
.33879 .63055 Mdot
.38645 .6172 Mdot
.50948 .40561 Mdot
.48621 .41598 Mdot
.66886 .48765 Mdot
.4692 .40034 Mdot
.66796 .43602 Mdot
.29684 .27128 Mdot
.54664 .67878 Mdot
.43506 .35612 Mdot
.39159 .65307 Mdot
.562 .65676 Mdot
.4376 .38071 Mdot
.18413 .38918 Mdot
.46485 .40008 Mdot
.5806 .71353 Mdot
.72132 .69857 Mdot
.60147 .36967 Mdot
.2212 .40927 Mdot
.3643 .69195 Mdot
.44882 .4142 Mdot
.63796 .51106 Mdot
.36319 .3517 Mdot
.54301 .63701 Mdot
.37153 .64315 Mdot
.38754 .17496 Mdot
.57071 .63296 Mdot
.45725 .40713 Mdot
.60286 .35734 Mdot
.33408 .59606 Mdot
.58681 .51254 Mdot
.78999 .47197 Mdot
.45928 .34976 Mdot
.45265 .45175 Mdot
.37677 .42459 Mdot
.62613 .78155 Mdot
.67808 .46626 Mdot
.34843 .61429 Mdot
.54022 .65241 Mdot
.55159 .64739 Mdot
.65974 .4854 Mdot
.45865 .74688 Mdot
.4697 .5389 Mdot
.67334 .82817 Mdot
.67582 .48104 Mdot
.59156 .38366 Mdot
.45351 .64932 Mdot
.63679 .5114 Mdot
.6633 .51858 Mdot
.68573 .51985 Mdot
.60274 .68652 Mdot
.36308 .62286 Mdot
.41136 .36517 Mdot
.39134 .57946 Mdot
.42877 .43145 Mdot
.47181 .50222 Mdot
.563 .65867 Mdot
.37629 .64199 Mdot
.1905 .38437 Mdot
.38165 .51896 Mdot
.4148 .40248 Mdot
.2069 .3877 Mdot
.45284 .35529 Mdot
.4726 .2779 Mdot
.48083 .38904 Mdot
.66306 .50184 Mdot
.33531 .41781 Mdot
.37673 .35235 Mdot
.82516 .45851 Mdot
.56344 .62553 Mdot
.67221 .45775 Mdot
.38836 .35929 Mdot
.46388 .34372 Mdot
.32464 .63029 Mdot
.37411 .58316 Mdot
.57244 .37019 Mdot
.59307 .25512 Mdot
.55071 .63514 Mdot
.3627 .22549 Mdot
.44282 .41051 Mdot
.77462 .62432 Mdot
.21866 .42911 Mdot
.43703 .38162 Mdot
.25484 .66112 Mdot
.23302 .52167 Mdot
.40967 .43581 Mdot
.46164 .31465 Mdot
.57808 .6456 Mdot
.6929 .71608 Mdot
.46143 .43772 Mdot
.64614 .50388 Mdot
.3568 .64384 Mdot
.34826 .58593 Mdot
.58623 .37607 Mdot
.7041 .25303 Mdot
.53052 .6523 Mdot
.37136 .64429 Mdot
.41233 .4192 Mdot
.54637 .6172 Mdot
.68808 .50338 Mdot
.46758 .38253 Mdot
.51808 .31098 Mdot
.37884 .61365 Mdot
.46675 .42959 Mdot
.48877 .69638 Mdot
.53905 .23533 Mdot
.49271 .84857 Mdot
.53561 .64447 Mdot
.5868 .3328 Mdot
.35676 .36173 Mdot
.39767 .21197 Mdot
.36662 .39817 Mdot
.44071 .22954 Mdot
.30459 .66704 Mdot
.58802 .33219 Mdot
.42273 .39818 Mdot
.39756 .39141 Mdot
.52986 .57497 Mdot
.56349 .34456 Mdot
.45854 .42443 Mdot
.34958 .47197 Mdot
.35829 .62209 Mdot
.62525 .53974 Mdot
.37613 .61808 Mdot
.40971 .39813 Mdot
.48045 .43537 Mdot
.39377 .60142 Mdot
.29342 .24551 Mdot
.58296 .32037 Mdot
.55289 .62106 Mdot
.48948 .4006 Mdot
.42482 .4525 Mdot
.70891 .7543 Mdot
.65574 .45834 Mdot
.54886 .78827 Mdot
.65271 .42792 Mdot
.45105 .7811 Mdot
.73883 .64334 Mdot
.31371 .78975 Mdot
.82011 .51258 Mdot
.43565 .47148 Mdot
.42826 .53687 Mdot
.44544 .31283 Mdot
.53153 .63822 Mdot
.3052 .43753 Mdot
.44011 .41481 Mdot
.42545 .41134 Mdot
.63114 .50284 Mdot
.42712 .73198 Mdot
.7828 .45464 Mdot
.5831 .5371 Mdot
.60076 .34719 Mdot
.33987 .61098 Mdot
.43893 .37329 Mdot
.56525 .435 Mdot
.63458 .52602 Mdot
.78015 .61172 Mdot
.43256 .39316 Mdot
.70782 .2772 Mdot
.61194 .69376 Mdot
.53962 .62629 Mdot
.64443 .52926 Mdot
.76754 .41305 Mdot
.43599 .4328 Mdot
.55969 .60419 Mdot
.40203 .41797 Mdot
.71994 .52535 Mdot
.46562 .38945 Mdot
.57497 .34206 Mdot
.40423 .36089 Mdot
.58532 .52848 Mdot
.41524 .83416 Mdot
.5529 .32645 Mdot
.33641 .60208 Mdot
.69355 .45242 Mdot
.6644 .4847 Mdot
.38545 .58801 Mdot
.66493 .48775 Mdot
.22561 .46688 Mdot
.29506 .52425 Mdot
.59626 .34538 Mdot
.44854 .33377 Mdot
.56877 .35711 Mdot
.65341 .45879 Mdot
.43576 .42253 Mdot
.30943 .23457 Mdot
.67546 .48757 Mdot
.73168 .70433 Mdot
.56561 .62956 Mdot
.6637 .45683 Mdot
.46703 .42312 Mdot
.64219 .65126 Mdot
.64995 .53323 Mdot
.62501 .70812 Mdot
.40271 .39095 Mdot
.38519 .62253 Mdot
.39614 .38758 Mdot
.47757 .37478 Mdot
.63495 .54646 Mdot
.404 .44665 Mdot
.57005 .62022 Mdot
.39799 .62936 Mdot
.26041 .70807 Mdot
.58658 .71476 Mdot
.45302 .42557 Mdot
.41259 .41681 Mdot
.32891 .59979 Mdot
.44483 .44404 Mdot
.58805 .6222 Mdot
.89712 .55337 Mdot
.58482 .34756 Mdot
.69443 .47336 Mdot
.72878 .65965 Mdot
.36674 .41173 Mdot
.37921 .39883 Mdot
.17382 .42069 Mdot
.72378 .6751 Mdot
.58292 .62349 Mdot
.39322 .34095 Mdot
.67637 .5214 Mdot
.60121 .35849 Mdot
.57724 .66586 Mdot
.38421 .4315 Mdot
.43014 .40253 Mdot
.58674 .33336 Mdot
.23828 .62405 Mdot
.76352 .38462 Mdot
.53746 .65798 Mdot
.33616 .42438 Mdot
.62954 .43481 Mdot
.43156 .44088 Mdot
.72378 .34011 Mdot
.37374 .58483 Mdot
.55728 .60876 Mdot
.53024 .80408 Mdot
.38317 .37439 Mdot
.5742 .66175 Mdot
.55228 .63269 Mdot
.38246 .3482 Mdot
.35681 .66283 Mdot
.38651 .64449 Mdot
.3428 .60258 Mdot
.83424 .41006 Mdot
.51951 .23415 Mdot
.65111 .47591 Mdot
.57771 .64712 Mdot
.6985 .49762 Mdot
.58372 .38422 Mdot
.53709 .46417 Mdot
.69699 .48044 Mdot
.38784 .58568 Mdot
.69546 .45009 Mdot
.39947 .38829 Mdot
.54966 .63924 Mdot
.65624 .46681 Mdot
.38651 .35895 Mdot
.41339 .67755 Mdot
.74578 .49202 Mdot
.61415 .33467 Mdot
.57031 .329 Mdot
.4503 .38386 Mdot
.63463 .47636 Mdot
.44072 .40005 Mdot
.59404 .66014 Mdot
.44566 .66092 Mdot
.37217 .37994 Mdot
.66439 .49578 Mdot
.38404 .67395 Mdot
.75406 .38925 Mdot
.42382 .34164 Mdot
.41321 .39278 Mdot
.42833 .4371 Mdot
.40159 .41884 Mdot
.42883 .75069 Mdot
.54347 .6749 Mdot
.46371 .61139 Mdot
.6751 .69456 Mdot
.3816 .60363 Mdot
.37605 .65649 Mdot
.68811 .32058 Mdot
.69173 .56551 Mdot
.58049 .63068 Mdot
.41986 .43813 Mdot
.60747 .71594 Mdot
.18511 .61431 Mdot
.27313 .25662 Mdot
.55483 .37657 Mdot
.6373 .4785 Mdot
.32952 .6187 Mdot
.63662 .52438 Mdot
.42849 .42585 Mdot
.35328 .36632 Mdot
.30925 .79146 Mdot
.58693 .59717 Mdot
.60419 .34482 Mdot
.42779 .43534 Mdot
.52003 .2283 Mdot
.6708 .52135 Mdot
.70049 .50589 Mdot
.46184 .41989 Mdot
.40579 .62487 Mdot
.62385 .81279 Mdot
.53702 .62978 Mdot
.43123 .57881 Mdot
.32803 .36956 Mdot
.49602 .67921 Mdot
.55555 .65533 Mdot
.76358 .44787 Mdot
.63359 .48238 Mdot
.2007 .50752 Mdot
.38445 .60456 Mdot
.60323 .34133 Mdot
.34976 .41643 Mdot
.39415 .61524 Mdot
.63389 .54117 Mdot
.38121 .63474 Mdot
.40641 .35857 Mdot
.53232 .66183 Mdot
.64464 .52565 Mdot
.60728 .6328 Mdot
.36113 .66225 Mdot
.58089 .37055 Mdot
.497 .58504 Mdot
.33265 .49512 Mdot
.23047 .51722 Mdot
.44204 .4419 Mdot
.56358 .43162 Mdot
.39152 .41303 Mdot
.3262 .63871 Mdot
.40505 .42077 Mdot
.40178 .66141 Mdot
.63897 .51696 Mdot
.46163 .4359 Mdot
.37527 .41526 Mdot
.28873 .39972 Mdot
.42582 .38834 Mdot
.47471 .42274 Mdot
.41266 .4382 Mdot
.37215 .56012 Mdot
.42067 .33067 Mdot
.36899 .62634 Mdot
.78183 .47974 Mdot
.66234 .51713 Mdot
.56725 .33167 Mdot
.61691 .34386 Mdot
.45688 .22519 Mdot
.62123 .31179 Mdot
.44327 .74253 Mdot
.36852 .61563 Mdot
.55831 .62389 Mdot
.40293 .42335 Mdot
.44206 .80771 Mdot
.72342 .63595 Mdot
.68169 .51837 Mdot
.58692 .71459 Mdot
.3541 .44518 Mdot
.63083 .78197 Mdot
.47037 .41706 Mdot
.78712 .34089 Mdot
.46352 .46544 Mdot
.46054 .38201 Mdot
.69344 .51657 Mdot
.57082 .32118 Mdot
.45832 .43454 Mdot
.32427 .62835 Mdot
.58764 .33629 Mdot
.39297 .53751 Mdot
.60993 .4735 Mdot
.76352 .46051 Mdot
.30332 .47584 Mdot
.39542 .41987 Mdot
.64429 .52366 Mdot
.36687 .63422 Mdot
.81435 .48956 Mdot
.55066 .61847 Mdot
.59465 .57408 Mdot
.34867 .31936 Mdot
.24027 .33542 Mdot
.5975 .33786 Mdot
.23698 .61438 Mdot
.42098 .37012 Mdot
.70696 .35228 Mdot
.37605 .44355 Mdot
.18805 .61651 Mdot
.5991 .38383 Mdot
.3964 .64193 Mdot
.58751 .63697 Mdot
.38233 .57717 Mdot
.23658 .53997 Mdot
.49942 .63042 Mdot
.52367 .54351 Mdot
.67582 .51147 Mdot
.46976 .60675 Mdot
.34906 .60597 Mdot
.38486 .38162 Mdot
.6592 .84181 Mdot
.36614 .58437 Mdot
.3381 .63721 Mdot
.31798 .25664 Mdot
.29823 .26407 Mdot
.34317 .42923 Mdot
.39763 .61145 Mdot
.67294 .51162 Mdot
.58731 .36997 Mdot
.39213 .39345 Mdot
.39966 .40498 Mdot
.39294 .60875 Mdot
.69804 .51101 Mdot
.39634 .52578 Mdot
.65849 .50307 Mdot
.35701 .624 Mdot
.65453 .51548 Mdot
.65465 .70686 Mdot
.65531 .46412 Mdot
.42784 .45147 Mdot
.40446 .42167 Mdot
.64675 .43773 Mdot
.38623 .61736 Mdot
.37946 .40914 Mdot
.41399 .3616 Mdot
.35753 .59938 Mdot
.60574 .42891 Mdot
.30671 .59351 Mdot
.4468 .42567 Mdot
.41115 .37906 Mdot
.5818 .33341 Mdot
.54399 .43923 Mdot
.62067 .22806 Mdot
.38442 .39326 Mdot
.56862 .37272 Mdot
.37946 .64441 Mdot
.4416 .39562 Mdot
.32711 .71705 Mdot
.63901 .70549 Mdot
.38546 .37266 Mdot
.6737 .45935 Mdot
.36544 .36901 Mdot
.53934 .83895 Mdot
.46172 .40117 Mdot
.35561 .60654 Mdot
.34607 .63849 Mdot
.34052 .25509 Mdot
.36769 .5884 Mdot
.69087 .49461 Mdot
.55901 .64572 Mdot
.20636 .63701 Mdot
.68763 .50444 Mdot
.39566 .3491 Mdot
.44314 .17335 Mdot
.47642 .40099 Mdot
.38006 .36581 Mdot
.66992 .76502 Mdot
.68533 .50699 Mdot
.34292 .62772 Mdot
.5773 .56586 Mdot
.45467 .46404 Mdot
.54797 .61399 Mdot
.36201 .35955 Mdot
.40665 .45131 Mdot
.72661 .69092 Mdot
.58327 .75332 Mdot
.5961 .62667 Mdot
.38409 .46409 Mdot
.38375 .39433 Mdot
.71497 .45529 Mdot
.40879 .42286 Mdot
.56759 .35979 Mdot
.33503 .62284 Mdot
.63645 .49542 Mdot
.58171 .35898 Mdot
.44482 .41404 Mdot
.60631 .35046 Mdot
.6447 .48 Mdot
.56029 .60542 Mdot
.43332 .42763 Mdot
.6242 .3676 Mdot
.60188 .34852 Mdot
.38835 .41303 Mdot
.36745 .6443 Mdot
.42014 .48823 Mdot
.44149 .39153 Mdot
.39538 .37259 Mdot
.39165 .6106 Mdot
.24634 .26572 Mdot
.46309 .39953 Mdot
.66811 .54585 Mdot
.33961 .64174 Mdot
.51766 .68191 Mdot
.63613 .49074 Mdot
.40899 .45207 Mdot
.56938 .6067 Mdot
.5683 .65969 Mdot
.69477 .50711 Mdot
.34132 .5843 Mdot
.65068 .43128 Mdot
.38892 .67133 Mdot
.47919 .4322 Mdot
.46611 .37389 Mdot
.49069 .16792 Mdot
.29854 .76628 Mdot
.34693 .58864 Mdot
.69212 .52208 Mdot
.57971 .53449 Mdot
.58062 .64703 Mdot
.70579 .47775 Mdot
.33064 .60177 Mdot
.33117 .61175 Mdot
.3777 .63506 Mdot
.61257 .34587 Mdot
.63825 .42624 Mdot
.40882 .60639 Mdot
.40484 .62635 Mdot
.40166 .38918 Mdot
.38204 .39764 Mdot
.50532 .33832 Mdot
.5523 .28768 Mdot
.58216 .37247 Mdot
.65558 .48823 Mdot
.87257 .55243 Mdot
.59541 .65622 Mdot
.28655 .40477 Mdot
.37196 .38138 Mdot
.56177 .91739 Mdot
.46901 .41198 Mdot
.4115 .42262 Mdot
.39834 .62651 Mdot
.629 .35469 Mdot
.57174 .35269 Mdot
.34585 .60951 Mdot
.33496 .64875 Mdot
.56652 .3576 Mdot
.18782 .56448 Mdot
.23612 .67764 Mdot
.51945 .58636 Mdot
.36449 .60109 Mdot
.33307 .50985 Mdot
.54493 .61286 Mdot
.38796 .66177 Mdot
.58405 .66713 Mdot
.66538 .52208 Mdot
.63034 .49056 Mdot
.53938 .65315 Mdot
.40306 .394 Mdot
.66146 .46877 Mdot
.47022 .43992 Mdot
.21401 .60961 Mdot
.27699 .59979 Mdot
.7623 .5881 Mdot
.40582 .46033 Mdot
.77813 .46774 Mdot
.70948 .56301 Mdot
.45288 .40578 Mdot
.39337 .7658 Mdot
.6055 .34629 Mdot
.40534 .63912 Mdot
.5853 .61724 Mdot
.51123 .85211 Mdot
.42732 .44066 Mdot
.35957 .60723 Mdot
.56749 .62384 Mdot
.38254 .25219 Mdot
.46266 .65248 Mdot
.42951 .43395 Mdot
.6975 .8105 Mdot
.36788 .55543 Mdot
.63737 .49274 Mdot
.57667 .17945 Mdot
.39109 .57804 Mdot
.60873 .39545 Mdot
.66857 .6801 Mdot
.20383 .37764 Mdot
.34975 .63049 Mdot
.71156 .49189 Mdot
.34139 .60999 Mdot
.57364 .36703 Mdot
.41748 .60224 Mdot
.6583 .52797 Mdot
.42558 .39274 Mdot
.65969 .49246 Mdot
.58879 .37522 Mdot
.71603 .34342 Mdot
.5827 .61414 Mdot
.67165 .45789 Mdot
.56965 .64563 Mdot
.5533 .24064 Mdot
.6758 .72549 Mdot
.56138 .61564 Mdot
.36515 .2429 Mdot
.38565 .3674 Mdot
.40388 .59065 Mdot
.67071 .47698 Mdot
.66275 .67505 Mdot
.53392 .56339 Mdot
.37851 .59827 Mdot
.64783 .49147 Mdot
.36592 .31581 Mdot
.45808 .18721 Mdot
.4812 .36076 Mdot
.5717 .2541 Mdot
.3625 .59825 Mdot
.70849 .4806 Mdot
.8017 .46756 Mdot
.38316 .58183 Mdot
.67596 .47999 Mdot
.58456 .64859 Mdot
.55215 .651 Mdot
.45679 .43232 Mdot
.60264 .67106 Mdot
.65385 .48059 Mdot
.73375 .54945 Mdot
.3596 .65138 Mdot
.39259 .2527 Mdot
.62243 .36192 Mdot
.66368 .51104 Mdot
.45322 .36636 Mdot
.35636 .66881 Mdot
.64674 .705 Mdot
.40314 .51966 Mdot
.85903 .56851 Mdot
.65941 .48629 Mdot
.3356 .62911 Mdot
.36446 .60786 Mdot
.41929 .3419 Mdot
.57573 .55019 Mdot
.64459 .43153 Mdot
.46625 .19708 Mdot
.4281 .23304 Mdot
.63187 .54283 Mdot
.61302 .53408 Mdot
.41087 .3474 Mdot
.3943 .42685 Mdot
.58302 .64471 Mdot
.42038 .39048 Mdot
.39788 .63428 Mdot
.45292 .43879 Mdot
.5543 .65813 Mdot
.67951 .50139 Mdot
.43321 .42173 Mdot
.59519 .37261 Mdot
.58139 .60778 Mdot
.55403 .67 Mdot
.66617 .50452 Mdot
.39407 .62002 Mdot
.5487 .34545 Mdot
.65677 .50174 Mdot
.39611 .41916 Mdot
.61098 .57916 Mdot
.41701 .35827 Mdot
.18873 .53939 Mdot
.38896 .58532 Mdot
.63683 .51959 Mdot
.3459 .64989 Mdot
.57356 .64201 Mdot
.67409 .69422 Mdot
.40867 .40629 Mdot
.67843 .48226 Mdot
.64472 .44201 Mdot
.20596 .58698 Mdot
.32508 .60514 Mdot
.6328 .59509 Mdot
.37118 .65465 Mdot
.6275 .53317 Mdot
.30822 .2983 Mdot
.59145 .33975 Mdot
.67781 .52206 Mdot
.28817 .73803 Mdot
.66963 .49128 Mdot
.42711 .38465 Mdot
.44083 .37913 Mdot
.63875 .48395 Mdot
.60768 .33484 Mdot
.82635 .52149 Mdot
.72829 .52494 Mdot
.34579 .63009 Mdot
.2374 .37232 Mdot
.82087 .64354 Mdot
.57998 .68138 Mdot
.5857 .63474 Mdot
.4501 .46731 Mdot
.45908 .37787 Mdot
.58627 .66311 Mdot
.53543 .61492 Mdot
.60925 .37587 Mdot
.68575 .51939 Mdot
.41197 .57851 Mdot
.56152 .60184 Mdot
.50616 .42389 Mdot
.63256 .31068 Mdot
.42253 .33835 Mdot
.33427 .36375 Mdot
.39143 .45383 Mdot
.43191 .22499 Mdot
.5467 .65734 Mdot
.44236 .37327 Mdot
.43059 .33633 Mdot
.56604 .60705 Mdot
.57111 .36394 Mdot
.57634 .74584 Mdot
.64847 .51565 Mdot
.13161 .49046 Mdot
.44764 .37114 Mdot
.43166 .38546 Mdot
.53414 .65009 Mdot
.67044 .42394 Mdot
.39004 .62167 Mdot
.38854 .58336 Mdot
.67518 .46527 Mdot
.49892 .57783 Mdot
.42666 .44711 Mdot
.4534 .39813 Mdot
.6427 .51276 Mdot
.66537 .45686 Mdot
.73982 .57141 Mdot
.41243 .36728 Mdot
.57019 .62538 Mdot
.57952 .50452 Mdot
.54963 .65842 Mdot
.43511 .35932 Mdot
.42756 .38152 Mdot
.42973 .45068 Mdot
.44715 .36288 Mdot
.55453 .67096 Mdot
.43854 .37106 Mdot
.49745 .42842 Mdot
.38407 .63526 Mdot
.40828 .44597 Mdot
.42156 .22913 Mdot
.41219 .38713 Mdot
.5816 .36912 Mdot
.47958 .47698 Mdot
.43046 .4377 Mdot
.41697 .45175 Mdot
.72474 .52808 Mdot
.42129 .40223 Mdot
.59323 .66101 Mdot
.37857 .60642 Mdot
.57712 .648 Mdot
.54414 .66206 Mdot
.69055 .48061 Mdot
.58263 .37551 Mdot
.3681 .41906 Mdot
.61659 .36327 Mdot
.36377 .42153 Mdot
.38673 .36868 Mdot
.69396 .67269 Mdot
.78047 .32894 Mdot
.76023 .37782 Mdot
.40769 .40627 Mdot
.68452 .49341 Mdot
.63499 .50192 Mdot
.43146 .55733 Mdot
.4748 .35612 Mdot
.58528 .66263 Mdot
.57232 .65753 Mdot
.51892 .30413 Mdot
.7194 .69592 Mdot
.57816 .36812 Mdot
.55364 .44685 Mdot
.4713 .43962 Mdot
.40552 .36517 Mdot
.4694 .38628 Mdot
.69773 .48997 Mdot
.59928 .54979 Mdot
.6807 .51868 Mdot
.59262 .71355 Mdot
.55652 .66065 Mdot
.42246 .44338 Mdot
.27969 .65609 Mdot
.37582 .58232 Mdot
.37909 .60706 Mdot
.57066 .66684 Mdot
.6985 .45895 Mdot
.53092 .3564 Mdot
.31628 .2036 Mdot
.38386 .55967 Mdot
.62647 .34537 Mdot
.4536 .41197 Mdot
.67568 .49993 Mdot
.34631 .59361 Mdot
.58438 .32954 Mdot
.38957 .37058 Mdot
.63737 .43049 Mdot
.40504 .40657 Mdot
.44848 .31406 Mdot
.36446 .64176 Mdot
.20357 .64294 Mdot
.34093 .5888 Mdot
.584 .61016 Mdot
.57041 .61218 Mdot
.43521 .3792 Mdot
.51726 .16933 Mdot
.39882 .58537 Mdot
.58424 .69984 Mdot
.60156 .38261 Mdot
.63862 .65886 Mdot
.56399 .35465 Mdot
.63717 .50653 Mdot
.59125 .33647 Mdot
.64695 .52899 Mdot
.55291 .29839 Mdot
.35015 .56977 Mdot
.58208 .35254 Mdot
.71833 .5132 Mdot
.47823 .36038 Mdot
.56484 .33533 Mdot
.41284 .47515 Mdot
.20445 .45136 Mdot
.64333 .50853 Mdot
.61394 .34256 Mdot
.38526 .38191 Mdot
.40386 .81359 Mdot
.57338 .6196 Mdot
.59073 .65728 Mdot
.48109 .42246 Mdot
.69261 .51421 Mdot
.32638 .62659 Mdot
.38232 .72571 Mdot
.50791 .62483 Mdot
.45093 .38679 Mdot
.45712 .43587 Mdot
.38286 .65494 Mdot
.31017 .6162 Mdot
.42917 .37807 Mdot
.31224 .36405 Mdot
.42556 .36768 Mdot
.58498 .6512 Mdot
.36286 .57963 Mdot
.37061 .607 Mdot
.64771 .4859 Mdot
.40093 .60929 Mdot
.41226 .65453 Mdot
.61653 .59704 Mdot
.43647 .47553 Mdot
.57053 .63498 Mdot
.61881 .62117 Mdot
.59063 .71489 Mdot
.32071 .76052 Mdot
.37526 .65902 Mdot
.42666 .45431 Mdot
.35405 .65076 Mdot
.60213 .36174 Mdot
.38372 .61811 Mdot
.33079 .62586 Mdot
.44578 .40027 Mdot
.42678 .42857 Mdot
.68307 .50616 Mdot
.58036 .55029 Mdot
.38182 .64019 Mdot
.44672 .38049 Mdot
.47496 .41519 Mdot
.47544 .42198 Mdot
.4984 .50689 Mdot
.34557 .59074 Mdot
.27521 .37959 Mdot
.41981 .2805 Mdot
.38335 .63882 Mdot
.56837 .83483 Mdot
.66355 .68625 Mdot
.66794 .4519 Mdot
.60626 .64784 Mdot
.41096 .36735 Mdot
.6349 .4899 Mdot
.42893 .42565 Mdot
.33396 .3641 Mdot
.42914 .40568 Mdot
.56518 .34797 Mdot
.43529 .47153 Mdot
.62481 .52115 Mdot
.65836 .49837 Mdot
.45842 .39418 Mdot
.43258 .4181 Mdot
.73383 .36032 Mdot
.34016 .65321 Mdot
.38775 .62477 Mdot
.69395 .4317 Mdot
.59063 .35309 Mdot
.55303 .61056 Mdot
.40778 .43163 Mdot
.68734 .477 Mdot
.65827 .49468 Mdot
.38006 .57584 Mdot
.64765 .50217 Mdot
.53546 .63689 Mdot
.40896 .41019 Mdot
.58966 .65947 Mdot
.6158 .34904 Mdot
.33958 .6062 Mdot
.42357 .44037 Mdot
.40184 .38846 Mdot
.34592 .63822 Mdot
.37041 .39473 Mdot
.5793 .33431 Mdot
.66759 .4901 Mdot
.35509 .63168 Mdot
.5576 .64728 Mdot
.63868 .51835 Mdot
.39407 .38178 Mdot
.86644 .5562 Mdot
.42201 .38262 Mdot
.40186 .37359 Mdot
.26999 .73318 Mdot
.43212 .47277 Mdot
.66433 .47916 Mdot
.4004 .63757 Mdot
.45459 .45205 Mdot
.47123 .22856 Mdot
.26074 .26292 Mdot
.68645 .51258 Mdot
.45513 .41596 Mdot
.33152 .78469 Mdot
.45883 .4059 Mdot
.37509 .2225 Mdot
.66068 .31333 Mdot
.46663 .58215 Mdot
.48259 .4352 Mdot
.539 .64083 Mdot
.6842 .50448 Mdot
.63894 .5136 Mdot
.25986 .36149 Mdot
.44869 .39882 Mdot
.48694 .33497 Mdot
.37519 .39742 Mdot
.55359 .6543 Mdot
.49752 .30728 Mdot
.65769 .48931 Mdot
.80436 .4164 Mdot
.3939 .4106 Mdot
.34235 .59292 Mdot
.69732 .45179 Mdot
.6573 .69311 Mdot
.39336 .37756 Mdot
.61532 .36196 Mdot
.59371 .61219 Mdot
.44751 .46263 Mdot
.56521 .63524 Mdot
.40145 .36449 Mdot
.51054 .39774 Mdot
.62665 .20288 Mdot
.37211 .64124 Mdot
.58634 .64043 Mdot
.642 .57595 Mdot
.37835 .4495 Mdot
.35265 .63179 Mdot
.38379 .60344 Mdot
.61005 .37394 Mdot
.54197 .52771 Mdot
.48006 .69909 Mdot
.32337 .55487 Mdot
.25551 .3557 Mdot
.69658 .45326 Mdot
.66595 .59281 Mdot
.38908 .39287 Mdot
.77278 .61774 Mdot
.60011 .64122 Mdot
.43 .38791 Mdot
.20915 .46576 Mdot
.34538 .59842 Mdot
.41344 .3749 Mdot
.56858 .35803 Mdot
.78838 .5601 Mdot
.78497 .5898 Mdot
.58401 .79815 Mdot
.67366 .51483 Mdot
.35374 .3676 Mdot
.35916 .34297 Mdot
.68885 .46879 Mdot
.37129 .42109 Mdot
.66901 .48086 Mdot
.17964 .45914 Mdot
.58925 .33067 Mdot
.33857 .60357 Mdot
.66202 .68888 Mdot
.38907 .44683 Mdot
.47879 .39729 Mdot
.5847 .32656 Mdot
.39012 .42948 Mdot
.70849 .25921 Mdot
.74587 .60656 Mdot
.66009 .46608 Mdot
.37672 .63668 Mdot
.39899 .45276 Mdot
.55273 .49742 Mdot
.44636 .39256 Mdot
.29026 .55153 Mdot
.41531 .45246 Mdot
.4768 .68092 Mdot
.35753 .64421 Mdot
.56773 .63756 Mdot
.35519 .40089 Mdot
.42249 .41069 Mdot
.58814 .45006 Mdot
.4791 .44229 Mdot
.46051 .38955 Mdot
.32449 .61818 Mdot
.36171 .58176 Mdot
.36871 .62525 Mdot
.6398 .53547 Mdot
.72542 .68814 Mdot
.57687 .6322 Mdot
.36736 .3602 Mdot
.55723 .60241 Mdot
.38174 .50872 Mdot
.61149 .33233 Mdot
.40977 .80475 Mdot
.39688 .44083 Mdot
.36521 .61909 Mdot
.49503 .77333 Mdot
.3786 .64572 Mdot
.55848 .47123 Mdot
.55038 .63588 Mdot
.3516 .59156 Mdot
.4153 .41744 Mdot
.59521 .5596 Mdot
.49327 .82282 Mdot
.57143 .65232 Mdot
.36428 .40885 Mdot
.63962 .47383 Mdot
.71537 .67591 Mdot
.86786 .57792 Mdot
.58164 .6219 Mdot
.63774 .57522 Mdot
.45153 .40011 Mdot
.38483 .58543 Mdot
.53729 .64025 Mdot
.56239 .61824 Mdot
.64618 .4991 Mdot
.42642 .43087 Mdot
.42494 .43472 Mdot
.62666 .5249 Mdot
.56864 .65796 Mdot
.4734 .37328 Mdot
.46949 .39736 Mdot
.3103 .79472 Mdot
.37426 .2934 Mdot
.14797 .39335 Mdot
.40124 .66647 Mdot
.20795 .49072 Mdot
.36736 .71358 Mdot
.33373 .62622 Mdot
.43198 .43723 Mdot
.40215 .46228 Mdot
.65363 .48177 Mdot
.41613 .39576 Mdot
.69429 .51877 Mdot
.58113 .62826 Mdot
.5618 .83297 Mdot
.54148 .74617 Mdot
.186 .43369 Mdot
.41867 .39645 Mdot
.566 .72121 Mdot
.59027 .36409 Mdot
.54322 .6042 Mdot
.36046 .62837 Mdot
.40933 .35679 Mdot
.74088 .36581 Mdot
.67841 .52118 Mdot
.38386 .59365 Mdot
.78719 .45732 Mdot
.76863 .45724 Mdot
.43356 .35869 Mdot
.634 .52971 Mdot
.43061 .77001 Mdot
.31272 .36936 Mdot
.53173 .6718 Mdot
.56446 .35096 Mdot
.67534 .52019 Mdot
.55889 .66473 Mdot
.30764 .67951 Mdot
.35989 .58789 Mdot
.40678 .58147 Mdot
.70889 .31719 Mdot
.69474 .47083 Mdot
.5831 .36387 Mdot
.71672 .69583 Mdot
.77774 .62803 Mdot
.56567 .34774 Mdot
.62931 .49841 Mdot
.35524 .5853 Mdot
.35166 .6175 Mdot
.37752 .60578 Mdot
.80724 .43104 Mdot
.34413 .58317 Mdot
.28452 .44167 Mdot
.47756 .40495 Mdot
.50903 .36776 Mdot
.45688 .41376 Mdot
.57835 .66927 Mdot
.35801 .63992 Mdot
.48736 .60411 Mdot
.37632 .3583 Mdot
.56238 .81453 Mdot
.45326 .39327 Mdot
.5252 .65115 Mdot
.41023 .37184 Mdot
.30281 .4492 Mdot
.34743 .649 Mdot
.4106 .40006 Mdot
.57137 .6764 Mdot
.59957 .35178 Mdot
.42021 .62731 Mdot
.42853 .43665 Mdot
.42768 .72645 Mdot
.42715 .47351 Mdot
.17631 .53983 Mdot
.40099 .25907 Mdot
.62621 .345 Mdot
.33434 .43428 Mdot
.70665 .48726 Mdot
.50841 .36309 Mdot
.41158 .32395 Mdot
.56933 .65182 Mdot
.6391 .74446 Mdot
.66449 .51675 Mdot
.55085 .31248 Mdot
.37511 .34599 Mdot
.5772 .37212 Mdot
.31819 .61266 Mdot
.56554 .6737 Mdot
.39461 .35617 Mdot
.39454 .34544 Mdot
.18142 .47381 Mdot
.45286 .33482 Mdot
.44897 .44214 Mdot
.60324 .32906 Mdot
.26235 .40257 Mdot
.40879 .38655 Mdot
.55591 .47173 Mdot
.40907 .58576 Mdot
.48594 .40885 Mdot
.28128 .37296 Mdot
.44758 .38249 Mdot
.38477 .59021 Mdot
.35984 .56776 Mdot
.4987 .75203 Mdot
.60063 .38157 Mdot
.41335 .45177 Mdot
.33181 .27167 Mdot
.39312 .41625 Mdot
.56804 .62654 Mdot
.45281 .37102 Mdot
.66588 .52516 Mdot
.80053 .43043 Mdot
.65413 .47527 Mdot
.44436 .43296 Mdot
.37281 .6033 Mdot
.53704 .6528 Mdot
.73966 .3431 Mdot
.67136 .35095 Mdot
.27809 .43204 Mdot
.18567 .39052 Mdot
.60908 .33697 Mdot
.55943 .35607 Mdot
.55856 .67407 Mdot
.40972 .39891 Mdot
.32091 .2633 Mdot
.466 .46213 Mdot
.41012 .37817 Mdot
.43013 .40617 Mdot
.68608 .71208 Mdot
.58211 .64114 Mdot
.64932 .50994 Mdot
.42731 .37909 Mdot
.44238 .37524 Mdot
.33993 .63641 Mdot
.59984 .34968 Mdot
.63538 .49475 Mdot
.59097 .34605 Mdot
.67936 .49324 Mdot
.55567 .83943 Mdot
.35977 .38224 Mdot
.59726 .35344 Mdot
.59617 .62407 Mdot
.39223 .6087 Mdot
.61651 .59396 Mdot
.63764 .50735 Mdot
.65441 .48791 Mdot
.45185 .39067 Mdot
.38775 .59143 Mdot
.39746 .62104 Mdot
.60319 .36205 Mdot
.55838 .61418 Mdot
.43392 .43271 Mdot
.39101 .36412 Mdot
.44807 .5764 Mdot
.69699 .4958 Mdot
.36718 .31832 Mdot
.46902 .75648 Mdot
.4077 .4034 Mdot
.39668 .61493 Mdot
.43585 .41038 Mdot
.28258 .69532 Mdot
.39075 .58998 Mdot
.46416 .39642 Mdot
.80289 .59877 Mdot
.59134 .52269 Mdot
.45609 .71997 Mdot
.44203 .44811 Mdot
.14366 .48669 Mdot
.38476 .40078 Mdot
.33442 .80738 Mdot
.71759 .37805 Mdot
.42606 .44433 Mdot
.39416 .38887 Mdot
.29381 .61003 Mdot
.44698 .41673 Mdot
.62489 .52821 Mdot
.54696 .31192 Mdot
.32849 .62586 Mdot
.41248 .69332 Mdot
.49805 .47805 Mdot
.61167 .37804 Mdot
.67431 .46494 Mdot
.60878 .5264 Mdot
.57129 .34693 Mdot
.36145 .60147 Mdot
.40144 .41937 Mdot
.4891 .5703 Mdot
.64215 .54401 Mdot
.47301 .36547 Mdot
.56197 .62806 Mdot
.69796 .60515 Mdot
.71241 .48143 Mdot
.56172 .64263 Mdot
.38772 .43777 Mdot
.3012 .60404 Mdot
.64508 .27175 Mdot
.2107 .66219 Mdot
.53663 .6564 Mdot
.56353 .6604 Mdot
.81626 .45538 Mdot
.61412 .37835 Mdot
.19846 .43251 Mdot
.46925 .6669 Mdot
.53448 .63311 Mdot
.34674 .28082 Mdot
.68762 .51484 Mdot
.43097 .71915 Mdot
.4053 .63934 Mdot
.4662 .37501 Mdot
.41705 .4151 Mdot
.56063 .61222 Mdot
.30747 .6838 Mdot
.60958 .19429 Mdot
.56867 .6468 Mdot
.49795 .43575 Mdot
.48893 .527 Mdot
.66337 .68372 Mdot
.69474 .4942 Mdot
.60197 .38028 Mdot
.61995 .38985 Mdot
.33855 .62403 Mdot
.59802 .37835 Mdot
.78342 .5803 Mdot
.39314 .43525 Mdot
.56344 .65301 Mdot
.64509 .69631 Mdot
.55468 .64612 Mdot
.57159 .34938 Mdot
.62795 .34721 Mdot
.38463 .63446 Mdot
.3867 .62509 Mdot
.21401 .50614 Mdot
.48908 .28592 Mdot
.4591 .40057 Mdot
.51688 .80451 Mdot
.36229 .65123 Mdot
.32712 .39465 Mdot
.56175 .36066 Mdot
.5956 .35135 Mdot
.41513 .29799 Mdot
.41622 .43853 Mdot
.34608 .25055 Mdot
.41355 .4356 Mdot
.49649 .30133 Mdot
.37617 .44176 Mdot
.6468 .50038 Mdot
.41599 .44148 Mdot
.55734 .33062 Mdot
.4141 .34768 Mdot
.45604 .37887 Mdot
.69572 .51051 Mdot
.44983 .46008 Mdot
.66355 .5255 Mdot
.44932 .43124 Mdot
.58371 .38382 Mdot
.68579 .47323 Mdot
.50644 .23437 Mdot
.66626 .55142 Mdot
.63618 .47511 Mdot
.59979 .37475 Mdot
.62103 .36169 Mdot
.49418 .21251 Mdot
.35896 .62824 Mdot
.39782 .65976 Mdot
.4119 .39517 Mdot
.70116 .50503 Mdot
.58422 .64033 Mdot
.43689 .37109 Mdot
.40554 .46766 Mdot
.45737 .43909 Mdot
.33674 .61498 Mdot
.65472 .43294 Mdot
.60205 .35533 Mdot
.63867 .53618 Mdot
.61024 .43129 Mdot
.66872 .53502 Mdot
.4193 .33354 Mdot
.35714 .43125 Mdot
.20752 .53989 Mdot
.56348 .77695 Mdot
.83234 .49752 Mdot
.36654 .58662 Mdot
.67229 .45868 Mdot
.62082 .36712 Mdot
.37826 .48315 Mdot
.35999 .6222 Mdot
.65939 .5276 Mdot
.40491 .40798 Mdot
.36384 .41044 Mdot
.56804 .59095 Mdot
.50062 .35308 Mdot
.43424 .24142 Mdot
.67396 .53111 Mdot
.71139 .49295 Mdot
.7754 .62778 Mdot
.54234 .31662 Mdot
.51298 .57137 Mdot
.43547 .3959 Mdot
.61581 .35993 Mdot
.34646 .59348 Mdot
.67194 .28686 Mdot
.58254 .61719 Mdot
.57864 .55087 Mdot
.41748 .39741 Mdot
.48078 .62792 Mdot
.37461 .603 Mdot
.57206 .36301 Mdot
.56052 .61156 Mdot
.63009 .34256 Mdot
.69484 .4759 Mdot
.26299 .28666 Mdot
.39103 .4212 Mdot
.4615 .40226 Mdot
.58665 .6162 Mdot
.34297 .60835 Mdot
.60027 .32616 Mdot
.19095 .56244 Mdot
.6427 .48051 Mdot
.33286 .2492 Mdot
.40257 .61769 Mdot
.30918 .48261 Mdot
.6413 .5377 Mdot
.56995 .66658 Mdot
.51277 .21955 Mdot
.55301 .65769 Mdot
.44077 .43911 Mdot
.36862 .61279 Mdot
.57363 .62112 Mdot
.57092 .47628 Mdot
.35966 .79845 Mdot
.32553 .50284 Mdot
.40371 .43662 Mdot
.4534 .82492 Mdot
.23039 .64296 Mdot
.3518 .55641 Mdot
.57053 .6066 Mdot
.44251 .39038 Mdot
.3762 .42963 Mdot
.39573 .41234 Mdot
.54967 .63091 Mdot
.68689 .65946 Mdot
.64171 .50581 Mdot
.45586 .4051 Mdot
.61192 .37393 Mdot
.65926 .52426 Mdot
.66354 .69462 Mdot
.66013 .48153 Mdot
.35315 .65824 Mdot
.45627 .37382 Mdot
.61533 .6415 Mdot
.43509 .84606 Mdot
.57584 .64933 Mdot
.63507 .47643 Mdot
.43722 .36526 Mdot
.63866 .72969 Mdot
.36713 .62407 Mdot
.64539 .47783 Mdot
.43214 .38601 Mdot
.66095 .65583 Mdot
.73072 .3547 Mdot
.65944 .48298 Mdot
.35132 .62253 Mdot
.32801 .726 Mdot
.4183 .39197 Mdot
.38444 .40655 Mdot
.34643 .60595 Mdot
.49924 .47017 Mdot
.79405 .46 Mdot
.43351 .41497 Mdot
.5668 .63875 Mdot
.3492 .20506 Mdot
.46627 .43397 Mdot
.43458 .29359 Mdot
.68129 .51146 Mdot
.45465 .74133 Mdot
.36016 .32143 Mdot
.33559 .42831 Mdot
.29169 .67891 Mdot
.51556 .4795 Mdot
.53872 .83396 Mdot
.70408 .50487 Mdot
.74286 .42499 Mdot
.53369 .84011 Mdot
.55428 .67667 Mdot
.32282 .6721 Mdot
.43544 .59599 Mdot
.79901 .39233 Mdot
.34749 .7328 Mdot
.71932 .43607 Mdot
.75322 .37696 Mdot
.48012 .55318 Mdot
.67475 .48891 Mdot
.53737 .35274 Mdot
.43146 .42991 Mdot
.2266 .63956 Mdot
.30362 .37887 Mdot
.57537 .17218 Mdot
.44126 .8219 Mdot
.33787 .27126 Mdot
.43276 .80823 Mdot
.31195 .75627 Mdot
.198 .52001 Mdot
.54544 .7807 Mdot
.35985 .21579 Mdot
.79873 .59468 Mdot
.26528 .31547 Mdot
.34896 .42839 Mdot
.56482 .43619 Mdot
.16294 .47427 Mdot
.2904 .47698 Mdot
.50401 .17634 Mdot
.64831 .48136 Mdot
.40175 .63497 Mdot
.43957 .60089 Mdot
.32112 .627 Mdot
.54656 .58218 Mdot
.30679 .71776 Mdot
.31463 .78319 Mdot
.29802 .43406 Mdot
.13883 .49656 Mdot
.22483 .43641 Mdot
.79432 .30524 Mdot
.74147 .4987 Mdot
.40145 .58353 Mdot
.6117 .41002 Mdot
.76591 .64577 Mdot
.52588 .72902 Mdot
.41034 .66284 Mdot
.70677 .67556 Mdot
.52446 .25838 Mdot
.36054 .60641 Mdot
.32518 .35207 Mdot
.7139 .54917 Mdot
.55979 .74069 Mdot
.64022 .29558 Mdot
.31809 .74761 Mdot
.51314 .55669 Mdot
.42145 .71369 Mdot
.68784 .59121 Mdot
.86383 .56047 Mdot
.42047 .27159 Mdot
.25839 .653 Mdot
.58081 .58204 Mdot
.31979 .70918 Mdot
.76827 .34595 Mdot
.51439 .28598 Mdot
.76972 .64123 Mdot
.71175 .73219 Mdot
.20881 .62766 Mdot
.736 .73018 Mdot
.40132 .6573 Mdot
.45018 .44264 Mdot
.26061 .62053 Mdot
.31688 .30425 Mdot
.5737 .38401 Mdot
.60564 .7868 Mdot
.61638 .34629 Mdot
.33902 .65838 Mdot
.79536 .43088 Mdot
.29111 .43919 Mdot
.34477 .24544 Mdot
.5977 .32401 Mdot
.40703 .46033 Mdot
.50731 .11309 Mdot
.52962 .83162 Mdot
.49295 .74714 Mdot
.3122 .79717 Mdot
.49214 .63633 Mdot
.38072 .25519 Mdot
.56952 .6212 Mdot
.49435 .84985 Mdot
.35663 .6154 Mdot
.64561 .82233 Mdot
.4125 .82959 Mdot
.60292 .20291 Mdot
.25596 .22165 Mdot
.76534 .6129 Mdot
.47111 .5961 Mdot
.49091 .49325 Mdot
.47446 .24263 Mdot
.66145 .23568 Mdot
.55837 .18719 Mdot
.63614 .72329 Mdot
.17621 .42471 Mdot
.49749 .84497 Mdot
.31698 .29317 Mdot
.26284 .29726 Mdot
.7931 .37962 Mdot
.54406 .47001 Mdot
.33103 .66113 Mdot
.6709 .56145 Mdot
.38875 .77376 Mdot
.65467 .78225 Mdot
.41605 .2857 Mdot
.29586 .21202 Mdot
.55975 .33151 Mdot
.71094 .38127 Mdot
.25712 .695 Mdot
.53717 .2449 Mdot
.36073 .28562 Mdot
.80803 .48915 Mdot
.45209 .34879 Mdot
.8138 .51935 Mdot
.45721 .79905 Mdot
.62532 .58275 Mdot
.80134 .57973 Mdot
.40794 .75034 Mdot
.17976 .50649 Mdot
.27355 .5914 Mdot
.7612 .65746 Mdot
.33125 .64139 Mdot
.49993 .27142 Mdot
.38329 .27156 Mdot
.30304 .78548 Mdot
.63946 .57458 Mdot
.24513 .74187 Mdot
.7836 .438 Mdot
.37287 .44341 Mdot
.40784 .32182 Mdot
.47004 .47099 Mdot
.47589 .27536 Mdot
.47317 .41834 Mdot
.57859 .72309 Mdot
.28834 .76423 Mdot
.21693 .4345 Mdot
.62834 .59502 Mdot
.64124 .74731 Mdot
.21391 .66697 Mdot
.22378 .57258 Mdot
.73846 .37723 Mdot
.4934 .32076 Mdot
.84498 .46081 Mdot
.65832 .51788 Mdot
.31344 .29359 Mdot
.53457 .6704 Mdot
.67811 .30261 Mdot
.33539 .54358 Mdot
.64716 .23744 Mdot
.28732 .76336 Mdot
.78231 .48189 Mdot
.77349 .40642 Mdot
.55538 .23016 Mdot
.32531 .24411 Mdot
.63298 .76018 Mdot
.35906 .36372 Mdot
.3834 .68886 Mdot
.61522 .33811 Mdot
.23188 .53949 Mdot
.28675 .31523 Mdot
.67661 .39658 Mdot
.4682 .45167 Mdot
.62444 .25344 Mdot
.68376 .43684 Mdot
.5912 .55923 Mdot
.7917 .69419 Mdot
.46103 .34787 Mdot
.72887 .67145 Mdot
.19067 .5984 Mdot
.4528 .25959 Mdot
.25847 .68764 Mdot
.39871 .72482 Mdot
.72392 .73561 Mdot
.38198 .81917 Mdot
.66854 .37026 Mdot
.58168 .81671 Mdot
.29634 .78837 Mdot
.75437 .70335 Mdot
.46361 .33675 Mdot
.59711 .65831 Mdot
.81929 .6943 Mdot
.63376 .5397 Mdot
.68527 .72764 Mdot
.25583 .3556 Mdot
.66708 .64813 Mdot
.42467 .60473 Mdot
.3633 .45349 Mdot
.48649 .557 Mdot
.33153 .57356 Mdot
.46135 .44787 Mdot
.82264 .63392 Mdot
.74288 .70236 Mdot
.78379 .68529 Mdot
.16583 .54736 Mdot
.58138 .82079 Mdot
.45564 .55888 Mdot
.2928 .46429 Mdot
.41814 .54095 Mdot
.43561 .35715 Mdot
.60029 .30203 Mdot
.76536 .60997 Mdot
.64307 .25903 Mdot
.51006 .71646 Mdot
.32489 .63776 Mdot
.55404 .80233 Mdot
.90032 .43308 Mdot
.22525 .45749 Mdot
.28064 .35731 Mdot
.78266 .60258 Mdot
.46993 .28101 Mdot
.41691 .78545 Mdot
.61739 .22288 Mdot
.2775 .74075 Mdot
.41024 .54269 Mdot
.25553 .33906 Mdot
.69582 .42019 Mdot
.42003 .21499 Mdot
.69089 .43325 Mdot
.34392 .78101 Mdot
.44302 .52043 Mdot
.70425 .29503 Mdot
.45271 .6472 Mdot
.60524 .1985 Mdot
.69288 .33978 Mdot
.70488 .60127 Mdot
.29193 .29895 Mdot
.62432 .71277 Mdot
.46057 .28814 Mdot
.50013 .53239 Mdot
.39926 .49486 Mdot
.51374 .48083 Mdot
.44708 .28444 Mdot
.43769 .21333 Mdot
.63973 .78724 Mdot
.30515 .80829 Mdot
.85214 .54811 Mdot
.13824 .51164 Mdot
.4547 .79353 Mdot
.46811 .3741 Mdot
.24481 .69829 Mdot
.74268 .73447 Mdot
.38494 .82679 Mdot
.75822 .52629 Mdot
.59358 .5099 Mdot
.5613 .59975 Mdot
.84265 .56573 Mdot
.70942 .44155 Mdot
.28858 .72707 Mdot
.82135 .52187 Mdot
.60797 .63687 Mdot
.77184 .31802 Mdot
.73615 .70223 Mdot
.34795 .52819 Mdot
.44877 .32065 Mdot
.45396 .355 Mdot
.30513 .43625 Mdot
.3552 .6557 Mdot
.67337 .58827 Mdot
.49876 .28325 Mdot
.66257 .50755 Mdot
.62773 .29972 Mdot
.39362 .67795 Mdot
.43704 .47094 Mdot
.50733 .47512 Mdot
.40137 .63791 Mdot
.56065 .77702 Mdot
.62459 .66552 Mdot
.6234 .81344 Mdot
.76181 .59822 Mdot
.48355 .43623 Mdot
.44561 .26293 Mdot
.75898 .48602 Mdot
.80845 .47594 Mdot
.53194 .66024 Mdot
.4191 .81739 Mdot
.56583 .45557 Mdot
.49776 .27313 Mdot
.30536 .42559 Mdot
.18552 .51677 Mdot
.35831 .43662 Mdot
.48343 .76378 Mdot
.2751 .54634 Mdot
.58277 .54885 Mdot
.33184 .65978 Mdot
.32741 .66054 Mdot
.18521 .64678 Mdot
.7892 .54605 Mdot
.68297 .59938 Mdot
.40604 .8122 Mdot
.54465 .64507 Mdot
.38092 .64206 Mdot
.58377 .30706 Mdot
.17862 .52105 Mdot
.28919 .52209 Mdot
.73199 .35555 Mdot
.72625 .6357 Mdot
.68994 .39093 Mdot
.42368 .81106 Mdot
.44795 .81867 Mdot
.56235 .16303 Mdot
.3245 .60443 Mdot
.19774 .55583 Mdot
.20178 .40746 Mdot
.38044 .65271 Mdot
.41856 .57207 Mdot
.5405 .72408 Mdot
.63678 .79761 Mdot
.60121 .67866 Mdot
.16946 .43124 Mdot
.44852 .22336 Mdot
.67159 .66118 Mdot
.74449 .34893 Mdot
.29559 .28799 Mdot
.39316 .8066 Mdot
.31319 .37779 Mdot
.35784 .53692 Mdot
.40015 .47466 Mdot
.50541 .3537 Mdot
.86719 .5088 Mdot
.67247 .54656 Mdot
.30945 .47779 Mdot
.3962 .74229 Mdot
.39645 .4239 Mdot
.85788 .56899 Mdot
.21193 .60947 Mdot
.81951 .46229 Mdot
.58811 .60674 Mdot
.37856 .40001 Mdot
.42515 .34953 Mdot
.47652 .31694 Mdot
.47693 .74796 Mdot
.69374 .73392 Mdot
.29118 .29145 Mdot
.40901 .7672 Mdot
.30381 .38258 Mdot
.72584 .67439 Mdot
.30978 .73553 Mdot
.24153 .65459 Mdot
.55337 .52263 Mdot
.76773 .59836 Mdot
.53341 .22983 Mdot
.14416 .51006 Mdot
.58557 .42679 Mdot
.45273 .57298 Mdot
.51889 .70074 Mdot
.43812 .74657 Mdot
.70543 .30687 Mdot
.40261 .36146 Mdot
.78731 .4575 Mdot
.31079 .75223 Mdot
.47667 .16569 Mdot
.7061 .27441 Mdot
.85145 .58459 Mdot
.29766 .55709 Mdot
.41989 .73798 Mdot
.30055 .6873 Mdot
.43304 .16132 Mdot
.57305 .42762 Mdot
.5393 .81795 Mdot
.5401 .22812 Mdot
.41475 .81168 Mdot
.58537 .67148 Mdot
.46438 .64761 Mdot
.64554 .74548 Mdot
.61302 .8048 Mdot
.24004 .58699 Mdot
.3394 .77185 Mdot
.47943 .60945 Mdot
.6939 .77566 Mdot
.60883 .73357 Mdot
.47463 .54437 Mdot
.67289 .46061 Mdot
.79161 .49543 Mdot
.43263 .80135 Mdot
.517 .79182 Mdot
.29219 .30376 Mdot
.71051 .5089 Mdot
.55812 .31149 Mdot
.34869 .50503 Mdot
.57025 .26049 Mdot
.43683 .75536 Mdot
.44618 .26251 Mdot
.31859 .77393 Mdot
.59865 .41935 Mdot
.77573 .42651 Mdot
.72314 .67397 Mdot
.24309 .31192 Mdot
.48247 .74551 Mdot
.79265 .53499 Mdot
.25953 .66152 Mdot
.69997 .36156 Mdot
.35598 .26995 Mdot
.36602 .87805 Mdot
.23149 .34961 Mdot
.57783 .76075 Mdot
.65588 .781 Mdot
.25096 .68001 Mdot
.57409 .77005 Mdot
.67308 .24144 Mdot
.37237 .29574 Mdot
.56212 .29766 Mdot
.42855 .40665 Mdot
.78384 .69837 Mdot
.54235 .26628 Mdot
.67048 .77813 Mdot
.23008 .68605 Mdot
.31176 .44997 Mdot
.43755 .47021 Mdot
.655 .53527 Mdot
.68545 .56614 Mdot
.59156 .27112 Mdot
.32537 .56615 Mdot
.34216 .30207 Mdot
.7426 .61538 Mdot
.68986 .469 Mdot
.69557 .43324 Mdot
.38578 .54976 Mdot
.7623 .5745 Mdot
.45989 .75506 Mdot
.63354 .32674 Mdot
.54183 .54756 Mdot
.45068 .28034 Mdot
.34953 .32583 Mdot
.34377 .52915 Mdot
.6552 .24463 Mdot
.53684 .48552 Mdot
.6621 .4786 Mdot
.31093 .56516 Mdot
.18219 .42077 Mdot
.43651 .76817 Mdot
.70521 .74075 Mdot
.79672 .48094 Mdot
.41186 .51562 Mdot
.45065 .2891 Mdot
.64472 .2269 Mdot
.39747 .21099 Mdot
.56929 .78553 Mdot
.35299 .34068 Mdot
.35854 .24934 Mdot
.42024 .66287 Mdot
.5502 .83915 Mdot
.26306 .32034 Mdot
.23527 .37128 Mdot
.71117 .53809 Mdot
.28367 .48452 Mdot
.3248 .46687 Mdot
.50213 .22884 Mdot
.53814 .56231 Mdot
.80606 .32417 Mdot
.41184 .6261 Mdot
.88305 .51287 Mdot
.58869 .64206 Mdot
.80785 .39005 Mdot
.5271 .21779 Mdot
.50047 .52888 Mdot
.52497 .57099 Mdot
.49435 .76309 Mdot
.47819 .68006 Mdot
.15494 .50848 Mdot
.54779 .17334 Mdot
.67006 .53494 Mdot
.2958 .27453 Mdot
.25728 .28535 Mdot
.29942 .59444 Mdot
.42128 .4595 Mdot
.22753 .35174 Mdot
.6934 .5247 Mdot
.64496 .2592 Mdot
.23699 .67689 Mdot
.49253 .78442 Mdot
.5076 .40583 Mdot
.47712 .28138 Mdot
.52956 .81842 Mdot
.3792 .81358 Mdot
.72912 .27955 Mdot
.45754 .79877 Mdot
.59815 .65528 Mdot
.46263 .55067 Mdot
.36086 .77719 Mdot
.40245 .24739 Mdot
.42762 .69827 Mdot
.37483 .27125 Mdot
.86655 .42871 Mdot
.67185 .74364 Mdot
.69274 .73401 Mdot
.39486 .25784 Mdot
.35276 .57649 Mdot
.5907 .73626 Mdot
.36481 .28299 Mdot
.50333 .77969 Mdot
.16564 .4888 Mdot
.37643 .27494 Mdot
.53481 .14568 Mdot
.20102 .45936 Mdot
.62246 .4287 Mdot
.33073 .47126 Mdot
.20601 .46048 Mdot
.60281 .62361 Mdot
.58849 .29247 Mdot
.39555 .74689 Mdot
.58677 .61413 Mdot
.4434 .75766 Mdot
.43318 .72755 Mdot
.2149 .40894 Mdot
.29936 .52183 Mdot
.42327 .77572 Mdot
.28238 .62072 Mdot
.30696 .6621 Mdot
.67464 .28972 Mdot
.67597 .44881 Mdot
.37526 .74084 Mdot
.65178 .46803 Mdot
.33292 .40576 Mdot
.57527 .53785 Mdot
.46858 .48426 Mdot
.84701 .54482 Mdot
.61336 .33841 Mdot
.38985 .57905 Mdot
.81974 .39507 Mdot
.39432 .64163 Mdot
.80845 .6594 Mdot
.63135 .23155 Mdot
.30249 .41696 Mdot
.67509 .36219 Mdot
.65829 .41285 Mdot
.67288 .19927 Mdot
.3847 .53321 Mdot
.71278 .53975 Mdot
.30706 .64414 Mdot
.36778 .577 Mdot
.73634 .64726 Mdot
.69377 .4814 Mdot
.40851 .3047 Mdot
.518 .68667 Mdot
.41637 .52936 Mdot
.33877 .57676 Mdot
.56616 .48792 Mdot
.52158 .31604 Mdot
.62839 .80283 Mdot
.67383 .48183 Mdot
.84791 .41624 Mdot
.38271 .45994 Mdot
.26214 .58033 Mdot
.27099 .73792 Mdot
.75315 .2997 Mdot
.61826 .53064 Mdot
.2738 .25334 Mdot
.36959 .43263 Mdot
.42775 .78151 Mdot
.35479 .60957 Mdot
.2457 .35626 Mdot
.5958 .33798 Mdot
.45984 .25309 Mdot
.55007 .60399 Mdot
.70657 .29807 Mdot
.75627 .57551 Mdot
.34926 .57536 Mdot
.48901 .79529 Mdot
.19315 .528 Mdot
.45351 .67126 Mdot
.65435 .42629 Mdot
.31131 .57495 Mdot
.29478 .51632 Mdot
.34286 .57416 Mdot
.6733 .75385 Mdot
.24742 .34605 Mdot
.52158 .85711 Mdot
.46779 .47116 Mdot
.75612 .4464 Mdot
.50218 .68165 Mdot
.46102 .7654 Mdot
.40908 .31288 Mdot
.28428 .75253 Mdot
.51056 .2793 Mdot
.53537 .70632 Mdot
.4891 .29676 Mdot
.34749 .4431 Mdot
.53035 .54311 Mdot
.70774 .57642 Mdot
.60731 .1782 Mdot
.46779 .32282 Mdot
.76989 .33902 Mdot
.34835 .34721 Mdot
.73941 .65905 Mdot
.39417 .56261 Mdot
.59882 .48885 Mdot
.29268 .48781 Mdot
.64345 .57506 Mdot
.53418 .8444 Mdot
.2809 .74801 Mdot
.58494 .59434 Mdot
.72394 .65957 Mdot
.34185 .71272 Mdot
.45761 .47324 Mdot
.47567 .62032 Mdot
.44628 .44148 Mdot
.40537 .56497 Mdot
.77121 .31222 Mdot
.49421 .77388 Mdot
.36265 .35465 Mdot
.53646 .83573 Mdot
.48416 .8479 Mdot
.68599 .7783 Mdot
.32955 .24814 Mdot
.33267 .6207 Mdot
.77673 .68418 Mdot
.331 .3239 Mdot
.33073 .79273 Mdot
.55768 .78815 Mdot
.19749 .66333 Mdot
.34541 .54628 Mdot
.39192 .73316 Mdot
.56211 .18249 Mdot
.46469 .69538 Mdot
.22446 .64702 Mdot
.47447 .52041 Mdot
.66439 .6102 Mdot
.22329 .65356 Mdot
.55891 .12969 Mdot
.37803 .32318 Mdot
.42382 .72106 Mdot
.44502 .62866 Mdot
.38241 .74394 Mdot
.73199 .38685 Mdot
.45199 .37032 Mdot
.6497 .70348 Mdot
.75815 .37144 Mdot
.43496 .27762 Mdot
.55987 .31093 Mdot
.73002 .38631 Mdot
.6052 .28141 Mdot
.5065 .30646 Mdot
.26539 .31441 Mdot
.33438 .55203 Mdot
.41414 .30707 Mdot
.37118 .44324 Mdot
.40374 .56829 Mdot
.58553 .38015 Mdot
.61593 .47521 Mdot
.45174 .43212 Mdot
.61964 .54501 Mdot
.46147 .67735 Mdot
.84128 .60309 Mdot
.6248 .59769 Mdot
.19355 .57964 Mdot
.40449 .63967 Mdot
.47992 .75365 Mdot
.2766 .65516 Mdot
.79884 .40768 Mdot
.73235 .42111 Mdot
.41589 .2856 Mdot
.50197 .83337 Mdot
.79978 .58264 Mdot
.18439 .47969 Mdot
.80045 .61413 Mdot
.59933 .63405 Mdot
.49721 .37258 Mdot
.45043 .60747 Mdot
.77178 .50355 Mdot
.32119 .64503 Mdot
.39711 .73592 Mdot
.72754 .51248 Mdot
.79672 .55544 Mdot
.19272 .60373 Mdot
.18932 .52018 Mdot
.364 .5115 Mdot
.45902 .82347 Mdot
.68809 .51008 Mdot
.2344 .36203 Mdot
.42165 .69359 Mdot
.74061 .43719 Mdot
.72642 .69111 Mdot
.59816 .82351 Mdot
.49069 .60189 Mdot
.51879 .25096 Mdot
.38849 .41062 Mdot
.27539 .38078 Mdot
.50166 .77012 Mdot
.5276 .39798 Mdot
.73686 .59667 Mdot
.39578 .60697 Mdot
.72634 .58664 Mdot
.56773 .41601 Mdot
.56447 .2932 Mdot
.32367 .58753 Mdot
.31803 .30738 Mdot
.55936 .37201 Mdot
.50939 .66769 Mdot
.46674 .43816 Mdot
.4999 .24993 Mdot
.34503 .24216 Mdot
.49354 .37351 Mdot
.42462 .79297 Mdot
.32317 .55739 Mdot
.17683 .49517 Mdot
.45649 .77697 Mdot
.5787 .78259 Mdot
.47972 .68657 Mdot
.30607 .49558 Mdot
.75723 .50624 Mdot
.45567 .44065 Mdot
.59811 .49707 Mdot
.3929 .63366 Mdot
.30866 .71448 Mdot
.29315 .55447 Mdot
.51012 .23551 Mdot
.51928 .51556 Mdot
.27272 .64423 Mdot
.5154 .50101 Mdot
.25512 .7111 Mdot
.46604 .6966 Mdot
.50316 .28445 Mdot
.57186 .68225 Mdot
.52489 .21943 Mdot
.66529 .24354 Mdot
.44671 .83645 Mdot
.62591 .21707 Mdot
.49023 .57797 Mdot
.77116 .33506 Mdot
.58484 .7496 Mdot
.22843 .67088 Mdot
.5115 .29306 Mdot
.49935 .59457 Mdot
.56016 .3174 Mdot
.58371 .59042 Mdot
.54748 .49534 Mdot
.59452 .46999 Mdot
.36657 .30854 Mdot
.70312 .63177 Mdot
.72976 .53997 Mdot
.37854 .46637 Mdot
.68685 .7183 Mdot
.48431 .83012 Mdot
.25064 .35706 Mdot
.52305 .4816 Mdot
.66387 .3069 Mdot
.56179 .28858 Mdot
.1222 .50864 Mdot
.86597 .55766 Mdot
.38851 .41306 Mdot
.52692 .47383 Mdot
.49444 .26114 Mdot
.65869 .53858 Mdot
.34956 .30736 Mdot
.28855 .65605 Mdot
.57794 .65888 Mdot
.58802 .49145 Mdot
.80048 .54064 Mdot
.50478 .76232 Mdot
.56562 .2497 Mdot
.66469 .71772 Mdot
.83895 .61418 Mdot
.16285 .45956 Mdot
.4743 .76907 Mdot
.13435 .57143 Mdot
.73388 .54884 Mdot
.34502 .67113 Mdot
.25867 .62492 Mdot
.64389 .7874 Mdot
.44227 .25893 Mdot
.70327 .31475 Mdot
.61045 .77036 Mdot
.51314 .28474 Mdot
.34958 .28346 Mdot
.7265 .67038 Mdot
.73086 .58829 Mdot
.49629 .54645 Mdot
.66002 .41335 Mdot
.77156 .65989 Mdot
.30686 .3925 Mdot
.5019 .8249 Mdot
.75915 .36895 Mdot
.50594 .1407 Mdot
.49686 .85064 Mdot
.61095 .30009 Mdot
.73296 .37949 Mdot
.25444 .61835 Mdot
.42765 .23195 Mdot
.33642 .2974 Mdot
.6668 .26811 Mdot
.27928 .5185 Mdot
.64731 .40202 Mdot
.76865 .35668 Mdot
.45868 .28772 Mdot
.20937 .44905 Mdot
.5013 .59146 Mdot
.32901 .541 Mdot
.74644 .62511 Mdot
.40463 .26163 Mdot
.57675 .4683 Mdot
.46082 .23153 Mdot
.30778 .57308 Mdot
.2688 .66573 Mdot
.38989 .71078 Mdot
.59134 .14618 Mdot
.5777 .79185 Mdot
.79606 .4006 Mdot
.47716 .40944 Mdot
.56261 .84365 Mdot
.4037 .70703 Mdot
.60219 .77761 Mdot
.17554 .55191 Mdot
.613 .45442 Mdot
.48625 .65502 Mdot
.45706 .43898 Mdot
.49722 .80788 Mdot
.31286 .4798 Mdot
.20521 .47752 Mdot
.72481 .31882 Mdot
.45686 .26558 Mdot
.74477 .38125 Mdot
.4873 .22278 Mdot
.50056 .40662 Mdot
.40408 .61195 Mdot
.77557 .69682 Mdot
.47952 .59342 Mdot
.3343 .3871 Mdot
.51798 .38106 Mdot
.57332 .18353 Mdot
.18925 .37536 Mdot
.47536 .46575 Mdot
.7897 .60602 Mdot
.3316 .28551 Mdot
.39705 .50513 Mdot
.32963 .35914 Mdot
.14745 .33407 Mdot
.31063 .80548 Mdot
.32832 .61044 Mdot
.28799 .33249 Mdot
.34345 .26187 Mdot
.63603 .79163 Mdot
.69805 .41921 Mdot
.64734 .44968 Mdot
.49945 .18209 Mdot
.40481 .23379 Mdot
.38188 .45382 Mdot
.18429 .58495 Mdot
.42903 .83094 Mdot
.737 .32802 Mdot
.52583 .83894 Mdot
.35683 .34891 Mdot
.36733 .3576 Mdot
.12439 .40802 Mdot
.36933 .78548 Mdot
.45102 .34949 Mdot
.57498 .18115 Mdot
.33373 .66311 Mdot
.42644 .42274 Mdot
.67458 .71222 Mdot
.28783 .29994 Mdot
.45857 .28963 Mdot
.61468 .80413 Mdot
.31936 .61048 Mdot
.63513 .56871 Mdot
.57486 .6636 Mdot
.52978 .56738 Mdot
.36051 .40295 Mdot
.55392 .62504 Mdot
.40867 .50383 Mdot
.3762 .7325 Mdot
.60235 .61725 Mdot
.2724 .29111 Mdot
.22938 .71866 Mdot
.30957 .54402 Mdot
.53479 .60273 Mdot
.4445 .48277 Mdot
.20057 .46629 Mdot
.5956 .27444 Mdot
.43044 .54996 Mdot
.21659 .65399 Mdot
.47676 .89694 Mdot
.67303 .61369 Mdot
.52336 .33653 Mdot
.32136 .59042 Mdot
.40854 .30863 Mdot
.34448 .51286 Mdot
.54701 .6916 Mdot
.68733 .50347 Mdot
.46164 .46444 Mdot
.49938 .40939 Mdot
.56293 .60189 Mdot
.87712 .50444 Mdot
.43522 .36247 Mdot
.33752 .34507 Mdot
.33617 .79339 Mdot
.67702 .291 Mdot
.25087 .57265 Mdot
.37745 .36992 Mdot
.57633 .73111 Mdot
.49843 .59651 Mdot
.35245 .74656 Mdot
.77601 .43131 Mdot
.5737 .81537 Mdot
.29062 .55401 Mdot
.34188 .4843 Mdot
.44741 .37935 Mdot
.60507 .38471 Mdot
.43404 .71478 Mdot
.62956 .77123 Mdot
.37652 .33259 Mdot
.3607 .81189 Mdot
.61547 .44927 Mdot
.71464 .64059 Mdot
.38486 .50297 Mdot
.7089 .75265 Mdot
.7459 .31487 Mdot
.32381 .47911 Mdot
.81759 .43859 Mdot
.78129 .52525 Mdot
.56733 .26066 Mdot
.66343 .53191 Mdot
.3441 .38488 Mdot
.32088 .60433 Mdot
.83952 .62296 Mdot
.63592 .76805 Mdot
.63802 .67678 Mdot
.70495 .604 Mdot
.27788 .41416 Mdot
.43561 .66971 Mdot
.17564 .6448 Mdot
.71969 .44182 Mdot
.84541 .60256 Mdot
.23482 .3689 Mdot
.3664 .54776 Mdot
.41769 .74382 Mdot
.47407 .35074 Mdot
.66243 .48406 Mdot
.61318 .797 Mdot
.49626 .41288 Mdot
.78831 .42013 Mdot
.37175 .39157 Mdot
.82036 .4783 Mdot
.59138 .53277 Mdot
.70364 .68663 Mdot
.62756 .71147 Mdot
.67533 .24472 Mdot
.29143 .71589 Mdot
.61778 .63237 Mdot
.14925 .58728 Mdot
.31687 .72276 Mdot
.4203 .81855 Mdot
.72412 .3473 Mdot
.71071 .25193 Mdot
.52701 .79162 Mdot
.42746 .77432 Mdot
.63008 .66197 Mdot
.46919 .49932 Mdot
.78753 .49154 Mdot
.40117 .50132 Mdot
.45025 .71626 Mdot
.59304 .59598 Mdot
.59133 .90444 Mdot
.58984 .31383 Mdot
.38193 .67482 Mdot
.77099 .486 Mdot
.46254 .8316 Mdot
.5061 .45365 Mdot
.19815 .62137 Mdot
.56536 .43664 Mdot
.35638 .36965 Mdot
.29284 .53235 Mdot
.26097 .34494 Mdot
.79776 .49631 Mdot
.71808 .22636 Mdot
.16373 .46379 Mdot
.70733 .62032 Mdot
.54872 .53921 Mdot
.37659 .65336 Mdot
.42445 .60936 Mdot
.67312 .38778 Mdot
.16799 .58306 Mdot
.38687 .73272 Mdot
.36194 .77831 Mdot
.6586 .19182 Mdot
.19648 .43593 Mdot
.63882 .79303 Mdot
.55529 .76656 Mdot
.41746 .59893 Mdot
.61849 .29726 Mdot
.64796 .3472 Mdot
.63833 .70414 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0XOooool2o`000:Kooooo000Looooo`03o`000?oooooooooo0:7o
oooo0_l0002Vooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0;;ooooo0_l0002Eooooo`00
7?ooool00ol0003oooooooooo`2Nooooo`;o00004_ooool2o`0009Gooooo000Looooo`03o`000?oo
oooooooo09kooooo0_l0002Yooooo`007?ooool00ol0003oooooooooo`2Qooooo`;o0000Y_ooool0
01cooooo00?o0000ooooooooool0XOooool2o`000:Kooooo000Looooo`03o`000?oooooooooo0:[o
oooo0_l00007ooooo`;o00001oooool2o`0008_ooooo000Looooo`03o`000?oooooooooo0:[ooooo
0_l00007ooooo`;o00001oooool2o`0008_ooooo000Looooo`;o0000oooooom;ooooo`007?ooool0
0ol0003oooooooooo`1dooooo`;o0000=oooool2o`0000[ooooo0_l0002>ooooo`007?ooool00ol0
003oooooooooo`1dooooo`;o0000=oooool2o`0000Sooooo1?l0002>ooooo`007?ooool00ol0003o
ooooooooo`29ooooo`;o0000:?ooool2o`0000;ooooo0_l0002@ooooo`007?ooool00ol0003ooooo
ooooo`1booooo`;o00005Oooool2o`0000cooooo0_l0000Jooooo`;o0000U?ooool001cooooo00?o
0000ooooooooool0L_ooool2o`0002?ooooo0_l00003ooooo`;o00008Oooool2o`000003ooooool0
003o000008Gooooo000Looooo`03o`000?oooooooooo093ooooo0_l0000:ooooo`;o00001_ooool2
o`00017ooooo0_l00006ooooo`;o000000?oooooo`000?l00000QOooool001cooooo00?o0000oooo
ooooool0N_ooool2o`00013ooooo0ol000000ooooooo0000o`00000<ooooo`;o00001?ooool2o`00
00Sooooo0_l00007ooooo`;o0000T?ooool001cooooo00?o0000ooooooooool0N_ooool2o`00013o
oooo0ol00006ooooo`;o00001oooool4o`0000Gooooo0_l00005ooooo`;o00004Oooool2o`0008Ko
oooo000Looooo`03o`000?oooooooooo07kooooo0_l0000=ooooo`;o00001_ooool2o`0000;ooooo
0_l00005ooooo`;o00001Oooool2o`0000kooooo0ol00007ooooo`;o0000Q_ooool001cooooo00?o
0000ooooooooool0N?ooool2o`0000Cooooo0_l0000Iooooo`;o00000_ooool3o`0001?ooooo1ol0
002?ooooo`007?ooool00ol0003oooooooooo`1hooooo`;o00005oooool2o`0000[ooooo0ol0000B
ooooo`Ko00002oooool2o`0008Cooooo000Looooo`03o`000?oooooooooo097ooooo0_l0000Ooooo
o`;o000000?oooooo`000?l000003?ooool2o`0008Cooooo00001_ooooook^k^oc8b<_l0003o<S8b
onk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`22ooooo`;o00002Oooool2
o`0004?ooooo0_l0001eooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0P_ooool2o`0000Wooooo
0_l0000Zooooo`;o00001oooool2o`0000kooooo0_l0001eooooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0U?oo
ool2o`0001[ooooo0_l00007ooooo`;o00001_ooool3o`00017ooooo1?l0001`ooooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0001[
ooooo`;o00009oooool2o`0001[ooooo0_l0000>ooooo`Ko00000_ooool2o`0000_ooooo1?l0001`
ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo
00Gooooo00?o0000ooooooooool0Hoooool2o`0000Kooooo0_l000000ooooooo0000o`00000>oooo
o`;o00007_ooool2o`0000Gooooo0_l0000Iooooo`Ko00000_ooool2o`0007oooooo00000ooooooo
410@ooooo`02ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`1Sooooo`;o00002Oooool2o`0000kooooo0_l00009ooooo`;o00004oooool4o`0000?o
oooo0_l0000Tooooo`;o0000O?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0
003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0G?ooool2o`0001oooooo0_l00008
ooooo`Co00002?ooool2o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o0000:Oooool2
o`0007cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c006ooooo`03o`000?oooooooooo05cooooo0_l00003ooooo`;o00002_ooool2o`0000kooooo
0ol00005ooooo`Co000000?oooooo`000?l000001oooool2o`0000Cooooo0_l000001?oooooo0000
o`000?l0002Zooooo`007?ooool00ol0003oooooooooo`1Looooo`;o00000oooool2o`0000[ooooo
0_l00002ooooo`;o00001oooool2o`0000;ooooo0_l00005ooooo`;o00000oooool2o`00017ooooo
1?l00006ooooo`;o00007oooool2o`0007oooooo000Looooo`03o`000?oooooooooo077ooooo0ol0
0006ooooo`;o00004_ooool2o`0000oooooo0ol000001?oooooo0000o`000?ooool3o`0001oooooo
0_l0001oooooo`007?ooool00ol0003oooooooooo`1?ooooo`;o00000_ooool2o`0001gooooo0_l0
0002ooooo`;o00005_ooool2o`0000_ooooo0_l00002ooooo`Ko000000Coooooo`000?l0003o0000
7?ooool2o`000003ooooool0003o000000;ooooo0_l0000Aooooo`;o0000J?ooool001cooooo00?o
0000ooooooooool0Coooool2o`0000;ooooo0_l0000Booooo`;o00002Oooool2o`0000;ooooo0_l0
0007ooooo`Co00001_ooool2o`0000?ooooo0_l000000ooooooo0000o`000008ooooo`;o00001Ooo
ool2o`00027ooooo0_l00005ooooo`Co00003oooool2o`0000Cooooo0_l0001Rooooo`007?ooool0
0ol0003oooooooooo`1Wooooo`;o00001?ooool2o`0000?ooooo0_l00002ooooo`;o00001oooool4
o`0000;ooooo0ol000000ooooooo0000o`000002o`000004ooooool0003o0000ooooo`;o00000_oo
ool2o`0000Sooooo0_l00004ooooo`;o000000?oooooo`000?l000001?l00003ooooo`;o00004ooo
ool2o`0000Kooooo0_l00007ooooo`;o00003?ooool2o`0006;ooooo000Looooo`03o`000?oooooo
oooo05kooooo0_l0000=ooooo`;o00001oooool2o`000003ooooool0003o000000;o00000_ooool3
o`0000?ooooo1?l00002ooooo`;o00001Oooool2o`000003ooooool0003o000000Sooooo0_l00004
ooooo`;o000000?oooooo`000?l000001?l00003ooooo`;o00004oooool2o`000003ooooool0003o
000000cooooo0_l0001`ooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o000000?oooooo`00
0?l000005_ooool6o`000003ooooool0003o000000Gooooo0_l00009ooooo`;o00003Oooool3o`00
0004ooooool0003o0000ooooo`;o000000?oooooo`000?l000006_ooool4o`0000?ooooo0ol00002
ooooo`;o00000_ooool2o`00073ooooo000Looooo`03o`000?oooooooooo067ooooo0_l0000>oooo
o`Co00002?ooool2o`00013ooooo0_l0000@ooooo`?o000000?oooooo`000?l000001?ooool5o`00
01Gooooo1?l00005ooooo`?o00000_ooool2o`0007Cooooo000Looooo`03o`000?oooooooooo06co
oooo0_l00003ooooo`Co00005?ooool4o`0000;ooooo0_l00005ooooo`;o00002_ooool2o`0000Wo
oooo1Ol0000Cooooo`;o00001oooool2o`0000Kooooo0ol0001`ooooo`007?ooool00ol0003ooooo
ooooo`1Looooo`;o00002?ooool2o`0000Cooooo0_l00005ooooo`;o00005?ooool5o`0000Gooooo
0_l000000ooooooo0000o`00000:ooooo`;o00001oooool2o`0000?ooooo0_l0000Oooooo`;o0000
00?oooooo`000?l000001?l0001_ooooo`007?ooool00ol0003oooooooooo`1Looooo`;o00002?oo
ool4o`0000;ooooo0_l0000>ooooo`;o000000?oooooo`000?l000002Oooool4o`0000Gooooo0_l0
000Fooooo`;o00006oooool2o`0000Oooooo0_l000000ooooooo0000o`000002ooooo`;o0000Kooo
ool001cooooo0_l0001Xooooo`?o00000oooool2o`0000;ooooo0_l00006ooooo`;o000000Cooooo
o`000?l0003ooooo0_l00005ooooo`;o00000_ooool2o`0000;ooooo0_l0000:ooooo`;o00000ooo
ool2o`0000Cooooo0_l0000;ooooo`Co00004_ooool2o`0000kooooo0_l00009ooooo`;o00001ooo
ool2o`0005_ooooo000Looooo`03o`000?oooooooooo05Gooooo0_l0000Dooooo`Co00000_ooool2
o`0000Gooooo1_l00008ooooo`;o00001_ooool2o`0000;ooooo0_l000000ooooooo0000o`000003
ooooo`;o00000oooool2o`0000Cooooo0_l00006ooooo`;o00000oooool6o`0000Gooooo0_l00008
ooooo`;o00001_ooool2o`0000Oooooo0_l00007ooooo`Co00001oooool2o`0005_ooooo000Loooo
o`03o`000?oooooooooo05Gooooo0_l000000ooooooo0000o`00000:ooooo`;o00001Oooool2o`00
00?ooooo0_l00006ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o00003Oooool2o`00
0003ooooool0003o000000Sooooo0_l00006ooooo`;o00001?ooool2o`0000Oooooo0_l00005oooo
o`?o00000_ooool2o`0000?ooooo0_l00006ooooo`;o00004?ooool2o`0006Kooooo000Looooo`03
o`000?oooooooooo05Gooooo0_l000000ooooooo0000o`000006ooooo`;o00000_ooool2o`0000Co
oooo0_l00004ooooo`;o00002oooool5o`000003ooooool0003o000000Oooooo1Ol0000<ooooo`;o
00002?ooool2o`0000cooooo0_l000000ooooooo0000o`000003ooooo`?o00000_ooool2o`0000Co
oooo0_l00003ooooo`?o00004_ooool2o`0006Gooooo000Looooo`03o`000?oooooooooo057ooooo
0_l0000:ooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo1?l00009ooooo`;o0000
0_ooool2o`0000;ooooo0ol0000:ooooo`Go00000oooool2o`0000Oooooo0_l0000Fooooo`Ko0000
3Oooool2o`0000?ooooo0ol00003ooooo`;o00003Oooool2o`0006Gooooo000Looooo`03o`000?oo
oooooooo04cooooo0_l00003ooooo`;o00002_ooool2o`000003ooooool0003o000000;o000000?o
ooooo`000?l000001?ooool3o`0000Wooooo1_l0000@ooooo`;o00000_ooool2o`000003ooooool0
003o000000Oooooo0_l00008ooooo`Co000000?oooooo`000?l000002?ooool2o`000003ooooool0
003o000000Kooooo0_l0000@ooooo`;o000000?oooooo`000?l00000LOooool001cooooo00?o0000
ooooooooool0C?ooool2o`0001;ooooo1?l0000<ooooo`?o00001_ooool2o`0000Sooooo0_l0000<
ooooo`;o00002_ooool2o`0000Sooooo1?l000000ooooooo0000o`00000=ooooo`;o000000Cooooo
o`000?l0003ooooo0_l0000@ooooo`Go00002Oooool2o`0006Kooooo000Looooo`03o`000?oooooo
oooo05gooooo0ol00008ooooo`Co00001?ooool3o`0000?ooooo0_l000000ooooooo0000o`000002
ooooo`;o00001?ooool4o`0001Oooooo0ol00006ooooo`Co00004?ooool5o`0000kooooo1?l00003
ooooo`;o00001oooool2o`000003ooooool0003o000006Kooooo000Looooo`03o`000?oooooooooo
05cooooo1?l00008ooooo`Co00001Oooool2o`0000?ooooo1Ol00002ooooo`;o00000_ooool2o`00
00;ooooo0_l000000ooooooo0000o`00000=ooooo`;o00001Oooool3o`0000Kooooo1?l000000ooo
oooo0000o`000002o`0000cooooo1?l0000>ooooo`Co00001_ooool2o`0000Cooooo1_l0001Uoooo
o`007?ooool00ol0003oooooooooo`1Looooo`;o00006Oooool2o`0000Sooooo0_l00005ooooo`Co
00002_ooool3o`0000Cooooo0_l000000ooooooo0000o`000002o`0000Gooooo0_l000000ooooooo
0000o`000002o`0000kooooo0_l0000Hooooo`;o00001_ooool6o`0000?ooooo0_l0001Nooooo`00
7?ooool00ol0003oooooooooo`1]ooooo`;o00001?ooool2o`00013ooooo0_l00003ooooo`?o0000
0_ooool2o`0000?ooooo1Ol00004ooooo`Oo00003oooool2o`0000cooooo0_l000000ooooooo0000
o`000004ooooo`;o000000?oooooo`000?l000001?ooool2o`0000gooooo1_l000000ooooooo0000
o`00001Nooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00004oooool2o`000003ooooool0
003o000000?ooooo0ol000000ooooooo0000o`000002o`0000kooooo1?l00004ooooo`Ko00000ooo
ool5o`0000;ooooo1ol000000ooooooo0000o`00000=ooooo`?o00003?ooool2o`000003ooooool0
003o000000Cooooo0_l000000ooooooo0000o`000004ooooo`;o00001Oooool4o`0000Sooooo0_l0
001Qooooo`007?ooool00ol0003oooooooooo`1@ooooo`Co00002?ooool2o`0000Oooooo0_l00000
0ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000003_ooool4o`0000Sooooo1ol00004
ooooo`;o000000?oooooo`000?l000001Ol000000ooooooo0000o`000005ooooo`;o00001?ooool5
o`0001kooooo0_l000000ooooooo0000o`000002ooooo`Co00007?ooool2o`0004gooooo000Loooo
o`03o`000?oooooooooo05;ooooo0_l000000ooooooo0000o`000004ooooo`?o00003_ooool2o`00
01?ooooo0_l00004ooooo`;o00001_ooool5o`0000Cooooo0_l0000:ooooo`;o00001?ooool2o`00
00?ooooo0ol000000ooooooo0000o`00000Cooooo`;o00003?ooool4o`0000cooooo0_l00005oooo
o`;o00002oooool2o`0004gooooo000Looooo`03o`000?oooooooooo05Gooooo0_l00004ooooo`Co
00000oooool3o`000003ooooool0003o000000Cooooo0_l00008ooooo`;o00003Oooool8o`0000Co
oooo0_l000000ooooooo0000o`000003ooooo`;o00001oooool4o`0000?ooooo0ol00003ooooo`;o
00000oooool2o`0000Gooooo0_l0000;ooooo`;o00003Oooool3o`0000Oooooo0_l00003ooooo`;o
000000?oooooo`000?l000000_ooool2o`0005[ooooo000Looooo`03o`000?oooooooooo05;ooooo
0_l00007ooooo`Co000000?oooooo`000?l000000ol000000ooooooo0000o`000002ooooo`;o0000
2Oooool3o`0000_ooooo1Ol000000ooooooo0000o`000002o`0000Kooooo0ol00003ooooo`Co0000
1Oooool2o`0000Gooooo0_l00005ooooo`;o000000Coooooo`000?l0003o00001Oooool2o`0000So
oooo0_l00005ooooo`;o00003Oooool2o`000004ooooool0003o0000ooooo`?o00001Oooool4o`00
05cooooo000Looooo`;o0000Doooool2o`0000Kooooo1?l00002ooooo`;o00002?ooool2o`0000Wo
oooo0_l0000<ooooo`;o000000?oooooo`000?l000001_ooool3o`0000;ooooo0ol00005ooooo`;o
000000?oooooo`000?l000000_l000000ooooooo0000o`000005ooooo`;o00001?ooool2o`000003
ooooool0003o000000_ooooo0_l000000ooooooo0000o`000002o`000004ooooool0003o0000oooo
o`?o00003Oooool2o`000003ooooool0003o000000;ooooo0_l00007ooooo`;o00001?ooool2o`00
05Kooooo000Looooo`03o`000?oooooooooo05[ooooo0ol00006ooooo`;o00000_ooool2o`0000;o
oooo0_l0000Dooooo`;o00001oooool2o`0000;ooooo0ol00003ooooo`;o00002?ooool4o`000003
ooooool0003o000000;o00000oooool2o`0000Kooooo0_l0000;ooooo`?o000000?oooooo`000?l0
00000oooool2o`000003ooooool0003o000000_ooooo0_l0000Gooooo`;o00004_ooool2o`0004;o
oooo000Looooo`03o`000?oooooooooo04;ooooo0_l0000Gooooo`;o00001_ooool3o`000003oooo
ool0003o000000;ooooo0_l000000ooooooo0000o`00000Aooooo`Co00001Oooool2o`0000;ooooo
0_l0000>ooooo`;o000000?oooooo`000?l000000_ooool2o`0000_ooooo0_l00006ooooo`;o0000
0oooool2o`0000[ooooo0_l00007ooooo`;o00000_ooool2o`0000Oooooo0_l0000:ooooo`;o0000
3oooool2o`0000Gooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00003ooo
ool2o`0000oooooo0_l00008ooooo`Co000000?oooooo`000?l000000_ooool2o`0000Sooooo1?l0
000Iooooo`;o000000?oooooo`000?l000003oooool2o`000003ooooool0003o000000?ooooo0_l0
000>ooooo`;o00002?ooool2o`0000_ooooo0_l0000:ooooo`Co00003Oooool2o`0004Wooooo000L
ooooo`03o`000?oooooooooo04_ooooo0_l00006ooooo`;o00006oooool2o`000003ooooool0003o
000000Co00002?ooool3o`0000Wooooo0_l0000?ooooo`;o00001Oooool2o`0000Oooooo0ol00000
0ooooooo0000o`000003o`0000?ooooo1?l00008ooooo`;o00000_ooool2o`0000Oooooo0_l0000J
ooooo`;o00001_ooool2o`00053ooooo000Looooo`03o`000?oooooooooo04_ooooo0_l00005oooo
o`;o00001Oooool2o`0000;ooooo0_l0000Dooooo`Co00002_ooool3o`0000Gooooo0_l00002oooo
o`?o00000_ooool2o`0000?ooooo0_l00005ooooo`;o00001Oooool3o`0000Cooooo1Ol000000ooo
oooo0000o`000002o`0000Kooooo0_l00008ooooo`;o00002_ooool3o`0000cooooo0_l0000;oooo
o`;o00000_ooool2o`0000?ooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`19ooooo`;o
00001oooool2o`0000Gooooo0_l00002ooooo`?o00001Oooool4o`0000Gooooo1?l000001?oooooo
0000o`000?l0000Cooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00002Oooool6o`00
00Cooooo0_l00004ooooo`Co00000_ooool2o`0001?ooooo0_l00003ooooo`;o00001_ooool4o`00
00?ooooo0ol00004ooooo`;o00001?ooool2o`0000;ooooo0_l00003ooooo`;o0000D?ooool001co
oooo00?o0000ooooooooool0BOooool2o`0000Oooooo0_l0000:ooooo`;o00001Oooool4o`0000Go
oooo1Ol000001?oooooo0000o`000?ooool2o`0000Sooooo0_l00002ooooo`;o00001oooool2o`00
00Cooooo0_l00007ooooo`;o00000oooool4o`0000cooooo0_l000000ooooooo0000o`000005o`00
00Kooooo0_l00007ooooo`Co00002_ooool5o`0000Cooooo0_l00004ooooo`;o00003Oooool2o`00
053ooooo000Looooo`03o`000?oooooooooo04cooooo0_l00004ooooo`;o00005?ooool2o`0000Co
oooo0_l000000ooooooo0000o`000004ooooo`;o00001?ooool2o`0000;ooooo0ol000000ooooooo
0000o`000003ooooo`;o00000_ooool2o`0000Cooooo0_l00003ooooo`;o00000_ooool2o`0000?o
oooo0_l00002ooooo`;o00000oooool2o`0000Sooooo0ol00002ooooo`;o00000_ooool3o`000003
ooooool0003o000000;ooooo0_l00003ooooo`Co00002_ooool2o`000003ooooool0003o000001?o
oooo1?l0000=ooooo`;o0000AOooool001cooooo00?o0000ooooooooool0C?ooool2o`0000_ooooo
0_l00002ooooo`;o00002Oooool2o`0000Cooooo0_l0000=ooooo`;o00000oooool3o`0000Cooooo
0ol0000=ooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo0ol00002ooooo`?o0000
0_ooool2o`0000?ooooo1?l000000ooooooo0000o`000007o`0000?ooooo0_l00002ooooo`;o0000
7oooool3o`0000?ooooo1?l00005ooooo`;o00001_ooool2o`0004Gooooo000Looooo`03o`000?oo
oooooooo05Wooooo0ol000000ooooooo0000o`00000Tooooo`Co00000_ooool3o`000003ooooool0
003o000000gooooo0_l00009ooooo`;o00000oooool2o`0000;ooooo6?l00002ooooo`Co00001Ooo
ool3o`0001Gooooo0ol0000<ooooo`;o0000COooool001cooooo00?o0000ooooooooool0;?ooool2
o`0001cooooo0_l0000>ooooo`;o00000oooool2o`0000Wooooo0_l0000;ooooo`;o00000_ooool4
o`0000Gooooo0ol000000ooooooo0000o`000003ooooo`Co00002Oooool2o`0001Gooooo1Ol00000
0ooooooo0000o`00000?o`0000Cooooo0_l00005ooooo`?o00004oooool2o`0000cooooo0_l00009
ooooo`;o0000AOooool001cooooo00?o0000ooooooooool0;?ooool2o`0000Wooooo0_l0000Aoooo
o`;o00002_ooool2o`0000Oooooo0_l00005ooooo`Ko00002oooool2o`0000;ooooo1?l00005oooo
o`Ko00001?ooool3o`0000;ooooo0_l00005ooooo`;o00001?ooool2o`0000Cooooo0_l00008oooo
o`;o00000_oooolBo`0000;ooooo0_l0000Oooooo`;o00003?ooool2o`0000Wooooo0_l00015oooo
o`007?ooool00ol0003oooooooooo`0gooooo`;o00005_ooool2o`0000Gooooo0_l00009ooooo`;o
00000oooool4o`0000Gooooo0_l00005ooooo`;o000000?oooooo`000?l000000ol00002ooooo`;o
00001?ooool4o`0000Wooooo0_l00008ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Co
oooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0ol00002ooooo`_o00000_ooool2o`00
00Gooooo0_l0000<ooooo`;o00002?ooool2o`0000gooooo0_l00004ooooo`;o0000Boooool001co
oooo00?o0000ooooooooool0Coooool2o`0000Gooooo0_l00009ooooo`;o00001?ooool2o`0000Ko
oooo1?l000000ooooooo0000o`000002o`000003ooooool0003o000000?o00000_ooool2o`000003
ooooool0003o000000Go00002Oooool2o`0000Sooooo0_l0000=ooooo`;o00000oooool9o`000003
ooooool0003o000000;o000000?oooooo`000?l000002Ol00004ooooo`;o00001Oooool2o`0000Go
oooo0_l00006ooooo`Co000000?oooooo`000?l000000_l00008ooooo`;o00001?ooool2o`0004_o
oooo000Looooo`03o`000?oooooooooo04gooooo0_l00002ooooo`;o00000oooool2o`0001;ooooo
0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000_l00003ooooo`?o0000
00Coooooo`000?l0003ooooo2?l000000ooooooo0000o`000005ooooo`?o00002?ooool2o`0000oo
oooo0_l000000ooooooo0000o`00000Ho`0000Cooooo0_l00005ooooo`;o00003Oooool4o`000003
ooooool0003o000000;o00002?ooool2o`00057ooooo000Looooo`;o0000B?ooool2o`0000?ooooo
0ol00002ooooo`;o00005oooool2o`000004ooooool0003o0000ooooo`?o00000_ooool5o`000003
ooooool0003o000000Co000000Goooooo`000?l0003o0000ooooo`03o`000004ooooool0003o0000
o`0000;ooooo2Ol00005ooooo`;o00003?ooool2o`000004ooooool0003o0000oooooaWo00001Ooo
ool2o`0000Gooooo0_l0000:ooooo`;o00000oooool2o`0000Gooooo0_l00006ooooo`;o0000DOoo
ool001cooooo00?o0000ooooooooool0@_ooool2o`0000;ooooo0ol00003ooooo`;o00004_ooool2
o`0000Cooooo0_l00006ooooo`Ko00000oooool5o`000005ooooool0003o0000o`000?ooool02ol0
0003ooooo`Co000000?oooooo`000?l000000_l00007ooooo`?o00001oooool4o`0000Cooooo6Ol0
00000ooooooo0000o`000009ooooo`;o00002Oooool3o`0000[ooooo0_l0001Iooooo`007?ooool0
0ol0003oooooooooo`12ooooo`;o00000_ooool3o`0000?ooooo1Ol0000?ooooo`;o00001?ooool2
o`0000Kooooo0ol000001?oooooo0000o`000?ooool4o`000003ooooool0003o000000?o000000?o
ooooo`000?l000002_l00003ooooo`?o00000oooool3o`000003ooooool0003o000000Cooooo0ol0
0007ooooo`Co00001OoooolKo`0001Cooooo0ol00006ooooo`?o00002Oooool2o`0000Gooooo0_l0
001:ooooo`007?ooool00ol0003oooooooooo`11ooooo`;o00001?ooool2o`0000?ooooo1Ol00006
ooooo`;o00003_ooool2o`0000Wooooo1ol000000ooooooo0000o`00000Ho`0000;ooooo1Ol0000>
ooooo`;o00001ooooolIo`0001oooooo0ol00008ooooo`?o00001?ooool3o`0004[ooooo000Loooo
o`03o`000?oooooooooo047ooooo0_l00005ooooo`;o00001oooool2o`0000Cooooo0_l0000>oooo
o`;o00001Oooool;o`000003ooooool0003o000001So00001?ooool3o`0000Kooooo0_l00009oooo
o`;o00001OoooolFo`0000kooooo0_l00007ooooo`;o00002Oooool2o`0000Sooooo0_l00005oooo
o`;o00000_ooool2o`0004Oooooo000Looooo`03o`000?oooooooooo04Oooooo0ol00007ooooo`;o
00003oooool2o`0000Gooooo0_l00003ooooo`Go000000?oooooo`000?l000007Ol00003ooooo`Ko
00000_ooool2o`000003ooooool0003o000000Wooooo0_l00005oooooaKo00003_ooool2o`0000Oo
oooo0_l00009ooooo`Co00004Oooool2o`0004Oooooo000Looooo`03o`000?oooooooooo037ooooo
0_l0000Dooooo`Co00005oooool2o`0000Gooooo0ol000000ooooooo0000o`00000No`000003oooo
ool0003o000000;o000000?oooooo`000?l000000ol00002ooooo`;o00000_ooool2o`0000;ooooo
0_l00008ooooo`Go000000?oooooo`000?l000005Ol0000Kooooo`Co00001Oooool2o`0000Cooooo
0_l0000:ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0<Oooool2o`0000oooooo0ol0
0004ooooo`;o00004Oooool2o`0000Cooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo
1Ol000000ooooooo0000o`00000Ho`000003ooooool0003o000000;o000000?oooooo`000?l00000
0_l00002ooooo`;o00001oooool2o`0000?ooooo0_l00005ooooo`?o000000Goooooo`000?l0003o
0000ooooo`0Co`0000cooooo0_l00008ooooo`;o00000oooool4o`0000Kooooo0_l00002ooooo`?o
00002_ooool3o`0004Oooooo000Looooo`03o`000?oooooooooo03[ooooo0_l00006ooooo`?o0000
1?ooool2o`0000cooooo0ol00002ooooo`;o00002Oooool2o`0000Oooooo0ol000000ooooooo0000
o`00000Mo`000003ooooool0003o000000Go00000_ooool3o`0000Oooooo0_l00009oooooaWo0000
2_ooool2o`0000Sooooo0_l0000=ooooo`;o00000_ooool2o`0000cooooo0_l00017ooooo`007?oo
ool00ol0003oooooooooo`0jooooo`;o00000oooool2o`0000?ooooo0_l0000Aooooo`?o00002?oo
ool2o`0000gooooo1Ol00002ooooo`go00000oooool;o`000003ooooool0003o000000Go00000_oo
ool3o`00013ooooo5_l000000ooooooo0000o`000002o`0001[ooooo0_l00005ooooo`Co000000?o
ooooo`000?l000000_l0000;ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0?oooool2
o`0000?ooooo0_l0000=ooooo`;o000000?oooooo`000?l000001oooool2o`000003ooooool0003o
000000oooooo4_l000000ooooooo0000o`00000;o`0000Gooooo0ol00004ooooo`;o00000oooool2
o`0000[ooooo1Ol00002ooooo`oo00001oooool2o`0001Cooooo1?l00003ooooo`_o00001Oooool2
o`0000;ooooo1?l00017ooooo`007?ooool00ol0003oooooooooo`0jooooo`;o00001_ooool2o`00
00oooooo0_l000000ooooooo0000o`000007ooooo`;o00002Oooool2o`0000Gooooo9Ol000000ooo
oooo0000o`000004o`0000;ooooo0_l00003ooooo`;o00004Oooool<o`0000[ooooo0_l0000?oooo
o`;o00000oooool2o`0000Gooooo0_l00002ooooo`Co000000Coooooo`000?l0003o00000oooool3
o`0000;ooooo0_l00019ooooo`007?ooool00ol0003oooooooooo`0jooooo`;o00001?ooool4o`00
01Sooooo1Ol00008ooooo`Go00000_ooool]o`0001[ooooo1ol000000ooooooo0000o`000002o`00
00Oooooo0_l0000;ooooo`;o00001Oooool2o`0000Wooooo0ol00003ooooo`;o00000oooool2o`00
00?ooooo0_l000000ooooooo0000o`000002ooooo`;o0000Aoooool001cooooo00?o0000oooooooo
ool0>?ooool3o`0000Gooooo1?l0000?ooooo`;o00000oooool3o`000003ooooool0003o000000;o
00002Oooool2o`000003ooooool0003o000000;ooooo0_l00002ooooobKo00003Oooool2o`0001?o
oooo0_l00008ooooo`;o00000_ooool2o`0000_ooooo0_l00003ooooo`;o00002oooool3o`0000?o
oooo1?l00009ooooo`;o00000_ooool2o`000003ooooool0003o000004Cooooo00001_ooooook^k^
oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0
003oooooooooo`0/ooooo`;o00002_ooool3o`0000Oooooo0_l0000?ooooo`;o00000oooool3o`00
00Gooooo0_l0000>ooooo`;o00000_oooolQo`0000;ooooo1Ol0000;ooooo`;o00005?ooool2o`00
00Oooooo0ol0000Cooooo`;o00004oooool2o`0000gooooo0_l000000ooooooo0000o`000014oooo
o`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo02cooooo0_l0000Wooooo`;o00002Oooool2o`0000;ooooo0_l00000
0ooooooo0000o`000003ooooo`?o00001?ooool5o`000003ooooool0003o000000go000000?ooooo
o`000?l000004Ol0000Qooooo`;o00000oooool3o`0000;ooooo0_l0000?ooooo`;o00003_ooool2
o`0001;ooooo0_l00002ooooo`?o00000oooool2o`00047ooooo00000ooooooo410@ooooo`02oooo
o`03oa0@4?oooooooooo00Wooooo1Ol00006ooooo`03o`000?oooooooooo05Gooooo0_l00003oooo
o`?o00001oooool2o`000004ooooool0003o0000ooooo`Go00001?oooolEo`000003ooooool0003o
0000013o00001oooool2o`0000Cooooo0_l0000Hooooo`?o00004oooool2o`0000kooooo0_l0000B
ooooo`;o00000oooool2o`0000?ooooo0_l00011ooooo`0000?oooooo`000?ooool00_ooool00ol0
003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0001Booooo`;o00001?ooool5
o`0000gooooo0_l000000ooooooo0000o`00000[o`000003ooooool0003o000000;o00000oooool2
o`0000Cooooo0_l0000Tooooo`;o00008oooool2o`0000[ooooo1?l00016ooooo`0000?oooooo`00
0?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000
ooooooooool0D_ooool2o`0000Cooooo0ol0000=ooooo`;o00001?ooool5o`000003ooooool0003o
000000[o000000?oooooo`000?l000005_l000000ooooooo0000o`000003o`0000;ooooo0ol0000H
ooooo`;o00004?ooool2o`0001gooooo0_l00004ooooo`Ko00001_ooool2o`0004Sooooo00000ooo
oooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oMgMgolc<c?l000001oooool00ol0
003oooooooooo`0Uooooo`;o00005?ooool5o`0000;ooooo1?l00004ooooo`;o00003Oooool2o`00
00Wooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000Go00000_oooolUo`00
0003ooooool0003o000000Co00006?ooool2o`0002oooooo0_l00006ooooo`Co00001oooool2o`00
00Kooooo0_l0000oooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co
000000Oooooo00?o0000ooooooooool09Oooool2o`00017ooooo0_l000000ooooooo0000o`000003
o`0000;ooooo1?l00004ooooo`;o00006?ooool2o`0000Gooooo0ol00002ooooobco00000_ooool3
o`0001gooooo0_l00003ooooo`;o0000>oooool2o`0000Kooooo0_l000000ooooooo0000o`00000l
ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o
0000ooooooooool0=oooool3o`0001gooooo0_l00003ooooo`;o00002Oooool2o`0000;ooooo0_l0
0005ooooobgo00007oooool2o`0000?ooooo0_l0000=ooooo`?o00002?ooool2o`0001Oooooo0_l0
0005ooooo`;o00003?ooool2o`0003cooooo000Looooo`03o`000?oooooooooo03Oooooo0_l00009
ooooo`Co00004Oooool2o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`Co00000oooool2
o`000003ooooool0003o000000;ooooo9?l000000ooooooo0000o`000003o`0000;ooooo0_l0000@
ooooo`Co00001Oooool2o`0000Gooooo0_l0000=ooooo`?o00002?ooool2o`0001Oooooo0_l00005
ooooo`;o000000Coooooo`000?l0003o00003Oooool2o`0003Oooooo000Looooo`03o`000?oooooo
oooo03Gooooo1?l00009ooooo`Co00003?ooool2o`0000[ooooo0ol00007ooooo`Co000000Gooooo
o`000?l0003o0000ooooo`0Xo`000003ooooool0003o000000?ooooo1?l0000>ooooo`Ko00001Ooo
ool2o`000003ooooool0003o000000;ooooo0_l0000Iooooo`?o00002Oooool2o`0000[ooooo0_l0
0004ooooo`;o00000_ooool3o`0000gooooo0_l0000gooooo`007?ooool00ol0003oooooooooo`0e
ooooo`Co00002_ooool4o`0000_ooooo0_l0000:ooooo`;o00002?ooool9o`000003ooooool0003o
000002Oo00001?ooool4o`0000kooooo0_l0000<ooooo`;o00005Oooool2o`0000Kooooo0ol00009
ooooo`;o00004?ooool2o`0000;ooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`0foooo
o`;o00001Oooool2o`0000Cooooo1?l0000Hooooo`;o00002?ooool;o`0000;ooooo3_l000000ooo
oooo0000o`00000Do`0000Kooooo1?l0000Aooooo`;o00000_ooool2o`0000Sooooo0_l00006oooo
o`Oo000000?oooooo`000?l000000_l0000Eooooo`;o00002Oooool2o`0004oooooo000Looooo`03
o`000?oooooooooo03Oooooo0_l00004ooooo`;o00001?ooool2o`0001[ooooo0_l00008ooooo`_o
00000_ooool>o`000003ooooool0003o000000oo00000_ooool2o`0000Cooooo0_l00003ooooo`;o
00004Oooool2o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l000000_l00003ooooo`So
000000?oooooo`000?l000005Oooool4o`000003ooooool0003o000000Gooooo0ol00002ooooo`;o
000000?oooooo`000?l000000ol0000?ooooo`;o000000?oooooo`000?l00000<Oooool001cooooo
00?o0000ooooooooool0<oooool2o`0000;ooooo1?l00002ooooo`;o00000oooool3o`0001;ooooo
0_l00004ooooo`Co00002?ooool2o`000003ooooool0003o0000013o00000_oooolFo`000004oooo
ool0003o0000o`0000;ooooo1?l0000Cooooo`;o00002?ooool3o`000004ooooool0003o0000o`00
00;ooooo0_l00003ooooo`;o000000?oooooo`000?l000000ol00004ooooo`;o00001?ooool3o`00
00_ooooo0_l00003ooooo`;o00001Oooool7o`000003ooooool0003o000000Go00003Oooool2o`00
0003ooooool0003o000000Wooooo0_l0000Vooooo`007?ooool00ol0003oooooooooo`0cooooo`;o
00000_ooool4o`000004ooooool0003o0000o`0000?ooooo1Ol0000@ooooo`;o00001?ooool4o`00
00Sooooo0_l00005ooooo`?o000000?oooooo`000?l000002?l000000ooooooo0000o`00000;o`00
0003ooooool0003o000000Oo000000?oooooo`000?l000000_l000000ooooooo0000o`000002o`00
01?ooooo0ol00007ooooo`Oo00001Oooool2o`0000?ooooo1Ol000000ooooooo0000o`000006o`00
0004ooooool0003o0000o`0000Kooooo0_l00005ooooo`;o00002Oooool4o`0000Sooooo0_l0000K
ooooo`;o00009_ooool001cooooo00?o0000ooooooooool0;Oooool2o`0000gooooo0_l00005oooo
o`Co00005?ooool2o`0000;ooooo0_l00002ooooo`;o00001?ooool3o`0000Gooooo0_l000000ooo
oooo0000o`00000Uo`0000?ooooo0_l00008ooooo`;o00000oooool2o`0000Gooooo0_l0000:oooo
o`;o000000?oooooo`000?l000001?ooool2o`0000?ooooo0_l00004ooooo`So00002_ooool2o`00
00Gooooo0_l0000<ooooo`;o00002Oooool2o`00047ooooo000Looooo`03o`000?oooooooooo02go
oooo0_l0000Zooooo`Co00000_ooool2o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l0
00000_oooolYo`0000Cooooo0_l00006ooooo`Co00000oooool2o`0000Wooooo0ol00008ooooo`;o
00002Oooool2o`0000Kooooo0_l00002ooooo`;o00001oooool2o`000003ooooool0003o000001?o
oooo1?l00007ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0FOooool2o`0000oooooo
0_l000000ooooooo0000o`00000To`0000;ooooo0_l000000ooooooo0000o`00000<ooooo`;o0000
4?ooool3o`0001?ooooo0_l0000:ooooo`;o00001oooool5o`0000[ooooo0_l000001?oooooo0000
o`000?ooool2o`0000?ooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o0000
7Oooool2o`0000Wooooo0_l000000ooooooo0000o`000004o`0000;ooooo7ol0000:ooooo`;o0000
4?ooool2o`0000Gooooo0_l0000;ooooo`;o00004_ooool2o`0000Gooooo0_l00003ooooo`;o0000
3?ooool8o`0000Cooooo0_l0000=ooooo`;o0000>_ooool001cooooo0_l00010ooooo`?o00006?oo
ool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0000Kooooo0_l00008ooooo`?o0000
00?oooooo`000?l000006Ol00008ooooo`;o00004?ooool2o`0000Gooooo1_l00007ooooo`;o0000
2?ooool2o`000003ooooool0003o000000Co000000?oooooo`000?l000000oooool4o`0000_ooooo
0_l00006ooooo`Co00001_ooool2o`0000gooooo0_l0000jooooo`007?ooool00ol0003ooooooooo
o`0oooooo`;o00006Oooool2o`0000Kooooo0_l000001?oooooo0000o`000?l0000:ooooo`?o0000
0oooool2o`000003ooooool0003o000000ko00000_ooool5o`0000;ooooo0_l00005ooooo`Co0000
0_ooool2o`00017ooooo1?l000000ooooooo0000o`000002o`0000Kooooo0_l00009ooooo`_o0000
1?ooool4o`0000?ooooo0_l00006ooooo`;o00003?ooool2o`0000Wooooo1Ol0000oooooo`007?oo
ool00ol0003oooooooooo`15ooooo`;o00007oooool4o`0000Sooooo0ol00002ooooo`?o000000?o
ooooo`000?l000003_l00002ooooo`;o00002Oooool2o`000003ooooool0003o000000;o00000_oo
ool2o`00017ooooo1?l0000;ooooo`;o00002?ooool>o`0000?ooooo1?l00002ooooo`;o00004?oo
ool2o`0000;ooooo1?l00007ooooo`Go0000?oooool001cooooo00?o0000ooooooooool0<Oooool2
o`0000Cooooo0_l00005ooooo`?o00001?ooool2o`00027ooooo0_l0000=ooooo`Co000000Cooooo
o`000?l0003ooooo2?l00006ooooo`Go00001_ooool2o`0001Cooooo0_l00003ooooo`Co000000?o
ooooo`000?l000002oooool2o`0000Kooooo4?l00002ooooo`?o00004_ooool4o`0000Cooooo1?l0
0003ooooo`;o00000oooool2o`0000Gooooo0_l00002ooooo`;o0000=?ooool001cooooo00?o0000
ooooooooool0<Oooool2o`0000Cooooo0_l00005ooooo`?o00006_ooool2o`0001cooooo1?l00002
ooooo`So00001?ooool;o`0000;ooooo0_l0000Aooooo`;o000000?oooooo`000?l000000oooool2
o`0000?ooooo0_l0000;ooooo`;o00002?ooool?o`000003ooooool0003o000000;o00004Oooool3
o`0000?ooooo0ol000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000001oooool2
o`0000;ooooo0_l0000dooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00002_ooool2o`00
0003ooooool0003o000000Cooooo0_l0000Cooooo`;o00002Oooool2o`0000Wooooo0ol00003oooo
o`Ko00000_ooool7o`0000Gooooo0_l000000ooooooo0000o`000006o`000003ooooool0003o0000
00_ooooo0_l00004ooooo`?o00001Oooool2o`0000?ooooo0_l0000Fooooo`co000000Coooooo`00
0?l0003o00000_ooool2o`00013ooooo1?l00002ooooo`Go000000?oooooo`000?l000000_l00003
ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool09_ooool2o`0001Gooooo0_l000000ooo
oooo0000o`000004ooooo`;o00007_ooool2o`0000Wooooo0ol00003ooooo`;o000000?oooooo`00
0?l000000oooool4o`0000Oooooo0ol000000ooooooo0000o`000009o`0000Gooooo0_l00004oooo
o`;o00001?ooool2o`000003ooooool0003o000000?ooooo0ol00002ooooo`?o00000oooool2o`00
00kooooo4ol00003ooooo`;o00003_ooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool4
o`0004Kooooo000Looooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`?o00002?ooool2o`00
02oooooo0_l00004ooooo`?o00002Oooool2o`000004ooooool0003o0000ooooo`Co00000oooool6
o`0000?ooooo0ol000001?oooooo0000o`000?l00007ooooo`;o00001oooool2o`0000?ooooo1?l0
00000ooooooo0000o`000002o`0000?ooooo0_l00003ooooo`;o00000oooool2o`0000Oooooo3Ol0
00000ooooooo0000o`000005o`0000;ooooo0ol0000=ooooo`Co00000oooool2o`0000;ooooo0_l0
00000ooooooo0000o`000017ooooo`007?ooool00ol0003oooooooooo`0/ooooo`Oo00001?ooool2
o`0002;ooooo0_l00002ooooo`;o00001oooool2o`0000Cooooo0ol00003ooooo`?o000000?ooooo
o`000?l000000_ooool4o`000004ooooool0003o0000o`0000;ooooo2?l00003ooooo`Go00000_oo
ool2o`0000Oooooo0_l00002ooooo`Co00000oooool4o`000004ooooool0003o0000o`0000;ooooo
0_l0000:ooooo`Co00001?ooool;o`000004ooooool0003o0000ooooo`Oo00000_ooool3o`0000go
oooo1?l000000ooooooo0000o`000002o`0000;ooooo0_l00004ooooo`;o0000A?ooool001cooooo
00?o0000ooooooooool0;?ooool2o`000003ooooool0003o000000;o00001Oooool2o`0000Gooooo
0_l00003ooooo`;o00005Oooool2o`0000;ooooo1Ol000000ooooooo0000o`00000=ooooo`?o0000
00?oooooo`000?l000000_ooool4o`0000;ooooo0_l00002ooooo`;o00000_ooool6o`0000?ooooo
0_l00003ooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`?o00001_ooool2o`000003
ooooool0003o000000Cooooo0_l0000<ooooo`;o00001?oooolFo`000003ooooool0003o000000?o
00003Oooool2o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`Co00000_ooool2o`00043o
oooo000Looooo`03o`000?oooooooooo02cooooo0_l0000:ooooo`;o00001Oooool2o`0000?ooooo
0_l0000Kooooo`?o000000?oooooo`000?l000002oooool2o`0000?ooooo0_l00006ooooo`;o0000
3?ooool4o`0000_ooooo1?l00003ooooo`Go00001?ooool3o`000004ooooool0003o0000o`0001;o
oooo0_l00003oooooaco00003Oooool2o`0000Gooooo0_l00003ooooo`Ko00000_ooool2o`0000Co
oooo0_l0000jooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00007_ooool2o`0000Oooooo
0_l00008ooooo`;o00001Oooool2o`0000?ooooo0_l000001Ooooooo0000o`000?l0003ooooo00?o
00003?ooool4o`0000?ooooo0_l00006ooooo`Co00000oooool2o`000004ooooool0003o0000o`00
00;ooooo0ol00003ooooo`;o00004_ooool2o`0000;ooooo7Ol0000<ooooo`?o00000_ooool2o`00
0003ooooool0003o000000?ooooo0_l00002ooooo`;o00002?ooool2o`0003[ooooo000Looooo`03
o`000?oooooooooo02_ooooo0_l00005ooooo`;o00000_ooool2o`000003ooooool0003o000000Go
oooo0_l0000Fooooo`;o000000?oooooo`000?l000003_ooool2o`0000gooooo0ol000000ooooooo
0000o`000005ooooo`;o00000_ooool2o`0000Wooooo0_l00008ooooo`;o00001oooool9o`0000Co
oooo0_l00009ooooo`;o00000oooool2o`0000?ooooo6ol0000>ooooo`?o00000_ooool2o`0000[o
oooo1?l00012ooooo`007?ooool00ol0003oooooooooo`0Wooooo`;o00000_ooool2o`0000Gooooo
0_l00002ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Cooooo0_l0000Cooooo`;o0000
5?ooool2o`0000Gooooo0_l0000;ooooo`;o000000Coooooo`000?l0003o00003oooool2o`0000go
oooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l0
00000_ooool3o`0000;ooooo0_l00002oooooago00002Oooool2o`000003ooooool0003o000000Wo
oooo0_l00005ooooo`Co000000?oooooo`000?l00000?oooool001cooooo00?o0000ooooooooool0
9oooool2o`0000gooooo0_l00008ooooo`;o00001?ooool2o`0001?ooooo0_l00003ooooo`;o0000
1_ooool2o`0000Oooooo0_l00005ooooo`;o00001?ooool2o`0000Sooooo0_l0000?ooooo`Go0000
3_ooool6o`0000Kooooo0_l000000ooooooo0000o`000003ooooo`;o00001?oooolOo`0000Wooooo
0_l000000ooooooo0000o`000007ooooo`Go00001_ooool2o`000003ooooool0003o000003oooooo
000Looooo`03o`000?oooooooooo02Wooooo0_l0000;ooooo`;o0000:?ooool2o`0000Gooooo0ol0
000Dooooo`;o00002_ooool2o`0000?ooooo0_l00008ooooo`;o000000?oooooo`000?l000002Ooo
ool3o`0000Cooooo1Ol000000ooooooo0000o`000009ooooo`;o00001Oooool2o`000003ooooool0
003o000001[o00002?ooool2o`0000Sooooo1Ol000000ooooooo0000o`000002o`0000Cooooo0_l0
0004ooooo`;o00003?ooool2o`0002kooooo000Looooo`;o0000:_ooool2o`0000oooooo0_l0000S
ooooo`;o00001_ooool2o`0000_ooooo1?l00007ooooo`;o00002Oooool2o`0000?ooooo0_l00004
ooooo`;o00003Oooool2o`000004ooooool0003o0000o`0000Gooooo2_l00006ooooo`;o00001_oo
oolOo`0000Oooooo0_l00008ooooo`Co00001?ooool2o`0000Oooooo0_l000000ooooooo0000o`00
000<ooooo`;o0000;_ooool001cooooo00?o0000ooooooooool0>_ooool2o`0002?ooooo0_l00005
ooooo`;o00003?ooool4o`000003ooooool0003o000000Cooooo1?l0000Booooo`?o00003?ooool2
o`0000cooooo0_l00002ooooo`Co00003Oooool5o`000003ooooool0003o000001Oo00004Oooool2
o`0000[ooooo0_l00003ooooo`;o00003oooool2o`0002kooooo000Looooo`03o`000?oooooooooo
03Oooooo0_l00004ooooo`?o00000_ooool2o`000003ooooool0003o0000017ooooo0_l00009oooo
o`;o000000?oooooo`000?l000001_ooool2o`0000Gooooo0_l00002ooooo`Ko00000_ooool2o`00
01?ooooo0_l00006ooooo`;o00001Oooool2o`00013ooooo1Ol00009oooooa;o00000_ooool;o`00
00kooooo0_l00003ooooo`;o00002_ooool2o`000004ooooool0003o0000ooooo`;o00003_ooool2
o`0002kooooo000Looooo`03o`000?oooooooooo02Cooooo0_l00005ooooo`;o00000_ooool2o`00
00Gooooo0ol00004ooooo`?o00000_ooool2o`000003ooooool0003o0000017ooooo0_l00009oooo
o`;o00000oooool3o`0000?ooooo0_l00008ooooo`;o000000?oooooo`000?l000000_l0000Ooooo
o`;o00001Oooool4o`0000Wooooo0_l00003ooooo`Go000000?oooooo`000?l000000oooool2o`00
0003ooooool0003o000000_o000000?oooooo`000?l000000ol000000ooooooo0000o`000007o`00
0003ooooool0003o000000Sooooo0_l00003ooooo`;o00004_ooool2o`000003ooooool0003o0000
00_ooooo0_l0000aooooo`007?ooool00ol0003oooooooooo`0Tooooo`;o00000oooool4o`0000;o
oooo0_l00005ooooo`;o0000<?ooool3o`000003ooooool0003o000000Gooooo0_l00003ooooo`;o
00007?ooool2o`0000oooooo1?l00007ooooo`;o00001_ooool5o`0000?ooooo0_l00003ooooo`co
000000?oooooo`000?l000002ol00002ooooo`;o000000Coooooo`000?l0003ooooo0_l00002oooo
o`;o00005oooool3o`0000gooooo0_l00003ooooo`;o0000;?ooool001cooooo00?o0000oooooooo
ool0:Oooool2o`0000Cooooo0_l00008ooooo`;o00003?ooool2o`0001?ooooo0_l0000>ooooo`;o
000000?oooooo`000?l000000_ooool2o`0000gooooo0_l0000Booooo`;o00003Oooool2o`0000;o
oooo0_l0000?ooooo`?o00002_oooolJo`0000Gooooo0_l000000ooooooo0000o`00000Kooooo`?o
00004_ooool2o`0002cooooo000Looooo`03o`000?oooooooooo02kooooo0_l00009ooooo`?o0000
00?oooooo`000?l000002?ooool2o`0000kooooo0_l00003ooooo`;o00002Oooool2o`0000Kooooo
0_l00007ooooo`;o00001Oooool2o`000003ooooool0003o000000[ooooo0_l00006ooooo`;o0000
3Oooool2o`00023ooooo6Ol0000Uooooo`?o0000@Oooool001cooooo00?o0000ooooooooool0;_oo
ool3o`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l000001_ooool2o`000003ooooool0
003o000000gooooo0_l000000ooooooo0000o`000002ooooo`;o00001oooool2o`0000oooooo0_l0
0005ooooo`;o00002oooool5o`0000Gooooo0_l0000Hooooo`;o00001_ooool2o`0000;ooooo0_l0
0009ooooo`[o000000?oooooo`000?l000003?l0000Tooooo`Oo0000?_ooool001cooooo00?o0000
ooooooooool0;oooool2o`0000Gooooo0_l0000=ooooo`;o000000?oooooo`000?l000003oooool7
o`0001gooooo0_l0000=ooooo`;o000000?oooooo`000?l000004?ooool2o`0000gooooo0_l00006
ooooo`;o00000_ooool2o`0000Cooooo0_l00003ooooo`[o000000?oooooo`000?l000002ol00007
ooooo`;o000000?oooooo`000?l000001oooool3o`0000Gooooo0_l00008ooooo`;o000000?ooooo
o`000?l000000_l0000nooooo`007?ooool00ol0003oooooooooo`0eooooo`;o00001?ooool2o`00
00[ooooo0_l0000@ooooo`;o000000?oooooo`000?l000000oooool4o`0000;ooooo0_l00003oooo
o`?o00003_ooool2o`000003ooooool0003o000000;ooooo1?l0000Cooooo`;o00000_ooool4o`00
00Wooooo0_l0000<ooooo`;o00001_ooool3o`0000;ooooo4_l000000ooooooo0000o`000003o`00
00Oooooo1Ol00007ooooo`?o00001Oooool2o`0000gooooo0_l00008ooooo`;o0000=?ooool001co
oooo00?o0000ooooooooool0=Oooool2o`0000Cooooo0_l00003ooooo`;o00001Oooool2o`000003
ooooool0003o000000oooooo0_l00004ooooo`Co00000_ooool2o`0000?ooooo0ol0000Aooooo`;o
00000_ooool4o`0001?ooooo0_l00002ooooo`;o00002oooool2o`0000;ooooo0_l00006ooooo`Co
00001ooooolIo`0000cooooo0_l0000Looooo`;o000000?oooooo`000?l000002?ooool2o`0003Co
oooo000Looooo`03o`000?oooooooooo03Gooooo0_l00009ooooo`;o00002?ooool2o`0000oooooo
0_l00004ooooo`;o00005_ooool2o`00013ooooo0_l0000Booooo`;o00003oooool2o`0000Kooooo
0ol000000ooooooo0000o`000005oooooaSo00008oooool2o`0000Kooooo0_l00009ooooo`Co0000
=?ooool001cooooo00?o0000ooooooooool0=oooool2o`0003Sooooo0_l00006ooooo`;o000000?o
ooooo`000?l000002Oooool2o`0000;ooooo0_l0000Sooooo`;o00001Oooool7o`0000Gooooo0_l0
0002oooooa?o00002Oooool2o`0000Oooooo0_l0000?ooooo`Oo00003Oooool4o`0003Cooooo000L
ooooo`03o`000?oooooooooo03;ooooo0_l00002ooooo`?o000000?oooooo`000?l000001?ooool2
o`0000Kooooo0ol0000Looooo`;o00001oooool3o`000003ooooool0003o000000Kooooo0_l00006
ooooo`;o000000?oooooo`000?l000002oooool3o`0001Oooooo0_l00007ooooo`;o000000?ooooo
o`000?l000000_l00009ooooo`;o000000?oooooo`000?l000002?l0000?ooooo`?o00000oooool5
o`0000oooooo0_l000000ooooooo0000o`000002o`0004Gooooo000Looooo`03o`000?oooooooooo
03;ooooo0_l00002ooooo`;o00000_ooool2o`0000Cooooo0_l00006ooooo`Go00005?ooool2o`00
00Cooooo1?l00005ooooo`Ko00003?ooool5o`0000gooooo1?l0000>ooooo`;o000000?oooooo`00
0?l000000oooool2o`0000cooooo0_l00007oooooa3o00000oooool2o`0000[ooooo0_l00003oooo
o`Co00004Oooool4o`0000gooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0booooo`;o
00005_ooool3o`0000Wooooo0_l00009ooooo`;o00001_ooool2o`000003ooooool0003o000000Co
oooo0ol0000=ooooo`Go00003oooool2o`0000Gooooo0_l00007ooooo`;o000000Coooooo`000?l0
003ooooo0_l00009ooooo`;o00003?ooool2o`0000;ooooo1_l000001?oooooo0000o`000?ooool9
o`0001Oooooo0_l00008ooooo`?o00001oooool2o`0000Kooooo1?l0000fooooo`007?ooool2o`00
03?ooooo0_l0000Rooooo`;o00005?ooool2o`0000Gooooo0_l00005ooooo`;o00002Oooool2o`00
0003ooooool0003o000000Wooooo0_l00008ooooo`;o00003Oooool2o`0000Wooooo1_l00002oooo
o`Co00001?ooool2o`000003ooooool0003o000000;o00001oooool4o`000003ooooool0003o0000
00Sooooo0_l00005ooooo`;o00001_ooool2o`0000Sooooo0ol00007ooooo`;o00002?ooool2o`00
03Kooooo000Looooo`03o`000?oooooooooo03;ooooo0_l000000ooooooo0000o`00000Booooo`;o
00004?ooool2o`0000cooooo0_l00009ooooo`;o00001?ooool2o`0000cooooo0_l00009ooooo`;o
00000oooool2o`0001_ooooo2?l00002ooooo`Ko00000_ooool2o`0000Oooooo0_l00003ooooo`;o
00003Oooool2o`0000Gooooo0_l00005ooooo`;o00003oooool2o`0000;ooooo0_l0000?ooooo`;o
00001_ooool2o`0002Oooooo000Looooo`03o`000?oooooooooo03;ooooo0_l000000ooooooo0000
o`000006ooooo`;o00002_ooool2o`0000?ooooo0_l00009ooooo`Ko00001_ooool2o`0000;ooooo
0_l00004ooooo`;o00000oooool2o`0000?ooooo0_l0000=ooooo`;o00003_ooool4o`0000Oooooo
0_l0000@ooooo`;o000000?oooooo`000?l000000ol00006ooooo`;o00002oooool2o`0000?ooooo
0_l0000=ooooo`;o00002oooool3o`0000_ooooo1_l00002ooooo`;o00003Oooool4o`0000Kooooo
0_l0000Wooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00001Oooool3o`000003ooooool0
003o000000_ooooo0_l00009ooooo`;o000000Coooooo`000?l0003o00001_ooool2o`0000Sooooo
0_l00003ooooo`?o00000_ooool2o`0000Kooooo0_l00005ooooo`;o00001_ooool2o`0000Sooooo
0_l00007ooooo`;o00005Oooool6o`0002gooooo0_l00002ooooo`;o00002Oooool2o`000003oooo
ool0003o000000?o00004Oooool3o`00037ooooo000Looooo`03o`000?oooooooooo02gooooo0_l0
0007ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000Hooooo`;o00002?oo
ool2o`0000kooooo1_l000000ooooooo0000o`000003ooooo`;o00000oooool2o`0000Sooooo0_l0
0005ooooo`;o00001oooool2o`0000Sooooo0ol0000=ooooo`Ko00002Oooool3o`0000[ooooo0_l0
000;ooooo`;o00002?ooool2o`0000Sooooo0_l00003ooooo`;o00001?ooool2o`00017ooooo0_l0
000booooo`007?ooool00ol0003oooooooooo`0]ooooo`;o00002_ooool3o`0001oooooo0_l00004
ooooo`;o00000oooool2o`0000oooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o
000000Cooooo0_l0000?ooooo`;o00001oooool2o`0000Kooooo1ol00009ooooo`;o00002_ooool2
o`0000?ooooo0ol0000:ooooo`;o00000oooool4o`0000Cooooo0_l0000Booooo`;o00005Oooool2
o`0000Gooooo0_l0000booooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00002?ooool2o`00
01_ooooo0_l00009ooooo`;o00000oooool4o`0000;ooooo0_l00003ooooo`;o00000oooool2o`00
0005ooooool0003o0000o`000?ooool01Ol0000?ooooo`;o00002oooool3o`0000Oooooo1ol00009
ooooo`;o00002_ooool2o`0000?ooooo1?l00004ooooo`;o00002?ooool4o`0000kooooo0_l0000O
ooooo`;o00000oooool2o`0003Cooooo000Looooo`03o`000?oooooooooo02Sooooo0_l00005oooo
o`;o00005?ooool2o`0000Oooooo0_l00006ooooo`Co00003_ooool3o`000003ooooool0003o0000
00;o000000?oooooo`000?l000000_ooool3o`000004ooooool0003o0000ooooo`;o000000?ooooo
o`000?l000000oooool2o`0000_ooooo0_l00008ooooo`;o000000Coooooo`000?l0003o00000_oo
ool2o`0000;ooooo0ol0000Hooooo`;o00001oooool2o`0000Cooooo0_l0000Jooooo`;o00009?oo
ool2o`0003Cooooo000Looooo`03o`000?oooooooooo02Sooooo0_l0000Cooooo`;o00001?ooool4
o`0000Oooooo0_l00008ooooo`;o00001_ooool3o`0000Gooooo0ol000000ooooooo0000o`000003
o`0000?ooooo1_l00002ooooo`Co00001?ooool2o`000003ooooool0003o000000Kooooo0_l0000:
ooooo`;o00001_ooool2o`000003ooooool0003o000000;o00004oooool2o`0000?ooooo0_l00007
ooooo`Co00001_ooool2o`0000Oooooo1?l0000;ooooo`;o00000oooool4o`0005?ooooo000Loooo
o`03o`000?oooooooooo03gooooo0_l00004ooooo`;o00006oooool3o`0000Gooooo4_l000000ooo
oooo0000o`000003o`0000;ooooo0_l00003ooooo`?o00001?ooool3o`0000[ooooo0_l000001?oo
oooo0000o`000?l00002ooooo`;o000000?oooooo`000?l000000_l0000Cooooo`;o00003?ooool4
o`0000Cooooo1?l00004ooooo`;o000000?oooooo`000?l000001?l0000>ooooo`Co00008?ooool2
o`00037ooooo000Looooo`03o`000?oooooooooo033ooooo0_l00009ooooo`;o00003_ooool2o`00
00Cooooo0_l000000ooooooo0000o`00000Dooooo`;o00000oooool?o`000003ooooool0003o0000
00?o00001?ooool2o`0000Cooooo0_l00002ooooo`;o00001oooool2o`000004ooooool0003o0000
o`0000;ooooo0_l0000Looooo`Co00001Oooool2o`000003ooooool0003o000000Cooooo0_l00006
ooooo`;o00001Oooool2o`0001Oooooo0_l00003ooooo`;o00005?ooool2o`00037ooooo000Loooo
o`03o`000?oooooooooo033ooooo0_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`00
0?l000003_ooool2o`0000Cooooo0_l000000ooooooo0000o`00000;ooooo`?o00001_ooool4o`00
0003ooooool0003o000000go000000Coooooo`000?l0003o00001_ooool2o`0000Sooooo1?l00008
ooooo`;o00001Oooool2o`0000Oooooo0_l00009ooooo`;o00001?ooool6o`0000;ooooo0_l00000
0ooooooo0000o`000007ooooo`;o00009_ooool2o`0000?ooooo0_l0000?ooooo`;o0000=_ooool0
01cooooo00?o0000ooooooooool0;Oooool2o`0000Cooooo0_l00003ooooo`;o00001Oooool2o`00
00Wooooo0_l0000Eooooo`?o000000?oooooo`000?l000000ooooolJo`0000;ooooo1?l0000:oooo
o`;o00002?ooool2o`0000Gooooo0_l00006ooooo`?o00002Oooool2o`0000Cooooo0_l00006oooo
o`;o00007oooool2o`0000[ooooo0_l0000:ooooo`?o00002?ooool2o`0000Cooooo0_l0000foooo
o`007?ooool00ol0003oooooooooo`0]ooooo`;o00001_ooool2o`0000Sooooo0_l00009ooooo`;o
00004?ooool2o`0000Oooooo0_l000001?oooooo0000o`000?oooolIo`0000;ooooo0_l0000Moooo
o`;o00001_ooool2o`0000Kooooo0_l00003ooooo`;o00003?ooool2o`0000;ooooo0_l00009oooo
o`;o000000?oooooo`000?l000000_l0000:ooooo`Co000000?oooooo`000?l000001Oooool2o`00
00Gooooo0_l00004ooooo`;o00002?ooool2o`0003cooooo00001_ooooook^k^oc8b<_l0003o<S8b
onk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003ooooooooo
o`0eooooo`?o00001Oooool2o`0000gooooo0_l00007ooooo`;o00001Oooool2o`0000;ooooo0_l0
0002ooooo`?o000000?oooooo`000?l000005ol0000Gooooo`;o00001Oooool2o`000003ooooool0
003o000000;ooooo0_l0000=ooooo`;o00000oooool2o`0000Sooooo0_l00002ooooo`;o00000_oo
ool2o`0000Kooooo1Ol000000ooooooo0000o`000002o`0000cooooo0_l000000ooooooo0000o`00
000<ooooo`?o0000Boooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo
00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo03Kooooo1Ol00002ooooo`;o
00001?ooool2o`0000Oooooo0_l00007ooooo`;o00001oooool4o`0000;ooooo3_l000001?oooooo
0000o`000?l00002ooooo`So000000?oooooo`000?l000001?ooool2o`000003ooooool0003o0000
00Wooooo0_l000000ooooooo0000o`000004ooooo`?o000000?oooooo`000?l000000_ooool2o`00
01;ooooo1Ol00005ooooo`;o00000_ooool4o`0000Sooooo0ol0000Eooooo`;o00003_ooool2o`00
00;ooooo0_l00017ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0eooooo`Oo00001oooool2o`00
013ooooo0ol00006ooooo`;o00001_ooool5o`000003ooooool0003o000001;o000000Coooooo`00
0?l0003ooooo1Ol000001?oooooo0000o`000?l00008ooooo`;o00001oooool2o`0001?ooooo0_l0
0006ooooo`Co00001Oooool2o`000003ooooool0003o000000?o00003_ooool2o`0000Oooooo0_l0
00000ooooooo0000o`000004ooooo`;o00001_ooool4o`0000Cooooo0_l00002ooooo`?o0000A_oo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oV9RHoooooonH
V9So8B4Q00Kooooo0ol0000eooooo`?o00000_ooool2o`0001Wooooo0ol0000>ooooob;o00000ooo
ool2o`0000oooooo0_l0000<ooooo`;o00000_ooool2o`000003ooooool0003o000000;o00000_oo
ool2o`0000cooooo1?l0000Aooooo`;o00001Oooool4o`000003ooooool0003o000000?ooooo0_l0
00000ooooooo0000o`000004ooooo`Co00000_ooool4o`0000?ooooo0_l00004ooooo`;o00001?oo
ool4o`0003Sooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000
oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo03Kooooo0_l00003ooooo`;o00001Ooo
ool2o`0001[ooooo0_l00005oooooaKo000000?oooooo`000?l000002_l00003ooooo`;o00002?oo
ool2o`0000Cooooo0ol0000<ooooo`;o000000?oooooo`000?l000001_l000000ooooooo0000o`00
0003o`000003ooooool0003o000000Oooooo0_l000000ooooooo0000o`00000=ooooo`?o00001Ooo
ool4o`0000Sooooo1Ol0000:ooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo0_l0
0004ooooo`Co0000>?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool0
0omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo03_ooooo0_l00004ooooo`?o00001Oooool2
o`0001?ooooo0_l00005ooooobGo00001Oooool2o`0000Cooooo0_l000001?oooooo0000o`000?oo
ool2o`000003ooooool0003o000000cooooo4_l00008ooooo`Co00003Oooool3o`0000Cooooo1Ol0
0002ooooo`;o00001Oooool4o`0000gooooo0_l00004ooooo`;o0000A?ooool00006oooooomgMgOo
V9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo047ooooo
0ol00002ooooo`;o000000?oooooo`000?l000004Oooool2o`0000Kooooo0_l000000ooooooo0000
o`00000Ko`0000;ooooo1?l00005ooooo`;o00000_ooool4o`000004ooooool0003o0000ooooo`;o
000000?oooooo`000?l000000_l00003ooooo`;o00001?oooolDo`0000Oooooo0_l0000<ooooo`Co
00001_ooool2o`0000Gooooo0_l00006ooooo`;o00001_ooool2o`0000?ooooo0_l000000ooooooo
0000o`00001:ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co0000
oa0@40Kooooo00?o0000ooooooooool0>?ooool2o`0000cooooo0_l000000ooooooo0000o`000002
ooooo`;o00003Oooool2o`0000Kooooo0_l000000ooooooo0000o`00000=o`000003ooooool0003o
000000_o00003oooool2o`0000_ooooo0_l00003ooooo`;o00000ooooolEo`0001Gooooo1Ol0000D
ooooo`Co00001?ooool2o`0000?ooooo0_l000000ooooooo0000o`000003o`0000_ooooo0_l0000j
ooooo`007?ooool00ol0003oooooooooo`0hooooo`?o00003_ooool2o`0000;ooooo1?l0000@oooo
o`;o000000?oooooo`000?l000007_l000000ooooooo0000o`00000Eooooo`;o00001Oooool2o`00
00Gooooo0_l000000ooooooo0000o`00000@o`000003ooooool0003o000001Gooooo0_l000000ooo
oooo0000o`000005ooooo`;o00002_ooool5o`0000?ooooo1?l00005ooooo`Co00002oooool2o`00
03[ooooo000Looooo`03o`000?oooooooooo03Wooooo0_l00002ooooo`;o00003_ooool6o`0000Go
oooo0_l00007ooooo`;o000000?oooooo`000?l000007_l000000ooooooo0000o`00000@ooooo`;o
00000oooool2o`0000Gooooo0_l00005ooooo`;o000000?oooooo`000?l000004?l000000ooooooo
0000o`000003ooooo`;o00004oooool2o`0000Gooooo0ol00007ooooo`;o00000oooool2o`0000Go
oooo0_l0000:ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0?Oooool2o`0000_ooooo
0_l000001?oooooo0000o`000?ooool3o`0000Gooooo0_l00004ooooo`;o00000oooool2o`0000?o
oooo7_l0000Aooooo`;o00002?ooool2o`0000Oooooo6?l00003ooooo`;o00005oooool2o`0000;o
oooo0_l00007ooooo`;o00000_ooool2o`0000Oooooo0_l00003ooooo`;o00001?ooool2o`0000So
oooo0_l0000jooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00002?ooool2o`0000Cooooo
0_l00002ooooo`;o00002?ooool2o`0000?ooooo9?l000000ooooooo0000o`00000>ooooo`;o0000
1oooool2o`0000Gooooo6_l0000Looooo`;o00000_ooool2o`0000Sooooo0_l000000ooooooo0000
o`000007ooooo`?o00000_ooool2o`0000kooooo0_l0000jooooo`007?ooool00ol0003ooooooooo
o`10ooooo`?o00000oooool2o`0000[ooooo1?l0000?oooooaoo000000Coooooo`000?l0003ooooo
0_l00003ooooo`;o00002Oooool2o`0000Cooooo0_l00002ooooo`;o00001?ooool6o`000003oooo
ool0003o000001;o00001?ooool3o`000003ooooool0003o000001Gooooo0_l00002ooooo`;o0000
1?ooool2o`0000[ooooo0ol0001>ooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00000_oo
ool2o`0000?ooooo0_l0000:ooooo`;o00001?ooool2o`0000cooooo7?l00005ooooo`;o00001?oo
ool2o`0000gooooo1?l00002ooooo`;o00001OoooolJo`0000;ooooo1Ol000000ooooooo0000o`00
000Dooooo`;o00000oooool2o`0001?ooooo0_l0000:ooooo`;o0000@?ooool001cooooo00?o0000
ooooooooool0?Oooool4o`0001Oooooo0_l00005ooooo`;o00001_oooolKo`0000Gooooo0_l00006
ooooo`;o00002oooool2o`000003ooooool0003o000000Gooooo3Ol000000ooooooo0000o`00000>
o`000003ooooool0003o000001[ooooo0_l00004ooooo`?o00004Oooool2o`0000[ooooo0_l00000
0ooooooo0000o`00000mooooo`007?ooool00ol0003oooooooooo`0oooooo`Co00000oooool2o`00
01Oooooo0_l00005oooooaKo00000_ooool4o`0000gooooo0_l0000;ooooo`;o000000?oooooo`00
0?l000000oooool?o`000003ooooool0003o000000_o000000?oooooo`000?l000008oooool3o`00
00oooooo0_l0000?ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0?_ooool5o`0000?o
oooo0ol0000Looooo`Go000000?oooooo`000?l000005Ol0000@ooooo`;o00003?ooool2o`0000;o
oooo0_l000000ooooooo0000o`00000Eo`000003ooooool0003o000000Go00004_ooool2o`0000[o
oooo0_l00006ooooo`;o00002?ooool2o`000003ooooool0003o000000cooooo0_l00010ooooo`00
7?ooool00ol0003oooooooooo`0eooooo`;o00001oooool4o`0000Gooooo0_l0000<ooooo`;o0000
2Oooool2o`0000?ooooo0_l000001?oooooo0000o`000?oooolDo`0000?ooooo0_l0000>ooooo`;o
00003?ooool2o`0000Gooooo7ol00003ooooo`;o00003Oooool2o`0000[ooooo0_l00006ooooo`;o
00001oooool3o`0000oooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0eooooo`;o0000
00?oooooo`000?l000002oooool2o`0000Oooooo0_l00005ooooo`;o00002?ooool3o`0000?ooooo
0_l00002oooooa?o000000?oooooo`000?l000000oooool2o`0000_ooooo0ol000000ooooooo0000
o`00000>ooooo`;o00000_oooolIo`000003ooooool0003o000000Kooooo0_l0000:ooooo`;o0000
5?ooool3o`0000Oooooo0_l0001Booooo`007?ooool2o`0003Wooooo0_l0000;ooooo`;o00001ooo
ool2o`0000Oooooo0_l00006ooooo`;o00002?oooolCo`0001?ooooo0ol000000ooooooo0000o`00
000>ooooo`;o00000_oooolLo`0000Kooooo0_l00002ooooo`;o00001_ooool2o`0001Cooooo0_l0
001Looooo`007?ooool00ol0003oooooooooo`13ooooo`Co00001?ooool2o`0000?ooooo0_l00004
ooooo`?o00004_oooolBo`0000Gooooo0_l0000;ooooo`;o00000_ooool2o`0000Gooooo0_l0000;
oooooa;o000000?oooooo`000?l000000_l000000ooooooo0000o`00000<ooooo`;o00001?ooool4
o`00013ooooo1?l0001Nooooo`007?ooool00ol0003oooooooooo`13ooooo`Co00001?ooool2o`00
00?ooooo0_l00004ooooo`?o000000?oooooo`000?l000002Oooool2o`0000?ooooo0ol00002oooo
o`oo000000Coooooo`000?l0003ooooo0ol00008ooooo`Co00002Oooool3o`0000_ooooo6Ol0000:
ooooo`?o00001Oooool4o`0000_ooooo0_l00003ooooo`Co00001?ooool2o`0000;ooooo0_l00000
1?oooooo0000o`000?l0001@ooooo`007?ooool00ol0003oooooooooo`1?ooooo`Co00001?ooool2
o`000003ooooool0003o000000Cooooo0_l00003ooooo`Oo00000oooool5o`0000;ooooo0ol00000
0ooooooo0000o`000009o`0000Kooooo1?l00004ooooo`;o00001_ooool3o`0000[ooooo6Ol00008
ooooo`Go00000_ooool2o`0000Cooooo0_l00003ooooo`;o00001Oooool2o`0000?ooooo1?l00000
1?oooooo0000o`000?ooool2o`0000;ooooo0_l000001?oooooo0000o`000?l0000:ooooo`;o0000
A?ooool001cooooo00?o0000ooooooooool0??ooool2o`0000?ooooo0_l00005ooooo`;o00001Ooo
ool4o`0000gooooo0_l00005ooooo`Co000000?oooooo`000?l000000_ooool4o`0000;ooooo0ol0
00000ooooooo0000o`000008o`000003ooooool0003o000000Cooooo1?l00004ooooo`;o00001ooo
ool2o`0000[ooooo5ol00002ooooo`;o00001_ooool2o`000003ooooool0003o000000Co00001?oo
ool2o`0000?ooooo1?l00008ooooo`Co000000?oooooo`000?l000002Oooool2o`0000[ooooo0_l0
0014ooooo`007?ooool00ol0003oooooooooo`0looooo`;o00000oooool3o`0000Cooooo0_l0000:
ooooo`;o00002Oooool2o`0000?ooooo0ol00002ooooo`;o000000?oooooo`000?l000000_ooool4
o`0000;ooooo0_l00002ooooo`Co000000Coooooo`000?l0003ooooo0_l000001?oooooo0000o`00
0?ooool2o`0000_ooooo0_l0000;ooooo`;o00001OoooolFo`0000;ooooo0_l00004ooooo`;o0000
1Oooool2o`0000gooooo0_l00003ooooo`;o00003_ooool2o`0005Gooooo000Looooo`03o`000?oo
oooooooo04;ooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l00006ooooo`;o0000
2Oooool2o`0000?ooooo1_l00002ooooo`;o00000_ooool2o`0000Oooooo1Ol000000ooooooo0000
o`000007ooooo`Co00001?ooool2o`0000?ooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo
0_l00005oooooa?o000000?oooooo`000?l000000ol00005ooooo`;o00000oooool2o`0000;ooooo
0_l00002ooooo`;o00002oooool3o`0000Cooooo0_l00007ooooo`?o0000EOooool001cooooo00?o
0000ooooooooool0A_ooool2o`000004ooooool0003o0000ooooo`;o00005oooool5o`0000;ooooo
0_l00002ooooo`;o00001oooool4o`0000gooooo0_l00004ooooo`;o00002?ooool2o`0000;ooooo
0_l00006oooooaKo00000_ooool4o`0000Gooooo2?l000000ooooooo0000o`000002ooooo`;o0000
2?ooool2o`000003ooooool0003o000000Cooooo1?l00006ooooo`;o00001Oooool2o`0004oooooo
000Looooo`03o`000?oooooooooo04;ooooo0_l00005ooooo`;o00005?ooool2o`0000Cooooo0_l0
000Aooooo`?o00003oooool2o`0000Kooooo0_l0000@ooooo`Oo000000?oooooo`000?l000002ol0
00000ooooooo0000o`000002o`0000_ooooo1_l00003ooooo`?o00002Oooool2o`0000;ooooo0_l0
00000ooooooo0000o`000004o`0000gooooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`12
ooooo`;o00001Oooool4o`000003ooooool0003o000000Kooooo0_l00003ooooo`;o00000_ooool5
o`0001Cooooo0_l00002ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00001?ooool2
o`000003ooooool0003o000000;o00001Oooool2o`0000Oooooo3?l00003ooooo`;o00000_ooool2
o`0000Wooooo0_l000000ooooooo0000o`000002ooooo`Go00002oooool2o`000003ooooool0003o
000000Co00008?ooool2o`0003cooooo000Looooo`03o`000?oooooooooo04Wooooo1?l000000ooo
oooo0000o`000006ooooo`;o00000oooool2o`0000?ooooo1?l0000Hooooo`;o00001Oooool2o`00
01;ooooo2_l00003ooooo`;o00002?ooool7o`000003ooooool0003o000000?o00001Oooool2o`00
00cooooo0_l00003ooooo`Co0000=?ooool2o`0003cooooo000Looooo`03o`000?oooooooooo04Go
oooo1?l00002ooooo`?o00004_ooool2o`0000Wooooo0_l0000Zooooo`Co00001?ooool2o`0000?o
oooo0_l00004ooooo`;o00000_ooool2o`000003ooooool0003o000000;o000000Coooooo`000?l0
003ooooo0_l00005ooooo`;o00004Oooool5o`0000Wooooo0_l0000Eooooo`;o000000?oooooo`00
0?l00000C?ooool001cooooo00?o0000ooooooooool0AOooool4o`0000;ooooo1?l000001?oooooo
0000o`000?l0000;ooooo`Co00002Oooool2o`0000?ooooo0_l00007ooooo`;o00001_ooool2o`00
00Gooooo0_l00003ooooo`;o00000oooool2o`0000?ooooo0ol0000:ooooo`;o00001?ooool2o`00
01Cooooo0_l0000;ooooo`;o00001?ooool5o`0000Oooooo1?l00005ooooo`;o00001?ooool2o`00
00Sooooo0_l000000ooooooo0000o`00001<ooooo`007?ooool00ol0003oooooooooo`13ooooo`;o
00002?ooool2o`000004ooooool0003o0000o`0000;ooooo0_l00007ooooo`;o00002Oooool2o`00
00Gooooo0_l000000ooooooo0000o`000004ooooo`;o00001_ooool2o`0000Gooooo0_l00002oooo
o`?o00000oooool2o`0001[ooooo0_l0000Cooooo`;o00002?ooool2o`0000Cooooo0ol00009oooo
o`;o00001oooool2o`0000Cooooo0_l0001Iooooo`007?ooool00ol0003oooooooooo`13ooooo`;o
00002oooool2o`0000?ooooo1Ol0000?ooooo`;o00001Oooool2o`000003ooooool0003o000000Go
oooo0_l00006ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00001Oooool2o`00
01Cooooo0_l00003ooooo`;o00004oooool2o`0000_ooooo3?l00009ooooo`Go00004oooool2o`00
00Oooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00000_ooool2o`0000Co
oooo1?l0000;ooooo`;o00002Oooool2o`0000Oooooo0ol00004ooooo`Co000000?oooooo`000?l0
00000ol00009ooooo`Go00000oooool2o`0000cooooo0_l00005ooooo`;o00002oooool2o`0000Co
oooo0_l00007oooooa3o00002Oooool4o`0000oooooo0_l000000ooooooo0000o`000002o`0000Oo
oooo0_l00011ooooo`007?ooool2o`0004gooooo0_l00009ooooo`;o00003?ooool2o`0000Oooooo
0_l00009ooooo`;o000000Coooooo`000?l0003ooooo0ol00005ooooo`;o00002oooool6o`000003
ooooool0003o000000Sooooo0_l00009ooooo`Co00001_ooool2o`000003ooooool0003o000000co
oooo1_l00004ooooo`;o00004?ooool2o`0000oooooo0_l000000ooooooo0000o`00001<ooooo`00
7?ooool00ol0003oooooooooo`1Gooooo`;o00003_ooool2o`0000Gooooo1?l00002ooooo`;o0000
1Oooool3o`000003ooooool0003o000001Oooooo0_l0000:ooooo`?o000000?oooooo`000?l00000
2?ooool4o`0000Cooooo0_l0000<ooooo`Wo00001oooool2o`00013ooooo0ol000001?oooooo0000
o`000?ooool2o`0005Kooooo000Looooo`03o`000?oooooooooo057ooooo0_l000000ooooooo0000
o`00000:ooooo`;o00001Oooool2o`0000Kooooo0ol00002ooooo`;o000000Goooooo`000?l0003o
0000ooooo`02o`0000;ooooo0_l00002ooooo`;o00007oooool2o`0000;ooooo1?l00008ooooo`;o
00002_ooool2o`0000Gooooo3?l000001?oooooo0000o`000?ooool3o`0000?ooooo0_l0000;oooo
o`?o000000Coooooo`000?l0003ooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`1?oooo
o`Co000000?oooooo`000?l000001_ooool2o`0000;ooooo0_l00002ooooo`;o00001?ooool2o`00
0003ooooool0003o000000Sooooo1_l00002ooooo`Ko00002Oooool2o`0001[ooooo0_l00006oooo
o`Co00002_ooool2o`0000Gooooo0_l000000ooooooo0000o`000002o`0000;ooooo0ol000001?oo
oooo0000o`000?ooool2o`0000Cooooo0_l0000Rooooo`;o0000A_ooool001cooooo00?o0000oooo
ooooool0Coooool4o`0000Wooooo0_l00003ooooo`;o000000?oooooo`000?l000001?ooool5o`00
00;ooooo0_l000000ooooooo0000o`000004ooooo`Co00000oooool2o`0000;ooooo0_l00002oooo
o`;o00000oooool2o`0002;ooooo1?l000000ooooooo0000o`000002o`0000;ooooo0_l00005oooo
o`;o000000?oooooo`000?l000000ol00007ooooo`;o00000_ooool2o`0000;ooooo0_l0000Toooo
o`;o0000A_ooool001cooooo00?o0000ooooooooool0DOooool2o`0000Sooooo0_l00004ooooo`;o
00001?ooool2o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Oo
oooo0_l00002ooooo`;o00001?ooool2o`00017ooooo0_l0000Cooooo`So000000?oooooo`000?l0
00002?l00009ooooo`;o00000_ooool2o`0000;ooooo1?l00005ooooo`;o0000Hoooool001cooooo
00?o0000ooooooooool0Aoooool2o`0000_ooooo0_l00005ooooo`;o00000oooool2o`0000Gooooo
0_l0000Oooooo`?o00001?ooool3o`00013ooooo0_l0000>ooooo`;o00001Oooool6o`000003oooo
ool0003o000000;o00000_ooool2o`0000cooooo0_l00005ooooo`Ko00000oooool2o`0006?ooooo
000Looooo`03o`000?oooooooooo04Oooooo0_l0000;ooooo`;o00002_ooool2o`000003ooooool0
003o000001?ooooo0_l0000<ooooo`Go00000_ooool2o`000003ooooool0003o0000023ooooo1?l0
0002ooooo`;o00004Oooool2o`0000Oooooo0_l00005ooooo`;o00000_ooool2o`0006Sooooo000L
ooooo`03o`000?oooooooooo05Gooooo0_l0000<ooooo`;o00000_ooool2o`0000oooooo0_l00004
ooooo`;o00001_ooool5o`0000;ooooo0_l0000?ooooo`;o00003?ooool4o`0000Cooooo1_l00004
ooooo`;o00002oooool2o`0000Oooooo0_l00002ooooo`;o0000Koooool001cooooo00?o0000oooo
ooooool0EOooool2o`0000?ooooo0ol0000:ooooo`;o00003oooool2o`0000Cooooo0_l00007oooo
o`Co00004oooool2o`0000Oooooo0_l00003ooooo`Co00001_ooool2o`0000Kooooo0_l00002oooo
o`;o000000?oooooo`000?l000001?ooool3o`0000Kooooo0_l00002ooooo`;o000000Coooooo`00
0?l0003o00000_ooool2o`0006Oooooo000Looooo`03o`000?oooooooooo05[ooooo0ol0000@oooo
o`;o00001oooool2o`0000;ooooo0_l0000;ooooo`Co00004_ooool3o`0000Oooooo0_l0000=oooo
o`Co00002?ooool2o`000003ooooool0003o000000Cooooo0ol00006ooooo`;o00001Oooool3o`00
00;ooooo0_l000000ooooooo0000o`000006ooooo`;o0000G?ooool001cooooo00?o0000oooooooo
ool0E?ooool2o`0000_ooooo0_l0000:ooooo`;o00001oooool3o`000003ooooool0003o000000?o
00002?ooool3o`0001?ooooo0_l000000ooooooo0000o`000009ooooo`;o00001?ooool2o`0000?o
oooo1?l00008ooooo`;o00006Oooool3o`0000?ooooo0_l00002ooooo`;o00000_ooool4o`0005[o
oooo000Looooo`03o`000?oooooooooo05Cooooo0_l00004ooooo`;o00001Oooool2o`0001Cooooo
0_l00003ooooo`?o00001_ooool2o`0001Wooooo0_l00009ooooo`;o00001?ooool2o`0000Wooooo
0_l00002ooooo`Co00001?ooool2o`0001?ooooo0ol00007ooooo`;o00001?ooool2o`0005[ooooo
000Looooo`03o`000?oooooooooo04cooooo0_l00006ooooo`Co00000_ooool2o`0000Kooooo0_l0
000@ooooo`Co00003Oooool2o`0000Wooooo0_l0000Nooooo`Co00002?ooool2o`0000;ooooo0_l0
0006ooooo`;o00002?ooool2o`0000gooooo1?l0001Tooooo`007?ooool00ol0003oooooooooo`19
ooooo`;o000000?oooooo`000?l000001oooool4o`0000Wooooo0_l0000@ooooo`Ko00000oooool2
o`0000Gooooo0_l00006ooooo`;o00000_ooool2o`0000[ooooo0_l00005ooooo`;o00002oooool4
o`0000Wooooo0_l00009ooooo`;o00000_ooool2o`0000Cooooo0_l00002ooooo`;o00002Oooool4
o`0006Cooooo000Looooo`03o`000?oooooooooo04Wooooo0_l0000:ooooo`Go00002_ooool2o`00
00Wooooo0_l00007ooooo`;o00000oooool2o`0000Gooooo0_l00005ooooo`?o00000oooool2o`00
00Cooooo1?l000001?oooooo0000o`000?l00004ooooo`;o00001oooool2o`0000;ooooo0ol00004
ooooo`;o00001?ooool2o`0000Wooooo0_l00002ooooo`Co00001_ooool2o`0000Oooooo1?l0001V
ooooo`007?ooool2o`0005Wooooo0_l00007ooooo`;o000000?oooooo`000?l000002Oooool2o`00
00cooooo0_l00002ooooo`;o00001Oooool2o`000003ooooool0003o000000Cooooo0_l00004oooo
o`Co000000Coooooo`000?l0003o00001?ooool2o`0000Oooooo0_l00003ooooo`;o00001?ooool2
o`000004ooooool0003o0000ooooo`;o00003_ooool3o`0000oooooo1?l0001Vooooo`007?ooool0
0ol0003oooooooooo`1Iooooo`;o00001_ooool2o`0000;ooooo0_l00003ooooo`;o000000?ooooo
o`000?l000004_ooool2o`0000Gooooo0_l00008ooooo`;o00001?ooool2o`0000Cooooo0_l0000J
ooooo`;o000000?oooooo`000?l000006?ooool2o`0000Wooooo1?l0001Sooooo`007?ooool00ol0
003oooooooooo`1Iooooo`;o00001_ooool3o`000003ooooool0003o000000?ooooo0_l000000ooo
oooo0000o`00000Fooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo0ol000001?oo
oooo0000o`000?ooool2o`0000Cooooo0_l0000<ooooo`;o00003?ooool2o`00013ooooo0_l00009
ooooo`;o00002Oooool4o`0006?ooooo000Looooo`03o`000?oooooooooo06;ooooo1Ol0000Noooo
o`;o00000oooool5o`0000;ooooo0ol000001?oooooo0000o`000?ooool2o`0001;ooooo0_l0000L
ooooo`Co0000Noooool001cooooo00?o0000ooooooooool0F_ooool4o`0000Cooooo1Ol0000Noooo
o`?o00001?ooool2o`0000oooooo0_l000000ooooooo0000o`00000Fooooo`;o00004?ooool2o`00
07gooooo000Looooo`03o`000?oooooooooo05[ooooo1Ol00002ooooo`;o00006Oooool2o`0000So
oooo0_l0000:ooooo`;o00001Oooool2o`0000;ooooo0_l000001?oooooo0000o`000?l0000>oooo
o`;o00001Oooool2o`0001cooooo0_l0001aooooo`007?ooool00ol0003oooooooooo`1Jooooo`;o
000000?oooooo`000?l000000_ooool2o`0000Kooooo0_l0000Aooooo`;o00000oooool2o`0000Oo
oooo0_l00006ooooo`;o00000_ooool2o`000003ooooool0003o000000Kooooo0_l00005ooooo`;o
00001oooool2o`0000[ooooo0_l0000<ooooo`?o00002?ooool2o`00077ooooo000Looooo`03o`00
0?oooooooooo05_ooooo0_l00002ooooo`;o00000_ooool2o`0000Cooooo1?l0000>ooooo`;o0000
1?ooool2o`0000Gooooo1?l0000:ooooo`;o00001oooool2o`0000Oooooo0_l0000=ooooo`;o0000
1?ooool2o`0000Cooooo0ol00002ooooo`Ko00004oooool2o`0006Kooooo000Looooo`03o`000?oo
oooooooo05_ooooo0_l00002ooooo`Oo00001Oooool2o`0000kooooo0_l00009ooooo`Go00002Ooo
ool2o`0000Oooooo1?l0000Eooooo`?o00001_ooool2o`0000;ooooo0ol00002ooooo`?o00001_oo
ool2o`0000_ooooo0_l000000ooooooo0000o`00000<ooooo`;o0000F?ooool001cooooo00?o0000
ooooooooool0H?ooool6o`0000;ooooo0_l00007ooooo`?o00001oooool2o`0000Gooooo0_l00002
ooooo`Go00001_ooool2o`000003ooooool0003o000000Gooooo1_l0000Aooooo`?o000000?ooooo
o`000?l000001oooool5o`0000gooooo0_l00003ooooo`;o00000oooool2o`000003ooooool0003o
000000oooooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`1Xooooo`;o00000_ooool2o`00
00?ooooo0ol0000>ooooo`;o00000oooool2o`0000Kooooo1?l00008ooooo`;o00000oooool2o`00
00_ooooo0_l00003ooooo`?o00002oooool4o`0000Cooooo0ol00006ooooo`;o00000_ooool3o`00
00?ooooo0_l0001/ooooo`007?ooool00ol0003oooooooooo`1Rooooo`;o00001?ooool2o`0000;o
oooo0_l0000Iooooo`;o00001_ooool2o`0000_ooooo0_l00002ooooo`;o00002oooool2o`0000Wo
oooo0ol0000=ooooo`?o00001_ooool2o`0000;ooooo0_l0001booooo`007?ooool00ol0003ooooo
ooooo`1Mooooo`Co000000?oooooo`000?l000000_ooool4o`0000[ooooo0_l0000>ooooo`?o0000
5Oooool2o`00013ooooo1Ol00002ooooo`;o000000Coooooo`000?l0003o00001_ooool2o`0000Wo
oooo0ol00002ooooo`;o00006_ooool2o`0005[ooooo000Looooo`03o`000?oooooooooo05gooooo
1ol00002ooooo`;o00003?ooool2o`0000cooooo1_l0000Vooooo`Go00000_ooool2o`000003oooo
ool0003o000000Oooooo0_l00009ooooo`?o00006Oooool2o`0000?ooooo0_l0001Jooooo`0000Ko
ooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<
00Kooooo00?o0000ooooooooool0HOooool3o`0000Cooooo0ol0000Gooooo`;o00000_ooool2o`00
00Sooooo0_l00007ooooo`;o00002Oooool2o`000003ooooool0003o000000oooooo0_l0000Aoooo
o`?o000000?oooooo`000?l000005oooool2o`0005oooooo00001_ooooooMgMgoiRHV?ooooooV9RH
ogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003ooooooooo
o`1Qooooo`?o00001?ooool3o`0001_ooooo0_l00006ooooo`Co00001oooool4o`0000Oooooo0_l0
00000ooooooo0000o`00000?ooooo`;o00002Oooool2o`0000Kooooo0ol000000ooooooo0000o`00
001hooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`1Qooooo`?o00003Oooool2o`0001_ooooo0_l0
00000ooooooo0000o`000008ooooo`;o00004Oooool2o`0000[ooooo0_l00007ooooo`;o00001_oo
ool2o`0007cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8b
oiRHV?ooooooV9RHoc8b<P06ooooo`?o0000I_ooool2o`0000Wooooo0_l00002ooooo`;o00004Ooo
ool3o`0000Kooooo0_l0000Kooooo`Co00002?ooool2o`0000cooooo0_l0001oooooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_oo
ool00ol0003oooooooooo`1Qooooo`;o00000oooool2o`0000gooooo1_l000000ooooooo0000o`00
0003ooooo`;o00001Oooool3o`0000Oooooo0_l00007ooooo`;o00001_ooool3o`0000;ooooo0_l0
0006ooooo`;o00002_ooool2o`0000Gooooo0ol00002ooooo`;o0000Ooooool00003ooooool@413o
oooo00;ooooo00?o410@ooooooooool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o
0000ooooooooool0Goooool4o`0000Kooooo0_l0000;ooooo`Go000000?oooooo`000?l000000ooo
ool2o`0000Kooooo0_l000000ooooooo0000o`000002ooooo`Co00001oooool2o`000003ooooool0
003o000000?ooooo0ol00002ooooo`;o00004_ooool2o`0000Gooooo0ol00023ooooo`0000Kooooo
ogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003o
ooooooooo`1Oooooo`;o00002?ooool2o`0000Kooooo0_l0000=ooooo`;o000000Coooooo`000?l0
003ooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00009ooooo`;o000000?ooooo
o`000?l000009oooool2o`0001Cooooo1?l0001Xooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^
k^h;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`1^ooooo`;o0000
00?oooooo`000?l000001?ooool2o`0000Kooooo0ol000001?oooooo0000o`000?ooool2o`0001?o
oooo0_l0000Fooooo`;o00000_ooool2o`0000kooooo0_l0000Dooooo`Co0000J?ooool001cooooo
00?o0000ooooooooool0K_ooool5o`0000Cooooo0ol00005ooooo`;o00000oooool4o`0000Kooooo
0_l0000=ooooo`;o00002Oooool2o`000003ooooool0003o000000Gooooo0ol00002ooooo`Co0000
3?ooool2o`00083ooooo000Looooo`03o`000?oooooooooo073ooooo0ol00005ooooo`;o00002_oo
ool4o`0000Cooooo1?l0000=ooooo`;o00002Oooool2o`000003ooooool0003o000000Gooooo0_l0
0005ooooo`;o0000S_ooool001cooooo00?o0000ooooooooool0S?ooool2o`0000;ooooo0ol00009
ooooo`;o000000?oooooo`000?l000004?ooool2o`0000Kooooo0_l00004ooooo`;o00003Oooool2
o`0000Gooooo0_l0001booooo`007?ooool00ol0003oooooooooo`1iooooo`;o00005Oooool3o`00
00Wooooo0_l000000ooooooo0000o`00000@ooooo`;o00003?ooool2o`0000gooooo0_l00005oooo
o`Co0000L?ooool001cooooo00?o0000ooooooooool0NOooool2o`0000Oooooo0_l00004ooooo`;o
00001oooool2o`0000Oooooo0_l0000Jooooo`;o00007oooool2o`00073ooooo000Looooo`03o`00
0?oooooooooo08;ooooo0ol00003ooooo`;o00002?ooool2o`0000Kooooo0_l00003ooooo`;o0000
1oooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o000000?oooooo`000?l00000
5Oooool2o`0007[ooooo000Looooo`03o`000?oooooooooo08?ooooo0_l00008ooooo`;o00000ooo
ool2o`0000_ooooo0_l00007ooooo`Go00000_ooool2o`0000;ooooo1?l0000Fooooo`;o0000N_oo
ool001cooooo00?o0000ooooooooool0SOooool2o`00013ooooo0_l00006ooooo`;o000000Cooooo
o`000?l0003o00000_ooool4o`0000;ooooo0_l0002Booooo`007?ooool00ol0003oooooooooo`2O
ooooo`;o00001_ooool2o`000004ooooool0003o0000o`0000;ooooo1_l0000Mooooo`;o0000MOoo
ool001cooooo00?o0000ooooooooool0L_ooool2o`0001Kooooo0_l0000Booooo`;o00002_ooool2
o`0000Oooooo0_l0000Mooooo`;o0000MOooool001cooooo00?o0000ooooooooool0L_ooool2o`00
01Kooooo0_l0000>ooooo`Ko00002_ooool2o`0002Gooooo0_l0001fooooo`007?ooool2o`0009_o
oooo1_l00002ooooo`;o0000;Oooool2o`0007Kooooo000Looooo`03o`000?oooooooooo09_ooooo
0_l000000ooooooo0000o`000002ooooo`;o0000YOooool001cooooo00?o0000ooooooooool0Y_oo
ool2o`000:7ooooo000Looooo`03o`000?oooooooooo0:Kooooo0_l0002Qooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0<_ooooo0_l0001looooo`00
7?ooool00ol0003oooooooooo`3;ooooo`Co0000N_ooool001cooooo00?o0000ooooooooool0cOoo
ool2o`0007[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0Loooool2o`000=Cooooo000Looooo`03o`000?oooooooooo07?ooooo0_l0003Dooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo09Oooooo0_l0002`ooooo`007?ooool2o`0009Sooooo
0_l0002`ooooo`007?ooool00ol0003oooooooooo`2looooo`;o0000Roooool001cooooo00?o0000
ooooooooool0_?ooool2o`0008_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2=ooooo`;o0000
9?ooool2o`0009Cooooo000Looooo`03o`000?oooooooooo08gooooo0_l0000Tooooo`;o0000U?oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
XOooool2o`000:Kooooo000Looooo`03o`000?oooooooooo0:7ooooo0_l0002Vooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Booooo`Co000000?o410@ooooooooool00oooool00ol0003ooooo
ooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooo
oom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`?o0000oooooom:ooooo`005?ooool00ol0
003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo
00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000B
ooooo`03oeEEEOmVIVKo00000?ooooooE?ooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00:7ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0Fooooo`Co0000
00So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Co410@o`000?m4A4Coc<c<1?oo
ool5o`0008cooooo002Rooooo`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?oV9RHoa0@4?oMgMd0
0oooool01OnHV9So8B4Qonk^k_ooooooA4A408cooooo002Rooooo`05o`000?ooooooooooooooool0
00006oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00on7
QhOoEEEEooooo`03ooooo`03oiRHV?lQ8B7ok^k^08gooooo002Rooooo`05o`000?oooooooooooooo
ool000002Oooool6o`0000cooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Goc<c<ob4Q8Ol0003oEEEEo`000005ooooo`03oiRHV?lQ8B7ok^k^08cooooo002R
ooooo`05o`000?n7QhOoooooojVYZOl000006oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01OlQ8B7oQhN7oooooonHV9So000000Kooooo00?oMgMgofIVI_oo
ool0Roooool00:7ooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Iooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05o`000?oooooooooooooo
ool000001oooool00ol0003oooooooooo`2:ooooo`00`_ooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OlQ8B7oV9RHoooooomgMgOoEEEE00?ooooo00Go0000
okZj^_ooooooV9RHoa0@402<ooooo`00`?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01Oo<c<co410@o`000?lb<S;ok^k^00?ooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c02<ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1098) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.33335 .63149 Mdot
.34747 .60312 Mdot
.64912 .50619 Mdot
.42362 .37309 Mdot
.3592 .75827 Mdot
.66629 .53118 Mdot
.56585 .65721 Mdot
.51089 .64364 Mdot
.64924 .5178 Mdot
.39594 .66189 Mdot
.56163 .65193 Mdot
.4998 .44324 Mdot
.54924 .64648 Mdot
.44372 .37537 Mdot
.20056 .66445 Mdot
.47722 .34923 Mdot
.37736 .56623 Mdot
.6046 .40246 Mdot
.39893 .33751 Mdot
.69 .54104 Mdot
.38529 .62077 Mdot
.43247 .37814 Mdot
.31657 .60451 Mdot
.44421 .37585 Mdot
.41368 .36433 Mdot
.37407 .58943 Mdot
.38979 .56317 Mdot
.39853 .40846 Mdot
.42331 .34931 Mdot
.51322 .65259 Mdot
.50647 .26401 Mdot
.24834 .71729 Mdot
.37157 .37153 Mdot
.65964 .75184 Mdot
.51529 .63553 Mdot
.26878 .55767 Mdot
.64622 .54308 Mdot
.5227 .64281 Mdot
.52205 .63188 Mdot
.5658 .67126 Mdot
.5345 .63426 Mdot
.36801 .59747 Mdot
.48844 .65518 Mdot
.48669 .59878 Mdot
.44398 .33579 Mdot
.41432 .74832 Mdot
.35743 .26686 Mdot
.44139 .42808 Mdot
.38032 .5737 Mdot
.68162 .46214 Mdot
.59179 .75298 Mdot
.57052 .65187 Mdot
.61005 .54048 Mdot
.71975 .80468 Mdot
.52193 .65155 Mdot
.42879 .33348 Mdot
.63461 .53157 Mdot
.43405 .38768 Mdot
.44581 .38041 Mdot
.21098 .4586 Mdot
.39927 .42214 Mdot
.62843 .38412 Mdot
.30792 .61225 Mdot
.5631 .42982 Mdot
.64542 .52909 Mdot
.53422 .62806 Mdot
.34781 .61467 Mdot
.54369 .6511 Mdot
.43536 .46557 Mdot
.64873 .56244 Mdot
.43899 .42756 Mdot
.54724 .63153 Mdot
.3849 .6072 Mdot
.42611 .41579 Mdot
.78004 .51856 Mdot
.15148 .45451 Mdot
.65473 .37043 Mdot
.2399 .5092 Mdot
.20828 .50258 Mdot
.71571 .41748 Mdot
.45675 .35904 Mdot
.55313 .21201 Mdot
.17133 .56439 Mdot
.31872 .58655 Mdot
.36748 .35599 Mdot
.58448 .50851 Mdot
.42615 .41075 Mdot
.34537 .70428 Mdot
.44455 .34088 Mdot
.80698 .55466 Mdot
.65796 .51515 Mdot
.3454 .58159 Mdot
.42567 .37087 Mdot
.39125 .4015 Mdot
.35416 .2891 Mdot
.45136 .44421 Mdot
.40284 .39827 Mdot
.37244 .62229 Mdot
.56496 .63531 Mdot
.51146 .38853 Mdot
.49424 .67154 Mdot
.62543 .51504 Mdot
.46683 .42429 Mdot
.65343 .55563 Mdot
.38711 .60941 Mdot
.42126 .42122 Mdot
.5317 .62189 Mdot
.46875 .41065 Mdot
.53608 .72811 Mdot
.34479 .60548 Mdot
.39075 .39478 Mdot
.63522 .38937 Mdot
.75159 .32222 Mdot
.33904 .58047 Mdot
.73166 .39841 Mdot
.46011 .3558 Mdot
.41208 .39593 Mdot
.34944 .60104 Mdot
.63704 .5075 Mdot
.32312 .69063 Mdot
.31341 .58332 Mdot
.5701 .66938 Mdot
.30794 .60038 Mdot
.36347 .39107 Mdot
.65853 .52207 Mdot
.6349 .70607 Mdot
.6018 .63964 Mdot
.50228 .24522 Mdot
.42763 .40613 Mdot
.4398 .68992 Mdot
.68994 .51956 Mdot
.35441 .58692 Mdot
.5446 .65474 Mdot
.45182 .32039 Mdot
.32785 .6035 Mdot
.54336 .66682 Mdot
.6222 .39853 Mdot
.67307 .65197 Mdot
.35511 .55788 Mdot
.47281 .6207 Mdot
.52449 .61392 Mdot
.56828 .66401 Mdot
.70729 .72994 Mdot
.35424 .61019 Mdot
.60611 .36892 Mdot
.53146 .6602 Mdot
.47399 .2702 Mdot
.39878 .35239 Mdot
.58058 .25019 Mdot
.48546 .16949 Mdot
.67209 .74517 Mdot
.72184 .62107 Mdot
.59483 .35618 Mdot
.57446 .63896 Mdot
.39885 .37219 Mdot
.37951 .59296 Mdot
.36978 .604 Mdot
.41668 .43166 Mdot
.41805 .36994 Mdot
.4327 .42614 Mdot
.38807 .38794 Mdot
.19046 .45952 Mdot
.47704 .4023 Mdot
.42151 .2046 Mdot
.34437 .57646 Mdot
.40548 .37945 Mdot
.62447 .5361 Mdot
.38957 .43454 Mdot
.5374 .63158 Mdot
.42681 .38447 Mdot
.41989 .37501 Mdot
.39537 .41993 Mdot
.57057 .64929 Mdot
.23818 .68363 Mdot
.5565 .18354 Mdot
.29363 .73307 Mdot
.7757 .48368 Mdot
.68119 .53475 Mdot
.41981 .40642 Mdot
.6289 .37282 Mdot
.2938 .52326 Mdot
.46041 .36775 Mdot
.80106 .31073 Mdot
.40863 .38936 Mdot
.31677 .73385 Mdot
.36209 .43443 Mdot
.31593 .76545 Mdot
.55952 .22821 Mdot
.39536 .37113 Mdot
.41551 .29152 Mdot
.3722 .51695 Mdot
.49442 .6011 Mdot
.53624 .63587 Mdot
.62638 .52896 Mdot
.63935 .51832 Mdot
.57951 .67457 Mdot
.36664 .65256 Mdot
.38897 .31521 Mdot
.45308 .45293 Mdot
.61572 .55597 Mdot
.31574 .62902 Mdot
.59065 .37482 Mdot
.35805 .62728 Mdot
.17375 .34554 Mdot
.58208 .74154 Mdot
.5672 .68899 Mdot
.64895 .38538 Mdot
.66751 .50159 Mdot
.61743 .52765 Mdot
.62679 .36438 Mdot
.45784 .41204 Mdot
.35352 .61415 Mdot
.62478 .79201 Mdot
.39757 .63431 Mdot
.67705 .76964 Mdot
.38121 .60707 Mdot
.43419 .63642 Mdot
.5495 .6626 Mdot
.65739 .54669 Mdot
.40898 .39763 Mdot
.45067 .40721 Mdot
.39559 .61144 Mdot
.43616 .42493 Mdot
.33813 .3602 Mdot
.4051 .40772 Mdot
.61905 .72764 Mdot
.65452 .36734 Mdot
.57912 .67485 Mdot
.49097 .23695 Mdot
.32786 .61973 Mdot
.6679 .30775 Mdot
.63227 .55513 Mdot
.27517 .5288 Mdot
.55235 .63246 Mdot
.62625 .39388 Mdot
.63148 .55698 Mdot
.58922 .37345 Mdot
.37635 .40125 Mdot
.6806 .49055 Mdot
.63984 .38006 Mdot
.21902 .57789 Mdot
.39559 .35941 Mdot
.18686 .45519 Mdot
.56841 .63152 Mdot
.31632 .57711 Mdot
.39904 .421 Mdot
.6727 .54652 Mdot
.37054 .36832 Mdot
.72304 .59522 Mdot
.63365 .70787 Mdot
.66081 .48561 Mdot
.72763 .4879 Mdot
.61787 .39197 Mdot
.67198 .6085 Mdot
.45065 .67381 Mdot
.38512 .58097 Mdot
.47594 .41611 Mdot
.29756 .7677 Mdot
.53188 .66002 Mdot
.46573 .4055 Mdot
.65334 .72081 Mdot
.53063 .65635 Mdot
.43443 .38976 Mdot
.54637 .61323 Mdot
.36845 .60652 Mdot
.67985 .27478 Mdot
.37897 .56832 Mdot
.44839 .34379 Mdot
.54001 .61846 Mdot
.65608 .49179 Mdot
.3746 .58243 Mdot
.46038 .41846 Mdot
.41091 .41491 Mdot
.5482 .50082 Mdot
.39951 .38429 Mdot
.26459 .70228 Mdot
.39461 .39719 Mdot
.63031 .52782 Mdot
.43834 .44515 Mdot
.84507 .47793 Mdot
.6072 .63559 Mdot
.34898 .6148 Mdot
.67706 .48474 Mdot
.64549 .51811 Mdot
.70532 .35302 Mdot
.62855 .5921 Mdot
.4678 .36521 Mdot
.6788 .54056 Mdot
.64252 .28446 Mdot
.52613 .66819 Mdot
.47185 .42745 Mdot
.47509 .60131 Mdot
.67704 .45889 Mdot
.61327 .55047 Mdot
.44263 .32319 Mdot
.39305 .58185 Mdot
.42472 .37046 Mdot
.61951 .52877 Mdot
.34332 .64511 Mdot
.46631 .35564 Mdot
.41677 .54065 Mdot
.54724 .50121 Mdot
.55063 .66961 Mdot
.35153 .39882 Mdot
.46374 .42188 Mdot
.64939 .55094 Mdot
.3441 .62356 Mdot
.50859 .65456 Mdot
.3686 .58719 Mdot
.46587 .8141 Mdot
.53914 .72438 Mdot
.19855 .52909 Mdot
.57523 .38061 Mdot
.7598 .59628 Mdot
.35489 .79264 Mdot
.80017 .44616 Mdot
.592 .30267 Mdot
.52926 .82906 Mdot
.62146 .53253 Mdot
.67093 .71524 Mdot
.64159 .52004 Mdot
.43188 .35504 Mdot
.65524 .52646 Mdot
.34653 .79099 Mdot
.40383 .4061 Mdot
.65431 .53299 Mdot
.6899 .30963 Mdot
.41249 .37617 Mdot
.33509 .58221 Mdot
.19603 .63306 Mdot
.81388 .44742 Mdot
.63171 .74347 Mdot
.68915 .50123 Mdot
.55138 .32536 Mdot
.4002 .39802 Mdot
.42176 .44609 Mdot
.37175 .5692 Mdot
.46497 .43832 Mdot
.59106 .36998 Mdot
.6485 .38861 Mdot
.48059 .49645 Mdot
.58382 .20604 Mdot
.48944 .43841 Mdot
.37487 .57913 Mdot
.22554 .38781 Mdot
.77887 .52842 Mdot
.75617 .52357 Mdot
.57237 .62236 Mdot
.22667 .65553 Mdot
.35578 .45247 Mdot
.51852 .70439 Mdot
.50516 .5872 Mdot
.341 .59105 Mdot
.24918 .69938 Mdot
.5331 .63873 Mdot
.30383 .35024 Mdot
.48273 .30043 Mdot
.45662 .40749 Mdot
.56014 .63822 Mdot
.48352 .45182 Mdot
.82932 .48635 Mdot
.32632 .26753 Mdot
.46698 .20291 Mdot
.46127 .3476 Mdot
.77981 .50877 Mdot
.41907 .38843 Mdot
.30431 .68308 Mdot
.39484 .39968 Mdot
.36632 .57995 Mdot
.34876 .67806 Mdot
.52236 .49019 Mdot
.51487 .18054 Mdot
.57138 .74097 Mdot
.59436 .35665 Mdot
.40925 .40452 Mdot
.4571 .40616 Mdot
.59854 .3824 Mdot
.32775 .57788 Mdot
.38778 .38605 Mdot
.65163 .30559 Mdot
.43442 .41577 Mdot
.52736 .63613 Mdot
.43846 .21916 Mdot
.38593 .55081 Mdot
.47667 .43553 Mdot
.33135 .63785 Mdot
.54771 .6714 Mdot
.51837 .63515 Mdot
.48796 .35706 Mdot
.54659 .68285 Mdot
.41544 .38335 Mdot
.33639 .2428 Mdot
.33972 .56602 Mdot
.34514 .39497 Mdot
.31878 .60312 Mdot
.23653 .51797 Mdot
.52298 .62446 Mdot
.61145 .7195 Mdot
.51327 .37677 Mdot
.53784 .63906 Mdot
.51678 .72075 Mdot
.49258 .43112 Mdot
.48303 .36394 Mdot
.79522 .59013 Mdot
.67956 .49496 Mdot
.54009 .49093 Mdot
.51238 .6334 Mdot
.45775 .42616 Mdot
.48024 .42281 Mdot
.55262 .67119 Mdot
.2846 .34518 Mdot
.74938 .3641 Mdot
.39969 .40489 Mdot
.35862 .57307 Mdot
.35673 .58733 Mdot
.47318 .3556 Mdot
.47161 .40226 Mdot
.67797 .51252 Mdot
.6848 .48863 Mdot
.70202 .51522 Mdot
.54587 .50054 Mdot
.61437 .72296 Mdot
.45633 .77473 Mdot
.56569 .67111 Mdot
.46383 .7193 Mdot
.80711 .53527 Mdot
.37432 .41948 Mdot
.69483 .52217 Mdot
.45919 .39556 Mdot
.42604 .37472 Mdot
.50905 .65753 Mdot
.64147 .73552 Mdot
.44199 .4756 Mdot
.33957 .56329 Mdot
.50771 .63974 Mdot
.47371 .31996 Mdot
.50423 .75681 Mdot
.63508 .38314 Mdot
.73372 .69399 Mdot
.54522 .62945 Mdot
.33682 .58981 Mdot
.53338 .61744 Mdot
.44815 .41034 Mdot
.41421 .3324 Mdot
.34789 .59427 Mdot
.64308 .37126 Mdot
.3956 .43305 Mdot
.43101 .39065 Mdot
.62635 .1802 Mdot
.79154 .50063 Mdot
.61713 .70377 Mdot
.39313 .37783 Mdot
.48785 .41253 Mdot
.59071 .38802 Mdot
.43947 .41459 Mdot
.41625 .42612 Mdot
.70547 .27338 Mdot
.59092 .69428 Mdot
.62979 .40578 Mdot
.29698 .36198 Mdot
.38369 .60089 Mdot
.27827 .74927 Mdot
.66239 .54647 Mdot
.54959 .68685 Mdot
.75563 .35726 Mdot
.62292 .51551 Mdot
.74163 .58761 Mdot
.26899 .73844 Mdot
.53853 .49467 Mdot
.66753 .3603 Mdot
.47576 .46693 Mdot
.40291 .41757 Mdot
.41787 .39224 Mdot
.62358 .37127 Mdot
.35918 .61065 Mdot
.54875 .47042 Mdot
.20601 .37923 Mdot
.42563 .38167 Mdot
.34179 .3502 Mdot
.21638 .59767 Mdot
.66821 .45268 Mdot
.59605 .36184 Mdot
.64568 .37437 Mdot
.41129 .40119 Mdot
.7208 .29763 Mdot
.375 .58891 Mdot
.4613 .41747 Mdot
.47759 .37827 Mdot
.68633 .49713 Mdot
.33917 .60549 Mdot
.61982 .53567 Mdot
.60501 .71875 Mdot
.31004 .73522 Mdot
.63588 .17897 Mdot
.519 .63056 Mdot
.25364 .64544 Mdot
.51904 .66123 Mdot
.53912 .21059 Mdot
.61553 .52767 Mdot
.4616 .36433 Mdot
.33787 .62294 Mdot
.46505 .4155 Mdot
.46998 .39103 Mdot
.45872 .41065 Mdot
.42828 .45713 Mdot
.82339 .35852 Mdot
.63249 .36399 Mdot
.48983 .42138 Mdot
.6381 .51623 Mdot
.25342 .66271 Mdot
.15595 .4879 Mdot
.45291 .40009 Mdot
.41256 .4121 Mdot
.3288 .58802 Mdot
.42669 .43849 Mdot
.52505 .66616 Mdot
.34821 .62435 Mdot
.39027 .39751 Mdot
.23878 .65962 Mdot
.41116 .35256 Mdot
.30822 .75178 Mdot
.52769 .61925 Mdot
.48784 .69811 Mdot
.48706 .43098 Mdot
.63235 .70317 Mdot
.54016 .49081 Mdot
.68422 .54012 Mdot
.50764 .67377 Mdot
.64544 .54124 Mdot
.26788 .29578 Mdot
.38643 .35257 Mdot
.40251 .36934 Mdot
.47862 .42288 Mdot
.67941 .5377 Mdot
.34444 .71686 Mdot
.63846 .61942 Mdot
.44949 .31213 Mdot
.6807 .52239 Mdot
.31514 .62525 Mdot
.59471 .43025 Mdot
.32806 .61683 Mdot
.64796 .3955 Mdot
.56044 .6514 Mdot
.62607 .3537 Mdot
.64511 .74685 Mdot
.34544 .60329 Mdot
.40205 .59435 Mdot
.67205 .53743 Mdot
.57627 .55791 Mdot
.64462 .83667 Mdot
.58819 .45234 Mdot
.54826 .24913 Mdot
.36732 .56755 Mdot
.4435 .34591 Mdot
.50063 .20989 Mdot
.56315 .55462 Mdot
.64381 .53912 Mdot
.45106 .36426 Mdot
.7 .29051 Mdot
.6789 .51281 Mdot
.47281 .42494 Mdot
.65763 .49655 Mdot
.54797 .63515 Mdot
.68809 .50859 Mdot
.3679 .55461 Mdot
.41984 .41779 Mdot
.61915 .84461 Mdot
.64184 .41891 Mdot
.39544 .39237 Mdot
.50932 .63598 Mdot
.43032 .52944 Mdot
.46359 .38468 Mdot
.60777 .39708 Mdot
.66404 .52414 Mdot
.58269 .47053 Mdot
.39813 .40415 Mdot
.68054 .53326 Mdot
.32698 .62587 Mdot
.50882 .67569 Mdot
.52354 .45609 Mdot
.63285 .71459 Mdot
.37484 .57183 Mdot
.48182 .66218 Mdot
.50972 .66919 Mdot
.48497 .42087 Mdot
.47857 .40066 Mdot
.35739 .5771 Mdot
.64961 .25429 Mdot
.42712 .4433 Mdot
.45677 .35921 Mdot
.63566 .51751 Mdot
.65209 .53956 Mdot
.65968 .2658 Mdot
.64212 .5025 Mdot
.40725 .33588 Mdot
.35921 .57821 Mdot
.43249 .36632 Mdot
.33085 .59071 Mdot
.43741 .44025 Mdot
.34104 .64862 Mdot
.32801 .57387 Mdot
.63713 .60803 Mdot
.44143 .36469 Mdot
.35525 .42041 Mdot
.46598 .40199 Mdot
.4324 .42178 Mdot
.67341 .51104 Mdot
.60801 .35876 Mdot
.47329 .33352 Mdot
.6534 .39576 Mdot
.59359 .38153 Mdot
.36967 .52015 Mdot
.68521 .49735 Mdot
.61243 .3752 Mdot
.18004 .50967 Mdot
.69851 .50674 Mdot
.62684 .37948 Mdot
.16298 .51321 Mdot
.5164 .63306 Mdot
.37766 .56333 Mdot
.41308 .37506 Mdot
.53037 .82351 Mdot
.37314 .24183 Mdot
.63371 .50191 Mdot
.39433 .39479 Mdot
.4604 .3918 Mdot
.31407 .58701 Mdot
.32831 .21185 Mdot
.67346 .55643 Mdot
.42242 .35476 Mdot
.34336 .61391 Mdot
.36892 .18732 Mdot
.62924 .53381 Mdot
.62634 .37658 Mdot
.57132 .64748 Mdot
.30939 .57094 Mdot
.60147 .63097 Mdot
.56239 .66478 Mdot
.60416 .52848 Mdot
.60046 .74666 Mdot
.46097 .35636 Mdot
.69412 .52377 Mdot
.75018 .68642 Mdot
.41227 .60346 Mdot
.51595 .60205 Mdot
.54645 .33371 Mdot
.34067 .58845 Mdot
.52571 .66549 Mdot
.61294 .35172 Mdot
.379 .61101 Mdot
.33941 .57036 Mdot
.51354 .66465 Mdot
.47898 .4877 Mdot
.47995 .59396 Mdot
.52264 .63586 Mdot
.79635 .56933 Mdot
.51482 .80064 Mdot
.69538 .52595 Mdot
.59423 .37794 Mdot
.60708 .78323 Mdot
.36854 .59648 Mdot
.22807 .65775 Mdot
.75862 .66886 Mdot
.40282 .39803 Mdot
.60737 .37626 Mdot
.38861 .74928 Mdot
.22868 .34263 Mdot
.5289 .65534 Mdot
.51969 .50125 Mdot
.60874 .34452 Mdot
.40399 .42446 Mdot
.4835 .29186 Mdot
.4431 .3579 Mdot
.55629 .65983 Mdot
.20388 .47721 Mdot
.33588 .59003 Mdot
.50515 .65261 Mdot
.73085 .69706 Mdot
.41941 .38192 Mdot
.44634 .3631 Mdot
.47413 .24201 Mdot
.37366 .60742 Mdot
.68207 .5431 Mdot
.46331 .3594 Mdot
.42902 .3878 Mdot
.44586 .32909 Mdot
.34928 .37659 Mdot
.74481 .31775 Mdot
.42709 .35496 Mdot
.58765 .72858 Mdot
.47931 .43365 Mdot
.44328 .36766 Mdot
.33012 .63778 Mdot
.69312 .21623 Mdot
.60197 .72063 Mdot
.42658 .38577 Mdot
.43988 .34688 Mdot
.51455 .66721 Mdot
.4923 .57438 Mdot
.57711 .56402 Mdot
.5751 .50489 Mdot
.57258 .30993 Mdot
.42896 .45838 Mdot
.33554 .6169 Mdot
.63912 .38718 Mdot
.4826 .37504 Mdot
.33497 .61558 Mdot
.38052 .39313 Mdot
.6815 .51496 Mdot
.69718 .50296 Mdot
.46101 .64519 Mdot
.61863 .37877 Mdot
.4273 .24196 Mdot
.45903 .72648 Mdot
.63256 .51867 Mdot
.40661 .36775 Mdot
.54099 .68969 Mdot
.61851 .52968 Mdot
.58804 .52372 Mdot
.38287 .32489 Mdot
.37619 .59599 Mdot
.34339 .58014 Mdot
.58357 .25102 Mdot
.69407 .63956 Mdot
.63857 .20058 Mdot
.55161 .6368 Mdot
.39728 .42732 Mdot
.44272 .6753 Mdot
.34111 .58031 Mdot
.51676 .21285 Mdot
.61218 .37717 Mdot
.52786 .65681 Mdot
.75017 .53327 Mdot
.32805 .5987 Mdot
.36938 .56149 Mdot
.43199 .34167 Mdot
.44067 .39653 Mdot
.60013 .29929 Mdot
.61317 .33535 Mdot
.54252 .67211 Mdot
.59693 .3817 Mdot
.62852 .55694 Mdot
.43003 .3526 Mdot
.31604 .59719 Mdot
.57634 .78838 Mdot
.44583 .34775 Mdot
.67556 .50953 Mdot
.34407 .58778 Mdot
.60368 .38761 Mdot
.59704 .38844 Mdot
.43259 .42041 Mdot
.23001 .38894 Mdot
.52748 .646 Mdot
.336 .58257 Mdot
.53659 .75355 Mdot
.43829 .44592 Mdot
.43457 .39813 Mdot
.37011 .43373 Mdot
.51746 .66491 Mdot
.46212 .66796 Mdot
.63437 .35487 Mdot
.36018 .60444 Mdot
.40164 .36254 Mdot
.62459 .38453 Mdot
.45585 .66794 Mdot
.65534 .48801 Mdot
.68298 .50416 Mdot
.60459 .39515 Mdot
.60043 .37621 Mdot
.61042 .39663 Mdot
.22256 .65432 Mdot
.35401 .55018 Mdot
.36853 .47032 Mdot
.42149 .4429 Mdot
.56484 .24046 Mdot
.46859 .32414 Mdot
.50947 .62881 Mdot
.67531 .49467 Mdot
.46758 .39526 Mdot
.45176 .34548 Mdot
.35847 .41828 Mdot
.35749 .43983 Mdot
.39192 .55911 Mdot
.34275 .60549 Mdot
.37653 .37474 Mdot
.67791 .49167 Mdot
.19644 .31236 Mdot
.46389 .84891 Mdot
.49502 .41882 Mdot
.53689 .56734 Mdot
.31692 .59489 Mdot
.53598 .67944 Mdot
.58212 .54113 Mdot
.54383 .61591 Mdot
.3588 .59915 Mdot
.42966 .35334 Mdot
.46998 .72897 Mdot
.59981 .39419 Mdot
.44528 .43017 Mdot
.54126 .66394 Mdot
.43896 .42936 Mdot
.56353 .66293 Mdot
.42966 .80129 Mdot
.81114 .52069 Mdot
.40775 .39054 Mdot
.4924 .40948 Mdot
.55931 .33123 Mdot
.45329 .39792 Mdot
.59382 .41971 Mdot
.31871 .59105 Mdot
.59895 .19543 Mdot
.41311 .34503 Mdot
.28528 .46818 Mdot
.4369 .44681 Mdot
.70428 .30191 Mdot
.43885 .40092 Mdot
.68774 .45959 Mdot
.40039 .41227 Mdot
.41888 .42517 Mdot
.54214 .61743 Mdot
.51332 .66544 Mdot
.36976 .62785 Mdot
.67539 .54567 Mdot
.29386 .74038 Mdot
.43159 .39332 Mdot
.63516 .7144 Mdot
.56139 .72017 Mdot
.59848 .37471 Mdot
.36114 .59868 Mdot
.33845 .19573 Mdot
.56254 .61707 Mdot
.77426 .43309 Mdot
.66119 .28017 Mdot
.602 .66186 Mdot
.5827 .5144 Mdot
.32019 .68044 Mdot
.62192 .39148 Mdot
.40479 .42689 Mdot
.62467 .7597 Mdot
.76773 .53336 Mdot
.39328 .31551 Mdot
.50402 .65789 Mdot
.287 .51586 Mdot
.59453 .78441 Mdot
.62746 .34743 Mdot
.62791 .35355 Mdot
.569 .65224 Mdot
.69704 .47289 Mdot
.46062 .46724 Mdot
.61236 .3799 Mdot
.64061 .50663 Mdot
.69851 .52085 Mdot
.71491 .56834 Mdot
.37292 .59536 Mdot
.70209 .71904 Mdot
.42596 .73931 Mdot
.56062 .66561 Mdot
.67368 .37859 Mdot
.33135 .55195 Mdot
.3821 .55866 Mdot
.66173 .54269 Mdot
.67052 .50788 Mdot
.38414 .56746 Mdot
.40777 .34218 Mdot
.376 .45203 Mdot
.42437 .38392 Mdot
.62083 .36625 Mdot
.4453 .40272 Mdot
.67662 .51746 Mdot
.53423 .65348 Mdot
.66298 .50748 Mdot
.55143 .61283 Mdot
.46908 .77164 Mdot
.45282 .42123 Mdot
.41578 .41776 Mdot
.37109 .24031 Mdot
.34052 .63552 Mdot
.56386 .74968 Mdot
.63144 .72901 Mdot
.64088 .51881 Mdot
.41573 .42663 Mdot
.32503 .61987 Mdot
.64956 .36898 Mdot
.36974 .2392 Mdot
.47122 .41662 Mdot
.31759 .59697 Mdot
.41069 .35913 Mdot
.19527 .54484 Mdot
.81338 .40106 Mdot
.36529 .58664 Mdot
.47622 .17262 Mdot
.42552 .34988 Mdot
.31947 .66856 Mdot
.4817 .41072 Mdot
.616 .27604 Mdot
.42916 .44364 Mdot
.38166 .60672 Mdot
.43098 .38242 Mdot
.36558 .61906 Mdot
.62607 .53899 Mdot
.55803 .67566 Mdot
.36003 .56383 Mdot
.48079 .38972 Mdot
.33811 .83458 Mdot
.5574 .65426 Mdot
.40905 .40069 Mdot
.56441 .62844 Mdot
.3507 .61778 Mdot
.37413 .56652 Mdot
.19529 .3849 Mdot
.60594 .69725 Mdot
.54674 .63516 Mdot
.42179 .35698 Mdot
.38913 .71094 Mdot
.43462 .36232 Mdot
.5804 .28531 Mdot
.44011 .33223 Mdot
.4358 .44513 Mdot
.15346 .44865 Mdot
.52861 .67095 Mdot
.66448 .22305 Mdot
.18863 .40437 Mdot
.21972 .6399 Mdot
.30165 .59331 Mdot
.63572 .35315 Mdot
.24582 .69329 Mdot
.61257 .71731 Mdot
.68218 .52769 Mdot
.46649 .39808 Mdot
.35519 .53982 Mdot
.52086 .64503 Mdot
.61259 .35857 Mdot
.40751 .39143 Mdot
.67023 .50619 Mdot
.75579 .38536 Mdot
.5754 .63803 Mdot
.36715 .59812 Mdot
.33245 .56709 Mdot
.42723 .17004 Mdot
.39513 .37066 Mdot
.41297 .41888 Mdot
.55916 .65652 Mdot
.41859 .58637 Mdot
.61856 .39373 Mdot
.71227 .32676 Mdot
.54856 .63634 Mdot
.54739 .53256 Mdot
.34987 .61056 Mdot
.46033 .39372 Mdot
.33683 .72231 Mdot
.76781 .49999 Mdot
.31334 .38873 Mdot
.6269 .37125 Mdot
.57027 .28501 Mdot
.38235 .60572 Mdot
.54111 .65778 Mdot
.68542 .65641 Mdot
.36623 .36906 Mdot
.45628 .38926 Mdot
.56335 .28182 Mdot
.51358 .48166 Mdot
.46107 .20571 Mdot
.46738 .42686 Mdot
.5339 .47513 Mdot
.45279 .43635 Mdot
.37434 .34744 Mdot
.41419 .33475 Mdot
.42899 .40206 Mdot
.31738 .59591 Mdot
.39605 .31702 Mdot
.68746 .52661 Mdot
.36104 .28852 Mdot
.55778 .51203 Mdot
.3971 .39889 Mdot
.43571 .35708 Mdot
.3302 .45724 Mdot
.50627 .69564 Mdot
.34878 .56736 Mdot
.39231 .62322 Mdot
.55374 .68134 Mdot
.36295 .43227 Mdot
.67217 .55008 Mdot
.42522 .31869 Mdot
.66939 .51112 Mdot
.31927 .61003 Mdot
.63636 .52375 Mdot
.57047 .66343 Mdot
.69627 .51693 Mdot
.6146 .72473 Mdot
.5208 .65837 Mdot
.38019 .59615 Mdot
.42755 .41555 Mdot
.50884 .63827 Mdot
.48673 .24819 Mdot
.62131 .36698 Mdot
.1873 .39534 Mdot
.38984 .37436 Mdot
.59796 .66506 Mdot
.41624 .53807 Mdot
.66405 .50876 Mdot
.77771 .34171 Mdot
.33002 .57202 Mdot
.63759 .40033 Mdot
.32015 .61355 Mdot
.81229 .57631 Mdot
.60151 .36331 Mdot
.16373 .52492 Mdot
.72288 .64315 Mdot
.61357 .45149 Mdot
.40664 .344 Mdot
.4928 .30377 Mdot
.62803 .55922 Mdot
.52082 .6461 Mdot
.71542 .63434 Mdot
.42203 .42738 Mdot
.79727 .46136 Mdot
.37985 .62203 Mdot
.67886 .54208 Mdot
.54563 .6516 Mdot
.50663 .64715 Mdot
.47472 .40229 Mdot
.68817 .36752 Mdot
.45172 .43293 Mdot
.67245 .63782 Mdot
.57034 .30394 Mdot
.42921 .47559 Mdot
.40569 .40753 Mdot
.64206 .55098 Mdot
.41115 .35916 Mdot
.56931 .3508 Mdot
.68807 .74221 Mdot
.42151 .45363 Mdot
.62734 .73393 Mdot
.62926 .41937 Mdot
.34742 .59816 Mdot
.50627 .39531 Mdot
.61319 .68798 Mdot
.40189 .36391 Mdot
.87602 .52012 Mdot
.62627 .3812 Mdot
.63848 .69633 Mdot
.46768 .44037 Mdot
.47665 .38419 Mdot
.52944 .35394 Mdot
.29003 .58774 Mdot
.77016 .499 Mdot
.44986 .3878 Mdot
.51961 .29062 Mdot
.56145 .63603 Mdot
.45969 .42823 Mdot
.41504 .39431 Mdot
.31816 .53907 Mdot
.51062 .6543 Mdot
.6501 .50919 Mdot
.61124 .53751 Mdot
.69502 .54995 Mdot
.59405 .39768 Mdot
.52449 .51471 Mdot
.53941 .22435 Mdot
.81091 .45027 Mdot
.63944 .39209 Mdot
.4113 .34986 Mdot
.56088 .35629 Mdot
.44451 .35044 Mdot
.60616 .35269 Mdot
.51276 .65609 Mdot
.34834 .56626 Mdot
.43522 .65402 Mdot
.64534 .56268 Mdot
.47286 .42664 Mdot
.58956 .36646 Mdot
.37877 .59354 Mdot
.59264 .34209 Mdot
.35279 .60259 Mdot
.54603 .63878 Mdot
.56128 .68097 Mdot
.61243 .35571 Mdot
.32406 .61268 Mdot
.52248 .71303 Mdot
.23269 .34282 Mdot
.42687 .3291 Mdot
.54621 .58799 Mdot
.3384 .63262 Mdot
.39678 .58627 Mdot
.36448 .62659 Mdot
.43962 .42484 Mdot
.5317 .56704 Mdot
.46933 .34265 Mdot
.54505 .67132 Mdot
.65865 .49687 Mdot
.66287 .3167 Mdot
.51357 .78771 Mdot
.67113 .33191 Mdot
.38947 .41976 Mdot
.42432 .37946 Mdot
.41126 .40084 Mdot
.44601 .33862 Mdot
.65802 .64818 Mdot
.46527 .41094 Mdot
.54764 .61816 Mdot
.66662 .51966 Mdot
.39999 .42394 Mdot
.64775 .49106 Mdot
.35088 .69322 Mdot
.64186 .38433 Mdot
.51277 .50946 Mdot
.29826 .78648 Mdot
.37983 .58585 Mdot
.6387 .50489 Mdot
.68067 .52951 Mdot
.62216 .39835 Mdot
.52402 .64218 Mdot
.35345 .60789 Mdot
.62699 .28741 Mdot
.60285 .39102 Mdot
.43003 .38451 Mdot
.60973 .57968 Mdot
.79106 .46657 Mdot
.41414 .4327 Mdot
.46637 .37677 Mdot
.65818 .48617 Mdot
.69074 .46712 Mdot
.68771 .77475 Mdot
.48611 .21817 Mdot
.60902 .35706 Mdot
.64252 .37399 Mdot
.39216 .57811 Mdot
.49938 .39219 Mdot
.54885 .67035 Mdot
.42517 .22136 Mdot
.43571 .51339 Mdot
.42985 .23686 Mdot
.52936 .45242 Mdot
.4706 .41393 Mdot
.27919 .32827 Mdot
.41807 .38154 Mdot
.3208 .57862 Mdot
.36094 .61549 Mdot
.36645 .57144 Mdot
.52357 .64806 Mdot
.25084 .52161 Mdot
.54315 .6192 Mdot
.32928 .80278 Mdot
.38559 .59725 Mdot
.65183 .67194 Mdot
.64394 .54991 Mdot
.48297 .43686 Mdot
.60883 .3896 Mdot
.5118 .61791 Mdot
.43261 .46584 Mdot
.72853 .30136 Mdot
.6838 .53415 Mdot
.38121 .59493 Mdot
.31592 .67764 Mdot
.3946 .80955 Mdot
.58017 .55295 Mdot
.48472 .32802 Mdot
.52161 .33553 Mdot
.59699 .37445 Mdot
.31259 .3787 Mdot
.59141 .35765 Mdot
.5341 .66364 Mdot
.41851 .41497 Mdot
.42614 .40962 Mdot
.44413 .44042 Mdot
.4607 .41506 Mdot
.53291 .68006 Mdot
.42098 .44822 Mdot
.84506 .47796 Mdot
.69561 .49912 Mdot
.21161 .5638 Mdot
.62483 .38752 Mdot
.50364 .66454 Mdot
.66834 .5184 Mdot
.67343 .4786 Mdot
.49918 .23305 Mdot
.40025 .40592 Mdot
.46768 .3979 Mdot
.77988 .45093 Mdot
.46531 .43001 Mdot
.49272 .33846 Mdot
.68125 .53174 Mdot
.66991 .33004 Mdot
.64602 .38734 Mdot
.63361 .35979 Mdot
.51264 .64531 Mdot
.32234 .61345 Mdot
.61722 .37214 Mdot
.62678 .53569 Mdot
.3825 .41081 Mdot
.47561 .37082 Mdot
.34215 .63355 Mdot
.76598 .66019 Mdot
.62061 .34475 Mdot
.33143 .6835 Mdot
.35399 .62182 Mdot
.34109 .55085 Mdot
.45604 .38743 Mdot
.37103 .32468 Mdot
.3257 .54743 Mdot
.63232 .3991 Mdot
.50572 .6677 Mdot
.57858 .49701 Mdot
.54717 .66602 Mdot
.36429 .60897 Mdot
.47486 .36392 Mdot
.36763 .60974 Mdot
.39232 .38108 Mdot
.21438 .72113 Mdot
.43105 .40569 Mdot
.8192 .46305 Mdot
.58167 .26344 Mdot
.66893 .52999 Mdot
.53665 .72034 Mdot
.66767 .54348 Mdot
.35859 .62043 Mdot
.48093 .37502 Mdot
.63636 .35809 Mdot
.20132 .60696 Mdot
.34061 .54803 Mdot
.68411 .51392 Mdot
.69484 .54244 Mdot
.52025 .66118 Mdot
.40199 .42813 Mdot
.45752 .39413 Mdot
.65392 .5347 Mdot
.41094 .47773 Mdot
.32481 .59829 Mdot
.41127 .41366 Mdot
.43533 .37254 Mdot
.66963 .53175 Mdot
.2491 .32423 Mdot
.28925 .62911 Mdot
.42023 .40759 Mdot
.68539 .68668 Mdot
.50829 .63069 Mdot
.42355 .33679 Mdot
.46744 .44796 Mdot
.60445 .37905 Mdot
.23853 .58557 Mdot
.6728 .75087 Mdot
.51553 .62411 Mdot
.66647 .54722 Mdot
.39661 .36734 Mdot
.64683 .55116 Mdot
.47898 .37996 Mdot
.26161 .61324 Mdot
.68906 .53454 Mdot
.47074 .37197 Mdot
.50135 .40238 Mdot
.37234 .60955 Mdot
.4702 .40592 Mdot
.35221 .48358 Mdot
.61729 .54252 Mdot
.47524 .3864 Mdot
.2285 .39377 Mdot
.52774 .63062 Mdot
.50042 .40891 Mdot
.63841 .3804 Mdot
.63298 .28813 Mdot
.45939 .73937 Mdot
.64257 .72023 Mdot
.63853 .37299 Mdot
.43911 .43106 Mdot
.6999 .53679 Mdot
.56678 .65764 Mdot
.80096 .42686 Mdot
.41935 .43191 Mdot
.55592 .65943 Mdot
.53645 .65327 Mdot
.63451 .37934 Mdot
.56958 .1605 Mdot
.45058 .4522 Mdot
.45187 .40029 Mdot
.36131 .51173 Mdot
.3098 .60865 Mdot
.4414 .406 Mdot
.43193 .34512 Mdot
.55294 .61975 Mdot
.5055 .35136 Mdot
.31335 .49324 Mdot
.69 .30685 Mdot
.53464 .60953 Mdot
.578 .46329 Mdot
.68547 .54466 Mdot
.62032 .38706 Mdot
.34998 .59201 Mdot
.59779 .34819 Mdot
.69231 .50862 Mdot
.41808 .34812 Mdot
.56592 .6244 Mdot
.33081 .40927 Mdot
.5688 .65576 Mdot
.64422 .71214 Mdot
.32057 .62146 Mdot
.42889 .6817 Mdot
.86573 .45349 Mdot
.42933 .74543 Mdot
.5128 .69958 Mdot
.59862 .37463 Mdot
.61276 .5084 Mdot
.43192 .37434 Mdot
.3155 .34689 Mdot
.42819 .4203 Mdot
.23213 .39449 Mdot
.6492 .4986 Mdot
.70219 .51568 Mdot
.41948 .41172 Mdot
.57428 .2987 Mdot
.56324 .66661 Mdot
.52699 .66884 Mdot
.47349 .39008 Mdot
.53783 .63874 Mdot
.44265 .39439 Mdot
.67363 .51344 Mdot
.70195 .24929 Mdot
.41623 .38752 Mdot
.48781 .37543 Mdot
.58871 .60063 Mdot
.16017 .44963 Mdot
.70858 .68386 Mdot
.30044 .31069 Mdot
.42935 .82195 Mdot
.53855 .63942 Mdot
.48079 .35013 Mdot
.58058 .45753 Mdot
.65391 .4871 Mdot
.51602 .70883 Mdot
.43774 .41237 Mdot
.43946 .41551 Mdot
.41309 .42326 Mdot
.44603 .36219 Mdot
.30964 .35749 Mdot
.36704 .47328 Mdot
.22617 .44953 Mdot
.46977 .39404 Mdot
.45386 .27683 Mdot
.51393 .63224 Mdot
.37895 .62568 Mdot
.58899 .35106 Mdot
.47055 .41335 Mdot
.3619 .46595 Mdot
.50382 .63804 Mdot
.33167 .80398 Mdot
.51485 .65441 Mdot
.64507 .51921 Mdot
.54237 .67925 Mdot
.39812 .38426 Mdot
.35647 .58649 Mdot
.56526 .50288 Mdot
.67651 .60886 Mdot
.68247 .52682 Mdot
.39538 .39262 Mdot
.62895 .68835 Mdot
.68624 .52523 Mdot
.35315 .69561 Mdot
.35154 .58524 Mdot
.50856 .28279 Mdot
.36227 .61517 Mdot
.47107 .37127 Mdot
.46226 .3614 Mdot
.50428 .605 Mdot
.56519 .66805 Mdot
.35869 .61768 Mdot
.60604 .1658 Mdot
.58871 .35928 Mdot
.36936 .57579 Mdot
.36965 .3783 Mdot
.46632 .55901 Mdot
.35446 .57932 Mdot
.64473 .32488 Mdot
.52069 .65162 Mdot
.38957 .58709 Mdot
.36766 .38352 Mdot
.77403 .62367 Mdot
.62138 .40246 Mdot
.70994 .52917 Mdot
.65138 .57917 Mdot
.61733 .53468 Mdot
.51395 .67677 Mdot
.67213 .53919 Mdot
.55872 .63183 Mdot
.53731 .73843 Mdot
.37868 .26737 Mdot
.55057 .68877 Mdot
.52463 .6802 Mdot
.67193 .53694 Mdot
.40645 .41437 Mdot
.62472 .57354 Mdot
.45698 .33685 Mdot
.39076 .44349 Mdot
.55182 .62904 Mdot
.381 .60617 Mdot
.36949 .55686 Mdot
.47299 .28676 Mdot
.32965 .5685 Mdot
.67004 .50991 Mdot
.81453 .41632 Mdot
.63098 .74819 Mdot
.5611 .64337 Mdot
.52115 .6759 Mdot
.43507 .36068 Mdot
.6447 .54067 Mdot
.63135 .54778 Mdot
.52968 .665 Mdot
.36173 .30456 Mdot
.49368 .3809 Mdot
.39966 .59247 Mdot
.38719 .59131 Mdot
.36269 .58162 Mdot
.36642 .62403 Mdot
.30613 .46176 Mdot
.52049 .65408 Mdot
.37833 .61019 Mdot
.47255 .37892 Mdot
.43988 .41416 Mdot
.57218 .50533 Mdot
.63753 .36563 Mdot
.3814 .39496 Mdot
.40574 .33971 Mdot
.45875 .38778 Mdot
.6852 .50668 Mdot
.37888 .43813 Mdot
.68487 .54145 Mdot
.70409 .53842 Mdot
.68298 .4897 Mdot
.6134 .71864 Mdot
.52901 .33782 Mdot
.47495 .83698 Mdot
.42189 .3547 Mdot
.40329 .62867 Mdot
.63925 .54462 Mdot
.75814 .32378 Mdot
.45678 .65832 Mdot
.41713 .42892 Mdot
.76439 .50474 Mdot
.65602 .53578 Mdot
.33339 .56452 Mdot
.4359 .41026 Mdot
.70293 .5443 Mdot
.63658 .38999 Mdot
.38135 .35318 Mdot
.61349 .53642 Mdot
.32881 .61581 Mdot
.57816 .37363 Mdot
.38739 .59993 Mdot
.67371 .48868 Mdot
.50105 .40457 Mdot
.66965 .8279 Mdot
.65897 .56153 Mdot
.17463 .50012 Mdot
.29599 .61416 Mdot
.41052 .4145 Mdot
.6288 .51583 Mdot
.30953 .60313 Mdot
.51311 .6776 Mdot
.46225 .5135 Mdot
.34183 .56539 Mdot
.702 .51645 Mdot
.61485 .53486 Mdot
.68185 .53083 Mdot
.34047 .60113 Mdot
.47753 .36034 Mdot
.33364 .59753 Mdot
.53905 .67905 Mdot
.42103 .37195 Mdot
.34499 .78902 Mdot
.41147 .61236 Mdot
.356 .62025 Mdot
.6561 .50407 Mdot
.59405 .39158 Mdot
.40795 .38715 Mdot
.18067 .46229 Mdot
.39127 .39306 Mdot
.56455 .64517 Mdot
.67639 .25482 Mdot
.32871 .40633 Mdot
.42571 .44414 Mdot
.43603 .36051 Mdot
.53522 .67206 Mdot
.40155 .39961 Mdot
.42232 .44162 Mdot
.61004 .71072 Mdot
.33928 .60805 Mdot
.43168 .37998 Mdot
.64806 .5036 Mdot
.59126 .75933 Mdot
.48471 .36145 Mdot
.73628 .40066 Mdot
.53318 .29123 Mdot
.63721 .2155 Mdot
.42524 .42136 Mdot
.46029 .22243 Mdot
.45367 .36569 Mdot
.44845 .42799 Mdot
.42739 .35857 Mdot
.32551 .29451 Mdot
.69173 .52588 Mdot
.67692 .52253 Mdot
.62483 .40203 Mdot
.53038 .29161 Mdot
.60691 .37777 Mdot
.51695 .64648 Mdot
.71771 .40234 Mdot
.68911 .53403 Mdot
.32979 .61752 Mdot
.44341 .43335 Mdot
.65362 .56259 Mdot
.46103 .3972 Mdot
.39723 .38201 Mdot
.65275 .55575 Mdot
.66235 .55851 Mdot
.63924 .7071 Mdot
.64046 .38228 Mdot
.36179 .56681 Mdot
.38211 .37866 Mdot
.59314 .37899 Mdot
.482 .37007 Mdot
.5637 .2364 Mdot
.36014 .5681 Mdot
.33736 .60592 Mdot
.35343 .55553 Mdot
.41728 .34856 Mdot
.39971 .38912 Mdot
.54493 .62005 Mdot
.32674 .61817 Mdot
.52805 .63224 Mdot
.55083 .50033 Mdot
.72859 .38169 Mdot
.43782 .4125 Mdot
.3442 .68009 Mdot
.61053 .38673 Mdot
.6552 .51428 Mdot
.76231 .40895 Mdot
.62004 .40352 Mdot
.39218 .3894 Mdot
.64553 .55269 Mdot
.61451 .35296 Mdot
.48259 .31734 Mdot
.54381 .83564 Mdot
.58639 .38141 Mdot
.47266 .38164 Mdot
.5224 .38329 Mdot
.32033 .2656 Mdot
.58991 .39182 Mdot
.56751 .63521 Mdot
.41384 .34967 Mdot
.41056 .5373 Mdot
.61886 .34478 Mdot
.55525 .75293 Mdot
.66257 .52708 Mdot
.72764 .68507 Mdot
.41326 .46309 Mdot
.33321 .31512 Mdot
.59879 .3507 Mdot
.35643 .60635 Mdot
.34862 .64434 Mdot
.45478 .37875 Mdot
.58774 .38987 Mdot
.54347 .60724 Mdot
.65879 .52318 Mdot
.60203 .72468 Mdot
.33906 .59897 Mdot
.39642 .67907 Mdot
.66465 .49895 Mdot
.35428 .68465 Mdot
.69037 .28819 Mdot
.41244 .47313 Mdot
.3094 .29587 Mdot
.75072 .56384 Mdot
.41119 .34814 Mdot
.58693 .3646 Mdot
.51347 .6272 Mdot
.57042 .64038 Mdot
.55076 .63945 Mdot
.55425 .72638 Mdot
.57534 .52313 Mdot
.65277 .49153 Mdot
.71657 .58129 Mdot
.62237 .38429 Mdot
.44914 .26364 Mdot
.48401 .39108 Mdot
.42288 .38103 Mdot
.39496 .42299 Mdot
.46445 .42588 Mdot
.45102 .36995 Mdot
.52845 .6389 Mdot
.56276 .72789 Mdot
.58022 .47493 Mdot
.35543 .57233 Mdot
.67402 .35361 Mdot
.6433 .54951 Mdot
.67463 .48433 Mdot
.6266 .35916 Mdot
.31246 .68429 Mdot
.63658 .502 Mdot
.63889 .51997 Mdot
.38818 .39972 Mdot
.32897 .60056 Mdot
.41717 .31592 Mdot
.45649 .35961 Mdot
.66226 .51423 Mdot
.56789 .42841 Mdot
.33056 .48316 Mdot
.35963 .37189 Mdot
.57235 .37991 Mdot
.52385 .56466 Mdot
.58764 .38776 Mdot
.48703 .3911 Mdot
.74353 .30972 Mdot
.69289 .51084 Mdot
.64162 .53087 Mdot
.59273 .35937 Mdot
.3039 .65631 Mdot
.34344 .59084 Mdot
.6729 .47823 Mdot
.56284 .62958 Mdot
.45208 .35307 Mdot
.74342 .37574 Mdot
.3166 .66189 Mdot
.69444 .37755 Mdot
.5559 .64236 Mdot
.63025 .54453 Mdot
.40653 .43323 Mdot
.47174 .38052 Mdot
.59755 .37929 Mdot
.39283 .77935 Mdot
.38387 .35497 Mdot
.2199 .64445 Mdot
.81452 .52728 Mdot
.77313 .64 Mdot
.45618 .38942 Mdot
.34063 .60696 Mdot
.61635 .5261 Mdot
.59479 .37859 Mdot
.39045 .43183 Mdot
.52308 .83793 Mdot
.35513 .63568 Mdot
.53659 .66135 Mdot
.56671 .46932 Mdot
.58267 .544 Mdot
.38817 .37986 Mdot
.42838 .41895 Mdot
.44614 .42332 Mdot
.61996 .80658 Mdot
.67988 .50594 Mdot
.31492 .5988 Mdot
.62802 .36908 Mdot
.32699 .57079 Mdot
.67464 .52689 Mdot
.40956 .68215 Mdot
.39714 .40803 Mdot
.35224 .63612 Mdot
.35619 .6036 Mdot
.5192 .65951 Mdot
.52355 .68196 Mdot
.5572 .48837 Mdot
.43176 .40441 Mdot
.61671 .55777 Mdot
.37702 .60613 Mdot
.6108 .57828 Mdot
.6003 .36483 Mdot
.52253 .6254 Mdot
.46923 .39679 Mdot
.69175 .51751 Mdot
.41983 .44824 Mdot
.34296 .57723 Mdot
.63795 .52159 Mdot
.63636 .70556 Mdot
.64189 .37529 Mdot
.45246 .41279 Mdot
.57215 .3674 Mdot
.66546 .54785 Mdot
.43364 .37219 Mdot
.29189 .66653 Mdot
.59584 .40467 Mdot
.6487 .61874 Mdot
.65722 .49178 Mdot
.63403 .71249 Mdot
.36295 .5579 Mdot
.51698 .73514 Mdot
.64364 .52615 Mdot
.29596 .67588 Mdot
.45171 .78767 Mdot
.37666 .39219 Mdot
.36861 .59251 Mdot
.63213 .48674 Mdot
.26746 .74795 Mdot
.24697 .33465 Mdot
.41012 .39908 Mdot
.64466 .49968 Mdot
.59313 .36192 Mdot
.56087 .6419 Mdot
.73691 .39885 Mdot
.56363 .35683 Mdot
.68175 .55112 Mdot
.42898 .35702 Mdot
.35175 .61571 Mdot
.5268 .65179 Mdot
.47826 .74374 Mdot
.63318 .52175 Mdot
.66378 .49578 Mdot
.41041 .43593 Mdot
.61346 .37729 Mdot
.20867 .40181 Mdot
.67675 .51466 Mdot
.78196 .46444 Mdot
.60203 .53617 Mdot
.58875 .36819 Mdot
.46137 .36982 Mdot
.49623 .30293 Mdot
.43863 .33672 Mdot
.17541 .53222 Mdot
.66204 .5453 Mdot
.34873 .57098 Mdot
.43218 .42538 Mdot
.68244 .29552 Mdot
.65884 .51662 Mdot
.54078 .56689 Mdot
.71442 .47148 Mdot
.5209 .65331 Mdot
.76615 .41319 Mdot
.44858 .40552 Mdot
.56518 .66288 Mdot
.60995 .38607 Mdot
.42321 .40363 Mdot
.40135 .38604 Mdot
.31265 .58687 Mdot
.53523 .66517 Mdot
.48263 .80436 Mdot
.5055 .65434 Mdot
.53042 .61845 Mdot
.33417 .55812 Mdot
.4432 .38292 Mdot
.64598 .51654 Mdot
.65378 .5368 Mdot
.38736 .43503 Mdot
.76492 .31651 Mdot
.34103 .59132 Mdot
.67134 .3857 Mdot
.63964 .79864 Mdot
.42403 .47339 Mdot
.76014 .40309 Mdot
.38833 .77528 Mdot
.54797 .60863 Mdot
.47217 .39219 Mdot
.33896 .61948 Mdot
.6773 .47831 Mdot
.65995 .49843 Mdot
.47417 .35874 Mdot
.53375 .64984 Mdot
.63354 .39395 Mdot
.6315 .55634 Mdot
.68892 .3659 Mdot
.45489 .42207 Mdot
.77146 .51393 Mdot
.62322 .52695 Mdot
.20689 .65542 Mdot
.63097 .49558 Mdot
.36897 .58745 Mdot
.39937 .3801 Mdot
.3382 .56443 Mdot
.62287 .36438 Mdot
.56423 .47676 Mdot
.53377 .65195 Mdot
.49147 .46229 Mdot
.85273 .55581 Mdot
.67996 .53544 Mdot
.31838 .5912 Mdot
.42685 .44477 Mdot
.54492 .38171 Mdot
.4476 .40063 Mdot
.51764 .40418 Mdot
.61585 .41807 Mdot
.5446 .62678 Mdot
.56622 .64314 Mdot
.42834 .37267 Mdot
.61266 .39479 Mdot
.62996 .54208 Mdot
.65602 .52269 Mdot
.13267 .44933 Mdot
.64058 .60191 Mdot
.60393 .29691 Mdot
.44343 .4154 Mdot
.70049 .52501 Mdot
.53802 .77945 Mdot
.5597 .65496 Mdot
.48226 .40233 Mdot
.67406 .54876 Mdot
.78443 .57818 Mdot
.63265 .27504 Mdot
.45465 .37094 Mdot
.44682 .4576 Mdot
.564 .63006 Mdot
.45624 .24929 Mdot
.67791 .49004 Mdot
.44254 .33167 Mdot
.57383 .6671 Mdot
.65663 .25346 Mdot
.72272 .71499 Mdot
.36251 .56706 Mdot
.69742 .46737 Mdot
.52757 .63926 Mdot
.3812 .43521 Mdot
.62935 .38638 Mdot
.62042 .55364 Mdot
.68604 .51107 Mdot
.41753 .36071 Mdot
.42217 .4479 Mdot
.56058 .33502 Mdot
.32205 .58523 Mdot
.51342 .63471 Mdot
.41888 .4195 Mdot
.42357 .65023 Mdot
.44755 .4392 Mdot
.53886 .62115 Mdot
.63318 .86168 Mdot
.38011 .37884 Mdot
.44915 .39892 Mdot
.20888 .39772 Mdot
.34358 .56449 Mdot
.32597 .56993 Mdot
.81438 .49395 Mdot
.44427 .41526 Mdot
.77871 .43642 Mdot
.36113 .5652 Mdot
.34106 .58751 Mdot
.61427 .66161 Mdot
.41247 .38602 Mdot
.39022 .23872 Mdot
.56471 .65899 Mdot
.54726 .61549 Mdot
.33499 .59675 Mdot
.37912 .37191 Mdot
.56141 .61496 Mdot
.30103 .39654 Mdot
.64513 .5419 Mdot
.73108 .29429 Mdot
.33695 .57741 Mdot
.52649 .49195 Mdot
.55934 .64682 Mdot
.32517 .80067 Mdot
.73331 .55396 Mdot
.4092 .41584 Mdot
.4517 .41591 Mdot
.61464 .38799 Mdot
.37953 .38338 Mdot
.70223 .51341 Mdot
.53763 .63842 Mdot
.19414 .47327 Mdot
.3675 .57225 Mdot
.43651 .40057 Mdot
.34143 .68901 Mdot
.47244 .76323 Mdot
.72974 .64827 Mdot
.34827 .59814 Mdot
.37216 .59378 Mdot
.6747 .49051 Mdot
.64028 .50444 Mdot
.44885 .37938 Mdot
.53817 .67061 Mdot
.3327 .621 Mdot
.54557 .62319 Mdot
.69209 .50975 Mdot
.64541 .51439 Mdot
.69173 .53204 Mdot
.42338 .32527 Mdot
.63987 .51508 Mdot
.68632 .34816 Mdot
.39585 .68585 Mdot
.38226 .55844 Mdot
.79343 .6493 Mdot
.47857 .74189 Mdot
.4168 .51905 Mdot
.63068 .35252 Mdot
.66512 .54826 Mdot
.52692 .67631 Mdot
.43669 .36334 Mdot
.4647 .39764 Mdot
.71686 .52169 Mdot
.54466 .67647 Mdot
.61528 .35971 Mdot
.55849 .67321 Mdot
.63485 .38051 Mdot
.76074 .51611 Mdot
.39956 .42547 Mdot
.4727 .36809 Mdot
.53376 .6363 Mdot
.63744 .52001 Mdot
.66981 .5213 Mdot
.5837 .38031 Mdot
.47218 .4951 Mdot
.68651 .52734 Mdot
.33847 .5772 Mdot
.29668 .45092 Mdot
.61533 .53097 Mdot
.43816 .40866 Mdot
.53551 .22003 Mdot
.32165 .34632 Mdot
.45014 .33891 Mdot
.60944 .68562 Mdot
.43381 .1947 Mdot
.43208 .43044 Mdot
.44473 .18359 Mdot
.63242 .71366 Mdot
.33751 .56682 Mdot
.65372 .49553 Mdot
.68273 .48094 Mdot
.51179 .37962 Mdot
.61319 .33754 Mdot
.38613 .42913 Mdot
.3492 .56261 Mdot
.33121 .63948 Mdot
.79311 .58591 Mdot
.17389 .50405 Mdot
.59812 .35402 Mdot
.6275 .35732 Mdot
.64547 .52658 Mdot
.23177 .32237 Mdot
.36361 .36755 Mdot
.61147 .3574 Mdot
.38607 .2634 Mdot
.43051 .35498 Mdot
.56307 .27417 Mdot
.77311 .47926 Mdot
.33907 .60294 Mdot
.49222 .30234 Mdot
.64915 .51928 Mdot
.32588 .57795 Mdot
.43557 .64562 Mdot
.38347 .3863 Mdot
.3618 .56924 Mdot
.54841 .62265 Mdot
.73789 .5923 Mdot
.37356 .56658 Mdot
.54791 .22496 Mdot
.53045 .66638 Mdot
.59928 .57725 Mdot
.48146 .27961 Mdot
.8302 .32503 Mdot
.53075 .64039 Mdot
.66511 .55555 Mdot
.65411 .5359 Mdot
.65459 .52353 Mdot
.3253 .57596 Mdot
.63546 .55011 Mdot
.32046 .59051 Mdot
.29149 .28008 Mdot
.46816 .49596 Mdot
.60929 .35598 Mdot
.60468 .69959 Mdot
.36407 .60226 Mdot
.80317 .3864 Mdot
.86211 .4874 Mdot
.47268 .39609 Mdot
.51106 .66623 Mdot
.60492 .35381 Mdot
.18927 .60453 Mdot
.60683 .38177 Mdot
.6269 .44511 Mdot
.69814 .26294 Mdot
.43737 .39499 Mdot
.28301 .53207 Mdot
.63788 .36085 Mdot
.35017 .60879 Mdot
.42995 .37469 Mdot
.49048 .68361 Mdot
.61299 .38226 Mdot
.63126 .39386 Mdot
.44352 .37507 Mdot
.38114 .59562 Mdot
.65121 .51217 Mdot
.55883 .67678 Mdot
.62946 .40651 Mdot
.34006 .6518 Mdot
.39997 .3543 Mdot
.39953 .36171 Mdot
.57446 .55837 Mdot
.61153 .32946 Mdot
.53818 .63993 Mdot
.35448 .25835 Mdot
.64372 .50198 Mdot
.63213 .47069 Mdot
.8033 .51192 Mdot
.61208 .69475 Mdot
.66438 .54321 Mdot
.66774 .54562 Mdot
.45171 .37291 Mdot
.61191 .32556 Mdot
.65774 .2373 Mdot
.54971 .71087 Mdot
.6186 .52321 Mdot
.65867 .52143 Mdot
.34413 .64186 Mdot
.79833 .58235 Mdot
.39204 .43236 Mdot
.52037 .62041 Mdot
.69046 .51692 Mdot
.26105 .61901 Mdot
.61787 .37727 Mdot
.77906 .35396 Mdot
.4019 .42648 Mdot
.41549 .4174 Mdot
.54691 .64739 Mdot
.54286 .61869 Mdot
.48508 .61993 Mdot
.81506 .54414 Mdot
.39367 .2211 Mdot
.51802 .74998 Mdot
.2687 .59195 Mdot
.36659 .63279 Mdot
.35712 .61985 Mdot
.59039 .7213 Mdot
.50362 .64696 Mdot
.43333 .42825 Mdot
.33263 .6199 Mdot
.72632 .63246 Mdot
.4138 .59105 Mdot
.57899 .28744 Mdot
.71437 .35073 Mdot
.39255 .38471 Mdot
.33164 .60869 Mdot
.34041 .56782 Mdot
.34699 .62596 Mdot
.63084 .71368 Mdot
.44995 .38843 Mdot
.40322 .40632 Mdot
.43514 .43622 Mdot
.34487 .36565 Mdot
.46394 .41431 Mdot
.57192 .70947 Mdot
.54824 .53648 Mdot
.21277 .54386 Mdot
.43039 .33188 Mdot
.54849 .61093 Mdot
.3906 .37056 Mdot
.61561 .39598 Mdot
.43025 .35907 Mdot
.58625 .2878 Mdot
.54987 .66016 Mdot
.29357 .62653 Mdot
.51423 .74448 Mdot
.39734 .41495 Mdot
.64217 .39023 Mdot
.401 .51335 Mdot
.42415 .80182 Mdot
.62528 .33712 Mdot
.33787 .57796 Mdot
.65037 .54503 Mdot
.53113 .67649 Mdot
.64133 .52164 Mdot
.41477 .32814 Mdot
.60187 .67684 Mdot
.38798 .74399 Mdot
.54691 .48084 Mdot
.46887 .41798 Mdot
.38441 .45195 Mdot
.33966 .58164 Mdot
.6461 .55285 Mdot
.39784 .56037 Mdot
.43694 .42391 Mdot
.62514 .36909 Mdot
.61686 .38433 Mdot
.46535 .64827 Mdot
.2856 .7187 Mdot
.50823 .72477 Mdot
.54604 .64476 Mdot
.67864 .5133 Mdot
.59389 .35319 Mdot
.37732 .65393 Mdot
.50148 .67005 Mdot
.53404 .67229 Mdot
.52998 .66205 Mdot
.43143 .34782 Mdot
.68507 .54144 Mdot
.20974 .52947 Mdot
.70085 .52076 Mdot
.39849 .39698 Mdot
.67826 .50338 Mdot
.67983 .54189 Mdot
.62136 .38929 Mdot
.51217 .64707 Mdot
.6868 .50041 Mdot
.47189 .3721 Mdot
.37605 .57578 Mdot
.50809 .487 Mdot
.59797 .26316 Mdot
.19171 .56271 Mdot
.20739 .5736 Mdot
.38514 .57807 Mdot
.29096 .75361 Mdot
.51191 .62341 Mdot
.36365 .30306 Mdot
.66921 .69253 Mdot
.46876 .35713 Mdot
.81535 .38962 Mdot
.65267 .49125 Mdot
.65601 .55601 Mdot
.4592 .36702 Mdot
.70053 .47378 Mdot
.44043 .40006 Mdot
.67764 .49874 Mdot
.67316 .35908 Mdot
.50221 .41114 Mdot
.62997 .53183 Mdot
.44843 .33123 Mdot
.41144 .3826 Mdot
.33798 .60407 Mdot
.62558 .52002 Mdot
.48127 .40673 Mdot
.14603 .53695 Mdot
.53321 .62101 Mdot
.62486 .69652 Mdot
.53117 .20873 Mdot
.52642 .63889 Mdot
.36766 .57636 Mdot
.39002 .44188 Mdot
.60293 .38348 Mdot
.3626 .60756 Mdot
.64449 .2763 Mdot
.63806 .36295 Mdot
.81293 .39632 Mdot
.33364 .58248 Mdot
.61742 .52748 Mdot
.62791 .39021 Mdot
.47481 .34565 Mdot
.62607 .5564 Mdot
.43893 .51885 Mdot
.65952 .54566 Mdot
.45768 .39528 Mdot
.59693 .72765 Mdot
.51655 .62824 Mdot
.41259 .39845 Mdot
.63429 .55607 Mdot
.60966 .71966 Mdot
.42894 .34924 Mdot
.44236 .36488 Mdot
.77197 .65117 Mdot
.78328 .38927 Mdot
.59793 .37091 Mdot
.31243 .60814 Mdot
.47253 .37841 Mdot
.63736 .38635 Mdot
.71228 .44994 Mdot
.40283 .35541 Mdot
.35297 .63403 Mdot
.35569 .36739 Mdot
.62031 .5408 Mdot
.52313 .63432 Mdot
.54473 .49468 Mdot
.63735 .38904 Mdot
.51999 .13484 Mdot
.69747 .52316 Mdot
.48655 .39645 Mdot
.4694 .42039 Mdot
.71708 .67532 Mdot
.33278 .57262 Mdot
.40175 .22216 Mdot
.45249 .41304 Mdot
.34579 .38839 Mdot
.42317 .4007 Mdot
.62349 .45485 Mdot
.34231 .59013 Mdot
.45286 .39941 Mdot
.37137 .67729 Mdot
.49031 .37689 Mdot
.6393 .3902 Mdot
.22865 .36077 Mdot
.41251 .34651 Mdot
.78494 .73141 Mdot
.77324 .43473 Mdot
.63097 .5286 Mdot
.58746 .72985 Mdot
.2342 .28016 Mdot
.53218 .73714 Mdot
.31904 .59428 Mdot
.38137 .76498 Mdot
.64616 .51565 Mdot
.55613 .75912 Mdot
.28541 .75493 Mdot
.41215 .38033 Mdot
.3881 .3803 Mdot
.62596 .44501 Mdot
.7029 .50819 Mdot
.613 .55453 Mdot
.41684 .33079 Mdot
.37215 .34649 Mdot
.6495 .50629 Mdot
.47655 .38369 Mdot
.44933 .32512 Mdot
.54915 .68077 Mdot
.38407 .57993 Mdot
.55715 .63553 Mdot
.51526 .65799 Mdot
.28366 .35425 Mdot
.80743 .55215 Mdot
.533 .62263 Mdot
.51551 .62119 Mdot
.57006 .27457 Mdot
.54573 .3326 Mdot
.62113 .34598 Mdot
.24638 .67968 Mdot
.6556 .52582 Mdot
.44696 .38791 Mdot
.38339 .57082 Mdot
.33904 .30598 Mdot
.75455 .43746 Mdot
.66993 .24192 Mdot
.43608 .4263 Mdot
.65416 .5185 Mdot
.63107 .7158 Mdot
.42792 .31647 Mdot
.61038 .49238 Mdot
.4138 .41975 Mdot
.64919 .5623 Mdot
.28745 .48692 Mdot
.31769 .6814 Mdot
.60477 .54766 Mdot
.39886 .60865 Mdot
.42255 .41529 Mdot
.33716 .5753 Mdot
.55501 .6385 Mdot
.61468 .39293 Mdot
.59929 .36965 Mdot
.43784 .37182 Mdot
.37524 .45281 Mdot
.76019 .51023 Mdot
.4074 .38666 Mdot
.42226 .36262 Mdot
.63251 .71382 Mdot
.42259 .36467 Mdot
.46314 .42571 Mdot
.45046 .43425 Mdot
.48813 .41636 Mdot
.5362 .61645 Mdot
.34229 .68799 Mdot
.39941 .33088 Mdot
.4386 .31964 Mdot
.57315 .6581 Mdot
.41932 .78885 Mdot
.5123 .65798 Mdot
.34966 .79211 Mdot
.56365 .64184 Mdot
.60467 .36156 Mdot
.64853 .72864 Mdot
.38273 .45611 Mdot
.37461 .6152 Mdot
.50287 .66697 Mdot
.63258 .37309 Mdot
.54472 .63764 Mdot
.66852 .49923 Mdot
.67119 .76819 Mdot
.37244 .64434 Mdot
.4383 .2169 Mdot
.4672 .65702 Mdot
.65991 .6079 Mdot
.69425 .50595 Mdot
.33846 .59284 Mdot
.33121 .49187 Mdot
.45569 .43378 Mdot
.63668 .38545 Mdot
.44783 .37569 Mdot
.52224 .62134 Mdot
.6499 .52166 Mdot
.22946 .35428 Mdot
.5989 .38072 Mdot
.79599 .63234 Mdot
.66516 .52673 Mdot
.4343 .44021 Mdot
.52303 .61928 Mdot
.82107 .61498 Mdot
.55143 .63012 Mdot
.43273 .49173 Mdot
.39197 .60939 Mdot
.30103 .30422 Mdot
.36619 .59648 Mdot
.63873 .49451 Mdot
.6774 .79232 Mdot
.22803 .63983 Mdot
.38064 .58955 Mdot
.69242 .5895 Mdot
.39457 .37143 Mdot
.39713 .36388 Mdot
.3012 .66394 Mdot
.31866 .61722 Mdot
.47208 .40061 Mdot
.6342 .70285 Mdot
.40102 .70391 Mdot
.77537 .41272 Mdot
.6538 .54957 Mdot
.44416 .40417 Mdot
.57438 .66079 Mdot
.557 .67344 Mdot
.69848 .52665 Mdot
.5121 .66039 Mdot
.40409 .40525 Mdot
.36451 .6003 Mdot
.63126 .56437 Mdot
.6088 .36795 Mdot
.15445 .49415 Mdot
.59171 .35234 Mdot
.66545 .54237 Mdot
.50041 .40567 Mdot
.64492 .51454 Mdot
.29034 .20444 Mdot
.4078 .40999 Mdot
.35582 .5653 Mdot
.44524 .35832 Mdot
.42152 .41147 Mdot
.38841 .37742 Mdot
.65862 .50181 Mdot
.43551 .20446 Mdot
.47518 .3783 Mdot
.53248 .65278 Mdot
.22844 .57343 Mdot
.38788 .37492 Mdot
.66891 .36993 Mdot
.55272 .30658 Mdot
.72301 .5771 Mdot
.39084 .57986 Mdot
.63531 .54477 Mdot
.37293 .57651 Mdot
.40792 .60464 Mdot
.36725 .57603 Mdot
.24161 .55567 Mdot
.32068 .49169 Mdot
.47757 .18954 Mdot
.22386 .40413 Mdot
.42183 .2889 Mdot
.31464 .61219 Mdot
.59946 .42506 Mdot
.35175 .62263 Mdot
.33626 .57229 Mdot
.42969 .91073 Mdot
.37128 .61515 Mdot
.44347 .41059 Mdot
.38621 .40444 Mdot
.44648 .74948 Mdot
.53817 .25844 Mdot
.42742 .36786 Mdot
.46618 .3689 Mdot
.61587 .39172 Mdot
.37106 .45754 Mdot
.60225 .67796 Mdot
.81444 .42792 Mdot
.49448 .76916 Mdot
.44565 .37441 Mdot
.47138 .37394 Mdot
.3951 .32439 Mdot
.81483 .66174 Mdot
.29862 .35038 Mdot
.32029 .62423 Mdot
.37492 .42586 Mdot
.18165 .56612 Mdot
.4031 .418 Mdot
.43101 .34484 Mdot
.39233 .38126 Mdot
.64638 .51596 Mdot
.36249 .63287 Mdot
.37052 .40958 Mdot
.78814 .49844 Mdot
.39526 .40931 Mdot
.61098 .69762 Mdot
.3081 .23362 Mdot
.44946 .40582 Mdot
.38156 .61365 Mdot
.4106 .35874 Mdot
.32981 .58565 Mdot
.3437 .61207 Mdot
.49753 .40012 Mdot
.25824 .58842 Mdot
.37665 .62318 Mdot
.39797 .39585 Mdot
.65713 .50775 Mdot
.23751 .68158 Mdot
.45872 .39752 Mdot
.59385 .37938 Mdot
.4506 .41526 Mdot
.64084 .39407 Mdot
.41634 .36838 Mdot
.69703 .53014 Mdot
.32462 .39238 Mdot
.64338 .53067 Mdot
.33767 .23555 Mdot
.68465 .54434 Mdot
.77778 .64493 Mdot
.33352 .63205 Mdot
.60099 .72136 Mdot
.60168 .18103 Mdot
.61888 .69168 Mdot
.50715 .57463 Mdot
.49813 .56025 Mdot
.53715 .6707 Mdot
.3433 .56119 Mdot
.42286 .2521 Mdot
.72676 .64493 Mdot
.70178 .68178 Mdot
.6856 .53497 Mdot
.60008 .16631 Mdot
.70038 .25369 Mdot
.4585 .35637 Mdot
.26709 .54247 Mdot
.23071 .46127 Mdot
.40855 .3502 Mdot
.38969 .44311 Mdot
.71122 .53274 Mdot
.47418 .41478 Mdot
.41636 .65335 Mdot
.67011 .53698 Mdot
.63409 .3752 Mdot
.34403 .57131 Mdot
.62451 .40088 Mdot
.7186 .65715 Mdot
.49348 .56428 Mdot
.6847 .50265 Mdot
.49189 .3931 Mdot
.45238 .36017 Mdot
.33277 .60011 Mdot
.35429 .53731 Mdot
.37154 .6099 Mdot
.59679 .35645 Mdot
.66759 .535 Mdot
.31699 .33389 Mdot
.46843 .3779 Mdot
.35648 .60102 Mdot
.47696 .60884 Mdot
.47237 .38281 Mdot
.53792 .63321 Mdot
.39231 .39316 Mdot
.38033 .58131 Mdot
.42234 .36496 Mdot
.36667 .59989 Mdot
.64575 .54417 Mdot
.40542 .42426 Mdot
.45828 .36926 Mdot
.80822 .63 Mdot
.61398 .36052 Mdot
.32307 .623 Mdot
.70711 .47438 Mdot
.45474 .43767 Mdot
.65085 .63303 Mdot
.42541 .41826 Mdot
.4068 .55734 Mdot
.48795 .3863 Mdot
.62317 .71719 Mdot
.3957 .43297 Mdot
.45788 .39764 Mdot
.45645 .60123 Mdot
.23105 .49484 Mdot
.34743 .53633 Mdot
.53451 .61409 Mdot
.36263 .62573 Mdot
.73665 .37345 Mdot
.62889 .50897 Mdot
.63602 .5517 Mdot
.48141 .23995 Mdot
.4774 .43613 Mdot
.43897 .39409 Mdot
.56233 .68057 Mdot
.63514 .36504 Mdot
.34945 .59988 Mdot
.63454 .37937 Mdot
.80048 .50168 Mdot
.61445 .3509 Mdot
.69107 .48622 Mdot
.76638 .50876 Mdot
.30928 .37318 Mdot
.61631 .39149 Mdot
.38138 .59736 Mdot
.70678 .35126 Mdot
.46842 .35261 Mdot
.56296 .36752 Mdot
.62408 .36993 Mdot
.58691 .15363 Mdot
.46545 .42224 Mdot
.5182 .57206 Mdot
.53054 .62633 Mdot
.62766 .38764 Mdot
.54388 .66716 Mdot
.43124 .36762 Mdot
.64192 .61998 Mdot
.31734 .605 Mdot
.5702 .62375 Mdot
.40072 .34828 Mdot
.60933 .3538 Mdot
.68923 .51744 Mdot
.49203 .62834 Mdot
.55579 .61344 Mdot
.38258 .77871 Mdot
.26329 .31931 Mdot
.66584 .53475 Mdot
.71632 .31037 Mdot
.56622 .65419 Mdot
.42213 .3446 Mdot
.35129 .42748 Mdot
.40859 .41589 Mdot
.54601 .72476 Mdot
.63767 .54761 Mdot
.39836 .72287 Mdot
.44895 .35773 Mdot
.44113 .43161 Mdot
.32992 .54654 Mdot
.64966 .53432 Mdot
.35663 .58395 Mdot
.36193 .62425 Mdot
.64625 .54331 Mdot
.36763 .58847 Mdot
.64111 .36615 Mdot
.4137 .7017 Mdot
.56906 .64429 Mdot
.53569 .65524 Mdot
.65731 .52161 Mdot
.63478 .52062 Mdot
.6396 .51968 Mdot
.39241 .39383 Mdot
.34547 .59518 Mdot
.40213 .37583 Mdot
.38882 .37758 Mdot
.29209 .57332 Mdot
.38849 .58328 Mdot
.39899 .36966 Mdot
.62743 .4902 Mdot
.56692 .36316 Mdot
.66063 .50576 Mdot
.52938 .6249 Mdot
.55743 .77587 Mdot
.54992 .60403 Mdot
.44107 .4047 Mdot
.78276 .57678 Mdot
.37849 .59904 Mdot
.6105 .38545 Mdot
.64403 .36035 Mdot
.60239 .37884 Mdot
.58169 .66463 Mdot
.33164 .62484 Mdot
.81429 .42503 Mdot
.44338 .40126 Mdot
.57546 .56036 Mdot
.39597 .25258 Mdot
.77281 .53352 Mdot
.52808 .62444 Mdot
.47136 .377 Mdot
.53983 .49177 Mdot
.33486 .47339 Mdot
.41407 .41585 Mdot
.46832 .34667 Mdot
.64546 .68413 Mdot
.36813 .33723 Mdot
.38664 .61577 Mdot
.82281 .53275 Mdot
.38272 .40819 Mdot
.28458 .64574 Mdot
.1583 .41321 Mdot
.43303 .40689 Mdot
.44439 .42567 Mdot
.46346 .38744 Mdot
.43422 .35579 Mdot
.38477 .61185 Mdot
.4881 .25879 Mdot
.50888 .62847 Mdot
.573 .53355 Mdot
.56909 .63736 Mdot
.64084 .56108 Mdot
.36636 .68882 Mdot
.35077 .55777 Mdot
.61381 .38794 Mdot
.28016 .67795 Mdot
.82482 .48537 Mdot
.67202 .4899 Mdot
.29561 .4117 Mdot
.61765 .36521 Mdot
.42944 .34189 Mdot
.64625 .39272 Mdot
.68291 .54393 Mdot
.52614 .65516 Mdot
.46439 .44894 Mdot
.36381 .61624 Mdot
.37058 .56438 Mdot
.4723 .39819 Mdot
.19978 .5984 Mdot
.53334 .6326 Mdot
.49211 .65632 Mdot
.41968 .34975 Mdot
.45628 .33707 Mdot
.35747 .58055 Mdot
.67038 .51506 Mdot
.675 .3061 Mdot
.62621 .3602 Mdot
.46053 .43917 Mdot
.43084 .35592 Mdot
.81595 .53912 Mdot
.51665 .64483 Mdot
.68267 .48751 Mdot
.43618 .34874 Mdot
.55834 .73789 Mdot
.43556 .34909 Mdot
.40644 .31425 Mdot
.65699 .50959 Mdot
.37748 .3508 Mdot
.47351 .37078 Mdot
.49235 .45499 Mdot
.55726 .6645 Mdot
.35625 .56725 Mdot
.38406 .55747 Mdot
.58582 .45281 Mdot
.54058 .63367 Mdot
.40358 .36451 Mdot
.51915 .64109 Mdot
.39425 .36478 Mdot
.47391 .40062 Mdot
.53828 .62136 Mdot
.35731 .58421 Mdot
.40291 .76703 Mdot
.35149 .68926 Mdot
.43705 .35539 Mdot
.38839 .41875 Mdot
.509 .25385 Mdot
.52815 .18406 Mdot
.43181 .42337 Mdot
.37693 .57344 Mdot
.46539 .37231 Mdot
.55008 .66401 Mdot
.62475 .35233 Mdot
.37769 .57777 Mdot
.67474 .52108 Mdot
.68552 .49354 Mdot
.51479 .74326 Mdot
.67401 .54499 Mdot
.4574 .34672 Mdot
.40525 .61433 Mdot
.3405 .55188 Mdot
.15168 .44945 Mdot
.64781 .54124 Mdot
.64369 .36468 Mdot
.43999 .3664 Mdot
.77229 .62814 Mdot
.55636 .68326 Mdot
.81913 .69893 Mdot
.81383 .40585 Mdot
.58774 .3557 Mdot
.64523 .21723 Mdot
.63057 .5613 Mdot
.47807 .39884 Mdot
.61416 .39336 Mdot
.6652 .49158 Mdot
.46084 .35217 Mdot
.46017 .45425 Mdot
.41087 .21568 Mdot
.5737 .46544 Mdot
.51847 .63904 Mdot
.62449 .53233 Mdot
.65658 .37756 Mdot
.6958 .49217 Mdot
.36923 .56203 Mdot
.45478 .39609 Mdot
.42461 .47205 Mdot
.67384 .51723 Mdot
.70176 .50469 Mdot
.39394 .38619 Mdot
.34005 .56303 Mdot
.71538 .51198 Mdot
.43891 .37537 Mdot
.40008 .29337 Mdot
.39603 .61331 Mdot
.67461 .53416 Mdot
.44583 .43356 Mdot
.57728 .33012 Mdot
.66593 .52298 Mdot
.66267 .50498 Mdot
.47308 .39822 Mdot
.64234 .36942 Mdot
.40747 .43422 Mdot
.56197 .636 Mdot
.39432 .20612 Mdot
.54479 .66463 Mdot
.72526 .38253 Mdot
.49836 .37962 Mdot
.61174 .60259 Mdot
.37057 .56012 Mdot
.65626 .36488 Mdot
.58127 .78205 Mdot
.42598 .3283 Mdot
.28217 .72901 Mdot
.5244 .50124 Mdot
.17315 .56775 Mdot
.55914 .81463 Mdot
.62328 .37358 Mdot
.54919 .63839 Mdot
.44422 .42517 Mdot
.51906 .67488 Mdot
.60279 .38847 Mdot
.32113 .26831 Mdot
.45139 .43241 Mdot
.34203 .58805 Mdot
.3957 .3972 Mdot
.33699 .5782 Mdot
.47277 .38953 Mdot
.42184 .31856 Mdot
.63586 .72334 Mdot
.62978 .27432 Mdot
.46994 .35726 Mdot
.68509 .76387 Mdot
.76323 .46377 Mdot
.62761 .36681 Mdot
.40286 .38149 Mdot
.6413 .49488 Mdot
.55144 .67452 Mdot
.42426 .60352 Mdot
.64752 .51381 Mdot
.50824 .64574 Mdot
.36334 .57934 Mdot
.64967 .54793 Mdot
.69547 .5009 Mdot
.37266 .39226 Mdot
.63493 .39608 Mdot
.52363 .65893 Mdot
.45576 .40181 Mdot
.4582 .42719 Mdot
.72029 .3247 Mdot
.74325 .42961 Mdot
.36007 .54335 Mdot
.84571 .56186 Mdot
.36657 .54925 Mdot
.61533 .35768 Mdot
.65192 .51011 Mdot
.43008 .42019 Mdot
.41183 .39626 Mdot
.60414 .72289 Mdot
.31573 .60565 Mdot
.56262 .47522 Mdot
.2764 .38179 Mdot
.71333 .51426 Mdot
.54376 .28854 Mdot
.3554 .56367 Mdot
.54343 .28665 Mdot
.6557 .37994 Mdot
.26834 .68157 Mdot
.6179 .28019 Mdot
.52674 .62807 Mdot
.53854 .28757 Mdot
.35321 .6101 Mdot
.45623 .35704 Mdot
.6216 .52077 Mdot
.6799 .54112 Mdot
.35239 .57384 Mdot
.69006 .5534 Mdot
.62269 .3877 Mdot
.4506 .42537 Mdot
.80231 .41589 Mdot
.46262 .7222 Mdot
.67624 .51051 Mdot
.44393 .31744 Mdot
.53255 .66266 Mdot
.47359 .40692 Mdot
.59306 .37661 Mdot
.52844 .64416 Mdot
.76408 .41674 Mdot
.39996 .71281 Mdot
.43439 .37058 Mdot
.7889 .61537 Mdot
.53595 .63629 Mdot
.61157 .20628 Mdot
.44388 .37989 Mdot
.56561 .65518 Mdot
.36254 .3604 Mdot
.7465 .56526 Mdot
.54248 .47994 Mdot
.28219 .75374 Mdot
.55304 .48523 Mdot
.61492 .54458 Mdot
.72472 .60384 Mdot
.69666 .66013 Mdot
.52419 .67667 Mdot
.70027 .50131 Mdot
.62937 .32826 Mdot
.54349 .66768 Mdot
.38689 .38198 Mdot
.42776 .4133 Mdot
.29846 .3391 Mdot
.51894 .5115 Mdot
.66911 .47787 Mdot
.47686 .69484 Mdot
.45192 .43857 Mdot
.37656 .38408 Mdot
.41809 .3912 Mdot
.33342 .64009 Mdot
.5207 .64909 Mdot
.75404 .69813 Mdot
.5433 .63238 Mdot
.77267 .35155 Mdot
.65415 .52528 Mdot
.62962 .54317 Mdot
.44606 .40625 Mdot
.60864 .58233 Mdot
.50937 .29901 Mdot
.40279 .40294 Mdot
.59765 .5595 Mdot
.21482 .37808 Mdot
.3912 .35947 Mdot
.39524 .60252 Mdot
.50646 .36621 Mdot
.34455 .64614 Mdot
.56999 .64725 Mdot
.61568 .37497 Mdot
.64964 .35305 Mdot
.5233 .65569 Mdot
.43741 .393 Mdot
.60839 .61542 Mdot
.41835 .40722 Mdot
.44951 .35186 Mdot
.76965 .33634 Mdot
.58921 .35585 Mdot
.63414 .53323 Mdot
.59801 .37442 Mdot
.33367 .57347 Mdot
.62217 .8793 Mdot
.63694 .36836 Mdot
.50529 .30106 Mdot
.34439 .24216 Mdot
.5354 .28471 Mdot
.36432 .56137 Mdot
.60389 .40071 Mdot
.52682 .63297 Mdot
.19722 .64669 Mdot
.49953 .17637 Mdot
.50094 .62202 Mdot
.43439 .37942 Mdot
.33938 .56079 Mdot
.3844 .59064 Mdot
.56979 .62488 Mdot
.34599 .61133 Mdot
.36412 .40466 Mdot
.44544 .35448 Mdot
.5167 .67163 Mdot
.46049 .74368 Mdot
.55567 .61319 Mdot
.41256 .68064 Mdot
.39963 .38563 Mdot
.36412 .56493 Mdot
.50682 .37103 Mdot
.30724 .62657 Mdot
.68037 .48596 Mdot
.41678 .34407 Mdot
.6208 .38853 Mdot
.5939 .60028 Mdot
.66673 .53228 Mdot
.77947 .57987 Mdot
.33245 .59669 Mdot
.5209 .58876 Mdot
.33888 .60629 Mdot
.30958 .59482 Mdot
.51648 .66042 Mdot
.32241 .61003 Mdot
.44581 .42611 Mdot
.62285 .50347 Mdot
.32616 .59281 Mdot
.54911 .65383 Mdot
.60939 .37436 Mdot
.36462 .5882 Mdot
.70553 .476 Mdot
.44868 .36647 Mdot
.66346 .49628 Mdot
.65673 .72096 Mdot
.32366 .57153 Mdot
.59287 .39201 Mdot
.64492 .55321 Mdot
.62691 .39752 Mdot
.19097 .40117 Mdot
.50296 .64877 Mdot
.68015 .25467 Mdot
.57883 .33233 Mdot
.375 .61096 Mdot
.6485 .72278 Mdot
.43213 .41786 Mdot
.4463 .36535 Mdot
.63045 .40291 Mdot
.38436 .59122 Mdot
.22387 .64765 Mdot
.34012 .53256 Mdot
.41225 .71361 Mdot
.50152 .65681 Mdot
.7522 .68496 Mdot
.40228 .67061 Mdot
.25688 .29117 Mdot
.38791 .35174 Mdot
.62455 .56034 Mdot
.43256 .39872 Mdot
.56632 .78274 Mdot
.60383 .35436 Mdot
.65855 .41566 Mdot
.49444 .38222 Mdot
.63859 .54326 Mdot
.45724 .37978 Mdot
.44738 .56594 Mdot
.4808 .33571 Mdot
.63581 .35706 Mdot
.59917 .69725 Mdot
.3706 .61794 Mdot
.61127 .36653 Mdot
.69578 .51929 Mdot
.52375 .29896 Mdot
.47333 .36384 Mdot
.40861 .32994 Mdot
.71323 .50738 Mdot
.33998 .59202 Mdot
.61791 .53716 Mdot
.56878 .64579 Mdot
.62007 .38243 Mdot
.43769 .36227 Mdot
.48948 .38806 Mdot
.65225 .63423 Mdot
.52271 .66046 Mdot
.70252 .53962 Mdot
.55165 .63154 Mdot
.61405 .55333 Mdot
.39508 .42748 Mdot
.63033 .54469 Mdot
.48163 .392 Mdot
.60943 .76349 Mdot
.76455 .33234 Mdot
.24139 .50853 Mdot
.64322 .54961 Mdot
.57266 .29952 Mdot
.55266 .65942 Mdot
.56207 .64106 Mdot
.32877 .28725 Mdot
.38554 .48391 Mdot
.75302 .37324 Mdot
.40047 .79391 Mdot
.56877 .63804 Mdot
.53953 .66224 Mdot
.66524 .49453 Mdot
.32081 .60484 Mdot
.31605 .57696 Mdot
.64479 .56224 Mdot
.52872 .2157 Mdot
.3496 .59989 Mdot
.26661 .70113 Mdot
.75247 .38611 Mdot
.37369 .41416 Mdot
.48234 .62646 Mdot
.61465 .38165 Mdot
.54664 .22729 Mdot
.44898 .57798 Mdot
.4398 .42982 Mdot
.81408 .54935 Mdot
.66486 .51544 Mdot
.46189 .24254 Mdot
.35263 .79274 Mdot
.45551 .4311 Mdot
.44671 .38589 Mdot
.4289 .39223 Mdot
.5845 .36421 Mdot
.33423 .41288 Mdot
.45334 .42859 Mdot
.5274 .21328 Mdot
.457 .43775 Mdot
.54019 .40268 Mdot
.59857 .3709 Mdot
.52681 .36175 Mdot
.63841 .69884 Mdot
.79998 .48184 Mdot
.50315 .42622 Mdot
.56768 .64491 Mdot
.58054 .50881 Mdot
.55816 .66595 Mdot
.23936 .54646 Mdot
.61111 .27769 Mdot
.39691 .57726 Mdot
.44058 .42821 Mdot
.66668 .5417 Mdot
.38434 .5881 Mdot
.69845 .63022 Mdot
.49541 .93178 Mdot
.56848 .6551 Mdot
.32089 .19544 Mdot
.55882 .63521 Mdot
.69836 .50642 Mdot
.35751 .57906 Mdot
.31453 .49067 Mdot
.5722 .55761 Mdot
.36619 .59046 Mdot
.39264 .75145 Mdot
.31275 .56719 Mdot
.55531 .29847 Mdot
.3551 .5505 Mdot
.55101 .65552 Mdot
.58113 .63479 Mdot
.41856 .46509 Mdot
.44141 .41437 Mdot
.48902 .56405 Mdot
.53555 .31978 Mdot
.43662 .41675 Mdot
.66855 .5367 Mdot
.59578 .1925 Mdot
.59965 .44601 Mdot
.33785 .61853 Mdot
.53587 .60886 Mdot
.44949 .38497 Mdot
.43268 .35173 Mdot
.46697 .35894 Mdot
.85219 .56115 Mdot
.25496 .67262 Mdot
.47491 .37816 Mdot
.44273 .44391 Mdot
.64658 .54737 Mdot
.64192 .40987 Mdot
.54563 .79247 Mdot
.51658 .44369 Mdot
.4178 .42778 Mdot
.60631 .3642 Mdot
.59514 .34753 Mdot
.46062 .35154 Mdot
.78467 .49693 Mdot
.63618 .60487 Mdot
.4562 .40155 Mdot
.41911 .48788 Mdot
.71553 .65145 Mdot
.70158 .50576 Mdot
.67217 .51942 Mdot
.37945 .61495 Mdot
.67521 .5414 Mdot
.68659 .54328 Mdot
.31753 .46924 Mdot
.55654 .50364 Mdot
.56734 .69013 Mdot
.59625 .35675 Mdot
.41236 .39992 Mdot
.34798 .54609 Mdot
.57684 .72728 Mdot
.53165 .66835 Mdot
.37596 .59463 Mdot
.55626 .67261 Mdot
.57841 .3689 Mdot
.43273 .22299 Mdot
.68498 .53851 Mdot
.5646 .62509 Mdot
.40002 .71162 Mdot
.6037 .36558 Mdot
.51071 .64607 Mdot
.61672 .61544 Mdot
.38612 .37927 Mdot
.29396 .54651 Mdot
.40109 .39768 Mdot
.1972 .61173 Mdot
.51187 .64361 Mdot
.61988 .71673 Mdot
.44512 .39519 Mdot
.66406 .52589 Mdot
.3891 .32228 Mdot
.41358 .42065 Mdot
.67956 .5212 Mdot
.45851 .35671 Mdot
.6015 .39125 Mdot
.38841 .62739 Mdot
.5722 .50984 Mdot
.76139 .27283 Mdot
.63272 .39791 Mdot
.68796 .63039 Mdot
.43318 .42468 Mdot
.23565 .34651 Mdot
.36396 .58993 Mdot
.48492 .39122 Mdot
.46793 .2885 Mdot
.32266 .58934 Mdot
.37513 .58335 Mdot
.41505 .36108 Mdot
.53224 .6271 Mdot
.67017 .53047 Mdot
.60051 .36991 Mdot
.18982 .38591 Mdot
.42429 .3809 Mdot
.46137 .37009 Mdot
.61547 .36554 Mdot
.54163 .66389 Mdot
.42679 .35179 Mdot
.66599 .73159 Mdot
.15141 .54225 Mdot
.52951 .67089 Mdot
.39036 .40605 Mdot
.31199 .5406 Mdot
.34125 .64874 Mdot
.40878 .17118 Mdot
.67237 .32356 Mdot
.63113 .53705 Mdot
.36209 .35033 Mdot
.70405 .80891 Mdot
.61378 .37563 Mdot
.80974 .45092 Mdot
.44734 .34967 Mdot
.46807 .38341 Mdot
.37348 .60665 Mdot
.39938 .37408 Mdot
.32018 .58449 Mdot
.72388 .24433 Mdot
.8203 .55798 Mdot
.33563 .58762 Mdot
.36601 .61664 Mdot
.49423 .30045 Mdot
.54951 .79043 Mdot
.35481 .57268 Mdot
.42271 .44723 Mdot
.23699 .61551 Mdot
.50975 .43706 Mdot
.63424 .40201 Mdot
.68109 .69783 Mdot
.29841 .63054 Mdot
.61905 .43673 Mdot
.39149 .77546 Mdot
.29572 .63215 Mdot
.65874 .59733 Mdot
.56088 .63144 Mdot
.44417 .43749 Mdot
.67718 .54341 Mdot
.63508 .55061 Mdot
.48295 .34118 Mdot
.41344 .40685 Mdot
.3307 .5831 Mdot
.59878 .35212 Mdot
.53681 .67818 Mdot
.46528 .36821 Mdot
.60291 .44723 Mdot
.63357 .36585 Mdot
.33127 .61198 Mdot
.36185 .27506 Mdot
.64027 .36019 Mdot
.48616 .3344 Mdot
.45721 .41104 Mdot
.39255 .38434 Mdot
.48325 .467 Mdot
.5368 .61876 Mdot
.64437 .73197 Mdot
.39598 .42083 Mdot
.80158 .50264 Mdot
.48829 .49014 Mdot
.37565 .34885 Mdot
.34537 .60403 Mdot
.55697 .68365 Mdot
.65795 .48667 Mdot
.43777 .26094 Mdot
.42956 .37444 Mdot
.2518 .65948 Mdot
.28936 .35887 Mdot
.66301 .48721 Mdot
.31511 .61205 Mdot
.60811 .38373 Mdot
.40466 .40402 Mdot
.23965 .57842 Mdot
.43167 .41023 Mdot
.57398 .3444 Mdot
.66346 .50811 Mdot
.55901 .62943 Mdot
.16767 .56163 Mdot
.63423 .54999 Mdot
.3738 .57818 Mdot
.29896 .78627 Mdot
.34701 .55419 Mdot
.34928 .62487 Mdot
.25284 .59146 Mdot
.5461 .61892 Mdot
.72797 .79296 Mdot
.47516 .1696 Mdot
.47018 .34369 Mdot
.55685 .65795 Mdot
.34706 .57747 Mdot
.47242 .40879 Mdot
.37736 .56166 Mdot
.32672 .62344 Mdot
.37631 .39981 Mdot
.46677 .40024 Mdot
.3693 .68501 Mdot
.3042 .76061 Mdot
.6041 .38243 Mdot
.34264 .5646 Mdot
.39636 .28478 Mdot
.47123 .41519 Mdot
.44416 .40118 Mdot
.71939 .63559 Mdot
.64233 .36717 Mdot
.42779 .63301 Mdot
.44107 .34955 Mdot
.81104 .58373 Mdot
.50764 .36878 Mdot
.38544 .61234 Mdot
.5266 .66867 Mdot
.79751 .47414 Mdot
.53179 .7184 Mdot
.31516 .60066 Mdot
.59188 .3673 Mdot
.38303 .55546 Mdot
.50906 .3043 Mdot
.55112 .6151 Mdot
.38036 .58138 Mdot
.54392 .49413 Mdot
.53627 .64578 Mdot
.51393 .63955 Mdot
.22921 .57616 Mdot
.69026 .54842 Mdot
.58619 .37632 Mdot
.52741 .66035 Mdot
.36567 .30263 Mdot
.55252 .64707 Mdot
.33262 .30171 Mdot
.40275 .42285 Mdot
.48469 .22376 Mdot
.51521 .57975 Mdot
.3831 .45407 Mdot
.51814 .62585 Mdot
.60117 .38605 Mdot
.4207 .35622 Mdot
.3496 .61289 Mdot
.63689 .37592 Mdot
.4984 .61341 Mdot
.65011 .50678 Mdot
.33678 .60745 Mdot
.50057 .64004 Mdot
.34809 .56428 Mdot
.42939 .25037 Mdot
.37774 .21147 Mdot
.70608 .70457 Mdot
.56789 .5508 Mdot
.46365 .35634 Mdot
.45883 .80157 Mdot
.37896 .41862 Mdot
.41406 .41149 Mdot
.67346 .53403 Mdot
.47744 .23825 Mdot
.35673 .58341 Mdot
.16843 .5702 Mdot
.56407 .6281 Mdot
.82449 .53815 Mdot
.38992 .54379 Mdot
.48562 .38746 Mdot
.32571 .59017 Mdot
.35165 .55238 Mdot
.22639 .492 Mdot
.68804 .48245 Mdot
.4313 .45727 Mdot
.41425 .45782 Mdot
.39207 .34121 Mdot
.51592 .63795 Mdot
.7812 .56989 Mdot
.61875 .55117 Mdot
.37822 .19907 Mdot
.66854 .5084 Mdot
.59272 .55516 Mdot
.32529 .61218 Mdot
.63928 .37006 Mdot
.44651 .40173 Mdot
.37552 .53155 Mdot
.31423 .59958 Mdot
.5697 .36781 Mdot
.62768 .38912 Mdot
.74497 .58372 Mdot
.53729 .6212 Mdot
.474 .36025 Mdot
.44631 .43291 Mdot
.40536 .37469 Mdot
.39795 .40565 Mdot
.56956 .653 Mdot
.40588 .35657 Mdot
.57708 .65995 Mdot
.35743 .30366 Mdot
.81221 .56158 Mdot
.55319 .50203 Mdot
.41908 .55961 Mdot
.34601 .6171 Mdot
.37476 .30208 Mdot
.48441 .33148 Mdot
.73845 .30469 Mdot
.17941 .48185 Mdot
.3977 .35355 Mdot
.65917 .49316 Mdot
.38003 .48081 Mdot
.67552 .54919 Mdot
.39358 .14615 Mdot
.64696 .64095 Mdot
.28341 .74584 Mdot
.4641 .41984 Mdot
.72139 .63717 Mdot
.34567 .36997 Mdot
.38805 .43516 Mdot
.68216 .64632 Mdot
.52958 .73057 Mdot
.42407 .7489 Mdot
.60908 .34456 Mdot
.44636 .3704 Mdot
.32814 .55609 Mdot
.44763 .42678 Mdot
.43842 .40102 Mdot
.44616 .34822 Mdot
.51493 .62322 Mdot
.45125 .45225 Mdot
.39161 .39693 Mdot
.74617 .49284 Mdot
.56915 .27943 Mdot
.62284 .53514 Mdot
.32489 .28518 Mdot
.63633 .36963 Mdot
.3292 .59122 Mdot
.33611 .7223 Mdot
.52622 .62801 Mdot
.22624 .4754 Mdot
.39386 .39656 Mdot
.38029 .69714 Mdot
.49813 .647 Mdot
.62156 .38455 Mdot
.6139 .53507 Mdot
.25468 .71799 Mdot
.66143 .54184 Mdot
.53947 .49665 Mdot
.66196 .53009 Mdot
.51494 .37701 Mdot
.33117 .58177 Mdot
.44898 .34676 Mdot
.52892 .65923 Mdot
.67939 .52979 Mdot
.52427 .25346 Mdot
.41969 .39174 Mdot
.64476 .54271 Mdot
.44721 .34657 Mdot
.44418 .21725 Mdot
.69053 .28974 Mdot
.69308 .53716 Mdot
.5743 .67573 Mdot
.54083 .64927 Mdot
.64061 .3665 Mdot
.33034 .60315 Mdot
.36989 .608 Mdot
.53059 .64323 Mdot
.52876 .17679 Mdot
.4173 .42621 Mdot
.47068 .41279 Mdot
.80395 .50161 Mdot
.44161 .42153 Mdot
.54189 .30575 Mdot
.54118 .48896 Mdot
.33682 .61553 Mdot
.47687 .39559 Mdot
.43184 .35331 Mdot
.43747 .36846 Mdot
.41648 .24706 Mdot
.67347 .5137 Mdot
.42712 .43666 Mdot
.62732 .39198 Mdot
.63008 .50308 Mdot
.47363 .40974 Mdot
.39286 .33919 Mdot
.37119 .60647 Mdot
.83998 .51184 Mdot
.55312 .62868 Mdot
.69513 .51066 Mdot
.63329 .54515 Mdot
.68503 .69417 Mdot
.28268 .60564 Mdot
.54396 .48665 Mdot
.35756 .20895 Mdot
.63412 .71096 Mdot
.62129 .36365 Mdot
.59507 .58715 Mdot
.5133 .47615 Mdot
.67961 .49374 Mdot
.56402 .66659 Mdot
.39792 .42024 Mdot
.41465 .42703 Mdot
.80848 .38396 Mdot
.48577 .3821 Mdot
.60993 .38215 Mdot
.57649 .64808 Mdot
.35415 .60904 Mdot
.62001 .38556 Mdot
.55969 .639 Mdot
.34007 .59432 Mdot
.38239 .3844 Mdot
.38154 .39449 Mdot
.37488 .59384 Mdot
.38268 .59398 Mdot
.45539 .40603 Mdot
.60659 .55854 Mdot
.37311 .61852 Mdot
.36944 .5659 Mdot
.68482 .5394 Mdot
.68148 .53762 Mdot
.37134 .38735 Mdot
.55885 .65165 Mdot
.39 .37967 Mdot
.65624 .54641 Mdot
.61147 .34951 Mdot
.3586 .58923 Mdot
.43774 .35431 Mdot
.45941 .36153 Mdot
.60362 .36713 Mdot
.60258 .34748 Mdot
.62585 .38706 Mdot
.57617 .63026 Mdot
.40955 .379 Mdot
.36063 .57486 Mdot
.5467 .62137 Mdot
.5948 .34755 Mdot
.6481 .38608 Mdot
.69951 .55103 Mdot
.42866 .42173 Mdot
.71685 .4913 Mdot
.61566 .87745 Mdot
.60173 .31427 Mdot
.66535 .48527 Mdot
.70991 .52547 Mdot
.53541 .2729 Mdot
.60919 .57705 Mdot
.53051 .63579 Mdot
.61433 .32329 Mdot
.65558 .36299 Mdot
.41569 .34523 Mdot
.38871 .41692 Mdot
.40031 .4533 Mdot
.62933 .38011 Mdot
.45492 .26051 Mdot
.37141 .55905 Mdot
.25219 .37562 Mdot
.63644 .37179 Mdot
.70295 .50701 Mdot
.69028 .54997 Mdot
.66779 .50798 Mdot
.38882 .41166 Mdot
.24129 .49927 Mdot
.4622 .30324 Mdot
.45923 .80796 Mdot
.51309 .63419 Mdot
.39554 .56813 Mdot
.20826 .38001 Mdot
.37479 .58851 Mdot
.65975 .55839 Mdot
.63285 .37444 Mdot
.3812 .57954 Mdot
.54738 .67183 Mdot
.5368 .66123 Mdot
.67328 .51029 Mdot
.65522 .52164 Mdot
.67117 .49819 Mdot
.3384 .62555 Mdot
.32301 .61002 Mdot
.42347 .378 Mdot
.36101 .59894 Mdot
.83358 .43668 Mdot
.58154 .3715 Mdot
.71027 .52959 Mdot
.55035 .63781 Mdot
.33567 .58006 Mdot
.41555 .3922 Mdot
.58711 .46193 Mdot
.49862 .73338 Mdot
.62225 .39882 Mdot
.70891 .31131 Mdot
.38656 .15234 Mdot
.48026 .36779 Mdot
.51668 .64112 Mdot
.79766 .4115 Mdot
.42779 .39029 Mdot
.65188 .51331 Mdot
.60806 .77077 Mdot
.62876 .50891 Mdot
.38868 .37912 Mdot
.47651 .3569 Mdot
.51325 .66161 Mdot
.32923 .2469 Mdot
.41845 .38199 Mdot
.43791 .64408 Mdot
.53894 .60681 Mdot
.62741 .556 Mdot
.1524 .5563 Mdot
.71351 .67772 Mdot
.53814 .22272 Mdot
.68736 .53534 Mdot
.42223 .41243 Mdot
.68783 .5297 Mdot
.61823 .39755 Mdot
.69152 .5164 Mdot
.39348 .61009 Mdot
.62038 .53908 Mdot
.462 .37148 Mdot
.35353 .57136 Mdot
.53631 .63561 Mdot
.82366 .52185 Mdot
.74679 .46847 Mdot
.66338 .52528 Mdot
.69816 .5226 Mdot
.47681 .37825 Mdot
.40595 .65538 Mdot
.46041 .33274 Mdot
.46709 .41833 Mdot
.56837 .63137 Mdot
.32525 .59525 Mdot
.50882 .63111 Mdot
.47725 .42208 Mdot
.65796 .74406 Mdot
.5463 .62815 Mdot
.37161 .69772 Mdot
.61822 .36478 Mdot
.45743 .53837 Mdot
.41028 .39871 Mdot
.53216 .66574 Mdot
.40841 .37985 Mdot
.38142 .56532 Mdot
.49952 .52707 Mdot
.58409 .73211 Mdot
.52944 .65725 Mdot
.21785 .63225 Mdot
.64423 .57288 Mdot
.50105 .41095 Mdot
.56399 .6585 Mdot
.46923 .29021 Mdot
.69675 .50239 Mdot
.62513 .36083 Mdot
.59802 .34671 Mdot
.63132 .39577 Mdot
.42446 .33188 Mdot
.50555 .40932 Mdot
.59042 .37925 Mdot
.53606 .6745 Mdot
.63033 .35254 Mdot
.27781 .63993 Mdot
.22011 .64397 Mdot
.60212 .35598 Mdot
.44142 .37806 Mdot
.46241 .4684 Mdot
.56353 .27486 Mdot
.70691 .48137 Mdot
.28735 .73954 Mdot
.41966 .577 Mdot
.43969 .41319 Mdot
.34965 .65309 Mdot
.37648 .56486 Mdot
.79335 .41568 Mdot
.54712 .32526 Mdot
.78346 .47818 Mdot
.36316 .6195 Mdot
.59956 .72307 Mdot
.33233 .61073 Mdot
.48167 .37548 Mdot
.4711 .40631 Mdot
.31286 .58124 Mdot
.79121 .57031 Mdot
.65908 .62088 Mdot
.15667 .49591 Mdot
.36489 .56297 Mdot
.55594 .66539 Mdot
.572 .6416 Mdot
.51625 .63138 Mdot
.74348 .37529 Mdot
.32662 .57091 Mdot
.41674 .3735 Mdot
.64882 .54947 Mdot
.42714 .43371 Mdot
.52911 .64924 Mdot
.17101 .57487 Mdot
.3638 .6099 Mdot
.45739 .39857 Mdot
.52639 .18637 Mdot
.64684 .52165 Mdot
.60815 .36157 Mdot
.42054 .22107 Mdot
.76887 .42078 Mdot
.54643 .61648 Mdot
.33039 .56222 Mdot
.61352 .69718 Mdot
.35685 .69914 Mdot
.38021 .36528 Mdot
.36763 .37971 Mdot
.22706 .32906 Mdot
.7597 .411 Mdot
.44306 .34231 Mdot
.69432 .5045 Mdot
.60553 .72306 Mdot
.44381 .35812 Mdot
.36085 .55946 Mdot
.61941 .34407 Mdot
.63539 .38873 Mdot
.41276 .44909 Mdot
.57722 .56135 Mdot
.46184 .51303 Mdot
.40294 .36416 Mdot
.48664 .3345 Mdot
.65864 .55721 Mdot
.63391 .70562 Mdot
.81014 .51576 Mdot
.59157 .36343 Mdot
.4373 .34748 Mdot
.43552 .76901 Mdot
.32172 .61646 Mdot
.63185 .51347 Mdot
.5476 .61378 Mdot
.39606 .25017 Mdot
.62229 .55398 Mdot
.44407 .35721 Mdot
.42803 .35195 Mdot
.51021 .64805 Mdot
.3856 .61227 Mdot
.62992 .3782 Mdot
.64278 .55027 Mdot
.59079 .36583 Mdot
.32261 .58399 Mdot
.36037 .6096 Mdot
.51639 .42723 Mdot
.48266 .43949 Mdot
.6729 .52089 Mdot
.4732 .42424 Mdot
.6935 .46977 Mdot
.32522 .24617 Mdot
.50281 .66713 Mdot
.48095 .36814 Mdot
.34785 .64055 Mdot
.52547 .65571 Mdot
.46688 .39103 Mdot
.19699 .36222 Mdot
.46951 .42198 Mdot
.53815 .7208 Mdot
.69591 .72485 Mdot
.61019 .38956 Mdot
.23275 .37926 Mdot
.32525 .66878 Mdot
.4462 .42106 Mdot
.63756 .51561 Mdot
.40943 .31864 Mdot
.53106 .62938 Mdot
.33322 .6173 Mdot
.41557 .16525 Mdot
.55037 .64909 Mdot
.4569 .4233 Mdot
.62053 .38324 Mdot
.34141 .55507 Mdot
.5858 .51407 Mdot
.79188 .50673 Mdot
.49987 .36764 Mdot
.42926 .44926 Mdot
.39232 .37428 Mdot
.59484 .79414 Mdot
.69416 .50962 Mdot
.34161 .57761 Mdot
.51694 .63726 Mdot
.5282 .64231 Mdot
.67001 .5119 Mdot
.42605 .73982 Mdot
.45984 .53666 Mdot
.65054 .84226 Mdot
.68197 .52182 Mdot
.59552 .39541 Mdot
.4255 .64456 Mdot
.63645 .51546 Mdot
.6446 .53974 Mdot
.65853 .55686 Mdot
.56039 .70398 Mdot
.34288 .59519 Mdot
.45934 .36037 Mdot
.39102 .58001 Mdot
.4209 .41545 Mdot
.45739 .50145 Mdot
.52437 .65762 Mdot
.3372 .62011 Mdot
.20403 .35692 Mdot
.37743 .49467 Mdot
.43549 .38628 Mdot
.22051 .35893 Mdot
.49329 .37389 Mdot
.51358 .28039 Mdot
.49323 .41632 Mdot
.6582 .52594 Mdot
.35226 .367 Mdot
.42856 .32529 Mdot
.8293 .48983 Mdot
.55209 .63811 Mdot
.69444 .49697 Mdot
.44181 .33796 Mdot
.5047 .35956 Mdot
.31158 .5791 Mdot
.37831 .57448 Mdot
.58888 .37306 Mdot
.62961 .27196 Mdot
.53758 .63403 Mdot
.39614 .21041 Mdot
.44587 .41395 Mdot
.75646 .65368 Mdot
.22778 .39943 Mdot
.4658 .39124 Mdot
.23806 .62801 Mdot
.23502 .48964 Mdot
.40647 .4029 Mdot
.50482 .32093 Mdot
.54402 .66265 Mdot
.66454 .74098 Mdot
.44202 .44516 Mdot
.64818 .51472 Mdot
.32373 .60703 Mdot
.35856 .55665 Mdot
.59438 .38456 Mdot
.72992 .27682 Mdot
.50876 .63354 Mdot
.33256 .61822 Mdot
.42129 .39479 Mdot
.54592 .61773 Mdot
.67056 .54582 Mdot
.48579 .40865 Mdot
.55528 .31879 Mdot
.35869 .60146 Mdot
.45125 .44316 Mdot
.45405 .68772 Mdot
.57534 .24538 Mdot
.4666 .84611 Mdot
.51943 .62965 Mdot
.62879 .35527 Mdot
.39882 .32331 Mdot
.43201 .20192 Mdot
.39931 .35045 Mdot
.47824 .22558 Mdot
.27954 .62844 Mdot
.63002 .35551 Mdot
.44402 .39011 Mdot
.43173 .36553 Mdot
.52707 .57436 Mdot
.60025 .35014 Mdot
.44628 .43458 Mdot
.34773 .42797 Mdot
.34087 .59082 Mdot
.60992 .54268 Mdot
.35372 .60236 Mdot
.43518 .37954 Mdot
.46703 .45236 Mdot
.37776 .60272 Mdot
.32053 .22327 Mdot
.62892 .34128 Mdot
.54921 .6262 Mdot
.49537 .42681 Mdot
.40466 .42818 Mdot
.68233 .77564 Mdot
.68164 .48663 Mdot
.51651 .79075 Mdot
.6764 .45602 Mdot
.41971 .77426 Mdot
.71769 .67237 Mdot
.28749 .77092 Mdot
.81574 .54405 Mdot
.41109 .45624 Mdot
.42071 .53043 Mdot
.49163 .31562 Mdot
.52009 .62321 Mdot
.31452 .39385 Mdot
.44071 .41449 Mdot
.43546 .40033 Mdot
.63831 .50526 Mdot
.39358 .72169 Mdot
.7886 .48911 Mdot
.57744 .53921 Mdot
.6283 .37564 Mdot
.33827 .56933 Mdot
.47322 .38618 Mdot
.57114 .44578 Mdot
.62431 .52941 Mdot
.76336 .64154 Mdot
.4541 .39499 Mdot
.73318 .3033 Mdot
.57317 .71135 Mdot
.53654 .61961 Mdot
.62737 .53763 Mdot
.77974 .44548 Mdot
.42425 .42225 Mdot
.56094 .61598 Mdot
.4156 .38588 Mdot
.70064 .56935 Mdot
.47874 .41428 Mdot
.61347 .35422 Mdot
.45554 .35113 Mdot
.58098 .53003 Mdot
.388 .82475 Mdot
.59375 .33333 Mdot
.34084 .56082 Mdot
.71103 .49864 Mdot
.67301 .51526 Mdot
.38212 .58595 Mdot
.67084 .51776 Mdot
.23141 .43627 Mdot
.29816 .48639 Mdot
.62711 .3713 Mdot
.49538 .34372 Mdot
.59692 .361 Mdot
.67936 .4854 Mdot
.43189 .41572 Mdot
.33787 .21414 Mdot
.67629 .52618 Mdot
.70683 .73032 Mdot
.55032 .64274 Mdot
.68852 .49061 Mdot
.45525 .43911 Mdot
.61677 .68035 Mdot
.62771 .54542 Mdot
.58887 .72495 Mdot
.4356 .36952 Mdot
.35543 .61245 Mdot
.43344 .36209 Mdot
.49997 .40096 Mdot
.6136 .55576 Mdot
.39506 .40692 Mdot
.55974 .63918 Mdot
.36205 .62596 Mdot
.23792 .67968 Mdot
.54497 .72386 Mdot
.44128 .4312 Mdot
.42328 .39349 Mdot
.33387 .55561 Mdot
.42342 .43722 Mdot
.56955 .65241 Mdot
.89175 .57255 Mdot
.61766 .36438 Mdot
.69975 .52529 Mdot
.70653 .6878 Mdot
.39145 .36095 Mdot
.41234 .35648 Mdot
.18337 .39375 Mdot
.7003 .7027 Mdot
.56493 .65083 Mdot
.44871 .3257 Mdot
.65057 .55191 Mdot
.61849 .38264 Mdot
.53081 .67483 Mdot
.39286 .38349 Mdot
.44557 .39861 Mdot
.62849 .35573 Mdot
.22798 .59002 Mdot
.77856 .41616 Mdot
.50994 .64056 Mdot
.35038 .37322 Mdot
.64728 .4546 Mdot
.41544 .42376 Mdot
.74518 .37014 Mdot
.37724 .5758 Mdot
.55762 .61895 Mdot
.49986 .80496 Mdot
.43006 .34394 Mdot
.53056 .66946 Mdot
.5403 .63369 Mdot
.43616 .32553 Mdot
.3158 .62925 Mdot
.34421 .63006 Mdot
.34605 .56526 Mdot
.84374 .43777 Mdot
.55581 .24118 Mdot
.6709 .49821 Mdot
.54257 .66325 Mdot
.68387 .54689 Mdot
.58918 .39207 Mdot
.53806 .47286 Mdot
.69608 .53308 Mdot
.38519 .58485 Mdot
.71309 .49574 Mdot
.43529 .36527 Mdot
.53387 .63595 Mdot
.67907 .49468 Mdot
.43987 .3364 Mdot
.3754 .66893 Mdot
.74229 .53532 Mdot
.64694 .373 Mdot
.61434 .34186 Mdot
.47215 .40197 Mdot
.6558 .48725 Mdot
.45345 .40577 Mdot
.55006 .6823 Mdot
.41432 .65556 Mdot
.41489 .34041 Mdot
.66397 .52274 Mdot
.34043 .656 Mdot
.7688 .42118 Mdot
.47706 .34483 Mdot
.44151 .37926 Mdot
.4163 .41864 Mdot
.41467 .3861 Mdot
.39623 .74044 Mdot
.50252 .66091 Mdot
.44619 .60795 Mdot
.64649 .72135 Mdot
.36806 .59673 Mdot
.33192 .63345 Mdot
.71264 .35143 Mdot
.66565 .5984 Mdot
.5578 .65476 Mdot
.41053 .41245 Mdot
.56874 .72966 Mdot
.17597 .58574 Mdot
.29804 .23292 Mdot
.56988 .37851 Mdot
.65799 .49035 Mdot
.32384 .56968 Mdot
.62673 .52852 Mdot
.42524 .4118 Mdot
.39285 .32558 Mdot
.28338 .77228 Mdot
.5808 .62073 Mdot
.63246 .37626 Mdot
.41731 .41706 Mdot
.556 .23539 Mdot
.6469 .54786 Mdot
.68067 .55366 Mdot
.45185 .43409 Mdot
.37221 .62666 Mdot
.59525 .82391 Mdot
.53119 .62073 Mdot
.42191 .58204 Mdot
.35772 .3277 Mdot
.46315 .66783 Mdot
.52335 .64987 Mdot
.77157 .4834 Mdot
.65201 .49099 Mdot
.20292 .47883 Mdot
.36904 .59945 Mdot
.63487 .37315 Mdot
.36945 .36348 Mdot
.3672 .6134 Mdot
.61484 .54762 Mdot
.345 .61835 Mdot
.45811 .35079 Mdot
.50266 .64265 Mdot
.63023 .5338 Mdot
.58004 .66739 Mdot
.31897 .63069 Mdot
.59494 .37704 Mdot
.48869 .58009 Mdot
.33319 .45656 Mdot
.23275 .48555 Mdot
.42186 .43322 Mdot
.56955 .44247 Mdot
.41224 .37463 Mdot
.30729 .58847 Mdot
.41546 .39006 Mdot
.35926 .65232 Mdot
.63392 .52148 Mdot
.44281 .44407 Mdot
.39773 .3665 Mdot
.30499 .35976 Mdot
.45343 .38669 Mdot
.46445 .44196 Mdot
.40631 .40672 Mdot
.38137 .54489 Mdot
.4736 .32926 Mdot
.34341 .60234 Mdot
.78182 .51524 Mdot
.64527 .53773 Mdot
.61046 .34241 Mdot
.642 .38299 Mdot
.49401 .2237 Mdot
.65904 .34349 Mdot
.4104 .73406 Mdot
.35154 .59467 Mdot
.55033 .63269 Mdot
.41212 .39003 Mdot
.41243 .80053 Mdot
.70195 .66496 Mdot
.6559 .55308 Mdot
.54533 .72381 Mdot
.35831 .3928 Mdot
.59985 .79518 Mdot
.46283 .43632 Mdot
.80449 .36858 Mdot
.44128 .46729 Mdot
.48068 .40614 Mdot
.66766 .5584 Mdot
.61606 .33574 Mdot
.43983 .44078 Mdot
.31257 .57698 Mdot
.62773 .35881 Mdot
.39224 .52236 Mdot
.62193 .47931 Mdot
.76883 .49699 Mdot
.30754 .43532 Mdot
.40987 .38209 Mdot
.63161 .53143 Mdot
.33625 .60632 Mdot
.81343 .52237 Mdot
.54918 .62231 Mdot
.58476 .58755 Mdot
.38816 .29137 Mdot
.26055 .30565 Mdot
.63395 .36676 Mdot
.22824 .58027 Mdot
.46289 .37102 Mdot
.72777 .38329 Mdot
.37749 .3916 Mdot
.1787 .58766 Mdot
.60134 .39926 Mdot
.35443 .63444 Mdot
.55771 .66378 Mdot
.38588 .57242 Mdot
.23678 .507 Mdot
.48277 .61699 Mdot
.5183 .54373 Mdot
.65649 .54318 Mdot
.45403 .60226 Mdot
.34809 .57248 Mdot
.42797 .34957 Mdot
.63709 .85427 Mdot
.37233 .56894 Mdot
.31718 .58956 Mdot
.34866 .23423 Mdot
.32669 .23983 Mdot
.35555 .37687 Mdot
.37282 .61266 Mdot
.65487 .54112 Mdot
.59964 .38012 Mdot
.42639 .36234 Mdot
.42345 .37549 Mdot
.37145 .60792 Mdot
.67523 .55637 Mdot
.39166 .50822 Mdot
.65503 .52338 Mdot
.33866 .59109 Mdot
.64298 .53038 Mdot
.6214 .7288 Mdot
.67938 .4916 Mdot
.4072 .4296 Mdot
.41438 .39017 Mdot
.67109 .46256 Mdot
.3601 .60954 Mdot
.40576 .36387 Mdot
.46304 .3595 Mdot
.35791 .57452 Mdot
.61437 .44483 Mdot
.30772 .54745 Mdot
.43663 .42656 Mdot
.44992 .36932 Mdot
.62442 .35244 Mdot
.54844 .45065 Mdot
.65213 .24469 Mdot
.42046 .35643 Mdot
.58369 .3745 Mdot
.33839 .62472 Mdot
.45748 .40378 Mdot
.29647 .6922 Mdot
.6046 .72471 Mdot
.43322 .34462 Mdot
.69485 .49967 Mdot
.40985 .33067 Mdot
.51205 .84121 Mdot
.46582 .42132 Mdot
.35157 .57808 Mdot
.3213 .59492 Mdot
.37391 .2351 Mdot
.37126 .57389 Mdot
.68007 .54076 Mdot
.53353 .64725 Mdot
.19482 .60676 Mdot
.6694 .5463 Mdot
.45134 .33482 Mdot
.47302 .16921 Mdot
.47971 .42752 Mdot
.43052 .33643 Mdot
.64036 .78342 Mdot
.66587 .54669 Mdot
.32755 .58392 Mdot
.57113 .57344 Mdot
.43022 .46098 Mdot
.54807 .61632 Mdot
.40692 .32336 Mdot
.39375 .41312 Mdot
.70201 .71774 Mdot
.54653 .76082 Mdot
.57278 .65942 Mdot
.37388 .41894 Mdot
.41918 .35666 Mdot
.72578 .50242 Mdot
.41622 .3943 Mdot
.59377 .36246 Mdot
.32552 .57581 Mdot
.64826 .50136 Mdot
.60579 .36903 Mdot
.44401 .41779 Mdot
.62884 .38151 Mdot
.66364 .49647 Mdot
.56101 .61769 Mdot
.42651 .41686 Mdot
.63366 .40261 Mdot
.6278 .37724 Mdot
.40997 .37238 Mdot
.32986 .61518 Mdot
.40069 .46849 Mdot
.46064 .40116 Mdot
.44249 .35242 Mdot
.36909 .60846 Mdot
.26825 .24186 Mdot
.46843 .42074 Mdot
.63716 .57122 Mdot
.31497 .59484 Mdot
.48117 .66798 Mdot
.65027 .49807 Mdot
.39482 .41554 Mdot
.56683 .62494 Mdot
.52734 .66299 Mdot
.67409 .55211 Mdot
.35252 .55041 Mdot
.67466 .45836 Mdot
.34528 .6556 Mdot
.46624 .44985 Mdot
.49125 .39905 Mdot
.52009 .16914 Mdot
.273 .74422 Mdot
.3562 .55787 Mdot
.66414 .56202 Mdot
.57465 .53655 Mdot
.54467 .66546 Mdot
.70653 .5306 Mdot
.33479 .55786 Mdot
.32967 .56549 Mdot
.34229 .61578 Mdot
.6371 .38217 Mdot
.65755 .45012 Mdot
.38677 .61279 Mdot
.37048 .62734 Mdot
.43616 .36761 Mdot
.41555 .35761 Mdot
.53879 .34821 Mdot
.59273 .29972 Mdot
.59413 .37923 Mdot
.66553 .51046 Mdot
.86629 .57567 Mdot
.55353 .6805 Mdot
.30159 .36478 Mdot
.41395 .3412 Mdot
.54782 .92131 Mdot
.46469 .43222 Mdot
.41809 .39628 Mdot
.36381 .62412 Mdot
.64583 .39567 Mdot
.60287 .35928 Mdot
.34363 .57235 Mdot
.30753 .60239 Mdot
.59439 .36048 Mdot
.18438 .53593 Mdot
.21819 .64732 Mdot
.51536 .58246 Mdot
.36068 .58133 Mdot
.33425 .47346 Mdot
.54567 .61312 Mdot
.34322 .64587 Mdot
.53628 .68063 Mdot
.64318 .54455 Mdot
.64429 .49522 Mdot
.51566 .63741 Mdot
.43362 .37159 Mdot
.68201 .50058 Mdot
.45203 .45175 Mdot
.20596 .57829 Mdot
.27178 .55817 Mdot
.74635 .62015 Mdot
.38904 .42333 Mdot
.78112 .50306 Mdot
.68628 .59834 Mdot
.45539 .41909 Mdot
.36198 .75176 Mdot
.63201 .37811 Mdot
.36506 .63678 Mdot
.5711 .64674 Mdot
.48548 .85168 Mdot
.41303 .42019 Mdot
.35328 .58175 Mdot
.55562 .64012 Mdot
.41978 .23821 Mdot
.43525 .64606 Mdot
.41941 .41761 Mdot
.67459 .8267 Mdot
.37673 .53613 Mdot
.65041 .50012 Mdot
.60473 .18988 Mdot
.39129 .57794 Mdot
.61101 .41578 Mdot
.64215 .70768 Mdot
.21829 .34919 Mdot
.32954 .59055 Mdot
.70274 .54432 Mdot
.34031 .56941 Mdot
.59257 .37084 Mdot
.39832 .60973 Mdot
.63546 .54522 Mdot
.44996 .38916 Mdot
.66438 .51666 Mdot
.59682 .38527 Mdot
.73741 .37371 Mdot
.57131 .64237 Mdot
.69399 .49681 Mdot
.53914 .65585 Mdot
.58984 .25258 Mdot
.64434 .74775 Mdot
.55788 .62896 Mdot
.40023 .22704 Mdot
.43588 .34146 Mdot
.39273 .59698 Mdot
.68245 .51487 Mdot
.63692 .70241 Mdot
.53045 .5639 Mdot
.3704 .59028 Mdot
.65862 .50675 Mdot
.41015 .29241 Mdot
.49021 .18492 Mdot
.5111 .3823 Mdot
.60919 .26833 Mdot
.36169 .57762 Mdot
.70722 .53351 Mdot
.80449 .50146 Mdot
.3848 .57878 Mdot
.68294 .52107 Mdot
.54671 .66929 Mdot
.52532 .6448 Mdot
.4396 .43823 Mdot
.55984 .69299 Mdot
.67008 .5038 Mdot
.71592 .58748 Mdot
.32143 .6169 Mdot
.43053 .2404 Mdot
.63434 .39817 Mdot
.6508 .53354 Mdot
.48727 .38732 Mdot
.31499 .63704 Mdot
.61306 .72563 Mdot
.39557 .50264 Mdot
.85025 .5929 Mdot
.66913 .51224 Mdot
.32134 .58122 Mdot
.35548 .58614 Mdot
.4736 .34268 Mdot
.56938 .55411 Mdot
.66715 .45643 Mdot
.49977 .19594 Mdot
.46567 .22698 Mdot
.61303 .54934 Mdot
.60371 .53449 Mdot
.46563 .34351 Mdot
.40373 .38609 Mdot
.54823 .66587 Mdot
.44817 .38367 Mdot
.35942 .62951 Mdot
.43274 .43968 Mdot
.52025 .65053 Mdot
.66666 .53851 Mdot
.43115 .41312 Mdot
.60327 .38682 Mdot
.57395 .63439 Mdot
.51189 .66065 Mdot
.65741 .53039 Mdot
.36331 .61687 Mdot
.58251 .34756 Mdot
.65529 .52108 Mdot
.41087 .38212 Mdot
.59651 .59768 Mdot
.46666 .35866 Mdot
.18757 .51113 Mdot
.38611 .58502 Mdot
.63052 .52328 Mdot
.31371 .60721 Mdot
.54439 .65693 Mdot
.6454 .72095 Mdot
.42853 .38365 Mdot
.68241 .5244 Mdot
.66924 .46538 Mdot
.20052 .55676 Mdot
.32713 .55777 Mdot
.61232 .62186 Mdot
.3285 .62829 Mdot
.61514 .53471 Mdot
.33781 .27055 Mdot
.62849 .36414 Mdot
.65122 .55354 Mdot
.26295 .71327 Mdot
.6703 .52394 Mdot
.4571 .38546 Mdot
.47012 .39216 Mdot
.65633 .49512 Mdot
.64259 .3701 Mdot
.82095 .55208 Mdot
.71218 .56851 Mdot
.32752 .58763 Mdot
.25311 .34091 Mdot
.80482 .66852 Mdot
.53039 .6897 Mdot
.55814 .66104 Mdot
.42551 .46122 Mdot
.48296 .40177 Mdot
.54036 .67946 Mdot
.53514 .60921 Mdot
.61352 .39971 Mdot
.65876 .55651 Mdot
.4061 .58327 Mdot
.56277 .6144 Mdot
.5059 .44394 Mdot
.66706 .34285 Mdot
.47601 .34 Mdot
.36683 .32271 Mdot
.38264 .40789 Mdot
.46889 .21962 Mdot
.51673 .64455 Mdot
.47545 .38833 Mdot
.48219 .34125 Mdot
.56454 .62316 Mdot
.59319 .3673 Mdot
.53823 .75194 Mdot
.64004 .52587 Mdot
.13433 .46812 Mdot
.48038 .38952 Mdot
.45943 .38956 Mdot
.51382 .63297 Mdot
.69436 .45753 Mdot
.35929 .61531 Mdot
.38717 .58293 Mdot
.69287 .5069 Mdot
.49136 .57371 Mdot
.40859 .42473 Mdot
.46206 .41453 Mdot
.63949 .51928 Mdot
.68977 .49175 Mdot
.72211 .60593 Mdot
.45884 .3627 Mdot
.55603 .64338 Mdot
.57941 .50792 Mdot
.51744 .6473 Mdot
.47943 .37163 Mdot
.45982 .38387 Mdot
.40891 .43039 Mdot
.4854 .38105 Mdot
.51173 .662 Mdot
.47448 .38405 Mdot
.49297 .44852 Mdot
.34687 .62095 Mdot
.39806 .40897 Mdot
.4586 .22212 Mdot
.44494 .3751 Mdot
.59664 .37637 Mdot
.4636 .48149 Mdot
.41714 .42077 Mdot
.39989 .42113 Mdot
.7069 .57113 Mdot
.44006 .39136 Mdot
.54881 .68241 Mdot
.36421 .5963 Mdot
.54148 .66329 Mdot
.51109 .64671 Mdot
.69159 .52975 Mdot
.59202 .38191 Mdot
.388 .36719 Mdot
.62704 .39623 Mdot
.38189 .3685 Mdot
.43636 .3431 Mdot
.66954 .70078 Mdot
.79882 .35613 Mdot
.77617 .40925 Mdot
.42788 .38283 Mdot
.6765 .53638 Mdot
.64255 .50574 Mdot
.42478 .55552 Mdot
.50838 .37665 Mdot
.5396 .67846 Mdot
.53145 .66495 Mdot
.55668 .31217 Mdot
.69404 .72236 Mdot
.59514 .37371 Mdot
.55822 .45683 Mdot
.4535 .45204 Mdot
.45471 .3556 Mdot
.48438 .41274 Mdot
.68914 .54073 Mdot
.58862 .55514 Mdot
.65496 .55266 Mdot
.55156 .72442 Mdot
.5193 .65377 Mdot
.40825 .41826 Mdot
.26103 .61862 Mdot
.37988 .57511 Mdot
.36399 .59715 Mdot
.5253 .67046 Mdot
.71203 .50813 Mdot
.55762 .36112 Mdot
.34263 .18664 Mdot
.39007 .54957 Mdot
.64898 .38713 Mdot
.45095 .42339 Mdot
.66597 .53454 Mdot
.35333 .56132 Mdot
.62811 .35078 Mdot
.43827 .34648 Mdot
.65724 .4533 Mdot
.42588 .38087 Mdot
.4942 .31783 Mdot
.32952 .61058 Mdot
.19133 .6131 Mdot
.35099 .55368 Mdot
.57441 .63837 Mdot
.56498 .6318 Mdot
.46657 .38821 Mdot
.54639 .17366 Mdot
.39227 .58979 Mdot
.53903 .709 Mdot
.60399 .39983 Mdot
.61146 .68664 Mdot
.59384 .35754 Mdot
.64055 .51099 Mdot
.63039 .36143 Mdot
.62884 .53875 Mdot
.59425 .30989 Mdot
.36245 .54287 Mdot
.61172 .36541 Mdot
.70141 .56074 Mdot
.50895 .38224 Mdot
.60688 .34401 Mdot
.39215 .44745 Mdot
.21122 .42243 Mdot
.64308 .51623 Mdot
.64087 .38047 Mdot
.42819 .35004 Mdot
.37541 .8024 Mdot
.56207 .64107 Mdot
.54771 .67858 Mdot
.47254 .44395 Mdot
.66798 .55622 Mdot
.3158 .5754 Mdot
.34733 .70903 Mdot
.49565 .61095 Mdot
.47012 .40463 Mdot
.43806 .4408 Mdot
.33849 .63665 Mdot
.30403 .56595 Mdot
.46339 .3828 Mdot
.33885 .32489 Mdot
.46771 .37262 Mdot
.54533 .67114 Mdot
.37207 .56166 Mdot
.35946 .59045 Mdot
.66227 .50275 Mdot
.37715 .6127 Mdot
.37297 .65032 Mdot
.60004 .62423 Mdot
.41262 .46132 Mdot
.54862 .65026 Mdot
.59689 .65532 Mdot
.5495 .72512 Mdot
.29366 .74064 Mdot
.33075 .63542 Mdot
.40522 .4314 Mdot
.31806 .61262 Mdot
.61647 .3852 Mdot
.35794 .60824 Mdot
.32009 .57593 Mdot
.45599 .41001 Mdot
.42208 .41206 Mdot
.66482 .54456 Mdot
.57338 .55466 Mdot
.34227 .623 Mdot
.47267 .39704 Mdot
.46911 .4369 Mdot
.46575 .44172 Mdot
.48851 .50884 Mdot
.35414 .55853 Mdot
.29358 .34305 Mdot
.46317 .27261 Mdot
.34428 .6231 Mdot
.54082 .84076 Mdot
.63531 .71251 Mdot
.69299 .48776 Mdot
.57129 .6788 Mdot
.45777 .36164 Mdot
.64948 .49683 Mdot
.42564 .41204 Mdot
.36635 .32299 Mdot
.44236 .39972 Mdot
.59962 .35326 Mdot
.41074 .45607 Mdot
.62186 .5195 Mdot
.65883 .51975 Mdot
.46908 .41454 Mdot
.43384 .41036 Mdot
.75269 .39128 Mdot
.30848 .60942 Mdot
.35567 .61596 Mdot
.7147 .47112 Mdot
.61685 .37182 Mdot
.55338 .61724 Mdot
.40863 .39888 Mdot
.69237 .52489 Mdot
.66183 .51703 Mdot
.38493 .56966 Mdot
.65034 .51453 Mdot
.52453 .6247 Mdot
.42586 .38635 Mdot
.54548 .67929 Mdot
.63678 .38645 Mdot
.34138 .56556 Mdot
.411 .41693 Mdot
.4368 .36734 Mdot
.32141 .59458 Mdot
.4055 .34922 Mdot
.62184 .35149 Mdot
.67027 .52151 Mdot
.33162 .59532 Mdot
.53145 .64698 Mdot
.63264 .52276 Mdot
.43596 .35693 Mdot
.85945 .58016 Mdot
.45516 .38018 Mdot
.44719 .35846 Mdot
.24621 .7072 Mdot
.40793 .45558 Mdot
.67733 .51136 Mdot
.36024 .63336 Mdot
.43119 .45085 Mdot
.50831 .22896 Mdot
.28432 .23875 Mdot
.66297 .55156 Mdot
.44918 .4269 Mdot
.30428 .76756 Mdot
.45919 .42339 Mdot
.40919 .20905 Mdot
.68908 .34533 Mdot
.45547 .57952 Mdot
.47004 .45281 Mdot
.52495 .62935 Mdot
.66691 .54411 Mdot
.63637 .51835 Mdot
.27885 .32856 Mdot
.45876 .41147 Mdot
.52398 .34677 Mdot
.40933 .35316 Mdot
.5232 .64779 Mdot
.5356 .31451 Mdot
.66586 .51289 Mdot
.81439 .44765 Mdot
.41561 .37471 Mdot
.3506 .55783 Mdot
.71386 .49825 Mdot
.6268 .71727 Mdot
.43796 .35383 Mdot
.62657 .39467 Mdot
.57988 .64361 Mdot
.42209 .45484 Mdot
.5456 .6462 Mdot
.4518 .35181 Mdot
.52072 .41905 Mdot
.65553 .21869 Mdot
.33466 .61608 Mdot
.55412 .66549 Mdot
.61886 .59858 Mdot
.37582 .39882 Mdot
.33017 .59361 Mdot
.36951 .59821 Mdot
.61512 .39889 Mdot
.53668 .52962 Mdot
.44558 .69099 Mdot
.32997 .518 Mdot
.27478 .32362 Mdot
.71285 .50022 Mdot
.64148 .62123 Mdot
.42448 .35965 Mdot
.75505 .6475 Mdot
.56713 .67262 Mdot
.45649 .38976 Mdot
.21487 .43658 Mdot
.35024 .56426 Mdot
.45435 .36846 Mdot
.59607 .36156 Mdot
.77649 .59219 Mdot
.77063 .62053 Mdot
.5527 .80547 Mdot
.65275 .54426 Mdot
.39326 .32651 Mdot
.40404 .31138 Mdot
.69934 .51791 Mdot
.38976 .36965 Mdot
.67851 .51642 Mdot
.18593 .43188 Mdot
.63166 .35492 Mdot
.34206 .56308 Mdot
.633 .71454 Mdot
.38506 .39909 Mdot
.48499 .4244 Mdot
.6293 .3482 Mdot
.39868 .38549 Mdot
.73404 .28357 Mdot
.72714 .63762 Mdot
.68234 .4971 Mdot
.34064 .61622 Mdot
.38813 .41046 Mdot
.5498 .50199 Mdot
.46255 .40563 Mdot
.29253 .51269 Mdot
.39846 .42047 Mdot
.44437 .67191 Mdot
.32391 .60789 Mdot
.54499 .64966 Mdot
.38412 .35026 Mdot
.43427 .39753 Mdot
.59515 .4608 Mdot
.4637 .45651 Mdot
.47455 .41209 Mdot
.31955 .56715 Mdot
.37044 .56288 Mdot
.3441 .60136 Mdot
.6207 .54232 Mdot
.70097 .71511 Mdot
.55444 .65327 Mdot
.41463 .32596 Mdot
.55949 .61251 Mdot
.37485 .48144 Mdot
.64662 .36921 Mdot
.38062 .79378 Mdot
.39457 .39798 Mdot
.34701 .59434 Mdot
.46224 .7703 Mdot
.33721 .6252 Mdot
.56089 .47932 Mdot
.53684 .63427 Mdot
.35845 .56375 Mdot
.42452 .39603 Mdot
.58444 .56801 Mdot
.46475 .82033 Mdot
.53438 .66107 Mdot
.39059 .35806 Mdot
.66195 .48829 Mdot
.69147 .70331 Mdot
.85861 .60088 Mdot
.56529 .64887 Mdot
.61549 .59677 Mdot
.45926 .41455 Mdot
.38356 .5832 Mdot
.52386 .62797 Mdot
.55686 .63195 Mdot
.65204 .51103 Mdot
.42002 .41317 Mdot
.41611 .41435 Mdot
.62039 .52454 Mdot
.52858 .66206 Mdot
.49745 .39911 Mdot
.47576 .42221 Mdot
.28448 .77591 Mdot
.41587 .27497 Mdot
.15848 .37078 Mdot
.3591 .65643 Mdot
.21177 .46163 Mdot
.33164 .69346 Mdot
.32205 .57783 Mdot
.41841 .42171 Mdot
.38607 .42391 Mdot
.66914 .50444 Mdot
.44134 .38338 Mdot
.66765 .56044 Mdot
.56012 .65338 Mdot
.53402 .8381 Mdot
.50419 .74598 Mdot
.19428 .40586 Mdot
.44258 .38584 Mdot
.52416 .72398 Mdot
.60683 .37795 Mdot
.54612 .60489 Mdot
.3371 .59689 Mdot
.461 .35134 Mdot
.75889 .39694 Mdot
.65205 .55319 Mdot
.377 .59041 Mdot
.79233 .4917 Mdot
.77447 .49296 Mdot
.47869 .37008 Mdot
.62133 .53325 Mdot
.39913 .76031 Mdot
.33862 .32932 Mdot
.49587 .65384 Mdot
.59682 .35507 Mdot
.65049 .55008 Mdot
.51803 .65914 Mdot
.28011 .64504 Mdot
.36642 .56709 Mdot
.40061 .58685 Mdot
.73238 .3465 Mdot
.70186 .52244 Mdot
.60228 .3733 Mdot
.69124 .72228 Mdot
.75945 .65709 Mdot
.60029 .3533 Mdot
.63962 .50065 Mdot
.3644 .56128 Mdot
.3409 .58236 Mdot
.36415 .59503 Mdot
.81553 .46294 Mdot
.35547 .55141 Mdot
.29307 .40125 Mdot
.47827 .43084 Mdot
.53188 .38387 Mdot
.45189 .42692 Mdot
.52994 .67812 Mdot
.32707 .60417 Mdot
.47476 .59715 Mdot
.42747 .32923 Mdot
.53294 .81931 Mdot
.46615 .41091 Mdot
.50433 .63139 Mdot
.45422 .364 Mdot
.30998 .40656 Mdot
.31511 .60682 Mdot
.43439 .38141 Mdot
.52095 .67884 Mdot
.62349 .37766 Mdot
.38894 .63115 Mdot
.41677 .41851 Mdot
.39395 .71633 Mdot
.40356 .45348 Mdot
.17486 .51241 Mdot
.44012 .24803 Mdot
.64902 .3867 Mdot
.34433 .38414 Mdot
.70038 .54017 Mdot
.5333 .37798 Mdot
.46443 .31689 Mdot
.5336 .65904 Mdot
.60512 .76078 Mdot
.64659 .53901 Mdot
.5925 .32191 Mdot
.42669 .31985 Mdot
.59099 .37639 Mdot
.3154 .5624 Mdot
.51785 .67239 Mdot
.44906 .34005 Mdot
.4503 .33077 Mdot
.18659 .44658 Mdot
.49846 .34601 Mdot
.42796 .4391 Mdot
.64265 .36143 Mdot
.27581 .36625 Mdot
.44296 .37197 Mdot
.55799 .47972 Mdot
.40004 .59188 Mdot
.48628 .43381 Mdot
.30153 .33648 Mdot
.47155 .39913 Mdot
.38013 .58772 Mdot
.37146 .54666 Mdot
.46484 .74849 Mdot
.60346 .39822 Mdot
.39764 .4183 Mdot
.36462 .24888 Mdot
.41098 .37797 Mdot
.55393 .64256 Mdot
.48386 .39222 Mdot
.64171 .54792 Mdot
.80911 .46273 Mdot
.67347 .50006 Mdot
.4295 .42917 Mdot
.36352 .58954 Mdot
.51408 .63615 Mdot
.75992 .37323 Mdot
.69311 .38646 Mdot
.28797 .39242 Mdot
.19849 .36337 Mdot
.64202 .37292 Mdot
.58828 .3571 Mdot
.51275 .66783 Mdot
.43462 .38001 Mdot
.35215 .24043 Mdot
.44409 .46575 Mdot
.44981 .36793 Mdot
.44251 .40085 Mdot
.65703 .73722 Mdot
.55029 .66308 Mdot
.64506 .52179 Mdot
.46139 .38205 Mdot
.47405 .39004 Mdot
.31902 .58954 Mdot
.62552 .37656 Mdot
.64758 .50034 Mdot
.62317 .36794 Mdot
.67339 .53291 Mdot
.52848 .84385 Mdot
.3976 .33741 Mdot
.62059 .37689 Mdot
.57461 .65716 Mdot
.37098 .60745 Mdot
.60024 .61975 Mdot
.64026 .51196 Mdot
.66511 .50931 Mdot
.46743 .40811 Mdot
.3811 .59033 Mdot
.36563 .61971 Mdot
.61698 .38618 Mdot
.55665 .62513 Mdot
.42305 .42048 Mdot
.44265 .3433 Mdot
.43757 .57634 Mdot
.68399 .54478 Mdot
.41225 .29487 Mdot
.43637 .75041 Mdot
.42998 .38106 Mdot
.3693 .61477 Mdot
.44216 .40822 Mdot
.25862 .66525 Mdot
.38403 .59041 Mdot
.47193 .41892 Mdot
.78862 .6282 Mdot
.58814 .52306 Mdot
.42267 .71279 Mdot
.41971 .4382 Mdot
.14704 .46282 Mdot
.4157 .3616 Mdot
.30799 .79142 Mdot
.7353 .40981 Mdot
.40982 .42193 Mdot
.43109 .36122 Mdot
.28765 .56376 Mdot
.44312 .42116 Mdot
.61683 .52796 Mdot
.58773 .32075 Mdot
.31821 .57511 Mdot
.37583 .6829 Mdot
.48763 .48443 Mdot
.6149 .40296 Mdot
.69247 .50601 Mdot
.60376 .5255 Mdot
.60654 .3552 Mdot
.35875 .57919 Mdot
.41418 .38631 Mdot
.48065 .56683 Mdot
.61878 .55516 Mdot
.50207 .38947 Mdot
.54938 .63866 Mdot
.67496 .63567 Mdot
.71063 .53423 Mdot
.53758 .64773 Mdot
.39052 .39034 Mdot
.2979 .55645 Mdot
.67694 .29543 Mdot
.1959 .63249 Mdot
.51064 .63895 Mdot
.52364 .6594 Mdot
.82105 .48766 Mdot
.6173 .40478 Mdot
.20701 .40398 Mdot
.43929 .65864 Mdot
.52628 .62158 Mdot
.38216 .25887 Mdot
.66284 .554 Mdot
.39715 .7097 Mdot
.36497 .63693 Mdot
.4905 .40035 Mdot
.42745 .39595 Mdot
.55914 .62516 Mdot
.27965 .65063 Mdot
.63814 .20826 Mdot
.53761 .65571 Mdot
.49165 .45387 Mdot
.47927 .52662 Mdot
.63571 .71024 Mdot
.68341 .54243 Mdot
.6051 .39802 Mdot
.62428 .4165 Mdot
.32733 .57858 Mdot
.60241 .39348 Mdot
.76973 .61167 Mdot
.3963 .39159 Mdot
.52947 .65481 Mdot
.61274 .71751 Mdot
.53094 .64403 Mdot
.60509 .35698 Mdot
.64922 .38903 Mdot
.34775 .62078 Mdot
.35472 .61543 Mdot
.21665 .47637 Mdot
.52883 .29108 Mdot
.46409 .41964 Mdot
.48657 .80414 Mdot
.32329 .61855 Mdot
.35082 .34816 Mdot
.58761 .36129 Mdot
.62147 .37448 Mdot
.46166 .28941 Mdot
.40812 .40978 Mdot
.37988 .23171 Mdot
.40889 .40583 Mdot
.53499 .3081 Mdot
.37877 .38968 Mdot
.65134 .51249 Mdot
.40571 .41156 Mdot
.59862 .33767 Mdot
.46806 .3459 Mdot
.48007 .40123 Mdot
.67306 .55499 Mdot
.42444 .45394 Mdot
.64005 .54655 Mdot
.43442 .43199 Mdot
.58931 .3916 Mdot
.69426 .52058 Mdot
.54291 .23936 Mdot
.63577 .57649 Mdot
.65788 .48718 Mdot
.60566 .39184 Mdot
.63281 .39743 Mdot
.52916 .21513 Mdot
.33639 .59564 Mdot
.35444 .6493 Mdot
.43885 .37959 Mdot
.68189 .55329 Mdot
.55246 .66409 Mdot
.47335 .38297 Mdot
.38695 .43314 Mdot
.43726 .4432 Mdot
.33258 .57074 Mdot
.67972 .46142 Mdot
.62179 .3815 Mdot
.61968 .54272 Mdot
.62029 .44771 Mdot
.6391 .55995 Mdot
.47275 .33218 Mdot
.36895 .37697 Mdot
.20674 .51002 Mdot
.52967 .78117 Mdot
.83085 .52828 Mdot
.37148 .57137 Mdot
.69413 .49807 Mdot
.62969 .40081 Mdot
.36832 .44567 Mdot
.34172 .59225 Mdot
.63629 .5456 Mdot
.42477 .38167 Mdot
.38909 .35925 Mdot
.56829 .60375 Mdot
.53034 .3676 Mdot
.47266 .23631 Mdot
.64463 .55938 Mdot
.70181 .54532 Mdot
.75702 .65693 Mdot
.58202 .32433 Mdot
.50757 .5688 Mdot
.45379 .39898 Mdot
.62841 .39364 Mdot
.35351 .56133 Mdot
.70029 .31387 Mdot
.56928 .64539 Mdot
.57184 .55519 Mdot
.44105 .38544 Mdot
.46131 .61917 Mdot
.36473 .59076 Mdot
.59481 .36693 Mdot
.55936 .62443 Mdot
.65419 .38469 Mdot
.69806 .52809 Mdot
.28701 .25986 Mdot
.40583 .37995 Mdot
.46469 .42202 Mdot
.57274 .6463 Mdot
.34263 .56934 Mdot
.64173 .35662 Mdot
.18775 .53368 Mdot
.66165 .49545 Mdot
.36513 .22887 Mdot
.37208 .62023 Mdot
.3125 .44253 Mdot
.62052 .54603 Mdot
.5249 .6697 Mdot
.54836 .22537 Mdot
.51995 .6493 Mdot
.42244 .43013 Mdot
.35384 .59284 Mdot
.56112 .64252 Mdot
.57406 .48373 Mdot
.33207 .7837 Mdot
.32707 .46503 Mdot
.4023 .39873 Mdot
.42474 .81905 Mdot
.21765 .61096 Mdot
.36211 .52943 Mdot
.56759 .62558 Mdot
.46214 .40124 Mdot
.38789 .37821 Mdot
.4156 .37725 Mdot
.54009 .6303 Mdot
.66328 .68807 Mdot
.64433 .51287 Mdot
.45762 .42103 Mdot
.61679 .4002 Mdot
.63838 .54215 Mdot
.63332 .71986 Mdot
.67322 .50956 Mdot
.31458 .62141 Mdot
.48416 .39653 Mdot
.58584 .67452 Mdot
.40884 .83882 Mdot
.53962 .663 Mdot
.65628 .48754 Mdot
.47725 .37821 Mdot
.60323 .74696 Mdot
.34415 .59928 Mdot
.66542 .49539 Mdot
.45931 .39028 Mdot
.63747 .68465 Mdot
.75032 .38546 Mdot
.67172 .50999 Mdot
.33671 .5856 Mdot
.29793 .70271 Mdot
.44563 .38289 Mdot
.41154 .36526 Mdot
.34644 .5704 Mdot
.48951 .47854 Mdot
.79847 .49414 Mdot
.43697 .40918 Mdot
.54349 .64963 Mdot
.37908 .19017 Mdot
.44882 .44572 Mdot
.47963 .29024 Mdot
.65981 .54726 Mdot
.42188 .73391 Mdot
.40358 .29549 Mdot
.34806 .37742 Mdot
.26748 .64508 Mdot
.50967 .48579 Mdot
.51105 .83609 Mdot
.68542 .55406 Mdot
.75561 .46041 Mdot
.50656 .84174 Mdot
.50873 .66824 Mdot
.29197 .63477 Mdot
.41995 .60063 Mdot
.81191 .42255 Mdot
.31565 .71213 Mdot
.73399 .47643 Mdot
.76951 .40847 Mdot
.47117 .55088 Mdot
.67482 .52648 Mdot
.56579 .35541 Mdot
.42367 .41672 Mdot
.21442 .60779 Mdot
.32614 .3388 Mdot
.60284 .1821 Mdot
.41241 .81481 Mdot
.37147 .24921 Mdot
.4032 .79992 Mdot
.28543 .73499 Mdot
.19892 .49138 Mdot
.51232 .78249 Mdot
.39201 .2011 Mdot
.78464 .62451 Mdot
.28873 .28584 Mdot
.36201 .37493 Mdot
.57067 .4469 Mdot
.16786 .44852 Mdot
.29526 .43753 Mdot
.53448 .17946 Mdot
.66555 .50006 Mdot
.36305 .63208 Mdot
.42255 .60451 Mdot
.31037 .57549 Mdot
.54679 .58523 Mdot
.27918 .69157 Mdot
.28824 .76403 Mdot
.30802 .39148 Mdot
.14102 .4732 Mdot
.23323 .40601 Mdot
.81233 .3292 Mdot
.73559 .54324 Mdot
.39522 .58886 Mdot
.61775 .43016 Mdot
.746 .67438 Mdot
.48795 .72544 Mdot
.37027 .65611 Mdot
.68254 .70297 Mdot
.56262 .26686 Mdot
.35447 .58195 Mdot
.35649 .31426 Mdot
.69101 .58707 Mdot
.52088 .74312 Mdot
.67343 .32367 Mdot
.29074 .72621 Mdot
.50752 .55546 Mdot
.38701 .70329 Mdot
.6638 .62195 Mdot
.85619 .58462 Mdot
.4625 .2639 Mdot
.24249 .61839 Mdot
.5762 .59628 Mdot
.28987 .68222 Mdot
.7865 .37515 Mdot
.55313 .2939 Mdot
.75025 .66992 Mdot
.68518 .75594 Mdot
.19844 .59701 Mdot
.71157 .75411 Mdot
.35883 .64894 Mdot
.42904 .44043 Mdot
.25065 .58281 Mdot
.3479 .27607 Mdot
.58139 .38824 Mdot
.57375 .79672 Mdot
.63955 .38463 Mdot
.30559 .61642 Mdot
.80411 .46349 Mdot
.30006 .39777 Mdot
.37816 .22685 Mdot
.6405 .35283 Mdot
.38979 .42401 Mdot
.52711 .1148 Mdot
.50183 .83273 Mdot
.45926 .74276 Mdot
.28635 .77875 Mdot
.472 .62393 Mdot
.41809 .24073 Mdot
.55871 .63958 Mdot
.46838 .84759 Mdot
.34526 .58497 Mdot
.61985 .83494 Mdot
.38485 .81975 Mdot
.63256 .21661 Mdot
.27707 .20206 Mdot
.74755 .64318 Mdot
.45778 .59207 Mdot
.47904 .4965 Mdot
.51272 .24407 Mdot
.69052 .25662 Mdot
.58806 .19599 Mdot
.6004 .74067 Mdot
.18535 .39752 Mdot
.47097 .84294 Mdot
.34802 .26658 Mdot
.2867 .26935 Mdot
.80756 .40957 Mdot
.54513 .47791 Mdot
.29968 .61925 Mdot
.64198 .58925 Mdot
.35826 .75971 Mdot
.62537 .79835 Mdot
.46016 .2769 Mdot
.32081 .19342 Mdot
.6015 .33904 Mdot
.72894 .41353 Mdot
.23577 .66552 Mdot
.57422 .25482 Mdot
.39901 .26537 Mdot
.80679 .52244 Mdot
.49525 .36511 Mdot
.80817 .55095 Mdot
.42691 .79324 Mdot
.60676 .60477 Mdot
.78854 .6101 Mdot
.3752 .7375 Mdot
.1818 .47912 Mdot
.2697 .55093 Mdot
.74045 .68568 Mdot
.30941 .59235 Mdot
.53936 .27717 Mdot
.42246 .25658 Mdot
.27745 .76519 Mdot
.61672 .59628 Mdot
.22363 .71729 Mdot
.79213 .47145 Mdot
.37505 .39107 Mdot
.46023 .31285 Mdot
.45038 .47446 Mdot
.51656 .27819 Mdot
.46521 .43834 Mdot
.53742 .72965 Mdot
.26334 .74127 Mdot
.2254 .40495 Mdot
.60885 .62165 Mdot
.60775 .76377 Mdot
.19843 .63725 Mdot
.22032 .54037 Mdot
.75517 .40867 Mdot
.53092 .3293 Mdot
.84846 .48933 Mdot
.64282 .53539 Mdot
.3439 .26673 Mdot
.49865 .6526 Mdot
.70494 .33175 Mdot
.34151 .50985 Mdot
.67743 .25737 Mdot
.26237 .74029 Mdot
.78178 .51741 Mdot
.78609 .43828 Mdot
.59082 .24201 Mdot
.35641 .22362 Mdot
.60021 .77476 Mdot
.40178 .32517 Mdot
.34302 .67126 Mdot
.64526 .37699 Mdot
.23193 .507 Mdot
.31251 .28494 Mdot
.69696 .43023 Mdot
.44705 .45883 Mdot
.65759 .2731 Mdot
.70668 .4759 Mdot
.58138 .56699 Mdot
.7723 .71807 Mdot
.50167 .36519 Mdot
.70584 .69929 Mdot
.18357 .5694 Mdot
.49322 .25824 Mdot
.23774 .65749 Mdot
.36372 .71081 Mdot
.69849 .75923 Mdot
.35466 .80668 Mdot
.68811 .40548 Mdot
.55238 .82391 Mdot
.27137 .76787 Mdot
.73154 .72888 Mdot
.50597 .34986 Mdot
.55464 .68266 Mdot
.80225 .71589 Mdot
.61528 .54542 Mdot
.65529 .7505 Mdot
.27515 .3235 Mdot
.64379 .67725 Mdot
.40452 .61159 Mdot
.36273 .40236 Mdot
.47809 .55457 Mdot
.34218 .53651 Mdot
.43958 .4523 Mdot
.80717 .65939 Mdot
.71906 .72845 Mdot
.76383 .71041 Mdot
.16356 .52064 Mdot
.55253 .82799 Mdot
.44651 .55679 Mdot
.29853 .42385 Mdot
.41303 .53348 Mdot
.48088 .36959 Mdot
.64268 .32624 Mdot
.74784 .64043 Mdot
.67461 .28089 Mdot
.4732 .71006 Mdot
.30685 .58724 Mdot
.52321 .80586 Mdot
.90564 .45053 Mdot
.23174 .42694 Mdot
.3028 .32274 Mdot
.76697 .63275 Mdot
.51117 .28332 Mdot
.38656 .77443 Mdot
.64856 .23886 Mdot
.25308 .71569 Mdot
.4071 .5339 Mdot
.2767 .30815 Mdot
.71618 .45729 Mdot
.45559 .20799 Mdot
.7123 .47267 Mdot
.31599 .7648 Mdot
.43109 .5142 Mdot
.72909 .32273 Mdot
.42501 .64279 Mdot
.63434 .21224 Mdot
.7154 .37154 Mdot
.68254 .63231 Mdot
.31914 .27053 Mdot
.58784 .72911 Mdot
.50276 .28985 Mdot
.49203 .53228 Mdot
.38542 .46887 Mdot
.50728 .48693 Mdot
.49013 .28313 Mdot
.47345 .20883 Mdot
.60969 .80135 Mdot
.28053 .79032 Mdot
.8453 .57421 Mdot
.1388 .48826 Mdot
.42407 .78734 Mdot
.49264 .39961 Mdot
.22399 .66933 Mdot
.71905 .75784 Mdot
.35803 .81482 Mdot
.74778 .56481 Mdot
.59376 .51073 Mdot
.56317 .61191 Mdot
.83335 .59213 Mdot
.7252 .48437 Mdot
.26329 .70121 Mdot
.81558 .5529 Mdot
.57877 .67085 Mdot
.79132 .34492 Mdot
.71174 .7284 Mdot
.35043 .49666 Mdot
.49494 .32616 Mdot
.49417 .37374 Mdot
.31473 .39251 Mdot
.31686 .61933 Mdot
.64858 .61742 Mdot
.53811 .28937 Mdot
.65318 .5299 Mdot
.66369 .328 Mdot
.35188 .66394 Mdot
.41234 .45651 Mdot
.49966 .48241 Mdot
.36114 .63407 Mdot
.52687 .7808 Mdot
.59213 .69171 Mdot
.59486 .82449 Mdot
.74506 .62954 Mdot
.4711 .45369 Mdot
.48643 .26024 Mdot
.75751 .52513 Mdot
.8097 .50946 Mdot
.50358 .641 Mdot
.39027 .80774 Mdot
.57055 .46495 Mdot
.53733 .27869 Mdot
.31746 .38154 Mdot
.1866 .48897 Mdot
.36681 .38233 Mdot
.45052 .75926 Mdot
.27666 .50861 Mdot
.5756 .55315 Mdot
.30059 .61732 Mdot
.29752 .61793 Mdot
.17304 .61913 Mdot
.77896 .57876 Mdot
.65892 .6293 Mdot
.37743 .80116 Mdot
.52608 .63576 Mdot
.34059 .62385 Mdot
.62899 .32721 Mdot
.17916 .49366 Mdot
.29228 .48432 Mdot
.75144 .38635 Mdot
.70493 .6648 Mdot
.70947 .42464 Mdot
.39438 .80172 Mdot
.41887 .81225 Mdot
.5893 .17103 Mdot
.32684 .557 Mdot
.19528 .52669 Mdot
.21335 .37886 Mdot
.33659 .63295 Mdot
.41255 .57472 Mdot
.50045 .72159 Mdot
.6074 .81082 Mdot
.55762 .69784 Mdot
.17783 .40472 Mdot
.48557 .22064 Mdot
.64785 .68994 Mdot
.76407 .37935 Mdot
.32362 .26094 Mdot
.36479 .79437 Mdot
.33768 .3364 Mdot
.36218 .50943 Mdot
.38318 .44055 Mdot
.53436 .36688 Mdot
.86547 .53361 Mdot
.64138 .57415 Mdot
.31303 .43718 Mdot
.36265 .72808 Mdot
.4075 .38553 Mdot
.849 .59349 Mdot
.20388 .57838 Mdot
.82318 .49453 Mdot
.57868 .63508 Mdot
.41097 .35689 Mdot
.47573 .35464 Mdot
.51701 .32477 Mdot
.444 .74229 Mdot
.66496 .75658 Mdot
.31854 .26389 Mdot
.3776 .75465 Mdot
.32562 .34202 Mdot
.70249 .70207 Mdot
.28257 .7121 Mdot
.22672 .62217 Mdot
.54848 .52479 Mdot
.75146 .6294 Mdot
.56935 .23898 Mdot
.14502 .48597 Mdot
.59152 .43932 Mdot
.44252 .57199 Mdot
.47998 .692 Mdot
.40534 .73746 Mdot
.7296 .33555 Mdot
.45401 .35033 Mdot
.79241 .49188 Mdot
.28424 .7305 Mdot
.50573 .16526 Mdot
.73167 .30025 Mdot
.84096 .60926 Mdot
.30041 .51749 Mdot
.38646 .72667 Mdot
.274 .65512 Mdot
.46072 .15622 Mdot
.57899 .43877 Mdot
.51041 .81993 Mdot
.57577 .23813 Mdot
.38577 .80144 Mdot
.53669 .68465 Mdot
.43826 .64122 Mdot
.61219 .76267 Mdot
.58315 .81504 Mdot
.23543 .55228 Mdot
.31137 .75478 Mdot
.46435 .60293 Mdot
.66724 .79453 Mdot
.57122 .74622 Mdot
.46528 .54227 Mdot
.69376 .50058 Mdot
.78843 .53004 Mdot
.40271 .79288 Mdot
.48546 .7913 Mdot
.31923 .27478 Mdot
.69204 .55782 Mdot
.60136 .32268 Mdot
.3474 .46965 Mdot
.60837 .27479 Mdot
.40447 .74616 Mdot
.48695 .25993 Mdot
.29187 .75471 Mdot
.60409 .43456 Mdot
.78617 .45941 Mdot
.69971 .70158 Mdot
.26469 .28379 Mdot
.44931 .74017 Mdot
.78408 .56797 Mdot
.2422 .62793 Mdot
.72013 .39345 Mdot
.39202 .25058 Mdot
.34714 .86779 Mdot
.24989 .31952 Mdot
.54197 .7672 Mdot
.62656 .79729 Mdot
.23173 .64941 Mdot
.5394 .7759 Mdot
.70128 .26368 Mdot
.41413 .27666 Mdot
.6046 .31117 Mdot
.4412 .39985 Mdot
.7636 .7224 Mdot
.58088 .27726 Mdot
.64207 .79572 Mdot
.21146 .65657 Mdot
.31849 .40618 Mdot
.41271 .45602 Mdot
.62982 .55116 Mdot
.65858 .59781 Mdot
.62977 .28921 Mdot
.33385 .52851 Mdot
.37833 .27647 Mdot
.72298 .64578 Mdot
.69983 .51867 Mdot
.71589 .47322 Mdot
.38991 .5363 Mdot
.74724 .60771 Mdot
.42739 .74822 Mdot
.66457 .36551 Mdot
.53762 .549 Mdot
.49314 .27938 Mdot
.38986 .29658 Mdot
.34674 .4967 Mdot
.68509 .26592 Mdot
.53415 .49115 Mdot
.67649 .50909 Mdot
.31603 .52512 Mdot
.19188 .39324 Mdot
.4048 .75919 Mdot
.67791 .76331 Mdot
.79661 .5153 Mdot
.4019 .50032 Mdot
.49384 .28907 Mdot
.67461 .24581 Mdot
.43168 .20094 Mdot
.53644 .7908 Mdot
.39524 .30819 Mdot
.39349 .23221 Mdot
.38328 .65765 Mdot
.52294 .84284 Mdot
.28608 .29042 Mdot
.25103 .34011 Mdot
.68724 .57835 Mdot
.28832 .44598 Mdot
.32776 .42365 Mdot
.53835 .23306 Mdot
.53486 .56342 Mdot
.82257 .34881 Mdot
.37889 .62912 Mdot
.88113 .53498 Mdot
.55496 .66791 Mdot
.82055 .41968 Mdot
.56233 .22585 Mdot
.49215 .52904 Mdot
.52123 .56974 Mdot
.46108 .75972 Mdot
.44593 .67091 Mdot
.15626 .4832 Mdot
.57637 .18032 Mdot
.64014 .56072 Mdot
.32404 .24902 Mdot
.28065 .25891 Mdot
.29826 .54873 Mdot
.3993 .43258 Mdot
.24546 .32185 Mdot
.66475 .5646 Mdot
.6763 .28123 Mdot
.21913 .64649 Mdot
.46045 .78137 Mdot
.51411 .42795 Mdot
.51784 .28471 Mdot
.50071 .81942 Mdot
.3517 .80068 Mdot
.7528 .30554 Mdot
.42721 .79298 Mdot
.55727 .68119 Mdot
.45305 .54819 Mdot
.33195 .76178 Mdot
.44043 .23699 Mdot
.39308 .6894 Mdot
.41324 .25478 Mdot
.8731 .452 Mdot
.64061 .76369 Mdot
.6638 .75659 Mdot
.43343 .24572 Mdot
.36473 .55125 Mdot
.55184 .74554 Mdot
.40341 .26376 Mdot
.47073 .77773 Mdot
.16916 .46274 Mdot
.41544 .25848 Mdot
.55991 .15057 Mdot
.20718 .43065 Mdot
.63619 .44826 Mdot
.33239 .42828 Mdot
.2121 .43147 Mdot
.58062 .65825 Mdot
.63042 .31226 Mdot
.3624 .73266 Mdot
.57408 .6441 Mdot
.41109 .74929 Mdot
.39965 .71815 Mdot
.22646 .37954 Mdot
.3025 .48393 Mdot
.39225 .76522 Mdot
.27237 .57784 Mdot
.28243 .62149 Mdot
.70256 .31713 Mdot
.69976 .48834 Mdot
.34199 .72395 Mdot
.67496 .49231 Mdot
.35435 .35654 Mdot
.56992 .53989 Mdot
.45042 .48497 Mdot
.84023 .57175 Mdot
.64376 .37661 Mdot
.39015 .57867 Mdot
.83136 .42392 Mdot
.35239 .63295 Mdot
.791 .68448 Mdot
.66239 .24953 Mdot
.31645 .37357 Mdot
.6956 .39695 Mdot
.68002 .4437 Mdot
.69813 .2172 Mdot
.38431 .51406 Mdot
.68936 .57969 Mdot
.28834 .59721 Mdot
.37632 .56257 Mdot
.71493 .67607 Mdot
.69312 .53211 Mdot
.45642 .29441 Mdot
.48035 .67414 Mdot
.40948 .5186 Mdot
.3506 .54246 Mdot
.56681 .49392 Mdot
.55848 .32364 Mdot
.59903 .8148 Mdot
.68025 .52102 Mdot
.85631 .44207 Mdot
.37402 .41272 Mdot
.25925 .5424 Mdot
.24708 .71241 Mdot
.77472 .32614 Mdot
.60986 .53046 Mdot
.29868 .23 Mdot
.37966 .37967 Mdot
.39693 .77182 Mdot
.34879 .57952 Mdot
.26407 .32487 Mdot
.63278 .36576 Mdot
.49952 .25285 Mdot
.5525 .60905 Mdot
.73108 .32598 Mdot
.74048 .60897 Mdot
.36144 .54782 Mdot
.45788 .79212 Mdot
.19319 .49958 Mdot
.42173 .66435 Mdot
.67799 .45506 Mdot
.31637 .53308 Mdot
.29798 .47839 Mdot
.35482 .54263 Mdot
.64305 .77321 Mdot
.26726 .31515 Mdot
.49632 .85786 Mdot
.44747 .47378 Mdot
.76478 .48254 Mdot
.46815 .66978 Mdot
.42869 .75887 Mdot
.4591 .30342 Mdot
.25939 .72859 Mdot
.54968 .28672 Mdot
.49345 .70036 Mdot
.52839 .30265 Mdot
.35322 .39147 Mdot
.52531 .54376 Mdot
.68514 .60997 Mdot
.63432 .19137 Mdot
.50978 .33175 Mdot
.7884 .36763 Mdot
.3884 .31186 Mdot
.71749 .68745 Mdot
.39748 .55795 Mdot
.60484 .49202 Mdot
.29679 .44882 Mdot
.61991 .59775 Mdot
.5075 .84617 Mdot
.25622 .72361 Mdot
.57984 .61591 Mdot
.70155 .68758 Mdot
.30864 .68867 Mdot
.43495 .47102 Mdot
.45742 .61338 Mdot
.42554 .43642 Mdot
.4046 .56398 Mdot
.79097 .33867 Mdot
.46147 .77076 Mdot
.40839 .32038 Mdot
.50895 .83762 Mdot
.45803 .84455 Mdot
.6589 .79664 Mdot
.36137 .2276 Mdot
.32521 .57282 Mdot
.75611 .70981 Mdot
.3654 .29275 Mdot
.30374 .7759 Mdot
.52519 .7918 Mdot
.18318 .63508 Mdot
.35241 .51579 Mdot
.35749 .71825 Mdot
.59111 .1914 Mdot
.43104 .68751 Mdot
.21135 .61572 Mdot
.46308 .51903 Mdot
.6404 .63916 Mdot
.20932 .6226 Mdot
.58105 .13616 Mdot
.42724 .30238 Mdot
.38974 .71059 Mdot
.42017 .6284 Mdot
.34909 .7281 Mdot
.7481 .41883 Mdot
.48382 .39109 Mdot
.6165 .72484 Mdot
.77492 .40266 Mdot
.47777 .27322 Mdot
.60344 .32265 Mdot
.7463 .4183 Mdot
.64347 .30273 Mdot
.54412 .31398 Mdot
.28889 .28486 Mdot
.34224 .51794 Mdot
.46261 .29873 Mdot
.37379 .39069 Mdot
.40264 .56863 Mdot
.59196 .38835 Mdot
.63022 .48077 Mdot
.43566 .43438 Mdot
.6044 .54973 Mdot
.42939 .66955 Mdot
.82901 .62833 Mdot
.60602 .62522 Mdot
.18873 .55056 Mdot
.36393 .63681 Mdot
.44695 .74842 Mdot
.25846 .61807 Mdot
.81009 .43873 Mdot
.74658 .45704 Mdot
.45998 .27675 Mdot
.47438 .83172 Mdot
.78669 .61297 Mdot
.18904 .45229 Mdot
.78451 .64292 Mdot
.57073 .66697 Mdot
.51884 .39411 Mdot
.43245 .60778 Mdot
.76642 .54084 Mdot
.29972 .59597 Mdot
.363 .72176 Mdot
.71435 .55919 Mdot
.7857 .58718 Mdot
.18499 .57451 Mdot
.1901 .4921 Mdot
.36121 .48027 Mdot
.43024 .8181 Mdot
.66601 .55068 Mdot
.25138 .3312 Mdot
.38626 .6844 Mdot
.75203 .47467 Mdot
.7018 .71792 Mdot
.57001 .83214 Mdot
.47913 .59493 Mdot
.55648 .25839 Mdot
.41177 .37084 Mdot
.29358 .34409 Mdot
.46854 .76772 Mdot
.53819 .41387 Mdot
.71797 .62856 Mdot
.37493 .60821 Mdot
.70647 .6195 Mdot
.57367 .42703 Mdot
.60657 .30741 Mdot
.33103 .54461 Mdot
.34925 .27873 Mdot
.57675 .37299 Mdot
.47895 .65104 Mdot
.44811 .44876 Mdot
.53805 .25467 Mdot
.37824 .22387 Mdot
.51501 .39635 Mdot
.39442 .78321 Mdot
.33009 .52024 Mdot
.17996 .46814 Mdot
.42481 .77043 Mdot
.5456 .78923 Mdot
.4464 .6776 Mdot
.30912 .45669 Mdot
.75053 .54642 Mdot
.43508 .44309 Mdot
.60236 .49878 Mdot
.35513 .62598 Mdot
.28069 .68783 Mdot
.29555 .51529 Mdot
.54658 .24106 Mdot
.51202 .51748 Mdot
.25725 .60608 Mdot
.50772 .504 Mdot
.23291 .68305 Mdot
.43228 .68874 Mdot
.54226 .29111 Mdot
.52197 .68535 Mdot
.5603 .22719 Mdot
.69426 .26549 Mdot
.4192 .83006 Mdot
.65615 .23357 Mdot
.48156 .57383 Mdot
.78981 .3633 Mdot
.54759 .75745 Mdot
.21188 .64044 Mdot
.54997 .30076 Mdot
.49034 .58819 Mdot
.60407 .32836 Mdot
.57919 .60958 Mdot
.54424 .49997 Mdot
.60194 .47726 Mdot
.4096 .28646 Mdot
.68031 .6607 Mdot
.71177 .58001 Mdot
.36959 .42139 Mdot
.65744 .74257 Mdot
.45637 .82673 Mdot
.26928 .32526 Mdot
.51869 .48749 Mdot
.6923 .33741 Mdot
.60303 .3023 Mdot
.12293 .48761 Mdot
.85879 .58163 Mdot
.41007 .37251 Mdot
.5244 .4811 Mdot
.53383 .26576 Mdot
.63084 .55749 Mdot
.38801 .28187 Mdot
.26877 .6169 Mdot
.53489 .67049 Mdot
.59153 .49544 Mdot
.79158 .57272 Mdot
.47108 .76004 Mdot
.60281 .26312 Mdot
.63159 .73977 Mdot
.82578 .63915 Mdot
.16912 .43382 Mdot
.44182 .7638 Mdot
.12992 .54913 Mdot
.71612 .58697 Mdot
.30696 .63661 Mdot
.24785 .58772 Mdot
.61415 .80203 Mdot
.48268 .25549 Mdot
.72717 .34417 Mdot
.57731 .78143 Mdot
.55195 .29252 Mdot
.38569 .2616 Mdot
.70346 .69819 Mdot
.71155 .62101 Mdot
.48858 .54513 Mdot
.68205 .44454 Mdot
.75133 .68761 Mdot
.32701 .35025 Mdot
.47361 .82326 Mdot
.77614 .40002 Mdot
.53064 .14282 Mdot
.47096 .84865 Mdot
.65088 .32609 Mdot
.74965 .411 Mdot
.24492 .58162 Mdot
.46511 .22583 Mdot
.37105 .27183 Mdot
.696 .29266 Mdot
.28246 .48093 Mdot
.66499 .43241 Mdot
.7862 .3866 Mdot
.50103 .28906 Mdot
.21634 .41985 Mdot
.49296 .58548 Mdot
.33414 .50601 Mdot
.72648 .65499 Mdot
.44432 .2512 Mdot
.58124 .47657 Mdot
.49845 .23077 Mdot
.31194 .53145 Mdot
.24976 .6317 Mdot
.35349 .69523 Mdot
.61505 .15624 Mdot
.54563 .79837 Mdot
.80823 .43139 Mdot
.475 .4339 Mdot
.53602 .84883 Mdot
.36755 .69432 Mdot
.56932 .78741 Mdot
.17298 .52445 Mdot
.62635 .46605 Mdot
.46006 .64372 Mdot
.43696 .44291 Mdot
.46724 .80566 Mdot
.31603 .43928 Mdot
.21004 .44867 Mdot
.74748 .34754 Mdot
.49775 .26519 Mdot
.76081 .4129 Mdot
.52335 .22473 Mdot
.50547 .43054 Mdot
.37793 .61619 Mdot
.75457 .7215 Mdot
.46763 .58847 Mdot
.36194 .34081 Mdot
.53473 .39728 Mdot
.60189 .19377 Mdot
.20338 .34833 Mdot
.45702 .47211 Mdot
.77399 .63576 Mdot
.36481 .26104 Mdot
.38637 .48191 Mdot
.36141 .31945 Mdot
.16047 .31462 Mdot
.28535 .78762 Mdot
.32765 .56314 Mdot
.31295 .30014 Mdot
.37745 .2416 Mdot
.6061 .80502 Mdot
.718 .45624 Mdot
.67319 .47335 Mdot
.53081 .18481 Mdot
.44167 .22411 Mdot
.37617 .40454 Mdot
.17876 .55657 Mdot
.40112 .82271 Mdot
.75843 .35706 Mdot
.49865 .83971 Mdot
.40043 .31487 Mdot
.41487 .32424 Mdot
.13291 .38853 Mdot
.34076 .77094 Mdot
.4943 .36579 Mdot
.60326 .19147 Mdot
.30087 .62261 Mdot
.42666 .40824 Mdot
.64349 .73629 Mdot
.31449 .27135 Mdot
.50102 .29118 Mdot
.58481 .81455 Mdot
.31797 .56045 Mdot
.61292 .58757 Mdot
.53016 .67134 Mdot
.52632 .56713 Mdot
.38968 .3525 Mdot
.54688 .62983 Mdot
.39562 .4843 Mdot
.34206 .71518 Mdot
.58367 .65157 Mdot
.29746 .26353 Mdot
.20942 .69263 Mdot
.31355 .50626 Mdot
.53695 .59979 Mdot
.42209 .47366 Mdot
.20622 .43767 Mdot
.63391 .29348 Mdot
.4237 .54652 Mdot
.2027 .62353 Mdot
.45854 .89432 Mdot
.64899 .64283 Mdot
.5568 .34286 Mdot
.32752 .54585 Mdot
.45742 .29856 Mdot
.34478 .47828 Mdot
.50139 .68414 Mdot
.66993 .54542 Mdot
.43873 .46547 Mdot
.50287 .4333 Mdot
.56371 .61525 Mdot
.87604 .52757 Mdot
.47761 .37456 Mdot
.37346 .30915 Mdot
.309 .77707 Mdot
.70462 .31857 Mdot
.24838 .53667 Mdot
.42571 .33732 Mdot
.53607 .73709 Mdot
.48905 .58988 Mdot
.32155 .72796 Mdot
.78587 .46455 Mdot
.54428 .82159 Mdot
.29282 .51494 Mdot
.34112 .4437 Mdot
.47403 .3966 Mdot
.60692 .40408 Mdot
.40024 .70582 Mdot
.59763 .78482 Mdot
.42717 .3098 Mdot
.33378 .79756 Mdot
.62934 .46257 Mdot
.69251 .66914 Mdot
.37599 .47484 Mdot
.68226 .77416 Mdot
.7673 .34263 Mdot
.32586 .43802 Mdot
.82465 .46999 Mdot
.77321 .56003 Mdot
.60554 .2746 Mdot
.6366 .55308 Mdot
.37546 .33822 Mdot
.32286 .55544 Mdot
.82582 .64738 Mdot
.60412 .78269 Mdot
.6081 .70037 Mdot
.68261 .63483 Mdot
.29052 .37494 Mdot
.40191 .66379 Mdot
.16407 .61847 Mdot
.73328 .48365 Mdot
.83339 .62734 Mdot
.25087 .33784 Mdot
.37318 .5258 Mdot
.38456 .73218 Mdot
.51004 .36926 Mdot
.67247 .5132 Mdot
.58252 .80741 Mdot
.49744 .43675 Mdot
.79873 .45227 Mdot
.40873 .34758 Mdot
.8215 .51084 Mdot
.58563 .53399 Mdot
.67833 .71374 Mdot
.5915 .72838 Mdot
.7034 .2674 Mdot
.26582 .68875 Mdot
.59213 .66675 Mdot
.14317 .56289 Mdot
.28808 .69808 Mdot
.3915 .80905 Mdot
.74475 .3777 Mdot
.73589 .27553 Mdot
.49537 .79196 Mdot
.39628 .76434 Mdot
.6 .68914 Mdot
.4539 .49821 Mdot
.78493 .52666 Mdot
.38862 .47833 Mdot
.41678 .70873 Mdot
.58468 .6201 Mdot
.5759 .91056 Mdot
.63534 .33736 Mdot
.33833 .65593 Mdot
.76949 .52314 Mdot
.43456 .82648 Mdot
.49998 .46643 Mdot
.18845 .59162 Mdot
.5712 .44733 Mdot
.39659 .32839 Mdot
.29578 .4944 Mdot
.28207 .31328 Mdot
.79468 .5302 Mdot
.74132 .24714 Mdot
.16966 .43798 Mdot
.68494 .64999 Mdot
.54402 .54072 Mdot
.33308 .63074 Mdot
.40182 .61607 Mdot
.6929 .42156 Mdot
.16239 .55617 Mdot
.35241 .71706 Mdot
.33308 .76302 Mdot
.68421 .20857 Mdot
.20465 .40747 Mdot
.60918 .80672 Mdot
.52019 .76929 Mdot
.40021 .60655 Mdot
.65649 .32373 Mdot
.67 .38787 Mdot
.60403 .72338 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Wooooo`;o
0000X?ooool001cooooo00?o0000ooooooooool0Yoooool2o`000:3ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0YOooool2o`000:;ooooo000Looooo`03o`000?oooooooooo0:Gooooo0_l0
000Booooo`;o0000S_ooool001cooooo00?o0000ooooooooool0^Oooool2o`0008kooooo000Loooo
o`03o`000?oooooooooo0:Wooooo0_l0002Nooooo`007?ooool00ol0003oooooooooo`1looooo`;o
0000:oooool2o`0009kooooo000Looooo`03o`000?oooooooooo07cooooo0_l0000dooooo`;o0000
UOooool001cooooo0_l0001kooooo`;o0000=_ooool2o`0000Oooooo0_l0002<ooooo`007?ooool0
0ol0003oooooooooo`1jooooo`;o00005_ooool2o`0002Oooooo0_l00007ooooo`;o0000Poooool0
01cooooo00?o0000ooooooooool0T_ooool2o`00033ooooo0_l00023ooooo`007?ooool00ol0003o
ooooooooo`2eooooo`;o0000T_ooool001cooooo00?o0000ooooooooool0Poooool2o`0001cooooo
0_l0000Booooo`;o00002_ooool2o`0008Kooooo000Looooo`03o`000?oooooooooo08?ooooo0_l0
000Aooooo`;o00002Oooool2o`0000;ooooo0_l0000Hooooo`Co0000Q_ooool001cooooo00?o0000
ooooooooool0POooool2o`0000Cooooo0_l0000=ooooo`?o000000?oooooo`000?l000002Oooool2
o`0001Gooooo0_l000000ooooooo0000o`000028ooooo`007?ooool00ol0003oooooooooo`21oooo
o`;o00001?ooool2o`0000kooooo0_l000000ooooooo0000o`00000Booooo`;o00003?ooool2o`00
08_ooooo000Looooo`03o`000?oooooooooo09Oooooo0_l00006ooooo`;o00001oooool2o`0000Co
oooo0_l0002Iooooo`007?ooool00ol0003oooooooooo`2Oooooo`;o00000_ooool2o`0000?ooooo
1?l0000;ooooo`;o00001oooool2o`0000Kooooo0_l000000ooooooo0000o`00001looooo`007?oo
ool00ol0003oooooooooo`2=ooooo`;o00005?ooool2o`0000?ooooo1?l00005ooooo`;o00001?oo
ool2o`0000Oooooo0_l00006ooooo`;o000000?oooooo`000?l00000O?ooool001cooooo00?o0000
ooooooooool0K?ooool2o`0000Kooooo0_l0000Gooooo`;o00003?ooool2o`0000[ooooo1?l00006
ooooo`;o00003Oooool2o`0008Oooooo000Looooo`03o`000?oooooooooo06cooooo0_l00006oooo
o`;o000000?oooooo`000?l000007_ooool2o`0000;ooooo0_l0000:ooooo`Co00005_ooool2o`00
08Kooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool0
0ol0003oooooooooo`1Tooooo`;o00004Oooool2o`0001kooooo0_l0000Sooooo`Oo00001oooool2
o`0007gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1Tooooo`?o00000oooool2o`0001gooooo
0_l0000Dooooo`;o00006_ooool7o`0000Sooooo0_l0001mooooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0IOoo
ool2o`0000?ooooo0_l0000;ooooo`;o00004?ooool2o`0001Cooooo0_l0000Jooooo`;o00000_oo
ool2o`0008Sooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RH
ob4Q8Oo^k^h01_ooool3o`0005Kooooo0_l0000Oooooo`;o00000oooool2o`0000[ooooo0ol00009
ooooo`;o0000=_ooool2o`0007_ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`1Fooooo`;o00000oooool2o`00
01oooooo0_l00007ooooo`;o000000?oooooo`000?l000000_l00006ooooo`Co00009?ooool2o`00
013ooooo0_l0001kooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0=ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0Foooool2o`0001?ooooo0_l0000:ooooo`;o
00000oooool2o`0000;ooooo0_l00003ooooo`;o00001?ooool4o`0000;ooooo0_l0000Aooooo`;o
00003oooool2o`0000Oooooo0_l00007ooooo`;o00003?ooool2o`0006gooooo00001_ooooooMgMg
oiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooo
oooo06Oooooo0_l00007ooooo`;o00001Oooool2o`0000Cooooo0_l00002ooooo`;o00003Oooool2
o`0000Cooooo0_l00007ooooo`;o00002?ooool4o`0000?ooooo0_l0000Aooooo`;o00001Oooool4
o`0000cooooo0_l0001]ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Wooooo`;o000000?oooooo`000?l00000
2oooool2o`0000Cooooo0_l0000Pooooo`;o00000oooool2o`0000;ooooo0_l000000ooooooo0000
o`000003ooooo`;o00006?ooool2o`0007gooooo000Looooo`03o`000?oooooooooo06[ooooo0_l0
000Fooooo`;o00001oooool4o`0000_ooooo0_l00008ooooo`;o00000_ooool2o`00023ooooo0ol0
00000ooooooo0000o`00000=ooooo`Co0000J?ooool001cooooo00?o0000ooooooooool0O?ooool2
o`0000Cooooo0_l000001?oooooo0000o`000?l00003ooooo`Co00001_ooool2o`0000?ooooo0_l0
000<ooooo`Co00007_ooool3o`000004ooooool0003o0000ooooo`;o00002_ooool4o`0006Sooooo
000Looooo`03o`000?oooooooooo06Cooooo0_l0000:ooooo`;o00001Oooool2o`0000?ooooo0_l0
00000ooooooo0000o`000004ooooo`?o000000?oooooo`000?l000000ol00003ooooo`?o000000?o
ooooo`000?l000000oooool2o`000003ooooool0003o000000_ooooo0ol0000Tooooo`;o000000?o
ooooo`000?l00000Loooool001cooooo00?o0000ooooooooool0I?ooool2o`0000[ooooo1?l00003
ooooo`;o00001Oooool3o`0000Sooooo0_l000000ooooooo0000o`000003ooooo`Go00000_ooool4
o`000003ooooool0003o000000Oooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool3
o`0001oooooo0_l0001cooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o00004oooool3o`00
00;ooooo0_l00005ooooo`;o00004oooool3o`0000;ooooo0_l00004ooooo`;o000000?oooooo`00
0?l000000oooool2o`0000Kooooo0_l00002ooooo`?o0000U?ooool001cooooo00?o0000oooooooo
ool0GOooool2o`000003ooooool0003o0000017ooooo0_l00003ooooo`;o00000_ooool2o`00023o
oooo0_l000000ooooooo0000o`000008ooooo`;o00001Oooool2o`0001gooooo0_l0001fooooo`00
7?ooool00ol0003oooooooooo`1Mooooo`;o000000?oooooo`000?l000002?ooool2o`0000;ooooo
0_l00006ooooo`Co00000_ooool2o`0000[ooooo0_l000000ooooooo0000o`000009ooooo`;o0000
1?ooool4o`0000_ooooo0_l00004ooooo`Co00007?ooool2o`0007Kooooo000Looooo`03o`000?oo
oooooooo05Wooooo0_l0000;ooooo`;o00000_ooool2o`0000;ooooo0_l00004ooooo`Co00000ooo
ool2o`0000Sooooo0_l000001?oooooo0000o`000?ooool2o`0000Wooooo1Ol000000ooooooo0000
o`00000?ooooo`;o00000_ooool8o`0001Kooooo0_l000000ooooooo0000o`00001eooooo`007?oo
ool00ol0003oooooooooo`1Cooooo`;o00001?ooool2o`0000_ooooo0_l00002ooooo`Co000000?o
ooooo`000?l000000oooool5o`0000;ooooo0_l00007ooooo`Ko00002?ooool2o`0000;ooooo1Ol0
000Booooo`?o000000Coooooo`000?l0003ooooo1Ol00003ooooo`;o00004Oooool2o`000003oooo
ool0003o000000;ooooo0_l0001aooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00004Ooo
ool2o`0000;ooooo1?l000000ooooooo0000o`000004ooooo`Co00002oooool2o`000003ooooool0
003o000000;o00001oooool2o`0000;ooooo0_l00007ooooo`;o00000_ooool2o`0000Wooooo0_l0
00001?oooooo0000o`000?ooool2o`000003ooooool0003o000000?ooooo0_l0000Booooo`;o0000
1?ooool3o`0000kooooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`1Vooooo`?o00002_oo
ool4o`0000gooooo0_l00003ooooo`Co00000oooool2o`0000Sooooo0_l00003ooooo`;o00000_oo
ool2o`0000Wooooo0_l00007ooooo`;o00005oooool2o`0000Gooooo0_l00007ooooo`;o00001Ooo
ool2o`0000Cooooo0_l0001Jooooo`007?ooool2o`0006Oooooo0ol0000:ooooo`Co00001Oooool3
o`0000Gooooo1_l000000ooooooo0000o`000002o`000003ooooool0003o000000Sooooo0_l0000B
ooooo`;o00002Oooool3o`0001Oooooo0_l0000;ooooo`;o00002oooool2o`0005[ooooo000Loooo
o`03o`000?oooooooooo07cooooo0ol00003ooooo`;o00000_ooool4o`0000?ooooo0_l0000:oooo
o`;o00001?ooool2o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o00002_ooool7o`00
017ooooo0_l000001?oooooo0000o`000?l00003ooooo`?o00001Oooool2o`0006Oooooo000Loooo
o`03o`000?oooooooooo06oooooo0_l0000<ooooo`;o00000oooool5o`0001;ooooo0_l000001?oo
oooo0000o`000?ooool2o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o00001?ooool2
o`0000Cooooo0_l00003ooooo`;o00004Oooool2o`000003ooooool0003o000000Cooooo0ol00002
ooooo`;o000000?oooooo`000?l00000Ioooool001cooooo00?o0000ooooooooool0Eoooool2o`00
0003ooooool0003o000000Wooooo0_l00008ooooo`;o00000_ooool2o`0000?ooooo1?l00007oooo
o`Co00000oooool2o`0000Cooooo0_l00008ooooo`Co00003Oooool2o`0000Cooooo0_l0000Uoooo
o`;o00000oooool2o`0006[ooooo000Looooo`03o`000?oooooooooo05Oooooo0_l000001?oooooo
0000o`000?ooool2o`0000Gooooo0ol0000<ooooo`;o00000oooool4o`0000?ooooo0_l00009oooo
o`;o00000_ooool6o`0000Kooooo0ol00004ooooo`;o00005_ooool2o`0000?ooooo1?l0000Moooo
o`?o0000Ioooool001cooooo00?o0000ooooooooool0GOooool2o`0000Gooooo1?l00004ooooo`?o
000000?oooooo`000?l000001Oooool2o`000003ooooool0003o000000;ooooo0ol0000=ooooo`;o
00000_ooool2o`0000[ooooo0_l000000ooooooo0000o`000007ooooo`;o00001oooool2o`0000Co
oooo0_l00003ooooo`Co00004?ooool2o`0000Oooooo0_l000000ooooooo0000o`000003o`0006Ko
oooo000Looooo`03o`000?oooooooooo05Wooooo0_l00009ooooo`Co00000_ooool5o`000003oooo
ool0003o000000Gooooo0_l00005ooooo`;o00005_ooool2o`0000Kooooo0_l0000:ooooo`;o0000
1oooool2o`0000gooooo0_l0000>ooooo`;o00001oooool2o`000004ooooool0003o0000ooooo`;o
0000I_ooool001cooooo00?o0000ooooooooool0FOooool2o`0000Oooooo1Ol00003ooooo`;o0000
2Oooool2o`0001cooooo0_l000001?oooooo0000o`000?l0000Aooooo`;o00005_ooool2o`0000Go
oooo0_l00007ooooo`;o00003Oooool2o`00017ooooo0_l0001Cooooo`007?ooool00ol0003ooooo
ooooo`1Rooooo`Co00001oooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`0000[ooooo
0_l0000;ooooo`Go00000_ooool2o`00017ooooo0_l00007ooooo`Co00002_ooool5o`0000?ooooo
0ol00002ooooo`;o00000_ooool2o`0000Gooooo0_l00006ooooo`;o00001_ooool4o`0000Oooooo
0_l0001Cooooo`007?ooool00ol0003oooooooooo`1Kooooo`;o00001oooool2o`0000Oooooo0ol0
0002ooooo`;o00000oooool2o`0000[ooooo0_l0000;ooooo`Co00001Oooool2o`000003ooooool0
003o000000Kooooo0_l00005ooooo`;o00001_ooool4o`0000;ooooo0_l00006ooooo`Go00000ooo
ool3o`0000;ooooo0_l00009ooooo`;o00003_ooool4o`0005cooooo000Looooo`03o`000?oooooo
oooo04Sooooo0_l0000Aooooo`;o00004Oooool2o`0000[ooooo0_l0000Mooooo`Go00000oooool5
o`0000Gooooo0_l00006ooooo`Co00000_ooool2o`0000Sooooo1?l0000<ooooo`;o00000_ooool3
o`0006oooooo000Looooo`03o`000?oooooooooo04Sooooo0_l00008ooooo`;o00001_ooool2o`00
00Kooooo0_l00002ooooo`;o00004_ooool2o`000003ooooool0003o000001cooooo0_l00004oooo
o`Go00001?ooool2o`0000Oooooo1?l00002ooooo`;o00002_ooool2o`0000Kooooo0_l00004oooo
o`;o00000_ooool3o`00017ooooo0_l0001Looooo`007?ooool00ol0003oooooooooo`1Booooo`;o
00001_ooool2o`0000Kooooo0_l00002ooooo`?o00001_ooool2o`000003ooooool0003o000000Wo
oooo0_l00002ooooo`;o00000_ooool2o`0000gooooo1?l00005ooooo`Co000000?oooooo`000?l0
00000_l00004ooooo`Oo00001?ooool2o`000003ooooool0003o000000?o00002oooool4o`000003
ooooool0003o000000gooooo0_l0000=ooooo`;o0000G?ooool001cooooo00?o0000ooooooooool0
D?ooool2o`0000Oooooo0_l0000<ooooo`;o00001_ooool2o`000003ooooool0003o000000Kooooo
0_l00005ooooo`Ko00002oooool9o`0000;ooooo1Ol00003ooooo`;o000000?oooooo`000?l00000
1ol00007ooooo`;o000000?oooooo`000?l000002oooool4o`00013ooooo0ol000000ooooooo0000
o`00001Wooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00001oooool2o`0000_ooooo0_l0
000;ooooo`;o00001Oooool2o`0000;ooooo1ol0000<ooooo`?o000000Coooooo`000?l0003ooooo
0ol00004ooooo`?o00000oooool2o`000005ooooool0003o0000o`000?ooool00_l00002ooooo`;o
00006?ooool2o`0000cooooo1?l000000ooooooo0000o`000003o`0000Sooooo0_l0001Mooooo`00
7?ooool00ol0003oooooooooo`1Cooooo`;o00003?ooool2o`0000?ooooo0_l0000;ooooo`;o0000
1_ooool2o`000005ooooool0003o0000o`000?ooool00_l0000=ooooo`;o00007Oooool3o`0000go
oooo0_l00008ooooo`;o00003?ooool4o`0000;ooooo0_l00006ooooo`;o00000_ooool2o`0005go
oooo000Looooo`;o0000E?ooool2o`0000cooooo0ol0000Gooooo`;o00005?ooool4o`0000Cooooo
0_l00002ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00001oooool4o`0000?ooooo
0ol00004ooooo`Go00009?ooool2o`000004ooooool0003o0000o`0005gooooo000Looooo`03o`00
0?oooooooooo05kooooo0_l00002ooooo`;o00001?ooool2o`0000Kooooo1Ol000000ooooooo0000
o`00000?ooooo`;o00002?ooool4o`0000Cooooo0_l000001Ooooooo0000o`000?l0003ooooo00Co
00000_ooool4o`0000Gooooo0_l00004ooooo`Co00001?ooool5o`0000_ooooo0_l0000Booooo`;o
00001_ooool5o`0005_ooooo000Looooo`03o`000?oooooooooo057ooooo0_l0000;ooooo`;o0000
2?ooool4o`0000Cooooo1Ol000000ooooooo0000o`00000?ooooo`;o00002?ooool3o`0000Sooooo
0ol00003ooooo`;o00001?ooool2o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0000Kooooo
0_l000001?oooooo0000o`000?l0000:ooooo`;o000000?oooooo`000?l000000oooool4o`0000?o
oooo0_l00003ooooo`;o00001oooool4o`0000?ooooo0_l0001Fooooo`007?ooool00ol0003ooooo
ooooo`1Aooooo`;o00000oooool2o`0000Kooooo0_l0000:ooooo`;o00002_ooool2o`0000Gooooo
0_l00008ooooo`;o00008Oooool4o`0000;ooooo0_l00004ooooo`;o00001Oooool2o`0000;ooooo
0_l0000=ooooo`;o00000oooool4o`0000?ooooo0_l00007ooooo`;o00001oooool2o`000003oooo
ool0003o000000gooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`0looooo`;o00006?oo
ool4o`0000Cooooo0_l0000Fooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o0000
1Oooool2o`0000Gooooo0_l00002ooooo`;o00005_ooool2o`000003ooooool0003o000000;ooooo
0_l00003ooooo`;o00001Oooool2o`0000;ooooo0_l00006ooooo`;o00004Oooool2o`0000;ooooo
1?l000000ooooooo0000o`000007ooooo`;o00004?ooool2o`0004Oooooo000Looooo`03o`000?oo
oooooooo033ooooo0_l0000:ooooo`;o00005Oooool2o`0000?ooooo0_l0000?ooooo`;o00001Ooo
ool2o`0000Sooooo2?l00002ooooo`;o000000?oooooo`000?l000001Oooool2o`0000;ooooo0ol0
0007ooooo`;o00003?ooool2o`000003ooooool0003o000000;ooooo0_l0000=ooooo`?o00001_oo
ool2o`0000Wooooo0_l0000:ooooo`Co00004Oooool2o`0005;ooooo000Looooo`03o`000?oooooo
oooo033ooooo0_l0000Kooooo`;o00000oooool3o`0001Cooooo0_l00005ooooo`Co00001oooool8
o`000003ooooool0003o000000?o00000_ooool3o`0000Gooooo0_l000001?oooooo0000o`000?oo
ool2o`000004ooooool0003o0000o`0000_ooooo0_l00005ooooo`;o00003Oooool2o`0001;ooooo
0_l0000:ooooo`?o00002oooool2o`0000Gooooo0_l0001Booooo`007?ooool00ol0003ooooooooo
o`18ooooo`;o00000_ooool3o`0000?ooooo0_l0000;ooooo`;o00004Oooool3o`0000Kooooo0_l0
0004ooooo`;o00000_ooool4o`0000;ooooo0ol000000ooooooo0000o`000005ooooo`;o000000?o
ooooo`000?l000000_ooool2o`000003ooooool0003o000000Sooooo0_l00005ooooo`;o00002?oo
ool4o`000003ooooool0003o000001kooooo0ol00006ooooo`;o00000oooool4o`0005Oooooo000L
ooooo`03o`000?oooooooooo04Sooooo0_l00002ooooo`?o00000oooool6o`0000Oooooo0_l00009
ooooo`;o00001oooool4o`0000;ooooo3?l000001Ooooooo0000o`000?l0003ooooo00Oo00000ooo
ool2o`0000Oooooo0_l000000ooooooo0000o`000002ooooo`;o00002?ooool3o`000003ooooool0
003o000000Gooooo1_l000001?oooooo0000o`000?ooool3o`0000Oooooo1_l00004ooooo`;o0000
3Oooool2o`000004ooooool0003o0000o`0000Cooooo1?l00004ooooo`;o00004?ooool2o`0003go
oooo000Looooo`03o`000?oooooooooo04Kooooo0_l00005ooooo`;o00000oooool7o`00017ooooo
0_l00004ooooo`;o00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000004o`000004oooo
ool0003o0000ooooo`?o000000Coooooo`000?l0003ooooo0ol00004ooooo`Co00000_ooool2o`00
0003ooooool0003o000000Gooooo0_l00003ooooo`;o00000oooool3o`000003ooooool0003o0000
00Gooooo0_l00005ooooo`;o000000Coooooo`000?l0003o00000oooool2o`0000;ooooo1_l00000
1?oooooo0000o`000?ooool2o`0000_ooooo1?l00002ooooo`;o00001_ooool2o`0000Cooooo0_l0
000:ooooo`;o00001?ooool2o`0003gooooo000Looooo`03o`000?oooooooooo04Kooooo0_l00006
ooooo`;o00001oooool2o`00017ooooo0_l00004ooooo`;o00002_ooool4o`000003ooooool0003o
000000Oo000000?oooooo`000?l000001?l00005ooooo`;o00000_ooool2o`0000Kooooo0_l00005
ooooo`;o00001oooool2o`0000Cooooo0_l00006ooooo`;o000000?oooooo`000?l000001?ooool2
o`0000Wooooo1?l00009ooooo`;o000000?oooooo`000?l000003oooool2o`0000gooooo0_l00013
ooooo`007?ooool00ol0003oooooooooo`1=ooooo`?o00004oooool2o`0001Wooooo0_l000000ooo
oooo0000o`000007o`000003ooooool0003o000000Co000000?oooooo`000?l000000_ooool2o`00
00;ooooo0_l00006ooooo`;o00000_ooool2o`0000Kooooo0_l00002ooooo`;o00001?ooool2o`00
00?ooooo0_l00004ooooo`;o00004Oooool2o`0000Wooooo0_l00006ooooo`;o00002_ooool2o`00
05;ooooo000Looooo`03o`000?oooooooooo04gooooo0ol0000>ooooo`;o00000oooool2o`0000Go
oooo0_l00008ooooo`Co00001Oooool3o`000003ooooool0003o000000;o000000?oooooo`000?l0
00000_l000000ooooooo0000o`000007o`0000;ooooo2?l00008ooooo`Co00001?ooool2o`0000;o
oooo0_l00009ooooo`Co00000_ooool3o`000003ooooool0003o000000;ooooo0_l0000@ooooo`;o
00002_ooool2o`0000_ooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`1>ooooo`?o0000
3?ooool3o`0000Kooooo0_l00002ooooo`;o00001_ooool6o`0000Cooooo2Ol000000ooooooo0000
o`00000;o`0000Cooooo1?l000000ooooooo0000o`00000:ooooo`;o00005Oooool3o`000005oooo
ool0003o0000o`000?ooool01_l0000@ooooo`;o00005oooool2o`000003ooooool0003o000000;o
oooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`17ooooo`?o00001?ooool3o`0000_ooooo
0ol00007ooooo`;o00002_ooool2o`0000Sooooo0_l00002ooooo`Oo000000?oooooo`000?l00000
1_l00003ooooo`So00000_ooool2o`0001;ooooo0_l00004ooooo`;o00001?ooool2o`000003oooo
ool0003o000000Ko000000?oooooo`000?l000001oooool2o`000003ooooool0003o0000017ooooo
0_l0000;ooooo`;o00000_ooool2o`0000;ooooo0_l0001:ooooo`007?ooool00ol0003ooooooooo
o`0eooooo`;o00004?ooool4o`0000kooooo0_l000000ooooooo0000o`000005ooooo`Go00003Ooo
ool3o`0000Sooooo1ol000000ooooooo0000o`00000?o`0000Cooooo0ol00006ooooo`;o00002Ooo
ool2o`0000Cooooo1?l00002ooooo`go00002?ooool2o`000003ooooool0003o000000Gooooo0_l0
000:ooooo`Co00000oooool2o`0000Cooooo0_l00006ooooo`;o0000B_ooool001cooooo0_l0000f
ooooo`;o00001oooool2o`0000?ooooo0_l00004ooooo`;o00003_ooool2o`0000;ooooo1?l00002
ooooo`Go00000oooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000004
o`0000?ooooo7?l00004ooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo0_l00008
ooooo`;o00000_ooool2o`0000;ooooo1Ol000000ooooooo0000o`000006o`00013ooooo0ol00006
ooooo`;o00001?ooool2o`0000?ooooo0_l0000<ooooo`;o00002?ooool2o`00043ooooo000Loooo
o`03o`000?oooooooooo03kooooo0_l00003ooooo`;o00006?ooool4o`0000Gooooo0_l00003oooo
o`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo8?l000001?oooooo0000o`000?l00006
ooooo`?o00001Oooool2o`000003ooooool0003o000000Sooooo0_l00005oooooa;o000000?ooooo
o`000?l000001_ooool2o`0000;ooooo0_l00004ooooo`Go00004Oooool4o`0000cooooo0_l00010
ooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00001_ooool2o`0000oooooo0_l0000Eoooo
o`;o00000oooool2o`0000;ooooo8Ol00002ooooo`;o00000oooool2o`0000Kooooo0_l00008oooo
o`Co00001OoooolFo`0000Kooooo0_l00008ooooo`Go00003Oooool2o`0000;ooooo1?l00005oooo
o`;o0000Aoooool001cooooo00?o0000ooooooooool0?oooool2o`0000?ooooo0_l000000ooooooo
0000o`00000?ooooo`Co00000oooool4o`0000Oooooo0_l00003ooooo`;o00000oooool2o`0000?o
oooo8?l00002ooooo`;o00000oooool2o`00013ooooo1?l00005ooooo`_o00000_ooool7o`0000So
oooo0_l0000Iooooo`?o00002oooool2o`0000Kooooo0_l0000oooooo`007?ooool00ol0003ooooo
ooooo`0looooo`;o00001_ooool2o`000003ooooool0003o0000017ooooo0_l000000ooooooo0000
o`000004o`0000Oooooo0_l00006ooooo`;o00001oooool6o`000003ooooool0003o000001Go0000
00?oooooo`000?l000001?ooool2o`0000Gooooo0_l00008ooooo`;o000000?oooooo`000?l00000
1Oooool;o`000003ooooool0003o000000Ko00000_ooool2o`0000;ooooo1?l0000Iooooo`;o0000
2Oooool2o`0000Wooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0looooo`?o00002?oo
ool2o`0000gooooo0_l00005ooooo`?o00003?ooool2o`0000Cooooo1?l00002ooooo`;o000000?o
ooooo`000?l000007ol000000ooooooo0000o`000004o`0000Cooooo0_l00008ooooo`;o000000?o
ooooo`000?l000001?oooolEo`0000;ooooo0_l000001?oooooo0000o`000?l00005ooooo`;o0000
4_ooool2o`0000_ooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00005ooo
ool2o`0000Kooooo0_l0000<ooooo`;o000000?oooooo`000?l000001_l000000ooooooo0000o`00
000Qo`0000;ooooo1ol00005ooooo`?o00001ooooolPo`000003ooooool0003o000000Kooooo0_l0
000Booooo`;o00002_ooool2o`0000Cooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`0`
ooooo`;o0000>oooool^o`0000Cooooo1Ol00005ooooo`?o00001ooooolPo`0000;ooooo0_l00005
ooooo`;o00001oooool2o`0000Oooooo0_l0000<ooooo`;o00001?ooool2o`0004Gooooo000Loooo
o`03o`000?oooooooooo033ooooo0_l0000Looooo`;o00002oooool2o`0000Cooooo1?l00008oooo
o`?o000000Goooooo`000?l0003o0000ooooo`04o`000003ooooool0003o000002?o00000_ooool2
o`0001Gooooo6?l000000ooooooo0000o`000002ooooo`;o00003_ooool2o`0000Cooooo1Ol00000
0ooooooo0000o`000002o`0000Oooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`12oooo
o`;o00002_ooool2o`0000_ooooo0_l00004ooooo`Co00002?ooool9o`000003ooooool0003o0000
01So00000oooool;o`0000;ooooo1Ol00003ooooo`;o00002_ooool2o`000003ooooool0003o0000
01Ko000000?oooooo`000?l000001?ooool2o`0000Gooooo0_l0000;ooooo`Go000000?oooooo`00
0?l000000_l00007ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0?oooool5o`0000;o
oooo1?l0000<ooooo`;o00002_ooool3o`0000Sooooo1Ol00002ooooo`;o00000_oooolKo`000003
ooooool0003o000000[o000000?oooooo`000?l000000ol00003ooooo`;o00000_ooool2o`0000Ko
oooo1?l000000ooooooo0000o`00000Do`000003ooooool0003o000000Cooooo0_l00005ooooo`;o
00002Oooool2o`0000?ooooo0_l00004ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0
?oooool5o`0000;ooooo1?l0000<ooooo`;o00002oooool2o`0000Oooooo0_l00005ooooo`?o0000
00?oooooo`000?l000008ol000001?oooooo0000o`000?l00002ooooo`;o00000_ooool2o`000003
ooooool0003o000000;ooooo0_l00007ooooo`?o000000?oooooo`000?l000004ol00002ooooo`;o
00005Oooool3o`0000Wooooo0_l0000=ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0
>_ooool4o`0000Sooooo0_l0000Tooooo`;o00001OoooolVo`000003ooooool0003o000000?o0000
0oooool2o`0000;ooooo0_l000000ooooooo0000o`00000@oooooaSo00000oooool2o`0000Gooooo
0_l00009ooooo`?o00001Oooool4o`0000Sooooo0_l00003ooooo`Co0000A?ooool001cooooo00?o
0000ooooooooool09oooool2o`00017ooooo1?l00008ooooo`?o00006Oooool2o`0000Wooooo0_l0
0006oooooa7o000000?oooooo`000?l000005?l00002ooooo`;o000000?oooooo`000?l000005Ooo
oolHo`0000Gooooo0_l00005ooooo`;o00004Oooool4o`0000Oooooo0ol00003ooooo`;o00000_oo
ool2o`0004;ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o0000
00?o410@ooooooooool01?ooool00ol0003oooooooooo`0Wooooo`;o00003oooool2o`000003oooo
ool0003o000000[ooooo0_l0000Aooooo`;o00001?ooool5o`000003ooooool0003o000000Gooooo
1ol000000ooooooo0000o`000003o`000003ooooool0003o000000?o000000?oooooo`000?l00000
7_l000001?oooooo0000o`000?ooool2o`0001;ooooo6?l0000Eooooo`;o00002Oooool2o`0000So
oooo0_l00008ooooo`;o0000@_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q
8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0hooooo`Go00002_ooool3o`00
013ooooo0_l00002ooooo`Oo000000?oooooo`000?l000001?ooool2o`000003ooooool0003o0000
00?o000000?oooooo`000?l000000ol000000ooooooo0000o`000003o`000003ooooool0003o0000
00co000000?oooooo`000?l000003_l000001?oooooo0000o`000?ooool3o`0001Gooooo5_l0000<
ooooo`;o00001_ooool2o`0000Wooooo1?l0000?ooooo`;o0000@oooool00003ooooool@413ooooo
00;ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo00?o0000ooooooooool0>Oooool2o`00
00Gooooo0_l00004ooooo`Co00005?ooool2o`0000cooooo1?l00006ooooob[o000000Coooooo`00
0?l0003ooooo0_l00004ooooo`;o00004Oooool?o`0000;ooooo1?l0000<ooooo`;o00002_ooool4
o`0000Gooooo0_l00003ooooo`;o00002_ooool2o`0004?ooooo00000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`0003Wooooo0ol00004
ooooo`;o00001?ooool2o`0001?ooooo0_l000000ooooooo0000o`00000>ooooo`;o00000_ooool2
o`0000;ooooo3_l00002oooooaGo000000?oooooo`000?l000000ol00009ooooo`Co00003oooool2
o`000005ooooool0003o0000o`000?ooool02Ol0000Hooooo`;o00000oooool4o`0000Gooooo0_l0
0003ooooo`;o00002_ooool2o`0004?ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`0fooooo`;o00000_oo
ool3o`0000?ooooo0_l00003ooooo`Go00004Oooool2o`0000Oooooo0_l000000ooooooo0000o`00
0009ooooo`?o000000Goooooo`000?l0003o0000ooooo`03o`000003ooooool0003o000000Co0000
00?oooooo`000?l000005?l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l00006ooooo`;o
00004?ooool5o`000003ooooool0003o000000Oo00003oooool2o`0000Oooooo0_l00004ooooo`;o
00001_ooool2o`0000?ooooo0_l0000:ooooo`?o0000@_ooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool02_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo03Kooooo
0_l00002ooooo`?o00000_ooool3o`0000?ooooo1Ol0000Gooooo`;o000000Coooooo`000?l0003o
oooo0ol00009ooooo`;o000000Coooooo`000?l0003ooooo9Ol000001?oooooo0000o`000?l00002
ooooo`;o00006?ooool2o`000003ooooool0003o000000;ooooo0ol000000ooooooo0000o`00000A
ooooo`;o00004oooool2o`000003ooooool0003o000000Co00002oooool2o`0004;ooooo00001_oo
ooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l000001oooool00ol0003ooooooooo
o`0oooooo`;o00006oooool2o`0000?ooooo0_l00005ooooo`;o00002oooool2o`0000;ooooo7ol0
00000ooooooo0000o`000003o`000004ooooool0003o0000o`0002Oooooo0_l00002ooooo`;o0000
7?ooool2o`0000?ooooo2_l00005ooooo`;o000000?oooooo`000?l00000AOooool00006ooooooo^
k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo033o
oooo0_l0000Zooooo`;o00002oooool2o`0000[ooooo0ol000000ooooooo0000o`00000Ro`0000;o
oooo0_l0000:ooooo`;o00008?ooool2o`0000?ooooo0_l0000Eooooo`Co00000oooool2o`000003
ooooool0003o000000;o000000?oooooo`000?l000001Oooool2o`000003ooooool0003o000004Go
oooo000Looooo`03o`000?oooooooooo033ooooo0_l0000gooooo`;o00001_ooool2o`0000?ooooo
0ol000000ooooooo0000o`00000Ro`0000gooooo0_l0000Fooooo`?o000000?oooooo`000?l00000
2Oooool2o`00017ooooo0_l00002ooooo`;o00001?ooool2o`0000;ooooo1?l000001?oooooo0000
o`000?l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`0004;ooooo000Looooo`03o`00
0?oooooooooo04?ooooo0_l0000[ooooo`?o000000?oooooo`000?l000000ol000000ooooooo0000
o`00000Mo`000003ooooool0003o000000?o00001_ooool2o`0001Kooooo0_l00004ooooo`?o0000
00?oooooo`000?l000000_l00002ooooo`;o00003_ooool2o`0000Kooooo0_l00008ooooo`;o0000
0oooool4o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000002ooooo`Co0000
@?ooool001cooooo00?o0000ooooooooool0@Oooool4o`0001Sooooo0_l00008ooooo`;o00001ooo
ool2o`0000;ooooo1?l00002ooooobGo00001_ooool2o`0001Kooooo0_l0000:ooooo`;o00000_oo
ool2o`0000kooooo0_l00004ooooo`;o00002_ooool2o`0000Gooooo0_l0000<ooooo`;o000000Co
ooooo`000?l0003ooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`11ooooo`;o00001Ooo
ool2o`0001?ooooo0_l00008ooooo`;o00001?ooool3o`0000Kooooo0_l00002ooooo`ko000000?o
ooooo`000?l000004Ol000001?oooooo0000o`000?ooool2o`000004ooooool0003o0000o`00017o
oooo0_l00006ooooo`;o00008_ooool2o`0001_ooooo0_l00002ooooo`?o00000oooool2o`0003go
oooo000Looooo`03o`000?oooooooooo043ooooo0_l00006ooooo`;o00007_ooool2o`0000?ooooo
0ol00006ooooo`;o00000_ooool2o`000003ooooool0003o000000So000000?oooooo`000?l00000
4_l000001?oooooo0000o`000?ooool2o`000004ooooool0003o0000o`0000gooooo1_l00004oooo
o`Co00001?ooool2o`0001Sooooo0_l0000=ooooo`;o00004?ooool2o`0000?ooooo0_l00012oooo
o`007?ooool00ol0003oooooooooo`0cooooo`;o00001?ooool2o`0000Gooooo0ol0000Uooooo`;o
00002?ooool4o`0000Cooooo6ol00002ooooo`Oo00000_ooool2o`00017ooooo1?l00006ooooo`;o
00001_ooool2o`0000gooooo0_l00009ooooo`;o00003Oooool2o`0000Sooooo0_l00009ooooo`;o
0000A?ooool001cooooo00?o0000ooooooooool0<oooool2o`0000Cooooo0_l00006ooooo`?o0000
0oooool2o`0001Oooooo1?l0000>ooooo`Co00000_oooolJo`000003ooooool0003o000000oo0000
7?ooool2o`0000?ooooo0_l0000=ooooo`;o00008Oooool4o`0000Sooooo0_l00006ooooo`;o0000
??ooool001cooooo00?o0000ooooooooool0<oooool2o`0000[ooooo0_l000000ooooooo0000o`00
0003ooooo`;o00004oooool2o`0000;ooooo1Ol000000ooooooo0000o`000008ooooo`Co00000ooo
ool6o`0000Cooooo0ol000000ooooooo0000o`00000Fo`000003ooooool0003o000000;ooooo0_l0
000Dooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o0000:_ooool2o`0000Cooooo1?l0
00000ooooooo0000o`000005ooooo`;o00001_ooool2o`000003ooooool0003o000003Wooooo000L
ooooo`03o`000?oooooooooo03?ooooo0_l0000:ooooo`;o00006oooool2o`0000Cooooo0ol00000
0ooooooo0000o`000008ooooo`;o00001Oooool6o`0000Sooooo4Ol00003ooooo`Co00000_ooool2
o`0001Cooooo0_l000000ooooooo0000o`000002ooooo`;o0000<oooool2o`0000Wooooo0_l00005
ooooo`;o00002Oooool2o`0000;ooooo0_l0000eooooo`007?ooool00ol0003oooooooooo`1Joooo
o`;o00001_ooool2o`0000Oooooo0_l00007ooooo`;o00000oooool4o`0000Sooooo3?l00002oooo
o`Go00001oooool4o`000003ooooool0003o000000oooooo0ol00007ooooo`;o00000oooool2o`00
00;ooooo0_l0000?ooooo`?o00007Oooool2o`0000Gooooo0_l0000@ooooo`;o0000=Oooool001co
oooo00?o0000ooooooooool09oooool2o`0000Gooooo0_l00003ooooo`;o00001?ooool2o`0000Ko
oooo0_l00003ooooo`;o00004_ooool2o`000003ooooool0003o000000cooooo0_l00007ooooo`;o
00001Oooool3o`0000Cooooo0_l000000ooooooo0000o`00000:o`0000;ooooo1Ol00004ooooo`;o
00000oooool2o`000003ooooool0003o0000013ooooo0_l00007ooooo`?o00000_ooool6o`000003
ooooool0003o000000cooooo0ol0000Mooooo`;o00001Oooool2o`0000?ooooo0_l00012ooooo`00
7?ooool2o`0002Sooooo0_l00005ooooo`Co000000?oooooo`000?l000001?ooool3o`0000Gooooo
0_l00003ooooo`;o00005Oooool2o`00017ooooo0_l00004ooooo`;o000000Coooooo`000?l0003o
oooo0_l00004ooooo`;o000000?oooooo`000?l000001_l000000ooooooo0000o`000002o`000004
ooooool0003o0000o`0000?ooooo0_l000000ooooooo0000o`00000:ooooo`;o00001?ooool2o`00
00Kooooo0_l00003ooooo`;o00000oooool2o`0000;ooooo1?l00003ooooo`;o00001Oooool2o`00
013ooooo0_l0000Dooooo`;o00001?ooool2o`000003ooooool0003o000000;o00004Oooool2o`00
00Sooooo0_l0000Uooooo`007?ooool00ol0003oooooooooo`0^ooooo`Co00001oooool3o`00027o
oooo0_l0000Aooooo`;o00001?ooool2o`000003ooooool0003o000000?ooooo1Ol00002ooooo`Go
000000?oooooo`000?l000000_ooool8o`0000;ooooo0_l000000ooooooo0000o`00000:ooooo`;o
00001?ooool2o`0000_ooooo0_l00007ooooo`;o000000?oooooo`000?l000001Oooool2o`0000;o
oooo0_l000001?oooooo0000o`000?ooool2o`0000[ooooo0_l0000Dooooo`;o00001?ooool2o`00
0004ooooool0003o0000o`0000oooooo0_l000000ooooooo0000o`000008ooooo`;o00009Oooool0
01cooooo00?o0000ooooooooool0;_ooool2o`0000Wooooo0_l00006ooooo`;o00007_ooool2o`00
00Gooooo0ol0000:ooooo`?o000000?oooooo`000?l000000oooool<o`0000?ooooo1?l000000ooo
oooo0000o`000003o`0000Gooooo0_l00008ooooo`;o00002_ooool2o`0000Gooooo1?l0000:oooo
o`;o00001Oooool2o`0000;ooooo0_l000000ooooooo0000o`000003o`0000Cooooo0_l00005oooo
o`;o00002?ooool2o`0002Cooooo0_l0000booooo`007?ooool00ol0003oooooooooo`0jooooo`;o
00001Oooool2o`0000Cooooo0_l0000Gooooo`?o00001Oooool3o`0000[ooooo0_l00002ooooo`;o
00001oooool3o`000003ooooool0003o000000;o00000oooool2o`0000Cooooo0_l0000Aooooo`;o
00002_ooool2o`0000Gooooo0_l00003ooooo`;o00005Oooool6o`000003ooooool0003o000000;o
00001Oooool2o`0000Sooooo0_l000000ooooooo0000o`000008ooooo`;o000000?oooooo`000?l0
0000B?ooool001cooooo00?o0000ooooooooool0;?ooool2o`0000Gooooo0_l00002ooooo`;o0000
00?oooooo`000?l000001Oooool2o`0000Cooooo0_l0000Gooooo`;o00008?ooool2o`0000;ooooo
1?l00003ooooo`;o00003Oooool2o`0001Sooooo1?l000001?oooooo0000o`000?ooool2o`0000Wo
oooo0_l0000;ooooo`So00005?ooool4o`0000Cooooo1?l000000ooooooo0000o`000007o`00047o
oooo000Looooo`03o`000?oooooooooo02cooooo0_l00005ooooo`;o00000_ooool2o`0002kooooo
0_l00009ooooo`;o00003_ooool4o`0000?ooooo1_l00003ooooo`;o00000oooool4o`000004oooo
ool0003o0000ooooo`;o00005Oooool4o`000003ooooool0003o000000_ooooo0ol0000;ooooo`;o
00000_ooool2o`000003ooooool0003o000000;o00004oooool2o`0000Cooooo1Ol00002ooooo`Oo
0000@Oooool001cooooo00?o0000ooooooooool0:?ooool2o`0000gooooo0_l0000Pooooo`;o0000
2?ooool2o`0000;ooooo0_l00004ooooo`;o00000oooool4o`0000?ooooo0_l00003ooooo`;o0000
1?ooool2o`0000?ooooo1_l00003ooooo`;o00000oooool4o`0000Cooooo0_l0000=ooooo`;o0000
1?ooool2o`000003ooooool0003o000000;o00003Oooool4o`0000[ooooo0_l00005ooooo`Co0000
0oooool2o`0000Wooooo0_l0000<ooooo`;o00002Oooool2o`0003oooooo000Looooo`03o`000?oo
oooooooo02Sooooo1?l0000;ooooo`;o00000_ooool2o`0001cooooo0_l00008ooooo`;o00001?oo
ool2o`0000;ooooo0_l00004ooooo`?o00000oooool2o`0000?ooooo0_l00002ooooo`;o000000Co
ooooo`000?l0003o00000_ooool2o`0000;ooooo0_l000001?oooooo0000o`000?l0000Gooooo`;o
000000?oooooo`000?l000001?ooool2o`0000?ooooo0_l0000?ooooo`;o00002oooool2o`0000Co
oooo1Ol00002ooooo`?o00002?ooool2o`0000cooooo1?l00007ooooo`;o0000?oooool001cooooo
00?o0000ooooooooool0:_ooool2o`0000oooooo0_l00002ooooo`;o00000_ooool2o`000003oooo
ool0003o0000027ooooo0_l00008ooooo`;o000000?oooooo`000?l000002_ooool2o`000003oooo
ool0003o000000?o00000_ooool7o`00013ooooo0_l00005ooooo`?o00001_ooool3o`0000?ooooo
0_l00005ooooo`;o00005Oooool2o`0000Kooooo2?l00004ooooo`;o00000oooool2o`0000_ooooo
1?l00018ooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00001Oooool3o`0000;ooooo0_l0
00000ooooooo0000o`00000Eooooo`;o00003Oooool2o`0000Cooooo0_l00002ooooo`;o00000_oo
ool2o`0000Kooooo0_l00004ooooo`;o00000_ooool2o`000003ooooool0003o000000[ooooo0_l0
0006ooooo`;o00001Oooool5o`0000;ooooo1Ol00003ooooo`;o00001Oooool2o`0000Cooooo0_l0
000>ooooo`Co00001oooool3o`0000Oooooo0_l00003ooooo`;o00001Oooool2o`0000;ooooo0_l0
000Booooo`;o0000>?ooool001cooooo00?o0000ooooooooool0;oooool2o`0000Kooooo0_l00005
ooooo`;o00006?ooool2o`0000?ooooo0_l00009ooooo`;o00000_ooool2o`0000Cooooo0_l00002
ooooo`Ko00001_ooool2o`0000oooooo0_l00006ooooo`;o00000_ooool2o`0000;ooooo0_l00002
ooooo`;o00000oooool4o`000004ooooool0003o0000o`0001;ooooo0_l000000ooooooo0000o`00
000;ooooo`So00001?ooool2o`00017ooooo1?l00002ooooo`;o00000oooool2o`0000gooooo0_l0
000hooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o00000_ooool2o`0000Kooooo0_l0000?
ooooo`;o00003_ooool2o`000003ooooool0003o000000Co00001oooool2o`0000Gooooo0_l00005
ooooo`Ko000000?oooooo`000?l000004?ooool2o`0000;ooooo0_l00006ooooo`;o00000_ooool2
o`000004ooooool0003o0000o`0000;ooooo0_l00005ooooo`Co00001Oooool2o`00013ooooo0_l0
0007ooooo`Co000000?oooooo`000?l000001_l00003ooooo`;o00001?ooool4o`0000Wooooo1Ol0
0006ooooo`;o00001_ooool4o`0003gooooo000Looooo`03o`000?oooooooooo02Cooooo0_l00003
ooooo`Co00000_ooool2o`0000Sooooo0_l0000=ooooo`;o00004?ooool7o`0000kooooo0_l00008
ooooo`;o00000_ooool2o`0000Gooooo0_l00009ooooo`;o00001oooool2o`000003ooooool0003o
000000Cooooo0ol000000ooooooo0000o`000005ooooo`?o000000Coooooo`000?l0003o00001?oo
ool2o`00017ooooo0_l00005ooooo`Go000000?oooooo`000?l000001_l000000ooooooo0000o`00
0006ooooo`Co00003?ooool2o`0000;ooooo0_l00009ooooo`Go00001?ooool2o`0000;ooooo0_l0
000cooooo`007?ooool00ol0003oooooooooo`0Tooooo`;o00000oooool2o`0000Cooooo0_l00008
ooooo`?o000000?oooooo`000?l000001oooool2o`000003ooooool0003o000000oooooo0_l00006
ooooo`Co00000_ooool2o`0001[ooooo0_l00003ooooo`;o00003Oooool2o`000003ooooool0003o
000000Cooooo0_l00002ooooo`Co000000?oooooo`000?l000000ol00002ooooo`;o00003_ooool3
o`0000Cooooo1?l00003oooooa?o00000oooool2o`0000;ooooo0_l0000Aooooo`Co00001oooool2
o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o0000<oooool001cooooo00?o0000oooo
ooooool0;_ooool2o`0000Oooooo0_l000001?oooooo0000o`000?ooool2o`0000Oooooo1Ol0000A
ooooo`;o00001?ooool4o`0000;ooooo0_l0000=ooooo`;o00004?ooool2o`0000_ooooo0_l00003
ooooo`;o00002Oooool3o`000003ooooool0003o000000?o00001Oooool2o`0000Kooooo0_l00003
ooooo`?o00001?ooool3o`000003ooooool0003o000001;o00001?ooool3o`0000Sooooo0_l00007
ooooo`;o00001?ooool4o`0000?ooooo0_l000000ooooooo0000o`000002o`0003gooooo000Loooo
o`03o`000?oooooooooo02kooooo0ol00006ooooo`;o00003_ooool2o`0001?ooooo0_l00004oooo
o`;o00002Oooool3o`0000Oooooo0_l0000Gooooo`;o00000_ooool6o`00017ooooo1?l00005oooo
o`;o00000_ooool2o`0000;ooooo0_l00002ooooo`;o00001oooool2o`000003ooooool0003o0000
00oo000000?oooooo`000?l000000oooool3o`0000Wooooo0_l00005ooooo`Co000000Coooooo`00
0?l0003o00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`00000oooooo`007?ooool2o`00
033ooooo0_l00004ooooo`;o00001?ooool2o`0000kooooo0_l0000Pooooo`?o00003oooool2o`00
00oooooo0ol000000ooooooo0000o`000002ooooo`;o00002oooool4o`0000;ooooo1_l00007oooo
o`;o00001_ooool2o`0000Sooooo1ol000000ooooooo0000o`00000>o`000004ooooool0003o0000
o`00013ooooo0_l00003ooooo`Co000000?oooooo`000?l000000_l00015ooooo`007?ooool00ol0
003oooooooooo`0eooooo`;o00001?ooool2o`0000?ooooo0_l00009ooooo`;o0000<?ooool4o`00
013ooooo0_l0000>ooooo`;o00000_ooool4o`0000Cooooo1_l000001?oooooo0000o`000?ooool2
o`0000kooooo6ol00002ooooo`;o00000_ooool2o`0000[ooooo1?l00002ooooo`;o000000Cooooo
o`000?l0003ooooo1?l00015ooooo`007?ooool00ol0003oooooooooo`0eooooo`;o00002Oooool2
o`0000Kooooo0ol0000Gooooo`;o00001Oooool2o`0001;ooooo0_l0000Rooooo`;o00003?ooool4
o`000003ooooool0003o000000Co00003OoooolAo`000003ooooool0003o000000So000000?ooooo
o`000?l000000_ooool2o`0000[ooooo0_l00004ooooo`;o000000?oooooo`000?l000000_ooool2
o`0004Kooooo000Looooo`03o`000?oooooooooo03Oooooo1?l00004ooooo`;o00001oooool5o`00
00Wooooo0_l0000:ooooo`;o00001Oooool4o`0000Gooooo0_l00007ooooo`;o00007_ooool2o`00
00Kooooo0_l0000Aooooo`Ko000000?oooooo`000?l000001?ooool2o`0000?ooooo0_l000000ooo
oooo0000o`00000Io`0000gooooo1?l00002ooooo`;o00000_ooool2o`0000Cooooo0_l00002oooo
o`;o0000@?ooool001cooooo00?o0000ooooooooool0<Oooool2o`0000;ooooo1_l00004ooooo`;o
00002Oooool3o`0000Wooooo0_l00003ooooo`;o00003_ooool2o`0000Gooooo0_l00005ooooo`Co
00000_ooool2o`0000Oooooo1?l00006ooooo`;o00001oooool2o`0000Kooooo1?l0000:ooooo`;o
00000oooool2o`000003ooooool0003o000000Co00001?ooool2o`0000?ooooo0ol000000ooooooo
0000o`00000Io`0000cooooo2?l00006ooooo`Co00000_ooool2o`0000Cooooo0_l0000jooooo`00
7?ooool00ol0003oooooooooo`0aooooo`;o00000_ooool2o`0002?ooooo1?l0000Aooooo`;o0000
00Coooooo`000?l0003ooooo0_l00002ooooo`;o00001?ooool2o`0000Oooooo1?l00006ooooo`;o
00004Oooool4o`0000Sooooo0_l00007ooooo`?o00002_oooolKo`0000;ooooo0ol0000<ooooo`;o
00000_ooool2o`000003ooooool0003o000000?ooooo1_l00008ooooo`;o0000>_ooool001cooooo
00?o0000ooooooooool0BOooool2o`0000oooooo1_l00007ooooo`;o00000_ooool2o`0000;ooooo
0_l00003ooooo`?o00002_ooool2o`000003ooooool0003o000000Gooooo0_l00006ooooo`;o0000
3_ooool2o`0000;ooooo0_l0000Aooooo`;o00002_oooolLo`0000;ooooo0_l0000=ooooo`;o0000
1Oooool2o`0000?ooooo0_l00002ooooo`;o00005?ooool2o`0002kooooo000Looooo`03o`000?oo
oooooooo037ooooo0_l0000Fooooo`;o00000oooool2o`0000cooooo1?l00007ooooo`;o00000_oo
ool2o`0000Oooooo0_l00006ooooo`;o00000oooool2o`000003ooooool0003o000000Gooooo0_l0
0006ooooo`;o00003_ooool2o`0001;ooooo0_l00002ooooo`;o00002?oooolMo`0000?ooooo0_l0
000?ooooo`;o00000_ooool2o`0000Kooooo1?l00002ooooo`;o00003oooool2o`0002kooooo000L
ooooo`03o`000?oooooooooo037ooooo0_l000000ooooooo0000o`00000Hooooo`;o00003?ooool2
o`0000Gooooo0_l0000@ooooo`;o00001Oooool2o`00033ooooo0_l00007ooooo`;o00000_ooool2
o`0000?ooooo0_l00002ooooo`Co000000?oooooo`000?l000005ol000000ooooooo0000o`000002
o`0000_ooooo0_l00002ooooo`;o00002_ooool4o`0000;ooooo0_l0000oooooo`007?ooool00ol0
003oooooooooo`0aooooo`;o000000?oooooo`000?l000001_ooool3o`000003ooooool0003o0000
01Cooooo0_l0000;ooooo`;o00001?ooool2o`0000Oooooo0_l000000ooooooo0000o`00000Aoooo
o`;o00003_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000:ooooo`;o000000?oooooo`00
0?l000002oooool2o`0000?ooooo0_l00002ooooo`co000000?oooooo`000?l000003ol000000ooo
oooo0000o`00000=ooooo`;o00001Oooool4o`0000Sooooo0_l00003ooooo`;o00003Oooool2o`00
02kooooo000Looooo`03o`000?oooooooooo03Gooooo0_l00005ooooo`?o000000?oooooo`000?l0
00005?ooool4o`0000Sooooo0_l00005ooooo`Co00001Oooool2o`0000;ooooo0_l0000=ooooo`;o
000000?oooooo`000?l000003_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000:ooooo`;o
000000?oooooo`000?l000002Oooool2o`0000Gooooo3?l000000ooooooo0000o`00000Bo`000004
ooooool0003o0000o`0001Cooooo1ol00005ooooo`;o00000oooool2o`0000gooooo0_l0000^oooo
o`007?ooool00ol0003oooooooooo`0eooooo`;o00000_ooool2o`0001gooooo0_l00008ooooo`?o
00001_ooool2o`0000Wooooo0_l00008ooooo`Co000000?oooooo`000?l000005Oooool2o`00013o
oooo0_l00006ooooo`;o000000Coooooo`000?l0003o00001?ooool<o`000003ooooool0003o0000
01;o000000Coooooo`000?l0003o00002?ooool2o`000003ooooool0003o000000Cooooo0ol00003
ooooo`Co00000_ooool2o`0000?ooooo0_l0000<ooooo`;o00000oooool2o`0002gooooo000Loooo
o`03o`000?oooooooooo02cooooo0_l0000:ooooo`?o00004_ooool2o`0001Cooooo0_l00006oooo
o`Ko00001_ooool2o`0000;ooooo0_l00003ooooo`Go00003?ooool3o`0001[ooooo0_l00006oooo
o`?o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000Oo000000?oooooo`00
0?l000001?l000000ooooooo0000o`00000?o`0000Sooooo0_l000000ooooooo0000o`000004oooo
o`?o00002Oooool2o`0000?ooooo0ol0000;ooooo`;o00000oooool2o`0002gooooo000Looooo`03
o`000?oooooooooo02cooooo0_l0000:ooooo`;o00002_ooool2o`0000Oooooo0_l0000Cooooo`Co
00001Oooool7o`0000Gooooo0_l00002ooooo`;o00001Oooool4o`0000_ooooo0ol0000Iooooo`?o
00001Oooool6o`0000Gooooo2ol00002oooooa;o000000Coooooo`000?l0003o00004_ooool2o`00
00kooooo0_l000000ooooooo0000o`00000oooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o
00003Oooool2o`0000?ooooo0_l000000ooooooo0000o`00000;ooooo`Co00003Oooool4o`0000;o
oooo0_l00004ooooo`Ko00001?ooool2o`000003ooooool0003o000000Oooooo0_l0000=ooooo`;o
00004?ooool4o`0000Cooooo0_l00006ooooo`;o000000Coooooo`000?l0003o00001ooooolQo`00
00Sooooo0_l00008ooooo`;o00003_ooool2o`0004;ooooo000Looooo`03o`000?oooooooooo02go
oooo0_l0000=ooooo`;o00000oooool2o`0000Oooooo0_l00005ooooo`Co00001oooool2o`0000;o
oooo0_l00004ooooo`Co000000?oooooo`000?l000001ol000001?oooooo0000o`000?ooool2o`00
0003ooooool0003o000000Wooooo0_l0000;ooooo`;o00001_ooool2o`0000Sooooo1?l0000@oooo
o`;o00001_oooolLo`000003ooooool0003o000000?o00002?ooool2o`0000?ooooo0_l0000Coooo
o`;o0000@_ooool001cooooo0_l0000Xooooo`;o00004Oooool2o`0000kooooo0_l00008ooooo`;o
00001_ooool3o`000003ooooool0003o000000Cooooo0ol00002ooooo`co00000oooool3o`0000Wo
oooo0_l00007ooooo`;o00001?ooool2o`0000Cooooo0_l0000>ooooo`;o00002?ooool2o`0000[o
oooo8Ol0000>ooooo`;o00004Oooool4o`0004;ooooo000Looooo`03o`000?oooooooooo02Oooooo
0_l0000Aooooo`;o00003Oooool2o`0000Wooooo0_l00007ooooo`;o00002Oooool2o`000003oooo
ool0003o000000Go000000?oooooo`000?l000001Oooool3o`0001;ooooo0_l00004ooooo`;o0000
5?ooool2o`0000Sooooo1_l00006ooooo`Oo000000?oooooo`000?l000002?l000000ooooooo0000
o`00000;o`0000Wooooo0_l0000Fooooo`Oo0000@?ooool001cooooo00?o0000ooooooooool0;_oo
ool2o`000003ooooool0003o000000?ooooo0_l00005ooooo`;o00002_ooool4o`00013ooooo0_l0
0006oooooa7o00000oooool2o`0000Gooooo0_l00004ooooo`;o00001Oooool2o`0000Wooooo0_l0
0007ooooo`;o00004?ooool<o`0000Cooooo2_l000000ooooooo0000o`00000>o`0000cooooo0_l0
000Fooooo`;o000000?oooooo`000?l000000_l00008ooooo`;o0000=_ooool001cooooo00?o0000
ooooooooool0;_ooool2o`000003ooooool0003o000000?ooooo0_l00005ooooo`;o00003?ooool2
o`0000Oooooo0ol00006ooooo`;o00001Oooool9o`000003ooooool0003o000000Oo000000Gooooo
o`000?l0003o0000ooooo`03o`000003ooooool0003o000000;ooooo1?l00005ooooo`;o00001Ooo
ool2o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l000004?ooool2o`000004ooooool0
003o0000o`0000;ooooo1Ol000000ooooooo0000o`00000Go`0000?ooooo0_l00005ooooo`;o0000
4Oooool2o`0000Wooooo0_l00003ooooo`;o00002?ooool2o`0003Kooooo000Looooo`03o`000?oo
oooooooo02_ooooo0_l00006ooooo`;o00001_ooool2o`0001Oooooo0ol0000<ooooo`?o000000?o
ooooo`000?l000005_l00005ooooo`;o00003_ooool2o`0000Sooooo0_l0000:ooooo`;o00002_oo
ool4o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`Ko000000?oooooo`000?l000002Ol0
0006ooooo`;o000000?oooooo`000?l000000_ooool2o`00017ooooo0_l0000;ooooo`;o000000?o
ooooo`000?l000001_ooool4o`0003Kooooo000Looooo`03o`000?oooooooooo02_ooooo0_l00006
ooooo`?o000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l0000Gooooo`;o00000oooool2
o`0000;ooooo0_l00002oooooa?o000000?oooooo`000?l000000oooool2o`0000cooooo0_l0000;
ooooo`Co00001oooool2o`000004ooooool0003o0000o`0000cooooo0_l0000?ooooo`;o000000?o
ooooo`000?l000002?l0000:ooooo`;o00003Oooool3o`0001;ooooo0_l00009ooooo`Co0000=_oo
ool001cooooo00?o0000ooooooooool0=?ooool6o`0000Oooooo0_l0000Gooooo`;o00000oooool2
o`000003ooooool0003o000001Oo00000_ooool5o`0000cooooo0_l00008ooooo`;o000000?ooooo
o`000?l000000_l00002ooooo`;o00000oooool8o`0000[ooooo1?l0000=ooooo`;o00002Oooool2
o`0000[ooooo0_l00002ooooo`;o00002Oooool3o`0000Wooooo0_l00002ooooo`;o0000B?ooool0
01cooooo00?o0000ooooooooool0<oooool4o`000003ooooool0003o000002Oooooo6ol000000ooo
oooo0000o`000002o`0000_ooooo0_l0000:ooooo`;o00001oooool2o`0000;ooooo2Ol0000;oooo
o`?o00003oooool2o`0001?ooooo1_l0000Dooooo`Oo00003?ooool2o`0000oooooo0_l0000Yoooo
o`007?ooool00ol0003oooooooooo`0cooooo`?o00000_ooool2o`0000Kooooo0_l00004ooooo`;o
00004oooool2o`0000Cooooo6ol00006ooooo`;o00002?ooool2o`0000_ooooo0_l000000ooooooo
0000o`000003ooooo`;o00000_ooool4o`0000gooooo0_l0000?ooooo`;o00000_ooool4o`0001?o
oooo0_l0000Fooooo`;o000000?oooooo`000?l000003_ooool4o`0000Gooooo0_l00006ooooo`;o
0000:Oooool001cooooo00?o0000ooooooooool0=?ooool2o`0000;ooooo0_l00005ooooo`?o0000
00Coooooo`000?l0003ooooo0ol000000ooooooo0000o`000009ooooo`;o00001?ooool2o`0000Co
oooo7_l00003ooooo`;o000000?oooooo`000?l000000oooool2o`0000;ooooo0_l00009ooooo`;o
000000?oooooo`000?l000000oooool2o`0000Cooooo0_l0000=ooooo`;o00001oooool2o`000004
ooooool0003o0000o`0000;ooooo0_l00002ooooo`Co00003?ooool2o`0000[ooooo0_l0000@oooo
o`Co00001oooool2o`0000Wooooo0_l00005ooooo`;o0000<Oooool001cooooo00?o0000oooooooo
ool0?oooool2o`0000;ooooo0_l000001Ooooooo0000o`000?l0003ooooo00Co00001oooool2o`00
00[ooooo7_l00006ooooo`;o00000oooool2o`0000;ooooo1?l00009ooooo`;o00001oooool2o`00
01Wooooo0_l000001?oooooo0000o`000?l00006ooooo`;o00000oooool2o`0000Wooooo0ol00005
ooooo`Ko00004?ooool4o`0000Oooooo0_l0000=ooooo`;o0000=?ooool001cooooo00?o0000oooo
ooooool0A_ooool2o`0000Cooooo1?l0000AoooooaCo000000?oooooo`000?l000001_l00002oooo
o`;o00000oooool2o`0000Wooooo0_l00009ooooo`;o00001oooool2o`0001cooooo0_l0000<oooo
o`;o00002_ooool2o`0000Gooooo1?l00007ooooo`;o00002Oooool2o`0000Gooooo0_l00002oooo
o`;o00003?ooool3o`0003Cooooo000Looooo`03o`000?oooooooooo03Gooooo0ol0000Booooo`;o
000000Coooooo`000?l0003o00002_ooool2o`0000Cooooo4_l000000ooooooo0000o`00000=o`00
00;ooooo0ol0000Eooooo`;o00000_ooool2o`0000;ooooo0_l00008ooooo`;o00002_ooool2o`00
00;ooooo0_l00002ooooo`?o00006?ooool2o`0000Kooooo0_l00006ooooo`?o00002oooool2o`00
0003ooooool0003o000000;o00000_ooool2o`0000cooooo0_l0000eooooo`007?ooool00ol0003o
ooooooooo`0eooooo`?o00003_ooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`00
00Sooooo0_l00004ooooob3o00000oooool3o`0000kooooo0_l00005ooooo`?o00000_ooool2o`00
00?ooooo0_l00007ooooo`;o00002_ooool2o`0000;ooooo0_l00003ooooo`;o00002?ooool2o`00
00kooooo0_l00006ooooo`;o00001_ooool2o`0000cooooo0_l000000ooooooo0000o`000019oooo
o`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0>_ooool2o`0000[ooooo0_l00006ooooo`Co00000_oo
ool2o`0000Sooooo8_l00003ooooo`;o00003?ooool2o`000003ooooool0003o000000;ooooo0_l0
00001?oooooo0000o`000?l00007ooooo`;o00008Oooool2o`0000?ooooo0_l0000>ooooo`;o0000
3Oooool2o`0000[ooooo0_l00004ooooo`;o00002oooool2o`0000?ooooo0_l0000gooooo`0000Ko
ooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q
00Kooooo00?o0000ooooooooool0>_ooool2o`000003ooooool0003o000000oooooo0_l00004oooo
o`;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000>o`0000;ooooo3_l0000@oooo
o`;o00000oooool4o`0001gooooo0_l0000;ooooo`?o000000?oooooo`000?l000002?ooool2o`00
01?ooooo0_l00003ooooo`;o00001Oooool2o`0000?ooooo0_l0000Aooooo`;o00000oooool2o`00
03Oooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo03gooooo0_l00004ooooo`;o00005Oooool2o`00
00;ooooo4_l000000ooooooo0000o`00000;o`000003ooooool0003o000001Gooooo1_l0000?oooo
o`;o00002_ooool2o`0000Cooooo0ol00004ooooo`Co00002_ooool4o`0000Gooooo0_l0000:oooo
o`;o00002_ooool2o`0005Cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wo
oooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000?Oooool2o`0000Cooooo0_l0000Koooo
oaKo000000?oooooo`000?l000000ol000000ooooooo0000o`000003ooooo`;o000000Coooooo`00
0?l0003o00002?ooool5o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000Gooooo0_l0
0005ooooo`;o00003_ooool5o`0000?ooooo1Ol00004ooooo`;o00001?ooool4o`0000Gooooo0_l0
000fooooo`;o0000=?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool0
1Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0>_ooool2o`0001Cooooo0_l0
0006ooooo`;o00001_ooool6o`000003ooooool0003o000001;o00000_ooool3o`000005ooooool0
003o0000o`000?ooool00ol00008ooooo`Go00000_ooool2o`0000Cooooo0_l000000ooooooo0000
o`000002ooooo`;o00002?ooool3o`0000Cooooo0_l00004ooooo`;o00001?ooool4o`0000Kooooo
0ol0000Iooooo`?o0000:Oooool2o`0003Cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oo
oooooooo00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`0jooooo`Ko00000_oo
ool2o`0000cooooo0_l00006ooooo`;o00001_oooolPo`000003ooooool0003o000000?ooooo0_l0
00000ooooooo0000o`000002ooooo`;o00002?ooool2o`0000Oooooo0_l00008ooooo`So00000ooo
ool2o`000003ooooool0003o000000Oooooo0_l00008ooooo`;o00001_ooool2o`000003ooooool0
003o000000;o00003Oooool3o`0000?ooooo1?l0000Looooo`;o0000>_ooool00006oooooomgMgOo
V9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo03cooooo
1?l00002ooooo`?o00006ooooolTo`0000Gooooo0_l00002ooooo`;o00002?ooool2o`0000Cooooo
0_l0000;ooooo`_o00000oooool2o`00017ooooo0_l00006ooooo`;o000000?oooooo`000?l00000
0_l000000ooooooo0000o`00000@ooooo`Co00001Oooool2o`0000Cooooo0_l0000?ooooo`;o0000
>_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106oooo
o`03o`000?oooooooooo03[ooooo1?l00003ooooo`Co00001?ooool2o`0000Kooooo0_l00009oooo
o`;o00000_oooolOo`000003ooooool0003o000000;o00003Oooool2o`0000[ooooo0ol00007oooo
o`;o000000Coooooo`000?l0003ooooo2?l0000=ooooo`;o000000?oooooo`000?l000005?ooool2
o`0001Wooooo0_l00004ooooo`;o00002Oooool2o`00043ooooo000Looooo`03o`000?oooooooooo
03;ooooo0_l00006ooooo`;o00001Oooool2o`0000Kooooo1?l00003ooooo`?o000000?oooooo`00
0?l000001_ooool6o`0000;ooooo6?l000000ooooooo0000o`000003o`0000oooooo0_l00006oooo
o`;o00000oooool2o`0000;ooooo0_l00003ooooo`ko00001?ooool2o`0000Oooooo0_l000000ooo
oooo0000o`000008ooooo`;o0000:oooool2o`0000Wooooo0_l00010ooooo`007?ooool00ol0003o
ooooooooo`0booooo`;o000000?oooooo`000?l000005?ooool2o`0000?ooooo0ol000000ooooooo
0000o`000002ooooo`;o00000ooooolNo`0000Cooooo0_l0000Aooooo`;o00000_ooool2o`000004
ooooool0003o0000o`0000?ooooo0_l000000ooooooo0000o`00000Ao`0000Cooooo0ol00003oooo
o`;o000000Coooooo`000?l0003o00001oooool5o`000003ooooool0003o000000;o00003?ooool3
o`0000;ooooo0_l00006ooooo`;o00001_ooool2o`00053ooooo000Looooo`03o`000?oooooooooo
03Gooooo0_l00007ooooo`Co00001?ooool2o`0000Wooooo0_l00005ooooo`;o00001?ooool2o`00
00;ooooo6Ol000000ooooooo0000o`00000Dooooo`;o00000_ooool2o`0000;ooooo0_l00003oooo
o`;o00000_oooolEo`000004ooooool0003o0000o`0000?ooooo0_l000001?oooooo0000o`000?l0
0007ooooo`?o00000oooool4o`0000cooooo0ol00002ooooo`;o00001_ooool2o`0000Kooooo0ol0
00000ooooooo0000o`00001<ooooo`007?ooool00ol0003oooooooooo`0nooooo`Co00001?ooool2
o`0000;ooooo0ol0000?ooooo`Ko000000?oooooo`000?l000005?l000000ooooooo0000o`000002
o`0001Sooooo0_l000000ooooooo0000o`000008ooooo`Wo000000?oooooo`000?l000002Ol00007
ooooo`Co0000=?ooool3o`000004ooooool0003o0000o`0000gooooo0_l0000looooo`007?ooool0
0ol0003oooooooooo`1:ooooo`?o00002_ooool2o`000003ooooool0003o000000?o000000Cooooo
o`000?l0003ooooo3?l000000ooooooo0000o`000007o`000004ooooool0003o0000o`0000;ooooo
0_l00004ooooo`;o00004_ooool2o`000003ooooool0003o000000?ooooo6?l00007ooooo`?o0000
3oooool2o`0000Sooooo0_l000000ooooooo0000o`000004ooooo`;o00001oooool4o`0000Gooooo
0_l00003ooooo`;o00001Oooool2o`0000Cooooo1?l0000looooo`007?ooool00ol0003ooooooooo
o`0looooo`;o00001Oooool2o`0000Sooooo0_l00008ooooo`;o000000?oooooo`000?l000000ol0
0004ooooo`?o000000?oooooo`000?l000001Ol000000ooooooo0000o`000004o`0000;ooooo0_l0
0002ooooo`Ko00001?ooool4o`0001?ooooo0_l00002oooooaWo00001oooool2o`0000kooooo1?l0
0006ooooo`Co000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000Cooooo1?l0
0003ooooo`;o00002?ooool2o`0000;ooooo0_l00004ooooo`;o0000?_ooool001cooooo00?o0000
ooooooooool0>?ooool2o`0000;ooooo0ol00004ooooo`;o00002?ooool2o`0000cooooo0ol00002
ooooo`;o000000?oooooo`000?l000000oooool5o`0000;ooooo1_l00008ooooo`;o00002?ooool4
o`0001Gooooo6ol00006ooooo`;o00003Oooool2o`0000Gooooo0_l000000ooooooo0000o`000009
ooooo`Go00002oooool2o`000003ooooool0003o000000Gooooo0_l00018ooooo`007?ooool00ol0
003oooooooooo`0hooooo`;o00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`00
00oooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000000?ooooo3Ol0000Doooo
o`;o00005?oooolLo`0000Gooooo0ol00009ooooo`;o00002Oooool2o`000003ooooool0003o0000
00;ooooo0_l00006ooooo`Co00001Oooool2o`0000Kooooo0ol0000>ooooo`;o0000?oooool001co
oooo00?o0000ooooooooool0@Oooool2o`000003ooooool0003o000000;o00003oooool2o`0000oo
oooo0ol000001?oooooo0000o`000?l0000Gooooo`;o00000oooool2o`0001;ooooo7?l00005oooo
o`;o00002_ooool5o`0000Kooooo0_l00005ooooo`;o00001oooool3o`0000Gooooo0_l00003oooo
o`;o000000?oooooo`000?l000000_ooool2o`0000_ooooo0_l0000oooooo`007?ooool00ol0003o
ooooooooo`0looooo`;o00001Oooool3o`0000Wooooo0_l00002ooooo`;o00000_ooool4o`00017o
oooo1?l00005ooooo`;o00003oooool2o`0000;ooooo0ol00005ooooo`;o00003?ooool<o`000003
ooooool0003o000000co00004oooool3o`0000Wooooo0_l0000;ooooo`?o00001Oooool2o`0000?o
oooo0_l00003ooooo`Co0000C?ooool001cooooo00?o0000ooooooooool0??ooool2o`0000Gooooo
1?l000000ooooooo0000o`000005ooooo`;o00000_ooool2o`0000;ooooo1?l0000@ooooo`So0000
0_ooool2o`0000oooooo0_l00002ooooo`;o00001_ooool3o`0000Wooooo6ol0000Iooooo`;o0000
1_ooool2o`0000_ooooo1?l00006ooooo`;o00001_ooool2o`0000?ooooo0_l00008ooooo`;o0000
?oooool001cooooo0_l00014ooooo`Co000000?oooooo`000?l000003Oooool2o`0001;ooooo0_l0
0002ooooo`So00003oooool2o`0000_ooooo0_l00003ooooo`;o00001?oooolKo`000003ooooool0
003o000001Kooooo0_l00003ooooo`;o00000_ooool2o`0000Sooooo0_l00002ooooo`;o00001_oo
ool2o`0000Cooooo0_l00005ooooo`;o00002?ooool2o`0003oooooo000Looooo`03o`000?oooooo
oooo043ooooo0_l00003ooooo`?o00003Oooool4o`00017ooooo1_l000000ooooooo0000o`000006
o`0000Oooooo0_l000000ooooooo0000o`000003o`0000;ooooo0_l0000<ooooo`;o000000?ooooo
o`000?l000006ol00002ooooo`;o00000_ooool2o`0001Oooooo0_l00002ooooo`;o00002?ooool2
o`000003ooooool0003o000000Sooooo0_l00003ooooo`;o0000D?ooool001cooooo00?o0000oooo
ooooool0@?ooool3o`0000;ooooo0ol00002ooooo`;o00002Oooool2o`0000Sooooo0_l00009oooo
o`Ko000000?oooooo`000?l000000_ooool6o`0000Gooooo0_l000001?oooooo0000o`000?l00004
ooooo`?o00001?ooool2o`000003ooooool0003o000000Gooooo8?l00003ooooo`;o00006oooool2
o`0000Wooooo1?l00008ooooo`?o0000E?ooool001cooooo00?o0000ooooooooool0@Oooool2o`00
00?ooooo0_l00002ooooo`;o00000_ooool2o`0000oooooo0_l00002ooooo`;o00001_ooool2o`00
00Cooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo0_l0000<ooooo`;o00001?ooool2o`00
0003ooooool0003o000000Kooooo0_l000000ooooooo0000o`00000Jo`0000Gooooo0_l00002oooo
o`;o00004oooool4o`000003ooooool0003o000000Kooooo0_l0000:ooooo`Go00002oooool2o`00
0003ooooool0003o000004;ooooo000Looooo`03o`000?oooooooooo03gooooo0_l0000;ooooo`;o
00000_ooool3o`0000gooooo0_l00003ooooo`;o00002_ooool2o`0000cooooo1?l00004ooooo`;o
00004_ooool2o`0000Cooooo7?l00003ooooo`Co00000_ooool2o`0001?ooooo0_l00003ooooo`Go
00004_ooool2o`0000_ooooo0_l000000ooooooo0000o`000012ooooo`007?ooool00ol0003ooooo
ooooo`0mooooo`;o00002_ooool2o`0000Cooooo0ol00009ooooo`;o000000?oooooo`000?l00000
3oooool2o`0000kooooo0_l00004ooooo`;o00002Oooool5o`0000Cooooo0_l00005ooooo`Ko0000
00?oooooo`000?l000004_l00002ooooo`?o00008?ooool3o`0006Kooooo000Looooo`03o`000?oo
oooooooo04Gooooo0_l00002ooooo`;o00001Oooool2o`0000Wooooo0_l00007ooooo`Co00001?oo
ool2o`0000Sooooo0_l00007ooooo`;o00001oooool2o`0000?ooooo0_l000000ooooooo0000o`00
0004o`0000?ooooo0_l00004ooooo`Ko00000_oooolDo`0000;ooooo0_l0000Nooooo`;o00004Ooo
ool2o`000003ooooool0003o000000gooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`15
ooooo`;o00002?ooool2o`0001?ooooo1?l00004ooooo`;o00002?ooool2o`0000Oooooo0_l00007
ooooo`;o00000oooool4o`0000?ooooo0_l00002ooooo`;o00000oooool9o`000003ooooool0003o
000000ko000000?oooooo`000?l000005_ooool2o`0000_ooooo0_l00006ooooo`;o00002?ooool3
o`000003ooooool0003o000000gooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`1?oooo
o`;o00002oooool2o`0001Oooooo0_l0000Eooooo`Go00001oooool2o`0000?ooooo0_l00002oooo
oaGo000000Goooooo`000?l0003o0000ooooo`02o`0000?ooooo0_l0000;ooooo`;o000000?ooooo
o`000?l000004_ooool3o`0000Sooooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`1:oooo
o`Co00002Oooool2o`0000?ooooo0_l00005ooooo`?o00001_ooool4o`0000Gooooo0_l00006oooo
o`;o00003Oooool3o`0001?ooooo4ol000000ooooooo0000o`000002o`000003ooooool0003o0000
00?ooooo0_l00003ooooo`;o00001_ooool2o`0001Gooooo0ol0001Rooooo`007?ooool00ol0003o
ooooooooo`18ooooo`Ko00001Oooool2o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o
00000_ooool3o`0000;ooooo0_l00002ooooo`Co00001_ooool2o`0000Gooooo0_l00002ooooo`?o
00001?ooool2o`0000?ooooo0_l0000=ooooo`;o00001OoooolBo`000003ooooool0003o000000So
oooo0_l00003ooooo`;o00006Oooool2o`0000;ooooo0_l0001Sooooo`007?ooool00ol0003ooooo
ooooo`18ooooo`Co00001oooool2o`0000Gooooo0_l00003ooooo`;o000000Coooooo`000?l0003o
00000oooool2o`0000Gooooo0_l00003ooooo`Co00000_ooool2o`000003ooooool0003o000000;o
oooo0ol00004ooooo`;o00004_ooool2o`000003ooooool0003o000000Gooooo0_l00002ooooo`?o
000000?oooooo`000?l000001Ol0000=ooooo`?o00001_ooool2o`000003ooooool0003o000000_o
oooo0_l00003ooooo`Co00001Oooool2o`0000;ooooo0_l000001?oooooo0000o`000?l0000:oooo
o`;o0000B_ooool001cooooo00?o0000ooooooooool0Doooool2o`0000;ooooo0_l00008ooooo`?o
00001oooool2o`000004ooooool0003o0000o`0000;ooooo0ol00004ooooo`Go00002Oooool3o`00
00Gooooo0_l0000=ooooo`;o00001Oooool2o`000003ooooool0003o000000?o000000?oooooo`00
0?l000000oooool2o`0000Wooooo0_l000001?oooooo0000o`000?l00004ooooo`Co000000?ooooo
o`000?l000001?ooool2o`0000Gooooo0_l00003ooooo`Co000000?oooooo`000?l000000_ooool2
o`0000;ooooo0_l000001?oooooo0000o`000?l0000:ooooo`;o0000B_ooool001cooooo00?o0000
ooooooooool0@?ooool2o`00017ooooo0_l00002ooooo`;o00001?ooool2o`0000;ooooo0_l00002
ooooo`;o00001?ooool2o`000003ooooool0003o000000?ooooo0_l00007ooooo`;o00002_ooool7
o`000003ooooool0003o000000Kooooo0_l0000?ooooo`;o000000Coooooo`000?l0003ooooo0_l0
0003ooooo`?o00001_ooool4o`0000;ooooo1?l00002ooooo`;o00001?ooool2o`0000?ooooo1?l0
0008ooooo`Co000000?oooooo`000?l000002Oooool2o`0005Oooooo000Looooo`03o`000?oooooo
oooo043ooooo0_l0000:ooooo`;o00002Oooool2o`0000Cooooo0_l00006ooooo`;o000000?ooooo
o`000?l000001?ooool3o`0000?ooooo0_l0000Eooooo`Co00002?ooool3o`0000Oooooo0_l0000?
ooooo`;o000000?oooooo`000?l000001Oooool3o`0000Cooooo1?l00008ooooo`;o00001Oooool2
o`0000?ooooo0_l0000>ooooo`;o0000G?ooool001cooooo00?o0000ooooooooool0C?ooool2o`00
00cooooo0_l0000<ooooo`;o00001?ooool3o`0000?ooooo0ol000000ooooooo0000o`00000Moooo
o`;o00000_ooool2o`0000Cooooo0_l0000>ooooo`?o00002?ooool2o`000003ooooool0003o0000
00Go000000?oooooo`000?l000000oooool2o`0000_ooooo1?l00004ooooo`;o00001oooool3o`00
00Cooooo0_l0000Cooooo`;o0000@Oooool001cooooo0_l0001>ooooo`;o00000oooool3o`0000Go
oooo0_l0000Dooooo`;o00000oooool2o`000003ooooool0003o000000Wooooo0_l0000Fooooo`Co
00001?ooool2o`0000cooooo0_l0000<ooooo`Oo000000?oooooo`000?l000000oooool2o`0000So
oooo0_l000000ooooooo0000o`000004ooooo`Co00001oooool2o`0000Gooooo0_l0000Cooooo`;o
0000@Oooool001cooooo00?o0000ooooooooool0COooool2o`0000?ooooo0ol00008ooooo`;o0000
3Oooool2o`0000;ooooo0_l00008ooooo`;o00000oooool2o`0000;ooooo0_l0000Hooooo`;o0000
1?ooool4o`0000_ooooo0_l0000=ooooo`?o000000?oooooo`000?l000000oooool3o`0000Wooooo
0_l00002ooooo`;o000000?oooooo`000?l000001Ol0001Uooooo`007?ooool00ol0003ooooooooo
o`1<ooooo`;o00001?ooool2o`0000Wooooo0_l0000=ooooo`;o00003?ooool2o`0000;ooooo0ol0
000Tooooo`;o00002oooool2o`00017ooooo0_l00003ooooo`Go00002oooool2o`000004ooooool0
003o0000ooooo`Co0000IOooool001cooooo00?o0000ooooooooool0C?ooool2o`0001oooooo0_l0
0003ooooo`;o00001oooool5o`0000Cooooo0_l0000@ooooo`;o00003?ooool2o`0000Gooooo0_l0
0002ooooo`;o00001Oooool2o`0000[ooooo0_l00006ooooo`Go00008oooool4o`0005?ooooo000L
ooooo`03o`000?oooooooooo04gooooo0_l00003ooooo`;o00001?ooool2o`0000Wooooo0_l00008
ooooo`;o00000oooool2o`0000Oooooo1Ol00002ooooo`Ko00003_ooool2o`0000cooooo1?l00003
ooooo`;o00000_ooool2o`0000Gooooo0_l0000:ooooo`;o00001Oooool6o`0000[ooooo0_l0000G
ooooo`Co0000Doooool001cooooo00?o0000ooooooooool0AOooool2o`0000Kooooo0ol00002oooo
o`;o00001?ooool2o`0000Wooooo0_l00006ooooo`?o000000?oooooo`000?l000002oooool4o`00
00;ooooo0_l00002ooooo`;o00007_ooool2o`0001_ooooo0_l000000ooooooo0000o`000007o`00
00Oooooo0_l000000ooooooo0000o`000005ooooo`;o00001Oooool2o`0001Sooooo0_l00016oooo
o`007?ooool00ol0003oooooooooo`15ooooo`;o00001_ooool4o`0000Sooooo0_l0000@ooooo`?o
000000Coooooo`000?l0003o00002_ooool4o`0001?ooooo0_l0000Dooooo`Co00001_ooool2o`00
00_ooooo1Ol000000ooooooo0000o`000004o`000003ooooool0003o000000Oooooo0_l00008oooo
o`;o00001Oooool2o`0000kooooo0_l00008ooooo`;o0000A_ooool001cooooo00?o0000oooooooo
ool0@_ooool2o`0000_ooooo0ol00007ooooo`;o00003_ooool3o`0000Cooooo1?l00008ooooo`Co
00004oooool2o`0000[ooooo0_l00003ooooo`;o00000oooool4o`0000Kooooo0_l00007ooooo`;o
000000?oooooo`000?l000001Ol00004ooooo`[o00002Oooool5o`0000oooooo0_l000001?oooooo
0000o`000?ooool2o`00053ooooo000Looooo`03o`000?oooooooooo04;ooooo0_l0000<ooooo`;o
00002Oooool2o`0000cooooo1?l00005ooooo`;o00001_ooool6o`00017ooooo1?l00006ooooo`;o
00000_ooool4o`000003ooooool0003o000000;o00000oooool7o`0000[ooooo0_l000000ooooooo
0000o`000005o`0000Gooooo0_l000000ooooooo0000o`000004o`0000Wooooo0ol0000Aooooo`;o
000000?oooooo`000?l00000Doooool001cooooo00?o0000ooooooooool0DOooool2o`0000Gooooo
0_l000000ooooooo0000o`000008ooooo`;o00001?ooool2o`000003ooooool0003o000000;ooooo
0_l00006ooooo`;o00005Oooool2o`0000;ooooo0_l00004ooooo`;o00001?ooool2o`0000?ooooo
0_l00002ooooo`So000000?oooooo`000?l000000_l000001?oooooo0000o`000?ooool=o`000003
ooooool0003o000000Cooooo0_l0000=ooooo`;o00000oooool2o`000003ooooool0003o000000;o
oooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o00001Oooool3o`0000[ooooo
0_l00007ooooo`;o00000_ooool2o`0000Gooooo0_l0000Jooooo`;o00004Oooool5o`0000Kooooo
1?l000000ooooooo0000o`000006o`0000Gooooo0ol000000ooooooo0000o`000003ooooo`?o0000
1?ooool2o`0000_ooooo0ol000000ooooooo0000o`000002ooooo`;o00003oooool2o`0004cooooo
000Looooo`03o`000?oooooooooo05Wooooo0_l000000ooooooo0000o`000003ooooo`Co00003Ooo
ool2o`0000Gooooo0_l00007ooooo`;o000000?oooooo`000?l000005oooool2o`0000Cooooo0_l0
0002ooooo`;o00004?ooool2o`0000cooooo0_l00003ooooo`?o00001Oooool2o`0000_ooooo0_l0
000Gooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0E?ooool2o`0000?ooooo0_l00000
0ooooooo0000o`000003ooooo`Co00004Oooool2o`0000Sooooo1?l000000ooooooo0000o`00000G
ooooo`;o00001?ooool2o`0000?ooooo1?l00005ooooo`;o00005?ooool2o`0000?ooooo0_l00003
ooooo`;o0000MOooool001cooooo00?o0000ooooooooool0D_ooool4o`0000Cooooo1?l0000Hoooo
o`;o00001Oooool2o`000003ooooool0003o000000Gooooo0_l00005ooooo`;o000000?oooooo`00
0?l000001Oooool2o`0000oooooo1?l00005ooooo`;o00000_ooool2o`000003ooooool0003o0000
00Cooooo0_l00008ooooo`;o00000_ooool2o`0000?ooooo1?l0001cooooo`007?ooool00ol0003o
ooooooooo`1Booooo`;o000000?oooooo`000?l000000oooool4o`0001cooooo0_l000000ooooooo
0000o`000008ooooo`;o00000oooool4o`000004ooooool0003o0000o`0000Cooooo0_l00009oooo
o`Co00003oooool2o`000003ooooool0003o000000Cooooo0_l00008ooooo`;o00001oooool4o`00
0003ooooool0003o000000?ooooo0_l0001[ooooo`007?ooool00ol0003oooooooooo`1Cooooo`Co
000000?oooooo`000?l000008?ooool2o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`?o
00000_ooool2o`0000?ooooo0ol00004ooooo`;o00001_ooool2o`000003ooooool0003o000000;o
00002?ooool2o`0000Gooooo0_l00007ooooo`?o00001oooool2o`0000?ooooo0_l00002ooooo`;o
00000oooool2o`0000?ooooo0_l0001[ooooo`007?ooool2o`0005Cooooo0_l00002ooooo`?o0000
8?ooool2o`0000Cooooo1Ol000000ooooooo0000o`000004o`000003ooooool0003o000000Cooooo
0_l0000;ooooo`;o00000oooool2o`0000Sooooo0_l00002ooooo`;o000000?oooooo`000?l00000
1oooool3o`0000Oooooo0_l00003ooooo`;o000000?oooooo`000?l000001?ooool2o`00073ooooo
000Looooo`03o`000?oooooooooo05Oooooo0ol000000ooooooo0000o`000003ooooo`;o00004?oo
ool2o`0000Kooooo1?l00004ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`00
0004ooooo`;o00004?ooool2o`0000Cooooo0_l00004ooooo`Co00001oooool2o`0001?ooooo0ol0
0003ooooo`;o00002_ooool2o`0006Cooooo000Looooo`03o`000?oooooooooo05Sooooo1Ol00003
ooooo`?o00003oooool2o`0000?ooooo0_l00003ooooo`;o00008_ooool2o`0000Wooooo0_l00000
1?oooooo0000o`000?ooool2o`0000Wooooo0_l0000Dooooo`Co00001Oooool2o`0000Kooooo0_l0
001Tooooo`007?ooool00ol0003oooooooooo`1Iooooo`Co00000_ooool4o`0000kooooo0_l00004
ooooo`;o00001Oooool4o`0000Kooooo0_l00005ooooo`;o000000Coooooo`000?l0003ooooo0_l0
0009ooooo`;o00003?ooool2o`000003ooooool0003o000000Wooooo0_l00009ooooo`;o00002ooo
ool2o`0000Gooooo0_l00002ooooo`;o00001Oooool2o`00067ooooo000Looooo`03o`000?oooooo
oooo05oooooo0_l00007ooooo`;o00001oooool2o`0000_ooooo1?l00006ooooo`;o00001Oooool2
o`000004ooooool0003o0000ooooo`?o00005_ooool2o`000003ooooool0003o000000Wooooo0_l0
0003ooooo`Co00000_ooool2o`0000?ooooo0_l0000:ooooo`;o00001Oooool2o`0000Gooooo0_l0
001Qooooo`007?ooool00ol0003oooooooooo`1Fooooo`;o00000_ooool2o`0000Oooooo0_l00003
ooooo`;o00003_ooool2o`0000;ooooo0ol0000=ooooo`;o00002?ooool2o`0001Kooooo0_l0000A
ooooo`Co00001oooool2o`0000[ooooo0_l000000ooooooo0000o`00001/ooooo`007?ooool00ol0
003oooooooooo`1Dooooo`Co00000_ooool2o`000003ooooool0003o000000;o00000_ooool2o`00
01?ooooo0_l00002ooooo`Go00002Oooool4o`0000Kooooo0_l00007ooooo`;o00001_ooool2o`00
00Gooooo0_l0000Dooooo`;o00004_ooool4o`000003ooooool0003o000006cooooo000Looooo`03
o`000?oooooooooo05Cooooo0_l00002ooooo`Co000000?oooooo`000?l000000_l0000:ooooo`;o
00004?ooool4o`0000Gooooo0_l00002ooooo`;o00001_ooool5o`0000Kooooo0_l00006ooooo`;o
00001Oooool2o`0001Cooooo0_l0000Booooo`Co0000Koooool001cooooo00?o0000ooooooooool0
F?ooool4o`0000?ooooo0_l0000:ooooo`;o00003Oooool5o`0000Kooooo0ol00008ooooo`Co0000
00?oooooo`000?l000005?ooool2o`0000Cooooo0_l0000<ooooo`;o000000?oooooo`000?l00000
2Oooool2o`0000_ooooo1?l0001[ooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o00001?oo
ool4o`0001Kooooo1?l00008ooooo`;o00002Oooool2o`0000?ooooo0_l0000Dooooo`;o00001?oo
ool2o`0000cooooo0_l0000<ooooo`;o00002oooool4o`0006_ooooo000Looooo`03o`000?oooooo
oooo05Wooooo0_l00006ooooo`;o00005_ooool2o`000003ooooool0003o000001Cooooo0_l00000
0ooooooo0000o`00000@ooooo`?o000000?oooooo`000?l000002oooool3o`0008kooooo000Loooo
o`03o`000?oooooooooo06Sooooo0_l0000Booooo`;o00005?ooool2o`0000oooooo0_l00002oooo
o`?o000000?oooooo`000?l000001oooool2o`0000;ooooo0ol00002ooooo`Ko00002Oooool2o`00
07_ooooo000Looooo`03o`000?oooooooooo05Wooooo0_l00002ooooo`;o00002Oooool2o`0001;o
oooo0_l00008ooooo`;o00001oooool2o`0001;ooooo0_l0000?ooooo`Go00001?ooool6o`0000Wo
oooo0_l0001kooooo`007?ooool00ol0003oooooooooo`1Gooooo`Co00000_ooool2o`000003oooo
ool0003o000000[ooooo0ol0000Eooooo`Co00001oooool2o`0000Wooooo0_l00007ooooo`?o0000
1?ooool2o`000003ooooool0003o000000;o00001?ooool4o`00093ooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0
003oooooooooo`1Gooooo`;o00001oooool2o`0000[ooooo1_l000000ooooooo0000o`000003oooo
o`;o00001?ooool3o`0000?ooooo0_l000000ooooooo0000o`000008ooooo`;o00001oooool2o`00
0003ooooool0003o000000Gooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o
000000;o00003?ooool2o`0000Sooooo0_l0000<ooooo`;o000000?oooooo`000?l000003oooool2
o`0005kooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1Yooooo`;o00000oooool4o`000003oooo
ool0003o000000?ooooo0_l00004ooooo`?o00001_ooool2o`0000Sooooo0_l0000:ooooo`;o0000
2?ooool2o`0000Cooooo0_l00008ooooo`;o00001?ooool4o`0000Kooooo0ol00003ooooo`;o0000
0oooool2o`000004ooooool0003o0000ooooo`;o00003oooool2o`0005kooooo00000ooooooo410@
ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo06Kooooo0_l000000ooooooo0000o`000004ooooo`;o00003_ooool2o`000003
ooooool0003o000001oooooo0_l00008ooooo`;o00002?ooool2o`0000Kooooo0_l00006ooooo`?o
00000_ooool3o`0000?ooooo0_l0001eooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooo
ooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`0006Kooooo0ol00006ooooo`;o
00001Oooool3o`000003ooooool0003o000000;o000000Coooooo`000?l0003ooooo0_l00002oooo
o`Co00001oooool2o`00013ooooo0_l00008ooooo`;o00004oooool4o`000003ooooool0003o0000
00?ooooo0_l0001kooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05
olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`1Wooooo`?o00001Oooool2o`00
00Gooooo0ol000000ooooooo0000o`000002o`0000Sooooo1?l00007ooooo`;o000000?oooooo`00
0?l000000oooool3o`0000?ooooo0_l00005ooooo`;o00002?ooool2o`0000oooooo1ol0000Noooo
o`;o0000HOooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol@413o
^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0J?ooool2o`0000Gooooo0_l0000:oooo
o`?o00004oooool2o`000003ooooool0003o000000?ooooo0ol00003ooooo`;o00001Oooool2o`00
00Sooooo0_l00007ooooo`;o00001_ooool3o`0000;ooooo0_l0000Iooooo`;o00000oooool2o`00
067ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zjo`00
0006ooooo`03o`000?oooooooooo07_ooooo0ol00006ooooo`;o00002oooool2o`0002Kooooo0_l0
0007ooooo`;o00007Oooool2o`0006Kooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo
00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo077ooooo0_l0000?ooooo`Co
00003_ooool2o`0001cooooo0_l00006ooooo`;o00000oooool2o`000003ooooool0003o000008Go
oooo000Looooo`03o`000?oooooooooo077ooooo0_l0000?ooooo`;o00000_ooool4o`0000[ooooo
0_l0000Looooo`;o00001_ooool2o`0000?ooooo0_l00028ooooo`007?ooool00ol0003ooooooooo
o`1iooooo`;o00002oooool4o`0000Wooooo0_l0000:ooooo`;o000000?oooooo`000?l000001Ooo
ool2o`0000;ooooo0_l0002Jooooo`007?ooool00ol0003oooooooooo`1iooooo`?o00000oooool2
o`0000Oooooo0_l00009ooooo`;o000000?oooooo`000?l000001oooool2o`000003ooooool0003o
000000Gooooo0_l00002ooooo`;o000000?oooooo`000?l000002oooool3o`0008Wooooo000Loooo
o`03o`000?oooooooooo07[ooooo0_l00003ooooo`;o00002?ooool2o`0000Gooooo0_l00004oooo
o`;o00004Oooool2o`0000Gooooo0_l0000;ooooo`?o00005_ooool3o`00073ooooo000Looooo`03
o`000?oooooooooo08Cooooo0_l00003ooooo`;o00001Oooool2o`0001Kooooo0_l00006ooooo`;o
00009?ooool3o`00073ooooo000Looooo`03o`000?oooooooooo06[ooooo0_l0000Hooooo`;o0000
4?ooool2o`0000Oooooo0_l00007ooooo`;o00002oooool2o`0009;ooooo000Looooo`03o`000?oo
oooooooo06[ooooo0_l0000Zooooo`?o00001_ooool2o`000003ooooool0003o000000Wooooo0_l0
0006ooooo`;o00003oooool2o`0000Kooooo0_l0001iooooo`007?ooool00ol0003oooooooooo`21
ooooo`;o00005?ooool2o`0000Gooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo1Ol0000G
ooooo`;o00001_ooool2o`0007Wooooo000Looooo`03o`000?oooooooooo087ooooo0_l0000Boooo
o`;o00001oooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000001_l0000Roooo
o`;o0000Moooool001cooooo00?o0000ooooooooool0TOooool2o`000004ooooool0003o0000o`00
00[ooooo1?l000000ooooooo0000o`000002o`0001_ooooo0_l00009ooooo`;o0000Moooool001co
oooo00?o0000ooooooooool0TOooool6o`0000[ooooo0_l00007ooooo`;o00006Oooool2o`0008;o
oooo000Looooo`;o0000U?ooool4o`0000?ooooo0_l0000>ooooo`;o0000WOooool001cooooo00?o
0000ooooooooool0V_ooool2o`0002oooooo0_l0001looooo`007?ooool00ol0003oooooooooo`2M
ooooo`;o0000;?ooool2o`0007cooooo000Looooo`03o`000?oooooooooo09gooooo0_l0000[oooo
o`;o0000OOooool001cooooo00?o0000ooooooooool0b_ooool2o`0007gooooo000Looooo`03o`00
0?oooooooooo06gooooo0_l0003Jooooo`007?ooool00ol0003oooooooooo`1]ooooo`;o0000f_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`34oooo
o`;o0000Poooool001cooooo00?o0000ooooooooool0a?ooool4o`00087ooooo000Looooo`03o`00
0?oooooooooo0<Kooooo0_l00021ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`2Aooooo`;o0000]_ooool001cooooo00?o0000ooooooooool0
TOooool2o`000;Kooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0R?ooool2o`0002gooooo0_l0002@ooooo`007?ooool00ol0003oooooooooo`28ooooo`;o0000
;Oooool2o`00093ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2^ooooo`;o0000VOooool001co
oooo00?o0000ooooooooool0[_ooool2o`0009Wooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0WOooool2o`000:[ooooo000Looooo`03o`000?oooooo
oooo09gooooo0_l0002Zooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Booooo`Co000000?o
410@ooooooooool00oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05oooo
o`?o0000oooooom:ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`00
0?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool0
0ol0003oooooooooo`3ooooooe;ooooo000Booooo`03oeEEEOmVIVKo00000?ooooooE?ooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00:7ooooo00Co410@o`000?l0003ooooo0_l0
00000ol@413oooooooooo`0Fooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^
kP?ooooo00Co410@o`000?m4A4Coc<c<1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<08cooooo002R
ooooo`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?oV9RHoa0@4?oMgMd00oooool01OlQ8B7oV9RH
oooooonHV9So8B4Q08cooooo002Rooooo`05o`000?ooooooooooooooool000006oooool00ol0003o
ooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00on7QhOoEEEEooooo`02oooo
o`05o`000?ooooooooooooooool00000S?ooool00:;ooooo00Go0000ooooooooooooooooo`000009
ooooo`Ko00003?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool01Oo<c<co8B4Qo`000?mEEEGo000000?ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P2<ooooo`00
X_ooool01Ol0003oQhN7oooooonYZJWo000001_ooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go8B4QohN7QoooooooV9RHo`000003ooooo`05olc<c?l0003o
0000o`000?o<c<`0S?ooool00:7ooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0I
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol@413o^[Zjoooooonj^[[o410@08cooooo0032ooooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ob4Q8OnHV9SoooooogMg
MomEEED00oooool01Ol0003o^[Zjoooooonj^[[o000008cooooo0030ooooo`03oeEEEOmVIVKo0000
00Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05olc<c?l@413o0000oc8b<_o^k^h00ooo
ool01OnYZJWo410@o`000?l@413oZJVY08cooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1104) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.30141 .5902 Mdot
.32896 .57286 Mdot
.66308 .52788 Mdot
.46071 .3611 Mdot
.33008 .74078 Mdot
.65133 .55776 Mdot
.52602 .67621 Mdot
.4992 .62643 Mdot
.65431 .53661 Mdot
.36073 .64871 Mdot
.52566 .67006 Mdot
.48751 .45629 Mdot
.5213 .65743 Mdot
.47127 .37869 Mdot
.18472 .63587 Mdot
.51242 .37489 Mdot
.37493 .56659 Mdot
.60841 .41069 Mdot
.45286 .31591 Mdot
.66075 .58046 Mdot
.34615 .61271 Mdot
.46225 .37164 Mdot
.3087 .555 Mdot
.47122 .37941 Mdot
.45963 .3471 Mdot
.35531 .58371 Mdot
.38595 .56605 Mdot
.4167 .36363 Mdot
.47525 .34343 Mdot
.49417 .6337 Mdot
.54621 .27273 Mdot
.22646 .69098 Mdot
.41062 .328 Mdot
.62887 .77112 Mdot
.50832 .62458 Mdot
.27211 .5165 Mdot
.63004 .5539 Mdot
.50941 .63434 Mdot
.51702 .62685 Mdot
.51944 .68508 Mdot
.52297 .63825 Mdot
.34506 .58515 Mdot
.4661 .63201 Mdot
.4798 .58962 Mdot
.49599 .34596 Mdot
.3832 .73552 Mdot
.39258 .24584 Mdot
.42942 .40927 Mdot
.3714 .57499 Mdot
.69956 .49944 Mdot
.55505 .76239 Mdot
.53392 .67567 Mdot
.60541 .5379 Mdot
.69851 .8217 Mdot
.50145 .63856 Mdot
.48413 .33304 Mdot
.63293 .53814 Mdot
.45605 .37917 Mdot
.46884 .38376 Mdot
.21916 .42973 Mdot
.40634 .3735 Mdot
.63771 .41243 Mdot
.29601 .56043 Mdot
.56832 .44118 Mdot
.64242 .54208 Mdot
.52725 .63357 Mdot
.32047 .58181 Mdot
.51409 .65555 Mdot
.41488 .4455 Mdot
.6183 .57517 Mdot
.42827 .40684 Mdot
.53259 .64661 Mdot
.35207 .60304 Mdot
.42908 .38888 Mdot
.77426 .55399 Mdot
.15862 .43007 Mdot
.67152 .41544 Mdot
.24534 .4757 Mdot
.21251 .47244 Mdot
.72857 .45268 Mdot
.49155 .37669 Mdot
.58698 .22318 Mdot
.168 .53601 Mdot
.32383 .54007 Mdot
.40914 .31695 Mdot
.58667 .51187 Mdot
.43314 .38621 Mdot
.31316 .68216 Mdot
.49445 .352 Mdot
.7966 .58615 Mdot
.66155 .54079 Mdot
.34489 .55627 Mdot
.46364 .3612 Mdot
.41604 .35487 Mdot
.39026 .26442 Mdot
.42892 .43148 Mdot
.42811 .36058 Mdot
.33293 .60639 Mdot
.54089 .66095 Mdot
.52082 .41521 Mdot
.46305 .64863 Mdot
.63698 .52072 Mdot
.4503 .42779 Mdot
.62456 .56982 Mdot
.35348 .60559 Mdot
.4217 .38789 Mdot
.53008 .62697 Mdot
.45973 .42028 Mdot
.49427 .7261 Mdot
.32566 .57251 Mdot
.42062 .35041 Mdot
.63947 .4207 Mdot
.772 .35096 Mdot
.34213 .55029 Mdot
.74548 .4316 Mdot
.49609 .3759 Mdot
.43625 .3666 Mdot
.33166 .57296 Mdot
.65216 .52071 Mdot
.29208 .664 Mdot
.32013 .53574 Mdot
.52508 .6866 Mdot
.30409 .5485 Mdot
.39046 .34114 Mdot
.65576 .54599 Mdot
.60509 .72797 Mdot
.57428 .66926 Mdot
.54091 .25203 Mdot
.43782 .38492 Mdot
.40706 .67669 Mdot
.67634 .56575 Mdot
.34558 .56731 Mdot
.51142 .65828 Mdot
.50368 .32996 Mdot
.31791 .55866 Mdot
.50248 .66486 Mdot
.62372 .41663 Mdot
.64559 .6775 Mdot
.36548 .54434 Mdot
.45852 .60683 Mdot
.52641 .61424 Mdot
.52491 .68205 Mdot
.68046 .75319 Mdot
.32737 .58333 Mdot
.63387 .38736 Mdot
.49908 .65058 Mdot
.51664 .2739 Mdot
.45068 .32744 Mdot
.61581 .2666 Mdot
.51563 .1704 Mdot
.64296 .7662 Mdot
.69818 .6513 Mdot
.63286 .37157 Mdot
.54632 .66786 Mdot
.44299 .34179 Mdot
.35636 .58976 Mdot
.34119 .591 Mdot
.41148 .39312 Mdot
.45929 .35448 Mdot
.42533 .40049 Mdot
.4227 .34484 Mdot
.19821 .43194 Mdot
.47244 .42083 Mdot
.45664 .19759 Mdot
.348 .55173 Mdot
.44381 .35141 Mdot
.62198 .53684 Mdot
.39132 .38532 Mdot
.52665 .63873 Mdot
.45408 .37143 Mdot
.45697 .35944 Mdot
.405 .37018 Mdot
.53568 .67387 Mdot
.2182 .65435 Mdot
.58656 .19285 Mdot
.26843 .7103 Mdot
.77821 .5186 Mdot
.65705 .57077 Mdot
.4327 .37875 Mdot
.6469 .40655 Mdot
.30317 .4848 Mdot
.48773 .3858 Mdot
.81843 .33447 Mdot
.43898 .35993 Mdot
.28924 .7126 Mdot
.36966 .38577 Mdot
.28952 .74684 Mdot
.59416 .24109 Mdot
.44034 .33874 Mdot
.46446 .28218 Mdot
.37776 .49669 Mdot
.49028 .59262 Mdot
.52284 .64083 Mdot
.62863 .53213 Mdot
.64791 .53012 Mdot
.53664 .69461 Mdot
.32577 .63257 Mdot
.43781 .29328 Mdot
.42989 .44195 Mdot
.59974 .55587 Mdot
.29111 .5819 Mdot
.6159 .38134 Mdot
.31973 .60077 Mdot
.1883 .32251 Mdot
.544 .74973 Mdot
.51967 .69946 Mdot
.65674 .42571 Mdot
.67766 .53781 Mdot
.62152 .52761 Mdot
.65228 .39953 Mdot
.4512 .41277 Mdot
.32417 .58581 Mdot
.59439 .80515 Mdot
.36117 .6265 Mdot
.64888 .78852 Mdot
.34843 .60094 Mdot
.40842 .6275 Mdot
.50967 .66703 Mdot
.63303 .56368 Mdot
.43287 .36508 Mdot
.45102 .40416 Mdot
.363 .6096 Mdot
.42833 .40262 Mdot
.36772 .31974 Mdot
.42201 .36794 Mdot
.58389 .74353 Mdot
.67314 .41238 Mdot
.53603 .69464 Mdot
.52947 .24154 Mdot
.30499 .57413 Mdot
.69781 .33706 Mdot
.61138 .55839 Mdot
.28231 .49014 Mdot
.53491 .65092 Mdot
.62957 .4165 Mdot
.6095 .56011 Mdot
.61537 .37988 Mdot
.4007 .3494 Mdot
.69288 .53432 Mdot
.65006 .41773 Mdot
.21525 .54399 Mdot
.44556 .33072 Mdot
.1949 .42791 Mdot
.54638 .65915 Mdot
.3267 .53189 Mdot
.40705 .37245 Mdot
.64316 .57371 Mdot
.41039 .32569 Mdot
.69902 .62879 Mdot
.60338 .72932 Mdot
.68103 .51744 Mdot
.73066 .53322 Mdot
.62384 .40821 Mdot
.64252 .63552 Mdot
.41978 .65958 Mdot
.36989 .58342 Mdot
.4629 .42854 Mdot
.27211 .74785 Mdot
.49949 .6508 Mdot
.46186 .41486 Mdot
.62317 .74359 Mdot
.50214 .64781 Mdot
.45471 .38074 Mdot
.54383 .62813 Mdot
.33857 .59179 Mdot
.70816 .29976 Mdot
.37445 .56941 Mdot
.49536 .3571 Mdot
.53764 .63058 Mdot
.67564 .52048 Mdot
.36106 .57879 Mdot
.44769 .41863 Mdot
.42001 .37671 Mdot
.545 .50491 Mdot
.43602 .34992 Mdot
.24174 .67479 Mdot
.42252 .35404 Mdot
.63265 .53305 Mdot
.41883 .42195 Mdot
.847 .50644 Mdot
.58049 .66412 Mdot
.32107 .5828 Mdot
.69326 .5258 Mdot
.65184 .53423 Mdot
.72584 .3877 Mdot
.60229 .61008 Mdot
.49492 .38779 Mdot
.65113 .57319 Mdot
.67551 .30891 Mdot
.4896 .65265 Mdot
.45357 .4335 Mdot
.46496 .59171 Mdot
.69538 .49442 Mdot
.60145 .54936 Mdot
.4968 .32973 Mdot
.37667 .5863 Mdot
.46336 .36016 Mdot
.62299 .52898 Mdot
.30461 .61233 Mdot
.50061 .37873 Mdot
.41238 .53671 Mdot
.54387 .50517 Mdot
.50637 .67249 Mdot
.37254 .34967 Mdot
.44873 .42374 Mdot
.62493 .56254 Mdot
.3123 .58698 Mdot
.48844 .63303 Mdot
.35344 .57846 Mdot
.43672 .808 Mdot
.49667 .72305 Mdot
.19992 .49916 Mdot
.59559 .38349 Mdot
.74155 .62871 Mdot
.32773 .7768 Mdot
.80691 .47792 Mdot
.63063 .3219 Mdot
.50057 .83021 Mdot
.62211 .53267 Mdot
.64269 .73875 Mdot
.64787 .53294 Mdot
.47787 .35475 Mdot
.65005 .54683 Mdot
.31969 .77464 Mdot
.42245 .366 Mdot
.64354 .5509 Mdot
.71638 .33929 Mdot
.45113 .35451 Mdot
.33833 .54854 Mdot
.18408 .60277 Mdot
.81989 .47861 Mdot
.59704 .7601 Mdot
.69134 .54954 Mdot
.58582 .33924 Mdot
.42644 .35836 Mdot
.40757 .41132 Mdot
.36928 .56582 Mdot
.442 .43655 Mdot
.61973 .3784 Mdot
.6548 .42754 Mdot
.46789 .49524 Mdot
.61458 .21924 Mdot
.47269 .45036 Mdot
.36377 .57628 Mdot
.23963 .35938 Mdot
.77086 .56393 Mdot
.74827 .56317 Mdot
.55538 .6506 Mdot
.21016 .62447 Mdot
.36029 .40954 Mdot
.47498 .69356 Mdot
.50264 .58267 Mdot
.33509 .55933 Mdot
.22776 .67135 Mdot
.5189 .64016 Mdot
.32792 .3152 Mdot
.52629 .31055 Mdot
.45427 .40916 Mdot
.53507 .66051 Mdot
.4647 .45791 Mdot
.8302 .51732 Mdot
.35681 .24358 Mdot
.50251 .20263 Mdot
.50211 .36823 Mdot
.77645 .54407 Mdot
.44643 .36778 Mdot
.2761 .65357 Mdot
.42074 .35574 Mdot
.35774 .57159 Mdot
.3135 .65446 Mdot
.51656 .49378 Mdot
.54606 .18514 Mdot
.53248 .74744 Mdot
.6322 .37161 Mdot
.42747 .36923 Mdot
.45566 .40878 Mdot
.61688 .39024 Mdot
.33608 .53991 Mdot
.42364 .34353 Mdot
.68431 .33401 Mdot
.4343 .39573 Mdot
.51737 .63375 Mdot
.47574 .2146 Mdot
.38819 .54914 Mdot
.4557 .44221 Mdot
.29776 .59758 Mdot
.50302 .67144 Mdot
.51138 .62646 Mdot
.51643 .38488 Mdot
.49756 .68016 Mdot
.44795 .36161 Mdot
.36757 .22228 Mdot
.35183 .53977 Mdot
.36654 .34764 Mdot
.31164 .55434 Mdot
.24084 .48424 Mdot
.52294 .62239 Mdot
.57656 .73463 Mdot
.52944 .40281 Mdot
.52123 .6442 Mdot
.47589 .71282 Mdot
.47802 .4463 Mdot
.50769 .39194 Mdot
.78019 .62087 Mdot
.68952 .53879 Mdot
.53721 .49574 Mdot
.50708 .62126 Mdot
.44189 .42179 Mdot
.46444 .43559 Mdot
.507 .67507 Mdot
.30629 .31213 Mdot
.76714 .39549 Mdot
.42048 .3622 Mdot
.35844 .56099 Mdot
.34651 .56947 Mdot
.50561 .38139 Mdot
.46857 .41699 Mdot
.67439 .55376 Mdot
.69664 .53378 Mdot
.69011 .56713 Mdot
.54237 .50449 Mdot
.57939 .73837 Mdot
.42421 .76657 Mdot
.51935 .68491 Mdot
.43006 .70742 Mdot
.79953 .56776 Mdot
.38741 .36611 Mdot
.67834 .56984 Mdot
.46569 .40393 Mdot
.46095 .36417 Mdot
.48634 .63551 Mdot
.60809 .75465 Mdot
.42259 .46172 Mdot
.35315 .53732 Mdot
.49882 .62213 Mdot
.51925 .33499 Mdot
.46814 .75156 Mdot
.64353 .41688 Mdot
.70925 .71977 Mdot
.53301 .64355 Mdot
.33372 .55527 Mdot
.53361 .6243 Mdot
.44695 .40392 Mdot
.47058 .32166 Mdot
.33622 .56703 Mdot
.6597 .41336 Mdot
.39639 .38455 Mdot
.45197 .37865 Mdot
.65232 .19504 Mdot
.79024 .53505 Mdot
.58546 .72247 Mdot
.43437 .34165 Mdot
.47809 .43252 Mdot
.60561 .39171 Mdot
.43835 .3993 Mdot
.4149 .38816 Mdot
.73139 .2991 Mdot
.55284 .71072 Mdot
.62873 .42883 Mdot
.31825 .326 Mdot
.35372 .59819 Mdot
.25411 .72635 Mdot
.6362 .56672 Mdot
.50062 .68665 Mdot
.77364 .38791 Mdot
.63413 .52009 Mdot
.72129 .62235 Mdot
.24548 .7141 Mdot
.5348 .49879 Mdot
.68917 .40343 Mdot
.4567 .46743 Mdot
.4125 .37245 Mdot
.44278 .36913 Mdot
.6445 .40186 Mdot
.32988 .5876 Mdot
.5498 .4786 Mdot
.22054 .35182 Mdot
.45547 .36861 Mdot
.3743 .31187 Mdot
.20938 .56429 Mdot
.68587 .48518 Mdot
.63047 .37606 Mdot
.65999 .41678 Mdot
.43154 .36898 Mdot
.74497 .32552 Mdot
.35635 .58393 Mdot
.44896 .41879 Mdot
.4924 .4033 Mdot
.69247 .54409 Mdot
.3226 .56828 Mdot
.6182 .53506 Mdot
.56943 .73266 Mdot
.28329 .71383 Mdot
.66125 .19421 Mdot
.51534 .62385 Mdot
.23639 .61108 Mdot
.49071 .64284 Mdot
.57327 .21979 Mdot
.61925 .52746 Mdot
.49108 .38383 Mdot
.309 .58264 Mdot
.45322 .42058 Mdot
.47611 .40881 Mdot
.45287 .41269 Mdot
.40961 .43004 Mdot
.83706 .38391 Mdot
.65669 .40262 Mdot
.47693 .43906 Mdot
.64852 .52775 Mdot
.23398 .63089 Mdot
.15993 .46225 Mdot
.45827 .40185 Mdot
.42338 .37615 Mdot
.33021 .54798 Mdot
.41402 .40582 Mdot
.49042 .65024 Mdot
.31431 .59049 Mdot
.41816 .3518 Mdot
.22098 .62831 Mdot
.46335 .33638 Mdot
.28206 .73187 Mdot
.52877 .62167 Mdot
.45102 .68274 Mdot
.47026 .44436 Mdot
.60282 .72493 Mdot
.53731 .49565 Mdot
.65565 .57643 Mdot
.4731 .6509 Mdot
.63124 .55184 Mdot
.29173 .26848 Mdot
.43597 .32082 Mdot
.44775 .34243 Mdot
.4627 .43463 Mdot
.6536 .57159 Mdot
.31306 .69569 Mdot
.61098 .64365 Mdot
.5014 .31807 Mdot
.66722 .5623 Mdot
.29279 .57687 Mdot
.59772 .44185 Mdot
.30729 .57129 Mdot
.65164 .43176 Mdot
.52506 .66888 Mdot
.65924 .39026 Mdot
.61208 .76503 Mdot
.32773 .57142 Mdot
.37852 .59817 Mdot
.64898 .56631 Mdot
.56728 .55948 Mdot
.62105 .84884 Mdot
.59275 .46399 Mdot
.58449 .26142 Mdot
.36778 .56177 Mdot
.49097 .35607 Mdot
.53611 .21432 Mdot
.55659 .55613 Mdot
.63222 .5491 Mdot
.48405 .37682 Mdot
.72618 .31785 Mdot
.67463 .55465 Mdot
.45571 .43241 Mdot
.67515 .52611 Mdot
.53007 .64971 Mdot
.68456 .55568 Mdot
.37492 .54789 Mdot
.42352 .38485 Mdot
.5949 .85426 Mdot
.64344 .4471 Mdot
.42689 .35169 Mdot
.50256 .62085 Mdot
.42333 .52334 Mdot
.47692 .40002 Mdot
.61292 .40654 Mdot
.65671 .55128 Mdot
.58709 .48044 Mdot
.41989 .36066 Mdot
.65773 .56931 Mdot
.30039 .58061 Mdot
.47291 .65344 Mdot
.51975 .467 Mdot
.60124 .73505 Mdot
.36926 .56997 Mdot
.45527 .64063 Mdot
.47756 .64632 Mdot
.47073 .43685 Mdot
.47475 .42089 Mdot
.35471 .56285 Mdot
.6803 .2752 Mdot
.41198 .41121 Mdot
.49144 .37684 Mdot
.64567 .52724 Mdot
.63638 .5544 Mdot
.68982 .28866 Mdot
.65926 .5203 Mdot
.46263 .31993 Mdot
.35487 .56512 Mdot
.47115 .36355 Mdot
.3295 .55141 Mdot
.41997 .41591 Mdot
.30283 .61591 Mdot
.33866 .53708 Mdot
.60981 .63077 Mdot
.47773 .36959 Mdot
.36836 .37056 Mdot
.4649 .41283 Mdot
.4283 .39747 Mdot
.67323 .54934 Mdot
.64272 .38287 Mdot
.5166 .3538 Mdot
.65894 .43457 Mdot
.61336 .38726 Mdot
.37654 .50032 Mdot
.69158 .54382 Mdot
.63336 .39532 Mdot
.18258 .48165 Mdot
.69358 .55872 Mdot
.63998 .40871 Mdot
.16464 .48628 Mdot
.51106 .62375 Mdot
.37719 .56419 Mdot
.45231 .35419 Mdot
.50117 .82463 Mdot
.40853 .22564 Mdot
.65102 .51481 Mdot
.42408 .35245 Mdot
.46935 .40241 Mdot
.31859 .53901 Mdot
.35626 .19395 Mdot
.63829 .58255 Mdot
.47146 .34686 Mdot
.3185 .57788 Mdot
.39803 .17468 Mdot
.62719 .53733 Mdot
.64201 .40685 Mdot
.53767 .67291 Mdot
.3204 .52527 Mdot
.57616 .66 Mdot
.51876 .67844 Mdot
.60537 .52717 Mdot
.56381 .75781 Mdot
.49631 .37683 Mdot
.67645 .57076 Mdot
.727 .71252 Mdot
.38799 .60471 Mdot
.51857 .59942 Mdot
.57942 .34742 Mdot
.33697 .55724 Mdot
.49135 .65012 Mdot
.65035 .38069 Mdot
.34448 .60228 Mdot
.34908 .54301 Mdot
.48382 .64334 Mdot
.46472 .48686 Mdot
.4716 .58545 Mdot
.51446 .62993 Mdot
.78363 .60114 Mdot
.48327 .79903 Mdot
.676 .57288 Mdot
.61689 .38491 Mdot
.57473 .79427 Mdot
.34617 .58485 Mdot
.21117 .62679 Mdot
.7363 .69593 Mdot
.42828 .36043 Mdot
.62874 .39206 Mdot
.35811 .73372 Mdot
.2466 .31461 Mdot
.50208 .64592 Mdot
.51286 .50297 Mdot
.64946 .37095 Mdot
.40794 .37831 Mdot
.52671 .30031 Mdot
.48355 .36609 Mdot
.5164 .67067 Mdot
.21035 .44832 Mdot
.33302 .55471 Mdot
.48664 .63039 Mdot
.70614 .7227 Mdot
.4515 .3638 Mdot
.48191 .37237 Mdot
.51353 .24387 Mdot
.34178 .59621 Mdot
.65221 .57722 Mdot
.49585 .38069 Mdot
.45293 .37533 Mdot
.49844 .33858 Mdot
.378 .33105 Mdot
.76587 .34655 Mdot
.47462 .35081 Mdot
.5495 .73844 Mdot
.45942 .44237 Mdot
.47669 .37308 Mdot
.29695 .597 Mdot
.71793 .23594 Mdot
.56584 .73378 Mdot
.45297 .3721 Mdot
.48806 .35447 Mdot
.48258 .6461 Mdot
.48683 .56949 Mdot
.56726 .56731 Mdot
.57579 .50917 Mdot
.61001 .32609 Mdot
.40992 .43215 Mdot
.3118 .5754 Mdot
.6446 .42178 Mdot
.49925 .40246 Mdot
.31246 .57385 Mdot
.41082 .34459 Mdot
.67436 .55777 Mdot
.69555 .55479 Mdot
.43789 .63014 Mdot
.63473 .40188 Mdot
.46668 .23537 Mdot
.42587 .71519 Mdot
.6422 .5265 Mdot
.45201 .3443 Mdot
.49229 .68389 Mdot
.62121 .52956 Mdot
.58815 .52385 Mdot
.43102 .29868 Mdot
.35162 .58983 Mdot
.34486 .55361 Mdot
.61874 .26777 Mdot
.66789 .66676 Mdot
.66579 .21727 Mdot
.53088 .6535 Mdot
.40111 .37814 Mdot
.41142 .6618 Mdot
.34348 .55185 Mdot
.55184 .21923 Mdot
.6315 .39608 Mdot
.50015 .64593 Mdot
.73924 .57403 Mdot
.32188 .55495 Mdot
.37302 .55732 Mdot
.48563 .34419 Mdot
.45344 .38977 Mdot
.6385 .31991 Mdot
.65501 .36343 Mdot
.49863 .66786 Mdot
.61612 .3889 Mdot
.60771 .55913 Mdot
.47802 .35136 Mdot
.31364 .54825 Mdot
.54332 .79483 Mdot
.49147 .35931 Mdot
.67564 .54986 Mdot
.33933 .55945 Mdot
.61653 .39689 Mdot
.6108 .39394 Mdot
.42946 .39681 Mdot
.24407 .36024 Mdot
.50978 .63978 Mdot
.33866 .54949 Mdot
.4984 .75314 Mdot
.41859 .42279 Mdot
.44844 .38594 Mdot
.37661 .38384 Mdot
.48647 .6451 Mdot
.43274 .6519 Mdot
.66458 .39549 Mdot
.33495 .58392 Mdot
.45066 .33697 Mdot
.63455 .40958 Mdot
.42624 .65292 Mdot
.67598 .51627 Mdot
.68484 .54943 Mdot
.61146 .40291 Mdot
.62358 .38722 Mdot
.61525 .40762 Mdot
.20645 .62336 Mdot
.36772 .53484 Mdot
.36838 .43329 Mdot
.40862 .4073 Mdot
.59999 .2546 Mdot
.51518 .33994 Mdot
.50681 .61655 Mdot
.68712 .53638 Mdot
.47128 .40976 Mdot
.49672 .36088 Mdot
.3724 .36753 Mdot
.36417 .39316 Mdot
.3897 .56167 Mdot
.32454 .57095 Mdot
.41626 .33141 Mdot
.69053 .53439 Mdot
.21345 .2892 Mdot
.43798 .84322 Mdot
.48502 .43866 Mdot
.53335 .56899 Mdot
.31611 .54655 Mdot
.4897 .66909 Mdot
.57691 .54021 Mdot
.54119 .62996 Mdot
.33831 .57916 Mdot
.47733 .35164 Mdot
.4358 .71839 Mdot
.60856 .39951 Mdot
.43063 .41416 Mdot
.50266 .66116 Mdot
.42709 .40816 Mdot
.5208 .6781 Mdot
.40014 .79217 Mdot
.80626 .55365 Mdot
.43751 .35994 Mdot
.48561 .43167 Mdot
.59422 .34447 Mdot
.46026 .40087 Mdot
.59645 .42939 Mdot
.32067 .54375 Mdot
.62754 .20899 Mdot
.46747 .33182 Mdot
.29507 .43111 Mdot
.41738 .4227 Mdot
.72967 .33043 Mdot
.44899 .39097 Mdot
.70454 .49803 Mdot
.41502 .36731 Mdot
.41728 .38912 Mdot
.53948 .63077 Mdot
.48303 .64396 Mdot
.32892 .60957 Mdot
.64564 .5748 Mdot
.26873 .71834 Mdot
.45029 .38072 Mdot
.60382 .73536 Mdot
.51886 .72571 Mdot
.62323 .38517 Mdot
.34 .58072 Mdot
.36576 .18002 Mdot
.55181 .64183 Mdot
.78273 .46569 Mdot
.69161 .30502 Mdot
.57037 .68854 Mdot
.58361 .51656 Mdot
.28905 .65178 Mdot
.62748 .41131 Mdot
.40671 .38089 Mdot
.59063 .77423 Mdot
.75817 .57037 Mdot
.44346 .2952 Mdot
.48135 .6342 Mdot
.29572 .47799 Mdot
.56172 .79346 Mdot
.66315 .38419 Mdot
.66065 .39108 Mdot
.53217 .67509 Mdot
.7108 .51632 Mdot
.43909 .46136 Mdot
.62932 .39756 Mdot
.65594 .52235 Mdot
.68264 .57035 Mdot
.68831 .60695 Mdot
.34989 .58718 Mdot
.67502 .74278 Mdot
.39452 .72731 Mdot
.51667 .67768 Mdot
.68905 .42116 Mdot
.34851 .52082 Mdot
.38296 .55981 Mdot
.63873 .56321 Mdot
.67433 .54492 Mdot
.3789 .57015 Mdot
.46237 .32558 Mdot
.37553 .40818 Mdot
.45302 .36911 Mdot
.64668 .39694 Mdot
.45153 .39723 Mdot
.66935 .5561 Mdot
.50673 .64914 Mdot
.67052 .53897 Mdot
.54707 .6304 Mdot
.43634 .76457 Mdot
.44103 .41405 Mdot
.42089 .38194 Mdot
.40616 .22392 Mdot
.3047 .59858 Mdot
.52557 .75478 Mdot
.59734 .74725 Mdot
.64848 .53155 Mdot
.41421 .38824 Mdot
.30308 .57297 Mdot
.6673 .41346 Mdot
.40459 .2227 Mdot
.45808 .42576 Mdot
.31525 .54853 Mdot
.46014 .34105 Mdot
.195 .51463 Mdot
.82487 .43037 Mdot
.35186 .57572 Mdot
.50696 .17249 Mdot
.47648 .34565 Mdot
.2879 .63697 Mdot
.47152 .42878 Mdot
.6514 .29704 Mdot
.41308 .41298 Mdot
.34904 .60095 Mdot
.45812 .37339 Mdot
.32899 .59898 Mdot
.62116 .53982 Mdot
.50975 .6825 Mdot
.36562 .55392 Mdot
.48589 .41363 Mdot
.31497 .82048 Mdot
.52075 .66826 Mdot
.43045 .36689 Mdot
.54563 .65462 Mdot
.31999 .58648 Mdot
.37271 .56491 Mdot
.209 .35785 Mdot
.57277 .71529 Mdot
.52934 .64878 Mdot
.46979 .34804 Mdot
.35677 .69507 Mdot
.47536 .36252 Mdot
.61744 .303 Mdot
.49377 .33935 Mdot
.41707 .41982 Mdot
.16122 .42412 Mdot
.48936 .65676 Mdot
.6922 .24252 Mdot
.20011 .37731 Mdot
.20604 .60813 Mdot
.30183 .54104 Mdot
.6665 .39398 Mdot
.22489 .66471 Mdot
.57811 .73292 Mdot
.6635 .56676 Mdot
.46836 .41075 Mdot
.36924 .52198 Mdot
.50631 .63424 Mdot
.64653 .38619 Mdot
.43668 .36028 Mdot
.67551 .54341 Mdot
.77085 .41753 Mdot
.5478 .66741 Mdot
.344 .58497 Mdot
.34595 .53498 Mdot
.45687 .16438 Mdot
.44038 .33828 Mdot
.41818 .38067 Mdot
.52063 .67094 Mdot
.40235 .58865 Mdot
.62325 .40991 Mdot
.73504 .3579 Mdot
.52943 .65094 Mdot
.54247 .53348 Mdot
.32463 .5802 Mdot
.46782 .40359 Mdot
.30646 .70085 Mdot
.76674 .53663 Mdot
.33227 .34828 Mdot
.6468 .4042 Mdot
.60727 .30167 Mdot
.35019 .60066 Mdot
.50671 .65707 Mdot
.65872 .68214 Mdot
.40392 .32551 Mdot
.46872 .39765 Mdot
.60043 .29767 Mdot
.50621 .48634 Mdot
.49697 .20466 Mdot
.44957 .42997 Mdot
.53206 .48202 Mdot
.43296 .42543 Mdot
.42002 .31268 Mdot
.4702 .32372 Mdot
.44197 .38379 Mdot
.31582 .54757 Mdot
.44731 .29765 Mdot
.66846 .56932 Mdot
.39864 .26489 Mdot
.55477 .51494 Mdot
.42328 .35671 Mdot
.47923 .35944 Mdot
.33811 .41734 Mdot
.46551 .67975 Mdot
.35661 .54841 Mdot
.35444 .6172 Mdot
.5048 .68412 Mdot
.37115 .38297 Mdot
.64057 .57628 Mdot
.48136 .31504 Mdot
.67106 .54642 Mdot
.3066 .56102 Mdot
.64092 .53255 Mdot
.52764 .68302 Mdot
.68372 .56636 Mdot
.57941 .74001 Mdot
.49452 .64182 Mdot
.3543 .59261 Mdot
.43017 .38994 Mdot
.50075 .62191 Mdot
.52637 .25269 Mdot
.64642 .39772 Mdot
.19964 .36855 Mdot
.433 .33745 Mdot
.56469 .69097 Mdot
.41195 .53338 Mdot
.67008 .54071 Mdot
.79541 .37006 Mdot
.34128 .53708 Mdot
.63719 .42967 Mdot
.30456 .56472 Mdot
.79954 .60656 Mdot
.63426 .3807 Mdot
.16433 .49775 Mdot
.69891 .67149 Mdot
.61951 .46748 Mdot
.46086 .32626 Mdot
.53436 .31604 Mdot
.60619 .56198 Mdot
.50541 .6348 Mdot
.69102 .66301 Mdot
.41773 .39281 Mdot
.80235 .49387 Mdot
.3399 .61086 Mdot
.65022 .57436 Mdot
.51477 .6574 Mdot
.49245 .62678 Mdot
.47076 .4192 Mdot
.70696 .40663 Mdot
.43386 .42182 Mdot
.64471 .66403 Mdot
.60749 .32024 Mdot
.41155 .45585 Mdot
.42257 .36826 Mdot
.62058 .55858 Mdot
.4605 .34141 Mdot
.6031 .35966 Mdot
.66023 .76413 Mdot
.40564 .42135 Mdot
.59235 .75078 Mdot
.62864 .44159 Mdot
.33287 .56934 Mdot
.51062 .42199 Mdot
.58243 .70911 Mdot
.45028 .33813 Mdot
.87362 .54344 Mdot
.63823 .40915 Mdot
.61045 .71967 Mdot
.44478 .44028 Mdot
.48664 .4077 Mdot
.55656 .3716 Mdot
.29027 .53834 Mdot
.76933 .5353 Mdot
.4658 .39169 Mdot
.55827 .30279 Mdot
.53776 .65963 Mdot
.44232 .42493 Mdot
.4394 .36805 Mdot
.33299 .50269 Mdot
.49047 .6337 Mdot
.66166 .53086 Mdot
.60821 .53556 Mdot
.6629 .5891 Mdot
.60147 .40125 Mdot
.518 .5158 Mdot
.57455 .2342 Mdot
.81671 .48172 Mdot
.64194 .42516 Mdot
.46435 .33436 Mdot
.59051 .36501 Mdot
.48905 .36088 Mdot
.64437 .37683 Mdot
.49073 .63601 Mdot
.35698 .54712 Mdot
.40652 .6424 Mdot
.61595 .57369 Mdot
.45497 .43361 Mdot
.62065 .37548 Mdot
.35535 .58977 Mdot
.63448 .35925 Mdot
.33228 .57671 Mdot
.52593 .65053 Mdot
.51279 .68937 Mdot
.64803 .38383 Mdot
.30797 .56538 Mdot
.47945 .70496 Mdot
.2507 .31452 Mdot
.48308 .32715 Mdot
.54476 .59487 Mdot
.30421 .59391 Mdot
.37766 .59059 Mdot
.32487 .60479 Mdot
.43052 .40551 Mdot
.52832 .56789 Mdot
.51032 .36515 Mdot
.50104 .66932 Mdot
.67562 .52713 Mdot
.6935 .34791 Mdot
.48067 .78531 Mdot
.69892 .36688 Mdot
.40046 .36853 Mdot
.45634 .36606 Mdot
.4318 .36875 Mdot
.49642 .35038 Mdot
.62995 .67337 Mdot
.45692 .41797 Mdot
.54221 .63463 Mdot
.66214 .55021 Mdot
.40553 .37536 Mdot
.66851 .51432 Mdot
.31748 .67127 Mdot
.6495 .42138 Mdot
.50513 .51027 Mdot
.27306 .76781 Mdot
.3621 .5845 Mdot
.65495 .51984 Mdot
.66096 .56693 Mdot
.62378 .41646 Mdot
.51081 .63499 Mdot
.3286 .581 Mdot
.66203 .31083 Mdot
.61321 .39885 Mdot
.45599 .37402 Mdot
.58917 .59001 Mdot
.79569 .49967 Mdot
.40914 .3925 Mdot
.48507 .39634 Mdot
.67873 .51628 Mdot
.70688 .50779 Mdot
.66086 .79389 Mdot
.52313 .22117 Mdot
.64458 .38244 Mdot
.65721 .41501 Mdot
.37823 .58281 Mdot
.50395 .42014 Mdot
.50453 .67159 Mdot
.4624 .21457 Mdot
.42618 .50487 Mdot
.46877 .23079 Mdot
.52745 .46392 Mdot
.45908 .4236 Mdot
.302 .29771 Mdot
.45094 .36248 Mdot
.33036 .5355 Mdot
.32775 .59266 Mdot
.36434 .56454 Mdot
.50563 .63787 Mdot
.25616 .48611 Mdot
.53903 .63321 Mdot
.30364 .78612 Mdot
.35812 .59627 Mdot
.62456 .69668 Mdot
.62261 .5586 Mdot
.46385 .44659 Mdot
.61862 .40106 Mdot
.51221 .61029 Mdot
.41275 .44435 Mdot
.75183 .32944 Mdot
.65955 .57206 Mdot
.35611 .59226 Mdot
.28547 .64791 Mdot
.36627 .79727 Mdot
.57181 .55381 Mdot
.52597 .34735 Mdot
.55445 .353 Mdot
.62219 .38414 Mdot
.33339 .33921 Mdot
.62871 .37062 Mdot
.49785 .65498 Mdot
.42492 .38228 Mdot
.43405 .38559 Mdot
.42465 .42183 Mdot
.45035 .41684 Mdot
.48733 .66791 Mdot
.4064 .41362 Mdot
.84699 .50647 Mdot
.69729 .5504 Mdot
.20968 .53128 Mdot
.6325 .4114 Mdot
.47588 .6401 Mdot
.66416 .55064 Mdot
.69234 .51647 Mdot
.53699 .23865 Mdot
.42005 .36324 Mdot
.46929 .4115 Mdot
.78661 .48377 Mdot
.44615 .43066 Mdot
.52898 .36128 Mdot
.65949 .56878 Mdot
.69814 .3646 Mdot
.65234 .42545 Mdot
.66076 .39991 Mdot
.4995 .62861 Mdot
.30617 .56547 Mdot
.63935 .39753 Mdot
.62399 .53762 Mdot
.40079 .35878 Mdot
.49667 .39619 Mdot
.30645 .59708 Mdot
.74435 .68766 Mdot
.6589 .37794 Mdot
.29875 .65705 Mdot
.31939 .59242 Mdot
.35738 .52631 Mdot
.46997 .39628 Mdot
.41483 .29528 Mdot
.34279 .5135 Mdot
.63232 .42498 Mdot
.47545 .64367 Mdot
.58093 .50289 Mdot
.50583 .66739 Mdot
.33416 .59039 Mdot
.50114 .38994 Mdot
.3359 .59348 Mdot
.43162 .34314 Mdot
.19555 .69699 Mdot
.44033 .38748 Mdot
.82318 .49453 Mdot
.61766 .28049 Mdot
.65378 .55884 Mdot
.49376 .71788 Mdot
.64169 .56788 Mdot
.3231 .59475 Mdot
.49781 .40188 Mdot
.66393 .3995 Mdot
.193 .57543 Mdot
.35724 .5229 Mdot
.6771 .55843 Mdot
.66523 .58392 Mdot
.49159 .64342 Mdot
.40393 .38025 Mdot
.46576 .40178 Mdot
.64176 .55189 Mdot
.39853 .45193 Mdot
.32031 .55234 Mdot
.42126 .37618 Mdot
.4682 .37008 Mdot
.65254 .56058 Mdot
.26965 .29552 Mdot
.2708 .58416 Mdot
.43201 .37971 Mdot
.65904 .71099 Mdot
.50462 .61698 Mdot
.47895 .33245 Mdot
.44468 .44682 Mdot
.62417 .39153 Mdot
.23396 .54853 Mdot
.64374 .77134 Mdot
.51583 .61714 Mdot
.63831 .57011 Mdot
.44366 .33699 Mdot
.62319 .56128 Mdot
.49222 .40526 Mdot
.25075 .57213 Mdot
.6639 .57551 Mdot
.49204 .39489 Mdot
.50056 .42839 Mdot
.33952 .59679 Mdot
.46469 .41829 Mdot
.35619 .44914 Mdot
.61078 .54114 Mdot
.48362 .40879 Mdot
.242 .3651 Mdot
.52152 .6303 Mdot
.49632 .43329 Mdot
.64847 .41716 Mdot
.66737 .3123 Mdot
.42638 .72942 Mdot
.61106 .74182 Mdot
.65427 .41243 Mdot
.42611 .40957 Mdot
.67371 .58247 Mdot
.5267 .67707 Mdot
.80987 .45799 Mdot
.41313 .395 Mdot
.51636 .67013 Mdot
.50813 .65083 Mdot
.64585 .41422 Mdot
.59602 .1694 Mdot
.42754 .43943 Mdot
.45748 .40112 Mdot
.36821 .48666 Mdot
.30015 .55666 Mdot
.44649 .39599 Mdot
.48373 .34702 Mdot
.54435 .63947 Mdot
.53484 .37549 Mdot
.32233 .45684 Mdot
.71662 .3361 Mdot
.53601 .6166 Mdot
.58213 .47328 Mdot
.65434 .58046 Mdot
.62935 .40744 Mdot
.33915 .56717 Mdot
.63861 .3672 Mdot
.68754 .55759 Mdot
.47146 .33827 Mdot
.54948 .65117 Mdot
.34669 .36489 Mdot
.5298 .67716 Mdot
.61423 .73498 Mdot
.299 .57303 Mdot
.39657 .6686 Mdot
.87011 .47764 Mdot
.39784 .73381 Mdot
.47041 .68607 Mdot
.62342 .3852 Mdot
.62353 .51225 Mdot
.4648 .36858 Mdot
.34204 .31145 Mdot
.42678 .39303 Mdot
.24563 .36555 Mdot
.66752 .52193 Mdot
.68994 .56756 Mdot
.42819 .3813 Mdot
.61157 .31563 Mdot
.51852 .68022 Mdot
.4897 .65376 Mdot
.47916 .41071 Mdot
.52149 .644 Mdot
.4563 .39006 Mdot
.67129 .5512 Mdot
.72803 .27255 Mdot
.44535 .36493 Mdot
.50364 .4041 Mdot
.57359 .61994 Mdot
.16803 .42445 Mdot
.68328 .70942 Mdot
.32719 .28115 Mdot
.40107 .81316 Mdot
.52131 .64498 Mdot
.51456 .37646 Mdot
.585 .46813 Mdot
.67485 .51445 Mdot
.47353 .69848 Mdot
.4391 .39662 Mdot
.4376 .3998 Mdot
.41491 .38385 Mdot
.48238 .3715 Mdot
.3336 .32098 Mdot
.36734 .43716 Mdot
.23542 .41973 Mdot
.47366 .41057 Mdot
.49893 .27677 Mdot
.50933 .62156 Mdot
.33813 .61334 Mdot
.62863 .36449 Mdot
.4594 .4232 Mdot
.36375 .42705 Mdot
.49542 .61946 Mdot
.30598 .78749 Mdot
.49387 .63584 Mdot
.65065 .53475 Mdot
.49427 .67309 Mdot
.43489 .3489 Mdot
.34703 .56868 Mdot
.56443 .50751 Mdot
.64721 .63649 Mdot
.66442 .56639 Mdot
.42665 .35181 Mdot
.60087 .71127 Mdot
.66856 .56771 Mdot
.31988 .67425 Mdot
.34534 .56382 Mdot
.54858 .29326 Mdot
.32882 .59343 Mdot
.49282 .39446 Mdot
.49366 .38181 Mdot
.50376 .59765 Mdot
.51984 .68252 Mdot
.32493 .59262 Mdot
.63171 .17811 Mdot
.62496 .37031 Mdot
.36283 .56998 Mdot
.40513 .332 Mdot
.45792 .55451 Mdot
.35147 .56208 Mdot
.67919 .35779 Mdot
.50063 .63767 Mdot
.36969 .58973 Mdot
.39982 .33547 Mdot
.75549 .65325 Mdot
.6214 .41946 Mdot
.69048 .57901 Mdot
.61825 .59802 Mdot
.61627 .53391 Mdot
.47601 .6558 Mdot
.6476 .56763 Mdot
.53929 .65448 Mdot
.49685 .7375 Mdot
.41713 .2497 Mdot
.50162 .68929 Mdot
.48168 .66379 Mdot
.64931 .56588 Mdot
.41747 .37309 Mdot
.5993 .58264 Mdot
.5045 .35389 Mdot
.38811 .39735 Mdot
.53728 .6478 Mdot
.34866 .6002 Mdot
.37502 .55165 Mdot
.51745 .29238 Mdot
.34285 .53407 Mdot
.67241 .54605 Mdot
.82427 .44628 Mdot
.59636 .76426 Mdot
.53159 .66451 Mdot
.48151 .65747 Mdot
.47672 .36169 Mdot
.63132 .55093 Mdot
.61692 .5506 Mdot
.49412 .65251 Mdot
.40091 .27808 Mdot
.50537 .40992 Mdot
.37683 .5964 Mdot
.36428 .59223 Mdot
.35426 .57028 Mdot
.32724 .60379 Mdot
.31562 .42337 Mdot
.49827 .6389 Mdot
.3443 .60128 Mdot
.48782 .40153 Mdot
.43895 .39939 Mdot
.5723 .50952 Mdot
.65922 .40661 Mdot
.41059 .34615 Mdot
.46057 .32211 Mdot
.4714 .39855 Mdot
.68419 .55267 Mdot
.38189 .38871 Mdot
.65553 .57778 Mdot
.67812 .58482 Mdot
.69488 .53429 Mdot
.57886 .73429 Mdot
.56084 .35408 Mdot
.4477 .83213 Mdot
.47112 .3464 Mdot
.36929 .6232 Mdot
.62453 .55156 Mdot
.77813 .35224 Mdot
.42959 .64341 Mdot
.41355 .39102 Mdot
.76205 .54202 Mdot
.64185 .55408 Mdot
.34778 .53357 Mdot
.43968 .39396 Mdot
.67437 .58858 Mdot
.64025 .42207 Mdot
.42932 .31893 Mdot
.61114 .53493 Mdot
.30856 .57065 Mdot
.60317 .37722 Mdot
.35803 .59912 Mdot
.68948 .52885 Mdot
.49914 .43009 Mdot
.64663 .84205 Mdot
.62541 .57953 Mdot
.178 .47269 Mdot
.28367 .56397 Mdot
.42009 .37617 Mdot
.64024 .52262 Mdot
.3038 .55139 Mdot
.47502 .65658 Mdot
.45096 .50899 Mdot
.35347 .54098 Mdot
.68914 .56817 Mdot
.61354 .53376 Mdot
.66068 .56858 Mdot
.32678 .56605 Mdot
.50574 .38743 Mdot
.32588 .55835 Mdot
.49198 .67064 Mdot
.45994 .35823 Mdot
.31816 .77252 Mdot
.38409 .61146 Mdot
.32157 .5926 Mdot
.66919 .53127 Mdot
.60584 .39552 Mdot
.44019 .35805 Mdot
.18795 .43528 Mdot
.42239 .34966 Mdot
.53294 .66791 Mdot
.70484 .27752 Mdot
.34516 .36241 Mdot
.41076 .4113 Mdot
.47743 .36236 Mdot
.49332 .66225 Mdot
.42615 .36035 Mdot
.4097 .40631 Mdot
.57616 .72674 Mdot
.32065 .5703 Mdot
.46037 .37229 Mdot
.66397 .52512 Mdot
.55522 .76846 Mdot
.51086 .38952 Mdot
.74967 .43364 Mdot
.57086 .30448 Mdot
.66563 .23281 Mdot
.42411 .39117 Mdot
.49801 .22151 Mdot
.4847 .37975 Mdot
.43402 .41518 Mdot
.47278 .3538 Mdot
.35602 .26699 Mdot
.67271 .57111 Mdot
.66497 .55966 Mdot
.62453 .42175 Mdot
.5682 .30466 Mdot
.62711 .39249 Mdot
.50209 .6323 Mdot
.73157 .43687 Mdot
.6643 .5752 Mdot
.30786 .5728 Mdot
.42754 .4151 Mdot
.62149 .57792 Mdot
.46554 .40629 Mdot
.43561 .34694 Mdot
.62404 .56954 Mdot
.62901 .57811 Mdot
.60965 .72967 Mdot
.64927 .41942 Mdot
.36493 .55785 Mdot
.42167 .33614 Mdot
.61502 .38515 Mdot
.50245 .39784 Mdot
.59865 .25023 Mdot
.36303 .558 Mdot
.32126 .56728 Mdot
.3655 .54062 Mdot
.47057 .33799 Mdot
.43283 .35287 Mdot
.5395 .63508 Mdot
.30543 .572 Mdot
.52056 .63167 Mdot
.54805 .50467 Mdot
.74477 .41466 Mdot
.43905 .39676 Mdot
.30963 .65569 Mdot
.62218 .40005 Mdot
.66075 .53822 Mdot
.77405 .44139 Mdot
.61985 .41941 Mdot
.42601 .34794 Mdot
.62123 .56198 Mdot
.65104 .38288 Mdot
.52589 .33255 Mdot
.51562 .83891 Mdot
.60664 .38488 Mdot
.48558 .4038 Mdot
.53613 .40673 Mdot
.35005 .24145 Mdot
.60205 .3952 Mdot
.54294 .66205 Mdot
.46693 .33616 Mdot
.40761 .53219 Mdot
.65753 .37707 Mdot
.51709 .7564 Mdot
.65324 .55226 Mdot
.70302 .71131 Mdot
.39918 .43111 Mdot
.36548 .28429 Mdot
.63876 .36992 Mdot
.33141 .58226 Mdot
.3086 .61396 Mdot
.47582 .38963 Mdot
.60155 .39319 Mdot
.54329 .61898 Mdot
.65489 .54693 Mdot
.5656 .73748 Mdot
.32773 .56345 Mdot
.36272 .66477 Mdot
.67799 .53348 Mdot
.31975 .66289 Mdot
.71754 .3151 Mdot
.39905 .44572 Mdot
.3375 .26788 Mdot
.73406 .60102 Mdot
.46473 .3329 Mdot
.6191 .37318 Mdot
.5121 .61799 Mdot
.54161 .66746 Mdot
.52816 .65455 Mdot
.51211 .72975 Mdot
.57347 .52417 Mdot
.67294 .51798 Mdot
.69062 .61707 Mdot
.63304 .40764 Mdot
.49191 .26173 Mdot
.48807 .41572 Mdot
.45429 .36597 Mdot
.40242 .37298 Mdot
.44741 .42708 Mdot
.47989 .38071 Mdot
.51604 .63645 Mdot
.52154 .73336 Mdot
.58422 .48425 Mdot
.35726 .55787 Mdot
.69715 .39386 Mdot
.62258 .55792 Mdot
.69166 .52411 Mdot
.65612 .39549 Mdot
.28283 .65566 Mdot
.65411 .51644 Mdot
.64624 .53104 Mdot
.41443 .35215 Mdot
.32094 .557 Mdot
.47235 .30763 Mdot
.49097 .377 Mdot
.66462 .5433 Mdot
.57328 .43936 Mdot
.33783 .44698 Mdot
.39354 .32696 Mdot
.59271 .38324 Mdot
.52052 .56436 Mdot
.60299 .391 Mdot
.49117 .41678 Mdot
.76517 .33801 Mdot
.68615 .55978 Mdot
.6386 .54103 Mdot
.62903 .37253 Mdot
.27623 .61976 Mdot
.33657 .56108 Mdot
.69202 .51576 Mdot
.5437 .65491 Mdot
.49245 .36855 Mdot
.76007 .40789 Mdot
.28552 .62796 Mdot
.71128 .4156 Mdot
.5289 .66014 Mdot
.61905 .54696 Mdot
.40369 .38809 Mdot
.48585 .40242 Mdot
.61864 .38747 Mdot
.36339 .76566 Mdot
.43233 .32132 Mdot
.20545 .61297 Mdot
.80873 .55971 Mdot
.75321 .6686 Mdot
.46853 .39768 Mdot
.32225 .57046 Mdot
.62143 .5261 Mdot
.61684 .38561 Mdot
.39346 .38212 Mdot
.49521 .83852 Mdot
.31506 .60758 Mdot
.50111 .65548 Mdot
.56969 .4783 Mdot
.57658 .54344 Mdot
.42809 .33988 Mdot
.42797 .39245 Mdot
.43552 .40988 Mdot
.59067 .8185 Mdot
.68126 .54968 Mdot
.31147 .5493 Mdot
.64939 .40359 Mdot
.33936 .53401 Mdot
.65973 .56088 Mdot
.37674 .6687 Mdot
.41594 .36246 Mdot
.31284 .60619 Mdot
.33337 .58012 Mdot
.4924 .64164 Mdot
.48015 .66527 Mdot
.557 .49481 Mdot
.44182 .38735 Mdot
.5993 .55801 Mdot
.34518 .59761 Mdot
.58994 .58803 Mdot
.63221 .38068 Mdot
.52202 .62273 Mdot
.47118 .41191 Mdot
.6796 .56486 Mdot
.40564 .41299 Mdot
.34666 .55114 Mdot
.6441 .53168 Mdot
.60676 .72777 Mdot
.65568 .41558 Mdot
.44747 .40881 Mdot
.59948 .37252 Mdot
.6372 .56996 Mdot
.46745 .36848 Mdot
.26634 .63315 Mdot
.6007 .41019 Mdot
.62052 .64346 Mdot
.67656 .52127 Mdot
.60293 .73346 Mdot
.37033 .54905 Mdot
.47754 .72923 Mdot
.64383 .53876 Mdot
.26935 .64455 Mdot
.42053 .77968 Mdot
.40678 .34263 Mdot
.34931 .58217 Mdot
.65071 .50232 Mdot
.24397 .72418 Mdot
.26626 .30562 Mdot
.43246 .36683 Mdot
.66307 .51978 Mdot
.62763 .37433 Mdot
.53256 .66347 Mdot
.75052 .43176 Mdot
.59394 .365 Mdot
.64767 .58308 Mdot
.47473 .35392 Mdot
.32206 .58565 Mdot
.50413 .64237 Mdot
.44365 .73541 Mdot
.6401 .52937 Mdot
.67946 .52995 Mdot
.40478 .39339 Mdot
.63233 .39712 Mdot
.22088 .37394 Mdot
.67187 .55432 Mdot
.78718 .49788 Mdot
.59939 .53335 Mdot
.61854 .37629 Mdot
.48687 .38797 Mdot
.53719 .31528 Mdot
.49192 .34363 Mdot
.17567 .50399 Mdot
.63687 .56553 Mdot
.35429 .55125 Mdot
.42554 .39955 Mdot
.71041 .32304 Mdot
.66077 .54242 Mdot
.53704 .56908 Mdot
.7242 .51496 Mdot
.49922 .63877 Mdot
.77728 .44566 Mdot
.45118 .4015 Mdot
.52233 .67926 Mdot
.62231 .39929 Mdot
.43708 .37998 Mdot
.43625 .35233 Mdot
.31714 .53851 Mdot
.49752 .65703 Mdot
.45233 .79965 Mdot
.48564 .63184 Mdot
.53107 .623 Mdot
.35034 .52852 Mdot
.46531 .38332 Mdot
.65339 .53343 Mdot
.63975 .55336 Mdot
.38952 .38555 Mdot
.78496 .34409 Mdot
.3349 .55954 Mdot
.68448 .42777 Mdot
.61085 .81288 Mdot
.4072 .45062 Mdot
.77273 .43549 Mdot
.35892 .76086 Mdot
.54625 .62303 Mdot
.47666 .4111 Mdot
.31194 .57978 Mdot
.69527 .51782 Mdot
.67547 .52947 Mdot
.50429 .38495 Mdot
.50972 .64681 Mdot
.6355 .42225 Mdot
.60997 .55939 Mdot
.70805 .40467 Mdot
.44187 .4164 Mdot
.76671 .55048 Mdot
.62755 .52908 Mdot
.19151 .62539 Mdot
.6496 .50872 Mdot
.35348 .5789 Mdot
.43869 .34732 Mdot
.35167 .5372 Mdot
.64954 .39705 Mdot
.56643 .48497 Mdot
.50785 .64794 Mdot
.47632 .46842 Mdot
.84569 .58239 Mdot
.6556 .57042 Mdot
.32023 .54379 Mdot
.41123 .41277 Mdot
.56161 .39627 Mdot
.45463 .39786 Mdot
.52099 .4279 Mdot
.61483 .43356 Mdot
.5346 .64092 Mdot
.53589 .66745 Mdot
.4639 .36457 Mdot
.61797 .40719 Mdot
.62102 .54459 Mdot
.65387 .5447 Mdot
.13961 .42724 Mdot
.6125 .62397 Mdot
.64186 .31805 Mdot
.44006 .403 Mdot
.68161 .5742 Mdot
.50348 .78043 Mdot
.52206 .67043 Mdot
.4774 .42369 Mdot
.64274 .57639 Mdot
.76999 .61024 Mdot
.6664 .29753 Mdot
.48153 .38419 Mdot
.42412 .44285 Mdot
.54417 .65592 Mdot
.4969 .24831 Mdot
.69141 .53251 Mdot
.49569 .34011 Mdot
.53042 .68724 Mdot
.68662 .27473 Mdot
.69721 .73973 Mdot
.36522 .55851 Mdot
.71196 .5092 Mdot
.51525 .63598 Mdot
.3851 .38468 Mdot
.63684 .41442 Mdot
.60478 .55378 Mdot
.681 .5569 Mdot
.46464 .34745 Mdot
.40726 .41388 Mdot
.59529 .34767 Mdot
.32746 .54108 Mdot
.50716 .62279 Mdot
.42152 .38517 Mdot
.39343 .6398 Mdot
.42769 .42355 Mdot
.53508 .63199 Mdot
.61231 .87181 Mdot
.4191 .33535 Mdot
.45692 .3981 Mdot
.22154 .36991 Mdot
.35503 .54164 Mdot
.3388 .53266 Mdot
.81429 .52686 Mdot
.44067 .40359 Mdot
.78681 .46887 Mdot
.36553 .55595 Mdot
.33793 .55687 Mdot
.58494 .68762 Mdot
.44404 .36097 Mdot
.42708 .22562 Mdot
.52395 .6765 Mdot
.54339 .63135 Mdot
.32725 .55882 Mdot
.42099 .33062 Mdot
.55216 .63872 Mdot
.31754 .35722 Mdot
.63047 .55226 Mdot
.75451 .32166 Mdot
.34295 .5464 Mdot
.52126 .49551 Mdot
.52758 .6654 Mdot
.29962 .78373 Mdot
.71441 .5955 Mdot
.41812 .37604 Mdot
.44446 .40998 Mdot
.62421 .40344 Mdot
.41574 .33794 Mdot
.69171 .56565 Mdot
.52164 .64364 Mdot
.2007 .44517 Mdot
.36438 .56585 Mdot
.4478 .38892 Mdot
.30819 .66495 Mdot
.43903 .7561 Mdot
.70612 .67648 Mdot
.33334 .57001 Mdot
.35062 .58554 Mdot
.68912 .53143 Mdot
.65667 .52052 Mdot
.47155 .38547 Mdot
.49633 .66342 Mdot
.30714 .57787 Mdot
.53775 .63848 Mdot
.68646 .55847 Mdot
.6547 .53146 Mdot
.6681 .57529 Mdot
.4805 .32105 Mdot
.65058 .52808 Mdot
.70925 .38496 Mdot
.36259 .67122 Mdot
.38315 .55951 Mdot
.77449 .67638 Mdot
.44386 .73336 Mdot
.41142 .50902 Mdot
.66322 .39134 Mdot
.63669 .57007 Mdot
.48527 .66088 Mdot
.47587 .36489 Mdot
.46755 .4092 Mdot
.70312 .57262 Mdot
.49764 .67266 Mdot
.64772 .38887 Mdot
.51085 .68099 Mdot
.64522 .41515 Mdot
.75521 .55436 Mdot
.40409 .37671 Mdot
.49646 .39258 Mdot
.52105 .63906 Mdot
.64513 .53018 Mdot
.66229 .55365 Mdot
.60479 .38328 Mdot
.45833 .49232 Mdot
.66711 .56923 Mdot
.34407 .54744 Mdot
.30724 .41247 Mdot
.61667 .53039 Mdot
.44238 .39494 Mdot
.57053 .22918 Mdot
.34946 .31043 Mdot
.49903 .35301 Mdot
.57799 .70682 Mdot
.46794 .18959 Mdot
.42204 .40301 Mdot
.4773 .17986 Mdot
.60093 .73415 Mdot
.34991 .53864 Mdot
.67248 .52236 Mdot
.69852 .52336 Mdot
.52622 .40626 Mdot
.65488 .36599 Mdot
.39189 .37805 Mdot
.35955 .54464 Mdot
.2972 .59971 Mdot
.77838 .61702 Mdot
.17682 .47658 Mdot
.63684 .37213 Mdot
.65804 .39444 Mdot
.64455 .54031 Mdot
.2514 .29491 Mdot
.40066 .32423 Mdot
.64637 .38451 Mdot
.42514 .24757 Mdot
.47696 .35359 Mdot
.6001 .28968 Mdot
.77653 .51429 Mdot
.32457 .56634 Mdot
.53394 .31419 Mdot
.65299 .5376 Mdot
.33463 .53861 Mdot
.4084 .63497 Mdot
.4186 .3416 Mdot
.3632 .55995 Mdot
.53976 .63965 Mdot
.7167 .62649 Mdot
.37231 .56463 Mdot
.58282 .23607 Mdot
.49356 .65417 Mdot
.58208 .58574 Mdot
.5243 .28582 Mdot
.84492 .34689 Mdot
.51633 .63931 Mdot
.63233 .57676 Mdot
.64075 .5529 Mdot
.65235 .54431 Mdot
.33533 .53673 Mdot
.6174 .55463 Mdot
.32281 .54386 Mdot
.31776 .25368 Mdot
.45414 .49229 Mdot
.64538 .38182 Mdot
.57098 .71691 Mdot
.33889 .58546 Mdot
.81627 .4157 Mdot
.86288 .51325 Mdot
.47402 .41392 Mdot
.48072 .64382 Mdot
.64283 .37682 Mdot
.18115 .57403 Mdot
.62367 .39475 Mdot
.63367 .46557 Mdot
.72475 .28755 Mdot
.45255 .38623 Mdot
.29093 .49278 Mdot
.6632 .40284 Mdot
.32609 .5791 Mdot
.46335 .36725 Mdot
.45524 .66436 Mdot
.62781 .39927 Mdot
.63369 .42046 Mdot
.47136 .37833 Mdot
.35549 .59277 Mdot
.66009 .53388 Mdot
.51038 .68402 Mdot
.62828 .42925 Mdot
.30226 .61972 Mdot
.45155 .32966 Mdot
.44901 .3349 Mdot
.56567 .56003 Mdot
.65349 .35582 Mdot
.52068 .64498 Mdot
.38867 .23795 Mdot
.66098 .52096 Mdot
.64768 .48937 Mdot
.79968 .54569 Mdot
.58054 .71431 Mdot
.63984 .5654 Mdot
.64023 .56965 Mdot
.47819 .38328 Mdot
.65352 .35142 Mdot
.68682 .25734 Mdot
.50413 .71228 Mdot
.62619 .52413 Mdot
.65642 .54564 Mdot
.30562 .6085 Mdot
.78422 .6134 Mdot
.39428 .38306 Mdot
.52228 .61733 Mdot
.6791 .5638 Mdot
.24864 .57876 Mdot
.63547 .40056 Mdot
.79575 .38307 Mdot
.40502 .37859 Mdot
.42099 .38151 Mdot
.51915 .6561 Mdot
.53918 .63253 Mdot
.47492 .60491 Mdot
.80664 .57564 Mdot
.42912 .20956 Mdot
.48013 .74581 Mdot
.26441 .54801 Mdot
.32504 .61228 Mdot
.32251 .59313 Mdot
.55259 .73234 Mdot
.48924 .62569 Mdot
.4243 .40252 Mdot
.30783 .57667 Mdot
.70297 .66179 Mdot
.3949 .59407 Mdot
.61609 .30502 Mdot
.73465 .38412 Mdot
.42951 .34542 Mdot
.31588 .56558 Mdot
.35119 .54179 Mdot
.31272 .59132 Mdot
.59918 .73385 Mdot
.46539 .39217 Mdot
.42184 .36568 Mdot
.42056 .41038 Mdot
.37536 .32321 Mdot
.45311 .419 Mdot
.52916 .71873 Mdot
.54337 .53716 Mdot
.21337 .51175 Mdot
.48583 .33256 Mdot
.54597 .62635 Mdot
.43575 .33543 Mdot
.61961 .40988 Mdot
.47445 .35652 Mdot
.62351 .30619 Mdot
.51132 .66576 Mdot
.27542 .57984 Mdot
.47599 .73922 Mdot
.41051 .36719 Mdot
.64625 .42531 Mdot
.39829 .49876 Mdot
.3948 .79229 Mdot
.66441 .37066 Mdot
.34316 .54754 Mdot
.63058 .55798 Mdot
.48807 .66352 Mdot
.6463 .53392 Mdot
.47147 .31822 Mdot
.56874 .69967 Mdot
.35722 .72825 Mdot
.5466 .48755 Mdot
.45517 .42501 Mdot
.38158 .40818 Mdot
.34165 .55162 Mdot
.62148 .56247 Mdot
.39332 .56383 Mdot
.42954 .40263 Mdot
.64736 .40162 Mdot
.62888 .40326 Mdot
.442 .63179 Mdot
.26085 .69394 Mdot
.46891 .71604 Mdot
.52089 .65392 Mdot
.67407 .5548 Mdot
.63321 .36874 Mdot
.33772 .6378 Mdot
.47038 .64606 Mdot
.49238 .66166 Mdot
.49662 .65059 Mdot
.4818 .34877 Mdot
.65572 .57789 Mdot
.2116 .49827 Mdot
.68488 .57121 Mdot
.42596 .35648 Mdot
.68241 .54657 Mdot
.65105 .57487 Mdot
.62852 .40953 Mdot
.49778 .62939 Mdot
.69041 .54769 Mdot
.49281 .39555 Mdot
.36708 .57415 Mdot
.49937 .49046 Mdot
.63346 .28178 Mdot
.18918 .53248 Mdot
.20392 .5414 Mdot
.37193 .58107 Mdot
.26595 .73222 Mdot
.51165 .61444 Mdot
.40326 .2772 Mdot
.64212 .71683 Mdot
.50139 .38122 Mdot
.82771 .41808 Mdot
.67292 .51764 Mdot
.62601 .57175 Mdot
.48743 .38449 Mdot
.71317 .51775 Mdot
.45063 .39171 Mdot
.68569 .54183 Mdot
.69479 .40067 Mdot
.49775 .43492 Mdot
.62924 .53611 Mdot
.50008 .34262 Mdot
.4459 .35797 Mdot
.32307 .56637 Mdot
.63504 .52449 Mdot
.47337 .42607 Mdot
.14529 .51186 Mdot
.53163 .62745 Mdot
.59554 .71787 Mdot
.56533 .21675 Mdot
.5148 .63481 Mdot
.36134 .5694 Mdot
.38815 .39503 Mdot
.61934 .3936 Mdot
.33408 .58804 Mdot
.67686 .29977 Mdot
.66173 .40471 Mdot
.8249 .4254 Mdot
.33718 .54765 Mdot
.62164 .52747 Mdot
.63311 .41547 Mdot
.5126 .37009 Mdot
.60659 .55794 Mdot
.4298 .51173 Mdot
.63509 .56416 Mdot
.46498 .40264 Mdot
.55979 .73922 Mdot
.51472 .62065 Mdot
.43458 .36847 Mdot
.61184 .56009 Mdot
.57455 .7344 Mdot
.47921 .34789 Mdot
.47816 .37046 Mdot
.75119 .6791 Mdot
.79698 .42028 Mdot
.62581 .38256 Mdot
.30262 .55704 Mdot
.48823 .4011 Mdot
.64341 .42027 Mdot
.72513 .48876 Mdot
.45425 .3325 Mdot
.31389 .60425 Mdot
.38952 .32375 Mdot
.61508 .5397 Mdot
.51597 .62928 Mdot
.54187 .49932 Mdot
.64156 .42197 Mdot
.54377 .13828 Mdot
.68 .57165 Mdot
.48664 .4207 Mdot
.45446 .42697 Mdot
.69218 .70168 Mdot
.34309 .53958 Mdot
.43784 .21174 Mdot
.44728 .40898 Mdot
.36954 .34152 Mdot
.43942 .37835 Mdot
.6322 .47322 Mdot
.33654 .5597 Mdot
.4588 .40141 Mdot
.33566 .65907 Mdot
.50493 .40583 Mdot
.64289 .42385 Mdot
.24517 .33253 Mdot
.46649 .33257 Mdot
.76507 .75243 Mdot
.78156 .4674 Mdot
.63254 .534 Mdot
.5493 .73955 Mdot
.25462 .25618 Mdot
.49173 .73481 Mdot
.31862 .5466 Mdot
.35181 .74929 Mdot
.65423 .53291 Mdot
.51884 .7628 Mdot
.26072 .73303 Mdot
.44801 .35705 Mdot
.42774 .34013 Mdot
.6325 .46517 Mdot
.69653 .56074 Mdot
.59865 .5539 Mdot
.47343 .32197 Mdot
.41696 .31144 Mdot
.66329 .52824 Mdot
.48697 .40726 Mdot
.50139 .33512 Mdot
.50007 .67993 Mdot
.36973 .58221 Mdot
.53538 .65651 Mdot
.49096 .6386 Mdot
.30414 .32027 Mdot
.79741 .58372 Mdot
.53037 .62854 Mdot
.51654 .61493 Mdot
.60688 .29087 Mdot
.57884 .34644 Mdot
.65889 .37956 Mdot
.2261 .64986 Mdot
.65083 .54662 Mdot
.46391 .38945 Mdot
.37586 .57352 Mdot
.37253 .277 Mdot
.76332 .47124 Mdot
.69844 .26318 Mdot
.42734 .4035 Mdot
.65653 .5405 Mdot
.59904 .73574 Mdot
.48357 .31399 Mdot
.62193 .50049 Mdot
.41803 .38182 Mdot
.61866 .57523 Mdot
.29664 .44986 Mdot
.28704 .65267 Mdot
.59614 .54532 Mdot
.36834 .60843 Mdot
.42724 .38569 Mdot
.34445 .54497 Mdot
.53158 .65707 Mdot
.62066 .40677 Mdot
.62794 .38276 Mdot
.47027 .37159 Mdot
.37481 .40927 Mdot
.7563 .54841 Mdot
.44018 .35732 Mdot
.46694 .35261 Mdot
.601 .73431 Mdot
.4659 .35435 Mdot
.44638 .42593 Mdot
.43226 .42183 Mdot
.47663 .43521 Mdot
.53603 .62552 Mdot
.30886 .66399 Mdot
.45319 .31084 Mdot
.49396 .3234 Mdot
.53315 .68115 Mdot
.38946 .77839 Mdot
.48866 .63724 Mdot
.32271 .77598 Mdot
.53472 .66521 Mdot
.63807 .38206 Mdot
.61685 .74982 Mdot
.3797 .41391 Mdot
.33851 .60237 Mdot
.47352 .64263 Mdot
.64938 .40912 Mdot
.52614 .6488 Mdot
.68001 .53662 Mdot
.64231 .78673 Mdot
.33057 .62666 Mdot
.47533 .21233 Mdot
.44132 .63969 Mdot
.6305 .63319 Mdot
.6911 .55614 Mdot
.33226 .55867 Mdot
.33894 .4569 Mdot
.43644 .42575 Mdot
.64339 .41931 Mdot
.47364 .38215 Mdot
.52379 .61946 Mdot
.65134 .53981 Mdot
.24649 .32605 Mdot
.61856 .38926 Mdot
.77833 .66049 Mdot
.65488 .55386 Mdot
.41781 .41317 Mdot
.5247 .61822 Mdot
.80639 .64189 Mdot
.53622 .64846 Mdot
.41864 .47799 Mdot
.35931 .60719 Mdot
.328 .27537 Mdot
.34471 .58312 Mdot
.65875 .5118 Mdot
.65085 .80941 Mdot
.21397 .60752 Mdot
.3599 .58777 Mdot
.66141 .62048 Mdot
.43943 .33842 Mdot
.44566 .33489 Mdot
.27387 .62978 Mdot
.30067 .56794 Mdot
.47017 .41631 Mdot
.6049 .72497 Mdot
.36863 .68957 Mdot
.78649 .44499 Mdot
.62867 .56397 Mdot
.44965 .39715 Mdot
.53329 .6835 Mdot
.5093 .67999 Mdot
.67849 .57461 Mdot
.48632 .63903 Mdot
.42333 .36567 Mdot
.34069 .58445 Mdot
.6064 .57062 Mdot
.63665 .38887 Mdot
.15775 .4685 Mdot
.63122 .3669 Mdot
.64112 .56547 Mdot
.49776 .43097 Mdot
.65428 .53122 Mdot
.31329 .186 Mdot
.42195 .37136 Mdot
.36215 .55253 Mdot
.48461 .36812 Mdot
.42967 .38282 Mdot
.42976 .33851 Mdot
.67239 .53135 Mdot
.47113 .19959 Mdot
.49038 .40231 Mdot
.50639 .64737 Mdot
.22576 .53823 Mdot
.43061 .33666 Mdot
.68687 .4137 Mdot
.5889 .32144 Mdot
.69903 .6141 Mdot
.37586 .58424 Mdot
.62198 .54975 Mdot
.36453 .57282 Mdot
.38184 .606 Mdot
.36134 .56887 Mdot
.24242 .51908 Mdot
.32919 .45574 Mdot
.51094 .19013 Mdot
.23616 .37552 Mdot
.47047 .28163 Mdot
.30141 .56176 Mdot
.60142 .43611 Mdot
.31751 .59145 Mdot
.34579 .54199 Mdot
.41448 .90485 Mdot
.33563 .60011 Mdot
.444 .40028 Mdot
.40896 .35461 Mdot
.4143 .73927 Mdot
.57564 .27016 Mdot
.46698 .36052 Mdot
.49101 .38994 Mdot
.62239 .40657 Mdot
.37107 .41587 Mdot
.56916 .7005 Mdot
.82277 .45827 Mdot
.46034 .76406 Mdot
.4732 .37955 Mdot
.49098 .39684 Mdot
.44715 .30331 Mdot
.79733 .68617 Mdot
.32183 .31569 Mdot
.29703 .57624 Mdot
.38452 .37314 Mdot
.17836 .53676 Mdot
.41229 .37287 Mdot
.48326 .34609 Mdot
.43153 .34325 Mdot
.65411 .53329 Mdot
.32152 .60964 Mdot
.38907 .35662 Mdot
.78735 .53299 Mdot
.41336 .36227 Mdot
.57893 .7164 Mdot
.33531 .21244 Mdot
.45146 .40238 Mdot
.34561 .60566 Mdot
.46026 .34069 Mdot
.33249 .54706 Mdot
.32004 .57668 Mdot
.49682 .42678 Mdot
.25406 .54733 Mdot
.33649 .60984 Mdot
.42646 .35542 Mdot
.66708 .53486 Mdot
.2177 .65215 Mdot
.46385 .40483 Mdot
.61535 .38571 Mdot
.44436 .40871 Mdot
.64277 .42719 Mdot
.4591 .35205 Mdot
.67468 .57658 Mdot
.34406 .34984 Mdot
.63991 .54188 Mdot
.36863 .21586 Mdot
.65373 .57974 Mdot
.7578 .67311 Mdot
.30124 .59097 Mdot
.56468 .73427 Mdot
.62907 .19392 Mdot
.58907 .71285 Mdot
.50362 .57157 Mdot
.4929 .55712 Mdot
.49553 .6627 Mdot
.35656 .5385 Mdot
.46353 .24454 Mdot
.70303 .67328 Mdot
.67634 .70699 Mdot
.6605 .57374 Mdot
.62616 .17813 Mdot
.72671 .27741 Mdot
.49459 .37551 Mdot
.27212 .5033 Mdot
.23949 .43081 Mdot
.46145 .33262 Mdot
.38751 .39667 Mdot
.6903 .58177 Mdot
.46192 .42654 Mdot
.38455 .64259 Mdot
.64816 .56464 Mdot
.6488 .41138 Mdot
.35125 .54756 Mdot
.62467 .42047 Mdot
.694 .68446 Mdot
.48793 .56044 Mdot
.68724 .54883 Mdot
.49484 .41993 Mdot
.48783 .37476 Mdot
.32338 .55954 Mdot
.36842 .51803 Mdot
.33867 .59647 Mdot
.63453 .37307 Mdot
.6485 .5614 Mdot
.34513 .30037 Mdot
.48561 .39847 Mdot
.33554 .57857 Mdot
.46616 .59756 Mdot
.48438 .40454 Mdot
.52579 .64035 Mdot
.42335 .35029 Mdot
.36579 .58144 Mdot
.46554 .35435 Mdot
.34231 .58582 Mdot
.62878 .55458 Mdot
.40906 .37919 Mdot
.48518 .38556 Mdot
.79173 .6573 Mdot
.6462 .38853 Mdot
.29966 .57573 Mdot
.71789 .51868 Mdot
.43377 .42803 Mdot
.62258 .6582 Mdot
.42666 .38961 Mdot
.40156 .55951 Mdot
.49566 .41337 Mdot
.59001 .7352 Mdot
.3965 .38448 Mdot
.46324 .40428 Mdot
.44232 .59351 Mdot
.23734 .46293 Mdot
.36265 .51319 Mdot
.53536 .6216 Mdot
.32371 .60264 Mdot
.75376 .40572 Mdot
.64281 .51766 Mdot
.61639 .5564 Mdot
.52045 .24302 Mdot
.45658 .44307 Mdot
.45424 .38694 Mdot
.51398 .68974 Mdot
.65782 .40492 Mdot
.33259 .57215 Mdot
.64585 .41425 Mdot
.79893 .53567 Mdot
.65188 .38088 Mdot
.70204 .53334 Mdot
.76297 .54589 Mdot
.3306 .3347 Mdot
.6229 .40673 Mdot
.35429 .59424 Mdot
.72745 .38558 Mdot
.5041 .37656 Mdot
.58789 .37437 Mdot
.64595 .40144 Mdot
.61183 .1636 Mdot
.45005 .42532 Mdot
.51541 .57097 Mdot
.52623 .6294 Mdot
.63466 .41377 Mdot
.50267 .66551 Mdot
.46943 .36343 Mdot
.61415 .64435 Mdot
.30897 .55567 Mdot
.55295 .65169 Mdot
.45364 .32553 Mdot
.6465 .38005 Mdot
.67768 .56369 Mdot
.4831 .61101 Mdot
.54943 .63364 Mdot
.35356 .76389 Mdot
.28529 .29027 Mdot
.64782 .55997 Mdot
.74006 .33959 Mdot
.52825 .67456 Mdot
.4763 .33864 Mdot
.36216 .37952 Mdot
.41768 .37562 Mdot
.50344 .72564 Mdot
.62092 .55344 Mdot
.36652 .70822 Mdot
.48737 .37036 Mdot
.42708 .41176 Mdot
.34738 .51484 Mdot
.6399 .54878 Mdot
.3491 .56707 Mdot
.32377 .60074 Mdot
.62985 .55411 Mdot
.35184 .57867 Mdot
.66175 .40873 Mdot
.38128 .68849 Mdot
.53762 .66965 Mdot
.50595 .65127 Mdot
.65554 .54483 Mdot
.64244 .5292 Mdot
.64697 .53129 Mdot
.42295 .35075 Mdot
.3342 .56572 Mdot
.44355 .34655 Mdot
.43012 .33884 Mdot
.29746 .52584 Mdot
.37133 .58637 Mdot
.44458 .34015 Mdot
.64494 .50322 Mdot
.59512 .36973 Mdot
.67057 .53592 Mdot
.52653 .62746 Mdot
.52247 .77997 Mdot
.5481 .61759 Mdot
.44734 .39499 Mdot
.76837 .60904 Mdot
.35078 .5936 Mdot
.62325 .39929 Mdot
.66836 .40393 Mdot
.6228 .39011 Mdot
.54194 .68876 Mdot
.30399 .5815 Mdot
.82298 .4553 Mdot
.45151 .39481 Mdot
.56626 .56253 Mdot
.4349 .2395 Mdot
.76349 .56978 Mdot
.52606 .62614 Mdot
.48851 .39937 Mdot
.53677 .49644 Mdot
.3416 .43581 Mdot
.42132 .37955 Mdot
.50752 .36975 Mdot
.61836 .70849 Mdot
.41137 .30394 Mdot
.35 .60973 Mdot
.81665 .56435 Mdot
.40282 .35648 Mdot
.26247 .60721 Mdot
.16857 .38899 Mdot
.44061 .38977 Mdot
.43287 .41005 Mdot
.47469 .40175 Mdot
.479 .35723 Mdot
.34977 .60614 Mdot
.52861 .26417 Mdot
.50628 .61598 Mdot
.56915 .53374 Mdot
.54262 .66453 Mdot
.61371 .56948 Mdot
.33207 .66976 Mdot
.36288 .54116 Mdot
.6236 .40283 Mdot
.25618 .647 Mdot
.82587 .51689 Mdot
.68777 .52928 Mdot
.30984 .37271 Mdot
.64526 .39404 Mdot
.48349 .34228 Mdot
.65029 .42905 Mdot
.65246 .57837 Mdot
.50068 .64369 Mdot
.44132 .44577 Mdot
.3292 .59544 Mdot
.37207 .56095 Mdot
.47217 .41496 Mdot
.19263 .56694 Mdot
.52347 .63613 Mdot
.4696 .63251 Mdot
.47232 .34086 Mdot
.50394 .35385 Mdot
.35217 .56539 Mdot
.66817 .54991 Mdot
.70375 .33518 Mdot
.65511 .39611 Mdot
.43761 .43384 Mdot
.47663 .35458 Mdot
.80834 .57085 Mdot
.50312 .63118 Mdot
.69583 .53155 Mdot
.4845 .35322 Mdot
.51826 .74195 Mdot
.48387 .35302 Mdot
.45964 .30033 Mdot
.66556 .53612 Mdot
.42423 .31594 Mdot
.49506 .39523 Mdot
.47678 .46297 Mdot
.51457 .67436 Mdot
.36122 .55462 Mdot
.38474 .55836 Mdot
.59036 .46418 Mdot
.52703 .64291 Mdot
.45138 .33978 Mdot
.50793 .63074 Mdot
.44227 .33374 Mdot
.47143 .4176 Mdot
.53456 .63169 Mdot
.34927 .5678 Mdot
.37257 .75392 Mdot
.31764 .66719 Mdot
.48114 .35923 Mdot
.4003 .36734 Mdot
.54792 .26215 Mdot
.55947 .19047 Mdot
.42675 .39794 Mdot
.36939 .57267 Mdot
.48785 .39227 Mdot
.50928 .66839 Mdot
.65905 .38821 Mdot
.36663 .57691 Mdot
.66509 .55713 Mdot
.69432 .53981 Mdot
.47636 .73796 Mdot
.64501 .57336 Mdot
.49995 .36538 Mdot
.37486 .61319 Mdot
.35674 .52695 Mdot
.15931 .42509 Mdot
.63256 .55322 Mdot
.66501 .40823 Mdot
.47559 .36962 Mdot
.75329 .65748 Mdot
.50756 .68799 Mdot
.80175 .72005 Mdot
.82478 .43537 Mdot
.62572 .36732 Mdot
.67349 .23518 Mdot
.60708 .56587 Mdot
.47572 .41941 Mdot
.61999 .40683 Mdot
.6826 .52685 Mdot
.499 .37276 Mdot
.43685 .44804 Mdot
.44679 .20679 Mdot
.57744 .47505 Mdot
.50877 .62902 Mdot
.62464 .53392 Mdot
.66955 .42193 Mdot
.70207 .54217 Mdot
.37265 .55783 Mdot
.46259 .40091 Mdot
.40744 .44899 Mdot
.66806 .55391 Mdot
.69816 .55719 Mdot
.42985 .34718 Mdot
.35359 .53749 Mdot
.70692 .56371 Mdot
.46827 .37487 Mdot
.44742 .27835 Mdot
.3628 .61102 Mdot
.65319 .5658 Mdot
.4292 .41738 Mdot
.61626 .34458 Mdot
.65874 .55189 Mdot
.67229 .53685 Mdot
.47268 .41553 Mdot
.6604 .41168 Mdot
.40375 .38974 Mdot
.53815 .65991 Mdot
.42819 .19532 Mdot
.50488 .66454 Mdot
.74136 .41586 Mdot
.51131 .40852 Mdot
.58971 .6228 Mdot
.37444 .55647 Mdot
.67626 .41001 Mdot
.54771 .78921 Mdot
.4824 .32574 Mdot
.2579 .70498 Mdot
.51821 .50324 Mdot
.16941 .53916 Mdot
.52868 .81908 Mdot
.64237 .40292 Mdot
.5281 .65273 Mdot
.4331 .40956 Mdot
.4806 .65549 Mdot
.61519 .397 Mdot
.35095 .24391 Mdot
.43388 .42113 Mdot
.33803 .55801 Mdot
.42345 .35476 Mdot
.34242 .54703 Mdot
.4791 .40986 Mdot
.47796 .31304 Mdot
.60306 .74324 Mdot
.66381 .29648 Mdot
.50217 .38187 Mdot
.65755 .78387 Mdot
.76929 .49886 Mdot
.65092 .40174 Mdot
.44049 .35072 Mdot
.6614 .51365 Mdot
.50409 .67638 Mdot
.40326 .60258 Mdot
.65648 .5325 Mdot
.49513 .62645 Mdot
.35639 .56908 Mdot
.62759 .56006 Mdot
.6959 .55207 Mdot
.40165 .3422 Mdot
.63577 .42473 Mdot
.49574 .64401 Mdot
.45851 .40517 Mdot
.44172 .42291 Mdot
.74254 .35521 Mdot
.7534 .46371 Mdot
.37277 .52929 Mdot
.83755 .58911 Mdot
.37631 .54049 Mdot
.6491 .38741 Mdot
.66216 .53286 Mdot
.42805 .39453 Mdot
.43582 .36658 Mdot
.56808 .73625 Mdot
.30713 .5558 Mdot
.56481 .48349 Mdot
.29306 .34668 Mdot
.70326 .56618 Mdot
.58122 .30262 Mdot
.36283 .55067 Mdot
.58098 .30061 Mdot
.66732 .42384 Mdot
.24579 .65146 Mdot
.65339 .30176 Mdot
.52271 .62774 Mdot
.57622 .3011 Mdot
.32685 .58247 Mdot
.4926 .37468 Mdot
.63088 .52336 Mdot
.65154 .57434 Mdot
.35444 .55646 Mdot
.65575 .58928 Mdot
.63071 .40974 Mdot
.437 .41507 Mdot
.81246 .44666 Mdot
.42905 .71059 Mdot
.67517 .55106 Mdot
.49791 .32294 Mdot
.49766 .65302 Mdot
.4664 .4213 Mdot
.6169 .38351 Mdot
.51195 .63956 Mdot
.77474 .4493 Mdot
.36782 .69834 Mdot
.4691 .36798 Mdot
.77184 .64496 Mdot
.52236 .64087 Mdot
.6404 .22153 Mdot
.468 .3819 Mdot
.52701 .67479 Mdot
.40117 .3193 Mdot
.72895 .60281 Mdot
.54181 .48651 Mdot
.25772 .73145 Mdot
.55278 .49177 Mdot
.60701 .54304 Mdot
.70118 .63622 Mdot
.6709 .68615 Mdot
.48322 .65986 Mdot
.69939 .55356 Mdot
.66785 .36012 Mdot
.50206 .66556 Mdot
.42529 .34057 Mdot
.4321 .3889 Mdot
.32307 .30596 Mdot
.51198 .51249 Mdot
.68918 .5135 Mdot
.44185 .67947 Mdot
.43121 .42653 Mdot
.41151 .33733 Mdot
.44371 .36869 Mdot
.29855 .60136 Mdot
.50283 .63632 Mdot
.73103 .7233 Mdot
.5296 .64421 Mdot
.78991 .38089 Mdot
.65053 .54526 Mdot
.61985 .5454 Mdot
.44908 .39988 Mdot
.58837 .59378 Mdot
.54851 .31145 Mdot
.42431 .3633 Mdot
.58429 .56027 Mdot
.22967 .35032 Mdot
.44058 .32823 Mdot
.36618 .6033 Mdot
.52832 .39291 Mdot
.30546 .61426 Mdot
.53647 .67217 Mdot
.63587 .39773 Mdot
.67684 .39608 Mdot
.49851 .64187 Mdot
.45409 .38504 Mdot
.58553 .63999 Mdot
.43114 .37799 Mdot
.49152 .36569 Mdot
.78819 .36483 Mdot
.62728 .36814 Mdot
.63126 .53924 Mdot
.62309 .38472 Mdot
.34319 .5409 Mdot
.60336 .88797 Mdot
.65663 .40835 Mdot
.54484 .31362 Mdot
.37651 .2224 Mdot
.57336 .29779 Mdot
.36969 .55395 Mdot
.60837 .40821 Mdot
.51931 .63122 Mdot
.18346 .61693 Mdot
.53051 .17908 Mdot
.49808 .60803 Mdot
.46245 .37405 Mdot
.35399 .53496 Mdot
.3622 .59052 Mdot
.55193 .65285 Mdot
.32187 .57782 Mdot
.38449 .35266 Mdot
.48724 .36512 Mdot
.48099 .65124 Mdot
.42746 .73421 Mdot
.54946 .63324 Mdot
.37982 .66736 Mdot
.43525 .35079 Mdot
.36763 .55755 Mdot
.52595 .39825 Mdot
.28628 .57824 Mdot
.69507 .52879 Mdot
.47133 .33387 Mdot
.62862 .40863 Mdot
.57717 .6194 Mdot
.65055 .55886 Mdot
.76444 .61215 Mdot
.32589 .55685 Mdot
.52121 .58809 Mdot
.32181 .56868 Mdot
.30908 .5443 Mdot
.48963 .64095 Mdot
.30891 .56216 Mdot
.43346 .41155 Mdot
.63745 .51157 Mdot
.3251 .5494 Mdot
.51503 .66144 Mdot
.63185 .39259 Mdot
.35024 .57629 Mdot
.71631 .52077 Mdot
.48094 .3765 Mdot
.67894 .53017 Mdot
.62698 .74397 Mdot
.33597 .53231 Mdot
.6045 .39567 Mdot
.62048 .56214 Mdot
.62822 .41966 Mdot
.2028 .37401 Mdot
.48715 .62689 Mdot
.7083 .27758 Mdot
.61828 .34668 Mdot
.34104 .5996 Mdot
.61747 .74483 Mdot
.4312 .39497 Mdot
.48025 .37387 Mdot
.62969 .42674 Mdot
.36172 .59095 Mdot
.20872 .61619 Mdot
.35509 .50491 Mdot
.38019 .70043 Mdot
.47965 .63277 Mdot
.72919 .71114 Mdot
.36861 .6573 Mdot
.27973 .2647 Mdot
.43796 .32092 Mdot
.60347 .56265 Mdot
.44677 .38471 Mdot
.5324 .78805 Mdot
.64166 .37646 Mdot
.66617 .45006 Mdot
.50522 .41117 Mdot
.62535 .55003 Mdot
.47662 .39216 Mdot
.43774 .56246 Mdot
.5211 .35765 Mdot
.66421 .39824 Mdot
.56404 .71424 Mdot
.33357 .60172 Mdot
.63961 .38999 Mdot
.68138 .56806 Mdot
.56139 .31212 Mdot
.50002 .38925 Mdot
.46438 .31581 Mdot
.7075 .55914 Mdot
.33376 .55922 Mdot
.61518 .53617 Mdot
.53627 .6706 Mdot
.63278 .40485 Mdot
.47726 .36496 Mdot
.49592 .41526 Mdot
.62396 .65946 Mdot
.49378 .64441 Mdot
.67547 .5853 Mdot
.53522 .64974 Mdot
.60018 .55269 Mdot
.39941 .37789 Mdot
.61895 .54715 Mdot
.4849 .41566 Mdot
.57494 .77555 Mdot
.78365 .36089 Mdot
.24703 .47493 Mdot
.62246 .55797 Mdot
.60989 .31626 Mdot
.51386 .66754 Mdot
.53411 .66376 Mdot
.35979 .26091 Mdot
.38142 .45453 Mdot
.76964 .40504 Mdot
.37131 .78166 Mdot
.54185 .66493 Mdot
.50242 .65854 Mdot
.68107 .52984 Mdot
.31191 .55661 Mdot
.32645 .53167 Mdot
.61577 .57285 Mdot
.56364 .22374 Mdot
.33266 .57228 Mdot
.24358 .67357 Mdot
.7675 .41836 Mdot
.38986 .36086 Mdot
.46974 .60986 Mdot
.62952 .4002 Mdot
.58171 .2383 Mdot
.43784 .57387 Mdot
.42732 .40922 Mdot
.80484 .58062 Mdot
.66498 .54608 Mdot
.50156 .24232 Mdot
.32557 .77679 Mdot
.43765 .42355 Mdot
.46528 .38798 Mdot
.4495 .37796 Mdot
.61665 .37198 Mdot
.3494 .36777 Mdot
.43726 .41983 Mdot
.56214 .22103 Mdot
.43546 .42988 Mdot
.54866 .42006 Mdot
.62636 .38298 Mdot
.55091 .38125 Mdot
.61008 .722 Mdot
.80212 .51523 Mdot
.49429 .44527 Mdot
.53589 .66942 Mdot
.58174 .51225 Mdot
.51445 .676 Mdot
.24112 .51068 Mdot
.64697 .29831 Mdot
.38322 .58255 Mdot
.42884 .40869 Mdot
.64236 .56578 Mdot
.36405 .58855 Mdot
.67237 .65833 Mdot
.48325 .93092 Mdot
.52988 .67654 Mdot
.34631 .17865 Mdot
.53668 .65732 Mdot
.69372 .55838 Mdot
.35332 .56436 Mdot
.32335 .45422 Mdot
.56391 .55923 Mdot
.34941 .579 Mdot
.36215 .73641 Mdot
.32574 .52331 Mdot
.59206 .31372 Mdot
.36842 .53591 Mdot
.51514 .66393 Mdot
.55503 .66607 Mdot
.40262 .4364 Mdot
.4397 .40078 Mdot
.483 .55988 Mdot
.5702 .33425 Mdot
.43487 .39814 Mdot
.6475 .56334 Mdot
.62434 .20554 Mdot
.60379 .45915 Mdot
.31195 .57824 Mdot
.5372 .61669 Mdot
.46771 .38958 Mdot
.48036 .35283 Mdot
.49882 .38209 Mdot
.84452 .58754 Mdot
.23448 .64185 Mdot
.49029 .40206 Mdot
.42238 .42423 Mdot
.62637 .55782 Mdot
.64222 .4396 Mdot
.5126 .79492 Mdot
.51104 .45781 Mdot
.41477 .3905 Mdot
.63759 .38488 Mdot
.63617 .36504 Mdot
.49925 .37203 Mdot
.78425 .53161 Mdot
.60894 .62701 Mdot
.45899 .40538 Mdot
.40658 .46881 Mdot
.69087 .67893 Mdot
.69715 .5583 Mdot
.66523 .55416 Mdot
.34289 .60534 Mdot
.64812 .57139 Mdot
.65618 .58012 Mdot
.32608 .4311 Mdot
.55423 .50785 Mdot
.51981 .70042 Mdot
.63388 .37292 Mdot
.43327 .36912 Mdot
.36356 .52584 Mdot
.53723 .7355 Mdot
.493 .65666 Mdot
.35254 .5887 Mdot
.50903 .67883 Mdot
.60638 .37359 Mdot
.47034 .21744 Mdot
.65744 .57578 Mdot
.54811 .65138 Mdot
.36785 .69716 Mdot
.63453 .38369 Mdot
.49729 .62789 Mdot
.59226 .63934 Mdot
.42608 .33848 Mdot
.30328 .50473 Mdot
.42734 .35887 Mdot
.18818 .58067 Mdot
.50005 .6271 Mdot
.58641 .73404 Mdot
.45724 .39253 Mdot
.6551 .55249 Mdot
.43902 .29903 Mdot
.41721 .3823 Mdot
.66762 .56071 Mdot
.49437 .37581 Mdot
.61205 .39828 Mdot
.34917 .61906 Mdot
.57176 .51315 Mdot
.78217 .29658 Mdot
.63308 .4244 Mdot
.66101 .65794 Mdot
.42667 .39996 Mdot
.2534 .31795 Mdot
.34848 .57698 Mdot
.4889 .41614 Mdot
.51328 .29329 Mdot
.32526 .54441 Mdot
.36071 .57981 Mdot
.46253 .34579 Mdot
.52673 .63129 Mdot
.654 .56007 Mdot
.62875 .38375 Mdot
.20324 .35918 Mdot
.45523 .36702 Mdot
.48668 .38817 Mdot
.64347 .39266 Mdot
.50297 .66145 Mdot
.47625 .34814 Mdot
.63659 .75381 Mdot
.15024 .51643 Mdot
.49004 .65734 Mdot
.41165 .35757 Mdot
.32587 .50226 Mdot
.303 .61617 Mdot
.43773 .16342 Mdot
.70071 .35636 Mdot
.62617 .54079 Mdot
.40217 .31236 Mdot
.68177 .82544 Mdot
.63397 .39657 Mdot
.81552 .48245 Mdot
.49139 .36214 Mdot
.48082 .40244 Mdot
.3421 .59554 Mdot
.44235 .34342 Mdot
.32658 .53922 Mdot
.74756 .26682 Mdot
.81021 .58833 Mdot
.33468 .55283 Mdot
.33064 .59743 Mdot
.53566 .31203 Mdot
.51625 .79342 Mdot
.35665 .55762 Mdot
.40779 .4133 Mdot
.22657 .57976 Mdot
.50185 .45305 Mdot
.63364 .4287 Mdot
.65423 .72167 Mdot
.27765 .58436 Mdot
.62193 .45482 Mdot
.36196 .76141 Mdot
.27488 .58708 Mdot
.62806 .62157 Mdot
.54097 .6555 Mdot
.42608 .41929 Mdot
.64825 .57424 Mdot
.61676 .55495 Mdot
.52062 .36513 Mdot
.4283 .37387 Mdot
.3348 .54589 Mdot
.63825 .37108 Mdot
.49095 .66849 Mdot
.49087 .38891 Mdot
.60732 .46114 Mdot
.656 .40463 Mdot
.31305 .56835 Mdot
.3984 .25361 Mdot
.66548 .40303 Mdot
.52536 .35602 Mdot
.45166 .41168 Mdot
.42975 .3452 Mdot
.4663 .47003 Mdot
.53537 .62833 Mdot
.6117 .75208 Mdot
.40481 .37117 Mdot
.79985 .53657 Mdot
.47577 .49088 Mdot
.42178 .31404 Mdot
.32711 .57189 Mdot
.5082 .68879 Mdot
.67845 .51664 Mdot
.47999 .2566 Mdot
.4633 .36677 Mdot
.2329 .62737 Mdot
.31002 .32388 Mdot
.68232 .52065 Mdot
.30186 .56179 Mdot
.62296 .39674 Mdot
.42475 .36534 Mdot
.23651 .54135 Mdot
.43704 .39046 Mdot
.6106 .3551 Mdot
.67028 .5398 Mdot
.5413 .65258 Mdot
.16459 .53363 Mdot
.61677 .55399 Mdot
.36381 .57478 Mdot
.27371 .76764 Mdot
.36154 .53448 Mdot
.31468 .59174 Mdot
.24762 .55151 Mdot
.54087 .63457 Mdot
.70655 .81092 Mdot
.50544 .1693 Mdot
.51037 .36667 Mdot
.51797 .66998 Mdot
.34882 .55469 Mdot
.4641 .42164 Mdot
.37817 .56253 Mdot
.30177 .5777 Mdot
.40154 .34823 Mdot
.46684 .41231 Mdot
.33459 .66645 Mdot
.27837 .74096 Mdot
.62109 .39357 Mdot
.35439 .54096 Mdot
.44098 .26936 Mdot
.45891 .42484 Mdot
.45206 .39539 Mdot
.69533 .66435 Mdot
.66204 .41001 Mdot
.40116 .62554 Mdot
.4873 .35766 Mdot
.79755 .6137 Mdot
.52807 .39553 Mdot
.35026 .6068 Mdot
.48956 .65336 Mdot
.80092 .50731 Mdot
.4888 .71407 Mdot
.31038 .551 Mdot
.62248 .37707 Mdot
.38471 .55538 Mdot
.5478 .31761 Mdot
.54587 .63307 Mdot
.36577 .5815 Mdot
.54104 .49878 Mdot
.51464 .64666 Mdot
.5045 .62615 Mdot
.22608 .54077 Mdot
.65766 .5858 Mdot
.61027 .38076 Mdot
.49665 .64752 Mdot
.40582 .27719 Mdot
.5228 .66036 Mdot
.36462 .27325 Mdot
.40828 .37608 Mdot
.52226 .22678 Mdot
.51285 .57804 Mdot
.38028 .41101 Mdot
.51808 .62006 Mdot
.61593 .39436 Mdot
.46943 .34659 Mdot
.32277 .58177 Mdot
.65057 .41348 Mdot
.4952 .60199 Mdot
.66341 .52905 Mdot
.31974 .56805 Mdot
.49005 .62006 Mdot
.35797 .54523 Mdot
.46994 .24421 Mdot
.41101 .19811 Mdot
.67993 .7293 Mdot
.56131 .55187 Mdot
.49823 .37812 Mdot
.4286 .79458 Mdot
.39243 .3652 Mdot
.42486 .37694 Mdot
.65258 .56491 Mdot
.51639 .24054 Mdot
.34957 .56678 Mdot
.16424 .54203 Mdot
.54564 .65415 Mdot
.81759 .56933 Mdot
.39285 .53966 Mdot
.4925 .41345 Mdot
.32671 .54721 Mdot
.3655 .5359 Mdot
.23263 .46064 Mdot
.70173 .52744 Mdot
.41168 .43207 Mdot
.40036 .4238 Mdot
.44427 .31507 Mdot
.50726 .62655 Mdot
.76751 .60274 Mdot
.6053 .55085 Mdot
.4099 .18658 Mdot
.67282 .54382 Mdot
.58189 .55543 Mdot
.30917 .56547 Mdot
.65724 .41074 Mdot
.45307 .39762 Mdot
.38287 .51869 Mdot
.3103 .54976 Mdot
.59615 .37321 Mdot
.63367 .41465 Mdot
.72542 .61878 Mdot
.53406 .63078 Mdot
.50311 .38641 Mdot
.42987 .41725 Mdot
.44676 .34819 Mdot
.41851 .36149 Mdot
.53224 .67591 Mdot
.4569 .33558 Mdot
.53707 .68412 Mdot
.39535 .27674 Mdot
.80121 .59241 Mdot
.55058 .50628 Mdot
.4115 .56036 Mdot
.31772 .5824 Mdot
.41734 .27856 Mdot
.52493 .35205 Mdot
.76075 .33278 Mdot
.18478 .45448 Mdot
.44923 .32762 Mdot
.67759 .52401 Mdot
.37717 .44908 Mdot
.64363 .57767 Mdot
.41729 .13774 Mdot
.61871 .66606 Mdot
.25898 .72318 Mdot
.44998 .42262 Mdot
.69748 .66589 Mdot
.37527 .32642 Mdot
.38992 .38583 Mdot
.65512 .67255 Mdot
.4885 .72697 Mdot
.39273 .73701 Mdot
.64972 .37119 Mdot
.4766 .37737 Mdot
.34482 .52265 Mdot
.43421 .41357 Mdot
.44863 .39069 Mdot
.49142 .35997 Mdot
.51537 .61611 Mdot
.42816 .43996 Mdot
.41988 .35218 Mdot
.74695 .53381 Mdot
.6061 .29582 Mdot
.62139 .53533 Mdot
.35523 .25895 Mdot
.65514 .40894 Mdot
.32812 .55054 Mdot
.30581 .70078 Mdot
.52244 .62731 Mdot
.23388 .44482 Mdot
.42233 .3532 Mdot
.347 .68032 Mdot
.48248 .62467 Mdot
.63222 .40713 Mdot
.61241 .53382 Mdot
.23231 .69178 Mdot
.63924 .56233 Mdot
.53556 .50055 Mdot
.65014 .55394 Mdot
.53113 .40255 Mdot
.33604 .54529 Mdot
.49413 .36043 Mdot
.49854 .64808 Mdot
.65988 .56623 Mdot
.56224 .26339 Mdot
.4443 .37033 Mdot
.62954 .55277 Mdot
.49305 .35913 Mdot
.48131 .21365 Mdot
.71767 .31682 Mdot
.6661 .57947 Mdot
.52912 .69318 Mdot
.51408 .65224 Mdot
.66106 .40879 Mdot
.31963 .55999 Mdot
.3386 .59393 Mdot
.5139 .64077 Mdot
.55911 .18291 Mdot
.41553 .38892 Mdot
.45988 .42293 Mdot
.80247 .53537 Mdot
.4341 .40504 Mdot
.57798 .32002 Mdot
.5388 .49415 Mdot
.31358 .5749 Mdot
.47727 .41656 Mdot
.47886 .35338 Mdot
.47255 .36901 Mdot
.45617 .23819 Mdot
.67097 .55126 Mdot
.41531 .40443 Mdot
.63156 .41611 Mdot
.64637 .51394 Mdot
.46447 .42304 Mdot
.4453 .31393 Mdot
.3405 .59377 Mdot
.8374 .54175 Mdot
.53831 .64826 Mdot
.68796 .56062 Mdot
.62039 .54906 Mdot
.65847 .71822 Mdot
.27467 .55751 Mdot
.54234 .49237 Mdot
.38854 .19355 Mdot
.60333 .73214 Mdot
.649 .39555 Mdot
.57887 .59994 Mdot
.50595 .48187 Mdot
.69038 .53752 Mdot
.51926 .68077 Mdot
.40677 .37134 Mdot
.41323 .38785 Mdot
.82157 .41272 Mdot
.49673 .40929 Mdot
.62566 .39703 Mdot
.54274 .67547 Mdot
.32815 .5824 Mdot
.63025 .40639 Mdot
.53414 .66077 Mdot
.33199 .56091 Mdot
.41857 .3399 Mdot
.41106 .3459 Mdot
.35241 .58742 Mdot
.35808 .5923 Mdot
.45478 .40732 Mdot
.59165 .55847 Mdot
.33539 .60386 Mdot
.37028 .5616 Mdot
.65666 .5763 Mdot
.65519 .57292 Mdot
.40275 .33848 Mdot
.52367 .66784 Mdot
.43015 .34083 Mdot
.6326 .56272 Mdot
.65003 .37758 Mdot
.34603 .57226 Mdot
.48225 .35893 Mdot
.49155 .38033 Mdot
.63331 .3845 Mdot
.64329 .36973 Mdot
.63363 .41198 Mdot
.55347 .6602 Mdot
.44715 .35418 Mdot
.3582 .56381 Mdot
.5396 .63738 Mdot
.63582 .36485 Mdot
.65538 .42572 Mdot
.66819 .59177 Mdot
.42597 .39423 Mdot
.71915 .54054 Mdot
.59632 .88563 Mdot
.64226 .33587 Mdot
.68461 .52003 Mdot
.69239 .57624 Mdot
.57377 .28528 Mdot
.58891 .58608 Mdot
.51949 .63606 Mdot
.6554 .34957 Mdot
.67665 .40806 Mdot
.46997 .33399 Mdot
.40188 .36569 Mdot
.39175 .41237 Mdot
.6413 .41101 Mdot
.49713 .25958 Mdot
.37543 .55564 Mdot
.26803 .34465 Mdot
.65349 .4105 Mdot
.6975 .55959 Mdot
.65714 .58691 Mdot
.67274 .54293 Mdot
.40592 .36122 Mdot
.24785 .46622 Mdot
.51018 .31006 Mdot
.42956 .80114 Mdot
.50722 .62223 Mdot
.38748 .57228 Mdot
.22278 .35248 Mdot
.35652 .58349 Mdot
.62729 .57653 Mdot
.64847 .41015 Mdot
.3677 .5806 Mdot
.5025 .67148 Mdot
.50133 .65557 Mdot
.6738 .54872 Mdot
.65439 .54342 Mdot
.68225 .53751 Mdot
.30766 .58564 Mdot
.30935 .56238 Mdot
.45692 .36437 Mdot
.33973 .58079 Mdot
.84035 .46554 Mdot
.60837 .37614 Mdot
.69068 .57935 Mdot
.52928 .65322 Mdot
.34025 .54741 Mdot
.44135 .36722 Mdot
.59188 .47289 Mdot
.46115 .72486 Mdot
.62363 .41691 Mdot
.73325 .34081 Mdot
.41095 .14301 Mdot
.50263 .39532 Mdot
.5058 .62905 Mdot
.80845 .44243 Mdot
.4503 .3759 Mdot
.65959 .53519 Mdot
.57443 .78241 Mdot
.64268 .51757 Mdot
.42908 .33971 Mdot
.50727 .38366 Mdot
.48614 .64057 Mdot
.35974 .22541 Mdot
.45084 .36308 Mdot
.41148 .63343 Mdot
.54019 .61635 Mdot
.60774 .55783 Mdot
.14965 .53022 Mdot
.68848 .70378 Mdot
.57323 .23234 Mdot
.66179 .57507 Mdot
.42933 .38391 Mdot
.6663 .57158 Mdot
.62084 .4127 Mdot
.68038 .56385 Mdot
.3609 .60811 Mdot
.61636 .53815 Mdot
.48608 .38963 Mdot
.35686 .55559 Mdot
.52307 .6407 Mdot
.81926 .55381 Mdot
.75324 .50644 Mdot
.65531 .55158 Mdot
.68103 .57152 Mdot
.49176 .40297 Mdot
.37213 .64408 Mdot
.50812 .3499 Mdot
.45338 .42393 Mdot
.54646 .659 Mdot
.32283 .5504 Mdot
.50497 .61756 Mdot
.46157 .43326 Mdot
.62697 .76414 Mdot
.53467 .64332 Mdot
.33816 .67963 Mdot
.64598 .39417 Mdot
.44869 .53425 Mdot
.43287 .36675 Mdot
.4951 .65492 Mdot
.44574 .35388 Mdot
.37836 .56747 Mdot
.49178 .52591 Mdot
.54563 .74103 Mdot
.50064 .64739 Mdot
.2055 .60011 Mdot
.61233 .58705 Mdot
.49627 .43475 Mdot
.5236 .67568 Mdot
.51457 .29559 Mdot
.69567 .55406 Mdot
.65388 .39597 Mdot
.63924 .36609 Mdot
.63274 .4218 Mdot
.4805 .32827 Mdot
.50305 .43329 Mdot
.6123 .38422 Mdot
.4925 .66487 Mdot
.66295 .3912 Mdot
.25814 .60067 Mdot
.20572 .61244 Mdot
.63942 .37641 Mdot
.46782 .3787 Mdot
.44138 .46338 Mdot
.60057 .29046 Mdot
.71575 .52794 Mdot
.26271 .71682 Mdot
.40679 .57946 Mdot
.43963 .39871 Mdot
.31009 .62546 Mdot
.37536 .56485 Mdot
.80377 .44702 Mdot
.5813 .33931 Mdot
.78675 .5123 Mdot
.32693 .59751 Mdot
.56296 .73557 Mdot
.31467 .56784 Mdot
.4981 .40252 Mdot
.46502 .41917 Mdot
.32071 .53388 Mdot
.77816 .60239 Mdot
.63056 .64657 Mdot
.15987 .46995 Mdot
.36925 .55606 Mdot
.513 .6739 Mdot
.54225 .66901 Mdot
.51213 .62255 Mdot
.76018 .40742 Mdot
.33897 .53384 Mdot
.45595 .35594 Mdot
.62575 .56088 Mdot
.41696 .40169 Mdot
.50774 .64279 Mdot
.16627 .54642 Mdot
.33322 .59068 Mdot
.4622 .4045 Mdot
.55807 .19268 Mdot
.64956 .53771 Mdot
.64098 .38476 Mdot
.45757 .21353 Mdot
.77894 .45334 Mdot
.54243 .63206 Mdot
.34586 .52949 Mdot
.58203 .71648 Mdot
.32372 .67865 Mdot
.42506 .32671 Mdot
.40169 .33277 Mdot
.24594 .30164 Mdot
.77116 .44351 Mdot
.49269 .35245 Mdot
.69232 .55489 Mdot
.56961 .73666 Mdot
.48386 .36683 Mdot
.36834 .54969 Mdot
.65817 .37659 Mdot
.63997 .42044 Mdot
.40088 .41053 Mdot
.56762 .56381 Mdot
.45049 .50844 Mdot
.45103 .33906 Mdot
.52569 .35614 Mdot
.62714 .57462 Mdot
.60408 .72739 Mdot
.80609 .54896 Mdot
.62496 .37442 Mdot
.48599 .35305 Mdot
.40395 .75881 Mdot
.30339 .56821 Mdot
.64439 .52219 Mdot
.54437 .62949 Mdot
.43468 .23727 Mdot
.60586 .55448 Mdot
.48462 .36634 Mdot
.477 .34926 Mdot
.49527 .62898 Mdot
.35048 .60683 Mdot
.6432 .41041 Mdot
.62162 .55832 Mdot
.62242 .3756 Mdot
.32865 .5406 Mdot
.3313 .58776 Mdot
.51274 .44583 Mdot
.46333 .44836 Mdot
.66428 .55567 Mdot
.45642 .43221 Mdot
.70864 .51176 Mdot
.35524 .22446 Mdot
.47336 .64281 Mdot
.50295 .39579 Mdot
.30853 .60875 Mdot
.49979 .64347 Mdot
.4741 .40657 Mdot
.2125 .3359 Mdot
.45384 .42814 Mdot
.49525 .7189 Mdot
.66841 .74797 Mdot
.61963 .40176 Mdot
.24783 .35047 Mdot
.29238 .6381 Mdot
.43716 .40848 Mdot
.64849 .52695 Mdot
.46404 .30606 Mdot
.52439 .63201 Mdot
.31012 .57447 Mdot
.4438 .1584 Mdot
.51976 .65981 Mdot
.44268 .41901 Mdot
.63248 .40564 Mdot
.35696 .53097 Mdot
.5875 .51613 Mdot
.78916 .5412 Mdot
.52081 .39599 Mdot
.41163 .42015 Mdot
.43563 .33889 Mdot
.56304 .80295 Mdot
.68808 .55928 Mdot
.34563 .5503 Mdot
.5086 .62683 Mdot
.51336 .63835 Mdot
.6707 .54743 Mdot
.39461 .72783 Mdot
.4509 .53255 Mdot
.62806 .85455 Mdot
.66852 .56278 Mdot
.60421 .39911 Mdot
.39646 .63491 Mdot
.64765 .52615 Mdot
.63209 .55006 Mdot
.62724 .57419 Mdot
.51383 .70978 Mdot
.33281 .56369 Mdot
.49234 .37939 Mdot
.37592 .5844 Mdot
.42607 .38442 Mdot
.44425 .49542 Mdot
.4974 .64373 Mdot
.31046 .57937 Mdot
.22015 .33032 Mdot
.37707 .46774 Mdot
.45798 .37942 Mdot
.23704 .33123 Mdot
.51006 .40294 Mdot
.55324 .29112 Mdot
.48354 .43653 Mdot
.65206 .54847 Mdot
.38492 .32356 Mdot
.48516 .32434 Mdot
.8297 .52093 Mdot
.53009 .65471 Mdot
.69798 .54766 Mdot
.49385 .34719 Mdot
.53025 .38567 Mdot
.32028 .53187 Mdot
.3695 .57443 Mdot
.6153 .37949 Mdot
.66353 .29384 Mdot
.52498 .64066 Mdot
.43062 .19966 Mdot
.44267 .40414 Mdot
.73461 .68164 Mdot
.24064 .3707 Mdot
.47325 .40592 Mdot
.22532 .59328 Mdot
.24212 .45768 Mdot
.4269 .36611 Mdot
.54255 .33763 Mdot
.50551 .6626 Mdot
.63462 .76206 Mdot
.42151 .42502 Mdot
.6562 .53364 Mdot
.31226 .5598 Mdot
.36813 .54508 Mdot
.61161 .38991 Mdot
.7538 .30251 Mdot
.50354 .61899 Mdot
.30904 .57499 Mdot
.4429 .37343 Mdot
.54145 .63318 Mdot
.64206 .57172 Mdot
.47757 .42925 Mdot
.59075 .33318 Mdot
.33642 .58066 Mdot
.42904 .43031 Mdot
.42116 .67365 Mdot
.61045 .26103 Mdot
.44032 .84059 Mdot
.51646 .62352 Mdot
.66031 .39325 Mdot
.45176 .30428 Mdot
.46719 .19653 Mdot
.45168 .32629 Mdot
.5161 .22763 Mdot
.26275 .58552 Mdot
.66105 .3941 Mdot
.4604 .3885 Mdot
.47129 .36239 Mdot
.52459 .57492 Mdot
.64033 .37041 Mdot
.42903 .4186 Mdot
.35864 .38087 Mdot
.33521 .55906 Mdot
.6039 .54012 Mdot
.33296 .57729 Mdot
.46283 .37476 Mdot
.44428 .45046 Mdot
.34767 .59575 Mdot
.34858 .20373 Mdot
.66617 .37722 Mdot
.53788 .64363 Mdot
.48301 .44405 Mdot
.40573 .38197 Mdot
.65498 .79439 Mdot
.69561 .53011 Mdot
.48383 .78886 Mdot
.69447 .49106 Mdot
.3891 .76319 Mdot
.69286 .69889 Mdot
.26263 .75029 Mdot
.80737 .57552 Mdot
.39851 .41996 Mdot
.4153 .52394 Mdot
.5328 .3309 Mdot
.52151 .61938 Mdot
.33254 .3529 Mdot
.43919 .40027 Mdot
.44734 .38795 Mdot
.6544 .51986 Mdot
.36168 .70643 Mdot
.78977 .52339 Mdot
.57271 .53862 Mdot
.64415 .4078 Mdot
.34894 .54125 Mdot
.4822 .40762 Mdot
.57559 .45633 Mdot
.62663 .53154 Mdot
.74277 .67018 Mdot
.46301 .39967 Mdot
.75597 .33142 Mdot
.53108 .72065 Mdot
.5347 .62891 Mdot
.62305 .53941 Mdot
.78697 .47814 Mdot
.42281 .39086 Mdot
.55136 .63987 Mdot
.44618 .36339 Mdot
.66871 .6053 Mdot
.4666 .42919 Mdot
.6496 .38328 Mdot
.49602 .3688 Mdot
.57824 .53013 Mdot
.36091 .8125 Mdot
.63634 .35211 Mdot
.35505 .53617 Mdot
.71072 .54976 Mdot
.66937 .55198 Mdot
.36378 .58585 Mdot
.66602 .55206 Mdot
.24155 .4064 Mdot
.30737 .44913 Mdot
.64691 .40437 Mdot
.52911 .36797 Mdot
.63187 .37611 Mdot
.69465 .52767 Mdot
.43276 .39361 Mdot
.36716 .19665 Mdot
.6613 .5616 Mdot
.67997 .75352 Mdot
.52511 .65613 Mdot
.69803 .5378 Mdot
.43345 .42958 Mdot
.58722 .70331 Mdot
.61663 .54677 Mdot
.55084 .73538 Mdot
.47063 .36823 Mdot
.32645 .58597 Mdot
.47477 .36138 Mdot
.49943 .42748 Mdot
.59833 .55537 Mdot
.4151 .36056 Mdot
.53401 .66093 Mdot
.32318 .60244 Mdot
.2182 .65007 Mdot
.50228 .72438 Mdot
.42741 .41155 Mdot
.44514 .37427 Mdot
.35043 .52592 Mdot
.41271 .4025 Mdot
.5326 .67553 Mdot
.88478 .59229 Mdot
.6459 .39353 Mdot
.68068 .57412 Mdot
.68105 .71312 Mdot
.44043 .32942 Mdot
.46285 .34027 Mdot
.19574 .36729 Mdot
.67402 .7272 Mdot
.52923 .67167 Mdot
.50088 .3356 Mdot
.62497 .56418 Mdot
.63144 .4037 Mdot
.48876 .66179 Mdot
.43059 .34491 Mdot
.45492 .39498 Mdot
.65981 .39354 Mdot
.22233 .55474 Mdot
.78916 .44834 Mdot
.50037 .624 Mdot
.3805 .32836 Mdot
.66235 .48049 Mdot
.41606 .3858 Mdot
.76245 .402 Mdot
.36783 .57491 Mdot
.54765 .64147 Mdot
.46925 .80186 Mdot
.48311 .34461 Mdot
.49158 .65683 Mdot
.52685 .64269 Mdot
.49151 .3291 Mdot
.29102 .58222 Mdot
.309 .59406 Mdot
.35615 .54436 Mdot
.85019 .46516 Mdot
.59128 .25409 Mdot
.68208 .53736 Mdot
.50406 .66179 Mdot
.6517 .58114 Mdot
.60125 .39547 Mdot
.53743 .48031 Mdot
.6718 .57815 Mdot
.3672 .58641 Mdot
.71402 .5462 Mdot
.47361 .36508 Mdot
.52137 .63891 Mdot
.68941 .53826 Mdot
.49292 .34412 Mdot
.33861 .65159 Mdot
.72977 .57789 Mdot
.6621 .41637 Mdot
.65485 .37142 Mdot
.46918 .41719 Mdot
.67651 .51581 Mdot
.45385 .40559 Mdot
.50109 .68227 Mdot
.38202 .64447 Mdot
.47017 .32926 Mdot
.65796 .55029 Mdot
.30291 .62542 Mdot
.77882 .45375 Mdot
.51462 .36941 Mdot
.46698 .3796 Mdot
.42053 .38286 Mdot
.44541 .36278 Mdot
.36516 .72556 Mdot
.47756 .63633 Mdot
.42868 .60122 Mdot
.61534 .74339 Mdot
.34567 .58467 Mdot
.2996 .592 Mdot
.73293 .38507 Mdot
.63481 .62403 Mdot
.52073 .66885 Mdot
.42176 .37489 Mdot
.52836 .73624 Mdot
.16993 .5567 Mdot
.32393 .21156 Mdot
.59064 .3824 Mdot
.67755 .52039 Mdot
.33692 .53106 Mdot
.62924 .53195 Mdot
.43171 .38603 Mdot
.44433 .30323 Mdot
.25881 .7514 Mdot
.56227 .64959 Mdot
.64667 .41101 Mdot
.42244 .38257 Mdot
.59117 .24808 Mdot
.62611 .55843 Mdot
.64559 .58446 Mdot
.43338 .42285 Mdot
.33138 .61007 Mdot
.56648 .83209 Mdot
.53057 .6257 Mdot
.40753 .58383 Mdot
.3969 .29545 Mdot
.43383 .65157 Mdot
.50387 .63868 Mdot
.77422 .51884 Mdot
.67239 .51696 Mdot
.20921 .44997 Mdot
.34414 .58726 Mdot
.65111 .41052 Mdot
.41033 .3223 Mdot
.3333 .59586 Mdot
.6047 .54641 Mdot
.31624 .58268 Mdot
.49798 .36996 Mdot
.49106 .62235 Mdot
.62794 .5378 Mdot
.53883 .69009 Mdot
.29248 .58443 Mdot
.61825 .3847 Mdot
.48273 .57428 Mdot
.34088 .41637 Mdot
.24007 .45399 Mdot
.41398 .39776 Mdot
.57409 .45316 Mdot
.452 .35326 Mdot
.31041 .53843 Mdot
.44293 .36588 Mdot
.3185 .62905 Mdot
.64095 .52949 Mdot
.42239 .42448 Mdot
.44519 .33713 Mdot
.32783 .32337 Mdot
.46888 .39378 Mdot
.44129 .43943 Mdot
.42367 .36822 Mdot
.38711 .54014 Mdot
.51794 .34801 Mdot
.3274 .56916 Mdot
.77686 .55043 Mdot
.63434 .54874 Mdot
.65146 .36984 Mdot
.65049 .4206 Mdot
.53127 .22807 Mdot
.68724 .38325 Mdot
.37898 .72073 Mdot
.33787 .57025 Mdot
.5335 .64971 Mdot
.44082 .36316 Mdot
.38326 .78982 Mdot
.67659 .69098 Mdot
.62763 .56865 Mdot
.50262 .72444 Mdot
.38316 .34298 Mdot
.56833 .80469 Mdot
.44086 .4334 Mdot
.81878 .39671 Mdot
.42003 .45114 Mdot
.47308 .42542 Mdot
.63284 .581 Mdot
.65744 .3652 Mdot
.42144 .41854 Mdot
.32238 .53045 Mdot
.65717 .39585 Mdot
.39336 .50916 Mdot
.63582 .49321 Mdot
.76851 .53339 Mdot
.31911 .39531 Mdot
.4452 .35642 Mdot
.6308 .53658 Mdot
.32034 .56678 Mdot
.8084 .5551 Mdot
.54043 .63978 Mdot
.5718 .59995 Mdot
.4324 .27294 Mdot
.28338 .27776 Mdot
.65556 .40556 Mdot
.22436 .54494 Mdot
.48706 .38979 Mdot
.74374 .41638 Mdot
.40816 .34252 Mdot
.17247 .5583 Mdot
.60677 .40501 Mdot
.31486 .60571 Mdot
.51535 .67427 Mdot
.37672 .57576 Mdot
.2422 .47393 Mdot
.47221 .60303 Mdot
.51319 .54297 Mdot
.63552 .5602 Mdot
.43921 .59479 Mdot
.3529 .55186 Mdot
.47835 .34736 Mdot
.61539 .86501 Mdot
.36982 .56594 Mdot
.32016 .54205 Mdot
.38083 .21561 Mdot
.35662 .21889 Mdot
.38617 .33051 Mdot
.3383 .59934 Mdot
.63647 .55746 Mdot
.61964 .38923 Mdot
.46992 .35577 Mdot
.4588 .36262 Mdot
.33981 .59499 Mdot
.63986 .58355 Mdot
.39043 .4896 Mdot
.65272 .54451 Mdot
.33375 .55758 Mdot
.6399 .54141 Mdot
.58632 .74505 Mdot
.69152 .53501 Mdot
.40649 .38506 Mdot
.44217 .36507 Mdot
.69039 .49658 Mdot
.33118 .58751 Mdot
.45353 .3409 Mdot
.49559 .38064 Mdot
.35695 .56144 Mdot
.61892 .46141 Mdot
.32096 .5071 Mdot
.4275 .40414 Mdot
.47965 .37942 Mdot
.65875 .38814 Mdot
.55076 .46137 Mdot
.68202 .26488 Mdot
.46914 .34656 Mdot
.60879 .37883 Mdot
.30816 .58475 Mdot
.45787 .40772 Mdot
.2696 .66408 Mdot
.56843 .73798 Mdot
.48492 .34762 Mdot
.69638 .55062 Mdot
.46587 .31724 Mdot
.48462 .8404 Mdot
.45079 .42497 Mdot
.35085 .55883 Mdot
.32022 .54785 Mdot
.40892 .21958 Mdot
.36547 .56953 Mdot
.6519 .57419 Mdot
.51189 .64525 Mdot
.18646 .57581 Mdot
.64093 .57133 Mdot
.50132 .34873 Mdot
.50323 .16865 Mdot
.46193 .43841 Mdot
.48526 .33748 Mdot
.61003 .7985 Mdot
.63825 .56925 Mdot
.33212 .54415 Mdot
.56187 .57938 Mdot
.41065 .4364 Mdot
.54346 .63279 Mdot
.46178 .30896 Mdot
.40906 .36424 Mdot
.675 .74156 Mdot
.50934 .76268 Mdot
.53195 .6819 Mdot
.38728 .36557 Mdot
.46808 .34572 Mdot
.72291 .55126 Mdot
.44014 .36901 Mdot
.62788 .37503 Mdot
.33558 .53676 Mdot
.66536 .52352 Mdot
.63353 .38719 Mdot
.43846 .40482 Mdot
.63991 .41136 Mdot
.67894 .53048 Mdot
.55049 .642 Mdot
.42848 .38978 Mdot
.63299 .42879 Mdot
.6425 .4083 Mdot
.45178 .35001 Mdot
.30969 .57059 Mdot
.39073 .43518 Mdot
.46205 .4085 Mdot
.48656 .36119 Mdot
.33773 .59365 Mdot
.2911 .21971 Mdot
.4534 .42652 Mdot
.60764 .5824 Mdot
.31428 .54592 Mdot
.45221 .64714 Mdot
.66867 .52222 Mdot
.40801 .36646 Mdot
.54977 .65203 Mdot
.49432 .64928 Mdot
.64094 .57919 Mdot
.36661 .53417 Mdot
.69316 .49311 Mdot
.30675 .62677 Mdot
.44338 .44776 Mdot
.49006 .42415 Mdot
.54957 .1739 Mdot
.24922 .72054 Mdot
.36615 .54503 Mdot
.62892 .58281 Mdot
.57036 .53638 Mdot
.50429 .665 Mdot
.68529 .5797 Mdot
.35094 .52872 Mdot
.34412 .53169 Mdot
.31652 .57863 Mdot
.64601 .41753 Mdot
.67341 .47952 Mdot
.35156 .60772 Mdot
.32968 .60956 Mdot
.47239 .36737 Mdot
.46479 .34359 Mdot
.56776 .36285 Mdot
.63109 .31908 Mdot
.61573 .38572 Mdot
.66952 .54308 Mdot
.85781 .59951 Mdot
.50456 .68312 Mdot
.32312 .32807 Mdot
.4691 .32925 Mdot
.53424 .92417 Mdot
.44452 .43177 Mdot
.43976 .37169 Mdot
.32523 .60199 Mdot
.64874 .43081 Mdot
.63816 .37928 Mdot
.35033 .54803 Mdot
.30249 .55012 Mdot
.62991 .37418 Mdot
.18459 .50687 Mdot
.20335 .6161 Mdot
.51344 .58066 Mdot
.35332 .56853 Mdot
.34106 .43589 Mdot
.54345 .62762 Mdot
.30447 .61329 Mdot
.48934 .67041 Mdot
.62696 .55351 Mdot
.66433 .51582 Mdot
.50738 .62602 Mdot
.46788 .36806 Mdot
.68711 .54566 Mdot
.42888 .43997 Mdot
.20179 .54618 Mdot
.27547 .51644 Mdot
.72551 .65077 Mdot
.39767 .37206 Mdot
.77923 .53805 Mdot
.65604 .6277 Mdot
.44402 .4148 Mdot
.33225 .73406 Mdot
.64486 .41184 Mdot
.3231 .61532 Mdot
.53793 .6723 Mdot
.4596 .84831 Mdot
.4172 .38158 Mdot
.34899 .56282 Mdot
.5306 .65857 Mdot
.45858 .23016 Mdot
.40793 .63538 Mdot
.42337 .38443 Mdot
.65178 .84116 Mdot
.38398 .52606 Mdot
.66784 .52404 Mdot
.63259 .20363 Mdot
.37752 .58254 Mdot
.61052 .42912 Mdot
.61269 .73063 Mdot
.23545 .32179 Mdot
.32881 .55032 Mdot
.67411 .58855 Mdot
.3502 .54299 Mdot
.62066 .37965 Mdot
.36723 .60905 Mdot
.62168 .55022 Mdot
.46484 .39264 Mdot
.66365 .54653 Mdot
.61313 .39147 Mdot
.75447 .40596 Mdot
.54109 .66926 Mdot
.69779 .54728 Mdot
.50732 .65442 Mdot
.62488 .27003 Mdot
.61123 .76571 Mdot
.54096 .65146 Mdot
.43673 .2162 Mdot
.48851 .34691 Mdot
.36577 .59871 Mdot
.67507 .55826 Mdot
.60793 .72503 Mdot
.52678 .56436 Mdot
.3522 .58187 Mdot
.66869 .53519 Mdot
.45873 .2811 Mdot
.52264 .18689 Mdot
.5239 .4092 Mdot
.64455 .28815 Mdot
.35671 .56661 Mdot
.6846 .58193 Mdot
.80305 .53518 Mdot
.37114 .58157 Mdot
.66983 .56291 Mdot
.50352 .66922 Mdot
.50955 .63746 Mdot
.42247 .41601 Mdot
.51097 .69897 Mdot
.67736 .54149 Mdot
.69003 .62201 Mdot
.30285 .56854 Mdot
.4698 .23447 Mdot
.63455 .42579 Mdot
.64122 .54896 Mdot
.49425 .41392 Mdot
.287 .59302 Mdot
.5776 .74049 Mdot
.39216 .48286 Mdot
.83885 .61775 Mdot
.66996 .54702 Mdot
.32934 .53774 Mdot
.34677 .56764 Mdot
.51324 .36613 Mdot
.5621 .55545 Mdot
.68552 .48869 Mdot
.53354 .19957 Mdot
.50379 .22702 Mdot
.60201 .54806 Mdot
.60192 .53209 Mdot
.50739 .36524 Mdot
.43797 .35417 Mdot
.50674 .66812 Mdot
.46787 .38771 Mdot
.31996 .60404 Mdot
.41713 .41143 Mdot
.50128 .63676 Mdot
.64489 .56334 Mdot
.43438 .39159 Mdot
.61686 .39611 Mdot
.54886 .66379 Mdot
.48593 .63915 Mdot
.64755 .5511 Mdot
.32849 .59554 Mdot
.62125 .35931 Mdot
.65491 .54308 Mdot
.44587 .35721 Mdot
.57926 .61552 Mdot
.49879 .3817 Mdot
.19021 .48256 Mdot
.3679 .58691 Mdot
.63656 .52943 Mdot
.30432 .5566 Mdot
.50939 .6593 Mdot
.61416 .74291 Mdot
.45572 .37225 Mdot
.66648 .56477 Mdot
.68903 .49904 Mdot
.19901 .52585 Mdot
.34362 .52351 Mdot
.5877 .64761 Mdot
.29994 .58415 Mdot
.61395 .53367 Mdot
.36999 .24711 Mdot
.65367 .4004 Mdot
.62432 .56624 Mdot
.24005 .68685 Mdot
.66012 .55576 Mdot
.47214 .39579 Mdot
.47534 .40963 Mdot
.6747 .52382 Mdot
.66013 .41228 Mdot
.8117 .58274 Mdot
.68453 .6068 Mdot
.32965 .54676 Mdot
.272 .31117 Mdot
.7863 .69318 Mdot
.48339 .67815 Mdot
.51716 .67288 Mdot
.40726 .43414 Mdot
.47861 .42352 Mdot
.49264 .6718 Mdot
.5365 .61659 Mdot
.61628 .41233 Mdot
.62756 .57395 Mdot
.38951 .58826 Mdot
.55329 .6384 Mdot
.49607 .45774 Mdot
.69383 .38133 Mdot
.51616 .36299 Mdot
.409 .29296 Mdot
.40297 .3562 Mdot
.50631 .22001 Mdot
.50338 .63107 Mdot
.48215 .41041 Mdot
.52003 .36521 Mdot
.54937 .6494 Mdot
.62381 .37771 Mdot
.49977 .75181 Mdot
.64188 .53615 Mdot
.13959 .44539 Mdot
.48563 .41334 Mdot
.47047 .40023 Mdot
.50872 .62196 Mdot
.71003 .49676 Mdot
.32681 .59123 Mdot
.37035 .58566 Mdot
.68934 .55635 Mdot
.48574 .5688 Mdot
.41084 .38183 Mdot
.45166 .41765 Mdot
.64722 .53092 Mdot
.69819 .53967 Mdot
.69819 .63794 Mdot
.49032 .38089 Mdot
.52813 .66084 Mdot
.58046 .51158 Mdot
.50185 .63309 Mdot
.49912 .39845 Mdot
.4751 .39677 Mdot
.40714 .38697 Mdot
.49719 .40833 Mdot
.48465 .64022 Mdot
.48498 .40658 Mdot
.47761 .45849 Mdot
.31553 .58627 Mdot
.41591 .36365 Mdot
.4963 .22092 Mdot
.47224 .37947 Mdot
.62032 .38513 Mdot
.44608 .47669 Mdot
.41943 .38484 Mdot
.40759 .3729 Mdot
.67731 .60801 Mdot
.45697 .38613 Mdot
.4998 .68142 Mdot
.34366 .58149 Mdot
.50322 .6609 Mdot
.49714 .62852 Mdot
.66959 .57368 Mdot
.61164 .38693 Mdot
.43431 .33179 Mdot
.62894 .41878 Mdot
.42623 .32957 Mdot
.48792 .34868 Mdot
.64212 .72488 Mdot
.81425 .38391 Mdot
.78776 .44142 Mdot
.45595 .37119 Mdot
.65261 .56867 Mdot
.65808 .52301 Mdot
.41705 .55443 Mdot
.52425 .40403 Mdot
.49268 .67049 Mdot
.49522 .65377 Mdot
.59271 .32706 Mdot
.66651 .74554 Mdot
.62109 .38272 Mdot
.56146 .46641 Mdot
.43029 .44131 Mdot
.49256 .37246 Mdot
.4736 .43135 Mdot
.66003 .57978 Mdot
.57845 .55578 Mdot
.62729 .56764 Mdot
.50903 .727 Mdot
.49778 .63788 Mdot
.41555 .37686 Mdot
.24872 .57832 Mdot
.37005 .57598 Mdot
.34287 .5819 Mdot
.48753 .65427 Mdot
.70583 .56001 Mdot
.58436 .36994 Mdot
.36923 .17198 Mdot
.3913 .54792 Mdot
.65597 .42684 Mdot
.43843 .41394 Mdot
.64808 .55992 Mdot
.36278 .54676 Mdot
.66229 .3883 Mdot
.48724 .35297 Mdot
.67392 .48238 Mdot
.45622 .36827 Mdot
.53455 .33385 Mdot
.31312 .56608 Mdot
.18212 .58261 Mdot
.36467 .53693 Mdot
.54667 .66735 Mdot
.54358 .65798 Mdot
.47609 .40453 Mdot
.57564 .18151 Mdot
.37051 .59271 Mdot
.49311 .70571 Mdot
.60872 .40723 Mdot
.58041 .70784 Mdot
.63124 .37193 Mdot
.6536 .52554 Mdot
.65719 .3995 Mdot
.62324 .54102 Mdot
.63388 .32953 Mdot
.37439 .52974 Mdot
.64082 .38971 Mdot
.66955 .59914 Mdot
.52155 .40962 Mdot
.64802 .36931 Mdot
.38775 .40302 Mdot
.22172 .39402 Mdot
.65185 .53119 Mdot
.65084 .41848 Mdot
.47822 .34791 Mdot
.34755 .78821 Mdot
.5341 .66377 Mdot
.49887 .67656 Mdot
.45054 .44644 Mdot
.63408 .57908 Mdot
.32676 .53044 Mdot
.3153 .68758 Mdot
.49149 .59997 Mdot
.46566 .41742 Mdot
.42019 .41704 Mdot
.30294 .59901 Mdot
.31458 .52061 Mdot
.47825 .39863 Mdot
.37242 .29225 Mdot
.48929 .3938 Mdot
.50136 .66941 Mdot
.37477 .55928 Mdot
.34554 .5738 Mdot
.67376 .53479 Mdot
.34197 .60229 Mdot
.33205 .6328 Mdot
.5767 .65224 Mdot
.3989 .42816 Mdot
.51769 .65908 Mdot
.56494 .68373 Mdot
.50702 .72708 Mdot
.26854 .71861 Mdot
.29817 .59413 Mdot
.40397 .38542 Mdot
.30371 .56318 Mdot
.62788 .40339 Mdot
.33088 .58484 Mdot
.3311 .5331 Mdot
.45182 .4101 Mdot
.42953 .38359 Mdot
.63913 .56681 Mdot
.56548 .55594 Mdot
.31155 .58522 Mdot
.47329 .4145 Mdot
.44658 .43838 Mdot
.4427 .44014 Mdot
.47809 .50789 Mdot
.3646 .5444 Mdot
.31694 .30966 Mdot
.507 .27423 Mdot
.31269 .58665 Mdot
.51321 .84373 Mdot
.60435 .73374 Mdot
.70256 .53589 Mdot
.52494 .69377 Mdot
.49036 .37938 Mdot
.6685 .52061 Mdot
.43178 .38648 Mdot
.40837 .29308 Mdot
.45208 .39306 Mdot
.63857 .37253 Mdot
.3983 .41956 Mdot
.63184 .52249 Mdot
.65804 .54458 Mdot
.45732 .42296 Mdot
.4383 .39232 Mdot
.76702 .42364 Mdot
.2985 .55728 Mdot
.32417 .58888 Mdot
.72451 .51449 Mdot
.63935 .39708 Mdot
.54609 .63694 Mdot
.43163 .36552 Mdot
.67404 .57075 Mdot
.66201 .5449 Mdot
.37795 .57268 Mdot
.65767 .53501 Mdot
.52371 .62369 Mdot
.45211 .3719 Mdot
.49674 .67544 Mdot
.6428 .41999 Mdot
.3531 .54076 Mdot
.41843 .37802 Mdot
.47297 .3677 Mdot
.32058 .5476 Mdot
.45858 .32959 Mdot
.65736 .38587 Mdot
.66233 .55414 Mdot
.32649 .55524 Mdot
.51104 .64343 Mdot
.63876 .52997 Mdot
.47948 .35954 Mdot
.85003 .60466 Mdot
.47497 .39086 Mdot
.48575 .36968 Mdot
.22474 .67993 Mdot
.39652 .41772 Mdot
.67504 .55246 Mdot
.31955 .60862 Mdot
.41256 .4235 Mdot
.54527 .2354 Mdot
.30892 .21669 Mdot
.63312 .57162 Mdot
.43515 .41498 Mdot
.27848 .7483 Mdot
.44436 .42103 Mdot
.44426 .20013 Mdot
.71215 .38121 Mdot
.44487 .57451 Mdot
.44773 .4525 Mdot
.52074 .62729 Mdot
.64077 .56786 Mdot
.64566 .52828 Mdot
.30158 .29798 Mdot
.4522 .4132 Mdot
.55358 .36526 Mdot
.46135 .3355 Mdot
.50562 .63745 Mdot
.57088 .32881 Mdot
.66768 .54504 Mdot
.82035 .47884 Mdot
.45433 .3559 Mdot
.36275 .5411 Mdot
.71338 .54917 Mdot
.59403 .73609 Mdot
.48268 .35872 Mdot
.62937 .41728 Mdot
.54889 .67338 Mdot
.40584 .42338 Mdot
.51941 .65438 Mdot
.49307 .36719 Mdot
.52044 .43936 Mdot
.68349 .23741 Mdot
.3119 .57413 Mdot
.51152 .67253 Mdot
.59515 .61766 Mdot
.40159 .3474 Mdot
.32698 .55292 Mdot
.34542 .58675 Mdot
.61786 .41236 Mdot
.53125 .53043 Mdot
.41268 .6776 Mdot
.3418 .48535 Mdot
.29752 .29377 Mdot
.71143 .55146 Mdot
.61371 .64568 Mdot
.47022 .35223 Mdot
.73348 .67587 Mdot
.5206 .68693 Mdot
.46847 .39814 Mdot
.22456 .4078 Mdot
.35934 .54703 Mdot
.48313 .38225 Mdot
.63069 .3759 Mdot
.76006 .62385 Mdot
.75211 .65039 Mdot
.52124 .80905 Mdot
.63258 .55878 Mdot
.44495 .30415 Mdot
.45624 .29653 Mdot
.68552 .56846 Mdot
.43522 .33437 Mdot
.67127 .55678 Mdot
.19556 .40484 Mdot
.66262 .39435 Mdot
.3548 .53917 Mdot
.6014 .73504 Mdot
.4117 .35032 Mdot
.4695 .43913 Mdot
.6643 .38595 Mdot
.43456 .35003 Mdot
.7575 .3098 Mdot
.70371 .66654 Mdot
.68986 .54225 Mdot
.31527 .57789 Mdot
.4062 .36 Mdot
.54671 .50602 Mdot
.45956 .41266 Mdot
.30163 .47501 Mdot
.40701 .37176 Mdot
.4136 .65828 Mdot
.31169 .56069 Mdot
.51608 .65582 Mdot
.43332 .31808 Mdot
.44871 .38534 Mdot
.60041 .47265 Mdot
.44065 .45232 Mdot
.46382 .4251 Mdot
.33361 .52641 Mdot
.37301 .55952 Mdot
.32854 .56898 Mdot
.61408 .54142 Mdot
.67402 .73902 Mdot
.51927 .66534 Mdot
.4712 .31613 Mdot
.55211 .63456 Mdot
.37339 .44921 Mdot
.6644 .41301 Mdot
.35221 .7796 Mdot
.42185 .35451 Mdot
.3357 .56638 Mdot
.42968 .76251 Mdot
.30715 .58463 Mdot
.56244 .48707 Mdot
.52436 .6402 Mdot
.36466 .55285 Mdot
.44392 .37678 Mdot
.57254 .57263 Mdot
.4362 .81427 Mdot
.50001 .65347 Mdot
.44014 .32687 Mdot
.68121 .52105 Mdot
.66478 .7273 Mdot
.84706 .62438 Mdot
.53094 .67068 Mdot
.59277 .615 Mdot
.44994 .41537 Mdot
.36697 .58448 Mdot
.52104 .62552 Mdot
.53805 .65341 Mdot
.66152 .53362 Mdot
.42736 .38251 Mdot
.42387 .38013 Mdot
.62694 .52588 Mdot
.49581 .6495 Mdot
.49729 .42604 Mdot
.45996 .43242 Mdot
.25988 .75542 Mdot
.46059 .26565 Mdot
.17104 .3482 Mdot
.31907 .6336 Mdot
.21975 .43265 Mdot
.29978 .6683 Mdot
.33176 .53581 Mdot
.41953 .38634 Mdot
.395 .37205 Mdot
.67631 .54126 Mdot
.4638 .38215 Mdot
.63207 .58303 Mdot
.52345 .66981 Mdot
.50609 .8402 Mdot
.46703 .73958 Mdot
.20573 .37845 Mdot
.46273 .38468 Mdot
.48282 .71826 Mdot
.6269 .39253 Mdot
.54538 .61707 Mdot
.3283 .56052 Mdot
.49963 .37201 Mdot
.77237 .42927 Mdot
.62508 .56639 Mdot
.35659 .58627 Mdot
.79293 .52589 Mdot
.77507 .52844 Mdot
.49967 .39681 Mdot
.6215 .53319 Mdot
.36874 .74642 Mdot
.37197 .29578 Mdot
.47537 .62985 Mdot
.63518 .37205 Mdot
.62625 .56242 Mdot
.49191 .64079 Mdot
.25902 .60686 Mdot
.36758 .56085 Mdot
.38137 .59148 Mdot
.75221 .37797 Mdot
.68477 .57276 Mdot
.62741 .3869 Mdot
.66359 .74536 Mdot
.73758 .68482 Mdot
.63916 .37302 Mdot
.65784 .51725 Mdot
.36978 .5539 Mdot
.34182 .55311 Mdot
.34462 .58058 Mdot
.81962 .4947 Mdot
.36847 .53726 Mdot
.30847 .36278 Mdot
.45887 .4398 Mdot
.54645 .404 Mdot
.43701 .41731 Mdot
.48637 .66434 Mdot
.31686 .55884 Mdot
.46501 .58824 Mdot
.4836 .3277 Mdot
.50333 .82063 Mdot
.45758 .4186 Mdot
.49985 .6151 Mdot
.48628 .37888 Mdot
.32533 .36576 Mdot
.30574 .5567 Mdot
.46094 .37541 Mdot
.47989 .66066 Mdot
.63908 .40514 Mdot
.3498 .62213 Mdot
.42094 .3831 Mdot
.36186 .70111 Mdot
.39389 .41331 Mdot
.17695 .48468 Mdot
.48051 .24407 Mdot
.65616 .42659 Mdot
.36919 .33811 Mdot
.67255 .58495 Mdot
.55061 .39704 Mdot
.5128 .32892 Mdot
.50135 .65166 Mdot
.57004 .77219 Mdot
.6339 .55059 Mdot
.63379 .34079 Mdot
.48309 .31722 Mdot
.61508 .3825 Mdot
.33 .52079 Mdot
.48129 .65244 Mdot
.4978 .35368 Mdot
.50152 .343 Mdot
.19533 .41943 Mdot
.53078 .37045 Mdot
.41446 .40727 Mdot
.66648 .40479 Mdot
.29411 .33213 Mdot
.47331 .37577 Mdot
.55916 .48726 Mdot
.37764 .59591 Mdot
.4687 .44595 Mdot
.3269 .30353 Mdot
.47094 .41501 Mdot
.36091 .5861 Mdot
.38032 .53967 Mdot
.43156 .7397 Mdot
.60892 .40515 Mdot
.40807 .36976 Mdot
.3995 .23077 Mdot
.44884 .35458 Mdot
.5275 .65877 Mdot
.48704 .41654 Mdot
.62306 .55571 Mdot
.81351 .49477 Mdot
.68224 .54082 Mdot
.42125 .39988 Mdot
.34854 .57638 Mdot
.50681 .62414 Mdot
.77621 .4048 Mdot
.70847 .42452 Mdot
.30419 .35501 Mdot
.21399 .3369 Mdot
.65748 .41407 Mdot
.62571 .36857 Mdot
.48083 .64599 Mdot
.46213 .37464 Mdot
.38511 .22156 Mdot
.42224 .45083 Mdot
.48059 .37838 Mdot
.45131 .39387 Mdot
.62612 .75811 Mdot
.50999 .66796 Mdot
.64839 .53659 Mdot
.47754 .3967 Mdot
.47961 .41102 Mdot
.32209 .54254 Mdot
.64144 .4062 Mdot
.66533 .52226 Mdot
.64693 .39957 Mdot
.65352 .5641 Mdot
.50121 .84524 Mdot
.45122 .31505 Mdot
.63769 .40251 Mdot
.53542 .68113 Mdot
.33974 .59432 Mdot
.57806 .64665 Mdot
.65283 .52605 Mdot
.67023 .54192 Mdot
.46088 .41772 Mdot
.35966 .58862 Mdot
.32865 .59952 Mdot
.62747 .40428 Mdot
.54298 .64715 Mdot
.4234 .38885 Mdot
.49188 .35311 Mdot
.42586 .57442 Mdot
.6529 .57966 Mdot
.46178 .28432 Mdot
.40462 .73948 Mdot
.45854 .37167 Mdot
.33422 .59842 Mdot
.44515 .39787 Mdot
.23834 .63341 Mdot
.36205 .59018 Mdot
.45758 .42775 Mdot
.77065 .65705 Mdot
.58849 .52325 Mdot
.39051 .70031 Mdot
.40978 .4012 Mdot
.15325 .43869 Mdot
.46273 .34668 Mdot
.28257 .77349 Mdot
.74764 .4431 Mdot
.41376 .38056 Mdot
.47375 .3588 Mdot
.29379 .5189 Mdot
.43528 .40605 Mdot
.62058 .52784 Mdot
.62825 .33845 Mdot
.32951 .53139 Mdot
.34112 .66552 Mdot
.47431 .48572 Mdot
.61622 .41647 Mdot
.68979 .55539 Mdot
.60646 .52463 Mdot
.64348 .37914 Mdot
.35389 .56546 Mdot
.44493 .36252 Mdot
.47365 .56188 Mdot
.6025 .55528 Mdot
.50901 .41732 Mdot
.52798 .65304 Mdot
.64731 .66214 Mdot
.68878 .58282 Mdot
.51364 .64876 Mdot
.42363 .3476 Mdot
.30772 .5127 Mdot
.70559 .3228 Mdot
.18404 .60218 Mdot
.50197 .62352 Mdot
.4953 .64431 Mdot
.8218 .51976 Mdot
.61734 .41945 Mdot
.21897 .37612 Mdot
.41035 .6462 Mdot
.52695 .6227 Mdot
.42011 .24269 Mdot
.63163 .57388 Mdot
.36488 .69486 Mdot
.323 .61541 Mdot
.48837 .42483 Mdot
.44576 .37904 Mdot
.54446 .64873 Mdot
.25777 .61402 Mdot
.66597 .22528 Mdot
.50659 .65309 Mdot
.47577 .46196 Mdot
.4701 .52395 Mdot
.60521 .73182 Mdot
.65369 .57759 Mdot
.61033 .4059 Mdot
.62274 .4357 Mdot
.33536 .54012 Mdot
.61098 .4004 Mdot
.75168 .64221 Mdot
.42822 .35182 Mdot
.50288 .64608 Mdot
.57828 .73314 Mdot
.51337 .64147 Mdot
.64134 .37939 Mdot
.65554 .42816 Mdot
.31616 .58674 Mdot
.32399 .58773 Mdot
.22362 .44654 Mdot
.56678 .30398 Mdot
.45008 .42248 Mdot
.45617 .79979 Mdot
.30288 .57093 Mdot
.38676 .31005 Mdot
.62224 .37124 Mdot
.64034 .40199 Mdot
.50804 .29294 Mdot
.42234 .37146 Mdot
.41521 .21741 Mdot
.42614 .36969 Mdot
.57098 .32219 Mdot
.41094 .3417 Mdot
.65991 .53421 Mdot
.41925 .37079 Mdot
.64147 .35848 Mdot
.50776 .36875 Mdot
.4757 .42209 Mdot
.63861 .58103 Mdot
.40751 .4234 Mdot
.6233 .55365 Mdot
.42259 .40627 Mdot
.6017 .39498 Mdot
.67906 .56842 Mdot
.57875 .25034 Mdot
.60648 .58967 Mdot
.6783 .51712 Mdot
.61458 .40094 Mdot
.63332 .42411 Mdot
.56401 .22319 Mdot
.32889 .55909 Mdot
.31372 .62307 Mdot
.46507 .37771 Mdot
.64689 .58486 Mdot
.51106 .67034 Mdot
.48499 .40518 Mdot
.39026 .38308 Mdot
.4187 .41886 Mdot
.34404 .53796 Mdot
.69793 .49807 Mdot
.63477 .40574 Mdot
.61284 .54167 Mdot
.62634 .4658 Mdot
.61304 .56715 Mdot
.51663 .3519 Mdot
.40473 .33104 Mdot
.21023 .47981 Mdot
.49551 .78076 Mdot
.82582 .55909 Mdot
.3675 .56752 Mdot
.69703 .54869 Mdot
.62935 .42438 Mdot
.37121 .39985 Mdot
.33453 .56072 Mdot
.62185 .55098 Mdot
.45495 .36792 Mdot
.43815 .32692 Mdot
.56027 .62345 Mdot
.55203 .3866 Mdot
.51153 .23772 Mdot
.61685 .56908 Mdot
.67266 .58886 Mdot
.73502 .68468 Mdot
.62179 .34038 Mdot
.50367 .56612 Mdot
.4597 .40191 Mdot
.63148 .41808 Mdot
.36289 .5469 Mdot
.72527 .34392 Mdot
.53703 .67054 Mdot
.56405 .55656 Mdot
.46207 .38322 Mdot
.4445 .60764 Mdot
.34829 .57813 Mdot
.62573 .37828 Mdot
.5451 .64816 Mdot
.66329 .4273 Mdot
.67712 .57549 Mdot
.31266 .23551 Mdot
.44375 .35199 Mdot
.44949 .42458 Mdot
.53986 .67269 Mdot
.35165 .54486 Mdot
.66885 .39938 Mdot
.18829 .50442 Mdot
.67832 .52805 Mdot
.3988 .2126 Mdot
.33354 .60447 Mdot
.32313 .40253 Mdot
.61076 .54543 Mdot
.48777 .65333 Mdot
.58328 .23656 Mdot
.50214 .63589 Mdot
.41621 .39536 Mdot
.34058 .57087 Mdot
.53227 .66401 Mdot
.57673 .49149 Mdot
.30557 .76644 Mdot
.33482 .42629 Mdot
.42736 .36043 Mdot
.39632 .80986 Mdot
.20862 .57781 Mdot
.37292 .51052 Mdot
.54989 .65295 Mdot
.46297 .4096 Mdot
.42875 .3387 Mdot
.45253 .35762 Mdot
.52924 .64005 Mdot
.63615 .71261 Mdot
.6551 .52958 Mdot
.44434 .41801 Mdot
.61858 .41448 Mdot
.62622 .54895 Mdot
.60079 .73972 Mdot
.67439 .54816 Mdot
.29476 .57185 Mdot
.48398 .41996 Mdot
.54605 .69634 Mdot
.38274 .82885 Mdot
.50201 .65913 Mdot
.67689 .51641 Mdot
.49216 .40312 Mdot
.56675 .75857 Mdot
.33022 .56754 Mdot
.68072 .53082 Mdot
.46984 .40061 Mdot
.61018 .70859 Mdot
.76548 .41774 Mdot
.67323 .54736 Mdot
.33685 .55222 Mdot
.27102 .67643 Mdot
.46685 .38521 Mdot
.45743 .34617 Mdot
.35329 .54887 Mdot
.47587 .48087 Mdot
.79848 .52811 Mdot
.44123 .39427 Mdot
.51526 .65459 Mdot
.4095 .17837 Mdot
.42657 .43109 Mdot
.52337 .29776 Mdot
.63403 .56571 Mdot
.39043 .72157 Mdot
.45203 .28159 Mdot
.37615 .33186 Mdot
.24846 .60867 Mdot
.50131 .48954 Mdot
.4832 .83502 Mdot
.65034 .58743 Mdot
.76247 .49604 Mdot
.47926 .84026 Mdot
.47746 .64504 Mdot
.27096 .59132 Mdot
.39865 .60124 Mdot
.82098 .45291 Mdot
.28695 .68791 Mdot
.73976 .51801 Mdot
.78129 .44083 Mdot
.46308 .54686 Mdot
.66021 .56074 Mdot
.59729 .36358 Mdot
.4268 .38737 Mdot
.2059 .5749 Mdot
.35576 .30389 Mdot
.63024 .19517 Mdot
.38398 .80443 Mdot
.40717 .23208 Mdot
.37421 .78819 Mdot
.26092 .71171 Mdot
.20384 .46253 Mdot
.47889 .77967 Mdot
.42505 .19025 Mdot
.76668 .65374 Mdot
.31465 .25894 Mdot
.39578 .32917 Mdot
.57505 .4574 Mdot
.17606 .42275 Mdot
.3069 .39878 Mdot
.56503 .18641 Mdot
.67772 .53511 Mdot
.32217 .60921 Mdot
.40087 .60377 Mdot
.32017 .52887 Mdot
.54464 .59157 Mdot
.2549 .66289 Mdot
.26332 .74299 Mdot
.32588 .35156 Mdot
.14597 .44953 Mdot
.24556 .37677 Mdot
.82825 .35342 Mdot
.71941 .58648 Mdot
.3743 .59261 Mdot
.61878 .44769 Mdot
.7228 .70125 Mdot
.45141 .71515 Mdot
.33034 .63755 Mdot
.65549 .72663 Mdot
.59938 .28193 Mdot
.34947 .56393 Mdot
.39475 .28495 Mdot
.65929 .61799 Mdot
.4819 .73886 Mdot
.70156 .35646 Mdot
.26567 .70253 Mdot
.50266 .55344 Mdot
.35427 .68723 Mdot
.63528 .64806 Mdot
.84605 .60925 Mdot
.50506 .26469 Mdot
.23125 .58195 Mdot
.56598 .61229 Mdot
.26416 .65206 Mdot
.80117 .40519 Mdot
.5901 .30899 Mdot
.72741 .69699 Mdot
.65743 .77667 Mdot
.19145 .56566 Mdot
.68581 .77567 Mdot
.31763 .62497 Mdot
.41447 .40939 Mdot
.24727 .54348 Mdot
.38199 .2528 Mdot
.59692 .39145 Mdot
.54157 .80275 Mdot
.64679 .42042 Mdot
.29111 .56525 Mdot
.80863 .49579 Mdot
.31632 .35852 Mdot
.41295 .2126 Mdot
.67012 .39485 Mdot
.39779 .37295 Mdot
.54725 .11835 Mdot
.47387 .83052 Mdot
.42631 .73312 Mdot
.26168 .75864 Mdot
.45675 .60949 Mdot
.45708 .23231 Mdot
.53302 .66044 Mdot
.44225 .84231 Mdot
.3422 .5585 Mdot
.59414 .84517 Mdot
.35749 .80703 Mdot
.66129 .23367 Mdot
.29835 .18382 Mdot
.72566 .67194 Mdot
.44551 .58533 Mdot
.46619 .49498 Mdot
.55061 .25207 Mdot
.71781 .28028 Mdot
.61744 .20852 Mdot
.56342 .75206 Mdot
.19742 .37082 Mdot
.44428 .83776 Mdot
.38168 .24457 Mdot
.31243 .24403 Mdot
.81829 .43974 Mdot
.54507 .48492 Mdot
.28422 .56926 Mdot
.61221 .60866 Mdot
.32931 .74226 Mdot
.59563 .81127 Mdot
.50485 .27822 Mdot
.34599 .17681 Mdot
.64418 .36132 Mdot
.74122 .44744 Mdot
.21743 .63482 Mdot
.60995 .27068 Mdot
.44017 .25213 Mdot
.80135 .55562 Mdot
.5179 .3936 Mdot
.79835 .58253 Mdot
.39702 .78359 Mdot
.58582 .6258 Mdot
.77174 .64003 Mdot
.34422 .72037 Mdot
.1875 .45166 Mdot
.27408 .51046 Mdot
.71663 .71191 Mdot
.31037 .54223 Mdot
.57748 .29022 Mdot
.4638 .2489 Mdot
.25324 .74332 Mdot
.59367 .61443 Mdot
.20396 .69196 Mdot
.79611 .50477 Mdot
.40541 .34162 Mdot
.50966 .32243 Mdot
.43026 .46421 Mdot
.55608 .28904 Mdot
.44223 .43674 Mdot
.49575 .72815 Mdot
.24013 .71682 Mdot
.23765 .37624 Mdot
.58479 .6478 Mdot
.5732 .77554 Mdot
.18584 .60686 Mdot
.22165 .50748 Mdot
.767 .4412 Mdot
.56439 .34466 Mdot
.84893 .51755 Mdot
.63517 .54542 Mdot
.37692 .24432 Mdot
.47944 .62893 Mdot
.72794 .36398 Mdot
.35086 .47907 Mdot
.70585 .28035 Mdot
.23921 .71573 Mdot
.77629 .55261 Mdot
.79396 .47043 Mdot
.62494 .25899 Mdot
.38871 .20676 Mdot
.56663 .78501 Mdot
.4557 .30747 Mdot
.30718 .6452 Mdot
.6578 .41834 Mdot
.23705 .47436 Mdot
.34109 .25827 Mdot
.711 .46655 Mdot
.42432 .44439 Mdot
.68819 .29684 Mdot
.71718 .52066 Mdot
.57031 .57126 Mdot
.75105 .7409 Mdot
.5241 .39295 Mdot
.67993 .72425 Mdot
.17989 .53979 Mdot
.53339 .26452 Mdot
.22029 .62605 Mdot
.33116 .69185 Mdot
.67184 .78021 Mdot
.32795 .79148 Mdot
.70138 .4427 Mdot
.52298 .82779 Mdot
.24769 .74593 Mdot
.70681 .75237 Mdot
.53589 .37354 Mdot
.50578 .68613 Mdot
.78364 .73704 Mdot
.60669 .54402 Mdot
.62386 .76947 Mdot
.29795 .29365 Mdot
.61672 .70177 Mdot
.37483 .61121 Mdot
.38401 .35074 Mdot
.47068 .55057 Mdot
.35787 .51059 Mdot
.41822 .43144 Mdot
.78908 .68461 Mdot
.69327 .75216 Mdot
.74171 .73423 Mdot
.16454 .49354 Mdot
.52357 .832 Mdot
.43766 .55334 Mdot
.31145 .38449 Mdot
.40945 .52727 Mdot
.50184 .39715 Mdot
.67767 .35946 Mdot
.72612 .66938 Mdot
.70351 .30636 Mdot
.43815 .69712 Mdot
.31058 .53732 Mdot
.49207 .80544 Mdot
.9097 .46741 Mdot
.2424 .39727 Mdot
.32946 .29167 Mdot
.74727 .6619 Mdot
.55092 .2941 Mdot
.3572 .75976 Mdot
.6783 .25835 Mdot
.23088 .68925 Mdot
.40492 .52745 Mdot
.30087 .27959 Mdot
.72795 .49731 Mdot
.49176 .20618 Mdot
.72223 .51657 Mdot
.28956 .74617 Mdot
.42234 .50513 Mdot
.75082 .35264 Mdot
.3961 .63351 Mdot
.66264 .22919 Mdot
.73303 .4058 Mdot
.65526 .65945 Mdot
.34869 .24576 Mdot
.54972 .73895 Mdot
.54324 .30051 Mdot
.48423 .53036 Mdot
.38054 .43282 Mdot
.49837 .49037 Mdot
.53213 .29135 Mdot
.50958 .20961 Mdot
.57924 .81208 Mdot
.2568 .77095 Mdot
.83561 .60066 Mdot
.14206 .46454 Mdot
.39398 .77723 Mdot
.49133 .42496 Mdot
.20596 .63941 Mdot
.69425 .77908 Mdot
.33168 .80023 Mdot
.73051 .60226 Mdot
.59788 .51321 Mdot
.55464 .63508 Mdot
.82092 .61891 Mdot
.72971 .5295 Mdot
.2406 .67355 Mdot
.80592 .58388 Mdot
.53621 .69188 Mdot
.80798 .37255 Mdot
.6853 .75192 Mdot
.35618 .46516 Mdot
.53395 .34484 Mdot
.51105 .40279 Mdot
.33304 .35162 Mdot
.29783 .56969 Mdot
.62038 .64204 Mdot
.57571 .30296 Mdot
.64583 .54792 Mdot
.69339 .3623 Mdot
.31375 .63927 Mdot
.3993 .42093 Mdot
.48887 .48578 Mdot
.32011 .60996 Mdot
.49275 .77992 Mdot
.55453 .70907 Mdot
.56615 .83261 Mdot
.72366 .65939 Mdot
.44898 .45379 Mdot
.52716 .26546 Mdot
.74928 .56437 Mdot
.80681 .54281 Mdot
.49328 .62143 Mdot
.36199 .79499 Mdot
.57409 .47444 Mdot
.57551 .29162 Mdot
.33838 .34106 Mdot
.19144 .461 Mdot
.39926 .33456 Mdot
.41809 .74982 Mdot
.28489 .47133 Mdot
.56773 .55418 Mdot
.28617 .56679 Mdot
.28299 .56809 Mdot
.16344 .59117 Mdot
.764 .61116 Mdot
.63055 .65491 Mdot
.34942 .78705 Mdot
.51685 .6325 Mdot
.31002 .58508 Mdot
.66753 .35866 Mdot
.18333 .46607 Mdot
.30158 .44708 Mdot
.76646 .41863 Mdot
.67972 .69101 Mdot
.72259 .46063 Mdot
.3657 .78915 Mdot
.39017 .80246 Mdot
.61637 .18212 Mdot
.34341 .52265 Mdot
.19673 .49709 Mdot
.22809 .35115 Mdot
.3029 .5935 Mdot
.40029 .57876 Mdot
.46193 .71147 Mdot
.57768 .82095 Mdot
.50906 .70227 Mdot
.18911 .37841 Mdot
.52285 .22366 Mdot
.62054 .71423 Mdot
.77956 .41108 Mdot
.35375 .23755 Mdot
.33721 .77914 Mdot
.37036 .30138 Mdot
.36833 .48389 Mdot
.38404 .39213 Mdot
.5565 .38426 Mdot
.86132 .55857 Mdot
.61027 .58785 Mdot
.32423 .39675 Mdot
.33124 .70957 Mdot
.44109 .35671 Mdot
.83747 .61845 Mdot
.19965 .54656 Mdot
.82295 .52662 Mdot
.55259 .66579 Mdot
.4615 .33956 Mdot
.50811 .38097 Mdot
.55236 .34133 Mdot
.41197 .73153 Mdot
.63496 .7758 Mdot
.34805 .23983 Mdot
.34763 .73821 Mdot
.35479 .30656 Mdot
.67633 .72672 Mdot
.25794 .68646 Mdot
.21576 .5885 Mdot
.54359 .52617 Mdot
.73072 .65911 Mdot
.60427 .25368 Mdot
.14876 .46159 Mdot
.59548 .45131 Mdot
.43178 .56908 Mdot
.44482 .67581 Mdot
.37405 .72362 Mdot
.75034 .36646 Mdot
.49548 .3671 Mdot
.79297 .52607 Mdot
.25981 .70674 Mdot
.53496 .16833 Mdot
.75478 .32816 Mdot
.82777 .63432 Mdot
.31024 .47994 Mdot
.35476 .71057 Mdot
.25259 .62016 Mdot
.48857 .15412 Mdot
.5838 .44953 Mdot
.48128 .81841 Mdot
.61039 .25356 Mdot
.35739 .78802 Mdot
.48857 .6752 Mdot
.41245 .63096 Mdot
.57777 .77519 Mdot
.55295 .82194 Mdot
.2363 .51676 Mdot
.28502 .73527 Mdot
.45147 .59376 Mdot
.64008 .81086 Mdot
.53288 .7526 Mdot
.4567 .53836 Mdot
.69496 .551 Mdot
.78057 .56439 Mdot
.37345 .78084 Mdot
.45387 .78643 Mdot
.34875 .24953 Mdot
.65755 .59348 Mdot
.64325 .34442 Mdot
.35205 .43158 Mdot
.64421 .29493 Mdot
.37351 .73229 Mdot
.52762 .2652 Mdot
.26679 .73348 Mdot
.60676 .44855 Mdot
.79184 .49235 Mdot
.67347 .72609 Mdot
.28833 .25765 Mdot
.41698 .72963 Mdot
.7709 .60069 Mdot
.22917 .5926 Mdot
.73488 .42758 Mdot
.43026 .23693 Mdot
.32799 .85615 Mdot
.27091 .29106 Mdot
.50568 .76841 Mdot
.5968 .81038 Mdot
.21587 .61766 Mdot
.50436 .77698 Mdot
.7276 .28843 Mdot
.45913 .26685 Mdot
.64457 .33336 Mdot
.45126 .39221 Mdot
.74149 .74517 Mdot
.61759 .29478 Mdot
.61314 .81031 Mdot
.19563 .62631 Mdot
.33434 .36412 Mdot
.3996 .42039 Mdot
.6131 .55343 Mdot
.62801 .62208 Mdot
.66461 .31319 Mdot
.34812 .49783 Mdot
.41795 .25768 Mdot
.69894 .67394 Mdot
.68541 .56923 Mdot
.72496 .51707 Mdot
.39283 .52871 Mdot
.72696 .63961 Mdot
.39595 .73656 Mdot
.68426 .40993 Mdot
.53292 .54955 Mdot
.53473 .28757 Mdot
.43557 .27794 Mdot
.35306 .46458 Mdot
.71291 .29019 Mdot
.53026 .49546 Mdot
.67652 .55024 Mdot
.32834 .48919 Mdot
.20459 .36619 Mdot
.37417 .74592 Mdot
.64964 .78287 Mdot
.79207 .54944 Mdot
.3964 .48118 Mdot
.53549 .29863 Mdot
.70294 .26768 Mdot
.46672 .19551 Mdot
.50327 .79182 Mdot
.44471 .28984 Mdot
.43002 .22007 Mdot
.34533 .64285 Mdot
.49558 .8435 Mdot
.31167 .26316 Mdot
.26989 .31058 Mdot
.65296 .60896 Mdot
.29932 .40819 Mdot
.34041 .3802 Mdot
.57398 .24308 Mdot
.53098 .56438 Mdot
.8368 .37354 Mdot
.33762 .61623 Mdot
.87726 .55729 Mdot
.51075 .67476 Mdot
.82969 .44925 Mdot
.59669 .23895 Mdot
.48405 .52727 Mdot
.51844 .56915 Mdot
.42817 .75132 Mdot
.41538 .65714 Mdot
.16072 .45765 Mdot
.60494 .19076 Mdot
.61341 .56866 Mdot
.35401 .22693 Mdot
.30556 .23472 Mdot
.30854 .50672 Mdot
.39921 .38458 Mdot
.266 .29348 Mdot
.62905 .58596 Mdot
.70501 .30681 Mdot
.20437 .61517 Mdot
.42855 .7739 Mdot
.50939 .44643 Mdot
.55696 .29624 Mdot
.47165 .81684 Mdot
.3249 .78504 Mdot
.77406 .33309 Mdot
.3973 .78334 Mdot
.50847 .6867 Mdot
.4445 .54424 Mdot
.30458 .74361 Mdot
.47951 .23295 Mdot
.35989 .67438 Mdot
.45397 .24509 Mdot
.87751 .47482 Mdot
.60825 .77988 Mdot
.63365 .7757 Mdot
.47337 .2404 Mdot
.37434 .54202 Mdot
.51255 .74825 Mdot
.4448 .25161 Mdot
.43833 .77108 Mdot
.17606 .43657 Mdot
.45683 .24922 Mdot
.58533 .1582 Mdot
.21709 .40231 Mdot
.64618 .47133 Mdot
.34403 .38439 Mdot
.22205 .40289 Mdot
.54244 .68429 Mdot
.66746 .34011 Mdot
.33131 .71427 Mdot
.54263 .67165 Mdot
.38007 .73621 Mdot
.36767 .70365 Mdot
.2414 .35118 Mdot
.31159 .44672 Mdot
.36228 .75075 Mdot
.27232 .53367 Mdot
.26783 .57597 Mdot
.72707 .34753 Mdot
.70717 .53742 Mdot
.31124 .70313 Mdot
.68831 .53361 Mdot
.39035 .31614 Mdot
.56512 .53976 Mdot
.43311 .47584 Mdot
.83038 .59898 Mdot
.65658 .41733 Mdot
.37599 .58305 Mdot
.83967 .45259 Mdot
.31374 .60264 Mdot
.77116 .70888 Mdot
.69176 .27085 Mdot
.33879 .33411 Mdot
.70984 .43407 Mdot
.69616 .47887 Mdot
.72256 .23707 Mdot
.38619 .49592 Mdot
.65576 .61077 Mdot
.28435 .54745 Mdot
.37689 .56273 Mdot
.68997 .70228 Mdot
.66939 .57606 Mdot
.50435 .29755 Mdot
.44921 .65438 Mdot
.40564 .50729 Mdot
.36576 .52293 Mdot
.56734 .50007 Mdot
.5939 .33766 Mdot
.56928 .82369 Mdot
.66816 .56109 Mdot
.86208 .4675 Mdot
.39105 .35949 Mdot
.26329 .5042 Mdot
.22541 .68564 Mdot
.79362 .35365 Mdot
.61084 .52938 Mdot
.32447 .20897 Mdot
.41807 .33568 Mdot
.36702 .75823 Mdot
.34828 .5576 Mdot
.28559 .29537 Mdot
.65548 .40411 Mdot
.53892 .25978 Mdot
.54904 .62592 Mdot
.75243 .35606 Mdot
.71926 .64091 Mdot
.37333 .53602 Mdot
.42688 .78478 Mdot
.19714 .47095 Mdot
.38998 .65218 Mdot
.69579 .49044 Mdot
.32993 .49666 Mdot
.30731 .44093 Mdot
.369 .52559 Mdot
.61183 .78904 Mdot
.28997 .2863 Mdot
.47088 .85578 Mdot
.42724 .46212 Mdot
.76774 .51881 Mdot
.43841 .65251 Mdot
.39722 .74775 Mdot
.50775 .30952 Mdot
.23652 .70319 Mdot
.58702 .3013 Mdot
.45544 .68553 Mdot
.56529 .31627 Mdot
.37745 .34274 Mdot
.52046 .54347 Mdot
.65643 .63863 Mdot
.66098 .20737 Mdot
.5448 .35054 Mdot
.80354 .39702 Mdot
.43653 .29034 Mdot
.69233 .71336 Mdot
.39404 .56081 Mdot
.61439 .49978 Mdot
.3075 .41028 Mdot
.59593 .61661 Mdot
.48065 .84493 Mdot
.23363 .69786 Mdot
.56373 .64301 Mdot
.67595 .71261 Mdot
.27976 .66053 Mdot
.41536 .4525 Mdot
.44101 .60357 Mdot
.41448 .40312 Mdot
.39714 .56795 Mdot
.80807 .36587 Mdot
.42897 .76293 Mdot
.46312 .30712 Mdot
.48125 .83632 Mdot
.4317 .8381 Mdot
.63134 .81232 Mdot
.39454 .21095 Mdot
.33688 .53431 Mdot
.73323 .73392 Mdot
.40445 .2691 Mdot
.27802 .75706 Mdot
.49234 .79111 Mdot
.17143 .60636 Mdot
.36196 .4893 Mdot
.32557 .6988 Mdot
.61989 .20388 Mdot
.39848 .67438 Mdot
.20171 .5834 Mdot
.45258 .51479 Mdot
.61225 .66431 Mdot
.19868 .5907 Mdot
.60358 .14481 Mdot
.47988 .29785 Mdot
.35738 .6948 Mdot
.39217 .62278 Mdot
.31816 .7083 Mdot
.7589 .45191 Mdot
.48787 .41566 Mdot
.58148 .74049 Mdot
.78744 .43472 Mdot
.52043 .27799 Mdot
.64531 .34513 Mdot
.75725 .45144 Mdot
.67738 .33006 Mdot
.57948 .32835 Mdot
.31484 .25805 Mdot
.35338 .48872 Mdot
.51005 .3042 Mdot
.40403 .34117 Mdot
.39318 .57347 Mdot
.60648 .39226 Mdot
.64735 .49693 Mdot
.42193 .40925 Mdot
.59464 .54783 Mdot
.39794 .65682 Mdot
.81411 .65368 Mdot
.58163 .65247 Mdot
.1876 .52081 Mdot
.32208 .61465 Mdot
.41475 .73821 Mdot
.24642 .57828 Mdot
.81728 .46972 Mdot
.75458 .49358 Mdot
.50466 .27802 Mdot
.44671 .82676 Mdot
.76962 .64281 Mdot
.19736 .4249 Mdot
.76515 .671 Mdot
.52664 .6854 Mdot
.52668 .41861 Mdot
.41232 .60421 Mdot
.75531 .57778 Mdot
.29823 .54377 Mdot
.33116 .70308 Mdot
.6879 .60032 Mdot
.77037 .61862 Mdot
.18066 .54466 Mdot
.19472 .46384 Mdot
.36324 .44578 Mdot
.40171 .80932 Mdot
.63569 .57276 Mdot
.27129 .30201 Mdot
.3523 .66868 Mdot
.75702 .51237 Mdot
.67477 .74171 Mdot
.5417 .83786 Mdot
.47053 .58628 Mdot
.59296 .27224 Mdot
.45415 .35029 Mdot
.31681 .31056 Mdot
.43558 .76044 Mdot
.54334 .4311 Mdot
.69384 .6579 Mdot
.34236 .59765 Mdot
.68083 .64905 Mdot
.57916 .43735 Mdot
.64588 .3298 Mdot
.34839 .51353 Mdot
.38374 .2552 Mdot
.6019 .37672 Mdot
.45682 .63038 Mdot
.4255 .43386 Mdot
.57526 .26612 Mdot
.41278 .20981 Mdot
.52099 .42173 Mdot
.36507 .76988 Mdot
.34243 .4878 Mdot
.18668 .44103 Mdot
.3938 .75959 Mdot
.51217 .79163 Mdot
.41487 .66388 Mdot
.31874 .41786 Mdot
.73669 .58591 Mdot
.41722 .4169 Mdot
.61109 .50472 Mdot
.31817 .59726 Mdot
.25628 .65855 Mdot
.3049 .47751 Mdot
.5824 .25266 Mdot
.50449 .51767 Mdot
.2484 .56541 Mdot
.49927 .50498 Mdot
.21333 .6539 Mdot
.39967 .67561 Mdot
.57961 .30515 Mdot
.47793 .6689 Mdot
.59484 .24012 Mdot
.72123 .29019 Mdot
.39182 .82063 Mdot
.68511 .25325 Mdot
.47453 .56815 Mdot
.80521 .3923 Mdot
.50994 .75943 Mdot
.19837 .60913 Mdot
.58652 .31552 Mdot
.48467 .58137 Mdot
.64661 .35149 Mdot
.56551 .63357 Mdot
.54055 .50386 Mdot
.60968 .48796 Mdot
.45656 .27511 Mdot
.65336 .686 Mdot
.68429 .61558 Mdot
.38179 .36881 Mdot
.6264 .76278 Mdot
.42842 .82002 Mdot
.29125 .2955 Mdot
.51231 .49138 Mdot
.71611 .37159 Mdot
.64167 .32359 Mdot
.12594 .46631 Mdot
.84915 .60613 Mdot
.45177 .35018 Mdot
.51974 .48645 Mdot
.57197 .27751 Mdot
.60882 .56054 Mdot
.4304 .26455 Mdot
.25659 .57442 Mdot
.49399 .66074 Mdot
.5971 .50176 Mdot
.77824 .60467 Mdot
.43763 .75257 Mdot
.6381 .28213 Mdot
.59685 .75674 Mdot
.81005 .66418 Mdot
.17847 .40816 Mdot
.4098 .7538 Mdot
.12772 .5266 Mdot
.69027 .62162 Mdot
.28156 .59222 Mdot
.24323 .54889 Mdot
.58405 .81336 Mdot
.52319 .25964 Mdot
.7474 .37588 Mdot
.54356 .78811 Mdot
.589 .30749 Mdot
.42448 .24586 Mdot
.67753 .72305 Mdot
.68659 .65072 Mdot
.48161 .54234 Mdot
.69818 .4801 Mdot
.72822 .71362 Mdot
.35542 .31315 Mdot
.44524 .81811 Mdot
.78898 .43195 Mdot
.55564 .14761 Mdot
.44492 .84368 Mdot
.68367 .3598 Mdot
.7613 .44371 Mdot
.24141 .54351 Mdot
.50313 .22576 Mdot
.40884 .25226 Mdot
.72252 .32018 Mdot
.29177 .44406 Mdot
.67775 .46513 Mdot
.79998 .41726 Mdot
.54174 .29947 Mdot
.22714 .39127 Mdot
.48782 .57943 Mdot
.34348 .47313 Mdot
.70239 .68267 Mdot
.48522 .24809 Mdot
.58534 .48576 Mdot
.53611 .23612 Mdot
.3246 .49421 Mdot
.23535 .59568 Mdot
.32018 .67391 Mdot
.63903 .16862 Mdot
.51331 .80089 Mdot
.81636 .46222 Mdot
.45399 .44001 Mdot
.5094 .85114 Mdot
.33379 .67557 Mdot
.536 .79304 Mdot
.17385 .49657 Mdot
.63876 .48366 Mdot
.43718 .62906 Mdot
.41859 .41827 Mdot
.43728 .79948 Mdot
.32685 .3987 Mdot
.2189 .42001 Mdot
.7666 .37803 Mdot
.53814 .27278 Mdot
.772 .44542 Mdot
.55913 .23256 Mdot
.4967 .44842 Mdot
.34085 .6053 Mdot
.73158 .74467 Mdot
.45754 .58112 Mdot
.40269 .30557 Mdot
.54424 .41667 Mdot
.63019 .20751 Mdot
.21993 .32213 Mdot
.43645 .46466 Mdot
.75446 .66461 Mdot
.40058 .24172 Mdot
.38181 .45188 Mdot
.40151 .28963 Mdot
.17475 .29511 Mdot
.26106 .76822 Mdot
.34295 .52839 Mdot
.34147 .27164 Mdot
.41328 .22613 Mdot
.57576 .81514 Mdot
.72959 .49593 Mdot
.69286 .50986 Mdot
.56217 .19158 Mdot
.47951 .22009 Mdot
.39848 .35206 Mdot
.17661 .52762 Mdot
.37341 .81143 Mdot
.77626 .38755 Mdot
.47129 .83729 Mdot
.45244 .29784 Mdot
.47129 .31466 Mdot
.14322 .36868 Mdot
.31348 .75354 Mdot
.51656 .39439 Mdot
.63131 .20518 Mdot
.28338 .57335 Mdot
.4355 .38527 Mdot
.61037 .75561 Mdot
.34345 .24625 Mdot
.54171 .30184 Mdot
.55459 .82163 Mdot
.33333 .52047 Mdot
.59119 .60186 Mdot
.49024 .65821 Mdot
.52314 .56722 Mdot
.44003 .32236 Mdot
.53372 .64507 Mdot
.38864 .45737 Mdot
.31077 .69356 Mdot
.54939 .68037 Mdot
.32437 .23875 Mdot
.19157 .66602 Mdot
.32338 .47031 Mdot
.53933 .6067 Mdot
.40583 .4502 Mdot
.21573 .40933 Mdot
.66853 .3185 Mdot
.41724 .5438 Mdot
.19198 .59225 Mdot
.43999 .89 Mdot
.62074 .66795 Mdot
.58905 .35442 Mdot
.34475 .51295 Mdot
.50582 .3027 Mdot
.34991 .44204 Mdot
.46374 .66408 Mdot
.64186 .57097 Mdot
.41757 .44732 Mdot
.49256 .45005 Mdot
.55348 .63978 Mdot
.87283 .55082 Mdot
.49539 .40019 Mdot
.41653 .28386 Mdot
.28309 .75861 Mdot
.72881 .34908 Mdot
.25198 .50032 Mdot
.48081 .33461 Mdot
.49545 .73575 Mdot
.48307 .58262 Mdot
.29317 .70613 Mdot
.79094 .49779 Mdot
.51468 .82449 Mdot
.30197 .47711 Mdot
.34927 .40054 Mdot
.47455 .4152 Mdot
.60969 .41378 Mdot
.36791 .69139 Mdot
.56499 .79434 Mdot
.48146 .30603 Mdot
.30771 .78087 Mdot
.64174 .48158 Mdot
.66657 .69445 Mdot
.37392 .44018 Mdot
.65483 .79303 Mdot
.78552 .37166 Mdot
.33621 .39612 Mdot
.82773 .50103 Mdot
.75994 .59454 Mdot
.64149 .29447 Mdot
.61558 .55797 Mdot
.42173 .30637 Mdot
.33922 .51907 Mdot
.80969 .67187 Mdot
.57156 .7933 Mdot
.57513 .71808 Mdot
.65542 .66181 Mdot
.30922 .33833 Mdot
.36778 .65103 Mdot
.15479 .59186 Mdot
.73724 .5267 Mdot
.81881 .65229 Mdot
.26999 .30841 Mdot
.38028 .50943 Mdot
.35316 .71593 Mdot
.53026 .39539 Mdot
.67088 .55016 Mdot
.55158 .81433 Mdot
.48431 .45128 Mdot
.80485 .48431 Mdot
.4623 .33066 Mdot
.81876 .54333 Mdot
.58235 .53319 Mdot
.65049 .73706 Mdot
.55378 .73891 Mdot
.72951 .29254 Mdot
.24327 .65962 Mdot
.55641 .69205 Mdot
.13954 .53813 Mdot
.26248 .6707 Mdot
.36324 .79646 Mdot
.76111 .40987 Mdot
.75922 .30089 Mdot
.46355 .78792 Mdot
.36612 .75031 Mdot
.56551 .70832 Mdot
.43995 .49122 Mdot
.77756 .56142 Mdot
.38308 .44723 Mdot
.38452 .69587 Mdot
.5655 .64883 Mdot
.561 .91554 Mdot
.67166 .37367 Mdot
.30131 .62464 Mdot
.76237 .56002 Mdot
.40666 .81813 Mdot
.48821 .47324 Mdot
.18192 .5612 Mdot
.57559 .45783 Mdot
.44947 .30727 Mdot
.30497 .45717 Mdot
.30647 .28411 Mdot
.78717 .56398 Mdot
.7634 .2693 Mdot
.17875 .41221 Mdot
.65813 .67611 Mdot
.53911 .5413 Mdot
.30162 .58918 Mdot
.36947 .6141 Mdot
.70659 .4577 Mdot
.15983 .52875 Mdot
.32061 .6969 Mdot
.30572 .74497 Mdot
.70914 .2274 Mdot
.21622 .37963 Mdot
.57918 .81721 Mdot
.48472 .76679 Mdot
.37089 .6072 Mdot
.68807 .35687 Mdot
.68244 .42969 Mdot
.56792 .73667 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0:kooooo0_l0002Iooooo`007?ooool00ol0003ooooooooo
o`2^ooooo`;o0000VOooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`24ooooo`;o00009ooo
ool2o`0009[ooooo000Looooo`03o`000?oooooooooo08Cooooo0_l0000Wooooo`;o0000V_ooool0
01cooooo00?o0000ooooooooool0P_ooool2o`000<Gooooo000Looooo`03o`000?oooooooooo08;o
oooo0_l0000]ooooo`;o00003Oooool2o`0008Oooooo000Looooo`03o`000?oooooooooo0;7ooooo
0_l0000=ooooo`;o0000Qoooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooo
oooo09_ooooo0_l0002/ooooo`007?ooool00ol0003oooooooooo`2<ooooo`;o00003Oooool2o`00
01gooooo0_l0002=ooooo`007?ooool00ol0003oooooooooo`2<ooooo`;o0000;?ooool2o`0008go
oooo000Looooo`03o`000?oooooooooo08[ooooo0_l00005ooooo`;o0000<?ooool2o`0008Cooooo
000Looooo`03o`000?oooooooooo08[ooooo0_l00005ooooo`;o00003Oooool2o`0000Sooooo0_l0
000Gooooo`;o00001oooool2o`0007_ooooo000Looooo`03o`000?oooooooooo07Cooooo0_l0000Z
ooooo`;o00000_ooool2o`0000Cooooo0_l0000Booooo`;o00003?ooool2o`0007_ooooo000Loooo
o`03o`000?oooooooooo07Cooooo0_l00008ooooo`;o00008?ooool3o`000003ooooool0003o0000
00Wooooo0_l0000=ooooo`;o0000ROooool001cooooo00?o0000ooooooooool0KOooool2o`0000oo
oooo0_l000000ooooooo0000o`00000Nooooo`;o00003?ooool2o`0001Oooooo0ol0001nooooo`00
7?ooool00ol0003oooooooooo`1]ooooo`;o00001?ooool2o`0000cooooo0_l0000Dooooo`;o0000
4?ooool2o`0000cooooo0_l0000?ooooo`?o0000O_ooool001cooooo00?o0000ooooooooool0GOoo
ool2o`0000kooooo0_l00004ooooo`;o00008_ooool2o`00013ooooo0_l00007ooooo`;o00000ooo
ool2o`0000_ooooo0_l00023ooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o00000oooool2
o`0001gooooo0_l0000Sooooo`;o00001_ooool2o`0000;ooooo1?l0000>ooooo`;o0000Poooool0
01cooooo00?o0000ooooooooool0H_ooool2o`0001gooooo0_l00003ooooo`;o00003?ooool2o`00
00cooooo0_l00002ooooo`;o00001_ooool2o`0000;ooooo1?l0000;ooooo`;o0000Q_ooool00006
ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooo
oooo07[ooooo0_l0000:ooooo`;o00003?ooool2o`0000cooooo0_l0000>ooooo`?o00001_ooool2
o`0000Cooooo0_l00026ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0L?ooool2o`0000;ooooo
0_l00004ooooo`;o00002oooool2o`0000_ooooo0_l0000Looooo`?o00001_ooool2o`0000cooooo
0_l00005ooooo`;o000000?oooooo`000?l00000M?ooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo073ooooo0_l0
0002ooooo`;o00003?ooool2o`0000?ooooo0ol00007ooooo`;o000000Coooooo`000?l0003o0000
4oooool2o`0001gooooo0_l00005ooooo`;o000000?oooooo`000?l00000M?ooool00003ooooool0
003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06ooooo`?o0000P_oo
ool2o`0000Cooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo0_l00008ooooo`;o00002Ooo
ool2o`0009gooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oMgMg
ofIVI_ooool01Oooool00ol0003oooooooooo`1^ooooo`;o00007Oooool2o`0000gooooo1Ol0000U
ooooo`Ko0000OOooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool03Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo06Kooooo0_l00006ooooo`;o00002oooool2o`00
013ooooo0_l0000=ooooo`Co00009Oooool7o`0000Oooooo0_l0001dooooo`0000KoooooogMgMonH
V9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003ooooooooo
o`1Uooooo`?o00004oooool3o`0000Cooooo0_l00004ooooo`Co000000?oooooo`000?l000002?oo
ool2o`0000Wooooo0_l0000Qooooo`;o000000Coooooo`000?l0003o00002?ooool2o`0007Cooooo
00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006oooo
o`03o`000?oooooooooo06Gooooo0_l00002ooooo`;o00004Oooool4o`0000;ooooo0_l00004oooo
o`Co00001Oooool3o`0000?ooooo1?l00007ooooo`;o00001_ooool2o`0009gooooo000Looooo`03
o`000?oooooooooo067ooooo0_l00006ooooo`;o00002Oooool2o`0000;ooooo0_l00004ooooo`;o
00000_ooool3o`0000Gooooo0_l00005ooooo`?o000000?oooooo`000?l000001?l0000?ooooo`;o
00002?ooool2o`0001kooooo0_l0001cooooo`007?ooool00ol0003oooooooooo`1Kooooo`;o0000
1?ooool2o`0000gooooo0_l00002ooooo`;o00000_ooool3o`0000Kooooo1?l00003ooooo`Co0000
2Oooool2o`000003ooooool0003o000000?ooooo0ol000000ooooooo0000o`000003ooooo`;o0000
1oooool2o`0000;ooooo1Ol0000<ooooo`;o00001_ooool2o`0000Kooooo0_l0001cooooo`007?oo
ool00ol0003oooooooooo`1Kooooo`;o00004oooool2o`0000;ooooo0_l000000ooooooo0000o`00
0002o`0000Gooooo0ol00005ooooo`;o00003_ooool2o`0000?ooooo0ol000000ooooooo0000o`00
0003ooooo`;o00001oooool2o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o00001ooo
ool2o`0000Kooooo0_l0001kooooo`007?ooool00ol0003oooooooooo`1_ooooo`Co000000Cooooo
o`000?l0003ooooo0_l00007ooooo`Go00000_ooool2o`0001Oooooo0_l00002ooooo`Co00002ooo
ool2o`0000Kooooo0_l0000Hooooo`;o00003?ooool2o`0006Cooooo000Looooo`03o`000?oooooo
oooo06oooooo1?l0000;ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00002?ooool2
o`0000;ooooo0_l00009ooooo`;o00000_ooool4o`000003ooooool0003o000000_ooooo0_l0000K
ooooo`Co00003?ooool2o`0006Cooooo000Looooo`03o`000?oooooooooo07kooooo0_l000000ooo
oooo0000o`00000>ooooo`;o00000_ooool2o`000003ooooool0003o000000oooooo0_l00007oooo
o`;o00000_ooool2o`0001_ooooo0ol0001cooooo`007?ooool00ol0003oooooooooo`1Pooooo`Co
00007Oooool2o`0000Gooooo0_l00007ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`00
013ooooo0_l000000ooooooo0000o`000003ooooo`;o00000_ooool3o`000003ooooool0003o0000
01Oooooo0ol000000ooooooo0000o`00000<ooooo`;o0000H_ooool001cooooo00?o0000oooooooo
ool0H?ooool4o`0000;ooooo0_l00005ooooo`Co00002_ooool2o`0000_ooooo1?l00004ooooo`;o
00000_ooool3o`0000_ooooo0_l00006ooooo`Go00002?ooool5o`0000;ooooo0_l0000Gooooo`;o
000000?oooooo`000?l000002Oooool4o`00063ooooo000Looooo`03o`000?oooooooooo06Kooooo
0_l00005ooooo`Co00002_ooool2o`000003ooooool0003o000000Gooooo0_l00002ooooo`?o0000
1?ooool2o`0000Cooooo0_l00007ooooo`;o000000?oooooo`000?l000000ol000001?oooooo0000
o`000?ooool2o`0000[ooooo1?l00002ooooo`?o00006_ooool2o`000003ooooool0003o000000So
oooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`1Rooooo`;o00002?ooool6o`0000Gooooo
0ol00002ooooo`Co00001Oooool3o`0000Sooooo0_l000000ooooooo0000o`000005o`0000Gooooo
0_l00002ooooo`Co000000?oooooo`000?l000003Oooool2o`0000Cooooo0_l0000Nooooo`;o0000
J_ooool001cooooo00?o0000ooooooooool0H_ooool2o`0000Sooooo1_l00002ooooo`;o000000Co
ooooo`000?l0003o00000_ooool2o`0000Sooooo0_l00008ooooo`Oo000000?oooooo`000?l00000
0_l00002ooooo`;o00000oooool2o`0001Oooooo0_l0002;ooooo`007?ooool2o`0006oooooo0_l0
0004ooooo`;o00002oooool2o`000003ooooool0003o000000;o00000oooool4o`0000;ooooo1?l0
0005ooooo`;o00000_ooool2o`0000cooooo0_l000000ooooooo0000o`000007ooooo`;o00000_oo
ool2o`000003ooooool0003o000008Sooooo000Looooo`03o`000?oooooooooo06?ooooo0_l00009
ooooo`;o00002?ooool3o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0000Gooooo1?l0
000Hooooo`;o00000oooool2o`000003ooooool0003o000000Oooooo0ol000001?oooooo0000o`00
0?ooool5o`0001Oooooo0_l0001/ooooo`007?ooool00ol0003oooooooooo`1?ooooo`;o00002Ooo
ool2o`0000Oooooo0_l00006ooooo`;o00002oooool3o`0000?ooooo0_l00004ooooo`;o00004_oo
ool2o`0000gooooo0_l0000@ooooo`;o000000Coooooo`000?l0003ooooo1Ol0000Eooooo`Co0000
K?ooool001cooooo00?o0000ooooooooool0Coooool2o`0000Wooooo0_l00006ooooo`?o00001_oo
ool2o`0000?ooooo0ol0000Aooooo`;o00004_ooool2o`0000Cooooo0_l00006ooooo`;o00000ooo
ool2o`0000gooooo0_l00007ooooo`;o00000_ooool2o`00013ooooo1?l0001/ooooo`007?ooool0
0ol0003oooooooooo`1Gooooo`;o00002Oooool2o`0000cooooo0ol00008ooooo`;o00002oooool2
o`0001;ooooo1_l00004ooooo`Oo000000?oooooo`000?l000000oooool2o`0000Gooooo0_l00007
ooooo`;o00000_ooool2o`0001Kooooo0_l0001Xooooo`007?ooool00ol0003oooooooooo`1Goooo
o`;o00002Oooool2o`0000cooooo0_l00009ooooo`;o000000?oooooo`000?l000002?ooool2o`00
00Oooooo0ol00008ooooo`;o00000_ooool2o`0000Gooooo1?l00003ooooo`;o00000oooool2o`00
00;ooooo0_l0000;ooooo`?o00004oooool2o`0000?ooooo1?l0000<ooooo`;o0000F?ooool001co
oooo00?o0000ooooooooool0Foooool2o`0000gooooo0_l00004ooooo`;o00003?ooool4o`0000Wo
oooo0_l00004ooooo`?o00004oooool3o`0000gooooo0_l00009ooooo`Oo00004Oooool2o`000003
ooooool0003o000000;ooooo0_l0000<ooooo`;o00000oooool2o`0005?ooooo000Looooo`03o`00
0?oooooooooo05_ooooo0_l0000=ooooo`?o00001_ooool2o`0000_ooooo0_l00007ooooo`Co0000
5oooool2o`0000Gooooo0_l000000ooooooo0000o`000007ooooo`;o00001?ooool2o`0000?ooooo
0_l00003ooooo`;o00005?ooool2o`0000[ooooo0_l00009ooooo`;o0000Doooool001cooooo00?o
0000ooooooooool0Ioooool2o`0000;ooooo0_l00006ooooo`Co00001_ooool2o`0000[ooooo0_l0
0006ooooo`;o00002oooool2o`000004ooooool0003o0000ooooo`;o00001Oooool2o`000003oooo
ool0003o000000gooooo0_l0000Jooooo`Co00003?ooool2o`0005kooooo000Looooo`03o`000?oo
oooooooo05Sooooo0_l00004ooooo`;o00001oooool2o`0000cooooo0_l00006ooooo`Go00000_oo
ool2o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l000002oooool5o`0000;ooooo0_l0
000?ooooo`;o00008Oooool4o`0000Cooooo0ol00004ooooo`;o0000Goooool001cooooo00?o0000
ooooooooool0F?ooool2o`0000Cooooo0_l00007ooooo`;o00005Oooool4o`0000;ooooo0_l00004
ooooo`;o00000_ooool9o`0000Wooooo0_l00003ooooo`;o00003oooool2o`0000Oooooo0_l00004
ooooo`;o00000oooool3o`0001Cooooo0ol000001?oooooo0000o`000?ooool2o`0005oooooo000L
ooooo`03o`000?oooooooooo05[ooooo0_l00004ooooo`;o00001Oooool2o`0000[ooooo0_l00007
ooooo`;o00001_ooool2o`0000Wooooo2?l0000@ooooo`;o00003_ooool2o`0000Kooooo0_l00004
ooooo`;o00000oooool3o`0001Cooooo0_l00002ooooo`;o0000H_ooool001cooooo00?o0000oooo
ooooool0@_ooool2o`0001Kooooo0_l00004ooooo`;o00004Oooool2o`0000Oooooo0_l00006oooo
o`;o00003?ooool2o`0001?ooooo0_l000000ooooooo0000o`000005ooooo`;o00001?ooool2o`00
01Gooooo0_l0000<ooooo`;o00002_ooool3o`0005kooooo000Looooo`03o`000?oooooooooo04;o
oooo0_l0000@ooooo`;o00000oooool2o`0000cooooo0_l0000<ooooo`;o00002?ooool2o`0000Wo
oooo0_l000000ooooooo0000o`00000Eooooo`;o00000oooool3o`0000Cooooo0ol00004ooooo`?o
00001Oooool4o`0000_ooooo0_l0000<ooooo`;o00001_ooool7o`0005kooooo000Looooo`03o`00
0?oooooooooo03Gooooo0_l0000Gooooo`;o00000oooool3o`0000?ooooo1_l00008ooooo`;o0000
3?ooool2o`0000Kooooo2?l00005ooooo`Go00004_ooool5o`0000?ooooo0_l00003ooooo`Co0000
1Oooool3o`0000Gooooo1?l00002ooooo`;o00001_ooool2o`0000Gooooo0_l0000>ooooo`Co0000
00?oooooo`000?l00000G_ooool001cooooo00?o0000ooooooooool0=Oooool2o`0001Oooooo0_l0
0003ooooo`?o00000oooool7o`0001Gooooo0_l00006ooooo`;o00000_ooool4o`0000Gooooo2?l0
0006ooooo`;o00001_ooool5o`000003ooooool0003o000000Kooooo1Ol00003ooooo`;o00001ooo
ool4o`0000;ooooo0_l00006ooooo`Go00000_ooool3o`0000Gooooo0_l0000;ooooo`;o00003ooo
ool2o`0004gooooo000Looooo`;o0000COooool2o`00013ooooo0_l0000<ooooo`;o00001oooool2
o`00017ooooo0_l000001?oooooo0000o`000?ooool6o`0000Cooooo0_l00006ooooo`;o000000Co
ooooo`000?l0003ooooo0ol000000ooooooo0000o`000003o`0000;ooooo0_l00003ooooo`Oo0000
0_ooool4o`0000_ooooo1?l00002ooooo`?o000000?oooooo`000?l000000_ooool2o`0000Cooooo
0_l00006ooooo`;o00001oooool2o`0000Gooooo0_l0001=ooooo`007?ooool00ol0003ooooooooo
o`1<ooooo`;o00001_ooool2o`00013ooooo0_l00004ooooo`;o00000_ooool2o`0000?ooooo0_l0
000;ooooo`;o00001?ooool2o`000003ooooool0003o000000Co000000?oooooo`000?l000003Ooo
ool3o`0000?ooooo0_l000000ooooooo0000o`000003o`0000?ooooo2ol00004ooooo`;o00000_oo
ool2o`0000Wooooo0_l00006ooooo`;o00002?ooool2o`0000Kooooo0_l00005ooooo`Co0000E?oo
ool001cooooo00?o0000ooooooooool0Doooool3o`0000oooooo0ol00008ooooo`;o00003Oooool2
o`000004ooooool0003o0000ooooo`;o00001_ooool5o`000004ooooool0003o0000ooooo`;o0000
00?oooooo`000?l000001_ooool3o`0000Sooooo0_l00004ooooo`Wo000000?oooooo`000?l00000
1_ooool5o`0000Oooooo0_l0000;ooooo`;o00000_ooool2o`0000kooooo0_l0001Fooooo`007?oo
ool00ol0003oooooooooo`1Cooooo`?o00003Oooool4o`0000Oooooo1?l00008ooooo`;o00000ooo
ool2o`0000Cooooo0_l00007ooooo`Oo000000Coooooo`000?l0003ooooo0_l00006ooooo`?o0000
0oooool2o`0000oooooo0_l00002ooooo`;o00001_ooool2o`000003ooooool0003o000000[ooooo
0_l00003ooooo`;o00000oooool2o`0000;ooooo0_l0000?ooooo`;o0000EOooool001cooooo00?o
0000ooooooooool0E?ooool3o`0000Wooooo0_l000000ooooooo0000o`000006ooooo`;o000000?o
ooooo`000?l000000_l00004ooooo`;o00000_ooool2o`0000?ooooo0_l00003ooooo`?o00001_oo
ool4o`000003ooooool0003o000000Cooooo0ol00006ooooo`?o00000oooool2o`000004ooooool0
003o0000ooooo`?o00000oooool2o`0000Oooooo0ol0000Dooooo`Co000000?oooooo`000?l00000
6?ooool2o`0005Gooooo000Looooo`03o`000?oooooooooo04cooooo1?l00005ooooo`;o00002Ooo
ool2o`0000?ooooo1?l00002ooooo`;o00000oooool2o`0000Cooooo0_l00003ooooo`;o00000_oo
ool4o`000003ooooool0003o000000;o00001Oooool4o`0000;ooooo1?l000001?oooooo0000o`00
0?l0000?ooooo`Ko00000oooool3o`0000Gooooo1?l00003ooooo`?o00003oooool3o`0000kooooo
0_l0001Rooooo`007?ooool00ol0003oooooooooo`1<ooooo`Go00005?ooool4o`0000_ooooo0_l0
0005ooooo`;o00000_ooool4o`0000;ooooo1_l00002ooooo`Co00000_ooool4o`0000;ooooo0_l0
0004ooooo`;o00002Oooool3o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o000000?o
ooooo`000?l000001Oooool3o`0000Cooooo0_l000001?oooooo0000o`000?l00006ooooo`;o0000
3_ooool5o`0005oooooo000Looooo`03o`000?oooooooooo03Wooooo0_l00009ooooo`;o00000ooo
ool2o`0000Cooooo0_l0000>ooooo`;o00002?ooool2o`0000Wooooo1?l00007ooooo`;o000000?o
ooooo`000?l000001?ooool5o`0000Gooooo2Ol00003ooooo`?o000000?oooooo`000?l000002_oo
ool2o`0000Kooooo1?l00002ooooo`;o00001?ooool2o`0000Gooooo0_l000001?oooooo0000o`00
0?l00006ooooo`;o00002_ooool4o`0000;ooooo0ol00007ooooo`;o0000E_ooool001cooooo00?o
0000ooooooooool0>Oooool2o`0000Wooooo0_l00003ooooo`;o000000?oooooo`000?l000004Ooo
ool4o`000004ooooool0003o0000ooooo`Co00002oooool2o`000003ooooool0003o000000;o0000
00Goooooo`000?l0003o0000ooooo`02o`0000Gooooo1?l00002ooooo`Go000000?oooooo`000?l0
00001Ol000001?oooooo0000o`000?l00002ooooo`;o00004_ooool2o`0000Cooooo0_l00004oooo
o`;o00001Oooool2o`0000;ooooo0_l0000Booooo`Co00002Oooool2o`000003ooooool0003o0000
05Kooooo000Looooo`03o`000?oooooooooo04cooooo0_l0000Cooooo`;o000000?oooooo`000?l0
00000ol0000=ooooo`_o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l000000ooooooo
0000o`000004o`000004ooooool0003o0000ooooo`Oo00001?ooool2o`00017ooooo1?l00003oooo
o`;o00000oooool2o`0000Wooooo0_l0000Oooooo`;o000000?oooooo`000?l00000E_ooool001co
oooo00?o0000ooooooooool0A?ooool2o`0000?ooooo0_l0000Aooooo`;o00001oooool2o`0000oo
oooo2Ol000000ooooooo0000o`00000Eo`000005ooooool0003o0000o`000?ooool01_l000000ooo
oooo0000o`000004ooooo`;o00002oooool4o`0000?ooooo0_l0000;ooooo`;o00000_ooool2o`00
00Sooooo0_l0000?ooooo`;o00001Oooool4o`0005Gooooo000Looooo`03o`000?oooooooooo04Co
oooo0_l00003ooooo`;o000000?oooooo`000?l000003_ooool2o`0000[ooooo1?l0000:ooooo`?o
000000?oooooo`000?l000000_ooool4o`000003ooooool0003o000001;o000000?oooooo`000?l0
00000_l00002ooooo`Co00000oooool7o`0000Wooooo0_l00005ooooo`;o00003?ooool2o`0000;o
oooo0_l00008ooooo`Co00001Oooool2o`0000Kooooo0_l00005ooooo`Go00000oooool2o`0000co
oooo0_l00011ooooo`007?ooool00ol0003oooooooooo`11ooooo`?o00002?ooool2o`0001?ooooo
0_l00005ooooo`Co00002?ooool2o`0000Sooooo0ol000000ooooooo0000o`00000Ho`0000;ooooo
0ol00004ooooo`Co000000?oooooo`000?l000000_l00007ooooo`;o00001Oooool3o`0000Wooooo
0_l00003ooooo`?o00002_ooool2o`0000?ooooo1?l00002ooooo`;o00003?ooool4o`000003oooo
ool0003o000000cooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`11ooooo`?o00007Ooo
ool2o`0000Kooooo0ol00008ooooo`;o00001Oooool2o`0000;ooooo6_l000001?oooooo0000o`00
0?ooool4o`0000?ooooo0_l00006ooooo`;o00000_ooool2o`0000Oooooo1_l00007ooooo`Ko0000
00?oooooo`000?l000001_ooool2o`0000Sooooo0_l00004ooooo`;o00000oooool2o`000003oooo
ool0003o000000Kooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00005?oo
ool3o`0000Sooooo0_l000000ooooooo0000o`000004o`0000;ooooo5_l000000ooooooo0000o`00
0009o`0000?ooooo0_l0000:ooooo`;o00000_ooool2o`0000?ooooo1_l00005ooooo`Co00000_oo
ool2o`000003ooooool0003o000000Kooooo0_l0000>ooooo`;o000000?oooooo`000?l000000_l0
00000ooooooo0000o`00000<ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0Doooool2
o`0000Kooooo0_l0000Fooooo`;o00000_ooool4o`0000Cooooo1Ol00002oooooa_o00001_ooool2
o`000003ooooool0003o000000Sooooo0_l00002ooooo`;o00000oooool3o`0000Cooooo0ol00006
ooooo`?o00003Oooool2o`0000Wooooo0_l0000;ooooo`;o00001?ooool2o`0001;ooooo0_l0000h
ooooo`007?ooool2o`0003Gooooo0_l0000Aooooo`;o00001?ooool2o`0000cooooo0_l0000;oooo
o`;o00000_ooool2o`0000Gooooo1?l00002ooooo`;o00000oooool3o`000004ooooool0003o0000
oooooako000000Coooooo`000?l0003ooooo0_l000001?oooooo0000o`000?ooool2o`0000Wooooo
0_l00004ooooo`;o00001Oooool2o`0000Oooooo0_l000000ooooooo0000o`00000:ooooo`;o0000
2Oooool3o`0000[ooooo1?l0000Fooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0=?oo
ool2o`0000kooooo1Ol00002ooooo`Co00005oooool4o`0000;ooooo0_l00007ooooo`;o00000_oo
ool2o`0000?ooooo0ol000000ooooooo0000o`00000?o`000003ooooool0003o000000go000000Co
ooooo`000?l0003ooooo0_l00004ooooo`;o000000?oooooo`000?l000006Oooool2o`000003oooo
ool0003o000000?o00005_ooool2o`0000Gooooo0_l00005ooooo`Co00000oooool2o`0000Wooooo
0_l0000nooooo`007?ooool00ol0003oooooooooo`14ooooo`Co00000oooool2o`0001;ooooo0_l0
0005ooooo`Co00003oooool4o`000003ooooool0003o000002;o00000_ooool2o`000003ooooool0
003o000000Oooooo1?l00008ooooo`;o00001Oooool2o`0000Kooooo0_l000000ooooooo0000o`00
0002o`0000[ooooo0_l00002ooooo`;o00002oooool2o`000004ooooool0003o0000o`0000Kooooo
0_l00003ooooo`;o00002Oooool2o`0003kooooo000Looooo`03o`000?oooooooooo03kooooo1?l0
0008ooooo`;o00004oooool2o`0000;ooooo0_l0000Fooooo`;o000000?oooooo`000?l000002Ol0
00000ooooooo0000o`00000Co`0000Oooooo0ol00009ooooo`;o00002?ooool2o`0000;ooooo0_l0
00001?oooooo0000o`000?ooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000?o
oooo0_l000000ooooooo0000o`000004o`0000;ooooo0_l00009ooooo`Co00000_ooool2o`0005Ko
oooo000Looooo`03o`000?oooooooooo03kooooo1?l00008ooooo`Co00004_ooool2o`000003oooo
ool0003o000000Oooooo0_l0000=ooooo`;o000000?oooooo`000?l000002Ol000000ooooooo0000
o`00000Do`0000Cooooo1_l0000;ooooo`;o00002Oooool2o`0000Cooooo0_l00002ooooo`;o0000
00?oooooo`000?l000001_ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l00000
3?ooool2o`0000kooooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00002_oo
ool3o`0001;ooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0ol0000;ooooo`Co0000
00?oooooo`000?l000009_l000000ooooooo0000o`000006ooooo`;o00000oooool2o`0000Gooooo
1?l00008ooooo`;o000000?oooooo`000?l000000_l00002ooooo`?o00002Oooool4o`0000Sooooo
0_l0000@ooooo`?o00001Oooool2o`0004Cooooo000Looooo`03o`000?oooooooooo02_ooooo0_l0
000?ooooo`Go00002_ooool3o`0001Sooooo0_l000000ooooooo0000o`000002ooooo`?o00001Ooo
ool2o`000003ooooool0003o000002go000000?oooooo`000?l000001_ooool2o`0000[ooooo1?l0
0007ooooo`Oo000000?oooooo`000?l000000ol0000;ooooo`;o00002?ooool2o`0000Gooooo0_l0
000:ooooo`;o00001Oooool2o`0004Cooooo000Looooo`03o`000?oooooooooo02_ooooo0_l0000?
ooooo`?o00001Oooool2o`0000Cooooo0_l0000Rooooo`;o00001?ooool3o`000003ooooool0003o
000000?ooooo:?l00003ooooo`?o00001_ooool2o`0000Oooooo0_l00002ooooo`?o00001?ooool>
o`000003ooooool0003o000000Wooooo0_l00004ooooo`;o00002Oooool2o`0000Wooooo0_l00002
ooooo`;o00000_ooool2o`0004Cooooo000Looooo`03o`000?oooooooooo03cooooo1?l00004oooo
o`;o00000oooool3o`0001Gooooo0_l0000Aooooo`;o00000oooool2o`0000;ooooo3?l00002oooo
oa[o00001?ooool3o`0000Gooooo0_l00007ooooo`?o000000?oooooo`000?l000000ol00002oooo
o`ko000000?oooooo`000?l000000_l0000=ooooo`;o00005?ooool2o`0000;ooooo0_l00002oooo
o`;o00001oooool2o`0003_ooooo000Looooo`03o`000?oooooooooo03[ooooo0_l000000ooooooo
0000o`000002o`0000;ooooo0ol00003ooooo`;o000000?oooooo`000?l000004oooool2o`0001Ko
oooo0_l000000ooooooo0000o`00000<o`000003ooooool0003o000001Go000000?oooooo`000?l0
00001Oooool2o`0000oooooo0_l000000ooooooo0000o`000004o`000003ooooool0003o000000[o
000000Coooooo`000?l0003ooooo0ol0000Gooooo`Co00000_ooool2o`0001Gooooo0_l0000koooo
o`007?ooool00ol0003oooooooooo`0jooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o
00001?ooool2o`000003ooooool0003o000001gooooo0_l00004ooooo`?o00002?oooolYo`0000[o
oooo0_l0000?oooooaCo000000?oooooo`000?l000001oooool2o`0000Cooooo0_l00009ooooo`Co
00000_ooool2o`0000Kooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`13ooooo`;o0000
7?ooool2o`0000Sooooo0ol00003ooooo`?o000000?oooooo`000?l00000;?l0000<ooooo`Co0000
2Oooool4o`000003ooooool0003o000001?o00001Oooool2o`000003ooooool0003o000000Cooooo
0_l00005ooooo`;o00004?ooool4o`0000Cooooo0_l00005ooooo`;o0000>oooool001cooooo00?o
0000ooooooooool0HOooool2o`0000Wooooo0_l00006oooooboo000000?oooooo`000?l000000_oo
ool2o`0000Kooooo0ol00009ooooo`Co000000?oooooo`000?l000004ol00005ooooo`;o00001_oo
ool2o`0000?ooooo1Ol0000:ooooo`?o00001Oooool2o`0000Cooooo0_l00005ooooo`;o0000>ooo
ool001cooooo00?o0000ooooooooool0<oooool2o`0003oooooo0_l00002ooooo`;o000000?ooooo
o`000?l000000_oooolJo`000003ooooool0003o000000[o00000_ooool2o`0000Kooooo0_l0000>
oooooa7o000000?oooooo`000?l000000_l0000=ooooo`;o00000oooool4o`0000_ooooo0ol0001?
ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo00Cooooo00?o0000ooooooooool0<oooool2o`0000oooooo1?l0000[ooooo`;o00000ooo
ool3o`0000Cooooo3_l000000ooooooo0000o`000009o`000003ooooool0003o000000ko00005?oo
oolCo`000003ooooool0003o000000?o00002?ooool2o`00027ooooo0_l00015ooooo`0000Kooooo
ogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo04Cooooo1?l0000Looooo`Co000000?oooooo`000?l000002?ooool2o`0000Cooooo
0ol00004oooooaWo000000?oooooo`000?l000001ol000000ooooooo0000o`000004o`0000Gooooo
0_l00002ooooo`;o00002OoooolLo`0000Gooooo0_l0000Dooooo`;o00002_ooool3o`0000;ooooo
0_l00011ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`Go00001_oo
ool00ol0003oooooooooo`1;ooooo`;o00004oooool2o`0000;ooooo1?l000000ooooooo0000o`00
000:ooooo`;o00000oooool2o`0000Kooooo8?l00002ooooo`Ko00001Oooool2o`0000;ooooo0_l0
000;oooooa[o00006oooool2o`0000[ooooo0_l00003ooooo`;o0000@Oooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool02Oooool01?m4A4CogMgMooooool00007ooooo`?o0000@ooo
ool3o`0000Gooooo0_l0000Cooooo`;o00000oooool3o`0000Kooooo0_l00005ooooo`;o00000ooo
ool2o`0000Gooooo8?l000000ooooooo0000o`000003ooooo`Co00005OoooolGo`0000Oooooo0_l0
000Dooooo`;o0000Doooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool0
1?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo03cooooo0_l00005ooooo`?o00001Ooo
ool2o`0001Sooooo0_l00007ooooo`;o00002_ooool2o`0000Gooooo8ol00003ooooo`Co00000ooo
ool2o`00013ooooo5ol00005ooooo`Co00000_ooool2o`0000Kooooo0_l00005ooooo`;o000000?o
ooooo`000?l000001?l00006ooooo`;o0000Aoooool00003ooooool@413ooooo00;ooooo00?o410@
ooooooooool02_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo03Kooooo0_l00004
ooooo`;o00001?ooool2o`000003ooooool0003o000000Cooooo0_l0000Aooooo`;o00005_ooool4
o`0000Oooooo8ol00002ooooo`?o000000?oooooo`000?l000000_ooool2o`00017ooooo5_l00000
0ooooooo0000o`000002ooooo`;o00001?ooool2o`0000Kooooo0_l00005ooooo`Co000000?ooooo
o`000?l000000_l00006ooooo`;o0000Aoooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg3?oo
ool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo03Kooooo0_l0000:ooooo`;o000000?o
ooooo`000?l000005oooool4o`0000oooooo0_l00003ooooo`Co00000_ooool4o`000003ooooool0
003o000000Wo000000?oooooo`000?l000003Ol00002ooooo`Ko00000_ooool2o`0000;ooooo0_l0
000Cooooo`;o000000?oooooo`000?l000004_l000000ooooooo0000o`000003o`0000Kooooo0_l0
000?ooooo`;o00001?ooool2o`0004kooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPgooooo
00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`0fooooo`;o0000:?ooool2o`0000oooooo
0_l00005ooooo`;o00000_oooolEo`000003ooooool0003o000000_o000000?oooooo`000?l00000
0oooool3o`0001Oooooo0_l000000ooooooo0000o`00000Io`0000Kooooo0_l00009ooooo`;o0000
0oooool2o`0000Cooooo0_l0000<ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0I?oo
ool2o`0000Cooooo0ol00008ooooo`;o000000?oooooo`000?l000000_ooool3o`000003ooooool0
003o000001Oo000000?oooooo`000?l000000ol00003ooooo`;o000000?oooooo`000?l000000_l0
0004ooooo`;o00004ooooolFo`0000?ooooo0_l00006ooooo`;o00002?ooool3o`0000Gooooo1?l0
0007ooooo`;o00000oooool6o`0003kooooo000Looooo`03o`000?oooooooooo03cooooo0_l00005
ooooo`;o00001?ooool2o`0001Wooooo0_l00004ooooo`?o00002?ooool2o`0000Kooooo8_l00000
0ooooooo0000o`000002o`000003ooooool0003o000000;o00001?ooool3o`0001Cooooo4Ol00007
ooooo`;o00003oooool3o`0000Gooooo1?l00006ooooo`?o00000oooool2o`0000;ooooo0_l0000n
ooooo`007?ooool00ol0003oooooooooo`0aooooo`Ko00001Oooool2o`0000Gooooo0_l00004oooo
o`;o00006?ooool2o`0001Wooooo8Ol000000ooooooo0000o`000002o`000003ooooool0003o0000
00Oooooo0_l0000Eooooo`go00000oooool3o`0000Cooooo0_l00004ooooo`;o00004Oooool2o`00
00Sooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`0Zooooo`;o00001?ooool7o`0000Go
oooo0_l0000Uooooo`;o00001?ooool2o`0000Oooooo0_l0000:oooooaOo000000?oooooo`000?l0
00000_l000000ooooooo0000o`000003o`0000;ooooo0_l000000ooooooo0000o`00000Rooooo`oo
00000oooool2o`0000Gooooo0_l00007ooooo`;o00002?ooool2o`00017ooooo0_l0000oooooo`00
7?ooool00ol0003oooooooooo`0Zooooo`;o00001?ooool2o`0000[ooooo0_l00005ooooo`;o0000
1Oooool2o`0001gooooo0_l00007ooooo`;o00002_ooool2o`000003ooooool0003o000000;ooooo
0_l000000ooooooo0000o`00000?o`0000?ooooo1Ol00004ooooo`;o00005oooool2o`0000?ooooo
0_l00003ooooo`ko00001?ooool3o`0000kooooo0_l0000:ooooo`;o00003oooool2o`0003oooooo
000Looooo`03o`000?oooooooooo033ooooo0_l0000;ooooo`;o00001?ooool3o`0000Cooooo0_l0
000@ooooo`;o00002?ooool2o`0000Oooooo0_l00003ooooo`;o00000_ooool2o`0000Cooooo0_l0
00000ooooooo0000o`00000Io`000003ooooool0003o000000?o00002oooool2o`0000oooooo0_l0
0003ooooo`?o00000_ooool5o`0000;ooooo1?l00007ooooo`;o00001oooool2o`0000Wooooo1?l0
0005ooooo`;o00000oooool2o`0000[ooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0e
ooooo`;o00000_ooool2o`0000;ooooo0_l00005ooooo`;o00005_ooool2o`0000Sooooo0_l00003
ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo4Ol0
00000ooooooo0000o`00000:o`000003ooooool0003o000000?o00002oooool2o`00017ooooo0_l0
0002ooooo`;o000000?oooooo`000?l000001oooool4o`0000oooooo0_l00005ooooo`;o00000_oo
ool4o`0000Gooooo0_l00003ooooo`;o00002_ooool2o`0003oooooo000Looooo`03o`000?oooooo
oooo02kooooo0_l00005ooooo`;o00000_ooool2o`00033ooooo0_l00007ooooo`Co00000oooool2
o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`?o00000_ooool3o`000003ooooool0003o
000000[o000000Coooooo`000?l0003o00001Oooool2o`0000oooooo1?l00006ooooo`;o00001Ooo
ool2o`0000Cooooo0_l00003ooooo`;o00005_ooool2o`0000_ooooo0_l00003ooooo`;o00002?oo
ool4o`0003oooooo000Looooo`03o`000?oooooooooo02kooooo0_l00009ooooo`;o00009Oooool2
o`0000cooooo0_l00006ooooo`;o00003_ooool4o`0000;ooooo0ol000000ooooooo0000o`000002
o`000003ooooool0003o000000;o000000?oooooo`000?l000002Oooool2o`0000kooooo1Ol00004
ooooo`;o00002?ooool2o`0000?ooooo0_l0000Aooooo`;o00003Oooool2o`0000Cooooo0_l00000
0ooooooo0000o`000004o`0000Gooooo0_l000000ooooooo0000o`000011ooooo`007?ooool00ol0
003oooooooooo`0Zooooo`;o00003Oooool2o`0000;ooooo0_l00009ooooo`;o00004Oooool2o`00
00?ooooo0_l0000<ooooo`;o00000_ooool2o`0000[ooooo0_l00002ooooo`?o000000?oooooo`00
0?l000000_l00002ooooo`;o000000?oooooo`000?l000000_l000001Ooooooo0000o`000?l0003o
oooo00?o00000_ooool2o`0000?ooooo0ol0000@ooooo`;o00001oooool2o`0000Sooooo0_l0000F
ooooo`;o00003Oooool2o`0000;ooooo2ol00005ooooo`;o00000oooool2o`0003oooooo000Loooo
o`03o`000?oooooooooo02[ooooo1?l0000?ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooo
oooo0000o`00000Aooooo`;o000000?oooooo`000?l000000ol00007ooooo`;o00001?ooool4o`00
00;ooooo1Ol00003ooooo`;o000000?oooooo`000?l000001Ol00002ooooo`Oo00000_ooool4o`00
0004ooooool0003o0000o`0000;ooooo0ol00002ooooo`?o00005Oooool2o`0000Gooooo0_l00002
ooooo`;o00001_ooool2o`0001kooooo0_l00004ooooo`;o00000_ooool4o`000004ooooool0003o
0000o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`Co0000?Oooool001cooooo0_l0000]
ooooo`;o00002oooool2o`0000Gooooo0ol00002ooooo`;o00005_ooool6o`0000Oooooo0_l00004
ooooo`;o00001?ooool5o`0000?ooooo2Ol00003ooooo`Ko00000oooool2o`000003ooooool0003o
000000;ooooo1_l0000Jooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo0_l00006
ooooo`;o00001_ooool2o`0001Kooooo0_l00003ooooo`?o00000oooool2o`0000?ooooo0_l00002
ooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000003[ooooo000Loooo
o`03o`000?oooooooooo03Sooooo0ol00005ooooo`;o00002?ooool2o`00017ooooo0_l00006oooo
o`;o00004Oooool2o`0000Cooooo2Ol00004ooooo`Go00001_ooool2o`0000;ooooo1?l000000ooo
oooo0000o`00000Fooooo`;o00001Oooool2o`0000Kooooo0_l0000=ooooo`;o00004_ooool2o`00
00Oooooo0ol00004ooooo`;o00003?ooool3o`0000?ooooo0_l0000jooooo`007?ooool00ol0003o
ooooooooo`0aooooo`;o00001Oooool2o`00013ooooo0ol0000Booooo`;o00001?ooool4o`000003
ooooool0003o000000cooooo0_l000000ooooooo0000o`000005ooooo`;o00002_ooool2o`0000?o
oooo0_l00002ooooo`;o00000_ooool6o`000003ooooool0003o000001?ooooo0_l0000=ooooo`;o
00006_ooool2o`0000Gooooo0_l0000>ooooo`;o00002?ooool2o`0000;ooooo0ol0000oooooo`00
7?ooool00ol0003oooooooooo`0]ooooo`;o00000_ooool2o`0000Oooooo0_l0000<ooooo`;o0000
00?oooooo`000?l000004_ooool2o`0000Cooooo1?l000000ooooooo0000o`00000?ooooo`;o0000
1Oooool2o`0000;ooooo0_l00003ooooo`;o00001_ooool2o`0000;ooooo0_l00002ooooo`Co0000
0oooool2o`0000_ooooo0_l00006ooooo`;o00001oooool3o`0000;ooooo0_l0000Kooooo`;o0000
0oooool2o`0001[ooooo0_l00002ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0:_oo
ool2o`000004ooooool0003o0000ooooo`;o00002?ooool4o`000003ooooool0003o000000Oooooo
0ol0000Tooooo`;o00005Oooool8o`0000Wooooo0_l0000?ooooo`;o00001Oooool2o`0000_ooooo
0ol000001?oooooo0000o`000?l00002ooooo`;o00008?ooool2o`0000Sooooo0_l0000Booooo`;o
0000@_ooool001cooooo00?o0000ooooooooool09Oooool2o`0000?ooooo0_l00004ooooo`;o0000
1_ooool2o`0000;ooooo0_l000000ooooooo0000o`000008ooooo`;o00000_ooool2o`00023ooooo
0ol00005ooooo`;o00003_ooool7o`0000?ooooo0_l00004ooooo`;o00003?ooool2o`000003oooo
ool0003o000000Wooooo0_l00007ooooo`?o00001_ooool2o`000003ooooool0003o000000;o0000
3?ooool2o`0000Wooooo0_l0000<ooooo`;o00001oooool2o`0000Wooooo0_l00006ooooo`;o0000
00?oooooo`000?l000000_ooool2o`0000kooooo0_l0000Sooooo`007?ooool00ol0003ooooooooo
o`0Uooooo`;o00002Oooool2o`0000Kooooo0_l00002ooooo`;o00003oooool2o`0001Kooooo0_l0
0009ooooo`;o00001Oooool2o`0000Oooooo0_l0000?ooooo`;o000000Coooooo`000?l0003ooooo
0_l0000<ooooo`;o00003?ooool2o`0000Gooooo0_l00009ooooo`;o000000?oooooo`000?l00000
0_l0000<ooooo`;o00002Oooool2o`0001Gooooo1_l00006ooooo`;o00001Oooool2o`000003oooo
ool0003o000000;ooooo0_l0000>ooooo`;o00008oooool001cooooo00?o0000ooooooooool0<?oo
ool2o`0000Cooooo0_l00004ooooo`;o00000oooool2o`0000Sooooo0_l0000<ooooo`;o00002_oo
ool2o`0000Gooooo0_l0000Booooo`;o00004_ooool2o`000003ooooool0003o000000;ooooo0_l0
000Looooo`Go000000?oooooo`000?l000002Oooool2o`0000;ooooo0_l0000Tooooo`;o00001_oo
ool4o`0000Kooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00002Oooool2
o`0000Kooooo1_l0000:ooooo`;o00000oooool2o`0000cooooo0_l0000Kooooo`;o00000_ooool2
o`0000cooooo0_l0000Jooooo`Co000000Coooooo`000?l0003ooooo0_l00009ooooo`;o00000_oo
ool2o`0002Cooooo0_l0000Sooooo`;o0000;_ooool001cooooo00?o0000ooooooooool0=_ooool2
o`0000Wooooo0_l00006ooooo`;o000000Coooooo`000?l0003o00003Oooool7o`0000_ooooo0_l0
000Dooooo`;o00000oooool2o`0000;ooooo0_l0000Looooo`;o00000_ooool2o`0000Cooooo1Ol0
000Mooooo`;o00001Oooool3o`0001_ooooo0_l00004ooooo`;o00000oooool2o`0000kooooo1?l0
000^ooooo`007?ooool00ol0003oooooooooo`0hooooo`Co00001Oooool2o`0001Wooooo0_l00000
0ooooooo0000o`000002o`0000_ooooo0_l0000<ooooo`?o00001Oooool2o`00017ooooo0_l00008
ooooo`;o00001_ooool4o`0000;ooooo0_l00004ooooo`;o00001?ooool2o`00013ooooo0_l00004
ooooo`;o00000_ooool2o`0000Gooooo0ol0000Kooooo`;o00001?ooool2o`000003ooooool0003o
000000;o00003_ooool2o`00033ooooo000Looooo`03o`000?oooooooooo03;ooooo0_l00002oooo
o`Ko00003oooool2o`0000;ooooo0_l0000>ooooo`;o00002_ooool2o`0000Oooooo0_l00006oooo
o`?o00005oooool3o`0000;ooooo0_l00004ooooo`;o00000_ooool2o`0000;ooooo0_l000001?oo
oooo0000o`000?l00005ooooo`;o00001?ooool3o`0000oooooo0ol00004ooooo`;o00000_ooool2
o`0000;ooooo0_l0000Oooooo`;o00001?ooool2o`000003ooooool0003o000004;ooooo000Loooo
o`03o`000?oooooooooo03;ooooo0_l00002ooooo`;o00004oooool2o`0000;ooooo0_l0000>oooo
o`;o00001_ooool2o`0000;ooooo0ol000001?oooooo0000o`000?ooool4o`0000Gooooo0_l0000F
ooooo`;o000000?oooooo`000?l000000oooool2o`0000;ooooo1?l00002ooooo`;o00001Oooool4
o`0000;ooooo1?l00004ooooo`;o00001_ooool2o`0000Sooooo0_l000000ooooooo0000o`00000:
ooooo`;o00002oooool2o`0001;ooooo0_l00004ooooo`;o0000AOooool001cooooo00?o0000oooo
ooooool0F?ooool2o`0000gooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo1?l00005
ooooo`;o00003_ooool2o`0000?ooooo1Ol00002ooooo`;o00001Oooool3o`0000;ooooo0_l00007
ooooo`Wo00000oooool2o`0000Sooooo0_l0000;ooooo`;o00002_ooool2o`000003ooooool0003o
000000Sooooo0_l0000Cooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0<_ooool2o`00
02Cooooo0_l000000ooooooo0000o`000009ooooo`;o00008oooool4o`000005ooooool0003o0000
o`000?ooool00_l000000ooooooo0000o`000005ooooo`;o00000oooool7o`000004ooooool0003o
0000o`0000;ooooo0ol00005ooooo`;o00004Oooool2o`00013ooooo0ol0000Aooooo`;o00002_oo
ool2o`0000;ooooo0_l000000ooooooo0000o`000004o`0003oooooo000Looooo`03o`000?oooooo
oooo03;ooooo0_l000000ooooooo0000o`000005ooooo`;o00000oooool2o`0001Sooooo0_l00009
ooooo`?o00001?ooool2o`0000Sooooo0_l000000ooooooo0000o`000002ooooo`;o00003Oooool2
o`0000Gooooo0_l0000>ooooo`[o00000oooool2o`0001Sooooo0_l000000ooooooo0000o`00000<
ooooo`Wo00001?ooool2o`0000Kooooo0_l000000ooooooo0000o`000006ooooo`?o00000_ooool9
o`0003oooooo000Looooo`;o0000<oooool2o`000003ooooool0003o000000Gooooo0ol00002oooo
o`;o00002oooool2o`0001Oooooo0_l00004ooooo`;o00002?ooool2o`000003ooooool0003o0000
00;ooooo0_l0000Zooooo`Co00001oooool2o`0000Oooooo0_l00004ooooo`Co00001_ooool2o`00
00cooooo0_l000000ooooooo0000o`000004o`0000Cooooo0_l00009ooooo`Co00001?ooool5o`00
00;ooooo0_l00004ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0=Oooool2o`0000;o
oooo0_l00002ooooo`;o00003oooool2o`0000;ooooo0_l000000ooooooo0000o`000008ooooo`;o
00001Oooool4o`0000Kooooo0_l00005ooooo`;o00003_ooool2o`0001Gooooo0_l00003ooooo`Co
00000oooool6o`0000Gooooo0_l00002ooooo`;o00000oooool2o`0000?ooooo1Ol00006ooooo`Co
00002_ooool2o`000003ooooool0003o000001Gooooo0_l00007ooooo`;o00002?ooool2o`0003ko
oooo000Looooo`03o`000?oooooooooo03Gooooo0_l000001?oooooo0000o`000?l00009ooooo`;o
00003?ooool2o`000003ooooool0003o000000Sooooo1?l00002ooooo`Go00001_ooool2o`0000ko
oooo0_l00003ooooo`Co00003oooool2o`0000Cooooo0_l00003ooooo`Co00001Oooool6o`0000;o
oooo0_l00003ooooo`;o00002?ooool2o`0000Wooooo1?l0000@ooooo`;o00003Oooool2o`0000co
oooo0ol0000=ooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0>?ooool2o`0000[ooooo
0_l00005ooooo`;o00002?ooool2o`0000[ooooo0_l00002ooooo`;o00002_ooool2o`0000;ooooo
0_l000000ooooooo0000o`000002ooooo`;o00000_ooool4o`000003ooooool0003o000000Sooooo
0_l00007ooooo`;o00001_ooool2o`0000_ooooo1Ol00002ooooo`Go00005_ooool2o`0000cooooo
0_l00003ooooo`?o00003?ooool2o`0000gooooo0_l0000=ooooo`;o0000>?ooool001cooooo00?o
0000ooooooooool0;?ooool2o`0001Cooooo0_l00007ooooo`;o00002?ooool2o`0000Wooooo0_l0
000:ooooo`?o00000_ooool3o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000Cooooo
0_l00004ooooo`;o00001Oooool2o`0000oooooo0_l000000ooooooo0000o`00000Aooooo`Oo0000
00?oooooo`000?l000001oooool2o`0000;ooooo0_l000001Ooooooo0000o`000?l0003ooooo00?o
00001oooool3o`0000?ooooo0ol0000=ooooo`;o00002?ooool2o`0001Kooooo0_l0000cooooo`00
7?ooool00ol0003oooooooooo`0/ooooo`?o00003Oooool2o`0000Cooooo0_l00005ooooo`;o0000
2_ooool3o`0000Sooooo0_l0000:ooooo`?o00000oooool2o`0001Cooooo0_l00005ooooo`;o0000
4_ooool3o`0000[ooooo0_l00004ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000
o`000007ooooo`;o00000_ooool2o`000003ooooool0003o000000_o000000Coooooo`000?l0003o
00000oooool3o`0000;ooooo0ol00008ooooo`;o00001?ooool2o`0000;ooooo0_l00003ooooo`;o
00001Oooool4o`0000Sooooo0_l0000cooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o0000
3Oooool2o`0000_ooooo1?l00008ooooo`?o00001?ooool2o`0000cooooo0_l000000ooooooo0000
o`000005ooooo`;o00000oooool2o`0001Cooooo0_l0000?ooooo`;o00000_ooool2o`0000[ooooo
0_l00008ooooo`?o00003Oooool2o`000004ooooool0003o0000oooooa3o00000oooool7o`0000;o
oooo0_l00008ooooo`Go00001_ooool2o`0000Cooooo1Ol00004ooooo`;o0000=oooool001cooooo
00?o0000ooooooooool0>Oooool2o`00013ooooo0_l0000?ooooo`;o00001?ooool2o`0000;ooooo
2Ol000001?oooooo0000o`000?ooool3o`0000?ooooo0_l0000;ooooo`;o00006?ooool2o`0001Wo
oooo0_l0000<oooooaCo000000Coooooo`000?l0003o00000oooool3o`0000Gooooo0_l00008oooo
o`Go00000_ooool2o`0000Sooooo0_l000000ooooooo0000o`000004ooooo`;o0000=oooool001co
oooo00?o0000ooooooooool0>Oooool2o`0000;ooooo0_l0000Nooooo`;o00000oooool9o`000003
ooooool0003o000000So00000oooool2o`0000Sooooo0_l000000ooooooo0000o`00000=ooooo`;o
00001Oooool2o`0000oooooo0_l00008ooooo`;o00000_ooool2o`0000Cooooo0_l00003oooooaKo
000000?oooooo`000?l000000_l00004ooooo`;o00005_ooool3o`0000[ooooo0_l0000mooooo`00
7?ooool00ol0003oooooooooo`0Vooooo`;o00002?ooool2o`0000Cooooo0_l00005ooooo`;o0000
7_ooool2o`0000Gooooo0_l00003ooooo`;o000000?oooooo`000?l000002Ol00002ooooo`;o0000
00?oooooo`000?l000000_ooool5o`00013ooooo0_l00002ooooo`;o000000?oooooo`000?l00000
3oooool2o`0000Sooooo0_l00002ooooo`;o00001?oooolBo`000003ooooool0003o000000co0000
0oooool2o`0000;ooooo0_l000000ooooooo0000o`00000:ooooo`;o00001?ooool4o`0000?ooooo
1?l00010ooooo`007?ooool00ol0003oooooooooo`0Vooooo`;o00001Oooool2o`000003ooooool0
003o000000Cooooo0_l00002ooooo`;o00001?ooool2o`0002;ooooo3_l00003ooooo`?o00001?oo
ool2o`0000;ooooo0ol0000<ooooo`;o00002?ooool3o`0000gooooo0_l0000=ooooo`;o00001_oo
oolRo`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000002_ooool2o`000003ooooool0
003o000000?ooooo0_l00003ooooo`Co0000@?ooool001cooooo00?o0000ooooooooool0;Oooool2
o`0000?ooooo0_l00006ooooo`;o00001?ooool2o`0001?ooooo0_l0000=oooooaCo00002Oooool3
o`0000[ooooo0ol00009ooooo`;o00003Oooool2o`000003ooooool0003o000000Oooooo0_l00000
1?oooooo0000o`000?l00004oooooaco000000?oooooo`000?l000001?l00008ooooo`;o00000ooo
ool2o`0000Gooooo0_l00003ooooo`Co000000Coooooo`000?l0003o0000A_ooool001cooooo00?o
0000ooooooooool0:_ooool2o`0000Kooooo0ol000000ooooooo0000o`00000>ooooo`;o00003Ooo
ool2o`0000Cooooo0_l00004ooooo`Go000000?oooooo`000?l000003ol0000:ooooo`;o00002_oo
ool2o`000003ooooool0003o000001Wooooo0ol00006ooooo`?o000000?oooooo`000?l000001?oo
ool=o`000003ooooool0003o000001Go00001_ooool2o`0000?ooooo0_l00004ooooo`?o000000Co
ooooo`000?l0003ooooo0ol000001?oooooo0000o`000?l00016ooooo`007?ooool00ol0003ooooo
ooooo`0Zooooo`;o00001oooool2o`000004ooooool0003o0000o`0000Kooooo0_l00005ooooo`;o
000000?oooooo`000?l000004?ooool2o`000004ooooool0003o0000oooooago00001?ooool2o`00
00gooooo0_l0000Hooooo`Co00001Oooool6o`0000Kooooo9?l00002ooooo`;o00003Oooool2o`00
00;ooooo0_l00002ooooo`;o000000?oooooo`000?l000002_ooool2o`0003_ooooo000Looooo`03
o`000?oooooooooo03;ooooo0ol00002ooooo`;o00001_ooool2o`000004ooooool0003o0000oooo
o`?o000000?oooooo`000?l000001?l0000>ooooo`?o000000Coooooo`000?l0003ooooo1ol00000
0ooooooo0000o`000007o`000003ooooool0003o000000Ko00001_ooool2o`0000Oooooo0_l0000:
ooooo`;o00002?ooool4o`0000Cooooo0_l00007ooooo`;o00000_ooool2o`0000Kooooo2ol00000
0ooooooo0000o`00000Do`0000Cooooo0_l0000<ooooo`;o00000_ooool2o`0000?ooooo0_l00003
ooooo`;o00000_ooool2o`0000Cooooo0_l0000:ooooo`;o0000;oooool001cooooo00?o0000oooo
ooooool0<_ooool2o`0000?ooooo0_l00004ooooo`?o00000_ooool2o`000003ooooool0003o0000
00Cooooo1_l000000ooooooo0000o`000005ooooo`;o00000_ooool2o`0000;ooooo5ol00003oooo
o`;o00001oooool2o`0000Oooooo0_l00004ooooo`;o00001?ooool2o`0000Sooooo1?l0000Aoooo
o`;o00000oooool;o`0000?ooooo5ol00002ooooo`;o00003_ooool2o`0000;ooooo0_l00006oooo
o`Co00000_ooool2o`00013ooooo0_l0000_ooooo`007?ooool2o`0003?ooooo0_l00009ooooo`?o
00002?ooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000005ooooo`;o
00001?oooolIo`0000;ooooo0ol0000Fooooo`Co00004_ooool2o`0001;ooooo9?l00002ooooo`?o
00003?ooool5o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l0000Dooooo`;o
0000;oooool001cooooo00?o0000ooooooooool0B?ooool2o`000003ooooool0003o000000;o0000
4?oooolIo`0000;ooooo0_l0000>ooooo`;o00002Oooool2o`0000Wooooo0_l00007ooooo`;o0000
2?ooool5o`0000Oooooo8_l00002ooooo`?o000000?oooooo`000?l000002Oooool2o`000004oooo
ool0003o0000ooooo`?o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00004?ooool2o`0002oo
oooo000Looooo`03o`000?oooooooooo03Cooooo0_l0000?ooooo`;o00001_ooool2o`0000kooooo
6ol000000ooooooo0000o`000009ooooo`;o00001?ooool2o`0000Gooooo0_l00009ooooo`;o0000
0_ooool2o`0000oooooo2_l00004ooooob;o00000_ooool2o`0000;ooooo0_l00009ooooo`;o0000
1?ooool2o`0000Kooooo1Ol000000ooooooo0000o`00000Aooooo`;o0000;_ooool001cooooo00?o
0000ooooooooool0=?ooool2o`0000oooooo0_l0000?ooooo`;o00001?oooolLo`000003ooooool0
003o000000Cooooo0_l000000ooooooo0000o`000002o`0000_ooooo0_l00006ooooo`Go00004ooo
ool5o`0000;ooooo1_l000000ooooooo0000o`00000<o`0000;ooooo5Ol0000>ooooo`Co00002_oo
ool2o`000003ooooool0003o000000?ooooo0_l0000:ooooo`;o00000oooool2o`0002kooooo000L
ooooo`03o`000?oooooooooo03Cooooo0_l000000ooooooo0000o`00000Mooooo`;o00001?oooolR
o`000004ooooool0003o0000ooooo`;o00001_ooool2o`0000[ooooo0_l000000ooooooo0000o`00
0002o`0001Kooooo0ol00004ooooo`Co000000?oooooo`000?l000006Ol000000ooooooo0000o`00
0007o`0000_ooooo0_l00003ooooo`;o00000oooool2o`0000Sooooo0_l00003ooooo`;o00002_oo
ool2o`0003?ooooo000Looooo`03o`000?oooooooooo03Oooooo0_l000000ooooooo0000o`000004
ooooo`;o00002oooool2o`0000Wooooo0_l000001?oooooo0000o`000?oooolKo`000003ooooool0
003o000000;o00003?ooool2o`0000[ooooo0_l00008ooooo`;o00000oooool6o`0000Wooooo0ol0
0009ooooo`Co00000_ooool<o`000003ooooool0003o000000_o000000Coooooo`000?l0003o0000
2oooool3o`0000Gooooo1ol00007ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0>_oo
ool3o`0000?ooooo0_l0000;ooooo`;o00002OoooolQo`000003ooooool0003o000000?o00002_oo
ool2o`0000_ooooo0_l00002ooooo`;o00001?ooool2o`0000?ooooo2?l00007ooooo`?o00002_oo
oolFo`000003ooooool0003o000000Go00000_ooool3o`0000cooooo0_l00005ooooo`;o000000?o
ooooo`000?l000000_l00002ooooo`;o00000oooool3o`00047ooooo000Looooo`03o`000?oooooo
oooo03_ooooo0_l0000Aooooo`;o00002?ooool3o`000003ooooool0003o000001_o000000Cooooo
o`000?l0003ooooo0_l0000:ooooo`;o00002oooool2o`0000;ooooo0_l00004ooooo`;o00000_oo
ool9o`0000Oooooo1?l00009oooooago00000oooool2o`0000oooooo1?l0000:ooooo`;o000000Co
ooooo`000?l0003ooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0gooooo`Ko00000_oo
ool2o`0000gooooo1?l00006ooooo`;o00000_oooolMo`000003ooooool0003o000000;o00002Ooo
ool2o`000004ooooool0003o0000ooooo`;o00002_ooool2o`0000Gooooo0_l00002ooooo`;o0000
00?oooooo`000?l000003?ooool3o`0000Wooooo0_l000000ooooooo0000o`00000Go`0000Cooooo
0_l00009ooooo`;o00001?ooool4o`0000cooooo0ol00014ooooo`007?ooool00ol0003ooooooooo
o`0gooooo`Ko00000_ooool3o`0000[ooooo0ol000001?oooooo0000o`000?ooool2o`0000?ooooo
4ol00002ooooo`Co000000?oooooo`000?l000001Ol00003ooooo`Co00001oooool2o`000004oooo
ool0003o0000ooooo`;o00002_ooool2o`0000Sooooo0_l00002ooooo`;o00006ooooolHo`000003
ooooool0003o000000[ooooo0_l000000ooooooo0000o`000004ooooo`;o00003_ooool2o`0004Go
oooo000Looooo`03o`000?oooooooooo03Wooooo0_l00005ooooo`;o00001?ooool3o`0000?ooooo
0ol00004ooooo`;o000000Coooooo`000?l0003ooooo7_l00007ooooo`Co00003oooool2o`0000Oo
oooo0ol00006ooooo`;o00003_ooool2o`00017ooooo2Ol000000ooooooo0000o`000007o`0000;o
oooo1?l0000:ooooo`;o00001oooool2o`0000kooooo0_l00015ooooo`007?ooool00ol0003ooooo
ooooo`0gooooo`Co00000oooool2o`0000Kooooo0ol0000;ooooo`Co00000oooool2o`000003oooo
ool0003o000001_o00001Oooool3o`0000kooooo0_l00006ooooo`Co00000oooool2o`000003oooo
ool0003o000000kooooo0_l0000:ooooo`;o000000?oooooo`000?l000000ooooolCo`000003oooo
ool0003o000000;o00008?ooool7o`0000Wooooo0_l0000hooooo`007?ooool00ol0003ooooooooo
o`0gooooo`;o00001Oooool2o`0001;ooooo1_l00003ooooo`;o000000?oooooo`000?l000006ol0
0006ooooo`;o00002_ooool2o`0000Kooooo0_l00002ooooo`;o00001Oooool2o`0000Cooooo0_l0
000Aooooo`;o000000Coooooo`000?l0003ooooo0_l000001?oooooo0000o`000?l00004ooooo`So
000000?oooooo`000?l000000_l000001?oooooo0000o`000?l00002ooooo`;o00002?ooool2o`00
00?ooooo0_l0000Booooo`Oo00002?ooool3o`0003Sooooo000Looooo`03o`000?oooooooooo037o
oooo0_l0000:ooooo`;o00000oooool2o`0000kooooo0_l00002ooooo`;o00001_oooolKo`0000;o
oooo0_l00002ooooo`;o00003?ooool2o`0000Cooooo1?l000000ooooooo0000o`00000<ooooo`;o
00004Oooool2o`000003ooooool0003o000000?ooooo1?l00004ooooo`;o00001?ooool7o`000004
ooooool0003o0000o`0000cooooo0_l00003ooooo`;o00004_ooool2o`0000;ooooo0_l00007oooo
o`Co0000>Oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo02oooooo1?l00008ooooo`Co00000ooo
ool2o`000003ooooool0003o000000;o00002oooool2o`0000;ooooo1?l000000ooooooo0000o`00
000>o`000003ooooool0003o000000[o000000?oooooo`000?l000001?l0000;ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0000?ooooo0_l00002ooooo`;o00003oooool2o`0000cooooo0ol0
0003ooooo`;o00003_ooool8o`0002Oooooo0_l000000ooooooo0000o`000007ooooo`;o00003_oo
ool2o`0002_ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEE
EOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0_ooooo`;o00002_ooool2o`0000So
oooo1_l00009ooooo`;o00000_ooool4o`000003ooooool0003o000001_o00000oooool2o`0000co
oooo0ol000000ooooooo0000o`000002ooooo`;o00001oooool2o`0000oooooo0_l0000<ooooo`;o
00005Oooool2o`000003ooooool0003o000000gooooo0_l0000=ooooo`;o00002oooool2o`0001[o
oooo0_l0000[ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`0oooooo`;o00002?ooool2o`0001;o
oooo1Ol00002oooooa7o00000_ooool2o`0001;ooooo0_l00007ooooo`;o00001_ooool2o`0000;o
oooo0_l00003ooooo`;o00001_ooool2o`0000Oooooo1?l0000;ooooo`;o00003oooool2o`0000Co
oooo0_l00006ooooo`;o00003Oooool2o`0001Gooooo0_l00007ooooo`;o0000=?ooool00003oooo
ool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Ko
oooo0ol0000hooooo`;o00001Oooool2o`0000oooooo0_l0000;ooooo`Co000000?oooooo`000?l0
00004Ol00002ooooo`;o00001Oooool3o`0000Oooooo0_l00002ooooo`;o00001_ooool4o`0000Co
oooo0ol000000ooooooo0000o`000003ooooo`;o00003oooool4o`0000;ooooo0_l00007ooooo`;o
00003oooool2o`0000Cooooo0_l0000;ooooo`Co00002?ooool8o`0000gooooo1?l00005ooooo`;o
0000=?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oEEEE
o`000?l@413oc<c<00Kooooo00?o0000ooooooooool0=?ooool2o`0000;ooooo0_l0000Fooooo`;o
00002oooool2o`0000?ooooo3ol00002ooooo`;o00000oooool4o`0000;ooooo0ol000000ooooooo
0000o`000004ooooo`;o00000_ooool2o`0000Sooooo0ol00004ooooo`;o00007Oooool2o`0001Oo
oooo0_l0000Booooo`Co00002?ooool8o`0000?ooooo0_l0000:ooooo`;o00000_ooool2o`0003Oo
oooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qoooool0
2?ooool00ol0003oooooooooo`0dooooo`;o00000oooool2o`0000;ooooo1?l000000ooooooo0000
o`000009ooooo`;o000000?oooooo`000?l000000_l0000<oooooaOo000000?oooooo`000?l00000
0_l00002ooooo`;o00000_ooool2o`0000Wooooo0_l00002ooooo`;o00001?ooool2o`0000Gooooo
0_l0000;ooooo`;o00005_ooool2o`0000_ooooo0_l00003ooooo`;o000000Coooooo`000?l0003o
oooo0ol0000Hooooo`;o000000?oooooo`000?l000001Oooool2o`0000gooooo0ol0000gooooo`00
00KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000oooo
ooooool0>Oooool2o`0000;ooooo1?l000000ooooooo0000o`000005ooooo`;o00000_ooool2o`00
0003ooooool0003o000000;o00002oooool3o`000003ooooool0003o000000_o000000?oooooo`00
0?l000001Ol000000ooooooo0000o`00000Booooo`;o00000_ooool2o`0000;ooooo0_l00002oooo
o`;o00000oooool2o`0000?ooooo0_l00006ooooo`;o00001oooool2o`0000[ooooo0_l000000ooo
oooo0000o`00000;ooooo`?o00001Oooool2o`000004ooooool0003o0000o`0001Kooooo1?l0000G
ooooo`;o0000>?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`00
0?l@4106ooooo`03o`000?oooooooooo03oooooo0_l00008ooooo`;o00001Oooool2o`0000gooooo
1?l000000ooooooo0000o`000009o`0000?ooooo1_l000000ooooooo0000o`00000Jooooo`;o0000
0_ooool2o`0000Cooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000_ooooo
0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000000oooooo0_l00007ooooo`;o0000
0oooool2o`0001?ooooo1?l00003ooooo`;o00000_ooool2o`0004Sooooo000Looooo`03o`000?oo
oooooooo03Sooooo0_l00004ooooo`Ko00003?ooool2o`0000gooooo1?l00002ooooo`;o00000ooo
ool2o`0000?ooooo0_l00003ooooo`Co00009oooool:o`000003ooooool0003o000000Co00002?oo
ool2o`0000?ooooo0ol0000Booooo`;o00001_ooool2o`000003ooooool0003o000000;o00001ooo
ool2o`0000cooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00006ooooo`;o00000ooo
ool3o`0003[ooooo000Looooo`03o`000?oooooooooo03Sooooo0_l00004ooooo`Ko00002_ooool2
o`0000Kooooo0_l00006ooooo`?o00002Oooool2o`0000;ooooo0ol0000ZoooooaGo00001oooool3
o`0000Cooooo0_l00008ooooo`;o00002?ooool3o`0000Oooooo0ol00009ooooo`;o00003?ooool2
o`000004ooooool0003o0000o`0000_ooooo0_l00003ooooo`?o0000>_ooool001cooooo00?o0000
ooooooooool0?oooool4o`0000_ooooo0_l00006ooooo`;o00001_ooool2o`0000;ooooo0ol00009
ooooo`;o00001?ooool2o`0000Kooooo0_l0000Koooooa?o00000_ooool2o`0000;ooooo0_l00003
ooooo`?o00000_ooool2o`0000Gooooo0_l00003ooooo`Co00001oooool2o`0000Oooooo0_l00008
ooooo`;o00002oooool2o`0000Gooooo0_l0000Cooooo`;o0000>?ooool001cooooo00?o0000oooo
ooooool0>oooool3o`000003ooooool0003o000000;o000000?oooooo`000?l000000_ooool2o`00
00oooooo0_l00003ooooo`Oo00000oooool2o`0000Cooooo0_l00002ooooo`Co00001_ooool2o`00
0003ooooool0003o000000;o00005_oooolCo`000003ooooool0003o000000;o000000?oooooo`00
0?l000001oooool3o`0000Cooooo0ol00003ooooo`Co00001Oooool2o`0001;ooooo0ol0000;oooo
o`;o00006_ooool2o`0003Sooooo000Looooo`03o`000?oooooooooo03_ooooo0ol00003ooooo`;o
000000?oooooo`000?l000000_ooool2o`0000_ooooo0_l00002ooooo`;o00001?ooool4o`000003
ooooool0003o000000;ooooo0_l00008ooooo`;o00002oooool5o`0000Kooooo0_l00005ooooo`;o
00001?oooolJo`0000[ooooo0_l00005ooooo`;o00003Oooool2o`0000cooooo0_l00004ooooo`;o
00001_ooool2o`0005[ooooo000Looooo`03o`000?oooooooooo04Cooooo0_l00002ooooo`Co0000
1oooool4o`0000gooooo1_l0000Cooooo`;o00000oooool2o`0000Kooooo1?l00003ooooo`;o0000
00?oooooo`000?l000006ol00003ooooo`;o00003?ooool2o`0000Gooooo0_l0000Dooooo`;o0000
3?ooool2o`0001[ooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00002Ooo
ool2o`0000Gooooo0_l00007ooooo`;o00001Oooool2o`0000Sooooo1_l0000Cooooo`;o00000_oo
ool3o`0000Sooooo0_l00006oooooako00000_ooool2o`0001?ooooo0_l00002ooooo`?o00004?oo
ool2o`0002Oooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00001Oooool2
o`0000;ooooo0_l0000Eooooo`?o00001Oooool2o`0000Cooooo1?l0000@ooooo`?o00000_ooool2
o`0000Wooooo0_l00009ooooo`;o000000?oooooo`000?l000003_l000000ooooooo0000o`000005
o`0000Sooooo0_l000000ooooooo0000o`00000>ooooo`?o000000?oooooo`000?l000003?ooool3
o`0000Kooooo0_l0000=ooooo`;o0000D?ooool001cooooo00?o0000ooooooooool0?oooool2o`00
00Oooooo0_l0000Aooooo`;o00001Oooool2o`0000Cooooo1_l0000;ooooo`;o000000?oooooo`00
0?l000000_ooool2o`0000Kooooo0_l00002ooooo`;o00000_ooool2o`0000Cooooo7?l000000ooo
oooo0000o`000005ooooo`;o000000?oooooo`000?l000001oooool2o`0000Wooooo0_l0000<oooo
o`;o00001Oooool4o`0000Kooooo0_l00004ooooo`?o00002Oooool2o`0004Gooooo000Looooo`03
o`000?oooooooooo04Sooooo0_l0000:ooooo`;o00002_ooool2o`0000[ooooo0_l00007ooooo`;o
000000Coooooo`000?l0003o00001Oooool4o`0000Cooooo0_l00006ooooo`;o00000ooooolHo`00
0004ooooool0003o0000o`0000;ooooo0_l00003ooooo`;o00002Oooool5o`000003ooooool0003o
000001_ooooo0_l00008ooooo`;o00001?ooool3o`0000Wooooo0_l00015ooooo`007?ooool00ol0
003oooooooooo`1@ooooo`;o00000_ooool2o`0000?ooooo0_l00005ooooo`;o00003oooool2o`00
00;ooooo0_l000000ooooooo0000o`000008ooooo`;o00002oooool2o`0000;ooooo2Ol000000ooo
oooo0000o`00000Bo`0000;ooooo0ol00002ooooo`Go00001_ooool3o`0000?ooooo1?l0000<oooo
o`;o00007?ooool2o`00053ooooo000Looooo`;o0000A?ooool2o`000003ooooool0003o000000Co
oooo0_l00002ooooo`Co00001Oooool3o`0000kooooo0_l00005ooooo`;o000000?oooooo`000?l0
00001Oooool2o`0000cooooo1?l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000go
00000_ooool?o`0000;ooooo1Ol0000>ooooo`;o00003?ooool4o`0000;ooooo0_l00007ooooo`;o
00001_ooool2o`0001Cooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`12ooooo`?o0000
00?oooooo`000?l000001?ooool2o`0000Cooooo0_l00002ooooo`Ko00001Oooool3o`0000Kooooo
0_l00008ooooo`;o00001Oooool2o`0000[ooooo1_l000000ooooooo0000o`000006oooooago0000
1Oooool3o`0000kooooo0_l0000@ooooo`;o00000_ooool2o`0000Oooooo0_l00006ooooo`Co0000
00?oooooo`000?l000003_ooool3o`00047ooooo000Looooo`03o`000?oooooooooo04;ooooo0ol0
000;ooooo`;o00001?ooool4o`0000?ooooo0_l00002ooooo`?o00004?ooool2o`0000Sooooo0_l0
0003ooooo`;o00000_ooool2o`0000Gooooo0_l00006oooooa_o00005Oooool2o`000003ooooool0
003o000000Sooooo0_l00002ooooo`;o00001Oooool2o`00017ooooo0ol000000ooooooo0000o`00
0002o`0000Cooooo0_l00006ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0Boooool2
o`0000?ooooo0_l00005ooooo`;o00001?ooool2o`0000[ooooo0_l00009ooooo`;o00002?ooool2
o`0000;ooooo1Ol0000@oooooa_o00001Oooool2o`0000gooooo0ol00008ooooo`Co00000_ooool2
o`0000Gooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000000oooool4
o`0000Cooooo1?l00002ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0AOooool2o`00
00Cooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo0_l00003oooo
o`?o000000?oooooo`000?l000000oooool2o`0000Oooooo0_l0000>ooooo`Go00002Oooool2o`00
0003ooooool0003o000000?ooooo6_l00005ooooo`Co00002?ooool2o`0000;ooooo0_l00005oooo
o`;o000000?oooooo`000?l000002_ooool3o`000003ooooool0003o000000Cooooo0_l000000ooo
oooo0000o`000003ooooo`Co00001_ooool2o`0000Sooooo0_l00014ooooo`007?ooool00ol0003o
ooooooooo`0kooooo`;o00002?ooool2o`0000Sooooo0_l00003ooooo`;o00001Oooool2o`0000?o
oooo1_l00003ooooo`Co00001Oooool2o`0000Cooooo0_l00009ooooo`;o00002oooool2o`000003
ooooool0003o000000?ooooo6ol00006ooooo`;o00002?ooool5o`0000Kooooo0_l00005ooooo`;o
00001_ooool6o`0000kooooo0_l0000@ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0
>oooool2o`0000Wooooo0_l0000:ooooo`;o00002_ooool2o`0000?ooooo0_l00003ooooo`Go0000
0_ooool2o`000003ooooool0003o000000?ooooo0ol00003ooooo`;o00006?ooool3o`000003oooo
ool0003o000001Ko00001?ooool2o`0000cooooo0ol0000=ooooo`;o00002?ooool4o`0000Gooooo
0_l00003ooooo`;o00000_ooool2o`0000;ooooo0_l0001Booooo`007?ooool00ol0003ooooooooo
o`16ooooo`;o00000_ooool3o`0000Gooooo0_l0000:ooooo`;o00000oooool3o`0000;ooooo0_l0
0005ooooo`Go00000oooool2o`0000Cooooo0ol00005ooooo`;o00004?ooool2o`0000;ooooo4ol0
00000ooooooo0000o`000006ooooo`;o00004?ooool2o`0000Kooooo0_l0000<ooooo`Co00001Ooo
ool2o`0000?ooooo0_l00002ooooo`?o000000?oooooo`000?l000003?ooool2o`0004Cooooo000L
ooooo`03o`000?oooooooooo04[ooooo0ol00007ooooo`;o00003_ooool2o`0000?ooooo0_l00006
ooooo`;o00002oooool4o`0000?ooooo0_l00006ooooo`;o00003?oooolFo`0001Sooooo0_l00003
ooooo`;o000000Coooooo`000?l0003o00002oooool5o`0000Cooooo1?l00006ooooo`;o00001?oo
ool2o`0000Wooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00001?ooool2
o`0000Oooooo0_l0000?ooooo`;o00000_ooool3o`000003ooooool0003o000000oooooo1_l00008
ooooo`?o00001?ooool2o`0000Cooooo1?l000000ooooooo0000o`00000<o`000003ooooool0003o
000000;o00007Oooool2o`0000;ooooo0_l00009ooooo`;o00000oooool2o`0000Kooooo0_l00004
ooooo`;o00001_ooool2o`0004oooooo000Looooo`03o`000?oooooooooo04Gooooo0_l0000Koooo
o`;o000000?oooooo`000?l000000oooool2o`000003ooooool0003o000001?ooooo0_l00008oooo
o`;o000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l00003ooooo`ko00000oooool2o`00
027ooooo0_l00009ooooo`;o000000?oooooo`000?l000002Oooool2o`0000?ooooo0_l0001Goooo
o`007?ooool00ol0003oooooooooo`16ooooo`;o00002?ooool2o`00013ooooo0_l0000[ooooo`?o
00000oooool2o`0000Gooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000Oo
00001_ooool2o`0001[ooooo1?l00002ooooo`;o00001_ooool4o`0000Wooooo0ol0000?ooooo`Co
0000B?ooool001cooooo00?o0000ooooooooool0A_ooool3o`000003ooooool0003o000000Cooooo
0_l00007ooooo`;o00002?ooool2o`0000[ooooo0_l00003ooooo`;o00000_ooool2o`0001Kooooo
0_l00003ooooo`;o00001Oooool2o`000003ooooool0003o000000go00001_ooool4o`0000;ooooo
0_l0000Dooooo`;o00001?ooool2o`0000Kooooo0_l0000;ooooo`Go00003Oooool4o`0004Sooooo
000Looooo`03o`000?oooooooooo03oooooo0_l00005ooooo`Ko00003Oooool2o`0000Sooooo0_l0
0003ooooo`;o00001Oooool2o`0000?ooooo0_l00002ooooo`;o00009Oooool8o`0000;ooooo1Ol0
0003ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00007?ooool3o`0001?ooooo0_l0
001Iooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00001Oooool4o`0000Oooooo0_l0000>
ooooo`?o00001?ooool2o`0000Kooooo0_l000001?oooooo0000o`000?l00003ooooo`;o00007?oo
ool2o`0000kooooo1_l00004ooooo`;o000000?oooooo`000?l000007oooool2o`000004ooooool0
003o0000o`00013ooooo0_l0000?ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0??oo
ool2o`0000[ooooo0_l00007ooooo`;o00003_ooool7o`0000Sooooo0_l000001?oooooo0000o`00
0?l00003ooooo`;o00004?ooool2o`0000Wooooo0ol00009ooooo`;o00000oooool6o`000003oooo
ool0003o000001Oooooo0_l0000<ooooo`;o00001_ooool2o`0000Wooooo0_l000000ooooooo0000
o`00000?ooooo`;o0000Boooool001cooooo0_l0000mooooo`;o00002_ooool2o`0001Kooooo0_l0
0002ooooo`Co00002_ooool4o`0000;ooooo0_l000000ooooooo0000o`00000>ooooo`;o00002Ooo
ool2o`0000[ooooo0_l000000ooooooo0000o`000007ooooo`;o00001Oooool2o`0000kooooo1?l0
000Dooooo`;o00002?ooool3o`0005oooooo000Looooo`03o`000?oooooooooo04Wooooo0_l00005
ooooo`;o000000?oooooo`000?l000002oooool3o`0000Gooooo0_l00008ooooo`Co00000_ooool2
o`000003ooooool0003o000001_ooooo0_l00008ooooo`;o000000?oooooo`000?l000003_ooool2
o`0000Cooooo0_l00008ooooo`;o00005Oooool3o`0000Sooooo0_l0001Pooooo`007?ooool00ol0
003oooooooooo`19ooooo`;o00001Oooool5o`0000Oooooo0_l00003ooooo`;o000000?oooooo`00
0?l000000_ooool2o`0000Sooooo1?l0000Booooo`;o00003_ooool2o`0000;ooooo0_l00004oooo
o`;o00005?ooool5o`0001_ooooo0_l00002ooooo`;o0000Joooool001cooooo00?o0000oooooooo
ool0DOooool4o`0000Oooooo0_l00006ooooo`;o00000_ooool2o`0000Kooooo1Ol0000Cooooo`;o
00004_ooool2o`0000Gooooo0_l0000;ooooo`;o00000_ooool2o`0000;ooooo0ol00004ooooo`;o
000000Coooooo`000?l0003ooooo0_l0000;ooooo`;o00001?ooool4o`0000Gooooo0_l00006oooo
o`;o00003?ooool2o`00053ooooo000Looooo`03o`000?oooooooooo04cooooo0_l00003ooooo`Co
00000oooool4o`0000cooooo0_l00006ooooo`;o00005_ooool2o`0000Sooooo0_l00003ooooo`;o
00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`00000;ooooo`;o000000Coooooo`000?l0
003o00000oooool2o`000004ooooool0003o0000ooooo`;o000000Coooooo`000?l0003ooooo0ol0
0003ooooo`;o00001Oooool2o`0000Cooooo1?l000000ooooooo0000o`000002ooooo`;o00000_oo
ool2o`000004ooooool0003o0000o`0000cooooo0_l0001@ooooo`007?ooool00ol0003ooooooooo
o`1:ooooo`Co00000oooool3o`0000Cooooo1?l0000<ooooo`;o00001Oooool2o`0001Kooooo0_l0
0006ooooo`;o000000Coooooo`000?l0003ooooo1?l00002ooooo`;o00000oooool2o`00017ooooo
0_l000000ooooooo0000o`000003o`000003ooooool0003o000000Sooooo0_l00003ooooo`Co0000
2Oooool3o`0000;ooooo0_l00006ooooo`;o000000Coooooo`000?l0003o0000G_ooool001cooooo
00?o0000ooooooooool0B_ooool2o`000003ooooool0003o000000?ooooo1?l0000Fooooo`;o0000
00?oooooo`000?l000005_ooool2o`000003ooooool0003o000000?ooooo0_l00004ooooo`;o0000
0_ooool2o`0000;ooooo0_l00009ooooo`;o00003?ooool5o`0000?ooooo0_l00003ooooo`;o0000
2?ooool2o`0000?ooooo0_l0000?ooooo`;o00007?ooool2o`0004Kooooo000Looooo`03o`000?oo
oooooooo04gooooo0_l000000ooooooo0000o`000002ooooo`;o00005_ooool2o`0000Sooooo0ol0
0002ooooo`;o00003Oooool2o`0000gooooo0_l00002ooooo`?o00002?ooool3o`0000cooooo0_l0
00000ooooooo0000o`000002ooooo`;o00000_ooool3o`0000cooooo0ol00004ooooo`;o00002?oo
ool3o`0000Gooooo0_l0000Eooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0C?ooool2
o`000004ooooool0003o0000o`00027ooooo0_l000001?oooooo0000o`000?l00002ooooo`;o0000
5Oooool2o`0000Wooooo1Ol00003ooooo`;o00000_ooool2o`0000cooooo0_l000000ooooooo0000
o`000004ooooo`Co00002Oooool2o`0000;ooooo0_l00004ooooo`Co00001oooool2o`0000Kooooo
0_l0001Mooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o000000?oooooo`000?l000007ooo
ool2o`000003ooooool0003o000000Oooooo0_l00006ooooo`;o000000?oooooo`000?l000002Ooo
ool2o`0000?ooooo0_l00002ooooo`co00004?ooool2o`0000Oooooo1?l00009ooooo`;o00000_oo
ool2o`000004ooooool0003o0000ooooo`Co0000K_ooool001cooooo00?o0000ooooooooool0D?oo
ool2o`000003ooooool0003o000000?ooooo0_l0000Fooooo`;o00001?ooool2o`0000Cooooo0_l0
0004ooooo`Co000000?oooooo`000?l000003_ooool2o`0000;ooooo1?l00002ooooo`Co00002ooo
ool2o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`Go00003oooool2o`000003ooooool0
003o000000;o0000K_ooool001cooooo00?o0000ooooooooool0D?ooool5o`0000?ooooo0ol0000=
ooooo`;o00001oooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool2
o`0000?ooooo0_l00003ooooo`;o00003_ooool3o`0000Oooooo0_l00003ooooo`;o00000_ooool3
o`000003ooooool0003o000000Go000000Goooooo`000?l0003o0000ooooo`07o`0002Cooooo0_l0
00000ooooooo0000o`00001Jooooo`007?ooool00ol0003oooooooooo`1Aooooo`Co00001?ooool2
o`0000gooooo0_l00003ooooo`;o00000_ooool3o`0000Cooooo0ol000001?oooooo0000o`000?l0
0004ooooo`;o00000_ooool2o`0000?ooooo0_l00009ooooo`Co000000?oooooo`000?l000000_l0
0006ooooo`Co000000?oooooo`000?l000000_ooool3o`000003ooooool0003o000000Go000000?o
ooooo`000?l000001_l000000ooooooo0000o`000007ooooo`;o000000?oooooo`000?l000001Ooo
ool2o`00017ooooo0_l000000ooooooo0000o`00000<ooooo`;o0000C?ooool001cooooo00?o0000
ooooooooool0Eoooool2o`0000kooooo0_l00004ooooo`;o00000oooool2o`0000Cooooo0_l00002
ooooo`?o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00002_ooool2o`000003ooooool0
003o000000;o00000oooool2o`0000Gooooo0_l000000ooooooo0000o`000003ooooo`[o000000Co
ooooo`000?l0003o00000_ooool4o`0000;ooooo0_l00008ooooo`;o000000?oooooo`000?l00000
1Oooool2o`0000Kooooo0_l0000?ooooo`;o00002Oooool2o`0004cooooo000Looooo`03o`000?oo
oooooooo04oooooo0_l000000ooooooo0000o`000003ooooo`;o00001_ooool3o`0000Gooooo0_l0
000Gooooo`;o000000?oooooo`000?l000000oooool2o`0000[ooooo0_l000000ooooooo0000o`00
000<ooooo`;o00001_ooool4o`000003ooooool0003o000000Cooooo1Ol00002ooooo`?o000000?o
ooooo`000?l000001Ol0000=ooooo`;o00001_ooool2o`0000Wooooo0_l000001?oooooo0000o`00
0?ooool2o`0005Oooooo000Looooo`03o`000?oooooooooo04gooooo1?l000001?oooooo0000o`00
0?ooool4o`000003ooooool0003o000000?ooooo0ol00005ooooo`;o00002oooool4o`0000Gooooo
0_l0000Iooooo`;o00002Oooool2o`0000Cooooo0_l0000?ooooo`?o000000?oooooo`000?l00000
0_l00002ooooo`Ko00002_ooool5o`00017ooooo0_l000000ooooooo0000o`00001Jooooo`007?oo
ool2o`0004kooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000;o000000?o
ooooo`000?l000004oooool2o`000003ooooool0003o000000Co00001Oooool2o`0000Gooooo0_l0
00000ooooooo0000o`00000?ooooo`;o00002Oooool2o`0000Cooooo0_l00002ooooo`;o00003_oo
ool3o`0000Gooooo0_l0000=ooooo`?o0000L_ooool001cooooo00?o0000ooooooooool0D?ooool4
o`0000kooooo0_l0000;ooooo`;o000000?oooooo`000?l000000ol0000:ooooo`;o000000Cooooo
o`000?l0003ooooo0_l000000ooooooo0000o`000008ooooo`;o00002?ooool3o`0000Sooooo0_l0
0002ooooo`;o00001?ooool2o`0000Sooooo0_l00004ooooo`Co00001?ooool2o`0000cooooo1_l0
0003ooooo`;o00004Oooool2o`0005;ooooo000Looooo`03o`000?oooooooooo057ooooo0_l00004
ooooo`;o00002Oooool2o`00017ooooo0_l0000:ooooo`;o00001oooool3o`0000Oooooo0_l00008
ooooo`?o00000oooool2o`000003ooooool0003o000000;o00002?ooool2o`0000Wooooo0_l00002
ooooo`?o00001_ooool2o`0000cooooo1_l00003ooooo`;o00004Oooool2o`0005;ooooo000Loooo
o`03o`000?oooooooooo057ooooo0_l00004ooooo`?o00005_ooool2o`000003ooooool0003o0000
00Oooooo0_l000000ooooooo0000o`000009ooooo`?o00005Oooool4o`000003ooooool0003o0000
00[ooooo0ol00008ooooo`;o00000_ooool2o`0000Cooooo0_l0001oooooo`007?ooool00ol0003o
ooooooooo`1Aooooo`;o00001Oooool2o`0001Kooooo1Ol00006ooooo`?o000000?oooooo`000?l0
00001oooool4o`0001Kooooo0_l000000ooooooo0000o`00000:ooooo`Go00002?ooool2o`0000So
oooo1?l0001mooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o00003Oooool5o`0000Oooooo
0_l00009ooooo`Ko00001_ooool2o`0000Kooooo0_l00006ooooo`;o000000?oooooo`000?l00000
2_ooool2o`0000_ooooo0_l00003ooooo`;o00000oooool4o`000003ooooool0003o000000Cooooo
0_l0001dooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o00000_ooool2o`0000Wooooo0_l0
000=ooooo`;o000000Coooooo`000?l0003o00004Oooool2o`0000;ooooo0_l00006ooooo`;o0000
1_ooool2o`0000Cooooo0_l0000?ooooo`;o00002oooool2o`0000?ooooo0_l00002ooooo`?o0000
0oooool2o`0000Cooooo0_l0001dooooo`007?ooool00ol0003oooooooooo`1@ooooo`?o00000_oo
ool2o`0000gooooo0_l0000=ooooo`;o00005_ooool2o`0001?ooooo0_l0000?ooooo`;o00000_oo
ool2o`00013ooooo0ol00003ooooo`;o0000N_ooool001cooooo00?o0000ooooooooool0D?ooool2
o`0000Kooooo0_l0000:ooooo`?o00008?ooool2o`0000;ooooo0_l0000Xooooo`Go00000_ooool2
o`0000[ooooo1?l000000ooooooo0000o`00000<ooooo`;o0000K?ooool001cooooo00?o0000oooo
ooooool0F?ooool2o`0000[ooooo1Ol000000ooooooo0000o`00000?ooooo`?o00002Oooool2o`00
01Oooooo0_l0000Dooooo`Co00000_ooool2o`0000cooooo0_l00006ooooo`;o00001oooool2o`00
0003ooooool0003o000006Wooooo000Looooo`03o`000?oooooooooo063ooooo0_l00004ooooo`?o
000000?oooooo`000?l000000oooool2o`0000Cooooo0ol00003ooooo`?o00001oooool2o`00017o
oooo0_l00002ooooo`?o000000?oooooo`000?l000001?ooool2o`0001[ooooo0_l0000>ooooo`;o
00000_ooool2o`0000Kooooo0_l0001Yooooo`007?ooool00ol0003oooooooooo`1Nooooo`Co0000
1?ooool2o`0000Oooooo0_l00004ooooo`?o00001Oooool2o`0000Kooooo1?l0000?ooooo`;o0000
0_ooool3o`000003ooooool0003o000000Cooooo0_l0000<ooooo`;o000000?oooooo`000?l00000
2Oooool2o`0000_ooooo0_l000000ooooooo0000o`000002ooooo`;o0000LOooool001cooooo00?o
0000ooooooooool0G_ooool4o`0000Cooooo0_l00005ooooo`Go00001?ooool2o`0000Gooooo0_l0
0008ooooo`;o00001oooool2o`000003ooooool0003o000000?ooooo0_l0000?ooooo`;o00000_oo
ool2o`0000Gooooo0_l000000ooooooo0000o`00000Dooooo`Co000000?oooooo`000?l00000MOoo
ool001cooooo00?o0000ooooooooool0Goooool3o`0000Gooooo0_l00004ooooo`Go000000Cooooo
o`000?l0003ooooo0_l000000ooooooo0000o`00000Eooooo`;o000000?oooooo`000?l000001?oo
ool2o`000003ooooool0003o000000_ooooo0_l00002ooooo`?o00004oooool2o`0000Sooooo1?l0
001hooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Q
o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0Ioooool2o`0000[ooooo0_l00004ooooo`;o
00000_ooool3o`0001Wooooo0_l000000ooooooo0000o`000002ooooo`;o000000Coooooo`000?l0
003o00001?ooool2o`0000;ooooo0_l00003ooooo`Ko00002_ooool2o`0000[ooooo1_l0001doooo
o`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonH
V9So8B4Q00Kooooo00?o0000ooooooooool0L_ooool3o`0000Sooooo0ol00007ooooo`;o00005ooo
ool2o`000004ooooool0003o0000o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`Ko0000
6?ooool4o`0007Cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo06Sooooo0_l00008ooooo`?o0000
4_ooool2o`000003ooooool0003o000000?ooooo0ol00007ooooo`;o00002?ooool2o`0000Sooooo
0_l0000Cooooo`;o0000QOooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Ooo
ool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0001Xooooo`;o00004Oooool2o`0000_ooooo
1?l00003ooooo`?o00000oooool2o`0000;ooooo0_l00008ooooo`;o00001oooool2o`0000Gooooo
0_l0000=ooooo`;o0000QOooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Ooo
ool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0NOooool4o`0000_ooooo
0_l0000;ooooo`;o00001Oooool2o`0000Gooooo0_l00007ooooo`;o00001Oooool4o`0000Kooooo
0_l0002:ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj
^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`1`ooooo`;o00001oooool2o`0000;ooooo
1?l00009ooooo`;o00004?ooool2o`0000Sooooo0_l0000=ooooo`;o00001_ooool2o`00017ooooo
0_l0001gooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj
^_l000001_ooool00ol0003oooooooooo`1`ooooo`Co00000_ooool2o`0000Gooooo1?l00009oooo
o`;o00006_ooool2o`00013ooooo0_l00004ooooo`;o00000oooool2o`0000Cooooo0_l000000ooo
oooo0000o`000002ooooo`;o00004?ooool2o`0006Gooooo00001_ooooook^k^oc8b<_l0003o<S8b
onk^kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo07;ooooo0_l0
0002ooooo`;o00001oooool2o`0000Wooooo0_l0000Sooooo`;o00001_ooool5o`0000;ooooo0_l0
0003ooooo`;o00001?ooool2o`000003ooooool0003o000001Cooooo0_l0001Uooooo`007?ooool0
0ol0003oooooooooo`1oooooo`?o00002?ooool2o`000003ooooool0003o000000Kooooo0_l00002
ooooo`;o00003Oooool2o`0000Gooooo0_l00006ooooo`Oo0000Roooool001cooooo00?o0000oooo
ooooool0Hoooool2o`0001Oooooo0_l00002ooooo`;o00001Oooool2o`0000Cooooo0_l00006oooo
o`;o00000_ooool2o`0000Gooooo0_l00006ooooo`;o00001_ooool2o`0000Kooooo0_l00002oooo
o`;o00008Oooool2o`0006Sooooo000Looooo`03o`000?oooooooooo06?ooooo0_l0000Gooooo`;o
00002Oooool2o`0001Kooooo0ol000000ooooooo0000o`00000;ooooo`;o00000oooool2o`000003
ooooool0003o000002Gooooo0_l0001Xooooo`007?ooool00ol0003oooooooooo`2=ooooo`;o0000
4?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000=ooooo`;o00008oooool2o`0006gooooo
000Looooo`03o`000?oooooooooo07Wooooo0_l0000Booooo`;o00001oooool2o`0000Oooooo0_l0
0005ooooo`;o0000<_ooool2o`0006gooooo000Looooo`03o`000?oooooooooo07Wooooo0_l0000C
ooooo`;o00001_ooool2o`0000Oooooo0_l00005ooooo`;o00003?ooool2o`0009?ooooo000Loooo
o`03o`000?oooooooooo08kooooo0_l00005ooooo`;o00000_ooool2o`0000_ooooo0_l0000<oooo
o`;o0000Toooool001cooooo00?o0000ooooooooool0R?ooool2o`000003ooooool0003o000000;o
00001_ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000000_ooool2o`000003
ooooool0003o000000Kooooo0_l0002Kooooo`007?ooool00ol0003oooooooooo`28ooooo`;o0000
00?oooooo`000?l000000_l00009ooooo`Co000000?oooooo`000?l000000_ooool5o`0000Kooooo
0_l0000Pooooo`Co0000Moooool001cooooo00?o0000ooooooooool0Roooool4o`0000Wooooo0_l0
0003ooooo`Co00000_ooool2o`0001Sooooo0_l0000?ooooo`Co0000Moooool001cooooo00?o0000
ooooooooool0T_ooool2o`0000Cooooo0_l00005ooooo`;o00007?ooool2o`0000Oooooo0_l00021
ooooo`007?ooool2o`0009?ooooo0_l0000>ooooo`;o00008_ooool2o`00087ooooo000Looooo`03
o`000?oooooooooo06Oooooo0_l0000/ooooo`;o00002oooool2o`0001Wooooo0_l00009ooooo`;o
0000Ooooool001cooooo00?o0000ooooooooool0Ioooool2o`0002cooooo0_l0000Vooooo`;o0000
2Oooool2o`0007oooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0a?ooool2o`0008?ooooo000Looooo`03o`000?oooooooooo0<Cooooo0_l00023oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0<?ooooo
0_l00024ooooo`007?ooool00ol0003oooooooooo`33ooooo`;o0000Q?ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0;kooooo0_l00029ooooo`007?ooool00ol0003oooooooooo`2;ooooo`;o0000
<Oooool4o`0008Oooooo000Looooo`03o`000?oooooooooo08_ooooo0_l0000cooooo`;o0000Qooo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`23ooooo`;o0000
a?ooool001cooooo00?o0000ooooooooool0Poooool2o`000<Cooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`2booooo`;o0000UOooool001cooooo00?o0000ooooooooool0/_ooool2o`0009Gooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0Z_ooool2
o`0009gooooo000Looooo`03o`000?oooooooooo0:[ooooo0_l0002Mooooo`007?ooool00ol0003o
ooooooooo`2Iooooo`;o0000[_ooool001cooooo00?o0000ooooooooool0VOooool2o`000:kooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001;ooooo1?l000000ol@413oooooooooo`03ooooo`03
o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo0ol0003ooooood[ooooo000D
ooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBoooo
o`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?oooooo
D_ooool001;ooooo00?oEEEEofIVI_l00000oooooomDooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00XOooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo01Ko
oooo1?l000001?l@413oooooooooooooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b
<_o^k^h5ooooo`;o000000?o410@ooooooooool0R_ooool00:;ooooo00Go0000oooooooooooooooo
o`000009ooooo`Ko00003?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo08_ooooo002Rooooo`05o`00
0?ooooooooooooooool000006oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@4003ooooo`Go0000S?ooool00:;ooooo00Go0000oooooooo
ooooooooo`000009ooooo`Ko00003?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`04odA4A?oMgMgoooooo`0008gooooo002R
ooooo`05o`000?n7QhOoooooojVYZOl000006oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`04omgMgOmEEEGoooooo`0008go
oooo002Qooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool06Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4004ooooo`03
ogMgMoo<c<co000008gooooo0032ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?ok^k^odA4A?l00000SOooool00<3ooooo
00?oEEEEofIVI_l000001Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool00omgMgOo0000ooooo`2<ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1110) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.29059 .53902 Mdot
.32296 .53856 Mdot
.66891 .56438 Mdot
.4928 .36863 Mdot
.30295 .72032 Mdot
.63472 .57718 Mdot
.48001 .67356 Mdot
.49886 .62159 Mdot
.65657 .56559 Mdot
.32709 .62806 Mdot
.48342 .66909 Mdot
.46908 .45691 Mdot
.48836 .65716 Mdot
.48506 .38747 Mdot
.17161 .60711 Mdot
.52263 .40644 Mdot
.3567 .56592 Mdot
.62018 .41563 Mdot
.5086 .3219 Mdot
.62361 .59954 Mdot
.30801 .58537 Mdot
.48511 .37632 Mdot
.32257 .51172 Mdot
.48446 .38791 Mdot
.50223 .35807 Mdot
.32871 .56643 Mdot
.36867 .56852 Mdot
.46112 .33492 Mdot
.51526 .36496 Mdot
.48914 .62223 Mdot
.58423 .28894 Mdot
.2071 .66389 Mdot
.46547 .3066 Mdot
.59734 .78638 Mdot
.50604 .62687 Mdot
.28441 .47679 Mdot
.62369 .56153 Mdot
.49974 .63451 Mdot
.50993 .63529 Mdot
.47162 .67606 Mdot
.50515 .64822 Mdot
.32144 .55972 Mdot
.45515 .60972 Mdot
.47723 .58134 Mdot
.52796 .37625 Mdot
.35367 .71854 Mdot
.42958 .23033 Mdot
.43628 .37338 Mdot
.34744 .57063 Mdot
.70668 .54195 Mdot
.5178 .76604 Mdot
.48651 .67985 Mdot
.61139 .53929 Mdot
.67732 .83718 Mdot
.49141 .63064 Mdot
.52718 .35793 Mdot
.63944 .5534 Mdot
.47534 .3764 Mdot
.47958 .38907 Mdot
.23144 .40119 Mdot
.44478 .3332 Mdot
.64215 .43251 Mdot
.30678 .51091 Mdot
.57205 .45253 Mdot
.6435 .5617 Mdot
.51163 .64813 Mdot
.31069 .53953 Mdot
.48557 .65003 Mdot
.40783 .40924 Mdot
.59647 .57335 Mdot
.43733 .37061 Mdot
.50424 .66022 Mdot
.31537 .57928 Mdot
.45105 .35943 Mdot
.76361 .58889 Mdot
.16874 .40526 Mdot
.67386 .45762 Mdot
.25645 .44259 Mdot
.2212 .4422 Mdot
.73466 .48895 Mdot
.50048 .40049 Mdot
.61988 .23895 Mdot
.16801 .50703 Mdot
.3427 .50933 Mdot
.46267 .29696 Mdot
.59086 .51735 Mdot
.45552 .36151 Mdot
.28501 .65621 Mdot
.52255 .38223 Mdot
.78212 .61737 Mdot
.65709 .57312 Mdot
.34435 .53876 Mdot
.49456 .37085 Mdot
.46527 .32916 Mdot
.4292 .24642 Mdot
.42147 .39379 Mdot
.4714 .34271 Mdot
.30038 .57012 Mdot
.5007 .67539 Mdot
.51429 .43653 Mdot
.44394 .62251 Mdot
.65185 .54238 Mdot
.43653 .40386 Mdot
.60525 .57034 Mdot
.31579 .58256 Mdot
.44717 .35255 Mdot
.5184 .64397 Mdot
.44672 .40532 Mdot
.45352 .7157 Mdot
.32163 .53578 Mdot
.47172 .33006 Mdot
.63836 .43984 Mdot
.78919 .38081 Mdot
.34756 .53209 Mdot
.75374 .46598 Mdot
.50499 .40219 Mdot
.47219 .35309 Mdot
.32422 .54071 Mdot
.66579 .55161 Mdot
.26595 .63408 Mdot
.34087 .50273 Mdot
.47658 .68237 Mdot
.32082 .50471 Mdot
.43619 .30611 Mdot
.64855 .5727 Mdot
.57344 .7448 Mdot
.53899 .69108 Mdot
.57842 .26556 Mdot
.45939 .36493 Mdot
.37638 .65873 Mdot
.64489 .59898 Mdot
.3358 .54736 Mdot
.48169 .64915 Mdot
.54229 .35731 Mdot
.32786 .51991 Mdot
.47076 .64628 Mdot
.62927 .42589 Mdot
.61474 .6984 Mdot
.36555 .54258 Mdot
.44945 .59258 Mdot
.52344 .628 Mdot
.47682 .67751 Mdot
.65214 .77335 Mdot
.31341 .54515 Mdot
.65843 .41629 Mdot
.48044 .63524 Mdot
.55783 .28673 Mdot
.50486 .33349 Mdot
.64898 .28818 Mdot
.54613 .17503 Mdot
.61298 .78332 Mdot
.66965 .67814 Mdot
.66735 .40326 Mdot
.5025 .68371 Mdot
.49422 .34237 Mdot
.32553 .57171 Mdot
.31491 .56122 Mdot
.43576 .34893 Mdot
.49694 .36316 Mdot
.44016 .3636 Mdot
.47602 .32796 Mdot
.20967 .40436 Mdot
.45511 .41621 Mdot
.49224 .19536 Mdot
.3496 .53788 Mdot
.48837 .34966 Mdot
.63098 .54613 Mdot
.42029 .33629 Mdot
.50703 .65125 Mdot
.48013 .37012 Mdot
.49169 .3648 Mdot
.44541 .33046 Mdot
.48879 .68006 Mdot
.20134 .62436 Mdot
.61644 .20587 Mdot
.24571 .68577 Mdot
.7758 .553 Mdot
.62703 .58936 Mdot
.46082 .35698 Mdot
.65327 .43742 Mdot
.31882 .44933 Mdot
.49081 .4039 Mdot
.83377 .35831 Mdot
.47895 .35127 Mdot
.26437 .68912 Mdot
.39445 .339 Mdot
.26489 .72626 Mdot
.62751 .25912 Mdot
.49312 .3374 Mdot
.5139 .28649 Mdot
.38473 .47888 Mdot
.49032 .5869 Mdot
.50294 .64959 Mdot
.63932 .54661 Mdot
.65674 .55674 Mdot
.4873 .69797 Mdot
.2915 .60082 Mdot
.49076 .28814 Mdot
.418 .40833 Mdot
.59365 .55143 Mdot
.28681 .52985 Mdot
.64844 .39857 Mdot
.29568 .55601 Mdot
.20466 .29988 Mdot
.5054 .75154 Mdot
.47076 .6928 Mdot
.65303 .45788 Mdot
.66912 .58147 Mdot
.63364 .53927 Mdot
.66228 .43815 Mdot
.44677 .39309 Mdot
.30957 .54497 Mdot
.56374 .81469 Mdot
.32322 .60642 Mdot
.62028 .80422 Mdot
.31325 .57488 Mdot
.38232 .6143 Mdot
.47385 .65312 Mdot
.61672 .5696 Mdot
.47118 .34935 Mdot
.45311 .38767 Mdot
.32431 .59185 Mdot
.44041 .36753 Mdot
.40552 .28798 Mdot
.46216 .34176 Mdot
.54794 .75349 Mdot
.67696 .45619 Mdot
.48664 .69765 Mdot
.56732 .25271 Mdot
.3062 .52482 Mdot
.723 .36985 Mdot
.60356 .55574 Mdot
.29671 .45356 Mdot
.50247 .66449 Mdot
.63375 .42994 Mdot
.6006 .55616 Mdot
.64885 .39734 Mdot
.44951 .31523 Mdot
.68411 .58391 Mdot
.64881 .44662 Mdot
.21625 .50921 Mdot
.49979 .33333 Mdot
.20658 .40064 Mdot
.50688 .67778 Mdot
.34743 .50361 Mdot
.44622 .33296 Mdot
.61465 .5822 Mdot
.46515 .3047 Mdot
.66876 .65824 Mdot
.57135 .74564 Mdot
.6875 .56265 Mdot
.72279 .57813 Mdot
.63528 .42032 Mdot
.60983 .65642 Mdot
.39122 .64149 Mdot
.3404 .576 Mdot
.44463 .41503 Mdot
.24838 .72634 Mdot
.48054 .63566 Mdot
.45181 .4036 Mdot
.59146 .76155 Mdot
.48475 .63619 Mdot
.47329 .37637 Mdot
.5265 .65136 Mdot
.31287 .55991 Mdot
.73356 .32743 Mdot
.3543 .5679 Mdot
.51945 .38716 Mdot
.52052 .65118 Mdot
.68216 .56491 Mdot
.33605 .5671 Mdot
.44039 .39381 Mdot
.45438 .34487 Mdot
.54157 .50814 Mdot
.48418 .3427 Mdot
.22191 .6461 Mdot
.47148 .33399 Mdot
.64248 .54961 Mdot
.42093 .37808 Mdot
.84576 .53464 Mdot
.54706 .68653 Mdot
.31022 .54069 Mdot
.69085 .57511 Mdot
.65671 .56232 Mdot
.74086 .42448 Mdot
.57677 .62355 Mdot
.49506 .40983 Mdot
.62095 .58711 Mdot
.70456 .33744 Mdot
.47149 .6303 Mdot
.4361 .41236 Mdot
.4587 .58088 Mdot
.70386 .53539 Mdot
.59979 .54584 Mdot
.53736 .35652 Mdot
.34679 .58114 Mdot
.49525 .37 Mdot
.63483 .54107 Mdot
.28012 .56683 Mdot
.50726 .40601 Mdot
.40711 .53447 Mdot
.54024 .50826 Mdot
.46817 .65505 Mdot
.40871 .30981 Mdot
.43777 .39877 Mdot
.61185 .56451 Mdot
.30122 .53907 Mdot
.48465 .61764 Mdot
.33147 .56127 Mdot
.40759 .79828 Mdot
.45529 .71279 Mdot
.20552 .46873 Mdot
.62184 .39243 Mdot
.7185 .65954 Mdot
.30167 .75841 Mdot
.80928 .50942 Mdot
.66565 .34777 Mdot
.47175 .82804 Mdot
.63288 .54325 Mdot
.61272 .7578 Mdot
.65479 .55886 Mdot
.50879 .37632 Mdot
.64428 .56958 Mdot
.29403 .75588 Mdot
.46386 .34106 Mdot
.63644 .56803 Mdot
.73879 .37155 Mdot
.4912 .35713 Mdot
.34684 .52763 Mdot
.17524 .57194 Mdot
.82186 .50958 Mdot
.56144 .77139 Mdot
.67022 .59629 Mdot
.61816 .35866 Mdot
.47184 .33998 Mdot
.41998 .36348 Mdot
.35207 .56283 Mdot
.42748 .40805 Mdot
.65377 .3993 Mdot
.65069 .45791 Mdot
.45597 .48953 Mdot
.64452 .23645 Mdot
.4513 .44381 Mdot
.33997 .56711 Mdot
.25693 .33228 Mdot
.75798 .5988 Mdot
.73343 .60183 Mdot
.52141 .67482 Mdot
.19701 .59284 Mdot
.37671 .36494 Mdot
.4378 .67125 Mdot
.50191 .58059 Mdot
.33685 .53343 Mdot
.20927 .64243 Mdot
.50114 .64606 Mdot
.35662 .28488 Mdot
.56428 .33106 Mdot
.45129 .39354 Mdot
.49623 .67062 Mdot
.44464 .44781 Mdot
.82731 .54788 Mdot
.38883 .22384 Mdot
.53816 .20753 Mdot
.51681 .39848 Mdot
.76828 .57887 Mdot
.47799 .36197 Mdot
.25297 .62128 Mdot
.46914 .33356 Mdot
.33939 .55955 Mdot
.28392 .62525 Mdot
.50948 .49527 Mdot
.57735 .19391 Mdot
.49326 .74724 Mdot
.66684 .40285 Mdot
.46471 .34717 Mdot
.45241 .39453 Mdot
.64379 .40451 Mdot
.35135 .51844 Mdot
.47733 .32778 Mdot
.71187 .36669 Mdot
.4491 .36797 Mdot
.50522 .64066 Mdot
.51362 .21579 Mdot
.38064 .55247 Mdot
.4353 .42378 Mdot
.28247 .54705 Mdot
.46652 .65204 Mdot
.50662 .63055 Mdot
.52124 .41471 Mdot
.45785 .65753 Mdot
.48386 .35938 Mdot
.39978 .20578 Mdot
.36011 .53082 Mdot
.40104 .30871 Mdot
.3257 .5127 Mdot
.25082 .45072 Mdot
.51689 .63593 Mdot
.5405 .74385 Mdot
.53021 .42712 Mdot
.49921 .65016 Mdot
.43766 .69619 Mdot
.45633 .44274 Mdot
.50643 .41762 Mdot
.76125 .65107 Mdot
.67742 .58747 Mdot
.53351 .49929 Mdot
.50758 .62354 Mdot
.43488 .39206 Mdot
.44381 .42304 Mdot
.46717 .65775 Mdot
.33158 .28255 Mdot
.78065 .42803 Mdot
.46517 .3372 Mdot
.34793 .55259 Mdot
.33455 .54963 Mdot
.51086 .40947 Mdot
.45463 .41038 Mdot
.65252 .58993 Mdot
.68769 .58424 Mdot
.6575 .6078 Mdot
.53858 .50751 Mdot
.54333 .74781 Mdot
.39272 .75395 Mdot
.47159 .67581 Mdot
.39836 .68983 Mdot
.78782 .59993 Mdot
.42473 .32172 Mdot
.64389 .6031 Mdot
.46228 .39994 Mdot
.49043 .37073 Mdot
.48131 .61755 Mdot
.5734 .76855 Mdot
.41166 .43542 Mdot
.36226 .52897 Mdot
.50075 .61817 Mdot
.55277 .36289 Mdot
.43253 .74063 Mdot
.64371 .44036 Mdot
.68235 .743 Mdot
.50704 .65861 Mdot
.33924 .52928 Mdot
.52237 .64275 Mdot
.45082 .38391 Mdot
.52158 .33811 Mdot
.33129 .53995 Mdot
.65984 .45151 Mdot
.42669 .33609 Mdot
.47316 .37297 Mdot
.67797 .21258 Mdot
.7845 .56887 Mdot
.55208 .73555 Mdot
.48724 .33523 Mdot
.45706 .43016 Mdot
.63016 .39991 Mdot
.44898 .37356 Mdot
.44214 .34762 Mdot
.75471 .32674 Mdot
.51191 .71827 Mdot
.62715 .44152 Mdot
.34431 .29417 Mdot
.31896 .5763 Mdot
.23199 .70214 Mdot
.61613 .57349 Mdot
.45764 .66639 Mdot
.78763 .41959 Mdot
.64913 .54024 Mdot
.69488 .65438 Mdot
.22423 .6886 Mdot
.53048 .50157 Mdot
.6995 .44847 Mdot
.43929 .45537 Mdot
.45159 .33659 Mdot
.4745 .3599 Mdot
.65487 .43295 Mdot
.31129 .55026 Mdot
.54966 .48572 Mdot
.23786 .32543 Mdot
.48327 .36943 Mdot
.41441 .28267 Mdot
.20663 .53008 Mdot
.69588 .52286 Mdot
.66358 .40575 Mdot
.65871 .45395 Mdot
.46745 .35051 Mdot
.76607 .35512 Mdot
.32923 .56737 Mdot
.44107 .39503 Mdot
.48323 .41862 Mdot
.67571 .59269 Mdot
.32344 .53044 Mdot
.62816 .54275 Mdot
.53267 .74055 Mdot
.2591 .69037 Mdot
.68624 .21198 Mdot
.51096 .63167 Mdot
.22394 .57544 Mdot
.48017 .62485 Mdot
.60679 .23396 Mdot
.6313 .53795 Mdot
.49476 .40482 Mdot
.30252 .53357 Mdot
.44253 .40002 Mdot
.46591 .41112 Mdot
.44784 .3945 Mdot
.41023 .38586 Mdot
.8482 .40921 Mdot
.66378 .44283 Mdot
.45415 .43482 Mdot
.6588 .55529 Mdot
.2186 .59806 Mdot
.1671 .43624 Mdot
.45922 .39272 Mdot
.45698 .34748 Mdot
.34265 .52083 Mdot
.42871 .36015 Mdot
.47424 .62912 Mdot
.29977 .54326 Mdot
.4688 .32893 Mdot
.2068 .59632 Mdot
.51138 .35136 Mdot
.25797 .71007 Mdot
.52095 .63769 Mdot
.41916 .66062 Mdot
.44773 .43601 Mdot
.57141 .74158 Mdot
.53364 .49922 Mdot
.62215 .59281 Mdot
.45503 .62372 Mdot
.62639 .56101 Mdot
.31734 .24374 Mdot
.49366 .31676 Mdot
.49726 .34639 Mdot
.44264 .42077 Mdot
.62396 .58762 Mdot
.2852 .67116 Mdot
.58067 .66378 Mdot
.54405 .34115 Mdot
.64056 .59055 Mdot
.29201 .52511 Mdot
.60131 .45118 Mdot
.31006 .52393 Mdot
.64674 .45925 Mdot
.4837 .66779 Mdot
.67492 .43458 Mdot
.57823 .77863 Mdot
.32354 .5366 Mdot
.34494 .58987 Mdot
.62521 .58097 Mdot
.55924 .55834 Mdot
.59788 .85892 Mdot
.59594 .47528 Mdot
.61904 .27964 Mdot
.35361 .55915 Mdot
.51689 .38436 Mdot
.57146 .22419 Mdot
.54986 .55566 Mdot
.62952 .55992 Mdot
.49511 .39541 Mdot
.74927 .34732 Mdot
.65192 .59065 Mdot
.43796 .41285 Mdot
.67771 .57055 Mdot
.50011 .66016 Mdot
.65896 .59739 Mdot
.3698 .54933 Mdot
.4506 .35234 Mdot
.57101 .86168 Mdot
.63966 .47019 Mdot
.47626 .33621 Mdot
.5043 .61977 Mdot
.4181 .51753 Mdot
.47256 .40608 Mdot
.62746 .413 Mdot
.64402 .57664 Mdot
.59053 .4907 Mdot
.46572 .33583 Mdot
.62862 .58878 Mdot
.29713 .52893 Mdot
.45322 .6258 Mdot
.51224 .474 Mdot
.56806 .75018 Mdot
.34914 .56582 Mdot
.43721 .61739 Mdot
.46354 .62131 Mdot
.44893 .42874 Mdot
.45708 .41817 Mdot
.34438 .55112 Mdot
.70864 .29936 Mdot
.42343 .36453 Mdot
.50027 .40053 Mdot
.65674 .55308 Mdot
.62794 .56576 Mdot
.71726 .31469 Mdot
.67125 .5553 Mdot
.51617 .33209 Mdot
.34266 .55286 Mdot
.49736 .37781 Mdot
.3398 .52303 Mdot
.42588 .37205 Mdot
.27759 .57168 Mdot
.35438 .51767 Mdot
.58084 .64953 Mdot
.49658 .38636 Mdot
.39798 .32615 Mdot
.45521 .40483 Mdot
.44417 .36392 Mdot
.65567 .58637 Mdot
.66752 .41989 Mdot
.54103 .38579 Mdot
.65433 .46637 Mdot
.64202 .40065 Mdot
.38417 .48393 Mdot
.67507 .5922 Mdot
.65212 .42029 Mdot
.18894 .45324 Mdot
.666 .60353 Mdot
.64651 .4325 Mdot
.16966 .45893 Mdot
.50832 .6283 Mdot
.36052 .56478 Mdot
.49225 .3578 Mdot
.47187 .82231 Mdot
.44521 .21456 Mdot
.66697 .54522 Mdot
.47359 .33428 Mdot
.4658 .40179 Mdot
.33872 .50464 Mdot
.3845 .17886 Mdot
.60646 .58904 Mdot
.51042 .36584 Mdot
.31273 .5353 Mdot
.42719 .16491 Mdot
.63522 .54949 Mdot
.64938 .43331 Mdot
.49107 .68105 Mdot
.3429 .49307 Mdot
.54256 .68353 Mdot
.47351 .6691 Mdot
.61401 .53214 Mdot
.52621 .76297 Mdot
.50443 .403 Mdot
.64172 .60248 Mdot
.70128 .7365 Mdot
.35663 .59676 Mdot
.5198 .60534 Mdot
.60966 .36572 Mdot
.33944 .5333 Mdot
.4751 .62961 Mdot
.67434 .4224 Mdot
.30971 .57338 Mdot
.35652 .53171 Mdot
.47332 .62128 Mdot
.45145 .47994 Mdot
.46681 .57673 Mdot
.50611 .63549 Mdot
.7668 .63252 Mdot
.45154 .79327 Mdot
.63999 .60364 Mdot
.64725 .40136 Mdot
.54211 .80128 Mdot
.32232 .56035 Mdot
.1976 .59524 Mdot
.7111 .72113 Mdot
.47163 .34276 Mdot
.65152 .41476 Mdot
.32949 .71439 Mdot
.26685 .28829 Mdot
.48623 .63517 Mdot
.50549 .50296 Mdot
.67913 .41177 Mdot
.44309 .33709 Mdot
.56587 .31857 Mdot
.50338 .3881 Mdot
.47635 .66146 Mdot
.22093 .41943 Mdot
.3393 .52832 Mdot
.48414 .61485 Mdot
.67906 .74572 Mdot
.48456 .36346 Mdot
.49715 .39107 Mdot
.55257 .25286 Mdot
.3117 .56599 Mdot
.61914 .5912 Mdot
.50092 .40563 Mdot
.47634 .37165 Mdot
.53445 .36812 Mdot
.41898 .29694 Mdot
.78373 .3766 Mdot
.50967 .37111 Mdot
.51055 .74125 Mdot
.43807 .4265 Mdot
.49305 .38781 Mdot
.28215 .54637 Mdot
.74155 .2574 Mdot
.5286 .74068 Mdot
.47889 .36968 Mdot
.51599 .38156 Mdot
.4698 .62267 Mdot
.48342 .56444 Mdot
.55741 .56762 Mdot
.57723 .51405 Mdot
.64507 .34896 Mdot
.40939 .38876 Mdot
.31018 .52954 Mdot
.64202 .44484 Mdot
.49003 .42205 Mdot
.31188 .52873 Mdot
.46388 .3186 Mdot
.64921 .59245 Mdot
.67078 .6015 Mdot
.41822 .6127 Mdot
.64796 .42471 Mdot
.50703 .23561 Mdot
.3945 .69844 Mdot
.65426 .55033 Mdot
.49887 .3507 Mdot
.45266 .6602 Mdot
.63281 .54052 Mdot
.59172 .52652 Mdot
.4849 .29065 Mdot
.32221 .56824 Mdot
.34646 .53679 Mdot
.6518 .28964 Mdot
.63773 .68969 Mdot
.69213 .23671 Mdot
.49771 .66296 Mdot
.4361 .33332 Mdot
.38188 .64402 Mdot
.34709 .53437 Mdot
.5865 .23108 Mdot
.65028 .41914 Mdot
.48492 .63366 Mdot
.72042 .61333 Mdot
.33288 .51997 Mdot
.36145 .55754 Mdot
.52172 .37086 Mdot
.46564 .38111 Mdot
.67276 .3468 Mdot
.68595 .40426 Mdot
.46593 .64634 Mdot
.64403 .40319 Mdot
.5996 .5548 Mdot
.51148 .3736 Mdot
.33073 .50909 Mdot
.51013 .79696 Mdot
.51471 .38728 Mdot
.65684 .58824 Mdot
.33892 .53679 Mdot
.6384 .40833 Mdot
.63485 .40337 Mdot
.44536 .3645 Mdot
.26142 .33292 Mdot
.49595 .63831 Mdot
.3463 .52866 Mdot
.46038 .74654 Mdot
.42023 .37902 Mdot
.46545 .37457 Mdot
.40346 .33586 Mdot
.47475 .62365 Mdot
.40698 .63255 Mdot
.6765 .44065 Mdot
.31691 .55106 Mdot
.50191 .3435 Mdot
.64192 .42845 Mdot
.3995 .63453 Mdot
.68467 .55981 Mdot
.66413 .5934 Mdot
.62877 .40979 Mdot
.65142 .40783 Mdot
.62883 .41469 Mdot
.19362 .59187 Mdot
.37253 .53219 Mdot
.37805 .39137 Mdot
.42345 .35957 Mdot
.63343 .27407 Mdot
.54729 .36966 Mdot
.50834 .61854 Mdot
.67752 .58463 Mdot
.46181 .40795 Mdot
.51765 .3908 Mdot
.40405 .32306 Mdot
.38558 .34727 Mdot
.37533 .56516 Mdot
.32234 .53382 Mdot
.47256 .31287 Mdot
.6821 .58345 Mdot
.23192 .26686 Mdot
.41183 .83455 Mdot
.46322 .43974 Mdot
.52837 .57032 Mdot
.33373 .50926 Mdot
.45845 .64322 Mdot
.57446 .53869 Mdot
.5233 .6523 Mdot
.32248 .55021 Mdot
.51082 .37342 Mdot
.4034 .70198 Mdot
.62833 .40613 Mdot
.43355 .37819 Mdot
.47383 .64384 Mdot
.43568 .37073 Mdot
.47516 .67053 Mdot
.37109 .77944 Mdot
.7974 .58626 Mdot
.47798 .35008 Mdot
.46513 .43458 Mdot
.62801 .36367 Mdot
.46117 .39383 Mdot
.6022 .43634 Mdot
.33867 .51014 Mdot
.65563 .22602 Mdot
.51626 .34872 Mdot
.31072 .39526 Mdot
.41949 .37862 Mdot
.75162 .36104 Mdot
.46201 .37803 Mdot
.71097 .54019 Mdot
.45741 .33563 Mdot
.44324 .34986 Mdot
.52155 .6523 Mdot
.47199 .62136 Mdot
.29637 .57148 Mdot
.61568 .58463 Mdot
.24585 .69461 Mdot
.47052 .37293 Mdot
.57086 .75103 Mdot
.47583 .72252 Mdot
.65254 .40629 Mdot
.3221 .55262 Mdot
.39312 .16689 Mdot
.52316 .66667 Mdot
.78628 .49835 Mdot
.71866 .3332 Mdot
.53356 .70539 Mdot
.58679 .52068 Mdot
.26367 .61947 Mdot
.6356 .42473 Mdot
.44008 .33802 Mdot
.55597 .78397 Mdot
.74291 .60672 Mdot
.49701 .29286 Mdot
.47617 .61436 Mdot
.31073 .44213 Mdot
.52858 .79834 Mdot
.68224 .43041 Mdot
.67564 .43577 Mdot
.48526 .67791 Mdot
.71079 .56311 Mdot
.42345 .44063 Mdot
.64765 .4181 Mdot
.66767 .55525 Mdot
.64771 .60615 Mdot
.65214 .6376 Mdot
.32287 .56492 Mdot
.64628 .76312 Mdot
.36471 .71068 Mdot
.4725 .66689 Mdot
.6946 .46329 Mdot
.36589 .50508 Mdot
.36888 .56318 Mdot
.62122 .57271 Mdot
.66052 .58415 Mdot
.35828 .57013 Mdot
.51447 .33862 Mdot
.39211 .36019 Mdot
.48129 .36788 Mdot
.66007 .43227 Mdot
.45874 .38399 Mdot
.64711 .58805 Mdot
.4865 .64059 Mdot
.66388 .57767 Mdot
.52736 .65456 Mdot
.40411 .75283 Mdot
.4397 .38536 Mdot
.45106 .3485 Mdot
.44246 .21251 Mdot
.28724 .5488 Mdot
.48716 .7536 Mdot
.56216 .7598 Mdot
.65621 .5582 Mdot
.44154 .34721 Mdot
.30557 .52295 Mdot
.66925 .45462 Mdot
.44063 .21109 Mdot
.44256 .40842 Mdot
.332 .51028 Mdot
.50662 .35382 Mdot
.19876 .48382 Mdot
.83279 .45958 Mdot
.33261 .55815 Mdot
.53802 .17619 Mdot
.51456 .36768 Mdot
.26358 .60076 Mdot
.45192 .42217 Mdot
.68338 .32279 Mdot
.42304 .36672 Mdot
.31372 .5753 Mdot
.48114 .37435 Mdot
.30236 .55966 Mdot
.62846 .54768 Mdot
.46542 .66651 Mdot
.35829 .5515 Mdot
.4708 .4217 Mdot
.29213 .80466 Mdot
.48095 .66357 Mdot
.46832 .34838 Mdot
.50881 .6742 Mdot
.30653 .54298 Mdot
.35574 .56378 Mdot
.22547 .33162 Mdot
.53781 .7267 Mdot
.50042 .65907 Mdot
.50851 .36572 Mdot
.32699 .67456 Mdot
.50089 .38021 Mdot
.65157 .32665 Mdot
.53058 .36824 Mdot
.42115 .37517 Mdot
.17191 .39928 Mdot
.46786 .63295 Mdot
.71842 .26438 Mdot
.21464 .35081 Mdot
.19596 .57589 Mdot
.32052 .49813 Mdot
.67932 .44014 Mdot
.20697 .63527 Mdot
.54241 .74272 Mdot
.63458 .59094 Mdot
.45904 .4063 Mdot
.37869 .51513 Mdot
.49789 .63198 Mdot
.66781 .42483 Mdot
.47719 .34961 Mdot
.66266 .58392 Mdot
.78146 .45059 Mdot
.50443 .68426 Mdot
.32097 .55878 Mdot
.35964 .52104 Mdot
.48677 .16202 Mdot
.49329 .33698 Mdot
.45011 .34556 Mdot
.47924 .6653 Mdot
.38048 .58565 Mdot
.63356 .42097 Mdot
.75366 .39111 Mdot
.4987 .66038 Mdot
.53737 .53356 Mdot
.31453 .54086 Mdot
.46393 .40136 Mdot
.27938 .67639 Mdot
.76019 .57262 Mdot
.35821 .31268 Mdot
.65485 .43611 Mdot
.64157 .32449 Mdot
.31477 .57584 Mdot
.47984 .64464 Mdot
.62867 .70362 Mdot
.45638 .30102 Mdot
.46879 .39826 Mdot
.63493 .31978 Mdot
.49687 .48792 Mdot
.53308 .20891 Mdot
.43503 .40557 Mdot
.5284 .48717 Mdot
.42733 .38974 Mdot
.47567 .29878 Mdot
.52077 .34047 Mdot
.46287 .36788 Mdot
.33303 .50988 Mdot
.50134 .29745 Mdot
.63625 .59609 Mdot
.43919 .24854 Mdot
.55196 .51744 Mdot
.47061 .33631 Mdot
.50591 .38079 Mdot
.35384 .37743 Mdot
.433 .65446 Mdot
.35675 .54213 Mdot
.31509 .59448 Mdot
.46135 .66542 Mdot
.39726 .33612 Mdot
.61105 .58292 Mdot
.53064 .33359 Mdot
.65708 .58303 Mdot
.31691 .51556 Mdot
.64969 .55419 Mdot
.47933 .68091 Mdot
.65083 .6041 Mdot
.54324 .74929 Mdot
.4838 .62718 Mdot
.3224 .57236 Mdot
.45092 .36098 Mdot
.50257 .61937 Mdot
.56513 .26438 Mdot
.65931 .43246 Mdot
.21486 .34235 Mdot
.48751 .33046 Mdot
.52584 .70617 Mdot
.40729 .53047 Mdot
.66199 .5786 Mdot
.80988 .39904 Mdot
.35585 .51965 Mdot
.6333 .4472 Mdot
.31264 .51745 Mdot
.78311 .6365 Mdot
.6634 .41237 Mdot
.16833 .47005 Mdot
.67097 .69675 Mdot
.62236 .48378 Mdot
.51314 .33855 Mdot
.5701 .3375 Mdot
.59631 .55696 Mdot
.4969 .6316 Mdot
.6623 .68817 Mdot
.44088 .35255 Mdot
.80292 .52591 Mdot
.30353 .57963 Mdot
.61947 .58743 Mdot
.48444 .65154 Mdot
.49196 .61674 Mdot
.45454 .41355 Mdot
.71802 .44762 Mdot
.43015 .38684 Mdot
.61336 .6854 Mdot
.64203 .34303 Mdot
.40458 .42421 Mdot
.46228 .34242 Mdot
.61186 .55948 Mdot
.50663 .35433 Mdot
.63917 .37744 Mdot
.63129 .78246 Mdot
.41234 .37387 Mdot
.55643 .76179 Mdot
.62581 .45701 Mdot
.32775 .53905 Mdot
.49831 .4393 Mdot
.54958 .72368 Mdot
.50115 .34437 Mdot
.86903 .56681 Mdot
.6449 .4312 Mdot
.58016 .73795 Mdot
.42788 .41435 Mdot
.47511 .4182 Mdot
.57669 .39238 Mdot
.30641 .49375 Mdot
.76317 .57097 Mdot
.47163 .39205 Mdot
.59375 .32222 Mdot
.49883 .67219 Mdot
.43322 .39527 Mdot
.4731 .35654 Mdot
.35188 .4742 Mdot
.48605 .61949 Mdot
.66591 .56597 Mdot
.61565 .53878 Mdot
.62294 .60914 Mdot
.61934 .40633 Mdot
.51139 .51547 Mdot
.60876 .2495 Mdot
.81836 .51296 Mdot
.63834 .44548 Mdot
.513 .34979 Mdot
.62102 .37938 Mdot
.5116 .38737 Mdot
.67251 .41557 Mdot
.4847 .62102 Mdot
.35794 .54149 Mdot
.37844 .62666 Mdot
.59584 .57146 Mdot
.43699 .41354 Mdot
.65592 .39779 Mdot
.32482 .57097 Mdot
.67239 .39066 Mdot
.32145 .54384 Mdot
.49688 .65738 Mdot
.4658 .67642 Mdot
.67053 .42381 Mdot
.31497 .5197 Mdot
.4405 .68656 Mdot
.27109 .28799 Mdot
.52888 .35021 Mdot
.53811 .60406 Mdot
.29014 .54343 Mdot
.3465 .58441 Mdot
.29629 .56331 Mdot
.43963 .37133 Mdot
.524 .56877 Mdot
.52717 .39734 Mdot
.46658 .64899 Mdot
.67717 .57173 Mdot
.71837 .38331 Mdot
.44768 .77837 Mdot
.71968 .40602 Mdot
.44105 .32703 Mdot
.4859 .36849 Mdot
.46778 .3506 Mdot
.52525 .38111 Mdot
.59859 .69364 Mdot
.44663 .40143 Mdot
.5205 .65724 Mdot
.6482 .5795 Mdot
.44274 .33384 Mdot
.6806 .5542 Mdot
.28851 .64477 Mdot
.64679 .44875 Mdot
.49724 .50925 Mdot
.24922 .74762 Mdot
.33288 .572 Mdot
.66843 .55242 Mdot
.63269 .58932 Mdot
.62941 .42578 Mdot
.50014 .63607 Mdot
.31603 .54421 Mdot
.69292 .33899 Mdot
.63368 .40768 Mdot
.47931 .37316 Mdot
.57033 .59499 Mdot
.79573 .53227 Mdot
.43419 .34732 Mdot
.48134 .4093 Mdot
.68651 .56062 Mdot
.71058 .55259 Mdot
.6336 .81027 Mdot
.55989 .23002 Mdot
.66908 .42067 Mdot
.6566 .45082 Mdot
.34975 .57951 Mdot
.48951 .436 Mdot
.46747 .65313 Mdot
.50034 .21339 Mdot
.42047 .49483 Mdot
.50857 .23126 Mdot
.52199 .47231 Mdot
.44433 .40739 Mdot
.32766 .2701 Mdot
.48526 .36223 Mdot
.34928 .50982 Mdot
.30617 .55304 Mdot
.34897 .5592 Mdot
.49473 .63364 Mdot
.26776 .45128 Mdot
.51941 .65441 Mdot
.27896 .76741 Mdot
.32356 .57792 Mdot
.59437 .71645 Mdot
.61361 .56036 Mdot
.44181 .43447 Mdot
.63689 .41228 Mdot
.51356 .61533 Mdot
.40678 .40705 Mdot
.7721 .35906 Mdot
.62783 .59198 Mdot
.32394 .57343 Mdot
.26095 .61463 Mdot
.33855 .782 Mdot
.5651 .55215 Mdot
.55361 .37645 Mdot
.58053 .37504 Mdot
.65245 .40482 Mdot
.36074 .30493 Mdot
.6645 .39945 Mdot
.47594 .63675 Mdot
.4534 .35213 Mdot
.45654 .36197 Mdot
.42469 .38055 Mdot
.4433 .39496 Mdot
.45736 .64105 Mdot
.4176 .36559 Mdot
.84574 .53467 Mdot
.6758 .59877 Mdot
.21234 .49793 Mdot
.63917 .42821 Mdot
.46546 .61671 Mdot
.64896 .58111 Mdot
.69581 .56386 Mdot
.57413 .2505 Mdot
.46418 .33743 Mdot
.45913 .4075 Mdot
.78848 .51638 Mdot
.43257 .40384 Mdot
.54983 .39099 Mdot
.63025 .58959 Mdot
.71946 .40338 Mdot
.64861 .45438 Mdot
.66968 .44271 Mdot
.49743 .62316 Mdot
.31343 .51884 Mdot
.65446 .42647 Mdot
.6323 .54783 Mdot
.44627 .32113 Mdot
.49126 .41635 Mdot
.28952 .54744 Mdot
.71974 .71349 Mdot
.68243 .42311 Mdot
.27158 .6264 Mdot
.3015 .54773 Mdot
.37055 .51747 Mdot
.47062 .39832 Mdot
.46519 .28041 Mdot
.3619 .4918 Mdot
.63144 .4397 Mdot
.46261 .61897 Mdot
.58373 .50953 Mdot
.47112 .65052 Mdot
.31145 .55555 Mdot
.49973 .41429 Mdot
.31018 .55942 Mdot
.48436 .33413 Mdot
.17858 .67267 Mdot
.45907 .36853 Mdot
.82317 .5256 Mdot
.65124 .303 Mdot
.63519 .57941 Mdot
.45233 .70561 Mdot
.61885 .5774 Mdot
.30192 .55198 Mdot
.489 .42084 Mdot
.67323 .44355 Mdot
.18825 .54327 Mdot
.37126 .51249 Mdot
.65069 .59466 Mdot
.62606 .60547 Mdot
.48045 .62583 Mdot
.43767 .33617 Mdot
.46388 .39864 Mdot
.63428 .56754 Mdot
.39638 .41619 Mdot
.33372 .51674 Mdot
.45558 .34567 Mdot
.49011 .37972 Mdot
.63282 .57968 Mdot
.29228 .26896 Mdot
.26446 .53601 Mdot
.45966 .3569 Mdot
.6301 .73132 Mdot
.50641 .61742 Mdot
.52393 .35524 Mdot
.42685 .42308 Mdot
.64875 .4108 Mdot
.23554 .51048 Mdot
.61394 .78807 Mdot
.51541 .62618 Mdot
.61449 .57695 Mdot
.49629 .33826 Mdot
.61165 .56267 Mdot
.48185 .41988 Mdot
.24773 .52926 Mdot
.62876 .5975 Mdot
.4881 .41267 Mdot
.48368 .44017 Mdot
.30997 .56488 Mdot
.45115 .40808 Mdot
.36586 .41233 Mdot
.61658 .5436 Mdot
.47167 .41687 Mdot
.25888 .33773 Mdot
.51044 .64162 Mdot
.47745 .44165 Mdot
.64764 .44487 Mdot
.69753 .34097 Mdot
.39476 .71416 Mdot
.57796 .75806 Mdot
.65527 .44693 Mdot
.43409 .37109 Mdot
.63447 .60955 Mdot
.47999 .67473 Mdot
.81459 .48909 Mdot
.43578 .3511 Mdot
.47664 .66104 Mdot
.48594 .6426 Mdot
.6472 .44072 Mdot
.62262 .18133 Mdot
.41735 .40367 Mdot
.45932 .3916 Mdot
.37675 .46276 Mdot
.31323 .50932 Mdot
.45659 .37881 Mdot
.51846 .37268 Mdot
.51829 .66236 Mdot
.5494 .40324 Mdot
.33621 .42144 Mdot
.73929 .3679 Mdot
.52834 .63464 Mdot
.58511 .48335 Mdot
.61893 .59555 Mdot
.63985 .42359 Mdot
.33263 .54229 Mdot
.67311 .40204 Mdot
.66036 .60017 Mdot
.51588 .35794 Mdot
.51471 .6736 Mdot
.37265 .3252 Mdot
.48227 .67738 Mdot
.58232 .75267 Mdot
.30166 .52176 Mdot
.36594 .65068 Mdot
.87204 .50144 Mdot
.36783 .71762 Mdot
.43554 .66183 Mdot
.65265 .40646 Mdot
.63837 .52814 Mdot
.48921 .37629 Mdot
.37353 .28154 Mdot
.44654 .35991 Mdot
.2626 .338 Mdot
.67586 .5618 Mdot
.65712 .60801 Mdot
.45616 .35441 Mdot
.64609 .33892 Mdot
.47239 .67033 Mdot
.47064 .6311 Mdot
.46677 .41473 Mdot
.49952 .65026 Mdot
.46714 .38363 Mdot
.65274 .58627 Mdot
.75218 .29763 Mdot
.47951 .35938 Mdot
.4943 .42514 Mdot
.55328 .64008 Mdot
.17896 .39903 Mdot
.65524 .7317 Mdot
.3567 .25555 Mdot
.37309 .80118 Mdot
.49861 .65065 Mdot
.52408 .40781 Mdot
.58814 .47864 Mdot
.68483 .55714 Mdot
.43621 .67773 Mdot
.45145 .37268 Mdot
.44813 .37321 Mdot
.44529 .34494 Mdot
.49817 .39084 Mdot
.36292 .28969 Mdot
.37638 .39646 Mdot
.24896 .3907 Mdot
.46289 .41032 Mdot
.54266 .28736 Mdot
.50877 .62539 Mdot
.30166 .58152 Mdot
.66637 .39324 Mdot
.44475 .40733 Mdot
.37552 .38435 Mdot
.49733 .61338 Mdot
.28121 .76894 Mdot
.48738 .62326 Mdot
.65545 .56193 Mdot
.45935 .64903 Mdot
.48416 .34115 Mdot
.33546 .54947 Mdot
.56388 .51204 Mdot
.61429 .65799 Mdot
.63551 .59132 Mdot
.47601 .33608 Mdot
.57074 .72874 Mdot
.63749 .59507 Mdot
.2908 .64834 Mdot
.33849 .54466 Mdot
.58585 .31156 Mdot
.30623 .55446 Mdot
.48904 .41286 Mdot
.49815 .40524 Mdot
.50645 .59686 Mdot
.47252 .67362 Mdot
.30459 .55116 Mdot
.65741 .19309 Mdot
.66149 .39649 Mdot
.34396 .56202 Mdot
.45795 .30632 Mdot
.45091 .54845 Mdot
.34322 .54811 Mdot
.70515 .39722 Mdot
.49144 .62948 Mdot
.33758 .58029 Mdot
.45037 .30584 Mdot
.73315 .68152 Mdot
.62597 .42677 Mdot
.65378 .61626 Mdot
.58861 .60647 Mdot
.62632 .54095 Mdot
.45517 .6279 Mdot
.62305 .5809 Mdot
.5033 .66998 Mdot
.45688 .72922 Mdot
.45763 .23885 Mdot
.4577 .67019 Mdot
.45536 .63543 Mdot
.62583 .58091 Mdot
.45523 .3408 Mdot
.57927 .58293 Mdot
.52956 .38606 Mdot
.41006 .34724 Mdot
.50647 .66424 Mdot
.31373 .57436 Mdot
.36729 .55295 Mdot
.55876 .3084 Mdot
.35838 .51776 Mdot
.65826 .58366 Mdot
.83031 .47606 Mdot
.56107 .77527 Mdot
.49119 .67048 Mdot
.45987 .63023 Mdot
.50246 .38065 Mdot
.62724 .5605 Mdot
.61503 .55266 Mdot
.4753 .63284 Mdot
.44425 .26067 Mdot
.4942 .42969 Mdot
.34345 .58802 Mdot
.33098 .579 Mdot
.33824 .5561 Mdot
.29829 .56358 Mdot
.33142 .38589 Mdot
.48874 .62839 Mdot
.31014 .5723 Mdot
.48025 .41462 Mdot
.44929 .37415 Mdot
.57306 .51413 Mdot
.66344 .44677 Mdot
.4631 .31949 Mdot
.51405 .33357 Mdot
.46987 .40091 Mdot
.66096 .59521 Mdot
.40748 .33963 Mdot
.62129 .5939 Mdot
.63872 .61435 Mdot
.68581 .58435 Mdot
.54311 .74407 Mdot
.58719 .37448 Mdot
.42038 .82409 Mdot
.51052 .36522 Mdot
.33207 .60606 Mdot
.62127 .5568 Mdot
.79495 .38169 Mdot
.40529 .62546 Mdot
.43897 .34869 Mdot
.75395 .57869 Mdot
.63222 .56896 Mdot
.36154 .52097 Mdot
.45381 .37165 Mdot
.6343 .6153 Mdot
.63819 .4415 Mdot
.4868 .31048 Mdot
.61966 .53945 Mdot
.31151 .52411 Mdot
.6355 .38985 Mdot
.32216 .58005 Mdot
.68571 .57753 Mdot
.48155 .44068 Mdot
.62393 .85431 Mdot
.59839 .57961 Mdot
.18507 .44491 Mdot
.28946 .51355 Mdot
.45482 .34465 Mdot
.65436 .54592 Mdot
.31927 .50685 Mdot
.45352 .62855 Mdot
.44196 .50192 Mdot
.36029 .53344 Mdot
.6559 .6081 Mdot
.62307 .53958 Mdot
.63122 .59027 Mdot
.32733 .53202 Mdot
.50697 .4138 Mdot
.33273 .52563 Mdot
.45917 .64567 Mdot
.4946 .36621 Mdot
.29256 .75361 Mdot
.35092 .60097 Mdot
.30266 .54914 Mdot
.66995 .57104 Mdot
.62815 .40238 Mdot
.48109 .35107 Mdot
.19877 .40816 Mdot
.47361 .33104 Mdot
.49015 .67383 Mdot
.731 .30272 Mdot
.37128 .32334 Mdot
.42244 .36431 Mdot
.50237 .38158 Mdot
.46633 .63905 Mdot
.47029 .34094 Mdot
.425 .35887 Mdot
.54083 .73706 Mdot
.32067 .53058 Mdot
.48342 .37535 Mdot
.67131 .5625 Mdot
.51883 .77215 Mdot
.51178 .41681 Mdot
.75763 .46762 Mdot
.60564 .32447 Mdot
.69286 .25315 Mdot
.44627 .3565 Mdot
.5359 .22678 Mdot
.49326 .3978 Mdot
.43483 .38141 Mdot
.50626 .37234 Mdot
.38896 .24442 Mdot
.63844 .60023 Mdot
.64118 .58731 Mdot
.62737 .43149 Mdot
.60303 .32454 Mdot
.65007 .41367 Mdot
.49658 .62741 Mdot
.73909 .47267 Mdot
.62923 .59753 Mdot
.30935 .52538 Mdot
.43107 .37672 Mdot
.59669 .57672 Mdot
.46044 .40131 Mdot
.48589 .34043 Mdot
.6051 .56989 Mdot
.60164 .57925 Mdot
.57807 .74716 Mdot
.64727 .44707 Mdot
.35458 .55451 Mdot
.47799 .32051 Mdot
.64527 .40026 Mdot
.49614 .4204 Mdot
.63202 .2693 Mdot
.3531 .55356 Mdot
.32354 .52871 Mdot
.36806 .53887 Mdot
.51543 .35715 Mdot
.47991 .34191 Mdot
.51824 .65637 Mdot
.3081 .52347 Mdot
.50882 .64187 Mdot
.5451 .50826 Mdot
.7557 .44914 Mdot
.45131 .37271 Mdot
.2807 .62608 Mdot
.64047 .41413 Mdot
.65909 .57086 Mdot
.78085 .47441 Mdot
.62476 .42559 Mdot
.47747 .33292 Mdot
.60945 .56238 Mdot
.67338 .42465 Mdot
.55921 .35869 Mdot
.48735 .83904 Mdot
.63555 .39603 Mdot
.47681 .41481 Mdot
.53817 .4294 Mdot
.38119 .22125 Mdot
.62386 .40122 Mdot
.50199 .67755 Mdot
.51394 .35321 Mdot
.40374 .52959 Mdot
.68183 .42169 Mdot
.479 .75369 Mdot
.64106 .57502 Mdot
.67565 .73483 Mdot
.40278 .38522 Mdot
.40162 .25994 Mdot
.67229 .40528 Mdot
.31644 .5472 Mdot
.28206 .56996 Mdot
.47932 .3984 Mdot
.62436 .3997 Mdot
.53185 .64028 Mdot
.64712 .57273 Mdot
.5282 .74391 Mdot
.32985 .53084 Mdot
.33126 .64451 Mdot
.67321 .57848 Mdot
.29005 .63588 Mdot
.74154 .34442 Mdot
.39772 .4069 Mdot
.36794 .24401 Mdot
.71065 .63619 Mdot
.51391 .34843 Mdot
.6554 .39493 Mdot
.51242 .62418 Mdot
.49761 .68034 Mdot
.49505 .66138 Mdot
.47003 .72475 Mdot
.57307 .5259 Mdot
.68177 .56075 Mdot
.65688 .64677 Mdot
.64231 .42626 Mdot
.53453 .26904 Mdot
.47223 .42457 Mdot
.48463 .36692 Mdot
.44071 .33081 Mdot
.43514 .401 Mdot
.48909 .39511 Mdot
.50237 .64141 Mdot
.47991 .73091 Mdot
.5875 .49379 Mdot
.34973 .54941 Mdot
.71102 .43715 Mdot
.61416 .5599 Mdot
.69087 .57289 Mdot
.66852 .43742 Mdot
.25842 .62386 Mdot
.66913 .54857 Mdot
.65482 .55639 Mdot
.46493 .3262 Mdot
.33091 .52083 Mdot
.52429 .32078 Mdot
.49979 .40036 Mdot
.65637 .57676 Mdot
.57778 .45032 Mdot
.35039 .41034 Mdot
.44162 .29768 Mdot
.61799 .39238 Mdot
.51695 .5643 Mdot
.62735 .39869 Mdot
.47521 .4272 Mdot
.78386 .36757 Mdot
.65744 .60096 Mdot
.64162 .55867 Mdot
.66403 .40149 Mdot
.257 .57875 Mdot
.33623 .53588 Mdot
.69589 .56286 Mdot
.5068 .67327 Mdot
.50795 .39489 Mdot
.77209 .44116 Mdot
.26276 .58876 Mdot
.72094 .45524 Mdot
.49182 .66536 Mdot
.62044 .55103 Mdot
.43215 .3415 Mdot
.47796 .41403 Mdot
.64732 .40409 Mdot
.33514 .7486 Mdot
.4902 .31495 Mdot
.1945 .58101 Mdot
.79896 .59186 Mdot
.72987 .69578 Mdot
.46866 .39814 Mdot
.32154 .53173 Mdot
.63395 .53812 Mdot
.64679 .40173 Mdot
.42467 .33378 Mdot
.46719 .83593 Mdot
.28892 .56282 Mdot
.47769 .63935 Mdot
.57165 .48693 Mdot
.57315 .54169 Mdot
.48251 .3286 Mdot
.4477 .36058 Mdot
.43944 .37836 Mdot
.56127 .82713 Mdot
.66097 .59161 Mdot
.32814 .50869 Mdot
.65721 .43803 Mdot
.35619 .51505 Mdot
.63692 .58456 Mdot
.34577 .64985 Mdot
.4612 .33365 Mdot
.28824 .56036 Mdot
.31919 .54709 Mdot
.4823 .62546 Mdot
.45298 .63662 Mdot
.55627 .50091 Mdot
.46013 .36974 Mdot
.5919 .55334 Mdot
.31293 .56967 Mdot
.57128 .59202 Mdot
.66198 .41066 Mdot
.51607 .63575 Mdot
.46015 .40924 Mdot
.64805 .60057 Mdot
.41743 .36473 Mdot
.34934 .53638 Mdot
.65273 .55552 Mdot
.57527 .74494 Mdot
.65493 .44993 Mdot
.44743 .38734 Mdot
.63202 .38558 Mdot
.61387 .57625 Mdot
.49095 .37817 Mdot
.24677 .59696 Mdot
.6132 .41479 Mdot
.58965 .66344 Mdot
.68224 .56615 Mdot
.57018 .74918 Mdot
.36557 .54874 Mdot
.43948 .71598 Mdot
.64732 .56042 Mdot
.24807 .61063 Mdot
.38981 .76765 Mdot
.45926 .31463 Mdot
.32615 .5608 Mdot
.66674 .53171 Mdot
.22253 .69931 Mdot
.28796 .27865 Mdot
.46963 .35004 Mdot
.67411 .55698 Mdot
.66212 .40203 Mdot
.49254 .67062 Mdot
.75876 .46567 Mdot
.62576 .37943 Mdot
.61283 .5943 Mdot
.50741 .3737 Mdot
.30845 .54356 Mdot
.49039 .63497 Mdot
.41026 .7213 Mdot
.65093 .55124 Mdot
.67723 .57638 Mdot
.42963 .346 Mdot
.65003 .42035 Mdot
.23638 .34695 Mdot
.65034 .58862 Mdot
.78762 .5309 Mdot
.60457 .53418 Mdot
.65365 .39695 Mdot
.4886 .40477 Mdot
.57269 .33644 Mdot
.52648 .3726 Mdot
.17953 .47513 Mdot
.61769 .57306 Mdot
.35331 .54238 Mdot
.44098 .36311 Mdot
.73472 .35335 Mdot
.65503 .57366 Mdot
.53154 .57064 Mdot
.72321 .55931 Mdot
.48959 .62904 Mdot
.78342 .47859 Mdot
.45525 .38622 Mdot
.47558 .67262 Mdot
.64118 .41376 Mdot
.46259 .36154 Mdot
.4826 .34436 Mdot
.33751 .50323 Mdot
.47396 .63778 Mdot
.42202 .79092 Mdot
.48246 .615 Mdot
.52155 .64014 Mdot
.36549 .51671 Mdot
.47778 .38608 Mdot
.65848 .56273 Mdot
.63143 .5672 Mdot
.41803 .33641 Mdot
.80215 .37251 Mdot
.33658 .53344 Mdot
.6881 .46849 Mdot
.58192 .82397 Mdot
.40219 .41533 Mdot
.78049 .46854 Mdot
.33083 .7431 Mdot
.53158 .64595 Mdot
.46467 .41303 Mdot
.30678 .53297 Mdot
.69721 .56624 Mdot
.67515 .57362 Mdot
.50693 .41157 Mdot
.49022 .64192 Mdot
.63494 .43894 Mdot
.60154 .55586 Mdot
.71961 .44544 Mdot
.43856 .38772 Mdot
.75659 .58635 Mdot
.63956 .54371 Mdot
.17907 .59497 Mdot
.66599 .53805 Mdot
.33115 .56161 Mdot
.48787 .34317 Mdot
.36151 .5278 Mdot
.66207 .43463 Mdot
.56771 .49277 Mdot
.48817 .64091 Mdot
.45908 .46407 Mdot
.83605 .60919 Mdot
.62629 .58813 Mdot
.33831 .50984 Mdot
.4218 .36599 Mdot
.57383 .4134 Mdot
.46014 .38712 Mdot
.51239 .44519 Mdot
.6153 .44207 Mdot
.51023 .65807 Mdot
.49271 .67595 Mdot
.49196 .37315 Mdot
.63157 .41577 Mdot
.62432 .55053 Mdot
.64864 .57066 Mdot
.14899 .40463 Mdot
.58362 .64143 Mdot
.67562 .34519 Mdot
.44727 .37726 Mdot
.64492 .6082 Mdot
.46889 .77668 Mdot
.4806 .6662 Mdot
.45893 .42254 Mdot
.61258 .58433 Mdot
.75115 .64162 Mdot
.69669 .32413 Mdot
.48752 .39861 Mdot
.41416 .4074 Mdot
.50658 .67425 Mdot
.53747 .25511 Mdot
.68437 .58177 Mdot
.53155 .36947 Mdot
.48168 .6872 Mdot
.71434 .29904 Mdot
.66981 .76164 Mdot
.35426 .55519 Mdot
.71434 .55405 Mdot
.50222 .64041 Mdot
.4132 .33579 Mdot
.64021 .43321 Mdot
.60035 .54999 Mdot
.65487 .59621 Mdot
.50549 .3619 Mdot
.41809 .36609 Mdot
.62931 .36648 Mdot
.34504 .51293 Mdot
.50658 .62472 Mdot
.44908 .35084 Mdot
.36305 .62412 Mdot
.42535 .38433 Mdot
.51781 .65127 Mdot
.592 .8803 Mdot
.47551 .31797 Mdot
.46133 .38928 Mdot
.23739 .34301 Mdot
.36076 .53532 Mdot
.35635 .51319 Mdot
.8101 .55927 Mdot
.4472 .37814 Mdot
.79011 .50131 Mdot
.35658 .55322 Mdot
.34022 .53377 Mdot
.55177 .70609 Mdot
.48162 .35591 Mdot
.46519 .21821 Mdot
.47835 .67201 Mdot
.52387 .65452 Mdot
.33311 .52702 Mdot
.47819 .31559 Mdot
.52562 .66399 Mdot
.34028 .32155 Mdot
.62542 .5608 Mdot
.77515 .35051 Mdot
.35083 .52961 Mdot
.51493 .49715 Mdot
.48767 .66766 Mdot
.27507 .7648 Mdot
.68577 .63253 Mdot
.45351 .34296 Mdot
.44471 .38542 Mdot
.6393 .41766 Mdot
.47136 .31748 Mdot
.66001 .60747 Mdot
.49991 .65018 Mdot
.21116 .41697 Mdot
.34807 .56013 Mdot
.46282 .37579 Mdot
.27993 .63655 Mdot
.40638 .7439 Mdot
.67873 .70191 Mdot
.32745 .53989 Mdot
.32447 .56426 Mdot
.68341 .58015 Mdot
.66931 .55402 Mdot
.47992 .3923 Mdot
.46763 .64151 Mdot
.30492 .5288 Mdot
.51432 .6583 Mdot
.65867 .60024 Mdot
.66099 .56212 Mdot
.63212 .60013 Mdot
.52887 .34143 Mdot
.66024 .55687 Mdot
.72524 .42458 Mdot
.3317 .65103 Mdot
.36926 .56297 Mdot
.75262 .70256 Mdot
.41043 .71901 Mdot
.40913 .49942 Mdot
.67786 .43678 Mdot
.61343 .57606 Mdot
.4608 .63408 Mdot
.49926 .38207 Mdot
.45964 .40469 Mdot
.67211 .61581 Mdot
.46202 .65017 Mdot
.66677 .42772 Mdot
.4668 .66564 Mdot
.64609 .44071 Mdot
.74323 .59223 Mdot
.44027 .33394 Mdot
.4933 .41386 Mdot
.50332 .64718 Mdot
.65454 .55504 Mdot
.645 .58175 Mdot
.63418 .39437 Mdot
.44643 .48449 Mdot
.63529 .59509 Mdot
.3507 .53138 Mdot
.32402 .37549 Mdot
.62768 .53871 Mdot
.4548 .37458 Mdot
.60473 .24371 Mdot
.38248 .28059 Mdot
.52541 .38453 Mdot
.54415 .72094 Mdot
.50247 .18892 Mdot
.43631 .36283 Mdot
.51028 .18017 Mdot
.56787 .74933 Mdot
.35969 .52801 Mdot
.67883 .56534 Mdot
.69642 .57357 Mdot
.52454 .42998 Mdot
.68506 .40778 Mdot
.42498 .33047 Mdot
.36137 .5408 Mdot
.28074 .54952 Mdot
.7596 .64758 Mdot
.18345 .44873 Mdot
.67001 .40652 Mdot
.671 .43745 Mdot
.64655 .56191 Mdot
.27285 .26924 Mdot
.45178 .29851 Mdot
.66887 .4234 Mdot
.46606 .23866 Mdot
.5091 .37483 Mdot
.63466 .31136 Mdot
.77492 .54878 Mdot
.32598 .53054 Mdot
.57007 .33529 Mdot
.65478 .56542 Mdot
.35111 .51609 Mdot
.38146 .62042 Mdot
.47332 .32232 Mdot
.35167 .55516 Mdot
.51467 .66046 Mdot
.68957 .65774 Mdot
.35558 .56338 Mdot
.61667 .25245 Mdot
.47347 .63356 Mdot
.56582 .58952 Mdot
.56466 .30146 Mdot
.8579 .36841 Mdot
.50033 .64349 Mdot
.60485 .57929 Mdot
.6326 .56754 Mdot
.64808 .56944 Mdot
.35241 .51478 Mdot
.61215 .5556 Mdot
.34025 .51184 Mdot
.34559 .23052 Mdot
.44257 .48356 Mdot
.67007 .42066 Mdot
.53559 .72762 Mdot
.31775 .5552 Mdot
.8259 .44519 Mdot
.8611 .53887 Mdot
.4607 .41276 Mdot
.4693 .62049 Mdot
.67147 .41472 Mdot
.17637 .54302 Mdot
.64587 .41217 Mdot
.63617 .48664 Mdot
.74898 .31416 Mdot
.46781 .37813 Mdot
.3062 .45603 Mdot
.67028 .44568 Mdot
.31629 .541 Mdot
.4894 .37441 Mdot
.42809 .6393 Mdot
.64525 .41779 Mdot
.63455 .43614 Mdot
.4854 .3873 Mdot
.32319 .57335 Mdot
.66257 .56731 Mdot
.46531 .66858 Mdot
.62668 .44172 Mdot
.27617 .57727 Mdot
.50488 .33645 Mdot
.50124 .3401 Mdot
.5576 .55909 Mdot
.68677 .39337 Mdot
.49824 .65014 Mdot
.42444 .22253 Mdot
.67202 .5569 Mdot
.66023 .51648 Mdot
.79203 .57892 Mdot
.54719 .72761 Mdot
.61993 .57475 Mdot
.61618 .57765 Mdot
.48589 .39567 Mdot
.68736 .38741 Mdot
.71405 .28017 Mdot
.45991 .70187 Mdot
.63953 .53918 Mdot
.64927 .5729 Mdot
.2824 .56167 Mdot
.76619 .644 Mdot
.4251 .33463 Mdot
.51959 .63038 Mdot
.64837 .59953 Mdot
.24347 .53665 Mdot
.64948 .42468 Mdot
.80897 .41278 Mdot
.43996 .33563 Mdot
.45144 .34834 Mdot
.48816 .65464 Mdot
.52003 .65385 Mdot
.47226 .59302 Mdot
.79415 .60692 Mdot
.46548 .20292 Mdot
.44263 .73546 Mdot
.27072 .50388 Mdot
.29291 .573 Mdot
.3028 .55015 Mdot
.51359 .73649 Mdot
.48884 .61373 Mdot
.43805 .36426 Mdot
.30634 .52828 Mdot
.6753 .68814 Mdot
.36887 .58991 Mdot
.65029 .32862 Mdot
.75 .41939 Mdot
.48155 .33407 Mdot
.32108 .52408 Mdot
.35849 .53231 Mdot
.29813 .54325 Mdot
.56598 .74865 Mdot
.47101 .39205 Mdot
.46369 .34036 Mdot
.43014 .36747 Mdot
.41581 .29109 Mdot
.44356 .39885 Mdot
.48503 .7186 Mdot
.53833 .53698 Mdot
.21874 .47912 Mdot
.52855 .35778 Mdot
.52927 .64987 Mdot
.4904 .33073 Mdot
.63089 .41848 Mdot
.50521 .37551 Mdot
.65762 .33047 Mdot
.47581 .65353 Mdot
.27152 .52988 Mdot
.4386 .7274 Mdot
.45319 .33222 Mdot
.6425 .4493 Mdot
.39899 .48447 Mdot
.36596 .77921 Mdot
.6901 .41493 Mdot
.35014 .53072 Mdot
.6203 .56434 Mdot
.46111 .63747 Mdot
.65288 .55858 Mdot
.52303 .33417 Mdot
.53196 .71353 Mdot
.32842 .70864 Mdot
.54516 .49332 Mdot
.44108 .40527 Mdot
.39807 .35916 Mdot
.3463 .53273 Mdot
.60921 .56289 Mdot
.37842 .56668 Mdot
.44113 .36849 Mdot
.65712 .43528 Mdot
.64284 .42079 Mdot
.42293 .61324 Mdot
.23892 .66753 Mdot
.432 .69948 Mdot
.49101 .65502 Mdot
.6514 .59039 Mdot
.66864 .40054 Mdot
.30236 .61092 Mdot
.45463 .61977 Mdot
.4661 .63808 Mdot
.47869 .63343 Mdot
.5159 .37338 Mdot
.62136 .59412 Mdot
.2181 .46671 Mdot
.64966 .60803 Mdot
.47274 .33843 Mdot
.66456 .59024 Mdot
.61975 .58841 Mdot
.63766 .4243 Mdot
.49534 .62235 Mdot
.67074 .59464 Mdot
.48833 .41358 Mdot
.34423 .56762 Mdot
.48927 .49046 Mdot
.6663 .30543 Mdot
.19052 .5015 Mdot
.20469 .50842 Mdot
.34358 .57542 Mdot
.24291 .70927 Mdot
.51272 .61981 Mdot
.44693 .26053 Mdot
.6126 .73668 Mdot
.50626 .40805 Mdot
.83671 .44647 Mdot
.68193 .56033 Mdot
.60469 .57257 Mdot
.49154 .40284 Mdot
.71222 .56461 Mdot
.46246 .37991 Mdot
.67141 .58861 Mdot
.70657 .44471 Mdot
.47931 .44354 Mdot
.63772 .54982 Mdot
.53324 .37316 Mdot
.48508 .35548 Mdot
.32519 .52943 Mdot
.64867 .54436 Mdot
.45437 .42132 Mdot
.1474 .4862 Mdot
.51901 .64517 Mdot
.56424 .73375 Mdot
.59903 .22984 Mdot
.50279 .63924 Mdot
.34332 .56061 Mdot
.41137 .34505 Mdot
.6435 .4082 Mdot
.31317 .5536 Mdot
.70581 .32709 Mdot
.66741 .44647 Mdot
.83331 .4544 Mdot
.34683 .52598 Mdot
.63381 .53923 Mdot
.63693 .43154 Mdot
.52612 .40209 Mdot
.59934 .5536 Mdot
.42369 .50351 Mdot
.61771 .57111 Mdot
.46275 .39858 Mdot
.52182 .7442 Mdot
.51278 .6287 Mdot
.46973 .35279 Mdot
.60277 .55707 Mdot
.53828 .7432 Mdot
.51478 .37128 Mdot
.49615 .38722 Mdot
.72721 .70556 Mdot
.80662 .4518 Mdot
.65614 .40671 Mdot
.31553 .51065 Mdot
.48088 .41457 Mdot
.64156 .44256 Mdot
.7297 .52848 Mdot
.50621 .34137 Mdot
.28999 .55817 Mdot
.43585 .2942 Mdot
.62274 .54439 Mdot
.50754 .63625 Mdot
.53852 .50296 Mdot
.63918 .44231 Mdot
.56795 .14421 Mdot
.64439 .60543 Mdot
.4691 .42713 Mdot
.43955 .40642 Mdot
.66433 .72493 Mdot
.35536 .52355 Mdot
.47482 .20648 Mdot
.44719 .38728 Mdot
.40596 .30392 Mdot
.46529 .36263 Mdot
.63728 .49404 Mdot
.3373 .53482 Mdot
.45988 .39295 Mdot
.30412 .63436 Mdot
.49524 .42677 Mdot
.63964 .44506 Mdot
.26442 .30585 Mdot
.51527 .34904 Mdot
.744 .7725 Mdot
.7849 .50013 Mdot
.64187 .55024 Mdot
.51039 .74229 Mdot
.27613 .23371 Mdot
.45205 .72501 Mdot
.33581 .511 Mdot
.32386 .73023 Mdot
.65951 .56289 Mdot
.48158 .76074 Mdot
.23799 .70971 Mdot
.48721 .35648 Mdot
.48212 .32851 Mdot
.63483 .48581 Mdot
.66805 .60602 Mdot
.59361 .54982 Mdot
.52359 .33982 Mdot
.47173 .29607 Mdot
.66881 .56482 Mdot
.47571 .41811 Mdot
.53849 .36401 Mdot
.45976 .65835 Mdot
.34085 .57505 Mdot
.49895 .66827 Mdot
.4832 .62268 Mdot
.32846 .28968 Mdot
.78326 .61502 Mdot
.51746 .64567 Mdot
.51669 .62421 Mdot
.64116 .31317 Mdot
.60911 .3649 Mdot
.68152 .42479 Mdot
.20911 .61912 Mdot
.64495 .56994 Mdot
.47221 .38911 Mdot
.35284 .57162 Mdot
.40952 .25453 Mdot
.76664 .50519 Mdot
.725 .28698 Mdot
.43918 .36738 Mdot
.65436 .56967 Mdot
.56552 .75025 Mdot
.53231 .33269 Mdot
.63428 .5169 Mdot
.44916 .34609 Mdot
.59668 .57347 Mdot
.3116 .41402 Mdot
.26201 .62044 Mdot
.59596 .54255 Mdot
.33036 .59344 Mdot
.4523 .356 Mdot
.35264 .52961 Mdot
.49574 .66566 Mdot
.63404 .41724 Mdot
.65754 .40854 Mdot
.49015 .38217 Mdot
.39099 .36151 Mdot
.74599 .58626 Mdot
.48161 .35061 Mdot
.5034 .36742 Mdot
.56792 .74949 Mdot
.50141 .36791 Mdot
.43511 .39908 Mdot
.4292 .38578 Mdot
.4549 .43134 Mdot
.5231 .6452 Mdot
.28049 .63555 Mdot
.50846 .31603 Mdot
.53752 .34765 Mdot
.48484 .68372 Mdot
.36037 .76426 Mdot
.4822 .6202 Mdot
.29691 .75739 Mdot
.49316 .6735 Mdot
.66495 .41612 Mdot
.58376 .76599 Mdot
.39394 .36567 Mdot
.30585 .5694 Mdot
.46073 .61772 Mdot
.65334 .44092 Mdot
.49842 .6566 Mdot
.67162 .58212 Mdot
.61303 .80194 Mdot
.29463 .59477 Mdot
.51295 .2134 Mdot
.42005 .61993 Mdot
.59892 .65273 Mdot
.66503 .60078 Mdot
.33589 .53075 Mdot
.35114 .42185 Mdot
.4292 .39231 Mdot
.64211 .44186 Mdot
.48382 .3916 Mdot
.51933 .63334 Mdot
.65169 .56588 Mdot
.2661 .29946 Mdot
.64602 .40507 Mdot
.75747 .68785 Mdot
.64051 .57706 Mdot
.42632 .36861 Mdot
.52059 .63228 Mdot
.78872 .66862 Mdot
.50522 .66389 Mdot
.41114 .45817 Mdot
.32078 .58772 Mdot
.3575 .2504 Mdot
.32277 .55797 Mdot
.67403 .54605 Mdot
.62418 .82391 Mdot
.20365 .57451 Mdot
.32923 .57287 Mdot
.62525 .64313 Mdot
.49248 .33636 Mdot
.49856 .33763 Mdot
.25342 .592 Mdot
.30716 .51796 Mdot
.4562 .41122 Mdot
.57368 .74205 Mdot
.33858 .67027 Mdot
.79284 .4775 Mdot
.61334 .56746 Mdot
.45765 .38228 Mdot
.48486 .68596 Mdot
.46623 .66368 Mdot
.64163 .60656 Mdot
.4791 .61962 Mdot
.46467 .34163 Mdot
.31951 .55584 Mdot
.59061 .56694 Mdot
.65917 .41946 Mdot
.16417 .44239 Mdot
.66776 .39732 Mdot
.62075 .57557 Mdot
.47962 .44064 Mdot
.66086 .56168 Mdot
.33614 .16937 Mdot
.45961 .34362 Mdot
.35688 .54876 Mdot
.50246 .39015 Mdot
.45593 .35653 Mdot
.48438 .32878 Mdot
.67177 .57317 Mdot
.50723 .19971 Mdot
.48203 .41672 Mdot
.48777 .63941 Mdot
.22858 .50216 Mdot
.4857 .32786 Mdot
.69357 .45751 Mdot
.62245 .3424 Mdot
.66705 .64579 Mdot
.34654 .57942 Mdot
.62074 .5542 Mdot
.34316 .56511 Mdot
.34787 .59645 Mdot
.34371 .56024 Mdot
.24988 .48222 Mdot
.34254 .42039 Mdot
.54454 .19531 Mdot
.25197 .3481 Mdot
.51908 .28761 Mdot
.3118 .51365 Mdot
.60475 .44442 Mdot
.30106 .54588 Mdot
.35534 .52801 Mdot
.39861 .89763 Mdot
.30546 .56517 Mdot
.45178 .37913 Mdot
.45789 .32369 Mdot
.3833 .72425 Mdot
.61125 .28828 Mdot
.49722 .37287 Mdot
.49049 .40874 Mdot
.63548 .41833 Mdot
.38513 .36954 Mdot
.53259 .71426 Mdot
.82731 .48842 Mdot
.42648 .75398 Mdot
.4856 .38949 Mdot
.48597 .41333 Mdot
.5023 .30381 Mdot
.7776 .7102 Mdot
.34942 .28534 Mdot
.29701 .5247 Mdot
.41783 .32665 Mdot
.17869 .50675 Mdot
.45111 .33667 Mdot
.51879 .37157 Mdot
.48424 .33414 Mdot
.65912 .56309 Mdot
.2919 .56788 Mdot
.43068 .31569 Mdot
.782 .56692 Mdot
.45892 .3315 Mdot
.54513 .72899 Mdot
.36302 .19409 Mdot
.45474 .38699 Mdot
.30928 .57754 Mdot
.50693 .35359 Mdot
.34461 .52184 Mdot
.3148 .53522 Mdot
.47939 .43724 Mdot
.25849 .50548 Mdot
.30139 .57639 Mdot
.47374 .3382 Mdot
.66569 .5725 Mdot
.20102 .62201 Mdot
.46041 .39908 Mdot
.64527 .40079 Mdot
.4456 .38455 Mdot
.63844 .44801 Mdot
.49849 .36131 Mdot
.6372 .60546 Mdot
.37215 .31298 Mdot
.64188 .56001 Mdot
.40043 .20003 Mdot
.61884 .59449 Mdot
.73454 .69999 Mdot
.28989 .53984 Mdot
.5273 .74083 Mdot
.6562 .20986 Mdot
.55725 .72811 Mdot
.50145 .5694 Mdot
.4888 .55347 Mdot
.46762 .64054 Mdot
.36352 .53251 Mdot
.50523 .24453 Mdot
.67539 .69874 Mdot
.64809 .72872 Mdot
.62738 .59389 Mdot
.6522 .1927 Mdot
.75098 .30303 Mdot
.50398 .40121 Mdot
.28507 .46552 Mdot
.25285 .40099 Mdot
.51166 .34617 Mdot
.40979 .34663 Mdot
.6532 .61822 Mdot
.44474 .41236 Mdot
.35264 .62581 Mdot
.62628 .57942 Mdot
.6514 .44168 Mdot
.35453 .53736 Mdot
.62802 .43019 Mdot
.66595 .70858 Mdot
.48387 .55604 Mdot
.66679 .59414 Mdot
.47849 .43142 Mdot
.49936 .39674 Mdot
.33051 .52463 Mdot
.37862 .50877 Mdot
.3097 .564 Mdot
.66794 .40591 Mdot
.62953 .57763 Mdot
.37756 .27231 Mdot
.48037 .41111 Mdot
.32156 .54766 Mdot
.46019 .58566 Mdot
.47526 .41453 Mdot
.50515 .6516 Mdot
.47411 .33225 Mdot
.33774 .57216 Mdot
.50118 .36765 Mdot
.31938 .55809 Mdot
.6221 .56117 Mdot
.44354 .33831 Mdot
.48907 .40204 Mdot
.77227 .6841 Mdot
.66594 .42649 Mdot
.3003 .52423 Mdot
.7159 .56511 Mdot
.42625 .39298 Mdot
.59108 .67852 Mdot
.44902 .35775 Mdot
.38938 .56174 Mdot
.48148 .42735 Mdot
.55554 .74752 Mdot
.42687 .33604 Mdot
.46042 .39827 Mdot
.43005 .58293 Mdot
.24866 .43136 Mdot
.3756 .49953 Mdot
.52512 .64049 Mdot
.29692 .56022 Mdot
.76612 .43932 Mdot
.65852 .54321 Mdot
.60975 .5564 Mdot
.55898 .253 Mdot
.43582 .42541 Mdot
.4683 .37994 Mdot
.46674 .67768 Mdot
.66314 .445 Mdot
.32534 .54083 Mdot
.64718 .44074 Mdot
.79327 .56915 Mdot
.67534 .42326 Mdot
.69287 .58467 Mdot
.75387 .58238 Mdot
.35796 .30127 Mdot
.63573 .41877 Mdot
.32148 .5736 Mdot
.74277 .42197 Mdot
.5126 .40547 Mdot
.61507 .38631 Mdot
.65623 .43398 Mdot
.63693 .17621 Mdot
.43766 .40124 Mdot
.51255 .57077 Mdot
.5142 .64416 Mdot
.63909 .4313 Mdot
.4704 .64692 Mdot
.49637 .37648 Mdot
.58361 .66445 Mdot
.3225 .51237 Mdot
.51814 .67502 Mdot
.50776 .33338 Mdot
.67201 .41976 Mdot
.64735 .59851 Mdot
.48343 .59961 Mdot
.52694 .65844 Mdot
.32584 .7459 Mdot
.3095 .26367 Mdot
.63043 .5763 Mdot
.76033 .37065 Mdot
.48262 .67431 Mdot
.51895 .36089 Mdot
.38767 .33489 Mdot
.45349 .34237 Mdot
.46144 .71781 Mdot
.6165 .55619 Mdot
.3369 .68907 Mdot
.50256 .39345 Mdot
.43312 .37357 Mdot
.3655 .49594 Mdot
.63586 .56442 Mdot
.33788 .54991 Mdot
.29812 .55815 Mdot
.62335 .56154 Mdot
.33034 .56022 Mdot
.66508 .44916 Mdot
.351 .67038 Mdot
.49276 .67881 Mdot
.48425 .64103 Mdot
.64952 .57181 Mdot
.65295 .55259 Mdot
.65522 .55704 Mdot
.47353 .33222 Mdot
.33134 .53746 Mdot
.49161 .34626 Mdot
.4846 .32935 Mdot
.31611 .48519 Mdot
.34069 .57878 Mdot
.4961 .34212 Mdot
.66086 .52987 Mdot
.62652 .38292 Mdot
.66671 .57551 Mdot
.5158 .64262 Mdot
.48749 .77923 Mdot
.53583 .63878 Mdot
.45789 .37897 Mdot
.7495 .64058 Mdot
.31922 .57051 Mdot
.6419 .41442 Mdot
.67526 .44853 Mdot
.6488 .40888 Mdot
.49377 .69623 Mdot
.29975 .53032 Mdot
.82789 .48537 Mdot
.4606 .38254 Mdot
.55759 .56197 Mdot
.47531 .23299 Mdot
.7489 .60534 Mdot
.51639 .64111 Mdot
.48224 .41354 Mdot
.53294 .49982 Mdot
.35463 .39734 Mdot
.45312 .34754 Mdot
.52099 .40135 Mdot
.58862 .72786 Mdot
.46303 .28681 Mdot
.3118 .58449 Mdot
.80669 .59573 Mdot
.44978 .32083 Mdot
.24827 .56561 Mdot
.18146 .36478 Mdot
.45754 .37006 Mdot
.43776 .37655 Mdot
.46986 .40548 Mdot
.50756 .37898 Mdot
.31246 .58072 Mdot
.56787 .27749 Mdot
.50793 .61756 Mdot
.56683 .53377 Mdot
.50031 .67902 Mdot
.59718 .56654 Mdot
.30178 .64531 Mdot
.36599 .53849 Mdot
.63933 .41687 Mdot
.23663 .61421 Mdot
.82297 .54798 Mdot
.68406 .5776 Mdot
.33031 .33661 Mdot
.66124 .4295 Mdot
.52152 .36798 Mdot
.6457 .45581 Mdot
.61867 .5924 Mdot
.48703 .6329 Mdot
.42466 .41981 Mdot
.30501 .55652 Mdot
.35787 .56042 Mdot
.45859 .41195 Mdot
.1891 .53483 Mdot
.50719 .64726 Mdot
.46001 .6103 Mdot
.51488 .36091 Mdot
.52908 .386 Mdot
.34094 .55102 Mdot
.65202 .58336 Mdot
.7282 .36737 Mdot
.66719 .43737 Mdot
.42589 .40216 Mdot
.50813 .37544 Mdot
.79672 .60235 Mdot
.49814 .62754 Mdot
.6887 .58181 Mdot
.51445 .37868 Mdot
.47815 .7388 Mdot
.51417 .3782 Mdot
.51325 .3065 Mdot
.6637 .57244 Mdot
.48087 .30425 Mdot
.49045 .41474 Mdot
.45826 .45868 Mdot
.4729 .66266 Mdot
.35457 .5499 Mdot
.37159 .56226 Mdot
.59356 .47524 Mdot
.50381 .65396 Mdot
.50129 .3468 Mdot
.50143 .63093 Mdot
.49624 .33401 Mdot
.45613 .41305 Mdot
.51772 .65074 Mdot
.33738 .55056 Mdot
.34362 .737 Mdot
.28844 .64031 Mdot
.50736 .38177 Mdot
.44146 .32621 Mdot
.58533 .27743 Mdot
.59075 .20099 Mdot
.44289 .363 Mdot
.3473 .56788 Mdot
.48638 .40828 Mdot
.47269 .65388 Mdot
.67614 .43273 Mdot
.34178 .56937 Mdot
.64349 .58581 Mdot
.68092 .58945 Mdot
.43886 .72598 Mdot
.61626 .58306 Mdot
.51692 .39558 Mdot
.33854 .5997 Mdot
.36995 .51806 Mdot
.16985 .40038 Mdot
.62621 .56266 Mdot
.66917 .45011 Mdot
.49515 .38484 Mdot
.73057 .68542 Mdot
.4622 .67155 Mdot
.78281 .74088 Mdot
.83216 .46479 Mdot
.66311 .39422 Mdot
.70045 .25597 Mdot
.5944 .56137 Mdot
.45844 .4178 Mdot
.63349 .41681 Mdot
.68214 .57384 Mdot
.5103 .40095 Mdot
.42149 .42074 Mdot
.48344 .203 Mdot
.58016 .4845 Mdot
.50319 .63038 Mdot
.6348 .5456 Mdot
.66942 .46134 Mdot
.68671 .59295 Mdot
.36075 .55786 Mdot
.46255 .39564 Mdot
.40254 .41291 Mdot
.64821 .58581 Mdot
.67217 .60402 Mdot
.48104 .33565 Mdot
.36241 .52947 Mdot
.68023 .61003 Mdot
.48622 .38273 Mdot
.49676 .2761 Mdot
.32402 .593 Mdot
.62847 .58339 Mdot
.43044 .37979 Mdot
.65415 .36786 Mdot
.64462 .57834 Mdot
.66685 .57728 Mdot
.45853 .41272 Mdot
.66169 .45065 Mdot
.4311 .34279 Mdot
.49896 .67269 Mdot
.46257 .18886 Mdot
.47256 .64771 Mdot
.75206 .45068 Mdot
.5029 .43017 Mdot
.5652 .64142 Mdot
.36329 .5573 Mdot
.68173 .45538 Mdot
.51389 .79188 Mdot
.52889 .34817 Mdot
.23616 .67945 Mdot
.51149 .50368 Mdot
.16904 .50996 Mdot
.49819 .81996 Mdot
.65254 .43166 Mdot
.49641 .66032 Mdot
.43824 .37634 Mdot
.46046 .62852 Mdot
.63706 .4076 Mdot
.38227 .22354 Mdot
.43062 .38623 Mdot
.33938 .5347 Mdot
.47182 .33522 Mdot
.35011 .52971 Mdot
.46733 .41413 Mdot
.52844 .32985 Mdot
.56891 .75763 Mdot
.69441 .32285 Mdot
.50668 .40873 Mdot
.6294 .80072 Mdot
.77 .53353 Mdot
.65964 .43839 Mdot
.48663 .34671 Mdot
.67556 .54948 Mdot
.46442 .6572 Mdot
.37855 .59577 Mdot
.6614 .56402 Mdot
.49496 .61852 Mdot
.34043 .55681 Mdot
.61614 .56395 Mdot
.67308 .59964 Mdot
.45232 .31127 Mdot
.63392 .44143 Mdot
.48313 .62931 Mdot
.45683 .39488 Mdot
.43405 .39292 Mdot
.76095 .38755 Mdot
.75769 .49814 Mdot
.37827 .52662 Mdot
.82645 .61653 Mdot
.37548 .54275 Mdot
.66882 .42741 Mdot
.66459 .56783 Mdot
.44619 .36192 Mdot
.47193 .35273 Mdot
.53098 .74337 Mdot
.32061 .51166 Mdot
.56601 .4913 Mdot
.31421 .3144 Mdot
.67435 .61151 Mdot
.61597 .32323 Mdot
.35887 .54746 Mdot
.6159 .32114 Mdot
.66612 .46184 Mdot
.22708 .61989 Mdot
.68525 .32816 Mdot
.51306 .64047 Mdot
.61121 .3213 Mdot
.31386 .54412 Mdot
.50299 .39959 Mdot
.64471 .54112 Mdot
.62047 .58832 Mdot
.3493 .54624 Mdot
.6165 .60524 Mdot
.63909 .42593 Mdot
.43666 .38341 Mdot
.81866 .47745 Mdot
.39742 .69333 Mdot
.65544 .58872 Mdot
.5404 .34759 Mdot
.47744 .63547 Mdot
.45038 .4116 Mdot
.6481 .40055 Mdot
.49748 .64003 Mdot
.78029 .48231 Mdot
.33799 .67913 Mdot
.4924 .37908 Mdot
.75103 .67367 Mdot
.50261 .64924 Mdot
.66836 .24027 Mdot
.4805 .38718 Mdot
.48156 .67343 Mdot
.45217 .29508 Mdot
.70432 .63797 Mdot
.53985 .49198 Mdot
.23522 .70781 Mdot
.55175 .49768 Mdot
.61066 .54342 Mdot
.67204 .66491 Mdot
.64179 .70826 Mdot
.45965 .63256 Mdot
.67589 .6017 Mdot
.69613 .40072 Mdot
.46996 .64656 Mdot
.47986 .32688 Mdot
.45287 .36209 Mdot
.35158 .27707 Mdot
.50482 .51191 Mdot
.69494 .55928 Mdot
.41103 .65848 Mdot
.42562 .38975 Mdot
.46624 .31407 Mdot
.47546 .36038 Mdot
.28089 .55153 Mdot
.49404 .63041 Mdot
.70579 .7465 Mdot
.50434 .6566 Mdot
.80361 .41093 Mdot
.64606 .56888 Mdot
.62264 .55037 Mdot
.45521 .38339 Mdot
.56903 .60054 Mdot
.58344 .33158 Mdot
.46698 .34111 Mdot
.57531 .5568 Mdot
.24741 .32376 Mdot
.49668 .3274 Mdot
.32861 .58826 Mdot
.53284 .41961 Mdot
.27992 .5697 Mdot
.4903 .67956 Mdot
.65194 .42363 Mdot
.68858 .44338 Mdot
.4868 .63026 Mdot
.46965 .3786 Mdot
.55745 .66287 Mdot
.46044 .35519 Mdot
.50955 .39225 Mdot
.80348 .39412 Mdot
.66424 .39608 Mdot
.63719 .55315 Mdot
.65273 .40589 Mdot
.3546 .52489 Mdot
.58519 .89528 Mdot
.65967 .44662 Mdot
.57978 .33414 Mdot
.40968 .20688 Mdot
.60874 .31768 Mdot
.3614 .55308 Mdot
.6218 .41331 Mdot
.50831 .64047 Mdot
.17259 .58677 Mdot
.56172 .18582 Mdot
.50157 .6048 Mdot
.48327 .37795 Mdot
.36412 .5267 Mdot
.32972 .57645 Mdot
.51636 .67566 Mdot
.31496 .53724 Mdot
.42509 .3124 Mdot
.50679 .38957 Mdot
.46407 .62566 Mdot
.39566 .71944 Mdot
.52726 .65803 Mdot
.34882 .64878 Mdot
.48303 .3426 Mdot
.35687 .5556 Mdot
.52713 .42408 Mdot
.28422 .52613 Mdot
.69009 .57871 Mdot
.51806 .35316 Mdot
.63841 .42382 Mdot
.55618 .63866 Mdot
.6332 .57735 Mdot
.74488 .64358 Mdot
.33381 .52448 Mdot
.52013 .59178 Mdot
.32272 .53012 Mdot
.32771 .50351 Mdot
.48061 .623 Mdot
.3181 .51761 Mdot
.43705 .37815 Mdot
.65358 .53428 Mdot
.33861 .51806 Mdot
.48132 .65394 Mdot
.6532 .41762 Mdot
.33121 .55733 Mdot
.71368 .56788 Mdot
.49317 .39304 Mdot
.67668 .57637 Mdot
.5957 .76226 Mdot
.35448 .51069 Mdot
.62647 .40214 Mdot
.60869 .56218 Mdot
.63104 .4318 Mdot
.21769 .34752 Mdot
.48608 .61306 Mdot
.73418 .3029 Mdot
.65667 .37049 Mdot
.30899 .56844 Mdot
.58488 .76179 Mdot
.44778 .36484 Mdot
.49478 .39087 Mdot
.62877 .43992 Mdot
.32909 .57645 Mdot
.19708 .58418 Mdot
.3701 .48508 Mdot
.35025 .68259 Mdot
.47448 .61295 Mdot
.70362 .73525 Mdot
.33651 .63778 Mdot
.30412 .24041 Mdot
.49558 .31817 Mdot
.59334 .55746 Mdot
.46529 .37244 Mdot
.4984 .78875 Mdot
.67092 .41372 Mdot
.66726 .48305 Mdot
.49355 .43047 Mdot
.62321 .55637 Mdot
.47788 .40072 Mdot
.4286 .55721 Mdot
.54336 .38919 Mdot
.67432 .44269 Mdot
.52704 .72379 Mdot
.30327 .56542 Mdot
.66035 .42259 Mdot
.64766 .60384 Mdot
.59545 .33215 Mdot
.49888 .41347 Mdot
.518 .3278 Mdot
.68292 .60674 Mdot
.33625 .53233 Mdot
.62446 .54198 Mdot
.49109 .67836 Mdot
.6443 .42459 Mdot
.5001 .38312 Mdot
.48112 .42877 Mdot
.59242 .6798 Mdot
.48137 .62801 Mdot
.63589 .61311 Mdot
.50356 .66398 Mdot
.59614 .54866 Mdot
.43432 .33235 Mdot
.62017 .55112 Mdot
.46888 .42239 Mdot
.54001 .78262 Mdot
.79949 .39034 Mdot
.25837 .44178 Mdot
.61401 .55987 Mdot
.64438 .33937 Mdot
.47634 .65696 Mdot
.49359 .67203 Mdot
.39299 .23949 Mdot
.38457 .41924 Mdot
.78192 .43781 Mdot
.343 .76618 Mdot
.49936 .67876 Mdot
.47591 .64206 Mdot
.67853 .57671 Mdot
.32461 .51461 Mdot
.3473 .50323 Mdot
.5963 .57054 Mdot
.59789 .23714 Mdot
.32527 .54099 Mdot
.22363 .64473 Mdot
.77798 .45153 Mdot
.43028 .31856 Mdot
.46479 .59561 Mdot
.64572 .41961 Mdot
.61568 .25468 Mdot
.42728 .56713 Mdot
.43506 .37174 Mdot
.79153 .61167 Mdot
.65385 .57877 Mdot
.54118 .24936 Mdot
.29962 .75833 Mdot
.43128 .39092 Mdot
.47418 .38917 Mdot
.4721 .37062 Mdot
.65347 .39245 Mdot
.37532 .32722 Mdot
.43348 .38732 Mdot
.59629 .23408 Mdot
.42639 .39617 Mdot
.55112 .43756 Mdot
.65626 .40741 Mdot
.56636 .4034 Mdot
.57951 .74011 Mdot
.79992 .5481 Mdot
.47579 .45039 Mdot
.49151 .67726 Mdot
.58443 .51703 Mdot
.47192 .6639 Mdot
.24921 .47479 Mdot
.67938 .3239 Mdot
.35601 .58095 Mdot
.43635 .37248 Mdot
.62131 .57652 Mdot
.33233 .57626 Mdot
.64197 .68208 Mdot
.47092 .92906 Mdot
.48266 .677 Mdot
.37161 .16406 Mdot
.49941 .66984 Mdot
.66638 .60334 Mdot
.3424 .55115 Mdot
.33716 .41859 Mdot
.55613 .55846 Mdot
.32864 .55861 Mdot
.33347 .71754 Mdot
.34806 .49417 Mdot
.62613 .33519 Mdot
.37244 .53387 Mdot
.47961 .65562 Mdot
.51407 .6865 Mdot
.40295 .39304 Mdot
.44873 .37563 Mdot
.47862 .55489 Mdot
.60123 .35417 Mdot
.44766 .36988 Mdot
.6271 .5782 Mdot
.65248 .22203 Mdot
.60622 .47175 Mdot
.30803 .53178 Mdot
.52905 .63525 Mdot
.47442 .39212 Mdot
.51189 .37622 Mdot
.50283 .40783 Mdot
.83424 .6142 Mdot
.21769 .60998 Mdot
.48209 .41649 Mdot
.42171 .38174 Mdot
.61732 .56174 Mdot
.63664 .4609 Mdot
.47955 .79305 Mdot
.4996 .46544 Mdot
.44033 .34907 Mdot
.66269 .41776 Mdot
.67207 .39819 Mdot
.51112 .40048 Mdot
.77915 .56566 Mdot
.58042 .64514 Mdot
.45695 .39542 Mdot
.40162 .44261 Mdot
.66259 .70305 Mdot
.6703 .60449 Mdot
.64622 .58405 Mdot
.30737 .57543 Mdot
.62012 .58373 Mdot
.62043 .59638 Mdot
.34079 .39328 Mdot
.55195 .51152 Mdot
.47088 .69404 Mdot
.66753 .40532 Mdot
.46842 .35206 Mdot
.37437 .51892 Mdot
.4968 .73628 Mdot
.47091 .63486 Mdot
.32355 .56807 Mdot
.46665 .66247 Mdot
.64105 .38861 Mdot
.50864 .21771 Mdot
.62383 .59342 Mdot
.5132 .67324 Mdot
.33799 .67793 Mdot
.66145 .41449 Mdot
.49607 .62105 Mdot
.56388 .66096 Mdot
.4812 .32581 Mdot
.32107 .46825 Mdot
.47209 .34104 Mdot
.1826 .54897 Mdot
.4991 .62263 Mdot
.55164 .74563 Mdot
.4658 .38599 Mdot
.64193 .57635 Mdot
.4935 .29488 Mdot
.44823 .34568 Mdot
.64208 .58979 Mdot
.50353 .40133 Mdot
.63296 .40673 Mdot
.30998 .59378 Mdot
.57219 .517 Mdot
.80113 .32108 Mdot
.63226 .43958 Mdot
.62997 .68076 Mdot
.44137 .36429 Mdot
.27366 .29119 Mdot
.32965 .55649 Mdot
.47296 .42538 Mdot
.55531 .30908 Mdot
.34176 .51411 Mdot
.33501 .5676 Mdot
.50513 .35912 Mdot
.51309 .64603 Mdot
.63417 .58031 Mdot
.65748 .40985 Mdot
.21935 .33317 Mdot
.4844 .36827 Mdot
.4883 .40478 Mdot
.66101 .42724 Mdot
.47379 .64424 Mdot
.51267 .36977 Mdot
.60592 .77158 Mdot
.15205 .49001 Mdot
.46791 .63371 Mdot
.45957 .32744 Mdot
.34503 .47138 Mdot
.27762 .57209 Mdot
.46693 .15869 Mdot
.72317 .393 Mdot
.63172 .55117 Mdot
.45252 .28999 Mdot
.65963 .84024 Mdot
.65156 .42144 Mdot
.8171 .51375 Mdot
.51236 .38947 Mdot
.47372 .41062 Mdot
.31234 .56566 Mdot
.49293 .34322 Mdot
.34513 .51059 Mdot
.76966 .29063 Mdot
.79635 .61851 Mdot
.34162 .52814 Mdot
.30438 .55925 Mdot
.57191 .33266 Mdot
.48299 .79203 Mdot
.3496 .54876 Mdot
.41886 .36563 Mdot
.22105 .54293 Mdot
.4868 .45949 Mdot
.63086 .44419 Mdot
.62509 .74151 Mdot
.27158 .53412 Mdot
.62189 .47057 Mdot
.33371 .74395 Mdot
.26729 .53808 Mdot
.59642 .639 Mdot
.50402 .67184 Mdot
.42725 .37918 Mdot
.61805 .58598 Mdot
.61126 .55556 Mdot
.53835 .39665 Mdot
.46179 .35045 Mdot
.34674 .52267 Mdot
.67145 .40624 Mdot
.45982 .64321 Mdot
.49107 .40798 Mdot
.60964 .47449 Mdot
.66166 .44383 Mdot
.31672 .52476 Mdot
.43717 .23839 Mdot
.67259 .44676 Mdot
.54875 .38644 Mdot
.44785 .39281 Mdot
.48185 .33411 Mdot
.44905 .46204 Mdot
.52072 .64783 Mdot
.57765 .767 Mdot
.44455 .33096 Mdot
.79403 .57001 Mdot
.46333 .48661 Mdot
.47792 .30101 Mdot
.32285 .53646 Mdot
.46248 .67288 Mdot
.68614 .56102 Mdot
.52275 .26108 Mdot
.48977 .37407 Mdot
.21809 .59433 Mdot
.33495 .29258 Mdot
.68659 .56686 Mdot
.31219 .51389 Mdot
.64377 .41269 Mdot
.46581 .34265 Mdot
.23976 .50341 Mdot
.45476 .36734 Mdot
.64893 .37598 Mdot
.66297 .5781 Mdot
.50616 .67017 Mdot
.16479 .50504 Mdot
.61205 .55491 Mdot
.34114 .56605 Mdot
.24983 .74746 Mdot
.36883 .5295 Mdot
.29906 .5446 Mdot
.25012 .51055 Mdot
.51959 .65657 Mdot
.685 .8273 Mdot
.53602 .17269 Mdot
.52615 .39878 Mdot
.47789 .66235 Mdot
.34769 .54066 Mdot
.44865 .40998 Mdot
.36253 .56382 Mdot
.30085 .52625 Mdot
.45096 .31501 Mdot
.45687 .40607 Mdot
.30388 .64215 Mdot
.25442 .71951 Mdot
.64492 .40947 Mdot
.36082 .53411 Mdot
.48781 .26441 Mdot
.44354 .40829 Mdot
.46048 .38337 Mdot
.66702 .68981 Mdot
.66468 .45012 Mdot
.37327 .6129 Mdot
.51295 .38388 Mdot
.78043 .64337 Mdot
.53126 .42173 Mdot
.31271 .5817 Mdot
.47086 .63076 Mdot
.79983 .53993 Mdot
.44802 .69971 Mdot
.32619 .50944 Mdot
.65676 .40036 Mdot
.37336 .55941 Mdot
.58179 .33847 Mdot
.52449 .65699 Mdot
.33768 .5722 Mdot
.53763 .50239 Mdot
.49327 .64601 Mdot
.50261 .6252 Mdot
.22847 .50449 Mdot
.61902 .60269 Mdot
.64261 .39504 Mdot
.48113 .63185 Mdot
.45 .26123 Mdot
.48726 .66016 Mdot
.39965 .25058 Mdot
.44506 .33589 Mdot
.5595 .23586 Mdot
.51071 .57792 Mdot
.39565 .3624 Mdot
.51535 .63082 Mdot
.63982 .40644 Mdot
.50929 .36429 Mdot
.31212 .5409 Mdot
.6514 .44438 Mdot
.49851 .5979 Mdot
.66835 .56561 Mdot
.32195 .52826 Mdot
.49104 .61023 Mdot
.35995 .54066 Mdot
.51137 .24565 Mdot
.44485 .18888 Mdot
.65157 .7507 Mdot
.55517 .55127 Mdot
.50527 .40471 Mdot
.39852 .78378 Mdot
.43207 .322 Mdot
.45734 .34917 Mdot
.62887 .58242 Mdot
.55498 .24969 Mdot
.33837 .55006 Mdot
.16325 .51327 Mdot
.50911 .67388 Mdot
.80695 .60034 Mdot
.38946 .54127 Mdot
.47793 .42569 Mdot
.34111 .51753 Mdot
.37056 .53275 Mdot
.24373 .42953 Mdot
.69659 .57818 Mdot
.41053 .38906 Mdot
.4073 .37545 Mdot
.5008 .31563 Mdot
.504 .6275 Mdot
.7492 .63491 Mdot
.60291 .54817 Mdot
.44197 .17775 Mdot
.66066 .58244 Mdot
.57462 .55253 Mdot
.31587 .5204 Mdot
.65884 .44843 Mdot
.45937 .38559 Mdot
.38794 .51239 Mdot
.32678 .50842 Mdot
.62709 .38543 Mdot
.63784 .43129 Mdot
.69973 .65133 Mdot
.5181 .64962 Mdot
.50456 .41225 Mdot
.43093 .38017 Mdot
.49263 .34967 Mdot
.46404 .33517 Mdot
.48488 .67855 Mdot
.50719 .3465 Mdot
.48865 .68937 Mdot
.43719 .25816 Mdot
.78621 .623 Mdot
.54787 .50987 Mdot
.40015 .56031 Mdot
.30842 .53844 Mdot
.46396 .26598 Mdot
.55033 .38213 Mdot
.78014 .36221 Mdot
.19379 .42691 Mdot
.50364 .33268 Mdot
.68094 .5696 Mdot
.38208 .41155 Mdot
.61248 .58613 Mdot
.44082 .1313 Mdot
.58711 .68625 Mdot
.23666 .6991 Mdot
.43918 .39877 Mdot
.66937 .69144 Mdot
.41552 .29337 Mdot
.41836 .33666 Mdot
.62451 .69428 Mdot
.44867 .71532 Mdot
.36284 .72071 Mdot
.67919 .41216 Mdot
.48953 .39052 Mdot
.36312 .50539 Mdot
.43607 .38028 Mdot
.46201 .37755 Mdot
.51415 .3878 Mdot
.51546 .62468 Mdot
.41753 .40467 Mdot
.4702 .33059 Mdot
.74014 .57397 Mdot
.64044 .31832 Mdot
.63116 .54474 Mdot
.38759 .23733 Mdot
.658 .44575 Mdot
.33963 .52127 Mdot
.27879 .67626 Mdot
.51318 .63993 Mdot
.24625 .4147 Mdot
.47175 .33329 Mdot
.31672 .65843 Mdot
.48138 .60861 Mdot
.64212 .42536 Mdot
.62163 .53916 Mdot
.21251 .66467 Mdot
.62243 .57246 Mdot
.53122 .50323 Mdot
.63764 .57408 Mdot
.53264 .42675 Mdot
.34785 .52313 Mdot
.51587 .38943 Mdot
.48206 .63355 Mdot
.63254 .58812 Mdot
.59853 .2799 Mdot
.47458 .36184 Mdot
.62425 .56054 Mdot
.51606 .38787 Mdot
.51895 .21579 Mdot
.74157 .34632 Mdot
.62818 .60207 Mdot
.47987 .692 Mdot
.48831 .64834 Mdot
.66423 .44894 Mdot
.32811 .52213 Mdot
.31135 .56171 Mdot
.4977 .64234 Mdot
.58953 .1929 Mdot
.44207 .34854 Mdot
.44519 .4075 Mdot
.79693 .5687 Mdot
.44209 .37375 Mdot
.61102 .34036 Mdot
.53552 .49814 Mdot
.31184 .53017 Mdot
.46117 .41702 Mdot
.51049 .37579 Mdot
.49372 .38224 Mdot
.49703 .23621 Mdot
.65248 .5861 Mdot
.43067 .35958 Mdot
.63542 .43099 Mdot
.66266 .54174 Mdot
.44817 .41144 Mdot
.50162 .31494 Mdot
.31255 .56297 Mdot
.83155 .57136 Mdot
.50688 .66529 Mdot
.65871 .60243 Mdot
.6199 .553 Mdot
.62953 .7383 Mdot
.28075 .50928 Mdot
.53982 .49705 Mdot
.41985 .18162 Mdot
.57083 .74812 Mdot
.66278 .43331 Mdot
.56128 .61017 Mdot
.49621 .48406 Mdot
.6793 .58644 Mdot
.4727 .67141 Mdot
.44664 .33214 Mdot
.44099 .34637 Mdot
.83126 .44151 Mdot
.48428 .42518 Mdot
.6455 .41493 Mdot
.49591 .68661 Mdot
.31461 .54498 Mdot
.64131 .42357 Mdot
.49536 .67005 Mdot
.33402 .53223 Mdot
.47388 .32107 Mdot
.46374 .31965 Mdot
.32431 .56701 Mdot
.32541 .5749 Mdot
.45297 .39287 Mdot
.5835 .55438 Mdot
.30315 .56888 Mdot
.35584 .56021 Mdot
.62296 .59335 Mdot
.62413 .58969 Mdot
.45433 .30946 Mdot
.48333 .66587 Mdot
.48396 .33105 Mdot
.61731 .5687 Mdot
.676 .41919 Mdot
.33205 .55124 Mdot
.50836 .38217 Mdot
.49763 .40291 Mdot
.66006 .41401 Mdot
.67553 .40752 Mdot
.63958 .42937 Mdot
.51415 .68186 Mdot
.48866 .35395 Mdot
.34557 .55442 Mdot
.51645 .65845 Mdot
.67186 .39779 Mdot
.65166 .45691 Mdot
.62772 .61483 Mdot
.44514 .35996 Mdot
.70681 .58915 Mdot
.57754 .89237 Mdot
.67781 .36541 Mdot
.68859 .56662 Mdot
.65701 .61501 Mdot
.6098 .30448 Mdot
.57092 .58926 Mdot
.5048 .64404 Mdot
.68885 .38528 Mdot
.68298 .45383 Mdot
.51707 .35254 Mdot
.4443 .32596 Mdot
.40586 .36239 Mdot
.64584 .43484 Mdot
.539 .26744 Mdot
.36473 .5569 Mdot
.28735 .31567 Mdot
.65566 .44521 Mdot
.66989 .60551 Mdot
.61825 .60352 Mdot
.66145 .5818 Mdot
.45151 .32566 Mdot
.2599 .43374 Mdot
.55172 .33044 Mdot
.39997 .79064 Mdot
.507 .62435 Mdot
.36689 .57368 Mdot
.24012 .32602 Mdot
.32964 .56718 Mdot
.60171 .57722 Mdot
.65195 .4407 Mdot
.3399 .57272 Mdot
.46614 .65176 Mdot
.47775 .63957 Mdot
.65661 .58634 Mdot
.65019 .57017 Mdot
.6725 .58387 Mdot
.2992 .53551 Mdot
.31831 .51801 Mdot
.48767 .36787 Mdot
.3219 .55246 Mdot
.84365 .49415 Mdot
.64276 .39113 Mdot
.65395 .61659 Mdot
.49681 .66155 Mdot
.34867 .52827 Mdot
.47503 .35762 Mdot
.59526 .48418 Mdot
.42544 .70955 Mdot
.62904 .42605 Mdot
.75393 .37234 Mdot
.43515 .13579 Mdot
.4979 .41867 Mdot
.50134 .62816 Mdot
.81522 .4735 Mdot
.4742 .36997 Mdot
.66118 .56798 Mdot
.54033 .78938 Mdot
.65841 .54305 Mdot
.48342 .32926 Mdot
.51124 .41159 Mdot
.47784 .62051 Mdot
.39132 .20775 Mdot
.4847 .36252 Mdot
.3854 .61898 Mdot
.5311 .63602 Mdot
.60051 .55392 Mdot
.1498 .50362 Mdot
.66055 .72667 Mdot
.60744 .24737 Mdot
.62744 .59574 Mdot
.45491 .35684 Mdot
.63311 .59621 Mdot
.62971 .42108 Mdot
.64941 .60038 Mdot
.32229 .58944 Mdot
.62496 .54394 Mdot
.48681 .40536 Mdot
.35131 .54744 Mdot
.50319 .6497 Mdot
.81102 .5856 Mdot
.75322 .5438 Mdot
.64292 .57593 Mdot
.64549 .60598 Mdot
.48286 .41801 Mdot
.33864 .62549 Mdot
.53549 .38178 Mdot
.44053 .40279 Mdot
.50705 .67771 Mdot
.33654 .51714 Mdot
.50666 .61826 Mdot
.44211 .41852 Mdot
.59512 .77998 Mdot
.50829 .65961 Mdot
.30811 .65663 Mdot
.66166 .43019 Mdot
.44122 .52875 Mdot
.46995 .35033 Mdot
.47398 .63498 Mdot
.48792 .35272 Mdot
.35953 .56777 Mdot
.48459 .52305 Mdot
.50651 .74306 Mdot
.48409 .6348 Mdot
.19687 .56749 Mdot
.58714 .58933 Mdot
.47731 .44273 Mdot
.47857 .67113 Mdot
.55628 .31201 Mdot
.67143 .601 Mdot
.66626 .43665 Mdot
.67394 .40109 Mdot
.63327 .43685 Mdot
.52671 .35083 Mdot
.48655 .44472 Mdot
.64275 .39822 Mdot
.46364 .64074 Mdot
.6777 .43658 Mdot
.2461 .55878 Mdot
.19487 .58044 Mdot
.66943 .41235 Mdot
.48288 .38488 Mdot
.42548 .44425 Mdot
.63511 .31222 Mdot
.70969 .57629 Mdot
.24032 .69254 Mdot
.38854 .57796 Mdot
.45023 .37435 Mdot
.28031 .5871 Mdot
.35832 .56468 Mdot
.80993 .4785 Mdot
.61285 .35857 Mdot
.78532 .54592 Mdot
.30219 .55693 Mdot
.52535 .74157 Mdot
.31836 .52524 Mdot
.4889 .42144 Mdot
.45074 .40892 Mdot
.34182 .50143 Mdot
.76082 .634 Mdot
.59903 .6671 Mdot
.16626 .44361 Mdot
.35939 .55487 Mdot
.47207 .66115 Mdot
.49747 .68181 Mdot
.50983 .62821 Mdot
.77226 .44068 Mdot
.35599 .51457 Mdot
.49356 .36168 Mdot
.614 .56361 Mdot
.43387 .35822 Mdot
.49233 .63822 Mdot
.16475 .51738 Mdot
.31071 .5551 Mdot
.45958 .3976 Mdot
.58966 .2032 Mdot
.65228 .56332 Mdot
.665 .42014 Mdot
.49532 .2115 Mdot
.78391 .4862 Mdot
.52264 .65489 Mdot
.36228 .51494 Mdot
.54879 .72974 Mdot
.29451 .65365 Mdot
.48274 .31512 Mdot
.4531 .305 Mdot
.26685 .27584 Mdot
.77763 .4766 Mdot
.5209 .3819 Mdot
.66724 .60039 Mdot
.53264 .74409 Mdot
.50299 .3888 Mdot
.36364 .5486 Mdot
.68258 .42139 Mdot
.63882 .43989 Mdot
.41518 .36092 Mdot
.55853 .56335 Mdot
.44147 .50126 Mdot
.50135 .34587 Mdot
.54902 .38649 Mdot
.60312 .57549 Mdot
.57242 .74406 Mdot
.79808 .58176 Mdot
.6599 .4001 Mdot
.51562 .37929 Mdot
.37345 .74428 Mdot
.30921 .51954 Mdot
.65828 .54816 Mdot
.52594 .65293 Mdot
.47479 .23079 Mdot
.60096 .55089 Mdot
.50392 .38893 Mdot
.51235 .37118 Mdot
.4935 .62021 Mdot
.31288 .58186 Mdot
.64771 .43621 Mdot
.61298 .55975 Mdot
.65735 .39916 Mdot
.34613 .51341 Mdot
.31193 .55138 Mdot
.50082 .45672 Mdot
.44149 .43621 Mdot
.64428 .58435 Mdot
.43855 .41323 Mdot
.71074 .55754 Mdot
.38628 .20642 Mdot
.46042 .61779 Mdot
.49801 .41911 Mdot
.28419 .56265 Mdot
.48657 .63209 Mdot
.46608 .40812 Mdot
.23038 .31049 Mdot
.43858 .40701 Mdot
.45366 .70729 Mdot
.63939 .76751 Mdot
.63716 .4134 Mdot
.26603 .3232 Mdot
.26688 .60244 Mdot
.4414 .37852 Mdot
.65924 .55462 Mdot
.51741 .31546 Mdot
.51103 .64504 Mdot
.30971 .52789 Mdot
.47223 .15448 Mdot
.4855 .65708 Mdot
.43721 .39029 Mdot
.64347 .42477 Mdot
.36805 .52331 Mdot
.59198 .52082 Mdot
.78204 .57499 Mdot
.52109 .423 Mdot
.41722 .37409 Mdot
.48925 .33385 Mdot
.53092 .80795 Mdot
.65973 .60157 Mdot
.34943 .53492 Mdot
.50463 .6287 Mdot
.49927 .64042 Mdot
.65589 .58346 Mdot
.36479 .71122 Mdot
.44338 .52705 Mdot
.60608 .86496 Mdot
.64107 .59176 Mdot
.62379 .4046 Mdot
.36683 .62024 Mdot
.65901 .55345 Mdot
.6286 .56044 Mdot
.60354 .57514 Mdot
.46756 .70259 Mdot
.33226 .53491 Mdot
.49891 .40285 Mdot
.34656 .57955 Mdot
.45252 .35429 Mdot
.4342 .4853 Mdot
.48457 .63042 Mdot
.30611 .53179 Mdot
.23866 .30478 Mdot
.38128 .43771 Mdot
.47634 .37799 Mdot
.25618 .30496 Mdot
.50343 .42604 Mdot
.59031 .30948 Mdot
.46156 .43702 Mdot
.64396 .5719 Mdot
.42929 .29285 Mdot
.5312 .34705 Mdot
.82633 .55161 Mdot
.49628 .66305 Mdot
.67853 .59671 Mdot
.52551 .37705 Mdot
.53884 .41343 Mdot
.34189 .49927 Mdot
.34612 .56921 Mdot
.64898 .39704 Mdot
.69414 .31987 Mdot
.5044 .65115 Mdot
.46577 .19348 Mdot
.44802 .38025 Mdot
.70949 .70768 Mdot
.257 .34323 Mdot
.46595 .40704 Mdot
.21709 .55769 Mdot
.25426 .42616 Mdot
.46664 .34492 Mdot
.57278 .36161 Mdot
.47448 .6468 Mdot
.60369 .77886 Mdot
.42066 .3824 Mdot
.66035 .56468 Mdot
.32268 .51737 Mdot
.36683 .54421 Mdot
.63839 .40131 Mdot
.77527 .32965 Mdot
.50533 .61869 Mdot
.30851 .52769 Mdot
.47127 .36258 Mdot
.52108 .65555 Mdot
.61548 .58006 Mdot
.45749 .42712 Mdot
.62411 .35349 Mdot
.32031 .54982 Mdot
.42208 .39242 Mdot
.39097 .65501 Mdot
.64366 .28187 Mdot
.41385 .83205 Mdot
.51191 .63229 Mdot
.67388 .43743 Mdot
.50661 .30745 Mdot
.5028 .19593 Mdot
.50599 .33294 Mdot
.55372 .23589 Mdot
.25567 .53997 Mdot
.67401 .43834 Mdot
.47082 .38581 Mdot
.4984 .37718 Mdot
.52108 .5765 Mdot
.67321 .40675 Mdot
.42948 .3807 Mdot
.38311 .33685 Mdot
.33711 .53332 Mdot
.60891 .54017 Mdot
.32132 .54478 Mdot
.48293 .37867 Mdot
.4264 .42787 Mdot
.31573 .5699 Mdot
.37705 .18716 Mdot
.68854 .42304 Mdot
.51013 .66195 Mdot
.46175 .44358 Mdot
.43832 .33825 Mdot
.62728 .81022 Mdot
.68957 .58023 Mdot
.45104 .78255 Mdot
.7033 .53122 Mdot
.35954 .74818 Mdot
.66499 .72231 Mdot
.23943 .72825 Mdot
.79495 .60676 Mdot
.40785 .37064 Mdot
.41152 .51875 Mdot
.56555 .35557 Mdot
.518 .63237 Mdot
.35786 .31663 Mdot
.44879 .37487 Mdot
.46325 .37483 Mdot
.66799 .55212 Mdot
.3321 .68671 Mdot
.78637 .55712 Mdot
.57013 .53765 Mdot
.65031 .43568 Mdot
.35756 .52991 Mdot
.47128 .41507 Mdot
.57896 .46645 Mdot
.63765 .54501 Mdot
.71863 .69714 Mdot
.46376 .39517 Mdot
.77578 .361 Mdot
.48753 .721 Mdot
.51988 .64809 Mdot
.63033 .5485 Mdot
.78938 .51062 Mdot
.44569 .3552 Mdot
.52407 .6649 Mdot
.48128 .35908 Mdot
.62921 .62914 Mdot
.44744 .41866 Mdot
.67205 .42423 Mdot
.51075 .39672 Mdot
.5776 .53065 Mdot
.33421 .79762 Mdot
.67439 .38292 Mdot
.364 .52878 Mdot
.69223 .59917 Mdot
.65079 .58549 Mdot
.33345 .57414 Mdot
.64869 .58327 Mdot
.25587 .37745 Mdot
.32215 .41312 Mdot
.6548 .43629 Mdot
.54647 .39763 Mdot
.66458 .4069 Mdot
.69056 .57744 Mdot
.44975 .36539 Mdot
.39681 .18233 Mdot
.63726 .58606 Mdot
.65162 .77363 Mdot
.49176 .65972 Mdot
.68585 .58843 Mdot
.42525 .3945 Mdot
.55511 .71964 Mdot
.61807 .54991 Mdot
.51182 .73876 Mdot
.49316 .38035 Mdot
.31072 .54659 Mdot
.50146 .37907 Mdot
.48246 .43901 Mdot
.59238 .55113 Mdot
.46152 .33188 Mdot
.49517 .67006 Mdot
.29673 .55972 Mdot
.20164 .61974 Mdot
.46025 .71603 Mdot
.43347 .37365 Mdot
.4721 .36488 Mdot
.3663 .51333 Mdot
.43008 .35667 Mdot
.48535 .67858 Mdot
.8762 .61254 Mdot
.66207 .4297 Mdot
.64399 .60759 Mdot
.65295 .73511 Mdot
.49618 .32845 Mdot
.50891 .35482 Mdot
.2109 .34132 Mdot
.64551 .74815 Mdot
.48507 .67319 Mdot
.53789 .36462 Mdot
.61041 .56584 Mdot
.64428 .42296 Mdot
.46307 .63637 Mdot
.48271 .33462 Mdot
.46253 .38562 Mdot
.67322 .43748 Mdot
.22173 .5185 Mdot
.79505 .48073 Mdot
.5016 .62079 Mdot
.42276 .29537 Mdot
.67264 .51208 Mdot
.44476 .34693 Mdot
.77524 .43505 Mdot
.34431 .56861 Mdot
.51957 .66519 Mdot
.4384 .79478 Mdot
.51972 .37011 Mdot
.46962 .6342 Mdot
.50388 .65371 Mdot
.53389 .35483 Mdot
.28652 .53016 Mdot
.29353 .54475 Mdot
.35958 .53885 Mdot
.85356 .49215 Mdot
.62514 .27255 Mdot
.67251 .58368 Mdot
.4742 .64523 Mdot
.61664 .59456 Mdot
.62275 .40134 Mdot
.53523 .48626 Mdot
.6338 .60475 Mdot
.33634 .57663 Mdot
.69815 .59558 Mdot
.49764 .38056 Mdot
.50363 .64735 Mdot
.6778 .58693 Mdot
.52687 .37345 Mdot
.30573 .62671 Mdot
.70798 .61818 Mdot
.66155 .45451 Mdot
.68273 .41454 Mdot
.45488 .41099 Mdot
.68525 .5594 Mdot
.45372 .39101 Mdot
.45945 .66141 Mdot
.34986 .62721 Mdot
.51912 .34719 Mdot
.64571 .57683 Mdot
.2755 .58571 Mdot
.78373 .48662 Mdot
.52883 .40137 Mdot
.48165 .38486 Mdot
.45014 .34871 Mdot
.48121 .35811 Mdot
.33603 .70659 Mdot
.46969 .61478 Mdot
.41185 .59111 Mdot
.58262 .76017 Mdot
.32216 .55984 Mdot
.28778 .54082 Mdot
.74818 .42062 Mdot
.60215 .64266 Mdot
.48057 .66396 Mdot
.45686 .34538 Mdot
.48747 .73522 Mdot
.16714 .52712 Mdot
.35028 .19281 Mdot
.61555 .39193 Mdot
.68348 .56545 Mdot
.35557 .51003 Mdot
.63998 .54682 Mdot
.45478 .36014 Mdot
.4997 .3022 Mdot
.23586 .72921 Mdot
.52968 .67523 Mdot
.64998 .43962 Mdot
.45161 .35016 Mdot
.62487 .26618 Mdot
.61655 .56201 Mdot
.61074 .59475 Mdot
.4292 .38749 Mdot
.29776 .57353 Mdot
.53757 .83725 Mdot
.51956 .64286 Mdot
.38841 .58122 Mdot
.44259 .27442 Mdot
.40829 .63205 Mdot
.49298 .63266 Mdot
.77176 .55372 Mdot
.68193 .55926 Mdot
.2196 .42107 Mdot
.31932 .56057 Mdot
.65377 .44319 Mdot
.46488 .30197 Mdot
.30704 .55968 Mdot
.60546 .54485 Mdot
.30722 .53784 Mdot
.51158 .39839 Mdot
.49184 .61264 Mdot
.63553 .55024 Mdot
.49004 .6955 Mdot
.28646 .53244 Mdot
.64869 .40219 Mdot
.47932 .56819 Mdot
.35662 .37599 Mdot
.25229 .42286 Mdot
.4345 .35351 Mdot
.57752 .4634 Mdot
.49268 .35694 Mdot
.33078 .49944 Mdot
.47712 .35807 Mdot
.2858 .59415 Mdot
.65156 .55188 Mdot
.42156 .38204 Mdot
.49747 .33954 Mdot
.35587 .29179 Mdot
.47189 .39582 Mdot
.42598 .41123 Mdot
.46301 .34334 Mdot
.38443 .54254 Mdot
.54559 .37898 Mdot
.32521 .53472 Mdot
.76714 .58513 Mdot
.63153 .56099 Mdot
.68104 .41129 Mdot
.64798 .44898 Mdot
.56809 .23841 Mdot
.70466 .42794 Mdot
.34946 .703 Mdot
.32951 .54354 Mdot
.50237 .66273 Mdot
.47778 .35473 Mdot
.35476 .77579 Mdot
.648 .71334 Mdot
.60844 .57062 Mdot
.46056 .71621 Mdot
.42509 .30571 Mdot
.53652 .81046 Mdot
.42809 .40357 Mdot
.82992 .42502 Mdot
.41023 .41882 Mdot
.45428 .42054 Mdot
.60321 .5847 Mdot
.68712 .4072 Mdot
.42497 .37527 Mdot
.34408 .49931 Mdot
.66918 .43818 Mdot
.39595 .49875 Mdot
.64831 .51548 Mdot
.7628 .56916 Mdot
.33776 .35724 Mdot
.48572 .35395 Mdot
.63877 .55106 Mdot
.3234 .52768 Mdot
.7994 .5875 Mdot
.51505 .66091 Mdot
.55618 .61075 Mdot
.47949 .26533 Mdot
.30804 .25224 Mdot
.66059 .44417 Mdot
.22583 .50869 Mdot
.48745 .40611 Mdot
.75438 .45098 Mdot
.46106 .31546 Mdot
.16955 .52842 Mdot
.6224 .41025 Mdot
.28978 .56032 Mdot
.47348 .66317 Mdot
.35213 .5737 Mdot
.25312 .44117 Mdot
.46845 .59107 Mdot
.50839 .54139 Mdot
.62174 .56882 Mdot
.42602 .58437 Mdot
.3521 .54176 Mdot
.51459 .3703 Mdot
.59426 .87399 Mdot
.35245 .5632 Mdot
.33896 .50833 Mdot
.41387 .20113 Mdot
.38742 .20152 Mdot
.43079 .29794 Mdot
.3075 .56628 Mdot
.62505 .56769 Mdot
.64698 .40587 Mdot
.50293 .37184 Mdot
.49032 .36818 Mdot
.31134 .56351 Mdot
.60714 .59096 Mdot
.39281 .47046 Mdot
.64811 .5698 Mdot
.3375 .53108 Mdot
.64228 .55971 Mdot
.55047 .75539 Mdot
.6824 .5843 Mdot
.43691 .34075 Mdot
.47723 .35697 Mdot
.69973 .53732 Mdot
.31206 .5511 Mdot
.50219 .34929 Mdot
.50071 .40548 Mdot
.34675 .5518 Mdot
.6205 .47696 Mdot
.34104 .4749 Mdot
.43881 .36798 Mdot
.48995 .39407 Mdot
.67593 .43255 Mdot
.55096 .47089 Mdot
.70988 .28811 Mdot
.50911 .36408 Mdot
.64199 .39311 Mdot
.30029 .53484 Mdot
.45453 .39583 Mdot
.24684 .63369 Mdot
.53128 .74502 Mdot
.51885 .37382 Mdot
.67465 .59874 Mdot
.519 .33028 Mdot
.45697 .8364 Mdot
.4383 .4015 Mdot
.34548 .54525 Mdot
.33636 .51315 Mdot
.44504 .20892 Mdot
.34629 .56337 Mdot
.62084 .58845 Mdot
.4928 .64297 Mdot
.18154 .54426 Mdot
.61511 .57918 Mdot
.53032 .38021 Mdot
.53376 .17176 Mdot
.44096 .42399 Mdot
.52574 .36363 Mdot
.57936 .81001 Mdot
.61522 .57633 Mdot
.34637 .51913 Mdot
.55076 .5828 Mdot
.40803 .39488 Mdot
.52285 .65595 Mdot
.51575 .31808 Mdot
.45336 .32951 Mdot
.64626 .76196 Mdot
.47231 .75881 Mdot
.48363 .68339 Mdot
.42477 .32134 Mdot
.50893 .36267 Mdot
.70662 .59809 Mdot
.47285 .35773 Mdot
.66201 .40282 Mdot
.35256 .51501 Mdot
.67332 .56192 Mdot
.65833 .41591 Mdot
.44489 .37703 Mdot
.64454 .43381 Mdot
.67641 .57663 Mdot
.52181 .66644 Mdot
.45001 .35942 Mdot
.63033 .44392 Mdot
.6487 .43449 Mdot
.4948 .35456 Mdot
.31242 .52468 Mdot
.39483 .39163 Mdot
.45653 .39987 Mdot
.50955 .38625 Mdot
.31107 .56087 Mdot
.3144 .19953 Mdot
.43911 .4051 Mdot
.58522 .58201 Mdot
.33228 .50762 Mdot
.431 .62361 Mdot
.67641 .56278 Mdot
.45105 .33004 Mdot
.51449 .67437 Mdot
.4781 .63103 Mdot
.60976 .58621 Mdot
.37215 .53091 Mdot
.70217 .53347 Mdot
.27793 .58825 Mdot
.42588 .42366 Mdot
.47208 .43176 Mdot
.5793 .18237 Mdot
.22757 .69564 Mdot
.3655 .54347 Mdot
.59977 .58564 Mdot
.56786 .53592 Mdot
.47184 .64763 Mdot
.64735 .6143 Mdot
.36579 .51735 Mdot
.36026 .51616 Mdot
.31077 .53476 Mdot
.64529 .44296 Mdot
.68346 .5142 Mdot
.31357 .5834 Mdot
.29685 .57191 Mdot
.49498 .3811 Mdot
.50809 .3588 Mdot
.59261 .38086 Mdot
.6658 .34486 Mdot
.64567 .40103 Mdot
.6594 .57982 Mdot
.84708 .62378 Mdot
.46156 .66418 Mdot
.34984 .29585 Mdot
.51836 .3466 Mdot
.52095 .92598 Mdot
.43107 .40402 Mdot
.47053 .35902 Mdot
.29821 .56039 Mdot
.64377 .45621 Mdot
.66685 .41405 Mdot
.35368 .53698 Mdot
.31839 .50536 Mdot
.66398 .40364 Mdot
.18861 .47721 Mdot
.19191 .58442 Mdot
.51154 .58091 Mdot
.33907 .55414 Mdot
.35415 .39748 Mdot
.52658 .65067 Mdot
.27965 .56817 Mdot
.45731 .64432 Mdot
.62155 .55942 Mdot
.67693 .55352 Mdot
.50445 .62721 Mdot
.49158 .37823 Mdot
.66938 .59188 Mdot
.41797 .40502 Mdot
.20173 .51338 Mdot
.28844 .47659 Mdot
.70016 .67924 Mdot
.43557 .32801 Mdot
.77256 .57255 Mdot
.62148 .64984 Mdot
.4409 .38809 Mdot
.30468 .71324 Mdot
.64802 .43848 Mdot
.29089 .57634 Mdot
.49157 .68084 Mdot
.4335 .842 Mdot
.44874 .34527 Mdot
.34127 .54675 Mdot
.49404 .66581 Mdot
.49844 .22852 Mdot
.38084 .62078 Mdot
.45082 .35199 Mdot
.6293 .85376 Mdot
.38718 .52326 Mdot
.67459 .56393 Mdot
.66002 .22062 Mdot
.349 .57905 Mdot
.61349 .43631 Mdot
.58121 .74853 Mdot
.25498 .29584 Mdot
.34019 .52163 Mdot
.63402 .61511 Mdot
.35716 .53263 Mdot
.65389 .40084 Mdot
.32903 .59345 Mdot
.62006 .55436 Mdot
.47032 .39194 Mdot
.65264 .57818 Mdot
.63909 .40303 Mdot
.76679 .43951 Mdot
.4961 .68121 Mdot
.67859 .59637 Mdot
.48244 .64377 Mdot
.65769 .29242 Mdot
.57728 .77912 Mdot
.50666 .66921 Mdot
.47421 .2107 Mdot
.52187 .37471 Mdot
.32973 .58454 Mdot
.64932 .59323 Mdot
.57689 .74262 Mdot
.52255 .56468 Mdot
.32809 .56277 Mdot
.66631 .57377 Mdot
.50848 .28333 Mdot
.55527 .19324 Mdot
.52034 .43233 Mdot
.67688 .31275 Mdot
.34253 .55529 Mdot
.64624 .61565 Mdot
.79756 .56848 Mdot
.34255 .57535 Mdot
.6419 .59273 Mdot
.46833 .65047 Mdot
.49753 .63667 Mdot
.42739 .37369 Mdot
.46399 .68764 Mdot
.66559 .58383 Mdot
.65696 .65096 Mdot
.30855 .51952 Mdot
.50997 .23533 Mdot
.63256 .44174 Mdot
.63667 .56535 Mdot
.4797 .42696 Mdot
.27608 .54194 Mdot
.54123 .74935 Mdot
.39324 .46107 Mdot
.82485 .64301 Mdot
.65585 .5827 Mdot
.34773 .51125 Mdot
.33616 .54852 Mdot
.52956 .39827 Mdot
.5552 .5548 Mdot
.69594 .52677 Mdot
.56729 .20796 Mdot
.54191 .23345 Mdot
.60132 .54494 Mdot
.60821 .53422 Mdot
.52412 .39722 Mdot
.48241 .34688 Mdot
.47121 .65173 Mdot
.47596 .39098 Mdot
.29387 .56001 Mdot
.42706 .36668 Mdot
.4926 .62945 Mdot
.62537 .57657 Mdot
.45226 .36563 Mdot
.63934 .40805 Mdot
.50721 .68233 Mdot
.47863 .61948 Mdot
.63876 .57068 Mdot
.30453 .55615 Mdot
.66081 .38404 Mdot
.65085 .57029 Mdot
.4856 .35497 Mdot
.55874 .63285 Mdot
.50308 .40754 Mdot
.1968 .45367 Mdot
.3368 .57739 Mdot
.64788 .54914 Mdot
.31744 .51105 Mdot
.4796 .648 Mdot
.58133 .75954 Mdot
.48054 .37187 Mdot
.63815 .59167 Mdot
.69854 .54014 Mdot
.20166 .49416 Mdot
.36215 .50575 Mdot
.55781 .67041 Mdot
.29394 .53243 Mdot
.6236 .5397 Mdot
.40397 .22849 Mdot
.66274 .43964 Mdot
.60811 .56722 Mdot
.21988 .65938 Mdot
.64177 .58163 Mdot
.47233 .39968 Mdot
.46477 .41104 Mdot
.67927 .5682 Mdot
.66098 .45096 Mdot
.79868 .61321 Mdot
.64741 .63636 Mdot
.34319 .51941 Mdot
.29359 .28362 Mdot
.7655 .71722 Mdot
.44844 .65149 Mdot
.4756 .66371 Mdot
.4068 .39087 Mdot
.46015 .42338 Mdot
.45894 .64707 Mdot
.52865 .63483 Mdot
.62627 .41838 Mdot
.60396 .57505 Mdot
.36293 .58563 Mdot
.52687 .66391 Mdot
.47988 .46133 Mdot
.71144 .42411 Mdot
.53479 .39509 Mdot
.45741 .27622 Mdot
.45006 .32076 Mdot
.54375 .22645 Mdot
.49839 .62768 Mdot
.46929 .41687 Mdot
.53762 .39682 Mdot
.51577 .67215 Mdot
.65749 .40185 Mdot
.46148 .74538 Mdot
.64793 .5574 Mdot
.14742 .42213 Mdot
.47067 .42133 Mdot
.46807 .40127 Mdot
.50812 .62524 Mdot
.71567 .53872 Mdot
.30673 .5512 Mdot
.33987 .57782 Mdot
.66306 .60017 Mdot
.48219 .5636 Mdot
.4433 .34105 Mdot
.44358 .39666 Mdot
.65567 .55692 Mdot
.68464 .59014 Mdot
.66871 .66609 Mdot
.49634 .40244 Mdot
.49084 .66515 Mdot
.58279 .51634 Mdot
.49581 .6277 Mdot
.49212 .41931 Mdot
.47357 .40258 Mdot
.43619 .34239 Mdot
.48521 .42479 Mdot
.47656 .61953 Mdot
.47439 .41632 Mdot
.45817 .4545 Mdot
.30385 .54035 Mdot
.46043 .33431 Mdot
.5342 .22589 Mdot
.48505 .38872 Mdot
.65037 .40394 Mdot
.43211 .46296 Mdot
.44794 .34888 Mdot
.44652 .33354 Mdot
.63914 .63503 Mdot
.47058 .38158 Mdot
.45892 .65985 Mdot
.32343 .556 Mdot
.4744 .64406 Mdot
.49545 .62132 Mdot
.63424 .59993 Mdot
.64029 .39953 Mdot
.49044 .32634 Mdot
.63202 .43149 Mdot
.4838 .31849 Mdot
.5202 .37617 Mdot
.61247 .74451 Mdot
.82666 .41197 Mdot
.79465 .47388 Mdot
.48152 .37138 Mdot
.62559 .58488 Mdot
.66879 .5571 Mdot
.40766 .5528 Mdot
.52258 .42854 Mdot
.45981 .64582 Mdot
.47506 .63433 Mdot
.62639 .348 Mdot
.6374 .76505 Mdot
.65241 .40308 Mdot
.56318 .47547 Mdot
.41844 .40759 Mdot
.50479 .39792 Mdot
.45309 .42594 Mdot
.62341 .59848 Mdot
.5711 .55327 Mdot
.60908 .56965 Mdot
.46669 .72095 Mdot
.48906 .62744 Mdot
.45095 .34137 Mdot
.24368 .53617 Mdot
.34547 .57065 Mdot
.32268 .55568 Mdot
.46828 .63038 Mdot
.68019 .60736 Mdot
.61152 .38342 Mdot
.39572 .1597 Mdot
.38426 .55066 Mdot
.65204 .4582 Mdot
.43827 .3835 Mdot
.63064 .57644 Mdot
.36191 .54385 Mdot
.67892 .43387 Mdot
.51656 .37985 Mdot
.68461 .51742 Mdot
.48402 .36978 Mdot
.56632 .35879 Mdot
.31854 .52298 Mdot
.1762 .55153 Mdot
.36949 .53377 Mdot
.5031 .68358 Mdot
.50485 .67526 Mdot
.46891 .40835 Mdot
.60496 .19294 Mdot
.33733 .58275 Mdot
.45083 .69004 Mdot
.62281 .41242 Mdot
.54715 .72224 Mdot
.66599 .40252 Mdot
.66409 .55664 Mdot
.66649 .44093 Mdot
.62914 .54962 Mdot
.66961 .35656 Mdot
.37908 .5278 Mdot
.66138 .42341 Mdot
.62898 .62302 Mdot
.51691 .43274 Mdot
.6789 .40928 Mdot
.40675 .3529 Mdot
.23586 .36638 Mdot
.65905 .56008 Mdot
.64916 .44778 Mdot
.51412 .37071 Mdot
.3205 .77124 Mdot
.49357 .67203 Mdot
.46062 .65446 Mdot
.43105 .42593 Mdot
.60488 .58276 Mdot
.34784 .50219 Mdot
.28707 .66243 Mdot
.49342 .59437 Mdot
.4524 .40832 Mdot
.42524 .37322 Mdot
.28562 .54909 Mdot
.33643 .48586 Mdot
.47443 .4062 Mdot
.41089 .26714 Mdot
.48652 .41023 Mdot
.46674 .64927 Mdot
.36143 .56006 Mdot
.33056 .55195 Mdot
.66957 .57673 Mdot
.30808 .57169 Mdot
.29661 .60308 Mdot
.54518 .67659 Mdot
.40393 .38115 Mdot
.48481 .65489 Mdot
.52603 .70105 Mdot
.46484 .72044 Mdot
.24567 .69489 Mdot
.28504 .54313 Mdot
.43421 .33972 Mdot
.31291 .51584 Mdot
.64202 .42015 Mdot
.31404 .54877 Mdot
.35056 .50793 Mdot
.44911 .39196 Mdot
.45527 .35684 Mdot
.61809 .5752 Mdot
.55834 .55502 Mdot
.30214 .53717 Mdot
.45974 .41255 Mdot
.42973 .41314 Mdot
.4266 .41294 Mdot
.46836 .50392 Mdot
.36491 .54233 Mdot
.34416 .28024 Mdot
.54942 .28563 Mdot
.30173 .53901 Mdot
.48555 .84361 Mdot
.57169 .74975 Mdot
.6916 .58725 Mdot
.47583 .68977 Mdot
.49753 .40149 Mdot
.67734 .56111 Mdot
.45448 .36045 Mdot
.45666 .2761 Mdot
.4623 .38199 Mdot
.67096 .40796 Mdot
.4079 .37018 Mdot
.64596 .54095 Mdot
.65127 .57327 Mdot
.44359 .40534 Mdot
.45416 .3695 Mdot
.77666 .45684 Mdot
.3112 .50917 Mdot
.30711 .54752 Mdot
.72368 .55867 Mdot
.6548 .42624 Mdot
.5217 .66076 Mdot
.47008 .34857 Mdot
.63976 .60086 Mdot
.6533 .57605 Mdot
.35553 .57185 Mdot
.6602 .56663 Mdot
.51651 .63755 Mdot
.47849 .36891 Mdot
.45974 .65243 Mdot
.64121 .4418 Mdot
.36022 .53291 Mdot
.45227 .3443 Mdot
.49507 .38173 Mdot
.33675 .51323 Mdot
.51045 .34097 Mdot
.6763 .43009 Mdot
.64457 .58208 Mdot
.3353 .5237 Mdot
.4938 .64134 Mdot
.64948 .55088 Mdot
.50599 .38102 Mdot
.83824 .62962 Mdot
.47786 .39858 Mdot
.50198 .39195 Mdot
.20601 .6519 Mdot
.40735 .3681 Mdot
.6541 .58953 Mdot
.29118 .56573 Mdot
.41578 .37834 Mdot
.58155 .24783 Mdot
.334 .19698 Mdot
.60967 .57546 Mdot
.43563 .38205 Mdot
.2544 .72728 Mdot
.4368 .39309 Mdot
.47994 .196 Mdot
.72881 .4199 Mdot
.43538 .56683 Mdot
.42894 .43241 Mdot
.51206 .63868 Mdot
.61823 .57683 Mdot
.65612 .55389 Mdot
.32716 .27035 Mdot
.44707 .39424 Mdot
.57553 .38736 Mdot
.51039 .34922 Mdot
.49503 .63338 Mdot
.60265 .34888 Mdot
.65642 .5799 Mdot
.82228 .50977 Mdot
.49246 .36045 Mdot
.36594 .53837 Mdot
.69587 .59834 Mdot
.55991 .74931 Mdot
.50882 .38227 Mdot
.63313 .43044 Mdot
.50402 .68886 Mdot
.41131 .3764 Mdot
.48973 .654 Mdot
.50958 .39414 Mdot
.51119 .45328 Mdot
.71001 .25866 Mdot
.31126 .52863 Mdot
.47177 .65892 Mdot
.57042 .63413 Mdot
.45125 .31453 Mdot
.33725 .52228 Mdot
.32045 .56117 Mdot
.62762 .41907 Mdot
.5259 .53021 Mdot
.38206 .65943 Mdot
.35594 .45585 Mdot
.32283 .26667 Mdot
.69217 .60054 Mdot
.5831 .66586 Mdot
.50581 .36939 Mdot
.70842 .70229 Mdot
.47241 .67903 Mdot
.46827 .39839 Mdot
.23813 .37967 Mdot
.35936 .54289 Mdot
.49021 .39838 Mdot
.66382 .40579 Mdot
.73929 .65442 Mdot
.72964 .67889 Mdot
.48978 .80876 Mdot
.62098 .56608 Mdot
.50037 .30358 Mdot
.50954 .30043 Mdot
.65167 .60651 Mdot
.49032 .32936 Mdot
.6478 .58978 Mdot
.20858 .37799 Mdot
.67534 .43905 Mdot
.36213 .53231 Mdot
.56825 .75021 Mdot
.46271 .32296 Mdot
.4472 .43001 Mdot
.68217 .43231 Mdot
.48312 .34157 Mdot
.77846 .33741 Mdot
.67613 .69256 Mdot
.67479 .59043 Mdot
.31057 .53344 Mdot
.45243 .32512 Mdot
.54344 .50928 Mdot
.45197 .40029 Mdot
.31667 .4395 Mdot
.44662 .33253 Mdot
.38466 .64063 Mdot
.32154 .51782 Mdot
.48655 .65186 Mdot
.49079 .31214 Mdot
.46607 .37445 Mdot
.60407 .48518 Mdot
.42386 .42867 Mdot
.44671 .41265 Mdot
.35425 .50249 Mdot
.3597 .5596 Mdot
.32591 .53547 Mdot
.6201 .54514 Mdot
.64527 .75946 Mdot
.48163 .66027 Mdot
.52314 .33135 Mdot
.52855 .65986 Mdot
.37916 .41185 Mdot
.66582 .45314 Mdot
.32478 .76251 Mdot
.47069 .33373 Mdot
.33155 .53908 Mdot
.39776 .75007 Mdot
.29966 .53431 Mdot
.56311 .49438 Mdot
.5044 .65042 Mdot
.35844 .55014 Mdot
.46939 .36541 Mdot
.56074 .57338 Mdot
.40762 .80468 Mdot
.47869 .63742 Mdot
.49676 .32576 Mdot
.68556 .56712 Mdot
.63596 .74744 Mdot
.83319 .6484 Mdot
.48697 .67397 Mdot
.56902 .63075 Mdot
.44412 .39365 Mdot
.33706 .57511 Mdot
.51351 .6375 Mdot
.50303 .66836 Mdot
.66359 .56801 Mdot
.45474 .35436 Mdot
.45432 .35006 Mdot
.63984 .54093 Mdot
.47897 .63226 Mdot
.48015 .43695 Mdot
.44104 .41636 Mdot
.23682 .73361 Mdot
.50648 .26652 Mdot
.18556 .32566 Mdot
.28651 .60035 Mdot
.23188 .40396 Mdot
.27265 .63942 Mdot
.3502 .51116 Mdot
.44691 .3498 Mdot
.43215 .32712 Mdot
.66516 .583 Mdot
.47776 .38415 Mdot
.60191 .58713 Mdot
.48197 .667 Mdot
.47804 .83919 Mdot
.43084 .72691 Mdot
.22035 .35172 Mdot
.47517 .38503 Mdot
.44347 .7037 Mdot
.64988 .41352 Mdot
.53423 .63791 Mdot
.3324 .52912 Mdot
.51149 .40061 Mdot
.78115 .46233 Mdot
.60855 .56768 Mdot
.32783 .56928 Mdot
.78905 .55951 Mdot
.77058 .56338 Mdot
.49358 .41854 Mdot
.63209 .54328 Mdot
.33991 .72868 Mdot
.41062 .26996 Mdot
.46946 .61003 Mdot
.66884 .40532 Mdot
.61297 .56504 Mdot
.4825 .62462 Mdot
.24526 .566 Mdot
.35415 .55833 Mdot
.35085 .58637 Mdot
.76783 .41099 Mdot
.6488 .60902 Mdot
.65438 .41071 Mdot
.63438 .76467 Mdot
.7126 .71072 Mdot
.67111 .40881 Mdot
.67166 .55144 Mdot
.36152 .55307 Mdot
.34524 .534 Mdot
.32467 .55608 Mdot
.81956 .52613 Mdot
.37179 .53566 Mdot
.32976 .32749 Mdot
.43813 .42318 Mdot
.55242 .42492 Mdot
.43511 .38518 Mdot
.4591 .63739 Mdot
.32699 .51934 Mdot
.45882 .57814 Mdot
.52902 .35104 Mdot
.47362 .81844 Mdot
.44659 .4024 Mdot
.50253 .61238 Mdot
.49506 .39833 Mdot
.3479 .32855 Mdot
.31877 .51175 Mdot
.48128 .37769 Mdot
.45589 .63226 Mdot
.64851 .42997 Mdot
.31069 .59734 Mdot
.45023 .34919 Mdot
.33216 .68128 Mdot
.40738 .36326 Mdot
.18275 .45649 Mdot
.52147 .24773 Mdot
.65229 .45815 Mdot
.40592 .30144 Mdot
.63285 .61097 Mdot
.56007 .41787 Mdot
.54957 .35572 Mdot
.48106 .63753 Mdot
.53455 .77841 Mdot
.62959 .56186 Mdot
.67109 .36899 Mdot
.53149 .33698 Mdot
.64694 .39872 Mdot
.35194 .49388 Mdot
.46349 .6266 Mdot
.52394 .38487 Mdot
.53417 .37367 Mdot
.20763 .39236 Mdot
.5471 .3996 Mdot
.42801 .36164 Mdot
.67268 .44838 Mdot
.31635 .30101 Mdot
.48868 .38706 Mdot
.55941 .49429 Mdot
.34463 .588 Mdot
.44633 .43679 Mdot
.35616 .27498 Mdot
.45767 .41102 Mdot
.33101 .57233 Mdot
.3789 .54288 Mdot
.39934 .72564 Mdot
.6245 .41074 Mdot
.44908 .33195 Mdot
.43582 .21768 Mdot
.48955 .35547 Mdot
.49165 .6633 Mdot
.47079 .42447 Mdot
.61644 .55867 Mdot
.81363 .52643 Mdot
.66946 .58634 Mdot
.43809 .35987 Mdot
.33015 .5561 Mdot
.50542 .62545 Mdot
.78832 .43721 Mdot
.71648 .4639 Mdot
.32576 .3208 Mdot
.23192 .31135 Mdot
.65727 .45048 Mdot
.66275 .39542 Mdot
.46784 .622 Mdot
.4826 .37809 Mdot
.41912 .20709 Mdot
.41166 .41892 Mdot
.49143 .39403 Mdot
.46121 .38179 Mdot
.59417 .77458 Mdot
.47344 .65408 Mdot
.65238 .56182 Mdot
.47526 .4044 Mdot
.46687 .41529 Mdot
.34027 .51019 Mdot
.64942 .43249 Mdot
.67417 .56075 Mdot
.65831 .43386 Mdot
.63021 .58252 Mdot
.47381 .84365 Mdot
.50707 .3199 Mdot
.64951 .4275 Mdot
.4871 .68556 Mdot
.31174 .56287 Mdot
.54826 .67107 Mdot
.66321 .5566 Mdot
.66093 .5795 Mdot
.44919 .4046 Mdot
.32859 .57331 Mdot
.30179 .55997 Mdot
.641 .42041 Mdot
.51137 .66753 Mdot
.44756 .35452 Mdot
.51981 .38213 Mdot
.41318 .56941 Mdot
.61827 .59387 Mdot
.51196 .28817 Mdot
.37418 .72392 Mdot
.48277 .3736 Mdot
.3058 .56266 Mdot
.45432 .37874 Mdot
.22225 .60037 Mdot
.32976 .5761 Mdot
.44126 .40982 Mdot
.74927 .68492 Mdot
.59229 .52613 Mdot
.36037 .68296 Mdot
.42864 .35429 Mdot
.1624 .41414 Mdot
.50468 .35994 Mdot
.25839 .75387 Mdot
.7543 .47735 Mdot
.44679 .34211 Mdot
.50293 .3767 Mdot
.31118 .47909 Mdot
.44205 .37538 Mdot
.63262 .53892 Mdot
.66554 .36492 Mdot
.34984 .50506 Mdot
.30991 .6422 Mdot
.46089 .48106 Mdot
.62328 .42151 Mdot
.66424 .59972 Mdot
.61611 .53078 Mdot
.67049 .41722 Mdot
.34184 .55236 Mdot
.48108 .35757 Mdot
.46842 .55596 Mdot
.597 .55088 Mdot
.49691 .43579 Mdot
.49609 .6604 Mdot
.61598 .68376 Mdot
.65125 .61832 Mdot
.49093 .64622 Mdot
.47562 .33066 Mdot
.32742 .47632 Mdot
.73049 .35315 Mdot
.17528 .57135 Mdot
.50292 .62157 Mdot
.48257 .62914 Mdot
.81847 .55143 Mdot
.62264 .42482 Mdot
.23423 .34911 Mdot
.38249 .6298 Mdot
.51919 .63804 Mdot
.45981 .23291 Mdot
.60676 .57663 Mdot
.33501 .67525 Mdot
.2908 .57643 Mdot
.47 .43124 Mdot
.46887 .36827 Mdot
.51153 .66948 Mdot
.24257 .5749 Mdot
.69275 .24519 Mdot
.48312 .64249 Mdot
.45688 .45718 Mdot
.46205 .51923 Mdot
.57295 .74825 Mdot
.62004 .59253 Mdot
.62538 .41169 Mdot
.62105 .44635 Mdot
.35082 .51809 Mdot
.63021 .40773 Mdot
.72947 .67141 Mdot
.47723 .33742 Mdot
.48665 .63589 Mdot
.54257 .74294 Mdot
.49682 .64228 Mdot
.66888 .41619 Mdot
.65129 .45892 Mdot
.30387 .5411 Mdot
.30792 .54644 Mdot
.23512 .41695 Mdot
.60175 .32378 Mdot
.43932 .39873 Mdot
.42571 .79139 Mdot
.30685 .52134 Mdot
.43124 .28341 Mdot
.6589 .39542 Mdot
.65177 .4295 Mdot
.5511 .30811 Mdot
.45979 .34401 Mdot
.4516 .20802 Mdot
.46353 .34628 Mdot
.60357 .34237 Mdot
.46482 .31675 Mdot
.6622 .56745 Mdot
.45817 .34102 Mdot
.67776 .39285 Mdot
.52195 .4005 Mdot
.45771 .41992 Mdot
.60729 .58726 Mdot
.41244 .37687 Mdot
.61845 .55743 Mdot
.43429 .3657 Mdot
.62356 .40102 Mdot
.64538 .60261 Mdot
.61321 .26711 Mdot
.58251 .59334 Mdot
.6858 .56159 Mdot
.63338 .40981 Mdot
.63257 .43945 Mdot
.5982 .2366 Mdot
.33379 .52849 Mdot
.2831 .58456 Mdot
.48195 .38216 Mdot
.61146 .59586 Mdot
.47267 .65677 Mdot
.47535 .41538 Mdot
.42025 .33439 Mdot
.42293 .37452 Mdot
.35683 .52265 Mdot
.70553 .54018 Mdot
.64499 .4266 Mdot
.61847 .54481 Mdot
.62878 .48435 Mdot
.59839 .56391 Mdot
.54218 .38368 Mdot
.45745 .30543 Mdot
.21819 .44941 Mdot
.4613 .77571 Mdot
.81722 .59002 Mdot
.34937 .56312 Mdot
.67678 .59733 Mdot
.62967 .43734 Mdot
.39083 .35236 Mdot
.33547 .53404 Mdot
.61953 .55495 Mdot
.48349 .36862 Mdot
.49514 .32444 Mdot
.54162 .64694 Mdot
.56564 .40796 Mdot
.55014 .2459 Mdot
.59996 .56706 Mdot
.63244 .61456 Mdot
.70988 .71054 Mdot
.65935 .3652 Mdot
.5009 .56383 Mdot
.46003 .39403 Mdot
.63424 .43258 Mdot
.36187 .54403 Mdot
.74628 .37629 Mdot
.49173 .67894 Mdot
.55683 .55577 Mdot
.47589 .38356 Mdot
.4308 .59396 Mdot
.32866 .55715 Mdot
.65869 .40377 Mdot
.51248 .66942 Mdot
.66008 .46281 Mdot
.63994 .6063 Mdot
.33932 .21401 Mdot
.48791 .35 Mdot
.43774 .40011 Mdot
.49339 .68262 Mdot
.35671 .53552 Mdot
.67837 .44541 Mdot
.19273 .47459 Mdot
.67808 .5741 Mdot
.43335 .20067 Mdot
.3017 .56833 Mdot
.341 .36397 Mdot
.61292 .54659 Mdot
.46929 .62983 Mdot
.61712 .25303 Mdot
.49388 .6296 Mdot
.43793 .35316 Mdot
.33037 .54605 Mdot
.492 .67072 Mdot
.57908 .49953 Mdot
.28045 .74699 Mdot
.34952 .38741 Mdot
.47103 .34199 Mdot
.36821 .79745 Mdot
.20363 .54388 Mdot
.38219 .49848 Mdot
.51408 .67513 Mdot
.45632 .40129 Mdot
.48343 .32812 Mdot
.48997 .36026 Mdot
.50755 .65392 Mdot
.6065 .73254 Mdot
.66255 .56087 Mdot
.43887 .39071 Mdot
.62668 .42082 Mdot
.62483 .55623 Mdot
.56687 .7541 Mdot
.6575 .58634 Mdot
.29772 .52062 Mdot
.46644 .42475 Mdot
.49937 .70415 Mdot
.35673 .81625 Mdot
.47514 .64211 Mdot
.6852 .56029 Mdot
.48312 .41835 Mdot
.52934 .76425 Mdot
.3279 .53572 Mdot
.67741 .57759 Mdot
.46739 .40102 Mdot
.58048 .72727 Mdot
.77605 .45097 Mdot
.65751 .58507 Mdot
.34327 .52936 Mdot
.2478 .64795 Mdot
.47726 .38853 Mdot
.50134 .35584 Mdot
.35463 .53993 Mdot
.46163 .47653 Mdot
.79422 .56155 Mdot
.45457 .37318 Mdot
.48707 .65054 Mdot
.44012 .16981 Mdot
.42016 .39183 Mdot
.56334 .31532 Mdot
.61555 .57158 Mdot
.36072 .70459 Mdot
.50218 .28136 Mdot
.41627 .29731 Mdot
.23543 .57045 Mdot
.4914 .48997 Mdot
.45518 .83067 Mdot
.61264 .60033 Mdot
.76368 .53134 Mdot
.45174 .83562 Mdot
.4643 .62042 Mdot
.26144 .54413 Mdot
.37236 .59501 Mdot
.82625 .4831 Mdot
.26186 .6611 Mdot
.73725 .55923 Mdot
.78824 .47358 Mdot
.45625 .54129 Mdot
.63732 .58479 Mdot
.63065 .37891 Mdot
.45078 .35656 Mdot
.20139 .54135 Mdot
.39038 .27539 Mdot
.65737 .2113 Mdot
.35591 .79094 Mdot
.44438 .22031 Mdot
.34595 .77326 Mdot
.23881 .68688 Mdot
.21289 .43345 Mdot
.4454 .77214 Mdot
.45852 .18346 Mdot
.74513 .68192 Mdot
.34227 .23524 Mdot
.44478 .29996 Mdot
.57831 .46748 Mdot
.18743 .39676 Mdot
.32486 .36194 Mdot
.59554 .19721 Mdot
.6716 .57952 Mdot
.29249 .56762 Mdot
.3751 .59679 Mdot
.34238 .49636 Mdot
.53801 .59956 Mdot
.23424 .63251 Mdot
.24018 .72048 Mdot
.35035 .31591 Mdot
.15371 .42542 Mdot
.26162 .3488 Mdot
.842 .37761 Mdot
.69308 .62575 Mdot
.34176 .58438 Mdot
.6181 .46089 Mdot
.69673 .72584 Mdot
.41715 .69819 Mdot
.29595 .60844 Mdot
.62631 .74634 Mdot
.63388 .30303 Mdot
.34063 .54792 Mdot
.43793 .26504 Mdot
.62269 .6399 Mdot
.44371 .72779 Mdot
.72389 .39303 Mdot
.24329 .67709 Mdot
.49863 .55102 Mdot
.32425 .66631 Mdot
.60356 .66897 Mdot
.83345 .63436 Mdot
.54676 .27448 Mdot
.2252 .54423 Mdot
.54987 .62995 Mdot
.24305 .61971 Mdot
.81219 .43565 Mdot
.62438 .33036 Mdot
.70165 .72194 Mdot
.62889 .79404 Mdot
.18808 .53368 Mdot
.65912 .7946 Mdot
.28542 .58823 Mdot
.42654 .36365 Mdot
.25152 .50338 Mdot
.41819 .23496 Mdot
.61947 .39822 Mdot
.50923 .80475 Mdot
.64457 .44566 Mdot
.29792 .51464 Mdot
.80877 .52766 Mdot
.33879 .32282 Mdot
.44868 .20301 Mdot
.68232 .44197 Mdot
.4352 .32861 Mdot
.56789 .12377 Mdot
.44574 .82503 Mdot
.39462 .71822 Mdot
.23849 .7372 Mdot
.44676 .59459 Mdot
.4972 .2304 Mdot
.49469 .66896 Mdot
.41588 .83401 Mdot
.34115 .53831 Mdot
.56866 .85297 Mdot
.33058 .79162 Mdot
.68879 .2539 Mdot
.31942 .16709 Mdot
.70003 .69854 Mdot
.43505 .57598 Mdot
.45425 .48895 Mdot
.58726 .26655 Mdot
.74286 .30613 Mdot
.64632 .22473 Mdot
.52569 .75734 Mdot
.21237 .34464 Mdot
.41749 .82954 Mdot
.41709 .22762 Mdot
.33943 .22167 Mdot
.82532 .46991 Mdot
.5437 .49089 Mdot
.28725 .51807 Mdot
.58411 .62164 Mdot
.30229 .72188 Mdot
.56568 .82079 Mdot
.54784 .28997 Mdot
.37102 .16235 Mdot
.67894 .39754 Mdot
.74747 .48238 Mdot
.2025 .60345 Mdot
.64357 .292 Mdot
.48315 .24667 Mdot
.79185 .58839 Mdot
.51835 .42144 Mdot
.78441 .61384 Mdot
.36776 .77025 Mdot
.56138 .6459 Mdot
.75111 .66909 Mdot
.31556 .69941 Mdot
.19686 .42401 Mdot
.28705 .47162 Mdot
.69017 .73573 Mdot
.32977 .50251 Mdot
.61316 .31001 Mdot
.50626 .24924 Mdot
.23078 .72025 Mdot
.56979 .62991 Mdot
.18643 .66626 Mdot
.79547 .53755 Mdot
.45763 .3131 Mdot
.54906 .34718 Mdot
.41738 .44136 Mdot
.59308 .30739 Mdot
.42756 .40843 Mdot
.45497 .71846 Mdot
.21908 .69134 Mdot
.25345 .34873 Mdot
.55488 .67108 Mdot
.53823 .78231 Mdot
.17635 .57599 Mdot
.22814 .47419 Mdot
.77382 .47438 Mdot
.59331 .36484 Mdot
.84637 .54548 Mdot
.63505 .5594 Mdot
.41167 .22681 Mdot
.47583 .61037 Mdot
.74633 .39854 Mdot
.3626 .44977 Mdot
.7319 .30585 Mdot
.21825 .69018 Mdot
.76605 .58732 Mdot
.79726 .50247 Mdot
.65717 .28067 Mdot
.4217 .1939 Mdot
.53262 .79065 Mdot
.51037 .31327 Mdot
.27813 .61313 Mdot
.65588 .45337 Mdot
.2474 .44191 Mdot
.37166 .23563 Mdot
.71767 .50449 Mdot
.41388 .40977 Mdot
.71576 .32393 Mdot
.71449 .56761 Mdot
.55915 .57202 Mdot
.72821 .76241 Mdot
.52709 .4202 Mdot
.65167 .74583 Mdot
.17988 .50955 Mdot
.57221 .27852 Mdot
.20648 .59395 Mdot
.30191 .66869 Mdot
.64443 .79825 Mdot
.30204 .77387 Mdot
.70758 .48096 Mdot
.49351 .82836 Mdot
.22565 .7229 Mdot
.68059 .77348 Mdot
.5516 .40107 Mdot
.46141 .66834 Mdot
.76361 .75754 Mdot
.60952 .54398 Mdot
.59164 .7843 Mdot
.32331 .26656 Mdot
.58684 .72111 Mdot
.33844 .59815 Mdot
.42484 .31106 Mdot
.46457 .5452 Mdot
.37262 .49419 Mdot
.41495 .38969 Mdot
.7686 .70928 Mdot
.66595 .77307 Mdot
.71774 .75647 Mdot
.16889 .46595 Mdot
.49452 .83279 Mdot
.42939 .54839 Mdot
.33092 .34758 Mdot
.40622 .52328 Mdot
.49582 .41968 Mdot
.70362 .39957 Mdot
.70059 .69619 Mdot
.7292 .33475 Mdot
.40598 .6781 Mdot
.33119 .4986 Mdot
.46075 .80111 Mdot
.91247 .48372 Mdot
.25714 .36862 Mdot
.35933 .26476 Mdot
.72389 .68949 Mdot
.58793 .31258 Mdot
.32918 .74179 Mdot
.70616 .28089 Mdot
.21128 .66195 Mdot
.40242 .52393 Mdot
.32726 .25392 Mdot
.73115 .53788 Mdot
.52822 .20974 Mdot
.72073 .56169 Mdot
.26493 .72555 Mdot
.41739 .49485 Mdot
.76894 .38417 Mdot
.36643 .61905 Mdot
.68981 .2492 Mdot
.74514 .44169 Mdot
.62409 .68175 Mdot
.3798 .225 Mdot
.51081 .74178 Mdot
.58026 .31939 Mdot
.47727 .52672 Mdot
.38805 .38913 Mdot
.48813 .49022 Mdot
.57128 .30851 Mdot
.54577 .21589 Mdot
.54858 .8193 Mdot
.23427 .75051 Mdot
.82305 .62742 Mdot
.14812 .44034 Mdot
.36463 .76331 Mdot
.47331 .43308 Mdot
.19099 .60899 Mdot
.66865 .79795 Mdot
.30593 .78326 Mdot
.70626 .63743 Mdot
.60565 .52005 Mdot
.53039 .66083 Mdot
.80545 .64583 Mdot
.72322 .57444 Mdot
.22093 .64472 Mdot
.79226 .61466 Mdot
.48707 .69538 Mdot
.82166 .40055 Mdot
.6573 .77246 Mdot
.3656 .43267 Mdot
.56221 .37167 Mdot
.50483 .42616 Mdot
.35864 .31549 Mdot
.30285 .51875 Mdot
.58959 .66191 Mdot
.61053 .32318 Mdot
.64066 .56759 Mdot
.71587 .40127 Mdot
.28294 .6067 Mdot
.40798 .37182 Mdot
.47652 .48442 Mdot
.29091 .56774 Mdot
.45856 .77434 Mdot
.51387 .71741 Mdot
.53729 .83773 Mdot
.69804 .68701 Mdot
.42997 .43477 Mdot
.56663 .27873 Mdot
.7343 .60272 Mdot
.79996 .57576 Mdot
.49457 .61349 Mdot
.33436 .77929 Mdot
.57654 .48367 Mdot
.61122 .31134 Mdot
.36648 .30619 Mdot
.20008 .43282 Mdot
.44961 .30496 Mdot
.38671 .73571 Mdot
.29938 .43575 Mdot
.56096 .553 Mdot
.29099 .51594 Mdot
.28646 .51703 Mdot
.15653 .5628 Mdot
.74448 .6427 Mdot
.59899 .67555 Mdot
.32225 .77015 Mdot
.50579 .63932 Mdot
.30125 .53616 Mdot
.69621 .39869 Mdot
.19124 .43822 Mdot
.31653 .4111 Mdot
.7769 .45184 Mdot
.6513 .71363 Mdot
.72859 .49773 Mdot
.33776 .77349 Mdot
.36184 .78939 Mdot
.64333 .19623 Mdot
.36212 .50447 Mdot
.20231 .46705 Mdot
.24571 .3246 Mdot
.28941 .54279 Mdot
.38025 .57854 Mdot
.42618 .69382 Mdot
.54789 .82772 Mdot
.46251 .69106 Mdot
.2032 .35252 Mdot
.55982 .23263 Mdot
.5907 .73375 Mdot
.79082 .44355 Mdot
.3852 .21809 Mdot
.31065 .76121 Mdot
.40895 .27431 Mdot
.37646 .45897 Mdot
.40828 .34266 Mdot
.57191 .4042 Mdot
.85469 .58368 Mdot
.58553 .59054 Mdot
.34283 .35809 Mdot
.30261 .68738 Mdot
.48267 .35092 Mdot
.82331 .64379 Mdot
.19942 .51404 Mdot
.81871 .55833 Mdot
.51096 .68551 Mdot
.50845 .35338 Mdot
.51393 .40998 Mdot
.58151 .36364 Mdot
.38132 .71588 Mdot
.60434 .79124 Mdot
.37891 .21961 Mdot
.31952 .71827 Mdot
.38913 .2775 Mdot
.6479 .74789 Mdot
.23627 .65926 Mdot
.20878 .55393 Mdot
.53854 .52682 Mdot
.7059 .6868 Mdot
.63746 .27352 Mdot
.15543 .43674 Mdot
.59855 .46212 Mdot
.421 .56379 Mdot
.41455 .65406 Mdot
.34467 .70546 Mdot
.76713 .39899 Mdot
.51165 .39518 Mdot
.78906 .5597 Mdot
.23789 .68145 Mdot
.56442 .17499 Mdot
.77493 .35753 Mdot
.81199 .65959 Mdot
.32575 .44513 Mdot
.32544 .69025 Mdot
.23689 .58327 Mdot
.51674 .15512 Mdot
.5876 .45988 Mdot
.45187 .81329 Mdot
.64325 .27397 Mdot
.3298 .77168 Mdot
.4539 .64904 Mdot
.38691 .61688 Mdot
.54286 .78276 Mdot
.52262 .82544 Mdot
.24328 .48091 Mdot
.26069 .71381 Mdot
.44149 .5825 Mdot
.61278 .82442 Mdot
.49424 .75262 Mdot
.4494 .53304 Mdot
.67286 .59856 Mdot
.76821 .59812 Mdot
.34505 .76551 Mdot
.42234 .77712 Mdot
.37997 .22838 Mdot
.61766 .61095 Mdot
.67942 .37584 Mdot
.36453 .39149 Mdot
.67676 .32006 Mdot
.34432 .7143 Mdot
.56703 .27851 Mdot
.24367 .71068 Mdot
.60828 .46016 Mdot
.79281 .52489 Mdot
.64497 .74703 Mdot
.31344 .23388 Mdot
.38606 .71406 Mdot
.75315 .63284 Mdot
.22089 .55619 Mdot
.74371 .46305 Mdot
.47003 .22957 Mdot
.30859 .84313 Mdot
.29391 .26475 Mdot
.4695 .76423 Mdot
.56681 .82008 Mdot
.20364 .58523 Mdot
.4693 .77315 Mdot
.75154 .31513 Mdot
.50537 .26742 Mdot
.67945 .36297 Mdot
.46246 .38076 Mdot
.71782 .76643 Mdot
.65153 .31811 Mdot
.58403 .82171 Mdot
.18286 .59569 Mdot
.35825 .32618 Mdot
.40853 .3712 Mdot
.60892 .55305 Mdot
.5964 .63962 Mdot
.69517 .34185 Mdot
.36362 .47315 Mdot
.46004 .24658 Mdot
.67102 .69905 Mdot
.65119 .60697 Mdot
.72321 .56164 Mdot
.39279 .52646 Mdot
.70176 .66932 Mdot
.36595 .72041 Mdot
.69148 .45467 Mdot
.52795 .54912 Mdot
.57375 .30446 Mdot
.48429 .27139 Mdot
.36309 .43174 Mdot
.73812 .3169 Mdot
.52543 .49817 Mdot
.65711 .58903 Mdot
.34476 .45755 Mdot
.2202 .33987 Mdot
.34505 .72866 Mdot
.62082 .7991 Mdot
.78326 .58293 Mdot
.39598 .45921 Mdot
.5736 .31702 Mdot
.72922 .292 Mdot
.50216 .19482 Mdot
.47001 .78849 Mdot
.49693 .28753 Mdot
.46765 .21337 Mdot
.31038 .61863 Mdot
.46804 .84111 Mdot
.33908 .23904 Mdot
.29139 .28319 Mdot
.61512 .62784 Mdot
.31635 .372 Mdot
.36239 .33974 Mdot
.60849 .25887 Mdot
.52624 .56486 Mdot
.84869 .39817 Mdot
.3008 .58473 Mdot
.8714 .5798 Mdot
.47001 .6602 Mdot
.83522 .47861 Mdot
.62979 .25711 Mdot
.47676 .52367 Mdot
.51528 .56929 Mdot
.39618 .73801 Mdot
.38676 .63948 Mdot
.16838 .43176 Mdot
.63336 .20468 Mdot
.59756 .5656 Mdot
.38505 .20852 Mdot
.33139 .21314 Mdot
.32742 .47103 Mdot
.42986 .33703 Mdot
.28852 .2672 Mdot
.59869 .59013 Mdot
.73054 .33526 Mdot
.19306 .58339 Mdot
.39716 .76209 Mdot
.49621 .45655 Mdot
.59331 .31515 Mdot
.4423 .81065 Mdot
.29905 .76699 Mdot
.79262 .3617 Mdot
.36802 .77001 Mdot
.46317 .6705 Mdot
.43703 .53897 Mdot
.27911 .72314 Mdot
.5192 .23571 Mdot
.32923 .65393 Mdot
.49592 .24282 Mdot
.87975 .49727 Mdot
.5752 .7919 Mdot
.60287 .79101 Mdot
.51407 .24233 Mdot
.37319 .54352 Mdot
.47337 .74422 Mdot
.48787 .24729 Mdot
.40633 .7599 Mdot
.18628 .41013 Mdot
.49952 .24786 Mdot
.6111 .16864 Mdot
.23064 .37455 Mdot
.65193 .49718 Mdot
.36559 .34303 Mdot
.23574 .37497 Mdot
.49471 .69306 Mdot
.69809 .37412 Mdot
.30287 .69233 Mdot
.49686 .68386 Mdot
.35065 .71901 Mdot
.33795 .68454 Mdot
.25939 .3242 Mdot
.32628 .41055 Mdot
.33384 .73264 Mdot
.28313 .49078 Mdot
.26495 .52825 Mdot
.74752 .38023 Mdot
.69547 .5885 Mdot
.28373 .67922 Mdot
.68094 .58217 Mdot
.43665 .28888 Mdot
.56177 .53906 Mdot
.42154 .45845 Mdot
.81751 .62641 Mdot
.6551 .45177 Mdot
.34709 .57869 Mdot
.84459 .48101 Mdot
.29081 .55605 Mdot
.74914 .73231 Mdot
.71896 .29499 Mdot
.3678 .30043 Mdot
.71693 .47243 Mdot
.70462 .5174 Mdot
.74582 .25858 Mdot
.39048 .47891 Mdot
.61798 .63083 Mdot
.29646 .50061 Mdot
.36118 .56353 Mdot
.66207 .72534 Mdot
.6327 .60157 Mdot
.54812 .31354 Mdot
.42494 .63107 Mdot
.40477 .49688 Mdot
.3764 .5154 Mdot
.56783 .50625 Mdot
.62769 .35776 Mdot
.53946 .82923 Mdot
.64215 .59041 Mdot
.86518 .49253 Mdot
.43251 .318 Mdot
.27479 .46688 Mdot
.20636 .65812 Mdot
.80965 .38186 Mdot
.62074 .53552 Mdot
.35067 .1905 Mdot
.4743 .31747 Mdot
.33845 .74105 Mdot
.34508 .54236 Mdot
.30947 .26834 Mdot
.66159 .44317 Mdot
.57699 .27389 Mdot
.53186 .64986 Mdot
.77011 .38772 Mdot
.69299 .67034 Mdot
.37561 .5359 Mdot
.39615 .77349 Mdot
.20509 .44208 Mdot
.35911 .63487 Mdot
.70442 .53063 Mdot
.34775 .4663 Mdot
.32235 .40463 Mdot
.37765 .52037 Mdot
.58016 .80108 Mdot
.3149 .26001 Mdot
.44529 .85092 Mdot
.41494 .43733 Mdot
.76527 .55447 Mdot
.41322 .63205 Mdot
.36696 .73225 Mdot
.54999 .32964 Mdot
.21607 .67686 Mdot
.62177 .32235 Mdot
.42273 .66314 Mdot
.59869 .33646 Mdot
.41683 .30498 Mdot
.51582 .5424 Mdot
.62347 .66134 Mdot
.68698 .2261 Mdot
.57113 .3751 Mdot
.81522 .42684 Mdot
.48866 .28449 Mdot
.66453 .7362 Mdot
.3806 .56396 Mdot
.62521 .51348 Mdot
.32446 .37327 Mdot
.57118 .63267 Mdot
.45355 .84062 Mdot
.21352 .67119 Mdot
.53446 .66947 Mdot
.64769 .73415 Mdot
.25561 .62955 Mdot
.4072 .41995 Mdot
.42699 .59119 Mdot
.43099 .35806 Mdot
.38103 .56968 Mdot
.8223 .39343 Mdot
.3971 .75046 Mdot
.51673 .3164 Mdot
.45338 .83179 Mdot
.40529 .82872 Mdot
.60365 .82511 Mdot
.42853 .19851 Mdot
.35438 .51347 Mdot
.7084 .7562 Mdot
.44677 .25367 Mdot
.25386 .7365 Mdot
.4594 .78612 Mdot
.16242 .5774 Mdot
.3726 .46518 Mdot
.29679 .67561 Mdot
.64827 .21987 Mdot
.3678 .65645 Mdot
.1959 .5505 Mdot
.444 .50842 Mdot
.58068 .68461 Mdot
.19169 .55828 Mdot
.6265 .15569 Mdot
.52966 .31028 Mdot
.32758 .67436 Mdot
.36159 .61025 Mdot
.29019 .6853 Mdot
.76422 .48541 Mdot
.47204 .4244 Mdot
.5455 .7502 Mdot
.79533 .46717 Mdot
.56128 .29198 Mdot
.68109 .37725 Mdot
.76266 .48501 Mdot
.70614 .36208 Mdot
.61179 .34841 Mdot
.34246 .23444 Mdot
.36609 .46265 Mdot
.55222 .3227 Mdot
.45581 .31197 Mdot
.37351 .57482 Mdot
.63089 .40056 Mdot
.66237 .52442 Mdot
.43177 .3676 Mdot
.59254 .54476 Mdot
.36773 .63949 Mdot
.79661 .67896 Mdot
.55051 .67611 Mdot
.19034 .49038 Mdot
.29041 .575 Mdot
.38375 .72313 Mdot
.24131 .53678 Mdot
.82043 .50061 Mdot
.75639 .52977 Mdot
.54766 .2897 Mdot
.41898 .81848 Mdot
.74873 .67172 Mdot
.20934 .3976 Mdot
.74259 .69793 Mdot
.47817 .68244 Mdot
.52172 .43887 Mdot
.39037 .59605 Mdot
.73847 .61387 Mdot
.31559 .49906 Mdot
.30228 .68056 Mdot
.65039 .63177 Mdot
.75082 .64929 Mdot
.18 .51422 Mdot
.20321 .43537 Mdot
.37172 .40779 Mdot
.37342 .79727 Mdot
.6104 .57758 Mdot
.29356 .275 Mdot
.32116 .64713 Mdot
.75583 .54938 Mdot
.64602 .76209 Mdot
.51327 .84053 Mdot
.46554 .57728 Mdot
.62748 .29207 Mdot
.49624 .35645 Mdot
.34394 .28101 Mdot
.40326 .74834 Mdot
.54262 .44698 Mdot
.66518 .68372 Mdot
.31108 .56763 Mdot
.65014 .6742 Mdot
.58432 .44764 Mdot
.68019 .35909 Mdot
.36618 .49459 Mdot
.42044 .23733 Mdot
.63398 .38909 Mdot
.44272 .60946 Mdot
.4183 .39509 Mdot
.61069 .28386 Mdot
.44822 .20033 Mdot
.5132 .44096 Mdot
.3368 .75323 Mdot
.35692 .45896 Mdot
.19695 .41379 Mdot
.36389 .7446 Mdot
.47872 .78962 Mdot
.38535 .64584 Mdot
.33493 .37997 Mdot
.7154 .62357 Mdot
.4233 .372 Mdot
.62211 .51666 Mdot
.29709 .55155 Mdot
.23576 .6275 Mdot
.32013 .44224 Mdot
.61671 .27 Mdot
.49699 .51626 Mdot
.24721 .52328 Mdot
.49057 .50356 Mdot
.19678 .62412 Mdot
.36898 .65772 Mdot
.61417 .32568 Mdot
.44867 .64055 Mdot
.62811 .25817 Mdot
.7457 .31704 Mdot
.36465 .80825 Mdot
.71229 .27569 Mdot
.46965 .56171 Mdot
.81725 .4217 Mdot
.47244 .75548 Mdot
.18828 .57746 Mdot
.62032 .33652 Mdot
.48198 .57518 Mdot
.68228 .38561 Mdot
.54097 .65925 Mdot
.53659 .50676 Mdot
.61666 .50161 Mdot
.50496 .27582 Mdot
.62323 .707 Mdot
.6489 .64406 Mdot
.41601 .32344 Mdot
.59448 .77872 Mdot
.40042 .80995 Mdot
.3157 .26834 Mdot
.50442 .49285 Mdot
.73431 .40863 Mdot
.67596 .35135 Mdot
.13125 .4445 Mdot
.83713 .6311 Mdot
.49468 .35466 Mdot
.51317 .48955 Mdot
.60812 .29597 Mdot
.59968 .55619 Mdot
.47515 .25649 Mdot
.25328 .52995 Mdot
.46811 .63826 Mdot
.60371 .51077 Mdot
.76066 .63612 Mdot
.40499 .73999 Mdot
.67069 .30602 Mdot
.56108 .76819 Mdot
.79187 .68906 Mdot
.19091 .38242 Mdot
.3789 .73935 Mdot
.12775 .50364 Mdot
.65719 .65066 Mdot
.27143 .54211 Mdot
.24571 .5091 Mdot
.55375 .82125 Mdot
.56268 .2716 Mdot
.76337 .40927 Mdot
.50958 .79021 Mdot
.62336 .32878 Mdot
.46504 .23687 Mdot
.64921 .74445 Mdot
.65664 .67637 Mdot
.47576 .53826 Mdot
.70648 .51891 Mdot
.70261 .73754 Mdot
.3897 .28273 Mdot
.41683 .80943 Mdot
.79726 .46429 Mdot
.58107 .15514 Mdot
.41861 .8357 Mdot
.70836 .39936 Mdot
.76774 .47704 Mdot
.2448 .50455 Mdot
.54117 .23203 Mdot
.44883 .23934 Mdot
.74579 .34995 Mdot
.30688 .40843 Mdot
.68477 .50036 Mdot
.80988 .44839 Mdot
.57903 .31819 Mdot
.2416 .36359 Mdot
.4853 .57403 Mdot
.3558 .4414 Mdot
.67475 .7075 Mdot
.52648 .25294 Mdot
.5888 .49532 Mdot
.57316 .24766 Mdot
.3421 .46222 Mdot
.2261 .55832 Mdot
.29106 .64802 Mdot
.6632 .18332 Mdot
.481 .79926 Mdot
.8205 .49297 Mdot
.43445 .41997 Mdot
.48268 .8506 Mdot
.30376 .65176 Mdot
.5026 .79424 Mdot
.17833 .46814 Mdot
.64823 .50693 Mdot
.41757 .61195 Mdot
.42327 .37389 Mdot
.40741 .78949 Mdot
.34526 .35972 Mdot
.2317 .3918 Mdot
.78175 .40975 Mdot
.57689 .28827 Mdot
.77818 .4785 Mdot
.59416 .2461 Mdot
.47941 .45395 Mdot
.30588 .57403 Mdot
.70695 .76605 Mdot
.44997 .57212 Mdot
.45208 .28468 Mdot
.5461 .43571 Mdot
.65799 .22462 Mdot
.23871 .29698 Mdot
.42203 .44422 Mdot
.73143 .69206 Mdot
.43812 .22797 Mdot
.38503 .41547 Mdot
.44732 .27082 Mdot
.1902 .27574 Mdot
.23806 .74759 Mdot
.36059 .51142 Mdot
.37255 .24753 Mdot
.45041 .21595 Mdot
.54525 .82174 Mdot
.73282 .53607 Mdot
.69882 .55528 Mdot
.59342 .20246 Mdot
.51793 .22211 Mdot
.44559 .31589 Mdot
.17807 .49803 Mdot
.34611 .79734 Mdot
.79013 .41902 Mdot
.44378 .83174 Mdot
.50631 .30022 Mdot
.52337 .32948 Mdot
.15538 .34852 Mdot
.28782 .73369 Mdot
.5162 .42173 Mdot
.65891 .22219 Mdot
.28396 .52164 Mdot
.45767 .36308 Mdot
.57599 .76985 Mdot
.37398 .225 Mdot
.5787 .32087 Mdot
.52424 .82531 Mdot
.35482 .49543 Mdot
.56981 .6122 Mdot
.46733 .6344 Mdot
.51949 .56775 Mdot
.49765 .32112 Mdot
.50625 .66005 Mdot
.38926 .42373 Mdot
.28309 .66861 Mdot
.50375 .69392 Mdot
.35247 .21723 Mdot
.1761 .63925 Mdot
.33766 .4362 Mdot
.53361 .6216 Mdot
.40137 .41441 Mdot
.22893 .38147 Mdot
.69859 .34819 Mdot
.41023 .5417 Mdot
.1847 .56046 Mdot
.42096 .88396 Mdot
.58917 .68809 Mdot
.62095 .37147 Mdot
.36339 .49205 Mdot
.54907 .32047 Mdot
.36124 .40402 Mdot
.4372 .63676 Mdot
.61604 .57943 Mdot
.40911 .41254 Mdot
.47427 .45365 Mdot
.52614 .66521 Mdot
.86745 .57419 Mdot
.48775 .41826 Mdot
.46433 .27063 Mdot
.25868 .73839 Mdot
.74894 .38184 Mdot
.26208 .46429 Mdot
.52419 .35861 Mdot
.45544 .72693 Mdot
.48031 .57596 Mdot
.26774 .68186 Mdot
.7913 .5306 Mdot
.48504 .82392 Mdot
.31711 .44163 Mdot
.36778 .35787 Mdot
.46014 .41399 Mdot
.61934 .41855 Mdot
.33791 .67205 Mdot
.53203 .79977 Mdot
.53122 .32146 Mdot
.28268 .762 Mdot
.65081 .50597 Mdot
.63754 .71583 Mdot
.38107 .39975 Mdot
.62702 .80895 Mdot
.80029 .40151 Mdot
.35524 .35581 Mdot
.82694 .5317 Mdot
.74156 .62816 Mdot
.67425 .3194 Mdot
.60778 .55713 Mdot
.47636 .29375 Mdot
.35957 .49714 Mdot
.79126 .6962 Mdot
.5387 .79981 Mdot
.54048 .72954 Mdot
.62438 .68404 Mdot
.33282 .30531 Mdot
.33487 .63151 Mdot
.14795 .56509 Mdot
.73212 .56924 Mdot
.8017 .67726 Mdot
.29167 .28112 Mdot
.38709 .49813 Mdot
.32405 .69561 Mdot
.53431 .42134 Mdot
.6534 .58535 Mdot
.52041 .81762 Mdot
.46452 .45097 Mdot
.8065 .51602 Mdot
.51301 .3445 Mdot
.8121 .57548 Mdot
.58202 .53306 Mdot
.62089 .75624 Mdot
.51523 .74258 Mdot
.75317 .3196 Mdot
.22416 .62912 Mdot
.51382 .70485 Mdot
.13842 .51296 Mdot
.2405 .64139 Mdot
.3356 .78091 Mdot
.77284 .44315 Mdot
.78026 .32755 Mdot
.4317 .77942 Mdot
.33747 .73254 Mdot
.5285 .71951 Mdot
.42999 .47954 Mdot
.76554 .59566 Mdot
.38653 .40896 Mdot
.35438 .67823 Mdot
.53376 .67473 Mdot
.54657 .9194 Mdot
.69455 .41867 Mdot
.27456 .58438 Mdot
.74967 .59628 Mdot
.37892 .80663 Mdot
.47341 .47274 Mdot
.17891 .53023 Mdot
.57887 .46789 Mdot
.50479 .3097 Mdot
.31969 .42146 Mdot
.33338 .25803 Mdot
.77528 .59711 Mdot
.784 .29248 Mdot
.19095 .38634 Mdot
.62781 .69786 Mdot
.53404 .54083 Mdot
.29153 .53792 Mdot
.33171 .59858 Mdot
.71319 .49523 Mdot
.16051 .50075 Mdot
.29211 .67315 Mdot
.28022 .72459 Mdot
.73305 .24808 Mdot
.2311 .35257 Mdot
.54905 .82429 Mdot
.44937 .75904 Mdot
.33341 .59359 Mdot
.71254 .39507 Mdot
.68546 .46997 Mdot
.53078 .74371 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`2eooooo`;o0000T_ooool001cooooo00?o0000oooo
ooooool0]Oooool2o`0009;ooooo000Looooo`03o`000?oooooooooo08_ooooo0_l0002looooo`00
7?ooool00ol0003oooooooooo`2;ooooo`;o0000_?ooool001cooooo00?o0000ooooooooool0R_oo
ool2o`000;gooooo000Looooo`03o`000?oooooooooo08[ooooo0_l0002mooooo`007?ooool00ol0
003oooooooooo`2eooooo`;o0000T_ooool001cooooo00?o0000ooooooooool0]Oooool2o`0009;o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000L
ooooo`03o`000?oooooooooo09Kooooo0_l0000<ooooo`;o00004oooool2o`0000gooooo0_l0001o
ooooo`007?ooool00ol0003oooooooooo`1mooooo`;o00005Oooool4o`0000cooooo0_l0000Coooo
o`;o00003Oooool2o`0007oooooo000Looooo`03o`000?oooooooooo07Gooooo0_l00006ooooo`;o
00005Oooool2o`0000Cooooo0_l0002]ooooo`007?ooool00ol0003oooooooooo`1eooooo`;o0000
4?ooool2o`00017ooooo0_l0002]ooooo`007?ooool00ol0003oooooooooo`1Tooooo`;o00003ooo
ool2o`0000Gooooo0_l00009ooooo`;o0000>_ooool2o`0008Cooooo000Looooo`03o`000?oooooo
oooo06Cooooo0_l00003ooooo`;o00004Oooool2o`0000gooooo0_l0000Mooooo`;o00005oooool2
o`0008Cooooo000Looooo`03o`000?oooooooooo06Wooooo0_l0000Pooooo`;o00007Oooool2o`00
00;ooooo0_l00004ooooo`;o0000Toooool001cooooo00?o0000ooooooooool0S?ooool2o`0001co
oooo0ol000000ooooooo0000o`000004ooooo`;o00005Oooool2o`0007cooooo000Looooo`03o`00
0?oooooooooo07Wooooo0_l0000Aooooo`;o00005?ooool2o`0000Oooooo0_l0000Iooooo`;o0000
0oooool2o`0007cooooo000Looooo`03o`000?oooooooooo07Wooooo0_l00002ooooo`;o00001_oo
ool2o`0000[ooooo0_l0000?ooooo`;o00005?ooool2o`0000cooooo0_l0000<ooooo`;o0000Looo
ool001cooooo00?o0000ooooooooool0Moooool2o`0000Cooooo0_l00006ooooo`;o00002_ooool2
o`00023ooooo0_l00003ooooo`;o00006_ooool2o`0007?ooooo000Looooo`03o`000?oooooooooo
06kooooo0_l00007ooooo`;o00005?ooool2o`0000Cooooo0_l0000:ooooo`;o00004_ooool2o`00
09Cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool0
0ol0003oooooooooo`1^ooooo`;o00007Oooool2o`0000Cooooo0ol00009ooooo`;o00004?ooool2
o`0000Wooooo0_l00003ooooo`;o00003Oooool4o`0007Gooooo00001_ooooooMgMgoiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003ooooo
ooooo`1^ooooo`;o00000_ooool2o`00017ooooo0_l0000=ooooo`;o00000_ooool2o`0000;ooooo
0_l000001?oooooo0000o`000?l0000;ooooo`;o00000_ooool2o`0000Gooooo0_l00002ooooo`;o
00000oooool2o`0000[ooooo0_l000000ooooooo0000o`000002o`0007Gooooo00000ooooooo410@
ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003ooooo
ooooo`1Rooooo`;o00001Oooool2o`0000Oooooo0_l0000:ooooo`;o00001Oooool4o`0000oooooo
0_l00002ooooo`;o000000?oooooo`000?l000000_l0000:ooooo`;o00002Oooool2o`0000Cooooo
0_l0000=ooooo`;o0000N_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02ooo
ool00onHV9So8B4Qonk^kP06ooooo`?o0000H_ooool2o`0000Gooooo0_l0000?ooooo`;o00000_oo
ool2o`0000?ooooo0_l00002ooooo`Co00000oooool2o`0000?ooooo0_l00004ooooo`;o00001_oo
ool2o`0001Wooooo1?l00029ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<
ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0N_ooool2o`0000;ooooo0_l00003
ooooo`;o00001?ooool2o`0000?ooooo0_l00003ooooo`;o00001?ooool2o`00027ooooo0ol00005
ooooo`;o00001?ooool2o`0007gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo
00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1iooooo`Co000000Coooooo`00
0?l0003ooooo0_l000000ooooooo0000o`000007ooooo`Co00001Oooool2o`00017ooooo1?l00008
ooooo`;o00001Oooool2o`0000Kooooo0_l00004ooooo`;o0000OOooool00006oooooomgMgOoV9RH
oooooonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
NOooool4o`0000Cooooo0_l000000ooooooo0000o`000005ooooo`Ko00001Oooool2o`0000Gooooo
0_l00009ooooo`Go00002?ooool2o`0001[ooooo0ol00007ooooo`;o0000K?ooool00006ooooooo^
k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000oooo
ooooool0J?ooool4o`0001oooooo1?l00005ooooo`Co00001Oooool4o`0000;ooooo0_l00003oooo
o`;o00009oooool3o`0000Cooooo0_l000000ooooooo0000o`00001/ooooo`007?ooool00ol0003o
ooooooooo`1Xooooo`Co00000oooool2o`0000Sooooo0_l0000?ooooo`Oo00000_ooool3o`0000Wo
oooo2?l00007ooooo`;o0000:?ooool2o`0006oooooo000Looooo`03o`000?oooooooooo06oooooo
0_l00006ooooo`Co00003oooool2o`000003ooooool0003o000000;o00000_ooool2o`0000cooooo
1_l00007ooooo`;o00007oooool2o`0000;ooooo0_l0001dooooo`007?ooool00ol0003ooooooooo
o`1[ooooo`;o00002_ooool3o`000003ooooool0003o000000Wooooo0_l00005ooooo`;o00005Ooo
ool2o`00013ooooo0_l0000Gooooo`Ko0000M?ooool001cooooo00?o0000ooooooooool0Joooool2
o`0000Wooooo1?l000000ooooooo0000o`000005ooooo`Ko00007?ooool2o`0000Cooooo0_l00000
0ooooooo0000o`000007ooooo`;o00005_ooool6o`0000Oooooo0_l0001/ooooo`007?ooool00ol0
003oooooooooo`1]ooooo`;o00001oooool4o`0000Gooooo0_l000000ooooooo0000o`000002o`00
00;ooooo0_l000000ooooooo0000o`000008ooooo`?o00001_ooool2o`0000[ooooo0_l000000ooo
oooo0000o`000003ooooo`;o00002oooool2o`0000gooooo0_l000000ooooooo0000o`000008oooo
o`;o0000K?ooool001cooooo00?o0000ooooooooool0E_ooool2o`0000[ooooo0_l00009ooooo`;o
00002Oooool2o`0000Gooooo0_l00007ooooo`;o000000?oooooo`000?l000001Oooool2o`000003
ooooool0003o000000;o00001Oooool2o`000003ooooool0003o000000Wooooo0_l00004ooooo`;o
00001oooool2o`0000;ooooo0_l00028ooooo`007?ooool00ol0003oooooooooo`1Fooooo`;o0000
2_ooool2o`0000Oooooo0ol00007ooooo`;o00003Oooool2o`0000cooooo0ol00002ooooo`;o0000
1Oooool2o`000005ooooool0003o0000o`000?ooool00_l00005ooooo`;o00000_ooool4o`0000Oo
oooo0_l000000ooooooo0000o`000003o`0000_ooooo0_l0000=ooooo`;o0000J_ooool001cooooo
00?o0000ooooooooool0J_ooool4o`0000Oooooo0_l00003ooooo`Co00001_ooool3o`0000?ooooo
0_l00002ooooo`;o000000?oooooo`000?l000000ol00008ooooo`;o000000Goooooo`000?l0003o
0000ooooo`02o`0000Wooooo1?l000000ooooooo0000o`000007ooooo`Go00000oooool2o`0000Ko
oooo0_l0000=ooooo`;o0000J_ooool001cooooo00?o0000ooooooooool0Goooool2o`0000Wooooo
0_l0000>ooooo`Co00001oooool2o`0000?ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o
oooo0_l00007ooooo`;o00001?ooool2o`00013ooooo0_l00007ooooo`;o00001_ooool2o`0000go
oooo0_l0001booooo`007?ooool00ol0003oooooooooo`1Oooooo`;o00000_ooool2o`0000oooooo
0_l00005ooooo`;o00008?ooool2o`000003ooooool0003o000000?o00002_ooool2o`0000cooooo
0_l00002ooooo`;o00004_ooool2o`0000Kooooo0_l0001Zooooo`007?ooool00ol0003ooooooooo
o`1Sooooo`;o00003oooool3o`0000Cooooo0_l0000;ooooo`;o000000?oooooo`000?l000001Ooo
ool2o`0000Gooooo1?l00002ooooo`Go00000_ooool2o`0000Oooooo0_l00005ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0000;ooooo0ol0000Hooooo`?o00002oooool2o`0005gooooo000L
ooooo`;o0000HOooool2o`0000kooooo0_l00003ooooo`;o00001oooool2o`0000Sooooo0_l00000
0ooooooo0000o`000005ooooo`;o00001Oooool4o`0000;ooooo1?l00003ooooo`;o00001?ooool2
o`0000?ooooo0_l00003ooooo`Go00001oooool2o`0001Sooooo0_l0000<ooooo`;o0000GOooool0
01cooooo00?o0000ooooooooool0H?ooool2o`0000Gooooo0_l00007ooooo`;o00003?ooool2o`00
0003ooooool0003o000000[ooooo0_l0000Hooooo`;o00000_ooool3o`0000;ooooo1?l000000ooo
oooo0000o`000002o`0000Wooooo1Ol0000Eooooo`?o0000J_ooool001cooooo00?o0000oooooooo
ool0Ioooool4o`0000Gooooo0_l0000?ooooo`;o00001oooool2o`000003ooooool0003o000000So
oooo0_l0000>ooooo`;o00000_ooool2o`0000?ooooo1?l000000ooooooo0000o`00000=ooooo`?o
000000Coooooo`000?l0003o00004Oooool3o`000003ooooool0003o000000_ooooo0_l0001Joooo
o`007?ooool00ol0003oooooooooo`1Sooooo`;o00001?ooool2o`0000Gooooo0_l0000=ooooo`;o
00002Oooool2o`000004ooooool0003o0000o`0000Oooooo0_l0000=ooooo`;o00006_ooool2o`00
00Cooooo0ol0000Eooooo`;o000000?oooooo`000?l000002?ooool3o`0005Wooooo000Looooo`03
o`000?oooooooooo067ooooo1?l0000Jooooo`;o00003?ooool3o`0000_ooooo0_l00009ooooo`;o
00003?ooool2o`0000cooooo0_l00004ooooo`;o00006Oooool2o`000003ooooool0003o000000Ko
oooo0_l0001Iooooo`007?ooool00ol0003oooooooooo`18ooooo`;o00004?ooool4o`0000?ooooo
0_l00002ooooo`;o00002_ooool2o`0000oooooo0_l00007ooooo`;o00001_ooool2o`0000?ooooo
0_l000000ooooooo0000o`000003ooooo`?o00002?ooool2o`0000Oooooo0_l00002ooooo`;o0000
00?oooooo`000?l000001_ooool2o`0000;ooooo0_l0000Mooooo`;o0000HOooool001cooooo00?o
0000ooooooooool0B?ooool2o`0000_ooooo0_l00003ooooo`Co00000oooool8o`0000Sooooo0_l0
000?ooooo`;o00001oooool2o`000003ooooool0003o000000?ooooo0_l00003ooooo`;o00001_oo
ool3o`0000Oooooo0ol0000;ooooo`;o000000?oooooo`000?l000001_ooool6o`000003ooooool0
003o000007gooooo000Looooo`03o`000?oooooooooo05Gooooo0_l00004ooooo`;o00001?ooool4
o`0000;ooooo0_l0000>ooooo`;o00002Oooool2o`0000[ooooo0_l00003ooooo`;o00001Oooool2
o`0000kooooo0_l00007ooooo`;o00000oooool2o`0000_ooooo1?l000000ooooooo0000o`000003
o`0007[ooooo000Looooo`03o`000?oooooooooo03[ooooo0_l0000Gooooo`;o00001oooool2o`00
01;ooooo0_l00005ooooo`;o00000_ooool2o`0000Cooooo0_l00009ooooo`;o00000oooool2o`00
00Oooooo0_l00002ooooo`Co00003?ooool2o`0000?ooooo0_l00003ooooo`;o00003Oooool2o`00
0003ooooool0003o000000?o00005Oooool2o`0006?ooooo000Looooo`03o`000?oooooooooo03[o
oooo0_l0000Gooooo`;o00001Oooool4o`00013ooooo1?l00009ooooo`;o00001?ooool2o`0000Wo
oooo0_l00003ooooo`;o00002oooool4o`0000cooooo0_l00004ooooo`Co00000_ooool2o`0000?o
oooo0_l00004ooooo`;o00000oooool2o`0001Sooooo0_l0001Sooooo`007?ooool00ol0003ooooo
ooooo`1Jooooo`?o00002oooool2o`0000;ooooo1?l00006ooooo`;o000000?oooooo`000?l00000
0_l00006ooooo`;o00003_ooool2o`0000[ooooo0_l0000Cooooo`Co00000_ooool2o`0000?ooooo
0_l00004ooooo`;o00001_ooool2o`0000?ooooo0_l0000>ooooo`Co0000Hoooool001cooooo00?o
0000ooooooooool0Foooool3o`0000[ooooo0_l00002ooooo`Ko00001?ooool2o`000003ooooool0
003o000000;o00001_ooool2o`0000?ooooo0_l00005ooooo`;o00000_ooool2o`0000Kooooo0_l0
0002ooooo`Co00003?ooool2o`0001;ooooo0_l00008ooooo`;o00000oooool2o`0000kooooo1?l0
001Sooooo`007?ooool00ol0003oooooooooo`1Cooooo`?o00001_ooool2o`00013ooooo1?l0000>
ooooo`;o00001_ooool4o`0000?ooooo0_l00002ooooo`;o00001_ooool5o`000003ooooool0003o
000000Co00001_ooool6o`0000Gooooo1?l00007ooooo`;o00002_ooool2o`0001;ooooo0_l00003
ooooo`;o0000Goooool001cooooo00?o0000ooooooooool0Doooool4o`00013ooooo0_l00007oooo
o`Co00003?ooool2o`000003ooooool0003o000000Gooooo0_l00003ooooo`;o00000_ooool2o`00
00Gooooo1_l00003ooooo`Co00001_ooool3o`000003ooooool0003o000000;o00000oooool4o`00
00Oooooo0_l00003ooooo`;o00000oooool7o`0000oooooo0_l00003ooooo`?o00002oooool2o`00
057ooooo000Looooo`03o`000?oooooooooo05Gooooo0_l0000@ooooo`Co000000?oooooo`000?l0
00000_ooool4o`0000oooooo0_l000000ooooooo0000o`000004o`0000?ooooo0_l00006ooooo`;o
000000Coooooo`000?l0003ooooo0ol0000>ooooo`;o00000oooool2o`0001?ooooo0_l00003oooo
o`;o000000?oooooo`000?l000000_l0000Booooo`;o000000?oooooo`000?l000002oooool2o`00
00?ooooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o00000oooool2o`0001So
oooo0_l000000ooooooo0000o`000002o`0001?ooooo2ol000000ooooooo0000o`000002ooooo`Ko
00001?ooool4o`00027ooooo0_l0000Rooooo`;o00002Oooool2o`0000Sooooo0_l0001<ooooo`00
7?ooool2o`00043ooooo0_l00009ooooo`;o00000oooool2o`0000;ooooo0_l0000>ooooo`;o0000
2Oooool2o`000004ooooool0003o0000ooooo`;o00002_ooool2o`000004ooooool0003o0000o`00
00;ooooo0_l00002ooooo`Ko000000?oooooo`000?l000001?l00006ooooo`Go00004?ooool2o`00
00cooooo0_l0000Nooooo`Co00002oooool2o`0005Kooooo000Looooo`03o`000?oooooooooo03oo
oooo0_l00009ooooo`;o00001oooool2o`0000kooooo0_l0000<ooooo`;o000000?oooooo`000?l0
00002_ooool2o`0000_ooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0ol00005oooo
o`Go00004?ooool2o`000003ooooool0003o000000Wooooo0_l00006ooooo`;o00001?ooool2o`00
013ooooo1?l00004ooooo`?o00000oooool2o`0005Oooooo000Looooo`03o`000?oooooooooo04[o
oooo0_l00004ooooo`Co00005?ooool2o`0000Oooooo1?l0000;ooooo`;o00000_ooool4o`0000;o
oooo0_l00002ooooo`Oo00000oooool2o`0000Gooooo1_l0000Booooo`;o00001?ooool2o`0000?o
oooo0_l00006ooooo`;o00001?ooool2o`0000?ooooo0ol0000Booooo`Go000000?oooooo`000?l0
0000Eoooool001cooooo00?o0000ooooooooool0Aoooool2o`0000Oooooo1?l0000Dooooo`;o0000
1oooool4o`0000[ooooo1?l000000ooooooo0000o`000002o`0000;ooooo0_l00002ooooo`Oo0000
1Oooool2o`0000Cooooo1Ol00003ooooo`;o00001Oooool5o`0000;ooooo0_l00004ooooo`?o0000
1?ooool2o`00013ooooo0ol0000Booooo`;o000000?oooooo`000?l00000F_ooool001cooooo00?o
0000ooooooooool0Aoooool3o`0002Oooooo0_l00002ooooo`;o00002?ooool4o`0000?ooooo0_l0
0007ooooo`Co00000oooool2o`0000;ooooo1?l00002ooooo`Co00001?ooool2o`0000Cooooo1_l0
0002ooooo`;o00000oooool3o`0000Gooooo0_l00005ooooo`Co00002_ooool2o`0006oooooo000L
ooooo`03o`000?oooooooooo04Sooooo0_l0000@ooooo`;o00001_ooool2o`0000[ooooo0_l00000
0ooooooo0000o`000002ooooo`;o00003oooool4o`0000?ooooo6Ol00008ooooo`;o000000?ooooo
o`000?l000000_l00002ooooo`;o00000_ooool4o`0000Cooooo0_l00005ooooo`Co00002_ooool2
o`0000_ooooo0_l00005ooooo`Ko0000Eoooool001cooooo00?o0000ooooooooool0F_ooool2o`00
00Kooooo0_l0000:ooooo`;o000000?oooooo`000?l000005Oooool3o`0000;ooooo5_l000000ooo
oooo0000o`00000=ooooo`?o000000?oooooo`000?l000000_l00002ooooo`;o00000oooool2o`00
00Kooooo1?l00002ooooo`;o00001Oooool3o`0000Cooooo0_l00005ooooo`;o00001Oooool7o`00
05Kooooo000Looooo`03o`000?oooooooooo05?ooooo0_l0000Aooooo`;o00000_ooool3o`0001?o
oooo0_l00004ooooo`Go00000_ooool3o`0000?ooooo2?l00002ooooo`?o000000Coooooo`000?l0
003ooooo0_l000000ooooooo0000o`000002o`0000Cooooo0ol00002ooooo`;o00000_ooool3o`00
00;ooooo0_l00003ooooo`Ko00000_ooool4o`0000;ooooo0_l00005ooooo`Go00000_ooool2o`00
017ooooo0_l0000=ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0>Oooool2o`0000oo
oooo1Ol00002ooooo`Co00004Oooool2o`0000;ooooo0ol00004ooooo`;o00000_ooool2o`0000Oo
oooo1?l000001?oooooo0000o`000?ooool2o`000004ooooool0003o0000ooooo`Wo000000?ooooo
o`000?l000000ol000000ooooooo0000o`000002o`000003ooooool0003o000000Cooooo1?l00004
ooooo`?o00001_ooool2o`0000?ooooo0_l000000ooooooo0000o`000006o`0000Gooooo0_l0000:
ooooo`?o00000_ooool3o`0000Cooooo0_l0000Iooooo`;o0000Aoooool001cooooo00?o0000oooo
ooooool0>Oooool2o`0000oooooo1Ol00002ooooo`;o00005?ooool2o`0000Cooooo0_l00002oooo
o`;o00000_ooool3o`0000Kooooo0_l00003ooooo`?o00000ooooolGo`0000Cooooo0_l0000Joooo
o`?o000000Coooooo`000?l0003ooooo0_l00004ooooo`Go00001oooool4o`0000;ooooo1?l00002
ooooo`;o00000oooool2o`0000Gooooo0_l00007ooooo`;o0000COooool001cooooo00?o0000oooo
ooooool0A_ooool2o`0000Sooooo0_l0000Eooooo`;o00001?ooool2o`0000Oooooo0_l0000<oooo
o`Co000000?oooooo`000?l000005Ol00004ooooo`Ko00001Oooool2o`0000?ooooo0_l00004oooo
o`;o00000_ooool2o`0000Oooooo0_l00006ooooo`Go00001oooool2o`0000Cooooo0_l00007oooo
o`;o00001Oooool2o`0000Gooooo1?l0001=ooooo`007?ooool00ol0003oooooooooo`14ooooo`Co
00002?ooool3o`0002Oooooo0_l00009ooooo`?o000000?oooooo`000?l000008?l00004ooooo`;o
00000oooool4o`000004ooooool0003o0000o`0000;ooooo0_l00007ooooo`?o00002?ooool2o`00
01;ooooo0_l000000ooooooo0000o`00000=ooooo`;o0000Coooool001cooooo00?o0000oooooooo
ool0A?ooool2o`0000[ooooo1?l0000Dooooo`;o00003oooool3o`000003ooooool0003o000000;o
000000?oooooo`000?l000008Ol000001?oooooo0000o`000?ooool2o`0000[ooooo0ol000000ooo
oooo0000o`000004ooooo`;o00001Oooool4o`0001Oooooo0_l00003ooooo`;o000000?oooooo`00
0?l000003_ooool2o`0004kooooo000Looooo`03o`000?oooooooooo047ooooo0_l000000ooooooo
0000o`00000:ooooo`Co00005?ooool2o`0000Sooooo0_l00005ooooo`;o000000?oooooo`000?l0
0000;Ol00002ooooo`;o00001_ooool3o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o
000000?oooooo`000?l000001_ooool2o`0000gooooo1_l0000Fooooo`;o0000C_ooool001cooooo
00?o0000ooooooooool0@Oooool5o`0000?ooooo0_l00005ooooo`;o00008?ooool3o`0000Oooooo
0_l00003ooooo`;o00001OoooolRo`0000?ooooo0_l0000Aooooo`;o000000Coooooo`000?l0003o
oooo0_l00005ooooo`?o00003Oooool4o`0000cooooo0_l0001Jooooo`007?ooool00ol0003ooooo
ooooo`11ooooo`Co00001?ooool2o`0000Gooooo0_l0000Fooooo`;o00002Oooool2o`0000Gooooo
0_l00005ooooo`?o00001?ooool?o`000003ooooool0003o000000go00000_ooool5o`000003oooo
ool0003o000000oooooo0_l00004ooooo`;o00001Oooool2o`0000Gooooo0_l000001?oooooo0000
o`000?l00004ooooo`;o00003Oooool2o`000003ooooool0003o000005Oooooo000Looooo`;o0000
<?ooool2o`00017ooooo0ol00003ooooo`?o00000oooool5o`0001Gooooo0_l0000@ooooo`;o0000
1Oooool3o`0000Cooooo9_l000000ooooooo0000o`00000?ooooo`;o000000?oooooo`000?l00000
0oooool2o`0000Cooooo0_l00004ooooo`;o000000Coooooo`000?l0003o00001Oooool2o`0000co
oooo1Ol00006ooooo`;o0000Coooool001cooooo00?o0000ooooooooool0;oooool2o`0000gooooo
0_l00002ooooo`Co000000Coooooo`000?l0003o00001?ooool5o`0002Sooooo0_l00003ooooo`;o
00001ooooolQo`0001Kooooo0_l000000ooooooo0000o`000002ooooo`?o00001?ooool2o`0000So
oooo0_l00005ooooo`;o00002?ooool4o`000003ooooool0003o000000Sooooo0_l0001?ooooo`00
7?ooool00ol0003oooooooooo`0nooooo`;o00001?ooool2o`000003ooooool0003o000002Oooooo
0_l00009ooooo`;o00000oooool2o`0000Gooooo9_l00002ooooo`;o00000oooool2o`0000[ooooo
0_l00005ooooo`;o00003Oooool4o`0000oooooo1?l00008ooooo`;o0000D_ooool001cooooo00?o
0000ooooooooool0J_ooool4o`0000;ooooo0_l00002ooooo`;o00001_ooool4o`0000Kooooo3_l0
00000ooooooo0000o`00000Go`000004ooooool0003o0000ooooo`Co00002_ooool2o`000003oooo
ool0003o000000;o000000?oooooo`000?l000003?ooool2o`000003ooooool0003o000001[ooooo
1Ol0000Aooooo`;o0000??ooool001cooooo00?o0000ooooooooool0I_ooool2o`0000;ooooo1?l0
0006ooooo`;o00001Oooool:o`000003ooooool0003o000002;o00000_ooool2o`0000;ooooo2?l0
000;ooooo`Co000000?oooooo`000?l000003oooool2o`0000Oooooo0_l0000<ooooo`;o00001Ooo
ool5o`0000;ooooo0_l0000;ooooo`;o0000??ooool001cooooo00?o0000ooooooooool0=oooool2
o`00013ooooo1?l0000Iooooo`;o00000oooool2o`0000[ooooo0_l00002ooooo`Co000000?ooooo
o`000?l000009ol00002ooooo`;o00000oooool2o`0000Cooooo0_l000000ooooooo0000o`000002
ooooo`;o00000oooool2o`0000Cooooo0_l00008ooooo`Co00000_ooool3o`0000Oooooo0_l0000<
ooooo`;o00001_ooool4o`0000;ooooo0_l00019ooooo`007?ooool00ol0003oooooooooo`0goooo
o`;o00004?ooool4o`0000?ooooo0_l0000Iooooo`;o00002_ooool2o`0000?ooooo0_l00003oooo
o`;o000000?oooooo`000?l000009ol0000<ooooo`;o00000_ooool2o`0000?ooooo0_l00004oooo
o`?o00001_ooool9o`0000Wooooo0_l00004ooooo`;o000000?oooooo`000?l000003Oooool2o`00
01Kooooo0_l0000dooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00004Oooool2o`0001Co
oooo0_l00006ooooo`;o00000ooooolRo`000004ooooool0003o0000o`0000;ooooo0_l00003oooo
o`;o00004Oooool2o`000003ooooool0003o000000Kooooo0ol00002ooooo`;o00002oooool2o`00
00;ooooo1?l000000ooooooo0000o`000003ooooo`Co00001_ooool2o`0000Cooooo0_l0000@oooo
o`;o0000=?ooool001cooooo00?o0000ooooooooool0Aoooool4o`0001Sooooo0_l000000ooooooo
0000o`00000Aooooo`;o00001_ooool[o`0000;ooooo0_l00003ooooo`;o000000Coooooo`000?l0
003ooooo1?l00009ooooo`;o00002_ooool2o`0000_ooooo0_l00006ooooo`;o00000oooool2o`00
00?ooooo1?l0000<ooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0@?ooool2o`0000Go
oooo1?l00004ooooo`;o00005Oooool2o`0000Oooooo0ol0000?ooooob_o00001?ooool2o`0000Co
oooo0_l000000ooooooo0000o`000002o`0000oooooo0_l000000ooooooo0000o`000008ooooo`;o
00001?ooool2o`0000kooooo0_l0000:ooooo`;o00004Oooool2o`0003Wooooo000Looooo`03o`00
0?oooooooooo043ooooo0_l00005ooooo`;o000000?oooooo`000?l000000oooool2o`0001Sooooo
0_l00004ooooo`?o00003Oooool2o`000003ooooool0003o000002So000000Coooooo`000?l0003o
oooo0_l0000;ooooo`;o00001oooool5o`000004ooooool0003o0000ooooo`;o00002?ooool2o`00
01Cooooo0_l0000:ooooo`Go00003_ooool2o`0003Wooooo000Looooo`03o`000?oooooooooo03[o
oooo0_l0000;ooooo`;o000000?oooooo`000?l000007Oooool2o`0000_ooooo0_l00007ooooo`;o
00001?ooool/o`0000cooooo0_l00004ooooo`;o000000?oooooo`000?l000000ol00008ooooo`;o
00000_ooool2o`0000gooooo0_l00007ooooo`;o00001Oooool2o`0000Gooooo0ol00003ooooo`;o
0000A?ooool001cooooo00?o0000ooooooooool0>_ooool2o`0002cooooo0_l00004ooooo`;o0000
1_ooool2o`0000Oooooo0_l000001?oooooo0000o`000?oooolUo`0000;ooooo1Ol00006ooooo`;o
00002_ooool3o`0000;ooooo1?l00007ooooo`;o00000_ooool2o`000003ooooool0003o000000;o
00002?ooool2o`0000Oooooo0_l00002ooooo`;o000000?oooooo`000?l000002oooool2o`0004Co
oooo000Looooo`03o`000?oooooooooo03[ooooo0_l0000Aooooo`;o00006Oooool2o`0000Cooooo
0_l0000:ooooo`;o00000oooool6o`0000;ooooo8?l000000ooooooo0000o`000002ooooo`Go0000
1_ooool2o`0000_ooooo0_l00002ooooo`Ko00002Oooool2o`000003ooooool0003o000000;o0000
5Oooool2o`000003ooooool0003o000000Sooooo0_l00017ooooo`0000Koooooonk^k_lb<S;o0000
oc8b<_o^k^h5ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000oooooooo
ool0@?ooool2o`0000Kooooo0_l00003ooooo`;o00007?ooool2o`0000Kooooo0_l00002ooooo`;o
000000Coooooo`000?l0003ooooo5ol000000ooooooo0000o`00000?o`0000Oooooo1?l00007oooo
o`;o00002_ooool4o`0000;ooooo1Ol000000ooooooo0000o`000003ooooo`Go000000?oooooo`00
0?l000002_ooool2o`0000Sooooo0_l0000=ooooo`;o00001Oooool2o`00043ooooo00001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0>Oooool2o`0000Gooooo0_l00006ooooo`;o00005oooool2o`0000Sooooo0_l00006
ooooo`;o00000_ooool2o`0000Cooooo1_l000000ooooooo0000o`00000Po`0000Cooooo0ol0000;
ooooo`;o00002_ooool4o`0000;ooooo3Ol000001?oooooo0000o`000?ooool2o`0000Oooooo0_l0
00000ooooooo0000o`000008ooooo`;o00003_ooool2o`0000Cooooo0_l00010ooooo`0000?ooooo
oa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`Go00001_ooool00ol0003oooooooooo`0d
ooooo`Co000000?oooooo`000?l000001Oooool2o`0001oooooo0_l0000<ooooo`;o00001_ooool3
o`0000Oooooo0_l000000ooooooo0000o`00000Wo`000003ooooool0003o000001Gooooo5_l00003
ooooo`;o000000?oooooo`000?l000000ol00009ooooo`;o00001?ooool2o`0000[ooooo1?l0000;
ooooo`;o0000=oooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?m4
A4CogMgMooooool00007ooooo`?o0000<oooool5o`0000Oooooo0ol00005ooooo`;o00001Oooool2
o`0001oooooo0_l00007ooooo`;o00003Oooool2o`000003ooooool0003o000000ko000000?ooooo
o`000?l000003Ol00004ooooo`?o00005?ooool6o`000003ooooool0003o000000go00000oooool2
o`000005ooooool0003o0000o`000?ooool00_l00008ooooo`;o00001?ooool2o`0000Wooooo0_l0
00000ooooooo0000o`000002ooooo`;o00001oooool2o`0003Oooooo00000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003ooooooooo
o`0]ooooo`;o00001?ooool2o`0000[ooooo0ol00005ooooo`?o00001?ooool2o`0001Gooooo0_l0
000;ooooo`;o00004?ooool2o`000003ooooool0003o0000013o000000?oooooo`000?l000003_l0
0005ooooo`;o00000oooool4o`0000gooooo5?l00002ooooo`;o000000?oooooo`000?l000001Ooo
ool3o`0001Sooooo0_l00005ooooo`;o0000@?ooool00003ooooool@413ooooo00;ooooo00?o410@
ooooooooool02_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo02gooooo0_l00004
ooooo`;o00002?ooool2o`000003ooooool0003o000000Kooooo0_l0000Fooooo`;o00000oooool2
o`0000_ooooo0_l000000ooooooo0000o`000003ooooo`;o000000Coooooo`000?l0003ooooo1_l0
00000ooooooo0000o`00000Lo`000003ooooool0003o000000cooooo1?l0000=oooooaSo00002Ooo
ool2o`0000?ooooo0_l00007ooooo`;o00006_ooool2o`0003Oooooo00001_ooooooMgMgoiRHV?oo
ooooV9RHogMgM`cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0iooooo`;o0000
0_ooool2o`00027ooooo0_l000001?oooooo0000o`000?ooool2o`0000Kooooo0_l00003ooooo`Wo
000000Coooooo`000?l0003ooooo1_l000001?oooooo0000o`000?oooolEo`000003ooooool0003o
000000?o000000?oooooo`000?l000003?ooool2o`00013ooooo5ol0000>ooooo`;o00001oooool4
o`0000;ooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l0000gooooo`0000Koooooonk^
k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0<Ooo
ool2o`0000Kooooo0_l000000ooooooo0000o`00000>ooooo`;o00004oooool7o`0000Kooooo0_l0
0003ooooo`;o00000_ooool4o`0000Cooooo1_l00002oooooako000000?oooooo`000?l000000ooo
ool2o`0000[ooooo0_l0000:ooooo`;o000000?oooooo`000?l000005_l0000Hooooo`;o00000_oo
ool2o`0000Gooooo1?l00004ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0<Oooool2
o`0000Wooooo0_l00003ooooo`;o00001_ooool2o`000003ooooool0003o000001?ooooo0_l00002
ooooo`;o00000oooool2o`0000gooooo0_l00002ooooo`Co00001_oooolMo`0000;ooooo0_l00003
ooooo`;o00001Oooool2o`0000?ooooo0_l0000:oooooaKo000000?oooooo`000?l000001?l0000S
ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0@Oooool2o`000003ooooool0003o0000
00?ooooo0_l0000Iooooo`;o00000oooool5o`0000_ooooo0_l00002ooooo`;o00000_ooool3o`00
0005ooooool0003o0000o`000?ooool00_l000000ooooooo0000o`000006o`000003ooooool0003o
000000Wo000000?oooooo`000?l000002Ol00006ooooo`;o00004OoooolGo`0000;ooooo0_l00009
ooooo`;o00001?ooool3o`0000[ooooo0ol00007ooooo`;o0000@Oooool001cooooo00?o0000oooo
ooooool0;?ooool2o`0000kooooo0_l00006ooooo`;o00002?ooool2o`0001Cooooo0_l00003oooo
o`;o000000?oooooo`000?l000000_l00009ooooo`Co00000oooool4o`000003ooooool0003o0000
00Oo000000?oooooo`000?l000001ol000000ooooooo0000o`000005o`0000Cooooo2?l00004oooo
o`;o00005?oooolHo`0000Gooooo0_l00003ooooo`?o00000_ooool5o`0000[ooooo0ol00007oooo
o`;o0000@Oooool001cooooo00?o0000ooooooooool0;?ooool4o`0000_ooooo0ol0000@ooooo`?o
00007Oooool2o`0000_ooooo0_l00003ooooo`;o00001Oooool7o`000003ooooool0003o000000ko
000000?oooooo`000?l000001?ooool5o`0000Gooooo0_l0000DoooooaSo00000oooool4o`0000?o
oooo0_l00003ooooo`;o00005_ooool2o`0000?ooooo0_l0000mooooo`007?ooool00ol0003ooooo
ooooo`0^ooooo`;o00002oooool2o`0000kooooo0_l00002ooooo`;o0000=Oooool7o`000003oooo
ool0003o000000?o00000_ooool7o`000004ooooool0003o0000ooooo`;o00001?ooool7o`0001[o
oooo4?l000000ooooooo0000o`000002o`0000Gooooo0_l0000Gooooo`;o00002Oooool2o`0000?o
oooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00002?ooool2o`0000;ooooo
0_l00008ooooo`Co00000_ooool2o`0001oooooo0ol0000Aooooo`Co00001?ooool5o`0000;ooooo
1_l00002ooooo`;o000000?oooooo`000?l000000_ooool5o`0000;ooooo0_l0000Kooooo`go0000
0oooool4o`0001kooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00000_oo
ool2o`0000Sooooo0ol000000ooooooo0000o`00000:ooooo`;o00000_ooool2o`0000_ooooo0_l0
000:ooooo`;o00001_ooool3o`0000gooooo0_l00004ooooo`;o00000_ooool>o`000004ooooool0
003o0000ooooo`;o00000oooool4o`0000Oooooo0_l0000@ooooo`;o000000?oooooo`000?l00000
0ooooolDo`0000Oooooo0_l0000Cooooo`;o00000_ooool2o`0000Kooooo0_l00013ooooo`007?oo
ool00ol0003oooooooooo`0_ooooo`;o00000_ooool2o`0000Gooooo0_l00002ooooo`;o00007_oo
ool2o`0000?ooooo0_l00005ooooo`;o00003?ooool2o`0000Sooooo0ol00003ooooo`;o00000_oo
ool9o`0000?ooooo1Ol000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000001_oo
ool3o`0000oooooo0_l000000ooooooo0000o`000003oooooa?o00002?ooool2o`00013ooooo0_l0
00000ooooooo0000o`000004o`0000Kooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`0/
ooooo`;o00001?ooool2o`0000Kooooo0_l00003ooooo`;o00000oooool2o`0000Oooooo1Ol0000?
ooooo`Go00002_ooool2o`0000Kooooo0_l00005ooooo`;o00000_ooool5o`0000Sooooo0_l00000
0ooooooo0000o`000002ooooo`Co00000oooool2o`0000?ooooo0_l000000ooooooo0000o`000007
ooooo`;o00004oooool2o`0000;ooooo5_l0000@ooooo`;o00001Oooool4o`000003ooooool0003o
000000kooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0Wooooo`;o00000oooool2o`00
00Cooooo0_l00004ooooo`;o00001Oooool2o`0000?ooooo0_l00007ooooo`Go00003oooool7o`00
00Sooooo0_l0000=ooooo`;o00000oooool4o`0000Oooooo1Ol00003ooooo`Go00001oooool2o`00
01cooooo0_l000000ooooooo0000o`00000Ho`0000Cooooo0_l00002ooooo`;o00001_ooool2o`00
00Oooooo0_l00004ooooo`;o00002Oooool6o`0003_ooooo000Looooo`03o`000?oooooooooo02Oo
oooo0_l00009ooooo`;o00001?ooool2o`0000Wooooo0_l0000Oooooo`Co00007Oooool3o`0000Go
oooo1?l000000ooooooo0000o`000004ooooo`Co00001oooool2o`0000Oooooo0_l0000<ooooo`;o
00001Oooool2o`0000?ooooo0_l000000ooooooo0000o`00000@o`0000Cooooo0_l000001?oooooo
0000o`000?ooool3o`0000[ooooo0_l00009ooooo`;o00001?ooool2o`0000?ooooo0_l00002oooo
o`;o0000>oooool001cooooo0_l0000iooooo`;o00002Oooool2o`0000Wooooo0_l00003ooooo`;o
00003oooool2o`0000cooooo0_l0000Iooooo`;o00001?ooool2o`0000;ooooo0_l0000Cooooo`;o
00002?ooool6o`0000Cooooo0_l00008oooooa3o00001Oooool2o`0000Cooooo0_l00009ooooo`Co
00001?ooool4o`0000Kooooo0ol00014ooooo`007?ooool00ol0003oooooooooo`0jooooo`Co0000
4?ooool2o`0000?ooooo0_l00008ooooo`;o00004oooool2o`0001Oooooo0_l00004ooooo`Co0000
00?oooooo`000?l000000_l00008ooooo`;o00004_ooool4o`0000Kooooo0_l0000=ooooo`Wo0000
0_ooool2o`000003ooooool0003o000000Oooooo0_l00008ooooo`?o00001Oooool4o`0000Kooooo
0_l00007ooooo`;o0000??ooool001cooooo00?o0000ooooooooool0>?ooool6o`0001oooooo0_l0
00000ooooooo0000o`00000:ooooo`;o00000_ooool2o`00013ooooo0_l000000ooooooo0000o`00
0004ooooo`;o00001?ooool2o`0000;ooooo1Ol00003ooooo`Co000000?oooooo`000?l000008ooo
ool2o`0000Cooooo3ol000000ooooooo0000o`000007ooooo`;o00004?ooool2o`00017ooooo0_l0
000looooo`007?ooool00ol0003oooooooooo`0cooooo`;o00000oooool2o`0002Kooooo0_l0000:
ooooo`;o00000_ooool2o`0000Gooooo0_l00003ooooo`?o00000oooool2o`000003ooooool0003o
000000[ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000002
o`0001[ooooo0_l00005ooooo`;o000000?oooooo`000?l000000_l00002ooooo`Oo00000oooool5
o`0000?ooooo0_l0000Iooooo`;o00004Oooool2o`0003cooooo000Looooo`03o`000?oooooooooo
03?ooooo0_l0000Looooo`;o00006?ooool2o`0000?ooooo0_l000000ooooooo0000o`000002oooo
o`;o00000oooool3o`0000[ooooo0_l00003ooooo`;o000000?oooooo`000?l000001Oooool4o`00
01cooooo0_l000000ooooooo0000o`000002ooooo`;o000000Coooooo`000?l0003ooooo0_l00004
ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000003o`0000Kooooo0_l00005
ooooo`;o00001oooool2o`0000[ooooo0_l00003ooooo`;o00002Oooool3o`0003cooooo000Loooo
o`03o`000?oooooooooo03?ooooo0_l00009ooooo`;o00000oooool2o`0000cooooo0_l00003oooo
o`;o000000?oooooo`000?l000004?ooool4o`0000Cooooo1_l0000@ooooo`;o00000oooool2o`00
0003ooooool0003o000000cooooo0_l0000Gooooo`;o00001Oooool2o`00013ooooo1?l00009oooo
o`;o00001Oooool2o`0000Oooooo0_l000000ooooooo0000o`000002o`0000Gooooo0_l00003oooo
o`;o00002Oooool2o`0003gooooo000Looooo`03o`000?oooooooooo03?ooooo0_l000000ooooooo
0000o`000006ooooo`?o00000_ooool2o`00017ooooo0_l000000ooooooo0000o`00000:ooooo`Co
00001?ooool2o`0000Kooooo0_l00005ooooo`;o00008Oooool2o`0000kooooo0_l00007ooooo`;o
00003?ooool2o`0000Cooooo0_l00003ooooo`;o00002?ooool3o`0001?ooooo1?l00005ooooo`;o
00000oooool2o`0000Oooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0cooooo`;o0000
00?oooooo`000?l000001oooool2o`0000Gooooo0_l0000Booooo`;o00002Oooool4o`0000?ooooo
0_l000001?oooooo0000o`000?ooool2o`0000Sooooo0_l0000Hooooo`;o00002oooool2o`000003
ooooool0003o000000Oooooo0_l0000@ooooo`;o00000oooool2o`0000Cooooo0_l0000=ooooo`?o
00001oooool2o`0000Gooooo0_l0000<ooooo`Ko00001Oooool2o`000003ooooool0003o000003oo
oooo000Looooo`03o`000?oooooooooo03Oooooo0_l000001?oooooo0000o`000?l00009ooooo`;o
00001Oooool2o`0000[ooooo0ol0000;ooooo`;o00000_ooool3o`000004ooooool0003o0000oooo
o`;o00007_ooool2o`0000;ooooo0_l0000;ooooo`;o000000?oooooo`000?l000002oooool2o`00
00Sooooo0ol000001?oooooo0000o`000?l00002ooooo`;o00007Oooool2o`0000Gooooo0_l00008
ooooo`[o00001Oooool2o`0000?ooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0goooo
o`;o000000Coooooo`000?l0003o00001_ooool2o`0000Sooooo0_l0000:ooooo`?o00001Oooool2
o`0000Cooooo0_l00002ooooo`;o00003?ooool4o`0000_ooooo0_l00005ooooo`;o000000?ooooo
o`000?l000007oooool2o`0000Kooooo1Ol00002ooooo`;o00000_ooool2o`0002Wooooo0_l00003
ooooo`Oo000000?oooooo`000?l000000oooool2o`000003ooooool0003o000000;ooooo0ol0000l
ooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00001_ooool4o`0001;ooooo0_l0000Foooo
o`Co00002oooool2o`0000Gooooo0_l000000ooooooo0000o`00000Vooooo`?o00006?ooool2o`00
00_ooooo0_l0000;ooooo`Co00001_ooool4o`000003ooooool0003o000000?ooooo0_l000001?oo
oooo0000o`000?ooool4o`0000;ooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0/oooo
o`;o00003oooool2o`0000cooooo1?l0000Dooooo`;o00001Oooool2o`0000Sooooo0_l00003oooo
o`;o00000oooool2o`0000Wooooo0_l000001?oooooo0000o`000?l00003ooooo`;o00000oooool2
o`0000Cooooo0_l0000;ooooo`;o00000oooool2o`0000Oooooo1?l00002ooooo`Co00001?ooool6
o`0000Wooooo0_l0000;ooooo`;o00002oooool2o`0000?ooooo0_l00004ooooo`?o000000?ooooo
o`000?l000002Oooool2o`0000Cooooo0_l0000Dooooo`;o00008_ooool001cooooo00?o0000oooo
ooooool0;?ooool2o`0000oooooo0_l0000Tooooo`;o00001Oooool2o`0000Sooooo0_l00003oooo
o`;o00000oooool2o`0000Wooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o000000?ooooo
o`000?l000000_ooool2o`0000Cooooo0ol00003ooooo`;o00000oooool4o`0000?ooooo0_l00005
ooooo`Go00000oooool4o`0000Cooooo1ol0000Nooooo`;o00001oooool2o`0000Gooooo0_l00008
ooooo`;o00000_ooool2o`0001[ooooo0_l0000Rooooo`007?ooool00ol0003oooooooooo`0^oooo
o`;o00002_ooool2o`0001cooooo0_l0000Hooooo`;o00007?ooool2o`000003ooooool0003o0000
00Kooooo1Ol00003ooooo`;o00000oooool2o`0000;ooooo0ol00005ooooo`Co00001?ooool2o`00
00gooooo0_l0000Nooooo`;o00003_ooool2o`0000Sooooo0_l00002ooooo`;o00001_ooool2o`00
00;ooooo0_l0000booooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00002_ooool2o`0000;o
oooo0_l0000Hooooo`;o00001_ooool2o`0000[ooooo2ol0000=ooooo`?o00005?ooool3o`0000;o
oooo1?l00008ooooo`?o00000oooool5o`0000Cooooo0ol0000=ooooo`;o00005oooool2o`00027o
oooo0_l00005ooooo`;o000000?oooooo`000?l000000_ooool2o`0003;ooooo000Looooo`03o`00
0?oooooooooo03Kooooo0_l00006ooooo`;o000000?oooooo`000?l000007Oooool2o`0000;ooooo
0_l00002ooooo`;o000000?oooooo`000?l000002_l000000ooooooo0000o`000002o`000004oooo
ool0003o0000ooooo`;o00000_ooool3o`0001Wooooo1_l000001?oooooo0000o`000?ooool7o`00
0003ooooool0003o000000?o00001?ooool2o`0000kooooo0_l00003ooooo`;o00004_ooool2o`00
00?ooooo0_l00007ooooo`;o00002?ooool2o`0000Wooooo0_l00005ooooo`;o00002_ooool2o`00
02gooooo000Looooo`;o0000<Oooool2o`0000Cooooo0_l00002ooooo`;o00001Oooool2o`0001[o
oooo0_l00004ooooo`?o00000_ooool2o`000004ooooool0003o0000o`0000?ooooo1?l000000ooo
oooo0000o`000004o`000004ooooool0003o0000ooooo`?o00002Oooool2o`0001Kooooo0_l00000
0ooooooo0000o`000005o`000003ooooool0003o000000;o00001Oooool2o`0000_ooooo0_l00009
ooooo`;o00002Oooool2o`0000cooooo0_l00007ooooo`;o00001oooool4o`0000Sooooo0_l0000>
ooooo`;o000000?oooooo`000?l00000;Oooool001cooooo00?o0000ooooooooool09_ooool2o`00
00Gooooo0_l000000ooooooo0000o`000008ooooo`;o00002oooool2o`000003ooooool0003o0000
00Co00001?ooool2o`0000Oooooo0_l00004ooooo`?o000000?oooooo`000?l000002?l000000ooo
oooo0000o`000002ooooo`;o00002Oooool2o`0000?ooooo0_l00004ooooo`;o00001_ooool2o`00
00Kooooo0_l00002ooooo`Co00001Oooool4o`0000Cooooo0_l00005ooooo`;o00002oooool2o`00
01Cooooo0_l00008ooooo`;o00005?ooool6o`0000Kooooo0_l0000>ooooo`;o0000<?ooool001co
oooo00?o0000ooooooooool09_ooool2o`0000Gooooo0_l00003ooooo`?o000000?oooooo`000?l0
00003oooool2o`000003ooooool0003o000000Ko00000_ooool2o`0000kooooo0_l000000ooooooo
0000o`000008o`000004ooooool0003o0000o`00017ooooo0_l0000<ooooo`;o00001_ooool2o`00
00;ooooo1?l00005ooooo`Co00002?ooool2o`0001Sooooo0ol0000Cooooo`;o00003_ooool2o`00
00Sooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`0booooo`?o000000Coooooo`000?l0
003o00001_ooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o
000000Co00001Oooool2o`0000Oooooo5Ol00002ooooo`;o00004oooool2o`00013ooooo0_l0000;
ooooo`Go00001Oooool2o`0000?ooooo0_l00004ooooo`;o00003Oooool3o`0002?ooooo0_l00006
ooooo`;o00001?ooool2o`0000;ooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0Yoooo
o`;o00001_ooool4o`0000;ooooo0_l00004ooooo`Co00000_ooool2o`000004ooooool0003o0000
ooooo`;o000000?oooooo`000?l000000_l00007ooooo`;o000000?oooooo`000?l000001?oooolI
o`000003ooooool0003o0000013ooooo0_l0000@ooooo`Co00002_ooool6o`000004ooooool0003o
0000ooooo`Ko00001?ooool2o`0000Gooooo0_l0000>ooooo`;o000000?oooooo`000?l000008Ooo
ool2o`0000Cooooo0_l000001?oooooo0000o`000?l00010ooooo`007?ooool00ol0003ooooooooo
o`0Yooooo`;o00001_ooool2o`0000Cooooo0_l00004ooooo`?o00006Oooool6o`0000?ooooo1_l0
00000ooooooo0000o`00000>o`000003ooooool0003o000002;ooooo1_l0000<ooooo`;o000000Co
ooooo`000?l0003ooooo1_l0000:ooooo`?o000000?oooooo`000?l000000oooool2o`0000;ooooo
0_l00002ooooo`;o000000?oooooo`000?l000008?ooool2o`0000Cooooo0_l00002ooooo`;o0000
@Oooool001cooooo00?o0000ooooooooool0<_ooool2o`00013ooooo0_l0000Cooooob3o00002Ooo
ool4o`0000cooooo0_l0000:ooooo`;o00000_ooool2o`0000cooooo0_l00004ooooo`;o00000_oo
ool4o`0000?ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00001_oo
ool2o`0000Cooooo0ol0000Hooooo`;o00001?ooool2o`0004Gooooo000Looooo`03o`000?oooooo
oooo03;ooooo0_l0000@ooooo`;o00001oooool2o`0000[ooooo0ol000000ooooooo0000o`00000J
o`000003ooooool0003o000000Cooooo1_l0000<ooooo`;o00001_ooool2o`0001Cooooo0_l00009
ooooo`Co00000_ooool2o`0001Sooooo0_l000001?oooooo0000o`000?ooool3o`0006Gooooo000L
ooooo`03o`000?oooooooooo04gooooo0_l0000:oooooago00001?ooool4o`000004ooooool0003o
0000o`0001Gooooo0_l000000ooooooo0000o`00000Jooooo`;o00000oooool4o`0001Cooooo0_l0
0009ooooo`;o00007_ooool2o`000004ooooool0003o0000ooooo`Ko0000?oooool001cooooo00?o
0000ooooooooool0<oooool2o`0001Sooooo0_l00003ooooo`;o00001OoooolMo`000003ooooool0
003o000000?ooooo0_l000000ooooooo0000o`00000;ooooo`;o00002Oooool2o`0001;ooooo0_l0
0009ooooo`;o00001?ooool3o`0000gooooo0_l00005ooooo`;o00002Oooool2o`0000Wooooo0_l0
000Cooooo`;o000000?oooooo`000?l000001ol0000oooooo`007?ooool00ol0003oooooooooo`0c
ooooo`;o000000?oooooo`000?l000001oooool2o`0000cooooo1?l000000ooooooo0000o`000002
o`0000?ooooo0_l000000ooooooo0000o`00000Ko`0000Kooooo1?l00009ooooo`;o00002Oooool2
o`0000kooooo0_l00002ooooo`;o00002oooool2o`0000[ooooo0_l00006ooooo`;o00001Oooool4
o`0000Oooooo0_l000000ooooooo0000o`000006ooooo`;o00001oooool4o`0000Kooooo1Ol00002
ooooo`;o00001?ooool2o`0003kooooo000Looooo`03o`000?oooooooooo03Kooooo0_l000001?oo
oooo0000o`000?l00003ooooo`;o00003_ooool2o`0000?ooooo0ol00002ooooo`;o000000?ooooo
o`000?l000006Ol0000:ooooo`;o00002oooool2o`0001Oooooo0_l00002ooooo`;o00001oooool2
o`0000;ooooo0ol00006ooooo`Oo00002Oooool6o`0000Wooooo0ol0000?ooooo`Ko00001?ooool5
o`0000Sooooo0_l00004ooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0>Oooool3o`00
00oooooo0_l00005ooooo`Go00001?oooolMo`0000Wooooo0_l0000;ooooo`;o00001oooool2o`00
01;ooooo0_l00007ooooo`Oo00001_ooool;o`0000Gooooo0_l00002ooooo`;o00002?ooool4o`00
00;ooooo0_l00003ooooo`;o00002_ooool2o`0000Oooooo0_l0000>ooooo`;o00000oooool2o`00
03?ooooo000Looooo`03o`000?oooooooooo03kooooo0_l0000;ooooo`;o00000_ooool2o`000005
ooooool0003o0000o`000?ooool00_l00002ooooo`?o000000?oooooo`000?l000006?l00003oooo
o`;o00001Oooool2o`0000Kooooo0_l00004ooooo`;o00001Oooool2o`0000Sooooo0_l00007oooo
o`?o00001_ooool6o`0000Wooooo3ol00002ooooo`Co00002?ooool8o`0000?ooooo0_l0000Coooo
o`?o00004_ooool2o`0003?ooooo000Looooo`03o`000?oooooooooo03Kooooo1Ol00003ooooo`;o
00001?ooool3o`0000Sooooo1?l000000ooooooo0000o`000002o`000003ooooool0003o000002;o
00001Oooool2o`0000Kooooo0_l00004ooooo`;o00003oooool2o`000003ooooool0003o000000Co
oooo0_l00007ooooo`;o000000?oooooo`000?l000001OoooolHo`0000[ooooo1_l0000<ooooo`;o
00003Oooool2o`0004Oooooo000Looooo`03o`000?oooooooooo03Kooooo1Ol00003ooooo`;o0000
1?ooool3o`0000[ooooo0_l000000ooooooo0000o`000002ooooob?o00006?ooool2o`0000oooooo
0_l0000Goooooa7o000000?oooooo`000?l000000ol000000ooooooo0000o`000002o`0001Sooooo
0_l00008ooooo`;o00000oooool2o`0000Kooooo0ol00004ooooo`;o0000>?ooool001cooooo0_l0
000iooooo`;o00000_ooool2o`0001Wooooo1Ol00002ooooo`Wo000000?oooooo`000?l000003?l0
0003ooooo`;o00003Oooool2o`0000Gooooo0_l00002ooooo`;o00002Oooool2o`0000Sooooo0_l0
000Cooooo`Go000000?oooooo`000?l000003ol000000ooooooo0000o`000003o`0001Sooooo0_l0
0004ooooo`;o000000?oooooo`000?l000000oooool2o`0000Kooooo0ol00004ooooo`;o0000>?oo
ool001cooooo00?o0000ooooooooool0=_ooool4o`0000;ooooo0_l00002ooooo`;o00005Oooool5
o`000003ooooool0003o000000So000000?oooooo`000?l000003?l00002ooooo`?o00001_ooool2
o`0000Gooooo0_l00005ooooo`;o00002_ooool2o`000003ooooool0003o000000Sooooo0_l00007
ooooo`So00000ooooolOo`0000Sooooo0ol0000<ooooo`;o00000oooool3o`0000cooooo0_l00000
0ooooooo0000o`00000nooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00002?ooool2o`00
00;ooooo0_l0000Booooo`;o000000?oooooo`000?l000006Ol00002ooooo`;o00001oooool2o`00
00Cooooo0_l0000;ooooo`;o00000_ooool5o`0001;ooooo2_l000000ooooooo0000o`00000=o`00
00;ooooo0ol000000ooooooo0000o`00000<o`0000;ooooo0_l00002ooooo`?o00003oooool5o`00
00;ooooo0_l00008ooooo`;o000000?oooooo`000?l00000?_ooool001cooooo00?o0000oooooooo
ool0>oooool2o`0000Kooooo1Ol00004ooooo`;o00003?oooolKo`000003ooooool0003o000000Ko
oooo0_l00007ooooo`;o00002oooool2o`0000;ooooo0ol0000Dooooo`Go00000oooool2o`000004
ooooool0003o0000ooooo`oo000000?oooooo`000?l000002_l000001Ooooooo0000o`000?l0003o
oooo00?o00000_ooool2o`0000;ooooo0_l00003ooooo`;o00001oooool2o`0000Gooooo0_l00005
ooooo`;o000000?oooooo`000?l00000@Oooool001cooooo00?o0000ooooooooool0;oooool2o`00
00Oooooo0_l000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l000001?ooool2o`00
00[ooooo4_l000000ooooooo0000o`00000;o`0000?ooooo0_l000000ooooooo0000o`00000Eoooo
o`;o00006_ooool3o`0000Wooooo0_l00003ooooo`[o000000?oooooo`000?l000001_l000000ooo
oooo0000o`000008o`0000?ooooo0_l000001?oooooo0000o`000?l00003ooooo`;o00002?ooool2
o`0000Cooooo1?l00003ooooo`;o000000?oooooo`000?l00000@Oooool001cooooo00?o0000oooo
ooooool0;?ooool2o`000003ooooool0003o000000Oooooo0_l0000Booooo`?o00002OoooolBo`00
0003ooooool0003o000000go000000?oooooo`000?l000002?ooool2o`0000kooooo0_l00002oooo
o`;o00001?ooool2o`0000?ooooo1Ol00008ooooo`?o00002Oooool4o`000003ooooool0003o0000
01go00000_ooool6o`0000gooooo0_l000000ooooooo0000o`000003ooooo`;o0000BOooool001co
oooo00?o0000ooooooooool0;?ooool2o`0000kooooo0_l0000>ooooo`?o00002?ooool2o`0000;o
oooo2Ol000000ooooooo0000o`00000Co`0000Sooooo0_l000000ooooooo0000o`000002o`000003
ooooool0003o000000cooooo0ol00004ooooo`;o00000oooool5o`0000Sooooo0_l00009ooooo`Go
000000?oooooo`000?l000007Ol00003ooooo`?o00000oooool2o`0000Sooooo0_l00003ooooo`Co
000000Coooooo`000?l0003o00005Oooool2o`00037ooooo000Looooo`03o`000?oooooooooo03Go
oooo0_l00005ooooo`;o00002oooool2o`0000_ooooo1?l000000ooooooo0000o`00000Fo`000004
ooooool0003o0000ooooo`?o00002?ooool2o`0000?ooooo0_l000000ooooooo0000o`000002oooo
o`;o00002?ooool2o`0000Gooooo0_l00002ooooo`So00001_ooool3o`0000Sooooo8Ol00007oooo
o`;o00001?ooool2o`0000Oooooo0ol000001?oooooo0000o`000?ooool3o`000004ooooool0003o
0000o`0000Wooooo0_l0000:ooooo`;o0000<Oooool001cooooo00?o0000ooooooooool0=Oooool2
o`0000Oooooo0_l00005ooooo`;o00000_ooool4o`0000Wooooo1?l000000ooooooo0000o`00000H
o`000003ooooool0003o000001Kooooo0_l00009ooooo`?o00001oooool2o`0000?ooooo0ol00007
ooooo`;o00002_ooool:o`0000?ooooo4Ol000001?oooooo0000o`000?l00007ooooo`;o00001?oo
ool2o`0000Cooooo0ol000001?oooooo0000o`000?ooool2o`0000;ooooo1?l00002ooooo`;o0000
1?ooool2o`0000[ooooo0_l0000aooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00000ooo
ool2o`000004ooooool0003o0000ooooo`Co00001Oooool2o`0000Cooooo0_l00003ooooo`;o0000
1?ooool2o`0000?ooooo5_l00002ooooo`;o000000?oooooo`000?l000001?l0000>ooooo`;o0000
1Oooool5o`0000;ooooo1?l00006ooooo`;o000000?oooooo`000?l000002oooool2o`0000[ooooo
8_l00003ooooo`;o00000_ooool2o`0000Cooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo
0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l0000@ooooo`;o0000<Oooool001cooooo
00?o0000ooooooooool0<Oooool2o`0000?ooooo0_l000000ooooooo0000o`000003o`0001;ooooo
0_l00004ooooo`;o00000oooool2o`000003ooooool0003o000001;o00001_ooool4o`0000kooooo
0_l00005ooooo`Go000000Coooooo`000?l0003o00001Oooool2o`000004ooooool0003o0000oooo
o`;o00004oooool2o`0000;ooooo8_l00003ooooo`;o00000_ooool2o`0000Sooooo0_l00003oooo
o`;o00001Oooool4o`0001Kooooo0_l0000`ooooo`007?ooool00ol0003oooooooooo`0kooooo`?o
00002oooool2o`0000[ooooo0_l000000ooooooo0000o`000004ooooo`?o000000?oooooo`000?l0
00003_l00008ooooo`;o00002oooool3o`0000;ooooo0_l00003ooooo`;o00001?ooool2o`0000Ko
oooo0_l000000ooooooo0000o`00000;ooooo`;o00001oooool4o`0000?ooooo8?l0000Booooo`;o
00002?ooool2o`0000;ooooo0_l0000Aooooo`;o00000oooool2o`00033ooooo000Looooo`03o`00
0?oooooooooo03Cooooo0_l00005ooooo`Go00002Oooool2o`0000[ooooo1Ol00004ooooo`So0000
00Coooooo`000?l0003ooooo1_l00002ooooo`;o00001?ooool2o`0000gooooo0ol00002ooooo`;o
00001?ooool2o`0000Sooooo0_l0000Aooooo`;o00001oooool2o`0000Gooooo8?l0000@ooooo`Go
000000?oooooo`000?l000001?ooool2o`0000;ooooo0ol00002ooooo`;o00003?ooool2o`0003Go
oooo000Looooo`03o`000?oooooooooo03Cooooo0_l00008ooooo`;o00004_ooool2o`0000;ooooo
1Ol00005ooooo`;o00000_ooool5o`0000?ooooo1?l00002ooooo`Co00000_ooool2o`0000Sooooo
0_l00003ooooo`;o00002Oooool4o`0000Kooooo0_l0000Fooooo`Co00000_ooool3o`0000;ooooo
8Ol00002ooooo`;o00002oooool2o`000003ooooool0003o000000?o00001_ooool5o`0000;ooooo
1?l00011ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko
<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0>oooool3o`000003ooooool0003o0000
00;ooooo0_l0000:ooooo`;o000000?oooooo`000?l000000oooool4o`0000Kooooo0_l00002oooo
o`Ko000000?oooooo`000?l000001_ooool2o`0000cooooo0_l00003ooooo`?o00001?ooool2o`00
00Cooooo1?l0000=ooooo`;o00003Oooool4o`000003ooooool0003o000000;o00000_oooolNo`00
0003ooooool0003o000000;ooooo0_l0000:ooooo`;o00001?ooool2o`0000Oooooo0_l000000ooo
oooo0000o`000004ooooo`;o0000@Oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo03Kooooo1?l0
00001Ooooooo0000o`000?l0003ooooo00;o00000_ooool2o`0000Oooooo0_l000000ooooooo0000
o`000008ooooo`;o000000?oooooo`000?l000000oooool4o`000003ooooool0003o000000?o0000
0_ooool2o`000003ooooool0003o000000?ooooo1?l00002ooooo`;o00002oooool2o`0000?ooooo
0ol00003ooooo`;o000000?oooooo`000?l000001Oooool2o`0000;ooooo0_l00002ooooo`;o0000
3_ooool3o`000003ooooool0003o000000Sooooo6_l00002ooooo`;o00003Oooool4o`0000?ooooo
0_l000000ooooooo0000o`000006ooooo`Co0000AOooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
=_ooool4o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`?o00001_ooool2o`0000_ooooo
0_l000000ooooooo0000o`000003ooooo`Co00000oooool4o`000004ooooool0003o0000ooooo`;o
00000oooool4o`0000;ooooo0_l0000@ooooo`;o00001?ooool2o`0000Cooooo0_l00002ooooo`?o
000000?oooooo`000?l000002?ooool2o`0000Sooooo0_l0000<oooooaSo00000_ooool4o`000003
ooooool0003o000000cooooo1?l000000ooooooo0000o`000003o`0000;ooooo0_l00004ooooo`;o
0000AOooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oV9RH
oooooonHV9So8B4Q00Kooooo0ol0000nooooo`;o00000oooool3o`0000cooooo0ol00004ooooo`Ko
00002Oooool4o`0000;ooooo0_l0000Yooooo`;o00000oooool2o`0000_ooooo0_l00008ooooo`;o
00003?ooool>o`000003ooooool0003o000000Ko00000oooool3o`0000;ooooo0_l00006ooooo`?o
00001Oooool2o`0000;ooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l00015oooo
o`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`01_ooool00ol0003oooooooooo`0nooooo`;o00004_ooool3o`0000Kooooo1?l00006oooo
o`;o000000?oooooo`000?l000001?ooool2o`0002oooooo0_l00004ooooo`;o00001?ooool2o`00
00Sooooo0_l00004ooooo`;o00001oooool3o`000003ooooool0003o0000013o00000oooool2o`00
00_ooooo0ol00002ooooo`;o00003_ooool2o`0004Sooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`0dooooo`;o
00001?ooool2o`0001cooooo0_l00002ooooo`;o00001oooool2o`000003ooooool0003o000002;o
oooo0_l00002ooooo`;o00001oooool2o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`0000ko
oooo0_l00007ooooo`;o000000?oooooo`000?l000004ol0000Booooo`?o00003Oooool2o`0000co
oooo0_l0000kooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH
00Sooooo00?o0000ooooooooool0=?ooool2o`0000Cooooo0_l00007ooooo`;o00002?ooool2o`00
00Wooooo0_l00002ooooo`Co00004_ooool2o`00013ooooo0_l00006ooooo`;o00000_ooool4o`00
0003ooooool0003o000000Co000000Coooooo`000?l0003ooooo0_l0000@ooooo`Ko00003_ooool4
o`000004ooooool0003o0000ooooo`So00000_ooool5o`0001;ooooo0_l0000=ooooo`?o00003?oo
ool2o`0000_ooooo0_l0000^ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`04olc<
c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0@oooool2o`0000Cooooo0_l00002ooooo`;o
00000_ooool2o`0000Cooooo0_l00005ooooo`;o00004_ooool2o`0000;ooooo1?l0000:ooooo`Co
00002_ooool2o`000003ooooool0003o000000[o00000_ooool2o`0000cooooo1_l0000>ooooo`;o
000000?oooooo`000?l000001_l00002ooooo`;o00000oooool4o`0000_ooooo0_l00004ooooo`;o
00003Oooool7o`0000Wooooo0_l0000<ooooo`;o0000;_ooool001cooooo00?o0000ooooooooool0
BOooool2o`0000Kooooo0_l00004ooooo`;o00002?ooool2o`0001?ooooo1_l0000:ooooo`;o0000
0_ooool2o`0000Kooooo4ol0000Sooooo`co00000oooool2o`0000Wooooo0_l00002ooooo`;o0000
1?ooool2o`0000cooooo0ol000000ooooooo0000o`000002o`0000Oooooo1?l0000looooo`007?oo
ool00ol0003oooooooooo`0nooooo`Co00001?ooool2o`0000?ooooo0_l000001?oooooo0000o`00
0?ooool3o`0000gooooo0_l0000@ooooo`;o00000oooool4o`0000Wooooo0_l00003ooooo`;o0000
1?oooolEo`0000Gooooo0_l0000>ooooo`;o00005?ooool3o`0000oooooo0_l0000Fooooo`;o0000
0oooool2o`0000Sooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0looooo`Ko00001?oo
ool2o`0000?ooooo0_l000000ooooooo0000o`000004o`0001kooooo0ol00003ooooo`;o00002ooo
ool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000004Ol0
0004ooooo`;o00003?ooool4o`0000gooooo0_l0000Jooooo`;o00005Oooool2o`00017ooooo0_l0
000hooooo`007?ooool00ol0003oooooooooo`0looooo`Co00002Oooool2o`0000Gooooo0_l00003
ooooo`Ko00001Oooool2o`0000Gooooo0_l000000ooooooo0000o`000002ooooo`?o000000?ooooo
o`000?l000000oooool2o`0000Oooooo0_l00006ooooo`;o00000_ooool2o`000005ooooool0003o
0000o`000?ooool05Ol0000@ooooo`;o00002_ooool2o`0000?ooooo0_l0000Booooo`;o00001_oo
ool2o`0000Kooooo0_l0000=ooooo`;o00002?ooool4o`0000Gooooo0_l0000hooooo`007?ooool0
0ol0003oooooooooo`15ooooo`;o00000_ooool2o`0000Cooooo0_l00004ooooo`Ko00001Oooool2
o`0000Gooooo0_l000000ooooooo0000o`000002ooooo`?o00001_ooool4o`0000Gooooo0_l00004
ooooo`;o00001ooooolIo`0000Oooooo0_l00004ooooo`;o00003Oooool3o`0000;ooooo0_l0000B
ooooo`;o00003_ooool2o`0001Oooooo1?l00002ooooo`;o0000>oooool001cooooo00?o0000oooo
ooooool0AOooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000002oooo
o`;o00002_ooool2o`0000Sooooo0_l0000>ooooo`;o00001Oooool4o`0000;ooooo0_l00008oooo
oaOo00002?ooool2o`000004ooooool0003o0000ooooo`?o00003Oooool2o`0000;ooooo0_l00004
ooooo`;o00002_ooool2o`0001Cooooo1_l0000Dooooo`?o0000>oooool001cooooo00?o0000oooo
ooooool0@?ooool2o`0000Kooooo0_l00002ooooo`;o00001Oooool2o`0000;ooooo0_l000000ooo
oooo0000o`000003ooooo`;o00002?ooool2o`0000Kooooo0_l0000;ooooo`Ko00001_ooool2o`00
00?ooooo6?l000001?oooooo0000o`000?l00007ooooo`;o00000_ooool2o`0001Cooooo0_l00000
0ooooooo0000o`00000:ooooo`;o00001Oooool3o`0000_ooooo1ol00004ooooo`;o00003_ooool2
o`0003cooooo000Looooo`03o`000?oooooooooo03Kooooo0_l00008ooooo`;o00004oooool4o`00
0003ooooool0003o000000kooooo0_l00005ooooo`;o000000?oooooo`000?l000001?ooool2o`00
00;ooooo0_l00007ooooo`;o000000?oooooo`000?l000000_oooolNo`0000Cooooo0ol0000;oooo
o`;o00001_ooool2o`0000Cooooo0_l000001?oooooo0000o`000?l0000?ooooo`Co00002oooool2
o`000003ooooool0003o000000Kooooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`0foooo
o`;o00002?ooool2o`0000Sooooo0_l00009ooooo`;o00000oooool2o`0000?ooooo1?l00007oooo
o`;o00002?ooool2o`0000?ooooo1?l0000:ooooo`;o00001Oooool2o`000003ooooool0003o0000
01Wo00001?ooool3o`000003ooooool0003o000000Cooooo0_l00002ooooo`Co00001?ooool3o`00
00Oooooo0_l0000?ooooo`;o00002oooool4o`0000Sooooo0_l0000<ooooo`;o0000?oooool001co
oooo00?o0000ooooooooool0@?ooool2o`0000;ooooo0ol00003ooooo`;o00003_ooool2o`0000;o
oooo1Ol00005ooooo`;o00003_ooool5o`0001Cooooo5ol000000ooooooo0000o`000008ooooo`?o
00000oooool3o`0000Cooooo0_l00005ooooo`;o00001_ooool2o`0000Cooooo0_l0000Gooooo`Co
00000oooool2o`0000?ooooo0_l00006ooooo`;o00001?ooool2o`0003oooooo000Looooo`03o`00
0?oooooooooo04Cooooo0ol00006ooooo`;o00002oooool3o`000003ooooool0003o000000Gooooo
0_l000000ooooooo0000o`000004ooooo`;o00002?ooool3o`0001Gooooo3_l000000ooooooo0000
o`000007o`000004ooooool0003o0000ooooo`;o00001Oooool2o`0000Cooooo0_l0000Dooooo`;o
000000Coooooo`000?l0003ooooo0_l0000Iooooo`;o000000?oooooo`000?l000000_l0000;oooo
o`;o00001?ooool2o`000003ooooool0003o000003cooooo000Looooo`;o0000@?ooool2o`0000co
oooo0_l0000<ooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`?o
00000oooool2o`0001Wooooo3ol000000ooooooo0000o`00000;o`000003ooooool0003o000000_o
oooo0_l00004ooooo`;o00001Oooool2o`0000[ooooo0_l0000;ooooo`;o00003oooool2o`000003
ooooool0003o000001Kooooo0_l0000looooo`007?ooool00ol0003oooooooooo`0oooooo`;o0000
6oooool2o`000003ooooool0003o000000Kooooo0ol00003ooooo`;o00001?ooool2o`0000Kooooo
0_l00006ooooo`;o00001?ooool2o`0000?ooooo0_l00002oooooa7o000000?oooooo`000?l00000
1Ol0000Dooooo`;o00001Oooool2o`0000[ooooo0_l0000:ooooo`?o00002oooool2o`0000Gooooo
0_l0001Dooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00006?ooool2o`000003ooooool0
003o000000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00002oooool2o`000003ooooool0
003o000000;ooooo0_l00005ooooo`?o00001?ooool2o`0000Kooooo6Ol0000Hooooo`Co00003ooo
ool2o`0000Gooooo1?l0000<ooooo`;o0000Foooool001cooooo00?o0000ooooooooool0?oooool4
o`000003ooooool0003o000000?ooooo0_l00006ooooo`;o00001_ooool2o`0000Gooooo0_l00000
0ooooooo0000o`00000?ooooo`;o000000Coooooo`000?l0003o00002?ooool4o`0000Cooooo0_l0
0003oooooaco000000?oooooo`000?l000001Oooool2o`0000Oooooo0_l00004ooooo`Co000000?o
ooooo`000?l000003?ooool2o`0000Gooooo0_l00008ooooo`;o00007?ooool2o`0004?ooooo000L
ooooo`03o`000?oooooooooo043ooooo0ol000000ooooooo0000o`000003ooooo`;o00001_ooool2
o`0000Oooooo0_l0000Looooo`;o00002_ooool4o`0000;ooooo0_l00003oooooaco000000?ooooo
o`000?l000000oooool4o`0000Cooooo1Ol00009ooooo`;o00003_ooool2o`0000gooooo0_l0000L
ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0>Oooool2o`0000Gooooo0ol00007oooo
o`;o00003_ooool2o`0000[ooooo0_l0000Nooooo`;o00002OoooolCo`000003ooooool0003o0000
00;o00002?ooool2o`0000Kooooo1Ol000000ooooooo0000o`00000Dooooo`Co0000L?ooool001co
oooo00?o0000ooooooooool0>Oooool2o`0000Oooooo0_l00006ooooo`;o00003?ooool3o`0000?o
oooo0_l00006ooooo`;o00000_ooool2o`0000;ooooo0_l0000Jooooo`;o00001OoooolDo`000005
ooooool0003o0000o`000?ooool00_l00002ooooo`Go00001oooool2o`0000?ooooo0ol0000Coooo
o`;o00001_ooool2o`000003ooooool0003o000000kooooo0_l0000:ooooo`;o0000Boooool001co
oooo00?o0000ooooooooool0=_ooool2o`0000[ooooo0_l0000Dooooo`Go000000?oooooo`000?l0
00001oooool2o`000003ooooool0003o000000;ooooo0_l0000Jooooo`;o00001Oooool4o`000003
ooooool0003o000000ko00001?ooool2o`0000;ooooo1Ol0000=ooooo`;o00003Oooool2o`0000co
oooo0_l000000ooooooo0000o`000007ooooo`;o00001?ooool3o`0000[ooooo0_l0001;ooooo`00
7?ooool00ol0003oooooooooo`0fooooo`;o00002_ooool2o`0000Oooooo0_l0000:ooooo`;o0000
0_ooool4o`0000Oooooo1_l0000Voooooa[o000000?oooooo`000?l000000_l0000>ooooo`;o0000
3_ooool2o`000003ooooool0003o000001Gooooo0_l00004ooooo`?o00003oooool2o`0004Kooooo
000Looooo`03o`000?oooooooooo04;ooooo0_l00005ooooo`Co00002_ooool3o`0000?ooooo0ol0
0006ooooo`;o000000Coooooo`000?l0003o00000oooool2o`0000oooooo0_l00008ooooo`;o0000
2?oooolHo`000003ooooool0003o000000;o00002oooool5o`00017ooooo0_l00002ooooo`;o0000
2?ooool2o`0000Oooooo0_l0000Dooooo`Co0000A_ooool001cooooo00?o0000ooooooooool0BOoo
ool3o`0000Oooooo0_l00003ooooo`;o00001?ooool2o`0000Sooooo1?l00002ooooo`Go00003Ooo
ool2o`0000Sooooo0_l00008oooooa7o00001oooool2o`0000kooooo0ol00008ooooo`Co00000_oo
ool2o`0000Oooooo0_l00008ooooo`;o00001oooool3o`0000;ooooo0_l0000?ooooo`;o0000B?oo
ool001cooooo00?o0000ooooooooool0B_ooool4o`0000Gooooo0_l00006ooooo`;o00002oooool4
o`0000;ooooo0_l000000ooooooo0000o`00000Hooooo`;o00002_ooool>o`0000Oooooo1?l00009
ooooo`Co00001_ooool3o`000003ooooool0003o000000;o00000_ooool2o`0000Gooooo0_l0000D
ooooo`;o00000_ooool4o`0000Gooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`15oooo
o`;o00000oooool4o`0000Cooooo0_l00007ooooo`;o00000_ooool2o`0000Oooooo1?l0000Boooo
o`;o00002oooool2o`0000Kooooo0_l00002ooooo`ko00002Oooool2o`0000Wooooo1Ol00005oooo
o`?o000000?oooooo`000?l000000_ooool2o`0000Kooooo1?l000000ooooooo0000o`000005oooo
o`Co00001?ooool2o`000003ooooool0003o000000Cooooo1?l00003ooooo`;o00001?ooool2o`00
04[ooooo000Looooo`03o`000?oooooooooo04?ooooo1?l00003ooooo`;o00001?ooool4o`0000_o
oooo0_l00005ooooo`;o00000_ooool2o`0001;ooooo0_l0000?ooooo`;o000000?oooooo`000?l0
00002Ol00003ooooo`;o00002Oooool2o`0000oooooo0_l0000=ooooo`;o00001_ooool7o`0000Go
oooo1?l00004ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Wooooo0_l0001:ooooo`00
7?ooool00ol0003oooooooooo`13ooooo`;o000000?oooooo`000?l000000_ooool4o`0000;ooooo
0_l0000=ooooo`;o00001Oooool2o`0001Gooooo0_l00008ooooo`;o00001_ooool2o`000004oooo
ool0003o0000ooooo`;o000000?oooooo`000?l000001Ol000000ooooooo0000o`000009ooooo`;o
00004_ooool2o`0000Kooooo0_l0000=ooooo`Co00003oooool3o`0005gooooo000Looooo`03o`00
0?oooooooooo04Kooooo0_l00004ooooo`;o00006?ooool2o`0001Cooooo0ol00005ooooo`;o0000
00Coooooo`000?l0003ooooo0_l00009ooooo`;o00000oooool5o`000003ooooool0003o000001go
oooo0_l00003ooooo`;o000000Coooooo`000?l0003o00003?ooool4o`0000Kooooo0_l00004oooo
o`;o000000?oooooo`000?l000000_ooool2o`0000kooooo0_l0001:ooooo`007?ooool2o`0004Ko
oooo0_l000001?oooooo0000o`000?l0000Hooooo`;o00005oooool2o`000003ooooool0003o0000
00?ooooo0_l00003ooooo`?o00000_ooool2o`0000;ooooo0_l00006ooooo`Go00002?ooool2o`00
01_ooooo0_l00002ooooo`;o00003?ooool5o`0000Gooooo0_l00004ooooo`;o00000oooool4o`00
00kooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`15ooooo`;o000000Coooooo`000?l0
003o00006?ooool2o`0000Wooooo0_l000000ooooooo0000o`00000<ooooo`;o00002?ooool2o`00
0003ooooool0003o000000;o00000_ooool4o`0000Sooooo0_l00003ooooo`;o00000_ooool2o`00
01oooooo0_l00009ooooo`;o00001?ooool2o`0000Oooooo0_l00007ooooo`;o00001?ooool2o`00
05Kooooo000Looooo`03o`000?oooooooooo04Wooooo0_l0000Nooooo`;o000000?oooooo`000?l0
00000_l000000ooooooo0000o`00000Iooooo`;o000000Coooooo`000?l0003o00000_ooool2o`00
00Sooooo0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o000000?ooooo0_l0000Foooo
o`?o00000oooool2o`0000Cooooo0_l00002ooooo`;o00002Oooool3o`0000?ooooo0_l00007oooo
o`;o0000E_ooool001cooooo00?o0000ooooooooool0BOooool4o`0000?ooooo0_l0000Eooooo`Co
000000?oooooo`000?l000001Oooool2o`00017ooooo0_l00007ooooo`?o00005Oooool2o`000003
ooooool0003o000000?ooooo0_l0000Fooooo`;o00001?ooool2o`0000Kooooo1?l0000:ooooo`?o
00000_ooool2o`0000cooooo0_l000000ooooooo0000o`00001>ooooo`007?ooool00ol0003ooooo
ooooo`1:ooooo`?o00000oooool3o`0000cooooo0_l00006ooooo`;o00000oooool2o`0000Gooooo
0_l00005ooooo`Co00002?ooool2o`0000Sooooo0_l0000Gooooo`;o00009?ooool3o`0000?ooooo
0_l0000<ooooo`Go00003_ooool2o`000003ooooool0003o000004kooooo000Looooo`03o`000?oo
oooooooo057ooooo0_l0000<ooooo`;o00001_ooool4o`000003ooooool0003o000000[ooooo1_l0
000=ooooo`;o000000?oooooo`000?l000001?l0000?ooooo`;o00001?ooool2o`0001;ooooo0_l0
000<ooooo`;o00000_ooool3o`0001Cooooo0_l0000=ooooo`;o0000D_ooool001cooooo00?o0000
ooooooooool0Aoooool2o`000003ooooool0003o000000?ooooo0_l0000>ooooo`;o00000oooool2
o`0000?ooooo0_l00003ooooo`?o00000_ooool3o`0000;ooooo0_l00002ooooo`?o00000oooool2
o`0000Oooooo0_l000000ooooooo0000o`000005o`0000Gooooo0_l00007ooooo`;o00000oooool2
o`0000Oooooo0_l0000:ooooo`;o00003?ooool2o`0002Sooooo0_l0001Booooo`007?ooool00ol0
003oooooooooo`16ooooo`?o000000?oooooo`000?l000000oooool2o`0000Kooooo0_l00005oooo
o`?o00000oooool2o`0000Sooooo0ol000000ooooooo0000o`000002o`0000?ooooo0_l000001?oo
oooo0000o`000?l00003ooooo`;o00003?ooool6o`000004ooooool0003o0000ooooo`?o00001_oo
ool2o`0000?ooooo0_l00003ooooo`Ko00002?ooool2o`0001Oooooo0_l0000:ooooo`;o000000?o
ooooo`000?l00000I?ooool001cooooo00?o0000ooooooooool0A_ooool2o`0000Gooooo0_l00003
ooooo`;o00000oooool2o`0000Gooooo0_l0000Booooo`;o00000_ooool2o`000003ooooool0003o
000000?ooooo0_l00002ooooo`;o00001oooool2o`0000;ooooo0_l00003ooooo`Go00000_ooool2
o`0000[ooooo0_l00002ooooo`Ko00002_ooool2o`0001Kooooo0ol00009ooooo`?o000000?ooooo
o`000?l00000I?ooool001cooooo00?o0000ooooooooool0BOooool3o`000003ooooool0003o0000
00;o000000?oooooo`000?l000000oooool2o`0001;ooooo0ol00008ooooo`;o000000?oooooo`00
0?l000000oooool2o`0000Sooooo0_l000001Ooooooo0000o`000?l0003ooooo00Co00000_ooool2
o`00013ooooo0_l000000ooooooo0000o`000004o`000003ooooool0003o000000?ooooo0_l00000
0ooooooo0000o`000002o`0001;ooooo0_l00002ooooo`?o00002Oooool2o`0006Sooooo000Loooo
o`03o`000?oooooooooo04Wooooo0ol00003ooooo`;o00005?ooool2o`0000;ooooo1Ol00005oooo
o`;o00004oooool2o`000004ooooool0003o0000o`0000;ooooo0ol00005ooooo`;o00004?ooool6
o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l00006
ooooo`;o00001?ooool4o`0001gooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`19oooo
o`;o00003oooool2o`0000Wooooo0_l00002ooooo`?o00001oooool2o`0000Gooooo0_l0000@oooo
o`;o00002_ooool2o`000003ooooool0003o000001?ooooo0_l00002ooooo`;o00001_ooool2o`00
00?ooooo0_l00006ooooo`;o00001?ooool4o`0000Gooooo0_l00002ooooo`;o00000oooool2o`00
00gooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`19ooooo`?o00000oooool3o`0000So
oooo0_l0000@ooooo`;o00003?ooool2o`000003ooooool0003o000000gooooo0_l0000:ooooo`;o
000000Coooooo`000?l0003ooooo0_l00002ooooo`?o00001oooool2o`0000;ooooo0_l00002oooo
o`;o00000oooool2o`000003ooooool0003o000000Gooooo0_l00004ooooo`;o00001?ooool3o`00
00;ooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo0ol0001Vooooo`007?ooool00ol0003o
ooooooooo`1:ooooo`;o00000oooool3o`0001Gooooo0_l000000ooooooo0000o`000002o`0000Wo
oooo0_l00004ooooo`;o000000?oooooo`000?l000001oooool2o`0000gooooo0_l00004ooooo`;o
00000_ooool3o`0000;ooooo1?l000000ooooooo0000o`000008ooooo`Go00002?ooool2o`0000;o
oooo1?l00009ooooo`;o00002_ooool2o`0001Sooooo0_l0001=ooooo`007?ooool00ol0003ooooo
ooooo`1Wooooo`Go00001_ooool2o`0000;ooooo0ol00007ooooo`;o00001oooool2o`0000_ooooo
0_l00009ooooo`ko00001oooool4o`0000Wooooo0_l00002ooooo`;o00001_ooool2o`0000Wooooo
0_l0000Nooooo`;o0000COooool001cooooo00?o0000ooooooooool0B_ooool2o`000003ooooool0
003o000000Sooooo0_l0000=ooooo`Go00001_ooool3o`0000;ooooo0_l00007ooooo`?o00004?oo
ool2o`0000;ooooo0_l00004ooooo`;o00000ooooolBo`0000?ooooo1?l00009ooooo`;o00000ooo
ool2o`000004ooooool0003o0000ooooo`Co00001oooool3o`0000Gooooo0_l0001Vooooo`007?oo
ool2o`0004Wooooo1?l000000ooooooo0000o`000008ooooo`;o00003Oooool2o`000003ooooool0
003o000000Kooooo0_l0000:ooooo`Co00004Oooool2o`0000Sooooo0_l0000>ooooo`oo00003Ooo
ool2o`000004ooooool0003o0000ooooo`Co00001oooool2o`0000Kooooo0_l0001Vooooo`007?oo
ool00ol0003oooooooooo`18ooooo`;o00001_ooool2o`0000Wooooo0_l0000<ooooo`?o00004?oo
ool3o`000003ooooool0003o000000Gooooo0_l0000?ooooo`Co000000Coooooo`000?l0003ooooo
0_l0000:ooooo`Co00000_ooool6o`000003ooooool0003o000001Gooooo0_l0001gooooo`007?oo
ool00ol0003oooooooooo`1@ooooo`;o00002Oooool4o`0000_ooooo0_l0000@ooooo`;o00000_oo
ool2o`0000Gooooo0_l0000=ooooo`Ko000000Coooooo`000?l0003ooooo0_l00005ooooo`;o0000
1Oooool3o`0000?ooooo0_l00003ooooo`;o00002oooool2o`0001[ooooo0_l000000ooooooo0000
o`00000=ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0G?ooool4o`00023ooooo0_l0
000<ooooo`;o00001_ooool2o`0000oooooo0_l00006ooooo`;o00000_ooool4o`000004ooooool0
003o0000o`0000Sooooo0_l000000ooooooo0000o`000006ooooo`;o00004_ooool2o`000003oooo
ool0003o000000gooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o00001?oo
ool2o`000003ooooool0003o000000?ooooo0_l0000;ooooo`;o00002?ooool2o`000003ooooool0
003o000000cooooo0_l00006ooooo`;o000000?oooooo`000?l000003?ooool2o`0000Sooooo1_l0
00000ooooooo0000o`000006o`0000?ooooo0_l00009ooooo`;o00001_ooool2o`00017ooooo0_l0
001Nooooo`007?ooool00ol0003oooooooooo`1Fooooo`Co00001oooool2o`0000?ooooo0_l00004
ooooo`;o00000oooool4o`0000Sooooo0_l0000Fooooo`;o00000_ooool2o`0000Wooooo0_l00000
1?oooooo0000o`000?l00007ooooo`;o00001oooool6o`0000[ooooo0ol000000ooooooo0000o`00
0006ooooo`;o00002_ooool2o`000003ooooool0003o000000;ooooo0_l0001Nooooo`007?ooool0
0ol0003oooooooooo`1Fooooo`Co00000oooool2o`0000gooooo0_l00003ooooo`;o00002?ooool2
o`0001Sooooo0_l0000=ooooo`;o00000_ooool2o`0000Sooooo0_l00002ooooo`Ko00003_ooool4
o`0001Cooooo0_l000000ooooooo0000o`00001Rooooo`007?ooool00ol0003oooooooooo`1Goooo
o`?o00000oooool2o`0000Gooooo1Ol0000;ooooo`;o00001Oooool2o`00013ooooo0_l0000Foooo
o`;o00002oooool3o`000003ooooool0003o000000;o00001oooool2o`0000Wooooo0_l00004oooo
o`;o00006_ooool2o`0005Wooooo000Looooo`03o`000?oooooooooo05kooooo0_l00004ooooo`Go
000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000002ooooo`;o00001oooool2o`00
00kooooo0_l00002ooooo`?o000000?oooooo`000?l000003_ooool2o`0000_ooooo0ol00008oooo
o`;o00000_ooool2o`0000gooooo1?l000000ooooooo0000o`000002ooooo`;o00004oooool2o`00
05Wooooo000Looooo`03o`000?oooooooooo05kooooo0_l0000:ooooo`;o000000Coooooo`000?l0
003ooooo0_l0000;ooooo`;o00001_ooool2o`0000Oooooo0_l000001Ooooooo0000o`000?l0003o
oooo00;o00004oooool2o`0000Kooooo0_l00004ooooo`;o00000oooool2o`000003ooooool0003o
000000kooooo0_l00003ooooo`;o00000_ooool2o`0006kooooo000Looooo`03o`000?oooooooooo
06Wooooo0ol00007ooooo`Co00003_ooool2o`000003ooooool0003o000000Cooooo0_l00005oooo
o`;o00001?ooool2o`0000gooooo0_l0000<ooooo`;o00000oooool5o`0008Oooooo000Looooo`03
o`000?oooooooooo063ooooo0_l00007ooooo`?o00001oooool4o`0000Oooooo0_l00008ooooo`;o
00001Oooool2o`0000[ooooo0_l0000>ooooo`Co00000_ooool2o`0000Wooooo1?l00003ooooo`;o
00001?ooool2o`0007kooooo000Looooo`03o`000?oooooooooo063ooooo0_l0000Looooo`;o0000
3oooool4o`0001Sooooo1?l00002ooooo`;o00002Oooool4o`0000?ooooo0ol00003ooooo`;o0000
O_ooool001cooooo00?o0000ooooooooool0L?ooool4o`0000[ooooo0_l000000ooooooo0000o`00
0002ooooo`Co00002?ooool2o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`;o00000_oo
ool2o`0000Gooooo0_l000000ooooooo0000o`00000@ooooo`Go000000?oooooo`000?l00000Pooo
ool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o
8B4Qolc<c006ooooo`03o`000?oooooooooo06Sooooo0_l00006ooooo`Co00002_ooool2o`000003
ooooool0003o000000;ooooo1?l00006ooooo`;o00001?ooool2o`000004ooooool0003o0000o`00
00?ooooo0ol000001?oooooo0000o`000?l00004ooooo`;o000000?oooooo`000?l000002Oooool2
o`0000Oooooo0ol00005ooooo`;o0000Ooooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Ooo
ool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo06Sooooo
0ol00002ooooo`;o00001Oooool4o`0001?ooooo0_l00002ooooo`;o00001oooool3o`0000Cooooo
0_l000001?oooooo0000o`000?l0000Booooo`;o00003oooool2o`0000Sooooo0_l0001eooooo`00
00?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`1Yooooo`;o00000_ooool2o`0000Gooooo1?l00009ooooo`;o
00002?ooool2o`0000_ooooo0_l00008ooooo`;o00001?ooool5o`0001Wooooo0_l000000ooooooo
0000o`000003ooooo`;o00000_ooool2o`000003ooooool0003o000007;ooooo00000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o
0000MOooool2o`0000[ooooo0_l0000?ooooo`;o00001?ooool2o`0000kooooo1_l0000;ooooo`;o
00002?ooool2o`000004ooooool0003o0000ooooo`;o00000oooool2o`0000Gooooo0_l0001boooo
o`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05olc<c?l0003o0000o`00
0?o<c<`01_ooool00ol0003oooooooooo`1Kooooo`;o00006?ooool4o`0000Sooooo0_l0000?oooo
o`;o00003_ooool2o`0000Sooooo0_l0000;ooooo`;o00002?ooool2o`000003ooooool0003o0000
087ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go410@okZj^_oo
oooo^[Zjoa0@4006ooooo`03o`000?oooooooooo05_ooooo0_l0000Fooooo`;o00000_ooool2o`00
00Gooooo0_l000001?oooooo0000o`000?ooool2o`0001Gooooo0_l00005ooooo`;o00001Oooool2
o`0001_ooooo1?l0001oooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj
^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`1cooooo`;o00002Oooool2o`0000Cooooo
0_l00006ooooo`;o00003Oooool2o`0000cooooo1?l0000;ooooo`;o00003_ooool4o`0007gooooo
00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06oooo
o`03o`000?oooooooooo08cooooo0_l000000ooooooo0000o`00000Jooooo`;o00001_ooool2o`00
00?ooooo0_l0000>ooooo`Co0000OOooool001cooooo00?o0000ooooooooool0L?ooool2o`0001;o
oooo0_l00009ooooo`;o00001Oooool2o`0000gooooo0_l0000<ooooo`;o0000U?ooool001cooooo
00?o0000ooooooooool0L?ooool2o`0001;ooooo0_l0000@ooooo`;o00001_ooool2o`0000Gooooo
0_l00006ooooo`Go00000_ooool2o`0000Cooooo0_l0002=ooooo`007?ooool00ol0003ooooooooo
o`25ooooo`;o00001_ooool2o`0000Oooooo0_l00002ooooo`;o00000_ooool2o`0000Oooooo0_l0
0004ooooo`Go00000_ooool2o`0000?ooooo0ol00004ooooo`;o000000?oooooo`000?l000000_oo
ool2o`00083ooooo000Looooo`03o`000?oooooooooo08Gooooo0_l00006ooooo`;o00001_ooool3
o`0000;ooooo0_l000000ooooooo0000o`000007ooooo`?o00001Oooool3o`0000;ooooo0_l00004
ooooo`;o00001Oooool2o`000003ooooool0003o000000;ooooo0_l0000Booooo`;o0000K?ooool0
01cooooo00?o0000ooooooooool0P?ooool2o`0000;ooooo0_l0000:ooooo`;o00000oooool2o`00
00Kooooo0_l00007ooooo`;o00000oooool2o`000003ooooool0003o000000?ooooo0_l0000Voooo
o`;o0000K?ooool001cooooo00?o0000ooooooooool0P?ooool6o`0000Kooooo0_l00002ooooo`;o
00002oooool2o`0000cooooo0_l0002Looooo`007?ooool00ol0003oooooooooo`22ooooo`Co0000
1_ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000001oooool2o`0000cooooo
0_l0000[ooooo`;o0000Koooool001cooooo00?o0000ooooooooool0Q?ooool2o`0000Wooooo1?l0
00000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Kooooo0_l0
000Uooooo`;o00001?ooool2o`0006oooooo000Looooo`03o`000?oooooooooo067ooooo0_l0000V
ooooo`;o00001Oooool2o`0000;ooooo2Ol00006ooooo`;o00001_ooool2o`0002Gooooo0_l0001e
ooooo`007?ooool00ol0003oooooooooo`1Qooooo`;o00009_ooool2o`0000Wooooo1?l00002oooo
o`;o0000[Oooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`0008kooooo
0_l0000:ooooo`;o00006_ooool2o`0009;ooooo000Looooo`03o`000?oooooooooo08gooooo0_l0
000:ooooo`;o00006_ooool2o`00013ooooo1?l0001nooooo`007?ooool00ol0003oooooooooo`2n
ooooo`;o00001oooool4o`0007kooooo000Looooo`03o`000?oooooooooo0;Kooooo0_l00006oooo
o`;o0000ROooool001cooooo00?o0000ooooooooool0]_ooool2o`0000Wooooo0_l00026ooooo`00
7?ooool00ol0003oooooooooo`31ooooo`;o0000Q_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`2mooooo`;o0000R_ooool001cooooo00?o0000oooo
ooooool0_Oooool2o`0008[ooooo000Looooo`03o`000?oooooooooo0;gooooo0_l0002:ooooo`00
7?ooool00ol0003oooooooooo`2mooooo`;o0000R_ooool001cooooo00?o0000ooooooooool0QOoo
ool2o`000<;ooooo000Looooo`03o`000?oooooooooo08Gooooo0_l00032ooooo`007?ooool00ol0
003oooooooooo`2hooooo`;o0000Soooool001cooooo00?o0000ooooooooool0^?ooool4o`0008go
oooo000Looooo`03o`000?oooooooooo07kooooo0_l0000jooooo`;o0000SOooool001cooooo0_l0
001oooooo`;o0000bOooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0:kooooo0_l0002Iooooo`007?ooool00ol0003oooooooooo`2^oooo
o`;o0000VOooool001cooooo00?o0000ooooooooool0YOooool2o`000:;ooooo000Looooo`03o`00
0?oooooooooo09Gooooo0_l0000>ooooo`;o0000X_ooool001cooooo00?o0000ooooooooool0UOoo
ool2o`000;;ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2
o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooo
oom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool0
01Cooooo00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o0000oooooooo
ool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oo
oooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`004_ooool00omE
EEGoIVIVo`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Q
ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05_ooool4o`000004oa0@4?oo
ooooooooooooo`Co000000Co410@oooooooooooooooo1?l000002?l@413oooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^S?ooool00:;ooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00003?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg08cooooo002Rooooo`05o`000?ooooooooooooooool00000
6oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@08cooooo002Rooooo`05o`000?ooooooooooooooool0
00002Oooool6o`0000cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00002<ooooo`00X_ooool01Ol0003o
QhN7oooooonYZJWo000001_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00002<ooooo`00XOooool00ol@
413o0000ogMgM`02o`000003oiRHV?oooooooooo01Wooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@402<
ooooo`00`_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg08cooooo0030ooooo`03oeEEEOmVIVKo0000
00Gooooo00?oEEEEofIVI_l000001Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h0S?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1116) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.30327 .49003 Mdot
.32781 .50782 Mdot
.65625 .60735 Mdot
.50874 .38385 Mdot
.27814 .69731 Mdot
.61912 .59213 Mdot
.44305 .65068 Mdot
.49283 .63191 Mdot
.64564 .60096 Mdot
.29774 .60072 Mdot
.44805 .64921 Mdot
.45282 .44436 Mdot
.45959 .64473 Mdot
.48874 .38901 Mdot
.16137 .57858 Mdot
.51084 .4266 Mdot
.32744 .55212 Mdot
.64187 .42479 Mdot
.55139 .35141 Mdot
.59274 .59926 Mdot
.28264 .54192 Mdot
.4974 .38233 Mdot
.3461 .48557 Mdot
.48799 .38883 Mdot
.52396 .38413 Mdot
.30724 .533 Mdot
.33992 .56002 Mdot
.51184 .33705 Mdot
.52921 .39563 Mdot
.48653 .62488 Mdot
.61901 .31203 Mdot
.19055 .63649 Mdot
.52298 .31227 Mdot
.5656 .79744 Mdot
.49377 .64065 Mdot
.3054 .44074 Mdot
.62342 .57642 Mdot
.48387 .64158 Mdot
.48997 .64957 Mdot
.43593 .64862 Mdot
.47605 .65412 Mdot
.3086 .5227 Mdot
.45428 .59301 Mdot
.4775 .57578 Mdot
.53387 .40814 Mdot
.3263 .69758 Mdot
.46768 .22059 Mdot
.47001 .34074 Mdot
.31738 .54966 Mdot
.70219 .58565 Mdot
.48075 .76379 Mdot
.44371 .66136 Mdot
.62273 .55293 Mdot
.6564 .85099 Mdot
.48173 .63215 Mdot
.54586 .39309 Mdot
.64212 .5828 Mdot
.49051 .37459 Mdot
.48377 .38586 Mdot
.24772 .37326 Mdot
.50084 .32129 Mdot
.65028 .44832 Mdot
.33293 .47527 Mdot
.57409 .46365 Mdot
.63938 .59054 Mdot
.48042 .65893 Mdot
.31979 .50023 Mdot
.46349 .63818 Mdot
.42094 .36352 Mdot
.58863 .56825 Mdot
.47273 .33967 Mdot
.46641 .66037 Mdot
.29034 .53702 Mdot
.48884 .34362 Mdot
.74834 .62268 Mdot
.18175 .3801 Mdot
.66523 .49229 Mdot
.27318 .41058 Mdot
.23448 .41216 Mdot
.73381 .52554 Mdot
.49051 .40885 Mdot
.65142 .25933 Mdot
.17151 .47746 Mdot
.36046 .49665 Mdot
.51957 .29927 Mdot
.59621 .52587 Mdot
.48962 .34882 Mdot
.26141 .62742 Mdot
.52346 .41059 Mdot
.76379 .64786 Mdot
.63912 .60552 Mdot
.33855 .52378 Mdot
.50831 .38645 Mdot
.51781 .33602 Mdot
.46978 .23545 Mdot
.44283 .34808 Mdot
.51351 .35164 Mdot
.2872 .52107 Mdot
.45521 .66861 Mdot
.49691 .44432 Mdot
.43556 .5986 Mdot
.65826 .58075 Mdot
.44656 .36316 Mdot
.60037 .56805 Mdot
.28897 .54115 Mdot
.49176 .33586 Mdot
.48894 .6607 Mdot
.45163 .37124 Mdot
.41534 .69704 Mdot
.32946 .50478 Mdot
.52188 .34218 Mdot
.64258 .45042 Mdot
.80291 .41133 Mdot
.34597 .52091 Mdot
.75615 .50079 Mdot
.49343 .41332 Mdot
.50598 .3583 Mdot
.32664 .51033 Mdot
.66422 .59504 Mdot
.24519 .60194 Mdot
.36207 .48735 Mdot
.43599 .65785 Mdot
.34737 .47725 Mdot
.49223 .29235 Mdot
.63346 .59968 Mdot
.54061 .75586 Mdot
.49866 .70181 Mdot
.61379 .28568 Mdot
.48905 .35434 Mdot
.34837 .63648 Mdot
.60915 .6124 Mdot
.32675 .52385 Mdot
.46179 .63441 Mdot
.56228 .39204 Mdot
.34541 .49709 Mdot
.45632 .62414 Mdot
.64494 .43572 Mdot
.58152 .71403 Mdot
.34949 .54018 Mdot
.44571 .57881 Mdot
.50532 .64834 Mdot
.43863 .65277 Mdot
.6228 .79011 Mdot
.31676 .50628 Mdot
.67255 .4519 Mdot
.47142 .62587 Mdot
.59551 .30831 Mdot
.54286 .36416 Mdot
.67925 .31424 Mdot
.57696 .1835 Mdot
.58249 .79624 Mdot
.63717 .7005 Mdot
.68791 .44695 Mdot
.4533 .67763 Mdot
.52904 .36749 Mdot
.30162 .53527 Mdot
.30371 .51959 Mdot
.48531 .32405 Mdot
.51601 .38371 Mdot
.47969 .33714 Mdot
.52604 .34358 Mdot
.22485 .37704 Mdot
.44914 .38696 Mdot
.52821 .1981 Mdot
.34225 .52669 Mdot
.51961 .36882 Mdot
.63886 .57176 Mdot
.47103 .30615 Mdot
.47473 .65739 Mdot
.49847 .37471 Mdot
.51084 .38075 Mdot
.50254 .31997 Mdot
.44504 .66319 Mdot
.18782 .59404 Mdot
.64587 .22262 Mdot
.22581 .65996 Mdot
.76865 .58652 Mdot
.60307 .59358 Mdot
.49615 .35068 Mdot
.65375 .4613 Mdot
.33908 .417 Mdot
.48135 .40425 Mdot
.847 .38195 Mdot
.51175 .36272 Mdot
.2425 .66393 Mdot
.43436 .30295 Mdot
.24234 .70408 Mdot
.6588 .28189 Mdot
.53168 .36284 Mdot
.55982 .30483 Mdot
.3932 .46282 Mdot
.49107 .58548 Mdot
.4736 .65311 Mdot
.64565 .57747 Mdot
.65356 .59563 Mdot
.44024 .68411 Mdot
.26777 .56118 Mdot
.54193 .30104 Mdot
.43014 .36204 Mdot
.59691 .5517 Mdot
.30362 .48231 Mdot
.67835 .43105 Mdot
.29513 .506 Mdot
.22273 .27787 Mdot
.46705 .74701 Mdot
.42905 .66958 Mdot
.64497 .47904 Mdot
.64079 .61796 Mdot
.64399 .56781 Mdot
.65959 .46919 Mdot
.4611 .36233 Mdot
.31455 .50373 Mdot
.53298 .82055 Mdot
.29082 .57461 Mdot
.59156 .81659 Mdot
.29184 .5312 Mdot
.3563 .5967 Mdot
.45344 .63085 Mdot
.61105 .5756 Mdot
.50829 .3553 Mdot
.46883 .36378 Mdot
.29183 .55649 Mdot
.47692 .34004 Mdot
.44857 .26642 Mdot
.50878 .34311 Mdot
.51174 .75739 Mdot
.66896 .4929 Mdot
.43973 .68334 Mdot
.6036 .27046 Mdot
.3267 .48628 Mdot
.74285 .40505 Mdot
.60797 .55863 Mdot
.31735 .41989 Mdot
.4628 .66187 Mdot
.64608 .44061 Mdot
.60446 .55691 Mdot
.67928 .43026 Mdot
.50815 .31004 Mdot
.65344 .62735 Mdot
.64546 .46457 Mdot
.22235 .4738 Mdot
.5391 .36211 Mdot
.22185 .37359 Mdot
.45838 .67547 Mdot
.36582 .49225 Mdot
.50204 .3224 Mdot
.59937 .58114 Mdot
.52268 .30983 Mdot
.63339 .68174 Mdot
.53829 .75616 Mdot
.67415 .61152 Mdot
.70495 .6205 Mdot
.65461 .43575 Mdot
.5754 .67117 Mdot
.36518 .61996 Mdot
.30927 .54929 Mdot
.44355 .37824 Mdot
.22668 .70357 Mdot
.47118 .62617 Mdot
.45578 .37385 Mdot
.55884 .77435 Mdot
.47356 .62998 Mdot
.48918 .37292 Mdot
.49139 .66979 Mdot
.3037 .51719 Mdot
.75554 .35708 Mdot
.32442 .5521 Mdot
.51627 .41292 Mdot
.48529 .66676 Mdot
.66699 .61274 Mdot
.31139 .53876 Mdot
.45693 .35783 Mdot
.50165 .33769 Mdot
.53771 .51049 Mdot
.52173 .36129 Mdot
.20537 .61676 Mdot
.51949 .34541 Mdot
.64677 .58166 Mdot
.45366 .33497 Mdot
.84129 .5626 Mdot
.50904 .69976 Mdot
.31855 .50084 Mdot
.66797 .6224 Mdot
.64879 .59918 Mdot
.7497 .46263 Mdot
.55153 .63296 Mdot
.48117 .41177 Mdot
.60034 .58837 Mdot
.72909 .36892 Mdot
.46784 .61579 Mdot
.43999 .37176 Mdot
.45679 .57068 Mdot
.70127 .5781 Mdot
.60688 .5503 Mdot
.55731 .39177 Mdot
.31263 .55797 Mdot
.50948 .38648 Mdot
.64432 .57015 Mdot
.2734 .51468 Mdot
.49347 .41765 Mdot
.39969 .53217 Mdot
.53621 .51041 Mdot
.44759 .62867 Mdot
.45498 .28386 Mdot
.45138 .35955 Mdot
.61083 .56951 Mdot
.31367 .49421 Mdot
.48519 .6172 Mdot
.31285 .53092 Mdot
.37862 .78499 Mdot
.41675 .69373 Mdot
.21555 .43789 Mdot
.65226 .41041 Mdot
.69095 .68786 Mdot
.27701 .73779 Mdot
.80717 .54067 Mdot
.69528 .37901 Mdot
.44289 .82248 Mdot
.64176 .57084 Mdot
.58164 .77219 Mdot
.65034 .59581 Mdot
.51468 .39975 Mdot
.63315 .59521 Mdot
.26982 .73501 Mdot
.51029 .34421 Mdot
.62844 .58891 Mdot
.75665 .40557 Mdot
.51626 .37574 Mdot
.3492 .51705 Mdot
.16977 .54111 Mdot
.81975 .54029 Mdot
.52581 .77738 Mdot
.63126 .62783 Mdot
.64808 .38288 Mdot
.51582 .35036 Mdot
.46164 .32445 Mdot
.32517 .54681 Mdot
.43721 .36433 Mdot
.68169 .43548 Mdot
.6431 .47733 Mdot
.44718 .48048 Mdot
.67325 .25751 Mdot
.438 .41907 Mdot
.31389 .5416 Mdot
.27711 .30689 Mdot
.74032 .63259 Mdot
.71182 .63857 Mdot
.47442 .68344 Mdot
.18758 .56094 Mdot
.40554 .32439 Mdot
.40984 .64085 Mdot
.50037 .58089 Mdot
.33926 .51442 Mdot
.19395 .6131 Mdot
.47539 .64961 Mdot
.38863 .25991 Mdot
.59447 .35908 Mdot
.46327 .3662 Mdot
.45504 .66097 Mdot
.43342 .42273 Mdot
.82067 .57797 Mdot
.42163 .20863 Mdot
.57377 .21781 Mdot
.50717 .4183 Mdot
.75553 .61253 Mdot
.50302 .36824 Mdot
.23518 .58744 Mdot
.51818 .34304 Mdot
.31871 .53544 Mdot
.26097 .59241 Mdot
.5017 .49449 Mdot
.60856 .20677 Mdot
.45456 .74041 Mdot
.68785 .44628 Mdot
.50615 .34852 Mdot
.46311 .36778 Mdot
.67149 .43216 Mdot
.35862 .51196 Mdot
.52708 .34441 Mdot
.73357 .40242 Mdot
.48127 .34762 Mdot
.48234 .64977 Mdot
.55178 .22291 Mdot
.36164 .55131 Mdot
.43258 .38564 Mdot
.289 .49529 Mdot
.44842 .62559 Mdot
.49143 .64398 Mdot
.50716 .43147 Mdot
.4364 .62616 Mdot
.50915 .37143 Mdot
.43239 .19344 Mdot
.35415 .52834 Mdot
.4444 .28156 Mdot
.34786 .48871 Mdot
.26654 .41804 Mdot
.49453 .65391 Mdot
.50416 .74735 Mdot
.51849 .44285 Mdot
.47102 .65022 Mdot
.40428 .67108 Mdot
.44162 .41982 Mdot
.4883 .42565 Mdot
.73867 .68021 Mdot
.64399 .62632 Mdot
.52918 .50146 Mdot
.49719 .63831 Mdot
.4547 .35284 Mdot
.43811 .387 Mdot
.44473 .63012 Mdot
.35945 .25688 Mdot
.78966 .46133 Mdot
.51341 .34251 Mdot
.32925 .53656 Mdot
.32419 .52458 Mdot
.49551 .42242 Mdot
.45261 .38148 Mdot
.62119 .61167 Mdot
.65769 .62851 Mdot
.61484 .62852 Mdot
.53444 .50953 Mdot
.50707 .75147 Mdot
.36224 .73714 Mdot
.43606 .64835 Mdot
.36964 .66702 Mdot
.77225 .6314 Mdot
.47815 .29834 Mdot
.60617 .61543 Mdot
.46449 .37931 Mdot
.5054 .38324 Mdot
.48256 .61467 Mdot
.53856 .77726 Mdot
.41331 .39951 Mdot
.35733 .52768 Mdot
.4964 .63036 Mdot
.57136 .39518 Mdot
.39798 .7243 Mdot
.64585 .45509 Mdot
.65358 .76321 Mdot
.46934 .66168 Mdot
.34394 .51301 Mdot
.4933 .66199 Mdot
.47044 .35945 Mdot
.55351 .3724 Mdot
.33085 .51506 Mdot
.65197 .47776 Mdot
.47964 .30947 Mdot
.4916 .37075 Mdot
.70298 .23271 Mdot
.77446 .60181 Mdot
.51784 .74299 Mdot
.52905 .3576 Mdot
.44403 .40337 Mdot
.66096 .4196 Mdot
.47708 .35122 Mdot
.49136 .32837 Mdot
.77499 .35576 Mdot
.46983 .71653 Mdot
.63287 .4486 Mdot
.37387 .26714 Mdot
.29448 .53552 Mdot
.21224 .67706 Mdot
.60745 .5772 Mdot
.43069 .63435 Mdot
.79735 .45197 Mdot
.65674 .57711 Mdot
.66291 .68216 Mdot
.20556 .66238 Mdot
.52563 .50302 Mdot
.69874 .4923 Mdot
.43014 .43268 Mdot
.50424 .32966 Mdot
.50214 .36416 Mdot
.65777 .45975 Mdot
.31115 .50885 Mdot
.54808 .49189 Mdot
.25776 .30033 Mdot
.50123 .37684 Mdot
.45932 .26411 Mdot
.20844 .49526 Mdot
.6962 .5636 Mdot
.68371 .4474 Mdot
.65035 .47912 Mdot
.50514 .35279 Mdot
.78378 .3858 Mdot
.30688 .53413 Mdot
.45637 .35922 Mdot
.46724 .40974 Mdot
.63895 .62863 Mdot
.33482 .50216 Mdot
.63782 .567 Mdot
.4956 .7424 Mdot
.23777 .66531 Mdot
.7106 .2321 Mdot
.49359 .64732 Mdot
.21658 .53908 Mdot
.47932 .62009 Mdot
.63916 .25296 Mdot
.64235 .56509 Mdot
.48381 .40785 Mdot
.31825 .4909 Mdot
.45332 .36386 Mdot
.45886 .39018 Mdot
.4606 .36416 Mdot
.43699 .33875 Mdot
.85684 .43422 Mdot
.65858 .47368 Mdot
.44096 .40785 Mdot
.65631 .59593 Mdot
.20742 .56462 Mdot
.17754 .40979 Mdot
.46829 .3721 Mdot
.50153 .34169 Mdot
.35234 .50822 Mdot
.47267 .3267 Mdot
.4711 .61743 Mdot
.30952 .49651 Mdot
.52039 .3387 Mdot
.19646 .56394 Mdot
.53633 .38304 Mdot
.23624 .68678 Mdot
.49626 .65724 Mdot
.39326 .63406 Mdot
.43638 .40644 Mdot
.53886 .75253 Mdot
.52933 .50142 Mdot
.59663 .59295 Mdot
.45146 .6022 Mdot
.62601 .5781 Mdot
.34406 .22188 Mdot
.54279 .34044 Mdot
.52854 .37233 Mdot
.43868 .38368 Mdot
.60222 .59055 Mdot
.26132 .64405 Mdot
.54772 .67877 Mdot
.57209 .37442 Mdot
.61189 .60324 Mdot
.31215 .48001 Mdot
.60581 .45964 Mdot
.33049 .48787 Mdot
.63969 .47589 Mdot
.44908 .6483 Mdot
.6729 .47597 Mdot
.54384 .78742 Mdot
.32977 .5068 Mdot
.30956 .56522 Mdot
.60869 .58734 Mdot
.55318 .55619 Mdot
.57523 .8668 Mdot
.59817 .48598 Mdot
.65094 .30324 Mdot
.32879 .54509 Mdot
.51554 .40981 Mdot
.60611 .23953 Mdot
.54399 .5542 Mdot
.62944 .57981 Mdot
.48955 .40137 Mdot
.76873 .37825 Mdot
.62016 .61166 Mdot
.44087 .37286 Mdot
.65796 .61547 Mdot
.46377 .65667 Mdot
.6205 .62109 Mdot
.35011 .54663 Mdot
.49406 .33877 Mdot
.54743 .86687 Mdot
.63392 .48705 Mdot
.5212 .35106 Mdot
.49765 .63338 Mdot
.41391 .51252 Mdot
.46673 .39173 Mdot
.6519 .42622 Mdot
.62659 .59855 Mdot
.59306 .50117 Mdot
.51454 .34192 Mdot
.60471 .59422 Mdot
.3161 .48472 Mdot
.44812 .60293 Mdot
.50237 .47622 Mdot
.53419 .75941 Mdot
.32119 .5471 Mdot
.42688 .59548 Mdot
.46351 .60425 Mdot
.43888 .39678 Mdot
.44917 .39009 Mdot
.3282 .53294 Mdot
.73405 .32607 Mdot
.46475 .32681 Mdot
.49033 .40873 Mdot
.65637 .59299 Mdot
.62351 .58166 Mdot
.74141 .34308 Mdot
.66574 .60041 Mdot
.55242 .36501 Mdot
.32584 .53297 Mdot
.50483 .39251 Mdot
.34922 .50826 Mdot
.46248 .33323 Mdot
.26805 .52136 Mdot
.36082 .51318 Mdot
.54983 .66402 Mdot
.49734 .39688 Mdot
.44045 .29407 Mdot
.4568 .37743 Mdot
.4817 .34075 Mdot
.62642 .61186 Mdot
.67588 .46084 Mdot
.54507 .41644 Mdot
.64592 .48984 Mdot
.67244 .42806 Mdot
.39268 .47028 Mdot
.63859 .62797 Mdot
.66572 .44955 Mdot
.19913 .42447 Mdot
.62415 .6305 Mdot
.65298 .45214 Mdot
.17811 .43106 Mdot
.49432 .6431 Mdot
.33138 .55363 Mdot
.51655 .37696 Mdot
.44255 .81654 Mdot
.4826 .20879 Mdot
.66881 .58873 Mdot
.52073 .3474 Mdot
.4653 .38336 Mdot
.36004 .48845 Mdot
.41259 .1667 Mdot
.58739 .58398 Mdot
.52433 .39413 Mdot
.32456 .49822 Mdot
.45623 .15817 Mdot
.64081 .57734 Mdot
.65417 .45518 Mdot
.44599 .66587 Mdot
.36548 .47504 Mdot
.50321 .69682 Mdot
.44149 .64297 Mdot
.62628 .54825 Mdot
.48888 .76205 Mdot
.49249 .41352 Mdot
.60493 .61345 Mdot
.67347 .75793 Mdot
.32265 .57692 Mdot
.51284 .61748 Mdot
.6376 .38809 Mdot
.34067 .51624 Mdot
.47155 .61842 Mdot
.67901 .46752 Mdot
.29077 .52801 Mdot
.35131 .52666 Mdot
.47384 .61153 Mdot
.44229 .46823 Mdot
.46555 .56858 Mdot
.48717 .64721 Mdot
.74601 .66302 Mdot
.41992 .78342 Mdot
.60307 .61344 Mdot
.6759 .43246 Mdot
.50929 .80406 Mdot
.30854 .52378 Mdot
.18776 .56343 Mdot
.68349 .74393 Mdot
.5136 .35186 Mdot
.66965 .44546 Mdot
.30322 .69175 Mdot
.28904 .26399 Mdot
.47526 .63068 Mdot
.49794 .50102 Mdot
.6909 .45922 Mdot
.49766 .32241 Mdot
.59906 .34478 Mdot
.5011 .40273 Mdot
.44886 .63827 Mdot
.23566 .39085 Mdot
.34476 .51229 Mdot
.48544 .61398 Mdot
.65019 .76568 Mdot
.50661 .37438 Mdot
.49404 .40008 Mdot
.59021 .26909 Mdot
.29784 .5215 Mdot
.59569 .59032 Mdot
.48805 .41295 Mdot
.49469 .37254 Mdot
.54662 .40282 Mdot
.46762 .27695 Mdot
.79812 .4074 Mdot
.51946 .39734 Mdot
.47155 .73756 Mdot
.43302 .39 Mdot
.49385 .39516 Mdot
.2891 .49467 Mdot
.76363 .28029 Mdot
.49109 .74142 Mdot
.49792 .37345 Mdot
.5166 .40767 Mdot
.46971 .60973 Mdot
.48157 .55992 Mdot
.54919 .56569 Mdot
.57906 .5199 Mdot
.67624 .37782 Mdot
.43431 .34142 Mdot
.32709 .49224 Mdot
.64198 .45736 Mdot
.47146 .41791 Mdot
.32894 .4927 Mdot
.5215 .32515 Mdot
.61676 .61079 Mdot
.62975 .63186 Mdot
.40187 .59364 Mdot
.65983 .44866 Mdot
.5475 .24302 Mdot
.3657 .67652 Mdot
.65623 .58926 Mdot
.52674 .37666 Mdot
.42944 .628 Mdot
.64284 .56845 Mdot
.59783 .53331 Mdot
.53765 .30216 Mdot
.30207 .53007 Mdot
.34142 .52372 Mdot
.68191 .31592 Mdot
.60459 .70751 Mdot
.71725 .25866 Mdot
.46054 .6565 Mdot
.49193 .31399 Mdot
.35458 .62241 Mdot
.34382 .52231 Mdot
.62029 .2483 Mdot
.66556 .44726 Mdot
.47561 .62877 Mdot
.69408 .64962 Mdot
.34802 .5007 Mdot
.33626 .54881 Mdot
.53084 .40235 Mdot
.48095 .36972 Mdot
.70148 .37861 Mdot
.7016 .45253 Mdot
.4522 .6212 Mdot
.67246 .4314 Mdot
.60373 .55554 Mdot
.51888 .40007 Mdot
.35299 .4884 Mdot
.47694 .79469 Mdot
.51166 .41004 Mdot
.6257 .61377 Mdot
.33741 .51842 Mdot
.66525 .43063 Mdot
.66476 .4248 Mdot
.48191 .34214 Mdot
.28173 .3074 Mdot
.47868 .64064 Mdot
.34809 .51747 Mdot
.4232 .73383 Mdot
.4523 .33534 Mdot
.48554 .36544 Mdot
.4474 .30141 Mdot
.47446 .61445 Mdot
.3847 .61099 Mdot
.67183 .4812 Mdot
.31368 .5131 Mdot
.53411 .37227 Mdot
.65322 .44569 Mdot
.37553 .61348 Mdot
.67361 .60873 Mdot
.62724 .62197 Mdot
.65497 .42496 Mdot
.6745 .4405 Mdot
.65248 .42803 Mdot
.18445 .56013 Mdot
.36392 .53298 Mdot
.40006 .34905 Mdot
.46756 .32338 Mdot
.66441 .29837 Mdot
.56157 .4027 Mdot
.50092 .63311 Mdot
.64593 .62464 Mdot
.45839 .38471 Mdot
.51221 .41402 Mdot
.44897 .29252 Mdot
.42075 .30919 Mdot
.34952 .5597 Mdot
.33144 .50385 Mdot
.5291 .32473 Mdot
.65145 .62621 Mdot
.25163 .24563 Mdot
.38553 .82307 Mdot
.44668 .41898 Mdot
.52231 .571 Mdot
.3549 .49061 Mdot
.44657 .61569 Mdot
.57462 .53929 Mdot
.48734 .66902 Mdot
.3175 .51614 Mdot
.51852 .3995 Mdot
.37369 .68004 Mdot
.6561 .42247 Mdot
.46444 .34213 Mdot
.46036 .62506 Mdot
.47156 .33849 Mdot
.44169 .64518 Mdot
.34271 .76343 Mdot
.78469 .61817 Mdot
.51203 .36124 Mdot
.44865 .41343 Mdot
.65997 .38913 Mdot
.46859 .3744 Mdot
.61059 .4437 Mdot
.35762 .49491 Mdot
.68278 .24634 Mdot
.54223 .38249 Mdot
.33165 .36152 Mdot
.45184 .33473 Mdot
.7697 .393 Mdot
.48101 .36483 Mdot
.70668 .58299 Mdot
.50887 .33428 Mdot
.49085 .33073 Mdot
.48557 .66808 Mdot
.47241 .61052 Mdot
.28329 .52162 Mdot
.59822 .58351 Mdot
.22555 .66964 Mdot
.4899 .36857 Mdot
.53709 .76086 Mdot
.43426 .71054 Mdot
.67625 .44018 Mdot
.31518 .51773 Mdot
.42025 .15642 Mdot
.47962 .67859 Mdot
.78475 .53084 Mdot
.74178 .36387 Mdot
.49367 .71214 Mdot
.5911 .5275 Mdot
.24448 .58496 Mdot
.65154 .43857 Mdot
.49473 .32042 Mdot
.52115 .78877 Mdot
.72231 .64146 Mdot
.54732 .30933 Mdot
.47857 .60802 Mdot
.33084 .40902 Mdot
.49534 .79885 Mdot
.6826 .47614 Mdot
.67303 .47728 Mdot
.44394 .65859 Mdot
.69755 .60926 Mdot
.42017 .40764 Mdot
.66481 .44437 Mdot
.66303 .59911 Mdot
.60721 .62055 Mdot
.61063 .65724 Mdot
.30503 .52775 Mdot
.61627 .77974 Mdot
.33713 .68987 Mdot
.44224 .64039 Mdot
.691 .50329 Mdot
.37625 .50076 Mdot
.3414 .55639 Mdot
.61242 .58026 Mdot
.63172 .61397 Mdot
.3273 .55625 Mdot
.54735 .37205 Mdot
.42623 .31823 Mdot
.50095 .37434 Mdot
.66154 .46364 Mdot
.47476 .36601 Mdot
.61876 .60662 Mdot
.47132 .63382 Mdot
.63987 .6125 Mdot
.49046 .67233 Mdot
.37281 .73659 Mdot
.4631 .35143 Mdot
.49706 .33683 Mdot
.47943 .20626 Mdot
.29275 .49772 Mdot
.44936 .74616 Mdot
.52687 .76651 Mdot
.65196 .59627 Mdot
.49114 .3276 Mdot
.32715 .48447 Mdot
.66006 .48688 Mdot
.47732 .20453 Mdot
.44696 .37058 Mdot
.35328 .49055 Mdot
.53066 .38304 Mdot
.20676 .45241 Mdot
.83717 .48868 Mdot
.31602 .52941 Mdot
.56943 .18382 Mdot
.52638 .3974 Mdot
.24687 .56174 Mdot
.44362 .39065 Mdot
.71109 .35228 Mdot
.4631 .32811 Mdot
.29182 .53188 Mdot
.49605 .37801 Mdot
.29756 .51107 Mdot
.63597 .57109 Mdot
.43721 .63635 Mdot
.33767 .54253 Mdot
.45644 .40266 Mdot
.26975 .7873 Mdot
.45035 .64297 Mdot
.50733 .35231 Mdot
.46199 .67423 Mdot
.31428 .50034 Mdot
.32763 .54989 Mdot
.24451 .30644 Mdot
.50132 .73165 Mdot
.46471 .65624 Mdot
.52287 .39303 Mdot
.30053 .6502 Mdot
.50553 .39642 Mdot
.68167 .35529 Mdot
.54213 .40281 Mdot
.45584 .33301 Mdot
.18549 .37414 Mdot
.46297 .61431 Mdot
.74273 .28828 Mdot
.23198 .32502 Mdot
.18956 .54326 Mdot
.34775 .47006 Mdot
.67483 .48275 Mdot
.19231 .60544 Mdot
.50635 .74683 Mdot
.60721 .59934 Mdot
.45792 .38141 Mdot
.37931 .51654 Mdot
.48464 .63832 Mdot
.67257 .46438 Mdot
.51187 .36033 Mdot
.63353 .61529 Mdot
.78726 .48417 Mdot
.45521 .67969 Mdot
.30916 .52167 Mdot
.36159 .51956 Mdot
.51697 .16299 Mdot
.53208 .36255 Mdot
.49829 .33417 Mdot
.448 .64312 Mdot
.35379 .57464 Mdot
.65263 .43495 Mdot
.7677 .42574 Mdot
.46282 .65556 Mdot
.53261 .53305 Mdot
.3211 .50365 Mdot
.46444 .38159 Mdot
.25599 .64966 Mdot
.74851 .60741 Mdot
.38931 .28315 Mdot
.65557 .46177 Mdot
.67212 .35245 Mdot
.29213 .53299 Mdot
.464 .63039 Mdot
.59611 .72017 Mdot
.51437 .30011 Mdot
.46992 .38339 Mdot
.66586 .34718 Mdot
.48709 .48577 Mdot
.5692 .21867 Mdot
.4442 .36409 Mdot
.52304 .49029 Mdot
.45073 .34701 Mdot
.53134 .30861 Mdot
.55141 .37491 Mdot
.48881 .35913 Mdot
.35416 .49082 Mdot
.55071 .31673 Mdot
.60452 .60394 Mdot
.48148 .23979 Mdot
.54912 .5197 Mdot
.51751 .34656 Mdot
.50893 .40027 Mdot
.37759 .33986 Mdot
.41023 .62491 Mdot
.34292 .53477 Mdot
.28493 .55654 Mdot
.43455 .63399 Mdot
.43861 .30108 Mdot
.59586 .57967 Mdot
.56359 .36722 Mdot
.63022 .61097 Mdot
.3402 .48526 Mdot
.64997 .58944 Mdot
.43849 .6577 Mdot
.61061 .62077 Mdot
.50687 .75274 Mdot
.47985 .6242 Mdot
.29918 .53377 Mdot
.48756 .34451 Mdot
.49679 .63232 Mdot
.60189 .28329 Mdot
.66087 .46319 Mdot
.23273 .3169 Mdot
.5322 .35326 Mdot
.4838 .71038 Mdot
.40093 .52817 Mdot
.6376 .61181 Mdot
.82104 .42835 Mdot
.36019 .5164 Mdot
.63443 .4565 Mdot
.3359 .48417 Mdot
.76312 .66586 Mdot
.67873 .45256 Mdot
.17576 .44177 Mdot
.63985 .71816 Mdot
.62271 .49934 Mdot
.54632 .37171 Mdot
.59836 .36529 Mdot
.59868 .55592 Mdot
.48432 .63723 Mdot
.63013 .70895 Mdot
.48746 .33043 Mdot
.79894 .55743 Mdot
.28254 .53298 Mdot
.59893 .58768 Mdot
.46166 .63807 Mdot
.49126 .62207 Mdot
.45047 .38417 Mdot
.72066 .48899 Mdot
.45519 .34626 Mdot
.57949 .7012 Mdot
.67281 .37141 Mdot
.41146 .38359 Mdot
.50843 .34366 Mdot
.61487 .56685 Mdot
.53028 .38347 Mdot
.67425 .40557 Mdot
.60169 .79699 Mdot
.44671 .32913 Mdot
.5207 .76702 Mdot
.62513 .46575 Mdot
.32984 .51175 Mdot
.47769 .43931 Mdot
.51499 .73198 Mdot
.53292 .3727 Mdot
.86221 .59028 Mdot
.65296 .44993 Mdot
.54842 .75089 Mdot
.43335 .37168 Mdot
.46145 .40305 Mdot
.59047 .41455 Mdot
.33312 .45973 Mdot
.75202 .60533 Mdot
.47644 .38157 Mdot
.62498 .34747 Mdot
.45582 .6645 Mdot
.45099 .35433 Mdot
.50384 .36105 Mdot
.37065 .45148 Mdot
.48593 .62023 Mdot
.65233 .60691 Mdot
.6274 .55517 Mdot
.58822 .61109 Mdot
.64457 .41838 Mdot
.50495 .51382 Mdot
.64132 .27001 Mdot
.81582 .54388 Mdot
.63903 .4561 Mdot
.53877 .38232 Mdot
.65233 .40061 Mdot
.50879 .40801 Mdot
.68255 .46085 Mdot
.48448 .62065 Mdot
.34417 .53509 Mdot
.35146 .60671 Mdot
.58924 .56663 Mdot
.43979 .37341 Mdot
.68402 .4355 Mdot
.30163 .53411 Mdot
.69833 .43386 Mdot
.32254 .51056 Mdot
.46411 .65222 Mdot
.43169 .64679 Mdot
.67525 .4657 Mdot
.33682 .48762 Mdot
.40826 .65861 Mdot
.29344 .26357 Mdot
.5526 .38557 Mdot
.52608 .61377 Mdot
.29974 .49367 Mdot
.31166 .5608 Mdot
.28956 .51297 Mdot
.47367 .34196 Mdot
.51862 .5694 Mdot
.52034 .42207 Mdot
.4508 .62341 Mdot
.65641 .61614 Mdot
.73692 .42164 Mdot
.41494 .76695 Mdot
.73265 .44808 Mdot
.49879 .31352 Mdot
.50382 .3784 Mdot
.50527 .35313 Mdot
.52748 .41063 Mdot
.56488 .7083 Mdot
.45454 .36816 Mdot
.48154 .67067 Mdot
.627 .60286 Mdot
.4989 .31993 Mdot
.67395 .60257 Mdot
.26468 .61495 Mdot
.64293 .46467 Mdot
.48981 .50623 Mdot
.22698 .72623 Mdot
.30628 .54059 Mdot
.66567 .59669 Mdot
.60721 .59719 Mdot
.64515 .43571 Mdot
.48291 .64293 Mdot
.31912 .50722 Mdot
.71887 .37065 Mdot
.66126 .4268 Mdot
.49563 .37583 Mdot
.55347 .59502 Mdot
.7911 .56427 Mdot
.48473 .32182 Mdot
.47112 .40114 Mdot
.67475 .60959 Mdot
.70203 .59757 Mdot
.6062 .82365 Mdot
.59596 .24483 Mdot
.67641 .46251 Mdot
.64965 .47465 Mdot
.31598 .55836 Mdot
.46903 .43107 Mdot
.44843 .62688 Mdot
.53864 .21803 Mdot
.41808 .48454 Mdot
.5485 .23863 Mdot
.51383 .47675 Mdot
.44874 .3711 Mdot
.35531 .24603 Mdot
.50804 .37421 Mdot
.36377 .50121 Mdot
.30583 .50768 Mdot
.32532 .54202 Mdot
.48149 .63673 Mdot
.28568 .41808 Mdot
.48216 .66815 Mdot
.25545 .74699 Mdot
.29642 .53976 Mdot
.56228 .73082 Mdot
.61576 .56858 Mdot
.43286 .40228 Mdot
.6616 .43199 Mdot
.5059 .63052 Mdot
.4212 .36098 Mdot
.78903 .38965 Mdot
.6015 .59573 Mdot
.2995 .53577 Mdot
.24276 .57918 Mdot
.31166 .76401 Mdot
.56077 .55028 Mdot
.56627 .40731 Mdot
.60014 .39914 Mdot
.67719 .43899 Mdot
.39287 .27687 Mdot
.68855 .44168 Mdot
.46694 .62297 Mdot
.49586 .34114 Mdot
.4898 .35 Mdot
.45531 .33871 Mdot
.45769 .36093 Mdot
.44651 .61393 Mdot
.45769 .32498 Mdot
.84127 .56264 Mdot
.63631 .63276 Mdot
.21982 .46396 Mdot
.65166 .44319 Mdot
.46653 .60237 Mdot
.62611 .60423 Mdot
.6815 .61238 Mdot
.60973 .26862 Mdot
.51259 .34178 Mdot
.45716 .38242 Mdot
.78544 .54851 Mdot
.44381 .36148 Mdot
.55504 .4193 Mdot
.60523 .59576 Mdot
.73317 .44518 Mdot
.64226 .47176 Mdot
.66433 .47791 Mdot
.49082 .63189 Mdot
.33603 .48587 Mdot
.66231 .45537 Mdot
.63918 .57403 Mdot
.50485 .31308 Mdot
.47451 .4139 Mdot
.29609 .49702 Mdot
.69255 .73719 Mdot
.68682 .47005 Mdot
.25055 .59324 Mdot
.30727 .50082 Mdot
.37205 .51763 Mdot
.47104 .38487 Mdot
.51784 .2815 Mdot
.37764 .47963 Mdot
.63729 .44796 Mdot
.46307 .6021 Mdot
.58672 .51729 Mdot
.4534 .6272 Mdot
.30675 .51293 Mdot
.48219 .41849 Mdot
.30266 .51504 Mdot
.52784 .35495 Mdot
.16369 .64846 Mdot
.48615 .35638 Mdot
.81912 .55621 Mdot
.68148 .33016 Mdot
.6175 .59358 Mdot
.4149 .68394 Mdot
.60668 .58103 Mdot
.30418 .50423 Mdot
.47081 .41597 Mdot
.66757 .481 Mdot
.18724 .51059 Mdot
.37551 .51143 Mdot
.61623 .61331 Mdot
.59194 .60758 Mdot
.47882 .62087 Mdot
.49301 .3172 Mdot
.46652 .37974 Mdot
.62716 .58712 Mdot
.40813 .37363 Mdot
.35075 .49828 Mdot
.50195 .33931 Mdot
.49821 .38816 Mdot
.61549 .592 Mdot
.3165 .24495 Mdot
.27198 .48817 Mdot
.49556 .34962 Mdot
.59923 .74723 Mdot
.50038 .63127 Mdot
.54458 .39019 Mdot
.42776 .38255 Mdot
.67079 .44051 Mdot
.24389 .47195 Mdot
.58372 .80076 Mdot
.50067 .64382 Mdot
.60335 .5779 Mdot
.53342 .36518 Mdot
.61212 .5684 Mdot
.46551 .40967 Mdot
.25369 .48605 Mdot
.59779 .60002 Mdot
.47424 .4088 Mdot
.46317 .43176 Mdot
.2978 .51954 Mdot
.45216 .37694 Mdot
.38264 .37414 Mdot
.62678 .55944 Mdot
.45958 .39923 Mdot
.27878 .3121 Mdot
.48503 .65412 Mdot
.45776 .42956 Mdot
.64558 .46215 Mdot
.72277 .37301 Mdot
.36516 .69389 Mdot
.54411 .76888 Mdot
.65015 .47024 Mdot
.47015 .33758 Mdot
.59599 .6163 Mdot
.44233 .6518 Mdot
.81509 .52016 Mdot
.48414 .3255 Mdot
.44937 .63816 Mdot
.46945 .63441 Mdot
.64785 .45844 Mdot
.64925 .19628 Mdot
.43256 .35676 Mdot
.46923 .37144 Mdot
.38766 .43919 Mdot
.33949 .47728 Mdot
.47734 .36091 Mdot
.52597 .40268 Mdot
.47672 .67274 Mdot
.55014 .42811 Mdot
.35491 .38724 Mdot
.75754 .40144 Mdot
.50515 .65594 Mdot
.58724 .49308 Mdot
.59225 .59387 Mdot
.65561 .44112 Mdot
.32951 .51778 Mdot
.69274 .44789 Mdot
.62001 .62404 Mdot
.53531 .39036 Mdot
.46735 .67821 Mdot
.40644 .29319 Mdot
.44225 .65589 Mdot
.54931 .76503 Mdot
.32416 .48146 Mdot
.33781 .62827 Mdot
.87151 .52507 Mdot
.33983 .69723 Mdot
.41053 .63133 Mdot
.67621 .4404 Mdot
.64915 .55787 Mdot
.50025 .38549 Mdot
.40844 .25807 Mdot
.48602 .34005 Mdot
.28264 .31225 Mdot
.66421 .60802 Mdot
.61443 .62845 Mdot
.49558 .34501 Mdot
.67653 .36764 Mdot
.43992 .64344 Mdot
.46659 .61554 Mdot
.45724 .39373 Mdot
.47112 .65055 Mdot
.48 .37254 Mdot
.62437 .60972 Mdot
.77401 .32407 Mdot
.506 .36797 Mdot
.47506 .42389 Mdot
.52621 .65884 Mdot
.19294 .3734 Mdot
.62506 .75024 Mdot
.38806 .2343 Mdot
.34547 .78617 Mdot
.4703 .64997 Mdot
.51238 .42807 Mdot
.59026 .48871 Mdot
.6757 .60598 Mdot
.40648 .6486 Mdot
.47902 .35268 Mdot
.4769 .35029 Mdot
.49526 .32945 Mdot
.49491 .40068 Mdot
.39599 .26433 Mdot
.39681 .35472 Mdot
.26662 .36279 Mdot
.45749 .38735 Mdot
.58262 .30838 Mdot
.49671 .64061 Mdot
.28029 .5349 Mdot
.69322 .43526 Mdot
.44903 .37137 Mdot
.39939 .34254 Mdot
.49641 .62251 Mdot
.25758 .74862 Mdot
.48475 .62428 Mdot
.6482 .59813 Mdot
.44365 .62013 Mdot
.52283 .36027 Mdot
.32479 .52514 Mdot
.56339 .51649 Mdot
.57941 .67319 Mdot
.60756 .60018 Mdot
.52113 .35077 Mdot
.53899 .74056 Mdot
.60615 .60401 Mdot
.2667 .61912 Mdot
.33043 .52386 Mdot
.61891 .33649 Mdot
.30468 .50876 Mdot
.47483 .40964 Mdot
.48615 .41064 Mdot
.50538 .60228 Mdot
.43798 .64665 Mdot
.30647 .50528 Mdot
.6829 .21066 Mdot
.68832 .4371 Mdot
.31986 .54058 Mdot
.51628 .30692 Mdot
.44556 .54123 Mdot
.32998 .52988 Mdot
.72178 .44118 Mdot
.48262 .63143 Mdot
.3051 .55126 Mdot
.50907 .30132 Mdot
.70741 .70789 Mdot
.64103 .43522 Mdot
.60986 .63454 Mdot
.56469 .60661 Mdot
.63687 .56422 Mdot
.45011 .6049 Mdot
.6071 .58582 Mdot
.46024 .66663 Mdot
.41843 .7139 Mdot
.49957 .23526 Mdot
.42862 .63839 Mdot
.4469 .60972 Mdot
.6092 .58773 Mdot
.50462 .3359 Mdot
.56591 .57735 Mdot
.5298 .41511 Mdot
.45509 .31042 Mdot
.46578 .66513 Mdot
.29251 .5309 Mdot
.34521 .54827 Mdot
.59446 .33349 Mdot
.36318 .51509 Mdot
.6305 .61214 Mdot
.83257 .50577 Mdot
.52536 .78101 Mdot
.45188 .65648 Mdot
.45564 .60792 Mdot
.50637 .39775 Mdot
.62711 .57846 Mdot
.62183 .56481 Mdot
.46936 .62033 Mdot
.48992 .25295 Mdot
.47437 .42801 Mdot
.30833 .56256 Mdot
.30092 .54562 Mdot
.32081 .53206 Mdot
.29093 .51373 Mdot
.35322 .35048 Mdot
.48182 .62864 Mdot
.29185 .52707 Mdot
.46727 .40436 Mdot
.47681 .35186 Mdot
.57414 .51942 Mdot
.65672 .47648 Mdot
.52079 .32558 Mdot
.54996 .36648 Mdot
.46858 .38599 Mdot
.62349 .62098 Mdot
.45277 .30468 Mdot
.59518 .59344 Mdot
.59731 .62388 Mdot
.65529 .62809 Mdot
.50705 .74818 Mdot
.60844 .39719 Mdot
.39289 .81287 Mdot
.52491 .39372 Mdot
.2984 .577 Mdot
.62502 .57209 Mdot
.80842 .41171 Mdot
.38373 .60525 Mdot
.48827 .32636 Mdot
.74039 .61429 Mdot
.62433 .58635 Mdot
.36305 .51988 Mdot
.48102 .35398 Mdot
.59368 .62278 Mdot
.64142 .45195 Mdot
.53959 .3291 Mdot
.63112 .55831 Mdot
.3316 .48891 Mdot
.66958 .41512 Mdot
.29431 .54122 Mdot
.66012 .62329 Mdot
.4613 .43103 Mdot
.60175 .8646 Mdot
.58646 .57341 Mdot
.19583 .41681 Mdot
.31227 .47087 Mdot
.50208 .33797 Mdot
.65876 .58549 Mdot
.34552 .4785 Mdot
.44754 .60475 Mdot
.43574 .49352 Mdot
.3522 .53045 Mdot
.61328 .62768 Mdot
.63422 .56075 Mdot
.60537 .59679 Mdot
.33555 .50624 Mdot
.4897 .42312 Mdot
.34362 .50539 Mdot
.44577 .61765 Mdot
.51194 .38379 Mdot
.26847 .73261 Mdot
.31642 .57853 Mdot
.30688 .50259 Mdot
.65078 .61223 Mdot
.6574 .42006 Mdot
.51337 .36427 Mdot
.21318 .38108 Mdot
.5227 .34462 Mdot
.44933 .65853 Mdot
.75441 .32985 Mdot
.40484 .29176 Mdot
.46386 .32614 Mdot
.50555 .39822 Mdot
.45794 .6165 Mdot
.5142 .34968 Mdot
.46954 .32371 Mdot
.50487 .74149 Mdot
.33322 .5002 Mdot
.49695 .38043 Mdot
.6599 .6068 Mdot
.48256 .77028 Mdot
.49468 .42817 Mdot
.75992 .50189 Mdot
.6366 .34997 Mdot
.71841 .27615 Mdot
.4884 .33758 Mdot
.57348 .23846 Mdot
.48668 .40162 Mdot
.4629 .34525 Mdot
.51589 .39564 Mdot
.4234 .22718 Mdot
.60367 .60905 Mdot
.61504 .60188 Mdot
.6392 .43938 Mdot
.63395 .34995 Mdot
.66956 .44353 Mdot
.48722 .63418 Mdot
.74002 .50905 Mdot
.59815 .60036 Mdot
.32911 .48857 Mdot
.46362 .33954 Mdot
.58659 .57097 Mdot
.46231 .37878 Mdot
.52455 .361 Mdot
.60059 .5677 Mdot
.58998 .57361 Mdot
.54528 .75904 Mdot
.64412 .46364 Mdot
.33273 .54238 Mdot
.53095 .33712 Mdot
.6751 .43016 Mdot
.47735 .42086 Mdot
.66306 .29318 Mdot
.33225 .54074 Mdot
.33625 .50092 Mdot
.35427 .53837 Mdot
.53551 .38955 Mdot
.51944 .35774 Mdot
.47987 .66866 Mdot
.32908 .48633 Mdot
.48372 .65311 Mdot
.54175 .51103 Mdot
.76106 .48414 Mdot
.47893 .35259 Mdot
.25826 .5932 Mdot
.66314 .43596 Mdot
.64263 .60559 Mdot
.78251 .50762 Mdot
.6406 .43394 Mdot
.52412 .34922 Mdot
.61036 .56667 Mdot
.6769 .4683 Mdot
.58042 .38959 Mdot
.459 .8359 Mdot
.66831 .42013 Mdot
.46461 .40176 Mdot
.52997 .44601 Mdot
.41305 .20524 Mdot
.65247 .41715 Mdot
.45487 .67139 Mdot
.53712 .3857 Mdot
.3975 .52794 Mdot
.68699 .46879 Mdot
.44158 .74484 Mdot
.62586 .59566 Mdot
.64621 .75511 Mdot
.42909 .33813 Mdot
.44005 .24244 Mdot
.68992 .45099 Mdot
.31677 .50981 Mdot
.2732 .51826 Mdot
.4766 .39171 Mdot
.65375 .41643 Mdot
.50458 .66181 Mdot
.6324 .59874 Mdot
.49063 .74433 Mdot
.33786 .50724 Mdot
.30355 .61914 Mdot
.64684 .61854 Mdot
.26608 .6051 Mdot
.7618 .37545 Mdot
.41332 .36198 Mdot
.39977 .22464 Mdot
.68082 .66795 Mdot
.54044 .38145 Mdot
.68521 .43227 Mdot
.49994 .64057 Mdot
.45041 .67026 Mdot
.4601 .65301 Mdot
.42949 .71163 Mdot
.5737 .52899 Mdot
.67013 .6092 Mdot
.6178 .66815 Mdot
.65515 .44474 Mdot
.57527 .28574 Mdot
.45636 .40654 Mdot
.50408 .37647 Mdot
.49771 .31606 Mdot
.44783 .35994 Mdot
.48561 .39678 Mdot
.47994 .64795 Mdot
.43924 .72074 Mdot
.58999 .50377 Mdot
.33279 .53549 Mdot
.71466 .481 Mdot
.61664 .56874 Mdot
.66971 .62062 Mdot
.66562 .47332 Mdot
.23955 .59026 Mdot
.66856 .59293 Mdot
.65238 .59418 Mdot
.51914 .3332 Mdot
.34636 .50005 Mdot
.56369 .35127 Mdot
.49006 .40825 Mdot
.63527 .60705 Mdot
.58118 .46149 Mdot
.3689 .37394 Mdot
.497 .28771 Mdot
.64693 .40903 Mdot
.51268 .56391 Mdot
.65792 .41726 Mdot
.45779 .41151 Mdot
.79924 .39784 Mdot
.61722 .62263 Mdot
.64032 .58761 Mdot
.68695 .44357 Mdot
.24668 .53495 Mdot
.33684 .51575 Mdot
.68223 .61137 Mdot
.46092 .67197 Mdot
.50047 .41025 Mdot
.77929 .47528 Mdot
.24882 .54631 Mdot
.72265 .49536 Mdot
.45553 .65294 Mdot
.6276 .56767 Mdot
.48525 .31652 Mdot
.46591 .40207 Mdot
.6742 .43454 Mdot
.30842 .72853 Mdot
.54096 .33655 Mdot
.1872 .54872 Mdot
.78541 .62341 Mdot
.70349 .72102 Mdot
.46993 .3832 Mdot
.33275 .50171 Mdot
.64461 .56687 Mdot
.67533 .43239 Mdot
.4772 .3067 Mdot
.43905 .83007 Mdot
.28399 .51048 Mdot
.46636 .62581 Mdot
.57278 .49517 Mdot
.57262 .54158 Mdot
.53 .34858 Mdot
.48615 .34148 Mdot
.46827 .34651 Mdot
.5319 .83241 Mdot
.62611 .6187 Mdot
.35135 .48623 Mdot
.65589 .46509 Mdot
.36382 .51087 Mdot
.61432 .59747 Mdot
.31787 .62613 Mdot
.51259 .33615 Mdot
.2852 .508 Mdot
.31844 .51151 Mdot
.48024 .62206 Mdot
.44321 .6096 Mdot
.55508 .50621 Mdot
.48585 .35803 Mdot
.59387 .55259 Mdot
.29556 .52573 Mdot
.55516 .59101 Mdot
.67909 .45034 Mdot
.49405 .65333 Mdot
.45656 .38451 Mdot
.61051 .6159 Mdot
.45794 .32433 Mdot
.34337 .52537 Mdot
.65142 .59228 Mdot
.54255 .75638 Mdot
.64871 .47257 Mdot
.46596 .3589 Mdot
.66618 .40975 Mdot
.60336 .57712 Mdot
.49999 .3879 Mdot
.23338 .55927 Mdot
.63294 .42328 Mdot
.55654 .67814 Mdot
.66599 .61373 Mdot
.5366 .75905 Mdot
.34595 .54452 Mdot
.40397 .69565 Mdot
.64337 .59213 Mdot
.23236 .57528 Mdot
.35988 .75182 Mdot
.51756 .31707 Mdot
.31025 .52677 Mdot
.67232 .57229 Mdot
.20345 .67379 Mdot
.31146 .25418 Mdot
.50682 .35438 Mdot
.66674 .60307 Mdot
.68534 .44319 Mdot
.45267 .65774 Mdot
.76142 .49991 Mdot
.65857 .40224 Mdot
.58867 .59095 Mdot
.51569 .39725 Mdot
.31502 .50196 Mdot
.4779 .63401 Mdot
.37874 .70172 Mdot
.65295 .58797 Mdot
.65236 .61931 Mdot
.4807 .31782 Mdot
.66447 .4478 Mdot
.2549 .32115 Mdot
.62065 .60932 Mdot
.78327 .56328 Mdot
.61512 .54487 Mdot
.68298 .43323 Mdot
.47917 .40325 Mdot
.60116 .36374 Mdot
.53467 .40513 Mdot
.18714 .44565 Mdot
.60914 .57805 Mdot
.34058 .53268 Mdot
.48053 .33749 Mdot
.75493 .38552 Mdot
.63717 .60448 Mdot
.52503 .57123 Mdot
.71237 .6021 Mdot
.48184 .6297 Mdot
.7845 .51162 Mdot
.47111 .3646 Mdot
.44068 .64735 Mdot
.66388 .43631 Mdot
.49353 .35496 Mdot
.51943 .36121 Mdot
.35972 .48592 Mdot
.46475 .62188 Mdot
.39193 .77827 Mdot
.48408 .61297 Mdot
.49478 .65961 Mdot
.36891 .51545 Mdot
.48484 .38256 Mdot
.64971 .60056 Mdot
.62517 .58491 Mdot
.46791 .30528 Mdot
.81631 .40135 Mdot
.33911 .51424 Mdot
.68307 .50664 Mdot
.55305 .83172 Mdot
.41324 .37178 Mdot
.78315 .50189 Mdot
.30441 .72234 Mdot
.50051 .66673 Mdot
.45689 .3908 Mdot
.32208 .49281 Mdot
.68135 .61458 Mdot
.65293 .61651 Mdot
.49034 .42147 Mdot
.47252 .63773 Mdot
.64053 .44828 Mdot
.60563 .55735 Mdot
.7228 .48674 Mdot
.46056 .35219 Mdot
.74139 .62115 Mdot
.64709 .57507 Mdot
.16991 .56462 Mdot
.67068 .58012 Mdot
.31239 .53095 Mdot
.52393 .36415 Mdot
.35768 .5264 Mdot
.66156 .46665 Mdot
.56829 .50033 Mdot
.47208 .63542 Mdot
.44604 .45007 Mdot
.8237 .63606 Mdot
.60354 .59235 Mdot
.35756 .49434 Mdot
.4622 .32702 Mdot
.58134 .43194 Mdot
.47318 .36917 Mdot
.49619 .45107 Mdot
.62227 .44678 Mdot
.47205 .66394 Mdot
.44978 .6625 Mdot
.50463 .3858 Mdot
.65455 .43042 Mdot
.63107 .57013 Mdot
.63539 .59868 Mdot
.16086 .38147 Mdot
.55377 .65451 Mdot
.70393 .37703 Mdot
.47346 .35221 Mdot
.6041 .62076 Mdot
.43462 .76803 Mdot
.44824 .64477 Mdot
.44792 .39552 Mdot
.59599 .58163 Mdot
.72819 .67169 Mdot
.72287 .35398 Mdot
.48197 .39792 Mdot
.42745 .3608 Mdot
.46019 .67253 Mdot
.57683 .26987 Mdot
.65527 .62595 Mdot
.54235 .40399 Mdot
.43754 .66669 Mdot
.7392 .32571 Mdot
.64104 .78045 Mdot
.33201 .54267 Mdot
.70521 .59841 Mdot
.48066 .64727 Mdot
.46117 .30338 Mdot
.64856 .44702 Mdot
.60617 .55313 Mdot
.61828 .61739 Mdot
.52354 .38864 Mdot
.45799 .3255 Mdot
.66186 .39199 Mdot
.35935 .50196 Mdot
.49568 .63898 Mdot
.49417 .33648 Mdot
.33371 .60267 Mdot
.45311 .34186 Mdot
.4828 .66507 Mdot
.57233 .88711 Mdot
.53022 .33267 Mdot
.47222 .37154 Mdot
.25618 .31735 Mdot
.35101 .53218 Mdot
.36526 .50861 Mdot
.80196 .59101 Mdot
.47277 .35273 Mdot
.78845 .53355 Mdot
.33515 .54273 Mdot
.34067 .51714 Mdot
.51637 .71688 Mdot
.51011 .36759 Mdot
.50407 .21656 Mdot
.44292 .64834 Mdot
.48659 .6708 Mdot
.3427 .50679 Mdot
.53273 .33139 Mdot
.48371 .67805 Mdot
.36786 .29062 Mdot
.6254 .5773 Mdot
.79266 .38027 Mdot
.34977 .52126 Mdot
.50797 .49686 Mdot
.45158 .65127 Mdot
.25176 .74423 Mdot
.64849 .66241 Mdot
.50223 .33568 Mdot
.46595 .35541 Mdot
.65972 .43721 Mdot
.52744 .32952 Mdot
.61724 .62992 Mdot
.47139 .65085 Mdot
.22552 .38896 Mdot
.32398 .54208 Mdot
.48308 .36406 Mdot
.25728 .60509 Mdot
.37482 .72694 Mdot
.64831 .72389 Mdot
.32897 .51214 Mdot
.30648 .5283 Mdot
.65539 .62455 Mdot
.6652 .59854 Mdot
.48155 .3882 Mdot
.45733 .61892 Mdot
.32337 .48859 Mdot
.47532 .66713 Mdot
.61854 .62292 Mdot
.65214 .60178 Mdot
.59895 .60478 Mdot
.55792 .37618 Mdot
.65612 .59781 Mdot
.73334 .46598 Mdot
.30441 .62607 Mdot
.34194 .55637 Mdot
.72823 .7274 Mdot
.37898 .69911 Mdot
.40894 .49155 Mdot
.67468 .4795 Mdot
.60313 .57671 Mdot
.45481 .61072 Mdot
.50275 .39633 Mdot
.45939 .38064 Mdot
.62868 .64404 Mdot
.4456 .62206 Mdot
.66976 .46555 Mdot
.43885 .63624 Mdot
.64715 .45747 Mdot
.72528 .62851 Mdot
.49641 .31787 Mdot
.47747 .4135 Mdot
.47577 .65205 Mdot
.65323 .59309 Mdot
.6227 .60177 Mdot
.66733 .41801 Mdot
.43863 .47296 Mdot
.60447 .6025 Mdot
.34827 .52251 Mdot
.34651 .34106 Mdot
.63877 .56322 Mdot
.47941 .35669 Mdot
.63751 .26344 Mdot
.41904 .25783 Mdot
.52544 .41296 Mdot
.50871 .72831 Mdot
.53731 .19287 Mdot
.47755 .33364 Mdot
.54353 .1846 Mdot
.53409 .75862 Mdot
.35608 .52594 Mdot
.6636 .61195 Mdot
.67563 .6215 Mdot
.51047 .4433 Mdot
.69881 .45599 Mdot
.47799 .30463 Mdot
.34695 .53681 Mdot
.28559 .49701 Mdot
.7371 .67705 Mdot
.19377 .4205 Mdot
.68743 .45128 Mdot
.66788 .47513 Mdot
.6415 .59252 Mdot
.29577 .24566 Mdot
.50899 .29462 Mdot
.67435 .4642 Mdot
.50827 .23718 Mdot
.51609 .3991 Mdot
.6658 .33829 Mdot
.76843 .58234 Mdot
.33607 .50413 Mdot
.5989 .3629 Mdot
.6445 .59971 Mdot
.36022 .50931 Mdot
.35513 .60167 Mdot
.52696 .33603 Mdot
.33011 .54094 Mdot
.47443 .66885 Mdot
.65706 .68454 Mdot
.32769 .54949 Mdot
.64871 .27382 Mdot
.46743 .61919 Mdot
.55119 .58909 Mdot
.60058 .32549 Mdot
.86914 .38942 Mdot
.47702 .64745 Mdot
.59305 .5744 Mdot
.62581 .58591 Mdot
.63607 .59767 Mdot
.36187 .50867 Mdot
.61745 .56465 Mdot
.35759 .49777 Mdot
.37433 .21091 Mdot
.43543 .47128 Mdot
.67712 .46322 Mdot
.49873 .73183 Mdot
.31053 .51682 Mdot
.83192 .47462 Mdot
.85671 .56437 Mdot
.45463 .38777 Mdot
.46985 .60782 Mdot
.68242 .4596 Mdot
.17512 .5116 Mdot
.66801 .43912 Mdot
.63497 .50708 Mdot
.77037 .34225 Mdot
.4844 .36959 Mdot
.32724 .42291 Mdot
.66383 .48052 Mdot
.32206 .50488 Mdot
.50183 .38456 Mdot
.40902 .61282 Mdot
.66355 .44217 Mdot
.64214 .44549 Mdot
.48911 .38916 Mdot
.29906 .53521 Mdot
.64847 .60582 Mdot
.4358 .6383 Mdot
.63239 .44867 Mdot
.26385 .52883 Mdot
.54112 .36718 Mdot
.53591 .36912 Mdot
.55138 .55696 Mdot
.70762 .43899 Mdot
.4705 .64936 Mdot
.46101 .2124 Mdot
.66514 .60221 Mdot
.66626 .55159 Mdot
.78032 .61137 Mdot
.51223 .73488 Mdot
.60971 .58039 Mdot
.60426 .57941 Mdot
.48304 .39481 Mdot
.71028 .43086 Mdot
.73897 .30529 Mdot
.42063 .67992 Mdot
.64895 .57095 Mdot
.63379 .60028 Mdot
.2791 .50839 Mdot
.7445 .67365 Mdot
.47769 .30753 Mdot
.50073 .64978 Mdot
.61133 .61526 Mdot
.24657 .49381 Mdot
.66076 .44995 Mdot
.81865 .44281 Mdot
.49558 .31874 Mdot
.49742 .33708 Mdot
.46141 .6431 Mdot
.48308 .66819 Mdot
.47431 .58574 Mdot
.77804 .63761 Mdot
.50237 .20138 Mdot
.40649 .719 Mdot
.28844 .46241 Mdot
.27973 .52243 Mdot
.30617 .50342 Mdot
.47427 .73379 Mdot
.48944 .61616 Mdot
.4778 .33593 Mdot
.3249 .48901 Mdot
.64402 .71058 Mdot
.3376 .57536 Mdot
.68045 .35729 Mdot
.76001 .456 Mdot
.52606 .3532 Mdot
.33846 .49552 Mdot
.35199 .52842 Mdot
.3081 .49575 Mdot
.53212 .75756 Mdot
.47605 .38108 Mdot
.51062 .34357 Mdot
.46955 .33245 Mdot
.46247 .27132 Mdot
.45481 .36385 Mdot
.44165 .70857 Mdot
.53363 .53627 Mdot
.22922 .4462 Mdot
.54733 .39304 Mdot
.49543 .66957 Mdot
.53399 .35508 Mdot
.65204 .43166 Mdot
.51259 .39673 Mdot
.68741 .35967 Mdot
.45455 .63245 Mdot
.28364 .48188 Mdot
.40291 .70922 Mdot
.50771 .32808 Mdot
.63951 .46153 Mdot
.40269 .4714 Mdot
.33783 .76293 Mdot
.69949 .46373 Mdot
.3485 .52163 Mdot
.61845 .57541 Mdot
.45329 .61298 Mdot
.64911 .59442 Mdot
.55691 .36793 Mdot
.49337 .71856 Mdot
.30213 .68568 Mdot
.54273 .49808 Mdot
.44846 .36676 Mdot
.43465 .31732 Mdot
.34475 .52053 Mdot
.60974 .56678 Mdot
.35357 .5614 Mdot
.47661 .34129 Mdot
.6575 .46317 Mdot
.65969 .44198 Mdot
.40789 .59356 Mdot
.22015 .64005 Mdot
.39907 .67551 Mdot
.46273 .64578 Mdot
.62 .61113 Mdot
.69061 .44464 Mdot
.27525 .57598 Mdot
.45201 .59956 Mdot
.45833 .61578 Mdot
.4715 .62347 Mdot
.52288 .40223 Mdot
.59506 .59365 Mdot
.22947 .43503 Mdot
.60797 .62355 Mdot
.51745 .34995 Mdot
.62998 .6203 Mdot
.59836 .58851 Mdot
.6535 .4398 Mdot
.49014 .62967 Mdot
.63262 .62707 Mdot
.47389 .40966 Mdot
.31651 .54505 Mdot
.47927 .48678 Mdot
.6956 .33317 Mdot
.19584 .46989 Mdot
.20995 .47476 Mdot
.31204 .55097 Mdot
.22217 .68519 Mdot
.50293 .63582 Mdot
.49283 .25369 Mdot
.58138 .7518 Mdot
.49137 .41848 Mdot
.84245 .47477 Mdot
.67062 .60886 Mdot
.59807 .56932 Mdot
.48251 .40401 Mdot
.69842 .61042 Mdot
.47993 .36639 Mdot
.63721 .62362 Mdot
.70769 .48827 Mdot
.45945 .43305 Mdot
.64269 .57912 Mdot
.5419 .40719 Mdot
.51294 .37001 Mdot
.33656 .50269 Mdot
.65457 .58071 Mdot
.44564 .39136 Mdot
.15244 .45988 Mdot
.48838 .66194 Mdot
.53189 .74408 Mdot
.63176 .24789 Mdot
.48198 .64706 Mdot
.32043 .53908 Mdot
.45735 .30919 Mdot
.66907 .43452 Mdot
.30939 .51259 Mdot
.73074 .35724 Mdot
.66066 .4791 Mdot
.83829 .4833 Mdot
.35052 .51573 Mdot
.64414 .56787 Mdot
.6475 .44349 Mdot
.51688 .42502 Mdot
.6038 .5547 Mdot
.42025 .4955 Mdot
.61071 .57706 Mdot
.46586 .37879 Mdot
.48375 .74303 Mdot
.49712 .64549 Mdot
.50472 .35605 Mdot
.60664 .55889 Mdot
.50173 .74623 Mdot
.5236 .40019 Mdot
.49638 .39707 Mdot
.70052 .73003 Mdot
.81218 .48349 Mdot
.67825 .44322 Mdot
.34102 .47987 Mdot
.46777 .40481 Mdot
.64313 .45508 Mdot
.72625 .56757 Mdot
.53896 .37223 Mdot
.28836 .50648 Mdot
.489 .28151 Mdot
.63242 .56439 Mdot
.48752 .64872 Mdot
.53467 .50552 Mdot
.64166 .45317 Mdot
.59271 .1527 Mdot
.60525 .61789 Mdot
.45323 .40708 Mdot
.44662 .36686 Mdot
.63405 .74468 Mdot
.35697 .5198 Mdot
.51237 .20659 Mdot
.46588 .35866 Mdot
.4508 .27884 Mdot
.49423 .35794 Mdot
.63855 .51636 Mdot
.33829 .51578 Mdot
.4685 .37278 Mdot
.27818 .60478 Mdot
.47576 .42601 Mdot
.64023 .45601 Mdot
.28602 .28112 Mdot
.54117 .38246 Mdot
.722 .79141 Mdot
.78314 .53265 Mdot
.64593 .58182 Mdot
.47147 .73855 Mdot
.29833 .21307 Mdot
.41418 .70807 Mdot
.35541 .49393 Mdot
.29792 .70815 Mdot
.65031 .60132 Mdot
.44489 .75292 Mdot
.21752 .68538 Mdot
.51377 .37228 Mdot
.52979 .34825 Mdot
.63355 .50564 Mdot
.62576 .63381 Mdot
.5974 .55062 Mdot
.55424 .37432 Mdot
.52768 .30324 Mdot
.65575 .60759 Mdot
.46195 .40345 Mdot
.55404 .39875 Mdot
.43774 .62719 Mdot
.31007 .54877 Mdot
.45819 .66158 Mdot
.4827 .62087 Mdot
.35562 .26305 Mdot
.76528 .64559 Mdot
.48677 .66127 Mdot
.50281 .64209 Mdot
.67192 .34057 Mdot
.63695 .38738 Mdot
.68483 .47139 Mdot
.19565 .58793 Mdot
.63333 .59585 Mdot
.479 .38013 Mdot
.32165 .55401 Mdot
.44862 .23896 Mdot
.76436 .53884 Mdot
.74914 .31275 Mdot
.47629 .33893 Mdot
.64037 .60185 Mdot
.53142 .75884 Mdot
.5654 .36607 Mdot
.64397 .54256 Mdot
.4973 .33363 Mdot
.58878 .56837 Mdot
.33175 .38015 Mdot
.24297 .58617 Mdot
.60315 .54651 Mdot
.29648 .56136 Mdot
.49219 .34256 Mdot
.35077 .52249 Mdot
.45764 .65669 Mdot
.65583 .43298 Mdot
.67788 .44569 Mdot
.49631 .38964 Mdot
.42436 .31936 Mdot
.72984 .6226 Mdot
.51408 .36439 Mdot
.5176 .39076 Mdot
.53412 .75877 Mdot
.51569 .38969 Mdot
.44931 .35834 Mdot
.45522 .34498 Mdot
.44224 .40366 Mdot
.49207 .66407 Mdot
.25779 .604 Mdot
.5534 .34371 Mdot
.5625 .38272 Mdot
.44084 .66441 Mdot
.33233 .7468 Mdot
.48273 .61791 Mdot
.27253 .73664 Mdot
.45143 .66073 Mdot
.67695 .45633 Mdot
.55009 .7771 Mdot
.42681 .32225 Mdot
.29144 .52216 Mdot
.46125 .60013 Mdot
.65163 .46386 Mdot
.46555 .65313 Mdot
.64244 .61983 Mdot
.58359 .81365 Mdot
.27085 .55274 Mdot
.55085 .22026 Mdot
.40309 .59896 Mdot
.56583 .66675 Mdot
.62409 .62769 Mdot
.34104 .51173 Mdot
.3683 .38694 Mdot
.45025 .34996 Mdot
.64391 .45496 Mdot
.48474 .39068 Mdot
.49837 .6526 Mdot
.64184 .598 Mdot
.28794 .27487 Mdot
.67271 .43429 Mdot
.73372 .71395 Mdot
.62361 .59627 Mdot
.46519 .33109 Mdot
.50011 .65205 Mdot
.76832 .69485 Mdot
.46508 .66382 Mdot
.41119 .43376 Mdot
.29016 .54966 Mdot
.38867 .2297 Mdot
.31085 .52226 Mdot
.67371 .59162 Mdot
.59769 .83563 Mdot
.19739 .54117 Mdot
.30332 .53883 Mdot
.58765 .65701 Mdot
.5319 .36157 Mdot
.53551 .36576 Mdot
.24003 .55215 Mdot
.33085 .48139 Mdot
.45296 .38332 Mdot
.5412 .75341 Mdot
.31169 .64678 Mdot
.79443 .51019 Mdot
.6098 .57212 Mdot
.47541 .36403 Mdot
.44004 .66711 Mdot
.43972 .63423 Mdot
.60266 .61726 Mdot
.48036 .61506 Mdot
.5104 .3453 Mdot
.31094 .51846 Mdot
.58612 .56212 Mdot
.67056 .45459 Mdot
.17384 .41587 Mdot
.69192 .44061 Mdot
.60973 .58137 Mdot
.45963 .42976 Mdot
.65246 .60144 Mdot
.35855 .15465 Mdot
.50596 .3419 Mdot
.33837 .5397 Mdot
.49877 .40333 Mdot
.49376 .34609 Mdot
.53114 .34983 Mdot
.65034 .61453 Mdot
.54361 .20501 Mdot
.46741 .40735 Mdot
.47298 .63428 Mdot
.23746 .46559 Mdot
.53251 .34962 Mdot
.68983 .49854 Mdot
.65264 .36849 Mdot
.62874 .66981 Mdot
.31289 .55631 Mdot
.62618 .57006 Mdot
.31728 .54234 Mdot
.31261 .57311 Mdot
.32094 .53909 Mdot
.26442 .44598 Mdot
.36071 .38581 Mdot
.57819 .20513 Mdot
.27095 .32219 Mdot
.56385 .30712 Mdot
.33667 .48037 Mdot
.61084 .45175 Mdot
.30843 .49919 Mdot
.35355 .5231 Mdot
.38197 .88904 Mdot
.29475 .51767 Mdot
.47449 .35715 Mdot
.51554 .32553 Mdot
.35409 .70474 Mdot
.64391 .31217 Mdot
.50868 .38958 Mdot
.47829 .40761 Mdot
.65627 .43469 Mdot
.41457 .32677 Mdot
.49431 .71936 Mdot
.8279 .51844 Mdot
.39335 .739 Mdot
.48755 .39068 Mdot
.47227 .40772 Mdot
.55119 .32569 Mdot
.75591 .73353 Mdot
.38017 .2599 Mdot
.31802 .48152 Mdot
.46832 .29861 Mdot
.18278 .47615 Mdot
.50384 .32929 Mdot
.52722 .40196 Mdot
.52775 .35489 Mdot
.64984 .60118 Mdot
.2826 .51646 Mdot
.48616 .29704 Mdot
.77228 .59998 Mdot
.51216 .33249 Mdot
.50984 .73558 Mdot
.39071 .1788 Mdot
.47024 .36468 Mdot
.28755 .53242 Mdot
.53107 .383 Mdot
.35259 .51054 Mdot
.32596 .49951 Mdot
.45981 .42579 Mdot
.27252 .46471 Mdot
.28326 .52845 Mdot
.51824 .35058 Mdot
.646 .61069 Mdot
.18771 .59155 Mdot
.464 .37725 Mdot
.67479 .43056 Mdot
.4671 .35557 Mdot
.63759 .45873 Mdot
.51862 .38374 Mdot
.60006 .61358 Mdot
.40656 .28366 Mdot
.63951 .58859 Mdot
.43252 .18816 Mdot
.59297 .5929 Mdot
.70843 .72504 Mdot
.30195 .49059 Mdot
.48965 .74122 Mdot
.6828 .22875 Mdot
.52391 .73753 Mdot
.49923 .56836 Mdot
.48574 .54965 Mdot
.45803 .61829 Mdot
.35547 .5312 Mdot
.54698 .25255 Mdot
.64463 .72055 Mdot
.61777 .74644 Mdot
.59961 .59668 Mdot
.67802 .20997 Mdot
.77273 .33004 Mdot
.49304 .4119 Mdot
.30545 .43079 Mdot
.27065 .37234 Mdot
.54012 .37854 Mdot
.45483 .30995 Mdot
.60922 .63636 Mdot
.44543 .3758 Mdot
.32258 .60263 Mdot
.61079 .58719 Mdot
.64989 .46279 Mdot
.34554 .52963 Mdot
.64069 .43853 Mdot
.63512 .72895 Mdot
.48116 .5516 Mdot
.62907 .6242 Mdot
.45975 .4187 Mdot
.49184 .40539 Mdot
.34327 .50296 Mdot
.38254 .5078 Mdot
.29841 .51858 Mdot
.68645 .44979 Mdot
.61478 .5886 Mdot
.41267 .25044 Mdot
.46935 .40176 Mdot
.31925 .51353 Mdot
.45929 .57504 Mdot
.4636 .40029 Mdot
.47328 .65608 Mdot
.5223 .34608 Mdot
.30942 .54415 Mdot
.51572 .38938 Mdot
.30888 .52009 Mdot
.62244 .5751 Mdot
.49743 .32363 Mdot
.48112 .40158 Mdot
.7501 .70997 Mdot
.67003 .4641 Mdot
.32162 .48267 Mdot
.70224 .60997 Mdot
.44738 .34917 Mdot
.55715 .69326 Mdot
.48903 .34077 Mdot
.36987 .55842 Mdot
.46293 .41664 Mdot
.52069 .75405 Mdot
.47988 .30956 Mdot
.46464 .37672 Mdot
.42033 .57032 Mdot
.26512 .40061 Mdot
.38421 .49446 Mdot
.49777 .66093 Mdot
.29262 .51014 Mdot
.77345 .47384 Mdot
.66329 .58441 Mdot
.6146 .5634 Mdot
.59604 .26995 Mdot
.43212 .38797 Mdot
.48339 .37111 Mdot
.43168 .64841 Mdot
.65715 .47488 Mdot
.32709 .51126 Mdot
.64782 .45844 Mdot
.7834 .6018 Mdot
.67933 .46873 Mdot
.66419 .62974 Mdot
.73941 .61779 Mdot
.38969 .27373 Mdot
.65615 .43514 Mdot
.29778 .5343 Mdot
.75215 .45982 Mdot
.49924 .42061 Mdot
.6436 .4042 Mdot
.65786 .46157 Mdot
.6621 .19143 Mdot
.44937 .36145 Mdot
.5088 .57089 Mdot
.48561 .65816 Mdot
.64927 .44492 Mdot
.45556 .62431 Mdot
.50518 .39102 Mdot
.55056 .6793 Mdot
.34575 .48615 Mdot
.47046 .68163 Mdot
.54519 .36487 Mdot
.67912 .46401 Mdot
.61123 .61376 Mdot
.4874 .59757 Mdot
.48787 .67483 Mdot
.29974 .72507 Mdot
.33529 .24 Mdot
.6166 .5886 Mdot
.77668 .40291 Mdot
.44425 .65325 Mdot
.53583 .3938 Mdot
.42547 .3 Mdot
.50254 .33529 Mdot
.42166 .70118 Mdot
.62136 .56824 Mdot
.31016 .66611 Mdot
.49652 .40551 Mdot
.46765 .33857 Mdot
.37877 .48687 Mdot
.63101 .58669 Mdot
.32566 .52726 Mdot
.29542 .50853 Mdot
.62314 .57618 Mdot
.31304 .5293 Mdot
.65725 .47953 Mdot
.32366 .64784 Mdot
.44823 .66508 Mdot
.46959 .63214 Mdot
.63497 .59987 Mdot
.65365 .59023 Mdot
.65215 .59487 Mdot
.52193 .34558 Mdot
.33301 .51326 Mdot
.52442 .36885 Mdot
.53094 .35052 Mdot
.34227 .45438 Mdot
.30819 .55196 Mdot
.53062 .36827 Mdot
.66804 .56895 Mdot
.65942 .40524 Mdot
.64404 .61304 Mdot
.4881 .65818 Mdot
.45281 .7735 Mdot
.5096 .66047 Mdot
.47797 .36208 Mdot
.72641 .67077 Mdot
.29856 .53006 Mdot
.66387 .43731 Mdot
.66811 .48598 Mdot
.67211 .43919 Mdot
.4455 .68553 Mdot
.31793 .48697 Mdot
.82889 .51534 Mdot
.47692 .36658 Mdot
.5508 .55975 Mdot
.51667 .23351 Mdot
.72935 .63953 Mdot
.48984 .65752 Mdot
.46936 .40507 Mdot
.5285 .50184 Mdot
.37499 .35947 Mdot
.49909 .33814 Mdot
.51033 .42256 Mdot
.55715 .74198 Mdot
.5174 .28782 Mdot
.2855 .54204 Mdot
.79309 .62668 Mdot
.50857 .31592 Mdot
.24262 .52215 Mdot
.19692 .34069 Mdot
.48418 .35607 Mdot
.46859 .34399 Mdot
.4653 .38915 Mdot
.51163 .40041 Mdot
.28771 .53753 Mdot
.60439 .29835 Mdot
.50124 .63183 Mdot
.56585 .53482 Mdot
.45281 .6712 Mdot
.59446 .56298 Mdot
.27648 .61683 Mdot
.35267 .53726 Mdot
.66033 .43676 Mdot
.22175 .58047 Mdot
.81619 .57856 Mdot
.65821 .62289 Mdot
.35591 .30451 Mdot
.66444 .46265 Mdot
.53285 .40011 Mdot
.63953 .4709 Mdot
.59442 .59111 Mdot
.47747 .63008 Mdot
.42802 .37754 Mdot
.30224 .5095 Mdot
.33122 .54876 Mdot
.4539 .38564 Mdot
.18942 .50223 Mdot
.47814 .65514 Mdot
.46144 .59483 Mdot
.53212 .39238 Mdot
.52922 .41494 Mdot
.32636 .53035 Mdot
.62634 .60761 Mdot
.74766 .40173 Mdot
.66443 .47232 Mdot
.44024 .35755 Mdot
.51486 .39877 Mdot
.78143 .63328 Mdot
.48808 .63554 Mdot
.66046 .62704 Mdot
.51734 .40505 Mdot
.4388 .72868 Mdot
.51746 .40459 Mdot
.55876 .33145 Mdot
.64452 .60944 Mdot
.53562 .31831 Mdot
.47482 .41209 Mdot
.4445 .44267 Mdot
.4455 .6371 Mdot
.33582 .5391 Mdot
.3451 .5567 Mdot
.59576 .48573 Mdot
.47062 .65628 Mdot
.53137 .37481 Mdot
.48765 .64063 Mdot
.5361 .36121 Mdot
.45174 .38485 Mdot
.48311 .66467 Mdot
.32486 .52737 Mdot
.31641 .71664 Mdot
.26467 .60996 Mdot
.50927 .40186 Mdot
.49937 .31323 Mdot
.62006 .29932 Mdot
.62172 .21567 Mdot
.4817 .33902 Mdot
.31865 .5474 Mdot
.47547 .40421 Mdot
.45203 .63056 Mdot
.67487 .47559 Mdot
.31378 .54469 Mdot
.61803 .60277 Mdot
.6466 .6294 Mdot
.40315 .70756 Mdot
.59996 .5828 Mdot
.50878 .4165 Mdot
.30354 .57236 Mdot
.37124 .51824 Mdot
.18325 .37535 Mdot
.62455 .57882 Mdot
.66111 .48316 Mdot
.49757 .39494 Mdot
.70452 .71143 Mdot
.43162 .64053 Mdot
.76251 .7612 Mdot
.83589 .49409 Mdot
.69063 .43523 Mdot
.72563 .2792 Mdot
.59454 .55849 Mdot
.45022 .39065 Mdot
.65567 .43232 Mdot
.65928 .61959 Mdot
.49921 .41595 Mdot
.42552 .37791 Mdot
.52053 .20452 Mdot
.58213 .49362 Mdot
.48922 .64159 Mdot
.64232 .57398 Mdot
.66001 .49307 Mdot
.65187 .63397 Mdot
.33536 .54868 Mdot
.46802 .37671 Mdot
.41466 .36871 Mdot
.62148 .6062 Mdot
.63065 .63462 Mdot
.52467 .35413 Mdot
.35705 .52816 Mdot
.6391 .64313 Mdot
.4932 .38699 Mdot
.54492 .2875 Mdot
.29151 .55783 Mdot
.60911 .59098 Mdot
.46079 .34133 Mdot
.68726 .40001 Mdot
.62549 .59981 Mdot
.64255 .61415 Mdot
.45338 .38625 Mdot
.65373 .47837 Mdot
.48355 .31668 Mdot
.45562 .66499 Mdot
.49734 .18683 Mdot
.45661 .62634 Mdot
.75694 .48619 Mdot
.48322 .43381 Mdot
.53711 .65736 Mdot
.33818 .54961 Mdot
.67468 .49479 Mdot
.48005 .78996 Mdot
.55387 .38344 Mdot
.21726 .65289 Mdot
.50453 .50244 Mdot
.17218 .4802 Mdot
.46772 .81723 Mdot
.65727 .4569 Mdot
.46161 .65351 Mdot
.46904 .34424 Mdot
.45729 .60704 Mdot
.66458 .42914 Mdot
.41436 .20749 Mdot
.45603 .34606 Mdot
.33944 .51725 Mdot
.51897 .34672 Mdot
.34929 .52086 Mdot
.45797 .39365 Mdot
.56342 .36268 Mdot
.53428 .76626 Mdot
.72092 .35252 Mdot
.49139 .41926 Mdot
.60095 .81423 Mdot
.7655 .56731 Mdot
.65734 .46735 Mdot
.5205 .36565 Mdot
.67297 .59597 Mdot
.4428 .62833 Mdot
.35115 .58183 Mdot
.65067 .60316 Mdot
.4925 .62636 Mdot
.32148 .53422 Mdot
.6151 .57227 Mdot
.63282 .63186 Mdot
.51099 .30819 Mdot
.63823 .45057 Mdot
.47784 .62494 Mdot
.46527 .37158 Mdot
.45344 .35296 Mdot
.77511 .42111 Mdot
.75598 .53244 Mdot
.37276 .52874 Mdot
.81258 .64399 Mdot
.36003 .54308 Mdot
.67157 .46685 Mdot
.64953 .60731 Mdot
.4843 .34111 Mdot
.50611 .35787 Mdot
.49366 .74453 Mdot
.34476 .48416 Mdot
.56642 .49877 Mdot
.33883 .28561 Mdot
.6317 .64159 Mdot
.64714 .34923 Mdot
.34076 .53999 Mdot
.64725 .34714 Mdot
.65628 .49166 Mdot
.2124 .58757 Mdot
.71259 .35826 Mdot
.4879 .65508 Mdot
.64257 .34704 Mdot
.31789 .50577 Mdot
.49308 .41002 Mdot
.65258 .57552 Mdot
.59899 .58888 Mdot
.33499 .53286 Mdot
.58529 .60436 Mdot
.65331 .44183 Mdot
.46264 .34788 Mdot
.82087 .50824 Mdot
.36862 .67084 Mdot
.6243 .61306 Mdot
.56537 .3823 Mdot
.46901 .62353 Mdot
.44929 .37939 Mdot
.67703 .43246 Mdot
.47821 .64301 Mdot
.78068 .51539 Mdot
.31119 .65594 Mdot
.50026 .38953 Mdot
.72688 .70099 Mdot
.47369 .65264 Mdot
.69503 .26221 Mdot
.48584 .38536 Mdot
.44411 .65167 Mdot
.50847 .2912 Mdot
.67301 .6692 Mdot
.53666 .49618 Mdot
.21501 .68323 Mdot
.55009 .50283 Mdot
.62041 .55539 Mdot
.63817 .68852 Mdot
.61015 .72581 Mdot
.45417 .60934 Mdot
.63543 .63489 Mdot
.71224 .44756 Mdot
.45548 .62378 Mdot
.52925 .34522 Mdot
.48774 .34692 Mdot
.3828 .25296 Mdot
.4978 .50973 Mdot
.68359 .60776 Mdot
.38495 .63349 Mdot
.4493 .34623 Mdot
.52374 .32165 Mdot
.50244 .36523 Mdot
.28443 .49875 Mdot
.48347 .6341 Mdot
.67872 .76736 Mdot
.46882 .6582 Mdot
.81364 .44138 Mdot
.63509 .59605 Mdot
.62975 .5688 Mdot
.47322 .36274 Mdot
.5509 .6026 Mdot
.61294 .35748 Mdot
.51214 .347 Mdot
.57152 .55346 Mdot
.26778 .2987 Mdot
.54018 .35448 Mdot
.29559 .55417 Mdot
.52281 .43823 Mdot
.27141 .51829 Mdot
.44628 .66384 Mdot
.66303 .45145 Mdot
.68542 .48715 Mdot
.47932 .62834 Mdot
.4852 .37136 Mdot
.52356 .68034 Mdot
.49736 .34928 Mdot
.50364 .40961 Mdot
.81535 .42382 Mdot
.69031 .4378 Mdot
.64043 .58129 Mdot
.67664 .44002 Mdot
.35553 .52028 Mdot
.56762 .90122 Mdot
.65364 .47353 Mdot
.6087 .36041 Mdot
.44332 .19575 Mdot
.64049 .34326 Mdot
.33923 .5455 Mdot
.64504 .42372 Mdot
.48455 .65193 Mdot
.16487 .55672 Mdot
.59304 .19669 Mdot
.50112 .61277 Mdot
.49488 .38184 Mdot
.3607 .52595 Mdot
.30154 .54242 Mdot
.46833 .68089 Mdot
.3244 .50113 Mdot
.47803 .29154 Mdot
.50297 .40603 Mdot
.46267 .60732 Mdot
.36572 .69973 Mdot
.48847 .67467 Mdot
.32077 .62527 Mdot
.52102 .3604 Mdot
.33378 .54461 Mdot
.5143 .44001 Mdot
.3019 .47922 Mdot
.66438 .62508 Mdot
.54069 .38706 Mdot
.65441 .44012 Mdot
.52954 .65643 Mdot
.6178 .59112 Mdot
.72109 .6735 Mdot
.34507 .50525 Mdot
.51466 .59774 Mdot
.33469 .50138 Mdot
.35284 .48019 Mdot
.48058 .6191 Mdot
.34024 .48794 Mdot
.46697 .34449 Mdot
.66203 .57269 Mdot
.35231 .50283 Mdot
.45791 .63685 Mdot
.66842 .44872 Mdot
.31596 .52777 Mdot
.69855 .61327 Mdot
.48989 .39842 Mdot
.65187 .61903 Mdot
.56348 .77543 Mdot
.36594 .50476 Mdot
.65544 .41898 Mdot
.60983 .56603 Mdot
.64235 .44067 Mdot
.23537 .32179 Mdot
.48738 .61345 Mdot
.75734 .33007 Mdot
.68974 .4037 Mdot
.29419 .52252 Mdot
.55154 .77361 Mdot
.48294 .34441 Mdot
.49263 .39826 Mdot
.63502 .44734 Mdot
.3011 .54199 Mdot
.18915 .55187 Mdot
.38333 .47085 Mdot
.32311 .66047 Mdot
.47714 .60558 Mdot
.67593 .75686 Mdot
.30789 .6126 Mdot
.32947 .21867 Mdot
.54367 .34304 Mdot
.59447 .55565 Mdot
.48698 .36397 Mdot
.46458 .78476 Mdot
.68277 .45846 Mdot
.6628 .51463 Mdot
.47363 .42831 Mdot
.62685 .57323 Mdot
.47395 .39213 Mdot
.42045 .54951 Mdot
.5467 .41866 Mdot
.66896 .48114 Mdot
.48853 .72602 Mdot
.29307 .51705 Mdot
.66894 .45751 Mdot
.60847 .6185 Mdot
.62502 .35743 Mdot
.48201 .41725 Mdot
.5559 .36002 Mdot
.64306 .64179 Mdot
.33989 .51317 Mdot
.63475 .56369 Mdot
.44743 .66335 Mdot
.65769 .44545 Mdot
.50253 .39753 Mdot
.46242 .41787 Mdot
.55846 .69455 Mdot
.47772 .6228 Mdot
.5954 .62092 Mdot
.46385 .66245 Mdot
.60132 .55042 Mdot
.49005 .31188 Mdot
.62733 .56754 Mdot
.45479 .40195 Mdot
.50495 .7846 Mdot
.81188 .42027 Mdot
.27537 .4098 Mdot
.61653 .56862 Mdot
.6749 .36795 Mdot
.4523 .63514 Mdot
.45253 .65982 Mdot
.42755 .22329 Mdot
.39715 .37954 Mdot
.7896 .47127 Mdot
.31581 .74768 Mdot
.45232 .67022 Mdot
.46311 .62581 Mdot
.65326 .62018 Mdot
.34623 .48983 Mdot
.36588 .49165 Mdot
.59042 .56598 Mdot
.631 .25577 Mdot
.32693 .51132 Mdot
.20702 .61521 Mdot
.78362 .48529 Mdot
.48583 .29908 Mdot
.46609 .5851 Mdot
.66247 .44365 Mdot
.64779 .27613 Mdot
.41805 .55791 Mdot
.47037 .33873 Mdot
.77457 .64212 Mdot
.63167 .60642 Mdot
.57978 .26384 Mdot
.27509 .73768 Mdot
.45291 .34997 Mdot
.48019 .38172 Mdot
.49264 .36847 Mdot
.68497 .42853 Mdot
.40974 .29469 Mdot
.45737 .34855 Mdot
.62942 .25232 Mdot
.44512 .35185 Mdot
.54775 .45264 Mdot
.67784 .44387 Mdot
.57369 .42572 Mdot
.54756 .7528 Mdot
.79332 .58028 Mdot
.45737 .43939 Mdot
.4483 .6627 Mdot
.58799 .52399 Mdot
.4439 .63749 Mdot
.26395 .43954 Mdot
.70748 .35343 Mdot
.32214 .5631 Mdot
.47073 .34019 Mdot
.60939 .58223 Mdot
.30347 .54401 Mdot
.60826 .70053 Mdot
.45828 .92618 Mdot
.44271 .65581 Mdot
.3965 .15173 Mdot
.45758 .66318 Mdot
.62458 .6306 Mdot
.32705 .53152 Mdot
.35596 .38409 Mdot
.54999 .55647 Mdot
.31347 .52687 Mdot
.30705 .69528 Mdot
.36874 .47884 Mdot
.6566 .36194 Mdot
.3626 .5346 Mdot
.45555 .63654 Mdot
.46576 .6884 Mdot
.42518 .34577 Mdot
.47544 .35236 Mdot
.47571 .54974 Mdot
.62835 .378 Mdot
.4791 .34769 Mdot
.61244 .58713 Mdot
.6798 .24179 Mdot
.60759 .48284 Mdot
.32387 .49262 Mdot
.50537 .65664 Mdot
.47815 .3838 Mdot
.51714 .40189 Mdot
.4884 .41594 Mdot
.82128 .64095 Mdot
.20481 .57752 Mdot
.46759 .40722 Mdot
.45173 .33815 Mdot
.61795 .57197 Mdot
.63216 .47375 Mdot
.44672 .78682 Mdot
.48562 .46523 Mdot
.48917 .32771 Mdot
.67421 .45588 Mdot
.69437 .44321 Mdot
.50028 .41613 Mdot
.76962 .5989 Mdot
.55025 .65911 Mdot
.46492 .37204 Mdot
.40549 .41026 Mdot
.63139 .72319 Mdot
.62853 .6339 Mdot
.62158 .60382 Mdot
.2878 .52931 Mdot
.60248 .58564 Mdot
.59271 .59509 Mdot
.36187 .357 Mdot
.54948 .51465 Mdot
.4289 .67138 Mdot
.6866 .44904 Mdot
.5045 .35451 Mdot
.37401 .52042 Mdot
.45654 .72994 Mdot
.46449 .61777 Mdot
.30298 .53081 Mdot
.44088 .63348 Mdot
.67531 .41714 Mdot
.54723 .22404 Mdot
.59738 .59431 Mdot
.46626 .6768 Mdot
.31118 .65469 Mdot
.67585 .45279 Mdot
.4915 .6293 Mdot
.53094 .67771 Mdot
.53069 .34493 Mdot
.34359 .43737 Mdot
.51518 .3512 Mdot
.18063 .51685 Mdot
.49223 .63286 Mdot
.51649 .7515 Mdot
.47742 .373 Mdot
.62532 .59694 Mdot
.5448 .31086 Mdot
.49689 .33254 Mdot
.61362 .60391 Mdot
.49259 .41167 Mdot
.66102 .42571 Mdot
.28143 .55403 Mdot
.57308 .52174 Mdot
.81803 .34591 Mdot
.63801 .44809 Mdot
.59599 .698 Mdot
.47987 .33863 Mdot
.29597 .26659 Mdot
.31584 .52601 Mdot
.45661 .40791 Mdot
.59135 .33442 Mdot
.35679 .50102 Mdot
.3104 .53841 Mdot
.52544 .38646 Mdot
.4832 .65866 Mdot
.61596 .5933 Mdot
.67689 .44662 Mdot
.23802 .30806 Mdot
.50291 .37707 Mdot
.47895 .40303 Mdot
.66594 .461 Mdot
.46004 .62524 Mdot
.52298 .39811 Mdot
.57461 .78484 Mdot
.15692 .46288 Mdot
.4626 .61475 Mdot
.51478 .3299 Mdot
.36506 .44623 Mdot
.26785 .52185 Mdot
.49635 .1571 Mdot
.73924 .43245 Mdot
.63694 .576 Mdot
.50746 .28603 Mdot
.63782 .8532 Mdot
.6645 .44978 Mdot
.81448 .54471 Mdot
.50809 .40978 Mdot
.46464 .39602 Mdot
.29848 .52158 Mdot
.5275 .36741 Mdot
.36111 .49961 Mdot
.78984 .31536 Mdot
.77898 .6482 Mdot
.34609 .51379 Mdot
.29941 .51147 Mdot
.60133 .35977 Mdot
.44995 .78622 Mdot
.3332 .53493 Mdot
.45913 .3255 Mdot
.22094 .50543 Mdot
.47001 .45478 Mdot
.6343 .4526 Mdot
.59425 .75678 Mdot
.28207 .48521 Mdot
.62095 .48272 Mdot
.3071 .72343 Mdot
.27481 .48932 Mdot
.5648 .65073 Mdot
.45969 .66862 Mdot
.45859 .33905 Mdot
.599 .58588 Mdot
.61655 .56397 Mdot
.53634 .42418 Mdot
.50189 .34775 Mdot
.35307 .51282 Mdot
.68864 .4516 Mdot
.44821 .61616 Mdot
.47917 .40747 Mdot
.61057 .48632 Mdot
.65631 .47285 Mdot
.33515 .4929 Mdot
.47733 .22973 Mdot
.66578 .48289 Mdot
.55548 .41602 Mdot
.46192 .36299 Mdot
.52623 .35342 Mdot
.43799 .44426 Mdot
.48783 .66471 Mdot
.54327 .77677 Mdot
.50158 .31956 Mdot
.78403 .60262 Mdot
.45323 .4783 Mdot
.53326 .3126 Mdot
.32953 .50618 Mdot
.4311 .64204 Mdot
.67408 .60994 Mdot
.56453 .27482 Mdot
.50235 .38465 Mdot
.20755 .56065 Mdot
.363 .26553 Mdot
.66979 .61514 Mdot
.33693 .4808 Mdot
.66628 .43776 Mdot
.51028 .34688 Mdot
.25016 .46522 Mdot
.48471 .35196 Mdot
.68349 .40778 Mdot
.63878 .61217 Mdot
.46222 .66915 Mdot
.16841 .47584 Mdot
.61768 .56413 Mdot
.31531 .54161 Mdot
.22756 .72607 Mdot
.36257 .52963 Mdot
.30791 .4972 Mdot
.26124 .46986 Mdot
.481 .66968 Mdot
.66356 .84199 Mdot
.56698 .17986 Mdot
.51817 .42282 Mdot
.44924 .63996 Mdot
.33876 .52754 Mdot
.44937 .37664 Mdot
.33379 .55405 Mdot
.3211 .48451 Mdot
.50969 .31101 Mdot
.45686 .37963 Mdot
.27829 .61355 Mdot
.23263 .69664 Mdot
.66918 .43652 Mdot
.35204 .53127 Mdot
.53468 .27096 Mdot
.44762 .37124 Mdot
.47623 .36703 Mdot
.63526 .71112 Mdot
.65655 .48005 Mdot
.34505 .59445 Mdot
.51239 .40691 Mdot
.75991 .67239 Mdot
.52035 .43936 Mdot
.2874 .53886 Mdot
.46698 .61553 Mdot
.79425 .57191 Mdot
.41214 .67564 Mdot
.34966 .48572 Mdot
.68302 .4385 Mdot
.34853 .5552 Mdot
.60981 .36469 Mdot
.48581 .67277 Mdot
.30935 .54413 Mdot
.5337 .50488 Mdot
.47102 .64267 Mdot
.49264 .63729 Mdot
.23695 .46769 Mdot
.58808 .60155 Mdot
.6753 .42394 Mdot
.47453 .62464 Mdot
.49637 .25542 Mdot
.45667 .64552 Mdot
.4365 .23399 Mdot
.49973 .32334 Mdot
.5959 .25114 Mdot
.50733 .57879 Mdot
.43025 .3197 Mdot
.49736 .64855 Mdot
.66751 .43045 Mdot
.52464 .39241 Mdot
.31957 .50218 Mdot
.64851 .46496 Mdot
.50002 .6023 Mdot
.65464 .6079 Mdot
.33575 .49941 Mdot
.49196 .61373 Mdot
.34607 .53582 Mdot
.5527 .25509 Mdot
.47897 .18388 Mdot
.62161 .7684 Mdot
.55018 .54987 Mdot
.49232 .41536 Mdot
.36891 .76927 Mdot
.48823 .30276 Mdot
.50039 .343 Mdot
.61023 .59071 Mdot
.59228 .26583 Mdot
.32579 .52774 Mdot
.16559 .48399 Mdot
.46242 .67422 Mdot
.79275 .63094 Mdot
.37713 .54249 Mdot
.46041 .41211 Mdot
.35395 .50397 Mdot
.36167 .53314 Mdot
.25978 .39912 Mdot
.67277 .62532 Mdot
.43534 .34174 Mdot
.43964 .32979 Mdot
.54804 .34155 Mdot
.49191 .63997 Mdot
.72648 .66571 Mdot
.60974 .55361 Mdot
.47417 .17258 Mdot
.63325 .61309 Mdot
.57174 .55011 Mdot
.33714 .4888 Mdot
.65229 .47435 Mdot
.47391 .36756 Mdot
.38866 .51125 Mdot
.35047 .48502 Mdot
.66 .40743 Mdot
.64837 .44396 Mdot
.6684 .68003 Mdot
.48424 .66422 Mdot
.4876 .4204 Mdot
.46091 .34189 Mdot
.52275 .37196 Mdot
.51373 .33988 Mdot
.44336 .65895 Mdot
.53628 .3771 Mdot
.44174 .67387 Mdot
.48141 .24839 Mdot
.76757 .65293 Mdot
.54485 .51276 Mdot
.38466 .5559 Mdot
.31913 .498 Mdot
.51244 .26519 Mdot
.55954 .41258 Mdot
.79627 .39246 Mdot
.20649 .39913 Mdot
.5424 .36288 Mdot
.66173 .61598 Mdot
.39733 .3705 Mdot
.5945 .58318 Mdot
.46411 .12681 Mdot
.5531 .7006 Mdot
.21679 .67402 Mdot
.45232 .36042 Mdot
.63786 .71295 Mdot
.46242 .27307 Mdot
.46835 .30557 Mdot
.59128 .71076 Mdot
.41149 .69582 Mdot
.33495 .70033 Mdot
.6907 .45962 Mdot
.48941 .39423 Mdot
.37443 .50054 Mdot
.46465 .34529 Mdot
.48135 .36452 Mdot
.51081 .40997 Mdot
.50168 .64218 Mdot
.43206 .35789 Mdot
.52051 .34136 Mdot
.72646 .61243 Mdot
.67115 .34599 Mdot
.63967 .57085 Mdot
.42121 .22068 Mdot
.65272 .47149 Mdot
.35046 .50655 Mdot
.25548 .64951 Mdot
.48844 .65481 Mdot
.26322 .3854 Mdot
.52009 .34504 Mdot
.29046 .63249 Mdot
.48472 .60597 Mdot
.65573 .44404 Mdot
.63299 .55939 Mdot
.19558 .63716 Mdot
.61362 .58099 Mdot
.52641 .50464 Mdot
.6241 .59273 Mdot
.52204 .44307 Mdot
.35329 .51404 Mdot
.51137 .41206 Mdot
.47386 .62632 Mdot
.60811 .5964 Mdot
.63209 .30257 Mdot
.50077 .36533 Mdot
.62466 .57632 Mdot
.51253 .41127 Mdot
.5568 .22387 Mdot
.7617 .37752 Mdot
.59502 .60453 Mdot
.43513 .67203 Mdot
.4664 .63961 Mdot
.65653 .47875 Mdot
.3439 .49913 Mdot
.30131 .51763 Mdot
.47645 .64452 Mdot
.61983 .20676 Mdot
.49077 .32889 Mdot
.44915 .37186 Mdot
.78723 .60123 Mdot
.47325 .34562 Mdot
.64044 .36565 Mdot
.53152 .50079 Mdot
.32791 .49376 Mdot
.45235 .39176 Mdot
.5164 .40065 Mdot
.49867 .39236 Mdot
.53823 .24152 Mdot
.62433 .60944 Mdot
.47481 .32757 Mdot
.64673 .44218 Mdot
.66703 .58378 Mdot
.4481 .37759 Mdot
.5488 .34082 Mdot
.3009 .51945 Mdot
.82239 .60063 Mdot
.4655 .66621 Mdot
.61764 .6247 Mdot
.62613 .56863 Mdot
.59882 .75399 Mdot
.30126 .46659 Mdot
.53652 .50055 Mdot
.45125 .17327 Mdot
.53743 .75825 Mdot
.66297 .46631 Mdot
.5425 .61779 Mdot
.48589 .48204 Mdot
.64655 .62674 Mdot
.43945 .6446 Mdot
.50278 .32221 Mdot
.49122 .32659 Mdot
.83758 .47027 Mdot
.46577 .4166 Mdot
.6658 .4406 Mdot
.44752 .67572 Mdot
.31762 .50691 Mdot
.65659 .44232 Mdot
.45481 .65973 Mdot
.33884 .51142 Mdot
.52796 .33518 Mdot
.52126 .32625 Mdot
.30424 .53044 Mdot
.29954 .53807 Mdot
.46472 .36711 Mdot
.582 .55153 Mdot
.29009 .52061 Mdot
.32976 .5473 Mdot
.59679 .59377 Mdot
.60065 .59199 Mdot
.51288 .30773 Mdot
.45018 .64648 Mdot
.52951 .35182 Mdot
.61228 .57554 Mdot
.68276 .46546 Mdot
.32153 .52391 Mdot
.50976 .40279 Mdot
.48706 .40855 Mdot
.67531 .45152 Mdot
.69077 .45418 Mdot
.65105 .44419 Mdot
.46564 .68443 Mdot
.5167 .37181 Mdot
.32638 .53622 Mdot
.4771 .66877 Mdot
.69445 .44265 Mdot
.64407 .47693 Mdot
.58908 .61969 Mdot
.48521 .33891 Mdot
.68096 .63314 Mdot
.55932 .89762 Mdot
.70601 .40124 Mdot
.67208 .61516 Mdot
.6129 .6351 Mdot
.64244 .32952 Mdot
.5557 .58756 Mdot
.47928 .6514 Mdot
.71212 .42787 Mdot
.67629 .49404 Mdot
.54026 .38619 Mdot
.50237 .31552 Mdot
.44409 .32011 Mdot
.65089 .45305 Mdot
.57899 .2843 Mdot
.33996 .55 Mdot
.30954 .28924 Mdot
.65125 .46918 Mdot
.62787 .63447 Mdot
.5872 .60243 Mdot
.63438 .61327 Mdot
.50982 .3219 Mdot
.27741 .40244 Mdot
.58312 .36038 Mdot
.37073 .77651 Mdot
.49622 .63882 Mdot
.33655 .56293 Mdot
.26008 .30089 Mdot
.30727 .53426 Mdot
.59151 .57204 Mdot
.65083 .46249 Mdot
.31061 .54614 Mdot
.4483 .62519 Mdot
.46625 .62598 Mdot
.62713 .61251 Mdot
.63695 .59945 Mdot
.64184 .62139 Mdot
.31434 .4905 Mdot
.34019 .48844 Mdot
.50556 .37942 Mdot
.31522 .51747 Mdot
.84343 .52246 Mdot
.67642 .42051 Mdot
.60999 .635 Mdot
.46096 .65468 Mdot
.34967 .51881 Mdot
.50424 .36328 Mdot
.59776 .49515 Mdot
.3926 .68773 Mdot
.64459 .43573 Mdot
.77048 .40523 Mdot
.45908 .13062 Mdot
.47932 .42065 Mdot
.48963 .63861 Mdot
.81793 .50457 Mdot
.4945 .3698 Mdot
.64681 .60534 Mdot
.50609 .79163 Mdot
.66328 .58421 Mdot
.53023 .34978 Mdot
.49523 .42413 Mdot
.47883 .61475 Mdot
.42332 .19414 Mdot
.50741 .37394 Mdot
.35999 .60066 Mdot
.50679 .65754 Mdot
.60508 .55555 Mdot
.15291 .47636 Mdot
.63028 .74596 Mdot
.64008 .26761 Mdot
.59814 .59794 Mdot
.49296 .34537 Mdot
.60202 .60184 Mdot
.64893 .43269 Mdot
.61158 .61666 Mdot
.29064 .55249 Mdot
.63455 .56564 Mdot
.47748 .40235 Mdot
.33529 .53514 Mdot
.47365 .65338 Mdot
.79921 .61679 Mdot
.74715 .57982 Mdot
.62643 .59743 Mdot
.60573 .61905 Mdot
.4673 .40898 Mdot
.30823 .5999 Mdot
.53962 .41391 Mdot
.45005 .3644 Mdot
.45855 .67555 Mdot
.35192 .50056 Mdot
.50005 .63234 Mdot
.43973 .38076 Mdot
.56284 .7913 Mdot
.46972 .66336 Mdot
.28236 .62979 Mdot
.66426 .4634 Mdot
.43524 .52226 Mdot
.50678 .35482 Mdot
.46677 .62039 Mdot
.51706 .37046 Mdot
.3293 .55528 Mdot
.47835 .5187 Mdot
.46747 .73852 Mdot
.47422 .62869 Mdot
.19199 .53439 Mdot
.57034 .58376 Mdot
.45768 .43081 Mdot
.44363 .64766 Mdot
.59171 .33781 Mdot
.63059 .63189 Mdot
.66396 .47113 Mdot
.69394 .4471 Mdot
.64059 .44574 Mdot
.55016 .38608 Mdot
.46635 .43862 Mdot
.67425 .4267 Mdot
.45411 .61615 Mdot
.67462 .47925 Mdot
.24259 .51537 Mdot
.18766 .5481 Mdot
.68272 .45649 Mdot
.48925 .38574 Mdot
.42098 .4136 Mdot
.66621 .33923 Mdot
.68995 .62219 Mdot
.22054 .66714 Mdot
.36596 .56975 Mdot
.47716 .35276 Mdot
.26307 .5417 Mdot
.32937 .55223 Mdot
.81183 .51002 Mdot
.64175 .38225 Mdot
.77929 .57874 Mdot
.29993 .50851 Mdot
.48752 .74139 Mdot
.33596 .49444 Mdot
.4706 .41648 Mdot
.45133 .37732 Mdot
.36307 .4862 Mdot
.73941 .66461 Mdot
.56524 .68209 Mdot
.17597 .41684 Mdot
.33625 .54568 Mdot
.44603 .63538 Mdot
.44977 .67166 Mdot
.49543 .64375 Mdot
.77955 .47478 Mdot
.36405 .51019 Mdot
.5146 .38031 Mdot
.61347 .57057 Mdot
.47849 .32879 Mdot
.47659 .63752 Mdot
.16655 .48783 Mdot
.30671 .51212 Mdot
.46468 .37561 Mdot
.62092 .21798 Mdot
.64458 .59692 Mdot
.67396 .45918 Mdot
.53345 .21521 Mdot
.78386 .51906 Mdot
.48508 .67037 Mdot
.36786 .51245 Mdot
.51408 .73714 Mdot
.26997 .62531 Mdot
.53595 .33331 Mdot
.51171 .30225 Mdot
.28932 .25207 Mdot
.77884 .50988 Mdot
.52165 .40994 Mdot
.62641 .62884 Mdot
.49547 .74562 Mdot
.50024 .40287 Mdot
.34415 .54348 Mdot
.68798 .4686 Mdot
.64289 .45072 Mdot
.45716 .32093 Mdot
.55139 .56111 Mdot
.4353 .49274 Mdot
.53206 .37406 Mdot
.55584 .41603 Mdot
.59423 .57102 Mdot
.53962 .75497 Mdot
.78617 .61389 Mdot
.6852 .44017 Mdot
.51787 .40618 Mdot
.34428 .72582 Mdot
.33212 .48386 Mdot
.66077 .58945 Mdot
.48979 .67065 Mdot
.5158 .23117 Mdot
.60658 .55405 Mdot
.50094 .40362 Mdot
.52155 .39898 Mdot
.49055 .62673 Mdot
.28744 .53914 Mdot
.6511 .4556 Mdot
.61569 .5678 Mdot
.68413 .4377 Mdot
.35957 .50315 Mdot
.31057 .51011 Mdot
.48493 .45736 Mdot
.43234 .40475 Mdot
.61989 .60258 Mdot
.441 .37347 Mdot
.70006 .6032 Mdot
.41769 .19226 Mdot
.46084 .60004 Mdot
.47935 .42111 Mdot
.28012 .50932 Mdot
.47781 .62926 Mdot
.46096 .38804 Mdot
.25046 .28625 Mdot
.44553 .36697 Mdot
.41577 .68634 Mdot
.60923 .78324 Mdot
.66108 .43291 Mdot
.28704 .29788 Mdot
.24924 .56363 Mdot
.46929 .34822 Mdot
.6572 .59566 Mdot
.56013 .34409 Mdot
.48259 .65661 Mdot
.32786 .49071 Mdot
.5009 .15352 Mdot
.45802 .64223 Mdot
.45768 .35304 Mdot
.65704 .44484 Mdot
.36637 .52349 Mdot
.5979 .52892 Mdot
.77067 .60793 Mdot
.50617 .43713 Mdot
.4523 .33067 Mdot
.53129 .35752 Mdot
.49867 .80889 Mdot
.61885 .62471 Mdot
.34465 .52432 Mdot
.49146 .64132 Mdot
.47891 .64479 Mdot
.62901 .61038 Mdot
.33719 .69044 Mdot
.43739 .5205 Mdot
.58464 .87344 Mdot
.6113 .60434 Mdot
.65106 .4192 Mdot
.33776 .59975 Mdot
.65794 .59463 Mdot
.62827 .57941 Mdot
.59491 .57088 Mdot
.42593 .6827 Mdot
.33566 .51207 Mdot
.48807 .40944 Mdot
.31286 .55644 Mdot
.49365 .34168 Mdot
.42902 .47291 Mdot
.47788 .62671 Mdot
.32231 .49154 Mdot
.25934 .28061 Mdot
.39142 .40446 Mdot
.49001 .37635 Mdot
.27762 .28046 Mdot
.48421 .43065 Mdot
.62341 .33428 Mdot
.4457 .41457 Mdot
.63086 .59616 Mdot
.48032 .27753 Mdot
.55674 .38224 Mdot
.8192 .58182 Mdot
.45964 .65527 Mdot
.64029 .63286 Mdot
.53052 .40794 Mdot
.53255 .43524 Mdot
.36371 .48327 Mdot
.31705 .54763 Mdot
.67953 .43008 Mdot
.72081 .3492 Mdot
.47318 .65521 Mdot
.50129 .19197 Mdot
.47165 .35477 Mdot
.68159 .7312 Mdot
.27647 .31743 Mdot
.46161 .38716 Mdot
.21372 .52121 Mdot
.27156 .3957 Mdot
.50901 .34889 Mdot
.59467 .38901 Mdot
.45866 .62724 Mdot
.5723 .7913 Mdot
.45029 .33815 Mdot
.64924 .6029 Mdot
.34356 .49104 Mdot
.34984 .54187 Mdot
.66911 .42591 Mdot
.79402 .35771 Mdot
.49897 .63248 Mdot
.32706 .48983 Mdot
.49802 .363 Mdot
.48311 .66991 Mdot
.60179 .58025 Mdot
.44524 .39987 Mdot
.65472 .3791 Mdot
.31668 .51436 Mdot
.44436 .34704 Mdot
.36377 .63245 Mdot
.67415 .30727 Mdot
.38725 .8206 Mdot
.49378 .64834 Mdot
.6706 .47717 Mdot
.55381 .33161 Mdot
.53872 .20035 Mdot
.54406 .36393 Mdot
.59059 .25055 Mdot
.25953 .49357 Mdot
.67029 .47788 Mdot
.48061 .3769 Mdot
.50611 .39291 Mdot
.51575 .57826 Mdot
.68955 .45273 Mdot
.45936 .3414 Mdot
.41904 .3016 Mdot
.33948 .51455 Mdot
.61956 .55206 Mdot
.32166 .51114 Mdot
.4941 .38199 Mdot
.42534 .38908 Mdot
.29701 .52749 Mdot
.40549 .17362 Mdot
.69359 .47081 Mdot
.46991 .66647 Mdot
.4455 .42343 Mdot
.49304 .31909 Mdot
.59945 .82297 Mdot
.66262 .62609 Mdot
.41844 .77189 Mdot
.70159 .57322 Mdot
.33136 .72955 Mdot
.63464 .7422 Mdot
.21819 .70518 Mdot
.77892 .63743 Mdot
.44285 .32625 Mdot
.4077 .51513 Mdot
.58852 .385 Mdot
.49812 .65107 Mdot
.38862 .28639 Mdot
.47602 .35191 Mdot
.48401 .3638 Mdot
.66554 .59625 Mdot
.30551 .66326 Mdot
.77862 .59005 Mdot
.56955 .53821 Mdot
.65307 .45753 Mdot
.35335 .52599 Mdot
.46028 .3975 Mdot
.58142 .47626 Mdot
.64495 .57516 Mdot
.69142 .72185 Mdot
.46914 .37736 Mdot
.79228 .39148 Mdot
.44457 .71207 Mdot
.48685 .66443 Mdot
.63717 .57307 Mdot
.78685 .54274 Mdot
.48896 .33626 Mdot
.48154 .67785 Mdot
.50749 .36922 Mdot
.58954 .64014 Mdot
.44288 .38386 Mdot
.67608 .46708 Mdot
.50203 .41332 Mdot
.57881 .53316 Mdot
.30817 .78034 Mdot
.70212 .42391 Mdot
.35895 .52794 Mdot
.65716 .63943 Mdot
.62365 .60789 Mdot
.3054 .54285 Mdot
.62404 .60518 Mdot
.27408 .34996 Mdot
.3421 .37885 Mdot
.65543 .46185 Mdot
.54763 .42441 Mdot
.68354 .44897 Mdot
.6659 .62417 Mdot
.48356 .34643 Mdot
.42652 .17127 Mdot
.61328 .5985 Mdot
.62226 .79033 Mdot
.45954 .64912 Mdot
.6531 .63079 Mdot
.44545 .34995 Mdot
.52134 .72949 Mdot
.62601 .56513 Mdot
.47262 .73548 Mdot
.49977 .39083 Mdot
.31393 .50568 Mdot
.50688 .39615 Mdot
.46224 .42974 Mdot
.59525 .55121 Mdot
.51376 .33506 Mdot
.45468 .65957 Mdot
.29288 .50963 Mdot
.1885 .58908 Mdot
.42063 .69871 Mdot
.46783 .33888 Mdot
.49687 .36504 Mdot
.37164 .51134 Mdot
.47579 .32524 Mdot
.44365 .65931 Mdot
.86595 .63325 Mdot
.66491 .46339 Mdot
.60377 .61965 Mdot
.62283 .7533 Mdot
.53927 .35545 Mdot
.53178 .38499 Mdot
.22862 .31604 Mdot
.6154 .76521 Mdot
.44647 .65399 Mdot
.55295 .39937 Mdot
.60848 .5692 Mdot
.65895 .44445 Mdot
.45623 .61312 Mdot
.52645 .3544 Mdot
.47574 .37013 Mdot
.66995 .47674 Mdot
.22673 .48151 Mdot
.79625 .51326 Mdot
.49514 .63315 Mdot
.47235 .27704 Mdot
.67586 .5488 Mdot
.49371 .33021 Mdot
.78343 .46892 Mdot
.31599 .54588 Mdot
.47647 .67557 Mdot
.40767 .78371 Mdot
.52931 .40119 Mdot
.46379 .61638 Mdot
.47085 .65619 Mdot
.5547 .39027 Mdot
.30309 .48253 Mdot
.30241 .49545 Mdot
.34735 .53415 Mdot
.85382 .5189 Mdot
.65661 .29608 Mdot
.642 .62128 Mdot
.45961 .62613 Mdot
.59131 .59231 Mdot
.65099 .41667 Mdot
.53123 .49054 Mdot
.59793 .61083 Mdot
.30604 .54706 Mdot
.66679 .63787 Mdot
.50279 .3943 Mdot
.47582 .65241 Mdot
.6447 .62621 Mdot
.53451 .40586 Mdot
.2791 .59615 Mdot
.67736 .65399 Mdot
.65239 .48163 Mdot
.69251 .46231 Mdot
.45235 .38219 Mdot
.67448 .60836 Mdot
.46658 .36648 Mdot
.43543 .6298 Mdot
.31982 .60356 Mdot
.54565 .38167 Mdot
.62764 .59982 Mdot
.25992 .5404 Mdot
.78361 .51947 Mdot
.52102 .42515 Mdot
.48842 .38478 Mdot
.4963 .33612 Mdot
.50817 .36859 Mdot
.30942 .68406 Mdot
.47152 .60374 Mdot
.39596 .57776 Mdot
.5491 .77176 Mdot
.30889 .52327 Mdot
.29888 .49107 Mdot
.75796 .45755 Mdot
.5692 .65488 Mdot
.44983 .64299 Mdot
.50297 .34034 Mdot
.4471 .72688 Mdot
.16768 .49707 Mdot
.37662 .17681 Mdot
.64352 .40815 Mdot
.66782 .61347 Mdot
.36701 .5044 Mdot
.64609 .578 Mdot
.4903 .34731 Mdot
.54939 .3228 Mdot
.21484 .70611 Mdot
.48534 .68752 Mdot
.65028 .46 Mdot
.49627 .33834 Mdot
.65636 .28925 Mdot
.61705 .57155 Mdot
.58678 .59086 Mdot
.45393 .34624 Mdot
.2828 .52423 Mdot
.50861 .83927 Mdot
.4908 .66061 Mdot
.36526 .57201 Mdot
.49169 .26576 Mdot
.38635 .61039 Mdot
.48117 .63468 Mdot
.76441 .58751 Mdot
.67146 .6079 Mdot
.23415 .39246 Mdot
.3067 .52196 Mdot
.65077 .46599 Mdot
.52241 .30645 Mdot
.30072 .51316 Mdot
.61384 .55308 Mdot
.31878 .49682 Mdot
.50191 .41499 Mdot
.49209 .61716 Mdot
.64066 .5781 Mdot
.44248 .68247 Mdot
.30193 .48428 Mdot
.67637 .43415 Mdot
.47796 .56302 Mdot
.38082 .3381 Mdot
.26954 .39273 Mdot
.48164 .32615 Mdot
.57998 .4734 Mdot
.51751 .37675 Mdot
.35619 .47721 Mdot
.50533 .36525 Mdot
.26489 .55146 Mdot
.65302 .58884 Mdot
.45137 .33831 Mdot
.53343 .36689 Mdot
.38756 .26569 Mdot
.47376 .38423 Mdot
.43407 .36748 Mdot
.50816 .34485 Mdot
.37059 .54388 Mdot
.5546 .41076 Mdot
.3322 .50665 Mdot
.75295 .61869 Mdot
.63025 .58182 Mdot
.69298 .45903 Mdot
.64373 .4659 Mdot
.60386 .25478 Mdot
.70988 .47404 Mdot
.32245 .68128 Mdot
.32686 .51636 Mdot
.46373 .66051 Mdot
.50833 .36384 Mdot
.3271 .75863 Mdot
.61696 .7314 Mdot
.603 .57041 Mdot
.42088 .69899 Mdot
.47725 .28634 Mdot
.50459 .81226 Mdot
.44082 .35975 Mdot
.83782 .45333 Mdot
.41796 .37569 Mdot
.44601 .39048 Mdot
.58769 .57868 Mdot
.70096 .45571 Mdot
.45944 .33501 Mdot
.36503 .48444 Mdot
.66584 .47432 Mdot
.39887 .49185 Mdot
.65592 .54635 Mdot
.75204 .60358 Mdot
.36268 .32273 Mdot
.51454 .36954 Mdot
.64291 .5807 Mdot
.337 .50004 Mdot
.78659 .61928 Mdot
.47454 .66944 Mdot
.5384 .61973 Mdot
.52733 .26959 Mdot
.33392 .22949 Mdot
.6553 .47231 Mdot
.23321 .47184 Mdot
.47753 .40339 Mdot
.75936 .48611 Mdot
.51922 .31943 Mdot
.17002 .49807 Mdot
.64712 .42206 Mdot
.28655 .50836 Mdot
.44554 .63788 Mdot
.32017 .55518 Mdot
.26954 .40939 Mdot
.46953 .58238 Mdot
.50401 .53915 Mdot
.616 .57868 Mdot
.415 .57152 Mdot
.34037 .53139 Mdot
.52424 .39939 Mdot
.57372 .88114 Mdot
.32523 .54734 Mdot
.35868 .49304 Mdot
.44729 .19091 Mdot
.41849 .1879 Mdot
.48341 .2825 Mdot
.29509 .51965 Mdot
.6196 .58054 Mdot
.67289 .43561 Mdot
.51376 .39302 Mdot
.50727 .38168 Mdot
.29977 .51908 Mdot
.5866 .58612 Mdot
.39881 .45099 Mdot
.63577 .59789 Mdot
.34157 .51315 Mdot
.64005 .58864 Mdot
.51434 .75955 Mdot
.65125 .62686 Mdot
.49063 .31956 Mdot
.50624 .3647 Mdot
.69712 .58085 Mdot
.31088 .50997 Mdot
.53035 .37727 Mdot
.48797 .41269 Mdot
.32911 .53514 Mdot
.62031 .49055 Mdot
.3625 .44981 Mdot
.47563 .33904 Mdot
.48697 .39674 Mdot
.67475 .47533 Mdot
.54938 .47902 Mdot
.73515 .31381 Mdot
.52467 .39217 Mdot
.67528 .42184 Mdot
.31566 .4906 Mdot
.46326 .37037 Mdot
.22859 .60192 Mdot
.49396 .74613 Mdot
.52543 .40367 Mdot
.63502 .63209 Mdot
.55555 .36319 Mdot
.42919 .8293 Mdot
.4496 .36202 Mdot
.3336 .52941 Mdot
.35454 .49655 Mdot
.48176 .20331 Mdot
.32058 .54325 Mdot
.59917 .58919 Mdot
.47316 .64056 Mdot
.18024 .51224 Mdot
.60217 .57949 Mdot
.53415 .41152 Mdot
.56467 .17862 Mdot
.43592 .3873 Mdot
.54037 .39798 Mdot
.54857 .81789 Mdot
.60446 .57807 Mdot
.35551 .50915 Mdot
.53979 .58361 Mdot
.42928 .34736 Mdot
.48467 .67119 Mdot
.55814 .34744 Mdot
.50929 .32631 Mdot
.61623 .77862 Mdot
.4359 .74924 Mdot
.44018 .6632 Mdot
.47823 .2981 Mdot
.52567 .39105 Mdot
.678 .6397 Mdot
.50274 .36151 Mdot
.68473 .44386 Mdot
.36179 .50901 Mdot
.66204 .60713 Mdot
.67279 .45157 Mdot
.47235 .3501 Mdot
.6508 .45122 Mdot
.65138 .61907 Mdot
.47822 .67772 Mdot
.48829 .3427 Mdot
.63405 .45216 Mdot
.65291 .45535 Mdot
.52086 .37678 Mdot
.33202 .48995 Mdot
.41753 .34555 Mdot
.46121 .37475 Mdot
.50778 .40596 Mdot
.30188 .51677 Mdot
.33774 .1815 Mdot
.44734 .36549 Mdot
.57212 .57513 Mdot
.35463 .48781 Mdot
.41682 .60024 Mdot
.66381 .60901 Mdot
.50731 .32467 Mdot
.46673 .6786 Mdot
.47287 .6217 Mdot
.59221 .58216 Mdot
.3645 .53167 Mdot
.70016 .57596 Mdot
.26089 .5436 Mdot
.42687 .38308 Mdot
.45435 .41438 Mdot
.60912 .19456 Mdot
.20839 .66996 Mdot
.34895 .54078 Mdot
.5839 .57906 Mdot
.56695 .53665 Mdot
.45614 .62577 Mdot
.60444 .62866 Mdot
.3687 .51633 Mdot
.36562 .5136 Mdot
.32369 .49655 Mdot
.64528 .45864 Mdot
.68547 .55277 Mdot
.28715 .54135 Mdot
.28332 .5222 Mdot
.50041 .39264 Mdot
.52807 .38773 Mdot
.61386 .40131 Mdot
.69529 .3758 Mdot
.67495 .43104 Mdot
.63462 .61077 Mdot
.83419 .64842 Mdot
.43551 .63289 Mdot
.38028 .2688 Mdot
.5454 .3809 Mdot
.50783 .92672 Mdot
.44261 .36118 Mdot
.50027 .3603 Mdot
.29359 .5106 Mdot
.63793 .47005 Mdot
.67974 .45624 Mdot
.34537 .52876 Mdot
.34529 .47647 Mdot
.68544 .44566 Mdot
.19658 .44701 Mdot
.18405 .55243 Mdot
.50809 .58248 Mdot
.32281 .53125 Mdot
.37449 .35968 Mdot
.49191 .66935 Mdot
.27209 .51643 Mdot
.4445 .61605 Mdot
.6234 .57381 Mdot
.67145 .60072 Mdot
.49242 .64002 Mdot
.50036 .38841 Mdot
.6329 .62444 Mdot
.43221 .35832 Mdot
.20599 .47995 Mdot
.31008 .44085 Mdot
.67087 .7046 Mdot
.49217 .30978 Mdot
.76139 .60608 Mdot
.58513 .66461 Mdot
.46168 .35424 Mdot
.27963 .68975 Mdot
.64979 .45748 Mdot
.27605 .52632 Mdot
.44641 .66604 Mdot
.40701 .83271 Mdot
.4975 .33275 Mdot
.33007 .52744 Mdot
.45653 .65526 Mdot
.53864 .23362 Mdot
.35439 .60192 Mdot
.49446 .33874 Mdot
.60735 .86447 Mdot
.3832 .5248 Mdot
.66129 .60922 Mdot
.68665 .24066 Mdot
.31539 .55752 Mdot
.62284 .4408 Mdot
.54849 .76101 Mdot
.27658 .27165 Mdot
.35047 .50726 Mdot
.59351 .62241 Mdot
.35096 .52778 Mdot
.6808 .43689 Mdot
.29538 .56068 Mdot
.62555 .56967 Mdot
.47569 .38046 Mdot
.63135 .60527 Mdot
.66875 .4276 Mdot
.77411 .47399 Mdot
.44907 .66993 Mdot
.6405 .63267 Mdot
.46637 .63207 Mdot
.68746 .31909 Mdot
.54284 .78771 Mdot
.46312 .66886 Mdot
.5123 .21073 Mdot
.52802 .40526 Mdot
.29752 .55058 Mdot
.61627 .61138 Mdot
.54453 .7546 Mdot
.51761 .56468 Mdot
.30973 .52966 Mdot
.64529 .6118 Mdot
.55531 .29968 Mdot
.58793 .20402 Mdot
.50479 .44347 Mdot
.70541 .3412 Mdot
.32388 .53466 Mdot
.60331 .62957 Mdot
.78791 .601 Mdot
.31125 .5502 Mdot
.61117 .60558 Mdot
.45118 .62546 Mdot
.48089 .64101 Mdot
.46279 .33518 Mdot
.42575 .66044 Mdot
.63593 .61716 Mdot
.61887 .67231 Mdot
.33153 .48346 Mdot
.55019 .24331 Mdot
.637 .4505 Mdot
.63089 .58774 Mdot
.46153 .41486 Mdot
.28436 .49087 Mdot
.50467 .75235 Mdot
.39909 .43743 Mdot
.80839 .66842 Mdot
.62964 .60993 Mdot
.36197 .50193 Mdot
.32595 .52496 Mdot
.52324 .42325 Mdot
.54964 .55314 Mdot
.69592 .56822 Mdot
.60078 .22129 Mdot
.57954 .24646 Mdot
.60896 .55066 Mdot
.61959 .54689 Mdot
.51622 .42118 Mdot
.51742 .36267 Mdot
.45255 .6281 Mdot
.47997 .38427 Mdot
.29024 .50914 Mdot
.46721 .33012 Mdot
.48332 .63233 Mdot
.6125 .58508 Mdot
.48469 .34871 Mdot
.66616 .43116 Mdot
.45808 .67993 Mdot
.47993 .61454 Mdot
.62796 .59188 Mdot
.30227 .50892 Mdot
.69241 .42174 Mdot
.63731 .59994 Mdot
.51371 .37009 Mdot
.5339 .64885 Mdot
.48877 .4159 Mdot
.20742 .42445 Mdot
.30594 .54804 Mdot
.65161 .58444 Mdot
.34249 .48144 Mdot
.46132 .63204 Mdot
.54771 .77094 Mdot
.49746 .37606 Mdot
.60922 .6022 Mdot
.69547 .58437 Mdot
.20866 .46176 Mdot
.37363 .5008 Mdot
.5226 .68686 Mdot
.31084 .48603 Mdot
.63469 .56122 Mdot
.43893 .21489 Mdot
.65919 .47058 Mdot
.60534 .56834 Mdot
.20277 .63136 Mdot
.62046 .59943 Mdot
.4711 .3871 Mdot
.4582 .38928 Mdot
.66141 .61428 Mdot
.65304 .47811 Mdot
.78211 .64321 Mdot
.6057 .65436 Mdot
.35366 .50724 Mdot
.31718 .25873 Mdot
.74268 .74029 Mdot
.42985 .61996 Mdot
.44666 .63957 Mdot
.43035 .34341 Mdot
.44839 .39719 Mdot
.44452 .61858 Mdot
.5053 .65616 Mdot
.64735 .42906 Mdot
.59539 .57093 Mdot
.32966 .57011 Mdot
.48523 .67856 Mdot
.46359 .45414 Mdot
.71873 .46883 Mdot
.532 .42236 Mdot
.50878 .27373 Mdot
.50888 .3161 Mdot
.58075 .23911 Mdot
.48813 .63585 Mdot
.45782 .39737 Mdot
.53524 .42412 Mdot
.46912 .67791 Mdot
.68252 .44028 Mdot
.42408 .73273 Mdot
.64622 .59058 Mdot
.15789 .39832 Mdot
.45651 .40221 Mdot
.46715 .38481 Mdot
.49637 .64017 Mdot
.71136 .58076 Mdot
.3077 .50665 Mdot
.30802 .55055 Mdot
.62243 .62587 Mdot
.48028 .55888 Mdot
.49588 .32521 Mdot
.45652 .36232 Mdot
.65259 .59507 Mdot
.65061 .63142 Mdot
.63464 .68908 Mdot
.48634 .40726 Mdot
.4551 .65193 Mdot
.5859 .52301 Mdot
.48654 .63374 Mdot
.47383 .41692 Mdot
.46979 .39005 Mdot
.48915 .32004 Mdot
.46666 .41692 Mdot
.47774 .61283 Mdot
.46195 .40099 Mdot
.44374 .43701 Mdot
.31455 .49673 Mdot
.5117 .33597 Mdot
.57183 .23727 Mdot
.48777 .38979 Mdot
.67639 .43677 Mdot
.42581 .44257 Mdot
.49471 .33426 Mdot
.50197 .32306 Mdot
.59803 .65031 Mdot
.48361 .37398 Mdot
.4359 .62831 Mdot
.31293 .52123 Mdot
.46059 .62566 Mdot
.49093 .62903 Mdot
.60068 .60602 Mdot
.67172 .42598 Mdot
.53648 .35045 Mdot
.64345 .44082 Mdot
.53565 .33804 Mdot
.52504 .4058 Mdot
.58131 .75941 Mdot
.8359 .44008 Mdot
.79686 .50658 Mdot
.49852 .37657 Mdot
.6057 .58991 Mdot
.66247 .6012 Mdot
.39606 .5484 Mdot
.50782 .44158 Mdot
.44638 .61799 Mdot
.46807 .62093 Mdot
.65696 .37429 Mdot
.60716 .78068 Mdot
.67833 .4376 Mdot
.56363 .48376 Mdot
.43095 .36123 Mdot
.49563 .41013 Mdot
.44267 .39576 Mdot
.59321 .59807 Mdot
.56748 .5509 Mdot
.60431 .57032 Mdot
.42621 .70628 Mdot
.4827 .62827 Mdot
.50131 .3323 Mdot
.24696 .49329 Mdot
.3158 .54832 Mdot
.31281 .52046 Mdot
.46479 .61324 Mdot
.63947 .64116 Mdot
.63886 .40181 Mdot
.4219 .14987 Mdot
.36714 .55012 Mdot
.64412 .47867 Mdot
.46364 .34909 Mdot
.61665 .58882 Mdot
.34541 .5393 Mdot
.67698 .47826 Mdot
.5183 .40705 Mdot
.68663 .55664 Mdot
.50151 .37765 Mdot
.58833 .3879 Mdot
.33756 .49279 Mdot
.17376 .52017 Mdot
.35986 .53393 Mdot
.45389 .67796 Mdot
.45831 .67191 Mdot
.46273 .39048 Mdot
.63411 .20797 Mdot
.30389 .5535 Mdot
.41582 .66262 Mdot
.64669 .42362 Mdot
.51217 .73017 Mdot
.68752 .44552 Mdot
.65924 .59912 Mdot
.66198 .47429 Mdot
.63561 .57302 Mdot
.6991 .38948 Mdot
.37278 .53002 Mdot
.66906 .45876 Mdot
.58947 .6315 Mdot
.50018 .44238 Mdot
.69237 .45671 Mdot
.44884 .31363 Mdot
.25337 .33976 Mdot
.65257 .59936 Mdot
.64517 .46587 Mdot
.52347 .39949 Mdot
.29455 .75181 Mdot
.45252 .6598 Mdot
.44124 .62463 Mdot
.42899 .38749 Mdot
.59056 .57726 Mdot
.36653 .49046 Mdot
.26316 .63448 Mdot
.49516 .59559 Mdot
.45271 .37808 Mdot
.4611 .33369 Mdot
.29089 .49764 Mdot
.36041 .46261 Mdot
.46793 .3933 Mdot
.45232 .25025 Mdot
.47446 .40578 Mdot
.45073 .62369 Mdot
.33449 .55067 Mdot
.32015 .52332 Mdot
.64527 .61546 Mdot
.29106 .52548 Mdot
.27118 .56472 Mdot
.50667 .69199 Mdot
.43257 .33435 Mdot
.4593 .64035 Mdot
.4827 .70601 Mdot
.42462 .70523 Mdot
.22538 .66993 Mdot
.29432 .49252 Mdot
.48825 .31681 Mdot
.33678 .48294 Mdot
.65966 .44092 Mdot
.31403 .50947 Mdot
.36575 .49964 Mdot
.4633 .36337 Mdot
.49315 .34569 Mdot
.60779 .5794 Mdot
.55286 .55319 Mdot
.3157 .49331 Mdot
.45419 .38693 Mdot
.43533 .37079 Mdot
.43339 .36963 Mdot
.46017 .49759 Mdot
.34902 .53972 Mdot
.37414 .2553 Mdot
.58831 .30658 Mdot
.31407 .49446 Mdot
.45774 .84039 Mdot
.53815 .75991 Mdot
.66123 .63127 Mdot
.43299 .66705 Mdot
.48775 .40743 Mdot
.66601 .60803 Mdot
.48989 .34725 Mdot
.50794 .27329 Mdot
.47832 .36759 Mdot
.68705 .45306 Mdot
.44313 .32592 Mdot
.65372 .57603 Mdot
.63487 .60179 Mdot
.44983 .3688 Mdot
.48279 .35287 Mdot
.78136 .49059 Mdot
.3377 .47602 Mdot
.31096 .50412 Mdot
.71309 .60132 Mdot
.66269 .45552 Mdot
.48092 .67372 Mdot
.50823 .35391 Mdot
.60433 .61057 Mdot
.63376 .6046 Mdot
.32406 .55587 Mdot
.64733 .60393 Mdot
.49293 .65498 Mdot
.49822 .37267 Mdot
.44175 .62277 Mdot
.64337 .45412 Mdot
.35258 .53 Mdot
.50057 .33537 Mdot
.49997 .39307 Mdot
.35472 .49689 Mdot
.54263 .37337 Mdot
.67631 .47394 Mdot
.6221 .60163 Mdot
.34643 .50566 Mdot
.47504 .64053 Mdot
.65204 .58683 Mdot
.50881 .40047 Mdot
.8241 .65484 Mdot
.47552 .39069 Mdot
.49706 .40412 Mdot
.19029 .62353 Mdot
.44347 .32432 Mdot
.62267 .61257 Mdot
.28364 .51399 Mdot
.44811 .33313 Mdot
.61636 .26623 Mdot
.35913 .17978 Mdot
.60035 .57386 Mdot
.46297 .34624 Mdot
.23235 .70486 Mdot
.45523 .35476 Mdot
.51604 .19681 Mdot
.73819 .46051 Mdot
.42781 .55745 Mdot
.4254 .39631 Mdot
.48868 .65326 Mdot
.60662 .58033 Mdot
.65533 .59324 Mdot
.35474 .24624 Mdot
.46037 .36337 Mdot
.59042 .41075 Mdot
.53701 .38077 Mdot
.48186 .63682 Mdot
.63051 .37325 Mdot
.63245 .60877 Mdot
.82015 .54044 Mdot
.51471 .37874 Mdot
.35272 .53713 Mdot
.66259 .63944 Mdot
.52536 .75663 Mdot
.51007 .40317 Mdot
.6452 .44059 Mdot
.45484 .68401 Mdot
.44405 .33087 Mdot
.46281 .64409 Mdot
.50249 .41085 Mdot
.49641 .45771 Mdot
.73472 .28212 Mdot
.32854 .49223 Mdot
.44747 .63357 Mdot
.54374 .64791 Mdot
.50997 .31075 Mdot
.34849 .50579 Mdot
.30682 .52316 Mdot
.64831 .4302 Mdot
.52079 .52921 Mdot
.35411 .63712 Mdot
.37207 .42804 Mdot
.34994 .24291 Mdot
.65674 .64034 Mdot
.54989 .68074 Mdot
.51787 .39359 Mdot
.68042 .72611 Mdot
.4348 .65204 Mdot
.46949 .38306 Mdot
.25538 .3525 Mdot
.34406 .53706 Mdot
.48406 .39975 Mdot
.68384 .44757 Mdot
.71446 .68327 Mdot
.70366 .70538 Mdot
.45844 .8045 Mdot
.6176 .57677 Mdot
.54984 .32489 Mdot
.55666 .32254 Mdot
.6102 .62344 Mdot
.53472 .3536 Mdot
.61784 .60813 Mdot
.22485 .35156 Mdot
.67126 .4793 Mdot
.3545 .53046 Mdot
.53439 .75949 Mdot
.51929 .32871 Mdot
.43741 .39774 Mdot
.68155 .47771 Mdot
.52183 .3598 Mdot
.79664 .36586 Mdot
.64513 .71481 Mdot
.63939 .62671 Mdot
.3246 .49542 Mdot
.51076 .32221 Mdot
.53975 .51171 Mdot
.45838 .37151 Mdot
.3365 .40653 Mdot
.50257 .32246 Mdot
.35786 .61932 Mdot
.34256 .49059 Mdot
.46264 .64009 Mdot
.54201 .33311 Mdot
.48601 .36586 Mdot
.60631 .49748 Mdot
.42347 .3896 Mdot
.44641 .37759 Mdot
.37035 .49389 Mdot
.33326 .54931 Mdot
.33193 .50773 Mdot
.62974 .56308 Mdot
.61517 .77612 Mdot
.45324 .6411 Mdot
.55841 .36457 Mdot
.48908 .67644 Mdot
.39468 .37138 Mdot
.65662 .48335 Mdot
.29862 .74282 Mdot
.51913 .34452 Mdot
.33173 .51461 Mdot
.36688 .73323 Mdot
.31545 .48987 Mdot
.56311 .50137 Mdot
.47377 .65481 Mdot
.33869 .54164 Mdot
.49472 .36309 Mdot
.55088 .57133 Mdot
.37909 .7917 Mdot
.4685 .6256 Mdot
.54109 .35268 Mdot
.66849 .61522 Mdot
.60556 .76347 Mdot
.81713 .67269 Mdot
.44718 .65605 Mdot
.54341 .64397 Mdot
.45917 .36065 Mdot
.30736 .54622 Mdot
.49071 .65333 Mdot
.46097 .66519 Mdot
.64859 .60683 Mdot
.49484 .3437 Mdot
.49801 .34075 Mdot
.6486 .5728 Mdot
.47261 .62308 Mdot
.46049 .42599 Mdot
.44048 .37785 Mdot
.21563 .71088 Mdot
.55144 .27825 Mdot
.202 .30336 Mdot
.26426 .56029 Mdot
.24808 .37587 Mdot
.25076 .60808 Mdot
.36331 .50324 Mdot
.49341 .33392 Mdot
.488 .30662 Mdot
.63625 .61639 Mdot
.4863 .38131 Mdot
.58482 .58102 Mdot
.44856 .64642 Mdot
.44988 .83491 Mdot
.39637 .70821 Mdot
.2379 .3258 Mdot
.48393 .37984 Mdot
.40817 .68065 Mdot
.66955 .44328 Mdot
.50858 .65954 Mdot
.34062 .50787 Mdot
.50059 .41647 Mdot
.78494 .49578 Mdot
.60537 .56889 Mdot
.30469 .53474 Mdot
.78087 .59235 Mdot
.76132 .59715 Mdot
.47529 .41734 Mdot
.64107 .57032 Mdot
.31306 .70746 Mdot
.45245 .25263 Mdot
.47245 .59993 Mdot
.68748 .44964 Mdot
.6114 .57058 Mdot
.48097 .62167 Mdot
.23954 .52354 Mdot
.32977 .54485 Mdot
.31579 .56501 Mdot
.77903 .4451 Mdot
.6069 .62395 Mdot
.67433 .4449 Mdot
.60407 .78003 Mdot
.68494 .73422 Mdot
.68653 .45394 Mdot
.66876 .59677 Mdot
.33934 .54556 Mdot
.34312 .52076 Mdot
.31352 .52215 Mdot
.81543 .55698 Mdot
.36059 .53623 Mdot
.35573 .29634 Mdot
.43462 .38554 Mdot
.55029 .44336 Mdot
.46021 .34805 Mdot
.45081 .61219 Mdot
.34523 .49594 Mdot
.45665 .56825 Mdot
.5522 .38643 Mdot
.44383 .81269 Mdot
.45377 .36887 Mdot
.50029 .62387 Mdot
.48769 .40333 Mdot
.37617 .29653 Mdot
.34332 .483 Mdot
.49367 .38011 Mdot
.44916 .6079 Mdot
.65609 .45233 Mdot
.28149 .55915 Mdot
.49605 .33649 Mdot
.30556 .65763 Mdot
.44578 .32085 Mdot
.19227 .42786 Mdot
.56201 .25927 Mdot
.64433 .47879 Mdot
.45055 .27695 Mdot
.59415 .617 Mdot
.56197 .43777 Mdot
.57106 .38897 Mdot
.47012 .6276 Mdot
.49897 .77932 Mdot
.62795 .58085 Mdot
.7009 .40475 Mdot
.56265 .37117 Mdot
.67714 .43008 Mdot
.37118 .47996 Mdot
.46173 .60745 Mdot
.52339 .41277 Mdot
.54268 .40765 Mdot
.22338 .36554 Mdot
.54788 .42575 Mdot
.47112 .32726 Mdot
.66537 .48418 Mdot
.34156 .27345 Mdot
.49151 .39148 Mdot
.55895 .50088 Mdot
.30943 .5632 Mdot
.43532 .40705 Mdot
.38809 .2514 Mdot
.45395 .3842 Mdot
.30484 .53959 Mdot
.36388 .54368 Mdot
.36881 .70661 Mdot
.64957 .42327 Mdot
.50474 .32425 Mdot
.47288 .20989 Mdot
.51625 .37345 Mdot
.45685 .65133 Mdot
.45535 .40542 Mdot
.61965 .56971 Mdot
.8095 .55753 Mdot
.63714 .62106 Mdot
.48078 .33305 Mdot
.31643 .52608 Mdot
.49437 .63909 Mdot
.79592 .47022 Mdot
.7166 .50356 Mdot
.35153 .29057 Mdot
.25208 .28702 Mdot
.65029 .47486 Mdot
.68973 .43643 Mdot
.46786 .60777 Mdot
.49431 .38139 Mdot
.45366 .19718 Mdot
.41902 .37569 Mdot
.48798 .39779 Mdot
.47782 .36659 Mdot
.56161 .78627 Mdot
.45242 .63123 Mdot
.64598 .5961 Mdot
.46969 .39266 Mdot
.45697 .39425 Mdot
.35856 .49602 Mdot
.65477 .45469 Mdot
.66374 .60648 Mdot
.65919 .46328 Mdot
.61114 .59169 Mdot
.44617 .83897 Mdot
.55113 .34857 Mdot
.65857 .4517 Mdot
.44164 .66812 Mdot
.30054 .51884 Mdot
.5112 .68789 Mdot
.65861 .5988 Mdot
.63601 .61162 Mdot
.45356 .37259 Mdot
.30263 .53879 Mdot
.29685 .51117 Mdot
.6588 .44023 Mdot
.46787 .67134 Mdot
.49062 .33744 Mdot
.52016 .40979 Mdot
.40009 .56103 Mdot
.59302 .59218 Mdot
.55843 .30668 Mdot
.34554 .70411 Mdot
.49777 .37888 Mdot
.29723 .51533 Mdot
.47615 .35899 Mdot
.21051 .56676 Mdot
.30176 .54211 Mdot
.44515 .3709 Mdot
.72476 .71134 Mdot
.59859 .53315 Mdot
.33295 .66134 Mdot
.47561 .32276 Mdot
.17442 .38915 Mdot
.52445 .38682 Mdot
.2357 .73287 Mdot
.75498 .51184 Mdot
.49789 .32901 Mdot
.50991 .39581 Mdot
.33587 .44678 Mdot
.47202 .34667 Mdot
.64323 .56686 Mdot
.69629 .39881 Mdot
.36676 .49553 Mdot
.28368 .61428 Mdot
.45031 .47146 Mdot
.64184 .43024 Mdot
.62371 .62634 Mdot
.62844 .54813 Mdot
.67985 .4611 Mdot
.32575 .53201 Mdot
.50848 .36816 Mdot
.46503 .54937 Mdot
.60172 .5521 Mdot
.47627 .43525 Mdot
.46138 .65327 Mdot
.58207 .69979 Mdot
.60746 .6354 Mdot
.46954 .64072 Mdot
.52427 .34581 Mdot
.35118 .4479 Mdot
.75111 .38553 Mdot
.1699 .5405 Mdot
.49546 .63446 Mdot
.47763 .62439 Mdot
.81128 .5824 Mdot
.63889 .43273 Mdot
.25254 .32323 Mdot
.35606 .60969 Mdot
.49455 .65686 Mdot
.50085 .22995 Mdot
.59687 .57306 Mdot
.30829 .65163 Mdot
.27593 .52642 Mdot
.45287 .41238 Mdot
.49227 .36438 Mdot
.46692 .67285 Mdot
.23445 .5342 Mdot
.71809 .26767 Mdot
.46778 .63195 Mdot
.44322 .44019 Mdot
.45551 .51298 Mdot
.53968 .75886 Mdot
.59533 .59176 Mdot
.65016 .42431 Mdot
.62572 .45209 Mdot
.3586 .5112 Mdot
.65759 .42457 Mdot
.70352 .69858 Mdot
.521 .35272 Mdot
.47496 .63142 Mdot
.50652 .74706 Mdot
.476 .64372 Mdot
.67952 .4592 Mdot
.64339 .47893 Mdot
.31398 .4973 Mdot
.31234 .50381 Mdot
.25096 .38787 Mdot
.63276 .34915 Mdot
.45244 .36049 Mdot
.39546 .77904 Mdot
.32916 .48394 Mdot
.4806 .26998 Mdot
.68729 .43473 Mdot
.65841 .45489 Mdot
.58794 .33347 Mdot
.5058 .34231 Mdot
.4886 .20373 Mdot
.50616 .34697 Mdot
.63219 .36727 Mdot
.52247 .32373 Mdot
.64807 .60567 Mdot
.50654 .33883 Mdot
.70112 .43796 Mdot
.51183 .42247 Mdot
.4485 .3921 Mdot
.58937 .58236 Mdot
.44513 .33136 Mdot
.62231 .57043 Mdot
.47411 .3341 Mdot
.65217 .41687 Mdot
.60749 .61591 Mdot
.64547 .28932 Mdot
.56446 .58992 Mdot
.67331 .61046 Mdot
.65986 .42793 Mdot
.63833 .44805 Mdot
.63127 .25521 Mdot
.34185 .50844 Mdot
.26611 .53783 Mdot
.49071 .38334 Mdot
.58655 .59216 Mdot
.4498 .63261 Mdot
.4632 .40103 Mdot
.47114 .30486 Mdot
.45798 .33349 Mdot
.35845 .52011 Mdot
.70166 .58365 Mdot
.65654 .44723 Mdot
.62828 .56166 Mdot
.62806 .502 Mdot
.59807 .56114 Mdot
.54766 .41476 Mdot
.51581 .3056 Mdot
.23074 .41911 Mdot
.42738 .76584 Mdot
.80526 .6204 Mdot
.32295 .5452 Mdot
.63801 .63234 Mdot
.6373 .44506 Mdot
.42666 .31257 Mdot
.33803 .51384 Mdot
.62477 .56966 Mdot
.50199 .37655 Mdot
.54064 .35052 Mdot
.51109 .66825 Mdot
.57156 .42933 Mdot
.58772 .2611 Mdot
.59746 .5638 Mdot
.59249 .62112 Mdot
.68203 .7339 Mdot
.69132 .39802 Mdot
.49833 .56213 Mdot
.46774 .37362 Mdot
.64456 .4426 Mdot
.34528 .53939 Mdot
.76287 .4102 Mdot
.44752 .66439 Mdot
.55116 .55396 Mdot
.48552 .37948 Mdot
.42054 .57872 Mdot
.31474 .52579 Mdot
.68195 .4427 Mdot
.46776 .67353 Mdot
.65053 .48914 Mdot
.60157 .61597 Mdot
.36642 .19555 Mdot
.51904 .36871 Mdot
.45031 .36055 Mdot
.44681 .66933 Mdot
.34836 .52967 Mdot
.67221 .48574 Mdot
.2012 .44428 Mdot
.65515 .61822 Mdot
.46832 .19326 Mdot
.28952 .51956 Mdot
.36556 .32867 Mdot
.62188 .5591 Mdot
.46605 .61374 Mdot
.64914 .27448 Mdot
.48398 .63345 Mdot
.48478 .32848 Mdot
.32512 .51884 Mdot
.45226 .65738 Mdot
.58106 .50767 Mdot
.25698 .7257 Mdot
.37149 .35009 Mdot
.51383 .35091 Mdot
.34059 .78205 Mdot
.20288 .50946 Mdot
.38906 .49258 Mdot
.46598 .67884 Mdot
.46002 .37562 Mdot
.53087 .3486 Mdot
.51299 .37674 Mdot
.47288 .65935 Mdot
.57508 .74764 Mdot
.65452 .60184 Mdot
.45844 .35448 Mdot
.64603 .43098 Mdot
.62824 .57431 Mdot
.53241 .76256 Mdot
.62776 .61314 Mdot
.32056 .47874 Mdot
.45213 .40269 Mdot
.45106 .69759 Mdot
.331 .80118 Mdot
.46252 .6252 Mdot
.67375 .60923 Mdot
.46731 .40944 Mdot
.49223 .76395 Mdot
.33274 .50941 Mdot
.65145 .62018 Mdot
.4669 .3841 Mdot
.54903 .74054 Mdot
.78176 .48482 Mdot
.62879 .61241 Mdot
.34594 .5159 Mdot
.22853 .6181 Mdot
.48264 .38372 Mdot
.52494 .382 Mdot
.34343 .53168 Mdot
.45015 .46617 Mdot
.78571 .59419 Mdot
.48031 .3556 Mdot
.46397 .63978 Mdot
.47075 .16453 Mdot
.44315 .34585 Mdot
.59738 .34124 Mdot
.60846 .57581 Mdot
.33342 .68346 Mdot
.55011 .29571 Mdot
.46403 .27641 Mdot
.22871 .53091 Mdot
.48149 .4867 Mdot
.42704 .82317 Mdot
.58449 .59708 Mdot
.7594 .56564 Mdot
.42408 .82791 Mdot
.46457 .60419 Mdot
.26475 .49592 Mdot
.34272 .58008 Mdot
.82759 .51322 Mdot
.24078 .63244 Mdot
.72738 .5987 Mdot
.79028 .50653 Mdot
.45101 .53475 Mdot
.61442 .59787 Mdot
.66482 .40359 Mdot
.49092 .34157 Mdot
.20104 .50732 Mdot
.42816 .25412 Mdot
.68392 .23038 Mdot
.32847 .77454 Mdot
.48238 .21418 Mdot
.31866 .75534 Mdot
.21939 .66097 Mdot
.22613 .40451 Mdot
.41227 .75994 Mdot
.49243 .18082 Mdot
.72034 .70854 Mdot
.37092 .21508 Mdot
.50137 .29182 Mdot
.58066 .47721 Mdot
.20201 .37073 Mdot
.34843 .32812 Mdot
.62582 .21194 Mdot
.6445 .61828 Mdot
.28323 .51636 Mdot
.34651 .58198 Mdot
.36469 .47943 Mdot
.52694 .60708 Mdot
.21757 .6012 Mdot
.21915 .69691 Mdot
.37977 .28572 Mdot
.16428 .40072 Mdot
.28102 .32257 Mdot
.85352 .40154 Mdot
.65721 .65839 Mdot
.30732 .55795 Mdot
.61885 .46948 Mdot
.6683 .74765 Mdot
.38626 .67489 Mdot
.27047 .57199 Mdot
.59556 .76153 Mdot
.66517 .32931 Mdot
.32876 .52783 Mdot
.48385 .25515 Mdot
.58533 .6528 Mdot
.40721 .71017 Mdot
.73989 .43235 Mdot
.2239 .65043 Mdot
.49514 .54836 Mdot
.29781 .64139 Mdot
.56953 .68421 Mdot
.81845 .6597 Mdot
.58593 .29318 Mdot
.22499 .50574 Mdot
.52704 .64769 Mdot
.22676 .58615 Mdot
.81938 .46629 Mdot
.65505 .35699 Mdot
.67344 .7442 Mdot
.59993 .80788 Mdot
.18855 .50122 Mdot
.6319 .81071 Mdot
.26639 .543 Mdot
.46848 .32775 Mdot
.26419 .46374 Mdot
.45567 .22279 Mdot
.64773 .41331 Mdot
.47689 .80262 Mdot
.64311 .4602 Mdot
.32274 .47419 Mdot
.80453 .55896 Mdot
.36611 .29178 Mdot
.48492 .19829 Mdot
.67775 .48526 Mdot
.49166 .30993 Mdot
.58915 .13113 Mdot
.41749 .81631 Mdot
.36483 .69838 Mdot
.21708 .71478 Mdot
.44212 .57982 Mdot
.53768 .23538 Mdot
.45501 .65826 Mdot
.38937 .82283 Mdot
.33723 .52117 Mdot
.54348 .85821 Mdot
.3044 .77379 Mdot
.71462 .27694 Mdot
.33999 .15198 Mdot
.67127 .72222 Mdot
.42705 .56479 Mdot
.44565 .47956 Mdot
.62172 .28728 Mdot
.76518 .33358 Mdot
.67432 .24444 Mdot
.48798 .75639 Mdot
.22997 .31916 Mdot
.39053 .81829 Mdot
.45349 .2159 Mdot
.36704 .20252 Mdot
.82847 .49999 Mdot
.54113 .49577 Mdot
.30864 .4737 Mdot
.55766 .62913 Mdot
.27755 .69898 Mdot
.53572 .82679 Mdot
.58687 .31169 Mdot
.39562 .15009 Mdot
.69966 .44411 Mdot
.74739 .51764 Mdot
.19118 .57174 Mdot
.67422 .31804 Mdot
.5268 .24977 Mdot
.77845 .6204 Mdot
.50265 .43477 Mdot
.76666 .64444 Mdot
.33936 .75356 Mdot
.53207 .66319 Mdot
.72702 .69677 Mdot
.28973 .67537 Mdot
.20995 .39622 Mdot
.30805 .43635 Mdot
.66163 .75668 Mdot
.35461 .48028 Mdot
.64537 .3355 Mdot
.54854 .25804 Mdot
.21037 .69632 Mdot
.54428 .64275 Mdot
.17128 .64052 Mdot
.79027 .56969 Mdot
.51601 .31409 Mdot
.57432 .38008 Mdot
.41606 .40854 Mdot
.62627 .3321 Mdot
.43701 .36477 Mdot
.41651 .7007 Mdot
.20054 .66531 Mdot
.27246 .32277 Mdot
.51912 .68764 Mdot
.50311 .78397 Mdot
.17022 .54511 Mdot
.24019 .44078 Mdot
.77532 .50784 Mdot
.61767 .38799 Mdot
.84069 .57317 Mdot
.63443 .58354 Mdot
.44737 .21438 Mdot
.47927 .60431 Mdot
.7597 .4348 Mdot
.37695 .42067 Mdot
.75511 .33326 Mdot
.1998 .66409 Mdot
.7513 .62092 Mdot
.79576 .53433 Mdot
.68676 .3065 Mdot
.45488 .18513 Mdot
.49848 .79161 Mdot
.55546 .34026 Mdot
.25682 .5771 Mdot
.64833 .4765 Mdot
.26315 .41024 Mdot
.40333 .21732 Mdot
.71652 .54293 Mdot
.42582 .36365 Mdot
.73967 .35351 Mdot
.69958 .61279 Mdot
.54974 .57012 Mdot
.70413 .78234 Mdot
.51443 .43735 Mdot
.62167 .76367 Mdot
.18363 .47874 Mdot
.60825 .29985 Mdot
.19656 .56147 Mdot
.2766 .64228 Mdot
.61651 .81324 Mdot
.27717 .75412 Mdot
.70616 .51934 Mdot
.46403 .82547 Mdot
.20556 .69915 Mdot
.65331 .79189 Mdot
.55392 .42641 Mdot
.43283 .63692 Mdot
.74242 .77717 Mdot
.61889 .55505 Mdot
.55921 .7948 Mdot
.35049 .24281 Mdot
.55509 .73504 Mdot
.3034 .57065 Mdot
.47754 .29039 Mdot
.46009 .53886 Mdot
.38352 .48562 Mdot
.43956 .34273 Mdot
.74598 .73302 Mdot
.63759 .79098 Mdot
.6923 .77682 Mdot
.17668 .4378 Mdot
.46545 .83019 Mdot
.42202 .54178 Mdot
.35595 .3144 Mdot
.4017 .52119 Mdot
.47713 .42 Mdot
.71959 .44442 Mdot
.67183 .72009 Mdot
.75119 .36532 Mdot
.37759 .65392 Mdot
.35656 .47639 Mdot
.42947 .7928 Mdot
.91392 .49959 Mdot
.27554 .34154 Mdot
.39146 .24266 Mdot
.69722 .71498 Mdot
.62076 .33754 Mdot
.30288 .72082 Mdot
.73162 .30598 Mdot
.19457 .63427 Mdot
.39781 .52252 Mdot
.35506 .23156 Mdot
.72622 .57745 Mdot
.56477 .21888 Mdot
.70884 .60522 Mdot
.24239 .70333 Mdot
.41572 .48478 Mdot
.78311 .41673 Mdot
.3372 .59866 Mdot
.71544 .27192 Mdot
.75108 .47863 Mdot
.59014 .69846 Mdot
.41171 .2085 Mdot
.47187 .73813 Mdot
.61232 .34489 Mdot
.47142 .52176 Mdot
.41129 .34444 Mdot
.47801 .48634 Mdot
.60565 .33332 Mdot
.58179 .2279 Mdot
.51789 .82284 Mdot
.2132 .72926 Mdot
.80774 .65426 Mdot
.15697 .41557 Mdot
.33632 .74599 Mdot
.45513 .41676 Mdot
.17945 .5784 Mdot
.64259 .81426 Mdot
.28101 .76418 Mdot
.6754 .66886 Mdot
.61455 .53305 Mdot
.49089 .67781 Mdot
.78711 .6726 Mdot
.70682 .617 Mdot
.20456 .61526 Mdot
.77496 .64485 Mdot
.44011 .68061 Mdot
.83224 .42867 Mdot
.62827 .78976 Mdot
.37964 .39891 Mdot
.57898 .40087 Mdot
.48575 .43157 Mdot
.38964 .28547 Mdot
.3265 .47973 Mdot
.55662 .67658 Mdot
.64169 .34889 Mdot
.63214 .59171 Mdot
.73037 .44359 Mdot
.26095 .56884 Mdot
.44241 .32714 Mdot
.46549 .47844 Mdot
.28194 .51604 Mdot
.42469 .76398 Mdot
.47187 .71633 Mdot
.50838 .83972 Mdot
.66877 .71154 Mdot
.42548 .4001 Mdot
.60331 .29967 Mdot
.71273 .63919 Mdot
.78916 .60808 Mdot
.49413 .62033 Mdot
.30766 .76093 Mdot
.57823 .49248 Mdot
.64342 .33681 Mdot
.39984 .27811 Mdot
.21263 .4045 Mdot
.50808 .29992 Mdot
.35675 .71715 Mdot
.31941 .40239 Mdot
.55598 .55126 Mdot
.31394 .47298 Mdot
.30782 .47282 Mdot
.15251 .53434 Mdot
.72069 .67272 Mdot
.56502 .69064 Mdot
.29619 .75074 Mdot
.4838 .64944 Mdot
.31566 .49209 Mdot
.71317 .44499 Mdot
.20289 .41009 Mdot
.33672 .37697 Mdot
.78248 .48564 Mdot
.62036 .73208 Mdot
.72728 .53502 Mdot
.31085 .75504 Mdot
.33412 .77332 Mdot
.66999 .2133 Mdot
.37431 .49913 Mdot
.21221 .43658 Mdot
.26597 .29951 Mdot
.2994 .49298 Mdot
.35412 .5697 Mdot
.39471 .66913 Mdot
.5181 .83113 Mdot
.42391 .66495 Mdot
.21998 .32717 Mdot
.59604 .24766 Mdot
.55923 .74805 Mdot
.79755 .47654 Mdot
.41727 .20286 Mdot
.28541 .74096 Mdot
.45106 .25599 Mdot
.38739 .43386 Mdot
.4534 .30691 Mdot
.58098 .4252 Mdot
.84558 .60888 Mdot
.56834 .58562 Mdot
.36815 .32306 Mdot
.27728 .66225 Mdot
.51459 .36537 Mdot
.80666 .66926 Mdot
.20342 .48095 Mdot
.81068 .58934 Mdot
.46221 .68552 Mdot
.53245 .38356 Mdot
.49897 .4245 Mdot
.60409 .3889 Mdot
.3527 .6957 Mdot
.57343 .8027 Mdot
.41046 .20345 Mdot
.29374 .69534 Mdot
.42683 .25575 Mdot
.61784 .76524 Mdot
.21792 .63107 Mdot
.20622 .51877 Mdot
.53371 .52688 Mdot
.6775 .71174 Mdot
.66821 .29806 Mdot
.16503 .41128 Mdot
.60173 .47191 Mdot
.41062 .55573 Mdot
.38955 .62876 Mdot
.31777 .6835 Mdot
.77967 .43263 Mdot
.50381 .41289 Mdot
.78085 .59253 Mdot
.21879 .65507 Mdot
.59422 .18536 Mdot
.79183 .38783 Mdot
.79372 .68482 Mdot
.34533 .41305 Mdot
.2991 .66637 Mdot
.22707 .54511 Mdot
.54532 .15924 Mdot
.59071 .46985 Mdot
.42227 .80465 Mdot
.67364 .29883 Mdot
.3033 .75271 Mdot
.43762 .61835 Mdot
.36193 .59899 Mdot
.50783 .78525 Mdot
.49222 .82543 Mdot
.25694 .44537 Mdot
.23869 .69083 Mdot
.43509 .57 Mdot
.58568 .83501 Mdot
.45613 .74629 Mdot
.44356 .52646 Mdot
.63305 .63099 Mdot
.75146 .63092 Mdot
.31777 .74711 Mdot
.39122 .76363 Mdot
.41207 .21161 Mdot
.58395 .61225 Mdot
.70682 .41478 Mdot
.3861 .35188 Mdot
.70519 .34916 Mdot
.31743 .69259 Mdot
.60366 .29945 Mdot
.22282 .68673 Mdot
.61039 .46917 Mdot
.78898 .5569 Mdot
.61485 .76405 Mdot
.33938 .21278 Mdot
.35719 .69379 Mdot
.73107 .66377 Mdot
.21782 .51902 Mdot
.74613 .49928 Mdot
.5108 .22893 Mdot
.28905 .82883 Mdot
.31841 .24098 Mdot
.43391 .75468 Mdot
.5368 .82624 Mdot
.19536 .55253 Mdot
.43465 .76429 Mdot
.77266 .34325 Mdot
.55067 .2791 Mdot
.7073 .39837 Mdot
.47932 .36693 Mdot
.69296 .78591 Mdot
.68168 .34628 Mdot
.55496 .82977 Mdot
.17343 .56493 Mdot
.38842 .29427 Mdot
.44344 .32673 Mdot
.615 .56066 Mdot
.56473 .65148 Mdot
.7207 .37401 Mdot
.37884 .45216 Mdot
.50368 .24369 Mdot
.64001 .72034 Mdot
.60963 .62355 Mdot
.71153 .60452 Mdot
.38739 .527 Mdot
.67211 .69585 Mdot
.33792 .70012 Mdot
.68735 .49606 Mdot
.52311 .54805 Mdot
.60841 .32888 Mdot
.53318 .2781 Mdot
.37765 .39788 Mdot
.76028 .34537 Mdot
.51984 .49916 Mdot
.62524 .61442 Mdot
.36317 .42891 Mdot
.2385 .31443 Mdot
.31788 .70779 Mdot
.59176 .81182 Mdot
.77038 .61554 Mdot
.401 .43481 Mdot
.60645 .34258 Mdot
.75302 .31821 Mdot
.53792 .19907 Mdot
.43696 .78076 Mdot
.54676 .30227 Mdot
.50598 .21222 Mdot
.28216 .58703 Mdot
.44027 .83557 Mdot
.36758 .21842 Mdot
.31487 .25839 Mdot
.57953 .63597 Mdot
.33875 .33842 Mdot
.39222 .30522 Mdot
.64109 .28008 Mdot
.52087 .56481 Mdot
.85824 .42249 Mdot
.27826 .53903 Mdot
.86347 .6025 Mdot
.44517 .63344 Mdot
.83706 .50789 Mdot
.6609 .2799 Mdot
.47059 .51866 Mdot
.51114 .56945 Mdot
.36552 .72004 Mdot
.36032 .61825 Mdot
.1793 .40543 Mdot
.66132 .22192 Mdot
.59566 .5623 Mdot
.41652 .19404 Mdot
.35763 .19438 Mdot
.35009 .44178 Mdot
.48357 .31209 Mdot
.31254 .24337 Mdot
.58002 .58395 Mdot
.75237 .36583 Mdot
.18536 .55129 Mdot
.36657 .74623 Mdot
.47959 .4554 Mdot
.62561 .34021 Mdot
.41283 .80092 Mdot
.27439 .7468 Mdot
.8082 .39089 Mdot
.3396 .75331 Mdot
.43297 .63967 Mdot
.43074 .53257 Mdot
.25586 .70075 Mdot
.55876 .24553 Mdot
.30219 .62888 Mdot
.53815 .24854 Mdot
.87979 .51953 Mdot
.54205 .7996 Mdot
.57182 .80232 Mdot
.55475 .25191 Mdot
.35702 .54334 Mdot
.43505 .73352 Mdot
.53137 .25161 Mdot
.37509 .74437 Mdot
.19989 .38355 Mdot
.54225 .25501 Mdot
.63715 .18191 Mdot
.24769 .34766 Mdot
.65323 .52554 Mdot
.39574 .30766 Mdot
.253 .34801 Mdot
.44631 .68235 Mdot
.72138 .4126 Mdot
.27758 .66749 Mdot
.44876 .67337 Mdot
.32341 .6979 Mdot
.31117 .66153 Mdot
.28015 .29905 Mdot
.34621 .376 Mdot
.3073 .7113 Mdot
.30473 .45247 Mdot
.27553 .48173 Mdot
.76348 .41445 Mdot
.66582 .63267 Mdot
.25984 .65293 Mdot
.65121 .62487 Mdot
.48863 .27711 Mdot
.55957 .53889 Mdot
.41814 .43458 Mdot
.80168 .65384 Mdot
.64819 .47436 Mdot
.31366 .55604 Mdot
.84613 .50911 Mdot
.29074 .50481 Mdot
.72527 .75443 Mdot
.74347 .32132 Mdot
.40167 .27349 Mdot
.71643 .51119 Mdot
.70422 .55728 Mdot
.76755 .28142 Mdot
.39708 .46311 Mdot
.58137 .64047 Mdot
.32223 .46263 Mdot
.33255 .55308 Mdot
.63177 .74483 Mdot
.5987 .60673 Mdot
.58451 .34024 Mdot
.40711 .6069 Mdot
.4058 .48848 Mdot
.3775 .51638 Mdot
.56814 .51209 Mdot
.659 .38368 Mdot
.50962 .83145 Mdot
.61317 .60432 Mdot
.86559 .51735 Mdot
.48884 .29991 Mdot
.29369 .4318 Mdot
.19022 .63027 Mdot
.82264 .41041 Mdot
.63284 .5555 Mdot
.37681 .17472 Mdot
.52954 .33135 Mdot
.31154 .72063 Mdot
.33583 .527 Mdot
.33506 .24427 Mdot
.65655 .47231 Mdot
.61254 .29494 Mdot
.49842 .66998 Mdot
.78382 .42039 Mdot
.66221 .6961 Mdot
.36421 .53721 Mdot
.36609 .75835 Mdot
.21721 .41307 Mdot
.33024 .61232 Mdot
.70269 .57245 Mdot
.36651 .44023 Mdot
.34274 .37009 Mdot
.37575 .52266 Mdot
.54831 .80917 Mdot
.34132 .23674 Mdot
.41942 .84324 Mdot
.41514 .40237 Mdot
.75767 .58871 Mdot
.39231 .60969 Mdot
.33839 .71278 Mdot
.58185 .3597 Mdot
.19831 .65003 Mdot
.65294 .34877 Mdot
.39653 .63579 Mdot
.62772 .36162 Mdot
.4658 .28251 Mdot
.51139 .54065 Mdot
.58796 .67751 Mdot
.712 .24736 Mdot
.58867 .40156 Mdot
.82324 .45683 Mdot
.53958 .29563 Mdot
.63459 .75568 Mdot
.35711 .55989 Mdot
.63395 .53447 Mdot
.34714 .33889 Mdot
.54476 .64599 Mdot
.42619 .83328 Mdot
.19618 .64408 Mdot
.49296 .68501 Mdot
.6175 .75173 Mdot
.23657 .59691 Mdot
.4151 .37749 Mdot
.4157 .5767 Mdot
.47594 .32675 Mdot
.35675 .56381 Mdot
.83357 .4211 Mdot
.36627 .73361 Mdot
.55941 .34531 Mdot
.42538 .82412 Mdot
.3787 .81638 Mdot
.57614 .8348 Mdot
.46284 .19045 Mdot
.36392 .50811 Mdot
.68202 .77633 Mdot
.49109 .24688 Mdot
.23154 .71458 Mdot
.4266 .77679 Mdot
.15633 .54827 Mdot
.38478 .44223 Mdot
.27183 .64947 Mdot
.67589 .23918 Mdot
.33976 .63411 Mdot
.19389 .51707 Mdot
.43768 .50083 Mdot
.54655 .69891 Mdot
.18837 .5254 Mdot
.64986 .16883 Mdot
.57042 .33729 Mdot
.3011 .65004 Mdot
.33051 .59006 Mdot
.26569 .65975 Mdot
.76396 .51913 Mdot
.45628 .40622 Mdot
.50929 .75403 Mdot
.79862 .49994 Mdot
.59829 .31456 Mdot
.70786 .41681 Mdot
.76243 .5188 Mdot
.72905 .39739 Mdot
.64083 .37312 Mdot
.37109 .21435 Mdot
.37996 .43797 Mdot
.5858 .35097 Mdot
.51428 .31147 Mdot
.34525 .56575 Mdot
.66152 .42046 Mdot
.66896 .56217 Mdot
.4708 .33363 Mdot
.59761 .54701 Mdot
.33953 .61748 Mdot
.77673 .70387 Mdot
.51347 .69193 Mdot
.19703 .4593 Mdot
.27657 .52452 Mdot
.35458 .70356 Mdot
.24406 .49452 Mdot
.81944 .53134 Mdot
.75226 .56499 Mdot
.58673 .31137 Mdot
.39112 .80692 Mdot
.72441 .69918 Mdot
.22489 .37054 Mdot
.71717 .72328 Mdot
.43701 .6588 Mdot
.50726 .44905 Mdot
.36712 .58288 Mdot
.71611 .64817 Mdot
.34322 .4686 Mdot
.27693 .65501 Mdot
.60767 .65029 Mdot
.72736 .67864 Mdot
.18308 .48323 Mdot
.21574 .40679 Mdot
.38903 .36802 Mdot
.3456 .78212 Mdot
.59938 .57549 Mdot
.31758 .25061 Mdot
.2942 .62087 Mdot
.74889 .58504 Mdot
.61598 .77872 Mdot
.48476 .83999 Mdot
.46423 .56879 Mdot
.65908 .31715 Mdot
.52057 .37906 Mdot
.37387 .25594 Mdot
.37196 .73165 Mdot
.53686 .45948 Mdot
.63284 .70514 Mdot
.2961 .52274 Mdot
.61576 .69384 Mdot
.58862 .4584 Mdot
.70788 .39369 Mdot
.37951 .48491 Mdot
.45852 .22533 Mdot
.66805 .41364 Mdot
.43587 .58991 Mdot
.43916 .34831 Mdot
.6433 .30735 Mdot
.48409 .19559 Mdot
.49628 .44767 Mdot
.30996 .73359 Mdot
.37296 .43209 Mdot
.21085 .38649 Mdot
.33539 .72589 Mdot
.44552 .78315 Mdot
.35827 .62409 Mdot
.35739 .34441 Mdot
.68689 .65792 Mdot
.45995 .33194 Mdot
.63188 .53667 Mdot
.30025 .50238 Mdot
.21939 .59546 Mdot
.33989 .40959 Mdot
.64872 .29269 Mdot
.49013 .51319 Mdot
.25474 .48098 Mdot
.48242 .49965 Mdot
.18353 .59412 Mdot
.34095 .6354 Mdot
.64511 .35154 Mdot
.43584 .61103 Mdot
.65935 .28091 Mdot
.7672 .34544 Mdot
.3378 .79312 Mdot
.73726 .30043 Mdot
.46685 .55499 Mdot
.82576 .45128 Mdot
.4356 .74562 Mdot
.18171 .54546 Mdot
.65056 .36265 Mdot
.48156 .57069 Mdot
.70709 .42847 Mdot
.50502 .67858 Mdot
.53227 .5086 Mdot
.62185 .51801 Mdot
.55164 .28928 Mdot
.59069 .72303 Mdot
.6089 .66327 Mdot
.46578 .29576 Mdot
.56207 .79007 Mdot
.37247 .79666 Mdot
.34191 .2443 Mdot
.49581 .4916 Mdot
.74631 .44771 Mdot
.70431 .38412 Mdot
.1389 .42196 Mdot
.82276 .65633 Mdot
.52069 .37677 Mdot
.50542 .49 Mdot
.64109 .32037 Mdot
.60337 .5564 Mdot
.52103 .25836 Mdot
.26002 .48541 Mdot
.46001 .61726 Mdot
.61029 .52362 Mdot
.73907 .66656 Mdot
.37359 .72257 Mdot
.69971 .33387 Mdot
.52553 .77425 Mdot
.77144 .71344 Mdot
.20644 .35678 Mdot
.34939 .72073 Mdot
.13 .48014 Mdot
.61905 .67207 Mdot
.27834 .49188 Mdot
.25625 .46928 Mdot
.52344 .82556 Mdot
.5998 .29122 Mdot
.77479 .44386 Mdot
.47565 .78765 Mdot
.65412 .35533 Mdot
.50693 .23514 Mdot
.61916 .76204 Mdot
.62293 .69692 Mdot
.47109 .53316 Mdot
.70583 .5589 Mdot
.67492 .75896 Mdot
.42796 .26012 Mdot
.38837 .79738 Mdot
.80105 .497 Mdot
.60699 .16543 Mdot
.39214 .82483 Mdot
.72398 .44309 Mdot
.76872 .51067 Mdot
.25599 .46555 Mdot
.57876 .24482 Mdot
.49028 .23348 Mdot
.76534 .38125 Mdot
.32718 .37477 Mdot
.68496 .53736 Mdot
.81579 .47963 Mdot
.61137 .34365 Mdot
.25946 .33707 Mdot
.48454 .57018 Mdot
.37152 .41002 Mdot
.64428 .72882 Mdot
.56693 .26591 Mdot
.59148 .50545 Mdot
.60878 .2654 Mdot
.36139 .43413 Mdot
.22253 .52007 Mdot
.26693 .61878 Mdot
.68731 .20026 Mdot
.44885 .79345 Mdot
.82054 .52362 Mdot
.43412 .38046 Mdot
.45583 .84717 Mdot
.27832 .62409 Mdot
.46929 .79093 Mdot
.18647 .4391 Mdot
.65322 .53586 Mdot
.40115 .59313 Mdot
.45872 .33322 Mdot
.37784 .77575 Mdot
.37065 .32432 Mdot
.24831 .36427 Mdot
.79272 .44228 Mdot
.61231 .31105 Mdot
.77909 .51173 Mdot
.62774 .26522 Mdot
.4615 .44545 Mdot
.28789 .52718 Mdot
.68102 .78535 Mdot
.44536 .56214 Mdot
.5055 .28028 Mdot
.54097 .45132 Mdot
.6849 .24493 Mdot
.25946 .27322 Mdot
.41876 .41305 Mdot
.70527 .71761 Mdot
.47668 .22014 Mdot
.39868 .37472 Mdot
.49602 .26405 Mdot
.20677 .2567 Mdot
.21661 .72606 Mdot
.3691 .50767 Mdot
.40508 .2282 Mdot
.48831 .21123 Mdot
.51472 .82478 Mdot
.72814 .57522 Mdot
.68934 .60288 Mdot
.62434 .21748 Mdot
.55643 .23052 Mdot
.50402 .30751 Mdot
.18323 .46777 Mdot
.3194 .78061 Mdot
.79981 .45113 Mdot
.41611 .82307 Mdot
.55429 .32163 Mdot
.55944 .36227 Mdot
.16941 .32806 Mdot
.2641 .71176 Mdot
.49983 .43398 Mdot
.68568 .24232 Mdot
.3032 .47583 Mdot
.48955 .35168 Mdot
.5413 .77897 Mdot
.40532 .20783 Mdot
.61053 .34651 Mdot
.49381 .82549 Mdot
.37252 .48336 Mdot
.54868 .61881 Mdot
.46168 .61465 Mdot
.51479 .56806 Mdot
.54393 .34759 Mdot
.46793 .66197 Mdot
.39976 .38468 Mdot
.25947 .64112 Mdot
.45459 .68895 Mdot
.38108 .19914 Mdot
.16321 .61266 Mdot
.35591 .40369 Mdot
.5171 .64022 Mdot
.413 .3707 Mdot
.24573 .35436 Mdot
.72335 .3814 Mdot
.40129 .53867 Mdot
.18101 .52831 Mdot
.40135 .8762 Mdot
.55517 .70245 Mdot
.65205 .39426 Mdot
.37845 .48032 Mdot
.58376 .34864 Mdot
.38008 .36555 Mdot
.4217 .60917 Mdot
.60275 .58025 Mdot
.42028 .36752 Mdot
.45669 .44261 Mdot
.48371 .67915 Mdot
.85985 .59769 Mdot
.47081 .41281 Mdot
.51417 .27038 Mdot
.23607 .71672 Mdot
.76456 .41609 Mdot
.27896 .42971 Mdot
.54246 .39335 Mdot
.41709 .71098 Mdot
.48009 .57113 Mdot
.24561 .65575 Mdot
.78693 .56278 Mdot
.45544 .81989 Mdot
.33699 .40878 Mdot
.39632 .31985 Mdot
.45352 .38841 Mdot
.63925 .42672 Mdot
.31106 .64856 Mdot
.49897 .80089 Mdot
.56888 .35184 Mdot
.25897 .74129 Mdot
.65521 .53566 Mdot
.6062 .73275 Mdot
.40035 .35725 Mdot
.59907 .82174 Mdot
.81143 .43184 Mdot
.38212 .3198 Mdot
.82225 .56189 Mdot
.71833 .66011 Mdot
.7029 .34839 Mdot
.61221 .56243 Mdot
.53118 .30253 Mdot
.37493 .48747 Mdot
.77071 .72004 Mdot
.50569 .80204 Mdot
.50446 .73485 Mdot
.59056 .70074 Mdot
.3601 .27661 Mdot
.30553 .60569 Mdot
.14366 .53825 Mdot
.71881 .60982 Mdot
.78228 .70197 Mdot
.31527 .25643 Mdot
.39263 .49164 Mdot
.2978 .67185 Mdot
.52483 .43969 Mdot
.62564 .60969 Mdot
.48915 .8172 Mdot
.44806 .43476 Mdot
.80366 .54733 Mdot
.54234 .37754 Mdot
.80175 .60699 Mdot
.58444 .53585 Mdot
.59006 .77087 Mdot
.47663 .73991 Mdot
.77393 .34807 Mdot
.20876 .59792 Mdot
.46792 .70467 Mdot
.13987 .48735 Mdot
.22238 .61097 Mdot
.30886 .76271 Mdot
.77975 .47721 Mdot
.7987 .35503 Mdot
.40014 .7667 Mdot
.31071 .71143 Mdot
.49005 .72267 Mdot
.42547 .46504 Mdot
.74903 .62887 Mdot
.40221 .36657 Mdot
.32705 .65621 Mdot
.49103 .68856 Mdot
.53253 .92215 Mdot
.70209 .46748 Mdot
.25967 .53869 Mdot
.73169 .63125 Mdot
.35144 .79213 Mdot
.46002 .46481 Mdot
.17956 .49882 Mdot
.58124 .47761 Mdot
.55217 .33433 Mdot
.33941 .38757 Mdot
.36189 .23551 Mdot
.75925 .62945 Mdot
.80283 .31629 Mdot
.20631 .36055 Mdot
.59488 .71451 Mdot
.5294 .53974 Mdot
.30499 .48941 Mdot
.29745 .56809 Mdot
.71223 .53328 Mdot
.1645 .47211 Mdot
.26754 .64658 Mdot
.25691 .70227 Mdot
.75557 .27034 Mdot
.24909 .32656 Mdot
.51891 .82787 Mdot
.4146 .74609 Mdot
.29906 .56311 Mdot
.72907 .43698 Mdot
.67999 .50754 Mdot
.49344 .7448 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
09?ooooo0_l0002dooooo`007?ooool00ol0003oooooooooo`2Aooooo`Co00009oooool2o`0008_o
oooo000Looooo`03o`000?oooooooooo097ooooo0_l0000Yooooo`;o0000Roooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`1mooooo`;o00001_ooool2o`000<;ooooo000Looooo`;o0000K?oo
ool2o`00013ooooo0_l00006ooooo`;o00006?ooool2o`0001cooooo0_l0002:ooooo`007?ooool0
0ol0003oooooooooo`1[ooooo`;o00001?ooool2o`0000[ooooo0_l00006ooooo`;o00006?ooool2
o`0001cooooo0_l0002:ooooo`007?ooool00ol0003oooooooooo`1aooooo`;o00004_ooool2o`00
00Wooooo0_l0000;ooooo`;o00003_ooool2o`0009[ooooo000Looooo`03o`000?oooooooooo093o
oooo0_l0000;ooooo`;o00001Oooool2o`0000Oooooo0_l0002Jooooo`007?ooool00ol0003ooooo
ooooo`2Eooooo`;o00003Oooool2o`0001_ooooo0_l00026ooooo`007?ooool00ol0003ooooooooo
o`22ooooo`;o00004Oooool2o`0002[ooooo0_l0000<ooooo`;o0000N?ooool001cooooo00?o0000
ooooooooool0P_ooool2o`0000?ooooo0_l00016ooooo`;o0000N?ooool001cooooo00?o0000oooo
ooooool0Moooool2o`0000Oooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l0002aoooo
o`007?ooool00ol0003oooooooooo`1gooooo`;o00001oooool2o`0000gooooo0_l00005ooooo`;o
0000/Oooool001cooooo00?o0000ooooooooool0J_ooool2o`0000Gooooo0_l00004ooooo`;o0000
0_ooool2o`0001oooooo0_l0000Fooooo`;o0000Toooool001cooooo00?o0000ooooooooool0J_oo
ool2o`0000Gooooo0_l00008ooooo`;o00006oooool2o`0000;ooooo0_l0000?ooooo`;o00001Ooo
ool3o`000003ooooool0003o0000017ooooo0_l0001looooo`007?ooool00ol0003oooooooooo`2@
ooooo`;o00001_ooool2o`0000Cooooo0_l0000=ooooo`;o00001_ooool2o`000003ooooool0003o
000000?ooooo0_l0000<ooooo`;o0000O?ooool001cooooo00?o0000ooooooooool0Q?ooool2o`00
00?ooooo0_l00005ooooo`;o000000?oooooo`000?l000002Oooool2o`0001gooooo0_l0002:oooo
o`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000
ooooooooool0Q?ooool2o`0000?ooooo0_l00003ooooo`;o00000oooool3o`0000Wooooo0_l0000:
ooooo`;o00009_ooool2o`0007Cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ
8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1`ooooo`;o0000
00?oooooo`000?l000003oooool4o`000004ooooool0003o0000ooooo`Co00001?ooool2o`0000?o
oooo0_l00004ooooo`;o00000oooool2o`0000Gooooo0_l0000@ooooo`;o00000oooool2o`0000_o
oooo0_l00002ooooo`;o0000M?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool0
2_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo073ooooo0_l000000ooooooo0000
o`000003ooooo`;o00002_ooool4o`0000Cooooo0_l00002ooooo`;o00001oooool3o`0000Sooooo
0_l00002ooooo`;o000000?oooooo`000?l000004?ooool2o`0000?ooooo0_l0000;ooooo`;o0000
N?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^
kP06ooooo`?o0000Loooool2o`0000?ooooo0_l0000:ooooo`;o00002_ooool2o`0000Sooooo0_l0
0003ooooo`;o00001oooool2o`000003ooooool0003o000002kooooo0_l0001/ooooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000
ooooooooool0Loooool2o`0000gooooo1?l0000Aooooo`Ko00000_ooool2o`0000Cooooo0_l00004
ooooo`Co00002Oooool2o`000003ooooool0003o000001kooooo0_l0001/ooooo`0000?ooooooa0@
4?ooool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0P?ooool7o`00013ooooo1_l00006ooooo`Co00001_ooool2o`0000Wooooo0_l000000ooo
oooo0000o`000005ooooo`;o00000_ooool2o`0000;ooooo0_l0001mooooo`0000KoooooogMgMonH
V9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003ooooooooo
o`1fooooo`;o00002?ooool7o`0000oooooo1ol00004ooooo`Co00007Oooool2o`0000;ooooo1_l0
000<ooooo`Co0000KOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@
o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0GOooool2o`0000cooooo0_l00008ooooo`?o
00002_ooool2o`0000Oooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool2o`000003
ooooool0003o000000;o00001?ooool4o`0000Gooooo0_l0000Looooo`;o00003?ooool6o`0006go
oooo000Looooo`03o`000?oooooooooo05gooooo0_l0000<ooooo`;o00001oooool3o`0000Sooooo
0_l0000:ooooo`;o000000?oooooo`000?l000001?l00005ooooo`;o00001Oooool2o`0000Sooooo
0ol0000:ooooo`;o00003Oooool3o`0000gooooo0_l0001aooooo`007?ooool00ol0003ooooooooo
o`1Wooooo`;o00002oooool2o`0000Wooooo0_l00004ooooo`;o00002Oooool2o`0000;ooooo0_l0
00000ooooooo0000o`000007ooooo`;o00002Oooool2o`0000;ooooo0_l00003ooooo`Go00001_oo
ool2o`0000Gooooo0ol00020ooooo`007?ooool00ol0003oooooooooo`1Wooooo`;o00000oooool2
o`00013ooooo0_l00005ooooo`Co00001oooool2o`0000;ooooo0_l000000ooooooo0000o`00000E
ooooo`Go000000Coooooo`000?l0003o00002?ooool2o`0000gooooo0_l00003ooooo`;o0000M?oo
ool001cooooo00?o0000ooooooooool0K?ooool2o`00013ooooo0_l00006ooooo`?o00001oooool3
o`0001_ooooo1Ol0000Kooooo`;o00000oooool2o`0007Cooooo000Looooo`03o`000?oooooooooo
06Wooooo0_l0000@ooooo`;o00000oooool2o`0000Cooooo0_l00009ooooo`;o00001?ooool2o`00
00Kooooo0_l000000ooooooo0000o`00000=ooooo`;o00001_ooool2o`0001oooooo0_l0001]oooo
o`007?ooool00ol0003oooooooooo`1Yooooo`;o00001Oooool2o`0000Wooooo0_l00003ooooo`;o
00005Oooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool4o`0000Gooooo0_l00004oooo
o`;o00001_ooool2o`0001oooooo0_l00005ooooo`Co0000I?ooool001cooooo00?o0000oooooooo
ool0Joooool2o`0000?ooooo1?l00006ooooo`;o00003_ooool2o`0000Wooooo0_l00005ooooo`;o
000000?oooooo`000?l000000_l000000ooooooo0000o`000005ooooo`;o0000=?ooool4o`0006Co
oooo000Looooo`03o`000?oooooooooo06Wooooo1?l00005ooooo`;o00001_ooool2o`0000kooooo
0_l00002ooooo`;o00001Oooool2o`0000;ooooo0_l00004ooooo`Co00002?ooool2o`000003oooo
ool0003o000000Kooooo1Ol00006ooooo`;o00005Oooool2o`0006oooooo000Looooo`03o`000?oo
oooooooo06Cooooo0_l00003ooooo`;o00000oooool2o`0000_ooooo0_l0000>ooooo`;o000000?o
ooooo`000?l000002Oooool2o`0000Kooooo0_l00008ooooo`;o000000?oooooo`000?l000001_oo
ool5o`0000Kooooo0_l0000Eooooo`Go0000K?ooool001cooooo00?o0000ooooooooool0C_ooool2
o`0000cooooo0_l00004ooooo`Co00000oooool4o`000003ooooool0003o000000;o00002Oooool2
o`0000kooooo0_l0000Cooooo`;o00002Oooool2o`000005ooooool0003o0000o`000?ooool00_l0
0004ooooo`;o00001?ooool2o`0001Oooooo1_l0001/ooooo`007?ooool00ol0003oooooooooo`1>
ooooo`;o00003?ooool2o`0000Cooooo0ol00004ooooo`Co00000oooool2o`0002Oooooo0_l00000
0ooooooo0000o`000002ooooo`;o00002Oooool2o`0000;ooooo0_l000000ooooooo0000o`000004
ooooo`;o00001?ooool2o`0000Kooooo0_l000000ooooooo0000o`00000<ooooo`;o000000Cooooo
o`000?l0003o00001_ooool2o`0006Cooooo000Looooo`;o0000Foooool2o`0000Oooooo0_l0000E
ooooo`;o00001_ooool2o`0000_ooooo0_l00008ooooo`;o000000?oooooo`000?l000002Oooool6
o`0000?ooooo0_l00006ooooo`;o00000_ooool4o`0000Kooooo0_l000000ooooooo0000o`00000?
ooooo`;o00001oooool2o`0006Cooooo000Looooo`03o`000?oooooooooo05[ooooo0_l00005oooo
o`Co00004Oooool2o`000004ooooool0003o0000o`0000Kooooo0_l00003ooooo`;o00001_ooool2
o`0000Sooooo1_l00008ooooo`Co000000?oooooo`000?l000001?l0000:ooooo`Ko00001oooool2
o`000003ooooool0003o000007_ooooo000Looooo`03o`000?oooooooooo03oooooo0_l0000Poooo
o`Co00003?ooool2o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`;o000000Coooooo`00
0?l0003ooooo0_l00006ooooo`;o00002?ooool6o`0000Kooooo0_l00005ooooo`Ko00003_ooool2
o`0000Oooooo0_l000000ooooooo0000o`000009ooooo`;o0000L?ooool001cooooo00?o0000oooo
ooooool0?oooool2o`0002;ooooo0_l0000<ooooo`;o00000oooool4o`000003ooooool0003o0000
00Cooooo0_l000001?oooooo0000o`000?ooool2o`0000Kooooo0_l0000Dooooo`;o00001oooool2
o`0000?ooooo0_l00006ooooo`;o00003?ooool2o`0000Gooooo0_l00005ooooo`;o00003?ooool2
o`0006;ooooo000Looooo`03o`000?oooooooooo05[ooooo1?l00005ooooo`;o00002oooool2o`00
00Kooooo0_l000000ooooooo0000o`000002o`0000Sooooo0_l00008ooooo`;o00002_ooool2o`00
01Cooooo0_l00004ooooo`Co00003_ooool2o`0000?ooooo0_l0000<ooooo`;o00001Oooool2o`00
06;ooooo000Looooo`03o`000?oooooooooo05[ooooo1?l0000Booooo`Co00000_ooool2o`0000;o
oooo0_l000000ooooooo0000o`00000?ooooo`;o000000?oooooo`000?l000002Oooool3o`0000Co
oooo0_l0000?ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`Co00000_ooool2o`000004
ooooool0003o0000o`00013ooooo0_l00005ooooo`;o0000H_ooool001cooooo00?o0000oooooooo
ool0G?ooool2o`0001Cooooo0_l00002ooooo`Ko00004_ooool2o`0000Sooooo0_l00002ooooo`;o
00001Oooool2o`0000?ooooo0_l0000:ooooo`;o00000_ooool2o`0000;ooooo2_l00002ooooo`;o
00000_ooool3o`0001Kooooo0_l0000;ooooo`;o0000EOooool001cooooo00?o0000ooooooooool0
DOooool2o`0000?ooooo0_l0000Cooooo`;o00002oooool2o`000003ooooool0003o000000;ooooo
0_l0000Aooooo`;o00001?ooool2o`0000Oooooo1?l00003ooooo`Co00003?ooool2o`0000;ooooo
2?l00009ooooo`Co00005?ooool2o`0000_ooooo0_l0001Eooooo`007?ooool00ol0003ooooooooo
o`1Aooooo`;o00000oooool2o`0000;ooooo0_l0000?ooooo`;o00001?ooool2o`0000Sooooo0ol0
00000ooooooo0000o`00000>ooooo`;o000000?oooooo`000?l000001?l00009ooooo`?o00001_oo
ool2o`0000Sooooo0_l0000Iooooo`;o00004oooool4o`00067ooooo000Looooo`03o`000?oooooo
oooo04Gooooo0_l0000Cooooo`;o00005Oooool2o`0000Wooooo1?l0000?ooooo`;o00000_ooool7
o`000003ooooool0003o000000cooooo0_l00004ooooo`;o00000oooool2o`0001Kooooo0_l00000
0ooooooo0000o`000002ooooo`;o00003oooool6o`0005oooooo000Looooo`03o`000?oooooooooo
04Gooooo0_l0000:ooooo`;o00000oooool2o`000003ooooool0003o0000023ooooo0_l000000ooo
oooo0000o`00000=ooooo`Co00000oooool2o`0000;ooooo1Ol00003ooooo`;o00000_ooool2o`00
00?ooooo0_l00004ooooo`;o00006oooool2o`0000Cooooo0ol0000Cooooo`;o000000?oooooo`00
0?l000001oooool4o`00057ooooo000Looooo`03o`000?oooooooooo04kooooo0_l000000ooooooo
0000o`000003ooooo`;o000000?oooooo`000?l000003oooool2o`0000cooooo0_l000000ooooooo
0000o`000003ooooo`;o00002oooool2o`000003ooooool0003o000000;ooooo0_l00003ooooo`Co
00000oooool3o`000003ooooool0003o0000017ooooo0ol00006ooooo`;o00000_ooool2o`0000co
oooo0_l0000Gooooo`;o00001oooool4o`00057ooooo000Looooo`03o`000?oooooooooo04kooooo
0_l0000Aooooo`;o00001oooool2o`0000cooooo1Ol00003ooooo`;o00003_ooool2o`0000Gooooo
0_l00005ooooo`;o000000Coooooo`000?l0003ooooo0_l00007ooooo`Co00001_ooool3o`0000Ko
oooo0_l00002ooooo`Co00001_ooool2o`000003ooooool0003o000001[ooooo0_l0001Jooooo`00
7?ooool00ol0003oooooooooo`1>ooooo`;o00004Oooool2o`0000_ooooo0_l00003ooooo`?o0000
1?ooool2o`0000Cooooo0_l0000Eooooo`?o00000_ooool7o`000003ooooool0003o000000Oooooo
1?l0000>ooooo`;o00001Oooool2o`0000Kooooo0_l000000ooooooo0000o`00000Jooooo`;o0000
F_ooool001cooooo00?o0000ooooooooool0K_ooool2o`0000?ooooo0ol00004ooooo`;o00001?oo
ool3o`0000Sooooo0_l000000ooooooo0000o`000007ooooo`?o00000_ooool2o`000003ooooool0
003o000000?o00005oooool2o`0000;ooooo0_l00002ooooo`;o00002_ooool2o`0000?ooooo0_l0
001cooooo`007?ooool00ol0003oooooooooo`1Jooooo`;o00005?ooool2o`0000Cooooo0_l00002
ooooo`;o00001?ooool3o`0000Sooooo0_l000000ooooooo0000o`000004ooooo`;o00000_ooool4
o`0000Kooooo0_l00008ooooo`;o000000?oooooo`000?l000002_ooool2o`0000Cooooo1?l0000:
ooooo`Co000000Coooooo`000?l0003o0000L_ooool001cooooo0_l0001Aooooo`Go00000_ooool2
o`000003ooooool0003o000001Cooooo0_l00004ooooo`;o00003?ooool4o`0000?ooooo0_l00000
0ooooooo0000o`000004ooooo`;o00000_ooool5o`0000Cooooo1_l00005ooooo`;o000000?ooooo
o`000?l000000_l0000=ooooo`Co00000_ooool2o`0000Wooooo0_l000000ooooooo0000o`000003
o`0001?ooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00004?ooool5o`00
00;ooooo0_l0000Gooooo`;o00004_ooool4o`000003ooooool0003o000000;o000000Goooooo`00
0?l0003o0000ooooo`02o`0000Cooooo1Ol00004ooooo`Ko000000?oooooo`000?l000001_l00000
0ooooooo0000o`00000=ooooo`Co00000_ooool2o`0000;ooooo0_l00004ooooo`;o00001Oooool2
o`0001?ooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00003?ooool2o`00
00Sooooo1?l0000Fooooo`;o00002_ooool3o`0000[ooooo0_l00004ooooo`_o000000?oooooo`00
0?l000000oooool=o`000003ooooool0003o000000;ooooo0ol00006ooooo`;o00003Oooool2o`00
0004ooooool0003o0000ooooo`;o00001Oooool2o`0000;ooooo0_l0000=ooooo`Co0000Foooool0
01cooooo00?o0000ooooooooool0B_ooool4o`0000Sooooo1?l0000Rooooo`?o00001_ooool2o`00
00Wooooo0ol000000ooooooo0000o`000004o`000004ooooool0003o0000o`0000;ooooo2?l00000
0ooooooo0000o`000002ooooo`?o00000_ooool3o`0000Cooooo1?l000000ooooooo0000o`00000=
ooooo`;o00002?ooool2o`0000;ooooo0_l0000=ooooo`Co0000Foooool001cooooo00?o0000oooo
ooooool0B_ooool2o`0000_ooooo0ol0000[ooooo`Co00001Oooool5o`0000Gooooo3Ol000001?oo
oooo0000o`000?ooool2o`0000;ooooo0ol00009ooooo`Co000000?oooooo`000?l000000oooool4
o`0000Kooooo0_l0000Looooo`;o00000oooool2o`0005Oooooo000Looooo`03o`000?oooooooooo
04Oooooo1Ol0000;ooooo`?o00005_ooool2o`0001Gooooo0_l00005ooooo`;o00002Oooool?o`00
0003ooooool0003o000000Cooooo0_l0000:ooooo`;o00000_ooool2o`0000;ooooo1?l00006oooo
o`;o00002_ooool3o`0000oooooo0_l00003ooooo`;o00002oooool2o`0000;ooooo0_l00016oooo
o`007?ooool00ol0003oooooooooo`17ooooo`Go00001?ooool2o`0000Cooooo0_l0000Hooooo`;o
00001_ooool2o`0000?ooooo0_l00007ooooo`Go00000_ooool2o`0000Wooooo3ol00003ooooo`;o
00000oooool2o`0000kooooo0_l0000Aooooo`;o00000oooool7o`0001?ooooo0_l0000:ooooo`;o
00000_ooool2o`0004Kooooo000Looooo`03o`000?oooooooooo04Oooooo1?l00003ooooo`Co0000
0_ooool6o`0001Sooooo1?l00002ooooo`;o00000oooool2o`0000Oooooo1Ol00002ooooo`;o0000
0_ooool2o`0000Cooooo3Ol000001?oooooo0000o`000?l00002ooooo`;o00000oooool4o`0001Wo
oooo0_l00004ooooo`;o00000oooool2o`0000?ooooo0_l0000@ooooo`;o000000?oooooo`000?l0
0000E_ooool001cooooo00?o0000ooooooooool0B?ooool4o`0000;ooooo0ol00003ooooo`?o0000
00?oooooo`000?l000006?ooool5o`0000Wooooo0_l00005ooooo`;o00000oooool3o`0000;ooooo
2ol000000ooooooo0000o`00000;o`0000Gooooo1?l0000<ooooo`;o00002oooool2o`0001gooooo
1Ol00008ooooo`;o0000Coooool001cooooo00?o0000ooooooooool0<oooool2o`0000oooooo0_l0
0002ooooo`Co000000?oooooo`000?l000007_ooool2o`0000Cooooo1?l00009ooooo`;o000000?o
ooooo`000?l000001oooool3o`0000;ooooo6Ol00002ooooo`;o000000?oooooo`000?l000003_oo
ool2o`000003ooooool0003o0000013ooooo0_l0000Eooooo`?o00002_ooool2o`0004oooooo000L
ooooo`03o`000?oooooooooo03?ooooo0_l0000?ooooo`;o00001oooool2o`0001kooooo0_l00004
ooooo`;o00003_ooool2o`0000Kooooo1_l000000ooooooo0000o`00000Co`000005ooooool0003o
0000o`000?ooool00_l00002ooooo`Co00003_ooool2o`0000Cooooo0_l00003ooooo`;o00001Ooo
ool2o`0000Cooooo0_l0000Eooooo`?o00000oooool2o`00053ooooo000Looooo`03o`000?oooooo
oooo08Wooooo4Ol000000ooooooo0000o`00000:o`000003ooooool0003o000000Co00000_ooool4
o`0000Oooooo1?l00002ooooo`;o00001?ooool3o`0000?ooooo0ol0000:ooooo`;o00000_ooool3
o`00013ooooo0ol000000ooooooo0000o`000002o`00053ooooo000Looooo`03o`000?oooooooooo
057ooooo0_l0000Gooooo`;o00003?ooool2o`0000kooooo0ol00003ooooo`co000000?oooooo`00
0?l000004Ol00002ooooo`;o00001?ooool2o`0000?ooooo1?l00002ooooo`;o00000_ooool4o`00
00Cooooo0ol00004ooooo`;o00002?ooool3o`00013ooooo0_l00002ooooo`;o0000D_ooool001co
oooo00?o0000ooooooooool0??ooool2o`00017ooooo1?l00003ooooo`;o00004_ooool2o`000003
ooooool0003o000000Sooooo0ol0000>ooooo`Co00000ooooolQo`000003ooooool0003o000000?o
oooo0_l00002ooooo`Ko00001Oooool4o`0000Cooooo0_l00005ooooo`Co00002Oooool2o`0006Ko
oooo000Looooo`03o`000?oooooooooo03cooooo0_l0000Aooooo`;o00001Oooool2o`0001Gooooo
0_l000000ooooooo0000o`000005ooooo`;o00001Oooool2o`0000;ooooo0_l00004ooooo`Go0000
0_oooolJo`0000Cooooo1ol00006ooooo`;o00000_ooool7o`0000;ooooo0_l00003ooooo`;o0000
1oooool3o`0000Wooooo0_l0000:ooooo`;o00001oooool3o`00053ooooo000Looooo`03o`000?oo
oooooooo04gooooo0_l0000Qooooo`;o00003?ooool2o`0000;ooooo2?l000000ooooooo0000o`00
000No`0000;ooooo0_l000000ooooooo0000o`000002o`0000_ooooo1_l00002ooooo`;o00000ooo
ool4o`0000Cooooo1?l00002ooooo`;o00004Oooool2o`0000Cooooo1_l0000=ooooo`;o0000@Ooo
ool001cooooo0_l0001>ooooo`?o00001Oooool2o`0001Sooooo0_l00004ooooo`;o00001oooool2
o`0000Cooooo1_l000000ooooooo0000o`00000To`000003ooooool0003o000000Kooooo0ol00006
ooooo`;o00000_ooool2o`000003ooooool0003o000000Ko00000_ooool4o`0000;ooooo0_l00005
ooooo`;o00000oooool2o`0000_ooooo1?l000000ooooooo0000o`00000<ooooo`;o0000@Oooool0
01cooooo00?o0000ooooooooool0AOooool2o`0000Oooooo0ol00004ooooo`;o00006?ooool2o`00
00Cooooo0_l00003ooooo`;o00000_ooool2o`0000_ooooo8ol000000ooooooo0000o`000002oooo
o`Co00000oooool3o`0000gooooo2?l00005ooooo`;o00002?ooool4o`000004ooooool0003o0000
o`0000?ooooo0_l0000:ooooo`;o0000Coooool001cooooo00?o0000ooooooooool0?oooool2o`00
00Cooooo0_l00005ooooo`;o000000?oooooo`000?l000008Oooool2o`0000Kooooo0_l000000ooo
oooo0000o`00000:ooooo`;o00000_oooolBo`000003ooooool0003o000000co000000?oooooo`00
0?l000000_ooool4o`0001Oooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`00
0?l000001_ooool3o`000004ooooool0003o0000o`0000?ooooo0_l00004ooooo`;o00001?ooool2
o`0000Kooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00002oooool2o`00
02Cooooo0_l00002ooooo`;o00001Oooool3o`0000Wooooo1?l000000ooooooo0000o`00000?o`00
0004ooooool0003o0000o`0000;ooooo2Ol00003ooooo`;o00001_ooool2o`0000;ooooo0_l00000
1?oooooo0000o`000?ooool2o`0000;ooooo0_l00008ooooo`;o00001_ooool4o`0000Oooooo0_l0
0004ooooo`;o00001_ooool2o`0000Cooooo0_l00004ooooo`Co0000Aoooool001cooooo00?o0000
ooooooooool0?oooool2o`0001;ooooo0_l0000Cooooo`;o00003?ooool2o`0000Kooooo0_l00003
ooooob_o00000oooool4o`0000Cooooo0ol000000ooooooo0000o`000006o`0000;ooooo0ol00006
ooooo`?o00001_ooool4o`0000Oooooo0_l00004ooooo`;o00004_ooool2o`0004Wooooo000Loooo
o`03o`000?oooooooooo03oooooo0_l00004ooooo`;o00001_ooool2o`0000Cooooo0_l0000Coooo
o`;o00003_ooool2o`0000Wooooo;?l000000ooooooo0000o`000004o`0000Cooooo0_l00003oooo
o`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo0_l00002ooooo`?o00006_ooool2o`00
0004ooooool0003o0000o`0000cooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`15oooo
o`;o00001_ooool2o`0002Wooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool9o`00
0003ooooool0003o000002Oo00002Oooool2o`000003ooooool0003o000000Kooooo1?l00002oooo
o`;o00001Oooool3o`0000oooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00003?ooool2
o`0004Sooooo000Looooo`03o`000?oooooooooo03kooooo0_l00005ooooo`;o00003Oooool2o`00
01Kooooo0_l0000=ooooo`Ko000000?oooooo`000?l000000ol00002oooooaKo000000?oooooo`00
0?l000004ol0000Eooooo`;o00001?ooool2o`0000Gooooo0ol0000<ooooo`;o000000?oooooo`00
0?l00000G_ooool001cooooo00?o0000ooooooooool0>?ooool5o`000003ooooool0003o000000Co
oooo0ol00006ooooo`;o00001Oooool2o`00017ooooo0_l00003ooooo`;o00001_ooool2o`0000?o
oooo0_l000000ooooooo0000o`000002o`000004ooooool0003o0000o`0000Gooooo:Ol000001?oo
oooo0000o`000?ooool2o`00017ooooo0_l000000ooooooo0000o`000004ooooo`;o00000oooool2
o`0000gooooo0ol0000;ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0>?ooool5o`00
00Oooooo0ol00006ooooo`;o00006?ooool2o`000004ooooool0003o0000ooooo`;o00001Oooool2
o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000001_l00002ooooob?o000000?ooooo
o`000?l000000_l00003ooooo`;o00004?ooool3o`000003ooooool0003o000000Cooooo0_l00004
ooooo`;o00001?ooool5o`0000?ooooo0ol0000;ooooo`Co0000DOooool001cooooo00?o0000oooo
ooooool0<Oooool2o`0000Cooooo0_l00009ooooo`;o000000?oooooo`000?l000001_ooool2o`00
01Wooooo1ol0000>ooooo`;o00001?ooool/o`0000;ooooo0_l00004ooooo`;o00003oooool2o`00
00Oooooo0_l00005ooooo`;o00001?ooool5o`0000Cooooo0_l0000;ooooo`Co00001_ooool2o`00
04Wooooo000Looooo`03o`000?oooooooooo037ooooo0_l00004ooooo`;o00001?ooool2o`0000?o
oooo0_l0000Tooooo`;o000000?oooooo`000?l000000oooool2o`0000_ooooo0ol00002ooooo`;o
00000ooooolXo`000003ooooool0003o000000Co000000?oooooo`000?l000005?ooool7o`0000[o
oooo0_l000000ooooooo0000o`000004ooooo`;o00003?ooool2o`0000Oooooo0_l0000?ooooo`;o
0000>?ooool001cooooo00?o0000ooooooooool0?Oooool2o`0000;ooooo0_l0000;ooooo`;o0000
0_ooool2o`0001Oooooo0_l00003ooooo`?o000000?oooooo`000?l000002?ooool2o`0000;ooooo
0_l00003ooooobOo000000?oooooo`000?l000001Ol00005ooooo`;o00003_ooool6o`000003oooo
ool0003o000000gooooo0_l0000=ooooo`?o00002?ooool4o`00013ooooo0_l0000hooooo`007?oo
ool00ol0003oooooooooo`0eooooo`;o00002_ooool2o`0000?ooooo0_l000000ooooooo0000o`00
0003ooooo`;o00000_ooool2o`0001Oooooo0_l00003ooooo`?o000000?oooooo`000?l000004?oo
ool/o`0000Cooooo0_l000000ooooooo0000o`000004o`000003ooooool0003o000000?ooooo0_l0
0004ooooo`;o00001_ooool2o`0000[ooooo0_l0000?ooooo`?o00002?ooool4o`0000Cooooo0_l0
000Aooooo`;o0000<Oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo
0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo03Gooooo0_l0000?ooooo`Go0000
2Oooool2o`00033ooooo0_l000001?oooooo0000o`000?oooolYo`000004ooooool0003o0000oooo
o`;o00000_ooool2o`000003ooooool0003o000000?ooooo0_l00004ooooo`;o00001_ooool2o`00
00[ooooo0_l000000ooooooo0000o`00000Booooo`;o00001?ooool5o`0000;ooooo0_l0000Aoooo
o`;o0000<Oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`10ooooo`;o00001_ooool2o`0000[ooooo0_l0000`
ooooo`;o00000ooooolUo`000003ooooool0003o000000;o000000?oooooo`000?l000002_ooool2
o`0000cooooo0_l000000ooooooo0000o`00000=ooooo`;o00004_ooool2o`0000Kooooo0ol00018
ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`Go00001_ooool00ol0
003oooooooooo`0`ooooo`;o00003Oooool3o`0000oooooo0_l000000ooooooo0000o`00000Qoooo
o`?o00002Oooool2o`000003ooooool0003o000000;ooooo1_l000000ooooooo0000o`000002o`00
00Cooooo4_l000000ooooooo0000o`000002ooooo`;o00001?ooool2o`0000Oooooo0_l000000ooo
oooo0000o`00000<ooooo`;o00002Oooool5o`0000;ooooo0_l00005ooooo`;o00005Oooool2o`00
04Oooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoo
oooo00001oooool3o`00033ooooo1?l0000;ooooo`;o00004?ooool3o`0000;ooooo0_l0000<oooo
o`;o00004Oooool3o`0000Wooooo0_l000001?oooooo0000o`000?ooool3o`000003ooooool0003o
000001co000000?oooooo`000?l000001?l000000ooooooo0000o`000003ooooo`;o000000?ooooo
o`000?l000000_ooool2o`0000?ooooo0_l00006ooooo`;o00000_ooool4o`0000Oooooo1Ol00002
ooooo`;o00001Oooool3o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`;o00001_ooool2
o`0000?ooooo0_l0000:ooooo`;o0000=_ooool00003ooooool0003ooooo00;ooooo00?o0000oooo
ooooool02Oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo03;ooooo0_l00003
ooooo`;o00002?ooool2o`0000?ooooo0_l0000:ooooo`;o00000_ooool2o`0000cooooo0_l0000:
ooooo`;o00002Oooool2o`0000Kooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo8Ol0
0003ooooo`;o00000oooool2o`000003ooooool0003o000000Oooooo0_l00006ooooo`?o000000?o
ooooo`000?l000001?l000000ooooooo0000o`000003ooooo`;o00000_ooool4o`0000Kooooo0_l0
00000ooooooo0000o`000002o`000003ooooool0003o000000;ooooo1?l0000;ooooo`;o00002_oo
ool2o`0003Kooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oMgMg
olc<c?l000001oooool00ol0003oooooooooo`0gooooo`;o00002?ooool3o`0000;ooooo0_l0000<
ooooo`;o00004_ooool4o`0000Cooooo0_l00009ooooo`;o00001_ooool4o`0000;ooooo1Ol00000
0ooooooo0000o`00000No`0000Gooooo0_l0000Gooooo`?o00000_ooool4o`000004ooooool0003o
0000ooooo`Co00000_ooool2o`0000_ooooo0_l00003ooooo`;o00000_ooool2o`0000Oooooo0_l0
0018ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo
00?o0000ooooooooool0<_ooool2o`0000;ooooo0_l00006ooooo`;o00000_ooool2o`0000Cooooo
0_l00008ooooo`Ko00004?ooool5o`0000Sooooo0_l00009ooooo`;o000000?oooooo`000?l00000
0_l00003ooooo`?o00000_oooolPo`000003ooooool0003o000000Co00001_ooool2o`0000oooooo
1Ol000000ooooooo0000o`000002o`0000?ooooo0_l0000Hooooo`;o00002Oooool6o`0000;ooooo
0_l00010ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Ko
oooo00?o0000ooooooooool0;oooool2o`000003ooooool0003o000000;ooooo0_l00006ooooo`;o
00000oooool2o`0000?ooooo0_l00008ooooo`;o000000Coooooo`000?l0003o00004oooool3o`00
00Oooooo0_l00009ooooo`;o00000_ooool3o`0000Kooooo9ol00008ooooo`;o00004Oooool3o`00
00?ooooo0ol0000:ooooo`;o00000oooool2o`0000_ooooo0_l0000;ooooo`Co00000_ooool2o`00
043ooooo000Looooo`03o`000?oooooooooo02oooooo0_l00004ooooo`;o00001Oooool2o`0000Go
oooo0_l0000>ooooo`;o00001?ooool2o`0000oooooo1?l0000Fooooo`?o00001_oooolMo`0000;o
oooo1?l000000ooooooo0000o`000009ooooo`;o00004?ooool6o`000003ooooool0003o000000?o
00002?ooool2o`0000?ooooo0_l0000;ooooo`?o00001?ooool2o`0004cooooo000Looooo`03o`00
0?oooooooooo03Gooooo0_l00004ooooo`?o00002Oooool2o`0000[ooooo0_l00004ooooo`;o0000
2?ooool2o`0000Gooooo0_l0000;ooooo`;o00004_ooool4o`000003ooooool0003o000001Co0000
1oooool3o`000003ooooool0003o000001_ooooo2Ol000000ooooooo0000o`000003ooooo`;o0000
0oooool2o`0000Sooooo0_l00007ooooo`;o000000Coooooo`000?l0003ooooo0_l00007ooooo`;o
00001Oooool2o`0003cooooo000Looooo`03o`000?oooooooooo02Wooooo0_l0000@ooooo`Co0000
00?oooooo`000?l000001Oooool2o`0001[ooooo0_l00002ooooo`;o00003_ooool2o`00013ooooo
1_l00008ooooo`?o000000?oooooo`000?l000000ol00002ooooo`Ko000000Coooooo`000?l0003o
00000_ooool2o`000003ooooool0003o000001Oooooo0_l000000ooooooo0000o`000008o`000003
ooooool0003o000000?ooooo0_l000000ooooooo0000o`00000:ooooo`;o00002_ooool2o`000003
ooooool0003o000000Oooooo0ol00004ooooo`;o00001_ooool2o`0003Cooooo000Looooo`03o`00
0?oooooooooo02Wooooo0_l0000@ooooo`Co000000?oooooo`000?l000009Oooool2o`00023ooooo
0_l00002ooooo`;o00000oooool2o`0000?ooooo0_l00002ooooo`Go00000_ooool6o`000004oooo
ool0003o0000o`0000;ooooo1?l00005ooooo`Co00003oooool@o`0000Kooooo0_l00002ooooo`;o
00004?ooool2o`0000gooooo0_l0000<ooooo`;o0000=?ooool001cooooo00?o0000ooooooooool0
=_ooool2o`0000?ooooo0_l0000Jooooo`;o00001_ooool2o`00017ooooo0_l000000ooooooo0000
o`00000Jooooo`?o000000?oooooo`000?l000000_l000000ooooooo0000o`000003o`0000?ooooo
1Ol00007ooooo`Co00001?ooool5o`00017ooooo4Ol00005ooooo`Co00004?ooool2o`0000oooooo
0_l00002ooooo`;o0000??ooool001cooooo00?o0000ooooooooool0=_ooool2o`0001oooooo0_l0
0003ooooo`;o000000?oooooo`000?l000004Oooool2o`000003ooooool0003o000000?ooooo0_l0
0006ooooo`;o00001?ooool2o`0000Oooooo1ol000001Ooooooo0000o`000?l0003ooooo00So0000
2_ooool2o`0000Gooooo0_l000000ooooooo0000o`00000Aoooooa7o00000_ooool2o`000004oooo
ool0003o0000o`0000Oooooo0ol0000:ooooo`;o00002Oooool2o`000003ooooool0003o000000;o
oooo0_l0000looooo`007?ooool00ol0003oooooooooo`11ooooo`;o00001?ooool2o`0001?ooooo
0_l00002ooooo`;o00004?ooool2o`000003ooooool0003o000000?ooooo0_l00003ooooo`;o0000
00?oooooo`000?l000000_l00002ooooo`;o00000_ooool4o`000003ooooool0003o000000;o0000
0_ooool5o`0000?ooooo1?l00006ooooo`;o00003_ooool2o`00017ooooo5Ol00008ooooo`;o0000
00Coooooo`000?l0003o00001?ooool2o`0000Cooooo0_l00009ooooo`;o00003?ooool2o`0003Go
oooo000Looooo`03o`000?oooooooooo03Kooooo0_l000000ooooooo0000o`000006ooooo`?o0000
0oooool2o`0000Wooooo0_l0000<ooooo`;o00002_ooool2o`0000Gooooo0_l00003ooooo`Co0000
0_ooool3o`0000?ooooo0_l00006ooooo`Co000000Coooooo`000?l0003ooooo0_l000000ooooooo
0000o`000007ooooo`_o00002?ooool2o`0001Oooooo4ol000000ooooooo0000o`000002o`0000Go
oooo0_l00008ooooo`;o00005oooool2o`0000Cooooo0_l0000eooooo`007?ooool00ol0003ooooo
ooooo`0eooooo`?o000000?oooooo`000?l000001oooool2o`0000Kooooo0_l00006ooooo`;o0000
2oooool4o`0000Wooooo1?l00003ooooo`;o00000oooool4o`0000;ooooo0_l00007ooooo`;o0000
0oooool3o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000Kooooo2_l00006ooooo`;o
00000_ooool2o`0001;ooooo0_l00003oooooaSo00000oooool2o`0001Gooooo0_l00004ooooo`Co
00001?ooool2o`0003_ooooo000Looooo`03o`000?oooooooooo03Gooooo0_l00002ooooo`;o0000
0oooool2o`0000Oooooo0_l000000ooooooo0000o`000004ooooo`Co00002oooool4o`0000_ooooo
0_l00003ooooo`;o00001?ooool2o`0000cooooo0_l00002ooooo`Wo00002_ooool6o`000003oooo
ool0003o000000?o00001Oooool2o`0001;ooooo0_l00002ooooo`;o00000_oooolFo`0000?ooooo
2?l0000<ooooo`?o00000oooool2o`0000Cooooo1?l00011ooooo`007?ooool00ol0003ooooooooo
o`0iooooo`;o000000?oooooo`000?l000000_l00007ooooo`;o00001oooool4o`0001Gooooo0_l0
0003ooooo`;o00000oooool2o`0001Kooooo0_l00002ooooo`;o000000?oooooo`000?l000002Ooo
ool6o`0000Gooooo0_l0000Iooooo`;o000000?oooooo`000?l000000_oooolGo`0000?ooooo1?l0
00001?oooooo0000o`000?l00003ooooo`;o00001oooool3o`0004kooooo000Looooo`;o0000?Ooo
ool2o`000003ooooool0003o000001kooooo0_l00008ooooo`;o00000oooool2o`0000;ooooo0_l0
00000ooooooo0000o`000002o`0000Gooooo0_l0000=ooooo`;o00003_ooool2o`0000;ooooo0_l0
0009ooooo`Co00004oooool2o`000005ooooool0003o0000o`000?ooool06?l00002ooooo`;o0000
1?ooool2o`0000?ooooo0_l0000>ooooo`?o00001_ooool2o`0003oooooo000Looooo`03o`000?oo
oooooooo03oooooo0_l0000Nooooo`;o00002_ooool2o`0000Gooooo0_l000000ooooooo0000o`00
0002o`0000Gooooo0_l0000=ooooo`;o00001?ooool4o`000003ooooool0003o000000?ooooo0_l0
000=ooooo`Co00004oooool2o`0000;ooooo0_l000000ooooooo0000o`00000Co`000003ooooool0
003o000001gooooo0ol00006ooooo`;o00000_ooool2o`0003_ooooo000Looooo`03o`000?oooooo
oooo06_ooooo0_l0000Vooooo`Co000000?oooooo`000?l000000_l000000ooooooo0000o`00000L
ooooo`;o00003OoooolHo`00013ooooo0ol0000Cooooo`;o00000_ooool2o`0003_ooooo000Loooo
o`03o`000?oooooooooo02kooooo0_l0000<ooooo`;o00000_ooool2o`0002Kooooo0_l0000`oooo
o`;o000000?oooooo`000?l000003?ooool2o`0000cooooo1?l00004ooooo`;o00001oooool:o`00
0003ooooool0003o000000Go000000?oooooo`000?l000000_l0000;ooooo`;o00000oooool4o`00
00Sooooo0_l00009ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0;_ooool3o`0000_o
oooo0_l00002ooooo`;o00000_ooool2o`0000cooooo0_l000000ooooooo0000o`000003ooooo`;o
00002Oooool2o`000003ooooool0003o000000Oooooo0_l00009ooooo`?o00004oooool2o`0001Oo
oooo0_l0000:ooooo`Co00001_ooool2o`0000Wooooo4?l000000ooooooo0000o`000002o`0000_o
oooo0_l00002ooooo`?o00002_ooool2o`0004[ooooo000Looooo`03o`000?oooooooooo02oooooo
0_l00007ooooo`;o00002_ooool2o`0000?ooooo0_l00003ooooo`?o000000Coooooo`000?l0003o
oooo0_l00003ooooo`;o00000_ooool2o`0000Gooooo0_l0000:ooooo`;o00002Oooool3o`0000Oo
oooo0_l00006ooooo`;o00000_ooool2o`0000Kooooo0_l0000Kooooo`;o00003_ooool2o`0000Co
oooo3ol000000ooooooo0000o`000003o`0000Sooooo0_l00004ooooo`;o00005?ooool2o`00047o
oooo000Looooo`03o`000?oooooooooo03Sooooo0_l00002ooooo`;o00002oooool2o`0000?ooooo
1Ol0000;ooooo`;o00000_ooool2o`0000Sooooo0ol0000:ooooo`;o000000?oooooo`000?l00000
2?ooool2o`0000Cooooo1?l0000:ooooo`;o00008?ooool2o`0000Cooooo0_l000000ooooooo0000
o`000002o`0000;ooooo5ol00004ooooo`;o00000_ooool2o`0000oooooo0_l00002ooooo`;o0000
1Oooool2o`0000Cooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0booooo`;o00002?oo
ool2o`0000Oooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool3o`0000gooooo1?l0
00000ooooooo0000o`000005ooooo`?o00002_ooool2o`000004ooooool0003o0000ooooo`;o0000
1oooool6o`000003ooooool0003o000002Sooooo0_l000000ooooooo0000o`000002ooooo`Co0000
00?oooooo`000?l000000oooool<o`0000;ooooo2?l00003ooooo`;o000000?oooooo`000?l00000
3oooool3o`000003ooooool0003o000000Co00002oooool2o`0003_ooooo000Looooo`03o`000?oo
oooooooo02kooooo0_l00002ooooo`?o00000oooool2o`0000Kooooo0_l00003ooooo`;o000000?o
ooooo`000?l000000_ooool2o`00017ooooo1Ol000001?oooooo0000o`000?ooool7o`000004oooo
ool0003o0000ooooo`;o00002_ooool2o`0000Oooooo1Ol00002ooooo`;o00003_ooool2o`0000;o
oooo0_l0000Dooooo`;o00001Oooool2o`0000Sooooo4ol00006ooooo`;o00004_ooool4o`0000;o
oooo1?l00009ooooo`;o00000_ooool2o`0003Wooooo000Looooo`03o`000?oooooooooo02Oooooo
0_l00005ooooo`;o00000oooool3o`0000;ooooo0_l00005ooooo`?o00007?ooool3o`000003oooo
ool0003o000000ko000000?oooooo`000?l000001?l0000Dooooo`Co00000_ooool2o`0000[ooooo
0_l00002ooooo`;o00002_ooool2o`0000Sooooo0_l0000Aoooooa3o00005?ooool2o`0000Oooooo
0_l00004ooooo`;o00001?ooool2o`0000?ooooo0_l00002ooooo`;o0000>Oooool001cooooo00?o
0000ooooooooool09oooool2o`0000_ooooo0_l00002ooooo`;o00001?ooool3o`0000Gooooo0_l0
0007ooooo`;o00001Oooool4o`0000Cooooo0ol000000ooooooo0000o`00000=o`000003ooooool0
003o000000Go00005?ooool4o`0000;ooooo0_l00005ooooo`;o00004oooool2o`0000Sooooo0_l0
0007ooooo`;o00000_ooool2o`0000Gooooo3ol00008ooooo`;o00002_ooool2o`0001?ooooo0_l0
0005ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0<_ooool2o`0000Cooooo0_l00004
ooooo`;o00001_ooool2o`0000Oooooo1?l00003ooooo`Co00001?oooolBo`000003ooooool0003o
000000Co000000Coooooo`000?l0003o00002?ooool3o`0000Sooooo0_l00008ooooo`Co00005ooo
ool2o`0000Wooooo0ol000001Ooooooo0000o`000?l0003ooooo00;o00002?ooool:o`0000[ooooo
0_l0000<ooooo`?o00001Oooool4o`0000Kooooo0_l00006ooooo`;o0000>oooool001cooooo00?o
0000ooooooooool0:_ooool2o`0000Kooooo0_l0000Kooooo`Co00000_ooool5o`0000Cooooo5ol0
00000ooooooo0000o`000003o`0000Gooooo0_l000001?oooooo0000o`000?l0000Booooo`Co0000
5oooool2o`0000Oooooo1Ol00002ooooo`;o00001Oooool2o`0000Cooooo0_l000000ooooooo0000
o`000005o`000003ooooool0003o000000Gooooo0_l00002ooooo`?o00002Oooool3o`0000Gooooo
1?l00006ooooo`;o00001_ooool2o`0003_ooooo000Looooo`03o`000?oooooooooo02[ooooo0_l0
0006ooooo`;o00008Oooool6o`000003ooooool0003o000000?o000000?oooooo`000?l000004Ol0
00001?oooooo0000o`000?l00002ooooo`So00005Oooool3o`0000;ooooo0_l000000ooooooo0000
o`000004ooooo`;o000000?oooooo`000?l000000oooool2o`0000Sooooo0_l00002ooooo`;o0000
2?ooool2o`0000;ooooo0_l00002ooooo`So00001Oooool2o`0000;ooooo0_l000000ooooooo0000
o`000002ooooo`?o00004Oooool2o`00013ooooo0_l0000kooooo`007?ooool00ol0003ooooooooo
o`10ooooo`;o00002_ooool3o`0000;ooooo0_l00004ooooob3o00000_ooool7o`000003ooooool0
003o000000;ooooo0_l00003ooooo`;o00004Oooool5o`0000Cooooo0_l000001?oooooo0000o`00
0?ooool4o`0000Kooooo1ol000000ooooooo0000o`000006ooooo`;o00001_ooool2o`000003oooo
ool0003o000000Oo00001Oooool2o`0000Kooooo0_l0000Aooooo`;o00004?ooool2o`0003_ooooo
000Looooo`03o`000?oooooooooo03?ooooo0ol000000ooooooo0000o`000007ooooo`;o00002_oo
ool3o`0000;ooooo0ol00005oooooako00000_ooool2o`0000[ooooo0_l00003ooooo`;o00001_oo
ool2o`0000_ooooo1?l00008ooooo`Co00001Oooool4o`000003ooooool0003o000000;o000000Co
ooooo`000?l0003ooooo0_l0000@ooooo`;o000000?oooooo`000?l000000_l000001?oooooo0000
o`000?l00009ooooo`;o00004_ooool2o`0000?ooooo0_l0000:ooooo`;o0000>oooool001cooooo
0_l0000dooooo`?o000000Coooooo`000?l0003ooooo0_l0000Fooooo`;o00001Oooool5o`0000;o
oooo5Ol000000ooooooo0000o`00000Booooo`;o00001_ooool2o`0000Gooooo0_l00003ooooo`;o
000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000Go00000oooool5o`0000Ko
oooo0_l00002ooooo`;o00000oooool2o`0001?ooooo0ol0000Aooooo`;o000000?oooooo`000?l0
00000_l00005ooooo`;o00000oooool2o`0000Oooooo0_l0000Jooooo`;o00008_ooool001cooooo
00?o0000ooooooooool0>_ooool2o`0001oooooo0_l000000ooooooo0000o`00000Eo`000003oooo
ool0003o000001;ooooo0_l0000=ooooo`;o00000oooool4o`0000?ooooo2?l00002ooooo`;o0000
00?oooooo`000?l000000ol00005ooooo`?o00001oooool4o`0001?ooooo0_l00006ooooo`;o0000
2?ooool2o`000003ooooool0003o000000;o00001Oooool2o`0000?ooooo0_l00004ooooo`;o0000
00?oooooo`000?l000006_ooool2o`0002;ooooo000Looooo`03o`000?oooooooooo03[ooooo0_l0
0002ooooo`;o00001?ooool3o`0001;ooooo7Ol00003ooooo`;o00008?ooool2o`0000?ooooo0_l0
0005ooooo`;o000000?oooooo`000?l000000oooool4o`0000Kooooo0_l000000ooooooo0000o`00
000:ooooo`Co00003Oooool3o`000003ooooool0003o000000Kooooo0_l0000Aooooo`Co000000?o
ooooo`000?l000000_l00005ooooo`;o00000oooool3o`0003_ooooo000Looooo`03o`000?oooooo
oooo03Wooooo0_l00003ooooo`;o00001?ooool3o`00013ooooo7ol00003ooooo`;o00008?ooool2
o`000003ooooool0003o000000Wooooo1Ol00003ooooo`;o00001_ooool2o`000003ooooool0003o
000000cooooo0_l0000=ooooo`?o00004Oooool2o`0000Oooooo1_l000000ooooooo0000o`000002
o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`?o000000?oooooo`000?l00000>?ooool0
01cooooo00?o0000ooooooooool0=Oooool6o`0000?ooooo0_l0000Gooooob7o00000oooool2o`00
00Kooooo0_l0000;ooooo`;o00002Oooool2o`000003ooooool0003o000000;o00001oooool6o`00
00Kooooo0_l0000^ooooo`;o00001_ooool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`00
0?l000000_l000001?oooooo0000o`000?l00003ooooo`;o000000?oooooo`000?l000000_l00004
ooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0=Oooool4o`0000;ooooo0_l0000>oooo
o`;o00002?ooool2o`000003ooooool0003o000001oo00000_ooool2o`0000Cooooo1?l0000;oooo
o`;o00002Oooool2o`0000?ooooo0_l0000:ooooo`Go00000_ooool4o`0000Cooooo0_l0000?oooo
o`;o00001_ooool2o`0000oooooo0_l0000:ooooo`;o00001_ooool4o`0000;ooooo0_l00008oooo
o`;o0000?_ooool001cooooo00?o0000ooooooooool0=Oooool4o`0000;ooooo0_l00002ooooo`;o
00000_ooool4o`0000Cooooo0_l00007ooooo`?o000000?oooooo`000?l000002ol000000ooooooo
0000o`00000Ao`0000Sooooo0_l0000Booooo`;o000000?oooooo`000?l000005Oooool2o`0000;o
oooo0_l00002ooooo`?o000000?oooooo`000?l000002Oooool2o`0000Cooooo0_l00006ooooo`;o
00003?ooool2o`0000_ooooo0_l00003ooooo`;o00001?ooool3o`0000Sooooo0_l00002ooooo`;o
00001oooool2o`000003ooooool0003o000000?ooooo0_l0000]ooooo`007?ooool00ol0003ooooo
ooooo`0eooooo`;o00002?ooool2o`000003ooooool0003o000000?o00001?ooool2o`0000Kooooo
5_l000000ooooooo0000o`00000<o`0000Gooooo1?l00009ooooo`;o00002Oooool2o`000003oooo
ool0003o000001Gooooo0_l00005ooooo`Co000000?oooooo`000?l000002Oooool2o`0001[ooooo
0_l0000;ooooo`;o00000oooool2o`0000Gooooo0_l00008ooooo`;o00000_ooool2o`0000?ooooo
0_l00002ooooo`;o000000?oooooo`000?l000000oooool2o`0002gooooo000Looooo`03o`000?oo
oooooooo03Wooooo0_l00007ooooo`;o00001_ooool3o`0000Kooooo0_l000000ooooooo0000o`00
0007o`000003ooooool0003o000001?o000000Coooooo`000?l0003ooooo0_l00002ooooo`Co0000
2Oooool4o`0000Oooooo0_l0000Oooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo
0_l0000<ooooo`;o00006Oooool2o`0001[ooooo0_l00005ooooo`;o00001oooool2o`00033ooooo
000Looooo`03o`000?oooooooooo03Oooooo1?l0000?ooooo`;o00001_ooool2o`0000;ooooo7_l0
00000ooooooo0000o`000002ooooo`?o000000Coooooo`000?l0003o00003?ooool2o`0001Oooooo
0_l00003ooooo`;o00002oooool2o`0000;ooooo1Ol00002ooooo`;o00003?ooool2o`0001Wooooo
0_l0000Jooooo`;o00003_ooool2o`00033ooooo000Looooo`03o`000?oooooooooo03Oooooo0_l0
000>ooooo`;o00002Oooool2o`0000Cooooo7ol00003ooooo`;o000000Coooooo`000?l0003o0000
2?ooool2o`0001_ooooo0_l00003ooooo`;o00002oooool2o`0000?ooooo1?l0000booooo`;o0000
1oooool2o`0000Wooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00002ooo
ool2o`0000[ooooo0ol00002ooooo`;o00002OoooolPo`0000Oooooo0_l00008ooooo`;o00001Ooo
ool2o`0000Cooooo0_l0000Booooo`;o00002Oooool2o`0000;ooooo0_l00004ooooo`?o00000ooo
ool2o`0000Cooooo0_l00005ooooo`;o00004Oooool2o`0000;ooooo0_l00008ooooo`;o00001ooo
ool3o`000003ooooool0003o000000Gooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0[
ooooo`;o000000?oooooo`000?l000002oooool2o`0000_ooooo0_l00002ooooo`;o00000oooool4
o`0000;ooooo3?l000000ooooooo0000o`000005o`000003ooooool0003o000000Oo00002_ooool2
o`0000kooooo0_l000001?oooooo0000o`000?ooool2o`0001;ooooo0ol00006ooooo`Go000000?o
ooooo`000?l000000_l00002ooooo`?o00000oooool2o`0000?ooooo0ol00004ooooo`?o00002?oo
ool2o`0000Oooooo0_l00002ooooo`;o00002_ooool2o`0000Kooooo0_l000000ooooooo0000o`00
0018ooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o00001_ooool2o`0000Oooooo0_l00005
ooooo`;o00003?ooool4o`0000;ooooo7_l0000:ooooo`;o00001?ooool2o`0000Kooooo0_l00003
ooooo`;o00003?ooool4o`0000Cooooo1?l00006ooooo`Oo000000?oooooo`000?l000003Oooool2
o`0000Gooooo0_l00009ooooo`;o00005oooool2o`0000cooooo0_l00002ooooo`?o0000@?ooool0
01cooooo00?o0000ooooooooool0<oooool2o`0000Gooooo1?l00005ooooo`;o00003?ooool4o`00
00;ooooo7Ol000000ooooooo0000o`000002o`0000cooooo0_l00006ooooo`;o00004Oooool4o`00
00Cooooo0_l0000<ooooo`?o00002oooool2o`0000Oooooo0_l0000Fooooo`;o00005Oooool2o`00
00Cooooo0_l000000ooooooo0000o`000002o`00043ooooo000Looooo`03o`000?oooooooooo03Co
oooo0_l000000ooooooo0000o`000003o`0000[ooooo0_l00005ooooo`;o00000_ooool4o`0000Co
oooo0_l00003oooooaKo000000?oooooo`000?l000000_l0000]ooooo`;o00005_ooool4o`0000;o
oooo0ol000000ooooooo0000o`000003ooooo`;o00000_ooool2o`0001;ooooo0_l0000Eooooo`;o
00000oooool2o`0000;ooooo0_l00012ooooo`007?ooool2o`00033ooooo0_l00003ooooo`;o0000
00?oooooo`000?l000000_l0000;ooooo`;o00001Oooool2o`0000cooooo5Ol00004ooooo`;o0000
1oooool2o`0000Kooooo0_l0000<ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o
00001oooool2o`0000Oooooo0_l000001?oooooo0000o`000?ooool3o`0000Kooooo1_l000001?oo
oooo0000o`000?ooool2o`0000Oooooo0_l00005ooooo`;o00008Oooool2o`0000Cooooo0_l00016
ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00001oooool6o`0000cooooo0_l00006oooo
o`Co00000_ooool2o`000003ooooool0003o0000017o00001?ooool4o`0000Oooooo0_l00006oooo
o`;o00003?ooool2o`0000;ooooo1Ol000000ooooooo0000o`00000>ooooo`Oo000000Goooooo`00
0?l0003o0000ooooo`02o`0000;ooooo3Ol0000;ooooo`;o000000Coooooo`000?l0003ooooo0_l0
000Nooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0<_ooool2o`0000Cooooo1_l0000<
ooooo`;o00001_ooool4o`0000;ooooo1_l000000ooooooo0000o`00000>o`0000?ooooo0_l00005
ooooo`;o00001oooool2o`00013ooooo0_l00003ooooo`;o00004_ooool6o`0000?ooooo0_l00000
0ooooooo0000o`000002ooooo`oo00002Oooool2o`0000Cooooo0_l00004ooooo`;o00006Oooool2
o`0000Oooooo0ol00011ooooo`007?ooool00ol0003oooooooooo`0booooo`;o00001?ooool2o`00
00kooooo0_l00008ooooo`;o00001?ooool5o`0000?ooooo2Ol00002ooooo`Oo00000_ooool2o`00
00?ooooo0_l00007ooooo`Co000000?oooooo`000?l000002oooool2o`0000;ooooo0ol0000Doooo
o`?o00002oooool7o`000003ooooool0003o000000Go00000oooool2o`0000[ooooo0_l00004oooo
o`;o00006Oooool2o`0000;ooooo2?l00011ooooo`007?ooool00ol0003oooooooooo`0hooooo`?o
000000?oooooo`000?l000000_ooool2o`0000Kooooo0_l00002ooooo`;o00001?ooool3o`0000?o
oooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000Go00000oooool3o`000003
ooooool0003o000000;o00000_ooool2o`0000Sooooo0_l00004ooooo`;o000000?oooooo`000?l0
00001?ooool2o`0000Wooooo0ol00003ooooo`;o00003oooool2o`0000[ooooo1Ol000000ooooooo
0000o`00000;o`000003ooooool0003o000000Gooooo0_l00009ooooo`;o00006?ooool3o`0000;o
oooo1Ol00002ooooo`;o00001?ooool2o`0003[ooooo000Looooo`03o`000?oooooooooo03?ooooo
1?l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000[ooooo0ol00004ooooo`?o0000
1_ooool3o`000003ooooool0003o000000Go00000oooool4o`000004ooooool0003o0000o`0000co
oooo0_l00007ooooo`;o00001?ooool2o`0000Wooooo0_l00004ooooo`;o00000oooool4o`0000So
oooo0_l0000:ooooo`Go00000_ooool=o`0000Oooooo0_l00006ooooo`;o00004Oooool4o`0000Ko
oooo1?l00008ooooo`;o00001?ooool2o`0000?ooooo0_l0000eooooo`007?ooool00ol0003ooooo
ooooo`0cooooo`Co00001Oooool2o`0000;ooooo0ol0000:ooooo`;o00000_ooool2o`000003oooo
ool0003o000000Oooooo0_l00002ooooo`Co00001oooool2o`000004ooooool0003o0000o`0001Go
oooo0_l00008ooooo`Co00002Oooool2o`0000;ooooo1Ol00008ooooo`;o00002_oooolEo`0000Go
oooo0_l00007ooooo`;o00002?ooool2o`0000Oooooo1_l00006ooooo`;o00004oooool2o`0003Go
oooo000Looooo`03o`000?oooooooooo03[ooooo0_l00005ooooo`;o00003_ooool2o`000003oooo
ool0003o000000Oooooo1?l00006ooooo`;o00001_ooool2o`0000;ooooo0_l0000>ooooo`Co0000
0oooool2o`0000Gooooo1?l00003ooooo`Co00000_ooool2o`0000;ooooo1ol00006ooooo`;o0000
2_oooolFo`0000;ooooo1_l00005ooooo`Co00001_ooool2o`0000_ooooo0_l00006ooooo`?o0000
BOooool001cooooo00?o0000ooooooooool0>_ooool2o`0000cooooo0_l0000:ooooo`;o00001Ooo
ool2o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000000ooo
ool2o`0000;ooooo0_l0000>ooooo`Co00000oooool2o`0000Gooooo0_l00004ooooo`Go00001_oo
ool2o`0000;ooooo0ol00006ooooo`;o00001Oooool2o`0000?ooooo5ol000000ooooooo0000o`00
0002ooooo`;o00001oooool2o`0000Oooooo0_l0000Cooooo`;o00003Oooool2o`0003[ooooo000L
ooooo`03o`000?oooooooooo037ooooo0_l00004ooooo`;o00001_ooool2o`0000Oooooo0_l00006
ooooo`;o00001?ooool2o`0000?ooooo1?l00003ooooo`Go00000oooool2o`0000?ooooo0_l0000<
ooooo`;o00001?ooool4o`0000Kooooo0_l00002ooooo`;o00001?ooool2o`0000Sooooo0_l00000
0ooooooo0000o`00000>ooooo`Co00000oooool?o`000003ooooool0003o000000Oo00003?ooool2
o`0000Kooooo0ol0000>ooooo`;o00002_ooool4o`0000Cooooo0_l0000jooooo`007?ooool00ol0
003oooooooooo`0aooooo`;o00001?ooool2o`0000Kooooo0_l00003ooooo`;o00001Oooool2o`00
00?ooooo0_l00004ooooo`;o00001Oooool2o`0000Cooooo1?l00005ooooo`Co00003Oooool2o`00
00Cooooo1?l00005ooooo`?o00004?ooool4o`000003ooooool0003o000000kooooo0_l00004oooo
oaKo000000Coooooo`000?l0003o00000_ooool2o`0000Oooooo0ol000000ooooooo0000o`000003
ooooo`;o00001Oooool2o`0000Sooooo0_l00003ooooo`;o00001Oooool4o`00043ooooo000Loooo
o`03o`000?oooooooooo04Cooooo0_l00005ooooo`?o00007_ooool4o`0000Cooooo0_l0000Foooo
o`;o00001_ooool3o`0000Sooooo1?l00009ooooo`;o00001oooool2o`0000;ooooo7ol00006oooo
o`Oo00002_ooool2o`0000Gooooo0_l00006ooooo`;o00001?ooool4o`00047ooooo000Looooo`03
o`000?oooooooooo03cooooo0_l00003ooooo`;o00000oooool2o`000003ooooool0003o000000?o
00002_ooool2o`0001[ooooo0_l0000Nooooo`Co00001?ooool2o`0000?ooooo0_l00009ooooo`;o
00000oooool2o`0000;ooooo0_l00002ooooo`co00000_ooool8o`000003ooooool0003o000000Go
00001oooool6o`0000_ooooo0_l00003ooooo`Co00003?ooool2o`0004?ooooo000Looooo`03o`00
0?oooooooooo03[ooooo1?l00003ooooo`;o00000oooool2o`000003ooooool0003o000000;o0000
2oooool2o`0000kooooo0_l0000Pooooo`;o00002_ooool2o`0000Cooooo0_l0000Aooooo`Co0000
00Coooooo`000?l0003o00001?ooool@o`000003ooooool0003o000000Wo00002Oooool2o`00013o
oooo1_l000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l000003_ooool2o`0003?o
oooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000
oa0@4?o<c<`01_ooool00ol0003oooooooooo`0hooooo`Co00003_ooool2o`0000;ooooo1Ol0000E
ooooo`;o00005Oooool4o`0000Oooooo0_l00004ooooo`;o00007Oooool4o`000003ooooool0003o
000000Gooooo7_l0000Iooooo`;o00001Oooool4o`0000Cooooo0_l000000ooooooo0000o`00000>
ooooo`;o0000<oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go
EEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo03Sooooo0ol00009ooooo`;o0000
0oooool2o`0000?ooooo1Ol00004ooooo`;o00004oooool2o`0000;ooooo0_l0000=ooooo`Co0000
1?ooool2o`0000Oooooo1?l00009ooooo`;o00004Oooool2o`0000Sooooo7ol0000Jooooo`;o0000
1Oooool3o`0004cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo043ooooo0_l00002ooooo`;o0000
0oooool2o`0000cooooo0_l00007ooooo`;o00002?ooool4o`0000;ooooo1?l0000;ooooo`;o0000
0oooool2o`000004ooooool0003o0000ooooo`;o00000oooool2o`000003ooooool0003o000000;o
oooo0_l00003ooooo`Co00001?ooool2o`0000_ooooo0_l00008ooooo`;o000000?oooooo`000?l0
00006_l00007ooooo`?o00001Oooool2o`0000Wooooo0_l000001?oooooo0000o`000?l0000Joooo
o`;o0000=?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003o
V9RHoooooonHV9So8B4Q00Kooooo0ol00010ooooo`;o000000?oooooo`000?l000000_ooool2o`00
00?ooooo0_l0000?ooooo`;o000000?oooooo`000?l000000_ooool3o`0000;ooooo0ol00003oooo
o`Go00002oooool2o`0000?ooooo0_l00004ooooo`;o00000_ooool3o`000003ooooool0003o0000
00Co00000oooool2o`0000;ooooo0ol000000ooooooo0000o`00000:ooooo`;o00002_oooolNo`00
00?ooooo0_l00002ooooo`?o000000?oooooo`000?l000000_ooool2o`0000Kooooo0_l00004oooo
o`Co000000Coooooo`000?l0003o00002Oooool2o`0000[ooooo1?l0000booooo`0000?oooooo`00
0?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool0
0ol0003oooooooooo`0kooooo`;o00001_ooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2
o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o000000?oooooo`000?l000000_ooool3
o`0000;ooooo0_l00004ooooo`Co00001_ooool2o`0001?ooooo0ol00002ooooo`Wo00000oooool3
o`0000gooooo0_l00003ooooo`;o00001?ooool3o`000003ooooool0003o000001[o00000_ooool2
o`0000;ooooo1_l0000:ooooo`;o00000_ooool2o`0000;ooooo0_l000001?oooooo0000o`000?l0
0009ooooo`;o00003?ooool2o`0003;ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooo
oooo00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`0kooooo`;o00004Oooool4
o`000003ooooool0003o000000;ooooo0_l00007ooooo`;o00003?ooool4o`0000Oooooo0_l00000
0ooooooo0000o`000003ooooo`;o00000_ooool2o`0000Gooooo4?l0000;ooooo`;o00002oooool2
o`0000Cooooo0_l000000ooooooo0000o`00000Mo`0000?ooooo0_l000001?oooooo0000o`000?l0
000:ooooo`?o00000_ooool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o00003?oo
ool2o`0003Sooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P0
2?ooool00ol0003oooooooooo`0aooooo`;o00004_ooool2o`0000Oooooo0_l00002ooooo`;o0000
3?ooool2o`0000Kooooo0_l00004ooooo`Co00001oooool5o`0000?ooooo0_l00002ooooo`;o0000
0oooool@o`0000Gooooo0_l00006ooooo`;o00004OoooolOo`000003ooooool0003o000000?ooooo
0ol00004ooooo`Co00001Oooool2o`000003ooooool0003o000000?ooooo0_l000001?oooooo0000
o`000?ooool2o`0000;ooooo0_l0000<ooooo`;o0000>?ooool00006ooooooo^k^ko<S8bo`000?lb
<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo037ooooo0_l00008
ooooo`;o00000_ooool3o`0000?ooooo0_l0000;ooooo`;o00000oooool3o`0000Kooooo0_l00006
ooooo`;o00003?ooool2o`000004ooooool0003o0000o`0000Gooooo0_l00007ooooo`;o000000?o
ooooo`000?l000003ol000000ooooooo0000o`000006ooooo`;o00004Oooool3o`000003ooooool0
003o000001Wo000000?oooooo`000?l000000oooool3o`0000Cooooo1?l00003ooooo`;o00000ooo
ool2o`0000;ooooo0_l00002ooooo`Co0000Boooool001cooooo00?o0000ooooooooool0>oooool2
o`0000;ooooo0ol00005ooooo`;o00002Oooool3o`000003ooooool0003o000000;o00004Oooool2
o`0000Cooooo0_l00003ooooo`;o00004_ooool2o`000003ooooool0003o000000oo00001Oooool2
o`0000;ooooo0_l00003ooooo`Co00003OoooolLo`000003ooooool0003o000000?ooooo0_l00000
0ooooooo0000o`000008ooooo`?o00000_ooool2o`0000?ooooo0_l00003ooooo`?o00000_ooool2
o`0004Oooooo000Looooo`03o`000?oooooooooo03oooooo0_l00006ooooo`;o00002_ooool2o`00
0003ooooool0003o000000Cooooo0_l000000ooooooo0000o`00000:ooooo`;o00001?ooool4o`00
01?ooooo5ol00004ooooo`;o00001_ooool5o`0000cooooo6Ol000000ooooooo0000o`000002o`00
00Oooooo0ol00008ooooo`?o000000Coooooo`000?l0003o00001_ooool5o`0000;ooooo1?l00015
ooooo`007?ooool00ol0003oooooooooo`0jooooo`;o00005oooool2o`0000;ooooo0_l00003oooo
o`;o000000?oooooo`000?l000003_ooool6o`0000gooooo0_l00004ooooo`;o00000_oooolEo`00
00[ooooo0_l0000?oooooako00000_ooool2o`0000?ooooo0_l00006ooooo`;o00000_ooool5o`00
00Oooooo1Ol00004ooooo`;o0000AOooool001cooooo00?o0000ooooooooool0>_ooool2o`0001Go
oooo0_l000001?oooooo0000o`000?ooool2o`0000Kooooo0_l00003ooooo`;o00002Oooool4o`00
00oooooo0_l00004oooooaWo00007?ooool3o`000003ooooool0003o000001Ko00000oooool2o`00
00_ooooo0_l00004ooooo`;o00002_ooool2o`000003ooooool0003o000004Wooooo000Looooo`03
o`000?oooooooooo03[ooooo0_l00007ooooo`;o00003?ooool2o`000003ooooool0003o000000;o
oooo0_l00004ooooo`?o00000oooool2o`0000Cooooo0_l0000?ooooo`;o00002ooooolKo`0000ko
oooo0_l0000=oooooaKo000000?oooooo`000?l000003oooool4o`0000?ooooo0ol000000ooooooo
0000o`000009ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0>_ooool6o`0000?ooooo
0_l00006ooooo`;o00002oooool2o`000004ooooool0003o0000ooooo`;o00002_ooool3o`0000Go
oooo0_l00005ooooo`Go00001?ooool2o`0000Cooooo6ol0000<ooooo`Co00002Oooool2o`0000;o
oooo0ol000000ooooooo0000o`00000@o`0000?ooooo0_l0000=ooooo`Co000000?oooooo`000?l0
00000ol000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000_ooool2o`0001Go
oooo0_l0000booooo`007?ooool00ol0003oooooooooo`0jooooo`Ko00002oooool2o`0000Gooooo
0_l00007ooooo`;o00003_ooool6o`000003ooooool0003o000000Gooooo0_l000001?oooooo0000
o`000?l00003ooooo`;o00001?oooolJo`0000gooooo0_l00007ooooo`;o00000_ooool2o`0000Co
oooo0ol00002ooooo`Oo00000_ooool2o`0000;ooooo0_l00003ooooo`;o00004_ooool2o`0000So
oooo1Ol0000<ooooo`;o00002oooool2o`0003;ooooo000Looooo`03o`000?oooooooooo03Cooooo
0_l00004ooooo`Co00001_ooool2o`0000cooooo0_l0000Gooooo`Ko00003?ooool2o`0000Sooooo
6ol00002ooooo`;o00004_ooool3o`000003ooooool0003o000000Cooooo0ol00003ooooo`Go0000
1Oooool5o`000003ooooool0003o000000Wooooo0ol00003ooooo`;o00003_ooool2o`0000gooooo
0_l0000oooooo`007?ooool00ol0003oooooooooo`0dooooo`;o00003_ooool2o`0000_ooooo0_l0
0003ooooo`;o00001Oooool2o`0002;ooooo0_l00004oooooa_o00000_ooool2o`0000Oooooo0_l0
000:ooooo`;o000000?oooooo`000?l000002oooool2o`000004ooooool0003o0000o`0000?ooooo
1Ol000000ooooooo0000o`000009ooooo`?o000000?oooooo`000?l000000_l0000=ooooo`Co0000
2oooool2o`00043ooooo000Looooo`03o`000?oooooooooo03cooooo0_l0000Cooooo`Co000000?o
ooooo`000?l000001Oooool2o`0002;ooooo0_l00005ooooo`;o000000?oooooo`000?l000005Ol0
000;ooooo`;o00006Oooool3o`000004ooooool0003o0000o`0001Sooooo0_l0000<ooooo`;o0000
00?oooooo`000?l000000_l00008ooooo`;o000000?oooooo`000?l00000@?ooool001cooooo00?o
0000ooooooooool0<Oooool2o`0000Wooooo0_l0000Aooooo`So00002_ooool3o`000003ooooool0
003o000001Wooooo0_l00006ooooo`So000000?oooooo`000?l000003ol00005ooooo`;o000000Co
ooooo`000?l0003ooooo0_l0000Iooooo`;o00005?ooool2o`0000Gooooo0_l0000=ooooo`?o0000
00Coooooo`000?l0003o00002Oooool2o`0000Gooooo0_l0000looooo`007?ooool2o`0003;ooooo
0_l0000:ooooo`;o00001_ooool2o`0000Sooooo0_l00004ooooo`;o00001oooool6o`000003oooo
ool0003o000001Wooooo0_l00006oooooa[o00001Oooool2o`000004ooooool0003o0000ooooo`;o
00001Oooool2o`0000Cooooo0_l00002ooooo`;o00000_ooool2o`0001[ooooo0_l00005ooooo`;o
00003Oooool2o`0000?ooooo0_l0000@ooooo`;o0000??ooool001cooooo00?o0000ooooooooool0
?Oooool2o`0000Cooooo1?l00005ooooo`;o00000oooool2o`0000?ooooo0_l00006ooooo`Go0000
5?ooool2o`00013ooooo6Ol0000>ooooo`;o00000_ooool3o`0000?ooooo0_l00002ooooo`;o0000
00Coooooo`000?l0003o00005?ooool2o`0001cooooo0_l00009ooooo`Co00000oooool2o`0003oo
oooo000Looooo`03o`000?oooooooooo04?ooooo0_l00007ooooo`;o00000oooool2o`0000?ooooo
0_l00008ooooo`?o00001?ooool2o`0000kooooo0_l00008ooooo`;o00001ooooolEo`000004oooo
ool0003o0000o`0000Cooooo0ol000000ooooooo0000o`000003ooooo`;o00000oooool2o`0000Co
oooo0_l00004ooooo`Co00003Oooool2o`0000Cooooo0_l000000ooooooo0000o`00000Iooooo`;o
00002Oooool4o`0000;ooooo0ol0000oooooo`007?ooool00ol0003oooooooooo`14ooooo`Co0000
2oooool2o`0000_ooooo0ol00002ooooo`Go00005oooool2o`0000Cooooo0_l000000ooooooo0000
o`00000Ho`0000?ooooo0ol000000ooooooo0000o`000002ooooo`;o00002_ooool2o`0000Kooooo
0_l0000=ooooo`;o00001oooool2o`0000Wooooo0_l0000Nooooo`?o0000@?ooool001cooooo00?o
0000ooooooooool0?Oooool4o`0000?ooooo1?l00003ooooo`;o00001_ooool2o`000003ooooool0
003o000000Sooooo0ol00002ooooo`;o000000?oooooo`000?l000006Oooool2o`000004ooooool0
003o0000o`0000;ooooo3Ol000000ooooooo0000o`000009o`0000Gooooo0_l00004ooooo`;o0000
2Oooool2o`0000Kooooo0_l0000;ooooo`;o00005Oooool2o`0000;ooooo1?l000000ooooooo0000
o`00000Eooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0?Oooool4o`0000?ooooo0_l0
0004ooooo`?o00002Oooool2o`0000Gooooo0_l000001?oooooo0000o`000?l0000Aooooo`;o0000
3Oooool2o`000004ooooool0003o0000oooooaGo000000Coooooo`000?l0003ooooo0_l00005oooo
o`;o00001?ooool2o`0000?ooooo0_l00004ooooo`;o00001_ooool2o`000003ooooool0003o0000
00Sooooo0_l00008ooooo`;o00003Oooool6o`000003ooooool0003o000000?ooooo0_l0001Coooo
o`007?ooool00ol0003oooooooooo`0mooooo`;o000000?oooooo`000?l000000_ooool4o`0000;o
oooo0_l0000:ooooo`;o00001Oooool2o`0000;ooooo0_l0000Aooooo`;o00001_ooool2o`0000;o
oooo0_l00006oooooaWo000000?oooooo`000?l000004?ooool2o`000003ooooool0003o000000co
oooo0_l000000ooooooo0000o`00000=ooooo`Co00003Oooool2o`0000;ooooo0_l00006ooooo`;o
00003?ooool3o`0004Cooooo000Looooo`03o`000?oooooooooo03kooooo1?l000001?oooooo0000
o`000?ooool2o`0001Gooooo0_l0000Eooooo`;o00001_ooool2o`0000;ooooo0_l00006oooooaSo
00005oooool3o`0000_ooooo0_l000000ooooooo0000o`00000=ooooo`?o00003?ooool5o`0000?o
oooo0_l00003ooooo`;o00001oooool2o`0000Cooooo0ol000000ooooooo0000o`000011ooooo`00
7?ooool00ol0003oooooooooo`0nooooo`;o000000?oooooo`000?l000000_l0000Eooooo`;o0000
00?oooooo`000?l000005?ooool2o`0000Gooooo0_l00002ooooo`;o00000_ooool2o`0000Cooooo
3_l000000ooooooo0000o`000005o`0001?ooooo0_l00005ooooo`;o000000?oooooo`000?l00000
2?ooool2o`0001oooooo0_l000001?oooooo0000o`000?ooool4o`0000?ooooo0_l00007ooooo`;o
00002?ooool2o`00047ooooo000Looooo`03o`000?oooooooooo047ooooo0_l0000Gooooo`;o0000
5oooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o00000_ooool2o`000003oooo
ool0003o000000Oooooo1Ol000000ooooooo0000o`000008o`0000;ooooo0_l00004ooooo`;o0000
00?oooooo`000?l000000oooool5o`0000Sooooo0_l0000Hooooo`;o00004Oooool2o`0000;ooooo
0_l0001Kooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00007oooool4o`0000;ooooo0_l0
000;ooooo`;o00002Oooool2o`0000;ooooo1?l00002ooooo`So000000?oooooo`000?l000002?l0
0002ooooo`;o00001?ooool2o`000003ooooool0003o000000?ooooo1Ol000000ooooooo0000o`00
000Dooooo`;o00002?ooool3o`0000gooooo0_l00002ooooo`;o00000_ooool2o`0005_ooooo000L
ooooo`03o`000?oooooooooo04;ooooo1Ol0000Gooooo`;o000000?oooooo`000?l000001?l00002
ooooo`;o00005_ooool4o`0000;ooooo0_l00002ooooo`Co000000?oooooo`000?l000001_l00004
ooooo`;o00004Oooool2o`0000?ooooo0ol0000Cooooo`;o00001_ooool4o`0000kooooo0_l0000H
ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0@oooool4o`0000;ooooo0_l0000<oooo
o`;o00001Oooool2o`000003ooooool0003o000001Wooooo0_l00005ooooo`;o00001_ooool4o`00
0003ooooool0003o000000Co00001?ooool4o`0000Cooooo0_l000001?oooooo0000o`000?l0000=
ooooo`;o00004oooool4o`0000Cooooo0_l00009ooooo`;o00007oooool2o`0004Wooooo000Loooo
o`03o`000?oooooooooo04Wooooo0ol0000;ooooo`;o00001_ooool2o`0000;ooooo0_l00005oooo
o`;o00004?ooool2o`0001;ooooo0_l00002ooooo`;o00001?ooool4o`0000?ooooo1ol0000<oooo
o`;o00005?ooool4o`0000oooooo0_l0001Zooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o
00004?ooool2o`000005ooooool0003o0000o`000?ooool00_l00005ooooo`;o00000oooool3o`00
0003ooooool0003o000000[ooooo0_l000000ooooooo0000o`000002o`0001_ooooo1?l0000<oooo
o`Go00003_ooool2o`00017ooooo0_l0000Mooooo`;o0000DOooool001cooooo00?o0000oooooooo
ool0@Oooool4o`0000?ooooo0_l0000<ooooo`?o00000oooool2o`0000;ooooo0_l00003ooooo`?o
00000oooool2o`0000;ooooo0ol000000ooooooo0000o`00000:ooooo`;o000000?oooooo`000?l0
00000ol00008ooooo`;o00003oooool2o`0000cooooo0_l000001?oooooo0000o`000?l00008oooo
o`Co00001?ooool2o`000003ooooool0003o000000[ooooo0_l00002ooooo`;o00002?ooool2o`00
00Gooooo0_l0000<ooooo`;o0000DOooool001cooooo0_l00010ooooo`Ko00000oooool2o`0000Go
oooo0_l00005ooooo`?o00003?ooool3o`000003ooooool0003o000000;o00001_ooool2o`0000;o
oooo0_l0000:ooooo`Co00002?ooool2o`0000gooooo1_l0000:ooooo`Co00001_ooool3o`000003
ooooool0003o000000;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00001_ooool2o`0000co
oooo0_l00005ooooo`;o00004?ooool2o`0004gooooo000Looooo`03o`000?oooooooooo03oooooo
0_l00002ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000002ooooo`?o0000
5oooool3o`000003ooooool0003o000000;o00000_ooool2o`0000;ooooo0_l0000;ooooo`Co0000
3?ooool2o`0000Sooooo0_l00002ooooo`;o00003?ooool3o`0000Gooooo0ol000000ooooooo0000
o`000004ooooo`;o00001_ooool3o`0000Wooooo0_l0000@ooooo`;o00003_ooool4o`0004gooooo
000Looooo`03o`000?oooooooooo04;ooooo0ol000000ooooooo0000o`000002o`000003ooooool0
003o000000?ooooo0_l0000;ooooo`;o00000oooool4o`0000Oooooo1?l00003ooooo`;o00001ooo
ool4o`0000;ooooo0_l000001?oooooo0000o`000?l0000;ooooo`;o00000oooool2o`0001Kooooo
0_l000000ooooooo0000o`00000;ooooo`;o00001oooool2o`0000[ooooo0_l00009ooooo`?o0000
5?ooool2o`0004oooooo000Looooo`03o`000?oooooooooo04;ooooo0_l0000Iooooo`;o000000?o
ooooo`000?l000001?l0000>ooooo`;o00001oooool9o`000003ooooool0003o000000;o000000?o
ooooo`000?l000002oooool2o`0001Wooooo0_l00006ooooo`;o00000oooool2o`0000Kooooo1_l0
000Booooo`?o00000_ooool4o`0000Kooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`12
ooooo`;o00003_ooool2o`0000cooooo0ol00007ooooo`;o00004oooool4o`000003ooooool0003o
000000;ooooo0ol000001?oooooo0000o`000?l0000:ooooo`;o00000_ooool2o`0001[ooooo0_l0
00000ooooooo0000o`00000;ooooo`Ko00001_ooool2o`000003ooooool0003o000000Oooooo0_l0
0003ooooo`Co000000?oooooo`000?l000000oooool2o`0000Gooooo0_l0001@ooooo`007?ooool0
0ol0003oooooooooo`13ooooo`;o00000oooool3o`0000Oooooo0_l0000=ooooo`Co00001Oooool2
o`0000Cooooo0_l0000Booooo`;o00000_ooool2o`0000?ooooo0_l00006ooooo`?o00001Oooool2
o`0000Gooooo0_l0000Cooooo`;o00000_ooool2o`0000cooooo0_l000000ooooooo0000o`000005
ooooo`;o000000?oooooo`000?l000001Oooool4o`0000Sooooo0_l0000:ooooo`;o0000D?ooool0
01cooooo00?o0000ooooooooool0@oooool2o`0000?ooooo0ol0000Fooooo`Co00002oooool2o`00
0003ooooool0003o000000_ooooo0_l0000Cooooo`?o00001Oooool2o`0000Gooooo0_l0000Goooo
o`?o00003?ooool4o`0000Kooooo0_l00007ooooo`Co00005?ooool2o`00053ooooo000Looooo`03
o`000?oooooooooo05oooooo1?l0000;ooooo`;o00000oooool2o`000003ooooool0003o000000So
oooo0_l00009ooooo`;o00003_ooool4o`0001gooooo1?l00009ooooo`;o000000?oooooo`000?l0
00000_l00006ooooo`;o00001Oooool2o`0000;ooooo0_l00002ooooo`;o00004?ooool2o`00053o
oooo000Looooo`03o`000?oooooooooo04?ooooo0_l000000ooooooo0000o`000008ooooo`;o0000
3?ooool4o`0000Oooooo0_l000000ooooooo0000o`000002o`0000Kooooo0_l00006ooooo`;o0000
2oooool2o`0000kooooo0_l0000Oooooo`;o00001?ooool2o`0000Gooooo0_l00004ooooo`;o0000
1Oooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`?o000000?oooooo`000?l00000
H_ooool001cooooo00?o0000ooooooooool0@_ooool3o`000003ooooool0003o000000Sooooo0_l0
000<ooooo`Co00001_ooool3o`000003ooooool0003o000000Sooooo0_l00006ooooo`;o00002ooo
ool4o`0000cooooo0_l00004ooooo`;o00000oooool2o`0001[ooooo0_l00007ooooo`Ko00002?oo
ool2o`0000Oooooo0_l00005ooooo`;o0000G_ooool001cooooo00?o0000ooooooooool0@_ooool2
o`0000Gooooo0_l00008ooooo`;o00002oooool2o`0000Kooooo0_l0000;ooooo`?o00003_ooool2
o`0000?ooooo1?l00002ooooo`;o00002oooool:o`0000_ooooo0_l0000<ooooo`;o00000_ooool3
o`0000?ooooo1?l0000;ooooo`;o00001?ooool2o`0000Oooooo0_l0001Nooooo`007?ooool00ol0
003oooooooooo`19ooooo`;o00002?ooool3o`0000_ooooo0_l0000@ooooo`Co00003oooool2o`00
00;ooooo0_l00005ooooo`;o00000oooool2o`0000Kooooo2?l0000;ooooo`Co00003?ooool2o`00
00;ooooo0ol0000Booooo`?o00000oooool2o`0000gooooo0_l000000ooooooo0000o`00001Eoooo
o`007?ooool00ol0003oooooooooo`1Dooooo`Co00002Oooool2o`0000oooooo1Ol00005ooooo`;o
00002?ooool2o`0000;ooooo0_l00008ooooo`Co00002?ooool5o`000003ooooool0003o000000Wo
oooo0_l0000Wooooo`Go00004?ooool2o`000003ooooool0003o000005Gooooo000Looooo`03o`00
0?oooooooooo053ooooo0_l00003ooooo`?o000000?oooooo`000?l000005oooool2o`000003oooo
ool0003o000000Gooooo0_l0000Booooo`;o00000_ooool5o`0000;ooooo0ol00002ooooo`;o0000
00Coooooo`000?l0003ooooo0_l00003ooooo`;o00000_ooool4o`0001Oooooo0_l0000Aooooo`;o
00003_ooool2o`0005[ooooo000Looooo`03o`000?oooooooooo04kooooo1?l00007ooooo`;o0000
0_ooool2o`0001Oooooo0_l0000Dooooo`;o00000_ooool2o`0000Gooooo2?l000000ooooooo0000
o`000002ooooo`;o00000oooool4o`0000;ooooo1?l0000Fooooo`?o00002oooool2o`000003oooo
ool0003o0000017ooooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`1>ooooo`?o00001?oo
ool2o`0000Kooooo0_l00004ooooo`;o00000oooool4o`0000Oooooo0_l000000ooooooo0000o`00
000;ooooo`;o00001Oooool8o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000001Ol0
00000ooooooo0000o`000003ooooo`;o00001oooool2o`0000?ooooo0_l00006ooooo`;o00001?oo
ool2o`0000;ooooo0ol00009ooooo`Co000000?oooooo`000?l00000KOooool001cooooo0_l0001@
ooooo`?o00000oooool2o`0000Gooooo0_l00005ooooo`;o00000oooool4o`0000Oooooo0_l0000>
ooooo`;o00001Oooool2o`0000;ooooo1?l00002ooooo`;o00001oooool6o`0000_ooooo0_l00002
ooooo`;o00000oooool2o`0000Kooooo0_l00004ooooo`Ko00002_ooool2o`0007;ooooo000Loooo
o`03o`000?oooooooooo053ooooo0_l00004ooooo`;o00001?ooool2o`000003ooooool0003o0000
00[ooooo0_l00004ooooo`;o00005oooool2o`000003ooooool0003o0000017ooooo1ol00004oooo
o`Go00002Oooool2o`0000Cooooo0_l00004ooooo`Co00007oooool2o`0005oooooo000Looooo`03
o`000?oooooooooo05Kooooo0_l00004ooooo`;o000000?oooooo`000?l000000_l000000ooooooo
0000o`000005ooooo`;o00001?ooool2o`0001Kooooo0_l00002ooooo`;o00003?ooool2o`0000?o
oooo4?l00009ooooo`;o00000_ooool4o`0000Cooooo1?l000000ooooooo0000o`000002ooooo`;o
00000oooool2o`0000?ooooo0_l0000>ooooo`;o0000Goooool001cooooo00?o0000ooooooooool0
HOooool2o`000004ooooool0003o0000ooooo`;o00002_ooool2o`0000gooooo0_l00005ooooo`;o
00004?ooool2o`0000Gooooo0ol00002ooooo`So00002_ooool2o`0000;ooooo0_l0000;ooooo`;o
00000_ooool2o`0000?ooooo0_l00002ooooo`?o0000Koooool001cooooo00?o0000ooooooooool0
H?ooool3o`0000Cooooo0_l000000ooooooo0000o`000002o`0000Gooooo0_l00006ooooo`;o0000
1Oooool2o`0001Oooooo0_l00006ooooo`;o00001?ooool7o`0000Wooooo0_l00003ooooo`;o0000
00?oooooo`000?l000000_ooool3o`0000Wooooo0_l00004ooooo`;o00006oooool2o`0005?ooooo
000Looooo`03o`000?oooooooooo05Sooooo0_l00006ooooo`Co00001_ooool4o`0000gooooo0_l0
00000ooooooo0000o`000006ooooo`Go00003Oooool2o`000004ooooool0003o0000o`0000Wooooo
1_l000001?oooooo0000o`000?l0000=ooooo`;o000000Coooooo`000?l0003ooooo1?l00007oooo
o`Co00008Oooool2o`0005?ooooo000Looooo`03o`000?oooooooooo05Sooooo0_l00008ooooo`;o
00004?ooool2o`0000Sooooo0_l00003ooooo`;o000000?oooooo`000?l000000ol0000=ooooo`;o
00000_ooool2o`0000Oooooo1?l000001?oooooo0000o`000?ooool4o`0001?ooooo1?l00007oooo
o`;o00002?ooool2o`0006kooooo000Looooo`03o`000?oooooooooo07Cooooo0_l0000=ooooo`?o
00000oooool2o`0000kooooo0_l0000:ooooo`;o00001_ooool4o`0000Sooooo0_l000000ooooooo
0000o`000008ooooo`;o00004Oooool2o`0006kooooo000Looooo`03o`000?oooooooooo05oooooo
0_l00006ooooo`Co00003?ooool2o`0000_ooooo0_l00009ooooo`;o00002?ooool2o`0000cooooo
0_l00005ooooo`?o000000Coooooo`000?l0003o00001?ooool2o`000003ooooool0003o000008_o
oooo000Looooo`03o`000?oooooooooo05oooooo0_l00006ooooo`Co00002_ooool4o`0000?ooooo
0ol00008ooooo`;o00001_ooool2o`0001Kooooo0_l00002ooooo`Ko000000Coooooo`000?l0003o
00003oooool2o`0001Cooooo0_l000000ooooooo0000o`00000>ooooo`;o0000F_ooool001cooooo
00?o0000ooooooooool0H?ooool2o`0000;ooooo0_l00005ooooo`Co00001_ooool2o`0000Gooooo
0ol00008ooooo`;o000000?oooooo`000?l000004_ooool2o`0000Oooooo0_l00002ooooo`Ko0000
3oooool3o`000003ooooool0003o000000Kooooo0_l0000<ooooo`;o000000?oooooo`000?l00000
3_ooool2o`0005[ooooo000Looooo`03o`000?oooooooooo063ooooo0_l00002ooooo`;o00001Ooo
ool4o`0000Sooooo0_l00008ooooo`;o00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`00
0004ooooo`;o00002Oooool5o`0000Cooooo0_l0000>ooooo`;o00001oooool6o`0000Kooooo0_l0
000Cooooo`;o0000I_ooool001cooooo00?o0000ooooooooool0E?ooool2o`0001Kooooo0_l00009
ooooo`;o00002?ooool2o`0000;ooooo0_l00006ooooo`?o00000oooool2o`0000;ooooo0_l00007
ooooo`?o00002_ooool2o`0000Cooooo0_l00002ooooo`;o00002Oooool2o`0001Gooooo0_l00002
ooooo`;o00000_ooool2o`0006Kooooo000Looooo`03o`000?oooooooooo05Cooooo0_l0000Foooo
o`;o00007oooool3o`0000Gooooo1Ol0000<ooooo`;o00001Oooool2o`0000Cooooo0_l000000ooo
oooo0000o`00000>ooooo`Co000000?oooooo`000?l000003?ooool2o`0000;ooooo0_l00008oooo
o`;o0000H?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<
ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo06[ooooo0_l00002ooooo`;o00001ooo
ool2o`0000oooooo0_l00004ooooo`;o00001Oooool2o`000003ooooool0003o000000Cooooo0_l0
00000ooooooo0000o`000003ooooo`;o00002oooool2o`000003ooooool0003o000000kooooo1?l0
00000ooooooo0000o`000003ooooo`;o00005Oooool2o`00063ooooo00001_ooooooMgMgoiRHV?oo
ooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003o
ooooooooo`1Zooooo`;o00000_ooool2o`0000Gooooo1?l000000ooooooo0000o`00000<ooooo`;o
00001?ooool2o`0000Oooooo0_l00005ooooo`;o000000?oooooo`000?l000003oooool4o`0000?o
oooo0_l00005ooooo`;o00003_ooool2o`0007Oooooo00000ooooooo410@ooooo`02ooooo`03oa0@
4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo07Go
oooo0_l00003ooooo`;o00006oooool2o`0000Cooooo0_l0000=ooooo`;o00001?ooool4o`0000?o
oooo0_l00005ooooo`;o0000Qoooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
2Oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0001Xooooo`;o00006?ooool2o`0001?o
oooo0_l00004ooooo`?o000000?oooooo`000?l000002Oooool2o`0000Sooooo0_l00002ooooo`;o
0000SOooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Oo<c<co0000
o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0J?ooool2o`0001Sooooo0_l000000ooooooo
0000o`00000:ooooo`;o00001?ooool2o`0000Gooooo0_l000001?oooooo0000o`000?l0000Boooo
o`;o00000_ooool2o`0008gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wo
oooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo07_ooooo0_l00008oooo
o`;o00002_ooool2o`0000_ooooo0_l00002ooooo`;o00002_ooool2o`0000oooooo0_l00028oooo
o`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l000001_oo
ool00ol0003oooooooooo`1kooooo`?o00003_ooool2o`00013ooooo1?l0000<ooooo`;o00003?oo
ool2o`000003ooooool0003o000000Sooooo0_l0001nooooo`0000Koooooonk^k_lb<S;o0000oc8b
<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`1looooo`;o
00003_ooool2o`0001;ooooo0_l0000Hooooo`Co000000?oooooo`000?l000000oooool2o`0000?o
oooo0_l00002ooooo`;o0000N_ooool001cooooo00?o0000ooooooooool0Moooool2o`0000;ooooo
0_l00007ooooo`;o00001_ooool2o`0000Kooooo0_l00005ooooo`;o00004Oooool2o`0000[ooooo
1?l000000ooooooo0000o`000003ooooo`;o00001oooool2o`0007[ooooo000Looooo`03o`000?oo
oooooooo07Oooooo0_l000001?oooooo0000o`000?l00007ooooo`;o00001_ooool2o`0000;ooooo
0_l00002ooooo`;o00001Oooool2o`0000cooooo0_l00003ooooo`;o00003?ooool2o`000003oooo
ool0003o000008Sooooo000Looooo`03o`000?oooooooooo07Wooooo1Ol00005ooooo`;o000000Co
ooooo`000?l0003o00000oooool2o`0000;ooooo0_l0000Aooooo`?o00000oooool2o`0001Cooooo
1?l00026ooooo`007?ooool00ol0003oooooooooo`1iooooo`Go00001Oooool2o`000004ooooool0
003o0000o`0000?ooooo0_l00005ooooo`;o00001oooool3o`0000Cooooo1Ol00002ooooo`?o0000
4_ooool4o`0008Kooooo000Looooo`03o`000?oooooooooo05[ooooo0_l0000Zooooo`Co000000?o
ooooo`000?l000001_ooool2o`0000Oooooo0ol00003ooooo`;o000000Coooooo`000?l0003o0000
0_ooool3o`0000?ooooo0_l0002Gooooo`007?ooool00ol0003oooooooooo`1Jooooo`;o00009?oo
ool2o`0000Gooooo0ol000000ooooooo0000o`000006ooooo`;o00003Oooool2o`000003ooooool0
003o000000;ooooo0_l00005ooooo`;o0000Uoooool001cooooo00?o0000ooooooooool0P?ooool2
o`0000Gooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Fooooo`;o00001Ooo
ool2o`0000Gooooo0_l000000ooooooo0000o`000002ooooo`;o0000ROooool001cooooo00?o0000
ooooooooool0Roooool5o`000003ooooool0003o000000Oooooo0_l00005ooooo`;o00005?ooool2
o`000003ooooool0003o000000;ooooo0_l00029ooooo`007?ooool00ol0003oooooooooo`24oooo
o`;o00001oooool2o`0000;ooooo0_l00007ooooo`;o00001Oooool2o`00037ooooo0_l0001coooo
o`007?ooool00ol0003oooooooooo`24ooooo`;o0000C_ooool2o`0007?ooooo000Looooo`03o`00
0?oooooooooo093ooooo0_l0002gooooo`007?ooool2o`00097ooooo0_l0000oooooo`;o0000M_oo
ool001cooooo00?o0000ooooooooool0boooool2o`0000Cooooo0_l0001fooooo`007?ooool00ol0
003oooooooooo`2]ooooo`;o00007?ooool2o`0007cooooo000Looooo`03o`000?oooooooooo0:go
oooo0_l0002Jooooo`007?ooool00ol0003oooooooooo`30ooooo`Co0000QOooool001cooooo00?o
0000ooooooooool0[_ooool2o`0000Oooooo0_l00007ooooo`Co0000QOooool001cooooo00?o0000
ooooooooool0[_ooool2o`0000Oooooo0_l0002@ooooo`007?ooool00ol0003oooooooooo`2joooo
o`;o0000SOooool001cooooo00?o0000ooooooooool0Ooooool2o`0003Wooooo0_l0002=ooooo`00
7?ooool00ol0003oooooooooo`1oooooo`;o0000b?ooool001cooooo00?o0000ooooooooool0]ooo
ool2o`00093ooooo000Looooo`03o`000?oooooooooo0;Oooooo0_l0002@ooooo`007?ooool00ol0
003oooooooooo`1hooooo`;o0000??ooool2o`00097ooooo000Looooo`03o`000?oooooooooo07So
oooo0_l0000looooo`;o0000TOooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`2booooo`;o0000UOooool001cooooo0_l0002cooooo`;o000000?ooooo
o`000?l00000T_ooool001cooooo00?o0000ooooooooool0]Oooool2o`0009;ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Yooooo`;o
0000W_ooool001cooooo00?o0000ooooooooool0TOooool2o`0000kooooo0_l00006ooooo`;o0000
W_ooool001cooooo00?o0000ooooooooool0TOooool2o`0000kooooo0_l0002Vooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo
00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000D
ooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBoooo
o`004_ooool00omEEEGoIVIVo`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo002Qooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05_ooool4
o`000004oa0@4?ooooooooooooooo`Co000000Co410@oooooooooooooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?l@413oc<c<S?ooool00:;ooooo00Go0000ooooooooooooooooo`000009
ooooo`Ko00003?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool01OmEEEGoMgMgoooooonHV9So8B4Q08cooooo002Rooooo`05o`000?oooooo
ooooooooool000006oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000008cooooo002Rooooo`05o`000?oo
ooooooooooooool000002Oooool6o`0000cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00;ooooo00Go0000oiRHV?ooooooV9RHob4Q8@2<ooooo`00
X_ooool01Ol0003oQhN7oooooonYZJWo000001_ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Go0000oeEEEOl0003o410@olc<c02<oooo
o`00XOooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo01Wooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?oEEEEohN7Qooo
ool0S_ooool00<;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00;ooooo00?ogMgMoa0@4?nHV9P0S_ooool00<3ooooo00?oEEEEofIVI_l000001Ooo
ool00omEEEGoIVIVo`000005ooooo`03oeEEEOmVIVKo000000Gooooo00Coc<c<odA4A?l0003o410@
S?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1122) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.33245 .45512 Mdot
.33736 .48491 Mdot
.62354 .64245 Mdot
.51084 .39136 Mdot
.25605 .67224 Mdot
.60464 .60643 Mdot
.42456 .62006 Mdot
.47017 .64535 Mdot
.61878 .63219 Mdot
.27511 .56844 Mdot
.42949 .62184 Mdot
.446 .42153 Mdot
.44021 .62731 Mdot
.49435 .37796 Mdot
.15411 .55025 Mdot
.4915 .42464 Mdot
.30132 .51906 Mdot
.66883 .44516 Mdot
.5716 .39084 Mdot
.57871 .59196 Mdot
.27713 .48976 Mdot
.50496 .38087 Mdot
.36548 .47663 Mdot
.49399 .37723 Mdot
.52175 .40339 Mdot
.30291 .48945 Mdot
.30887 .53425 Mdot
.54748 .36482 Mdot
.52009 .4141 Mdot
.47126 .63648 Mdot
.64922 .34093 Mdot
.17709 .60908 Mdot
.56889 .34363 Mdot
.53369 .80414 Mdot
.46425 .65211 Mdot
.33276 .41009 Mdot
.61907 .60236 Mdot
.45625 .64607 Mdot
.4542 .65565 Mdot
.41979 .61518 Mdot
.44183 .64717 Mdot
.31294 .48296 Mdot
.4589 .58389 Mdot
.47816 .57335 Mdot
.52001 .42499 Mdot
.30155 .67321 Mdot
.50621 .21683 Mdot
.51911 .3325 Mdot
.29565 .51015 Mdot
.68699 .62704 Mdot
.44417 .75581 Mdot
.41695 .62864 Mdot
.62932 .58152 Mdot
.63588 .86313 Mdot
.46234 .63845 Mdot
.54084 .42088 Mdot
.62978 .62024 Mdot
.50628 .37048 Mdot
.49346 .37197 Mdot
.26785 .34641 Mdot
.5512 .34293 Mdot
.66422 .46676 Mdot
.36164 .45699 Mdot
.57411 .47472 Mdot
.62162 .62238 Mdot
.44045 .65387 Mdot
.33948 .47356 Mdot
.44752 .62665 Mdot
.45659 .3225 Mdot
.59139 .56922 Mdot
.52175 .33402 Mdot
.43159 .64311 Mdot
.28699 .48631 Mdot
.529 .35018 Mdot
.72888 .65472 Mdot
.19773 .35475 Mdot
.65148 .51818 Mdot
.29545 .38061 Mdot
.25246 .38272 Mdot
.72588 .56174 Mdot
.48156 .39345 Mdot
.68086 .28394 Mdot
.17861 .44739 Mdot
.36525 .49483 Mdot
.56962 .324 Mdot
.60146 .53736 Mdot
.52531 .35384 Mdot
.24268 .59672 Mdot
.50693 .42002 Mdot
.74206 .67708 Mdot
.60966 .62937 Mdot
.32854 .5037 Mdot
.50865 .39259 Mdot
.55233 .36774 Mdot
.51123 .23176 Mdot
.49127 .3173 Mdot
.53759 .37506 Mdot
.29754 .47142 Mdot
.41915 .6421 Mdot
.4789 .43591 Mdot
.43634 .58037 Mdot
.64569 .62586 Mdot
.48612 .32978 Mdot
.605 .57639 Mdot
.28273 .48985 Mdot
.53643 .34778 Mdot
.44636 .66205 Mdot
.48432 .33831 Mdot
.38148 .67068 Mdot
.341 .4838 Mdot
.55079 .37472 Mdot
.65674 .46339 Mdot
.813 .44209 Mdot
.33524 .50675 Mdot
.75241 .53582 Mdot
.48118 .39967 Mdot
.52768 .37284 Mdot
.33445 .48592 Mdot
.64146 .6392 Mdot
.22984 .56864 Mdot
.37378 .48408 Mdot
.41332 .62301 Mdot
.37 .4661 Mdot
.54862 .30208 Mdot
.60976 .62214 Mdot
.50744 .76147 Mdot
.4559 .70118 Mdot
.64584 .31187 Mdot
.52058 .35669 Mdot
.32382 .61043 Mdot
.58234 .61087 Mdot
.3222 .4955 Mdot
.44949 .62298 Mdot
.56412 .42296 Mdot
.35589 .48767 Mdot
.45286 .61208 Mdot
.6679 .45487 Mdot
.54672 .7238 Mdot
.32433 .5232 Mdot
.4469 .56724 Mdot
.46972 .66318 Mdot
.41932 .6195 Mdot
.59276 .80332 Mdot
.33272 .47616 Mdot
.6739 .48715 Mdot
.46155 .62594 Mdot
.62782 .33737 Mdot
.55402 .39987 Mdot
.70582 .34394 Mdot
.60795 .19583 Mdot
.5517 .80494 Mdot
.60169 .71735 Mdot
.68967 .49257 Mdot
.41262 .65079 Mdot
.53752 .39616 Mdot
.29721 .48841 Mdot
.31273 .47773 Mdot
.53972 .333 Mdot
.51567 .39735 Mdot
.5281 .33812 Mdot
.55307 .37774 Mdot
.24364 .35027 Mdot
.46989 .34823 Mdot
.56436 .20585 Mdot
.32807 .5084 Mdot
.52903 .39048 Mdot
.63435 .61055 Mdot
.53014 .30427 Mdot
.43853 .64807 Mdot
.51117 .37707 Mdot
.51442 .39123 Mdot
.55295 .34275 Mdot
.41652 .63093 Mdot
.17775 .56377 Mdot
.67441 .24294 Mdot
.20894 .63338 Mdot
.75688 .6185 Mdot
.59157 .59392 Mdot
.52752 .36026 Mdot
.6563 .47899 Mdot
.3628 .3877 Mdot
.47862 .3827 Mdot
.85809 .40515 Mdot
.52804 .38045 Mdot
.22384 .63759 Mdot
.48411 .28219 Mdot
.22211 .6807 Mdot
.68728 .30892 Mdot
.54314 .39474 Mdot
.59771 .33589 Mdot
.40328 .44851 Mdot
.48913 .58769 Mdot
.44127 .64444 Mdot
.63665 .61852 Mdot
.63029 .63473 Mdot
.40162 .65486 Mdot
.25532 .5168 Mdot
.58481 .33088 Mdot
.46904 .32211 Mdot
.60582 .56167 Mdot
.33482 .44889 Mdot
.69438 .47537 Mdot
.31656 .4633 Mdot
.24233 .25674 Mdot
.42959 .73619 Mdot
.4003 .63419 Mdot
.64011 .48996 Mdot
.60183 .63718 Mdot
.6406 .60903 Mdot
.65437 .4897 Mdot
.49766 .33926 Mdot
.33334 .47277 Mdot
.50227 .82259 Mdot
.26926 .53466 Mdot
.56275 .82535 Mdot
.29311 .48162 Mdot
.33135 .57387 Mdot
.44661 .61391 Mdot
.61027 .59087 Mdot
.5314 .37291 Mdot
.50093 .34638 Mdot
.27517 .50909 Mdot
.52448 .33776 Mdot
.49449 .25559 Mdot
.54098 .36632 Mdot
.47582 .75553 Mdot
.65467 .52093 Mdot
.40153 .65368 Mdot
.6372 .29455 Mdot
.35288 .46574 Mdot
.75695 .44174 Mdot
.61558 .57642 Mdot
.34264 .38997 Mdot
.42842 .64144 Mdot
.66608 .45889 Mdot
.61286 .57201 Mdot
.69558 .47505 Mdot
.56005 .33377 Mdot
.60925 .65254 Mdot
.64879 .47644 Mdot
.23402 .43815 Mdot
.55126 .39729 Mdot
.24063 .34705 Mdot
.41695 .65105 Mdot
.37279 .49061 Mdot
.55134 .34494 Mdot
.59779 .58382 Mdot
.56941 .34009 Mdot
.59445 .69786 Mdot
.50495 .76112 Mdot
.64182 .65289 Mdot
.67886 .65843 Mdot
.67592 .46214 Mdot
.54 .67967 Mdot
.34195 .59515 Mdot
.29094 .50553 Mdot
.47227 .33876 Mdot
.20723 .67991 Mdot
.46118 .62594 Mdot
.4851 .34279 Mdot
.5256 .78197 Mdot
.4595 .63034 Mdot
.50665 .36839 Mdot
.44569 .67038 Mdot
.31483 .47601 Mdot
.77376 .38803 Mdot
.29909 .51706 Mdot
.49918 .41633 Mdot
.44091 .66369 Mdot
.63165 .65143 Mdot
.30028 .49639 Mdot
.49826 .33318 Mdot
.54071 .35732 Mdot
.53356 .5121 Mdot
.53613 .38724 Mdot
.19239 .5872 Mdot
.54649 .37563 Mdot
.63479 .62219 Mdot
.50821 .31584 Mdot
.83356 .5904 Mdot
.46839 .7027 Mdot
.33822 .47319 Mdot
.62814 .65765 Mdot
.62303 .63354 Mdot
.75204 .50154 Mdot
.52594 .6386 Mdot
.47381 .38944 Mdot
.59314 .58896 Mdot
.74859 .40238 Mdot
.46548 .61493 Mdot
.47406 .33231 Mdot
.45803 .56238 Mdot
.68825 .6193 Mdot
.61596 .56761 Mdot
.5572 .42277 Mdot
.28829 .51724 Mdot
.50939 .39359 Mdot
.6397 .61142 Mdot
.28612 .4639 Mdot
.47897 .40356 Mdot
.38979 .52732 Mdot
.53192 .51179 Mdot
.44336 .60779 Mdot
.5067 .27357 Mdot
.49275 .33039 Mdot
.61347 .58687 Mdot
.33907 .4645 Mdot
.47635 .62923 Mdot
.30803 .49151 Mdot
.35009 .76839 Mdot
.38313 .66636 Mdot
.23016 .40696 Mdot
.68212 .43943 Mdot
.65956 .71282 Mdot
.25405 .71533 Mdot
.80065 .57179 Mdot
.71842 .41426 Mdot
.41399 .81364 Mdot
.63731 .61132 Mdot
.54982 .78174 Mdot
.62713 .63284 Mdot
.50448 .40613 Mdot
.61298 .6198 Mdot
.24736 .71243 Mdot
.54111 .36816 Mdot
.61402 .61293 Mdot
.76953 .4406 Mdot
.52148 .39256 Mdot
.34082 .5059 Mdot
.1678 .51017 Mdot
.8135 .57079 Mdot
.49017 .77787 Mdot
.58856 .63788 Mdot
.67472 .41173 Mdot
.54013 .37616 Mdot
.51956 .31432 Mdot
.30243 .51238 Mdot
.47607 .3259 Mdot
.69348 .48072 Mdot
.63953 .48675 Mdot
.44245 .46959 Mdot
.70008 .28207 Mdot
.44217 .38102 Mdot
.29941 .50036 Mdot
.2998 .28361 Mdot
.71837 .66449 Mdot
.6842 .67198 Mdot
.42605 .67017 Mdot
.18182 .52901 Mdot
.44465 .29359 Mdot
.39209 .60802 Mdot
.4964 .58277 Mdot
.33731 .4976 Mdot
.18198 .58379 Mdot
.44502 .64383 Mdot
.42268 .24058 Mdot
.61592 .3907 Mdot
.49579 .3435 Mdot
.42457 .63521 Mdot
.43754 .38679 Mdot
.81032 .60753 Mdot
.45472 .19806 Mdot
.60901 .2335 Mdot
.48883 .41389 Mdot
.73854 .64454 Mdot
.51859 .37675 Mdot
.22283 .55293 Mdot
.54735 .37315 Mdot
.3075 .49866 Mdot
.24476 .55745 Mdot
.49393 .49125 Mdot
.63946 .2238 Mdot
.4171 .72718 Mdot
.69012 .49204 Mdot
.53519 .36723 Mdot
.49444 .34438 Mdot
.68901 .47264 Mdot
.35129 .50785 Mdot
.55329 .37886 Mdot
.74896 .43997 Mdot
.5216 .34621 Mdot
.44887 .64983 Mdot
.58956 .23618 Mdot
.33414 .53813 Mdot
.45647 .34176 Mdot
.31539 .45305 Mdot
.44563 .60651 Mdot
.45983 .65287 Mdot
.48779 .42722 Mdot
.43269 .59981 Mdot
.52 .38395 Mdot
.46498 .1854 Mdot
.33523 .5175 Mdot
.49304 .26771 Mdot
.36424 .48102 Mdot
.28806 .38719 Mdot
.45475 .66148 Mdot
.46798 .74506 Mdot
.50048 .44504 Mdot
.44211 .64043 Mdot
.37761 .63906 Mdot
.44445 .38213 Mdot
.47222 .40881 Mdot
.71295 .70767 Mdot
.59997 .64527 Mdot
.52427 .50239 Mdot
.46885 .65237 Mdot
.49985 .32831 Mdot
.4609 .34386 Mdot
.44027 .60641 Mdot
.38889 .23546 Mdot
.79401 .49514 Mdot
.54442 .3696 Mdot
.31269 .50656 Mdot
.32019 .49423 Mdot
.47838 .40967 Mdot
.47674 .34602 Mdot
.5913 .61833 Mdot
.61344 .65607 Mdot
.57659 .62933 Mdot
.53 .51071 Mdot
.471 .74939 Mdot
.33331 .71658 Mdot
.42009 .61503 Mdot
.34468 .63968 Mdot
.75308 .66156 Mdot
.53637 .30056 Mdot
.57806 .61147 Mdot
.48605 .35277 Mdot
.50918 .38818 Mdot
.47628 .62557 Mdot
.50311 .78056 Mdot
.43017 .35846 Mdot
.33851 .51876 Mdot
.47416 .6457 Mdot
.57602 .42476 Mdot
.36536 .70289 Mdot
.65593 .46882 Mdot
.6234 .78012 Mdot
.43223 .64644 Mdot
.34124 .49961 Mdot
.45017 .66614 Mdot
.50539 .34485 Mdot
.56141 .4086 Mdot
.33233 .4922 Mdot
.64518 .49322 Mdot
.53822 .31366 Mdot
.50977 .36898 Mdot
.72699 .25511 Mdot
.76036 .63334 Mdot
.48341 .74464 Mdot
.54475 .38972 Mdot
.45425 .36233 Mdot
.68859 .45399 Mdot
.51618 .34496 Mdot
.5411 .34166 Mdot
.79193 .38556 Mdot
.42782 .70539 Mdot
.64802 .45768 Mdot
.40561 .24527 Mdot
.29149 .48632 Mdot
.19509 .65143 Mdot
.60665 .58846 Mdot
.42174 .60312 Mdot
.80282 .48471 Mdot
.64643 .62194 Mdot
.62629 .70447 Mdot
.18972 .63579 Mdot
.5203 .50315 Mdot
.68737 .53173 Mdot
.43272 .40201 Mdot
.54804 .35334 Mdot
.52101 .3734 Mdot
.65985 .48032 Mdot
.32695 .47445 Mdot
.54519 .4971 Mdot
.27993 .27687 Mdot
.51132 .38071 Mdot
.50656 .25665 Mdot
.2151 .46006 Mdot
.68653 .60447 Mdot
.68553 .49105 Mdot
.64359 .4937 Mdot
.53129 .36881 Mdot
.79773 .41698 Mdot
.30169 .49002 Mdot
.49691 .33365 Mdot
.46608 .37842 Mdot
.59418 .64348 Mdot
.34609 .48541 Mdot
.63606 .60583 Mdot
.45878 .73816 Mdot
.21951 .6392 Mdot
.73398 .25433 Mdot
.45893 .65647 Mdot
.21433 .50216 Mdot
.47046 .62859 Mdot
.66967 .27651 Mdot
.6405 .60574 Mdot
.47784 .38749 Mdot
.34459 .46461 Mdot
.49127 .3345 Mdot
.47422 .35624 Mdot
.49591 .34005 Mdot
.48712 .3082 Mdot
.86293 .45901 Mdot
.65127 .49333 Mdot
.44947 .36649 Mdot
.63272 .63642 Mdot
.20058 .53122 Mdot
.19126 .38292 Mdot
.49397 .35123 Mdot
.53758 .35958 Mdot
.35034 .50131 Mdot
.52936 .32506 Mdot
.46705 .61923 Mdot
.33451 .46387 Mdot
.55223 .37138 Mdot
.19 .53152 Mdot
.53426 .41048 Mdot
.21712 .66242 Mdot
.45488 .66479 Mdot
.37334 .6054 Mdot
.44663 .36429 Mdot
.50582 .75789 Mdot
.52444 .50239 Mdot
.58641 .58989 Mdot
.45625 .59131 Mdot
.61999 .60531 Mdot
.37123 .2032 Mdot
.56987 .38008 Mdot
.5338 .39884 Mdot
.46388 .34106 Mdot
.59312 .59148 Mdot
.24175 .61517 Mdot
.51234 .68755 Mdot
.58443 .40903 Mdot
.59106 .60631 Mdot
.34389 .45101 Mdot
.6115 .46859 Mdot
.35453 .46979 Mdot
.63768 .4841 Mdot
.43091 .62185 Mdot
.66029 .50605 Mdot
.50952 .79139 Mdot
.33933 .48552 Mdot
.2837 .52545 Mdot
.60046 .59472 Mdot
.5494 .55456 Mdot
.55298 .87249 Mdot
.59991 .49609 Mdot
.67929 .33149 Mdot
.30587 .51326 Mdot
.50014 .41363 Mdot
.63944 .26031 Mdot
.53926 .55268 Mdot
.62152 .60893 Mdot
.48576 .38676 Mdot
.78426 .41002 Mdot
.59058 .61758 Mdot
.4741 .3335 Mdot
.61951 .64786 Mdot
.43304 .63849 Mdot
.58459 .62489 Mdot
.32211 .52865 Mdot
.53558 .35171 Mdot
.52412 .86976 Mdot
.62971 .49822 Mdot
.54342 .38054 Mdot
.47292 .64874 Mdot
.4099 .50793 Mdot
.47808 .36307 Mdot
.67833 .45303 Mdot
.60533 .61589 Mdot
.59448 .51135 Mdot
.54565 .37 Mdot
.59241 .59542 Mdot
.34615 .4576 Mdot
.45234 .58976 Mdot
.49185 .47349 Mdot
.50025 .76293 Mdot
.29972 .51002 Mdot
.42348 .57614 Mdot
.46765 .601 Mdot
.45465 .35355 Mdot
.46748 .35088 Mdot
.31509 .50308 Mdot
.75603 .35464 Mdot
.52222 .31872 Mdot
.4815 .3932 Mdot
.63511 .6347 Mdot
.61552 .60531 Mdot
.76186 .37313 Mdot
.63904 .64344 Mdot
.56443 .40266 Mdot
.31374 .5015 Mdot
.50184 .39337 Mdot
.34844 .49942 Mdot
.51754 .32147 Mdot
.27577 .47028 Mdot
.35185 .51 Mdot
.51666 .67324 Mdot
.49385 .38997 Mdot
.49074 .27702 Mdot
.48288 .34589 Mdot
.52724 .34236 Mdot
.59489 .62236 Mdot
.66984 .49594 Mdot
.53321 .43594 Mdot
.63738 .50464 Mdot
.69246 .46951 Mdot
.40175 .45955 Mdot
.59414 .64268 Mdot
.67214 .48004 Mdot
.21333 .39552 Mdot
.58202 .6362 Mdot
.66306 .4713 Mdot
.19004 .40268 Mdot
.46281 .65408 Mdot
.30367 .52308 Mdot
.5208 .39358 Mdot
.41317 .80729 Mdot
.52032 .20844 Mdot
.6508 .635 Mdot
.5459 .37776 Mdot
.48339 .35607 Mdot
.37159 .48507 Mdot
.4403 .15751 Mdot
.58374 .57846 Mdot
.51591 .41004 Mdot
.34388 .47524 Mdot
.48502 .15441 Mdot
.63251 .61596 Mdot
.66135 .47431 Mdot
.41524 .63394 Mdot
.382 .46743 Mdot
.46057 .69834 Mdot
.42896 .61358 Mdot
.63247 .5778 Mdot
.45199 .75536 Mdot
.48039 .39909 Mdot
.57858 .60924 Mdot
.64408 .77637 Mdot
.29338 .5446 Mdot
.49664 .63186 Mdot
.66307 .41427 Mdot
.33643 .49985 Mdot
.46692 .6206 Mdot
.66861 .50363 Mdot
.29495 .47844 Mdot
.33405 .5145 Mdot
.47166 .61553 Mdot
.43862 .45362 Mdot
.46636 .56228 Mdot
.45406 .6521 Mdot
.72176 .69194 Mdot
.38859 .76952 Mdot
.57722 .6083 Mdot
.69167 .47549 Mdot
.47642 .80249 Mdot
.31192 .48369 Mdot
.18156 .53158 Mdot
.65399 .76388 Mdot
.53749 .37526 Mdot
.67743 .48085 Mdot
.27983 .66631 Mdot
.31272 .24202 Mdot
.45987 .63218 Mdot
.4909 .497 Mdot
.68434 .50335 Mdot
.54865 .34164 Mdot
.62465 .37583 Mdot
.49222 .39707 Mdot
.43849 .61464 Mdot
.25453 .36302 Mdot
.34236 .49959 Mdot
.47856 .62558 Mdot
.61999 .78231 Mdot
.51635 .38369 Mdot
.48947 .38943 Mdot
.62527 .2924 Mdot
.30705 .47571 Mdot
.58742 .58761 Mdot
.47753 .39515 Mdot
.51041 .3726 Mdot
.53824 .42756 Mdot
.51945 .2723 Mdot
.80878 .43849 Mdot
.50969 .40843 Mdot
.43309 .72741 Mdot
.45396 .34592 Mdot
.49298 .38608 Mdot
.31566 .45264 Mdot
.78384 .30424 Mdot
.45383 .73592 Mdot
.51174 .37582 Mdot
.50216 .41298 Mdot
.46952 .61048 Mdot
.4804 .55636 Mdot
.5434 .56319 Mdot
.5807 .52683 Mdot
.70177 .4116 Mdot
.48277 .30905 Mdot
.34964 .47174 Mdot
.65155 .46809 Mdot
.46424 .38979 Mdot
.35048 .4734 Mdot
.56189 .35905 Mdot
.58885 .6147 Mdot
.58521 .64048 Mdot
.38877 .57331 Mdot
.66982 .47455 Mdot
.58729 .258 Mdot
.34031 .65005 Mdot
.63778 .63187 Mdot
.52932 .4004 Mdot
.42283 .59842 Mdot
.6394 .60938 Mdot
.60484 .54554 Mdot
.58154 .33203 Mdot
.30243 .48416 Mdot
.33013 .50567 Mdot
.70829 .34573 Mdot
.56935 .71952 Mdot
.74073 .28279 Mdot
.43136 .63582 Mdot
.54847 .32821 Mdot
.33026 .59696 Mdot
.33271 .50632 Mdot
.65243 .27068 Mdot
.67389 .47852 Mdot
.46158 .63123 Mdot
.66098 .68129 Mdot
.35423 .49266 Mdot
.30946 .52169 Mdot
.51862 .41946 Mdot
.50367 .35987 Mdot
.72375 .41396 Mdot
.69981 .50133 Mdot
.45095 .60663 Mdot
.69016 .47259 Mdot
.61243 .57019 Mdot
.50782 .40969 Mdot
.36729 .48292 Mdot
.4439 .78799 Mdot
.49669 .41083 Mdot
.593 .62294 Mdot
.33272 .49911 Mdot
.68623 .46712 Mdot
.68893 .46143 Mdot
.5264 .34345 Mdot
.30459 .28412 Mdot
.45386 .64125 Mdot
.33974 .50554 Mdot
.38787 .7153 Mdot
.50661 .31513 Mdot
.50981 .36086 Mdot
.50141 .28601 Mdot
.47082 .61914 Mdot
.36562 .58728 Mdot
.65805 .51021 Mdot
.32476 .47917 Mdot
.53852 .40249 Mdot
.66819 .4673 Mdot
.35428 .58964 Mdot
.64289 .65091 Mdot
.58899 .63024 Mdot
.68151 .45439 Mdot
.68424 .4813 Mdot
.67812 .45488 Mdot
.17889 .52838 Mdot
.34259 .52568 Mdot
.43446 .31281 Mdot
.52577 .31822 Mdot
.69206 .32675 Mdot
.55984 .43038 Mdot
.4759 .64984 Mdot
.60255 .64539 Mdot
.47811 .35196 Mdot
.49511 .41413 Mdot
.50137 .27897 Mdot
.46557 .28366 Mdot
.31918 .53898 Mdot
.34288 .48447 Mdot
.5676 .36075 Mdot
.60756 .65038 Mdot
.27236 .22575 Mdot
.35912 .80879 Mdot
.44805 .38231 Mdot
.51579 .57077 Mdot
.36661 .48617 Mdot
.44816 .59836 Mdot
.57648 .54285 Mdot
.44196 .66696 Mdot
.32424 .48383 Mdot
.50781 .40904 Mdot
.3475 .65313 Mdot
.68354 .45322 Mdot
.51415 .3289 Mdot
.45553 .61616 Mdot
.52156 .33226 Mdot
.42766 .61523 Mdot
.3154 .74443 Mdot
.76821 .64896 Mdot
.52933 .37973 Mdot
.45188 .37564 Mdot
.68815 .4208 Mdot
.49236 .35289 Mdot
.62102 .45448 Mdot
.36471 .49208 Mdot
.70854 .26968 Mdot
.54149 .41255 Mdot
.35718 .33082 Mdot
.50628 .3144 Mdot
.78358 .42568 Mdot
.50738 .35687 Mdot
.69244 .62347 Mdot
.54762 .36049 Mdot
.53933 .34312 Mdot
.44068 .6649 Mdot
.47108 .61334 Mdot
.29318 .47066 Mdot
.59482 .58467 Mdot
.20809 .64389 Mdot
.51028 .36626 Mdot
.50321 .7651 Mdot
.39576 .69008 Mdot
.68566 .48208 Mdot
.32142 .48349 Mdot
.44692 .1486 Mdot
.43141 .66887 Mdot
.77822 .5631 Mdot
.76058 .39619 Mdot
.45262 .70922 Mdot
.59563 .53728 Mdot
.23149 .54942 Mdot
.67187 .46154 Mdot
.54797 .33749 Mdot
.4865 .78863 Mdot
.69678 .67365 Mdot
.58711 .34225 Mdot
.4766 .61547 Mdot
.35502 .37889 Mdot
.46213 .79492 Mdot
.66915 .51314 Mdot
.66002 .50735 Mdot
.41918 .62655 Mdot
.67328 .65044 Mdot
.43292 .36739 Mdot
.67581 .47616 Mdot
.63702 .64168 Mdot
.57528 .61636 Mdot
.56889 .66558 Mdot
.30628 .48431 Mdot
.58543 .79245 Mdot
.31237 .66532 Mdot
.43147 .61212 Mdot
.67923 .54023 Mdot
.37508 .50247 Mdot
.31119 .53177 Mdot
.60822 .59466 Mdot
.59746 .62778 Mdot
.2995 .52318 Mdot
.55407 .40679 Mdot
.47368 .29115 Mdot
.51294 .3789 Mdot
.65917 .48617 Mdot
.50261 .35258 Mdot
.59337 .61359 Mdot
.45523 .63087 Mdot
.60494 .63339 Mdot
.44383 .67162 Mdot
.343 .7163 Mdot
.50713 .33377 Mdot
.53871 .353 Mdot
.51671 .20525 Mdot
.31873 .45618 Mdot
.41282 .73253 Mdot
.4919 .76764 Mdot
.62828 .63409 Mdot
.54143 .34084 Mdot
.35412 .46418 Mdot
.64781 .50885 Mdot
.51429 .2031 Mdot
.48117 .33508 Mdot
.36571 .48548 Mdot
.52872 .40697 Mdot
.21916 .42062 Mdot
.83797 .51774 Mdot
.31121 .49244 Mdot
.60101 .19543 Mdot
.51621 .41347 Mdot
.2378 .52119 Mdot
.4628 .34913 Mdot
.73395 .38446 Mdot
.52022 .31836 Mdot
.29251 .48221 Mdot
.50732 .37712 Mdot
.31528 .46815 Mdot
.63237 .60783 Mdot
.42846 .60715 Mdot
.31358 .51715 Mdot
.4634 .36555 Mdot
.24804 .76864 Mdot
.43601 .6189 Mdot
.53305 .37036 Mdot
.41994 .65199 Mdot
.33571 .46994 Mdot
.30248 .51698 Mdot
.2659 .28262 Mdot
.46448 .72997 Mdot
.43389 .63895 Mdot
.51511 .40834 Mdot
.27812 .6228 Mdot
.49928 .39637 Mdot
.70674 .38777 Mdot
.53202 .42599 Mdot
.51117 .31615 Mdot
.20198 .34889 Mdot
.46278 .60985 Mdot
.7647 .31378 Mdot
.25196 .30028 Mdot
.18707 .51057 Mdot
.37276 .45597 Mdot
.66069 .51387 Mdot
.18103 .57563 Mdot
.47039 .74515 Mdot
.59062 .60025 Mdot
.48041 .34935 Mdot
.36875 .51682 Mdot
.45933 .64457 Mdot
.66572 .496 Mdot
.52991 .37901 Mdot
.59794 .63001 Mdot
.78814 .51807 Mdot
.4127 .65403 Mdot
.31421 .48258 Mdot
.34705 .51527 Mdot
.54747 .16737 Mdot
.54374 .39474 Mdot
.54138 .35219 Mdot
.4343 .61738 Mdot
.32546 .55378 Mdot
.67486 .45999 Mdot
.777 .46114 Mdot
.43338 .63698 Mdot
.52831 .5323 Mdot
.33748 .47714 Mdot
.48423 .35423 Mdot
.23666 .62138 Mdot
.73212 .64025 Mdot
.42389 .2603 Mdot
.65703 .48058 Mdot
.6979 .3844 Mdot
.29183 .48328 Mdot
.4539 .62253 Mdot
.56183 .73127 Mdot
.56598 .32323 Mdot
.48627 .35956 Mdot
.69222 .37858 Mdot
.4784 .48 Mdot
.60496 .23393 Mdot
.48331 .32914 Mdot
.51649 .49113 Mdot
.49981 .3217 Mdot
.57564 .3402 Mdot
.55739 .40997 Mdot
.5166 .35945 Mdot
.36599 .48613 Mdot
.58774 .35177 Mdot
.5852 .60169 Mdot
.52446 .23898 Mdot
.54622 .52195 Mdot
.54419 .37507 Mdot
.49947 .40176 Mdot
.40854 .3074 Mdot
.39654 .59573 Mdot
.32237 .51486 Mdot
.27022 .50874 Mdot
.42655 .60445 Mdot
.48968 .28207 Mdot
.59515 .58074 Mdot
.57687 .40397 Mdot
.59851 .62494 Mdot
.36212 .4731 Mdot
.63181 .62899 Mdot
.41563 .62348 Mdot
.57757 .61843 Mdot
.47074 .75046 Mdot
.46753 .63176 Mdot
.29678 .48626 Mdot
.5276 .34962 Mdot
.47301 .6475 Mdot
.63529 .30898 Mdot
.6591 .48528 Mdot
.25306 .29256 Mdot
.55099 .38811 Mdot
.44066 .70376 Mdot
.39219 .52401 Mdot
.60366 .63124 Mdot
.82874 .45773 Mdot
.34867 .51208 Mdot
.64557 .46373 Mdot
.36 .46927 Mdot
.74012 .6939 Mdot
.67692 .49257 Mdot
.18663 .41288 Mdot
.60626 .73502 Mdot
.62099 .51297 Mdot
.55302 .40624 Mdot
.61869 .39581 Mdot
.6076 .56657 Mdot
.45995 .64365 Mdot
.5954 .72441 Mdot
.53729 .33992 Mdot
.79041 .5885 Mdot
.28379 .48009 Mdot
.59236 .58773 Mdot
.44656 .62504 Mdot
.47674 .63597 Mdot
.47305 .34679 Mdot
.71415 .52954 Mdot
.50429 .32441 Mdot
.54406 .71089 Mdot
.69838 .40429 Mdot
.43539 .34117 Mdot
.54034 .36634 Mdot
.6181 .58889 Mdot
.52811 .407 Mdot
.70134 .444 Mdot
.57165 .80761 Mdot
.50136 .30715 Mdot
.48536 .76665 Mdot
.63041 .47243 Mdot
.33484 .48917 Mdot
.46311 .42133 Mdot
.47992 .734 Mdot
.53723 .40198 Mdot
.85312 .61392 Mdot
.6648 .46979 Mdot
.51584 .75845 Mdot
.46707 .32996 Mdot
.46654 .36816 Mdot
.59854 .4366 Mdot
.36244 .43708 Mdot
.73626 .63787 Mdot
.49181 .36347 Mdot
.65113 .37696 Mdot
.42239 .63871 Mdot
.49571 .3267 Mdot
.52431 .3728 Mdot
.38861 .43215 Mdot
.47455 .63242 Mdot
.62012 .63968 Mdot
.63259 .58698 Mdot
.56702 .60257 Mdot
.67315 .44204 Mdot
.49892 .51078 Mdot
.67137 .29528 Mdot
.80911 .57449 Mdot
.65025 .46525 Mdot
.53719 .4114 Mdot
.68173 .42993 Mdot
.49538 .40717 Mdot
.67476 .50098 Mdot
.47325 .63212 Mdot
.32305 .51596 Mdot
.3266 .58211 Mdot
.59279 .56851 Mdot
.47269 .3334 Mdot
.69527 .48168 Mdot
.29831 .4874 Mdot
.70816 .48358 Mdot
.33207 .48326 Mdot
.43674 .63577 Mdot
.4166 .61234 Mdot
.66684 .49922 Mdot
.35865 .47356 Mdot
.38494 .62467 Mdot
.31726 .24158 Mdot
.55355 .41747 Mdot
.50953 .62294 Mdot
.32773 .45617 Mdot
.28654 .52041 Mdot
.30608 .46601 Mdot
.52101 .33629 Mdot
.51278 .5691 Mdot
.50155 .42692 Mdot
.44873 .60701 Mdot
.61748 .6472 Mdot
.74868 .46166 Mdot
.38292 .75124 Mdot
.73718 .49143 Mdot
.5532 .33253 Mdot
.51176 .3839 Mdot
.53111 .36911 Mdot
.51142 .42281 Mdot
.52985 .7168 Mdot
.48886 .33813 Mdot
.43611 .66374 Mdot
.60231 .61832 Mdot
.55076 .34011 Mdot
.64724 .64681 Mdot
.24634 .583 Mdot
.64707 .47489 Mdot
.48329 .50128 Mdot
.20656 .70399 Mdot
.29564 .49517 Mdot
.64178 .64084 Mdot
.59218 .59898 Mdot
.66809 .45501 Mdot
.45458 .64617 Mdot
.33323 .47845 Mdot
.73932 .40474 Mdot
.68553 .46079 Mdot
.50863 .37542 Mdot
.54011 .59137 Mdot
.78185 .59553 Mdot
.54067 .33069 Mdot
.47415 .37327 Mdot
.64383 .65169 Mdot
.68276 .63895 Mdot
.57884 .83395 Mdot
.63054 .26561 Mdot
.66931 .49766 Mdot
.64508 .48827 Mdot
.29039 .51927 Mdot
.45789 .40584 Mdot
.44499 .60735 Mdot
.57679 .22872 Mdot
.41855 .47584 Mdot
.58787 .25316 Mdot
.50447 .47679 Mdot
.48219 .33648 Mdot
.38413 .22579 Mdot
.51734 .38479 Mdot
.36406 .50064 Mdot
.32421 .47034 Mdot
.30591 .50825 Mdot
.45854 .64117 Mdot
.30947 .38763 Mdot
.43761 .66225 Mdot
.23337 .7252 Mdot
.28941 .49085 Mdot
.52916 .73962 Mdot
.61787 .59089 Mdot
.44599 .35931 Mdot
.68305 .46542 Mdot
.48239 .64808 Mdot
.45813 .32054 Mdot
.8023 .42066 Mdot
.58871 .59433 Mdot
.2952 .48811 Mdot
.2309 .54277 Mdot
.28595 .74368 Mdot
.55855 .54961 Mdot
.56568 .43337 Mdot
.61418 .42388 Mdot
.68731 .48166 Mdot
.4281 .25548 Mdot
.69418 .48887 Mdot
.46135 .62045 Mdot
.53476 .3546 Mdot
.52447 .35469 Mdot
.50854 .31955 Mdot
.49658 .33573 Mdot
.44867 .59708 Mdot
.51511 .31169 Mdot
.83353 .59044 Mdot
.59044 .64542 Mdot
.23249 .42973 Mdot
.66894 .46452 Mdot
.47051 .60095 Mdot
.60057 .61825 Mdot
.65127 .65468 Mdot
.64274 .29272 Mdot
.54443 .36855 Mdot
.47912 .34953 Mdot
.7774 .58008 Mdot
.48466 .32713 Mdot
.54738 .44022 Mdot
.59169 .59672 Mdot
.73865 .48844 Mdot
.64198 .4805 Mdot
.65296 .50148 Mdot
.46867 .64425 Mdot
.35917 .47122 Mdot
.66576 .48087 Mdot
.63331 .61259 Mdot
.55713 .33583 Mdot
.46838 .38741 Mdot
.32259 .45705 Mdot
.66333 .75816 Mdot
.67515 .51042 Mdot
.23568 .55867 Mdot
.33018 .46599 Mdot
.35957 .51695 Mdot
.48587 .36138 Mdot
.56755 .29905 Mdot
.38841 .47546 Mdot
.65328 .45884 Mdot
.46778 .59857 Mdot
.58897 .5263 Mdot
.44881 .61162 Mdot
.32054 .47477 Mdot
.47087 .39696 Mdot
.31606 .47384 Mdot
.54577 .38719 Mdot
.15101 .62457 Mdot
.51727 .35562 Mdot
.81111 .58638 Mdot
.70755 .36094 Mdot
.60238 .6057 Mdot
.38354 .65344 Mdot
.60354 .58977 Mdot
.32543 .4668 Mdot
.46485 .38725 Mdot
.6544 .50696 Mdot
.19012 .47761 Mdot
.36793 .51174 Mdot
.58662 .61596 Mdot
.57256 .59928 Mdot
.46955 .62868 Mdot
.54828 .33272 Mdot
.48694 .35462 Mdot
.61435 .611 Mdot
.4362 .33221 Mdot
.35773 .49218 Mdot
.53965 .35857 Mdot
.50099 .38511 Mdot
.60209 .60315 Mdot
.34173 .22381 Mdot
.2942 .44497 Mdot
.52801 .35917 Mdot
.56698 .75838 Mdot
.47672 .64798 Mdot
.54051 .41855 Mdot
.45354 .33858 Mdot
.68207 .47877 Mdot
.25979 .43396 Mdot
.55331 .80936 Mdot
.46786 .65813 Mdot
.60322 .58505 Mdot
.54306 .39722 Mdot
.61508 .58734 Mdot
.46497 .37718 Mdot
.26952 .44418 Mdot
.58256 .59509 Mdot
.47121 .38217 Mdot
.454 .40472 Mdot
.30877 .47425 Mdot
.48006 .34258 Mdot
.40789 .33769 Mdot
.63068 .59111 Mdot
.46799 .36377 Mdot
.30133 .28861 Mdot
.44712 .65471 Mdot
.45124 .40009 Mdot
.65058 .47445 Mdot
.74254 .40726 Mdot
.33839 .66911 Mdot
.50982 .77421 Mdot
.64787 .48431 Mdot
.52099 .33051 Mdot
.57 .60917 Mdot
.42312 .62054 Mdot
.81127 .55127 Mdot
.5381 .33323 Mdot
.43892 .61495 Mdot
.45374 .62961 Mdot
.65474 .47277 Mdot
.67572 .21417 Mdot
.4747 .31903 Mdot
.49504 .35156 Mdot
.40161 .41505 Mdot
.36525 .4628 Mdot
.50827 .35138 Mdot
.51324 .41658 Mdot
.43134 .6616 Mdot
.53992 .44525 Mdot
.37859 .35507 Mdot
.77097 .43598 Mdot
.46571 .66849 Mdot
.58824 .50242 Mdot
.58182 .58801 Mdot
.67314 .46644 Mdot
.32914 .49318 Mdot
.69342 .49536 Mdot
.58262 .62744 Mdot
.52933 .41443 Mdot
.42205 .65983 Mdot
.44549 .2701 Mdot
.41998 .62361 Mdot
.51573 .77185 Mdot
.35342 .45921 Mdot
.31324 .60173 Mdot
.8685 .54878 Mdot
.31446 .67307 Mdot
.39541 .60049 Mdot
.68544 .48222 Mdot
.64802 .59898 Mdot
.5043 .38519 Mdot
.4454 .24127 Mdot
.53025 .34569 Mdot
.30537 .28874 Mdot
.63155 .64752 Mdot
.57633 .62905 Mdot
.53161 .35657 Mdot
.70178 .40066 Mdot
.42714 .61315 Mdot
.46472 .6137 Mdot
.47049 .35802 Mdot
.4419 .64071 Mdot
.50093 .36081 Mdot
.59501 .61962 Mdot
.79312 .35135 Mdot
.52059 .37907 Mdot
.46391 .39914 Mdot
.49189 .67186 Mdot
.20994 .34776 Mdot
.59337 .76464 Mdot
.42042 .21765 Mdot
.31846 .76842 Mdot
.44191 .63965 Mdot
.49299 .4271 Mdot
.59152 .49833 Mdot
.6473 .64943 Mdot
.38597 .61543 Mdot
.5161 .34748 Mdot
.51684 .34423 Mdot
.54291 .34595 Mdot
.48958 .39054 Mdot
.43144 .24524 Mdot
.42899 .3178 Mdot
.2881 .33656 Mdot
.47548 .35326 Mdot
.6163 .33834 Mdot
.46674 .65372 Mdot
.28015 .48194 Mdot
.7027 .48496 Mdot
.48219 .33684 Mdot
.43482 .30773 Mdot
.48004 .63775 Mdot
.23535 .72691 Mdot
.47054 .63511 Mdot
.62332 .63261 Mdot
.44393 .59925 Mdot
.53772 .3874 Mdot
.32002 .49504 Mdot
.56271 .5212 Mdot
.5435 .68196 Mdot
.59026 .60106 Mdot
.54359 .3803 Mdot
.5068 .7467 Mdot
.58634 .60283 Mdot
.24789 .58767 Mdot
.32414 .49807 Mdot
.64663 .3663 Mdot
.32249 .47048 Mdot
.47108 .38336 Mdot
.47763 .39165 Mdot
.49646 .612 Mdot
.42311 .61459 Mdot
.32647 .46893 Mdot
.70778 .23068 Mdot
.69744 .48501 Mdot
.30379 .50341 Mdot
.56603 .33364 Mdot
.44214 .53324 Mdot
.31867 .50203 Mdot
.72797 .48756 Mdot
.46346 .63866 Mdot
.28706 .50599 Mdot
.5622 .32248 Mdot
.6788 .73175 Mdot
.66441 .45199 Mdot
.5703 .63465 Mdot
.54703 .60097 Mdot
.63654 .60256 Mdot
.45453 .59276 Mdot
.60041 .59252 Mdot
.42352 .64346 Mdot
.38279 .69187 Mdot
.542 .23926 Mdot
.41745 .6052 Mdot
.45016 .59434 Mdot
.60056 .59538 Mdot
.54382 .3586 Mdot
.5593 .57146 Mdot
.51312 .42746 Mdot
.51281 .29778 Mdot
.42778 .6463 Mdot
.29393 .48158 Mdot
.31694 .52701 Mdot
.62278 .36483 Mdot
.35231 .51254 Mdot
.59785 .62579 Mdot
.83105 .53539 Mdot
.48981 .78139 Mdot
.42618 .62975 Mdot
.46007 .59932 Mdot
.49886 .39793 Mdot
.6206 .60634 Mdot
.62441 .59261 Mdot
.46451 .62048 Mdot
.53626 .25543 Mdot
.46219 .40425 Mdot
.28372 .52146 Mdot
.28815 .49822 Mdot
.31166 .49748 Mdot
.30696 .46707 Mdot
.38035 .3187 Mdot
.46519 .63624 Mdot
.29672 .47799 Mdot
.46946 .37334 Mdot
.51549 .34515 Mdot
.57502 .52556 Mdot
.64874 .49495 Mdot
.56115 .35922 Mdot
.56062 .40361 Mdot
.48347 .36028 Mdot
.58682 .62683 Mdot
.50915 .29145 Mdot
.58477 .58939 Mdot
.56649 .61783 Mdot
.61096 .65427 Mdot
.47111 .74651 Mdot
.62537 .42132 Mdot
.36546 .79864 Mdot
.51671 .41017 Mdot
.27453 .53875 Mdot
.62297 .60052 Mdot
.81839 .44193 Mdot
.36477 .58269 Mdot
.54027 .33735 Mdot
.7219 .6478 Mdot
.61274 .60825 Mdot
.34805 .51624 Mdot
.51621 .34994 Mdot
.56438 .61624 Mdot
.6548 .46377 Mdot
.57356 .36753 Mdot
.63446 .59281 Mdot
.35461 .47155 Mdot
.6965 .45399 Mdot
.28668 .49161 Mdot
.61802 .65403 Mdot
.45303 .40309 Mdot
.58008 .87291 Mdot
.58679 .57133 Mdot
.21039 .3885 Mdot
.34449 .44206 Mdot
.54076 .35786 Mdot
.64294 .62998 Mdot
.3684 .46707 Mdot
.45155 .5909 Mdot
.43247 .48504 Mdot
.33236 .51782 Mdot
.57592 .62761 Mdot
.63594 .5974 Mdot
.59105 .59745 Mdot
.34286 .48911 Mdot
.47395 .40668 Mdot
.34781 .49369 Mdot
.44672 .59914 Mdot
.51294 .394 Mdot
.24616 .70991 Mdot
.28832 .5447 Mdot
.32866 .46712 Mdot
.61452 .64129 Mdot
.68562 .45203 Mdot
.52793 .38278 Mdot
.23113 .35431 Mdot
.54958 .3769 Mdot
.42292 .62961 Mdot
.77465 .35825 Mdot
.44338 .26883 Mdot
.52147 .31746 Mdot
.49796 .39753 Mdot
.45795 .60785 Mdot
.53953 .37449 Mdot
.52774 .32016 Mdot
.46896 .74007 Mdot
.34696 .48275 Mdot
.50611 .37934 Mdot
.62756 .64455 Mdot
.44662 .76295 Mdot
.47657 .41563 Mdot
.75632 .53639 Mdot
.66298 .37953 Mdot
.74181 .30138 Mdot
.53331 .34609 Mdot
.61007 .25661 Mdot
.48376 .38464 Mdot
.51111 .32967 Mdot
.50768 .40451 Mdot
.4585 .21538 Mdot
.58081 .60512 Mdot
.59432 .60791 Mdot
.66039 .45392 Mdot
.6602 .37944 Mdot
.67895 .47965 Mdot
.4643 .6437 Mdot
.73389 .54533 Mdot
.58264 .59549 Mdot
.35322 .46958 Mdot
.51504 .32656 Mdot
.58785 .56986 Mdot
.48516 .35076 Mdot
.53851 .38906 Mdot
.60533 .57636 Mdot
.59089 .57343 Mdot
.51204 .76559 Mdot
.64857 .47479 Mdot
.31025 .51362 Mdot
.56174 .37453 Mdot
.69276 .4729 Mdot
.46658 .39673 Mdot
.69091 .32117 Mdot
.31114 .51193 Mdot
.34789 .48534 Mdot
.32983 .5247 Mdot
.52996 .41404 Mdot
.53703 .3834 Mdot
.43544 .66078 Mdot
.35443 .4673 Mdot
.4471 .65302 Mdot
.53796 .51323 Mdot
.76062 .51962 Mdot
.51613 .34735 Mdot
.24237 .55843 Mdot
.68136 .46953 Mdot
.61249 .63213 Mdot
.77919 .54096 Mdot
.66452 .45084 Mdot
.54717 .38099 Mdot
.61448 .58451 Mdot
.66667 .50261 Mdot
.59023 .41955 Mdot
.43061 .82948 Mdot
.69376 .45902 Mdot
.4695 .36927 Mdot
.51502 .45288 Mdot
.44514 .19356 Mdot
.68197 .4459 Mdot
.41711 .64461 Mdot
.53366 .4126 Mdot
.38784 .52433 Mdot
.67577 .5095 Mdot
.40555 .72993 Mdot
.60697 .61393 Mdot
.61517 .77189 Mdot
.47618 .30534 Mdot
.47962 .23198 Mdot
.6886 .49653 Mdot
.32956 .47878 Mdot
.28382 .46671 Mdot
.48439 .37007 Mdot
.6834 .44611 Mdot
.46318 .67219 Mdot
.60966 .62082 Mdot
.45344 .73853 Mdot
.34313 .49142 Mdot
.28092 .58978 Mdot
.6065 .64191 Mdot
.24822 .57209 Mdot
.77803 .40751 Mdot
.4475 .32149 Mdot
.43234 .20988 Mdot
.64532 .69494 Mdot
.53977 .41136 Mdot
.69857 .47929 Mdot
.46957 .65547 Mdot
.41508 .64091 Mdot
.43389 .63308 Mdot
.39193 .69061 Mdot
.57493 .53382 Mdot
.63806 .65034 Mdot
.57659 .6799 Mdot
.67016 .46827 Mdot
.61206 .31151 Mdot
.46081 .3697 Mdot
.51332 .38289 Mdot
.55167 .3348 Mdot
.48947 .32831 Mdot
.48658 .38053 Mdot
.44883 .64674 Mdot
.40088 .70292 Mdot
.59146 .51352 Mdot
.31561 .50819 Mdot
.70756 .52324 Mdot
.61846 .59181 Mdot
.63105 .65733 Mdot
.65596 .49792 Mdot
.22633 .55581 Mdot
.64774 .63855 Mdot
.63034 .63324 Mdot
.55522 .36607 Mdot
.3539 .49102 Mdot
.58503 .38952 Mdot
.48161 .39257 Mdot
.60545 .62703 Mdot
.58276 .47302 Mdot
.3939 .33975 Mdot
.55177 .29875 Mdot
.67618 .43535 Mdot
.50816 .56303 Mdot
.68682 .44963 Mdot
.45887 .37583 Mdot
.81114 .4284 Mdot
.58141 .62443 Mdot
.62462 .62156 Mdot
.69137 .48959 Mdot
.24581 .48993 Mdot
.33482 .49684 Mdot
.65277 .65402 Mdot
.42052 .64899 Mdot
.48785 .40249 Mdot
.78156 .50986 Mdot
.24384 .50222 Mdot
.71582 .53486 Mdot
.43124 .62969 Mdot
.62739 .59888 Mdot
.54274 .3257 Mdot
.47014 .37044 Mdot
.68896 .47632 Mdot
.28361 .70586 Mdot
.57057 .3759 Mdot
.18374 .51641 Mdot
.76818 .65385 Mdot
.67462 .74373 Mdot
.48642 .35945 Mdot
.34541 .48366 Mdot
.64152 .60822 Mdot
.69135 .47511 Mdot
.53598 .30898 Mdot
.41085 .8211 Mdot
.30148 .46254 Mdot
.45883 .62184 Mdot
.57292 .50302 Mdot
.57395 .54428 Mdot
.5526 .38355 Mdot
.52925 .34668 Mdot
.51417 .33477 Mdot
.50255 .83423 Mdot
.59004 .62669 Mdot
.36812 .47982 Mdot
.65482 .48359 Mdot
.35645 .50934 Mdot
.59714 .60482 Mdot
.29426 .5983 Mdot
.54862 .36469 Mdot
.30456 .46096 Mdot
.32899 .48114 Mdot
.46944 .63064 Mdot
.44606 .59175 Mdot
.55328 .51089 Mdot
.51575 .35641 Mdot
.60215 .56061 Mdot
.30119 .4781 Mdot
.54312 .58661 Mdot
.67893 .49131 Mdot
.45464 .66081 Mdot
.47707 .35061 Mdot
.58077 .61429 Mdot
.51551 .31138 Mdot
.32983 .50823 Mdot
.63094 .63157 Mdot
.50943 .76246 Mdot
.64558 .48553 Mdot
.50322 .34089 Mdot
.69483 .44585 Mdot
.60364 .5846 Mdot
.50229 .38643 Mdot
.2261 .52093 Mdot
.65746 .44036 Mdot
.52145 .68689 Mdot
.62984 .65152 Mdot
.50287 .76329 Mdot
.31905 .52437 Mdot
.37251 .66878 Mdot
.62379 .62621 Mdot
.22226 .53945 Mdot
.33115 .73257 Mdot
.56355 .34803 Mdot
.31025 .48687 Mdot
.66246 .61758 Mdot
.18697 .64794 Mdot
.3362 .23254 Mdot
.53115 .37114 Mdot
.63813 .64551 Mdot
.69029 .48859 Mdot
.42567 .6312 Mdot
.75827 .53438 Mdot
.68815 .43416 Mdot
.58045 .58396 Mdot
.50662 .40535 Mdot
.33505 .47171 Mdot
.45869 .63649 Mdot
.3499 .67714 Mdot
.63572 .62959 Mdot
.61133 .64627 Mdot
.53891 .32346 Mdot
.6729 .47794 Mdot
.27614 .2969 Mdot
.59268 .61657 Mdot
.77409 .59479 Mdot
.62381 .56766 Mdot
.69618 .47927 Mdot
.47791 .38043 Mdot
.62219 .39394 Mdot
.522 .42345 Mdot
.19849 .41575 Mdot
.60735 .59049 Mdot
.32236 .51163 Mdot
.52845 .33908 Mdot
.77055 .41886 Mdot
.60894 .62734 Mdot
.51824 .57081 Mdot
.69306 .64114 Mdot
.46436 .63695 Mdot
.7806 .54473 Mdot
.50158 .34873 Mdot
.42511 .61633 Mdot
.68152 .47038 Mdot
.52264 .36065 Mdot
.53445 .38552 Mdot
.37328 .48201 Mdot
.46051 .61778 Mdot
.36233 .7619 Mdot
.47823 .62404 Mdot
.45238 .66549 Mdot
.35783 .51451 Mdot
.49663 .37081 Mdot
.62275 .63485 Mdot
.61443 .60827 Mdot
.52696 .30134 Mdot
.82738 .43033 Mdot
.3374 .49737 Mdot
.6713 .54188 Mdot
.52431 .836 Mdot
.44307 .32975 Mdot
.78083 .53543 Mdot
.28006 .699 Mdot
.45668 .67385 Mdot
.47243 .35547 Mdot
.34599 .46885 Mdot
.65006 .65618 Mdot
.61363 .64504 Mdot
.47499 .40525 Mdot
.4528 .63421 Mdot
.65626 .46073 Mdot
.61381 .57335 Mdot
.71695 .52749 Mdot
.50483 .33226 Mdot
.72161 .65401 Mdot
.63932 .6169 Mdot
.16403 .53438 Mdot
.65779 .62658 Mdot
.30774 .49124 Mdot
.5358 .39055 Mdot
.33949 .51805 Mdot
.65718 .48878 Mdot
.56805 .50733 Mdot
.45438 .63248 Mdot
.44135 .42867 Mdot
.80887 .66274 Mdot
.59286 .59348 Mdot
.36515 .4914 Mdot
.51963 .31681 Mdot
.58408 .45017 Mdot
.49918 .35331 Mdot
.47979 .44371 Mdot
.6355 .45563 Mdot
.43224 .65036 Mdot
.42014 .63309 Mdot
.5068 .38909 Mdot
.67869 .4583 Mdot
.62891 .60343 Mdot
.61206 .62326 Mdot
.17524 .3578 Mdot
.52222 .66312 Mdot
.72592 .41215 Mdot
.5132 .34261 Mdot
.57301 .61551 Mdot
.40111 .75473 Mdot
.43316 .61873 Mdot
.46247 .35538 Mdot
.59409 .58208 Mdot
.70167 .69971 Mdot
.74446 .38602 Mdot
.48341 .37835 Mdot
.46625 .32082 Mdot
.41974 .64907 Mdot
.61362 .29258 Mdot
.6117 .65273 Mdot
.53202 .42682 Mdot
.40866 .63207 Mdot
.76075 .35408 Mdot
.61138 .79591 Mdot
.30959 .51336 Mdot
.68605 .63909 Mdot
.44981 .64693 Mdot
.51908 .29511 Mdot
.66388 .46469 Mdot
.61507 .56989 Mdot
.5851 .62003 Mdot
.5184 .40605 Mdot
.51534 .31232 Mdot
.69026 .42427 Mdot
.35975 .50055 Mdot
.4671 .65203 Mdot
.53735 .3503 Mdot
.30776 .57533 Mdot
.50487 .32001 Mdot
.43934 .66041 Mdot
.55322 .89222 Mdot
.56402 .37 Mdot
.49676 .35401 Mdot
.27762 .29327 Mdot
.33038 .51831 Mdot
.35971 .50764 Mdot
.78987 .62206 Mdot
.51235 .34238 Mdot
.78181 .56557 Mdot
.3117 .51558 Mdot
.33561 .50049 Mdot
.48023 .72014 Mdot
.52337 .38227 Mdot
.54334 .22087 Mdot
.42626 .61824 Mdot
.44062 .66773 Mdot
.34608 .49419 Mdot
.56674 .36928 Mdot
.43524 .67134 Mdot
.3988 .26523 Mdot
.62004 .60436 Mdot
.80679 .41047 Mdot
.3373 .50948 Mdot
.50079 .49452 Mdot
.43014 .6257 Mdot
.22993 .72234 Mdot
.60506 .68221 Mdot
.54256 .3565 Mdot
.50602 .33859 Mdot
.67851 .46743 Mdot
.56378 .36589 Mdot
.57753 .63206 Mdot
.44182 .64113 Mdot
.24379 .3615 Mdot
.30505 .50739 Mdot
.50927 .35805 Mdot
.24038 .57199 Mdot
.34495 .70565 Mdot
.61544 .74178 Mdot
.33403 .48884 Mdot
.30665 .4856 Mdot
.61227 .65181 Mdot
.63987 .64199 Mdot
.49024 .37166 Mdot
.45633 .6092 Mdot
.34938 .46585 Mdot
.43252 .65564 Mdot
.58219 .62548 Mdot
.62401 .63708 Mdot
.58028 .59916 Mdot
.56503 .41159 Mdot
.63102 .63742 Mdot
.73284 .50788 Mdot
.28187 .59738 Mdot
.31171 .53207 Mdot
.70172 .75043 Mdot
.35035 .67416 Mdot
.4095 .48601 Mdot
.66098 .51062 Mdot
.60368 .58415 Mdot
.45797 .60089 Mdot
.49756 .39397 Mdot
.48195 .34986 Mdot
.58289 .65413 Mdot
.44485 .602 Mdot
.66318 .49462 Mdot
.43043 .60772 Mdot
.65501 .47153 Mdot
.70202 .66232 Mdot
.55017 .33596 Mdot
.47049 .38884 Mdot
.4433 .64566 Mdot
.63203 .63307 Mdot
.59994 .61419 Mdot
.69381 .45608 Mdot
.43576 .45979 Mdot
.58623 .6006 Mdot
.33525 .50944 Mdot
.37382 .31039 Mdot
.63856 .60288 Mdot
.51301 .35035 Mdot
.66803 .28801 Mdot
.45766 .24236 Mdot
.50841 .42307 Mdot
.47258 .72901 Mdot
.57231 .20156 Mdot
.52872 .33386 Mdot
.57693 .19338 Mdot
.50022 .76217 Mdot
.33837 .51684 Mdot
.62809 .64931 Mdot
.63898 .65967 Mdot
.49174 .44147 Mdot
.69457 .50388 Mdot
.53681 .30735 Mdot
.32422 .51908 Mdot
.31061 .45323 Mdot
.71132 .70476 Mdot
.2079 .39205 Mdot
.68598 .49569 Mdot
.65661 .50134 Mdot
.62189 .62505 Mdot
.3197 .22446 Mdot
.56229 .3133 Mdot
.66702 .4973 Mdot
.55072 .24343 Mdot
.50599 .40685 Mdot
.69258 .36927 Mdot
.75727 .61443 Mdot
.345 .48783 Mdot
.61985 .39352 Mdot
.61877 .63077 Mdot
.35451 .50682 Mdot
.33043 .57807 Mdot
.55926 .372 Mdot
.30967 .51062 Mdot
.43105 .65637 Mdot
.6202 .70559 Mdot
.30271 .51663 Mdot
.67815 .29975 Mdot
.46365 .61775 Mdot
.53961 .58564 Mdot
.6302 .35584 Mdot
.87862 .40976 Mdot
.44761 .64392 Mdot
.59417 .57569 Mdot
.61419 .60929 Mdot
.6134 .62333 Mdot
.35647 .50693 Mdot
.62125 .58957 Mdot
.36217 .49541 Mdot
.4034 .19499 Mdot
.43342 .45769 Mdot
.66943 .49877 Mdot
.4616 .72935 Mdot
.31941 .47993 Mdot
.83438 .50407 Mdot
.84958 .58983 Mdot
.47321 .35182 Mdot
.47045 .60863 Mdot
.67532 .49993 Mdot
.17748 .47989 Mdot
.68168 .47566 Mdot
.63069 .52598 Mdot
.78859 .37125 Mdot
.50602 .36253 Mdot
.35215 .39364 Mdot
.65165 .50386 Mdot
.33691 .47875 Mdot
.50598 .38597 Mdot
.3968 .58719 Mdot
.67689 .47377 Mdot
.65937 .45982 Mdot
.49447 .37836 Mdot
.29536 .48749 Mdot
.61741 .63652 Mdot
.42577 .6079 Mdot
.64741 .4576 Mdot
.26682 .47841 Mdot
.54988 .4015 Mdot
.54266 .40108 Mdot
.5473 .55524 Mdot
.71434 .48805 Mdot
.4425 .63944 Mdot
.49807 .20753 Mdot
.63696 .64441 Mdot
.66202 .59285 Mdot
.76476 .64254 Mdot
.477 .73605 Mdot
.60617 .59224 Mdot
.60296 .58673 Mdot
.48635 .37714 Mdot
.72094 .47858 Mdot
.76109 .33212 Mdot
.38936 .64761 Mdot
.64303 .61349 Mdot
.60957 .62269 Mdot
.29689 .45984 Mdot
.7196 .70173 Mdot
.53642 .31019 Mdot
.46359 .66235 Mdot
.58181 .61426 Mdot
.25888 .45146 Mdot
.66927 .47614 Mdot
.82464 .47294 Mdot
.54929 .33633 Mdot
.53873 .35347 Mdot
.44253 .62782 Mdot
.43842 .66302 Mdot
.47628 .5843 Mdot
.75841 .66721 Mdot
.53953 .20503 Mdot
.37265 .69695 Mdot
.31676 .42743 Mdot
.28896 .47026 Mdot
.32752 .46734 Mdot
.43546 .7243 Mdot
.47981 .62909 Mdot
.52751 .33568 Mdot
.35019 .46725 Mdot
.60995 .72832 Mdot
.30739 .54843 Mdot
.70555 .38986 Mdot
.76452 .49345 Mdot
.54563 .38494 Mdot
.35357 .48202 Mdot
.33341 .51623 Mdot
.33379 .46241 Mdot
.4982 .76062 Mdot
.49192 .36287 Mdot
.54181 .36805 Mdot
.52348 .32655 Mdot
.51208 .26461 Mdot
.49241 .33551 Mdot
.40147 .68905 Mdot
.52948 .53542 Mdot
.24512 .41337 Mdot
.54289 .42121 Mdot
.44996 .67293 Mdot
.55128 .39026 Mdot
.67608 .45722 Mdot
.50438 .40249 Mdot
.7119 .39258 Mdot
.44636 .6158 Mdot
.31116 .44195 Mdot
.37013 .68518 Mdot
.55115 .35432 Mdot
.64689 .47002 Mdot
.40881 .46013 Mdot
.3108 .74373 Mdot
.69196 .50981 Mdot
.33616 .50893 Mdot
.61589 .5976 Mdot
.45551 .60144 Mdot
.62711 .63134 Mdot
.56808 .40509 Mdot
.4541 .71531 Mdot
.27886 .65993 Mdot
.53946 .50194 Mdot
.48526 .33333 Mdot
.48577 .29285 Mdot
.33486 .50567 Mdot
.61392 .58401 Mdot
.32387 .54228 Mdot
.52348 .33831 Mdot
.65713 .48299 Mdot
.67498 .4704 Mdot
.39686 .57329 Mdot
.20482 .6119 Mdot
.37178 .64506 Mdot
.44113 .63055 Mdot
.59086 .61714 Mdot
.69379 .49202 Mdot
.2578 .53629 Mdot
.4568 .58914 Mdot
.45864 .60761 Mdot
.46346 .62444 Mdot
.51037 .41414 Mdot
.58452 .58946 Mdot
.24602 .40355 Mdot
.57424 .62028 Mdot
.54156 .37718 Mdot
.59193 .63076 Mdot
.59121 .58795 Mdot
.67263 .46388 Mdot
.46992 .64221 Mdot
.58999 .63808 Mdot
.47046 .38277 Mdot
.29822 .50502 Mdot
.47109 .47984 Mdot
.72068 .36414 Mdot
.20522 .4378 Mdot
.21996 .44069 Mdot
.29157 .50871 Mdot
.20396 .66038 Mdot
.47589 .65275 Mdot
.5393 .25716 Mdot
.54907 .76197 Mdot
.47708 .40285 Mdot
.84486 .50293 Mdot
.63893 .65025 Mdot
.6022 .57537 Mdot
.4795 .38328 Mdot
.67391 .65128 Mdot
.50551 .35699 Mdot
.59549 .63847 Mdot
.69827 .52938 Mdot
.45146 .40573 Mdot
.63296 .61832 Mdot
.53056 .42865 Mdot
.52341 .38618 Mdot
.34652 .48701 Mdot
.64237 .62446 Mdot
.46385 .35051 Mdot
.16047 .43277 Mdot
.44545 .66254 Mdot
.49895 .74858 Mdot
.66286 .27064 Mdot
.45078 .64789 Mdot
.30538 .50258 Mdot
.51542 .2981 Mdot
.68585 .47305 Mdot
.32255 .47612 Mdot
.75122 .38937 Mdot
.65009 .50027 Mdot
.83974 .51218 Mdot
.34284 .50573 Mdot
.64069 .60913 Mdot
.6654 .46169 Mdot
.49775 .42718 Mdot
.61263 .56948 Mdot
.41869 .48847 Mdot
.60912 .59139 Mdot
.48728 .35351 Mdot
.44612 .73553 Mdot
.46337 .65732 Mdot
.52857 .3704 Mdot
.61428 .57549 Mdot
.46537 .74341 Mdot
.51201 .41334 Mdot
.49312 .38933 Mdot
.67157 .75198 Mdot
.81355 .51524 Mdot
.68438 .48545 Mdot
.36519 .46692 Mdot
.46949 .37409 Mdot
.65401 .46708 Mdot
.71527 .60497 Mdot
.54379 .40443 Mdot
.30911 .46089 Mdot
.54288 .2872 Mdot
.63282 .59949 Mdot
.4531 .65332 Mdot
.53033 .50712 Mdot
.65422 .46476 Mdot
.61804 .16374 Mdot
.57568 .61308 Mdot
.45838 .36937 Mdot
.48361 .33236 Mdot
.6021 .76034 Mdot
.34349 .51272 Mdot
.55017 .21217 Mdot
.50336 .34067 Mdot
.50027 .26743 Mdot
.52072 .36301 Mdot
.63588 .53967 Mdot
.33557 .49787 Mdot
.49357 .35182 Mdot
.2587 .57212 Mdot
.46367 .40231 Mdot
.65126 .46591 Mdot
.30956 .25871 Mdot
.54012 .41226 Mdot
.69936 .80893 Mdot
.77632 .56488 Mdot
.63392 .6219 Mdot
.43312 .72838 Mdot
.32085 .19446 Mdot
.3795 .68448 Mdot
.36413 .49018 Mdot
.27445 .68358 Mdot
.62269 .63562 Mdot
.40931 .73937 Mdot
.19956 .66042 Mdot
.52231 .38833 Mdot
.55267 .38319 Mdot
.62938 .52367 Mdot
.58143 .64028 Mdot
.60629 .56103 Mdot
.56125 .41013 Mdot
.57441 .33183 Mdot
.62286 .64226 Mdot
.46659 .36886 Mdot
.55006 .42658 Mdot
.43392 .60105 Mdot
.29178 .50533 Mdot
.42599 .63781 Mdot
.47191 .6314 Mdot
.38455 .24067 Mdot
.74388 .67492 Mdot
.44416 .66082 Mdot
.47134 .65769 Mdot
.69823 .37188 Mdot
.6622 .41358 Mdot
.67254 .51052 Mdot
.18582 .55671 Mdot
.61263 .62025 Mdot
.49457 .36463 Mdot
.29621 .5173 Mdot
.48874 .23043 Mdot
.75644 .57174 Mdot
.77046 .33996 Mdot
.52469 .33647 Mdot
.61357 .62868 Mdot
.49734 .7616 Mdot
.57974 .4028 Mdot
.64576 .57755 Mdot
.5412 .35094 Mdot
.59152 .56939 Mdot
.35648 .34901 Mdot
.22998 .55092 Mdot
.612 .56108 Mdot
.27618 .51651 Mdot
.53165 .35236 Mdot
.3369 .51103 Mdot
.42952 .63386 Mdot
.6784 .46123 Mdot
.68189 .48713 Mdot
.49868 .38452 Mdot
.471 .29152 Mdot
.70841 .65665 Mdot
.52832 .38342 Mdot
.51193 .40295 Mdot
.50024 .76231 Mdot
.51119 .40077 Mdot
.49181 .32821 Mdot
.50507 .3236 Mdot
.45278 .36206 Mdot
.44832 .66673 Mdot
.24093 .57078 Mdot
.57814 .38315 Mdot
.56819 .41621 Mdot
.4127 .63044 Mdot
.3057 .72629 Mdot
.47423 .62898 Mdot
.24986 .71412 Mdot
.42255 .63262 Mdot
.67339 .49365 Mdot
.5157 .78292 Mdot
.47452 .29409 Mdot
.30072 .47369 Mdot
.46627 .59537 Mdot
.65315 .47979 Mdot
.43681 .63756 Mdot
.60194 .63954 Mdot
.55411 .82155 Mdot
.26101 .50517 Mdot
.58846 .23311 Mdot
.39013 .57728 Mdot
.53176 .67495 Mdot
.58352 .63348 Mdot
.34074 .49683 Mdot
.39136 .35338 Mdot
.49769 .3233 Mdot
.65465 .46749 Mdot
.4905 .3758 Mdot
.45937 .663 Mdot
.61786 .62799 Mdot
.31154 .25262 Mdot
.68822 .47528 Mdot
.70753 .73831 Mdot
.60483 .61229 Mdot
.52088 .32218 Mdot
.46155 .66358 Mdot
.74553 .72008 Mdot
.42828 .6447 Mdot
.41932 .40524 Mdot
.2779 .49989 Mdot
.42071 .21346 Mdot
.31467 .48405 Mdot
.65422 .63783 Mdot
.5713 .84453 Mdot
.19515 .50768 Mdot
.29522 .49224 Mdot
.55108 .66325 Mdot
.54432 .39397 Mdot
.54475 .39852 Mdot
.23397 .51117 Mdot
.35801 .46308 Mdot
.47554 .34755 Mdot
.50824 .75932 Mdot
.28878 .61986 Mdot
.79124 .54298 Mdot
.6113 .58759 Mdot
.50458 .35183 Mdot
.41028 .63306 Mdot
.4326 .60667 Mdot
.57429 .61164 Mdot
.47459 .62496 Mdot
.54036 .36889 Mdot
.3182 .48138 Mdot
.59065 .56391 Mdot
.67078 .48724 Mdot
.18676 .38883 Mdot
.69782 .48953 Mdot
.60548 .59272 Mdot
.45232 .40076 Mdot
.62459 .63711 Mdot
.38023 .14187 Mdot
.5401 .36335 Mdot
.3158 .51535 Mdot
.49032 .39566 Mdot
.52975 .35567 Mdot
.55264 .38504 Mdot
.61239 .64215 Mdot
.57988 .21548 Mdot
.46764 .37621 Mdot
.45578 .63256 Mdot
.25286 .42925 Mdot
.55403 .38549 Mdot
.67714 .53553 Mdot
.67872 .39877 Mdot
.58708 .6843 Mdot
.28925 .51535 Mdot
.62502 .59979 Mdot
.30085 .50321 Mdot
.28507 .53686 Mdot
.30567 .50292 Mdot
.28644 .41184 Mdot
.38426 .3531 Mdot
.61172 .21973 Mdot
.29277 .29818 Mdot
.60058 .33845 Mdot
.36227 .46527 Mdot
.61937 .46062 Mdot
.33215 .46539 Mdot
.33835 .5132 Mdot
.36451 .87909 Mdot
.30767 .47147 Mdot
.5097 .34664 Mdot
.55763 .3566 Mdot
.32726 .68116 Mdot
.67263 .3409 Mdot
.50657 .39482 Mdot
.47453 .38369 Mdot
.67776 .46278 Mdot
.45681 .29556 Mdot
.45544 .71639 Mdot
.82457 .54843 Mdot
.36164 .71946 Mdot
.49233 .37808 Mdot
.47059 .37983 Mdot
.58484 .36297 Mdot
.73258 .75573 Mdot
.41286 .23967 Mdot
.3488 .45566 Mdot
.526 .29478 Mdot
.19069 .44503 Mdot
.54806 .35272 Mdot
.51485 .41695 Mdot
.54574 .3871 Mdot
.62236 .63523 Mdot
.29606 .46655 Mdot
.54389 .30409 Mdot
.75843 .63157 Mdot
.55093 .36137 Mdot
.47433 .73609 Mdot
.41807 .16657 Mdot
.50102 .34809 Mdot
.28849 .48126 Mdot
.52915 .4072 Mdot
.3486 .50315 Mdot
.34374 .47728 Mdot
.4535 .39483 Mdot
.29675 .42762 Mdot
.28792 .47629 Mdot
.54163 .37817 Mdot
.61141 .63709 Mdot
.17787 .56113 Mdot
.48738 .35109 Mdot
.69228 .47311 Mdot
.50659 .33962 Mdot
.64717 .46664 Mdot
.51738 .39953 Mdot
.57493 .60726 Mdot
.44517 .26262 Mdot
.62321 .62145 Mdot
.46459 .18039 Mdot
.58313 .58777 Mdot
.67999 .74773 Mdot
.33102 .45487 Mdot
.45228 .73533 Mdot
.70843 .25038 Mdot
.49053 .74129 Mdot
.49607 .56795 Mdot
.48353 .54597 Mdot
.4572 .6093 Mdot
.33491 .52026 Mdot
.58749 .2689 Mdot
.61137 .73806 Mdot
.58585 .7598 Mdot
.58644 .59386 Mdot
.70326 .22982 Mdot
.79163 .35794 Mdot
.48163 .39811 Mdot
.33165 .40033 Mdot
.2926 .34545 Mdot
.54109 .40924 Mdot
.51246 .29722 Mdot
.56905 .63675 Mdot
.47575 .33797 Mdot
.29705 .57347 Mdot
.6021 .59655 Mdot
.65287 .47778 Mdot
.32782 .51285 Mdot
.66242 .45411 Mdot
.60224 .74489 Mdot
.47943 .54756 Mdot
.58908 .63342 Mdot
.45644 .38514 Mdot
.48455 .39169 Mdot
.34976 .49152 Mdot
.37753 .50916 Mdot
.31011 .47387 Mdot
.68612 .49411 Mdot
.60404 .60084 Mdot
.44937 .23503 Mdot
.47259 .37256 Mdot
.32761 .48313 Mdot
.46175 .56746 Mdot
.46986 .36733 Mdot
.43876 .64601 Mdot
.54815 .37772 Mdot
.29475 .50021 Mdot
.51142 .40061 Mdot
.31548 .48127 Mdot
.61914 .60077 Mdot
.54784 .34265 Mdot
.48027 .38035 Mdot
.72563 .73448 Mdot
.66416 .49367 Mdot
.35112 .45892 Mdot
.67869 .65016 Mdot
.49536 .32091 Mdot
.5214 .70155 Mdot
.53135 .34872 Mdot
.34503 .54562 Mdot
.45945 .38353 Mdot
.4859 .75466 Mdot
.53844 .31393 Mdot
.48819 .35126 Mdot
.4136 .55642 Mdot
.28656 .37148 Mdot
.38626 .49441 Mdot
.45524 .66825 Mdot
.31128 .46518 Mdot
.77563 .50896 Mdot
.6481 .6305 Mdot
.61958 .58617 Mdot
.63043 .29367 Mdot
.45442 .34389 Mdot
.50424 .36267 Mdot
.41562 .61367 Mdot
.64977 .49359 Mdot
.33384 .48691 Mdot
.65472 .47275 Mdot
.7696 .6333 Mdot
.66828 .50486 Mdot
.62094 .6606 Mdot
.7201 .65116 Mdot
.42424 .25247 Mdot
.67742 .463 Mdot
.29518 .48632 Mdot
.75533 .49846 Mdot
.48176 .41045 Mdot
.67196 .42964 Mdot
.65852 .48189 Mdot
.68714 .20923 Mdot
.48983 .33027 Mdot
.50412 .57098 Mdot
.44442 .65769 Mdot
.66594 .46381 Mdot
.45216 .61155 Mdot
.50321 .39274 Mdot
.51528 .68803 Mdot
.36492 .47716 Mdot
.42325 .66551 Mdot
.55619 .40104 Mdot
.6704 .50097 Mdot
.58283 .6131 Mdot
.48607 .60364 Mdot
.44036 .67174 Mdot
.27565 .70182 Mdot
.36191 .21952 Mdot
.6054 .60248 Mdot
.78887 .43574 Mdot
.42352 .62264 Mdot
.52817 .41692 Mdot
.47154 .27781 Mdot
.54304 .35648 Mdot
.38594 .6765 Mdot
.62233 .59508 Mdot
.28692 .64001 Mdot
.48756 .39557 Mdot
.51856 .32917 Mdot
.38574 .48549 Mdot
.61773 .61389 Mdot
.31862 .49716 Mdot
.31521 .46527 Mdot
.619 .602 Mdot
.3096 .49047 Mdot
.64781 .49862 Mdot
.30009 .62168 Mdot
.41724 .6344 Mdot
.45562 .6284 Mdot
.6108 .62347 Mdot
.63464 .63145 Mdot
.62957 .63346 Mdot
.54824 .37716 Mdot
.33512 .49243 Mdot
.53286 .39381 Mdot
.55193 .38549 Mdot
.36877 .43236 Mdot
.28857 .50803 Mdot
.53827 .39772 Mdot
.65981 .61426 Mdot
.6891 .43773 Mdot
.60798 .63683 Mdot
.44652 .65969 Mdot
.4187 .76279 Mdot
.47 .67283 Mdot
.50768 .35264 Mdot
.69971 .69885 Mdot
.29969 .48285 Mdot
.68078 .47102 Mdot
.65426 .51276 Mdot
.6839 .47874 Mdot
.40475 .65834 Mdot
.34643 .46082 Mdot
.826 .54526 Mdot
.50348 .35469 Mdot
.54638 .55774 Mdot
.55814 .24139 Mdot
.70513 .67154 Mdot
.44842 .66056 Mdot
.47037 .37543 Mdot
.52352 .50261 Mdot
.40269 .32485 Mdot
.53887 .35551 Mdot
.4911 .42025 Mdot
.52466 .75067 Mdot
.56803 .30736 Mdot
.27943 .48992 Mdot
.77604 .65667 Mdot
.55838 .3417 Mdot
.24603 .47798 Mdot
.21492 .31687 Mdot
.51637 .35382 Mdot
.51607 .33344 Mdot
.47906 .36014 Mdot
.50163 .40409 Mdot
.28451 .48592 Mdot
.63672 .32602 Mdot
.4771 .6487 Mdot
.56578 .53747 Mdot
.41597 .64323 Mdot
.60088 .56894 Mdot
.25674 .58556 Mdot
.32897 .52296 Mdot
.67919 .46765 Mdot
.2117 .54637 Mdot
.80568 .60848 Mdot
.61598 .65253 Mdot
.38527 .27725 Mdot
.66157 .48783 Mdot
.52185 .41917 Mdot
.64058 .47856 Mdot
.58569 .5874 Mdot
.46157 .63361 Mdot
.45717 .33412 Mdot
.3201 .46963 Mdot
.30567 .5183 Mdot
.47436 .34978 Mdot
.19372 .46927 Mdot
.44216 .6496 Mdot
.46606 .58944 Mdot
.52493 .41379 Mdot
.51245 .42698 Mdot
.3163 .4999 Mdot
.59811 .62012 Mdot
.7618 .43738 Mdot
.65568 .49607 Mdot
.48341 .32249 Mdot
.50514 .40565 Mdot
.76257 .66313 Mdot
.46384 .64516 Mdot
.61717 .65676 Mdot
.50414 .41178 Mdot
.40138 .71177 Mdot
.50447 .41156 Mdot
.58922 .36897 Mdot
.61107 .63537 Mdot
.57549 .3538 Mdot
.46962 .38576 Mdot
.44076 .41733 Mdot
.43665 .61161 Mdot
.31462 .51309 Mdot
.31464 .53414 Mdot
.59741 .49567 Mdot
.43713 .64387 Mdot
.5345 .40228 Mdot
.45957 .64821 Mdot
.54874 .39557 Mdot
.47345 .34797 Mdot
.43976 .66036 Mdot
.31808 .4967 Mdot
.29135 .69332 Mdot
.24664 .57749 Mdot
.49896 .40317 Mdot
.55367 .33259 Mdot
.65087 .32711 Mdot
.65203 .23442 Mdot
.52832 .34118 Mdot
.29792 .50863 Mdot
.47491 .37881 Mdot
.44576 .61257 Mdot
.66212 .5072 Mdot
.29691 .50309 Mdot
.59577 .61083 Mdot
.60135 .64952 Mdot
.37045 .68322 Mdot
.59707 .5852 Mdot
.49104 .41357 Mdot
.27832 .53339 Mdot
.35814 .51742 Mdot
.19954 .35019 Mdot
.61836 .60467 Mdot
.64915 .50511 Mdot
.49544 .38891 Mdot
.67571 .73486 Mdot
.41998 .6076 Mdot
.74119 .78073 Mdot
.836 .52334 Mdot
.70063 .48432 Mdot
.74861 .30448 Mdot
.60274 .56588 Mdot
.46783 .35184 Mdot
.67866 .46064 Mdot
.6186 .65111 Mdot
.484 .40631 Mdot
.4541 .33437 Mdot
.55781 .21138 Mdot
.583 .50246 Mdot
.45999 .64987 Mdot
.63604 .61434 Mdot
.64742 .51638 Mdot
.60562 .65665 Mdot
.30883 .52097 Mdot
.49022 .35387 Mdot
.44627 .32685 Mdot
.59562 .61545 Mdot
.58516 .64386 Mdot
.54373 .38479 Mdot
.338 .51895 Mdot
.59181 .65808 Mdot
.49874 .3803 Mdot
.58809 .31258 Mdot
.27426 .51085 Mdot
.59814 .59693 Mdot
.51182 .32549 Mdot
.71132 .43918 Mdot
.60354 .61556 Mdot
.60593 .6363 Mdot
.47353 .34993 Mdot
.64607 .49507 Mdot
.54136 .3245 Mdot
.42191 .63901 Mdot
.53231 .18928 Mdot
.45183 .61378 Mdot
.75572 .52206 Mdot
.46724 .41639 Mdot
.5046 .66874 Mdot
.31057 .52367 Mdot
.66032 .52602 Mdot
.44638 .7834 Mdot
.55622 .41639 Mdot
.20142 .62572 Mdot
.4977 .49928 Mdot
.17896 .44994 Mdot
.43729 .81085 Mdot
.66184 .47779 Mdot
.43433 .63462 Mdot
.51623 .33396 Mdot
.462 .59978 Mdot
.68662 .46533 Mdot
.44671 .19585 Mdot
.50514 .3249 Mdot
.33486 .49971 Mdot
.54511 .37618 Mdot
.33736 .50887 Mdot
.47104 .35838 Mdot
.57903 .4001 Mdot
.49972 .76933 Mdot
.74283 .38448 Mdot
.47671 .40361 Mdot
.57234 .82426 Mdot
.75589 .59971 Mdot
.65416 .48653 Mdot
.53202 .38909 Mdot
.65058 .6416 Mdot
.43947 .60394 Mdot
.32341 .55931 Mdot
.62155 .63675 Mdot
.47428 .64049 Mdot
.31018 .49954 Mdot
.61529 .59264 Mdot
.58774 .64237 Mdot
.56232 .33289 Mdot
.65281 .46099 Mdot
.46583 .63056 Mdot
.49263 .3485 Mdot
.49873 .32748 Mdot
.78481 .45529 Mdot
.74828 .56628 Mdot
.35516 .52541 Mdot
.79603 .6711 Mdot
.33344 .53132 Mdot
.66367 .49716 Mdot
.61718 .63797 Mdot
.52854 .34487 Mdot
.52808 .37267 Mdot
.4567 .73959 Mdot
.36544 .47423 Mdot
.56597 .50571 Mdot
.36591 .26076 Mdot
.58544 .65254 Mdot
.67381 .37943 Mdot
.31731 .51725 Mdot
.6741 .37736 Mdot
.64474 .51272 Mdot
.2018 .55498 Mdot
.73484 .391 Mdot
.44835 .65754 Mdot
.66941 .37698 Mdot
.33384 .47654 Mdot
.48263 .39651 Mdot
.64368 .61902 Mdot
.59152 .58852 Mdot
.31898 .50777 Mdot
.56854 .59507 Mdot
.67108 .465 Mdot
.50922 .33114 Mdot
.81898 .539 Mdot
.34344 .64377 Mdot
.59248 .62146 Mdot
.5723 .41573 Mdot
.46204 .62248 Mdot
.47597 .3426 Mdot
.69244 .47605 Mdot
.45174 .64227 Mdot
.77599 .54847 Mdot
.28814 .62946 Mdot
.50121 .38766 Mdot
.6998 .72634 Mdot
.4417 .64422 Mdot
.71989 .287 Mdot
.4952 .37333 Mdot
.42464 .62137 Mdot
.56167 .30846 Mdot
.63577 .69476 Mdot
.53251 .49909 Mdot
.19731 .65806 Mdot
.54766 .50719 Mdot
.6271 .58295 Mdot
.60083 .70572 Mdot
.57663 .73827 Mdot
.45804 .59933 Mdot
.58921 .64702 Mdot
.71491 .49569 Mdot
.45239 .61112 Mdot
.55449 .38052 Mdot
.52579 .35117 Mdot
.41568 .23392 Mdot
.4915 .50585 Mdot
.65642 .65129 Mdot
.36369 .60602 Mdot
.49892 .32021 Mdot
.56535 .35599 Mdot
.52041 .37434 Mdot
.30848 .45416 Mdot
.46184 .64106 Mdot
.65027 .78555 Mdot
.43462 .64359 Mdot
.81989 .472 Mdot
.61388 .62177 Mdot
.62852 .60135 Mdot
.50433 .34924 Mdot
.5353 .60064 Mdot
.63643 .38695 Mdot
.54021 .37127 Mdot
.57201 .55335 Mdot
.29042 .27553 Mdot
.55786 .39213 Mdot
.279 .50671 Mdot
.50432 .44274 Mdot
.28158 .46697 Mdot
.41688 .6321 Mdot
.66925 .47897 Mdot
.67125 .52396 Mdot
.46397 .63403 Mdot
.50523 .36425 Mdot
.485 .68916 Mdot
.5293 .36045 Mdot
.49054 .40442 Mdot
.82371 .45369 Mdot
.69851 .48649 Mdot
.62945 .61823 Mdot
.68606 .48218 Mdot
.34207 .51223 Mdot
.5506 .90576 Mdot
.6482 .48984 Mdot
.63123 .39004 Mdot
.47697 .1891 Mdot
.6677 .37315 Mdot
.31315 .52075 Mdot
.6725 .44637 Mdot
.44855 .65296 Mdot
.16039 .52661 Mdot
.62434 .21165 Mdot
.48944 .62733 Mdot
.50377 .37845 Mdot
.34253 .51937 Mdot
.291 .49507 Mdot
.4218 .66327 Mdot
.34149 .47749 Mdot
.53456 .29289 Mdot
.49187 .40111 Mdot
.46573 .60336 Mdot
.33838 .67554 Mdot
.44101 .67203 Mdot
.29692 .59757 Mdot
.53624 .38618 Mdot
.30968 .51626 Mdot
.49496 .43996 Mdot
.33345 .44544 Mdot
.62265 .6576 Mdot
.53696 .41528 Mdot
.6731 .46482 Mdot
.49642 .66932 Mdot
.60444 .60478 Mdot
.69364 .7011 Mdot
.34871 .49452 Mdot
.50519 .6038 Mdot
.34669 .48469 Mdot
.37224 .47237 Mdot
.47196 .62886 Mdot
.36054 .47602 Mdot
.51456 .33246 Mdot
.65324 .61885 Mdot
.35471 .4973 Mdot
.44526 .62122 Mdot
.67418 .48178 Mdot
.31266 .49122 Mdot
.67304 .65366 Mdot
.4881 .38505 Mdot
.61102 .64576 Mdot
.53074 .7836 Mdot
.36333 .50423 Mdot
.68427 .44968 Mdot
.61431 .58356 Mdot
.66265 .45659 Mdot
.25565 .29721 Mdot
.4801 .62534 Mdot
.77736 .35845 Mdot
.71291 .44428 Mdot
.30297 .4749 Mdot
.51747 .78003 Mdot
.52515 .34568 Mdot
.48993 .38712 Mdot
.65115 .4575 Mdot
.29104 .4945 Mdot
.18506 .51952 Mdot
.3952 .46115 Mdot
.29951 .63489 Mdot
.47658 .61151 Mdot
.64664 .77555 Mdot
.28455 .58283 Mdot
.3552 .19969 Mdot
.56904 .38267 Mdot
.60297 .56353 Mdot
.51179 .36107 Mdot
.43115 .77614 Mdot
.67632 .49928 Mdot
.65417 .54497 Mdot
.46161 .40426 Mdot
.62373 .60265 Mdot
.48237 .36844 Mdot
.41386 .53988 Mdot
.53529 .43795 Mdot
.65553 .5081 Mdot
.4498 .7208 Mdot
.30659 .4703 Mdot
.66776 .48786 Mdot
.57751 .61517 Mdot
.64961 .38644 Mdot
.47132 .39551 Mdot
.57149 .39849 Mdot
.59562 .65878 Mdot
.33878 .49715 Mdot
.63506 .60055 Mdot
.41799 .63238 Mdot
.67115 .4708 Mdot
.49651 .39454 Mdot
.4585 .38486 Mdot
.52273 .70287 Mdot
.46744 .62906 Mdot
.56664 .61405 Mdot
.42858 .64269 Mdot
.61044 .56357 Mdot
.54742 .32431 Mdot
.62725 .59858 Mdot
.46275 .36426 Mdot
.47007 .78148 Mdot
.82074 .4504 Mdot
.29788 .37995 Mdot
.61845 .59163 Mdot
.70027 .40084 Mdot
.44296 .61554 Mdot
.42394 .63263 Mdot
.46274 .21243 Mdot
.42162 .34011 Mdot
.79253 .50519 Mdot
.29014 .72663 Mdot
.4163 .64195 Mdot
.45696 .6191 Mdot
.61179 .64742 Mdot
.36247 .48134 Mdot
.37327 .48992 Mdot
.59452 .56872 Mdot
.66221 .27935 Mdot
.3337 .48683 Mdot
.19405 .58544 Mdot
.78424 .51936 Mdot
.54391 .30635 Mdot
.46937 .58024 Mdot
.67514 .47375 Mdot
.67722 .30221 Mdot
.41068 .5466 Mdot
.52053 .33146 Mdot
.75421 .67144 Mdot
.60311 .62385 Mdot
.61616 .28578 Mdot
.25224 .71521 Mdot
.5001 .32516 Mdot
.49416 .36655 Mdot
.51207 .36838 Mdot
.70089 .47551 Mdot
.44986 .27159 Mdot
.50473 .3275 Mdot
.66077 .27548 Mdot
.49161 .3213 Mdot
.53933 .46327 Mdot
.68349 .48574 Mdot
.57388 .446 Mdot
.51488 .7602 Mdot
.78248 .61159 Mdot
.44915 .41501 Mdot
.41904 .63236 Mdot
.59132 .53295 Mdot
.43494 .61096 Mdot
.28571 .40625 Mdot
.73058 .38577 Mdot
.29318 .52793 Mdot
.51998 .33273 Mdot
.60463 .59283 Mdot
.29109 .4974 Mdot
.57234 .71292 Mdot
.44519 .92225 Mdot
.42039 .62378 Mdot
.42067 .14168 Mdot
.42441 .63871 Mdot
.58226 .63653 Mdot
.31567 .50124 Mdot
.3799 .35171 Mdot
.54579 .5548 Mdot
.31203 .48898 Mdot
.28341 .67014 Mdot
.3827 .47382 Mdot
.68277 .39284 Mdot
.34029 .52629 Mdot
.44405 .61907 Mdot
.41862 .67076 Mdot
.46905 .30974 Mdot
.51426 .34432 Mdot
.47396 .54479 Mdot
.65154 .4049 Mdot
.52029 .34443 Mdot
.60336 .59801 Mdot
.70582 .26457 Mdot
.60895 .49217 Mdot
.34729 .46992 Mdot
.4657 .66905 Mdot
.49126 .3662 Mdot
.50551 .40952 Mdot
.47627 .39832 Mdot
.80584 .66752 Mdot
.19599 .54503 Mdot
.46784 .37621 Mdot
.50512 .31661 Mdot
.61763 .59511 Mdot
.63269 .48108 Mdot
.4143 .7762 Mdot
.47336 .45714 Mdot
.54005 .33923 Mdot
.67198 .49109 Mdot
.69816 .49258 Mdot
.48468 .40724 Mdot
.75587 .63054 Mdot
.51792 .66838 Mdot
.49206 .34852 Mdot
.41994 .37358 Mdot
.59801 .73862 Mdot
.5836 .6419 Mdot
.59752 .61429 Mdot
.29125 .47859 Mdot
.59706 .58862 Mdot
.58142 .58909 Mdot
.38892 .32405 Mdot
.54672 .51754 Mdot
.39929 .63642 Mdot
.68686 .49358 Mdot
.52959 .3693 Mdot
.35995 .51962 Mdot
.41781 .71646 Mdot
.46224 .61406 Mdot
.30235 .48521 Mdot
.43436 .60666 Mdot
.69993 .45906 Mdot
.58549 .2367 Mdot
.58614 .59117 Mdot
.42177 .65764 Mdot
.28816 .62816 Mdot
.6751 .4904 Mdot
.47119 .64265 Mdot
.49388 .68709 Mdot
.55594 .38091 Mdot
.36785 .41106 Mdot
.53905 .37614 Mdot
.18242 .48447 Mdot
.46899 .64573 Mdot
.48139 .75155 Mdot
.49891 .35904 Mdot
.6056 .61405 Mdot
.58482 .3444 Mdot
.54174 .34978 Mdot
.59178 .60806 Mdot
.48142 .39755 Mdot
.6859 .45966 Mdot
.26885 .50549 Mdot
.57391 .5274 Mdot
.83268 .37075 Mdot
.65396 .45925 Mdot
.56015 .70908 Mdot
.52735 .33932 Mdot
.31984 .2445 Mdot
.31418 .48987 Mdot
.46014 .37132 Mdot
.61953 .36628 Mdot
.35869 .49878 Mdot
.30001 .49548 Mdot
.52163 .40585 Mdot
.44242 .656 Mdot
.60147 .6042 Mdot
.68039 .48726 Mdot
.25901 .28417 Mdot
.51217 .38228 Mdot
.47791 .3801 Mdot
.66356 .48783 Mdot
.45517 .616 Mdot
.51247 .41159 Mdot
.54286 .79334 Mdot
.16493 .43501 Mdot
.46232 .60997 Mdot
.55441 .36049 Mdot
.38475 .4244 Mdot
.27526 .47077 Mdot
.52597 .15863 Mdot
.7484 .47345 Mdot
.6302 .61221 Mdot
.56013 .30121 Mdot
.61646 .86425 Mdot
.67133 .47917 Mdot
.80765 .57538 Mdot
.49391 .40794 Mdot
.47363 .36479 Mdot
.3075 .47609 Mdot
.53634 .39506 Mdot
.36317 .49845 Mdot
.80781 .34057 Mdot
.75836 .67689 Mdot
.34183 .50153 Mdot
.31648 .46943 Mdot
.62326 .39025 Mdot
.41732 .77594 Mdot
.31629 .50804 Mdot
.51663 .31319 Mdot
.22668 .46743 Mdot
.45849 .43978 Mdot
.64761 .46082 Mdot
.56236 .76746 Mdot
.30864 .44405 Mdot
.6212 .49112 Mdot
.28252 .70029 Mdot
.29794 .44596 Mdot
.53329 .65706 Mdot
.42185 .64493 Mdot
.51125 .32228 Mdot
.59378 .58661 Mdot
.62087 .58833 Mdot
.52094 .4377 Mdot
.53315 .36332 Mdot
.34697 .50512 Mdot
.68693 .49646 Mdot
.44948 .59991 Mdot
.47518 .38413 Mdot
.61125 .49602 Mdot
.65024 .49097 Mdot
.35402 .47764 Mdot
.51811 .22797 Mdot
.65268 .5078 Mdot
.54839 .43814 Mdot
.49761 .34034 Mdot
.54558 .3852 Mdot
.43629 .41939 Mdot
.44396 .66413 Mdot
.50815 .78118 Mdot
.55258 .34164 Mdot
.77011 .6341 Mdot
.44739 .46731 Mdot
.57588 .34605 Mdot
.33976 .4849 Mdot
.41864 .60847 Mdot
.64272 .65182 Mdot
.60336 .29775 Mdot
.50623 .38647 Mdot
.20141 .527 Mdot
.39305 .24318 Mdot
.63395 .65404 Mdot
.36224 .46593 Mdot
.68181 .47337 Mdot
.53908 .3697 Mdot
.2684 .428 Mdot
.52001 .35172 Mdot
.70795 .44903 Mdot
.60432 .63236 Mdot
.42304 .64721 Mdot
.17552 .44615 Mdot
.62167 .58931 Mdot
.30026 .5013 Mdot
.2071 .70382 Mdot
.34268 .5228 Mdot
.33283 .46348 Mdot
.28187 .43136 Mdot
.43603 .66252 Mdot
.64238 .85492 Mdot
.59818 .19085 Mdot
.49922 .42606 Mdot
.4376 .61602 Mdot
.32543 .50656 Mdot
.47824 .3407 Mdot
.30545 .52499 Mdot
.34996 .46045 Mdot
.56076 .33597 Mdot
.48113 .34742 Mdot
.25847 .582 Mdot
.21324 .67276 Mdot
.68436 .47466 Mdot
.33177 .51829 Mdot
.5792 .28926 Mdot
.48119 .33592 Mdot
.50271 .35441 Mdot
.60093 .72739 Mdot
.64716 .49875 Mdot
.31836 .5695 Mdot
.49893 .40919 Mdot
.73644 .7001 Mdot
.5017 .44255 Mdot
.28324 .48709 Mdot
.465 .614 Mdot
.78426 .60311 Mdot
.38351 .64316 Mdot
.3675 .47855 Mdot
.69216 .48383 Mdot
.31852 .53476 Mdot
.63169 .39382 Mdot
.43918 .66868 Mdot
.29472 .50016 Mdot
.52927 .50636 Mdot
.44808 .63579 Mdot
.46593 .64915 Mdot
.25196 .43106 Mdot
.57293 .59262 Mdot
.69689 .46691 Mdot
.46422 .62766 Mdot
.54312 .26018 Mdot
.43786 .62544 Mdot
.47429 .22357 Mdot
.54941 .34416 Mdot
.63054 .2726 Mdot
.50226 .58001 Mdot
.47954 .29321 Mdot
.46118 .65964 Mdot
.68773 .46856 Mdot
.51718 .40916 Mdot
.33778 .47494 Mdot
.65044 .47872 Mdot
.49264 .61225 Mdot
.62152 .64171 Mdot
.34892 .48374 Mdot
.4829 .62665 Mdot
.32412 .51777 Mdot
.59257 .27282 Mdot
.51321 .18313 Mdot
.59044 .78212 Mdot
.54664 .54888 Mdot
.47931 .40061 Mdot
.34012 .7514 Mdot
.54613 .31229 Mdot
.5359 .3594 Mdot
.59916 .59777 Mdot
.62714 .28881 Mdot
.31826 .49759 Mdot
.17137 .45424 Mdot
.42023 .65227 Mdot
.77514 .66063 Mdot
.35602 .53573 Mdot
.46024 .37722 Mdot
.35468 .49925 Mdot
.34001 .52483 Mdot
.28063 .3701 Mdot
.63361 .6614 Mdot
.4841 .30963 Mdot
.49211 .30351 Mdot
.57417 .38117 Mdot
.46327 .65058 Mdot
.69999 .69439 Mdot
.61838 .5733 Mdot
.5063 .17111 Mdot
.5993 .6285 Mdot
.57246 .55076 Mdot
.35811 .47499 Mdot
.64694 .48978 Mdot
.50088 .35288 Mdot
.38275 .51136 Mdot
.36842 .47801 Mdot
.68965 .44039 Mdot
.66583 .46259 Mdot
.63223 .70348 Mdot
.44091 .66094 Mdot
.47357 .40235 Mdot
.51158 .32594 Mdot
.5293 .39465 Mdot
.54664 .36812 Mdot
.41849 .62652 Mdot
.53753 .4068 Mdot
.40733 .64167 Mdot
.52653 .24789 Mdot
.74565 .68166 Mdot
.54143 .51521 Mdot
.36604 .54547 Mdot
.34063 .47129 Mdot
.56012 .27658 Mdot
.55487 .43675 Mdot
.80891 .42301 Mdot
.22294 .37144 Mdot
.55438 .39884 Mdot
.62345 .6505 Mdot
.42487 .33136 Mdot
.59147 .58219 Mdot
.48709 .12428 Mdot
.5175 .70847 Mdot
.19958 .64834 Mdot
.49294 .33159 Mdot
.60378 .72961 Mdot
.51251 .26628 Mdot
.52743 .30191 Mdot
.55628 .72143 Mdot
.37863 .66899 Mdot
.30961 .67628 Mdot
.68389 .50359 Mdot
.49088 .38191 Mdot
.37361 .50196 Mdot
.51237 .33109 Mdot
.50783 .35694 Mdot
.49602 .41015 Mdot
.47012 .65732 Mdot
.47351 .3197 Mdot
.55035 .3734 Mdot
.70668 .64812 Mdot
.69727 .37758 Mdot
.63555 .61041 Mdot
.45534 .2091 Mdot
.64874 .48722 Mdot
.35057 .49896 Mdot
.23621 .62122 Mdot
.44896 .65779 Mdot
.28465 .35762 Mdot
.54722 .37574 Mdot
.26894 .60351 Mdot
.48148 .61475 Mdot
.67103 .46833 Mdot
.63551 .59519 Mdot
.18181 .60959 Mdot
.60858 .5961 Mdot
.52119 .50481 Mdot
.60786 .61106 Mdot
.50465 .44697 Mdot
.34608 .50616 Mdot
.49541 .41208 Mdot
.46254 .62821 Mdot
.59343 .59918 Mdot
.66185 .33056 Mdot
.51931 .37302 Mdot
.62011 .60321 Mdot
.49678 .41237 Mdot
.59422 .23803 Mdot
.77774 .40972 Mdot
.57722 .59724 Mdot
.40369 .63806 Mdot
.44801 .62997 Mdot
.64768 .4973 Mdot
.35337 .4886 Mdot
.31293 .47488 Mdot
.44959 .64166 Mdot
.64973 .22449 Mdot
.5404 .34157 Mdot
.4819 .33726 Mdot
.77364 .63272 Mdot
.5183 .33827 Mdot
.66578 .39457 Mdot
.5269 .50223 Mdot
.34909 .47365 Mdot
.46854 .35375 Mdot
.50547 .4081 Mdot
.49806 .38814 Mdot
.57899 .2546 Mdot
.59518 .61943 Mdot
.53038 .32732 Mdot
.6656 .46035 Mdot
.65219 .63035 Mdot
.47647 .34067 Mdot
.57532 .38042 Mdot
.31109 .47593 Mdot
.81001 .62942 Mdot
.4269 .64701 Mdot
.58058 .62678 Mdot
.62575 .59863 Mdot
.56692 .76503 Mdot
.33248 .43396 Mdot
.53249 .50299 Mdot
.48234 .16854 Mdot
.50384 .7628 Mdot
.65827 .48955 Mdot
.5228 .62246 Mdot
.47675 .47586 Mdot
.60224 .64739 Mdot
.4259 .61376 Mdot
.55189 .34525 Mdot
.54208 .34007 Mdot
.84051 .49901 Mdot
.46125 .38472 Mdot
.67934 .47475 Mdot
.41006 .64589 Mdot
.33266 .47721 Mdot
.67286 .46798 Mdot
.42539 .6341 Mdot
.33984 .49518 Mdot
.56064 .3716 Mdot
.56109 .36011 Mdot
.30343 .48572 Mdot
.29319 .4902 Mdot
.49589 .34523 Mdot
.58576 .55402 Mdot
.3008 .47194 Mdot
.30534 .51595 Mdot
.58598 .59052 Mdot
.59071 .59144 Mdot
.56363 .33323 Mdot
.43311 .62127 Mdot
.54965 .3858 Mdot
.61123 .59198 Mdot
.67256 .50468 Mdot
.31938 .49198 Mdot
.49888 .40422 Mdot
.47946 .39043 Mdot
.67573 .48917 Mdot
.68733 .49935 Mdot
.66776 .4647 Mdot
.4189 .66572 Mdot
.52468 .3903 Mdot
.31131 .50434 Mdot
.43316 .65851 Mdot
.69861 .49219 Mdot
.64037 .48685 Mdot
.56254 .61227 Mdot
.53056 .34419 Mdot
.64354 .6685 Mdot
.54158 .90134 Mdot
.72565 .44125 Mdot
.63705 .65468 Mdot
.57203 .63623 Mdot
.6707 .35924 Mdot
.54484 .58284 Mdot
.44576 .64826 Mdot
.72387 .47462 Mdot
.66191 .52604 Mdot
.53689 .41455 Mdot
.5548 .33743 Mdot
.49906 .29914 Mdot
.66095 .47052 Mdot
.61525 .30981 Mdot
.31178 .52517 Mdot
.33396 .26576 Mdot
.64921 .48409 Mdot
.58292 .64214 Mdot
.57155 .5933 Mdot
.60006 .6295 Mdot
.55617 .34942 Mdot
.30013 .37331 Mdot
.60303 .39414 Mdot
.34215 .75911 Mdot
.46766 .65222 Mdot
.30543 .53527 Mdot
.28232 .27745 Mdot
.3018 .49037 Mdot
.59332 .57328 Mdot
.65366 .47813 Mdot
.29393 .50276 Mdot
.44573 .60616 Mdot
.45864 .62186 Mdot
.59495 .62327 Mdot
.61272 .62486 Mdot
.6005 .64015 Mdot
.34176 .46175 Mdot
.36017 .4765 Mdot
.51208 .38601 Mdot
.32168 .48332 Mdot
.83977 .55079 Mdot
.69946 .46358 Mdot
.57018 .63526 Mdot
.43304 .6349 Mdot
.3395 .50753 Mdot
.52293 .37457 Mdot
.59902 .50567 Mdot
.36379 .66001 Mdot
.66757 .45466 Mdot
.78265 .43882 Mdot
.48266 .12751 Mdot
.46796 .39763 Mdot
.46261 .64821 Mdot
.81649 .53564 Mdot
.51226 .37073 Mdot
.6163 .6351 Mdot
.47193 .78905 Mdot
.64822 .63032 Mdot
.55188 .3846 Mdot
.47771 .41135 Mdot
.47378 .62334 Mdot
.45531 .18469 Mdot
.51715 .38409 Mdot
.33591 .57792 Mdot
.46721 .67008 Mdot
.61369 .57129 Mdot
.15895 .44845 Mdot
.59837 .7611 Mdot
.67029 .29264 Mdot
.58429 .59393 Mdot
.52987 .3546 Mdot
.58481 .59864 Mdot
.67293 .45561 Mdot
.58098 .61545 Mdot
.27657 .50361 Mdot
.63396 .60212 Mdot
.47744 .37856 Mdot
.31732 .50967 Mdot
.44109 .64465 Mdot
.78392 .64722 Mdot
.73546 .61385 Mdot
.60606 .61523 Mdot
.57523 .61431 Mdot
.46657 .3777 Mdot
.28395 .56851 Mdot
.52613 .43191 Mdot
.48837 .33262 Mdot
.41701 .65124 Mdot
.35644 .4951 Mdot
.47566 .64892 Mdot
.46708 .33885 Mdot
.53046 .79807 Mdot
.43126 .64802 Mdot
.26154 .60015 Mdot
.66097 .48826 Mdot
.43087 .51537 Mdot
.53079 .37136 Mdot
.46266 .61827 Mdot
.52592 .38968 Mdot
.30142 .52341 Mdot
.47333 .51321 Mdot
.42917 .72755 Mdot
.46088 .63004 Mdot
.19101 .50113 Mdot
.56289 .57645 Mdot
.45089 .40197 Mdot
.42737 .61809 Mdot
.61904 .36977 Mdot
.58589 .64101 Mdot
.65599 .4946 Mdot
.69509 .49528 Mdot
.65782 .45906 Mdot
.55007 .41717 Mdot
.455 .41603 Mdot
.69454 .46919 Mdot
.45477 .60447 Mdot
.66097 .51034 Mdot
.24822 .47142 Mdot
.1843 .51574 Mdot
.67766 .49777 Mdot
.49715 .3763 Mdot
.43142 .3752 Mdot
.69292 .37028 Mdot
.65897 .66152 Mdot
.20357 .64108 Mdot
.34029 .55328 Mdot
.51494 .34601 Mdot
.25946 .49263 Mdot
.3027 .52041 Mdot
.80936 .54159 Mdot
.66747 .40988 Mdot
.76873 .61053 Mdot
.3192 .46757 Mdot
.45 .73491 Mdot
.3532 .47952 Mdot
.46444 .38766 Mdot
.47915 .34234 Mdot
.37527 .48287 Mdot
.71448 .69353 Mdot
.52996 .69089 Mdot
.18898 .38958 Mdot
.3109 .51887 Mdot
.43821 .61076 Mdot
.4138 .64217 Mdot
.46326 .65514 Mdot
.7819 .50936 Mdot
.35723 .50883 Mdot
.51715 .39411 Mdot
.61499 .59003 Mdot
.53229 .33112 Mdot
.45517 .63758 Mdot
.17185 .45784 Mdot
.3212 .47415 Mdot
.48909 .35058 Mdot
.65145 .23695 Mdot
.62107 .62949 Mdot
.66967 .49318 Mdot
.57151 .22484 Mdot
.7788 .55188 Mdot
.4394 .66627 Mdot
.3592 .51158 Mdot
.47928 .73862 Mdot
.2505 .59463 Mdot
.56824 .3719 Mdot
.56398 .32508 Mdot
.31297 .23059 Mdot
.77495 .54325 Mdot
.50547 .4183 Mdot
.5845 .63587 Mdot
.45865 .74113 Mdot
.49156 .39648 Mdot
.318 .52237 Mdot
.67694 .50979 Mdot
.65679 .46378 Mdot
.51498 .30804 Mdot
.54687 .55895 Mdot
.43214 .48418 Mdot
.53559 .40226 Mdot
.54891 .43822 Mdot
.59698 .57417 Mdot
.50647 .76037 Mdot
.77045 .6449 Mdot
.69257 .48618 Mdot
.50403 .41294 Mdot
.31697 .7038 Mdot
.35772 .4666 Mdot
.64199 .63388 Mdot
.44376 .66992 Mdot
.55697 .2387 Mdot
.61534 .57111 Mdot
.49162 .39762 Mdot
.51068 .41108 Mdot
.47257 .63999 Mdot
.28306 .48737 Mdot
.65905 .47263 Mdot
.61823 .5903 Mdot
.69367 .48365 Mdot
.35895 .50169 Mdot
.32551 .47501 Mdot
.47113 .44733 Mdot
.4442 .36233 Mdot
.59725 .61224 Mdot
.47379 .33399 Mdot
.67847 .64464 Mdot
.44909 .18207 Mdot
.46593 .59505 Mdot
.46779 .39818 Mdot
.2976 .46073 Mdot
.46242 .63335 Mdot
.47718 .35617 Mdot
.27245 .2635 Mdot
.48257 .33183 Mdot
.38372 .65655 Mdot
.57847 .79494 Mdot
.68216 .46565 Mdot
.31037 .27493 Mdot
.23939 .5231 Mdot
.51369 .33667 Mdot
.6338 .63676 Mdot
.58475 .38282 Mdot
.44364 .65423 Mdot
.3511 .47083 Mdot
.52979 .15554 Mdot
.44123 .62453 Mdot
.50207 .33064 Mdot
.67123 .4699 Mdot
.34962 .52013 Mdot
.60396 .54109 Mdot
.75531 .63929 Mdot
.48673 .43253 Mdot
.50789 .31192 Mdot
.54684 .39082 Mdot
.4664 .80578 Mdot
.58143 .62746 Mdot
.33146 .50834 Mdot
.46191 .65114 Mdot
.45074 .64394 Mdot
.59802 .62367 Mdot
.3124 .66591 Mdot
.43312 .5135 Mdot
.56375 .87996 Mdot
.58981 .60661 Mdot
.68005 .44677 Mdot
.31142 .57311 Mdot
.63534 .63648 Mdot
.62086 .6078 Mdot
.59784 .57447 Mdot
.3925 .6513 Mdot
.33758 .49343 Mdot
.47956 .39196 Mdot
.28917 .51549 Mdot
.53313 .35308 Mdot
.42848 .45992 Mdot
.46446 .63176 Mdot
.34694 .46788 Mdot
.28187 .25812 Mdot
.40945 .36923 Mdot
.50467 .37117 Mdot
.30097 .25809 Mdot
.46832 .4128 Mdot
.65148 .36403 Mdot
.44939 .37627 Mdot
.61045 .61835 Mdot
.53333 .27861 Mdot
.56054 .41613 Mdot
.80843 .61143 Mdot
.43183 .63429 Mdot
.59404 .64813 Mdot
.51591 .42294 Mdot
.51597 .44461 Mdot
.37765 .47946 Mdot
.29679 .50791 Mdot
.69588 .47499 Mdot
.74298 .38082 Mdot
.43939 .64539 Mdot
.53704 .1952 Mdot
.50998 .34279 Mdot
.65149 .75162 Mdot
.2987 .29369 Mdot
.47825 .35601 Mdot
.21543 .48422 Mdot
.29372 .36707 Mdot
.53672 .36981 Mdot
.60901 .41672 Mdot
.45284 .6161 Mdot
.54062 .79918 Mdot
.50351 .31562 Mdot
.62045 .63565 Mdot
.36004 .48096 Mdot
.32374 .52472 Mdot
.69142 .46536 Mdot
.80978 .38622 Mdot
.47466 .64867 Mdot
.35113 .46946 Mdot
.51932 .36927 Mdot
.43779 .66438 Mdot
.60064 .5849 Mdot
.45735 .35886 Mdot
.68149 .40949 Mdot
.32538 .48201 Mdot
.49344 .31756 Mdot
.33995 .60655 Mdot
.70113 .33648 Mdot
.36058 .80632 Mdot
.45828 .65727 Mdot
.65793 .50537 Mdot
.58465 .36986 Mdot
.57468 .20981 Mdot
.55554 .40005 Mdot
.62577 .27158 Mdot
.27559 .44932 Mdot
.65745 .50581 Mdot
.49806 .36395 Mdot
.50237 .3947 Mdot
.50932 .5791 Mdot
.68705 .49772 Mdot
.51063 .32441 Mdot
.46281 .27791 Mdot
.33731 .49784 Mdot
.62702 .57871 Mdot
.33106 .48308 Mdot
.50316 .3779 Mdot
.4469 .34495 Mdot
.30079 .48012 Mdot
.43352 .16316 Mdot
.68286 .51331 Mdot
.4294 .65069 Mdot
.44557 .38818 Mdot
.54754 .33482 Mdot
.5717 .83252 Mdot
.62016 .65731 Mdot
.38643 .75697 Mdot
.68978 .6141 Mdot
.30496 .70768 Mdot
.60255 .75796 Mdot
.19915 .68144 Mdot
.75937 .66703 Mdot
.49687 .30281 Mdot
.40287 .51157 Mdot
.60212 .41456 Mdot
.46005 .66182 Mdot
.42309 .26293 Mdot
.51498 .34453 Mdot
.51005 .35863 Mdot
.64197 .64048 Mdot
.28253 .63676 Mdot
.76654 .62182 Mdot
.5703 .54107 Mdot
.65878 .47544 Mdot
.33607 .51529 Mdot
.46973 .36278 Mdot
.58268 .48582 Mdot
.63751 .61634 Mdot
.66174 .74363 Mdot
.49039 .35516 Mdot
.80519 .42233 Mdot
.40425 .69388 Mdot
.44313 .66319 Mdot
.63219 .61028 Mdot
.77931 .57444 Mdot
.53454 .34565 Mdot
.43337 .66961 Mdot
.52058 .38112 Mdot
.55467 .64029 Mdot
.46733 .34282 Mdot
.66668 .50097 Mdot
.48742 .40617 Mdot
.58123 .53842 Mdot
.28294 .76093 Mdot
.71701 .47112 Mdot
.33989 .51982 Mdot
.61063 .66419 Mdot
.59588 .61807 Mdot
.29324 .49703 Mdot
.59828 .61701 Mdot
.29582 .32442 Mdot
.36684 .34718 Mdot
.65689 .48055 Mdot
.53635 .44212 Mdot
.68411 .49218 Mdot
.62481 .65784 Mdot
.52385 .34741 Mdot
.45593 .16349 Mdot
.59562 .60449 Mdot
.59221 .80347 Mdot
.43668 .63001 Mdot
.60775 .65488 Mdot
.49297 .32022 Mdot
.4869 .7331 Mdot
.62743 .59566 Mdot
.43394 .72557 Mdot
.4999 .38805 Mdot
.33139 .47386 Mdot
.50039 .39736 Mdot
.45391 .40139 Mdot
.6038 .56024 Mdot
.55019 .36452 Mdot
.42544 .6339 Mdot
.31191 .46491 Mdot
.17885 .55845 Mdot
.38542 .67314 Mdot
.51853 .32952 Mdot
.51714 .36964 Mdot
.36398 .51111 Mdot
.53245 .32636 Mdot
.41843 .62695 Mdot
.854 .65434 Mdot
.66139 .48881 Mdot
.57347 .61425 Mdot
.59126 .76737 Mdot
.55625 .39253 Mdot
.52867 .40889 Mdot
.24873 .29181 Mdot
.58408 .77808 Mdot
.42456 .62448 Mdot
.5483 .42674 Mdot
.6117 .58445 Mdot
.67262 .47127 Mdot
.45811 .60385 Mdot
.54501 .38601 Mdot
.50002 .35595 Mdot
.6575 .50446 Mdot
.23781 .44432 Mdot
.79267 .54587 Mdot
.47105 .64742 Mdot
.52474 .27449 Mdot
.67003 .58909 Mdot
.54146 .34523 Mdot
.78671 .50332 Mdot
.29732 .50551 Mdot
.43006 .66392 Mdot
.37725 .7688 Mdot
.51744 .41779 Mdot
.46239 .61229 Mdot
.43732 .64402 Mdot
.55424 .42114 Mdot
.33423 .44882 Mdot
.32919 .45901 Mdot
.32615 .5174 Mdot
.85099 .54566 Mdot
.68473 .32403 Mdot
.6007 .64019 Mdot
.45427 .6162 Mdot
.58201 .58642 Mdot
.6805 .44452 Mdot
.52586 .49295 Mdot
.57519 .60405 Mdot
.29045 .50165 Mdot
.6229 .66759 Mdot
.49914 .39274 Mdot
.44305 .64592 Mdot
.6007 .64568 Mdot
.52155 .42384 Mdot
.25965 .56198 Mdot
.63892 .68297 Mdot
.644 .49802 Mdot
.68448 .50639 Mdot
.476 .34637 Mdot
.64425 .65081 Mdot
.49745 .34631 Mdot
.42972 .60193 Mdot
.29461 .57408 Mdot
.54639 .41294 Mdot
.60516 .61737 Mdot
.25701 .49192 Mdot
.77848 .55229 Mdot
.50222 .43013 Mdot
.49734 .37504 Mdot
.53881 .35187 Mdot
.52145 .38128 Mdot
.28587 .65853 Mdot
.47337 .6055 Mdot
.38126 .56139 Mdot
.51493 .7779 Mdot
.31258 .48355 Mdot
.3278 .45372 Mdot
.76208 .49522 Mdot
.5362 .66161 Mdot
.43566 .61854 Mdot
.53947 .36001 Mdot
.40868 .71126 Mdot
.1717 .46659 Mdot
.40263 .16363 Mdot
.67213 .43299 Mdot
.6323 .65225 Mdot
.36457 .50408 Mdot
.63669 .61914 Mdot
.52688 .35352 Mdot
.58451 .35953 Mdot
.19598 .68239 Mdot
.43699 .68162 Mdot
.65513 .47563 Mdot
.53714 .35329 Mdot
.68475 .31671 Mdot
.61719 .59402 Mdot
.57867 .58303 Mdot
.50322 .32347 Mdot
.29077 .47259 Mdot
.47965 .83801 Mdot
.44816 .66336 Mdot
.33962 .55493 Mdot
.54125 .2702 Mdot
.3677 .58672 Mdot
.45999 .63963 Mdot
.75236 .61965 Mdot
.64065 .64984 Mdot
.25284 .36456 Mdot
.31247 .48125 Mdot
.65109 .48102 Mdot
.57015 .33521 Mdot
.31612 .47139 Mdot
.62224 .57615 Mdot
.3412 .47006 Mdot
.48648 .40746 Mdot
.48089 .63084 Mdot
.63187 .61639 Mdot
.40361 .65316 Mdot
.33276 .44974 Mdot
.69068 .47721 Mdot
.47729 .55905 Mdot
.41253 .30568 Mdot
.29154 .36434 Mdot
.53608 .3317 Mdot
.58121 .48323 Mdot
.52166 .39416 Mdot
.37541 .46902 Mdot
.52216 .37675 Mdot
.25664 .50446 Mdot
.63512 .6302 Mdot
.50467 .31647 Mdot
.54178 .39842 Mdot
.4216 .24543 Mdot
.48809 .36304 Mdot
.47061 .3271 Mdot
.53926 .36681 Mdot
.34667 .5355 Mdot
.54795 .4345 Mdot
.34076 .48711 Mdot
.73459 .6506 Mdot
.62073 .61067 Mdot
.68669 .50399 Mdot
.64675 .47645 Mdot
.63768 .27706 Mdot
.70256 .51802 Mdot
.29851 .65621 Mdot
.32905 .49035 Mdot
.42998 .6411 Mdot
.52504 .37836 Mdot
.30066 .73872 Mdot
.58409 .74466 Mdot
.60637 .58017 Mdot
.38557 .67354 Mdot
.53246 .28674 Mdot
.4726 .81006 Mdot
.48281 .32433 Mdot
.84253 .48165 Mdot
.44675 .33254 Mdot
.4648 .34981 Mdot
.58632 .57533 Mdot
.69719 .50407 Mdot
.51403 .32027 Mdot
.37775 .48115 Mdot
.6556 .49901 Mdot
.40055 .48831 Mdot
.65437 .58523 Mdot
.73663 .63618 Mdot
.39262 .29321 Mdot
.52482 .38715 Mdot
.63206 .61952 Mdot
.34903 .4851 Mdot
.77004 .64998 Mdot
.43091 .65697 Mdot
.51848 .62629 Mdot
.5732 .28595 Mdot
.36041 .20978 Mdot
.64991 .48977 Mdot
.24688 .435 Mdot
.47677 .37947 Mdot
.75844 .52162 Mdot
.56346 .3517 Mdot
.17402 .4673 Mdot
.67517 .44643 Mdot
.3059 .46165 Mdot
.43619 .61216 Mdot
.29466 .51774 Mdot
.29139 .37946 Mdot
.47203 .57829 Mdot
.50013 .5365 Mdot
.61193 .59714 Mdot
.40664 .55709 Mdot
.32323 .51052 Mdot
.51302 .41328 Mdot
.55374 .88644 Mdot
.30211 .51291 Mdot
.36702 .49016 Mdot
.48064 .185 Mdot
.44958 .17809 Mdot
.53775 .28562 Mdot
.30638 .47303 Mdot
.61333 .60136 Mdot
.68728 .47643 Mdot
.50754 .40119 Mdot
.5115 .3888 Mdot
.31067 .47499 Mdot
.58166 .57941 Mdot
.40841 .43123 Mdot
.61299 .62319 Mdot
.33975 .49822 Mdot
.62362 .62192 Mdot
.47857 .75794 Mdot
.60711 .65072 Mdot
.5458 .33345 Mdot
.52312 .37716 Mdot
.68331 .62295 Mdot
.32584 .47511 Mdot
.53198 .40318 Mdot
.47763 .39484 Mdot
.31378 .50538 Mdot
.61933 .50104 Mdot
.38295 .42916 Mdot
.52416 .33599 Mdot
.48748 .3816 Mdot
.66209 .50688 Mdot
.54595 .48559 Mdot
.75737 .34134 Mdot
.51734 .40903 Mdot
.69797 .46459 Mdot
.34277 .46266 Mdot
.49245 .34615 Mdot
.21491 .56949 Mdot
.45703 .74119 Mdot
.51223 .41686 Mdot
.58951 .64395 Mdot
.56924 .40116 Mdot
.40131 .8191 Mdot
.48964 .33079 Mdot
.32105 .50426 Mdot
.36131 .49277 Mdot
.51875 .20282 Mdot
.30208 .5061 Mdot
.59145 .58882 Mdot
.45092 .63641 Mdot
.18267 .47994 Mdot
.60142 .58485 Mdot
.51943 .42743 Mdot
.59584 .18925 Mdot
.45861 .34368 Mdot
.53136 .42216 Mdot
.51781 .82197 Mdot
.60394 .58618 Mdot
.35156 .50392 Mdot
.52989 .58224 Mdot
.47423 .31165 Mdot
.43872 .66659 Mdot
.58096 .38662 Mdot
.55323 .35365 Mdot
.58534 .79136 Mdot
.40077 .73401 Mdot
.41308 .629 Mdot
.53639 .30033 Mdot
.51902 .40895 Mdot
.6387 .6725 Mdot
.5233 .37219 Mdot
.68923 .48882 Mdot
.35611 .50718 Mdot
.62968 .64589 Mdot
.67428 .48714 Mdot
.51429 .34033 Mdot
.66236 .46909 Mdot
.61053 .64545 Mdot
.43063 .6671 Mdot
.52943 .34919 Mdot
.64756 .46045 Mdot
.66042 .47362 Mdot
.52429 .39652 Mdot
.35423 .47284 Mdot
.45845 .30905 Mdot
.48775 .34734 Mdot
.49563 .40488 Mdot
.31405 .47461 Mdot
.36077 .16571 Mdot
.48522 .33182 Mdot
.56803 .56975 Mdot
.36873 .48283 Mdot
.40911 .57844 Mdot
.6304 .64784 Mdot
.55306 .35079 Mdot
.42145 .65982 Mdot
.46559 .62438 Mdot
.58994 .58012 Mdot
.34389 .525 Mdot
.68768 .61722 Mdot
.25648 .49553 Mdot
.45224 .33905 Mdot
.45515 .37841 Mdot
.63893 .21047 Mdot
.19192 .64382 Mdot
.32352 .52333 Mdot
.58182 .57342 Mdot
.56712 .53926 Mdot
.45181 .61301 Mdot
.56935 .62554 Mdot
.35686 .51529 Mdot
.35593 .51215 Mdot
.34454 .47324 Mdot
.65289 .47126 Mdot
.67795 .59327 Mdot
.28121 .48947 Mdot
.29279 .47112 Mdot
.49892 .38971 Mdot
.52339 .40832 Mdot
.63212 .42396 Mdot
.71853 .41058 Mdot
.69205 .47364 Mdot
.60211 .62836 Mdot
.8192 .67309 Mdot
.42826 .60409 Mdot
.4131 .24729 Mdot
.54649 .41234 Mdot
.49473 .92637 Mdot
.48372 .32625 Mdot
.52266 .36936 Mdot
.31194 .46591 Mdot
.63975 .47756 Mdot
.6752 .49583 Mdot
.32836 .51209 Mdot
.36903 .46415 Mdot
.68844 .49051 Mdot
.20854 .4164 Mdot
.17993 .52048 Mdot
.5024 .58471 Mdot
.31352 .49819 Mdot
.40211 .3251 Mdot
.44638 .67041 Mdot
.28347 .46531 Mdot
.44603 .59711 Mdot
.62067 .60057 Mdot
.6455 .64506 Mdot
.46364 .65093 Mdot
.50214 .38707 Mdot
.59174 .63613 Mdot
.47348 .32005 Mdot
.21491 .44602 Mdot
.33763 .41079 Mdot
.63819 .72617 Mdot
.54927 .32336 Mdot
.74596 .63785 Mdot
.54885 .67215 Mdot
.50416 .33446 Mdot
.25754 .6641 Mdot
.65673 .47326 Mdot
.28198 .4736 Mdot
.4154 .63431 Mdot
.38042 .82058 Mdot
.54194 .35045 Mdot
.32081 .50036 Mdot
.42999 .63205 Mdot
.57858 .24579 Mdot
.3296 .57818 Mdot
.53582 .35202 Mdot
.58594 .87322 Mdot
.37015 .52346 Mdot
.62735 .6466 Mdot
.71208 .26352 Mdot
.29034 .51798 Mdot
.63872 .45105 Mdot
.51521 .76806 Mdot
.29986 .24953 Mdot
.35 .49948 Mdot
.56443 .61576 Mdot
.33301 .51511 Mdot
.69168 .48159 Mdot
.27568 .51539 Mdot
.62473 .59904 Mdot
.49216 .36221 Mdot
.60376 .62305 Mdot
.69033 .46682 Mdot
.77631 .50904 Mdot
.41446 .63988 Mdot
.59429 .6481 Mdot
.45389 .62557 Mdot
.71342 .3491 Mdot
.50848 .79149 Mdot
.42377 .64761 Mdot
.55066 .21645 Mdot
.51418 .41961 Mdot
.28244 .50282 Mdot
.58807 .61474 Mdot
.51164 .76127 Mdot
.51246 .56386 Mdot
.30734 .48863 Mdot
.60996 .63713 Mdot
.59506 .32931 Mdot
.62043 .21931 Mdot
.48604 .43882 Mdot
.72945 .37255 Mdot
.31118 .50145 Mdot
.56816 .62652 Mdot
.77437 .63248 Mdot
.29158 .50749 Mdot
.58879 .60736 Mdot
.44798 .60865 Mdot
.45485 .64335 Mdot
.51669 .32301 Mdot
.40221 .62409 Mdot
.59853 .63302 Mdot
.57837 .68484 Mdot
.35752 .46579 Mdot
.58968 .25879 Mdot
.65159 .4604 Mdot
.61684 .61435 Mdot
.45948 .38084 Mdot
.31061 .4486 Mdot
.46837 .74961 Mdot
.41014 .41188 Mdot
.78963 .69362 Mdot
.59884 .62394 Mdot
.362 .50096 Mdot
.32079 .49573 Mdot
.50477 .42991 Mdot
.54572 .5518 Mdot
.68535 .60956 Mdot
.63357 .23951 Mdot
.6158 .26614 Mdot
.61795 .56962 Mdot
.62742 .57257 Mdot
.4971 .42309 Mdot
.53194 .38492 Mdot
.44762 .61148 Mdot
.49211 .36794 Mdot
.30947 .46351 Mdot
.52301 .32311 Mdot
.46317 .63978 Mdot
.60486 .59706 Mdot
.52263 .34973 Mdot
.68642 .46819 Mdot
.41455 .65582 Mdot
.47462 .62411 Mdot
.61143 .61394 Mdot
.3206 .46922 Mdot
.71032 .46885 Mdot
.61263 .62537 Mdot
.52386 .38684 Mdot
.50361 .66121 Mdot
.47655 .39855 Mdot
.22222 .39515 Mdot
.28969 .50268 Mdot
.63714 .62641 Mdot
.36537 .46964 Mdot
.45107 .62119 Mdot
.51349 .77687 Mdot
.50959 .37707 Mdot
.58993 .60367 Mdot
.68048 .62704 Mdot
.22024 .42891 Mdot
.37277 .50205 Mdot
.48399 .69447 Mdot
.3411 .45576 Mdot
.63612 .59819 Mdot
.47444 .2064 Mdot
.65332 .49073 Mdot
.60931 .58095 Mdot
.18899 .6031 Mdot
.6001 .6111 Mdot
.48423 .36289 Mdot
.47446 .35513 Mdot
.62405 .64936 Mdot
.64573 .49433 Mdot
.7622 .67224 Mdot
.56482 .6611 Mdot
.35194 .50141 Mdot
.34214 .23686 Mdot
.71826 .76203 Mdot
.42596 .59333 Mdot
.43593 .61402 Mdot
.4768 .3092 Mdot
.46158 .35721 Mdot
.44526 .59885 Mdot
.46581 .6687 Mdot
.67309 .45186 Mdot
.59839 .57478 Mdot
.29907 .53955 Mdot
.43645 .67283 Mdot
.4535 .43743 Mdot
.71513 .51313 Mdot
.51525 .43424 Mdot
.55876 .28586 Mdot
.5585 .34211 Mdot
.61665 .25805 Mdot
.46365 .6454 Mdot
.46814 .36132 Mdot
.51947 .43716 Mdot
.42351 .66074 Mdot
.69031 .48509 Mdot
.38855 .71417 Mdot
.62751 .62735 Mdot
.17096 .37383 Mdot
.46376 .36514 Mdot
.48345 .35843 Mdot
.46677 .65323 Mdot
.69787 .62046 Mdot
.32636 .47071 Mdot
.28936 .50636 Mdot
.58335 .63076 Mdot
.47915 .5551 Mdot
.54593 .34283 Mdot
.49476 .33574 Mdot
.62982 .63384 Mdot
.60491 .65379 Mdot
.59728 .70557 Mdot
.4798 .38876 Mdot
.43179 .62867 Mdot
.58876 .53142 Mdot
.46416 .64298 Mdot
.46629 .39018 Mdot
.48124 .36402 Mdot
.54459 .33272 Mdot
.46165 .38565 Mdot
.47394 .62027 Mdot
.46829 .36675 Mdot
.44107 .40844 Mdot
.33827 .46717 Mdot
.54817 .36389 Mdot
.60854 .25508 Mdot
.49314 .37768 Mdot
.68859 .47939 Mdot
.42818 .41711 Mdot
.53925 .34919 Mdot
.55094 .34557 Mdot
.55947 .65457 Mdot
.50224 .36458 Mdot
.43102 .6011 Mdot
.31685 .48461 Mdot
.45532 .61675 Mdot
.471 .64214 Mdot
.58075 .60105 Mdot
.69324 .46709 Mdot
.55711 .38772 Mdot
.66359 .45732 Mdot
.56505 .37674 Mdot
.51082 .41797 Mdot
.54923 .76941 Mdot
.84201 .46822 Mdot
.79434 .53939 Mdot
.50987 .37828 Mdot
.59637 .59355 Mdot
.63476 .64284 Mdot
.38226 .53987 Mdot
.48859 .43825 Mdot
.44715 .59983 Mdot
.4633 .61987 Mdot
.68337 .40514 Mdot
.57623 .79216 Mdot
.68927 .48106 Mdot
.56255 .49157 Mdot
.47046 .32176 Mdot
.48443 .39866 Mdot
.45833 .35374 Mdot
.5799 .5914 Mdot
.56697 .55087 Mdot
.60759 .58131 Mdot
.38928 .68352 Mdot
.46604 .63662 Mdot
.5445 .35329 Mdot
.25946 .45096 Mdot
.29558 .50788 Mdot
.31748 .48399 Mdot
.46452 .61023 Mdot
.59216 .65607 Mdot
.66591 .426 Mdot
.44757 .1425 Mdot
.34153 .53904 Mdot
.63969 .48895 Mdot
.50913 .3327 Mdot
.60528 .60264 Mdot
.32142 .51991 Mdot
.66338 .51114 Mdot
.50396 .41385 Mdot
.67856 .59762 Mdot
.51091 .38148 Mdot
.60114 .41689 Mdot
.35544 .47904 Mdot
.17495 .48856 Mdot
.33767 .52455 Mdot
.4128 .65144 Mdot
.41895 .6473 Mdot
.47646 .35924 Mdot
.66278 .22656 Mdot
.2849 .50818 Mdot
.39132 .62715 Mdot
.67427 .44734 Mdot
.4766 .73164 Mdot
.6904 .49132 Mdot
.63303 .64 Mdot
.65308 .4962 Mdot
.63094 .60904 Mdot
.72122 .42672 Mdot
.35469 .52631 Mdot
.66693 .48881 Mdot
.55765 .62811 Mdot
.4815 .43521 Mdot
.68734 .50196 Mdot
.50508 .29682 Mdot
.274 .31459 Mdot
.62637 .63612 Mdot
.6477 .47735 Mdot
.51223 .4128 Mdot
.27001 .7303 Mdot
.42394 .63262 Mdot
.43973 .60056 Mdot
.45157 .34331 Mdot
.59015 .57608 Mdot
.3746 .48862 Mdot
.2439 .60458 Mdot
.49142 .602 Mdot
.47955 .34369 Mdot
.51614 .32069 Mdot
.31667 .45543 Mdot
.38157 .44758 Mdot
.47769 .36506 Mdot
.49517 .24175 Mdot
.47324 .37952 Mdot
.44854 .60714 Mdot
.30729 .52222 Mdot
.31915 .49067 Mdot
.60725 .63902 Mdot
.29743 .47636 Mdot
.25698 .52123 Mdot
.46435 .69562 Mdot
.48162 .30379 Mdot
.44345 .62444 Mdot
.43809 .69883 Mdot
.38805 .68198 Mdot
.2079 .6442 Mdot
.32237 .45291 Mdot
.54499 .32848 Mdot
.36116 .46837 Mdot
.67576 .46973 Mdot
.32823 .47673 Mdot
.36691 .49942 Mdot
.49808 .34169 Mdot
.52973 .35494 Mdot
.60548 .58998 Mdot
.54933 .55191 Mdot
.34115 .46503 Mdot
.47356 .35093 Mdot
.46985 .32987 Mdot
.46846 .32845 Mdot
.45438 .48951 Mdot
.3242 .52256 Mdot
.40578 .23512 Mdot
.62158 .3358 Mdot
.33923 .46497 Mdot
.42977 .83398 Mdot
.50443 .76453 Mdot
.61681 .66014 Mdot
.40483 .6318 Mdot
.4806 .39003 Mdot
.6337 .64834 Mdot
.52671 .35315 Mdot
.55796 .28503 Mdot
.50358 .35645 Mdot
.68436 .49692 Mdot
.4973 .30274 Mdot
.64437 .61988 Mdot
.60923 .62427 Mdot
.4849 .33551 Mdot
.51816 .3507 Mdot
.781 .52462 Mdot
.36462 .46035 Mdot
.3306 .47078 Mdot
.69411 .6403 Mdot
.66583 .48128 Mdot
.43441 .66572 Mdot
.53241 .37204 Mdot
.5802 .60666 Mdot
.60615 .62467 Mdot
.29712 .52074 Mdot
.61788 .63481 Mdot
.45253 .66122 Mdot
.51248 .37558 Mdot
.44113 .59954 Mdot
.65486 .46652 Mdot
.33295 .51773 Mdot
.54182 .3549 Mdot
.49832 .38963 Mdot
.36111 .49324 Mdot
.54748 .40631 Mdot
.66385 .50684 Mdot
.59961 .61361 Mdot
.34908 .49571 Mdot
.45194 .63803 Mdot
.63574 .62837 Mdot
.49928 .4018 Mdot
.80774 .68008 Mdot
.48444 .36858 Mdot
.48873 .3949 Mdot
.17777 .59521 Mdot
.4979 .3018 Mdot
.59167 .61996 Mdot
.29884 .46502 Mdot
.50222 .31082 Mdot
.64875 .29029 Mdot
.38395 .16514 Mdot
.6026 .57991 Mdot
.51052 .33035 Mdot
.21254 .68142 Mdot
.49904 .32994 Mdot
.55242 .20261 Mdot
.73976 .5018 Mdot
.42276 .54659 Mdot
.44273 .35276 Mdot
.45036 .65701 Mdot
.60399 .58937 Mdot
.63391 .6343 Mdot
.38349 .22595 Mdot
.49641 .33935 Mdot
.5991 .43383 Mdot
.53617 .4095 Mdot
.4587 .64153 Mdot
.65427 .40083 Mdot
.60192 .62562 Mdot
.8139 .57092 Mdot
.51832 .39323 Mdot
.32909 .5229 Mdot
.61734 .66689 Mdot
.4909 .75798 Mdot
.49894 .40473 Mdot
.66531 .4583 Mdot
.41123 .65958 Mdot
.49776 .30667 Mdot
.44252 .62958 Mdot
.48902 .40451 Mdot
.48162 .45168 Mdot
.7572 .30739 Mdot
.35056 .47271 Mdot
.44048 .61068 Mdot
.51429 .65771 Mdot
.56102 .33578 Mdot
.35009 .49715 Mdot
.31145 .48219 Mdot
.67354 .45339 Mdot
.51586 .52754 Mdot
.32966 .61108 Mdot
.39078 .40078 Mdot
.37811 .22277 Mdot
.61015 .66474 Mdot
.51452 .68939 Mdot
.51044 .40486 Mdot
.65006 .74673 Mdot
.41633 .61761 Mdot
.48624 .35902 Mdot
.27606 .32675 Mdot
.32175 .51734 Mdot
.48344 .38125 Mdot
.68552 .49123 Mdot
.68615 .70961 Mdot
.67473 .72921 Mdot
.42727 .79625 Mdot
.6144 .59759 Mdot
.58403 .36207 Mdot
.59068 .3585 Mdot
.57588 .62122 Mdot
.55309 .38948 Mdot
.5916 .6138 Mdot
.24419 .32589 Mdot
.65785 .50789 Mdot
.33442 .51918 Mdot
.50046 .76306 Mdot
.55823 .36178 Mdot
.45274 .35433 Mdot
.6678 .51382 Mdot
.53729 .3864 Mdot
.81172 .39469 Mdot
.61146 .73258 Mdot
.59545 .64226 Mdot
.34588 .47288 Mdot
.55656 .35037 Mdot
.53573 .51352 Mdot
.48867 .3431 Mdot
.36029 .37627 Mdot
.55163 .34537 Mdot
.33379 .5943 Mdot
.35989 .47997 Mdot
.44557 .62705 Mdot
.57348 .37214 Mdot
.50979 .36149 Mdot
.60682 .50889 Mdot
.44472 .34556 Mdot
.47512 .33977 Mdot
.37494 .49349 Mdot
.30695 .52016 Mdot
.33963 .48772 Mdot
.63131 .59642 Mdot
.58414 .78877 Mdot
.43923 .6199 Mdot
.57188 .40218 Mdot
.44098 .6738 Mdot
.42163 .33267 Mdot
.64609 .50266 Mdot
.27406 .72093 Mdot
.54691 .37478 Mdot
.3332 .4925 Mdot
.33762 .71243 Mdot
.34299 .46188 Mdot
.56235 .50768 Mdot
.44004 .64564 Mdot
.31483 .51713 Mdot
.51723 .36665 Mdot
.54396 .56819 Mdot
.35091 .77549 Mdot
.46016 .62341 Mdot
.56009 .39101 Mdot
.63221 .65358 Mdot
.57406 .77502 Mdot
.799 .69694 Mdot
.42344 .62647 Mdot
.51516 .65352 Mdot
.49779 .33666 Mdot
.2919 .5013 Mdot
.45176 .6586 Mdot
.42494 .64277 Mdot
.61671 .63708 Mdot
.53221 .35521 Mdot
.53625 .35617 Mdot
.64184 .61525 Mdot
.46437 .62508 Mdot
.45386 .39529 Mdot
.46993 .337 Mdot
.19649 .68752 Mdot
.59296 .30103 Mdot
.22023 .28153 Mdot
.25276 .51616 Mdot
.2682 .34886 Mdot
.23426 .57532 Mdot
.36215 .50239 Mdot
.53876 .34782 Mdot
.54579 .3166 Mdot
.59929 .63278 Mdot
.49853 .37124 Mdot
.58221 .57513 Mdot
.43205 .62014 Mdot
.42168 .82741 Mdot
.36468 .68398 Mdot
.25814 .30104 Mdot
.49806 .36843 Mdot
.37877 .64991 Mdot
.67915 .47949 Mdot
.46892 .67193 Mdot
.344 .49369 Mdot
.48474 .40775 Mdot
.78375 .52947 Mdot
.60912 .58135 Mdot
.2998 .48924 Mdot
.76852 .62407 Mdot
.74756 .62918 Mdot
.46701 .39154 Mdot
.63701 .61059 Mdot
.28863 .68328 Mdot
.49587 .24397 Mdot
.47547 .60183 Mdot
.6872 .49444 Mdot
.61337 .58811 Mdot
.47018 .63092 Mdot
.24216 .48038 Mdot
.30667 .51372 Mdot
.28812 .5275 Mdot
.78553 .47977 Mdot
.57328 .6203 Mdot
.6803 .48434 Mdot
.57305 .79114 Mdot
.65515 .75476 Mdot
.68324 .49739 Mdot
.6452 .64163 Mdot
.3132 .52087 Mdot
.3337 .50473 Mdot
.31635 .48564 Mdot
.80726 .58733 Mdot
.33723 .52656 Mdot
.38504 .27003 Mdot
.45859 .3419 Mdot
.5414 .45656 Mdot
.50733 .32934 Mdot
.45359 .59897 Mdot
.35677 .4865 Mdot
.45735 .55993 Mdot
.55262 .41794 Mdot
.41407 .80334 Mdot
.48777 .33806 Mdot
.48191 .64033 Mdot
.48323 .38672 Mdot
.40841 .27063 Mdot
.36518 .47205 Mdot
.5043 .37645 Mdot
.45302 .59454 Mdot
.66483 .47376 Mdot
.26644 .5125 Mdot
.53839 .35191 Mdot
.28272 .63088 Mdot
.50118 .30065 Mdot
.20565 .39895 Mdot
.60076 .27894 Mdot
.63978 .48922 Mdot
.49947 .26563 Mdot
.56812 .6097 Mdot
.55695 .4543 Mdot
.57768 .42028 Mdot
.45948 .62601 Mdot
.46369 .77503 Mdot
.61958 .60839 Mdot
.72118 .44599 Mdot
.5737 .40732 Mdot
.6942 .47387 Mdot
.38391 .47585 Mdot
.46503 .60289 Mdot
.50614 .42149 Mdot
.53152 .42928 Mdot
.24251 .33936 Mdot
.53668 .44312 Mdot
.52784 .32423 Mdot
.65219 .50898 Mdot
.36878 .24983 Mdot
.49426 .38181 Mdot
.55772 .50674 Mdot
.28426 .5227 Mdot
.44545 .36504 Mdot
.42165 .23309 Mdot
.47554 .34877 Mdot
.29556 .49359 Mdot
.3379 .53338 Mdot
.34063 .68304 Mdot
.67724 .44903 Mdot
.5518 .34861 Mdot
.51033 .20745 Mdot
.52316 .39104 Mdot
.43333 .62949 Mdot
.46082 .36814 Mdot
.62024 .59504 Mdot
.80116 .58818 Mdot
.59695 .63654 Mdot
.53131 .33613 Mdot
.31446 .4903 Mdot
.46594 .65137 Mdot
.79899 .50366 Mdot
.70834 .54225 Mdot
.38024 .26496 Mdot
.27417 .26421 Mdot
.6454 .48893 Mdot
.69906 .48506 Mdot
.46908 .6072 Mdot
.50375 .37772 Mdot
.48824 .19181 Mdot
.44799 .33248 Mdot
.48736 .3831 Mdot
.50404 .35542 Mdot
.52897 .7933 Mdot
.44562 .61329 Mdot
.62294 .63009 Mdot
.47928 .36584 Mdot
.46992 .3583 Mdot
.36439 .49365 Mdot
.66213 .47438 Mdot
.63206 .64647 Mdot
.65806 .48421 Mdot
.59911 .59907 Mdot
.4184 .83118 Mdot
.57301 .38816 Mdot
.66674 .47537 Mdot
.41075 .63471 Mdot
.31139 .47527 Mdot
.4697 .69356 Mdot
.63267 .63944 Mdot
.60255 .62989 Mdot
.48461 .34047 Mdot
.29478 .49193 Mdot
.31458 .46786 Mdot
.67578 .46857 Mdot
.42535 .65339 Mdot
.53467 .34791 Mdot
.50418 .41711 Mdot
.38707 .54893 Mdot
.58366 .58731 Mdot
.59629 .33833 Mdot
.31932 .68043 Mdot
.50776 .37909 Mdot
.31176 .47098 Mdot
.50915 .34917 Mdot
.20318 .53304 Mdot
.2914 .49485 Mdot
.47935 .33435 Mdot
.69758 .73581 Mdot
.6056 .5457 Mdot
.30897 .63595 Mdot
.53357 .32424 Mdot
.18942 .3638 Mdot
.52045 .40545 Mdot
.21473 .71084 Mdot
.7495 .54635 Mdot
.54477 .34781 Mdot
.50279 .3997 Mdot
.36262 .42145 Mdot
.5167 .33791 Mdot
.64047 .60787 Mdot
.71829 .43825 Mdot
.37099 .49473 Mdot
.26317 .58309 Mdot
.44484 .45861 Mdot
.66716 .44907 Mdot
.584 .63198 Mdot
.63415 .57885 Mdot
.67238 .49932 Mdot
.31453 .50073 Mdot
.52194 .38127 Mdot
.46343 .54284 Mdot
.61083 .56545 Mdot
.46218 .4152 Mdot
.43439 .63428 Mdot
.54656 .70969 Mdot
.56833 .63502 Mdot
.44884 .63335 Mdot
.54993 .37857 Mdot
.37474 .42521 Mdot
.767 .41918 Mdot
.16804 .50954 Mdot
.47031 .64861 Mdot
.46614 .63003 Mdot
.80024 .61271 Mdot
.66307 .44911 Mdot
.27361 .29884 Mdot
.33177 .5854 Mdot
.45325 .66345 Mdot
.54235 .23407 Mdot
.59916 .57706 Mdot
.28546 .62476 Mdot
.28177 .47373 Mdot
.45517 .37552 Mdot
.5148 .36551 Mdot
.42394 .65414 Mdot
.23351 .49258 Mdot
.74154 .29235 Mdot
.45477 .62672 Mdot
.44021 .41328 Mdot
.45088 .50578 Mdot
.50616 .76399 Mdot
.58608 .58836 Mdot
.6775 .45028 Mdot
.6377 .45961 Mdot
.35189 .50727 Mdot
.68382 .45613 Mdot
.67447 .72296 Mdot
.54197 .3815 Mdot
.45913 .63241 Mdot
.47057 .74541 Mdot
.44996 .64078 Mdot
.67316 .49767 Mdot
.63908 .48891 Mdot
.33752 .46729 Mdot
.33179 .47141 Mdot
.27112 .35994 Mdot
.65905 .37864 Mdot
.49299 .33171 Mdot
.36565 .76293 Mdot
.35572 .46486 Mdot
.53146 .27054 Mdot
.69838 .48243 Mdot
.6641 .4773 Mdot
.61643 .36581 Mdot
.5397 .36345 Mdot
.52585 .20468 Mdot
.53639 .36638 Mdot
.65655 .39554 Mdot
.56334 .35785 Mdot
.61717 .63615 Mdot
.5428 .36202 Mdot
.70826 .4878 Mdot
.49261 .42122 Mdot
.46546 .35226 Mdot
.58674 .57858 Mdot
.49901 .30766 Mdot
.62182 .59737 Mdot
.52597 .33134 Mdot
.68172 .44546 Mdot
.57865 .6126 Mdot
.67458 .31637 Mdot
.55328 .5831 Mdot
.64136 .65199 Mdot
.68398 .4607 Mdot
.6543 .45939 Mdot
.66246 .27873 Mdot
.34416 .49489 Mdot
.26423 .48767 Mdot
.49993 .37599 Mdot
.57757 .58406 Mdot
.44281 .61198 Mdot
.46907 .36766 Mdot
.5303 .30307 Mdot
.51323 .31812 Mdot
.34425 .51385 Mdot
.68705 .62505 Mdot
.6691 .47094 Mdot
.63085 .59415 Mdot
.62503 .5175 Mdot
.60566 .57013 Mdot
.53711 .43562 Mdot
.56605 .33158 Mdot
.24809 .38925 Mdot
.39425 .75138 Mdot
.79007 .65023 Mdot
.30211 .50942 Mdot
.59204 .6461 Mdot
.65495 .4569 Mdot
.47408 .28724 Mdot
.3372 .49633 Mdot
.62413 .59848 Mdot
.51199 .38117 Mdot
.56112 .38921 Mdot
.47002 .67857 Mdot
.57057 .44852 Mdot
.62316 .28317 Mdot
.60392 .57141 Mdot
.56435 .61409 Mdot
.65204 .75422 Mdot
.71451 .437 Mdot
.49549 .56069 Mdot
.49247 .35173 Mdot
.66343 .45919 Mdot
.32124 .5199 Mdot
.77473 .44499 Mdot
.41728 .63332 Mdot
.54734 .55256 Mdot
.49938 .36949 Mdot
.41411 .56287 Mdot
.31374 .48901 Mdot
.6878 .48672 Mdot
.42414 .65539 Mdot
.64076 .50626 Mdot
.5744 .61005 Mdot
.3935 .18023 Mdot
.52868 .38999 Mdot
.4912 .33032 Mdot
.41342 .63806 Mdot
.32979 .5148 Mdot
.65798 .51517 Mdot
.21385 .41361 Mdot
.61488 .64751 Mdot
.50333 .19041 Mdot
.30107 .47094 Mdot
.39559 .29837 Mdot
.6271 .58766 Mdot
.46516 .61162 Mdot
.67852 .30048 Mdot
.46268 .64101 Mdot
.53674 .33612 Mdot
.32587 .49089 Mdot
.42571 .63065 Mdot
.58229 .51582 Mdot
.23541 .70295 Mdot
.40027 .31682 Mdot
.53836 .3749 Mdot
.31367 .76392 Mdot
.20655 .4746 Mdot
.39166 .49104 Mdot
.42079 .65958 Mdot
.48637 .34695 Mdot
.55335 .38396 Mdot
.51863 .39055 Mdot
.43596 .64772 Mdot
.54253 .75764 Mdot
.62624 .63862 Mdot
.5017 .33214 Mdot
.67107 .45236 Mdot
.62421 .60445 Mdot
.49807 .76536 Mdot
.59497 .62414 Mdot
.35158 .45426 Mdot
.46041 .3642 Mdot
.40766 .67696 Mdot
.30569 .78387 Mdot
.45699 .61819 Mdot
.64275 .65127 Mdot
.4663 .37818 Mdot
.45547 .75789 Mdot
.33851 .48949 Mdot
.60995 .64616 Mdot
.48382 .35775 Mdot
.51688 .74821 Mdot
.78243 .519 Mdot
.59632 .62457 Mdot
.33984 .50301 Mdot
.21346 .58749 Mdot
.49431 .36975 Mdot
.52406 .40267 Mdot
.32493 .51291 Mdot
.44455 .45178 Mdot
.77317 .62585 Mdot
.51444 .35038 Mdot
.44655 .62799 Mdot
.5013 .16261 Mdot
.49262 .31602 Mdot
.62385 .37245 Mdot
.60822 .58859 Mdot
.30912 .65863 Mdot
.59159 .32394 Mdot
.51526 .27019 Mdot
.22854 .49066 Mdot
.47313 .48004 Mdot
.39882 .81243 Mdot
.57218 .58816 Mdot
.74973 .59862 Mdot
.39631 .81706 Mdot
.46839 .60157 Mdot
.2823 .45051 Mdot
.31344 .55494 Mdot
.82499 .54328 Mdot
.22387 .60261 Mdot
.71086 .63532 Mdot
.78748 .5396 Mdot
.44753 .52738 Mdot
.59691 .60512 Mdot
.69371 .43811 Mdot
.53173 .35075 Mdot
.205 .47284 Mdot
.4678 .24038 Mdot
.70949 .25218 Mdot
.30195 .75552 Mdot
.52079 .21375 Mdot
.29271 .73485 Mdot
.20292 .63441 Mdot
.24364 .37601 Mdot
.38005 .74328 Mdot
.52651 .18237 Mdot
.69274 .73306 Mdot
.4 .1986 Mdot
.55634 .3062 Mdot
.58183 .48669 Mdot
.21975 .34486 Mdot
.37651 .29851 Mdot
.65551 .23053 Mdot
.60469 .64009 Mdot
.29682 .46666 Mdot
.31802 .55801 Mdot
.37992 .47403 Mdot
.51235 .61371 Mdot
.20495 .56944 Mdot
.20047 .67265 Mdot
.41253 .26161 Mdot
.17769 .37551 Mdot
.3033 .29855 Mdot
.86281 .42503 Mdot
.6139 .68115 Mdot
.28478 .51501 Mdot
.62294 .476 Mdot
.63804 .76622 Mdot
.35984 .64617 Mdot
.25478 .53114 Mdot
.56381 .7722 Mdot
.69228 .35967 Mdot
.31977 .49971 Mdot
.53072 .2558 Mdot
.54974 .65772 Mdot
.37365 .68648 Mdot
.74906 .47319 Mdot
.20776 .623 Mdot
.49219 .54552 Mdot
.27572 .6134 Mdot
.53408 .69317 Mdot
.80118 .68496 Mdot
.62076 .32025 Mdot
.23108 .4668 Mdot
.49647 .66181 Mdot
.21545 .55212 Mdot
.82276 .49698 Mdot
.68131 .38778 Mdot
.64332 .76334 Mdot
.57074 .81798 Mdot
.19297 .46839 Mdot
.60442 .8239 Mdot
.26182 .4936 Mdot
.5254 .3225 Mdot
.28609 .42655 Mdot
.49372 .2165 Mdot
.67711 .43959 Mdot
.44466 .7963 Mdot
.6503 .47114 Mdot
.35386 .45046 Mdot
.79593 .58985 Mdot
.39681 .26619 Mdot
.52133 .19848 Mdot
.66343 .51821 Mdot
.54885 .32319 Mdot
.61114 .14042 Mdot
.38918 .80431 Mdot
.3377 .67408 Mdot
.19768 .69174 Mdot
.4429 .56713 Mdot
.57789 .24756 Mdot
.42668 .63316 Mdot
.36275 .80881 Mdot
.33015 .50093 Mdot
.51847 .86085 Mdot
.27919 .75383 Mdot
.73826 .30232 Mdot
.35979 .13855 Mdot
.63991 .74243 Mdot
.42202 .55258 Mdot
.44118 .46835 Mdot
.65291 .31373 Mdot
.78442 .36205 Mdot
.7009 .26741 Mdot
.45094 .74963 Mdot
.25005 .29472 Mdot
.36355 .80413 Mdot
.49046 .20955 Mdot
.39479 .18671 Mdot
.82778 .53004 Mdot
.53755 .4996 Mdot
.34065 .44327 Mdot
.53264 .63189 Mdot
.25547 .67404 Mdot
.50579 .82915 Mdot
.61967 .34183 Mdot
.41949 .14006 Mdot
.70277 .49401 Mdot
.74079 .55272 Mdot
.1836 .54001 Mdot
.70101 .34789 Mdot
.56988 .26169 Mdot
.7613 .65114 Mdot
.48352 .42801 Mdot
.74548 .6738 Mdot
.31225 .73379 Mdot
.49772 .67468 Mdot
.69994 .72247 Mdot
.26726 .6488 Mdot
.2268 .3686 Mdot
.33497 .40605 Mdot
.63148 .77436 Mdot
.3733 .47308 Mdot
.6732 .36556 Mdot
.58923 .27567 Mdot
.19225 .67188 Mdot
.51635 .65197 Mdot
.15867 .61507 Mdot
.78053 .60101 Mdot
.56373 .34338 Mdot
.58519 .41324 Mdot
.42922 .36923 Mdot
.6546 .3618 Mdot
.47558 .32612 Mdot
.38191 .67549 Mdot
.18472 .639 Mdot
.29432 .29875 Mdot
.47978 .69478 Mdot
.4682 .78052 Mdot
.1676 .51419 Mdot
.25817 .40794 Mdot
.77159 .5414 Mdot
.63809 .41327 Mdot
.83184 .60064 Mdot
.62282 .61479 Mdot
.48362 .20715 Mdot
.47862 .61149 Mdot
.76782 .47197 Mdot
.39525 .39127 Mdot
.77509 .36193 Mdot
.18408 .63774 Mdot
.73241 .65282 Mdot
.78945 .56609 Mdot
.71293 .33565 Mdot
.48799 .18053 Mdot
.46445 .78781 Mdot
.58207 .37939 Mdot
.24308 .539 Mdot
.64336 .48934 Mdot
.28427 .38014 Mdot
.43558 .20349 Mdot
.70774 .58059 Mdot
.46268 .32286 Mdot
.75956 .38487 Mdot
.67447 .65309 Mdot
.54299 .56721 Mdot
.67917 .80044 Mdot
.49476 .43735 Mdot
.59039 .77745 Mdot
.19126 .44743 Mdot
.64009 .3277 Mdot
.19054 .52895 Mdot
.25578 .61351 Mdot
.58839 .82504 Mdot
.25362 .73258 Mdot
.69714 .5571 Mdot
.43453 .8192 Mdot
.18765 .67497 Mdot
.62533 .80739 Mdot
.54541 .44482 Mdot
.42312 .6057 Mdot
.72037 .79571 Mdot
.62599 .58165 Mdot
.52664 .80076 Mdot
.37872 .22271 Mdot
.52262 .7433 Mdot
.27847 .53101 Mdot
.53377 .29134 Mdot
.45734 .53195 Mdot
.39028 .48309 Mdot
.48947 .31191 Mdot
.72163 .75542 Mdot
.60855 .80561 Mdot
.66578 .79497 Mdot
.18793 .40908 Mdot
.43634 .82423 Mdot
.41602 .53347 Mdot
.3852 .28599 Mdot
.39451 .51833 Mdot
.4668 .39556 Mdot
.72433 .49145 Mdot
.6404 .74049 Mdot
.76907 .39725 Mdot
.35362 .62568 Mdot
.37596 .46788 Mdot
.39847 .78055 Mdot
.91402 .51522 Mdot
.29727 .31648 Mdot
.42487 .2256 Mdot
.66784 .73768 Mdot
.64835 .36731 Mdot
.27868 .6973 Mdot
.75419 .33301 Mdot
.18106 .60653 Mdot
.38938 .52007 Mdot
.38361 .21277 Mdot
.7138 .6149 Mdot
.60099 .23359 Mdot
.68802 .64467 Mdot
.2222 .6799 Mdot
.41658 .47658 Mdot
.79311 .44981 Mdot
.31072 .57191 Mdot
.73903 .29694 Mdot
.75048 .516 Mdot
.55446 .70901 Mdot
.44392 .1964 Mdot
.43347 .72804 Mdot
.63834 .37485 Mdot
.46693 .51586 Mdot
.45016 .30828 Mdot
.4699 .47922 Mdot
.63386 .36369 Mdot
.61701 .24561 Mdot
.48723 .82272 Mdot
.19379 .70751 Mdot
.78982 .68075 Mdot
.1686 .3901 Mdot
.30943 .72552 Mdot
.45447 .3816 Mdot
.17136 .54799 Mdot
.61633 .82791 Mdot
.25722 .74328 Mdot
.63869 .69487 Mdot
.62142 .55314 Mdot
.44234 .67602 Mdot
.76613 .69876 Mdot
.68213 .65526 Mdot
.19176 .5856 Mdot
.75436 .67394 Mdot
.40285 .64994 Mdot
.83971 .4568 Mdot
.59851 .80357 Mdot
.40009 .36489 Mdot
.58535 .42816 Mdot
.46932 .41475 Mdot
.42431 .26225 Mdot
.35579 .45873 Mdot
.52164 .68536 Mdot
.66834 .37873 Mdot
.61485 .61731 Mdot
.73619 .48763 Mdot
.2479 .52792 Mdot
.49615 .30319 Mdot
.45765 .4685 Mdot
.2956 .46607 Mdot
.39166 .749 Mdot
.4298 .7058 Mdot
.47947 .83843 Mdot
.63644 .73238 Mdot
.44073 .35729 Mdot
.63564 .3275 Mdot
.68527 .67241 Mdot
.77452 .63928 Mdot
.48004 .63488 Mdot
.2822 .74027 Mdot
.57891 .50099 Mdot
.67119 .36683 Mdot
.43658 .25735 Mdot
.22913 .37632 Mdot
.56161 .32009 Mdot
.32884 .69464 Mdot
.34401 .37199 Mdot
.55304 .5503 Mdot
.34608 .4449 Mdot
.3398 .4421 Mdot
.15142 .50575 Mdot
.6932 .70041 Mdot
.52944 .69938 Mdot
.27158 .7292 Mdot
.45005 .65083 Mdot
.3419 .46396 Mdot
.71718 .49322 Mdot
.21839 .3819 Mdot
.36162 .3456 Mdot
.78301 .51976 Mdot
.5876 .74581 Mdot
.71869 .57172 Mdot
.28531 .73419 Mdot
.30731 .7545 Mdot
.69602 .23324 Mdot
.37434 .50059 Mdot
.22655 .40597 Mdot
.28851 .27626 Mdot
.32769 .45546 Mdot
.32516 .54957 Mdot
.36882 .63859 Mdot
.48834 .83107 Mdot
.39818 .62867 Mdot
.23932 .30259 Mdot
.63065 .26875 Mdot
.52669 .75717 Mdot
.79973 .50994 Mdot
.44953 .19198 Mdot
.26181 .71873 Mdot
.49504 .24671 Mdot
.40199 .4078 Mdot
.51035 .29376 Mdot
.58419 .44535 Mdot
.83395 .63404 Mdot
.55955 .57819 Mdot
.39885 .29341 Mdot
.25571 .63485 Mdot
.52794 .38446 Mdot
.78769 .6945 Mdot
.21197 .44732 Mdot
.79891 .61969 Mdot
.41614 .66513 Mdot
.53016 .40841 Mdot
.48061 .41437 Mdot
.62092 .4153 Mdot
.3267 .67141 Mdot
.5425 .81007 Mdot
.44219 .19152 Mdot
.27078 .66994 Mdot
.4665 .24161 Mdot
.58655 .77846 Mdot
.20312 .60226 Mdot
.20821 .48317 Mdot
.52927 .52658 Mdot
.64616 .73325 Mdot
.69567 .32655 Mdot
.17764 .38531 Mdot
.60483 .48119 Mdot
.40125 .54484 Mdot
.36966 .60144 Mdot
.29392 .65831 Mdot
.78767 .46684 Mdot
.48899 .40715 Mdot
.76847 .62425 Mdot
.20272 .62806 Mdot
.62414 .1994 Mdot
.80518 .41852 Mdot
.77321 .7096 Mdot
.36841 .38345 Mdot
.27634 .63965 Mdot
.22324 .50637 Mdot
.57427 .1665 Mdot
.5932 .47998 Mdot
.39285 .79248 Mdot
.7008 .32753 Mdot
.27821 .73145 Mdot
.43731 .5949 Mdot
.33813 .5767 Mdot
.47297 .78263 Mdot
.46179 .82195 Mdot
.27765 .41132 Mdot
.21924 .66671 Mdot
.43245 .55768 Mdot
.55867 .84253 Mdot
.41914 .73372 Mdot
.43948 .51909 Mdot
.58825 .64169 Mdot
.73081 .66206 Mdot
.29199 .72611 Mdot
.36091 .74612 Mdot
.44454 .19935 Mdot
.56255 .60374 Mdot
.72383 .45864 Mdot
.41679 .31678 Mdot
.72877 .38117 Mdot
.29334 .6677 Mdot
.63597 .32725 Mdot
.20449 .66202 Mdot
.61421 .47707 Mdot
.78036 .58822 Mdot
.58349 .77686 Mdot
.36562 .19455 Mdot
.33106 .66928 Mdot
.70525 .69274 Mdot
.22018 .48129 Mdot
.74175 .53564 Mdot
.55186 .23526 Mdot
.26948 .81335 Mdot
.34383 .22008 Mdot
.3994 .73982 Mdot
.50683 .82875 Mdot
.19105 .51974 Mdot
.40084 .75064 Mdot
.79065 .37223 Mdot
.5924 .30204 Mdot
.72704 .4376 Mdot
.50472 .35684 Mdot
.66725 .80335 Mdot
.70711 .37817 Mdot
.52602 .83429 Mdot
.16739 .53437 Mdot
.4229 .26941 Mdot
.49758 .30346 Mdot
.62121 .58447 Mdot
.53306 .65798 Mdot
.74062 .40847 Mdot
.39428 .43342 Mdot
.54762 .24943 Mdot
.60659 .73718 Mdot
.57541 .62103 Mdot
.69138 .64352 Mdot
.37504 .52492 Mdot
.63869 .7183 Mdot
.31244 .6761 Mdot
.674 .5326 Mdot
.51849 .54652 Mdot
.63728 .35896 Mdot
.57884 .29823 Mdot
.39847 .36405 Mdot
.77901 .37499 Mdot
.51384 .49854 Mdot
.59221 .623 Mdot
.38364 .40191 Mdot
.25926 .29022 Mdot
.29311 .68381 Mdot
.56255 .82079 Mdot
.75364 .64665 Mdot
.41186 .40798 Mdot
.63279 .37296 Mdot
.77395 .34575 Mdot
.57376 .20833 Mdot
.40439 .7686 Mdot
.58814 .33274 Mdot
.54464 .2168 Mdot
.2622 .55084 Mdot
.41243 .82695 Mdot
.3966 .20145 Mdot
.3397 .23655 Mdot
.54859 .63548 Mdot
.36561 .30846 Mdot
.4276 .27851 Mdot
.67081 .30617 Mdot
.51534 .56397 Mdot
.86544 .44649 Mdot
.27507 .48701 Mdot
.85342 .62544 Mdot
.43876 .60887 Mdot
.83524 .53706 Mdot
.68927 .30684 Mdot
.46586 .51254 Mdot
.50627 .5693 Mdot
.33676 .69791 Mdot
.33649 .59349 Mdot
.19349 .37875 Mdot
.68845 .24239 Mdot
.60261 .56922 Mdot
.44798 .18357 Mdot
.38382 .17851 Mdot
.37344 .4171 Mdot
.54166 .31944 Mdot
.33753 .22229 Mdot
.57516 .5762 Mdot
.77011 .39774 Mdot
.18144 .5192 Mdot
.33728 .72668 Mdot
.46627 .44332 Mdot
.65292 .36992 Mdot
.38353 .78768 Mdot
.25121 .72485 Mdot
.82062 .42023 Mdot
.31247 .73353 Mdot
.42191 .6076 Mdot
.426 .52511 Mdot
.23512 .67688 Mdot
.59733 .26267 Mdot
.27986 .60028 Mdot
.5796 .26258 Mdot
.87762 .54183 Mdot
.50875 .80279 Mdot
.54075 .80953 Mdot
.59416 .26941 Mdot
.33018 .52994 Mdot
.39851 .71655 Mdot
.57408 .26476 Mdot
.34515 .72491 Mdot
.21684 .35703 Mdot
.58368 .27095 Mdot
.66329 .198 Mdot
.26795 .32202 Mdot
.64967 .55654 Mdot
.43201 .28059 Mdot
.27355 .32244 Mdot
.40604 .65406 Mdot
.73665 .45379 Mdot
.25589 .64043 Mdot
.41213 .64365 Mdot
.29879 .67345 Mdot
.288 .63532 Mdot
.30324 .27611 Mdot
.37111 .34409 Mdot
.28311 .68719 Mdot
.33401 .42142 Mdot
.30013 .44066 Mdot
.77467 .44952 Mdot
.62216 .66341 Mdot
.23994 .62496 Mdot
.60775 .64922 Mdot
.5414 .28186 Mdot
.55831 .53994 Mdot
.42415 .4056 Mdot
.7831 .68078 Mdot
.64429 .48697 Mdot
.28989 .51536 Mdot
.84433 .53709 Mdot
.31276 .46057 Mdot
.69994 .77491 Mdot
.76489 .34924 Mdot
.43861 .25372 Mdot
.708 .54916 Mdot
.69502 .59677 Mdot
.78744 .30524 Mdot
.40596 .44871 Mdot
.54868 .64146 Mdot
.35348 .437 Mdot
.30479 .52328 Mdot
.59981 .76018 Mdot
.57868 .60062 Mdot
.61117 .37357 Mdot
.39487 .583 Mdot
.40753 .48292 Mdot
.36678 .51646 Mdot
.56803 .51798 Mdot
.68646 .41496 Mdot
.47979 .83023 Mdot
.59115 .60798 Mdot
.86333 .5422 Mdot
.54675 .30938 Mdot
.31919 .40048 Mdot
.17722 .60244 Mdot
.83246 .43895 Mdot
.63667 .5908 Mdot
.40259 .16169 Mdot
.5643 .36844 Mdot
.28671 .69743 Mdot
.3243 .50409 Mdot
.36163 .22345 Mdot
.6507 .49061 Mdot
.64425 .32223 Mdot
.45319 .67502 Mdot
.79331 .45356 Mdot
.62765 .71731 Mdot
.34085 .52879 Mdot
.33706 .73975 Mdot
.23353 .38421 Mdot
.30516 .58477 Mdot
.69104 .61312 Mdot
.3859 .41635 Mdot
.36808 .3384 Mdot
.36131 .52139 Mdot
.51649 .81326 Mdot
.36851 .21676 Mdot
.3931 .83276 Mdot
.43069 .36161 Mdot
.74515 .62135 Mdot
.37525 .58582 Mdot
.312 .6897 Mdot
.60182 .39378 Mdot
.18358 .62306 Mdot
.67965 .37938 Mdot
.37695 .60634 Mdot
.65206 .3903 Mdot
.51898 .27707 Mdot
.5074 .53842 Mdot
.55131 .68699 Mdot
.73564 .27087 Mdot
.59842 .4273 Mdot
.82765 .48688 Mdot
.58383 .32312 Mdot
.60323 .77126 Mdot
.32819 .54263 Mdot
.63725 .56303 Mdot
.37461 .30837 Mdot
.51587 .65539 Mdot
.39873 .82294 Mdot
.18193 .61691 Mdot
.44553 .68376 Mdot
.58584 .76504 Mdot
.22274 .56345 Mdot
.44248 .33457 Mdot
.40763 .56106 Mdot
.53167 .32759 Mdot
.32781 .54561 Mdot
.84188 .44878 Mdot
.33705 .71283 Mdot
.58338 .38423 Mdot
.39729 .81325 Mdot
.35216 .80132 Mdot
.54873 .84128 Mdot
.49713 .1868 Mdot
.35882 .50696 Mdot
.65451 .79402 Mdot
.53601 .24925 Mdot
.21127 .69168 Mdot
.39432 .7631 Mdot
.15327 .5192 Mdot
.39922 .41933 Mdot
.25107 .62119 Mdot
.70226 .26158 Mdot
.31525 .60782 Mdot
.19587 .4833 Mdot
.43388 .49321 Mdot
.51066 .70645 Mdot
.18893 .49223 Mdot
.67352 .18422 Mdot
.59811 .37327 Mdot
.27866 .62266 Mdot
.30273 .56153 Mdot
.24495 .63235 Mdot
.75796 .55255 Mdot
.46095 .36932 Mdot
.47331 .75212 Mdot
.79721 .53288 Mdot
.62966 .34424 Mdot
.72414 .46118 Mdot
.7564 .55232 Mdot
.74561 .43471 Mdot
.66604 .4015 Mdot
.40012 .19793 Mdot
.39605 .41361 Mdot
.60905 .38441 Mdot
.56349 .33901 Mdot
.31431 .54226 Mdot
.68864 .45519 Mdot
.66255 .60604 Mdot
.52376 .32835 Mdot
.60623 .55799 Mdot
.31455 .59098 Mdot
.75478 .72798 Mdot
.47294 .69732 Mdot
.20776 .42773 Mdot
.28386 .47186 Mdot
.3278 .67988 Mdot
.25567 .45255 Mdot
.81426 .56198 Mdot
.74239 .59877 Mdot
.61958 .34147 Mdot
.36338 .79226 Mdot
.69709 .72461 Mdot
.24394 .3441 Mdot
.68945 .74648 Mdot
.41355 .62409 Mdot
.48988 .44619 Mdot
.3432 .56394 Mdot
.68874 .67958 Mdot
.36992 .45241 Mdot
.25561 .62714 Mdot
.5665 .65571 Mdot
.70052 .70589 Mdot
.19007 .45178 Mdot
.23231 .37839 Mdot
.41634 .33057 Mdot
.31844 .76418 Mdot
.60091 .58017 Mdot
.34277 .22917 Mdot
.2725 .59109 Mdot
.73652 .61866 Mdot
.58509 .79142 Mdot
.45617 .83617 Mdot
.46516 .56218 Mdot
.68673 .34648 Mdot
.52241 .39783 Mdot
.40548 .23566 Mdot
.34227 .71082 Mdot
.52695 .46647 Mdot
.59776 .72113 Mdot
.30445 .47586 Mdot
.57895 .70714 Mdot
.59166 .4699 Mdot
.72802 .43183 Mdot
.38741 .48284 Mdot
.4972 .21949 Mdot
.69564 .45142 Mdot
.43607 .57392 Mdot
.48696 .31549 Mdot
.67214 .33575 Mdot
.52009 .19563 Mdot
.47905 .43966 Mdot
.28493 .71138 Mdot
.39121 .40594 Mdot
.22834 .35945 Mdot
.30874 .70379 Mdot
.41277 .77217 Mdot
.33417 .59873 Mdot
.3853 .3128 Mdot
.65195 .68742 Mdot
.51583 .3186 Mdot
.63615 .56519 Mdot
.32361 .46317 Mdot
.20733 .56299 Mdot
.36345 .37962 Mdot
.6775 .32012 Mdot
.48425 .50856 Mdot
.27189 .44018 Mdot
.47536 .49354 Mdot
.17367 .56422 Mdot
.31642 .60919 Mdot
.67156 .38157 Mdot
.43619 .58934 Mdot
.68782 .30788 Mdot
.78541 .37483 Mdot
.31152 .77547 Mdot
.75956 .32695 Mdot
.4658 .54868 Mdot
.83076 .4809 Mdot
.40019 .72995 Mdot
.17894 .5135 Mdot
.67658 .39285 Mdot
.48123 .56843 Mdot
.71916 .47615 Mdot
.46035 .6843 Mdot
.52764 .50949 Mdot
.62344 .53685 Mdot
.59312 .31545 Mdot
.55657 .73365 Mdot
.56821 .67246 Mdot
.5224 .2903 Mdot
.52958 .79684 Mdot
.34486 .78036 Mdot
.36914 .22368 Mdot
.48772 .48748 Mdot
.75178 .48797 Mdot
.72582 .42043 Mdot
.1489 .39869 Mdot
.80616 .68156 Mdot
.52416 .3964 Mdot
.49727 .48761 Mdot
.66983 .34959 Mdot
.61194 .57067 Mdot
.5662 .27051 Mdot
.27808 .44316 Mdot
.45934 .61016 Mdot
.61466 .53986 Mdot
.714 .6953 Mdot
.34396 .70075 Mdot
.72451 .36481 Mdot
.49005 .77478 Mdot
.74909 .73695 Mdot
.22491 .33149 Mdot
.32183 .69839 Mdot
.13449 .45602 Mdot
.57848 .6846 Mdot
.30226 .44812 Mdot
.27552 .43103 Mdot
.49316 .82624 Mdot
.63305 .31793 Mdot
.78147 .47906 Mdot
.44195 .78047 Mdot
.68042 .38604 Mdot
.5491 .24095 Mdot
.58782 .77549 Mdot
.58651 .71134 Mdot
.46775 .52738 Mdot
.69639 .59834 Mdot
.64569 .77745 Mdot
.46855 .24565 Mdot
.36012 .78201 Mdot
.80018 .52986 Mdot
.63332 .17856 Mdot
.36554 .81112 Mdot
.72958 .48889 Mdot
.76418 .54429 Mdot
.27561 .42807 Mdot
.61506 .26424 Mdot
.53234 .23498 Mdot
.78078 .41346 Mdot
.35205 .34398 Mdot
.67768 .57563 Mdot
.81768 .51095 Mdot
.63761 .37368 Mdot
.28044 .31216 Mdot
.4837 .56823 Mdot
.39163 .37887 Mdot
.61157 .74606 Mdot
.60515 .28722 Mdot
.59313 .51548 Mdot
.64195 .28909 Mdot
.38214 .40834 Mdot
.22492 .48124 Mdot
.24812 .5873 Mdot
.71107 .21937 Mdot
.41702 .78347 Mdot
.81642 .55426 Mdot
.46176 .33724 Mdot
.42876 .8408 Mdot
.25807 .59369 Mdot
.43625 .78318 Mdot
.19835 .40969 Mdot
.65177 .57037 Mdot
.38785 .57293 Mdot
.51409 .31851 Mdot
.34892 .75855 Mdot
.40167 .29445 Mdot
.26858 .33791 Mdot
.79937 .47526 Mdot
.643 .33999 Mdot
.7749 .54501 Mdot
.65905 .28958 Mdot
.45162 .4248 Mdot
.29312 .47676 Mdot
.65419 .80233 Mdot
.44379 .55225 Mdot
.55739 .29301 Mdot
.5304 .46076 Mdot
.71048 .26816 Mdot
.28188 .25113 Mdot
.42989 .37472 Mdot
.67652 .74065 Mdot
.51561 .21839 Mdot
.42494 .33505 Mdot
.54495 .26985 Mdot
.22432 .23817 Mdot
.19693 .70394 Mdot
.36413 .50739 Mdot
.43837 .21385 Mdot
.52656 .21212 Mdot
.48422 .8242 Mdot
.71616 .61237 Mdot
.66588 .64657 Mdot
.65452 .23657 Mdot
.59443 .24537 Mdot
.55802 .32811 Mdot
.19219 .43697 Mdot
.2935 .76152 Mdot
.80532 .48359 Mdot
.38833 .81124 Mdot
.589 .35764 Mdot
.57441 .40016 Mdot
.18531 .30741 Mdot
.24265 .68817 Mdot
.48098 .42548 Mdot
.71119 .26531 Mdot
.33486 .44299 Mdot
.52298 .35549 Mdot
.50605 .78278 Mdot
.43698 .1949 Mdot
.63613 .37655 Mdot
.46336 .82219 Mdot
.38327 .48099 Mdot
.52796 .62166 Mdot
.46174 .60922 Mdot
.50959 .56767 Mdot
.56635 .38708 Mdot
.43123 .64551 Mdot
.42259 .34485 Mdot
.24025 .61191 Mdot
.41026 .66623 Mdot
.40977 .18464 Mdot
.15306 .58636 Mdot
.3782 .3728 Mdot
.48864 .65666 Mdot
.4433 .32883 Mdot
.26589 .32842 Mdot
.7423 .41677 Mdot
.39058 .5322 Mdot
.18113 .49598 Mdot
.38108 .8667 Mdot
.51975 .71041 Mdot
.68069 .42364 Mdot
.38877 .47647 Mdot
.60766 .38245 Mdot
.40707 .32975 Mdot
.41552 .58459 Mdot
.60131 .58578 Mdot
.45383 .32561 Mdot
.44855 .41971 Mdot
.43482 .67225 Mdot
.84997 .62136 Mdot
.46661 .3839 Mdot
.56266 .28347 Mdot
.21551 .69396 Mdot
.77546 .45117 Mdot
.30239 .39791 Mdot
.53609 .4201 Mdot
.38175 .68824 Mdot
.48002 .56876 Mdot
.22705 .62837 Mdot
.77779 .59416 Mdot
.42582 .81238 Mdot
.36076 .37871 Mdot
.4327 .29019 Mdot
.47194 .35171 Mdot
.66534 .44504 Mdot
.28816 .62171 Mdot
.46589 .79763 Mdot
.59044 .389 Mdot
.23682 .71911 Mdot
.65319 .57056 Mdot
.57318 .74467 Mdot
.43268 .31937 Mdot
.57116 .83129 Mdot
.81886 .46238 Mdot
.41529 .29037 Mdot
.81369 .59171 Mdot
.69078 .6895 Mdot
.72671 .38038 Mdot
.61791 .58317 Mdot
.57695 .33155 Mdot
.38247 .4864 Mdot
.74838 .74302 Mdot
.47262 .79988 Mdot
.46822 .73387 Mdot
.55501 .71133 Mdot
.3898 .25272 Mdot
.28211 .57488 Mdot
.14193 .51129 Mdot
.69842 .64703 Mdot
.76081 .72601 Mdot
.34017 .23469 Mdot
.39522 .4892 Mdot
.27497 .64533 Mdot
.50707 .44507 Mdot
.59596 .6206 Mdot
.4579 .81309 Mdot
.44416 .40589 Mdot
.79633 .57844 Mdot
.5445 .40914 Mdot
.78781 .63777 Mdot
.58855 .54278 Mdot
.55841 .78091 Mdot
.43852 .73085 Mdot
.79148 .37736 Mdot
.19721 .56649 Mdot
.42283 .69161 Mdot
.14391 .46126 Mdot
.20841 .57995 Mdot
.28331 .74219 Mdot
.7817 .51171 Mdot
.81429 .38288 Mdot
.36932 .74982 Mdot
.28627 .68746 Mdot
.45117 .71814 Mdot
.42638 .44941 Mdot
.72852 .66036 Mdot
.43196 .32693 Mdot
.3033 .63057 Mdot
.44381 .6859 Mdot
.51874 .92377 Mdot
.69412 .51309 Mdot
.25755 .49004 Mdot
.70894 .66407 Mdot
.32444 .77488 Mdot
.45192 .45122 Mdot
.18396 .46699 Mdot
.58244 .48708 Mdot
.58194 .37313 Mdot
.36371 .35619 Mdot
.39128 .2168 Mdot
.73948 .66021 Mdot
.81967 .34033 Mdot
.2247 .33506 Mdot
.56015 .72553 Mdot
.52522 .53846 Mdot
.33433 .4555 Mdot
.27489 .52625 Mdot
.70369 .57085 Mdot
.17184 .44298 Mdot
.24726 .618 Mdot
.23607 .67846 Mdot
.77639 .29384 Mdot
.26988 .30195 Mdot
.48882 .82792 Mdot
.38121 .72817 Mdot
.27736 .5194 Mdot
.73705 .48091 Mdot
.66841 .54193 Mdot
.45646 .73978 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`2Jooooo`;o0000[Oooool001cooooo00?o0000oooo
ooooool0VOooool3o`000:gooooo000Looooo`03o`000?oooooooooo09Wooooo0_l0002^ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0LOooool2o`0001;ooooo0_l0000looooo`;o0000Q?ooool0
01cooooo00?o0000ooooooooool0LOooool2o`0000Gooooo0_l0000;ooooo`;o00001oooool2o`00
03?ooooo0_l00024ooooo`007?ooool00ol0003oooooooooo`1hooooo`;o00002oooool2o`0000Oo
oooo0_l0002iooooo`007?ooool00ol0003oooooooooo`2=ooooo`;o0000^_ooool001cooooo0_l0
002>ooooo`;o0000^_ooool001cooooo00?o0000ooooooooool0V_ooool2o`0000cooooo0_l0002O
ooooo`007?ooool00ol0003oooooooooo`2;ooooo`;o00003Oooool2o`0000_ooooo0ol0002Ooooo
o`007?ooool00ol0003oooooooooo`1oooooo`;o00002_ooool2o`0001;ooooo0_l00006ooooo`;o
0000X?ooool001cooooo00?o0000ooooooooool0LOooool2o`0000Kooooo0_l00004ooooo`;o0000
2?ooool2o`0000Gooooo0_l0000=ooooo`;o00009?ooool2o`0008;ooooo000Looooo`03o`000?oo
oooooooo077ooooo0_l00006ooooo`;o00001?ooool2o`0000?ooooo0_l00003ooooo`;o00001Ooo
ool2o`0000Oooooo0_l0000Cooooo`;o00001oooool2o`0000cooooo0_l00022ooooo`007?ooool0
0ol0003oooooooooo`24ooooo`;o00004oooool2o`0000Kooooo0_l0000;ooooo`;o00001oooool2
o`00093ooooo000Looooo`03o`000?oooooooooo0:7ooooo0_l0002Vooooo`007?ooool00ol0003o
ooooooooo`2>ooooo`;o0000^Oooool001cooooo00?o0000ooooooooool0NOooool2o`000003oooo
ool0003o0000013ooooo0_l00003ooooo`;o00001_ooool2o`0002gooooo0_l0001mooooo`007?oo
ool00ol0003oooooooooo`1iooooo`;o000000?oooooo`000?l000000oooool2o`0000_ooooo0_l0
0003ooooo`;o00001_ooool2o`0000Kooooo0_l00002ooooo`;o00008Oooool2o`0000_ooooo0_l0
001`ooooo`007?ooool00ol0003oooooooooo`1mooooo`;o00000_ooool2o`0000_ooooo1?l00000
0ooooooo0000o`000003ooooo`;o00001?ooool2o`0000?ooooo0_l00002ooooo`;o0000;_ooool2
o`00073ooooo000Looooo`03o`000?oooooooooo07gooooo0_l0000Aooooo`;o000000?oooooo`00
0?l000000_ooool3o`0000Cooooo1?l00007ooooo`;o00004oooool2o`0008Wooooo00001_oooooo
k^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`2<
ooooo`Co00001oooool2o`0000;ooooo0_l00003ooooo`;o00001oooool2o`0000gooooo0_l00004
ooooo`?o0000R?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo06Cooooo0_l0000=ooooo`;o0000
2_ooool2o`0000Wooooo1_l0000;ooooo`;o00002?ooool2o`0000Cooooo0_l0000;ooooo`;o0000
1Oooool2o`000003ooooool0003o000008Gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oo
oooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`1Tooooo`;o00002_oo
ool2o`000003ooooool0003o000000Wooooo0ol00009ooooo`Go000000?oooooo`000?l000004ooo
ool3o`0000?ooooo0_l0000Booooo`;o000000?oooooo`000?l000000oooool2o`0000_ooooo0_l0
001cooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7o
k^k^00Kooooo0ol0001`ooooo`;o00002oooool3o`0000gooooo0_l000000ooooooo0000o`00000A
ooooo`Go00002?ooool2o`0000Cooooo0_l0000?ooooo`;o00002oooool2o`0007?ooooo00000ooo
oooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0
003oooooooooo`1eooooo`;o00001_ooool2o`0000_ooooo0_l0000Gooooo`Ko00000_ooool2o`00
00?ooooo0_l00002ooooo`Co0000TOooool00003ooooool@413ooooo00;ooooo00?o410@oooooooo
ool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07Gooooo0_l0000Cooooo`;o
00001?ooool2o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`;o00000_ooool7o`0000;o
oooo0_l00007ooooo`;o000000?oooooo`000?l000008_ooool2o`0006cooooo00001_ooooooMgMg
oiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooo
oooo077ooooo0_l0000Fooooo`;o00001Oooool2o`0000Cooooo0_l000001?oooooo0000o`000?oo
ool4o`0000;ooooo0_l000000ooooooo0000o`000002o`0000Kooooo1?l00004ooooo`;o00003_oo
ool2o`0000?ooooo0_l0000=ooooo`;o0000K?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^
2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0LOooool2o`0000Ko
oooo0_l0000:ooooo`;o00000_ooool4o`0000Cooooo1?l00007ooooo`;o00001oooool4o`0000Ko
oooo1?l00004ooooo`;o00003_ooool2o`0000?ooooo0_l0000:ooooo`;o0000Koooool001cooooo
00?o0000ooooooooool0M?ooool2o`0000?ooooo1?l00008ooooo`;o00001?ooool2o`0000Cooooo
1?l00008ooooo`;o00000_ooool2o`000004ooooool0003o0000o`0000Kooooo1?l00008ooooo`;o
00007Oooool2o`0006oooooo000Looooo`03o`000?oooooooooo06cooooo0_l00004ooooo`Co0000
1Oooool2o`0000Sooooo0_l0000Fooooo`?o000000Coooooo`000?l0003ooooo0_l00007ooooo`Co
00002?ooool2o`0000Sooooo0_l000000ooooooo0000o`00000Kooooo`;o0000I?ooool001cooooo
00?o0000ooooooooool0I?ooool2o`0000Cooooo1?l00004ooooo`Co000000?oooooo`000?l00000
7Oooool2o`0000Kooooo0_l0000=ooooo`;o00005?ooool2o`000003ooooool0003o000000Cooooo
0_l000000ooooooo0000o`00000Booooo`;o0000I?ooool001cooooo00?o0000ooooooooool0EOoo
ool2o`0000gooooo0_l00004ooooo`?o00001Oooool4o`000003ooooool0003o000000;o00002ooo
ool2o`0000kooooo0_l0000Nooooo`;o00005?ooool2o`000003ooooool0003o000000;ooooo0_l0
001dooooo`007?ooool00ol0003oooooooooo`1Eooooo`;o00002oooool2o`0000Sooooo0_l0000;
ooooo`;o00002oooool2o`0001?ooooo0_l00008ooooo`;o00003oooool4o`0001Oooooo1?l0000<
ooooo`?o0000IOooool001cooooo00?o0000ooooooooool0H_ooool2o`0000Gooooo0_l000000ooo
oooo0000o`00000Eooooo`Co00004Oooool2o`000003ooooool0003o000000Gooooo0_l000000ooo
oooo0000o`00000Aooooo`;o000000?oooooo`000?l000000_ooool5o`0000gooooo0_l0000;oooo
o`;o000000Coooooo`000?l0003o0000IOooool001cooooo00?o0000ooooooooool0JOooool4o`00
00kooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l00007ooooo`;o00002?ooool2o`00
00Sooooo0_l00005ooooo`;o000000Coooooo`000?l0003ooooo0_l00009ooooo`Co000000?ooooo
o`000?l000000ol0000<ooooo`?o00002oooool2o`0006Wooooo000Looooo`03o`000?oooooooooo
04Gooooo0_l0000Tooooo`;o00003_ooool2o`0000?ooooo1?l0000:ooooo`;o00005oooool4o`00
0004ooooool0003o0000ooooo`Co00001oooool5o`0000_ooooo0_l00004ooooo`?o0000M_ooool0
01cooooo00?o0000ooooooooool0AOooool2o`0001_ooooo0ol0000Dooooo`;o00001oooool2o`00
00;ooooo0_l00005ooooo`;o00000_ooool2o`000003ooooool0003o000000Oooooo0_l00008oooo
o`;o00000oooool2o`000003ooooool0003o000000?o00002Oooool2o`0000_ooooo0_l0000;oooo
o`;o00000oooool2o`0006_ooooo000Looooo`03o`000?oooooooooo06;ooooo1?l0000Cooooo`;o
000000?oooooo`000?l000000_ooool2o`0000?ooooo1Ol00003ooooo`;o00000_ooool2o`000003
ooooool0003o000000Oooooo0_l0000@ooooo`;o000000?oooooo`000?l000001?ooool2o`0000?o
oooo0_l00006ooooo`;o00004?ooool2o`0000?ooooo0_l0001[ooooo`007?ooool00ol0003ooooo
ooooo`1Tooooo`;o00005_ooool2o`0000;ooooo1?l000001?oooooo0000o`000?ooool2o`0000[o
oooo0_l00007ooooo`;o00002?ooool2o`000003ooooool0003o000000?ooooo0_l00007ooooo`;o
00000oooool2o`0000Kooooo0_l00022ooooo`007?ooool2o`0005Wooooo0_l00004ooooo`;o0000
5?ooool2o`0000cooooo0_l0000Iooooo`;o00002?ooool2o`000003ooooool0003o000000;ooooo
0_l00008ooooo`;o0000:?ooool3o`0006Cooooo000Looooo`03o`000?oooooooooo05Sooooo0_l0
0004ooooo`;o000000?oooooo`000?l000004Oooool2o`0000Gooooo0_l00009ooooo`?o00000_oo
ool2o`0001gooooo0_l00002ooooo`;o00002?ooool2o`000003ooooool0003o000000Gooooo0_l0
000Nooooo`?o00000oooool2o`000003ooooool0003o000005cooooo000Looooo`03o`000?oooooo
oooo04_ooooo0_l0000;ooooo`;o00001?ooool2o`000003ooooool0003o000001Sooooo0_l00009
ooooo`?o000000Coooooo`000?l0003o00004?ooool2o`0000;ooooo0_l00006ooooo`Co00002ooo
ool2o`000003ooooool0003o000000Gooooo0_l000000ooooooo0000o`00000Qooooo`;o000000?o
ooooo`000?l00000G?ooool001cooooo00?o0000ooooooooool0Boooool2o`0000_ooooo0_l00004
ooooo`;o000000?oooooo`000?l000004?ooool2o`0000gooooo0_l00002ooooo`;o00000_ooool2
o`00017ooooo0_l00002ooooo`;o00001_ooool6o`0000cooooo0ol00004ooooo`;o000000?ooooo
o`000?l000001Oooool2o`0001;ooooo0_l0001Wooooo`007?ooool00ol0003oooooooooo`1Eoooo
o`;o00002_ooool2o`00013ooooo0_l0000=ooooo`;o00000_ooool2o`0000Gooooo0_l0000Doooo
o`;o00002?ooool2o`0000Kooooo0_l000000ooooooo0000o`000002ooooo`Co00001?ooool2o`00
00Kooooo0_l0000Booooo`?o000000?oooooo`000?l00000Hoooool001cooooo00?o0000oooooooo
ool0EOooool2o`0001;ooooo0_l0000=ooooo`;o00000oooool3o`0000Kooooo0_l00005ooooo`;o
00003Oooool5o`0000;ooooo0_l0000@ooooo`Go00001?ooool2o`0000Cooooo0_l00003ooooo`;o
00005Oooool6o`0006?ooooo000Looooo`03o`000?oooooooooo06Wooooo0_l0000=ooooo`?o0000
0_ooool3o`000003ooooool0003o000000?ooooo0_l00004ooooo`?o00003Oooool5o`0000;ooooo
0ol00003ooooo`;o000000Coooooo`000?l0003o00001Oooool2o`000003ooooool0003o000000;o
oooo1?l00005ooooo`;o00000oooool2o`0000Gooooo0_l00002ooooo`;o00002_ooool5o`0000Ko
oooo0_l0001Looooo`007?ooool00ol0003oooooooooo`1iooooo`;o00001_ooool2o`0000?ooooo
0_l00004ooooo`Co00004Oooool2o`000004ooooool0003o0000o`0000;ooooo0_l000001?oooooo
0000o`000?l00005ooooo`;o00001?ooool5o`0000Sooooo1?l00005ooooo`;o00000_ooool2o`00
00cooooo0ol00006ooooo`;o0000G?ooool001cooooo00?o0000ooooooooool0Eoooool2o`000004
ooooool0003o0000o`0000;ooooo1?l0000[ooooo`;o00003?ooool2o`0000?ooooo0_l00002oooo
o`Co00002Oooool2o`0000Kooooo1Ol00008ooooo`Ko00001_ooool2o`000003ooooool0003o0000
077ooooo000Looooo`03o`000?oooooooooo05Oooooo1_l00002ooooo`Co00005_ooool2o`0000co
oooo0_l0000:ooooo`Co00001Oooool2o`000003ooooool0003o000000Cooooo1_l00007ooooo`;o
00002?ooool2o`000003ooooool0003o000000[ooooo0_l00006ooooo`;o000000?oooooo`000?l0
0000LOooool001cooooo00?o0000ooooooooool0A?ooool2o`0000gooooo0_l00003ooooo`;o0000
7oooool2o`0000cooooo1?l00008ooooo`Co00000_ooool4o`0000;ooooo0_l00004ooooo`;o0000
0_ooool2o`000003ooooool0003o0000017ooooo0_l00006ooooo`;o00002_ooool2o`0000_ooooo
0_l0000;ooooo`;o0000F_ooool001cooooo00?o0000ooooooooool0A?ooool2o`0000[ooooo0_l0
00000ooooooo0000o`000009ooooo`?o00006?ooool2o`0000kooooo0_l00008ooooo`;o00001?oo
ool4o`0000;ooooo0_l0000:ooooo`?o00000oooool4o`000003ooooool0003o000000cooooo0_l0
00000ooooooo0000o`00000@ooooo`;o00001Oooool2o`0000_ooooo0_l0001Jooooo`007?ooool0
0ol0003oooooooooo`1@ooooo`;o00003?ooool3o`0001Sooooo0_l0000Hooooo`;o000000?ooooo
o`000?l000001oooool2o`0000Sooooo1_l00002ooooo`Co000000?oooooo`000?l000000_l00007
ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l00006ooooo`;o00000_ooool2
o`0000_ooooo0_l0001Qooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00000_ooool2o`00
00_ooooo0ol0000Rooooo`;o00001?ooool2o`0000[ooooo0ol0000:ooooo`;o00000_ooool2o`00
0005ooooool0003o0000o`000?ooool00_l00009ooooo`;o00001oooool2o`0000Cooooo0ol00003
ooooo`Co000000Coooooo`000?l0003ooooo0_l0000?ooooo`;o00001Oooool2o`0005[ooooo000L
ooooo`03o`000?oooooooooo04gooooo0ol000000ooooooo0000o`000003ooooo`;o00001Oooool2
o`0001gooooo1Ol00002ooooo`;o00001?ooool2o`0000;ooooo0_l00006ooooo`Oo00001_ooool2
o`000003ooooool0003o000000;o000000?oooooo`000?l000001Oooool2o`00017ooooo0_l00000
0ooooooo0000o`000008o`000003ooooool0003o000000;ooooo0_l0000Eooooo`;o00002Oooool2
o`0004oooooo000Looooo`03o`000?oooooooooo04kooooo0ol00005ooooo`;o00000oooool6o`00
01Kooooo0_l00003ooooo`Go00003?ooool2o`0000;ooooo0_l00003ooooo`Ko00001?ooool9o`00
0003ooooool0003o000000Gooooo0_l00005ooooo`;o00001_ooool2o`0000;ooooo0_l00003oooo
o`Ko00001oooool2o`0001Cooooo0_l0000:ooooo`;o0000Coooool001cooooo0_l0001?ooooo`Co
00000oooool3o`0000?ooooo0ol000000ooooooo0000o`00000Fooooo`;o00001?ooool2o`0001;o
oooo0_l0000;ooooo`Co000000Goooooo`000?l0003o0000ooooo`02o`000003ooooool0003o0000
00?ooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000?ooooo0_l00000
0ooooooo0000o`00000Fooooo`?o00004Oooool3o`0005[ooooo000Looooo`03o`000?oooooooooo
04[ooooo0_l00002ooooo`Co00000_ooool3o`0000Gooooo0_l0000kooooo`;o000000?oooooo`00
0?l000000ol00006ooooo`Go000000?oooooo`000?l000000_l000001?oooooo0000o`000?ooool2
o`0000Kooooo0_l0000Iooooo`?o00004Oooool5o`0000[ooooo0_l0001<ooooo`007?ooool00ol0
003oooooooooo`0hooooo`;o00004?ooool2o`0000Sooooo0_l0000[ooooo`?o00001Oooool2o`00
00cooooo1?l000000ooooooo0000o`000003o`0000Oooooo0_l000000ooooooo0000o`000003o`00
0003ooooool0003o000000;ooooo0_l00006ooooo`;o00005oooool4o`0000;ooooo0_l0000>oooo
o`;o000000Coooooo`000?l0003ooooo0_l00007ooooo`?o0000Boooool001cooooo00?o0000oooo
ooooool0>?ooool2o`0003Wooooo0_l000000ooooooo0000o`000009ooooo`?o00001Oooool2o`00
00?ooooo0_l000000ooooooo0000o`000002ooooo`Oo00000_ooool3o`0000?ooooo0_l00004oooo
o`Ko000000?oooooo`000?l000001?l0000=ooooo`;o00001Oooool2o`0000Wooooo0_l00003oooo
o`?o00005?ooool2o`0000Sooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`1Gooooo`;o
00006_ooool2o`000004ooooool0003o0000ooooo`;o00003_ooool2o`0000?ooooo0_l000000ooo
oooo0000o`000002ooooo`So00000_ooool4o`000003ooooool0003o000000Cooooo0ol000000ooo
oooo0000o`000003ooooo`;o00001_ooool2o`0000Kooooo0ol00005ooooo`;o000000?oooooo`00
0?l000000_l00009ooooo`?o00005oooool2o`0005;ooooo000Looooo`03o`000?oooooooooo04;o
oooo0_l0000Aooooo`Co00001?ooool2o`0001[ooooo0_l00003ooooo`;o00001?ooool2o`0000?o
oooo0_l0000;ooooo`;o00000_ooool4o`0000;ooooo1ol00004ooooo`;o000000?oooooo`000?l0
00000oooool2o`0000Kooooo1?l00004ooooo`;o00002Oooool4o`0000Gooooo0_l00002ooooo`;o
00006?ooool2o`0005;ooooo000Looooo`03o`000?oooooooooo04;ooooo0_l0000Aooooo`;o0000
1_ooool2o`0001Wooooo0_l00004ooooo`;o00001?ooool2o`0000;ooooo0ol0000;ooooo`;o0000
0_ooool5o`000003ooooool0003o000000So00000_ooool4o`0000?ooooo0_l00008ooooo`;o0000
2oooool2o`0000_ooooo0ol000000ooooooo0000o`00001/ooooo`007?ooool00ol0003ooooooooo
o`1Cooooo`Co00008Oooool2o`0000kooooo0ol00003ooooo`;o000000?oooooo`000?l000001Ol0
00001?oooooo0000o`000?ooool>o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`?o0000
1?ooool2o`0000[ooooo0_l00002ooooo`;o000000?oooooo`000?l000002Oooool2o`0000?ooooo
0_l0001Zooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00001Oooool4o`0000Gooooo0_l0
000Mooooo`;o00000_ooool2o`0000gooooo3Ol000000ooooooo0000o`00000Co`0000;ooooo1?l0
0003ooooo`Co00002?ooool2o`0000?ooooo1?l0000<ooooo`Co0000J_ooool001cooooo00?o0000
ooooooooool0C?ooool2o`0000Gooooo0_l000000ooooooo0000o`000004ooooo`;o00007Oooool2
o`0000;ooooo0_l00008ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000;ooooo8ol0
0005ooooo`Co00002oooool3o`0000;ooooo0_l00009ooooo`Oo00004Oooool2o`0005Cooooo000L
ooooo`03o`000?oooooooooo04Gooooo0_l0000<ooooo`;o000000?oooooo`000?l000006?ooool2
o`0000kooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000Go00001?oo
ool4o`000003ooooool0003o000001Go000000Coooooo`000?l0003ooooo0_l000000ooooooo0000
o`000003o`0000;ooooo0_l0000;ooooo`?o00000_ooool2o`000003ooooool0003o000000Cooooo
0_l00002ooooo`Go00004Oooool2o`0005Cooooo000Looooo`03o`000?oooooooooo04Gooooo0_l0
000Yooooo`;o00003_ooool2o`000003ooooool0003o000000?o00000_ooool9o`000003ooooool0
003o000002Oo00005_ooool2o`0000Cooooo0_l0000Fooooo`Co0000E?ooool001cooooo00?o0000
ooooooooool0AOooool2o`0000gooooo0_l00004ooooo`;o00006?ooool2o`0000_ooooo0_l00002
ooooo`?o00001?ooool3o`000003ooooool0003o000000;o000000?oooooo`000?l000008?l00004
ooooo`;o000000Coooooo`000?l0003o00000oooool6o`0000gooooo0_l00007ooooo`;o00000_oo
ool2o`0000_ooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o00001oooool2
o`0000Cooooo0_l0000Hooooo`;o00001_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2
o`0000?ooooo:_l00005ooooo`?o00000oooool6o`0000?ooooo1?l00006ooooo`;o00001oooool2
o`0000;ooooo0_l0000<ooooo`;o00000_ooool2o`0000_ooooo0_l000000ooooooo0000o`000011
ooooo`007?ooool00ol0003oooooooooo`1;ooooo`?o00008Oooool2o`0000Cooooo0_l00005oooo
o`;o00001oooool2o`0000?ooooo0_l00003ooooob[o000000Coooooo`000?l0003o00002?ooool3
o`000003ooooool0003o000000;ooooo1?l00006ooooo`;o00002?ooool2o`0000oooooo0_l00002
ooooo`;o00002oooool2o`000003ooooool0003o0000047ooooo000Looooo`03o`000?oooooooooo
043ooooo0_l00002ooooo`;o00001?ooool4o`0000Gooooo0_l00006ooooo`;o00004_ooool2o`00
0003ooooool0003o000000?o00003oooool2o`0000Gooooo;?l000001?oooooo0000o`000?l00009
ooooo`;o000000?oooooo`000?l000004?ooool2o`0000?ooooo1?l0000Dooooo`;o0000Coooool0
01cooooo0_l0000nooooo`Go00000_ooool2o`0000Cooooo0ol00006ooooo`;o00001_ooool2o`00
01?ooooo1Ol0000Aooooo`;o00001Oooool2o`000004ooooool0003o0000ooooob;o00000_ooool2
o`0001gooooo0_l00003ooooo`;o00000oooool6o`0000oooooo0_l000000ooooooo0000o`00001?
ooooo`007?ooool00ol0003oooooooooo`0mooooo`?o00002oooool2o`0000Kooooo0_l0000Koooo
o`;o00001_ooool5o`0000oooooo0_l00002ooooobGo00000_ooool2o`0000;ooooo0_l0000Ioooo
o`;o00003?ooool2o`0000oooooo0_l00007ooooo`;o0000BOooool001cooooo00?o0000oooooooo
ool0?Oooool2o`0000Cooooo0_l00002ooooo`;o0000:Oooool2o`0000?ooooo1_l0000?ooooo`;o
000000?oooooo`000?l000004_l000000ooooooo0000o`00000@o`000003ooooool0003o000000;o
oooo0_l0000<ooooo`;o00009oooool3o`0000Wooooo0_l00019ooooo`007?ooool00ol0003ooooo
ooooo`0eooooo`;o00001_ooool2o`0000Cooooo0_l000001?oooooo0000o`000?l0000;ooooo`;o
00000oooool2o`0001Oooooo0_l00003ooooo`;o00003oooool2o`000003ooooool0003o000000Oo
000000?oooooo`000?l000007ol00004ooooo`Co00002oooool4o`0000Wooooo0_l00005ooooo`;o
00004oooool3o`0000?ooooo0ol00002ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0
=Oooool2o`0000oooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00003ooooo`;o0000
;Oooool2o`000003ooooool0003o000002[o00000oooool4o`0000gooooo0_l00004ooooo`;o0000
0oooool2o`0000Gooooo0_l00003ooooo`;o00005?ooool7o`0004[ooooo000Looooo`03o`000?oo
oooooooo03[ooooo0_l0000?ooooo`;o000000Coooooo`000?l0003o00002_ooool2o`00027ooooo
0_l00008ooooo`;o00000ooooolZo`0000?ooooo0_l00008ooooo`Go000000?oooooo`000?l00000
0_ooool5o`0000Cooooo0_l00009ooooo`;o00000_ooool4o`0000kooooo0_l000000ooooooo0000
o`00001<ooooo`007?ooool00ol0003oooooooooo`0jooooo`;o00002_ooool2o`0000Kooooo0_l0
000;ooooo`?o00008?ooool2o`000003ooooool0003o000000Gooooo0ol00002ooooo`?o000000?o
ooooo`000?l000008ol000000ooooooo0000o`000003ooooo`;o00001_ooool5o`000003ooooool0
003o000000;ooooo1?l00004ooooo`?o00001?ooool2o`0000Oooooo1?l0001Oooooo`007?ooool0
0ol0003oooooooooo`15ooooo`?o00003oooool4o`000003ooooool0003o000000kooooo0_l0000C
ooooo`;o00001Oooool3o`0000?ooooo0_l000000ooooooo0000o`000004o`0000;ooooo8?l00000
0ooooooo0000o`000002o`0000Oooooo1?l00006ooooo`?o00001?ooool2o`0000Gooooo1?l00008
ooooo`;o00004Oooool3o`0000cooooo0_l0000looooo`007?ooool00ol0003oooooooooo`0doooo
o`Co00003Oooool2o`00013ooooo1?l00003ooooo`;o00003?ooool2o`0000Wooooo0_l0000<oooo
o`;o000000?oooooo`000?l000001_ooool4o`000004ooooool0003o0000o`0000;ooooo8_l00003
ooooo`;o00000_ooool6o`000003ooooool0003o000000;o00000_ooool2o`0000?ooooo0_l00006
ooooo`Co00002?ooool2o`0000Wooooo0_l00003ooooo`Ko00003?ooool2o`0003cooooo000Loooo
o`03o`000?oooooooooo03Cooooo1?l0000?ooooo`?o000000?oooooo`000?l000004Oooool2o`00
017ooooo0_l00004ooooo`;o00003?ooool2o`000003ooooool0003o000000Cooooo9?l000000ooo
oooo0000o`000003o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o00000_ooool2o`00
0003ooooool0003o000000;o00000_ooool4o`000003ooooool0003o000000;o00001?ooool4o`00
0003ooooool0003o0000013ooooo0_l00003ooooo`Ko0000B_ooool001cooooo00?o0000oooooooo
ool0>oooool2o`0000[ooooo0ol000000ooooooo0000o`00000<ooooo`Ko00004Oooool4o`0000Oo
oooo0_l0000?oooooako000000?oooooo`000?l000001_l000000ooooooo0000o`000005o`0000co
oooo0_l00002ooooo`;o00000oooool;o`0000;ooooo1?l000000ooooooo0000o`000004ooooo`?o
00000oooool2o`0000gooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`0jooooo`?o0000
1_ooool2o`0000?ooooo0_l00004ooooo`;o00002Oooool6o`00017ooooo1_l00005ooooo`;o0000
3ooooolNo`000003ooooool0003o000000Ko00000_ooool7o`0000Kooooo0_l0000?ooooo`So0000
1?ooool2o`0000Oooooo2?l00003ooooo`;o00004?ooool2o`0004;ooooo000Looooo`03o`000?oo
oooooooo03Kooooo0_l00002ooooo`;o00001oooool2o`0000?ooooo0_l00004ooooo`;o00002_oo
ool2o`0000Gooooo0_l0000?ooooo`Co00005?ooool2o`000005ooooool0003o0000o`000?ooool0
8_l000001Ooooooo0000o`000?l0003ooooo00Co00001_ooool2o`0000Oooooo0_l00002ooooo`;o
00002?ooool3o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`Ko00000oooool2o`0000So
oooo0_l00004ooooo`Co0000@_ooool001cooooo00?o0000ooooooooool0<oooool2o`000004oooo
ool0003o0000ooooo`?o00001Oooool2o`0000[ooooo0_l0000;ooooo`;o00001Oooool2o`0000Wo
oooo0_l00004ooooo`;o00005_ooool2o`000003ooooool0003o000000;ooooo9ol000000ooooooo
0000o`000003o`0000Kooooo0_l000000ooooooo0000o`000004o`0000;ooooo0ol00007ooooo`?o
00001Oooool3o`0000Kooooo0ol000000ooooooo0000o`000002o`0000Kooooo0_l00003ooooo`;o
00001?ooool2o`0004Cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0cooooo`;o00001?ooool3o`00
00Cooooo0ol0000:ooooo`;o00007Oooool2o`000003ooooool0003o000000cooooo0_l0000>oooo
o`;o00001?oooolQo`0000;ooooo0_l00002ooooo`Co00000_ooool2o`0000;ooooo1ol00005oooo
o`;o00001_ooool4o`0000Gooooo1?l00006ooooo`;o00000oooool2o`0000Kooooo0_l0001?oooo
o`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo043ooooo1_l0000Yooooo`;o00003?ooool2o`00017ooooo0_l00002
oooooaco000000?oooooo`000?l000003Oooool2o`0000?ooooo0ol000000ooooooo0000o`000006
ooooo`;o000000?oooooo`000?l000000_ooool4o`0000Oooooo0_l0000>ooooo`;o00003oooool2
o`0004?ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006oooo
o`03o`000?oooooooooo02gooooo0_l0000@ooooo`;o000000?oooooo`000?l000000_l0000Ioooo
o`;o0000;_ooool3o`000003ooooool0003o000000ko000000?oooooo`000?l000003Ol00003oooo
o`Co00001_ooool2o`0000?ooooo0_l0000:ooooo`;o000000?oooooo`000?l000000oooool2o`00
01Sooooo0_l000000ooooooo0000o`00000<ooooo`;o0000@oooool00003ooooool0003ooooo00;o
oooo00?o0000ooooooooool02Oooool01?m4A4CogMgMooooool00007ooooo`?o0000;Oooool2o`00
00_ooooo0_l00003ooooo`;o00007_ooool2o`0000?ooooo0_l00002ooooo`;o00003oooool4o`00
00cooooo0_l00004ooooo`?o000000?oooooo`000?l000007_l000000ooooooo0000o`000005o`00
01Kooooo0_l00002ooooo`;o00000_ooool2o`0000Gooooo0_l0000=ooooo`;o00001Oooool2o`00
057ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoo
oooo00001oooool00ol0003oooooooooo`0jooooo`;o00002_ooool2o`0000Cooooo0_l0000;oooo
o`;o00002Oooool2o`0000;ooooo0ol0000>ooooo`Co00001oooool4o`000003ooooool0003o0000
00;ooooo2?l000000ooooooo0000o`00000So`0001Gooooo0ol00002ooooo`;o00000oooool2o`00
00?ooooo0ol0000:ooooo`;o000000?oooooo`000?l000008_ooool2o`0003Cooooo00000ooooooo
410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oMgMgolc<c?l000001oooool00ol0003o
ooooooooo`0iooooo`;o00002oooool3o`0000?ooooo0_l00002ooooo`;o00001oooool2o`0000ko
oooo0_l0000=ooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000Co
00001?ooool8o`0000;ooooo9_l0000Dooooo`;o00002?ooool2o`0000?ooooo0_l0000;ooooo`?o
00002_ooool2o`0001Sooooo0_l0000dooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<oooo
o`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0>Oooool2o`0000;ooooo0_l00008oooo
o`;o00001oooool2o`0000Cooooo0_l000000ooooooo0000o`00000=ooooo`Co00002?ooool2o`00
00;ooooo0_l00005ooooo`Go00002?ooool2o`0000Sooooo8?l000001?oooooo0000o`000?ooool2
o`0001Wooooo1?l000000ooooooo0000o`000004ooooo`;o00001?ooool4o`0000?ooooo0_l0000:
ooooo`Co00001Oooool2o`0001Kooooo0_l0000]ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^
k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0>Oooool2o`0000;ooooo0_l0
0003ooooo`;o00002?ooool2o`0000Sooooo0_l000000ooooooo0000o`00000=ooooo`Co00002?oo
ool2o`0000Oooooo1_l00008ooooo`;o000000?oooooo`000?l000000_oooolNo`000003ooooool0
003o000000?o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00000oooool2o`0000Kooooo1_l0
0002ooooo`;o00000oooool2o`0000Cooooo1?l0000?ooooo`Co00001Oooool2o`0001Kooooo0_l0
000]ooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00000_ooool2o`000003ooooool0003o
000000;o00002?ooool2o`0002Sooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l00006
ooooo`;o00000_ooool2o`000003ooooool0003o000000[o000000?oooooo`000?l000005ol00000
1?oooooo0000o`000?l00002ooooo`;o00000oooool5o`0000;ooooo0_l00003ooooo`;o00001_oo
ool3o`0000Gooooo0_l00009ooooo`?o00001?ooool2o`0000_ooooo0_l00003ooooo`;o000000?o
ooooo`000?l00000AOooool001cooooo00?o0000ooooooooool0?Oooool2o`000004ooooool0003o
0000ooooo`;o00009?ooool2o`0000Oooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo0_l0
0007ooooo`;o000000?oooooo`000?l000001_l000001?oooooo0000o`000?l00006oooooaSo0000
00?oooooo`000?l000000ol00002ooooo`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o
00004oooool2o`0000[ooooo0_l00003ooooo`;o00001_ooool3o`0000Oooooo1Ol00003ooooo`;o
0000@?ooool001cooooo00?o0000ooooooooool0@oooool2o`0002Cooooo0_l00007ooooo`;o0000
1Oooool2o`0000?ooooo0_l0000:ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o0000
1oooool4o`000003ooooool0003o000000Go000000?oooooo`000?l000001?l000000ooooooo0000
o`000003o`0000;ooooo0ol00002ooooo`;o00001_ooool2o`000004ooooool0003o0000ooooo`;o
00003Oooool2o`000003ooooool0003o000000[ooooo0_l0000;ooooo`?o00002Oooool4o`0000;o
oooo0_l00010ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00004Oooool2o`0000Cooooo
0_l00002ooooo`;o00001?ooool2o`00017ooooo0_l000000ooooooo0000o`00000Dooooo`;o0000
1oooool2o`000003ooooool0003o000000_o000000?oooooo`000?l000000_l000000ooooooo0000
o`000005o`0000;ooooo0_l00006ooooo`;o00000oooool2o`0000Cooooo0_l00009ooooo`;o0000
0_ooool2o`000003ooooool0003o000000Sooooo0_l0000Cooooo`;o00001Oooool3o`0000oooooo
0_l0000cooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00000_ooool2o`0000;ooooo0_l0
0004ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000Cooooo
0_l0000Aooooo`;o000000?oooooo`000?l000004Oooool2o`0000[ooooo2_l000000ooooooo0000
o`000002o`0000;ooooo1?l000001Ooooooo0000o`000?l0003ooooo00;o00001_ooool2o`0000?o
oooo0_l0000Dooooo`?o00000_ooool2o`0000[ooooo0_l0000Cooooo`;o00001oooool2o`0000?o
oooo0_l00009ooooo`;o0000<oooool001cooooo00?o0000ooooooooool0<?ooool2o`0001;ooooo
0_l00002ooooo`;o00001?ooool2o`000003ooooool0003o000000?ooooo1?l0000>ooooo`;o0000
2_ooool2o`0000?ooooo1Ol00003ooooo`;o00002Oooool2o`0000_ooooo0ol00003ooooo`?o0000
1Oooool4o`0000Oooooo1?l00004ooooo`;o00000oooool2o`0001Gooooo0ol000000ooooooo0000
o`000002o`0000_ooooo0_l0000Iooooo`;o00000oooool2o`0003kooooo000Looooo`03o`000?oo
oooooooo033ooooo1?l00007ooooo`;o00003oooool2o`0000?ooooo0_l00005ooooo`;o00003_oo
ool2o`0000Gooooo0_l000000ooooooo0000o`000002o`0000Cooooo1?l00003ooooo`;o00005Ooo
ool4o`0000Sooooo2Ol000000ooooooo0000o`000002o`0000;ooooo0_l00009ooooo`;o00005_oo
ool3o`0000;ooooo0_l00006ooooo`;o00000oooool2o`0000?ooooo0_l00007ooooo`;o00000ooo
ool2o`0004_ooooo000Looooo`03o`000?oooooooooo03;ooooo0_l00007ooooo`;o00000_ooool2
o`0000Oooooo0_l00002ooooo`;o00001oooool2o`0001Sooooo0_l000000ooooooo0000o`00000L
ooooo`?o00001Oooool7o`0000Gooooo0ol00002ooooo`Co000000?oooooo`000?l000000_l0000=
ooooo`;o00005oooool8o`0000?ooooo1ol00004ooooo`?o00000oooool2o`000004ooooool0003o
0000ooooo`Co00001Oooool2o`0000Kooooo0_l0000looooo`007?ooool00ol0003oooooooooo`0d
ooooo`;o00002Oooool2o`0000?ooooo0_l00002ooooo`;o00002oooool4o`0000Gooooo0_l00000
0ooooooo0000o`000006ooooo`Go00008_ooool3o`000003ooooool0003o000000;ooooo2_l00003
ooooo`;o00000oooool3o`000004ooooool0003o0000o`00027ooooo0_l00003ooooo`Wo00000ooo
ool2o`000003ooooool0003o000000;o00001Oooool2o`000003ooooool0003o000000Co00000_oo
ool2o`0000Oooooo1Ol00003ooooo`;o0000??ooool001cooooo00?o0000ooooooooool0=?ooool3
o`0000?ooooo0_l00006ooooo`Co00001?ooool2o`0000Sooooo0_l000000ooooooo0000o`000003
ooooo`Co000000?oooooo`000?l000001_ooool6o`0002Gooooo0_l00002ooooo`;o000000Gooooo
o`000?l0003o0000ooooo`04o`000003ooooool0003o000000Cooooo1Ol00008ooooo`;o000000?o
ooooo`000?l000005_ooool@o`0000;ooooo1_l00008ooooo`;o00000_ooool4o`0000[ooooo1?l0
0011ooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00000oooool3o`0000;ooooo0_l00005
ooooo`?o00001_ooool2o`0000Sooooo1?l00004ooooo`Co000000?oooooo`000?l000001_ooool2
o`0000;ooooo0_l00009ooooo`;o00001Oooool3o`0000Gooooo0_l0000<ooooo`;o000000Cooooo
o`000?l0003ooooo0_l00002ooooo`Co000000?oooooo`000?l000001_ooool3o`0000Oooooo0ol0
00000ooooooo0000o`00000Hooooo`So00000_ooool:o`00013ooooo0_l0000Dooooo`;o00001Ooo
ool2o`0003;ooooo000Looooo`;o0000<Oooool2o`0000Cooooo0_l00002ooooo`;o00001Oooool2
o`0000cooooo1?l00003ooooo`Co00001?ooool2o`000003ooooool0003o000000;o00000oooool3
o`000004ooooool0003o0000ooooo`;o00000oooool2o`0000;ooooo0_l00005ooooo`?o00001Ooo
ool2o`0000Cooooo1?l00004ooooo`;o00000_ooool2o`0000Gooooo0_l0000Dooooo`;o00000_oo
ool2o`00013ooooo0_l00006ooooo`Wo000000?oooooo`000?l000000_ooool2o`0001Cooooo0_l0
0004ooooo`;o00001oooool2o`0000Gooooo0_l00005ooooo`;o0000<_ooool001cooooo00?o0000
ooooooooool0=?ooool4o`0000;ooooo0_l0000Cooooo`Co00001Oooool2o`0000Kooooo2ol00000
0ooooooo0000o`000003o`0000?ooooo0_l0000Eooooo`Ko00002?ooool2o`0000Wooooo0_l0000;
ooooo`;o00001oooool2o`0000[ooooo0_l00003ooooo`?o00001Oooool=o`0000_ooooo0_l0000;
ooooo`;o000000Coooooo`000?l0003ooooo0_l00007ooooo`?o0000?oooool001cooooo00?o0000
ooooooooool0:?ooool2o`0000[ooooo0_l0000ZoooooaCo000000?oooooo`000?l000004_ooool6
o`0000Oooooo0_l0000<ooooo`;o00001_ooool2o`0000?ooooo0_l0000Cooooo`;o00000oooool2
o`0000;ooooo4Ol00007ooooo`;o00000_ooool2o`0000kooooo0_l000000ooooooo0000o`000008
ooooo`?o00000_ooool2o`0003[ooooo000Looooo`03o`000?oooooooooo02Sooooo0_l000000ooo
oooo0000o`000007ooooo`;o00003?ooool2o`0001Wooooo3?l00002ooooo`co00001_ooool6o`00
00Cooooo1Ol000000ooooooo0000o`000007ooooo`;o00004Oooool2o`000003ooooool0003o0000
01Oooooo0_l00004ooooo`;o00000_oooolCo`0000Gooooo0_l00006ooooo`;o00002?ooool2o`00
00kooooo0_l00002ooooo`;o00001Oooool2o`0003?ooooo000Looooo`03o`000?oooooooooo02_o
oooo0_l0000Eooooo`;o00005Oooool2o`0000;ooooo6Ol00007ooooo`Ko00001?ooool2o`000003
ooooool0003o000001gooooo1?l0000Hooooo`;o00001?ooool2o`000003ooooool0003o000001;o
00001Oooool2o`0000Kooooo0_l00008ooooo`;o00002oooool2o`0000cooooo0_l0000cooooo`00
7?ooool00ol0003oooooooooo`0dooooo`?o000000?oooooo`000?l000003?ooool3o`0000oooooo
0ol000000ooooooo0000o`00000Lo`0001Cooooo0_l0000Gooooo`;o00000_ooool2o`00027ooooo
4ol0000Kooooo`;o00002?ooool2o`00047ooooo000Looooo`03o`000?oooooooooo03Cooooo0ol0
00001?oooooo0000o`000?ooool2o`0000Wooooo0ol0000=ooooobCo00004_ooool4o`000003oooo
ool0003o000001Cooooo0_l0000Cooooo`;o00001Oooool2o`0000Wooooo4ol00002ooooo`Co0000
5Oooool2o`00013ooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`0kooooo`;o00000_oo
ool2o`0000cooooo0_l00007ooooobGo00004Oooool2o`0000?ooooo0_l00009ooooo`;o00007?oo
ool4o`0000Gooooo0_l00004ooooo`;o00000ooooolBo`0000?ooooo1?l00008ooooo`?o00001?oo
ool2o`0000oooooo0ol00004ooooo`;o0000>Oooool001cooooo00?o0000ooooooooool0?oooool2
o`0000cooooo0_l00009ooooobGo00001oooool2o`00017ooooo0_l00003ooooo`;o00000_ooool2
o`0001Gooooo0_l000000ooooooo0000o`000008ooooo`;o000000?oooooo`000?l000000_l00003
oooooaCo00001?ooool3o`0000Kooooo0ol00004ooooo`;o00002?ooool2o`0000Gooooo0ol0000o
ooooo`007?ooool00ol0003oooooooooo`0fooooo`Ko00000oooool2o`0000_ooooo0_l00005oooo
o`;o00000ooooolFo`000003ooooool0003o000000Go000000?oooooo`000?l000001?l00007oooo
o`;o00003oooool5o`0000Kooooo0_l0000Eooooo`;o00001?ooool2o`0000Gooooo0_l000000ooo
oooo0000o`000003oooooaKo00001?ooool3o`00017ooooo0ol00003ooooo`;o0000Aoooool001co
oooo00?o0000ooooooooool0=_ooool8o`0000;ooooo0_l00002ooooo`?o00001?ooool3o`0000Go
oooo0_l00002ooooo`Wo000000?oooooo`000?l000006_l00004ooooo`;o00004_ooool5o`0001oo
oooo0_l00002ooooo`;o00000_ooool2o`0000Oooooo5ol00005ooooo`;o00001?ooool2o`0000co
oooo0ol0000=ooooo`;o00000_ooool2o`0003Wooooo000Looooo`03o`000?oooooooooo03Sooooo
0_l00002ooooo`;o00000_ooool7o`0000Cooooo0_l0000:ooooobKo00001?ooool2o`0000Kooooo
0_l0000Sooooo`;o00002Oooool2o`0000Kooooo0_l00007ooooo`co000000?oooooo`000?l00000
2ol00008ooooo`;o00004oooool3o`0000Kooooo0_l00002ooooo`;o0000>Oooool001cooooo00?o
0000ooooooooool0=Oooool2o`000003ooooool0003o000000Sooooo0_l0000>ooooo`;o00000_oo
oolBo`000003ooooool0003o000000Oo000000?oooooo`000?l000000ol000001Ooooooo0000o`00
0?l0003ooooo00?o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00001Oooool2o`0000Wo
oooo0_l000000ooooooo0000o`00000>ooooo`;o00002Oooool2o`00013ooooo6ol00003ooooo`Go
00000_ooool2o`0000oooooo0ol00005ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0
=Oooool2o`0000?ooooo0_l0000;ooooo`?o00000_ooool2o`0000;ooooo1?l00002oooooaco0000
00?oooooo`000?l000000ol00003ooooo`Go00001?ooool2o`0000[ooooo0_l00009ooooo`Go0000
1?ooool2o`0000gooooo0_l00004ooooo`;o00001oooool2o`0000;ooooo0_l00004oooooaGo0000
00?oooooo`000?l000000_l000000ooooooo0000o`000005o`0000;ooooo0_l0000Gooooo`;o0000
?_ooool001cooooo00?o0000ooooooooool0>_ooool2o`0000_ooooo0ol00002ooooo`;o00000_oo
ool3o`0000?ooooo8_l00002ooooo`?o00003?ooool2o`0000cooooo0_l00004ooooo`Co00000ooo
ool2o`000003ooooool0003o000000[ooooo0_l00009ooooo`;o00000_ooool2o`0000;ooooo0_l0
0004ooooo`Oo000000?oooooo`000?l000003?l00002ooooo`Go00000oooool2o`0000Kooooo0ol0
0007ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0=oooool2o`0001Oooooo0ol00007
oooooako00000_ooool2o`0000gooooo0_l0000<ooooo`;o00000oooool2o`000003ooooool0003o
000000;ooooo0_l00002ooooo`;o00001?ooool2o`0000gooooo1Ol00002ooooo`;o00001?ooool2
o`0000;ooooo1_l000000ooooooo0000o`00000<o`0000;ooooo0ol0000;ooooo`Go00001oooool2
o`0000Oooooo0_l00010ooooo`007?ooool2o`0003Sooooo0_l000000ooooooo0000o`00000Koooo
o`;o000000?oooooo`000?l000006Ol000000ooooooo0000o`00000Qooooo`;o000000?oooooo`00
0?l000000_l00003ooooo`;o00001?ooool6o`0000Wooooo0_l00002ooooo`;o000000?oooooo`00
0?l000000_ooool4o`0000;ooooo0_l00002ooooo`Ko000000?oooooo`000?l000002?l00002oooo
o`;o00002_ooool2o`0000;ooooo1?l0000Cooooo`;o00001?ooool2o`0003[ooooo000Looooo`03
o`000?oooooooooo03[ooooo0_l00006ooooo`;o00001oooool2o`0000?ooooo0_l00004ooooob;o
00008Oooool2o`0000?ooooo0_l00005ooooo`So00002Oooool7o`0000Sooooo0_l00004ooooo`;o
000000?oooooo`000?l000001?l000000ooooooo0000o`000006o`000003ooooool0003o000000;o
00002_ooool2o`0000;ooooo0_l0000:ooooo`;o00000_ooool2o`0000Wooooo1_l0000hooooo`00
7?ooool00ol0003oooooooooo`0]ooooo`;o00003Oooool2o`0000Cooooo0_l000000ooooooo0000
o`000004ooooo`;o00000oooool3o`000003ooooool0003o000002;o00002Oooool2o`0000cooooo
0_l0000;ooooo`;o00001oooool8o`000004ooooool0003o0000ooooo`Oo00000_ooool3o`0000;o
oooo0_l0000:ooooo`ko000000Goooooo`000?l0003o0000ooooo`03o`0000Wooooo0_l0000@oooo
o`Ko00002Oooool2o`0000;ooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o
00001?ooool2o`0000Cooooo0_l000000ooooooo0000o`000007ooooo`;o000000?oooooo`000?l0
00001oooool2o`000003ooooool0003o000001oo00000_ooool2o`0000Sooooo0_l0000<ooooo`;o
00002Oooool6o`0000Sooooo0ol00003ooooo`Wo00002?ooool4o`0000Wooooo0_l000000ooooooo
0000o`000005o`000005ooooool0003o0000o`000?ooool01?l0000;ooooo`;o00003?ooool4o`00
00;ooooo1?l00004ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0:_ooool2o`0000Oo
oooo0_l000001?oooooo0000o`000?ooool2o`0000gooooo0_l00009ooooo`Go000000?oooooo`00
0?l000006ol000000ooooooo0000o`000002o`0000Cooooo0_l00008ooooo`;o00002Oooool4o`00
00;ooooo0_l00002ooooo`;o00002?ooool5o`0000?ooooo0_l0000:ooooo`?o00000_ooool2o`00
00?ooooo0_l00006ooooo`ko000000Coooooo`000?l0003o00001?ooool2o`0001;ooooo1?l00004
ooooo`;o00001?ooool2o`0000Gooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`0Zoooo
o`;o00001oooool2o`000003ooooool0003o000000;o00005?ooool3o`0000;ooooo0_l000001?oo
oooo0000o`000?oooolMo`0000?ooooo0_l00004ooooo`;o00001oooool3o`0000Wooooo1?l0000A
ooooo`Go00002oooool2o`000004ooooool0003o0000o`0000Oooooo0_l00006ooooo`[o00000_oo
ool2o`0000;ooooo0_l00004ooooo`;o00002_ooool2o`0000Sooooo0_l00008ooooo`;o00001ooo
ool2o`0001Kooooo0_l0000Rooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00001oooool5
o`0001;ooooo0ol00005ooooo`;o000000?oooooo`000?l000006ol00005ooooo`?o00002_ooool2
o`000003ooooool0003o000000Oooooo0_l0000Fooooo`Co00001Oooool2o`0000;ooooo0_l00002
ooooo`;o00002?ooool2o`0000Kooooo1ol0000:ooooo`;o00003_ooool2o`000003ooooool0003o
000000Gooooo1?l00006ooooo`;o00001_ooool2o`0001Oooooo0_l0000Rooooo`007?ooool00ol0
003oooooooooo`0^ooooo`;o00001oooool5o`0000[ooooo0_l00002ooooo`;o00001?ooool2o`00
00Cooooo6_l000001Ooooooo0000o`000?l0003ooooo00;o00001?ooool3o`0000gooooo0_l0000Q
ooooo`;o00000oooool4o`00013ooooo0_l00007ooooo`?o000000?oooooo`000?l000002_ooool4
o`0000kooooo0ol00005ooooo`Co00003_ooool2o`0003_ooooo000Looooo`03o`000?oooooooooo
03Oooooo0_l0000=ooooo`;o00000_ooool2o`0000Cooooo0_l00004ooooo`Go00000_ooool<o`00
0003ooooool0003o000000;o000000?oooooo`000?l000000ol000001?oooooo0000o`000?l00002
ooooo`Co00002Oooool2o`0002Gooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l0000;
ooooo`;o00001_ooool4o`000003ooooool0003o000000[ooooo0_l0000>ooooo`?o00001Oooool2
o`00013ooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00001?ooool3o`00
0003ooooool0003o000000;ooooo0_l0000=ooooo`;o00001oooool8o`000003ooooool0003o0000
00So000000?oooooo`000?l000000_l000001?oooooo0000o`000?l00004ooooo`;o00000_ooool4
o`0000Wooooo0_l00005ooooo`;o00001?ooool2o`0000kooooo0_l00002ooooo`;o00003Oooool4
o`000003ooooool0003o000000_ooooo0_l00008ooooo`;o000000?oooooo`000?l000001oooool2
o`0000?ooooo0ol0000Cooooo`?o0000C?ooool001cooooo00?o0000ooooooooool0<?ooool2o`00
00Cooooo0ol000001?oooooo0000o`000?ooool3o`0000gooooo1?l00006ooooo`;o000000?ooooo
o`000?l000000_l00003ooooo`Ko000000?oooooo`000?l000000ol0000>ooooo`;o00004Oooool2
o`000004ooooool0003o0000ooooo`;o00003_ooool2o`0000;ooooo0_l0000=ooooo`Ko00006_oo
ool2o`0000;ooooo0_l00002ooooo`;o00000oooool3o`0001Cooooo0_l00003ooooo`;o00001ooo
ool2o`0003kooooo000Looooo`03o`000?oooooooooo03;ooooo0ol00002ooooo`;o000000Cooooo
o`000?l0003ooooo0ol0000?ooooo`;o00000oooool2o`000003ooooool0003o000000Kooooo1ol0
0002ooooo`Co000000Coooooo`000?l0003ooooo0_l00009ooooo`;o00001_ooool2o`0000Oooooo
0_l00003ooooo`;o00005Oooool2o`0000gooooo0_l00002ooooo`?o00006Oooool3o`000003oooo
ool0003o000000Sooooo0_l00006ooooo`;o00000oooool2o`0000Kooooo0_l00003ooooo`?o0000
0oooool2o`0000;ooooo0ol0000mooooo`007?ooool00ol0003oooooooooo`0booooo`?o00002Ooo
ool2o`00013ooooo0_l00002ooooo`Oo00001?ooool7o`0000?ooooo0ol000001?oooooo0000o`00
0?ooool2o`00017ooooo0_l00007ooooo`;o00004Oooool4o`0000Cooooo0ol0000:ooooo`;o0000
00?oooooo`000?l000000_l000000ooooooo0000o`000004o`0000Gooooo0_l0000?ooooo`;o0000
2oooool2o`0000Kooooo0_l00002ooooo`?o00001_ooool2o`0000?ooooo0_l00004ooooo`;o0000
0oooool3o`000003ooooool0003o000003Wooooo000Looooo`03o`000?oooooooooo03Sooooo0_l0
000:ooooo`;o00001Oooool2o`0000?ooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo0_l0
0005ooooo`;o00000oooool4o`0000_ooooo0_l00009ooooo`;o00006_ooool4o`0000Cooooo0_l0
0009ooooo`Go00000_ooool2o`0000?ooooo1?l00002ooooo`;o000000?oooooo`000?l000000_oo
ool2o`0000Sooooo0ol000000ooooooo0000o`00000Fooooo`?o00000oooool4o`000003ooooool0
003o000000;o00000oooool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`00
0009ooooo`;o0000;_ooool001cooooo00?o0000ooooooooool0>?ooool2o`0000;ooooo0_l00006
ooooo`;o000000?oooooo`000?l000000_ooool2o`0000gooooo1Ol00003ooooo`Oo00000_ooool2
o`0000_ooooo0_l00005ooooo`;o00000_ooool2o`0000kooooo0_l000000ooooooo0000o`00000J
ooooo`Oo00000_ooool2o`0000?ooooo0_l00002ooooo`;o00001Oooool2o`0000Cooooo0_l00002
ooooo`?o000000?oooooo`000?l000001oooool2o`00013ooooo0_l000000ooooooo0000o`000007
o`0000?ooooo0_l000000ooooooo0000o`000002o`0000_ooooo0_l00002ooooo`;o0000;_ooool0
01cooooo00?o0000ooooooooool0=?ooool2o`0000Kooooo0_l00003ooooo`;o00001?ooool2o`00
017ooooo1?l00004ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o00001Oooool2o`00
00[ooooo0_l000000ooooooo0000o`000002ooooo`;o00002oooool2o`000003ooooool0003o0000
00?o000000?oooooo`000?l000001oooool2o`00013ooooo0_l00002ooooo`;o00001?ooool2o`00
00kooooo0_l0000?ooooo`;o00001oooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool4o`00
0004ooooool0003o0000o`0000Sooooo0_l00007ooooo`;o00000_ooool2o`0003;ooooo000Loooo
o`;o0000;oooool2o`0000Cooooo0_l0000;ooooo`;o00001?ooool2o`0000Sooooo0_l0000=oooo
o`;o00001?ooool3o`0000?ooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00002oooo
o`;o00003?ooool2o`0000;ooooo0ol000000ooooooo0000o`000007ooooo`;o00001oooool:o`00
00Wooooo0_l0000Oooooo`;o00001oooool2o`0000?ooooo0_l00006ooooo`;o00001?ooool2o`00
00Sooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l0000aooooo`007?ooool00ol0003o
ooooooooo`0^ooooo`;o00004_ooool2o`000003ooooool0003o000000;o00002?ooool2o`0000go
oooo0_l00004ooooo`;o00000oooool2o`0000gooooo0_l00009ooooo`;o00001Oooool2o`0000Ko
oooo0_l0000Eooooo`go00000_ooool2o`0000[ooooo0_l0000Jooooo`;o00002Oooool2o`0000?o
oooo0_l00004ooooo`?o00002Oooool3o`000003ooooool0003o000000?ooooo0_l00007ooooo`;o
0000<Oooool001cooooo00?o0000ooooooooool0>Oooool2o`0000?ooooo0_l00002ooooo`;o0000
00Coooooo`000?l0003o00006_ooool2o`0000;ooooo0_l00003ooooo`;o00004oooool2o`000003
ooooool0003o000000;o00001Oooool2o`0000[ooooo0_l0000Aooooo`Ko00001Oooool2o`0000;o
oooo0_l0000:ooooo`;o00001oooool2o`0000kooooo0_l0000<ooooo`;o00000oooool2o`0000Go
oooo0_l00009ooooo`?o0000@_ooool001cooooo00?o0000ooooooooool0=_ooool2o`000003oooo
ool0003o000000?ooooo0_l00006ooooo`;o000000?oooooo`000?l000000ol0000Dooooo`Go0000
1?ooool2o`0001?ooooo0_l000000ooooooo0000o`000004ooooo`;o00001_ooool2o`0000Cooooo
0ol0000Dooooo`?o00003oooool3o`0000cooooo0_l0000>ooooo`;o0000J?ooool001cooooo00?o
0000ooooooooool0=_ooool2o`0000Sooooo0_l00003ooooo`;o00000_ooool5o`0000?ooooo0_l0
000<ooooo`;o00000oooool3o`00017ooooo0_l00007ooooo`Co00001?ooool2o`0000Kooooo1Ol0
00000ooooooo0000o`000004ooooo`;o00000_ooool2o`0000[ooooo0ol0000@ooooo`Go00001_oo
ool2o`0001_ooooo0_l0000?ooooo`;o00002_ooool2o`0004;ooooo000Looooo`03o`000?oooooo
oooo03Gooooo0ol00004ooooo`;o00000_ooool2o`0000?ooooo0_l0000:ooooo`;o00003?ooool2
o`0000_ooooo0_l0000:ooooo`;o00001oooool4o`0000cooooo1Ol00007ooooo`;o00000_ooool5
o`0000Oooooo0_l0000=ooooo`;o00000_ooool5o`0000Kooooo0_l0000Kooooo`;o00001Oooool2
o`0000Oooooo1?l000000ooooooo0000o`000006ooooo`;o0000@_ooool001cooooo00?o0000oooo
ooooool0=Oooool3o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l0000=
ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Kooooo0_l0000Nooooo`?o00000oooool2
o`0000Cooooo0ol00002ooooo`;o00000_ooool5o`0000Oooooo0_l0000=ooooo`go00000_ooool2
o`0002;ooooo0_l00007ooooo`Co000000?oooooo`000?l00000B_ooool001cooooo00?o0000oooo
ooooool0?oooool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000003o`00
0003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000006ooooo`;o000000?oooooo`00
0?l000009_ooool3o`0000?ooooo0_l00004ooooo`?o00000_ooool2o`000003ooooool0003o0000
00Go00001_ooool2o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`oo00001_ooool2o`00
00oooooo0_l00003ooooo`;o00002_ooool2o`0000cooooo0_l00002ooooo`?o0000@_ooool001co
oooo00?o0000ooooooooool0=oooool2o`0000oooooo1ol000000ooooooo0000o`000006ooooo`;o
00000_ooool3o`000004ooooool0003o0000o`0000Gooooo0_l0000@ooooo`Go00002oooool2o`00
00cooooo0_l00006ooooo`;o00000_ooool3o`0000_ooooo0_l000000ooooooo0000o`000002oooo
o`ko000000?oooooo`000?l000001_ooool2o`0000Kooooo0_l00007ooooo`;o00000oooool2o`00
00[ooooo0_l00005ooooo`;o00001Oooool2o`000003ooooool0003o000000;o0000@_ooool001co
oooo00?o0000ooooooooool0=oooool2o`0000oooooo0_l00002ooooo`;o00002_ooool2o`0000;o
oooo0ol000001?oooooo0000o`000?l00004ooooo`Go00003_ooool5o`0000;ooooo0_l00003oooo
o`;o00000_ooool2o`0000[ooooo1?l0000Hooooo`?o00000_ooool<o`000003ooooool0003o0000
00Ko00000_ooool2o`0000Sooooo0_l0000Oooooo`;o00001?ooool2o`0000;ooooo0_l00014oooo
o`007?ooool00ol0003oooooooooo`10ooooo`;o00002_ooool2o`0000;ooooo0_l0000Eooooo`Go
00003oooool2o`0000Cooooo0_l00003ooooo`;o00000_ooool2o`0000Wooooo0ol00007ooooo`;o
000000?oooooo`000?l000003_ooool3o`0000;ooooo5Ol00002ooooo`;o00004_ooool2o`0001Go
oooo0_l00004ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0=oooool2o`0000Oooooo
0_l0000:ooooo`;o00000_ooool4o`0000Gooooo0_l00004ooooo`;o00001Oooool2o`0000_ooooo
0_l00008ooooo`;o00001?ooool2o`0000Gooooo0_l00005ooooo`;o00000_ooool4o`0000Cooooo
1?l000000ooooooo0000o`000004ooooo`;o00000oooool2o`000003ooooool0003o000000Kooooo
0ol000000ooooooo0000o`00000=o`0001Oooooo0_l0000Eooooo`;o0000C_ooool001cooooo00?o
0000ooooooooool0;_ooool2o`0000Oooooo0_l00002ooooo`;o00001Oooool2o`0000Sooooo0ol0
00000ooooooo0000o`000002o`0000Gooooo0_l00004ooooo`;o00001Oooool4o`0000Wooooo1Ol0
0005ooooo`;o00001?ooool2o`0000cooooo0_l00004ooooo`;o00000_ooool6o`0000Oooooo0_l0
0002ooooo`?o000000?oooooo`000?l000001?ooool<o`000003ooooool0003o000000Oo00001Ooo
ool2o`0002gooooo1_l00013ooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00002oooool2
o`0000Gooooo0_l00009ooooo`;o000000?oooooo`000?l000000oooool2o`000003ooooool0003o
000000Sooooo0_l00004ooooo`;o00001Oooool2o`0000;ooooo1Ol00005ooooo`;o00002oooool2
o`0000?ooooo1?l000000ooooooo0000o`000005ooooo`;o00003oooool3o`0000Oooooo0_l00000
0ooooooo0000o`00000Bo`0000Cooooo0_l00003ooooo`;o00008_ooool2o`000003ooooool0003o
000000Oo00001Oooool2o`0000?ooooo0_l0000gooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^
k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0
D?ooool2o`0000?ooooo0_l000000ooooooo0000o`000008ooooo`;o00001Oooool3o`0000?ooooo
0_l0000Fooooo`;o000000Coooooo`000?l0003ooooo1_l000000ooooooo0000o`00000Fooooo`;o
00002?oooolGo`0000Kooooo0_l000000ooooooo0000o`000002o`0001oooooo0ol000000ooooooo
0000o`000002o`0000?ooooo0_l00005ooooo`;o00000oooool2o`0003Oooooo00001_ooooooMgMg
oiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool0
0ol0003oooooooooo`0fooooo`;o00004oooool2o`000003ooooool0003o000000;o00001_ooool2
o`0000kooooo1Ol0000@ooooo`;o00002?ooool2o`000004ooooool0003o0000ooooo`Go00000_oo
ool2o`0001Kooooo0_l00007oooooaSo00001_ooool2o`0000?ooooo0_l00004ooooo`;o00006?oo
ool4o`0000Sooooo0_l00013ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0fooooo`;o00004ooo
ool2o`000004ooooool0003o0000ooooo`;o00001?ooool3o`0000;ooooo0ol00009ooooo`Go0000
4?ooool2o`0000Oooooo0_l000000ooooooo0000o`00000;o`0001oooooo6?l00002ooooo`;o0000
2?ooool2o`0000?ooooo0_l0000=ooooo`;o000000?oooooo`000?l000000_l00004ooooo`Co0000
COooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oV9RHoooo
oonHV9So8B4Q00Kooooo0ol0000fooooo`;o00000_ooool2o`0000;ooooo0_l00005ooooo`;o0000
2_ooool2o`000004ooooool0003o0000ooooo`;o00000oooool3o`0000?ooooo0_l00005ooooo`;o
00002Oooool2o`0000Oooooo0_l00006oooooaCo00000oooool2o`0000cooooo0_l00002ooooo`;o
00001?oooolJo`000003ooooool0003o000000Sooooo0_l00003ooooo`;o00003Oooool2o`000003
ooooool0003o000000;o00001_ooool3o`0000gooooo0_l0000mooooo`0000?oooooo`000?ooool0
0_ooool00ol0003oooooooooo`09ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003o
ooooooooo`0fooooo`?o000000?oooooo`000?l000000_ooool2o`0000Gooooo0_l00005ooooo`;o
00001_ooool2o`0000cooooo0_l00007ooooo`;o00001Oooool7o`0000_ooooo5Ol000000ooooooo
0000o`000002o`0000;ooooo0_l00008ooooo`;o00000_ooool2o`0000?ooooo0ol000000ooooooo
0000o`00000Eo`0000Gooooo0_l00006ooooo`;o00002?ooool2o`0001?ooooo0ol0000=ooooo`;o
0000?Oooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7
ooooo`08ooooo`03o`000?oooooooooo03Kooooo0ol0000Cooooo`;o00005Oooool2o`0000Kooooo
0_l00005ooooo`;o00000_ooool3o`0000?ooooo0_l00006oooooa3o000000Coooooo`000?l0003o
00000_ooool2o`0000Cooooo0_l0000Aoooooaco00001?ooool2o`0000Kooooo0_l00008ooooo`;o
00006oooool3o`0004Cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@
4?nHV9P02?ooool00ol0003oooooooooo`0fooooo`?o00001_ooool2o`0000Wooooo0_l0000Goooo
o`Ko00004oooool2o`0000Kooooo5_l00002ooooo`Co00004ooooolEo`000003ooooool0003o0000
00Co00003?ooool2o`0000Sooooo0_l0000?ooooo`;o00000_ooool2o`0000Cooooo1Ol00014oooo
o`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o
0000ooooooooool0<?ooool2o`0000gooooo0_l00009ooooo`?o00000_ooool2o`0000Gooooo0_l0
000=ooooo`Co00004Oooool2o`0000Oooooo6?l000000ooooooo0000o`000002o`0000?ooooo0_l0
000>oooooaco00001?ooool2o`0000Oooooo0ol00005ooooo`?o00001?ooool2o`0000Gooooo0_l0
0002ooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`00000<ooooo`;o0000=_oo
ool001cooooo00?o0000ooooooooool0<?ooool2o`0000Gooooo0_l0000Booooo`Ko00001Oooool2
o`0002;ooooo0_l00007oooooaSo00002?ooool2o`0000oooooo6ol000001?oooooo0000o`000?oo
ool2o`0000Oooooo0ol00005ooooo`;o00001Oooool2o`0000Gooooo0_l0000Mooooo`;o0000=_oo
ool001cooooo00?o0000ooooooooool0=oooool2o`00013ooooo0_l00002ooooo`?o00002_ooool2
o`0000;ooooo0_l0000SoooooaGo00004?ooool2o`0000[ooooo4_l000000ooooooo0000o`000009
o`000003ooooool0003o000000Oooooo0_l000000ooooooo0000o`00000:ooooo`;o000000Cooooo
o`000?l0003ooooo0ol000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l000003_oo
ool2o`0003Oooooo000Looooo`03o`000?oooooooooo02gooooo0_l00009ooooo`;o00001_ooool2
o`0000Oooooo0ol00002ooooo`;o00001oooool5o`0000;ooooo0_l0000Iooooo`;o00001?ooool2
o`0000;ooooo5ol00008ooooo`;o00000_ooool4o`0000cooooo6_l0000:ooooo`Oo00003Oooool2
o`000003ooooool0003o000000;ooooo0ol00005ooooo`;o000000?oooooo`000?l000003_ooool2
o`0003Oooooo000Looooo`03o`000?oooooooooo02gooooo0_l00009ooooo`;o00001?ooool4o`00
00Sooooo0_l00003ooooo`;o00001_ooool5o`0001?ooooo0_l00008ooooo`Co00000_ooool2o`00
00;ooooo4_l000000ooooooo0000o`000005o`0000Gooooo0_l000001?oooooo0000o`000?l00009
ooooo`;o00000_oooolKo`0000;ooooo0_l00005ooooo`Ko00005oooool3o`0001Sooooo0_l0000f
ooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00001_ooool2o`0000Oooooo0_l00007oooo
o`Co00000oooool2o`0000kooooo0_l0000:ooooo`;o000000?oooooo`000?l000000_oooolKo`00
00Sooooo0_l0000:ooooo`;o00000_oooolOo`0000Gooooo1?l0000Booooo`;o000000?oooooo`00
0?l000000oooool2o`0000[ooooo0_l0000<ooooo`;o0000=_ooool001cooooo00?o0000oooooooo
ool0@?ooool2o`0000Cooooo0_l00004ooooo`;o00002_ooool4o`0000?ooooo0_l0000Moooooaco
00001?ooool2o`0000Wooooo0_l0000<oooooa_o00007Oooool2o`000005ooooool0003o0000o`00
0?ooool01?l00009ooooo`;o00001_ooool2o`0003cooooo000Looooo`03o`000?oooooooooo03[o
oooo0_l00002ooooo`Co00002_ooool2o`000003ooooool0003o000000Oooooo1?l00002ooooo`;o
000000?oooooo`000?l000006oooool>o`0000;ooooo3?l00004ooooo`;o00002Oooool2o`0000?o
oooo0_l00005oooooa[o000000?oooooo`000?l000004Oooool2o`0000Kooooo0_l00006ooooo`;o
000000?oooooo`000?l000000_l0000Aooooo`;o0000??ooool001cooooo00?o0000ooooooooool0
>?ooool4o`0000;ooooo0_l00004ooooo`?o00002?ooool2o`0000Gooooo1_l00002ooooo`;o0000
00?oooooo`000?l000002Oooool2o`0000Kooooo0_l000000ooooooo0000o`000005ooooo`?o0000
00?oooooo`000?l000005ol0000<ooooo`;o00001Oooool4o`0000?ooooo0ol000000ooooooo0000
o`00000Ho`0000Oooooo0ol000000ooooooo0000o`000003ooooo`;o00001Oooool3o`0000;ooooo
0_l000000ooooooo0000o`000004ooooo`;o00000_ooool2o`0004_ooooo000Looooo`03o`000?oo
oooooooo03Sooooo0_l00004ooooo`;o00001?ooool3o`0000Sooooo0_l00005ooooo`;o000000?o
ooooo`000?l000004Oooool2o`0000Kooooo0_l000000ooooooo0000o`000002o`0000Cooooo7?l0
000<ooooo`;o00001Oooool4o`0000Oooooo6_l00007ooooo`Ko00002_ooool3o`0000;ooooo0_l0
00001?oooooo0000o`000?ooool2o`000003ooooool0003o000000;ooooo0_l0001;ooooo`007?oo
ool00ol0003oooooooooo`0kooooo`;o000000?oooooo`000?l000000_l0000Dooooo`;o00005?oo
ool2o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`0000Kooooo5ol0000Fooooo`;o00002_oo
oolHo`0000?ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00003Oooool2o`0000?ooooo
0_l00002ooooo`?o0000DOooool001cooooo00?o0000ooooooooool0>Oooool6o`000003ooooool0
003o0000017ooooo0_l000000ooooooo0000o`00000Dooooo`;o00000oooool2o`0000;ooooo0_l0
0004ooooo`;o00001?oooolJo`0001oooooo4ol000000ooooooo0000o`000005ooooo`;o00000_oo
ool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo
0_l00003ooooo`;o00000oooool2o`0000?ooooo0_l0001<ooooo`007?ooool2o`0003[ooooo0_l0
00001?oooooo0000o`000?l0000Dooooo`;o00005_ooool2o`0000[ooooo0_l00002ooooo`?o0000
00Coooooo`000?l0003ooooo6Ol00009ooooo`;o00005?ooool5o`000003ooooool0003o000000ko
000000?oooooo`000?l000001?ooool4o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`?o
000000Coooooo`000?l0003o00001_ooool2o`000003ooooool0003o000000?ooooo1?l0001:oooo
o`007?ooool00ol0003oooooooooo`0looooo`;o0000;Oooool4o`0000Sooooo1?l000001?oooooo
0000o`000?oooolJo`0000_ooooo0_l0000<ooooo`Co00001?ooool2o`0000Gooooo3_l000001?oo
oooo0000o`000?l00004ooooo`Go00002_ooool7o`0000Kooooo0_l000000ooooooo0000o`000005
ooooo`;o00004oooool2o`0003Gooooo000Looooo`03o`000?oooooooooo03cooooo0_l0000Koooo
o`;o000000Coooooo`000?l0003o00000_ooool2o`0000[ooooo0_l0000:ooooo`;o00001?oooolH
o`0000Cooooo0_l00006ooooo`?o00000oooool2o`0000Cooooo0_l000000ooooooo0000o`000002
o`0000Cooooo1_l000000ooooooo0000o`00000?o`0000Gooooo1Ol00006ooooo`;o00000oooool4
o`0000_ooooo1?l0000Hooooo`;o0000=Oooool001cooooo00?o0000ooooooooool0??ooool5o`00
01Kooooo1?l000001?oooooo0000o`000?l00002ooooo`;o00003oooool2o`0000Gooooo0_l00005
ooooo`Co000000?oooooo`000?l000004?l00004ooooo`;o000000?oooooo`000?l000000_l00000
0ooooooo0000o`000004ooooo`?o00000oooool2o`0000?ooooo0_l00006ooooo`Co000000?ooooo
o`000?l000002ol000001?oooooo0000o`000?ooool2o`0000Gooooo0_l00007ooooo`;o00001Ooo
ool5o`0000?ooooo0_l00005ooooo`;o0000Coooool001cooooo00?o0000ooooooooool0?Oooool4
o`0000;ooooo0_l0000;ooooo`;o00001Oooool2o`0001Wooooo0_l0000>oooooaGo00001oooool4
o`0000Cooooo0_l00002ooooo`;o00000oooool2o`0000?ooooo0_l0000<ooooo`Ko00000_ooool4
o`0000Cooooo0_l0000<ooooo`Co00000_ooool2o`000003ooooool0003o000000?o00000oooool2
o`000003ooooool0003o000000;ooooo0_l00009ooooo`;o0000A?ooool001cooooo00?o0000oooo
ooooool0@oooool3o`0000[ooooo0_l00005ooooo`;o00000oooool2o`0000Cooooo0_l0000Eoooo
o`;o00001ooooolEo`0000oooooo0_l00007ooooo`;o00001?ooool2o`0000_ooooo1ol0000Goooo
o`Co00000_ooool2o`0000_ooooo0ol0000<ooooo`?o0000A?ooool001cooooo00?o0000oooooooo
ool0A?ooool2o`0000kooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00001?ooool2o`00
00Cooooo1?l00009ooooo`Ko00001oooool@o`0000;ooooo0_l00007ooooo`;o000000?oooooo`00
0?l000000_ooool2o`0000oooooo0_l0000>ooooo`Co00001?ooool2o`0002Cooooo0_l0000:oooo
o`;o000000?oooooo`000?l00000AOooool001cooooo00?o0000ooooooooool0>oooool4o`0000?o
oooo0_l0000;ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`?o00000_ooool2o`0000;o
oooo1_l00002ooooo`;o00001Oooool7o`0000Sooooo0_l000000ooooooo0000o`000007o`000003
ooooool0003o000000Co00001Oooool3o`000003ooooool0003o000000;ooooo0_l00009ooooo`;o
00001?ooool2o`0001Gooooo0ol0000;ooooo`?o00000_ooool4o`0000_ooooo0_l000001?oooooo
0000o`000?ooool2o`0000Wooooo0_l00005ooooo`;o0000@Oooool001cooooo00?o0000oooooooo
ool0>Oooool6o`0000?ooooo0_l00005ooooo`;o00001?ooool2o`0000cooooo0ol000001?oooooo
0000o`000?l00002ooooo`;o00000_ooool2o`0000;ooooo0_l00008ooooo`Co00001Oooool2o`00
00Kooooo3_l00005ooooo`Co00001?ooool2o`0000?ooooo0_l00004ooooo`;o00001?ooool2o`00
01Gooooo0_l0000<ooooo`?o00000_ooool4o`0000[ooooo0ol000000ooooooo0000o`000003o`00
013ooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00001Oooool2o`0000;o
oooo0_l00003ooooo`;o00005_ooool5o`000004ooooool0003o0000ooooo`;o00000_ooool2o`00
00Sooooo1?l00005ooooo`;o00002Oooool2o`000003ooooool0003o000000Cooooo0_l00007oooo
o`;o00002Oooool2o`000003ooooool0003o000000[ooooo0_l0000Rooooo`;o00003oooool3o`00
00?ooooo0_l0000>ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0??ooool3o`000005
ooooool0003o0000o`000?ooool00_l00003ooooo`;o00002_ooool2o`0000?ooooo0_l00008oooo
o`;o000000?oooooo`000?l000000_ooool2o`0000Sooooo0_l00003ooooo`?o00003Oooool2o`00
00Wooooo0_l0000Eooooo`?o00002Oooool2o`0000Oooooo0_l000000ooooooo0000o`000006oooo
o`;o00001Oooool2o`0000Oooooo0_l0000@ooooo`;o00002oooool4o`0000?ooooo0ol00014oooo
o`007?ooool00ol0003oooooooooo`0looooo`?o00000_ooool2o`000003ooooool0003o000000oo
oooo0_l00003ooooo`?o00002_ooool2o`0000;ooooo0_l00006ooooo`[o00003Oooool5o`0000?o
oooo0_l0000Booooo`;o00001Oooool2o`0000Wooooo0_l000000ooooooo0000o`000004ooooo`;o
000000?oooooo`000?l000001_ooool2o`0000Gooooo0_l0000Iooooo`;o00002oooool4o`000003
ooooool0003o000000;o0000AOooool001cooooo00?o0000ooooooooool0??ooool2o`0000gooooo
0_l0000;ooooo`Go00001Oooool2o`0000oooooo1ol00005ooooo`;o00002oooool3o`0000?ooooo
0_l00006ooooo`;o000000?oooooo`000?l000001?ooool5o`0000Oooooo0_l00007ooooo`;o0000
00?oooooo`000?l000004oooool2o`0000_ooooo0_l0000Qooooo`;o0000Aoooool001cooooo00?o
0000ooooooooool0??ooool3o`0000;ooooo0_l00008ooooo`;o00002oooool3o`0000Oooooo0_l0
000Dooooo`?o000000?oooooo`000?l000000ol00005ooooo`;o00004_ooool2o`000003ooooool0
003o000000Cooooo1ol00005ooooo`;o00007oooool2o`0000_ooooo0_l00002ooooo`;o00001?oo
ool2o`00063ooooo000Looooo`03o`000?oooooooooo03gooooo0_l00002ooooo`?o00005oooool2
o`0000[ooooo0_l0000@ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000Cooooo0_l0
000;ooooo`Co000000Coooooo`000?l0003o00003Oooool4o`0001oooooo1Ol0000@ooooo`?o0000
00Coooooo`000?l0003ooooo0_l00004ooooo`;o00003Oooool3o`0004[ooooo000Looooo`03o`00
0?oooooooooo04;ooooo0_l0000Cooooo`Ko00002?ooool4o`000003ooooool0003o000000Wooooo
0_l00009ooooo`;o00002Oooool2o`0000Gooooo2Ol0000?ooooo`;o00004Oooool2o`0000cooooo
1Ol0000?ooooo`?o00000_ooool2o`0000Oooooo0_l00006ooooo`;o00001Oooool3o`000003oooo
ool0003o000004Oooooo000Looooo`;o0000Eoooool5o`0000[ooooo0_l00003ooooo`Co00001ooo
ool2o`0001Cooooo0_l00003ooooo`Co00000_ooool2o`0000kooooo1?l0000Cooooo`;o00007_oo
ool5o`0000Cooooo0_l00003ooooo`;o00002?ooool2o`0000Wooooo0_l00017ooooo`007?ooool0
0ol0003oooooooooo`0looooo`;o000000Coooooo`000?l0003o00001oooool2o`0000_ooooo1?l0
0007ooooo`Co00001oooool2o`0000Gooooo0_l00009ooooo`;o00002oooool2o`0000?ooooo0_l0
0002ooooo`;o00004?ooool4o`0001kooooo1?l0000Aooooo`Go000000Coooooo`000?l0003ooooo
0_l00003ooooo`;o0000G?ooool001cooooo00?o0000ooooooooool0>oooool3o`000004ooooool0
003o0000o`0000Oooooo0_l0000=ooooo`;o00001Oooool6o`0000Oooooo0_l00005ooooo`;o0000
2Oooool2o`0000Oooooo0ol000000ooooooo0000o`000007ooooo`;o00003?ooool2o`0000;ooooo
0_l0000@ooooo`;o00001?ooool3o`0000Gooooo1_l0000Dooooo`;o000000Coooooo`000?l0003o
0000Hoooool001cooooo00?o0000ooooooooool0>oooool2o`0000Gooooo0_l00008ooooo`;o0000
2_ooool3o`0000Cooooo0_l0000:ooooo`?o00004oooool2o`0000Cooooo0ol00005ooooo`;o0000
4Oooool5o`0000Kooooo1ol00004ooooo`;o000000Coooooo`000?l0003ooooo0ol00005ooooo`;o
00004oooool2o`0000?ooooo0_l00002ooooo`;o00004Oooool2o`00053ooooo000Looooo`03o`00
0?oooooooooo04;ooooo0_l00008ooooo`?o00002_ooool2o`0000oooooo0ol0000=ooooo`;o0000
0oooool4o`0000cooooo0_l0000Cooooo`?o00001_ooool7o`0000;ooooo0_l00003ooooo`;o0000
5Oooool2o`0000Oooooo0_l0000Jooooo`;o0000D?ooool001cooooo00?o0000ooooooooool0COoo
ool4o`0001Sooooo1Ol0000<ooooo`;o00000_ooool3o`0000?ooooo0_l0000:ooooo`;o00005_oo
ool2o`0000cooooo0_l00008ooooo`;o00001_ooool2o`0000Sooooo0_l0001eooooo`007?ooool0
0ol0003oooooooooo`19ooooo`;o00000oooool5o`0001Kooooo0_l000000ooooooo0000o`000004
ooooo`;o00001_ooool2o`0000;ooooo0_l00004ooooo`;o00002Oooool3o`0000Kooooo0_l0000>
ooooo`;o00002oooool2o`0000Wooooo0_l00006ooooo`;o00000_ooool2o`00023ooooo0_l0001I
ooooo`007?ooool00ol0003oooooooooo`17ooooo`Co00001_ooool2o`0000;ooooo0_l0000Koooo
o`;o00006_ooool3o`0000Oooooo0_l0000Gooooo`;o00000_ooool2o`0000Oooooo0_l0000<oooo
o`;o00002Oooool2o`0000Oooooo0_l0000<ooooo`;o0000FOooool001cooooo00?o0000oooooooo
ool0Aoooool3o`0000Cooooo0_l00005ooooo`;o00001?ooool2o`0000?ooooo0ol00007ooooo`Co
00006oooool3o`0000;ooooo0_l0000Nooooo`;o000000Coooooo`000?l0003o00002_ooool2o`00
00cooooo0_l00009ooooo`;o00001_ooool3o`00017ooooo0_l0001Dooooo`007?ooool00ol0003o
ooooooooo`18ooooo`?o00000oooool2o`0000Gooooo0_l00004ooooo`;o00000oooool3o`0000Oo
oooo1?l0000:ooooo`;o00002_ooool2o`0000;ooooo1?l00006ooooo`;o00000_ooool2o`0001Ko
oooo0_l00002ooooo`;o00002_ooool6o`0000Sooooo0_l00009ooooo`;o00001_ooool3o`0000oo
oooo1?l0001Dooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00001?ooool2o`0000?ooooo
1Ol0000?ooooo`;o00003_ooool2o`0000Cooooo2?l00002ooooo`Go00001Oooool3o`000004oooo
ool0003o0000o`0001[ooooo0_l0000:ooooo`Ko00001_ooool2o`0000[ooooo1?l0000Fooooo`;o
0000E_ooool001cooooo00?o0000ooooooooool0Coooool2o`0000?ooooo0_l000000ooooooo0000
o`000004o`0000Gooooo0_l00004ooooo`;o00005?ooool8o`0000Gooooo1ol000001Ooooooo0000
o`000?l0003ooooo00Go00005Oooool4o`0000cooooo1?l00006ooooo`;o000000?oooooo`000?l0
00002?ooool3o`0000;ooooo1?l00007ooooo`;o0000Goooool001cooooo00?o0000ooooooooool0
FOooool4o`000003ooooool0003o000000;ooooo0_l0000Jooooo`;o00001?ooool2o`0000;ooooo
0_l00003ooooo`Ko000000?oooooo`000?l000001_l0000Eooooo`;o00001Oooool2o`0000Cooooo
0_l000000ooooooo0000o`000002o`0000Wooooo0_l00005ooooo`;o000000?oooooo`000?l00000
0oooool4o`000003ooooool0003o000000Cooooo0_l00006ooooo`;o0000Eoooool001cooooo00?o
0000ooooooooool0F?ooool2o`0000Cooooo0_l0000:ooooo`;o00004_ooool2o`000003ooooool0
003o000000Gooooo0_l00006ooooo`?o00000_ooool5o`0000;ooooo0_l0000:ooooo`;o00003_oo
ool2o`0000Cooooo0_l000000ooooooo0000o`000003o`0000Kooooo0_l00007ooooo`;o000000?o
ooooo`000?l000002?ooool2o`0000cooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`1@
ooooo`;o00001_ooool3o`0000Kooooo1?l00005ooooo`;o00003?ooool2o`0000Cooooo0_l00000
0ooooooo0000o`00000>ooooo`Ko00000_ooool2o`000003ooooool0003o000000Sooooo1?l0000<
ooooo`;o00000_ooool2o`0000Cooooo0_l00002ooooo`;o00001_ooool2o`0000Gooooo0_l00002
ooooo`?o00005Oooool2o`0005Sooooo000Looooo`03o`000?oooooooooo053ooooo0_l00007oooo
o`;o00001_ooool4o`0000gooooo0_l00004ooooo`;o00006Oooool4o`0000;ooooo0_l00006oooo
o`;o000000?oooooo`000?l000000_l0000>ooooo`;o00000_ooool3o`0000?ooooo0_l000000ooo
oooo0000o`000007ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo1?l000000ooo
oooo0000o`00000Aooooo`;o0000F?ooool001cooooo0_l0001/ooooo`;o00001Oooool4o`0000?o
oooo1ol0000?ooooo`;o00000oooool3o`0000Oooooo0_l000001?oooooo0000o`000?ooool2o`00
0003ooooool0003o000001;ooooo0_l00006ooooo`;o00002_ooool2o`0000Sooooo0_l000000ooo
oooo0000o`000002ooooo`;o0000Ioooool001cooooo00?o0000ooooooooool0Eoooool2o`0000Oo
oooo0_l00009ooooo`;o00001oooool2o`0000?ooooo1ol0000?ooooo`;o00000oooool4o`000003
ooooool0003o000000?ooooo0_l00007ooooo`;o00009oooool2o`0000Cooooo0_l00008ooooo`;o
0000Ioooool001cooooo00?o0000ooooooooool0Eoooool2o`0000Gooooo1?l0000Hooooo`;o0000
0oooool2o`0000cooooo1?l00005ooooo`Ko00002oooool2o`0002Oooooo0ol00003ooooo`;o0000
3oooool2o`000003ooooool0003o000005gooooo000Looooo`03o`000?oooooooooo05kooooo0_l0
000;ooooo`;o000000?oooooo`000?l000002_ooool2o`0000?ooooo0_l0000<ooooo`Go00001Ooo
ool9o`000003ooooool0003o000000?o000000?oooooo`000?l000000oooool2o`0000Kooooo0_l0
0005ooooo`;o00000_ooool3o`0000oooooo0_l000000ooooooo0000o`00000Aooooo`;o000000?o
ooooo`000?l00000GOooool001cooooo00?o0000ooooooooool0F?ooool2o`0000;ooooo0_l0000=
ooooo`;o000000?oooooo`000?l000000_ooool3o`0000Oooooo0_l00006ooooo`;o00001oooool2
o`000003ooooool0003o000000Kooooo0_l00002ooooo`[o00001_ooool2o`000003ooooool0003o
000000?ooooo0_l00005ooooo`;o00000_ooool3o`0000_ooooo0_l00005ooooo`;o00004?ooool2
o`00067ooooo000Looooo`03o`000?oooooooooo05Sooooo0_l00002ooooo`;o00001?ooool4o`00
00cooooo0ol00007ooooo`;o00001_ooool2o`0000Oooooo0_l0000;ooooo`;o00000_ooool7o`00
00[ooooo0_l00003ooooo`;o00001Oooool6o`0000[ooooo1?l00002ooooo`;o00004oooool2o`00
067ooooo000Looooo`03o`000?oooooooooo04gooooo0_l0000Cooooo`Co00002?ooool2o`0000Oo
oooo0_l000000ooooooo0000o`000004ooooo`;o00006?ooool<o`0000Wooooo0_l00002ooooo`?o
00001Oooool4o`0000cooooo0_l00004ooooo`;o0000M_ooool001cooooo00?o0000ooooooooool0
COooool2o`0001Gooooo0_l00008ooooo`;o00001oooool2o`000003ooooool0003o000000Cooooo
1?l0000Hooooo`;o000000?oooooo`000?l000000oooool2o`0000Wooooo0_l00002ooooo`;o0000
1oooool2o`0000;ooooo0_l00002ooooo`;o0000Poooool001cooooo00?o0000ooooooooool0HOoo
ool2o`0000?ooooo0_l00006ooooo`;o00004_ooool4o`0000gooooo0_l00006ooooo`;o00001Ooo
ool4o`0000gooooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000ooo
ool2o`0000?ooooo0_l0000@ooooo`;o0000Ioooool001cooooo00?o0000ooooooooool0HOooool2
o`0000?ooooo0_l00006ooooo`;o00004oooool3o`0000;ooooo0_l00009ooooo`;o00001_ooool2
o`0000Gooooo1?l0000Aooooo`;o000000?oooooo`000?l000000_l0000;ooooo`;o00000_ooool3
o`00013ooooo0_l0001Wooooo`007?ooool00ol0003oooooooooo`1/ooooo`;o00000oooool2o`00
00_ooooo0_l00003ooooo`;o00000oooool2o`0000;ooooo0_l00006ooooo`?o00001?ooool2o`00
00?ooooo1_l000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l000001_ooool4o`00
00Wooooo0_l00004ooooo`?o00007Oooool2o`0005[ooooo000Looooo`03o`000?oooooooooo063o
oooo0_l0000:ooooo`;o00000oooool2o`0000_ooooo0_l00004ooooo`;o00001?ooool5o`0000Go
oooo1?l00003ooooo`;o00000oooool3o`000004ooooool0003o0000ooooo`Co00001?ooool2o`00
0003ooooool0003o000000Sooooo0_l00008ooooo`?o00009?ooool2o`0005[ooooo000Looooo`03
o`000?oooooooooo063ooooo0_l0000Gooooo`;o00002Oooool2o`0000Cooooo1Ol00004ooooo`;o
000000?oooooo`000?l000002Oooool2o`000003ooooool0003o000000?ooooo0_l0000Kooooo`;o
00001oooool2o`0007Sooooo000Looooo`03o`000?oooooooooo07Wooooo0_l0000Aooooo`;o0000
1Oooool2o`000003ooooool0003o000000;ooooo0_l00005ooooo`?o00004_ooool2o`0000;ooooo
0_l0000Cooooo`;o0000N?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Co
oooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo07;ooooo0_l00008oooo
o`;o00006?ooool2o`0000;ooooo0_l00005ooooo`?o00001?ooool2o`0000?ooooo0_l00007oooo
o`?o000000?oooooo`000?l000005Oooool2o`0007Kooooo00001_ooooooMgMgoiRHV?ooooooV9RH
ogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003ooooooooo
o`1booooo`;o00002?ooool2o`0000Wooooo0_l00004ooooo`;o00000oooool4o`0001;ooooo0_l0
0003ooooo`;o00002?ooool5o`0000Oooooo0_l0000<ooooo`;o000000?oooooo`000?l000004?oo
ool2o`00067ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo07?ooooo0_l0000Booooo`;o00001?oo
ool2o`0000?ooooo1_l0000@ooooo`?o000000?oooooo`000?l000002_ooool2o`0000Wooooo0_l0
000?ooooo`;o00000oooool2o`0000_ooooo0_l0001Qooooo`0000?oooooo`000?ooool00_ooool0
0ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`0006oooooo0_l0
0002ooooo`;o00003_ooool2o`00017ooooo0ol00008ooooo`;o00001?ooool4o`000003ooooool0
003o000000oooooo1?l0000@ooooo`;o00000_ooool2o`0000;ooooo0_l0001^ooooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_oo
ool00ol0003oooooooooo`1_ooooo`Go00001oooool2o`0000Kooooo0_l0000?ooooo`;o000000?o
ooooo`000?l000002?ooool2o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`;o00003?oo
ool4o`000003ooooool0003o000000gooooo0_l00002ooooo`;o0000L_ooool00003ooooool@413o
oooo00;ooooo00?o410@ooooooooool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o
0000ooooooooool0LOooool3o`0000Oooooo0_l00005ooooo`;o00004?ooool2o`0001Cooooo1?l0
00001?oooooo0000o`000?l00004ooooo`;o00002_ooool2o`0000?ooooo0_l0000Fooooo`;o0000
J?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o0000
00Kooooo00?o0000ooooooooool0LOooool4o`0000Gooooo0_l00002ooooo`;o00000_ooool2o`00
00?ooooo0_l000000ooooooo0000o`00000:ooooo`;o00005?ooool2o`0000;ooooo0_l00004oooo
o`;o00003oooool2o`0001Kooooo0_l0001Xooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;
ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`1Dooooo`;o00007Ooo
ool2o`0000Gooooo0_l000001?oooooo0000o`000?l00003ooooo`;o00000_ooool2o`000003oooo
ool0003o000000Gooooo0_l00003ooooo`;o00003?ooool2o`0000Kooooo0_l0002Kooooo`007?oo
ool00ol0003oooooooooo`1Dooooo`;o00009oooool4o`0000;ooooo0_l00004ooooo`;o00001_oo
ool2o`00017ooooo0_l0000@ooooo`;o0000TOooool001cooooo00?o0000ooooooooool0N?ooool2
o`0000?ooooo1?l000000ooooooo0000o`000005ooooo`;o00001oooool3o`0000oooooo0_l0000:
ooooo`;o000000Coooooo`000?l0003ooooo0_l0002Aooooo`007?ooool00ol0003oooooooooo`1h
ooooo`;o00001?ooool2o`0000;ooooo0_l00006ooooo`;o00001_ooool3o`0000Gooooo0ol00002
ooooo`;o00000oooool2o`0000[ooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l0
0004ooooo`;o0000Q_ooool001cooooo00?o0000ooooooooool0O_ooool2o`0000;ooooo0_l00000
0ooooooo0000o`000003ooooo`;o00003_ooool4o`000003ooooool0003o000001;ooooo0_l00000
0ooooooo0000o`000003ooooo`;o00001?ooool2o`000003ooooool0003o000008?ooooo000Loooo
o`03o`000?oooooooooo08;ooooo1Ol000000ooooooo0000o`00000>ooooo`;o000000Coooooo`00
0?l0003o00000oooool2o`0001?ooooo0_l0000<ooooo`;o0000Poooool001cooooo00?o0000oooo
ooooool0O?ooool2o`0000Kooooo0_l00002ooooo`;o00003_ooool2o`000003ooooool0003o0000
00;ooooo1?l00004ooooo`;o00003Oooool4o`0008oooooo000Looooo`03o`000?oooooooooo07co
oooo0_l0000:ooooo`;o00001_ooool2o`0000gooooo0_l00006ooooo`;o00003Oooool4o`0008oo
oooo000Looooo`03o`000?oooooooooo093ooooo0_l00006ooooo`;o00003Oooool2o`000:3ooooo
000Looooo`03o`000?oooooooooo08Sooooo0_l0000>ooooo`;o00005?ooool2o`0000;ooooo0_l0
002Eooooo`007?ooool00ol0003oooooooooo`28ooooo`;o00009?ooool2o`0000;ooooo0_l00002
ooooo`;o0000TOooool001cooooo00?o0000ooooooooool0]_ooool2o`00097ooooo000Looooo`;o
0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3=ooooo`;o0000N_ooool001cooooo00?o
0000ooooooooool0cOooool2o`0007[ooooo000Looooo`03o`000?oooooooooo0:Gooooo0_l0002R
ooooo`007?ooool00ol0003oooooooooo`2Uooooo`;o00007Oooool2o`0000Gooooo0_l0001loooo
o`007?ooool00ol0003oooooooooo`1hooooo`;o0000B_ooool2o`0000Gooooo0_l0001looooo`00
7?ooool00ol0003oooooooooo`1hooooo`;o0000;?ooool2o`000:7ooooo000Looooo`03o`000?oo
oooooooo0:Kooooo0_l00008ooooo`;o00001oooool4o`0008cooooo000Looooo`03o`000?oooooo
oooo0;3ooooo0_l00007ooooo`Co0000S?ooool001cooooo00?o0000ooooooooool0Loooool2o`00
03kooooo0_l0002Dooooo`007?ooool00ol0003oooooooooo`1cooooo`;o0000?_ooool2o`0009Co
oooo000Looooo`03o`000?oooooooooo0;3ooooo0_l0002Gooooo`007?ooool00ol0003ooooooooo
o`2`ooooo`;o0000Uoooool001cooooo00?o0000ooooooooool0/?ooool2o`0009Oooooo000Loooo
o`03o`000?oooooooooo0;3ooooo0_l0002Gooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`;o0000[Oooool2o`0009_ooooo000Looooo`03o`000?oooooooooo0:cooooo0_l0
002Kooooo`007?ooool00ol0003oooooooooo`2_ooooo`;o0000V?ooool001cooooo00?o0000oooo
ooooool0[oooool2o`0009Sooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo08gooooo0_l0000Fooooo`;o0000X_ooool001cooooo00?o0000oooo
ooooool0SOooool2o`0000kooooo0_l00006ooooo`;o0000X_ooool001cooooo00?o0000oooooooo
ool0WOooool2o`000:[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Booooo`Co0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05
ooooo`?o0000oooooom:ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03
o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?oo
ool00ol0003oooooooooo`3ooooooe;ooooo000Booooo`03oeEEEOmVIVKo00000?ooooooE?ooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:7ooooo00Co410@o`000?l0003ooooo
0_l000000ol@413oooooooooo`0Fooooo`Co000000Co410@oooooooooooooooo1?l000000ol@413o
ooooooooo`05o`0000?ooooo1Ol0002<ooooo`00X_ooool01Ol0003ooooooooooooooooo000000Wo
oooo1_l0000<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01OnHV9So
8B4Qonk^k_ooooooA4A400?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A02<ooooo`00X_ooool01Ol0
003ooooooooooooooooo000001_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03
ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?oV9RHob4Q8Oo^k^h0SOooool00:;ooooo00Go0000oooo
ooooooooooooo`000009ooooo`Ko00003?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?oV9RHob4Q8Oo^k^h01Oooool00onHV9So8B4Qonk^kP2<ooooo`00X_ooool01Ol0
003oQhN7oooooonYZJWo000001_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03ogMgMomVIVKooooo00Gooooo00?oMgMgofIVI_ooool0Roooool00:7ooooo00?o410@o`00
0?mgMgL00_l000000onHV9Soooooooooo`0Iooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08[ooooo0032ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01Ol0003o^[ZjoooooonHV9So410@
00?ooooo00Go0000okZj^_ooooooV9RHoa0@402<ooooo`00`?ooool00omEEEGoIVIVo`000005oooo
o`03oeEEEOmVIVKo000000Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`0S?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1128) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.36424 .43923 Mdot
.34455 .46795 Mdot
.58015 .65949 Mdot
.51308 .38356 Mdot
.23702 .64557 Mdot
.58888 .6222 Mdot
.42301 .59595 Mdot
.43242 .64825 Mdot
.58191 .64941 Mdot
.26009 .5332 Mdot
.42535 .60094 Mdot
.45188 .39156 Mdot
.42846 .61321 Mdot
.51324 .36161 Mdot
.1499 .52246 Mdot
.48156 .40096 Mdot
.29136 .47188 Mdot
.69235 .47903 Mdot
.56942 .42387 Mdot
.57882 .59049 Mdot
.2933 .4395 Mdot
.5175 .3719 Mdot
.37075 .47498 Mdot
.51355 .36085 Mdot
.51181 .40093 Mdot
.31887 .44879 Mdot
.28823 .49247 Mdot
.55633 .39611 Mdot
.50548 .40854 Mdot
.43875 .64291 Mdot
.67383 .37417 Mdot
.16682 .58186 Mdot
.59142 .38768 Mdot
.50189 .80649 Mdot
.42329 .64844 Mdot
.36352 .38531 Mdot
.60133 .63269 Mdot
.42171 .63781 Mdot
.41406 .64244 Mdot
.42074 .58947 Mdot
.41306 .62626 Mdot
.33145 .45067 Mdot
.46253 .5831 Mdot
.47672 .57333 Mdot
.50198 .41902 Mdot
.27997 .646 Mdot
.54487 .219 Mdot
.56286 .35394 Mdot
.29473 .46162 Mdot
.663 .66354 Mdot
.40881 .74254 Mdot
.4098 .59743 Mdot
.62123 .62106 Mdot
.61585 .87356 Mdot
.43061 .63817 Mdot
.52315 .42931 Mdot
.59898 .6521 Mdot
.5261 .3661 Mdot
.51704 .35692 Mdot
.2916 .32129 Mdot
.57647 .3826 Mdot
.67872 .49513 Mdot
.38236 .45231 Mdot
.57182 .48501 Mdot
.59049 .64676 Mdot
.40705 .62986 Mdot
.35624 .46067 Mdot
.43319 .61889 Mdot
.50936 .29984 Mdot
.59792 .58196 Mdot
.56364 .35708 Mdot
.41031 .61594 Mdot
.30686 .43893 Mdot
.55614 .37275 Mdot
.70557 .68421 Mdot
.2166 .32944 Mdot
.63831 .53571 Mdot
.32275 .35378 Mdot
.27511 .35459 Mdot
.71098 .59674 Mdot
.49332 .36309 Mdot
.7074 .31228 Mdot
.1894 .41681 Mdot
.35562 .49069 Mdot
.60354 .36524 Mdot
.60349 .55152 Mdot
.55098 .37172 Mdot
.22894 .56493 Mdot
.49325 .40428 Mdot
.7173 .70423 Mdot
.57655 .63969 Mdot
.32168 .47464 Mdot
.51088 .38265 Mdot
.55787 .40157 Mdot
.55278 .23546 Mdot
.54981 .31843 Mdot
.54154 .3945 Mdot
.32724 .43335 Mdot
.40197 .6076 Mdot
.47097 .41326 Mdot
.44265 .56974 Mdot
.61223 .66514 Mdot
.54127 .32441 Mdot
.60691 .60008 Mdot
.29963 .44061 Mdot
.56257 .37739 Mdot
.40508 .64106 Mdot
.53481 .32854 Mdot
.35402 .63759 Mdot
.34769 .46935 Mdot
.55208 .40452 Mdot
.67582 .48666 Mdot
.81938 .47285 Mdot
.32323 .48124 Mdot
.74231 .5707 Mdot
.48831 .36759 Mdot
.53722 .38511 Mdot
.34191 .4668 Mdot
.60052 .67123 Mdot
.21987 .53496 Mdot
.37243 .48396 Mdot
.40918 .59183 Mdot
.38287 .46539 Mdot
.59488 .33346 Mdot
.58162 .6358 Mdot
.47429 .76154 Mdot
.4137 .68971 Mdot
.67326 .3432 Mdot
.54588 .36928 Mdot
.30363 .58106 Mdot
.57121 .60624 Mdot
.32564 .46497 Mdot
.43721 .61815 Mdot
.55235 .44314 Mdot
.35349 .48092 Mdot
.44664 .61173 Mdot
.68863 .48853 Mdot
.51123 .72744 Mdot
.30409 .48746 Mdot
.45024 .5592 Mdot
.42354 .66051 Mdot
.41828 .5923 Mdot
.5623 .81284 Mdot
.34994 .45861 Mdot
.66779 .51608 Mdot
.44091 .62922 Mdot
.65331 .37196 Mdot
.54273 .42213 Mdot
.7279 .37632 Mdot
.63888 .21206 Mdot
.52071 .80925 Mdot
.56417 .7279 Mdot
.67491 .53132 Mdot
.38989 .61267 Mdot
.52787 .40788 Mdot
.31538 .44478 Mdot
.33555 .44698 Mdot
.57624 .36836 Mdot
.5114 .39145 Mdot
.56504 .36482 Mdot
.55238 .40791 Mdot
.26593 .32458 Mdot
.51661 .32379 Mdot
.6003 .21858 Mdot
.31741 .47763 Mdot
.52489 .3974 Mdot
.60913 .64881 Mdot
.58197 .33035 Mdot
.41046 .62433 Mdot
.52402 .37431 Mdot
.51526 .38632 Mdot
.57791 .38332 Mdot
.40777 .59879 Mdot
.1713 .53375 Mdot
.7015 .26664 Mdot
.19527 .60637 Mdot
.74081 .6489 Mdot
.58897 .60218 Mdot
.54717 .3774 Mdot
.66475 .49662 Mdot
.38972 .36124 Mdot
.49955 .35309 Mdot
.86696 .42777 Mdot
.53167 .39014 Mdot
.20859 .6105 Mdot
.53805 .27855 Mdot
.20437 .65646 Mdot
.71207 .33947 Mdot
.53344 .41122 Mdot
.62402 .37527 Mdot
.41488 .43609 Mdot
.48294 .59215 Mdot
.41498 .62409 Mdot
.60664 .65554 Mdot
.59062 .66073 Mdot
.37741 .61569 Mdot
.25396 .47033 Mdot
.61362 .37217 Mdot
.52573 .30602 Mdot
.6105 .58342 Mdot
.36796 .4329 Mdot
.69126 .52194 Mdot
.34854 .43841 Mdot
.26325 .23671 Mdot
.39354 .71971 Mdot
.38768 .59626 Mdot
.64387 .49757 Mdot
.56557 .63819 Mdot
.61613 .65071 Mdot
.65459 .50411 Mdot
.54379 .34057 Mdot
.35332 .45643 Mdot
.47153 .82084 Mdot
.25945 .49043 Mdot
.53394 .83053 Mdot
.31663 .43809 Mdot
.30975 .54545 Mdot
.44184 .60864 Mdot
.60271 .61704 Mdot
.53938 .38821 Mdot
.54092 .34752 Mdot
.27781 .45742 Mdot
.56287 .36178 Mdot
.54141 .25536 Mdot
.55058 .392 Mdot
.44076 .74847 Mdot
.64005 .54108 Mdot
.37799 .61436 Mdot
.66679 .32432 Mdot
.37119 .4606 Mdot
.76509 .47907 Mdot
.61403 .609 Mdot
.37129 .36394 Mdot
.40958 .61263 Mdot
.68525 .49082 Mdot
.61372 .6016 Mdot
.69246 .52241 Mdot
.59014 .37665 Mdot
.56343 .65632 Mdot
.66061 .49057 Mdot
.2516 .40305 Mdot
.54073 .41864 Mdot
.26279 .32154 Mdot
.39339 .61392 Mdot
.36702 .48906 Mdot
.57493 .3843 Mdot
.59867 .60074 Mdot
.59427 .38407 Mdot
.55372 .70557 Mdot
.47177 .76053 Mdot
.59621 .6799 Mdot
.64643 .69008 Mdot
.68881 .50083 Mdot
.50415 .68166 Mdot
.32228 .56703 Mdot
.29503 .45592 Mdot
.52451 .31952 Mdot
.19019 .65568 Mdot
.44071 .62895 Mdot
.53262 .33204 Mdot
.49227 .78451 Mdot
.43608 .63078 Mdot
.52795 .36501 Mdot
.4011 .64918 Mdot
.33839 .4471 Mdot
.78798 .41968 Mdot
.29142 .46924 Mdot
.48976 .3956 Mdot
.4007 .63849 Mdot
.58462 .67191 Mdot
.31107 .45182 Mdot
.54796 .33693 Mdot
.5574 .38653 Mdot
.52915 .51299 Mdot
.53193 .40092 Mdot
.18303 .55764 Mdot
.54795 .40178 Mdot
.60258 .65671 Mdot
.56401 .33083 Mdot
.8226 .61809 Mdot
.42774 .69586 Mdot
.35585 .45965 Mdot
.57935 .67411 Mdot
.58472 .65392 Mdot
.7477 .54053 Mdot
.49965 .64036 Mdot
.49094 .35543 Mdot
.59249 .60018 Mdot
.76284 .43694 Mdot
.45216 .62302 Mdot
.5293 .31658 Mdot
.4601 .55665 Mdot
.6663 .65643 Mdot
.61693 .59848 Mdot
.54302 .43997 Mdot
.28346 .46657 Mdot
.51055 .38391 Mdot
.61384 .65231 Mdot
.31661 .42324 Mdot
.48392 .37018 Mdot
.37744 .518 Mdot
.52739 .51238 Mdot
.4441 .6012 Mdot
.55916 .27933 Mdot
.54575 .3303 Mdot
.60715 .61663 Mdot
.36333 .45275 Mdot
.44859 .6401 Mdot
.32059 .45328 Mdot
.3224 .74872 Mdot
.35657 .632 Mdot
.24947 .37646 Mdot
.7036 .47914 Mdot
.62529 .73362 Mdot
.23309 .69144 Mdot
.7898 .60272 Mdot
.73455 .452 Mdot
.38519 .80144 Mdot
.61154 .6509 Mdot
.51759 .78638 Mdot
.58881 .65707 Mdot
.49865 .38917 Mdot
.58549 .63751 Mdot
.22692 .68853 Mdot
.54928 .39318 Mdot
.5908 .63467 Mdot
.77732 .47617 Mdot
.51842 .39278 Mdot
.3274 .4844 Mdot
.16933 .47927 Mdot
.80332 .60116 Mdot
.45531 .77307 Mdot
.55596 .6307 Mdot
.69626 .44489 Mdot
.54253 .39715 Mdot
.57254 .3375 Mdot
.2978 .46564 Mdot
.53331 .31357 Mdot
.68652 .52518 Mdot
.64527 .49475 Mdot
.44194 .45835 Mdot
.72443 .3097 Mdot
.46796 .34055 Mdot
.30684 .45411 Mdot
.32459 .26286 Mdot
.69275 .69361 Mdot
.65201 .70063 Mdot
.38788 .63777 Mdot
.17986 .49724 Mdot
.49038 .27519 Mdot
.3838 .5775 Mdot
.49013 .58489 Mdot
.33246 .47647 Mdot
.17351 .55462 Mdot
.41752 .62677 Mdot
.4577 .22686 Mdot
.62945 .42253 Mdot
.53974 .34163 Mdot
.41182 .60607 Mdot
.46047 .34698 Mdot
.79635 .63662 Mdot
.4877 .19203 Mdot
.64316 .25453 Mdot
.48433 .3866 Mdot
.71766 .67412 Mdot
.52877 .38006 Mdot
.21588 .51838 Mdot
.55036 .40095 Mdot
.31364 .45783 Mdot
.23528 .52174 Mdot
.48748 .48576 Mdot
.66953 .24489 Mdot
.38162 .70794 Mdot
.67567 .53122 Mdot
.54608 .38796 Mdot
.5382 .34099 Mdot
.68924 .51682 Mdot
.33368 .4926 Mdot
.55197 .4087 Mdot
.75791 .47844 Mdot
.55453 .36429 Mdot
.41479 .63375 Mdot
.62626 .25563 Mdot
.30779 .50861 Mdot
.50478 .31232 Mdot
.35094 .42813 Mdot
.44626 .6017 Mdot
.41948 .6454 Mdot
.47843 .40262 Mdot
.438 .58645 Mdot
.52409 .38588 Mdot
.49739 .18154 Mdot
.31539 .48923 Mdot
.54342 .26735 Mdot
.3657 .47894 Mdot
.31501 .35931 Mdot
.41073 .64739 Mdot
.43247 .73705 Mdot
.48551 .43308 Mdot
.41877 .62241 Mdot
.35896 .6032 Mdot
.46974 .34157 Mdot
.47598 .37462 Mdot
.68473 .73263 Mdot
.55995 .64405 Mdot
.51902 .50189 Mdot
.42695 .65197 Mdot
.552 .33474 Mdot
.50959 .3155 Mdot
.4429 .59785 Mdot
.41912 .2185 Mdot
.79375 .52918 Mdot
.55064 .39656 Mdot
.30949 .46667 Mdot
.32566 .46281 Mdot
.47967 .37697 Mdot
.52411 .32732 Mdot
.57223 .61768 Mdot
.56544 .66207 Mdot
.55309 .6185 Mdot
.52531 .51099 Mdot
.43567 .74185 Mdot
.30654 .6927 Mdot
.42118 .58951 Mdot
.32425 .60868 Mdot
.7307 .68984 Mdot
.58674 .32784 Mdot
.56686 .60462 Mdot
.52644 .3388 Mdot
.5145 .38011 Mdot
.45164 .63684 Mdot
.46788 .7786 Mdot
.46347 .32166 Mdot
.31687 .49237 Mdot
.4361 .65066 Mdot
.56965 .44734 Mdot
.3357 .67702 Mdot
.67188 .48971 Mdot
.59229 .79339 Mdot
.40795 .61868 Mdot
.33304 .4804 Mdot
.40566 .64802 Mdot
.54492 .35034 Mdot
.55003 .43213 Mdot
.33466 .46956 Mdot
.64572 .50258 Mdot
.58547 .34679 Mdot
.52945 .3679 Mdot
.74958 .27949 Mdot
.74238 .66314 Mdot
.44926 .74063 Mdot
.53769 .40912 Mdot
.49192 .32566 Mdot
.70211 .50022 Mdot
.55187 .35915 Mdot
.57054 .37628 Mdot
.80525 .41572 Mdot
.38856 .68521 Mdot
.66949 .4772 Mdot
.43856 .2287 Mdot
.31159 .44063 Mdot
.18069 .62561 Mdot
.60189 .61205 Mdot
.42629 .58209 Mdot
.80392 .51761 Mdot
.61538 .66244 Mdot
.58619 .72009 Mdot
.17682 .60908 Mdot
.51489 .50186 Mdot
.66815 .56616 Mdot
.44924 .36637 Mdot
.56556 .38906 Mdot
.53285 .37994 Mdot
.66601 .50009 Mdot
.34785 .45371 Mdot
.54137 .50146 Mdot
.30402 .25547 Mdot
.52132 .37684 Mdot
.55416 .2603 Mdot
.22677 .42479 Mdot
.66764 .64265 Mdot
.67219 .52761 Mdot
.64429 .50221 Mdot
.54253 .38566 Mdot
.80783 .44833 Mdot
.31751 .44844 Mdot
.54671 .33609 Mdot
.49305 .34289 Mdot
.55646 .63896 Mdot
.34916 .47353 Mdot
.61355 .64627 Mdot
.42257 .72793 Mdot
.20451 .61243 Mdot
.75598 .27841 Mdot
.41652 .64711 Mdot
.21724 .46516 Mdot
.44445 .63668 Mdot
.69755 .30416 Mdot
.61788 .648 Mdot
.49538 .35611 Mdot
.36678 .45572 Mdot
.54214 .33183 Mdot
.51533 .33169 Mdot
.54207 .33957 Mdot
.54658 .30632 Mdot
.86657 .48352 Mdot
.64977 .50575 Mdot
.48401 .32794 Mdot
.59202 .66364 Mdot
.1981 .49813 Mdot
.20826 .3559 Mdot
.5328 .34448 Mdot
.55365 .38539 Mdot
.33771 .48736 Mdot
.57422 .35481 Mdot
.44992 .62759 Mdot
.36073 .44947 Mdot
.55541 .40366 Mdot
.18754 .49921 Mdot
.51874 .41606 Mdot
.2008 .6373 Mdot
.40945 .65057 Mdot
.35892 .57575 Mdot
.48166 .32595 Mdot
.47289 .7577 Mdot
.5192 .50192 Mdot
.58672 .59479 Mdot
.45897 .59203 Mdot
.60009 .63535 Mdot
.39837 .18778 Mdot
.57163 .41643 Mdot
.52354 .4069 Mdot
.5143 .31554 Mdot
.59129 .60195 Mdot
.22668 .58512 Mdot
.47563 .6892 Mdot
.5834 .43797 Mdot
.58076 .60959 Mdot
.37379 .43899 Mdot
.61744 .48039 Mdot
.36868 .46506 Mdot
.64505 .492 Mdot
.42631 .60209 Mdot
.64745 .52379 Mdot
.4754 .79052 Mdot
.3451 .46959 Mdot
.27463 .47612 Mdot
.59431 .61105 Mdot
.5474 .5544 Mdot
.53103 .87593 Mdot
.60071 .50576 Mdot
.70312 .36334 Mdot
.29929 .46783 Mdot
.49171 .39339 Mdot
.67058 .28627 Mdot
.53592 .55159 Mdot
.59899 .63888 Mdot
.50122 .36113 Mdot
.79567 .44219 Mdot
.57229 .61661 Mdot
.52884 .31741 Mdot
.57371 .65958 Mdot
.41503 .61408 Mdot
.56271 .61789 Mdot
.29973 .49172 Mdot
.55886 .37911 Mdot
.50092 .87027 Mdot
.62932 .50547 Mdot
.54205 .40238 Mdot
.43296 .65218 Mdot
.40531 .50269 Mdot
.5135 .33886 Mdot
.69615 .49361 Mdot
.58283 .62832 Mdot
.59441 .52103 Mdot
.55126 .39775 Mdot
.58876 .60401 Mdot
.37179 .44815 Mdot
.45624 .58759 Mdot
.48327 .46603 Mdot
.46669 .76095 Mdot
.29796 .46254 Mdot
.42638 .56089 Mdot
.4631 .60824 Mdot
.49714 .31946 Mdot
.51274 .32388 Mdot
.31419 .46564 Mdot
.77426 .38438 Mdot
.57279 .34423 Mdot
.49348 .36286 Mdot
.59548 .66435 Mdot
.59685 .63151 Mdot
.77831 .40419 Mdot
.59585 .67229 Mdot
.55534 .42954 Mdot
.31485 .46369 Mdot
.50634 .3777 Mdot
.33805 .48486 Mdot
.56829 .34367 Mdot
.30065 .42509 Mdot
.33291 .49448 Mdot
.4814 .67609 Mdot
.50405 .36927 Mdot
.54383 .27621 Mdot
.52898 .33208 Mdot
.56118 .36675 Mdot
.57164 .62326 Mdot
.65898 .51926 Mdot
.51431 .43811 Mdot
.63316 .51363 Mdot
.69415 .51651 Mdot
.41097 .4522 Mdot
.5568 .6381 Mdot
.67257 .51008 Mdot
.23148 .36666 Mdot
.55249 .6267 Mdot
.67473 .49713 Mdot
.2054 .37404 Mdot
.42091 .64862 Mdot
.29023 .47706 Mdot
.51724 .39294 Mdot
.38405 .79463 Mdot
.55802 .2136 Mdot
.61443 .67271 Mdot
.54601 .40261 Mdot
.52226 .33861 Mdot
.36966 .48421 Mdot
.46749 .1512 Mdot
.58928 .58437 Mdot
.50434 .40176 Mdot
.35725 .46446 Mdot
.51353 .1537 Mdot
.60415 .65131 Mdot
.67152 .49761 Mdot
.40434 .60017 Mdot
.39159 .46654 Mdot
.41781 .6886 Mdot
.42978 .59479 Mdot
.62498 .61757 Mdot
.41637 .74339 Mdot
.48821 .36664 Mdot
.56901 .60317 Mdot
.61351 .79158 Mdot
.27532 .50327 Mdot
.46954 .64341 Mdot
.68457 .44487 Mdot
.32989 .47734 Mdot
.44868 .62863 Mdot
.6538 .5259 Mdot
.32059 .43682 Mdot
.31662 .48612 Mdot
.456 .6261 Mdot
.44103 .43777 Mdot
.46732 .55795 Mdot
.41635 .63985 Mdot
.69466 .71853 Mdot
.35809 .75188 Mdot
.56837 .60189 Mdot
.68904 .52042 Mdot
.4437 .79662 Mdot
.33013 .4505 Mdot
.17914 .4999 Mdot
.62313 .7806 Mdot
.54132 .39454 Mdot
.67456 .51487 Mdot
.25981 .6386 Mdot
.33746 .22267 Mdot
.43468 .6323 Mdot
.48507 .49129 Mdot
.66559 .53675 Mdot
.57567 .3803 Mdot
.64272 .40902 Mdot
.49753 .3734 Mdot
.43634 .60302 Mdot
.27739 .33656 Mdot
.33377 .48113 Mdot
.45353 .63776 Mdot
.58891 .79527 Mdot
.52204 .38279 Mdot
.50161 .36573 Mdot
.65626 .32212 Mdot
.33269 .442 Mdot
.58855 .59409 Mdot
.48923 .36196 Mdot
.52702 .37078 Mdot
.52011 .43344 Mdot
.57066 .28309 Mdot
.81571 .46959 Mdot
.50062 .39524 Mdot
.39623 .71109 Mdot
.49984 .3141 Mdot
.50644 .36595 Mdot
.35127 .42787 Mdot
.80192 .32892 Mdot
.41735 .72448 Mdot
.52532 .37394 Mdot
.49331 .39402 Mdot
.45807 .61985 Mdot
.47916 .55369 Mdot
.53989 .56133 Mdot
.58148 .53484 Mdot
.72037 .44871 Mdot
.54215 .30398 Mdot
.36384 .46478 Mdot
.66855 .4862 Mdot
.4833 .35182 Mdot
.36282 .46668 Mdot
.57385 .39955 Mdot
.57325 .61331 Mdot
.5518 .63191 Mdot
.37882 .55198 Mdot
.67589 .50486 Mdot
.62497 .28056 Mdot
.31911 .61974 Mdot
.59986 .66461 Mdot
.51912 .40453 Mdot
.42804 .57909 Mdot
.61471 .65057 Mdot
.60794 .56235 Mdot
.61007 .37416 Mdot
.32284 .44494 Mdot
.32098 .47706 Mdot
.73017 .37816 Mdot
.53293 .72519 Mdot
.76212 .30873 Mdot
.41614 .61117 Mdot
.58534 .36752 Mdot
.30996 .56795 Mdot
.32204 .47925 Mdot
.68203 .29782 Mdot
.67468 .5106 Mdot
.43643 .63293 Mdot
.62266 .70681 Mdot
.34822 .48347 Mdot
.29499 .47773 Mdot
.50182 .41209 Mdot
.5326 .35727 Mdot
.7392 .45144 Mdot
.68224 .54292 Mdot
.44924 .60556 Mdot
.69014 .51746 Mdot
.61387 .59898 Mdot
.49867 .39483 Mdot
.36706 .48135 Mdot
.41132 .77688 Mdot
.49105 .38849 Mdot
.56999 .62216 Mdot
.32835 .47437 Mdot
.69158 .51099 Mdot
.69763 .50808 Mdot
.55979 .3667 Mdot
.32955 .26347 Mdot
.42407 .63274 Mdot
.32701 .48342 Mdot
.35528 .6914 Mdot
.56303 .32876 Mdot
.53586 .36274 Mdot
.55745 .29125 Mdot
.45263 .62917 Mdot
.3496 .56122 Mdot
.6444 .52785 Mdot
.34247 .45575 Mdot
.52593 .41321 Mdot
.68063 .49884 Mdot
.33606 .56277 Mdot
.59823 .67918 Mdot
.56186 .62482 Mdot
.69737 .49686 Mdot
.67852 .5201 Mdot
.69499 .49544 Mdot
.17709 .49683 Mdot
.31735 .50095 Mdot
.47796 .28801 Mdot
.57542 .34588 Mdot
.71556 .35841 Mdot
.54666 .44684 Mdot
.43546 .65446 Mdot
.56186 .64581 Mdot
.52129 .33196 Mdot
.48825 .39083 Mdot
.55557 .28313 Mdot
.51591 .27264 Mdot
.29504 .50231 Mdot
.34816 .47094 Mdot
.57917 .40251 Mdot
.56321 .65342 Mdot
.29385 .20743 Mdot
.33285 .7919 Mdot
.47336 .34175 Mdot
.50986 .56962 Mdot
.36402 .48385 Mdot
.45119 .59524 Mdot
.57858 .54934 Mdot
.39981 .64267 Mdot
.33788 .45861 Mdot
.49902 .39424 Mdot
.32573 .62219 Mdot
.69934 .49671 Mdot
.56173 .34724 Mdot
.44535 .6173 Mdot
.56471 .35569 Mdot
.42789 .59498 Mdot
.28954 .72288 Mdot
.7483 .67809 Mdot
.53299 .39072 Mdot
.48147 .33594 Mdot
.7091 .45773 Mdot
.53049 .3441 Mdot
.6322 .46976 Mdot
.35737 .48832 Mdot
.73235 .29568 Mdot
.52481 .42295 Mdot
.38658 .30422 Mdot
.56296 .32768 Mdot
.79302 .4587 Mdot
.53727 .35851 Mdot
.67004 .65971 Mdot
.55956 .39369 Mdot
.56819 .37622 Mdot
.39993 .63958 Mdot
.45718 .62355 Mdot
.32287 .43068 Mdot
.5959 .59861 Mdot
.1936 .61772 Mdot
.53191 .36657 Mdot
.46954 .76385 Mdot
.36213 .66187 Mdot
.67899 .52151 Mdot
.33651 .45651 Mdot
.47306 .14342 Mdot
.39198 .6385 Mdot
.76679 .59492 Mdot
.7748 .42942 Mdot
.41248 .69714 Mdot
.59806 .54976 Mdot
.22444 .51374 Mdot
.68691 .49747 Mdot
.57847 .37637 Mdot
.45223 .78352 Mdot
.66723 .70214 Mdot
.61091 .38441 Mdot
.45975 .62722 Mdot
.38281 .352 Mdot
.42925 .78656 Mdot
.65116 .53737 Mdot
.64669 .5252 Mdot
.4137 .59709 Mdot
.6406 .68425 Mdot
.46369 .3289 Mdot
.67756 .51078 Mdot
.59422 .66982 Mdot
.56082 .60703 Mdot
.53079 .66337 Mdot
.32559 .44737 Mdot
.55384 .80107 Mdot
.29105 .63764 Mdot
.43266 .59564 Mdot
.66182 .57364 Mdot
.36177 .49919 Mdot
.29074 .49019 Mdot
.59903 .61809 Mdot
.5694 .62876 Mdot
.28731 .476 Mdot
.5409 .42685 Mdot
.52812 .28224 Mdot
.52367 .37691 Mdot
.66077 .50351 Mdot
.53737 .3523 Mdot
.57701 .61621 Mdot
.43351 .62771 Mdot
.5704 .63804 Mdot
.39938 .64923 Mdot
.31539 .69243 Mdot
.55382 .34498 Mdot
.55966 .38238 Mdot
.55399 .20958 Mdot
.35317 .43302 Mdot
.37814 .7133 Mdot
.45756 .76326 Mdot
.58912 .65871 Mdot
.57142 .37588 Mdot
.37329 .45951 Mdot
.63837 .52107 Mdot
.55128 .20689 Mdot
.53431 .32387 Mdot
.36368 .48304 Mdot
.51565 .40919 Mdot
.23614 .38896 Mdot
.83533 .54678 Mdot
.32182 .45588 Mdot
.63252 .21106 Mdot
.50292 .40497 Mdot
.23602 .48013 Mdot
.50895 .31996 Mdot
.75151 .41839 Mdot
.57158 .34256 Mdot
.31561 .43822 Mdot
.52168 .3713 Mdot
.34448 .44158 Mdot
.60892 .64577 Mdot
.43197 .58965 Mdot
.30102 .47559 Mdot
.4996 .33173 Mdot
.22723 .74896 Mdot
.43175 .60413 Mdot
.54234 .38804 Mdot
.39509 .61569 Mdot
.35712 .45562 Mdot
.29385 .47012 Mdot
.28932 .26054 Mdot
.42826 .72181 Mdot
.4152 .615 Mdot
.50457 .39965 Mdot
.26028 .59317 Mdot
.50254 .37777 Mdot
.72599 .42283 Mdot
.51364 .42806 Mdot
.56611 .33359 Mdot
.22132 .32378 Mdot
.45399 .61676 Mdot
.784 .34045 Mdot
.2743 .27694 Mdot
.18851 .47791 Mdot
.39036 .45175 Mdot
.64512 .5339 Mdot
.17333 .54601 Mdot
.43505 .7378 Mdot
.58473 .60552 Mdot
.52485 .33214 Mdot
.34904 .50712 Mdot
.42461 .63952 Mdot
.65666 .51622 Mdot
.53387 .39073 Mdot
.56811 .63059 Mdot
.78422 .55214 Mdot
.38769 .61605 Mdot
.33265 .45122 Mdot
.32576 .4953 Mdot
.5782 .17514 Mdot
.53402 .41166 Mdot
.56195 .38391 Mdot
.43157 .60166 Mdot
.30102 .5225 Mdot
.68974 .49829 Mdot
.78122 .49676 Mdot
.41648 .61342 Mdot
.52423 .53141 Mdot
.3518 .46225 Mdot
.52415 .33819 Mdot
.22154 .59208 Mdot
.71142 .67052 Mdot
.46044 .24432 Mdot
.66398 .49819 Mdot
.71802 .41917 Mdot
.31419 .43863 Mdot
.43983 .62116 Mdot
.52649 .73646 Mdot
.60101 .36421 Mdot
.52154 .34315 Mdot
.71311 .41294 Mdot
.4723 .47155 Mdot
.63964 .25467 Mdot
.53964 .32169 Mdot
.50977 .4895 Mdot
.55584 .32976 Mdot
.60026 .38406 Mdot
.54452 .43091 Mdot
.54126 .36752 Mdot
.36345 .48366 Mdot
.60733 .39373 Mdot
.58052 .6014 Mdot
.56738 .24635 Mdot
.54326 .52422 Mdot
.54652 .39964 Mdot
.49855 .38206 Mdot
.44464 .28231 Mdot
.39078 .56928 Mdot
.30867 .47905 Mdot
.27291 .45793 Mdot
.43087 .5862 Mdot
.54421 .28104 Mdot
.59815 .59596 Mdot
.5733 .43375 Mdot
.57213 .62766 Mdot
.37119 .47057 Mdot
.59553 .65866 Mdot
.41163 .59326 Mdot
.56148 .60955 Mdot
.43538 .74277 Mdot
.43961 .63737 Mdot
.31667 .4431 Mdot
.55572 .37124 Mdot
.43383 .65135 Mdot
.66386 .34046 Mdot
.6615 .50278 Mdot
.27558 .26968 Mdot
.5449 .41256 Mdot
.39941 .68692 Mdot
.38083 .51576 Mdot
.57105 .63569 Mdot
.83297 .48712 Mdot
.32899 .49399 Mdot
.66412 .48007 Mdot
.37291 .46632 Mdot
.71449 .71999 Mdot
.66536 .52226 Mdot
.201 .38371 Mdot
.57088 .74674 Mdot
.61809 .52304 Mdot
.53971 .42587 Mdot
.6319 .42656 Mdot
.61126 .59075 Mdot
.42559 .63947 Mdot
.55884 .73392 Mdot
.56953 .37259 Mdot
.77744 .61888 Mdot
.30731 .43338 Mdot
.59246 .59858 Mdot
.43397 .61711 Mdot
.44414 .64532 Mdot
.52045 .32507 Mdot
.69831 .56782 Mdot
.55734 .3355 Mdot
.50797 .71397 Mdot
.71756 .44038 Mdot
.47552 .30804 Mdot
.5501 .39153 Mdot
.60904 .62233 Mdot
.51514 .40875 Mdot
.71605 .48963 Mdot
.54126 .81419 Mdot
.55985 .31574 Mdot
.45074 .76067 Mdot
.64195 .48185 Mdot
.33902 .46923 Mdot
.46394 .38994 Mdot
.44502 .72979 Mdot
.52504 .41186 Mdot
.84165 .63776 Mdot
.67683 .49762 Mdot
.48295 .76067 Mdot
.52177 .31042 Mdot
.50075 .33516 Mdot
.60152 .45773 Mdot
.38828 .42271 Mdot
.71625 .66795 Mdot
.52221 .35005 Mdot
.67185 .40924 Mdot
.40726 .60706 Mdot
.55007 .33017 Mdot
.53527 .38231 Mdot
.40685 .41491 Mdot
.44451 .64175 Mdot
.57864 .65483 Mdot
.62106 .62793 Mdot
.56098 .59321 Mdot
.69642 .47801 Mdot
.49379 .50642 Mdot
.69806 .32477 Mdot
.79838 .605 Mdot
.66878 .4835 Mdot
.5209 .41892 Mdot
.70433 .46698 Mdot
.49239 .38411 Mdot
.65907 .52758 Mdot
.4436 .64092 Mdot
.30824 .48034 Mdot
.30578 .55287 Mdot
.59945 .58234 Mdot
.52733 .31636 Mdot
.68736 .52688 Mdot
.31713 .44468 Mdot
.70035 .53206 Mdot
.34306 .46341 Mdot
.41952 .6154 Mdot
.4176 .58607 Mdot
.65511 .5201 Mdot
.3681 .47012 Mdot
.37121 .58962 Mdot
.34212 .2223 Mdot
.53845 .43421 Mdot
.48836 .62964 Mdot
.36033 .4379 Mdot
.27991 .46955 Mdot
.33814 .4344 Mdot
.56155 .35803 Mdot
.50727 .56812 Mdot
.48748 .40933 Mdot
.44771 .60431 Mdot
.5724 .65755 Mdot
.75332 .50242 Mdot
.35218 .7314 Mdot
.73291 .5345 Mdot
.58576 .37376 Mdot
.5192 .37932 Mdot
.54219 .38569 Mdot
.49532 .41036 Mdot
.4942 .71878 Mdot
.53818 .33223 Mdot
.39748 .63524 Mdot
.5792 .62695 Mdot
.57841 .38005 Mdot
.60532 .67882 Mdot
.23352 .5499 Mdot
.66008 .4886 Mdot
.47812 .49491 Mdot
.18809 .68121 Mdot
.30833 .44869 Mdot
.60023 .67239 Mdot
.58652 .60615 Mdot
.68869 .48882 Mdot
.42069 .6364 Mdot
.34817 .46065 Mdot
.75406 .44022 Mdot
.69583 .50545 Mdot
.52374 .37122 Mdot
.53096 .58617 Mdot
.7681 .62588 Mdot
.57846 .36671 Mdot
.50322 .34338 Mdot
.59926 .68017 Mdot
.65517 .67427 Mdot
.55145 .84113 Mdot
.66257 .29203 Mdot
.65751 .52037 Mdot
.64883 .4985 Mdot
.28348 .46928 Mdot
.46767 .36795 Mdot
.44533 .60196 Mdot
.61417 .24557 Mdot
.42077 .46883 Mdot
.62541 .27496 Mdot
.4954 .47225 Mdot
.53427 .3256 Mdot
.41341 .20957 Mdot
.52179 .38431 Mdot
.34952 .49463 Mdot
.34926 .44884 Mdot
.30377 .46376 Mdot
.42645 .63669 Mdot
.33826 .36109 Mdot
.39931 .63477 Mdot
.21295 .70241 Mdot
.30599 .44313 Mdot
.49559 .74268 Mdot
.60769 .6237 Mdot
.48329 .32196 Mdot
.69079 .50782 Mdot
.44395 .65598 Mdot
.51167 .29916 Mdot
.81181 .45174 Mdot
.58657 .59983 Mdot
.31383 .44355 Mdot
.22506 .50631 Mdot
.26175 .72137 Mdot
.55795 .55116 Mdot
.55486 .45115 Mdot
.62351 .44835 Mdot
.68067 .52219 Mdot
.46506 .24082 Mdot
.6818 .53116 Mdot
.44535 .62524 Mdot
.55601 .38018 Mdot
.5498 .3715 Mdot
.5629 .33493 Mdot
.54518 .33723 Mdot
.45184 .5941 Mdot
.57017 .33127 Mdot
.82257 .61812 Mdot
.55282 .6394 Mdot
.25064 .39601 Mdot
.6831 .49751 Mdot
.46493 .60879 Mdot
.57815 .62536 Mdot
.60888 .68528 Mdot
.67194 .32217 Mdot
.55143 .39594 Mdot
.52374 .33124 Mdot
.76462 .61093 Mdot
.54171 .3214 Mdot
.53149 .44949 Mdot
.58756 .6042 Mdot
.73558 .53147 Mdot
.65155 .49072 Mdot
.64561 .5151 Mdot
.4318 .64652 Mdot
.3706 .46799 Mdot
.66869 .50533 Mdot
.60696 .64958 Mdot
.58639 .37831 Mdot
.48832 .35126 Mdot
.35607 .43602 Mdot
.63263 .77608 Mdot
.65628 .53778 Mdot
.22679 .52372 Mdot
.3564 .44885 Mdot
.3377 .50354 Mdot
.51994 .34397 Mdot
.60862 .33165 Mdot
.39258 .47524 Mdot
.67486 .48107 Mdot
.46463 .60535 Mdot
.58973 .53603 Mdot
.44464 .60833 Mdot
.34339 .44987 Mdot
.48299 .36098 Mdot
.34089 .44631 Mdot
.54014 .40825 Mdot
.14065 .60119 Mdot
.54461 .36584 Mdot
.79923 .61626 Mdot
.72868 .39427 Mdot
.58803 .61962 Mdot
.36094 .61673 Mdot
.5992 .61043 Mdot
.35261 .44668 Mdot
.48563 .34962 Mdot
.64335 .52201 Mdot
.19685 .4445 Mdot
.34971 .50351 Mdot
.57073 .61261 Mdot
.56852 .59325 Mdot
.44373 .63623 Mdot
.58219 .37208 Mdot
.52566 .34065 Mdot
.5923 .63386 Mdot
.47857 .30188 Mdot
.35117 .48515 Mdot
.55573 .38645 Mdot
.51204 .37158 Mdot
.58963 .61782 Mdot
.36746 .20578 Mdot
.32915 .41178 Mdot
.54833 .37718 Mdot
.53382 .76451 Mdot
.43742 .65359 Mdot
.52293 .42711 Mdot
.50182 .30927 Mdot
.67905 .51698 Mdot
.2837 .39799 Mdot
.5227 .81373 Mdot
.42235 .65523 Mdot
.60169 .60641 Mdot
.53217 .41285 Mdot
.60792 .6184 Mdot
.49299 .34138 Mdot
.29605 .40626 Mdot
.58138 .5949 Mdot
.49444 .34838 Mdot
.46526 .3666 Mdot
.33507 .44204 Mdot
.52903 .32775 Mdot
.44116 .3072 Mdot
.61743 .63147 Mdot
.50496 .33276 Mdot
.3261 .2677 Mdot
.41027 .63573 Mdot
.4657 .36089 Mdot
.66366 .48997 Mdot
.75671 .44275 Mdot
.31525 .6404 Mdot
.4754 .77412 Mdot
.6538 .49659 Mdot
.56546 .35394 Mdot
.56072 .59918 Mdot
.42161 .59519 Mdot
.80327 .58248 Mdot
.57503 .36767 Mdot
.43643 .6036 Mdot
.43383 .62573 Mdot
.66834 .49144 Mdot
.70164 .23488 Mdot
.53276 .30718 Mdot
.53324 .34555 Mdot
.41966 .39017 Mdot
.38196 .46107 Mdot
.54193 .3562 Mdot
.49919 .40541 Mdot
.39576 .63017 Mdot
.52385 .45076 Mdot
.40729 .32641 Mdot
.77943 .47105 Mdot
.41894 .66229 Mdot
.58828 .51142 Mdot
.58375 .58962 Mdot
.68396 .50223 Mdot
.33188 .46807 Mdot
.67736 .53552 Mdot
.55933 .61886 Mdot
.5127 .41561 Mdot
.39079 .62416 Mdot
.48762 .25646 Mdot
.41661 .59543 Mdot
.48185 .77322 Mdot
.37576 .45306 Mdot
.29345 .57166 Mdot
.86307 .57278 Mdot
.29229 .64574 Mdot
.38924 .5725 Mdot
.6787 .52148 Mdot
.62895 .64331 Mdot
.51391 .37425 Mdot
.48344 .23112 Mdot
.56048 .37115 Mdot
.33032 .26789 Mdot
.5859 .66924 Mdot
.55309 .61815 Mdot
.55256 .37871 Mdot
.72066 .4366 Mdot
.4284 .59312 Mdot
.45255 .62148 Mdot
.51098 .33032 Mdot
.41841 .62241 Mdot
.53009 .35566 Mdot
.57369 .62153 Mdot
.80929 .37907 Mdot
.52817 .38317 Mdot
.47638 .36125 Mdot
.45184 .67489 Mdot
.22992 .32242 Mdot
.56052 .77455 Mdot
.4532 .20554 Mdot
.29248 .74822 Mdot
.4193 .6218 Mdot
.48189 .40511 Mdot
.59175 .50755 Mdot
.60459 .68048 Mdot
.37412 .58271 Mdot
.54994 .36046 Mdot
.55286 .35929 Mdot
.56817 .38049 Mdot
.50083 .36662 Mdot
.46809 .23243 Mdot
.47041 .29112 Mdot
.31308 .31268 Mdot
.51834 .33077 Mdot
.64182 .37435 Mdot
.42418 .65143 Mdot
.30175 .43387 Mdot
.69295 .53257 Mdot
.53407 .32585 Mdot
.47843 .28432 Mdot
.4464 .64815 Mdot
.21475 .70415 Mdot
.43907 .64157 Mdot
.58554 .65368 Mdot
.44778 .59334 Mdot
.53295 .40227 Mdot
.3248 .46322 Mdot
.56169 .52613 Mdot
.5074 .68399 Mdot
.58395 .60566 Mdot
.54235 .40237 Mdot
.47431 .7471 Mdot
.5804 .60315 Mdot
.23447 .55496 Mdot
.32434 .46794 Mdot
.66842 .39925 Mdot
.34801 .44788 Mdot
.49347 .34923 Mdot
.49201 .35919 Mdot
.4799 .62206 Mdot
.42421 .59121 Mdot
.35185 .44912 Mdot
.73167 .25296 Mdot
.68735 .53026 Mdot
.30691 .45889 Mdot
.59535 .37682 Mdot
.44083 .52508 Mdot
.31737 .46711 Mdot
.72314 .53328 Mdot
.43113 .6392 Mdot
.2914 .45526 Mdot
.59847 .36311 Mdot
.64804 .75247 Mdot
.68721 .48323 Mdot
.54403 .62359 Mdot
.5364 .59291 Mdot
.61595 .64389 Mdot
.45731 .59277 Mdot
.59565 .60953 Mdot
.40439 .61094 Mdot
.35135 .66378 Mdot
.58399 .2511 Mdot
.42095 .58132 Mdot
.45357 .59184 Mdot
.59395 .61158 Mdot
.55842 .38964 Mdot
.55839 .56906 Mdot
.49569 .41695 Mdot
.56984 .31236 Mdot
.40516 .61557 Mdot
.31749 .43845 Mdot
.29686 .48711 Mdot
.64295 .39922 Mdot
.33199 .49656 Mdot
.57109 .62773 Mdot
.82588 .56504 Mdot
.45486 .77656 Mdot
.41745 .60349 Mdot
.45948 .60471 Mdot
.50108 .37863 Mdot
.59991 .6365 Mdot
.61151 .62992 Mdot
.44723 .62721 Mdot
.58164 .26829 Mdot
.47181 .36664 Mdot
.277 .47074 Mdot
.29879 .44871 Mdot
.31734 .4596 Mdot
.33842 .43572 Mdot
.41174 .29204 Mdot
.43417 .63902 Mdot
.32262 .43743 Mdot
.49948 .34072 Mdot
.55127 .35869 Mdot
.57529 .53247 Mdot
.64697 .50599 Mdot
.57291 .39946 Mdot
.54996 .42846 Mdot
.51918 .34133 Mdot
.56287 .62081 Mdot
.56593 .30206 Mdot
.5856 .59302 Mdot
.55127 .60609 Mdot
.56387 .65878 Mdot
.43582 .73924 Mdot
.63866 .44647 Mdot
.33833 .78153 Mdot
.50488 .40251 Mdot
.26234 .49551 Mdot
.60547 .63471 Mdot
.82474 .47209 Mdot
.34843 .55742 Mdot
.57342 .37245 Mdot
.699 .67837 Mdot
.59295 .6308 Mdot
.32626 .49664 Mdot
.54817 .36187 Mdot
.54999 .6046 Mdot
.67395 .48549 Mdot
.5825 .40856 Mdot
.6196 .63438 Mdot
.36713 .46678 Mdot
.7078 .50239 Mdot
.30258 .44293 Mdot
.56996 .66324 Mdot
.46542 .36459 Mdot
.55895 .87925 Mdot
.5929 .58045 Mdot
.22872 .36031 Mdot
.37578 .42693 Mdot
.557 .38689 Mdot
.60677 .66655 Mdot
.38097 .46616 Mdot
.45538 .58852 Mdot
.43147 .47769 Mdot
.31312 .48765 Mdot
.55375 .61664 Mdot
.61837 .63915 Mdot
.58673 .60409 Mdot
.34376 .47425 Mdot
.47842 .37243 Mdot
.34283 .48043 Mdot
.44995 .59513 Mdot
.51232 .38701 Mdot
.22593 .68592 Mdot
.27159 .50305 Mdot
.3546 .44892 Mdot
.57314 .65109 Mdot
.70129 .49655 Mdot
.5299 .39155 Mdot
.2525 .32828 Mdot
.54973 .40487 Mdot
.41493 .60127 Mdot
.79144 .38739 Mdot
.48482 .255 Mdot
.57278 .3424 Mdot
.50083 .37771 Mdot
.45246 .6118 Mdot
.54333 .39568 Mdot
.57578 .34907 Mdot
.43344 .73265 Mdot
.35216 .47211 Mdot
.51931 .37181 Mdot
.58288 .66414 Mdot
.41165 .75053 Mdot
.47542 .38418 Mdot
.74659 .57089 Mdot
.6842 .41211 Mdot
.76263 .32841 Mdot
.56205 .3739 Mdot
.64459 .28113 Mdot
.50153 .35816 Mdot
.55914 .34531 Mdot
.50164 .3903 Mdot
.49399 .209 Mdot
.57434 .60105 Mdot
.5816 .61357 Mdot
.68341 .48208 Mdot
.68129 .41185 Mdot
.67629 .51535 Mdot
.42862 .64301 Mdot
.72055 .58092 Mdot
.58128 .59522 Mdot
.36801 .46438 Mdot
.56379 .34612 Mdot
.59405 .57989 Mdot
.52727 .33688 Mdot
.53252 .40393 Mdot
.60715 .60031 Mdot
.59704 .5857 Mdot
.47854 .76652 Mdot
.66158 .48919 Mdot
.30173 .47062 Mdot
.56373 .41038 Mdot
.69185 .51922 Mdot
.48004 .35951 Mdot
.71479 .35254 Mdot
.30376 .46984 Mdot
.35029 .47456 Mdot
.30719 .49222 Mdot
.51342 .41574 Mdot
.53523 .3992 Mdot
.39891 .63197 Mdot
.37082 .46264 Mdot
.41148 .6345 Mdot
.53391 .51488 Mdot
.75423 .55524 Mdot
.55005 .36041 Mdot
.23299 .52301 Mdot
.6864 .50996 Mdot
.57685 .64371 Mdot
.77066 .57418 Mdot
.68762 .48219 Mdot
.54508 .40548 Mdot
.60914 .61553 Mdot
.65304 .52351 Mdot
.59048 .44533 Mdot
.40216 .81987 Mdot
.70262 .50799 Mdot
.50243 .33765 Mdot
.49961 .44809 Mdot
.47709 .1861 Mdot
.70172 .48734 Mdot
.39837 .60837 Mdot
.51724 .41724 Mdot
.37478 .51577 Mdot
.65697 .53715 Mdot
.37156 .70944 Mdot
.58525 .62871 Mdot
.58307 .78474 Mdot
.53452 .29649 Mdot
.51974 .2284 Mdot
.67198 .53368 Mdot
.34575 .45857 Mdot
.31277 .42443 Mdot
.51262 .34853 Mdot
.7026 .48829 Mdot
.41608 .66384 Mdot
.58243 .635 Mdot
.41706 .72687 Mdot
.34176 .47605 Mdot
.26421 .55765 Mdot
.56658 .64543 Mdot
.2365 .53795 Mdot
.78999 .44006 Mdot
.49644 .29646 Mdot
.46513 .1997 Mdot
.60538 .71564 Mdot
.52332 .42078 Mdot
.69194 .52712 Mdot
.42564 .65456 Mdot
.39929 .60478 Mdot
.41992 .61152 Mdot
.35901 .66242 Mdot
.5757 .54044 Mdot
.59224 .67591 Mdot
.53597 .68198 Mdot
.68099 .50117 Mdot
.64271 .34487 Mdot
.49451 .33354 Mdot
.52085 .37987 Mdot
.5831 .37567 Mdot
.54462 .32617 Mdot
.50646 .35732 Mdot
.41715 .63175 Mdot
.36608 .67799 Mdot
.59138 .52292 Mdot
.30985 .46971 Mdot
.69017 .56215 Mdot
.60754 .62493 Mdot
.58255 .67593 Mdot
.64962 .51272 Mdot
.21865 .52123 Mdot
.60885 .67395 Mdot
.59155 .65996 Mdot
.56169 .40215 Mdot
.34936 .48212 Mdot
.5889 .42448 Mdot
.49403 .36246 Mdot
.57522 .63459 Mdot
.58212 .48449 Mdot
.42503 .31046 Mdot
.59751 .3294 Mdot
.69977 .47152 Mdot
.50385 .56193 Mdot
.70324 .49413 Mdot
.48852 .33763 Mdot
.81943 .45893 Mdot
.56058 .61581 Mdot
.59353 .64892 Mdot
.67852 .53018 Mdot
.25484 .4452 Mdot
.3317 .4743 Mdot
.61112 .68539 Mdot
.39784 .61328 Mdot
.49061 .37469 Mdot
.7789 .54468 Mdot
.24812 .45768 Mdot
.70032 .57239 Mdot
.42087 .60735 Mdot
.61013 .63647 Mdot
.58282 .36262 Mdot
.50211 .3389 Mdot
.68629 .5194 Mdot
.26114 .68104 Mdot
.57457 .41385 Mdot
.18413 .4842 Mdot
.74761 .68268 Mdot
.64396 .76337 Mdot
.52172 .3432 Mdot
.35041 .47186 Mdot
.61752 .65032 Mdot
.68908 .51996 Mdot
.58507 .33947 Mdot
.3826 .80893 Mdot
.33507 .42909 Mdot
.44288 .62436 Mdot
.57207 .51054 Mdot
.57582 .55003 Mdot
.54886 .41093 Mdot
.55907 .37091 Mdot
.55794 .35153 Mdot
.47314 .83257 Mdot
.56523 .62274 Mdot
.3701 .47893 Mdot
.6598 .49928 Mdot
.33754 .49667 Mdot
.58547 .61429 Mdot
.27607 .56728 Mdot
.55725 .39691 Mdot
.3387 .42956 Mdot
.34324 .4599 Mdot
.44196 .63765 Mdot
.45089 .58627 Mdot
.55081 .51522 Mdot
.54305 .36502 Mdot
.60769 .5799 Mdot
.32643 .44007 Mdot
.53555 .5815 Mdot
.66739 .5229 Mdot
.411 .64672 Mdot
.52137 .33036 Mdot
.56729 .60796 Mdot
.57053 .33116 Mdot
.31864 .47864 Mdot
.59311 .65954 Mdot
.47619 .76296 Mdot
.65108 .49651 Mdot
.54647 .34644 Mdot
.71051 .49155 Mdot
.6022 .60639 Mdot
.51181 .37348 Mdot
.2249 .48257 Mdot
.68267 .4679 Mdot
.48538 .68886 Mdot
.58262 .67058 Mdot
.46938 .76203 Mdot
.29968 .48546 Mdot
.34655 .63629 Mdot
.58988 .65067 Mdot
.21778 .50378 Mdot
.30423 .71025 Mdot
.58317 .3914 Mdot
.32622 .45156 Mdot
.63689 .6594 Mdot
.17322 .62196 Mdot
.36168 .21399 Mdot
.54061 .38694 Mdot
.59406 .67292 Mdot
.67811 .52886 Mdot
.41588 .6041 Mdot
.74908 .56888 Mdot
.70883 .47419 Mdot
.58432 .58578 Mdot
.50045 .39011 Mdot
.35527 .45664 Mdot
.4304 .63401 Mdot
.32477 .64822 Mdot
.59905 .66179 Mdot
.56815 .65252 Mdot
.58146 .35849 Mdot
.67466 .50944 Mdot
.29979 .27459 Mdot
.5744 .6176 Mdot
.76034 .62531 Mdot
.62216 .60207 Mdot
.68989 .52573 Mdot
.50075 .35097 Mdot
.63642 .42486 Mdot
.50393 .41881 Mdot
.21365 .3856 Mdot
.60111 .61424 Mdot
.31119 .47647 Mdot
.56456 .36575 Mdot
.7815 .4527 Mdot
.57746 .6379 Mdot
.51219 .56945 Mdot
.66692 .67517 Mdot
.43302 .63886 Mdot
.7716 .57769 Mdot
.53958 .34934 Mdot
.42525 .59385 Mdot
.68581 .51067 Mdot
.54398 .37343 Mdot
.53206 .39851 Mdot
.37327 .48217 Mdot
.447 .62261 Mdot
.33371 .74208 Mdot
.45449 .63624 Mdot
.40747 .64917 Mdot
.33682 .50097 Mdot
.51989 .35867 Mdot
.5837 .65438 Mdot
.59414 .63234 Mdot
.58018 .32474 Mdot
.83513 .4591 Mdot
.33273 .47638 Mdot
.65502 .57406 Mdot
.49562 .83683 Mdot
.48884 .30096 Mdot
.77332 .56894 Mdot
.2582 .67356 Mdot
.40953 .66091 Mdot
.51433 .33 Mdot
.36429 .46047 Mdot
.60693 .68585 Mdot
.57056 .65323 Mdot
.48003 .37099 Mdot
.42946 .62774 Mdot
.677 .48446 Mdot
.61397 .604 Mdot
.70173 .56606 Mdot
.55314 .3419 Mdot
.69768 .68401 Mdot
.61031 .65601 Mdot
.1616 .5043 Mdot
.62739 .6671 Mdot
.32063 .45293 Mdot
.52958 .40277 Mdot
.31806 .49248 Mdot
.65722 .50472 Mdot
.56692 .51401 Mdot
.43172 .62802 Mdot
.44681 .40235 Mdot
.7916 .68892 Mdot
.5901 .60309 Mdot
.35839 .48789 Mdot
.57175 .34042 Mdot
.58212 .46672 Mdot
.5346 .34994 Mdot
.47091 .42496 Mdot
.65327 .47133 Mdot
.40477 .62153 Mdot
.40971 .60205 Mdot
.51243 .37881 Mdot
.69314 .49915 Mdot
.60859 .64061 Mdot
.58253 .63852 Mdot
.19212 .33375 Mdot
.48914 .66616 Mdot
.74127 .4493 Mdot
.55165 .35546 Mdot
.55933 .60531 Mdot
.36875 .73689 Mdot
.42991 .60173 Mdot
.50498 .32403 Mdot
.5966 .59601 Mdot
.67227 .72482 Mdot
.76104 .41947 Mdot
.50599 .35344 Mdot
.52236 .30344 Mdot
.39716 .61303 Mdot
.64598 .32256 Mdot
.56517 .6579 Mdot
.51359 .42884 Mdot
.39908 .59557 Mdot
.77868 .38352 Mdot
.58106 .80779 Mdot
.30153 .47 Mdot
.65906 .67406 Mdot
.41752 .63271 Mdot
.57456 .31235 Mdot
.67994 .49341 Mdot
.61581 .60076 Mdot
.56658 .61458 Mdot
.50809 .4004 Mdot
.57018 .33218 Mdot
.7109 .46227 Mdot
.3456 .49233 Mdot
.42558 .65055 Mdot
.56106 .37966 Mdot
.2876 .54289 Mdot
.56016 .3324 Mdot
.40157 .63421 Mdot
.53445 .89562 Mdot
.56932 .40789 Mdot
.53251 .34836 Mdot
.30139 .27116 Mdot
.31142 .48681 Mdot
.34156 .49726 Mdot
.77399 .65203 Mdot
.55126 .35465 Mdot
.77038 .59714 Mdot
.30103 .47312 Mdot
.32883 .47722 Mdot
.44434 .7164 Mdot
.52745 .38753 Mdot
.58252 .23131 Mdot
.42525 .596 Mdot
.39859 .6426 Mdot
.3412 .47975 Mdot
.57312 .40822 Mdot
.39354 .64339 Mdot
.43175 .24558 Mdot
.60075 .6348 Mdot
.81735 .44069 Mdot
.32242 .48457 Mdot
.49424 .48998 Mdot
.4231 .60399 Mdot
.2098 .6995 Mdot
.55956 .68981 Mdot
.55924 .38743 Mdot
.54987 .34732 Mdot
.68627 .50677 Mdot
.57148 .40498 Mdot
.55192 .6215 Mdot
.41802 .62258 Mdot
.26585 .33509 Mdot
.304 .46257 Mdot
.53764 .36067 Mdot
.22931 .5381 Mdot
.31761 .6806 Mdot
.58078 .75507 Mdot
.33886 .46847 Mdot
.32482 .44847 Mdot
.56607 .65753 Mdot
.59738 .67198 Mdot
.51523 .35418 Mdot
.4506 .6118 Mdot
.36894 .45929 Mdot
.40088 .62579 Mdot
.56044 .61706 Mdot
.58351 .65673 Mdot
.5773 .59641 Mdot
.55452 .43564 Mdot
.58978 .66282 Mdot
.72347 .54902 Mdot
.26484 .56601 Mdot
.29096 .49075 Mdot
.67362 .77116 Mdot
.32558 .64484 Mdot
.40945 .48262 Mdot
.64617 .52979 Mdot
.60246 .60605 Mdot
.45724 .6054 Mdot
.50332 .3748 Mdot
.52562 .3337 Mdot
.54382 .64835 Mdot
.44789 .59692 Mdot
.65626 .51326 Mdot
.43363 .59152 Mdot
.66942 .49081 Mdot
.67438 .69251 Mdot
.58118 .37604 Mdot
.48889 .35337 Mdot
.41509 .62646 Mdot
.59327 .6612 Mdot
.58062 .62245 Mdot
.70454 .50453 Mdot
.43792 .44641 Mdot
.58188 .60169 Mdot
.32114 .48317 Mdot
.40476 .28471 Mdot
.61764 .64488 Mdot
.54577 .35946 Mdot
.69542 .31685 Mdot
.49737 .23418 Mdot
.49313 .40866 Mdot
.43686 .72312 Mdot
.60712 .21491 Mdot
.56843 .3621 Mdot
.61035 .20636 Mdot
.46673 .76021 Mdot
.31803 .49078 Mdot
.58151 .66766 Mdot
.59113 .68299 Mdot
.47923 .42486 Mdot
.67545 .54274 Mdot
.58597 .33758 Mdot
.30669 .48367 Mdot
.34643 .42592 Mdot
.68294 .72993 Mdot
.22578 .36364 Mdot
.66996 .53134 Mdot
.64791 .51675 Mdot
.58901 .64839 Mdot
.34426 .20586 Mdot
.60216 .35103 Mdot
.65649 .51838 Mdot
.59244 .25782 Mdot
.49914 .39091 Mdot
.71409 .40319 Mdot
.7417 .64498 Mdot
.34626 .47462 Mdot
.63368 .42461 Mdot
.5828 .64865 Mdot
.33707 .4938 Mdot
.30928 .54946 Mdot
.56213 .40794 Mdot
.304 .46792 Mdot
.39939 .62547 Mdot
.58017 .71974 Mdot
.2943 .46984 Mdot
.70411 .3296 Mdot
.44889 .62459 Mdot
.53188 .58122 Mdot
.65267 .39016 Mdot
.88634 .42939 Mdot
.41878 .629 Mdot
.59949 .59071 Mdot
.59331 .63272 Mdot
.58346 .6398 Mdot
.33883 .49497 Mdot
.61087 .62553 Mdot
.35207 .48988 Mdot
.43232 .18275 Mdot
.43641 .44386 Mdot
.65684 .52147 Mdot
.42518 .7204 Mdot
.33841 .45281 Mdot
.83331 .53349 Mdot
.83974 .61543 Mdot
.51739 .32826 Mdot
.45998 .61789 Mdot
.65991 .527 Mdot
.18343 .4479 Mdot
.68148 .51457 Mdot
.62415 .54236 Mdot
.80337 .40068 Mdot
.53212 .36071 Mdot
.37995 .36794 Mdot
.64346 .51716 Mdot
.35002 .46315 Mdot
.5143 .37609 Mdot
.39085 .56329 Mdot
.68006 .51023 Mdot
.68013 .48617 Mdot
.51303 .36196 Mdot
.31446 .44319 Mdot
.57817 .65059 Mdot
.42916 .58831 Mdot
.6688 .47684 Mdot
.28568 .43079 Mdot
.53735 .42066 Mdot
.53011 .41528 Mdot
.54495 .55475 Mdot
.70594 .53536 Mdot
.4198 .62217 Mdot
.53519 .20801 Mdot
.59306 .67143 Mdot
.64494 .63541 Mdot
.7456 .67198 Mdot
.44197 .73102 Mdot
.5993 .61454 Mdot
.60061 .60756 Mdot
.50878 .35486 Mdot
.71829 .52721 Mdot
.78013 .36015 Mdot
.36881 .60932 Mdot
.61621 .65507 Mdot
.58111 .63591 Mdot
.33107 .42469 Mdot
.6921 .72747 Mdot
.5851 .34131 Mdot
.41713 .65546 Mdot
.56819 .60849 Mdot
.28102 .41156 Mdot
.67434 .50536 Mdot
.827 .50312 Mdot
.58027 .37596 Mdot
.55928 .38268 Mdot
.42946 .61544 Mdot
.3994 .63607 Mdot
.47407 .58723 Mdot
.73576 .69507 Mdot
.57665 .21391 Mdot
.34233 .66992 Mdot
.35128 .4016 Mdot
.31806 .42863 Mdot
.35368 .44842 Mdot
.39818 .70833 Mdot
.45174 .64146 Mdot
.56638 .36262 Mdot
.36822 .46094 Mdot
.57381 .74066 Mdot
.28544 .51065 Mdot
.72472 .42506 Mdot
.76332 .53116 Mdot
.54135 .40673 Mdot
.35674 .47552 Mdot
.31499 .48705 Mdot
.36114 .44759 Mdot
.46473 .75816 Mdot
.52274 .34976 Mdot
.54987 .39364 Mdot
.56952 .35242 Mdot
.56181 .27119 Mdot
.54234 .33348 Mdot
.36673 .66074 Mdot
.52564 .53458 Mdot
.26657 .38145 Mdot
.5254 .43092 Mdot
.40365 .65507 Mdot
.54409 .41409 Mdot
.69227 .49648 Mdot
.50098 .38606 Mdot
.73038 .42795 Mdot
.44043 .61003 Mdot
.34799 .41509 Mdot
.34145 .656 Mdot
.56711 .39161 Mdot
.66282 .48492 Mdot
.41652 .45124 Mdot
.28523 .72208 Mdot
.67146 .54655 Mdot
.32211 .48342 Mdot
.60214 .62686 Mdot
.45542 .60415 Mdot
.58969 .65625 Mdot
.56012 .43224 Mdot
.41522 .70405 Mdot
.25915 .63192 Mdot
.53533 .50487 Mdot
.53849 .32605 Mdot
.54273 .29001 Mdot
.3239 .48023 Mdot
.60904 .6146 Mdot
.29856 .50837 Mdot
.56177 .36131 Mdot
.66203 .49999 Mdot
.68188 .50653 Mdot
.38984 .55301 Mdot
.19305 .58349 Mdot
.35133 .61012 Mdot
.42643 .61592 Mdot
.5728 .61652 Mdot
.67942 .53321 Mdot
.24968 .49432 Mdot
.45987 .58951 Mdot
.45303 .6121 Mdot
.44329 .62945 Mdot
.49827 .40094 Mdot
.58536 .59286 Mdot
.26784 .37306 Mdot
.55726 .60957 Mdot
.54294 .39887 Mdot
.56353 .62706 Mdot
.59145 .59769 Mdot
.68563 .4999 Mdot
.43407 .64602 Mdot
.55682 .63165 Mdot
.49341 .34847 Mdot
.30142 .4575 Mdot
.4659 .47072 Mdot
.74091 .39726 Mdot
.21895 .4055 Mdot
.23501 .4067 Mdot
.29278 .45908 Mdot
.18845 .63513 Mdot
.43367 .65652 Mdot
.58459 .27122 Mdot
.51604 .767 Mdot
.48308 .36883 Mdot
.84402 .531 Mdot
.59334 .67643 Mdot
.60542 .5968 Mdot
.49973 .35411 Mdot
.64123 .68484 Mdot
.53596 .35709 Mdot
.56034 .63507 Mdot
.67959 .56607 Mdot
.46269 .36815 Mdot
.60314 .65312 Mdot
.51202 .42969 Mdot
.52451 .39011 Mdot
.34793 .47493 Mdot
.60919 .6627 Mdot
.50925 .32146 Mdot
.17141 .40501 Mdot
.40424 .64082 Mdot
.46608 .74734 Mdot
.69148 .29769 Mdot
.41731 .63416 Mdot
.30867 .45928 Mdot
.57186 .31427 Mdot
.68662 .51524 Mdot
.34362 .45214 Mdot
.76689 .42268 Mdot
.6445 .51225 Mdot
.83778 .54102 Mdot
.32886 .48563 Mdot
.61616 .65081 Mdot
.68303 .49253 Mdot
.48496 .40771 Mdot
.61418 .59824 Mdot
.41818 .48303 Mdot
.60166 .61644 Mdot
.52672 .34025 Mdot
.40946 .72216 Mdot
.41921 .6513 Mdot
.53969 .38436 Mdot
.61359 .60692 Mdot
.42967 .73476 Mdot
.49985 .40151 Mdot
.50407 .36829 Mdot
.64104 .77091 Mdot
.81088 .54712 Mdot
.67524 .523 Mdot
.37872 .4652 Mdot
.49897 .34131 Mdot
.67136 .48716 Mdot
.69771 .63951 Mdot
.52986 .41856 Mdot
.34321 .43206 Mdot
.59154 .31104 Mdot
.61444 .63982 Mdot
.41493 .63984 Mdot
.5256 .50769 Mdot
.67288 .48574 Mdot
.64385 .17734 Mdot
.56345 .60479 Mdot
.49229 .33233 Mdot
.53787 .32406 Mdot
.56882 .77168 Mdot
.32439 .4911 Mdot
.58785 .22321 Mdot
.54672 .34643 Mdot
.55097 .26983 Mdot
.54095 .37321 Mdot
.62918 .56347 Mdot
.33117 .47548 Mdot
.53209 .34448 Mdot
.24577 .53775 Mdot
.47409 .36478 Mdot
.66947 .48454 Mdot
.33454 .23895 Mdot
.52344 .42173 Mdot
.67642 .82485 Mdot
.76462 .59662 Mdot
.60188 .65599 Mdot
.39634 .71213 Mdot
.34338 .17804 Mdot
.34946 .65484 Mdot
.35836 .4866 Mdot
.25385 .65695 Mdot
.58318 .65475 Mdot
.37535 .72053 Mdot
.18427 .63513 Mdot
.52217 .39063 Mdot
.54911 .41077 Mdot
.62338 .53882 Mdot
.54919 .63079 Mdot
.61086 .58293 Mdot
.54954 .43307 Mdot
.60368 .37481 Mdot
.57966 .6588 Mdot
.50032 .3357 Mdot
.53364 .43942 Mdot
.43895 .58843 Mdot
.29589 .45597 Mdot
.41079 .60867 Mdot
.44311 .63967 Mdot
.41443 .22282 Mdot
.71946 .70221 Mdot
.40442 .63826 Mdot
.42595 .65724 Mdot
.71923 .40602 Mdot
.68356 .44402 Mdot
.65427 .53626 Mdot
.17978 .52562 Mdot
.58494 .63743 Mdot
.52313 .35298 Mdot
.28916 .46879 Mdot
.52923 .2288 Mdot
.74308 .60391 Mdot
.78869 .36809 Mdot
.56395 .36111 Mdot
.57999 .64284 Mdot
.46373 .75883 Mdot
.57775 .43367 Mdot
.6349 .61971 Mdot
.56287 .38295 Mdot
.59807 .58223 Mdot
.38528 .3216 Mdot
.22282 .51555 Mdot
.61509 .58673 Mdot
.27363 .46571 Mdot
.55599 .37624 Mdot
.32098 .48542 Mdot
.41651 .60857 Mdot
.69097 .50167 Mdot
.67216 .52232 Mdot
.51111 .36936 Mdot
.52481 .28145 Mdot
.6824 .68728 Mdot
.52967 .39228 Mdot
.50529 .39254 Mdot
.46674 .76036 Mdot
.50624 .39027 Mdot
.54642 .32802 Mdot
.55833 .33548 Mdot
.49034 .32507 Mdot
.40416 .6472 Mdot
.22997 .53676 Mdot
.58163 .42022 Mdot
.55848 .43974 Mdot
.40424 .59644 Mdot
.28094 .70332 Mdot
.44709 .63886 Mdot
.22919 .69025 Mdot
.41222 .6031 Mdot
.66261 .52028 Mdot
.48149 .78362 Mdot
.5299 .28528 Mdot
.32899 .43674 Mdot
.46494 .6008 Mdot
.66168 .49532 Mdot
.41812 .61647 Mdot
.56421 .64005 Mdot
.52459 .82574 Mdot
.26536 .45581 Mdot
.62507 .25199 Mdot
.38096 .55518 Mdot
.49681 .67706 Mdot
.55555 .62458 Mdot
.33526 .47826 Mdot
.42066 .32353 Mdot
.55342 .32924 Mdot
.6717 .48788 Mdot
.5124 .35716 Mdot
.4133 .65261 Mdot
.58384 .64635 Mdot
.33645 .23302 Mdot
.68657 .51822 Mdot
.67947 .76038 Mdot
.58498 .6258 Mdot
.57022 .34673 Mdot
.41501 .65493 Mdot
.72078 .74372 Mdot
.40682 .61473 Mdot
.43666 .37385 Mdot
.28748 .44785 Mdot
.4531 .20164 Mdot
.33167 .4525 Mdot
.61801 .67507 Mdot
.54519 .85049 Mdot
.19702 .47417 Mdot
.31049 .44641 Mdot
.51656 .66236 Mdot
.53498 .41158 Mdot
.53323 .41501 Mdot
.23502 .46992 Mdot
.37671 .45961 Mdot
.5221 .32735 Mdot
.47532 .75971 Mdot
.27051 .59037 Mdot
.78321 .57569 Mdot
.60534 .61534 Mdot
.5392 .35348 Mdot
.40012 .59697 Mdot
.43607 .59232 Mdot
.56316 .60304 Mdot
.45074 .63567 Mdot
.54818 .39303 Mdot
.33634 .45299 Mdot
.59706 .57618 Mdot
.66607 .51361 Mdot
.2029 .36154 Mdot
.68509 .53351 Mdot
.59857 .61431 Mdot
.46621 .36167 Mdot
.584 .65725 Mdot
.40109 .13104 Mdot
.55227 .3896 Mdot
.30395 .47547 Mdot
.49739 .37098 Mdot
.55219 .3766 Mdot
.54815 .41185 Mdot
.57107 .65013 Mdot
.61564 .23129 Mdot
.49592 .34197 Mdot
.43234 .6292 Mdot
.27529 .39439 Mdot
.54935 .41308 Mdot
.65912 .56774 Mdot
.69929 .43241 Mdot
.54496 .68828 Mdot
.28561 .46489 Mdot
.60759 .63565 Mdot
.30524 .45694 Mdot
.27064 .49208 Mdot
.30853 .4597 Mdot
.31549 .38162 Mdot
.41332 .32399 Mdot
.64459 .23898 Mdot
.31706 .27656 Mdot
.62605 .37742 Mdot
.37792 .46287 Mdot
.62903 .47405 Mdot
.35813 .44948 Mdot
.32043 .48801 Mdot
.34625 .8678 Mdot
.33613 .43937 Mdot
.54638 .3548 Mdot
.57119 .39624 Mdot
.30348 .65404 Mdot
.69644 .37334 Mdot
.50798 .38249 Mdot
.49584 .35133 Mdot
.68941 .50255 Mdot
.5071 .27963 Mdot
.41686 .70562 Mdot
.81738 .57855 Mdot
.33217 .69586 Mdot
.5119 .3601 Mdot
.49569 .34624 Mdot
.59893 .4041 Mdot
.70806 .7764 Mdot
.44652 .22464 Mdot
.3745 .44664 Mdot
.57961 .31523 Mdot
.20251 .41362 Mdot
.56609 .38861 Mdot
.50022 .40699 Mdot
.54015 .40817 Mdot
.58313 .65425 Mdot
.32803 .42919 Mdot
.59133 .33525 Mdot
.74062 .66142 Mdot
.56134 .39656 Mdot
.43908 .73033 Mdot
.44486 .15742 Mdot
.5397 .34853 Mdot
.31196 .43586 Mdot
.51589 .40969 Mdot
.33491 .48758 Mdot
.35528 .46598 Mdot
.47094 .35471 Mdot
.3298 .3974 Mdot
.31419 .43223 Mdot
.54228 .39953 Mdot
.57293 .64569 Mdot
.17167 .53097 Mdot
.52857 .3389 Mdot
.69133 .51908 Mdot
.54954 .34845 Mdot
.66479 .48275 Mdot
.5108 .3943 Mdot
.5669 .60002 Mdot
.48614 .25006 Mdot
.5924 .64766 Mdot
.49641 .17664 Mdot
.58495 .59055 Mdot
.64982 .76756 Mdot
.36332 .43822 Mdot
.41571 .7235 Mdot
.73263 .27446 Mdot
.45724 .7392 Mdot
.49216 .56758 Mdot
.48194 .54256 Mdot
.45103 .61255 Mdot
.31333 .49128 Mdot
.62511 .29367 Mdot
.5763 .75071 Mdot
.55288 .76839 Mdot
.585 .59748 Mdot
.72751 .25204 Mdot
.80745 .38629 Mdot
.4898 .36672 Mdot
.36152 .37468 Mdot
.31836 .32111 Mdot
.52529 .42015 Mdot
.56954 .31143 Mdot
.5416 .62601 Mdot
.52817 .32152 Mdot
.27835 .53967 Mdot
.59412 .61378 Mdot
.66309 .49365 Mdot
.31373 .48085 Mdot
.68497 .48375 Mdot
.56776 .75603 Mdot
.4782 .54393 Mdot
.55959 .62739 Mdot
.47989 .34521 Mdot
.49664 .3639 Mdot
.34606 .48005 Mdot
.36325 .5041 Mdot
.33637 .44259 Mdot
.67083 .53021 Mdot
.59238 .61828 Mdot
.48692 .22596 Mdot
.50253 .3419 Mdot
.34056 .46036 Mdot
.46389 .56333 Mdot
.50414 .33636 Mdot
.41227 .62311 Mdot
.54797 .40428 Mdot
.30315 .45212 Mdot
.50649 .39033 Mdot
.33464 .45117 Mdot
.60241 .63175 Mdot
.57426 .38071 Mdot
.50243 .35255 Mdot
.69944 .7571 Mdot
.65751 .51302 Mdot
.37438 .45185 Mdot
.64762 .68366 Mdot
.55289 .32539 Mdot
.48501 .70297 Mdot
.55875 .37383 Mdot
.31909 .52117 Mdot
.48375 .34443 Mdot
.45165 .74981 Mdot
.58556 .34725 Mdot
.529 .33966 Mdot
.41039 .54239 Mdot
.31268 .34489 Mdot
.38008 .49393 Mdot
.40878 .65426 Mdot
.34326 .43684 Mdot
.77263 .54432 Mdot
.61289 .66906 Mdot
.61161 .62135 Mdot
.66077 .32346 Mdot
.50124 .31297 Mdot
.53086 .35937 Mdot
.41582 .58658 Mdot
.6486 .50523 Mdot
.34062 .46706 Mdot
.66834 .49141 Mdot
.752 .66329 Mdot
.65312 .52707 Mdot
.57167 .67172 Mdot
.69646 .68155 Mdot
.46033 .23761 Mdot
.68903 .50251 Mdot
.31518 .4423 Mdot
.75212 .53723 Mdot
.4815 .37864 Mdot
.69606 .4632 Mdot
.66392 .5001 Mdot
.71173 .22946 Mdot
.54368 .32779 Mdot
.49874 .5709 Mdot
.40662 .63586 Mdot
.68183 .49452 Mdot
.4466 .61074 Mdot
.5076 .37839 Mdot
.47877 .68974 Mdot
.36983 .47535 Mdot
.3881 .63096 Mdot
.54501 .42422 Mdot
.65616 .52431 Mdot
.56992 .60817 Mdot
.47445 .6141 Mdot
.39691 .64704 Mdot
.25399 .67662 Mdot
.38883 .20246 Mdot
.59205 .62056 Mdot
.79666 .46881 Mdot
.42073 .5968 Mdot
.51059 .41682 Mdot
.52181 .26941 Mdot
.55957 .38778 Mdot
.35639 .64458 Mdot
.60835 .6305 Mdot
.26772 .61143 Mdot
.49565 .36897 Mdot
.56463 .35099 Mdot
.38425 .48594 Mdot
.59293 .63858 Mdot
.32195 .46371 Mdot
.34637 .43927 Mdot
.60151 .6324 Mdot
.32258 .45354 Mdot
.64402 .50925 Mdot
.28103 .59266 Mdot
.40593 .60149 Mdot
.43581 .62646 Mdot
.58147 .63748 Mdot
.59687 .66212 Mdot
.5907 .65944 Mdot
.5484 .40403 Mdot
.33605 .47157 Mdot
.52538 .40262 Mdot
.54721 .41161 Mdot
.39291 .41592 Mdot
.29095 .45758 Mdot
.52776 .40955 Mdot
.63507 .65684 Mdot
.70886 .47921 Mdot
.57039 .64269 Mdot
.40663 .63911 Mdot
.38558 .74735 Mdot
.42366 .66848 Mdot
.54061 .35642 Mdot
.67008 .72391 Mdot
.3218 .44241 Mdot
.68477 .51073 Mdot
.64119 .52937 Mdot
.68043 .51808 Mdot
.37818 .6197 Mdot
.3703 .45229 Mdot
.8193 .57529 Mdot
.53636 .35418 Mdot
.54383 .55689 Mdot
.59875 .25694 Mdot
.67722 .70034 Mdot
.40726 .64133 Mdot
.49871 .34281 Mdot
.51822 .50194 Mdot
.43659 .29668 Mdot
.5577 .38403 Mdot
.48274 .39511 Mdot
.49158 .7541 Mdot
.60772 .34308 Mdot
.29592 .43994 Mdot
.75576 .68529 Mdot
.58305 .38458 Mdot
.25908 .43455 Mdot
.23533 .29358 Mdot
.54537 .36409 Mdot
.56014 .35217 Mdot
.51633 .33768 Mdot
.49824 .38544 Mdot
.30441 .43786 Mdot
.66335 .35908 Mdot
.43741 .65428 Mdot
.56576 .54176 Mdot
.39841 .60685 Mdot
.60621 .58877 Mdot
.24272 .55271 Mdot
.30751 .49006 Mdot
.6865 .50735 Mdot
.20631 .51246 Mdot
.7914 .63786 Mdot
.5686 .66048 Mdot
.417 .25539 Mdot
.66078 .50637 Mdot
.50445 .41425 Mdot
.65158 .48849 Mdot
.58724 .59246 Mdot
.43437 .63454 Mdot
.50796 .3077 Mdot
.34701 .44573 Mdot
.29491 .47258 Mdot
.51971 .32784 Mdot
.20201 .43622 Mdot
.41132 .6281 Mdot
.4661 .59239 Mdot
.50939 .4119 Mdot
.49521 .41593 Mdot
.31793 .46413 Mdot
.57529 .62437 Mdot
.77044 .4737 Mdot
.65068 .51068 Mdot
.54165 .31661 Mdot
.49935 .38923 Mdot
.74059 .69129 Mdot
.42737 .6436 Mdot
.56861 .66524 Mdot
.49519 .39415 Mdot
.36693 .68841 Mdot
.49552 .39416 Mdot
.6019 .40859 Mdot
.57366 .64431 Mdot
.59228 .3971 Mdot
.49053 .3504 Mdot
.44964 .38603 Mdot
.43718 .59931 Mdot
.30496 .47289 Mdot
.29255 .49451 Mdot
.59812 .50529 Mdot
.41307 .62051 Mdot
.52262 .41001 Mdot
.42239 .64208 Mdot
.53874 .4158 Mdot
.52006 .32608 Mdot
.40186 .63444 Mdot
.32206 .46306 Mdot
.26895 .66752 Mdot
.23442 .54389 Mdot
.49725 .3829 Mdot
.58607 .37395 Mdot
.67661 .35953 Mdot
.68113 .25712 Mdot
.56282 .36691 Mdot
.29781 .46078 Mdot
.49976 .3479 Mdot
.44226 .6069 Mdot
.64811 .52611 Mdot
.30221 .45535 Mdot
.58043 .61668 Mdot
.55898 .649 Mdot
.34201 .65366 Mdot
.5974 .60111 Mdot
.48593 .38768 Mdot
.26684 .48768 Mdot
.33591 .50317 Mdot
.21866 .3251 Mdot
.59932 .63352 Mdot
.64122 .51736 Mdot
.50587 .36975 Mdot
.64483 .75512 Mdot
.42354 .58425 Mdot
.71918 .79918 Mdot
.8326 .55257 Mdot
.69095 .53144 Mdot
.769 .33136 Mdot
.60793 .5865 Mdot
.51248 .32471 Mdot
.69157 .50134 Mdot
.5714 .6612 Mdot
.48549 .37551 Mdot
.50362 .30678 Mdot
.59492 .22361 Mdot
.58286 .51107 Mdot
.42158 .64353 Mdot
.60849 .65241 Mdot
.6359 .53142 Mdot
.55879 .65813 Mdot
.29503 .47667 Mdot
.52836 .3429 Mdot
.49398 .29975 Mdot
.57707 .61937 Mdot
.54975 .63566 Mdot
.53966 .40523 Mdot
.31638 .49219 Mdot
.54848 .65495 Mdot
.51424 .36661 Mdot
.62222 .34885 Mdot
.27564 .45958 Mdot
.59146 .61035 Mdot
.56206 .34259 Mdot
.72498 .48324 Mdot
.58191 .62649 Mdot
.56909 .64063 Mdot
.5189 .32732 Mdot
.6451 .50471 Mdot
.58258 .36077 Mdot
.40662 .60699 Mdot
.5673 .19622 Mdot
.44489 .61242 Mdot
.74817 .55804 Mdot
.46881 .38363 Mdot
.46831 .67275 Mdot
.29448 .4804 Mdot
.64402 .55037 Mdot
.41325 .77228 Mdot
.54206 .4348 Mdot
.18887 .5983 Mdot
.49174 .49442 Mdot
.18941 .4192 Mdot
.407 .80078 Mdot
.66908 .50017 Mdot
.41898 .61278 Mdot
.55991 .35268 Mdot
.46039 .60564 Mdot
.69323 .50988 Mdot
.47897 .18856 Mdot
.55765 .33657 Mdot
.32906 .4762 Mdot
.54647 .40103 Mdot
.32293 .48418 Mdot
.51121 .33091 Mdot
.57729 .43181 Mdot
.46551 .76697 Mdot
.75971 .41789 Mdot
.48229 .36957 Mdot
.54361 .83075 Mdot
.7414 .63074 Mdot
.65693 .50136 Mdot
.52788 .39886 Mdot
.61157 .67692 Mdot
.4432 .59502 Mdot
.30001 .52815 Mdot
.58155 .65438 Mdot
.43914 .64722 Mdot
.3145 .46009 Mdot
.60488 .62276 Mdot
.55241 .63482 Mdot
.59262 .37585 Mdot
.67342 .48227 Mdot
.43955 .63538 Mdot
.53397 .3418 Mdot
.5517 .3332 Mdot
.78984 .48975 Mdot
.73475 .59931 Mdot
.33019 .50764 Mdot
.77698 .69746 Mdot
.30818 .50108 Mdot
.65472 .51601 Mdot
.57716 .65127 Mdot
.56005 .36926 Mdot
.53759 .38534 Mdot
.42048 .72874 Mdot
.37283 .47258 Mdot
.56461 .51223 Mdot
.39448 .24021 Mdot
.54625 .64667 Mdot
.69525 .41274 Mdot
.30342 .47794 Mdot
.6957 .41071 Mdot
.63491 .52515 Mdot
.19546 .52254 Mdot
.7516 .42541 Mdot
.4092 .63893 Mdot
.69103 .41004 Mdot
.35024 .45959 Mdot
.4917 .3662 Mdot
.61378 .65962 Mdot
.59143 .59838 Mdot
.31232 .47146 Mdot
.56539 .58866 Mdot
.68393 .49956 Mdot
.55693 .34483 Mdot
.81297 .56985 Mdot
.32272 .61291 Mdot
.57073 .62074 Mdot
.56461 .44038 Mdot
.44408 .62714 Mdot
.52559 .32462 Mdot
.68919 .52127 Mdot
.4222 .63153 Mdot
.76613 .58129 Mdot
.26943 .60047 Mdot
.51027 .37343 Mdot
.67049 .74908 Mdot
.41539 .6243 Mdot
.74237 .31418 Mdot
.51715 .3592 Mdot
.42234 .59683 Mdot
.60292 .3444 Mdot
.59408 .71303 Mdot
.52779 .50067 Mdot
.18231 .63264 Mdot
.54445 .51101 Mdot
.61893 .62198 Mdot
.56114 .71541 Mdot
.54175 .74513 Mdot
.45823 .60384 Mdot
.55124 .64084 Mdot
.70358 .54124 Mdot
.44702 .61054 Mdot
.55226 .4105 Mdot
.55337 .37059 Mdot
.44933 .2199 Mdot
.48631 .50059 Mdot
.61707 .68431 Mdot
.34708 .57662 Mdot
.55584 .32771 Mdot
.57973 .39829 Mdot
.53176 .38003 Mdot
.34415 .4257 Mdot
.42852 .63941 Mdot
.62088 .80079 Mdot
.41178 .61848 Mdot
.82235 .50269 Mdot
.58485 .6394 Mdot
.60955 .63893 Mdot
.54097 .35186 Mdot
.5234 .59583 Mdot
.65422 .41824 Mdot
.54624 .39431 Mdot
.57464 .55788 Mdot
.31496 .25466 Mdot
.55039 .41962 Mdot
.28369 .45419 Mdot
.48825 .43152 Mdot
.3097 .42392 Mdot
.40728 .59977 Mdot
.67201 .50705 Mdot
.65221 .55189 Mdot
.43535 .63662 Mdot
.53026 .36118 Mdot
.44419 .68795 Mdot
.54806 .37904 Mdot
.49106 .37831 Mdot
.82847 .48353 Mdot
.68758 .53181 Mdot
.59991 .65063 Mdot
.67923 .52182 Mdot
.32366 .48979 Mdot
.53397 .9089 Mdot
.65015 .50121 Mdot
.64778 .42109 Mdot
.51045 .18687 Mdot
.68964 .40622 Mdot
.29804 .47856 Mdot
.69486 .48259 Mdot
.41232 .63567 Mdot
.15923 .49655 Mdot
.65522 .23064 Mdot
.46366 .64024 Mdot
.51858 .36938 Mdot
.31969 .49551 Mdot
.30414 .44685 Mdot
.38839 .62789 Mdot
.35379 .46485 Mdot
.5857 .31627 Mdot
.49423 .37634 Mdot
.46036 .6106 Mdot
.31447 .64742 Mdot
.39727 .64781 Mdot
.27846 .56657 Mdot
.53275 .40034 Mdot
.29913 .47246 Mdot
.48156 .42403 Mdot
.36737 .428 Mdot
.57369 .66996 Mdot
.51959 .42181 Mdot
.68515 .50096 Mdot
.45793 .67324 Mdot
.5899 .62102 Mdot
.66322 .72549 Mdot
.34271 .48154 Mdot
.49163 .60916 Mdot
.35019 .47337 Mdot
.37978 .47256 Mdot
.44537 .63767 Mdot
.36727 .47307 Mdot
.55975 .35022 Mdot
.62526 .66081 Mdot
.34458 .48704 Mdot
.43609 .61345 Mdot
.67218 .51284 Mdot
.32388 .45596 Mdot
.63964 .6867 Mdot
.50407 .36156 Mdot
.56817 .6519 Mdot
.49784 .78665 Mdot
.3469 .49678 Mdot
.70155 .49301 Mdot
.60955 .61457 Mdot
.6843 .48617 Mdot
.27824 .27411 Mdot
.45504 .63812 Mdot
.79399 .38751 Mdot
.72481 .48988 Mdot
.33001 .43896 Mdot
.48325 .78126 Mdot
.55725 .36694 Mdot
.50369 .36437 Mdot
.6731 .4788 Mdot
.30466 .44643 Mdot
.18485 .48728 Mdot
.40529 .45617 Mdot
.28005 .60645 Mdot
.46241 .62281 Mdot
.61616 .79105 Mdot
.26763 .54991 Mdot
.38083 .18363 Mdot
.56935 .41786 Mdot
.60833 .58385 Mdot
.53696 .36451 Mdot
.39838 .76291 Mdot
.66094 .52719 Mdot
.64243 .5751 Mdot
.47139 .36651 Mdot
.60472 .63666 Mdot
.51249 .34584 Mdot
.40927 .52894 Mdot
.51676 .44115 Mdot
.64355 .52393 Mdot
.41186 .70848 Mdot
.33603 .43787 Mdot
.66398 .51154 Mdot
.56369 .60714 Mdot
.66916 .41786 Mdot
.48441 .35969 Mdot
.56665 .42881 Mdot
.55077 .65657 Mdot
.33376 .47716 Mdot
.61579 .64168 Mdot
.40816 .60051 Mdot
.67956 .50366 Mdot
.50222 .37444 Mdot
.48199 .34538 Mdot
.48644 .70439 Mdot
.44191 .63529 Mdot
.55389 .60263 Mdot
.40867 .61356 Mdot
.61368 .58894 Mdot
.58678 .3627 Mdot
.6102 .63616 Mdot
.49983 .33045 Mdot
.43584 .77342 Mdot
.82593 .4805 Mdot
.32537 .35333 Mdot
.60764 .62477 Mdot
.71931 .43674 Mdot
.43866 .60728 Mdot
.41336 .60395 Mdot
.4982 .2069 Mdot
.45754 .30787 Mdot
.79079 .53933 Mdot
.26635 .70345 Mdot
.39961 .60611 Mdot
.44412 .62096 Mdot
.56792 .65373 Mdot
.36389 .47872 Mdot
.36802 .4886 Mdot
.60127 .58393 Mdot
.69059 .30738 Mdot
.34061 .46692 Mdot
.18471 .55566 Mdot
.77996 .55359 Mdot
.59099 .33848 Mdot
.47031 .58011 Mdot
.67921 .5088 Mdot
.70308 .33224 Mdot
.40567 .53408 Mdot
.56452 .3543 Mdot
.73087 .69897 Mdot
.5759 .63075 Mdot
.64869 .31464 Mdot
.23137 .69136 Mdot
.55403 .33261 Mdot
.52145 .3539 Mdot
.53136 .36939 Mdot
.69691 .5252 Mdot
.49327 .25858 Mdot
.55587 .33826 Mdot
.68946 .30311 Mdot
.54977 .32263 Mdot
.52779 .46781 Mdot
.67436 .52258 Mdot
.56786 .46219 Mdot
.48187 .76211 Mdot
.76744 .64183 Mdot
.45661 .38167 Mdot
.40921 .60101 Mdot
.59274 .5437 Mdot
.43621 .59748 Mdot
.31402 .37653 Mdot
.74825 .41998 Mdot
.2802 .48044 Mdot
.5633 .35478 Mdot
.59799 .61364 Mdot
.30225 .44878 Mdot
.53521 .71861 Mdot
.43151 .91723 Mdot
.41695 .59577 Mdot
.44415 .13391 Mdot
.40887 .60824 Mdot
.55243 .62711 Mdot
.31628 .46469 Mdot
.40895 .32306 Mdot
.5432 .55415 Mdot
.32553 .45407 Mdot
.26302 .64264 Mdot
.38807 .47412 Mdot
.70325 .42691 Mdot
.3151 .50011 Mdot
.43687 .61085 Mdot
.38258 .63655 Mdot
.52604 .29631 Mdot
.55107 .35725 Mdot
.47308 .5402 Mdot
.6708 .43449 Mdot
.55501 .36222 Mdot
.59389 .6159 Mdot
.73003 .29005 Mdot
.61049 .50078 Mdot
.36409 .46204 Mdot
.41892 .66277 Mdot
.51985 .35136 Mdot
.49729 .39297 Mdot
.48585 .36417 Mdot
.78801 .69356 Mdot
.1912 .5126 Mdot
.49608 .34208 Mdot
.56148 .32912 Mdot
.60493 .62665 Mdot
.6411 .48881 Mdot
.3826 .76133 Mdot
.46648 .44304 Mdot
.57181 .37385 Mdot
.66372 .51725 Mdot
.68386 .53579 Mdot
.48536 .37689 Mdot
.73809 .6604 Mdot
.4836 .67157 Mdot
.53359 .34133 Mdot
.4469 .33763 Mdot
.56304 .74886 Mdot
.54973 .63303 Mdot
.57906 .62036 Mdot
.31669 .43516 Mdot
.59567 .60363 Mdot
.58296 .59002 Mdot
.42093 .29656 Mdot
.54366 .52027 Mdot
.38519 .59811 Mdot
.67176 .5303 Mdot
.54117 .38453 Mdot
.33698 .5056 Mdot
.38142 .69607 Mdot
.4507 .62051 Mdot
.32195 .44561 Mdot
.4377 .59364 Mdot
.70765 .50877 Mdot
.62267 .25569 Mdot
.58593 .59542 Mdot
.39217 .62183 Mdot
.26952 .5991 Mdot
.66594 .51926 Mdot
.43496 .64704 Mdot
.45456 .68754 Mdot
.5535 .41174 Mdot
.39323 .38773 Mdot
.54174 .3963 Mdot
.18788 .45191 Mdot
.43119 .64768 Mdot
.44684 .74615 Mdot
.53012 .35302 Mdot
.58427 .62752 Mdot
.6075 .38714 Mdot
.56419 .38255 Mdot
.57997 .61133 Mdot
.4901 .36614 Mdot
.69686 .50467 Mdot
.27358 .45466 Mdot
.57418 .53402 Mdot
.84496 .39534 Mdot
.67538 .48182 Mdot
.52339 .71331 Mdot
.56364 .36503 Mdot
.34481 .22521 Mdot
.3261 .45603 Mdot
.49284 .33449 Mdot
.639 .40094 Mdot
.34631 .49041 Mdot
.31168 .45105 Mdot
.51056 .40283 Mdot
.40662 .63301 Mdot
.58853 .61787 Mdot
.67114 .52126 Mdot
.28205 .26184 Mdot
.52064 .37856 Mdot
.50099 .35073 Mdot
.66182 .50803 Mdot
.44526 .61689 Mdot
.50105 .40033 Mdot
.5109 .79714 Mdot
.17605 .40658 Mdot
.45361 .61666 Mdot
.56509 .39778 Mdot
.40509 .40438 Mdot
.29978 .42538 Mdot
.55568 .16327 Mdot
.75033 .51488 Mdot
.6043 .6474 Mdot
.60302 .3342 Mdot
.59558 .87346 Mdot
.67288 .50889 Mdot
.79677 .60592 Mdot
.49098 .38387 Mdot
.50898 .33683 Mdot
.33278 .44255 Mdot
.52748 .4062 Mdot
.35044 .4926 Mdot
.82334 .36589 Mdot
.73485 .704 Mdot
.33171 .48207 Mdot
.34451 .44331 Mdot
.63834 .42168 Mdot
.38542 .76134 Mdot
.31041 .47002 Mdot
.57086 .33411 Mdot
.23861 .42944 Mdot
.45683 .41712 Mdot
.66777 .47914 Mdot
.52959 .77309 Mdot
.34555 .41622 Mdot
.62365 .49848 Mdot
.26039 .67497 Mdot
.33371 .41389 Mdot
.50147 .65829 Mdot
.40194 .61103 Mdot
.56339 .33948 Mdot
.59412 .59908 Mdot
.61131 .62423 Mdot
.50227 .43337 Mdot
.54798 .38397 Mdot
.3322 .48792 Mdot
.67045 .53257 Mdot
.45195 .59805 Mdot
.49599 .35202 Mdot
.61213 .50419 Mdot
.6508 .50314 Mdot
.36104 .47221 Mdot
.55893 .23319 Mdot
.64189 .52217 Mdot
.53235 .44811 Mdot
.54309 .34125 Mdot
.54115 .40686 Mdot
.44559 .38971 Mdot
.40245 .64124 Mdot
.47316 .78035 Mdot
.57852 .38223 Mdot
.75242 .66407 Mdot
.44616 .45549 Mdot
.59711 .38991 Mdot
.34594 .46941 Mdot
.42167 .58418 Mdot
.59774 .67967 Mdot
.63681 .32915 Mdot
.51407 .37662 Mdot
.19969 .49373 Mdot
.42417 .2256 Mdot
.58647 .6755 Mdot
.37736 .46351 Mdot
.68352 .51304 Mdot
.54667 .39251 Mdot
.29486 .39365 Mdot
.54932 .36598 Mdot
.71924 .4962 Mdot
.57071 .63691 Mdot
.40107 .61335 Mdot
.18627 .41591 Mdot
.61134 .62561 Mdot
.30661 .45521 Mdot
.18862 .68101 Mdot
.31834 .49845 Mdot
.35985 .4481 Mdot
.31207 .3978 Mdot
.3981 .63394 Mdot
.62159 .86608 Mdot
.6294 .20572 Mdot
.48619 .407 Mdot
.43476 .60332 Mdot
.31733 .47458 Mdot
.52871 .32516 Mdot
.29026 .47993 Mdot
.37283 .45334 Mdot
.58921 .37911 Mdot
.52669 .33157 Mdot
.24462 .5488 Mdot
.19642 .64819 Mdot
.68424 .51548 Mdot
.31237 .48767 Mdot
.61801 .31901 Mdot
.53383 .32444 Mdot
.53607 .35341 Mdot
.56469 .73798 Mdot
.64352 .50905 Mdot
.29667 .53817 Mdot
.49339 .3883 Mdot
.71044 .72583 Mdot
.48626 .43023 Mdot
.30213 .43852 Mdot
.45252 .6219 Mdot
.76993 .63335 Mdot
.36427 .60595 Mdot
.37072 .47747 Mdot
.68302 .52658 Mdot
.29533 .49691 Mdot
.6478 .42434 Mdot
.39724 .64271 Mdot
.30317 .45207 Mdot
.52445 .50676 Mdot
.42578 .62472 Mdot
.42642 .6478 Mdot
.27405 .39588 Mdot
.5716 .58865 Mdot
.69937 .51686 Mdot
.44103 .63225 Mdot
.58835 .27589 Mdot
.42835 .61011 Mdot
.51244 .21927 Mdot
.57414 .38271 Mdot
.66232 .29979 Mdot
.49565 .58111 Mdot
.53568 .28693 Mdot
.41601 .6512 Mdot
.6915 .51297 Mdot
.50571 .40203 Mdot
.35399 .46074 Mdot
.6603 .49316 Mdot
.47605 .62359 Mdot
.57876 .6573 Mdot
.3524 .47401 Mdot
.45679 .63982 Mdot
.3076 .48251 Mdot
.62923 .29883 Mdot
.54735 .18663 Mdot
.55851 .7916 Mdot
.54431 .54888 Mdot
.4863 .36744 Mdot
.31266 .73045 Mdot
.59124 .34732 Mdot
.55276 .38394 Mdot
.59154 .61183 Mdot
.6582 .31801 Mdot
.32132 .46377 Mdot
.18065 .42399 Mdot
.39509 .61608 Mdot
.7544 .68892 Mdot
.3307 .51656 Mdot
.48884 .33929 Mdot
.34283 .48841 Mdot
.31532 .4986 Mdot
.3061 .34334 Mdot
.58483 .68105 Mdot
.54343 .30546 Mdot
.55188 .30523 Mdot
.57699 .41836 Mdot
.42353 .64664 Mdot
.67044 .72003 Mdot
.61717 .60787 Mdot
.53826 .17337 Mdot
.5701 .63056 Mdot
.57487 .55562 Mdot
.36637 .47134 Mdot
.64925 .50056 Mdot
.53602 .35109 Mdot
.36989 .50645 Mdot
.37197 .4772 Mdot
.70872 .48292 Mdot
.68265 .49354 Mdot
.59232 .72056 Mdot
.40226 .63581 Mdot
.481 .36739 Mdot
.56164 .34276 Mdot
.52211 .40037 Mdot
.55336 .39741 Mdot
.41299 .59672 Mdot
.52324 .4157 Mdot
.39126 .60311 Mdot
.57133 .25684 Mdot
.72089 .70846 Mdot
.5377 .51732 Mdot
.34488 .52736 Mdot
.35898 .45956 Mdot
.60383 .30029 Mdot
.54057 .44972 Mdot
.81796 .45357 Mdot
.24308 .34423 Mdot
.54359 .42167 Mdot
.57628 .66463 Mdot
.46334 .301 Mdot
.59442 .59375 Mdot
.50982 .12373 Mdot
.48146 .70953 Mdot
.18521 .62238 Mdot
.54515 .33128 Mdot
.56782 .74078 Mdot
.56269 .27328 Mdot
.58048 .32576 Mdot
.52039 .72583 Mdot
.35196 .63582 Mdot
.28734 .64921 Mdot
.66513 .53668 Mdot
.5082 .36152 Mdot
.36004 .49857 Mdot
.55912 .34741 Mdot
.53751 .35891 Mdot
.49101 .38738 Mdot
.42496 .6562 Mdot
.53142 .30693 Mdot
.55255 .40342 Mdot
.68168 .67998 Mdot
.71792 .41201 Mdot
.61037 .64934 Mdot
.48964 .20261 Mdot
.65237 .49936 Mdot
.34004 .48579 Mdot
.22114 .59192 Mdot
.40941 .63963 Mdot
.31018 .33215 Mdot
.54846 .40241 Mdot
.25265 .57247 Mdot
.46404 .62756 Mdot
.68141 .50193 Mdot
.61921 .63695 Mdot
.17129 .58205 Mdot
.59831 .61944 Mdot
.51583 .50361 Mdot
.58777 .6279 Mdot
.48895 .43709 Mdot
.33079 .48807 Mdot
.48954 .38892 Mdot
.43954 .63152 Mdot
.58714 .60743 Mdot
.68675 .36278 Mdot
.53215 .37829 Mdot
.60153 .63413 Mdot
.49024 .39006 Mdot
.63046 .2583 Mdot
.78946 .4424 Mdot
.57467 .59376 Mdot
.38958 .59956 Mdot
.43063 .62128 Mdot
.64473 .50778 Mdot
.35098 .48012 Mdot
.3378 .44508 Mdot
.42164 .62936 Mdot
.67878 .24596 Mdot
.57016 .3758 Mdot
.5336 .32588 Mdot
.75625 .66278 Mdot
.55829 .35714 Mdot
.68608 .4266 Mdot
.52184 .50234 Mdot
.36177 .46618 Mdot
.51194 .32637 Mdot
.49807 .39163 Mdot
.50806 .37126 Mdot
.61792 .2755 Mdot
.57394 .62155 Mdot
.57363 .35762 Mdot
.68408 .49166 Mdot
.61837 .66956 Mdot
.52723 .32379 Mdot
.57886 .41821 Mdot
.33565 .44467 Mdot
.79447 .6576 Mdot
.40398 .61553 Mdot
.55826 .61723 Mdot
.60891 .63531 Mdot
.53408 .77109 Mdot
.36648 .41304 Mdot
.52785 .5043 Mdot
.51319 .16744 Mdot
.47043 .76182 Mdot
.6573 .50594 Mdot
.50254 .62393 Mdot
.47045 .4666 Mdot
.56066 .64746 Mdot
.42703 .59264 Mdot
.57508 .38484 Mdot
.57249 .37562 Mdot
.84006 .52769 Mdot
.48447 .34611 Mdot
.68062 .51256 Mdot
.39107 .6074 Mdot
.34896 .45936 Mdot
.68264 .50315 Mdot
.41334 .60585 Mdot
.33618 .47659 Mdot
.56409 .40808 Mdot
.57223 .40009 Mdot
.32235 .44659 Mdot
.31025 .4441 Mdot
.53853 .3427 Mdot
.59096 .56365 Mdot
.3301 .43556 Mdot
.29661 .47014 Mdot
.58609 .59484 Mdot
.58944 .59968 Mdot
.59353 .37628 Mdot
.42819 .60345 Mdot
.54475 .41019 Mdot
.60264 .61874 Mdot
.65613 .52978 Mdot
.32731 .46079 Mdot
.49648 .38375 Mdot
.49426 .35932 Mdot
.66719 .51888 Mdot
.66949 .53512 Mdot
.68231 .49668 Mdot
.38499 .63 Mdot
.52219 .39382 Mdot
.3107 .46422 Mdot
.39909 .62848 Mdot
.68453 .53573 Mdot
.64594 .49518 Mdot
.5504 .60096 Mdot
.56187 .37051 Mdot
.59775 .69225 Mdot
.52412 .90354 Mdot
.73653 .48396 Mdot
.58981 .67812 Mdot
.54445 .6255 Mdot
.69379 .39236 Mdot
.53856 .57809 Mdot
.41433 .63011 Mdot
.72337 .52257 Mdot
.64515 .55097 Mdot
.51965 .42117 Mdot
.58344 .37933 Mdot
.55831 .30517 Mdot
.6741 .49486 Mdot
.64572 .34259 Mdot
.29434 .48259 Mdot
.35993 .24562 Mdot
.65504 .49703 Mdot
.54909 .63317 Mdot
.56967 .58859 Mdot
.56988 .63177 Mdot
.57528 .39014 Mdot
.32756 .34728 Mdot
.61225 .42668 Mdot
.3147 .73867 Mdot
.42597 .65107 Mdot
.2855 .49276 Mdot
.30651 .25612 Mdot
.31729 .44874 Mdot
.59937 .58762 Mdot
.66345 .49436 Mdot
.30002 .45422 Mdot
.44655 .60147 Mdot
.44277 .62423 Mdot
.57101 .62391 Mdot
.58193 .64 Mdot
.56278 .63947 Mdot
.36676 .45119 Mdot
.36652 .47345 Mdot
.51781 .38096 Mdot
.33682 .45657 Mdot
.83275 .5792 Mdot
.70421 .51367 Mdot
.54352 .62429 Mdot
.41795 .6119 Mdot
.32531 .48467 Mdot
.53306 .38228 Mdot
.59921 .51564 Mdot
.34031 .6274 Mdot
.68852 .48808 Mdot
.79022 .47274 Mdot
.50594 .12648 Mdot
.48039 .36082 Mdot
.42456 .64457 Mdot
.81089 .56682 Mdot
.52963 .37105 Mdot
.57811 .64881 Mdot
.43822 .7817 Mdot
.61313 .66897 Mdot
.54759 .41104 Mdot
.47833 .37894 Mdot
.45142 .63394 Mdot
.48713 .1793 Mdot
.52222 .38369 Mdot
.31493 .55022 Mdot
.42054 .66462 Mdot
.6145 .60142 Mdot
.16803 .41991 Mdot
.56521 .77182 Mdot
.69722 .32189 Mdot
.58326 .59564 Mdot
.55313 .37607 Mdot
.5817 .59915 Mdot
.69141 .49284 Mdot
.56661 .60893 Mdot
.28338 .45129 Mdot
.61386 .6424 Mdot
.50177 .34932 Mdot
.3096 .47188 Mdot
.41471 .62408 Mdot
.76539 .67641 Mdot
.7186 .64555 Mdot
.58376 .62862 Mdot
.56218 .60548 Mdot
.49396 .34258 Mdot
.2674 .53322 Mdot
.50745 .43025 Mdot
.54116 .32816 Mdot
.3933 .61412 Mdot
.34777 .48647 Mdot
.43576 .65368 Mdot
.5189 .31613 Mdot
.49803 .80015 Mdot
.40603 .61912 Mdot
.24598 .56871 Mdot
.6601 .50624 Mdot
.42811 .50789 Mdot
.54022 .38678 Mdot
.44788 .62445 Mdot
.52346 .39441 Mdot
.28849 .4768 Mdot
.46973 .50693 Mdot
.39256 .71043 Mdot
.43707 .63159 Mdot
.19402 .46782 Mdot
.56282 .57339 Mdot
.46432 .36329 Mdot
.42621 .59674 Mdot
.63764 .40417 Mdot
.55193 .63269 Mdot
.6519 .50938 Mdot
.67924 .53627 Mdot
.67919 .4844 Mdot
.53403 .43206 Mdot
.46042 .38246 Mdot
.69593 .51748 Mdot
.45293 .60639 Mdot
.64624 .52944 Mdot
.26349 .42859 Mdot
.18482 .48346 Mdot
.66266 .52693 Mdot
.51618 .36272 Mdot
.45894 .3365 Mdot
.71435 .40427 Mdot
.61943 .69179 Mdot
.18959 .6147 Mdot
.31545 .52711 Mdot
.55027 .35871 Mdot
.26994 .44413 Mdot
.29133 .47375 Mdot
.8026 .57329 Mdot
.68872 .44156 Mdot
.75385 .641 Mdot
.34776 .44352 Mdot
.41335 .72251 Mdot
.35881 .47335 Mdot
.485 .34986 Mdot
.52844 .32688 Mdot
.37463 .48337 Mdot
.68662 .71988 Mdot
.4939 .69305 Mdot
.20527 .36211 Mdot
.29789 .47553 Mdot
.4389 .59992 Mdot
.39723 .6052 Mdot
.42056 .6497 Mdot
.77934 .54418 Mdot
.33857 .49673 Mdot
.5147 .39042 Mdot
.60628 .6205 Mdot
.57259 .36226 Mdot
.42778 .6317 Mdot
.18063 .42736 Mdot
.34433 .44985 Mdot
.5301 .34003 Mdot
.68069 .25994 Mdot
.58553 .65003 Mdot
.6609 .51695 Mdot
.60897 .24054 Mdot
.76865 .58444 Mdot
.3984 .64014 Mdot
.33949 .49964 Mdot
.44462 .73411 Mdot
.23626 .56256 Mdot
.57356 .41048 Mdot
.59853 .36651 Mdot
.33743 .21162 Mdot
.76579 .57641 Mdot
.49305 .40158 Mdot
.55454 .62721 Mdot
.42256 .73071 Mdot
.49756 .37248 Mdot
.30025 .48294 Mdot
.65785 .53824 Mdot
.67563 .48697 Mdot
.57083 .3267 Mdot
.54438 .55806 Mdot
.43126 .47679 Mdot
.52354 .41082 Mdot
.53301 .44841 Mdot
.60225 .59156 Mdot
.47341 .76025 Mdot
.75123 .67429 Mdot
.68189 .52842 Mdot
.4945 .3952 Mdot
.29205 .67879 Mdot
.37361 .46304 Mdot
.60363 .66841 Mdot
.39989 .64725 Mdot
.59737 .25363 Mdot
.61572 .60258 Mdot
.49672 .3734 Mdot
.49997 .3984 Mdot
.43779 .64598 Mdot
.30173 .4387 Mdot
.67146 .49462 Mdot
.6083 .62357 Mdot
.68456 .5273 Mdot
.34416 .49266 Mdot
.34645 .45322 Mdot
.46486 .42912 Mdot
.4796 .32423 Mdot
.58034 .61888 Mdot
.52829 .31752 Mdot
.64857 .67932 Mdot
.48025 .17576 Mdot
.46479 .60026 Mdot
.47987 .36135 Mdot
.33159 .42571 Mdot
.43506 .63502 Mdot
.5177 .33382 Mdot
.29607 .24257 Mdot
.53741 .32286 Mdot
.36007 .62023 Mdot
.54701 .8025 Mdot
.69002 .50751 Mdot
.33554 .25472 Mdot
.23705 .48198 Mdot
.5563 .35238 Mdot
.59299 .66461 Mdot
.59082 .41965 Mdot
.40863 .63258 Mdot
.36556 .46465 Mdot
.55883 .16054 Mdot
.43122 .61228 Mdot
.55215 .33833 Mdot
.68032 .50316 Mdot
.32594 .50049 Mdot
.6063 .55664 Mdot
.7362 .66873 Mdot
.47664 .40994 Mdot
.56475 .32618 Mdot
.53916 .41135 Mdot
.43423 .79863 Mdot
.55842 .61824 Mdot
.31958 .47982 Mdot
.42215 .64593 Mdot
.42036 .63168 Mdot
.57272 .62648 Mdot
.29102 .63826 Mdot
.43048 .50607 Mdot
.54329 .88451 Mdot
.57981 .60864 Mdot
.70018 .48745 Mdot
.29071 .54091 Mdot
.5948 .66554 Mdot
.59919 .63762 Mdot
.6028 .59253 Mdot
.37043 .61267 Mdot
.33652 .4739 Mdot
.49314 .36056 Mdot
.28544 .46501 Mdot
.55629 .3779 Mdot
.43217 .44748 Mdot
.43765 .63533 Mdot
.36572 .46006 Mdot
.30589 .23763 Mdot
.43696 .33569 Mdot
.52457 .36527 Mdot
.3258 .23815 Mdot
.47125 .37898 Mdot
.67385 .39703 Mdot
.47838 .33625 Mdot
.58465 .63439 Mdot
.58337 .29631 Mdot
.54781 .43682 Mdot
.79404 .64052 Mdot
.41767 .61059 Mdot
.55422 .64384 Mdot
.49871 .41371 Mdot
.49845 .43885 Mdot
.37886 .48124 Mdot
.29759 .45978 Mdot
.69274 .52254 Mdot
.76026 .41392 Mdot
.41315 .6232 Mdot
.57287 .20325 Mdot
.54942 .35295 Mdot
.61974 .76853 Mdot
.32329 .27248 Mdot
.51862 .33453 Mdot
.22233 .4472 Mdot
.32042 .34122 Mdot
.54501 .39071 Mdot
.61691 .44325 Mdot
.44387 .61517 Mdot
.50881 .80254 Mdot
.56054 .32678 Mdot
.58122 .65278 Mdot
.36214 .47775 Mdot
.3028 .48858 Mdot
.69648 .51274 Mdot
.82231 .41482 Mdot
.43486 .65298 Mdot
.36681 .46339 Mdot
.53513 .37593 Mdot
.39829 .63707 Mdot
.60019 .60417 Mdot
.49746 .32416 Mdot
.70252 .44391 Mdot
.34027 .45812 Mdot
.55173 .32045 Mdot
.32021 .57754 Mdot
.72377 .36858 Mdot
.33409 .78935 Mdot
.41557 .64712 Mdot
.64632 .52187 Mdot
.59568 .40974 Mdot
.61026 .22437 Mdot
.5445 .42317 Mdot
.6581 .29859 Mdot
.30413 .41056 Mdot
.6458 .52215 Mdot
.52587 .35532 Mdot
.50564 .37903 Mdot
.50238 .5792 Mdot
.66998 .53364 Mdot
.56179 .34071 Mdot
.51093 .26682 Mdot
.33225 .47663 Mdot
.62083 .6172 Mdot
.34265 .46262 Mdot
.51863 .36853 Mdot
.49055 .31169 Mdot
.32476 .44119 Mdot
.46104 .15581 Mdot
.662 .54548 Mdot
.40268 .61989 Mdot
.46754 .34763 Mdot
.5802 .3738 Mdot
.5439 .83877 Mdot
.57126 .66783 Mdot
.35554 .738 Mdot
.66916 .65142 Mdot
.28087 .68315 Mdot
.5691 .76934 Mdot
.18246 .6573 Mdot
.7368 .6949 Mdot
.55629 .30778 Mdot
.39676 .50628 Mdot
.60784 .44193 Mdot
.41419 .65212 Mdot
.45968 .24645 Mdot
.5514 .35794 Mdot
.53772 .36162 Mdot
.6006 .67228 Mdot
.2637 .60792 Mdot
.75043 .65212 Mdot
.57117 .54616 Mdot
.66921 .49616 Mdot
.31743 .48803 Mdot
.5072 .33297 Mdot
.58235 .49563 Mdot
.60879 .65458 Mdot
.63024 .7621 Mdot
.52751 .3438 Mdot
.81441 .45321 Mdot
.36876 .66708 Mdot
.4024 .63965 Mdot
.60731 .64733 Mdot
.767 .6055 Mdot
.56317 .37459 Mdot
.39299 .64037 Mdot
.52661 .3845 Mdot
.52692 .63271 Mdot
.51726 .31876 Mdot
.65391 .52176 Mdot
.48786 .37778 Mdot
.58312 .54648 Mdot
.25885 .73974 Mdot
.71735 .52061 Mdot
.31716 .49411 Mdot
.56261 .66998 Mdot
.57535 .62127 Mdot
.30457 .44913 Mdot
.5776 .62263 Mdot
.32073 .30146 Mdot
.39595 .31939 Mdot
.66389 .49808 Mdot
.519 .44591 Mdot
.67032 .52742 Mdot
.57585 .6718 Mdot
.55507 .36683 Mdot
.48515 .15899 Mdot
.58478 .61269 Mdot
.56174 .8129 Mdot
.42409 .61199 Mdot
.56119 .65755 Mdot
.55114 .32276 Mdot
.45256 .73047 Mdot
.61213 .63404 Mdot
.39687 .70933 Mdot
.50921 .37265 Mdot
.35117 .45606 Mdot
.50246 .37929 Mdot
.46716 .36237 Mdot
.60896 .58043 Mdot
.55851 .39803 Mdot
.41355 .60575 Mdot
.34394 .43701 Mdot
.17289 .52806 Mdot
.35676 .6403 Mdot
.56439 .35124 Mdot
.53351 .37434 Mdot
.34508 .50157 Mdot
.57556 .35795 Mdot
.4126 .59699 Mdot
.84032 .67569 Mdot
.65986 .50697 Mdot
.5606 .6046 Mdot
.55861 .77695 Mdot
.54842 .41883 Mdot
.51472 .41067 Mdot
.27098 .26892 Mdot
.55199 .78655 Mdot
.42023 .5988 Mdot
.5315 .43862 Mdot
.60736 .61308 Mdot
.67997 .5052 Mdot
.4553 .60825 Mdot
.54011 .40695 Mdot
.53316 .35213 Mdot
.64662 .52068 Mdot
.25544 .40787 Mdot
.78433 .57838 Mdot
.43196 .65018 Mdot
.57566 .28782 Mdot
.65373 .62978 Mdot
.56783 .37908 Mdot
.78519 .53797 Mdot
.30023 .4577 Mdot
.39345 .63189 Mdot
.34764 .75032 Mdot
.50175 .40972 Mdot
.45204 .61892 Mdot
.41307 .62075 Mdot
.53914 .43731 Mdot
.36753 .43257 Mdot
.35996 .44161 Mdot
.30925 .48345 Mdot
.8451 .57259 Mdot
.70872 .3555 Mdot
.56292 .63967 Mdot
.44461 .61636 Mdot
.58459 .5887 Mdot
.70112 .48489 Mdot
.51977 .49319 Mdot
.56927 .59777 Mdot
.29804 .45224 Mdot
.57326 .68034 Mdot
.50523 .37515 Mdot
.41473 .62642 Mdot
.56031 .64489 Mdot
.50349 .4189 Mdot
.24755 .52606 Mdot
.5945 .70295 Mdot
.64186 .50659 Mdot
.66491 .53966 Mdot
.52325 .32698 Mdot
.60008 .67983 Mdot
.53873 .3446 Mdot
.43458 .58628 Mdot
.2763 .5402 Mdot
.53017 .42658 Mdot
.5817 .629 Mdot
.26727 .44406 Mdot
.76824 .58482 Mdot
.4873 .41389 Mdot
.51721 .36204 Mdot
.56064 .38178 Mdot
.52701 .38532 Mdot
.2659 .63055 Mdot
.46399 .61485 Mdot
.36776 .54196 Mdot
.48051 .77871 Mdot
.3307 .45083 Mdot
.36122 .4353 Mdot
.76036 .53313 Mdot
.50331 .66269 Mdot
.43174 .60359 Mdot
.55448 .38716 Mdot
.37317 .68867 Mdot
.17919 .43572 Mdot
.42812 .1532 Mdot
.69648 .467 Mdot
.58514 .673 Mdot
.3483 .49724 Mdot
.60631 .65596 Mdot
.55219 .37289 Mdot
.6001 .40126 Mdot
.17942 .65834 Mdot
.39246 .6576 Mdot
.66655 .49357 Mdot
.55849 .3813 Mdot
.70919 .34777 Mdot
.60531 .62548 Mdot
.58297 .5839 Mdot
.55714 .3339 Mdot
.31916 .43094 Mdot
.45067 .83343 Mdot
.40555 .6437 Mdot
.3151 .52856 Mdot
.58844 .28788 Mdot
.35216 .56084 Mdot
.42834 .63699 Mdot
.73592 .65002 Mdot
.5956 .67726 Mdot
.27556 .33797 Mdot
.33254 .44923 Mdot
.65897 .49537 Mdot
.59801 .37867 Mdot
.34284 .44457 Mdot
.61866 .61292 Mdot
.36043 .45892 Mdot
.48641 .37836 Mdot
.45155 .64324 Mdot
.60327 .65119 Mdot
.38023 .61387 Mdot
.36622 .43309 Mdot
.6869 .52105 Mdot
.47651 .55615 Mdot
.44956 .28106 Mdot
.31795 .33861 Mdot
.57474 .36509 Mdot
.58063 .49326 Mdot
.51732 .394 Mdot
.38486 .46913 Mdot
.53089 .383 Mdot
.26096 .45618 Mdot
.5981 .66172 Mdot
.56119 .32861 Mdot
.53044 .41273 Mdot
.45682 .231 Mdot
.52015 .34681 Mdot
.52681 .31063 Mdot
.549 .39096 Mdot
.32012 .51232 Mdot
.53127 .44477 Mdot
.34441 .47157 Mdot
.71245 .68006 Mdot
.59726 .63929 Mdot
.66752 .53876 Mdot
.65875 .48964 Mdot
.6685 .3048 Mdot
.6838 .55694 Mdot
.27822 .62834 Mdot
.33453 .46615 Mdot
.41091 .6135 Mdot
.53139 .38636 Mdot
.27582 .71657 Mdot
.54982 .75265 Mdot
.60629 .60494 Mdot
.35679 .6408 Mdot
.58383 .30695 Mdot
.44071 .80389 Mdot
.54074 .31763 Mdot
.84395 .50985 Mdot
.49357 .30359 Mdot
.51062 .3216 Mdot
.59226 .58372 Mdot
.67844 .54395 Mdot
.56642 .33993 Mdot
.37799 .48262 Mdot
.64869 .51369 Mdot
.39969 .48665 Mdot
.64009 .62814 Mdot
.71691 .66633 Mdot
.42584 .26976 Mdot
.52467 .39188 Mdot
.60156 .65327 Mdot
.3512 .47506 Mdot
.7501 .67906 Mdot
.39884 .62586 Mdot
.49655 .62978 Mdot
.61362 .31433 Mdot
.38698 .19328 Mdot
.65145 .50195 Mdot
.26745 .39932 Mdot
.50063 .34955 Mdot
.75136 .55731 Mdot
.58054 .39452 Mdot
.18155 .43613 Mdot
.69681 .48426 Mdot
.33978 .43086 Mdot
.43646 .59936 Mdot
.2877 .46883 Mdot
.31825 .35247 Mdot
.47217 .57823 Mdot
.49688 .53356 Mdot
.59978 .62311 Mdot
.40151 .54189 Mdot
.31262 .47615 Mdot
.50063 .40228 Mdot
.53408 .88989 Mdot
.29712 .46603 Mdot
.36134 .4873 Mdot
.5138 .18345 Mdot
.48027 .17204 Mdot
.58767 .30732 Mdot
.33405 .43971 Mdot
.59791 .62714 Mdot
.68492 .51847 Mdot
.50378 .38764 Mdot
.51538 .38237 Mdot
.336 .44374 Mdot
.58714 .58348 Mdot
.42178 .41118 Mdot
.58326 .63934 Mdot
.33338 .4785 Mdot
.59245 .64826 Mdot
.44364 .75114 Mdot
.56271 .65346 Mdot
.57997 .37174 Mdot
.53115 .38404 Mdot
.65983 .66038 Mdot
.34658 .4535 Mdot
.52012 .40875 Mdot
.48953 .36175 Mdot
.31125 .46648 Mdot
.61912 .5088 Mdot
.40316 .41107 Mdot
.56393 .36036 Mdot
.50624 .35873 Mdot
.64822 .52571 Mdot
.54052 .49068 Mdot
.77623 .37011 Mdot
.50589 .40205 Mdot
.7021 .51466 Mdot
.36687 .45272 Mdot
.5356 .34031 Mdot
.20585 .53693 Mdot
.42088 .73034 Mdot
.49831 .40488 Mdot
.55281 .63732 Mdot
.56266 .42996 Mdot
.37342 .80582 Mdot
.54323 .32798 Mdot
.31675 .47015 Mdot
.35349 .48754 Mdot
.55573 .20754 Mdot
.30332 .45982 Mdot
.59124 .59853 Mdot
.42667 .62746 Mdot
.18878 .44745 Mdot
.6007 .60477 Mdot
.50134 .42127 Mdot
.62707 .20372 Mdot
.50684 .31435 Mdot
.51316 .42399 Mdot
.48714 .8222 Mdot
.60152 .60793 Mdot
.33655 .48996 Mdot
.52216 .57957 Mdot
.53263 .30074 Mdot
.3978 .64004 Mdot
.58421 .42256 Mdot
.56938 .39214 Mdot
.55371 .79996 Mdot
.36751 .71353 Mdot
.40557 .59565 Mdot
.58678 .32752 Mdot
.50716 .40333 Mdot
.59181 .69346 Mdot
.53516 .38109 Mdot
.67691 .52845 Mdot
.33836 .49495 Mdot
.58453 .66672 Mdot
.668 .51637 Mdot
.55406 .35508 Mdot
.67595 .49513 Mdot
.56794 .65129 Mdot
.39221 .63593 Mdot
.55719 .37252 Mdot
.66789 .47886 Mdot
.67156 .49638 Mdot
.5172 .39766 Mdot
.36569 .46785 Mdot
.5116 .29083 Mdot
.53148 .33702 Mdot
.49401 .38218 Mdot
.33883 .44559 Mdot
.38321 .15221 Mdot
.53938 .32502 Mdot
.56997 .57001 Mdot
.36846 .48165 Mdot
.40743 .55908 Mdot
.58451 .66854 Mdot
.57157 .38982 Mdot
.39036 .62396 Mdot
.44466 .63073 Mdot
.59416 .59089 Mdot
.31875 .50114 Mdot
.66615 .65459 Mdot
.26499 .44746 Mdot
.49988 .30916 Mdot
.4831 .33886 Mdot
.66829 .23001 Mdot
.17827 .61753 Mdot
.30344 .4871 Mdot
.58748 .57862 Mdot
.56739 .54374 Mdot
.44541 .61174 Mdot
.54919 .61359 Mdot
.33546 .501 Mdot
.3358 .49834 Mdot
.35947 .46328 Mdot
.66785 .48917 Mdot
.6609 .63287 Mdot
.29822 .43997 Mdot
.3222 .43081 Mdot
.50739 .37297 Mdot
.51075 .40623 Mdot
.64784 .44861 Mdot
.73495 .44779 Mdot
.69075 .51933 Mdot
.57206 .63266 Mdot
.80221 .69754 Mdot
.43266 .58708 Mdot
.44718 .23138 Mdot
.5304 .42619 Mdot
.48147 .92492 Mdot
.54114 .31993 Mdot
.53704 .37879 Mdot
.34337 .43782 Mdot
.65139 .48735 Mdot
.66211 .52341 Mdot
.31468 .48061 Mdot
.38359 .4631 Mdot
.67511 .52912 Mdot
.22463 .38573 Mdot
.17959 .48866 Mdot
.49462 .58678 Mdot
.31783 .46124 Mdot
.43588 .29692 Mdot
.40157 .64971 Mdot
.31269 .42338 Mdot
.44977 .59234 Mdot
.60365 .63294 Mdot
.60355 .67697 Mdot
.42358 .64717 Mdot
.51125 .37377 Mdot
.55947 .63105 Mdot
.53137 .30719 Mdot
.22864 .41208 Mdot
.36798 .38653 Mdot
.60298 .74327 Mdot
.58859 .36211 Mdot
.72658 .66743 Mdot
.51333 .6729 Mdot
.55133 .34292 Mdot
.23876 .63681 Mdot
.66948 .49319 Mdot
.30786 .4285 Mdot
.40423 .6005 Mdot
.35373 .80568 Mdot
.56376 .38313 Mdot
.32025 .46725 Mdot
.41827 .60779 Mdot
.61717 .2652 Mdot
.30846 .54943 Mdot
.55875 .37949 Mdot
.56509 .88007 Mdot
.34915 .51202 Mdot
.5818 .66527 Mdot
.73576 .28887 Mdot
.28441 .46791 Mdot
.65835 .46902 Mdot
.4816 .76955 Mdot
.32445 .22979 Mdot
.33912 .48583 Mdot
.55034 .60416 Mdot
.31551 .48592 Mdot
.68434 .52473 Mdot
.27392 .46448 Mdot
.60782 .63492 Mdot
.52338 .34954 Mdot
.57688 .63087 Mdot
.69463 .51318 Mdot
.77336 .54434 Mdot
.39948 .60373 Mdot
.55442 .64391 Mdot
.43732 .62325 Mdot
.73487 .38155 Mdot
.4743 .79043 Mdot
.40131 .61405 Mdot
.58887 .2279 Mdot
.49843 .40888 Mdot
.28994 .45114 Mdot
.57267 .61277 Mdot
.47854 .76237 Mdot
.50779 .56259 Mdot
.32267 .45093 Mdot
.57177 .64453 Mdot
.62361 .36839 Mdot
.65229 .23903 Mdot
.47544 .41903 Mdot
.74852 .4058 Mdot
.31332 .46206 Mdot
.54742 .61452 Mdot
.75704 .66256 Mdot
.29383 .45792 Mdot
.57866 .60818 Mdot
.44617 .60519 Mdot
.42292 .63485 Mdot
.56694 .34444 Mdot
.39486 .5886 Mdot
.56633 .63302 Mdot
.53786 .68788 Mdot
.37416 .46219 Mdot
.62699 .28177 Mdot
.67242 .48112 Mdot
.59196 .63803 Mdot
.48566 .34199 Mdot
.34714 .42147 Mdot
.43288 .7414 Mdot
.42723 .38459 Mdot
.76875 .71814 Mdot
.57306 .6273 Mdot
.34728 .49386 Mdot
.3246 .46418 Mdot
.4891 .41496 Mdot
.54318 .55141 Mdot
.66532 .64773 Mdot
.66496 .26246 Mdot
.64944 .29226 Mdot
.61794 .60284 Mdot
.62334 .60971 Mdot
.48572 .40211 Mdot
.53087 .39613 Mdot
.44406 .60734 Mdot
.51912 .35318 Mdot
.34242 .43441 Mdot
.57111 .34899 Mdot
.43022 .63966 Mdot
.5954 .61671 Mdot
.55251 .3671 Mdot
.69088 .51192 Mdot
.38794 .61824 Mdot
.45147 .63494 Mdot
.58828 .63285 Mdot
.34763 .4457 Mdot
.71156 .51856 Mdot
.58151 .64019 Mdot
.52429 .3909 Mdot
.4682 .66667 Mdot
.48588 .36447 Mdot
.24123 .3661 Mdot
.29646 .45298 Mdot
.60241 .6608 Mdot
.37665 .46797 Mdot
.4394 .61805 Mdot
.47905 .77743 Mdot
.52306 .37307 Mdot
.58194 .60695 Mdot
.65547 .66439 Mdot
.2366 .39622 Mdot
.35894 .49847 Mdot
.44384 .69247 Mdot
.36954 .44382 Mdot
.61809 .63994 Mdot
.50999 .20302 Mdot
.65308 .50447 Mdot
.60774 .60808 Mdot
.17862 .57483 Mdot
.58289 .62076 Mdot
.51775 .34364 Mdot
.51629 .33116 Mdot
.57732 .66432 Mdot
.64536 .50385 Mdot
.73936 .69969 Mdot
.52815 .65792 Mdot
.33883 .48838 Mdot
.36794 .21824 Mdot
.69269 .782 Mdot
.43171 .57666 Mdot
.43498 .60051 Mdot
.53568 .30025 Mdot
.503 .32484 Mdot
.44887 .5938 Mdot
.41905 .66254 Mdot
.69341 .48902 Mdot
.6031 .59327 Mdot
.28 .49714 Mdot
.39387 .64593 Mdot
.45368 .41399 Mdot
.70006 .55445 Mdot
.49727 .42624 Mdot
.60303 .31265 Mdot
.58283 .38501 Mdot
.65038 .28315 Mdot
.42707 .6436 Mdot
.50675 .33108 Mdot
.50096 .43199 Mdot
.39118 .62562 Mdot
.68042 .52639 Mdot
.35584 .69015 Mdot
.59249 .65441 Mdot
.18665 .34884 Mdot
.50021 .33159 Mdot
.52054 .34013 Mdot
.42453 .65113 Mdot
.67672 .65635 Mdot
.35043 .45047 Mdot
.293 .45625 Mdot
.55742 .62202 Mdot
.47806 .55213 Mdot
.57282 .37981 Mdot
.54387 .33565 Mdot
.5907 .65986 Mdot
.55961 .65505 Mdot
.55773 .71454 Mdot
.49576 .35832 Mdot
.422 .60717 Mdot
.58993 .5414 Mdot
.42897 .64244 Mdot
.48463 .35284 Mdot
.51497 .34197 Mdot
.57966 .37049 Mdot
.48417 .34708 Mdot
.45407 .63134 Mdot
.50321 .33507 Mdot
.45337 .37328 Mdot
.36091 .45478 Mdot
.55748 .39611 Mdot
.64325 .27928 Mdot
.51269 .36047 Mdot
.6835 .52136 Mdot
.44009 .38806 Mdot
.56312 .38041 Mdot
.5741 .38462 Mdot
.52592 .65 Mdot
.5281 .359 Mdot
.43606 .58645 Mdot
.33261 .45428 Mdot
.44483 .61765 Mdot
.43508 .64659 Mdot
.57692 .598 Mdot
.69648 .51511 Mdot
.55152 .41648 Mdot
.68449 .48752 Mdot
.56689 .41279 Mdot
.4968 .40489 Mdot
.5165 .77427 Mdot
.84492 .49624 Mdot
.78704 .57215 Mdot
.52231 .37409 Mdot
.59242 .60645 Mdot
.59121 .66886 Mdot
.36705 .52602 Mdot
.47724 .419 Mdot
.45017 .59625 Mdot
.44699 .62608 Mdot
.70402 .43966 Mdot
.54465 .7994 Mdot
.68275 .52294 Mdot
.55998 .49878 Mdot
.52756 .30658 Mdot
.49122 .36913 Mdot
.50139 .32104 Mdot
.58053 .5905 Mdot
.56812 .55426 Mdot
.60645 .60692 Mdot
.35763 .65351 Mdot
.4344 .63986 Mdot
.56309 .38678 Mdot
.28185 .41115 Mdot
.29666 .45941 Mdot
.33357 .45427 Mdot
.45485 .61791 Mdot
.54954 .65262 Mdot
.68966 .45721 Mdot
.47271 .13758 Mdot
.31464 .51321 Mdot
.64409 .49659 Mdot
.55587 .3459 Mdot
.59187 .62054 Mdot
.30419 .48268 Mdot
.6476 .5317 Mdot
.49402 .39606 Mdot
.66068 .63716 Mdot
.52052 .37702 Mdot
.60626 .44365 Mdot
.36061 .47418 Mdot
.17969 .45678 Mdot
.31347 .49688 Mdot
.38961 .61332 Mdot
.39786 .61125 Mdot
.51505 .33515 Mdot
.69055 .24854 Mdot
.28784 .4567 Mdot
.37876 .59088 Mdot
.69592 .48476 Mdot
.4413 .72666 Mdot
.67639 .53088 Mdot
.59049 .66585 Mdot
.64894 .50947 Mdot
.6069 .64574 Mdot
.73553 .46663 Mdot
.32952 .50814 Mdot
.66278 .51151 Mdot
.53599 .61713 Mdot
.47277 .41258 Mdot
.66865 .53734 Mdot
.56328 .30622 Mdot
.29747 .29134 Mdot
.58614 .65823 Mdot
.65896 .49079 Mdot
.50027 .40121 Mdot
.24725 .70709 Mdot
.41338 .60394 Mdot
.44431 .5919 Mdot
.4976 .31169 Mdot
.59578 .58759 Mdot
.37029 .48785 Mdot
.22946 .57351 Mdot
.48001 .61079 Mdot
.52792 .32804 Mdot
.5677 .34194 Mdot
.3516 .43118 Mdot
.39943 .4381 Mdot
.51177 .33994 Mdot
.53838 .24166 Mdot
.49796 .34747 Mdot
.44751 .60428 Mdot
.2932 .47741 Mdot
.32842 .45978 Mdot
.56859 .6436 Mdot
.32436 .43668 Mdot
.25374 .47524 Mdot
.42119 .68734 Mdot
.54079 .29837 Mdot
.43264 .61411 Mdot
.39585 .68023 Mdot
.35693 .65156 Mdot
.1934 .61806 Mdot
.35706 .43159 Mdot
.58277 .36654 Mdot
.37454 .4657 Mdot
.68284 .50662 Mdot
.34674 .45622 Mdot
.3535 .49487 Mdot
.54253 .34253 Mdot
.55276 .37614 Mdot
.60027 .61225 Mdot
.54735 .55199 Mdot
.36431 .45439 Mdot
.51828 .32795 Mdot
.52518 .31211 Mdot
.52385 .31026 Mdot
.45122 .48095 Mdot
.30436 .48677 Mdot
.43821 .21977 Mdot
.64751 .37095 Mdot
.36311 .45331 Mdot
.40179 .82449 Mdot
.47086 .76362 Mdot
.56793 .66859 Mdot
.39475 .59455 Mdot
.49533 .35982 Mdot
.58796 .67145 Mdot
.55238 .37252 Mdot
.60245 .31137 Mdot
.53511 .35525 Mdot
.66799 .53121 Mdot
.55669 .308 Mdot
.61411 .66043 Mdot
.57979 .63647 Mdot
.53687 .32718 Mdot
.54888 .36389 Mdot
.77554 .55874 Mdot
.3829 .45769 Mdot
.3532 .45318 Mdot
.66831 .67437 Mdot
.66839 .50566 Mdot
.39536 .63626 Mdot
.54066 .3885 Mdot
.57257 .60191 Mdot
.57737 .63391 Mdot
.28722 .47265 Mdot
.57959 .65005 Mdot
.40949 .6453 Mdot
.52597 .37437 Mdot
.44558 .59179 Mdot
.67243 .48738 Mdot
.31359 .48794 Mdot
.56002 .38593 Mdot
.50709 .37244 Mdot
.35292 .48779 Mdot
.53299 .42246 Mdot
.64938 .52666 Mdot
.58082 .62181 Mdot
.34191 .4826 Mdot
.42582 .62926 Mdot
.59979 .66108 Mdot
.4984 .38196 Mdot
.78932 .70492 Mdot
.51373 .34756 Mdot
.49693 .36929 Mdot
.16859 .56713 Mdot
.55733 .30742 Mdot
.57128 .61908 Mdot
.33154 .42954 Mdot
.56022 .32046 Mdot
.67756 .31942 Mdot
.40819 .15304 Mdot
.60388 .60156 Mdot
.55831 .34533 Mdot
.19515 .65729 Mdot
.55046 .33526 Mdot
.58875 .21338 Mdot
.73328 .54284 Mdot
.42064 .53546 Mdot
.4819 .31677 Mdot
.4108 .64022 Mdot
.59971 .61051 Mdot
.59442 .66327 Mdot
.4127 .20966 Mdot
.54284 .33954 Mdot
.60241 .45575 Mdot
.52085 .41673 Mdot
.42628 .63705 Mdot
.67366 .43113 Mdot
.57387 .63083 Mdot
.80372 .60126 Mdot
.51604 .39074 Mdot
.30764 .49008 Mdot
.56824 .6766 Mdot
.45697 .75385 Mdot
.49617 .38423 Mdot
.68508 .48969 Mdot
.38277 .62172 Mdot
.55672 .31253 Mdot
.42804 .61649 Mdot
.49001 .37734 Mdot
.47213 .43659 Mdot
.77708 .33404 Mdot
.36351 .46609 Mdot
.44053 .60159 Mdot
.48136 .66226 Mdot
.58956 .37894 Mdot
.34134 .48421 Mdot
.33105 .4492 Mdot
.69295 .49094 Mdot
.51132 .52535 Mdot
.30946 .58179 Mdot
.41347 .37368 Mdot
.40663 .20639 Mdot
.56218 .6704 Mdot
.47793 .69098 Mdot
.50318 .39286 Mdot
.61793 .76374 Mdot
.41529 .58961 Mdot
.52193 .34279 Mdot
.29986 .30298 Mdot
.30633 .48069 Mdot
.50388 .3555 Mdot
.67206 .52773 Mdot
.6551 .73261 Mdot
.64356 .74977 Mdot
.39647 .78413 Mdot
.60112 .62557 Mdot
.59833 .40344 Mdot
.60788 .39931 Mdot
.5581 .61085 Mdot
.54638 .41484 Mdot
.57574 .61484 Mdot
.26641 .3014 Mdot
.64512 .52483 Mdot
.31367 .49007 Mdot
.46689 .76113 Mdot
.56799 .4003 Mdot
.4943 .3195 Mdot
.65004 .53748 Mdot
.5333 .4013 Mdot
.82354 .42354 Mdot
.57584 .74524 Mdot
.55799 .63847 Mdot
.36058 .46376 Mdot
.57489 .39104 Mdot
.53152 .51472 Mdot
.53498 .33525 Mdot
.38787 .3491 Mdot
.57478 .3848 Mdot
.31355 .56565 Mdot
.36298 .47677 Mdot
.43181 .61752 Mdot
.58012 .4121 Mdot
.53535 .36312 Mdot
.60615 .51873 Mdot
.48732 .31176 Mdot
.52658 .32222 Mdot
.3673 .49195 Mdot
.29435 .47501 Mdot
.34317 .47132 Mdot
.61494 .63653 Mdot
.55242 .7972 Mdot
.43327 .60748 Mdot
.56633 .43131 Mdot
.39668 .64988 Mdot
.45885 .30213 Mdot
.64066 .51301 Mdot
.25152 .69727 Mdot
.54886 .40158 Mdot
.33488 .47034 Mdot
.31063 .68815 Mdot
.36747 .45193 Mdot
.56075 .5136 Mdot
.41332 .62385 Mdot
.30187 .47634 Mdot
.53593 .37253 Mdot
.53982 .5656 Mdot
.32341 .75631 Mdot
.44226 .62647 Mdot
.55339 .42032 Mdot
.58467 .67388 Mdot
.5418 .78194 Mdot
.77895 .72074 Mdot
.41783 .59941 Mdot
.48354 .65823 Mdot
.54546 .33891 Mdot
.29962 .45233 Mdot
.41063 .64259 Mdot
.40601 .6113 Mdot
.57728 .65032 Mdot
.55402 .3784 Mdot
.55562 .38232 Mdot
.61391 .6561 Mdot
.44331 .63049 Mdot
.47095 .35525 Mdot
.52282 .31685 Mdot
.17959 .66384 Mdot
.62785 .33381 Mdot
.24011 .26041 Mdot
.25176 .47031 Mdot
.29201 .32358 Mdot
.22317 .54197 Mdot
.34658 .49494 Mdot
.56396 .37911 Mdot
.58947 .35289 Mdot
.56701 .6334 Mdot
.52075 .36045 Mdot
.58794 .58034 Mdot
.42825 .60184 Mdot
.39339 .8168 Mdot
.33695 .65482 Mdot
.28082 .27782 Mdot
.52254 .35822 Mdot
.35731 .61375 Mdot
.67651 .51542 Mdot
.42243 .66714 Mdot
.34025 .47817 Mdot
.48508 .37744 Mdot
.77751 .5632 Mdot
.6074 .60826 Mdot
.31683 .44677 Mdot
.75215 .65432 Mdot
.72953 .65915 Mdot
.48419 .35437 Mdot
.61168 .65022 Mdot
.26709 .65662 Mdot
.53972 .24406 Mdot
.46759 .61093 Mdot
.67163 .53117 Mdot
.60636 .61754 Mdot
.44226 .63829 Mdot
.25367 .43756 Mdot
.29939 .46862 Mdot
.27684 .47903 Mdot
.78723 .5147 Mdot
.55638 .60928 Mdot
.67334 .51933 Mdot
.54144 .79794 Mdot
.62381 .77195 Mdot
.66686 .5308 Mdot
.60426 .67476 Mdot
.29799 .47872 Mdot
.32397 .47881 Mdot
.33138 .45464 Mdot
.7951 .6174 Mdot
.31247 .49851 Mdot
.41639 .24896 Mdot
.50756 .31321 Mdot
.52816 .46203 Mdot
.55665 .34185 Mdot
.45526 .6 Mdot
.35503 .48062 Mdot
.45913 .55386 Mdot
.53717 .43407 Mdot
.38464 .7905 Mdot
.53744 .33127 Mdot
.4472 .65056 Mdot
.49959 .35928 Mdot
.44303 .25122 Mdot
.37449 .47033 Mdot
.52038 .36847 Mdot
.45576 .59401 Mdot
.67383 .50017 Mdot
.26686 .46278 Mdot
.56036 .38146 Mdot
.26421 .60178 Mdot
.56031 .30838 Mdot
.22283 .37003 Mdot
.63588 .30652 Mdot
.64401 .49685 Mdot
.5496 .26756 Mdot
.55846 .59892 Mdot
.54667 .46494 Mdot
.57215 .44465 Mdot
.43974 .62776 Mdot
.4291 .76574 Mdot
.59784 .63692 Mdot
.73137 .49074 Mdot
.568 .43513 Mdot
.69224 .52076 Mdot
.38786 .47639 Mdot
.46023 .60989 Mdot
.49212 .40537 Mdot
.51295 .43087 Mdot
.26485 .31427 Mdot
.51963 .44708 Mdot
.5737 .35313 Mdot
.64106 .52336 Mdot
.39714 .23039 Mdot
.51039 .36409 Mdot
.55561 .51208 Mdot
.27666 .47236 Mdot
.47986 .32646 Mdot
.45594 .21998 Mdot
.52133 .3281 Mdot
.30963 .44752 Mdot
.31169 .50567 Mdot
.31565 .65551 Mdot
.69741 .48848 Mdot
.5723 .38751 Mdot
.54781 .21045 Mdot
.52064 .3931 Mdot
.42236 .60892 Mdot
.49552 .33237 Mdot
.60679 .62884 Mdot
.78864 .61843 Mdot
.56272 .6345 Mdot
.5686 .36574 Mdot
.32587 .4565 Mdot
.42504 .64927 Mdot
.79756 .53726 Mdot
.69192 .57899 Mdot
.41071 .24421 Mdot
.2979 .24326 Mdot
.64864 .49917 Mdot
.68893 .53115 Mdot
.46001 .61587 Mdot
.51911 .36888 Mdot
.52265 .19106 Mdot
.49539 .30385 Mdot
.50505 .35966 Mdot
.53617 .35503 Mdot
.49628 .79549 Mdot
.44169 .6074 Mdot
.58674 .652 Mdot
.51232 .34165 Mdot
.51031 .33012 Mdot
.35573 .48946 Mdot
.67188 .4983 Mdot
.58685 .66898 Mdot
.66167 .50141 Mdot
.59065 .61261 Mdot
.39058 .8204 Mdot
.5725 .42252 Mdot
.67361 .50276 Mdot
.3995 .59834 Mdot
.33635 .44439 Mdot
.42668 .68739 Mdot
.5904 .66526 Mdot
.57127 .63396 Mdot
.53373 .33018 Mdot
.31036 .44599 Mdot
.34413 .44093 Mdot
.68377 .5058 Mdot
.39789 .6195 Mdot
.56141 .37608 Mdot
.49272 .39953 Mdot
.37441 .53325 Mdot
.58559 .59068 Mdot
.62179 .37823 Mdot
.29611 .65348 Mdot
.52047 .37296 Mdot
.33976 .44153 Mdot
.54414 .35572 Mdot
.20035 .49968 Mdot
.3047 .44682 Mdot
.53329 .32196 Mdot
.66842 .75765 Mdot
.60858 .56283 Mdot
.28913 .60751 Mdot
.57747 .35649 Mdot
.20734 .33831 Mdot
.50987 .40156 Mdot
.19563 .6881 Mdot
.73777 .58055 Mdot
.56786 .38301 Mdot
.50209 .38277 Mdot
.38888 .40083 Mdot
.55745 .35562 Mdot
.61664 .64971 Mdot
.73088 .48139 Mdot
.36199 .49209 Mdot
.24876 .55003 Mdot
.44506 .44422 Mdot
.69014 .48216 Mdot
.557 .62337 Mdot
.62579 .61931 Mdot
.65827 .52419 Mdot
.31606 .46362 Mdot
.52733 .38571 Mdot
.46304 .53681 Mdot
.61369 .59167 Mdot
.46594 .38108 Mdot
.41929 .61263 Mdot
.51037 .71294 Mdot
.54206 .62403 Mdot
.4282 .62395 Mdot
.54903 .4061 Mdot
.39765 .40589 Mdot
.77808 .45342 Mdot
.16967 .47861 Mdot
.4306 .65045 Mdot
.4402 .63521 Mdot
.78541 .64228 Mdot
.68682 .47948 Mdot
.29712 .27635 Mdot
.31121 .55685 Mdot
.40887 .64794 Mdot
.5835 .24537 Mdot
.60283 .59614 Mdot
.26714 .59545 Mdot
.30755 .42852 Mdot
.48505 .33633 Mdot
.53534 .3698 Mdot
.39633 .61944 Mdot
.23999 .45102 Mdot
.76263 .31883 Mdot
.4368 .62469 Mdot
.45078 .38027 Mdot
.44804 .49822 Mdot
.4727 .76358 Mdot
.58713 .59345 Mdot
.69697 .49002 Mdot
.65556 .4745 Mdot
.33456 .49255 Mdot
.69776 .49987 Mdot
.64296 .74398 Mdot
.5402 .40186 Mdot
.43412 .63183 Mdot
.43524 .73808 Mdot
.42254 .62916 Mdot
.6597 .52336 Mdot
.64353 .49639 Mdot
.36034 .45443 Mdot
.35345 .45441 Mdot
.29536 .33387 Mdot
.68015 .41106 Mdot
.54511 .33141 Mdot
.3368 .74333 Mdot
.37376 .46074 Mdot
.58048 .28526 Mdot
.6898 .52908 Mdot
.67068 .50174 Mdot
.63561 .40093 Mdot
.55193 .38935 Mdot
.56307 .21092 Mdot
.5475 .38843 Mdot
.67613 .42654 Mdot
.57629 .39907 Mdot
.57819 .65017 Mdot
.55514 .39088 Mdot
.69829 .53537 Mdot
.48341 .39722 Mdot
.50986 .32356 Mdot
.59201 .58694 Mdot
.55776 .31454 Mdot
.60653 .63172 Mdot
.56824 .35815 Mdot
.70167 .48666 Mdot
.5666 .60572 Mdot
.69961 .34737 Mdot
.54959 .57797 Mdot
.59588 .67906 Mdot
.6949 .50445 Mdot
.67567 .48215 Mdot
.69085 .3067 Mdot
.33926 .47911 Mdot
.27823 .43882 Mdot
.5181 .36472 Mdot
.58122 .58406 Mdot
.44098 .6043 Mdot
.50325 .33617 Mdot
.58225 .32877 Mdot
.56684 .33723 Mdot
.32433 .49244 Mdot
.66356 .66176 Mdot
.67835 .502 Mdot
.61588 .63444 Mdot
.6206 .5295 Mdot
.60924 .59364 Mdot
.51854 .43996 Mdot
.5966 .37444 Mdot
.27025 .36046 Mdot
.36239 .73253 Mdot
.77183 .67894 Mdot
.30023 .46273 Mdot
.55369 .64081 Mdot
.6773 .48073 Mdot
.52763 .27892 Mdot
.33357 .47556 Mdot
.60767 .63413 Mdot
.52137 .37767 Mdot
.55548 .41967 Mdot
.42355 .67315 Mdot
.56361 .46352 Mdot
.65506 .31163 Mdot
.60774 .5938 Mdot
.55132 .60261 Mdot
.62048 .77108 Mdot
.72802 .48018 Mdot
.49261 .55933 Mdot
.53144 .34352 Mdot
.68335 .48898 Mdot
.30409 .48256 Mdot
.7816 .48015 Mdot
.40676 .60079 Mdot
.54505 .55232 Mdot
.52258 .35997 Mdot
.41184 .54775 Mdot
.32663 .45518 Mdot
.67696 .52612 Mdot
.39553 .62068 Mdot
.63506 .5158 Mdot
.56438 .6019 Mdot
.42022 .168 Mdot
.52503 .3968 Mdot
.54468 .32896 Mdot
.39984 .60194 Mdot
.31357 .48363 Mdot
.64309 .53442 Mdot
.23074 .38299 Mdot
.57023 .65593 Mdot
.53822 .19212 Mdot
.33094 .43502 Mdot
.42936 .27435 Mdot
.61652 .62693 Mdot
.45429 .61962 Mdot
.70442 .33039 Mdot
.42913 .64004 Mdot
.57208 .36925 Mdot
.33216 .46439 Mdot
.41636 .60377 Mdot
.58235 .52412 Mdot
.21598 .67912 Mdot
.43429 .29003 Mdot
.54218 .39501 Mdot
.28787 .74339 Mdot
.21479 .43953 Mdot
.38835 .49023 Mdot
.39007 .62349 Mdot
.53077 .33563 Mdot
.54938 .4117 Mdot
.51823 .38918 Mdot
.4092 .62221 Mdot
.50937 .76254 Mdot
.58459 .65951 Mdot
.551 .33911 Mdot
.69189 .48821 Mdot
.60397 .63815 Mdot
.46417 .76269 Mdot
.5704 .6245 Mdot
.37702 .44577 Mdot
.49759 .32927 Mdot
.3731 .64431 Mdot
.28111 .76456 Mdot
.44477 .62021 Mdot
.59794 .67934 Mdot
.4934 .34281 Mdot
.41991 .74669 Mdot
.34081 .47189 Mdot
.56713 .65142 Mdot
.52129 .34001 Mdot
.48405 .75033 Mdot
.77814 .55335 Mdot
.57097 .6258 Mdot
.32918 .48174 Mdot
.20262 .55657 Mdot
.5192 .35612 Mdot
.51392 .40218 Mdot
.31185 .47908 Mdot
.44562 .43498 Mdot
.75665 .65608 Mdot
.54668 .36065 Mdot
.43156 .61889 Mdot
.53171 .16402 Mdot
.55112 .31823 Mdot
.64251 .40605 Mdot
.6028 .6135 Mdot
.28842 .63075 Mdot
.62216 .36255 Mdot
.56634 .27895 Mdot
.23509 .45039 Mdot
.46769 .47113 Mdot
.37073 .7986 Mdot
.57254 .58511 Mdot
.73502 .62998 Mdot
.36858 .80323 Mdot
.4632 .60908 Mdot
.31337 .41269 Mdot
.29076 .52025 Mdot
.81855 .57346 Mdot
.21127 .57215 Mdot
.68862 .6683 Mdot
.7797 .57265 Mdot
.44572 .51984 Mdot
.58512 .61426 Mdot
.71212 .4808 Mdot
.55734 .37535 Mdot
.21345 .43809 Mdot
.50833 .23418 Mdot
.73359 .27643 Mdot
.27669 .73432 Mdot
.55916 .21911 Mdot
.26845 .71222 Mdot
.18954 .60756 Mdot
.2654 .34851 Mdot
.34937 .72234 Mdot
.56053 .18806 Mdot
.66308 .7548 Mdot
.42896 .18583 Mdot
.59957 .34072 Mdot
.58141 .49637 Mdot
.24056 .31949 Mdot
.40775 .27401 Mdot
.68414 .25284 Mdot
.56606 .64256 Mdot
.32882 .42967 Mdot
.295 .52509 Mdot
.38516 .47485 Mdot
.495 .61827 Mdot
.19656 .53772 Mdot
.18429 .648 Mdot
.44725 .24382 Mdot
.1939 .34986 Mdot
.32808 .27718 Mdot
.86983 .44801 Mdot
.56718 .69141 Mdot
.28251 .46331 Mdot
.63092 .485 Mdot
.60645 .78123 Mdot
.33887 .61324 Mdot
.24849 .48831 Mdot
.53128 .77788 Mdot
.71438 .39302 Mdot
.32023 .46615 Mdot
.5768 .26711 Mdot
.51659 .65598 Mdot
.34427 .65744 Mdot
.75108 .51447 Mdot
.19505 .59518 Mdot
.48987 .54268 Mdot
.25851 .58316 Mdot
.49788 .69549 Mdot
.78185 .70974 Mdot
.64932 .35396 Mdot
.24381 .42808 Mdot
.45883 .66754 Mdot
.20896 .51822 Mdot
.82238 .52768 Mdot
.70209 .42166 Mdot
.61181 .77895 Mdot
.54128 .82438 Mdot
.20137 .43545 Mdot
.57694 .83405 Mdot
.27231 .44455 Mdot
.57301 .34995 Mdot
.31685 .39453 Mdot
.53197 .21601 Mdot
.69993 .47712 Mdot
.41272 .78588 Mdot
.6656 .48749 Mdot
.38035 .44125 Mdot
.78304 .62011 Mdot
.42954 .24626 Mdot
.55778 .20366 Mdot
.64615 .54098 Mdot
.5884 .3618 Mdot
.63379 .15167 Mdot
.3611 .78928 Mdot
.31401 .64587 Mdot
.18043 .66835 Mdot
.4464 .55805 Mdot
.61667 .26714 Mdot
.41507 .60609 Mdot
.33627 .79213 Mdot
.32517 .47385 Mdot
.49353 .86083 Mdot
.25526 .7321 Mdot
.75925 .32959 Mdot
.37869 .1268 Mdot
.60663 .75866 Mdot
.42055 .54046 Mdot
.44104 .45686 Mdot
.67962 .34496 Mdot
.80032 .39107 Mdot
.72551 .29324 Mdot
.41501 .73718 Mdot
.27235 .27167 Mdot
.33679 .78721 Mdot
.52751 .20859 Mdot
.42226 .17421 Mdot
.82334 .56011 Mdot
.53324 .5023 Mdot
.37299 .42756 Mdot
.50907 .6306 Mdot
.23641 .64753 Mdot
.47583 .8279 Mdot
.64447 .37745 Mdot
.44264 .13224 Mdot
.6885 .53879 Mdot
.72759 .5871 Mdot
.17972 .50842 Mdot
.72316 .38056 Mdot
.61068 .28276 Mdot
.74071 .68006 Mdot
.47545 .40238 Mdot
.72129 .70117 Mdot
.28681 .71147 Mdot
.45903 .67736 Mdot
.67053 .74551 Mdot
.24858 .62032 Mdot
.24735 .34157 Mdot
.36514 .38109 Mdot
.60022 .78849 Mdot
.38007 .47357 Mdot
.69575 .39881 Mdot
.6264 .30209 Mdot
.17658 .64721 Mdot
.48536 .65653 Mdot
.1487 .59001 Mdot
.76636 .63133 Mdot
.58659 .38713 Mdot
.58387 .44084 Mdot
.45868 .33131 Mdot
.67736 .39486 Mdot
.53273 .31338 Mdot
.35327 .64358 Mdot
.17175 .61261 Mdot
.31866 .27716 Mdot
.43897 .69182 Mdot
.43395 .77214 Mdot
.16844 .48333 Mdot
.28215 .37665 Mdot
.76249 .57475 Mdot
.65503 .44058 Mdot
.81988 .62798 Mdot
.59631 .64356 Mdot
.5199 .20514 Mdot
.46391 .62329 Mdot
.77046 .50946 Mdot
.41893 .36218 Mdot
.79153 .39132 Mdot
.17124 .61132 Mdot
.70972 .68225 Mdot
.77845 .5975 Mdot
.735 .36735 Mdot
.5209 .18017 Mdot
.43092 .77932 Mdot
.58842 .41732 Mdot
.23674 .50017 Mdot
.6468 .49856 Mdot
.31045 .35264 Mdot
.46787 .19407 Mdot
.69163 .61646 Mdot
.51753 .3029 Mdot
.77509 .41723 Mdot
.64161 .68619 Mdot
.53881 .56472 Mdot
.65371 .81645 Mdot
.48158 .4203 Mdot
.55826 .78697 Mdot
.20279 .41583 Mdot
.66633 .36071 Mdot
.18854 .49654 Mdot
.23974 .58312 Mdot
.56023 .83355 Mdot
.23169 .70965 Mdot
.68095 .59311 Mdot
.40504 .80943 Mdot
.17207 .65063 Mdot
.59694 .81982 Mdot
.53016 .45281 Mdot
.42714 .58488 Mdot
.69781 .81291 Mdot
.61879 .62028 Mdot
.49417 .80224 Mdot
.4073 .20638 Mdot
.48951 .74598 Mdot
.26785 .48434 Mdot
.5851 .31381 Mdot
.45602 .52514 Mdot
.39039 .48321 Mdot
.54856 .31168 Mdot
.69601 .77607 Mdot
.57912 .81685 Mdot
.63861 .81072 Mdot
.20265 .38008 Mdot
.40715 .81493 Mdot
.41171 .52376 Mdot
.41725 .26312 Mdot
.38465 .51169 Mdot
.48106 .35839 Mdot
.71737 .53734 Mdot
.60698 .7569 Mdot
.78266 .42996 Mdot
.33461 .5944 Mdot
.38613 .46778 Mdot
.36809 .76455 Mdot
.91279 .53084 Mdot
.32197 .29401 Mdot
.45882 .2136 Mdot
.63651 .75709 Mdot
.67012 .40017 Mdot
.25702 .6717 Mdot
.77355 .36143 Mdot
.17081 .57888 Mdot
.37731 .51294 Mdot
.41229 .19765 Mdot
.69499 .64917 Mdot
.63616 .25393 Mdot
.66024 .67851 Mdot
.20451 .65562 Mdot
.41879 .47025 Mdot
.79879 .48309 Mdot
.29001 .53948 Mdot
.76013 .32382 Mdot
.74312 .55336 Mdot
.51796 .71281 Mdot
.47605 .18862 Mdot
.39664 .71185 Mdot
.65815 .40737 Mdot
.46394 .50927 Mdot
.49989 .28768 Mdot
.46482 .46989 Mdot
.65516 .39726 Mdot
.65061 .26895 Mdot
.45659 .81884 Mdot
.17617 .68551 Mdot
.76948 .70648 Mdot
.18301 .36411 Mdot
.28442 .70249 Mdot
.48035 .34157 Mdot
.16682 .51785 Mdot
.5901 .8388 Mdot
.23483 .72097 Mdot
.5975 .71393 Mdot
.6216 .58011 Mdot
.39718 .65346 Mdot
.7428 .72372 Mdot
.65104 .68748 Mdot
.18256 .55595 Mdot
.7308 .70128 Mdot
.38138 .61053 Mdot
.84401 .48488 Mdot
.56833 .81384 Mdot
.42804 .3333 Mdot
.58306 .45102 Mdot
.47095 .38177 Mdot
.46108 .24606 Mdot
.37757 .45324 Mdot
.48564 .6874 Mdot
.68979 .41168 Mdot
.58853 .63787 Mdot
.7329 .53135 Mdot
.2434 .48577 Mdot
.5556 .30767 Mdot
.45437 .45681 Mdot
.32768 .42861 Mdot
.35997 .72962 Mdot
.39033 .68621 Mdot
.45053 .83384 Mdot
.60184 .74887 Mdot
.47738 .32011 Mdot
.66216 .36076 Mdot
.65332 .70099 Mdot
.75629 .66907 Mdot
.44801 .64612 Mdot
.25832 .71767 Mdot
.57853 .5093 Mdot
.69368 .40004 Mdot
.47523 .2439 Mdot
.24956 .34873 Mdot
.59916 .35999 Mdot
.30363 .66868 Mdot
.37239 .34515 Mdot
.55163 .55103 Mdot
.37665 .43131 Mdot
.37243 .42573 Mdot
.15333 .47708 Mdot
.6627 .72484 Mdot
.49307 .70145 Mdot
.24878 .70594 Mdot
.41472 .63544 Mdot
.36549 .45367 Mdot
.7075 .5393 Mdot
.23774 .35403 Mdot
.39068 .31807 Mdot
.77861 .55404 Mdot
.55344 .75437 Mdot
.70316 .60685 Mdot
.26148 .71133 Mdot
.28178 .73336 Mdot
.72098 .2558 Mdot
.36149 .49773 Mdot
.24546 .37571 Mdot
.31297 .25528 Mdot
.36054 .43711 Mdot
.3001 .51753 Mdot
.34949 .60438 Mdot
.45857 .82749 Mdot
.3875 .59196 Mdot
.26098 .27914 Mdot
.66257 .29552 Mdot
.49371 .76129 Mdot
.79741 .54351 Mdot
.48163 .18532 Mdot
.24018 .69496 Mdot
.53958 .24659 Mdot
.42154 .38071 Mdot
.56744 .30571 Mdot
.58195 .46317 Mdot
.81982 .65914 Mdot
.5583 .57406 Mdot
.43306 .27023 Mdot
.23826 .60589 Mdot
.52866 .39264 Mdot
.76659 .71902 Mdot
.22519 .4136 Mdot
.78348 .64916 Mdot
.38329 .62893 Mdot
.51618 .4114 Mdot
.47869 .38319 Mdot
.63285 .4419 Mdot
.30407 .6436 Mdot
.51152 .81328 Mdot
.47378 .18366 Mdot
.25104 .64252 Mdot
.50712 .23509 Mdot
.55447 .78733 Mdot
.19203 .57331 Mdot
.21489 .4474 Mdot
.52498 .52597 Mdot
.61261 .75078 Mdot
.71903 .35821 Mdot
.19317 .35888 Mdot
.60775 .49139 Mdot
.39351 .5317 Mdot
.35448 .5727 Mdot
.27366 .63045 Mdot
.79103 .50128 Mdot
.48826 .37977 Mdot
.75208 .6545 Mdot
.1899 .60077 Mdot
.65394 .21706 Mdot
.81489 .44926 Mdot
.75072 .73342 Mdot
.39512 .35637 Mdot
.25764 .61079 Mdot
.22535 .46752 Mdot
.60355 .17691 Mdot
.59448 .49085 Mdot
.36378 .77696 Mdot
.72389 .35919 Mdot
.25491 .70834 Mdot
.44327 .58466 Mdot
.31711 .54943 Mdot
.43873 .77505 Mdot
.43127 .81487 Mdot
.30532 .38027 Mdot
.20255 .64179 Mdot
.43329 .54671 Mdot
.53182 .84691 Mdot
.38384 .71549 Mdot
.43717 .51134 Mdot
.55317 .63428 Mdot
.70669 .6908 Mdot
.26812 .70293 Mdot
.33205 .72494 Mdot
.47696 .19155 Mdot
.55515 .59341 Mdot
.72976 .50539 Mdot
.45447 .28993 Mdot
.74705 .41511 Mdot
.27259 .64017 Mdot
.6625 .36047 Mdot
.18883 .63686 Mdot
.61951 .4866 Mdot
.76712 .61875 Mdot
.55136 .78523 Mdot
.39164 .17935 Mdot
.3084 .64109 Mdot
.67641 .71887 Mdot
.22818 .44345 Mdot
.73033 .5715 Mdot
.59234 .24874 Mdot
.2501 .79687 Mdot
.36963 .20231 Mdot
.36654 .71999 Mdot
.47683 .82762 Mdot
.19075 .48704 Mdot
.3683 .73234 Mdot
.80522 .40161 Mdot
.62727 .33512 Mdot
.73851 .47925 Mdot
.53556 .35637 Mdot
.64109 .81857 Mdot
.72709 .41262 Mdot
.49714 .83531 Mdot
.16487 .504 Mdot
.45993 .25196 Mdot
.55687 .30897 Mdot
.61376 .62108 Mdot
.50097 .65933 Mdot
.75481 .44426 Mdot
.41079 .41617 Mdot
.59057 .26406 Mdot
.57142 .74898 Mdot
.5578 .61057 Mdot
.66446 .6773 Mdot
.356 .51424 Mdot
.60237 .73595 Mdot
.29005 .64899 Mdot
.65578 .5634 Mdot
.51443 .54475 Mdot
.65958 .39264 Mdot
.61708 .33081 Mdot
.42649 .33277 Mdot
.79402 .40518 Mdot
.50792 .49623 Mdot
.56941 .62163 Mdot
.4072 .37577 Mdot
.2822 .26758 Mdot
.27121 .65723 Mdot
.53325 .82604 Mdot
.73335 .67575 Mdot
.42965 .37913 Mdot
.65235 .40586 Mdot
.79165 .37411 Mdot
.60925 .22261 Mdot
.37266 .75226 Mdot
.61598 .37374 Mdot
.58319 .22718 Mdot
.2508 .51232 Mdot
.38449 .81528 Mdot
.42555 .18821 Mdot
.36536 .21791 Mdot
.52347 .6289 Mdot
.39583 .28319 Mdot
.46646 .26025 Mdot
.69678 .33647 Mdot
.5105 .56255 Mdot
.87035 .47007 Mdot
.29243 .43718 Mdot
.84118 .64858 Mdot
.44054 .5989 Mdot
.82991 .56625 Mdot
.71403 .33723 Mdot
.46271 .50567 Mdot
.50105 .56887 Mdot
.31067 .67212 Mdot
.31637 .5651 Mdot
.21095 .35195 Mdot
.71425 .26585 Mdot
.60732 .59032 Mdot
.47923 .17701 Mdot
.4096 .16554 Mdot
.39733 .39514 Mdot
.58545 .35538 Mdot
.36302 .20423 Mdot
.57952 .57714 Mdot
.78359 .4304 Mdot
.18133 .48724 Mdot
.30991 .70385 Mdot
.46183 .42262 Mdot
.67465 .40266 Mdot
.35465 .77112 Mdot
.22979 .70155 Mdot
.82972 .44945 Mdot
.28702 .71119 Mdot
.42546 .58548 Mdot
.42295 .51682 Mdot
.21708 .65194 Mdot
.63347 .28713 Mdot
.26292 .56915 Mdot
.61866 .28514 Mdot
.87328 .56434 Mdot
.47559 .80154 Mdot
.50966 .81257 Mdot
.63064 .29485 Mdot
.30576 .49777 Mdot
.36468 .69363 Mdot
.61423 .28712 Mdot
.31715 .70192 Mdot
.23709 .3309 Mdot
.62201 .29584 Mdot
.68928 .21681 Mdot
.29116 .29814 Mdot
.64034 .59101 Mdot
.47218 .26264 Mdot
.29709 .29877 Mdot
.38192 .61507 Mdot
.74342 .49651 Mdot
.2381 .61179 Mdot
.39462 .60591 Mdot
.27733 .64626 Mdot
.269 .60658 Mdot
.32821 .25573 Mdot
.40053 .31622 Mdot
.26171 .6608 Mdot
.36608 .39825 Mdot
.33588 .41002 Mdot
.7808 .48495 Mdot
.57282 .67558 Mdot
.22422 .59586 Mdot
.56392 .65252 Mdot
.59007 .30327 Mdot
.55751 .54244 Mdot
.4406 .37315 Mdot
.76198 .70681 Mdot
.64906 .49708 Mdot
.28607 .46509 Mdot
.83923 .56521 Mdot
.34671 .43389 Mdot
.6736 .79338 Mdot
.78286 .37817 Mdot
.47723 .2411 Mdot
.69182 .58545 Mdot
.67766 .63399 Mdot
.80522 .32971 Mdot
.41688 .43587 Mdot
.52097 .63596 Mdot
.38224 .42164 Mdot
.29087 .4777 Mdot
.56656 .77114 Mdot
.57487 .5968 Mdot
.62761 .40864 Mdot
.3879 .56004 Mdot
.40826 .48009 Mdot
.34661 .5062 Mdot
.5673 .52402 Mdot
.70733 .45071 Mdot
.44997 .82549 Mdot
.57965 .61069 Mdot
.85845 .56728 Mdot
.59231 .34341 Mdot
.34942 .37404 Mdot
.16748 .57485 Mdot
.83909 .46744 Mdot
.62243 .63308 Mdot
.42782 .15136 Mdot
.57056 .4069 Mdot
.26442 .67192 Mdot
.31885 .47208 Mdot
.3886 .20612 Mdot
.65138 .50306 Mdot
.67084 .35458 Mdot
.40631 .65962 Mdot
.79847 .48696 Mdot
.59025 .7331 Mdot
.31507 .50282 Mdot
.30967 .71803 Mdot
.25408 .35601 Mdot
.28571 .55308 Mdot
.67073 .65034 Mdot
.40709 .39358 Mdot
.39773 .31091 Mdot
.33799 .50745 Mdot
.4848 .8133 Mdot
.39596 .20025 Mdot
.3667 .81961 Mdot
.46306 .32424 Mdot
.72807 .65185 Mdot
.36172 .56049 Mdot
.28835 .66362 Mdot
.61075 .42653 Mdot
.17194 .59603 Mdot
.70103 .41311 Mdot
.36349 .5764 Mdot
.67149 .42148 Mdot
.57134 .28878 Mdot
.50392 .53602 Mdot
.51454 .68934 Mdot
.75748 .29629 Mdot
.60179 .4511 Mdot
.82845 .51694 Mdot
.61571 .3628 Mdot
.57072 .78281 Mdot
.3023 .51077 Mdot
.63153 .59889 Mdot
.40565 .28286 Mdot
.48377 .65981 Mdot
.37117 .8096 Mdot
.17084 .58971 Mdot
.39935 .66477 Mdot
.55315 .77369 Mdot
.21401 .52977 Mdot
.487 .30408 Mdot
.40316 .54519 Mdot
.57434 .35869 Mdot
.30201 .51405 Mdot
.84711 .47629 Mdot
.3101 .68858 Mdot
.58844 .42074 Mdot
.36932 .79933 Mdot
.3259 .78362 Mdot
.52141 .84452 Mdot
.53127 .18757 Mdot
.34105 .49629 Mdot
.62627 .80905 Mdot
.5803 .26101 Mdot
.19323 .6681 Mdot
.363 .74541 Mdot
.15321 .49023 Mdot
.41691 .39619 Mdot
.23479 .59143 Mdot
.72687 .28674 Mdot
.29538 .57814 Mdot
.20184 .44946 Mdot
.43211 .48598 Mdot
.47431 .70696 Mdot
.19333 .45902 Mdot
.69726 .20181 Mdot
.61157 .41067 Mdot
.26081 .59304 Mdot
.28253 .52617 Mdot
.22829 .60366 Mdot
.74622 .58571 Mdot
.49488 .33333 Mdot
.43813 .74487 Mdot
.7911 .56582 Mdot
.65403 .3788 Mdot
.72914 .50825 Mdot
.74457 .58559 Mdot
.75572 .47308 Mdot
.68653 .43323 Mdot
.42904 .18522 Mdot
.41553 .38907 Mdot
.62237 .41808 Mdot
.58947 .38271 Mdot
.29094 .50466 Mdot
.70144 .50161 Mdot
.64117 .64879 Mdot
.56864 .35415 Mdot
.61072 .57901 Mdot
.2945 .56048 Mdot
.73113 .75081 Mdot
.43146 .69213 Mdot
.22276 .39602 Mdot
.31097 .42789 Mdot
.30413 .65265 Mdot
.27667 .41263 Mdot
.80504 .59261 Mdot
.72722 .63066 Mdot
.64446 .37709 Mdot
.33607 .77464 Mdot
.6675 .74728 Mdot
.26633 .31878 Mdot
.65998 .767 Mdot
.40889 .59265 Mdot
.47788 .43091 Mdot
.3208 .53834 Mdot
.65729 .70689 Mdot
.38985 .44621 Mdot
.23865 .5977 Mdot
.53119 .65049 Mdot
.67099 .73032 Mdot
.20091 .42004 Mdot
.25294 .35065 Mdot
.45242 .30072 Mdot
.29239 .74374 Mdot
.60264 .60042 Mdot
.36858 .21092 Mdot
.25661 .55899 Mdot
.71919 .64996 Mdot
.55346 .79999 Mdot
.42749 .82909 Mdot
.46629 .55765 Mdot
.70963 .37908 Mdot
.51506 .39709 Mdot
.43791 .22021 Mdot
.31495 .68637 Mdot
.51518 .46701 Mdot
.56078 .73102 Mdot
.33054 .44051 Mdot
.54077 .71319 Mdot
.59283 .48233 Mdot
.74043 .47214 Mdot
.3874 .48334 Mdot
.53601 .2197 Mdot
.70853 .499 Mdot
.44091 .56306 Mdot
.54573 .31311 Mdot
.69618 .36795 Mdot
.55614 .2005 Mdot
.47067 .41888 Mdot
.26211 .68705 Mdot
.41299 .3799 Mdot
.24936 .33306 Mdot
.28449 .67891 Mdot
.38082 .75688 Mdot
.31402 .56992 Mdot
.41739 .28672 Mdot
.61194 .71048 Mdot
.56847 .33966 Mdot
.63053 .60172 Mdot
.35368 .4424 Mdot
.19961 .53058 Mdot
.39068 .35249 Mdot
.7021 .35135 Mdot
.47958 .50278 Mdot
.2994 .40344 Mdot
.47041 .48607 Mdot
.16732 .53462 Mdot
.29649 .57961 Mdot
.69283 .41467 Mdot
.44323 .57852 Mdot
.71263 .33836 Mdot
.80003 .40466 Mdot
.28614 .75561 Mdot
.77882 .35472 Mdot
.46578 .54329 Mdot
.83223 .51054 Mdot
.36681 .70889 Mdot
.17991 .48163 Mdot
.69718 .42621 Mdot
.47938 .56781 Mdot
.71731 .5253 Mdot
.41336 .6737 Mdot
.52275 .50937 Mdot
.62061 .55671 Mdot
.62574 .35183 Mdot
.52151 .73846 Mdot
.52962 .67222 Mdot
.57665 .30753 Mdot
.49705 .79888 Mdot
.31786 .76127 Mdot
.3968 .2067 Mdot
.48141 .48093 Mdot
.75046 .52833 Mdot
.74026 .45882 Mdot
.16128 .37471 Mdot
.7875 .70636 Mdot
.51721 .39747 Mdot
.49031 .48252 Mdot
.69345 .38243 Mdot
.61341 .59918 Mdot
.60819 .29328 Mdot
.30773 .40641 Mdot
.45167 .61496 Mdot
.6146 .55847 Mdot
.68603 .72146 Mdot
.317 .67513 Mdot
.74447 .39777 Mdot
.45533 .76994 Mdot
.72522 .75911 Mdot
.24621 .30691 Mdot
.29683 .67285 Mdot
.14123 .43138 Mdot
.53793 .68761 Mdot
.33849 .4174 Mdot
.30397 .39664 Mdot
.46286 .82325 Mdot
.66091 .35049 Mdot
.78324 .51448 Mdot
.40883 .76865 Mdot
.70134 .41984 Mdot
.59065 .25462 Mdot
.55562 .78457 Mdot
.54844 .71884 Mdot
.46563 .52142 Mdot
.67885 .63538 Mdot
.61529 .79276 Mdot
.51017 .23929 Mdot
.33247 .76359 Mdot
.79474 .56279 Mdot
.65992 .19446 Mdot
.33903 .79476 Mdot
.72461 .53404 Mdot
.75411 .57764 Mdot
.30397 .3943 Mdot
.64884 .29009 Mdot
.57422 .244 Mdot
.79194 .44606 Mdot
.38085 .31693 Mdot
.66276 .61393 Mdot
.81566 .54232 Mdot
.65753 .40632 Mdot
.30422 .28933 Mdot
.48152 .56762 Mdot
.41744 .34914 Mdot
.57722 .75874 Mdot
.63914 .31642 Mdot
.59307 .52521 Mdot
.6715 .31816 Mdot
.40514 .38371 Mdot
.23351 .44233 Mdot
.23471 .55456 Mdot
.73415 .24048 Mdot
.38578 .76935 Mdot
.80817 .58497 Mdot
.5131 .31194 Mdot
.40149 .83151 Mdot
.24327 .56162 Mdot
.40375 .77094 Mdot
.21397 .38006 Mdot
.64116 .61005 Mdot
.37754 .55158 Mdot
.56729 .33829 Mdot
.32107 .73816 Mdot
.43639 .27127 Mdot
.29221 .31331 Mdot
.80167 .50841 Mdot
.6678 .37353 Mdot
.76548 .57806 Mdot
.687 .31858 Mdot
.45483 .39574 Mdot
.31984 .43474 Mdot
.62686 .81681 Mdot
.44476 .54359 Mdot
.60187 .32233 Mdot
.51712 .46219 Mdot
.73417 .29398 Mdot
.30566 .231 Mdot
.45742 .33638 Mdot
.64588 .76063 Mdot
.55457 .2227 Mdot
.46277 .30378 Mdot
.59136 .28834 Mdot
.24274 .22032 Mdot
.17915 .68151 Mdot
.34658 .49921 Mdot
.47199 .20439 Mdot
.56472 .21869 Mdot
.45375 .81993 Mdot
.69787 .64646 Mdot
.63171 .68182 Mdot
.68341 .25957 Mdot
.63092 .26674 Mdot
.59222 .36974 Mdot
.20497 .40584 Mdot
.26875 .74048 Mdot
.80654 .51617 Mdot
.36069 .79648 Mdot
.60627 .39887 Mdot
.57049 .43066 Mdot
.20301 .28673 Mdot
.22371 .66335 Mdot
.47441 .39819 Mdot
.7349 .29084 Mdot
.36865 .42536 Mdot
.54827 .37067 Mdot
.47107 .78146 Mdot
.46854 .18608 Mdot
.65544 .40897 Mdot
.43282 .81527 Mdot
.38387 .48216 Mdot
.5082 .62098 Mdot
.45377 .61564 Mdot
.50447 .56684 Mdot
.56364 .41994 Mdot
.40808 .61733 Mdot
.45779 .31156 Mdot
.22556 .58161 Mdot
.37846 .62966 Mdot
.43815 .17365 Mdot
.14565 .56062 Mdot
.4052 .34443 Mdot
.44877 .66345 Mdot
.48932 .3004 Mdot
.28913 .30418 Mdot
.75533 .45334 Mdot
.37861 .52154 Mdot
.18496 .46358 Mdot
.36017 .85551 Mdot
.48386 .71163 Mdot
.70311 .45937 Mdot
.39232 .47641 Mdot
.62108 .41668 Mdot
.44124 .30057 Mdot
.41769 .56544 Mdot
.60013 .60543 Mdot
.50507 .30099 Mdot
.45429 .38863 Mdot
.39296 .64435 Mdot
.83775 .64518 Mdot
.48951 .34755 Mdot
.60589 .30995 Mdot
.19715 .67045 Mdot
.7813 .48658 Mdot
.33151 .37032 Mdot
.51811 .42531 Mdot
.35087 .65938 Mdot
.47839 .56809 Mdot
.21223 .60018 Mdot
.76411 .62462 Mdot
.39633 .80136 Mdot
.3882 .35164 Mdot
.47416 .27051 Mdot
.51634 .32731 Mdot
.6895 .47681 Mdot
.26984 .59231 Mdot
.43307 .78995 Mdot
.59664 .42392 Mdot
.21646 .69583 Mdot
.64224 .6102 Mdot
.53889 .75127 Mdot
.47538 .29256 Mdot
.5432 .83749 Mdot
.82251 .49296 Mdot
.4524 .26873 Mdot
.80138 .62118 Mdot
.65977 .71528 Mdot
.74521 .41436 Mdot
.61219 .61741 Mdot
.60611 .37422 Mdot
.38006 .48716 Mdot
.72469 .76467 Mdot
.43977 .79331 Mdot
.4324 .72655 Mdot
.51859 .71526 Mdot
.4209 .23381 Mdot
.26572 .54069 Mdot
.1428 .48433 Mdot
.67219 .67972 Mdot
.73765 .74889 Mdot
.36585 .21614 Mdot
.39331 .48813 Mdot
.25605 .6167 Mdot
.49064 .43561 Mdot
.57359 .62292 Mdot
.42673 .80522 Mdot
.45689 .36938 Mdot
.78456 .60909 Mdot
.52888 .42248 Mdot
.77045 .66746 Mdot
.59172 .55321 Mdot
.52622 .78609 Mdot
.40168 .71584 Mdot
.80552 .40701 Mdot
.18958 .53511 Mdot
.38258 .6667 Mdot
.15054 .43474 Mdot
.19861 .54882 Mdot
.25931 .71973 Mdot
.77873 .54644 Mdot
.82685 .41079 Mdot
.33983 .72917 Mdot
.26462 .66112 Mdot
.41274 .70609 Mdot
.43232 .43357 Mdot
.70439 .68937 Mdot
.47357 .2979 Mdot
.28381 .60204 Mdot
.39807 .66652 Mdot
.50503 .92421 Mdot
.67353 .55022 Mdot
.26877 .44225 Mdot
.6822 .69371 Mdot
.2983 .75515 Mdot
.45102 .43396 Mdot
.19209 .4349 Mdot
.5821 .49674 Mdot
.59074 .4126 Mdot
.39224 .32835 Mdot
.42085 .20196 Mdot
.71634 .68877 Mdot
.83433 .3643 Mdot
.24598 .31026 Mdot
.52444 .73041 Mdot
.52124 .53711 Mdot
.36531 .44058 Mdot
.26703 .47837 Mdot
.68777 .60697 Mdot
.18272 .41327 Mdot
.23151 .58806 Mdot
.21791 .65355 Mdot
.79519 .31827 Mdot
.29318 .27914 Mdot
.45871 .82435 Mdot
.34989 .70555 Mdot
.27282 .46902 Mdot
.73602 .52498 Mdot
.65261 .57357 Mdot
.42025 .72885 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`2Rooooo`;o0000YOooool001cooooo00?o0000oooo
ooooool0Moooool2o`0002Sooooo0ol0002Uooooo`007?ooool00ol0003oooooooooo`1gooooo`;o
00001_ooool2o`0000_ooooo0_l0000Cooooo`;o0000Y_ooool001cooooo00?o0000ooooooooool0
Ooooool2o`0000_ooooo0ol0002jooooo`007?ooool00ol0003oooooooooo`2=ooooo`;o00001ooo
ool2o`000;7ooooo000Looooo`03o`000?oooooooooo09Kooooo0_l0002aooooo`007?ooool00ol0
003oooooooooo`2Fooooo`;o0000/Oooool001cooooo00?o0000ooooooooool0U_ooool2o`000;7o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0001jooooo`;o00001_oo
ool2o`0000Cooooo0_l0000;ooooo`;o00003Oooool2o`0002Gooooo0_l0001mooooo`007?ooool0
0ol0003oooooooooo`1iooooo`;o00001_ooool2o`0000Cooooo0_l00009ooooo`Co00003Oooool2
o`0002Gooooo0_l0001mooooo`007?ooool00ol0003oooooooooo`2=ooooo`;o00000oooool2o`00
00Kooooo0_l0002]ooooo`007?ooool00ol0003oooooooooo`2=ooooo`;o00002oooool2o`0001Ko
oooo0_l0002Eooooo`007?ooool00ol0003oooooooooo`21ooooo`;o00009_ooool2o`0000Kooooo
0ol0002Eooooo`007?ooool00ol0003oooooooooo`21ooooo`;o00000_ooool2o`0001cooooo0_l0
0004ooooo`;o00001_ooool2o`0009Kooooo000Looooo`03o`000?oooooooooo08Gooooo0_l0000A
ooooo`;o00002Oooool2o`000:Cooooo000Looooo`03o`000?oooooooooo08Gooooo0_l00004oooo
o`;o00002oooool2o`00017ooooo0_l0000;ooooo`;o0000Soooool001cooooo00?o0000oooooooo
ool0K?ooool2o`0001Oooooo0_l00004ooooo`;o00002oooool2o`0000?ooooo0_l0000<ooooo`;o
00002oooool2o`0000Kooooo0_l0000;ooooo`;o0000N_ooool001cooooo00?o0000ooooooooool0
K?ooool2o`0000gooooo0_l0000Kooooo`Co000000Coooooo`000?l0003o00001Oooool2o`0001Wo
oooo0_l0000;ooooo`;o0000N_ooool001cooooo00?o0000ooooooooool0N?ooool2o`000003oooo
ool0003o000000cooooo0_l0000;ooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`Co0000
X_ooool001cooooo00?o0000ooooooooool0N?ooool2o`0000kooooo0ol00009ooooo`Oo00001ooo
ool3o`0000Cooooo0_l00003ooooo`;o0000VOooool001cooooo00?o0000ooooooooool0O_ooool2
o`0000Kooooo1?l0000:ooooo`;o000000?oooooo`000?l000000_l00007ooooo`;o00001Oooool2
o`0000?ooooo0_l00002ooooo`;o0000UOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Ooo
ool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo07[ooooo0_l00002ooooo`;o00001_oo
ool2o`0000oooooo0ol000000ooooooo0000o`000009ooooo`;o00000oooool2o`0000Gooooo0_l0
002Eooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Q
onk^k_ooooooA4A400Kooooo00?o0000ooooooooool0N_ooool2o`0001Sooooo0_l000000ooooooo
0000o`000002ooooo`;o00002Oooool2o`0000?ooooo0_l00008ooooo`;o00007?ooool2o`0007Co
oooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h0
1oooool00ol0003oooooooooo`22ooooo`;o00003oooool3o`0001oooooo0_l0000Looooo`;o0000
M?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^
kP06ooooo`?o0000M?ooool2o`0000Gooooo1?l00003ooooo`;o000000?oooooo`000?l000002?oo
ool2o`0000;ooooo0_l00006ooooo`;o00001Oooool2o`0000gooooo0_l0000/ooooo`;o0000J?oo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`05
ooooo`03o`000?oooooooooo06cooooo0_l00004ooooo`Co00001?ooool5o`0000Kooooo0_l00008
ooooo`;o00001Oooool2o`0000?ooooo0_l00005ooooo`;o000000?oooooo`000?l000002_ooool2
o`0000?ooooo0_l0000@ooooo`?o00005?ooool2o`0006Sooooo00000ooooooo410@ooooo`02oooo
o`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Loooo
o`;o00003_ooool2o`0000Cooooo1?l00004ooooo`;o000000Coooooo`000?l0003ooooo0ol0000<
ooooo`;o00001Oooool2o`0000Gooooo0ol00005ooooo`;o000000?oooooo`000?l000000_l00003
ooooo`Co00000oooool2o`0000[ooooo0_l00004ooooo`?o0000O_ooool00006oooooomgMgOoV9RH
oooooonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
G?ooool2o`0000cooooo0_l00008ooooo`;o00001oooool2o`000003ooooool0003o000000?o0000
6?ooool3o`0000Sooooo1?l00002ooooo`Oo00003Oooool2o`0000Kooooo1?l0001kooooo`0000Ko
ooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0
003oooooooooo`1Zooooo`;o00001_ooool4o`0000cooooo0ol0000<ooooo`;o00006oooool7o`00
00?ooooo0_l000000ooooooo0000o`000004ooooo`;o00001oooool4o`0007_ooooo000Looooo`03
o`000?oooooooooo07;ooooo1?l0000>ooooo`;o00002oooool2o`0001Kooooo0_l00006ooooo`;o
00001Oooool2o`000003ooooool0003o000000Cooooo0_l0000>ooooo`;o00002Oooool2o`0006_o
oooo000Looooo`03o`000?oooooooooo04_ooooo0_l0000Vooooo`?o00003_ooool2o`0000Cooooo
0ol000000ooooooo0000o`000002o`00017ooooo0_l00004ooooo`?o000000?oooooo`000?l00000
0oooool4o`0000Wooooo0_l0000@ooooo`;o00002Oooool2o`0006_ooooo000Looooo`03o`000?oo
oooooooo04_ooooo0_l0000Mooooo`?o00005_ooool2o`0000Gooooo2?l0000Aooooo`;o00001Ooo
ool2o`000004ooooool0003o0000ooooo`Ko00001Oooool6o`000003ooooool0003o000008Gooooo
000Looooo`03o`000?oooooooooo06[ooooo1?l0000Eooooo`;o000000?oooooo`000?l000001Ooo
ool2o`0000;ooooo0_l00007ooooo`;o00005?ooool2o`0000Sooooo1Ol00003ooooo`;o0000QOoo
ool001cooooo00?o0000ooooooooool0I_ooool2o`0000Cooooo0_l0000?ooooo`;o00001oooool2
o`0000?ooooo0_l00004ooooo`;o00001oooool2o`0000Wooooo0_l000000ooooooo0000o`00000@
ooooo`Co00004oooool2o`0000;ooooo0_l0000<ooooo`;o0000I?ooool001cooooo00?o0000oooo
ooooool0H?ooool2o`0000Cooooo0_l00002ooooo`;o00004Oooool2o`0000Kooooo0_l00004oooo
o`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000003ooooo`;o00002_ooool2
o`000003ooooool0003o000000Sooooo0_l00005ooooo`;o000000?oooooo`000?l000001_ooool2
o`0000_ooooo0_l00002ooooo`;o00003?ooool2o`0006Cooooo000Looooo`03o`000?oooooooooo
05;ooooo0_l0000<ooooo`;o00002?ooool2o`0001Wooooo0_l00007ooooo`;o000000Coooooo`00
0?l0003ooooo0_l00003ooooo`;o00000oooool2o`000003ooooool0003o000000gooooo1?l00005
ooooo`;o00002Oooool2o`0001[ooooo0_l0001Wooooo`007?ooool00ol0003oooooooooo`1Boooo
o`;o00003?ooool2o`0000Cooooo0_l000000ooooooo0000o`00000Wooooo`;o00002_ooool2o`00
0004ooooool0003o0000o`0000cooooo0_l0000Looooo`Co00003_ooool2o`0006Oooooo000Loooo
o`03o`000?oooooooooo05cooooo0_l00002ooooo`;o00001?ooool2o`000003ooooool0003o0000
017ooooo0_l0000Dooooo`?o00000_ooool2o`0000Wooooo0_l00007ooooo`;o00005Oooool2o`00
00[ooooo1?l0000Iooooo`;o0000G?ooool001cooooo00?o0000ooooooooool0G?ooool3o`0001;o
oooo0_l00009ooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00000_ooool3o`0000;o
oooo0_l0000Booooo`?o00002Oooool2o`000003ooooool0003o000000Kooooo1?l0000@ooooo`;o
000000?oooooo`000?l000004?ooool2o`0005cooooo000Looooo`03o`000?oooooooooo05gooooo
0_l0000Booooo`;o00003oooool4o`0000;ooooo0_l00004ooooo`;o00000_ooool2o`0000?ooooo
0_l0000Cooooo`;o00001oooool4o`000004ooooool0003o0000ooooo`;o00001Oooool2o`00013o
oooo0_l000000ooooooo0000o`000002ooooo`;o0000J_ooool001cooooo0_l00025ooooo`;o0000
0_ooool2o`0000;ooooo0_l00004ooooo`;o00001_ooool2o`00013ooooo0_l00007ooooo`;o0000
0oooool2o`000003ooooool0003o000000Sooooo0_l0000Dooooo`;o00002_ooool2o`0005kooooo
000Looooo`03o`000?oooooooooo05oooooo0_l000001?oooooo0000o`000?l00004ooooo`;o0000
6Oooool2o`0000Kooooo0_l00004ooooo`;o00001_ooool2o`00013ooooo0_l0000<ooooo`Ko0000
1oooool2o`0000;ooooo1?l0000;ooooo`;o00003Oooool3o`0005gooooo000Looooo`03o`000?oo
oooooooo05oooooo1_l00002ooooo`Co00006Oooool2o`0001Cooooo0ol0000?ooooo`;o00002?oo
ool2o`0000Cooooo1Ol00005ooooo`Wo00002_ooool3o`0000[ooooo0_l00002ooooo`;o0000GOoo
ool001cooooo00?o0000ooooooooool0B_ooool2o`0000kooooo0_l00004ooooo`;o00001Oooool2
o`0002_ooooo0_l00005ooooo`?o00004_ooool2o`0000Cooooo0_l000000ooooooo0000o`000002
ooooo`Co00001Oooool5o`0000kooooo0ol0000:ooooo`;o0000HOooool001cooooo00?o0000oooo
ooooool0B_ooool2o`0000cooooo1?l0000:ooooo`?o00006oooool2o`0000kooooo1?l00004oooo
o`;o00004_ooool2o`0000Oooooo0_l000000ooooooo0000o`00000Fooooo`;o00000oooool3o`00
06gooooo000Looooo`03o`000?oooooooooo05Sooooo0_l0000<ooooo`?o00006oooool2o`00013o
oooo0_l0000:ooooo`;o00002Oooool4o`0000Oooooo0_l00002ooooo`;o00001oooool2o`0000;o
oooo0_l00009ooooo`;o00002_ooool2o`0000;ooooo0_l0001Sooooo`007?ooool00ol0003ooooo
ooooo`1Dooooo`Ko00003?ooool4o`0001gooooo1?l00004ooooo`;o00001Oooool2o`0000[ooooo
0_l00002ooooo`;o00001Oooool4o`0000Oooooo0ol0000:ooooo`;o00000_ooool2o`0000Gooooo
0_l0000>ooooo`;o00000_ooool2o`0006?ooooo000Looooo`03o`000?oooooooooo05Cooooo1?l0
0006ooooo`;o00001Oooool2o`000003ooooool0003o000001gooooo1Ol00003ooooo`;o00001Ooo
ool2o`0000cooooo1?l00007ooooo`;o00000_ooool2o`0000Cooooo0ol0000Dooooo`;o0000Mooo
ool001cooooo00?o0000ooooooooool0EOooool4o`0000Cooooo0ol00003ooooo`Co00006_ooool2
o`0000Gooooo1?l0000@ooooo`;o00001_ooool2o`0000Oooooo0_l00004ooooo`;o00001Oooool3
o`0000Sooooo1?l0000Qooooo`;o0000GOooool001cooooo00?o0000ooooooooool0DOooool2o`00
00;ooooo1Ol00002ooooo`Co00000oooool3o`000003ooooool0003o000001Sooooo0_l00005oooo
o`;o00004_ooool2o`0000?ooooo0_l00005ooooo`;o000000?oooooo`000?l000000_l00003oooo
o`Co00001Oooool2o`0000Sooooo1?l00004ooooo`;o00006oooool2o`0000Cooooo1?l0001Eoooo
o`007?ooool00ol0003oooooooooo`1Aooooo`;o00001Oooool2o`0000;ooooo0_l00006ooooo`;o
000000?oooooo`000?l000005?ooool2o`000003ooooool0003o000000_ooooo0ol0000Aooooo`;o
00001?ooool3o`000003ooooool0003o000000;o00000_ooool7o`0000_ooooo0_l00002ooooo`?o
00000oooool4o`0001oooooo1?l0001Eooooo`007?ooool00ol0003oooooooooo`1mooooo`;o0000
00?oooooo`000?l000002oooool3o`0000Sooooo0_l0000=ooooo`?o00000oooool2o`0000;ooooo
0_l00003ooooo`;o000000?oooooo`000?l000002?ooool7o`0000Cooooo0ol00005ooooo`;o0000
LOooool001cooooo00?o0000ooooooooool0?_ooool2o`0001oooooo0_l0000Oooooo`;o00000_oo
ool2o`0001;ooooo0_l00005ooooo`;o00001oooool4o`0000[ooooo2?l00006ooooo`?o00000ooo
ool2o`0000[ooooo0_l0000@ooooo`;o000000?oooooo`000?l00000G?ooool001cooooo00?o0000
ooooooooool0?_ooool2o`0001gooooo1?l0000Qooooo`Co00000oooool2o`0000Gooooo0_l00003
ooooo`;o000000?oooooo`000?l000001Oooool2o`000003ooooool0003o000000Kooooo0_l00000
0ooooooo0000o`000002ooooo`;o00000oooool3o`0000;ooooo0ol00006ooooo`;o00001?ooool2
o`0000?ooooo0_l00002ooooo`;o00004oooool5o`0005cooooo000Looooo`03o`000?oooooooooo
04Wooooo0_l0000Booooo`;o00001_ooool2o`0001_ooooo0_l00005ooooo`;o00001Oooool2o`00
00?ooooo1?l00009ooooo`;o00002Oooool2o`0000;ooooo0_l0000?ooooo`;o00000oooool4o`00
00Cooooo0_l00002ooooo`;o00004oooool5o`0005cooooo000Looooo`03o`000?oooooooooo04Wo
oooo0_l0000@ooooo`;o00002?ooool2o`0001kooooo0_l00003ooooo`;o00002_ooool3o`0000Go
oooo0_l00007ooooo`;o000000?oooooo`000?l000000_l0000<ooooo`;o00001_ooool2o`0000;o
oooo1Ol00007ooooo`?o00001Oooool2o`000003ooooool0003o000000Wooooo1Ol00005ooooo`;o
0000EOooool001cooooo0_l0001Dooooo`;o00001_ooool4o`0000Gooooo0_l0000Oooooo`;o0000
0oooool4o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000003ooooo`Wo0000
0oooool7o`0000cooooo0_l00004ooooo`;o00001?ooool2o`000003ooooool0003o000000Oooooo
0ol00005ooooo`;o000000?oooooo`000?l000002oooool2o`0000Kooooo0_l0001Eooooo`007?oo
ool00ol0003oooooooooo`1Cooooo`;o00001Oooool2o`000004ooooool0003o0000o`0000Cooooo
0_l0000Dooooo`;o00004?ooool2o`000003ooooool0003o000000Co00000oooool7o`000003oooo
ool0003o000000Ko000000?oooooo`000?l000000ol00006ooooo`;o00001_ooool2o`0000;ooooo
0_l00006ooooo`?o00002?ooool2o`0000Oooooo0_l000000ooooooo0000o`00001Xooooo`007?oo
ool00ol0003oooooooooo`1<ooooo`;o00003?ooool2o`0000;ooooo0_l0000Jooooo`;o00004?oo
ool2o`0000?ooooo1?l00003ooooo`Co000000Coooooo`000?l0003ooooo0ol000000ooooooo0000
o`000005o`000003ooooool0003o000000Wo000000?oooooo`000?l000001?l0000:ooooo`;o0000
00?oooooo`000?l000002?ooool2o`0000Gooooo1Ol0001Xooooo`007?ooool00ol0003ooooooooo
o`1<ooooo`;o0000;oooool2o`0000Oooooo0_l00004ooooo`;o00000oooool2o`0000Cooooo0_l0
0006ooooo`Co00000oooool5o`0000;ooooo2_l000000ooooooo0000o`000003o`0000Cooooo0_l0
0008ooooo`;o00002?ooool2o`0000Kooooo0_l00009ooooo`;o00002_ooool2o`0005?ooooo000L
ooooo`03o`000?oooooooooo04cooooo0_l0000=ooooo`;o00001Oooool2o`0001Wooooo0_l00007
ooooo`;o00002Oooool2o`0000Cooooo0_l00002ooooo`[o000000?oooooo`000?l000000ol00003
ooooo`;o000000Goooooo`000?l0003o0000ooooo`04o`000003ooooool0003o000000;o00000_oo
ool3o`0000kooooo0_l0000?ooooo`;o00001?ooool2o`0000[ooooo0_l0001Cooooo`007?ooool0
0ol0003oooooooooo`1Booooo`;o00001oooool2o`0000Gooooo0_l0000Dooooo`;o00001?ooool2
o`00017ooooo0_l00006oooooa;o000000?oooooo`000?l000000_l000001Ooooooo0000o`000?l0
003ooooo00Wo00000_ooool2o`0000;ooooo0_l00006ooooo`;o000000?oooooo`000?l000000_l0
000;ooooo`;o00000_ooool2o`0000Wooooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`1:
ooooo`;o00001_ooool3o`0002?ooooo0_l000000ooooooo0000o`000003o`0001Oooooo1?l00002
ooooo`go00000_ooool2o`000003ooooool0003o000000?o00000_ooool6o`0000Sooooo0ol00005
ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`Co000000Coooooo`000?l0003ooooo
0_l0000=ooooo`;o00001Oooool2o`0000Sooooo0_l00019ooooo`007?ooool00ol0003ooooooooo
o`17ooooo`;o000000?oooooo`000?l000001_ooool3o`0000Kooooo0_l00007ooooo`;o00004ooo
ool6o`0000;ooooo0_l0000@ooooo`;o00000_ooool4o`0000;ooooo1?l000000ooooooo0000o`00
0002o`000003ooooool0003o000000Go000000Coooooo`000?l0003ooooo0_l0000<ooooo`;o0000
0oooool2o`0000Oooooo0_l000001?oooooo0000o`000?l00002ooooo`Co000000?oooooo`000?l0
00000_ooool2o`0001?ooooo0_l00008ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0
@oooool3o`000003ooooool0003o000000Wooooo0ol00006ooooo`;o00001oooool2o`0001?ooooo
0_l00006ooooo`Ko00003?ooool2o`0000?ooooo0ol000000ooooooo0000o`00000Ho`0000?ooooo
0_l00005ooooo`;o00003?ooool2o`000003ooooool0003o000000Go00001oooool2o`0001;ooooo
0_l0001Dooooo`007?ooool00ol0003oooooooooo`13ooooo`?o00002?ooool2o`0000?ooooo0_l0
0006ooooo`;o00007oooool2o`0000?ooooo1_l0000<ooooo`;o00000oooool3o`000003ooooool0
003o000001[o000000?oooooo`000?l000000_l000000ooooooo0000o`00000;ooooo`;o00001_oo
ool4o`0000Sooooo0_l0000Booooo`?o00002oooool2o`0004Kooooo000Looooo`03o`000?oooooo
oooo04?ooooo0_l00004ooooo`;o00000oooool2o`00017ooooo0_l0000Iooooo`;o00000oooool2
o`0000kooooo1?l00003ooooo`?o000000?oooooo`000?l000006_l000000ooooooo0000o`000002
o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000004ooooo`;o00005?ooool2
o`00013ooooo1Ol00009ooooo`?o0000AOooool001cooooo00?o0000ooooooooool0>oooool2o`00
00Kooooo0_l00004ooooo`;o00000_ooool2o`0000Cooooo0_l00007ooooo`;o00000oooool2o`00
02Cooooo0_l00008ooooo`;o00002OoooolLo`000004ooooool0003o0000ooooo`?o000000?ooooo
o`000?l000000_l000001?oooooo0000o`000?ooool2o`0001Oooooo0_l0000@ooooo`;o000000Co
ooooo`000?l0003ooooo0_l00007ooooo`;o0000AOooool001cooooo00?o0000ooooooooool0>ooo
ool2o`0000?ooooo0_l0000;ooooo`;o00001?ooool2o`000003ooooool0003o000000Cooooo0_l0
0006ooooo`;o00008Oooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000Gooooo
8?l00003ooooo`Co000000?oooooo`000?l000001_ooool2o`0001Gooooo0_l00003ooooo`;o0000
4oooool2o`0004kooooo000Looooo`03o`000?oooooooooo043ooooo0_l0000;ooooo`;o00001ooo
ool2o`0000cooooo0_l0000Tooooo`;o000000?oooooo`000?l000000_ooool2o`000005ooooool0
003o0000o`000?ooool08?l00002ooooo`Co000000?oooooo`000?l000004oooool2o`0000Wooooo
0_l00003ooooo`;o00005Oooool2o`0004cooooo000Looooo`03o`000?oooooooooo04_ooooo1?l0
000Aooooo`;o00000_ooool2o`0001[ooooo0_l0000BooooobCo00000_ooool2o`000003ooooool0
003o000000Go00002_ooool2o`0000Cooooo0_l000000ooooooo0000o`00000;ooooo`;o00005Ooo
ool2o`0004cooooo000Looooo`03o`000?oooooooooo04_ooooo0_l0000Cooooo`Co00000oooool2
o`0000cooooo0_l00009ooooo`;o00004?ooool@o`000003ooooool0003o000001Co000000?ooooo
o`000?l000000ol000000ooooooo0000o`000002o`0000Wooooo0ol00007ooooo`Co00001?ooool2
o`0000;ooooo0_l0001Tooooo`007?ooool2o`0003[ooooo1?l0000@ooooo`?o00000_ooool2o`00
00kooooo0_l00003ooooo`;o00003?ooool2o`0000?ooooo0_l00008ooooo`;o00003?ooool4o`00
00;ooooo2Ol00002ooooo`Go000000?oooooo`000?l000003_l000000ooooooo0000o`000002o`00
00Sooooo0_l00005ooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00000_ooool2o`00
06Cooooo000Looooo`03o`000?oooooooooo03Wooooo1?l00004ooooo`;o00001oooool2o`000004
ooooool0003o0000o`0000;ooooo0_l0000=ooooo`;o000000?oooooo`000?l000000_l0000Aoooo
o`Co00001oooool2o`0001?ooooo8?l00003ooooo`;o00000_ooool2o`0000Cooooo0ol00006oooo
o`;o00000_ooool2o`0000_ooooo0_l00002ooooo`;o0000Hoooool001cooooo00?o0000oooooooo
ool0@?ooool3o`0000Oooooo0_l00003ooooo`;o00001Oooool2o`0000Wooooo0_l000000ooooooo
0000o`000002o`00017ooooo1_l0000Fooooo`;o00000_oooolUo`0000;ooooo0_l00005ooooo`;o
00001_ooool2o`0000Gooooo0_l00008ooooo`Ko00004oooool2o`0004kooooo000Looooo`03o`00
0?oooooooooo03_ooooo0_l00003ooooo`;o00003Oooool2o`0000Gooooo0_l0000;ooooo`;o0000
6?ooool2o`0001Kooooo0_l000000ooooooo0000o`00000Ro`0000?ooooo0_l0000Cooooo`Ko0000
2?ooool2o`000003ooooool0003o000000;o00004?ooool3o`0004gooooo000Looooo`03o`000?oo
oooooooo03_ooooo0_l000001?oooooo0000o`000?l00006ooooo`;o00002oooool2o`0000gooooo
0_l00005ooooo`;o00003oooool2o`0000Oooooo0_l0000=ooooo`?o000000?oooooo`000?l00000
5?l000000ooooooo0000o`00000=o`0000;ooooo0_l00003ooooo`Co00002oooool4o`000004oooo
ool0003o0000ooooo`;o00002?ooool4o`0000kooooo0_l000000ooooooo0000o`00001=ooooo`00
7?ooool00ol0003oooooooooo`0hooooo`;o00001?ooool3o`0000Gooooo0ol00002ooooo`;o0000
1oooool2o`0001Cooooo0_l00009ooooo`;o00001?ooool2o`0000Oooooo0_l00008ooooo`;o0000
0ooooolZo`0000;ooooo0ol00002ooooo`Co00002oooool4o`0000Cooooo0_l00004ooooo`;o0000
5?ooool2o`0000oooooo0_l000000ooooooo0000o`00000looooo`007?ooool00ol0003ooooooooo
o`0hooooo`;o00003?ooool3o`0000;ooooo0_l0000Xooooo`;o000000?oooooo`000?l000005?oo
ool2o`000003ooooool0003o000002Wo00000oooool3o`0000Gooooo0_l0000Eooooo`;o000000?o
ooooo`000?l000001?ooool2o`0000;ooooo0_l0000?ooooo`;o00002_ooool2o`000003ooooool0
003o000003cooooo000Looooo`03o`000?oooooooooo04Gooooo1?l0000Oooooo`;o00003_ooool2
o`0001Oooooo9?l000000ooooooo0000o`000004o`000003ooooool0003o000000;o00000oooool2
o`000003ooooool0003o000000Kooooo0ol0000<ooooo`;o00001oooool2o`0000;ooooo0_l0000;
ooooo`;o00000_ooool2o`0004_ooooo000Looooo`03o`000?oooooooooo037ooooo0_l0000<oooo
o`;o00001?ooool2o`0000cooooo0_l0000Cooooo`;o00001?ooool2o`0000;ooooo0_l0000?oooo
o`;o00001Oooool3o`0000?ooooo0_l00005ooooob7o000000?oooooo`000?l000002ol000000ooo
oooo0000o`000004ooooo`Go00000oooool4o`0000Gooooo0_l0000Hooooo`;o00000oooool2o`00
04[ooooo000Looooo`03o`000?oooooooooo037ooooo0_l0000<ooooo`;o00002oooool3o`0000Co
oooo0_l00003ooooo`;o00002?ooool2o`0000[ooooo0_l00002ooooo`;o00003Oooool4o`0000Go
oooo0ol00003ooooo`;o00001Ooooolco`0000?ooooo0ol00005ooooo`Co00001Oooool2o`0000Wo
oooo0_l0000?ooooo`;o000000?oooooo`000?l00000B_ooool001cooooo00?o0000ooooooooool0
?_ooool2o`0000;ooooo0_l00008ooooo`?o00001?ooool2o`0000?ooooo0_l00005ooooo`;o0000
00Coooooo`000?l0003o00003_ooool2o`0000cooooo0ol000001?oooooo0000o`000?ooool2o`00
00Gooooo1?l000001Ooooooo0000o`000?l0003ooooo01Go000000?oooooo`000?l000004?l00006
ooooo`Co00001?ooool2o`000003ooooool0003o0000013ooooo0_l00002ooooo`Ko00003Oooool2
o`0000Oooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00000_ooool2o`00
00?ooooo0_l0000:ooooo`;o00002_ooool2o`0000;ooooo0_l0000>ooooo`;o00002oooool4o`00
0003ooooool0003o000000?o00001Oooool;o`000003ooooool0003o000002Co00000_ooool2o`00
00cooooo0_l0000:ooooo`;o00001?ooool2o`0000;ooooo0_l00002ooooo`;o00002oooool3o`00
00Sooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00000_ooool2o`000003
ooooool0003o000000;o0000:Oooool4o`0000Kooooo0_l00002ooooo`;o00001Oooool2o`0000Go
oooo0_l00002ooooo`;o000000?oooooo`000?l00000:_l000001?oooooo0000o`000?l0000Hoooo
o`;o00006Oooool3o`0000;ooooo0ol00002ooooo`;o0000AOooool001cooooo00?o0000oooooooo
ool0@_ooool2o`000003ooooool0003o000000;ooooo0_l0000Wooooo`Co00001_ooool2o`0000Go
oooo1?l00004ooooo`Oo000000?oooooo`000?l000001OoooolOo`000003ooooool0003o000000Co
00000_ooool2o`0000cooooo0_l0000[ooooo`?o00000_ooool2o`0004Gooooo00001_ooooook^k^
oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0
003oooooooooo`19ooooo`;o00004Oooool2o`0002;ooooo0_l000000ooooooo0000o`000002o`00
00Cooooo1ol000000ooooooo0000o`000006oooooako000000?oooooo`000?l000000_ooool2o`00
0003ooooool0003o000000gooooo1?l0000:ooooo`;o00001?ooool2o`0001Oooooo0_l000000ooo
oooo0000o`000017ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Gooooo0_l00002ooooo`;o00000oooool2
o`0000Gooooo0ol00004ooooo`;o000000?oooooo`000?l000000_ooool2o`0001Sooooo0_l00000
0ooooooo0000o`000002ooooo`;o00002Oooool3o`0000Oooooo4_l000000ooooooo0000o`00000>
o`000003ooooool0003o000000;ooooo0_l0000?ooooo`;o00000oooool3o`0000Cooooo0_l00004
ooooo`;o00000oooool2o`0001;ooooo0_l000000ooooooo0000o`00000=ooooo`;o0000>?ooool0
0003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo00?o0000oooo
ooooool0AOooool2o`0000;ooooo0_l00003ooooo`;o00000oooool7o`0000Gooooo0_l000001?oo
oooo0000o`000?l00002ooooo`;o00002_ooool2o`0000Sooooo0_l00005ooooo`;o00002_ooool2
o`0000Cooooo0_l000000ooooooo0000o`00000Po`0000;ooooo0_l00002ooooo`?o00002Oooool2
o`0000;ooooo0_l00002ooooo`Go00001?ooool2o`0000Wooooo0_l00002ooooo`?o00007oooool2
o`0003Sooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgM
gOoooooo00001oooool3o`0004kooooo0_l00003ooooo`;o00000oooool2o`0000Sooooo0_l00003
ooooo`;o00001Oooool2o`0000?ooooo0_l00006ooooo`;o00004?ooool2o`0000Oooooo9Ol00004
ooooo`Go00001oooool4o`0000;ooooo0_l00002ooooo`Co00001Oooool2o`0000Cooooo0_l00007
ooooo`?o00004Oooool3o`0004Gooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`0dooooo`;o00002Oooool2
o`0000;ooooo0_l00009ooooo`;o00003?ooool6o`0000cooooo0_l0000;ooooo`Co000000?ooooo
o`000?l000002oooool2o`0000Sooooo5?l000000ooooooo0000o`00000<o`0000Gooooo0_l0000:
ooooo`Co000000?oooooo`000?l000000_l00003ooooo`;o00000oooool2o`0000Kooooo1?l00007
ooooo`;o00002?ooool2o`0000?ooooo1_l00015ooooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0=?ooool3o`00
00Sooooo0_l00002ooooo`;o00001?ooool2o`0000Cooooo0_l0000;ooooo`Ko00006oooool2o`00
0003ooooool0003o000001Oooooo7ol000000ooooooo0000o`000004ooooo`?o00001_ooool2o`00
0003ooooool0003o000000;o000000?oooooo`000?l000000_l00002ooooo`;o00001?ooool2o`00
00Kooooo1?l00007ooooo`;o00002?ooool2o`0000?ooooo1_l00015ooooo`0000KoooooogMgMonH
V9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0=Oooool2
o`00013ooooo1?l00004ooooo`;o00001oooool2o`0000Gooooo0_l00006ooooo`Co00005?ooool2
o`0000Cooooo0_l0000?ooooo`?o000000?oooooo`000?l000005_l000000ooooooo0000o`000006
o`0000?ooooo1?l000000ooooooo0000o`000003ooooo`;o00000oooool2o`0000;ooooo0ol00002
ooooo`;o000000?oooooo`000?l000001Ol00005ooooo`;o00006oooool2o`0000Gooooo0_l0000n
ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o
0000ooooooooool0>?ooool2o`0000Cooooo0_l00005ooooo`Co00003Oooool4o`0000Gooooo0_l0
00000ooooooo0000o`000003ooooo`Co00000_ooool2o`0000Cooooo0_l0000:ooooo`?o00000ooo
ool2o`0000Wooooo0_l00003ooooo`Co00000_oooolGo`000005ooooool0003o0000o`000?ooool0
1?l000000ooooooo0000o`000002o`0000?ooooo0_l0000Dooooo`Wo00000_ooool3o`000003oooo
ool0003o000000Cooooo0ol00002ooooo`;o00004_ooool4o`0003kooooo000Looooo`03o`000?oo
oooooooo03Sooooo1?l00002ooooo`;o00001Oooool2o`0000oooooo0_l0000:ooooo`;o00001Ooo
ool3o`000003ooooool0003o000000Cooooo0_l00007ooooo`;o00000_ooool4o`0000cooooo0ol0
0002ooooo`;o00001?oooolFo`0000?ooooo1_l000001?oooooo0000o`000?l00008ooooo`;o0000
2Oooool2o`0000?ooooo0_l00005ooooo`Go00000_ooool2o`0000;ooooo0_l00004ooooo`Co0000
00?oooooo`000?l000000oooool2o`0000Sooooo0_l00003ooooo`;o0000@?ooool001cooooo00?o
0000ooooooooool0<oooool2o`0000Cooooo0ol00002ooooo`;o0000:_ooool2o`000003ooooool0
003o000000Wooooo0_l00002ooooo`;o00001?ooool2o`0000gooooo0_l00002ooooo`Ko00000_oo
ool=o`000003ooooool0003o0000017o00002?ooool2o`0000Cooooo0_l000000ooooooo0000o`00
0002o`0000?ooooo0_l00008ooooo`;o00000oooool2o`0000Sooooo0ol000000ooooooo0000o`00
0003ooooo`;o00000_ooool2o`0000Cooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`0c
ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo0_l00006ooooo`;o00006Oooool4
o`0000?ooooo0_l00003ooooo`;o00002Oooool4o`0001Kooooo0_l000000ooooooo0000o`000004
o`0000Cooooo0ol000000ooooooo0000o`00000Co`000003ooooool0003o000000Go00002Oooool5
o`000003ooooool0003o000000Gooooo0_l00008ooooo`;o00000oooool2o`000003ooooool0003o
000000Gooooo0_l00002ooooo`Co00001Oooool2o`0000[ooooo0_l0000oooooo`007?ooool00ol0
003oooooooooo`0gooooo`;o00003Oooool2o`0001Kooooo0_l000000ooooooo0000o`000002o`00
00?ooooo0_l00002ooooo`Co00001?ooool4o`0000;ooooo0_l0000Fooooo`;o000000Coooooo`00
0?l0003ooooo0ol00003ooooo`;o00000oooool8o`000004ooooool0003o0000o`0000Kooooo0ol0
0002ooooo`Ko00000oooool2o`0000Cooooo1?l00002ooooo`;o00001oooool2o`000003ooooool0
003o000000;ooooo1?l00005ooooo`?o00001Oooool2o`0000?ooooo0_l0000Aooooo`;o00003?oo
ool2o`00037ooooo000Looooo`03o`000?oooooooooo03Oooooo0_l0000Aooooo`?o00001Oooool2
o`0000Gooooo0_l00003ooooo`Go000000?oooooo`000?l000002_l00004ooooo`Co00006oooool6
o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000008o`000003ooooool0003o
000000[o00002oooool2o`0000Cooooo0_l0000=ooooo`;o000000?oooooo`000?l000000_ooool4
o`0000Gooooo0ol00005ooooo`;o00001_ooool5o`0001Wooooo0_l00004ooooo`;o0000:oooool0
01cooooo00?o0000ooooooooool0:_ooool2o`0001kooooo0ol00005ooooo`;o00001Oooool2o`00
00?ooooo5?l000001Ooooooo0000o`000?l0003ooooo00;o00004?ooool2o`0000Cooooo0_l00002
ooooo`;o00000_ooool2o`000004ooooool0003o0000o`0000;ooooo2_l000000ooooooo0000o`00
000>o`0001gooooo0_l00002ooooo`;o00000_ooool2o`0001Oooooo1Ol0000Oooooo`;o0000:ooo
ool001cooooo00?o0000ooooooooool0:_ooool2o`000003ooooool0003o000000Sooooo0_l00002
ooooo`;o000000?oooooo`000?l000004?ooool2o`0000Wooooo0_l000000ooooooo0000o`00000F
o`000003ooooool0003o000000[ooooo0ol00003ooooo`;o00000_ooool4o`0000Gooooo0_l00002
ooooo`Co000000?oooooo`000?l000001?ooool2o`0000?ooooo4?l0000Looooo`?o00000_ooool2
o`0000;ooooo0_l00005ooooo`;o00003?ooool2o`0005?ooooo000Looooo`03o`000?oooooooooo
02gooooo0_l00008ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo0_l0000;oooo
o`?o00001Oooool2o`0000;ooooo5?l000000ooooooo0000o`000003o`000003ooooool0003o0000
00Kooooo0_l00003ooooo`?o00001_ooool3o`0000Oooooo0_l00003ooooo`Go00000oooool4o`00
00;ooooo2ol000000ooooooo0000o`000003ooooo`;o00006_ooool2o`0000Wooooo0_l00003oooo
o`;o00002Oooool2o`000003ooooool0003o000000Oooooo0_l0001:ooooo`007?ooool00ol0003o
ooooooooo`12ooooo`;o00001?ooool2o`0000Gooooo0_l00003ooooo`;o000000?oooooo`000?l0
00000ooooolIo`000003ooooool0003o000000;o00001?ooool2o`0000cooooo0_l00006ooooo`;o
00002?ooool2o`0000?ooooo1?l00002ooooo`Ko000000?oooooo`000?l000001?l00004ooooo`;o
00001_ooool2o`000003ooooool0003o000000?ooooo0_l00005ooooo`;o00002Oooool2o`0000?o
oooo0_l00002ooooo`;o00002_ooool3o`0000Wooooo1?l00005ooooo`;o0000@Oooool001cooooo
00?o0000ooooooooool0??ooool2o`0000Sooooo1?l00005ooooo`;o00000_ooool4o`0000Oooooo
6?l000001Ooooooo0000o`000?l0003ooooo00;o00003Oooool5o`0000Gooooo0_l0000>ooooo`?o
00000_ooool2o`0000Gooooo0_l00002ooooo`Co00000_ooool4o`0000?ooooo0ol000000ooooooo
0000o`000003ooooo`Co00000oooool2o`0000Oooooo2?l00003ooooo`;o00002_ooool3o`0000Wo
oooo1?l00005ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0>?ooool8o`0000;ooooo
0_l000001?oooooo0000o`000?l00007ooooo`;o000000?oooooo`000?l000000ol00003ooooo`;o
000000?oooooo`000?l000006_l00002ooooo`;o00003?ooool6o`00013ooooo0_l00004ooooo`;o
00000_ooool2o`0000?ooooo0_l00005ooooo`?o00001?ooool2o`0000?ooooo0_l00004ooooo`;o
00000oooool2o`000003ooooool0003o000000Wooooo0ol000000ooooooo0000o`000002o`0000Co
oooo0_l00003ooooo`Co00000_ooool2o`0000[ooooo0_l00004ooooo`Co00000oooool2o`0000_o
oooo0_l0000`ooooo`007?ooool2o`0003Wooooo1?l00002ooooo`;o00000_ooool2o`000003oooo
ool0003o000000;ooooo0ol00006ooooo`;o00001?ooool4o`000003ooooool0003o000001_o0000
00?oooooo`000?l000001Oooool4o`0000?ooooo0_l0000Dooooo`;o00001?ooool3o`000004oooo
ool0003o0000ooooo`Ko00000oooool2o`0000?ooooo0_l00004ooooo`;o00001Oooool2o`0000Ko
oooo0_l0000Aooooo`;o00000_ooool2o`0000?ooooo1?l0000Dooooo`Co00000oooool2o`0000_o
oooo0_l0000`ooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00003_ooool3o`0000Wooooo
0_l000000ooooooo0000o`00000Po`000003ooooool0003o000000Gooooo1?l00007ooooo`;o0000
5oooool4o`0000;ooooo0_l00002ooooo`;o00002?ooool2o`0000Cooooo0_l0000Pooooo`;o0000
1oooool3o`0000Cooooo0_l00005ooooo`?o00002?ooool4o`00047ooooo000Looooo`03o`000?oo
oooooooo03Oooooo0_l0000Dooooo`;o00000_ooool3o`000003ooooool0003o000002Co00001Ooo
ool2o`0000[ooooo0ol000000ooooooo0000o`00000Fooooo`;o00005_ooool2o`0001[ooooo0_l0
0005ooooo`;o00003Oooool2o`0000Gooooo0ol00002ooooo`;o00001Oooool3o`00047ooooo000L
ooooo`03o`000?oooooooooo03Oooooo0_l00002ooooo`;o00004?ooool2o`0000;ooooo0ol00000
0ooooooo0000o`000002o`000003ooooool0003o000000go000000?oooooo`000?l000003ol00005
ooooo`;o00002_ooool2o`0000;ooooo0_l0000^ooooo`;o00006_ooool2o`0000?ooooo1?l00008
ooooo`;o00003oooool2o`0000Kooooo0_l00003ooooo`;o0000??ooool001cooooo00?o0000oooo
ooooool0>?ooool2o`000003ooooool0003o000001Kooooo5ol000000ooooooo0000o`00000>o`00
02Wooooo0_l00002ooooo`;o00001?ooool2o`0000?ooooo1?l00002ooooo`;o00008oooool2o`00
0003ooooool0003o000000;o00002?ooool2o`0001Oooooo0_l00003ooooo`;o0000??ooool001co
oooo00?o0000ooooooooool0>?ooool2o`000003ooooool0003o000000Kooooo1?l0000<ooooo`Co
000000Coooooo`000?l0003o00000_oooolPo`0001Sooooo0_l00002ooooo`;o00002Oooool2o`00
00;ooooo0_l00004ooooo`;o00000oooool4o`0000;ooooo0_l0000Oooooo`;o00000_ooool2o`00
0003ooooool0003o000000;o00001_ooool2o`00023ooooo0_l0000jooooo`007?ooool00ol0003o
ooooooooo`0kooooo`;o00001_ooool4o`0000;ooooo0_l00003ooooo`?o00001?oooolJo`000003
ooooool0003o000000_o00001oooool3o`0000cooooo1?l00002ooooo`;o00002Oooool2o`0000;o
oooo0_l0000?ooooo`;o00003oooool2o`0000Kooooo0_l00006ooooo`;o00000_ooool2o`000003
ooooool0003o000000Sooooo0_l0000<ooooo`;o00001?ooool2o`0000Cooooo0_l00006ooooo`;o
00002?ooool2o`00033ooooo000Looooo`03o`000?oooooooooo03cooooo0_l0000;ooooo`;o0000
0oooool3o`0000Cooooo9ol00008ooooo`?o00003?ooool5o`0000Gooooo0_l0000Zooooo`?o0000
1?ooool4o`0000cooooo1?l00009ooooo`;o00000oooool2o`0000;ooooo0_l000000ooooooo0000
o`000002ooooo`Co00001?ooool5o`0000gooooo0_l0000`ooooo`007?ooool00ol0003ooooooooo
o`0^ooooo`;o00003?ooool2o`00017ooooo0_l00004ooooo`?o00000_oooolMo`000003ooooool0
003o000000Co00002_ooool2o`0000[ooooo1?l00005ooooo`;o0000:_ooool2o`0000Gooooo0ol0
0002ooooo`?o00001?ooool2o`0000;ooooo1?l00009ooooo`;o00000oooool2o`0000;ooooo0_l0
00000ooooooo0000o`000002ooooo`;o00001oooool4o`0000Gooooo0_l0000hooooo`007?ooool0
0ol0003oooooooooo`0^ooooo`;o00000oooool2o`0000Gooooo0_l0000=ooooo`;o00001?ooool2
o`0000;ooooo1Ol00002oooooago00000_ooool5o`0000?ooooo0_l00005ooooo`;o0000Aoooool2
o`000003ooooool0003o000000?o00000_ooool9o`0000Gooooo0_l000000ooooooo0000o`000004
ooooo`;o000000?oooooo`000?l000000_ooool3o`0001?ooooo0_l0000hooooo`007?ooool00ol0
003oooooooooo`0cooooo`;o00000_ooool2o`000003ooooool0003o000000Wooooo0_l00002oooo
o`;o00002?ooool2o`000004ooooool0003o0000o`0000;ooooo8_l00004ooooo`;o000000?ooooo
o`000?l000000_ooool2o`0000Gooooo0_l00008ooooo`;o000000?oooooo`000?l000007oooool2
o`0000Kooooo0_l00006ooooo`;o00001Oooool<o`000003ooooool0003o000000?o00000_ooool6
o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`;o00001?ooool2o`0000Kooooo0_l0000o
ooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o00001_ooool2o`0000;ooooo0ol0000;oooo
o`;o00000_ooool4o`0000Kooooo0_l00002ooooo`;o00000ooooolQo`0000Cooooo0_l000000ooo
oooo0000o`000003ooooo`;o00001?ooool2o`0000Cooooo0_l00002ooooo`Go00006?ooool2o`00
0003ooooool0003o000000;ooooo0_l00006ooooo`;o00000_ooool2o`0000;ooooo0_l00005oooo
oa;o00000_ooool5o`0000gooooo0_l00004ooooo`;o00001_ooool3o`0000?ooooo0_l00006oooo
o`;o0000<Oooool001cooooo00?o0000ooooooooool0:oooool2o`0000[ooooo1Ol0000?ooooo`Co
00001?ooool2o`0000Sooooo6_l000001Ooooooo0000o`000?l0003ooooo00Co00002Oooool2o`00
00[ooooo0_l00004ooooo`;o00001Oooool2o`0001;ooooo0_l000000ooooooo0000o`00000:oooo
o`;o00000_ooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`00000=o`00
00Wooooo0_l0000=ooooo`;o00001?ooool2o`0000Oooooo1?l000000ooooooo0000o`000006oooo
o`;o0000<Oooool001cooooo00?o0000ooooooooool0;_ooool2o`0000Oooooo1Ol0000Aooooo`;o
00000_ooool5o`0000Cooooo7Ol000000ooooooo0000o`000006o`0001[ooooo0_l000000ooooooo
0000o`000003ooooo`;o00002?ooool2o`0000oooooo0_l00003ooooo`;o000000?oooooo`000?l0
00001OoooolFo`000003ooooool0003o000000;o000000?oooooo`000?l000000_l0000>ooooo`;o
000000Coooooo`000?l0003ooooo0_l00009ooooo`;o0000??ooool001cooooo00?o0000oooooooo
ool0;_ooool2o`0000gooooo0_l0000>ooooo`;o00000_ooool5o`0000?ooooo1?l000000ooooooo
0000o`00000Fo`0000;ooooo1?l0000Looooo`Oo00001_ooool2o`0000Gooooo0_l0000;ooooo`;o
00000_ooool2o`0000?ooooo0_l0000:oooooaWo000000?oooooo`000?l000000_l0000Aooooo`;o
00002?ooool2o`00043ooooo000Looooo`03o`000?oooooooooo033ooooo0_l00004ooooo`?o0000
00Coooooo`000?l0003ooooo0_l0000>ooooo`;o00000oooool2o`0000?ooooo1ol00002oooooaCo
00001?ooool2o`0001Cooooo0_l00008ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o
00002oooool2o`0000Gooooo0_l0000<ooooo`;o00001?oooolFo`0000?ooooo0_l00006ooooo`;o
00002_ooool2o`0000_ooooo0_l00006ooooo`;o0000>?ooool001cooooo0_l0000aooooo`;o0000
1?ooool6o`000003ooooool0003o000000[ooooo0_l0000<ooooo`;o00000oooool2o`0000;ooooo
3ol00002ooooo`?o00006_ooool2o`0000[ooooo0_l00005ooooo`Ko000000?oooooo`000?l00000
0_ooool2o`0000Cooooo0_l00005ooooo`;o00002?ooool2o`0000;ooooo0_l00004oooooaOo0000
0_ooool2o`0000Kooooo0_l0000:ooooo`;o000000?oooooo`000?l000004?ooool2o`0003Sooooo
000Looooo`03o`000?oooooooooo037ooooo0ol00002ooooo`;o000000?oooooo`000?l000000_oo
ool2o`0000Cooooo0_l00004ooooo`;o00002_ooool3o`0000?ooooo0ol00002ooooo`;o000000?o
ooooo`000?l000000ol000000ooooooo0000o`000005o`0000;ooooo0_l0000<ooooo`;o00005_oo
ool4o`0000Oooooo2ol0000Eooooo`;o00002?oooolGo`0000gooooo0_l0000:ooooo`;o00002?oo
ool4o`0003kooooo000Looooo`03o`000?oooooooooo037ooooo0ol0000?ooooo`Co00003_ooool3
o`0000?ooooo0ol00004ooooo`?o00000oooool4o`000004ooooool0003o0000o`0000;ooooo1?l0
0007ooooo`;o000000?oooooo`000?l000001Oooool3o`0000Wooooo1?l000000ooooooo0000o`00
0003ooooo`;o00001Oooool8o`00013ooooo0_l000000ooooooo0000o`000002ooooo`;o00001?oo
ool2o`0000;ooooo5ol00005ooooo`;o00001_ooool2o`0001Cooooo1?l0000nooooo`007?ooool0
0ol0003oooooooooo`0gooooo`;o00003?ooool2o`0001;ooooo0_l00002ooooo`Oo00000oooool5
o`000004ooooool0003o0000o`0000Cooooo0_l00007ooooo`;o00002?ooool3o`0000Wooooo1?l0
0006ooooo`;o00001oooool3o`0000Cooooo0_l00007ooooo`So000000?oooooo`000?l000001?oo
ool2o`0000;ooooo0_l00002oooooaOo00001Oooool2o`0000_ooooo0_l00009ooooo`;o00002?oo
ool2o`000003ooooool0003o000003Wooooo000Looooo`03o`000?oooooooooo03Oooooo0_l00000
0ooooooo0000o`000003ooooo`;o00001?ooool2o`0000Oooooo0_l00009ooooo`;o00000_ooool9
o`000003ooooool0003o000000Gooooo1?l00005ooooo`Co00003oooool2o`0000Oooooo0_l0000A
ooooo`Co00000oooool2o`0000;ooooo3?l00008ooooo`;o00000ooooolFo`000004ooooool0003o
0000o`0000Gooooo0_l0000;ooooo`;o00002Oooool2o`0000Sooooo0_l000000ooooooo0000o`00
000iooooo`007?ooool00ol0003oooooooooo`0jooooo`;o00000oooool2o`0000Cooooo0_l00007
ooooo`;o00003_ooool2o`0000;ooooo1?l00002ooooo`;o00001?ooool4o`0000Cooooo1Ol0000;
ooooo`;o00000_ooool2o`0001cooooo1Ol00002ooooo`Oo00001Oooool2o`0000;ooooo0_l00009
oooooaWo00003Oooool2o`0000Wooooo0ol00004ooooo`;o00001Oooool2o`0003kooooo000Loooo
o`03o`000?oooooooooo03;ooooo0_l0000<ooooo`Co000000?oooooo`000?l000005?ooool2o`00
0003ooooool0003o000000Sooooo0_l0000<ooooo`Co00003?ooool2o`0000Gooooo0_l0000Joooo
o`So00003_ooool4o`0000Sooooo5ol000000ooooooo0000o`00000;ooooo`;o00002Oooool3o`00
00?ooooo0ol00005ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0;Oooool2o`0000?o
oooo0_l00008ooooo`;o00000_ooool5o`0000?ooooo0ol0000@ooooo`;o000000?oooooo`000?l0
00001?ooool2o`00017ooooo0_l0000Dooooo`;o00001?ooool2o`0001Sooooo0_l0000=ooooo`?o
00000_ooool2o`0000;ooooo0_l00005ooooo`Co000000?oooooo`000?l000003Ol00003ooooo`Ko
00006?ooool2o`0004Kooooo000Looooo`03o`000?oooooooooo02gooooo0_l00008ooooo`;o0000
0oooool2o`0000Gooooo0_l000000ooooooo0000o`000003o`0000;ooooo0_l00009ooooo`;o0000
0_ooool4o`0000Cooooo0_l0000=ooooo`;o00000_ooool2o`0000Wooooo0_l00007ooooo`;o0000
0oooool2o`000003ooooool0003o000000gooooo0_l00003ooooo`;o00001?ooool2o`0000Cooooo
1?l00002ooooo`;o000000Coooooo`000?l0003o00001_ooool2o`0000?ooooo5ol00004ooooo`Co
00000_ooool2o`0005cooooo000Looooo`03o`000?oooooooooo03Cooooo0_l000000ooooooo0000
o`00000=ooooo`;o00001Oooool2o`0000Wooooo0_l00002ooooo`Co00000oooool2o`0000Oooooo
0_l00005ooooo`;o00003?ooool3o`0000Oooooo0_l00003ooooo`;o00004?ooool2o`0000?ooooo
0_l00004ooooo`;o00001?ooool4o`0000;ooooo0_l00002ooooo`;o00001oooool2o`0000;ooooo
2ol000000ooooooo0000o`000009o`0000Cooooo0ol00003ooooo`;o00000oooool2o`0000cooooo
0_l00007ooooo`;o00001?ooool2o`0003[ooooo000Looooo`03o`000?oooooooooo03Cooooo0_l0
0007ooooo`;o00000oooool2o`0001[ooooo0_l00003ooooo`;o00001oooool2o`0000kooooo0_l0
0003ooooo`;o00009?ooool2o`0000kooooo0_l0000=ooooo`;o00000ooooolDo`000003ooooool0
003o000000Cooooo0_l00002ooooo`?o00000oooool2o`0000;ooooo0_l00008ooooo`;o00001ooo
ool2o`0000Cooooo0ol0000Eooooo`;o00008_ooool001cooooo00?o0000ooooooooool0<oooool3
o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`Co00002oooool4o`00027ooooo0_l00004
ooooo`;o00000_ooool2o`0000?ooooo0_l0000Gooooo`;o00001oooool2o`0000kooooo1?l0000@
ooooo`So00000_ooool?o`0000?ooooo1_l00006ooooo`?o00005Oooool2o`000003ooooool0003o
000001Gooooo0_l0000Rooooo`007?ooool00ol0003oooooooooo`0cooooo`?o00001?ooool4o`00
0003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o0000
00?ooooo1?l00008ooooo`;o00001Oooool2o`00013ooooo0_l00008ooooo`;o00000oooool2o`00
00cooooo0_l00009ooooo`Co00001?ooool3o`0000kooooo1?l000000ooooooo0000o`000009oooo
o`;o00000ooooolBo`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000001Ol00005
ooooo`Co00001_ooool2o`0000;ooooo0_l0000:ooooo`;o0000??ooool001cooooo00?o0000oooo
ooooool0??ooool2o`000003ooooool0003o000000Cooooo1_l000000ooooooo0000o`000005oooo
o`;o000000Goooooo`000?l0003o0000ooooo`05o`0000Gooooo0_l0000>ooooo`;o00002Oooool2
o`0000Cooooo0_l0000<ooooo`;o000000?oooooo`000?l000002?ooool2o`0000Cooooo0_l0000<
ooooo`;o000000?oooooo`000?l000000oooool2o`0000Wooooo0_l00003ooooo`_o00000_ooool2
o`000003ooooool0003o000000?ooooo0ol000000ooooooo0000o`000008ooooo`Co00002?ooool6
o`0000_ooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`15ooooo`;o000000?oooooo`00
0?l000002Oooool2o`000005ooooool0003o0000o`000?ooool00ol0000Gooooo`;o00002Oooool2
o`000004ooooool0003o0000ooooo`;o00001_ooool2o`0000Gooooo2Ol00006ooooo`;o00003?oo
ool2o`000003ooooool0003o000000?o00000oooool3o`0000Sooooo0_l00003ooooo`Co00001?oo
ool2o`0000;ooooo1?l00005ooooo`?o00001_ooool2o`0000?ooooo0_l00006ooooo`Co00000_oo
ool4o`0000Cooooo0_l00005ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0=Oooool2
o`00017ooooo0_l0000@ooooo`;o00001Oooool2o`0001cooooo0_l000000ooooooo0000o`000005
ooooo`;o00000_ooool2o`0000Gooooo0_l00002ooooo`Go00001_ooool2o`0000cooooo0_l00002
ooooo`?o00000_ooool2o`000003ooooool0003o000000Sooooo0_l0000:ooooo`;o000000?ooooo
o`000?l000001?l0000>ooooo`;o00002oooool4o`0000Cooooo0_l00003ooooo`?o00001Oooool2
o`0003_ooooo000Looooo`;o0000=_ooool2o`0000Kooooo0_l00009ooooo`;o00000_ooool3o`00
00Cooooo0_l0000;ooooo`Go00006_ooool2o`000003ooooool0003o000000Gooooo0_l0000Roooo
o`Ko00000oooool6o`0000;ooooo0_l0000=ooooo`?o00000oooool2o`000004ooooool0003o0000
o`0000kooooo0_l0000@ooooo`;o00002Oooool2o`0000Kooooo0_l0000kooooo`007?ooool00ol0
003oooooooooo`0mooooo`;o00002Oooool2o`000003ooooool0003o000000;o00001?ooool2o`00
00Cooooo0_l00005ooooo`Go00004_ooool2o`0000;ooooo0_l0000Dooooo`;o00001Oooool2o`00
013ooooo0_l000000ooooooo0000o`000004o`0000;ooooo1Ol00002ooooo`Ko00002oooool5o`00
00Gooooo0_l0000>ooooo`;o00001Oooool2o`0000Wooooo1?l0000>ooooo`;o0000??ooool001co
oooo00?o0000ooooooooool0=Oooool2o`000003ooooool0003o000000Cooooo0_l00008ooooo`Go
00003?ooool2o`0000Gooooo0ol0000Dooooo`?o000000?oooooo`000?l000005?ooool3o`0000?o
oooo0ol0000@ooooo`;o000000Coooooo`000?l0003o00001Oooool4o`0000?ooooo0_l00002oooo
o`?o00000oooool2o`0000Sooooo0_l00008ooooo`;o00001?ooool2o`0000cooooo1Ol00006oooo
o`Co00003_ooool2o`0003cooooo000Looooo`03o`000?oooooooooo03Gooooo0_l000000ooooooo
0000o`000004ooooo`;o00002?ooool3o`0000Gooooo1?l0000=ooooo`;o00002_ooool2o`0000Wo
oooo1?l00005ooooo`;o00002_ooool4o`000003ooooool0003o000000;o000000?oooooo`000?l0
00000oooool2o`0000oooooo0ol00007ooooo`;o00002?ooool2o`000003ooooool0003o000000;o
00004_ooool2o`0000Cooooo0_l0000=ooooo`Co00001Oooool2o`0000kooooo0_l0000oooooo`00
7?ooool00ol0003oooooooooo`0/ooooo`;o00002_ooool2o`0000oooooo1?l00003ooooo`Co0000
2?ooool2o`0000_ooooo0_l00002ooooo`Co000000?oooooo`000?l000001_ooool3o`0000Cooooo
0_l00004ooooo`;o00000_ooool6o`0000;ooooo0ol00006ooooo`;o00000_ooool4o`0000Sooooo
0ol00008ooooo`;o00002Oooool4o`0000?ooooo0_l00006ooooo`;o00002Oooool2o`00017ooooo
0_l00007ooooo`?o00000oooool2o`0000Sooooo0_l0000oooooo`007?ooool00ol0003ooooooooo
o`0/ooooo`;o00006Oooool6o`0000Gooooo0_l00003ooooo`;o00000oooool2o`0000Cooooo0ol0
0004ooooo`;o00000oooool3o`000003ooooool0003o000000Oooooo0_l00007ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0000Kooooo0_l0000;ooooo`Co00001oooool3o`0000kooooo0_l0
0004ooooo`;o00001Oooool2o`0000Kooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0
003o000000;ooooo0_l0000Gooooo`;o00000_ooool3o`0000Sooooo1?l000000ooooooo0000o`00
0009ooooo`;o0000;oooool001cooooo00?o0000ooooooooool0<oooool2o`0001;ooooo0_l00003
ooooo`;o00001?ooool2o`0000;ooooo0ol00008ooooo`Ko00005?ooool2o`0000Oooooo0_l0000B
ooooo`?o000000Coooooo`000?l0003ooooo1_l00006ooooo`?o00001?ooool2o`0000Sooooo0_l0
000Dooooo`;o000000?oooooo`000?l000000_ooool2o`0000Cooooo0ol0000>ooooo`;o00001Ooo
ool2o`0000Cooooo0_l00005ooooo`;o00000_ooool4o`000003ooooool0003o000000Cooooo0_l0
0003ooooo`;o0000;oooool001cooooo00?o0000ooooooooool0<oooool2o`0000cooooo0_l00009
ooooo`Co00000_ooool2o`0000;ooooo0_l00004ooooo`;o00000oooool3o`000003ooooool0003o
000000Sooooo0_l0000:ooooo`;o00003oooool2o`0000[ooooo0ol000000ooooooo0000o`000007
o`0000gooooo0_l000000ooooooo0000o`00000Kooooo`;o00002oooool3o`0000Oooooo0_l00002
ooooo`Go00001Oooool4o`000003ooooool0003o000000Kooooo0_l00009ooooo`;o00000_ooool4
o`0003;ooooo000Looooo`03o`000?oooooooooo03?ooooo0_l000000ooooooo0000o`000003oooo
o`;o00001?ooool2o`0000Cooooo0_l00005ooooo`;o00003?ooool2o`0000Cooooo0_l0000;oooo
o`Co00002?ooool2o`0000oooooo0_l00009ooooo`;o00001Oooool2o`0001;ooooo1Ol0000Foooo
o`;o000000?oooooo`000?l000000ol0000;ooooo`;o00001oooool2o`0000;ooooo1?l00003oooo
o`;o000000?oooooo`000?l000001Ol00003ooooo`;o000000?oooooo`000?l000000_l00007oooo
o`;o00001?ooool2o`0003;ooooo000Looooo`03o`000?oooooooooo03?ooooo1Ol00003ooooo`;o
00002_ooool2o`0001?ooooo0_l00006ooooo`;o00001oooool2o`0000;ooooo0ol00005ooooo`;o
00003Oooool2o`0000;ooooo0_l00008ooooo`?o00004_ooool2o`0000;ooooo0_l000001?oooooo
0000o`000?l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l0000=ooooo`;o000000?ooooo
o`000?l000000ol0000Looooo`;o000000?oooooo`000?l000000ol00002ooooo`;o00001?ooool2
o`0000?ooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0booooo`Co00004?ooool2o`00
01Cooooo1ol000000ooooooo0000o`000007ooooo`;o00000oooool2o`0000Gooooo0_l0000:oooo
o`Go00000_ooool2o`0000Oooooo0ol00005ooooo`Co00001Oooool2o`000003ooooool0003o0000
00;o00000_ooool2o`0000Oooooo0_l000000ooooooo0000o`000003o`0000;ooooo0ol000000ooo
oooo0000o`00000Eooooo`;o00001oooool2o`0000Cooooo0_l00003ooooo`;o00000_ooool4o`00
00;ooooo0_l00009ooooo`;o00000oooool2o`0003cooooo000Looooo`03o`000?oooooooooo03;o
oooo1?l00005ooooo`;o00002Oooool2o`0000;ooooo0_l00004ooooo`;o00002oooool6o`0001?o
oooo0_l0000=ooooo`Co00000oooool2o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`Ko
00001Oooool2o`000004ooooool0003o0000o`0000gooooo3?l000000ooooooo0000o`00000Eoooo
o`;o00001oooool2o`0000Cooooo0_l00007ooooo`?o00002Oooool4o`0000Kooooo0_l0000loooo
o`007?ooool00ol0003oooooooooo`0dooooo`;o00001Oooool2o`0000Wooooo0ol000000ooooooo
0000o`000004ooooo`;o00009?ooool2o`0000_ooooo2ol000000ooooooo0000o`000003o`0000;o
oooo0_l00003ooooo`Co00002_ooool2o`0000_ooooo0_l000000ooooooo0000o`00000;o`0001Oo
oooo0_l0000:ooooo`;o00000oooool3o`0000Gooooo0_l00009ooooo`Co0000A?ooool001cooooo
00?o0000ooooooooool0;Oooool2o`0000Gooooo0_l0000@ooooo`?o00002oooool2o`0001oooooo
1?l00004ooooo`;o00001?ooool:o`0000;ooooo1Ol00002ooooo`;o00001Oooool2o`0000[ooooo
0_l00009ooooo`So000000?oooooo`000?l000001ol00006ooooo`;o00003oooool2o`0000[ooooo
0_l00003ooooo`?o0000F?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Co
oooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo02gooooo0_l00005oooo
o`;o00003_ooool2o`0000?ooooo0_l00006ooooo`;o000000?oooooo`000?l000000_ooool2o`00
01_ooooo1?l000001?oooooo0000o`000?ooool2o`0000;ooooo5Ol00003ooooo`;o00003oooool2
o`0000Gooooo5Ol00006ooooo`;o00002oooool2o`0002Oooooo0_l00015ooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo
00?o0000ooooooooool0=?ooool2o`0000Kooooo0_l00006ooooo`?o00000_ooool2o`0000Kooooo
1Ol00002ooooo`;o00003oooool2o`0000oooooo6Ol000000ooooooo0000o`000003ooooo`;o0000
2oooool2o`0000;ooooo0_l00005ooooo`?o000000?oooooo`000?l000003ol0000Cooooo`;o0000
2?ooool2o`00013ooooo0ol0000:ooooo`;o0000AOooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
=?ooool2o`0000Cooooo1?l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00007ooooo`?o0000
4oooool2o`0000kooooo6Ol000000ooooooo0000o`00000Aooooo`;o00002_oooolEo`0000;ooooo
0_l0000Hooooo`;o00001_ooool2o`0000Sooooo0ol000000ooooooo0000o`00001>ooooo`0000?o
ooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B40
1_ooool3o`0002[ooooo0_l0000>ooooo`;o00001Oooool2o`0000Oooooo0_l00006ooooo`Co0000
0_ooool2o`0001Oooooo0_l00006ooooo`Co000000?oooooo`000?l000004_l000000ooooooo0000
o`00000JoooooaWo000000?oooooo`000?l000008?ooool2o`0000cooooo0_l00002ooooo`;o0000
0_ooool2o`0004Kooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go
0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo02[ooooo0_l0000>ooooo`Co0000
2?ooool2o`0000;ooooo0_l00006ooooo`Co000000Coooooo`000?l0003o00005?ooool2o`000003
ooooool0003o000000;o00001_oooolJo`0001[ooooo5?l000000ooooooo0000o`000002o`000003
ooooool0003o000002?ooooo0_l00005ooooo`;o00001_ooool6o`0004Kooooo00000ooooooo410@
ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003ooooo
ooooo`0fooooo`;o00000_ooool4o`0000Sooooo0_l00002ooooo`;o00001_ooool4o`000004oooo
ool0003o0000ooooo`;o00002_ooool2o`0000Kooooo0_l00003ooooo`?o00001OoooolJo`0000Oo
oooo0_l0000Aoooooa[o00004oooool2o`0000?ooooo0_l0000;ooooo`;o00001Oooool2o`0000Co
oooo0_l00002ooooo`?o0000Aoooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool00ooM
gMgo410@oiRHV008ooooo`03o`000?oooooooooo03Cooooo1?l00002ooooo`;o00000oooool3o`00
00Sooooo0_l00004ooooo`Go00001Oooool2o`0000[ooooo0_l00006ooooo`;o00001?ooool3o`00
0004ooooool0003o0000oooooa_o00000_ooool2o`0000;ooooo0_l0000CoooooaSo00000oooool3
o`0000gooooo0_l00003ooooo`;o00004_ooool2o`0000Cooooo0_l0001<ooooo`0000Koooooonk^
k_lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0
=?ooool2o`0000Cooooo0_l00003ooooo`?o00002?ooool2o`0000Cooooo0_l000000ooooooo0000
o`00000@ooooo`;o00000oooool2o`0000;ooooo1?l00003ooooo`Go000000?oooooo`000?l00000
7Ol0000DoooooaKo000000?oooooo`000?l000001Oooool3o`0000Cooooo0_l0000Pooooo`;o0000
5_ooool2o`0003[ooooo000Looooo`03o`000?oooooooooo03Kooooo0_l00002ooooo`?o00004_oo
ool2o`0001Cooooo0_l00003ooooo`;o00001?ooool4o`0000?ooooo7_l000000ooooooo0000o`00
0005ooooo`;o00002oooool2o`0000;ooooo6ol0000:ooooo`;o00002?ooool2o`0001Kooooo0_l0
0002ooooo`;o000000?oooooo`000?l000001?l00005ooooo`;o00001?ooool2o`0003[ooooo000L
ooooo`03o`000?oooooooooo03Gooooo0ol00003ooooo`;o00004?ooool4o`0001?ooooo0_l0000;
ooooo`?o00000oooool?o`000003ooooool0003o000000_o00001?ooool2o`0000?ooooo0_l00002
ooooo`;o00001oooool2o`0000Cooooo6Ol000000ooooooo0000o`00000Aooooo`;o00005_ooool2
o`0000;ooooo2Ol00005ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0=Oooool2o`00
0003ooooool0003o000001?ooooo0_l0000Eooooo`Co00002Oooool2o`0000Cooooo7_l00002oooo
o`?o00001Oooool4o`0000Wooooo0ol000000ooooooo0000o`00000Go`000003ooooool0003o0000
02Sooooo0_l00005ooooo`;o00000oooool2o`0004Oooooo000Looooo`03o`000?oooooooooo03Oo
oooo0ol0000/ooooo`;o00000oooool2o`0000gooooo0ol000001?oooooo0000o`000?oooolDo`00
00;ooooo0_l00006ooooo`;o00002oooool3o`000003ooooool0003o000001Ko00001?ooool2o`00
02Gooooo1Ol0000>ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0=oooool2o`0001[o
oooo1_l000000ooooooo0000o`00000?ooooo`;o00002_oooolNo`0000Kooooo0_l000000ooooooo
0000o`000002ooooo`;o00000_ooool2o`0000Cooooo7?l00004ooooo`;o00000oooool2o`0001Go
oooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l000000ooooooo0000o`00000>ooooo`;o
0000@Oooool001cooooo00?o0000ooooooooool0>?ooool2o`0001Kooooo0_l000000ooooooo0000
o`000004o`000003ooooool0003o000001Cooooo0_l00005oooooa_o00002Oooool2o`000003oooo
ool0003o000000;ooooo0_l00002ooooo`?o00001_oooolIo`0000Wooooo1?l00003ooooo`;o0000
3_ooool2o`000003ooooool0003o000000;o00001_ooool3o`00057ooooo000Looooo`03o`000?oo
oooooooo03Sooooo1?l00002ooooo`;o00002_ooool2o`0000Cooooo0_l0000Kooooo`Go00001ooo
ool2o`000003ooooool0003o000001Co00004oooool4o`0000Kooooo6Ol00006ooooo`;o00000ooo
ool2o`0000?ooooo0ol0000Jooooo`?o00001oooool2o`0004Sooooo000Looooo`03o`000?oooooo
oooo03Sooooo1?l00002ooooo`;o00002_ooool2o`0000Gooooo0_l00002ooooo`;o00001?ooool2
o`0000Kooooo0_l00008ooooo`Go00001ooooolLo`0000[ooooo0_l00004ooooo`;o00002?oooolH
o`0000Oooooo0_l00003ooooo`;o00001?ooool2o`0000Cooooo0_l0000Looooo`Co00003Oooool2
o`0003Wooooo000Looooo`03o`000?oooooooooo03kooooo0_l0000>ooooo`;o000000Goooooo`00
0?l0003o0000ooooo`02o`0000Cooooo0_l00002ooooo`?o000000?oooooo`000?l000002_ooool3
o`0000Sooooo7Ol00008ooooo`;o00003_oooolHo`0000;ooooo0_l0000:ooooo`;o00002?ooool2
o`00013ooooo0_l00002ooooo`;o00001?ooool5o`0000kooooo0_l0000iooooo`007?ooool00ol0
003oooooooooo`0nooooo`;o00002Oooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool3o`00
00;ooooo0_l00002ooooo`Go00000_ooool2o`0000Oooooo0ol00003ooooo`;o00001OoooolEo`00
00Cooooo0_l0000Gooooo`ko00000_ooool2o`000003ooooool0003o000000Co00000_ooool2o`00
00[ooooo0_l00008ooooo`;o00001Oooool2o`0000Gooooo0_l00002ooooo`;o00000_ooool2o`00
00Cooooo0_l0000?ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0=_ooool4o`0000;o
oooo0_l0000;ooooo`;o00002oooool3o`000004ooooool0003o0000o`0000Gooooo0_l00002oooo
o`;o00002?ooool2o`0000?ooooo0_l00005oooooaCo00007OoooolBo`0000;ooooo1_l00005oooo
o`;o00001_ooool2o`0000Sooooo0ol00005ooooo`;o00001Oooool2o`0000cooooo0_l0000?oooo
o`?o0000>_ooool001cooooo0_l0000eooooo`Ko00000_ooool2o`0000Gooooo0_l00004ooooo`;o
00003oooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o00002?ooool2o`0000_o
oooo4ol0000Gooooo`Co00000_ooool4o`000003ooooool0003o000001?o00001Oooool2o`0000Ko
oooo1?l00006ooooo`;o00001_ooool2o`000003ooooool0003o000000Co000000?oooooo`000?l0
00001_ooool2o`000003ooooool0003o0000013ooooo0_l0000jooooo`007?ooool00ol0003ooooo
ooooo`0dooooo`;o00001?ooool2o`0000?ooooo0_l00002ooooo`;o00005oooool2o`000003oooo
ool0003o000000;ooooo0_l00005ooooo`?o000000?oooooo`000?l000000_l0000;ooooo`oo0000
0_ooool2o`0001Oooooo1?l00003ooooo`?o000000?oooooo`000?l000004ol0000>ooooo`?o0000
3_ooool2o`000003ooooool0003o000000;o00000oooool3o`0000Gooooo0_l0001?ooooo`007?oo
ool00ol0003oooooooooo`0gooooo`Oo000000?oooooo`000?l000000_ooool2o`0000[ooooo0_l0
0002ooooo`?o00001_ooool2o`000003ooooool0003o000000;ooooo0_l00005ooooo`So00002_oo
oolBo`0000_ooooo0ol00003ooooo`;o00000oooool2o`0000;ooooo0_l00004ooooo`?o000000?o
ooooo`000?l000004_l00005ooooo`;o00002?ooool2o`000003ooooool0003o000001Kooooo1?l0
000:ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0=oooool3o`0000;ooooo0_l00000
0ooooooo0000o`00000>ooooo`Oo00005Oooool5o`0000;ooooo0ol00007ooooo`;o00000_ooool3
o`0000?ooooo1Ol000000ooooooo0000o`00000;ooooo`?o00000oooool2o`0000?ooooo0_l00002
ooooo`;o00001Oooool2o`000003ooooool0003o000001;o000000?oooooo`000?l000000_ooool2
o`0000Kooooo1ol0000?ooooo`;o000000Coooooo`000?l0003o00000oooool2o`0000[ooooo0_l0
0006ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0=oooool2o`0000cooooo0_l0000:
ooooo`?o00001_ooool2o`0001;ooooo0_l000000ooooooo0000o`000002o`0000Wooooo2_l00006
ooooo`;o00002Oooool2o`0000Cooooo0ol00002ooooo`;o00000oooool2o`0000Wooooo4_l00000
0ooooooo0000o`000002ooooo`;o00001?ooool7o`00017ooooo0_l000001Ooooooo0000o`000?l0
003ooooo00Co00004_ooool2o`00047ooooo000Looooo`03o`000?oooooooooo03Oooooo0_l00002
ooooo`;o00002?ooool2o`0000gooooo0_l00004ooooo`;o00004_ooool2o`000004ooooool0003o
0000ooooo`;o00000oooool2o`0000?ooooo0_l00003ooooo`Co00001oooool2o`000004ooooool0
003o0000ooooo`;o00000oooool4o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000[ooooo
4Ol00002ooooo`;o00001oooool2o`000003ooooool0003o000000oooooo0_l000000ooooooo0000
o`000003ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o0000DOooool001cooooo00?o
0000ooooooooool0=oooool2o`0000;ooooo0ol0000Fooooo`;o00002Oooool2o`0000[ooooo0_l0
0007ooooo`;o00000oooool2o`0000?ooooo0_l00005ooooo`?o00002Oooool2o`000003ooooool0
003o000000Gooooo0_l0000FoooooaCo000000?oooooo`000?l000004_ooool2o`0000Gooooo1?l0
00001?oooooo0000o`000?ooool2o`0000Gooooo0_l00002ooooo`;o0000DOooool001cooooo00?o
0000ooooooooool0=oooool2o`0000?ooooo0_l0000Booooo`Co00002Oooool6o`0000Sooooo0_l0
000Fooooo`;o000000?oooooo`000?l000002Oooool2o`000003ooooool0003o000000?ooooo0_l0
0008ooooo`;o00000oooool2o`0000Wooooo5?l0000:ooooo`?o000000?oooooo`000?l000001Ooo
ool2o`0000Gooooo1?l00004ooooo`;o000000?oooooo`000?l000001?l0001Eooooo`007?ooool0
0ol0003oooooooooo`1?ooooo`Go00002Oooool2o`0000;ooooo1?l00004ooooo`;o00006?ooool2
o`000003ooooool0003o000000Oooooo1?l000000ooooooo0000o`000003ooooo`;o00000oooool2
o`0000?ooooo0_l00003ooooo`;o00002ooooolBo`0000[ooooo1_l0000>ooooo`;o00000oooool2
o`0000;ooooo1?l00003ooooo`;o00005_ooool2o`0003[ooooo000Looooo`03o`000?oooooooooo
04;ooooo0_l0000;ooooo`Co00001_ooool4o`0000Kooooo0_l00004ooooo`;o00002?ooool2o`00
00Sooooo0_l0000@ooooo`Co00001_ooool2o`0000?ooooo0_l0000Eooooo`?o000000?oooooo`00
0?l000003?l00008ooooo`;o00000_ooool6o`000003ooooool0003o000000?ooooo0_l00003oooo
o`;o00001?ooool2o`000003ooooool0003o000000?o00000oooool4o`0001Cooooo0_l0000joooo
o`007?ooool00ol0003oooooooooo`0fooooo`;o000000Coooooo`000?l0003o00001_ooool2o`00
00gooooo0_l00005ooooo`Go00001_ooool2o`0000kooooo0_l00008ooooo`;o00008Oooool2o`00
00Sooooo0_l0000:ooooo`;o00000_ooool9o`0000Kooooo0_l00004ooooo`;o00000_ooool2o`00
00;ooooo0_l000000ooooooo0000o`000002ooooo`?o00000_ooool3o`0000Oooooo1Ol00005oooo
o`;o0000D?ooool001cooooo00?o0000ooooooooool0=_ooool2o`000004ooooool0003o0000o`00
00[ooooo0_l00009ooooo`;o00001Oooool2o`0000Wooooo0_l0000Eooooo`?o00008oooool3o`00
00Oooooo0_l0000>ooooo`Co00000oooool6o`0000;ooooo0_l000000ooooooo0000o`000003o`00
00gooooo1ol0000:ooooo`;o000000?oooooo`000?l00000EOooool001cooooo00?o0000oooooooo
ool0=_ooool2o`0000Cooooo0_l00008ooooo`;o00002Oooool2o`0000kooooo1?l0000>ooooo`Co
00000oooool3o`000003ooooool0003o000000?ooooo1_l00004ooooo`;o000000?oooooo`000?l0
00001Oooool5o`0000Gooooo1?l00006ooooo`Co00000oooool2o`0000gooooo1_l00005ooooo`?o
000000?oooooo`000?l000002?ooool2o`0000?ooooo1?l00002ooooo`;o00002_ooool3o`0000Wo
oooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`0looooo`;o00002?ooool4o`0000Oooooo
0_l0000=ooooo`Go00002oooool2o`000003ooooool0003o000000;o00001oooool2o`0000?ooooo
1ol000000ooooooo0000o`000002o`000003ooooool0003o000000Gooooo1Ol00007ooooo`;o0000
1_ooool4o`0000?ooooo1?l00008ooooo`;o00001Oooool2o`0000Oooooo1?l00005ooooo`;o0000
00?oooooo`000?l000001Oooool3o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000
o`000002ooooo`;o00002_ooool2o`0004[ooooo000Looooo`03o`000?oooooooooo04?ooooo0_l0
0002ooooo`Go00005?ooool2o`000003ooooool0003o000000?ooooo0_l00006ooooo`;o000000?o
ooooo`000?l000004_ooool3o`000004ooooool0003o0000o`0000Wooooo0_l00004ooooo`?o0000
5?ooool2o`0000Kooooo1?l00005ooooo`;o00001oooool2o`0000Oooooo0_l000001?oooooo0000
o`000?ooool2o`0000?ooooo0_l00006ooooo`Go00003Oooool2o`0004_ooooo000Looooo`03o`00
0?oooooooooo04?ooooo0_l00005ooooo`;o00000_ooool2o`0001Sooooo0_l00009ooooo`;o0000
0oooool2o`0000Sooooo0_l00003ooooo`;o00005?ooool3o`0001cooooo0_l0000Looooo`;o0000
00?oooooo`000?l000002oooool4o`0000_ooooo0_l000000ooooooo0000o`000003ooooo`;o0000
A_ooool001cooooo0_l00011ooooo`;o00001Oooool2o`0000Gooooo0_l0000Cooooo`;o00004ooo
ool2o`0000Sooooo0_l0000Hooooo`;o0000<_ooool2o`0000?ooooo0_l000000ooooooo0000o`00
000<ooooo`;o00000_ooool4o`0000_ooooo0_l00006ooooo`;o0000A_ooool001cooooo00?o0000
ooooooooool0@?ooool4o`0000?ooooo0_l0000:ooooo`;o00000oooool3o`0000Kooooo1?l0000N
ooooo`;o00005Oooool4o`0001oooooo0_l0000Aooooo`;o00000oooool2o`000003ooooool0003o
000000_ooooo0ol00002ooooo`Co00003oooool2o`0004[ooooo000Looooo`03o`000?oooooooooo
047ooooo0ol00009ooooo`;o00001?ooool2o`0000?ooooo0ol00006ooooo`;o00002oooool2o`00
00Sooooo0_l00008ooooo`Co00004?ooool2o`0000;ooooo0_l0000Dooooo`;o00002oooool2o`00
00Oooooo0_l0000:ooooo`;o00004Oooool3o`0000?ooooo0_l00007ooooo`Co00001?ooool3o`00
04[ooooo000Looooo`03o`000?oooooooooo04Sooooo0_l00003ooooo`Ko00001oooool2o`0000?o
oooo0_l0000=ooooo`;o00000oooool4o`000003ooooool0003o000000;ooooo1?l00002ooooo`Co
00004?ooool2o`000003ooooool0003o000001Gooooo0_l0000Aooooo`;o000000?oooooo`000?l0
00002_ooool2o`0001;ooooo0_l0000<ooooo`Co00000_ooool4o`0004_ooooo000Looooo`03o`00
0?oooooooooo04Sooooo0_l00005ooooo`Ko00001?ooool3o`0000?ooooo0_l0000Booooo`Ko0000
0oooool4o`0000;ooooo0_l0000Eooooo`;o00001_ooool7o`0000Cooooo0_l0000?ooooo`?o0000
0oooool2o`00027ooooo0_l0000Booooo`;o0000COooool001cooooo00?o0000ooooooooool0Dooo
ool2o`000004ooooool0003o0000ooooo`;o00006Oooool2o`000003ooooool0003o000000;o0000
0_ooool4o`0000cooooo0_l0000:ooooo`;o00001_ooool7o`0000Cooooo0_l00003ooooo`Co0000
2?ooool3o`000003ooooool0003o0000013ooooo0_l0001dooooo`007?ooool00ol0003ooooooooo
o`1@ooooo`?o00000oooool2o`0000Wooooo0_l0000@ooooo`;o000000Coooooo`000?l0003ooooo
0_l000001?oooooo0000o`000?ooool2o`0000Gooooo0_l00005ooooo`;o00003_ooool2o`0000Ko
oooo0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o000000;o00001?ooool6o`0000;o
oooo0_l0000@ooooo`;o000000?oooooo`000?l000000_l000001?oooooo0000o`000?ooool2o`00
00Cooooo0_l0000?ooooo`?o0000DOooool001cooooo00?o0000ooooooooool0BOooool2o`0000Go
oooo0ol00006ooooo`?o00001Oooool2o`0000_ooooo0_l00003ooooo`;o000000?oooooo`000?l0
00001?ooool2o`0000?ooooo1?l000001Ooooooo0000o`000?l0003ooooo00;o00004Oooool2o`00
00_ooooo0_l00002ooooo`;o00002Oooool6o`0001Oooooo1?l000001?oooooo0000o`000?ooool2
o`0000Cooooo0_l00007ooooo`;o00001_ooool3o`000003ooooool0003o000004kooooo000Loooo
o`03o`000?oooooooooo04Wooooo0_l00006ooooo`;o00001_ooool3o`0000cooooo0_l00004oooo
o`;o00004Oooool5o`000003ooooool0003o000000Go00005oooool2o`0000;ooooo0_l0000Xoooo
o`Ko00000_ooool2o`0000Kooooo0_l00008ooooo`;o00002_ooool2o`0004kooooo000Looooo`03
o`000?oooooooooo06Sooooo0_l000000ooooooo0000o`000004ooooo`;o00004Oooool4o`000004
ooooool0003o0000ooooo`?o00004oooool2o`000003ooooool0003o000000;ooooo0_l00008oooo
o`;o00007_ooool6o`0000Cooooo0_l00004ooooo`;o0000I?ooool001cooooo00?o0000oooooooo
ool0Coooool2o`00017ooooo0_l00007ooooo`;o00000_ooool7o`0000kooooo1?l000000ooooooo
0000o`000006o`00017ooooo0_l00003ooooo`;o00002Oooool3o`0001cooooo0_l00003ooooo`;o
00000_ooool5o`0006[ooooo000Looooo`03o`000?oooooooooo04oooooo0_l00005ooooo`Co0000
2?ooool2o`0000_ooooo0_l000000ooooooo0000o`000002o`0000oooooo3?l0000Fooooo`;o0000
2Oooool2o`0000Sooooo0_l00002ooooo`;o00001Oooool2o`0000Sooooo0_l00003ooooo`;o0000
0_ooool3o`0001?ooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`1Fooooo`Co00002Ooo
ool4o`0000Wooooo0_l00002ooooo`;o00003Oooool2o`0000?ooooo1?l000000ooooooo0000o`00
000Gooooo`?o00002Oooool4o`0000Kooooo0_l00002ooooo`;o00001Oooool2o`0002Oooooo0_l0
001Gooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00000_ooool2o`0000gooooo1?l00002
ooooo`;o00001Oooool2o`0000;ooooo0_l0000=ooooo`;o00001?ooool3o`0000;ooooo0_l00000
0ooooooo0000o`00000Cooooo`?o00002oooool5o`00093ooooo000Looooo`03o`000?oooooooooo
053ooooo0_l00002ooooo`;o00001?ooool3o`0000cooooo0ol0000Eooooo`;o000000?oooooo`00
0?l000000oooool4o`000004ooooool0003o0000ooooo`;o00002_ooool2o`0000gooooo0_l00007
ooooo`Co00001oooool2o`0000_ooooo0_l0000Gooooo`;o0000HOooool001cooooo00?o0000oooo
ooooool0F_ooool3o`0000gooooo0_l00006ooooo`;o00001_ooool2o`0000Gooooo0_l000001?oo
oooo0000o`000?l00003ooooo`Go00001Oooool4o`0000?ooooo1?l0000=ooooo`;o00002?ooool3
o`0000Oooooo0_l0000;ooooo`;o00001_ooool3o`0000kooooo0_l0001Qooooo`007?ooool2o`00
04Oooooo0_l0000Cooooo`;o00002?ooool2o`0000Kooooo0_l00003ooooo`;o00001_ooool2o`00
00Kooooo0_l000000ooooooo0000o`000004ooooo`Ko00000oooool4o`000003ooooool0003o0000
00;o00003_ooool2o`0000Kooooo0_l000001?oooooo0000o`000?l00007ooooo`;o000000?ooooo
o`000?l000002?ooool2o`0000Kooooo0ol0000Booooo`Co0000Foooool001cooooo00?o0000oooo
ooooool0A_ooool2o`0001gooooo0_l00006ooooo`;o00000_ooool2o`0000;ooooo0_l0000;oooo
o`;o00001oooool3o`000003ooooool0003o000000;o00001_ooool2o`000003ooooool0003o0000
00gooooo0_l00002ooooo`?o000000Coooooo`000?l0003ooooo0ol00007ooooo`;o000000?ooooo
o`000?l000002?ooool4o`0000Gooooo0_l0000Booooo`Co0000Foooool001cooooo00?o0000oooo
ooooool0FOooool2o`0000;ooooo0_l00006ooooo`;o00002_ooool2o`0000;ooooo0_l000000ooo
oooo0000o`00000Gooooo`;o00002Oooool2o`00017ooooo0ol00003ooooo`;o00000_ooool2o`00
00Kooooo0_l00008ooooo`;o000000Coooooo`000?l0003o00000oooool2o`0000Wooooo0_l0001X
ooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o00000_ooool2o`0000Kooooo0_l0000Aoooo
o`;o00005Oooool2o`0000;ooooo2?l0000Jooooo`;o000000Coooooo`000?l0003o00001_ooool2
o`0000Sooooo0_l000000ooooooo0000o`000004ooooo`?o00000_ooool2o`0000Cooooo0_l00007
ooooo`;o0000Goooool001cooooo00?o0000ooooooooool0I?ooool2o`0000;ooooo0_l0000?oooo
o`;o00000oooool2o`0000oooooo3?l00002ooooo`;o00000oooool2o`0001Cooooo0_l00007oooo
o`;o00000_ooool2o`0000;ooooo0_l00002ooooo`?o00001Oooool2o`0000;ooooo0_l0000=oooo
o`;o0000Goooool001cooooo00?o0000ooooooooool0F?ooool2o`0000[ooooo0_l00002ooooo`;o
00002_ooool2o`0000?ooooo0_l00003ooooo`;o00002?ooool2o`0000Oooooo2_l00002ooooo`;o
00000oooool2o`0000Kooooo0_l0000Iooooo`;o00000_ooool2o`0000;ooooo0_l0000Iooooo`;o
0000Goooool001cooooo00?o0000ooooooooool0F?ooool2o`0001[ooooo0_l00004ooooo`;o0000
1Oooool2o`0000Gooooo0_l00009ooooo`Co000000Coooooo`000?l0003o00002Oooool2o`0000Co
oooo0_l00004ooooo`;o00000oooool2o`0000oooooo0_l00007ooooo`;o00000_ooool2o`0001?o
oooo0_l0001Oooooo`007?ooool00ol0003oooooooooo`1_ooooo`;o00002Oooool2o`0000?ooooo
1Ol00005ooooo`;o00001Oooool2o`000003ooooool0003o000000Cooooo0_l00009ooooo`;o0000
1?ooool2o`0000Cooooo0_l00002ooooo`?o00003oooool3o`0000?ooooo0_l000000ooooooo0000
o`000002ooooo`;o00000_ooool2o`00073ooooo000Looooo`03o`000?oooooooooo06Wooooo0_l0
0004ooooo`;o00003_ooool2o`000003ooooool0003o000000Gooooo1?l00003ooooo`;o00001Ooo
ool4o`0000Wooooo0_l00002ooooo`Co00001?ooool7o`0000oooooo0ol000000ooooooo0000o`00
0002o`0000Wooooo0_l00005ooooo`;o0000JOooool001cooooo00?o0000ooooooooool0JOooool2
o`0000Oooooo0_l0000>ooooo`;o00001_ooool3o`0000?ooooo0_l00002ooooo`;o000000?ooooo
o`000?l000000_l00009ooooo`;o00000_ooool3o`0000Gooooo1?l0000?ooooo`;o00001Oooool2
o`0001;ooooo0_l00002ooooo`;o0000IOooool001cooooo00?o0000ooooooooool0J_ooool2o`00
00Kooooo0_l0000>ooooo`;o00001?ooool2o`000003ooooool0003o000000?ooooo0_l00002oooo
o`Oo00003_ooool2o`000003ooooool0003o000000Cooooo0_l0000=ooooo`Co00000_ooool2o`00
01Cooooo0_l00003ooooo`;o0000IOooool001cooooo00?o0000ooooooooool0I_ooool2o`0000;o
oooo0_l0000Aooooo`;o00002Oooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`?o
000000Coooooo`000?l0003ooooo0_l0000>ooooo`;o000000?oooooo`000?l000000_l00003oooo
o`;o00000_ooool2o`0000Gooooo0_l00004ooooo`;o00005?ooool2o`0006[ooooo000Looooo`03
o`000?oooooooooo06Kooooo0_l00002ooooo`;o00004Oooool2o`0000?ooooo0_l00004ooooo`;o
00001Oooool2o`0000Sooooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l000000ooooooo
0000o`000006ooooo`Go00000_ooool2o`0000;ooooo0_l0002=ooooo`007?ooool00ol0003ooooo
ooooo`1Yooooo`?o00001_ooool2o`0000Gooooo0_l00007ooooo`;o00001?ooool3o`0000_ooooo
0ol00005ooooo`;o00001?ooool2o`000003ooooool0003o000000Oooooo1?l0000;ooooo`;o0000
0oooool2o`0008?ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Xooooo`Co00001_ooool2o`00
00Gooooo0_l0000>ooooo`Co00002Oooool3o`0001Wooooo0_l00009ooooo`Co00000oooool2o`00
017ooooo0_l0001`ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool0
1OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0C_ooool2o`0001Sooooo1?l0
0005ooooo`;o00001_ooool2o`00013ooooo0ol0000?ooooo`;o00000oooool2o`0000cooooo1?l0
0008ooooo`?o00001Oooool2o`00017ooooo0_l0001`ooooo`0000?ooooooa0@4?ooool00_ooool0
0ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`1>ooooo`;o00006_ooool2o`0000Gooooo0_l000001?oooooo0000o`000?l00002ooooo`;o0000
3_ooool2o`000003ooooool0003o000000oooooo0ol00002ooooo`;o00002?ooool3o`000003oooo
ool0003o000000[ooooo0_l0000Xooooo`;o0000HOooool00003ooooool0003ooooo00;ooooo00?o
0000ooooooooool02Oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0001dooooo`?o0000
0_ooool2o`0000;ooooo0_l000000ooooooo0000o`000007ooooo`;o00003?ooool2o`0000Cooooo
0ol00002ooooo`;o00002?ooool6o`0001Cooooo0_l0000Nooooo`;o0000HOooool00003ooooool0
003ooooo00;ooooo00?o0000ooooooooool02Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo
00?o0000ooooooooool0Koooool2o`0000?ooooo1?l000000ooooooo0000o`000002ooooo`;o0000
00?oooooo`000?l000001Oooool2o`0000;ooooo0_l0000:ooooo`;o00001?ooool4o`000003oooo
ool0003o000000[ooooo1?l0000Dooooo`;o0000POooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0
Koooool2o`0000Cooooo0ol000000ooooooo0000o`000005ooooo`;o00001Oooool2o`0000;ooooo
0_l0000Booooo`;o00001?ooool2o`0001;ooooo0_l0000=ooooo`;o0000Ooooool00006oooooomg
MgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000oooo
ooooool0MOooool2o`0000;ooooo0_l00005ooooo`;o00008?ooool2o`000003ooooool0003o0000
00cooooo0_l00004ooooo`;o00003Oooool2o`0000;ooooo0_l0000Aooooo`;o0000J?ooool00006
ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o
0000ooooooooool0NOooool2o`0000Kooooo0_l00005ooooo`?o00003oooool2o`0000Kooooo0_l0
0002ooooo`;o00001?ooool2o`0000Gooooo1?l0000Eooooo`;o00004Oooool2o`0006Sooooo000L
ooooo`03o`000?oooooooooo07Wooooo0_l000000ooooooo0000o`000003ooooo`;o00001Oooool3
o`0000Kooooo0_l00007ooooo`;o00001_ooool2o`0000;ooooo0_l00004ooooo`;o00001oooool2
o`000003ooooool0003o000000kooooo0_l00002ooooo`;o00000oooool2o`0007Kooooo000Loooo
o`03o`000?oooooooooo07?ooooo0_l00006ooooo`?o000000?oooooo`000?l000003oooool3o`00
00;ooooo0_l00003ooooo`;o00007?ooool2o`0000Cooooo0_l00008ooooo`;o00000_ooool2o`00
00?ooooo0_l0001fooooo`007?ooool00ol0003oooooooooo`1cooooo`;o00001_ooool2o`0000;o
oooo0_l0000?ooooo`Oo00000oooool2o`00013ooooo0_l0000@ooooo`;o00006?ooool2o`0006oo
oooo000Looooo`03o`000?oooooooooo07oooooo0_l0000=ooooo`;o000000?oooooo`000?l00000
0_l00002ooooo`;o00003_ooool4o`000003ooooool0003o000002[ooooo0_l0001_ooooo`007?oo
ool00ol0003oooooooooo`1oooooo`;o00001_ooool2o`0000Gooooo0_l000000ooooooo0000o`00
0004ooooo`;o00003_ooool5o`000003ooooool0003o000009[ooooo000Looooo`03o`000?oooooo
oooo07oooooo0_l00006ooooo`;o00001_ooool2o`0000Gooooo0_l0000Booooo`;o000000?ooooo
o`000?l000000oooool2o`0000Cooooo0_l0002?ooooo`007?ooool00ol0003oooooooooo`2?oooo
o`;o00001Oooool2o`0000Gooooo0ol0000=ooooo`;o00000oooool2o`0000Cooooo0_l0002?oooo
o`007?ooool00ol0003oooooooooo`2Mooooo`?o00003Oooool2o`0000gooooo0_l0002;ooooo`00
7?ooool00ol0003oooooooooo`2]ooooo`Co00002oooool2o`0008_ooooo000Looooo`03o`000?oo
oooooooo0:Kooooo0_l000000ooooooo0000o`000004ooooo`;o0000V?ooool001cooooo00?o0000
ooooooooool0Y_ooool2o`000003ooooool0003o000009kooooo000Looooo`;o0000[_ooool2o`00
09[ooooo000Looooo`03o`000?oooooooooo077ooooo0_l0000jooooo`;o0000V_ooool001cooooo
00?o0000ooooooooool0LOooool2o`000=Kooooo000Looooo`03o`000?oooooooooo09gooooo0_l0
002Zooooo`007?ooool00ol0003oooooooooo`2Mooooo`;o0000Z_ooool001cooooo00?o0000oooo
ooooool0KOooool2o`0005Oooooo0_l00021ooooo`007?ooool00ol0003oooooooooo`1]ooooo`;o
0000<?ooool2o`0002Gooooo0_l00021ooooo`007?ooool00ol0003oooooooooo`2Oooooo`;o0000
7Oooool2o`0000Cooooo0_l00023ooooo`007?ooool00ol0003oooooooooo`2Yooooo`;o00004ooo
ool2o`0000Cooooo0_l00023ooooo`007?ooool00ol0003oooooooooo`2Yooooo`;o00001oooool4
o`0009?ooooo000Looooo`03o`000?oooooooooo0;;ooooo1?l0002Cooooo`007?ooool00ol0003o
ooooooooo`2]ooooo`;o0000V_ooool001cooooo00?o0000ooooooooool0Z_ooool2o`000003oooo
ool0003o000009[ooooo000Looooo`03o`000?oooooooooo0:[ooooo0_l0002Mooooo`007?ooool0
0ol0003oooooooooo`2Zooooo`;o0000WOooool001cooooo00?o0000ooooooooool0Z_ooool2o`00
09gooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`2Vooooo`;o0000
XOooool001cooooo00?o0000ooooooooool0Y_ooool2o`000:7ooooo000Looooo`03o`000?oooooo
oooo0:[ooooo0_l0002Mooooo`007?ooool00ol0003oooooooooo`2Zooooo`;o0000WOooool001co
oooo00?o0000ooooooooool0R?ooool2o`000;oooooo000Looooo`03o`000?oooooooooo08Sooooo
0_l0002oooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo09Wooooo0_l00005ooooo`;o0000Yoooool001cooooo00?o0000ooooooooool0VOooool2o`00
00Gooooo0_l0002Wooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`004_ooool4o`000003
oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Ooo
ool3o`000?ooooooB_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0
003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo
00?o0000ooooooooool0oooooomBooooo`004_ooool00omEEEGoIVIVo`00003ooooooeCooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo002Qooooo`04oa0@4?l0003o0000ooooo`;o
000000?o410@ooooooooool05_ooool4o`000004oa0@4?ooooooooooooooo`Co000000?o410@oooo
ooooool01Ol00003ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0S?ooool00:;ooooo00Go0000oooo
ooooooooooooo`000009ooooo`Ko00003?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40
S?ooool00:;ooooo00Go0000ooooooooooooooooo`00000Kooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00oooool00onHV9So8B4Qonk^kP04ooooo`05o`000?ooooooooooooooool0
0000S?ooool00:;ooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00003?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?oV9RHob4Q8Oo^k^h00oooool01Olb<S;o
V9RHoooooonHV9So<S8b08cooooo002Rooooo`05o`000?n7QhOoooooojVYZOl000006oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?oMgMgofIVI_ooool00_ooool01Oo<
c<co0000o`000?l0003oc<c<08cooooo002Qooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHoooo
ooooool06Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00Wo0000oooo
oooooooooooooa0@4?nj^[[ooooookZj^_l@4100S?ooool00<;ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`02ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Ol0003o^[Zj
oooooonj^[[o000008cooooo0030ooooo`03oeEEEOmVIVKo000000Gooooo00?oEEEEofIVI_l00000
1?ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2<oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1134) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.38635 .43793 Mdot
.34711 .45003 Mdot
.53915 .65628 Mdot
.52908 .36729 Mdot
.22137 .61772 Mdot
.56907 .63803 Mdot
.42516 .58676 Mdot
.39074 .63045 Mdot
.54682 .65027 Mdot
.25268 .49642 Mdot
.4239 .59271 Mdot
.47298 .3588 Mdot
.41613 .60378 Mdot
.5462 .35358 Mdot
.14869 .49512 Mdot
.49492 .36605 Mdot
.30464 .4227 Mdot
.70382 .52411 Mdot
.55258 .44072 Mdot
.58262 .6032 Mdot
.328 .4006 Mdot
.5411 .36346 Mdot
.36342 .46905 Mdot
.54695 .35334 Mdot
.51541 .37918 Mdot
.34702 .42144 Mdot
.28588 .4425 Mdot
.54737 .41009 Mdot
.50613 .38235 Mdot
.39762 .63131 Mdot
.69214 .41012 Mdot
.15978 .55485 Mdot
.5897 .426 Mdot
.47012 .80449 Mdot
.38493 .62339 Mdot
.39541 .36561 Mdot
.56917 .65656 Mdot
.39158 .61387 Mdot
.38355 .61145 Mdot
.42736 .57965 Mdot
.39655 .59981 Mdot
.35429 .43105 Mdot
.45911 .58789 Mdot
.47304 .57427 Mdot
.49781 .39301 Mdot
.26211 .61644 Mdot
.58322 .22707 Mdot
.58317 .39026 Mdot
.317 .41657 Mdot
.63246 .69375 Mdot
.37507 .7243 Mdot
.41437 .57868 Mdot
.59235 .66042 Mdot
.59635 .88235 Mdot
.39625 .6213 Mdot
.50902 .41551 Mdot
.55668 .66763 Mdot
.55102 .36677 Mdot
.55202 .35359 Mdot
.31854 .29861 Mdot
.57336 .41706 Mdot
.68481 .53291 Mdot
.39196 .45381 Mdot
.56697 .49422 Mdot
.55387 .65595 Mdot
.38972 .59779 Mdot
.36198 .45278 Mdot
.41364 .61104 Mdot
.56878 .30254 Mdot
.59774 .60763 Mdot
.58135 .39296 Mdot
.40316 .59135 Mdot
.3428 .40686 Mdot
.5645 .39606 Mdot
.67902 .71041 Mdot
.23823 .30453 Mdot
.62787 .54578 Mdot
.35429 .33111 Mdot
.3023 .32863 Mdot
.68953 .62948 Mdot
.53136 .33927 Mdot
.73022 .34379 Mdot
.20366 .38614 Mdot
.33841 .47188 Mdot
.61654 .41064 Mdot
.60099 .56624 Mdot
.56233 .39113 Mdot
.22023 .53255 Mdot
.50085 .37279 Mdot
.69006 .72871 Mdot
.54972 .63884 Mdot
.32588 .43966 Mdot
.52842 .36498 Mdot
.54546 .41526 Mdot
.59357 .24641 Mdot
.59788 .35076 Mdot
.53945 .3961 Mdot
.36332 .41486 Mdot
.40262 .57985 Mdot
.47964 .38201 Mdot
.44738 .56668 Mdot
.56468 .68761 Mdot
.58939 .35136 Mdot
.59397 .63466 Mdot
.33489 .40417 Mdot
.56506 .40392 Mdot
.37912 .60436 Mdot
.58288 .34966 Mdot
.3345 .59969 Mdot
.34799 .45287 Mdot
.53985 .4126 Mdot
.689 .52349 Mdot
.82188 .50348 Mdot
.32072 .44462 Mdot
.72577 .60458 Mdot
.52396 .33927 Mdot
.54415 .3872 Mdot
.34643 .44765 Mdot
.55058 .6835 Mdot
.21516 .5013 Mdot
.35909 .47586 Mdot
.41584 .57395 Mdot
.38366 .46641 Mdot
.62292 .37944 Mdot
.55546 .64045 Mdot
.4413 .75629 Mdot
.37468 .66834 Mdot
.69488 .37837 Mdot
.56129 .38531 Mdot
.28877 .54903 Mdot
.56924 .61115 Mdot
.33754 .43629 Mdot
.41636 .61353 Mdot
.53432 .44828 Mdot
.3425 .46371 Mdot
.4276 .61488 Mdot
.69541 .53268 Mdot
.47565 .72465 Mdot
.30206 .43893 Mdot
.45322 .55486 Mdot
.37966 .63598 Mdot
.42405 .58066 Mdot
.53155 .81859 Mdot
.35954 .44769 Mdot
.66094 .53837 Mdot
.40943 .62373 Mdot
.67125 .4092 Mdot
.5252 .42056 Mdot
.74488 .41052 Mdot
.66926 .23208 Mdot
.48947 .80919 Mdot
.52515 .73138 Mdot
.65433 .55636 Mdot
.38607 .57685 Mdot
.5215 .39536 Mdot
.34749 .41637 Mdot
.36023 .43134 Mdot
.58272 .40842 Mdot
.522 .37155 Mdot
.5765 .39863 Mdot
.5381 .41549 Mdot
.29147 .3006 Mdot
.57263 .33052 Mdot
.63558 .23626 Mdot
.32015 .439 Mdot
.52653 .38527 Mdot
.56686 .67394 Mdot
.61357 .37575 Mdot
.39669 .59659 Mdot
.54359 .37014 Mdot
.52831 .3708 Mdot
.57434 .41843 Mdot
.41205 .57819 Mdot
.1684 .50414 Mdot
.72653 .29338 Mdot
.18485 .57905 Mdot
.72074 .6772 Mdot
.58289 .62278 Mdot
.55579 .39112 Mdot
.67524 .5235 Mdot
.4201 .33798 Mdot
.54311 .33713 Mdot
.87361 .44984 Mdot
.53656 .38593 Mdot
.19687 .58295 Mdot
.59058 .29207 Mdot
.18927 .63169 Mdot
.73242 .37278 Mdot
.52352 .40297 Mdot
.63761 .41632 Mdot
.42755 .42572 Mdot
.47274 .59673 Mdot
.39949 .59997 Mdot
.56163 .67673 Mdot
.54645 .66638 Mdot
.36882 .57615 Mdot
.26344 .42444 Mdot
.62589 .41548 Mdot
.58396 .31999 Mdot
.60449 .61455 Mdot
.39221 .42963 Mdot
.67144 .56036 Mdot
.37538 .43116 Mdot
.28526 .21802 Mdot
.35993 .69803 Mdot
.38868 .56524 Mdot
.65526 .5117 Mdot
.54368 .62965 Mdot
.57327 .67996 Mdot
.66206 .52115 Mdot
.58053 .36602 Mdot
.36389 .44827 Mdot
.44081 .81528 Mdot
.26102 .44496 Mdot
.50487 .83207 Mdot
.35225 .41213 Mdot
.29443 .51222 Mdot
.42731 .6099 Mdot
.57998 .64649 Mdot
.54306 .39074 Mdot
.57369 .36782 Mdot
.29983 .40938 Mdot
.57734 .39521 Mdot
.58764 .26562 Mdot
.54639 .40238 Mdot
.40685 .73642 Mdot
.62742 .5537 Mdot
.37023 .57513 Mdot
.69097 .35871 Mdot
.37483 .46009 Mdot
.76742 .51667 Mdot
.593 .64665 Mdot
.40257 .34184 Mdot
.40507 .58877 Mdot
.69178 .53287 Mdot
.59747 .63913 Mdot
.67224 .56144 Mdot
.59372 .41864 Mdot
.52964 .64397 Mdot
.6756 .51598 Mdot
.27555 .36953 Mdot
.52423 .41537 Mdot
.2881 .29762 Mdot
.38922 .57947 Mdot
.35092 .47702 Mdot
.57092 .41695 Mdot
.58879 .62993 Mdot
.59525 .42466 Mdot
.51275 .70401 Mdot
.43886 .75463 Mdot
.54558 .68814 Mdot
.60955 .71438 Mdot
.68569 .54344 Mdot
.46866 .677 Mdot
.30742 .5357 Mdot
.32172 .41277 Mdot
.58058 .33363 Mdot
.17569 .63112 Mdot
.4095 .62341 Mdot
.5793 .35041 Mdot
.45886 .78185 Mdot
.40528 .62095 Mdot
.55297 .36759 Mdot
.37055 .61041 Mdot
.36212 .43328 Mdot
.79801 .45162 Mdot
.30704 .42074 Mdot
.50464 .36244 Mdot
.37812 .59987 Mdot
.53735 .67161 Mdot
.33873 .4186 Mdot
.58572 .36697 Mdot
.55437 .40505 Mdot
.5245 .51303 Mdot
.52862 .39297 Mdot
.1774 .52827 Mdot
.53858 .40684 Mdot
.55759 .67414 Mdot
.60011 .37148 Mdot
.80856 .64573 Mdot
.38899 .67997 Mdot
.36267 .45187 Mdot
.53261 .67032 Mdot
.54571 .65588 Mdot
.73663 .57881 Mdot
.4724 .63821 Mdot
.53428 .33266 Mdot
.58602 .6241 Mdot
.7717 .47197 Mdot
.42282 .62604 Mdot
.58508 .33465 Mdot
.46115 .5535 Mdot
.63747 .68775 Mdot
.60153 .63676 Mdot
.524 .43964 Mdot
.3005 .41707 Mdot
.52723 .36558 Mdot
.5701 .67971 Mdot
.35695 .39891 Mdot
.51819 .33888 Mdot
.36353 .50227 Mdot
.52264 .51206 Mdot
.43544 .60537 Mdot
.60776 .3008 Mdot
.58864 .35985 Mdot
.58321 .6493 Mdot
.37507 .45018 Mdot
.40701 .63651 Mdot
.34454 .42559 Mdot
.29608 .72636 Mdot
.33874 .59312 Mdot
.27356 .34717 Mdot
.71188 .52586 Mdot
.58916 .74948 Mdot
.21441 .66655 Mdot
.7747 .63327 Mdot
.74345 .49086 Mdot
.35674 .78606 Mdot
.56831 .67714 Mdot
.48502 .78608 Mdot
.54666 .66174 Mdot
.51588 .3609 Mdot
.5566 .64508 Mdot
.20876 .66374 Mdot
.54479 .40196 Mdot
.56154 .64815 Mdot
.78 .51176 Mdot
.52553 .37741 Mdot
.32067 .44936 Mdot
.17438 .44855 Mdot
.78923 .63135 Mdot
.42149 .76313 Mdot
.54135 .61894 Mdot
.71075 .48153 Mdot
.53801 .39852 Mdot
.602 .38181 Mdot
.31652 .42064 Mdot
.5889 .33443 Mdot
.66574 .55963 Mdot
.65812 .51029 Mdot
.44499 .44793 Mdot
.74566 .33984 Mdot
.51366 .31222 Mdot
.33361 .41766 Mdot
.35107 .245 Mdot
.66402 .71912 Mdot
.61638 .72338 Mdot
.3678 .59568 Mdot
.18171 .46576 Mdot
.53939 .26982 Mdot
.38335 .55086 Mdot
.4821 .5863 Mdot
.33112 .44763 Mdot
.16857 .52582 Mdot
.39863 .60361 Mdot
.49292 .21872 Mdot
.63627 .453 Mdot
.57721 .36317 Mdot
.41109 .58632 Mdot
.50169 .31593 Mdot
.7789 .66505 Mdot
.52056 .1904 Mdot
.67524 .28066 Mdot
.50695 .35201 Mdot
.69335 .70082 Mdot
.5425 .3775 Mdot
.21405 .48424 Mdot
.54063 .40835 Mdot
.33579 .42423 Mdot
.23196 .486 Mdot
.48311 .4786 Mdot
.69814 .26978 Mdot
.34914 .68323 Mdot
.65488 .5568 Mdot
.54695 .39623 Mdot
.57671 .36143 Mdot
.673 .55541 Mdot
.31916 .45967 Mdot
.53734 .41577 Mdot
.76045 .51714 Mdot
.57011 .38987 Mdot
.39112 .606 Mdot
.66076 .28114 Mdot
.29295 .4654 Mdot
.56338 .31088 Mdot
.3831 .42028 Mdot
.43647 .60659 Mdot
.3846 .61775 Mdot
.49152 .36735 Mdot
.44086 .58694 Mdot
.53469 .37746 Mdot
.52958 .18188 Mdot
.30864 .44656 Mdot
.59254 .28029 Mdot
.35473 .46939 Mdot
.34657 .33559 Mdot
.37791 .61332 Mdot
.39822 .72356 Mdot
.48235 .4101 Mdot
.40304 .60193 Mdot
.3484 .56688 Mdot
.51587 .31329 Mdot
.50737 .3391 Mdot
.65461 .7545 Mdot
.53508 .63097 Mdot
.51399 .50004 Mdot
.38531 .6295 Mdot
.5897 .36832 Mdot
.56827 .31747 Mdot
.43741 .60177 Mdot
.44943 .20594 Mdot
.78889 .56314 Mdot
.54341 .40541 Mdot
.32494 .42756 Mdot
.33956 .43496 Mdot
.50951 .34217 Mdot
.57625 .33945 Mdot
.56314 .62017 Mdot
.52757 .65048 Mdot
.54575 .60894 Mdot
.52045 .51025 Mdot
.40153 .72899 Mdot
.28258 .66612 Mdot
.42763 .57994 Mdot
.30909 .57502 Mdot
.70549 .71561 Mdot
.61868 .37279 Mdot
.56704 .60655 Mdot
.57104 .34975 Mdot
.5327 .36618 Mdot
.41194 .6361 Mdot
.43341 .77144 Mdot
.50952 .29834 Mdot
.30729 .45006 Mdot
.39228 .63553 Mdot
.55569 .46026 Mdot
.31001 .64723 Mdot
.6847 .5237 Mdot
.56057 .80287 Mdot
.39961 .59119 Mdot
.32788 .45044 Mdot
.37434 .61098 Mdot
.57423 .37307 Mdot
.53073 .4358 Mdot
.339 .44476 Mdot
.65425 .51611 Mdot
.60719 .39378 Mdot
.55188 .37057 Mdot
.77033 .30555 Mdot
.72087 .69076 Mdot
.41593 .73093 Mdot
.52756 .40455 Mdot
.54786 .31256 Mdot
.69581 .54986 Mdot
.57232 .38458 Mdot
.57207 .40938 Mdot
.81494 .44588 Mdot
.35407 .65704 Mdot
.68876 .51033 Mdot
.47189 .2173 Mdot
.34657 .41094 Mdot
.1692 .59978 Mdot
.58285 .64196 Mdot
.43386 .5754 Mdot
.80072 .55048 Mdot
.56887 .68772 Mdot
.54415 .72816 Mdot
.16699 .58258 Mdot
.50992 .49924 Mdot
.64504 .59578 Mdot
.4812 .33289 Mdot
.55896 .41314 Mdot
.54542 .38069 Mdot
.6735 .52682 Mdot
.36267 .44336 Mdot
.53664 .5047 Mdot
.32971 .23649 Mdot
.5398 .36957 Mdot
.60032 .27502 Mdot
.24365 .38973 Mdot
.64114 .67586 Mdot
.65485 .55094 Mdot
.65298 .51523 Mdot
.54678 .39194 Mdot
.81401 .47952 Mdot
.3463 .42031 Mdot
.58551 .36537 Mdot
.54309 .32561 Mdot
.53571 .62554 Mdot
.34528 .45641 Mdot
.5723 .67531 Mdot
.38807 .71206 Mdot
.19291 .58527 Mdot
.77624 .30401 Mdot
.38169 .61713 Mdot
.22509 .42856 Mdot
.40598 .63131 Mdot
.72184 .3353 Mdot
.57632 .67897 Mdot
.5378 .3361 Mdot
.37529 .45409 Mdot
.58545 .35843 Mdot
.56738 .33516 Mdot
.58016 .36389 Mdot
.59947 .33337 Mdot
.8678 .50779 Mdot
.65628 .52014 Mdot
.53769 .30954 Mdot
.54639 .67011 Mdot
.19984 .46539 Mdot
.22842 .32905 Mdot
.57083 .35885 Mdot
.55303 .40121 Mdot
.32562 .45829 Mdot
.59141 .39741 Mdot
.41755 .6283 Mdot
.37586 .4466 Mdot
.54268 .41477 Mdot
.18905 .46721 Mdot
.5109 .39778 Mdot
.18741 .61173 Mdot
.3751 .61569 Mdot
.34935 .54548 Mdot
.53484 .30694 Mdot
.44014 .75212 Mdot
.51416 .5001 Mdot
.58589 .6139 Mdot
.45207 .59946 Mdot
.56671 .65728 Mdot
.42515 .17563 Mdot
.55566 .43617 Mdot
.5192 .39128 Mdot
.57297 .32127 Mdot
.58427 .62459 Mdot
.21624 .55437 Mdot
.4385 .68318 Mdot
.57246 .45795 Mdot
.57373 .62166 Mdot
.39351 .43853 Mdot
.6222 .49525 Mdot
.36911 .46173 Mdot
.65885 .50829 Mdot
.42383 .59434 Mdot
.64155 .53398 Mdot
.44152 .78489 Mdot
.34596 .4514 Mdot
.28337 .42489 Mdot
.57964 .63473 Mdot
.54635 .55593 Mdot
.50911 .87717 Mdot
.60039 .51611 Mdot
.72172 .39783 Mdot
.31591 .4228 Mdot
.50772 .36107 Mdot
.69841 .31684 Mdot
.53361 .55142 Mdot
.5639 .65864 Mdot
.53859 .34374 Mdot
.80281 .4743 Mdot
.5638 .61949 Mdot
.58446 .33513 Mdot
.53477 .65191 Mdot
.40768 .59389 Mdot
.55612 .61304 Mdot
.29548 .44264 Mdot
.56098 .40199 Mdot
.4776 .86837 Mdot
.63374 .51443 Mdot
.53445 .40234 Mdot
.38945 .63442 Mdot
.40035 .49559 Mdot
.56209 .33866 Mdot
.69607 .54176 Mdot
.56156 .6366 Mdot
.5929 .53032 Mdot
.54309 .40681 Mdot
.58166 .62418 Mdot
.38573 .44896 Mdot
.45242 .59292 Mdot
.47885 .4552 Mdot
.43369 .75366 Mdot
.31937 .41862 Mdot
.43245 .55138 Mdot
.44395 .61718 Mdot
.55458 .31137 Mdot
.56963 .32744 Mdot
.32927 .42964 Mdot
.78844 .41477 Mdot
.59769 .388 Mdot
.53166 .33923 Mdot
.54877 .67373 Mdot
.56713 .65167 Mdot
.79054 .43573 Mdot
.54592 .68058 Mdot
.53623 .43677 Mdot
.33151 .42879 Mdot
.52946 .35824 Mdot
.32767 .45673 Mdot
.5946 .38531 Mdot
.33941 .39281 Mdot
.31739 .46073 Mdot
.44494 .6717 Mdot
.53445 .35116 Mdot
.59494 .29133 Mdot
.57692 .34724 Mdot
.57243 .39672 Mdot
.55903 .62343 Mdot
.65312 .53519 Mdot
.50142 .42307 Mdot
.63489 .52112 Mdot
.67738 .55813 Mdot
.41911 .44748 Mdot
.53667 .62496 Mdot
.66845 .53837 Mdot
.25359 .33847 Mdot
.5407 .61436 Mdot
.681 .53181 Mdot
.22419 .34552 Mdot
.3834 .6217 Mdot
.29887 .42679 Mdot
.52462 .37668 Mdot
.35539 .77867 Mdot
.59531 .22423 Mdot
.56634 .6945 Mdot
.53687 .40584 Mdot
.56851 .34597 Mdot
.35568 .47484 Mdot
.49405 .14767 Mdot
.59124 .60406 Mdot
.50999 .37507 Mdot
.35909 .45582 Mdot
.54184 .15599 Mdot
.56127 .67167 Mdot
.67878 .52957 Mdot
.40849 .57669 Mdot
.39307 .46735 Mdot
.378 .66838 Mdot
.43038 .59014 Mdot
.598 .65819 Mdot
.38228 .72642 Mdot
.52457 .33853 Mdot
.56951 .60712 Mdot
.58227 .80329 Mdot
.27037 .45753 Mdot
.43269 .64598 Mdot
.70017 .47954 Mdot
.32863 .44651 Mdot
.41571 .62842 Mdot
.64445 .53896 Mdot
.35623 .41362 Mdot
.31195 .44459 Mdot
.42429 .62994 Mdot
.44873 .42192 Mdot
.46731 .55542 Mdot
.38692 .61114 Mdot
.66528 .74195 Mdot
.32892 .73073 Mdot
.56982 .60567 Mdot
.67039 .5578 Mdot
.41134 .78641 Mdot
.35351 .43006 Mdot
.18049 .46851 Mdot
.59146 .79371 Mdot
.5393 .39595 Mdot
.66533 .543 Mdot
.24357 .60911 Mdot
.36293 .20616 Mdot
.40326 .62082 Mdot
.48108 .48428 Mdot
.64561 .55642 Mdot
.5739 .41525 Mdot
.65389 .4424 Mdot
.52704 .34887 Mdot
.42925 .60215 Mdot
.30401 .31223 Mdot
.32773 .45139 Mdot
.41314 .63776 Mdot
.5573 .80441 Mdot
.53564 .37389 Mdot
.53549 .34701 Mdot
.68141 .35712 Mdot
.362 .4257 Mdot
.58725 .61468 Mdot
.52875 .33581 Mdot
.54823 .37038 Mdot
.50619 .41934 Mdot
.61669 .30887 Mdot
.81872 .50055 Mdot
.51253 .36709 Mdot
.362 .68899 Mdot
.55793 .30883 Mdot
.53852 .35093 Mdot
.38347 .42007 Mdot
.81763 .35405 Mdot
.38271 .70735 Mdot
.54475 .37096 Mdot
.50843 .36227 Mdot
.43028 .62618 Mdot
.47758 .55148 Mdot
.5382 .56085 Mdot
.58043 .54344 Mdot
.73133 .48761 Mdot
.59685 .32799 Mdot
.36465 .4593 Mdot
.68422 .5183 Mdot
.52874 .32555 Mdot
.36212 .46005 Mdot
.56178 .42551 Mdot
.56639 .61797 Mdot
.53658 .61809 Mdot
.37217 .52981 Mdot
.67473 .53778 Mdot
.65893 .31051 Mdot
.303 .58643 Mdot
.55215 .67773 Mdot
.51775 .38658 Mdot
.43541 .57287 Mdot
.57172 .67907 Mdot
.605 .58182 Mdot
.62074 .41764 Mdot
.35287 .42139 Mdot
.32313 .44064 Mdot
.74695 .41232 Mdot
.49594 .72404 Mdot
.78099 .33608 Mdot
.41063 .59297 Mdot
.59359 .41088 Mdot
.29506 .53581 Mdot
.32177 .44261 Mdot
.70812 .32914 Mdot
.66904 .54039 Mdot
.40376 .62264 Mdot
.58111 .72498 Mdot
.33633 .46226 Mdot
.30286 .42805 Mdot
.50147 .38426 Mdot
.56137 .36661 Mdot
.74773 .48987 Mdot
.6557 .57277 Mdot
.43509 .61101 Mdot
.67327 .55644 Mdot
.59918 .63625 Mdot
.51157 .36554 Mdot
.35426 .47164 Mdot
.37961 .76167 Mdot
.51095 .35635 Mdot
.55892 .62129 Mdot
.3304 .44371 Mdot
.67916 .55262 Mdot
.68623 .55377 Mdot
.57154 .3956 Mdot
.35618 .24587 Mdot
.39705 .61249 Mdot
.32126 .44846 Mdot
.32639 .66283 Mdot
.60073 .36895 Mdot
.5596 .37268 Mdot
.60769 .31677 Mdot
.41887 .63077 Mdot
.33683 .53246 Mdot
.6366 .53697 Mdot
.35718 .44128 Mdot
.51729 .39895 Mdot
.68264 .53705 Mdot
.32182 .53264 Mdot
.54757 .68892 Mdot
.55105 .6176 Mdot
.69432 .54525 Mdot
.66346 .54973 Mdot
.69393 .54266 Mdot
.17905 .46556 Mdot
.30248 .45902 Mdot
.52667 .27694 Mdot
.59873 .39054 Mdot
.73417 .39244 Mdot
.52909 .44927 Mdot
.39082 .63844 Mdot
.53536 .63337 Mdot
.57168 .34041 Mdot
.50703 .35733 Mdot
.60556 .30474 Mdot
.56779 .27633 Mdot
.28596 .45535 Mdot
.34686 .45416 Mdot
.56761 .43064 Mdot
.53135 .64099 Mdot
.31591 .19083 Mdot
.30712 .77264 Mdot
.5208 .31436 Mdot
.50493 .56797 Mdot
.34969 .47182 Mdot
.44482 .60121 Mdot
.57898 .55837 Mdot
.37424 .60317 Mdot
.3515 .44014 Mdot
.51225 .36524 Mdot
.30936 .58807 Mdot
.69579 .54618 Mdot
.58731 .38454 Mdot
.42168 .61839 Mdot
.58314 .39273 Mdot
.429 .58905 Mdot
.26559 .69925 Mdot
.72523 .70515 Mdot
.53699 .3873 Mdot
.53291 .31372 Mdot
.72114 .49805 Mdot
.56969 .35664 Mdot
.64298 .48912 Mdot
.34123 .47117 Mdot
.75363 .3239 Mdot
.51197 .40867 Mdot
.41891 .28266 Mdot
.60132 .36778 Mdot
.798 .49159 Mdot
.56347 .37131 Mdot
.64134 .69041 Mdot
.55098 .41125 Mdot
.57026 .40759 Mdot
.3767 .60039 Mdot
.4271 .62855 Mdot
.3607 .40962 Mdot
.58877 .62558 Mdot
.18219 .59125 Mdot
.5544 .37175 Mdot
.43634 .75725 Mdot
.33505 .62717 Mdot
.66281 .55118 Mdot
.35251 .43801 Mdot
.49863 .14078 Mdot
.37097 .59714 Mdot
.75055 .62606 Mdot
.78425 .46305 Mdot
.37507 .67682 Mdot
.59656 .56316 Mdot
.22321 .47846 Mdot
.68742 .5396 Mdot
.57925 .41467 Mdot
.41841 .7736 Mdot
.63461 .72595 Mdot
.61798 .42547 Mdot
.42719 .63235 Mdot
.414 .32889 Mdot
.39698 .77389 Mdot
.63599 .55067 Mdot
.64003 .53498 Mdot
.41772 .58131 Mdot
.60219 .70937 Mdot
.50927 .30341 Mdot
.67031 .54282 Mdot
.54556 .67719 Mdot
.56107 .60375 Mdot
.49798 .65323 Mdot
.3529 .42492 Mdot
.52189 .80553 Mdot
.27374 .60738 Mdot
.43181 .59292 Mdot
.64073 .6046 Mdot
.34227 .48172 Mdot
.28931 .44013 Mdot
.57715 .64427 Mdot
.55357 .6255 Mdot
.29689 .42545 Mdot
.52319 .4242 Mdot
.58259 .29233 Mdot
.54135 .37149 Mdot
.66751 .52483 Mdot
.56797 .36762 Mdot
.56701 .62327 Mdot
.40624 .61695 Mdot
.54711 .6329 Mdot
.36933 .60995 Mdot
.29069 .66556 Mdot
.58372 .3773 Mdot
.55887 .40456 Mdot
.59093 .2192 Mdot
.38185 .42694 Mdot
.34618 .68897 Mdot
.42414 .75358 Mdot
.54615 .66333 Mdot
.57307 .40981 Mdot
.37762 .46034 Mdot
.63597 .52869 Mdot
.58797 .21585 Mdot
.58525 .34543 Mdot
.3498 .47108 Mdot
.51255 .38898 Mdot
.25778 .3581 Mdot
.82932 .57576 Mdot
.34319 .42811 Mdot
.66352 .2306 Mdot
.5068 .37714 Mdot
.24115 .43951 Mdot
.56736 .32105 Mdot
.76363 .45316 Mdot
.5979 .38596 Mdot
.35129 .41157 Mdot
.54432 .36642 Mdot
.37051 .43237 Mdot
.56805 .67169 Mdot
.43489 .58662 Mdot
.31026 .42865 Mdot
.55438 .32243 Mdot
.20756 .72857 Mdot
.42579 .59976 Mdot
.54483 .39312 Mdot
.38997 .58153 Mdot
.36746 .44967 Mdot
.30875 .42214 Mdot
.31444 .24056 Mdot
.39357 .70749 Mdot
.40707 .59458 Mdot
.51168 .3734 Mdot
.24739 .562 Mdot
.52702 .35539 Mdot
.73891 .45926 Mdot
.50251 .40951 Mdot
.59983 .3752 Mdot
.24338 .29919 Mdot
.42869 .62227 Mdot
.80034 .36792 Mdot
.29871 .2554 Mdot
.19386 .44555 Mdot
.39989 .45265 Mdot
.63348 .54411 Mdot
.16915 .51676 Mdot
.40089 .72493 Mdot
.57862 .62201 Mdot
.57415 .34366 Mdot
.327 .4818 Mdot
.39179 .6173 Mdot
.654 .53148 Mdot
.53755 .38798 Mdot
.5513 .62588 Mdot
.77552 .58613 Mdot
.3817 .57795 Mdot
.35465 .43222 Mdot
.31175 .45736 Mdot
.60906 .18626 Mdot
.52366 .40383 Mdot
.55955 .40725 Mdot
.42751 .59776 Mdot
.28639 .4832 Mdot
.68841 .54196 Mdot
.78043 .53239 Mdot
.40914 .59462 Mdot
.52016 .53037 Mdot
.35742 .45108 Mdot
.56999 .34732 Mdot
.21069 .56212 Mdot
.68699 .69767 Mdot
.49776 .235 Mdot
.67361 .52395 Mdot
.73181 .45563 Mdot
.34985 .41099 Mdot
.41503 .61761 Mdot
.49057 .73548 Mdot
.61398 .41 Mdot
.56492 .34835 Mdot
.72779 .44915 Mdot
.46967 .46149 Mdot
.67223 .28074 Mdot
.58986 .34763 Mdot
.5037 .48548 Mdot
.59537 .36619 Mdot
.60341 .42548 Mdot
.52583 .43098 Mdot
.55972 .38023 Mdot
.34923 .47138 Mdot
.60995 .43209 Mdot
.57894 .61505 Mdot
.60932 .2619 Mdot
.54011 .5265 Mdot
.53888 .4039 Mdot
.52126 .35547 Mdot
.48366 .2657 Mdot
.39192 .54688 Mdot
.31268 .43511 Mdot
.29286 .40967 Mdot
.43615 .58253 Mdot
.59628 .29775 Mdot
.59156 .62496 Mdot
.55826 .4505 Mdot
.55606 .62687 Mdot
.36739 .46638 Mdot
.55106 .66919 Mdot
.41782 .57683 Mdot
.56014 .60602 Mdot
.40123 .72981 Mdot
.40206 .6281 Mdot
.34957 .41599 Mdot
.56545 .39485 Mdot
.39038 .63435 Mdot
.68621 .37626 Mdot
.66853 .52495 Mdot
.3 .24857 Mdot
.5303 .41326 Mdot
.36254 .66103 Mdot
.36789 .50158 Mdot
.54931 .63172 Mdot
.83372 .51648 Mdot
.31486 .45797 Mdot
.6833 .50999 Mdot
.37235 .46444 Mdot
.68669 .74346 Mdot
.65468 .54139 Mdot
.21878 .35451 Mdot
.53423 .75289 Mdot
.61571 .53082 Mdot
.52233 .42228 Mdot
.63935 .45624 Mdot
.60201 .62525 Mdot
.39239 .61806 Mdot
.52102 .7369 Mdot
.5739 .40661 Mdot
.76027 .64845 Mdot
.34501 .40274 Mdot
.58695 .62255 Mdot
.4156 .61046 Mdot
.40113 .63735 Mdot
.57485 .33467 Mdot
.67432 .60233 Mdot
.59263 .37239 Mdot
.47197 .71026 Mdot
.72945 .47829 Mdot
.52636 .29163 Mdot
.54644 .40167 Mdot
.58109 .65488 Mdot
.51246 .38826 Mdot
.71651 .53881 Mdot
.51049 .81674 Mdot
.6055 .35257 Mdot
.41717 .74964 Mdot
.6568 .50017 Mdot
.34214 .44734 Mdot
.48557 .35414 Mdot
.41117 .71965 Mdot
.51737 .39698 Mdot
.82792 .66183 Mdot
.68169 .53369 Mdot
.45 .75768 Mdot
.58038 .322 Mdot
.55371 .32576 Mdot
.59971 .47703 Mdot
.41058 .41357 Mdot
.69253 .69509 Mdot
.56025 .35337 Mdot
.68685 .4433 Mdot
.40702 .58348 Mdot
.59142 .36289 Mdot
.54512 .38401 Mdot
.42658 .39927 Mdot
.40268 .6349 Mdot
.54117 .65164 Mdot
.5886 .66583 Mdot
.56445 .59349 Mdot
.7071 .52381 Mdot
.48975 .50114 Mdot
.72041 .35766 Mdot
.78363 .63514 Mdot
.68563 .51602 Mdot
.51104 .40202 Mdot
.71642 .50955 Mdot
.51527 .35339 Mdot
.64673 .54292 Mdot
.40231 .63358 Mdot
.31118 .43575 Mdot
.291 .51973 Mdot
.5986 .60923 Mdot
.58371 .33279 Mdot
.66546 .5615 Mdot
.3489 .41744 Mdot
.67671 .57248 Mdot
.35045 .4463 Mdot
.40941 .59821 Mdot
.4258 .57457 Mdot
.64974 .53411 Mdot
.36457 .4647 Mdot
.36591 .55717 Mdot
.36767 .20599 Mdot
.5204 .43052 Mdot
.46266 .63225 Mdot
.38421 .4354 Mdot
.29416 .41897 Mdot
.37074 .42197 Mdot
.57926 .39196 Mdot
.50244 .56665 Mdot
.49385 .37752 Mdot
.43512 .60937 Mdot
.5352 .64947 Mdot
.75088 .5433 Mdot
.32334 .7079 Mdot
.7195 .57573 Mdot
.59 .41529 Mdot
.5364 .36942 Mdot
.54657 .39167 Mdot
.49838 .38067 Mdot
.45879 .7142 Mdot
.5827 .35538 Mdot
.37821 .59595 Mdot
.56057 .63246 Mdot
.57667 .41693 Mdot
.55514 .69364 Mdot
.22609 .51635 Mdot
.67612 .51412 Mdot
.47483 .48774 Mdot
.17173 .65813 Mdot
.33887 .41479 Mdot
.5501 .68425 Mdot
.57915 .62407 Mdot
.69524 .53299 Mdot
.39221 .61216 Mdot
.35647 .44784 Mdot
.76287 .47628 Mdot
.68676 .55091 Mdot
.54574 .36802 Mdot
.52668 .58188 Mdot
.75008 .65516 Mdot
.58632 .40815 Mdot
.55172 .33346 Mdot
.54861 .69065 Mdot
.62142 .70235 Mdot
.52405 .84517 Mdot
.6909 .32358 Mdot
.65121 .53551 Mdot
.66022 .51446 Mdot
.29836 .41928 Mdot
.50205 .33261 Mdot
.43559 .60647 Mdot
.64993 .26854 Mdot
.42361 .46375 Mdot
.65964 .30385 Mdot
.48899 .46382 Mdot
.58424 .34683 Mdot
.44259 .1974 Mdot
.53429 .37466 Mdot
.33092 .4713 Mdot
.36808 .44089 Mdot
.32312 .42245 Mdot
.39508 .61693 Mdot
.37079 .33933 Mdot
.38008 .59652 Mdot
.19436 .67893 Mdot
.33999 .40947 Mdot
.46206 .73995 Mdot
.57922 .65505 Mdot
.53737 .30492 Mdot
.68115 .54979 Mdot
.3987 .64557 Mdot
.57106 .30324 Mdot
.8175 .48267 Mdot
.58309 .6187 Mdot
.34691 .41449 Mdot
.22509 .47038 Mdot
.23941 .69753 Mdot
.55781 .55506 Mdot
.53894 .45756 Mdot
.62881 .47231 Mdot
.66334 .55301 Mdot
.50264 .23278 Mdot
.65894 .56114 Mdot
.41562 .62406 Mdot
.55841 .40025 Mdot
.56185 .38999 Mdot
.59675 .37495 Mdot
.58378 .36501 Mdot
.44592 .59998 Mdot
.60414 .37446 Mdot
.80852 .64577 Mdot
.53197 .62499 Mdot
.27459 .36374 Mdot
.68519 .53739 Mdot
.44534 .6179 Mdot
.56113 .63049 Mdot
.55962 .7015 Mdot
.69604 .35606 Mdot
.5443 .40569 Mdot
.57385 .34202 Mdot
.74721 .64086 Mdot
.5913 .34884 Mdot
.51537 .44478 Mdot
.58091 .62332 Mdot
.72353 .57293 Mdot
.66691 .5103 Mdot
.64642 .52514 Mdot
.3912 .62846 Mdot
.36878 .46446 Mdot
.67058 .53228 Mdot
.56445 .67283 Mdot
.58792 .41851 Mdot
.53416 .32821 Mdot
.38219 .43166 Mdot
.60104 .79045 Mdot
.63917 .55335 Mdot
.22364 .48892 Mdot
.3731 .44434 Mdot
.31661 .47197 Mdot
.56333 .34751 Mdot
.63595 .3752 Mdot
.38952 .47446 Mdot
.69134 .5174 Mdot
.44777 .61445 Mdot
.58815 .54565 Mdot
.42936 .61124 Mdot
.36321 .43829 Mdot
.52336 .33173 Mdot
.3645 .43431 Mdot
.52967 .40576 Mdot
.1326 .5782 Mdot
.56303 .38214 Mdot
.78354 .64569 Mdot
.74433 .4292 Mdot
.57046 .63549 Mdot
.3479 .57785 Mdot
.58252 .63842 Mdot
.37232 .441 Mdot
.53229 .32548 Mdot
.63979 .53033 Mdot
.20739 .41144 Mdot
.32808 .47881 Mdot
.56508 .61538 Mdot
.57217 .59843 Mdot
.40583 .63047 Mdot
.58669 .41306 Mdot
.56928 .35029 Mdot
.56294 .64902 Mdot
.52991 .28803 Mdot
.33753 .46521 Mdot
.55343 .40358 Mdot
.53785 .35889 Mdot
.57254 .6357 Mdot
.3933 .19095 Mdot
.3689 .39234 Mdot
.55661 .39198 Mdot
.49993 .76542 Mdot
.39272 .63911 Mdot
.50936 .41266 Mdot
.56049 .30616 Mdot
.66604 .54801 Mdot
.3157 .36665 Mdot
.49182 .81387 Mdot
.38078 .62932 Mdot
.58659 .63716 Mdot
.52176 .40341 Mdot
.58266 .65117 Mdot
.54376 .32453 Mdot
.33221 .37576 Mdot
.58285 .60971 Mdot
.54155 .33033 Mdot
.49993 .33138 Mdot
.36366 .4273 Mdot
.57948 .34402 Mdot
.4801 .28565 Mdot
.58322 .66671 Mdot
.55845 .32738 Mdot
.3527 .24976 Mdot
.3868 .60402 Mdot
.50319 .32674 Mdot
.67833 .5178 Mdot
.76502 .47878 Mdot
.2966 .60844 Mdot
.44139 .76876 Mdot
.66645 .51563 Mdot
.58503 .39193 Mdot
.56383 .59797 Mdot
.42466 .58521 Mdot
.79126 .61368 Mdot
.58202 .40741 Mdot
.42879 .60262 Mdot
.40806 .61593 Mdot
.68119 .52253 Mdot
.72658 .25817 Mdot
.58974 .32639 Mdot
.57031 .35989 Mdot
.44317 .36552 Mdot
.38538 .46296 Mdot
.56811 .37399 Mdot
.50405 .37573 Mdot
.3806 .59152 Mdot
.50905 .44318 Mdot
.44051 .30299 Mdot
.78292 .50613 Mdot
.37586 .63517 Mdot
.58696 .52047 Mdot
.58612 .60596 Mdot
.68153 .54162 Mdot
.33862 .44209 Mdot
.65373 .56213 Mdot
.55223 .61203 Mdot
.50688 .39405 Mdot
.38017 .58484 Mdot
.5313 .25194 Mdot
.42097 .5822 Mdot
.44806 .76937 Mdot
.3852 .45475 Mdot
.27944 .53902 Mdot
.85527 .59716 Mdot
.27395 .61578 Mdot
.39037 .5489 Mdot
.66266 .55093 Mdot
.59211 .67946 Mdot
.53695 .36204 Mdot
.52178 .22735 Mdot
.56854 .39868 Mdot
.35706 .25017 Mdot
.5394 .67008 Mdot
.54591 .6087 Mdot
.55772 .39646 Mdot
.73258 .47412 Mdot
.43043 .58766 Mdot
.42419 .62512 Mdot
.56468 .33057 Mdot
.40285 .60165 Mdot
.56096 .36353 Mdot
.56141 .62406 Mdot
.8223 .40688 Mdot
.53965 .37897 Mdot
.51601 .32897 Mdot
.40929 .66602 Mdot
.25273 .29782 Mdot
.52683 .77987 Mdot
.48592 .19781 Mdot
.26789 .72599 Mdot
.40387 .60198 Mdot
.49259 .3709 Mdot
.5907 .51717 Mdot
.55432 .69464 Mdot
.3701 .55266 Mdot
.57017 .38366 Mdot
.57283 .38552 Mdot
.56722 .40995 Mdot
.53432 .34697 Mdot
.50503 .2257 Mdot
.5172 .27736 Mdot
.34115 .29188 Mdot
.57015 .33704 Mdot
.65845 .41275 Mdot
.38384 .6269 Mdot
.33907 .40018 Mdot
.66827 .5693 Mdot
.58397 .34686 Mdot
.52659 .27403 Mdot
.4029 .64104 Mdot
.19597 .6807 Mdot
.3986 .63056 Mdot
.54639 .65638 Mdot
.44351 .59787 Mdot
.5284 .3948 Mdot
.33861 .43467 Mdot
.55992 .53132 Mdot
.47173 .67925 Mdot
.57811 .62145 Mdot
.53465 .40257 Mdot
.44212 .7419 Mdot
.57774 .61635 Mdot
.22641 .52172 Mdot
.33388 .43729 Mdot
.68411 .43407 Mdot
.3681 .43956 Mdot
.54023 .33022 Mdot
.53295 .33583 Mdot
.45512 .62834 Mdot
.42871 .58326 Mdot
.36961 .44239 Mdot
.75417 .27725 Mdot
.66369 .56418 Mdot
.32981 .42095 Mdot
.60028 .42024 Mdot
.44101 .51755 Mdot
.33009 .43246 Mdot
.70705 .57574 Mdot
.39572 .62239 Mdot
.31804 .41099 Mdot
.61152 .40923 Mdot
.61585 .7695 Mdot
.69816 .52653 Mdot
.53304 .60998 Mdot
.53273 .58684 Mdot
.57591 .67494 Mdot
.4505 .59992 Mdot
.58135 .63464 Mdot
.40246 .58376 Mdot
.32534 .63053 Mdot
.62442 .27082 Mdot
.42925 .57158 Mdot
.44836 .59764 Mdot
.5791 .63484 Mdot
.55284 .40775 Mdot
.56073 .57197 Mdot
.49493 .38915 Mdot
.61316 .35057 Mdot
.39995 .58717 Mdot
.35285 .41297 Mdot
.29653 .43737 Mdot
.65545 .43424 Mdot
.31555 .46203 Mdot
.55538 .62609 Mdot
.81721 .59478 Mdot
.42096 .7667 Mdot
.41696 .589 Mdot
.44363 .61306 Mdot
.52546 .35484 Mdot
.56591 .65789 Mdot
.57859 .66217 Mdot
.41559 .62656 Mdot
.62399 .29162 Mdot
.50769 .33172 Mdot
.28983 .41985 Mdot
.3301 .4095 Mdot
.33689 .4277 Mdot
.37008 .42341 Mdot
.44596 .27169 Mdot
.39762 .62473 Mdot
.35761 .41547 Mdot
.55003 .32871 Mdot
.57228 .38378 Mdot
.57415 .53991 Mdot
.65338 .51908 Mdot
.5607 .42488 Mdot
.531 .43216 Mdot
.56478 .34516 Mdot
.55454 .61526 Mdot
.61297 .3348 Mdot
.58606 .61113 Mdot
.55019 .5992 Mdot
.5284 .64659 Mdot
.40168 .72651 Mdot
.64887 .47258 Mdot
.3119 .7618 Mdot
.50979 .37611 Mdot
.26182 .45034 Mdot
.57083 .66145 Mdot
.8274 .50213 Mdot
.33496 .52897 Mdot
.57704 .40943 Mdot
.67236 .70536 Mdot
.56529 .64759 Mdot
.31125 .45886 Mdot
.56806 .38292 Mdot
.54912 .59765 Mdot
.68839 .52121 Mdot
.57097 .4364 Mdot
.584 .67004 Mdot
.36625 .46211 Mdot
.70048 .55197 Mdot
.33676 .40742 Mdot
.53017 .65367 Mdot
.50113 .32971 Mdot
.53822 .88364 Mdot
.59455 .60182 Mdot
.2508 .33273 Mdot
.40039 .42129 Mdot
.55387 .40492 Mdot
.5582 .68483 Mdot
.38093 .46703 Mdot
.45135 .5939 Mdot
.43219 .47122 Mdot
.30828 .44399 Mdot
.5474 .60792 Mdot
.58056 .67286 Mdot
.58054 .62251 Mdot
.34071 .45349 Mdot
.51137 .33813 Mdot
.33455 .45686 Mdot
.44401 .60071 Mdot
.52592 .36903 Mdot
.20803 .66105 Mdot
.26732 .45794 Mdot
.37174 .44356 Mdot
.53996 .64482 Mdot
.69782 .54636 Mdot
.5343 .38545 Mdot
.27714 .30356 Mdot
.53799 .41083 Mdot
.4164 .58542 Mdot
.80454 .41689 Mdot
.52779 .2499 Mdot
.59895 .38641 Mdot
.526 .35405 Mdot
.43177 .61762 Mdot
.53953 .39822 Mdot
.59687 .39337 Mdot
.39924 .71954 Mdot
.34878 .45737 Mdot
.54235 .36484 Mdot
.53918 .66288 Mdot
.37816 .73334 Mdot
.50048 .34771 Mdot
.7307 .60456 Mdot
.69953 .44676 Mdot
.78048 .35679 Mdot
.56746 .40149 Mdot
.67568 .31161 Mdot
.54095 .34201 Mdot
.58693 .3814 Mdot
.51689 .36386 Mdot
.52948 .20787 Mdot
.5748 .6097 Mdot
.57152 .62536 Mdot
.69641 .52316 Mdot
.69656 .44631 Mdot
.66581 .54471 Mdot
.39147 .62306 Mdot
.70016 .61461 Mdot
.58265 .60996 Mdot
.36899 .46099 Mdot
.58956 .38489 Mdot
.59552 .60192 Mdot
.57282 .34917 Mdot
.52706 .3958 Mdot
.59396 .635 Mdot
.59584 .61186 Mdot
.44519 .76224 Mdot
.67708 .51567 Mdot
.31539 .4259 Mdot
.54712 .42648 Mdot
.67349 .55876 Mdot
.5211 .32925 Mdot
.7339 .38639 Mdot
.31766 .42648 Mdot
.3453 .45775 Mdot
.30061 .44495 Mdot
.5073 .39459 Mdot
.53193 .39428 Mdot
.382 .59431 Mdot
.373 .46119 Mdot
.38855 .60405 Mdot
.52957 .51584 Mdot
.74181 .59065 Mdot
.57028 .38373 Mdot
.2296 .4876 Mdot
.67618 .54879 Mdot
.54728 .64201 Mdot
.75731 .60704 Mdot
.69902 .52564 Mdot
.53457 .40743 Mdot
.58533 .64971 Mdot
.64571 .53636 Mdot
.58327 .46535 Mdot
.37374 .80714 Mdot
.69089 .556 Mdot
.55394 .32884 Mdot
.49026 .43297 Mdot
.50887 .18271 Mdot
.70531 .53598 Mdot
.39836 .57829 Mdot
.50927 .3983 Mdot
.35942 .49975 Mdot
.63989 .55283 Mdot
.34046 .684 Mdot
.56254 .63907 Mdot
.55027 .79354 Mdot
.59116 .31379 Mdot
.55972 .23157 Mdot
.65122 .55677 Mdot
.35676 .44505 Mdot
.353 .39804 Mdot
.55533 .34442 Mdot
.70542 .53708 Mdot
.37355 .63541 Mdot
.55649 .64064 Mdot
.38253 .70968 Mdot
.33765 .45339 Mdot
.25372 .52392 Mdot
.53917 .63569 Mdot
.23059 .50346 Mdot
.79756 .47267 Mdot
.55254 .29147 Mdot
.49774 .19399 Mdot
.56282 .72897 Mdot
.51181 .40534 Mdot
.66933 .56461 Mdot
.38331 .63111 Mdot
.40173 .57625 Mdot
.41286 .59616 Mdot
.33225 .62819 Mdot
.57509 .54821 Mdot
.54195 .68103 Mdot
.49819 .67463 Mdot
.68077 .53907 Mdot
.66505 .38332 Mdot
.54875 .31996 Mdot
.5371 .3711 Mdot
.58546 .41568 Mdot
.59043 .35533 Mdot
.54486 .34533 Mdot
.39415 .60645 Mdot
.33621 .64683 Mdot
.58986 .53206 Mdot
.32233 .42972 Mdot
.66465 .59556 Mdot
.57836 .65586 Mdot
.53424 .67419 Mdot
.6514 .5252 Mdot
.21628 .48698 Mdot
.55947 .69198 Mdot
.54747 .66658 Mdot
.54795 .41886 Mdot
.33822 .46202 Mdot
.57925 .4498 Mdot
.53238 .33933 Mdot
.5527 .63425 Mdot
.57878 .49568 Mdot
.4609 .28826 Mdot
.62693 .37425 Mdot
.71201 .5154 Mdot
.49997 .56062 Mdot
.7017 .54372 Mdot
.54082 .31897 Mdot
.82403 .48931 Mdot
.55531 .61036 Mdot
.55445 .66026 Mdot
.65723 .55788 Mdot
.27375 .40231 Mdot
.33264 .44581 Mdot
.56241 .70274 Mdot
.39452 .58138 Mdot
.52079 .3456 Mdot
.77111 .57944 Mdot
.26145 .41407 Mdot
.677 .60676 Mdot
.41671 .59429 Mdot
.57363 .66622 Mdot
.59412 .40671 Mdot
.55309 .32947 Mdot
.66893 .55518 Mdot
.24141 .65457 Mdot
.55979 .4359 Mdot
.18844 .45227 Mdot
.72404 .70941 Mdot
.61209 .77948 Mdot
.56499 .34854 Mdot
.34767 .45613 Mdot
.57502 .68043 Mdot
.67068 .55749 Mdot
.61118 .3863 Mdot
.35459 .79377 Mdot
.37141 .41503 Mdot
.41449 .62191 Mdot
.56987 .51791 Mdot
.57621 .55838 Mdot
.53391 .41505 Mdot
.5678 .39741 Mdot
.58165 .38499 Mdot
.4437 .82741 Mdot
.55531 .61813 Mdot
.35944 .4714 Mdot
.66991 .52144 Mdot
.31977 .46556 Mdot
.57299 .62937 Mdot
.26375 .53427 Mdot
.54753 .41143 Mdot
.37391 .41723 Mdot
.35388 .44428 Mdot
.40345 .63008 Mdot
.44946 .58989 Mdot
.54759 .51917 Mdot
.56263 .38028 Mdot
.60405 .60839 Mdot
.35893 .42011 Mdot
.53282 .57832 Mdot
.6553 .54331 Mdot
.37855 .61288 Mdot
.57262 .33933 Mdot
.56538 .6093 Mdot
.60446 .37445 Mdot
.32003 .44032 Mdot
.54885 .66767 Mdot
.44312 .75822 Mdot
.66377 .51409 Mdot
.57802 .37201 Mdot
.71039 .54088 Mdot
.58689 .63752 Mdot
.53622 .35989 Mdot
.22943 .44466 Mdot
.70055 .5058 Mdot
.44903 .68372 Mdot
.53639 .66892 Mdot
.43633 .75543 Mdot
.30027 .43591 Mdot
.32758 .59968 Mdot
.55106 .65813 Mdot
.21861 .46873 Mdot
.27964 .68546 Mdot
.57647 .42571 Mdot
.3499 .42816 Mdot
.59935 .69125 Mdot
.16232 .59618 Mdot
.38751 .19867 Mdot
.54473 .39105 Mdot
.54415 .67967 Mdot
.65772 .55642 Mdot
.4154 .58818 Mdot
.73382 .60273 Mdot
.71769 .51957 Mdot
.58733 .6021 Mdot
.51631 .36287 Mdot
.3651 .44946 Mdot
.39944 .61846 Mdot
.30428 .61575 Mdot
.55258 .67482 Mdot
.53556 .64253 Mdot
.59564 .40316 Mdot
.67004 .53965 Mdot
.32553 .25464 Mdot
.56455 .62199 Mdot
.74214 .65458 Mdot
.6034 .64242 Mdot
.66818 .5623 Mdot
.54539 .33663 Mdot
.64519 .45513 Mdot
.49916 .39328 Mdot
.23259 .35566 Mdot
.58092 .64306 Mdot
.3169 .43483 Mdot
.57548 .39878 Mdot
.78764 .48665 Mdot
.55157 .63834 Mdot
.50739 .56765 Mdot
.63552 .70337 Mdot
.39707 .6237 Mdot
.75781 .61027 Mdot
.57151 .36775 Mdot
.42788 .58631 Mdot
.67516 .5489 Mdot
.55706 .38613 Mdot
.53043 .39145 Mdot
.36086 .47496 Mdot
.41883 .62312 Mdot
.30657 .71925 Mdot
.41536 .63698 Mdot
.37468 .61304 Mdot
.31691 .46892 Mdot
.55252 .35707 Mdot
.54475 .65536 Mdot
.565 .64973 Mdot
.61502 .36879 Mdot
.83964 .48783 Mdot
.33138 .44774 Mdot
.63559 .60482 Mdot
.46684 .83413 Mdot
.54381 .29175 Mdot
.76097 .60218 Mdot
.23921 .64651 Mdot
.37005 .62837 Mdot
.56753 .33313 Mdot
.36882 .4566 Mdot
.55733 .70095 Mdot
.53677 .64472 Mdot
.51401 .33756 Mdot
.40409 .61373 Mdot
.69099 .52207 Mdot
.59614 .64173 Mdot
.67804 .60109 Mdot
.58547 .37462 Mdot
.67032 .71045 Mdot
.56503 .67984 Mdot
.16254 .47454 Mdot
.58466 .69559 Mdot
.34488 .42538 Mdot
.52583 .39253 Mdot
.30802 .45072 Mdot
.66401 .52302 Mdot
.56467 .52046 Mdot
.40503 .61572 Mdot
.46371 .37318 Mdot
.77204 .71426 Mdot
.58292 .62454 Mdot
.34238 .47147 Mdot
.5995 .38419 Mdot
.57594 .48049 Mdot
.56793 .36379 Mdot
.47464 .3989 Mdot
.6721 .49641 Mdot
.3951 .59077 Mdot
.41187 .58197 Mdot
.53241 .36373 Mdot
.6898 .54467 Mdot
.57017 .66793 Mdot
.55416 .6431 Mdot
.21138 .30961 Mdot
.45461 .66294 Mdot
.74992 .48729 Mdot
.57485 .38216 Mdot
.56049 .60174 Mdot
.33819 .71494 Mdot
.4264 .59661 Mdot
.56255 .32107 Mdot
.59068 .62363 Mdot
.64075 .74626 Mdot
.77254 .45361 Mdot
.54738 .34236 Mdot
.58118 .31477 Mdot
.39396 .58085 Mdot
.67188 .35859 Mdot
.52993 .64612 Mdot
.50227 .41051 Mdot
.40439 .56997 Mdot
.79271 .41355 Mdot
.55049 .81596 Mdot
.31578 .42539 Mdot
.62621 .70229 Mdot
.39355 .60735 Mdot
.6163 .35141 Mdot
.68684 .53219 Mdot
.59945 .63895 Mdot
.56109 .61339 Mdot
.51338 .37635 Mdot
.60361 .37548 Mdot
.72203 .50395 Mdot
.32866 .46713 Mdot
.38517 .62713 Mdot
.56213 .40404 Mdot
.27513 .50707 Mdot
.59651 .37119 Mdot
.38224 .59741 Mdot
.51583 .89736 Mdot
.55408 .4285 Mdot
.5678 .36101 Mdot
.32714 .25146 Mdot
.30778 .44238 Mdot
.32264 .46857 Mdot
.75458 .68075 Mdot
.57519 .38132 Mdot
.75425 .6281 Mdot
.31254 .42712 Mdot
.32805 .44575 Mdot
.40935 .70596 Mdot
.53575 .38108 Mdot
.62082 .24784 Mdot
.42663 .58826 Mdot
.37335 .60275 Mdot
.3339 .45537 Mdot
.55876 .43104 Mdot
.36876 .60242 Mdot
.46559 .23169 Mdot
.56747 .6575 Mdot
.82435 .47082 Mdot
.31722 .44649 Mdot
.48935 .48381 Mdot
.42051 .59359 Mdot
.19153 .67601 Mdot
.51639 .68439 Mdot
.55483 .40713 Mdot
.57955 .37551 Mdot
.67875 .54643 Mdot
.55738 .4278 Mdot
.54301 .61048 Mdot
.40248 .60144 Mdot
.29151 .3104 Mdot
.3244 .42176 Mdot
.56219 .37294 Mdot
.2237 .50402 Mdot
.29356 .65239 Mdot
.54492 .76344 Mdot
.34277 .44677 Mdot
.35149 .42517 Mdot
.53083 .64612 Mdot
.54742 .68158 Mdot
.55288 .3503 Mdot
.43036 .61682 Mdot
.37393 .45799 Mdot
.38848 .59123 Mdot
.55442 .61122 Mdot
.54311 .65691 Mdot
.5796 .60802 Mdot
.53527 .44195 Mdot
.545 .66745 Mdot
.70491 .58764 Mdot
.25364 .53305 Mdot
.28914 .44078 Mdot
.64451 .78912 Mdot
.30563 .61196 Mdot
.40763 .4795 Mdot
.63659 .53955 Mdot
.58727 .63743 Mdot
.44131 .61313 Mdot
.52978 .35408 Mdot
.57374 .34546 Mdot
.51736 .63296 Mdot
.44146 .60223 Mdot
.65623 .52886 Mdot
.43491 .58955 Mdot
.68236 .52286 Mdot
.64317 .71807 Mdot
.58279 .41536 Mdot
.53354 .32997 Mdot
.39753 .60151 Mdot
.54831 .66918 Mdot
.56462 .63069 Mdot
.69532 .55377 Mdot
.44413 .43388 Mdot
.57949 .61641 Mdot
.31761 .4448 Mdot
.43811 .26485 Mdot
.57733 .67661 Mdot
.56825 .37937 Mdot
.71872 .34931 Mdot
.53743 .23295 Mdot
.49797 .37803 Mdot
.4025 .71111 Mdot
.64133 .23289 Mdot
.58089 .3997 Mdot
.64336 .22357 Mdot
.43379 .75296 Mdot
.3093 .44924 Mdot
.53673 .66526 Mdot
.54107 .68807 Mdot
.48069 .39775 Mdot
.6504 .56897 Mdot
.61305 .38423 Mdot
.30714 .43736 Mdot
.3808 .41593 Mdot
.65261 .7519 Mdot
.24744 .33577 Mdot
.65118 .55297 Mdot
.64702 .52763 Mdot
.55194 .65575 Mdot
.36915 .19005 Mdot
.62186 .39764 Mdot
.65209 .53324 Mdot
.63205 .28033 Mdot
.51487 .3626 Mdot
.72968 .43899 Mdot
.722 .67348 Mdot
.34219 .45529 Mdot
.64173 .45479 Mdot
.54788 .65047 Mdot
.321 .46285 Mdot
.29416 .51649 Mdot
.54604 .42344 Mdot
.31958 .42536 Mdot
.38743 .59021 Mdot
.53842 .72615 Mdot
.30945 .42209 Mdot
.72571 .36258 Mdot
.41889 .62558 Mdot
.5284 .57801 Mdot
.66792 .42601 Mdot
.89234 .44829 Mdot
.39741 .60596 Mdot
.59509 .6202 Mdot
.56426 .6492 Mdot
.55391 .64481 Mdot
.32172 .46497 Mdot
.58065 .65842 Mdot
.33557 .46919 Mdot
.46084 .17415 Mdot
.44351 .43089 Mdot
.64989 .53623 Mdot
.39033 .70525 Mdot
.35718 .43698 Mdot
.8288 .56286 Mdot
.82727 .64123 Mdot
.57081 .33444 Mdot
.4333 .62543 Mdot
.64769 .54273 Mdot
.1929 .41598 Mdot
.66923 .54834 Mdot
.61647 .55467 Mdot
.8146 .43016 Mdot
.55863 .36833 Mdot
.4104 .34572 Mdot
.64324 .52579 Mdot
.35537 .45052 Mdot
.53574 .36351 Mdot
.3907 .54209 Mdot
.67199 .54449 Mdot
.69202 .5256 Mdot
.5458 .35365 Mdot
.34766 .41463 Mdot
.54364 .64811 Mdot
.43375 .58356 Mdot
.68828 .50957 Mdot
.31964 .39229 Mdot
.5213 .41478 Mdot
.51906 .40398 Mdot
.54365 .55573 Mdot
.68334 .57649 Mdot
.40384 .6026 Mdot
.57207 .21378 Mdot
.54399 .67759 Mdot
.6153 .67258 Mdot
.72312 .69928 Mdot
.40803 .72013 Mdot
.57974 .64177 Mdot
.58521 .63727 Mdot
.54821 .34552 Mdot
.70203 .57148 Mdot
.79575 .38893 Mdot
.35946 .57106 Mdot
.57163 .68319 Mdot
.5551 .64007 Mdot
.3695 .40809 Mdot
.66259 .75009 Mdot
.61013 .38827 Mdot
.37735 .62601 Mdot
.56572 .61039 Mdot
.3132 .37712 Mdot
.6735 .53684 Mdot
.82576 .53329 Mdot
.5817 .41504 Mdot
.55836 .40443 Mdot
.41471 .606 Mdot
.37909 .59747 Mdot
.46686 .59199 Mdot
.71037 .72064 Mdot
.61325 .228 Mdot
.31658 .63847 Mdot
.38618 .38484 Mdot
.35702 .40479 Mdot
.37153 .44276 Mdot
.36359 .68624 Mdot
.41006 .63937 Mdot
.57907 .39846 Mdot
.37182 .45889 Mdot
.53628 .74717 Mdot
.27664 .46603 Mdot
.73748 .46166 Mdot
.75641 .56848 Mdot
.53136 .40544 Mdot
.3496 .46224 Mdot
.31006 .44448 Mdot
.37781 .44527 Mdot
.43187 .75052 Mdot
.56078 .35363 Mdot
.54483 .40278 Mdot
.58926 .39316 Mdot
.60869 .2908 Mdot
.58451 .35986 Mdot
.33918 .62521 Mdot
.52187 .53378 Mdot
.29377 .35177 Mdot
.51047 .4187 Mdot
.36893 .61844 Mdot
.52889 .41395 Mdot
.69143 .54194 Mdot
.51974 .36014 Mdot
.74245 .46459 Mdot
.42526 .60999 Mdot
.3837 .40193 Mdot
.31817 .62246 Mdot
.55877 .41589 Mdot
.68002 .51319 Mdot
.4245 .44457 Mdot
.26158 .69843 Mdot
.64694 .57169 Mdot
.31804 .4455 Mdot
.57334 .65321 Mdot
.44096 .61146 Mdot
.54773 .66194 Mdot
.54147 .44227 Mdot
.37878 .68554 Mdot
.24338 .6022 Mdot
.53062 .50657 Mdot
.58674 .35074 Mdot
.59678 .30911 Mdot
.32206 .44441 Mdot
.58584 .64891 Mdot
.28653 .46376 Mdot
.57697 .39408 Mdot
.67101 .52362 Mdot
.67629 .54346 Mdot
.38703 .53333 Mdot
.18485 .55487 Mdot
.33832 .57339 Mdot
.41272 .60399 Mdot
.56419 .61986 Mdot
.65616 .56125 Mdot
.25044 .45191 Mdot
.45397 .59642 Mdot
.43193 .61809 Mdot
.41089 .62558 Mdot
.50664 .37081 Mdot
.586 .61077 Mdot
.29491 .34464 Mdot
.55534 .60422 Mdot
.53713 .40019 Mdot
.55079 .62018 Mdot
.58693 .62081 Mdot
.68459 .54085 Mdot
.39289 .62988 Mdot
.54143 .62005 Mdot
.54058 .32966 Mdot
.32652 .41692 Mdot
.46424 .46047 Mdot
.75588 .43162 Mdot
.23698 .37334 Mdot
.2553 .37338 Mdot
.31702 .41406 Mdot
.17577 .60961 Mdot
.38886 .63903 Mdot
.62646 .29585 Mdot
.48258 .76674 Mdot
.51835 .33748 Mdot
.83999 .5591 Mdot
.54292 .68239 Mdot
.59513 .63046 Mdot
.54258 .33794 Mdot
.60301 .70987 Mdot
.56364 .36932 Mdot
.54199 .62426 Mdot
.6547 .59766 Mdot
.4961 .33281 Mdot
.55962 .67206 Mdot
.50093 .41088 Mdot
.53175 .38041 Mdot
.34315 .45653 Mdot
.56172 .6838 Mdot
.5675 .32262 Mdot
.18535 .37681 Mdot
.37873 .60369 Mdot
.43401 .74064 Mdot
.71678 .32849 Mdot
.39221 .60814 Mdot
.33086 .42224 Mdot
.61383 .35367 Mdot
.67213 .55255 Mdot
.36129 .43983 Mdot
.77764 .45658 Mdot
.64735 .52242 Mdot
.83251 .56981 Mdot
.32063 .45117 Mdot
.57327 .68006 Mdot
.68925 .53315 Mdot
.49313 .37485 Mdot
.59981 .63552 Mdot
.41764 .47848 Mdot
.57974 .64521 Mdot
.57021 .35096 Mdot
.37484 .70323 Mdot
.38078 .62302 Mdot
.54621 .38882 Mdot
.59399 .64447 Mdot
.39535 .72062 Mdot
.50728 .372 Mdot
.5352 .35056 Mdot
.60945 .78642 Mdot
.80413 .57896 Mdot
.65967 .54937 Mdot
.37904 .46623 Mdot
.54928 .32872 Mdot
.68572 .52106 Mdot
.67454 .67044 Mdot
.51723 .407 Mdot
.37563 .42186 Mdot
.62868 .35053 Mdot
.57614 .67116 Mdot
.3861 .61012 Mdot
.52068 .50709 Mdot
.68753 .52075 Mdot
.66991 .19341 Mdot
.56437 .60409 Mdot
.54675 .31763 Mdot
.58747 .34848 Mdot
.53468 .77842 Mdot
.31334 .45272 Mdot
.62478 .23976 Mdot
.57818 .37222 Mdot
.59958 .28574 Mdot
.55546 .38341 Mdot
.61839 .58742 Mdot
.3312 .44619 Mdot
.57039 .35824 Mdot
.23934 .5027 Mdot
.51139 .33091 Mdot
.68569 .51742 Mdot
.3606 .22212 Mdot
.51149 .40649 Mdot
.6535 .83902 Mdot
.74807 .62762 Mdot
.55727 .67302 Mdot
.36214 .69015 Mdot
.36571 .16389 Mdot
.32561 .62018 Mdot
.34298 .47052 Mdot
.23646 .62876 Mdot
.54418 .65519 Mdot
.34382 .69696 Mdot
.17179 .60966 Mdot
.52973 .37892 Mdot
.53417 .41512 Mdot
.61644 .54947 Mdot
.53466 .61654 Mdot
.60488 .61396 Mdot
.53016 .4364 Mdot
.61218 .41849 Mdot
.53925 .65537 Mdot
.55308 .32582 Mdot
.51592 .4335 Mdot
.44035 .58961 Mdot
.32261 .41316 Mdot
.40866 .58723 Mdot
.40263 .6323 Mdot
.44449 .2094 Mdot
.69249 .72685 Mdot
.38092 .6019 Mdot
.38245 .63413 Mdot
.73428 .44184 Mdot
.69911 .47842 Mdot
.6385 .55044 Mdot
.17749 .49488 Mdot
.55633 .64452 Mdot
.55866 .35604 Mdot
.30504 .4198 Mdot
.56942 .23397 Mdot
.72442 .63464 Mdot
.80352 .39673 Mdot
.57857 .39566 Mdot
.54987 .64391 Mdot
.43079 .75091 Mdot
.56431 .45241 Mdot
.60807 .6603 Mdot
.56103 .40739 Mdot
.59775 .60811 Mdot
.41748 .29891 Mdot
.22137 .48059 Mdot
.60597 .62098 Mdot
.28912 .41569 Mdot
.56158 .39796 Mdot
.31553 .44633 Mdot
.41279 .59162 Mdot
.68632 .54536 Mdot
.65835 .54637 Mdot
.53898 .35677 Mdot
.5793 .28985 Mdot
.65283 .71368 Mdot
.53359 .38573 Mdot
.51744 .36818 Mdot
.43379 .75311 Mdot
.51973 .36708 Mdot
.59047 .35833 Mdot
.59329 .37301 Mdot
.546 .31118 Mdot
.37393 .60949 Mdot
.22454 .50256 Mdot
.56883 .44414 Mdot
.54062 .44821 Mdot
.40956 .57398 Mdot
.25853 .67835 Mdot
.40628 .63466 Mdot
.21079 .66545 Mdot
.41323 .58462 Mdot
.65466 .53794 Mdot
.44724 .77923 Mdot
.58505 .29696 Mdot
.36293 .41899 Mdot
.45145 .60997 Mdot
.6738 .52024 Mdot
.40768 .59777 Mdot
.54127 .63011 Mdot
.4949 .82605 Mdot
.28372 .40871 Mdot
.65967 .27682 Mdot
.37561 .53284 Mdot
.46168 .67273 Mdot
.54502 .61437 Mdot
.33128 .45054 Mdot
.45537 .29987 Mdot
.59412 .36417 Mdot
.68557 .52194 Mdot
.54889 .34998 Mdot
.37641 .62032 Mdot
.55001 .64971 Mdot
.36232 .21635 Mdot
.66997 .55456 Mdot
.65014 .77962 Mdot
.5645 .63687 Mdot
.59393 .38885 Mdot
.37626 .62398 Mdot
.69452 .76521 Mdot
.40168 .58793 Mdot
.46459 .34346 Mdot
.3174 .40468 Mdot
.4854 .19406 Mdot
.35285 .43237 Mdot
.57077 .69812 Mdot
.5191 .8536 Mdot
.20289 .441 Mdot
.34231 .41448 Mdot
.48441 .65552 Mdot
.52436 .40454 Mdot
.52132 .40623 Mdot
.24289 .42929 Mdot
.3808 .46169 Mdot
.57481 .33776 Mdot
.44245 .75476 Mdot
.25737 .55905 Mdot
.77048 .60829 Mdot
.58278 .64712 Mdot
.56829 .36993 Mdot
.40528 .57157 Mdot
.4361 .592 Mdot
.56516 .60261 Mdot
.41205 .63472 Mdot
.54423 .40088 Mdot
.35561 .43577 Mdot
.59819 .59883 Mdot
.66215 .53539 Mdot
.2222 .33432 Mdot
.66037 .56538 Mdot
.57953 .64095 Mdot
.50346 .32739 Mdot
.54309 .6577 Mdot
.42098 .12213 Mdot
.5491 .40243 Mdot
.31255 .43018 Mdot
.52871 .34722 Mdot
.55917 .39494 Mdot
.5329 .41524 Mdot
.53917 .64257 Mdot
.65026 .25233 Mdot
.54621 .32697 Mdot
.40438 .61696 Mdot
.30492 .36283 Mdot
.53302 .41723 Mdot
.6383 .59655 Mdot
.71322 .46842 Mdot
.5052 .68177 Mdot
.30437 .41603 Mdot
.57192 .66381 Mdot
.33007 .41866 Mdot
.27063 .44422 Mdot
.33041 .42245 Mdot
.35007 .35724 Mdot
.44717 .3006 Mdot
.67615 .26269 Mdot
.34345 .25777 Mdot
.63951 .41782 Mdot
.37981 .46436 Mdot
.63879 .49178 Mdot
.37384 .44554 Mdot
.31309 .44812 Mdot
.32732 .85523 Mdot
.36623 .42563 Mdot
.57198 .3771 Mdot
.5602 .42169 Mdot
.28345 .62408 Mdot
.71465 .40831 Mdot
.52675 .36266 Mdot
.5411 .33329 Mdot
.68458 .5451 Mdot
.5605 .2802 Mdot
.38057 .68774 Mdot
.8065 .60876 Mdot
.30577 .66869 Mdot
.54644 .35151 Mdot
.54381 .32976 Mdot
.5955 .43862 Mdot
.68277 .79509 Mdot
.48038 .21482 Mdot
.38905 .4476 Mdot
.61877 .35608 Mdot
.21813 .38208 Mdot
.55978 .41325 Mdot
.50366 .37781 Mdot
.52973 .4057 Mdot
.54447 .65479 Mdot
.36574 .41137 Mdot
.61898 .38158 Mdot
.71924 .68905 Mdot
.55059 .41464 Mdot
.40505 .71878 Mdot
.47105 .15123 Mdot
.57218 .36736 Mdot
.34884 .40739 Mdot
.51242 .38961 Mdot
.32342 .45659 Mdot
.35636 .45553 Mdot
.51254 .32282 Mdot
.3674 .37633 Mdot
.35224 .4057 Mdot
.5363 .40015 Mdot
.54338 .64048 Mdot
.16905 .5012 Mdot
.57229 .35169 Mdot
.67311 .55834 Mdot
.57854 .37594 Mdot
.68275 .51276 Mdot
.51954 .37333 Mdot
.5697 .60311 Mdot
.52827 .24568 Mdot
.55451 .65834 Mdot
.52793 .17685 Mdot
.5866 .60792 Mdot
.61851 .78407 Mdot
.3862 .43643 Mdot
.38104 .70599 Mdot
.75491 .30065 Mdot
.42452 .73114 Mdot
.48785 .56685 Mdot
.48078 .53947 Mdot
.42999 .61763 Mdot
.30565 .4473 Mdot
.65785 .32633 Mdot
.53998 .75812 Mdot
.51894 .77202 Mdot
.5836 .61519 Mdot
.75035 .27637 Mdot
.81993 .4147 Mdot
.5259 .33946 Mdot
.39357 .3537 Mdot
.34746 .30008 Mdot
.51343 .40575 Mdot
.61328 .34922 Mdot
.52875 .61208 Mdot
.58214 .33831 Mdot
.26752 .50325 Mdot
.57765 .63672 Mdot
.67586 .52013 Mdot
.3146 .43915 Mdot
.69643 .5258 Mdot
.53232 .76198 Mdot
.47728 .54069 Mdot
.54717 .61823 Mdot
.52811 .31916 Mdot
.53334 .34211 Mdot
.33729 .45863 Mdot
.3432 .48625 Mdot
.36419 .4286 Mdot
.6524 .55245 Mdot
.5736 .63853 Mdot
.52469 .22305 Mdot
.55194 .3319 Mdot
.35166 .44288 Mdot
.46416 .56164 Mdot
.55596 .32928 Mdot
.39879 .59722 Mdot
.53717 .40888 Mdot
.33197 .41418 Mdot
.51984 .3673 Mdot
.35606 .43349 Mdot
.57048 .65683 Mdot
.57238 .41448 Mdot
.54561 .33897 Mdot
.67201 .77724 Mdot
.65738 .52929 Mdot
.38496 .45328 Mdot
.61129 .7094 Mdot
.59606 .36002 Mdot
.44873 .69733 Mdot
.56526 .39882 Mdot
.30024 .4853 Mdot
.53278 .32079 Mdot
.41847 .73992 Mdot
.60699 .39422 Mdot
.57202 .35257 Mdot
.41063 .5294 Mdot
.34294 .32187 Mdot
.36683 .48558 Mdot
.37266 .61965 Mdot
.37265 .42691 Mdot
.76438 .57957 Mdot
.56485 .69087 Mdot
.58367 .65577 Mdot
.68543 .35822 Mdot
.55958 .30886 Mdot
.55877 .36646 Mdot
.42402 .57399 Mdot
.65547 .51925 Mdot
.3453 .447 Mdot
.6812 .5225 Mdot
.7309 .69137 Mdot
.64314 .53974 Mdot
.52812 .66422 Mdot
.66918 .7083 Mdot
.49692 .22892 Mdot
.68437 .54485 Mdot
.34881 .41444 Mdot
.7424 .57545 Mdot
.51005 .34426 Mdot
.71089 .50364 Mdot
.67222 .52516 Mdot
.73551 .2519 Mdot
.5889 .35616 Mdot
.49342 .57004 Mdot
.38437 .60164 Mdot
.68702 .53421 Mdot
.42847 .61411 Mdot
.52971 .35965 Mdot
.44196 .68402 Mdot
.36213 .46889 Mdot
.37281 .58949 Mdot
.52694 .42444 Mdot
.64725 .53858 Mdot
.56715 .61154 Mdot
.45236 .62244 Mdot
.36893 .6069 Mdot
.23511 .64993 Mdot
.41564 .18887 Mdot
.57182 .63984 Mdot
.80005 .50177 Mdot
.42316 .58607 Mdot
.50476 .39426 Mdot
.57278 .27501 Mdot
.5548 .40761 Mdot
.33467 .60705 Mdot
.5756 .66058 Mdot
.25303 .58101 Mdot
.52892 .3447 Mdot
.58662 .38918 Mdot
.3739 .48157 Mdot
.56037 .65274 Mdot
.33628 .43319 Mdot
.37333 .43103 Mdot
.56947 .65651 Mdot
.34569 .42706 Mdot
.64858 .52009 Mdot
.26708 .5615 Mdot
.40917 .57875 Mdot
.40852 .61795 Mdot
.55422 .64145 Mdot
.55073 .67315 Mdot
.54704 .66539 Mdot
.5376 .40903 Mdot
.33799 .4469 Mdot
.52312 .38913 Mdot
.53239 .41429 Mdot
.41555 .40319 Mdot
.31606 .41239 Mdot
.52046 .39673 Mdot
.59716 .68941 Mdot
.71583 .52624 Mdot
.54371 .63623 Mdot
.38169 .60388 Mdot
.35401 .72753 Mdot
.3792 .64598 Mdot
.56711 .37295 Mdot
.63828 .74522 Mdot
.35395 .41884 Mdot
.67442 .54824 Mdot
.63323 .53814 Mdot
.66598 .54985 Mdot
.368 .57921 Mdot
.38122 .4528 Mdot
.80891 .60545 Mdot
.56598 .36789 Mdot
.54249 .55751 Mdot
.63727 .28015 Mdot
.64621 .72492 Mdot
.38031 .60594 Mdot
.54829 .32958 Mdot
.5132 .49994 Mdot
.47449 .27685 Mdot
.55637 .40388 Mdot
.49967 .3601 Mdot
.45844 .75204 Mdot
.63094 .3884 Mdot
.33099 .40197 Mdot
.73261 .71203 Mdot
.57992 .4214 Mdot
.28217 .39373 Mdot
.25795 .27115 Mdot
.56473 .38177 Mdot
.58261 .38712 Mdot
.56486 .34021 Mdot
.51848 .35775 Mdot
.34068 .40467 Mdot
.68331 .39559 Mdot
.39255 .63971 Mdot
.56509 .54738 Mdot
.3994 .57726 Mdot
.59989 .62068 Mdot
.23446 .51903 Mdot
.30243 .44309 Mdot
.67844 .54699 Mdot
.20558 .47902 Mdot
.77357 .66649 Mdot
.53074 .65009 Mdot
.44986 .23908 Mdot
.66529 .52661 Mdot
.50195 .38791 Mdot
.66774 .50874 Mdot
.58724 .61185 Mdot
.40131 .622 Mdot
.56712 .30908 Mdot
.36925 .43743 Mdot
.30761 .42421 Mdot
.57279 .33608 Mdot
.21432 .40307 Mdot
.39392 .59967 Mdot
.45768 .60034 Mdot
.5067 .3882 Mdot
.49518 .38774 Mdot
.33323 .43095 Mdot
.56024 .62734 Mdot
.77366 .51018 Mdot
.65379 .52414 Mdot
.59352 .34376 Mdot
.5163 .36139 Mdot
.7158 .71725 Mdot
.39035 .62251 Mdot
.52828 .65517 Mdot
.50967 .36324 Mdot
.33649 .6594 Mdot
.50989 .36339 Mdot
.59908 .44201 Mdot
.54478 .64 Mdot
.58737 .43221 Mdot
.5368 .32904 Mdot
.47323 .35308 Mdot
.43265 .5998 Mdot
.31572 .4291 Mdot
.28803 .44533 Mdot
.59762 .5156 Mdot
.40142 .59626 Mdot
.51676 .39365 Mdot
.3886 .61737 Mdot
.52447 .41127 Mdot
.57402 .33509 Mdot
.38226 .59774 Mdot
.33695 .43286 Mdot
.24961 .63977 Mdot
.22773 .50992 Mdot
.51974 .35524 Mdot
.59026 .41552 Mdot
.69634 .39517 Mdot
.70834 .28346 Mdot
.57341 .39809 Mdot
.32071 .41734 Mdot
.54646 .33383 Mdot
.42913 .60888 Mdot
.64039 .53651 Mdot
.32887 .41589 Mdot
.56867 .62656 Mdot
.53085 .63529 Mdot
.31917 .61972 Mdot
.5879 .62914 Mdot
.50751 .35357 Mdot
.26903 .43983 Mdot
.31536 .47061 Mdot
.24049 .30047 Mdot
.56735 .65534 Mdot
.64131 .52487 Mdot
.53528 .35288 Mdot
.61259 .77167 Mdot
.43124 .57616 Mdot
.69682 .81624 Mdot
.82583 .58178 Mdot
.66661 .56732 Mdot
.78645 .35942 Mdot
.60186 .6181 Mdot
.56898 .32783 Mdot
.68698 .54546 Mdot
.53224 .65229 Mdot
.51585 .3436 Mdot
.56258 .30526 Mdot
.63123 .2412 Mdot
.58128 .51978 Mdot
.38709 .61785 Mdot
.56469 .67599 Mdot
.62793 .54025 Mdot
.52494 .64449 Mdot
.30388 .42723 Mdot
.56926 .35405 Mdot
.55037 .29323 Mdot
.56484 .62554 Mdot
.53167 .62108 Mdot
.53114 .40279 Mdot
.30709 .44966 Mdot
.51805 .64017 Mdot
.54309 .35758 Mdot
.6436 .39146 Mdot
.29567 .41084 Mdot
.57872 .63173 Mdot
.59089 .38114 Mdot
.72792 .52974 Mdot
.56238 .63455 Mdot
.5443 .63379 Mdot
.57245 .33502 Mdot
.65229 .51736 Mdot
.59521 .40525 Mdot
.40658 .58295 Mdot
.60218 .2076 Mdot
.42581 .61448 Mdot
.73429 .59346 Mdot
.49404 .34712 Mdot
.42929 .66774 Mdot
.29999 .43034 Mdot
.62796 .56847 Mdot
.3811 .75691 Mdot
.52331 .43347 Mdot
.17963 .57073 Mdot
.48726 .48826 Mdot
.20339 .38836 Mdot
.37712 .78725 Mdot
.67526 .52934 Mdot
.41123 .59619 Mdot
.58208 .38731 Mdot
.44359 .6142 Mdot
.68136 .5527 Mdot
.51105 .18546 Mdot
.59211 .3735 Mdot
.32916 .44528 Mdot
.53805 .40496 Mdot
.3179 .44648 Mdot
.56455 .33118 Mdot
.56351 .45077 Mdot
.43199 .75923 Mdot
.7715 .45204 Mdot
.5171 .33763 Mdot
.51466 .83369 Mdot
.72239 .65989 Mdot
.66615 .52073 Mdot
.52744 .38849 Mdot
.56256 .69602 Mdot
.43937 .5986 Mdot
.2855 .49042 Mdot
.54336 .65356 Mdot
.39601 .63508 Mdot
.33447 .42625 Mdot
.57777 .65235 Mdot
.53498 .62084 Mdot
.59734 .41891 Mdot
.68974 .51777 Mdot
.40365 .62674 Mdot
.57351 .35822 Mdot
.59054 .36679 Mdot
.79021 .52422 Mdot
.71545 .63075 Mdot
.30955 .47262 Mdot
.75564 .72266 Mdot
.29579 .45544 Mdot
.65276 .53035 Mdot
.54252 .64789 Mdot
.56972 .39727 Mdot
.5442 .38763 Mdot
.38598 .71233 Mdot
.36755 .4684 Mdot
.5621 .51845 Mdot
.42371 .22404 Mdot
.5207 .63127 Mdot
.71062 .44815 Mdot
.3099 .43146 Mdot
.71125 .44616 Mdot
.63033 .53319 Mdot
.19323 .4903 Mdot
.76269 .46061 Mdot
.38346 .60546 Mdot
.70669 .44523 Mdot
.35884 .44849 Mdot
.52786 .34022 Mdot
.56754 .68476 Mdot
.58651 .62146 Mdot
.32249 .43222 Mdot
.56936 .59246 Mdot
.6839 .53956 Mdot
.58583 .37947 Mdot
.8031 .60079 Mdot
.30717 .5793 Mdot
.56035 .62099 Mdot
.5481 .45203 Mdot
.41321 .62459 Mdot
.57872 .33863 Mdot
.67005 .55853 Mdot
.39709 .61025 Mdot
.75141 .61359 Mdot
.25554 .56967 Mdot
.53528 .35862 Mdot
.63962 .76859 Mdot
.39955 .60042 Mdot
.76191 .34328 Mdot
.55043 .35519 Mdot
.4242 .58712 Mdot
.62562 .3907 Mdot
.55002 .7229 Mdot
.52276 .50075 Mdot
.17013 .60709 Mdot
.5405 .51422 Mdot
.58967 .66014 Mdot
.52044 .7169 Mdot
.50593 .74613 Mdot
.44337 .61187 Mdot
.52938 .62606 Mdot
.6794 .58034 Mdot
.42893 .61418 Mdot
.53653 .41746 Mdot
.56458 .39251 Mdot
.48308 .21084 Mdot
.48244 .49438 Mdot
.56995 .70468 Mdot
.33495 .54543 Mdot
.59659 .36413 Mdot
.56938 .42826 Mdot
.54462 .37988 Mdot
.37923 .41482 Mdot
.39407 .62039 Mdot
.59096 .8129 Mdot
.40221 .59403 Mdot
.8211 .53338 Mdot
.55501 .64575 Mdot
.57184 .66753 Mdot
.5706 .3705 Mdot
.51562 .58999 Mdot
.66661 .45058 Mdot
.54217 .39993 Mdot
.57612 .5664 Mdot
.34108 .23643 Mdot
.53214 .42387 Mdot
.30921 .40808 Mdot
.48455 .40823 Mdot
.34988 .39604 Mdot
.41118 .57855 Mdot
.67082 .53602 Mdot
.63316 .57247 Mdot
.40021 .62415 Mdot
.55713 .36709 Mdot
.40382 .67644 Mdot
.555 .39281 Mdot
.51851 .3484 Mdot
.82963 .51335 Mdot
.66324 .56557 Mdot
.5581 .66751 Mdot
.66273 .55161 Mdot
.31387 .45128 Mdot
.51754 .91068 Mdot
.65975 .51704 Mdot
.65899 .4527 Mdot
.54371 .18891 Mdot
.70567 .44141 Mdot
.30495 .42947 Mdot
.70342 .52943 Mdot
.38808 .60547 Mdot
.16139 .46683 Mdot
.68506 .25351 Mdot
.42508 .64302 Mdot
.54375 .36276 Mdot
.30724 .45442 Mdot
.3363 .41111 Mdot
.37528 .5869 Mdot
.35633 .45391 Mdot
.62276 .35772 Mdot
.52244 .34879 Mdot
.43934 .61905 Mdot
.29478 .61605 Mdot
.3687 .60786 Mdot
.26594 .53347 Mdot
.52954 .39317 Mdot
.31164 .42574 Mdot
.48263 .39639 Mdot
.39414 .42272 Mdot
.53017 .66308 Mdot
.50879 .40459 Mdot
.68338 .54138 Mdot
.41644 .66624 Mdot
.57041 .63816 Mdot
.63069 .74592 Mdot
.33357 .45753 Mdot
.4751 .61211 Mdot
.34621 .45694 Mdot
.37501 .47137 Mdot
.40585 .63266 Mdot
.3613 .46626 Mdot
.58378 .38547 Mdot
.5824 .69078 Mdot
.33099 .46253 Mdot
.41993 .60938 Mdot
.66589 .53981 Mdot
.3445 .42948 Mdot
.60088 .71116 Mdot
.54017 .34624 Mdot
.53599 .642 Mdot
.46489 .78463 Mdot
.32757 .47146 Mdot
.70095 .54249 Mdot
.58624 .64916 Mdot
.69456 .52792 Mdot
.30286 .25287 Mdot
.41463 .63867 Mdot
.80697 .41687 Mdot
.72503 .53749 Mdot
.36222 .4215 Mdot
.44902 .77729 Mdot
.56975 .39366 Mdot
.53786 .34777 Mdot
.69108 .51404 Mdot
.33702 .41109 Mdot
.1886 .45534 Mdot
.41213 .45433 Mdot
.26533 .57593 Mdot
.43292 .62975 Mdot
.58499 .80307 Mdot
.25748 .51523 Mdot
.40616 .17052 Mdot
.55269 .43594 Mdot
.60308 .61443 Mdot
.55908 .3747 Mdot
.36674 .74549 Mdot
.64822 .54343 Mdot
.62658 .6061 Mdot
.50727 .33156 Mdot
.56912 .66221 Mdot
.55722 .34253 Mdot
.40718 .51734 Mdot
.50292 .42806 Mdot
.63861 .53246 Mdot
.37616 .68952 Mdot
.3671 .42416 Mdot
.66281 .53239 Mdot
.56321 .60594 Mdot
.6833 .45106 Mdot
.52553 .33163 Mdot
.54921 .44317 Mdot
.51916 .64208 Mdot
.33131 .44889 Mdot
.57668 .67327 Mdot
.41151 .57973 Mdot
.67764 .53999 Mdot
.52935 .35303 Mdot
.53044 .3204 Mdot
.45026 .6989 Mdot
.40531 .62848 Mdot
.5548 .59763 Mdot
.40379 .58864 Mdot
.60428 .62365 Mdot
.59843 .40801 Mdot
.57386 .66604 Mdot
.55522 .32169 Mdot
.40254 .76047 Mdot
.82746 .51055 Mdot
.35701 .33092 Mdot
.57853 .65581 Mdot
.73132 .4743 Mdot
.42675 .60678 Mdot
.41362 .58611 Mdot
.53361 .20652 Mdot
.50138 .2875 Mdot
.78445 .57336 Mdot
.24485 .67861 Mdot
.40135 .57733 Mdot
.4179 .62027 Mdot
.5346 .64351 Mdot
.35311 .46833 Mdot
.35225 .47716 Mdot
.59904 .61214 Mdot
.71512 .3392 Mdot
.34543 .4469 Mdot
.17917 .52604 Mdot
.77071 .58771 Mdot
.61704 .38529 Mdot
.46666 .58308 Mdot
.67283 .54291 Mdot
.72448 .3654 Mdot
.40374 .52118 Mdot
.58408 .39161 Mdot
.70487 .72412 Mdot
.55592 .63216 Mdot
.67552 .34944 Mdot
.21278 .66652 Mdot
.5924 .36771 Mdot
.55696 .35524 Mdot
.55205 .37303 Mdot
.67501 .56602 Mdot
.53826 .25537 Mdot
.5898 .37376 Mdot
.71448 .33457 Mdot
.59563 .35524 Mdot
.51607 .46533 Mdot
.65943 .54833 Mdot
.55692 .47268 Mdot
.44886 .75885 Mdot
.74851 .67077 Mdot
.48244 .34659 Mdot
.41207 .58086 Mdot
.59139 .55485 Mdot
.4331 .59726 Mdot
.34773 .35203 Mdot
.7603 .45507 Mdot
.28654 .42847 Mdot
.58284 .39115 Mdot
.5797 .63991 Mdot
.33334 .41138 Mdot
.49762 .71718 Mdot
.41712 .91111 Mdot
.42104 .5827 Mdot
.46679 .12838 Mdot
.40752 .58547 Mdot
.5404 .61461 Mdot
.33159 .43029 Mdot
.44248 .29988 Mdot
.54169 .55479 Mdot
.34728 .42934 Mdot
.24632 .61324 Mdot
.38434 .47343 Mdot
.71719 .46306 Mdot
.30118 .45699 Mdot
.42264 .60809 Mdot
.36345 .594 Mdot
.58408 .30867 Mdot
.5732 .38275 Mdot
.47261 .53615 Mdot
.68527 .46671 Mdot
.57197 .3891 Mdot
.57605 .63816 Mdot
.75183 .31779 Mdot
.61213 .51093 Mdot
.3672 .45761 Mdot
.37577 .63576 Mdot
.55783 .35225 Mdot
.51204 .36323 Mdot
.52414 .3355 Mdot
.76796 .71869 Mdot
.19049 .48049 Mdot
.54631 .32715 Mdot
.59947 .36861 Mdot
.57539 .65527 Mdot
.65469 .5046 Mdot
.35209 .74251 Mdot
.46703 .42556 Mdot
.57479 .409 Mdot
.65786 .53607 Mdot
.65855 .56664 Mdot
.51476 .34456 Mdot
.71669 .68797 Mdot
.44777 .66782 Mdot
.57362 .35759 Mdot
.4855 .30942 Mdot
.52691 .75353 Mdot
.53361 .61864 Mdot
.56526 .62792 Mdot
.35352 .40973 Mdot
.58534 .62978 Mdot
.58549 .60579 Mdot
.45631 .27603 Mdot
.54027 .52282 Mdot
.38494 .56537 Mdot
.65292 .55318 Mdot
.5469 .39015 Mdot
.31547 .47373 Mdot
.34873 .66943 Mdot
.42329 .62354 Mdot
.35174 .42127 Mdot
.43641 .59448 Mdot
.6962 .55751 Mdot
.65768 .28098 Mdot
.58517 .61391 Mdot
.38304 .58403 Mdot
.25574 .56823 Mdot
.65739 .53923 Mdot
.39296 .63148 Mdot
.41497 .6785 Mdot
.53673 .41945 Mdot
.42054 .36667 Mdot
.53819 .39735 Mdot
.19696 .41949 Mdot
.39022 .62896 Mdot
.41333 .73555 Mdot
.5629 .36189 Mdot
.56289 .63737 Mdot
.61233 .42747 Mdot
.56243 .40815 Mdot
.57211 .62227 Mdot
.52658 .33921 Mdot
.6881 .55092 Mdot
.29542 .40733 Mdot
.57308 .54125 Mdot
.85483 .41948 Mdot
.69134 .51847 Mdot
.48659 .71041 Mdot
.5754 .39766 Mdot
.37051 .20897 Mdot
.34594 .43095 Mdot
.54662 .31952 Mdot
.65058 .43576 Mdot
.3303 .46609 Mdot
.33982 .41843 Mdot
.51327 .38002 Mdot
.38676 .59968 Mdot
.57195 .63473 Mdot
.65855 .54473 Mdot
.3068 .24144 Mdot
.53798 .3701 Mdot
.54573 .33666 Mdot
.66456 .52847 Mdot
.422 .61802 Mdot
.50893 .37158 Mdot
.47875 .79619 Mdot
.19029 .37776 Mdot
.42844 .62204 Mdot
.55316 .41845 Mdot
.42749 .3857 Mdot
.33835 .39267 Mdot
.58543 .17101 Mdot
.74491 .5559 Mdot
.56321 .66912 Mdot
.62994 .3792 Mdot
.57519 .88082 Mdot
.66964 .53787 Mdot
.78184 .63607 Mdot
.51435 .35253 Mdot
.5596 .33355 Mdot
.36167 .42619 Mdot
.52224 .3936 Mdot
.33269 .47026 Mdot
.83626 .39109 Mdot
.70891 .72886 Mdot
.32555 .45066 Mdot
.36932 .43398 Mdot
.64765 .45267 Mdot
.35471 .74273 Mdot
.32245 .43022 Mdot
.60292 .37776 Mdot
.25689 .39216 Mdot
.46697 .38979 Mdot
.68676 .51131 Mdot
.49627 .77368 Mdot
.38177 .40279 Mdot
.62895 .50866 Mdot
.24115 .648 Mdot
.37299 .39638 Mdot
.4697 .65445 Mdot
.40054 .58201 Mdot
.59402 .37925 Mdot
.58755 .62449 Mdot
.58177 .65774 Mdot
.49335 .41271 Mdot
.55109 .39558 Mdot
.32118 .45503 Mdot
.65083 .55459 Mdot
.44346 .6046 Mdot
.54083 .33386 Mdot
.61342 .51374 Mdot
.65905 .51873 Mdot
.35578 .46273 Mdot
.599 .2453 Mdot
.6385 .53012 Mdot
.51587 .44349 Mdot
.5796 .36583 Mdot
.53116 .40539 Mdot
.46762 .35842 Mdot
.37718 .60301 Mdot
.43857 .77432 Mdot
.57556 .41822 Mdot
.73124 .69213 Mdot
.44909 .44396 Mdot
.59677 .42913 Mdot
.34671 .45181 Mdot
.42964 .57502 Mdot
.54707 .68904 Mdot
.66231 .36722 Mdot
.53518 .36366 Mdot
.20223 .46081 Mdot
.45559 .21282 Mdot
.5373 .67635 Mdot
.37879 .46467 Mdot
.67169 .54887 Mdot
.54375 .39926 Mdot
.32898 .36461 Mdot
.56575 .38635 Mdot
.71628 .54575 Mdot
.54816 .63233 Mdot
.39796 .58309 Mdot
.20038 .38554 Mdot
.58098 .65878 Mdot
.33252 .41828 Mdot
.17223 .6579 Mdot
.30446 .45672 Mdot
.37636 .44519 Mdot
.34953 .37239 Mdot
.37976 .59532 Mdot
.60125 .87551 Mdot
.66026 .22434 Mdot
.49438 .37426 Mdot
.42813 .60127 Mdot
.32303 .43702 Mdot
.58062 .3417 Mdot
.29645 .42934 Mdot
.38244 .45456 Mdot
.59109 .41994 Mdot
.57573 .34486 Mdot
.23673 .51476 Mdot
.18231 .62317 Mdot
.67026 .55102 Mdot
.30775 .44361 Mdot
.64765 .35825 Mdot
.58463 .34551 Mdot
.56634 .36717 Mdot
.52721 .74243 Mdot
.64821 .51973 Mdot
.28287 .50234 Mdot
.51285 .35729 Mdot
.68249 .74884 Mdot
.48362 .40609 Mdot
.33816 .40392 Mdot
.42387 .62542 Mdot
.75154 .66243 Mdot
.35443 .56863 Mdot
.36135 .47069 Mdot
.66234 .55824 Mdot
.28874 .44847 Mdot
.65897 .45544 Mdot
.37221 .60253 Mdot
.33201 .41416 Mdot
.51948 .50592 Mdot
.40482 .60892 Mdot
.38716 .62523 Mdot
.30346 .36399 Mdot
.57577 .59637 Mdot
.68207 .56106 Mdot
.40712 .62582 Mdot
.6296 .3023 Mdot
.41877 .60161 Mdot
.55049 .22091 Mdot
.5711 .41551 Mdot
.68993 .33215 Mdot
.48852 .58121 Mdot
.59053 .30179 Mdot
.37889 .62073 Mdot
.67755 .55406 Mdot
.51067 .37622 Mdot
.36031 .45154 Mdot
.67405 .51765 Mdot
.44957 .63016 Mdot
.53963 .65361 Mdot
.3474 .45869 Mdot
.41629 .64059 Mdot
.30879 .43697 Mdot
.66061 .33244 Mdot
.58124 .19423 Mdot
.52587 .79682 Mdot
.54269 .55004 Mdot
.52231 .33805 Mdot
.28707 .70688 Mdot
.61246 .39454 Mdot
.5537 .39963 Mdot
.57774 .63297 Mdot
.68376 .35243 Mdot
.3358 .43284 Mdot
.19327 .39351 Mdot
.38972 .58179 Mdot
.73086 .71534 Mdot
.30962 .48341 Mdot
.5405 .32035 Mdot
.32874 .46243 Mdot
.30218 .45548 Mdot
.33564 .31989 Mdot
.53514 .68139 Mdot
.59752 .33061 Mdot
.60319 .33457 Mdot
.56264 .44047 Mdot
.38615 .62198 Mdot
.63858 .74176 Mdot
.59609 .64689 Mdot
.57002 .17928 Mdot
.55262 .62733 Mdot
.57594 .56406 Mdot
.3618 .46472 Mdot
.65929 .51617 Mdot
.56799 .36572 Mdot
.35159 .49085 Mdot
.36294 .47105 Mdot
.7139 .53088 Mdot
.68827 .53384 Mdot
.55026 .73035 Mdot
.38141 .59893 Mdot
.51734 .33535 Mdot
.59047 .38102 Mdot
.52248 .38501 Mdot
.54466 .40841 Mdot
.41733 .58049 Mdot
.51421 .39986 Mdot
.39204 .57129 Mdot
.61441 .27514 Mdot
.69376 .73269 Mdot
.5337 .51893 Mdot
.32468 .50005 Mdot
.36518 .45341 Mdot
.64006 .33537 Mdot
.52373 .44948 Mdot
.82334 .484 Mdot
.26681 .31802 Mdot
.52596 .42074 Mdot
.53401 .65849 Mdot
.5089 .28327 Mdot
.59068 .61927 Mdot
.53238 .12512 Mdot
.44567 .70368 Mdot
.17382 .59631 Mdot
.58766 .36026 Mdot
.53055 .74603 Mdot
.60966 .29377 Mdot
.61473 .37008 Mdot
.48424 .72361 Mdot
.333 .59819 Mdot
.26876 .61965 Mdot
.64535 .55608 Mdot
.54295 .34948 Mdot
.34045 .48036 Mdot
.5854 .38298 Mdot
.56334 .37176 Mdot
.51177 .35539 Mdot
.38219 .63233 Mdot
.58881 .32524 Mdot
.54079 .41216 Mdot
.65254 .70739 Mdot
.73245 .44815 Mdot
.5678 .67521 Mdot
.52379 .201 Mdot
.66334 .51674 Mdot
.32842 .45871 Mdot
.21034 .56197 Mdot
.38301 .60609 Mdot
.33937 .30988 Mdot
.53855 .4078 Mdot
.24169 .54013 Mdot
.43193 .63371 Mdot
.68032 .53989 Mdot
.58246 .67169 Mdot
.16409 .55478 Mdot
.57586 .64467 Mdot
.51089 .50118 Mdot
.56443 .64086 Mdot
.48377 .41634 Mdot
.32004 .45419 Mdot
.50947 .35607 Mdot
.40673 .6242 Mdot
.57861 .62566 Mdot
.70599 .39793 Mdot
.54619 .37913 Mdot
.56842 .65772 Mdot
.50915 .35739 Mdot
.66439 .28453 Mdot
.79674 .47513 Mdot
.57822 .60338 Mdot
.39079 .56822 Mdot
.41028 .61062 Mdot
.65011 .51937 Mdot
.34112 .46168 Mdot
.36332 .43145 Mdot
.39864 .60844 Mdot
.70636 .27095 Mdot
.57211 .40883 Mdot
.58365 .3465 Mdot
.73539 .69107 Mdot
.57781 .3888 Mdot
.70063 .46106 Mdot
.51677 .50101 Mdot
.36151 .45923 Mdot
.56763 .32857 Mdot
.5136 .36254 Mdot
.53554 .35553 Mdot
.65337 .30415 Mdot
.56154 .62429 Mdot
.58876 .39933 Mdot
.69049 .53297 Mdot
.57163 .69439 Mdot
.5803 .33935 Mdot
.56515 .44132 Mdot
.36211 .42973 Mdot
.7759 .68498 Mdot
.39906 .58632 Mdot
.55198 .61039 Mdot
.57319 .66457 Mdot
.50061 .77212 Mdot
.3971 .40105 Mdot
.52292 .5043 Mdot
.54378 .16989 Mdot
.43741 .75552 Mdot
.66317 .52386 Mdot
.48206 .62225 Mdot
.4682 .45576 Mdot
.5333 .6343 Mdot
.42979 .58634 Mdot
.57075 .41735 Mdot
.57413 .41045 Mdot
.8363 .55634 Mdot
.53281 .32237 Mdot
.67035 .54638 Mdot
.39012 .57397 Mdot
.3582 .44754 Mdot
.6799 .54154 Mdot
.41237 .58736 Mdot
.33343 .4501 Mdot
.54803 .42503 Mdot
.55964 .42488 Mdot
.35124 .42222 Mdot
.34346 .41267 Mdot
.57568 .36278 Mdot
.59238 .57843 Mdot
.36449 .41866 Mdot
.31143 .42314 Mdot
.58552 .61344 Mdot
.58469 .62099 Mdot
.59825 .41949 Mdot
.42413 .59675 Mdot
.53157 .41112 Mdot
.57882 .64772 Mdot
.64327 .54376 Mdot
.3425 .43473 Mdot
.51856 .35538 Mdot
.53479 .33741 Mdot
.65835 .53986 Mdot
.64888 .55675 Mdot
.68546 .53624 Mdot
.37019 .58818 Mdot
.52735 .38093 Mdot
.32803 .42666 Mdot
.38483 .59206 Mdot
.65918 .56701 Mdot
.65872 .51087 Mdot
.55049 .59517 Mdot
.56999 .39941 Mdot
.54781 .70201 Mdot
.50673 .90422 Mdot
.73856 .52789 Mdot
.53952 .68145 Mdot
.53252 .61158 Mdot
.71101 .42773 Mdot
.53654 .57542 Mdot
.39395 .60326 Mdot
.71026 .5677 Mdot
.62865 .56959 Mdot
.50911 .40387 Mdot
.58349 .4182 Mdot
.60745 .33719 Mdot
.68252 .52961 Mdot
.66839 .38051 Mdot
.29801 .43242 Mdot
.38695 .22915 Mdot
.66736 .5167 Mdot
.53283 .61868 Mdot
.57379 .59506 Mdot
.55155 .62804 Mdot
.56792 .42056 Mdot
.3589 .32531 Mdot
.61286 .45524 Mdot
.28889 .71562 Mdot
.38515 .62791 Mdot
.28354 .44257 Mdot
.33231 .23728 Mdot
.3459 .42037 Mdot
.59648 .61629 Mdot
.67569 .5209 Mdot
.32786 .41388 Mdot
.43688 .6065 Mdot
.41452 .62174 Mdot
.55821 .62334 Mdot
.55285 .6436 Mdot
.54061 .62887 Mdot
.37923 .4504 Mdot
.3602 .46618 Mdot
.53417 .36935 Mdot
.35266 .43825 Mdot
.82253 .60774 Mdot
.68914 .56068 Mdot
.53205 .61055 Mdot
.41127 .59484 Mdot
.31906 .44822 Mdot
.5437 .38222 Mdot
.59803 .52515 Mdot
.32335 .59134 Mdot
.69567 .53217 Mdot
.79319 .50663 Mdot
.529 .12751 Mdot
.52072 .33035 Mdot
.3881 .62103 Mdot
.80137 .59806 Mdot
.54974 .37265 Mdot
.54478 .64673 Mdot
.40519 .76968 Mdot
.56516 .69095 Mdot
.53298 .41412 Mdot
.50688 .34327 Mdot
.41402 .63384 Mdot
.51865 .1779 Mdot
.53507 .3746 Mdot
.29947 .51804 Mdot
.37683 .63918 Mdot
.59814 .63921 Mdot
.18011 .39103 Mdot
.53116 .77792 Mdot
.71991 .35464 Mdot
.58357 .61195 Mdot
.5601 .39545 Mdot
.58094 .61408 Mdot
.69383 .53834 Mdot
.56432 .60946 Mdot
.3104 .40606 Mdot
.57434 .6727 Mdot
.5472 .33632 Mdot
.3201 .43098 Mdot
.39935 .59974 Mdot
.74381 .70402 Mdot
.6971 .67432 Mdot
.56184 .63764 Mdot
.56301 .60363 Mdot
.54408 .32603 Mdot
.25898 .49594 Mdot
.49757 .40974 Mdot
.58713 .35461 Mdot
.389 .57956 Mdot
.33391 .46409 Mdot
.39125 .63796 Mdot
.57721 .32569 Mdot
.46571 .79765 Mdot
.39794 .59005 Mdot
.2357 .53617 Mdot
.66498 .52599 Mdot
.42679 .50024 Mdot
.54464 .39064 Mdot
.41817 .62493 Mdot
.52779 .38228 Mdot
.29738 .42631 Mdot
.46749 .50029 Mdot
.35873 .68763 Mdot
.40521 .62227 Mdot
.20091 .43476 Mdot
.56638 .57762 Mdot
.50039 .32864 Mdot
.42684 .58956 Mdot
.64853 .43843 Mdot
.53612 .61881 Mdot
.6558 .52373 Mdot
.65466 .56411 Mdot
.69243 .52327 Mdot
.51708 .42516 Mdot
.48599 .34667 Mdot
.67835 .55977 Mdot
.43709 .61297 Mdot
.63687 .53919 Mdot
.28915 .38903 Mdot
.18926 .45148 Mdot
.6495 .54406 Mdot
.54725 .35669 Mdot
.5017 .30833 Mdot
.72982 .44011 Mdot
.57408 .71148 Mdot
.17872 .58812 Mdot
.29775 .49185 Mdot
.57164 .38291 Mdot
.29476 .39996 Mdot
.30293 .42413 Mdot
.79174 .60499 Mdot
.70364 .47674 Mdot
.73489 .66985 Mdot
.37149 .43598 Mdot
.37867 .70446 Mdot
.35301 .46214 Mdot
.53151 .32526 Mdot
.57951 .34282 Mdot
.36201 .47634 Mdot
.65651 .74294 Mdot
.45781 .68829 Mdot
.2248 .33476 Mdot
.30766 .42725 Mdot
.43334 .60167 Mdot
.39894 .57552 Mdot
.38254 .62242 Mdot
.77167 .57894 Mdot
.32054 .46626 Mdot
.52484 .37314 Mdot
.58015 .6517 Mdot
.58413 .40233 Mdot
.39988 .61485 Mdot
.19278 .39667 Mdot
.36387 .43882 Mdot
.57243 .35376 Mdot
.70791 .28665 Mdot
.54873 .65376 Mdot
.65639 .53413 Mdot
.64505 .26221 Mdot
.75376 .61647 Mdot
.37506 .60033 Mdot
.31966 .46933 Mdot
.41082 .72368 Mdot
.22726 .5298 Mdot
.55889 .4329 Mdot
.60977 .41208 Mdot
.36239 .19536 Mdot
.75169 .60912 Mdot
.5026 .36969 Mdot
.5424 .61572 Mdot
.38812 .71481 Mdot
.52773 .34831 Mdot
.30296 .43358 Mdot
.64 .55462 Mdot
.68871 .52367 Mdot
.60724 .36946 Mdot
.54316 .55873 Mdot
.43214 .4703 Mdot
.51691 .395 Mdot
.51652 .44418 Mdot
.59627 .62282 Mdot
.44051 .75478 Mdot
.72877 .70172 Mdot
.66045 .55887 Mdot
.50839 .36386 Mdot
.27017 .65136 Mdot
.37543 .4627 Mdot
.55443 .68379 Mdot
.371 .60785 Mdot
.63592 .27601 Mdot
.59829 .64085 Mdot
.52647 .34829 Mdot
.50971 .36925 Mdot
.39545 .63295 Mdot
.3377 .40385 Mdot
.68119 .52742 Mdot
.57977 .65533 Mdot
.66303 .5599 Mdot
.32728 .4665 Mdot
.36218 .44222 Mdot
.46899 .40563 Mdot
.53223 .30474 Mdot
.56705 .62802 Mdot
.58403 .33479 Mdot
.61273 .70606 Mdot
.51106 .17321 Mdot
.4517 .60945 Mdot
.51985 .33048 Mdot
.36967 .40949 Mdot
.40132 .62287 Mdot
.56801 .33867 Mdot
.321 .22374 Mdot
.58784 .34706 Mdot
.346 .58102 Mdot
.51521 .8058 Mdot
.68084 .54912 Mdot
.36213 .23766 Mdot
.2417 .44125 Mdot
.58 .38419 Mdot
.54675 .67178 Mdot
.58192 .44688 Mdot
.38843 .60071 Mdot
.3664 .46002 Mdot
.58798 .1685 Mdot
.4184 .60515 Mdot
.58736 .37126 Mdot
.67853 .54016 Mdot
.30891 .46254 Mdot
.6034 .57347 Mdot
.71366 .69581 Mdot
.48589 .37654 Mdot
.60337 .36692 Mdot
.52725 .40767 Mdot
.40248 .78749 Mdot
.55159 .61119 Mdot
.31958 .44161 Mdot
.38579 .62027 Mdot
.39598 .60888 Mdot
.55727 .62654 Mdot
.27364 .60802 Mdot
.42917 .49855 Mdot
.52303 .88719 Mdot
.57373 .62011 Mdot
.70387 .53616 Mdot
.27785 .50496 Mdot
.54776 .67412 Mdot
.56479 .65798 Mdot
.59607 .62428 Mdot
.36072 .57364 Mdot
.33614 .44865 Mdot
.53303 .33748 Mdot
.30407 .4161 Mdot
.56038 .39918 Mdot
.43902 .43645 Mdot
.40255 .62519 Mdot
.37043 .457 Mdot
.33109 .21944 Mdot
.47328 .3089 Mdot
.55065 .36503 Mdot
.35173 .22093 Mdot
.49946 .3426 Mdot
.69017 .4321 Mdot
.52889 .31239 Mdot
.55818 .64226 Mdot
.62559 .32937 Mdot
.52825 .43909 Mdot
.7762 .66888 Mdot
.41209 .59381 Mdot
.5301 .62937 Mdot
.4986 .38558 Mdot
.49002 .41994 Mdot
.36795 .47661 Mdot
.32133 .41654 Mdot
.67243 .56171 Mdot
.77256 .44778 Mdot
.39921 .59797 Mdot
.60834 .21601 Mdot
.57525 .37867 Mdot
.58702 .78156 Mdot
.34985 .25421 Mdot
.56832 .33995 Mdot
.23451 .41042 Mdot
.35101 .31907 Mdot
.54424 .39686 Mdot
.61957 .46783 Mdot
.42269 .61591 Mdot
.47692 .80132 Mdot
.60021 .36567 Mdot
.54419 .65213 Mdot
.35225 .46678 Mdot
.30021 .43968 Mdot
.68204 .55656 Mdot
.83151 .44319 Mdot
.39063 .63664 Mdot
.36859 .45981 Mdot
.54989 .38013 Mdot
.3774 .59772 Mdot
.58727 .6341 Mdot
.55442 .31527 Mdot
.71613 .48113 Mdot
.35353 .44135 Mdot
.59811 .35419 Mdot
.30545 .54574 Mdot
.74141 .40268 Mdot
.30818 .76996 Mdot
.38111 .61646 Mdot
.6421 .5316 Mdot
.58985 .44142 Mdot
.64494 .24395 Mdot
.52661 .42299 Mdot
.68622 .33101 Mdot
.34262 .38187 Mdot
.64152 .53162 Mdot
.55863 .35983 Mdot
.528 .35857 Mdot
.49539 .57832 Mdot
.64997 .55544 Mdot
.59203 .37947 Mdot
.5605 .26854 Mdot
.33083 .44759 Mdot
.59399 .65704 Mdot
.35092 .44556 Mdot
.54443 .36227 Mdot
.54716 .30119 Mdot
.35694 .41989 Mdot
.48791 .15136 Mdot
.64034 .5661 Mdot
.39467 .58838 Mdot
.51102 .31702 Mdot
.58308 .4136 Mdot
.51594 .84175 Mdot
.52918 .65951 Mdot
.32634 .71543 Mdot
.64155 .68335 Mdot
.25958 .65644 Mdot
.53476 .77605 Mdot
.16823 .633 Mdot
.71149 .72051 Mdot
.60562 .34008 Mdot
.38889 .49748 Mdot
.60696 .4659 Mdot
.37724 .62041 Mdot
.49713 .23677 Mdot
.57291 .38344 Mdot
.56158 .37359 Mdot
.55049 .68445 Mdot
.24944 .57736 Mdot
.73048 .6806 Mdot
.57106 .55316 Mdot
.67859 .52671 Mdot
.311 .4466 Mdot
.56016 .32937 Mdot
.58027 .50544 Mdot
.56405 .67774 Mdot
.59763 .7767 Mdot
.56808 .35387 Mdot
.81988 .48395 Mdot
.33952 .63309 Mdot
.37839 .60172 Mdot
.56583 .67155 Mdot
.75003 .63581 Mdot
.56769 .40277 Mdot
.37045 .59914 Mdot
.53753 .37857 Mdot
.50728 .62137 Mdot
.57526 .32691 Mdot
.64764 .53512 Mdot
.51627 .3464 Mdot
.58291 .55622 Mdot
.23622 .71714 Mdot
.70278 .56667 Mdot
.30627 .45183 Mdot
.52211 .65896 Mdot
.56252 .62533 Mdot
.3352 .41293 Mdot
.56279 .62819 Mdot
.34843 .28169 Mdot
.42874 .29667 Mdot
.67363 .52381 Mdot
.50456 .43517 Mdot
.65382 .54941 Mdot
.53102 .66607 Mdot
.56851 .3918 Mdot
.514 .15762 Mdot
.57378 .62758 Mdot
.53098 .81858 Mdot
.41488 .5997 Mdot
.52716 .64449 Mdot
.59641 .35624 Mdot
.41898 .72173 Mdot
.57679 .66564 Mdot
.36248 .68714 Mdot
.53521 .3573 Mdot
.36274 .44682 Mdot
.52582 .3563 Mdot
.50429 .32799 Mdot
.60463 .60962 Mdot
.54777 .41328 Mdot
.41259 .58745 Mdot
.37301 .42742 Mdot
.17053 .49807 Mdot
.33632 .60211 Mdot
.58627 .38922 Mdot
.54995 .37783 Mdot
.3238 .47444 Mdot
.59023 .40052 Mdot
.41687 .58041 Mdot
.82491 .69722 Mdot
.66427 .52625 Mdot
.56229 .60185 Mdot
.52515 .78199 Mdot
.53044 .42161 Mdot
.51105 .38994 Mdot
.29509 .24773 Mdot
.5192 .7905 Mdot
.42177 .58747 Mdot
.51432 .43138 Mdot
.58564 .6466 Mdot
.67643 .54127 Mdot
.43727 .61539 Mdot
.53042 .40462 Mdot
.56543 .3639 Mdot
.64316 .53056 Mdot
.28014 .37332 Mdot
.77134 .61077 Mdot
.38953 .63178 Mdot
.62046 .3164 Mdot
.62721 .6664 Mdot
.56791 .4089 Mdot
.7789 .57255 Mdot
.3254 .41638 Mdot
.37733 .59171 Mdot
.31937 .72858 Mdot
.5029 .38146 Mdot
.4255 .62303 Mdot
.40122 .59641 Mdot
.5206 .43437 Mdot
.39207 .42914 Mdot
.38185 .43992 Mdot
.30915 .43862 Mdot
.83629 .59979 Mdot
.72774 .38959 Mdot
.54057 .62908 Mdot
.42207 .61724 Mdot
.58692 .60559 Mdot
.70653 .53307 Mdot
.51372 .4912 Mdot
.57235 .60295 Mdot
.32711 .41155 Mdot
.52636 .67492 Mdot
.53073 .35575 Mdot
.39736 .60121 Mdot
.53478 .63186 Mdot
.49883 .39327 Mdot
.24254 .48955 Mdot
.54733 .71204 Mdot
.64792 .51729 Mdot
.64389 .55962 Mdot
.57583 .33847 Mdot
.54942 .6909 Mdot
.57443 .36413 Mdot
.43865 .58487 Mdot
.26576 .50393 Mdot
.51473 .41621 Mdot
.56046 .63604 Mdot
.29102 .4 Mdot
.75328 .61682 Mdot
.49118 .38341 Mdot
.5484 .35709 Mdot
.56012 .40496 Mdot
.53717 .37939 Mdot
.24993 .60066 Mdot
.43959 .62358 Mdot
.35561 .51911 Mdot
.44626 .77431 Mdot
.35363 .43066 Mdot
.38624 .43215 Mdot
.7527 .57068 Mdot
.47068 .65829 Mdot
.42623 .59937 Mdot
.55217 .40291 Mdot
.34171 .66 Mdot
.19008 .4047 Mdot
.45288 .14547 Mdot
.71077 .50877 Mdot
.5373 .67303 Mdot
.32866 .47267 Mdot
.56117 .67676 Mdot
.5621 .39283 Mdot
.59766 .43703 Mdot
.16529 .63422 Mdot
.36005 .61946 Mdot
.67849 .52273 Mdot
.55891 .403 Mdot
.72889 .38154 Mdot
.57639 .65467 Mdot
.58653 .59904 Mdot
.59356 .37083 Mdot
.35732 .40757 Mdot
.42169 .82557 Mdot
.37738 .60673 Mdot
.29758 .49359 Mdot
.62973 .31812 Mdot
.33985 .53245 Mdot
.39591 .61867 Mdot
.71545 .67816 Mdot
.545 .68498 Mdot
.30207 .31347 Mdot
.35626 .43083 Mdot
.67172 .51823 Mdot
.60283 .42169 Mdot
.36722 .43412 Mdot
.59439 .65237 Mdot
.36698 .45362 Mdot
.51461 .34615 Mdot
.40955 .64049 Mdot
.56058 .67083 Mdot
.37349 .57478 Mdot
.39089 .42977 Mdot
.66833 .5568 Mdot
.47518 .554 Mdot
.48951 .26528 Mdot
.34821 .31644 Mdot
.58377 .40547 Mdot
.57814 .50312 Mdot
.5239 .37746 Mdot
.38358 .4694 Mdot
.54166 .38096 Mdot
.27786 .40985 Mdot
.55184 .67391 Mdot
.59959 .36795 Mdot
.52064 .40188 Mdot
.49233 .22231 Mdot
.56136 .34953 Mdot
.58459 .32609 Mdot
.54621 .40038 Mdot
.30114 .47416 Mdot
.51431 .43886 Mdot
.34363 .4522 Mdot
.687 .70646 Mdot
.56257 .65731 Mdot
.64595 .55986 Mdot
.67449 .51397 Mdot
.69498 .33736 Mdot
.65726 .58856 Mdot
.26207 .59824 Mdot
.34216 .44258 Mdot
.40536 .59032 Mdot
.53933 .3834 Mdot
.25298 .69257 Mdot
.51457 .7551 Mdot
.59034 .63887 Mdot
.33619 .60268 Mdot
.62411 .3447 Mdot
.40906 .79383 Mdot
.59255 .34437 Mdot
.84217 .53801 Mdot
.55062 .29638 Mdot
.56881 .3239 Mdot
.59341 .60551 Mdot
.65252 .57195 Mdot
.59586 .38123 Mdot
.36641 .47719 Mdot
.64993 .52552 Mdot
.39537 .48351 Mdot
.6112 .66719 Mdot
.69342 .69355 Mdot
.46086 .25284 Mdot
.53051 .38163 Mdot
.55821 .6708 Mdot
.34559 .45862 Mdot
.72704 .70613 Mdot
.38662 .59018 Mdot
.47267 .62977 Mdot
.64505 .35305 Mdot
.4133 .18005 Mdot
.66054 .51816 Mdot
.29532 .36648 Mdot
.54618 .3356 Mdot
.73815 .59264 Mdot
.57169 .42641 Mdot
.19252 .40488 Mdot
.70361 .53193 Mdot
.37408 .41915 Mdot
.43215 .5993 Mdot
.30341 .41952 Mdot
.34946 .32945 Mdot
.46868 .58056 Mdot
.49422 .53043 Mdot
.57425 .64858 Mdot
.40009 .52699 Mdot
.31822 .43541 Mdot
.50723 .37312 Mdot
.51454 .89155 Mdot
.31555 .42059 Mdot
.34543 .47277 Mdot
.54672 .18604 Mdot
.51064 .1696 Mdot
.62678 .34533 Mdot
.3646 .42474 Mdot
.57056 .64969 Mdot
.66861 .55355 Mdot
.52023 .36333 Mdot
.53147 .36832 Mdot
.36309 .42927 Mdot
.58974 .60144 Mdot
.43966 .39117 Mdot
.55408 .64431 Mdot
.32981 .44947 Mdot
.55418 .6588 Mdot
.40988 .7395 Mdot
.53093 .64086 Mdot
.58421 .41218 Mdot
.541 .38179 Mdot
.62912 .69122 Mdot
.36202 .44248 Mdot
.51582 .39101 Mdot
.52916 .33586 Mdot
.3264 .42845 Mdot
.62033 .51701 Mdot
.42454 .39478 Mdot
.57912 .39521 Mdot
.54369 .3461 Mdot
.64074 .53618 Mdot
.53407 .49363 Mdot
.79138 .39961 Mdot
.51078 .37635 Mdot
.68617 .5607 Mdot
.37801 .45171 Mdot
.5756 .35872 Mdot
.20133 .50448 Mdot
.38643 .71403 Mdot
.50382 .37486 Mdot
.53351 .62317 Mdot
.54436 .44183 Mdot
.34581 .78965 Mdot
.58851 .35602 Mdot
.32685 .43395 Mdot
.33805 .46831 Mdot
.5924 .21743 Mdot
.3262 .41956 Mdot
.58632 .62144 Mdot
.4029 .61132 Mdot
.1985 .41505 Mdot
.58714 .63503 Mdot
.49636 .39582 Mdot
.65798 .22192 Mdot
.56542 .31424 Mdot
.50342 .4041 Mdot
.45644 .81867 Mdot
.58546 .63831 Mdot
.32303 .45949 Mdot
.51691 .57648 Mdot
.58986 .31829 Mdot
.37467 .60003 Mdot
.57248 .44693 Mdot
.56071 .41782 Mdot
.52165 .8044 Mdot
.33695 .68835 Mdot
.41107 .57433 Mdot
.61886 .3724 Mdot
.5107 .37832 Mdot
.54219 .70028 Mdot
.54601 .38321 Mdot
.65725 .55516 Mdot
.32137 .46465 Mdot
.53938 .66665 Mdot
.66081 .53874 Mdot
.57665 .38402 Mdot
.68331 .53112 Mdot
.53623 .64135 Mdot
.37315 .59479 Mdot
.56532 .3968 Mdot
.68694 .5111 Mdot
.67981 .52876 Mdot
.52121 .37998 Mdot
.36397 .46213 Mdot
.5687 .29402 Mdot
.57536 .35296 Mdot
.51792 .35283 Mdot
.36365 .43251 Mdot
.40489 .14102 Mdot
.58787 .3505 Mdot
.57363 .57725 Mdot
.35558 .47252 Mdot
.41112 .54368 Mdot
.53863 .66834 Mdot
.56432 .41788 Mdot
.37988 .58448 Mdot
.41085 .62741 Mdot
.59192 .61581 Mdot
.30341 .45986 Mdot
.63757 .68619 Mdot
.28666 .40258 Mdot
.55835 .30478 Mdot
.53422 .31659 Mdot
.69667 .25299 Mdot
.1676 .59138 Mdot
.30189 .43833 Mdot
.59063 .59583 Mdot
.56695 .54977 Mdot
.42677 .61424 Mdot
.54386 .60379 Mdot
.31583 .46817 Mdot
.31742 .46588 Mdot
.36199 .45623 Mdot
.68209 .52033 Mdot
.63505 .66801 Mdot
.33359 .40303 Mdot
.36007 .40933 Mdot
.53379 .35607 Mdot
.51112 .38326 Mdot
.66121 .47582 Mdot
.74435 .48609 Mdot
.67245 .55815 Mdot
.55224 .63035 Mdot
.78334 .72143 Mdot
.43686 .5845 Mdot
.48166 .22104 Mdot
.51499 .41591 Mdot
.46784 .92232 Mdot
.59177 .34708 Mdot
.54898 .38341 Mdot
.37213 .42799 Mdot
.6679 .50783 Mdot
.65188 .54052 Mdot
.31547 .43949 Mdot
.38592 .46458 Mdot
.6557 .55444 Mdot
.2449 .35551 Mdot
.1831 .45709 Mdot
.486 .58749 Mdot
.33578 .42905 Mdot
.47364 .277 Mdot
.37052 .61116 Mdot
.35312 .39703 Mdot
.44544 .5972 Mdot
.57061 .65871 Mdot
.55317 .69075 Mdot
.38587 .62248 Mdot
.53563 .35963 Mdot
.54429 .62087 Mdot
.58873 .32552 Mdot
.24734 .37845 Mdot
.39916 .36697 Mdot
.56606 .75539 Mdot
.60081 .4081 Mdot
.70365 .69441 Mdot
.47912 .66728 Mdot
.5836 .37391 Mdot
.22358 .60831 Mdot
.68087 .52475 Mdot
.34703 .39902 Mdot
.40826 .57683 Mdot
.3273 .78814 Mdot
.56164 .40817 Mdot
.3319 .43432 Mdot
.41458 .59251 Mdot
.65299 .2918 Mdot
.2934 .51635 Mdot
.56058 .40212 Mdot
.54467 .88502 Mdot
.3271 .48655 Mdot
.53791 .66314 Mdot
.75715 .31629 Mdot
.3005 .41828 Mdot
.67786 .49653 Mdot
.44807 .76584 Mdot
.34999 .21264 Mdot
.32774 .45814 Mdot
.54972 .59746 Mdot
.31136 .44386 Mdot
.66435 .55774 Mdot
.29028 .41466 Mdot
.57252 .66349 Mdot
.56134 .35402 Mdot
.5564 .63305 Mdot
.68011 .5559 Mdot
.76517 .57953 Mdot
.4024 .57567 Mdot
.53024 .62946 Mdot
.41196 .61703 Mdot
.75126 .41558 Mdot
.44039 .7846 Mdot
.39768 .5837 Mdot
.62621 .24508 Mdot
.50127 .37954 Mdot
.31869 .4077 Mdot
.56632 .6171 Mdot
.44551 .75827 Mdot
.50387 .56114 Mdot
.34798 .4254 Mdot
.54337 .63868 Mdot
.63916 .41024 Mdot
.68284 .26296 Mdot
.48035 .38961 Mdot
.76235 .44008 Mdot
.33186 .42681 Mdot
.5414 .6037 Mdot
.73623 .69089 Mdot
.31906 .41365 Mdot
.57322 .61879 Mdot
.43324 .60949 Mdot
.39468 .61292 Mdot
.59306 .38521 Mdot
.39988 .56303 Mdot
.54816 .62642 Mdot
.49938 .68155 Mdot
.37656 .46242 Mdot
.66051 .31202 Mdot
.68956 .51602 Mdot
.56012 .65147 Mdot
.53596 .32025 Mdot
.3823 .41033 Mdot
.39864 .72789 Mdot
.4518 .35726 Mdot
.74597 .74151 Mdot
.55686 .62739 Mdot
.32926 .46934 Mdot
.3376 .43515 Mdot
.49177 .38523 Mdot
.54156 .5522 Mdot
.6377 .6804 Mdot
.69408 .28987 Mdot
.67907 .32425 Mdot
.59975 .64189 Mdot
.60037 .65049 Mdot
.49714 .3684 Mdot
.53145 .38905 Mdot
.42988 .61018 Mdot
.55604 .35284 Mdot
.37362 .42399 Mdot
.59304 .39115 Mdot
.39482 .62194 Mdot
.57625 .6401 Mdot
.56678 .38977 Mdot
.67783 .55294 Mdot
.3808 .57949 Mdot
.41326 .63464 Mdot
.56128 .6446 Mdot
.36971 .43777 Mdot
.69584 .56541 Mdot
.55248 .64336 Mdot
.53099 .38073 Mdot
.42883 .6626 Mdot
.52397 .33572 Mdot
.2644 .33798 Mdot
.32506 .41132 Mdot
.5558 .67701 Mdot
.37497 .46713 Mdot
.41756 .61505 Mdot
.44484 .77278 Mdot
.54389 .36861 Mdot
.57616 .62068 Mdot
.62314 .69454 Mdot
.2579 .36433 Mdot
.33924 .47968 Mdot
.40452 .68103 Mdot
.38726 .44409 Mdot
.57989 .67329 Mdot
.54541 .20461 Mdot
.66036 .5207 Mdot
.58919 .64255 Mdot
.17177 .54677 Mdot
.56705 .63156 Mdot
.5622 .34546 Mdot
.56841 .3356 Mdot
.53491 .65893 Mdot
.65308 .51686 Mdot
.71388 .72503 Mdot
.49747 .64776 Mdot
.32574 .45979 Mdot
.39411 .203 Mdot
.66644 .79981 Mdot
.43853 .57187 Mdot
.43048 .59929 Mdot
.59222 .31936 Mdot
.56032 .32004 Mdot
.44401 .59875 Mdot
.3759 .63555 Mdot
.69787 .53595 Mdot
.59585 .62534 Mdot
.27668 .44844 Mdot
.36728 .60514 Mdot
.4655 .38633 Mdot
.67491 .59043 Mdot
.49197 .40202 Mdot
.63702 .35201 Mdot
.57937 .42159 Mdot
.68065 .31391 Mdot
.39018 .62227 Mdot
.56078 .32766 Mdot
.49277 .41056 Mdot
.37965 .58599 Mdot
.6607 .55616 Mdot
.32691 .66139 Mdot
.55072 .66317 Mdot
.20486 .32366 Mdot
.555 .32279 Mdot
.56646 .34553 Mdot
.38422 .62687 Mdot
.64953 .68731 Mdot
.3674 .44263 Mdot
.31928 .41221 Mdot
.54844 .61345 Mdot
.47671 .54968 Mdot
.57168 .41295 Mdot
.58402 .36276 Mdot
.54687 .66573 Mdot
.52749 .64149 Mdot
.51731 .71527 Mdot
.53667 .33781 Mdot
.41758 .59506 Mdot
.58866 .55172 Mdot
.39206 .62291 Mdot
.52957 .32703 Mdot
.56152 .34202 Mdot
.58481 .4112 Mdot
.532 .32285 Mdot
.41865 .63305 Mdot
.55584 .32762 Mdot
.48296 .33872 Mdot
.37125 .45076 Mdot
.54814 .41108 Mdot
.67464 .30947 Mdot
.54668 .3524 Mdot
.66569 .55455 Mdot
.46294 .35805 Mdot
.56315 .40607 Mdot
.56995 .41656 Mdot
.49833 .63949 Mdot
.55731 .364 Mdot
.43957 .58597 Mdot
.35192 .43411 Mdot
.42104 .61832 Mdot
.39326 .63119 Mdot
.57855 .6092 Mdot
.68048 .5583 Mdot
.53365 .42186 Mdot
.69376 .52935 Mdot
.55026 .43051 Mdot
.50279 .37438 Mdot
.48338 .77397 Mdot
.84462 .52418 Mdot
.77512 .60485 Mdot
.54261 .36865 Mdot
.58185 .62936 Mdot
.54362 .6739 Mdot
.35103 .50558 Mdot
.48173 .38931 Mdot
.44349 .6021 Mdot
.41626 .6256 Mdot
.71741 .47659 Mdot
.5126 .80229 Mdot
.66422 .55518 Mdot
.55606 .50499 Mdot
.58553 .32199 Mdot
.52535 .34197 Mdot
.5592 .31569 Mdot
.58377 .60448 Mdot
.56872 .56076 Mdot
.58912 .64076 Mdot
.33325 .61746 Mdot
.39707 .62547 Mdot
.55835 .40988 Mdot
.31429 .37692 Mdot
.32072 .41588 Mdot
.35258 .43475 Mdot
.42862 .6235 Mdot
.52029 .63765 Mdot
.70589 .49469 Mdot
.49724 .13499 Mdot
.297 .47345 Mdot
.65598 .5111 Mdot
.58438 .37947 Mdot
.57175 .63966 Mdot
.3062 .43521 Mdot
.63636 .54207 Mdot
.50739 .36447 Mdot
.63407 .67178 Mdot
.5391 .36904 Mdot
.60492 .467 Mdot
.3538 .46371 Mdot
.18803 .42504 Mdot
.30183 .45276 Mdot
.38535 .57715 Mdot
.39595 .58001 Mdot
.56526 .33736 Mdot
.71682 .27366 Mdot
.31297 .41083 Mdot
.37651 .55895 Mdot
.70261 .53238 Mdot
.40726 .71577 Mdot
.65551 .55699 Mdot
.5443 .67069 Mdot
.65313 .52241 Mdot
.5662 .67014 Mdot
.74191 .50769 Mdot
.3089 .47288 Mdot
.6622 .53141 Mdot
.52558 .60555 Mdot
.48141 .38073 Mdot
.64731 .55882 Mdot
.61051 .34026 Mdot
.32341 .27048 Mdot
.5441 .66032 Mdot
.67411 .51495 Mdot
.50779 .37193 Mdot
.22659 .68262 Mdot
.41364 .58612 Mdot
.44194 .59516 Mdot
.55554 .3054 Mdot
.59432 .61322 Mdot
.35523 .47767 Mdot
.21994 .54178 Mdot
.46089 .61774 Mdot
.57854 .34327 Mdot
.59539 .38355 Mdot
.38182 .42415 Mdot
.41397 .43299 Mdot
.56022 .33797 Mdot
.58118 .24973 Mdot
.54517 .33221 Mdot
.43501 .60927 Mdot
.30144 .42752 Mdot
.34417 .43481 Mdot
.54182 .63568 Mdot
.35936 .41597 Mdot
.26119 .4295 Mdot
.38066 .66802 Mdot
.59612 .3197 Mdot
.41754 .60744 Mdot
.35925 .65174 Mdot
.33313 .61519 Mdot
.18198 .59161 Mdot
.38533 .42637 Mdot
.59129 .40942 Mdot
.37445 .46477 Mdot
.67677 .54417 Mdot
.3596 .44423 Mdot
.33459 .47384 Mdot
.57832 .36615 Mdot
.55985 .39518 Mdot
.58183 .64079 Mdot
.54617 .55362 Mdot
.37441 .45191 Mdot
.57165 .33496 Mdot
.58305 .32647 Mdot
.58219 .32339 Mdot
.45052 .47262 Mdot
.30283 .43852 Mdot
.4708 .20914 Mdot
.66528 .40882 Mdot
.3744 .45054 Mdot
.37373 .81199 Mdot
.43769 .75739 Mdot
.52648 .65882 Mdot
.39883 .56715 Mdot
.53531 .33848 Mdot
.54005 .67367 Mdot
.5625 .39278 Mdot
.63688 .35037 Mdot
.5644 .36746 Mdot
.65004 .55159 Mdot
.60583 .34057 Mdot
.56771 .68554 Mdot
.55397 .63931 Mdot
.58502 .35031 Mdot
.56702 .38474 Mdot
.76505 .59269 Mdot
.38859 .45987 Mdot
.36685 .44595 Mdot
.63729 .70271 Mdot
.67014 .53224 Mdot
.37562 .59603 Mdot
.54355 .39198 Mdot
.57294 .60896 Mdot
.55445 .63554 Mdot
.29963 .42262 Mdot
.54492 .6488 Mdot
.37865 .61064 Mdot
.54486 .37174 Mdot
.44287 .59537 Mdot
.68634 .52198 Mdot
.30836 .44448 Mdot
.55643 .40691 Mdot
.53401 .35551 Mdot
.33741 .46815 Mdot
.51776 .41338 Mdot
.64089 .53762 Mdot
.56519 .63044 Mdot
.33213 .45772 Mdot
.40092 .61175 Mdot
.55344 .67494 Mdot
.52124 .3553 Mdot
.769 .72896 Mdot
.55676 .34469 Mdot
.52964 .3458 Mdot
.16281 .53936 Mdot
.60638 .34004 Mdot
.56172 .62033 Mdot
.36845 .41362 Mdot
.6035 .35853 Mdot
.70162 .35279 Mdot
.43169 .14349 Mdot
.59113 .63444 Mdot
.58637 .38085 Mdot
.1803 .63274 Mdot
.58839 .36757 Mdot
.62454 .22911 Mdot
.71837 .58223 Mdot
.42148 .52522 Mdot
.53563 .30052 Mdot
.38338 .60742 Mdot
.58272 .63894 Mdot
.54839 .67192 Mdot
.44182 .19742 Mdot
.58067 .36455 Mdot
.60071 .47562 Mdot
.51206 .39962 Mdot
.39469 .61703 Mdot
.68809 .46387 Mdot
.55471 .63051 Mdot
.78964 .63143 Mdot
.52546 .37433 Mdot
.3025 .44317 Mdot
.52407 .66874 Mdot
.424 .74475 Mdot
.51798 .35554 Mdot
.69251 .53172 Mdot
.37273 .58097 Mdot
.60473 .34688 Mdot
.41307 .60558 Mdot
.51839 .34714 Mdot
.4722 .41576 Mdot
.79406 .36165 Mdot
.36327 .45999 Mdot
.43281 .60399 Mdot
.4457 .65962 Mdot
.59164 .41994 Mdot
.33051 .45846 Mdot
.35524 .42982 Mdot
.69617 .53749 Mdot
.50732 .52274 Mdot
.29445 .54979 Mdot
.44139 .34816 Mdot
.43503 .19386 Mdot
.52167 .65937 Mdot
.44108 .68511 Mdot
.51589 .36695 Mdot
.5847 .77677 Mdot
.42272 .57643 Mdot
.56542 .34845 Mdot
.3264 .28175 Mdot
.3095 .43494 Mdot
.54446 .34207 Mdot
.65469 .55095 Mdot
.62213 .75156 Mdot
.61095 .76644 Mdot
.36635 .76828 Mdot
.5735 .65144 Mdot
.59474 .43802 Mdot
.60937 .43593 Mdot
.55554 .60557 Mdot
.52998 .41638 Mdot
.56712 .62118 Mdot
.29126 .27856 Mdot
.63915 .53393 Mdot
.3068 .4464 Mdot
.43388 .75388 Mdot
.55468 .42227 Mdot
.55135 .30948 Mdot
.63522 .55045 Mdot
.52927 .39432 Mdot
.83196 .45214 Mdot
.53881 .75236 Mdot
.53746 .62565 Mdot
.36251 .45709 Mdot
.56701 .42085 Mdot
.52705 .51519 Mdot
.57871 .3548 Mdot
.4191 .32572 Mdot
.57049 .41713 Mdot
.29861 .53371 Mdot
.35385 .46661 Mdot
.41412 .60911 Mdot
.56736 .43767 Mdot
.55901 .37249 Mdot
.60473 .52761 Mdot
.54295 .29958 Mdot
.58067 .33755 Mdot
.3506 .47918 Mdot
.30477 .42581 Mdot
.34299 .45127 Mdot
.57819 .6691 Mdot
.52015 .8014 Mdot
.42369 .60318 Mdot
.54897 .44505 Mdot
.36696 .61013 Mdot
.50292 .28334 Mdot
.64343 .52124 Mdot
.23135 .67225 Mdot
.53928 .40751 Mdot
.33841 .44539 Mdot
.28663 .66099 Mdot
.37918 .45131 Mdot
.55813 .5192 Mdot
.39876 .5985 Mdot
.3102 .42959 Mdot
.5528 .37873 Mdot
.5381 .56457 Mdot
.29708 .73451 Mdot
.41249 .62286 Mdot
.53492 .4268 Mdot
.53659 .67352 Mdot
.50896 .78411 Mdot
.75721 .74366 Mdot
.41973 .58629 Mdot
.44894 .65634 Mdot
.58277 .3664 Mdot
.32861 .4124 Mdot
.38141 .60916 Mdot
.4034 .58521 Mdot
.54323 .64725 Mdot
.55874 .39754 Mdot
.5565 .40114 Mdot
.56873 .68242 Mdot
.41008 .62629 Mdot
.51231 .3232 Mdot
.58021 .32962 Mdot
.16501 .64007 Mdot
.65304 .37405 Mdot
.26146 .24027 Mdot
.26101 .42503 Mdot
.31909 .30078 Mdot
.21726 .50843 Mdot
.3281 .46977 Mdot
.5648 .40597 Mdot
.60751 .39994 Mdot
.54836 .62715 Mdot
.55176 .35895 Mdot
.59079 .59824 Mdot
.42525 .59552 Mdot
.36525 .8031 Mdot
.31433 .62165 Mdot
.3056 .25652 Mdot
.55448 .35896 Mdot
.34449 .5758 Mdot
.66587 .54494 Mdot
.37821 .64357 Mdot
.33467 .45375 Mdot
.51413 .34483 Mdot
.76639 .59676 Mdot
.58884 .64252 Mdot
.34712 .41871 Mdot
.73205 .68281 Mdot
.70774 .68662 Mdot
.5283 .32782 Mdot
.56872 .67677 Mdot
.24887 .62803 Mdot
.58311 .25269 Mdot
.44654 .62002 Mdot
.65233 .55395 Mdot
.58207 .6495 Mdot
.40314 .63073 Mdot
.27426 .39658 Mdot
.31529 .42337 Mdot
.28388 .4274 Mdot
.78411 .54957 Mdot
.55449 .60363 Mdot
.66117 .54505 Mdot
.50932 .80031 Mdot
.59154 .78537 Mdot
.64958 .55045 Mdot
.55411 .68939 Mdot
.30477 .42958 Mdot
.32343 .44359 Mdot
.35076 .43353 Mdot
.77908 .64691 Mdot
.30015 .45398 Mdot
.44868 .23323 Mdot
.56628 .31377 Mdot
.51479 .45878 Mdot
.58777 .3771 Mdot
.44427 .60746 Mdot
.34398 .46443 Mdot
.46027 .55023 Mdot
.51939 .42953 Mdot
.35575 .77427 Mdot
.58285 .35401 Mdot
.40328 .64335 Mdot
.5388 .34127 Mdot
.47872 .23826 Mdot
.371 .46768 Mdot
.5456 .36363 Mdot
.44875 .60104 Mdot
.67789 .5332 Mdot
.28224 .41413 Mdot
.56015 .40456 Mdot
.25043 .57099 Mdot
.60811 .34254 Mdot
.24383 .34154 Mdot
.6652 .34116 Mdot
.65577 .51125 Mdot
.59794 .2825 Mdot
.56132 .59651 Mdot
.53375 .46849 Mdot
.55845 .45897 Mdot
.4098 .6219 Mdot
.39559 .75159 Mdot
.56437 .65624 Mdot
.73133 .53673 Mdot
.55149 .44913 Mdot
.67294 .5601 Mdot
.38259 .47522 Mdot
.43984 .61833 Mdot
.49937 .37378 Mdot
.50134 .41286 Mdot
.29011 .2908 Mdot
.50512 .43691 Mdot
.59221 .39584 Mdot
.63698 .53135 Mdot
.42585 .21513 Mdot
.54251 .35289 Mdot
.5525 .51696 Mdot
.28827 .42124 Mdot
.53237 .30641 Mdot
.49032 .21199 Mdot
.57384 .33765 Mdot
.34079 .41474 Mdot
.29653 .46252 Mdot
.29462 .62471 Mdot
.70087 .53709 Mdot
.56643 .41698 Mdot
.58498 .21882 Mdot
.52682 .37927 Mdot
.41645 .59645 Mdot
.55023 .31985 Mdot
.5754 .65824 Mdot
.77215 .64806 Mdot
.54431 .62523 Mdot
.57825 .40202 Mdot
.34539 .43111 Mdot
.38548 .62548 Mdot
.79168 .57073 Mdot
.66855 .61253 Mdot
.44197 .22849 Mdot
.32297 .22447 Mdot
.65958 .51488 Mdot
.66478 .56588 Mdot
.43465 .62389 Mdot
.54448 .36287 Mdot
.55684 .1948 Mdot
.55292 .29764 Mdot
.54222 .34577 Mdot
.56524 .36825 Mdot
.46368 .79293 Mdot
.42833 .60891 Mdot
.54824 .6562 Mdot
.55971 .33959 Mdot
.56423 .32988 Mdot
.33912 .47105 Mdot
.67842 .53034 Mdot
.54022 .67057 Mdot
.66973 .52422 Mdot
.57676 .63281 Mdot
.36279 .80665 Mdot
.5565 .44132 Mdot
.67544 .53464 Mdot
.40431 .57213 Mdot
.36283 .42998 Mdot
.38576 .67002 Mdot
.54447 .6701 Mdot
.55076 .63065 Mdot
.58118 .35 Mdot
.34243 .41409 Mdot
.3707 .43156 Mdot
.67809 .5442 Mdot
.39038 .58552 Mdot
.56525 .40224 Mdot
.50385 .36735 Mdot
.3625 .51356 Mdot
.58694 .60857 Mdot
.63398 .41924 Mdot
.27655 .62388 Mdot
.54223 .36647 Mdot
.36726 .42972 Mdot
.56988 .37567 Mdot
.20182 .46675 Mdot
.33684 .4114 Mdot
.58551 .34294 Mdot
.63786 .77641 Mdot
.60545 .58264 Mdot
.27408 .57681 Mdot
.59314 .40011 Mdot
.22806 .31303 Mdot
.51371 .37849 Mdot
.17856 .66495 Mdot
.71969 .61349 Mdot
.56522 .41117 Mdot
.52293 .3585 Mdot
.4152 .38323 Mdot
.5784 .38718 Mdot
.57425 .67952 Mdot
.7341 .52615 Mdot
.34432 .47662 Mdot
.24038 .51597 Mdot
.45037 .42996 Mdot
.70065 .52707 Mdot
.54722 .61422 Mdot
.598 .65989 Mdot
.64876 .53942 Mdot
.33243 .42949 Mdot
.53707 .37987 Mdot
.46315 .53168 Mdot
.60305 .62734 Mdot
.49251 .34475 Mdot
.41155 .59634 Mdot
.47426 .70934 Mdot
.53037 .61039 Mdot
.40674 .61037 Mdot
.53682 .41123 Mdot
.42126 .38879 Mdot
.78423 .48779 Mdot
.17483 .44786 Mdot
.38846 .63093 Mdot
.4042 .62713 Mdot
.76701 .67093 Mdot
.7 .52215 Mdot
.32276 .25615 Mdot
.29617 .52448 Mdot
.37637 .61261 Mdot
.62339 .26401 Mdot
.59402 .62844 Mdot
.25377 .56438 Mdot
.34668 .39888 Mdot
.53726 .31597 Mdot
.55434 .37656 Mdot
.38884 .58467 Mdot
.25381 .41025 Mdot
.78101 .34668 Mdot
.41049 .6176 Mdot
.47697 .34652 Mdot
.447 .4907 Mdot
.43955 .75785 Mdot
.58673 .61281 Mdot
.69934 .53877 Mdot
.67501 .50013 Mdot
.31985 .46021 Mdot
.69222 .54796 Mdot
.60987 .76092 Mdot
.53353 .40037 Mdot
.40331 .62007 Mdot
.40109 .72525 Mdot
.39929 .60905 Mdot
.65039 .53928 Mdot
.65544 .51073 Mdot
.37109 .45026 Mdot
.36589 .44695 Mdot
.32324 .31046 Mdot
.69545 .44547 Mdot
.58755 .36034 Mdot
.3094 .72065 Mdot
.37719 .46135 Mdot
.62389 .31373 Mdot
.6664 .56481 Mdot
.6748 .53163 Mdot
.64652 .43589 Mdot
.54908 .40198 Mdot
.59988 .22242 Mdot
.54735 .39768 Mdot
.6906 .45979 Mdot
.56489 .42669 Mdot
.54393 .6478 Mdot
.54996 .40569 Mdot
.67358 .5741 Mdot
.49873 .36246 Mdot
.56742 .32485 Mdot
.59226 .60933 Mdot
.60464 .35002 Mdot
.57345 .66021 Mdot
.58385 .3968 Mdot
.70575 .53518 Mdot
.56619 .60715 Mdot
.71969 .38135 Mdot
.55066 .57763 Mdot
.54526 .68704 Mdot
.68678 .54968 Mdot
.69138 .51898 Mdot
.71544 .33845 Mdot
.33316 .45369 Mdot
.3081 .39659 Mdot
.54697 .35951 Mdot
.58517 .59806 Mdot
.43067 .60622 Mdot
.55532 .32843 Mdot
.61461 .37383 Mdot
.59797 .37894 Mdot
.31246 .45392 Mdot
.6334 .69227 Mdot
.67855 .53803 Mdot
.58015 .6681 Mdot
.61636 .53776 Mdot
.59931 .62827 Mdot
.50432 .42715 Mdot
.60317 .41849 Mdot
.29708 .33374 Mdot
.33245 .70966 Mdot
.75075 .70622 Mdot
.32122 .41988 Mdot
.53175 .62647 Mdot
.69319 .51844 Mdot
.58123 .28806 Mdot
.33268 .44778 Mdot
.57287 .66281 Mdot
.53918 .37013 Mdot
.53703 .42777 Mdot
.37955 .65186 Mdot
.55223 .47261 Mdot
.68173 .34561 Mdot
.59832 .62794 Mdot
.55141 .59669 Mdot
.58799 .78411 Mdot
.73186 .52531 Mdot
.48963 .5579 Mdot
.5707 .35708 Mdot
.69205 .53007 Mdot
.30623 .43507 Mdot
.78355 .51536 Mdot
.41022 .57888 Mdot
.54365 .55344 Mdot
.55324 .36014 Mdot
.41344 .53459 Mdot
.34704 .43075 Mdot
.65874 .55325 Mdot
.38718 .58506 Mdot
.63586 .52309 Mdot
.56677 .60267 Mdot
.44643 .15884 Mdot
.52707 .385 Mdot
.58882 .35792 Mdot
.40355 .57471 Mdot
.31203 .44112 Mdot
.63183 .54441 Mdot
.25197 .353 Mdot
.53477 .64678 Mdot
.57291 .1983 Mdot
.36545 .4187 Mdot
.46516 .25724 Mdot
.58473 .66273 Mdot
.427 .6245 Mdot
.72593 .36341 Mdot
.39391 .6213 Mdot
.5782 .40674 Mdot
.3423 .44 Mdot
.41597 .58833 Mdot
.581 .53259 Mdot
.19891 .65456 Mdot
.47161 .27114 Mdot
.53941 .3969 Mdot
.26354 .72089 Mdot
.2276 .40463 Mdot
.3788 .4852 Mdot
.37989 .58402 Mdot
.57584 .35138 Mdot
.53383 .41611 Mdot
.52809 .37494 Mdot
.39766 .59431 Mdot
.47584 .76213 Mdot
.54236 .66006 Mdot
.58609 .37095 Mdot
.69755 .53426 Mdot
.5677 .66261 Mdot
.43098 .75466 Mdot
.55741 .62326 Mdot
.39174 .44668 Mdot
.55343 .31917 Mdot
.35021 .60323 Mdot
.25757 .74359 Mdot
.41892 .62014 Mdot
.54728 .68886 Mdot
.54346 .3258 Mdot
.38576 .73045 Mdot
.34083 .45015 Mdot
.53556 .64096 Mdot
.56701 .34609 Mdot
.45135 .74696 Mdot
.7688 .58757 Mdot
.55677 .62462 Mdot
.32415 .44878 Mdot
.19605 .5256 Mdot
.55395 .35484 Mdot
.5159 .38152 Mdot
.3149 .4369 Mdot
.45296 .41726 Mdot
.73651 .68468 Mdot
.56799 .38089 Mdot
.4128 .60982 Mdot
.56191 .16876 Mdot
.59881 .35131 Mdot
.65403 .43994 Mdot
.5824 .64382 Mdot
.27189 .60042 Mdot
.63931 .4051 Mdot
.61315 .3022 Mdot
.24822 .41081 Mdot
.46575 .46096 Mdot
.34301 .78179 Mdot
.57713 .59365 Mdot
.71558 .65932 Mdot
.34116 .78651 Mdot
.44336 .61802 Mdot
.35343 .3872 Mdot
.279 .47921 Mdot
.80839 .60374 Mdot
.20297 .54146 Mdot
.66174 .69703 Mdot
.76717 .60551 Mdot
.44539 .51262 Mdot
.57284 .62903 Mdot
.71765 .52846 Mdot
.56312 .39854 Mdot
.22639 .40349 Mdot
.54904 .23516 Mdot
.75574 .30276 Mdot
.25308 .71133 Mdot
.59712 .23029 Mdot
.24628 .68791 Mdot
.17937 .58052 Mdot
.29124 .32274 Mdot
.32091 .69763 Mdot
.59444 .19782 Mdot
.63192 .7733 Mdot
.45757 .17672 Mdot
.62395 .38729 Mdot
.57926 .506 Mdot
.26427 .29512 Mdot
.44086 .25529 Mdot
.71107 .2786 Mdot
.54079 .63314 Mdot
.36623 .41229 Mdot
.28178 .48601 Mdot
.3801 .47392 Mdot
.47523 .61992 Mdot
.1923 .50608 Mdot
.17072 .62313 Mdot
.48275 .23223 Mdot
.21285 .32413 Mdot
.35495 .25893 Mdot
.87462 .47048 Mdot
.52208 .688 Mdot
.30189 .41436 Mdot
.64106 .49947 Mdot
.57403 .7923 Mdot
.32412 .57778 Mdot
.25111 .44529 Mdot
.49825 .7787 Mdot
.7308 .42831 Mdot
.33289 .43364 Mdot
.62009 .28916 Mdot
.48643 .64886 Mdot
.32039 .6238 Mdot
.74583 .55537 Mdot
.18571 .56711 Mdot
.48811 .53997 Mdot
.24649 .5515 Mdot
.4618 .69093 Mdot
.76061 .73361 Mdot
.67006 .39177 Mdot
.26348 .39033 Mdot
.41672 .66152 Mdot
.20723 .48469 Mdot
.81832 .55834 Mdot
.71646 .45759 Mdot
.57945 .7907 Mdot
.51157 .82697 Mdot
.21376 .40243 Mdot
.54941 .8412 Mdot
.29797 .40023 Mdot
.59391 .39287 Mdot
.35395 .37032 Mdot
.56991 .22122 Mdot
.71001 .52306 Mdot
.3815 .77151 Mdot
.68124 .51729 Mdot
.39737 .44126 Mdot
.76609 .64968 Mdot
.46317 .23208 Mdot
.59393 .21377 Mdot
.63147 .55447 Mdot
.6008 .40782 Mdot
.65702 .16484 Mdot
.3336 .77128 Mdot
.29459 .61442 Mdot
.16544 .64484 Mdot
.44997 .55296 Mdot
.65254 .29408 Mdot
.41349 .58888 Mdot
.31031 .773 Mdot
.32885 .44138 Mdot
.4685 .8581 Mdot
.23296 .709 Mdot
.77718 .3583 Mdot
.3966 .11674 Mdot
.57212 .77058 Mdot
.4221 .52988 Mdot
.44452 .44622 Mdot
.70078 .37976 Mdot
.81266 .42023 Mdot
.74754 .32151 Mdot
.38082 .71977 Mdot
.29659 .25034 Mdot
.31063 .76779 Mdot
.56435 .21297 Mdot
.44925 .16497 Mdot
.8153 .59023 Mdot
.52837 .50363 Mdot
.3982 .42223 Mdot
.4872 .62605 Mdot
.22065 .61985 Mdot
.44584 .82303 Mdot
.66084 .41526 Mdot
.46495 .12662 Mdot
.6622 .57211 Mdot
.70795 .61991 Mdot
.17966 .47717 Mdot
.73999 .41507 Mdot
.64707 .31273 Mdot
.71702 .7067 Mdot
.48914 .36707 Mdot
.69452 .72591 Mdot
.26354 .68708 Mdot
.41839 .67006 Mdot
.6395 .76526 Mdot
.23401 .59043 Mdot
.27147 .31568 Mdot
.39677 .36077 Mdot
.56824 .79879 Mdot
.37461 .47213 Mdot
.71242 .43427 Mdot
.65778 .33656 Mdot
.16348 .62257 Mdot
.45153 .65493 Mdot
.14141 .56535 Mdot
.74802 .66046 Mdot
.5833 .42413 Mdot
.57346 .46027 Mdot
.50196 .30462 Mdot
.69408 .4301 Mdot
.58854 .3338 Mdot
.33204 .60649 Mdot
.16172 .58647 Mdot
.34513 .25845 Mdot
.3993 .67902 Mdot
.40066 .75889 Mdot
.17282 .45267 Mdot
.31198 .34846 Mdot
.74827 .60763 Mdot
.66854 .47009 Mdot
.80488 .65515 Mdot
.55945 .65929 Mdot
.55603 .20827 Mdot
.43431 .63048 Mdot
.76754 .54689 Mdot
.44917 .33549 Mdot
.80424 .42102 Mdot
.16135 .58514 Mdot
.68378 .70853 Mdot
.76292 .62846 Mdot
.75238 .40078 Mdot
.55355 .18379 Mdot
.39815 .76627 Mdot
.57845 .44463 Mdot
.2371 .46153 Mdot
.65798 .51364 Mdot
.3411 .32887 Mdot
.50001 .18894 Mdot
.66905 .64934 Mdot
.57685 .31097 Mdot
.78613 .45016 Mdot
.60346 .71094 Mdot
.53697 .56374 Mdot
.6281 .83021 Mdot
.48425 .39102 Mdot
.52537 .79208 Mdot
.2182 .38412 Mdot
.68606 .39702 Mdot
.19054 .46445 Mdot
.22864 .55177 Mdot
.53199 .83888 Mdot
.21164 .68574 Mdot
.65832 .62676 Mdot
.37581 .79637 Mdot
.15896 .62636 Mdot
.56831 .82909 Mdot
.51479 .44826 Mdot
.43412 .57898 Mdot
.67509 .82852 Mdot
.59044 .6587 Mdot
.46185 .79918 Mdot
.43576 .19391 Mdot
.45651 .743 Mdot
.27159 .43559 Mdot
.62318 .35437 Mdot
.45568 .51885 Mdot
.38291 .48045 Mdot
.59958 .34163 Mdot
.66958 .79448 Mdot
.54945 .82462 Mdot
.61115 .82384 Mdot
.22078 .35111 Mdot
.37815 .80235 Mdot
.40941 .51323 Mdot
.45073 .24608 Mdot
.37254 .49953 Mdot
.52281 .32895 Mdot
.69834 .57896 Mdot
.57231 .76894 Mdot
.79173 .4629 Mdot
.32088 .56101 Mdot
.38596 .46833 Mdot
.33877 .745 Mdot
.91026 .54662 Mdot
.34922 .27468 Mdot
.49272 .20636 Mdot
.60392 .77262 Mdot
.68587 .43495 Mdot
.23826 .64453 Mdot
.78934 .39071 Mdot
.1639 .55151 Mdot
.36248 .49833 Mdot
.44065 .18621 Mdot
.67086 .67948 Mdot
.66924 .27973 Mdot
.62718 .70594 Mdot
.18948 .63081 Mdot
.42139 .46558 Mdot
.8001 .51633 Mdot
.27731 .50322 Mdot
.77834 .35213 Mdot
.72894 .58987 Mdot
.48149 .70959 Mdot
.508 .18499 Mdot
.3624 .68989 Mdot
.67191 .44116 Mdot
.46232 .50249 Mdot
.55453 .28495 Mdot
.46336 .45951 Mdot
.66973 .43223 Mdot
.68151 .29754 Mdot
.42594 .81118 Mdot
.16044 .66352 Mdot
.74697 .73097 Mdot
.20015 .33787 Mdot
.2618 .67739 Mdot
.5301 .31687 Mdot
.16581 .48806 Mdot
.56392 .84694 Mdot
.21411 .69763 Mdot
.55378 .72493 Mdot
.61205 .61326 Mdot
.36532 .61459 Mdot
.71751 .74694 Mdot
.61539 .71265 Mdot
.1771 .52651 Mdot
.70468 .72625 Mdot
.37634 .57242 Mdot
.8451 .51281 Mdot
.53789 .8204 Mdot
.46301 .30779 Mdot
.57399 .46789 Mdot
.4974 .34524 Mdot
.4987 .2367 Mdot
.38668 .4551 Mdot
.44931 .68233 Mdot
.70529 .44675 Mdot
.55817 .64816 Mdot
.72019 .57322 Mdot
.24694 .44375 Mdot
.60519 .33964 Mdot
.45576 .4446 Mdot
.36566 .41059 Mdot
.3303 .70624 Mdot
.35551 .65856 Mdot
.42161 .82598 Mdot
.56573 .76061 Mdot
.52944 .30091 Mdot
.6819 .39738 Mdot
.61797 .7238 Mdot
.73473 .69702 Mdot
.40503 .64056 Mdot
.23637 .69361 Mdot
.57666 .51767 Mdot
.71028 .43546 Mdot
.51468 .23771 Mdot
.27381 .32233 Mdot
.61401 .40645 Mdot
.28176 .63995 Mdot
.404 .32243 Mdot
.55082 .55359 Mdot
.39911 .42751 Mdot
.39862 .41962 Mdot
.15822 .44834 Mdot
.63009 .74527 Mdot
.45681 .69653 Mdot
.22812 .6814 Mdot
.38966 .60705 Mdot
.37603 .45186 Mdot
.68474 .57962 Mdot
.26082 .32697 Mdot
.42321 .29549 Mdot
.76918 .5882 Mdot
.51827 .75754 Mdot
.68121 .6394 Mdot
.23975 .68694 Mdot
.25794 .71033 Mdot
.74439 .28074 Mdot
.34234 .48049 Mdot
.26896 .3465 Mdot
.33901 .23689 Mdot
.38478 .43442 Mdot
.28602 .4764 Mdot
.33697 .56861 Mdot
.42877 .82036 Mdot
.3889 .56233 Mdot
.28472 .25717 Mdot
.69061 .32745 Mdot
.46051 .75992 Mdot
.79066 .57685 Mdot
.51353 .18278 Mdot
.22084 .67003 Mdot
.58364 .25542 Mdot
.44749 .35417 Mdot
.6133 .34052 Mdot
.57497 .47752 Mdot
.80322 .68403 Mdot
.56144 .57648 Mdot
.46914 .25401 Mdot
.22513 .57585 Mdot
.53264 .38518 Mdot
.74359 .74234 Mdot
.24322 .38007 Mdot
.76463 .67763 Mdot
.36903 .58704 Mdot
.5116 .39148 Mdot
.50434 .34721 Mdot
.64081 .4683 Mdot
.28553 .61286 Mdot
.4804 .81227 Mdot
.50519 .17973 Mdot
.23493 .61353 Mdot
.54795 .23583 Mdot
.52167 .79176 Mdot
.18466 .54419 Mdot
.22619 .41193 Mdot
.52063 .52501 Mdot
.57766 .76384 Mdot
.73757 .39214 Mdot
.21158 .33235 Mdot
.60977 .50344 Mdot
.38778 .51675 Mdot
.34371 .54266 Mdot
.25744 .60046 Mdot
.78972 .53572 Mdot
.51515 .34807 Mdot
.73196 .68298 Mdot
.18037 .57328 Mdot
.68312 .23825 Mdot
.82088 .47987 Mdot
.72655 .75578 Mdot
.42574 .33266 Mdot
.2434 .58037 Mdot
.2332 .4291 Mdot
.63292 .19044 Mdot
.59392 .50258 Mdot
.33551 .75822 Mdot
.74224 .39299 Mdot
.23375 .68383 Mdot
.44528 .58611 Mdot
.30147 .51751 Mdot
.40539 .76257 Mdot
.40097 .80432 Mdot
.33891 .35432 Mdot
.18874 .6164 Mdot
.43622 .53828 Mdot
.50492 .8482 Mdot
.35117 .69206 Mdot
.43647 .50372 Mdot
.53613 .62056 Mdot
.67955 .71637 Mdot
.24654 .67804 Mdot
.30518 .70053 Mdot
.50923 .18802 Mdot
.55735 .59116 Mdot
.7242 .55203 Mdot
.49639 .27325 Mdot
.7598 .45 Mdot
.25563 .61046 Mdot
.68228 .39705 Mdot
.17599 .61141 Mdot
.62472 .49988 Mdot
.74943 .64826 Mdot
.51853 .78906 Mdot
.41723 .16716 Mdot
.29 .60986 Mdot
.64523 .74129 Mdot
.24189 .40595 Mdot
.71173 .60588 Mdot
.6313 .26948 Mdot
.23111 .77955 Mdot
.39543 .18771 Mdot
.33611 .69564 Mdot
.44681 .82288 Mdot
.19451 .45471 Mdot
.33772 .70982 Mdot
.81629 .431 Mdot
.65219 .37561 Mdot
.74168 .52202 Mdot
.56389 .36853 Mdot
.61481 .83141 Mdot
.74105 .44849 Mdot
.46819 .83276 Mdot
.16578 .47394 Mdot
.49813 .24172 Mdot
.60573 .34202 Mdot
.58562 .65673 Mdot
.46888 .65548 Mdot
.76302 .48059 Mdot
.42944 .40017 Mdot
.63089 .2877 Mdot
.53502 .75534 Mdot
.55536 .60522 Mdot
.63237 .70509 Mdot
.33494 .49156 Mdot
.56421 .74821 Mdot
.27137 .61933 Mdot
.63568 .59015 Mdot
.5111 .54312 Mdot
.67519 .42806 Mdot
.64383 .37263 Mdot
.4613 .30747 Mdot
.80516 .43559 Mdot
.50253 .4921 Mdot
.55899 .62044 Mdot
.43501 .35133 Mdot
.30701 .24688 Mdot
.25264 .62862 Mdot
.50368 .8275 Mdot
.7098 .70239 Mdot
.45583 .35064 Mdot
.66555 .43975 Mdot
.80596 .40289 Mdot
.6439 .24184 Mdot
.34236 .73201 Mdot
.62823 .41643 Mdot
.62094 .24338 Mdot
.24744 .47311 Mdot
.35671 .80066 Mdot
.45415 .17862 Mdot
.39141 .2026 Mdot
.50504 .61885 Mdot
.4283 .26324 Mdot
.50702 .25039 Mdot
.71802 .37002 Mdot
.50663 .56101 Mdot
.87299 .4933 Mdot
.32749 .39861 Mdot
.82682 .67195 Mdot
.43507 .60181 Mdot
.82123 .59549 Mdot
.73448 .37036 Mdot
.46102 .49856 Mdot
.49596 .5678 Mdot
.28796 .64334 Mdot
.30143 .53338 Mdot
.23156 .32539 Mdot
.73816 .29195 Mdot
.59986 .62324 Mdot
.51014 .17425 Mdot
.43484 .15546 Mdot
.42291 .37518 Mdot
.60186 .40178 Mdot
.38862 .18927 Mdot
.5845 .5894 Mdot
.79257 .46328 Mdot
.1851 .45553 Mdot
.28508 .67832 Mdot
.46885 .39659 Mdot
.69047 .43735 Mdot
.32669 .75141 Mdot
.21039 .67728 Mdot
.83544 .47845 Mdot
.26375 .68678 Mdot
.43258 .57859 Mdot
.42188 .50827 Mdot
.20192 .62618 Mdot
.66548 .31849 Mdot
.25165 .53645 Mdot
.65334 .3159 Mdot
.86684 .58716 Mdot
.44279 .79586 Mdot
.47846 .81138 Mdot
.66231 .32763 Mdot
.29581 .4507 Mdot
.33455 .66543 Mdot
.64959 .31828 Mdot
.29179 .67599 Mdot
.26047 .30564 Mdot
.65499 .32908 Mdot
.71468 .23819 Mdot
.31699 .27654 Mdot
.6227 .62861 Mdot
.51425 .25377 Mdot
.32327 .27755 Mdot
.37512 .57579 Mdot
.74189 .5397 Mdot
.22453 .58208 Mdot
.39532 .57471 Mdot
.25957 .61675 Mdot
.25464 .57601 Mdot
.35468 .23828 Mdot
.4337 .29371 Mdot
.24347 .63265 Mdot
.39759 .38124 Mdot
.37459 .39234 Mdot
.78195 .5204 Mdot
.52759 .66916 Mdot
.21277 .56602 Mdot
.53246 .64046 Mdot
.62932 .33963 Mdot
.55658 .54635 Mdot
.46901 .34175 Mdot
.73857 .73143 Mdot
.6613 .51353 Mdot
.30476 .41625 Mdot
.83103 .59338 Mdot
.37686 .42529 Mdot
.64671 .80953 Mdot
.79717 .40766 Mdot
.51651 .23556 Mdot
.66883 .61892 Mdot
.65326 .66723 Mdot
.8207 .35455 Mdot
.42928 .42491 Mdot
.49886 .62676 Mdot
.40654 .41286 Mdot
.29893 .42744 Mdot
.53242 .77745 Mdot
.57744 .60644 Mdot
.63511 .44229 Mdot
.38595 .53858 Mdot
.40682 .47754 Mdot
.32456 .47966 Mdot
.56559 .53019 Mdot
.72013 .48938 Mdot
.42013 .81719 Mdot
.5723 .62152 Mdot
.851 .59255 Mdot
.61567 .39056 Mdot
.38249 .35292 Mdot
.16106 .5475 Mdot
.84248 .49583 Mdot
.58772 .67027 Mdot
.45232 .14367 Mdot
.5558 .42857 Mdot
.24509 .6446 Mdot
.32643 .43638 Mdot
.41552 .19231 Mdot
.65968 .51893 Mdot
.69123 .39044 Mdot
.36847 .62524 Mdot
.79924 .52033 Mdot
.55105 .74295 Mdot
.30004 .46023 Mdot
.28447 .69372 Mdot
.27877 .32913 Mdot
.27304 .51856 Mdot
.64351 .68234 Mdot
.43142 .37184 Mdot
.43082 .28879 Mdot
.31613 .47626 Mdot
.45323 .80925 Mdot
.42317 .18722 Mdot
.34032 .80388 Mdot
.50878 .30005 Mdot
.70687 .67983 Mdot
.35135 .53345 Mdot
.26795 .63512 Mdot
.61073 .45501 Mdot
.16344 .56925 Mdot
.7162 .44886 Mdot
.35508 .54634 Mdot
.68573 .45458 Mdot
.61741 .31689 Mdot
.50094 .53348 Mdot
.47841 .68457 Mdot
.77709 .32328 Mdot
.59941 .47206 Mdot
.82568 .54697 Mdot
.63184 .40668 Mdot
.53748 .79002 Mdot
.28861 .46739 Mdot
.61303 .63933 Mdot
.43899 .26321 Mdot
.44893 .65754 Mdot
.34386 .79347 Mdot
.16295 .56276 Mdot
.36228 .63037 Mdot
.5196 .77757 Mdot
.21028 .49632 Mdot
.54187 .29344 Mdot
.40264 .53018 Mdot
.58856 .40052 Mdot
.28775 .47185 Mdot
.84927 .50361 Mdot
.28611 .66148 Mdot
.57843 .44703 Mdot
.34171 .78244 Mdot
.3003 .76357 Mdot
.494 .84444 Mdot
.56517 .19262 Mdot
.32274 .46746 Mdot
.59766 .82119 Mdot
.62235 .28218 Mdot
.17756 .64414 Mdot
.3332 .72397 Mdot
.15621 .46143 Mdot
.43921 .37333 Mdot
.22321 .56076 Mdot
.74912 .31426 Mdot
.28108 .54594 Mdot
.21186 .41561 Mdot
.43175 .47956 Mdot
.43824 .70028 Mdot
.20151 .426 Mdot
.72078 .22147 Mdot
.61287 .44384 Mdot
.24791 .56186 Mdot
.27203 .48665 Mdot
.21576 .57413 Mdot
.7288 .61782 Mdot
.5492 .32007 Mdot
.40409 .73245 Mdot
.78051 .59864 Mdot
.67103 .41563 Mdot
.72246 .55477 Mdot
.72696 .61777 Mdot
.75937 .51171 Mdot
.70101 .46772 Mdot
.45759 .17615 Mdot
.43979 .365 Mdot
.62719 .44945 Mdot
.58951 .42229 Mdot
.28227 .45818 Mdot
.69409 .55084 Mdot
.60732 .68336 Mdot
.58727 .39401 Mdot
.606 .60805 Mdot
.2807 .52708 Mdot
.70616 .77184 Mdot
.39175 .677 Mdot
.24204 .36467 Mdot
.35033 .40015 Mdot
.28427 .62253 Mdot
.30751 .37743 Mdot
.79194 .62318 Mdot
.70715 .66022 Mdot
.66089 .41493 Mdot
.30955 .75435 Mdot
.6363 .76665 Mdot
.29179 .29514 Mdot
.62933 .78444 Mdot
.41529 .57439 Mdot
.47771 .4069 Mdot
.30364 .50614 Mdot
.62297 .72912 Mdot
.40243 .44604 Mdot
.22626 .56721 Mdot
.50353 .63834 Mdot
.63948 .75116 Mdot
.21568 .38819 Mdot
.27751 .32421 Mdot
.49439 .28141 Mdot
.26781 .72124 Mdot
.59117 .63264 Mdot
.3946 .19596 Mdot
.24658 .52553 Mdot
.69743 .67832 Mdot
.5214 .80438 Mdot
.39874 .81883 Mdot
.46644 .55502 Mdot
.72704 .41386 Mdot
.52024 .37823 Mdot
.47049 .20951 Mdot
.29069 .65889 Mdot
.50478 .4611 Mdot
.52244 .73411 Mdot
.36154 .42312 Mdot
.50229 .71154 Mdot
.59134 .49527 Mdot
.74521 .51337 Mdot
.37868 .48036 Mdot
.57455 .22585 Mdot
.70351 .54877 Mdot
.4461 .5577 Mdot
.59734 .34191 Mdot
.71474 .40281 Mdot
.59199 .21017 Mdot
.47682 .39008 Mdot
.24193 .66106 Mdot
.43964 .35487 Mdot
.27372 .30789 Mdot
.26318 .65174 Mdot
.35017 .73757 Mdot
.29909 .53802 Mdot
.4521 .26719 Mdot
.56897 .72579 Mdot
.59754 .38195 Mdot
.61097 .64261 Mdot
.3766 .43798 Mdot
.19617 .49831 Mdot
.42166 .329 Mdot
.7217 .38544 Mdot
.47627 .49631 Mdot
.33589 .3742 Mdot
.46781 .47787 Mdot
.16445 .50541 Mdot
.28209 .5475 Mdot
.70805 .4499 Mdot
.44748 .57838 Mdot
.73306 .37159 Mdot
.81098 .43461 Mdot
.26199 .7339 Mdot
.79477 .38331 Mdot
.46606 .53884 Mdot
.83023 .54015 Mdot
.33636 .68302 Mdot
.18472 .44996 Mdot
.71151 .46185 Mdot
.47611 .5676 Mdot
.70121 .57014 Mdot
.37163 .64781 Mdot
.51779 .50812 Mdot
.61303 .57584 Mdot
.64641 .39377 Mdot
.48595 .73722 Mdot
.49473 .6639 Mdot
.61904 .3449 Mdot
.46464 .79629 Mdot
.29194 .73976 Mdot
.42435 .19332 Mdot
.47764 .47255 Mdot
.7422 .56798 Mdot
.74761 .49808 Mdot
.17599 .3502 Mdot
.76695 .73035 Mdot
.52135 .37984 Mdot
.4855 .47536 Mdot
.71128 .41767 Mdot
.59875 .63633 Mdot
.64433 .32603 Mdot
.34628 .37932 Mdot
.42825 .61988 Mdot
.60909 .57743 Mdot
.65588 .74436 Mdot
.29349 .64634 Mdot
.7593 .4319 Mdot
.4216 .75985 Mdot
.70021 .77943 Mdot
.27014 .28346 Mdot
.27506 .64478 Mdot
.15019 .40629 Mdot
.49945 .68122 Mdot
.37646 .40228 Mdot
.34015 .36926 Mdot
.43253 .81657 Mdot
.68205 .38699 Mdot
.78008 .54983 Mdot
.37675 .75261 Mdot
.71589 .45568 Mdot
.63033 .27619 Mdot
.52265 .78917 Mdot
.5096 .71899 Mdot
.46452 .51561 Mdot
.6544 .6684 Mdot
.58424 .80463 Mdot
.55194 .2407 Mdot
.30576 .74245 Mdot
.78488 .59553 Mdot
.68646 .21309 Mdot
.31299 .7759 Mdot
.70885 .57621 Mdot
.73844 .61035 Mdot
.33973 .36709 Mdot
.67874 .3218 Mdot
.61506 .26067 Mdot
.79867 .47863 Mdot
.41287 .29458 Mdot
.6397 .65012 Mdot
.8097 .57366 Mdot
.67134 .44022 Mdot
.33042 .26907 Mdot
.47792 .56736 Mdot
.44944 .32329 Mdot
.54181 .76656 Mdot
.66661 .35232 Mdot
.59145 .53456 Mdot
.69611 .35175 Mdot
.43167 .36042 Mdot
.24826 .40399 Mdot
.22668 .52129 Mdot
.7562 .26338 Mdot
.35553 .75142 Mdot
.79614 .6157 Mdot
.57204 .31682 Mdot
.37417 .8194 Mdot
.23389 .52858 Mdot
.37221 .75461 Mdot
.23331 .35068 Mdot
.61815 .65035 Mdot
.37039 .52921 Mdot
.59759 .38012 Mdot
.29489 .71499 Mdot
.47306 .2553 Mdot
.31881 .29111 Mdot
.79958 .54155 Mdot
.68605 .40979 Mdot
.75112 .61063 Mdot
.71058 .35149 Mdot
.47392 .3629 Mdot
.35648 .41136 Mdot
.59928 .82858 Mdot
.44679 .53681 Mdot
.63326 .36477 Mdot
.50544 .45574 Mdot
.75539 .32195 Mdot
.33048 .21309 Mdot
.49963 .30822 Mdot
.61398 .77705 Mdot
.59324 .23314 Mdot
.50833 .28524 Mdot
.63188 .31901 Mdot
.26185 .20331 Mdot
.16338 .659 Mdot
.32612 .47326 Mdot
.50533 .19971 Mdot
.60242 .23096 Mdot
.42327 .81194 Mdot
.67424 .67674 Mdot
.59005 .7066 Mdot
.71034 .28617 Mdot
.6646 .29446 Mdot
.60031 .4146 Mdot
.22159 .37466 Mdot
.24549 .71782 Mdot
.80355 .54874 Mdot
.33348 .77884 Mdot
.60714 .4356 Mdot
.55423 .44669 Mdot
.22242 .26623 Mdot
.2075 .63763 Mdot
.49073 .36226 Mdot
.75625 .31848 Mdot
.39621 .41903 Mdot
.56162 .3882 Mdot
.43638 .77497 Mdot
.49992 .18126 Mdot
.66869 .44251 Mdot
.40248 .80487 Mdot
.37406 .47896 Mdot
.48996 .61724 Mdot
.42934 .62134 Mdot
.49974 .56553 Mdot
.54575 .43397 Mdot
.40067 .59047 Mdot
.50174 .29027 Mdot
.21556 .55065 Mdot
.36304 .58758 Mdot
.46601 .16609 Mdot
.14109 .5353 Mdot
.43699 .32003 Mdot
.4033 .65435 Mdot
.54435 .2915 Mdot
.31513 .2822 Mdot
.76225 .49038 Mdot
.36575 .50534 Mdot
.1925 .43131 Mdot
.33876 .84264 Mdot
.44822 .70607 Mdot
.71647 .49944 Mdot
.38849 .47539 Mdot
.6256 .4484 Mdot
.4802 .2803 Mdot
.42503 .55335 Mdot
.58639 .63512 Mdot
.56409 .30093 Mdot
.47674 .35476 Mdot
.36763 .60331 Mdot
.82327 .66916 Mdot
.53729 .32645 Mdot
.63988 .3482 Mdot
.18117 .64647 Mdot
.78217 .52201 Mdot
.36485 .3481 Mdot
.50649 .40813 Mdot
.3258 .62538 Mdot
.47526 .56793 Mdot
.20122 .57147 Mdot
.74604 .65391 Mdot
.36718 .78699 Mdot
.41929 .32828 Mdot
.51817 .26108 Mdot
.57052 .33287 Mdot
.70288 .52009 Mdot
.25659 .56109 Mdot
.40079 .77799 Mdot
.59053 .45135 Mdot
.19813 .67184 Mdot
.61921 .65031 Mdot
.50379 .75222 Mdot
.52399 .27979 Mdot
.51505 .84036 Mdot
.82242 .52355 Mdot
.49148 .25524 Mdot
.78541 .65024 Mdot
.62625 .73652 Mdot
.75813 .44933 Mdot
.58652 .65293 Mdot
.6156 .4179 Mdot
.36809 .48105 Mdot
.69997 .78456 Mdot
.40735 .78238 Mdot
.39808 .71332 Mdot
.48214 .71221 Mdot
.45253 .21992 Mdot
.25676 .50476 Mdot
.14631 .45737 Mdot
.64136 .70719 Mdot
.71313 .77012 Mdot
.39188 .2009 Mdot
.38616 .48412 Mdot
.24144 .58651 Mdot
.48518 .41441 Mdot
.56035 .6249 Mdot
.39582 .79377 Mdot
.48878 .33429 Mdot
.76857 .63927 Mdot
.51492 .41057 Mdot
.74994 .69563 Mdot
.5913 .5658 Mdot
.49362 .78647 Mdot
.36716 .69513 Mdot
.81604 .43668 Mdot
.18592 .50393 Mdot
.35045 .6317 Mdot
.15976 .40784 Mdot
.19299 .51766 Mdot
.23718 .69578 Mdot
.77062 .5811 Mdot
.83623 .43841 Mdot
.31227 .70509 Mdot
.24615 .63292 Mdot
.37673 .68713 Mdot
.44282 .41815 Mdot
.67719 .7151 Mdot
.52238 .2834 Mdot
.2692 .57136 Mdot
.36108 .6327 Mdot
.49118 .92351 Mdot
.64829 .57717 Mdot
.29375 .39867 Mdot
.65221 .71928 Mdot
.27341 .73331 Mdot
.45739 .41478 Mdot
.20391 .40281 Mdot
.58006 .50641 Mdot
.58224 .442 Mdot
.42452 .30519 Mdot
.45022 .19111 Mdot
.69026 .71443 Mdot
.84667 .38797 Mdot
.26998 .28659 Mdot
.4883 .72884 Mdot
.51739 .53577 Mdot
.38644 .4399 Mdot
.27384 .42913 Mdot
.66517 .64036 Mdot
.19682 .38338 Mdot
.22045 .55732 Mdot
.20259 .62781 Mdot
.81177 .34332 Mdot
.31866 .25856 Mdot
.42858 .81714 Mdot
.32148 .67889 Mdot
.28592 .4186 Mdot
.72563 .56758 Mdot
.6338 .60406 Mdot
.38575 .71239 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`1mooooo`;o
0000b_ooool001cooooo00?o0000ooooooooool0OOooool2o`000<[ooooo000Looooo`03o`000?oo
oooooooo08Gooooo0_l00032ooooo`007?ooool00ol0003oooooooooo`25ooooo`;o00008_ooool2
o`0009kooooo000Looooo`03o`000?oooooooooo09?ooooo0ol0000Booooo`?o0000W_ooool001co
oooo00?o0000ooooooooool0Toooool3o`0001;ooooo0_l0002Oooooo`007?ooool00ol0003ooooo
ooooo`2Nooooo`;o0000ZOooool001cooooo00?o0000ooooooooool0W_ooool2o`000:Wooooo000L
ooooo`03o`000?oooooooooo083ooooo0_l0000Looooo`;o0000ZOooool001cooooo00?o0000oooo
ooooool0P?ooool2o`0000Kooooo0_l00005ooooo`;o00003Oooool2o`000:Wooooo000Looooo`03
o`000?oooooooooo08Sooooo0_l00005ooooo`;o00003?ooool2o`000:[ooooo000Looooo`03o`00
0?oooooooooo08oooooo0_l0000<ooooo`;o0000Z_ooool001cooooo0_l0002Fooooo`;o00001?oo
ool2o`000:cooooo000Looooo`03o`000?oooooooooo08[ooooo0_l00009ooooo`;o00001?ooool2
o`0000oooooo0_l0002Kooooo`007?ooool00ol0003oooooooooo`2:ooooo`;o000000?oooooo`00
0?l000005?ooool2o`0000Oooooo0_l0002Kooooo`007?ooool00ol0003oooooooooo`2=ooooo`;o
00005?ooool2o`000:Cooooo000Looooo`03o`000?oooooooooo07?ooooo0_l0000Iooooo`;o0000
1?ooool2o`0003cooooo0_l0001eooooo`007?ooool00ol0003oooooooooo`1cooooo`;o00003ooo
ool2o`0000Sooooo0_l00004ooooo`;o00007Oooool2o`0000Kooooo0_l0000Eooooo`;o0000MOoo
ool001cooooo00?o0000ooooooooool0P?ooool2o`0000;ooooo0_l0000Looooo`;o00002Oooool2
o`0000Cooooo0_l00005ooooo`?o0000S?ooool001cooooo00?o0000ooooooooool0P?ooool2o`00
013ooooo0_l0000>ooooo`;o00002Oooool2o`0000_ooooo0_l0002=ooooo`007?ooool00ol0003o
ooooooooo`26ooooo`;o00002Oooool3o`0000kooooo0_l000001?oooooo0000o`000?ooool2o`00
09oooooo000Looooo`03o`000?oooooooooo08?ooooo0_l000000ooooooo0000o`000008ooooo`?o
00003?ooool3o`0000?ooooo0_l000000ooooooo0000o`00000;ooooo`;o0000T_ooool001cooooo
00?o0000ooooooooool0Poooool2o`0000_ooooo0_l0000=ooooo`Ko00000oooool2o`0000Kooooo
0_l00003ooooo`;o0000T_ooool001cooooo00?o0000ooooooooool0OOooool2o`0000Oooooo0_l0
0003ooooo`;o00005?ooool4o`0000?ooooo0_l00004ooooo`Co00004?ooool2o`0008Gooooo000L
ooooo`03o`000?oooooooooo07Cooooo0_l00004ooooo`;o000000?oooooo`000?l000001?ooool2
o`000003ooooool0003o000000?ooooo0_l0000Booooo`Go000000?oooooo`000?l000001_ooool3
o`0001;ooooo0_l00006ooooo`;o0000OOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Ooo
ool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo06?ooooo0_l0000?ooooo`;o00001?oo
ool4o`0000Gooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool2o`0000oooooo0_l0
00001?oooooo0000o`000?ooool2o`0000Kooooo0_l00005ooooo`;o00005?ooool2o`0000[ooooo
0_l0001aooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0Hoooool2o`0000gooooo0_l00008oooo
o`;o00001Oooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o00002_ooool2o`00
00;ooooo0_l0000Aooooo`;o000000?oooooo`000?l000000oooool2o`0001_ooooo0_l0001aoooo
o`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo00?o0000ooooooooool0L_ooool2o`0000Kooooo1?l0000<ooooo`Co00003?ooool2o`0000;o
oooo1?l0000?ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo0_l0002:ooooo`00
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo
0ol0001jooooo`Co00003_ooool2o`0000cooooo0_l00004ooooo`;o00001?ooool2o`0000kooooo
0_l00005ooooo`;o0000R_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?oo
ool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo057ooooo0_l0000Oooooo`Co00001Ooo
ool3o`00013ooooo0_l0000Fooooo`;o00001Oooool2o`0009[ooooo00000ooooooo410@ooooo`02
ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1A
ooooo`;o00007oooool5o`0001Oooooo0_l00005ooooo`;o00001Oooool2o`0000[ooooo1?l00000
0ooooooo0000o`000002ooooo`;o00003Oooool2o`0008Oooooo00001_ooooooMgMgoiRHV?oooooo
V9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo07Gooooo
0_l0000Fooooo`;o00001_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000:ooooo`Co0000
1Oooool2o`0000[ooooo0_l000000ooooooo0000o`000027ooooo`0000Koooooonk^k_lb<S;o0000
oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Xoooo
o`;o00001?ooool2o`0001Oooooo0_l00004ooooo`;o000000?oooooo`000?l000000oooool2o`00
0005ooooool0003o0000o`000?ooool00_l0000Fooooo`Co00001Oooool2o`0001cooooo0_l0001/
ooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o00003Oooool2o`0000Cooooo0_l00002oooo
o`;o00004oooool2o`0000Oooooo0_l00004ooooo`Co00006_ooool4o`0000?ooooo1?l00003oooo
o`;o00005oooool2o`0006cooooo000Looooo`03o`000?oooooooooo05Wooooo0_l0000=ooooo`;o
00001Oooool2o`000003ooooool0003o000001_ooooo0_l00005ooooo`;o000000Coooooo`000?l0
003ooooo0_l0000Aooooo`;o00001?ooool2o`0000?ooooo1Ol00003ooooo`;o00008_ooool2o`00
067ooooo000Looooo`03o`000?oooooooooo06Gooooo0_l000000ooooooo0000o`000005ooooo`Co
00004oooool2o`0000Oooooo0_l00008ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Ko
oooo0_l00004ooooo`;o00000oooool7o`0000cooooo0_l00003ooooo`?o00004Oooool2o`00067o
oooo000Looooo`03o`000?oooooooooo06Gooooo0_l0000:ooooo`;o00004oooool2o`0001Cooooo
0_l00002ooooo`;o00001?ooool3o`0000kooooo0_l000000ooooooo0000o`000002ooooo`?o0000
3?ooool2o`0000?ooooo0ol0001dooooo`007?ooool00ol0003oooooooooo`1jooooo`;o00004?oo
ool2o`00013ooooo1?l00004ooooo`;o00003oooool2o`000003ooooool0003o000000;ooooo0_l0
0003ooooo`;o00000_ooool2o`0000_ooooo0_l0001cooooo`007?ooool00ol0003oooooooooo`1j
ooooo`;o00004?ooool4o`0000?ooooo0_l00004ooooo`;o00000oooool4o`0000Wooooo0_l00005
ooooo`;o00002Oooool5o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o00001Oooool4
o`00077ooooo000Looooo`03o`000?oooooooooo06Oooooo0_l000001?oooooo0000o`000?l0000Q
ooooo`;o00000oooool2o`0000Cooooo0_l00003ooooo`Co00000_ooool2o`0000Gooooo0_l00000
1Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`000?l000001_ooool2o`000003ooooool0
003o000000Wooooo1?l00007ooooo`;o0000LOooool001cooooo00?o0000ooooooooool0Ioooool6
o`0000;ooooo0_l000000ooooooo0000o`00000Jooooo`;o00002?ooool2o`0000Cooooo0_l00003
ooooo`?o00002?ooool3o`0000Cooooo0_l0000@ooooo`;o00000_ooool2o`0000gooooo0_l00008
ooooo`;o0000Hoooool001cooooo00?o0000ooooooooool0DOooool2o`0000gooooo1?l00004oooo
o`;o00001Oooool2o`000003ooooool0003o000001[ooooo0_l00008ooooo`;o00001?ooool2o`00
00?ooooo0_l0000;ooooo`;o00005Oooool4o`0000;ooooo0_l0000;ooooo`;o00002?ooool2o`00
06?ooooo000Looooo`03o`000?oooooooooo057ooooo0_l0000=ooooo`Co00002_ooool4o`0001go
oooo0_l0000=ooooo`;o00002?ooool2o`0000Kooooo0_l0000=ooooo`;o00001Oooool5o`0000;o
oooo0ol0001iooooo`007?ooool00ol0003oooooooooo`1Looooo`Ko00003?ooool4o`0001gooooo
0_l0000Gooooo`;o00004oooool4o`0000Gooooo1?l00004ooooo`;o0000NOooool001cooooo0_l0
001Mooooo`Ko00001Oooool2o`0000Kooooo0ol0000_ooooo`;o00001Oooool3o`0000kooooo0_l0
0002ooooo`;o00001oooool2o`0000Oooooo0_l0000Jooooo`;o0000G?ooool001cooooo00?o0000
ooooooooool0GOooool4o`0000Gooooo0ol00005ooooo`Co00006Oooool2o`0000Gooooo0_l00000
1?oooooo0000o`000?l00004ooooo`;o00000oooool4o`0000?ooooo1Ol0000<ooooo`?o00004ooo
ool2o`0000[ooooo0_l00002ooooo`;o00002_ooool2o`0005cooooo000Looooo`03o`000?oooooo
oooo05Wooooo0_l00002ooooo`Go00000_ooool4o`0000Cooooo1?l0000Kooooo`;o00001Oooool6
o`0000Cooooo0_l00005ooooo`;o00001_ooool2o`0000gooooo0_l0000Oooooo`;o00000_ooool2
o`0000Oooooo0_l0001Oooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o00001Oooool2o`00
00;ooooo0ol00005ooooo`;o00000_ooool2o`00027ooooo0_l0000@ooooo`;o00007Oooool2o`00
02;ooooo0_l0001Oooooo`007?ooool00ol0003oooooooooo`1`ooooo`;o00005Oooool2o`0000;o
oooo0_l0000Hooooo`;o00006oooool4o`000003ooooool0003o000000Gooooo0_l00008ooooo`Co
00005_ooool2o`0005Gooooo000Looooo`03o`000?oooooooooo04Gooooo0_l00010ooooo`;o0000
0_ooool2o`0000;ooooo0_l00008ooooo`Co00007_ooool2o`0000Gooooo0_l00003ooooo`;o0000
1Oooool2o`0000Sooooo1?l0000Fooooo`;o0000EOooool001cooooo00?o0000ooooooooool0AOoo
ool2o`0001kooooo0_l000000ooooooo0000o`00000Qooooo`;o00000_ooool2o`0000Sooooo1?l0
000>ooooo`;o00001Oooool2o`0000Oooooo0_l0000:ooooo`Co00001?ooool2o`0000kooooo0_l0
001Xooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00004oooool2o`000003ooooool0003o
000002?ooooo0_l00006ooooo`;o00001_ooool2o`0000cooooo0_l00005ooooo`;o00004oooool4
o`0000Cooooo0_l0000>ooooo`;o000000Coooooo`000?l0003ooooo0_l0001Rooooo`007?ooool0
0ol0003oooooooooo`1@ooooo`;o00004Oooool2o`0000Wooooo0_l0000Mooooo`;o000000?ooooo
o`000?l000000oooool3o`0000Gooooo0_l00008ooooo`;o00003?ooool3o`0000Oooooo0_l00003
ooooo`;o00000oooool4o`0000Gooooo0_l0000>ooooo`;o000000?oooooo`000?l000002Oooool2
o`0005Oooooo000Looooo`03o`000?oooooooooo05_ooooo0_l00006ooooo`Co00001oooool2o`00
023ooooo0_l00004ooooo`;o00003?ooool5o`0000cooooo0ol00007ooooo`;o00000oooool2o`00
00?ooooo1?l00005ooooo`;o00000_ooool2o`0000_ooooo0_l0000;ooooo`?o0000E_ooool001co
oooo00?o0000ooooooooool0Foooool2o`0000Kooooo1Ol00005ooooo`;o00005Oooool2o`0001;o
oooo0_l00003ooooo`;o00001Oooool4o`0000[ooooo0_l00009ooooo`?o00001_ooool2o`0000;o
oooo0ol00005ooooo`?o000000?oooooo`000?l000000_l00009ooooo`;o00002Oooool2o`000003
ooooool0003o000005Kooooo000Looooo`03o`000?oooooooooo05Cooooo0_l0000=ooooo`;o0000
00?oooooo`000?l000001Oooool2o`0001Gooooo0_l0000Booooo`;o00000oooool2o`000003oooo
ool0003o000000;o00000_ooool2o`0000Sooooo1?l00009ooooo`Co00001Oooool2o`0000;ooooo
0ol00005ooooo`Co000000Coooooo`000?l0003o00002?ooool3o`0000Wooooo0_l0001Iooooo`00
7?ooool00ol0003oooooooooo`1Dooooo`;o0000<_ooool2o`0000Sooooo0_l00004ooooo`;o0000
1Oooool5o`0000;ooooo1?l00006ooooo`;o00001oooool2o`0000Cooooo0_l00005ooooo`;o0000
00?oooooo`000?l000002Oooool2o`0000cooooo0ol0001Tooooo`007?ooool00ol0003ooooooooo
o`1Dooooo`;o00001Oooool2o`0000Oooooo0_l00005ooooo`;o00006oooool2o`0000Sooooo0_l0
000;ooooo`;o00001_ooool3o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`?o000000Co
ooooo`000?l0003o00000oooool2o`0000;ooooo1Ol00005ooooo`;o00003?ooool2o`0000;ooooo
0_l00008ooooo`;o0000Foooool001cooooo00?o0000ooooooooool0D_ooool2o`0000Oooooo0_l0
0007ooooo`;o00001Oooool2o`0001Gooooo0_l00002ooooo`;o000000?oooooo`000?l000005?oo
ool2o`0000Kooooo0_l00003ooooo`Ko00000oooool2o`000005ooooool0003o0000o`000?ooool0
0ol00003ooooo`;o00000oooool2o`0000Oooooo0_l00002ooooo`;o00002?ooool2o`0000Sooooo
0_l00002ooooo`;o0000Foooool001cooooo00?o0000ooooooooool0C_ooool2o`0000;ooooo0_l0
0006ooooo`?o00001oooool2o`0001cooooo0_l00002ooooo`Go00005oooool2o`0000Sooooo0_l0
00001?oooooo0000o`000?l00003ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`;o0000
1?ooool2o`0000Kooooo0_l00002ooooo`;o00001?ooool2o`0000cooooo0_l0001Oooooo`007?oo
ool2o`0004_ooooo0ol000000ooooooo0000o`00000:ooooo`?o00001oooool2o`0000Oooooo0_l0
000Eooooo`;o00000_ooool2o`0000;ooooo1_l0000@ooooo`;o00001?ooool4o`000003ooooool0
003o000000?o000000?oooooo`000?l000001Oooool2o`0000;ooooo0_l00002ooooo`;o00001?oo
ool2o`00013ooooo0_l0000Eooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0B_ooool3
o`0000Wooooo0_l00003ooooo`;o00001oooool2o`0000Oooooo0_l0000Eooooo`;o00001Oooool7
o`0000gooooo0_l000000ooooooo0000o`000004ooooo`Co000000Coooooo`000?l0003o00000_oo
ool6o`0000Cooooo0_l00003ooooo`Co00001?ooool2o`0000Gooooo1?l0000Mooooo`?o00001?oo
ool2o`0004oooooo000Looooo`03o`000?oooooooooo04[ooooo0_l00005ooooo`;o00000oooool2
o`0002kooooo0_l00003ooooo`;o00001Oooool3o`0000[ooooo0_l000000ooooooo0000o`000005
ooooo`Co00001?ooool7o`0000Cooooo0_l00003ooooo`Co00001?ooool2o`0000Gooooo1?l0000N
ooooo`;o00000_ooool4o`0004oooooo000Looooo`03o`000?oooooooooo047ooooo0_l0000>oooo
o`;o00000_ooool2o`0000Cooooo0_l00008ooooo`;o00001?ooool2o`0001Wooooo0_l0000:oooo
o`?o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l00008ooooo`Co00000_ooool7o`00
00Cooooo0_l00002ooooo`;o00001Oooool2o`0000_ooooo0_l00003ooooo`;o00007Oooool2o`00
057ooooo000Looooo`03o`000?oooooooooo047ooooo0_l00003ooooo`;o00003Oooool2o`0000Co
oooo0_l000001?oooooo0000o`000?l00004ooooo`;o00001?ooool2o`0002Wooooo0_l00002oooo
o`;o00000oooool2o`0000;ooooo0ol00002ooooo`Go000000?oooooo`000?l000001_l00002oooo
o`So00001Oooool4o`0000Gooooo0_l00002ooooo`?o00000_ooool4o`0006kooooo000Looooo`03
o`000?oooooooooo04Kooooo0_l0000<ooooo`;o00002?ooool3o`0000cooooo0_l0000`ooooo`;o
000000?oooooo`000?l000000ol000000ooooooo0000o`000003o`000003ooooool0003o000000_o
000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000;o00001Oooool4o`000003
ooooool0003o000000?ooooo0ol00004ooooo`;o00003oooool4o`0005Gooooo000Looooo`03o`00
0?oooooooooo05?ooooo0ol0000Cooooo`;o00000_ooool3o`0001[ooooo0_l0000Cooooo`;o0000
00Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00000>o`000003ooooool0003o000000Go
00000_ooool2o`000005ooooool0003o0000o`000?ooool00_l00004ooooo`?o00000_ooool2o`00
00Wooooo0_l0000?ooooo`Co0000EOooool001cooooo00?o0000ooooooooool0Doooool4o`0000Co
oooo0_l0000<ooooo`;o000000?oooooo`000?l000000_l0000?ooooo`;o00002Oooool2o`0001Oo
oooo0_l00003oooooa3o000000?oooooo`000?l000001Ol00009ooooo`;o00001?ooool2o`0000?o
oooo0_l00003ooooo`;o00005?ooool5o`0005Gooooo000Looooo`03o`000?oooooooooo03oooooo
1?l00005ooooo`;o00002oooool3o`0000?ooooo0_l0000?ooooo`;o00000oooool2o`0000cooooo
0_l00003ooooo`;o00002?ooool2o`0001?ooooo0_l00003ooooo`Oo000000?oooooo`000?l00000
2ol0000Aooooo`;o00000_ooool2o`0000Gooooo0_l00002ooooo`;o00004?ooool5o`0000Gooooo
0_l0001>ooooo`007?ooool00ol0003oooooooooo`0oooooo`Co00000oooool4o`0000Oooooo0_l0
0003ooooo`?o00001Oooool2o`0000_ooooo0_l00004ooooo`;o00004?ooool4o`0000Oooooo0_l0
000?ooooo`?o00000_ooool@o`000003ooooool0003o000000Wo00001oooool2o`0000Gooooo0_l0
00000ooooooo0000o`000002o`0000Cooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0
003o000000[ooooo0_l00006ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0@Oooool2
o`0000?ooooo0_l00009ooooo`;o00001?ooool2o`0000Gooooo0_l0000;ooooo`;o000000?ooooo
o`000?l000000_l0000Aooooo`Co00006?oooolQo`0000Oooooo0_l00008ooooo`Co00001_ooool4
o`0000?ooooo0_l000000ooooooo0000o`00001Rooooo`007?ooool00ol0003oooooooooo`11oooo
o`;o000000Coooooo`000?l0003o00001oooool2o`0000gooooo0_l0000?ooooo`Co00005Oooool2
o`0000Gooooo0_l00009oooooa3o000000?oooooo`000?l000005_l000000ooooooo0000o`000007
ooooo`;o00001Oooool2o`0000Kooooo0ol00006ooooo`;o000000?oooooo`000?l00000H?ooool0
01cooooo00?o0000ooooooooool0?Oooool2o`0000Gooooo0ol00006ooooo`Co000000?oooooo`00
0?l000002Oooool2o`0000kooooo0_l0000Fooooo`Co00001Oooool2o`0000Wooooo2?l000000ooo
oooo0000o`00000=o`000003ooooool0003o000000[o000000?oooooo`000?l000001?l00007oooo
o`;o00001?ooool2o`0000[ooooo0_l00004ooooo`Go00004Oooool2o`0004gooooo000Looooo`03
o`000?oooooooooo03gooooo0_l0000<ooooo`Ko000000?oooooo`000?l000006Oooool2o`0000Ko
oooo0_l0000>ooooo`;o00004_ooool2o`0000Kooooo3ol00002ooooo`Wo00001?ooool6o`0000Co
oooo0_l00007ooooo`Co00002?ooool2o`0000Cooooo0ol00007ooooo`;o00002_ooool2o`0004go
oooo000Looooo`03o`000?oooooooooo04_ooooo0_l0000?ooooo`;o00005oooool2o`0000Sooooo
0_l0000Booooo`Co00000_ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l00000
3Ol000000ooooooo0000o`000009o`000003ooooool0003o000000Ko00000_ooool4o`0000Wooooo
0_l0000>ooooo`;o00000oooool2o`0000?ooooo0_l00004ooooo`;o00003_ooool2o`0004?ooooo
000Looooo`03o`000?oooooooooo04Gooooo0_l0000=ooooo`?o00001Oooool2o`00027ooooo0_l0
00000ooooooo0000o`00000?oooooago000000?oooooo`000?l000003Ol000001Ooooooo0000o`00
0?l0003ooooo00Go00004?ooool2o`0000gooooo0_l00009ooooo`;o00001?ooool2o`0000Sooooo
0_l00013ooooo`007?ooool2o`0003Kooooo0_l0000>ooooo`;o000000?oooooo`000?l000002_oo
ool3o`0000_ooooo0_l0000?ooooo`;o00003Oooool2o`0000Sooooo0_l00002ooooo`;o00001Ooo
ool5o`000003ooooool0003o000000?o000000?oooooo`000?l000003Ol000000ooooooo0000o`00
000;o`000003ooooool0003o000000Co000000Coooooo`000?l0003ooooo0ol0000:ooooo`Co0000
2_ooool2o`0001;ooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`0eooooo`;o00003Ooo
ool2o`0000;ooooo0_l00004ooooo`;o00003?ooool2o`0000Cooooo0_l00009ooooo`;o00001?oo
ool2o`0000Cooooo0_l000000ooooooo0000o`00000<ooooo`Co00000_ooool2o`0000Cooooo0_l0
0009ooooobGo00000_ooool2o`000003ooooool0003o000000?o00001Oooool2o`000003ooooool0
003o000000;o00000_ooool4o`000004ooooool0003o0000ooooo`;o00004Oooool2o`0000_ooooo
0_l00011ooooo`007?ooool00ol0003oooooooooo`13ooooo`?o00000_ooool2o`0000;ooooo1?l0
000<ooooo`;o00003?ooool2o`000003ooooool0003o000000[ooooo0_l000000ooooooo0000o`00
000<ooooo`?o000000?oooooo`000?l000001_ooool3o`000003ooooool0003o000000Gooooo8_l0
00000ooooooo0000o`000003o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`;o00000ooo
ool2o`0000;ooooo1?l000001?oooooo0000o`000?ooool2o`00017ooooo0ol0000:ooooo`?o0000
@?ooool001cooooo00?o0000ooooooooool0@oooool2o`0000?ooooo0_l00002ooooo`;o00000_oo
ool2o`0001Sooooo0_l00002ooooo`;o00006oooool2o`000004ooooool0003o0000o`0000;ooooo
1_l000000ooooooo0000o`000003oooooaGo000000?oooooo`000?l000002ol00003ooooo`Co0000
1_ooool2o`0000Gooooo0_l00002ooooo`Ko00001_ooool2o`00017ooooo1Ol00009ooooo`;o0000
@?ooool001cooooo00?o0000ooooooooool0D?ooool2o`0000gooooo0_l0000=ooooo`;o00003Ooo
ool2o`0000Wooooo0_l00005ooooo`;o00000_ooool5o`0000Cooooo9_l00005ooooo`;o00001_oo
ool2o`0000Gooooo0_l00003ooooo`Co00001oooool4o`0000oooooo0_l000000ooooooo0000o`00
0002o`0004Wooooo000Looooo`03o`000?oooooooooo04_ooooo0_l00003ooooo`;o00000oooool2
o`0000Sooooo0_l00006ooooo`;o00005?ooool2o`0000Wooooo0_l000001?oooooo0000o`000?l0
0008ooooo`;o00001?oooolUo`0000Wooooo0_l0000Looooo`;o00005?ooool2o`0004Wooooo000L
ooooo`03o`000?oooooooooo04_ooooo0_l00003ooooo`;o00000oooool2o`0000Gooooo0_l00000
0ooooooo0000o`000002ooooo`;o00000_ooool2o`0000;ooooo0_l0000@ooooo`?o00001Oooool2
o`0000Cooooo0ol0000=ooooobSo000000?oooooo`000?l000001?ooool2o`0000Oooooo0_l0000C
ooooo`;o00005_ooool2o`0004Oooooo000Looooo`03o`000?oooooooooo05Kooooo0_l00004oooo
o`;o00001Oooool2o`0000Kooooo0_l000001?oooooo0000o`000?l0000=ooooo`;o00001Oooool2
o`000003ooooool0003o0000017ooooo:?l000001?oooooo0000o`000?l0000<ooooo`;o00004?oo
ool2o`0000?ooooo0ol0000Cooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0A?ooool2
o`0000?ooooo0_l00004ooooo`;o00001Oooool3o`00013ooooo0_l00003ooooo`?o00005Oooool4
o`000003ooooool0003o000000Kooooo0_l00007ooooo`So000000?oooooo`000?l000007?l00000
1Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`000?l000000_l000000ooooooo0000o`00
000Cooooo`;o00000oooool3o`0005cooooo000Looooo`03o`000?oooooooooo03Wooooo0ol00008
ooooo`;o00000oooool2o`0000;ooooo1?l00006ooooo`;o00001oooool4o`0000Cooooo0ol00009
ooooo`;o00004?ooool2o`0000?ooooo0_l00006ooooo`;o00001OoooolDo`000003ooooool0003o
000001;o000000Goooooo`000?l0003o0000ooooo`02o`000003ooooool0003o000000;o000000?o
ooooo`000?l000002Oooool2o`000003ooooool0003o000000[ooooo0_l0001Mooooo`007?ooool0
0ol0003oooooooooo`0iooooo`?o00003oooool4o`00017ooooo1?l00004ooooo`;o00000oooool2
o`0000Gooooo0_l00007ooooo`;o00006_ooool3o`000003ooooool0003o000002?o00000_ooool7
o`0000[ooooo0_l00004ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o000000?ooooo
o`000?l00000G_ooool001cooooo00?o0000ooooooooool0??ooool2o`0000Gooooo0_l00006oooo
o`;o00007oooool3o`0000_ooooo0_l000000ooooooo0000o`000004ooooo`;o00004oooool3o`00
0003ooooool0003o000002Co000000?oooooo`000?l000001_l00009ooooo`?o00002Oooool2o`00
00Cooooo0_l000000ooooooo0000o`00000Cooooo`;o0000BOooool001cooooo00?o0000oooooooo
ool0??ooool4o`0000?ooooo0_l0000Wooooo`;o000000?oooooo`000?l000002Oooool2o`0000Oo
oooo0_l00002ooooo`;o00002_ooool2o`0000?ooooo0_l00002ooooobKo000000?oooooo`000?l0
00001?l0000;ooooo`;o00001?ooool2o`0000_ooooo0_l00002ooooo`;o00004Oooool2o`0004Wo
oooo000Looooo`03o`000?oooooooooo03Oooooo0_l00004ooooo`?o00000_ooool2o`0000Oooooo
0_l00005ooooo`;o00001_ooool2o`0001?ooooo0_l0000Dooooo`Co00002_ooool3o`000003oooo
ool0003o000001Oo000000?oooooo`000?l000003_l000000ooooooo0000o`000007o`0000oooooo
0_l000000ooooooo0000o`000008ooooo`Ko00004?ooool4o`0000kooooo0_l0000hooooo`0000Ko
ooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Co
oooo00?o0000ooooooooool0=oooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o
00001oooool2o`0000?ooooo1?l00004ooooo`Co00002?ooool2o`0000Cooooo0ol00007ooooo`Co
00003Oooool2o`0000Cooooo0_l00007ooooo`;o000000?oooooo`000?l000000ol000001Ooooooo
0000o`000?l0003ooooo00oo000000?oooooo`000?l000004ol000000ooooooo0000o`000002o`00
00;ooooo0ol00006ooooo`;o00001Oooool2o`0000[ooooo1_l0000>ooooo`Co00002oooool2o`00
0003ooooool0003o000003Sooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>oooool2o`0001?ooooo0_l00003
ooooo`;o000000?oooooo`000?l000001_ooool2o`0000;ooooo0_l00004ooooo`?o000000Cooooo
o`000?l0003o00000oooool4o`0000kooooo0_l00003ooooo`;o00002?ooool2o`0000;ooooo0_l0
0002ooooob?o000000?oooooo`000?l000000_l00008ooooo`?o00001_ooool2o`0000;ooooo0ol0
00000ooooooo0000o`00000;ooooo`Co00004_ooool2o`0000Wooooo0_l0000kooooo`0000?ooooo
oa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`Go00001_ooool00ol0003oooooooooo`0k
ooooo`;o00006?ooool2o`0000Cooooo1?l000000ooooooo0000o`000005ooooo`;o000000Cooooo
o`000?l0003ooooo1Ol00003ooooo`;o00003oooool4o`0000_ooooo1_l00002ooooo`;o000000?o
ooooo`000?l000007Ol00002ooooo`Co000000?oooooo`000?l000004_ooool3o`000003ooooool0
003o000000;ooooo0_l00003ooooo`;o00005?ooool2o`0000;ooooo0_l00016ooooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0
000oooooo`;o000000?oooooo`000?l000004Oooool2o`0000;ooooo1_l00008ooooo`_o00001Ooo
ool4o`0000;ooooo0_l00004ooooo`;o00000_ooool3o`0000cooooo1?l00002ooooo`;o00001?oo
ool6o`000003ooooool0003o000001Wo00000_ooool2o`0001;ooooo0_l00006ooooo`Co000000?o
ooooo`000?l000001?ooool2o`0000;ooooo0_l0000:ooooo`;o00000oooool2o`0004Gooooo0000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo00001ooo
ool00ol0003oooooooooo`0]ooooo`;o00002oooool3o`0000;ooooo0_l000000ooooooo0000o`00
0002ooooo`;o00000oooool4o`0000Kooooo0_l00002ooooo`;o00001_ooool4o`0000;ooooo1ol0
00001?oooooo0000o`000?l00005ooooo`Co00000_ooool2o`0000Cooooo0_l0000@ooooo`;o0000
0_ooool2o`000003ooooool0003o000000;ooooo5ol000000ooooooo0000o`000008o`0000[ooooo
0_l0000Fooooo`;o00001oooool2o`0000;ooooo0_l0000?ooooo`;o0000AOooool00003ooooool@
413ooooo00;ooooo00?o410@ooooooooool02_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oo
oooooooo02gooooo0_l000000ooooooo0000o`000008ooooo`?o00002Oooool2o`0000?ooooo1?l0
0009ooooo`;o00000_ooool4o`000003ooooool0003o000000?o00000_ooool;o`000003ooooool0
003o000001oooooo1ol00003ooooob;o00000_ooool3o`0000?ooooo0_l000000ooooooo0000o`00
0006ooooo`Co00003?ooool2o`0001Wooooo0_l00006ooooo`;o0000@?ooool00006oooooomgMgOo
V9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo033ooooo
0_l0000>ooooo`;o00001?ooool4o`0000?ooooo1?l00006ooooo`?o000000?oooooo`000?l00000
0ol000000ooooooo0000o`00000Co`0000;ooooo0_l0000Mooooo`oo000000?oooooo`000?l00000
6?l000000ooooooo0000o`000002o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`Co0000
0oooool4o`0000Gooooo0_l00008ooooo`?o00003_ooool2o`0000Kooooo0_l00010ooooo`0000Ko
ooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000oooooooo
ool0?Oooool2o`000004ooooool0003o0000o`0000?ooooo1?l00003ooooo`Ko00001?ooool3o`00
0003ooooool0003o000000?o00000_oooolHo`0000Kooooo1?l0000=ooooo`;o00001_ooool8o`00
0003ooooool0003o000000go000000?oooooo`000?l000003Ol000000ooooooo0000o`000002o`00
00;ooooo0_l00002ooooo`;o00001?ooool3o`000003ooooool0003o000000?ooooo1?l00009oooo
o`;o00000oooool5o`0000[ooooo1?l00007ooooo`;o0000@?ooool001cooooo00?o0000oooooooo
ool0>oooool4o`0000;ooooo0_l0000>ooooo`;o00001Oooool5o`000004ooooool0003o0000o`00
00;ooooo5ol00006ooooo`Co00002?ooool2o`000003ooooool0003o000000;o00000oooool2o`00
0003ooooool0003o000000?o000000Coooooo`000?l0003ooooo8?l000000ooooooo0000o`000005
o`000004ooooool0003o0000o`0000Cooooo0ol000000ooooooo0000o`00000;ooooo`;o00000ooo
ool2o`0000?ooooo0_l000000ooooooo0000o`00000:ooooo`Co00000_ooool2o`0000?ooooo0_l0
0010ooooo`007?ooool00ol0003oooooooooo`0kooooo`?o00006oooool9o`000003ooooool0003o
0000013o000000?oooooo`000?l000000ol00002ooooo`?o00003?ooool2o`000003ooooool0003o
000000Gooooo0_l000000ooooooo0000o`000002o`0000Cooooo1Ol000000ooooooo0000o`000004
o`000003ooooool0003o000001;o000000?oooooo`000?l000002Ol0000Eooooo`;o00007?ooool5
o`0000cooooo0_l0000eooooo`007?ooool00ol0003oooooooooo`0looooo`;o00005?ooool2o`00
00Cooooo4ol00002ooooo`ko000000?oooooo`000?l000000_l00008ooooo`;o00001?ooool2o`00
00_ooooo0_l00002ooooo`Co00000oooool7o`000003ooooool0003o000000Oo000000?oooooo`00
0?l000002?l00008ooooo`;o0000=Oooool2o`000003ooooool0003o000000cooooo0_l0000eoooo
o`007?ooool00ol0003oooooooooo`0iooooo`;o00000oooool2o`00017ooooo0ol00004ooooo`;o
00000ooooolDo`000003ooooool0003o000000Oo000000?oooooo`000?l000000_l00007ooooo`?o
00001?ooool2o`0000Cooooo0_l00009ooooo`?o00000_ooool9o`000003ooooool0003o000000Wo
000000?oooooo`000?l000001_l000000ooooooo0000o`000002o`0000kooooo0_l0000<ooooo`;o
0000I?ooool001cooooo00?o0000ooooooooool0>Oooool2o`0000?ooooo0_l00005ooooo`;o0000
00Coooooo`000?l0003ooooo0_l00004ooooo`;o00000_ooool2o`000004ooooool0003o0000o`00
00;ooooo8ol00007ooooo`;o00000oooool2o`000003ooooool0003o000000?ooooo0_l0000:oooo
o`;o00000_ooool5o`000005ooooool0003o0000o`000?ooool02ol00003ooooo`Ko000000?ooooo
o`000?l000000_l0000>ooooo`;o000000?oooooo`000?l000001?ooool2o`0000?ooooo0_l00005
ooooo`;o00000_ooool2o`0001Gooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`0koooo
o`;o00002?ooool2o`000004ooooool0003o0000ooooo`;o00001?ooool2o`0000;ooooo0_l00002
ooooo`;o00000_oooolQo`0000Gooooo0_l00007ooooo`Go00002_ooool2o`0000?ooooo0_l00000
0ooooooo0000o`000006o`0000?ooooo1_l000000ooooooo0000o`000004ooooo`;o000000?ooooo
o`000?l000000_ooool2o`0001;ooooo2_l0000:ooooo`;o00000_ooool2o`0000;ooooo0ol0000@
ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0>oooool2o`000003ooooool0003o0000
01Gooooo0_l00006oooooaoo00001oooool2o`0000Kooooo1?l0000<ooooo`;o00000oooool2o`00
0003ooooool0003o000000Oo00000_ooool6o`0000;ooooo0_l00003ooooo`;o000000Coooooo`00
0?l0003ooooo0ol0000:ooooo`Go00000oooool2o`0000;ooooo1?l00005ooooo`?o00003?ooool3
o`0000Sooooo0_l00003ooooo`Go0000@_ooool001cooooo00?o0000ooooooooool0?_ooool2o`00
00_ooooo0_l00007ooooo`?o00000oooool2o`000003ooooool0003o000001oo00003Oooool2o`00
01?ooooo0_l000000ooooooo0000o`000007o`0000Cooooo1?l000001?oooooo0000o`000?l00005
ooooo`?o000000Coooooo`000?l0003o00002_ooool5o`000003ooooool0003o000000;o00000ooo
ool3o`0000Gooooo0ol00003ooooo`;o00002Oooool2o`0000Oooooo0_l00003ooooo`Go00001Ooo
ool2o`0003_ooooo000Looooo`03o`000?oooooooooo03kooooo0_l0000;ooooo`;o00001oooool2
o`0000;ooooo5Ol000000ooooooo0000o`00000?o`0002?ooooo0ol000000ooooooo0000o`00000?
o`0000;ooooo0_l000000ooooooo0000o`000003o`0000[ooooo0_l00002ooooo`Co000000?ooooo
o`000?l000000_l00003ooooo`?o00000oooool2o`0000Kooooo1?l00007ooooo`;o00005?ooool4
o`0003_ooooo000Looooo`03o`000?oooooooooo03_ooooo0_l000000ooooooo0000o`000007oooo
o`;o00000_ooool5o`000004ooooool0003o0000ooooo`;o00000_oooolEo`000003ooooool0003o
000000Wo000000Coooooo`000?l0003ooooo1?l00005ooooo`;o00001Oooool5o`00013ooooo1?l0
0004ooooo`go000000Goooooo`000?l0003o0000ooooo`02o`000003ooooool0003o000000;ooooo
0_l00006ooooo`;o00001?ooool2o`0000;ooooo0ol00003ooooo`;o000000Coooooo`000?l0003o
oooo1?l00006ooooo`;o00006?ooool2o`0000?ooooo0_l0000mooooo`007?ooool00ol0003ooooo
ooooo`0`ooooo`;o00000oooool2o`0000Cooooo0_l0000:ooooo`;o00001?ooool3o`000004oooo
ool0003o0000ooooo`Co00000_ooool2o`0000;ooooo6ol000000ooooooo0000o`000002o`000003
ooooool0003o000000?ooooo1?l00005ooooo`Go00004Oooool;o`000004ooooool0003o0000o`00
00?ooooo1_l00008ooooo`;o00000_ooool3o`0001Cooooo2Ol00002ooooo`?o000000?oooooo`00
0?l000000oooool2o`0000?ooooo0_l0000<ooooo`;o00005oooool2o`0002Wooooo000Looooo`;o
0000<Oooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`0001;ooooo0_l000000ooooooo
0000o`000003ooooo`;o00000_ooool4o`0000;ooooo3ol000000ooooooo0000o`000007o`000003
ooooool0003o000000;o00001_ooool2o`0000Oooooo0_l0000Dooooo`;o000000?oooooo`000?l0
00004ol000000ooooooo0000o`000009ooooo`?o00002oooool2o`0000?ooooo0_l00003ooooo`So
00000_ooool3o`000003ooooool0003o000000?ooooo0ol00002ooooo`;o00000oooool2o`000003
ooooool0003o000000Wooooo0_l0000<ooooo`;o00001?ooool2o`0002Wooooo000Looooo`03o`00
0?oooooooooo03Cooooo0_l00002ooooo`Go00004Oooool2o`000003ooooool0003o000000Kooooo
0_l000000ooooooo0000o`00000Ao`000003ooooool0003o000000ko00000_ooool2o`0001Cooooo
0_l0000Dooooo`;o00000_ooool4o`0000;ooooo0_l00002ooooo`;o00001Oooool2o`0000Kooooo
1_l000001?oooooo0000o`000?ooool2o`0000?ooooo0ol00005ooooo`;o000000?oooooo`000?l0
00000oooool2o`0000Oooooo0ol000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l0
00002Oooool2o`0000cooooo0_l0000_ooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o0000
1_ooool2o`0000;ooooo1Ol0000Fooooo`?o00000_ooool3o`000003ooooool0003o000002;o0000
0_ooool2o`00013ooooo0_l00002ooooo`;o00001_ooool2o`000003ooooool0003o000000Kooooo
0_l00009ooooo`;o00002oooool2o`0000Kooooo1_l000000ooooooo0000o`000007ooooo`;o0000
2?ooool2o`0000?ooooo0_l00007ooooo`?o000000?oooooo`000?l000000_l0001>ooooo`007?oo
ool00ol0003oooooooooo`0/ooooo`;o000000?oooooo`000?l000001oooool2o`0000Cooooo0_l0
0009ooooo`;o00002?ooool3o`0000;ooooo0_l00004oooooa;o000000?oooooo`000?l000002Ol0
000Gooooo`Co00002Oooool2o`000003ooooool0003o000000Kooooo0_l00004ooooo`?o00000_oo
ool3o`0001?ooooo0_l0000?ooooo`;o000000Coooooo`000?l0003ooooo1?l00005ooooo`;o0000
1_ooool2o`0000?ooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00002Ooo
ool2o`0000;ooooo0_l00009ooooo`;o00003_ooool2o`0000;ooooo7ol0000:ooooo`;o00002ooo
ool4o`0000Cooooo0_l00003ooooo`;o00003oooool3o`0000?ooooo0_l0000Sooooo`?o000000Co
ooooo`000?l0003ooooo1?l00005ooooo`?o00001Oooool2o`0000Gooooo1Ol00019ooooo`007?oo
ool00ol0003oooooooooo`0aooooo`;o00000oooool3o`000004ooooool0003o0000ooooo`?o0000
5_ooool2o`000003ooooool0003o000000Co00000_oooolMo`0000Oooooo0ol0000Cooooo`;o0000
1oooool2o`00017ooooo0_l000000ooooooo0000o`000005ooooo`;o00000_ooool2o`0001Cooooo
0ol00002ooooo`;o00000oooool2o`0000Kooooo0_l0000<ooooo`Go0000BOooool001cooooo00?o
0000ooooooooool0<Oooool2o`0000?ooooo0ol000001?oooooo0000o`000?ooool3o`0000?ooooo
1?l0000?ooooo`;o00000_ooool3o`0000Kooooo6ol00007ooooo`;o00000_ooool2o`0001Wooooo
0_l00004ooooo`;o00002oooool2o`000003ooooool0003o000000Gooooo0_l00002ooooo`;o0000
1Oooool2o`0000Oooooo0_l00004ooooo`;o00000oooool2o`0000;ooooo0_l0000Rooooo`;o0000
3_ooool2o`0002oooooo000Looooo`03o`000?oooooooooo03;ooooo0_l00003ooooo`;o00002_oo
ool4o`0000Kooooo0_l0000;ooooo`;o000000Goooooo`000?l0003o0000ooooo`0Ko`0000gooooo
0_l00004ooooo`;o00001_ooool2o`00017ooooo0_l00004ooooo`?o00003?ooool2o`0000Oooooo
0_l00002ooooo`;o000000?oooooo`000?l000001?ooool2o`0000gooooo0_l00004ooooo`;o0000
2oooool2o`0000Kooooo0_l00007ooooo`;o00003_ooool2o`0002oooooo000Looooo`03o`000?oo
oooooooo037ooooo0ol00003ooooo`;o00005?ooool2o`0000[ooooo0ol000001Ooooooo0000o`00
0?l0003ooooo01co00003?ooool2o`0000Cooooo0_l00006ooooo`;o000000?oooooo`000?l00000
5?ooool3o`0000cooooo0_l00007ooooo`;o00001Oooool2o`0000;ooooo0_l0000<ooooo`;o0000
0_ooool2o`0000?ooooo0_l00008ooooo`;o000000?oooooo`000?l000001_ooool4o`0004Kooooo
000Looooo`03o`000?oooooooooo037ooooo0_l00004ooooo`;o00001_ooool2o`0000Cooooo0_l0
000@ooooo`Co00002?ooool6o`000003ooooool0003o0000017o00000oooool3o`000003ooooool0
003o000000;ooooo0_l0000:ooooo`;o00000oooool3o`0001_ooooo0_l00006ooooo`;o00004_oo
ool2o`0000[ooooo1?l00002ooooo`;o00000_ooool3o`0000Sooooo0ol00008ooooo`Co00000_oo
ool4o`0000?ooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0jooooo`;o00000oooool2
o`0000?ooooo0ol0000@ooooo`Co00001_ooool2o`0000?ooooo0ol000001Ooooooo0000o`000?l0
003ooooo00Co00000_ooool7o`0000Gooooo0ol000000ooooooo0000o`000002ooooo`;o00002_oo
ool2o`0000?ooooo0_l0000Looooo`;o00009_ooool3o`000003ooooool0003o000000;o00000_oo
ool2o`0000Wooooo0ol00009ooooo`;o00000oooool4o`0000?ooooo0_l0000kooooo`007?ooool0
0ol0003oooooooooo`0jooooo`;o00001?ooool6o`0000;ooooo0_l0000>ooooo`?o00000oooool2
o`000003ooooool0003o000000?ooooo0_l00003ooooo`?o00001Oooool9o`000003ooooool0003o
000001[ooooo1?l00003ooooo`;o00005Oooool2o`0002[ooooo1?l00007ooooo`;o00001?ooool2
o`00013ooooo1?l0000oooooo`007?ooool00ol0003oooooooooo`0booooo`;o00003?ooool:o`00
0003ooooool0003o000000Sooooo0_l000000ooooooo0000o`000004ooooo`;o00001oooool2o`00
00?ooooo0_l00005ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o00005oooool2
o`000003ooooool0003o000000;o00000oooool2o`0002_ooooo0_l0000Gooooo`;o00000_ooool2
o`0000;ooooo1?l00009ooooo`?o00002?ooool4o`0000?ooooo0_l0000jooooo`007?ooool00ol0
003oooooooooo`0booooo`;o00001oooool2o`0000Kooooo1_l00002ooooo`;o00002?ooool2o`00
00;ooooo0_l00002ooooo`;o00002?ooool4o`0000?ooooo0_l0000Mooooo`;o00001oooool2o`00
00?ooooo0_l00002ooooo`;o00000_ooool2o`0002Oooooo0ol0000Gooooo`;o00000_ooool2o`00
00;ooooo1?l00002ooooo`;o00001Oooool3o`000003ooooool0003o000000Oooooo0_l00003oooo
o`;o0000>_ooool001cooooo00?o0000ooooooooool0;Oooool2o`0000Oooooo0_l00003ooooo`;o
00007?ooool2o`0000;ooooo0_l0000:ooooo`;o00000oooool2o`0000kooooo0_l0000=ooooo`;o
00002_ooool2o`0000Cooooo0_l00002ooooo`;o00001Oooool2o`0000Sooooo0_l00002ooooo`;o
00000_ooool2o`0000Sooooo0_l00004ooooo`;o00004oooool2o`0000_ooooo0ol00003ooooo`;o
00002Oooool2o`0001Oooooo0_l0000_ooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o0000
1Oooool4o`0000Cooooo0_l00003ooooo`;o00002oooool4o`0000_ooooo0_l0000Cooooo`;o0000
1oooool2o`000003ooooool0003o000000Sooooo0_l00008ooooo`;o00000oooool4o`0000oooooo
0_l00008ooooo`;o00000_ooool2o`0000;ooooo0_l00008ooooo`;o00003oooool3o`0000Oooooo
0_l00003ooooo`;o00001oooool2o`0001gooooo0_l00008ooooo`;o0000;oooool001cooooo0_l0
000dooooo`?o00001_ooool2o`0000?ooooo0ol0000:ooooo`Co00005?ooool2o`0000Wooooo1_l0
0004ooooo`;o00002_ooool3o`0000Sooooo1?l000000ooooooo0000o`000002ooooo`;o00001Ooo
ool6o`0001oooooo0_l00003ooooo`;o00001?ooool2o`0000?ooooo0ol0000;ooooo`?o00001ooo
ool2o`0000oooooo0_l00004ooooo`;o00001_ooool2o`0003Wooooo000Looooo`03o`000?oooooo
oooo03?ooooo0_l00004ooooo`;o00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000002
o`000003ooooool0003o000000Cooooo0_l000001?oooooo0000o`000?ooool4o`0000cooooo0_l0
0009ooooo`Ko00004?ooool2o`000003ooooool0003o000000Kooooo1?l00005ooooo`;o00001Ooo
ool8o`000003ooooool0003o000000Cooooo0_l00005ooooo`;o00000oooool2o`0000?ooooo0_l0
0003ooooo`;o00000oooool2o`0000?ooooo0ol00003ooooo`;o00002_ooool6o`0001Oooooo0_l0
0004ooooo`Go00001Oooool2o`0003Oooooo000Looooo`03o`000?oooooooooo03;ooooo0ol00004
ooooo`Co000000?oooooo`000?l000001Oooool4o`000003ooooool0003o000000Cooooo0_l00000
1?oooooo0000o`000?ooool4o`0000Gooooo0_l0000=ooooo`;o00000_ooool3o`0001Gooooo0_l0
0006ooooo`;o00004Oooool8o`0000Cooooo0_l00005ooooo`?o00000_ooool2o`0000?ooooo0_l0
000=ooooo`;o00000_ooool2o`0000Wooooo0_l000000ooooooo0000o`000002ooooo`;o00001?oo
ool2o`0000cooooo0_l000000ooooooo0000o`000007ooooo`Co00001Oooool2o`0000Cooooo0_l0
000aooooo`007?ooool00ol0003oooooooooo`0booooo`;o00001oooool2o`0000Kooooo0_l00000
0ooooooo0000o`00000>ooooo`;o00001oooool2o`0000gooooo0_l00003ooooo`;o00004?ooool2
o`0001gooooo0ol00002ooooo`;o00003Oooool3o`0000Sooooo0_l00004ooooo`;o00001_ooool3
o`000003ooooool0003o000000?ooooo1?l00002ooooo`;o000000?oooooo`000?l000000_l00006
ooooo`;o00002?ooool2o`0000;ooooo0_l000000ooooooo0000o`000009ooooo`;o00002oooool2
o`00037ooooo000Looooo`03o`000?oooooooooo04?ooooo0_l000000ooooooo0000o`00000Doooo
o`;o00005?ooool2o`0000gooooo0_l00002ooooo`;o00001_ooool2o`0001Gooooo1Ol00003oooo
o`;o00005Oooool2o`0000Cooooo0_l00006ooooo`ko00001?ooool4o`0000Oooooo0_l00003oooo
o`;o00000_ooool2o`000003ooooool0003o000000gooooo0ol00003ooooo`;o0000>?ooool001co
oooo00?o0000ooooooooool0<oooool2o`00017ooooo0_l000001?oooooo0000o`000?l00004oooo
o`;o00002_ooool2o`0001Cooooo0_l00006ooooo`;o00001Oooool2o`0000[ooooo0_l00004oooo
o`;o00004Oooool4o`0000;ooooo0_l00002ooooo`;o00002_ooool5o`0000;ooooo0_l000000ooo
oooo0000o`000002ooooo`;o00000oooool@o`0000Cooooo0_l00009ooooo`;o00000oooool4o`00
00?ooooo0ol00003ooooo`;o00002?ooool3o`0000;ooooo0_l0000hooooo`007?ooool00ol0003o
ooooooooo`0cooooo`;o00001_ooool2o`0000Wooooo1_l00004ooooo`;o00000oooool2o`0000Co
oooo1Ol0000@ooooo`;o00002?ooool2o`0000Gooooo0_l00009ooooo`;o00000_ooool2o`000003
ooooool0003o000001;ooooo1Ol00002ooooo`Wo000000Goooooo`000?l0003o0000ooooo`05o`00
00Gooooo0_l00002ooooo`;o00000oooool@o`0000;ooooo1_l0000<ooooo`Co00000oooool3o`00
00?ooooo0_l00009ooooo`;o0000??ooool001cooooo00?o0000ooooooooool0>oooool2o`0000Wo
oooo1?l0000;ooooo`;o00001?ooool2o`000003ooooool0003o0000013ooooo0_l0000=ooooo`Co
00002Oooool2o`0000;ooooo0_l0000?ooooo`;o00001oooool6o`0000;ooooo1Ol000000ooooooo
0000o`000003o`0000gooooo7Ol00006ooooo`;o00002oooool2o`0000Cooooo0_l00017ooooo`00
7?ooool00ol0003oooooooooo`0cooooo`;o000000Coooooo`000?l0003o00000oooool2o`0000So
oooo0_l00004ooooo`;o000000?oooooo`000?l000002oooool2o`00027ooooo0_l00004ooooo`;o
00006_ooool2o`0000;ooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l000000ooooooo
0000o`00000:oooooago00000oooool5o`0000_ooooo0_l000000ooooooo0000o`000008ooooo`;o
00001_ooool2o`0003Sooooo000Looooo`03o`000?oooooooooo03?ooooo0_l000001?oooooo0000
o`000?l00003ooooo`;o00002_ooool2o`0000;ooooo0_l000000ooooooo0000o`000006ooooo`;o
00000oooool2o`0000_ooooo0_l0000:ooooo`;o00001oooool2o`0000;ooooo0_l000000ooooooo
0000o`00000Nooooo`;o00001Oooool2o`00013ooooo0_l000000ooooooo0000o`000008oooooaco
00000oooool4o`0000oooooo0_l00008ooooo`;o00001_ooool2o`0003Sooooo000Looooo`03o`00
0?oooooooooo03Kooooo0_l0000<ooooo`Ko00003Oooool2o`0000cooooo0_l00002ooooo`Co0000
2?ooool2o`0000Oooooo0ol000001?oooooo0000o`000?ooool2o`0000cooooo0_l00008ooooo`;o
00001_ooool2o`0000_ooooo1?l00003ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`00
0003ooooool0003o000000Gooooo6?l000001?oooooo0000o`000?l00002ooooo`;o000000?ooooo
o`000?l000003?ooool2o`0004gooooo000Looooo`03o`000?oooooooooo02[ooooo0_l0000Hoooo
o`Co00001oooool2o`000004ooooool0003o0000o`0000Oooooo1_l00003ooooo`;o00000oooool3
o`000003ooooool0003o000000Gooooo0ol00002ooooo`;o00000oooool2o`0000;ooooo1?l0000<
ooooo`;o00002?ooool4o`0000?ooooo1?l0000:ooooo`Co00000oooool2o`000004ooooool0003o
0000o`0000Gooooo0_l00003oooooago00000oooool2o`0000oooooo0_l000000ooooooo0000o`00
0008ooooo`?o0000?oooool001cooooo00?o0000ooooooooool0:_ooool2o`0001gooooo0_l00003
ooooo`?o000000Coooooo`000?l0003o00001oooool6o`0000cooooo0_l00006ooooo`;o00000_oo
ool2o`0000Oooooo0_l00005ooooo`;o000000?oooooo`000?l000001Oooool4o`0000Oooooo0_l0
0003ooooo`Co00005?ooool2o`0000Kooooo0_l00003oooooa_o000000Coooooo`000?l0003ooooo
1?l0000Aooooo`;o00002?ooool3o`0000Cooooo0_l0000iooooo`007?ooool00ol0003ooooooooo
o`0aooooo`;o00002oooool2o`0000Cooooo0_l00003ooooo`Co000000?oooooo`000?l000001ooo
ool2o`0000Cooooo0_l0000Kooooo`;o00003_ooool2o`000003ooooool0003o000000Gooooo1_l0
00000ooooooo0000o`00000Iooooo`?o00002oooool2o`0000;ooooo7ol000000ooooooo0000o`00
0002o`000003ooooool0003o0000017ooooo0_l00008ooooo`;o00000_ooool2o`0003Wooooo000L
ooooo`03o`000?oooooooooo037ooooo0_l00005ooooo`;o00001?ooool2o`0000Cooooo0_l00005
ooooo`;o00002_ooool2o`0001?ooooo0_l0000=ooooo`;o00001Oooool2o`0001?ooooo0ol00000
0ooooooo0000o`000005ooooo`;o00004_ooool5o`0000gooooo6_l000000ooooooo0000o`000008
ooooo`;o000000?oooooo`000?l000003_ooool2o`0000Sooooo0_l0000mooooo`007?ooool00ol0
003oooooooooo`0aooooo`;o000000?oooooo`000?l000000_ooool2o`0001kooooo0_l00005oooo
o`;o00002?ooool2o`000003ooooool0003o000000Co00002Oooool3o`0000Cooooo0_l0000Noooo
o`;o00003Oooool2o`000003ooooool0003o000000?ooooo1?l0000;oooooa[o00000oooool2o`00
00Wooooo0_l00004ooooo`;o00004?ooool2o`0001[ooooo0_l0000Sooooo`007?ooool2o`0003;o
oooo0_l000000ooooooo0000o`00000<ooooo`;o00005?ooool6o`000003ooooool0003o000000So
oooo0_l00003ooooo`Co00001oooool5o`0001Cooooo0_l00003ooooo`;o00005?ooool2o`0000;o
oooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00007ooooo`;o00000_ooool2o`00
0005ooooool0003o0000o`000?ooool05?l00002ooooo`;o00003oooool2o`0000;ooooo0ol00003
ooooo`?o00001Oooool2o`0001[ooooo0_l0000Sooooo`007?ooool00ol0003oooooooooo`0boooo
o`;o00003_ooool2o`0000?ooooo0_l00003ooooo`;o00003?ooool4o`0001Kooooo0_l00003oooo
o`Co00002Oooool2o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o00000oooool2o`00
017ooooo1ol00003ooooo`Go00000_ooool2o`0000Oooooo0_l00002ooooo`;o000000Goooooo`00
0?l0003o0000ooooo`0Do`0000Cooooo0_l0000Aooooo`?o00000oooool3o`0004Kooooo000Loooo
o`03o`000?oooooooooo033ooooo1?l00004ooooo`;o00002Oooool3o`000003ooooool0003o0000
00?ooooo0_l0000Uooooo`?o00004?ooool2o`000003ooooool0003o000000?ooooo0ol000000ooo
oooo0000o`000002o`000003ooooool0003o0000017ooooo2Ol00003ooooo`;o00000_ooool4o`00
00Kooooo0_l00002ooooo`?o000000?oooooo`000?l000005?l00005ooooo`;o00001Oooool2o`00
01cooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0`ooooo`Co00001?ooool2o`0000Wo
oooo0ol0000:ooooo`;o00008Oooool2o`0000;ooooo0_l0000Dooooo`Co00000oooool2o`0000Go
oooo0_l0000?ooooo`Co000000?oooooo`000?l000001?ooool7o`0000Kooooo0_l00003ooooo`;o
000000?oooooo`000?l000003_l000001?oooooo0000o`000?l00007ooooo`;o00001Oooool2o`00
01Kooooo0_l00004ooooo`?o0000>_ooool001cooooo00?o0000ooooooooool0<Oooool2o`0000ko
oooo0_l00002ooooo`;o00001_ooool2o`000004ooooool0003o0000ooooo`;o00004?ooool2o`00
013ooooo0_l00002ooooo`;o000000?oooooo`000?l000003Oooool2o`0000Cooooo0_l00006oooo
o`;o00000_ooool4o`0000Sooooo1?l00006ooooo`Go00001?ooool2o`0000gooooo0ol000000ooo
oooo0000o`00000=o`0001cooooo0_l00008ooooo`;o000000?oooooo`000?l000000_ooool2o`00
03[ooooo000Looooo`03o`000?oooooooooo02[ooooo0_l00005ooooo`;o00003_ooool2o`0000;o
oooo0_l00006ooooo`Go000000?oooooo`000?l000004?ooool2o`0001;ooooo1?l000000ooooooo
0000o`00000Cooooo`;o00002_ooool4o`0000Sooooo0_l00008ooooo`Co00000oooool5o`0000_o
oooo0_l00003ooooo`So000000?oooooo`000?l000001?l0000Looooo`;o00002oooool2o`0003ko
oooo000Looooo`03o`000?oooooooooo02[ooooo0_l00005ooooo`;o00001_ooool2o`0000Kooooo
0_l00003ooooo`;o00001oooool2o`0001Wooooo0_l000000ooooooo0000o`000002o`0000Sooooo
1?l000000ooooooo0000o`00000>ooooo`;o00001oooool2o`0000;ooooo2?l00008ooooo`;o0000
2_ooool2o`0000?ooooo0_l000000ooooooo0000o`000007ooooo`;o00000_ooool2o`000003oooo
ool0003o000000So00001Oooool4o`000003ooooool0003o000000?ooooo0_l00003ooooo`;o0000
0oooool2o`0005Gooooo000Looooo`03o`000?oooooooooo037ooooo0_l00004ooooo`Co00000ooo
ool2o`0000Kooooo0_l00006ooooo`?o00000oooool2o`0001Cooooo0_l000000ooooooo0000o`00
0004o`0000Cooooo0_l00002ooooo`Oo00001_ooool2o`000004ooooool0003o0000ooooo`;o0000
1oooool2o`0000;ooooo2?l0000?ooooo`;o00005?ooool4o`0000;ooooo2Ol000000ooooooo0000
o`000006ooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo0_l00002ooooo`?o0000
1Oooool2o`0000;ooooo0_l0000<ooooo`;o0000??ooool001cooooo00?o0000ooooooooool0=ooo
ool2o`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l000001oooool2o`0000Cooooo0_l0
000;ooooo`;o00001oooool4o`0000?ooooo0_l00002ooooo`Co00000_ooool:o`000003ooooool0
003o000000Go00002Oooool2o`0000Gooooo0_l0000<ooooo`;o00001Oooool2o`0000cooooo0_l0
00000ooooooo0000o`000005ooooo`;o00000_ooool7o`0000;ooooo0ol00006ooooo`Co00000_oo
ool3o`0000Cooooo0_l00002ooooo`;o00001_ooool6o`0000Cooooo0_l00005ooooo`?o0000??oo
ool001cooooo00?o0000ooooooooool09oooool2o`0000kooooo0_l00009ooooo`;o000000?ooooo
o`000?l000001_ooool4o`000004ooooool0003o0000ooooo`;o00002_ooool2o`0000?ooooo0_l0
0002ooooo`Go00000_ooool2o`000003ooooool0003o000001Ko00000_ooool2o`0000Kooooo0_l0
0005ooooo`;o00001Oooool2o`0000;ooooo1Ol00002ooooo`;o00000_ooool3o`000003ooooool0
003o000000Cooooo0_l000000ooooooo0000o`000003o`0000[ooooo0_l00006ooooo`;o000000?o
ooooo`000?l000001_ooool2o`0000;ooooo0ol00002ooooo`Co00002?ooool2o`0000;ooooo1?l0
0004ooooo`;o00001Oooool2o`0003gooooo000Looooo`03o`000?oooooooooo02Oooooo0_l0000>
ooooo`?o00004Oooool6o`000004ooooool0003o0000ooooo`;o00002Oooool2o`0000Cooooo0_l0
0005ooooo`;o00001Oooool3o`000003ooooool0003o0000017o00000oooool2o`0000Cooooo0_l0
0005ooooo`Co00001Oooool2o`000003ooooool0003o000000;o00001?ooool2o`0000;ooooo0ol0
00000ooooooo0000o`000004ooooo`;o00000_ooool3o`0000_ooooo0_l00008ooooo`Co00000_oo
ool2o`000003ooooool0003o000000Oooooo0_l00007ooooo`Go00001?ooool2o`0000;ooooo0_l0
0005ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0<oooool2o`0000;ooooo0ol00002
ooooo`;o00001oooool2o`0000Cooooo0_l000000ooooooo0000o`00000@ooooo`;o00002oooool2
o`0000Gooooo0ol000000ooooooo0000o`00000Co`0000Oooooo0_l00005ooooo`;o00002_ooool2
o`0001Sooooo0_l0000Fooooo`Co00000_ooool2o`0000Gooooo0_l0000<ooooo`Go00002?ooool2
o`0000Gooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0aooooo`Co000000?oooooo`00
0?l000000oooool3o`0000Oooooo0_l00004ooooo`;o00004_ooool4o`0000oooooo7Ol00002oooo
o`;o000000?oooooo`000?l000000oooool3o`0000gooooo0_l0000Fooooo`;o00000_ooool2o`00
01[ooooo0_l00003ooooo`;o00003_ooool4o`0001cooooo0_l0000aooooo`007?ooool00ol0003o
ooooooooo`0aooooo`;o00000oooool3o`0000;ooooo0_l0000;ooooo`;o000000?oooooo`000?l0
00004_ooool4o`0000oooooo7_l000000ooooooo0000o`000006ooooo`?o00002?ooool2o`0000?o
oooo0_l00006ooooo`;o00001oooool2o`0000Wooooo0_l00004ooooo`;o00001Oooool2o`0000?o
oooo0_l00008ooooo`;o00001_ooool2o`0000;ooooo0_l00007ooooo`Co00002oooool2o`0000oo
oooo0_l0000aooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^
k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0<oooool2o`0000;ooooo0_l0000?
ooooo`;o00006oooool2o`0000?ooooo0_l00006ooooo`;o000000?oooooo`000?l000005_l00000
1?oooooo0000o`000?l00003ooooo`;o00003_ooool2o`0000_ooooo0_l000001Ooooooo0000o`00
0?l0003ooooo00Co00003oooool2o`0000Gooooo0_l00003ooooo`;o00004?ooool6o`0000Kooooo
0ol0000=ooooo`;o00000oooool2o`0000Gooooo0_l0000fooooo`0000KoooooogMgMonHV9Sooooo
oiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000oooo
ooooool0<Oooool8o`0002cooooo0_l00003ooooo`;o00001_ooool9o`0000;ooooo5Ol00002oooo
o`Co00005oooool2o`0000;ooooo1ol00002ooooo`;o00003_ooool4o`0000Cooooo0_l0000Eoooo
o`?o00001oooool2o`0000Cooooo0_l00009ooooo`?o000000?oooooo`000?l000001Oooool3o`00
03Gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo037ooooo1_l0000Iooooo`?o00000_ooool2o`00
013ooooo1?l00009oooooaoo00000oooool2o`0001Oooooo0ol000001?oooooo0000o`000?ooool3
o`000003ooooool0003o000000;o000000?oooooo`000?l000002oooool4o`000004ooooool0003o
0000ooooo`;o00007oooool2o`0000?ooooo0ol00003ooooo`;o00001?ooool3o`0000?ooooo0_l0
0004ooooo`;o0000=Oooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool0
1Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0000cooooo`;o00005_ooool4o`000004ooooool0
003o0000o`0000;ooooo0_l0000@ooooo`Go00000_ooool2o`0000Cooooo7ol0000Loooooa;o0000
4?ooool2o`0000Cooooo0ol0000Aooooo`;o00001_ooool2o`0000Gooooo0_l00004ooooo`?o0000
2Oooool2o`0003_ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go
0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo04_ooooo1?l0000Iooooo`Co0000
0_ooool2o`0000Cooooo3Ol000000ooooooo0000o`00000<o`0001Oooooo0_l00003ooooo`?o0000
00?oooooo`000?l000003_l00008ooooo`Ko00002Oooool3o`0000Wooooo0_l00003ooooo`Go0000
1_ooool4o`000003ooooool0003o000000?ooooo0_l00002ooooo`Co0000A?ooool00003ooooool@
413ooooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo03Cooooo0ol0000>ooooo`;o00001?ooool2o`0000Sooooo0_l00006ooooo`;o00002Ooo
ool3o`0000Wooooo7Ol0000Fooooo`;o00000ooooolGo`0000Gooooo1_l0000:ooooo`;o00002Ooo
ool2o`0000?ooooo1?l00003ooooo`Go000000?oooooo`000?l000000ol00003ooooo`;o00000ooo
ool3o`0000;ooooo0_l00010ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgM
gOl@413oV9RH00Sooooo00?o0000ooooooooool0=?ooool3o`0000;ooooo0_l0000:ooooo`;o0000
1?ooool2o`0000;ooooo0_l00004ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`;o
00001oooool2o`0000Sooooo7_l00006ooooo`;o00003oooool3o`0000;ooooo1_l000000ooooooo
0000o`00000=o`0001;ooooo0_l000000ooooooo0000o`00000Booooo`;o000000?oooooo`000?l0
00000ol00002ooooo`?o00002Oooool2o`0000?ooooo0_l00010ooooo`0000Koooooonk^k_lb<S;o
0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0=Oooool2
o`0000;ooooo0_l0000>ooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o00000_oo
ool5o`000004ooooool0003o0000o`0000Kooooo0_l00009oooooako00001_ooool2o`0000oooooo
0ol000000ooooooo0000o`000009o`000003ooooool0003o000000_o00004?ooool2o`0000Wooooo
0_l00004ooooo`;o00001?ooool2o`0000;ooooo1?l00003ooooo`;o00001?ooool4o`0004Sooooo
000Looooo`03o`000?oooooooooo03[ooooo0_l00008ooooo`;o00000oooool2o`000003ooooool0
003o000000?ooooo0_l00002ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o0000
1oooool3o`0000Sooooo7Ol00002ooooo`;o00001oooool2o`0000?ooooo0_l00007oooooaco0000
4?ooool2o`0000Wooooo0_l00004ooooo`Go00001Oooool3o`0000[ooooo1?l00018ooooo`007?oo
ool00ol0003oooooooooo`0jooooo`;o00002?ooool2o`0000_ooooo0_l000000ooooooo0000o`00
0006ooooo`;o00001?ooool6o`000003ooooool0003o000000Kooooo0_l000000ooooooo0000o`00
000Io`0000?ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0ol00006oooooa[o00004_oo
ool2o`0000_ooooo0_l00004ooooo`?o00001_ooool2o`0005Kooooo000Looooo`03o`000?oooooo
oooo037ooooo0_l000000ooooooo0000o`000002ooooo`;o00002_ooool2o`0000kooooo1ol00000
0ooooooo0000o`000004ooooo`Ko00002Oooool2o`0000;ooooo7?l00006ooooo`Co00001_ooool2
o`0000Kooooo6_l0000Oooooo`;o00006Oooool2o`0004[ooooo000Looooo`03o`000?oooooooooo
033ooooo0ol000000ooooooo0000o`000002ooooo`;o00001?ooool2o`0000gooooo0_l00007oooo
o`Go000000?oooooo`000?l000001_ooool8o`0000Sooooo6Ol00002ooooo`;o00002?ooool4o`00
0003ooooool0003o000000Sooooo6ol0000?ooooo`;o00006oooool4o`0000[ooooo0_l0001:oooo
o`007?ooool00ol0003oooooooooo`0`ooooo`;o00000oooool2o`0000?ooooo0_l00002ooooo`;o
00002Oooool2o`0000;ooooo0ol0000Fooooo`Ko00001_ooool4o`000003ooooool0003o000001;o
00000oooool4o`0000Cooooo0_l00003ooooo`;o000000?oooooo`000?l000001Oooool2o`000003
ooooool0003o000001So00001?ooool2o`0000[ooooo0_l00008ooooo`;o00001oooool2o`0000So
oooo1?l000000ooooooo0000o`00001Cooooo`007?ooool00ol0003oooooooooo`0booooo`Oo0000
00?oooooo`000?l000003Oooool7o`0001Kooooo0_l00003ooooo`;o000000?oooooo`000?l00000
0_ooool4o`0000;ooooo2_l000000ooooooo0000o`000006o`0000?ooooo1?l000001?oooooo0000
o`000?ooool2o`0000cooooo0ol000000ooooooo0000o`00000Go`0000Gooooo0_l0000Dooooo`;o
00001oooool2o`0000gooooo0_l00002ooooo`;o00000oooool2o`0004[ooooo000Looooo`03o`00
0?oooooooooo03;ooooo0ol00002ooooo`;o000000?oooooo`000?l000003oooool3o`0000Gooooo
0_l0000Fooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo1?l000000ooooooo0000
o`000009o`000003ooooool0003o000000;o00002?ooool2o`0000oooooo0_l00003oooooaWo0000
9_ooool2o`0000Kooooo0_l00006ooooo`Oo0000B_ooool001cooooo00?o0000ooooooooool0<_oo
ool2o`0000cooooo0_l0000;ooooo`;o00001?ooool2o`0000?ooooo0_l00009ooooo`;o00004Ooo
ool4o`000003ooooool0003o000000So00004Oooool2o`0000Kooooo1?l00003ooooo`;o00000_oo
oolIo`000003ooooool0003o000000oooooo0_l00003ooooo`;o00003Oooool2o`0000Kooooo0_l0
0004ooooo`;o00000_ooool3o`0004cooooo000Looooo`03o`000?oooooooooo03;ooooo0_l0000<
ooooo`;o00002oooool2o`0000Wooooo1?l00007ooooo`;o00004_ooool2o`0000;ooooo0ol00000
0ooooooo0000o`000004o`000003ooooool0003o000000kooooo0_l00006ooooo`Co00000oooool2
o`000003ooooool0003o000001So000000?oooooo`000?l000003oooool2o`0000?ooooo0_l0000D
ooooo`;o00001Oooool2o`00017ooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0boooo
o`;o00000_ooool3o`00017ooooo1?l00008ooooo`;o00000_ooool4o`0001Wooooo0_l00005oooo
o`Co000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00000Joooooa7o000000?ooooo
o`000?l000002Ol000000ooooooo0000o`00000Zooooo`;o00002_ooool2o`0000Kooooo0_l00004
ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0<_ooool2o`0000;ooooo0ol0000Aoooo
o`Co00002?ooool2o`0000Cooooo0_l00003ooooo`;o00001_ooool2o`0000[ooooo1?l00005oooo
o`;o00002Oooool2o`0000oooooo0_l00002ooooo`;o00001ooooolIo`0001Kooooo0_l0000Hoooo
o`;o000000?oooooo`000?l000002?l00006ooooo`;o0000A?ooool001cooooo0_l0001:ooooo`Co
00001Oooool4o`0000Kooooo0_l00003ooooo`;o00001_ooool2o`0000Kooooo0_l00002ooooo`;o
000000?oooooo`000?l000008?ooool2o`0000;ooooo0_l00008ooooo`Wo000000?oooooo`000?l0
00003Ol00004ooooo`;o00001Oooool2o`0000Sooooo0_l0000Hooooo`;o000000?oooooo`000?l0
00002?l0001<ooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00002_ooool4o`0000Gooooo
1?l00006ooooo`;o00004oooool2o`0000Gooooo0_l00005ooooo`;o00003_ooool2o`0000Cooooo
0_l00003ooooo`;o00000_ooool2o`0000Sooooo6Ol00004ooooo`;o00001Oooool2o`0001oooooo
1Ol00009ooooo`;o00001Oooool2o`0004Gooooo000Looooo`03o`000?oooooooooo037ooooo0_l0
00000ooooooo0000o`000007ooooo`;o00003?ooool2o`0000Cooooo0_l00008ooooo`;o00004_oo
ool3o`0000gooooo0_l0000=ooooo`?o00001?ooool2o`0000?ooooo0_l00002ooooo`;o00001_oo
ool<o`000003ooooool0003o000000_o0000;Oooool5o`00013ooooo0_l00015ooooo`007?ooool0
0ol0003oooooooooo`0aooooo`;o000000?oooooo`000?l000002_ooool2o`0000Wooooo0_l00004
ooooo`;o00001_ooool4o`0000Wooooo0_l00002ooooo`?o00000_ooool5o`00013ooooo0_l00007
ooooo`?o00001Oooool2o`0000oooooo6_l00002ooooo`;o00007_ooool2o`000003ooooool0003o
000000;o00001_ooool2o`0001Sooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0`oooo
o`;o00001?ooool2o`0000Sooooo0_l00009ooooo`;o00003?ooool2o`0000_ooooo0_l00002oooo
o`?o00001Oooool2o`00013ooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o0000
00_ooooo0_l00007ooooo`Co000000?oooooo`000?l000001ol000000ooooooo0000o`000009o`00
00;ooooo0_l0000Nooooo`;o000000?oooooo`000?l000000_l00006ooooo`?o00001oooool2o`00
00kooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00001?ooool2o`0000So
oooo1?l0000Dooooo`;o000000?oooooo`000?l000002Oooool2o`000003ooooool0003o000000go
oooo0_l00007ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Cooooo1?l00006ooooo`;o
00000oooool2o`0000Wooooo3?l000000ooooooo0000o`000006o`0000Kooooo0_l00003ooooo`Co
00001?ooool2o`0001kooooo0_l00005ooooo`Co0000C_ooool001cooooo00?o0000ooooooooool0
@Oooool5o`0001;ooooo0_l000000ooooooo0000o`000003ooooo`;o00001oooool2o`0000?ooooo
0_l00006ooooo`Ko00001Oooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o0000
2?ooool2o`0000cooooo5ol00006ooooo`;o00000oooool4o`0000Cooooo0ol00004ooooo`;o0000
4_ooool2o`0000;ooooo0_l00004ooooo`Go00003_ooool2o`0003oooooo000Looooo`03o`000?oo
oooooooo03gooooo0_l00005ooooo`;o000000?oooooo`000?l000005oooool2o`0000cooooo0_l0
0006ooooo`?o000000?oooooo`000?l000002?ooool2o`0000Oooooo0_l00003ooooo`;o00004_oo
oolGo`0000Oooooo0_l00004ooooo`;o00001Oooool2o`0000Cooooo0_l00006ooooo`;o00001_oo
ool2o`0000;ooooo0_l00002ooooo`;o00001?ooool2o`000003ooooool0003o000000kooooo0ol0
000nooooo`007?ooool00ol0003oooooooooo`0kooooo`Co00000_ooool2o`0000Cooooo0_l00008
ooooo`;o00002?ooool2o`0001Wooooo0_l00004ooooo`;o000000?oooooo`000?l000003?ooool2
o`0000?ooooo1?l00008ooooo`;o00001oooool2o`000003ooooool0003o000000oo00002Oooool2
o`0000Cooooo1?l00009ooooo`;o00001_ooool2o`0000Gooooo0ol0000Pooooo`;o0000?_ooool0
01cooooo00?o0000ooooooooool0>oooool2o`0000Cooooo0_l00009ooooo`;o00000_ooool3o`00
00Kooooo1?l00008ooooo`;o00003oooool2o`0000?ooooo1_l00002ooooo`;o00003oooool3o`00
00Oooooo0_l00007ooooo`;o00000_ooool?o`0000?ooooo0_l0000<ooooo`?o00002?ooool3o`00
00Kooooo0_l000001?oooooo0000o`000?ooool3o`0000gooooo0_l0001Booooo`007?ooool00ol0
003oooooooooo`0kooooo`?o00002?ooool2o`0000Cooooo0_l00002ooooo`;o00001oooool2o`00
00[ooooo0_l00003ooooo`;o00000_ooool2o`0000_ooooo0_l000000ooooooo0000o`000002o`00
0003ooooool0003o000000Kooooo0_l000000ooooooo0000o`000005ooooo`;o00001oooool4o`00
00Sooooo2?l000000ooooooo0000o`000004o`0000Cooooo0_l00002ooooo`;o00002?ooool4o`00
00Oooooo0_l00007ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`?o00001Oooool2
o`0000;ooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`0looooo`;o00000oooool2o`00
00?ooooo1?l0000=ooooo`;o00004Oooool3o`000003ooooool0003o000000;ooooo0_l00003oooo
o`;o00001oooool2o`0000Wooooo1Ol00008ooooo`;o00001?ooool4o`0000;ooooo0_l00004oooo
o`ko00002Oooool2o`0000Sooooo1?l0000Cooooo`;o00001Oooool4o`0000Cooooo0_l00005oooo
o`;o00001oooool2o`0004Kooooo000Looooo`03o`000?oooooooooo047ooooo0_l00005ooooo`Ko
00001?ooool2o`0000?ooooo0_l0000Aooooo`Go00000_ooool3o`0000;ooooo1?l0000Booooo`Co
000000?oooooo`000?l000001Oooool2o`0000[ooooo1?l00004ooooo`_o00001oooool2o`0000_o
oooo0_l00002ooooo`;o00004Oooool2o`000004ooooool0003o0000o`0000?ooooo0_l0000;oooo
o`;o00001oooool2o`0004Kooooo000Looooo`03o`000?oooooooooo04[ooooo1_l00002ooooo`;o
00005_ooool2o`000005ooooool0003o0000o`000?ooool00ol00002ooooo`Co00005oooool3o`00
01;ooooo0_l00004ooooo`_o00000_ooool2o`0000?ooooo0ol00008ooooo`So00005?ooool3o`00
00;ooooo0ol0001Looooo`007?ooool00ol0003oooooooooo`19ooooo`;o00000oooool2o`0000Wo
oooo0_l0000>ooooo`;o00000oooool2o`0000;ooooo1?l0000Looooo`;o00006_ooool:o`000004
ooooool0003o0000o`0000?ooooo0_l00006ooooo`Go000000?oooooo`000?l000003_ooool2o`00
00;ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0ol00003ooooo`;o0000Eoooool001co
oooo00?o0000ooooooooool0@_ooool2o`0000Gooooo0ol00005ooooo`;o00001_ooool2o`0000[o
oooo0_l00002ooooo`;o000000?oooooo`000?l000000oooool2o`000003ooooool0003o000001So
oooo1Ol0000Mooooo`So00000_ooool2o`0000_ooooo0_l000000ooooooo0000o`000007ooooo`;o
00001_ooool4o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`;o00000oooool2o`0001Ko
oooo0_l0000oooooo`007?ooool2o`0004?ooooo0_l00006ooooo`;o00001Oooool4o`0000[ooooo
0_l00004ooooo`;o00001Oooool2o`0000?ooooo0_l0000Hooooo`;o000000?oooooo`000?l00000
0ol0000Iooooo`Co000000?oooooo`000?l000000_l000000ooooooo0000o`00000Kooooo`;o0000
1_ooool4o`0000Sooooo1_l0000Kooooo`;o0000?oooool001cooooo00?o0000ooooooooool0Dooo
ool2o`0000[ooooo0_l000000ooooooo0000o`00000Booooo`?o00004_ooool4o`0001Cooooo0_l0
0007ooooo`Co000000?oooooo`000?l000001?l0000?ooooo`Oo00004?ooool2o`0000Cooooo0_l0
0002ooooo`Co00000oooool2o`0005Wooooo000Looooo`03o`000?oooooooooo05[ooooo0_l00006
ooooo`;o000000Coooooo`000?l0003ooooo0_l0000<ooooo`So00000oooool2o`0000[ooooo0ol0
000Cooooo`;o00003_ooool4o`0000Gooooo0_l00005ooooo`;o000000?oooooo`000?l000001ol0
00000ooooooo0000o`000004ooooo`?o00000_ooool2o`0000Kooooo1?l000000ooooooo0000o`00
0004ooooo`Co0000Eoooool001cooooo00?o0000ooooooooool0B?ooool2o`0000Cooooo1?l00008
ooooo`;o00002Oooool2o`000003ooooool0003o000000;o00003?ooool6o`000003ooooool0003o
000000;o00002oooool2o`0000Kooooo0_l000001?oooooo0000o`000?l0000Pooooo`;o000000Go
ooooo`000?l0003o0000ooooo`02o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l00000
1?ooool7o`0000Sooooo1Ol00006ooooo`;o0000Eoooool001cooooo00?o0000ooooooooool0B?oo
ool2o`0000Cooooo1?l0000Fooooo`Co00003Oooool3o`0000;ooooo0ol0000@ooooo`;o00000ooo
ool2o`000004ooooool0003o0000o`0000?ooooo0_l0000=ooooo`;o00001oooool2o`0000Kooooo
1ol0000:ooooo`;o00001?ooool2o`000003ooooool0003o000000?o00002Oooool2o`000003oooo
ool0003o000000_ooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00003ooo
ool4o`0000Sooooo0_l00002ooooo`;o00003_ooool2o`0000;ooooo0_l000000ooooooo0000o`00
000>ooooo`;o00001_ooool2o`0000?ooooo0ol00003ooooo`?o00001oooool2o`0000Oooooo0_l0
0009ooooo`Co00002_ooool2o`0000Kooooo0ol000000ooooooo0000o`000003ooooo`;o00000_oo
ool2o`0000?ooooo0_l0000;ooooo`;o0000D?ooool001cooooo00?o0000ooooooooool0BOooool2
o`000003ooooool0003o000000cooooo1?l00002ooooo`;o00001?ooool2o`0000;ooooo0_l0000<
ooooo`Co000000?oooooo`000?l000001Ol0000Jooooo`;o00000_ooool5o`0002Kooooo0_l00000
0ooooooo0000o`000002ooooo`;o00000_ooool3o`0000Kooooo1_l00003ooooo`;o00002_ooool2
o`00057ooooo000Looooo`03o`000?oooooooooo04cooooo0_l00004ooooo`?o00002oooool3o`00
01Gooooo0_l00003ooooo`Wo00005?ooool2o`0000Kooooo0_l0000;ooooo`;o00004oooool2o`00
00Oooooo0_l000000ooooooo0000o`000002ooooo`;o00003Oooool2o`0000gooooo0_l00002oooo
o`;o00000oooool2o`0004cooooo000Looooo`03o`000?oooooooooo05;ooooo0ol00007ooooo`;o
00000oooool2o`0000Kooooo0_l0000;ooooo`Co00001?ooool3o`000003ooooool0003o000000;o
00004Oooool2o`000004ooooool0003o0000ooooo`;o00003?ooool2o`0000;ooooo0ol00003oooo
o`;o00000_ooool2o`0000Wooooo0ol00003ooooo`;o00000_ooool2o`0000kooooo0_l000001?oo
oooo0000o`000?ooool2o`0000cooooo0_l00007ooooo`;o0000C?ooool001cooooo00?o0000oooo
ooooool0@?ooool2o`00017ooooo0_l00007ooooo`;o00001_ooool2o`0000?ooooo0_l00004oooo
o`;o00001Oooool4o`0000Cooooo0ol0000Fooooo`;o00000_ooool4o`0000cooooo1?l000001?oo
oooo0000o`000?ooool4o`0000;ooooo0_l0000:ooooo`Co000000?oooooo`000?l000000_ooool2
o`0000cooooo1?l000000ooooooo0000o`000003o`00013ooooo0_l0001Aooooo`007?ooool00ol0
003oooooooooo`10ooooo`;o00008_ooool2o`000003ooooool0003o000000;ooooo0_l00002oooo
o`;o00002Oooool2o`0000;ooooo1?l000001?oooooo0000o`000?ooool2o`0001?ooooo0_l0000:
ooooo`;o00001?ooool4o`0000;ooooo0_l0000Booooo`;o00004oooool4o`0000;ooooo0_l00008
ooooo`;o000000?oooooo`000?l000001?ooool3o`00057ooooo000Looooo`03o`000?oooooooooo
057ooooo0_l00002ooooo`;o00001_ooool2o`0000Sooooo0_l00002ooooo`;o00002_ooool2o`00
0003ooooool0003o000000Cooooo0_l000001?oooooo0000o`000?ooool2o`0001Cooooo0_l00008
ooooo`?o00001_ooool2o`0002gooooo0_l0000<ooooo`;o000000?oooooo`000?l000000_ooool4
o`0005;ooooo000Looooo`03o`000?oooooooooo057ooooo0_l00002ooooo`;o00001_ooool2o`00
00oooooo0_l00007ooooo`;o00001oooool2o`000003ooooool0003o000001Gooooo1?l00007oooo
o`?o00008?ooool2o`0002Wooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`1Kooooo`;o
00004Oooool2o`00013ooooo0ol000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l0
00001?ooool2o`0000Kooooo0_l00009ooooo`;o00008Oooool2o`0000;ooooo1?l00004ooooo`;o
00006Oooool2o`0005Sooooo000Looooo`03o`000?oooooooooo053ooooo0_l00009ooooo`;o0000
0oooool2o`0000Sooooo0_l00003ooooo`;o00004?ooool2o`000003ooooool0003o000000;o0000
00Coooooo`000?l0003ooooo0_l00003ooooo`?o00004oooool2o`0000Kooooo0_l0000Hooooo`;o
000000?oooooo`000?l000000_l000001?oooooo0000o`000?ooool2o`0000Gooooo0_l0000Aoooo
o`?o000000?oooooo`000?l00000EOooool001cooooo00?o0000ooooooooool0D?ooool2o`0000ko
oooo0_l00008ooooo`;o00000oooool2o`0000;ooooo0_l0000Aooooo`;o00001oooool4o`0000ko
oooo0_l00004ooooo`Go00000oooool2o`0000?ooooo0_l0000Cooooo`;o000000?oooooo`000?l0
00000oooool2o`0000Sooooo0_l00008ooooo`;o00001oooool2o`0000;ooooo0_l0001Eooooo`00
7?ooool2o`0006Oooooo0_l00008ooooo`;o000000?oooooo`000?l000003oooool2o`0000;ooooo
0ol00004ooooo`;o00004?ooool2o`0000Kooooo0ol00008ooooo`;o00001_ooool2o`0000_ooooo
0_l000000ooooooo0000o`000005ooooo`;o00001Oooool2o`0000Wooooo0_l0001Rooooo`007?oo
ool00ol0003oooooooooo`1Qooooo`;o00000oooool2o`0000Sooooo0_l00005ooooo`;o00001?oo
ool2o`0000Gooooo2Ol00004ooooo`;o00003Oooool2o`0000Gooooo0_l000001?oooooo0000o`00
0?l0000?ooooo`;o00002?ooool2o`0000Cooooo0_l00002ooooo`Go00001Oooool2o`0006gooooo
000Looooo`03o`000?oooooooooo067ooooo0_l0000Booooo`Go00000oooool2o`0000Oooooo2?l0
0003ooooo`;o00003Oooool2o`000003ooooool0003o000000Co000000Coooooo`000?l0003o0000
1oooool2o`00013ooooo0_l00008ooooo`?o00005Oooool2o`0005oooooo000Looooo`03o`000?oo
oooooooo06Wooooo0_l0000:ooooo`;o000000?oooooo`000?l000001?ooool3o`0000Cooooo0_l0
00000ooooooo0000o`000006o`0000;ooooo0_l0000?ooooo`Co00000oooool4o`0000Kooooo0_l0
000booooo`;o0000Goooool001cooooo00?o0000ooooooooool0G_ooool2o`0000;ooooo0_l00005
ooooo`;o00003Oooool2o`0000Cooooo1?l00003ooooo`;o00000_ooool7o`0000;ooooo0_l00003
ooooo`;o00004?ooool2o`000004ooooool0003o0000o`0000Gooooo0_l0000<ooooo`;o0000QOoo
ool001cooooo00?o0000ooooooooool0G_ooool2o`0000;ooooo0_l0000Dooooo`;o00001?ooool4
o`0000?ooooo0_l00006ooooo`?o00001oooool4o`0000Cooooo0_l00008ooooo`;o000000Cooooo
o`000?l0003o00002Oooool2o`0000Sooooo0ol00006ooooo`?o00004?ooool2o`0006Wooooo000L
ooooo`03o`000?oooooooooo067ooooo0_l0000@ooooo`;o00002Oooool4o`0000?ooooo0_l00005
ooooo`Co00002Oooool2o`0000Cooooo0_l0000;ooooo`;o00002?ooool4o`0000Wooooo0ol00005
ooooo`?o00004?ooool2o`0006Wooooo000Looooo`03o`000?oooooooooo063ooooo0ol00006oooo
o`;o00002?ooool2o`0000?ooooo0_l00006ooooo`;o00001oooool2o`000003ooooool0003o0000
00;o00003oooool2o`0000Cooooo0_l0000?ooooo`;o00002?ooool2o`000004ooooool0003o0000
o`0000Kooooo0_l0000Dooooo`Co0000Hoooool001cooooo00?o0000ooooooooool0H?ooool4o`00
00Gooooo0_l00005ooooo`;o00001_ooool2o`0000?ooooo0_l00005ooooo`;o00000oooool6o`00
00[ooooo0_l00002ooooo`Co00001?ooool2o`0000?ooooo0_l0000:ooooo`;o00002?ooool2o`00
0003ooooool0003o000000Cooooo0_l0000Gooooo`Co0000Hoooool001cooooo00?o0000oooooooo
ool0H_ooool2o`0000Gooooo0_l00005ooooo`;o00002oooool3o`0000Cooooo0_l00004ooooo`Ko
00002Oooool2o`0000;ooooo0ol00005ooooo`;o00000_ooool3o`0000kooooo0_l00002ooooo`;o
00001?ooool2o`0000?ooooo1?l00009ooooo`;o0000LOooool001cooooo00?o0000ooooooooool0
Aoooool2o`00023ooooo0_l000000ooooooo0000o`000002ooooo`;o00003?ooool2o`0000kooooo
0_l000000ooooooo0000o`00000;ooooo`;o00001Oooool7o`0000kooooo0ol000000ooooooo0000
o`000003ooooo`?o00001Oooool2o`0000;ooooo0_l00005ooooo`;o00002?ooool2o`0006Oooooo
000Looooo`03o`000?oooooooooo04Oooooo0_l0000Rooooo`?o00004oooool2o`0000Sooooo1Ol0
00000ooooooo0000o`000002o`0000gooooo0_l00003ooooo`;o00004_ooool2o`0000Kooooo1?l0
0002ooooo`;o00001?ooool2o`0000oooooo0_l0001Wooooo`007?ooool00ol0003oooooooooo`1W
ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000001_ooool5
o`0000Oooooo0ol00005ooooo`;o00001Oooool2o`000003ooooool0003o000000?ooooo0_l0000G
ooooo`?o00001?ooool2o`000003ooooool0003o000000;ooooo0_l0000Eooooo`;o0000Ioooool0
01cooooo00?o0000ooooooooool0Ioooool2o`0000;ooooo1?l000000ooooooo0000o`000002oooo
o`;o000000?oooooo`000?l000001_ooool2o`000003ooooool0003o000001Kooooo0_l000000ooo
oooo0000o`000006ooooo`?o00000oooool2o`0000_ooooo0_l00002ooooo`;o000000Coooooo`00
0?l0003ooooo0_l0000:ooooo`;o0000NOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Ooo
ool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo06cooooo
1Ol0000<ooooo`;o00000_ooool2o`00013ooooo0_l0000@ooooo`Co00000_ooool2o`0000;ooooo
0_l00006ooooo`?o00000_ooool2o`000003ooooool0003o000000gooooo0_l00006ooooo`;o0000
LOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?oo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo06cooooo0_l000000ooooooo0000o`000005oooo
o`;o00001Oooool2o`0000;ooooo0_l00009ooooo`;o00001Oooool3o`0000;ooooo0_l0000<oooo
o`?o00001_ooool2o`0000Kooooo0_l00003ooooo`;o00006?ooool2o`0000;ooooo0_l0001]oooo
o`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooooooo`1`ooooo`;o00001?ooool2o`0001Cooooo0_l00004oooo
o`Co00000_ooool2o`0000Sooooo0_l00003ooooo`;o00003?ooool2o`0001kooooo0_l00003oooo
o`;o0000KOooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Olb<S;o
V9RHoooooonHV9So<S8b00Kooooo0ol0001`ooooo`;o000000?oooooo`000?l000000_ooool2o`00
01Wooooo0_l00003ooooo`;o00002Oooool5o`0000_ooooo0_l000000ooooooo0000o`000002oooo
o`?o00006Oooool2o`0007;ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wo
oooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo06_ooooo0_l00005oooo
o`?o00000_ooool2o`0000Kooooo0_l0000Dooooo`Co00002_ooool5o`0000Wooooo0ol00005oooo
o`?o0000SOooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol@413o
^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0Joooool2o`0000Gooooo0_l00002oooo
o`;o00001oooool2o`0000kooooo0_l00004ooooo`;o00001?ooool2o`0000Oooooo1?l00009oooo
o`;o00001oooool2o`0001;ooooo0_l0001iooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;
ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`1fooooo`;o00003_oo
ool3o`0000Kooooo0_l00007ooooo`;o000000?oooooo`000?l000007oooool2o`00013ooooo0_l0
001iooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT01_ooool00ol0003oooooooooo`1fooooo`;o00003_ooool3o`0000;ooooo0_l0000;ooooo`;o
00000_ooool2o`00017ooooo0_l0000;ooooo`;o0000Roooool001cooooo00?o0000ooooooooool0
O_ooool2o`0000Gooooo2?l00004ooooo`;o00002Oooool2o`0000Cooooo0_l00005ooooo`;o0000
1?ooool2o`0002kooooo0_l0001Xooooo`007?ooool00ol0003oooooooooo`1fooooo`;o00001_oo
ool2o`0000Gooooo1_l00006ooooo`;o00003oooool2o`0000Gooooo1?l0000Aooooo`;o00007ooo
ool2o`0006Sooooo000Looooo`03o`000?oooooooooo07Kooooo0_l0000@ooooo`;o00000oooool2
o`0001cooooo0_l00002ooooo`;o00003Oooool2o`0000?ooooo0_l00024ooooo`007?ooool00ol0
003oooooooooo`25ooooo`;o00001Oooool3o`0000kooooo0_l000000ooooooo0000o`000002o`00
00_ooooo0_l0000Booooo`;o0000Q?ooool001cooooo00?o0000ooooooooool0QOooool2o`0000Go
oooo0_l0000?ooooo`;o000000?oooooo`000?l000000_l0000Aooooo`;o00002?ooool2o`0000?o
oooo0_l00002ooooo`;o00003Oooool2o`00073ooooo000Looooo`03o`000?oooooooooo09Cooooo
0_l0000:ooooo`;o000000?oooooo`000?l000004?ooool2o`0000Sooooo0_l00003ooooo`;o0000
0_ooool2o`0000gooooo0_l0001`ooooo`007?ooool00ol0003oooooooooo`2Dooooo`;o00002_oo
ool2o`000003ooooool0003o00000:Cooooo000Looooo`03o`000?oooooooooo0:Cooooo0_l00003
ooooo`;o00009Oooool2o`0007Oooooo000Looooo`03o`000?oooooooooo06[ooooo0_l0000hoooo
o`;o00000oooool2o`0000Cooooo0_l0000Oooooo`;o0000Moooool001cooooo00?o0000oooooooo
ool0J_ooool2o`00037ooooo0_l00005ooooo`Co00001oooool2o`0009Sooooo000Looooo`03o`00
0?oooooooooo09gooooo0_l000000ooooooo0000o`000004ooooo`;o00002oooool2o`0009Cooooo
000Looooo`;o0000XOooool2o`00017ooooo0_l0002Dooooo`007?ooool00ol0003oooooooooo`1W
ooooo`;o0000??ooool2o`000:;ooooo000Looooo`03o`000?oooooooooo06Oooooo0_l0000[oooo
o`;o00003oooool2o`000:;ooooo000Looooo`03o`000?oooooooooo09Cooooo0_l0002cooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo09Oooooo0_l0
002`ooooo`007?ooool00ol0003oooooooooo`2Gooooo`;o0000/?ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Rooooo`;o00007?ooool2o`0008Oo
oooo000Looooo`03o`000?oooooooooo0:;ooooo0_l0000Cooooo`;o00001oooool2o`0008Oooooo
000Looooo`03o`000?oooooooooo0:_ooooo0_l0000:ooooo`;o00001Oooool2o`0008Wooooo000L
ooooo`03o`000?oooooooooo0:_ooooo1?l0000?ooooo`;o0000ROooool001cooooo00?o0000oooo
ooooool0Y_ooool2o`0000Gooooo0_l0002Jooooo`007?ooool00ol0003oooooooooo`2Sooooo`;o
000000?oooooo`000?l00000XOooool001cooooo00?o0000ooooooooool0Xoooool2o`000:Cooooo
000Looooo`03o`000?oooooooooo0:Cooooo0_l0002Sooooo`007?ooool2o`000:Gooooo0_l0002S
ooooo`007?ooool00ol0003oooooooooo`2Qooooo`;o0000Y_ooool001cooooo00?o0000oooooooo
ool0XOooool2o`000:Kooooo000Looooo`03o`000?oooooooooo08Cooooo0_l0000Nooooo`;o0000
Xoooool001cooooo00?o0000ooooooooool0Q?ooool2o`0001kooooo0_l0002Sooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0U?ooool2o`0000Kooooo0_l0002[ooooo`007?ooool00ol0003ooooo
ooooo`2Dooooo`;o00001_ooool2o`000:_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001;ooooo1?l000000ol@413oooooooooo`03
ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo0ol0003ooooood[o
oooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooo
oomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo
0?ooooooD_ooool001;ooooo00?oEEEEofIVI_l00000oooooomDooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00XOooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooo
oooo01Kooooo1?l000001?l@413oooooooooooooool4o`000008oa0@4?oooooooooooiRHV?l@413o
0000oc8b<_o<c<`5ooooo`;o000000?o410@ooooooooool0R_ooool00:;ooooo00Go0000oooooooo
ooooooooo`000009ooooo`Ko00003?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo08_ooooo002Roooo
o`05o`000?ooooooooooooooool000006oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00Co0000oooooooooooooooo1Ol0002<ooooo`00X_ooool01Ol0003ooooooooooooo
oooo000000Wooooo1_l0000<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00onYZJWo410@ooooo`02ooooo`04odA4A?oMgMgoooooo`0008gooooo002Rooooo`05o`000?n7
QhOoooooojVYZOl000006oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
00?o410@o`000?nj^[X00oooool01?oMgMgoEEEEooooool0002=ooooo`00XOooool00ol@413o0000
ogMgM`02o`000003oiRHV?oooooooooo01Wooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03okZj^_lQ8B7ooooo00?ooooo00?oMgMgolc<c?l00000SOooool00<;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`05oa0@4?nHV9SooooookZj^_l00000
1?ooool00oo^k^koA4A4o`00002=ooooo`00`?ooool00omEEEGoIVIVo`000005ooooo`03oeEEEOmV
IVKo000000Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@05ooooo`03ogMgMol0003ooooo08cooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1140) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.39318 .44043 Mdot
.34992 .42638 Mdot
.5136 .64135 Mdot
.56259 .35822 Mdot
.20922 .58901 Mdot
.54371 .65053 Mdot
.41948 .58767 Mdot
.3604 .59335 Mdot
.52304 .64155 Mdot
.25236 .45948 Mdot
.41305 .59158 Mdot
.50968 .33115 Mdot
.39787 .5939 Mdot
.58295 .3636 Mdot
.15051 .46813 Mdot
.53423 .33699 Mdot
.33838 .38427 Mdot
.69839 .57322 Mdot
.53422 .43684 Mdot
.57623 .62977 Mdot
.3712 .38042 Mdot
.57283 .36578 Mdot
.35057 .44876 Mdot
.5836 .36407 Mdot
.54476 .35588 Mdot
.37502 .4097 Mdot
.30256 .39258 Mdot
.54201 .40074 Mdot
.53472 .35391 Mdot
.36403 .59882 Mdot
.70378 .44736 Mdot
.156 .52803 Mdot
.57194 .44686 Mdot
.43834 .79818 Mdot
.36248 .58372 Mdot
.42808 .35029 Mdot
.53011 .66469 Mdot
.37494 .58164 Mdot
.37209 .57457 Mdot
.42699 .58223 Mdot
.39009 .5772 Mdot
.37222 .42071 Mdot
.4485 .593 Mdot
.46745 .57509 Mdot
.51973 .36127 Mdot
.24836 .58512 Mdot
.62074 .24093 Mdot
.57929 .41838 Mdot
.35472 .38759 Mdot
.59727 .71687 Mdot
.34381 .7016 Mdot
.4178 .57521 Mdot
.54581 .68516 Mdot
.57737 .8895 Mdot
.37085 .58974 Mdot
.51374 .3876 Mdot
.51637 .66346 Mdot
.57687 .37623 Mdot
.58672 .36843 Mdot
.34828 .27918 Mdot
.55627 .42709 Mdot
.67526 .57313 Mdot
.39052 .45382 Mdot
.56015 .50138 Mdot
.52255 .65139 Mdot
.38712 .57074 Mdot
.35974 .43807 Mdot
.38973 .59664 Mdot
.62128 .3299 Mdot
.58247 .64049 Mdot
.57589 .41878 Mdot
.40127 .57696 Mdot
.38169 .39486 Mdot
.56285 .40643 Mdot
.64983 .73277 Mdot
.26244 .28049 Mdot
.62274 .55256 Mdot
.38904 .31359 Mdot
.33362 .306 Mdot
.66238 .6587 Mdot
.58271 .34142 Mdot
.74865 .37779 Mdot
.2213 .35568 Mdot
.32706 .43566 Mdot
.61121 .44816 Mdot
.59404 .57955 Mdot
.56532 .40173 Mdot
.21636 .49999 Mdot
.53635 .34421 Mdot
.66081 .74993 Mdot
.53324 .63518 Mdot
.34357 .40678 Mdot
.56377 .35616 Mdot
.5373 .40346 Mdot
.63299 .26437 Mdot
.6188 .3988 Mdot
.54811 .38475 Mdot
.39125 .41215 Mdot
.40822 .56797 Mdot
.50775 .35062 Mdot
.44731 .56844 Mdot
.51402 .68958 Mdot
.61176 .3953 Mdot
.56048 .66624 Mdot
.37618 .38762 Mdot
.55764 .41138 Mdot
.37386 .56759 Mdot
.60857 .39006 Mdot
.32403 .55937 Mdot
.34817 .42847 Mdot
.53569 .3975 Mdot
.6869 .56758 Mdot
.8207 .53389 Mdot
.33512 .40597 Mdot
.70279 .6366 Mdot
.57673 .33504 Mdot
.55784 .38355 Mdot
.35149 .42467 Mdot
.50401 .67472 Mdot
.21541 .46798 Mdot
.34394 .45115 Mdot
.42109 .57125 Mdot
.37435 .46051 Mdot
.62916 .42663 Mdot
.53521 .64085 Mdot
.40888 .7459 Mdot
.34147 .63892 Mdot
.70978 .41602 Mdot
.56925 .39716 Mdot
.28006 .51508 Mdot
.56403 .62915 Mdot
.35529 .41268 Mdot
.38938 .60003 Mdot
.5203 .43834 Mdot
.33507 .43114 Mdot
.39651 .6082 Mdot
.68391 .57785 Mdot
.44061 .71537 Mdot
.32367 .3924 Mdot
.45402 .55334 Mdot
.35001 .59445 Mdot
.42397 .58216 Mdot
.50063 .82054 Mdot
.36163 .43374 Mdot
.65671 .56002 Mdot
.37645 .60128 Mdot
.68156 .44704 Mdot
.52165 .39723 Mdot
.75636 .44572 Mdot
.69856 .25566 Mdot
.45794 .80489 Mdot
.48568 .72745 Mdot
.63735 .56974 Mdot
.39464 .55416 Mdot
.53743 .37199 Mdot
.379 .40586 Mdot
.37627 .42452 Mdot
.56846 .42928 Mdot
.55498 .3553 Mdot
.56863 .41809 Mdot
.53276 .39931 Mdot
.31999 .27896 Mdot
.61544 .36677 Mdot
.66942 .25866 Mdot
.33995 .40263 Mdot
.54827 .36815 Mdot
.51873 .67764 Mdot
.61917 .42388 Mdot
.39274 .57535 Mdot
.56979 .37223 Mdot
.55967 .35988 Mdot
.55677 .42907 Mdot
.41618 .57298 Mdot
.16908 .47487 Mdot
.74884 .32272 Mdot
.17778 .5518 Mdot
.69715 .70298 Mdot
.56251 .64992 Mdot
.5616 .39605 Mdot
.67757 .56068 Mdot
.45391 .31911 Mdot
.59196 .34983 Mdot
.87806 .4714 Mdot
.55436 .37645 Mdot
.18868 .55507 Mdot
.63654 .32168 Mdot
.17686 .60657 Mdot
.74767 .40808 Mdot
.53303 .37908 Mdot
.64025 .4539 Mdot
.44099 .41827 Mdot
.45957 .59903 Mdot
.39163 .57963 Mdot
.51391 .67566 Mdot
.51102 .65452 Mdot
.37306 .54384 Mdot
.28303 .38129 Mdot
.62387 .45275 Mdot
.62777 .36031 Mdot
.58294 .65094 Mdot
.40486 .43278 Mdot
.64501 .58453 Mdot
.38822 .43197 Mdot
.30815 .20085 Mdot
.32958 .67174 Mdot
.39839 .54627 Mdot
.66827 .5374 Mdot
.53627 .62417 Mdot
.52245 .68843 Mdot
.67044 .54944 Mdot
.59487 .40016 Mdot
.36479 .43697 Mdot
.41017 .80594 Mdot
.27281 .40064 Mdot
.4755 .82999 Mdot
.38543 .40485 Mdot
.28702 .47579 Mdot
.4005 .60479 Mdot
.54271 .66591 Mdot
.55443 .38472 Mdot
.58952 .39585 Mdot
.33845 .37354 Mdot
.57148 .41681 Mdot
.63133 .28606 Mdot
.54708 .39448 Mdot
.37455 .7195 Mdot
.61856 .56016 Mdot
.37507 .54373 Mdot
.70858 .39644 Mdot
.36657 .45086 Mdot
.76412 .55377 Mdot
.55258 .67502 Mdot
.43633 .32412 Mdot
.40464 .57657 Mdot
.68074 .57643 Mdot
.56086 .67143 Mdot
.64504 .58612 Mdot
.57776 .44399 Mdot
.51414 .62726 Mdot
.68347 .55481 Mdot
.30588 .33883 Mdot
.52444 .39098 Mdot
.31626 .2759 Mdot
.39721 .55843 Mdot
.33581 .44695 Mdot
.55408 .42484 Mdot
.56029 .65946 Mdot
.57935 .44921 Mdot
.47336 .69307 Mdot
.40664 .74366 Mdot
.49929 .67753 Mdot
.5696 .73083 Mdot
.66662 .58094 Mdot
.43423 .66611 Mdot
.29857 .50165 Mdot
.36091 .38758 Mdot
.61852 .3746 Mdot
.16383 .60645 Mdot
.37674 .60111 Mdot
.60571 .38835 Mdot
.42573 .7743 Mdot
.37608 .59629 Mdot
.57754 .37841 Mdot
.36097 .56718 Mdot
.37602 .42688 Mdot
.80393 .48352 Mdot
.34232 .38447 Mdot
.54672 .33785 Mdot
.37603 .5642 Mdot
.50152 .65513 Mdot
.37122 .40244 Mdot
.59746 .40484 Mdot
.55013 .4033 Mdot
.51979 .51212 Mdot
.54398 .37495 Mdot
.17542 .49914 Mdot
.53905 .39163 Mdot
.51303 .67002 Mdot
.60636 .41637 Mdot
.79159 .67311 Mdot
.35444 .65626 Mdot
.36104 .43806 Mdot
.49872 .65219 Mdot
.51818 .64504 Mdot
.71847 .61541 Mdot
.44409 .63204 Mdot
.58771 .33861 Mdot
.56321 .65299 Mdot
.77518 .50684 Mdot
.38456 .6127 Mdot
.62073 .37796 Mdot
.46061 .55183 Mdot
.60366 .71233 Mdot
.56612 .67137 Mdot
.51372 .42305 Mdot
.33643 .3787 Mdot
.56258 .35558 Mdot
.51972 .6857 Mdot
.3949 .39174 Mdot
.57168 .33013 Mdot
.34949 .47847 Mdot
.51795 .51078 Mdot
.4115 .60589 Mdot
.64787 .33642 Mdot
.60472 .40184 Mdot
.54309 .67053 Mdot
.3737 .44552 Mdot
.36711 .61018 Mdot
.36998 .41105 Mdot
.27161 .7018 Mdot
.3303 .55298 Mdot
.30234 .32006 Mdot
.70516 .57443 Mdot
.55203 .75986 Mdot
.19822 .64104 Mdot
.75562 .66306 Mdot
.74521 .52979 Mdot
.32903 .76773 Mdot
.51863 .6818 Mdot
.45226 .78097 Mdot
.51435 .65042 Mdot
.55779 .34346 Mdot
.53222 .6453 Mdot
.19308 .63842 Mdot
.54647 .39278 Mdot
.53234 .65173 Mdot
.77772 .54699 Mdot
.55321 .36202 Mdot
.33072 .40854 Mdot
.18294 .41804 Mdot
.77152 .66107 Mdot
.38886 .74834 Mdot
.54047 .61459 Mdot
.71705 .52002 Mdot
.54531 .38512 Mdot
.60191 .42462 Mdot
.35206 .39007 Mdot
.62337 .37944 Mdot
.64193 .58006 Mdot
.6714 .53796 Mdot
.45048 .43925 Mdot
.76311 .37199 Mdot
.56968 .30605 Mdot
.3682 .39864 Mdot
.37889 .23041 Mdot
.63296 .74048 Mdot
.57853 .73966 Mdot
.3664 .55623 Mdot
.18739 .43463 Mdot
.58867 .2772 Mdot
.38932 .52994 Mdot
.47337 .58581 Mdot
.33998 .41447 Mdot
.16714 .49728 Mdot
.38796 .58109 Mdot
.52773 .21581 Mdot
.63775 .48139 Mdot
.59497 .39561 Mdot
.41071 .57918 Mdot
.55412 .30337 Mdot
.75824 .6926 Mdot
.55305 .19302 Mdot
.70412 .31155 Mdot
.55458 .33184 Mdot
.66614 .72408 Mdot
.56405 .37613 Mdot
.2172 .45066 Mdot
.53912 .39414 Mdot
.3648 .40458 Mdot
.23457 .45074 Mdot
.48116 .47017 Mdot
.72449 .29812 Mdot
.32069 .65389 Mdot
.63737 .57049 Mdot
.55232 .39128 Mdot
.59596 .39405 Mdot
.64916 .58118 Mdot
.32037 .41461 Mdot
.53213 .39917 Mdot
.75696 .55531 Mdot
.5708 .40747 Mdot
.38169 .57657 Mdot
.69175 .31236 Mdot
.29554 .416 Mdot
.61663 .33866 Mdot
.40305 .42296 Mdot
.4115 .60715 Mdot
.36715 .5794 Mdot
.5294 .33742 Mdot
.43138 .59311 Mdot
.55915 .36952 Mdot
.5614 .18609 Mdot
.32323 .40049 Mdot
.63742 .30584 Mdot
.3424 .4432 Mdot
.38162 .31714 Mdot
.3658 .5728 Mdot
.36602 .70501 Mdot
.49504 .38199 Mdot
.39191 .58352 Mdot
.34515 .53216 Mdot
.57248 .30822 Mdot
.55999 .32323 Mdot
.62321 .77262 Mdot
.52758 .6204 Mdot
.50956 .49683 Mdot
.35786 .58922 Mdot
.59918 .40879 Mdot
.61848 .34984 Mdot
.41623 .60424 Mdot
.47945 .19773 Mdot
.7796 .59676 Mdot
.54294 .39386 Mdot
.35383 .39959 Mdot
.35802 .41329 Mdot
.56143 .32663 Mdot
.61193 .37736 Mdot
.55486 .63265 Mdot
.50762 .63214 Mdot
.54724 .60985 Mdot
.51584 .50855 Mdot
.36923 .71117 Mdot
.26198 .63736 Mdot
.42699 .58262 Mdot
.29984 .53948 Mdot
.67788 .73836 Mdot
.62678 .42145 Mdot
.56505 .62281 Mdot
.60128 .38151 Mdot
.56566 .36049 Mdot
.37101 .61318 Mdot
.40008 .75939 Mdot
.56195 .29253 Mdot
.31904 .40273 Mdot
.3582 .59964 Mdot
.53967 .46161 Mdot
.28905 .61438 Mdot
.68366 .5658 Mdot
.52859 .80832 Mdot
.39897 .57433 Mdot
.33504 .41389 Mdot
.36419 .56952 Mdot
.5859 .39986 Mdot
.51913 .42 Mdot
.34847 .41813 Mdot
.66606 .54034 Mdot
.60271 .43449 Mdot
.57478 .37947 Mdot
.78878 .33293 Mdot
.69616 .71577 Mdot
.38398 .71595 Mdot
.53431 .38295 Mdot
.6048 .33033 Mdot
.67163 .59077 Mdot
.57605 .40601 Mdot
.55847 .42044 Mdot
.82077 .47588 Mdot
.32602 .62226 Mdot
.69557 .55405 Mdot
.50502 .21088 Mdot
.38229 .40081 Mdot
.16058 .57395 Mdot
.54746 .66477 Mdot
.43379 .57931 Mdot
.79339 .58309 Mdot
.51765 .69278 Mdot
.50159 .72804 Mdot
.16021 .55607 Mdot
.50563 .49521 Mdot
.62013 .62226 Mdot
.52617 .31107 Mdot
.54728 .41234 Mdot
.56365 .38068 Mdot
.67371 .56156 Mdot
.3677 .43345 Mdot
.53137 .50627 Mdot
.35668 .2202 Mdot
.56781 .36867 Mdot
.64289 .30035 Mdot
.26556 .35576 Mdot
.60894 .70264 Mdot
.64186 .56525 Mdot
.66502 .53889 Mdot
.55563 .38862 Mdot
.81627 .51054 Mdot
.37536 .40839 Mdot
.59849 .40359 Mdot
.59734 .33994 Mdot
.53159 .61679 Mdot
.34303 .42847 Mdot
.52244 .6834 Mdot
.35606 .69096 Mdot
.18471 .55783 Mdot
.79433 .33077 Mdot
.36559 .57734 Mdot
.23775 .39277 Mdot
.36916 .60465 Mdot
.74178 .36933 Mdot
.52532 .68987 Mdot
.58889 .34449 Mdot
.37125 .44784 Mdot
.60361 .39861 Mdot
.60932 .36752 Mdot
.5962 .39846 Mdot
.63146 .38117 Mdot
.86661 .53194 Mdot
.66648 .54467 Mdot
.59614 .31932 Mdot
.50863 .65809 Mdot
.20579 .43318 Mdot
.25153 .30285 Mdot
.59447 .3875 Mdot
.55206 .39967 Mdot
.32644 .41712 Mdot
.58248 .42874 Mdot
.37911 .6107 Mdot
.37682 .44405 Mdot
.53596 .40124 Mdot
.19454 .43567 Mdot
.52749 .36885 Mdot
.17697 .58592 Mdot
.36143 .57301 Mdot
.34429 .51479 Mdot
.59322 .31459 Mdot
.40815 .74144 Mdot
.50972 .49693 Mdot
.57111 .64366 Mdot
.43385 .60549 Mdot
.52826 .66315 Mdot
.45122 .16681 Mdot
.53718 .4332 Mdot
.53877 .36737 Mdot
.6201 .35695 Mdot
.56181 .65228 Mdot
.21036 .52319 Mdot
.40224 .66939 Mdot
.55615 .46646 Mdot
.55893 .64208 Mdot
.4002 .44223 Mdot
.62527 .51262 Mdot
.35983 .44781 Mdot
.67252 .53666 Mdot
.4115 .59263 Mdot
.64468 .5452 Mdot
.40796 .77459 Mdot
.34783 .4263 Mdot
.30925 .37901 Mdot
.5512 .6569 Mdot
.54518 .55891 Mdot
.48706 .87633 Mdot
.59868 .52731 Mdot
.73449 .43396 Mdot
.3501 .39103 Mdot
.5506 .33837 Mdot
.72192 .35141 Mdot
.53167 .55218 Mdot
.52585 .66183 Mdot
.58493 .35078 Mdot
.80576 .5062 Mdot
.55572 .63265 Mdot
.62002 .37811 Mdot
.51336 .63573 Mdot
.40182 .58174 Mdot
.55464 .62099 Mdot
.3136 .39305 Mdot
.55645 .40692 Mdot
.45394 .86413 Mdot
.64234 .52888 Mdot
.54015 .38544 Mdot
.35713 .59677 Mdot
.3965 .48621 Mdot
.6037 .36642 Mdot
.67699 .58518 Mdot
.54128 .64314 Mdot
.59012 .53949 Mdot
.54166 .39455 Mdot
.56073 .65019 Mdot
.38598 .44885 Mdot
.43856 .59943 Mdot
.47938 .44244 Mdot
.4016 .74149 Mdot
.35583 .39047 Mdot
.43733 .5478 Mdot
.41076 .61748 Mdot
.61014 .33376 Mdot
.61502 .36165 Mdot
.35526 .40358 Mdot
.79842 .4455 Mdot
.59349 .427 Mdot
.58296 .34164 Mdot
.50799 .66324 Mdot
.53232 .6591 Mdot
.79841 .46732 Mdot
.50225 .66861 Mdot
.52279 .42384 Mdot
.35768 .40455 Mdot
.56911 .35258 Mdot
.32936 .41749 Mdot
.5921 .42323 Mdot
.38242 .37732 Mdot
.31822 .41504 Mdot
.40832 .65949 Mdot
.5772 .35216 Mdot
.6396 .32146 Mdot
.60664 .38417 Mdot
.56728 .41349 Mdot
.55002 .63171 Mdot
.65359 .55308 Mdot
.50415 .39595 Mdot
.64222 .53381 Mdot
.6503 .58652 Mdot
.42515 .44505 Mdot
.53293 .61684 Mdot
.66099 .56525 Mdot
.27948 .31154 Mdot
.54122 .61068 Mdot
.6737 .57012 Mdot
.24618 .31759 Mdot
.36287 .58158 Mdot
.32904 .38366 Mdot
.55313 .3608 Mdot
.32761 .75966 Mdot
.63178 .24019 Mdot
.51441 .69802 Mdot
.53883 .38975 Mdot
.60253 .37681 Mdot
.34104 .4481 Mdot
.51999 .14687 Mdot
.58066 .63365 Mdot
.54321 .34996 Mdot
.35488 .4377 Mdot
.57003 .16125 Mdot
.51669 .67089 Mdot
.67444 .56717 Mdot
.41405 .569 Mdot
.38707 .46378 Mdot
.34399 .63952 Mdot
.42038 .59229 Mdot
.553 .68624 Mdot
.3505 .70473 Mdot
.57751 .335 Mdot
.56635 .62519 Mdot
.55073 .81121 Mdot
.27795 .41113 Mdot
.39028 .63366 Mdot
.70807 .51692 Mdot
.33919 .41222 Mdot
.37767 .60942 Mdot
.64383 .55037 Mdot
.38712 .40809 Mdot
.32797 .40073 Mdot
.38425 .6166 Mdot
.46138 .40711 Mdot
.466 .55394 Mdot
.37467 .57658 Mdot
.63428 .76167 Mdot
.30176 .70658 Mdot
.56727 .62386 Mdot
.64595 .58146 Mdot
.37953 .77209 Mdot
.37253 .41961 Mdot
.18571 .43747 Mdot
.55929 .803 Mdot
.54813 .38454 Mdot
.65521 .56613 Mdot
.23137 .57827 Mdot
.38893 .19262 Mdot
.37502 .59466 Mdot
.4791 .47647 Mdot
.63162 .56564 Mdot
.55737 .42613 Mdot
.65935 .47506 Mdot
.57404 .34438 Mdot
.40856 .60082 Mdot
.33401 .29091 Mdot
.33408 .41434 Mdot
.3713 .61551 Mdot
.52543 .80956 Mdot
.56222 .36798 Mdot
.58072 .35032 Mdot
.69941 .39588 Mdot
.38241 .42181 Mdot
.57134 .64519 Mdot
.58193 .33642 Mdot
.57258 .37628 Mdot
.50941 .39187 Mdot
.65308 .34789 Mdot
.81791 .53125 Mdot
.55085 .34552 Mdot
.33158 .66178 Mdot
.61297 .33269 Mdot
.57991 .35544 Mdot
.4035 .42273 Mdot
.83082 .37947 Mdot
.35081 .68504 Mdot
.56996 .37374 Mdot
.55049 .33962 Mdot
.39161 .61744 Mdot
.47577 .54949 Mdot
.53722 .56207 Mdot
.57751 .55226 Mdot
.73458 .527 Mdot
.63255 .37393 Mdot
.35727 .44335 Mdot
.68763 .56075 Mdot
.58613 .32819 Mdot
.35436 .44202 Mdot
.54427 .42577 Mdot
.55816 .63343 Mdot
.53531 .6117 Mdot
.36869 .50709 Mdot
.66488 .56944 Mdot
.68712 .34698 Mdot
.29269 .5509 Mdot
.50773 .66955 Mdot
.54113 .36289 Mdot
.43589 .57648 Mdot
.52124 .68636 Mdot
.59524 .60227 Mdot
.6164 .45388 Mdot
.37925 .41329 Mdot
.34061 .40547 Mdot
.75827 .44743 Mdot
.45914 .71597 Mdot
.79706 .3645 Mdot
.40444 .58315 Mdot
.57969 .43871 Mdot
.2867 .50141 Mdot
.33777 .40561 Mdot
.72961 .36387 Mdot
.65951 .56701 Mdot
.37384 .59624 Mdot
.53792 .73495 Mdot
.33138 .42654 Mdot
.3329 .38639 Mdot
.52922 .35382 Mdot
.58341 .38475 Mdot
.74945 .52824 Mdot
.62948 .59105 Mdot
.40657 .6095 Mdot
.6486 .58225 Mdot
.56405 .67001 Mdot
.55108 .34383 Mdot
.34094 .44459 Mdot
.34924 .7425 Mdot
.55643 .33706 Mdot
.55162 .63006 Mdot
.34308 .4119 Mdot
.65483 .58329 Mdot
.6597 .58872 Mdot
.5675 .41209 Mdot
.38415 .23169 Mdot
.37914 .58495 Mdot
.33198 .40842 Mdot
.3022 .63049 Mdot
.60872 .41465 Mdot
.57799 .3874 Mdot
.64473 .35913 Mdot
.37896 .61361 Mdot
.32814 .50082 Mdot
.6376 .54578 Mdot
.36527 .42867 Mdot
.53174 .37226 Mdot
.66997 .57462 Mdot
.31267 .49932 Mdot
.50064 .67964 Mdot
.54887 .62085 Mdot
.67268 .58695 Mdot
.64824 .5698 Mdot
.67423 .58492 Mdot
.18474 .43459 Mdot
.30793 .40865 Mdot
.57688 .27989 Mdot
.59326 .42924 Mdot
.74727 .42802 Mdot
.51637 .43778 Mdot
.35562 .60211 Mdot
.52619 .6223 Mdot
.60848 .37508 Mdot
.55205 .33545 Mdot
.64572 .34197 Mdot
.61716 .29434 Mdot
.29474 .40548 Mdot
.34619 .42837 Mdot
.548 .43532 Mdot
.51775 .62551 Mdot
.33833 .17605 Mdot
.28231 .75127 Mdot
.57856 .31217 Mdot
.50119 .56605 Mdot
.33669 .44176 Mdot
.42427 .60605 Mdot
.57623 .56838 Mdot
.36952 .56433 Mdot
.36214 .42419 Mdot
.55186 .34405 Mdot
.29911 .55177 Mdot
.6737 .58823 Mdot
.58659 .41754 Mdot
.38883 .60673 Mdot
.57753 .42002 Mdot
.42029 .59089 Mdot
.24398 .67399 Mdot
.69943 .72965 Mdot
.5536 .37762 Mdot
.5917 .32022 Mdot
.72401 .53998 Mdot
.59544 .38508 Mdot
.65243 .51284 Mdot
.32974 .4365 Mdot
.77184 .35387 Mdot
.52044 .38005 Mdot
.4532 .26671 Mdot
.61014 .41393 Mdot
.79841 .52415 Mdot
.5812 .3897 Mdot
.60811 .71482 Mdot
.54355 .40465 Mdot
.55841 .41784 Mdot
.37409 .5638 Mdot
.38754 .61732 Mdot
.39286 .40571 Mdot
.56372 .65582 Mdot
.17392 .56481 Mdot
.57555 .38237 Mdot
.4039 .7457 Mdot
.31603 .58768 Mdot
.64664 .57052 Mdot
.36479 .42366 Mdot
.52363 .14063 Mdot
.36943 .55874 Mdot
.72984 .65596 Mdot
.78892 .49654 Mdot
.34238 .64953 Mdot
.59083 .57536 Mdot
.22738 .44389 Mdot
.67108 .57927 Mdot
.56265 .43049 Mdot
.38576 .75897 Mdot
.59982 .74439 Mdot
.61192 .45853 Mdot
.38657 .62023 Mdot
.44826 .31054 Mdot
.36579 .75706 Mdot
.62762 .55826 Mdot
.64272 .54499 Mdot
.41919 .5805 Mdot
.56006 .72532 Mdot
.56281 .29681 Mdot
.65804 .56959 Mdot
.50393 .66489 Mdot
.56201 .6159 Mdot
.47148 .63843 Mdot
.37649 .41592 Mdot
.48955 .80581 Mdot
.261 .57508 Mdot
.41899 .59515 Mdot
.61598 .63401 Mdot
.32659 .44721 Mdot
.30812 .39041 Mdot
.54268 .66193 Mdot
.54529 .62881 Mdot
.3274 .382 Mdot
.51838 .40133 Mdot
.63094 .32028 Mdot
.56746 .37122 Mdot
.67157 .5559 Mdot
.58647 .39097 Mdot
.55439 .63807 Mdot
.38013 .59464 Mdot
.53606 .62899 Mdot
.36009 .56624 Mdot
.26949 .63628 Mdot
.58884 .4101 Mdot
.55332 .40675 Mdot
.62716 .23397 Mdot
.39725 .4293 Mdot
.31791 .66027 Mdot
.39203 .73927 Mdot
.5129 .65151 Mdot
.55907 .42161 Mdot
.36921 .45294 Mdot
.6407 .53937 Mdot
.62399 .2298 Mdot
.61328 .38789 Mdot
.33713 .44122 Mdot
.53529 .36203 Mdot
.28405 .32876 Mdot
.82013 .6047 Mdot
.36688 .41177 Mdot
.69344 .25383 Mdot
.53897 .35005 Mdot
.2528 .40008 Mdot
.6165 .35348 Mdot
.77012 .48822 Mdot
.59466 .42591 Mdot
.38516 .40388 Mdot
.57282 .3704 Mdot
.38321 .4312 Mdot
.52076 .6767 Mdot
.42688 .59081 Mdot
.34035 .39089 Mdot
.60704 .34626 Mdot
.18922 .70778 Mdot
.40789 .59738 Mdot
.55357 .38763 Mdot
.39695 .56046 Mdot
.36698 .44012 Mdot
.34328 .38627 Mdot
.34097 .22299 Mdot
.36136 .68755 Mdot
.40081 .58178 Mdot
.54586 .3495 Mdot
.23968 .52991 Mdot
.56951 .34865 Mdot
.74524 .4964 Mdot
.51263 .37937 Mdot
.60357 .41908 Mdot
.26797 .2756 Mdot
.39169 .61374 Mdot
.81352 .3959 Mdot
.32491 .23598 Mdot
.20306 .41377 Mdot
.40087 .45415 Mdot
.62933 .55179 Mdot
.16853 .48785 Mdot
.36865 .70699 Mdot
.56099 .64616 Mdot
.6076 .37939 Mdot
.31397 .4411 Mdot
.37197 .58392 Mdot
.65713 .5511 Mdot
.55343 .37848 Mdot
.54369 .62727 Mdot
.76215 .61966 Mdot
.38976 .55193 Mdot
.37145 .42164 Mdot
.31658 .41025 Mdot
.63982 .20061 Mdot
.53246 .37988 Mdot
.55181 .40897 Mdot
.41105 .59694 Mdot
.28377 .43969 Mdot
.66995 .58152 Mdot
.77475 .56772 Mdot
.40203 .58322 Mdot
.51622 .52924 Mdot
.35718 .43406 Mdot
.60244 .37897 Mdot
.20418 .53172 Mdot
.65948 .72113 Mdot
.53507 .23207 Mdot
.67617 .55977 Mdot
.73894 .49279 Mdot
.38456 .40261 Mdot
.38505 .60153 Mdot
.45476 .72823 Mdot
.60757 .44707 Mdot
.59862 .37555 Mdot
.73593 .48609 Mdot
.47055 .45101 Mdot
.70155 .31171 Mdot
.61486 .3923 Mdot
.49926 .47955 Mdot
.60541 .41042 Mdot
.59071 .45416 Mdot
.51712 .4115 Mdot
.57234 .3926 Mdot
.3365 .44113 Mdot
.60003 .46099 Mdot
.56648 .64033 Mdot
.64883 .28541 Mdot
.53665 .52861 Mdot
.54149 .38937 Mdot
.56555 .34389 Mdot
.52374 .25766 Mdot
.39856 .53009 Mdot
.33733 .39582 Mdot
.32883 .371 Mdot
.43108 .58762 Mdot
.64028 .33085 Mdot
.56606 .6568 Mdot
.5404 .45153 Mdot
.54567 .63179 Mdot
.35562 .44957 Mdot
.51207 .66052 Mdot
.42128 .57555 Mdot
.56057 .61759 Mdot
.36893 .71192 Mdot
.3688 .59909 Mdot
.38075 .40676 Mdot
.56431 .40653 Mdot
.35775 .59726 Mdot
.7013 .41475 Mdot
.67215 .55673 Mdot
.32603 .22959 Mdot
.52955 .39252 Mdot
.3323 .62778 Mdot
.35434 .47964 Mdot
.53825 .6298 Mdot
.83102 .54572 Mdot
.31848 .41177 Mdot
.6919 .55161 Mdot
.36169 .45178 Mdot
.65727 .76371 Mdot
.64963 .55831 Mdot
.23979 .32579 Mdot
.49696 .75326 Mdot
.61481 .53895 Mdot
.51884 .39846 Mdot
.64196 .48446 Mdot
.57374 .66177 Mdot
.37161 .58482 Mdot
.48271 .73303 Mdot
.56162 .42043 Mdot
.73912 .6769 Mdot
.38495 .39164 Mdot
.56502 .65225 Mdot
.39147 .59767 Mdot
.36268 .60712 Mdot
.61429 .37217 Mdot
.64489 .6318 Mdot
.59853 .41358 Mdot
.43682 .69981 Mdot
.73396 .51673 Mdot
.58091 .29411 Mdot
.54766 .39406 Mdot
.53833 .67329 Mdot
.53575 .36141 Mdot
.70268 .58614 Mdot
.47937 .81529 Mdot
.62434 .40244 Mdot
.38511 .73409 Mdot
.67143 .52822 Mdot
.3485 .42158 Mdot
.52754 .32693 Mdot
.37894 .70385 Mdot
.53325 .37075 Mdot
.81207 .68603 Mdot
.67241 .57179 Mdot
.41722 .74907 Mdot
.62463 .36159 Mdot
.60504 .34887 Mdot
.59358 .49359 Mdot
.43011 .40836 Mdot
.66567 .71875 Mdot
.59212 .37508 Mdot
.69574 .47848 Mdot
.4097 .5741 Mdot
.60448 .40588 Mdot
.5609 .38245 Mdot
.44872 .38519 Mdot
.36505 .60574 Mdot
.51852 .63865 Mdot
.54041 .68721 Mdot
.56703 .60637 Mdot
.7018 .57269 Mdot
.48683 .49522 Mdot
.7376 .39319 Mdot
.76515 .66472 Mdot
.69014 .55905 Mdot
.52449 .37276 Mdot
.71707 .55516 Mdot
.56219 .33795 Mdot
.64251 .55459 Mdot
.36553 .60419 Mdot
.3354 .39524 Mdot
.2837 .48406 Mdot
.58206 .64293 Mdot
.62104 .37534 Mdot
.64054 .58176 Mdot
.37924 .40761 Mdot
.64515 .6 Mdot
.35578 .42674 Mdot
.39893 .58578 Mdot
.4281 .57553 Mdot
.65167 .55027 Mdot
.35372 .44653 Mdot
.36764 .52843 Mdot
.39368 .19273 Mdot
.51379 .40942 Mdot
.4325 .62917 Mdot
.39303 .43764 Mdot
.32736 .37712 Mdot
.39189 .42226 Mdot
.575 .41648 Mdot
.49861 .56481 Mdot
.52603 .34619 Mdot
.40796 .60842 Mdot
.51553 .63383 Mdot
.74179 .58356 Mdot
.29715 .6813 Mdot
.69659 .61348 Mdot
.57394 .43931 Mdot
.56576 .3657 Mdot
.55572 .38828 Mdot
.52873 .34976 Mdot
.42443 .70325 Mdot
.60409 .39448 Mdot
.37851 .56168 Mdot
.54396 .63941 Mdot
.55945 .42992 Mdot
.50555 .69004 Mdot
.22391 .4828 Mdot
.68498 .55327 Mdot
.47335 .48017 Mdot
.15755 .63499 Mdot
.37404 .39957 Mdot
.50345 .67531 Mdot
.55958 .64823 Mdot
.68351 .57802 Mdot
.37683 .58105 Mdot
.35911 .43172 Mdot
.76593 .51231 Mdot
.66193 .58695 Mdot
.57262 .37264 Mdot
.52595 .57997 Mdot
.72814 .68294 Mdot
.57231 .43196 Mdot
.59977 .35399 Mdot
.50115 .68245 Mdot
.58366 .72264 Mdot
.4966 .84617 Mdot
.71415 .35937 Mdot
.65183 .55213 Mdot
.67226 .54291 Mdot
.33279 .37901 Mdot
.55478 .31585 Mdot
.41075 .60671 Mdot
.68293 .29726 Mdot
.42553 .45975 Mdot
.68865 .33915 Mdot
.48656 .45306 Mdot
.61159 .38852 Mdot
.47136 .18908 Mdot
.56083 .36736 Mdot
.3211 .43095 Mdot
.37402 .43563 Mdot
.35653 .39536 Mdot
.37409 .58611 Mdot
.40581 .32286 Mdot
.38033 .56297 Mdot
.17777 .65511 Mdot
.37824 .39579 Mdot
.42888 .73183 Mdot
.53697 .67194 Mdot
.59561 .31415 Mdot
.65833 .58253 Mdot
.35805 .61542 Mdot
.62286 .33197 Mdot
.81933 .51342 Mdot
.56587 .64665 Mdot
.37995 .40397 Mdot
.2306 .43528 Mdot
.21923 .67261 Mdot
.55662 .5607 Mdot
.52472 .45207 Mdot
.63039 .49565 Mdot
.64546 .57239 Mdot
.54013 .23099 Mdot
.63689 .57744 Mdot
.38029 .60611 Mdot
.55609 .40373 Mdot
.56593 .40061 Mdot
.60048 .41768 Mdot
.59766 .40199 Mdot
.4264 .60537 Mdot
.60899 .41983 Mdot
.79155 .67315 Mdot
.52769 .61459 Mdot
.30441 .33411 Mdot
.67142 .57645 Mdot
.4119 .61842 Mdot
.54576 .63848 Mdot
.50892 .70198 Mdot
.71395 .39324 Mdot
.54326 .39486 Mdot
.60861 .3779 Mdot
.72546 .66934 Mdot
.61503 .39409 Mdot
.50705 .42875 Mdot
.56105 .64897 Mdot
.70232 .61136 Mdot
.67958 .54388 Mdot
.65377 .54217 Mdot
.36217 .59184 Mdot
.35797 .44927 Mdot
.66745 .56294 Mdot
.51792 .67462 Mdot
.57066 .4401 Mdot
.58949 .3348 Mdot
.39399 .43381 Mdot
.56892 .80107 Mdot
.62876 .56107 Mdot
.22596 .4546 Mdot
.37577 .44097 Mdot
.31044 .42669 Mdot
.59822 .37367 Mdot
.64682 .42154 Mdot
.38069 .46773 Mdot
.69323 .56293 Mdot
.41787 .61634 Mdot
.58462 .55492 Mdot
.40113 .60677 Mdot
.3725 .43073 Mdot
.57907 .32876 Mdot
.37695 .42901 Mdot
.53466 .38526 Mdot
.1269 .5556 Mdot
.57268 .39658 Mdot
.76428 .67447 Mdot
.75424 .46488 Mdot
.54636 .64986 Mdot
.34404 .54043 Mdot
.5498 .66191 Mdot
.37732 .43858 Mdot
.58918 .33099 Mdot
.64466 .54176 Mdot
.22158 .37892 Mdot
.31558 .43778 Mdot
.55925 .63014 Mdot
.57152 .61716 Mdot
.36956 .60381 Mdot
.57088 .43545 Mdot
.59984 .38045 Mdot
.53234 .65356 Mdot
.58397 .29226 Mdot
.33019 .42943 Mdot
.55059 .40154 Mdot
.57395 .3601 Mdot
.54715 .65175 Mdot
.41907 .17939 Mdot
.40474 .38515 Mdot
.56141 .3973 Mdot
.46563 .76098 Mdot
.35644 .60397 Mdot
.51579 .38422 Mdot
.61518 .33081 Mdot
.65118 .57026 Mdot
.35448 .34264 Mdot
.46066 .8099 Mdot
.35509 .58701 Mdot
.55313 .66396 Mdot
.53159 .37831 Mdot
.54158 .67154 Mdot
.59827 .3395 Mdot
.37389 .35589 Mdot
.57233 .63756 Mdot
.59424 .34283 Mdot
.55207 .314 Mdot
.38229 .4238 Mdot
.61059 .38332 Mdot
.52203 .27416 Mdot
.53452 .68459 Mdot
.6076 .35404 Mdot
.38074 .2352 Mdot
.3806 .57213 Mdot
.55678 .31211 Mdot
.68399 .55783 Mdot
.76769 .51469 Mdot
.28327 .57389 Mdot
.40796 .75842 Mdot
.67707 .54836 Mdot
.57969 .42085 Mdot
.56586 .61141 Mdot
.4205 .58621 Mdot
.77538 .64456 Mdot
.56822 .42806 Mdot
.40778 .60089 Mdot
.38207 .59542 Mdot
.68223 .56327 Mdot
.75008 .28372 Mdot
.62857 .37022 Mdot
.59341 .38778 Mdot
.47336 .34313 Mdot
.37733 .45901 Mdot
.5818 .39542 Mdot
.53742 .34785 Mdot
.38383 .56013 Mdot
.50306 .42548 Mdot
.47704 .28624 Mdot
.78151 .54088 Mdot
.34787 .59264 Mdot
.58421 .52992 Mdot
.57664 .63459 Mdot
.66522 .57692 Mdot
.35067 .4165 Mdot
.63321 .57613 Mdot
.55176 .61709 Mdot
.52688 .36428 Mdot
.38657 .55561 Mdot
.57506 .25616 Mdot
.42058 .58251 Mdot
.41465 .76041 Mdot
.38161 .45311 Mdot
.27181 .50469 Mdot
.84517 .62182 Mdot
.25993 .58378 Mdot
.39727 .53135 Mdot
.64677 .57022 Mdot
.54322 .69931 Mdot
.57118 .36139 Mdot
.55993 .22963 Mdot
.56345 .41131 Mdot
.38524 .23595 Mdot
.50397 .65428 Mdot
.54746 .60976 Mdot
.55851 .40095 Mdot
.73731 .51221 Mdot
.42259 .5902 Mdot
.38619 .61296 Mdot
.61014 .36144 Mdot
.39205 .58321 Mdot
.58536 .38236 Mdot
.55089 .63409 Mdot
.83206 .43454 Mdot
.56126 .37467 Mdot
.57296 .32116 Mdot
.36931 .64519 Mdot
.27814 .27445 Mdot
.49266 .78047 Mdot
.51811 .1944 Mdot
.24508 .70214 Mdot
.39233 .58417 Mdot
.52862 .34045 Mdot
.58823 .52724 Mdot
.50479 .69077 Mdot
.37242 .52622 Mdot
.57552 .40362 Mdot
.57565 .40703 Mdot
.55477 .41674 Mdot
.58002 .3493 Mdot
.5417 .2248 Mdot
.56608 .2767 Mdot
.37176 .27479 Mdot
.60984 .37116 Mdot
.66673 .45059 Mdot
.35889 .586 Mdot
.3808 .38563 Mdot
.63913 .59213 Mdot
.61138 .3884 Mdot
.57594 .27693 Mdot
.36216 .61226 Mdot
.17916 .65686 Mdot
.36509 .59876 Mdot
.51819 .64593 Mdot
.42526 .60333 Mdot
.54243 .37613 Mdot
.35758 .41251 Mdot
.55709 .53656 Mdot
.43727 .66813 Mdot
.5612 .64531 Mdot
.54008 .38575 Mdot
.41068 .7314 Mdot
.56494 .64062 Mdot
.2235 .48836 Mdot
.35165 .41081 Mdot
.69345 .46978 Mdot
.37518 .43478 Mdot
.59329 .34159 Mdot
.58533 .34004 Mdot
.42278 .62653 Mdot
.42506 .58585 Mdot
.37404 .43756 Mdot
.77487 .30323 Mdot
.63796 .58355 Mdot
.36295 .39862 Mdot
.58646 .44897 Mdot
.44233 .51112 Mdot
.35332 .4057 Mdot
.67969 .61243 Mdot
.36963 .59011 Mdot
.35832 .38407 Mdot
.60412 .44592 Mdot
.58272 .78239 Mdot
.69122 .57412 Mdot
.53344 .60412 Mdot
.53355 .58527 Mdot
.5256 .68601 Mdot
.43172 .60582 Mdot
.55213 .65817 Mdot
.40609 .57107 Mdot
.30603 .59327 Mdot
.66176 .29825 Mdot
.43182 .57283 Mdot
.43078 .6039 Mdot
.55085 .65654 Mdot
.54722 .40379 Mdot
.5619 .57962 Mdot
.51961 .35713 Mdot
.63293 .40075 Mdot
.40212 .57187 Mdot
.38525 .40593 Mdot
.31874 .38949 Mdot
.6615 .46836 Mdot
.31587 .41573 Mdot
.54588 .63069 Mdot
.80515 .62446 Mdot
.38821 .75197 Mdot
.4119 .58488 Mdot
.41372 .6145 Mdot
.56885 .34698 Mdot
.52743 .66296 Mdot
.53274 .67735 Mdot
.37864 .60791 Mdot
.66081 .32475 Mdot
.56227 .31814 Mdot
.32085 .37658 Mdot
.36994 .38989 Mdot
.36265 .40742 Mdot
.39025 .42331 Mdot
.48176 .25811 Mdot
.36869 .59315 Mdot
.38681 .41053 Mdot
.60102 .34853 Mdot
.57663 .40547 Mdot
.57149 .54747 Mdot
.66407 .54205 Mdot
.54351 .42425 Mdot
.52011 .41525 Mdot
.60081 .37323 Mdot
.55253 .62167 Mdot
.64161 .38316 Mdot
.57321 .64077 Mdot
.55437 .60433 Mdot
.51113 .62905 Mdot
.36942 .70874 Mdot
.65606 .50015 Mdot
.28663 .73977 Mdot
.54231 .35066 Mdot
.27175 .40588 Mdot
.52829 .6702 Mdot
.82649 .53197 Mdot
.3257 .49722 Mdot
.56275 .42496 Mdot
.6428 .72821 Mdot
.53456 .65447 Mdot
.31498 .41137 Mdot
.57489 .40136 Mdot
.55339 .60206 Mdot
.68834 .5653 Mdot
.5505 .4433 Mdot
.53444 .68777 Mdot
.35681 .44605 Mdot
.67574 .59411 Mdot
.37653 .3919 Mdot
.50797 .63557 Mdot
.55381 .31334 Mdot
.51774 .88618 Mdot
.58384 .63155 Mdot
.27639 .3063 Mdot
.41758 .42173 Mdot
.54991 .40279 Mdot
.50925 .68166 Mdot
.37073 .45939 Mdot
.43671 .60065 Mdot
.43372 .46542 Mdot
.32523 .39853 Mdot
.54902 .61014 Mdot
.53031 .68775 Mdot
.56151 .64807 Mdot
.34192 .42378 Mdot
.56487 .32487 Mdot
.33443 .42193 Mdot
.42375 .60551 Mdot
.55935 .35677 Mdot
.19265 .63566 Mdot
.27467 .4124 Mdot
.37505 .43964 Mdot
.52254 .63288 Mdot
.67579 .58918 Mdot
.55329 .37435 Mdot
.30481 .28073 Mdot
.53581 .39481 Mdot
.41479 .58225 Mdot
.81386 .44643 Mdot
.57086 .25317 Mdot
.59553 .42678 Mdot
.56977 .34691 Mdot
.39784 .61228 Mdot
.54645 .38605 Mdot
.59 .42979 Mdot
.36707 .7012 Mdot
.34505 .43141 Mdot
.57266 .36773 Mdot
.50861 .64724 Mdot
.34678 .71171 Mdot
.54904 .32558 Mdot
.70865 .63664 Mdot
.70857 .4826 Mdot
.795 .38614 Mdot
.56082 .41199 Mdot
.70179 .34736 Mdot
.58759 .35161 Mdot
.58836 .4152 Mdot
.55658 .3462 Mdot
.56472 .21171 Mdot
.56796 .63182 Mdot
.555 .64327 Mdot
.69261 .57059 Mdot
.70562 .48197 Mdot
.65397 .56768 Mdot
.36669 .58762 Mdot
.67322 .64491 Mdot
.57205 .63772 Mdot
.36018 .44729 Mdot
.58816 .41939 Mdot
.58434 .63197 Mdot
.60277 .38256 Mdot
.54079 .37598 Mdot
.56026 .6665 Mdot
.57863 .64539 Mdot
.41215 .75277 Mdot
.68464 .55524 Mdot
.34747 .39254 Mdot
.53252 .41617 Mdot
.64728 .58442 Mdot
.57799 .32508 Mdot
.74764 .42189 Mdot
.34905 .39432 Mdot
.34187 .42917 Mdot
.31723 .39624 Mdot
.52685 .36489 Mdot
.54506 .37815 Mdot
.38341 .56284 Mdot
.36405 .45022 Mdot
.3817 .57347 Mdot
.52494 .51598 Mdot
.72337 .62483 Mdot
.57553 .40375 Mdot
.23199 .45266 Mdot
.65611 .57819 Mdot
.52951 .63564 Mdot
.73912 .63905 Mdot
.69262 .5738 Mdot
.53628 .38971 Mdot
.54431 .67243 Mdot
.64677 .54935 Mdot
.57071 .47824 Mdot
.34564 .79143 Mdot
.66332 .59289 Mdot
.60372 .35187 Mdot
.49192 .41159 Mdot
.54027 .18328 Mdot
.69095 .58379 Mdot
.40557 .56387 Mdot
.52577 .36882 Mdot
.34434 .47422 Mdot
.62971 .56064 Mdot
.3132 .65429 Mdot
.53982 .64575 Mdot
.51712 .79809 Mdot
.63438 .35342 Mdot
.599 .24121 Mdot
.63512 .56848 Mdot
.36171 .43046 Mdot
.39213 .38936 Mdot
.59527 .36502 Mdot
.69031 .58467 Mdot
.3461 .59271 Mdot
.53558 .64185 Mdot
.35067 .68739 Mdot
.33973 .42181 Mdot
.24925 .48952 Mdot
.52808 .62601 Mdot
.23023 .46915 Mdot
.80073 .505 Mdot
.60784 .30743 Mdot
.52998 .19248 Mdot
.51935 .73426 Mdot
.52269 .37635 Mdot
.64165 .58752 Mdot
.35541 .58992 Mdot
.40897 .56421 Mdot
.40289 .58674 Mdot
.31309 .58942 Mdot
.5725 .55651 Mdot
.49945 .66709 Mdot
.46505 .65973 Mdot
.66701 .57466 Mdot
.67808 .42397 Mdot
.60374 .33929 Mdot
.56505 .36737 Mdot
.56868 .4363 Mdot
.60955 .39921 Mdot
.58778 .35704 Mdot
.38296 .57921 Mdot
.31252 .61069 Mdot
.58701 .54096 Mdot
.35001 .39913 Mdot
.63532 .62327 Mdot
.53596 .67188 Mdot
.49776 .65676 Mdot
.65884 .54518 Mdot
.21899 .45327 Mdot
.5091 .6908 Mdot
.51151 .65541 Mdot
.53645 .40829 Mdot
.33301 .42748 Mdot
.56188 .46177 Mdot
.58348 .34236 Mdot
.5383 .63426 Mdot
.57322 .50551 Mdot
.49957 .27431 Mdot
.63632 .42193 Mdot
.71113 .56273 Mdot
.49676 .55917 Mdot
.68158 .58869 Mdot
.59821 .33191 Mdot
.82491 .51943 Mdot
.55495 .61798 Mdot
.51965 .65515 Mdot
.63807 .57304 Mdot
.30244 .36332 Mdot
.34276 .41448 Mdot
.51181 .7049 Mdot
.40102 .56376 Mdot
.57134 .33692 Mdot
.75853 .61372 Mdot
.28351 .37332 Mdot
.6479 .63655 Mdot
.40694 .5881 Mdot
.5274 .67668 Mdot
.58173 .43633 Mdot
.6028 .35173 Mdot
.64698 .57812 Mdot
.22476 .6269 Mdot
.54045 .43558 Mdot
.19652 .42084 Mdot
.69782 .73357 Mdot
.57955 .79163 Mdot
.59853 .37574 Mdot
.34516 .42997 Mdot
.52397 .69022 Mdot
.64634 .58139 Mdot
.61129 .43051 Mdot
.32718 .77579 Mdot
.39705 .41482 Mdot
.38112 .60379 Mdot
.56637 .52502 Mdot
.57378 .56785 Mdot
.53049 .39643 Mdot
.56388 .40997 Mdot
.58185 .41371 Mdot
.41417 .8189 Mdot
.55169 .62472 Mdot
.34585 .44787 Mdot
.67576 .55534 Mdot
.3165 .42045 Mdot
.55245 .6475 Mdot
.25768 .5001 Mdot
.54117 .40187 Mdot
.39755 .41804 Mdot
.3602 .42806 Mdot
.36836 .6018 Mdot
.43759 .59652 Mdot
.54365 .52262 Mdot
.57392 .39505 Mdot
.58619 .64318 Mdot
.38456 .41572 Mdot
.53288 .57793 Mdot
.64845 .56003 Mdot
.36671 .57282 Mdot
.60982 .37488 Mdot
.5628 .62449 Mdot
.60936 .41993 Mdot
.33863 .40324 Mdot
.51163 .65744 Mdot
.41047 .74824 Mdot
.67553 .54509 Mdot
.58891 .4022 Mdot
.6939 .58814 Mdot
.55309 .66442 Mdot
.57222 .35938 Mdot
.23935 .40766 Mdot
.7061 .55079 Mdot
.41329 .67128 Mdot
.50245 .65206 Mdot
.40406 .74388 Mdot
.32414 .38971 Mdot
.31649 .56059 Mdot
.51945 .65081 Mdot
.22457 .43458 Mdot
.25788 .65874 Mdot
.55714 .43722 Mdot
.37163 .41614 Mdot
.55413 .71049 Mdot
.1543 .57046 Mdot
.41343 .18667 Mdot
.55514 .38633 Mdot
.50163 .6667 Mdot
.63941 .57188 Mdot
.41168 .58331 Mdot
.7125 .6351 Mdot
.71413 .56741 Mdot
.57955 .62985 Mdot
.5568 .3451 Mdot
.36499 .43843 Mdot
.37504 .59029 Mdot
.28931 .58052 Mdot
.50967 .66704 Mdot
.52042 .62884 Mdot
.58473 .43507 Mdot
.66071 .56725 Mdot
.35297 .23747 Mdot
.55415 .63514 Mdot
.71992 .68215 Mdot
.56548 .67629 Mdot
.64187 .58434 Mdot
.59374 .35135 Mdot
.64899 .48449 Mdot
.52078 .36173 Mdot
.25517 .32649 Mdot
.54556 .6641 Mdot
.34122 .39833 Mdot
.56785 .41729 Mdot
.78891 .52027 Mdot
.53466 .63624 Mdot
.50393 .56577 Mdot
.60056 .72518 Mdot
.36925 .59201 Mdot
.73927 .64196 Mdot
.58835 .39401 Mdot
.42187 .58819 Mdot
.65545 .57754 Mdot
.56623 .39407 Mdot
.54632 .37522 Mdot
.34592 .45156 Mdot
.3831 .60783 Mdot
.28153 .6939 Mdot
.37346 .61631 Mdot
.36303 .57106 Mdot
.3123 .42328 Mdot
.58459 .37112 Mdot
.51799 .64397 Mdot
.53279 .65584 Mdot
.62448 .4181 Mdot
.84081 .51632 Mdot
.34006 .4147 Mdot
.61191 .63504 Mdot
.43791 .82804 Mdot
.59987 .30313 Mdot
.74377 .63467 Mdot
.22341 .61827 Mdot
.34777 .5837 Mdot
.61063 .36582 Mdot
.36326 .44479 Mdot
.50676 .70011 Mdot
.52002 .63103 Mdot
.56793 .32612 Mdot
.38179 .59111 Mdot
.6895 .56725 Mdot
.55815 .6728 Mdot
.6484 .63089 Mdot
.59195 .40965 Mdot
.64025 .73277 Mdot
.51541 .68162 Mdot
.16681 .44524 Mdot
.53492 .70916 Mdot
.37039 .41113 Mdot
.54245 .37276 Mdot
.31911 .40352 Mdot
.67054 .55213 Mdot
.56117 .52665 Mdot
.38054 .59299 Mdot
.49343 .34584 Mdot
.75043 .73842 Mdot
.56111 .65136 Mdot
.33058 .43738 Mdot
.59732 .4256 Mdot
.56648 .49016 Mdot
.58926 .38837 Mdot
.49371 .37002 Mdot
.68632 .53158 Mdot
.39594 .57056 Mdot
.41429 .57648 Mdot
.56718 .35866 Mdot
.66894 .58423 Mdot
.52426 .67523 Mdot
.53249 .64179 Mdot
.23285 .28571 Mdot
.41902 .6526 Mdot
.75192 .52524 Mdot
.57935 .40657 Mdot
.56235 .61348 Mdot
.3102 .6895 Mdot
.41127 .59556 Mdot
.61323 .35057 Mdot
.5665 .65522 Mdot
.60779 .7635 Mdot
.77882 .48792 Mdot
.59142 .35711 Mdot
.62781 .35242 Mdot
.4008 .56295 Mdot
.68969 .39866 Mdot
.513 .62909 Mdot
.51183 .3805 Mdot
.41388 .5601 Mdot
.80264 .44378 Mdot
.51975 .8204 Mdot
.34819 .39249 Mdot
.58949 .72323 Mdot
.38184 .57926 Mdot
.63557 .40152 Mdot
.67744 .57368 Mdot
.56285 .67221 Mdot
.5582 .62533 Mdot
.54518 .35263 Mdot
.60773 .42042 Mdot
.72357 .54734 Mdot
.32192 .42578 Mdot
.35959 .58693 Mdot
.55571 .40907 Mdot
.27075 .46985 Mdot
.60286 .41476 Mdot
.38188 .56488 Mdot
.49723 .8975 Mdot
.53741 .4232 Mdot
.59117 .38641 Mdot
.35453 .23453 Mdot
.32623 .39725 Mdot
.31655 .42442 Mdot
.73197 .70782 Mdot
.58019 .4063 Mdot
.73373 .65791 Mdot
.34386 .39145 Mdot
.33947 .41143 Mdot
.37657 .68927 Mdot
.55732 .37277 Mdot
.65732 .27037 Mdot
.41922 .58942 Mdot
.36884 .5636 Mdot
.33524 .42065 Mdot
.54065 .42951 Mdot
.36405 .56102 Mdot
.49956 .22346 Mdot
.52856 .66399 Mdot
.82764 .50069 Mdot
.33067 .40475 Mdot
.48644 .47655 Mdot
.40991 .59018 Mdot
.17529 .65224 Mdot
.47905 .66768 Mdot
.54893 .40505 Mdot
.58727 .40578 Mdot
.65962 .57834 Mdot
.54023 .42489 Mdot
.54437 .60924 Mdot
.39202 .58281 Mdot
.32049 .2882 Mdot
.35807 .39574 Mdot
.57926 .38974 Mdot
.22341 .47018 Mdot
.27345 .6217 Mdot
.50843 .76674 Mdot
.3495 .42171 Mdot
.37528 .41521 Mdot
.51391 .62936 Mdot
.50272 .67053 Mdot
.58959 .36696 Mdot
.39721 .61103 Mdot
.36719 .44907 Mdot
.39046 .56578 Mdot
.55389 .61806 Mdot
.51578 .64415 Mdot
.57164 .63369 Mdot
.52118 .43028 Mdot
.5094 .65466 Mdot
.67715 .62167 Mdot
.24825 .49924 Mdot
.30748 .39095 Mdot
.61476 .80393 Mdot
.29141 .57634 Mdot
.40461 .47425 Mdot
.63581 .548 Mdot
.55343 .66459 Mdot
.41105 .6137 Mdot
.57219 .35013 Mdot
.60605 .38048 Mdot
.50568 .61729 Mdot
.41988 .60595 Mdot
.66086 .55068 Mdot
.42445 .59337 Mdot
.68275 .56405 Mdot
.60946 .73847 Mdot
.56592 .43396 Mdot
.58827 .33577 Mdot
.38916 .57899 Mdot
.51039 .65849 Mdot
.54743 .64153 Mdot
.66905 .59332 Mdot
.4536 .42313 Mdot
.56576 .64206 Mdot
.33256 .40406 Mdot
.47273 .25112 Mdot
.52658 .68855 Mdot
.57777 .39918 Mdot
.73703 .38459 Mdot
.57722 .23826 Mdot
.53004 .34747 Mdot
.37024 .69336 Mdot
.67424 .25527 Mdot
.57099 .42249 Mdot
.67542 .24477 Mdot
.40176 .74082 Mdot
.32146 .4028 Mdot
.50508 .64855 Mdot
.49617 .67527 Mdot
.50018 .36735 Mdot
.62735 .58376 Mdot
.61458 .42966 Mdot
.33015 .39382 Mdot
.40376 .41758 Mdot
.62092 .77002 Mdot
.27261 .30898 Mdot
.6379 .56462 Mdot
.65322 .5442 Mdot
.5217 .64967 Mdot
.39419 .17712 Mdot
.62166 .44017 Mdot
.65423 .55112 Mdot
.66781 .31065 Mdot
.55587 .34385 Mdot
.73898 .47566 Mdot
.69864 .69953 Mdot
.34154 .42575 Mdot
.64477 .48366 Mdot
.52349 .6425 Mdot
.3193 .41816 Mdot
.28665 .48059 Mdot
.53288 .41192 Mdot
.35154 .39489 Mdot
.39027 .56436 Mdot
.49623 .72422 Mdot
.34408 .38665 Mdot
.74222 .39795 Mdot
.3816 .60964 Mdot
.52774 .57679 Mdot
.67629 .46196 Mdot
.89661 .46663 Mdot
.38519 .58149 Mdot
.57214 .65423 Mdot
.53284 .65482 Mdot
.53106 .64289 Mdot
.3183 .42045 Mdot
.53609 .67585 Mdot
.3261 .43165 Mdot
.48872 .16909 Mdot
.45392 .41972 Mdot
.65022 .55181 Mdot
.35811 .68448 Mdot
.36908 .42613 Mdot
.82097 .59214 Mdot
.81231 .6671 Mdot
.61193 .36931 Mdot
.39519 .61847 Mdot
.64338 .55504 Mdot
.20578 .38446 Mdot
.65267 .57282 Mdot
.6087 .56249 Mdot
.82211 .45954 Mdot
.58055 .38361 Mdot
.44361 .32752 Mdot
.6501 .54078 Mdot
.35599 .43234 Mdot
.56942 .36133 Mdot
.39563 .52487 Mdot
.65748 .572 Mdot
.68731 .57067 Mdot
.58265 .36332 Mdot
.38039 .40452 Mdot
.52278 .63761 Mdot
.42849 .58775 Mdot
.69557 .55296 Mdot
.36328 .36836 Mdot
.52301 .38881 Mdot
.52933 .37725 Mdot
.54246 .55809 Mdot
.65082 .60683 Mdot
.39176 .58452 Mdot
.60838 .22458 Mdot
.50269 .66445 Mdot
.57575 .69931 Mdot
.6977 .72398 Mdot
.37583 .70373 Mdot
.54578 .66223 Mdot
.5522 .66306 Mdot
.58981 .35992 Mdot
.67314 .60839 Mdot
.80779 .41812 Mdot
.36001 .53672 Mdot
.52074 .69028 Mdot
.53531 .64026 Mdot
.39994 .40621 Mdot
.63167 .76912 Mdot
.60903 .43154 Mdot
.35507 .58249 Mdot
.56246 .62582 Mdot
.35384 .35177 Mdot
.66507 .56795 Mdot
.82099 .56335 Mdot
.5649 .43284 Mdot
.55309 .40625 Mdot
.39495 .59433 Mdot
.37861 .56311 Mdot
.45475 .5958 Mdot
.6827 .74336 Mdot
.64879 .24711 Mdot
.29635 .60366 Mdot
.41881 .37442 Mdot
.39338 .39931 Mdot
.37539 .43907 Mdot
.33298 .65884 Mdot
.36815 .61499 Mdot
.57047 .4202 Mdot
.36447 .4481 Mdot
.49806 .74752 Mdot
.28089 .41935 Mdot
.74354 .499 Mdot
.74373 .60503 Mdot
.53591 .38604 Mdot
.34185 .43471 Mdot
.32639 .39972 Mdot
.37954 .44447 Mdot
.40006 .73793 Mdot
.59227 .3757 Mdot
.54584 .39335 Mdot
.58262 .42462 Mdot
.64944 .32263 Mdot
.60189 .39906 Mdot
.32063 .58451 Mdot
.51809 .53295 Mdot
.32659 .32577 Mdot
.5128 .39177 Mdot
.35379 .57322 Mdot
.52823 .39236 Mdot
.67253 .58316 Mdot
.56127 .34582 Mdot
.74792 .50174 Mdot
.39877 .60366 Mdot
.41345 .39855 Mdot
.30121 .58558 Mdot
.54525 .41405 Mdot
.68815 .55403 Mdot
.43137 .44075 Mdot
.24024 .67323 Mdot
.62424 .58682 Mdot
.33225 .4047 Mdot
.53457 .66555 Mdot
.41203 .61242 Mdot
.51482 .65133 Mdot
.52559 .43334 Mdot
.34615 .66063 Mdot
.23184 .57114 Mdot
.52563 .50687 Mdot
.61037 .39319 Mdot
.63916 .34756 Mdot
.33631 .40675 Mdot
.54515 .6722 Mdot
.29074 .41487 Mdot
.57203 .41581 Mdot
.6748 .55765 Mdot
.66071 .57441 Mdot
.38851 .51514 Mdot
.18032 .52632 Mdot
.33238 .5367 Mdot
.39564 .59173 Mdot
.55564 .63325 Mdot
.63519 .57622 Mdot
.25934 .41043 Mdot
.43793 .60283 Mdot
.39758 .61269 Mdot
.37604 .60368 Mdot
.54314 .34513 Mdot
.57343 .64032 Mdot
.32707 .31969 Mdot
.55729 .61245 Mdot
.54344 .38556 Mdot
.5476 .62276 Mdot
.56638 .65079 Mdot
.66791 .57843 Mdot
.36211 .59423 Mdot
.54025 .61548 Mdot
.59379 .34141 Mdot
.36294 .3937 Mdot
.46589 .45026 Mdot
.76533 .46665 Mdot
.25919 .34199 Mdot
.28071 .34154 Mdot
.35586 .38577 Mdot
.16596 .58405 Mdot
.3541 .60186 Mdot
.6623 .33029 Mdot
.449 .76121 Mdot
.57229 .32921 Mdot
.83288 .58721 Mdot
.49942 .66908 Mdot
.56443 .66334 Mdot
.59116 .35002 Mdot
.56113 .72588 Mdot
.58276 .38849 Mdot
.53899 .619 Mdot
.62746 .62503 Mdot
.54669 .31365 Mdot
.51547 .66985 Mdot
.51058 .38071 Mdot
.5552 .36904 Mdot
.34123 .42707 Mdot
.51216 .68314 Mdot
.61586 .35523 Mdot
.20207 .34851 Mdot
.37392 .56697 Mdot
.40261 .72856 Mdot
.73777 .36235 Mdot
.38041 .57866 Mdot
.3627 .40011 Mdot
.63175 .40394 Mdot
.65084 .57821 Mdot
.36965 .43048 Mdot
.78339 .49053 Mdot
.65598 .54087 Mdot
.82407 .59851 Mdot
.32904 .40954 Mdot
.52244 .68852 Mdot
.67845 .57552 Mdot
.52685 .34381 Mdot
.56505 .66974 Mdot
.41707 .47326 Mdot
.54341 .66475 Mdot
.59991 .38167 Mdot
.34326 .67942 Mdot
.35996 .58117 Mdot
.55777 .38628 Mdot
.55469 .6738 Mdot
.36322 .70138 Mdot
.54291 .34634 Mdot
.57809 .3524 Mdot
.57732 .79811 Mdot
.79361 .61054 Mdot
.64626 .56705 Mdot
.36854 .4576 Mdot
.60048 .34792 Mdot
.68659 .56398 Mdot
.64684 .69694 Mdot
.52567 .37943 Mdot
.39575 .42348 Mdot
.6486 .39892 Mdot
.52676 .68297 Mdot
.37506 .57535 Mdot
.51605 .50536 Mdot
.68811 .5645 Mdot
.69591 .21184 Mdot
.56413 .61838 Mdot
.60299 .33521 Mdot
.61256 .39172 Mdot
.5001 .7805 Mdot
.32179 .407 Mdot
.66015 .26152 Mdot
.58885 .40248 Mdot
.64288 .31454 Mdot
.56743 .39097 Mdot
.60302 .61088 Mdot
.34136 .41375 Mdot
.59466 .38673 Mdot
.23891 .46776 Mdot
.56717 .31958 Mdot
.68925 .5605 Mdot
.38753 .20849 Mdot
.52162 .37756 Mdot
.6308 .85127 Mdot
.727 .65729 Mdot
.51351 .66874 Mdot
.33168 .66312 Mdot
.38777 .15203 Mdot
.30897 .5819 Mdot
.33152 .43686 Mdot
.22259 .59946 Mdot
.51776 .64345 Mdot
.31554 .66931 Mdot
.16213 .58416 Mdot
.55493 .3664 Mdot
.53061 .39666 Mdot
.61026 .55686 Mdot
.5335 .60969 Mdot
.58361 .65031 Mdot
.51861 .42059 Mdot
.60372 .4523 Mdot
.51436 .64063 Mdot
.60456 .34843 Mdot
.50982 .41289 Mdot
.42881 .59537 Mdot
.36151 .38841 Mdot
.40834 .57807 Mdot
.36645 .60319 Mdot
.47435 .20039 Mdot
.66346 .74829 Mdot
.37749 .56695 Mdot
.3529 .593 Mdot
.74309 .47852 Mdot
.70712 .51556 Mdot
.63002 .55833 Mdot
.17902 .46452 Mdot
.53251 .64464 Mdot
.58923 .37553 Mdot
.34059 .38278 Mdot
.60867 .24569 Mdot
.70077 .66322 Mdot
.81482 .4256 Mdot
.572 .41812 Mdot
.52962 .63896 Mdot
.39895 .73807 Mdot
.54635 .45675 Mdot
.56629 .69018 Mdot
.55263 .41024 Mdot
.58219 .64114 Mdot
.4522 .28182 Mdot
.22522 .4463 Mdot
.58021 .65816 Mdot
.32161 .37383 Mdot
.55971 .40506 Mdot
.32942 .40369 Mdot
.40697 .58374 Mdot
.66553 .58269 Mdot
.64796 .56401 Mdot
.57613 .35965 Mdot
.62841 .31594 Mdot
.62052 .73524 Mdot
.55263 .37395 Mdot
.55406 .34953 Mdot
.40174 .74096 Mdot
.5565 .35049 Mdot
.60726 .40171 Mdot
.59863 .41446 Mdot
.60348 .32727 Mdot
.36489 .56831 Mdot
.22447 .46862 Mdot
.5495 .4502 Mdot
.52515 .44065 Mdot
.41613 .5671 Mdot
.23885 .6519 Mdot
.3675 .60791 Mdot
.19486 .64007 Mdot
.41355 .57958 Mdot
.65252 .5559 Mdot
.41361 .7699 Mdot
.63274 .32747 Mdot
.38819 .41636 Mdot
.42609 .61337 Mdot
.6793 .5574 Mdot
.39828 .58431 Mdot
.53401 .62306 Mdot
.46488 .82262 Mdot
.31564 .3684 Mdot
.69106 .30726 Mdot
.37408 .51088 Mdot
.42695 .66199 Mdot
.5449 .6137 Mdot
.33748 .41617 Mdot
.49376 .28406 Mdot
.60576 .40829 Mdot
.68576 .56468 Mdot
.5872 .36347 Mdot
.35878 .57692 Mdot
.52526 .64352 Mdot
.38891 .20279 Mdot
.64804 .57833 Mdot
.62001 .7956 Mdot
.54249 .64583 Mdot
.58946 .42504 Mdot
.35579 .58026 Mdot
.66712 .78411 Mdot
.40285 .57361 Mdot
.50305 .31972 Mdot
.36009 .37866 Mdot
.51715 .19066 Mdot
.37003 .42059 Mdot
.51923 .70442 Mdot
.49292 .85391 Mdot
.21282 .40822 Mdot
.37672 .40134 Mdot
.45486 .64433 Mdot
.53236 .38093 Mdot
.5292 .38045 Mdot
.25727 .39005 Mdot
.372 .45597 Mdot
.61223 .37494 Mdot
.41015 .7446 Mdot
.24957 .52664 Mdot
.75337 .64024 Mdot
.54409 .66854 Mdot
.58494 .3928 Mdot
.41386 .56211 Mdot
.4233 .59592 Mdot
.5652 .61732 Mdot
.3717 .612 Mdot
.54701 .3916 Mdot
.36902 .42439 Mdot
.58735 .62827 Mdot
.65999 .55889 Mdot
.24441 .30762 Mdot
.63518 .58303 Mdot
.5463 .66145 Mdot
.55713 .31271 Mdot
.51517 .6448 Mdot
.44001 .11514 Mdot
.54869 .39696 Mdot
.3414 .3931 Mdot
.57628 .34472 Mdot
.56058 .40135 Mdot
.52974 .39603 Mdot
.52342 .63085 Mdot
.68289 .27827 Mdot
.59909 .34378 Mdot
.37907 .59322 Mdot
.34136 .33709 Mdot
.52857 .39818 Mdot
.61518 .62353 Mdot
.71991 .50575 Mdot
.46997 .66626 Mdot
.34148 .38006 Mdot
.52769 .67314 Mdot
.36482 .39721 Mdot
.28395 .39719 Mdot
.36219 .39996 Mdot
.38774 .33999 Mdot
.48444 .28434 Mdot
.70547 .29059 Mdot
.37157 .24212 Mdot
.64258 .45501 Mdot
.36998 .45696 Mdot
.64747 .51363 Mdot
.37565 .44213 Mdot
.3257 .40354 Mdot
.30791 .84141 Mdot
.38556 .42371 Mdot
.58158 .40079 Mdot
.54376 .42041 Mdot
.26778 .5918 Mdot
.72677 .44477 Mdot
.5643 .35326 Mdot
.59257 .34498 Mdot
.66444 .58141 Mdot
.61203 .29678 Mdot
.34788 .6635 Mdot
.79218 .63884 Mdot
.28313 .63866 Mdot
.58454 .36245 Mdot
.59616 .34429 Mdot
.5801 .45995 Mdot
.65701 .81147 Mdot
.51393 .20983 Mdot
.39062 .44847 Mdot
.63548 .40611 Mdot
.23748 .35101 Mdot
.54771 .41303 Mdot
.53564 .34932 Mdot
.53474 .38525 Mdot
.51824 .64334 Mdot
.39524 .40903 Mdot
.62324 .4286 Mdot
.69461 .71405 Mdot
.54091 .40678 Mdot
.37284 .70173 Mdot
.49654 .14793 Mdot
.58901 .3943 Mdot
.38621 .39877 Mdot
.53472 .36248 Mdot
.32626 .4146 Mdot
.35275 .43567 Mdot
.56929 .31408 Mdot
.40457 .36404 Mdot
.38951 .39851 Mdot
.54298 .38497 Mdot
.52806 .63191 Mdot
.17002 .4718 Mdot
.6006 .38387 Mdot
.64726 .58379 Mdot
.5863 .40529 Mdot
.69022 .55454 Mdot
.55204 .35455 Mdot
.56811 .62092 Mdot
.5704 .24909 Mdot
.52109 .65372 Mdot
.55911 .18083 Mdot
.57568 .63719 Mdot
.58659 .79682 Mdot
.39419 .43898 Mdot
.34918 .68332 Mdot
.77479 .3286 Mdot
.39289 .71769 Mdot
.48357 .56547 Mdot
.47973 .53669 Mdot
.39618 .61137 Mdot
.31992 .39994 Mdot
.68313 .36546 Mdot
.50313 .76015 Mdot
.48444 .77062 Mdot
.56886 .64372 Mdot
.77139 .30252 Mdot
.82908 .44303 Mdot
.57826 .33685 Mdot
.42726 .33728 Mdot
.37927 .28307 Mdot
.52366 .37709 Mdot
.63385 .39932 Mdot
.52759 .60407 Mdot
.6164 .37991 Mdot
.26463 .46584 Mdot
.54868 .65674 Mdot
.68073 .55869 Mdot
.33531 .39914 Mdot
.69048 .57277 Mdot
.49631 .76264 Mdot
.47654 .53787 Mdot
.54549 .61836 Mdot
.58712 .32202 Mdot
.58274 .34529 Mdot
.33503 .42471 Mdot
.32668 .45257 Mdot
.3816 .425 Mdot
.63908 .5649 Mdot
.54541 .65469 Mdot
.56223 .22594 Mdot
.60074 .35286 Mdot
.35977 .42578 Mdot
.4623 .56119 Mdot
.60491 .35384 Mdot
.39359 .57736 Mdot
.53673 .39255 Mdot
.36906 .39495 Mdot
.55643 .35072 Mdot
.37134 .42331 Mdot
.53069 .66603 Mdot
.55629 .4242 Mdot
.59251 .35332 Mdot
.64374 .7945 Mdot
.66152 .5517 Mdot
.3823 .45195 Mdot
.57137 .72693 Mdot
.61054 .40594 Mdot
.41358 .6849 Mdot
.56131 .40862 Mdot
.2939 .44173 Mdot
.59137 .32731 Mdot
.38663 .72497 Mdot
.60226 .43473 Mdot
.59979 .38424 Mdot
.41399 .51867 Mdot
.37649 .30338 Mdot
.35048 .4641 Mdot
.3562 .57514 Mdot
.38944 .42731 Mdot
.75115 .61421 Mdot
.51367 .69317 Mdot
.53978 .67593 Mdot
.70321 .39654 Mdot
.6142 .33381 Mdot
.58195 .38247 Mdot
.42702 .57426 Mdot
.66607 .54349 Mdot
.35121 .42357 Mdot
.68226 .56326 Mdot
.70665 .71714 Mdot
.6422 .55012 Mdot
.49874 .64478 Mdot
.63911 .73084 Mdot
.53333 .22621 Mdot
.6645 .5811 Mdot
.38135 .40502 Mdot
.72606 .61223 Mdot
.5613 .32841 Mdot
.7147 .54762 Mdot
.67428 .55954 Mdot
.75804 .27628 Mdot
.60779 .39898 Mdot
.48879 .56841 Mdot
.3807 .56894 Mdot
.67574 .57524 Mdot
.3979 .60818 Mdot
.5683 .35372 Mdot
.40593 .67069 Mdot
.34938 .44777 Mdot
.37556 .55467 Mdot
.5206 .40301 Mdot
.64633 .55181 Mdot
.56266 .628 Mdot
.42027 .62244 Mdot
.36159 .56401 Mdot
.21931 .62219 Mdot
.44209 .1788 Mdot
.54357 .65417 Mdot
.79901 .53438 Mdot
.41867 .58644 Mdot
.52495 .36384 Mdot
.621 .29418 Mdot
.54857 .40534 Mdot
.32216 .56632 Mdot
.53163 .67352 Mdot
.24324 .54933 Mdot
.57816 .34325 Mdot
.5829 .42014 Mdot
.35893 .46476 Mdot
.52827 .65422 Mdot
.35723 .41015 Mdot
.38662 .43121 Mdot
.53031 .66491 Mdot
.36957 .41274 Mdot
.6585 .53996 Mdot
.25867 .52898 Mdot
.4137 .57147 Mdot
.38062 .59695 Mdot
.5338 .64057 Mdot
.50953 .6641 Mdot
.51204 .65399 Mdot
.53686 .39294 Mdot
.34576 .41855 Mdot
.5431 .36841 Mdot
.53009 .39479 Mdot
.43809 .39321 Mdot
.35573 .384 Mdot
.53572 .37232 Mdot
.55088 .70855 Mdot
.70891 .57453 Mdot
.53133 .62909 Mdot
.37676 .56865 Mdot
.32467 .7038 Mdot
.34528 .60821 Mdot
.58202 .39387 Mdot
.60504 .76221 Mdot
.38187 .41181 Mdot
.6556 .57652 Mdot
.63302 .54622 Mdot
.64959 .57164 Mdot
.37175 .54562 Mdot
.37813 .45074 Mdot
.79513 .63547 Mdot
.58515 .38949 Mdot
.54141 .5596 Mdot
.67206 .31068 Mdot
.61306 .74477 Mdot
.37389 .56921 Mdot
.59938 .34785 Mdot
.5088 .49658 Mdot
.51437 .26582 Mdot
.55224 .40425 Mdot
.54287 .33402 Mdot
.42554 .7445 Mdot
.63662 .43306 Mdot
.37345 .38329 Mdot
.70689 .73646 Mdot
.56143 .43627 Mdot
.31527 .35792 Mdot
.28255 .24994 Mdot
.57393 .39778 Mdot
.58107 .41585 Mdot
.60441 .36981 Mdot
.56192 .34326 Mdot
.38082 .39137 Mdot
.69587 .43378 Mdot
.356 .60457 Mdot
.56311 .55398 Mdot
.4068 .56364 Mdot
.57518 .65672 Mdot
.23164 .48525 Mdot
.32051 .39555 Mdot
.65896 .57852 Mdot
.20938 .4461 Mdot
.75247 .69407 Mdot
.51104 .63268 Mdot
.4831 .22837 Mdot
.66883 .55549 Mdot
.52708 .35717 Mdot
.6807 .5429 Mdot
.57339 .6421 Mdot
.37296 .59395 Mdot
.61951 .33817 Mdot
.37792 .43415 Mdot
.34069 .38681 Mdot
.61212 .37214 Mdot
.23038 .3705 Mdot
.38857 .57508 Mdot
.43992 .60572 Mdot
.531 .359 Mdot
.52082 .35576 Mdot
.35701 .4069 Mdot
.5477 .6355 Mdot
.77156 .54622 Mdot
.66177 .5459 Mdot
.62024 .39077 Mdot
.55778 .3441 Mdot
.68859 .74047 Mdot
.36654 .58644 Mdot
.5051 .63639 Mdot
.55096 .34104 Mdot
.31134 .62582 Mdot
.55105 .34128 Mdot
.5855 .4643 Mdot
.52935 .63249 Mdot
.5689 .4503 Mdot
.59116 .33768 Mdot
.51168 .32656 Mdot
.41342 .60092 Mdot
.34527 .39451 Mdot
.30317 .39496 Mdot
.59569 .52658 Mdot
.39594 .57881 Mdot
.53521 .36781 Mdot
.37005 .58173 Mdot
.52745 .38705 Mdot
.61351 .37202 Mdot
.38171 .5651 Mdot
.35803 .41041 Mdot
.23373 .61056 Mdot
.22643 .47605 Mdot
.56463 .34249 Mdot
.57419 .43964 Mdot
.70937 .43263 Mdot
.7329 .31306 Mdot
.56696 .41512 Mdot
.35772 .39039 Mdot
.59597 .34997 Mdot
.40292 .6051 Mdot
.64216 .54623 Mdot
.36555 .39441 Mdot
.55266 .64188 Mdot
.52081 .6212 Mdot
.30285 .58248 Mdot
.56034 .65828 Mdot
.55444 .33319 Mdot
.28404 .39336 Mdot
.31026 .4248 Mdot
.26484 .27676 Mdot
.52985 .66213 Mdot
.6484 .5391 Mdot
.57653 .35399 Mdot
.5795 .78409 Mdot
.43151 .57938 Mdot
.67434 .83163 Mdot
.81579 .61097 Mdot
.63857 .58889 Mdot
.80063 .38834 Mdot
.57854 .65444 Mdot
.6144 .36163 Mdot
.66597 .58316 Mdot
.51087 .63506 Mdot
.56766 .33173 Mdot
.61675 .33072 Mdot
.66591 .2639 Mdot
.57819 .52869 Mdot
.36868 .58106 Mdot
.51621 .67757 Mdot
.62582 .54727 Mdot
.50868 .62663 Mdot
.33459 .38648 Mdot
.59708 .38299 Mdot
.60626 .30849 Mdot
.55154 .63799 Mdot
.52877 .6117 Mdot
.53784 .38374 Mdot
.3192 .40233 Mdot
.50267 .62279 Mdot
.57816 .36361 Mdot
.65176 .43415 Mdot
.33241 .37273 Mdot
.55316 .65391 Mdot
.59161 .4179 Mdot
.72017 .57612 Mdot
.5433 .64239 Mdot
.53354 .62768 Mdot
.61259 .37095 Mdot
.66365 .54012 Mdot
.58352 .43611 Mdot
.40968 .57335 Mdot
.63647 .2233 Mdot
.39535 .60691 Mdot
.71391 .62734 Mdot
.541 .32321 Mdot
.39019 .65273 Mdot
.32801 .38623 Mdot
.61307 .58037 Mdot
.35039 .73748 Mdot
.51468 .41421 Mdot
.17372 .54327 Mdot
.48455 .48123 Mdot
.22071 .35774 Mdot
.34795 .77031 Mdot
.67267 .56447 Mdot
.40187 .58567 Mdot
.58052 .4156 Mdot
.41278 .61528 Mdot
.65626 .58487 Mdot
.54277 .18642 Mdot
.59744 .4139 Mdot
.34071 .41191 Mdot
.54018 .38973 Mdot
.33122 .40514 Mdot
.60973 .36192 Mdot
.54532 .45454 Mdot
.3994 .74665 Mdot
.77804 .48639 Mdot
.57103 .32838 Mdot
.48545 .83316 Mdot
.69928 .68663 Mdot
.67375 .55212 Mdot
.54654 .37103 Mdot
.51095 .69729 Mdot
.42055 .60266 Mdot
.28173 .44909 Mdot
.51847 .64163 Mdot
.36074 .60152 Mdot
.36208 .40495 Mdot
.53767 .6686 Mdot
.53267 .61302 Mdot
.58257 .44634 Mdot
.69185 .56261 Mdot
.37069 .59914 Mdot
.59647 .38928 Mdot
.60086 .40829 Mdot
.78601 .55839 Mdot
.69082 .6597 Mdot
.30507 .42571 Mdot
.73228 .74634 Mdot
.30439 .40434 Mdot
.65684 .54956 Mdot
.52219 .63672 Mdot
.56519 .41151 Mdot
.55753 .38385 Mdot
.35403 .69078 Mdot
.35495 .45108 Mdot
.55838 .52424 Mdot
.45309 .21238 Mdot
.51122 .61585 Mdot
.71943 .48469 Mdot
.33772 .39219 Mdot
.72028 .48276 Mdot
.632 .54177 Mdot
.19513 .45841 Mdot
.76809 .496 Mdot
.37704 .57072 Mdot
.71584 .48155 Mdot
.36043 .4337 Mdot
.57954 .33912 Mdot
.5169 .68879 Mdot
.56563 .65109 Mdot
.34792 .4006 Mdot
.57074 .60778 Mdot
.66853 .57711 Mdot
.58887 .41311 Mdot
.78955 .63153 Mdot
.29756 .54364 Mdot
.5527 .63099 Mdot
.53163 .44849 Mdot
.37828 .60469 Mdot
.61402 .37828 Mdot
.64524 .58189 Mdot
.38118 .5837 Mdot
.73182 .6448 Mdot
.24681 .5377 Mdot
.57252 .35775 Mdot
.60773 .78443 Mdot
.39126 .57993 Mdot
.77807 .37391 Mdot
.58455 .36815 Mdot
.41847 .58766 Mdot
.62883 .43505 Mdot
.50555 .72367 Mdot
.51799 .49929 Mdot
.16078 .58152 Mdot
.53593 .51654 Mdot
.54296 .6835 Mdot
.48009 .70958 Mdot
.46974 .74105 Mdot
.41438 .61359 Mdot
.52435 .61411 Mdot
.64701 .60932 Mdot
.39823 .60849 Mdot
.53057 .40041 Mdot
.56555 .40443 Mdot
.51643 .20649 Mdot
.48015 .48755 Mdot
.52008 .71095 Mdot
.32775 .51272 Mdot
.60801 .4094 Mdot
.55006 .43424 Mdot
.56375 .37949 Mdot
.40316 .41613 Mdot
.37046 .58752 Mdot
.56075 .82164 Mdot
.39839 .57802 Mdot
.81623 .56395 Mdot
.53089 .64451 Mdot
.52555 .67629 Mdot
.5858 .39511 Mdot
.51252 .5853 Mdot
.67378 .48347 Mdot
.54659 .38924 Mdot
.57436 .57717 Mdot
.36839 .22109 Mdot
.52411 .40512 Mdot
.3503 .37719 Mdot
.49794 .37918 Mdot
.39009 .38552 Mdot
.41536 .57272 Mdot
.66437 .56547 Mdot
.61531 .58659 Mdot
.37058 .59459 Mdot
.5805 .38154 Mdot
.36675 .65573 Mdot
.55979 .39637 Mdot
.56794 .33697 Mdot
.82726 .54301 Mdot
.63695 .58485 Mdot
.51728 .66455 Mdot
.64625 .57081 Mdot
.3235 .40608 Mdot
.50115 .91117 Mdot
.67098 .54469 Mdot
.66541 .48451 Mdot
.57662 .195 Mdot
.71522 .47774 Mdot
.33417 .38831 Mdot
.69383 .57804 Mdot
.38032 .57392 Mdot
.16674 .43754 Mdot
.71321 .27992 Mdot
.38169 .62765 Mdot
.57498 .36753 Mdot
.31536 .40626 Mdot
.37437 .39503 Mdot
.37988 .55416 Mdot
.35402 .4348 Mdot
.63896 .40731 Mdot
.57102 .3404 Mdot
.404 .61699 Mdot
.28008 .58211 Mdot
.36077 .56452 Mdot
.25977 .49918 Mdot
.54443 .37572 Mdot
.34399 .39011 Mdot
.5028 .36548 Mdot
.41103 .42476 Mdot
.50123 .64425 Mdot
.52087 .37498 Mdot
.66664 .57801 Mdot
.3763 .64768 Mdot
.54423 .65176 Mdot
.59675 .7618 Mdot
.33313 .42174 Mdot
.4565 .61126 Mdot
.3433 .42939 Mdot
.36247 .45827 Mdot
.36833 .60578 Mdot
.34987 .44538 Mdot
.58316 .41559 Mdot
.53125 .70407 Mdot
.32712 .42354 Mdot
.39525 .60002 Mdot
.65834 .56432 Mdot
.36665 .41346 Mdot
.55863 .72656 Mdot
.5842 .35375 Mdot
.52111 .62871 Mdot
.43211 .77779 Mdot
.31843 .42936 Mdot
.68145 .58758 Mdot
.54533 .67267 Mdot
.68724 .57365 Mdot
.32919 .23388 Mdot
.37232 .61736 Mdot
.81625 .44627 Mdot
.71369 .58407 Mdot
.38594 .41858 Mdot
.41547 .76831 Mdot
.56779 .40944 Mdot
.58169 .35281 Mdot
.69519 .55922 Mdot
.37496 .39544 Mdot
.19615 .4239 Mdot
.41502 .45319 Mdot
.25577 .54389 Mdot
.39358 .62136 Mdot
.5535 .81134 Mdot
.2539 .47985 Mdot
.43095 .16044 Mdot
.53492 .4311 Mdot
.58189 .65059 Mdot
.57619 .38835 Mdot
.33683 .72418 Mdot
.64322 .55585 Mdot
.60446 .63827 Mdot
.56177 .31779 Mdot
.52685 .6694 Mdot
.59782 .36526 Mdot
.40798 .50615 Mdot
.50311 .40308 Mdot
.64245 .54267 Mdot
.34405 .66469 Mdot
.38741 .42287 Mdot
.66285 .55747 Mdot
.56267 .61953 Mdot
.69162 .48548 Mdot
.58094 .33045 Mdot
.53158 .43811 Mdot
.50307 .62425 Mdot
.33898 .41528 Mdot
.52665 .68518 Mdot
.41513 .57414 Mdot
.66448 .573 Mdot
.57265 .34907 Mdot
.58948 .3251 Mdot
.41517 .68664 Mdot
.37054 .60179 Mdot
.55895 .60568 Mdot
.40385 .57558 Mdot
.57694 .66058 Mdot
.58646 .43987 Mdot
.52764 .67672 Mdot
.60796 .3462 Mdot
.37064 .74312 Mdot
.82542 .54043 Mdot
.39176 .31363 Mdot
.53609 .67198 Mdot
.73613 .5124 Mdot
.40265 .60246 Mdot
.41247 .58079 Mdot
.56879 .21102 Mdot
.54911 .28034 Mdot
.7736 .60711 Mdot
.22599 .65259 Mdot
.40824 .56492 Mdot
.38461 .60524 Mdot
.51901 .62896 Mdot
.34145 .44131 Mdot
.33696 .44785 Mdot
.58048 .64679 Mdot
.73496 .3741 Mdot
.3514 .4236 Mdot
.17732 .49667 Mdot
.75671 .62132 Mdot
.61933 .43137 Mdot
.45832 .58623 Mdot
.65933 .57151 Mdot
.74067 .40091 Mdot
.40496 .50897 Mdot
.5791 .41995 Mdot
.67678 .74632 Mdot
.54161 .63542 Mdot
.69496 .3886 Mdot
.19666 .64109 Mdot
.60169 .41007 Mdot
.58872 .3736 Mdot
.57319 .38125 Mdot
.64547 .59243 Mdot
.5831 .26161 Mdot
.59558 .41235 Mdot
.73495 .36918 Mdot
.61374 .40173 Mdot
.50754 .45689 Mdot
.647 .56611 Mdot
.54429 .47616 Mdot
.41602 .75007 Mdot
.72603 .69804 Mdot
.52563 .32122 Mdot
.41501 .57562 Mdot
.58698 .56499 Mdot
.41599 .59929 Mdot
.38476 .33407 Mdot
.76657 .49048 Mdot
.31173 .38175 Mdot
.5784 .41875 Mdot
.54715 .66081 Mdot
.37181 .39349 Mdot
.46055 .70831 Mdot
.40194 .90389 Mdot
.42018 .58296 Mdot
.48878 .12507 Mdot
.4088 .57599 Mdot
.54086 .61068 Mdot
.3564 .40546 Mdot
.47918 .28352 Mdot
.54043 .55672 Mdot
.36875 .41518 Mdot
.2336 .58244 Mdot
.37379 .46528 Mdot
.72413 .50036 Mdot
.30835 .40634 Mdot
.39834 .60088 Mdot
.36178 .55307 Mdot
.63098 .34447 Mdot
.57795 .40557 Mdot
.47218 .53272 Mdot
.69399 .50112 Mdot
.57249 .40855 Mdot
.54684 .65645 Mdot
.77071 .34734 Mdot
.61305 .52351 Mdot
.36097 .44421 Mdot
.34747 .59342 Mdot
.5914 .37234 Mdot
.55303 .34251 Mdot
.57827 .3323 Mdot
.74594 .74258 Mdot
.19381 .44875 Mdot
.59909 .34404 Mdot
.60764 .41396 Mdot
.53452 .66892 Mdot
.66877 .53103 Mdot
.32331 .72014 Mdot
.47576 .40659 Mdot
.56099 .42267 Mdot
.65648 .55659 Mdot
.63343 .58377 Mdot
.56615 .33164 Mdot
.69201 .71287 Mdot
.4113 .65627 Mdot
.59699 .38895 Mdot
.53167 .2942 Mdot
.49021 .75241 Mdot
.5317 .6108 Mdot
.5499 .64006 Mdot
.38791 .40314 Mdot
.55826 .65719 Mdot
.57637 .63413 Mdot
.49349 .26299 Mdot
.53647 .525 Mdot
.39398 .544 Mdot
.63885 .56585 Mdot
.55712 .38767 Mdot
.30871 .42847 Mdot
.32098 .6377 Mdot
.38626 .61122 Mdot
.37853 .4125 Mdot
.42137 .59818 Mdot
.66858 .59632 Mdot
.68914 .31218 Mdot
.57068 .6433 Mdot
.38964 .55712 Mdot
.24713 .53622 Mdot
.65343 .55845 Mdot
.36113 .59588 Mdot
.37763 .66055 Mdot
.52944 .40257 Mdot
.45079 .34838 Mdot
.54635 .38453 Mdot
.20955 .3875 Mdot
.36121 .59169 Mdot
.38128 .71987 Mdot
.58768 .38289 Mdot
.54132 .64482 Mdot
.60357 .45842 Mdot
.55297 .41183 Mdot
.55768 .64132 Mdot
.5789 .33724 Mdot
.66317 .58771 Mdot
.33312 .37043 Mdot
.57049 .54874 Mdot
.86218 .44319 Mdot
.69249 .56403 Mdot
.45062 .70038 Mdot
.56856 .41657 Mdot
.39669 .19589 Mdot
.36638 .41528 Mdot
.60232 .33711 Mdot
.65537 .46925 Mdot
.3239 .42586 Mdot
.37211 .40296 Mdot
.54246 .3553 Mdot
.38375 .56962 Mdot
.54765 .65056 Mdot
.64953 .56295 Mdot
.33296 .22329 Mdot
.56629 .36748 Mdot
.59395 .35165 Mdot
.66694 .55618 Mdot
.38938 .60672 Mdot
.54468 .3468 Mdot
.44652 .79069 Mdot
.2075 .34892 Mdot
.39158 .61343 Mdot
.53993 .41163 Mdot
.45317 .36853 Mdot
.38151 .37672 Mdot
.61508 .18176 Mdot
.73241 .59576 Mdot
.51935 .6703 Mdot
.63819 .42587 Mdot
.55522 .88638 Mdot
.66208 .5658 Mdot
.76314 .6656 Mdot
.56182 .33673 Mdot
.60513 .36039 Mdot
.38175 .42196 Mdot
.53921 .37117 Mdot
.32315 .43099 Mdot
.84647 .41607 Mdot
.68094 .75094 Mdot
.33314 .41249 Mdot
.38093 .43185 Mdot
.65188 .48284 Mdot
.32572 .72051 Mdot
.34965 .39949 Mdot
.6055 .42191 Mdot
.28138 .35669 Mdot
.49028 .36192 Mdot
.69372 .55443 Mdot
.46259 .76919 Mdot
.41175 .40002 Mdot
.63576 .52396 Mdot
.22507 .61979 Mdot
.40689 .3912 Mdot
.43761 .64561 Mdot
.40556 .56836 Mdot
.59526 .41894 Mdot
.56383 .65421 Mdot
.5373 .67613 Mdot
.50314 .38322 Mdot
.55526 .39455 Mdot
.32594 .41213 Mdot
.63644 .56596 Mdot
.42024 .60821 Mdot
.59211 .34523 Mdot
.6146 .52573 Mdot
.66964 .5455 Mdot
.34699 .43931 Mdot
.63769 .26408 Mdot
.64327 .54107 Mdot
.50758 .42702 Mdot
.59443 .3993 Mdot
.53583 .38587 Mdot
.50314 .33166 Mdot
.37275 .56578 Mdot
.40508 .76339 Mdot
.558 .42997 Mdot
.70694 .71788 Mdot
.45522 .43397 Mdot
.58137 .45332 Mdot
.34806 .42703 Mdot
.43077 .57736 Mdot
.50026 .67952 Mdot
.6782 .40903 Mdot
.56896 .36096 Mdot
.20904 .42838 Mdot
.48682 .20472 Mdot
.49881 .66019 Mdot
.36872 .45645 Mdot
.65356 .575 Mdot
.54804 .39024 Mdot
.36834 .34364 Mdot
.57094 .40163 Mdot
.69925 .59163 Mdot
.53712 .62936 Mdot
.40301 .56746 Mdot
.21783 .35533 Mdot
.53614 .6764 Mdot
.36697 .39845 Mdot
.15805 .63471 Mdot
.31125 .40724 Mdot
.37821 .44359 Mdot
.38944 .35664 Mdot
.38071 .56202 Mdot
.5814 .88321 Mdot
.69024 .24655 Mdot
.5286 .34354 Mdot
.40833 .59968 Mdot
.34393 .40351 Mdot
.61303 .38215 Mdot
.32436 .38423 Mdot
.37835 .45235 Mdot
.57412 .44323 Mdot
.60767 .38146 Mdot
.23447 .48067 Mdot
.17095 .59798 Mdot
.65099 .57562 Mdot
.3251 .39802 Mdot
.66522 .40297 Mdot
.61281 .38762 Mdot
.58589 .38931 Mdot
.48909 .7404 Mdot
.65825 .5395 Mdot
.27802 .46395 Mdot
.55768 .33886 Mdot
.65301 .76863 Mdot
.49827 .37667 Mdot
.37901 .3892 Mdot
.38577 .61296 Mdot
.72943 .68999 Mdot
.35326 .53435 Mdot
.34792 .44859 Mdot
.64092 .57653 Mdot
.30188 .39796 Mdot
.66553 .48693 Mdot
.36775 .56286 Mdot
.36912 .39496 Mdot
.5149 .50395 Mdot
.38658 .5889 Mdot
.36232 .5865 Mdot
.33985 .33784 Mdot
.57462 .61688 Mdot
.65266 .59207 Mdot
.37346 .60104 Mdot
.66392 .33859 Mdot
.4015 .59424 Mdot
.58821 .2283 Mdot
.55475 .42384 Mdot
.71198 .36866 Mdot
.48158 .57996 Mdot
.63603 .33573 Mdot
.36044 .57839 Mdot
.65279 .58326 Mdot
.54299 .35116 Mdot
.35919 .43629 Mdot
.68131 .55543 Mdot
.41449 .62732 Mdot
.51598 .63933 Mdot
.34281 .43115 Mdot
.37325 .62025 Mdot
.33206 .39454 Mdot
.68429 .3721 Mdot
.61477 .20583 Mdot
.49273 .79771 Mdot
.54115 .55224 Mdot
.57574 .33275 Mdot
.26383 .68121 Mdot
.60967 .43643 Mdot
.55361 .39927 Mdot
.55171 .65403 Mdot
.70251 .39072 Mdot
.3572 .40965 Mdot
.20909 .36315 Mdot
.39662 .56046 Mdot
.70482 .73942 Mdot
.3012 .43976 Mdot
.5976 .33305 Mdot
.32547 .42206 Mdot
.31032 .40538 Mdot
.36856 .30072 Mdot
.49465 .66499 Mdot
.63162 .37741 Mdot
.63368 .38286 Mdot
.54291 .44248 Mdot
.36445 .58339 Mdot
.60516 .75909 Mdot
.55554 .6767 Mdot
.60154 .18869 Mdot
.54338 .62935 Mdot
.57402 .5744 Mdot
.3511 .44466 Mdot
.67088 .54367 Mdot
.58788 .38971 Mdot
.33485 .46122 Mdot
.3493 .44991 Mdot
.70418 .5792 Mdot
.67703 .57563 Mdot
.50762 .73224 Mdot
.38019 .56528 Mdot
.57202 .32687 Mdot
.59135 .41753 Mdot
.54567 .3649 Mdot
.54143 .39712 Mdot
.41932 .57941 Mdot
.52863 .37175 Mdot
.40204 .55394 Mdot
.65392 .30252 Mdot
.66469 .75381 Mdot
.52931 .5199 Mdot
.31148 .46373 Mdot
.36219 .44058 Mdot
.66504 .37912 Mdot
.51243 .43665 Mdot
.82499 .51417 Mdot
.29389 .29348 Mdot
.52202 .3979 Mdot
.50775 .64131 Mdot
.55758 .27925 Mdot
.5699 .65137 Mdot
.55488 .12847 Mdot
.41094 .69113 Mdot
.16536 .57026 Mdot
.6037 .40153 Mdot
.49263 .74501 Mdot
.64999 .32679 Mdot
.62347 .41923 Mdot
.44849 .71473 Mdot
.32272 .55829 Mdot
.25431 .58816 Mdot
.63166 .56519 Mdot
.58372 .3582 Mdot
.32539 .44495 Mdot
.58613 .41512 Mdot
.58079 .3899 Mdot
.55777 .3369 Mdot
.35386 .59078 Mdot
.62856 .36847 Mdot
.53655 .39765 Mdot
.62033 .72977 Mdot
.74053 .48508 Mdot
.51872 .67957 Mdot
.55765 .20398 Mdot
.67403 .54701 Mdot
.32819 .41919 Mdot
.20387 .53159 Mdot
.37617 .57084 Mdot
.37161 .29167 Mdot
.53833 .39243 Mdot
.23624 .50722 Mdot
.39141 .62371 Mdot
.66601 .57487 Mdot
.53247 .6881 Mdot
.16024 .5276 Mdot
.54177 .66115 Mdot
.50667 .49748 Mdot
.53934 .64869 Mdot
.49319 .38983 Mdot
.32583 .41091 Mdot
.55515 .336 Mdot
.37442 .59958 Mdot
.55805 .64908 Mdot
.71889 .43482 Mdot
.56526 .38033 Mdot
.52897 .665 Mdot
.5541 .33669 Mdot
.69462 .31631 Mdot
.79956 .50755 Mdot
.57351 .62737 Mdot
.4009 .55039 Mdot
.38809 .59395 Mdot
.66049 .54033 Mdot
.33549 .42894 Mdot
.37851 .4264 Mdot
.38365 .58387 Mdot
.73176 .29907 Mdot
.55884 .42015 Mdot
.61143 .38791 Mdot
.71138 .71717 Mdot
.57629 .41329 Mdot
.7086 .49694 Mdot
.51228 .4984 Mdot
.35444 .44117 Mdot
.61314 .36153 Mdot
.55483 .343 Mdot
.57484 .35594 Mdot
.68324 .33978 Mdot
.55078 .63436 Mdot
.57877 .4282 Mdot
.67961 .57594 Mdot
.5196 .70119 Mdot
.61451 .37989 Mdot
.54541 .44495 Mdot
.37907 .42457 Mdot
.7546 .71127 Mdot
.40199 .57063 Mdot
.55212 .61549 Mdot
.52805 .67488 Mdot
.46669 .76796 Mdot
.42373 .39506 Mdot
.51817 .50294 Mdot
.57409 .17581 Mdot
.40512 .74422 Mdot
.66935 .5521 Mdot
.4619 .61732 Mdot
.47007 .44437 Mdot
.52368 .62183 Mdot
.42325 .58885 Mdot
.55382 .42505 Mdot
.55965 .42299 Mdot
.82936 .58492 Mdot
.59084 .32874 Mdot
.65494 .57216 Mdot
.39945 .55478 Mdot
.36071 .43276 Mdot
.66432 .5757 Mdot
.41058 .58073 Mdot
.33946 .41731 Mdot
.53361 .41499 Mdot
.54265 .42342 Mdot
.37745 .41294 Mdot
.37885 .40052 Mdot
.59437 .39411 Mdot
.58715 .59549 Mdot
.38954 .4166 Mdot
.34548 .38846 Mdot
.57123 .64297 Mdot
.56493 .64964 Mdot
.58373 .44727 Mdot
.40949 .59441 Mdot
.53182 .39124 Mdot
.54123 .66588 Mdot
.63919 .55322 Mdot
.36042 .41514 Mdot
.5636 .3417 Mdot
.58611 .34293 Mdot
.65357 .55946 Mdot
.63362 .56732 Mdot
.67268 .5758 Mdot
.3726 .55257 Mdot
.55192 .36584 Mdot
.35692 .40105 Mdot
.38703 .56357 Mdot
.63365 .58452 Mdot
.67185 .53885 Mdot
.55458 .60034 Mdot
.56385 .41296 Mdot
.49925 .69682 Mdot
.48923 .90345 Mdot
.73227 .57147 Mdot
.49762 .66653 Mdot
.53235 .60512 Mdot
.72189 .46436 Mdot
.5369 .57586 Mdot
.38564 .5772 Mdot
.68472 .60692 Mdot
.61315 .58202 Mdot
.52163 .37428 Mdot
.56587 .43661 Mdot
.63569 .38615 Mdot
.67676 .56951 Mdot
.68221 .42088 Mdot
.32412 .38669 Mdot
.41461 .21649 Mdot
.67713 .54987 Mdot
.53077 .61048 Mdot
.57355 .61386 Mdot
.54223 .629 Mdot
.55047 .42556 Mdot
.39327 .30826 Mdot
.60654 .47884 Mdot
.2652 .69048 Mdot
.35897 .58765 Mdot
.29982 .39297 Mdot
.35939 .22117 Mdot
.37503 .4082 Mdot
.57595 .6508 Mdot
.68001 .55921 Mdot
.36581 .39222 Mdot
.41197 .60727 Mdot
.38126 .60369 Mdot
.5496 .63098 Mdot
.53144 .64109 Mdot
.5344 .62174 Mdot
.37754 .44843 Mdot
.3489 .44457 Mdot
.5644 .36379 Mdot
.36469 .4239 Mdot
.80929 .63635 Mdot
.65955 .59558 Mdot
.53206 .60418 Mdot
.40312 .5848 Mdot
.33054 .40684 Mdot
.56146 .38017 Mdot
.59563 .53511 Mdot
.31358 .5534 Mdot
.68455 .57757 Mdot
.79158 .5402 Mdot
.55196 .13058 Mdot
.5772 .32563 Mdot
.36647 .58391 Mdot
.78807 .62909 Mdot
.57199 .37905 Mdot
.52453 .63735 Mdot
.37334 .75316 Mdot
.51391 .69348 Mdot
.53055 .39497 Mdot
.55808 .32585 Mdot
.37356 .6126 Mdot
.54979 .18032 Mdot
.56136 .36797 Mdot
.29132 .48254 Mdot
.34638 .59811 Mdot
.56145 .6718 Mdot
.195 .3621 Mdot
.49665 .77929 Mdot
.73749 .39009 Mdot
.5712 .6404 Mdot
.56073 .40243 Mdot
.56822 .64092 Mdot
.67763 .58161 Mdot
.56209 .6239 Mdot
.35235 .37629 Mdot
.52483 .68281 Mdot
.5951 .3526 Mdot
.34723 .39836 Mdot
.39174 .57937 Mdot
.7196 .7296 Mdot
.67168 .69966 Mdot
.5406 .64412 Mdot
.56337 .61701 Mdot
.5979 .34114 Mdot
.25827 .45813 Mdot
.50851 .37915 Mdot
.6077 .39665 Mdot
.39698 .55833 Mdot
.32815 .42645 Mdot
.35616 .6018 Mdot
.62084 .36423 Mdot
.43357 .79082 Mdot
.3986 .57231 Mdot
.23088 .50324 Mdot
.66907 .55484 Mdot
.42704 .49264 Mdot
.55542 .38601 Mdot
.38148 .60864 Mdot
.55126 .36709 Mdot
.32749 .38272 Mdot
.46652 .49363 Mdot
.32877 .65984 Mdot
.37497 .59709 Mdot
.21163 .4022 Mdot
.5674 .58777 Mdot
.55288 .31224 Mdot
.41819 .59058 Mdot
.65273 .47123 Mdot
.53459 .61204 Mdot
.66384 .54688 Mdot
.63256 .57898 Mdot
.68957 .56891 Mdot
.51387 .40148 Mdot
.5304 .32151 Mdot
.65012 .58859 Mdot
.40686 .61176 Mdot
.63638 .54773 Mdot
.32534 .35565 Mdot
.19747 .42001 Mdot
.64367 .55706 Mdot
.58145 .36648 Mdot
.55345 .29761 Mdot
.73899 .47681 Mdot
.52639 .71961 Mdot
.17091 .56159 Mdot
.29095 .4507 Mdot
.57693 .40437 Mdot
.33328 .36516 Mdot
.33548 .38419 Mdot
.77692 .6364 Mdot
.71103 .51401 Mdot
.71216 .69668 Mdot
.38091 .4346 Mdot
.34689 .68132 Mdot
.34495 .43704 Mdot
.58864 .33017 Mdot
.61151 .38237 Mdot
.34663 .45341 Mdot
.62483 .76203 Mdot
.42255 .67661 Mdot
.24729 .30798 Mdot
.33878 .38858 Mdot
.41253 .60248 Mdot
.40716 .56186 Mdot
.36167 .58167 Mdot
.75921 .61323 Mdot
.31655 .42137 Mdot
.55578 .35861 Mdot
.53952 .67004 Mdot
.57262 .42669 Mdot
.37852 .58851 Mdot
.20815 .36612 Mdot
.37253 .4315 Mdot
.59915 .38538 Mdot
.73234 .31667 Mdot
.52147 .64567 Mdot
.657 .55437 Mdot
.67876 .28952 Mdot
.73414 .64744 Mdot
.37234 .5629 Mdot
.31401 .42438 Mdot
.37867 .70786 Mdot
.22339 .49678 Mdot
.54037 .43166 Mdot
.60101 .44738 Mdot
.38762 .18198 Mdot
.73264 .64083 Mdot
.54006 .34251 Mdot
.54227 .6129 Mdot
.35612 .69378 Mdot
.57489 .3446 Mdot
.3288 .3896 Mdot
.62863 .5624 Mdot
.68654 .5676 Mdot
.61546 .41711 Mdot
.54216 .56097 Mdot
.43376 .46456 Mdot
.53434 .36897 Mdot
.5079 .4281 Mdot
.57101 .65717 Mdot
.40825 .7442 Mdot
.70347 .7267 Mdot
.63935 .57596 Mdot
.5494 .34072 Mdot
.2518 .62207 Mdot
.36575 .45285 Mdot
.50655 .67768 Mdot
.36316 .56569 Mdot
.67112 .30554 Mdot
.5607 .67314 Mdot
.57407 .34352 Mdot
.547 .34537 Mdot
.3617 .59901 Mdot
.37864 .38886 Mdot
.6779 .56725 Mdot
.53714 .67262 Mdot
.64015 .57859 Mdot
.32123 .42434 Mdot
.36828 .43248 Mdot
.48515 .37981 Mdot
.59052 .31064 Mdot
.55073 .64161 Mdot
.61997 .37755 Mdot
.57297 .72442 Mdot
.54147 .17427 Mdot
.42679 .61299 Mdot
.57632 .32507 Mdot
.39921 .4079 Mdot
.37223 .59453 Mdot
.60742 .37093 Mdot
.34698 .20727 Mdot
.61385 .39074 Mdot
.34112 .54268 Mdot
.48302 .80492 Mdot
.65865 .58182 Mdot
.38985 .22401 Mdot
.25296 .40167 Mdot
.58115 .41198 Mdot
.50787 .65999 Mdot
.56437 .46039 Mdot
.38421 .57149 Mdot
.35836 .44494 Mdot
.61709 .17934 Mdot
.39796 .59628 Mdot
.59557 .4089 Mdot
.66481 .57375 Mdot
.31051 .41418 Mdot
.59505 .5895 Mdot
.68811 .72005 Mdot
.51761 .34515 Mdot
.61289 .41391 Mdot
.53176 .38545 Mdot
.37132 .77242 Mdot
.55152 .61589 Mdot
.33708 .40362 Mdot
.3657 .58187 Mdot
.38182 .58205 Mdot
.54661 .63253 Mdot
.26081 .57574 Mdot
.42948 .49117 Mdot
.50287 .88808 Mdot
.56014 .64082 Mdot
.68918 .58365 Mdot
.27336 .4673 Mdot
.50713 .66297 Mdot
.52675 .66205 Mdot
.56978 .6584 Mdot
.36163 .53873 Mdot
.34277 .41825 Mdot
.58471 .34143 Mdot
.34111 .37995 Mdot
.55808 .40477 Mdot
.44817 .4274 Mdot
.37118 .59715 Mdot
.3645 .44611 Mdot
.35722 .20374 Mdot
.51575 .29248 Mdot
.57784 .37478 Mdot
.37854 .20668 Mdot
.54941 .3216 Mdot
.70012 .4682 Mdot
.58743 .31599 Mdot
.5352 .64446 Mdot
.65453 .37441 Mdot
.51675 .42355 Mdot
.75521 .69625 Mdot
.40456 .58469 Mdot
.5236 .61671 Mdot
.52566 .3541 Mdot
.49655 .39347 Mdot
.35288 .45738 Mdot
.35871 .3902 Mdot
.64504 .58651 Mdot
.77969 .48188 Mdot
.39319 .57816 Mdot
.64308 .23341 Mdot
.58224 .40455 Mdot
.55379 .79037 Mdot
.378 .23926 Mdot
.60674 .3722 Mdot
.25177 .37468 Mdot
.38471 .30155 Mdot
.55024 .38929 Mdot
.61754 .49032 Mdot
.39171 .60585 Mdot
.44492 .79568 Mdot
.61042 .41199 Mdot
.52008 .64108 Mdot
.34145 .43959 Mdot
.32115 .39217 Mdot
.65457 .58832 Mdot
.83732 .47135 Mdot
.35651 .5999 Mdot
.36064 .44635 Mdot
.56672 .38413 Mdot
.37652 .56242 Mdot
.55597 .66193 Mdot
.60931 .33844 Mdot
.72163 .51992 Mdot
.36255 .42624 Mdot
.61659 .40186 Mdot
.29657 .51171 Mdot
.75357 .43798 Mdot
.28325 .74841 Mdot
.36575 .57656 Mdot
.64641 .54394 Mdot
.57297 .45952 Mdot
.67793 .26826 Mdot
.52115 .401 Mdot
.70865 .36779 Mdot
.38465 .3659 Mdot
.64584 .54361 Mdot
.58652 .378 Mdot
.56795 .35156 Mdot
.48958 .5764 Mdot
.63525 .5664 Mdot
.59354 .41766 Mdot
.60889 .28263 Mdot
.3398 .41426 Mdot
.54864 .68353 Mdot
.3568 .42668 Mdot
.57575 .36778 Mdot
.60439 .31634 Mdot
.3833 .41448 Mdot
.51413 .14981 Mdot
.62245 .57744 Mdot
.39722 .56871 Mdot
.56675 .30858 Mdot
.56684 .433 Mdot
.48781 .84152 Mdot
.50282 .64062 Mdot
.29956 .68975 Mdot
.60888 .7089 Mdot
.24152 .62806 Mdot
.49995 .77802 Mdot
.15653 .60864 Mdot
.68388 .7433 Mdot
.63245 .38945 Mdot
.38085 .48468 Mdot
.60053 .48601 Mdot
.35938 .57738 Mdot
.53461 .23359 Mdot
.57725 .40577 Mdot
.57843 .38968 Mdot
.50367 .67581 Mdot
.24009 .54566 Mdot
.70711 .70685 Mdot
.56887 .56112 Mdot
.67683 .56522 Mdot
.32528 .40155 Mdot
.60777 .35716 Mdot
.57599 .51502 Mdot
.51504 .67866 Mdot
.56442 .78703 Mdot
.59651 .38191 Mdot
.82153 .51448 Mdot
.31855 .59348 Mdot
.37497 .56553 Mdot
.5195 .67468 Mdot
.72867 .66476 Mdot
.5601 .41293 Mdot
.3678 .55976 Mdot
.56019 .37261 Mdot
.49614 .60935 Mdot
.61898 .36454 Mdot
.64922 .54967 Mdot
.56683 .33395 Mdot
.5796 .56639 Mdot
.21544 .69356 Mdot
.67454 .60502 Mdot
.3167 .4038 Mdot
.49643 .6387 Mdot
.55049 .63592 Mdot
.37247 .39593 Mdot
.54842 .63821 Mdot
.37841 .26558 Mdot
.46414 .28006 Mdot
.6763 .5597 Mdot
.50183 .41332 Mdot
.64243 .56343 Mdot
.50002 .64741 Mdot
.56841 .40729 Mdot
.54254 .15926 Mdot
.55426 .64679 Mdot
.50004 .82043 Mdot
.4009 .59042 Mdot
.51119 .62702 Mdot
.61365 .40291 Mdot
.38687 .70742 Mdot
.52974 .67885 Mdot
.33202 .65972 Mdot
.5734 .35682 Mdot
.36495 .43541 Mdot
.56808 .34825 Mdot
.55822 .31356 Mdot
.58593 .64489 Mdot
.54003 .40343 Mdot
.41063 .58094 Mdot
.38932 .42788 Mdot
.17183 .46845 Mdot
.32535 .5613 Mdot
.58258 .41991 Mdot
.56849 .38267 Mdot
.31417 .43128 Mdot
.57975 .42992 Mdot
.419 .57896 Mdot
.80784 .71876 Mdot
.66841 .55451 Mdot
.56352 .6147 Mdot
.49118 .78232 Mdot
.52429 .40149 Mdot
.53335 .36219 Mdot
.32079 .22854 Mdot
.48589 .78993 Mdot
.41637 .5869 Mdot
.50947 .40966 Mdot
.54637 .67029 Mdot
.66271 .573 Mdot
.40501 .6135 Mdot
.53598 .38479 Mdot
.58774 .38635 Mdot
.64795 .54387 Mdot
.312 .34221 Mdot
.754 .64251 Mdot
.35879 .59396 Mdot
.65427 .35791 Mdot
.59245 .69512 Mdot
.55595 .41666 Mdot
.76786 .60678 Mdot
.36227 .3926 Mdot
.38002 .5584 Mdot
.29305 .70408 Mdot
.53247 .35193 Mdot
.38838 .61234 Mdot
.3957 .57875 Mdot
.51263 .41486 Mdot
.40505 .43225 Mdot
.38724 .44132 Mdot
.3309 .39567 Mdot
.82471 .62708 Mdot
.74118 .4254 Mdot
.5342 .62188 Mdot
.3901 .60627 Mdot
.57732 .63441 Mdot
.69449 .58154 Mdot
.50863 .48718 Mdot
.56998 .62261 Mdot
.36636 .38988 Mdot
.49127 .65581 Mdot
.57164 .35203 Mdot
.38933 .57868 Mdot
.52667 .62089 Mdot
.52049 .36166 Mdot
.24411 .45332 Mdot
.5008 .7095 Mdot
.65888 .53757 Mdot
.62837 .56912 Mdot
.61236 .37622 Mdot
.50172 .68326 Mdot
.59266 .39399 Mdot
.43118 .59055 Mdot
.263 .46671 Mdot
.51738 .38936 Mdot
.54117 .64182 Mdot
.32801 .36404 Mdot
.73358 .64774 Mdot
.51946 .35143 Mdot
.58191 .3677 Mdot
.55379 .40801 Mdot
.5594 .37285 Mdot
.23836 .56929 Mdot
.40297 .62012 Mdot
.34564 .49218 Mdot
.41272 .7649 Mdot
.37209 .42006 Mdot
.39747 .4349 Mdot
.73907 .6073 Mdot
.43824 .64878 Mdot
.40858 .59736 Mdot
.55027 .40002 Mdot
.31577 .62628 Mdot
.20422 .37389 Mdot
.47696 .1404 Mdot
.71289 .55437 Mdot
.50064 .65658 Mdot
.31856 .43109 Mdot
.51362 .6753 Mdot
.56388 .40256 Mdot
.58293 .45973 Mdot
.15362 .61009 Mdot
.3442 .57392 Mdot
.68026 .56225 Mdot
.55446 .40581 Mdot
.7432 .41718 Mdot
.53548 .66928 Mdot
.58062 .62536 Mdot
.60036 .41306 Mdot
.3919 .4024 Mdot
.39266 .81439 Mdot
.37037 .56826 Mdot
.29059 .45301 Mdot
.66117 .35903 Mdot
.33128 .50119 Mdot
.37297 .58778 Mdot
.69145 .7036 Mdot
.49978 .67324 Mdot
.33204 .29193 Mdot
.37381 .4218 Mdot
.67936 .55432 Mdot
.58994 .45128 Mdot
.37919 .43061 Mdot
.55108 .68015 Mdot
.36369 .44192 Mdot
.56528 .33263 Mdot
.36739 .6158 Mdot
.51677 .66957 Mdot
.37969 .5449 Mdot
.40352 .43299 Mdot
.64546 .57914 Mdot
.47332 .55224 Mdot
.53047 .25841 Mdot
.38157 .29874 Mdot
.57079 .4283 Mdot
.57348 .51241 Mdot
.55209 .36075 Mdot
.37363 .46235 Mdot
.56115 .37767 Mdot
.30669 .36851 Mdot
.50976 .66563 Mdot
.60822 .4135 Mdot
.53203 .37635 Mdot
.52751 .21915 Mdot
.59557 .37343 Mdot
.62545 .3683 Mdot
.54855 .39304 Mdot
.29811 .42629 Mdot
.50742 .42021 Mdot
.34532 .42511 Mdot
.65883 .72924 Mdot
.52593 .65956 Mdot
.62964 .57002 Mdot
.68392 .55227 Mdot
.71596 .37373 Mdot
.62906 .61348 Mdot
.25052 .56648 Mdot
.35287 .41913 Mdot
.40358 .57781 Mdot
.55795 .3772 Mdot
.23253 .6672 Mdot
.47874 .7519 Mdot
.55471 .66757 Mdot
.32504 .56186 Mdot
.6468 .39345 Mdot
.37786 .77986 Mdot
.61912 .39082 Mdot
.83721 .56622 Mdot
.60703 .31259 Mdot
.61614 .35738 Mdot
.58114 .63629 Mdot
.62768 .58878 Mdot
.59559 .4215 Mdot
.35104 .45686 Mdot
.65722 .5445 Mdot
.38784 .47544 Mdot
.57024 .69526 Mdot
.66675 .71732 Mdot
.49651 .24245 Mdot
.55354 .36883 Mdot
.51538 .66756 Mdot
.34138 .42985 Mdot
.70128 .73069 Mdot
.38961 .56373 Mdot
.44689 .62572 Mdot
.66418 .39812 Mdot
.43912 .17014 Mdot
.67111 .54612 Mdot
.33049 .33857 Mdot
.59483 .35119 Mdot
.7187 .62659 Mdot
.55254 .43421 Mdot
.2068 .37384 Mdot
.69209 .58023 Mdot
.39646 .42035 Mdot
.41337 .60035 Mdot
.33882 .38173 Mdot
.38396 .31144 Mdot
.4614 .58309 Mdot
.492 .52722 Mdot
.53814 .66272 Mdot
.40238 .51357 Mdot
.34174 .39949 Mdot
.54211 .34717 Mdot
.49499 .89148 Mdot
.35117 .38943 Mdot
.3326 .44017 Mdot
.57929 .19254 Mdot
.54061 .17063 Mdot
.64907 .39363 Mdot
.38509 .42229 Mdot
.53545 .66049 Mdot
.64807 .57653 Mdot
.55943 .34836 Mdot
.56341 .36087 Mdot
.38019 .42482 Mdot
.58128 .62962 Mdot
.46285 .37184 Mdot
.53152 .64264 Mdot
.33735 .41462 Mdot
.52058 .65379 Mdot
.37767 .72301 Mdot
.51744 .62524 Mdot
.56851 .43295 Mdot
.56015 .37763 Mdot
.59334 .7145 Mdot
.36793 .43252 Mdot
.5364 .36525 Mdot
.58225 .33681 Mdot
.35416 .40104 Mdot
.62304 .52851 Mdot
.44816 .38019 Mdot
.57266 .41833 Mdot
.58651 .35659 Mdot
.64269 .5462 Mdot
.5276 .4939 Mdot
.80271 .42953 Mdot
.54299 .35132 Mdot
.65653 .59408 Mdot
.37549 .44835 Mdot
.59731 .39133 Mdot
.2012 .47222 Mdot
.35448 .69261 Mdot
.53779 .34708 Mdot
.53017 .61403 Mdot
.52777 .43408 Mdot
.31887 .77074 Mdot
.60761 .39863 Mdot
.34956 .40438 Mdot
.32859 .43226 Mdot
.62837 .23233 Mdot
.36108 .39542 Mdot
.56553 .65096 Mdot
.38334 .5888 Mdot
.21174 .38309 Mdot
.55514 .6626 Mdot
.51646 .36395 Mdot
.6881 .24367 Mdot
.61744 .34417 Mdot
.51691 .3735 Mdot
.42582 .81128 Mdot
.55159 .66401 Mdot
.32343 .41618 Mdot
.51436 .574 Mdot
.63213 .35949 Mdot
.37212 .5625 Mdot
.55378 .45519 Mdot
.54523 .41692 Mdot
.4892 .80463 Mdot
.30995 .65922 Mdot
.41717 .56845 Mdot
.62719 .42111 Mdot
.54153 .35276 Mdot
.49519 .6922 Mdot
.56204 .38273 Mdot
.64007 .57042 Mdot
.31828 .42003 Mdot
.50616 .65089 Mdot
.65629 .56019 Mdot
.57903 .40927 Mdot
.67589 .57102 Mdot
.52173 .62839 Mdot
.37326 .55833 Mdot
.5628 .40754 Mdot
.69394 .55426 Mdot
.67574 .56741 Mdot
.54843 .36041 Mdot
.35464 .4445 Mdot
.62101 .31798 Mdot
.60146 .38722 Mdot
.56487 .33947 Mdot
.37785 .4273 Mdot
.42584 .13209 Mdot
.61133 .39367 Mdot
.57331 .58973 Mdot
.34184 .44618 Mdot
.41773 .53383 Mdot
.50451 .65225 Mdot
.54808 .41999 Mdot
.38638 .55517 Mdot
.37479 .60503 Mdot
.57335 .64847 Mdot
.30807 .40972 Mdot
.6039 .71105 Mdot
.3212 .36482 Mdot
.61365 .32768 Mdot
.59303 .32416 Mdot
.72344 .2791 Mdot
.15988 .56522 Mdot
.32396 .39194 Mdot
.584 .62166 Mdot
.56497 .55682 Mdot
.39637 .6073 Mdot
.54721 .60439 Mdot
.31198 .42217 Mdot
.31458 .42017 Mdot
.35714 .4399 Mdot
.68472 .56178 Mdot
.60215 .69625 Mdot
.37541 .38573 Mdot
.39261 .40522 Mdot
.57337 .35483 Mdot
.53833 .35677 Mdot
.67111 .50598 Mdot
.74678 .5245 Mdot
.64691 .58316 Mdot
.54091 .63118 Mdot
.76277 .74446 Mdot
.4301 .58961 Mdot
.51588 .21596 Mdot
.51776 .38905 Mdot
.45368 .91859 Mdot
.61664 .39279 Mdot
.56362 .38538 Mdot
.38816 .42808 Mdot
.68104 .54208 Mdot
.64831 .55599 Mdot
.33575 .39986 Mdot
.37772 .46026 Mdot
.63964 .56876 Mdot
.26922 .32634 Mdot
.19031 .42593 Mdot
.47734 .58609 Mdot
.36063 .40749 Mdot
.51339 .26582 Mdot
.36043 .56767 Mdot
.39239 .38809 Mdot
.42783 .60319 Mdot
.52967 .66769 Mdot
.50453 .68528 Mdot
.36385 .58359 Mdot
.57204 .35871 Mdot
.54232 .61821 Mdot
.62837 .3688 Mdot
.27096 .346 Mdot
.43126 .35148 Mdot
.52851 .76221 Mdot
.58939 .44136 Mdot
.67767 .71824 Mdot
.44646 .65586 Mdot
.59117 .40776 Mdot
.21214 .57886 Mdot
.68007 .56498 Mdot
.3874 .38815 Mdot
.4138 .56898 Mdot
.30152 .76822 Mdot
.55245 .41121 Mdot
.35295 .4079 Mdot
.40726 .58553 Mdot
.68435 .32509 Mdot
.28598 .4804 Mdot
.55611 .40667 Mdot
.52454 .88816 Mdot
.31312 .44711 Mdot
.50748 .64693 Mdot
.77578 .34539 Mdot
.3359 .37944 Mdot
.69106 .53359 Mdot
.41476 .75695 Mdot
.37624 .19829 Mdot
.32819 .4184 Mdot
.55398 .60224 Mdot
.32814 .39997 Mdot
.64247 .57734 Mdot
.32365 .37342 Mdot
.52823 .67338 Mdot
.59233 .37642 Mdot
.54121 .63644 Mdot
.65344 .58655 Mdot
.75204 .61413 Mdot
.40976 .56411 Mdot
.52369 .61684 Mdot
.38357 .59897 Mdot
.76228 .45051 Mdot
.40683 .77411 Mdot
.40248 .56775 Mdot
.66178 .26781 Mdot
.53228 .34975 Mdot
.36029 .38181 Mdot
.55874 .63261 Mdot
.41282 .74882 Mdot
.50073 .55969 Mdot
.37259 .41314 Mdot
.52933 .63063 Mdot
.64298 .44931 Mdot
.71127 .29076 Mdot
.5044 .35833 Mdot
.7707 .47481 Mdot
.35965 .4036 Mdot
.545 .60282 Mdot
.71228 .71705 Mdot
.35801 .38666 Mdot
.56089 .63929 Mdot
.40608 .60761 Mdot
.37748 .58338 Mdot
.59085 .42208 Mdot
.4105 .5507 Mdot
.54148 .62517 Mdot
.46458 .66711 Mdot
.36707 .45347 Mdot
.68825 .34864 Mdot
.69286 .5607 Mdot
.52912 .65305 Mdot
.59406 .3293 Mdot
.40811 .41011 Mdot
.36637 .70945 Mdot
.48475 .33355 Mdot
.72156 .76329 Mdot
.54573 .63281 Mdot
.32101 .42819 Mdot
.35639 .41209 Mdot
.51895 .35317 Mdot
.54015 .55414 Mdot
.60446 .70627 Mdot
.71993 .32127 Mdot
.70299 .36112 Mdot
.5616 .6746 Mdot
.55852 .68135 Mdot
.53529 .33944 Mdot
.54879 .3744 Mdot
.40248 .60635 Mdot
.58985 .37126 Mdot
.39255 .42491 Mdot
.58738 .42588 Mdot
.36953 .58914 Mdot
.54543 .65805 Mdot
.56891 .40461 Mdot
.65383 .58258 Mdot
.38865 .55246 Mdot
.37264 .61276 Mdot
.53494 .64882 Mdot
.37799 .43468 Mdot
.66615 .60198 Mdot
.53143 .64061 Mdot
.55448 .36863 Mdot
.38862 .6476 Mdot
.57803 .33233 Mdot
.2916 .31151 Mdot
.36462 .38844 Mdot
.51031 .67139 Mdot
.36355 .45539 Mdot
.38886 .60181 Mdot
.41133 .76312 Mdot
.57104 .37148 Mdot
.56088 .64317 Mdot
.5858 .71653 Mdot
.2841 .33403 Mdot
.32459 .4437 Mdot
.36832 .66109 Mdot
.3906 .44544 Mdot
.52957 .68763 Mdot
.58055 .21095 Mdot
.66949 .54788 Mdot
.55154 .66965 Mdot
.1684 .51884 Mdot
.54794 .64418 Mdot
.59898 .37133 Mdot
.60969 .36865 Mdot
.50819 .64199 Mdot
.66464 .54022 Mdot
.6863 .74762 Mdot
.47287 .63355 Mdot
.32523 .41814 Mdot
.42034 .19128 Mdot
.63984 .81511 Mdot
.43858 .57616 Mdot
.41191 .59958 Mdot
.6333 .36152 Mdot
.61217 .34807 Mdot
.42516 .60411 Mdot
.34768 .59316 Mdot
.6833 .58145 Mdot
.5688 .65927 Mdot
.28886 .39985 Mdot
.36084 .56204 Mdot
.49023 .35859 Mdot
.64403 .61909 Mdot
.50828 .37057 Mdot
.65639 .39879 Mdot
.56086 .43599 Mdot
.70599 .34961 Mdot
.36665 .58615 Mdot
.60902 .35597 Mdot
.50385 .3806 Mdot
.38569 .55601 Mdot
.64144 .57346 Mdot
.30277 .6288 Mdot
.51564 .65461 Mdot
.22541 .29862 Mdot
.60732 .34709 Mdot
.60159 .37485 Mdot
.35916 .58618 Mdot
.61791 .71253 Mdot
.37206 .43621 Mdot
.35893 .38571 Mdot
.54809 .61545 Mdot
.47516 .54755 Mdot
.5563 .42245 Mdot
.59944 .40069 Mdot
.51171 .65418 Mdot
.51347 .62468 Mdot
.4774 .70726 Mdot
.58725 .34489 Mdot
.40677 .58917 Mdot
.58477 .56143 Mdot
.36715 .58792 Mdot
.58623 .33007 Mdot
.60096 .36837 Mdot
.56951 .43277 Mdot
.59003 .32853 Mdot
.37775 .61528 Mdot
.60567 .35227 Mdot
.52799 .31544 Mdot
.36971 .44327 Mdot
.54182 .40213 Mdot
.70113 .34499 Mdot
.58408 .36324 Mdot
.64561 .57534 Mdot
.49755 .33221 Mdot
.55491 .41112 Mdot
.55336 .42368 Mdot
.47712 .62622 Mdot
.58277 .37965 Mdot
.43105 .59185 Mdot
.36784 .42102 Mdot
.38842 .60626 Mdot
.36149 .5958 Mdot
.57031 .63414 Mdot
.65246 .58875 Mdot
.5261 .40354 Mdot
.68537 .57448 Mdot
.53407 .42306 Mdot
.53714 .3463 Mdot
.45011 .76857 Mdot
.84121 .55211 Mdot
.75889 .63697 Mdot
.5702 .37043 Mdot
.55664 .65448 Mdot
.50455 .66043 Mdot
.33686 .47676 Mdot
.50596 .35783 Mdot
.42215 .60639 Mdot
.37973 .60771 Mdot
.72312 .51489 Mdot
.48016 .80087 Mdot
.64428 .57489 Mdot
.55065 .51 Mdot
.62795 .36335 Mdot
.5768 .33823 Mdot
.61269 .34225 Mdot
.57615 .63183 Mdot
.56735 .56908 Mdot
.55252 .6683 Mdot
.31731 .57745 Mdot
.36779 .59334 Mdot
.54921 .4097 Mdot
.35502 .35188 Mdot
.35854 .38934 Mdot
.36775 .42182 Mdot
.39102 .61456 Mdot
.50706 .62083 Mdot
.71243 .53576 Mdot
.52121 .13469 Mdot
.29511 .42582 Mdot
.66912 .53734 Mdot
.58781 .41202 Mdot
.54368 .65398 Mdot
.33099 .39213 Mdot
.6337 .55032 Mdot
.54808 .34063 Mdot
.60065 .69925 Mdot
.56773 .36773 Mdot
.59805 .48645 Mdot
.34464 .43858 Mdot
.19973 .39373 Mdot
.31214 .40298 Mdot
.39382 .55388 Mdot
.40291 .56372 Mdot
.6066 .36787 Mdot
.74098 .30158 Mdot
.35326 .38113 Mdot
.38292 .53396 Mdot
.69068 .58038 Mdot
.37501 .69914 Mdot
.63763 .57105 Mdot
.50688 .65751 Mdot
.66217 .54428 Mdot
.52053 .67378 Mdot
.7407 .54867 Mdot
.30449 .42586 Mdot
.66322 .55641 Mdot
.52516 .59833 Mdot
.51034 .34924 Mdot
.6312 .56919 Mdot
.63658 .38972 Mdot
.35144 .25254 Mdot
.51382 .64761 Mdot
.68312 .55304 Mdot
.54341 .34652 Mdot
.20827 .6573 Mdot
.41248 .58081 Mdot
.42567 .60079 Mdot
.61147 .32677 Mdot
.57673 .64657 Mdot
.33965 .45015 Mdot
.21521 .50974 Mdot
.43406 .61924 Mdot
.61057 .38208 Mdot
.59383 .42265 Mdot
.39926 .42664 Mdot
.42519 .43112 Mdot
.60289 .36441 Mdot
.62254 .26569 Mdot
.59591 .34755 Mdot
.40793 .60829 Mdot
.33165 .38532 Mdot
.3616 .4163 Mdot
.53031 .62752 Mdot
.38769 .41185 Mdot
.27858 .38615 Mdot
.34597 .63957 Mdot
.6358 .36264 Mdot
.39536 .59718 Mdot
.33055 .61485 Mdot
.31794 .57507 Mdot
.17367 .56519 Mdot
.4008 .4292 Mdot
.57739 .43629 Mdot
.36382 .45348 Mdot
.66039 .57527 Mdot
.36455 .43192 Mdot
.32301 .43552 Mdot
.59344 .39849 Mdot
.56079 .40206 Mdot
.54764 .66314 Mdot
.54485 .55655 Mdot
.3719 .44604 Mdot
.61212 .37038 Mdot
.62427 .3681 Mdot
.62516 .36406 Mdot
.45178 .46479 Mdot
.3248 .39241 Mdot
.50311 .20311 Mdot
.67485 .44695 Mdot
.37282 .44527 Mdot
.34596 .79661 Mdot
.40521 .74617 Mdot
.50082 .63927 Mdot
.40948 .55428 Mdot
.58598 .34425 Mdot
.50229 .65827 Mdot
.56415 .40286 Mdot
.65686 .39707 Mdot
.58457 .38787 Mdot
.63822 .56279 Mdot
.63233 .38998 Mdot
.51693 .68972 Mdot
.53527 .63881 Mdot
.60951 .39186 Mdot
.5729 .40166 Mdot
.74969 .62601 Mdot
.38252 .4577 Mdot
.36907 .43771 Mdot
.60266 .7248 Mdot
.66723 .5626 Mdot
.37546 .56039 Mdot
.55373 .38586 Mdot
.56736 .62965 Mdot
.5383 .63658 Mdot
.33264 .38156 Mdot
.52307 .63901 Mdot
.36853 .57142 Mdot
.5695 .37435 Mdot
.42644 .6012 Mdot
.68626 .56506 Mdot
.32486 .3989 Mdot
.55011 .40623 Mdot
.5739 .35464 Mdot
.3282 .43178 Mdot
.52145 .38646 Mdot
.64189 .54728 Mdot
.54792 .64182 Mdot
.33187 .42095 Mdot
.38189 .58751 Mdot
.51012 .66776 Mdot
.56565 .34376 Mdot
.74698 .75188 Mdot
.59602 .36637 Mdot
.57786 .34457 Mdot
.16045 .51178 Mdot
.63313 .38942 Mdot
.55397 .63161 Mdot
.39575 .41237 Mdot
.61847 .40745 Mdot
.71988 .3894 Mdot
.45447 .1364 Mdot
.55839 .66453 Mdot
.58832 .41441 Mdot
.16808 .60802 Mdot
.59879 .40732 Mdot
.65914 .24955 Mdot
.69463 .61839 Mdot
.42424 .51684 Mdot
.59367 .3084 Mdot
.37534 .57192 Mdot
.54951 .66245 Mdot
.50882 .66121 Mdot
.47053 .18902 Mdot
.59604 .39929 Mdot
.5945 .49265 Mdot
.52708 .37083 Mdot
.3738 .58588 Mdot
.69652 .49856 Mdot
.54217 .63328 Mdot
.77195 .66112 Mdot
.55534 .35991 Mdot
.32051 .39564 Mdot
.49251 .64878 Mdot
.39234 .73062 Mdot
.56304 .34138 Mdot
.68234 .57583 Mdot
.37811 .54896 Mdot
.62729 .39665 Mdot
.39435 .59294 Mdot
.56848 .33603 Mdot
.48365 .39189 Mdot
.80788 .38996 Mdot
.35545 .44277 Mdot
.41019 .60377 Mdot
.40817 .64884 Mdot
.57482 .44359 Mdot
.33001 .42038 Mdot
.37397 .42054 Mdot
.68049 .58193 Mdot
.50375 .5197 Mdot
.28561 .51579 Mdot
.47518 .32673 Mdot
.46299 .18502 Mdot
.4957 .6391 Mdot
.4051 .67164 Mdot
.55371 .34759 Mdot
.55099 .78533 Mdot
.42505 .57681 Mdot
.59885 .37603 Mdot
.35529 .26372 Mdot
.33457 .3938 Mdot
.58974 .35452 Mdot
.64175 .56517 Mdot
.58793 .76589 Mdot
.57737 .77881 Mdot
.33738 .74894 Mdot
.53579 .66428 Mdot
.57899 .45911 Mdot
.59927 .46353 Mdot
.55695 .61383 Mdot
.52722 .39547 Mdot
.55607 .63658 Mdot
.31841 .25784 Mdot
.64234 .54392 Mdot
.32173 .39968 Mdot
.40177 .74176 Mdot
.53923 .41653 Mdot
.60796 .32929 Mdot
.62706 .55795 Mdot
.54336 .37636 Mdot
.83692 .4805 Mdot
.50116 .75369 Mdot
.53343 .61775 Mdot
.35698 .44071 Mdot
.54963 .42509 Mdot
.52237 .51483 Mdot
.60205 .39119 Mdot
.45364 .30732 Mdot
.55365 .42463 Mdot
.29013 .49932 Mdot
.34298 .44057 Mdot
.39174 .59582 Mdot
.54701 .44231 Mdot
.57778 .38677 Mdot
.60275 .53721 Mdot
.6006 .31183 Mdot
.61598 .37841 Mdot
.33473 .44871 Mdot
.33651 .38614 Mdot
.34565 .4242 Mdot
.52919 .68287 Mdot
.48744 .80132 Mdot
.40326 .59839 Mdot
.53159 .44031 Mdot
.35751 .5657 Mdot
.55022 .27731 Mdot
.65224 .53786 Mdot
.21384 .64631 Mdot
.53897 .3926 Mdot
.34745 .41805 Mdot
.26617 .63153 Mdot
.37688 .44892 Mdot
.55439 .52434 Mdot
.39247 .57814 Mdot
.33953 .39136 Mdot
.56952 .38572 Mdot
.53751 .56565 Mdot
.27244 .71053 Mdot
.37908 .60296 Mdot
.52452 .4102 Mdot
.49985 .65687 Mdot
.47559 .78146 Mdot
.73404 .76531 Mdot
.41603 .58504 Mdot
.41187 .64662 Mdot
.59601 .40214 Mdot
.36726 .39148 Mdot
.37222 .5719 Mdot
.40593 .57284 Mdot
.52313 .6367 Mdot
.5583 .40244 Mdot
.55428 .40265 Mdot
.51823 .68733 Mdot
.37502 .60361 Mdot
.56902 .31426 Mdot
.62073 .37024 Mdot
.15279 .6163 Mdot
.66674 .41727 Mdot
.28406 .22135 Mdot
.27981 .38234 Mdot
.34903 .28129 Mdot
.2164 .47515 Mdot
.31982 .42791 Mdot
.55602 .41239 Mdot
.60081 .43875 Mdot
.54106 .62585 Mdot
.58278 .37171 Mdot
.58338 .62535 Mdot
.41143 .59421 Mdot
.33747 .78652 Mdot
.29771 .58532 Mdot
.3322 .23757 Mdot
.58452 .37398 Mdot
.33953 .53857 Mdot
.6538 .56789 Mdot
.34546 .60452 Mdot
.33721 .42019 Mdot
.56539 .3314 Mdot
.7505 .62971 Mdot
.5513 .6694 Mdot
.37708 .4076 Mdot
.70856 .70906 Mdot
.6826 .71111 Mdot
.58481 .32967 Mdot
.51907 .68179 Mdot
.23438 .59797 Mdot
.62484 .26953 Mdot
.41262 .62015 Mdot
.63788 .56619 Mdot
.54218 .6698 Mdot
.36775 .60215 Mdot
.30385 .35926 Mdot
.34917 .39098 Mdot
.30869 .38081 Mdot
.7763 .58408 Mdot
.55677 .61131 Mdot
.65096 .5648 Mdot
.4768 .79826 Mdot
.55876 .79476 Mdot
.6388 .56159 Mdot
.50544 .68424 Mdot
.33389 .38827 Mdot
.33808 .40722 Mdot
.36753 .41993 Mdot
.7594 .67568 Mdot
.30974 .40338 Mdot
.48121 .22281 Mdot
.61814 .34404 Mdot
.50626 .44799 Mdot
.59191 .413 Mdot
.41899 .61048 Mdot
.33571 .43249 Mdot
.46013 .54807 Mdot
.51349 .40787 Mdot
.32783 .75491 Mdot
.60524 .39351 Mdot
.36175 .61518 Mdot
.58675 .34934 Mdot
.51458 .23155 Mdot
.35886 .45296 Mdot
.57555 .36965 Mdot
.42891 .60651 Mdot
.67071 .5688 Mdot
.31193 .37169 Mdot
.5541 .40779 Mdot
.24171 .53912 Mdot
.6331 .39221 Mdot
.26847 .31408 Mdot
.68668 .38118 Mdot
.66888 .53734 Mdot
.64159 .30982 Mdot
.56439 .60826 Mdot
.52242 .4643 Mdot
.54197 .46133 Mdot
.3781 .60033 Mdot
.36372 .73316 Mdot
.52762 .66026 Mdot
.72136 .58199 Mdot
.5342 .44649 Mdot
.64615 .58527 Mdot
.37113 .46554 Mdot
.40506 .61673 Mdot
.53426 .34442 Mdot
.50969 .38312 Mdot
.31801 .26954 Mdot
.50172 .41589 Mdot
.58408 .42828 Mdot
.64096 .54145 Mdot
.45462 .20419 Mdot
.58107 .36007 Mdot
.54844 .52123 Mdot
.31794 .37716 Mdot
.59075 .31242 Mdot
.52422 .20882 Mdot
.61172 .37421 Mdot
.37545 .40066 Mdot
.30034 .41195 Mdot
.27832 .59131 Mdot
.68525 .58353 Mdot
.55017 .421 Mdot
.62146 .23239 Mdot
.55274 .3643 Mdot
.40481 .58932 Mdot
.60488 .3404 Mdot
.53279 .67139 Mdot
.75189 .67677 Mdot
.54008 .62132 Mdot
.56764 .42156 Mdot
.36584 .415 Mdot
.36109 .58563 Mdot
.78155 .60386 Mdot
.64001 .64212 Mdot
.47335 .21776 Mdot
.34909 .20809 Mdot
.67156 .54281 Mdot
.63788 .58613 Mdot
.39717 .61804 Mdot
.57537 .36821 Mdot
.59066 .20279 Mdot
.60912 .31548 Mdot
.58581 .35515 Mdot
.58447 .38911 Mdot
.43128 .78589 Mdot
.40221 .6047 Mdot
.51935 .64719 Mdot
.60149 .3652 Mdot
.61021 .36049 Mdot
.32802 .43525 Mdot
.67355 .56739 Mdot
.50425 .65512 Mdot
.67348 .55711 Mdot
.55139 .6531 Mdot
.33533 .79012 Mdot
.53759 .43977 Mdot
.6681 .56795 Mdot
.41285 .56205 Mdot
.37939 .42514 Mdot
.35021 .64322 Mdot
.50736 .657 Mdot
.53986 .63021 Mdot
.60721 .38926 Mdot
.37709 .40111 Mdot
.38406 .43061 Mdot
.66111 .57625 Mdot
.39535 .56354 Mdot
.55891 .41056 Mdot
.5428 .34121 Mdot
.35167 .48903 Mdot
.57545 .6381 Mdot
.63487 .45586 Mdot
.26118 .59212 Mdot
.57146 .36869 Mdot
.38295 .42747 Mdot
.58152 .39805 Mdot
.2076 .43432 Mdot
.37464 .3956 Mdot
.61529 .3859 Mdot
.60641 .7916 Mdot
.59543 .60357 Mdot
.26431 .54423 Mdot
.58305 .43156 Mdot
.25136 .28838 Mdot
.54391 .35441 Mdot
.16363 .64165 Mdot
.69542 .64419 Mdot
.55262 .4159 Mdot
.56461 .34731 Mdot
.4428 .36817 Mdot
.57782 .41277 Mdot
.52337 .68878 Mdot
.72813 .57085 Mdot
.33013 .44313 Mdot
.23784 .48178 Mdot
.46035 .41679 Mdot
.69286 .57556 Mdot
.54681 .61518 Mdot
.55254 .68749 Mdot
.64685 .55332 Mdot
.35775 .40556 Mdot
.55901 .37309 Mdot
.4634 .52748 Mdot
.57321 .66405 Mdot
.53971 .32118 Mdot
.40193 .58598 Mdot
.43898 .6989 Mdot
.53003 .60344 Mdot
.3863 .59118 Mdot
.53484 .39448 Mdot
.44683 .37361 Mdot
.7854 .52184 Mdot
.18351 .41732 Mdot
.35866 .59239 Mdot
.37074 .59985 Mdot
.74533 .69834 Mdot
.6962 .57114 Mdot
.35016 .23868 Mdot
.28818 .48947 Mdot
.3649 .57162 Mdot
.66065 .28984 Mdot
.5651 .66107 Mdot
.2456 .53227 Mdot
.38716 .38784 Mdot
.59576 .32586 Mdot
.57206 .38559 Mdot
.3945 .56182 Mdot
.27468 .37155 Mdot
.7963 .37556 Mdot
.38215 .59821 Mdot
.51832 .32122 Mdot
.44739 .48356 Mdot
.407 .74706 Mdot
.57239 .64292 Mdot
.68246 .5842 Mdot
.68856 .5371 Mdot
.32045 .41529 Mdot
.66903 .5878 Mdot
.57577 .77333 Mdot
.54117 .38339 Mdot
.37569 .59421 Mdot
.36885 .70735 Mdot
.38345 .58472 Mdot
.6482 .55422 Mdot
.66866 .5367 Mdot
.36991 .44289 Mdot
.3675 .43761 Mdot
.35432 .29077 Mdot
.70457 .4811 Mdot
.60357 .40151 Mdot
.28407 .69542 Mdot
.36824 .45325 Mdot
.65758 .35393 Mdot
.6395 .58593 Mdot
.67041 .56557 Mdot
.6503 .46902 Mdot
.54901 .39664 Mdot
.63586 .23903 Mdot
.55138 .39248 Mdot
.69887 .49468 Mdot
.54659 .42935 Mdot
.5232 .63757 Mdot
.54685 .39991 Mdot
.64219 .60026 Mdot
.5405 .33546 Mdot
.61479 .35756 Mdot
.57811 .64098 Mdot
.6252 .39979 Mdot
.53052 .67136 Mdot
.57539 .42315 Mdot
.69204 .5832 Mdot
.56426 .62285 Mdot
.73411 .41736 Mdot
.55246 .58238 Mdot
.49933 .67596 Mdot
.66273 .58608 Mdot
.69215 .56455 Mdot
.73536 .37326 Mdot
.33614 .41921 Mdot
.35045 .3676 Mdot
.5793 .36808 Mdot
.58015 .62355 Mdot
.40645 .6042 Mdot
.60489 .35258 Mdot
.62139 .42241 Mdot
.59899 .4212 Mdot
.32003 .40764 Mdot
.59847 .71574 Mdot
.66672 .57237 Mdot
.53116 .68358 Mdot
.61404 .54463 Mdot
.56927 .66348 Mdot
.50441 .40205 Mdot
.59063 .44929 Mdot
.32835 .31017 Mdot
.30518 .68344 Mdot
.72716 .73165 Mdot
.35677 .39252 Mdot
.52681 .61552 Mdot
.69383 .56481 Mdot
.62967 .31397 Mdot
.34099 .41557 Mdot
.5288 .67309 Mdot
.56703 .36851 Mdot
.52548 .41246 Mdot
.3445 .61692 Mdot
.53973 .47452 Mdot
.70174 .38378 Mdot
.56872 .66273 Mdot
.55568 .60249 Mdot
.55499 .79302 Mdot
.72608 .57057 Mdot
.4867 .55633 Mdot
.59569 .3862 Mdot
.68341 .5743 Mdot
.33114 .39206 Mdot
.78068 .55024 Mdot
.41447 .57236 Mdot
.54232 .55582 Mdot
.5829 .37372 Mdot
.41804 .52493 Mdot
.36734 .41588 Mdot
.64247 .56962 Mdot
.39286 .56085 Mdot
.64272 .53543 Mdot
.56627 .61845 Mdot
.47193 .15268 Mdot
.54883 .36836 Mdot
.60636 .40037 Mdot
.41109 .56396 Mdot
.33127 .39871 Mdot
.62748 .55183 Mdot
.27741 .32425 Mdot
.51701 .63151 Mdot
.60717 .20881 Mdot
.39021 .41702 Mdot
.50174 .24706 Mdot
.53731 .6824 Mdot
.38901 .6143 Mdot
.74234 .39879 Mdot
.36957 .58804 Mdot
.5651 .4243 Mdot
.35537 .41787 Mdot
.4119 .58379 Mdot
.57814 .54103 Mdot
.18432 .62954 Mdot
.51046 .26046 Mdot
.54744 .38519 Mdot
.24108 .69684 Mdot
.24491 .37044 Mdot
.36504 .47047 Mdot
.38652 .55488 Mdot
.60293 .38651 Mdot
.52977 .39748 Mdot
.55665 .36243 Mdot
.3952 .57472 Mdot
.44229 .75633 Mdot
.51291 .64634 Mdot
.59493 .40774 Mdot
.68442 .57999 Mdot
.52578 .66854 Mdot
.3988 .74185 Mdot
.54921 .63028 Mdot
.39418 .44829 Mdot
.60753 .3422 Mdot
.34073 .56007 Mdot
.23542 .72131 Mdot
.38539 .60589 Mdot
.50043 .6794 Mdot
.59753 .34042 Mdot
.3538 .70954 Mdot
.34499 .42214 Mdot
.52142 .62775 Mdot
.60152 .3757 Mdot
.4192 .73823 Mdot
.75466 .62127 Mdot
.5478 .63075 Mdot
.33382 .41052 Mdot
.19368 .49466 Mdot
.58709 .37083 Mdot
.54343 .35793 Mdot
.33764 .39813 Mdot
.46665 .39979 Mdot
.71303 .71113 Mdot
.57644 .39996 Mdot
.39032 .5953 Mdot
.59191 .17673 Mdot
.61919 .39967 Mdot
.65954 .473 Mdot
.54593 .6658 Mdot
.26005 .56813 Mdot
.6439 .44538 Mdot
.65151 .33871 Mdot
.26775 .3729 Mdot
.46716 .4507 Mdot
.31614 .76221 Mdot
.57621 .61404 Mdot
.69194 .68598 Mdot
.31446 .7671 Mdot
.40936 .61787 Mdot
.39413 .37538 Mdot
.27878 .43526 Mdot
.79478 .63389 Mdot
.19898 .51063 Mdot
.63136 .72095 Mdot
.75011 .63771 Mdot
.44619 .50615 Mdot
.55265 .64712 Mdot
.70956 .57658 Mdot
.56021 .40668 Mdot
.24373 .36958 Mdot
.58922 .2429 Mdot
.77543 .33083 Mdot
.23147 .68697 Mdot
.63407 .24705 Mdot
.22655 .66238 Mdot
.17237 .55357 Mdot
.3209 .29965 Mdot
.29542 .66975 Mdot
.62803 .21157 Mdot
.59984 .78804 Mdot
.48554 .17122 Mdot
.62772 .43256 Mdot
.57499 .51535 Mdot
.29061 .27226 Mdot
.47485 .2425 Mdot
.73561 .30744 Mdot
.53133 .62505 Mdot
.395 .4102 Mdot
.27961 .44361 Mdot
.36823 .46328 Mdot
.45345 .61756 Mdot
.1922 .47469 Mdot
.15985 .59819 Mdot
.51829 .22662 Mdot
.23433 .29871 Mdot
.38348 .24423 Mdot
.87718 .49251 Mdot
.48268 .67184 Mdot
.33932 .37773 Mdot
.65184 .52065 Mdot
.54123 .79932 Mdot
.31597 .54098 Mdot
.2619 .40353 Mdot
.46479 .77452 Mdot
.74113 .46461 Mdot
.35432 .40818 Mdot
.65798 .32141 Mdot
.45899 .63774 Mdot
.303 .58668 Mdot
.73361 .59516 Mdot
.17995 .53907 Mdot
.48664 .5375 Mdot
.23981 .519 Mdot
.42666 .67954 Mdot
.7377 .75621 Mdot
.68233 .43114 Mdot
.29003 .35493 Mdot
.37541 .64268 Mdot
.21012 .45163 Mdot
.81065 .58886 Mdot
.72404 .49464 Mdot
.54666 .79841 Mdot
.48155 .82587 Mdot
.22987 .36996 Mdot
.522 .84529 Mdot
.33759 .3665 Mdot
.58728 .42754 Mdot
.39306 .35514 Mdot
.60728 .23206 Mdot
.7051 .5717 Mdot
.35138 .75331 Mdot
.68628 .55855 Mdot
.40302 .44448 Mdot
.7453 .6782 Mdot
.49695 .22348 Mdot
.62945 .22868 Mdot
.6216 .56135 Mdot
.58945 .44117 Mdot
.68059 .17988 Mdot
.30712 .75063 Mdot
.2802 .58043 Mdot
.15276 .62135 Mdot
.45152 .55102 Mdot
.68376 .32782 Mdot
.40988 .58246 Mdot
.28529 .75171 Mdot
.34413 .40966 Mdot
.44321 .8527 Mdot
.21257 .68496 Mdot
.79167 .38803 Mdot
.41358 .10831 Mdot
.53701 .77782 Mdot
.42561 .52184 Mdot
.45043 .43747 Mdot
.71551 .41693 Mdot
.82144 .44941 Mdot
.76643 .3517 Mdot
.3491 .69748 Mdot
.32248 .23107 Mdot
.28552 .74614 Mdot
.60069 .22242 Mdot
.47561 .15893 Mdot
.80375 .62026 Mdot
.52336 .50342 Mdot
.41504 .42336 Mdot
.46746 .61877 Mdot
.20834 .59134 Mdot
.41578 .81463 Mdot
.6692 .45268 Mdot
.48662 .12316 Mdot
.63387 .59253 Mdot
.68217 .64981 Mdot
.18347 .44625 Mdot
.75113 .45062 Mdot
.67661 .35049 Mdot
.69064 .73057 Mdot
.52669 .33694 Mdot
.66567 .7475 Mdot
.24288 .66113 Mdot
.37919 .65236 Mdot
.60741 .78125 Mdot
.22373 .55962 Mdot
.29893 .2916 Mdot
.42967 .34476 Mdot
.53594 .80504 Mdot
.36181 .45853 Mdot
.72273 .47093 Mdot
.68075 .37721 Mdot
.15298 .5979 Mdot
.41503 .64579 Mdot
.1368 .54084 Mdot
.72585 .68798 Mdot
.56436 .4411 Mdot
.55794 .46927 Mdot
.55327 .29477 Mdot
.70443 .46643 Mdot
.62354 .37863 Mdot
.31951 .56634 Mdot
.15469 .56038 Mdot
.37332 .24294 Mdot
.36323 .6576 Mdot
.3688 .74129 Mdot
.18063 .42229 Mdot
.34711 .3252 Mdot
.72895 .63945 Mdot
.67779 .502 Mdot
.78703 .682 Mdot
.52295 .65846 Mdot
.59179 .2163 Mdot
.39504 .62249 Mdot
.75939 .58383 Mdot
.48565 .31461 Mdot
.8131 .45073 Mdot
.15445 .55903 Mdot
.65517 .7311 Mdot
.74315 .65848 Mdot
.76469 .43535 Mdot
.58587 .19116 Mdot
.36666 .74888 Mdot
.56001 .4563 Mdot
.24383 .42379 Mdot
.67046 .54072 Mdot
.37526 .30989 Mdot
.5318 .18783 Mdot
.641 .67796 Mdot
.62593 .34547 Mdot
.79259 .48311 Mdot
.5618 .72685 Mdot
.53619 .56467 Mdot
.60257 .84151 Mdot
.50754 .35938 Mdot
.49196 .79274 Mdot
.23735 .35287 Mdot
.69859 .43501 Mdot
.19651 .43285 Mdot
.22254 .51982 Mdot
.5037 .84097 Mdot
.19367 .66121 Mdot
.63015 .65699 Mdot
.34708 .78005 Mdot
.14832 .60227 Mdot
.53966 .83517 Mdot
.50629 .43352 Mdot
.43223 .58373 Mdot
.65246 .84235 Mdot
.54429 .68284 Mdot
.42975 .79188 Mdot
.46378 .18513 Mdot
.42396 .73467 Mdot
.28897 .38892 Mdot
.64115 .40391 Mdot
.45613 .51326 Mdot
.37042 .46907 Mdot
.62635 .39063 Mdot
.6427 .81032 Mdot
.51977 .82889 Mdot
.58369 .83414 Mdot
.24214 .32267 Mdot
.34952 .78663 Mdot
.40971 .50275 Mdot
.48474 .23496 Mdot
.35962 .47984 Mdot
.57968 .32617 Mdot
.66836 .61341 Mdot
.53699 .77627 Mdot
.79635 .49572 Mdot
.31296 .52603 Mdot
.377 .46269 Mdot
.31111 .72233 Mdot
.90644 .5627 Mdot
.37859 .25894 Mdot
.52613 .2038 Mdot
.57061 .7839 Mdot
.69527 .47067 Mdot
.22269 .61619 Mdot
.8014 .42054 Mdot
.16037 .52425 Mdot
.34736 .47418 Mdot
.46851 .17844 Mdot
.64253 .70523 Mdot
.69906 .31058 Mdot
.59065 .72639 Mdot
.17714 .60565 Mdot
.42299 .46173 Mdot
.79709 .54935 Mdot
.27311 .46528 Mdot
.79327 .38149 Mdot
.70766 .62448 Mdot
.44586 .69937 Mdot
.5396 .18538 Mdot
.33191 .66286 Mdot
.67982 .47554 Mdot
.46184 .49589 Mdot
.60802 .3003 Mdot
.46526 .44924 Mdot
.67785 .46746 Mdot
.70843 .33091 Mdot
.39552 .79987 Mdot
.14661 .6417 Mdot
.72255 .75377 Mdot
.21978 .31174 Mdot
.24197 .65073 Mdot
.58907 .3213 Mdot
.16831 .45868 Mdot
.53792 .8523 Mdot
.19531 .67368 Mdot
.50946 .72712 Mdot
.59 .64961 Mdot
.35282 .56934 Mdot
.69064 .76788 Mdot
.57657 .73031 Mdot
.17529 .49733 Mdot
.6765 .7483 Mdot
.38369 .54452 Mdot
.84304 .54066 Mdot
.50738 .82328 Mdot
.50305 .2911 Mdot
.56079 .47717 Mdot
.54602 .32279 Mdot
.53634 .23385 Mdot
.38321 .45369 Mdot
.41353 .66998 Mdot
.71429 .48296 Mdot
.53067 .64892 Mdot
.69777 .6116 Mdot
.2579 .40296 Mdot
.63235 .38895 Mdot
.46123 .43329 Mdot
.39568 .40813 Mdot
.30338 .67953 Mdot
.32703 .62425 Mdot
.39262 .81482 Mdot
.52896 .76731 Mdot
.58724 .30512 Mdot
.6942 .43556 Mdot
.58043 .74026 Mdot
.7102 .72273 Mdot
.36385 .61306 Mdot
.21666 .66855 Mdot
.57336 .52592 Mdot
.72047 .47208 Mdot
.55408 .23823 Mdot
.30165 .29786 Mdot
.60831 .44471 Mdot
.26387 .60906 Mdot
.43832 .30458 Mdot
.54951 .55756 Mdot
.41291 .42917 Mdot
.41683 .42018 Mdot
.16609 .4197 Mdot
.59603 .76113 Mdot
.42167 .68482 Mdot
.20985 .65598 Mdot
.37996 .57603 Mdot
.37348 .4471 Mdot
.65234 .61033 Mdot
.28746 .30136 Mdot
.45822 .27878 Mdot
.75497 .62182 Mdot
.48252 .75513 Mdot
.65383 .6682 Mdot
.22044 .66148 Mdot
.23614 .68584 Mdot
.76582 .3077 Mdot
.32696 .44594 Mdot
.29699 .31924 Mdot
.36629 .22135 Mdot
.39436 .43681 Mdot
.28526 .43077 Mdot
.33105 .53278 Mdot
.39899 .80975 Mdot
.39842 .5437 Mdot
.31025 .23707 Mdot
.71333 .36356 Mdot
.42734 .75309 Mdot
.77967 .60988 Mdot
.54505 .18423 Mdot
.20404 .64439 Mdot
.62586 .27287 Mdot
.4807 .33141 Mdot
.63889 .38999 Mdot
.56463 .48696 Mdot
.78433 .70853 Mdot
.56315 .58487 Mdot
.50584 .24463 Mdot
.21644 .545 Mdot
.55241 .37285 Mdot
.71896 .76403 Mdot
.26598 .34757 Mdot
.74262 .70474 Mdot
.37149 .55129 Mdot
.53267 .36371 Mdot
.55372 .32718 Mdot
.6453 .49468 Mdot
.2717 .57983 Mdot
.44915 .80714 Mdot
.53619 .17962 Mdot
.22263 .58345 Mdot
.58828 .24339 Mdot
.48835 .7917 Mdot
.18104 .5152 Mdot
.24205 .37722 Mdot
.51632 .52372 Mdot
.54198 .77206 Mdot
.75071 .42755 Mdot
.23263 .30612 Mdot
.60979 .51738 Mdot
.38451 .50052 Mdot
.33709 .51115 Mdot
.24575 .56886 Mdot
.78382 .56986 Mdot
.56493 .33431 Mdot
.70845 .70921 Mdot
.17415 .54592 Mdot
.71107 .2627 Mdot
.82312 .51028 Mdot
.70102 .77623 Mdot
.46023 .31368 Mdot
.23387 .54889 Mdot
.24648 .39184 Mdot
.66214 .207 Mdot
.59087 .51469 Mdot
.30855 .73664 Mdot
.75528 .42812 Mdot
.21501 .65836 Mdot
.43616 .59277 Mdot
.2931 .48204 Mdot
.37341 .74559 Mdot
.37095 .79037 Mdot
.37651 .33503 Mdot
.17782 .59068 Mdot
.43957 .5329 Mdot
.47773 .84645 Mdot
.32211 .6642 Mdot
.43707 .49648 Mdot
.53409 .61334 Mdot
.65002 .73821 Mdot
.22763 .65195 Mdot
.281 .67349 Mdot
.54115 .18863 Mdot
.5613 .60001 Mdot
.70753 .59578 Mdot
.54005 .26674 Mdot
.76681 .4853 Mdot
.24288 .57915 Mdot
.69463 .43523 Mdot
.166 .58591 Mdot
.62927 .51666 Mdot
.72764 .67637 Mdot
.48516 .78831 Mdot
.44226 .158 Mdot
.27659 .57624 Mdot
.61247 .75949 Mdot
.26116 .36971 Mdot
.68609 .63744 Mdot
.66731 .29727 Mdot
.21274 .76162 Mdot
.42112 .17634 Mdot
.30888 .66755 Mdot
.41672 .81458 Mdot
.2022 .42295 Mdot
.30984 .68375 Mdot
.82365 .46028 Mdot
.66544 .41887 Mdot
.73712 .56452 Mdot
.58349 .38817 Mdot
.58864 .84164 Mdot
.74878 .48505 Mdot
.43908 .82678 Mdot
.17013 .44431 Mdot
.53639 .23844 Mdot
.63134 .39154 Mdot
.54082 .67813 Mdot
.4365 .64656 Mdot
.76548 .51682 Mdot
.45101 .38551 Mdot
.66642 .31992 Mdot
.49805 .75609 Mdot
.55693 .61339 Mdot
.5968 .72629 Mdot
.31943 .45574 Mdot
.52522 .75462 Mdot
.25688 .58766 Mdot
.61408 .61435 Mdot
.50832 .54182 Mdot
.68425 .46399 Mdot
.65672 .41774 Mdot
.50097 .29078 Mdot
.81239 .46587 Mdot
.49842 .48639 Mdot
.55231 .6295 Mdot
.46778 .33057 Mdot
.33337 .2285 Mdot
.23785 .59843 Mdot
.47379 .82521 Mdot
.68347 .72606 Mdot
.4909 .32695 Mdot
.67274 .47378 Mdot
.81666 .43183 Mdot
.67692 .26575 Mdot
.3141 .70833 Mdot
.62706 .45353 Mdot
.65706 .26522 Mdot
.25155 .43423 Mdot
.32937 .78328 Mdot
.48213 .17268 Mdot
.41757 .19076 Mdot
.4937 .60796 Mdot
.46203 .249 Mdot
.54803 .2485 Mdot
.73373 .40593 Mdot
.50365 .55959 Mdot
.87337 .51627 Mdot
.37119 .37818 Mdot
.81045 .6954 Mdot
.41401 .60333 Mdot
.80926 .62475 Mdot
.74994 .40547 Mdot
.4607 .49164 Mdot
.49176 .56611 Mdot
.26927 .61226 Mdot
.29279 .49905 Mdot
.2551 .29956 Mdot
.75964 .32031 Mdot
.57335 .65916 Mdot
.54064 .17514 Mdot
.45935 .14823 Mdot
.45142 .35741 Mdot
.59253 .43793 Mdot
.41419 .17746 Mdot
.5816 .61043 Mdot
.79713 .49603 Mdot
.1926 .42427 Mdot
.26334 .65064 Mdot
.48913 .36902 Mdot
.70002 .47314 Mdot
.30017 .72896 Mdot
.19322 .65241 Mdot
.83778 .50727 Mdot
.2431 .6608 Mdot
.43137 .58281 Mdot
.42264 .50001 Mdot
.18977 .59993 Mdot
.69157 .35574 Mdot
.24606 .50294 Mdot
.68136 .35372 Mdot
.85836 .61032 Mdot
.41025 .78602 Mdot
.44715 .80605 Mdot
.68691 .36644 Mdot
.30789 .39991 Mdot
.30917 .63306 Mdot
.67766 .35691 Mdot
.26971 .64766 Mdot
.28677 .28182 Mdot
.67998 .36905 Mdot
.73903 .26188 Mdot
.34509 .25778 Mdot
.5938 .66508 Mdot
.55689 .25346 Mdot
.35172 .25935 Mdot
.38199 .54638 Mdot
.73257 .58217 Mdot
.2152 .55155 Mdot
.40451 .55897 Mdot
.24588 .58555 Mdot
.24531 .54419 Mdot
.38232 .22412 Mdot
.46943 .27756 Mdot
.22879 .60319 Mdot
.4282 .36863 Mdot
.40887 .38553 Mdot
.77826 .55551 Mdot
.49536 .64958 Mdot
.20571 .53568 Mdot
.51911 .62562 Mdot
.65389 .38658 Mdot
.55479 .55132 Mdot
.50894 .31795 Mdot
.71319 .75412 Mdot
.67351 .54287 Mdot
.34182 .38042 Mdot
.81983 .62159 Mdot
.39416 .42692 Mdot
.61962 .82308 Mdot
.80758 .43735 Mdot
.5557 .23655 Mdot
.64052 .64866 Mdot
.62333 .69506 Mdot
.8337 .37962 Mdot
.44288 .4167 Mdot
.48286 .61577 Mdot
.4269 .40864 Mdot
.32871 .38407 Mdot
.49783 .77905 Mdot
.57137 .63029 Mdot
.63566 .47288 Mdot
.38882 .51963 Mdot
.40388 .47279 Mdot
.31266 .43771 Mdot
.56269 .53635 Mdot
.72438 .52953 Mdot
.39042 .80549 Mdot
.55835 .64086 Mdot
.84108 .61807 Mdot
.6155 .43464 Mdot
.41714 .33698 Mdot
.15799 .52034 Mdot
.84261 .52397 Mdot
.5385 .69016 Mdot
.47614 .13858 Mdot
.53879 .42456 Mdot
.22903 .61594 Mdot
.34702 .40542 Mdot
.44213 .18207 Mdot
.67003 .54609 Mdot
.70466 .42831 Mdot
.34851 .58009 Mdot
.79569 .55347 Mdot
.51118 .74637 Mdot
.30505 .40916 Mdot
.26195 .66732 Mdot
.30741 .3044 Mdot
.26763 .48281 Mdot
.61125 .70813 Mdot
.46011 .35211 Mdot
.46619 .27289 Mdot
.30794 .43166 Mdot
.42187 .80113 Mdot
.44996 .17779 Mdot
.31425 .7857 Mdot
.56143 .29373 Mdot
.68212 .70479 Mdot
.34431 .50447 Mdot
.25143 .60477 Mdot
.60359 .47817 Mdot
.15815 .54249 Mdot
.72482 .4857 Mdot
.35144 .51671 Mdot
.69404 .48906 Mdot
.65183 .35884 Mdot
.49837 .5308 Mdot
.44368 .67299 Mdot
.7941 .35146 Mdot
.59217 .48923 Mdot
.81943 .57689 Mdot
.63349 .44664 Mdot
.5038 .79283 Mdot
.29085 .41905 Mdot
.57866 .67514 Mdot
.47355 .24967 Mdot
.41194 .64761 Mdot
.31712 .77468 Mdot
.15834 .53588 Mdot
.34014 .58577 Mdot
.48553 .77661 Mdot
.21132 .46322 Mdot
.59847 .30405 Mdot
.40586 .5173 Mdot
.57797 .42882 Mdot
.28829 .42476 Mdot
.84843 .53078 Mdot
.26564 .6321 Mdot
.56042 .45863 Mdot
.31493 .76282 Mdot
.27581 .74145 Mdot
.46627 .84118 Mdot
.59868 .20181 Mdot
.31732 .42329 Mdot
.56898 .83034 Mdot
.66007 .31239 Mdot
.16438 .62003 Mdot
.30564 .69934 Mdot
.16223 .43277 Mdot
.46729 .35211 Mdot
.21631 .52939 Mdot
.76849 .34366 Mdot
.27289 .51198 Mdot
.22566 .38246 Mdot
.43235 .47336 Mdot
.40348 .68684 Mdot
.21339 .39341 Mdot
.74372 .24299 Mdot
.60506 .47021 Mdot
.24019 .52976 Mdot
.27113 .44573 Mdot
.20763 .544 Mdot
.70576 .64809 Mdot
.60404 .33977 Mdot
.37177 .71511 Mdot
.76557 .63105 Mdot
.68068 .45286 Mdot
.70444 .59797 Mdot
.70367 .64802 Mdot
.75688 .54984 Mdot
.70874 .50393 Mdot
.48551 .17067 Mdot
.46994 .3433 Mdot
.62535 .47727 Mdot
.57191 .44394 Mdot
.28963 .40907 Mdot
.6692 .5907 Mdot
.56464 .70614 Mdot
.58023 .42382 Mdot
.58783 .64284 Mdot
.27382 .49189 Mdot
.68019 .79067 Mdot
.3563 .65332 Mdot
.26554 .33429 Mdot
.38973 .39096 Mdot
.26883 .59009 Mdot
.34731 .35059 Mdot
.77517 .65337 Mdot
.68277 .68676 Mdot
.66929 .4524 Mdot
.28433 .73174 Mdot
.60406 .7822 Mdot
.32003 .27379 Mdot
.59801 .79829 Mdot
.42049 .57141 Mdot
.49257 .37889 Mdot
.29499 .46903 Mdot
.58663 .74559 Mdot
.40675 .4477 Mdot
.21852 .53594 Mdot
.48442 .62376 Mdot
.60667 .76789 Mdot
.23409 .35679 Mdot
.30579 .29983 Mdot
.53914 .27336 Mdot
.24512 .6971 Mdot
.55981 .66308 Mdot
.42059 .18438 Mdot
.24237 .49161 Mdot
.67195 .70329 Mdot
.48896 .80456 Mdot
.3701 .80542 Mdot
.46526 .5535 Mdot
.73849 .44992 Mdot
.54904 .35842 Mdot
.50281 .20341 Mdot
.27013 .62899 Mdot
.49889 .44982 Mdot
.48364 .73011 Mdot
.3842 .41964 Mdot
.46459 .70196 Mdot
.58723 .50773 Mdot
.74272 .55434 Mdot
.36509 .46668 Mdot
.61238 .23791 Mdot
.68119 .59264 Mdot
.44828 .55667 Mdot
.62441 .39035 Mdot
.72724 .43925 Mdot
.62722 .22446 Mdot
.5005 .35955 Mdot
.22471 .63393 Mdot
.47204 .33333 Mdot
.30122 .28454 Mdot
.24525 .62284 Mdot
.32141 .71466 Mdot
.29046 .5038 Mdot
.48815 .25456 Mdot
.52482 .73261 Mdot
.59664 .42309 Mdot
.57488 .6777 Mdot
.38348 .43855 Mdot
.19695 .46634 Mdot
.45616 .31038 Mdot
.73567 .42143 Mdot
.47453 .48949 Mdot
.37718 .35526 Mdot
.46748 .46936 Mdot
.16508 .47654 Mdot
.27373 .51359 Mdot
.7167 .48625 Mdot
.44334 .58415 Mdot
.74842 .40682 Mdot
.81808 .46441 Mdot
.23943 .71073 Mdot
.80719 .41239 Mdot
.46622 .53537 Mdot
.8248 .56966 Mdot
.30968 .65315 Mdot
.19317 .41875 Mdot
.71887 .4987 Mdot
.47192 .56712 Mdot
.67218 .60719 Mdot
.33997 .60984 Mdot
.51332 .50594 Mdot
.60126 .59271 Mdot
.65475 .43571 Mdot
.45057 .72991 Mdot
.46418 .64949 Mdot
.64183 .39447 Mdot
.43242 .78934 Mdot
.26757 .71623 Mdot
.45154 .18365 Mdot
.47669 .46322 Mdot
.72692 .60611 Mdot
.74801 .53715 Mdot
.19289 .32539 Mdot
.74472 .75318 Mdot
.54862 .36042 Mdot
.48332 .46656 Mdot
.72283 .45426 Mdot
.56361 .66986 Mdot
.67139 .36698 Mdot
.38755 .36402 Mdot
.39274 .61184 Mdot
.59842 .59537 Mdot
.62419 .76331 Mdot
.27405 .61507 Mdot
.76867 .46662 Mdot
.38912 .74503 Mdot
.67439 .79754 Mdot
.29646 .26161 Mdot
.25699 .61474 Mdot
.1614 .38094 Mdot
.46472 .66673 Mdot
.40809 .39962 Mdot
.38036 .35106 Mdot
.4023 .80627 Mdot
.69559 .42562 Mdot
.77208 .58486 Mdot
.34621 .73256 Mdot
.7237 .49264 Mdot
.66658 .30538 Mdot
.48916 .78921 Mdot
.47109 .71118 Mdot
.46422 .51013 Mdot
.62454 .69606 Mdot
.55289 .81277 Mdot
.59325 .24942 Mdot
.2806 .71897 Mdot
.77077 .62798 Mdot
.71254 .23419 Mdot
.28784 .75485 Mdot
.68212 .61302 Mdot
.71732 .64169 Mdot
.37955 .34864 Mdot
.70309 .35847 Mdot
.65351 .28475 Mdot
.80097 .51089 Mdot
.4472 .2777 Mdot
.60925 .68116 Mdot
.80005 .60481 Mdot
.67921 .47465 Mdot
.35864 .25186 Mdot
.47366 .56667 Mdot
.48684 .30409 Mdot
.50577 .76941 Mdot
.68567 .39297 Mdot
.58847 .5434 Mdot
.71468 .38877 Mdot
.46272 .34003 Mdot
.26908 .36718 Mdot
.22382 .4879 Mdot
.77684 .28778 Mdot
.32678 .73002 Mdot
.78038 .64614 Mdot
.62123 .35113 Mdot
.34702 .80458 Mdot
.2299 .4953 Mdot
.34217 .73442 Mdot
.25622 .32208 Mdot
.58229 .68346 Mdot
.36622 .50599 Mdot
.59781 .42188 Mdot
.27086 .68957 Mdot
.51036 .2464 Mdot
.34799 .27202 Mdot
.79325 .57446 Mdot
.69737 .44719 Mdot
.73183 .64216 Mdot
.72881 .38741 Mdot
.50946 .33439 Mdot
.38882 .40598 Mdot
.57177 .83757 Mdot
.44887 .53214 Mdot
.64742 .41241 Mdot
.49949 .44248 Mdot
.77367 .35163 Mdot
.35611 .19758 Mdot
.55063 .29674 Mdot
.58133 .7895 Mdot
.6308 .24946 Mdot
.55732 .28076 Mdot
.66269 .3599 Mdot
.2815 .18727 Mdot
.14962 .63657 Mdot
.31641 .43072 Mdot
.53829 .19955 Mdot
.63906 .24868 Mdot
.39301 .80037 Mdot
.64641 .70261 Mdot
.54429 .7203 Mdot
.73454 .31596 Mdot
.69402 .32797 Mdot
.58721 .44525 Mdot
.24185 .34397 Mdot
.2241 .69398 Mdot
.79651 .58107 Mdot
.30713 .75862 Mdot
.59604 .46265 Mdot
.5363 .44493 Mdot
.24335 .24615 Mdot
.1942 .61134 Mdot
.53102 .33342 Mdot
.77476 .34782 Mdot
.41496 .42001 Mdot
.56719 .39928 Mdot
.40294 .76362 Mdot
.53095 .18013 Mdot
.67618 .47647 Mdot
.37242 .79107 Mdot
.35966 .46295 Mdot
.47403 .61079 Mdot
.39275 .61349 Mdot
.49593 .56382 Mdot
.53006 .42475 Mdot
.40027 .57466 Mdot
.55012 .28276 Mdot
.21011 .51936 Mdot
.36325 .5489 Mdot
.49326 .16187 Mdot
.13931 .51017 Mdot
.47292 .30161 Mdot
.36178 .62907 Mdot
.60031 .30313 Mdot
.34351 .26309 Mdot
.76335 .52719 Mdot
.35292 .48234 Mdot
.20355 .39955 Mdot
.31704 .82818 Mdot
.41359 .69385 Mdot
.71979 .54205 Mdot
.37905 .4681 Mdot
.62314 .47626 Mdot
.52153 .26963 Mdot
.43158 .54887 Mdot
.5546 .66219 Mdot
.61807 .32553 Mdot
.51573 .32759 Mdot
.36227 .56102 Mdot
.80667 .69317 Mdot
.59261 .33585 Mdot
.66062 .39405 Mdot
.16763 .62231 Mdot
.77821 .5571 Mdot
.40059 .33163 Mdot
.51661 .3785 Mdot
.30774 .58748 Mdot
.47105 .56758 Mdot
.19407 .54245 Mdot
.72397 .68163 Mdot
.33877 .76944 Mdot
.45372 .30977 Mdot
.56293 .26154 Mdot
.61272 .36767 Mdot
.70047 .569 Mdot
.24863 .5288 Mdot
.36944 .76187 Mdot
.57586 .46843 Mdot
.18198 .64746 Mdot
.58375 .6834 Mdot
.46827 .74736 Mdot
.57465 .28169 Mdot
.4867 .83998 Mdot
.81871 .554 Mdot
.53114 .24961 Mdot
.76599 .67862 Mdot
.59099 .75262 Mdot
.76527 .48474 Mdot
.54349 .67578 Mdot
.60883 .45279 Mdot
.35213 .46089 Mdot
.67456 .80231 Mdot
.37564 .76729 Mdot
.36593 .69461 Mdot
.44649 .70222 Mdot
.48412 .2109 Mdot
.25477 .46834 Mdot
.15244 .43051 Mdot
.60736 .72897 Mdot
.68757 .7893 Mdot
.41799 .18911 Mdot
.3746 .4732 Mdot
.23135 .55525 Mdot
.4953 .38701 Mdot
.54965 .63384 Mdot
.36549 .77869 Mdot
.53644 .31305 Mdot
.74854 .66851 Mdot
.52132 .38273 Mdot
.72659 .72198 Mdot
.58654 .57831 Mdot
.46069 .78209 Mdot
.33607 .66941 Mdot
.82274 .46618 Mdot
.18624 .47305 Mdot
.32899 .58935 Mdot
.17154 .38085 Mdot
.19154 .48666 Mdot
.21726 .67081 Mdot
.75774 .61527 Mdot
.84242 .46592 Mdot
.28729 .67827 Mdot
.23127 .60335 Mdot
.34444 .66208 Mdot
.45734 .40404 Mdot
.64751 .73702 Mdot
.57382 .28445 Mdot
.25992 .53905 Mdot
.338 .58859 Mdot
.477 .92172 Mdot
.6238 .59554 Mdot
.3319 .3639 Mdot
.61976 .74014 Mdot
.25017 .70978 Mdot
.47135 .39515 Mdot
.21921 .37106 Mdot
.57588 .51589 Mdot
.56385 .45596 Mdot
.45975 .28784 Mdot
.47908 .18405 Mdot
.66174 .73668 Mdot
.85663 .41127 Mdot
.29644 .26453 Mdot
.45238 .72076 Mdot
.51395 .53463 Mdot
.39206 .4421 Mdot
.29461 .38302 Mdot
.63693 .66975 Mdot
.21419 .35356 Mdot
.21405 .52598 Mdot
.19028 .60158 Mdot
.82593 .36875 Mdot
.34598 .24064 Mdot
.39854 .80638 Mdot
.2968 .6488 Mdot
.31576 .37508 Mdot
.70592 .60726 Mdot
.61064 .6343 Mdot
.3538 .69079 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo08?ooooo0_l00034
ooooo`007?ooool00ol0003oooooooooo`23ooooo`;o0000a?ooool001cooooo00?o0000oooooooo
ool0Roooool2o`000;cooooo000Looooo`03o`000?oooooooooo08_ooooo0_l0002looooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo09[ooooo0ol0002/
ooooo`007?ooool00ol0003oooooooooo`2Jooooo`?o00004oooool2o`0009Oooooo000Looooo`03
o`000?oooooooooo08Oooooo0_l0000Wooooo`;o0000Uoooool001cooooo00?o0000ooooooooool0
Qoooool2o`0001gooooo0_l00008ooooo`;o0000Uoooool001cooooo00?o0000ooooooooool0T?oo
ool2o`0001Cooooo0_l0002Qooooo`007?ooool00ol0003oooooooooo`2@ooooo`;o00001Oooool2
o`0000gooooo0_l0002Qooooo`007?ooool00ol0003oooooooooo`2Gooooo`;o00003Oooool2o`00
0:7ooooo000Looooo`03o`000?oooooooooo0:Gooooo0_l0002Rooooo`007?ooool00ol0003ooooo
ooooo`2Aooooo`;o00002oooool2o`0000?ooooo1?l0002Rooooo`007?ooool2o`0007_ooooo0_l0
000Eooooo`;o00000oooool2o`0000Kooooo0_l00003ooooo`;o0000Y?ooool001cooooo00?o0000
ooooooooool0N_ooool2o`0001[ooooo0_l0002aooooo`007?ooool00ol0003oooooooooo`2<oooo
o`;o00002Oooool2o`0001?ooooo0_l0002Kooooo`007?ooool00ol0003oooooooooo`28ooooo`;o
00000_ooool2o`0000Wooooo0_l00003ooooo`;o00003_ooool2o`0000Oooooo0_l0002Booooo`00
7?ooool00ol0003oooooooooo`28ooooo`;o00004_ooool2o`0001Oooooo0_l0002Booooo`007?oo
ool00ol0003oooooooooo`2?ooooo`;o00002_ooool2o`000:cooooo000Looooo`03o`000?oooooo
oooo08_ooooo0_l00002ooooo`;o00002Oooool3o`0000oooooo0_l0002Kooooo`007?ooool00ol0
003oooooooooo`2;ooooo`;o00003?ooool3o`00013ooooo0_l0002Kooooo`007?ooool00ol0003o
ooooooooo`1Zooooo`;o00004?ooool2o`0000Gooooo1?l00007ooooo`;o00001?ooool2o`0000?o
oooo0_l0000Aooooo`;o00002Oooool2o`0000?ooooo0_l0002;ooooo`007?ooool00ol0003ooooo
ooooo`1Zooooo`;o00004?ooool2o`0000Gooooo1?l00005ooooo`Co00001?ooool2o`0001?ooooo
0ol00003ooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo0_l00007ooooo`;o0000
4_ooool2o`0006kooooo000Looooo`03o`000?oooooooooo07[ooooo0_l00008ooooo`?o00001Ooo
ool2o`000003ooooool0003o000000Oooooo0_l0000?ooooo`So000000?oooooo`000?l000004?oo
ool3o`0001;ooooo0_l0001^ooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o00008?ooool2
o`0000Oooooo1?l00005ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l0000B
ooooo`?o00001?ooool2o`0000oooooo0_l00023ooooo`007?ooool00ol0003oooooooooo`1Hoooo
o`;o0000:Oooool3o`0000gooooo1?l0000=ooooo`;o00000oooool2o`000004ooooool0003o0000
o`0000Cooooo0_l0000;ooooo`;o0000Qoooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Ooo
ool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo07_ooooo0ol00006ooooo`?o00003_oo
ool2o`0000gooooo0_l00002ooooo`?o000000?oooooo`000?l000000_ooool2o`0000Kooooo0_l0
00000ooooooo0000o`000003ooooo`;o0000Qoooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo07_o
oooo1?l00006ooooo`;o00007_ooool2o`000003ooooool0003o000000Kooooo0_l00006ooooo`;o
000000?oooooo`000?l00000S?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool0
2_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo073ooooo0_l00004ooooo`;o0000
1Oooool2o`0001Wooooo0_l0000;ooooo`;o00001?ooool2o`0000_ooooo0_l0002?ooooo`0000?o
ooooo`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0
001Pooooo`;o00003_ooool2o`0000Cooooo0_l00003ooooo`;o00006Oooool4o`0000Kooooo0_l0
0009ooooo`;o00003oooool2o`000003ooooool0003o000000_ooooo0_l0001kooooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000
ooooooooool0H?ooool2o`0000kooooo0_l00009ooooo`;o00004oooool2o`0000Cooooo0_l00002
ooooo`;o00001?ooool2o`0000Gooooo0_l00008ooooo`;o00002Oooool2o`000003ooooool0003o
000000?ooooo0_l00006ooooo`;o0000Noooool00003ooooool@413ooooo00;ooooo00?o410@oooo
ooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06gooooo1Ol00005oooo
o`;o000000?oooooo`000?l000005?ooool2o`0000Sooooo0_l00004ooooo`;o00000_ooool2o`00
0003ooooool0003o000000Sooooo0_l0000>ooooo`;o000000?oooooo`000?l000003Oooool2o`00
07Cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@
4006ooooo`03o`000?oooooooooo06gooooo0ol00007ooooo`;o000000?oooooo`000?l000007_oo
ool2o`0000Cooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00002oooool3o`0000;ooooo
0_l00006ooooo`;o00001Oooool2o`0000Wooooo0_l00009ooooo`;o0000JOooool00006ooooooo^
k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000oooo
ooooool0Soooool2o`0000Wooooo0_l00004ooooo`;o000000?oooooo`000?l000003oooool3o`00
00;ooooo0_l0000=ooooo`;o00005?ooool2o`0006Wooooo000Looooo`03o`000?oooooooooo08?o
oooo0_l0000:ooooo`;o00001Oooool2o`0000cooooo0_l00002ooooo`;o00004_ooool2o`0008_o
oooo000Looooo`03o`000?oooooooooo05Wooooo0_l0000Eooooo`Ko00003Oooool2o`00017ooooo
0_l0000<ooooo`;o00000_ooool2o`0001;ooooo0_l0002;ooooo`007?ooool00ol0003ooooooooo
o`1Iooooo`;o00003Oooool2o`000003ooooool0003o000000?ooooo1_l00002ooooo`;o000000?o
ooooo`000?l000007?ooool2o`0000?ooooo0ol00007ooooo`;o00005Oooool2o`000003ooooool0
003o000000Cooooo0_l000000ooooooo0000o`00001looooo`007?ooool00ol0003oooooooooo`1X
ooooo`;o000000?oooooo`000?l000002oooool2o`000003ooooool0003o000001cooooo0_l00003
ooooo`?o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`;o00002_ooool2
o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`00001looooo`007?ooool00ol0
003oooooooooo`1Tooooo`Co000000?oooooo`000?l000003?ooool2o`00023ooooo0_l0000:oooo
o`;o00000_ooool2o`000003ooooool0003o000000Cooooo0ol00006ooooo`;o00002_ooool4o`00
07kooooo000Looooo`03o`000?oooooooooo06Cooooo1ol0000<ooooo`Co00007_ooool2o`0000So
oooo0_l00005ooooo`Co00001?ooool2o`0000Oooooo0_l00004ooooo`;o00000oooool5o`0000;o
oooo0_l0001jooooo`007?ooool00ol0003oooooooooo`1Uooooo`Co00001_ooool2o`0000Oooooo
0ol0000Oooooo`;o00001oooool2o`0000Gooooo1?l00003ooooo`;o00003_ooool2o`0000?ooooo
1?l00003ooooo`;o00005Oooool2o`0006?ooooo000Looooo`03o`000?oooooooooo067ooooo0_l0
0003ooooo`Co00001?ooool3o`0000Kooooo1?l0000Oooooo`;o00003_ooool2o`0000Cooooo0ol0
0005ooooo`;o00002Oooool2o`0000?ooooo0_l000000ooooooo0000o`00000Gooooo`;o0000Hooo
ool001cooooo00?o0000ooooooooool0HOooool2o`0000Gooooo0_l00003ooooo`Co00001?ooool4
o`0001gooooo0_l00006ooooo`;o00002_ooool2o`0000Cooooo0_l00006ooooo`;o00000_ooool2
o`000003ooooool0003o000000;ooooo0_l000001?oooooo0000o`000?ooool4o`00027ooooo0_l0
001Iooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o00008?ooool2o`0000Kooooo0ol00000
0ooooooo0000o`00000Kooooo`;o00001_ooool2o`000003ooooool0003o000001Sooooo0ol00000
1?oooooo0000o`000?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000=ooooo`;o00000_oo
ool2o`00013ooooo0_l0001Iooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o0000;?ooool2
o`0001Oooooo0_l0000;ooooo`Go00002_ooool2o`0000Kooooo0_l00003ooooo`;o00001Oooool2
o`0000Kooooo1?l000000ooooooo0000o`000007ooooo`;o00000_ooool2o`0006_ooooo000Loooo
o`;o0000FOooool2o`0001Oooooo0_l0000Oooooo`;o00000_ooool2o`0000Oooooo0_l000000ooo
oooo0000o`000005ooooo`;o00000oooool2o`0000Kooooo0_l00005ooooo`;o00002_ooool5o`00
0004ooooool0003o0000ooooo`;o00002?ooool2o`0006_ooooo000Looooo`03o`000?oooooooooo
05Sooooo0_l0000Dooooo`;o000000?oooooo`000?l000008oooool2o`0000?ooooo0_l0000<oooo
o`;o00001_ooool2o`0000?ooooo0_l00005ooooo`;o00002_ooool2o`0000Oooooo0_l00003oooo
o`;o00001?ooool2o`0006[ooooo000Looooo`03o`000?oooooooooo06Cooooo0_l00006ooooo`Co
0000:Oooool4o`0000Wooooo0_l000000ooooooo0000o`000006ooooo`;o00000oooool3o`0001ko
oooo0_l00004ooooo`Co0000J?ooool001cooooo00?o0000ooooooooool0GOooool2o`0000Gooooo
0_l00006ooooo`;o000000?oooooo`000?l000001_ooool2o`00023ooooo0_l00007ooooo`;o0000
0_ooool2o`000003ooooool0003o000000Sooooo0_l00002ooooo`;o000000?oooooo`000?l00000
5oooool2o`000003ooooool0003o000000Oooooo0_l0001Xooooo`007?ooool00ol0003ooooooooo
o`1Mooooo`;o00003Oooool2o`000004ooooool0003o0000o`0000Gooooo0_l0000Tooooo`;o0000
0oooool2o`0000oooooo0_l00005ooooo`;o00003_ooool3o`0000Kooooo1Ol0000;ooooo`;o0000
1oooool2o`0005_ooooo000Looooo`03o`000?oooooooooo05gooooo0_l0000=ooooo`;o00000_oo
ool2o`0000Gooooo0_l0000Fooooo`;o00003?ooool2o`0000Cooooo0_l00007ooooo`;o00006?oo
ool2o`0000;ooooo0ol00005ooooo`Go000000?oooooo`000?l000002Oooool2o`0000Oooooo0_l0
001Kooooo`007?ooool00ol0003oooooooooo`1Tooooo`;o00004Oooool2o`0001Kooooo0_l0000B
ooooo`;o000000?oooooo`000?l000001?ooool2o`0001Sooooo0ol00009ooooo`?o00000oooool2
o`0006oooooo000Looooo`03o`000?oooooooooo05_ooooo0_l00007ooooo`;o00001oooool2o`00
02Gooooo0_l0000@ooooo`;o00000oooool2o`0001[ooooo0ol00008ooooo`;o00001?ooool2o`00
06oooooo000Looooo`03o`000?oooooooooo05;ooooo0ol00002ooooo`;o00000_ooool2o`0000Ko
oooo0ol00007ooooo`;o00001_ooool2o`0001gooooo0_l00009ooooo`;o00001Oooool2o`0000?o
oooo0_l00007ooooo`;o000000?oooooo`000?l000003oooool2o`0002Sooooo0_l0001Eooooo`00
7?ooool00ol0003oooooooooo`1Booooo`?o00000_ooool2o`0000[ooooo0ol00007ooooo`;o0000
1_ooool2o`0001Oooooo0_l000000ooooooo0000o`000004o`0000Sooooo0_l00005ooooo`;o0000
1oooool4o`000004ooooool0003o0000ooooo`?o000000?oooooo`000?l000007Oooool2o`0000So
oooo0_l000000ooooooo0000o`000009ooooo`;o0000EOooool001cooooo00?o0000ooooooooool0
D_ooool2o`0000Gooooo0_l00004ooooo`;o00000oooool2o`0000Oooooo0ol00007ooooo`;o0000
5Oooool9o`0001Sooooo1?l00004ooooo`?o000000?oooooo`000?l000001Oooool2o`0001Kooooo
0_l00008ooooo`;o000000?oooooo`000?l00000H?ooool001cooooo00?o0000ooooooooool0B?oo
ool2o`0000Sooooo0_l00005ooooo`;o00000oooool3o`0000gooooo0_l00007ooooo`;o00005_oo
ool2o`0000Kooooo1Ol000000ooooooo0000o`00000@ooooo`Co00001?ooool2o`0000Wooooo0_l0
0005ooooo`;o00001?ooool3o`0001kooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`18
ooooo`;o00001?ooool2o`0000kooooo0_l00004ooooo`;o0000;?ooool2o`0000?ooooo1Ol00000
0ooooooo0000o`00000Hooooo`;o00004?ooool2o`0000Cooooo0ol0000Nooooo`;o00001oooool2
o`0004kooooo000Looooo`03o`000?oooooooooo04kooooo0_l0000=ooooo`;o00001Oooool2o`00
00;ooooo0ol00004ooooo`;o00001?ooool2o`0001_ooooo0_l0000;ooooo`?o00006?ooool2o`00
01Oooooo0_l00004ooooo`;o00001_ooool4o`0001Cooooo0_l0001>ooooo`007?ooool00ol0003o
ooooooooo`1Looooo`?o00002Oooool3o`0000Cooooo0_l00004ooooo`;o0000:?ooool3o`0000;o
oooo0_l00003ooooo`;o00001Oooool2o`000003ooooool0003o000000Cooooo0ol00009ooooo`?o
00002oooool2o`0000Cooooo0_l00006ooooo`Co0000I?ooool001cooooo00?o0000ooooooooool0
A_ooool2o`0001Cooooo1?l00014ooooo`;o00000oooool2o`0000Cooooo0ol000000ooooooo0000
o`000004ooooo`;o00002?ooool5o`0000_ooooo1?l00003ooooo`;o00003?ooool2o`0005oooooo
000Looooo`;o0000Aoooool4o`0000Gooooo0_l00009ooooo`;o00000_ooool4o`0000?ooooo0_l0
000=ooooo`;o00000_ooool3o`0001_ooooo0_l0000Gooooo`?o000000?oooooo`000?l000003Ooo
ool3o`0000Sooooo0_l00004ooooo`Co00000oooool2o`0000cooooo1?l000000ooooooo0000o`00
001Jooooo`007?ooool00ol0003oooooooooo`18ooooo`;o00001?ooool3o`0000Wooooo0_l00004
ooooo`;o00000oooool2o`0000gooooo0_l000000ooooooo0000o`000002o`00013ooooo0_l00009
ooooo`;o00000_ooool2o`0001Cooooo0_l0000=ooooo`;o000000?oooooo`000?l000002Oooool2
o`0000;ooooo0_l0000Gooooo`;o000000?oooooo`000?l000002?ooool3o`0004oooooo000Loooo
o`03o`000?oooooooooo04Sooooo0_l00002ooooo`Co00001_ooool2o`0000Sooooo0_l00007oooo
o`;o00003?ooool2o`0001;ooooo0_l00003ooooo`;o00002?ooool2o`0001Cooooo0_l00003oooo
o`;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000007ooooo`;o00001?ooool2o`00
00;ooooo0ol00005ooooo`;o00003?ooool2o`0000Sooooo1Ol0001?ooooo`007?ooool00ol0003o
ooooooooo`18ooooo`;o00000_ooool3o`0000Kooooo0ol0000?ooooo`Co00002oooool2o`0000Co
oooo0_l0000@ooooo`Co00008_ooool4o`0000?ooooo1?l00002ooooo`?o00001oooool4o`0000Ko
oooo1?l00004ooooo`Co00002_ooool2o`0000Sooooo0_l0001Booooo`007?ooool00ol0003ooooo
ooooo`14ooooo`;o00001oooool2o`0000Kooooo1?l00002ooooo`;o00002_ooool2o`0000gooooo
0_l000000ooooooo0000o`000003o`00013ooooo1_l0000Cooooo`;o000000?oooooo`000?l00000
0_ooool<o`0000;ooooo1ol00006ooooo`;o00000_ooool2o`0000Cooooo1_l00003ooooo`Oo0000
1oooool2o`0005gooooo000Looooo`03o`000?oooooooooo04Cooooo0_l0000=ooooo`;o00000_oo
ool2o`0000;ooooo0_l0000Looooo`Go00005?ooool2o`0000Kooooo0_l0000;ooooo`Go00000_oo
ool6o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000001ol00004ooooo`?o0000
0_ooool2o`0000Cooooo0_l00007ooooo`Oo00001oooool3o`0005cooooo000Looooo`03o`000?oo
oooooooo04cooooo0_l00005ooooo`;o00002?ooool3o`0000Oooooo0_l0000?ooooo`;o00005_oo
ool2o`0000Sooooo0_l00004ooooo`Co00001?ooool2o`0000Kooooo0_l000000ooooooo0000o`00
0002o`0000Cooooo1Ol000001?oooooo0000o`000?l00002ooooo`Co00000oooool2o`0000Kooooo
0_l00007ooooo`;o00002_ooool3o`0005cooooo000Looooo`03o`000?oooooooooo04_ooooo0ol0
0002ooooo`;o00002oooool3o`0000Oooooo0_l0000?ooooo`;o00001_ooool2o`0000kooooo0_l0
000>ooooo`Co000000?oooooo`000?l000001?l000000ooooooo0000o`000003o`000003ooooool0
003o000000Co00000oooool5o`0000Kooooo0_l000000ooooooo0000o`000003o`000004ooooool0
003o0000ooooo`;o000000?oooooo`000?l000003oooool2o`0000Oooooo0_l00002ooooo`;o0000
E?ooool001cooooo00?o0000ooooooooool0>oooool2o`0000gooooo0ol00003ooooo`;o00000_oo
ool4o`0000kooooo0_l00005ooooo`;o00004Oooool2o`0000Sooooo0_l0000Iooooo`Ko000000?o
ooooo`000?l000000ol000000ooooooo0000o`00000<o`0000Gooooo0_l00002ooooo`Go000000Co
ooooo`000?l0003ooooo0ol00006ooooo`;o00002Oooool2o`0000Oooooo0_l00002ooooo`;o0000
E?ooool001cooooo00?o0000ooooooooool0>oooool2o`0000gooooo0_l00003ooooo`;o00000ooo
ool4o`000003ooooool0003o000000_ooooo0_l00005ooooo`;o00006oooool4o`0000Wooooo0_l0
0003ooooo`;o00001?ooool4o`0000;ooooo0_l00005oooooaSo00000oooool2o`0000?ooooo0_l0
0002ooooo`;o00001Oooool3o`000003ooooool0003o000001Sooooo0_l0001?ooooo`007?ooool0
0ol0003oooooooooo`1?ooooo`;o00002?ooool2o`0002?ooooo0_l0000<ooooo`;o00001_ooool2
o`000004ooooool0003o0000o`0000;ooooo2_l00002ooooo`;o00001_ooool2o`000003ooooool0
003o000001Co000000?oooooo`000?l000000_l000000ooooooo0000o`000002ooooo`;o00001Ooo
ool2o`0000;ooooo0_l00002ooooo`;o00005?ooool2o`0000Cooooo0_l00019ooooo`007?ooool0
0ol0003oooooooooo`1Cooooo`;o00001?ooool2o`0000Cooooo0_l0000Fooooo`Co00000oooool2
o`0001Cooooo2?l00002ooooo`Ko00001Oooool2o`000005ooooool0003o0000o`000?ooool00_l0
0002oooooaGo00000oooool2o`0000Gooooo0_l0000=ooooo`;o00005?ooool2o`0000;ooooo1?l0
0019ooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00001?ooool2o`0000Cooooo0_l00007
ooooo`;o000000?oooooo`000?l000002_ooool4o`0000Wooooo0_l000000ooooooo0000o`00000=
ooooo`;o00000_ooool2o`0000Kooooo0_l00003ooooob3o00001?ooool2o`0000;ooooo0_l00003
ooooo`;o00009_ooool2o`0004_ooooo000Looooo`03o`000?oooooooooo05Oooooo0_l00007oooo
o`;o00001_ooool2o`000003ooooool0003o000000gooooo0_l00008ooooo`;o000000?oooooo`00
0?l000002_ooool2o`0001;ooooo1Ol000000ooooooo0000o`00000Eo`000003ooooool0003o0000
00Cooooo0_l00002ooooo`?o00000_ooool2o`0000Cooooo1?l0001[ooooo`007?ooool00ol0003o
ooooooooo`1;ooooo`;o00000oooool2o`0000Gooooo0_l00007ooooo`Co00002oooool2o`0000?o
oooo0_l00004ooooo`;o00003?ooool2o`0000Wooooo1Ol0000?ooooob3o00000_ooool2o`0000?o
oooo1?l00008ooooo`Co00006?ooool2o`00057ooooo000Looooo`03o`000?oooooooooo04_ooooo
0_l00003ooooo`;o000000Coooooo`000?l0003o00003?ooool2o`0000_ooooo0_l00003ooooo`;o
00004_ooool2o`0000_ooooo0ol00005ooooo`;o00001Oooool2o`000003ooooool0003o000001ko
000000Goooooo`000?l0003o0000ooooo`06o`0000Wooooo0_l00003ooooo`;o00005?ooool4o`00
04oooooo000Looooo`;o0000?oooool4o`00017ooooo0ol0000Gooooo`;o00002Oooool2o`0000go
oooo0_l00006ooooo`;o00003?ooool2o`0000;ooooo1Ol000000ooooooo0000o`00000?o`000003
ooooool0003o000000co000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00006ooooo`;o
000000Coooooo`000?l0003o00000_ooool4o`0001?ooooo0ol0001?ooooo`007?ooool00ol0003o
ooooooooo`0nooooo`Ko00001Oooool2o`0002;ooooo1Ol00006ooooo`;o00003Oooool3o`0000Go
oooo0_l000000ooooooo0000o`000002o`0000_ooooo0ol000001?oooooo0000o`000?oooolTo`00
00Kooooo0_l00004ooooo`Ko00001?ooool2o`0000?ooooo0_l0000<ooooo`Co00001Oooool2o`00
04Wooooo000Looooo`03o`000?oooooooooo04;ooooo1?l00002ooooo`?o00002?ooool2o`0000?o
oooo1?l0000:ooooo`;o00001oooool3o`0000Cooooo1?l000001?oooooo0000o`000?l0000:oooo
o`;o00002?ooool4o`0000oooooo2_l000000ooooooo0000o`00000Jo`0000Kooooo0_l00004oooo
o`Co000000?oooooo`000?l000002?ooool2o`0000cooooo1?l00005ooooo`;o0000BOooool001co
oooo00?o0000ooooooooool0@oooool3o`0000;ooooo0_l00009ooooo`;o00000oooool4o`0000?o
oooo0_l00002ooooo`;o000000?oooooo`000?l000003_ooool3o`0000;ooooo0ol0000Aooooo`;o
00002_ooool2o`0000;ooooo1?l00002oooooaWo00001?ooool6o`0000;ooooo0_l00002ooooo`Oo
00000oooool2o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l00000Hoooool001cooooo
00?o0000ooooooooool0??ooool2o`0000;ooooo0_l00002ooooo`;o00006Oooool2o`0000;ooooo
0_l0000Zooooo`;o00002_ooool3o`000003ooooool0003o000000;o00000_oooolIo`0000?ooooo
1Ol000000ooooooo0000o`000004o`000003ooooool0003o000000Go00003?ooool2o`000003oooo
ool0003o000000Kooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`0looooo`;o00000_oo
ool2o`0001gooooo0_l00004ooooo`Ko00003_ooool3o`0000Cooooo0_l0000Jooooo`;o00000_oo
ool2o`0000;ooooo6Ol000000ooooooo0000o`00000=o`0000gooooo0_l00005ooooo`;o000000?o
ooooo`000?l000000oooool2o`000003ooooool0003o0000017ooooo0_l00018ooooo`007?ooool0
0ol0003oooooooooo`10ooooo`;o00004_ooool2o`0000Wooooo0ol000000ooooooo0000o`000007
o`0000;ooooo0_l00002ooooo`;o00001Oooool3o`0000Cooooo0_l00005ooooo`;o00000oooool2
o`000003ooooool0003o000000[ooooo0_l00002ooooo`?o00000_ooool2o`000003ooooool0003o
0000027o00003?ooool2o`000003ooooool0003o000000;o00001Oooool4o`0000?ooooo1_l0000@
ooooo`;o00001oooool2o`0003oooooo000Looooo`03o`000?oooooooooo04Cooooo0_l000000ooo
oooo0000o`000002ooooo`?o00000oooool2o`000003ooooool0003o000000;o00002?ooool5o`00
00;ooooo1Ol00002ooooo`;o00000_ooool2o`0001?ooooo0_l00003ooooo`;o000000?oooooo`00
0?l000000_ooool2o`0000Kooooo2?l00004oooooaOo000000?oooooo`000?l000002Ol0000<oooo
o`;o000000?oooooo`000?l000000_l00005ooooo`?o00001_ooool4o`0000Gooooo0_l0000Boooo
o`;o0000?oooool001cooooo00?o0000ooooooooool0?oooool2o`0000?ooooo0_l000000ooooooo
0000o`000002ooooo`Go000000?oooooo`000?l000000_l000000ooooooo0000o`000002o`0000So
oooo2_l0000@ooooo`;o00001_ooool2o`0000Oooooo0_l00004ooooo`;o00002?ooool2o`0000;o
oooo0_l000000ooooooo0000o`00000Vo`0000Gooooo0_l00007ooooo`;o00002Oooool2o`0000Co
oooo0_l00007ooooo`;o00000oooool2o`0000Cooooo0_l00018ooooo`007?ooool00ol0003ooooo
ooooo`0oooooo`;o00002_ooool2o`000003ooooool0003o000000?ooooo0_l00003ooooo`;o0000
2Oooool9o`0000;ooooo1Ol00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Kooooo
0_l00007ooooo`;o00003oooool2o`0000Cooooo1ol000000ooooooo0000o`00000No`0000Gooooo
0_l00006ooooo`;o00002_ooool2o`0000Cooooo0_l00002ooooo`;o00002?ooool2o`0000Cooooo
0_l00018ooooo`007?ooool00ol0003oooooooooo`0aooooo`;o000000?oooooo`000?l000003_oo
ool2o`0000Gooooo0_l0000;ooooo`;o00001oooool5o`000003ooooool0003o000000Co000000?o
ooooo`000?l000000ol00002ooooo`;o000000?oooooo`000?l000005?ooool2o`0000[ooooo4Ol0
00001Ooooooo0000o`000?l0003ooooo01_o00002Oooool2o`0000?ooooo1?l0000Booooo`;o0000
3Oooool2o`0000[ooooo0ol0000looooo`007?ooool00ol0003oooooooooo`0aooooo`;o000000?o
ooooo`000?l000002Oooool4o`000003ooooool0003o000000;o00003oooool3o`0000;ooooo0_l0
0003ooooo`?o00000_ooool7o`0000;ooooo1?l00002ooooo`?o00005_ooool2o`0000[ooooo8ol0
00000ooooooo0000o`000006o`000003ooooool0003o000000?o000000?oooooo`000?l000001Ooo
ool2o`0000Gooooo0_l00003ooooo`;o00002_ooool2o`00013ooooo0_l0000:ooooo`?o0000??oo
ool001cooooo00?o0000ooooooooool0?oooool4o`0000?ooooo0_l0000?ooooo`;o00000oooool2
o`0000Sooooo2?l000000ooooooo0000o`000003o`0000;ooooo1ol00003ooooo`?o00002oooool3
o`0000cooooo0_l000000ooooooo0000o`00000To`0000Cooooo1Ol00002ooooo`;o00003Oooool2
o`0000Oooooo0_l000000ooooooo0000o`00000@ooooo`;o0000BOooool001cooooo00?o0000oooo
ooooool0@?ooool2o`0000kooooo0_l00005ooooo`;o000000?oooooo`000?l000001?ooool2o`00
00;ooooo6_l00002ooooo`?o00002oooool3o`0000_ooooo0ol00004ooooob_o00000oooool2o`00
00_ooooo1?l00002ooooo`Co000000Coooooo`000?l0003ooooo0_l0000?ooooo`Go000000?ooooo
o`000?l00000A?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l0
00000ol@413oooooooooo`04ooooo`03o`000?oooooooooo03gooooo0_l00003ooooo`;o00001_oo
ool4o`0000;ooooo0_l00007ooooo`?o00000_oooolQo`000003ooooool0003o000000Wooooo0_l0
000<ooooo`;o000000?oooooo`000?l000000_l00002oooooa7o000000?oooooo`000?l000006ol0
0002ooooo`;o00001_ooool2o`000003ooooool0003o000000;o00000_ooool4o`0000Cooooo0_l0
000?ooooo`;o000000Coooooo`000?l0003ooooo0_l00014ooooo`0000KoooooogMgMonHV9Sooooo
oiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03go
oooo0_l00003ooooo`;o00001_ooool4o`0000_ooooo0_l00003ooooo`?o000000?oooooo`000?l0
00005ol00002ooooo`;o000000?oooooo`000?l000001?ooool2o`0000?ooooo0_l00008ooooo`;o
00000_ooool2o`0000?ooooo1ol00002ooooob3o000000?oooooo`000?l000000_l000000ooooooo
0000o`000002o`000004ooooool0003o0000o`0000Kooooo0_l00002ooooo`Oo00001_ooool2o`00
01Kooooo0_l00013ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`Go
00001_ooool00ol0003oooooooooo`0nooooo`;o00003_ooool2o`0000Wooooo0ol00002ooooo`Co
000000?oooooo`000?l000006Ol00003ooooo`Co000000?oooooo`000?l000003?ooool3o`0000Wo
oooo0_l00003ooooobOo000000?oooooo`000?l000001ol00006ooooo`;o000000?oooooo`000?l0
00000ol00009ooooo`;o00005Oooool2o`0004?ooooo00000ooooooo0000ooooo`02ooooo`03o`00
0?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`0003kooooo0_l000000ooooooo
0000o`00000;ooooo`Co00000oooool2o`0000?ooooo0_l00002ooooob3o00000oooool4o`0000oo
oooo0_l0000:ooooo`;o000000?oooooo`000?l000009?l000001?oooooo0000o`000?l00002oooo
o`Co000000?oooooo`000?l000001_ooool2o`0000oooooo0_l0001Jooooo`0000?oooooo`000?oo
ool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000oooo
ooooool0@Oooool2o`0000_ooooo1Ol00002ooooo`;o00001Oooool2o`000003ooooool0003o0000
01oo00004Oooool2o`0000gooooo0_l000000ooooooo0000o`00000Yo`0000Kooooo0_l0000Eoooo
o`Co000000?oooooo`000?l00000Eoooool00003ooooool@413ooooo00;ooooo00?o410@oooooooo
ool02_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo047ooooo0_l00007ooooo`;o
00001Oooool2o`0000;ooooo0_l00003ooooo`Co000000?oooooo`000?l000005?l000000ooooooo
0000o`000008o`0000Oooooo0ol00007ooooo`?o00000oooool2o`0000[ooooo0_l000001Ooooooo
0000o`000?l0003ooooo01go00000_ooool5o`0000_ooooo0_l0000@ooooo`;o00000_ooool3o`00
05Oooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l000001oooool0
0ol0003oooooooooo`11ooooo`;o00001oooool2o`0000Gooooo0_l00003ooooo`?o000000?ooooo
o`000?l000000_oooolRo`000003ooooool0003o000000Cooooo0ol00008ooooo`;o00000oooool2
o`0000?ooooo0_l00004ooooo`Co000000?oooooo`000?l000007_l00005ooooo`;o000000?ooooo
o`000?l000002?ooool2o`0001Cooooo0_l0000Aooooo`;o00003_ooool2o`0003Gooooo00001_oo
ooook^k^oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooooooo
o`0nooooo`;o00004Oooool2o`0000?ooooo0ol00002ooooo`;o000000?oooooo`000?l000007ol0
0002ooooo`;o00006Oooool2o`000004ooooool0003o0000ooooob?o00002_ooool2o`0000oooooo
0_l0000Pooooo`;o00003_ooool2o`0003Gooooo000Looooo`03o`000?oooooooooo03Sooooo0_l0
00001?oooooo0000o`000?ooool2o`0001_ooooo0ol00003ooooob3o00002_ooool3o`0000Cooooo
0_l0000;ooooo`;o000000?oooooo`000?l000000ol00002oooooago000000?oooooo`000?l00000
2Oooool2o`000003ooooool0003o000000Wooooo0_l000000ooooooo0000o`000002o`0000Cooooo
0_l000000ooooooo0000o`00000Cooooo`;o00002_ooool2o`0003Sooooo000Looooo`03o`000?oo
oooooooo03;ooooo0_l00004ooooo`;o000000Coooooo`000?l0003o00006_ooool2o`000004oooo
ool0003o0000o`0000Cooooo7ol00002ooooo`?o00001Oooool3o`0000;ooooo1?l0000;ooooo`Co
00000_ooool2o`0000;ooooo7Ol000001?oooooo0000o`000?l00004ooooo`;o00000_ooool5o`00
00?ooooo0_l00007ooooo`Co00001?ooool2o`000003ooooool0003o0000013ooooo0_l000000ooo
oooo0000o`00000:ooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0<_ooool2o`0000?o
oooo0_l00002ooooo`Go00002oooool2o`0000_ooooo1Ol00004oooooa3o000000?oooooo`000?l0
00003Ol000000ooooooo0000o`000002o`0000[ooooo0_l0000?ooooob?o000000?oooooo`000?l0
00000ol000001?oooooo0000o`000?ooool2o`0000Cooooo0_l00002ooooo`Co00003oooool2o`00
00;ooooo0_l0000?ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0=oooool2o`000003
ooooool0003o000000Co00002oooool2o`0000gooooo9ol000001?oooooo0000o`000?l00009oooo
o`Co00003_oooolSo`0000;ooooo0ol000000ooooooo0000o`000003o`0000[ooooo0_l00004oooo
o`;o00003Oooool5o`0001?ooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o
00002_ooool2o`0000Cooooo0_l0000Gooooo`;o000000?oooooo`000?l000008_l00002ooooo`;o
00002_ooool2o`00013ooooo0ol00003ooooo`;o00001?oooolDo`0000?ooooo0ol000000ooooooo
0000o`000002o`000003ooooool0003o0000013ooooo0_l000000ooooooo0000o`00000:ooooo`Oo
00003Oooool2o`0000;ooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o0000
00?oooooo`000?l000002Oooool2o`000004ooooool0003o0000o`0001Oooooo0_l00005ooooo`oo
000000?oooooo`000?l000004_l00002ooooo`;o00002?ooool4o`0000gooooo0_l00003ooooo`[o
000000?oooooo`000?l000003?l00003ooooo`So000000?oooooo`000?l000000oooool2o`0000So
oooo0_l00002ooooo`;o000000?oooooo`000?l000000_l00006ooooo`;o00000_ooool2o`000003
ooooool0003o000000gooooo0_l00002ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0
<Oooool2o`0000Gooooo1_l000001?oooooo0000o`000?l00003ooooo`Co00001Oooool2o`0000Oo
oooo0_l00007ooooo`ko000000?oooooo`000?l000004Ol00004ooooo`;o00002?ooool4o`0000go
oooo1?l00002oooooaGo00001?ooool7o`000004ooooool0003o0000ooooo`;o00000oooool3o`00
00Oooooo0_l00002ooooo`?o00000_ooool2o`000003ooooool0003o000000?ooooo0_l00008oooo
o`;o00003_ooool2o`0000?ooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0booooo`;o
00001?ooool5o`0000?ooooo0_l00003ooooo`Co00001Oooool2o`0000Oooooo0ol00004ooooo`;o
00000_ooool8o`000003ooooool0003o000000ko000000Coooooo`000?l0003o00004?ooool2o`00
01;ooooo1?l00002ooooob7o00001oooool2o`0000_ooooo0ol00005ooooo`Co00001oooool2o`00
00;ooooo0_l0000<ooooo`;o00001Oooool2o`0003gooooo000Looooo`03o`000?oooooooooo03;o
oooo0_l00005ooooo`;o00007Oooool2o`0000;ooooo1?l00002ooooo`?o00000ooooolHo`0000So
oooo0_l00005ooooo`;o00001oooool2o`0000Cooooo0_l00004ooooo`go00000oooool=o`0000Go
oooo0_l0000Pooooo`;o00001oooool2o`00013ooooo0_l00004ooooo`;o00002Oooool2o`0003?o
oooo000Looooo`03o`000?oooooooooo03;ooooo1?l00002ooooo`;o00001_ooool2o`0000?ooooo
0ol0000<ooooo`;o000000?oooooo`000?l000000oooool2o`0000Cooooo0_l00002oooooa_o0000
1Oooool4o`0000_ooooo0_l000000ooooooo0000o`000004ooooo`;o00001oooool2o`000004oooo
ool0003o0000ooooo`Co00000oooool:o`0000;ooooo1?l00009ooooo`;o00006Oooool2o`0000So
oooo0_l0000<ooooo`?o00000_ooool2o`0000;ooooo0_l00009ooooo`;o0000<oooool001cooooo
00?o0000ooooooooool0<_ooool4o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o0000
0oooool3o`0000cooooo0_l000001?oooooo0000o`000?l00008ooooo`;o00000_ooool2o`000003
ooooool0003o000001?o000000Coooooo`000?l0003o00001?ooool2o`0000_ooooo1?l0000:oooo
o`;o00001_ooool3o`000003ooooool0003o000000Oooooo2?l000000ooooooo0000o`000004o`00
00Gooooo0_l000000ooooooo0000o`000008ooooo`;o000000?oooooo`000?l000000oooool4o`00
00Gooooo0_l00008ooooo`;o00003?ooool3o`0000;ooooo1?l00010ooooo`007?ooool2o`0003co
oooo0_l00004ooooo`Co00000oooool2o`0000kooooo0_l000000ooooooo0000o`000005ooooo`;o
00000_ooool2o`000003ooooool0003o000001?o00000_ooool2o`00017ooooo1?l00007ooooo`;o
000000?oooooo`000?l000001?ooool7o`000003ooooool0003o000000Cooooo2Ol000000ooooooo
0000o`000004o`0000Gooooo0_l000000ooooooo0000o`000006ooooo`Co000000?oooooo`000?l0
00000oooool4o`0000Wooooo0_l00002ooooo`Ko00003_ooool2o`000003ooooool0003o0000043o
oooo000Looooo`03o`000?oooooooooo047ooooo1?l000000ooooooo0000o`000002o`0000;ooooo
0_l0000=ooooo`;o00002Oooool2o`0000?ooooo2ol000000ooooooo0000o`000004o`000003oooo
ool0003o000000?ooooo0_l0000?ooooo`?o00000oooool2o`0000;ooooo0_l00007ooooo`;o0000
0oooool6o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool6o`000004oooo
ool0003o0000o`0000;ooooo0ol00006ooooo`?o000000?oooooo`000?l000003?ooool2o`0000?o
oooo0_l00002ooooo`;o00000_ooool2o`0000kooooo0_l00013ooooo`007?ooool00ol0003ooooo
ooooo`0cooooo`;o00001oooool2o`0000Gooooo0_l000000ooooooo0000o`000002o`0000;ooooo
0_l00002ooooo`;o00002Oooool2o`0000Oooooo0_l00007ooooo`[o000000?oooooo`000?l00000
0ol000000ooooooo0000o`000003ooooo`;o00005Oooool2o`0000Gooooo0_l0000:ooooo`So0000
1?ooool2o`000003ooooool0003o000000;ooooo1_l000000ooooooo0000o`000006o`0000Oooooo
0_l000000ooooooo0000o`00000<ooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0<ooo
ool2o`0000Oooooo0_l0000@ooooo`Co00004_ooool2o`0000?ooooo0_l00003ooooo`?o000000?o
ooooo`000?l000001ol0000;ooooo`;o00006Oooool2o`0000Wooooo1?l00002ooooo`[o00000ooo
ool3o`000003ooooool0003o000000Gooooo0_l0000kooooo`?o0000?oooool001cooooo00?o0000
ooooooooool0=_ooool2o`0000Wooooo0_l0000;ooooo`;o00001oooool2o`0000Sooooo0_l00006
ooooo`;o00000oooool5o`000003ooooool0003o000000?o000000?oooooo`000?l000002_ooool2
o`000003ooooool0003o000000Cooooo0_l00006ooooo`;o00003Oooool2o`0000Cooooo0_l00005
ooooo`Wo00000_ooool3o`0001Oooooo1?l0000;ooooo`;o00001?ooool2o`0000;ooooo0_l0000C
ooooo`Co0000?oooool001cooooo00?o0000ooooooooool0=_ooool2o`0000Cooooo0_l00003oooo
o`?o00001_ooool2o`0000Kooooo0_l000000ooooooo0000o`000002o`0000Sooooo0_l0000;oooo
o`;o000000?oooooo`000?l000002Ol0000=ooooo`;o00001?ooool2o`0000Kooooo1?l0000;oooo
o`;o00002Oooool2o`0000Oooooo0_l00002ooooo`?o00005oooool4o`0000Gooooo0_l00004oooo
o`;o00001?ooool2o`0000;ooooo0_l00002ooooo`?o00002?ooool2o`0000;ooooo1Ol00005oooo
o`;o00003oooool2o`0002Sooooo000Looooo`03o`000?oooooooooo02gooooo0_l00005ooooo`;o
00001_ooool2o`0000Cooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000?o
oooo0_l000000ooooooo0000o`000003o`0000Gooooo0_l0000Eooooo`Oo00003oooool2o`0000Wo
oooo0_l00003ooooo`;o00005_ooool2o`0000Cooooo0_l00008ooooo`;o00003?ooool6o`0000?o
oooo0_l00003ooooo`Ko00001?ooool2o`0000cooooo0ol00008ooooo`;o00000_ooool2o`000003
ooooool0003o000000Gooooo0_l0000?ooooo`;o0000:?ooool001cooooo00?o0000ooooooooool0
;Oooool2o`0000Gooooo0_l00003ooooo`;o00000oooool2o`0000Gooooo1?l00006ooooo`;o0000
0oooool2o`0000Kooooo0_l0000?ooooo`;o00001?ooool6o`0000Kooooo0_l00003ooooo`;o0000
0oooool2o`0000Wooooo0_l00003ooooo`;o00005_ooool2o`0000Cooooo0_l00008ooooo`;o0000
2?ooool2o`0000;ooooo1_l00002ooooo`;o00001?ooool5o`0000Cooooo0ol0000Sooooo`;o0000
2oooool2o`0002kooooo000Looooo`03o`000?oooooooooo03;ooooo1?l00003ooooo`Co000000?o
ooooo`000?l000000oooool2o`000003ooooool0003o000001;ooooo0_l0000>ooooo`Go00001ooo
ool2o`0000;ooooo0_l00003ooooo`?o00000_ooool2o`0000?ooooo0_l0000=ooooo`Co00004?oo
ool3o`0000?ooooo0_l0000Cooooo`;o00000_ooool2o`0000?ooooo1?l00003ooooo`Co00001Ooo
ool2o`0000Cooooo0_l00004ooooo`;o00002Oooool2o`0000kooooo0_l00003ooooo`;o00002ooo
ool2o`0002kooooo000Looooo`03o`000?oooooooooo03;ooooo0ol00006ooooo`;o00001_ooool2
o`000003ooooool0003o000000Oooooo0_l00009ooooo`;o00003_ooool9o`0000Oooooo0_l00004
ooooo`;o00005?ooool6o`0000;ooooo0_l0000<ooooo`?o00000oooool2o`0000;ooooo0_l00008
ooooo`?o00001?ooool2o`0000Wooooo0_l00004ooooo`?o00000oooool2o`0000Gooooo0_l00005
ooooo`Co00001oooool2o`0000kooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`15oooo
o`;o000000?oooooo`000?l000000_l00003ooooo`;o00000_ooool2o`0000Cooooo1?l0000Aoooo
o`Go00008oooool2o`0000;ooooo0_l00002ooooo`;o00005_ooool2o`0000Sooooo0ol00008oooo
o`;o00000oooool2o`0000cooooo0_l000000ooooooo0000o`000005o`0000Kooooo0_l00009oooo
o`;o00000oooool2o`0000cooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`15ooooo`;o
000000?oooooo`000?l000000_l00007ooooo`;o00000oooool5o`0001;ooooo0_l00007ooooo`;o
00000oooool2o`0000oooooo0_l0000:ooooo`;o00000_ooool2o`0001kooooo0ol0000:ooooo`Oo
00000_ooool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`Wo000000?oooooo`000?l0
00001?l00004ooooo`;o00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000009ooooo`;o
0000>oooool001cooooo00?o0000ooooooooool0<oooool2o`0000Kooooo0_l00008ooooo`;o0000
00?oooooo`000?l000000oooool2o`0000Wooooo1?l0000Cooooo`;o00001oooool2o`0000?ooooo
0_l0000?ooooo`;o00001_ooool4o`0000Cooooo0_l000000ooooooo0000o`00000Aooooo`;o0000
1oooool4o`0000cooooo1?l00003ooooo`;o000000?oooooo`000?l000001?ooool3o`0000Gooooo
1Ol000000ooooooo0000o`000004o`0000Cooooo0ol000000ooooooo0000o`000006ooooo`;o0000
A_ooool001cooooo00?o0000ooooooooool0<oooool2o`0000Kooooo0_l00008ooooo`;o00001?oo
ool4o`0000Kooooo0_l00003ooooo`;o00004Oooool4o`0001Kooooo0ol00008ooooo`;o00000_oo
ool4o`0000Oooooo0_l0000Aooooo`;o00001oooool2o`0000Kooooo0_l0000=ooooo`;o00002?oo
ool2o`0000Oooooo0_l0000<ooooo`?o000000?oooooo`000?l000000_l0000Looooo`;o0000;_oo
ool001cooooo00?o0000ooooooooool0>oooool2o`0000[ooooo0_l00002ooooo`;o00002?ooool2
o`0001Kooooo0_l0000Hooooo`?o00002?ooool4o`0000Cooooo0_l00004ooooo`;o00001_ooool2
o`0000[ooooo0_l00007ooooo`;o00001_ooool2o`0000;ooooo0_l00003ooooo`;o00003oooool2
o`0000Kooooo0_l00003ooooo`;o00001oooool2o`0000Cooooo0_l00002ooooo`;o00006?ooool2
o`0002kooooo000Looooo`03o`000?oooooooooo03?ooooo1Ol00003ooooo`;o00002?ooool4o`00
01gooooo0_l0000Rooooo`;o00001_ooool4o`0000Cooooo0_l00004ooooo`Go00000oooool2o`00
01?ooooo0_l0000:ooooo`;o00000oooool2o`0000kooooo0ol000000ooooooo0000o`000002oooo
o`?o00000oooool4o`0000Kooooo0_l00004ooooo`;o000000?oooooo`000?l00000B?ooool001co
oooo0_l0000dooooo`Go00002oooool4o`0000Kooooo0_l000001?oooooo0000o`000?l00006oooo
o`Ko00000oooool2o`0000;ooooo1?l0000?ooooo`;o00002oooool2o`0000;ooooo0_l00006oooo
o`;o00003Oooool5o`0000cooooo0_l0000Mooooo`;o00002oooool2o`0000;ooooo0_l00002oooo
o`?o00001Oooool3o`0000Gooooo0_l00004ooooo`;o000000?oooooo`000?l000002?ooool2o`00
03kooooo000Looooo`03o`000?oooooooooo03Gooooo0_l0000<ooooo`;o00000_ooool2o`0000?o
oooo0ol000001?oooooo0000o`000?l00002ooooo`;o00000_ooool6o`0000?ooooo0_l00003oooo
o`?o00000_ooool2o`0000_ooooo0_l00006ooooo`;o00000oooool2o`0001_ooooo1Ol0000:oooo
o`;o00007Oooool2o`0000Gooooo0_l00004ooooo`;o00000_ooool2o`0000?ooooo0_l00005oooo
o`?o00003oooool2o`0000Oooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`17ooooo`Co
000000?oooooo`000?l000001oooool2o`0000Cooooo0_l0000?ooooo`;o00001Oooool3o`0000_o
oooo0_l0000:ooooo`;o00005?ooool8o`0000_ooooo0_l00003ooooo`;o00006Oooool4o`0000So
oooo0_l00002ooooo`;o00004?ooool2o`0000Kooooo1?l00008ooooo`;o0000>oooool001cooooo
00?o0000ooooooooool0:_ooool2o`00017ooooo0_l00003ooooo`;o00001Oooool2o`0001oooooo
0_l00007ooooo`Go00002?ooool3o`0000Wooooo0ol00004ooooo`;o00003_ooool3o`000003oooo
ool0003o000000;o00001?ooool2o`0000Gooooo0_l00003ooooo`;o00006Oooool2o`0000kooooo
0_l0000@ooooo`;o00001_ooool4o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0003_o
oooo000Looooo`03o`000?oooooooooo02[ooooo0_l00004ooooo`;o00002oooool2o`0000?ooooo
0_l0000Aooooo`;o00001_ooool2o`0000Sooooo0_l000000ooooooo0000o`00000:ooooo`;o0000
1oooool3o`0000[ooooo0_l00002ooooo`;o000000?oooooo`000?l000003oooool3o`0000Sooooo
0_l00006ooooo`;o00003_ooool2o`0000Kooooo0ol0000Aooooo`;o00001_ooool3o`0000Oooooo
0_l00009ooooo`;o00000oooool5o`0003oooooo000Looooo`03o`000?oooooooooo033ooooo0_l0
0005ooooo`;o00007?ooool6o`0000;ooooo0_l00008ooooo`;o00000oooool4o`0000[ooooo0_l0
0003ooooo`?o00001?ooool2o`0000Sooooo0_l0000Cooooo`Co000000?oooooo`000?l000002ooo
ool2o`0000?ooooo0_l00009ooooo`Co00001?ooool3o`00013ooooo0ol00002ooooo`;o00000_oo
ool3o`0000Oooooo0ol0000>ooooo`Co00000oooool2o`0000Wooooo0_l0000_ooooo`007?ooool0
0ol0003oooooooooo`0`ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Sooooo0_l00002
ooooo`;o00000oooool2o`0000_ooooo1?l0000Aooooo`Co00002_ooool3o`0000?ooooo0_l00000
1?oooooo0000o`000?ooool2o`0001Sooooo0_l00004ooooo`Ko00002oooool2o`0000?ooooo0_l0
0004ooooo`;o00001Oooool2o`0001Oooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l0
0008ooooo`?o00001?ooool2o`0000Wooooo0ol00003ooooo`;o00002Oooool2o`0002oooooo000L
ooooo`03o`000?oooooooooo033ooooo0_l000000ooooooo0000o`00000<ooooo`;o00000_ooool2
o`0000?ooooo0_l0000_ooooo`;o00001_ooool2o`0000;ooooo0_l0000Gooooo`;o00001_ooool2
o`0000?ooooo0ol0000Booooo`;o00003?ooool2o`0001?ooooo1?l0000Booooo`?o00002_ooool2
o`0003oooooo000Looooo`03o`000?oooooooooo033ooooo0_l00005ooooo`;o00002?ooool3o`00
01kooooo0_l0000Aooooo`;o00001_ooool2o`0000Gooooo0_l000000ooooooo0000o`00000Koooo
o`;o00001?ooool2o`000003ooooool0003o000000Wo00002oooool3o`0000Gooooo0_l00003oooo
o`;o00007Oooool3o`0000Wooooo0_l00003ooooo`;o00003?ooool2o`0003Wooooo000Looooo`03
o`000?oooooooooo02oooooo0ol00005ooooo`;o00002Oooool3o`0000Sooooo0_l000000ooooooo
0000o`00000@ooooo`;o00004?ooool3o`0000Kooooo0_l00005ooooo`;o00003Oooool2o`0000Oo
oooo0_l00006ooooo`;o00001?ooool3o`0000?ooooo2_l000001?oooooo0000o`000?ooool3o`00
00;ooooo0ol000000ooooooo0000o`000002ooooo`Co00001oooool2o`0000oooooo0_l00002oooo
o`;o00000_ooool3o`0000;ooooo0_l0000:ooooo`;o00003?ooool2o`0003Wooooo000Looooo`03
o`000?oooooooooo02oooooo0ol0000=ooooo`;o00000_ooool2o`0000Gooooo1Ol000000ooooooo
0000o`00000Jooooo`;o00001_ooool2o`0000Gooooo1Ol0000>ooooo`;o00000oooool2o`000003
ooooool0003o000000Cooooo1?l00004ooooo`;o00001Oooool2o`0000Kooooo0_l00003ooooo`Go
000000Coooooo`000?l0003o00001_ooool2o`0000Cooooo0_l00006ooooo`?o00000oooool2o`00
00[ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00004?ooool2o`00
0003ooooool0003o000000Gooooo0_l00004ooooo`;o0000<Oooool001cooooo00?o0000oooooooo
ool0?oooool2o`0000Wooooo1?l0000Jooooo`;o00000_ooool2o`000003ooooool0003o000000So
oooo1ol00004ooooo`;o00001Oooool2o`000003ooooool0003o000000Cooooo1?l00006ooooo`;o
00000oooool4o`0001?ooooo0_l00002ooooo`;o00003Oooool2o`0000Kooooo0_l00004ooooo`Co
00001Oooool2o`0000Sooooo0_l0000@ooooo`;o00001?ooool5o`0000Gooooo0_l00004ooooo`;o
0000<Oooool001cooooo00?o0000ooooooooool0<?ooool2o`0000gooooo0_l00002ooooo`;o0000
1oooool3o`0001Wooooo0_l000000ooooooo0000o`000002ooooo`Go00001Oooool2o`0000Wooooo
0_l00005ooooo`;o00001oooool2o`000003ooooool0003o000000?o00001oooool4o`0000[ooooo
1?l00009ooooo`Co00002oooool2o`000003ooooool0003o000000Oo00000oooool3o`0000Gooooo
0_l00009ooooo`;o00003oooool2o`0000Gooooo0_l00010ooooo`007?ooool00ol0003ooooooooo
o`0Yooooo`;o00001Oooool2o`0000Gooooo0_l0000:ooooo`;o00001_ooool4o`0000;ooooo0_l0
000;ooooo`;o00000oooool2o`0000?ooooo0_l000001?oooooo0000o`000?l00003ooooo`?o0000
8oooool5o`0000Gooooo0_l0000>ooooo`Co00000oooool2o`000004ooooool0003o0000o`0000;o
oooo0_l00002ooooo`;o00001?ooool?o`0000?ooooo0_l00009ooooo`;o00001_ooool2o`0000Wo
oooo0_l000000ooooooo0000o`000009ooooo`;o00001?ooool2o`0003Wooooo000Looooo`03o`00
0?oooooooooo02Wooooo0_l00005ooooo`;o00000oooool4o`0000;ooooo0_l00003ooooo`;o0000
00?oooooo`000?l000001_ooool3o`000003ooooool0003o000000?o00002Oooool3o`0000?ooooo
0_l00006ooooo`?o00001oooool6o`000003ooooool0003o000000;o00008Oooool2o`0001Gooooo
0_l000001?oooooo0000o`000?l00006ooooo`;o00001?oooolAo`0000_ooooo0ol0000Aooooo`;o
000000?oooooo`000?l000002Oooool3o`0000?ooooo0_l0000iooooo`007?ooool00ol0003ooooo
ooooo`0`ooooo`;o00000oooool2o`0000Cooooo0_l00003ooooo`;o000000?oooooo`000?l00000
1Oooool4o`000004ooooool0003o0000ooooo`;o00002Oooool2o`0000cooooo0_l00008ooooo`Ko
000000?oooooo`000?l000000_l0000:ooooo`;o00001_ooool2o`0000?ooooo0_l0000Mooooo`;o
00000oooool2o`0000Oooooo0_l00002oooooa?o00002Oooool5o`0000kooooo1?l0000>ooooo`?o
0000?Oooool001cooooo0_l0000fooooo`;o00004Oooool5o`0000kooooo0_l0000Eooooo`;o0000
00?oooooo`000?l000000ol00004ooooo`;o00000_ooool2o`0000Cooooo1?l00003ooooo`;o0000
00?oooooo`000?l000000oooool2o`0001gooooo0_l0000@oooooa;o00002?ooool4o`000003oooo
ool0003o000000Cooooo0_l00003ooooo`;o00000oooool5o`0000?ooooo0_l00009ooooo`;o0000
?Oooool001cooooo00?o0000ooooooooool0=?ooool4o`0000[ooooo0_l00004ooooo`;o000000?o
ooooo`000?l000003_ooool4o`0000?ooooo0_l00004ooooo`;o00002?ooool2o`000003ooooool0
003o000000?o000000?oooooo`000?l000001ol00004ooooo`;o00001Oooool:o`00013ooooo0_l0
00000ooooooo0000o`000002ooooo`;o000000Coooooo`000?l0003ooooo1?l0000=ooooo`ko0000
00?oooooo`000?l000002?l00002ooooo`;o00002Oooool2o`0000?ooooo1?l00004ooooo`;o0000
0oooool2o`0000Gooooo0_l00005ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool09_oo
ool2o`0000Sooooo0_l00002ooooo`Co00000_ooool2o`0000Kooooo0_l00003ooooo`;o00005?oo
ool2o`0000?ooooo0_l00004ooooo`;o00002?oooolAo`0000_ooooo2_l00002ooooo`;o00003Ooo
ool2o`000005ooooool0003o0000o`000?ooool00_l000000ooooooo0000o`000007o`0000Kooooo
0_l00003ooooo`Co000000?oooooo`000?l000004_l00004ooooo`?o00001_ooool2o`0000?ooooo
1?l00003ooooo`;o00001?ooool2o`0000Gooooo0_l00005ooooo`;o0000>_ooool001cooooo00?o
0000ooooooooool09_ooool2o`0000Kooooo1?l00006ooooo`Co00002Oooool4o`0001cooooo0ol0
0003ooooo`;o00001_ooool?o`000003ooooool0003o000000Wooooo0_l0000:ooooo`;o00000_oo
ool4o`0000[ooooo1Ol00003ooooo`Co00000_ooool2o`0000Kooooo0_l000001?oooooo0000o`00
0?ooool3o`0000;ooooo4ol00004ooooo`?o00001_ooool2o`0000?ooooo0_l00005ooooo`;o0000
00?oooooo`000?l00000Boooool001cooooo00?o0000ooooooooool0;_ooool3o`0000?ooooo0_l0
0002ooooo`;o00002oooool2o`0001cooooo1Ol00003ooooo`;o00001?ooool:o`000003ooooool0
003o000000Oo00003Oooool2o`0000[ooooo1?l00009ooooo`So00000_ooool2o`0000?ooooo0_l0
0006ooooo`;o000000?oooooo`000?l000001?l000000ooooooo0000o`00000Bo`0000?ooooo0_l0
000Gooooo`;o00002Oooool2o`0001[ooooo0_l0000Tooooo`007?ooool00ol0003oooooooooo`0`
ooooo`;o00000_ooool3o`0001Oooooo0_l0000Cooooo`Go00002?oooolEo`0000gooooo0_l00005
ooooo`;o000000?oooooo`000?l000001?l00008ooooo`Co00000oooool2o`0000;ooooo0_l00000
0ooooooo0000o`000003o`0000Gooooo0_l00002oooooa[o00000oooool2o`0000Oooooo0_l0000G
ooooo`Co00000oooool2o`0001Gooooo0_l0000Tooooo`007?ooool00ol0003oooooooooo`0`oooo
o`;o00000oooool2o`0001?ooooo1_l000000ooooooo0000o`00000Aooooo`?o00002?oooolGo`00
00Sooooo0_l00005ooooo`?o000000?oooooo`000?l000001ol00008ooooo`?o00002?ooool5o`00
0003ooooool0003o000000_ooooo6_l00002ooooo`;o00001_ooool2o`0000[ooooo0_l0000;oooo
o`;o000000?oooooo`000?l000000_ooool2o`0003_ooooo000Looooo`03o`000?oooooooooo02ko
oooo0_l00002ooooo`;o00005?ooool6o`0000?ooooo0_l0000Looooo`go000000?oooooo`000?l0
00002?l00007ooooo`;o00001Oooool3o`0000?ooooo0_l0000Hooooo`Co00003ooooolBo`000003
ooooool0003o000000Ko000000?oooooo`000?l000000_ooool4o`0000cooooo0_l000000ooooooo
0000o`00000;ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0;_ooool6o`0001Cooooo
0_l00007ooooo`;o00001Oooool2o`0000[ooooo0_l00006ooooo`;o000000?oooooo`000?l00000
6_l00009ooooo`;o00003Oooool2o`0000Kooooo0_l0000:ooooo`;o00000oooool2o`0000_ooooo
6ol00004ooooo`Co00003oooool2o`000003ooooool0003o000004Wooooo000Looooo`03o`000?oo
oooooooo033ooooo0_l0000?ooooo`;o00001?ooool2o`0000Sooooo0_l00003ooooo`Co000000?o
ooooo`000?l000001_ooool3o`0000Kooooo0_l000000ooooooo0000o`00000Lo`0000Oooooo0_l0
0005ooooo`;o00001_ooool2o`0000?ooooo1Ol0000:ooooo`;o00000_ooool3o`0000Sooooo0_l0
0002oooooa_o000000?oooooo`000?l000005_ooool2o`0000Kooooo0_l00011ooooo`007?ooool0
0ol0003oooooooooo`0aooooo`;o00003_ooool2o`0000Cooooo0_l00002ooooo`;o00002?ooool4
o`000004ooooool0003o0000o`0000Cooooo1?l00008ooooo`;o000000?oooooo`000?l000006ol0
000<ooooo`Co00002_ooool4o`0000Sooooo0_l00002ooooo`;o00000_ooool4o`0000Cooooo0_l0
00000ooooooo0000o`000002oooooaKo000000?oooooo`000?l000000_l000001?oooooo0000o`00
0?l0000Fooooo`;o00001Oooool2o`00047ooooo000Looooo`03o`000?oooooooooo037ooooo0ol0
000Aooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o00000_ooool4o`000003oooo
ool0003o000000?ooooo1?l000000ooooooo0000o`000007ooooo`;o000000?oooooo`000?l00000
6Ol000000ooooooo0000o`000004ooooo`;o00001Oooool2o`0000cooooo0_l00007ooooo`;o0000
00?oooooo`000?l000002?ooool2o`0000Cooooo0_l00003oooooaSo000000Coooooo`000?l0003o
oooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000Cooooo0_l00002oooo
o`?o00001?ooool3o`0000Wooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0aooooo`?o
00000_ooool2o`0000gooooo0_l000000ooooooo0000o`000002ooooo`Oo00001?ooool2o`0000Co
oooo1Ol000001?oooooo0000o`000?l00005ooooo`Co000000?oooooo`000?l000002Ol000000ooo
oooo0000o`00000=o`000003ooooool0003o000000?ooooo0ol00002ooooo`?o00002_ooool2o`00
00Gooooo0_l00004ooooo`;o000000?oooooo`000?l000000_l0000=ooooo`;o000000?oooooo`00
0?l000006Ol00002ooooo`;o00001?ooool2o`000003ooooool0003o000000Cooooo0_l00002oooo
o`?o00001?ooool2o`0000[ooooo0ol0000looooo`007?ooool00ol0003oooooooooo`0booooo`;o
00000_ooool2o`0000Sooooo0_l0000:ooooo`Ko00000_ooool2o`0000Oooooo2?l00002ooooo`;o
000000Coooooo`000?l0003o00000_ooool=o`0000;ooooo1Ol000000ooooooo0000o`000004o`00
00Oooooo0_l00003ooooo`?o00002_ooool2o`0000Gooooo0_l00009ooooo`?o00001_ooool2o`00
00Cooooo0_l000000ooooooo0000o`00000Co`0000;ooooo1?l0000Rooooo`;o00001Oooool2o`00
03cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o
0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0fooooo`;o00002?ooool2o`0000oooooo1Ol0
00000ooooooo0000o`000007ooooo`Ko000000Coooooo`000?l0003ooooo0_l000000ooooooo0000
o`00000Mo`0000;ooooo0_l0000Vooooo`;o00001_ooool4o`0000Kooooo5?l00003ooooo`;o0000
8oooool2o`000003ooooool0003o0000043ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`10oooo
o`;o00003oooool4o`0000;ooooo0_l00007ooooo`;o00000_ooool2o`0000Oooooo7ol00002oooo
o`Co0000:Oooool2o`0000;ooooo0ol00005ooooo`;o000000?oooooo`000?l000003ol00004oooo
o`;o000000?oooooo`000?l000001_ooool2o`0000gooooo0_l0000<ooooo`;o0000@?ooool00003
ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool0;_ooool4o`0000;ooooo0_l00004ooooo`;o00002Oooool2o`00
0003ooooool0003o000000;o00008OoooolPo`0000?ooooo1?l0000Cooooo`;o00001oooool2o`00
0003ooooool0003o000000Kooooo0_l00002ooooo`;o00001_ooool2o`0000Cooooo0ol00002oooo
o`;o000000?oooooo`000?l000002_ooool3o`0000Kooooo0_l0000=ooooo`;o00003Oooool2o`00
03oooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oiRHV?oo
ooooV9RHob4Q8@06ooooo`?o0000;?ooool6o`0000;ooooo0_l00004ooooo`;o00002Oooool7o`00
027ooooo7?l000001?oooooo0000o`000?l00005ooooo`;o00004oooool3o`0000?ooooo0_l00000
0ooooooo0000o`000003o`0000Wooooo0_l0000=ooooo`?o00001Oooool2o`0000[ooooo0_l0000U
ooooo`;o0000?oooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0
003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0;?ooool2o`0000Cooooo0_l00002
ooooo`;o00000_ooool2o`0000_ooooo0_l00005ooooo`;o00003Oooool2o`0000gooooo0_l00000
0ooooooo0000o`00000Lo`0001_ooooo1?l000000ooooooo0000o`000007o`0000Sooooo0_l0000E
ooooo`Co00003oooool2o`0000Cooooo0_l0000:ooooo`;o00001?ooool2o`0000Gooooo0_l00010
ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`03oeEEEOn7QhOooooo
00Sooooo00?o0000ooooooooool0;oooool2o`000005ooooool0003o0000o`000?ooool00_l0000F
ooooo`;o00000_ooool2o`0000Wooooo0_l0000=ooooo`;o00000_oooolMo`00013ooooo0_l00009
ooooo`Co000000?oooooo`000?l000002Ol0000Fooooo`Co00001Oooool2o`0000;ooooo0_l00005
ooooo`;o00001?ooool2o`0000;ooooo1?l00006ooooo`?o000000?oooooo`000?l000001?ooool2
o`0000Gooooo0_l00010ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@
413oV9RH00Sooooo00?o0000ooooooooool0;_ooool3o`0000;ooooo0_l00006ooooo`;o00002ooo
ool2o`0000Sooooo1?l0000<ooooo`;o00001oooool3o`0000Cooooo5Ol0000:ooooo`;o00000ooo
ool2o`0000Gooooo0_l00009ooooo`_o000000?oooooo`000?l000000_l000000ooooooo0000o`00
0005ooooo`;o00003?ooool4o`0000Gooooo1_l00002ooooo`Go00001?ooool2o`0000;ooooo0_l0
0008ooooo`Go00000oooool2o`0000Gooooo0_l0000<ooooo`;o0000=?ooool00006ooooooo^k^ko
<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo02ko
oooo0_l0000;ooooo`;o00002oooool2o`0000Kooooo0_l00002ooooo`?o00000oooool2o`0000Ko
oooo0_l00004ooooo`;o000000?oooooo`000?l000001?ooool>o`000003ooooool0003o000000Co
000000?oooooo`000?l000002?ooool2o`0000?ooooo0_l000000ooooooo0000o`000007ooooo`;o
00000oooool?o`000003ooooool0003o000000;o00001Oooool2o`0000;ooooo0_l00003ooooo`;o
00001Oooool2o`0000?ooooo0_l00002ooooo`?o00000_ooool4o`0000Cooooo1?l00006ooooo`Go
00001?ooool2o`0000?ooooo0_l00005ooooo`;o00003?ooool2o`0003Cooooo000Looooo`03o`00
0?oooooooooo02kooooo0_l0000Eooooo`Co00001oooool2o`0000?ooooo0_l00003ooooo`;o0000
3?ooool2o`0000;ooooo0_l00003oooooaGo000000?oooooo`000?l000001oooool6o`0000?ooooo
0_l00005ooooo`Co00000_oooolCo`0000_ooooo0_l00003ooooo`;o00002_ooool2o`0000?ooooo
0_l00002ooooo`;o00001_ooool2o`0000Sooooo1Ol0000Hooooo`;o0000>_ooool001cooooo00?o
0000ooooooooool0;_ooool2o`0000;ooooo0_l0000Aooooo`Co00003?ooool2o`0001Gooooo0_l0
0007ooooo`?o000000?oooooo`000?l000002ol00003ooooo`;o00001Oooool6o`0000[ooooo0ol0
0002oooooaCo000000?oooooo`000?l000004Oooool2o`0000Wooooo0_l00004ooooo`;o00004Ooo
ool5o`0000_ooooo0_l00003ooooo`;o00001Oooool4o`0003Sooooo000Looooo`03o`000?oooooo
oooo02kooooo0_l00002ooooo`?o00003oooool3o`0000Gooooo1?l00005ooooo`;o00003oooool3
o`0000gooooo0_l00002ooooo`Oo000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00003ooo
ool2o`0000Cooooo4_l000000ooooooo0000o`000002o`0000;ooooo0ol00008ooooo`Ko000000?o
ooooo`000?l000000_l00009ooooo`;o00002?ooool2o`0000?ooooo0_l00008ooooo`Go00002ooo
ool4o`000003ooooool0003o000000Oooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0c
ooooo`;o00003oooool3o`0000Cooooo1Ol0000Aooooo`Co000000?oooooo`000?l000000_l0000>
ooooo`;o000000?oooooo`000?l000000_l00004ooooo`Go00001Oooool2o`0000Sooooo0_l00000
0ooooooo0000o`000004oooooa7o000000?oooooo`000?l000002?l00008ooooo`Ko000000?ooooo
o`000?l000005Oooool7o`0000Oooooo0_l00005ooooo`;o00002Oooool3o`0000?ooooo0_l0000o
ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00002oooool2o`0000Cooooo0_l00007oooo
o`;o00002?ooool7o`0000?ooooo0_l00008ooooo`;o00001?ooool2o`0000Wooooo0_l000001?oo
oooo0000o`000?ooool2o`0000;ooooo0_l00008ooooo`;o00002?oooolLo`0001;ooooo0_l0000C
ooooo`Co00002?ooool2o`0000?ooooo1?l00003ooooo`;o00002_ooool2o`0003oooooo000Loooo
o`03o`000?oooooooooo03Sooooo0_l0000;ooooo`;o00003?ooool3o`0000Sooooo1Ol0000?oooo
o`;o00001oooool2o`0000cooooo0_l00002ooooo`;o00001oooool2o`0000Wooooo7?l00006oooo
o`?o00002?ooool3o`0001oooooo0_l00003ooooo`;o00001Oooool4o`0004Wooooo000Looooo`03
o`000?oooooooooo02gooooo1Ol00009ooooo`;o00002?ooool2o`0000[ooooo1Ol0000;ooooo`;o
00006?ooool2o`00013ooooo0_l00007ooooo`;o00002?oooolDo`000003ooooool0003o000000Go
00001oooool3o`0000Sooooo0ol0000:ooooo`;o00000oooool6o`0000Sooooo0_l00003ooooo`;o
00001?ooool2o`0000;ooooo0ol00003ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0
;Oooool5o`0000Wooooo0ol0000Cooooo`;o000000?oooooo`000?l000000_ooool2o`0000_ooooo
0_l00004ooooo`Co00008_ooool2o`0000;ooooo0_l00006oooooako00001_ooool4o`0000[ooooo
0_l0000:ooooo`;o00000oooool6o`0000?ooooo0_l000000ooooooo0000o`000007o`0000Cooooo
0_l00003ooooo`;o00000oooool2o`0004Cooooo000Looooo`03o`000?oooooooooo02cooooo0_l0
0003ooooo`;o00002?ooool4o`0001Wooooo0_l0000;ooooo`;o00001?ooool5o`0000Kooooo0_l0
000Iooooo`;o00000_ooool2o`0000Kooooo8?l00004ooooo`;o00002Oooool2o`0001Oooooo0_l0
0002ooooo`Go00000_ooool3o`0000_ooooo0_l00019ooooo`007?ooool00ol0003oooooooooo`0/
ooooo`;o00000oooool2o`0000Wooooo1Ol000000ooooooo0000o`00000Zooooo`;o00001?ooool4
o`0000[ooooo0ol00005ooooo`;o00001?ooool2o`0000cooooo7ol0000?ooooo`;o00002Oooool2
o`0000Gooooo0_l00005ooooo`;o00000oooool4o`0000?ooooo0_l00005ooooo`Co0000COooool0
01cooooo00?o0000ooooooooool0=oooool2o`0000Kooooo0_l000000ooooooo0000o`00000@oooo
o`;o00001oooool2o`0000cooooo0_l00007ooooo`Co00000_ooool2o`0000Gooooo1?l00005oooo
o`?o00000oooool2o`000003ooooool0003o000000Oooooo3?l000000ooooooo0000o`00000Co`00
00kooooo0_l00009ooooo`;o00001Oooool2o`000003ooooool0003o000000Oooooo0ol0000;oooo
o`Co0000COooool001cooooo0_l0000fooooo`Co00000_ooool2o`0000Wooooo0_l00002ooooo`?o
00001Oooool4o`0000Oooooo0_l0000<ooooo`;o00002Oooool3o`000004ooooool0003o0000o`00
00Cooooo1Ol00005ooooo`;o00001_ooool2o`0000Oooooo3?l000000ooooooo0000o`00000Co`00
00kooooo0_l0000<ooooo`;o00001Oooool2o`0000Oooooo0ol0001Looooo`007?ooool00ol0003o
ooooooooo`0eooooo`?o00000oooool2o`0000Wooooo0_l00002ooooo`?o00001Oooool2o`0000go
oooo1Ol0000:ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00007ooooo`;o
00001oooool2o`0000gooooo4?l000000ooooooo0000o`00000=o`0001kooooo0_l0000Looooo`;o
0000Coooool001cooooo00?o0000ooooooooool0=_ooool3o`0000Oooooo1?l0000<ooooo`;o0000
3oooool5o`0000;ooooo0_l00005ooooo`Ko00003Oooool2o`0000Wooooo0_l0000=oooooa3o0000
00?oooooo`000?l000003?l0000>ooooo`;o00002?ooool2o`0001?ooooo1Ol000000ooooooo0000
o`000008ooooo`;o0000Coooool001cooooo00?o0000ooooooooool0=oooool2o`0000;ooooo0_l0
0003ooooo`Ko00001Oooool2o`0000?ooooo0_l0000?ooooo`;o000000Coooooo`000?l0003ooooo
0ol00002ooooo`Go000000?oooooo`000?l000000_l000000ooooooo0000o`000008ooooo`?o0000
0oooool2o`0000[ooooo0_l00009ooooo`Oo000000?oooooo`000?l000004ol0000>ooooo`;o0000
2?ooool2o`0000Sooooo0_l00009ooooo`Go000000?oooooo`000?l000001oooool2o`00053ooooo
000Looooo`03o`000?oooooooooo03_ooooo0_l00007ooooo`Co00000oooool2o`0001Cooooo0_l0
00000ooooooo0000o`000004o`0000;ooooo0ol00005ooooo`;o000000?oooooo`000?l000002?oo
ool2o`0000Cooooo0_l0000:ooooo`;o00002?ooool9o`000003ooooool0003o0000017o00000ooo
ool2o`0001kooooo0_l000000ooooooo0000o`000007ooooo`;o00001oooool2o`000003ooooool0
003o000000;o0000D?ooool001cooooo00?o0000ooooooooool0A_ooool4o`0000Oooooo0_l0000>
ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo0ol0000Jooooo`?o00001oooool4
o`000003ooooool0003o000000?ooooo2Ol00002oooooa3o00001Oooool2o`0001;ooooo0_l0000=
ooooo`;o00001oooool2o`0000Oooooo1Ol0000=ooooo`;o0000@oooool001cooooo00?o0000oooo
ooooool0@oooool2o`0000?ooooo0_l00007ooooo`;o00002Oooool2o`0000?ooooo1?l00004oooo
o`;o00005?ooool3o`000003ooooool0003o000000Cooooo0ol00007ooooo`Co000000?oooooo`00
0?l000001?oooolHo`0001Gooooo0_l00004ooooo`;o00005Oooool2o`0000Gooooo0_l00003oooo
o`;o00003_ooool2o`0004?ooooo000Looooo`03o`000?oooooooooo03cooooo0_l00005ooooo`?o
00001?ooool4o`0000[ooooo0_l00002ooooo`;o00001Oooool2o`0000;ooooo1?l0000Dooooo`?o
000000?oooooo`000?l000001oooool2o`0000_ooooo0_l00003oooooaSo00005Oooool2o`0001_o
oooo0_l00005ooooo`;o00003?ooool2o`0004[ooooo000Looooo`03o`000?oooooooooo03cooooo
0_l00006ooooo`;o00001?ooool4o`0000[ooooo0_l0000=ooooo`;o00005oooool2o`0000Cooooo
0_l00004ooooo`;o00002oooool2o`0000;ooooo4_l000000ooooooo0000o`000004o`0000;ooooo
0_l0000_ooooo`;o000000?oooooo`000?l000000_ooool2o`000004ooooool0003o0000o`0000Oo
oooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`1Jooooo`;o00000oooool2o`0000_ooooo
0_l0000Hooooo`?o00005?oooolIo`000004ooooool0003o0000o`0001;ooooo0_l0000Kooooo`;o
000000?oooooo`000?l000001?l000000ooooooo0000o`000002o`0005;ooooo000Looooo`03o`00
0?oooooooooo05;ooooo0_l00006ooooo`;o000000?oooooo`000?l000000_l0000;ooooo`Co0000
5oooool2o`0001Gooooo4ol000000ooooooo0000o`000003ooooo`Go00001_ooool2o`0000Sooooo
0_l0000Hooooo`Go00000oooool2o`0000Gooooo0_l00005ooooo`;o0000Boooool001cooooo00?o
0000ooooooooool0@Oooool2o`0000Kooooo0_l00007ooooo`;o00002Oooool6o`0000[ooooo0ol0
00000ooooooo0000o`00000@ooooo`Co00006?oooolEo`0000Gooooo0ol00006ooooo`;o00006Ooo
ool4o`0000Gooooo1Ol0000Aooooo`;o00001_ooool2o`0004?ooooo000Looooo`03o`000?oooooo
oooo047ooooo0_l00004ooooo`Co00002Oooool2o`0000Sooooo0_l000000ooooooo0000o`00000;
ooooo`;o000000Coooooo`000?l0003o00000oooool2o`0000Kooooo0_l00002ooooo`Co00006Ooo
ool2o`000003ooooool0003o000000go0000:?ooool2o`000003ooooool0003o000000;o00001ooo
ool2o`0001[ooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`17ooooo`;o00002Oooool4
o`0000Sooooo0_l000000ooooooo0000o`00000;ooooo`Ko00000oooool2o`0000Kooooo0_l00000
0ooooooo0000o`00000Iooooo`;o000000?oooooo`000?l000003?l00002ooooo`;o00000_ooool2
o`0002Cooooo0_l0000<ooooo`?o00001oooool2o`0005Gooooo000Looooo`03o`000?oooooooooo
04;ooooo0_l000000ooooooo0000o`00000;ooooo`;o00001?ooool3o`0001Cooooo0ol000000ooo
oooo0000o`000002o`0000_ooooo0ol0000Aooooo`;o00001Oooool2o`000003ooooool0003o0000
00Oo00000_ooool2o`0000Oooooo0ol00006ooooo`;o00002?ooool2o`00023ooooo0_l00006oooo
o`?o00003_ooool3o`0004Cooooo000Looooo`03o`000?oooooooooo04;ooooo0_l000000ooooooo
0000o`000004ooooo`?o00002_ooool3o`0001?ooooo1?l000000ooooooo0000o`000002o`0000co
oooo0_l00006ooooo`;o00002Oooool2o`0000Kooooo0_l00002ooooo`?o00004?ooool2o`0000Ko
oooo0_l000000ooooooo0000o`000005ooooo`;o00001Oooool2o`0001Cooooo0_l00002ooooo`;o
00001?ooool2o`000004ooooool0003o0000o`0000kooooo0ol00014ooooo`007?ooool2o`0004co
oooo0ol00007ooooo`;o00002Oooool2o`0000[ooooo1?l00002ooooo`Ko00004_ooool7o`0000;o
oooo0_l00009ooooo`;o000000?oooooo`000?l000001?l00006ooooo`;o00002?ooool2o`0000Ko
oooo0ol00005ooooo`;o00001Oooool2o`0000Kooooo0_l00007ooooo`;o00000oooool2o`0000;o
oooo0_l00004ooooo`;o00000_ooool2o`0005Gooooo000Looooo`03o`000?oooooooooo04cooooo
0_l00007ooooo`;o00001?ooool2o`0000?ooooo0_l00004ooooo`;o00001?ooool4o`0000;ooooo
1ol0000=ooooo`;o00000_ooool2o`000003ooooool0003o000000;o00000_ooool2o`0000cooooo
0ol000000ooooooo0000o`000002ooooo`;o00000_ooool2o`0000Sooooo0_l00006ooooo`;o0000
00?oooooo`000?l000002Oooool3o`0000Kooooo0_l00002ooooo`;o000000?oooooo`000?l00000
0_l0000<ooooo`;o0000F_ooool001cooooo00?o0000ooooooooool0>_ooool2o`0001oooooo0_l0
00000ooooooo0000o`000006ooooo`;o00001_ooool2o`0000?ooooo1_l000000ooooooo0000o`00
000:ooooo`;o00001Oooool2o`0000?ooooo0_l00003ooooo`;o00002Oooool2o`000003ooooool0
003o000000;ooooo0_l00009ooooo`;o00002oooool4o`0000Sooooo0ol00006ooooo`;o00000_oo
ool2o`000003ooooool0003o000000;o000000?oooooo`000?l000001_ooool2o`000003ooooool0
003o000005[ooooo000Looooo`03o`000?oooooooooo03[ooooo0_l0000>ooooo`;o00000_ooool2
o`0000Gooooo0_l00007ooooo`;o00000_ooool2o`0000_ooooo0_l00002ooooo`?o000000Cooooo
o`000?l0003ooooo0_l0000Fooooo`;o000000?oooooo`000?l000000ol00005ooooo`;o00001?oo
ool2o`0000?ooooo0_l00003ooooo`?o00000_ooool2o`0000[ooooo1Ol0000Eooooo`;o00001_oo
ool4o`0000Cooooo0_l00005ooooo`;o00002?ooool2o`0004cooooo000Looooo`03o`000?oooooo
oooo04[ooooo0_l00002ooooo`;o00001Oooool2o`0000_ooooo0_l00009ooooo`Co00000_ooool3
o`0001oooooo0_l000000ooooooo0000o`000005ooooo`;o00001?ooool2o`0000?ooooo0_l00003
ooooo`?o00003_ooool4o`000003ooooool0003o000001?ooooo0_l000001?oooooo0000o`000?l0
0002ooooo`Co00002oooool2o`0000Sooooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`1C
ooooo`;o00004?ooool2o`0000Kooooo0_l00005ooooo`?o00000_ooool2o`00013ooooo0_l00000
1?oooooo0000o`000?ooool2o`0002Sooooo2Ol000000ooooooo0000o`00000>ooooo`;o00001_oo
ool3o`0000;ooooo1?l0001Sooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00000_ooool2
o`0000cooooo0ol0000=ooooo`Ko000000?oooooo`000?l000003Oooool2o`000004ooooool0003o
0000ooooo`;o00005?ooool2o`0000Cooooo0_l0000<ooooo`Ko000000?oooooo`000?l000004?oo
ool3o`000003ooooool0003o000000;ooooo1?l00002ooooo`Co00007Oooool2o`0004Cooooo000L
ooooo`03o`000?oooooooooo04Wooooo0_l0000<ooooo`;o00002?ooool2o`0000;ooooo0ol0000>
ooooo`Co00000_ooool2o`00017ooooo0_l0000?ooooo`;o00001Oooool2o`0000Cooooo0_l0000;
ooooo`Co00002oooool2o`0000Oooooo1?l00002ooooo`;o00000_ooool2o`0000Cooooo0ol00003
ooooo`;o00006Oooool2o`0004Cooooo000Looooo`03o`000?oooooooooo04Wooooo0_l0000Foooo
o`;o00001oooool2o`0000_ooooo0_l000000ooooooo0000o`00000Cooooo`;o00003?ooool2o`00
0003ooooool0003o0000013ooooo0ol000000ooooooo0000o`000002ooooo`So00001oooool2o`00
00Oooooo0_l000000ooooooo0000o`000003ooooo`;o00000oooool6o`0000?ooooo0_l0001Ooooo
o`007?ooool00ol0003oooooooooo`1Nooooo`;o00002_ooool2o`0000kooooo0_l00003ooooo`;o
00003oooool2o`0000Sooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000ko
oooo0ol000000ooooooo0000o`000004ooooo`So00000_ooool2o`0000Gooooo0_l00003ooooo`;o
000000?oooooo`000?l000000oooool2o`0000?ooooo1?l00003ooooo`;o0000HOooool001cooooo
00?o0000ooooooooool0FOooool2o`0000?ooooo0_l00006ooooo`;o00001Oooool2o`0000gooooo
0_l000001?oooooo0000o`000?ooool2o`0000Cooooo0_l00005ooooo`?o00001oooool3o`0000?o
oooo1Ol00003ooooo`;o00002_ooool7o`0000Sooooo0_l00002ooooo`;o00001?ooool8o`0000Wo
oooo1Ol00004ooooo`Co0000Goooool001cooooo00?o0000ooooooooool0FOooool2o`0000_ooooo
0_l00003ooooo`Co00000oooool2o`0000Gooooo0_l000000ooooooo0000o`000004ooooo`;o0000
0_ooool4o`0000Gooooo0_l00008ooooo`;o00001_ooool2o`0000;ooooo1?l00002ooooo`;o0000
2?ooool2o`000003ooooool0003o000000cooooo0_l00004ooooo`;o000000?oooooo`000?l00000
0_l0000:ooooo`Go00001_ooool2o`0005oooooo000Looooo`03o`000?oooooooooo067ooooo0_l0
0008ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Gooooo0_l00003ooooo`;o00001?oo
ool4o`00017ooooo0_l0000:ooooo`;o00001?ooool2o`0001Gooooo0_l00002ooooo`;o00001ooo
ool2o`0000;ooooo0_l00003ooooo`;o00001Oooool2o`000003ooooool0003o000000cooooo0_l0
001Gooooo`007?ooool00ol0003oooooooooo`1Fooooo`;o000000?oooooo`000?l000001_ooool2
o`0000_ooooo0_l00004ooooo`;o00001_ooool7o`000003ooooool0003o000000oooooo0_l00004
ooooo`;o00006oooool3o`0000Oooooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo0_l00002
ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`?o00003?ooool2o`0005Oooooo000Loooo
o`03o`000?oooooooooo05Kooooo0_l000000ooooooo0000o`00000Cooooo`;o00001?ooool3o`00
00Cooooo2?l00003ooooo`;o00003Oooool2o`0000Cooooo0ol0000Jooooo`?o00001?ooool2o`00
00;ooooo0_l000000ooooooo0000o`000002ooooo`;o00003_ooool4o`0000?ooooo0_l0000;oooo
o`;o00001?ooool2o`0005?ooooo000Looooo`03o`000?oooooooooo05Wooooo0_l0000Cooooo`;o
00001Oooool3o`0000?ooooo0_l000000ooooooo0000o`000004o`0000;ooooo0_l0000<ooooo`;o
00001_ooool4o`0000;ooooo0_l0000Gooooo`;o00000_ooool2o`0000;ooooo0_l0000?ooooo`;o
00000_ooool5o`0000gooooo0_l00002ooooo`;o00001?ooool2o`0005?ooooo000Looooo`;o0000
FOooool3o`0000Gooooo0_l00008ooooo`;o00001oooool2o`000003ooooool0003o000000?ooooo
0_l000000ooooooo0000o`000006o`0000kooooo0_l00008ooooo`;o00000_ooool2o`0001Oooooo
0_l0000Fooooo`?o00000_ooool5o`0000gooooo0_l0001Mooooo`007?ooool00ol0003ooooooooo
o`1Hooooo`?o00001Oooool2o`0000Sooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0
003o000000;ooooo0_l00006ooooo`Co000000?oooooo`000?l000003oooool2o`000004ooooool0
003o0000ooooo`?o00006oooool2o`0001Gooooo0ol00003ooooo`;o00002Oooool2o`000003oooo
ool0003o000000Gooooo0ol0001Hooooo`007?ooool00ol0003oooooooooo`1Iooooo`?o00002ooo
ool2o`0000Gooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Kooooo0ol0
0002ooooo`;o00000oooool2o`0000[ooooo1Ol000001?oooooo0000o`000?l00006ooooo`;o0000
4oooool2o`0001Kooooo0_l0000>ooooo`;o000000?oooooo`000?l000000oooool5o`0005Sooooo
000Looooo`03o`000?oooooooooo05[ooooo0_l00004ooooo`;o00001Oooool2o`0000[ooooo0_l0
0005ooooo`;o00000_ooool2o`000003ooooool0003o000000;o00001oooool2o`0000_ooooo0_l0
0003ooooo`Co00001Oooool2o`0000Oooooo0_l0000?ooooo`Co00009oooool2o`0005_ooooo000L
ooooo`03o`000?oooooooooo047ooooo0_l0000Mooooo`;o000000?oooooo`000?l000000_ooool2
o`0000_ooooo0_l00004ooooo`;o00000_ooool7o`0000Wooooo0_l00003ooooo`;o00002?ooool2
o`000003ooooool0003o000000Kooooo0_l00006ooooo`;o00003?ooool2o`000003ooooool0003o
000000;o00000_ooool2o`000003ooooool0003o000000Kooooo0_l0000Cooooo`;o0000H?ooool0
01cooooo00?o0000ooooooooool0@Oooool2o`00023ooooo0_l0000?ooooo`;o00002Oooool5o`00
00[ooooo0_l00003ooooo`;o00002?ooool2o`0000;ooooo0_l00005ooooo`;o00004Oooool2o`00
0004ooooool0003o0000ooooo`?o00000oooool2o`000003ooooool0003o000000Kooooo0_l0000B
ooooo`?o00000_ooool2o`0005cooooo000Looooo`03o`000?oooooooooo05kooooo0_l00002oooo
o`;o00000oooool2o`000003ooooool0003o000000[ooooo0_l0000:ooooo`?o00002Oooool2o`00
00?ooooo0ol0000;ooooo`;o00001Oooool2o`00017ooooo0_l00004ooooo`;o00001_ooool2o`00
00Gooooo0_l0000;ooooo`;o00001oooool2o`0000?ooooo0_l0001Looooo`007?ooool00ol0003o
ooooooooo`1Nooooo`;o00000_ooool4o`000004ooooool0003o0000ooooo`;o000000?oooooo`00
0?l000001_ooool5o`0000Wooooo0_l00009ooooo`;o00000oooool3o`0000Cooooo0_l00005oooo
o`;o00001Oooool2o`0000;ooooo0_l0000Cooooo`;o00000oooool5o`0000Gooooo0_l0000;oooo
o`;o0000J_ooool001cooooo00?o0000ooooooooool0Hoooool3o`000003ooooool0003o000000Co
oooo0_l00006ooooo`;o000000?oooooo`000?l000001_ooool3o`0000Cooooo0_l0000:ooooo`;o
00001Oooool2o`00013ooooo0_l00009ooooo`;o00003Oooool3o`00083ooooo000Looooo`03o`00
0?oooooooooo06?ooooo0_l00002ooooo`;o00002_ooool2o`0000_ooooo0ol00004ooooo`Co0000
2?ooool2o`0000Gooooo0_l00002ooooo`?o00002_ooool2o`0000[ooooo0ol0000Vooooo`;o0000
Ioooool001cooooo00?o0000ooooooooool0KOooool2o`0000Cooooo0_l00002ooooo`;o00004?oo
ool2o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000001Ol0
000:ooooo`;o00002oooool2o`0000Kooooo1?l0000Looooo`;o0000Ioooool001cooooo00?o0000
ooooooooool0Ioooool2o`0000Cooooo0_l00008ooooo`;o00005_ooool2o`000003ooooool0003o
000000?ooooo0_l00003ooooo`Go00003_ooool2o`0000Gooooo1_l00004ooooo`Co00004Oooool2
o`0007;ooooo000Looooo`03o`000?oooooooooo06;ooooo0_l00003ooooo`;o000000?oooooo`00
0?l000000_ooool2o`0001;ooooo0_l00004ooooo`;o00004?ooool4o`00017ooooo0_l00003oooo
o`So00000oooool2o`000003ooooool0003o0000017ooooo0_l0001booooo`007?ooool00ol0003o
ooooooooo`1Rooooo`;o00001Oooool3o`000004ooooool0003o0000o`0000Gooooo0_l0000;oooo
o`;o00001?ooool3o`0000;ooooo0_l0000;ooooo`?o00004oooool2o`0000;ooooo0_l00003oooo
o`;o00001?ooool2o`0001Sooooo0_l000000ooooooo0000o`00001[ooooo`0000Koooooonk^k_lb
<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o
0000ooooooooool0JOooool2o`0000;ooooo0_l00006ooooo`;o00004Oooool3o`0000;ooooo0_l0
000;ooooo`Co00000_ooool2o`0000kooooo0ol00005ooooo`?o00001_ooool2o`0000[ooooo0_l0
000:ooooo`;o000000?oooooo`000?l00000Joooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo06go
oooo0_l0000Iooooo`;o00000oooool2o`0000cooooo0ol00002ooooo`;o00003oooool3o`0000Co
oooo0_l000000ooooooo0000o`000004ooooo`;o00000oooool2o`0000Gooooo0_l00008ooooo`;o
0000L?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool0KOooool2o`0000gooooo0ol0000<ooooo`Co
00002?ooool2o`0000?ooooo0_l00006ooooo`;o00001_ooool4o`0000;ooooo0_l00004ooooo`;o
000000Coooooo`000?l0003ooooo0_l00006ooooo`;o00003oooool2o`00073ooooo00000ooooooo
0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06oooo
o`?o0000O?ooool3o`0000Kooooo0_l00004ooooo`;o00002_ooool3o`000004ooooool0003o0000
o`0000Kooooo0_l00006ooooo`Co00000_ooool2o`000004ooooool0003o0000ooooo`;o00001?oo
ool2o`0001Oooooo0_l0001`ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09
ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`1]ooooo`;o00001Ooo
ool2o`0000Gooooo0_l000000ooooooo0000o`000003o`0000;ooooo0_l00006ooooo`;o00000_oo
ool2o`0000Gooooo1Ol0000=ooooo`;o00001_ooool2o`000003ooooool0003o000000gooooo0_l0
000Aooooo`;o0000L?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool0
1Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0KOooool2o`0000Gooooo0_l0
0005ooooo`;o000000?oooooo`000?l000000ol0000:ooooo`?o000000Coooooo`000?l0003o0000
1Oooool4o`0000[ooooo1Ol0000Hooooo`;o0000Poooool00006oooooomgMgOoV9RHoooooonHV9So
MgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0O_ooool2o`00
00Oooooo0_l00005ooooo`;o00000_ooool2o`0001?ooooo0ol00005ooooo`?o00006oooool2o`00
00?ooooo0_l0001eooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o
0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`1looooo`;o00001Oooool3o`000003ooooool0
003o000000oooooo0_l0000Eooooo`?o00006_ooool3o`0000?ooooo0_l0001eooooo`007?ooool0
0ol0003oooooooooo`1looooo`;o00001Oooool3o`0001;ooooo0_l0000booooo`;o0000Noooool0
01cooooo00?o0000ooooooooool0Poooool2o`0001[ooooo0_l00004ooooo`;o00002oooool2o`00
09Gooooo000Looooo`03o`000?oooooooooo09?ooooo0_l000000ooooooo0000o`000007ooooo`Co
00000_ooool2o`0000_ooooo0_l0000Aooooo`;o0000P_ooool001cooooo00?o0000ooooooooool0
Hoooool2o`0002Gooooo0ol00006ooooo`;o000000Coooooo`000?l0003ooooo0_l00006ooooo`;o
00008_ooool2o`0008;ooooo000Looooo`03o`000?oooooooooo06?ooooo0_l0000Uooooo`?o0000
2_ooool4o`0000[ooooo0_l0000>ooooo`;o0000T_ooool001cooooo00?o0000ooooooooool0Uooo
ool2o`000003ooooool0003o000000Wooooo0_l0000>ooooo`;o00000oooool2o`0001_ooooo0_l0
001`ooooo`007?ooool00ol0003oooooooooo`2Jooooo`;o00004?ooool2o`0000Sooooo0_l00002
ooooo`;o00006oooool2o`00073ooooo000Looooo`03o`000?oooooooooo09[ooooo0_l0000@oooo
o`;o00002?ooool2o`00097ooooo000Looooo`03o`000?oooooooooo063ooooo0_l0000booooo`;o
00001?ooool3o`0000?ooooo0_l0000Iooooo`;o00000oooool2o`0000kooooo0_l0001gooooo`00
7?ooool00ol0003oooooooooo`1Pooooo`;o0000<_ooool2o`000003ooooool0003o000000;ooooo
0_l000000ooooooo0000o`000002o`0000Cooooo0_l0000Cooooo`;o00000oooool2o`0000kooooo
0_l0001gooooo`007?ooool00ol0003oooooooooo`2Gooooo`;o00001Oooool2o`0000Kooooo0_l0
002Qooooo`007?ooool2o`0008gooooo0_l0000Mooooo`;o00007?ooool2o`0007kooooo000Loooo
o`03o`000?oooooooooo08cooooo0_l0000>ooooo`;o00003Oooool2o`0001cooooo0_l0001noooo
o`007?ooool00ol0003oooooooooo`2Looooo`;o0000Zoooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`2@ooooo`;o0000]oooool001cooooo00?o0000
ooooooooool0T?ooool2o`000;Oooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Jooooo`;o0000
[Oooool001cooooo00?o0000ooooooooool0V_ooool2o`000:gooooo000Looooo`03o`000?oooooo
oooo0;Wooooo0_l0002>ooooo`007?ooool00ol0003oooooooooo`2Tooooo`;o00002oooool2o`00
00Kooooo0_l0002>ooooo`007?ooool00ol0003oooooooooo`2Pooooo`;o00000_ooool2o`000003
ooooool0003o000000Sooooo0_l00005ooooo`;o0000Soooool001cooooo00?o0000ooooooooool0
WOooool2o`000003ooooool0003o000000Gooooo0_l0000?ooooo`;o0000Soooool001cooooo00?o
0000ooooooooool0WOooool2o`000:[ooooo000Looooo`03o`000?oooooooooo09kooooo0_l0002Y
ooooo`007?ooool2o`0009oooooo0_l0002Yooooo`007?ooool00ol0003oooooooooo`1oooooo`;o
00006_ooool2o`000:cooooo000Looooo`03o`000?oooooooooo07oooooo0_l0000Jooooo`;o0000
[?ooool001cooooo00?o0000ooooooooool0Woooool2o`000:Sooooo000Looooo`03o`000?oooooo
oooo09oooooo0_l0002Xooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo093ooooo0_l0002gooooo`007?ooool00ol0003oooooooooo`2@ooooo`;o0000
1Oooool2o`000;3ooooo000Looooo`03o`000?oooooooooo09Oooooo0_l0002`ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Boooo
o`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003ooooo
ooooo`05ooooo`?o0000oooooom:ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000D
ooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBoooo
o`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Booooo`03oeEEEOmVIVKo00000?oooooo
E?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:7ooooo00Co410@o`000?l0
003ooooo0_l000000ol@413oooooooooo`0Fooooo`Co000000Co410@oooooooooooooooo1?l00000
0ol@413oooooooooo`02ooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h0S?ooool00:;ooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00003?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg08cooooo002Rooooo`05o`000?ooooooooooooooool000006oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo1Ol00003ooooo`05oa0@4?oooooooooo
ooooool@4100S?ooool00:;ooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00003?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00CoA4A4omgMgOoooooo00001?oo
ool01Ol0003ooooooooooooooooo000008cooooo002Rooooo`05o`000?n7QhOoooooojVYZOl00000
6oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00CogMgMoeEEEOoooooo
00001?ooool01Ol0003ooooooooooooooooo000008cooooo002Qooooo`03oa0@4?l0003oMgMg00;o
000000?oV9RHooooooooool06Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?o
oooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@08cooooo0032ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00oo^k^koA4A4o`000004ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0S?ooool00<3ooooo00?oEEEEofIVI_l000001Oooool00omEEEGo
IVIVo`000006ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP2<oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1146) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.3875 .4363 Mdot
.35993 .39723 Mdot
.50386 .6288 Mdot
.60261 .36871 Mdot
.20072 .55972 Mdot
.51411 .65634 Mdot
.40026 .58622 Mdot
.35122 .54996 Mdot
.51107 .63474 Mdot
.2587 .42324 Mdot
.39087 .58476 Mdot
.55825 .31767 Mdot
.37622 .57568 Mdot
.61016 .39002 Mdot
.15524 .44138 Mdot
.58946 .33089 Mdot
.3816 .36559 Mdot
.67588 .61747 Mdot
.52907 .41688 Mdot
.55164 .66032 Mdot
.41058 .37896 Mdot
.60275 .38313 Mdot
.34529 .41205 Mdot
.61022 .39088 Mdot
.59223 .35262 Mdot
.3929 .40625 Mdot
.33647 .35132 Mdot
.55858 .38165 Mdot
.58493 .34398 Mdot
.34928 .55551 Mdot
.70851 .48492 Mdot
.15537 .50135 Mdot
.55265 .44577 Mdot
.40676 .78778 Mdot
.36143 .54415 Mdot
.4619 .33924 Mdot
.49543 .65695 Mdot
.37159 .55277 Mdot
.37462 .54653 Mdot
.41268 .58593 Mdot
.38554 .56182 Mdot
.38133 .41128 Mdot
.43237 .59421 Mdot
.46099 .57404 Mdot
.56584 .34169 Mdot
.23901 .55241 Mdot
.6568 .26023 Mdot
.56782 .42355 Mdot
.39407 .37913 Mdot
.55912 .73257 Mdot
.31572 .67496 Mdot
.40903 .57746 Mdot
.49403 .68712 Mdot
.55885 .89505 Mdot
.36227 .55373 Mdot
.54395 .35979 Mdot
.48873 .64714 Mdot
.59744 .39386 Mdot
.60903 .39646 Mdot
.38046 .2637 Mdot
.54806 .41345 Mdot
.65208 .60624 Mdot
.38206 .44484 Mdot
.55188 .50592 Mdot
.50277 .64163 Mdot
.38879 .55613 Mdot
.35937 .41101 Mdot
.36796 .57124 Mdot
.65665 .37678 Mdot
.5494 .67217 Mdot
.56513 .42075 Mdot
.39396 .56965 Mdot
.40969 .3972 Mdot
.56646 .40155 Mdot
.61865 .75084 Mdot
.28893 .25783 Mdot
.62338 .56146 Mdot
.42584 .30197 Mdot
.36863 .28781 Mdot
.6306 .68314 Mdot
.62559 .37292 Mdot
.76203 .41367 Mdot
.24193 .32604 Mdot
.33369 .38988 Mdot
.59409 .47181 Mdot
.58425 .58947 Mdot
.57153 .40089 Mdot
.21726 .46752 Mdot
.59062 .3377 Mdot
.63 .76734 Mdot
.52178 .63767 Mdot
.37071 .38284 Mdot
.60469 .36819 Mdot
.55309 .38037 Mdot
.66988 .28887 Mdot
.61089 .43992 Mdot
.57532 .37642 Mdot
.40406 .41585 Mdot
.40683 .56708 Mdot
.55338 .33122 Mdot
.44186 .57125 Mdot
.46956 .67234 Mdot
.60653 .43311 Mdot
.51261 .68062 Mdot
.41022 .38809 Mdot
.55958 .40066 Mdot
.38047 .54363 Mdot
.6074 .42751 Mdot
.32259 .51945 Mdot
.35682 .39704 Mdot
.55683 .37529 Mdot
.66695 .60967 Mdot
.81579 .56393 Mdot
.36464 .37606 Mdot
.67347 .66522 Mdot
.62589 .36253 Mdot
.58155 .38361 Mdot
.36259 .3975 Mdot
.47156 .6515 Mdot
.2204 .43516 Mdot
.3387 .40977 Mdot
.41496 .57577 Mdot
.36232 .43984 Mdot
.61748 .46311 Mdot
.51856 .64331 Mdot
.37756 .73073 Mdot
.31599 .6031 Mdot
.71741 .45481 Mdot
.57731 .40155 Mdot
.27776 .48003 Mdot
.5434 .65492 Mdot
.37538 .39455 Mdot
.36465 .57275 Mdot
.51878 .41729 Mdot
.34368 .38957 Mdot
.36415 .58314 Mdot
.6562 .61441 Mdot
.40706 .69992 Mdot
.36339 .36036 Mdot
.45252 .55292 Mdot
.34053 .54687 Mdot
.40945 .58502 Mdot
.46974 .81872 Mdot
.36391 .41006 Mdot
.65154 .58608 Mdot
.35516 .56444 Mdot
.68463 .48412 Mdot
.54498 .36933 Mdot
.76203 .48153 Mdot
.72605 .28249 Mdot
.42623 .79636 Mdot
.44692 .71609 Mdot
.62902 .58 Mdot
.40336 .54796 Mdot
.57756 .35917 Mdot
.39926 .40583 Mdot
.38112 .4165 Mdot
.55475 .42385 Mdot
.59981 .36022 Mdot
.56075 .41369 Mdot
.55297 .37503 Mdot
.35105 .26036 Mdot
.62968 .41506 Mdot
.70096 .28539 Mdot
.37119 .37806 Mdot
.58726 .36446 Mdot
.47939 .66128 Mdot
.60413 .45719 Mdot
.38905 .56273 Mdot
.59632 .38537 Mdot
.59983 .36745 Mdot
.54734 .41595 Mdot
.40939 .57481 Mdot
.17321 .44593 Mdot
.76784 .35424 Mdot
.17396 .52438 Mdot
.67046 .72573 Mdot
.52522 .66979 Mdot
.57391 .39432 Mdot
.66501 .60028 Mdot
.49065 .30597 Mdot
.62519 .38695 Mdot
.88033 .4926 Mdot
.58483 .37575 Mdot
.18408 .52697 Mdot
.67078 .36497 Mdot
.16725 .58122 Mdot
.75727 .44467 Mdot
.56915 .36128 Mdot
.63422 .48578 Mdot
.45444 .41352 Mdot
.44482 .59669 Mdot
.38463 .56423 Mdot
.4778 .65662 Mdot
.49259 .63697 Mdot
.38565 .52284 Mdot
.31179 .34306 Mdot
.61178 .4807 Mdot
.64511 .41302 Mdot
.54367 .68063 Mdot
.40611 .4342 Mdot
.62288 .59623 Mdot
.3875 .42811 Mdot
.33168 .18536 Mdot
.30362 .64173 Mdot
.40869 .5409 Mdot
.67402 .575 Mdot
.53153 .63158 Mdot
.47538 .67526 Mdot
.66926 .58766 Mdot
.59036 .42409 Mdot
.36397 .41439 Mdot
.37984 .793 Mdot
.2936 .35953 Mdot
.44577 .82449 Mdot
.40525 .40771 Mdot
.28817 .43792 Mdot
.36938 .58354 Mdot
.50137 .66734 Mdot
.57889 .38155 Mdot
.59034 .41703 Mdot
.38524 .35641 Mdot
.56346 .41536 Mdot
.67055 .31591 Mdot
.56701 .38145 Mdot
.34461 .69816 Mdot
.61572 .5666 Mdot
.38775 .524 Mdot
.71876 .43603 Mdot
.3576 .42546 Mdot
.75541 .58979 Mdot
.50186 .68219 Mdot
.47231 .31153 Mdot
.397 .5715 Mdot
.65414 .6117 Mdot
.51068 .68487 Mdot
.62162 .59787 Mdot
.55763 .44633 Mdot
.51311 .61888 Mdot
.6747 .59933 Mdot
.34221 .31288 Mdot
.55234 .3654 Mdot
.34689 .25705 Mdot
.40401 .55405 Mdot
.33413 .40319 Mdot
.54806 .40968 Mdot
.5168 .67515 Mdot
.55894 .45345 Mdot
.43777 .67322 Mdot
.37567 .72795 Mdot
.46591 .65336 Mdot
.52783 .73923 Mdot
.63944 .60551 Mdot
.40103 .64894 Mdot
.29666 .46585 Mdot
.39889 .38227 Mdot
.62654 .42284 Mdot
.15452 .58173 Mdot
.35549 .56451 Mdot
.6065 .42437 Mdot
.39318 .76214 Mdot
.35947 .56111 Mdot
.59625 .39588 Mdot
.36961 .53316 Mdot
.37924 .41775 Mdot
.80562 .51522 Mdot
.385 .36857 Mdot
.60231 .34041 Mdot
.3842 .54299 Mdot
.48354 .63359 Mdot
.39624 .39936 Mdot
.58896 .4293 Mdot
.5615 .38939 Mdot
.51532 .51032 Mdot
.57977 .36622 Mdot
.17709 .47013 Mdot
.5642 .37359 Mdot
.48136 .65102 Mdot
.59021 .44428 Mdot
.77198 .69992 Mdot
.3255 .62625 Mdot
.36042 .41194 Mdot
.48242 .63061 Mdot
.50502 .63419 Mdot
.6934 .64929 Mdot
.41408 .62115 Mdot
.63026 .37392 Mdot
.52349 .67243 Mdot
.77336 .54131 Mdot
.35233 .57876 Mdot
.6262 .42632 Mdot
.45881 .55044 Mdot
.56669 .72982 Mdot
.5163 .68795 Mdot
.5207 .39759 Mdot
.38208 .35972 Mdot
.60441 .36674 Mdot
.47486 .67028 Mdot
.42208 .39556 Mdot
.62477 .35363 Mdot
.34016 .44506 Mdot
.51365 .50863 Mdot
.37823 .5917 Mdot
.67478 .38317 Mdot
.59635 .43285 Mdot
.49811 .67154 Mdot
.36593 .42731 Mdot
.34223 .56717 Mdot
.38796 .40406 Mdot
.24948 .67556 Mdot
.33107 .51454 Mdot
.33537 .29635 Mdot
.68396 .6193 Mdot
.51437 .76437 Mdot
.18474 .61523 Mdot
.73292 .69165 Mdot
.74017 .56797 Mdot
.30248 .74661 Mdot
.47644 .66531 Mdot
.41957 .77119 Mdot
.4983 .63564 Mdot
.60885 .35392 Mdot
.51319 .64409 Mdot
.18 .61284 Mdot
.56806 .37994 Mdot
.50758 .64877 Mdot
.7705 .58153 Mdot
.5946 .3637 Mdot
.35887 .37418 Mdot
.19477 .38802 Mdot
.75044 .68986 Mdot
.35797 .72906 Mdot
.54017 .62581 Mdot
.71521 .55914 Mdot
.57332 .37439 Mdot
.58329 .44703 Mdot
.39027 .37939 Mdot
.62803 .42829 Mdot
.6244 .59026 Mdot
.67625 .57741 Mdot
.45746 .43259 Mdot
.77634 .4056 Mdot
.62539 .32399 Mdot
.39664 .3947 Mdot
.40785 .21939 Mdot
.60027 .75724 Mdot
.5393 .74914 Mdot
.37773 .5293 Mdot
.19676 .40398 Mdot
.63512 .29652 Mdot
.39922 .51645 Mdot
.46564 .58309 Mdot
.36142 .3838 Mdot
.16919 .46893 Mdot
.38068 .56237 Mdot
.56183 .2179 Mdot
.63463 .50743 Mdot
.59379 .42119 Mdot
.39976 .57653 Mdot
.60939 .31195 Mdot
.73466 .71888 Mdot
.58503 .19966 Mdot
.72864 .34654 Mdot
.61086 .34137 Mdot
.63666 .74343 Mdot
.59033 .38356 Mdot
.22504 .4179 Mdot
.5622 .37525 Mdot
.38953 .39681 Mdot
.24273 .41647 Mdot
.48167 .46149 Mdot
.7479 .32934 Mdot
.29743 .62084 Mdot
.6285 .58054 Mdot
.57262 .38376 Mdot
.59557 .42095 Mdot
.62815 .59498 Mdot
.34475 .37101 Mdot
.55256 .37465 Mdot
.74776 .59246 Mdot
.57032 .40904 Mdot
.37998 .5554 Mdot
.71777 .34852 Mdot
.3154 .36827 Mdot
.64894 .38771 Mdot
.40921 .42648 Mdot
.37756 .59253 Mdot
.36792 .5454 Mdot
.58364 .32875 Mdot
.40919 .59404 Mdot
.59248 .37442 Mdot
.59275 .19395 Mdot
.35819 .36481 Mdot
.67474 .34287 Mdot
.34146 .40167 Mdot
.41888 .30491 Mdot
.37097 .54043 Mdot
.33657 .68183 Mdot
.52515 .35577 Mdot
.38138 .56641 Mdot
.34797 .49973 Mdot
.62824 .32837 Mdot
.61735 .33724 Mdot
.59101 .78678 Mdot
.52855 .62202 Mdot
.50599 .49219 Mdot
.35229 .54611 Mdot
.58778 .4334 Mdot
.64366 .40061 Mdot
.38365 .59368 Mdot
.509 .1937 Mdot
.76614 .62963 Mdot
.56503 .37784 Mdot
.38467 .38669 Mdot
.37705 .39687 Mdot
.61796 .34178 Mdot
.61875 .42174 Mdot
.53537 .6522 Mdot
.5039 .61894 Mdot
.546 .62407 Mdot
.51173 .50593 Mdot
.3395 .68878 Mdot
.24521 .60704 Mdot
.41237 .58618 Mdot
.29711 .50277 Mdot
.64834 .75763 Mdot
.61449 .45882 Mdot
.549 .64936 Mdot
.60867 .41662 Mdot
.60266 .37306 Mdot
.34277 .57199 Mdot
.36775 .74275 Mdot
.61457 .30408 Mdot
.35245 .36335 Mdot
.34393 .55377 Mdot
.5281 .45211 Mdot
.27359 .57932 Mdot
.66522 .60704 Mdot
.49656 .80971 Mdot
.39447 .56664 Mdot
.3579 .37991 Mdot
.37149 .5371 Mdot
.58514 .41679 Mdot
.52704 .39308 Mdot
.36532 .392 Mdot
.67109 .57677 Mdot
.58271 .45546 Mdot
.59383 .39443 Mdot
.80465 .36134 Mdot
.66878 .73774 Mdot
.3541 .69612 Mdot
.56735 .36472 Mdot
.64544 .37401 Mdot
.63813 .61662 Mdot
.57457 .41264 Mdot
.55344 .4082 Mdot
.82272 .5056 Mdot
.30584 .58259 Mdot
.68602 .60118 Mdot
.53771 .20924 Mdot
.40603 .40344 Mdot
.15491 .54819 Mdot
.50499 .66992 Mdot
.42227 .58428 Mdot
.78205 .61511 Mdot
.47093 .67822 Mdot
.46015 .71965 Mdot
.15655 .52968 Mdot
.50247 .48988 Mdot
.59263 .64639 Mdot
.57804 .30634 Mdot
.55269 .39406 Mdot
.58675 .38645 Mdot
.66146 .59842 Mdot
.36856 .41477 Mdot
.52592 .50606 Mdot
.3847 .20683 Mdot
.59785 .38105 Mdot
.67938 .33542 Mdot
.29218 .32392 Mdot
.57292 .72235 Mdot
.63658 .5788 Mdot
.6709 .57471 Mdot
.57651 .3849 Mdot
.81464 .54121 Mdot
.39428 .4056 Mdot
.59046 .4293 Mdot
.63513 .38143 Mdot
.53269 .62153 Mdot
.35243 .39318 Mdot
.47771 .66932 Mdot
.32749 .66544 Mdot
.1799 .53031 Mdot
.80999 .35843 Mdot
.36807 .54297 Mdot
.25482 .35852 Mdot
.34774 .56285 Mdot
.75657 .40553 Mdot
.47698 .67886 Mdot
.62703 .38002 Mdot
.36284 .42698 Mdot
.59757 .42982 Mdot
.62433 .41252 Mdot
.59242 .42403 Mdot
.636 .43219 Mdot
.86302 .55607 Mdot
.66911 .581 Mdot
.64452 .35569 Mdot
.48775 .63869 Mdot
.21593 .40162 Mdot
.27728 .27788 Mdot
.59972 .41542 Mdot
.56565 .38851 Mdot
.34803 .37595 Mdot
.56507 .43485 Mdot
.34958 .57363 Mdot
.36918 .42883 Mdot
.55392 .37803 Mdot
.20383 .40459 Mdot
.57062 .35093 Mdot
.16953 .55984 Mdot
.36736 .53712 Mdot
.34327 .48348 Mdot
.6438 .34777 Mdot
.37733 .72597 Mdot
.50614 .49232 Mdot
.53676 .67035 Mdot
.40536 .60248 Mdot
.49572 .65435 Mdot
.47685 .16128 Mdot
.53274 .4124 Mdot
.58144 .35677 Mdot
.64041 .40832 Mdot
.52297 .67095 Mdot
.20905 .4918 Mdot
.36841 .64838 Mdot
.54107 .4632 Mdot
.52931 .66197 Mdot
.39579 .44078 Mdot
.62615 .5318 Mdot
.35351 .41798 Mdot
.67764 .57664 Mdot
.38856 .58433 Mdot
.65095 .56708 Mdot
.37527 .75994 Mdot
.3582 .39562 Mdot
.34979 .34407 Mdot
.5128 .66641 Mdot
.54287 .56286 Mdot
.46475 .87346 Mdot
.59515 .5392 Mdot
.74095 .4708 Mdot
.38801 .37881 Mdot
.6059 .34401 Mdot
.74002 .389 Mdot
.52933 .55364 Mdot
.4956 .65161 Mdot
.62037 .38213 Mdot
.80448 .53779 Mdot
.53582 .65279 Mdot
.62532 .42621 Mdot
.507 .62468 Mdot
.3903 .57256 Mdot
.54424 .6414 Mdot
.35163 .35476 Mdot
.56229 .39655 Mdot
.4298 .85758 Mdot
.65068 .55211 Mdot
.56978 .37048 Mdot
.34537 .55122 Mdot
.39414 .47387 Mdot
.62123 .40815 Mdot
.64575 .6153 Mdot
.51947 .64953 Mdot
.58619 .54913 Mdot
.5636 .37735 Mdot
.52378 .66874 Mdot
.3769 .43905 Mdot
.41422 .59975 Mdot
.4848 .42984 Mdot
.37103 .72464 Mdot
.39291 .38182 Mdot
.43846 .54808 Mdot
.37293 .59955 Mdot
.64713 .37998 Mdot
.6331 .41053 Mdot
.38275 .38996 Mdot
.80413 .47625 Mdot
.57455 .4422 Mdot
.62558 .3733 Mdot
.48303 .64265 Mdot
.50115 .65408 Mdot
.80197 .49882 Mdot
.47437 .64509 Mdot
.5276 .39811 Mdot
.38394 .39219 Mdot
.61015 .37014 Mdot
.35016 .37794 Mdot
.57497 .43812 Mdot
.4195 .37674 Mdot
.34228 .37037 Mdot
.37315 .63921 Mdot
.61499 .37674 Mdot
.67314 .36445 Mdot
.61026 .42229 Mdot
.56355 .40968 Mdot
.53364 .64807 Mdot
.65443 .57933 Mdot
.5278 .36768 Mdot
.65071 .5564 Mdot
.62457 .60067 Mdot
.42796 .44321 Mdot
.53376 .62259 Mdot
.64947 .59211 Mdot
.30879 .28663 Mdot
.54181 .62169 Mdot
.65351 .60351 Mdot
.27103 .29085 Mdot
.36333 .54323 Mdot
.37321 .35844 Mdot
.59535 .36273 Mdot
.30121 .73784 Mdot
.66674 .26117 Mdot
.46765 .68404 Mdot
.56556 .37221 Mdot
.61297 .41441 Mdot
.33778 .4057 Mdot
.54534 .14871 Mdot
.55227 .66563 Mdot
.59436 .34702 Mdot
.35566 .40726 Mdot
.59799 .16935 Mdot
.48304 .65376 Mdot
.65673 .60227 Mdot
.41067 .57055 Mdot
.37675 .45094 Mdot
.31784 .60396 Mdot
.39705 .58938 Mdot
.50075 .69258 Mdot
.32188 .67911 Mdot
.62642 .36311 Mdot
.54803 .65228 Mdot
.51906 .81523 Mdot
.29638 .36758 Mdot
.35176 .60537 Mdot
.7078 .55567 Mdot
.36267 .38212 Mdot
.34951 .57168 Mdot
.64814 .57032 Mdot
.40394 .41102 Mdot
.36243 .36818 Mdot
.35015 .58232 Mdot
.47884 .39383 Mdot
.46377 .5525 Mdot
.37513 .54978 Mdot
.60221 .77723 Mdot
.27719 .67995 Mdot
.54965 .65128 Mdot
.62592 .59359 Mdot
.34875 .75381 Mdot
.38247 .41088 Mdot
.19458 .40688 Mdot
.52701 .80813 Mdot
.57549 .37631 Mdot
.64505 .58848 Mdot
.22346 .54643 Mdot
.41532 .18213 Mdot
.36035 .55949 Mdot
.4792 .46849 Mdot
.62649 .57466 Mdot
.54925 .41311 Mdot
.65972 .50655 Mdot
.61854 .36818 Mdot
.37887 .58663 Mdot
.36701 .27345 Mdot
.35674 .37944 Mdot
.3418 .57481 Mdot
.49353 .81064 Mdot
.59529 .37581 Mdot
.61828 .37831 Mdot
.70931 .43644 Mdot
.38839 .41826 Mdot
.53578 .67162 Mdot
.62835 .36784 Mdot
.5949 .3905 Mdot
.53618 .36338 Mdot
.67506 .39598 Mdot
.81331 .56157 Mdot
.60269 .34979 Mdot
.30609 .63054 Mdot
.64956 .37944 Mdot
.61419 .38153 Mdot
.40988 .42631 Mdot
.84142 .40503 Mdot
.32258 .65836 Mdot
.5953 .38661 Mdot
.60548 .34499 Mdot
.35527 .58739 Mdot
.47393 .54758 Mdot
.53552 .5647 Mdot
.57293 .56083 Mdot
.7304 .56599 Mdot
.64141 .42681 Mdot
.35379 .41267 Mdot
.67339 .60554 Mdot
.63489 .36167 Mdot
.35227 .40964 Mdot
.54162 .4043 Mdot
.53645 .65503 Mdot
.53684 .61895 Mdot
.36856 .48407 Mdot
.64805 .59717 Mdot
.70751 .38848 Mdot
.2889 .51409 Mdot
.47804 .64792 Mdot
.58579 .35512 Mdot
.42622 .58175 Mdot
.47548 .672 Mdot
.57933 .62228 Mdot
.60196 .47873 Mdot
.39307 .41095 Mdot
.36943 .37996 Mdot
.7638 .48309 Mdot
.42374 .70098 Mdot
.81002 .39375 Mdot
.39109 .57502 Mdot
.5594 .44179 Mdot
.28524 .46575 Mdot
.36705 .37787 Mdot
.74564 .40121 Mdot
.64692 .59204 Mdot
.35815 .55948 Mdot
.4947 .73636 Mdot
.3442 .38456 Mdot
.3756 .36309 Mdot
.5795 .34064 Mdot
.59506 .40487 Mdot
.74465 .56589 Mdot
.60784 .60033 Mdot
.37181 .59091 Mdot
.62696 .5957 Mdot
.51444 .68574 Mdot
.60389 .34874 Mdot
.3395 .40235 Mdot
.32081 .7198 Mdot
.61108 .34766 Mdot
.53582 .64786 Mdot
.36609 .38492 Mdot
.6299 .60006 Mdot
.62938 .60781 Mdot
.56478 .40901 Mdot
.41324 .22116 Mdot
.37154 .55768 Mdot
.36004 .37499 Mdot
.28355 .59536 Mdot
.59332 .4447 Mdot
.58977 .40242 Mdot
.66232 .41068 Mdot
.34795 .57646 Mdot
.3247 .46633 Mdot
.64388 .56286 Mdot
.37023 .41017 Mdot
.57265 .35574 Mdot
.6468 .60363 Mdot
.31008 .46355 Mdot
.46568 .65579 Mdot
.54115 .63751 Mdot
.64104 .61407 Mdot
.63744 .58562 Mdot
.64343 .61342 Mdot
.19408 .4041 Mdot
.33526 .36304 Mdot
.62528 .29601 Mdot
.57369 .44384 Mdot
.75459 .46443 Mdot
.51599 .41703 Mdot
.33982 .55502 Mdot
.52654 .62257 Mdot
.61814 .41764 Mdot
.60789 .34262 Mdot
.67078 .39053 Mdot
.66063 .32528 Mdot
.31992 .35985 Mdot
.3552 .39551 Mdot
.53898 .41813 Mdot
.5179 .61948 Mdot
.36097 .16314 Mdot
.25887 .72808 Mdot
.63348 .33692 Mdot
.4988 .56446 Mdot
.33768 .39854 Mdot
.39191 .59953 Mdot
.57066 .57771 Mdot
.37873 .5379 Mdot
.37139 .40542 Mdot
.60434 .34952 Mdot
.29559 .51421 Mdot
.64126 .6157 Mdot
.5736 .42923 Mdot
.35913 .57669 Mdot
.56568 .42324 Mdot
.39821 .58851 Mdot
.22507 .64758 Mdot
.67128 .7512 Mdot
.58357 .37598 Mdot
.64144 .35483 Mdot
.71805 .58173 Mdot
.60219 .41456 Mdot
.65931 .54115 Mdot
.33532 .3916 Mdot
.78657 .38515 Mdot
.55656 .35579 Mdot
.48855 .2567 Mdot
.59513 .44513 Mdot
.7944 .55628 Mdot
.58999 .40646 Mdot
.57195 .7326 Mdot
.55634 .3855 Mdot
.55528 .4061 Mdot
.38283 .54119 Mdot
.35224 .58492 Mdot
.4109 .41029 Mdot
.52189 .67481 Mdot
.16877 .53816 Mdot
.59211 .39703 Mdot
.3728 .72944 Mdot
.30627 .54552 Mdot
.63579 .58505 Mdot
.37371 .40716 Mdot
.54813 .14291 Mdot
.38064 .53367 Mdot
.70484 .68394 Mdot
.78881 .52972 Mdot
.31603 .61661 Mdot
.58241 .58476 Mdot
.23655 .4103 Mdot
.64407 .6073 Mdot
.55042 .42109 Mdot
.35448 .73989 Mdot
.56368 .75726 Mdot
.59688 .48081 Mdot
.35013 .58724 Mdot
.48495 .29803 Mdot
.33611 .73637 Mdot
.62725 .56755 Mdot
.64922 .56558 Mdot
.40606 .58198 Mdot
.51587 .73201 Mdot
.61663 .30937 Mdot
.64364 .59246 Mdot
.47853 .64228 Mdot
.55182 .64038 Mdot
.45114 .62201 Mdot
.3886 .41113 Mdot
.45703 .80197 Mdot
.25313 .54136 Mdot
.39314 .59022 Mdot
.58625 .66164 Mdot
.32652 .40087 Mdot
.3452 .35107 Mdot
.50432 .66397 Mdot
.53346 .64228 Mdot
.37218 .35614 Mdot
.53901 .37238 Mdot
.66715 .3632 Mdot
.59579 .38269 Mdot
.66502 .59331 Mdot
.59223 .41141 Mdot
.53044 .65592 Mdot
.36349 .56321 Mdot
.52789 .63519 Mdot
.36906 .53191 Mdot
.25235 .60526 Mdot
.57966 .4258 Mdot
.5606 .39416 Mdot
.66207 .25356 Mdot
.39855 .43086 Mdot
.29437 .62811 Mdot
.36173 .72046 Mdot
.49641 .63562 Mdot
.55298 .40961 Mdot
.35907 .42932 Mdot
.6486 .56006 Mdot
.65883 .24845 Mdot
.61246 .42936 Mdot
.33834 .39818 Mdot
.58143 .35052 Mdot
.31459 .30204 Mdot
.80785 .63332 Mdot
.38506 .40243 Mdot
.72158 .28041 Mdot
.59083 .3439 Mdot
.2703 .36274 Mdot
.63984 .40363 Mdot
.77112 .52303 Mdot
.57597 .44227 Mdot
.40584 .40679 Mdot
.59937 .38651 Mdot
.38289 .42498 Mdot
.48126 .66156 Mdot
.40555 .59126 Mdot
.37973 .37168 Mdot
.63752 .39256 Mdot
.17238 .68687 Mdot
.38126 .58439 Mdot
.57618 .38261 Mdot
.4032 .55615 Mdot
.36352 .41804 Mdot
.38493 .37063 Mdot
.36861 .20805 Mdot
.33255 .66272 Mdot
.3895 .57187 Mdot
.59665 .34875 Mdot
.23721 .49723 Mdot
.61304 .36758 Mdot
.74512 .53338 Mdot
.54805 .35307 Mdot
.58639 .44415 Mdot
.29473 .25349 Mdot
.35719 .5842 Mdot
.82343 .42432 Mdot
.35258 .21911 Mdot
.21602 .38266 Mdot
.39544 .44935 Mdot
.63191 .56361 Mdot
.17138 .45919 Mdot
.33906 .68437 Mdot
.5271 .66618 Mdot
.61441 .41988 Mdot
.3189 .39266 Mdot
.36782 .55162 Mdot
.65844 .58057 Mdot
.58286 .37648 Mdot
.53369 .63982 Mdot
.74456 .65226 Mdot
.40025 .54244 Mdot
.38003 .4112 Mdot
.34441 .36656 Mdot
.67012 .21801 Mdot
.56813 .36147 Mdot
.55796 .3947 Mdot
.38438 .58625 Mdot
.29248 .3956 Mdot
.6417 .60815 Mdot
.76437 .60225 Mdot
.38913 .57342 Mdot
.51249 .52811 Mdot
.36023 .4068 Mdot
.61133 .41578 Mdot
.20194 .50107 Mdot
.6296 .74044 Mdot
.57176 .23515 Mdot
.66483 .59883 Mdot
.73941 .53015 Mdot
.40639 .40555 Mdot
.36042 .57053 Mdot
.41977 .71486 Mdot
.58923 .46909 Mdot
.61137 .41068 Mdot
.73746 .5233 Mdot
.47463 .44122 Mdot
.72637 .34696 Mdot
.6109 .43319 Mdot
.49714 .47214 Mdot
.59209 .43938 Mdot
.57031 .46582 Mdot
.53076 .38315 Mdot
.58257 .40139 Mdot
.33787 .3979 Mdot
.58278 .47767 Mdot
.53567 .66555 Mdot
.68425 .31634 Mdot
.5326 .5303 Mdot
.56766 .374 Mdot
.61364 .36069 Mdot
.56358 .25759 Mdot
.40772 .52076 Mdot
.37391 .37235 Mdot
.37538 .34816 Mdot
.4132 .59036 Mdot
.6705 .37724 Mdot
.52309 .67711 Mdot
.52915 .43824 Mdot
.53134 .64494 Mdot
.3492 .41645 Mdot
.48825 .64241 Mdot
.41189 .5796 Mdot
.54989 .64169 Mdot
.33917 .68949 Mdot
.35233 .5582 Mdot
.39989 .40732 Mdot
.56724 .40287 Mdot
.34553 .55178 Mdot
.70868 .45427 Mdot
.6647 .59423 Mdot
.35336 .21307 Mdot
.55574 .36875 Mdot
.31001 .58896 Mdot
.34453 .44886 Mdot
.52861 .63756 Mdot
.82492 .5747 Mdot
.34517 .36835 Mdot
.68442 .59805 Mdot
.35326 .42265 Mdot
.62667 .7803 Mdot
.64784 .57987 Mdot
.26368 .29814 Mdot
.45971 .74774 Mdot
.61531 .55045 Mdot
.54152 .3698 Mdot
.64039 .51112 Mdot
.5279 .68504 Mdot
.36687 .5518 Mdot
.44484 .72219 Mdot
.55521 .41016 Mdot
.71439 .70364 Mdot
.41425 .39425 Mdot
.52535 .67315 Mdot
.36825 .57304 Mdot
.34138 .56216 Mdot
.62467 .41898 Mdot
.61235 .65595 Mdot
.58463 .43621 Mdot
.40354 .68287 Mdot
.73128 .55495 Mdot
.63272 .31478 Mdot
.5677 .38166 Mdot
.49329 .67043 Mdot
.58214 .35035 Mdot
.67539 .62699 Mdot
.44796 .80994 Mdot
.61568 .44495 Mdot
.355 .71409 Mdot
.6787 .5659 Mdot
.36252 .3937 Mdot
.5825 .32015 Mdot
.34916 .68298 Mdot
.57493 .35557 Mdot
.79427 .71007 Mdot
.65107 .60362 Mdot
.38521 .7357 Mdot
.64142 .41384 Mdot
.63442 .39405 Mdot
.5843 .50671 Mdot
.44726 .40632 Mdot
.63636 .73843 Mdot
.60763 .40532 Mdot
.69832 .51407 Mdot
.40314 .57235 Mdot
.5938 .4355 Mdot
.58398 .38541 Mdot
.47384 .37306 Mdot
.34411 .56182 Mdot
.50955 .62982 Mdot
.48904 .68575 Mdot
.5596 .62846 Mdot
.68051 .61771 Mdot
.48525 .48898 Mdot
.74899 .43051 Mdot
.74326 .69326 Mdot
.67725 .60492 Mdot
.56531 .35235 Mdot
.70697 .60052 Mdot
.61492 .35325 Mdot
.64495 .57235 Mdot
.3457 .5607 Mdot
.37265 .37056 Mdot
.28418 .44727 Mdot
.54741 .67409 Mdot
.62847 .42436 Mdot
.6221 .59146 Mdot
.39796 .40714 Mdot
.61446 .61533 Mdot
.3646 .40184 Mdot
.38445 .57248 Mdot
.41882 .5809 Mdot
.6546 .57589 Mdot
.34906 .41251 Mdot
.37526 .50461 Mdot
.42007 .18258 Mdot
.52901 .38094 Mdot
.39772 .61763 Mdot
.389 .43432 Mdot
.37318 .35237 Mdot
.39711 .42365 Mdot
.56583 .41819 Mdot
.49605 .56324 Mdot
.57825 .33342 Mdot
.37362 .59106 Mdot
.51011 .62455 Mdot
.72665 .62211 Mdot
.27427 .65232 Mdot
.6644 .64536 Mdot
.55439 .43794 Mdot
.5989 .37708 Mdot
.57683 .38477 Mdot
.58051 .33738 Mdot
.39183 .68614 Mdot
.60087 .4273 Mdot
.38747 .54292 Mdot
.52407 .64909 Mdot
.54862 .41847 Mdot
.4639 .66975 Mdot
.22677 .44955 Mdot
.67729 .5985 Mdot
.47353 .47267 Mdot
.14566 .61198 Mdot
.40058 .39878 Mdot
.47073 .65194 Mdot
.52455 .66658 Mdot
.65569 .61429 Mdot
.37331 .55395 Mdot
.36352 .407 Mdot
.76335 .54786 Mdot
.63207 .60742 Mdot
.59761 .38796 Mdot
.52617 .58107 Mdot
.70264 .70869 Mdot
.55617 .4294 Mdot
.62734 .39582 Mdot
.46445 .65915 Mdot
.54325 .73492 Mdot
.4691 .84413 Mdot
.7312 .39829 Mdot
.65366 .57736 Mdot
.67457 .58297 Mdot
.37864 .35754 Mdot
.61288 .32577 Mdot
.37707 .59175 Mdot
.71188 .33112 Mdot
.42622 .45532 Mdot
.71059 .37966 Mdot
.48863 .44126 Mdot
.61074 .42861 Mdot
.49963 .18472 Mdot
.59499 .37416 Mdot
.33215 .38351 Mdot
.372 .42122 Mdot
.38987 .38561 Mdot
.36742 .55439 Mdot
.44239 .31192 Mdot
.38827 .54535 Mdot
.1633 .63125 Mdot
.40642 .39715 Mdot
.39677 .71833 Mdot
.49358 .66825 Mdot
.64542 .34815 Mdot
.63256 .60141 Mdot
.33283 .57059 Mdot
.65686 .37961 Mdot
.81738 .54381 Mdot
.53018 .66971 Mdot
.4016 .40503 Mdot
.24121 .40134 Mdot
.20149 .64702 Mdot
.55349 .56722 Mdot
.51818 .43678 Mdot
.62853 .51819 Mdot
.63335 .58564 Mdot
.57695 .23511 Mdot
.62281 .58575 Mdot
.35359 .57041 Mdot
.56468 .39419 Mdot
.57273 .40076 Mdot
.58411 .44074 Mdot
.59094 .42756 Mdot
.3949 .60007 Mdot
.59202 .4485 Mdot
.77193 .69995 Mdot
.5296 .61658 Mdot
.33965 .30867 Mdot
.64647 .60573 Mdot
.37383 .60092 Mdot
.52576 .64984 Mdot
.46324 .68757 Mdot
.7248 .43236 Mdot
.56437 .37873 Mdot
.61617 .41963 Mdot
.6998 .69579 Mdot
.61003 .43446 Mdot
.51243 .40615 Mdot
.52492 .66812 Mdot
.67192 .64479 Mdot
.67968 .58801 Mdot
.66051 .57118 Mdot
.35409 .54966 Mdot
.35131 .41789 Mdot
.65584 .5953 Mdot
.48104 .6579 Mdot
.55175 .43658 Mdot
.63359 .37124 Mdot
.39244 .43221 Mdot
.53661 .80753 Mdot
.62669 .57011 Mdot
.23331 .42109 Mdot
.36991 .42586 Mdot
.32499 .37758 Mdot
.61249 .40911 Mdot
.64251 .4627 Mdot
.36955 .45093 Mdot
.67722 .60884 Mdot
.38105 .60283 Mdot
.57959 .56385 Mdot
.36867 .58533 Mdot
.37397 .41711 Mdot
.63027 .3577 Mdot
.37858 .41973 Mdot
.56584 .36653 Mdot
.1235 .53326 Mdot
.57976 .40413 Mdot
.74181 .70217 Mdot
.75807 .50078 Mdot
.516 .65787 Mdot
.34802 .50647 Mdot
.50846 .6693 Mdot
.37265 .42566 Mdot
.63553 .36685 Mdot
.65214 .56444 Mdot
.23925 .34737 Mdot
.32226 .38881 Mdot
.53978 .65296 Mdot
.55726 .64474 Mdot
.34871 .56234 Mdot
.55364 .43182 Mdot
.60852 .41487 Mdot
.50597 .6501 Mdot
.63489 .31363 Mdot
.34094 .38617 Mdot
.56322 .38853 Mdot
.60749 .37989 Mdot
.5147 .65974 Mdot
.44469 .17113 Mdot
.43372 .38577 Mdot
.57282 .3949 Mdot
.43137 .75132 Mdot
.33909 .55702 Mdot
.54865 .35735 Mdot
.65201 .37729 Mdot
.63883 .58792 Mdot
.39701 .32831 Mdot
.4293 .80179 Mdot
.35109 .5435 Mdot
.50916 .67345 Mdot
.56855 .35984 Mdot
.49646 .6713 Mdot
.63599 .38152 Mdot
.41531 .34771 Mdot
.54242 .66618 Mdot
.63133 .38225 Mdot
.60983 .32202 Mdot
.38693 .41952 Mdot
.61356 .42462 Mdot
.5647 .2726 Mdot
.48488 .67883 Mdot
.63279 .40012 Mdot
.41 .2243 Mdot
.38268 .55194 Mdot
.61425 .32295 Mdot
.67258 .60193 Mdot
.76477 .5501 Mdot
.27577 .53764 Mdot
.3754 .74327 Mdot
.6747 .59089 Mdot
.56685 .42589 Mdot
.5567 .63563 Mdot
.40251 .5859 Mdot
.75598 .67465 Mdot
.55513 .42244 Mdot
.37815 .58615 Mdot
.36399 .56505 Mdot
.66621 .60471 Mdot
.77156 .31114 Mdot
.6396 .42274 Mdot
.59887 .41476 Mdot
.51017 .32633 Mdot
.3658 .44085 Mdot
.58604 .41071 Mdot
.59064 .34112 Mdot
.39241 .54574 Mdot
.51063 .40256 Mdot
.51547 .27701 Mdot
.7753 .57501 Mdot
.33969 .54482 Mdot
.57969 .53958 Mdot
.54821 .66526 Mdot
.64158 .60186 Mdot
.3685 .39291 Mdot
.62095 .58301 Mdot
.54521 .63542 Mdot
.57235 .34727 Mdot
.39627 .54359 Mdot
.61756 .26845 Mdot
.40569 .58383 Mdot
.38184 .74656 Mdot
.37126 .43947 Mdot
.27071 .46968 Mdot
.83291 .64666 Mdot
.25064 .55026 Mdot
.40678 .52189 Mdot
.63613 .58494 Mdot
.49022 .70015 Mdot
.60503 .37846 Mdot
.59734 .23763 Mdot
.56301 .40501 Mdot
.41461 .22545 Mdot
.48666 .63371 Mdot
.54616 .62408 Mdot
.56832 .39455 Mdot
.73507 .55011 Mdot
.4012 .58921 Mdot
.35336 .57997 Mdot
.62944 .40801 Mdot
.38177 .56636 Mdot
.59805 .4048 Mdot
.53209 .65052 Mdot
.83845 .46213 Mdot
.58989 .38014 Mdot
.62851 .34475 Mdot
.33649 .61451 Mdot
.3058 .25276 Mdot
.45838 .77626 Mdot
.54974 .19498 Mdot
.22439 .6771 Mdot
.38109 .56703 Mdot
.58238 .33059 Mdot
.58384 .53764 Mdot
.46309 .6705 Mdot
.38036 .50461 Mdot
.57609 .41074 Mdot
.57354 .41292 Mdot
.55397 .40286 Mdot
.61859 .37695 Mdot
.57769 .22937 Mdot
.614 .28832 Mdot
.40442 .26212 Mdot
.62197 .41574 Mdot
.66745 .48641 Mdot
.35594 .5442 Mdot
.4148 .38688 Mdot
.6136 .60292 Mdot
.61067 .42838 Mdot
.62358 .29222 Mdot
.33752 .56743 Mdot
.16448 .63297 Mdot
.35009 .556 Mdot
.50438 .63483 Mdot
.39402 .59836 Mdot
.57795 .36587 Mdot
.37736 .39616 Mdot
.55326 .54165 Mdot
.40431 .65094 Mdot
.52792 .66574 Mdot
.5695 .37062 Mdot
.38048 .71583 Mdot
.53432 .66494 Mdot
.22561 .4552 Mdot
.37395 .39093 Mdot
.69641 .50567 Mdot
.37345 .42167 Mdot
.63158 .38049 Mdot
.628 .37361 Mdot
.38492 .61274 Mdot
.40761 .58761 Mdot
.37076 .42238 Mdot
.79341 .33054 Mdot
.61885 .5925 Mdot
.39255 .39168 Mdot
.56548 .45794 Mdot
.44418 .50605 Mdot
.37947 .38963 Mdot
.64378 .64041 Mdot
.36118 .55299 Mdot
.39897 .37803 Mdot
.58477 .46621 Mdot
.54912 .79084 Mdot
.6667 .61562 Mdot
.5365 .60956 Mdot
.53479 .58873 Mdot
.47834 .67434 Mdot
.4022 .6021 Mdot
.51244 .66808 Mdot
.40272 .56843 Mdot
.29433 .55351 Mdot
.69425 .33275 Mdot
.42431 .57786 Mdot
.40149 .60066 Mdot
.51288 .66588 Mdot
.55933 .38759 Mdot
.55867 .58964 Mdot
.56737 .33852 Mdot
.62796 .44606 Mdot
.39898 .56723 Mdot
.40421 .40856 Mdot
.35956 .35536 Mdot
.66176 .50102 Mdot
.33928 .36997 Mdot
.53232 .64423 Mdot
.79008 .65376 Mdot
.35712 .73275 Mdot
.39576 .58058 Mdot
.37707 .59909 Mdot
.61376 .36579 Mdot
.49546 .65361 Mdot
.48734 .6701 Mdot
.35122 .57092 Mdot
.68906 .36648 Mdot
.62 .33353 Mdot
.36569 .34785 Mdot
.40416 .38826 Mdot
.38554 .39708 Mdot
.39491 .42347 Mdot
.51806 .25122 Mdot
.35789 .55408 Mdot
.40164 .41288 Mdot
.63187 .39173 Mdot
.57534 .41281 Mdot
.56728 .55525 Mdot
.66869 .5772 Mdot
.54209 .40218 Mdot
.53092 .38753 Mdot
.61446 .41076 Mdot
.54257 .64066 Mdot
.64713 .43429 Mdot
.54069 .66912 Mdot
.55207 .62081 Mdot
.50904 .61861 Mdot
.33975 .68631 Mdot
.65971 .52938 Mdot
.26302 .71578 Mdot
.59325 .34685 Mdot
.29076 .36427 Mdot
.49025 .66053 Mdot
.82199 .5615 Mdot
.32208 .46199 Mdot
.55307 .41528 Mdot
.6111 .74641 Mdot
.50626 .65234 Mdot
.34174 .36677 Mdot
.57743 .40886 Mdot
.55184 .61716 Mdot
.67024 .6089 Mdot
.53754 .42977 Mdot
.48422 .68237 Mdot
.35189 .41438 Mdot
.64045 .62175 Mdot
.40771 .39261 Mdot
.5023 .62154 Mdot
.61147 .32241 Mdot
.49741 .88692 Mdot
.55661 .66386 Mdot
.30519 .28174 Mdot
.42711 .42474 Mdot
.56178 .38888 Mdot
.47068 .6607 Mdot
.35859 .43602 Mdot
.41109 .60016 Mdot
.43516 .45994 Mdot
.36136 .36506 Mdot
.54701 .62545 Mdot
.48113 .67957 Mdot
.52594 .66783 Mdot
.35521 .38987 Mdot
.62115 .34263 Mdot
.35056 .38359 Mdot
.39143 .59892 Mdot
.60173 .36487 Mdot
.17988 .61002 Mdot
.29213 .3695 Mdot
.37018 .42445 Mdot
.51678 .62796 Mdot
.64264 .61765 Mdot
.58572 .37326 Mdot
.33506 .26047 Mdot
.55914 .37358 Mdot
.40063 .58066 Mdot
.81929 .476 Mdot
.61282 .26416 Mdot
.57652 .44366 Mdot
.61435 .36651 Mdot
.36294 .58717 Mdot
.57334 .37589 Mdot
.57053 .44172 Mdot
.33773 .67808 Mdot
.35192 .39631 Mdot
.60124 .38443 Mdot
.49606 .63016 Mdot
.3183 .68626 Mdot
.60677 .33151 Mdot
.68054 .66574 Mdot
.71098 .51892 Mdot
.80595 .41624 Mdot
.56096 .40327 Mdot
.72137 .38709 Mdot
.62135 .38495 Mdot
.57619 .42898 Mdot
.60635 .35493 Mdot
.59936 .2202 Mdot
.54386 .65924 Mdot
.52617 .65988 Mdot
.67069 .61396 Mdot
.70809 .5181 Mdot
.64288 .58846 Mdot
.36139 .54944 Mdot
.64085 .67033 Mdot
.54208 .66617 Mdot
.35406 .41782 Mdot
.57379 .43193 Mdot
.55679 .66434 Mdot
.60887 .41839 Mdot
.57702 .36448 Mdot
.51225 .68068 Mdot
.54241 .67487 Mdot
.37999 .73841 Mdot
.67536 .60008 Mdot
.38477 .37805 Mdot
.53973 .39069 Mdot
.62439 .59718 Mdot
.63095 .35272 Mdot
.75564 .45836 Mdot
.38475 .3802 Mdot
.3509 .39269 Mdot
.35439 .35852 Mdot
.57201 .34771 Mdot
.57816 .36941 Mdot
.39079 .54766 Mdot
.35584 .42304 Mdot
.38246 .5536 Mdot
.52014 .51522 Mdot
.69906 .65695 Mdot
.57599 .41083 Mdot
.23978 .41864 Mdot
.63478 .5966 Mdot
.51927 .6351 Mdot
.71643 .6695 Mdot
.66855 .61597 Mdot
.56363 .37051 Mdot
.4974 .67407 Mdot
.65108 .57167 Mdot
.55609 .4829 Mdot
.31822 .77296 Mdot
.63012 .61401 Mdot
.6315 .39616 Mdot
.50695 .38822 Mdot
.5712 .1876 Mdot
.66092 .62162 Mdot
.40796 .56283 Mdot
.56891 .35002 Mdot
.33532 .43755 Mdot
.62801 .5702 Mdot
.29082 .62139 Mdot
.51647 .65016 Mdot
.48396 .79825 Mdot
.65514 .4056 Mdot
.63706 .25682 Mdot
.62786 .57817 Mdot
.36635 .40836 Mdot
.4212 .39242 Mdot
.61675 .4009 Mdot
.65974 .62192 Mdot
.33782 .5447 Mdot
.51786 .64427 Mdot
.32242 .66083 Mdot
.355 .38721 Mdot
.2508 .45512 Mdot
.52513 .62682 Mdot
.2352 .43541 Mdot
.79952 .53704 Mdot
.65405 .34215 Mdot
.56162 .19506 Mdot
.47669 .73128 Mdot
.56125 .35414 Mdot
.61834 .59805 Mdot
.34923 .54571 Mdot
.41028 .56445 Mdot
.38654 .57571 Mdot
.30266 .54794 Mdot
.56808 .56473 Mdot
.47296 .64298 Mdot
.43665 .64039 Mdot
.64471 .60166 Mdot
.68221 .46401 Mdot
.63968 .38406 Mdot
.59728 .37775 Mdot
.55179 .43122 Mdot
.60219 .43428 Mdot
.61768 .38926 Mdot
.37878 .55779 Mdot
.29626 .57109 Mdot
.58281 .55031 Mdot
.38193 .38368 Mdot
.60464 .64628 Mdot
.49308 .66747 Mdot
.47844 .63376 Mdot
.66312 .57693 Mdot
.22645 .42034 Mdot
.46595 .67186 Mdot
.49221 .63794 Mdot
.54857 .38386 Mdot
.34479 .38605 Mdot
.54476 .45936 Mdot
.62537 .37428 Mdot
.5254 .64101 Mdot
.5655 .51328 Mdot
.53934 .2687 Mdot
.62796 .46152 Mdot
.69738 .60971 Mdot
.49426 .55784 Mdot
.6483 .62052 Mdot
.64045 .37301 Mdot
.8222 .54924 Mdot
.54644 .63844 Mdot
.49786 .64247 Mdot
.62723 .58264 Mdot
.34048 .33145 Mdot
.36367 .38591 Mdot
.46502 .69266 Mdot
.40467 .56101 Mdot
.62145 .35994 Mdot
.74143 .64699 Mdot
.3136 .33726 Mdot
.61513 .66112 Mdot
.38861 .5791 Mdot
.48497 .66584 Mdot
.5615 .44098 Mdot
.63095 .39557 Mdot
.62933 .59095 Mdot
.21138 .5984 Mdot
.53386 .41608 Mdot
.20841 .39002 Mdot
.66938 .75475 Mdot
.54656 .7996 Mdot
.61117 .41073 Mdot
.35309 .3956 Mdot
.47594 .67846 Mdot
.62623 .59371 Mdot
.59329 .45778 Mdot
.30071 .75515 Mdot
.4074 .41952 Mdot
.35592 .56921 Mdot
.56131 .53162 Mdot
.56859 .57696 Mdot
.55342 .37198 Mdot
.56431 .40458 Mdot
.57242 .42241 Mdot
.38471 .80698 Mdot
.53998 .64309 Mdot
.34179 .40784 Mdot
.66837 .59552 Mdot
.33615 .37346 Mdot
.52112 .66084 Mdot
.25769 .46557 Mdot
.55711 .38179 Mdot
.40547 .42247 Mdot
.36704 .40594 Mdot
.34963 .56006 Mdot
.41485 .59757 Mdot
.53898 .52531 Mdot
.58164 .40424 Mdot
.55173 .67511 Mdot
.39536 .41534 Mdot
.53267 .58062 Mdot
.64568 .58008 Mdot
.37166 .54117 Mdot
.61917 .4185 Mdot
.54629 .64994 Mdot
.59242 .44882 Mdot
.36964 .37735 Mdot
.49055 .63968 Mdot
.37882 .73347 Mdot
.67584 .5871 Mdot
.58522 .42066 Mdot
.66279 .62567 Mdot
.50881 .6738 Mdot
.60706 .37787 Mdot
.25422 .37222 Mdot
.69789 .59816 Mdot
.37948 .65197 Mdot
.48663 .63154 Mdot
.37317 .72762 Mdot
.36533 .35902 Mdot
.31368 .52087 Mdot
.50144 .63913 Mdot
.23515 .40138 Mdot
.23943 .63057 Mdot
.54404 .42554 Mdot
.3848 .40821 Mdot
.50547 .7162 Mdot
.14915 .545 Mdot
.43943 .17795 Mdot
.57802 .38312 Mdot
.47521 .64314 Mdot
.62928 .58231 Mdot
.39696 .57962 Mdot
.68522 .66473 Mdot
.69866 .61324 Mdot
.55414 .66144 Mdot
.60717 .35431 Mdot
.36309 .41536 Mdot
.36433 .55723 Mdot
.28055 .54338 Mdot
.48132 .64669 Mdot
.51808 .62353 Mdot
.56444 .4422 Mdot
.64745 .59302 Mdot
.3818 .22331 Mdot
.53288 .6536 Mdot
.69403 .70742 Mdot
.51456 .69134 Mdot
.62096 .59473 Mdot
.62525 .3895 Mdot
.64864 .51276 Mdot
.56686 .34246 Mdot
.28103 .29879 Mdot
.50436 .66795 Mdot
.37547 .37675 Mdot
.56091 .41251 Mdot
.78536 .55341 Mdot
.52186 .63958 Mdot
.50172 .56439 Mdot
.56333 .74034 Mdot
.35932 .55372 Mdot
.71636 .67209 Mdot
.59105 .4149 Mdot
.40219 .5877 Mdot
.63493 .59569 Mdot
.57799 .39707 Mdot
.581 .36826 Mdot
.34005 .4111 Mdot
.35413 .57358 Mdot
.25918 .6666 Mdot
.34286 .57674 Mdot
.3697 .53716 Mdot
.32951 .37475 Mdot
.60581 .39657 Mdot
.50562 .63331 Mdot
.5042 .65206 Mdot
.61175 .45568 Mdot
.83871 .54463 Mdot
.36129 .38397 Mdot
.5821 .66385 Mdot
.40877 .81853 Mdot
.64876 .33389 Mdot
.72207 .66576 Mdot
.21103 .58924 Mdot
.34524 .53843 Mdot
.6266 .41187 Mdot
.35785 .41813 Mdot
.46206 .6842 Mdot
.51611 .62499 Mdot
.62339 .34638 Mdot
.36771 .56266 Mdot
.66992 .61057 Mdot
.50764 .68418 Mdot
.61548 .65498 Mdot
.58211 .42807 Mdot
.60821 .75048 Mdot
.47463 .66329 Mdot
.17429 .41634 Mdot
.48484 .70731 Mdot
.3882 .40436 Mdot
.58039 .36341 Mdot
.35196 .36385 Mdot
.66731 .58984 Mdot
.55629 .53229 Mdot
.36524 .56268 Mdot
.53499 .32707 Mdot
.72706 .76108 Mdot
.52316 .66981 Mdot
.33541 .39265 Mdot
.57859 .44416 Mdot
.5553 .49499 Mdot
.5959 .41187 Mdot
.52869 .34585 Mdot
.68929 .57363 Mdot
.39548 .56249 Mdot
.40502 .57651 Mdot
.60482 .37298 Mdot
.63925 .60955 Mdot
.4843 .66244 Mdot
.51642 .64185 Mdot
.25622 .2625 Mdot
.38352 .63465 Mdot
.74756 .56252 Mdot
.57613 .41578 Mdot
.55341 .63748 Mdot
.28548 .66123 Mdot
.38577 .58569 Mdot
.63922 .39953 Mdot
.52446 .67624 Mdot
.57391 .77624 Mdot
.77994 .52194 Mdot
.61985 .39223 Mdot
.64987 .40446 Mdot
.40513 .56034 Mdot
.69849 .44036 Mdot
.51089 .61963 Mdot
.54641 .35381 Mdot
.41699 .563 Mdot
.80849 .47416 Mdot
.48902 .82102 Mdot
.38542 .37854 Mdot
.55024 .7366 Mdot
.37802 .55696 Mdot
.63127 .44725 Mdot
.65338 .60795 Mdot
.51248 .68669 Mdot
.54303 .64795 Mdot
.59436 .35053 Mdot
.59047 .44809 Mdot
.7158 .59028 Mdot
.33684 .37973 Mdot
.35595 .54509 Mdot
.56018 .39759 Mdot
.27425 .43251 Mdot
.58752 .44053 Mdot
.38848 .54803 Mdot
.47857 .89611 Mdot
.53852 .3996 Mdot
.59855 .41207 Mdot
.38326 .22062 Mdot
.36307 .365 Mdot
.33298 .37658 Mdot
.70654 .73282 Mdot
.57684 .41632 Mdot
.70907 .68594 Mdot
.38241 .37465 Mdot
.36357 .38195 Mdot
.34674 .667 Mdot
.58912 .37539 Mdot
.69086 .29846 Mdot
.39848 .5871 Mdot
.37851 .53683 Mdot
.35228 .38344 Mdot
.53705 .40803 Mdot
.37452 .53128 Mdot
.53317 .22055 Mdot
.49519 .65526 Mdot
.82733 .53026 Mdot
.36185 .3722 Mdot
.48578 .46854 Mdot
.38933 .58207 Mdot
.16118 .62845 Mdot
.45064 .64408 Mdot
.55935 .38974 Mdot
.5816 .42164 Mdot
.63672 .59898 Mdot
.53948 .40206 Mdot
.54424 .62168 Mdot
.38212 .56614 Mdot
.35235 .26925 Mdot
.39079 .38678 Mdot
.58878 .40498 Mdot
.22816 .43687 Mdot
.25785 .58916 Mdot
.472 .76474 Mdot
.36326 .39452 Mdot
.38831 .40996 Mdot
.51158 .62032 Mdot
.47341 .64703 Mdot
.61184 .39776 Mdot
.36307 .58574 Mdot
.35888 .42451 Mdot
.395 .55562 Mdot
.5458 .63785 Mdot
.50379 .6321 Mdot
.54499 .66251 Mdot
.52305 .4061 Mdot
.49118 .6363 Mdot
.64215 .64858 Mdot
.24868 .46523 Mdot
.34409 .35128 Mdot
.58479 .81541 Mdot
.28363 .53885 Mdot
.40152 .46578 Mdot
.64123 .56355 Mdot
.5089 .67419 Mdot
.37439 .59686 Mdot
.61359 .37097 Mdot
.61259 .41944 Mdot
.50553 .60774 Mdot
.38661 .59707 Mdot
.6615 .58274 Mdot
.4005 .59188 Mdot
.66595 .60549 Mdot
.5741 .75338 Mdot
.551 .42694 Mdot
.63233 .37151 Mdot
.38337 .56212 Mdot
.48875 .63989 Mdot
.52389 .65312 Mdot
.63466 .61746 Mdot
.46564 .41482 Mdot
.53371 .66646 Mdot
.36399 .37322 Mdot
.50767 .24351 Mdot
.47819 .67804 Mdot
.58079 .40998 Mdot
.7497 .42185 Mdot
.6161 .24967 Mdot
.58268 .33642 Mdot
.3409 .67041 Mdot
.70506 .2817 Mdot
.55966 .41943 Mdot
.70586 .26965 Mdot
.37126 .72399 Mdot
.35482 .36491 Mdot
.4918 .62972 Mdot
.4645 .65078 Mdot
.53813 .34327 Mdot
.61097 .59046 Mdot
.59758 .45896 Mdot
.3688 .36575 Mdot
.41302 .42219 Mdot
.5884 .78408 Mdot
.301 .28397 Mdot
.63339 .57661 Mdot
.65898 .57237 Mdot
.50377 .63978 Mdot
.41929 .16706 Mdot
.60723 .47019 Mdot
.65614 .57842 Mdot
.69769 .34805 Mdot
.60729 .35265 Mdot
.74189 .51264 Mdot
.67214 .72259 Mdot
.3533 .39059 Mdot
.64354 .51105 Mdot
.51068 .63573 Mdot
.34084 .37288 Mdot
.28726 .44335 Mdot
.54304 .38611 Mdot
.38629 .3822 Mdot
.39569 .55443 Mdot
.45529 .71393 Mdot
.38545 .37152 Mdot
.75299 .43493 Mdot
.35191 .57409 Mdot
.52757 .57822 Mdot
.67828 .49716 Mdot
.89915 .48457 Mdot
.37835 .56057 Mdot
.53021 .67882 Mdot
.50511 .65136 Mdot
.51475 .6415 Mdot
.33794 .37409 Mdot
.49019 .6711 Mdot
.33586 .38622 Mdot
.51602 .16743 Mdot
.46715 .41089 Mdot
.65257 .57595 Mdot
.32948 .65892 Mdot
.37484 .41177 Mdot
.80995 .62113 Mdot
.79506 .69277 Mdot
.62494 .41545 Mdot
.35784 .59068 Mdot
.6454 .57329 Mdot
.22187 .35371 Mdot
.63742 .59052 Mdot
.60304 .56943 Mdot
.82583 .48871 Mdot
.59417 .40184 Mdot
.4795 .3144 Mdot
.6577 .56741 Mdot
.36051 .40494 Mdot
.6041 .37691 Mdot
.40404 .51343 Mdot
.64108 .59344 Mdot
.66486 .61174 Mdot
.61018 .38956 Mdot
.40148 .40562 Mdot
.51358 .63168 Mdot
.40999 .58984 Mdot
.68675 .60008 Mdot
.40705 .36144 Mdot
.55266 .36324 Mdot
.56734 .35783 Mdot
.5403 .56141 Mdot
.61718 .62615 Mdot
.38036 .5668 Mdot
.64376 .24027 Mdot
.47779 .64143 Mdot
.52954 .7136 Mdot
.66984 .74566 Mdot
.34613 .68231 Mdot
.50585 .66655 Mdot
.50917 .67203 Mdot
.61691 .39301 Mdot
.63655 .63443 Mdot
.81611 .44762 Mdot
.36841 .50871 Mdot
.47361 .67654 Mdot
.51912 .64299 Mdot
.41728 .41138 Mdot
.59983 .78415 Mdot
.59043 .45723 Mdot
.35444 .5403 Mdot
.54505 .65102 Mdot
.39813 .33843 Mdot
.64956 .59646 Mdot
.81278 .59312 Mdot
.55084 .42509 Mdot
.56087 .39363 Mdot
.37371 .57383 Mdot
.38684 .54413 Mdot
.43955 .59519 Mdot
.65323 .76275 Mdot
.6825 .27085 Mdot
.28233 .56641 Mdot
.44893 .36884 Mdot
.41628 .40426 Mdot
.37083 .42438 Mdot
.30754 .6272 Mdot
.33991 .57287 Mdot
.56043 .41687 Mdot
.35714 .42162 Mdot
.45996 .7416 Mdot
.29676 .37442 Mdot
.74305 .53617 Mdot
.72577 .64013 Mdot
.56625 .36782 Mdot
.34678 .39581 Mdot
.3617 .36653 Mdot
.37127 .43135 Mdot
.36986 .72073 Mdot
.60728 .40585 Mdot
.5672 .37979 Mdot
.5672 .43155 Mdot
.68042 .36504 Mdot
.5959 .42888 Mdot
.31213 .54154 Mdot
.51445 .53224 Mdot
.36446 .30521 Mdot
.54001 .36334 Mdot
.35852 .53332 Mdot
.55469 .36805 Mdot
.64289 .61103 Mdot
.60972 .35852 Mdot
.74698 .53865 Mdot
.36884 .58163 Mdot
.43521 .40102 Mdot
.29147 .54653 Mdot
.55018 .39399 Mdot
.67942 .5998 Mdot
.43612 .43835 Mdot
.22156 .64695 Mdot
.60662 .59447 Mdot
.36323 .37332 Mdot
.49715 .66099 Mdot
.37585 .59654 Mdot
.49791 .63661 Mdot
.52469 .41076 Mdot
.31865 .63056 Mdot
.22471 .53914 Mdot
.5207 .50569 Mdot
.60664 .43078 Mdot
.6624 .3985 Mdot
.36495 .37732 Mdot
.49809 .67449 Mdot
.3101 .36806 Mdot
.56456 .41522 Mdot
.66572 .59651 Mdot
.64088 .59717 Mdot
.39404 .49977 Mdot
.17934 .49771 Mdot
.33328 .50121 Mdot
.37654 .57303 Mdot
.53526 .65322 Mdot
.62245 .58396 Mdot
.27533 .37104 Mdot
.41219 .6017 Mdot
.36251 .58732 Mdot
.35285 .56593 Mdot
.59708 .34334 Mdot
.54119 .66888 Mdot
.36377 .29967 Mdot
.55092 .63338 Mdot
.57184 .37317 Mdot
.53912 .63854 Mdot
.52749 .67295 Mdot
.64225 .60465 Mdot
.35192 .5513 Mdot
.53966 .62668 Mdot
.632 .38062 Mdot
.39608 .388 Mdot
.47029 .44111 Mdot
.76911 .5017 Mdot
.28525 .31231 Mdot
.31097 .31253 Mdot
.39604 .37822 Mdot
.15902 .55836 Mdot
.33877 .55428 Mdot
.68895 .3731 Mdot
.41573 .75056 Mdot
.62556 .35316 Mdot
.82285 .61509 Mdot
.47154 .64491 Mdot
.51777 .68095 Mdot
.62459 .3865 Mdot
.51721 .7328 Mdot
.59186 .40687 Mdot
.53701 .6294 Mdot
.59809 .64891 Mdot
.60366 .31831 Mdot
.48306 .65218 Mdot
.54476 .3539 Mdot
.59064 .37076 Mdot
.35201 .39107 Mdot
.47165 .66368 Mdot
.63818 .40504 Mdot
.22134 .32064 Mdot
.38089 .54327 Mdot
.37299 .71165 Mdot
.75371 .39861 Mdot
.37753 .55552 Mdot
.39129 .39262 Mdot
.62521 .44796 Mdot
.63162 .5933 Mdot
.37207 .41466 Mdot
.78414 .52417 Mdot
.663 .5715 Mdot
.81256 .62696 Mdot
.35663 .37352 Mdot
.47534 .67537 Mdot
.65279 .6097 Mdot
.57972 .33214 Mdot
.51562 .68612 Mdot
.41654 .46671 Mdot
.50264 .66689 Mdot
.60764 .41573 Mdot
.3156 .65133 Mdot
.36111 .54115 Mdot
.57945 .38523 Mdot
.50413 .68265 Mdot
.33403 .67757 Mdot
.59619 .34408 Mdot
.61532 .37768 Mdot
.54485 .80572 Mdot
.77946 .64151 Mdot
.6385 .58257 Mdot
.357 .43279 Mdot
.63191 .39088 Mdot
.66957 .60734 Mdot
.6157 .71836 Mdot
.56229 .35762 Mdot
.40027 .42632 Mdot
.64974 .44611 Mdot
.48044 .67163 Mdot
.37627 .5494 Mdot
.51194 .50255 Mdot
.67066 .6083 Mdot
.72139 .23242 Mdot
.55163 .64424 Mdot
.64162 .37916 Mdot
.60934 .4313 Mdot
.46543 .77783 Mdot
.35218 .36744 Mdot
.69306 .2882 Mdot
.58498 .42079 Mdot
.67739 .35463 Mdot
.58105 .39618 Mdot
.58234 .63411 Mdot
.36315 .38449 Mdot
.60043 .41506 Mdot
.24415 .43339 Mdot
.62401 .33869 Mdot
.67518 .60589 Mdot
.4151 .19817 Mdot
.55938 .35454 Mdot
.60843 .86152 Mdot
.70164 .68495 Mdot
.48264 .65015 Mdot
.30607 .6321 Mdot
.40952 .14244 Mdot
.30048 .5414 Mdot
.33654 .39256 Mdot
.2125 .56936 Mdot
.50579 .6328 Mdot
.29147 .63843 Mdot
.1553 .55865 Mdot
.59241 .3685 Mdot
.55333 .37219 Mdot
.60691 .56422 Mdot
.53558 .61554 Mdot
.54477 .68034 Mdot
.52626 .39383 Mdot
.58532 .4716 Mdot
.50492 .62874 Mdot
.63438 .3934 Mdot
.52313 .38554 Mdot
.404 .59474 Mdot
.39875 .38319 Mdot
.39873 .57448 Mdot
.34715 .56029 Mdot
.50373 .19563 Mdot
.63284 .76596 Mdot
.38376 .54609 Mdot
.34435 .54696 Mdot
.74555 .5153 Mdot
.70709 .55404 Mdot
.62991 .56864 Mdot
.18425 .43443 Mdot
.51391 .64385 Mdot
.60551 .4033 Mdot
.38422 .36596 Mdot
.6464 .26353 Mdot
.67251 .68871 Mdot
.82249 .45462 Mdot
.56275 .41664 Mdot
.51701 .6376 Mdot
.36875 .72064 Mdot
.53314 .44681 Mdot
.51528 .70274 Mdot
.55747 .39626 Mdot
.5487 .67264 Mdot
.48851 .27089 Mdot
.23396 .4129 Mdot
.53677 .68528 Mdot
.36673 .34615 Mdot
.56571 .39799 Mdot
.36159 .37078 Mdot
.39259 .57697 Mdot
.63741 .60608 Mdot
.64212 .58203 Mdot
.60903 .38144 Mdot
.66651 .35697 Mdot
.5865 .75168 Mdot
.58563 .37242 Mdot
.6026 .35529 Mdot
.37123 .72413 Mdot
.6037 .35797 Mdot
.59865 .43451 Mdot
.58422 .4369 Mdot
.64611 .36965 Mdot
.37274 .53688 Mdot
.22948 .43523 Mdot
.53569 .43878 Mdot
.52141 .42076 Mdot
.41378 .56996 Mdot
.22225 .62443 Mdot
.34407 .56503 Mdot
.18156 .61444 Mdot
.40184 .57839 Mdot
.65173 .58044 Mdot
.38065 .75599 Mdot
.66595 .37334 Mdot
.39785 .41776 Mdot
.39191 .60492 Mdot
.66911 .59918 Mdot
.38533 .57131 Mdot
.53094 .62897 Mdot
.43455 .81545 Mdot
.3591 .33907 Mdot
.7178 .34257 Mdot
.37639 .48991 Mdot
.393 .64469 Mdot
.54313 .62736 Mdot
.35792 .38277 Mdot
.53399 .27689 Mdot
.59354 .43812 Mdot
.66816 .6074 Mdot
.61283 .39339 Mdot
.36257 .53781 Mdot
.51104 .63769 Mdot
.41606 .19249 Mdot
.62981 .59177 Mdot
.58944 .80811 Mdot
.51769 .65224 Mdot
.57214 .43745 Mdot
.35686 .53898 Mdot
.63884 .80005 Mdot
.39809 .5687 Mdot
.54902 .30787 Mdot
.40213 .37289 Mdot
.54837 .19113 Mdot
.3799 .40956 Mdot
.47021 .69475 Mdot
.46662 .85147 Mdot
.22653 .37644 Mdot
.40135 .4016 Mdot
.42715 .62941 Mdot
.56727 .36212 Mdot
.56481 .3601 Mdot
.27759 .35317 Mdot
.36073 .43418 Mdot
.62083 .42011 Mdot
.37891 .72967 Mdot
.24728 .49357 Mdot
.73211 .671 Mdot
.5002 .67059 Mdot
.58992 .41144 Mdot
.41557 .56473 Mdot
.39688 .59293 Mdot
.553 .64331 Mdot
.34395 .57109 Mdot
.56935 .37966 Mdot
.37614 .41078 Mdot
.56196 .66007 Mdot
.65466 .58779 Mdot
.26923 .28201 Mdot
.61725 .59104 Mdot
.50669 .66628 Mdot
.61473 .32384 Mdot
.50289 .63218 Mdot
.45828 .11001 Mdot
.56591 .38422 Mdot
.37921 .37385 Mdot
.61963 .37032 Mdot
.56914 .39656 Mdot
.5531 .37136 Mdot
.51887 .62701 Mdot
.71249 .30864 Mdot
.63372 .3862 Mdot
.36412 .56172 Mdot
.38313 .31937 Mdot
.55037 .37238 Mdot
.58825 .64907 Mdot
.71928 .54343 Mdot
.44067 .64502 Mdot
.38612 .36432 Mdot
.48774 .66275 Mdot
.39501 .39166 Mdot
.30884 .35479 Mdot
.391 .39222 Mdot
.42608 .33013 Mdot
.52356 .27605 Mdot
.73168 .32209 Mdot
.40106 .23012 Mdot
.6374 .48711 Mdot
.35851 .43336 Mdot
.65383 .54002 Mdot
.36917 .42653 Mdot
.35832 .36811 Mdot
.28822 .82641 Mdot
.39012 .42124 Mdot
.58186 .414 Mdot
.54476 .39838 Mdot
.25694 .55796 Mdot
.73236 .48183 Mdot
.60695 .3665 Mdot
.62886 .38315 Mdot
.63746 .60439 Mdot
.65709 .32774 Mdot
.32005 .63418 Mdot
.77469 .66842 Mdot
.2649 .60653 Mdot
.61193 .39052 Mdot
.63154 .3848 Mdot
.56054 .46597 Mdot
.631 .82533 Mdot
.54693 .20951 Mdot
.38284 .44095 Mdot
.62982 .45035 Mdot
.2601 .321 Mdot
.55243 .39492 Mdot
.58823 .341 Mdot
.56591 .36657 Mdot
.50625 .63301 Mdot
.41045 .41376 Mdot
.60924 .46245 Mdot
.66725 .73594 Mdot
.55296 .38509 Mdot
.34327 .67969 Mdot
.52149 .14743 Mdot
.59122 .41561 Mdot
.41069 .40248 Mdot
.58071 .35047 Mdot
.35007 .37438 Mdot
.35538 .4045 Mdot
.62601 .33363 Mdot
.43936 .35817 Mdot
.41357 .40289 Mdot
.57198 .37243 Mdot
.521 .63125 Mdot
.17448 .44272 Mdot
.60642 .41768 Mdot
.62489 .59654 Mdot
.58136 .42056 Mdot
.68086 .60067 Mdot
.59823 .35732 Mdot
.55245 .64849 Mdot
.61154 .25972 Mdot
.49991 .64237 Mdot
.5899 .18837 Mdot
.54551 .66711 Mdot
.55423 .80564 Mdot
.38944 .43578 Mdot
.32106 .6563 Mdot
.79185 .35793 Mdot
.36307 .69913 Mdot
.47999 .56341 Mdot
.47873 .53413 Mdot
.36207 .58531 Mdot
.35527 .3623 Mdot
.69897 .40881 Mdot
.46633 .75663 Mdot
.4498 .76417 Mdot
.5348 .66934 Mdot
.79024 .33009 Mdot
.83467 .47119 Mdot
.62591 .36547 Mdot
.46245 .32564 Mdot
.41328 .27087 Mdot
.5618 .35509 Mdot
.62979 .44532 Mdot
.53113 .60628 Mdot
.62038 .42615 Mdot
.26924 .42868 Mdot
.51148 .66438 Mdot
.66905 .60097 Mdot
.36999 .3727 Mdot
.66672 .61448 Mdot
.46028 .75797 Mdot
.4757 .53541 Mdot
.54102 .63291 Mdot
.63787 .35463 Mdot
.62294 .37602 Mdot
.34874 .38552 Mdot
.32449 .40704 Mdot
.38548 .41995 Mdot
.63432 .5773 Mdot
.51127 .66044 Mdot
.59907 .23429 Mdot
.62877 .39541 Mdot
.36844 .40445 Mdot
.45885 .56041 Mdot
.63101 .39854 Mdot
.38793 .5644 Mdot
.56169 .37266 Mdot
.39994 .39217 Mdot
.60352 .35808 Mdot
.37861 .41201 Mdot
.49469 .65852 Mdot
.54974 .41042 Mdot
.62314 .39022 Mdot
.61502 .80859 Mdot
.66129 .58393 Mdot
.37219 .43907 Mdot
.52923 .73611 Mdot
.59937 .43966 Mdot
.38058 .66612 Mdot
.56386 .40151 Mdot
.30114 .39577 Mdot
.63849 .36373 Mdot
.35679 .70544 Mdot
.58218 .45534 Mdot
.60559 .41734 Mdot
.41912 .51152 Mdot
.41248 .29038 Mdot
.34038 .42754 Mdot
.36061 .53551 Mdot
.3917 .42564 Mdot
.73314 .64767 Mdot
.46814 .67699 Mdot
.49207 .6738 Mdot
.71315 .43669 Mdot
.64983 .3811 Mdot
.59588 .40218 Mdot
.41862 .57952 Mdot
.66951 .57972 Mdot
.36322 .39673 Mdot
.66625 .60472 Mdot
.6797 .74013 Mdot
.64686 .569 Mdot
.48688 .6252 Mdot
.60699 .74868 Mdot
.5691 .22912 Mdot
.63772 .6042 Mdot
.40183 .4064 Mdot
.70332 .64677 Mdot
.61752 .34347 Mdot
.70739 .59254 Mdot
.66371 .59748 Mdot
.77892 .30223 Mdot
.60082 .43295 Mdot
.48533 .5663 Mdot
.38502 .54996 Mdot
.65082 .6078 Mdot
.36525 .58409 Mdot
.60891 .37029 Mdot
.3721 .65029 Mdot
.34482 .41037 Mdot
.38745 .53475 Mdot
.53978 .3744 Mdot
.64949 .57314 Mdot
.54347 .65316 Mdot
.38211 .60843 Mdot
.3712 .53153 Mdot
.20675 .59371 Mdot
.46811 .17226 Mdot
.51085 .65872 Mdot
.79368 .56652 Mdot
.40058 .58506 Mdot
.57052 .34598 Mdot
.66338 .32563 Mdot
.5589 .38968 Mdot
.31894 .52528 Mdot
.48958 .66587 Mdot
.23839 .5167 Mdot
.62171 .3707 Mdot
.56952 .4281 Mdot
.34716 .43345 Mdot
.50336 .64767 Mdot
.37901 .39473 Mdot
.38635 .42677 Mdot
.49536 .65729 Mdot
.38622 .4048 Mdot
.66547 .57216 Mdot
.25593 .49567 Mdot
.4085 .57235 Mdot
.36167 .56478 Mdot
.51812 .64202 Mdot
.48352 .6441 Mdot
.49379 .63709 Mdot
.56147 .373 Mdot
.36271 .39013 Mdot
.58391 .36067 Mdot
.55439 .37062 Mdot
.46091 .38577 Mdot
.39676 .37651 Mdot
.57605 .35823 Mdot
.50126 .7131 Mdot
.68888 .61949 Mdot
.52496 .63161 Mdot
.38213 .5467 Mdot
.29835 .67678 Mdot
.32713 .56113 Mdot
.58735 .40986 Mdot
.57084 .77461 Mdot
.39649 .41129 Mdot
.63589 .59502 Mdot
.63799 .56111 Mdot
.63663 .58768 Mdot
.38429 .52373 Mdot
.36804 .43492 Mdot
.77816 .66505 Mdot
.59256 .4094 Mdot
.53942 .5628 Mdot
.70118 .34784 Mdot
.57851 .75952 Mdot
.37953 .54472 Mdot
.63123 .39016 Mdot
.50531 .4918 Mdot
.55461 .26336 Mdot
.56198 .39159 Mdot
.59919 .33423 Mdot
.39338 .7323 Mdot
.62794 .46948 Mdot
.41099 .38292 Mdot
.67897 .7582 Mdot
.54713 .42675 Mdot
.35768 .33068 Mdot
.30881 .23031 Mdot
.57958 .40591 Mdot
.57054 .42325 Mdot
.61927 .41101 Mdot
.61171 .35718 Mdot
.41126 .39323 Mdot
.70105 .47229 Mdot
.33829 .55751 Mdot
.55936 .56117 Mdot
.40906 .56313 Mdot
.53176 .68219 Mdot
.23413 .45173 Mdot
.35838 .36012 Mdot
.63616 .59865 Mdot
.21759 .41393 Mdot
.72842 .7202 Mdot
.50678 .62119 Mdot
.51618 .22301 Mdot
.66349 .59131 Mdot
.57572 .34207 Mdot
.68106 .58705 Mdot
.53988 .6702 Mdot
.35976 .55756 Mdot
.65128 .38759 Mdot
.37599 .42351 Mdot
.38237 .36913 Mdot
.62293 .41784 Mdot
.25005 .33905 Mdot
.38627 .55961 Mdot
.41419 .60379 Mdot
.57893 .3456 Mdot
.56931 .33793 Mdot
.3815 .39294 Mdot
.52928 .64921 Mdot
.76427 .58145 Mdot
.6649 .57926 Mdot
.61677 .43541 Mdot
.60846 .35439 Mdot
.65947 .76047 Mdot
.36228 .54871 Mdot
.49917 .62063 Mdot
.60537 .34655 Mdot
.29243 .58892 Mdot
.60535 .34683 Mdot
.56714 .47365 Mdot
.52137 .63266 Mdot
.55011 .44818 Mdot
.63283 .37534 Mdot
.56099 .31467 Mdot
.38305 .58986 Mdot
.38149 .37756 Mdot
.33656 .35296 Mdot
.59186 .53813 Mdot
.38845 .56686 Mdot
.57831 .35469 Mdot
.36824 .54896 Mdot
.55815 .36389 Mdot
.62413 .41848 Mdot
.38821 .54805 Mdot
.37944 .39544 Mdot
.22164 .58037 Mdot
.23029 .44262 Mdot
.61391 .35887 Mdot
.55457 .4385 Mdot
.71537 .47078 Mdot
.75405 .34542 Mdot
.56209 .4104 Mdot
.39442 .38276 Mdot
.62761 .38987 Mdot
.37115 .58542 Mdot
.64828 .56613 Mdot
.39758 .38987 Mdot
.5262 .65724 Mdot
.52261 .61783 Mdot
.29394 .54314 Mdot
.51764 .6743 Mdot
.61049 .34252 Mdot
.31016 .35189 Mdot
.3262 .37582 Mdot
.29137 .25449 Mdot
.49736 .65465 Mdot
.65665 .56483 Mdot
.61332 .37755 Mdot
.54595 .79209 Mdot
.41978 .58436 Mdot
.65191 .8452 Mdot
.80269 .63978 Mdot
.61531 .59874 Mdot
.81132 .41789 Mdot
.53659 .68193 Mdot
.63261 .41023 Mdot
.63749 .60675 Mdot
.5052 .6228 Mdot
.62129 .35194 Mdot
.65313 .37741 Mdot
.69802 .29132 Mdot
.57343 .53743 Mdot
.36778 .54751 Mdot
.4779 .65978 Mdot
.62832 .55901 Mdot
.50744 .61569 Mdot
.37708 .36437 Mdot
.60482 .41446 Mdot
.65295 .34331 Mdot
.52907 .65378 Mdot
.53101 .61448 Mdot
.56941 .36767 Mdot
.35291 .3632 Mdot
.50142 .61035 Mdot
.60734 .38604 Mdot
.64854 .4723 Mdot
.3792 .35186 Mdot
.51624 .66571 Mdot
.57713 .43365 Mdot
.70254 .61955 Mdot
.52111 .65056 Mdot
.52731 .63223 Mdot
.6242 .41714 Mdot
.66933 .57518 Mdot
.56315 .44222 Mdot
.40373 .5718 Mdot
.66973 .24304 Mdot
.36404 .58139 Mdot
.6871 .65853 Mdot
.59906 .32405 Mdot
.35452 .62806 Mdot
.37106 .35949 Mdot
.60055 .58713 Mdot
.32178 .71446 Mdot
.52681 .38644 Mdot
.17107 .51566 Mdot
.48372 .47377 Mdot
.24109 .32795 Mdot
.31993 .75026 Mdot
.65801 .59954 Mdot
.38674 .57449 Mdot
.57029 .42257 Mdot
.37578 .59909 Mdot
.62954 .60224 Mdot
.574 .19123 Mdot
.58364 .43555 Mdot
.36417 .38311 Mdot
.56654 .37318 Mdot
.36202 .3728 Mdot
.62879 .40817 Mdot
.53249 .44346 Mdot
.36834 .72942 Mdot
.77938 .52047 Mdot
.62501 .3513 Mdot
.45599 .8292 Mdot
.67248 .71036 Mdot
.66956 .59185 Mdot
.58412 .36532 Mdot
.46548 .68163 Mdot
.38879 .59539 Mdot
.28821 .40715 Mdot
.50759 .63193 Mdot
.34444 .55628 Mdot
.38711 .39533 Mdot
.49651 .66589 Mdot
.53427 .61847 Mdot
.56191 .45249 Mdot
.67603 .60833 Mdot
.3535 .55932 Mdot
.59956 .41819 Mdot
.58931 .43443 Mdot
.77737 .59195 Mdot
.66128 .685 Mdot
.32017 .37668 Mdot
.70722 .76813 Mdot
.33343 .35944 Mdot
.65912 .57921 Mdot
.51378 .63062 Mdot
.56387 .40665 Mdot
.58117 .38355 Mdot
.32556 .66493 Mdot
.34803 .41733 Mdot
.55338 .5294 Mdot
.48229 .20508 Mdot
.51234 .60887 Mdot
.72155 .52164 Mdot
.3766 .37048 Mdot
.72265 .51971 Mdot
.63759 .5575 Mdot
.20098 .42697 Mdot
.7679 .53106 Mdot
.38094 .54826 Mdot
.7184 .51833 Mdot
.36307 .40909 Mdot
.62529 .3685 Mdot
.47169 .67258 Mdot
.52665 .67271 Mdot
.37913 .38297 Mdot
.56134 .63104 Mdot
.64374 .60421 Mdot
.57778 .42791 Mdot
.77264 .66175 Mdot
.29452 .50683 Mdot
.53563 .64938 Mdot
.52358 .43275 Mdot
.3534 .56803 Mdot
.61962 .4237 Mdot
.62513 .59367 Mdot
.37388 .55861 Mdot
.70771 .67421 Mdot
.24333 .50487 Mdot
.60839 .37692 Mdot
.5753 .79626 Mdot
.3841 .56413 Mdot
.7904 .40561 Mdot
.6079 .39452 Mdot
.39933 .58566 Mdot
.61692 .469 Mdot
.46269 .7153 Mdot
.5137 .49622 Mdot
.15428 .556 Mdot
.53079 .51772 Mdot
.49177 .68353 Mdot
.44177 .69366 Mdot
.43392 .72991 Mdot
.37809 .59883 Mdot
.52669 .61393 Mdot
.61414 .62865 Mdot
.36532 .58454 Mdot
.55026 .37487 Mdot
.56958 .4027 Mdot
.5492 .20665 Mdot
.47934 .48053 Mdot
.47197 .70341 Mdot
.32567 .47845 Mdot
.59509 .44049 Mdot
.54076 .4179 Mdot
.58769 .38574 Mdot
.41331 .42087 Mdot
.36389 .5523 Mdot
.53048 .82688 Mdot
.39089 .56818 Mdot
.80783 .5942 Mdot
.51323 .64253 Mdot
.48424 .66426 Mdot
.58868 .41363 Mdot
.51256 .58342 Mdot
.67569 .51656 Mdot
.571 .37793 Mdot
.56849 .58751 Mdot
.39671 .20896 Mdot
.54116 .37725 Mdot
.39434 .36653 Mdot
.53004 .35292 Mdot
.42176 .3876 Mdot
.40891 .57417 Mdot
.65141 .59461 Mdot
.59951 .59519 Mdot
.35772 .55625 Mdot
.5957 .40037 Mdot
.33539 .62733 Mdot
.57268 .39298 Mdot
.61919 .35716 Mdot
.82138 .57238 Mdot
.61714 .59361 Mdot
.48842 .64855 Mdot
.63527 .58501 Mdot
.35442 .36807 Mdot
.48469 .91042 Mdot
.67254 .58379 Mdot
.66703 .51618 Mdot
.60902 .2049 Mdot
.71823 .51454 Mdot
.37573 .3653 Mdot
.66728 .6191 Mdot
.38106 .55281 Mdot
.17522 .40869 Mdot
.73884 .30941 Mdot
.3448 .59412 Mdot
.60268 .38621 Mdot
.34594 .3635 Mdot
.40402 .39496 Mdot
.3915 .53742 Mdot
.35707 .40493 Mdot
.63435 .45199 Mdot
.61924 .36259 Mdot
.3662 .59501 Mdot
.27092 .54634 Mdot
.37024 .53127 Mdot
.25981 .46449 Mdot
.57949 .36713 Mdot
.38338 .37388 Mdot
.54231 .34182 Mdot
.4181 .42809 Mdot
.49031 .62533 Mdot
.56012 .35237 Mdot
.64162 .60351 Mdot
.34208 .61908 Mdot
.51328 .65756 Mdot
.56187 .77291 Mdot
.34965 .38267 Mdot
.43702 .60597 Mdot
.35193 .39388 Mdot
.35151 .42901 Mdot
.34625 .56343 Mdot
.34649 .40876 Mdot
.57221 .42488 Mdot
.48012 .69976 Mdot
.34313 .38042 Mdot
.36897 .57695 Mdot
.64867 .58971 Mdot
.38345 .40322 Mdot
.51452 .73283 Mdot
.61787 .38383 Mdot
.51877 .62384 Mdot
.39974 .76626 Mdot
.33096 .38119 Mdot
.64865 .61963 Mdot
.49784 .67501 Mdot
.66256 .61354 Mdot
.35691 .21745 Mdot
.34153 .57739 Mdot
.82167 .47564 Mdot
.69152 .62625 Mdot
.39405 .41806 Mdot
.38248 .75468 Mdot
.56701 .40765 Mdot
.61707 .38103 Mdot
.68203 .60607 Mdot
.40418 .39558 Mdot
.20754 .39304 Mdot
.41426 .4502 Mdot
.25161 .5108 Mdot
.35528 .59238 Mdot
.52189 .81573 Mdot
.25671 .44463 Mdot
.45541 .15336 Mdot
.53225 .40927 Mdot
.54266 .68005 Mdot
.58799 .40164 Mdot
.30924 .69945 Mdot
.64476 .57371 Mdot
.57378 .6691 Mdot
.61956 .33277 Mdot
.49007 .65879 Mdot
.6182 .40302 Mdot
.41151 .49616 Mdot
.52248 .37529 Mdot
.64963 .56366 Mdot
.31674 .6351 Mdot
.39242 .42168 Mdot
.65777 .58893 Mdot
.54994 .64492 Mdot
.69384 .52048 Mdot
.63071 .36087 Mdot
.52678 .41823 Mdot
.50161 .61149 Mdot
.35991 .38345 Mdot
.47933 .67404 Mdot
.4076 .57517 Mdot
.64456 .59895 Mdot
.61458 .37057 Mdot
.63821 .35985 Mdot
.38221 .6681 Mdot
.35105 .56127 Mdot
.5548 .62531 Mdot
.3972 .57045 Mdot
.53191 .68576 Mdot
.5656 .44835 Mdot
.48507 .66603 Mdot
.63822 .39288 Mdot
.34071 .72168 Mdot
.81978 .56999 Mdot
.42851 .30222 Mdot
.49307 .66765 Mdot
.73392 .55033 Mdot
.37273 .58357 Mdot
.39988 .57859 Mdot
.60335 .2201 Mdot
.59708 .28586 Mdot
.75862 .64001 Mdot
.21002 .62585 Mdot
.40919 .56473 Mdot
.35703 .5726 Mdot
.51666 .62285 Mdot
.3418 .39967 Mdot
.33462 .4044 Mdot
.54337 .67666 Mdot
.7493 .41128 Mdot
.36335 .3969 Mdot
.17918 .46744 Mdot
.73832 .65389 Mdot
.60381 .4626 Mdot
.44759 .58626 Mdot
.64265 .59445 Mdot
.75105 .43798 Mdot
.40916 .49845 Mdot
.56685 .42461 Mdot
.64695 .76509 Mdot
.5263 .6445 Mdot
.70591 .42992 Mdot
.1832 .61538 Mdot
.58901 .43632 Mdot
.60658 .40159 Mdot
.59157 .3944 Mdot
.61758 .60511 Mdot
.62638 .27669 Mdot
.58311 .43294 Mdot
.75005 .40617 Mdot
.60465 .43873 Mdot
.505 .44398 Mdot
.63977 .58252 Mdot
.53307 .47232 Mdot
.38398 .73648 Mdot
.70038 .72315 Mdot
.57942 .31473 Mdot
.40632 .57625 Mdot
.58058 .57412 Mdot
.38674 .59058 Mdot
.42313 .32329 Mdot
.7672 .52563 Mdot
.35278 .34684 Mdot
.56698 .42302 Mdot
.50763 .6664 Mdot
.4031 .3923 Mdot
.42521 .6922 Mdot
.38599 .89554 Mdot
.40494 .58389 Mdot
.51025 .12395 Mdot
.40085 .57327 Mdot
.54156 .62149 Mdot
.38216 .39176 Mdot
.51763 .27474 Mdot
.53833 .5596 Mdot
.38354 .40567 Mdot
.22512 .55059 Mdot
.3615 .4439 Mdot
.724 .53773 Mdot
.33731 .36152 Mdot
.3706 .57965 Mdot
.37263 .5235 Mdot
.65694 .39536 Mdot
.57605 .41398 Mdot
.4717 .52978 Mdot
.69592 .53686 Mdot
.57048 .41115 Mdot
.51065 .66276 Mdot
.7862 .37828 Mdot
.61233 .5381 Mdot
.35631 .41599 Mdot
.33876 .54543 Mdot
.60915 .40289 Mdot
.60611 .34935 Mdot
.6282 .36094 Mdot
.72223 .76489 Mdot
.20097 .41747 Mdot
.63355 .38643 Mdot
.5924 .44349 Mdot
.49455 .66383 Mdot
.67612 .56799 Mdot
.2969 .69468 Mdot
.49316 .38809 Mdot
.55339 .41182 Mdot
.65417 .58381 Mdot
.61546 .59147 Mdot
.62027 .35062 Mdot
.66458 .73457 Mdot
.37575 .6366 Mdot
.60014 .41838 Mdot
.58082 .2932 Mdot
.45346 .74545 Mdot
.53378 .6155 Mdot
.52642 .654 Mdot
.40868 .40693 Mdot
.51699 .67195 Mdot
.54833 .66475 Mdot
.53129 .25732 Mdot
.53207 .52658 Mdot
.40545 .53638 Mdot
.63335 .57787 Mdot
.57804 .38554 Mdot
.32199 .37932 Mdot
.29935 .60201 Mdot
.35437 .57847 Mdot
.39318 .41003 Mdot
.3928 .59323 Mdot
.63311 .62015 Mdot
.71553 .34851 Mdot
.53666 .66988 Mdot
.39821 .54738 Mdot
.24382 .50337 Mdot
.65051 .58272 Mdot
.34966 .55204 Mdot
.34489 .63484 Mdot
.54757 .37623 Mdot
.48461 .33405 Mdot
.5744 .37486 Mdot
.22545 .35637 Mdot
.35337 .54914 Mdot
.35135 .69958 Mdot
.59908 .40698 Mdot
.51802 .65068 Mdot
.58642 .47704 Mdot
.55648 .39772 Mdot
.52931 .66053 Mdot
.62611 .36636 Mdot
.63255 .60886 Mdot
.38011 .35021 Mdot
.56632 .55645 Mdot
.86702 .46652 Mdot
.6756 .60952 Mdot
.41657 .68347 Mdot
.5619 .41269 Mdot
.42327 .18603 Mdot
.38173 .40403 Mdot
.64006 .38096 Mdot
.65455 .50075 Mdot
.33848 .38069 Mdot
.39649 .4002 Mdot
.5908 .35044 Mdot
.38696 .5528 Mdot
.51601 .65931 Mdot
.64409 .58255 Mdot
.36027 .20762 Mdot
.59789 .37887 Mdot
.62518 .38989 Mdot
.66163 .59062 Mdot
.35956 .57706 Mdot
.59732 .34581 Mdot
.41443 .78078 Mdot
.22736 .32063 Mdot
.35725 .58385 Mdot
.54859 .38824 Mdot
.48296 .35388 Mdot
.41896 .37586 Mdot
.64442 .1954 Mdot
.71325 .63349 Mdot
.48515 .65472 Mdot
.63033 .46471 Mdot
.53558 .89022 Mdot
.64964 .59318 Mdot
.74102 .69406 Mdot
.61523 .35186 Mdot
.62658 .40431 Mdot
.38769 .41801 Mdot
.57943 .35982 Mdot
.33387 .38442 Mdot
.85395 .44082 Mdot
.65133 .76978 Mdot
.35755 .37786 Mdot
.38013 .42422 Mdot
.65176 .51193 Mdot
.29911 .69513 Mdot
.38137 .38363 Mdot
.58769 .44763 Mdot
.31185 .32466 Mdot
.52715 .3397 Mdot
.68408 .60121 Mdot
.42891 .75973 Mdot
.43282 .40324 Mdot
.64245 .54477 Mdot
.21241 .59073 Mdot
.43269 .39318 Mdot
.40485 .63101 Mdot
.40447 .56622 Mdot
.57939 .4374 Mdot
.52309 .67372 Mdot
.49062 .67221 Mdot
.53427 .356 Mdot
.57165 .38811 Mdot
.35181 .37287 Mdot
.63095 .57694 Mdot
.38631 .59872 Mdot
.62842 .38304 Mdot
.61453 .54016 Mdot
.67102 .58368 Mdot
.34787 .40236 Mdot
.67385 .28909 Mdot
.65088 .56299 Mdot
.51362 .40381 Mdot
.5907 .42317 Mdot
.56632 .36765 Mdot
.54935 .31702 Mdot
.38067 .54152 Mdot
.37223 .74784 Mdot
.54768 .41768 Mdot
.67996 .74086 Mdot
.46396 .42592 Mdot
.56067 .45937 Mdot
.35783 .39619 Mdot
.42034 .58263 Mdot
.46545 .65556 Mdot
.68419 .45124 Mdot
.60412 .37624 Mdot
.22008 .39681 Mdot
.51767 .20106 Mdot
.47727 .63667 Mdot
.35751 .43192 Mdot
.63601 .5926 Mdot
.57105 .37968 Mdot
.40951 .33209 Mdot
.57489 .40566 Mdot
.66906 .62981 Mdot
.52827 .63632 Mdot
.40323 .56449 Mdot
.23817 .32588 Mdot
.4898 .67164 Mdot
.39581 .39382 Mdot
.14616 .61164 Mdot
.34033 .36286 Mdot
.37053 .42963 Mdot
.42765 .34986 Mdot
.38903 .54489 Mdot
.56201 .8892 Mdot
.7187 .27197 Mdot
.58187 .33283 Mdot
.37963 .58586 Mdot
.37364 .38149 Mdot
.61608 .42563 Mdot
.36819 .35561 Mdot
.36786 .43635 Mdot
.55452 .44282 Mdot
.61295 .42128 Mdot
.23762 .44694 Mdot
.16237 .57257 Mdot
.63393 .59137 Mdot
.36153 .36467 Mdot
.66978 .44784 Mdot
.61227 .42887 Mdot
.59315 .40985 Mdot
.45113 .73177 Mdot
.66542 .57156 Mdot
.28201 .42519 Mdot
.61132 .35027 Mdot
.62245 .7848 Mdot
.5316 .35083 Mdot
.41128 .39046 Mdot
.35305 .57972 Mdot
.70396 .71553 Mdot
.359 .50403 Mdot
.34319 .41 Mdot
.62661 .58655 Mdot
.33343 .35469 Mdot
.6674 .51849 Mdot
.3777 .53544 Mdot
.39997 .39221 Mdot
.5109 .50087 Mdot
.37276 .56514 Mdot
.359 .54595 Mdot
.38176 .31976 Mdot
.55947 .64483 Mdot
.62269 .60783 Mdot
.35355 .56241 Mdot
.68816 .38278 Mdot
.37874 .57842 Mdot
.62509 .24103 Mdot
.54906 .40908 Mdot
.72729 .40805 Mdot
.476 .57718 Mdot
.66517 .38423 Mdot
.36345 .53961 Mdot
.6287 .59888 Mdot
.59351 .34775 Mdot
.36024 .40955 Mdot
.67234 .59892 Mdot
.37518 .60979 Mdot
.50703 .6288 Mdot
.35018 .39447 Mdot
.34091 .58127 Mdot
.37011 .36761 Mdot
.69842 .41538 Mdot
.64757 .22119 Mdot
.45952 .79423 Mdot
.53881 .55513 Mdot
.62637 .35949 Mdot
.24338 .65396 Mdot
.5909 .46141 Mdot
.5669 .38952 Mdot
.51528 .66471 Mdot
.71338 .43112 Mdot
.3794 .39446 Mdot
.22787 .33346 Mdot
.40292 .55595 Mdot
.67664 .76079 Mdot
.30852 .39206 Mdot
.63945 .37404 Mdot
.34296 .37858 Mdot
.34042 .36137 Mdot
.4041 .28687 Mdot
.46942 .64061 Mdot
.63835 .42954 Mdot
.63762 .43409 Mdot
.53281 .42619 Mdot
.36311 .54545 Mdot
.57074 .77166 Mdot
.50413 .68566 Mdot
.63255 .2014 Mdot
.53198 .64126 Mdot
.56839 .58415 Mdot
.34793 .40912 Mdot
.67306 .58281 Mdot
.59405 .41169 Mdot
.32857 .41923 Mdot
.34366 .4121 Mdot
.68025 .62254 Mdot
.65157 .60885 Mdot
.46593 .72603 Mdot
.38691 .547 Mdot
.62623 .35046 Mdot
.57713 .43316 Mdot
.58787 .36 Mdot
.56128 .37886 Mdot
.40708 .58144 Mdot
.57014 .35359 Mdot
.4092 .55091 Mdot
.6876 .33826 Mdot
.63415 .77127 Mdot
.52448 .52012 Mdot
.31002 .42152 Mdot
.35949 .41432 Mdot
.67602 .42639 Mdot
.51339 .41595 Mdot
.82302 .54402 Mdot
.32398 .2713 Mdot
.54481 .36998 Mdot
.49903 .62537 Mdot
.60606 .28786 Mdot
.5301 .67547 Mdot
.57736 .13376 Mdot
.37841 .67251 Mdot
.15997 .54413 Mdot
.59571 .43191 Mdot
.45478 .7377 Mdot
.67968 .37048 Mdot
.61019 .45603 Mdot
.41419 .69937 Mdot
.32107 .51857 Mdot
.24438 .55519 Mdot
.62684 .57435 Mdot
.61444 .38678 Mdot
.32664 .3981 Mdot
.57463 .42706 Mdot
.5896 .40628 Mdot
.61216 .34862 Mdot
.347 .54572 Mdot
.64068 .42114 Mdot
.55738 .37587 Mdot
.58617 .74681 Mdot
.74212 .52218 Mdot
.47801 .66312 Mdot
.59113 .21136 Mdot
.67352 .58788 Mdot
.34771 .37818 Mdot
.20165 .50096 Mdot
.3802 .54762 Mdot
.40624 .27844 Mdot
.56302 .37361 Mdot
.23615 .47406 Mdot
.3528 .59368 Mdot
.64386 .6011 Mdot
.48268 .68142 Mdot
.15966 .50047 Mdot
.50438 .66263 Mdot
.50339 .4925 Mdot
.51365 .6518 Mdot
.51903 .36377 Mdot
.35271 .37215 Mdot
.6104 .34565 Mdot
.35543 .56195 Mdot
.52295 .66602 Mdot
.72509 .47252 Mdot
.58787 .3875 Mdot
.4946 .6564 Mdot
.60935 .34542 Mdot
.71972 .35291 Mdot
.79793 .53964 Mdot
.5514 .65701 Mdot
.40935 .54644 Mdot
.36924 .5687 Mdot
.66681 .57359 Mdot
.34574 .38833 Mdot
.38162 .4192 Mdot
.37529 .56057 Mdot
.75435 .32981 Mdot
.55386 .40818 Mdot
.61102 .42811 Mdot
.68468 .74062 Mdot
.56909 .4173 Mdot
.70963 .53344 Mdot
.50846 .49433 Mdot
.35287 .40911 Mdot
.6317 .40953 Mdot
.60709 .35118 Mdot
.61099 .37758 Mdot
.70549 .38106 Mdot
.53181 .65064 Mdot
.56263 .43132 Mdot
.65346 .6107 Mdot
.47056 .69054 Mdot
.61874 .42521 Mdot
.53373 .43024 Mdot
.38339 .4183 Mdot
.73084 .73612 Mdot
.39991 .56632 Mdot
.54636 .63383 Mdot
.48665 .6646 Mdot
.43274 .75883 Mdot
.44652 .39305 Mdot
.51391 .50031 Mdot
.60415 .18505 Mdot
.37416 .7282 Mdot
.66651 .58908 Mdot
.44308 .60904 Mdot
.47553 .43395 Mdot
.52495 .62037 Mdot
.4031 .58869 Mdot
.54778 .40973 Mdot
.55243 .41128 Mdot
.81936 .61328 Mdot
.63755 .36519 Mdot
.6394 .59174 Mdot
.40692 .55095 Mdot
.36395 .40881 Mdot
.64203 .60046 Mdot
.39833 .57751 Mdot
.35856 .38478 Mdot
.54138 .38958 Mdot
.54205 .40085 Mdot
.39195 .40975 Mdot
.40364 .40202 Mdot
.59457 .41972 Mdot
.57535 .61281 Mdot
.39877 .41868 Mdot
.38568 .37388 Mdot
.53739 .66989 Mdot
.52719 .67124 Mdot
.56295 .4543 Mdot
.38524 .58394 Mdot
.55871 .369 Mdot
.50054 .66621 Mdot
.64293 .56913 Mdot
.37739 .39957 Mdot
.61375 .35743 Mdot
.62647 .37665 Mdot
.64984 .58345 Mdot
.62727 .57671 Mdot
.64797 .60617 Mdot
.38488 .53075 Mdot
.59107 .36563 Mdot
.38603 .38961 Mdot
.3934 .55116 Mdot
.61508 .59245 Mdot
.67627 .57866 Mdot
.55305 .61539 Mdot
.56195 .40637 Mdot
.45751 .67753 Mdot
.47151 .90127 Mdot
.71821 .61317 Mdot
.47149 .64229 Mdot
.53533 .61 Mdot
.72621 .50138 Mdot
.53639 .57938 Mdot
.38235 .55864 Mdot
.64906 .63694 Mdot
.59984 .58935 Mdot
.56136 .35218 Mdot
.54982 .42975 Mdot
.63834 .43688 Mdot
.65632 .60512 Mdot
.68712 .46119 Mdot
.36696 .3571 Mdot
.44271 .20784 Mdot
.67363 .59218 Mdot
.533 .61457 Mdot
.56036 .64036 Mdot
.53158 .64008 Mdot
.5455 .40812 Mdot
.42972 .29685 Mdot
.59501 .49677 Mdot
.24409 .66375 Mdot
.35473 .54538 Mdot
.33239 .35109 Mdot
.38753 .20806 Mdot
.3942 .40528 Mdot
.53624 .67797 Mdot
.66805 .60089 Mdot
.39935 .38826 Mdot
.37795 .5929 Mdot
.35609 .56923 Mdot
.53402 .64719 Mdot
.51652 .64054 Mdot
.53214 .62821 Mdot
.36812 .43265 Mdot
.34613 .40743 Mdot
.59955 .37448 Mdot
.37346 .4072 Mdot
.79324 .66471 Mdot
.62611 .61507 Mdot
.53522 .60883 Mdot
.38851 .57493 Mdot
.3601 .37319 Mdot
.58598 .38438 Mdot
.59221 .54568 Mdot
.31136 .51485 Mdot
.65706 .61457 Mdot
.78552 .57322 Mdot
.57486 .13565 Mdot
.63022 .3528 Mdot
.36413 .54731 Mdot
.77135 .65957 Mdot
.59252 .39194 Mdot
.51497 .63267 Mdot
.34314 .73252 Mdot
.46825 .67752 Mdot
.55464 .37096 Mdot
.61513 .33839 Mdot
.34482 .57267 Mdot
.58051 .18636 Mdot
.59483 .37508 Mdot
.29126 .44535 Mdot
.33454 .54965 Mdot
.51115 .68552 Mdot
.21254 .33352 Mdot
.46205 .77583 Mdot
.74932 .42741 Mdot
.53928 .66793 Mdot
.56837 .39732 Mdot
.53646 .66694 Mdot
.6481 .61311 Mdot
.5463 .64901 Mdot
.39627 .36657 Mdot
.47943 .67019 Mdot
.62526 .39149 Mdot
.38026 .38121 Mdot
.38492 .56417 Mdot
.69309 .75276 Mdot
.64306 .72104 Mdot
.51828 .64966 Mdot
.552 .64231 Mdot
.63471 .38296 Mdot
.26469 .42103 Mdot
.54313 .35261 Mdot
.60227 .43129 Mdot
.40386 .55382 Mdot
.34158 .38302 Mdot
.34051 .55493 Mdot
.63623 .41505 Mdot
.40174 .77968 Mdot
.39591 .56531 Mdot
.23124 .47015 Mdot
.66419 .591 Mdot
.42869 .48555 Mdot
.57841 .38315 Mdot
.35246 .57318 Mdot
.58977 .36606 Mdot
.37206 .35671 Mdot
.46668 .48726 Mdot
.30383 .62807 Mdot
.35804 .56076 Mdot
.226 .37054 Mdot
.56302 .60078 Mdot
.61024 .32065 Mdot
.39647 .58723 Mdot
.65148 .50192 Mdot
.53614 .6188 Mdot
.66589 .58134 Mdot
.61832 .58542 Mdot
.66866 .61165 Mdot
.53444 .37234 Mdot
.58582 .31695 Mdot
.62295 .60267 Mdot
.37105 .59276 Mdot
.642 .56362 Mdot
.37011 .33246 Mdot
.20951 .38915 Mdot
.64432 .57482 Mdot
.60721 .39081 Mdot
.60713 .30546 Mdot
.74175 .51382 Mdot
.47961 .71634 Mdot
.16625 .53493 Mdot
.29588 .40744 Mdot
.57636 .41239 Mdot
.38031 .3453 Mdot
.37901 .36339 Mdot
.75846 .66705 Mdot
.7106 .55225 Mdot
.68619 .72095 Mdot
.37818 .42605 Mdot
.31894 .65384 Mdot
.34773 .39947 Mdot
.63556 .36554 Mdot
.61487 .42467 Mdot
.33999 .41344 Mdot
.59216 .77693 Mdot
.38909 .65854 Mdot
.27247 .28236 Mdot
.37974 .36897 Mdot
.38117 .59021 Mdot
.41064 .56187 Mdot
.36237 .54239 Mdot
.74226 .64652 Mdot
.33546 .37418 Mdot
.59835 .36328 Mdot
.49643 .66849 Mdot
.55883 .42469 Mdot
.36803 .55895 Mdot
.22653 .33625 Mdot
.3735 .41759 Mdot
.6043 .41761 Mdot
.75317 .3495 Mdot
.50693 .6367 Mdot
.65612 .58273 Mdot
.70876 .32202 Mdot
.71016 .67667 Mdot
.38183 .53914 Mdot
.33044 .37596 Mdot
.34885 .68707 Mdot
.22453 .46381 Mdot
.53572 .41079 Mdot
.58117 .46566 Mdot
.4131 .17137 Mdot
.70891 .67077 Mdot
.59495 .339 Mdot
.54188 .6249 Mdot
.32749 .66841 Mdot
.61889 .36905 Mdot
.37002 .3622 Mdot
.62563 .57103 Mdot
.66657 .60951 Mdot
.60045 .45046 Mdot
.54022 .56444 Mdot
.43523 .45914 Mdot
.57695 .35494 Mdot
.5134 .40516 Mdot
.52737 .6803 Mdot
.37715 .72884 Mdot
.67573 .74882 Mdot
.62592 .58541 Mdot
.60419 .34504 Mdot
.23732 .59145 Mdot
.35617 .42652 Mdot
.47147 .65528 Mdot
.37226 .53385 Mdot
.70107 .34157 Mdot
.50998 .6861 Mdot
.61914 .36754 Mdot
.59988 .34663 Mdot
.34732 .55464 Mdot
.41123 .39 Mdot
.65923 .60447 Mdot
.49315 .66897 Mdot
.62436 .58803 Mdot
.33741 .37832 Mdot
.36966 .41468 Mdot
.51438 .3562 Mdot
.64219 .34094 Mdot
.52546 .65564 Mdot
.6257 .42576 Mdot
.5307 .73421 Mdot
.57149 .17874 Mdot
.39294 .60497 Mdot
.62982 .35154 Mdot
.4153 .41297 Mdot
.35879 .55734 Mdot
.62045 .41401 Mdot
.37382 .19331 Mdot
.61102 .43154 Mdot
.34427 .50742 Mdot
.45056 .79989 Mdot
.63331 .60102 Mdot
.41844 .21404 Mdot
.27015 .36416 Mdot
.5731 .42064 Mdot
.48555 .63989 Mdot
.54652 .45867 Mdot
.38593 .55432 Mdot
.35376 .41463 Mdot
.64595 .19296 Mdot
.37421 .57695 Mdot
.58514 .43053 Mdot
.64409 .59962 Mdot
.33444 .36744 Mdot
.58259 .60266 Mdot
.66007 .74097 Mdot
.56778 .32929 Mdot
.59825 .44678 Mdot
.56325 .36497 Mdot
.34126 .7537 Mdot
.54579 .63391 Mdot
.36809 .37636 Mdot
.36511 .54561 Mdot
.37568 .5583 Mdot
.53122 .64621 Mdot
.25284 .54204 Mdot
.43102 .48423 Mdot
.48273 .8872 Mdot
.53109 .66197 Mdot
.65886 .62077 Mdot
.27711 .42944 Mdot
.48258 .64202 Mdot
.49587 .6524 Mdot
.52545 .68051 Mdot
.37108 .51139 Mdot
.36049 .38774 Mdot
.62671 .37439 Mdot
.38585 .36397 Mdot
.56499 .39645 Mdot
.45869 .42103 Mdot
.35567 .55829 Mdot
.35813 .42007 Mdot
.38416 .19071 Mdot
.56107 .28772 Mdot
.59908 .39364 Mdot
.40609 .19558 Mdot
.60788 .3282 Mdot
.70352 .50462 Mdot
.63976 .34683 Mdot
.51537 .64577 Mdot
.66613 .42436 Mdot
.52298 .39774 Mdot
.73133 .72224 Mdot
.38977 .57585 Mdot
.52566 .6158 Mdot
.57552 .33899 Mdot
.52093 .36658 Mdot
.34402 .42186 Mdot
.39532 .38315 Mdot
.62131 .59827 Mdot
.78176 .5158 Mdot
.38698 .56454 Mdot
.67648 .25508 Mdot
.57944 .41689 Mdot
.52028 .79475 Mdot
.40745 .22804 Mdot
.61908 .41441 Mdot
.2738 .34072 Mdot
.42064 .28942 Mdot
.57306 .38089 Mdot
.61146 .51028 Mdot
.36194 .5781 Mdot
.41308 .7858 Mdot
.59616 .44398 Mdot
.50924 .63249 Mdot
.34287 .39833 Mdot
.36092 .3585 Mdot
.62607 .60461 Mdot
.83973 .49935 Mdot
.34229 .55339 Mdot
.35492 .41741 Mdot
.58582 .39118 Mdot
.38549 .542 Mdot
.51229 .67393 Mdot
.64397 .38547 Mdot
.71923 .55888 Mdot
.37011 .40679 Mdot
.60732 .44061 Mdot
.29436 .47619 Mdot
.75998 .47401 Mdot
.25978 .72501 Mdot
.36865 .54263 Mdot
.65299 .56731 Mdot
.55376 .46166 Mdot
.70826 .29695 Mdot
.54173 .3726 Mdot
.72411 .40756 Mdot
.42344 .3613 Mdot
.65259 .56666 Mdot
.60202 .40278 Mdot
.61019 .3684 Mdot
.48556 .57376 Mdot
.62948 .57675 Mdot
.57872 .43506 Mdot
.65305 .30812 Mdot
.36145 .38357 Mdot
.49686 .68736 Mdot
.36548 .40261 Mdot
.60294 .38703 Mdot
.65055 .35432 Mdot
.39539 .41381 Mdot
.53975 .15104 Mdot
.61098 .5821 Mdot
.39797 .56244 Mdot
.62315 .32522 Mdot
.55203 .42653 Mdot
.45946 .83811 Mdot
.49432 .62303 Mdot
.27589 .66163 Mdot
.57286 .72765 Mdot
.227 .59854 Mdot
.46506 .77516 Mdot
.14733 .58446 Mdot
.65447 .76278 Mdot
.63269 .43816 Mdot
.37421 .46682 Mdot
.58996 .50153 Mdot
.36297 .53838 Mdot
.57149 .23653 Mdot
.57547 .41351 Mdot
.58833 .4043 Mdot
.47056 .65252 Mdot
.23568 .51313 Mdot
.68074 .73035 Mdot
.56458 .56933 Mdot
.66031 .60258 Mdot
.35937 .36675 Mdot
.63077 .40298 Mdot
.57003 .52369 Mdot
.47643 .66016 Mdot
.53083 .79292 Mdot
.60529 .41329 Mdot
.81949 .54467 Mdot
.30705 .55072 Mdot
.3826 .54314 Mdot
.48197 .65887 Mdot
.70333 .69181 Mdot
.55985 .40346 Mdot
.37877 .53323 Mdot
.59081 .37767 Mdot
.49351 .60037 Mdot
.63437 .41463 Mdot
.65298 .57369 Mdot
.61984 .35344 Mdot
.57371 .57584 Mdot
.1967 .66936 Mdot
.63785 .63156 Mdot
.34916 .36269 Mdot
.48688 .62053 Mdot
.53033 .65156 Mdot
.4019 .39475 Mdot
.5273 .65164 Mdot
.41022 .25382 Mdot
.50109 .27008 Mdot
.66499 .59886 Mdot
.51555 .38765 Mdot
.63854 .57787 Mdot
.48699 .62735 Mdot
.56905 .40688 Mdot
.57069 .16384 Mdot
.52267 .66172 Mdot
.46913 .81853 Mdot
.38164 .57611 Mdot
.51005 .61721 Mdot
.60397 .4395 Mdot
.35686 .68789 Mdot
.48466 .66942 Mdot
.30664 .62818 Mdot
.60955 .37699 Mdot
.36517 .41365 Mdot
.61247 .36606 Mdot
.61594 .32552 Mdot
.55051 .67644 Mdot
.55508 .38201 Mdot
.39819 .57767 Mdot
.39122 .42595 Mdot
.17663 .43914 Mdot
.32394 .521 Mdot
.5694 .42764 Mdot
.58788 .39164 Mdot
.32545 .38223 Mdot
.56249 .43362 Mdot
.40715 .58099 Mdot
.7893 .74012 Mdot
.66402 .59035 Mdot
.55347 .63943 Mdot
.45711 .77791 Mdot
.54406 .37373 Mdot
.57964 .34939 Mdot
.34778 .21165 Mdot
.45247 .7848 Mdot
.39804 .58414 Mdot
.52474 .38173 Mdot
.50026 .67376 Mdot
.64341 .59772 Mdot
.36857 .59287 Mdot
.56727 .36703 Mdot
.5965 .40934 Mdot
.65444 .56834 Mdot
.35052 .31679 Mdot
.7326 .67306 Mdot
.3492 .5498 Mdot
.67228 .40713 Mdot
.55178 .71413 Mdot
.55471 .40357 Mdot
.75254 .64013 Mdot
.39635 .38681 Mdot
.3901 .54131 Mdot
.26926 .67736 Mdot
.58378 .34105 Mdot
.35529 .58076 Mdot
.38832 .56665 Mdot
.52454 .38748 Mdot
.40665 .43379 Mdot
.38033 .4341 Mdot
.36841 .36741 Mdot
.81053 .65428 Mdot
.74864 .46209 Mdot
.53191 .62816 Mdot
.36042 .57726 Mdot
.54891 .6653 Mdot
.66631 .62158 Mdot
.50516 .4814 Mdot
.55247 .6509 Mdot
.40142 .38661 Mdot
.47135 .63242 Mdot
.61196 .37191 Mdot
.38375 .56207 Mdot
.52769 .62178 Mdot
.56656 .34229 Mdot
.25174 .41787 Mdot
.45734 .69574 Mdot
.66654 .57 Mdot
.62109 .57581 Mdot
.61992 .42119 Mdot
.46442 .66024 Mdot
.59365 .41828 Mdot
.41102 .59232 Mdot
.26757 .42978 Mdot
.54669 .36168 Mdot
.52059 .64856 Mdot
.37443 .34149 Mdot
.70951 .67691 Mdot
.56892 .3343 Mdot
.60662 .39204 Mdot
.55989 .39542 Mdot
.5902 .37719 Mdot
.2313 .5369 Mdot
.3642 .59703 Mdot
.33936 .46006 Mdot
.3797 .75075 Mdot
.38179 .41082 Mdot
.39557 .4346 Mdot
.71989 .64228 Mdot
.40564 .63367 Mdot
.38186 .58485 Mdot
.56431 .38731 Mdot
.29628 .58891 Mdot
.22139 .3438 Mdot
.50045 .13794 Mdot
.70306 .60064 Mdot
.48165 .63441 Mdot
.32979 .38274 Mdot
.47787 .6561 Mdot
.57005 .40014 Mdot
.5633 .46727 Mdot
.14442 .58616 Mdot
.34541 .53063 Mdot
.66553 .60294 Mdot
.56202 .39432 Mdot
.75162 .45391 Mdot
.4948 .66485 Mdot
.55814 .65639 Mdot
.58631 .43735 Mdot
.41266 .40704 Mdot
.36384 .80017 Mdot
.37727 .54122 Mdot
.29501 .41035 Mdot
.67879 .40663 Mdot
.32769 .46726 Mdot
.36529 .55437 Mdot
.66435 .72579 Mdot
.46907 .64905 Mdot
.36505 .27419 Mdot
.38153 .41307 Mdot
.67176 .59706 Mdot
.56903 .46249 Mdot
.37931 .42243 Mdot
.49944 .68573 Mdot
.35983 .41641 Mdot
.61927 .35088 Mdot
.33898 .57351 Mdot
.48411 .65263 Mdot
.39233 .52817 Mdot
.40423 .43432 Mdot
.6275 .59109 Mdot
.4712 .55049 Mdot
.57104 .25977 Mdot
.41721 .28637 Mdot
.55678 .42467 Mdot
.56705 .52048 Mdot
.59472 .36187 Mdot
.36135 .44095 Mdot
.58765 .38233 Mdot
.3467 .33607 Mdot
.48247 .64551 Mdot
.59317 .44357 Mdot
.57029 .35876 Mdot
.56199 .22116 Mdot
.61097 .40692 Mdot
.6378 .41996 Mdot
.56908 .38174 Mdot
.3126 .37759 Mdot
.51684 .39506 Mdot
.35699 .3931 Mdot
.62855 .74795 Mdot
.49756 .64995 Mdot
.62174 .57699 Mdot
.67717 .5973 Mdot
.73033 .41275 Mdot
.60098 .63372 Mdot
.24379 .5334 Mdot
.36817 .39585 Mdot
.39507 .5716 Mdot
.58627 .37931 Mdot
.21476 .64094 Mdot
.44289 .74296 Mdot
.50761 .67757 Mdot
.32344 .52146 Mdot
.64935 .44199 Mdot
.34755 .76227 Mdot
.61551 .43494 Mdot
.82918 .59423 Mdot
.65299 .34949 Mdot
.63695 .40716 Mdot
.5509 .66816 Mdot
.60799 .59718 Mdot
.57846 .4396 Mdot
.34262 .42005 Mdot
.66216 .57536 Mdot
.38024 .46135 Mdot
.52133 .70844 Mdot
.63756 .73714 Mdot
.53205 .23837 Mdot
.58984 .36924 Mdot
.48478 .65011 Mdot
.34997 .39269 Mdot
.67318 .75236 Mdot
.39547 .5534 Mdot
.41887 .61651 Mdot
.66968 .44393 Mdot
.46453 .16356 Mdot
.67182 .58518 Mdot
.37182 .31806 Mdot
.62606 .39011 Mdot
.69315 .65822 Mdot
.54238 .41936 Mdot
.22414 .34357 Mdot
.6639 .61983 Mdot
.40286 .42413 Mdot
.38345 .58951 Mdot
.38309 .36388 Mdot
.42071 .29927 Mdot
.45211 .58283 Mdot
.49009 .5241 Mdot
.50122 .66123 Mdot
.40768 .50288 Mdot
.37507 .37779 Mdot
.59506 .34409 Mdot
.47535 .88973 Mdot
.38996 .37838 Mdot
.33524 .39575 Mdot
.61136 .20273 Mdot
.57019 .17495 Mdot
.65224 .44201 Mdot
.39056 .42005 Mdot
.5015 .65736 Mdot
.63137 .59027 Mdot
.60698 .35884 Mdot
.60116 .37141 Mdot
.38424 .4191 Mdot
.55573 .66146 Mdot
.49213 .35479 Mdot
.5152 .64169 Mdot
.35915 .38192 Mdot
.49956 .64208 Mdot
.3477 .70214 Mdot
.5177 .61911 Mdot
.55315 .42763 Mdot
.58716 .38147 Mdot
.55428 .72981 Mdot
.36938 .41442 Mdot
.5807 .35362 Mdot
.62829 .36845 Mdot
.38383 .38775 Mdot
.62586 .54427 Mdot
.47476 .36766 Mdot
.56304 .41739 Mdot
.61723 .38789 Mdot
.64878 .56647 Mdot
.52183 .49146 Mdot
.81002 .45967 Mdot
.59342 .34786 Mdot
.62453 .61195 Mdot
.36634 .43092 Mdot
.59847 .42022 Mdot
.20537 .44037 Mdot
.32596 .66692 Mdot
.59131 .34082 Mdot
.53189 .61773 Mdot
.52585 .41208 Mdot
.29299 .74936 Mdot
.6009 .43258 Mdot
.37748 .38618 Mdot
.3375 .38774 Mdot
.66305 .25195 Mdot
.39338 .38827 Mdot
.52665 .67256 Mdot
.37075 .56269 Mdot
.22824 .35198 Mdot
.51133 .67385 Mdot
.56061 .34273 Mdot
.71679 .26861 Mdot
.64632 .39426 Mdot
.55648 .34987 Mdot
.39535 .8002 Mdot
.50813 .67236 Mdot
.34625 .37362 Mdot
.51343 .57309 Mdot
.64968 .41233 Mdot
.38184 .53866 Mdot
.53863 .44727 Mdot
.54811 .39638 Mdot
.45657 .8007 Mdot
.28748 .62698 Mdot
.41364 .5716 Mdot
.61509 .45871 Mdot
.59147 .34784 Mdot
.4558 .67069 Mdot
.58437 .3865 Mdot
.63097 .58154 Mdot
.33827 .37376 Mdot
.49121 .63193 Mdot
.65112 .58587 Mdot
.57385 .41716 Mdot
.65434 .60544 Mdot
.51949 .62398 Mdot
.38448 .53627 Mdot
.56557 .40216 Mdot
.6844 .60108 Mdot
.65746 .60323 Mdot
.59239 .3588 Mdot
.35094 .41159 Mdot
.66087 .35969 Mdot
.60443 .42053 Mdot
.6159 .35678 Mdot
.38043 .41938 Mdot
.44615 .12542 Mdot
.60714 .43175 Mdot
.56702 .60394 Mdot
.33931 .40405 Mdot
.42371 .5307 Mdot
.48862 .63236 Mdot
.54768 .401 Mdot
.39628 .54304 Mdot
.35096 .56622 Mdot
.53529 .67503 Mdot
.33469 .36383 Mdot
.56696 .72877 Mdot
.36641 .33877 Mdot
.65244 .37274 Mdot
.64081 .36066 Mdot
.74793 .30786 Mdot
.15521 .53919 Mdot
.36394 .36028 Mdot
.5632 .65208 Mdot
.56109 .56437 Mdot
.36458 .58239 Mdot
.54709 .6171 Mdot
.33002 .37377 Mdot
.33439 .3727 Mdot
.35593 .41023 Mdot
.66976 .60504 Mdot
.56452 .71632 Mdot
.41085 .38591 Mdot
.41107 .40979 Mdot
.61096 .37548 Mdot
.58672 .34854 Mdot
.67598 .53909 Mdot
.74255 .56228 Mdot
.62518 .59576 Mdot
.5292 .64075 Mdot
.74073 .76635 Mdot
.41043 .59144 Mdot
.54952 .21584 Mdot
.54731 .36156 Mdot
.43889 .91379 Mdot
.61214 .43467 Mdot
.58322 .38948 Mdot
.38993 .42548 Mdot
.68175 .58613 Mdot
.64851 .57743 Mdot
.36987 .37344 Mdot
.36602 .44214 Mdot
.63185 .58021 Mdot
.29725 .29909 Mdot
.20122 .39527 Mdot
.47034 .58283 Mdot
.38391 .39579 Mdot
.55352 .26317 Mdot
.36889 .53306 Mdot
.42211 .39088 Mdot
.39759 .59926 Mdot
.49288 .65927 Mdot
.46537 .66343 Mdot
.36254 .54509 Mdot
.60744 .37722 Mdot
.53942 .63084 Mdot
.64029 .4214 Mdot
.29912 .31585 Mdot
.46471 .34007 Mdot
.49089 .76335 Mdot
.56842 .45208 Mdot
.64916 .73848 Mdot
.41517 .63971 Mdot
.58278 .42614 Mdot
.20463 .54885 Mdot
.66289 .60448 Mdot
.41821 .39053 Mdot
.41049 .57041 Mdot
.27682 .74618 Mdot
.55663 .39688 Mdot
.37739 .39047 Mdot
.39118 .57804 Mdot
.70931 .36413 Mdot
.28668 .44316 Mdot
.5623 .39612 Mdot
.5046 .88956 Mdot
.31551 .40001 Mdot
.49526 .62942 Mdot
.79123 .37575 Mdot
.38136 .35999 Mdot
.69224 .57677 Mdot
.38222 .74311 Mdot
.40308 .18692 Mdot
.3484 .37772 Mdot
.55222 .61772 Mdot
.36314 .36789 Mdot
.62702 .58796 Mdot
.36926 .34703 Mdot
.48786 .66334 Mdot
.60678 .40637 Mdot
.52526 .64492 Mdot
.6265 .60226 Mdot
.73415 .64758 Mdot
.41096 .5647 Mdot
.52572 .61598 Mdot
.36168 .56798 Mdot
.76759 .48577 Mdot
.37413 .75928 Mdot
.40261 .56448 Mdot
.69457 .2957 Mdot
.58454 .33929 Mdot
.40148 .37663 Mdot
.53745 .65473 Mdot
.381 .73455 Mdot
.49835 .55851 Mdot
.3881 .407 Mdot
.52266 .63126 Mdot
.63751 .48285 Mdot
.73671 .32192 Mdot
.54699 .33648 Mdot
.77365 .50946 Mdot
.38625 .39296 Mdot
.54584 .61399 Mdot
.68563 .74059 Mdot
.39733 .38015 Mdot
.53287 .6614 Mdot
.37235 .58926 Mdot
.37185 .55564 Mdot
.57453 .43622 Mdot
.4167 .55012 Mdot
.53398 .63643 Mdot
.43434 .64711 Mdot
.35704 .42806 Mdot
.7082 .39011 Mdot
.67859 .60693 Mdot
.50482 .64741 Mdot
.63934 .36775 Mdot
.42315 .41489 Mdot
.33675 .68649 Mdot
.52532 .31778 Mdot
.69583 .78315 Mdot
.53054 .64575 Mdot
.33415 .38119 Mdot
.37675 .39509 Mdot
.56776 .33541 Mdot
.53793 .5569 Mdot
.56759 .72484 Mdot
.7415 .35604 Mdot
.71983 .40142 Mdot
.5106 .6878 Mdot
.50654 .69153 Mdot
.59035 .33342 Mdot
.58308 .36962 Mdot
.37002 .58596 Mdot
.60896 .4009 Mdot
.39624 .42568 Mdot
.57014 .43646 Mdot
.36193 .55241 Mdot
.50865 .66287 Mdot
.57141 .40571 Mdot
.62986 .59887 Mdot
.39916 .54214 Mdot
.34409 .57237 Mdot
.51141 .64861 Mdot
.37571 .42388 Mdot
.62975 .62512 Mdot
.51691 .6402 Mdot
.59054 .36985 Mdot
.35218 .62176 Mdot
.62804 .3608 Mdot
.32241 .28758 Mdot
.4011 .38461 Mdot
.47851 .65084 Mdot
.35343 .42716 Mdot
.3628 .57344 Mdot
.37836 .74869 Mdot
.59757 .38584 Mdot
.52952 .66407 Mdot
.54522 .73003 Mdot
.31485 .30649 Mdot
.3266 .3965 Mdot
.33716 .63411 Mdot
.38319 .43874 Mdot
.4806 .67893 Mdot
.61502 .22177 Mdot
.6696 .58576 Mdot
.50405 .67697 Mdot
.16848 .49091 Mdot
.52179 .65526 Mdot
.61465 .4081 Mdot
.62375 .41365 Mdot
.49903 .62608 Mdot
.67005 .57583 Mdot
.65697 .76705 Mdot
.45454 .61827 Mdot
.3461 .37584 Mdot
.44662 .18307 Mdot
.61311 .8277 Mdot
.42919 .58141 Mdot
.38284 .58817 Mdot
.64964 .41447 Mdot
.64003 .39662 Mdot
.39364 .59879 Mdot
.33915 .54523 Mdot
.65341 .61638 Mdot
.52397 .6806 Mdot
.31451 .35615 Mdot
.37086 .52962 Mdot
.5281 .3371 Mdot
.61168 .64107 Mdot
.5472 .34592 Mdot
.66014 .44572 Mdot
.54689 .42611 Mdot
.72498 .389 Mdot
.36258 .54864 Mdot
.63249 .40261 Mdot
.53656 .35379 Mdot
.39539 .54331 Mdot
.62959 .58437 Mdot
.28428 .59337 Mdot
.49573 .63965 Mdot
.248 .2742 Mdot
.63718 .39348 Mdot
.61379 .41242 Mdot
.35608 .54442 Mdot
.58332 .73165 Mdot
.37009 .41996 Mdot
.39868 .37988 Mdot
.54411 .63129 Mdot
.47358 .54559 Mdot
.55084 .40869 Mdot
.59297 .42812 Mdot
.4934 .63705 Mdot
.5135 .61666 Mdot
.43966 .69075 Mdot
.62581 .37918 Mdot
.38753 .57952 Mdot
.57895 .57058 Mdot
.36143 .54995 Mdot
.63413 .36394 Mdot
.61804 .40755 Mdot
.5539 .42814 Mdot
.63713 .36442 Mdot
.34626 .57755 Mdot
.63261 .39751 Mdot
.58129 .31073 Mdot
.36382 .42238 Mdot
.5573 .38244 Mdot
.72115 .38459 Mdot
.6111 .39069 Mdot
.63086 .5879 Mdot
.54186 .31697 Mdot
.55816 .39856 Mdot
.54835 .40801 Mdot
.46296 .61243 Mdot
.59851 .4009 Mdot
.4098 .59314 Mdot
.37799 .40811 Mdot
.35914 .57606 Mdot
.35003 .55214 Mdot
.54361 .66239 Mdot
.62439 .604 Mdot
.54401 .37607 Mdot
.66004 .61309 Mdot
.53621 .39892 Mdot
.59089 .33979 Mdot
.41705 .75822 Mdot
.83465 .57999 Mdot
.73855 .66806 Mdot
.59787 .38436 Mdot
.51793 .66874 Mdot
.48249 .6388 Mdot
.32953 .43942 Mdot
.54921 .33622 Mdot
.38918 .59862 Mdot
.35204 .57136 Mdot
.72125 .55325 Mdot
.4475 .7952 Mdot
.63037 .58686 Mdot
.54423 .51335 Mdot
.64336 .41614 Mdot
.6242 .36552 Mdot
.64403 .39094 Mdot
.54998 .66238 Mdot
.56305 .57779 Mdot
.50568 .67656 Mdot
.31073 .53566 Mdot
.35714 .55363 Mdot
.55584 .39338 Mdot
.39918 .33888 Mdot
.39581 .38243 Mdot
.37728 .40845 Mdot
.35624 .58447 Mdot
.50689 .61086 Mdot
.70882 .57857 Mdot
.54472 .13668 Mdot
.30958 .37756 Mdot
.67471 .57541 Mdot
.5777 .42627 Mdot
.51107 .65867 Mdot
.37062 .36537 Mdot
.6378 .56437 Mdot
.60307 .34388 Mdot
.56274 .71855 Mdot
.59849 .38028 Mdot
.58732 .50114 Mdot
.34635 .40013 Mdot
.2148 .36312 Mdot
.34433 .36026 Mdot
.40281 .54718 Mdot
.40609 .56169 Mdot
.62213 .41113 Mdot
.76246 .33181 Mdot
.39573 .3723 Mdot
.39397 .51776 Mdot
.66216 .6193 Mdot
.3454 .67736 Mdot
.62833 .58104 Mdot
.4868 .63743 Mdot
.66609 .5781 Mdot
.48325 .65863 Mdot
.73231 .58847 Mdot
.31946 .37685 Mdot
.65894 .58848 Mdot
.52905 .59937 Mdot
.5572 .33058 Mdot
.62373 .57703 Mdot
.63772 .43954 Mdot
.38119 .23786 Mdot
.49996 .63331 Mdot
.67589 .59775 Mdot
.5965 .3446 Mdot
.19252 .63148 Mdot
.39986 .5786 Mdot
.39567 .59692 Mdot
.6514 .3711 Mdot
.5398 .67504 Mdot
.33578 .40743 Mdot
.21517 .47764 Mdot
.40114 .61097 Mdot
.61445 .4238 Mdot
.57656 .43906 Mdot
.40245 .42929 Mdot
.43229 .43105 Mdot
.62213 .4061 Mdot
.66129 .28906 Mdot
.62921 .38769 Mdot
.37365 .59095 Mdot
.37501 .36149 Mdot
.37732 .40101 Mdot
.52545 .62964 Mdot
.40126 .4143 Mdot
.30476 .34702 Mdot
.3193 .60412 Mdot
.65147 .41557 Mdot
.37147 .57554 Mdot
.31152 .57216 Mdot
.31211 .53342 Mdot
.16849 .53857 Mdot
.40289 .43131 Mdot
.55777 .43732 Mdot
.35434 .42565 Mdot
.6399 .59747 Mdot
.36733 .41137 Mdot
.33037 .38814 Mdot
.5907 .42185 Mdot
.5687 .39715 Mdot
.50628 .66869 Mdot
.54246 .5603 Mdot
.3642 .42619 Mdot
.62428 .41641 Mdot
.63679 .41941 Mdot
.6403 .41629 Mdot
.45405 .45792 Mdot
.36453 .36117 Mdot
.53497 .20149 Mdot
.67705 .48376 Mdot
.36532 .42639 Mdot
.31876 .77855 Mdot
.37402 .73021 Mdot
.49258 .6216 Mdot
.41503 .55414 Mdot
.62552 .37771 Mdot
.48209 .63622 Mdot
.56998 .40054 Mdot
.66121 .44425 Mdot
.59342 .40787 Mdot
.63517 .57545 Mdot
.63226 .4385 Mdot
.47136 .6738 Mdot
.52031 .64195 Mdot
.60687 .42932 Mdot
.57602 .40735 Mdot
.72981 .65816 Mdot
.3717 .44358 Mdot
.36678 .41837 Mdot
.56576 .74036 Mdot
.65601 .59495 Mdot
.38565 .53963 Mdot
.57764 .38168 Mdot
.54521 .65697 Mdot
.52365 .64274 Mdot
.37756 .35942 Mdot
.51283 .6329 Mdot
.37398 .54177 Mdot
.5946 .38667 Mdot
.39649 .59748 Mdot
.66834 .60787 Mdot
.3608 .36501 Mdot
.55911 .39145 Mdot
.61139 .3758 Mdot
.33752 .3872 Mdot
.55294 .36088 Mdot
.64769 .56672 Mdot
.52388 .65368 Mdot
.34927 .38143 Mdot
.37098 .56098 Mdot
.48109 .64753 Mdot
.61378 .36067 Mdot
.72355 .77334 Mdot
.61627 .40241 Mdot
.62064 .3715 Mdot
.16142 .48432 Mdot
.63356 .43834 Mdot
.53577 .65077 Mdot
.40818 .417 Mdot
.60686 .44555 Mdot
.73151 .42807 Mdot
.4766 .13178 Mdot
.51224 .67778 Mdot
.57662 .42838 Mdot
.15847 .58316 Mdot
.5884 .43207 Mdot
.69182 .2744 Mdot
.66226 .64897 Mdot
.42807 .51102 Mdot
.64444 .33913 Mdot
.37884 .54759 Mdot
.50791 .66953 Mdot
.48531 .64134 Mdot
.49874 .18456 Mdot
.59173 .42445 Mdot
.58506 .50606 Mdot
.56912 .35212 Mdot
.36742 .55405 Mdot
.69819 .53432 Mdot
.52831 .64336 Mdot
.75091 .68991 Mdot
.59728 .36388 Mdot
.35833 .36017 Mdot
.47683 .62691 Mdot
.36254 .71195 Mdot
.61359 .35672 Mdot
.65606 .61228 Mdot
.39074 .53123 Mdot
.62233 .44171 Mdot
.37451 .57271 Mdot
.62 .35675 Mdot
.50747 .36881 Mdot
.81834 .4188 Mdot
.35269 .41096 Mdot
.3782 .58948 Mdot
.37118 .62839 Mdot
.55511 .44374 Mdot
.34821 .37994 Mdot
.3827 .41242 Mdot
.65044 .61508 Mdot
.50059 .51633 Mdot
.28323 .48056 Mdot
.5142 .31234 Mdot
.49047 .17996 Mdot
.48573 .62069 Mdot
.37139 .65117 Mdot
.60352 .3536 Mdot
.51696 .78938 Mdot
.41475 .58176 Mdot
.61116 .41118 Mdot
.38611 .24935 Mdot
.37281 .36906 Mdot
.62062 .38893 Mdot
.63655 .57868 Mdot
.55289 .77542 Mdot
.54338 .78653 Mdot
.31007 .72642 Mdot
.49876 .66081 Mdot
.55929 .46441 Mdot
.58253 .4797 Mdot
.55002 .6349 Mdot
.55136 .36985 Mdot
.53264 .65602 Mdot
.34755 .23978 Mdot
.64923 .56452 Mdot
.35725 .36335 Mdot
.37117 .72495 Mdot
.54449 .39244 Mdot
.64798 .37349 Mdot
.62678 .56708 Mdot
.57837 .36676 Mdot
.83843 .50864 Mdot
.4636 .74908 Mdot
.53385 .6239 Mdot
.35526 .41066 Mdot
.54528 .40706 Mdot
.5177 .51357 Mdot
.60179 .42362 Mdot
.49067 .29505 Mdot
.54794 .40919 Mdot
.28869 .46351 Mdot
.34357 .40012 Mdot
.37008 .57228 Mdot
.53557 .42713 Mdot
.59012 .40182 Mdot
.60005 .5481 Mdot
.64902 .34669 Mdot
.6212 .42477 Mdot
.33245 .40473 Mdot
.37898 .36556 Mdot
.35801 .39289 Mdot
.48195 .67316 Mdot
.45456 .79698 Mdot
.37656 .58176 Mdot
.52592 .42132 Mdot
.36633 .52986 Mdot
.59745 .28321 Mdot
.66075 .56638 Mdot
.19917 .61986 Mdot
.56335 .37416 Mdot
.36454 .39119 Mdot
.24979 .60042 Mdot
.36736 .43248 Mdot
.54954 .52884 Mdot
.38648 .56402 Mdot
.37872 .37135 Mdot
.58617 .39451 Mdot
.53612 .56858 Mdot
.24997 .68486 Mdot
.35531 .5673 Mdot
.53777 .38272 Mdot
.48065 .63438 Mdot
.44206 .77416 Mdot
.70968 .78535 Mdot
.39935 .5829 Mdot
.37464 .62713 Mdot
.58974 .42632 Mdot
.40099 .38838 Mdot
.37649 .54503 Mdot
.40115 .56963 Mdot
.51447 .63123 Mdot
.56701 .39525 Mdot
.5645 .3921 Mdot
.47318 .67141 Mdot
.35229 .56528 Mdot
.62577 .33365 Mdot
.63188 .42008 Mdot
.14299 .59275 Mdot
.6691 .45925 Mdot
.30767 .20386 Mdot
.30718 .34405 Mdot
.38146 .26584 Mdot
.22035 .44226 Mdot
.33333 .38044 Mdot
.55787 .4003 Mdot
.58038 .45779 Mdot
.53323 .63665 Mdot
.60428 .39551 Mdot
.56036 .65659 Mdot
.38709 .5851 Mdot
.31046 .76723 Mdot
.28798 .54685 Mdot
.36026 .22128 Mdot
.60371 .39845 Mdot
.34177 .5036 Mdot
.64258 .58846 Mdot
.32949 .55667 Mdot
.35428 .38455 Mdot
.61983 .34977 Mdot
.7302 .66146 Mdot
.50407 .67658 Mdot
.39629 .40601 Mdot
.68214 .73261 Mdot
.65469 .73208 Mdot
.63344 .36258 Mdot
.4767 .66556 Mdot
.22386 .56695 Mdot
.66371 .29408 Mdot
.37403 .60264 Mdot
.63215 .57772 Mdot
.49812 .67025 Mdot
.34892 .56005 Mdot
.3422 .32871 Mdot
.38728 .37819 Mdot
.34872 .34503 Mdot
.76403 .61785 Mdot
.5512 .6316 Mdot
.64352 .58465 Mdot
.44413 .79192 Mdot
.52573 .7998 Mdot
.63674 .57486 Mdot
.46658 .66242 Mdot
.3755 .36506 Mdot
.36597 .37888 Mdot
.37868 .40731 Mdot
.73645 .70327 Mdot
.34103 .35987 Mdot
.51354 .21747 Mdot
.64692 .39423 Mdot
.50536 .43225 Mdot
.58005 .43036 Mdot
.38418 .59948 Mdot
.34317 .39079 Mdot
.45898 .54639 Mdot
.52974 .37921 Mdot
.30139 .73268 Mdot
.60242 .42745 Mdot
.33547 .57086 Mdot
.62244 .38246 Mdot
.54998 .23071 Mdot
.3505 .42175 Mdot
.60148 .3882 Mdot
.39797 .60169 Mdot
.65256 .60078 Mdot
.35398 .33997 Mdot
.56024 .39549 Mdot
.23809 .50647 Mdot
.63208 .44025 Mdot
.29637 .28834 Mdot
.69869 .42399 Mdot
.67452 .57527 Mdot
.67732 .34826 Mdot
.55721 .63086 Mdot
.51558 .45347 Mdot
.52976 .45212 Mdot
.35699 .56486 Mdot
.33404 .71078 Mdot
.49782 .65164 Mdot
.70223 .62402 Mdot
.52577 .43036 Mdot
.62299 .59751 Mdot
.35856 .44222 Mdot
.36731 .59546 Mdot
.58831 .33649 Mdot
.54224 .35584 Mdot
.34819 .25109 Mdot
.51414 .39078 Mdot
.56648 .43577 Mdot
.64839 .56179 Mdot
.48297 .19736 Mdot
.61154 .38594 Mdot
.54349 .5247 Mdot
.36186 .34667 Mdot
.64233 .34356 Mdot
.55743 .21032 Mdot
.62102 .41925 Mdot
.40093 .40046 Mdot
.32366 .36461 Mdot
.26732 .5561 Mdot
.65445 .61883 Mdot
.54824 .40334 Mdot
.65672 .25089 Mdot
.59267 .3651 Mdot
.38575 .57828 Mdot
.63976 .38578 Mdot
.49179 .66478 Mdot
.72824 .7041 Mdot
.53602 .63222 Mdot
.55786 .41561 Mdot
.38157 .40348 Mdot
.35852 .54479 Mdot
.76742 .63624 Mdot
.60764 .66715 Mdot
.50455 .21184 Mdot
.37608 .19428 Mdot
.67408 .58244 Mdot
.61685 .59531 Mdot
.35972 .59158 Mdot
.60241 .38702 Mdot
.62389 .2148 Mdot
.65376 .35418 Mdot
.61782 .38623 Mdot
.59243 .40861 Mdot
.39925 .77437 Mdot
.37081 .58466 Mdot
.5043 .63644 Mdot
.62063 .40572 Mdot
.63018 .40723 Mdot
.33478 .38991 Mdot
.65588 .60184 Mdot
.48631 .63447 Mdot
.66527 .59532 Mdot
.51582 .66382 Mdot
.30858 .77099 Mdot
.53021 .42152 Mdot
.65157 .59854 Mdot
.41483 .56427 Mdot
.38328 .41887 Mdot
.32229 .60924 Mdot
.48763 .63723 Mdot
.5293 .63915 Mdot
.60693 .42604 Mdot
.40182 .40162 Mdot
.38415 .42503 Mdot
.63949 .59861 Mdot
.40055 .55804 Mdot
.56094 .40093 Mdot
.59799 .34004 Mdot
.34424 .4588 Mdot
.54462 .6678 Mdot
.6271 .486 Mdot
.25044 .55889 Mdot
.59986 .38413 Mdot
.38515 .42232 Mdot
.58388 .4122 Mdot
.21764 .40263 Mdot
.40384 .3956 Mdot
.61527 .4295 Mdot
.57444 .80301 Mdot
.57909 .62433 Mdot
.26017 .51071 Mdot
.56411 .43768 Mdot
.27696 .26486 Mdot
.5924 .35088 Mdot
.15084 .61838 Mdot
.6653 .67123 Mdot
.55331 .40072 Mdot
.61095 .36242 Mdot
.47274 .35585 Mdot
.57042 .41828 Mdot
.47584 .67626 Mdot
.71367 .61347 Mdot
.33152 .39776 Mdot
.24082 .44793 Mdot
.47448 .40541 Mdot
.66771 .61716 Mdot
.54353 .6302 Mdot
.50017 .69346 Mdot
.64906 .57458 Mdot
.38319 .39278 Mdot
.58981 .37705 Mdot
.46364 .52406 Mdot
.5266 .68636 Mdot
.59746 .32145 Mdot
.3865 .57468 Mdot
.40562 .68195 Mdot
.53348 .60694 Mdot
.37052 .56603 Mdot
.55862 .37281 Mdot
.47528 .36084 Mdot
.78164 .55538 Mdot
.19546 .38729 Mdot
.3504 .54867 Mdot
.35288 .55986 Mdot
.7207 .72409 Mdot
.67454 .61547 Mdot
.37897 .2242 Mdot
.28769 .45304 Mdot
.37093 .53899 Mdot
.69377 .32231 Mdot
.51966 .67964 Mdot
.24277 .49943 Mdot
.41822 .39012 Mdot
.64184 .36425 Mdot
.58768 .39646 Mdot
.40067 .55591 Mdot
.30215 .33624 Mdot
.80825 .40523 Mdot
.36147 .56656 Mdot
.56961 .31216 Mdot
.44866 .47685 Mdot
.37563 .73152 Mdot
.53842 .67037 Mdot
.6513 .61779 Mdot
.68939 .581 Mdot
.34428 .37149 Mdot
.63733 .61252 Mdot
.54117 .78089 Mdot
.57199 .36995 Mdot
.36117 .55975 Mdot
.33923 .68478 Mdot
.37442 .56082 Mdot
.64959 .57618 Mdot
.6746 .57447 Mdot
.36418 .42229 Mdot
.36562 .417 Mdot
.38808 .27561 Mdot
.7071 .51718 Mdot
.59561 .4318 Mdot
.26144 .66815 Mdot
.35811 .42879 Mdot
.67709 .40183 Mdot
.61812 .59556 Mdot
.65538 .59875 Mdot
.64833 .49962 Mdot
.56637 .38428 Mdot
.67035 .26047 Mdot
.57114 .38371 Mdot
.70048 .53041 Mdot
.54101 .40984 Mdot
.5139 .63193 Mdot
.56231 .38467 Mdot
.61244 .61516 Mdot
.59651 .33373 Mdot
.63576 .40679 Mdot
.54488 .6712 Mdot
.61799 .44338 Mdot
.49059 .66315 Mdot
.56264 .42402 Mdot
.6625 .62169 Mdot
.54847 .64905 Mdot
.74229 .45451 Mdot
.55111 .5908 Mdot
.46693 .65174 Mdot
.63321 .60713 Mdot
.67483 .60977 Mdot
.74982 .41037 Mdot
.35424 .3833 Mdot
.3967 .35619 Mdot
.60479 .39017 Mdot
.55901 .65418 Mdot
.37465 .58723 Mdot
.63185 .3974 Mdot
.60715 .45731 Mdot
.58138 .44212 Mdot
.35 .36674 Mdot
.56054 .73183 Mdot
.64661 .60012 Mdot
.48287 .67531 Mdot
.61354 .55467 Mdot
.52242 .68394 Mdot
.52438 .37388 Mdot
.56958 .46095 Mdot
.36354 .29099 Mdot
.28129 .65456 Mdot
.7014 .75487 Mdot
.39214 .38378 Mdot
.52868 .61686 Mdot
.67644 .61042 Mdot
.66788 .35417 Mdot
.36131 .38509 Mdot
.48838 .66349 Mdot
.59754 .38028 Mdot
.53693 .38537 Mdot
.32228 .57257 Mdot
.52932 .4693 Mdot
.71385 .42441 Mdot
.52216 .68309 Mdot
.55334 .61896 Mdot
.52174 .79754 Mdot
.71139 .61365 Mdot
.48411 .55461 Mdot
.60148 .41551 Mdot
.65813 .61194 Mdot
.37079 .36544 Mdot
.77307 .58445 Mdot
.40845 .57343 Mdot
.54007 .55903 Mdot
.60291 .39697 Mdot
.42336 .51967 Mdot
.38193 .40506 Mdot
.63359 .58208 Mdot
.39965 .55366 Mdot
.65115 .55807 Mdot
.55298 .64505 Mdot
.49679 .14946 Mdot
.58744 .36508 Mdot
.59868 .43296 Mdot
.41209 .56513 Mdot
.36679 .36942 Mdot
.62958 .56287 Mdot
.30673 .29771 Mdot
.51299 .62368 Mdot
.64069 .22335 Mdot
.39899 .41934 Mdot
.53823 .24351 Mdot
.48739 .67841 Mdot
.35476 .58292 Mdot
.753 .43576 Mdot
.36288 .55188 Mdot
.55483 .41629 Mdot
.37123 .39715 Mdot
.39672 .58001 Mdot
.57377 .54953 Mdot
.17233 .60438 Mdot
.54949 .25763 Mdot
.57458 .37615 Mdot
.22082 .67168 Mdot
.26646 .33776 Mdot
.35276 .44354 Mdot
.39651 .54287 Mdot
.60598 .42111 Mdot
.55196 .37239 Mdot
.59627 .36687 Mdot
.39138 .56415 Mdot
.40916 .74524 Mdot
.50013 .63186 Mdot
.5854 .42921 Mdot
.65525 .61603 Mdot
.49013 .65728 Mdot
.36826 .72443 Mdot
.5344 .64635 Mdot
.38744 .44241 Mdot
.64046 .38875 Mdot
.34374 .52026 Mdot
.21496 .6981 Mdot
.35707 .57361 Mdot
.46567 .65547 Mdot
.63494 .38202 Mdot
.32482 .6847 Mdot
.35912 .39134 Mdot
.51974 .62328 Mdot
.61313 .41293 Mdot
.38782 .72458 Mdot
.73605 .65388 Mdot
.53328 .64571 Mdot
.35977 .37736 Mdot
.19551 .4639 Mdot
.60755 .3984 Mdot
.59013 .35314 Mdot
.37264 .37393 Mdot
.48665 .38361 Mdot
.68669 .735 Mdot
.57941 .40934 Mdot
.36954 .57098 Mdot
.62165 .18776 Mdot
.61084 .44073 Mdot
.6598 .50477 Mdot
.50332 .66964 Mdot
.25325 .53447 Mdot
.63849 .48006 Mdot
.6771 .38534 Mdot
.29324 .33775 Mdot
.47143 .44139 Mdot
.29053 .74015 Mdot
.56199 .64102 Mdot
.66453 .70933 Mdot
.28891 .74531 Mdot
.37137 .59903 Mdot
.42858 .37436 Mdot
.28914 .3917 Mdot
.77796 .66358 Mdot
.19927 .47981 Mdot
.59854 .73966 Mdot
.72878 .66866 Mdot
.44765 .50066 Mdot
.52156 .66074 Mdot
.68877 .62099 Mdot
.56474 .39938 Mdot
.26522 .33711 Mdot
.62833 .25697 Mdot
.79228 .36025 Mdot
.21215 .66168 Mdot
.6693 .26911 Mdot
.20953 .63608 Mdot
.16856 .52649 Mdot
.35393 .28011 Mdot
.27361 .6394 Mdot
.66081 .229 Mdot
.56725 .79876 Mdot
.51294 .16916 Mdot
.61531 .46688 Mdot
.56905 .5238 Mdot
.31926 .25141 Mdot
.50899 .23551 Mdot
.75706 .33885 Mdot
.52784 .62851 Mdot
.40925 .41483 Mdot
.28766 .40111 Mdot
.35559 .43783 Mdot
.43072 .61059 Mdot
.19613 .44361 Mdot
.15161 .57332 Mdot
.55326 .22663 Mdot
.25802 .27409 Mdot
.41337 .23345 Mdot
.87751 .51427 Mdot
.45294 .64751 Mdot
.38498 .36077 Mdot
.66045 .54899 Mdot
.50832 .80197 Mdot
.31476 .50382 Mdot
.27992 .36417 Mdot
.43126 .76549 Mdot
.74518 .5012 Mdot
.37827 .39162 Mdot
.68752 .36253 Mdot
.434 .62403 Mdot
.29301 .54733 Mdot
.71481 .63289 Mdot
.1776 .51092 Mdot
.48523 .53522 Mdot
.23855 .48608 Mdot
.39331 .66182 Mdot
.7134 .77718 Mdot
.68633 .47006 Mdot
.32307 .32365 Mdot
.34082 .61251 Mdot
.21748 .4193 Mdot
.79958 .61895 Mdot
.72468 .53179 Mdot
.51374 .80174 Mdot
.45118 .82114 Mdot
.24957 .33859 Mdot
.4947 .84632 Mdot
.38481 .34898 Mdot
.56926 .43772 Mdot
.43063 .34812 Mdot
.64354 .24812 Mdot
.68532 .61733 Mdot
.3229 .73168 Mdot
.67403 .60336 Mdot
.39925 .44297 Mdot
.72105 .70517 Mdot
.53042 .22018 Mdot
.66377 .24808 Mdot
.61865 .56756 Mdot
.56848 .45193 Mdot
.70424 .19666 Mdot
.28213 .72761 Mdot
.27139 .54461 Mdot
.14243 .59806 Mdot
.45062 .55058 Mdot
.70831 .3674 Mdot
.39618 .57811 Mdot
.26164 .72854 Mdot
.3688 .38466 Mdot
.41755 .84464 Mdot
.1943 .66034 Mdot
.80247 .41856 Mdot
.42976 .10152 Mdot
.50184 .78023 Mdot
.42968 .5167 Mdot
.45795 .43078 Mdot
.72329 .45525 Mdot
.8264 .47842 Mdot
.7817 .38339 Mdot
.32076 .67123 Mdot
.34973 .21419 Mdot
.26191 .72259 Mdot
.63622 .23678 Mdot
.50138 .15601 Mdot
.78908 .64987 Mdot
.51864 .50166 Mdot
.42353 .42673 Mdot
.45066 .60896 Mdot
.19962 .56225 Mdot
.38592 .80269 Mdot
.67032 .48836 Mdot
.50777 .12184 Mdot
.60995 .6028 Mdot
.65092 .67539 Mdot
.191 .41573 Mdot
.75631 .48662 Mdot
.69662 .39396 Mdot
.66205 .75122 Mdot
.58034 .3271 Mdot
.63519 .76535 Mdot
.22517 .63411 Mdot
.34502 .62539 Mdot
.57472 .79315 Mdot
.21795 .52794 Mdot
.32937 .27002 Mdot
.46411 .33312 Mdot
.50357 .80718 Mdot
.35088 .4288 Mdot
.72646 .50792 Mdot
.6934 .42111 Mdot
.14508 .57346 Mdot
.37801 .62717 Mdot
.13488 .51659 Mdot
.70024 .7134 Mdot
.54714 .43393 Mdot
.543 .46746 Mdot
.6061 .30234 Mdot
.70811 .50309 Mdot
.62876 .42774 Mdot
.31596 .52557 Mdot
.15061 .53458 Mdot
.40289 .23114 Mdot
.33268 .62912 Mdot
.33896 .71964 Mdot
.1918 .39224 Mdot
.38639 .3086 Mdot
.70474 .66939 Mdot
.68155 .53617 Mdot
.76661 .70821 Mdot
.4969 .64713 Mdot
.62683 .229 Mdot
.35622 .59445 Mdot
.74618 .61969 Mdot
.52687 .30237 Mdot
.81802 .48044 Mdot
.15053 .53321 Mdot
.6245 .74953 Mdot
.71943 .68701 Mdot
.77153 .4704 Mdot
.61766 .20213 Mdot
.33695 .72753 Mdot
.54315 .45142 Mdot
.25634 .38738 Mdot
.67437 .57978 Mdot
.41192 .29673 Mdot
.56304 .19068 Mdot
.60873 .70122 Mdot
.65224 .39649 Mdot
.79446 .51588 Mdot
.51817 .73386 Mdot
.53473 .56729 Mdot
.57727 .85032 Mdot
.55091 .33751 Mdot
.45847 .78891 Mdot
.2598 .32269 Mdot
.70386 .47337 Mdot
.20636 .40175 Mdot
.22132 .48749 Mdot
.47543 .83988 Mdot
.17794 .63636 Mdot
.59716 .68244 Mdot
.31926 .76079 Mdot
.14019 .5783 Mdot
.51099 .83798 Mdot
.50984 .41255 Mdot
.41751 .58774 Mdot
.63005 .85426 Mdot
.49303 .68378 Mdot
.39803 .78041 Mdot
.49131 .18016 Mdot
.39231 .7212 Mdot
.31825 .34823 Mdot
.6382 .44992 Mdot
.457 .50857 Mdot
.35803 .44542 Mdot
.62444 .43718 Mdot
.61562 .82336 Mdot
.49011 .82959 Mdot
.55631 .84152 Mdot
.26639 .29534 Mdot
.32166 .76801 Mdot
.41256 .49304 Mdot
.51866 .22954 Mdot
.34918 .45147 Mdot
.63165 .35516 Mdot
.63211 .63826 Mdot
.50158 .77867 Mdot
.79649 .5283 Mdot
.31128 .49018 Mdot
.36505 .44374 Mdot
.28568 .69696 Mdot
.90133 .57913 Mdot
.40969 .24737 Mdot
.55884 .20571 Mdot
.53688 .79067 Mdot
.69829 .50665 Mdot
.21059 .58707 Mdot
.80952 .45067 Mdot
.16014 .49704 Mdot
.33783 .43856 Mdot
.49578 .17427 Mdot
.61107 .72581 Mdot
.72434 .34587 Mdot
.55183 .73958 Mdot
.16763 .58025 Mdot
.4231 .45706 Mdot
.7899 .58181 Mdot
.27722 .42722 Mdot
.80468 .41167 Mdot
.67921 .65573 Mdot
.41217 .68246 Mdot
.57072 .18961 Mdot
.30629 .63181 Mdot
.68186 .50992 Mdot
.46234 .48977 Mdot
.65437 .33185 Mdot
.46986 .4401 Mdot
.67988 .50231 Mdot
.73005 .36822 Mdot
.36544 .78506 Mdot
.13474 .62016 Mdot
.69655 .77454 Mdot
.24167 .28619 Mdot
.22529 .62298 Mdot
.63937 .35481 Mdot
.1742 .42964 Mdot
.51203 .8549 Mdot
.17864 .64947 Mdot
.46654 .72043 Mdot
.55285 .68082 Mdot
.35879 .53034 Mdot
.6625 .78617 Mdot
.5358 .74022 Mdot
.17714 .46829 Mdot
.64664 .76695 Mdot
.39602 .53038 Mdot
.83781 .5685 Mdot
.47693 .82244 Mdot
.54563 .28431 Mdot
.54686 .47839 Mdot
.60423 .32696 Mdot
.57336 .23714 Mdot
.373 .44099 Mdot
.37962 .65068 Mdot
.71667 .51964 Mdot
.50922 .64553 Mdot
.66587 .64413 Mdot
.27546 .36443 Mdot
.63283 .43779 Mdot
.47007 .42366 Mdot
.41159 .41297 Mdot
.27996 .65019 Mdot
.30631 .58499 Mdot
.36384 .80062 Mdot
.49208 .76862 Mdot
.63968 .33174 Mdot
.69908 .47394 Mdot
.54152 .75005 Mdot
.68315 .74573 Mdot
.33814 .56891 Mdot
.19941 .64286 Mdot
.56839 .53386 Mdot
.72412 .50907 Mdot
.59275 .24517 Mdot
.33271 .27613 Mdot
.58984 .46749 Mdot
.25041 .57662 Mdot
.4747 .29237 Mdot
.54683 .56233 Mdot
.41837 .43162 Mdot
.42687 .42357 Mdot
.17684 .39131 Mdot
.56104 .77215 Mdot
.38847 .66679 Mdot
.1942 .63004 Mdot
.37921 .55375 Mdot
.36504 .42829 Mdot
.61824 .631 Mdot
.31729 .27804 Mdot
.49469 .26841 Mdot
.73632 .65437 Mdot
.44666 .74709 Mdot
.62212 .69206 Mdot
.20377 .63533 Mdot
.21668 .66031 Mdot
.78482 .3363 Mdot
.32745 .39964 Mdot
.32907 .29501 Mdot
.39458 .20899 Mdot
.39099 .43439 Mdot
.29701 .38515 Mdot
.33141 .49765 Mdot
.36944 .79583 Mdot
.40911 .53786 Mdot
.33727 .21916 Mdot
.72962 .40269 Mdot
.39477 .74124 Mdot
.76473 .64215 Mdot
.57611 .18943 Mdot
.19001 .61836 Mdot
.66497 .29834 Mdot
.52047 .31614 Mdot
.64054 .43981 Mdot
.55269 .49086 Mdot
.76338 .73236 Mdot
.5599 .59664 Mdot
.54232 .24185 Mdot
.21233 .51369 Mdot
.5863 .3714 Mdot
.69301 .78375 Mdot
.29309 .31709 Mdot
.71783 .73008 Mdot
.38381 .5288 Mdot
.57827 .35011 Mdot
.61093 .33637 Mdot
.64623 .52114 Mdot
.26303 .54505 Mdot
.41781 .79796 Mdot
.56678 .18315 Mdot
.21443 .55244 Mdot
.62754 .25733 Mdot
.45492 .78712 Mdot
.18111 .48618 Mdot
.26218 .344 Mdot
.51226 .52223 Mdot
.50604 .77509 Mdot
.75816 .46382 Mdot
.25604 .28071 Mdot
.60763 .53246 Mdot
.38454 .48349 Mdot
.33491 .47839 Mdot
.23866 .53606 Mdot
.77351 .60333 Mdot
.61837 .35221 Mdot
.68202 .73275 Mdot
.17117 .5184 Mdot
.7371 .29005 Mdot
.82164 .54035 Mdot
.67439 .79445 Mdot
.49766 .301 Mdot
.22914 .51662 Mdot
.26477 .35638 Mdot
.69081 .22641 Mdot
.58561 .52649 Mdot
.28342 .71256 Mdot
.76277 .46416 Mdot
.19889 .6323 Mdot
.41572 .59472 Mdot
.29292 .44473 Mdot
.34333 .72446 Mdot
.34165 .77323 Mdot
.4158 .32356 Mdot
.16987 .56471 Mdot
.4417 .53037 Mdot
.45018 .84173 Mdot
.29765 .63271 Mdot
.4388 .49018 Mdot
.53548 .61983 Mdot
.61869 .75587 Mdot
.21165 .62509 Mdot
.26007 .64444 Mdot
.57255 .19317 Mdot
.55774 .61793 Mdot
.68007 .63413 Mdot
.58349 .26987 Mdot
.76821 .52038 Mdot
.2345 .54661 Mdot
.69959 .47364 Mdot
.15886 .56028 Mdot
.63234 .53649 Mdot
.70213 .70244 Mdot
.45169 .78297 Mdot
.46673 .1519 Mdot
.26858 .54081 Mdot
.5787 .77308 Mdot
.2856 .33566 Mdot
.65404 .66429 Mdot
.69885 .33148 Mdot
.19518 .74326 Mdot
.44658 .16827 Mdot
.2858 .63643 Mdot
.38682 .80273 Mdot
.21387 .39182 Mdot
.2854 .65486 Mdot
.82728 .48934 Mdot
.66726 .46062 Mdot
.72524 .60551 Mdot
.59254 .40722 Mdot
.56268 .84925 Mdot
.75026 .52155 Mdot
.40974 .81733 Mdot
.1778 .41502 Mdot
.57408 .24162 Mdot
.63018 .43929 Mdot
.49111 .67653 Mdot
.40346 .63171 Mdot
.76228 .55252 Mdot
.47599 .37273 Mdot
.69486 .35976 Mdot
.46108 .7511 Mdot
.55024 .63432 Mdot
.559 .74063 Mdot
.31768 .41026 Mdot
.48634 .75486 Mdot
.24699 .55449 Mdot
.58972 .63686 Mdot
.50579 .54088 Mdot
.68686 .49965 Mdot
.65641 .46016 Mdot
.54313 .28374 Mdot
.81559 .49605 Mdot
.49617 .47982 Mdot
.53664 .64787 Mdot
.50529 .31586 Mdot
.36099 .21266 Mdot
.22706 .56722 Mdot
.4435 .81933 Mdot
.65486 .74627 Mdot
.53349 .31258 Mdot
.67423 .50733 Mdot
.82372 .46084 Mdot
.70741 .294 Mdot
.28856 .68174 Mdot
.61616 .48228 Mdot
.6905 .29234 Mdot
.2624 .39664 Mdot
.30282 .7633 Mdot
.50953 .17021 Mdot
.4438 .18237 Mdot
.49016 .59931 Mdot
.49615 .24048 Mdot
.58833 .25404 Mdot
.74333 .44334 Mdot
.50136 .55857 Mdot
.87149 .53909 Mdot
.41098 .37602 Mdot
.79225 .7187 Mdot
.38199 .59169 Mdot
.79439 .65366 Mdot
.75989 .44194 Mdot
.4614 .48519 Mdot
.48869 .56425 Mdot
.25514 .5795 Mdot
.29126 .46319 Mdot
.28127 .27501 Mdot
.77821 .35056 Mdot
.5285 .68304 Mdot
.57077 .17946 Mdot
.48323 .14378 Mdot
.4836 .34296 Mdot
.57167 .45102 Mdot
.43962 .16886 Mdot
.56711 .63647 Mdot
.79723 .52855 Mdot
.20385 .39355 Mdot
.24518 .62135 Mdot
.5233 .34573 Mdot
.7031 .50928 Mdot
.27563 .70415 Mdot
.17848 .62726 Mdot
.83672 .5358 Mdot
.22541 .63375 Mdot
.41718 .58703 Mdot
.42503 .49259 Mdot
.18059 .57338 Mdot
.70977 .39725 Mdot
.24616 .46917 Mdot
.70035 .39666 Mdot
.84787 .63373 Mdot
.37841 .77205 Mdot
.41577 .79667 Mdot
.70254 .40914 Mdot
.34065 .35713 Mdot
.28954 .59752 Mdot
.69586 .40075 Mdot
.25138 .61755 Mdot
.31563 .26002 Mdot
.69477 .41303 Mdot
.76187 .28753 Mdot
.3751 .24232 Mdot
.55344 .69253 Mdot
.59871 .26105 Mdot
.38206 .24462 Mdot
.39447 .53126 Mdot
.71603 .62246 Mdot
.21037 .52054 Mdot
.40974 .55774 Mdot
.23653 .55302 Mdot
.24107 .51147 Mdot
.41093 .21347 Mdot
.50655 .2682 Mdot
.21793 .57284 Mdot
.45879 .35963 Mdot
.43706 .38534 Mdot
.76978 .58993 Mdot
.47993 .62797 Mdot
.20292 .50504 Mdot
.51926 .62029 Mdot
.66098 .43581 Mdot
.55155 .55681 Mdot
.55659 .30745 Mdot
.68616 .77453 Mdot
.67555 .58372 Mdot
.38628 .36485 Mdot
.80585 .64957 Mdot
.3967 .4278 Mdot
.59253 .83387 Mdot
.81411 .46723 Mdot
.59412 .24381 Mdot
.60798 .67365 Mdot
.58947 .71668 Mdot
.84418 .40478 Mdot
.457 .41115 Mdot
.47348 .60447 Mdot
.44381 .4078 Mdot
.37271 .3585 Mdot
.46314 .77582 Mdot
.54756 .65923 Mdot
.63054 .49979 Mdot
.39576 .50472 Mdot
.40038 .46447 Mdot
.31969 .38894 Mdot
.5586 .54235 Mdot
.72039 .56966 Mdot
.36102 .79049 Mdot
.53008 .6607 Mdot
.82882 .64366 Mdot
.59848 .46311 Mdot
.45278 .32629 Mdot
.15814 .49332 Mdot
.83954 .552 Mdot
.48698 .6877 Mdot
.49933 .13606 Mdot
.53866 .40147 Mdot
.21658 .58638 Mdot
.3746 .3848 Mdot
.46835 .17547 Mdot
.671 .58447 Mdot
.71079 .46685 Mdot
.34823 .53621 Mdot
.78796 .58608 Mdot
.47165 .74311 Mdot
.33128 .36291 Mdot
.24258 .63942 Mdot
.33958 .28281 Mdot
.26933 .4468 Mdot
.57564 .72726 Mdot
.49376 .33627 Mdot
.50276 .26354 Mdot
.31919 .38269 Mdot
.39081 .78923 Mdot
.47626 .17184 Mdot
.28893 .76535 Mdot
.61439 .30518 Mdot
.65433 .72617 Mdot
.34092 .47324 Mdot
.23907 .57307 Mdot
.59134 .49514 Mdot
.156 .51589 Mdot
.72667 .52273 Mdot
.35189 .48751 Mdot
.69608 .5242 Mdot
.66947 .40877 Mdot
.49604 .52821 Mdot
.41103 .65551 Mdot
.80825 .38054 Mdot
.58159 .50197 Mdot
.80982 .60651 Mdot
.6243 .4787 Mdot
.47005 .79123 Mdot
.30821 .37171 Mdot
.53122 .69658 Mdot
.50839 .24222 Mdot
.37491 .62812 Mdot
.29135 .75351 Mdot
.15689 .50911 Mdot
.33502 .53901 Mdot
.45131 .77073 Mdot
.21693 .43069 Mdot
.64778 .33475 Mdot
.41165 .50789 Mdot
.56175 .43118 Mdot
.30263 .37796 Mdot
.84458 .55788 Mdot
.24923 .60108 Mdot
.54341 .45466 Mdot
.28939 .74077 Mdot
.25288 .71764 Mdot
.43818 .83478 Mdot
.63156 .21487 Mdot
.33466 .37592 Mdot
.54032 .8363 Mdot
.69107 .35076 Mdot
.15362 .59588 Mdot
.28096 .67205 Mdot
.17116 .40456 Mdot
.50167 .33506 Mdot
.21414 .49768 Mdot
.7845 .37455 Mdot
.27111 .4772 Mdot
.24313 .35035 Mdot
.43352 .46728 Mdot
.37111 .66723 Mdot
.22876 .3618 Mdot
.7657 .26608 Mdot
.59107 .48837 Mdot
.23774 .49705 Mdot
.27922 .40525 Mdot
.20374 .5135 Mdot
.67736 .67543 Mdot
.63959 .38472 Mdot
.34191 .69325 Mdot
.74668 .66257 Mdot
.68344 .48931 Mdot
.6753 .63535 Mdot
.67494 .67524 Mdot
.74858 .58697 Mdot
.70926 .54097 Mdot
.51285 .16862 Mdot
.50615 .3268 Mdot
.61816 .50102 Mdot
.55267 .44218 Mdot
.31149 .36335 Mdot
.63595 .61513 Mdot
.51677 .71587 Mdot
.56585 .42886 Mdot
.55373 .67503 Mdot
.27398 .45613 Mdot
.65349 .80702 Mdot
.32693 .62284 Mdot
.29289 .3058 Mdot
.41838 .39415 Mdot
.25827 .55603 Mdot
.39197 .33524 Mdot
.75497 .68275 Mdot
.65463 .70957 Mdot
.67043 .48813 Mdot
.26093 .70717 Mdot
.57125 .79364 Mdot
.35067 .25539 Mdot
.56629 .80843 Mdot
.41427 .57572 Mdot
.52359 .35354 Mdot
.29595 .42951 Mdot
.54911 .75607 Mdot
.40391 .44553 Mdot
.2155 .50419 Mdot
.47445 .60968 Mdot
.57301 .78023 Mdot
.25585 .32641 Mdot
.33738 .27842 Mdot
.58404 .27592 Mdot
.22465 .67178 Mdot
.51417 .67764 Mdot
.44651 .17621 Mdot
.24389 .45774 Mdot
.64337 .72437 Mdot
.45633 .80059 Mdot
.34184 .78907 Mdot
.4631 .55206 Mdot
.74374 .48643 Mdot
.59391 .35781 Mdot
.53468 .20174 Mdot
.25381 .59734 Mdot
.49938 .43539 Mdot
.44539 .71894 Mdot
.39166 .41781 Mdot
.42917 .68479 Mdot
.5804 .51895 Mdot
.73324 .59398 Mdot
.35256 .43934 Mdot
.64887 .25543 Mdot
.64624 .62335 Mdot
.44665 .55761 Mdot
.62221 .4364 Mdot
.7332 .4764 Mdot
.66137 .24307 Mdot
.54144 .33727 Mdot
.21067 .606 Mdot
.50992 .31806 Mdot
.33145 .26368 Mdot
.23105 .59272 Mdot
.29522 .68865 Mdot
.2887 .4682 Mdot
.52452 .24866 Mdot
.48137 .73074 Mdot
.57868 .44166 Mdot
.52612 .69687 Mdot
.37802 .43018 Mdot
.2018 .43476 Mdot
.49333 .29795 Mdot
.74342 .45843 Mdot
.47413 .48269 Mdot
.41791 .34733 Mdot
.46897 .46137 Mdot
.16907 .44801 Mdot
.2718 .47883 Mdot
.71865 .52307 Mdot
.43026 .58784 Mdot
.75818 .44338 Mdot
.82126 .49405 Mdot
.21879 .68651 Mdot
.81594 .44182 Mdot
.46604 .53263 Mdot
.81607 .59891 Mdot
.28782 .62021 Mdot
.2053 .38811 Mdot
.71915 .53592 Mdot
.46751 .56569 Mdot
.63548 .63288 Mdot
.32167 .5638 Mdot
.50944 .50275 Mdot
.5864 .6063 Mdot
.65252 .47372 Mdot
.41604 .71667 Mdot
.43823 .632 Mdot
.64239 .44303 Mdot
.40054 .77803 Mdot
.24524 .69111 Mdot
.47831 .17763 Mdot
.47836 .45409 Mdot
.70502 .64198 Mdot
.74175 .57529 Mdot
.2118 .30068 Mdot
.72107 .77452 Mdot
.59251 .35895 Mdot
.48387 .45739 Mdot
.72785 .49132 Mdot
.51402 .68538 Mdot
.68656 .4126 Mdot
.42591 .35891 Mdot
.35901 .5833 Mdot
.58355 .61083 Mdot
.59154 .77808 Mdot
.2593 .58197 Mdot
.77254 .50137 Mdot
.35844 .72569 Mdot
.648 .81315 Mdot
.32484 .24179 Mdot
.24312 .58324 Mdot
.17482 .35557 Mdot
.43458 .64673 Mdot
.42959 .40366 Mdot
.42035 .34254 Mdot
.37232 .79248 Mdot
.70148 .46476 Mdot
.75954 .61905 Mdot
.31789 .70895 Mdot
.72463 .52974 Mdot
.69739 .34154 Mdot
.45558 .78469 Mdot
.43426 .69556 Mdot
.46442 .50518 Mdot
.59084 .71758 Mdot
.5214 .81709 Mdot
.6331 .26501 Mdot
.25751 .69359 Mdot
.7528 .65959 Mdot
.73768 .25751 Mdot
.264 .73188 Mdot
.64653 .6416 Mdot
.69091 .67065 Mdot
.41961 .33949 Mdot
.72047 .39866 Mdot
.68799 .31577 Mdot
.79886 .54279 Mdot
.48294 .2668 Mdot
.57306 .70469 Mdot
.78689 .63537 Mdot
.68122 .50903 Mdot
.38854 .23806 Mdot
.46942 .56511 Mdot
.52794 .29368 Mdot
.46974 .76708 Mdot
.69513 .43557 Mdot
.58422 .55271 Mdot
.72627 .4279 Mdot
.49849 .32466 Mdot
.29563 .33311 Mdot
.22598 .45472 Mdot
.79575 .31336 Mdot
.30014 .70554 Mdot
.76128 .67589 Mdot
.64506 .40256 Mdot
.32025 .78721 Mdot
.23115 .46205 Mdot
.31422 .71076 Mdot
.28232 .29495 Mdot
.53646 .70347 Mdot
.36523 .48201 Mdot
.58012 .44168 Mdot
.24949 .66243 Mdot
.54743 .24425 Mdot
.3794 .25667 Mdot
.78282 .60679 Mdot
.70177 .4848 Mdot
.70789 .6719 Mdot
.74097 .4254 Mdot
.55775 .31994 Mdot
.40714 .40971 Mdot
.54435 .84361 Mdot
.45017 .52932 Mdot
.64467 .45606 Mdot
.50166 .42561 Mdot
.78855 .38259 Mdot
.38239 .18464 Mdot
.60372 .30317 Mdot
.54822 .79771 Mdot
.66655 .27134 Mdot
.60624 .28935 Mdot
.68002 .4072 Mdot
.3015 .17229 Mdot
.13799 .61437 Mdot
.32802 .38197 Mdot
.57066 .20369 Mdot
.67387 .27156 Mdot
.3631 .78534 Mdot
.61536 .72346 Mdot
.49743 .72271 Mdot
.75525 .34847 Mdot
.71743 .36648 Mdot
.56629 .45457 Mdot
.26543 .31445 Mdot
.20482 .66937 Mdot
.78554 .61283 Mdot
.2821 .73607 Mdot
.57848 .47725 Mdot
.5276 .42851 Mdot
.26553 .22678 Mdot
.18378 .58469 Mdot
.5861 .32652 Mdot
.79 .37843 Mdot
.42481 .42386 Mdot
.57448 .40106 Mdot
.37019 .74768 Mdot
.5615 .18276 Mdot
.67798 .51032 Mdot
.34307 .77406 Mdot
.34805 .43191 Mdot
.46185 .60232 Mdot
.35818 .5847 Mdot
.49324 .56225 Mdot
.53232 .40039 Mdot
.39515 .56774 Mdot
.59893 .28865 Mdot
.20923 .48789 Mdot
.37441 .52108 Mdot
.51991 .16089 Mdot
.14031 .4852 Mdot
.51173 .2906 Mdot
.33102 .59048 Mdot
.64907 .33401 Mdot
.37394 .24738 Mdot
.75872 .56331 Mdot
.34379 .45147 Mdot
.21814 .36852 Mdot
.29528 .81221 Mdot
.38111 .67562 Mdot
.71368 .58494 Mdot
.36771 .45023 Mdot
.61517 .4996 Mdot
.56327 .26831 Mdot
.43373 .54959 Mdot
.51125 .67311 Mdot
.65631 .37042 Mdot
.56659 .31636 Mdot
.37261 .52996 Mdot
.78814 .71695 Mdot
.63482 .37434 Mdot
.66656 .44106 Mdot
.15653 .59804 Mdot
.76949 .59151 Mdot
.4375 .32128 Mdot
.55329 .3534 Mdot
.29764 .54722 Mdot
.4665 .56621 Mdot
.19076 .51317 Mdot
.69826 .70718 Mdot
.3115 .74892 Mdot
.49073 .29733 Mdot
.60691 .27096 Mdot
.62681 .41448 Mdot
.68106 .6148 Mdot
.24613 .4958 Mdot
.33944 .74188 Mdot
.5586 .47364 Mdot
.16813 .62292 Mdot
.53855 .70376 Mdot
.43298 .73678 Mdot
.62372 .29728 Mdot
.45813 .83637 Mdot
.81142 .58415 Mdot
.57031 .25137 Mdot
.7435 .70596 Mdot
.55468 .76324 Mdot
.76673 .51996 Mdot
.49438 .67635 Mdot
.5918 .47458 Mdot
.34235 .42497 Mdot
.64869 .81767 Mdot
.34512 .74825 Mdot
.3368 .67098 Mdot
.41266 .68552 Mdot
.5154 .20659 Mdot
.25947 .43235 Mdot
.1612 .40377 Mdot
.5713 .74469 Mdot
.66124 .80612 Mdot
.44413 .18074 Mdot
.36348 .45246 Mdot
.22594 .52314 Mdot
.52288 .36047 Mdot
.53167 .64942 Mdot
.3361 .76028 Mdot
.59144 .3121 Mdot
.72492 .69638 Mdot
.55559 .3581 Mdot
.70078 .74608 Mdot
.5781 .58908 Mdot
.42769 .773 Mdot
.30952 .63964 Mdot
.82571 .49545 Mdot
.19043 .44248 Mdot
.31968 .54417 Mdot
.18579 .35403 Mdot
.19416 .45588 Mdot
.19977 .64521 Mdot
.74033 .64841 Mdot
.84537 .49311 Mdot
.26553 .6493 Mdot
.22024 .57286 Mdot
.31716 .63207 Mdot
.47598 .39171 Mdot
.61601 .75466 Mdot
.62373 .30018 Mdot
.25623 .50583 Mdot
.33086 .54185 Mdot
.46236 .91889 Mdot
.60188 .60695 Mdot
.37876 .34335 Mdot
.5858 .75604 Mdot
.22895 .68499 Mdot
.49322 .37668 Mdot
.23781 .34024 Mdot
.57003 .52453 Mdot
.54605 .45272 Mdot
.49683 .27702 Mdot
.50741 .1809 Mdot
.63134 .755 Mdot
.86417 .43429 Mdot
.32504 .24454 Mdot
.4176 .7063 Mdot
.5107 .53366 Mdot
.38565 .43698 Mdot
.32765 .34401 Mdot
.60416 .69382 Mdot
.23436 .32444 Mdot
.21234 .49437 Mdot
.18092 .57503 Mdot
.83755 .39442 Mdot
.37476 .22565 Mdot
.36877 .79221 Mdot
.2766 .61625 Mdot
.35901 .34404 Mdot
.67687 .64223 Mdot
.58111 .66331 Mdot
.32535 .66491 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0R?ooool2o`000;oooooo
000Looooo`03o`000?oooooooooo08Sooooo0_l0002oooooo`007?ooool00ol0003oooooooooo`2A
ooooo`;o0000]_ooool001cooooo00?o0000ooooooooool0TOooool2o`000;Kooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`2Qooooo`;o0000Y_ooool001cooooo00?o0000ooooooooool0SOooool2
o`0001;ooooo0ol0002Uooooo`007?ooool00ol0003oooooooooo`2=ooooo`;o00004oooool2o`00
0:Gooooo000Looooo`03o`000?oooooooooo09Oooooo0_l0002`ooooo`007?ooool00ol0003ooooo
ooooo`2Gooooo`;o00007oooool2o`0008oooooo000Looooo`03o`000?oooooooooo09kooooo0ol0
000<ooooo`;o00002?ooool3o`0008oooooo000Looooo`03o`000?oooooooooo09kooooo0ol0000<
ooooo`;o00002?ooool2o`00093ooooo000Looooo`03o`000?oooooooooo087ooooo0_l0000Foooo
o`;o00004oooool2o`0009Wooooo000Looooo`03o`000?oooooooooo087ooooo0_l0000Fooooo`;o
00002oooool2o`0000Kooooo0_l0002Iooooo`007?ooool00ol0003oooooooooo`2Nooooo`;o0000
1_ooool2o`0000Gooooo0_l0002Jooooo`007?ooool2o`00097ooooo0_l00002ooooo`;o00002?oo
ool2o`0000cooooo0ol0002Jooooo`007?ooool00ol0003oooooooooo`2@ooooo`;o00000_ooool2
o`0000Wooooo0_l0000;ooooo`;o0000Voooool001cooooo00?o0000ooooooooool0Woooool2o`00
0:Sooooo000Looooo`03o`000?oooooooooo09Oooooo0_l0000<ooooo`;o0000X_ooool001cooooo
00?o0000ooooooooool0L_ooool2o`0001oooooo0_l00002ooooo`;o00003?ooool2o`0000oooooo
0_l0002Aooooo`007?ooool00ol0003oooooooooo`1booooo`;o00004?ooool2o`0000Gooooo1?l0
0004ooooo`;o00003_ooool3o`00013ooooo0_l0002Aooooo`007?ooool00ol0003oooooooooo`1N
ooooo`;o00008_ooool4o`0000Gooooo1?l00005ooooo`;o000000?oooooo`000?l000002Oooool4
o`0001Sooooo0_l00029ooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o00008_ooool2o`00
00Wooooo0_l00005ooooo`;o000000?oooooo`000?l000001?ooool2o`0000?ooooo0_l0000Aoooo
o`;o00001oooool2o`0008Wooooo000Looooo`03o`000?oooooooooo08_ooooo1?l00005ooooo`;o
00000_ooool2o`0000?ooooo0_l0000Fooooo`;o0000T_ooool001cooooo00?o0000ooooooooool0
Roooool4o`0000Gooooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo0_l0000Cooooo`;o0000
TOooool001cooooo00?o0000ooooooooool0N?ooool2o`0000Wooooo1?l00005ooooo`?o00003Ooo
ool4o`000003ooooool0003o0000013ooooo1Ol0002Aooooo`007?ooool00ol0003oooooooooo`1X
ooooo`;o00003_ooool2o`0000Gooooo0_l00002ooooo`Go00001?ooool3o`0000oooooo0ol0000B
ooooo`Go000000?oooooo`000?l000001Oooool2o`0008Oooooo000Looooo`03o`000?oooooooooo
06Sooooo0_l0000?ooooo`;o00001?ooool2o`0000Gooooo0_l0000Gooooo`;o00004_ooool2o`00
0003ooooool0003o000000?o000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l00021oooo
o`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000
ooooooooool0M_ooool2o`000003ooooool0003o000000Sooooo0_l0000Mooooo`;o00002_ooool2
o`0000?ooooo0_l000001?oooooo0000o`000?l00003ooooo`;o00002?ooool2o`0000Kooooo0_l0
001iooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Q
onk^k_ooooooA4A400Kooooo00?o0000ooooooooool0M_ooool2o`0000Sooooo0_l000000ooooooo
0000o`00000Kooooo`Co00002_ooool3o`0000;ooooo0_l000001?oooooo0000o`000?l00004oooo
o`;o00003oooool2o`00017ooooo0_l0001Vooooo`0000?ooooooa0@4?ooool00_ooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0M_ooool2o`0000So
oooo0_l000000ooooooo0000o`00000Dooooo`;o00001Oooool2o`0000gooooo0_l00002ooooo`;o
00001Oooool2o`000003ooooool0003o000000oooooo0_l0000Aooooo`;o0000I_ooool00003oooo
ool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06ooooo`?o0000
Poooool2o`0001Cooooo0_l00009ooooo`;o00001?ooool2o`0000kooooo0_l00007ooooo`Co0000
0oooool2o`0007gooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?o
MgMgofIVI_ooool01Oooool00ol0003oooooooooo`1Pooooo`;o0000=oooool2o`0000Wooooo0_l0
0004ooooo`;o00001_ooool2o`0000;ooooo0_l0000:ooooo`Go00000oooool2o`0007gooooo0000
0ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1Pooooo`;o00003oooool2o`000003ooooool0003o000000?ooooo1_l0000=
ooooo`;o00002oooool2o`0000Wooooo0_l00005ooooo`;o00000_ooool2o`000003ooooool0003o
000000;ooooo0_l0000:ooooo`;o0000QOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2ooo
ool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0KOooool2o`0000;ooooo
0_l000000ooooooo0000o`000003ooooo`Ko00003Oooool2o`0001;ooooo0_l00002ooooo`;o0000
1Oooool2o`000003ooooool0003o000000?o00002Oooool2o`0008_ooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo
06gooooo1?l000000ooooooo0000o`00000>ooooo`Co00006_ooool2o`0000cooooo0_l000000ooo
oooo0000o`000009ooooo`;o00002Oooool4o`0007kooooo000Looooo`03o`000?oooooooooo06ko
oooo1_l0000>ooooo`Co00007Oooool2o`0000[ooooo0_l00002ooooo`;o00004_ooool4o`0000_o
oooo0_l0001aooooo`007?ooool00ol0003oooooooooo`1Zooooo`;o00000oooool4o`0000Kooooo
0_l00006ooooo`?o00007oooool2o`0000Cooooo0_l00004ooooo`;o00000_ooool2o`0000[ooooo
0ol0000=ooooo`;o00001Oooool2o`00077ooooo000Looooo`03o`000?oooooooooo06[ooooo0_l0
0003ooooo`Co00001?ooool4o`0000Kooooo0ol0000Pooooo`;o00000oooool2o`0000Sooooo0_l0
000:ooooo`?o00000_ooool2o`0000Kooooo0_l000000ooooooo0000o`00001hooooo`007?ooool0
0ol0003oooooooooo`1Cooooo`;o00008Oooool4o`0000Oooooo1?l0000Oooooo`;o00002_ooool2
o`0001;ooooo0_l00006ooooo`;o00003oooool2o`0006[ooooo000Looooo`03o`000?oooooooooo
05?ooooo0_l0000<ooooo`;o00004oooool2o`0000Oooooo1_l0000Pooooo`;o00002?ooool3o`00
00?ooooo0_l000000ooooooo0000o`00000>ooooo`;o00002Oooool2o`0000Sooooo0_l0001Zoooo
o`007?ooool00ol0003oooooooooo`1Qooooo`;o00007?ooool6o`00023ooooo0_l00008ooooo`;o
00001?ooool2o`000003ooooool0003o000000kooooo0_l00009ooooo`;o00004_ooool2o`00063o
oooo000Looooo`03o`000?oooooooooo07oooooo0_l00002ooooo`;o00007Oooool2o`0001;ooooo
1?l00005ooooo`;o00002_ooool2o`0001[ooooo0_l0001Pooooo`007?ooool00ol0003ooooooooo
o`1]ooooo`;o00002Oooool4o`0002Kooooo0_l00005ooooo`;o00002oooool4o`0000Cooooo0ol0
000:ooooo`;o0000O?ooool001cooooo00?o0000ooooooooool0I_ooool2o`0000Gooooo0_l00007
ooooo`Ko00008Oooool2o`0000;ooooo0_l00006ooooo`;o000000?oooooo`000?l000002?ooool3
o`0000Gooooo0_l00007ooooo`;o00001?ooool2o`0000Cooooo0_l000000ooooooo0000o`00001a
ooooo`007?ooool00ol0003oooooooooo`1Vooooo`;o00003_ooool4o`0002?ooooo0_l00002oooo
o`;o00002?ooool5o`0000Oooooo0_l00004ooooo`;o00002?ooool2o`0000Cooooo0_l00004oooo
o`;o000000?oooooo`000?l00000LOooool001cooooo00?o0000ooooooooool0I_ooool2o`0000ko
oooo1?l00007ooooo`;o00007_ooool2o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l0
00003Oooool2o`0000kooooo0_l00003ooooo`Co0000Loooool001cooooo0_l0001Uooooo`;o0000
1oooool2o`0000Oooooo0_l00002ooooo`;o00001Oooool2o`0002;ooooo1?l0000<ooooo`;o0000
3Oooool2o`0000Oooooo0_l00003ooooo`Co0000Loooool001cooooo00?o0000ooooooooool0Fooo
ool3o`0000;ooooo0_l00002ooooo`;o00001oooool3o`0000[ooooo0_l00006ooooo`;o00008Ooo
ool2o`0000kooooo0_l00004ooooo`;o00001oooool2o`0000Wooooo0_l000000ooooooo0000o`00
0002o`0000;ooooo0_l0001_ooooo`007?ooool00ol0003oooooooooo`1Jooooo`Co00000_ooool2
o`0000_ooooo0ol00008ooooo`;o00002?ooool2o`0001Oooooo0_l0000<ooooo`;o00001?ooool2
o`0000;ooooo0_l00006ooooo`;o00002oooool2o`000003ooooool0003o000000;ooooo0_l00002
ooooo`;o00000oooool2o`0001;ooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`1Joooo
o`;o00001oooool2o`0000Cooooo0_l00002ooooo`?o00002?ooool2o`00027ooooo0_l0000<oooo
o`;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000007ooooo`;o00000_ooool2o`00
00?ooooo0_l000000ooooooo0000o`000005ooooo`;o000000Coooooo`000?l0003o00005?ooool2
o`0005_ooooo000Looooo`03o`000?oooooooooo053ooooo0_l0000Aooooo`;o00000oooool3o`00
00?ooooo0_l00008ooooo`;o00001_ooool2o`0001kooooo0_l0000>ooooo`;o00001?ooool2o`00
00Oooooo0_l00002ooooo`;o00002Oooool2o`0000;ooooo0_l000001?oooooo0000o`000?l0001a
ooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00001?ooool2o`00013ooooo0_l0000>oooo
o`;o00001_ooool2o`0001Oooooo0_l00005ooooo`;o00003_ooool2o`00017ooooo0_l00005oooo
o`;o00000_ooool2o`0002Gooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`1Fooooo`;o
00003oooool2o`0000Kooooo0_l00007ooooo`;o00002Oooool2o`0001Cooooo2_l00008ooooo`;o
00001_ooool2o`0000Gooooo0_l00009ooooo`;o00000oooool2o`0000[ooooo0_l00002ooooo`;o
00001Oooool2o`0000;ooooo0_l0000>ooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0
I_ooool3o`0000Kooooo0_l00002ooooo`;o00003_ooool2o`0001Kooooo2?l00008ooooo`;o0000
1_ooool3o`0000Cooooo0_l00005ooooo`;o00000_ooool2o`0000kooooo1?l000000ooooooo0000
o`000005ooooo`;o00000_ooool3o`00067ooooo000Looooo`03o`000?oooooooooo04gooooo0_l0
00000ooooooo0000o`000006ooooo`;o00003?ooool4o`0000Wooooo0_l00005ooooo`;o00008_oo
ool2o`0000Cooooo1?l00002ooooo`;o00002?ooool2o`0000Cooooo0_l00005ooooo`;o00001Ooo
ool2o`0000_ooooo1?l00004ooooo`;o00001oooool2o`00067ooooo000Looooo`03o`000?oooooo
oooo04gooooo0_l000000ooooooo0000o`000004ooooo`Co00002Oooool2o`0000?ooooo1?l00003
ooooo`;o00000_ooool2o`0000Gooooo0_l00004ooooo`;o00007?ooool2o`0000Cooooo1?l00002
ooooo`;o00003_ooool2o`0000cooooo0_l0000Cooooo`;o0000J_ooool001cooooo00?o0000oooo
ooooool0Coooool2o`0000?ooooo1?l00007ooooo`;o00000_ooool2o`0000Gooooo0ol00002oooo
o`;o00003oooool2o`0003cooooo0_l0000Qooooo`;o00001?ooool3o`0005oooooo000Looooo`03
o`000?oooooooooo04_ooooo0_l00002ooooo`;o00000oooool3o`0000Oooooo0ol0000:ooooo`;o
0000@?ooool2o`0000oooooo0_l0000Pooooo`?o00001?ooool3o`0005oooooo000Looooo`03o`00
0?oooooooooo04_ooooo0_l0000@ooooo`?o000000?oooooo`000?l000000_ooool2o`0000gooooo
0_l0000:ooooo`;o00000_ooool2o`0002Oooooo0_l00003ooooo`;o00002_ooool5o`000003oooo
ool0003o000000gooooo0_l000001?oooooo0000o`000?l00004ooooo`;o000000?oooooo`000?l0
00004_ooool2o`0005?ooooo000Looooo`03o`000?oooooooooo05Cooooo0_l00007ooooo`;o0000
0_ooool2o`0000;ooooo0_l0000;ooooo`Co00002_ooool7o`0000oooooo0_l0000:ooooo`;o0000
3_ooool2o`0000_ooooo1?l000001?oooooo0000o`000?ooool2o`0000[ooooo0_l000001?oooooo
0000o`000?l00003ooooo`Go00002oooool2o`0000Kooooo0_l0001Cooooo`007?ooool00ol0003o
ooooooooo`1Cooooo`?o00000_ooool2o`0000gooooo0_l00009ooooo`;o00003_ooool2o`000003
ooooool0003o000000oooooo0_l00004ooooo`;o00001?ooool2o`0000Cooooo0_l0000?ooooo`;o
00003?ooool2o`0000_ooooo0_l00006ooooo`;o000000Coooooo`000?l0003ooooo0_l00008oooo
o`;o0000Foooool001cooooo00?o0000ooooooooool0D_ooool3o`0000?ooooo0_l00006ooooo`;o
00001Oooool4o`0001Oooooo0_l00004ooooo`;o00004?ooool4o`0000[ooooo0_l0000?ooooo`;o
00003?ooool2o`0000;ooooo0_l00007ooooo`;o00001oooool3o`0000;ooooo0_l0001Uooooo`00
7?ooool2o`0004;ooooo0_l0000?ooooo`;o00001?ooool2o`0000?ooooo0_l000000ooooooo0000
o`000007ooooo`;o00001oooool2o`0000kooooo0_l000001?oooooo0000o`000?ooool2o`00013o
oooo1_l0000Wooooo`;o00000_ooool2o`0000Oooooo0_l00007ooooo`?o00000_ooool2o`0006Go
oooo000Looooo`03o`000?oooooooooo047ooooo0_l0000Eooooo`;o00000oooool2o`0000?ooooo
0_l0000>ooooo`;o00004Oooool4o`0001Gooooo0_l00007ooooo`;o00005oooool3o`000004oooo
ool0003o0000ooooo`;o0000<?ooool2o`0004kooooo000Looooo`03o`000?oooooooooo05_ooooo
0_l00005ooooo`?o00003_ooool2o`0000oooooo0_l000000ooooooo0000o`00000Cooooo`;o0000
2Oooool2o`0000Sooooo0_l00005ooooo`;o00001_ooool3o`000003ooooool0003o000002Wooooo
0_l00008ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0Foooool2o`0000Kooooo0_l0
0006ooooo`;o00001_ooool2o`0000Gooooo0_l00008ooooo`;o00005_ooool2o`00017ooooo1?l0
0005ooooo`?o00001_ooool2o`000004ooooool0003o0000o`0000Wooooo0_l0000Booooo`;o0000
1_ooool2o`000003ooooool0003o000005Sooooo000Looooo`03o`000?oooooooooo05Wooooo0_l0
0006ooooo`;o00002?ooool2o`0000gooooo0_l0000@ooooo`;o00002?ooool2o`0000_ooooo0_l0
0005ooooo`;o00000oooool2o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l000001?oo
ool2o`000003ooooool0003o000000?ooooo0_l00004ooooo`;o00004_ooool2o`0000Kooooo0_l0
0009ooooo`;o00001_ooool2o`0004Sooooo000Looooo`03o`000?oooooooooo05?ooooo0_l00004
ooooo`Ko00000_ooool2o`0000Sooooo0_l000000ooooooo0000o`00000Looooo`;o00002?ooool4
o`0000Kooooo0_l000000ooooooo0000o`000002o`0000?ooooo1?l000001?oooooo0000o`000?oo
ool5o`000004ooooool0003o0000ooooo`?o00001?ooool2o`0000Kooooo0_l0000:ooooo`;o0000
0_ooool4o`0001Wooooo0_l00006ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0Dooo
ool2o`0000Kooooo1?l0000?ooooo`;o00001Oooool2o`000004ooooool0003o0000o`0001gooooo
0_l00006ooooo`Co000000?oooooo`000?l000000_l00003ooooo`;o000000?oooooo`000?l00000
1Ol00002ooooo`Go00000oooool2o`0000Sooooo0_l0000:ooooo`;o00000_ooool4o`0006_ooooo
000Looooo`03o`000?oooooooooo04Cooooo1?l00009ooooo`;o00008_ooool2o`000004ooooool0
003o0000o`0000oooooo0_l0000Fooooo`;o00000oooool2o`0000Sooooo0ol00005ooooo`;o0000
0oooool8o`0001Sooooo0_l00002ooooo`;o00001_ooool3o`0005cooooo000Looooo`03o`000?oo
oooooooo04Cooooo2Ol00004ooooo`;o00002?ooool2o`0000Gooooo0_l000000ooooooo0000o`00
000Looooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l000000ooooooo0000o`00
000:ooooo`;o00000_ooool2o`0001[ooooo0ol000000ooooooo0000o`000002o`000003ooooool0
003o000000[ooooo0ol00008ooooo`;o00000_ooool2o`0000Kooooo0ol0001Looooo`007?ooool0
0ol0003oooooooooo`18ooooo`Go00000_ooool2o`0000[ooooo0_l00005ooooo`;o000000?ooooo
o`000?l000001?ooool2o`00013ooooo0_l00004ooooo`;o000000?oooooo`000?l000001oooool2
o`000003ooooool0003o000000[ooooo0_l000001?oooooo0000o`000?l00006ooooo`;o00002Ooo
ool2o`0000;ooooo1?l00002ooooo`Oo000000Coooooo`000?l0003o00002?ooool4o`0001Wooooo
0_l0001Hooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o00000_ooool2o`0001[ooooo0_l0
0003ooooo`;o00000_ooool2o`0000Oooooo0_l00002ooooo`;o00001?ooool2o`0001Sooooo0_l0
0007ooooo`;o00001?ooool3o`0000;ooooo0_l00002ooooo`Go00000_ooool4o`0000Cooooo0_l0
0002ooooo`;o00000oooool3o`0000_ooooo0_l00002ooooo`;o00002_ooool4o`000003ooooool0
003o000000Oooooo0ol00019ooooo`007?ooool00ol0003oooooooooo`11ooooo`;o00000oooool2
o`0001Cooooo0_l0000=ooooo`;o00000oooool2o`0000;ooooo0_l00006ooooo`;o00000oooool2
o`0000Cooooo0_l0000:ooooo`;o00001Oooool2o`0000?ooooo0_l0000?ooooo`?o00000_ooool2
o`000005ooooool0003o0000o`000?ooool01ol00002ooooo`Go00000_ooool2o`000003ooooool0
003o000000;o00001_ooool2o`0000?ooooo0ol00002ooooo`;o00003?ooool2o`000003ooooool0
003o000000Oooooo0ol00019ooooo`007?ooool00ol0003oooooooooo`11ooooo`;o00000oooool2
o`0000Gooooo0_l00003ooooo`?o00001?ooool2o`000003ooooool0003o000000;o00000_ooool2
o`0000Wooooo0_l0000=ooooo`Co00004oooool2o`0000Gooooo0_l000000ooooooo0000o`000002
o`0000Oooooo0_l00002ooooo`Go00001?ooool2o`000003ooooool0003o000000Oo00000_ooool9
o`0000?ooooo0_l00008ooooo`;o000000?oooooo`000?l000000_l0000Kooooo`;o0000C?ooool0
01cooooo00?o0000ooooooooool0A_ooool2o`0000;ooooo0_l000001?oooooo0000o`000?l00002
ooooo`Go00000_ooool2o`000003ooooool0003o000000;o00000_ooool2o`0000Wooooo2?l00000
0ooooooo0000o`000006ooooo`;o00001Oooool2o`0000_ooooo0ol00008ooooo`;o00002?ooool3
o`0000;ooooo1Ol00003ooooo`ko000000?oooooo`000?l000001?l000001?oooooo0000o`000?oo
ool3o`0000cooooo0_l000001?oooooo0000o`000?l0000@ooooo`;o00001oooool2o`0004cooooo
000Looooo`03o`000?oooooooooo04Cooooo0ol00003ooooo`;o00000_ooool2o`000003ooooool0
003o000000;ooooo0_l00009ooooo`Co00000oooool2o`0000Gooooo1ol000001?oooooo0000o`00
0?l00005ooooo`;o00001Oooool2o`0000_ooooo0ol00004ooooo`;o00003?ooool2o`0000;ooooo
0ol00004ooooo`Co000000?oooooo`000?l000004Ol00003ooooo`Ko00001?ooool2o`0000Kooooo
0ol00003ooooo`;o00002oooool2o`0005Gooooo000Looooo`03o`000?oooooooooo04Cooooo0ol0
0003ooooo`;o00001Oooool2o`0000cooooo1Ol00003ooooo`;o00001Oooool8o`000004ooooool0
003o0000o`0000Wooooo1?l0000Booooo`;o00002oooool4o`000003ooooool0003o000000?o0000
0_oooolHo`0000;ooooo1ol00004ooooo`;o00001oooool2o`0000?ooooo1_l00006ooooo`;o0000
E_ooool001cooooo0_l0001;ooooo`?o00004_ooool2o`0000?ooooo0_l00008ooooo`?o000000?o
ooooo`000?l000001ol00008ooooo`?o000000Coooooo`000?l0003o00007?ooool5o`0000?ooooo
0_l000000ooooooo0000o`000002oooooaGo00000_ooool6o`0000Kooooo0_l00003ooooo`Go0000
0oooool6o`0000Kooooo0ol00005ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0>Ooo
ool2o`0000Wooooo1?l00003ooooo`;o00002Oooool2o`0000Wooooo0_l000000ooooooo0000o`00
0002ooooo`Ko00001oooool6o`0000cooooo0ol0000?ooooo`;o00002ooooolUo`0000?ooooo1?l0
0006ooooo`;o00000oooool4o`0000Cooooo0ol00009ooooo`?o00001Oooool2o`0004kooooo000L
ooooo`03o`000?oooooooooo03Gooooo0_l00002ooooo`;o00002Oooool4o`0000[ooooo0_l00002
ooooo`;o00002Oooool3o`0000Cooooo2?l000000ooooooo0000o`000008o`0000;ooooo0_l0000G
ooooo`;o000000Coooooo`000?l0003ooooo0_l00005ooooo`;o000000?oooooo`000?l000005ol0
00000ooooooo0000o`00000Ao`0000;ooooo0_l000000ooooooo0000o`00000<ooooo`;o00001Ooo
ool2o`0000Oooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`0eooooo`;o00003oooool2
o`0000Oooooo0_l000000ooooooo0000o`000008ooooo`;o00000oooool5o`0000?ooooo1?l00000
0ooooooo0000o`00000;o`0000;ooooo0_l00008ooooo`;o00000_ooool2o`0000Cooooo0_l00003
ooooo`;o00001?ooool2o`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l000001?l00000
0ooooooo0000o`00000To`000003ooooool0003o000000Cooooo0_l0000=ooooo`;o00001oooool2
o`0000Gooooo0_l00004ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0@_ooool2o`00
00?ooooo0_l00006ooooo`;o00000oooool2o`0000Kooooo0_l00006ooooo`;o00000_oooolCo`00
00Gooooo0_l00004ooooo`?o00000_ooool2o`0000Cooooo0_l00004ooooo`;o00003Oooool2o`00
00Gooooo8Ol00005ooooo`Co00001Oooool4o`0001gooooo0ol00002ooooo`?o0000A?ooool001co
oooo00?o0000ooooooooool0@_ooool2o`0000?ooooo0_l0000;ooooo`Go00000_ooool2o`0000Co
oooo0_l00002ooooo`;o000000?oooooo`000?l000004_l00004ooooo`;o00001?ooool2o`0000oo
oooo0_l0000<ooooo`?o00000_ooool=o`000003ooooool0003o000000So000000?oooooo`000?l0
00002_l00006ooooo`Ko000000?oooooo`000?l000001Oooool2o`0001Wooooo0_l00002ooooo`;o
0000AOooool001cooooo00?o0000ooooooooool0@oooool2o`0000oooooo1Ol00002ooooo`Co0000
0_ooool6o`0000;ooooo5_l0000?ooooo`;o00001_ooool2o`0000Wooooo0_l00002ooooo`;o0000
00?oooooo`000?l000001Ol000000ooooooo0000o`000005o`000003ooooool0003o000001Go0000
1oooool5o`000003ooooool0003o000000Cooooo1Ol00002ooooo`;o0000G_ooool001cooooo00?o
0000ooooooooool0@oooool2o`000003ooooool0003o000000Oooooo0_l00005ooooo`;o00000ooo
ool4o`000003ooooool0003o000000?o00001?oooolBo`000004ooooool0003o0000o`0000oooooo
0_l00006ooooo`;o00002Oooool2o`0000;ooooo0_l000000ooooooo0000o`00000Yo`0000Kooooo
0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000000_ooool2o`0005kooooo
000Looooo`03o`000?oooooooooo04Kooooo0_l00007ooooo`;o00001Oooool2o`0000?ooooo1?l0
00000ooooooo0000o`000005oooooaGo000000?oooooo`000?l000000_l00006ooooo`;o00003Ooo
ool3o`0000gooooo0ol000000ooooooo0000o`00000=o`000003ooooool0003o000001Oo00000_oo
ool2o`0000;ooooo0_l000000ooooooo0000o`00000Mooooo`;o0000C?ooool001cooooo00?o0000
ooooooooool0A_ooool2o`0001Gooooo9?l000000ooooooo0000o`000005o`0000gooooo0ol00003
ooooo`;o00002?ooool3o`0000?ooooo3Ol000000ooooooo0000o`00000Ho`000004ooooool0003o
0000o`0000Cooooo0_l0000Mooooo`Co0000B_ooool001cooooo00?o0000ooooooooool0A_ooool2
o`0001Oooooo8_l000000ooooooo0000o`000003o`0001Gooooo0_l00009ooooo`?o00000_oooolX
o`0000;ooooo0_l00009ooooo`Co00005oooool3o`0000Cooooo0_l00014ooooo`007?ooool00ol0
003oooooooooo`12ooooo`;o00008?oooolMo`000003ooooool0003o000001Kooooo0_l0000;oooo
o`Ko000000?oooooo`000?l000008Ol000000ooooooo0000o`000002o`000003ooooool0003o0000
00?ooooo0_l00003ooooo`Co000000?oooooo`000?l000004_ooool4o`0000Gooooo0_l00014oooo
o`007?ooool00ol0003oooooooooo`0looooo`;o00001?ooool2o`0000cooooo0_l0000;ooooo`;o
00001OoooolMo`000003ooooool0003o000000?o00000_ooool3o`0000Kooooo0_l00006ooooo`;o
00002?ooool^o`0000;ooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00002?ooool3o`00
017ooooo1?l0001;ooooo`007?ooool00ol0003oooooooooo`0looooo`;o000000Coooooo`000?l0
003o00003_ooool2o`0000_ooooo0_l00005ooooo`?o000000?oooooo`000?l000002ol000000ooo
oooo0000o`00000?o`0000;ooooo0ol00006ooooo`;o00002?ooool2o`0000?ooooo<Ol00004oooo
o`Co00002?ooool2o`0000?ooooo0ol00003ooooo`;o00003Oooool2o`0004_ooooo00001_oooooo
k^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool0
0ol0003oooooooooo`0fooooo`;o00000oooool3o`000003ooooool0003o000000?o00005_ooool2
o`0000Cooooo0_l00002ooooo`?o000000?oooooo`000?l000007Ol00002ooooo`;o00000_ooool2
o`0000Sooooo0ol00002ooooo`;o00000oooool4o`0000;ooooo0_l00003ooooo`co00000_oooolE
o`0000Oooooo0_l00006ooooo`;o00000_ooool2o`0000Cooooo0_l00003ooooo`;o00005?ooool2
o`0004Cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0=_ooool2o`0000?ooooo0_l000000ooooooo0000o`00
0006o`0000cooooo0_l00006ooooo`?o000000?oooooo`000?l000000_l00002ooooo`Co000000Go
ooooo`000?l0003o0000ooooo`0Jo`0000;ooooo0_l00002ooooo`;o00002?ooool3o`0000[ooooo
0_l000000ooooooo0000o`000004ooooobOo00000oooool2o`0000Gooooo1?l0000Qooooo`;o0000
1oooool2o`0003_ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo1Ol0
0006ooooo`03o`000?oooooooooo03kooooo0_l00004ooooo`;o00003?ooool2o`0000Oooooo0_l0
00000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000007ol0000Mooooob7o00000ooo
ool=o`0000;ooooo0_l00007ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o0000
1Oooool2o`0001Wooooo0_l0000kooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooooooo
o`09ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0000oooooo`;o000000Coooooo`000?l0003o
00001?ooool4o`0000gooooo0_l00007ooooo`;o000000?oooooo`000?l000001ol00002ooooo`Co
00000_ooool4o`0000;ooooo2?l00004ooooo`?o00005_ooool2o`000003ooooool0003o0000023o
00000_ooool7o`0000?ooooo0_l00003ooooo`;o00001?ooool2o`0000?ooooo0_l000001?oooooo
0000o`000?ooool3o`0000;ooooo0_l000000ooooooo0000o`00001Fooooo`0000?oooooo`000?oo
ool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000oooo
ooooool0<Oooool2o`000003ooooool0003o000000Gooooo0ol000001?oooooo0000o`000?ooool3
o`0000Cooooo1?l0000:ooooo`;o000000?oooooo`000?l000002_ooool9o`000003ooooool0003o
000001?o00000oooool4o`0000;ooooo0_l00006ooooo`;o00002_ooool3o`000004ooooool0003o
0000ooooob[o00001Oooool2o`0000Cooooo0_l00006ooooo`;o000000?oooooo`000?l000000ooo
ool6o`0000Cooooo0_l00003ooooo`;o00001?ooool2o`0000Sooooo0ol0000iooooo`0000?ooooo
oa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000
ooooooooool0<Oooool2o`000004ooooool0003o0000o`0000Cooooo0ol000000ooooooo0000o`00
000Fooooo`;o000000?oooooo`000?l000000_l00008oooooaoo00000oooool2o`0000;ooooo1?l0
0006ooooo`;o00002oooool2o`000004ooooool0003o0000ooooobGo000000?oooooo`000?l00000
0_l00003ooooo`Go00001?ooool3o`0000Gooooo0ol00006ooooo`Co00001?ooool2o`0000?ooooo
0_l00004ooooo`;o00002?ooool3o`0003Wooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`co
oooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0eooooo`;o00001Oooool2o`0000_o
oooo0_l0000?ooooo`Co00001Oooool2o`000004ooooool0003o0000oooooago00001_ooool2o`00
00?ooooo0_l000000ooooooo0000o`00000<ooooo`;o00000ooooolJo`0000;ooooo2ol000000ooo
oooo0000o`000002ooooo`;o000000?oooooo`000?l000000ol00004ooooo`?o00001Oooool3o`00
00Kooooo0_l0000@ooooo`;o0000AOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool0
0omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo03Kooooo0_l0000;ooooo`;o00000oooool3
o`00017ooooo0_l00005ooooo`;o00001OoooolNo`0000Sooooo0ol000000ooooooo0000o`00000<
ooooo`;o00000oooool[o`000003ooooool0003o000000Kooooo0_l000001?oooooo0000o`000?l0
0008ooooo`;o00001Oooool2o`0000;ooooo0_l0000<ooooo`;o0000AOooool001cooooo00?o0000
ooooooooool0=Oooool3o`0000;ooooo0_l00002ooooo`;o00000oooool4o`000003ooooool0003o
000000?o000000?oooooo`000?l000006ooooolJo`000003ooooool0003o000000Sooooo0_l00002
ooooo`;o00003Oooool_o`0000Wooooo0_l000001?oooooo0000o`000?l00008ooooo`;o00002Ooo
ool2o`0000_ooooo1Ol00013ooooo`007?ooool00ol0003oooooooooo`0eooooo`;o00000oooool2
o`0000;ooooo0_l00003ooooo`[o000000?oooooo`000?l000000_ooool2o`0000gooooo0_l00004
ooooo`;o00000ooooolIo`0000cooooo0_l0000@ooooobco00003_ooool2o`0002;ooooo1ol00011
ooooo`007?ooool00ol0003oooooooooo`13ooooo`;o000000?oooooo`000?l000000_l00006oooo
o`Co00003Oooool2o`0000Cooooo0_l00003oooooaWo000000Coooooo`000?l0003o00002?ooool2
o`0000;ooooo0_l0000?ooooo`Co00000_ooool2o`000003ooooool0003o000000Oo000000?ooooo
o`000?l000004ol00007ooooo`;o00001_ooool4o`0000?ooooo0_l0000:ooooo`;o00005?ooool4
o`0003oooooo000Looooo`03o`000?oooooooooo03kooooo0_l0000@ooooo`;o00001?ooool4o`00
017ooooo0ol000000ooooooo0000o`00000Co`0000;ooooo0ol0000:ooooo`Co00002?ooool2o`00
00Sooooo0ol000000ooooooo0000o`00000Ko`0000;ooooo0ol00006ooooo`;o000000?oooooo`00
0?l000001Oooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o0000
01Kooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0eooooo`;o00001oooool2o`0000?o
oooo0_l0000>ooooo`Oo00000_ooool2o`0000gooooo0_l000000ooooooo0000o`00000Co`000003
ooooool0003o000000;o000000?oooooo`000?l000001_ooool4o`0000Gooooo0_l00003ooooo`;o
00001_ooool<o`000003ooooool0003o000001Co00000_ooool3o`0000Wooooo0_l00008ooooo`;o
00001?ooool4o`000003ooooool0003o000000?o0000Eoooool001cooooo00?o0000ooooooooool0
=Oooool2o`0000cooooo0_l00007ooooo`;o00000oooool7o`0000Cooooo0_l0000?oooooaGo0000
0_ooool2o`0000?ooooo0_l00006ooooo`;o00001?ooool2o`000003ooooool0003o000000Cooooo
0_l00004ooooo`Oo000000?oooooo`000?l000005_l00002ooooo`;o000000Coooooo`000?l0003o
00005?ooool4o`0000;ooooo1?l00003ooooo`;o0000F?ooool001cooooo00?o0000ooooooooool0
>?ooool2o`0000Cooooo0_l00004ooooo`Oo000000?oooooo`000?l000000oooool2o`0000;ooooo
0_l0000Fooooo`;o000000Goooooo`000?l0003o0000ooooo`03o`000003ooooool0003o000000So
00000_ooool2o`0000_ooooo0_l00004ooooo`;o00001Oooool4o`0000?ooooo0ol00006ooooo`Co
000000?oooooo`000?l000005?l00002ooooo`Go00000oooool2o`0000Wooooo0_l00003ooooo`Oo
00001oooool2o`0002;ooooo0_l0000booooo`007?ooool00ol0003oooooooooo`0fooooo`Co0000
1?ooool2o`0000Cooooo1ol0000?ooooo`;o00002oooool5o`0000?ooooo4?l000000ooooooo0000
o`000008ooooo`;o00002Oooool2o`0000Oooooo0_l00005ooooo`;o000000?oooooo`000?l00000
0_l00003ooooob7o00000oooool2o`0000Wooooo0_l00003ooooo`Go00002?ooool3o`0002;ooooo
0_l0000booooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00001?ooool3o`0000;ooooo0_l0
0003ooooo`;o00000oooool2o`000003ooooool0003o0000013ooooo0ol0000;ooooo`Go00000ooo
ool=o`000004ooooool0003o0000o`0000Oooooo0_l000000ooooooo0000o`000009ooooo`?o0000
0oooool2o`0000_ooooo1?l00004oooooaSo000000?oooooo`000?l000001ol00003ooooo`;o0000
2?ooool2o`0000gooooo1ol0000@ooooo`;o00002oooool2o`0003Gooooo000Looooo`03o`000?oo
oooooooo02oooooo0_l00004ooooo`;o00000oooool4o`000003ooooool0003o000000?ooooo0_l0
00000ooooooo0000o`000007ooooo`;o00001oooool4o`0000kooooo0_l00002ooooo`So000000?o
ooooo`000?l000000_l000000ooooooo0000o`000002o`0000Kooooo0_l0000<ooooo`?o00000ooo
ool2o`0000?ooooo0_l00007ooooo`;o00001Oooool@o`000003ooooool0003o000000So00000_oo
ool5o`000003ooooool0003o000000?o00001oooool2o`0000gooooo0_l00002ooooo`?o00004?oo
ool2o`0000_ooooo0_l0000eooooo`007?ooool00ol0003oooooooooo`0cooooo`Co00001Oooool2
o`0000Sooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l00002ooooo`;o00000oooool4
o`0000kooooo0ol000000ooooooo0000o`000006o`000003ooooool0003o000000?ooooo1?l0000O
ooooo`;o00001oooool4o`0000;ooooo1?l000001?oooooo0000o`000?ooool<o`000004ooooool0
003o0000ooooo`Co00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000Jooooo`;o0000
4Oooool2o`0004;ooooo000Looooo`;o0000=?ooool2o`00017ooooo1ol00007ooooo`;o00000ooo
ool2o`00017ooooo1?l00002ooooo`Co000000?oooooo`000?l000001?ooool2o`0000Cooooo0_l0
000Sooooo`Wo00000_ooool5o`0000;ooooo1ol00006ooooo`Oo00002?ooool2o`0000;ooooo0_l0
000Wooooo`Co0000@_ooool001cooooo00?o0000ooooooooool0A_ooool4o`0000Cooooo0_l0000:
ooooo`;o00004?ooool4o`0000;ooooo1?l000000ooooooo0000o`00000:ooooo`;o00000_ooool2
o`0000oooooo0_l0000:ooooo`;o00000_ooool2o`0000?ooooo0ol00002ooooo`Ko000000Cooooo
o`000?l0003o00000oooool2o`0000;ooooo0_l00004ooooo`Go00003?ooool2o`0000Kooooo0_l0
00000ooooooo0000o`000002o`0000Cooooo0_l000000ooooooo0000o`00000Aooooo`;o00000_oo
ool2o`00043ooooo000Looooo`03o`000?oooooooooo03_ooooo0_l00009ooooo`;o00001?ooool4
o`0000Gooooo0_l00003ooooo`;o00004?ooool2o`0001Sooooo0ol00007ooooo`;o00001_ooool3
o`0000Wooooo0_l00007ooooo`?o00000_ooool4o`0000?ooooo1_l000000ooooooo0000o`000004
o`0000Sooooo0_l0000Booooo`;o000000?oooooo`000?l000000_l00004ooooo`Oo00004oooool2
o`00043ooooo000Looooo`03o`000?oooooooooo03Cooooo0_l00005ooooo`;o00003oooool2o`00
00Oooooo0_l0000Dooooo`?o00002_ooool2o`0000cooooo0_l00002ooooo`;o00001?ooool2o`00
00?ooooo0_l00002ooooo`;o00004_ooool:o`0000;ooooo0_l000000ooooooo0000o`000008o`00
00;ooooo0_l00004ooooo`;o000000?oooooo`000?l000000_ooool3o`0000?ooooo0_l0000Aoooo
o`;o00000_ooool2o`0000oooooo0_l00003ooooo`;o0000?oooool001cooooo00?o0000oooooooo
ool0=?ooool2o`0000Kooooo0_l00007ooooo`Co00002?ooool2o`0000Oooooo0ol00004ooooo`;o
00000_ooool2o`0000Cooooo0_l0000;ooooo`;o00001?ooool2o`0000[ooooo0_l00009ooooo`;o
00000_ooool2o`00017ooooo0ol000000ooooooo0000o`000002o`000003ooooool0003o000000Go
oooo2ol000001?oooooo0000o`000?l00002ooooo`;o00000_ooool2o`0000;ooooo0ol00002oooo
o`?o00000oooool2o`0000gooooo1ol0000=ooooo`;o00000oooool2o`0000?ooooo0_l0000joooo
o`007?ooool00ol0003oooooooooo`0gooooo`;o00000oooool2o`0000Gooooo1_l00004ooooo`;o
000000Coooooo`000?l0003o00001_ooool6o`0000;ooooo0_l00002ooooo`Co00003Oooool2o`00
00Kooooo0ol00003ooooo`;o00000oooool2o`00027ooooo0ol00003ooooo`Go00000_ooool5o`00
0003ooooool0003o000000Ko00000_ooool2o`0000;ooooo0_l0000;ooooo`;o00001?ooool2o`00
0003ooooool0003o000000[ooooo1ol0000?ooooo`;o00001_ooool2o`0000Oooooo0_l0000aoooo
o`007?ooool00ol0003oooooooooo`0cooooo`;o000000Coooooo`000?l0003o00002_ooool2o`00
00;ooooo0_l00003ooooo`?o000000?oooooo`000?l000000_ooool2o`0000?ooooo0ol000000ooo
oooo0000o`000007ooooo`?o00003Oooool2o`0000Oooooo0_l00003ooooo`;o00000oooool2o`00
00gooooo1?l0000<ooooo`;o00000oooool2o`0000?ooooo1Ol00002ooooo`Go00000oooool2o`00
0005ooooool0003o0000o`000?ooool00_l0000Aooooo`;o00001_ooool4o`0000Kooooo0_l00008
ooooo`;o00003?ooool2o`0000oooooo0_l0000aooooo`007?ooool00ol0003oooooooooo`0coooo
o`;o000000?oooooo`000?l000003oooool4o`000003ooooool0003o000000Kooooo0_l00004oooo
o`;o00003oooool2o`0000oooooo0_l0000Hooooo`Ko00000_ooool2o`0000Sooooo0ol00007oooo
o`Co00001?ooool5o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000001Oooool3o`00
00Wooooo0_l00002ooooo`Co00000_ooool2o`000003ooooool0003o000000?ooooo0_l00004oooo
o`;o00000_ooool2o`0000[ooooo0_l00006ooooo`;o0000??ooool001cooooo00?o0000oooooooo
ool0BOooool2o`0000Wooooo0_l00006ooooo`;o00003Oooool2o`0000oooooo0_l0000@ooooo`;o
00001_ooool2o`000003ooooool0003o000000?ooooo0_l00009ooooo`;o00001oooool4o`0000;o
oooo1ol0000@ooooo`?o00003Oooool4o`0000Gooooo1?l00007ooooo`;o00003?ooool4o`000004
ooooool0003o0000o`0000;ooooo0_l0000looooo`007?ooool00ol0003oooooooooo`0mooooo`;o
00000oooool2o`00013ooooo1Ol00003ooooo`;o00002?ooool2o`000003ooooool0003o000002?o
oooo0_l0000=ooooo`;o00003oooool2o`0000Sooooo1_l00002ooooo`;o00001Oooool2o`0000?o
oooo0_l0000Looooo`;o00005Oooool2o`0000?ooooo1Ol0000nooooo`007?ooool00ol0003ooooo
ooooo`0mooooo`;o00000oooool2o`00017ooooo1Ol0000<ooooo`;o000000?oooooo`000?l00000
2?ooool2o`00027ooooo1?l00003ooooo`;o000000?oooooo`000?l000003?ooool2o`000003oooo
ool0003o000000Kooooo0ol00002ooooo`Co000000Goooooo`000?l0003o0000ooooo`02o`0000;o
oooo0ol0000Looooo`;o00002?ooool2o`00013ooooo0_l000000ooooooo0000o`00000nooooo`00
7?ooool00ol0003oooooooooo`0Zooooo`;o00001Oooool2o`0000Cooooo0_l0000Aooooo`;o0000
3?ooool2o`0001;ooooo0_l00005ooooo`?o00000oooool2o`0000gooooo0_l00008ooooo`;o0000
0_ooool4o`0000Kooooo0_l0000?ooooo`;o00002oooool2o`0000?ooooo0ol00002ooooo`Go0000
2?ooool2o`000004ooooool0003o0000ooooo`;o00000oooool4o`0000Kooooo0_l00002ooooo`;o
00001?ooool4o`0000kooooo0_l0000Hooooo`;o00009oooool001cooooo00?o0000ooooooooool0
:_ooool2o`0000Gooooo0_l00004ooooo`;o00001oooool2o`0000;ooooo0_l00004ooooo`;o0000
8?ooool2o`000003ooooool0003o000000?ooooo0_l00003ooooo`;o00003Oooool2o`0000Sooooo
1?l00004ooooo`;o00008?ooool2o`0000[ooooo1Ol00008ooooo`So00000oooool4o`0000[ooooo
0_l00002ooooo`;o00000_ooool2o`00013ooooo0ol0000Eooooo`;o00009oooool001cooooo00?o
0000ooooooooool0<oooool2o`0000_ooooo0_l00002ooooo`;o00006oooool2o`0000cooooo0_l0
0006ooooo`;o00003Oooool2o`0000?ooooo0_l00005ooooo`Co00001?ooool2o`0000?ooooo1?l0
0003ooooo`;o00002?ooool2o`0000[ooooo0_l0000=ooooo`;o00002Oooool2o`0000;ooooo0_l0
000=ooooo`;o00001oooool2o`0001Cooooo0ol0000?ooooo`;o0000;Oooool001cooooo00?o0000
ooooooooool0<?ooool2o`000003ooooool0003o000000_ooooo0ol0000:ooooo`Co00004?ooool2
o`0001Cooooo0_l00009ooooo`;o00000_ooool2o`0000?ooooo0_l00005ooooo`;o00002oooool4
o`0000?ooooo0_l00008ooooo`?o00002Oooool2o`0002_ooooo0_l0000Looooo`?o00001Oooool2
o`0000Wooooo0_l0000]ooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00001Oooool2o`00
00Sooooo0ol00005ooooo`So00005oooool2o`0001Oooooo0ol0000Mooooo`Co00003?ooool2o`00
00Wooooo0ol0000Jooooo`;o00009_ooool2o`0000;ooooo1Ol00005ooooo`;o0000>?ooool001co
oooo0_l0000`ooooo`?o00001Oooool2o`0000Gooooo0_l00002ooooo`;o00001Oooool5o`0001[o
oooo0ol00002ooooo`;o00003Oooool2o`0000?ooooo0ol0000:ooooo`;o00004_ooool5o`0001Co
oooo1?l00005ooooo`?o00000_ooool2o`0000Cooooo1_l00004ooooo`Co00002oooool2o`0000Co
oooo0_l00002ooooo`;o00000_ooool3o`0000Sooooo0_l00002ooooo`;o00001_ooool2o`0003[o
oooo000Looooo`03o`000?oooooooooo02oooooo0ol0000<ooooo`;o00000_ooool2o`0000Oooooo
0_l0000@ooooo`;o00001?ooool2o`0000Cooooo1_l00002ooooo`;o00000oooool4o`0000;ooooo
0ol00002ooooo`;o00002oooool2o`0001;ooooo1Ol0000Booooo`Go00001_ooool3o`0000;ooooo
0_l00004ooooo`Ko00001?ooool4o`0000Cooooo0ol00004ooooo`;o00001?ooool2o`0000;ooooo
0_l00002ooooo`?o00005?ooool2o`0003[ooooo000Looooo`03o`000?oooooooooo03kooooo0_l0
0002ooooo`;o00001_ooool3o`0000?ooooo0_l0000:ooooo`?o00001?ooool2o`0000Kooooo1?l0
0002ooooo`;o00000oooool4o`0000?ooooo0_l00002ooooo`?o00002Oooool2o`0000Cooooo0_l0
000=ooooo`Oo00001_ooool2o`0000Sooooo0ol0000>ooooo`;o00001oooool2o`0000;ooooo1?l0
0003ooooo`Ko00001?ooool2o`0001gooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0_
ooooo`;o00001Oooool2o`0000Kooooo0_l0000:ooooo`;o00000_ooool5o`0000Wooooo0_l0000>
ooooo`?o00001Oooool2o`0000cooooo0_l00003ooooo`;o00001?ooool2o`0000;ooooo1?l0000=
ooooo`Oo00001_ooool2o`0000Wooooo0_l00007ooooo`;o00001Oooool5o`0000Cooooo0_l00002
ooooo`Go00000_ooool5o`0000Cooooo0ol0000=ooooo`;o00003_ooool2o`0000Cooooo0_l0000j
ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00001Oooool2o`0000;ooooo0_l00002oooo
o`;o000000?oooooo`000?l000001_ooool4o`000004ooooool0003o0000ooooo`;o00001oooool4
o`0001Kooooo0ol00009ooooo`;o00000_ooool2o`000003ooooool0003o000000Sooooo0_l0000@
ooooo`?o00001oooool2o`0000Gooooo0_l0000=ooooo`;o00001oooool6o`0000Kooooo1?l00003
ooooo`Co00001?ooool2o`0000Cooooo0_l00008ooooo`;o00005?ooool2o`0003[ooooo000Loooo
o`03o`000?oooooooooo02Sooooo0_l00005ooooo`;o00000oooool2o`0000Cooooo0_l00002oooo
o`;o000000?oooooo`000?l000001?ooool6o`0000gooooo1?l00003ooooo`;o00001Oooool2o`00
00_ooooo0_l00007ooooo`Co00000_ooool2o`0000;ooooo0_l0000Eooooo`;o00000oooool3o`00
00Kooooo0_l00005ooooo`;o00006Oooool3o`0000?ooooo0_l000000ooooooo0000o`000005oooo
o`;o000000?oooooo`000?l000000_ooool2o`0000Gooooo0ol0000:ooooo`;o00000_ooool2o`00
00;ooooo0_l0000Eooooo`;o0000;_ooool001cooooo00?o0000ooooooooool0:?ooool2o`0000Go
oooo0_l00003ooooo`;o00004Oooool2o`000003ooooool0003o000001Gooooo0_l00002ooooo`;o
000000?oooooo`000?l000000_ooool2o`0000kooooo1?l00006ooooo`Co00005Oooool2o`0000Co
oooo1_l0000>ooooo`;o00003Oooool2o`0000_ooooo0_l000000ooooooo0000o`000008ooooo`Oo
00001Oooool2o`0000Gooooo0ol00002ooooo`;o00000_ooool2o`0000;ooooo0_l0000Eooooo`;o
0000;_ooool001cooooo00?o0000ooooooooool0=?ooool2o`0000_ooooo0_l00003ooooo`;o0000
6_ooool2o`000004ooooool0003o0000o`0000Cooooo0_l00008ooooo`;o00000_ooool4o`0000;o
oooo0ol00003ooooo`;o00006oooool2o`0000;ooooo1?l00009ooooo`;o00000oooool2o`0000go
oooo0_l00004ooooo`;o00001Oooool2o`0000Oooooo0_l00002ooooo`So00000_ooool3o`000003
ooooool0003o000000?ooooo1ol0001=ooooo`007?ooool00ol0003oooooooooo`0cooooo`Co0000
2_ooool2o`0000?ooooo0_l0000Jooooo`Ko00003Oooool3o`000004ooooool0003o0000o`0000Co
oooo0ol0000@ooooo`;o00001_ooool2o`0000Kooooo0_l00006ooooo`Co00001Oooool3o`0000?o
oooo0_l0000Booooo`;o00003_ooool2o`0000Kooooo1?l00002ooooo`?o000000?oooooo`000?l0
00000oooool8o`0004cooooo000Looooo`03o`000?oooooooooo03?ooooo1?l000000ooooooo0000
o`000009ooooo`;o00007_ooool3o`0000oooooo2Ol0000@ooooo`;o00000oooool2o`0000Kooooo
1?l00004ooooo`;o00001?ooool9o`0000?ooooo0_l00003ooooo`;o00005oooool2o`0000Wooooo
0_l0000Eooooo`;o00001?ooool2o`0000;ooooo0_l00018ooooo`007?ooool00ol0003ooooooooo
o`0_ooooo`;o00001_ooool3o`0000Wooooo0_l0000Wooooo`;o00000oooool>o`0000Oooooo0_l0
0004ooooo`Co00001?ooool3o`0000Kooooo0_l00004ooooo`;o00001?ooool2o`0000Cooooo1_l0
000=ooooo`;o00001?ooool2o`0000Wooooo0_l0000;ooooo`;o00001_ooool2o`0000;ooooo0_l0
0008ooooo`;o00001?ooool2o`000003ooooool0003o000000Sooooo0_l0000nooooo`007?ooool0
0ol0003oooooooooo`0Tooooo`;o00001oooool4o`000003ooooool0003o000000?ooooo0_l0000B
ooooo`;o00000_ooool2o`00013ooooo0ol00008ooooo`;o00000oooool>o`0000Oooooo0_l00004
ooooo`;o00001_ooool8o`0000Kooooo0ol00004ooooo`;o00001_ooool6o`0000_ooooo0_l00004
ooooo`;o00005Oooool3o`000003ooooool0003o000000?ooooo0_l00002ooooo`Co00001_ooool2
o`0000Cooooo0_l0000;ooooo`;o000000?oooooo`000?l00000>oooool001cooooo00?o0000oooo
ooooool09?ooool2o`0000Oooooo0_l00003ooooo`?o00004_ooool2o`000004ooooool0003o0000
o`0000;ooooo0_l00005ooooo`Co00001oooool3o`0000Sooooo0ol00002ooooo`co00000oooool3
o`0001Cooooo1Ol00006ooooo`;o00004Oooool3o`0000;ooooo1?l00005ooooo`;o00001Oooool2
o`0000kooooo0_l00002ooooo`?o00000_ooool2o`000004ooooool0003o0000o`0000Gooooo0ol0
000?ooooo`?o00002Oooool2o`0003_ooooo000Looooo`03o`000?oooooooooo02oooooo0_l00002
ooooo`;o00004?ooool4o`000003ooooool0003o000000?ooooo0_l00003ooooo`Ko00001?ooool2
o`0000;ooooo0_l00004ooooo`?o000000?oooooo`000?l000003ol00003ooooo`?o00007_ooool2
o`0000gooooo0_l00004ooooo`;o000000?oooooo`000?l000001Ol00003ooooo`?o00001?ooool2
o`0000Gooooo0ol00004ooooo`Co00000_ooool2o`0000?ooooo0_l000001?oooooo0000o`000?l0
0005ooooo`?o00001_ooool2o`0000Kooooo1?l00002ooooo`Co00003_ooool2o`00033ooooo000L
ooooo`03o`000?oooooooooo02gooooo1Ol0000Cooooo`;o00001oooool3o`000003ooooool0003o
000000;o000000?oooooo`000?l000000oooool4o`0000;ooooo1?l00002ooooo`Go000000?ooooo
o`000?l000004?l000000ooooooo0000o`00000Nooooo`;o00003Oooool4o`0000Gooooo0_l00003
ooooo`;o00001?ooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool3o`0000Cooooo0_l00009
ooooo`;o000000?oooooo`000?l000003oooool2o`0000Kooooo0ol00003ooooo`Go00000oooool2
o`0000Sooooo0_l0000`ooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o000000?oooooo`00
0?l000004oooool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`Co000000Coooooo`00
0?l0003ooooo2?l00002ooooo`;o00001?oooolIo`0000Sooooo0_l00004ooooo`;o00000oooool2
o`0001[ooooo0_l00009ooooo`Co00001oooool2o`0000?ooooo0_l0000Gooooo`;o00003?ooool2
o`0000[ooooo0_l00004ooooo`Co00000oooool2o`0003[ooooo000Looooo`;o0000<?ooool2o`00
00kooooo0_l00004ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Cooooo0_l00004oooo
o`So00001ooooolJo`000003ooooool0003o000000?ooooo1?l00002ooooo`Co00000_ooool3o`00
01oooooo0_l000000ooooooo0000o`000005o`0000?ooooo0_l0000=ooooo`;o00005_ooool2o`00
00Oooooo0ol0000@ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0;oooool2o`0000ko
oooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0ol00002ooooo`;o00003?ooool2o`00
00;ooooo0_l00007oooooago00000oooool2o`0000Cooooo2?l0000Aooooo`;o00003Oooool2o`00
0004ooooool0003o0000o`0000Oooooo0_l0000:ooooo`;o000000?oooooo`000?l000003Oooool3
o`000003ooooool0003o000000?ooooo0_l00007ooooo`?o00001?ooool2o`0000[ooooo0_l00004
ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0;_ooool2o`0001;ooooo0_l00005oooo
o`Ko000000Coooooo`000?l0003ooooo0_l00007ooooo`;o00002Oooool2o`000003ooooool0003o
000001Go00000_ooool2o`0000[ooooo0_l00002ooooo`;o00001?ooool2o`0000gooooo0_l00000
0ooooooo0000o`000002ooooo`;o00000oooool2o`0000Cooooo0_l00008ooooo`;o00002_ooool2
o`00013ooooo0ol000000ooooooo0000o`000002ooooo`;o00002?ooool2o`0000Cooooo0ol00000
0ooooooo0000o`00000=ooooo`;o00001_ooool2o`0003;ooooo000Looooo`03o`000?oooooooooo
02kooooo1?l000000ooooooo0000o`000009ooooo`;o00003?ooool6o`000003ooooool0003o0000
01;ooooo0_l000000ooooooo0000o`00000Go`0000[ooooo0_l00002ooooo`;o00001_ooool2o`00
00;ooooo1?l0000:ooooo`?o000000?oooooo`000?l000000oooool2o`0000kooooo0_l00002oooo
o`;o000000?oooooo`000?l000000_ooool3o`00013ooooo0_l000001?oooooo0000o`000?l00002
ooooo`;o00003_ooool2o`0000;ooooo0_l0000?ooooo`;o00001?ooool2o`0003;ooooo000Loooo
o`03o`000?oooooooooo02oooooo0ol000000ooooooo0000o`000008ooooo`?o00003_ooool4o`00
01Gooooo0_l000000ooooooo0000o`00000Jo`0000Oooooo0_l00002ooooo`;o00001Oooool2o`00
00;ooooo1Ol0000:ooooo`Go00000_ooool2o`0000;ooooo0_l0000?ooooo`_o00004oooool3o`00
00Gooooo1?l00002ooooo`;o00003oooool2o`000003ooooool0003o000000Kooooo0_l0000hoooo
o`007?ooool00ol0003oooooooooo`0cooooo`;o00002?ooool2o`0001Wooooo0_l0000;ooooo`Co
00000_oooolKo`0000kooooo0ol000000ooooooo0000o`000007o`0000Wooooo1_l00002ooooo`;o
000000?oooooo`000?l000000ol00007ooooo`;o000000Coooooo`000?l0003ooooo3_l00004oooo
o`;o00003_ooool2o`0000;ooooo1?l00002ooooo`;o00002Oooool2o`0000Cooooo1Ol00010oooo
o`007?ooool00ol0003oooooooooo`0cooooo`;o00003?ooool2o`0000;ooooo0ol0000@ooooo`;o
00002oooool2o`0000?ooooo3Ol000000ooooooo0000o`00000;o`0000oooooo0ol00003ooooo`?o
000000Coooooo`000?l0003o00002Oooool4o`0000;ooooo1ol000000ooooooo0000o`000006oooo
o`?o000000Goooooo`000?l0003o0000ooooo`0=o`0000?ooooo0ol0000;ooooo`;o000000?ooooo
o`000?l000000_ooool3o`0000kooooo0_l00005ooooo`;o00001Oooool2o`0003_ooooo000Loooo
o`03o`000?oooooooooo037ooooo0_l0000>ooooo`;o00000_ooool3o`0001Gooooo0_l00002oooo
o`;o00000_ooool2o`000003ooooool0003o000001_o00001oooool2o`0001cooooo0_l00004oooo
o`;o00000_ooool2o`0000;ooooo0_l00006ooooo`;o00000oooool6o`0000;ooooo2_l000000ooo
oooo0000o`00000<ooooo`;o00001Oooool2o`0001Oooooo0ol00003ooooo`;o0000>oooool001co
oooo00?o0000ooooooooool0:oooool2o`000004ooooool0003o0000ooooo`;o00001?ooool2o`00
00[ooooo0ol00004ooooo`;o00004Oooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`00
0?l000006ol00007ooooo`;o00001?ooool2o`0000Kooooo0_l00007ooooo`;o00004_ooool4o`00
00_ooooo1?l000001?oooooo0000o`000?ooool;o`0000?ooooo0_l0000?ooooo`;o00002Oooool2
o`000003ooooool0003o000000Wooooo1?l0000oooooo`007?ooool00ol0003oooooooooo`0Zoooo
o`?o000000?oooooo`000?l000001oooool2o`0000[ooooo0ol00004ooooo`;o00000_ooool2o`00
01[ooooo6ol000000ooooooo0000o`00000:ooooo`;o00000oooool2o`000003ooooool0003o0000
00Oooooo0_l00003ooooo`;o00002Oooool8o`0000_ooooo5?l00002ooooo`?o00000oooool2o`00
00Wooooo0_l00009ooooo`;o000000?oooooo`000?l000002oooool2o`0003oooooo000Looooo`03
o`000?oooooooooo02[ooooo0_l00003ooooo`;o00000_ooool2o`0000oooooo0_l00008ooooo`Go
00000_ooool2o`0001Cooooo7ol0000=ooooo`;o00003_ooool5o`0000Oooooo1Ol0000>oooooaCo
00000_ooool3o`0000?ooooo0_l000000ooooooo0000o`00000=ooooo`Co00001Oooool2o`0000co
oooo0_l0000Dooooo`;o00009_ooool001cooooo00?o0000ooooooooool0;?ooool2o`000005oooo
ool0003o0000o`000?ooool00_l00003ooooo`;o00002_ooool2o`0000Gooooo0_l00002ooooo`Co
00000_ooool2o`0000Wooooo0_l00009ooooo`;o000000?oooooo`000?l000006_l00005ooooo`;o
00000oooool3o`0000cooooo0_l00002ooooo`Go00002Oooool2o`0000;ooooo0_l00008ooooo`;o
000000?oooooo`000?l000004_l00002ooooo`;o00001_ooool3o`0000gooooo1Ol00004ooooo`;o
00001Oooool2o`0000Gooooo0_l0000Dooooo`;o00009_ooool001cooooo00?o0000ooooooooool0
:oooool3o`0000;ooooo0_l00006ooooo`;o00001oooool4o`0000Kooooo0_l0000Cooooo`;o0000
3?oooolIo`000003ooooool0003o000000Cooooo0ol00003ooooo`?o00003?ooool2o`00013ooooo
0_l00002ooooo`;o00001?ooool2o`0000;ooooo4_l000000ooooooo0000o`000004o`0000Sooooo
0_l00009ooooo`;o00001_ooool2o`0000?ooooo0_l00006ooooo`;o0000@oooool001cooooo00?o
0000ooooooooool0:oooool2o`0001Cooooo1?l0000;ooooo`;o00002Oooool4o`0000;ooooo0_l0
0005ooooo`;o00001?oooolHo`0000;ooooo0_l00004ooooo`;o00006_ooool2o`0000?ooooo0_l0
00001?oooooo0000o`000?ooool2o`000003ooooool0003o000000;o00000oooool2o`0000;ooooo
6Ol00009ooooo`;o00000oooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o0000
1?ooool2o`0004_ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05
onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0[ooooo`;o00004_ooool4o`00
00Cooooo1?l00005ooooo`;o00001oooool6o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`00
0003ooooool0003o000000;o000000?oooooo`000?l000003_l00005ooooo`;o00007oooool2o`00
00?ooooo0_l000000ooooooo0000o`000004ooooo`Co00000oooool2o`0000;ooooo3_l000000ooo
oooo0000o`000005o`0000Wooooo0_l000000ooooooo0000o`000003ooooo`;o00000oooool2o`00
0003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000008ooooo`?o00001?ooool2o`00
03gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOo
oooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0[ooooo`;o000000?oooooo`000?l000003ooo
ool2o`0000Kooooo1?l00004ooooo`;o00001oooool3o`00017ooooo0_l000000ooooooo0000o`00
000Do`0000Cooooo1_l0000Sooooo`;o00002ooooolDo`000003ooooool0003o000000Co00002?oo
ool2o`0000Kooooo0_l00003ooooo`;o00001Oooool2o`000003ooooool0003o000000Sooooo0ol0
0004ooooo`;o0000?Oooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0:oooool2o`000004ooooool0
003o0000o`00013ooooo0_l00003ooooo`;o00001Oooool4o`0000Oooooo1?l0000Dooooo`;o0000
00?oooooo`000?l000003?l000001?oooooo0000o`000?l00006ooooo`Co00003?ooool4o`0000Wo
oooo0_l00008ooooo`;o00002ooooolNo`0000;ooooo0_l0000Tooooo`;o0000@_ooool00003oooo
ool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Ko
oooo0ol0000[ooooo`;o00000_ooool2o`00013ooooo0_l00003ooooo`;o00001Oooool2o`0000_o
oooo0_l00002ooooo`;o00000oooool2o`00013ooooo4?l0000=ooooo`;o00001oooool4o`0000Wo
oooo0_l00009ooooo`;o00001?ooool2o`0000Oooooo6ol00002ooooo`Go00004?ooool2o`000003
ooooool0003o000000cooooo0_l00012ooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooo
ooooo`09ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0dooooo`;o
00002oooool2o`0000[ooooo0ol00002ooooo`;o00002_ooool2o`0000?ooooo0ol00009ooooo`;o
00001Oooool4o`0000;ooooo2Ol00005ooooo`;o00001_ooool2o`0000;ooooo0_l0000Aooooo`;o
00002?ooool3o`0000?ooooo1?l00005oooooa_o00001?ooool3o`0000Cooooo0_l0000:ooooo`;o
000000?oooooo`000?l000002_ooool2o`0004Cooooo00000ooooooo410@ooooo`02ooooo`03oa0@
4?oooooooooo00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`0dooooo`;o0000
2oooool2o`0000Wooooo1?l00002ooooo`;o00004?ooool3o`0000Sooooo0_l00007ooooo`;o0000
0_ooool2o`0000Gooooo0_l00005ooooo`Co000000?oooooo`000?l000001Oooool2o`0000Sooooo
0_l000000ooooooo0000o`000004ooooo`Co00001oooool2o`0000Gooooo0_l00003ooooo`;o0000
0ooooolGo`0000?ooooo0_l00007ooooo`;o00004?ooool2o`0000Oooooo0_l00014ooooo`0000Ko
ooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000oooooooo
ool0;?ooool2o`0000Wooooo0_l0000Cooooo`;o00005oooool2o`0000Cooooo0_l00009ooooo`Go
00001?ooool2o`0000Oooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`000003
ooooool0003o000000Oooooo1_l00005ooooo`?o00002_ooool2o`000003ooooool0003o000000Co
oooo0_l00004ooooo`Wo000000?oooooo`000?l000002Ol00004ooooo`;o00006Oooool2o`0004go
oooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool0
0ol0003oooooooooo`0Yooooo`;o000000?oooooo`000?l000002Oooool3o`00033ooooo0ol00009
ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Oooooo0_l00009ooooo`;o00002_ooool4
o`0000Cooooo1Ol00002ooooo`Co00001Oooool2o`000003ooooool0003o000000Oooooo0ol00000
0ooooooo0000o`00000Bo`0000Cooooo0_l00002ooooo`Co00004oooool3o`0000Wooooo0ol00010
ooooo`007?ooool00ol0003oooooooooo`0Yooooo`;o00000_ooool2o`0000Sooooo1Ol0000Boooo
o`;o00001_ooool2o`0000_ooooo0_l00005ooooo`;o00004Oooool2o`0000Gooooo0_l0000:oooo
o`;o00003_ooool5o`000003ooooool0003o000000Go000000?oooooo`000?l000000ol0000@oooo
o`?o00000_oooolEo`0000;ooooo0_l00002ooooo`Co00003Oooool2o`0000Cooooo0ol00003oooo
o`;o00001?ooool3o`00043ooooo000Looooo`03o`000?oooooooooo02Sooooo0_l00003ooooo`;o
00002oooool2o`000003ooooool0003o000000gooooo1?l00006ooooo`;o00000_ooool5o`0000Co
oooo0_l00006ooooo`;o00000_ooool2o`0000cooooo0_l00004ooooo`?o00002Oooool3o`0000So
oooo6Ol0000Gooooo`go000000?oooooo`000?l000001?l00002ooooo`;o00003Oooool2o`0000;o
oooo0ol0000:ooooo`;o000000?oooooo`000?l00000A?ooool001cooooo00?o0000ooooooooool0
:?ooool2o`0000Wooooo0_l00008ooooo`;o00000_ooool2o`000004ooooool0003o0000o`0000Go
oooo0_l0000<ooooo`Go00001oooool2o`0000?ooooo0_l00002ooooo`;o00004_ooool2o`0000Co
oooo0_l00004ooooo`;o00002OoooolHo`0000Kooooo0_l0000?ooooo`So000000?oooooo`000?l0
00000ol00002ooooo`Go00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000005ooooo`;o
00000_ooool2o`0000kooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o0000
00?oooooo`000?l000002Oooool2o`000004ooooool0003o0000o`0001?ooooo1?l000001?oooooo
0000o`000?l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000005
ooooo`?o00004?ooool2o`0000cooooo6ol00006ooooo`;o00002oooool2o`0000;ooooo0_l00003
ooooo`;o00001?ooool2o`0000;ooooo0ol00002ooooo`;o000000?oooooo`000?l000000oooool2
o`000003ooooool0003o000001[ooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`0aoooo
o`;o00000oooool2o`0000?ooooo0_l00004ooooo`;o00001oooool2o`0000kooooo1?l000001?oo
oooo0000o`000?l00002ooooo`Oo000000Coooooo`000?l0003ooooo0_l00004ooooo`Co00001ooo
ool2o`0000Gooooo0_l0000>oooooako00003oooool3o`0000gooooo1_l00003ooooo`;o00005_oo
ool2o`0000gooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`0aooooo`?o00001oooool4
o`0000Kooooo0ol00002ooooo`;o00004Oooool2o`000004ooooool0003o0000ooooo`?o00000_oo
ool4o`0000Wooooo0_l00008ooooo`?o00001Oooool2o`0000;ooooo0_l00008ooooo`;o000000?o
ooooo`000?l000006ol00004ooooo`;o00001?ooool2o`0000?ooooo0ol00004ooooo`;o00002Ooo
ool2o`000003ooooool0003o000000Wooooo0_l0000?ooooo`;o00003?ooool2o`0000_ooooo0_l0
000gooooo`007?ooool00ol0003oooooooooo`0booooo`;o00000_ooool2o`0000?ooooo1ol00003
ooooo`?o00004Oooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool3o`0000Cooooo1?l0
0008ooooo`;o000000?oooooo`000?l000001?ooool3o`0000Wooooo0_l00008oooooako000000?o
ooooo`000?l000000oooool2o`000004ooooool0003o0000ooooo`;o00002_ooool2o`0000;ooooo
0_l00007ooooo`?o00002Oooool2o`0000oooooo0_l00005ooooo`;o00001Oooool2o`0000_ooooo
0_l0000gooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00001_ooool4o`0000Wooooo0_l0
0008ooooo`;o00000_ooool4o`0000Cooooo1?l00007ooooo`;o00001oooool3o`000003ooooool0
003o000000Sooooo0_l00005ooooo`;o00002ooooolOo`0000Kooooo0_l0000<ooooo`Oo00001ooo
ool2o`0000kooooo0_l00007ooooo`Ko00001Oooool2o`0000?ooooo0_l00016ooooo`007?ooool0
0ol0003oooooooooo`0mooooo`;o00000oooool2o`0000Oooooo0_l00008ooooo`;o00001?ooool2
o`0000;ooooo1?l0000Booooo`;o00003?ooool2o`0000Gooooo0_l00009ooooob3o00003_ooool2
o`0000Gooooo0_l000001?oooooo0000o`000?l00008ooooo`;o00001oooool2o`0000?ooooo1?l0
0007ooooo`Ko00000_ooool2o`0000Kooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`0m
ooooo`;o00000oooool2o`0000gooooo0_l0000<ooooo`;o00006oooool2o`0000gooooo0_l00002
ooooo`;o00001?ooool8o`000003ooooool0003o000001Go00002?ooool2o`0000;ooooo1?l00009
ooooo`;o00001?ooool6o`0000Oooooo0_l00003ooooo`;o00001Oooool2o`0000Kooooo0_l00002
ooooo`;o00003_ooool4o`0003cooooo000Looooo`03o`000?oooooooooo03Kooooo0_l00005oooo
o`?o00001?ooool3o`0000[ooooo1?l0000Oooooo`;o00001_ooool2o`000003ooooool0003o0000
00Sooooo1?l00002ooooo`;o00001?ooool8o`000003ooooool0003o000001Co00001oooool5o`00
0003ooooool0003o000000[ooooo0_l00004ooooo`Go00001Oooool2o`0000;ooooo0_l00007oooo
o`Go00004oooool2o`0000Gooooo1?l0000looooo`007?ooool2o`0003Oooooo0_l00006ooooo`;o
00001?ooool3o`0000cooooo1_l0000:ooooo`;o00003oooool3o`000003ooooool0003o000000Go
oooo0ol00007ooooo`;o00001?ooool2o`0000;ooooo7ol000000ooooooo0000o`000006ooooo`;o
000000?oooooo`000?l000003Oooool2o`0000Cooooo0_l00008ooooo`;o00000_ooool2o`0000Oo
oooo1_l0000=ooooo`;o00000oooool2o`0004Gooooo000Looooo`03o`000?oooooooooo04_ooooo
0_l00008ooooo`Ko00002?ooool3o`0000oooooo0_l000000ooooooo0000o`000006ooooo`Co0000
3oooool4o`000003ooooool0003o000000;o000000?oooooo`000?l000005_l0000>ooooo`?o0000
4oooool2o`00013ooooo1Ol0000=ooooo`?o00000oooool2o`0004Cooooo000Looooo`03o`000?oo
oooooooo04_ooooo0_l0000;ooooo`?o00002Oooool5o`0001;ooooo0_l00005ooooo`;o00003ooo
ool>o`000003ooooool0003o000000go000000?oooooo`000?l000003oooool3o`0001?ooooo2?l0
0008ooooo`Go00003oooool3o`0000?ooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0k
ooooo`;o00001?ooool4o`00017ooooo0_l000000ooooooo0000o`00000:ooooo`Co00004_ooool3
o`0001Gooooo3_l000000ooooooo0000o`000007o`0000;ooooo2?l00006ooooo`;o00001oooool2
o`0001Gooooo1_l00008ooooo`;o00001_ooool2o`0000Cooooo0_l0001@ooooo`007?ooool00ol0
003oooooooooo`0kooooo`;o00001?ooool4o`0000Oooooo0ol00007ooooo`;o000000?oooooo`00
0?l000002_ooool5o`0001;ooooo0_l0000EoooooaWo000000?oooooo`000?l000001_l00004oooo
o`Co00001oooool2o`0000_ooooo0_l00008ooooo`;o00003?ooool2o`0000Cooooo1?l00004oooo
o`Co00000oooool2o`0004Wooooo000Looooo`03o`000?oooooooooo04cooooo0ol000001?oooooo
0000o`000?l0000Cooooo`Co00000oooool2o`0000Kooooo0_l000000ooooooo0000o`000002o`00
01Oooooo8?l00006ooooo`;o00001oooool2o`0000gooooo0_l00004ooooo`Ko00002_ooool2o`00
00?ooooo0_l000000ooooooo0000o`000002ooooo`;o00001?ooool2o`0000?ooooo0_l00019oooo
o`007?ooool00ol0003oooooooooo`0looooo`;o000000?oooooo`000?l000003oooool3o`00017o
oooo1Ol000000ooooooo0000o`000003o`0000Kooooo0_l000000ooooooo0000o`000002o`0001Co
oooo0_l000001?oooooo0000o`000?oooolLo`0000Gooooo0_l00009ooooo`;o00002?ooool2o`00
00Kooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00002ooooo`?o000000?oooooo`00
0?l000001ol00005ooooo`;o00000oooool2o`0004oooooo000Looooo`03o`000?oooooooooo03co
oooo0_l000000ooooooo0000o`000003ooooo`?o00004Oooool2o`0000[ooooo0_l000001?oooooo
0000o`000?ooool3o`0000[ooooo0_l0000Aooooo`;o00001?ooool2o`000003ooooool0003o0000
01co00001_ooool2o`0000Wooooo0_l00008ooooo`;o00001_ooool2o`0000Oooooo0_l00002oooo
o`?o000000?oooooo`000?l000000_ooool3o`0000cooooo0_l0001?ooooo`007?ooool00ol0003o
ooooooooo`14ooooo`?o00001_ooool2o`0000Gooooo0_l00002ooooo`;o00000oooool2o`0000Co
oooo0_l00007ooooo`;o00002Oooool3o`00013ooooo0_l00008oooooako00004?ooool2o`0000co
oooo0_l00005ooooo`?o00002?ooool5o`0000?ooooo0_l00006ooooo`?o0000E?ooool001cooooo
00?o0000ooooooooool0AOooool2o`0000Kooooo0_l00005ooooo`Co00001Oooool2o`0000Cooooo
1?l00002ooooo`Go00002_ooool2o`0001Oooooo0_l000000ooooooo0000o`00000Lo`0001kooooo
0_l00005ooooo`?o00002Oooool2o`0000gooooo0ol0001Dooooo`007?ooool00ol0003ooooooooo
o`1Fooooo`;o00000_ooool2o`0000Wooooo0_l00002ooooo`Oo00003oooool7o`0000_ooooo3Ol0
00000ooooooo0000o`00000>o`000003ooooool0003o000000cooooo0_l00009ooooo`;o00009_oo
ool2o`0005Kooooo000Looooo`03o`000?oooooooooo04?ooooo0_l00002ooooo`;o00001?ooool2
o`0000_ooooo0_l00008ooooo`Co00000_ooool6o`0000cooooo0_l000000ooooooo0000o`000005
o`0000;ooooo0_l00008ooooo`Co00000ooooolFo`000003ooooool0003o000000cooooo0_l00009
ooooo`;o00002?ooool2o`0000_ooooo1Ol0000<ooooo`;o0000E_ooool001cooooo00?o0000oooo
ooooool0=?ooool2o`0000gooooo0_l00002ooooo`;o00001?ooool2o`0000gooooo0_l00006oooo
o`Co00000_ooool3o`000003ooooool0003o000000;o00002_ooool2o`0000Cooooo0_l00004oooo
o`;o00002?ooool4o`0000Cooooo4ol0000Vooooo`;o00000_ooool2o`0000Oooooo1Ol000000ooo
oooo0000o`00001Qooooo`007?ooool00ol0003oooooooooo`0dooooo`;o00005_ooool2o`0000ko
oooo0_l0000<ooooo`?o000000?oooooo`000?l000000_l0000Dooooo`;o00000oooool2o`0000Ko
oooo1?l00003ooooo`;o000000?oooooo`000?l000001ol0000:ooooo`;o00005?ooool2o`0000oo
oooo0_l00008ooooo`;o00000oooool2o`0000;ooooo0_l00004ooooo`;o00003?ooool2o`0004Wo
oooo000Looooo`03o`000?oooooooooo04cooooo0_l00002ooooo`;o00002oooool2o`0000cooooo
0_l0000Iooooo`;o000000?oooooo`000?l000000ol00003ooooo`Ko00002?ooool6o`0000_ooooo
0_l0000>ooooo`;o00001?ooool2o`0001Sooooo0ol00007ooooo`;o000000?oooooo`000?l00000
0ol0000<ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0@_ooool2o`0000cooooo0_l0
0007ooooo`;o00000_ooool2o`0000cooooo0ol000000ooooooo0000o`00000Hooooo`;o000000?o
ooooo`000?l000000oooool2o`0000;ooooo0_l00008ooooo`;o00001_ooool4o`0001Gooooo0_l0
000Nooooo`;o00001_ooool2o`0000?ooooo0ol0001Iooooo`007?ooool2o`0004?ooooo0_l0000E
ooooo`;o00001_ooool2o`0000Wooooo1Ol000000ooooooo0000o`00000<ooooo`;o000000Cooooo
o`000?l0003ooooo0_l0000@ooooo`;o000000?oooooo`000?l000002_ooool4o`0001Oooooo0_l0
000Tooooo`;o00003Oooool2o`00053ooooo000Looooo`03o`000?oooooooooo05Kooooo0_l00009
ooooo`;o00002_ooool3o`0000;ooooo0_l0000<ooooo`;o000000Coooooo`000?l0003ooooo0_l0
000>ooooo`Co000000?oooooo`000?l000001oooool2o`0000Cooooo0ol00009ooooo`;o00002_oo
ool2o`0001cooooo0_l00002ooooo`Co000000?oooooo`000?l000001?l00008ooooo`;o0000D?oo
ool001cooooo00?o0000ooooooooool0DOooool2o`0000?ooooo0_l00006ooooo`;o00004?ooool2
o`0001;ooooo0_l0000@ooooo`;o00000_ooool2o`0000Sooooo0_l00004ooooo`?o00002Oooool2
o`0002Kooooo1?l00002ooooo`Co000000?oooooo`000?l000001Ol00005ooooo`;o0000D_ooool0
01cooooo00?o0000ooooooooool0DOooool2o`0000_ooooo0_l00002ooooo`Co00000oooool2o`00
00Gooooo0_l0000Booooo`;o00005?ooool2o`0000[ooooo0_l0000Yooooo`;o000000Coooooo`00
0?l0003ooooo0_l00005ooooo`Co00003?ooool2o`0000Gooooo0_l00007ooooo`;o0000BOooool0
01cooooo00?o0000ooooooooool0F?ooool2o`0000Sooooo1Ol00002ooooo`;o00001Oooool4o`00
0003ooooool0003o000001Wooooo0_l0000=ooooo`;o00001Oooool4o`0000Gooooo0_l0000Poooo
o`;o000000Coooooo`000?l0003ooooo0_l00007ooooo`;o00007?ooool2o`0004Wooooo000Loooo
o`03o`000?oooooooooo05;ooooo0_l00004ooooo`;o00002oooool2o`0000Wooooo1?l000001?oo
oooo0000o`000?ooool2o`0000Wooooo1?l00006ooooo`;o000000Coooooo`000?l0003ooooo0_l0
0003ooooo`;o00001Oooool3o`0000;ooooo0_l00002ooooo`;o00001Oooool2o`0000?ooooo0_l0
0006ooooo`;o00008_ooool3o`0001Wooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`1>
ooooo`;o00000_ooool2o`00013ooooo0_l00004ooooo`;o00001_ooool4o`0000;ooooo0_l00003
ooooo`;o00001?ooool4o`0000Kooooo0_l00003ooooo`Co00000_ooool2o`0000Kooooo0_l00002
ooooo`;o00003Oooool3o`0000Kooooo0_l00006ooooo`;o00006oooool2o`0000Kooooo1?l0000?
ooooo`Co0000BOooool001cooooo00?o0000ooooooooool0C_ooool2o`000003ooooool0003o0000
017ooooo0_l00004ooooo`?o00001Oooool4o`0000Kooooo0ol0000>ooooo`;o00000oooool4o`00
00Sooooo0_l0000Cooooo`;o000000?oooooo`000?l000001?ooool2o`0000Kooooo0_l00007oooo
o`;o00002?ooool2o`0000;ooooo0_l00003ooooo`;o00001oooool4o`00017ooooo0_l00019oooo
o`007?ooool00ol0003oooooooooo`1Aooooo`;o00003_ooool2o`0000Sooooo0ol00003ooooo`;o
000000?oooooo`000?l000000ol000000ooooooo0000o`000002o`0000oooooo0_l00005ooooo`;o
00002?ooool2o`0001Gooooo0ol0000;ooooo`?o00001oooool2o`0000;ooooo0_l000000ooooooo
0000o`000003o`0000;ooooo0_l00003ooooo`;o00001?ooool2o`0000;ooooo0_l0001Mooooo`00
7?ooool00ol0003oooooooooo`1@ooooo`?o00001Oooool2o`0000Oooooo0_l00007ooooo`Co0000
0oooool2o`000003ooooool0003o000000?o000000?oooooo`000?l000006?ooool2o`0001[ooooo
0_l00002ooooo`Go00002_ooool2o`0000Sooooo0_l00002ooooo`;o000000?oooooo`000?l00000
0_l0000>ooooo`;o0000HOooool001cooooo00?o0000ooooooooool0D?ooool4o`0000Cooooo0_l0
0004ooooo`;o00001Oooool2o`0000?ooooo1?l00002ooooo`?o000000?oooooo`000?l000000ol0
0003ooooo`;o00002oooool2o`0000Cooooo0_l00006ooooo`Co00002?ooool3o`0000Oooooo0_l0
00000ooooooo0000o`000007o`000003ooooool0003o000001Gooooo0_l00006ooooo`?o00001_oo
ool2o`000003ooooool0003o000000gooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`1B
ooooo`;o00002_ooool2o`0000Gooooo0_l00005ooooo`;o00000_ooool2o`0000Cooooo1Ol00000
0ooooooo0000o`00000;ooooo`;o00001?ooool2o`0000Kooooo1?l00008ooooo`Co00000_ooool2
o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo0_l0000Eooooo`;o000000Cooooo
o`000?l0003o00000_ooool4o`0000Gooooo0_l000000ooooooo0000o`00000=ooooo`;o0000Dooo
ool001cooooo00?o0000ooooooooool0F?ooool2o`0000Cooooo0_l00009ooooo`;o00003?ooool4
o`0000kooooo0_l00005ooooo`;o00002oooool2o`0000Kooooo0_l000001?oooooo0000o`000?l0
0002ooooo`Co00006_ooool2o`0000;ooooo0_l00003ooooo`?o00001?ooool2o`0000gooooo0_l0
001Mooooo`007?ooool00ol0003oooooooooo`1Hooooo`Go000000?oooooo`000?l000002Oooool4
o`0000;ooooo0_l00007ooooo`?o000000?oooooo`000?l000002oooool2o`0000Gooooo1?l00009
ooooo`;o00002Oooool4o`0000?ooooo0_l000000ooooooo0000o`000002o`0000Wooooo0_l00008
ooooo`Co00000_ooool2o`0000;ooooo1?l00002ooooo`Co00003Oooool2o`00017ooooo0_l0001:
ooooo`007?ooool00ol0003oooooooooo`0looooo`;o00007?ooool3o`0000kooooo0_l00002oooo
o`;o00000oooool6o`0000;ooooo0_l00003ooooo`;o00002Oooool2o`0000Cooooo0_l000000ooo
oooo0000o`00000Aooooo`Co00000oooool2o`000003ooooool0003o000000Co00001oooool2o`00
00Sooooo1?l00006ooooo`;o00001?ooool4o`00023ooooo0_l0001:ooooo`007?ooool00ol0003o
ooooooooo`0looooo`;o00006?ooool2o`0000;ooooo0_l00003ooooo`;o00002oooool2o`0000Ko
oooo1_l00007ooooo`;o00002Oooool3o`000003ooooool0003o000000;o000000?oooooo`000?l0
00007oooool2o`0000?ooooo0_l00006ooooo`;o00000oooool2o`000003ooooool0003o000000Co
oooo0_l00003ooooo`;o00000_ooool2o`0000Cooooo0_l0001Wooooo`007?ooool2o`0005Oooooo
0_l00002ooooo`?o00000_ooool4o`000003ooooool0003o000000Kooooo0_l00007ooooo`Go0000
2Oooool2o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000000ol0000Fooooo`?o0000
3Oooool2o`0000Cooooo2Ol00007ooooo`Co000000?oooooo`000?l000001?l00004ooooo`;o0000
Ioooool001cooooo00?o0000ooooooooool0Foooool2o`0000Cooooo0_l000000ooooooo0000o`00
0005ooooo`;o000000?oooooo`000?l000001oooool3o`0000Wooooo0_l00003ooooo`;o00002?oo
ool3o`0001Kooooo0ol00009ooooo`;o00000_ooool2o`0000Cooooo0ol000000ooooooo0000o`00
0002o`0000[ooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l0001Zooooo`007?ooool0
0ol0003oooooooooo`1Kooooo`;o000000?oooooo`000?l000002oooool2o`000003ooooool0003o
000000Sooooo0ol0000Iooooo`;o00001?ooool2o`0001?ooooo0_l00002ooooo`;o00000_ooool2
o`0000;ooooo0_l00002ooooo`;o00000oooool3o`0000;ooooo0_l0000;ooooo`?o00001?ooool2
o`000003ooooool0003o000006Oooooo000Looooo`03o`000?oooooooooo05kooooo0_l00009oooo
o`;o00002oooool5o`0000Wooooo0_l00002ooooo`?o00001oooool4o`0000Cooooo0_l0000Coooo
o`;o00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool3o`00
00;ooooo0_l00004ooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o0000
00Gooooo0_l0001Wooooo`007?ooool00ol0003oooooooooo`1Oooooo`;o00000oooool2o`0000?o
oooo0_l00002ooooo`;o00001oooool2o`0000Cooooo0_l00006ooooo`;o00000_ooool3o`0000Oo
oooo0_l00008ooooo`;o00004_ooool2o`0000Kooooo0_l0000Eooooo`Go00001?ooool3o`0000go
oooo0_l0001Oooooo`007?ooool00ol0003oooooooooo`1Jooooo`;o00000oooool2o`0000?ooooo
0_l00007ooooo`;o00003Oooool4o`0000Sooooo0_l00004ooooo`;o00001_ooool2o`0000Cooooo
0_l00005ooooo`;o00002oooool2o`0001Sooooo0ol000000ooooooo0000o`000003o`0000Gooooo
0_l0000=ooooo`?o00000oooool2o`0005[ooooo000Looooo`03o`000?oooooooooo05[ooooo0_l0
0005ooooo`;o00000_ooool2o`0001Oooooo0_l00008ooooo`;o00001?ooool2o`0000Gooooo0ol0
0004ooooo`;o00001Oooool2o`0002Cooooo1?l000000ooooooo0000o`000004o`0000kooooo0_l0
0003ooooo`;o00001?ooool2o`0005[ooooo000Looooo`03o`000?oooooooooo067ooooo0_l00000
1?oooooo0000o`000?l0000@ooooo`;o00003?ooool4o`0000Kooooo0_l00004ooooo`;o00001Ooo
ool2o`0001Cooooo0ol000000ooooooo0000o`00000Aooooo`?o00000_ooool6o`0000kooooo0_l0
001Uooooo`007?ooool00ol0003oooooooooo`1Qooooo`;o000000?oooooo`000?l000001Oooool3
o`0000Wooooo0_l00005ooooo`;o00001Oooool4o`0000?ooooo0_l000001?oooooo0000o`000?oo
ool3o`0000cooooo0_l0000=ooooo`Go000000?oooooo`000?l000000_l0000@ooooo`;o00003ooo
ool2o`000003ooooool0003o000000Kooooo0ol0001Pooooo`007?ooool00ol0003oooooooooo`1T
ooooo`;o00001Oooool3o`00013ooooo0_l0000<ooooo`;o00000oooool4o`0000[ooooo1?l0000=
ooooo`;o00001?ooool4o`0000;ooooo0ol000000ooooooo0000o`00000Iooooo`;o000000?ooooo
o`000?l000001?ooool5o`00063ooooo000Looooo`03o`000?oooooooooo06Cooooo0_l0000Hoooo
o`?o00000_ooool2o`0000cooooo1?l0000:ooooo`;o00002oooool2o`0000Sooooo0ol00003oooo
o`?o000000?oooooo`000?l000001_ooool2o`0001[ooooo0_l0001Sooooo`007?ooool00ol0003o
ooooooooo`1cooooo`;o00002Oooool3o`0000;ooooo0_l0000:ooooo`?o00003Oooool2o`0000_o
oooo0_l00008ooooo`;o00000oooool2o`0000;ooooo0_l00005ooooo`Co00004oooool3o`0006Wo
oooo000Looooo`03o`000?oooooooooo06Cooooo0_l0000<ooooo`?o00002oooool4o`0000_ooooo
0ol0000Kooooo`;o00003?ooool3o`000003ooooool0003o000000Gooooo0_l0000;ooooo`;o0000
2?ooool3o`0000?ooooo0_l0001Tooooo`007?ooool00ol0003oooooooooo`1Tooooo`;o00001Ooo
ool2o`0000Gooooo0_l00007ooooo`;o00000oooool4o`0000cooooo0ol00002ooooo`;o00003Ooo
ool2o`0000Gooooo1_l0000;ooooo`;o00005Oooool2o`0000kooooo0_l0001Tooooo`0000Kooooo
onk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Ko
oooo00?o0000ooooooooool0Joooool2o`0000Gooooo1Ol000001?oooooo0000o`000?ooool2o`00
013ooooo0_l00002ooooo`?o000000?oooooo`000?l000003Oooool2o`0000?ooooo1?l000001?oo
oooo0000o`000?l00005ooooo`?o00007_ooool2o`00073ooooo00001_ooooooMgMgoiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`1dooooo`?o000000?oooooo`000?l000002Oooool2o`0000;ooooo0_l00004ooooo`Oo0000
4Oooool3o`000003ooooool0003o000000?ooooo0_l00006ooooo`?o00007_ooool2o`00073ooooo
00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo07;ooooo1?l00007ooooo`;o00001?ooool3o`000003oooo
ool0003o000000Gooooo1Ol00006ooooo`;o00002_ooool4o`0000Gooooo0_l00004ooooo`;o0000
00?oooooo`000?l000004oooool2o`0007_ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oo
oooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000L_ooool2o`0000Kooooo
0_l000000ooooooo0000o`000005ooooo`;o00000_ooool2o`0000Gooooo1?l00006ooooo`;o0000
1_ooool4o`0000;ooooo0_l00005ooooo`;o00001?ooool2o`000003ooooool0003o000001?ooooo
0_l0001kooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05olc<c?l0
003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`1jooooo`;o00003?ooool2o`0000Oooooo
0_l0000>ooooo`Co00002?ooool2o`000003ooooool0003o000000Gooooo0_l0000Jooooo`;o0000
M?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol@413o^[Zjoooo
oonj^[[o410@00Kooooo00?o0000ooooooooool0NOooool2o`0001?ooooo0_l0000>ooooo`Co0000
1Oooool2o`0000;ooooo1?l000000ooooooo0000o`000002ooooo`;o00001_ooool2o`0000Kooooo
0_l0000:ooooo`;o000000?oooooo`000?l00000M?ooool00006oooooomgMgOoV9RHoooooonHV9So
MgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0G?ooool2o`00
01_ooooo0_l0000Cooooo`;o00003Oooool5o`0000Gooooo0_l00002ooooo`;o00001oooool2o`00
00Kooooo0_l00006ooooo`;o00002_ooool2o`0007Oooooo00001_ooooook^k^oc8b<_l0003o<S8b
onk^kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo05cooooo0_l0
000[ooooo`;o00004_ooool2o`0000Kooooo0ol0000Booooo`;o00004oooool2o`0007Sooooo000L
ooooo`03o`000?oooooooooo087ooooo0_l00006ooooo`;o00002_ooool2o`0000kooooo0ol0000B
ooooo`;o00004oooool2o`0007Sooooo000Looooo`03o`000?oooooooooo087ooooo0_l00009oooo
o`;o000000?oooooo`000?l000001?ooool2o`0000Cooooo0_l00009ooooo`;o00009oooool2o`00
07Sooooo000Looooo`03o`000?oooooooooo08cooooo1Ol00006ooooo`;o00000_ooool2o`0002Oo
oooo0_l00003ooooo`;o0000O_ooool001cooooo00?o0000ooooooooool0F_ooool2o`00037ooooo
0_l00008ooooo`;o00004?ooool2o`0001Sooooo0ol00003ooooo`;o0000O_ooool001cooooo00?o
0000ooooooooool0F_ooool2o`0003Cooooo0_l00009ooooo`;o00003?ooool2o`0001Sooooo0_l0
0024ooooo`007?ooool00ol0003oooooooooo`2@ooooo`;o00002Oooool2o`00023ooooo0_l0002:
ooooo`007?ooool00ol0003oooooooooo`2;ooooo`;o00001?ooool2o`0001Wooooo0_l0000?oooo
o`;o0000R_ooool001cooooo00?o0000ooooooooool0Roooool2o`0000Cooooo0_l00004ooooo`;o
00002Oooool2o`0000Sooooo0_l0002Kooooo`007?ooool00ol0003oooooooooo`2>ooooo`;o0000
00?oooooo`000?l000001?ooool2o`0000Wooooo0_l00009ooooo`;o00000_ooool2o`0009Kooooo
000Looooo`03o`000?oooooooooo08Cooooo0_l00008ooooo`;o00001Oooool2o`0000Kooooo0_l0
000>ooooo`;o00000_ooool2o`0001gooooo0_l0001gooooo`007?ooool00ol0003oooooooooo`24
ooooo`;o00003oooool2o`0000Kooooo0_l0000Dooooo`;o00006oooool2o`0007Oooooo000Loooo
o`;o0000UOooool2o`0001gooooo0_l00003ooooo`;o0000Soooool001cooooo00?o0000oooooooo
ool0U?ooool2o`0000gooooo0_l0000Cooooo`;o00003oooool2o`0007kooooo000Looooo`03o`00
0?oooooooooo08Sooooo0_l0000Iooooo`;o00009?ooool2o`0007kooooo000Looooo`03o`000?oo
oooooooo08Sooooo0_l0000hooooo`;o0000QOooool001cooooo00?o0000ooooooooool0`_ooool2
o`0008Gooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Cooooo`;o0000]?ooool001cooooo00?o
0000ooooooooool0Toooool2o`000;Cooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Nooooo`;o
0000ZOooool001cooooo00?o0000ooooooooool0Uoooool4o`0000?ooooo1?l0000Aooooo`;o0000
U?ooool001cooooo00?o0000ooooooooool0Uoooool4o`0000Gooooo0_l00008ooooo`;o00001ooo
ool2o`0009Cooooo000Looooo`03o`000?oooooooooo07[ooooo0_l0000Looooo`;o00004?ooool2
o`0000Kooooo0_l0002Eooooo`007?ooool00ol0003oooooooooo`1jooooo`;o00007?ooool2o`00
01Sooooo0_l0002Eooooo`007?ooool2o`0009Kooooo0_l0002booooo`007?ooool00ol0003ooooo
ooooo`2Eooooo`;o0000/_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`2Jooooo`;o0000[Oooool001cooooo00?o0000ooooooooool0Roooool2o`00
00gooooo0_l0002]ooooo`007?ooool00ol0003oooooooooo`2;ooooo`;o0000_?ooool001cooooo
00?o0000ooooooooool0T_ooool2o`000;Gooooo000Looooo`03o`000?oooooooooo09;ooooo0_l0
002eooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001;ooooo1?l000000ol@413o
ooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo0ol0
003ooooood[ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000oooo
ooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`00
0?oooooooooo0?ooooooD_ooool001;ooooo00?oEEEEofIVI_l00000oooooomDooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00XOooool01?l@413o0000o`000?ooool2o`000003
oa0@4?oooooooooo01Kooooo1?l000001?l@413oooooooooooooool4o`000003oa0@4?oooooooooo
00;ooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o410@olc<c02<ooooo`00X_oo
ool01Ol0003ooooooooooooooooo000000Wooooo1_l0000<ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B40S?ooool00:;ooooo00Go0000ooooooooooooooooo`00000Kooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00_ooool5o`0000?ooooo00Go0000ooooooooooooooooo`00002<oooo
o`00X_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l0000<ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool01?m4A4CogMgMooooool00004ooooo`05o`000?nHV9So
oooooiRHV?lQ8B40S?ooool00:;ooooo00Go0000ohN7QoooooooZJVYo`00000Kooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00_ooool01?oMgMgoEEEEooooool00004ooooo`05o`00
0?mEEEGo0000oa0@4?o<c<`0S?ooool00:7ooooo00?o410@o`000?mgMgL00_l000000onHV9Sooooo
ooooo`0Iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00omgMgOoc<c<
o`000004ooooo`03oeEEEOn7QhOooooo08kooooo0032ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00oooool00oo^k^koA4A4o`000004ooooo`03omgMgOl@413oV9RH08kooooo0030
ooooo`03oeEEEOmVIVKo000000Gooooo00?oEEEEofIVI_l000001_ooool00omgMgOo0000ooooo`04
ooooo`04olc<c?m4A4Co0000oa0@48cooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1152) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.37929 .41768 Mdot
.38149 .36872 Mdot
.50103 .62803 Mdot
.63275 .39977 Mdot
.19595 .53001 Mdot
.48483 .65462 Mdot
.37171 .57145 Mdot
.36054 .5146 Mdot
.5019 .63754 Mdot
.27119 .38835 Mdot
.36424 .56321 Mdot
.61156 .32256 Mdot
.35896 .54674 Mdot
.62028 .42074 Mdot
.16288 .41463 Mdot
.64415 .35404 Mdot
.41971 .36642 Mdot
.63984 .65016 Mdot
.54524 .39152 Mdot
.50905 .682 Mdot
.43605 .38729 Mdot
.62138 .41004 Mdot
.35931 .36843 Mdot
.61968 .42143 Mdot
.63838 .37901 Mdot
.39897 .4004 Mdot
.38292 .32449 Mdot
.59781 .37425 Mdot
.6377 .36517 Mdot
.35476 .51653 Mdot
.70646 .52188 Mdot
.15782 .47465 Mdot
.54638 .42778 Mdot
.37563 .77345 Mdot
.37311 .51899 Mdot
.49709 .33291 Mdot
.47278 .6425 Mdot
.37417 .53279 Mdot
.38094 .53227 Mdot
.38665 .57949 Mdot
.3771 .54861 Mdot
.38624 .39437 Mdot
.41337 .58868 Mdot
.45568 .57047 Mdot
.62249 .34937 Mdot
.23435 .51901 Mdot
.69054 .28447 Mdot
.57027 .41062 Mdot
.42103 .38379 Mdot
.51944 .74085 Mdot
.29162 .64529 Mdot
.38695 .57289 Mdot
.44814 .66682 Mdot
.54072 .89905 Mdot
.36701 .5251 Mdot
.5944 .3502 Mdot
.47675 .63202 Mdot
.61013 .41376 Mdot
.61488 .42465 Mdot
.41458 .25289 Mdot
.56527 .39132 Mdot
.62336 .62703 Mdot
.37329 .42258 Mdot
.54339 .50751 Mdot
.49156 .63722 Mdot
.38418 .54787 Mdot
.3714 .37613 Mdot
.35654 .53803 Mdot
.66716 .43172 Mdot
.50127 .68896 Mdot
.57086 .40647 Mdot
.37805 .55871 Mdot
.42166 .40338 Mdot
.58663 .39402 Mdot
.58614 .76429 Mdot
.31721 .23707 Mdot
.62672 .57815 Mdot
.46386 .29663 Mdot
.40644 .27519 Mdot
.59542 .70169 Mdot
.64279 .4192 Mdot
.76988 .45076 Mdot
.26527 .29786 Mdot
.36281 .34714 Mdot
.57366 .47975 Mdot
.57337 .59674 Mdot
.58974 .39768 Mdot
.22286 .43523 Mdot
.64401 .36289 Mdot
.59812 .78071 Mdot
.5062 .64744 Mdot
.39956 .37005 Mdot
.63429 .40093 Mdot
.59439 .3695 Mdot
.70296 .31926 Mdot
.58923 .45698 Mdot
.61151 .38425 Mdot
.40345 .41304 Mdot
.39255 .56623 Mdot
.60812 .33264 Mdot
.43337 .5705 Mdot
.43934 .64321 Mdot
.58823 .44798 Mdot
.46435 .66993 Mdot
.42909 .39569 Mdot
.58367 .38797 Mdot
.38692 .53452 Mdot
.59184 .44455 Mdot
.32982 .48186 Mdot
.37935 .3661 Mdot
.60056 .36885 Mdot
.63376 .63979 Mdot
.80725 .59361 Mdot
.40028 .3613 Mdot
.63846 .6888 Mdot
.6514 .4104 Mdot
.60917 .39415 Mdot
.38315 .37107 Mdot
.45669 .62668 Mdot
.22982 .403 Mdot
.35473 .3635 Mdot
.39549 .57481 Mdot
.35734 .40396 Mdot
.59597 .48322 Mdot
.49939 .6492 Mdot
.34791 .7112 Mdot
.29905 .56286 Mdot
.71749 .49357 Mdot
.59238 .40281 Mdot
.28197 .4447 Mdot
.50498 .674 Mdot
.39424 .38015 Mdot
.35297 .53648 Mdot
.53459 .39363 Mdot
.37367 .35229 Mdot
.3444 .54273 Mdot
.62136 .63545 Mdot
.37592 .67876 Mdot
.40888 .34973 Mdot
.44947 .55189 Mdot
.35025 .50605 Mdot
.38273 .57715 Mdot
.43899 .81311 Mdot
.37516 .37935 Mdot
.63975 .61585 Mdot
.35277 .52557 Mdot
.68094 .51965 Mdot
.59263 .35718 Mdot
.76179 .51728 Mdot
.75106 .31194 Mdot
.39472 .7838 Mdot
.41049 .69748 Mdot
.62705 .59578 Mdot
.40212 .55054 Mdot
.62539 .37354 Mdot
.40507 .40416 Mdot
.38246 .39746 Mdot
.56169 .40336 Mdot
.63788 .39129 Mdot
.574 .3982 Mdot
.59758 .3659 Mdot
.38419 .2454 Mdot
.61778 .45329 Mdot
.72931 .31593 Mdot
.4034 .36778 Mdot
.62754 .38514 Mdot
.45699 .63635 Mdot
.58097 .46894 Mdot
.37928 .55175 Mdot
.61601 .40679 Mdot
.63224 .39678 Mdot
.56266 .39337 Mdot
.38946 .57168 Mdot
.18073 .41721 Mdot
.78307 .38747 Mdot
.17344 .49677 Mdot
.64116 .74491 Mdot
.48083 .67109 Mdot
.59636 .39512 Mdot
.63826 .63317 Mdot
.52946 .29981 Mdot
.632 .42924 Mdot
.88041 .51366 Mdot
.61733 .39137 Mdot
.18299 .49866 Mdot
.68857 .4167 Mdot
.16032 .5558 Mdot
.7609 .48198 Mdot
.61867 .36874 Mdot
.62184 .51118 Mdot
.46735 .41111 Mdot
.43144 .58929 Mdot
.37442 .5489 Mdot
.45937 .63261 Mdot
.48648 .62732 Mdot
.3988 .51511 Mdot
.34837 .31153 Mdot
.59391 .49794 Mdot
.63514 .45966 Mdot
.49258 .69195 Mdot
.40048 .42724 Mdot
.61002 .60264 Mdot
.38141 .41062 Mdot
.35563 .17166 Mdot
.28263 .6089 Mdot
.41048 .54437 Mdot
.66503 .61868 Mdot
.51664 .64842 Mdot
.44207 .64746 Mdot
.65193 .62829 Mdot
.58345 .42825 Mdot
.37224 .3821 Mdot
.35016 .77669 Mdot
.32168 .32319 Mdot
.41588 .81553 Mdot
.41027 .40818 Mdot
.29757 .40012 Mdot
.34795 .54627 Mdot
.46706 .65304 Mdot
.6094 .39061 Mdot
.58862 .42348 Mdot
.42711 .35896 Mdot
.57418 .40142 Mdot
.70302 .3538 Mdot
.60319 .38075 Mdot
.31754 .67295 Mdot
.61703 .57872 Mdot
.40038 .51783 Mdot
.72104 .47619 Mdot
.36057 .38567 Mdot
.74158 .6244 Mdot
.45598 .66505 Mdot
.50992 .30495 Mdot
.37939 .56183 Mdot
.62125 .63201 Mdot
.46096 .67294 Mdot
.60755 .60353 Mdot
.54935 .42975 Mdot
.51381 .62513 Mdot
.64822 .63849 Mdot
.38348 .29367 Mdot
.60271 .35907 Mdot
.3795 .2416 Mdot
.39893 .5563 Mdot
.35413 .35686 Mdot
.56831 .38819 Mdot
.47112 .66861 Mdot
.5476 .4398 Mdot
.40754 .64682 Mdot
.34647 .70794 Mdot
.44878 .62674 Mdot
.48542 .73945 Mdot
.61447 .61815 Mdot
.36988 .62615 Mdot
.30185 .42938 Mdot
.42286 .38826 Mdot
.61092 .45653 Mdot
.14794 .5571 Mdot
.35298 .52583 Mdot
.59314 .4417 Mdot
.36159 .74554 Mdot
.35908 .52661 Mdot
.60792 .41431 Mdot
.38447 .51698 Mdot
.38015 .39676 Mdot
.80315 .5467 Mdot
.42038 .37042 Mdot
.65107 .37407 Mdot
.39011 .53654 Mdot
.48072 .61947 Mdot
.40664 .39835 Mdot
.5788 .4307 Mdot
.59401 .38152 Mdot
.5113 .50766 Mdot
.62172 .38058 Mdot
.18222 .44118 Mdot
.60684 .37337 Mdot
.46719 .63065 Mdot
.5718 .44539 Mdot
.75009 .72571 Mdot
.30327 .59152 Mdot
.37149 .37759 Mdot
.48109 .61678 Mdot
.49825 .63306 Mdot
.6617 .67887 Mdot
.38209 .60337 Mdot
.64521 .42263 Mdot
.47763 .6715 Mdot
.7664 .57514 Mdot
.33881 .53265 Mdot
.60903 .45858 Mdot
.4565 .54867 Mdot
.52796 .74013 Mdot
.46479 .67995 Mdot
.54859 .37388 Mdot
.42361 .36169 Mdot
.63529 .39966 Mdot
.44538 .64249 Mdot
.43675 .40294 Mdot
.65728 .40113 Mdot
.34121 .40253 Mdot
.50984 .50561 Mdot
.34986 .55851 Mdot
.68447 .43472 Mdot
.58069 .43915 Mdot
.46128 .65408 Mdot
.36524 .39313 Mdot
.33958 .51933 Mdot
.39652 .39531 Mdot
.23016 .64812 Mdot
.33995 .47921 Mdot
.37205 .27719 Mdot
.64987 .65517 Mdot
.47653 .76295 Mdot
.17398 .58927 Mdot
.70708 .71839 Mdot
.72886 .60466 Mdot
.27754 .72309 Mdot
.45084 .6385 Mdot
.3874 .75693 Mdot
.49205 .62987 Mdot
.6475 .39233 Mdot
.49573 .646 Mdot
.1696 .58718 Mdot
.60484 .38063 Mdot
.48815 .64522 Mdot
.75859 .615 Mdot
.63228 .39008 Mdot
.39743 .35549 Mdot
.20988 .35862 Mdot
.72646 .7172 Mdot
.32938 .70596 Mdot
.52585 .64681 Mdot
.70584 .59768 Mdot
.61186 .38124 Mdot
.56599 .44376 Mdot
.4175 .38185 Mdot
.61018 .46111 Mdot
.61578 .59901 Mdot
.6654 .62182 Mdot
.46496 .42801 Mdot
.78489 .44033 Mdot
.67017 .36284 Mdot
.41082 .39554 Mdot
.4377 .21209 Mdot
.56665 .76909 Mdot
.49941 .75182 Mdot
.39194 .51854 Mdot
.20965 .3739 Mdot
.67636 .32625 Mdot
.40883 .51199 Mdot
.46039 .57833 Mdot
.39238 .3628 Mdot
.17451 .44067 Mdot
.37284 .54481 Mdot
.59499 .22474 Mdot
.62751 .53104 Mdot
.58766 .42911 Mdot
.37796 .56622 Mdot
.65886 .33995 Mdot
.70863 .7434 Mdot
.61638 .2101 Mdot
.74767 .38481 Mdot
.65586 .38033 Mdot
.60536 .75848 Mdot
.61408 .40097 Mdot
.2372 .38606 Mdot
.60444 .37289 Mdot
.40314 .39242 Mdot
.25592 .38342 Mdot
.48433 .45337 Mdot
.76762 .36283 Mdot
.28005 .58518 Mdot
.62621 .59572 Mdot
.60433 .38693 Mdot
.58891 .43043 Mdot
.61545 .60417 Mdot
.38674 .34275 Mdot
.59745 .36537 Mdot
.7331 .62783 Mdot
.5829 .40217 Mdot
.37791 .54116 Mdot
.73744 .38863 Mdot
.34923 .32886 Mdot
.65248 .4404 Mdot
.40569 .42284 Mdot
.34892 .55879 Mdot
.3769 .52544 Mdot
.6394 .34756 Mdot
.37869 .58215 Mdot
.62265 .3963 Mdot
.62348 .20536 Mdot
.40255 .34913 Mdot
.70114 .38883 Mdot
.36272 .35855 Mdot
.45735 .29931 Mdot
.3821 .52462 Mdot
.31066 .65486 Mdot
.56998 .34163 Mdot
.37014 .54707 Mdot
.35611 .47038 Mdot
.67144 .36987 Mdot
.66173 .37863 Mdot
.55838 .79669 Mdot
.5216 .63672 Mdot
.50378 .48651 Mdot
.36399 .51302 Mdot
.57526 .43292 Mdot
.63885 .44972 Mdot
.3532 .56372 Mdot
.53807 .19371 Mdot
.74886 .66117 Mdot
.60442 .37683 Mdot
.40714 .38294 Mdot
.39374 .38277 Mdot
.66013 .38464 Mdot
.60421 .44995 Mdot
.50119 .66699 Mdot
.50623 .61951 Mdot
.53089 .64672 Mdot
.50818 .50241 Mdot
.31302 .66255 Mdot
.23258 .57566 Mdot
.38612 .57947 Mdot
.30112 .46572 Mdot
.61731 .77298 Mdot
.59193 .47718 Mdot
.51393 .67272 Mdot
.60008 .43839 Mdot
.6293 .40292 Mdot
.33629 .52365 Mdot
.3372 .72188 Mdot
.66168 .33125 Mdot
.39822 .34355 Mdot
.3506 .51204 Mdot
.52619 .43533 Mdot
.26406 .5428 Mdot
.63383 .63708 Mdot
.4646 .8069 Mdot
.38086 .55774 Mdot
.39273 .35779 Mdot
.38407 .52206 Mdot
.58562 .41896 Mdot
.55873 .36978 Mdot
.38906 .3704 Mdot
.66162 .61966 Mdot
.56303 .45362 Mdot
.60759 .41137 Mdot
.81765 .39047 Mdot
.63918 .75614 Mdot
.32703 .67209 Mdot
.61507 .3698 Mdot
.65779 .42821 Mdot
.60579 .62716 Mdot
.58254 .40781 Mdot
.57364 .38963 Mdot
.82086 .5351 Mdot
.29475 .54013 Mdot
.66015 .64392 Mdot
.56981 .21202 Mdot
.41388 .40577 Mdot
.15211 .52252 Mdot
.46731 .65716 Mdot
.40114 .58203 Mdot
.76699 .64615 Mdot
.43651 .64956 Mdot
.42144 .70307 Mdot
.15584 .50338 Mdot
.50089 .48377 Mdot
.56082 .6677 Mdot
.63 .31921 Mdot
.58464 .37841 Mdot
.60975 .40019 Mdot
.63666 .6297 Mdot
.37505 .38616 Mdot
.52085 .50425 Mdot
.41358 .19668 Mdot
.62028 .40488 Mdot
.70694 .37845 Mdot
.32297 .29522 Mdot
.53464 .7347 Mdot
.63436 .60053 Mdot
.66276 .61753 Mdot
.60541 .39092 Mdot
.80911 .57152 Mdot
.40053 .40107 Mdot
.5797 .43192 Mdot
.64307 .43122 Mdot
.52433 .63816 Mdot
.37875 .36058 Mdot
.44855 .64234 Mdot
.30323 .63621 Mdot
.17848 .50256 Mdot
.82299 .38674 Mdot
.37853 .52394 Mdot
.2758 .32638 Mdot
.34791 .51968 Mdot
.76574 .44323 Mdot
.44074 .65154 Mdot
.63818 .42552 Mdot
.36333 .39026 Mdot
.58363 .43807 Mdot
.61419 .44813 Mdot
.58475 .42993 Mdot
.61834 .46849 Mdot
.85701 .58023 Mdot
.6571 .62317 Mdot
.66992 .40896 Mdot
.4815 .62561 Mdot
.23001 .371 Mdot
.30517 .25473 Mdot
.59547 .43027 Mdot
.59688 .38432 Mdot
.38703 .34786 Mdot
.56069 .41859 Mdot
.34081 .52745 Mdot
.36682 .39721 Mdot
.59656 .3685 Mdot
.2169 .37423 Mdot
.62401 .36096 Mdot
.16508 .53351 Mdot
.38117 .51878 Mdot
.34684 .4518 Mdot
.67412 .39891 Mdot
.34829 .7062 Mdot
.50391 .48666 Mdot
.48852 .67984 Mdot
.3708 .58536 Mdot
.47545 .64101 Mdot
.50211 .15901 Mdot
.55225 .38693 Mdot
.62928 .37449 Mdot
.63141 .45459 Mdot
.47843 .67018 Mdot
.21219 .46028 Mdot
.3389 .62094 Mdot
.5331 .45019 Mdot
.48956 .6691 Mdot
.38776 .42686 Mdot
.62443 .55223 Mdot
.36223 .37708 Mdot
.667 .62142 Mdot
.36255 .56111 Mdot
.65149 .60047 Mdot
.34398 .74128 Mdot
.38141 .36644 Mdot
.39925 .32581 Mdot
.47539 .66003 Mdot
.5387 .56728 Mdot
.44215 .86855 Mdot
.58994 .55149 Mdot
.74106 .50763 Mdot
.41594 .38004 Mdot
.65149 .38022 Mdot
.75173 .4287 Mdot
.52599 .5556 Mdot
.47796 .63919 Mdot
.63233 .42244 Mdot
.79906 .56896 Mdot
.50101 .66769 Mdot
.60818 .45789 Mdot
.50589 .62657 Mdot
.37255 .55705 Mdot
.5161 .66424 Mdot
.40051 .33639 Mdot
.58852 .38719 Mdot
.40523 .84869 Mdot
.65439 .58371 Mdot
.61251 .3757 Mdot
.3535 .51153 Mdot
.39445 .45937 Mdot
.61441 .44282 Mdot
.61222 .62931 Mdot
.49421 .65407 Mdot
.58068 .55932 Mdot
.60389 .37537 Mdot
.48069 .66938 Mdot
.36906 .41315 Mdot
.3833 .58802 Mdot
.49472 .41876 Mdot
.34244 .70362 Mdot
.41792 .38498 Mdot
.43581 .549 Mdot
.34211 .56283 Mdot
.65543 .43372 Mdot
.62329 .45206 Mdot
.40312 .38348 Mdot
.80555 .50713 Mdot
.56192 .43219 Mdot
.64248 .4195 Mdot
.47491 .62576 Mdot
.47922 .64431 Mdot
.80111 .53019 Mdot
.46378 .62361 Mdot
.55644 .37396 Mdot
.40236 .38562 Mdot
.63574 .40642 Mdot
.38769 .35054 Mdot
.56461 .42841 Mdot
.4458 .38462 Mdot
.38453 .34065 Mdot
.34223 .61133 Mdot
.63322 .41471 Mdot
.69112 .41555 Mdot
.59717 .44342 Mdot
.57869 .39752 Mdot
.50354 .66304 Mdot
.6472 .61358 Mdot
.57091 .35032 Mdot
.65432 .58884 Mdot
.60772 .60707 Mdot
.42769 .43956 Mdot
.52427 .63988 Mdot
.63313 .61768 Mdot
.34104 .26463 Mdot
.52972 .64275 Mdot
.62652 .62649 Mdot
.29826 .26596 Mdot
.37499 .52 Mdot
.41708 .35478 Mdot
.63344 .38989 Mdot
.27664 .71359 Mdot
.69936 .28666 Mdot
.43082 .6562 Mdot
.60866 .37352 Mdot
.60443 .44045 Mdot
.35635 .35992 Mdot
.57024 .15322 Mdot
.50724 .68586 Mdot
.64274 .3753 Mdot
.37121 .37102 Mdot
.62572 .18026 Mdot
.46649 .63328 Mdot
.62999 .62823 Mdot
.39423 .56989 Mdot
.36913 .42638 Mdot
.30043 .56368 Mdot
.36706 .57084 Mdot
.45129 .67642 Mdot
.29697 .65006 Mdot
.65129 .41118 Mdot
.51095 .67452 Mdot
.48732 .81529 Mdot
.32349 .32914 Mdot
.32522 .56406 Mdot
.69953 .59434 Mdot
.39449 .36297 Mdot
.34235 .52617 Mdot
.64802 .60174 Mdot
.40664 .40975 Mdot
.4041 .35495 Mdot
.33447 .53518 Mdot
.50108 .38291 Mdot
.46136 .55042 Mdot
.37894 .5345 Mdot
.56943 .78845 Mdot
.25582 .65138 Mdot
.51311 .67453 Mdot
.61476 .60204 Mdot
.31954 .73209 Mdot
.38742 .39503 Mdot
.20698 .37683 Mdot
.49465 .80909 Mdot
.61168 .38432 Mdot
.63323 .61256 Mdot
.21994 .51387 Mdot
.4421 .17469 Mdot
.36119 .52632 Mdot
.48109 .46097 Mdot
.62766 .59031 Mdot
.56648 .39155 Mdot
.6553 .53677 Mdot
.64215 .41109 Mdot
.35312 .55494 Mdot
.40238 .26066 Mdot
.39217 .35659 Mdot
.33307 .52611 Mdot
.46173 .80757 Mdot
.62308 .39936 Mdot
.63396 .4182 Mdot
.71051 .47714 Mdot
.38739 .40417 Mdot
.48687 .67994 Mdot
.64877 .41637 Mdot
.61121 .40937 Mdot
.58337 .34931 Mdot
.67968 .44622 Mdot
.80496 .59148 Mdot
.6465 .38415 Mdot
.28628 .59613 Mdot
.65812 .43398 Mdot
.62905 .41754 Mdot
.40658 .423 Mdot
.84936 .43073 Mdot
.29894 .62806 Mdot
.61446 .40689 Mdot
.65076 .38102 Mdot
.33495 .5421 Mdot
.47226 .5457 Mdot
.53206 .56825 Mdot
.56694 .56912 Mdot
.71929 .60354 Mdot
.62642 .46773 Mdot
.36602 .37322 Mdot
.64292 .64143 Mdot
.65831 .41363 Mdot
.36686 .37023 Mdot
.56717 .38109 Mdot
.49967 .66961 Mdot
.52844 .63715 Mdot
.37217 .46098 Mdot
.62769 .61915 Mdot
.7184 .43296 Mdot
.29181 .4768 Mdot
.46605 .62708 Mdot
.63292 .37637 Mdot
.40801 .58104 Mdot
.44456 .64425 Mdot
.55777 .64146 Mdot
.58297 .49145 Mdot
.39608 .40326 Mdot
.40077 .36744 Mdot
.76351 .51866 Mdot
.39089 .67967 Mdot
.81966 .42351 Mdot
.37138 .55875 Mdot
.55282 .42444 Mdot
.29069 .42982 Mdot
.40065 .3643 Mdot
.75537 .44027 Mdot
.63141 .61577 Mdot
.3594 .52483 Mdot
.45253 .72929 Mdot
.37768 .34988 Mdot
.41703 .36122 Mdot
.63455 .35778 Mdot
.60067 .41961 Mdot
.73374 .60216 Mdot
.59288 .60337 Mdot
.34516 .55373 Mdot
.6139 .60405 Mdot
.46353 .67623 Mdot
.64779 .38389 Mdot
.36034 .35806 Mdot
.29488 .69398 Mdot
.65276 .38748 Mdot
.50508 .6643 Mdot
.39481 .36731 Mdot
.61235 .6089 Mdot
.60552 .61549 Mdot
.57989 .39798 Mdot
.44321 .21457 Mdot
.37023 .53503 Mdot
.39778 .35692 Mdot
.27116 .5584 Mdot
.57397 .44815 Mdot
.59922 .41357 Mdot
.65857 .46009 Mdot
.33719 .52894 Mdot
.32771 .42965 Mdot
.64726 .59174 Mdot
.37932 .38467 Mdot
.62393 .3668 Mdot
.62132 .62175 Mdot
.31469 .42635 Mdot
.44695 .62848 Mdot
.51726 .65927 Mdot
.6093 .62573 Mdot
.63003 .60531 Mdot
.61148 .62634 Mdot
.20686 .37414 Mdot
.37945 .33198 Mdot
.66876 .32361 Mdot
.56058 .4335 Mdot
.75575 .5011 Mdot
.53182 .39402 Mdot
.34551 .51025 Mdot
.52009 .63638 Mdot
.606 .44679 Mdot
.6534 .37995 Mdot
.67665 .44215 Mdot
.69449 .36715 Mdot
.35838 .32421 Mdot
.37923 .364 Mdot
.55412 .39296 Mdot
.51694 .62882 Mdot
.38374 .15213 Mdot
.23721 .7034 Mdot
.67226 .38319 Mdot
.49709 .56392 Mdot
.36117 .35446 Mdot
.35764 .57411 Mdot
.56317 .58564 Mdot
.38863 .52796 Mdot
.38348 .38282 Mdot
.64764 .38499 Mdot
.29903 .47631 Mdot
.60859 .62746 Mdot
.5697 .41964 Mdot
.34566 .53528 Mdot
.56925 .40878 Mdot
.36856 .57121 Mdot
.20909 .62048 Mdot
.64125 .76931 Mdot
.61644 .39055 Mdot
.66804 .40779 Mdot
.70416 .62205 Mdot
.59761 .43178 Mdot
.6607 .57401 Mdot
.3635 .34889 Mdot
.79744 .41748 Mdot
.6099 .35485 Mdot
.52405 .25264 Mdot
.57518 .44995 Mdot
.7861 .58794 Mdot
.59635 .4164 Mdot
.53422 .74365 Mdot
.59365 .37503 Mdot
.57658 .38912 Mdot
.39004 .53395 Mdot
.33433 .53855 Mdot
.41486 .41249 Mdot
.4747 .67187 Mdot
.16678 .51133 Mdot
.60461 .41185 Mdot
.34355 .70893 Mdot
.30612 .50319 Mdot
.6292 .60376 Mdot
.38379 .38575 Mdot
.57223 .14759 Mdot
.39196 .52479 Mdot
.67617 .70922 Mdot
.78398 .5624 Mdot
.29685 .5796 Mdot
.57277 .59232 Mdot
.25051 .37809 Mdot
.61618 .62201 Mdot
.56075 .39926 Mdot
.32519 .71706 Mdot
.5268 .76431 Mdot
.57846 .49135 Mdot
.33128 .54049 Mdot
.52314 .29213 Mdot
.30853 .71226 Mdot
.63044 .58529 Mdot
.6507 .59783 Mdot
.38027 .57332 Mdot
.47134 .72924 Mdot
.66398 .33923 Mdot
.62875 .61355 Mdot
.47021 .62348 Mdot
.52305 .66577 Mdot
.43733 .6054 Mdot
.39224 .39997 Mdot
.42459 .79403 Mdot
.25038 .50662 Mdot
.36312 .56836 Mdot
.55022 .68415 Mdot
.34709 .35375 Mdot
.39379 .32915 Mdot
.47194 .65265 Mdot
.50855 .65866 Mdot
.41712 .35158 Mdot
.58402 .35636 Mdot
.68589 .41553 Mdot
.61782 .40449 Mdot
.64369 .6294 Mdot
.59401 .4215 Mdot
.49494 .66607 Mdot
.36024 .53057 Mdot
.51166 .64951 Mdot
.38435 .51529 Mdot
.23964 .57303 Mdot
.57576 .42114 Mdot
.5896 .38412 Mdot
.69495 .27755 Mdot
.39206 .42068 Mdot
.27622 .59342 Mdot
.33383 .69773 Mdot
.4905 .62868 Mdot
.57215 .39048 Mdot
.35945 .39032 Mdot
.652 .59177 Mdot
.69185 .2714 Mdot
.59494 .45001 Mdot
.36212 .35449 Mdot
.63247 .3688 Mdot
.34889 .27902 Mdot
.79272 .6614 Mdot
.39555 .39211 Mdot
.74724 .30978 Mdot
.64187 .36954 Mdot
.29285 .32836 Mdot
.63291 .45094 Mdot
.76674 .55733 Mdot
.56278 .4332 Mdot
.41151 .40786 Mdot
.61685 .40991 Mdot
.37867 .40466 Mdot
.45826 .63742 Mdot
.37509 .57826 Mdot
.41415 .36984 Mdot
.63715 .44139 Mdot
.15714 .66611 Mdot
.35639 .5552 Mdot
.60711 .3891 Mdot
.39676 .5579 Mdot
.36947 .38405 Mdot
.41896 .37197 Mdot
.39719 .19602 Mdot
.30809 .6339 Mdot
.3724 .55611 Mdot
.64333 .37871 Mdot
.23989 .46427 Mdot
.63942 .4067 Mdot
.73874 .56966 Mdot
.60083 .34771 Mdot
.56908 .4425 Mdot
.32325 .23334 Mdot
.33844 .5397 Mdot
.82988 .453 Mdot
.38142 .20495 Mdot
.23261 .35268 Mdot
.38823 .43477 Mdot
.63606 .58501 Mdot
.17755 .43067 Mdot
.31286 .65788 Mdot
.48486 .67018 Mdot
.60177 .44522 Mdot
.34287 .34667 Mdot
.37244 .52889 Mdot
.64908 .61728 Mdot
.61565 .39034 Mdot
.51086 .65695 Mdot
.72314 .68325 Mdot
.40275 .54507 Mdot
.38527 .3933 Mdot
.38886 .33984 Mdot
.69942 .23811 Mdot
.61788 .3681 Mdot
.58764 .38245 Mdot
.35783 .55886 Mdot
.31123 .35425 Mdot
.6138 .62122 Mdot
.74958 .6354 Mdot
.37087 .55646 Mdot
.50877 .52688 Mdot
.37489 .37433 Mdot
.6024 .44001 Mdot
.20391 .4702 Mdot
.59791 .75521 Mdot
.60747 .24379 Mdot
.63921 .63226 Mdot
.73349 .56665 Mdot
.41291 .40731 Mdot
.35174 .5324 Mdot
.38682 .69573 Mdot
.56888 .47398 Mdot
.60609 .43661 Mdot
.73257 .55981 Mdot
.48126 .43317 Mdot
.74555 .38562 Mdot
.59182 .45158 Mdot
.4976 .46394 Mdot
.57461 .44143 Mdot
.55313 .46085 Mdot
.5686 .36196 Mdot
.59561 .40697 Mdot
.36184 .35408 Mdot
.56448 .48143 Mdot
.49133 .67597 Mdot
.71379 .35365 Mdot
.52781 .53141 Mdot
.60871 .37639 Mdot
.64528 .40171 Mdot
.60235 .26482 Mdot
.41518 .51902 Mdot
.40943 .36641 Mdot
.4224 .34431 Mdot
.38561 .5822 Mdot
.68237 .42993 Mdot
.47371 .67422 Mdot
.5324 .41704 Mdot
.50497 .65923 Mdot
.35979 .37381 Mdot
.47971 .62852 Mdot
.38869 .57561 Mdot
.52043 .66639 Mdot
.31267 .66325 Mdot
.35547 .52013 Mdot
.4047 .40545 Mdot
.58598 .39557 Mdot
.35337 .51195 Mdot
.70809 .49331 Mdot
.64267 .6297 Mdot
.38176 .19918 Mdot
.60407 .36369 Mdot
.297 .54659 Mdot
.34369 .40912 Mdot
.51003 .65192 Mdot
.81544 .60341 Mdot
.38865 .34146 Mdot
.65995 .64135 Mdot
.35912 .38118 Mdot
.59522 .79295 Mdot
.64222 .60942 Mdot
.29005 .27227 Mdot
.4233 .73625 Mdot
.61606 .56594 Mdot
.58827 .35561 Mdot
.63495 .53621 Mdot
.47581 .68502 Mdot
.37164 .52814 Mdot
.40886 .70462 Mdot
.5733 .39211 Mdot
.68661 .72812 Mdot
.42862 .40179 Mdot
.47831 .67331 Mdot
.3553 .53919 Mdot
.34268 .5152 Mdot
.6109 .45271 Mdot
.5776 .67486 Mdot
.57153 .43303 Mdot
.37306 .66023 Mdot
.72183 .59203 Mdot
.67575 .35105 Mdot
.60345 .38144 Mdot
.45893 .65041 Mdot
.63304 .36919 Mdot
.63733 .65681 Mdot
.41652 .80077 Mdot
.59273 .46483 Mdot
.32753 .69042 Mdot
.67303 .60967 Mdot
.38588 .36897 Mdot
.63769 .3371 Mdot
.32253 .6578 Mdot
.62563 .36842 Mdot
.77481 .73361 Mdot
.62456 .62479 Mdot
.35456 .7177 Mdot
.63031 .45896 Mdot
.63378 .44064 Mdot
.57272 .51582 Mdot
.46169 .40668 Mdot
.60512 .75371 Mdot
.60768 .42992 Mdot
.69454 .54924 Mdot
.38458 .5667 Mdot
.57739 .43906 Mdot
.60906 .39729 Mdot
.50234 .36379 Mdot
.34549 .51666 Mdot
.50419 .63251 Mdot
.4453 .66321 Mdot
.53802 .65356 Mdot
.64567 .65273 Mdot
.48488 .48271 Mdot
.75406 .46879 Mdot
.71841 .7202 Mdot
.64746 .64318 Mdot
.61903 .35828 Mdot
.68699 .64258 Mdot
.65149 .39555 Mdot
.64465 .60143 Mdot
.34774 .51707 Mdot
.40982 .36437 Mdot
.29214 .41048 Mdot
.49833 .68929 Mdot
.61224 .45881 Mdot
.61271 .59891 Mdot
.40285 .40434 Mdot
.58898 .62202 Mdot
.38142 .37514 Mdot
.36776 .55215 Mdot
.39724 .57933 Mdot
.64975 .6111 Mdot
.36224 .37055 Mdot
.38707 .48709 Mdot
.44682 .17558 Mdot
.56748 .36007 Mdot
.36204 .59497 Mdot
.38119 .41697 Mdot
.41927 .34796 Mdot
.39203 .41418 Mdot
.5733 .40519 Mdot
.49416 .56248 Mdot
.63462 .34924 Mdot
.34654 .55502 Mdot
.50811 .6284 Mdot
.70608 .65792 Mdot
.25528 .62159 Mdot
.62477 .66859 Mdot
.55175 .41866 Mdot
.62403 .40291 Mdot
.60569 .39109 Mdot
.63616 .35512 Mdot
.36203 .66359 Mdot
.58742 .43904 Mdot
.39269 .53878 Mdot
.49715 .65707 Mdot
.56158 .39613 Mdot
.43587 .63969 Mdot
.23445 .41689 Mdot
.65151 .63925 Mdot
.47518 .46571 Mdot
.13591 .58914 Mdot
.4112 .40025 Mdot
.45546 .62675 Mdot
.48287 .66858 Mdot
.62101 .63502 Mdot
.37444 .53486 Mdot
.37703 .3772 Mdot
.75533 .58261 Mdot
.60776 .61621 Mdot
.61473 .40962 Mdot
.5247 .58487 Mdot
.67406 .73184 Mdot
.55849 .4096 Mdot
.62742 .43737 Mdot
.44345 .63068 Mdot
.50149 .73907 Mdot
.44147 .83908 Mdot
.74105 .4392 Mdot
.64808 .61159 Mdot
.66023 .62656 Mdot
.42159 .35716 Mdot
.66159 .3609 Mdot
.34893 .55781 Mdot
.73537 .36919 Mdot
.42623 .44979 Mdot
.7238 .42366 Mdot
.49502 .43029 Mdot
.5939 .44808 Mdot
.5274 .18412 Mdot
.62425 .39799 Mdot
.36513 .3425 Mdot
.373 .39326 Mdot
.41228 .3857 Mdot
.37003 .52991 Mdot
.47978 .30709 Mdot
.39167 .54096 Mdot
.15106 .6075 Mdot
.41833 .40189 Mdot
.36644 .69991 Mdot
.461 .64897 Mdot
.67513 .39938 Mdot
.61313 .61145 Mdot
.32678 .52179 Mdot
.66567 .43447 Mdot
.8116 .57384 Mdot
.48428 .67463 Mdot
.4081 .40473 Mdot
.25661 .36891 Mdot
.18636 .62111 Mdot
.54818 .57357 Mdot
.52383 .41691 Mdot
.62328 .53958 Mdot
.62674 .60228 Mdot
.61273 .24474 Mdot
.61755 .59514 Mdot
.34658 .52803 Mdot
.59172 .38744 Mdot
.59045 .39858 Mdot
.56856 .43691 Mdot
.58127 .43111 Mdot
.36042 .57671 Mdot
.57183 .45141 Mdot
.75004 .72575 Mdot
.52554 .63091 Mdot
.37948 .28924 Mdot
.61932 .62272 Mdot
.34229 .56479 Mdot
.4974 .65878 Mdot
.42615 .66081 Mdot
.72803 .47232 Mdot
.60344 .37688 Mdot
.60327 .44649 Mdot
.6707 .71942 Mdot
.59052 .45186 Mdot
.534 .38362 Mdot
.48192 .66982 Mdot
.63321 .67032 Mdot
.66128 .63231 Mdot
.65696 .61091 Mdot
.36357 .5164 Mdot
.36056 .37601 Mdot
.63492 .62398 Mdot
.46125 .63493 Mdot
.55074 .41632 Mdot
.64985 .42185 Mdot
.38523 .4176 Mdot
.50417 .80989 Mdot
.62933 .58697 Mdot
.24546 .38869 Mdot
.36886 .39519 Mdot
.35907 .33668 Mdot
.60791 .43645 Mdot
.62752 .49433 Mdot
.36252 .4222 Mdot
.64522 .64551 Mdot
.34733 .57055 Mdot
.57321 .57246 Mdot
.34619 .54713 Mdot
.37704 .39212 Mdot
.65802 .40779 Mdot
.37843 .39752 Mdot
.61285 .36987 Mdot
.12234 .51101 Mdot
.59191 .40646 Mdot
.71657 .72827 Mdot
.75601 .53632 Mdot
.48447 .65693 Mdot
.35825 .47715 Mdot
.47019 .65902 Mdot
.37095 .39729 Mdot
.65477 .41869 Mdot
.65343 .59859 Mdot
.26002 .31742 Mdot
.34917 .34386 Mdot
.50359 .67045 Mdot
.52497 .67079 Mdot
.34915 .52003 Mdot
.55506 .41149 Mdot
.60125 .43711 Mdot
.48594 .64499 Mdot
.67727 .34978 Mdot
.37342 .34853 Mdot
.5956 .38236 Mdot
.62652 .41133 Mdot
.48198 .65716 Mdot
.47035 .16621 Mdot
.45546 .39051 Mdot
.59532 .39461 Mdot
.39785 .73653 Mdot
.34349 .51118 Mdot
.6006 .35113 Mdot
.66194 .43239 Mdot
.62924 .60765 Mdot
.43955 .3245 Mdot
.39798 .7898 Mdot
.36396 .51051 Mdot
.46741 .6624 Mdot
.61911 .36715 Mdot
.46034 .65293 Mdot
.64374 .43165 Mdot
.45231 .34937 Mdot
.49623 .68097 Mdot
.63942 .43004 Mdot
.65972 .35416 Mdot
.3853 .40385 Mdot
.59839 .44766 Mdot
.60652 .28016 Mdot
.44646 .65388 Mdot
.62874 .44419 Mdot
.44022 .21733 Mdot
.38265 .54127 Mdot
.66272 .35753 Mdot
.64436 .63888 Mdot
.75651 .58469 Mdot
.27457 .50033 Mdot
.34437 .72379 Mdot
.65439 .63299 Mdot
.56794 .41181 Mdot
.53075 .6618 Mdot
.37414 .57297 Mdot
.73347 .70338 Mdot
.56311 .40205 Mdot
.35283 .55406 Mdot
.359 .53188 Mdot
.63633 .63643 Mdot
.79062 .33997 Mdot
.62516 .46413 Mdot
.59546 .42916 Mdot
.55221 .3184 Mdot
.35952 .40714 Mdot
.59077 .41585 Mdot
.64296 .36659 Mdot
.39452 .54391 Mdot
.53386 .38059 Mdot
.55443 .2753 Mdot
.76436 .60823 Mdot
.34993 .50433 Mdot
.57347 .54907 Mdot
.50274 .68372 Mdot
.61908 .61715 Mdot
.3906 .37355 Mdot
.61771 .59241 Mdot
.52177 .65895 Mdot
.6266 .35895 Mdot
.39893 .545 Mdot
.65754 .28792 Mdot
.3788 .57406 Mdot
.35029 .72827 Mdot
.36433 .40959 Mdot
.27597 .43467 Mdot
.81853 .67139 Mdot
.24632 .51579 Mdot
.41443 .5204 Mdot
.62956 .60395 Mdot
.44296 .68281 Mdot
.62629 .40847 Mdot
.63341 .25098 Mdot
.58205 .39379 Mdot
.44494 .21906 Mdot
.48339 .62138 Mdot
.531 .64676 Mdot
.5933 .39066 Mdot
.72629 .58688 Mdot
.37113 .57392 Mdot
.33863 .53414 Mdot
.62137 .44803 Mdot
.37047 .54737 Mdot
.6025 .42201 Mdot
.50048 .66366 Mdot
.84151 .4898 Mdot
.6166 .39829 Mdot
.66525 .39244 Mdot
.31319 .57634 Mdot
.33527 .23333 Mdot
.42431 .76723 Mdot
.58077 .19945 Mdot
.20609 .65131 Mdot
.36943 .54707 Mdot
.63834 .34886 Mdot
.57755 .54795 Mdot
.4346 .64046 Mdot
.3918 .4892 Mdot
.58484 .40773 Mdot
.58174 .40724 Mdot
.57828 .38589 Mdot
.63522 .41745 Mdot
.61269 .23906 Mdot
.65823 .31082 Mdot
.43873 .25444 Mdot
.6102 .44861 Mdot
.66183 .51959 Mdot
.36859 .51449 Mdot
.43464 .39495 Mdot
.59632 .60671 Mdot
.59396 .44786 Mdot
.66682 .31835 Mdot
.33411 .51923 Mdot
.15203 .60918 Mdot
.35513 .51736 Mdot
.49737 .63314 Mdot
.3602 .57477 Mdot
.62085 .37889 Mdot
.39448 .38262 Mdot
.54816 .54643 Mdot
.37344 .62836 Mdot
.48576 .67049 Mdot
.61223 .37558 Mdot
.35223 .69585 Mdot
.49082 .67459 Mdot
.23258 .42254 Mdot
.39588 .37703 Mdot
.69301 .54102 Mdot
.37368 .39476 Mdot
.64091 .42879 Mdot
.64385 .42117 Mdot
.34946 .58383 Mdot
.37921 .57746 Mdot
.37144 .3931 Mdot
.80951 .35883 Mdot
.60865 .59871 Mdot
.40969 .39123 Mdot
.55065 .44821 Mdot
.44616 .50241 Mdot
.40087 .38079 Mdot
.60471 .65776 Mdot
.36685 .52379 Mdot
.42612 .38483 Mdot
.56466 .46815 Mdot
.51519 .79485 Mdot
.63005 .64341 Mdot
.53264 .62452 Mdot
.53276 .59569 Mdot
.44509 .64722 Mdot
.36732 .58318 Mdot
.47382 .66086 Mdot
.3872 .5646 Mdot
.29075 .51264 Mdot
.7199 .37311 Mdot
.40677 .57844 Mdot
.36694 .58164 Mdot
.47586 .65974 Mdot
.59422 .37857 Mdot
.55123 .59918 Mdot
.62435 .34737 Mdot
.60683 .47409 Mdot
.38453 .56139 Mdot
.40858 .40825 Mdot
.40775 .3424 Mdot
.65689 .53195 Mdot
.38148 .33845 Mdot
.50616 .65936 Mdot
.77215 .68226 Mdot
.32824 .7097 Mdot
.37126 .56494 Mdot
.34551 .56451 Mdot
.64126 .40589 Mdot
.47598 .64038 Mdot
.45509 .64686 Mdot
.34431 .5268 Mdot
.70598 .41398 Mdot
.66476 .37492 Mdot
.4152 .33891 Mdot
.42306 .39449 Mdot
.39991 .38954 Mdot
.39004 .41245 Mdot
.55406 .25072 Mdot
.36353 .52167 Mdot
.40278 .40991 Mdot
.6334 .43725 Mdot
.58285 .40851 Mdot
.56167 .56304 Mdot
.65944 .61941 Mdot
.56923 .37957 Mdot
.56654 .36533 Mdot
.60801 .43919 Mdot
.5155 .6629 Mdot
.63285 .47495 Mdot
.49278 .68181 Mdot
.53734 .6433 Mdot
.51073 .62229 Mdot
.31341 .66 Mdot
.6589 .56036 Mdot
.24151 .6902 Mdot
.6421 .3743 Mdot
.31718 .3272 Mdot
.46585 .64164 Mdot
.81394 .59073 Mdot
.32557 .42434 Mdot
.56763 .39498 Mdot
.57802 .75971 Mdot
.48399 .64663 Mdot
.38595 .33815 Mdot
.58703 .40759 Mdot
.53924 .63804 Mdot
.63754 .64147 Mdot
.54449 .40533 Mdot
.44372 .65752 Mdot
.36333 .37336 Mdot
.60543 .63403 Mdot
.42307 .39912 Mdot
.50451 .62105 Mdot
.66084 .3555 Mdot
.47711 .88587 Mdot
.51312 .68631 Mdot
.33667 .25988 Mdot
.42939 .42572 Mdot
.59458 .3814 Mdot
.44914 .63313 Mdot
.35621 .39782 Mdot
.37876 .58681 Mdot
.43663 .4545 Mdot
.40503 .35191 Mdot
.53064 .64857 Mdot
.44328 .65331 Mdot
.48282 .67037 Mdot
.38337 .36092 Mdot
.66171 .38715 Mdot
.3842 .35387 Mdot
.3575 .57333 Mdot
.6353 .39627 Mdot
.16982 .58429 Mdot
.31774 .33123 Mdot
.36978 .3942 Mdot
.5103 .63575 Mdot
.60868 .63015 Mdot
.61981 .39033 Mdot
.36749 .24338 Mdot
.60351 .36942 Mdot
.3755 .5688 Mdot
.8208 .5055 Mdot
.65255 .28204 Mdot
.56247 .43518 Mdot
.64103 .40686 Mdot
.34068 .54526 Mdot
.61078 .38228 Mdot
.55971 .42897 Mdot
.31202 .65105 Mdot
.37603 .36193 Mdot
.61952 .40983 Mdot
.49381 .62433 Mdot
.29329 .65754 Mdot
.65678 .36567 Mdot
.64679 .69043 Mdot
.70683 .5548 Mdot
.81313 .44694 Mdot
.58232 .39096 Mdot
.7331 .42946 Mdot
.63085 .42517 Mdot
.57146 .42128 Mdot
.64541 .39161 Mdot
.63306 .23304 Mdot
.5023 .67718 Mdot
.48904 .66552 Mdot
.63503 .64484 Mdot
.70401 .55383 Mdot
.63172 .61091 Mdot
.36959 .52211 Mdot
.60462 .68951 Mdot
.49592 .68076 Mdot
.36276 .3772 Mdot
.568 .42211 Mdot
.51317 .6867 Mdot
.59891 .43971 Mdot
.6213 .37714 Mdot
.46408 .66977 Mdot
.49228 .68689 Mdot
.34928 .71959 Mdot
.64841 .6393 Mdot
.41372 .37744 Mdot
.57504 .36975 Mdot
.61054 .60399 Mdot
.66195 .40279 Mdot
.75751 .49524 Mdot
.41217 .37902 Mdot
.37785 .35916 Mdot
.40202 .34138 Mdot
.62617 .35909 Mdot
.6184 .38163 Mdot
.39195 .54408 Mdot
.36079 .38266 Mdot
.3812 .54204 Mdot
.51551 .51358 Mdot
.6693 .68565 Mdot
.58472 .40772 Mdot
.25255 .38582 Mdot
.61882 .60946 Mdot
.50688 .64362 Mdot
.68973 .6976 Mdot
.63187 .64484 Mdot
.60863 .37086 Mdot
.4587 .6556 Mdot
.64969 .60503 Mdot
.54356 .47974 Mdot
.29184 .75197 Mdot
.60134 .62162 Mdot
.63025 .44035 Mdot
.53627 .36836 Mdot
.60155 .19554 Mdot
.62211 .6444 Mdot
.39695 .56422 Mdot
.62277 .35889 Mdot
.33903 .39269 Mdot
.63059 .58793 Mdot
.27402 .5861 Mdot
.49194 .65235 Mdot
.451 .79399 Mdot
.65087 .45574 Mdot
.67304 .27781 Mdot
.62721 .59377 Mdot
.378 .38035 Mdot
.43776 .40011 Mdot
.61636 .43405 Mdot
.62088 .64395 Mdot
.3476 .50337 Mdot
.49814 .64938 Mdot
.29869 .63071 Mdot
.38517 .35929 Mdot
.25805 .42125 Mdot
.51645 .64012 Mdot
.24515 .4026 Mdot
.79402 .56863 Mdot
.68467 .39118 Mdot
.59265 .20143 Mdot
.43614 .72001 Mdot
.61491 .35681 Mdot
.60437 .60275 Mdot
.36086 .51071 Mdot
.39828 .56584 Mdot
.36698 .55529 Mdot
.30123 .50599 Mdot
.56187 .57261 Mdot
.46336 .6216 Mdot
.41246 .61872 Mdot
.62148 .61916 Mdot
.67816 .50173 Mdot
.64528 .43503 Mdot
.62261 .40217 Mdot
.55418 .4103 Mdot
.58427 .44532 Mdot
.62529 .42582 Mdot
.37515 .5412 Mdot
.28822 .52975 Mdot
.57702 .56001 Mdot
.40723 .37931 Mdot
.5721 .665 Mdot
.46137 .64812 Mdot
.47466 .61748 Mdot
.65526 .61729 Mdot
.23833 .38832 Mdot
.43647 .64201 Mdot
.48559 .6278 Mdot
.58822 .36889 Mdot
.37721 .35109 Mdot
.53663 .4449 Mdot
.64157 .42014 Mdot
.50519 .65236 Mdot
.5567 .51827 Mdot
.57892 .27099 Mdot
.60818 .48723 Mdot
.67181 .6508 Mdot
.49218 .55698 Mdot
.6118 .63598 Mdot
.65403 .42597 Mdot
.81584 .57876 Mdot
.52018 .66238 Mdot
.48722 .63464 Mdot
.62362 .59608 Mdot
.38617 .30987 Mdot
.3924 .3658 Mdot
.42607 .66782 Mdot
.39484 .56195 Mdot
.65055 .40584 Mdot
.72032 .67857 Mdot
.3508 .30752 Mdot
.57976 .68009 Mdot
.36621 .55851 Mdot
.45717 .64234 Mdot
.55464 .42407 Mdot
.63023 .43954 Mdot
.61963 .60234 Mdot
.20153 .56944 Mdot
.5507 .39055 Mdot
.22385 .36008 Mdot
.63917 .77245 Mdot
.51338 .80334 Mdot
.60592 .43649 Mdot
.37751 .36242 Mdot
.44023 .65087 Mdot
.61493 .60227 Mdot
.57094 .46264 Mdot
.27563 .73219 Mdot
.40479 .41703 Mdot
.3494 .52883 Mdot
.55499 .53719 Mdot
.5613 .58489 Mdot
.59994 .36418 Mdot
.5831 .39447 Mdot
.57383 .41314 Mdot
.35555 .79192 Mdot
.51169 .66347 Mdot
.35883 .36338 Mdot
.64493 .6327 Mdot
.37594 .33862 Mdot
.48509 .66248 Mdot
.26359 .43137 Mdot
.59666 .37324 Mdot
.4015 .41828 Mdot
.38017 .37951 Mdot
.35171 .51935 Mdot
.38507 .58705 Mdot
.53356 .52694 Mdot
.59295 .40805 Mdot
.50342 .69212 Mdot
.39517 .40755 Mdot
.53009 .58546 Mdot
.64057 .6081 Mdot
.38216 .52578 Mdot
.60631 .44818 Mdot
.51112 .67196 Mdot
.57202 .45203 Mdot
.40282 .36612 Mdot
.48324 .62803 Mdot
.34876 .71428 Mdot
.65832 .63039 Mdot
.58281 .42158 Mdot
.62312 .64918 Mdot
.4669 .66242 Mdot
.62787 .40959 Mdot
.27351 .33902 Mdot
.67681 .64199 Mdot
.34913 .62636 Mdot
.48464 .61978 Mdot
.34413 .70711 Mdot
.41086 .34986 Mdot
.31901 .48208 Mdot
.49229 .63449 Mdot
.2503 .36964 Mdot
.22458 .60142 Mdot
.55257 .40188 Mdot
.39113 .39526 Mdot
.45759 .70851 Mdot
.14682 .51961 Mdot
.46551 .17272 Mdot
.60767 .39095 Mdot
.46587 .62266 Mdot
.6256 .59734 Mdot
.37303 .56544 Mdot
.65231 .6903 Mdot
.67243 .65339 Mdot
.51124 .68382 Mdot
.64629 .39157 Mdot
.37099 .38198 Mdot
.36571 .52859 Mdot
.27843 .50523 Mdot
.4704 .62773 Mdot
.51426 .63269 Mdot
.55578 .42655 Mdot
.63091 .61664 Mdot
.41182 .21256 Mdot
.49842 .66622 Mdot
.66504 .72979 Mdot
.46288 .68265 Mdot
.60933 .60089 Mdot
.63026 .43117 Mdot
.64427 .53994 Mdot
.62318 .35073 Mdot
.30964 .27328 Mdot
.46853 .65537 Mdot
.40739 .37027 Mdot
.57502 .3975 Mdot
.77716 .586 Mdot
.50456 .64891 Mdot
.50007 .56413 Mdot
.52494 .74881 Mdot
.36496 .52259 Mdot
.68951 .69987 Mdot
.59064 .42273 Mdot
.37289 .57376 Mdot
.61973 .60906 Mdot
.59624 .40039 Mdot
.62097 .38306 Mdot
.35523 .36515 Mdot
.3444 .53032 Mdot
.23998 .63793 Mdot
.33256 .52803 Mdot
.38282 .52072 Mdot
.36683 .33617 Mdot
.61295 .42222 Mdot
.49925 .63277 Mdot
.48302 .64506 Mdot
.58859 .47228 Mdot
.8333 .57261 Mdot
.39216 .36279 Mdot
.545 .68672 Mdot
.37973 .80576 Mdot
.68384 .37983 Mdot
.69641 .69469 Mdot
.20222 .55978 Mdot
.35863 .50339 Mdot
.61659 .44917 Mdot
.36546 .37961 Mdot
.4264 .65626 Mdot
.5119 .63269 Mdot
.66102 .3925 Mdot
.36354 .53395 Mdot
.63617 .64229 Mdot
.459 .67033 Mdot
.58052 .67359 Mdot
.57565 .42469 Mdot
.57497 .76328 Mdot
.45095 .63625 Mdot
.185 .38773 Mdot
.43921 .69125 Mdot
.39648 .39567 Mdot
.62414 .37897 Mdot
.39753 .34354 Mdot
.64847 .62871 Mdot
.55038 .53704 Mdot
.36186 .53184 Mdot
.58422 .3226 Mdot
.70227 .78198 Mdot
.47945 .6696 Mdot
.36286 .34963 Mdot
.56359 .43713 Mdot
.54478 .49505 Mdot
.59588 .42487 Mdot
.57637 .3353 Mdot
.67892 .61877 Mdot
.38501 .55659 Mdot
.38326 .56992 Mdot
.63053 .40447 Mdot
.611 .62094 Mdot
.45977 .63959 Mdot
.49954 .6467 Mdot
.2811 .24044 Mdot
.3508 .60829 Mdot
.73722 .59855 Mdot
.58105 .41111 Mdot
.52659 .66323 Mdot
.2647 .6308 Mdot
.35935 .55966 Mdot
.63436 .44763 Mdot
.47531 .67463 Mdot
.53964 .78424 Mdot
.776 .55555 Mdot
.62459 .42961 Mdot
.64467 .45396 Mdot
.39582 .56173 Mdot
.69801 .48122 Mdot
.51185 .6245 Mdot
.5987 .34733 Mdot
.40666 .56605 Mdot
.81017 .50464 Mdot
.45837 .8178 Mdot
.41392 .37819 Mdot
.50972 .74231 Mdot
.37529 .54018 Mdot
.61098 .47696 Mdot
.62313 .62898 Mdot
.46176 .67606 Mdot
.50996 .66883 Mdot
.64089 .37869 Mdot
.57081 .44986 Mdot
.69983 .63121 Mdot
.37318 .34251 Mdot
.36818 .51508 Mdot
.58656 .38618 Mdot
.28514 .39596 Mdot
.57095 .43915 Mdot
.38992 .54277 Mdot
.45973 .8932 Mdot
.56788 .37611 Mdot
.59731 .42721 Mdot
.4131 .21009 Mdot
.40643 .35331 Mdot
.37027 .33877 Mdot
.67872 .75536 Mdot
.58105 .412 Mdot
.68088 .71145 Mdot
.41417 .37359 Mdot
.39524 .36362 Mdot
.32089 .6402 Mdot
.62 .39444 Mdot
.72019 .3314 Mdot
.36956 .57058 Mdot
.38896 .52673 Mdot
.38575 .35509 Mdot
.55997 .38321 Mdot
.38891 .51861 Mdot
.56618 .22258 Mdot
.47424 .64126 Mdot
.8234 .55955 Mdot
.40109 .35689 Mdot
.48727 .46061 Mdot
.36469 .56051 Mdot
.1493 .60478 Mdot
.43159 .61974 Mdot
.59257 .38001 Mdot
.57987 .4193 Mdot
.6181 .61219 Mdot
.56699 .3784 Mdot
.53134 .64344 Mdot
.37091 .54757 Mdot
.38659 .2543 Mdot
.41213 .38702 Mdot
.59671 .41443 Mdot
.23764 .40435 Mdot
.24723 .5554 Mdot
.43614 .75726 Mdot
.38579 .37003 Mdot
.39276 .39904 Mdot
.51199 .6256 Mdot
.46155 .62446 Mdot
.6156 .42782 Mdot
.34173 .54411 Mdot
.36205 .38533 Mdot
.38971 .55215 Mdot
.5202 .66155 Mdot
.49881 .63063 Mdot
.5011 .68007 Mdot
.54604 .3814 Mdot
.48572 .62596 Mdot
.60373 .66694 Mdot
.2546 .4315 Mdot
.39246 .32863 Mdot
.55472 .82337 Mdot
.28269 .50042 Mdot
.3995 .45355 Mdot
.64492 .59083 Mdot
.46666 .66276 Mdot
.34441 .56091 Mdot
.63701 .40956 Mdot
.6007 .44346 Mdot
.50875 .60909 Mdot
.35408 .56846 Mdot
.64957 .62077 Mdot
.36911 .57504 Mdot
.63558 .63669 Mdot
.53799 .76254 Mdot
.55662 .40545 Mdot
.64869 .42153 Mdot
.3751 .54698 Mdot
.48166 .62707 Mdot
.49334 .65965 Mdot
.60285 .62703 Mdot
.47948 .40905 Mdot
.48924 .67513 Mdot
.40194 .35923 Mdot
.54244 .24176 Mdot
.44223 .65094 Mdot
.58817 .41104 Mdot
.75612 .4603 Mdot
.65326 .26661 Mdot
.63806 .35563 Mdot
.31549 .64329 Mdot
.73298 .31159 Mdot
.56874 .40154 Mdot
.73391 .29768 Mdot
.34273 .70299 Mdot
.39958 .34649 Mdot
.49035 .62146 Mdot
.4485 .62466 Mdot
.58958 .33602 Mdot
.60141 .59512 Mdot
.57493 .46665 Mdot
.4104 .35843 Mdot
.41127 .42141 Mdot
.55545 .79383 Mdot
.33212 .26154 Mdot
.63292 .59664 Mdot
.65512 .61117 Mdot
.49358 .63653 Mdot
.44466 .15989 Mdot
.58633 .48495 Mdot
.64906 .6141 Mdot
.71944 .39104 Mdot
.64746 .39005 Mdot
.73849 .54907 Mdot
.64288 .74211 Mdot
.38134 .35982 Mdot
.63843 .537 Mdot
.50098 .63808 Mdot
.38162 .34112 Mdot
.29575 .40604 Mdot
.58125 .36786 Mdot
.41197 .3813 Mdot
.39114 .55191 Mdot
.41724 .69547 Mdot
.41878 .37294 Mdot
.75766 .47282 Mdot
.34225 .52922 Mdot
.5255 .58177 Mdot
.67426 .53104 Mdot
.9 .50233 Mdot
.37262 .54208 Mdot
.47888 .68101 Mdot
.48423 .64522 Mdot
.49895 .64531 Mdot
.37765 .34003 Mdot
.4562 .64918 Mdot
.36785 .34566 Mdot
.54284 .16912 Mdot
.48256 .40467 Mdot
.64827 .60973 Mdot
.30532 .62938 Mdot
.38123 .38944 Mdot
.79594 .6496 Mdot
.77583 .71787 Mdot
.61307 .45053 Mdot
.3349 .54643 Mdot
.64452 .60254 Mdot
.24098 .32423 Mdot
.626 .60805 Mdot
.59963 .57753 Mdot
.82578 .51776 Mdot
.60233 .41684 Mdot
.51734 .30748 Mdot
.65678 .60553 Mdot
.37638 .37348 Mdot
.62701 .40668 Mdot
.41234 .50875 Mdot
.62609 .6122 Mdot
.63051 .63968 Mdot
.62064 .42042 Mdot
.40758 .40505 Mdot
.50562 .63674 Mdot
.38146 .58017 Mdot
.66167 .64329 Mdot
.44196 .36769 Mdot
.60384 .3578 Mdot
.61907 .36447 Mdot
.53641 .56532 Mdot
.58699 .63708 Mdot
.36906 .54636 Mdot
.67767 .2603 Mdot
.46984 .6226 Mdot
.48077 .71469 Mdot
.63994 .76383 Mdot
.3197 .6567 Mdot
.4707 .65538 Mdot
.46852 .6614 Mdot
.62209 .42813 Mdot
.5992 .64923 Mdot
.82065 .47729 Mdot
.3816 .48858 Mdot
.43979 .64835 Mdot
.49999 .64938 Mdot
.42153 .41569 Mdot
.56747 .79494 Mdot
.56842 .46028 Mdot
.3688 .51072 Mdot
.50922 .67217 Mdot
.44047 .33751 Mdot
.62937 .61991 Mdot
.80128 .62245 Mdot
.55789 .40347 Mdot
.59017 .38396 Mdot
.35853 .5438 Mdot
.39146 .53926 Mdot
.42397 .58878 Mdot
.62237 .77839 Mdot
.71352 .29869 Mdot
.27515 .5279 Mdot
.47757 .36663 Mdot
.42467 .41005 Mdot
.37029 .3947 Mdot
.28801 .59229 Mdot
.33275 .5241 Mdot
.5713 .40021 Mdot
.36262 .38195 Mdot
.42298 .72928 Mdot
.32224 .3345 Mdot
.73624 .57256 Mdot
.70297 .67289 Mdot
.61219 .37109 Mdot
.37198 .35796 Mdot
.4045 .35324 Mdot
.36728 .40134 Mdot
.34175 .69936 Mdot
.60708 .43 Mdot
.60444 .37985 Mdot
.56417 .417 Mdot
.69803 .41443 Mdot
.58331 .43607 Mdot
.31407 .49904 Mdot
.51075 .53155 Mdot
.40595 .29185 Mdot
.58851 .35059 Mdot
.37432 .50808 Mdot
.60365 .36247 Mdot
.61258 .62404 Mdot
.64471 .39715 Mdot
.73987 .57477 Mdot
.34897 .54461 Mdot
.44947 .40569 Mdot
.28944 .50652 Mdot
.58262 .37701 Mdot
.65295 .64113 Mdot
.43873 .43609 Mdot
.20577 .62004 Mdot
.59479 .59765 Mdot
.40133 .35866 Mdot
.47007 .64611 Mdot
.34571 .5614 Mdot
.49109 .63036 Mdot
.54481 .38573 Mdot
.29717 .5965 Mdot
.22211 .50644 Mdot
.51628 .50321 Mdot
.58946 .44629 Mdot
.6627 .45033 Mdot
.39958 .36226 Mdot
.45886 .65634 Mdot
.34176 .32854 Mdot
.57492 .40215 Mdot
.64178 .6316 Mdot
.62264 .614 Mdot
.40243 .48871 Mdot
.18185 .46895 Mdot
.3404 .46749 Mdot
.36128 .54582 Mdot
.5003 .66759 Mdot
.61853 .59371 Mdot
.2973 .33495 Mdot
.37982 .58831 Mdot
.34027 .54517 Mdot
.34966 .52487 Mdot
.64635 .37363 Mdot
.49342 .68198 Mdot
.40394 .28612 Mdot
.52772 .65835 Mdot
.61184 .3792 Mdot
.51512 .65919 Mdot
.4799 .67473 Mdot
.61715 .61926 Mdot
.36031 .51587 Mdot
.52493 .6475 Mdot
.64114 .42911 Mdot
.41576 .39079 Mdot
.47663 .43379 Mdot
.76738 .53646 Mdot
.31467 .28519 Mdot
.3456 .28751 Mdot
.42343 .38404 Mdot
.15495 .5327 Mdot
.34456 .50946 Mdot
.70363 .42111 Mdot
.38331 .735 Mdot
.6581 .40101 Mdot
.80996 .6427 Mdot
.46069 .62225 Mdot
.46772 .67359 Mdot
.6319 .42849 Mdot
.47286 .7304 Mdot
.5972 .41823 Mdot
.52139 .64901 Mdot
.56543 .66922 Mdot
.65537 .34611 Mdot
.46781 .63225 Mdot
.59662 .34652 Mdot
.62457 .39233 Mdot
.37996 .35909 Mdot
.44784 .63572 Mdot
.6307 .45106 Mdot
.24293 .29367 Mdot
.38744 .53451 Mdot
.3454 .69036 Mdot
.76396 .43654 Mdot
.37611 .53915 Mdot
.40789 .39103 Mdot
.60346 .47395 Mdot
.61945 .60534 Mdot
.37743 .38898 Mdot
.77999 .55739 Mdot
.65866 .61208 Mdot
.79821 .65492 Mdot
.39605 .35327 Mdot
.44196 .64756 Mdot
.62145 .62969 Mdot
.63601 .34881 Mdot
.46442 .67745 Mdot
.4166 .45847 Mdot
.46829 .65353 Mdot
.60007 .43695 Mdot
.29279 .61997 Mdot
.37455 .51669 Mdot
.6067 .39355 Mdot
.45729 .66675 Mdot
.30854 .64997 Mdot
.64541 .37372 Mdot
.63268 .41562 Mdot
.51228 .80924 Mdot
.76199 .67142 Mdot
.6333 .60435 Mdot
.35637 .39331 Mdot
.63399 .43665 Mdot
.63783 .64013 Mdot
.58213 .73421 Mdot
.61496 .36042 Mdot
.39452 .41841 Mdot
.63593 .48394 Mdot
.44882 .6453 Mdot
.38004 .53532 Mdot
.50848 .4987 Mdot
.63835 .64137 Mdot
.7459 .25483 Mdot
.52007 .6691 Mdot
.65066 .43152 Mdot
.59136 .44888 Mdot
.43104 .77023 Mdot
.39586 .34607 Mdot
.72244 .31918 Mdot
.58256 .42147 Mdot
.69926 .403 Mdot
.59866 .40227 Mdot
.55546 .65622 Mdot
.39308 .36462 Mdot
.59617 .43064 Mdot
.25462 .39993 Mdot
.66539 .38338 Mdot
.64462 .64261 Mdot
.44324 .19127 Mdot
.61302 .35581 Mdot
.58639 .86974 Mdot
.67258 .70978 Mdot
.46908 .6307 Mdot
.28606 .59792 Mdot
.43113 .13506 Mdot
.30038 .50041 Mdot
.36423 .34997 Mdot
.2062 .53883 Mdot
.4997 .63248 Mdot
.27222 .6052 Mdot
.15132 .53321 Mdot
.62733 .39201 Mdot
.59973 .36427 Mdot
.60526 .57464 Mdot
.52962 .63227 Mdot
.4939 .69236 Mdot
.55734 .37043 Mdot
.5658 .47511 Mdot
.50178 .62865 Mdot
.63416 .44013 Mdot
.55779 .36373 Mdot
.37193 .57936 Mdot
.42201 .38884 Mdot
.37863 .5645 Mdot
.34935 .51781 Mdot
.53264 .19496 Mdot
.6011 .77962 Mdot
.38781 .53853 Mdot
.35474 .50842 Mdot
.74183 .55152 Mdot
.69911 .59249 Mdot
.63292 .58795 Mdot
.19306 .4048 Mdot
.49636 .64633 Mdot
.60789 .42683 Mdot
.42147 .36798 Mdot
.68174 .28692 Mdot
.64023 .71007 Mdot
.82643 .48368 Mdot
.57278 .4018 Mdot
.50358 .64403 Mdot
.34067 .69908 Mdot
.53183 .42783 Mdot
.46283 .69629 Mdot
.58607 .3832 Mdot
.5003 .68894 Mdot
.52528 .26638 Mdot
.2474 .3808 Mdot
.48463 .69141 Mdot
.41628 .33766 Mdot
.58914 .39092 Mdot
.40183 .35584 Mdot
.37122 .56081 Mdot
.61259 .61751 Mdot
.63651 .60676 Mdot
.62619 .4136 Mdot
.68833 .40837 Mdot
.55161 .76272 Mdot
.62043 .38966 Mdot
.64302 .38922 Mdot
.34269 .70313 Mdot
.64173 .39233 Mdot
.58147 .44247 Mdot
.57082 .43334 Mdot
.66152 .42429 Mdot
.38501 .52277 Mdot
.23925 .40269 Mdot
.53756 .41684 Mdot
.53509 .397 Mdot
.39833 .57048 Mdot
.209 .59638 Mdot
.34306 .51851 Mdot
.17094 .5887 Mdot
.37849 .5686 Mdot
.64448 .61249 Mdot
.34897 .73784 Mdot
.67937 .42686 Mdot
.39571 .4108 Mdot
.35641 .57906 Mdot
.64285 .63522 Mdot
.36937 .5524 Mdot
.51831 .64544 Mdot
.40418 .8047 Mdot
.40877 .32586 Mdot
.73863 .3818 Mdot
.3825 .4707 Mdot
.36144 .62073 Mdot
.5266 .64971 Mdot
.39063 .35933 Mdot
.57448 .278 Mdot
.57612 .44133 Mdot
.63639 .63925 Mdot
.6193 .42534 Mdot
.377 .5153 Mdot
.49991 .6399 Mdot
.4437 .18546 Mdot
.61936 .60315 Mdot
.5588 .81687 Mdot
.49068 .65458 Mdot
.56335 .42591 Mdot
.37159 .51155 Mdot
.60996 .81281 Mdot
.38257 .56138 Mdot
.59803 .31017 Mdot
.43205 .38035 Mdot
.57899 .19544 Mdot
.38637 .39222 Mdot
.42932 .67112 Mdot
.4402 .84629 Mdot
.24391 .346 Mdot
.41011 .40239 Mdot
.40035 .61123 Mdot
.61688 .36792 Mdot
.61636 .36444 Mdot
.30295 .31955 Mdot
.35838 .39648 Mdot
.60678 .45056 Mdot
.34933 .71036 Mdot
.2504 .46024 Mdot
.70728 .69983 Mdot
.4635 .65461 Mdot
.59258 .41957 Mdot
.40398 .56706 Mdot
.3652 .57302 Mdot
.52195 .66868 Mdot
.33811 .52309 Mdot
.60579 .38151 Mdot
.3828 .38991 Mdot
.52117 .68467 Mdot
.64048 .61902 Mdot
.29619 .25809 Mdot
.60786 .59727 Mdot
.47148 .65575 Mdot
.66299 .35898 Mdot
.49811 .6301 Mdot
.47608 .10674 Mdot
.60052 .38165 Mdot
.41223 .37099 Mdot
.64107 .41344 Mdot
.59207 .39272 Mdot
.60006 .36356 Mdot
.51236 .63636 Mdot
.73797 .34274 Mdot
.63836 .43444 Mdot
.36193 .53047 Mdot
.42712 .3115 Mdot
.59683 .36241 Mdot
.55575 .67157 Mdot
.71172 .58041 Mdot
.41709 .62165 Mdot
.42398 .3676 Mdot
.46197 .64169 Mdot
.41185 .39262 Mdot
.34296 .31942 Mdot
.40797 .39059 Mdot
.46369 .32732 Mdot
.56307 .27552 Mdot
.7538 .35649 Mdot
.43174 .22198 Mdot
.62609 .51337 Mdot
.35719 .39462 Mdot
.6555 .57056 Mdot
.36798 .39516 Mdot
.40085 .35147 Mdot
.2685 .81031 Mdot
.3869 .40736 Mdot
.58577 .41447 Mdot
.57461 .37764 Mdot
.25123 .52308 Mdot
.7314 .51867 Mdot
.63687 .40136 Mdot
.63711 .42901 Mdot
.61404 .61633 Mdot
.69141 .37081 Mdot
.29804 .60078 Mdot
.75442 .69695 Mdot
.25155 .57297 Mdot
.62092 .42248 Mdot
.6378 .432 Mdot
.546 .45783 Mdot
.60489 .83647 Mdot
.57918 .21368 Mdot
.37402 .419 Mdot
.60922 .47865 Mdot
.28571 .29288 Mdot
.58373 .37892 Mdot
.64117 .36463 Mdot
.61287 .36996 Mdot
.49987 .63294 Mdot
.41215 .41457 Mdot
.58694 .47783 Mdot
.63764 .75422 Mdot
.59124 .37249 Mdot
.31715 .65354 Mdot
.54607 .1497 Mdot
.59021 .42332 Mdot
.41944 .40735 Mdot
.63199 .36821 Mdot
.38982 .34853 Mdot
.37291 .36916 Mdot
.6686 .37685 Mdot
.47126 .3574 Mdot
.42234 .40863 Mdot
.61246 .37881 Mdot
.51082 .64157 Mdot
.18235 .41387 Mdot
.59788 .43724 Mdot
.61149 .60371 Mdot
.58051 .41829 Mdot
.65406 .64234 Mdot
.63912 .38774 Mdot
.51781 .67298 Mdot
.65058 .27681 Mdot
.4889 .63588 Mdot
.6201 .19924 Mdot
.49887 .68344 Mdot
.52179 .8104 Mdot
.38148 .41856 Mdot
.2976 .62568 Mdot
.80579 .38837 Mdot
.33596 .67628 Mdot
.47749 .56126 Mdot
.47776 .53183 Mdot
.34129 .54321 Mdot
.40121 .34496 Mdot
.70403 .45342 Mdot
.43012 .74731 Mdot
.41555 .75273 Mdot
.48783 .67777 Mdot
.8066 .35872 Mdot
.83679 .49941 Mdot
.64905 .41305 Mdot
.4992 .31944 Mdot
.44888 .26409 Mdot
.61517 .35798 Mdot
.60909 .47458 Mdot
.52955 .61789 Mdot
.60345 .45415 Mdot
.28084 .39259 Mdot
.47613 .65779 Mdot
.64148 .63619 Mdot
.40647 .36375 Mdot
.63065 .64264 Mdot
.42475 .74771 Mdot
.47479 .53323 Mdot
.52098 .65472 Mdot
.66549 .40705 Mdot
.63865 .41981 Mdot
.3812 .35358 Mdot
.34154 .35947 Mdot
.38378 .40301 Mdot
.63337 .59783 Mdot
.47936 .65515 Mdot
.63463 .24777 Mdot
.62874 .43799 Mdot
.38219 .37981 Mdot
.45498 .5585 Mdot
.62837 .44184 Mdot
.37701 .55166 Mdot
.60588 .37078 Mdot
.41591 .39553 Mdot
.64154 .39228 Mdot
.38363 .39266 Mdot
.47078 .64304 Mdot
.56906 .38951 Mdot
.6283 .43027 Mdot
.58598 .81929 Mdot
.64842 .62139 Mdot
.36521 .40985 Mdot
.48618 .73675 Mdot
.57996 .44775 Mdot
.3509 .64179 Mdot
.58531 .39191 Mdot
.32066 .3524 Mdot
.65945 .41687 Mdot
.32962 .68194 Mdot
.5627 .45317 Mdot
.59761 .43634 Mdot
.42394 .50868 Mdot
.45016 .2837 Mdot
.3468 .38042 Mdot
.37588 .51166 Mdot
.38625 .41176 Mdot
.71082 .67923 Mdot
.43508 .64778 Mdot
.45525 .65237 Mdot
.71475 .47713 Mdot
.65734 .43541 Mdot
.6031 .41846 Mdot
.39756 .57847 Mdot
.65839 .62213 Mdot
.38415 .37118 Mdot
.63636 .63646 Mdot
.65051 .75992 Mdot
.64754 .59961 Mdot
.48757 .61534 Mdot
.57363 .76155 Mdot
.60392 .23725 Mdot
.61438 .61633 Mdot
.40743 .40572 Mdot
.67479 .67798 Mdot
.65897 .38641 Mdot
.69005 .63526 Mdot
.63927 .63079 Mdot
.79773 .32936 Mdot
.58385 .44306 Mdot
.48316 .56437 Mdot
.3859 .54167 Mdot
.62117 .62704 Mdot
.34452 .5441 Mdot
.63493 .4056 Mdot
.34233 .62357 Mdot
.35996 .36685 Mdot
.39633 .53012 Mdot
.58412 .35802 Mdot
.64773 .60525 Mdot
.50633 .67283 Mdot
.34718 .57744 Mdot
.38624 .51653 Mdot
.19766 .56488 Mdot
.49391 .16913 Mdot
.4807 .65379 Mdot
.78423 .59812 Mdot
.37266 .57104 Mdot
.62541 .35644 Mdot
.6965 .36739 Mdot
.59234 .37962 Mdot
.32485 .48595 Mdot
.46039 .64492 Mdot
.23861 .48354 Mdot
.64205 .41509 Mdot
.56797 .41567 Mdot
.34934 .39004 Mdot
.48666 .64167 Mdot
.39676 .38316 Mdot
.38085 .40866 Mdot
.47241 .64266 Mdot
.39466 .39437 Mdot
.66014 .61343 Mdot
.25885 .46201 Mdot
.39036 .5699 Mdot
.35759 .53007 Mdot
.50031 .64801 Mdot
.47442 .62703 Mdot
.4874 .62814 Mdot
.60551 .37084 Mdot
.38863 .36723 Mdot
.62824 .37962 Mdot
.60165 .36398 Mdot
.48462 .38084 Mdot
.42519 .38272 Mdot
.62499 .37159 Mdot
.45311 .70328 Mdot
.65679 .65666 Mdot
.51291 .64453 Mdot
.38617 .53786 Mdot
.27566 .64712 Mdot
.32575 .51322 Mdot
.5922 .4164 Mdot
.53628 .78218 Mdot
.39872 .40599 Mdot
.621 .60938 Mdot
.64284 .58663 Mdot
.62777 .60589 Mdot
.39773 .51551 Mdot
.36339 .40236 Mdot
.75843 .69362 Mdot
.59574 .42047 Mdot
.53559 .56671 Mdot
.7226 .39021 Mdot
.54332 .76898 Mdot
.38555 .53475 Mdot
.63398 .43567 Mdot
.50322 .48604 Mdot
.59413 .26869 Mdot
.59245 .38343 Mdot
.65108 .36468 Mdot
.36253 .71509 Mdot
.60997 .49436 Mdot
.43365 .39105 Mdot
.64931 .77679 Mdot
.55396 .40408 Mdot
.4058 .31611 Mdot
.33636 .21264 Mdot
.59049 .40746 Mdot
.5721 .4124 Mdot
.611 .44334 Mdot
.64682 .3973 Mdot
.42619 .40048 Mdot
.69896 .50989 Mdot
.34217 .51129 Mdot
.55383 .56813 Mdot
.39791 .56468 Mdot
.48 .68519 Mdot
.24166 .41876 Mdot
.40494 .3457 Mdot
.61799 .61162 Mdot
.22989 .38264 Mdot
.70189 .74444 Mdot
.50806 .62344 Mdot
.54888 .22265 Mdot
.64407 .62725 Mdot
.631 .3565 Mdot
.66332 .63192 Mdot
.49139 .682 Mdot
.36235 .52491 Mdot
.65502 .44092 Mdot
.37444 .39822 Mdot
.41794 .36949 Mdot
.60991 .45068 Mdot
.2729 .30933 Mdot
.37945 .54804 Mdot
.3822 .59058 Mdot
.6325 .3622 Mdot
.62625 .34808 Mdot
.39995 .38414 Mdot
.49994 .66085 Mdot
.75209 .61546 Mdot
.65501 .62007 Mdot
.59604 .4578 Mdot
.64696 .3925 Mdot
.62881 .77683 Mdot
.37071 .52246 Mdot
.50186 .61839 Mdot
.64987 .3826 Mdot
.28065 .54989 Mdot
.64971 .38288 Mdot
.55126 .47007 Mdot
.51001 .64305 Mdot
.54368 .43029 Mdot
.64596 .4251 Mdot
.61389 .32075 Mdot
.35466 .56033 Mdot
.41137 .37501 Mdot
.38284 .32571 Mdot
.58626 .54991 Mdot
.37547 .55314 Mdot
.62836 .37026 Mdot
.37471 .52787 Mdot
.60933 .36213 Mdot
.61067 .45199 Mdot
.38971 .54262 Mdot
.39655 .38389 Mdot
.21348 .54952 Mdot
.239 .40992 Mdot
.64682 .40028 Mdot
.55153 .41937 Mdot
.71426 .50858 Mdot
.77115 .3799 Mdot
.57732 .39692 Mdot
.41849 .38645 Mdot
.63161 .43304 Mdot
.34801 .54882 Mdot
.64976 .59777 Mdot
.41562 .39279 Mdot
.49115 .6639 Mdot
.52079 .62937 Mdot
.29288 .50296 Mdot
.47231 .66858 Mdot
.65507 .38141 Mdot
.34527 .31751 Mdot
.36166 .33591 Mdot
.31964 .2341 Mdot
.47625 .64223 Mdot
.65689 .60203 Mdot
.63164 .41405 Mdot
.51211 .79564 Mdot
.39734 .58159 Mdot
.62961 .85692 Mdot
.78674 .66799 Mdot
.60095 .60258 Mdot
.8184 .44798 Mdot
.4848 .68845 Mdot
.62298 .45156 Mdot
.61208 .61804 Mdot
.5059 .62387 Mdot
.65621 .39772 Mdot
.66301 .43253 Mdot
.72652 .32291 Mdot
.56725 .54573 Mdot
.37539 .52661 Mdot
.45691 .63471 Mdot
.6325 .57893 Mdot
.50969 .61828 Mdot
.41722 .36303 Mdot
.59928 .43384 Mdot
.6833 .39283 Mdot
.49582 .66374 Mdot
.52737 .62887 Mdot
.61428 .37347 Mdot
.39871 .3438 Mdot
.50478 .60981 Mdot
.62171 .41563 Mdot
.63701 .50395 Mdot
.42397 .35059 Mdot
.47816 .66204 Mdot
.56886 .4259 Mdot
.67623 .65786 Mdot
.49416 .65594 Mdot
.51376 .64657 Mdot
.61147 .45116 Mdot
.66125 .61757 Mdot
.55497 .42609 Mdot
.38562 .56683 Mdot
.70129 .26642 Mdot
.3456 .54138 Mdot
.65413 .68538 Mdot
.65197 .35137 Mdot
.32589 .59544 Mdot
.41508 .3545 Mdot
.59156 .5918 Mdot
.29583 .68829 Mdot
.56196 .3644 Mdot
.17168 .48796 Mdot
.48477 .46638 Mdot
.26416 .29961 Mdot
.29351 .72737 Mdot
.63304 .62773 Mdot
.36808 .55493 Mdot
.57246 .41168 Mdot
.34452 .56386 Mdot
.61024 .61063 Mdot
.60459 .19975 Mdot
.5714 .43182 Mdot
.3948 .36475 Mdot
.60859 .37495 Mdot
.40081 .35737 Mdot
.62071 .44777 Mdot
.53269 .42346 Mdot
.33928 .70804 Mdot
.77565 .55416 Mdot
.65898 .39874 Mdot
.42652 .8219 Mdot
.64259 .73043 Mdot
.64886 .63118 Mdot
.62502 .38335 Mdot
.43028 .65299 Mdot
.35669 .56866 Mdot
.30391 .3669 Mdot
.50147 .63295 Mdot
.34972 .51373 Mdot
.40241 .38979 Mdot
.4651 .64904 Mdot
.52722 .63535 Mdot
.54981 .43926 Mdot
.64413 .64452 Mdot
.35564 .52156 Mdot
.59331 .43191 Mdot
.57543 .43484 Mdot
.76446 .62449 Mdot
.6276 .70546 Mdot
.3528 .33498 Mdot
.68079 .78771 Mdot
.37795 .32869 Mdot
.6506 .6168 Mdot
.50647 .63599 Mdot
.58123 .39562 Mdot
.60901 .3938 Mdot
.30145 .63544 Mdot
.35828 .37401 Mdot
.5474 .5335 Mdot
.51113 .20213 Mdot
.51479 .61357 Mdot
.71702 .55806 Mdot
.41269 .36698 Mdot
.71839 .55616 Mdot
.64285 .58288 Mdot
.21081 .39614 Mdot
.76226 .56552 Mdot
.38417 .53804 Mdot
.71434 .55462 Mdot
.37526 .37807 Mdot
.64616 .41536 Mdot
.44101 .64387 Mdot
.47953 .67397 Mdot
.4056 .37686 Mdot
.53779 .65678 Mdot
.61862 .61998 Mdot
.57316 .42152 Mdot
.75273 .69089 Mdot
.29825 .46966 Mdot
.5037 .66524 Mdot
.5304 .41095 Mdot
.34842 .52646 Mdot
.60394 .45193 Mdot
.61402 .60169 Mdot
.3711 .53745 Mdot
.67956 .70096 Mdot
.24514 .47165 Mdot
.62936 .40992 Mdot
.54254 .80401 Mdot
.37408 .54842 Mdot
.7987 .43814 Mdot
.61566 .42234 Mdot
.37112 .57041 Mdot
.59669 .48869 Mdot
.42314 .69794 Mdot
.51033 .49167 Mdot
.15062 .53055 Mdot
.52528 .51772 Mdot
.44832 .66171 Mdot
.40749 .66999 Mdot
.39948 .71297 Mdot
.34643 .56483 Mdot
.52494 .62634 Mdot
.58386 .6411 Mdot
.34424 .54447 Mdot
.59513 .36403 Mdot
.58732 .39733 Mdot
.58124 .21114 Mdot
.47988 .47372 Mdot
.42974 .68348 Mdot
.32936 .44319 Mdot
.57647 .445 Mdot
.55581 .3932 Mdot
.61084 .40045 Mdot
.41185 .42062 Mdot
.36922 .52578 Mdot
.50022 .82855 Mdot
.3765 .55567 Mdot
.79609 .62393 Mdot
.4972 .64497 Mdot
.45806 .64083 Mdot
.59016 .41993 Mdot
.51269 .585 Mdot
.67214 .54937 Mdot
.60795 .38172 Mdot
.55952 .5965 Mdot
.42587 .2002 Mdot
.58428 .3606 Mdot
.42908 .37238 Mdot
.57722 .34056 Mdot
.44159 .39539 Mdot
.38939 .57109 Mdot
.63231 .62036 Mdot
.58718 .59916 Mdot
.36168 .52271 Mdot
.60429 .41707 Mdot
.31106 .59322 Mdot
.59683 .39318 Mdot
.65122 .4019 Mdot
.81205 .60144 Mdot
.60613 .5991 Mdot
.4754 .63279 Mdot
.62881 .60334 Mdot
.39751 .34823 Mdot
.46808 .90845 Mdot
.65784 .62667 Mdot
.66373 .54755 Mdot
.64066 .21837 Mdot
.71466 .55086 Mdot
.41564 .36286 Mdot
.62927 .64625 Mdot
.38077 .54068 Mdot
.18683 .38013 Mdot
.76119 .34141 Mdot
.32389 .54803 Mdot
.61896 .41222 Mdot
.39186 .33896 Mdot
.41763 .39923 Mdot
.39833 .53589 Mdot
.37391 .3707 Mdot
.6151 .48233 Mdot
.64707 .40693 Mdot
.33883 .55459 Mdot
.26779 .5095 Mdot
.38551 .51555 Mdot
.26583 .43014 Mdot
.62088 .38104 Mdot
.41549 .37358 Mdot
.59519 .33659 Mdot
.41689 .42758 Mdot
.49119 .6173 Mdot
.61431 .35456 Mdot
.6177 .61818 Mdot
.31683 .58269 Mdot
.4832 .65479 Mdot
.52667 .77903 Mdot
.38405 .35271 Mdot
.41767 .59584 Mdot
.37783 .3606 Mdot
.35439 .38686 Mdot
.34619 .51901 Mdot
.3625 .36636 Mdot
.57188 .41496 Mdot
.43564 .6796 Mdot
.37942 .34688 Mdot
.35264 .54185 Mdot
.63467 .61586 Mdot
.39376 .39129 Mdot
.47023 .72976 Mdot
.62951 .4219 Mdot
.51451 .63343 Mdot
.36827 .75036 Mdot
.36508 .34061 Mdot
.61243 .63521 Mdot
.4583 .65662 Mdot
.62734 .63923 Mdot
.38579 .20379 Mdot
.33086 .52854 Mdot
.82323 .50496 Mdot
.65959 .66159 Mdot
.3923 .40824 Mdot
.35071 .73672 Mdot
.58216 .39873 Mdot
.63113 .41929 Mdot
.65234 .6462 Mdot
.41729 .39974 Mdot
.22251 .36301 Mdot
.41119 .44307 Mdot
.25291 .47712 Mdot
.3322 .54768 Mdot
.49017 .81617 Mdot
.26554 .41025 Mdot
.47952 .14925 Mdot
.55401 .38393 Mdot
.49144 .6909 Mdot
.5987 .41159 Mdot
.28463 .67186 Mdot
.64383 .60248 Mdot
.53382 .69199 Mdot
.66469 .37367 Mdot
.46737 .64041 Mdot
.61582 .43676 Mdot
.41686 .48873 Mdot
.56134 .35569 Mdot
.65164 .59614 Mdot
.29508 .60173 Mdot
.38866 .40936 Mdot
.64173 .6219 Mdot
.51805 .66922 Mdot
.68976 .55528 Mdot
.65596 .41113 Mdot
.54199 .39329 Mdot
.50485 .61101 Mdot
.39158 .36135 Mdot
.44608 .64721 Mdot
.38714 .57086 Mdot
.62368 .61755 Mdot
.6379 .41 Mdot
.66211 .41299 Mdot
.35248 .64404 Mdot
.35201 .521 Mdot
.53641 .64938 Mdot
.3804 .56151 Mdot
.4797 .68852 Mdot
.55355 .43485 Mdot
.45708 .64253 Mdot
.63758 .44194 Mdot
.31331 .69667 Mdot
.81067 .59923 Mdot
.46643 .29703 Mdot
.46119 .64824 Mdot
.72511 .58715 Mdot
.35045 .54854 Mdot
.37642 .56727 Mdot
.63693 .23348 Mdot
.64261 .30273 Mdot
.73984 .67146 Mdot
.19721 .59872 Mdot
.39689 .56581 Mdot
.34744 .53153 Mdot
.51376 .63113 Mdot
.36448 .35725 Mdot
.35387 .35795 Mdot
.49288 .68879 Mdot
.75744 .44991 Mdot
.38412 .37138 Mdot
.18455 .43829 Mdot
.71598 .6847 Mdot
.58146 .47475 Mdot
.43723 .58176 Mdot
.62629 .61384 Mdot
.75522 .47585 Mdot
.4152 .49086 Mdot
.5689 .41076 Mdot
.61586 .78003 Mdot
.50254 .65545 Mdot
.7076 .47152 Mdot
.17244 .58954 Mdot
.57396 .4361 Mdot
.60975 .42646 Mdot
.60628 .40956 Mdot
.59822 .60963 Mdot
.66651 .29958 Mdot
.57288 .42931 Mdot
.75906 .44471 Mdot
.58446 .45118 Mdot
.50937 .42952 Mdot
.63434 .60527 Mdot
.52649 .46271 Mdot
.3533 .71829 Mdot
.67202 .74561 Mdot
.63373 .32926 Mdot
.38486 .57064 Mdot
.57324 .58211 Mdot
.35731 .56359 Mdot
.46158 .31951 Mdot
.76232 .56022 Mdot
.40265 .33016 Mdot
.57017 .40958 Mdot
.47198 .65648 Mdot
.41885 .39699 Mdot
.39293 .66962 Mdot
.36927 .88601 Mdot
.37791 .57359 Mdot
.53141 .12503 Mdot
.38158 .56552 Mdot
.52969 .64242 Mdot
.40133 .38403 Mdot
.55648 .27342 Mdot
.53461 .56306 Mdot
.392 .39277 Mdot
.22101 .51805 Mdot
.35582 .40875 Mdot
.71703 .57443 Mdot
.38258 .33213 Mdot
.35173 .54453 Mdot
.38847 .50851 Mdot
.65716 .44834 Mdot
.58237 .40983 Mdot
.47114 .52725 Mdot
.69088 .57298 Mdot
.58138 .40375 Mdot
.47696 .65617 Mdot
.79793 .41034 Mdot
.60979 .55426 Mdot
.36574 .37716 Mdot
.34856 .50423 Mdot
.61034 .4294 Mdot
.64881 .386 Mdot
.65418 .4101 Mdot
.69716 .78535 Mdot
.21205 .38684 Mdot
.63808 .4345 Mdot
.57366 .44615 Mdot
.46566 .64644 Mdot
.67017 .61148 Mdot
.27351 .66668 Mdot
.51954 .37223 Mdot
.57066 .39241 Mdot
.64345 .61631 Mdot
.60567 .59709 Mdot
.65643 .39582 Mdot
.63489 .75256 Mdot
.34416 .60885 Mdot
.59352 .43251 Mdot
.62887 .30573 Mdot
.41751 .73262 Mdot
.52857 .63141 Mdot
.49402 .66204 Mdot
.41452 .40928 Mdot
.47373 .66656 Mdot
.50315 .68344 Mdot
.56868 .25862 Mdot
.52703 .52739 Mdot
.40958 .53885 Mdot
.63216 .5975 Mdot
.6057 .39261 Mdot
.35404 .33713 Mdot
.28475 .56363 Mdot
.3406 .53364 Mdot
.39677 .40281 Mdot
.36128 .57011 Mdot
.60064 .62992 Mdot
.73541 .38893 Mdot
.4888 .67947 Mdot
.39803 .549 Mdot
.24583 .47015 Mdot
.64179 .61307 Mdot
.3576 .51478 Mdot
.31846 .60287 Mdot
.59172 .36325 Mdot
.52177 .32541 Mdot
.61216 .38245 Mdot
.24447 .32658 Mdot
.36329 .51558 Mdot
.32423 .67529 Mdot
.60148 .42433 Mdot
.49232 .65379 Mdot
.56759 .48223 Mdot
.58419 .38363 Mdot
.49062 .66818 Mdot
.64845 .41391 Mdot
.60694 .61765 Mdot
.42519 .34901 Mdot
.5607 .56416 Mdot
.86938 .48963 Mdot
.64296 .64502 Mdot
.38556 .66046 Mdot
.57542 .39837 Mdot
.45023 .17944 Mdot
.39187 .3904 Mdot
.64785 .43261 Mdot
.64881 .52997 Mdot
.37445 .34398 Mdot
.4062 .39905 Mdot
.63869 .37591 Mdot
.38525 .54463 Mdot
.48313 .65783 Mdot
.6375 .60855 Mdot
.38853 .19463 Mdot
.62204 .4034 Mdot
.62993 .43141 Mdot
.64313 .62562 Mdot
.34567 .53577 Mdot
.64526 .37628 Mdot
.38276 .76666 Mdot
.24961 .2934 Mdot
.33874 .53944 Mdot
.58534 .37203 Mdot
.51721 .34363 Mdot
.44573 .38371 Mdot
.67317 .21168 Mdot
.68816 .6678 Mdot
.46745 .63501 Mdot
.61187 .49117 Mdot
.51615 .89234 Mdot
.63231 .61834 Mdot
.71591 .72088 Mdot
.65258 .39431 Mdot
.62121 .44348 Mdot
.38697 .40349 Mdot
.62614 .37551 Mdot
.36666 .34368 Mdot
.85865 .46546 Mdot
.62046 .78498 Mdot
.39389 .3564 Mdot
.37697 .40202 Mdot
.64747 .53994 Mdot
.27553 .66713 Mdot
.40683 .37888 Mdot
.56894 .44744 Mdot
.34776 .29762 Mdot
.57439 .33046 Mdot
.65767 .64357 Mdot
.39585 .74543 Mdot
.44566 .40822 Mdot
.64576 .5715 Mdot
.20337 .56124 Mdot
.45044 .39875 Mdot
.37182 .60977 Mdot
.39071 .56458 Mdot
.56769 .43062 Mdot
.47635 .67204 Mdot
.45555 .65028 Mdot
.58235 .34374 Mdot
.6003 .38902 Mdot
.39233 .34903 Mdot
.63059 .5951 Mdot
.35309 .56966 Mdot
.6369 .42863 Mdot
.61293 .55667 Mdot
.65662 .62611 Mdot
.36817 .36267 Mdot
.70622 .31969 Mdot
.65289 .59625 Mdot
.5367 .38099 Mdot
.58434 .42791 Mdot
.61235 .37102 Mdot
.6007 .3186 Mdot
.38826 .53283 Mdot
.34106 .72805 Mdot
.5615 .3951 Mdot
.65075 .76065 Mdot
.47385 .42029 Mdot
.54711 .44866 Mdot
.38073 .36645 Mdot
.39884 .58071 Mdot
.44683 .62828 Mdot
.68067 .49109 Mdot
.62755 .40623 Mdot
.23504 .36622 Mdot
.54808 .20162 Mdot
.4717 .61909 Mdot
.35705 .39249 Mdot
.62321 .60816 Mdot
.60672 .38292 Mdot
.44947 .33005 Mdot
.58797 .40351 Mdot
.62925 .65602 Mdot
.51091 .65068 Mdot
.39075 .56304 Mdot
.26116 .2978 Mdot
.45548 .64938 Mdot
.41079 .3945 Mdot
.13643 .58874 Mdot
.38594 .33475 Mdot
.36747 .3991 Mdot
.46238 .35018 Mdot
.39256 .54115 Mdot
.54299 .89353 Mdot
.74495 .30012 Mdot
.6378 .35105 Mdot
.35419 .55497 Mdot
.40263 .37172 Mdot
.59997 .45038 Mdot
.41426 .3484 Mdot
.36275 .40375 Mdot
.54906 .42451 Mdot
.59981 .44495 Mdot
.24588 .41387 Mdot
.15652 .54718 Mdot
.62274 .60596 Mdot
.40538 .35177 Mdot
.66293 .48804 Mdot
.59504 .44951 Mdot
.59575 .42126 Mdot
.4146 .71649 Mdot
.66042 .61277 Mdot
.29404 .38725 Mdot
.65132 .39038 Mdot
.5912 .79702 Mdot
.57978 .33952 Mdot
.42837 .39799 Mdot
.3386 .53379 Mdot
.67558 .73852 Mdot
.3698 .47899 Mdot
.35874 .36576 Mdot
.62041 .59791 Mdot
.37849 .32542 Mdot
.66433 .54998 Mdot
.38909 .5248 Mdot
.41591 .39557 Mdot
.50762 .49669 Mdot
.36496 .53929 Mdot
.37032 .51808 Mdot
.42601 .31165 Mdot
.527 .67137 Mdot
.60043 .61348 Mdot
.35314 .52334 Mdot
.69948 .43116 Mdot
.35872 .55004 Mdot
.66048 .25862 Mdot
.56961 .38812 Mdot
.73495 .44914 Mdot
.4729 .57375 Mdot
.67283 .43746 Mdot
.37712 .51755 Mdot
.61247 .60736 Mdot
.64182 .37537 Mdot
.373 .37597 Mdot
.64615 .63697 Mdot
.34146 .57609 Mdot
.50317 .63003 Mdot
.37594 .35961 Mdot
.32764 .5324 Mdot
.41018 .36069 Mdot
.7019 .45937 Mdot
.67921 .23994 Mdot
.42649 .7864 Mdot
.535 .55837 Mdot
.65408 .40783 Mdot
.22611 .62568 Mdot
.56929 .46557 Mdot
.59671 .38603 Mdot
.47834 .66073 Mdot
.71576 .47207 Mdot
.39725 .38333 Mdot
.24922 .30503 Mdot
.39662 .55765 Mdot
.64686 .77895 Mdot
.33053 .34744 Mdot
.65238 .42656 Mdot
.38045 .34573 Mdot
.38657 .33385 Mdot
.44158 .27914 Mdot
.46039 .61859 Mdot
.62198 .46794 Mdot
.62007 .47063 Mdot
.54248 .40153 Mdot
.37351 .52128 Mdot
.53591 .77934 Mdot
.45582 .66989 Mdot
.6628 .21719 Mdot
.50862 .65692 Mdot
.55997 .59277 Mdot
.36352 .36734 Mdot
.65904 .62596 Mdot
.5949 .4232 Mdot
.33978 .37146 Mdot
.35786 .3677 Mdot
.64418 .65584 Mdot
.62101 .62823 Mdot
.42663 .71181 Mdot
.38949 .54112 Mdot
.66032 .39834 Mdot
.56919 .42549 Mdot
.63109 .38212 Mdot
.60148 .37451 Mdot
.38172 .57372 Mdot
.62281 .36295 Mdot
.40568 .55417 Mdot
.71317 .38078 Mdot
.60254 .78481 Mdot
.51938 .51948 Mdot
.32153 .37743 Mdot
.36925 .37833 Mdot
.67281 .47102 Mdot
.52967 .39357 Mdot
.8174 .57361 Mdot
.35654 .25221 Mdot
.59215 .35751 Mdot
.49975 .62237 Mdot
.65124 .30785 Mdot
.47986 .67824 Mdot
.59983 .14099 Mdot
.34912 .64858 Mdot
.15753 .51804 Mdot
.58099 .43798 Mdot
.41813 .7239 Mdot
.69508 .42057 Mdot
.587 .47165 Mdot
.38238 .67803 Mdot
.32787 .48082 Mdot
.23919 .52147 Mdot
.62811 .59032 Mdot
.62522 .42157 Mdot
.34891 .35147 Mdot
.57181 .41855 Mdot
.59625 .41595 Mdot
.65286 .38918 Mdot
.35833 .5093 Mdot
.62691 .46364 Mdot
.60061 .36963 Mdot
.55102 .75832 Mdot
.73738 .55865 Mdot
.45415 .63721 Mdot
.62382 .22279 Mdot
.65558 .6303 Mdot
.38528 .34887 Mdot
.20363 .47011 Mdot
.38407 .53718 Mdot
.44268 .27089 Mdot
.60608 .37245 Mdot
.2412 .44103 Mdot
.3298 .54866 Mdot
.62134 .61824 Mdot
.44318 .65588 Mdot
.16224 .47333 Mdot
.47319 .6518 Mdot
.50149 .48668 Mdot
.48881 .65141 Mdot
.56017 .34696 Mdot
.3936 .34933 Mdot
.65341 .38485 Mdot
.35507 .52435 Mdot
.48226 .66706 Mdot
.72439 .51002 Mdot
.60952 .4018 Mdot
.47274 .64163 Mdot
.65288 .38394 Mdot
.73835 .39333 Mdot
.79198 .57128 Mdot
.51092 .67954 Mdot
.40824 .54986 Mdot
.35952 .53781 Mdot
.66034 .61531 Mdot
.37649 .35299 Mdot
.38104 .39956 Mdot
.37048 .5395 Mdot
.77347 .3626 Mdot
.57394 .38986 Mdot
.5944 .44797 Mdot
.65572 .76102 Mdot
.57585 .40698 Mdot
.70382 .56961 Mdot
.50582 .48907 Mdot
.36772 .37027 Mdot
.62254 .45051 Mdot
.64832 .3885 Mdot
.63028 .41233 Mdot
.71821 .42599 Mdot
.50021 .66355 Mdot
.5615 .41365 Mdot
.62134 .63084 Mdot
.43061 .66534 Mdot
.60249 .45222 Mdot
.54076 .40632 Mdot
.38316 .40037 Mdot
.70507 .75916 Mdot
.38609 .56169 Mdot
.52389 .65769 Mdot
.4595 .64237 Mdot
.39936 .7448 Mdot
.46628 .39377 Mdot
.51034 .49641 Mdot
.63365 .19734 Mdot
.345 .70791 Mdot
.64841 .62778 Mdot
.42661 .59754 Mdot
.48423 .42561 Mdot
.52062 .63327 Mdot
.37337 .57502 Mdot
.56805 .38811 Mdot
.5704 .3915 Mdot
.80645 .64128 Mdot
.65762 .4179 Mdot
.6264 .6101 Mdot
.40355 .55386 Mdot
.37605 .37863 Mdot
.62058 .61662 Mdot
.37586 .5656 Mdot
.38962 .36093 Mdot
.5774 .36966 Mdot
.57025 .37847 Mdot
.39593 .40171 Mdot
.41225 .40371 Mdot
.5892 .42877 Mdot
.55839 .62888 Mdot
.3959 .412 Mdot
.41737 .37487 Mdot
.48934 .67999 Mdot
.48102 .67344 Mdot
.54999 .44216 Mdot
.36002 .55819 Mdot
.60632 .36604 Mdot
.4675 .65172 Mdot
.64444 .59715 Mdot
.392 .3845 Mdot
.6478 .39886 Mdot
.6404 .42269 Mdot
.64073 .61307 Mdot
.62745 .59233 Mdot
.62013 .62401 Mdot
.39618 .52411 Mdot
.62882 .38888 Mdot
.40597 .38565 Mdot
.39156 .54813 Mdot
.60468 .59769 Mdot
.66465 .62307 Mdot
.54096 .63546 Mdot
.5804 .39396 Mdot
.42547 .64837 Mdot
.45352 .8977 Mdot
.69737 .65143 Mdot
.46201 .62052 Mdot
.53175 .62465 Mdot
.72402 .53797 Mdot
.53305 .58459 Mdot
.37708 .54456 Mdot
.60919 .65493 Mdot
.58985 .59387 Mdot
.61553 .35528 Mdot
.55378 .4081 Mdot
.62067 .47294 Mdot
.6276 .62952 Mdot
.68372 .49947 Mdot
.41277 .34907 Mdot
.47115 .20326 Mdot
.65238 .63343 Mdot
.52853 .62984 Mdot
.53073 .66727 Mdot
.50944 .6558 Mdot
.56747 .38581 Mdot
.46736 .29161 Mdot
.58081 .50831 Mdot
.22592 .63594 Mdot
.36685 .51433 Mdot
.37747 .32247 Mdot
.41655 .19822 Mdot
.40067 .40082 Mdot
.48499 .68493 Mdot
.64058 .63553 Mdot
.41852 .39258 Mdot
.34905 .55936 Mdot
.34951 .52895 Mdot
.50453 .66267 Mdot
.50077 .64588 Mdot
.51954 .64525 Mdot
.36437 .4001 Mdot
.36307 .36515 Mdot
.62649 .4016 Mdot
.38358 .38557 Mdot
.77474 .6923 Mdot
.59779 .62177 Mdot
.53203 .62299 Mdot
.36922 .5566 Mdot
.39908 .35598 Mdot
.61101 .39816 Mdot
.58718 .55694 Mdot
.3166 .47686 Mdot
.62198 .63616 Mdot
.7751 .60554 Mdot
.5977 .14273 Mdot
.66142 .40257 Mdot
.37296 .52326 Mdot
.75152 .68894 Mdot
.60872 .40855 Mdot
.50586 .63853 Mdot
.31516 .70824 Mdot
.43483 .64837 Mdot
.60165 .36439 Mdot
.65986 .37906 Mdot
.33764 .52467 Mdot
.61066 .19581 Mdot
.62342 .39851 Mdot
.29926 .40784 Mdot
.34128 .50554 Mdot
.46109 .67394 Mdot
.23246 .30588 Mdot
.42772 .76745 Mdot
.75485 .46576 Mdot
.49224 .68008 Mdot
.59106 .39261 Mdot
.49087 .67743 Mdot
.61527 .62876 Mdot
.51183 .67128 Mdot
.43061 .37281 Mdot
.44923 .64366 Mdot
.62886 .43267 Mdot
.40775 .37666 Mdot
.3747 .54912 Mdot
.66467 .77309 Mdot
.61182 .73784 Mdot
.49342 .65331 Mdot
.52177 .66755 Mdot
.64155 .4323 Mdot
.27765 .38535 Mdot
.59484 .34481 Mdot
.58581 .44301 Mdot
.39893 .55606 Mdot
.37613 .34726 Mdot
.34636 .51052 Mdot
.62432 .45703 Mdot
.37059 .76453 Mdot
.38319 .55824 Mdot
.23662 .43728 Mdot
.6449 .62753 Mdot
.43151 .47904 Mdot
.60786 .39129 Mdot
.34344 .52903 Mdot
.62775 .38823 Mdot
.41681 .35213 Mdot
.46766 .48137 Mdot
.28463 .59326 Mdot
.35821 .52547 Mdot
.24384 .34024 Mdot
.55254 .61386 Mdot
.66009 .35246 Mdot
.36768 .56907 Mdot
.64554 .53035 Mdot
.52812 .63663 Mdot
.6542 .62216 Mdot
.61285 .59347 Mdot
.63424 .64213 Mdot
.57814 .35489 Mdot
.64019 .33511 Mdot
.60473 .60843 Mdot
.34367 .55502 Mdot
.64551 .59136 Mdot
.41794 .3231 Mdot
.22511 .35921 Mdot
.64294 .60312 Mdot
.61803 .41906 Mdot
.65603 .33028 Mdot
.73821 .55027 Mdot
.43638 .70196 Mdot
.16471 .50814 Mdot
.3116 .36552 Mdot
.58375 .40901 Mdot
.42689 .34297 Mdot
.41924 .36346 Mdot
.73687 .69644 Mdot
.70258 .59026 Mdot
.65752 .74213 Mdot
.37468 .40197 Mdot
.29575 .62287 Mdot
.37013 .36073 Mdot
.65582 .41752 Mdot
.59943 .44876 Mdot
.35376 .36703 Mdot
.5589 .7873 Mdot
.35867 .63452 Mdot
.29983 .25852 Mdot
.41602 .36795 Mdot
.35296 .55925 Mdot
.40049 .56406 Mdot
.3748 .51861 Mdot
.72129 .67813 Mdot
.37474 .33862 Mdot
.6347 .39256 Mdot
.46273 .65083 Mdot
.56391 .40558 Mdot
.36682 .53259 Mdot
.24751 .30764 Mdot
.3764 .39204 Mdot
.5966 .43546 Mdot
.76975 .38452 Mdot
.49786 .6363 Mdot
.64572 .61702 Mdot
.73376 .35873 Mdot
.68229 .70332 Mdot
.39028 .53124 Mdot
.3674 .33722 Mdot
.32209 .66205 Mdot
.23052 .43117 Mdot
.55653 .38557 Mdot
.56162 .46563 Mdot
.43881 .16371 Mdot
.68104 .6981 Mdot
.64684 .36749 Mdot
.52756 .6465 Mdot
.30303 .63938 Mdot
.64166 .41199 Mdot
.41317 .35646 Mdot
.62804 .58699 Mdot
.6335 .63945 Mdot
.57753 .45934 Mdot
.53629 .56862 Mdot
.43673 .45381 Mdot
.62732 .36944 Mdot
.53568 .38238 Mdot
.47585 .68011 Mdot
.34776 .70916 Mdot
.64602 .76762 Mdot
.6206 .59677 Mdot
.64994 .38024 Mdot
.22708 .55991 Mdot
.35896 .38616 Mdot
.45395 .62937 Mdot
.38619 .51959 Mdot
.72397 .3828 Mdot
.46 .67384 Mdot
.64302 .41097 Mdot
.64651 .37902 Mdot
.3536 .51472 Mdot
.42866 .39756 Mdot
.63036 .6313 Mdot
.46008 .64925 Mdot
.61736 .59746 Mdot
.37465 .34204 Mdot
.37583 .38702 Mdot
.55533 .34143 Mdot
.67658 .38978 Mdot
.49201 .66238 Mdot
.60878 .45786 Mdot
.48734 .73529 Mdot
.60116 .18651 Mdot
.35743 .57978 Mdot
.66196 .40098 Mdot
.41819 .41624 Mdot
.36171 .52409 Mdot
.60997 .44629 Mdot
.40126 .18209 Mdot
.59266 .45043 Mdot
.35413 .47672 Mdot
.41823 .79072 Mdot
.61399 .61153 Mdot
.4478 .20789 Mdot
.29244 .32962 Mdot
.57559 .41228 Mdot
.47901 .62514 Mdot
.53804 .44415 Mdot
.3833 .54481 Mdot
.36467 .37466 Mdot
.67428 .20914 Mdot
.35647 .54574 Mdot
.57571 .42879 Mdot
.62276 .61756 Mdot
.37682 .3342 Mdot
.56783 .61268 Mdot
.62996 .75812 Mdot
.62405 .33846 Mdot
.57699 .45398 Mdot
.61229 .36679 Mdot
.31277 .73163 Mdot
.5234 .6576 Mdot
.40246 .36431 Mdot
.37479 .5231 Mdot
.37258 .53883 Mdot
.50376 .66006 Mdot
.24996 .50732 Mdot
.43364 .47782 Mdot
.46253 .88457 Mdot
.49076 .67038 Mdot
.62037 .64234 Mdot
.28852 .39242 Mdot
.47485 .6251 Mdot
.47739 .63986 Mdot
.474 .67877 Mdot
.38527 .49298 Mdot
.38883 .3641 Mdot
.64236 .42104 Mdot
.42399 .36719 Mdot
.59003 .38925 Mdot
.46945 .41696 Mdot
.3583 .52246 Mdot
.36437 .38119 Mdot
.41164 .18049 Mdot
.60647 .2943 Mdot
.61125 .41487 Mdot
.43414 .18765 Mdot
.65792 .36174 Mdot
.70039 .54055 Mdot
.67164 .39758 Mdot
.4954 .64866 Mdot
.66042 .47023 Mdot
.55118 .37385 Mdot
.70508 .74641 Mdot
.3696 .55803 Mdot
.52355 .62823 Mdot
.63167 .35334 Mdot
.56202 .34904 Mdot
.3524 .37623 Mdot
.41897 .38717 Mdot
.60696 .60375 Mdot
.7788 .5494 Mdot
.37609 .55096 Mdot
.70779 .28067 Mdot
.58214 .41433 Mdot
.48674 .7945 Mdot
.43798 .22074 Mdot
.60869 .44545 Mdot
.30005 .30944 Mdot
.45812 .28346 Mdot
.60688 .38538 Mdot
.60195 .52734 Mdot
.34659 .53788 Mdot
.38162 .77183 Mdot
.57631 .44951 Mdot
.5022 .63449 Mdot
.3665 .35697 Mdot
.40769 .34622 Mdot
.60562 .61135 Mdot
.83865 .52726 Mdot
.34903 .5108 Mdot
.3637 .37736 Mdot
.60538 .40271 Mdot
.39166 .53658 Mdot
.46914 .66481 Mdot
.64868 .43726 Mdot
.70958 .59702 Mdot
.38164 .38255 Mdot
.58601 .45492 Mdot
.29893 .44013 Mdot
.76033 .51015 Mdot
.23815 .70011 Mdot
.37915 .52421 Mdot
.65303 .6021 Mdot
.54205 .45018 Mdot
.73497 .32936 Mdot
.58733 .35762 Mdot
.73166 .44906 Mdot
.4559 .36489 Mdot
.65294 .60116 Mdot
.60624 .42371 Mdot
.63717 .40518 Mdot
.48362 .57138 Mdot
.62939 .59391 Mdot
.56886 .42817 Mdot
.69027 .34369 Mdot
.39258 .36271 Mdot
.44996 .66824 Mdot
.38147 .3763 Mdot
.61847 .413 Mdot
.67568 .40722 Mdot
.39617 .40666 Mdot
.56489 .15508 Mdot
.60636 .58899 Mdot
.38728 .55849 Mdot
.66853 .3641 Mdot
.55766 .40532 Mdot
.43107 .8316 Mdot
.49619 .61774 Mdot
.25589 .63172 Mdot
.53493 .7394 Mdot
.21628 .56821 Mdot
.4305 .76728 Mdot
.14074 .56032 Mdot
.62366 .77855 Mdot
.61309 .47082 Mdot
.37115 .44351 Mdot
.57697 .5118 Mdot
.37714 .51612 Mdot
.60738 .24514 Mdot
.58239 .40908 Mdot
.59695 .41361 Mdot
.4549 .62711 Mdot
.23634 .48012 Mdot
.65189 .75066 Mdot
.55814 .57706 Mdot
.6326 .63108 Mdot
.40249 .35144 Mdot
.62537 .44512 Mdot
.56241 .53069 Mdot
.45522 .63443 Mdot
.49711 .7942 Mdot
.60043 .43345 Mdot
.81366 .57452 Mdot
.30558 .50761 Mdot
.38881 .53556 Mdot
.46122 .636 Mdot
.67448 .71615 Mdot
.58156 .39024 Mdot
.39089 .52322 Mdot
.6191 .39729 Mdot
.49681 .59758 Mdot
.62263 .45568 Mdot
.64999 .60814 Mdot
.65429 .39861 Mdot
.56638 .58372 Mdot
.18017 .64489 Mdot
.60049 .64575 Mdot
.3954 .34071 Mdot
.48843 .6118 Mdot
.4985 .66316 Mdot
.41572 .39814 Mdot
.49662 .66112 Mdot
.44353 .24684 Mdot
.53836 .26686 Mdot
.63933 .63239 Mdot
.54727 .36599 Mdot
.63667 .60139 Mdot
.48699 .61697 Mdot
.58386 .39974 Mdot
.59831 .17119 Mdot
.48541 .66415 Mdot
.43836 .81284 Mdot
.36277 .55141 Mdot
.51188 .62144 Mdot
.58363 .45133 Mdot
.32977 .6639 Mdot
.45378 .64507 Mdot
.28709 .59341 Mdot
.62994 .41084 Mdot
.37355 .38263 Mdot
.64031 .40513 Mdot
.66368 .36188 Mdot
.50159 .69248 Mdot
.59503 .37188 Mdot
.37562 .56555 Mdot
.3857 .41165 Mdot
.1849 .4101 Mdot
.33154 .48338 Mdot
.56821 .41519 Mdot
.60622 .40467 Mdot
.35717 .33981 Mdot
.55984 .41607 Mdot
.38208 .57354 Mdot
.76953 .76103 Mdot
.64529 .62705 Mdot
.5252 .66518 Mdot
.42321 .76875 Mdot
.58947 .35956 Mdot
.63171 .36637 Mdot
.37578 .19728 Mdot
.41922 .77521 Mdot
.37086 .56856 Mdot
.56162 .36066 Mdot
.46098 .65703 Mdot
.62394 .61607 Mdot
.34165 .55371 Mdot
.61338 .37134 Mdot
.59818 .42376 Mdot
.6538 .60418 Mdot
.39412 .29963 Mdot
.70767 .70169 Mdot
.35848 .51317 Mdot
.67236 .45593 Mdot
.50777 .72273 Mdot
.57822 .38688 Mdot
.73329 .67193 Mdot
.41696 .39013 Mdot
.39564 .53924 Mdot
.2486 .64895 Mdot
.63776 .36135 Mdot
.33948 .53584 Mdot
.37552 .55295 Mdot
.55861 .36526 Mdot
.40124 .42716 Mdot
.37314 .41075 Mdot
.40911 .35931 Mdot
.79394 .68105 Mdot
.74982 .49903 Mdot
.51944 .64509 Mdot
.34615 .53641 Mdot
.50349 .6841 Mdot
.62752 .64762 Mdot
.50381 .47441 Mdot
.51613 .67503 Mdot
.42176 .39236 Mdot
.46585 .61408 Mdot
.63534 .40903 Mdot
.37544 .54727 Mdot
.52126 .63605 Mdot
.62296 .35038 Mdot
.26497 .38386 Mdot
.41972 .6719 Mdot
.66207 .61135 Mdot
.62225 .58752 Mdot
.60545 .45054 Mdot
.44271 .6315 Mdot
.5897 .42706 Mdot
.38186 .58215 Mdot
.27896 .39391 Mdot
.59731 .35305 Mdot
.49573 .65423 Mdot
.42275 .33587 Mdot
.68154 .70347 Mdot
.62586 .34414 Mdot
.61677 .41951 Mdot
.58817 .38443 Mdot
.61915 .3965 Mdot
.22895 .50381 Mdot
.33635 .55576 Mdot
.33967 .42306 Mdot
.34804 .73227 Mdot
.38693 .39445 Mdot
.38833 .42168 Mdot
.69567 .67473 Mdot
.3731 .61236 Mdot
.3566 .55597 Mdot
.59717 .38241 Mdot
.28427 .5492 Mdot
.24132 .31485 Mdot
.5235 .13809 Mdot
.6822 .64337 Mdot
.4783 .61917 Mdot
.3626 .34128 Mdot
.45985 .63231 Mdot
.58959 .39595 Mdot
.548 .46033 Mdot
.13773 .56229 Mdot
.35981 .4977 Mdot
.63687 .63498 Mdot
.59021 .38539 Mdot
.75382 .49109 Mdot
.46488 .64728 Mdot
.51853 .68108 Mdot
.57172 .43508 Mdot
.41882 .41119 Mdot
.33548 .78296 Mdot
.38598 .53021 Mdot
.30998 .36883 Mdot
.68076 .45459 Mdot
.33028 .43099 Mdot
.3686 .52805 Mdot
.6347 .74423 Mdot
.4554 .62423 Mdot
.40047 .26109 Mdot
.38513 .39563 Mdot
.64698 .63554 Mdot
.5521 .45589 Mdot
.37735 .4 Mdot
.45243 .66748 Mdot
.36808 .3799 Mdot
.65565 .3956 Mdot
.33128 .5247 Mdot
.46838 .63308 Mdot
.4024 .52537 Mdot
.39806 .42656 Mdot
.618 .6012 Mdot
.46921 .54854 Mdot
.61045 .26861 Mdot
.45452 .28002 Mdot
.56248 .40482 Mdot
.55925 .52661 Mdot
.63373 .38875 Mdot
.35637 .40493 Mdot
.61359 .39806 Mdot
.39469 .31661 Mdot
.4724 .62748 Mdot
.5742 .4468 Mdot
.62083 .36757 Mdot
.59557 .22802 Mdot
.60855 .4337 Mdot
.62404 .4613 Mdot
.60414 .38263 Mdot
.34182 .3352 Mdot
.5453 .37215 Mdot
.38235 .3641 Mdot
.59673 .76223 Mdot
.4808 .63939 Mdot
.62238 .58877 Mdot
.65226 .6384 Mdot
.73728 .4533 Mdot
.57211 .65038 Mdot
.24196 .49959 Mdot
.38822 .37486 Mdot
.37754 .56043 Mdot
.61527 .39493 Mdot
.19987 .61415 Mdot
.40792 .72832 Mdot
.46322 .66449 Mdot
.33089 .48365 Mdot
.6354 .48093 Mdot
.31854 .74143 Mdot
.59508 .45648 Mdot
.81814 .62201 Mdot
.68029 .40094 Mdot
.62857 .45186 Mdot
.50451 .68696 Mdot
.5949 .59993 Mdot
.56569 .43196 Mdot
.35222 .37383 Mdot
.65564 .61552 Mdot
.3751 .43988 Mdot
.47025 .70564 Mdot
.60639 .75256 Mdot
.56699 .24011 Mdot
.62533 .39064 Mdot
.47107 .63179 Mdot
.37707 .35845 Mdot
.64322 .77065 Mdot
.39169 .55108 Mdot
.38858 .60115 Mdot
.66293 .48503 Mdot
.48975 .16023 Mdot
.65614 .62765 Mdot
.41658 .30731 Mdot
.63038 .43217 Mdot
.66181 .68596 Mdot
.55596 .39507 Mdot
.24429 .3145 Mdot
.62552 .64469 Mdot
.39788 .4183 Mdot
.35517 .56035 Mdot
.42195 .3658 Mdot
.45879 .29356 Mdot
.4435 .57896 Mdot
.48832 .52117 Mdot
.47249 .64882 Mdot
.41467 .49572 Mdot
.40633 .37063 Mdot
.64467 .37291 Mdot
.45555 .88632 Mdot
.41794 .3809 Mdot
.36047 .35163 Mdot
.6427 .21638 Mdot
.59945 .18242 Mdot
.63947 .48156 Mdot
.38801 .4069 Mdot
.47635 .64657 Mdot
.62171 .60346 Mdot
.64293 .39547 Mdot
.62981 .40064 Mdot
.38332 .40153 Mdot
.51308 .68433 Mdot
.52754 .34288 Mdot
.49902 .64575 Mdot
.39216 .3599 Mdot
.48884 .63545 Mdot
.32051 .67743 Mdot
.51701 .6283 Mdot
.55765 .40683 Mdot
.61401 .39709 Mdot
.51339 .73723 Mdot
.37582 .38661 Mdot
.63049 .37111 Mdot
.64824 .41688 Mdot
.40565 .383 Mdot
.62748 .56408 Mdot
.50495 .35829 Mdot
.57235 .40254 Mdot
.62605 .42446 Mdot
.65001 .59842 Mdot
.5176 .48672 Mdot
.81336 .49001 Mdot
.6417 .37541 Mdot
.59878 .61808 Mdot
.36378 .39689 Mdot
.59117 .43233 Mdot
.21373 .40909 Mdot
.30169 .6376 Mdot
.64356 .36678 Mdot
.52626 .63335 Mdot
.54517 .38693 Mdot
.26862 .72582 Mdot
.58411 .44285 Mdot
.40196 .37735 Mdot
.36869 .34741 Mdot
.69576 .27585 Mdot
.41317 .38948 Mdot
.47965 .67388 Mdot
.3656 .53656 Mdot
.2478 .32227 Mdot
.46856 .66412 Mdot
.61735 .34689 Mdot
.74332 .29629 Mdot
.6456 .44509 Mdot
.61125 .35017 Mdot
.36526 .78561 Mdot
.46757 .66094 Mdot
.38666 .34529 Mdot
.51219 .57418 Mdot
.64138 .45999 Mdot
.3905 .53074 Mdot
.53595 .42784 Mdot
.57909 .37768 Mdot
.42406 .79263 Mdot
.27018 .59245 Mdot
.39696 .57162 Mdot
.59257 .47743 Mdot
.64045 .37392 Mdot
.42702 .64109 Mdot
.60838 .39835 Mdot
.62761 .5981 Mdot
.37822 .34004 Mdot
.48844 .62276 Mdot
.63963 .61544 Mdot
.57869 .4104 Mdot
.62577 .62821 Mdot
.5149 .63405 Mdot
.39348 .52986 Mdot
.58568 .39373 Mdot
.65815 .64354 Mdot
.62987 .62931 Mdot
.63465 .38456 Mdot
.36442 .3708 Mdot
.6817 .41278 Mdot
.59453 .43746 Mdot
.64954 .39956 Mdot
.37995 .39875 Mdot
.46607 .12094 Mdot
.58935 .44742 Mdot
.55471 .61795 Mdot
.359 .35927 Mdot
.4258 .53225 Mdot
.48592 .62155 Mdot
.57498 .38108 Mdot
.3993 .54462 Mdot
.34789 .52379 Mdot
.48484 .68194 Mdot
.37845 .33216 Mdot
.52819 .73926 Mdot
.41553 .32903 Mdot
.66527 .42796 Mdot
.66351 .4144 Mdot
.76945 .33878 Mdot
.15343 .51327 Mdot
.40933 .35007 Mdot
.52674 .67826 Mdot
.55521 .57169 Mdot
.34527 .54243 Mdot
.53607 .63776 Mdot
.36803 .33578 Mdot
.37419 .33722 Mdot
.36938 .37304 Mdot
.63955 .63893 Mdot
.52415 .72778 Mdot
.43135 .39379 Mdot
.41536 .41225 Mdot
.63192 .41083 Mdot
.63697 .37101 Mdot
.67387 .57444 Mdot
.73211 .59875 Mdot
.61239 .60324 Mdot
.50752 .65475 Mdot
.71753 .78685 Mdot
.38141 .58133 Mdot
.58233 .2205 Mdot
.5981 .35331 Mdot
.42346 .90787 Mdot
.59222 .45368 Mdot
.60531 .39947 Mdot
.38466 .41032 Mdot
.66463 .63133 Mdot
.64439 .60807 Mdot
.40586 .36411 Mdot
.35945 .40887 Mdot
.62934 .59795 Mdot
.32853 .27457 Mdot
.21561 .36534 Mdot
.46607 .57843 Mdot
.39965 .38756 Mdot
.59296 .26828 Mdot
.38389 .51632 Mdot
.43985 .39854 Mdot
.36336 .578 Mdot
.46884 .64241 Mdot
.44167 .63415 Mdot
.37334 .52056 Mdot
.6286 .40942 Mdot
.52165 .65178 Mdot
.62637 .46361 Mdot
.33133 .28897 Mdot
.49994 .33332 Mdot
.45365 .75874 Mdot
.55424 .44126 Mdot
.61861 .75468 Mdot
.38493 .61873 Mdot
.57739 .42364 Mdot
.20104 .51837 Mdot
.63346 .634 Mdot
.43569 .39843 Mdot
.39412 .56974 Mdot
.2536 .72232 Mdot
.58501 .38309 Mdot
.3987 .37958 Mdot
.36919 .56014 Mdot
.72618 .40751 Mdot
.29523 .4059 Mdot
.58887 .38689 Mdot
.48473 .88922 Mdot
.33516 .35344 Mdot
.4936 .62328 Mdot
.80312 .40714 Mdot
.42295 .36166 Mdot
.68035 .62194 Mdot
.35092 .72479 Mdot
.4304 .17845 Mdot
.38624 .3491 Mdot
.53919 .63885 Mdot
.40483 .35536 Mdot
.61979 .599 Mdot
.41826 .33992 Mdot
.46151 .64216 Mdot
.60641 .42998 Mdot
.50159 .65502 Mdot
.60793 .60932 Mdot
.712 .67915 Mdot
.39886 .56615 Mdot
.52351 .62848 Mdot
.35484 .53181 Mdot
.76727 .52097 Mdot
.34289 .74045 Mdot
.39013 .56269 Mdot
.72341 .3281 Mdot
.63889 .3601 Mdot
.42927 .38406 Mdot
.50059 .67009 Mdot
.35069 .7158 Mdot
.49632 .55801 Mdot
.39456 .39713 Mdot
.51185 .64272 Mdot
.62523 .50964 Mdot
.75829 .35574 Mdot
.60074 .33431 Mdot
.77122 .54377 Mdot
.40356 .38778 Mdot
.53684 .63324 Mdot
.65672 .76109 Mdot
.42314 .38607 Mdot
.49239 .67129 Mdot
.34648 .55265 Mdot
.37208 .53436 Mdot
.5656 .42641 Mdot
.41308 .55453 Mdot
.51399 .65428 Mdot
.40839 .62402 Mdot
.35875 .38816 Mdot
.71871 .43445 Mdot
.64775 .64514 Mdot
.48779 .64247 Mdot
.65707 .42084 Mdot
.42715 .41835 Mdot
.31053 .65978 Mdot
.57075 .31309 Mdot
.66909 .8008 Mdot
.50379 .65926 Mdot
.36908 .34194 Mdot
.39483 .38156 Mdot
.62473 .34452 Mdot
.53422 .56013 Mdot
.5286 .73591 Mdot
.75793 .39347 Mdot
.72839 .44369 Mdot
.45998 .67613 Mdot
.4561 .67815 Mdot
.6446 .3577 Mdot
.62116 .38568 Mdot
.34681 .54849 Mdot
.61164 .42784 Mdot
.39055 .41508 Mdot
.56279 .42364 Mdot
.3678 .52414 Mdot
.47563 .65484 Mdot
.58602 .4008 Mdot
.61335 .60794 Mdot
.40206 .54465 Mdot
.33722 .52425 Mdot
.49052 .64775 Mdot
.37404 .39829 Mdot
.5965 .63579 Mdot
.5013 .64591 Mdot
.62523 .3916 Mdot
.32407 .58708 Mdot
.65418 .4099 Mdot
.35631 .26715 Mdot
.42303 .39077 Mdot
.46445 .6292 Mdot
.35668 .38566 Mdot
.35107 .53562 Mdot
.34682 .72993 Mdot
.61635 .40806 Mdot
.48814 .67059 Mdot
.50282 .73514 Mdot
.34965 .2829 Mdot
.34985 .3502 Mdot
.31223 .60154 Mdot
.3746 .41707 Mdot
.44337 .65246 Mdot
.64843 .23678 Mdot
.65374 .62712 Mdot
.46122 .66188 Mdot
.17187 .46296 Mdot
.49017 .6595 Mdot
.60999 .4375 Mdot
.613 .44851 Mdot
.49924 .62293 Mdot
.66139 .61842 Mdot
.62626 .78292 Mdot
.44308 .60306 Mdot
.38518 .34644 Mdot
.47295 .17846 Mdot
.58641 .83745 Mdot
.41256 .58093 Mdot
.3554 .55891 Mdot
.64057 .4616 Mdot
.63696 .44565 Mdot
.35965 .57481 Mdot
.34912 .5043 Mdot
.61793 .6351 Mdot
.47261 .67769 Mdot
.35087 .32081 Mdot
.3864 .51426 Mdot
.57554 .32868 Mdot
.57916 .65778 Mdot
.60148 .34208 Mdot
.65043 .4857 Mdot
.55425 .40334 Mdot
.73642 .43086 Mdot
.37097 .52268 Mdot
.62697 .44592 Mdot
.58595 .34291 Mdot
.39844 .54422 Mdot
.62444 .59878 Mdot
.27218 .55611 Mdot
.48744 .63126 Mdot
.27221 .2509 Mdot
.63623 .44194 Mdot
.60639 .43977 Mdot
.36863 .51475 Mdot
.54709 .7445 Mdot
.37254 .39077 Mdot
.42453 .38631 Mdot
.52429 .65431 Mdot
.47208 .54374 Mdot
.5713 .38867 Mdot
.58209 .43316 Mdot
.4871 .62788 Mdot
.51487 .62298 Mdot
.40607 .66662 Mdot
.63804 .42406 Mdot
.36498 .5578 Mdot
.572 .57875 Mdot
.36927 .52243 Mdot
.656 .41552 Mdot
.61256 .43989 Mdot
.55781 .40758 Mdot
.65789 .41703 Mdot
.33493 .52943 Mdot
.63023 .44209 Mdot
.63452 .32554 Mdot
.3668 .38731 Mdot
.59638 .3738 Mdot
.73341 .42701 Mdot
.62031 .42198 Mdot
.62305 .60174 Mdot
.59144 .3161 Mdot
.58457 .3854 Mdot
.5699 .38693 Mdot
.45645 .5995 Mdot
.60556 .41964 Mdot
.37987 .58196 Mdot
.38605 .38983 Mdot
.34619 .5349 Mdot
.35789 .51509 Mdot
.49997 .67914 Mdot
.60481 .61016 Mdot
.58807 .36118 Mdot
.62538 .63721 Mdot
.56589 .37503 Mdot
.64364 .3654 Mdot
.38472 .74311 Mdot
.82505 .60759 Mdot
.71474 .69739 Mdot
.61768 .40725 Mdot
.47686 .66517 Mdot
.47669 .62275 Mdot
.3339 .39575 Mdot
.60356 .33509 Mdot
.35562 .57149 Mdot
.34459 .52761 Mdot
.71224 .5908 Mdot
.41505 .78525 Mdot
.62337 .60078 Mdot
.53743 .51471 Mdot
.63182 .46135 Mdot
.64786 .41224 Mdot
.64517 .44176 Mdot
.50618 .68262 Mdot
.55599 .58578 Mdot
.46266 .66256 Mdot
.31367 .49444 Mdot
.36327 .52086 Mdot
.58742 .37993 Mdot
.44126 .33816 Mdot
.41998 .38692 Mdot
.38528 .38945 Mdot
.33757 .53957 Mdot
.50967 .61296 Mdot
.69574 .6207 Mdot
.56792 .14095 Mdot
.33778 .33539 Mdot
.66533 .6193 Mdot
.57424 .42013 Mdot
.48088 .65391 Mdot
.412 .35959 Mdot
.64187 .58957 Mdot
.64981 .37826 Mdot
.52222 .72932 Mdot
.62125 .40482 Mdot
.57428 .51051 Mdot
.36839 .36025 Mdot
.23297 .33363 Mdot
.39143 .33569 Mdot
.40211 .54973 Mdot
.39581 .56287 Mdot
.61316 .44562 Mdot
.78071 .36385 Mdot
.42686 .37838 Mdot
.40492 .51229 Mdot
.62403 .64321 Mdot
.31926 .65133 Mdot
.6257 .5959 Mdot
.48138 .62414 Mdot
.65679 .61951 Mdot
.46248 .6365 Mdot
.71745 .62623 Mdot
.35172 .33499 Mdot
.64294 .62248 Mdot
.52896 .60781 Mdot
.61252 .33392 Mdot
.62415 .59014 Mdot
.61951 .47449 Mdot
.41244 .22701 Mdot
.49504 .62911 Mdot
.65059 .63812 Mdot
.64534 .37446 Mdot
.17944 .6055 Mdot
.37639 .56726 Mdot
.3623 .57489 Mdot
.6654 .42622 Mdot
.48939 .68528 Mdot
.35319 .3607 Mdot
.21982 .4456 Mdot
.36538 .59025 Mdot
.59958 .44784 Mdot
.56494 .43029 Mdot
.39663 .42192 Mdot
.43512 .43044 Mdot
.61652 .44194 Mdot
.69601 .31914 Mdot
.63423 .4325 Mdot
.34661 .55494 Mdot
.41736 .35931 Mdot
.39088 .38523 Mdot
.51469 .64303 Mdot
.40136 .41068 Mdot
.33841 .3138 Mdot
.30162 .56368 Mdot
.64268 .46269 Mdot
.35557 .54293 Mdot
.30349 .52693 Mdot
.3157 .49253 Mdot
.16647 .51177 Mdot
.39688 .42366 Mdot
.5544 .41886 Mdot
.35815 .38451 Mdot
.62169 .61347 Mdot
.37656 .38301 Mdot
.35988 .345 Mdot
.5853 .427 Mdot
.59136 .39276 Mdot
.46919 .65712 Mdot
.5384 .56442 Mdot
.36472 .39071 Mdot
.61194 .45073 Mdot
.62315 .46036 Mdot
.62811 .46016 Mdot
.45712 .45208 Mdot
.4094 .3513 Mdot
.56632 .20398 Mdot
.67253 .51848 Mdot
.36536 .39183 Mdot
.29248 .75805 Mdot
.34461 .70997 Mdot
.49459 .61559 Mdot
.40953 .55827 Mdot
.63897 .42279 Mdot
.47769 .62071 Mdot
.58923 .39617 Mdot
.65195 .48481 Mdot
.59741 .4202 Mdot
.63511 .59709 Mdot
.61249 .47081 Mdot
.43985 .64502 Mdot
.50158 .64949 Mdot
.59041 .44541 Mdot
.58735 .40549 Mdot
.70585 .68827 Mdot
.36387 .41457 Mdot
.37141 .38698 Mdot
.52769 .74936 Mdot
.63534 .62394 Mdot
.39291 .53432 Mdot
.60864 .38967 Mdot
.50502 .67649 Mdot
.50268 .65236 Mdot
.42015 .3588 Mdot
.50429 .63725 Mdot
.3834 .52818 Mdot
.61401 .4064 Mdot
.36291 .57592 Mdot
.63624 .63964 Mdot
.40461 .35141 Mdot
.591 .38103 Mdot
.63191 .41137 Mdot
.36907 .34712 Mdot
.60483 .35631 Mdot
.64907 .59795 Mdot
.49281 .66 Mdot
.38459 .35176 Mdot
.36717 .53604 Mdot
.46957 .62819 Mdot
.64538 .40179 Mdot
.69899 .79308 Mdot
.61501 .43477 Mdot
.64074 .41501 Mdot
.16559 .45689 Mdot
.61419 .47145 Mdot
.50263 .66629 Mdot
.4074 .41569 Mdot
.58426 .45915 Mdot
.73587 .46773 Mdot
.49833 .12963 Mdot
.46614 .6675 Mdot
.57213 .42109 Mdot
.15156 .55837 Mdot
.57654 .43235 Mdot
.72174 .30303 Mdot
.62314 .67145 Mdot
.43169 .50811 Mdot
.67897 .38728 Mdot
.38311 .53625 Mdot
.46964 .65881 Mdot
.47789 .62603 Mdot
.52646 .18387 Mdot
.58402 .42963 Mdot
.5733 .51531 Mdot
.62235 .3609 Mdot
.3703 .52975 Mdot
.69304 .5702 Mdot
.50469 .65601 Mdot
.72698 .71724 Mdot
.63363 .39222 Mdot
.40487 .3457 Mdot
.47502 .61219 Mdot
.3352 .68928 Mdot
.64823 .39811 Mdot
.62252 .6338 Mdot
.40016 .52819 Mdot
.60014 .46682 Mdot
.36003 .54399 Mdot
.652 .40199 Mdot
.54374 .35187 Mdot
.82536 .44807 Mdot
.36629 .37139 Mdot
.35097 .55662 Mdot
.33919 .59843 Mdot
.54897 .42583 Mdot
.3846 .3502 Mdot
.38651 .39615 Mdot
.61611 .63199 Mdot
.49784 .51275 Mdot
.28745 .445 Mdot
.55653 .30705 Mdot
.51748 .17852 Mdot
.48712 .61135 Mdot
.34175 .62446 Mdot
.6447 .38839 Mdot
.48286 .78866 Mdot
.39114 .57828 Mdot
.6056 .43678 Mdot
.41853 .23927 Mdot
.41099 .36356 Mdot
.62747 .42763 Mdot
.63442 .60043 Mdot
.51767 .77992 Mdot
.50906 .7896 Mdot
.28498 .70114 Mdot
.4713 .647 Mdot
.54525 .45536 Mdot
.56471 .48378 Mdot
.52582 .65983 Mdot
.59941 .36137 Mdot
.49632 .66764 Mdot
.37826 .22471 Mdot
.65104 .59676 Mdot
.40247 .34731 Mdot
.34254 .70397 Mdot
.57859 .37314 Mdot
.66043 .42846 Mdot
.63005 .58461 Mdot
.62046 .37987 Mdot
.83646 .5366 Mdot
.42691 .73843 Mdot
.52349 .64141 Mdot
.36856 .37285 Mdot
.56812 .38486 Mdot
.51335 .5115 Mdot
.59069 .43734 Mdot
.52911 .2896 Mdot
.56861 .38773 Mdot
.29431 .42732 Mdot
.36583 .35852 Mdot
.35719 .54018 Mdot
.54441 .40236 Mdot
.59987 .41347 Mdot
.59616 .56022 Mdot
.67866 .39745 Mdot
.60484 .45389 Mdot
.35133 .35776 Mdot
.41777 .36504 Mdot
.38326 .36481 Mdot
.44871 .6473 Mdot
.4219 .78838 Mdot
.3546 .55012 Mdot
.53911 .39689 Mdot
.38233 .5111 Mdot
.6423 .29983 Mdot
.65953 .60591 Mdot
.18748 .59315 Mdot
.60591 .37307 Mdot
.38912 .36931 Mdot
.23783 .56821 Mdot
.36388 .39932 Mdot
.54379 .53225 Mdot
.3761 .55034 Mdot
.41362 .36895 Mdot
.60296 .40529 Mdot
.53262 .57256 Mdot
.23006 .65797 Mdot
.35053 .52729 Mdot
.57738 .36328 Mdot
.47716 .61873 Mdot
.4088 .76219 Mdot
.68443 .80351 Mdot
.37281 .56892 Mdot
.34191 .59772 Mdot
.58144 .42927 Mdot
.41994 .3934 Mdot
.3832 .53276 Mdot
.38471 .56408 Mdot
.50651 .63698 Mdot
.59206 .39006 Mdot
.59333 .38585 Mdot
.44309 .64314 Mdot
.34974 .52413 Mdot
.66844 .37683 Mdot
.6176 .45807 Mdot
.13556 .56932 Mdot
.66199 .49693 Mdot
.33201 .18799 Mdot
.34195 .3118 Mdot
.41588 .25517 Mdot
.22882 .40996 Mdot
.36853 .34112 Mdot
.58295 .38648 Mdot
.56072 .45517 Mdot
.51338 .65402 Mdot
.61285 .42026 Mdot
.52094 .68169 Mdot
.36083 .56038 Mdot
.28459 .74551 Mdot
.28561 .50739 Mdot
.38953 .2079 Mdot
.61036 .42196 Mdot
.35025 .47214 Mdot
.63151 .61069 Mdot
.33105 .51001 Mdot
.38657 .35726 Mdot
.6567 .39469 Mdot
.70597 .69122 Mdot
.46152 .66159 Mdot
.40204 .40264 Mdot
.65329 .75303 Mdot
.6245 .74915 Mdot
.65655 .41394 Mdot
.45086 .63879 Mdot
.2175 .53526 Mdot
.69817 .32549 Mdot
.34187 .56682 Mdot
.63122 .59652 Mdot
.46236 .65312 Mdot
.35109 .51887 Mdot
.38766 .30807 Mdot
.41574 .3791 Mdot
.39806 .3261 Mdot
.74763 .65021 Mdot
.52927 .65647 Mdot
.63538 .60932 Mdot
.41166 .78125 Mdot
.49269 .80038 Mdot
.63683 .59781 Mdot
.44361 .63359 Mdot
.41564 .36256 Mdot
.39915 .36396 Mdot
.38713 .38991 Mdot
.71068 .72911 Mdot
.38777 .33324 Mdot
.5455 .21692 Mdot
.6463 .44521 Mdot
.51386 .41519 Mdot
.57284 .42511 Mdot
.351 .56896 Mdot
.37233 .35262 Mdot
.4573 .54464 Mdot
.56923 .35888 Mdot
.27693 .70798 Mdot
.58826 .44041 Mdot
.32944 .5222 Mdot
.63341 .4241 Mdot
.58452 .23535 Mdot
.35756 .37908 Mdot
.61674 .41274 Mdot
.36298 .58014 Mdot
.62791 .62432 Mdot
.40353 .3241 Mdot
.58831 .38476 Mdot
.23962 .47342 Mdot
.61203 .47197 Mdot
.32709 .26506 Mdot
.70045 .46686 Mdot
.66526 .61911 Mdot
.7015 .39514 Mdot
.53457 .65639 Mdot
.51595 .43881 Mdot
.52744 .43521 Mdot
.35389 .52703 Mdot
.30722 .68501 Mdot
.47938 .64062 Mdot
.6751 .66104 Mdot
.53357 .40769 Mdot
.60908 .60368 Mdot
.35421 .40548 Mdot
.3395 .55567 Mdot
.64246 .35979 Mdot
.59297 .34661 Mdot
.3802 .23592 Mdot
.54407 .36894 Mdot
.56098 .4204 Mdot
.65126 .59343 Mdot
.51107 .19467 Mdot
.62418 .41877 Mdot
.53779 .5269 Mdot
.41193 .3355 Mdot
.67533 .39332 Mdot
.58981 .21626 Mdot
.60741 .45015 Mdot
.41042 .40148 Mdot
.36264 .3282 Mdot
.26204 .51991 Mdot
.6176 .63793 Mdot
.57355 .38318 Mdot
.69006 .27389 Mdot
.63013 .38969 Mdot
.36441 .55578 Mdot
.64413 .43647 Mdot
.46291 .64543 Mdot
.70171 .72953 Mdot
.51863 .65139 Mdot
.57071 .39769 Mdot
.39216 .38996 Mdot
.37066 .51695 Mdot
.74963 .66731 Mdot
.57204 .6866 Mdot
.53535 .21054 Mdot
.40369 .18327 Mdot
.66019 .62594 Mdot
.60478 .60025 Mdot
.33572 .548 Mdot
.61818 .41259 Mdot
.65609 .23052 Mdot
.67841 .40692 Mdot
.62766 .42364 Mdot
.59624 .41985 Mdot
.36803 .75873 Mdot
.34826 .54803 Mdot
.49621 .63433 Mdot
.61563 .4406 Mdot
.62246 .44791 Mdot
.36408 .34755 Mdot
.62963 .62735 Mdot
.48264 .62172 Mdot
.64229 .63067 Mdot
.47939 .66054 Mdot
.2829 .74953 Mdot
.54315 .3964 Mdot
.62903 .62243 Mdot
.40346 .56658 Mdot
.38268 .40065 Mdot
.30311 .56993 Mdot
.48218 .62449 Mdot
.509 .6536 Mdot
.59237 .44316 Mdot
.41059 .40262 Mdot
.3797 .40563 Mdot
.6204 .61383 Mdot
.39289 .55801 Mdot
.58421 .38921 Mdot
.64843 .37077 Mdot
.34337 .42257 Mdot
.49759 .68337 Mdot
.61315 .50901 Mdot
.24459 .52469 Mdot
.61898 .40857 Mdot
.38203 .40439 Mdot
.58834 .41501 Mdot
.23165 .37191 Mdot
.41694 .39959 Mdot
.59726 .45235 Mdot
.54237 .8104 Mdot
.55671 .64443 Mdot
.26172 .47663 Mdot
.55831 .42125 Mdot
.30441 .24299 Mdot
.63948 .37753 Mdot
.14027 .59529 Mdot
.63006 .69299 Mdot
.57954 .38388 Mdot
.64238 .40125 Mdot
.5055 .34733 Mdot
.57585 .40865 Mdot
.44172 .64858 Mdot
.69179 .65227 Mdot
.35482 .352 Mdot
.24897 .41466 Mdot
.49237 .39648 Mdot
.6305 .64514 Mdot
.52473 .65294 Mdot
.45078 .67732 Mdot
.64667 .60622 Mdot
.40135 .38536 Mdot
.61905 .39611 Mdot
.46375 .52135 Mdot
.47436 .68535 Mdot
.65073 .34706 Mdot
.36773 .55481 Mdot
.37507 .65926 Mdot
.5311 .61966 Mdot
.36266 .53778 Mdot
.60364 .36852 Mdot
.50723 .35159 Mdot
.77314 .5883 Mdot
.2107 .35789 Mdot
.36046 .51328 Mdot
.35469 .52144 Mdot
.69365 .74775 Mdot
.63894 .64809 Mdot
.40901 .21307 Mdot
.29466 .41632 Mdot
.3828 .52334 Mdot
.721 .36039 Mdot
.46962 .67368 Mdot
.24523 .46627 Mdot
.43598 .39804 Mdot
.66174 .41829 Mdot
.60237 .40787 Mdot
.39448 .55659 Mdot
.3354 .30555 Mdot
.81664 .43545 Mdot
.3559 .53089 Mdot
.6228 .32193 Mdot
.45074 .47095 Mdot
.34598 .71164 Mdot
.48995 .68105 Mdot
.61542 .63494 Mdot
.67561 .62706 Mdot
.38599 .3427 Mdot
.6075 .62269 Mdot
.50635 .78352 Mdot
.61425 .3771 Mdot
.36158 .52707 Mdot
.313 .65833 Mdot
.36967 .53888 Mdot
.64601 .60786 Mdot
.6658 .61829 Mdot
.3671 .38755 Mdot
.37157 .38514 Mdot
.42404 .26586 Mdot
.70312 .55286 Mdot
.58101 .43783 Mdot
.24197 .63947 Mdot
.3591 .38938 Mdot
.68012 .45085 Mdot
.60593 .60073 Mdot
.6317 .62537 Mdot
.64158 .52745 Mdot
.6007 .38207 Mdot
.70254 .28622 Mdot
.60361 .38565 Mdot
.69539 .56604 Mdot
.56227 .3858 Mdot
.50566 .63717 Mdot
.59816 .37903 Mdot
.58753 .62202 Mdot
.64924 .36229 Mdot
.62767 .4509 Mdot
.49633 .68583 Mdot
.59522 .46509 Mdot
.4636 .64359 Mdot
.56687 .40713 Mdot
.62363 .64543 Mdot
.51368 .67227 Mdot
.74399 .49197 Mdot
.54544 .60011 Mdot
.45105 .62572 Mdot
.6088 .61641 Mdot
.64192 .64476 Mdot
.75813 .44895 Mdot
.38746 .35655 Mdot
.43589 .36126 Mdot
.61714 .41672 Mdot
.5208 .67944 Mdot
.34949 .5525 Mdot
.62972 .44151 Mdot
.58401 .47103 Mdot
.56625 .4366 Mdot
.3942 .34398 Mdot
.521 .74053 Mdot
.62411 .61962 Mdot
.44768 .64967 Mdot
.61436 .569 Mdot
.47077 .6799 Mdot
.56435 .35465 Mdot
.55266 .45402 Mdot
.4018 .27742 Mdot
.26145 .62368 Mdot
.67386 .77554 Mdot
.41569 .38585 Mdot
.52484 .63084 Mdot
.64352 .64602 Mdot
.69087 .40457 Mdot
.39135 .36339 Mdot
.46174 .64257 Mdot
.62072 .40411 Mdot
.57499 .3649 Mdot
.3147 .52413 Mdot
.52387 .45857 Mdot
.71733 .46594 Mdot
.47065 .67884 Mdot
.53929 .64066 Mdot
.48849 .79751 Mdot
.68892 .65269 Mdot
.48208 .55295 Mdot
.59645 .43179 Mdot
.62445 .63507 Mdot
.41209 .35978 Mdot
.7609 .6176 Mdot
.38945 .57046 Mdot
.53623 .56268 Mdot
.61098 .42026 Mdot
.42737 .51869 Mdot
.39125 .39115 Mdot
.62946 .60035 Mdot
.39507 .5544 Mdot
.65445 .59105 Mdot
.52071 .67017 Mdot
.5212 .14917 Mdot
.62718 .38574 Mdot
.58228 .44123 Mdot
.39981 .56667 Mdot
.40665 .35942 Mdot
.63362 .58291 Mdot
.33943 .2743 Mdot
.51067 .62948 Mdot
.67304 .24157 Mdot
.39566 .41255 Mdot
.57405 .24611 Mdot
.44852 .65435 Mdot
.33755 .53751 Mdot
.75757 .47361 Mdot
.36885 .5247 Mdot
.56807 .39663 Mdot
.38938 .37812 Mdot
.37252 .56542 Mdot
.56798 .55803 Mdot
.16295 .57913 Mdot
.58778 .26201 Mdot
.6113 .38347 Mdot
.20301 .64583 Mdot
.29171 .30733 Mdot
.35006 .40502 Mdot
.39958 .54462 Mdot
.59509 .43912 Mdot
.59833 .36347 Mdot
.63074 .3937 Mdot
.38013 .55422 Mdot
.37705 .72936 Mdot
.49618 .6281 Mdot
.57678 .42794 Mdot
.61967 .63607 Mdot
.46885 .63948 Mdot
.33979 .70288 Mdot
.50548 .66232 Mdot
.37854 .42324 Mdot
.64281 .4391 Mdot
.35694 .48846 Mdot
.19644 .67429 Mdot
.34664 .53215 Mdot
.44714 .62825 Mdot
.64247 .43163 Mdot
.29935 .65632 Mdot
.38521 .36487 Mdot
.51557 .63357 Mdot
.6056 .43958 Mdot
.35813 .70631 Mdot
.71341 .68465 Mdot
.5054 .6611 Mdot
.39594 .35798 Mdot
.20132 .43344 Mdot
.61262 .42492 Mdot
.63676 .37789 Mdot
.40741 .36645 Mdot
.51349 .37008 Mdot
.65795 .75586 Mdot
.58783 .4095 Mdot
.35785 .53912 Mdot
.65084 .20165 Mdot
.58896 .45765 Mdot
.65518 .53507 Mdot
.46641 .6559 Mdot
.25157 .49988 Mdot
.6258 .50751 Mdot
.6862 .43621 Mdot
.32386 .30632 Mdot
.47777 .43388 Mdot
.26662 .71594 Mdot
.53189 .66801 Mdot
.634 .72867 Mdot
.26494 .72142 Mdot
.34109 .56147 Mdot
.4556 .37938 Mdot
.3086 .35123 Mdot
.75833 .69227 Mdot
.2037 .44906 Mdot
.56427 .75284 Mdot
.70375 .6976 Mdot
.44951 .49637 Mdot
.48544 .66273 Mdot
.65633 .65763 Mdot
.58749 .39111 Mdot
.29034 .30684 Mdot
.66535 .27663 Mdot
.80596 .39077 Mdot
.19531 .63584 Mdot
.70189 .29589 Mdot
.19543 .60938 Mdot
.16794 .49928 Mdot
.38979 .26509 Mdot
.25602 .60734 Mdot
.69227 .24979 Mdot
.53437 .8054 Mdot
.53985 .17049 Mdot
.59437 .48578 Mdot
.5615 .53058 Mdot
.34978 .2331 Mdot
.54286 .23405 Mdot
.77487 .37228 Mdot
.51691 .64333 Mdot
.41008 .41473 Mdot
.30472 .3608 Mdot
.3535 .3988 Mdot
.40708 .59867 Mdot
.20398 .41305 Mdot
.14611 .54854 Mdot
.58737 .23188 Mdot
.28347 .25076 Mdot
.44442 .2269 Mdot
.87559 .53597 Mdot
.43376 .62196 Mdot
.42532 .36419 Mdot
.66258 .58409 Mdot
.47546 .80019 Mdot
.3204 .4671 Mdot
.30395 .32842 Mdot
.39822 .75183 Mdot
.74305 .53734 Mdot
.39851 .3809 Mdot
.70585 .40997 Mdot
.41075 .6075 Mdot
.2909 .50702 Mdot
.69021 .66731 Mdot
.17865 .48263 Mdot
.48386 .53316 Mdot
.2425 .45309 Mdot
.36293 .63828 Mdot
.68802 .79621 Mdot
.68276 .50707 Mdot
.3621 .29866 Mdot
.31658 .57355 Mdot
.22897 .38775 Mdot
.78524 .64837 Mdot
.71858 .56834 Mdot
.48087 .80068 Mdot
.4208 .81284 Mdot
.27241 .30895 Mdot
.46744 .84429 Mdot
.42898 .34908 Mdot
.56143 .4242 Mdot
.46536 .34764 Mdot
.67809 .26895 Mdot
.65233 .65441 Mdot
.29657 .70696 Mdot
.64498 .64051 Mdot
.39153 .43077 Mdot
.69385 .7301 Mdot
.56331 .22182 Mdot
.69623 .27155 Mdot
.62095 .58023 Mdot
.55432 .44107 Mdot
.72763 .21496 Mdot
.25912 .70261 Mdot
.26862 .50773 Mdot
.13438 .57494 Mdot
.44791 .54978 Mdot
.72444 .4112 Mdot
.37351 .56416 Mdot
.23979 .70382 Mdot
.39689 .36943 Mdot
.39158 .83394 Mdot
.17834 .63547 Mdot
.80938 .44969 Mdot
.44538 .09627 Mdot
.4667 .77762 Mdot
.4329 .51487 Mdot
.46597 .42623 Mdot
.72375 .49369 Mdot
.82764 .50738 Mdot
.79292 .41622 Mdot
.29651 .64161 Mdot
.37805 .19992 Mdot
.24024 .69749 Mdot
.67037 .25551 Mdot
.52667 .15615 Mdot
.77145 .67864 Mdot
.51454 .49852 Mdot
.42425 .42721 Mdot
.43818 .59719 Mdot
.19456 .53277 Mdot
.35642 .78749 Mdot
.6652 .52172 Mdot
.5286 .12267 Mdot
.59316 .60643 Mdot
.6154 .6952 Mdot
.20208 .38576 Mdot
.75546 .52253 Mdot
.70532 .44009 Mdot
.63163 .76818 Mdot
.63645 .3436 Mdot
.60357 .77924 Mdot
.21067 .60641 Mdot
.31861 .59123 Mdot
.54167 .80092 Mdot
.21669 .49584 Mdot
.36226 .25171 Mdot
.50008 .3266 Mdot
.47125 .80502 Mdot
.35405 .38637 Mdot
.72367 .54446 Mdot
.69474 .46495 Mdot
.13984 .54902 Mdot
.34472 .59856 Mdot
.13558 .4924 Mdot
.67168 .73615 Mdot
.54918 .41196 Mdot
.53384 .45628 Mdot
.65456 .32579 Mdot
.70526 .53926 Mdot
.61119 .46123 Mdot
.32124 .48599 Mdot
.14941 .50886 Mdot
.43368 .22325 Mdot
.30881 .59532 Mdot
.31171 .69446 Mdot
.20617 .36283 Mdot
.42804 .29989 Mdot
.67621 .69657 Mdot
.67826 .57173 Mdot
.744 .73336 Mdot
.48286 .63716 Mdot
.66062 .24597 Mdot
.33181 .55031 Mdot
.72838 .65368 Mdot
.57062 .3004 Mdot
.81895 .51008 Mdot
.14948 .50747 Mdot
.5924 .76344 Mdot
.69236 .71341 Mdot
.77282 .50569 Mdot
.64871 .21643 Mdot
.30961 .70269 Mdot
.53778 .43332 Mdot
.27402 .3531 Mdot
.66234 .62361 Mdot
.45016 .29021 Mdot
.5937 .19724 Mdot
.57344 .71827 Mdot
.65115 .44823 Mdot
.7918 .5484 Mdot
.47409 .73174 Mdot
.53138 .57095 Mdot
.55221 .85654 Mdot
.60591 .33695 Mdot
.42515 .78067 Mdot
.28529 .2944 Mdot
.7019 .51092 Mdot
.21997 .37142 Mdot
.22498 .45512 Mdot
.44719 .83555 Mdot
.16465 .61156 Mdot
.56021 .70133 Mdot
.29277 .73882 Mdot
.13454 .55451 Mdot
.48231 .83752 Mdot
.52766 .39096 Mdot
.39274 .58269 Mdot
.6079 .86419 Mdot
.44905 .66252 Mdot
.36704 .76496 Mdot
.51837 .1788 Mdot
.36237 .70293 Mdot
.35738 .31623 Mdot
.62022 .48249 Mdot
.45799 .50485 Mdot
.35324 .40944 Mdot
.60327 .46481 Mdot
.58848 .83346 Mdot
.4605 .82671 Mdot
.52907 .84598 Mdot
.29307 .26982 Mdot
.29497 .74674 Mdot
.41732 .48535 Mdot
.55218 .22942 Mdot
.34668 .41434 Mdot
.66075 .40574 Mdot
.59553 .6535 Mdot
.46621 .77599 Mdot
.79214 .56042 Mdot
.31601 .45406 Mdot
.3584 .41028 Mdot
.26304 .6694 Mdot
.89486 .596 Mdot
.44212 .24037 Mdot
.59082 .21181 Mdot
.50292 .79283 Mdot
.6949 .54212 Mdot
.20207 .55754 Mdot
.81369 .48107 Mdot
.16307 .46983 Mdot
.34079 .3938 Mdot
.52255 .17352 Mdot
.57749 .74084 Mdot
.7439 .38467 Mdot
.51188 .74546 Mdot
.16081 .55475 Mdot
.42271 .45102 Mdot
.77867 .61355 Mdot
.28904 .39008 Mdot
.81234 .44244 Mdot
.64402 .6816 Mdot
.38138 .65958 Mdot
.60122 .19751 Mdot
.28629 .5976 Mdot
.67804 .54373 Mdot
.46353 .48426 Mdot
.68845 .37675 Mdot
.47643 .43287 Mdot
.676 .53618 Mdot
.7452 .40856 Mdot
.33622 .76699 Mdot
.12475 .59909 Mdot
.66929 .79294 Mdot
.26543 .26177 Mdot
.21204 .59459 Mdot
.66646 .40756 Mdot
.18342 .40088 Mdot
.48622 .85476 Mdot
.16417 .62526 Mdot
.42662 .70496 Mdot
.50405 .69663 Mdot
.37508 .50566 Mdot
.63342 .80147 Mdot
.49415 .74229 Mdot
.18243 .43932 Mdot
.61553 .78179 Mdot
.40427 .52965 Mdot
.82951 .59609 Mdot
.4466 .81785 Mdot
.58861 .28732 Mdot
.53645 .47195 Mdot
.65556 .35816 Mdot
.60937 .2461 Mdot
.3654 .41252 Mdot
.34916 .62498 Mdot
.71244 .55582 Mdot
.49215 .64421 Mdot
.62612 .66786 Mdot
.29861 .3292 Mdot
.61332 .47063 Mdot
.48131 .41657 Mdot
.41396 .41456 Mdot
.26066 .61891 Mdot
.29458 .54278 Mdot
.33551 .78345 Mdot
.45546 .76443 Mdot
.67819 .37665 Mdot
.69676 .51132 Mdot
.50194 .75316 Mdot
.65396 .76566 Mdot
.33374 .52053 Mdot
.18477 .61689 Mdot
.56203 .541 Mdot
.72122 .54561 Mdot
.63002 .25801 Mdot
.36646 .25794 Mdot
.5692 .47236 Mdot
.2418 .54314 Mdot
.51219 .28644 Mdot
.54233 .56735 Mdot
.41669 .4301 Mdot
.42928 .42485 Mdot
.19041 .36325 Mdot
.52571 .77815 Mdot
.35837 .64308 Mdot
.18129 .60394 Mdot
.37869 .53981 Mdot
.36406 .39325 Mdot
.58623 .64387 Mdot
.34981 .25767 Mdot
.53152 .26455 Mdot
.71365 .68509 Mdot
.41152 .73343 Mdot
.58722 .71004 Mdot
.18995 .60888 Mdot
.1998 .63417 Mdot
.80108 .36615 Mdot
.3489 .35277 Mdot
.36468 .27492 Mdot
.42374 .19997 Mdot
.38336 .41843 Mdot
.31939 .34351 Mdot
.33774 .46369 Mdot
.3405 .77877 Mdot
.41206 .54113 Mdot
.36548 .20362 Mdot
.7385 .44369 Mdot
.36327 .72445 Mdot
.74617 .67307 Mdot
.60655 .19826 Mdot
.17875 .59214 Mdot
.69924 .33096 Mdot
.56448 .31098 Mdot
.62328 .4761 Mdot
.54205 .48933 Mdot
.74072 .75519 Mdot
.55122 .60805 Mdot
.57805 .24512 Mdot
.21275 .48206 Mdot
.62161 .38947 Mdot
.66604 .8012 Mdot
.32405 .28957 Mdot
.69075 .75324 Mdot
.39627 .52136 Mdot
.63041 .36601 Mdot
.65806 .37435 Mdot
.6435 .54763 Mdot
.25985 .50938 Mdot
.3867 .78486 Mdot
.59681 .19023 Mdot
.21026 .52103 Mdot
.6647 .27692 Mdot
.42167 .77813 Mdot
.18475 .45708 Mdot
.28606 .31301 Mdot
.50829 .52045 Mdot
.47007 .77283 Mdot
.75952 .50042 Mdot
.28136 .25663 Mdot
.603 .54788 Mdot
.38815 .46644 Mdot
.33796 .44434 Mdot
.2364 .50255 Mdot
.75911 .63566 Mdot
.65424 .39654 Mdot
.65317 .75314 Mdot
.17145 .49077 Mdot
.76056 .3198 Mdot
.8165 .57015 Mdot
.64697 .81013 Mdot
.53706 .2957 Mdot
.22933 .48386 Mdot
.28737 .32348 Mdot
.71846 .2483 Mdot
.57792 .53716 Mdot
.26064 .68639 Mdot
.7643 .50038 Mdot
.18558 .60601 Mdot
.38745 .58579 Mdot
.30096 .40703 Mdot
.31568 .6997 Mdot
.3134 .75311 Mdot
.45516 .31979 Mdot
.16485 .5385 Mdot
.44216 .52958 Mdot
.42239 .8341 Mdot
.2785 .59858 Mdot
.44118 .485 Mdot
.5271 .63757 Mdot
.58617 .76901 Mdot
.19885 .59782 Mdot
.24288 .61405 Mdot
.60331 .20149 Mdot
.54286 .63923 Mdot
.64268 .66415 Mdot
.62533 .28171 Mdot
.76411 .55495 Mdot
.2308 .51333 Mdot
.69733 .51108 Mdot
.15458 .53468 Mdot
.63286 .55902 Mdot
.67336 .72585 Mdot
.41839 .77312 Mdot
.49082 .14876 Mdot
.26644 .5044 Mdot
.54449 .78193 Mdot
.31456 .30474 Mdot
.61717 .6848 Mdot
.724 .37104 Mdot
.17858 .72469 Mdot
.47207 .16346 Mdot
.26741 .60314 Mdot
.35728 .78761 Mdot
.22925 .36166 Mdot
.26514 .62381 Mdot
.82716 .51827 Mdot
.65974 .49789 Mdot
.70693 .64365 Mdot
.59736 .41904 Mdot
.53693 .85418 Mdot
.74569 .55746 Mdot
.38054 .80456 Mdot
.18876 .38609 Mdot
.61074 .25079 Mdot
.60976 .47011 Mdot
.45247 .65433 Mdot
.37039 .61012 Mdot
.75366 .58732 Mdot
.50477 .36288 Mdot
.71364 .4053 Mdot
.42483 .74024 Mdot
.52645 .65925 Mdot
.52007 .74812 Mdot
.33308 .36335 Mdot
.44809 .74873 Mdot
.24191 .5205 Mdot
.56117 .65744 Mdot
.50317 .54031 Mdot
.68327 .5344 Mdot
.64567 .49584 Mdot
.58572 .28624 Mdot
.81468 .52604 Mdot
.49592 .47268 Mdot
.50559 .66484 Mdot
.5461 .30925 Mdot
.38965 .1996 Mdot
.22054 .5353 Mdot
.41314 .80985 Mdot
.62435 .76266 Mdot
.58015 .31025 Mdot
.67032 .54006 Mdot
.82703 .48985 Mdot
.73439 .32594 Mdot
.26633 .65284 Mdot
.59935 .50137 Mdot
.72013 .32405 Mdot
.27922 .36111 Mdot
.27748 .74102 Mdot
.53643 .17113 Mdot
.47011 .17754 Mdot
.49257 .59556 Mdot
.53024 .23748 Mdot
.627 .26633 Mdot
.7464 .48132 Mdot
.49936 .55831 Mdot
.86734 .56186 Mdot
.43822 .3843 Mdot
.77252 .74151 Mdot
.35285 .56098 Mdot
.77676 .68186 Mdot
.76395 .47911 Mdot
.46284 .47933 Mdot
.48658 .56275 Mdot
.24599 .54559 Mdot
.29685 .42685 Mdot
.30956 .25234 Mdot
.79346 .38223 Mdot
.47667 .68358 Mdot
.6005 .18713 Mdot
.50675 .14213 Mdot
.51982 .33361 Mdot
.55673 .44145 Mdot
.46517 .16349 Mdot
.53968 .66269 Mdot
.79288 .56059 Mdot
.21859 .36361 Mdot
.23093 .59098 Mdot
.56894 .3342 Mdot
.69969 .54497 Mdot
.25357 .67742 Mdot
.16627 .6021 Mdot
.83231 .56406 Mdot
.21093 .60602 Mdot
.39254 .58216 Mdot
.42857 .48661 Mdot
.17449 .5466 Mdot
.71862 .44111 Mdot
.25166 .4356 Mdot
.70863 .44202 Mdot
.83541 .65724 Mdot
.34763 .75434 Mdot
.38467 .78338 Mdot
.70789 .45328 Mdot
.38772 .33099 Mdot
.27647 .55989 Mdot
.7026 .44658 Mdot
.23724 .58622 Mdot
.34658 .24079 Mdot
.69819 .45778 Mdot
.78273 .31474 Mdot
.40668 .23064 Mdot
.50482 .70543 Mdot
.63862 .27573 Mdot
.41394 .23393 Mdot
.40285 .53019 Mdot
.69314 .65915 Mdot
.2099 .4892 Mdot
.40224 .56076 Mdot
.23182 .51981 Mdot
.242 .47825 Mdot
.44033 .20649 Mdot
.54392 .26573 Mdot
.21096 .54197 Mdot
.49004 .35414 Mdot
.45924 .38896 Mdot
.75676 .62318 Mdot
.47905 .61389 Mdot
.20438 .47413 Mdot
.51734 .63048 Mdot
.6522 .47866 Mdot
.54684 .56225 Mdot
.60684 .31213 Mdot
.65779 .7923 Mdot
.66054 .62752 Mdot
.42377 .3681 Mdot
.78927 .67704 Mdot
.39046 .41704 Mdot
.56559 .84179 Mdot
.81664 .49717 Mdot
.63118 .25684 Mdot
.57206 .69283 Mdot
.55312 .73158 Mdot
.85209 .43003 Mdot
.47118 .40808 Mdot
.47182 .59581 Mdot
.45694 .40909 Mdot
.41668 .35453 Mdot
.42874 .76764 Mdot
.50567 .67925 Mdot
.62084 .5227 Mdot
.40516 .49524 Mdot
.39785 .45182 Mdot
.34582 .34361 Mdot
.55313 .54809 Mdot
.70886 .60868 Mdot
.33235 .77242 Mdot
.49101 .66884 Mdot
.81431 .66908 Mdot
.5764 .47203 Mdot
.48931 .32101 Mdot
.16147 .46626 Mdot
.83324 .5798 Mdot
.44306 .66497 Mdot
.5221 .13609 Mdot
.56666 .37763 Mdot
.20785 .55628 Mdot
.40089 .37429 Mdot
.49435 .17232 Mdot
.65598 .62676 Mdot
.70958 .50488 Mdot
.36268 .50346 Mdot
.77619 .61789 Mdot
.43341 .73309 Mdot
.3741 .32992 Mdot
.22671 .61049 Mdot
.3747 .26531 Mdot
.27771 .41128 Mdot
.53809 .73949 Mdot
.53184 .32667 Mdot
.53949 .2608 Mdot
.34849 .33897 Mdot
.36042 .77366 Mdot
.50221 .1693 Mdot
.26471 .74305 Mdot
.66171 .33268 Mdot
.62406 .74355 Mdot
.34252 .43951 Mdot
.2313 .54053 Mdot
.57669 .50519 Mdot
.15685 .48931 Mdot
.72194 .5592 Mdot
.35648 .45876 Mdot
.69172 .55931 Mdot
.66831 .45765 Mdot
.49377 .52583 Mdot
.38082 .63287 Mdot
.8192 .41021 Mdot
.56906 .50968 Mdot
.79706 .63562 Mdot
.60787 .50125 Mdot
.43652 .78507 Mdot
.33794 .33125 Mdot
.47752 .69797 Mdot
.54303 .24057 Mdot
.34227 .59896 Mdot
.26698 .73024 Mdot
.15851 .48234 Mdot
.34542 .49878 Mdot
.41735 .76001 Mdot
.2268 .39878 Mdot
.68287 .38105 Mdot
.41808 .50291 Mdot
.56103 .41314 Mdot
.32855 .33647 Mdot
.83772 .58497 Mdot
.2372 .56896 Mdot
.53693 .43795 Mdot
.26553 .71658 Mdot
.2319 .69248 Mdot
.40988 .82537 Mdot
.66342 .23149 Mdot
.37276 .33919 Mdot
.51169 .83908 Mdot
.71284 .39546 Mdot
.14548 .57182 Mdot
.25981 .64274 Mdot
.18303 .37656 Mdot
.54131 .32527 Mdot
.21658 .46575 Mdot
.79673 .40663 Mdot
.27564 .44227 Mdot
.26389 .31996 Mdot
.4351 .46122 Mdot
.34235 .64234 Mdot
.24741 .3316 Mdot
.78633 .2904 Mdot
.57468 .49742 Mdot
.24044 .46408 Mdot
.29526 .36667 Mdot
.20409 .48268 Mdot
.6441 .69849 Mdot
.64471 .43555 Mdot
.31511 .66753 Mdot
.72434 .69253 Mdot
.67972 .52437 Mdot
.63645 .66333 Mdot
.64135 .698 Mdot
.73473 .6224 Mdot
.70263 .57774 Mdot
.5397 .16994 Mdot
.54723 .31855 Mdot
.60689 .5202 Mdot
.54817 .42324 Mdot
.34501 .3253 Mdot
.60493 .62476 Mdot
.46806 .71215 Mdot
.5652 .4136 Mdot
.50601 .69293 Mdot
.28091 .42052 Mdot
.62627 .82065 Mdot
.3048 .58729 Mdot
.32362 .28 Mdot
.43331 .40186 Mdot
.25292 .52098 Mdot
.43579 .33267 Mdot
.73184 .71075 Mdot
.62341 .72802 Mdot
.6653 .52152 Mdot
.2398 .68107 Mdot
.53807 .80093 Mdot
.38323 .24044 Mdot
.53448 .81466 Mdot
.39466 .57449 Mdot
.56828 .33983 Mdot
.30653 .38979 Mdot
.51091 .76037 Mdot
.39709 .43537 Mdot
.21715 .47217 Mdot
.47321 .59968 Mdot
.53898 .78799 Mdot
.28061 .29784 Mdot
.37178 .2608 Mdot
.62732 .28819 Mdot
.20668 .6457 Mdot
.46751 .66865 Mdot
.47245 .1715 Mdot
.25072 .42425 Mdot
.61231 .74095 Mdot
.42381 .79247 Mdot
.31431 .76998 Mdot
.46072 .54999 Mdot
.74275 .52275 Mdot
.63623 .38489 Mdot
.56605 .20419 Mdot
.24214 .5645 Mdot
.50725 .42077 Mdot
.40926 .70079 Mdot
.39044 .40633 Mdot
.39735 .6609 Mdot
.57162 .5282 Mdot
.71753 .63149 Mdot
.35096 .39948 Mdot
.68332 .27795 Mdot
.60919 .63814 Mdot
.44225 .55734 Mdot
.60095 .46264 Mdot
.73259 .51337 Mdot
.69385 .26562 Mdot
.59355 .33259 Mdot
.20004 .57761 Mdot
.55171 .31148 Mdot
.36394 .24597 Mdot
.22087 .56176 Mdot
.2722 .66013 Mdot
.29384 .4322 Mdot
.56048 .24912 Mdot
.43997 .72022 Mdot
.56475 .43429 Mdot
.47241 .69534 Mdot
.37273 .40543 Mdot
.21073 .40379 Mdot
.53211 .2925 Mdot
.74476 .49567 Mdot
.47481 .4762 Mdot
.45456 .34858 Mdot
.47188 .4543 Mdot
.17633 .4197 Mdot
.27617 .44388 Mdot
.71394 .55937 Mdot
.41213 .58481 Mdot
.76201 .48066 Mdot
.82049 .52349 Mdot
.20032 .66162 Mdot
.82094 .47151 Mdot
.46555 .53036 Mdot
.80418 .62777 Mdot
.27144 .58501 Mdot
.22088 .35833 Mdot
.7126 .57251 Mdot
.46385 .563 Mdot
.59858 .64709 Mdot
.31791 .51559 Mdot
.50622 .49862 Mdot
.56979 .61657 Mdot
.64229 .50594 Mdot
.38348 .6979 Mdot
.41595 .61275 Mdot
.62581 .47927 Mdot
.36939 .7627 Mdot
.22532 .66484 Mdot
.50469 .1751 Mdot
.48249 .44593 Mdot
.67707 .67429 Mdot
.72934 .61178 Mdot
.23248 .27654 Mdot
.69633 .79409 Mdot
.63462 .38478 Mdot
.48713 .44874 Mdot
.72632 .52804 Mdot
.46332 .67558 Mdot
.68847 .45854 Mdot
.45893 .36141 Mdot
.34046 .53992 Mdot
.56575 .6237 Mdot
.55833 .78835 Mdot
.24967 .54768 Mdot
.77101 .53588 Mdot
.33015 .70255 Mdot
.62123 .82609 Mdot
.35481 .22451 Mdot
.23381 .55084 Mdot
.19044 .33042 Mdot
.40875 .62369 Mdot
.44155 .40917 Mdot
.45762 .34237 Mdot
.34305 .77546 Mdot
.69974 .503 Mdot
.74277 .65174 Mdot
.29233 .68229 Mdot
.71885 .56625 Mdot
.72076 .3833 Mdot
.42216 .77569 Mdot
.40067 .67287 Mdot
.46493 .50089 Mdot
.5547 .73249 Mdot
.48979 .81751 Mdot
.67051 .28672 Mdot
.23692 .66678 Mdot
.73138 .68979 Mdot
.7614 .28264 Mdot
.24189 .70732 Mdot
.60705 .65965 Mdot
.65961 .69608 Mdot
.45743 .33873 Mdot
.72966 .44095 Mdot
.71689 .35271 Mdot
.79249 .57427 Mdot
.51915 .26205 Mdot
.5332 .71954 Mdot
.77045 .66505 Mdot
.67739 .5428 Mdot
.41985 .22823 Mdot
.46598 .56253 Mdot
.5705 .29261 Mdot
.43426 .7594 Mdot
.69459 .47725 Mdot
.57862 .56247 Mdot
.73027 .46804 Mdot
.53813 .31661 Mdot
.327 .3027 Mdot
.23301 .42205 Mdot
.81266 .33976 Mdot
.27616 .67849 Mdot
.73922 .7044 Mdot
.63954 .45157 Mdot
.29425 .7675 Mdot
.23735 .42913 Mdot
.28897 .68419 Mdot
.31111 .27 Mdot
.48532 .70761 Mdot
.36801 .45736 Mdot
.56563 .43524 Mdot
.23119 .63414 Mdot
.58368 .24833 Mdot
.41265 .24568 Mdot
.76859 .6382 Mdot
.69934 .52164 Mdot
.67983 .69898 Mdot
.74637 .4644 Mdot
.61156 .32456 Mdot
.41104 .41038 Mdot
.51705 .84677 Mdot
.45047 .52774 Mdot
.62949 .4898 Mdot
.51302 .40854 Mdot
.79967 .41457 Mdot
.40921 .17431 Mdot
.65279 .32594 Mdot
.51486 .80168 Mdot
.69958 .2982 Mdot
.65173 .30969 Mdot
.68207 .45487 Mdot
.32162 .15842 Mdot
.12837 .59255 Mdot
.36074 .34029 Mdot
.60242 .21187 Mdot
.70594 .29903 Mdot
.33405 .76711 Mdot
.58204 .73884 Mdot
.45213 .71408 Mdot
.77184 .38308 Mdot
.73343 .40871 Mdot
.55212 .44378 Mdot
.29186 .28688 Mdot
.18783 .64434 Mdot
.77091 .64371 Mdot
.25883 .71154 Mdot
.5607 .47913 Mdot
.53626 .40516 Mdot
.28863 .20839 Mdot
.17642 .55789 Mdot
.64148 .34653 Mdot
.80159 .41006 Mdot
.42647 .4251 Mdot
.59115 .40021 Mdot
.33915 .72756 Mdot
.59151 .18893 Mdot
.67418 .54355 Mdot
.31474 .75405 Mdot
.35062 .38865 Mdot
.45521 .59271 Mdot
.33883 .54062 Mdot
.49119 .56127 Mdot
.5605 .37593 Mdot
.38062 .55875 Mdot
.64503 .30653 Mdot
.21282 .45635 Mdot
.38989 .50666 Mdot
.54612 .16304 Mdot
.14404 .46028 Mdot
.55183 .28748 Mdot
.31484 .54381 Mdot
.68402 .38 Mdot
.40604 .23558 Mdot
.74867 .59831 Mdot
.3429 .41243 Mdot
.23599 .3387 Mdot
.27373 .79483 Mdot
.35169 .65207 Mdot
.69896 .62637 Mdot
.36073 .42019 Mdot
.6031 .51791 Mdot
.60416 .27552 Mdot
.43061 .55165 Mdot
.46908 .66355 Mdot
.67076 .42524 Mdot
.62065 .32496 Mdot
.3878 .5159 Mdot
.76796 .74015 Mdot
.64831 .42511 Mdot
.65911 .48285 Mdot
.14807 .57386 Mdot
.75627 .62472 Mdot
.47483 .31694 Mdot
.60696 .35091 Mdot
.29592 .50617 Mdot
.46271 .56344 Mdot
.19129 .48367 Mdot
.66943 .72999 Mdot
.2858 .72576 Mdot
.52928 .29176 Mdot
.64835 .28842 Mdot
.61533 .45112 Mdot
.64727 .65114 Mdot
.24901 .46252 Mdot
.31138 .71838 Mdot
.54492 .46779 Mdot
.15668 .5984 Mdot
.48791 .70887 Mdot
.39883 .72062 Mdot
.66775 .32491 Mdot
.42954 .82962 Mdot
.80069 .61382 Mdot
.60828 .25993 Mdot
.71835 .73175 Mdot
.51786 .76838 Mdot
.76264 .55465 Mdot
.4548 .65572 Mdot
.57204 .48183 Mdot
.34951 .37861 Mdot
.62251 .83048 Mdot
.31634 .72566 Mdot
.31162 .64335 Mdot
.3817 .66281 Mdot
.54626 .20668 Mdot
.27037 .39745 Mdot
.17251 .37718 Mdot
.53426 .75432 Mdot
.63436 .8204 Mdot
.47034 .17592 Mdot
.35731 .42076 Mdot
.22531 .4905 Mdot
.56608 .34468 Mdot
.50117 .66264 Mdot
.30809 .7388 Mdot
.64427 .33197 Mdot
.69816 .72225 Mdot
.60836 .35598 Mdot
.67291 .76753 Mdot
.56784 .59714 Mdot
.39512 .75946 Mdot
.28818 .60669 Mdot
.82484 .52453 Mdot
.19839 .41237 Mdot
.32235 .50022 Mdot
.20248 .32768 Mdot
.20074 .4255 Mdot
.18487 .61931 Mdot
.71891 .67985 Mdot
.84504 .52017 Mdot
.24753 .61884 Mdot
.21319 .54177 Mdot
.29575 .59822 Mdot
.49872 .38176 Mdot
.58332 .7677 Mdot
.66816 .32878 Mdot
.25817 .47211 Mdot
.33895 .49987 Mdot
.44726 .91499 Mdot
.58336 .61296 Mdot
.42623 .3399 Mdot
.55108 .76667 Mdot
.21002 .65936 Mdot
.52344 .36184 Mdot
.25929 .31091 Mdot
.56251 .53157 Mdot
.53936 .43547 Mdot
.53452 .27305 Mdot
.53521 .18142 Mdot
.59957 .76908 Mdot
.8693 .45712 Mdot
.35531 .22714 Mdot
.38512 .68591 Mdot
.50738 .53279 Mdot
.37725 .41703 Mdot
.37113 .31571 Mdot
.56809 .71143 Mdot
.2571 .29661 Mdot
.21518 .46258 Mdot
.17463 .54826 Mdot
.84656 .42031 Mdot
.40482 .21398 Mdot
.33969 .77486 Mdot
.26149 .58187 Mdot
.40921 .33116 Mdot
.63911 .66962 Mdot
.54395 .68641 Mdot
.30125 .63539 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0SOooool2o`00
0;[ooooo000Looooo`;o0000S_ooool2o`000;[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0Uoooool2o`000;3ooooo000Looooo`03o`000?oooooo
oooo09Oooooo0_l0002`ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`2Dooooo`;o00004_ooool2o`0009oooooo000Looooo`03o`000?oooooo
oooo09Cooooo0_l0000Booooo`?o0000W_ooool001cooooo00?o0000ooooooooool0ZOooool2o`00
09kooooo000Looooo`03o`000?oooooooooo09kooooo0_l0002Yooooo`007?ooool00ol0003ooooo
ooooo`28ooooo`;o00005?ooool2o`000:Wooooo000Looooo`03o`000?oooooooooo08Sooooo0_l0
000Looooo`;o0000XOooool001cooooo00?o0000ooooooooool0Y_ooool2o`0000gooooo0_l00008
ooooo`;o0000R?ooool001cooooo00?o0000ooooooooool0XOooool2o`0001;ooooo0_l00007oooo
o`?o0000R?ooool001cooooo00?o0000ooooooooool0XOooool2o`0001?ooooo0_l00006ooooo`;o
0000ROooool001cooooo00?o0000ooooooooool0V?ooool2o`0000;ooooo0_l00008ooooo`;o0000
1_ooool2o`0000Kooooo0_l0002Aooooo`007?ooool2o`0007[ooooo0_l0000Mooooo`;o00000_oo
ool2o`0000Sooooo0_l00006ooooo`;o00001Oooool2o`0009;ooooo000Looooo`03o`000?oooooo
oooo07Wooooo0_l0000/ooooo`;o00002oooool3o`0009;ooooo000Looooo`03o`000?oooooooooo
06Gooooo0_l0000Vooooo`;o00004?ooool2o`0000Kooooo0_l0000;ooooo`;o0000Toooool001co
oooo00?o0000ooooooooool0IOooool2o`0002Kooooo0_l0000<ooooo`;o00000_ooool2o`0000go
oooo0_l0002Iooooo`007?ooool00ol0003oooooooooo`2;ooooo`;o00001_ooool2o`000003oooo
ool0003o000000?ooooo0_l0000Aooooo`;o0000VOooool001cooooo00?o0000ooooooooool0Rooo
ool2o`0000Kooooo1Ol00005ooooo`;o00003_ooool2o`0009[ooooo000Looooo`03o`000?oooooo
oooo073ooooo0_l0000Sooooo`?o00001Oooool4o`0000Wooooo1Ol0000@ooooo`;o0000R?ooool0
01cooooo00?o0000ooooooooool0L?ooool2o`0000oooooo0_l00009ooooo`;o00001Oooool2o`00
0003ooooool0003o000000Gooooo1Ol00004ooooo`;o00000_ooool4o`00017ooooo0_l00028oooo
o`007?ooool00ol0003oooooooooo`21ooooo`;o00001Oooool2o`0000;ooooo0ol00004ooooo`Go
00002?ooool2o`0000Cooooo0_l0002Qooooo`007?ooool00ol0003oooooooooo`22ooooo`;o0000
1?ooool2o`0000?ooooo0ol00005ooooo`?o00003?ooool3o`0000?ooooo0_l0000Kooooo`;o0000
P?ooool001cooooo00?o0000ooooooooool0Ooooool2o`000003ooooool0003o000000[ooooo0_l0
000Dooooo`So00004oooool2o`0000Kooooo0_l00020ooooo`007?ooool00ol0003oooooooooo`1o
ooooo`;o00002?ooool2o`000003ooooool0003o000001Wooooo0ol0000Eooooo`;o0000R?ooool0
01cooooo00?o0000ooooooooool0J?ooool2o`0001oooooo0_l000000ooooooo0000o`00000^oooo
o`Go0000R?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006
ooooo`03o`000?oooooooooo06Sooooo0_l0000Rooooo`;o00007Oooool2o`0000oooooo1?l00029
ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^
k_ooooooA4A400Kooooo00?o0000ooooooooool0N_ooool2o`000003ooooool0003o000000Cooooo
0_l00007ooooo`;o00005?ooool2o`0000Gooooo1?l0000;ooooo`;o00001_ooool2o`000003oooo
ool0003o000008Cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?o
V9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`1fooooo`Wo00001?ooool5o`0001[ooooo0_l0
0005ooooo`;o00003Oooool3o`0000;ooooo0_l000000ooooooo0000o`000003o`000003ooooool0
003o000000;ooooo0_l0001mooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0;
ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0001fooooo`Co000000?oooooo`000?l000001oooool5
o`0001Wooooo0_l0000:ooooo`;o00002Oooool2o`0000;ooooo0_l000001?oooooo0000o`000?l0
0003ooooo`;o00000_ooool2o`0000Cooooo0_l0001gooooo`0000?oooooo`000?ooool00_ooool0
0ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0Loooool2
o`0000?ooooo1?l0000;ooooo`;o00003?ooool2o`0000_ooooo0_l0000:ooooo`;o00001?ooool2
o`0000Oooooo0_l000000ooooooo0000o`000005ooooo`;o00001oooool2o`0007Oooooo00000ooo
oooo410@ooooo`02ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`1Jooooo`;o00005oooool2o`0000?ooooo1Ol0000>ooooo`;o000000?oooooo`00
0?l000001Oooool2o`0001Oooooo0_l00004ooooo`;o00004Oooool2o`0000kooooo0_l0001`oooo
o`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_oo
ool00ol0003oooooooooo`1Jooooo`;o00007oooool2o`0000Gooooo0_l00006ooooo`?o000000?o
ooooo`000?l000006_ooool2o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`000003ooooool0
003o000000;ooooo0_l00002ooooo`;o00004Oooool2o`00073ooooo00001_ooooook^k^oc8b<_l0
003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo06[o
oooo0_l0000Dooooo`Co00001_ooool4o`0001cooooo0_l00009ooooo`;o000000Goooooo`000?l0
003o0000ooooo`02o`0000;ooooo0_l00002ooooo`;o00004Oooool2o`00013ooooo0_l0001Noooo
o`007?ooool00ol0003oooooooooo`1Zooooo`;o00005?ooool4o`0000Oooooo0ol0000Oooooo`;o
00002Oooool2o`0000;ooooo0_l0000>ooooo`Go00000oooool2o`0001?ooooo0_l0001Nooooo`00
7?ooool00ol0003oooooooooo`2;ooooo`Co00007_ooool2o`0000[ooooo0_l000000ooooooo0000
o`00000>ooooo`Go00000oooool2o`0007?ooooo000Looooo`03o`000?oooooooooo073ooooo0_l0
000Fooooo`Oo00008?ooool2o`0000;ooooo0ol00003ooooo`;o00003?ooool2o`00083ooooo000L
ooooo`03o`000?oooooooooo073ooooo0_l00005ooooo`;o00002Oooool2o`0000Cooooo0ol00002
ooooo`;o00008?ooool2o`0000;ooooo0ol00007ooooo`;o00002?ooool2o`00083ooooo000Loooo
o`03o`000?oooooooooo073ooooo0_l00005ooooo`;o00001oooool4o`000003ooooool0003o0000
00Kooooo0_l0000Qooooo`;o00002oooool3o`00017ooooo0_l0001fooooo`007?ooool00ol0003o
ooooooooo`1Uooooo`;o00000_ooool2o`0000?ooooo0_l0000@ooooo`;o000000?oooooo`000?l0
00000_l0000Yooooo`;o00002Oooool2o`000003ooooool0003o000000[ooooo0ol00004ooooo`;o
000000?oooooo`000?l00000Loooool001cooooo00?o0000ooooooooool0I?ooool3o`0000;ooooo
0_l00003ooooo`;o00002?ooool2o`0000Kooooo0_l000000ooooooo0000o`00000Xooooo`;o0000
2oooool3o`0000gooooo0ol00002ooooo`;o00000oooool2o`0007?ooooo000Looooo`03o`000?oo
oooooooo06?ooooo0ol0000Booooo`;o00001_ooool2o`0000;ooooo0_l0000Rooooo`;o00000ooo
ool2o`0000_ooooo0_l00004ooooo`;o000000?oooooo`000?l000002_ooool2o`0000Sooooo0_l0
0004ooooo`;o0000J?ooool001cooooo00?o0000ooooooooool0F?ooool2o`0000Gooooo0_l00002
ooooo`;o00002?ooool2o`0000Wooooo0ol00009ooooo`;o00001_ooool2o`0001[ooooo0_l00002
ooooo`?o00001Oooool2o`0000[ooooo0_l000000ooooooo0000o`00000Booooo`Co00001?ooool2
o`0006Sooooo000Looooo`03o`000?oooooooooo05Sooooo0_l00005ooooo`;o00003?ooool2o`00
00?ooooo1?l00002ooooo`?o00001oooool2o`0000Sooooo0_l0000Nooooo`?o00001Oooool2o`00
0004ooooool0003o0000o`0000Sooooo0ol0000>ooooo`;o00000_ooool2o`00073ooooo000Loooo
o`03o`000?oooooooooo07;ooooo1?l00003ooooo`;o00001oooool2o`0000Sooooo0_l0000Toooo
o`;o00000oooool5o`0000Kooooo0ol00005ooooo`;o00001oooool2o`00017ooooo0_l0001Qoooo
o`007?ooool2o`0005Kooooo0_l000000ooooooo0000o`000007ooooo`;o00003Oooool4o`0001So
oooo0_l0000Rooooo`Co00001_ooool2o`0000Oooooo0_l00005ooooo`;o00004Oooool2o`0000Oo
oooo0_l0001Qooooo`007?ooool00ol0003oooooooooo`1Eooooo`;o000000?oooooo`000?l00000
1Oooool4o`0000gooooo1?l00006ooooo`;o00001oooool2o`0000Kooooo0_l0000Iooooo`;o0000
2?ooool2o`00017ooooo0_l00005ooooo`;o00004Oooool2o`0000oooooo0_l0001Iooooo`007?oo
ool00ol0003oooooooooo`1Hooooo`;o00000_ooool5o`0000gooooo0_l00003ooooo`;o00001Ooo
ool2o`0000Oooooo0_l00006ooooo`;o00006Oooool2o`00027ooooo0_l0000;ooooo`;o00005_oo
ool2o`0005Wooooo000Looooo`03o`000?oooooooooo05Sooooo0_l00002ooooo`Co00002?ooool4
o`0000;ooooo0_l00003ooooo`Co00001oooool3o`0002[ooooo0_l00008ooooo`;o00002oooool2
o`0000Gooooo0_l00008ooooo`;o000000?oooooo`000?l000000_l0001_ooooo`007?ooool00ol0
003oooooooooo`1Cooooo`;o00004oooool5o`0000Sooooo0_l00007ooooo`?o00003Oooool2o`00
01Gooooo0_l00002ooooo`Co00002?ooool2o`0000Cooooo0_l00005ooooo`;o00003oooool2o`00
00?ooooo0_l0001_ooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00002?ooool2o`0000So
oooo0_l00002ooooo`;o00000oooool2o`0000Cooooo0_l00003ooooo`;o00002Oooool2o`0000Ko
oooo0_l0000Eooooo`[o00003?ooool2o`0000?ooooo0_l00006ooooo`;o00001_ooool2o`0000co
oooo1?l0001Wooooo`007?ooool00ol0003oooooooooo`1Kooooo`Co00000_ooool2o`0000Cooooo
0_l00007ooooo`;o00001?ooool2o`0000?ooooo0_l00009ooooo`;o00001?ooool2o`0001Wooooo
0_l00002ooooo`Co00003_ooool2o`000004ooooool0003o0000ooooo`;o00000oooool2o`0000Ko
oooo0_l00006ooooo`;o00001?ooool4o`0006Oooooo000Looooo`03o`000?oooooooooo05[ooooo
0ol00004ooooo`;o0000:Oooool2o`0001cooooo0_l00005ooooo`;o00001Oooool2o`0000?ooooo
0_l00004ooooo`;o00004oooool2o`0000;ooooo1?l0001Yooooo`007?ooool00ol0003ooooooooo
o`18ooooo`;o00004?ooool2o`0000Gooooo0_l00004ooooo`;o00000_ooool2o`0000Kooooo0_l0
000;ooooo`;o0000:?ooool2o`0000Cooooo1Ol00003ooooo`;o00001_ooool2o`0000[ooooo0_l0
0002ooooo`;o00000_ooool2o`0000Kooooo1?l0001Yooooo`007?ooool00ol0003oooooooooo`18
ooooo`;o00006oooool4o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`Co00002?ooool3
o`0000[ooooo0_l00002ooooo`;o00007_ooool2o`000003ooooool0003o000000;ooooo0_l00007
ooooo`;o00002_ooool2o`0000;ooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l0
0002ooooo`;o0000JOooool001cooooo00?o0000ooooooooool0IOooool2o`0000Oooooo0_l00005
ooooo`;o00002?ooool2o`0000_ooooo0_l00002ooooo`;o00009Oooool2o`0000Sooooo0_l00004
ooooo`;o00001oooool2o`0000Gooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool2
o`00013ooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`1Rooooo`;o00002_ooool2o`00
00oooooo0_l0000=ooooo`;o000000?oooooo`000?l000009oooool2o`0000Gooooo0_l00004oooo
o`;o00001oooool2o`0000_ooooo0_l000000ooooooo0000o`000002o`00013ooooo0_l0001Coooo
o`007?ooool00ol0003oooooooooo`1Kooooo`;o00001Oooool2o`0000Cooooo0_l00003ooooo`;o
00002Oooool2o`0000Gooooo0_l0000=ooooo`;o000000?oooooo`000?l000004?ooool2o`0000[o
oooo0_l00009ooooo`?o00002oooool2o`0000Gooooo0_l000000ooooooo0000o`000002ooooo`;o
00000_ooool2o`000003ooooool0003o000000?o0000Ioooool001cooooo00?o0000ooooooooool0
Foooool2o`0000Wooooo1?l00003ooooo`;o00002Oooool2o`0000Kooooo0_l0000<ooooo`;o0000
1?ooool2o`0000gooooo0_l000000ooooooo0000o`000002o`0000Gooooo0_l0000:ooooo`;o0000
2oooool2o`0000Gooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool2o`0000?ooooo
0_l0000Kooooo`;o0000Boooool001cooooo00?o0000ooooooooool0Boooool4o`0000[ooooo0_l0
000:ooooo`?o00004Oooool2o`0000Gooooo0_l0000<ooooo`;o000000Coooooo`000?l0003ooooo
0_l0000@ooooo`Go00002oooool2o`0000Wooooo0_l0000iooooo`;o0000Boooool001cooooo00?o
0000ooooooooool0Boooool4o`000003ooooool0003o000000;o00000oooool4o`0000[ooooo0_l0
0006ooooo`;o00002_ooool2o`0001Kooooo1Ol0000Cooooo`Co00002Oooool2o`0000Wooooo0_l0
000Looooo`?o00002Oooool2o`000003ooooool0003o000005Wooooo000Looooo`;o0000DOooool4
o`0000?ooooo0_l0000Dooooo`;o00000oooool2o`0000Sooooo0_l00009ooooo`;o00002?ooool5
o`0001;ooooo0_l000000ooooooo0000o`000009ooooo`;o00005Oooool2o`0000Kooooo0_l00008
ooooo`Oo00001Oooool2o`000003ooooool0003o000005Wooooo000Looooo`03o`000?oooooooooo
05;ooooo0_l0000>ooooo`;o00000_ooool2o`0000[ooooo0_l00008ooooo`;o00002Oooool2o`00
00Sooooo0_l0000Eooooo`;o00003?ooool2o`0001Gooooo0_l00006ooooo`;o00002oooool4o`00
0003ooooool0003o000000Gooooo0_l0001Iooooo`007?ooool00ol0003oooooooooo`18ooooo`;o
00000oooool2o`0000cooooo0_l00005ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`00
00?ooooo0_l0000Dooooo`;o00004_ooool2o`0000Sooooo1?l0000;ooooo`;o00005Oooool2o`00
00?ooooo1Ol0000Eooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0B?ooool2o`0000?o
oooo0_l00002ooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`000005ooooo`;o
00000_ooool2o`0000?ooooo0_l0000:ooooo`;o00002?ooool2o`0001;ooooo0_l00008ooooo`Co
00002?ooool2o`000003ooooool0003o000000Kooooo0_l00003ooooo`;o00002?ooool2o`0000Co
oooo1_l0000Kooooo`;o0000F?ooool001cooooo00?o0000ooooooooool0DOooool2o`0000;ooooo
0_l00002ooooo`;o00000oooool2o`0000[ooooo1Ol0000;ooooo`;o00002oooool2o`0002Gooooo
0ol00003ooooo`Co000000?oooooo`000?l000000oooool2o`000003ooooool0003o000000gooooo
1?l0000Fooooo`;o00000oooool3o`0005Oooooo000Looooo`03o`000?oooooooooo04_ooooo0ol0
000;ooooo`;o00003oooool5o`000003ooooool0003o000000?ooooo0_l00005ooooo`;o00000_oo
ool2o`0000Gooooo0_l0000=ooooo`;o00004oooool2o`0000;ooooo0_l00003ooooo`Co00001?oo
ool2o`0000?ooooo0_l0000Vooooo`?o00001?ooool2o`0000Sooooo0_l0001=ooooo`007?ooool0
0ol0003oooooooooo`1;ooooo`?o00000oooool3o`0000_ooooo0_l0000;ooooo`;o00000_ooool2
o`0000?ooooo0_l00005ooooo`;o00000_ooool2o`0000kooooo1?l00002ooooo`;o00001_ooool2
o`0000_ooooo0_l000000ooooooo0000o`000002o`0000[ooooo0_l000000ooooooo0000o`000008
ooooo`;o00002_ooool2o`0000Oooooo0_l000001?oooooo0000o`000?l00003ooooo`Co00002?oo
ool2o`0000Gooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00000_ooool3
o`0000_ooooo0_l00004ooooo`;o00001Oooool4o`0000Oooooo0_l0000;ooooo`;o00002_ooool4
o`0000Oooooo0_l000000ooooooo0000o`00000>ooooo`Co00002?ooool2o`0000?ooooo0_l00002
ooooo`?o000000?oooooo`000?l000000_l0000:ooooo`;o00001oooool2o`000004ooooool0003o
0000o`0000?ooooo0ol00009ooooo`;o0000E?ooool001cooooo00?o0000ooooooooool0Boooool4
o`0000_ooooo0_l00009ooooo`;o00001Oooool4o`000003ooooool0003o000000Cooooo1?l00003
ooooo`Go000000?oooooo`000?l000001Oooool2o`0000kooooo0_l00009ooooo`;o00001?ooool2
o`0000cooooo0_l00007ooooo`Ko000000?oooooo`000?l000001?ooool3o`0000;ooooo0_l00000
0ooooooo0000o`000005ooooo`;o00001Oooool4o`000003ooooool0003o000005cooooo000Loooo
o`03o`000?oooooooooo03kooooo0_l0000;ooooo`?o00002?ooool2o`0000;ooooo1ol00002oooo
o`Co00001?ooool5o`000004ooooool0003o0000o`0000?ooooo1?l000000ooooooo0000o`000007
o`0000Kooooo0_l00006ooooo`;o00002_ooool2o`0000Gooooo0_l000001?oooooo0000o`000?oo
ool2o`0000Wooooo0_l0000:ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Cooooo0ol0
0002ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Gooooo0ol00002ooooo`;o00004_oo
ool2o`0004Sooooo000Looooo`03o`000?oooooooooo03[ooooo0_l00002ooooo`;o00003?ooool3
o`0000Oooooo0_l00003ooooo`Ko00000_ooool4o`0000?ooooo0ol000000ooooooo0000o`000002
ooooo`;o00000_ooool8o`000003ooooool0003o000000Co00002Oooool2o`0000?ooooo0_l0000:
ooooo`;o00002?ooool2o`0000cooooo0_l0000Aooooo`;o000000?oooooo`000?l000000_ooool6
o`0000Sooooo0_l00005ooooo`?o00000_ooool2o`0001;ooooo0_l00018ooooo`007?ooool00ol0
003oooooooooo`0jooooo`;o00003?ooool2o`0000?ooooo0_l0000<ooooo`Co00001?ooool4o`00
00?ooooo0ol00002ooooo`;o00001Oooool6o`0000?ooooo1Ol00006ooooo`;o00000_ooool2o`00
00kooooo0ol00004ooooo`;o00003_ooool4o`0000Cooooo2?l00007ooooo`?o00000_ooool4o`00
00[ooooo0_l00005ooooo`;o0000HOooool001cooooo00?o0000ooooooooool0B?ooool2o`0001?o
oooo0_l00006ooooo`Co000000Coooooo`000?l0003o00000_ooool>o`000003ooooool0003o0000
00;ooooo0ol000000ooooooo0000o`000002ooooo`Co00004?ooool3o`0000Cooooo0_l0000>oooo
o`Co00000oooool9o`0000;ooooo0_l00002ooooo`?o00001Oooool2o`0007Cooooo000Looooo`03
o`000?oooooooooo04Wooooo1?l00008ooooo`;o00004?ooool2o`0000Cooooo5?l00002ooooo`Ko
00000_ooool3o`0000?ooooo0_l0000Nooooo`;o00000_ooool2o`000005ooooool0003o0000o`00
0?ooool01?l000000ooooooo0000o`000004ooooo`;o00000_ooool2o`0000Gooooo1?l0000Moooo
o`;o000000?oooooo`000?l000001Oooool2o`0000Gooooo0_l00013ooooo`007?ooool00ol0003o
ooooooooo`19ooooo`Co00002?ooool2o`0000gooooo0_l00007oooooaco00002?ooool2o`00017o
oooo0_l00002ooooo`;o00001oooool2o`000005ooooool0003o0000o`000?ooool01ol000000ooo
oooo0000o`000005ooooo`?o000000?oooooo`000?l000001Oooool4o`0000Kooooo0_l0000>oooo
o`;o00001Oooool2o`000003ooooool0003o000000Gooooo0_l00005ooooo`;o0000@oooool001co
oooo00?o0000ooooooooool0C?ooool2o`0001Kooooo0_l00002ooooo`;o00000_ooool4o`000003
ooooool0003o0000013o00000_ooool4o`0000Sooooo1?l0000;ooooo`;o00000_ooool2o`0000;o
oooo0_l00008ooooo`Co00000oooool9o`0000?ooooo1Ol000000ooooooo0000o`000002o`000004
ooooool0003o0000o`0000Wooooo0_l0000>ooooo`;o0000Foooool001cooooo0_l0001=ooooo`;o
00006_ooool2o`0000;ooooo1?l000000ooooooo0000o`00000Go`0000Gooooo1_l0000;ooooo`;o
00004?ooool3o`000003ooooool0003o000000;ooooo5Ol000001?oooooo0000o`000?l00005oooo
o`;o0000Koooool001cooooo00?o0000ooooooooool0B?ooool2o`0000_ooooo0_l0000:ooooo`;o
000000?oooooo`000?l000000oooool2o`0000;ooooo7Ol00005ooooo`Go00003Oooool2o`0000[o
oooo0_l00004ooooo`;o000000?oooooo`000?l000000_ooool;o`000003ooooool0003o000000Oo
000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00001oooool2o`000004ooooool0003o0000
o`0006;ooooo000Looooo`03o`000?oooooooooo04Sooooo0_l0000;ooooo`;o00002_ooool2o`00
0003ooooool0003o000000?ooooo0_l00002oooooaWo00005Oooool2o`0000Cooooo0_l0000:oooo
o`;o00001?ooool3o`0000;ooooo1Ol000000ooooooo0000o`000006o`000003ooooool0003o0000
00Ko000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00001oooool2o`000004ooooool0003o
0000o`0000[ooooo1?l0001Dooooo`007?ooool00ol0003oooooooooo`10ooooo`?o000000Cooooo
o`000?l0003o00006_ooool2o`0000Sooooo0_l000000ooooooo0000o`00000Io`0000cooooo0_l0
0004ooooo`;o00000oooool2o`00017ooooo1?l000000ooooooo0000o`000005o`000003ooooool0
003o000000ko000000?oooooo`000?l000000ol0000Eooooo`;o00001?ooool4o`0000gooooo0ol0
0014ooooo`007?ooool00ol0003oooooooooo`0jooooo`;o00000oooool4o`000003ooooool0003o
000000?o00003_ooool2o`0000Kooooo0_l0000:ooooo`;o000000?oooooo`000?l000006Ol00000
0ooooooo0000o`000005ooooo`;o00000_ooool2o`0000Wooooo0_l00004ooooo`;o00002oooool4
o`000003ooooool0003o000001ko00003_ooool2o`0000?ooooo0_l00009ooooo`?o00002Oooool3
o`0004Cooooo000Looooo`03o`000?oooooooooo03[ooooo0_l00003ooooo`;o000000?oooooo`00
0?l000001ol0000<ooooo`;o00001_ooool4o`0000Gooooo0_l00005oooooaWo00000_ooool2o`00
00Cooooo0ol0000<ooooo`?o00001?ooool2o`0000Kooooo0_l000000ooooooo0000o`00000Uo`00
00kooooo0_l0000>ooooo`?o000000?oooooo`000?l000001?ooool2o`0004Oooooo000Looooo`03
o`000?oooooooooo04;ooooo0ol00004ooooo`;o00001Oooool2o`0000[ooooo0_l000000ooooooo
0000o`000002o`0000Gooooo0_l00005ooooo`Go000000?oooooo`000?l000004Ol00004ooooo`;o
00000_ooool2o`0000Gooooo0_l00006ooooo`;o00002Oooool2o`000005ooooool0003o0000o`00
0?ooool01Ol000000ooooooo0000o`000004o`000003ooooool0003o000001Co000000?oooooo`00
0?l000001oooool2o`0000_ooooo0_l0000=ooooo`;o00001?ooool2o`0004Oooooo000Looooo`03
o`000?oooooooooo04Cooooo0_l000001?oooooo0000o`000?l00004ooooo`Co00002_ooool2o`00
0003ooooool0003o000000;o00002?ooool2o`0000;ooooo6ol00002ooooo`;o00002Oooool2o`00
00[ooooo1?l00003ooooo`;o000000?oooooo`000?l000000_ooool3o`0000?ooooo6_l00005oooo
o`;o00001Oooool3o`0000Oooooo0_l00002ooooo`;o00002oooool2o`0004oooooo000Looooo`03
o`000?oooooooooo03oooooo0ol000001Ooooooo0000o`000?l0003ooooo00?o00001?ooool2o`00
01_ooooo0_l00002ooooo`ko000000?oooooo`000?l000001ol000000ooooooo0000o`00000Ioooo
o`Co00001_ooool9o`000003ooooool0003o000000go000000?oooooo`000?l000003ol00005oooo
o`;o00001oooool3o`0000oooooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`0dooooo`;o
00000_ooool2o`0000Gooooo0ol000000ooooooo0000o`000009ooooo`;o00005Oooool2o`0000Oo
oooo6?l000001?oooooo0000o`000?l0000Tooooo`ko000000?oooooo`000?l000006?l00002oooo
o`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo0_l0001Qooooo`007?ooool00ol0003o
ooooooooo`0dooooo`;o00000_ooool3o`0000Gooooo0_l0000;ooooo`?o00005Oooool2o`0000Ko
oooo3Ol000000ooooooo0000o`000009o`000003ooooool0003o000000;o00001Oooool2o`0000So
oooo0_l00002ooooo`;o00002_ooool3o`000003ooooool0003o000000;ooooo9Ol00002ooooo`Go
00001?ooool4o`00017ooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`0iooooo`;o0000
3?ooool2o`0000Cooooo1?l000000ooooooo0000o`00000Iooooo`;o000000?oooooo`000?l00000
2Ol000000ooooooo0000o`00000Ao`000003ooooool0003o000000Sooooo0_l00002ooooo`?o0000
2Oooool3o`000003ooooool0003o000002Ko000000Coooooo`000?l0003ooooo0_l00008ooooo`Go
00000oooool5o`0000Gooooo0ol00005ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0
>?ooool4o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`Co00000oooool3o`000003oooo
ool0003o000000;ooooo0_l00004ooooo`;o00004OoooolPo`00013ooooo0_l00009ooooo`;o0000
00Coooooo`000?l0003ooooo5Ol000000ooooooo0000o`00000>o`000003ooooool0003o000000;o
00002oooool3o`0000?ooooo1Ol00005ooooo`?o00000_ooool2o`000003ooooool0003o000000So
oooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0hooooo`Co00000_ooool2o`000003oooo
ool0003o000000Cooooo2Ol00004ooooo`Co00000_ooool4o`0000;ooooo0_l0000<oooooa[o0000
0_ooool2o`0000Cooooo0ol0000Eooooo`;o00000ooooolXo`0000?ooooo0ol00005ooooo`;o0000
1Oooool2o`0000;ooooo1Ol0000;ooooo`;o00001Oooool2o`0000;ooooo1?l0000oooooo`0000Ko
ooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Co
oooo00?o0000ooooooooool0B_ooool4o`0000Kooooo0_l000000ooooooo0000o`000003o`0000Co
oooo0_l00008ooooo`?o000000?oooooo`000?l000006ol00005ooooo`?o000000?oooooo`000?l0
00004_oooolZo`000004ooooool0003o0000o`0000;ooooo1Ol00003ooooo`;o00001?ooool3o`00
00;ooooo0ol00004ooooo`;o00003_ooool2o`0000;ooooo0_l00011ooooo`0000KoooooogMgMonH
V9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo047ooooo0_l0000Dooooo`Go00003Oooool4o`0000?ooooo6ol000000ooooooo0000o`000006
ooooo`;o00001_ooool2o`0000[ooooo1ol000000ooooooo0000o`00000>o`000003ooooool0003o
000001?o00000_ooool5o`0000?ooooo0_l00002ooooo`Co00001?ooool2o`0000Cooooo0_l0001E
ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`Go00001_ooool00ol0
003oooooooooo`11ooooo`;o00000oooool2o`0000Oooooo0_l00003ooooo`;o00000oooool2o`00
00;ooooo0_l0000:ooooo`;o00000ooooolAo`000003ooooool0003o000000co000000?oooooo`00
0?l000002oooool2o`0000cooooo1Ol00002ooooo`oo000000?oooooo`000?l000001_l000000ooo
oooo0000o`000009o`000003ooooool0003o000000?o00001Oooool2o`0000;ooooo0_l0001Soooo
o`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`00
00Oooooo0ol0000hooooo`;o00003?ooool3o`000003ooooool0003o000000;o000000?oooooo`00
0?l000000oooool2o`0000Oooooo0_l0000<ooooo`;o000000?oooooo`000?l000002ol000000ooo
oooo0000o`00000?o`0000;ooooo0_l0000Kooooo`?o000000?oooooo`000?l000008ol000000ooo
oooo0000o`000003o`0000Cooooo0_l0001Xooooo`0000?oooooo`000?ooool00_ooool00ol0003o
ooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0>?ooool2o`00
0003ooooool0003o000000Cooooo0_l00004ooooo`Oo00003_ooool2o`0000gooooo0_l000000ooo
oooo0000o`00000Lo`0000;ooooo0_l00009ooooo`;o00003oooool5o`000003ooooool0003o0000
02?o00001?ooool2o`0000;ooooo1?l00003ooooo`;o0000Hoooool00003ooooool@413ooooo00;o
oooo00?o410@ooooooooool02_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo03_o
oooo0_l00004ooooo`?o00001Oooool2o`00017ooooo1?l0000<ooooo`So000000?oooooo`000?l0
00004?l00005ooooo`Co000000Goooooo`000?l0003o0000ooooo`02o`000004ooooool0003o0000
o`0000Sooooo0_l00005ooooo`Go000000?oooooo`000?l00000:Ol000001?oooooo0000o`000?l0
0005ooooo`;o00000_ooool4o`0000;ooooo0_l0000?ooooo`Co0000A_ooool00006oooooomgMgOo
V9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo03Sooooo
0_l00003ooooo`;o00000oooool2o`0000?ooooo0_l000000ooooooo0000o`000007ooooo`;o0000
00?oooooo`000?l000000oooool5o`0000cooooo0_l000000ooooooo0000o`000006o`000003oooo
ool0003o000000ko00001?ooool3o`0000;ooooo1_l000000ooooooo0000o`000009ooooo`;o0000
1?ooool3o`0000?ooooo;?l000000ooooooo0000o`000003ooooo`;o00001Oooool4o`0000;ooooo
0_l0000?ooooo`Co00000oooool2o`00047ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPgo
oooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`0aooooo`;o00001Oooool2o`0000?o
oooo1?l00006ooooo`;o000000?oooooo`000?l000000ol00004ooooo`;o000000?oooooo`000?l0
00000oooool2o`0000oooooo0ol00002ooooo`Ko000000?oooooo`000?l000003_l0000<ooooo`;o
00003Oooool2o`0000Cooooo0_l00004ooooo`ko000000?oooooo`000?l000005_l00004ooooo`[o
00001?ooool2o`0001Gooooo1?l00003ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0
<Oooool2o`0000Cooooo0ol00005ooooo`;o00001oooool2o`0000;ooooo0ol0000=ooooo`;o0000
3oooool2o`0000?ooooo5ol0000<ooooo`;o00000_ooool2o`0000Sooooo0_l000001?oooooo0000
o`000?ooool4o`0000;ooooo0_l000000ooooooo0000o`00000Ro`0000Cooooo1ol000000ooooooo
0000o`00000Jooooo`Co0000Aoooool001cooooo00?o0000ooooooooool0=_ooool3o`0000oooooo
0_l000000ooooooo0000o`000003ooooo`;o00001_ooool2o`0000;ooooo0_l0000Booooo`?o0000
0ooooolCo`0000cooooo0ol000000ooooooo0000o`000002ooooo`;o00000_ooool2o`0000?ooooo
0_l000000ooooooo0000o`000002o`0000;ooooo9_l00007ooooo`Co000000?oooooo`000?l00000
6oooool3o`0000kooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00004?oo
ool2o`000004ooooool0003o0000ooooo`Co00001_ooool2o`0000cooooo0_l00003ooooo`?o0000
0_ooool4o`0000;ooooo0ol000000ooooooo0000o`000003o`000003ooooool0003o000000;o0000
1?ooool2o`0000cooooo0_l00005ooooo`;o00000_ooool2o`0000Kooooo0_l00003ooooob?o0000
00Coooooo`000?l0003o00002Oooool2o`000003ooooool0003o000000Cooooo0_l0000Mooooo`;o
00001oooool2o`0003Sooooo000Looooo`03o`000?oooooooooo03kooooo0_l00008ooooo`;o0000
1?ooool2o`0000cooooo0ol00003ooooo`;o00000_ooool2o`0000?ooooo0ol00004ooooo`Oo0000
00Coooooo`000?l0003ooooo1Ol00002ooooo`Ko00002_ooool2o`0000Cooooo0_l0000=ooooo`?o
00000_oooolZo`000003ooooool0003o000000[ooooo1?l000000ooooooo0000o`00000Jooooo`;o
0000@Oooool001cooooo00?o0000ooooooooool0=_ooool2o`0000Kooooo0_l00009ooooo`;o0000
2?ooool2o`0000Kooooo1Ol00002ooooo`;o00000oooool3o`0000[ooooo0_l00004ooooo`?o0000
00Coooooo`000?l0003o00000oooool8o`0000Oooooo0ol00004ooooo`;o000000?oooooo`000?l0
00000oooool2o`0000Gooooo0ol000000ooooooo0000o`00000Ao`000003ooooool0003o000001Go
000000Coooooo`000?l0003o00002Oooool2o`0000?ooooo0ol00003ooooo`;o00007_ooool3o`00
03Kooooo000Looooo`03o`000?oooooooooo03Kooooo0_l00006ooooo`;o00001oooool4o`0000Co
oooo0_l000001?oooooo0000o`000?l00006ooooo`Go00001oooool3o`00017ooooo0_l00007oooo
o`;o00001?ooool2o`0000Oooooo0_l00002ooooo`Co00000_ooool2o`0000?ooooo0_l00007oooo
o`Ko000000?oooooo`000?l000008ol00003ooooo`;o00000oooool2o`0000Gooooo0_l00002oooo
o`?o00000oooool2o`0001kooooo0ol0000fooooo`007?ooool00ol0003oooooooooo`0nooooo`;o
00001Oooool4o`0000Gooooo0ol000000ooooooo0000o`000002ooooo`;o00001?ooool2o`0001co
oooo0_l000000ooooooo0000o`00000<ooooo`;o00002_ooool4o`0000cooooo0ol000000ooooooo
0000o`000003oooooaKo00000_ooool?o`0000Cooooo0_l00002ooooo`;o00001Oooool2o`0000co
oooo0_l0000?ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0>?ooool2o`0000_ooooo
0_l00002ooooo`;o00000oooool2o`0000Kooooo0_l00005ooooo`;o00003Oooool2o`0000Sooooo
0_l00002ooooo`;o000000?oooooo`000?l000002?ooool2o`0000;ooooo0_l0000Gooooo`;o0000
00Goooooo`000?l0003o0000ooooo`02o`000003ooooool0003o000000;o000000?oooooo`000?l0
00004Ol00002ooooo`Wo000000?oooooo`000?l000000_l000000ooooooo0000o`000002ooooo`;o
00001?ooool2o`0000?ooooo0_l00005ooooo`;o00000oooool4o`0000[ooooo0_l00003ooooo`;o
0000@_ooool001cooooo00?o0000ooooooooool0=Oooool5o`0000oooooo1?l00009ooooo`;o0000
1Oooool2o`0000Sooooo0_l00003ooooo`;o00002?ooool2o`0000[ooooo0_l00003ooooo`;o0000
6oooool2o`0000Gooooo0_l000000ooooooo0000o`000003o`0000;ooooo4Ol00002ooooo`_o0000
1?ooool3o`0000Oooooo0ol00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo
0_l000000ooooooo0000o`000004ooooo`;o00000oooool2o`0000;ooooo0_l00013ooooo`007?oo
ool00ol0003oooooooooo`0eooooo`Co00002oooool2o`0000Gooooo0_l00009ooooo`Ko00002ooo
ool2o`000003ooooool0003o000000Wooooo0_l0000;ooooo`;o00005Oooool2o`00013ooooo0_l0
0002ooooo`Co000000?oooooo`000?l000005ol000000ooooooo0000o`000003o`0000Gooooo0ol0
0007ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o00001Oooool4o`0000Cooooo
0_l00007ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0?_ooool2o`0000Cooooo0_l0
000@ooooo`Ko00003_ooool2o`0000Wooooo0_l0000Rooooo`?o00003oooool2o`000003ooooool0
003o000000;o00000_oooolIo`000003ooooool0003o000000Co00001Oooool2o`0000Gooooo0_l0
0007ooooo`Go00001?ooool3o`0000oooooo1_l0000oooooo`007?ooool2o`0003oooooo0_l0000]
ooooo`;o00003_ooool2o`0000Oooooo0ol00008ooooo`;o00001oooool2o`0000gooooo0_l00000
0ooooooo0000o`000003o`0000Cooooo6Ol00002ooooo`Go00001?ooool2o`0000Gooooo0_l00008
ooooo`?o00001Oooool2o`0000;ooooo0_l0000;ooooo`Oo0000?oooool001cooooo00?o0000oooo
ooooool0AOooool2o`0000Cooooo0_l0000Fooooo`;o00002?ooool2o`0000kooooo0ol00006oooo
o`?o000000?oooooo`000?l000001Oooool2o`0000?ooooo0_l00002ooooo`;o00003Oooool2o`00
0005ooooool0003o0000o`000?ooool01Ol000000ooooooo0000o`00000Ho`0000?ooooo0_l00004
ooooo`?o00001Oooool3o`0000Sooooo0_l00004ooooo`;o00000_ooool2o`0000_ooooo0_l00005
ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0<_ooool2o`0000Cooooo0_l00007oooo
o`;o00000_ooool2o`0000Cooooo0_l0000Fooooo`;o00002oooool2o`0000;ooooo0_l00008oooo
o`;o00001?ooool2o`0000Cooooo0_l0000:ooooo`;o00000_ooool2o`0000[ooooo0_l00002oooo
o`;o000000?oooooo`000?l000001_l00003ooooo`;o000000?oooooo`000?l000003_l00003oooo
o`Co00000oooool9o`000003ooooool0003o000000?o00002?ooool2o`0001cooooo0_l0000;oooo
o`;o0000<?ooool001cooooo00?o0000ooooooooool0:oooool2o`0000Gooooo0_l00004ooooo`;o
00001oooool2o`0000_ooooo0_l0000Pooooo`;o00000_ooool3o`0000Gooooo0_l00006ooooo`;o
00001?ooool2o`0000gooooo1?l00009ooooo`;o00000_ooool2o`0000;ooooo1?l00003ooooo`;o
000000?oooooo`000?l000001_l00002ooooo`go000000?oooooo`000?l000000_l000000ooooooo
0000o`000002o`0000?ooooo0_l000001?oooooo0000o`000?l0000@ooooo`;o00008oooool2o`00
033ooooo000Looooo`03o`000?oooooooooo02_ooooo0_l00007ooooo`;o00002oooool3o`0000Ko
oooo0_l000000ooooooo0000o`000003o`0001Sooooo0_l00009ooooo`;o00001Oooool2o`0000co
oooo0_l0000=ooooo`Co000000?oooooo`000?l000001oooool2o`0000Gooooo1?l00003ooooo`Oo
000000?oooooo`000?l000001_l00002ooooo`So00000oooool2o`0000[ooooo1?l0000=ooooo`;o
000000?oooooo`000?l00000EOooool001cooooo00?o0000ooooooooool0<Oooool2o`000003oooo
ool0003o000000cooooo0ol00005ooooo`Go000000?oooooo`000?l000003?ooool2o`0000Cooooo
0_l00004ooooo`?o00003Oooool2o`0001_ooooo0_l000000ooooooo0000o`000002ooooo`;o0000
1oooool2o`0000Cooooo0_l00004ooooo`Ko00001?ooool5o`0000Cooooo1?l00003ooooo`;o0000
3oooool4o`0000?ooooo0_l00002ooooo`Co00000_ooool4o`00023ooooo0_l0000dooooo`007?oo
ool00ol0003oooooooooo`0aooooo`;o00001?ooool2o`0000Gooooo0ol00002ooooo`;o00001ooo
ool2o`0000oooooo0ol00004ooooo`;o00001Oooool2o`0000?ooooo0_l00007ooooo`?o00004ooo
ool2o`0000Kooooo0_l000000ooooooo0000o`00000Aooooo`Co00000_ooool9o`0000;ooooo0ol0
00000ooooooo0000o`000006o`0000Wooooo0_l00002ooooo`;o00001oooool2o`0000?ooooo0_l0
0002ooooo`Co00001?ooool2o`00023ooooo0_l0000dooooo`007?ooool00ol0003oooooooooo`0a
ooooo`;o00001?ooool2o`0000Gooooo0ol00002ooooo`;o00001Oooool4o`0000;ooooo0_l0000;
ooooo`;o00003oooool4o`0000Oooooo0_l0000Dooooo`;o00001oooool2o`0000?ooooo0_l0000;
ooooo`;o00000oooool2o`0000?ooooo2Ol00003ooooo`So00002oooool2o`0000;ooooo0_l00009
ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Kooooo0ol0000Cooooo`;o0000@?ooool0
01cooooo00?o0000ooooooooool0<?ooool3o`0000cooooo0_l00002ooooo`;o00001Oooool9o`00
00Sooooo1?l00004ooooo`;o00002Oooool5o`0002?ooooo1?l00003ooooo`;o000000?oooooo`00
0?l000002?ooool2o`0000Sooooo2_l00002ooooo`Wo000000?oooooo`000?l000004_ooool2o`00
00;ooooo1_l000000ooooooo0000o`000007ooooo`;o00004oooool2o`00043ooooo000Looooo`03
o`000?oooooooooo033ooooo0_l0000Gooooo`Co000000Coooooo`000?l0003ooooo0_l00008oooo
o`Co00001?ooool2o`0000Kooooo0_l00002ooooo`Co000000?oooooo`000?l000004_ooool3o`00
00Sooooo0_l000000ooooooo0000o`000008ooooo`;o00002oooool2o`0000?ooooo1?l000000ooo
oooo0000o`000006o`0000?ooooo1ol000000ooooooo0000o`000004ooooo`;o00003?ooool2o`00
00?ooooo1Ol0000:ooooo`Co00004Oooool2o`00043ooooo000Looooo`03o`000?oooooooooo033o
oooo0_l00004ooooo`;o00001oooool4o`0000Kooooo1?l0000Gooooo`;o000000Goooooo`000?l0
003o0000ooooo`02o`0000Oooooo0_l0000Booooo`?o00002?ooool3o`0000Cooooo0_l0000Aoooo
o`;o00000oooool7o`0000;ooooo1Ol00002ooooo`Oo00000_ooool3o`0000;ooooo1?l0000;oooo
o`;o00003_ooool2o`0000;ooooo0ol0000>ooooo`;o000000?oooooo`000?l00000@?ooool001co
oooo00?o0000ooooooooool0<?ooool2o`0000Cooooo0_l00002ooooo`;o00000oooool4o`0000Co
oooo0_l000000ooooooo0000o`00000Hooooo`Ko00006_ooool2o`0000Kooooo0_l00005ooooo`?o
00001?ooool2o`0000?ooooo0ol0000Booooo`Co00000oooool5o`0000Cooooo1?l00003ooooo`?o
000000?oooooo`000?l000001Ol00009ooooo`;o00003_ooool2o`0000;ooooo0ol0000>ooooo`;o
00000oooool2o`0003kooooo000Looooo`03o`000?oooooooooo02oooooo0_l00003ooooo`;o0000
1?ooool2o`0000Cooooo0_l00005ooooo`;o000000?oooooo`000?l000006Oooool5o`0000Kooooo
0_l00006ooooo`Ko000000?oooooo`000?l000000oooool2o`000003ooooool0003o000000?ooooo
0_l00005ooooo`;o00002_ooool4o`000003ooooool0003o000000Kooooo0_l00006ooooo`;o0000
1Oooool5o`0000;ooooo0_l00007ooooo`;o00000_ooool3o`0000;ooooo0_l0000cooooo`;o0000
?_ooool001cooooo00?o0000ooooooooool0:?ooool2o`0000Gooooo0_l00003ooooo`;o00002_oo
ool2o`0000?ooooo0_l0000Looooo`;o00002oooool2o`0000Kooooo1_l000000ooooooo0000o`00
0002ooooo`?o000000?oooooo`000?l000005_ooool7o`0000Kooooo0_l0000:ooooo`Co00000_oo
ool2o`0000;ooooo0ol00004ooooo`;o00002Oooool2o`0000?ooooo0_l0000Cooooo`;o000000?o
ooooo`000?l000004Oooool2o`0000?ooooo0_l00003ooooo`;o00001oooool2o`00033ooooo000L
ooooo`03o`000?oooooooooo02Sooooo0_l0000:ooooo`;o00003oooool2o`0001_ooooo0ol0000D
ooooo`;o00001Oooool2o`000003ooooool0003o000001gooooo0_l00009ooooo`;o00002Oooool4
o`0000Kooooo0ol00003ooooo`?o00003_ooool2o`0000Oooooo0_l000000ooooooo0000o`000002
o`0000Gooooo0_l000001?oooooo0000o`000?l0000@ooooo`;o00000oooool2o`0000?ooooo0_l0
0007ooooo`;o0000<?ooool001cooooo00?o0000ooooooooool0=Oooool2o`000003ooooool0003o
000000Wooooo0_l0000Mooooo`;o00002?ooool2o`0000?ooooo0_l00006ooooo`;o00001Oooool2
o`000003ooooool0003o000000Wooooo0_l0000Aooooo`Co00002?ooool2o`0000Sooooo0_l00004
ooooo`;o00000oooool2o`0000Cooooo0_l00004ooooo`;o00000oooool2o`0000gooooo0_l00000
0ooooooo0000o`000002o`0000Gooooo0_l00002ooooo`;o00004Oooool2o`0004;ooooo000Loooo
o`;o0000=?ooool4o`000003ooooool0003o000000Wooooo0_l00006ooooo`;o000000?oooooo`00
0?l000001Oooool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o000000?oooooo`00
0?l000000oooool4o`0000?ooooo0_l0000Kooooo`;o00000oooool2o`0000cooooo1?l0000Boooo
o`;o00001?ooool4o`000003ooooool0003o000000[ooooo0_l00003ooooo`;o00000oooool4o`00
01Cooooo1_l0000?ooooo`;o00001Oooool2o`0003_ooooo000Looooo`03o`000?oooooooooo02oo
oooo0_l00002ooooo`;o000000?oooooo`000?l000003oooool6o`000003ooooool0003o000000?o
oooo1?l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000Co000000?oooooo`00
0?l000000oooool2o`000005ooooool0003o0000o`000?ooool00ol0000@ooooo`;o00001oooool2
o`0000;ooooo1?l0000<ooooo`;o000000Coooooo`000?l0003o00006?ooool2o`000003ooooool0
003o000000Oooooo0_l0000;ooooo`Co00000oooool2o`0000;ooooo0_l0000;ooooo`Ko00003Ooo
ool2o`0000?ooooo0_l00002ooooo`;o00004oooool2o`0002Kooooo000Looooo`03o`000?oooooo
oooo02gooooo1?l00005ooooo`;o00003?ooool2o`000003ooooool0003o000000;o00000_ooool3
o`0000?ooooo0ol000000ooooooo0000o`000009o`0000Wooooo1Ol000001?oooooo0000o`000?l0
0002ooooo`;o00000oooool2o`0000Oooooo0_l00007ooooo`;o00000_ooool2o`0000kooooo1_l0
0006ooooo`;o00002Oooool2o`0000gooooo0_l00002ooooo`Co00002oooool2o`0000?ooooo0_l0
0002ooooo`;o00002?ooool2o`0000Sooooo0_l00009ooooo`?o00000_ooool4o`0001Kooooo0_l0
000Vooooo`007?ooool00ol0003oooooooooo`0Tooooo`;o00001oooool2o`0000?ooooo0_l0000@
ooooo`;o00001oooool3o`000003ooooool0003o000000?o000000?oooooo`000?l000002Ol00006
ooooo`;o000000?oooooo`000?l000004?l00005ooooo`;o00000_ooool4o`0001Sooooo0_l00009
ooooo`;o00001_ooool6o`0000Sooooo0_l00002ooooo`;o00001?ooool2o`0000_ooooo0_l00003
ooooo`?o00000_ooool2o`000003ooooool0003o000000Cooooo0_l00004ooooo`;o00000_ooool2
o`0000Wooooo0_l00002ooooo`Go0000?_ooool001cooooo00?o0000ooooooooool09?ooool2o`00
00Oooooo0ol00002ooooo`;o00004?ooool2o`000003ooooool0003o000000Sooooo1?l00006oooo
o`;o00002Oooool4o`000003ooooool0003o000000oo00001?ooool4o`0000;ooooo1?l0000Doooo
o`;o00000oooool3o`0000oooooo1_l00008ooooo`;o000000?oooooo`000?l000000_l0000Eoooo
o`?o00000_ooool2o`000004ooooool0003o0000ooooo`;o00001oooool2o`00017ooooo0_l0000B
ooooo`;o0000;Oooool001cooooo00?o0000ooooooooool0;_ooool2o`0000;ooooo0_l0000@oooo
o`;o000000?oooooo`000?l000000oooool2o`0000gooooo0_l00007ooooo`Co00000ooooolAo`00
0003ooooool0003o000000Co00001_ooool2o`0001?ooooo0_l00003ooooo`?o00001Oooool2o`00
00Wooooo1?l0000<ooooo`Co00005Oooool2o`0000Wooooo0_l00008ooooo`;o00009?ooool2o`00
02gooooo000Looooo`03o`000?oooooooooo02cooooo0_l000000ooooooo0000o`00000=ooooo`;o
00001?ooool2o`0000;ooooo0_l00002ooooo`;o00000oooool2o`00017ooooo0_l00003oooooaOo
00000oooool2o`0000;ooooo1?l0000Jooooo`Co00000_ooool2o`0000Cooooo0_l00003ooooo`;o
00002?ooool3o`00013ooooo0_l00002ooooo`Co00003oooool2o`0000Sooooo0_l0000Booooo`?o
00001?ooool2o`0003Sooooo000Looooo`03o`000?oooooooooo02cooooo1Ol0000=ooooo`;o0000
00Coooooo`000?l0003ooooo0_l00002ooooo`Go000000Coooooo`000?l0003ooooo0_l0000Coooo
oa[o00000oooool2o`0000;ooooo0_l0000:ooooo`;o00001_ooool2o`0000Cooooo0_l00002oooo
o`Co00002?ooool2o`0000gooooo0ol00003ooooo`;o00002oooool3o`000003ooooool0003o0000
00;o00001?ooool2o`000003ooooool0003o000000Kooooo0_l000000ooooooo0000o`000003oooo
o`Go00004?ooool4o`0000Cooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o
00004Oooool2o`0000Oooooo1_l0000Cooooo`;o000000?oooooo`000?l000006Ol0000Booooo`;o
00001_ooool4o`0000;ooooo0_l0000Sooooo`;o00003?ooool2o`0000?ooooo0_l00004ooooo`;o
000000?oooooo`000?l000002Oooool2o`0000?ooooo0_l000000ooooooo0000o`00000>ooooo`Go
0000?oooool001cooooo00?o0000ooooooooool0C?ooool2o`0000Sooooo0_l00007ooooo`;o0000
0_ooool2o`0000?ooooo6_l0000:ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Kooooo
0_l00003ooooo`;o00000oooool2o`000004ooooool0003o0000o`0000Gooooo0_l00002ooooo`;o
00002?ooool2o`0000_ooooo0_l0000:ooooo`;o00003Oooool2o`0001_ooooo0_l000000ooooooo
0000o`000003ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0;Oooool4o`0000_ooooo
0_l0000Hooooo`;o00000_ooool2o`0000?ooooo0_l00006oooooa_o00001Oooool2o`0000?ooooo
0_l000000ooooooo0000o`000002ooooo`Ko00002Oooool2o`0000?ooooo2?l00003ooooo`?o0000
00?oooooo`000?l000002?ooool2o`0000Kooooo0_l00003ooooo`Co000000?oooooo`000?l00000
0oooool2o`0000oooooo0_l0000Fooooo`;o00002oooool2o`0003[ooooo000Looooo`03o`000?oo
oooooooo02gooooo1?l000000ooooooo0000o`000008ooooo`;o00001Oooool3o`0001Cooooo0_l0
000;oooooa[o00001_ooool2o`0000[ooooo0_l000000ooooooo0000o`000003o`0000Kooooo0ol0
0004ooooo`;o00000oooool3o`0000?ooooo0_l0000Cooooo`;o00001?ooool6o`0000?ooooo0_l0
00000ooooooo0000o`00000Tooooo`;o00001Oooool2o`00043ooooo000Looooo`03o`000?oooooo
oooo02gooooo1?l000000ooooooo0000o`000008ooooo`;o000000?oooooo`000?l000000_ooool3
o`0002?ooooo5ol000000ooooooo0000o`00000Cooooo`;o000000?oooooo`000?l000001_ooool2
o`0000_ooooo1Ol00005ooooo`;o00004?ooool4o`0000?ooooo0_l00005ooooo`Co00002oooool2
o`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l0000>ooooo`;o00000oooool2
o`0000_ooooo0_l0000^ooooo`007?ooool00ol0003oooooooooo`0booooo`;o00002oooool5o`00
00?ooooo0_l0000Cooooo`;o00002_oooolHo`000004ooooool0003o0000o`0001cooooo0_l0000=
ooooo`Ko00000oooool2o`0000gooooo0_l000000ooooooo0000o`000007o`0000?ooooo1?l00003
ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`0000Gooooo0_l00002ooooo`;o000000?o
ooooo`000?l000000_l0000Cooooo`;o00002oooool2o`0002kooooo000Looooo`03o`000?oooooo
oooo047ooooo0ol00003ooooo`;o00000_ooool2o`0000Gooooo0_l00008ooooo`;o00001Oooool2
o`0000?ooooo6Ol000000ooooooo0000o`00000=ooooo`;o00000oooool2o`0000Sooooo0_l0000A
ooooo`;o00004_ooool2o`0000Cooooo1?l00005ooooo`Co00000oooool6o`0000Cooooo0_l0000>
ooooo`;o0000D?ooool001cooooo00?o0000ooooooooool0;oooool2o`0000Cooooo0_l0000Doooo
o`Co00000oooool2o`0000Sooooo0ol00004ooooo`Co000000?oooooo`000?l000005ol000000ooo
oooo0000o`00000=ooooo`;o00000oooool2o`0001Kooooo1?l00002ooooo`;o00000_ooool2o`00
00Kooooo0_l0000;ooooo`;o00001Oooool2o`000004ooooool0003o0000o`0000Cooooo0ol00005
ooooo`?o00003_ooool2o`0000Sooooo0_l00016ooooo`007?ooool2o`0002_ooooo1?l000000ooo
oooo0000o`000004ooooo`;o00002oooool2o`0000Cooooo0_l00002ooooo`?o00002?ooool4o`00
00;ooooo0_l00006oooooaSo000000?oooooo`000?l000000ol00007ooooo`;o00000_ooool2o`00
0005ooooool0003o0000o`000?ooool00ol0000Fooooo`Co00000_ooool2o`000005ooooool0003o
0000o`000?ooool00_l00003ooooo`;o00002oooool2o`0000Gooooo0_l000000ooooooo0000o`00
0005ooooo`;o00001?ooool4o`0000Cooooo0_l0000;ooooo`;o00000_ooool2o`0000;ooooo0_l0
0016ooooo`007?ooool00ol0003oooooooooo`0Zooooo`Co00001oooool2o`0000_ooooo0_l00004
ooooo`;o00003Oooool4o`0000cooooo0ol000000ooooooo0000o`00000=o`000004ooooool0003o
0000ooooo`Go00001Oooool4o`0000;ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o0000
0_ooool2o`0001cooooo0_l00002ooooo`?o00001?ooool2o`0000?ooooo0_l0000;ooooo`;o0000
00?oooooo`000?l000001Oooool2o`000004ooooool0003o0000ooooo`;o00001_ooool3o`0000Wo
oooo0ol00002ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0:?ooool2o`0000;ooooo
0_l00002ooooo`?o00003Oooool2o`0000_ooooo0_l00006ooooo`;o00004ooooolJo`0000Cooooo
0_l00002ooooo`Co00002Oooool2o`000003ooooool0003o000000Wooooo0_l0000Booooo`?o0000
1?ooool3o`0000;ooooo0_l0000Cooooo`;o00000oooool7o`0000Gooooo0_l00005ooooo`?o0000
00?oooooo`000?l00000Coooool001cooooo00?o0000ooooooooool0:?ooool;o`0000?ooooo0_l0
0006ooooo`Co00001?ooool2o`0000Gooooo0_l00005ooooo`Co00004_oooolFo`000004ooooool0
003o0000o`0000Sooooo0_l00002ooooo`;o00002_ooool4o`0000Oooooo0_l000000ooooooo0000
o`000009ooooo`;o000000?oooooo`000?l000000ol000000ooooooo0000o`000003ooooo`;o0000
1Oooool2o`0000Kooooo0_l00008ooooo`?o00000oooool7o`000003ooooool0003o000000Co0000
1?ooool3o`000003ooooool0003o000000;o000000?oooooo`000?l000002Oooool2o`0003oooooo
000Looooo`03o`000?oooooooooo02Wooooo0ol00002ooooo`;o00001_ooool2o`0000Kooooo0_l0
0004ooooo`Co00003?ooool4o`0000Gooooo0_l0000<oooooaSo00003Oooool2o`000005ooooool0
003o0000o`000?ooool00_l000000ooooooo0000o`000004o`0000[ooooo0_l00002ooooo`;o0000
0oooool4o`000004ooooool0003o0000o`0000?ooooo0_l0000:ooooo`;o00001_ooool2o`0000Wo
oooo0_l00005ooooo`Go000000?oooooo`000?l000001?l00004ooooo`;o00001?ooool6o`0000So
oooo0_l0000<ooooo`;o0000<Oooool001cooooo00?o0000ooooooooool0:Oooool2o`0001;ooooo
0ol00004ooooo`;o00001Oooool2o`0000cooooo0_l00002ooooo`?o00001_ooool2o`0000?ooooo
5ol0000Aooooo`?o000000?oooooo`000?l000002?l00009ooooo`?o000000?oooooo`000?l00000
0_ooool3o`0000?ooooo0_l0000:ooooo`;o00000_ooool2o`0001Cooooo0_l00006ooooo`;o0000
3?ooool2o`0000Gooooo0_l000000ooooooo0000o`00000;ooooo`;o00002Oooool2o`00037ooooo
000Looooo`03o`000?oooooooooo02Sooooo0_l0000Cooooo`?o00000oooool2o`0000Cooooo1?l0
000<ooooo`;o00000oooool2o`0000Kooooo0_l00003oooooaOo00005oooool2o`0000?ooooo0ol0
0008ooooo`Go00000_ooool6o`0000kooooo0_l00002ooooo`;o00005?ooool2o`000003ooooool0
003o000000?ooooo0_l00002ooooo`Co00001_ooool2o`0000Sooooo1?l00009ooooo`;o0000??oo
ool001cooooo00?o0000ooooooooool0:?ooool2o`0000;ooooo0_l0000@ooooo`;o00000oooool2
o`0000Cooooo0ol0000Cooooo`;o00002_oooolFo`0000Sooooo0_l00005ooooo`;o00001oooool2
o`0000kooooo1Ol00002ooooo`So00003?ooool2o`0000Sooooo0_l000000ooooooo0000o`000006
ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000;ooooo1?l0000?
ooooo`Go000000?oooooo`000?l000000_l00004ooooo`;o0000??ooool001cooooo00?o0000oooo
ooooool0:?ooool2o`0000;ooooo0_l0000Jooooo`Co00000_ooool2o`0000oooooo0_l00002oooo
o`;o00002?ooool2o`000003ooooool0003o000000ko00002Oooool2o`0000Gooooo0_l00004oooo
o`;o000000?oooooo`000?l000002?ooool2o`0000Cooooo0_l00003ooooo`;o000000?oooooo`00
0?l000000_l000000ooooooo0000o`000009ooooo`;o00002oooool2o`000003ooooool0003o0000
00;o00000_ooool4o`0000;ooooo0_l00005ooooo`?o00001?ooool4o`0000Kooooo0_l00006oooo
o`?o00000oooool5o`0000?ooooo0_l0000looooo`007?ooool00ol0003oooooooooo`0Xooooo`;o
00000_ooool2o`0000oooooo0_l00009ooooo`Co00000_ooool2o`0001;ooooo0ol00006ooooo`Co
000000?oooooo`000?l000003Ol000000ooooooo0000o`00000@ooooo`Ko00002oooool2o`0000Wo
oooo0_l00002ooooo`;o00000_ooool2o`0000Oooooo1?l00002ooooo`;o000000?oooooo`000?l0
00000_l00007ooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`;o
00001_ooool2o`0000Kooooo0_l00007ooooo`;o00001?ooool4o`00047ooooo000Looooo`03o`00
0?oooooooooo037ooooo0_l0000:ooooo`;o00004_ooool2o`0000[ooooo0_l00003ooooo`;o0000
1oooool4o`000003ooooool0003o000001;o00001_ooool4o`0000Cooooo1?l0000Aooooo`;o0000
2Oooool2o`0000;ooooo0_l00007ooooo`;o00001?ooool7o`0001Cooooo0_l000000ooooooo0000
o`00000Pooooo`;o00001?ooool2o`0000Kooooo0_l0000dooooo`007?ooool00ol0003ooooooooo
o`0aooooo`Co00007?ooool2o`000003ooooool0003o000000Oooooo0_l00004ooooo`;o00002Ooo
oolFo`0000Kooooo1?l0000Eooooo`;o00000_ooool4o`0000Sooooo1Ol0000>ooooo`;o000000?o
ooooo`000?l000001?l00002ooooo`Co00003_ooool2o`0000gooooo0_l0000Gooooo`?o00001Ooo
ool2o`0003Cooooo000Looooo`03o`000?oooooooooo03?ooooo0_l0000Dooooo`;o00002Oooool5
o`0000Kooooo0_l00002ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Cooooo2_l00000
1?oooooo0000o`000?ooool2o`0001oooooo0_l00002ooooo`Co00001_ooool7o`0000kooooo2Ol0
0002ooooo`Co00004oooool2o`0000Oooooo0ol00005ooooo`;o000000?oooooo`000?l000003_oo
ool2o`0003_ooooo000Looooo`03o`000?oooooooooo02Sooooo0ol00008ooooo`Co00004?ooool4
o`0000[ooooo1?l00006ooooo`;o00000oooool4o`0000_ooooo2Ol00007ooooo`;o000000?ooooo
o`000?l000000_l0000Nooooo`;o00001oooool4o`0000cooooo0_l00003ooooo`Ko000000Gooooo
o`000?l0003o0000ooooo`02o`0000gooooo0_l00002ooooo`;o00000_ooool2o`0000Oooooo0_l0
0004ooooo`Co000000?oooooo`000?l000001oooool2o`0004;ooooo00001_ooooook^k^oc8b<_l0
003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003o
ooooooooo`0Vooooo`Go00002Oooool4o`000003ooooool0003o000000cooooo0_l0000;ooooo`Co
000000Coooooo`000?l0003o00000oooool4o`000003ooooool0003o000000gooooo0_l00003oooo
o`;o00002Oooool2o`000003ooooool0003o000000;o00001_ooool2o`00023ooooo0_l00002oooo
o`;o00001?ooool2o`0000?ooooo2_l00002ooooo`Ko00003?ooool3o`0000;ooooo0_l000000ooo
oooo0000o`00000>ooooo`;o00002Oooool2o`000003ooooool0003o000004;ooooo00001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_oo
ool00ol0003oooooooooo`0Vooooo`;o00000_ooool2o`0000[ooooo0_l000000ooooooo0000o`00
0005ooooo`?o00004Oooool4o`000005ooooool0003o0000o`000?ooool01_l00003ooooo`;o0000
2_ooool2o`00013ooooo0_l00005ooooo`;o00000oooool2o`0000Cooooo0_l00004ooooo`;o0000
2oooool2o`0000Oooooo0_l000001?oooooo0000o`000?l00004ooooo`;o00000_ooool=o`000003
ooooool0003o000000;o00003Oooool2o`0000;ooooo0_l00002ooooo`;o00006Oooool2o`0000Ko
oooo0_l0000Cooooo`;o0000:?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool0
2Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool09Oooool2o`0000?o
oooo0_l00003ooooo`;o00002oooool3o`000004ooooool0003o0000o`0001Cooooo1?l000001?oo
oooo0000o`000?l00002ooooo`;o00000oooool2o`0000;ooooo1?l00004ooooo`;o00003?ooool2
o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00001?ooool2o`0000?ooooo0_l00004
ooooo`Co00002Oooool2o`0000;ooooo1?l000001?oooooo0000o`000?ooool3o`0000?ooooo1?l0
00000ooooooo0000o`00000;o`000003ooooool0003o000000;o00003oooool4o`0000Gooooo1?l0
00000ooooooo0000o`00000:ooooo`;o00001oooool2o`0000Cooooo0_l0000Cooooo`;o0000:?oo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oV9RHoooooonH
V9So8B4Q00Kooooo0ol0000Uooooo`;o00002?ooool2o`000003ooooool0003o000000Sooooo0ol0
0006ooooo`;o00003?ooool2o`0000;ooooo1?l000001?oooooo0000o`000?l00003ooooo`Co0000
1?ooool4o`0000[ooooo1?l00004ooooo`;o00001Oooool2o`0000?ooooo0_l00003ooooo`;o0000
0oooool2o`0000Kooooo0_l0000=ooooo`Co00002_oooolIo`0000gooooo0_l00003ooooo`;o0000
0_ooool4o`000003ooooool0003o000000[ooooo0_l00007ooooo`?o0000@_ooool00003ooooool0
003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo
00?o0000ooooooooool0;Oooool2o`0000?ooooo0_l00003ooooo`Co00001_ooool2o`0000;ooooo
0_l0000<ooooo`Co00001Oooool3o`0000?ooooo1?l0000Booooo`Co00003_ooool4o`0002oooooo
5ol0000Booooo`;o000000?oooooo`000?l000000_l0000;ooooo`;o00002_ooool3o`0004;ooooo
00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qoooool02?oo
ool00ol0003oooooooooo`0]ooooo`?o00001oooool7o`0000?ooooo0_l0000<ooooo`;o00001?oo
ool2o`000003ooooool0003o000000;o00004?ooool4o`0001;ooooo0_l00006ooooo`;o00005Ooo
ool2o`0000Gooooo0_l00005ooooo`;o00003?oooolGo`0000?ooooo0_l00009ooooo`;o00001Ooo
ool2o`0000Wooooo0_l00002ooooo`;o00003_ooool2o`0003oooooo00001_ooooooMgMgoiRHV?oo
ooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0]ooooo`?o0000
0_ooool2o`0000Kooooo1?l00008ooooo`;o00001oooool2o`0000Oooooo1?l0000?ooooo`Go0000
1Oooool2o`0000Oooooo0_l00002ooooo`?o00004_ooool2o`000004ooooool0003o0000o`0000?o
oooo0ol00005ooooo`;o00001Oooool2o`0000Cooooo0_l00007oooooaOo000000Coooooo`000?l0
003o00002Oooool2o`0000Gooooo0_l00009ooooo`;o00004_ooool2o`0003oooooo00001_oooooo
k^k^oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003ooooooooo
o`0booooo`;o00002Oooool2o`0000Oooooo0_l00003ooooo`;o00007_ooool2o`0000Sooooo0_l0
0007ooooo`;o00000oooool2o`0000oooooo0_l000000ooooooo0000o`000006o`000003ooooool0
003o000000?o00002oooool2o`0000?ooooo0_l00003ooooo`;o00000ooooolFo`000003ooooool0
003o0000017ooooo0_l00005ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Gooooo0_l0
0017ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00000oooool2o`0000cooooo1?l00002
ooooo`;o00009_ooool2o`0000Oooooo0_l0000>ooooo`oo000000Coooooo`000?l0003o00000ooo
ool2o`0000Kooooo0_l00003ooooo`;o00000oooool2o`0000?ooooo5ol00003ooooo`;o00005Ooo
ool2o`000003ooooool0003o000000?ooooo0ol00005ooooo`;o0000Aoooool001cooooo00?o0000
ooooooooool0>?ooool3o`0000Cooooo0ol0000;ooooo`Ko00002?ooool2o`0000gooooo0_l00006
ooooo`;o00001Oooool2o`0000Oooooo1?l00002ooooo`?o00001ooooolCo`0000?ooooo0ol00005
ooooo`;o00000oooool2o`0000Cooooo7?l00002ooooo`;o00000oooool2o`000003ooooool0003o
0000013ooooo0_l00003ooooo`;o00003?ooool2o`00047ooooo000Looooo`03o`000?oooooooooo
03Sooooo0ol00004ooooo`?o00003Oooool5o`0000Oooooo0ol0000<ooooo`?o000000?oooooo`00
0?l000000_ooool2o`0000gooooo0_l000000ooooooo0000o`000002ooooo`?o00000ooooolGo`00
00Cooooo0_l00009ooooo`;o00001OoooolLo`0000;ooooo0_l00003ooooo`;o000000?oooooo`00
0?l000002?ooool4o`0000?ooooo0_l000000ooooooo0000o`000008ooooo`?o00001?ooool2o`00
047ooooo000Looooo`03o`000?oooooooooo03;ooooo0_l0000Booooo`;o00002Oooool3o`0000So
oooo0ol0000<ooooo`;o000000?oooooo`000?l000001?ooool2o`0000_ooooo0_l0000;oooooaOo
00000_ooool4o`0000Wooooo0_l0000:oooooaKo00000_ooool2o`0000Gooooo0_l00004ooooo`;o
00000oooool5o`0000?ooooo0_l000000ooooooo0000o`000008ooooo`Co0000A_ooool001cooooo
00?o0000ooooooooool0<_ooool2o`0001;ooooo0_l0000:ooooo`;o00002Oooool4o`0000gooooo
0_l00004ooooo`Co00005?oooolNo`0000Sooooo0_l0000;oooooaKo00000oooool2o`0000Gooooo
0ol00003ooooo`;o00000oooool2o`0001Gooooo0_l00016ooooo`007?ooool00ol0003ooooooooo
o`0mooooo`;o00002?ooool2o`0000Kooooo0_l000000ooooooo0000o`000009ooooo`Go00005?oo
ool4o`0001;ooooo3_l000000ooooooo0000o`00000=o`000003ooooool0003o000000Gooooo0_l0
000;oooooaOo00002_ooool2o`0000?ooooo0_l0001Rooooo`007?ooool00ol0003oooooooooo`0f
ooooo`;o00001?ooool3o`0000Oooooo0ol00006ooooo`;o00003Oooool4o`0000oooooo0_l00005
ooooo`;o00004_oooolNo`000004ooooool0003o0000o`0000gooooo0_l000001?oooooo0000o`00
0?ooool8o`000003ooooool0003o000000[o00001_ooool2o`0000Oooooo0_l00009ooooo`;o0000
00?oooooo`000?l000002_ooool2o`0004Sooooo000Looooo`03o`000?oooooooooo03Kooooo0_l0
0004ooooo`;o00002?ooool2o`0000;ooooo0ol0000Aooooo`?o00001?ooool2o`0000[ooooo0ol0
000Eooooo`?o00000_oooolQo`0000cooooo0_l000000ooooooo0000o`000002oooooa3o00002_oo
ool2o`0001;ooooo0_l000001?oooooo0000o`000?ooool2o`0000Oooooo0_l00018ooooo`007?oo
ool00ol0003oooooooooo`1:ooooo`?o00001?ooool2o`0000[ooooo1?l000000ooooooo0000o`00
0003o`0000Cooooo0_l000001?oooooo0000o`000?ooool3o`0001?ooooo5_l00002oooooa3o0000
0_ooool2o`0000Oooooo0_l00006ooooo`;o000000?oooooo`000?l000003_l00003ooooo`Go0000
6Oooool2o`0000[ooooo0ol00014ooooo`007?ooool00ol0003oooooooooo`0gooooo`Co00000ooo
ool3o`00013ooooo0_l00008ooooo`Co00000oooool3o`0000Kooooo0_l000000ooooooo0000o`00
0003o`0001Cooooo0_l000000ooooooo0000o`00000Qo`0000Cooooo0_l00007ooooo`?o00000_oo
ool2o`0000Gooooo3ol00003ooooo`Go00001Oooool2o`00017ooooo1?l00009ooooo`?o0000A?oo
ool001cooooo00?o0000ooooooooool0=oooool4o`0000?ooooo0ol00006ooooo`;o00001?ooool2
o`0000Oooooo0_l00003ooooo`;o00004Oooool3o`00013ooooo0_l00003ooooo`;o000000?ooooo
o`000?l000008Ol00005ooooo`;o00002?ooool2o`0000;ooooo0_l00005ooooo`co000000?ooooo
o`000?l000003Oooool2o`00017ooooo1?l00002ooooo`;o00000_ooool2o`0004Sooooo000Loooo
o`;o0000@?ooool2o`0000Kooooo0_l00004ooooo`Co00000_ooool2o`000003ooooool0003o0000
00Gooooo0_l00002ooooo`Go00002?ooool3o`00013ooooo0_l00003ooooo`;o000000?oooooo`00
0?l000003Ol00003oooooa7o00002_ooool2o`0000Oooooo0_l00006ooooo`?o00000_ooool4o`00
00Kooooo0_l00004ooooo`Go00003?ooool4o`0000[ooooo0_l00002ooooo`;o0000B?ooool001co
oooo00?o0000ooooooooool0?oooool2o`0000kooooo0_l00002ooooo`;o00002?ooool2o`0000;o
oooo1Ol00009ooooo`;o00005oooool2o`000003ooooool0003o000001co00000_ooool2o`0000Wo
oooo0_l00006ooooo`;o00000_ooool2o`0000Sooooo1_l00004ooooo`?o00000oooool5o`0000So
oooo0_l00002ooooo`Co00003_ooool2o`0004Sooooo000Looooo`03o`000?oooooooooo04Oooooo
0_l0000Cooooo`Co000000?oooooo`000?l000001?l0000Pooooo`?o00000_oooolQo`0000Cooooo
1?l00003ooooo`;o00001?ooool2o`000004ooooool0003o0000o`0000Gooooo2ol00003ooooo`?o
00002?ooool2o`0000Gooooo0_l0000Dooooo`;o00002oooool2o`0003_ooooo000Looooo`03o`00
0?oooooooooo03gooooo0_l00002ooooo`;o00001?ooool2o`0000cooooo0_l00005ooooo`Co0000
00?oooooo`000?l000001?l0000>ooooo`Oo000000?oooooo`000?l000002?ooool3o`0000;ooooo
1?l000000ooooooo0000o`00000Jo`0000Cooooo1?l00003ooooo`;o00001oooool2o`0000Kooooo
1?l00004ooooo`?o00000oooool3o`0000?ooooo0_l00003ooooo`;o00002oooool2o`0000gooooo
0_l0000<ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0?Oooool2o`0000;ooooo0_l0
0002ooooo`;o00003_ooool2o`0000[ooooo0ol000000ooooooo0000o`000002o`0000Wooooo0_l0
00000ooooooo0000o`000005o`000003ooooool0003o000000Sooooo0_l00003oooooaoo000000?o
ooooo`000?l000002?ooool2o`0000Wooooo0_l00008ooooo`Co00000oooool2o`0000?ooooo0_l0
0004ooooo`;o00004?ooool2o`0000Gooooo0_l00006ooooo`;o0000BOooool001cooooo00?o0000
ooooooooool0;oooool2o`0001Cooooo0_l00002ooooo`;o00002_ooool3o`0000[ooooo0ol00002
ooooo`;o00002Oooool2o`0000Cooooo0_l00006ooooo`;o00001Oooool3o`0000;ooooo7ol00000
0ooooooo0000o`000004ooooo`;o00000_ooool2o`0000Sooooo0_l00006ooooo`;o000000?ooooo
o`000?l000000_l0000=ooooo`;o00004_ooool2o`0000Cooooo0_l00004ooooo`;o0000Boooool0
01cooooo00?o0000ooooooooool0;oooool2o`0001Sooooo0_l00007ooooo`;o000000Coooooo`00
0?l0003o00002oooool2o`0001Oooooo0_l00002ooooo`?o00001?ooool3o`0000Cooooo5_l00000
0ooooooo0000o`000004o`0000Oooooo1?l0000:ooooo`;o00001Oooool7o`0000kooooo0_l0000B
ooooo`;o00002_ooool2o`0000Oooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`0loooo
o`;o00005?ooool2o`0000Gooooo0_l00008ooooo`;o00000_ooool2o`0001?ooooo1?l000000ooo
oooo0000o`000002ooooo`;o000000?oooooo`000?l000001_ooool>o`000003ooooool0003o0000
00So00002?ooool2o`000003ooooool0003o000000?ooooo0_l0000<ooooo`;o000000?oooooo`00
0?l000000_l0000:ooooo`;o00001oooool2o`0000Oooooo0_l000000ooooooo0000o`000002o`00
00?ooooo0_l0000?ooooo`?o0000@Oooool001cooooo00?o0000ooooooooool0??ooool2o`00017o
oooo0_l00008ooooo`;o00002?ooool8o`0001?ooooo0_l00005ooooo`;o00002?ooool2o`000003
ooooool0003o000000[o000000?oooooo`000?l000001Ol000000ooooooo0000o`000008ooooo`;o
00001Oooool3o`0000cooooo0_l0000?ooooo`;o00001?ooool2o`000003ooooool0003o000000Oo
oooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l00007ooooo`;o00001oooool2o`00047o
oooo000Looooo`03o`000?oooooooooo04oooooo0_l00005ooooo`;o00003?ooool4o`000003oooo
ool0003o000000_ooooo1?l000000ooooooo0000o`00000=ooooo`;o00000oooool?o`000003oooo
ool0003o000000So00003oooool3o`0001Sooooo0_l00002ooooo`;o00001Oooool2o`0000?ooooo
0_l000000ooooooo0000o`00000?ooooo`;o00001?ooool2o`0004[ooooo000Looooo`03o`000?oo
oooooooo04[ooooo0_l0000:ooooo`;o00000oooool2o`0000[ooooo0_l0000=ooooo`Co000000?o
ooooo`000?l000002oooool6o`0000;ooooo0_l000000ooooooo0000o`00000?o`000003ooooool0
003o000000;o00004?ooool2o`0001;ooooo0_l00004ooooo`;o00000_ooool2o`0000[ooooo0_l0
00001?oooooo0000o`000?l0000>ooooo`Co00000oooool2o`0004Wooooo000Looooo`03o`000?oo
oooooooo04[ooooo0_l00005ooooo`;o00001oooool3o`0000?ooooo0_l00005ooooo`;o00004?oo
ool2o`0000gooooo0_l00002ooooo`;o00001Oooool2o`000003ooooool0003o0000013o00001Ooo
ool4o`0000Gooooo0_l0000=ooooo`;o00001_ooool2o`0000;ooooo1?l000000ooooooo0000o`00
000<ooooo`Go00003_ooool4o`0000?ooooo0_l00019ooooo`007?ooool00ol0003oooooooooo`1A
ooooo`;o00001oooool4o`0000;ooooo0_l00007ooooo`;o00003_ooool2o`0001_ooooo3ol00000
0ooooooo0000o`000005ooooo`Co00001Oooool2o`0000Wooooo0_l00002ooooo`;o00001Oooool2
o`0000?ooooo1?l000000ooooooo0000o`000009ooooo`;o000000Coooooo`000?l0003o00000ooo
ool2o`0000Cooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`18ooooo`;o000000?ooooo
o`000?l000003oooool2o`0000Wooooo1?l000000ooooooo0000o`00000Mooooo`;o00002oooool:
o`0000Sooooo0_l0000:ooooo`;o00002Oooool2o`0000Wooooo1_l0000?ooooo`?o00000oooool2
o`000003ooooool0003o000000Cooooo1Ol00003ooooo`;o0000Coooool001cooooo00?o0000oooo
ooooool0B?ooool2o`000003ooooool0003o000000oooooo0_l00004ooooo`;o00000oooool2o`00
00?ooooo0_l000000ooooooo0000o`000009ooooo`;o00002?ooool2o`0000Gooooo0_l00009oooo
o`;o00000_ooool9o`0000Oooooo0_l0000:ooooo`;o00003?ooool2o`0000?ooooo0_l00003oooo
o`Co00003?ooool2o`0000;ooooo0_l00003ooooo`;o00002?ooool4o`0000?ooooo0_l0001?oooo
o`007?ooool00ol0003oooooooooo`1:ooooo`;o00004?ooool2o`0000Cooooo0_l00005ooooo`;o
00001?ooool2o`0000Sooooo0ol00006ooooo`Ko00002oooool2o`000004ooooool0003o0000o`00
00Oooooo0ol0000Qooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00001?ooool3o`00
0003ooooool0003o000000;o000000Coooooo`000?l0003ooooo0_l00006ooooo`;o00000oooool4
o`0005Cooooo000Looooo`;o0000Boooool2o`0000gooooo0_l00007ooooo`?o00001?ooool4o`00
00Kooooo0_l00004ooooo`;o00001_ooool3o`0000;ooooo0_l00002ooooo`;o00001oooool2o`00
00;ooooo0_l00007ooooo`;o00004?ooool2o`0000[ooooo0_l0000=ooooo`;o00000oooool2o`00
00Cooooo0ol000000ooooooo0000o`000003ooooo`Go00001_ooool2o`0000?ooooo0_l0001Foooo
o`007?ooool00ol0003oooooooooo`19ooooo`?o00001?ooool2o`0000Oooooo0_l00006ooooo`Co
00000oooool2o`000004ooooool0003o0000o`0000Cooooo0ol0000<ooooo`;o00000_ooool4o`00
0003ooooool0003o000000?ooooo0_l0000Qooooo`;o00002_ooool2o`0001Wooooo1Ol00004oooo
o`;o00001_ooool4o`0005_ooooo000Looooo`03o`000?oooooooooo04Wooooo1?l00003ooooo`;o
00001?ooool2o`0000Gooooo0_l00002ooooo`Co00000_ooool8o`0000;ooooo0ol0000=ooooo`;o
00000_ooool4o`0000Kooooo0_l00004ooooo`;o00000oooool2o`0000Cooooo0_l0000Vooooo`;o
00004?ooool2o`0000kooooo1?l0001Kooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o0000
2Oooool2o`0000Gooooo0_l00004ooooo`;o00000_ooool2o`000003ooooool0003o000000Co0000
00?oooooo`000?l000007_ooool2o`0000;ooooo0_l00003ooooo`?o00000oooool2o`0001Wooooo
0_l0000;ooooo`;o00000_ooool2o`0000Wooooo0ol0000@ooooo`;o0000GOooool001cooooo00?o
0000ooooooooool0D?ooool2o`0000Cooooo0_l00008ooooo`;o00001Oooool2o`0000?ooooo1?l0
000>ooooo`;o00001oooool2o`0000Kooooo1?l000000ooooooo0000o`000005ooooo`;o00006?oo
ool2o`0000Cooooo0_l0000?ooooo`;o00002Oooool4o`0000;ooooo0_l0000;ooooo`;o0000GOoo
ool001cooooo00?o0000ooooooooool0D?ooool2o`000004ooooool0003o0000ooooo`;o00002?oo
ool2o`0000Cooooo0_l00005ooooo`?o00000_ooool2o`0000[ooooo0_l00003ooooo`;o00000_oo
ool2o`0000Kooooo0_l00003ooooo`;o00000_ooool2o`0001_ooooo0_l0000Pooooo`Co00000_oo
ool2o`0000Wooooo0_l0001Oooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00003?ooool2
o`0000?ooooo0_l00006ooooo`?o000000?oooooo`000?l000002_ooool2o`0000?ooooo0_l00005
ooooo`?o00002oooool2o`0000oooooo0_l0000;ooooo`;o00007_ooool3o`0000Wooooo0_l00002
ooooo`Co00003_ooool2o`0004oooooo000Looooo`03o`000?oooooooooo04oooooo0_l000000ooo
oooo0000o`000002ooooo`;o00002Oooool2o`0000Oooooo0_l00002ooooo`?o00003Oooool2o`00
00[ooooo0ol0000Dooooo`;o00001_ooool2o`0000_ooooo0_l0000Nooooo`;o00001oooool2o`00
0004ooooool0003o0000ooooo`?o00004?ooool2o`0004oooooo000Looooo`03o`000?oooooooooo
03Kooooo0_l0000Gooooo`;o000000?oooooo`000?l000001?l000000ooooooo0000o`000008oooo
o`;o00001Oooool6o`0000;ooooo0_l0000@ooooo`;o00006oooool2o`0003Cooooo0_l00006oooo
o`;o00001?ooool2o`0000Wooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`0fooooo`;o
00007?ooool2o`0000?ooooo0_l000000ooooooo0000o`000005ooooo`;o00001Oooool6o`0000;o
oooo0_l00003ooooo`;o00002?ooool2o`000003ooooool0003o000000;o00001oooool2o`0000Co
oooo0_l0000?ooooo`;o00007oooool2o`000003ooooool0003o000000Sooooo0_l000000ooooooo
0000o`000002ooooo`;o00000oooool2o`000003ooooool0003o000000;o00002Oooool2o`0005Oo
oooo000Looooo`03o`000?oooooooooo05?ooooo0_l000000ooooooo0000o`000004ooooo`;o0000
1?ooool4o`0000Cooooo1_l00007ooooo`;o00002?ooool2o`000003ooooool0003o000000;o0000
1oooool2o`0000Cooooo0ol0000>ooooo`;o00002?ooool2o`0001Gooooo0_l000001?oooooo0000
o`000?ooool2o`0000Gooooo1Ol00002ooooo`;o000000?oooooo`000?l000000_l000000ooooooo
0000o`000003o`00067ooooo000Looooo`03o`000?oooooooooo05?ooooo0_l000000ooooooo0000
o`00000:ooooo`Co00001oooool2o`0000[ooooo0_l00007ooooo`Co00000oooool2o`0000_ooooo
0_l00003ooooo`;o00000oooool2o`0000Kooooo1?l00004ooooo`;o00001oooool2o`0001;ooooo
0_l00007ooooo`?o00001Oooool2o`0000Kooooo0_l00006ooooo`;o00002?ooool2o`0004oooooo
000Looooo`03o`000?oooooooooo05_ooooo0_l00003ooooo`;o00003?ooool2o`0000Wooooo0_l0
0002ooooo`;o00000oooool2o`0000;ooooo1Ol0000?ooooo`?o00000_ooool3o`000003ooooool0
003o000000?ooooo1?l0000=ooooo`;o00002?ooool2o`00017ooooo1?l0000Dooooo`;o00002?oo
ool2o`0004oooooo000Looooo`03o`000?oooooooooo05Kooooo0_l00003ooooo`;o00000oooool2
o`0000;ooooo0_l00006ooooo`Co00003Oooool2o`0000Oooooo0ol0000Aooooo`;o00000oooool2
o`0000;ooooo1?l000000ooooooo0000o`000003o`0000_ooooo0ol00008ooooo`;o00002?ooool2
o`0000?ooooo0_l00002ooooo`Co00007?ooool3o`00053ooooo000Looooo`03o`000?oooooooooo
05;ooooo0_l00002ooooo`;o00003?ooool2o`0000Kooooo0_l0000;ooooo`;o00000oooool2o`00
00Kooooo0_l0000Booooo`;o000000?oooooo`000?l000000oooool2o`000004ooooool0003o0000
ooooo`Go000000?oooooo`000?l000002?ooool2o`0000Wooooo0_l00002ooooo`;o000000?ooooo
o`000?l000000ol00003ooooo`;o00003?ooool4o`0001;ooooo0ol0001@ooooo`007?ooool00ol0
003oooooooooo`1Booooo`;o00001Oooool2o`000003ooooool0003o000001Cooooo0_l00005oooo
o`;o00000_ooool3o`0000Kooooo1?l0000Cooooo`;o00000oooool5o`0000?ooooo0_l00002oooo
o`;o00005oooool2o`000003ooooool0003o000000;o00002?ooool2o`0000Kooooo1_l0001Uoooo
o`007?ooool2o`0005Wooooo0ol000000ooooooo0000o`00000Dooooo`Co00001oooool2o`0000Oo
oooo1?l00004ooooo`;o00004oooool7o`0001gooooo0_l00007ooooo`;o00001?ooool2o`0000Ko
oooo0_l000000ooooooo0000o`00001Vooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o0000
00?oooooo`000?l000001Oooool3o`0000Sooooo0_l00005ooooo`;o00002?ooool2o`0000?ooooo
0_l00009ooooo`;o00003_ooool3o`0000Kooooo1Ol00008ooooo`;o00002oooool2o`0000Cooooo
0_l000001?oooooo0000o`000?l00003ooooo`;o00002oooool2o`0006[ooooo000Looooo`03o`00
0?oooooooooo05_ooooo0_l00005ooooo`?o00002?ooool2o`0000_ooooo0_l00002ooooo`;o0000
0oooool2o`0000Gooooo0_l0000Booooo`?o00002Oooool2o`0000Sooooo0_l00008ooooo`;o0000
00?oooooo`000?l000000_ooool2o`0000?ooooo1?l00002ooooo`Co00001Oooool2o`0000;ooooo
0_l0000>ooooo`;o0000F_ooool001cooooo00?o0000ooooooooool0Foooool2o`0001Oooooo0_l0
0004ooooo`;o000000?oooooo`000?l000001Oooool2o`0000?ooooo0ol00004ooooo`;o00004?oo
ool2o`0000_ooooo0_l00007ooooo`;o00001?ooool2o`000003ooooool0003o000000;ooooo0_l0
0002ooooo`;o000000?oooooo`000?l000000_ooool4o`0000Gooooo0_l00006ooooo`;o00002_oo
ool2o`0005[ooooo000Looooo`03o`000?oooooooooo05_ooooo0_l0000Gooooo`;o00001oooool2
o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o00001Oooool2o`0000Gooooo0_l00009
ooooo`;o00001oooool2o`0000;ooooo0_l00006ooooo`?o00000oooool3o`000003ooooool0003o
000000Cooooo1?l00005ooooo`Co00003Oooool2o`0001?ooooo0_l0001Aooooo`007?ooool00ol0
003oooooooooo`1cooooo`Co00000_ooool2o`0000Kooooo0_l0000=ooooo`;o00001Oooool2o`00
00kooooo0_l00002ooooo`;o00000_ooool2o`0000Kooooo0_l00002ooooo`Go00001oooool2o`00
00?ooooo0_l00003ooooo`?o00008_ooool2o`00057ooooo000Looooo`03o`000?oooooooooo05co
oooo0_l0000;ooooo`;o00002?ooool4o`0000;ooooo0_l0000;ooooo`Co00001_ooool2o`0001;o
oooo0_l000000ooooooo0000o`000004ooooo`Co00000oooool2o`0000Cooooo0ol00002ooooo`;o
00002?ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000001?ooool2o`00073o
oooo000Looooo`03o`000?oooooooooo05cooooo0_l00004ooooo`;o00001?ooool3o`0000gooooo
0_l0000<ooooo`Co00002oooool2o`0000gooooo0_l00007ooooo`;o00001Oooool2o`0000Cooooo
0ol00002ooooo`;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000Oooooo
0_l0001`ooooo`007?ooool00ol0003oooooooooo`1Rooooo`;o00001?ooool2o`000004ooooool0
003o0000o`0000?ooooo0_l00003ooooo`Co00002_ooool3o`000003ooooool0003o000000[ooooo
0ol0000^ooooo`;o00001Oooool3o`0000Gooooo0_l000000ooooooo0000o`00001`ooooo`007?oo
ool00ol0003oooooooooo`1[ooooo`Go000000?oooooo`000?l000000oooool2o`0000cooooo0ol0
000=ooooo`;o00004Oooool2o`0001gooooo1?l00004ooooo`?o00000oooool2o`000003ooooool0
003o0000073ooooo000Looooo`03o`000?oooooooooo06_ooooo0_l000000ooooooo0000o`00000B
ooooo`;o000000Coooooo`000?l0003o00003?ooool2o`0000kooooo0_l000001?oooooo0000o`00
0?ooool2o`000003ooooool0003o0000013ooooo0ol00002ooooo`Ko00001?ooool3o`0000oooooo
0_l0001Wooooo`007?ooool00ol0003oooooooooo`1Yooooo`;o00003_ooool5o`0000Cooooo0ol0
00000ooooooo0000o`000002ooooo`;o00005Oooool2o`000003ooooool0003o000000Cooooo1Ol0
000@ooooo`?o00000_ooool6o`0001Kooooo0_l0001Wooooo`007?ooool00ol0003oooooooooo`1Y
ooooo`;o00001Oooool2o`000003ooooool0003o000000Cooooo1Ol00005ooooo`Ko000000?ooooo
o`000?l000005Oooool2o`0000Sooooo0ol00004ooooo`;o00003?ooool2o`0000Cooooo1?l0000?
ooooo`;o00001?ooool2o`0000Cooooo0_l0001Rooooo`007?ooool00ol0003oooooooooo`1`oooo
o`;o000000?oooooo`000?l000002Oooool2o`0000Cooooo1Ol0000@ooooo`;o00001oooool2o`00
00Oooooo0_l00005ooooo`;o000000?oooooo`000?l000008_ooool2o`0000Cooooo0_l00004oooo
o`;o0000H_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<
ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo073ooooo0_l0000<ooooo`;o00001?oo
ool4o`0000Oooooo0_l00008ooooo`?o00000_ooool6o`0000gooooo0_l00002ooooo`;o00001ooo
ool2o`0001;ooooo0_l00002ooooo`;o00001_ooool3o`0006Sooooo00001_ooooooMgMgoiRHV?oo
ooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003o
ooooooooo`1Eooooo`;o00006Oooool2o`0001Cooooo0_l00007ooooo`;o00002Oooool3o`000003
ooooool0003o000000;o000000Coooooo`000?l0003o00002oooool3o`000003ooooool0003o0000
00Gooooo1?l0000Booooo`;o00000_ooool2o`0000Cooooo1Ol0001Xooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`1Eooooo`;o0000@?ooool3o`000004ooooool0003o0000o`0000Gooooo0ol0000<
ooooo`;o000000?oooooo`000?l000001Oooool2o`0001kooooo0_l0001[ooooo`0000?oooooo`00
0?ooool00_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3
o`0008Cooooo0_l0000Aooooo`?o00000_ooool2o`0000Gooooo0_l00006ooooo`?o00007?ooool2
o`0000Wooooo0ol00003ooooo`;o0000K?ooool00003ooooool0003ooooo00;ooooo00?o0000oooo
ooooool02Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0N?ooool2
o`0000Kooooo0_l00002ooooo`;o00003oooool2o`0000cooooo0_l00005ooooo`Co00007?ooool2
o`0000Wooooo0ol00003ooooo`;o0000K?ooool00003ooooool@413ooooo00;ooooo00?o410@oooo
ooooool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0N?ooool2
o`0000Kooooo1?l0000>ooooo`Go00001_ooool2o`000004ooooool0003o0000ooooo`;o00001Ooo
ool4o`0009_ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo
^[Zjo`000006ooooo`03o`000?oooooooooo05Cooooo0_l0000/ooooo`;o000000?oooooo`000?l0
00001?ooool2o`0000Gooooo0ol00008ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooo
oooo0000o`000004ooooo`;o00005?ooool2o`0000[ooooo0_l0001iooooo`0000Koooooonk^k_lb
<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003ooooooooo
o`1Dooooo`;o0000;Oooool4o`0000Cooooo0_l0000>ooooo`;o00002Oooool2o`0000;ooooo1?l0
000Dooooo`;o00002_ooool2o`0007Wooooo000Looooo`03o`000?oooooooooo08?ooooo0_l00006
ooooo`Co00000_ooool2o`0000Sooooo0_l0000=ooooo`;o00001_ooool2o`0009Gooooo000Loooo
o`03o`000?oooooooooo08Oooooo0_l00004ooooo`;o00000_ooool2o`0000Sooooo0_l0000Eoooo
o`;o00001oooool2o`0000_ooooo1?l0001mooooo`007?ooool00ol0003oooooooooo`21ooooo`;o
00001?ooool2o`0002Oooooo0_l00009ooooo`;o00002oooool4o`0007gooooo000Looooo`03o`00
0?oooooooooo087ooooo0_l0000?ooooo`;o00007?ooool2o`0001Cooooo0_l00021ooooo`007?oo
ool00ol0003oooooooooo`28ooooo`;o00002?ooool2o`0000_ooooo0_l0000Uooooo`;o0000POoo
ool001cooooo00?o0000ooooooooool0Noooool2o`0000Sooooo0_l000000ooooooo0000o`00000E
ooooo`;o00006_ooool2o`0000Wooooo0_l00021ooooo`007?ooool00ol0003oooooooooo`1koooo
o`;o00002?ooool2o`000003ooooool0003o000000Cooooo0_l00009ooooo`;o00008?ooool2o`00
00Cooooo0_l00026ooooo`007?ooool00ol0003oooooooooo`2<ooooo`Co00002Oooool2o`0000Oo
oooo0_l0000Gooooo`;o00001?ooool2o`0008Kooooo000Looooo`03o`000?oooooooooo08cooooo
0_l0000Dooooo`;o00004?ooool2o`0009?ooooo000Looooo`03o`000?oooooooooo08_ooooo0_l0
0007ooooo`;o00003_ooool2o`0000;ooooo0_l0000:ooooo`;o0000Toooool001cooooo00?o0000
ooooooooool0P?ooool2o`0000Wooooo0_l00007ooooo`;o00003_ooool2o`0000;ooooo0_l0002O
ooooo`007?ooool2o`00087ooooo0_l00037ooooo`007?ooool00ol0003oooooooooo`2Jooooo`;o
00003oooool2o`0009cooooo000Looooo`03o`000?oooooooooo09[ooooo0_l0000?ooooo`;o0000
0oooool2o`0001Oooooo0_l0001nooooo`007?ooool00ol0003oooooooooo`2`ooooo`;o00005ooo
ool2o`0007kooooo000Looooo`03o`000?oooooooooo0<;ooooo0_l00025ooooo`007?ooool00ol0
003oooooooooo`32ooooo`;o0000QOooool001cooooo00?o0000ooooooooool0S?ooool2o`0002go
oooo0_l0002<ooooo`007?ooool00ol0003oooooooooo`2<ooooo`;o0000;Oooool2o`0008cooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo07Co
oooo0_l0000Jooooo`Co00000oooool2o`000;3ooooo000Looooo`03o`000?oooooooooo07Cooooo
0_l0000Jooooo`Co00000oooool2o`000003ooooool0003o00000:gooooo000Looooo`03o`000?oo
oooooooo09[ooooo0_l00008ooooo`;o0000Xoooool001cooooo00?o0000ooooooooool0T_ooool2
o`00013ooooo0_l00007ooooo`;o0000V_ooool001cooooo00?o0000ooooooooool0T?ooool4o`00
01Sooooo0ol0002Jooooo`007?ooool2o`00097ooooo0_l0000Jooooo`;o0000Voooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`26ooooo`;o00003?oo
ool2o`000;?ooooo000Looooo`03o`000?oooooooooo08Kooooo0_l0000<ooooo`;o0000/oooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2>ooooo`;o
0000^Oooool001cooooo00?o0000ooooooooool0S_ooool2o`000;Wooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Booooo`Co
000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003ooooooooo
o`05ooooo`?o0000oooooom:ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Doooo
o`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`00
5?ooool00ol0003oooooooooo`3ooooooe;ooooo000Booooo`03oeEEEOmVIVKo00000?ooooooE?oo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:7ooooo00Co410@o`000?l0003o
oooo0_l000000ol@413oooooooooo`0Fooooo`Co000000Co410@oooooooooooooooo1?l000001Ol@
413oooooooooooooooooA4A400;o000000Co<S8bomgMgOoooooooooo1Ol0002<ooooo`00X_ooool0
1Ol0003ooooooooooooooooo000000Wooooo1_l0000<ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool02OmgMgOo<S8booooooooooooV9RHob4Q8Oo^k^koooooodA4A02<oooo
o`00X_ooool01Ol0003ooooooooooooooooo000001_ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`07ooooo`07o`000?oooooooooooooooonHV9So8B4Qonk^kP2=ooooo`00X_ooool0
1Ol0003ooooooooooooooooo000000Wooooo1_l0000<ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00omgMgOo<S8booooo`03ooooo`03oiRHV?lQ8B7ok^k^08cooooo002R
ooooo`05o`000?n7QhOoooooojVYZOl000006oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03ogMgMomVIVKooooo08_ooooo
002Qooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool06Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`2:ooooo`00`_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01?ooool01Ol0003o^[ZjoooooonHV9So410@08cooooo0030ooooo`03oeEEEOmVIVKo
000000Gooooo00?oEEEEofIVI_l000001Oooool4o`0000?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c02<ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1158) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.3793 .38359 Mdot
.41296 .3487 Mdot
.49187 .63895 Mdot
.64195 .43813 Mdot
.19495 .5001 Mdot
.4584 .64639 Mdot
.34709 .53904 Mdot
.37692 .49611 Mdot
.48517 .64711 Mdot
.28916 .35532 Mdot
.34636 .52691 Mdot
.66138 .34553 Mdot
.35395 .51273 Mdot
.6177 .44292 Mdot
.17327 .38817 Mdot
.68237 .40135 Mdot
.44182 .37624 Mdot
.59739 .6672 Mdot
.58381 .37554 Mdot
.45745 .68229 Mdot
.44643 .39634 Mdot
.62679 .43634 Mdot
.39498 .33182 Mdot
.61682 .44297 Mdot
.66244 .42677 Mdot
.40212 .38208 Mdot
.43473 .31668 Mdot
.64234 .39375 Mdot
.6721 .41281 Mdot
.37118 .49251 Mdot
.69791 .55738 Mdot
.16331 .44784 Mdot
.56198 .40536 Mdot
.34545 .75541 Mdot
.38356 .5101 Mdot
.53373 .33187 Mdot
.46003 .63163 Mdot
.37492 .51946 Mdot
.38002 .525 Mdot
.35618 .5568 Mdot
.36538 .53016 Mdot
.39702 .36829 Mdot
.39274 .57608 Mdot
.45277 .56578 Mdot
.6705 .38609 Mdot
.23457 .48518 Mdot
.72117 .31287 Mdot
.59725 .39884 Mdot
.43125 .38828 Mdot
.47938 .74166 Mdot
.27206 .61333 Mdot
.35898 .55257 Mdot
.41821 .63333 Mdot
.52288 .90153 Mdot
.37547 .50884 Mdot
.64942 .36891 Mdot
.47087 .62756 Mdot
.61738 .43043 Mdot
.61158 .44172 Mdot
.45031 .24737 Mdot
.60714 .38262 Mdot
.59768 .63737 Mdot
.37379 .38746 Mdot
.53572 .50593 Mdot
.47834 .64054 Mdot
.371 .53639 Mdot
.4003 .34507 Mdot
.35863 .50604 Mdot
.65267 .47902 Mdot
.44904 .68318 Mdot
.60091 .39634 Mdot
.35925 .53619 Mdot
.42074 .40162 Mdot
.6206 .39889 Mdot
.55269 .77278 Mdot
.34675 .21863 Mdot
.62778 .6035 Mdot
.50212 .29795 Mdot
.44625 .26931 Mdot
.55804 .71363 Mdot
.63339 .45847 Mdot
.77176 .48866 Mdot
.29081 .27178 Mdot
.40883 .32106 Mdot
.55818 .47347 Mdot
.56338 .60219 Mdot
.61942 .40374 Mdot
.23297 .40349 Mdot
.67765 .41256 Mdot
.56551 .78962 Mdot
.47859 .65671 Mdot
.42393 .36468 Mdot
.64196 .44005 Mdot
.64309 .38712 Mdot
.73093 .35459 Mdot
.5742 .44904 Mdot
.64205 .41189 Mdot
.39977 .39541 Mdot
.36762 .55302 Mdot
.66035 .35666 Mdot
.42502 .56525 Mdot
.42483 .61346 Mdot
.57864 .43909 Mdot
.43007 .64169 Mdot
.43297 .39991 Mdot
.62374 .39253 Mdot
.38298 .52999 Mdot
.58309 .43879 Mdot
.3444 .44753 Mdot
.41335 .34539 Mdot
.64749 .39159 Mdot
.59673 .65399 Mdot
.79515 .62282 Mdot
.43116 .36002 Mdot
.59899 .70554 Mdot
.64683 .45738 Mdot
.6326 .41649 Mdot
.41235 .35147 Mdot
.45578 .61161 Mdot
.24348 .37181 Mdot
.39235 .32622 Mdot
.36821 .5603 Mdot
.37023 .35943 Mdot
.57457 .48624 Mdot
.47267 .65354 Mdot
.32061 .68778 Mdot
.2916 .51997 Mdot
.71009 .531 Mdot
.6166 .40934 Mdot
.29243 .41005 Mdot
.457 .67303 Mdot
.41265 .36605 Mdot
.3571 .50235 Mdot
.56841 .3765 Mdot
.41753 .33267 Mdot
.346 .49882 Mdot
.58983 .64222 Mdot
.34839 .6527 Mdot
.44538 .35707 Mdot
.44631 .54927 Mdot
.37039 .48037 Mdot
.35322 .5521 Mdot
.40852 .80375 Mdot
.4007 .34994 Mdot
.61791 .6444 Mdot
.3648 .49647 Mdot
.67119 .55283 Mdot
.64695 .37489 Mdot
.75571 .55264 Mdot
.77295 .34345 Mdot
.36375 .76738 Mdot
.37801 .67219 Mdot
.62334 .62155 Mdot
.38739 .54945 Mdot
.65854 .41411 Mdot
.40487 .38959 Mdot
.39222 .36732 Mdot
.59559 .38911 Mdot
.65216 .43559 Mdot
.60932 .3927 Mdot
.64727 .38664 Mdot
.41899 .23472 Mdot
.59578 .4663 Mdot
.75358 .3495 Mdot
.42834 .36634 Mdot
.65066 .42415 Mdot
.45057 .61774 Mdot
.5648 .46064 Mdot
.36476 .53384 Mdot
.62618 .43008 Mdot
.64409 .43567 Mdot
.60325 .38265 Mdot
.36207 .55387 Mdot
.1915 .38882 Mdot
.79412 .42198 Mdot
.17617 .46907 Mdot
.60975 .76015 Mdot
.44175 .65265 Mdot
.62501 .4071 Mdot
.60418 .65275 Mdot
.56903 .30125 Mdot
.619 .45794 Mdot
.87828 .53481 Mdot
.6395 .42094 Mdot
.18541 .47015 Mdot
.68695 .4686 Mdot
.15626 .53044 Mdot
.75824 .51945 Mdot
.65803 .4054 Mdot
.60561 .52998 Mdot
.47877 .41072 Mdot
.42144 .57838 Mdot
.36333 .52775 Mdot
.4558 .61697 Mdot
.48172 .63014 Mdot
.40411 .51838 Mdot
.39107 .28853 Mdot
.57503 .50446 Mdot
.6096 .48543 Mdot
.441 .68024 Mdot
.39505 .40777 Mdot
.60457 .61358 Mdot
.38349 .37705 Mdot
.37976 .15982 Mdot
.2672 .57406 Mdot
.40088 .54673 Mdot
.63928 .65998 Mdot
.48464 .66337 Mdot
.42568 .61695 Mdot
.61927 .66 Mdot
.59097 .42037 Mdot
.39654 .34946 Mdot
.3215 .75717 Mdot
.35535 .29293 Mdot
.38611 .80328 Mdot
.40776 .39687 Mdot
.31455 .36383 Mdot
.34605 .50374 Mdot
.44646 .63309 Mdot
.63566 .41438 Mdot
.59767 .42104 Mdot
.45397 .37168 Mdot
.60709 .39498 Mdot
.7265 .39807 Mdot
.64041 .40292 Mdot
.29415 .64462 Mdot
.61887 .59909 Mdot
.40433 .52195 Mdot
.71516 .51546 Mdot
.38488 .34435 Mdot
.72316 .6569 Mdot
.42661 .63417 Mdot
.54854 .30501 Mdot
.3582 .53908 Mdot
.59227 .63945 Mdot
.42534 .64293 Mdot
.60169 .61236 Mdot
.56349 .40727 Mdot
.50275 .64095 Mdot
.60964 .66387 Mdot
.42828 .28337 Mdot
.65411 .38427 Mdot
.4137 .23017 Mdot
.38021 .55144 Mdot
.39448 .32177 Mdot
.61228 .38216 Mdot
.43628 .64438 Mdot
.55486 .41821 Mdot
.3828 .61719 Mdot
.31979 .68415 Mdot
.4456 .60733 Mdot
.44335 .73185 Mdot
.59833 .62558 Mdot
.3425 .59779 Mdot
.31388 .39349 Mdot
.43047 .39198 Mdot
.58923 .46372 Mdot
.14407 .53248 Mdot
.36479 .49679 Mdot
.58575 .4374 Mdot
.33165 .72502 Mdot
.36881 .50242 Mdot
.61573 .42917 Mdot
.39252 .51447 Mdot
.39113 .36501 Mdot
.79654 .57774 Mdot
.43947 .37933 Mdot
.67491 .42727 Mdot
.3841 .53333 Mdot
.48241 .62076 Mdot
.40948 .38704 Mdot
.5863 .41872 Mdot
.63485 .39603 Mdot
.50787 .50417 Mdot
.65084 .41699 Mdot
.19087 .41236 Mdot
.64801 .40039 Mdot
.46441 .62058 Mdot
.56981 .42863 Mdot
.72636 .75001 Mdot
.28849 .5534 Mdot
.39932 .34605 Mdot
.48314 .61811 Mdot
.48625 .6414 Mdot
.62422 .70234 Mdot
.35052 .57668 Mdot
.63296 .4625 Mdot
.43905 .65075 Mdot
.75443 .60795 Mdot
.34806 .48904 Mdot
.58717 .46435 Mdot
.45438 .54625 Mdot
.48871 .74314 Mdot
.42405 .65131 Mdot
.59413 .36398 Mdot
.44882 .37355 Mdot
.64364 .43986 Mdot
.43335 .61482 Mdot
.44029 .40795 Mdot
.65823 .45419 Mdot
.35714 .35717 Mdot
.50665 .50177 Mdot
.33869 .51315 Mdot
.67593 .48279 Mdot
.58048 .42634 Mdot
.44059 .62982 Mdot
.38325 .35286 Mdot
.35562 .48195 Mdot
.40355 .37696 Mdot
.21392 .61996 Mdot
.35506 .44804 Mdot
.4117 .26387 Mdot
.60698 .67771 Mdot
.43912 .75577 Mdot
.16607 .56338 Mdot
.6787 .74262 Mdot
.71186 .63922 Mdot
.25466 .69759 Mdot
.44241 .61521 Mdot
.35637 .73844 Mdot
.48396 .63521 Mdot
.65777 .44232 Mdot
.47332 .64907 Mdot
.16196 .56159 Mdot
.64141 .4042 Mdot
.46903 .64355 Mdot
.74235 .64697 Mdot
.6496 .43096 Mdot
.43327 .35384 Mdot
.22803 .33007 Mdot
.70008 .7425 Mdot
.30381 .67947 Mdot
.49359 .6662 Mdot
.6894 .63426 Mdot
.6447 .41019 Mdot
.56706 .42448 Mdot
.42886 .3852 Mdot
.58753 .46808 Mdot
.61235 .61562 Mdot
.63784 .66242 Mdot
.47153 .42514 Mdot
.78842 .47578 Mdot
.69646 .41578 Mdot
.41454 .38871 Mdot
.46841 .20887 Mdot
.53257 .776 Mdot
.45964 .74774 Mdot
.39735 .52027 Mdot
.22588 .34457 Mdot
.70983 .36462 Mdot
.4133 .51417 Mdot
.45881 .57333 Mdot
.42467 .35448 Mdot
.1831 .41249 Mdot
.36513 .52416 Mdot
.62703 .23588 Mdot
.61708 .55203 Mdot
.59262 .4242 Mdot
.35453 .54042 Mdot
.69609 .38343 Mdot
.68075 .76566 Mdot
.64683 .22409 Mdot
.76029 .42543 Mdot
.67388 .43506 Mdot
.5728 .76884 Mdot
.62973 .42473 Mdot
.25349 .35548 Mdot
.64702 .39809 Mdot
.41046 .38067 Mdot
.27372 .35206 Mdot
.4888 .44643 Mdot
.78304 .39792 Mdot
.26914 .54775 Mdot
.62275 .62089 Mdot
.636 .40798 Mdot
.59226 .42606 Mdot
.60869 .61845 Mdot
.43364 .33688 Mdot
.64749 .38607 Mdot
.71365 .66085 Mdot
.61205 .40165 Mdot
.37123 .52719 Mdot
.74955 .43142 Mdot
.39342 .3017 Mdot
.63182 .47954 Mdot
.39987 .40615 Mdot
.33778 .51288 Mdot
.38224 .51793 Mdot
.68179 .39077 Mdot
.34784 .55323 Mdot
.63862 .42816 Mdot
.65339 .22001 Mdot
.44128 .35274 Mdot
.71341 .43977 Mdot
.40375 .32805 Mdot
.49599 .30064 Mdot
.38644 .52026 Mdot
.28891 .62482 Mdot
.62239 .34665 Mdot
.36167 .52272 Mdot
.36878 .44396 Mdot
.69375 .4246 Mdot
.67993 .43475 Mdot
.52566 .80221 Mdot
.49902 .65579 Mdot
.50314 .48032 Mdot
.38047 .49791 Mdot
.58206 .4186 Mdot
.61507 .47922 Mdot
.33777 .51954 Mdot
.56662 .19766 Mdot
.72819 .69083 Mdot
.64414 .40115 Mdot
.41945 .37848 Mdot
.41036 .36717 Mdot
.67412 .44024 Mdot
.58787 .4528 Mdot
.45927 .66572 Mdot
.50124 .63262 Mdot
.49866 .66698 Mdot
.50534 .49808 Mdot
.29043 .63325 Mdot
.22439 .54353 Mdot
.35559 .55637 Mdot
.3118 .42952 Mdot
.58506 .78404 Mdot
.5711 .4764 Mdot
.46498 .6786 Mdot
.5923 .44035 Mdot
.63729 .43764 Mdot
.35012 .4823 Mdot
.30907 .69741 Mdot
.69905 .37089 Mdot
.44206 .34568 Mdot
.36901 .48559 Mdot
.53669 .41693 Mdot
.26078 .5057 Mdot
.5983 .65191 Mdot
.43284 .79989 Mdot
.36199 .53832 Mdot
.42841 .35168 Mdot
.3896 .51942 Mdot
.59966 .41558 Mdot
.60842 .36436 Mdot
.41677 .35605 Mdot
.6348 .65988 Mdot
.55879 .43495 Mdot
.61783 .42689 Mdot
.82758 .4202 Mdot
.60785 .77071 Mdot
.30346 .64463 Mdot
.65518 .4037 Mdot
.64237 .47328 Mdot
.58389 .62933 Mdot
.60717 .40535 Mdot
.61565 .38652 Mdot
.81513 .56446 Mdot
.29335 .49681 Mdot
.62143 .67495 Mdot
.6011 .21891 Mdot
.41192 .39787 Mdot
.15214 .49684 Mdot
.443 .63524 Mdot
.37371 .56811 Mdot
.7485 .67581 Mdot
.4172 .61714 Mdot
.38684 .67879 Mdot
.15809 .47703 Mdot
.50091 .47738 Mdot
.52371 .68346 Mdot
.67575 .34748 Mdot
.63161 .38647 Mdot
.62796 .42091 Mdot
.60526 .64932 Mdot
.3955 .35414 Mdot
.51666 .50102 Mdot
.4432 .18975 Mdot
.63026 .43206 Mdot
.7231 .4267 Mdot
.35701 .27065 Mdot
.49548 .73961 Mdot
.6257 .63081 Mdot
.63744 .65856 Mdot
.63325 .41147 Mdot
.79986 .60143 Mdot
.40293 .38378 Mdot
.58588 .42013 Mdot
.62593 .46727 Mdot
.49992 .6579 Mdot
.41673 .34172 Mdot
.43741 .61605 Mdot
.28379 .60419 Mdot
.18039 .47465 Mdot
.83313 .41545 Mdot
.38439 .51792 Mdot
.30018 .29707 Mdot
.36372 .48886 Mdot
.76867 .48183 Mdot
.42118 .61942 Mdot
.62574 .45971 Mdot
.38384 .34953 Mdot
.58313 .4272 Mdot
.59544 .4588 Mdot
.59034 .42252 Mdot
.59273 .4823 Mdot
.84855 .60443 Mdot
.62782 .65997 Mdot
.66713 .46266 Mdot
.47936 .62623 Mdot
.24781 .34157 Mdot
.33464 .23399 Mdot
.59609 .43104 Mdot
.63413 .40024 Mdot
.43129 .34092 Mdot
.58315 .39982 Mdot
.35313 .48768 Mdot
.38147 .35718 Mdot
.6451 .38804 Mdot
.23346 .34471 Mdot
.66633 .40127 Mdot
.16358 .50712 Mdot
.38924 .51476 Mdot
.35561 .41934 Mdot
.67803 .45546 Mdot
.32175 .68258 Mdot
.50323 .48049 Mdot
.44155 .66474 Mdot
.34065 .55138 Mdot
.46321 .63253 Mdot
.52716 .16003 Mdot
.59504 .37386 Mdot
.66021 .41743 Mdot
.60692 .4784 Mdot
.44066 .65039 Mdot
.21974 .42872 Mdot
.31528 .58832 Mdot
.53626 .43256 Mdot
.44956 .65798 Mdot
.38438 .39958 Mdot
.6198 .57354 Mdot
.39221 .33927 Mdot
.64 .66246 Mdot
.34652 .52422 Mdot
.63855 .64064 Mdot
.31445 .71905 Mdot
.41455 .34732 Mdot
.44819 .32659 Mdot
.44678 .64226 Mdot
.53265 .5717 Mdot
.41924 .86159 Mdot
.58269 .5636 Mdot
.73464 .54379 Mdot
.42854 .38315 Mdot
.6706 .43357 Mdot
.75646 .46966 Mdot
.52146 .55784 Mdot
.4665 .63306 Mdot
.62399 .45321 Mdot
.78966 .59968 Mdot
.45864 .66603 Mdot
.58666 .46291 Mdot
.49634 .63986 Mdot
.35647 .53021 Mdot
.47263 .67431 Mdot
.44692 .33985 Mdot
.62722 .39563 Mdot
.3803 .83749 Mdot
.64791 .62181 Mdot
.64946 .40675 Mdot
.37191 .48759 Mdot
.39809 .44384 Mdot
.59878 .45483 Mdot
.58762 .63339 Mdot
.46496 .65281 Mdot
.57369 .56943 Mdot
.64494 .39962 Mdot
.44296 .65142 Mdot
.37379 .3744 Mdot
.35125 .56189 Mdot
.50867 .41062 Mdot
.31671 .679 Mdot
.42727 .38742 Mdot
.43087 .54794 Mdot
.32985 .51458 Mdot
.63749 .47608 Mdot
.6007 .4699 Mdot
.41621 .37541 Mdot
.80261 .538 Mdot
.57304 .41195 Mdot
.63294 .45848 Mdot
.47407 .62221 Mdot
.46351 .637 Mdot
.79591 .56134 Mdot
.46489 .61356 Mdot
.60431 .36644 Mdot
.4142 .37602 Mdot
.63834 .44489 Mdot
.42991 .34314 Mdot
.57807 .40986 Mdot
.46079 .39367 Mdot
.43245 .33328 Mdot
.31796 .57703 Mdot
.63033 .44851 Mdot
.69072 .46726 Mdot
.58731 .44209 Mdot
.61309 .39544 Mdot
.46379 .66495 Mdot
.62553 .64837 Mdot
.62423 .35457 Mdot
.64643 .62849 Mdot
.59973 .61446 Mdot
.42619 .43303 Mdot
.49831 .65954 Mdot
.61189 .63997 Mdot
.37559 .24622 Mdot
.50064 .66324 Mdot
.60032 .63942 Mdot
.32729 .24355 Mdot
.38432 .5124 Mdot
.44804 .36574 Mdot
.65047 .43162 Mdot
.25434 .68735 Mdot
.72878 .31596 Mdot
.4068 .62271 Mdot
.64892 .40196 Mdot
.59382 .44535 Mdot
.39603 .32486 Mdot
.5948 .16038 Mdot
.45524 .68449 Mdot
.66819 .42543 Mdot
.40383 .34173 Mdot
.65308 .19376 Mdot
.46193 .62181 Mdot
.60137 .64306 Mdot
.36809 .55648 Mdot
.37034 .39106 Mdot
.2927 .52063 Mdot
.34385 .5349 Mdot
.41558 .64403 Mdot
.27657 .6186 Mdot
.64618 .45786 Mdot
.46128 .6777 Mdot
.4557 .81138 Mdot
.35718 .29747 Mdot
.31534 .51479 Mdot
.68387 .63161 Mdot
.42597 .35632 Mdot
.3552 .48818 Mdot
.63491 .64055 Mdot
.40387 .39522 Mdot
.43835 .35829 Mdot
.34153 .48872 Mdot
.52828 .37538 Mdot
.45958 .54781 Mdot
.37689 .52485 Mdot
.53652 .79515 Mdot
.23805 .62148 Mdot
.46311 .67924 Mdot
.60941 .61669 Mdot
.29251 .70717 Mdot
.39736 .36964 Mdot
.22269 .34751 Mdot
.46235 .80598 Mdot
.6421 .41207 Mdot
.61603 .63736 Mdot
.22084 .48101 Mdot
.46929 .1705 Mdot
.37049 .50417 Mdot
.48438 .45433 Mdot
.62601 .6169 Mdot
.60811 .38342 Mdot
.64641 .56529 Mdot
.63905 .45234 Mdot
.34368 .51318 Mdot
.43957 .25335 Mdot
.42886 .35048 Mdot
.34502 .48216 Mdot
.43013 .80029 Mdot
.63641 .4305 Mdot
.62816 .45145 Mdot
.70308 .51624 Mdot
.39134 .37606 Mdot
.44029 .66363 Mdot
.64033 .46011 Mdot
.62141 .42821 Mdot
.63835 .36063 Mdot
.66721 .49076 Mdot
.793 .62092 Mdot
.66378 .43517 Mdot
.27274 .55956 Mdot
.64055 .47746 Mdot
.62558 .4473 Mdot
.40077 .40693 Mdot
.85463 .45655 Mdot
.28043 .59518 Mdot
.62519 .42898 Mdot
.6694 .43408 Mdot
.33734 .49428 Mdot
.47082 .54397 Mdot
.5267 .57212 Mdot
.55953 .57702 Mdot
.70205 .63891 Mdot
.60064 .48729 Mdot
.39807 .33934 Mdot
.60333 .66212 Mdot
.65043 .46357 Mdot
.40079 .33806 Mdot
.61473 .37661 Mdot
.4563 .66622 Mdot
.50431 .65765 Mdot
.37961 .43803 Mdot
.60705 .63624 Mdot
.7189 .47788 Mdot
.30149 .43992 Mdot
.4657 .61751 Mdot
.66101 .42129 Mdot
.38456 .57011 Mdot
.43117 .6156 Mdot
.53057 .65827 Mdot
.56538 .49213 Mdot
.39835 .38195 Mdot
.42677 .3641 Mdot
.75744 .55387 Mdot
.36201 .65294 Mdot
.82581 .45387 Mdot
.35448 .53008 Mdot
.57094 .40254 Mdot
.30269 .3947 Mdot
.42912 .36212 Mdot
.75845 .48042 Mdot
.61226 .63756 Mdot
.37026 .50178 Mdot
.41251 .71418 Mdot
.42242 .33454 Mdot
.44343 .37118 Mdot
.67454 .40275 Mdot
.60757 .42754 Mdot
.71735 .63647 Mdot
.58446 .60761 Mdot
.33845 .50689 Mdot
.60733 .61722 Mdot
.42532 .64717 Mdot
.6649 .43554 Mdot
.4015 .32613 Mdot
.27202 .66575 Mdot
.66565 .4407 Mdot
.46399 .66689 Mdot
.4229 .3591 Mdot
.60289 .6188 Mdot
.59227 .61899 Mdot
.61351 .39661 Mdot
.47402 .21213 Mdot
.37056 .51683 Mdot
.43252 .35508 Mdot
.26532 .5204 Mdot
.56939 .43247 Mdot
.6115 .42219 Mdot
.63792 .49687 Mdot
.34853 .48593 Mdot
.33835 .39179 Mdot
.64012 .6302 Mdot
.39953 .35653 Mdot
.66254 .40718 Mdot
.60051 .63275 Mdot
.32687 .38921 Mdot
.44263 .60741 Mdot
.47681 .67149 Mdot
.58802 .62908 Mdot
.61938 .63056 Mdot
.58935 .63049 Mdot
.22293 .34492 Mdot
.43046 .32171 Mdot
.7044 .36068 Mdot
.57103 .4125 Mdot
.75068 .53746 Mdot
.56446 .37708 Mdot
.36461 .4802 Mdot
.4982 .65497 Mdot
.59097 .45157 Mdot
.67225 .43395 Mdot
.66344 .48755 Mdot
.7154 .41662 Mdot
.40636 .3023 Mdot
.41475 .34408 Mdot
.59444 .37858 Mdot
.50232 .64606 Mdot
.40652 .14301 Mdot
.21766 .67761 Mdot
.68632 .4401 Mdot
.4949 .56458 Mdot
.40393 .3245 Mdot
.33512 .53179 Mdot
.55402 .59257 Mdot
.38899 .52616 Mdot
.40368 .35875 Mdot
.66388 .43644 Mdot
.3094 .43921 Mdot
.58609 .63038 Mdot
.58926 .40513 Mdot
.35236 .49575 Mdot
.59794 .39695 Mdot
.34482 .53635 Mdot
.19618 .59304 Mdot
.60969 .78374 Mdot
.63966 .41974 Mdot
.66562 .46144 Mdot
.68334 .65915 Mdot
.59608 .43375 Mdot
.65393 .61011 Mdot
.40888 .32266 Mdot
.80411 .45047 Mdot
.66048 .38493 Mdot
.55914 .25442 Mdot
.56907 .43496 Mdot
.77362 .61878 Mdot
.60767 .42201 Mdot
.49594 .7478 Mdot
.63934 .39097 Mdot
.6182 .38821 Mdot
.38592 .53138 Mdot
.33914 .49124 Mdot
.4113 .40376 Mdot
.43656 .64902 Mdot
.1679 .48437 Mdot
.61581 .425 Mdot
.3169 .68472 Mdot
.31527 .46271 Mdot
.61994 .62895 Mdot
.40166 .36082 Mdot
.59605 .15473 Mdot
.39366 .52556 Mdot
.64439 .73094 Mdot
.77462 .5945 Mdot
.28551 .53971 Mdot
.56342 .59839 Mdot
.26869 .34745 Mdot
.59653 .62942 Mdot
.59749 .38579 Mdot
.29861 .69077 Mdot
.48993 .76579 Mdot
.562 .49068 Mdot
.33443 .49213 Mdot
.56173 .29326 Mdot
.28367 .68523 Mdot
.62961 .61354 Mdot
.63948 .63771 Mdot
.3527 .54728 Mdot
.42831 .71751 Mdot
.69966 .38262 Mdot
.61227 .63421 Mdot
.47123 .61752 Mdot
.47808 .67917 Mdot
.43125 .58995 Mdot
.39745 .37667 Mdot
.39247 .78202 Mdot
.25302 .47161 Mdot
.34233 .52997 Mdot
.50851 .69791 Mdot
.38604 .31701 Mdot
.44314 .32769 Mdot
.45075 .63627 Mdot
.47048 .66566 Mdot
.45023 .36253 Mdot
.63915 .36787 Mdot
.68395 .46806 Mdot
.6291 .42992 Mdot
.61106 .65483 Mdot
.6023 .4238 Mdot
.45557 .66028 Mdot
.36687 .50546 Mdot
.48013 .66143 Mdot
.39327 .51259 Mdot
.23161 .54 Mdot
.59214 .40992 Mdot
.63029 .39437 Mdot
.72503 .30531 Mdot
.38835 .39503 Mdot
.26398 .55711 Mdot
.30906 .67166 Mdot
.48368 .6334 Mdot
.61376 .38617 Mdot
.38077 .34762 Mdot
.64355 .63142 Mdot
.7223 .29798 Mdot
.58183 .44605 Mdot
.40494 .32518 Mdot
.66634 .41418 Mdot
.38629 .2607 Mdot
.77497 .68857 Mdot
.40498 .37423 Mdot
.76973 .34129 Mdot
.6718 .41925 Mdot
.31954 .29781 Mdot
.60934 .47621 Mdot
.7571 .59069 Mdot
.57289 .41322 Mdot
.40906 .3976 Mdot
.62418 .43281 Mdot
.38465 .36978 Mdot
.45114 .61916 Mdot
.34644 .54718 Mdot
.43463 .37535 Mdot
.61614 .47106 Mdot
.14356 .64569 Mdot
.34599 .5159 Mdot
.63568 .41161 Mdot
.37669 .55119 Mdot
.39305 .34877 Mdot
.43704 .37962 Mdot
.42646 .187 Mdot
.28849 .60197 Mdot
.357 .52955 Mdot
.66596 .42892 Mdot
.24763 .43148 Mdot
.64056 .44757 Mdot
.72656 .60447 Mdot
.6551 .37048 Mdot
.57008 .42453 Mdot
.353 .21561 Mdot
.34298 .49308 Mdot
.83282 .48204 Mdot
.41119 .19379 Mdot
.25251 .32408 Mdot
.38552 .41015 Mdot
.63414 .61706 Mdot
.18705 .40234 Mdot
.29069 .62827 Mdot
.44537 .65508 Mdot
.58919 .44713 Mdot
.3818 .31137 Mdot
.37666 .51592 Mdot
.62439 .65173 Mdot
.63938 .419 Mdot
.47341 .66611 Mdot
.69857 .71191 Mdot
.39114 .54615 Mdot
.3971 .36682 Mdot
.4364 .33583 Mdot
.72724 .26058 Mdot
.65799 .40425 Mdot
.63054 .39172 Mdot
.34449 .51922 Mdot
.33799 .31807 Mdot
.59537 .62738 Mdot
.7307 .66669 Mdot
.35571 .52836 Mdot
.505 .52541 Mdot
.40422 .34662 Mdot
.59276 .44343 Mdot
.21004 .43921 Mdot
.56497 .76508 Mdot
.64177 .25746 Mdot
.60551 .65296 Mdot
.72161 .6017 Mdot
.41059 .39828 Mdot
.35918 .49921 Mdot
.35712 .67147 Mdot
.5558 .46413 Mdot
.59738 .44371 Mdot
.72165 .59497 Mdot
.48943 .42741 Mdot
.75807 .42671 Mdot
.57885 .44512 Mdot
.50068 .45606 Mdot
.57461 .42586 Mdot
.54801 .44472 Mdot
.6222 .36346 Mdot
.61493 .41474 Mdot
.40483 .32473 Mdot
.5515 .47383 Mdot
.44607 .66399 Mdot
.73574 .39596 Mdot
.52245 .53171 Mdot
.64682 .40427 Mdot
.64873 .44767 Mdot
.63953 .27853 Mdot
.4165 .52288 Mdot
.43368 .36997 Mdot
.45878 .35543 Mdot
.35431 .55811 Mdot
.67444 .47937 Mdot
.43412 .65016 Mdot
.55363 .39647 Mdot
.46746 .66358 Mdot
.39228 .3355 Mdot
.47582 .62714 Mdot
.35974 .55579 Mdot
.47499 .67839 Mdot
.29005 .63395 Mdot
.3702 .49564 Mdot
.40391 .39022 Mdot
.61899 .39946 Mdot
.37163 .48781 Mdot
.69979 .53057 Mdot
.61001 .65419 Mdot
.41096 .18817 Mdot
.65261 .38971 Mdot
.294 .50282 Mdot
.35644 .3649 Mdot
.47686 .66217 Mdot
.80275 .63174 Mdot
.43572 .33721 Mdot
.62173 .67313 Mdot
.38675 .34015 Mdot
.56317 .80151 Mdot
.6247 .64254 Mdot
.31829 .2488 Mdot
.38855 .71873 Mdot
.61517 .58527 Mdot
.64324 .37017 Mdot
.62605 .55947 Mdot
.42972 .66171 Mdot
.37665 .5148 Mdot
.37619 .68069 Mdot
.61342 .38805 Mdot
.6563 .74972 Mdot
.43012 .40373 Mdot
.43826 .65252 Mdot
.35683 .50566 Mdot
.3601 .48162 Mdot
.59061 .46 Mdot
.54048 .68793 Mdot
.57937 .417 Mdot
.34648 .63284 Mdot
.70625 .62735 Mdot
.70517 .39934 Mdot
.63999 .4036 Mdot
.44156 .62653 Mdot
.66641 .41486 Mdot
.59391 .6722 Mdot
.38526 .78788 Mdot
.57359 .46042 Mdot
.30331 .66349 Mdot
.65326 .65294 Mdot
.41573 .35254 Mdot
.68255 .37475 Mdot
.29983 .62918 Mdot
.66247 .40986 Mdot
.75398 .75626 Mdot
.60035 .63693 Mdot
.32589 .69556 Mdot
.6049 .4816 Mdot
.61365 .46807 Mdot
.56079 .52071 Mdot
.47291 .40835 Mdot
.57249 .76426 Mdot
.60331 .4401 Mdot
.68471 .58323 Mdot
.35959 .5466 Mdot
.57839 .42491 Mdot
.62996 .41846 Mdot
.53493 .35865 Mdot
.36253 .48482 Mdot
.49086 .64438 Mdot
.4179 .62943 Mdot
.50178 .67369 Mdot
.60277 .67321 Mdot
.48555 .47661 Mdot
.75246 .50737 Mdot
.69112 .74492 Mdot
.60708 .66668 Mdot
.66486 .3952 Mdot
.65904 .67881 Mdot
.6579 .44715 Mdot
.63244 .63875 Mdot
.36461 .48696 Mdot
.43553 .36895 Mdot
.30708 .37494 Mdot
.44627 .6814 Mdot
.58968 .46719 Mdot
.60947 .61329 Mdot
.40294 .38792 Mdot
.57062 .62346 Mdot
.40816 .35242 Mdot
.35648 .52318 Mdot
.36908 .56419 Mdot
.62956 .64824 Mdot
.39656 .33505 Mdot
.39976 .47695 Mdot
.47397 .17191 Mdot
.62092 .36131 Mdot
.33291 .55929 Mdot
.38085 .38351 Mdot
.45416 .3592 Mdot
.39035 .38848 Mdot
.60366 .39697 Mdot
.492 .56275 Mdot
.67824 .39139 Mdot
.33859 .50857 Mdot
.49666 .64254 Mdot
.68094 .69012 Mdot
.24057 .58972 Mdot
.58279 .68103 Mdot
.57445 .39726 Mdot
.63411 .43362 Mdot
.63326 .4118 Mdot
.67686 .40003 Mdot
.33595 .6365 Mdot
.58444 .43081 Mdot
.38466 .53655 Mdot
.46405 .65659 Mdot
.60031 .38405 Mdot
.42182 .6105 Mdot
.2466 .38505 Mdot
.6126 .66666 Mdot
.47788 .45947 Mdot
.12845 .56664 Mdot
.41193 .3918 Mdot
.45418 .61096 Mdot
.44514 .65253 Mdot
.58987 .64167 Mdot
.37356 .52074 Mdot
.40362 .35007 Mdot
.74216 .61607 Mdot
.5941 .62033 Mdot
.62318 .43101 Mdot
.51993 .59035 Mdot
.64306 .7518 Mdot
.58828 .39193 Mdot
.6105 .46079 Mdot
.43698 .60712 Mdot
.45955 .73522 Mdot
.4139 .83103 Mdot
.74305 .48092 Mdot
.62775 .64768 Mdot
.62881 .66385 Mdot
.45014 .36925 Mdot
.69083 .41359 Mdot
.33847 .51207 Mdot
.7521 .4103 Mdot
.4264 .44258 Mdot
.72711 .46892 Mdot
.50537 .42176 Mdot
.58232 .44355 Mdot
.55476 .18719 Mdot
.63821 .43049 Mdot
.41304 .31968 Mdot
.38872 .35754 Mdot
.42174 .38419 Mdot
.37422 .51416 Mdot
.51744 .30835 Mdot
.38218 .53752 Mdot
.14102 .58403 Mdot
.41729 .39854 Mdot
.33885 .67732 Mdot
.4447 .62712 Mdot
.67886 .45597 Mdot
.60204 .62076 Mdot
.33847 .47763 Mdot
.64984 .48053 Mdot
.80214 .60349 Mdot
.44182 .65776 Mdot
.40714 .39245 Mdot
.2763 .33834 Mdot
.17387 .59513 Mdot
.54099 .57938 Mdot
.54339 .39869 Mdot
.61497 .55965 Mdot
.61932 .62616 Mdot
.64706 .25931 Mdot
.6161 .61419 Mdot
.35793 .49265 Mdot
.62879 .39828 Mdot
.61905 .40491 Mdot
.57413 .41914 Mdot
.58745 .42065 Mdot
.33594 .53584 Mdot
.56599 .43527 Mdot
.7263 .75005 Mdot
.50695 .65071 Mdot
.42269 .27762 Mdot
.59829 .6319 Mdot
.32887 .5167 Mdot
.46266 .65773 Mdot
.39967 .62755 Mdot
.72332 .51175 Mdot
.64357 .40038 Mdot
.58937 .44928 Mdot
.63885 .73954 Mdot
.57786 .4445 Mdot
.57148 .36918 Mdot
.4435 .65262 Mdot
.59041 .68532 Mdot
.62687 .66802 Mdot
.63613 .65142 Mdot
.37828 .50002 Mdot
.39149 .33746 Mdot
.60819 .64474 Mdot
.45614 .61953 Mdot
.57511 .39519 Mdot
.63749 .46476 Mdot
.38381 .387 Mdot
.47178 .80816 Mdot
.62835 .61464 Mdot
.26189 .35768 Mdot
.38436 .35649 Mdot
.40684 .31166 Mdot
.59863 .44497 Mdot
.60681 .51478 Mdot
.36638 .3832 Mdot
.60411 .66694 Mdot
.32956 .52419 Mdot
.56618 .58101 Mdot
.34408 .50282 Mdot
.39238 .35955 Mdot
.65406 .45938 Mdot
.38937 .36419 Mdot
.65384 .40212 Mdot
.12341 .48874 Mdot
.61337 .41154 Mdot
.6891 .75218 Mdot
.7483 .57098 Mdot
.45613 .64731 Mdot
.37298 .45289 Mdot
.44365 .6381 Mdot
.3843 .35933 Mdot
.64406 .46518 Mdot
.64118 .63927 Mdot
.2835 .28969 Mdot
.39175 .31147 Mdot
.45853 .66971 Mdot
.47761 .68361 Mdot
.36471 .49014 Mdot
.58338 .39222 Mdot
.59394 .44034 Mdot
.46773 .64193 Mdot
.70668 .39741 Mdot
.41915 .33012 Mdot
.63502 .39788 Mdot
.62889 .44115 Mdot
.4542 .64562 Mdot
.49623 .16452 Mdot
.4706 .39658 Mdot
.6249 .40593 Mdot
.36587 .7168 Mdot
.3622 .47939 Mdot
.65452 .37416 Mdot
.64565 .47795 Mdot
.61716 .6314 Mdot
.47887 .33023 Mdot
.36709 .77395 Mdot
.38151 .49577 Mdot
.43846 .63799 Mdot
.65936 .40422 Mdot
.44075 .62865 Mdot
.62627 .46802 Mdot
.48345 .35756 Mdot
.44628 .67136 Mdot
.62361 .46391 Mdot
.69254 .40433 Mdot
.38992 .37414 Mdot
.58551 .4466 Mdot
.64627 .2957 Mdot
.42602 .62276 Mdot
.60814 .46732 Mdot
.47133 .21461 Mdot
.37446 .53162 Mdot
.69335 .40909 Mdot
.60586 .66132 Mdot
.74319 .618 Mdot
.27994 .46303 Mdot
.31546 .70045 Mdot
.61877 .66446 Mdot
.59455 .39834 Mdot
.4888 .67915 Mdot
.34813 .5421 Mdot
.70845 .73012 Mdot
.5977 .38899 Mdot
.34408 .5124 Mdot
.36504 .50498 Mdot
.60064 .65341 Mdot
.80686 .36979 Mdot
.59945 .48288 Mdot
.59698 .43025 Mdot
.5967 .32124 Mdot
.37009 .36344 Mdot
.60506 .41732 Mdot
.67454 .41641 Mdot
.38307 .54107 Mdot
.57218 .36702 Mdot
.59275 .28083 Mdot
.74913 .64013 Mdot
.37041 .47858 Mdot
.56566 .55789 Mdot
.4509 .67905 Mdot
.60259 .62844 Mdot
.41536 .35916 Mdot
.61735 .61209 Mdot
.481 .67366 Mdot
.66904 .40032 Mdot
.38694 .54424 Mdot
.69364 .31349 Mdot
.35119 .54664 Mdot
.32075 .70599 Mdot
.37219 .36835 Mdot
.28733 .40042 Mdot
.80218 .69577 Mdot
.24725 .481 Mdot
.41537 .5243 Mdot
.62005 .62935 Mdot
.40644 .65142 Mdot
.63102 .43905 Mdot
.66759 .26908 Mdot
.6181 .39533 Mdot
.47614 .21699 Mdot
.48368 .62389 Mdot
.49873 .66704 Mdot
.62706 .40169 Mdot
.7115 .62201 Mdot
.3454 .5406 Mdot
.34694 .48976 Mdot
.60066 .46469 Mdot
.36168 .52319 Mdot
.60668 .4306 Mdot
.46116 .66308 Mdot
.84115 .51751 Mdot
.63339 .42487 Mdot
.67307 .44832 Mdot
.30051 .53316 Mdot
.36609 .21655 Mdot
.39108 .75341 Mdot
.61116 .20748 Mdot
.19039 .62513 Mdot
.36117 .52204 Mdot
.68069 .39223 Mdot
.56955 .55748 Mdot
.41964 .61065 Mdot
.40342 .48141 Mdot
.6085 .40703 Mdot
.60721 .40434 Mdot
.62203 .38712 Mdot
.62952 .45187 Mdot
.64637 .25339 Mdot
.69638 .34246 Mdot
.47424 .25239 Mdot
.59257 .45616 Mdot
.65105 .54955 Mdot
.38298 .50279 Mdot
.44017 .40202 Mdot
.58692 .6107 Mdot
.58249 .4434 Mdot
.7031 .35335 Mdot
.34929 .47837 Mdot
.14178 .58569 Mdot
.37119 .49344 Mdot
.48554 .64092 Mdot
.33667 .53369 Mdot
.65168 .41519 Mdot
.41095 .36771 Mdot
.54168 .55051 Mdot
.34608 .60051 Mdot
.44578 .65596 Mdot
.64939 .40644 Mdot
.32661 .67191 Mdot
.44664 .66265 Mdot
.244 .39057 Mdot
.41612 .36561 Mdot
.6836 .57502 Mdot
.3881 .35908 Mdot
.62549 .46407 Mdot
.63286 .46057 Mdot
.32575 .54121 Mdot
.35004 .54959 Mdot
.38774 .35641 Mdot
.82288 .38775 Mdot
.60566 .61028 Mdot
.41632 .3853 Mdot
.55216 .42814 Mdot
.44795 .5003 Mdot
.41658 .37195 Mdot
.56764 .66552 Mdot
.37623 .50795 Mdot
.43616 .39144 Mdot
.55391 .45513 Mdot
.48131 .79438 Mdot
.59214 .65485 Mdot
.51718 .64325 Mdot
.52609 .60352 Mdot
.42957 .61773 Mdot
.33856 .54683 Mdot
.44483 .64159 Mdot
.36304 .54767 Mdot
.2955 .47227 Mdot
.73687 .41765 Mdot
.38327 .56817 Mdot
.33878 .5449 Mdot
.44739 .64244 Mdot
.63727 .39412 Mdot
.5407 .60689 Mdot
.67212 .38426 Mdot
.58246 .48069 Mdot
.36257 .54352 Mdot
.40619 .39557 Mdot
.44932 .34941 Mdot
.6474 .56075 Mdot
.43041 .32896 Mdot
.46822 .66449 Mdot
.75178 .70949 Mdot
.30227 .68324 Mdot
.35033 .53379 Mdot
.33153 .51715 Mdot
.64254 .44812 Mdot
.4641 .6325 Mdot
.44076 .62234 Mdot
.35669 .49013 Mdot
.70942 .46325 Mdot
.68499 .43097 Mdot
.45652 .34798 Mdot
.42668 .39615 Mdot
.40978 .3763 Mdot
.38945 .38537 Mdot
.58928 .25616 Mdot
.37519 .50361 Mdot
.40029 .39218 Mdot
.61497 .46509 Mdot
.60677 .40608 Mdot
.5544 .57026 Mdot
.63264 .65876 Mdot
.61744 .37672 Mdot
.61892 .36492 Mdot
.5969 .4471 Mdot
.47302 .67299 Mdot
.60823 .49823 Mdot
.44346 .66953 Mdot
.50778 .66439 Mdot
.50247 .63685 Mdot
.29101 .63059 Mdot
.65215 .59228 Mdot
.22244 .66345 Mdot
.66851 .42419 Mdot
.34925 .29598 Mdot
.45516 .6265 Mdot
.80244 .61962 Mdot
.33705 .38576 Mdot
.60659 .38651 Mdot
.54404 .76779 Mdot
.46491 .64152 Mdot
.43432 .33196 Mdot
.60982 .4086 Mdot
.51354 .65911 Mdot
.59888 .65823 Mdot
.57512 .3857 Mdot
.42028 .62456 Mdot
.39566 .33763 Mdot
.57871 .63586 Mdot
.42374 .39925 Mdot
.49907 .63385 Mdot
.69281 .40628 Mdot
.45675 .88306 Mdot
.46151 .68884 Mdot
.37027 .24128 Mdot
.42655 .42153 Mdot
.63524 .3964 Mdot
.44328 .61126 Mdot
.37308 .35289 Mdot
.34709 .55788 Mdot
.43832 .4491 Mdot
.44113 .35654 Mdot
.49698 .66861 Mdot
.42289 .62139 Mdot
.44375 .65367 Mdot
.41979 .34581 Mdot
.67367 .44281 Mdot
.42516 .34241 Mdot
.33541 .53091 Mdot
.64643 .43746 Mdot
.16256 .55865 Mdot
.34951 .29907 Mdot
.38576 .35627 Mdot
.49219 .65021 Mdot
.58413 .63294 Mdot
.64179 .42214 Mdot
.40156 .23006 Mdot
.64883 .39442 Mdot
.35132 .54009 Mdot
.81837 .53505 Mdot
.68883 .30577 Mdot
.57114 .41484 Mdot
.6416 .44866 Mdot
.34097 .4981 Mdot
.64327 .41003 Mdot
.57385 .40818 Mdot
.29059 .6209 Mdot
.41378 .34022 Mdot
.62584 .43478 Mdot
.48915 .63174 Mdot
.27249 .62648 Mdot
.68459 .41929 Mdot
.60836 .70899 Mdot
.69641 .58946 Mdot
.81643 .47813 Mdot
.62054 .39358 Mdot
.73619 .47291 Mdot
.62111 .45409 Mdot
.58912 .40737 Mdot
.65694 .44047 Mdot
.66537 .24987 Mdot
.45277 .67306 Mdot
.45186 .65531 Mdot
.59523 .65931 Mdot
.69371 .58835 Mdot
.61631 .63523 Mdot
.37928 .50946 Mdot
.56619 .70161 Mdot
.44615 .67093 Mdot
.39257 .33972 Mdot
.5859 .40611 Mdot
.46153 .6892 Mdot
.5907 .44043 Mdot
.65332 .41423 Mdot
.42997 .64143 Mdot
.44138 .67434 Mdot
.3206 .69676 Mdot
.60946 .66454 Mdot
.42829 .38013 Mdot
.6266 .37298 Mdot
.60423 .61473 Mdot
.66196 .45647 Mdot
.7531 .53193 Mdot
.42588 .38006 Mdot
.417 .34015 Mdot
.44616 .34612 Mdot
.6687 .40026 Mdot
.64804 .41534 Mdot
.38043 .53972 Mdot
.38716 .34223 Mdot
.37283 .53077 Mdot
.51135 .51109 Mdot
.63468 .70959 Mdot
.60845 .40693 Mdot
.26981 .35457 Mdot
.60825 .62402 Mdot
.48263 .65441 Mdot
.65965 .72241 Mdot
.59278 .65724 Mdot
.65076 .3997 Mdot
.43697 .62906 Mdot
.63391 .64384 Mdot
.53662 .47009 Mdot
.26693 .72886 Mdot
.58383 .62297 Mdot
.61092 .46524 Mdot
.57863 .3585 Mdot
.63128 .20686 Mdot
.58579 .65187 Mdot
.37349 .55507 Mdot
.66676 .39823 Mdot
.35959 .34682 Mdot
.62903 .61649 Mdot
.26325 .54933 Mdot
.46507 .65023 Mdot
.41835 .78539 Mdot
.62781 .49062 Mdot
.70603 .30334 Mdot
.62435 .61987 Mdot
.40192 .35279 Mdot
.44244 .4061 Mdot
.60556 .44972 Mdot
.5851 .65083 Mdot
.36823 .47603 Mdot
.47171 .6528 Mdot
.28 .59804 Mdot
.42216 .34639 Mdot
.2705 .38855 Mdot
.49228 .65678 Mdot
.25961 .37103 Mdot
.78436 .59971 Mdot
.69463 .44639 Mdot
.62294 .21146 Mdot
.39852 .70069 Mdot
.66302 .39071 Mdot
.59911 .60979 Mdot
.37878 .49321 Mdot
.37449 .55697 Mdot
.35376 .52428 Mdot
.3089 .46532 Mdot
.55425 .57995 Mdot
.465 .61176 Mdot
.39142 .59556 Mdot
.60271 .63135 Mdot
.66692 .53564 Mdot
.62613 .47149 Mdot
.63386 .43203 Mdot
.58329 .39108 Mdot
.57789 .43393 Mdot
.61702 .45043 Mdot
.36933 .52457 Mdot
.28883 .48832 Mdot
.56998 .56954 Mdot
.42209 .37643 Mdot
.53686 .67893 Mdot
.44576 .62694 Mdot
.47691 .61504 Mdot
.63005 .65524 Mdot
.25439 .35759 Mdot
.42148 .61207 Mdot
.48074 .63004 Mdot
.63867 .38177 Mdot
.42136 .3349 Mdot
.54209 .42519 Mdot
.63179 .45832 Mdot
.47332 .65945 Mdot
.54754 .52058 Mdot
.61723 .2805 Mdot
.58533 .49754 Mdot
.63631 .68336 Mdot
.48994 .55684 Mdot
.58239 .63926 Mdot
.63938 .4699 Mdot
.80591 .60795 Mdot
.47732 .67538 Mdot
.47701 .63605 Mdot
.62071 .61935 Mdot
.4354 .30177 Mdot
.42245 .35621 Mdot
.39706 .635 Mdot
.3721 .55228 Mdot
.64947 .45372 Mdot
.69584 .7077 Mdot
.39371 .28603 Mdot
.54222 .69278 Mdot
.35097 .52549 Mdot
.44636 .62127 Mdot
.57305 .4025 Mdot
.61132 .46458 Mdot
.61376 .62058 Mdot
.1952 .54017 Mdot
.59142 .3759 Mdot
.2427 .3313 Mdot
.60753 .78646 Mdot
.48028 .80278 Mdot
.59736 .4435 Mdot
.41455 .34174 Mdot
.42104 .61879 Mdot
.60942 .61695 Mdot
.55994 .44888 Mdot
.25239 .70734 Mdot
.40013 .40005 Mdot
.35986 .49539 Mdot
.54752 .54171 Mdot
.55229 .59184 Mdot
.64979 .38695 Mdot
.61818 .39657 Mdot
.59756 .40294 Mdot
.32706 .77383 Mdot
.46958 .67092 Mdot
.39715 .32845 Mdot
.60998 .65777 Mdot
.42529 .32494 Mdot
.45167 .65057 Mdot
.27501 .39802 Mdot
.64231 .39201 Mdot
.39679 .39892 Mdot
.40402 .35402 Mdot
.36732 .49188 Mdot
.35307 .56205 Mdot
.52759 .52733 Mdot
.61263 .41346 Mdot
.4508 .68777 Mdot
.39548 .38473 Mdot
.52438 .59131 Mdot
.62448 .64048 Mdot
.38567 .52111 Mdot
.59031 .45291 Mdot
.4632 .67615 Mdot
.56576 .43607 Mdot
.42921 .36489 Mdot
.47889 .62897 Mdot
.32091 .69114 Mdot
.62449 .66521 Mdot
.59596 .41527 Mdot
.58426 .65755 Mdot
.43803 .63766 Mdot
.63108 .44101 Mdot
.29667 .30864 Mdot
.64508 .67813 Mdot
.32401 .5955 Mdot
.4855 .62314 Mdot
.31774 .68291 Mdot
.4467 .35815 Mdot
.33179 .44554 Mdot
.48084 .63892 Mdot
.26951 .33955 Mdot
.2136 .57173 Mdot
.58715 .38431 Mdot
.39978 .3727 Mdot
.41432 .68825 Mdot
.14726 .49423 Mdot
.49192 .17081 Mdot
.63444 .41326 Mdot
.46725 .61412 Mdot
.62151 .62178 Mdot
.35136 .53566 Mdot
.61464 .71011 Mdot
.63689 .68521 Mdot
.45969 .68542 Mdot
.65756 .441 Mdot
.39571 .34848 Mdot
.37213 .50948 Mdot
.28327 .46713 Mdot
.46906 .62069 Mdot
.49745 .64909 Mdot
.57219 .40496 Mdot
.61123 .63759 Mdot
.44284 .20545 Mdot
.45788 .66311 Mdot
.63355 .74869 Mdot
.42133 .65361 Mdot
.60501 .61208 Mdot
.6165 .45813 Mdot
.63615 .56603 Mdot
.67066 .38828 Mdot
.34042 .25071 Mdot
.4456 .63521 Mdot
.4292 .37097 Mdot
.6106 .39289 Mdot
.76451 .61761 Mdot
.47618 .65673 Mdot
.49776 .56513 Mdot
.48627 .75059 Mdot
.37564 .50547 Mdot
.65938 .72438 Mdot
.59942 .42207 Mdot
.3468 .54179 Mdot
.6093 .62449 Mdot
.62058 .41062 Mdot
.64839 .41814 Mdot
.39217 .3275 Mdot
.35458 .4921 Mdot
.22426 .60839 Mdot
.34345 .48319 Mdot
.38944 .51756 Mdot
.41645 .31638 Mdot
.61238 .43853 Mdot
.4872 .64178 Mdot
.46565 .63999 Mdot
.56952 .4683 Mdot
.8247 .60036 Mdot
.42453 .35428 Mdot
.50175 .69963 Mdot
.35092 .78981 Mdot
.7 .43441 Mdot
.66737 .72057 Mdot
.1971 .52999 Mdot
.37849 .48416 Mdot
.59652 .46155 Mdot
.39315 .3431 Mdot
.40183 .62314 Mdot
.49589 .6482 Mdot
.66881 .4476 Mdot
.36672 .51008 Mdot
.5974 .65793 Mdot
.42547 .6398 Mdot
.5436 .68632 Mdot
.58915 .41242 Mdot
.54097 .77101 Mdot
.4438 .61404 Mdot
.19862 .35966 Mdot
.40184 .66296 Mdot
.4033 .37716 Mdot
.65357 .41749 Mdot
.44159 .34525 Mdot
.6157 .65797 Mdot
.54339 .54069 Mdot
.36709 .50754 Mdot
.63465 .33443 Mdot
.67642 .80084 Mdot
.44187 .65069 Mdot
.40788 .32266 Mdot
.57045 .4171 Mdot
.53671 .49049 Mdot
.60066 .42759 Mdot
.62886 .34357 Mdot
.65586 .66098 Mdot
.36608 .54147 Mdot
.3568 .54744 Mdot
.63678 .43963 Mdot
.59333 .62561 Mdot
.45113 .62137 Mdot
.47511 .65207 Mdot
.307 .22001 Mdot
.32461 .57433 Mdot
.72147 .63278 Mdot
.60361 .40657 Mdot
.4833 .6789 Mdot
.24834 .59889 Mdot
.34512 .52083 Mdot
.61165 .47436 Mdot
.43505 .65147 Mdot
.50541 .78757 Mdot
.76714 .58846 Mdot
.6138 .45272 Mdot
.62033 .4862 Mdot
.37331 .55283 Mdot
.68854 .51938 Mdot
.50181 .63963 Mdot
.65329 .36863 Mdot
.38641 .56097 Mdot
.8076 .53515 Mdot
.42786 .81074 Mdot
.42793 .38073 Mdot
.46899 .74053 Mdot
.37017 .5242 Mdot
.58626 .48671 Mdot
.59594 .63839 Mdot
.42408 .6463 Mdot
.46448 .67329 Mdot
.66432 .42783 Mdot
.56623 .43307 Mdot
.67692 .66822 Mdot
.42134 .32578 Mdot
.38237 .50297 Mdot
.62691 .39345 Mdot
.30254 .36122 Mdot
.57397 .4222 Mdot
.37936 .5377 Mdot
.44065 .88873 Mdot
.61698 .37347 Mdot
.59961 .43033 Mdot
.44391 .20317 Mdot
.44116 .35861 Mdot
.41961 .3208 Mdot
.64906 .7749 Mdot
.60287 .40721 Mdot
.64969 .73364 Mdot
.43172 .37786 Mdot
.426 .35733 Mdot
.29968 .60987 Mdot
.63854 .42494 Mdot
.74414 .36836 Mdot
.3459 .53661 Mdot
.39008 .52542 Mdot
.42541 .34443 Mdot
.60601 .37422 Mdot
.39501 .51862 Mdot
.59837 .22918 Mdot
.46209 .63187 Mdot
.81588 .58863 Mdot
.43485 .35761 Mdot
.49072 .45344 Mdot
.34849 .52548 Mdot
.1396 .58137 Mdot
.42143 .59779 Mdot
.63527 .39385 Mdot
.59617 .41147 Mdot
.6057 .625 Mdot
.61535 .37462 Mdot
.50166 .66408 Mdot
.36184 .52371 Mdot
.42274 .24406 Mdot
.4208 .38486 Mdot
.60946 .4209 Mdot
.25152 .37292 Mdot
.2418 .52093 Mdot
.40125 .74435 Mdot
.41489 .35308 Mdot
.39842 .37645 Mdot
.50119 .64089 Mdot
.46244 .61285 Mdot
.60958 .44455 Mdot
.34288 .49758 Mdot
.38631 .34497 Mdot
.37313 .54302 Mdot
.47786 .6748 Mdot
.48839 .63978 Mdot
.45018 .67429 Mdot
.58882 .3685 Mdot
.48213 .62868 Mdot
.56566 .67675 Mdot
.26576 .39872 Mdot
.44219 .32636 Mdot
.52478 .82779 Mdot
.28887 .4622 Mdot
.40051 .43852 Mdot
.63887 .62858 Mdot
.43754 .63768 Mdot
.33287 .51314 Mdot
.63666 .44792 Mdot
.58958 .44488 Mdot
.50682 .61999 Mdot
.33556 .52442 Mdot
.62228 .65409 Mdot
.34333 .54005 Mdot
.5999 .653 Mdot
.50177 .76618 Mdot
.5893 .38822 Mdot
.63665 .46387 Mdot
.36515 .52742 Mdot
.47841 .62738 Mdot
.45941 .65517 Mdot
.58131 .62854 Mdot
.49425 .406 Mdot
.44515 .66184 Mdot
.43381 .35991 Mdot
.57656 .2455 Mdot
.42339 .61939 Mdot
.60759 .4119 Mdot
.75595 .49936 Mdot
.68788 .28844 Mdot
.67779 .40143 Mdot
.29459 .61286 Mdot
.75715 .34427 Mdot
.60284 .39173 Mdot
.75889 .32822 Mdot
.31707 .67838 Mdot
.44101 .34883 Mdot
.48863 .62752 Mdot
.4459 .60591 Mdot
.64357 .35101 Mdot
.59933 .60319 Mdot
.56123 .45557 Mdot
.44043 .36533 Mdot
.40567 .40856 Mdot
.52243 .79906 Mdot
.36534 .24226 Mdot
.62715 .62667 Mdot
.63428 .65088 Mdot
.48031 .64124 Mdot
.4703 .15559 Mdot
.56731 .48452 Mdot
.62671 .64985 Mdot
.73124 .43757 Mdot
.65958 .4406 Mdot
.72904 .58417 Mdot
.61142 .75767 Mdot
.41913 .34347 Mdot
.62976 .5613 Mdot
.48409 .64696 Mdot
.42976 .33144 Mdot
.31156 .37006 Mdot
.63319 .3757 Mdot
.42425 .38131 Mdot
.37468 .54393 Mdot
.38391 .66949 Mdot
.43615 .38018 Mdot
.75587 .51099 Mdot
.35337 .48978 Mdot
.52062 .58664 Mdot
.66476 .56305 Mdot
.89914 .52011 Mdot
.36695 .52258 Mdot
.43373 .65905 Mdot
.46634 .6409 Mdot
.47603 .65075 Mdot
.42654 .32746 Mdot
.43999 .62424 Mdot
.41477 .32387 Mdot
.56928 .17405 Mdot
.49927 .40119 Mdot
.62929 .64655 Mdot
.28626 .59687 Mdot
.39721 .36109 Mdot
.77913 .67723 Mdot
.75495 .74199 Mdot
.59326 .45985 Mdot
.33422 .49803 Mdot
.63154 .63951 Mdot
.26278 .29641 Mdot
.61468 .629 Mdot
.59825 .58951 Mdot
.82192 .54678 Mdot
.61065 .42679 Mdot
.55639 .30755 Mdot
.63959 .64685 Mdot
.40592 .34726 Mdot
.63288 .43842 Mdot
.41697 .51 Mdot
.61156 .6313 Mdot
.59424 .65147 Mdot
.61816 .44295 Mdot
.40655 .39227 Mdot
.48828 .64859 Mdot
.35082 .5534 Mdot
.62353 .67522 Mdot
.46444 .37966 Mdot
.65537 .38381 Mdot
.6611 .40165 Mdot
.53071 .56938 Mdot
.56062 .64187 Mdot
.36142 .52133 Mdot
.70939 .28404 Mdot
.47115 .61656 Mdot
.4331 .70239 Mdot
.60846 .77826 Mdot
.29727 .62772 Mdot
.44733 .6367 Mdot
.44021 .6382 Mdot
.61327 .44973 Mdot
.56611 .65487 Mdot
.82129 .5072 Mdot
.39601 .47725 Mdot
.42219 .61693 Mdot
.47288 .65407 Mdot
.41729 .41056 Mdot
.53491 .8014 Mdot
.55929 .44499 Mdot
.38523 .49981 Mdot
.46155 .67494 Mdot
.47677 .34642 Mdot
.60757 .63802 Mdot
.78657 .6511 Mdot
.59192 .38736 Mdot
.63074 .39471 Mdot
.35579 .51074 Mdot
.38324 .53615 Mdot
.41002 .57744 Mdot
.59037 .78994 Mdot
.74101 .32993 Mdot
.27516 .4891 Mdot
.50529 .36754 Mdot
.42276 .4078 Mdot
.38575 .35696 Mdot
.27506 .55512 Mdot
.34557 .48076 Mdot
.60585 .39231 Mdot
.38916 .3429 Mdot
.38797 .71057 Mdot
.3549 .30147 Mdot
.7236 .60742 Mdot
.6762 .70238 Mdot
.65263 .40269 Mdot
.41293 .33464 Mdot
.43983 .35723 Mdot
.37899 .36115 Mdot
.31663 .67445 Mdot
.6029 .43971 Mdot
.64182 .40333 Mdot
.58732 .40018 Mdot
.69996 .46517 Mdot
.58457 .42559 Mdot
.32542 .45927 Mdot
.50689 .53069 Mdot
.44934 .28738 Mdot
.64378 .36529 Mdot
.39017 .50054 Mdot
.65305 .38825 Mdot
.59208 .62901 Mdot
.65198 .44406 Mdot
.72704 .60944 Mdot
.34804 .5036 Mdot
.45704 .40948 Mdot
.2953 .46697 Mdot
.63089 .38383 Mdot
.61353 .66887 Mdot
.43917 .4328 Mdot
.193 .59284 Mdot
.58987 .60372 Mdot
.43377 .35903 Mdot
.45497 .63178 Mdot
.33357 .51402 Mdot
.48291 .63504 Mdot
.58569 .37135 Mdot
.28231 .5596 Mdot
.22404 .4734 Mdot
.51259 .49953 Mdot
.58044 .4384 Mdot
.6434 .49082 Mdot
.42997 .36006 Mdot
.43649 .62955 Mdot
.38247 .29915 Mdot
.60708 .39595 Mdot
.60801 .65461 Mdot
.60774 .62945 Mdot
.41148 .48285 Mdot
.18787 .4401 Mdot
.35275 .43571 Mdot
.35633 .51401 Mdot
.45819 .66543 Mdot
.61766 .61378 Mdot
.32409 .30311 Mdot
.34789 .56007 Mdot
.34065 .49791 Mdot
.36254 .49343 Mdot
.67191 .42513 Mdot
.44383 .67015 Mdot
.44613 .2805 Mdot
.48737 .67567 Mdot
.64634 .40878 Mdot
.47515 .67014 Mdot
.43845 .65463 Mdot
.59945 .62826 Mdot
.37614 .49685 Mdot
.49218 .66646 Mdot
.62546 .46446 Mdot
.42141 .3898 Mdot
.48416 .42879 Mdot
.7602 .57061 Mdot
.34671 .26141 Mdot
.38376 .26767 Mdot
.4337 .38956 Mdot
.15373 .50703 Mdot
.36386 .47888 Mdot
.70441 .4699 Mdot
.35258 .71482 Mdot
.65916 .45429 Mdot
.79439 .66972 Mdot
.46221 .61073 Mdot
.43014 .64643 Mdot
.61944 .45731 Mdot
.42985 .71915 Mdot
.60671 .42394 Mdot
.48782 .66625 Mdot
.5286 .68413 Mdot
.69234 .39223 Mdot
.46371 .62199 Mdot
.65151 .36638 Mdot
.64299 .42696 Mdot
.41863 .34188 Mdot
.44041 .61196 Mdot
.60735 .47474 Mdot
.26641 .26822 Mdot
.38341 .53028 Mdot
.32085 .66534 Mdot
.76789 .4755 Mdot
.37149 .52446 Mdot
.41503 .38373 Mdot
.57982 .47841 Mdot
.61163 .62218 Mdot
.39499 .35778 Mdot
.77112 .58999 Mdot
.63689 .65297 Mdot
.78119 .68209 Mdot
.43386 .35128 Mdot
.42547 .61699 Mdot
.59422 .63791 Mdot
.67926 .39135 Mdot
.42524 .64867 Mdot
.41837 .44948 Mdot
.44704 .63416 Mdot
.5933 .43928 Mdot
.27532 .58625 Mdot
.38576 .50895 Mdot
.63176 .41419 Mdot
.42652 .63605 Mdot
.28742 .61941 Mdot
.67119 .42488 Mdot
.6293 .44873 Mdot
.47976 .80861 Mdot
.7416 .69978 Mdot
.62223 .63242 Mdot
.37613 .34895 Mdot
.61574 .46505 Mdot
.59976 .65733 Mdot
.54704 .74415 Mdot
.66118 .39473 Mdot
.39093 .39437 Mdot
.61368 .50835 Mdot
.43549 .61796 Mdot
.37701 .52628 Mdot
.50598 .49395 Mdot
.59957 .65872 Mdot
.76899 .27869 Mdot
.47283 .68014 Mdot
.63307 .47208 Mdot
.58015 .44228 Mdot
.39741 .75781 Mdot
.43871 .34604 Mdot
.74734 .35365 Mdot
.59591 .41501 Mdot
.70568 .45464 Mdot
.62034 .4138 Mdot
.52121 .67426 Mdot
.4238 .35611 Mdot
.59619 .43183 Mdot
.2699 .36798 Mdot
.67981 .44005 Mdot
.60447 .66426 Mdot
.47193 .1879 Mdot
.6623 .38829 Mdot
.56465 .87595 Mdot
.64039 .73092 Mdot
.46584 .6218 Mdot
.2722 .5616 Mdot
.45267 .12981 Mdot
.30882 .46062 Mdot
.40922 .32388 Mdot
.20399 .50797 Mdot
.48775 .64183 Mdot
.25827 .57033 Mdot
.15014 .50775 Mdot
.64495 .42879 Mdot
.6496 .38686 Mdot
.60464 .58929 Mdot
.50928 .65262 Mdot
.4421 .6816 Mdot
.60648 .36429 Mdot
.55344 .46513 Mdot
.49198 .63987 Mdot
.61416 .46792 Mdot
.60869 .35966 Mdot
.3435 .54593 Mdot
.42915 .39196 Mdot
.35603 .53993 Mdot
.36581 .48881 Mdot
.56106 .1983 Mdot
.56853 .78881 Mdot
.3807 .5334 Mdot
.374 .48598 Mdot
.73213 .58649 Mdot
.68379 .62967 Mdot
.63079 .61813 Mdot
.20521 .37562 Mdot
.47341 .6497 Mdot
.60589 .43805 Mdot
.44227 .37814 Mdot
.7137 .31498 Mdot
.60465 .72631 Mdot
.82653 .51294 Mdot
.6058 .39433 Mdot
.48016 .65275 Mdot
.31564 .67401 Mdot
.54676 .40718 Mdot
.41804 .67193 Mdot
.62905 .39102 Mdot
.44811 .68246 Mdot
.56179 .26822 Mdot
.26505 .35016 Mdot
.43434 .67422 Mdot
.45785 .34672 Mdot
.62455 .39865 Mdot
.43611 .3574 Mdot
.35298 .53114 Mdot
.59742 .62387 Mdot
.62265 .63645 Mdot
.62688 .44243 Mdot
.6903 .46162 Mdot
.51639 .76838 Mdot
.64269 .42216 Mdot
.65725 .43726 Mdot
.31701 .67853 Mdot
.65386 .43877 Mdot
.57828 .4297 Mdot
.57862 .41695 Mdot
.64817 .47231 Mdot
.38981 .52044 Mdot
.25343 .37128 Mdot
.5599 .39533 Mdot
.56748 .37902 Mdot
.37314 .55966 Mdot
.1992 .568 Mdot
.35945 .48416 Mdot
.1631 .56303 Mdot
.35364 .54247 Mdot
.62411 .64596 Mdot
.31918 .71589 Mdot
.67127 .47707 Mdot
.39446 .38794 Mdot
.33208 .53687 Mdot
.60662 .6577 Mdot
.35743 .52477 Mdot
.48845 .66203 Mdot
.37393 .79043 Mdot
.45516 .32972 Mdot
.75233 .42378 Mdot
.39173 .45407 Mdot
.33435 .59064 Mdot
.49204 .66874 Mdot
.42593 .35096 Mdot
.61389 .28685 Mdot
.5757 .4264 Mdot
.59911 .65558 Mdot
.61364 .44555 Mdot
.38817 .50909 Mdot
.48174 .64764 Mdot
.47184 .18185 Mdot
.61297 .62085 Mdot
.52809 .82188 Mdot
.46227 .65055 Mdot
.57915 .40715 Mdot
.38659 .50232 Mdot
.58067 .82222 Mdot
.36096 .54176 Mdot
.64564 .3262 Mdot
.44545 .39063 Mdot
.60908 .20316 Mdot
.39862 .36698 Mdot
.39895 .63839 Mdot
.41362 .83835 Mdot
.26462 .31724 Mdot
.40991 .39237 Mdot
.37374 .58882 Mdot
.65752 .40335 Mdot
.65948 .39968 Mdot
.33241 .29007 Mdot
.37576 .35238 Mdot
.58916 .45518 Mdot
.32207 .68713 Mdot
.25882 .42722 Mdot
.67947 .72601 Mdot
.44207 .6315 Mdot
.60303 .42135 Mdot
.38216 .56055 Mdot
.34134 .53541 Mdot
.47505 .6808 Mdot
.35245 .48315 Mdot
.64123 .40556 Mdot
.39791 .36265 Mdot
.47078 .69222 Mdot
.61601 .6467 Mdot
.32476 .23644 Mdot
.60556 .60878 Mdot
.4476 .63743 Mdot
.69286 .41103 Mdot
.48824 .63893 Mdot
.49372 .10526 Mdot
.63824 .40134 Mdot
.43223 .37488 Mdot
.63641 .45334 Mdot
.62472 .40213 Mdot
.65022 .38648 Mdot
.49301 .65168 Mdot
.75835 .37972 Mdot
.62034 .46641 Mdot
.36812 .50694 Mdot
.46979 .31404 Mdot
.64837 .38296 Mdot
.51673 .68756 Mdot
.69773 .61585 Mdot
.39817 .59772 Mdot
.44495 .37861 Mdot
.45162 .62397 Mdot
.41715 .38783 Mdot
.38438 .29306 Mdot
.41537 .38354 Mdot
.49997 .33076 Mdot
.60172 .28241 Mdot
.77106 .39299 Mdot
.46338 .2181 Mdot
.6108 .5337 Mdot
.37598 .35034 Mdot
.65022 .60445 Mdot
.38376 .35599 Mdot
.43847 .35347 Mdot
.24898 .79322 Mdot
.38931 .37835 Mdot
.60345 .41251 Mdot
.62347 .37864 Mdot
.25102 .48776 Mdot
.72395 .55459 Mdot
.64324 .44215 Mdot
.62268 .4615 Mdot
.59945 .62419 Mdot
.71124 .42187 Mdot
.28233 .56458 Mdot
.73175 .72391 Mdot
.2434 .53842 Mdot
.61676 .44467 Mdot
.62122 .46419 Mdot
.54394 .44061 Mdot
.57869 .8449 Mdot
.6105 .22192 Mdot
.37522 .38326 Mdot
.58489 .48764 Mdot
.31363 .26728 Mdot
.63074 .38616 Mdot
.67467 .41362 Mdot
.6538 .4022 Mdot
.48752 .6423 Mdot
.4081 .40345 Mdot
.56753 .47516 Mdot
.60628 .76862 Mdot
.63929 .38703 Mdot
.29516 .62408 Mdot
.57045 .15469 Mdot
.5987 .42215 Mdot
.41708 .40324 Mdot
.66647 .41333 Mdot
.4328 .34348 Mdot
.40643 .3419 Mdot
.68708 .43314 Mdot
.50095 .3606 Mdot
.42015 .40577 Mdot
.64699 .40897 Mdot
.48711 .6551 Mdot
.19344 .38542 Mdot
.5918 .43775 Mdot
.6053 .61525 Mdot
.59736 .41125 Mdot
.61448 .67038 Mdot
.65584 .43379 Mdot
.46858 .68141 Mdot
.68653 .29947 Mdot
.47736 .63796 Mdot
.6496 .21342 Mdot
.44747 .67579 Mdot
.48941 .81105 Mdot
.38052 .38543 Mdot
.27936 .59257 Mdot
.81632 .41964 Mdot
.3122 .64974 Mdot
.47564 .55971 Mdot
.47675 .52982 Mdot
.34318 .49672 Mdot
.44318 .3486 Mdot
.69788 .49646 Mdot
.39525 .73231 Mdot
.38233 .73633 Mdot
.44239 .6627 Mdot
.82016 .38804 Mdot
.83537 .5277 Mdot
.64301 .45788 Mdot
.53716 .31923 Mdot
.48561 .2633 Mdot
.66259 .3922 Mdot
.5844 .48271 Mdot
.51854 .63419 Mdot
.58482 .45573 Mdot
.29864 .35838 Mdot
.44935 .64172 Mdot
.60495 .6573 Mdot
.43361 .36614 Mdot
.59294 .65444 Mdot
.39049 .73201 Mdot
.47379 .5313 Mdot
.48313 .67025 Mdot
.66308 .46045 Mdot
.62997 .45602 Mdot
.42319 .33975 Mdot
.37623 .31971 Mdot
.38938 .37232 Mdot
.62672 .62796 Mdot
.45411 .64275 Mdot
.66839 .2658 Mdot
.61102 .46225 Mdot
.40513 .35586 Mdot
.45187 .55519 Mdot
.6088 .46507 Mdot
.36323 .53162 Mdot
.64928 .39747 Mdot
.41859 .3927 Mdot
.65377 .43862 Mdot
.39645 .36509 Mdot
.45808 .63062 Mdot
.61191 .38355 Mdot
.61579 .456 Mdot
.55678 .82652 Mdot
.6208 .6537 Mdot
.37267 .36903 Mdot
.44346 .72916 Mdot
.57357 .43439 Mdot
.32577 .61303 Mdot
.62151 .39647 Mdot
.34991 .31535 Mdot
.6495 .46643 Mdot
.30582 .65508 Mdot
.55879 .43432 Mdot
.59238 .43692 Mdot
.42682 .50932 Mdot
.48864 .28372 Mdot
.37415 .33591 Mdot
.38934 .50487 Mdot
.3868 .3819 Mdot
.68493 .708 Mdot
.41646 .61564 Mdot
.43643 .62544 Mdot
.70792 .51627 Mdot
.63913 .47814 Mdot
.60982 .42852 Mdot
.36976 .56388 Mdot
.6298 .66001 Mdot
.41293 .35238 Mdot
.60065 .65345 Mdot
.61954 .77612 Mdot
.63596 .63853 Mdot
.489 .61988 Mdot
.53951 .76925 Mdot
.63743 .25012 Mdot
.5997 .62446 Mdot
.40614 .39266 Mdot
.64106 .70411 Mdot
.67174 .44156 Mdot
.66441 .67301 Mdot
.60653 .65211 Mdot
.81417 .35726 Mdot
.57926 .43148 Mdot
.48162 .56349 Mdot
.37671 .53436 Mdot
.59613 .63585 Mdot
.34507 .49971 Mdot
.63851 .44373 Mdot
.31815 .59165 Mdot
.39658 .33125 Mdot
.39371 .53207 Mdot
.63908 .36953 Mdot
.63213 .64309 Mdot
.45884 .67328 Mdot
.32624 .53237 Mdot
.39403 .51488 Mdot
.19201 .53579 Mdot
.51963 .16946 Mdot
.4563 .64303 Mdot
.77072 .62879 Mdot
.34801 .53945 Mdot
.66965 .39669 Mdot
.71712 .4164 Mdot
.63545 .3934 Mdot
.33898 .45021 Mdot
.44751 .62467 Mdot
.24396 .45027 Mdot
.63591 .45512 Mdot
.59134 .40121 Mdot
.37147 .34449 Mdot
.47124 .64048 Mdot
.41203 .36992 Mdot
.38395 .37475 Mdot
.45962 .63148 Mdot
.40284 .37488 Mdot
.63741 .65459 Mdot
.26734 .42861 Mdot
.36374 .55348 Mdot
.36532 .50288 Mdot
.47437 .65342 Mdot
.47274 .62275 Mdot
.4818 .63127 Mdot
.64904 .39723 Mdot
.41886 .35385 Mdot
.65555 .42076 Mdot
.65097 .3881 Mdot
.50927 .37866 Mdot
.43639 .38963 Mdot
.65976 .41219 Mdot
.41092 .68043 Mdot
.61515 .68248 Mdot
.48567 .65846 Mdot
.37986 .53194 Mdot
.25712 .61559 Mdot
.33942 .47164 Mdot
.60538 .41881 Mdot
.50177 .785 Mdot
.39886 .386 Mdot
.61009 .62567 Mdot
.63884 .62284 Mdot
.61748 .6292 Mdot
.4031 .5188 Mdot
.37564 .36029 Mdot
.7363 .72069 Mdot
.60411 .4244 Mdot
.52991 .5708 Mdot
.73461 .43604 Mdot
.50807 .77329 Mdot
.38172 .52936 Mdot
.61624 .46428 Mdot
.50269 .47981 Mdot
.63207 .28101 Mdot
.63245 .39612 Mdot
.68123 .41684 Mdot
.33376 .69377 Mdot
.58849 .50681 Mdot
.44111 .39895 Mdot
.61831 .79197 Mdot
.58735 .38629 Mdot
.45344 .31654 Mdot
.36481 .19719 Mdot
.6118 .41114 Mdot
.59701 .40129 Mdot
.59631 .4526 Mdot
.65331 .4455 Mdot
.42734 .4017 Mdot
.68998 .5454 Mdot
.36073 .47851 Mdot
.54671 .57441 Mdot
.37445 .55601 Mdot
.43262 .66402 Mdot
.25383 .3867 Mdot
.44529 .35142 Mdot
.60604 .6246 Mdot
.24611 .35243 Mdot
.67346 .76625 Mdot
.49992 .63734 Mdot
.58098 .22702 Mdot
.61286 .65393 Mdot
.67299 .39958 Mdot
.62962 .66865 Mdot
.44239 .66868 Mdot
.37227 .50447 Mdot
.63469 .48114 Mdot
.38606 .36205 Mdot
.43804 .37735 Mdot
.59112 .45759 Mdot
.29845 .28204 Mdot
.36738 .53213 Mdot
.35001 .56376 Mdot
.67079 .40722 Mdot
.67324 .38617 Mdot
.41348 .37315 Mdot
.4628 .66091 Mdot
.73539 .6478 Mdot
.62784 .65688 Mdot
.57793 .45387 Mdot
.65727 .44211 Mdot
.59693 .78924 Mdot
.37987 .51076 Mdot
.49899 .63036 Mdot
.66748 .43521 Mdot
.27652 .50991 Mdot
.66714 .4354 Mdot
.54381 .45712 Mdot
.48517 .65578 Mdot
.55761 .40808 Mdot
.63191 .46476 Mdot
.663 .34418 Mdot
.34106 .51785 Mdot
.42842 .3769 Mdot
.43467 .3179 Mdot
.57856 .5612 Mdot
.36115 .5309 Mdot
.66281 .41318 Mdot
.37899 .51754 Mdot
.65667 .39224 Mdot
.59081 .4592 Mdot
.37927 .53746 Mdot
.41137 .37018 Mdot
.20953 .51833 Mdot
.25221 .37824 Mdot
.65093 .44763 Mdot
.57364 .39784 Mdot
.70623 .54493 Mdot
.78362 .41588 Mdot
.61264 .39407 Mdot
.42689 .38866 Mdot
.61614 .46053 Mdot
.34424 .50533 Mdot
.6388 .63739 Mdot
.42002 .3909 Mdot
.45457 .65596 Mdot
.50451 .64801 Mdot
.29976 .46339 Mdot
.43723 .64514 Mdot
.6724 .43589 Mdot
.38752 .29223 Mdot
.41025 .3127 Mdot
.34914 .21605 Mdot
.4629 .6338 Mdot
.64192 .64363 Mdot
.62986 .44687 Mdot
.47833 .79472 Mdot
.3686 .56568 Mdot
.6075 .86675 Mdot
.76821 .6952 Mdot
.5953 .60842 Mdot
.82174 .47851 Mdot
.43514 .67079 Mdot
.60061 .46919 Mdot
.59659 .6239 Mdot
.49817 .63718 Mdot
.66003 .45097 Mdot
.64696 .47843 Mdot
.75048 .35785 Mdot
.55931 .55319 Mdot
.38038 .51752 Mdot
.45154 .61673 Mdot
.63256 .60762 Mdot
.50432 .63204 Mdot
.44225 .37256 Mdot
.59536 .43648 Mdot
.69214 .44838 Mdot
.45786 .65952 Mdot
.50997 .64865 Mdot
.65213 .40629 Mdot
.44223 .34617 Mdot
.50389 .62022 Mdot
.62256 .4404 Mdot
.62037 .52799 Mdot
.45641 .36288 Mdot
.4471 .64526 Mdot
.58336 .40963 Mdot
.64218 .689 Mdot
.46324 .6538 Mdot
.4843 .66045 Mdot
.59184 .45914 Mdot
.6358 .65815 Mdot
.57179 .40436 Mdot
.36045 .54759 Mdot
.73051 .2929 Mdot
.3479 .49902 Mdot
.61594 .70612 Mdot
.68841 .39941 Mdot
.30634 .55662 Mdot
.4467 .36466 Mdot
.58642 .59876 Mdot
.27314 .65969 Mdot
.61389 .36199 Mdot
.17555 .4602 Mdot
.4874 .45956 Mdot
.28952 .27337 Mdot
.26917 .70212 Mdot
.60396 .64524 Mdot
.35479 .52502 Mdot
.59786 .401 Mdot
.33114 .51617 Mdot
.59992 .61819 Mdot
.63451 .21173 Mdot
.58028 .41589 Mdot
.42485 .35763 Mdot
.64783 .40304 Mdot
.43431 .35773 Mdot
.60028 .46391 Mdot
.55022 .40257 Mdot
.31302 .68311 Mdot
.76696 .58715 Mdot
.6619 .45255 Mdot
.39713 .81127 Mdot
.6102 .74626 Mdot
.61446 .65973 Mdot
.65059 .42117 Mdot
.40777 .6199 Mdot
.33734 .52596 Mdot
.32739 .33026 Mdot
.48865 .64326 Mdot
.36756 .48614 Mdot
.41154 .37851 Mdot
.44831 .62985 Mdot
.50477 .65564 Mdot
.55716 .41752 Mdot
.60335 .6654 Mdot
.36954 .49664 Mdot
.59355 .43049 Mdot
.58056 .42036 Mdot
.7476 .65561 Mdot
.59068 .71991 Mdot
.39821 .30727 Mdot
.65337 .80482 Mdot
.42974 .31781 Mdot
.62608 .65237 Mdot
.48948 .64846 Mdot
.61616 .39599 Mdot
.63281 .41614 Mdot
.28219 .60325 Mdot
.39066 .33478 Mdot
.54052 .53618 Mdot
.53968 .20341 Mdot
.51002 .62725 Mdot
.7062 .59316 Mdot
.43569 .37252 Mdot
.70784 .59132 Mdot
.63989 .61797 Mdot
.2243 .36594 Mdot
.75135 .59892 Mdot
.37809 .53086 Mdot
.70397 .58962 Mdot
.40172 .34922 Mdot
.63894 .45784 Mdot
.42672 .6143 Mdot
.43871 .65382 Mdot
.42285 .37362 Mdot
.4997 .67639 Mdot
.59995 .62972 Mdot
.59009 .40858 Mdot
.73027 .71836 Mdot
.30866 .43314 Mdot
.46233 .66646 Mdot
.55446 .39135 Mdot
.36053 .4933 Mdot
.58648 .45423 Mdot
.60893 .61593 Mdot
.36933 .51883 Mdot
.64801 .72406 Mdot
.25221 .43849 Mdot
.63171 .44237 Mdot
.50991 .80741 Mdot
.36343 .52717 Mdot
.80254 .47116 Mdot
.61382 .44064 Mdot
.34718 .53774 Mdot
.57584 .49371 Mdot
.38858 .67234 Mdot
.50838 .48611 Mdot
.14976 .5051 Mdot
.51992 .51644 Mdot
.42195 .62903 Mdot
.3788 .64061 Mdot
.36765 .69049 Mdot
.33204 .51773 Mdot
.50987 .64545 Mdot
.5561 .64799 Mdot
.34459 .49971 Mdot
.64633 .38306 Mdot
.61838 .40166 Mdot
.61235 .21963 Mdot
.48167 .46746 Mdot
.3958 .65338 Mdot
.33944 .40737 Mdot
.57317 .43016 Mdot
.59632 .37933 Mdot
.62835 .42192 Mdot
.40639 .40824 Mdot
.37659 .5113 Mdot
.47001 .82669 Mdot
.36018 .53318 Mdot
.78103 .65289 Mdot
.47522 .64938 Mdot
.44843 .621 Mdot
.60138 .41975 Mdot
.5101 .58936 Mdot
.66322 .58149 Mdot
.6422 .40743 Mdot
.54887 .60328 Mdot
.45578 .195 Mdot
.63869 .372 Mdot
.44683 .38382 Mdot
.63075 .34901 Mdot
.4495 .40248 Mdot
.36223 .55344 Mdot
.6092 .64067 Mdot
.57917 .6034 Mdot
.37321 .50258 Mdot
.61156 .42842 Mdot
.29472 .55494 Mdot
.62687 .40617 Mdot
.6529 .45141 Mdot
.79937 .63007 Mdot
.603 .6088 Mdot
.46925 .62719 Mdot
.61996 .62839 Mdot
.43838 .34878 Mdot
.45125 .90521 Mdot
.62624 .66259 Mdot
.65534 .57857 Mdot
.6712 .23512 Mdot
.70474 .58591 Mdot
.4411 .37159 Mdot
.59016 .65721 Mdot
.37353 .52969 Mdot
.20129 .35213 Mdot
.77962 .37527 Mdot
.322 .49726 Mdot
.62359 .43595 Mdot
.43916 .3371 Mdot
.4177 .39617 Mdot
.39163 .53776 Mdot
.40612 .34361 Mdot
.59091 .49553 Mdot
.64602 .45238 Mdot
.33239 .50603 Mdot
.27094 .47254 Mdot
.39397 .51344 Mdot
.27745 .39666 Mdot
.64997 .41672 Mdot
.43279 .37871 Mdot
.64944 .35473 Mdot
.41165 .41798 Mdot
.49156 .62404 Mdot
.66363 .3877 Mdot
.60073 .62802 Mdot
.30178 .54081 Mdot
.45714 .64531 Mdot
.49156 .7802 Mdot
.42586 .34161 Mdot
.39966 .58121 Mdot
.41603 .34097 Mdot
.37845 .34281 Mdot
.36237 .487 Mdot
.39933 .33263 Mdot
.59473 .40301 Mdot
.40158 .64785 Mdot
.42553 .33406 Mdot
.35285 .50498 Mdot
.61439 .64029 Mdot
.40431 .37227 Mdot
.42743 .71786 Mdot
.62259 .45072 Mdot
.497 .64992 Mdot
.33824 .73044 Mdot
.41363 .31837 Mdot
.58341 .63876 Mdot
.43571 .62942 Mdot
.59211 .64905 Mdot
.41553 .19321 Mdot
.34094 .48313 Mdot
.82092 .53432 Mdot
.61898 .68757 Mdot
.39301 .38322 Mdot
.32089 .71491 Mdot
.61429 .39877 Mdot
.62555 .45008 Mdot
.61153 .67215 Mdot
.41714 .39622 Mdot
.24094 .33408 Mdot
.4089 .4308 Mdot
.25965 .44346 Mdot
.33064 .49859 Mdot
.45856 .81268 Mdot
.27977 .37712 Mdot
.50368 .14805 Mdot
.59842 .37238 Mdot
.44009 .67825 Mdot
.61282 .42039 Mdot
.26359 .64205 Mdot
.63105 .63905 Mdot
.4869 .70188 Mdot
.68575 .42956 Mdot
.4574 .62681 Mdot
.6034 .45132 Mdot
.42265 .48474 Mdot
.61287 .3547 Mdot
.64116 .63619 Mdot
.27958 .56574 Mdot
.38972 .38149 Mdot
.61479 .64922 Mdot
.47091 .67901 Mdot
.67957 .58909 Mdot
.65005 .46051 Mdot
.57863 .37646 Mdot
.50382 .62185 Mdot
.42517 .35296 Mdot
.43076 .61807 Mdot
.35998 .5514 Mdot
.60559 .63216 Mdot
.63687 .44887 Mdot
.65486 .46459 Mdot
.32721 .61558 Mdot
.36677 .49319 Mdot
.50258 .66991 Mdot
.35917 .53984 Mdot
.43133 .66778 Mdot
.56374 .41254 Mdot
.44612 .62131 Mdot
.6163 .47181 Mdot
.28911 .66876 Mdot
.79813 .62803 Mdot
.50459 .29839 Mdot
.4455 .62689 Mdot
.71026 .62233 Mdot
.34628 .5071 Mdot
.3528 .53976 Mdot
.66909 .25078 Mdot
.68313 .32924 Mdot
.71778 .70087 Mdot
.18755 .57141 Mdot
.37279 .55595 Mdot
.35641 .49522 Mdot
.49838 .64733 Mdot
.40617 .32853 Mdot
.39372 .32234 Mdot
.44148 .67685 Mdot
.75909 .48944 Mdot
.41277 .35247 Mdot
.19349 .40934 Mdot
.69038 .71301 Mdot
.56424 .4689 Mdot
.42968 .57355 Mdot
.6104 .63234 Mdot
.75283 .5139 Mdot
.42127 .48728 Mdot
.59612 .39813 Mdot
.58373 .79079 Mdot
.46881 .65954 Mdot
.70012 .5114 Mdot
.1645 .56377 Mdot
.57851 .42082 Mdot
.60724 .43918 Mdot
.61853 .42466 Mdot
.58756 .61315 Mdot
.70188 .32896 Mdot
.58344 .4144 Mdot
.76165 .48427 Mdot
.57442 .44026 Mdot
.52121 .4162 Mdot
.62228 .63383 Mdot
.5264 .44979 Mdot
.32461 .69599 Mdot
.64157 .76495 Mdot
.67978 .36228 Mdot
.3579 .54931 Mdot
.56541 .58959 Mdot
.34095 .52219 Mdot
.49914 .32242 Mdot
.75212 .59377 Mdot
.44983 .33319 Mdot
.59801 .39805 Mdot
.44734 .63814 Mdot
.42015 .39573 Mdot
.36496 .64179 Mdot
.35186 .87529 Mdot
.35074 .5456 Mdot
.55248 .12834 Mdot
.3577 .5432 Mdot
.50087 .66295 Mdot
.41455 .37423 Mdot
.59463 .27927 Mdot
.52921 .56679 Mdot
.40207 .37175 Mdot
.22136 .48515 Mdot
.36642 .3645 Mdot
.70387 .60967 Mdot
.43311 .32388 Mdot
.35017 .50577 Mdot
.39926 .50677 Mdot
.63622 .48751 Mdot
.60541 .40665 Mdot
.47047 .52506 Mdot
.67898 .60854 Mdot
.60993 .4016 Mdot
.45141 .64153 Mdot
.80564 .44317 Mdot
.6048 .57117 Mdot
.39507 .34171 Mdot
.36909 .47749 Mdot
.60525 .44173 Mdot
.66388 .43783 Mdot
.64931 .45878 Mdot
.67109 .80369 Mdot
.22666 .35692 Mdot
.62009 .46626 Mdot
.57052 .43019 Mdot
.45104 .62895 Mdot
.64927 .65464 Mdot
.25358 .63679 Mdot
.55457 .36236 Mdot
.61105 .38657 Mdot
.6204 .64744 Mdot
.60341 .60717 Mdot
.66176 .44942 Mdot
.60342 .7666 Mdot
.31944 .57418 Mdot
.59318 .43107 Mdot
.67235 .32991 Mdot
.38332 .7139 Mdot
.50905 .6516 Mdot
.4579 .65706 Mdot
.41173 .40105 Mdot
.43992 .64478 Mdot
.45131 .67909 Mdot
.60504 .26628 Mdot
.52161 .52725 Mdot
.40214 .54242 Mdot
.6261 .6268 Mdot
.63201 .4128 Mdot
.3998 .30931 Mdot
.27781 .52359 Mdot
.3492 .49081 Mdot
.3991 .38212 Mdot
.33992 .53009 Mdot
.57726 .63105 Mdot
.74751 .43212 Mdot
.44198 .66466 Mdot
.38369 .54625 Mdot
.25309 .43701 Mdot
.62158 .64439 Mdot
.37435 .49365 Mdot
.29933 .56637 Mdot
.64395 .37974 Mdot
.56165 .3241 Mdot
.64388 .41123 Mdot
.2663 .29857 Mdot
.37854 .49919 Mdot
.3006 .64768 Mdot
.60427 .43149 Mdot
.46401 .65129 Mdot
.55365 .47548 Mdot
.62763 .38989 Mdot
.45098 .65822 Mdot
.64189 .45815 Mdot
.59238 .62102 Mdot
.45837 .36117 Mdot
.55342 .57126 Mdot
.86924 .51272 Mdot
.60206 .66498 Mdot
.35864 .63269 Mdot
.61024 .39376 Mdot
.4776 .17626 Mdot
.40364 .37019 Mdot
.62969 .47126 Mdot
.63894 .55687 Mdot
.42205 .32788 Mdot
.4087 .38711 Mdot
.66503 .42417 Mdot
.37404 .53557 Mdot
.4544 .64678 Mdot
.622 .63833 Mdot
.41748 .18453 Mdot
.63252 .43242 Mdot
.61611 .45807 Mdot
.61323 .6523 Mdot
.35203 .49603 Mdot
.66917 .4274 Mdot
.3521 .74858 Mdot
.2738 .26787 Mdot
.34349 .49301 Mdot
.63509 .38204 Mdot
.556 .33997 Mdot
.46115 .39296 Mdot
.70094 .23039 Mdot
.65817 .69768 Mdot
.46141 .6235 Mdot
.58951 .50406 Mdot
.49684 .89278 Mdot
.61081 .63962 Mdot
.68837 .74541 Mdot
.65971 .44676 Mdot
.60272 .46078 Mdot
.3914 .37517 Mdot
.65749 .41622 Mdot
.41424 .32164 Mdot
.86058 .49019 Mdot
.58872 .79618 Mdot
.43017 .35173 Mdot
.38517 .36657 Mdot
.63924 .56681 Mdot
.25544 .6372 Mdot
.42214 .37585 Mdot
.56651 .42961 Mdot
.38809 .27691 Mdot
.62546 .33814 Mdot
.61839 .6734 Mdot
.36409 .72646 Mdot
.45104 .41146 Mdot
.64298 .60355 Mdot
.19801 .53139 Mdot
.4605 .40444 Mdot
.34206 .58044 Mdot
.36643 .5506 Mdot
.57857 .41317 Mdot
.43769 .65026 Mdot
.43846 .62441 Mdot
.63676 .35468 Mdot
.63213 .40613 Mdot
.43422 .34568 Mdot
.62627 .62357 Mdot
.33421 .52522 Mdot
.62279 .46106 Mdot
.60892 .5746 Mdot
.6254 .6615 Mdot
.40681 .33438 Mdot
.7336 .35498 Mdot
.64204 .63664 Mdot
.57603 .36732 Mdot
.59173 .42082 Mdot
.65276 .40276 Mdot
.6506 .33663 Mdot
.38528 .52953 Mdot
.31207 .70456 Mdot
.60095 .38328 Mdot
.61978 .77685 Mdot
.48403 .4171 Mdot
.54905 .42879 Mdot
.41407 .34675 Mdot
.37076 .56603 Mdot
.44256 .60723 Mdot
.66889 .52657 Mdot
.63357 .43853 Mdot
.25375 .33703 Mdot
.57795 .20628 Mdot
.47374 .6147 Mdot
.37727 .34849 Mdot
.61267 .62677 Mdot
.64057 .40724 Mdot
.48638 .3359 Mdot
.61369 .40644 Mdot
.58697 .66757 Mdot
.47857 .66182 Mdot
.36725 .54975 Mdot
.28631 .27174 Mdot
.43913 .6239 Mdot
.41517 .38808 Mdot
.129 .56615 Mdot
.43521 .32862 Mdot
.3806 .35914 Mdot
.49349 .35564 Mdot
.38284 .53819 Mdot
.52426 .89622 Mdot
.76838 .33039 Mdot
.67957 .39513 Mdot
.34448 .51403 Mdot
.42476 .36813 Mdot
.58487 .45005 Mdot
.4501 .35823 Mdot
.37435 .36139 Mdot
.56705 .4022 Mdot
.58808 .44541 Mdot
.25885 .38189 Mdot
.15356 .52176 Mdot
.61391 .62515 Mdot
.44147 .35666 Mdot
.64742 .52105 Mdot
.5822 .44569 Mdot
.60348 .42497 Mdot
.38067 .69483 Mdot
.63813 .65415 Mdot
.3134 .35148 Mdot
.66209 .44276 Mdot
.55942 .80521 Mdot
.63351 .34929 Mdot
.43093 .40106 Mdot
.34713 .48955 Mdot
.64498 .75842 Mdot
.38379 .46013 Mdot
.39588 .32983 Mdot
.6174 .61843 Mdot
.43036 .315 Mdot
.65604 .58127 Mdot
.39146 .52406 Mdot
.41856 .39273 Mdot
.50543 .49167 Mdot
.36373 .51395 Mdot
.38215 .50713 Mdot
.4689 .31418 Mdot
.47986 .68488 Mdot
.58795 .61627 Mdot
.36641 .49552 Mdot
.69669 .47874 Mdot
.3514 .51446 Mdot
.69367 .28047 Mdot
.61345 .38292 Mdot
.7344 .49053 Mdot
.47187 .57127 Mdot
.65899 .48388 Mdot
.38704 .51138 Mdot
.60395 .61803 Mdot
.66751 .4251 Mdot
.40164 .34617 Mdot
.60849 .66138 Mdot
.32274 .52985 Mdot
.49201 .64177 Mdot
.41527 .33882 Mdot
.33472 .4853 Mdot
.43859 .36676 Mdot
.6945 .50133 Mdot
.70918 .26167 Mdot
.39377 .77436 Mdot
.52975 .56179 Mdot
.65082 .45715 Mdot
.21224 .59681 Mdot
.55784 .4524 Mdot
.63266 .40126 Mdot
.44839 .64472 Mdot
.70946 .51185 Mdot
.41223 .37043 Mdot
.27286 .27839 Mdot
.3767 .55095 Mdot
.61578 .79369 Mdot
.3639 .31069 Mdot
.63736 .46949 Mdot
.42698 .33413 Mdot
.43599 .32818 Mdot
.48012 .27813 Mdot
.46247 .60773 Mdot
.59616 .48436 Mdot
.59431 .48579 Mdot
.57482 .3826 Mdot
.38255 .51236 Mdot
.50118 .78212 Mdot
.42306 .63844 Mdot
.69191 .23575 Mdot
.4718 .6646 Mdot
.5499 .59953 Mdot
.39972 .33393 Mdot
.62791 .66286 Mdot
.60145 .42567 Mdot
.36963 .32823 Mdot
.39388 .3305 Mdot
.60075 .67511 Mdot
.59506 .6366 Mdot
.39079 .68975 Mdot
.38016 .5363 Mdot
.66359 .45249 Mdot
.58396 .40942 Mdot
.65531 .42447 Mdot
.64423 .39694 Mdot
.35373 .54876 Mdot
.66436 .40266 Mdot
.38991 .55322 Mdot
.72829 .4278 Mdot
.57026 .79408 Mdot
.51453 .51797 Mdot
.34497 .33631 Mdot
.39707 .34488 Mdot
.65747 .50869 Mdot
.56175 .37707 Mdot
.80817 .60287 Mdot
.39106 .23684 Mdot
.64647 .37487 Mdot
.49486 .63342 Mdot
.69066 .33749 Mdot
.43617 .65738 Mdot
.6223 .15014 Mdot
.32414 .62043 Mdot
.15801 .49192 Mdot
.58164 .42547 Mdot
.38369 .70379 Mdot
.69403 .47079 Mdot
.56851 .46672 Mdot
.3543 .65163 Mdot
.34202 .44611 Mdot
.23901 .48732 Mdot
.62634 .61722 Mdot
.62013 .44726 Mdot
.38935 .31611 Mdot
.59165 .40559 Mdot
.60797 .42161 Mdot
.6643 .44228 Mdot
.37701 .48977 Mdot
.60117 .48366 Mdot
.64702 .39229 Mdot
.51543 .76407 Mdot
.7267 .59367 Mdot
.44686 .61648 Mdot
.6554 .238 Mdot
.62164 .66354 Mdot
.42937 .34024 Mdot
.20976 .43914 Mdot
.37869 .53021 Mdot
.48026 .26972 Mdot
.64823 .39902 Mdot
.25111 .40852 Mdot
.32763 .49901 Mdot
.60336 .63073 Mdot
.4209 .62322 Mdot
.16787 .44616 Mdot
.45247 .63674 Mdot
.5011 .48053 Mdot
.46389 .6475 Mdot
.61081 .34713 Mdot
.43489 .34678 Mdot
.66835 .43854 Mdot
.36735 .49774 Mdot
.44589 .65113 Mdot
.71694 .54649 Mdot
.62653 .42182 Mdot
.46067 .63109 Mdot
.66868 .43753 Mdot
.74932 .43628 Mdot
.78183 .60237 Mdot
.45956 .68147 Mdot
.39552 .55084 Mdot
.36102 .50831 Mdot
.63637 .65612 Mdot
.41965 .33544 Mdot
.38972 .36758 Mdot
.36738 .51926 Mdot
.78857 .39682 Mdot
.61571 .38688 Mdot
.58271 .44383 Mdot
.62497 .77793 Mdot
.60402 .39984 Mdot
.69154 .60464 Mdot
.50465 .48315 Mdot
.40148 .33871 Mdot
.60062 .46786 Mdot
.66144 .43977 Mdot
.63036 .44469 Mdot
.72035 .47178 Mdot
.46105 .66281 Mdot
.58792 .39629 Mdot
.59324 .63866 Mdot
.40231 .63169 Mdot
.58537 .45342 Mdot
.56994 .38617 Mdot
.39065 .36984 Mdot
.67775 .78 Mdot
.3637 .54505 Mdot
.48384 .67374 Mdot
.4487 .62275 Mdot
.36729 .72597 Mdot
.48315 .39634 Mdot
.50789 .49146 Mdot
.66249 .21261 Mdot
.31843 .68389 Mdot
.6163 .65738 Mdot
.41413 .58324 Mdot
.49458 .41969 Mdot
.50127 .65204 Mdot
.34662 .54323 Mdot
.61211 .38194 Mdot
.61153 .38577 Mdot
.79074 .66865 Mdot
.64718 .46616 Mdot
.61341 .63045 Mdot
.38729 .55224 Mdot
.40187 .35019 Mdot
.60413 .62926 Mdot
.35337 .53819 Mdot
.42411 .35107 Mdot
.62897 .37445 Mdot
.6188 .37654 Mdot
.39912 .3807 Mdot
.41115 .39503 Mdot
.59376 .42514 Mdot
.53712 .64271 Mdot
.39413 .38917 Mdot
.4334 .38069 Mdot
.44203 .66545 Mdot
.44019 .65446 Mdot
.55535 .42088 Mdot
.34663 .52038 Mdot
.65258 .39364 Mdot
.44799 .63276 Mdot
.6351 .63503 Mdot
.40796 .36676 Mdot
.65274 .44723 Mdot
.62918 .45931 Mdot
.62081 .64358 Mdot
.62515 .61874 Mdot
.59784 .63323 Mdot
.39735 .52729 Mdot
.64842 .42768 Mdot
.41687 .37905 Mdot
.3775 .54203 Mdot
.60219 .60692 Mdot
.63615 .66318 Mdot
.51697 .65608 Mdot
.61696 .39426 Mdot
.40402 .61613 Mdot
.43518 .89273 Mdot
.67091 .68513 Mdot
.46386 .61015 Mdot
.5164 .64352 Mdot
.71547 .57354 Mdot
.52687 .59043 Mdot
.36821 .5281 Mdot
.5717 .66188 Mdot
.58388 .59999 Mdot
.66409 .38935 Mdot
.58442 .38928 Mdot
.59499 .48862 Mdot
.59865 .64197 Mdot
.673 .53437 Mdot
.44857 .35831 Mdot
.50001 .20279 Mdot
.61641 .66346 Mdot
.51021 .64985 Mdot
.48603 .68315 Mdot
.47324 .66444 Mdot
.61306 .38002 Mdot
.50539 .29282 Mdot
.56618 .51327 Mdot
.21097 .60754 Mdot
.38187 .5013 Mdot
.4291 .31145 Mdot
.44632 .1917 Mdot
.40319 .38373 Mdot
.43644 .667 Mdot
.60456 .65614 Mdot
.42283 .39265 Mdot
.33749 .51343 Mdot
.35986 .49555 Mdot
.46476 .66545 Mdot
.47666 .65229 Mdot
.48953 .6625 Mdot
.37775 .35854 Mdot
.40059 .33227 Mdot
.63666 .43461 Mdot
.40166 .36054 Mdot
.75404 .71873 Mdot
.57998 .62268 Mdot
.51756 .64114 Mdot
.35445 .52697 Mdot
.43408 .35544 Mdot
.63031 .42053 Mdot
.58048 .56837 Mdot
.32887 .44042 Mdot
.58985 .64315 Mdot
.76058 .63674 Mdot
.62048 .15179 Mdot
.66151 .45621 Mdot
.38097 .51337 Mdot
.7291 .7166 Mdot
.62066 .42579 Mdot
.48682 .65012 Mdot
.29009 .68087 Mdot
.4158 .61607 Mdot
.65073 .38847 Mdot
.67804 .43484 Mdot
.35118 .48374 Mdot
.64016 .20861 Mdot
.63729 .4302 Mdot
.31475 .37144 Mdot
.36094 .47354 Mdot
.42481 .64394 Mdot
.25452 .27961 Mdot
.39424 .75423 Mdot
.75375 .50452 Mdot
.44397 .66761 Mdot
.62425 .40128 Mdot
.44477 .66469 Mdot
.59042 .63419 Mdot
.46426 .67619 Mdot
.44828 .3844 Mdot
.43722 .61716 Mdot
.61453 .45823 Mdot
.42449 .37524 Mdot
.36337 .52813 Mdot
.6348 .79035 Mdot
.57867 .74971 Mdot
.46515 .65182 Mdot
.47559 .67989 Mdot
.624 .46703 Mdot
.2965 .35174 Mdot
.64986 .36343 Mdot
.58043 .43261 Mdot
.38036 .55129 Mdot
.42227 .33153 Mdot
.36539 .48106 Mdot
.60009 .47535 Mdot
.34061 .74558 Mdot
.36349 .54069 Mdot
.24674 .40495 Mdot
.61336 .65472 Mdot
.43528 .4741 Mdot
.63426 .41362 Mdot
.35455 .49063 Mdot
.64829 .42647 Mdot
.44962 .363 Mdot
.46927 .47609 Mdot
.27181 .55639 Mdot
.36897 .50107 Mdot
.26487 .31167 Mdot
.53814 .62464 Mdot
.69345 .40194 Mdot
.34527 .53393 Mdot
.63567 .55643 Mdot
.50447 .65709 Mdot
.62563 .6577 Mdot
.61203 .60945 Mdot
.59596 .65639 Mdot
.63302 .36261 Mdot
.68437 .37258 Mdot
.59584 .61377 Mdot
.33628 .50748 Mdot
.63904 .62933 Mdot
.4624 .32803 Mdot
.24411 .33047 Mdot
.62988 .63895 Mdot
.6177 .44002 Mdot
.69526 .36879 Mdot
.72861 .58537 Mdot
.39861 .67757 Mdot
.16626 .48126 Mdot
.33632 .32773 Mdot
.60684 .40712 Mdot
.46305 .35416 Mdot
.4436 .37382 Mdot
.71261 .72383 Mdot
.68741 .62681 Mdot
.62652 .7598 Mdot
.38362 .36525 Mdot
.27784 .58946 Mdot
.40971 .33477 Mdot
.64578 .46491 Mdot
.5855 .44829 Mdot
.38951 .32802 Mdot
.52561 .79306 Mdot
.33264 .60553 Mdot
.32883 .23704 Mdot
.43759 .37523 Mdot
.34051 .51583 Mdot
.37804 .5572 Mdot
.38491 .51094 Mdot
.69697 .70732 Mdot
.42412 .32402 Mdot
.64908 .4344 Mdot
.44468 .62916 Mdot
.59595 .39183 Mdot
.37001 .51247 Mdot
.27083 .28081 Mdot
.392 .35902 Mdot
.59253 .43552 Mdot
.78148 .42105 Mdot
.48349 .64368 Mdot
.62168 .64942 Mdot
.75254 .39864 Mdot
.65118 .72654 Mdot
.38802 .5295 Mdot
.41693 .31757 Mdot
.29911 .63366 Mdot
.24105 .39912 Mdot
.60089 .37446 Mdot
.55248 .45135 Mdot
.46495 .15889 Mdot
.64965 .72178 Mdot
.67652 .41874 Mdot
.49547 .66629 Mdot
.28333 .6076 Mdot
.63796 .45269 Mdot
.44389 .36562 Mdot
.62734 .6138 Mdot
.59672 .65351 Mdot
.56566 .44691 Mdot
.53044 .57292 Mdot
.43835 .44846 Mdot
.66276 .4118 Mdot
.5742 .36826 Mdot
.43198 .65644 Mdot
.3208 .68562 Mdot
.61469 .78285 Mdot
.61817 .61775 Mdot
.66942 .43306 Mdot
.22121 .52784 Mdot
.38317 .34396 Mdot
.45106 .61176 Mdot
.39251 .51823 Mdot
.73806 .42772 Mdot
.42401 .64339 Mdot
.63981 .45278 Mdot
.66792 .43051 Mdot
.37086 .49018 Mdot
.43149 .40092 Mdot
.59934 .64514 Mdot
.44363 .62666 Mdot
.61475 .61577 Mdot
.42293 .3266 Mdot
.3954 .35529 Mdot
.60424 .34127 Mdot
.68639 .44659 Mdot
.45633 .65573 Mdot
.58714 .46336 Mdot
.44423 .72789 Mdot
.63019 .19743 Mdot
.33253 .53804 Mdot
.66332 .45498 Mdot
.41373 .4089 Mdot
.37237 .50343 Mdot
.59385 .45414 Mdot
.4293 .17363 Mdot
.58008 .44469 Mdot
.36901 .45071 Mdot
.38618 .77756 Mdot
.60276 .62145 Mdot
.47788 .20576 Mdot
.31894 .2989 Mdot
.5994 .40349 Mdot
.47777 .62439 Mdot
.54384 .42396 Mdot
.37239 .53404 Mdot
.3959 .33937 Mdot
.7017 .22765 Mdot
.35281 .51021 Mdot
.58584 .4155 Mdot
.60493 .63145 Mdot
.42739 .32187 Mdot
.5524 .61923 Mdot
.59829 .77123 Mdot
.67313 .37177 Mdot
.56805 .44036 Mdot
.6556 .39893 Mdot
.28644 .70666 Mdot
.48343 .67345 Mdot
.43036 .36352 Mdot
.38234 .51477 Mdot
.36933 .52093 Mdot
.46602 .66323 Mdot
.25247 .47233 Mdot
.43712 .47293 Mdot
.44216 .88015 Mdot
.44953 .65978 Mdot
.58549 .64881 Mdot
.30673 .35735 Mdot
.47451 .62173 Mdot
.46557 .63312 Mdot
.4314 .65429 Mdot
.3989 .48469 Mdot
.4213 .35223 Mdot
.63178 .45949 Mdot
.44525 .37827 Mdot
.62639 .39819 Mdot
.4796 .41512 Mdot
.37097 .49945 Mdot
.39114 .34342 Mdot
.43968 .17317 Mdot
.64945 .31103 Mdot
.61715 .43204 Mdot
.46276 .18307 Mdot
.68771 .41448 Mdot
.69113 .57513 Mdot
.67621 .4539 Mdot
.47064 .65049 Mdot
.64157 .50547 Mdot
.59758 .36463 Mdot
.67702 .76825 Mdot
.35372 .5281 Mdot
.50742 .64745 Mdot
.67486 .39581 Mdot
.61326 .34954 Mdot
.38302 .33381 Mdot
.42691 .38938 Mdot
.601 .61208 Mdot
.77093 .5824 Mdot
.36307 .53039 Mdot
.73627 .30946 Mdot
.60155 .40969 Mdot
.45334 .78976 Mdot
.46942 .2178 Mdot
.59354 .45251 Mdot
.32957 .28168 Mdot
.49629 .28401 Mdot
.63864 .40899 Mdot
.58974 .54099 Mdot
.3512 .49791 Mdot
.35108 .75403 Mdot
.57008 .43493 Mdot
.48792 .6449 Mdot
.40833 .32981 Mdot
.44684 .35312 Mdot
.59494 .61614 Mdot
.83412 .55507 Mdot
.36796 .48339 Mdot
.39324 .34046 Mdot
.62357 .41927 Mdot
.38537 .53428 Mdot
.43779 .6406 Mdot
.62867 .47518 Mdot
.69319 .63316 Mdot
.40268 .35709 Mdot
.57334 .44514 Mdot
.31005 .40468 Mdot
.75473 .54594 Mdot
.21872 .67408 Mdot
.38463 .51846 Mdot
.63871 .64256 Mdot
.54423 .43079 Mdot
.75714 .36475 Mdot
.6421 .37146 Mdot
.73069 .49074 Mdot
.48144 .37275 Mdot
.63926 .64167 Mdot
.60742 .4346 Mdot
.64027 .44503 Mdot
.48265 .57063 Mdot
.62589 .62158 Mdot
.58147 .41157 Mdot
.71809 .38728 Mdot
.42487 .35459 Mdot
.41898 .63518 Mdot
.40732 .35316 Mdot
.62268 .43612 Mdot
.67509 .46218 Mdot
.39665 .38471 Mdot
.58972 .16184 Mdot
.6058 .6016 Mdot
.36681 .54439 Mdot
.69452 .41752 Mdot
.59043 .38856 Mdot
.40277 .82198 Mdot
.49522 .6272 Mdot
.24 .60055 Mdot
.49635 .74402 Mdot
.20956 .5375 Mdot
.39678 .75451 Mdot
.13664 .53631 Mdot
.59169 .79026 Mdot
.58791 .48109 Mdot
.37349 .415 Mdot
.56366 .5167 Mdot
.38783 .50998 Mdot
.64185 .25883 Mdot
.60604 .40613 Mdot
.61025 .42049 Mdot
.4533 .61087 Mdot
.24206 .44704 Mdot
.62099 .76737 Mdot
.55033 .58401 Mdot
.60119 .64683 Mdot
.43965 .3545 Mdot
.60508 .46549 Mdot
.55359 .53572 Mdot
.44979 .61554 Mdot
.46347 .79096 Mdot
.59633 .43712 Mdot
.80419 .60401 Mdot
.3139 .46637 Mdot
.38374 .53184 Mdot
.45526 .62015 Mdot
.64278 .73703 Mdot
.62066 .39252 Mdot
.39385 .52381 Mdot
.6357 .42612 Mdot
.49886 .60226 Mdot
.59899 .47269 Mdot
.63192 .64639 Mdot
.65761 .45099 Mdot
.55762 .59081 Mdot
.16593 .62038 Mdot
.56867 .65005 Mdot
.44173 .3415 Mdot
.49025 .61626 Mdot
.46015 .66126 Mdot
.41684 .39407 Mdot
.46032 .65851 Mdot
.47793 .24514 Mdot
.57517 .27017 Mdot
.60553 .65313 Mdot
.59424 .35821 Mdot
.62664 .63313 Mdot
.48825 .62142 Mdot
.6145 .40071 Mdot
.62572 .18121 Mdot
.45049 .65175 Mdot
.40786 .80338 Mdot
.35343 .51846 Mdot
.5038 .63622 Mdot
.57381 .44001 Mdot
.3063 .63631 Mdot
.44089 .62057 Mdot
.27401 .55644 Mdot
.63134 .44343 Mdot
.3971 .35076 Mdot
.64244 .44703 Mdot
.6919 .41483 Mdot
.44903 .68693 Mdot
.64216 .3896 Mdot
.35321 .53795 Mdot
.38642 .38138 Mdot
.19638 .38149 Mdot
.3466 .44942 Mdot
.59192 .40099 Mdot
.62242 .42125 Mdot
.40394 .31274 Mdot
.58462 .39734 Mdot
.35411 .54891 Mdot
.74884 .78116 Mdot
.61403 .65474 Mdot
.48069 .6797 Mdot
.39012 .75488 Mdot
.64358 .37488 Mdot
.66757 .41131 Mdot
.40459 .18564 Mdot
.38657 .76118 Mdot
.34795 .53607 Mdot
.61362 .3589 Mdot
.43778 .63107 Mdot
.60697 .63159 Mdot
.33553 .50577 Mdot
.65314 .40382 Mdot
.60287 .42859 Mdot
.63796 .64468 Mdot
.44041 .29301 Mdot
.67982 .72769 Mdot
.37579 .49318 Mdot
.6563 .49702 Mdot
.46246 .72106 Mdot
.62119 .38778 Mdot
.71066 .70154 Mdot
.42294 .39015 Mdot
.38692 .53871 Mdot
.23141 .6194 Mdot
.67464 .40858 Mdot
.34679 .4912 Mdot
.36132 .53086 Mdot
.60959 .36112 Mdot
.3957 .4081 Mdot
.37754 .37332 Mdot
.43885 .36514 Mdot
.77517 .70701 Mdot
.74456 .53556 Mdot
.48959 .66232 Mdot
.35193 .49676 Mdot
.45159 .68 Mdot
.5882 .65763 Mdot
.5048 .46687 Mdot
.46606 .68176 Mdot
.42659 .39412 Mdot
.46855 .60689 Mdot
.63605 .44631 Mdot
.36517 .5279 Mdot
.49936 .65502 Mdot
.67062 .3877 Mdot
.28325 .35166 Mdot
.38997 .64076 Mdot
.64067 .65343 Mdot
.62274 .61065 Mdot
.58831 .45419 Mdot
.43553 .60738 Mdot
.59542 .42435 Mdot
.35063 .5554 Mdot
.29643 .35986 Mdot
.65157 .37395 Mdot
.46576 .65397 Mdot
.46322 .34534 Mdot
.65033 .72656 Mdot
.6737 .3805 Mdot
.61664 .43942 Mdot
.62924 .39349 Mdot
.63637 .42564 Mdot
.23137 .4704 Mdot
.32938 .50679 Mdot
.34937 .38276 Mdot
.31841 .70992 Mdot
.39743 .36888 Mdot
.38512 .39362 Mdot
.66723 .70352 Mdot
.34364 .58361 Mdot
.34561 .51652 Mdot
.63582 .39916 Mdot
.28034 .50848 Mdot
.26371 .28759 Mdot
.5464 .14086 Mdot
.6525 .67946 Mdot
.48029 .61909 Mdot
.4106 .31707 Mdot
.45657 .61708 Mdot
.62076 .40243 Mdot
.54441 .44398 Mdot
.13344 .53868 Mdot
.37979 .47845 Mdot
.60194 .65281 Mdot
.62961 .39571 Mdot
.7496 .52809 Mdot
.44963 .62885 Mdot
.46783 .68794 Mdot
.5778 .41891 Mdot
.41555 .40557 Mdot
.30801 .76306 Mdot
.38537 .52634 Mdot
.33381 .331 Mdot
.66783 .49696 Mdot
.34051 .3932 Mdot
.37456 .5119 Mdot
.60294 .75855 Mdot
.455 .60923 Mdot
.43776 .25345 Mdot
.39537 .36823 Mdot
.61006 .66105 Mdot
.54936 .43799 Mdot
.38682 .36519 Mdot
.42171 .63513 Mdot
.39502 .34506 Mdot
.66123 .44899 Mdot
.34338 .48057 Mdot
.46354 .62288 Mdot
.40209 .52954 Mdot
.39304 .40557 Mdot
.61301 .61866 Mdot
.46763 .54654 Mdot
.64794 .28411 Mdot
.49267 .28016 Mdot
.59526 .39055 Mdot
.55044 .53049 Mdot
.65158 .431 Mdot
.36891 .36024 Mdot
.63185 .42243 Mdot
.44433 .31342 Mdot
.47082 .62178 Mdot
.57043 .4311 Mdot
.66012 .40581 Mdot
.62796 .23932 Mdot
.60096 .44346 Mdot
.59883 .47926 Mdot
.63943 .40497 Mdot
.38195 .3036 Mdot
.59017 .36205 Mdot
.41688 .34677 Mdot
.56379 .77168 Mdot
.46857 .63511 Mdot
.62252 .61194 Mdot
.61379 .66658 Mdot
.73629 .49408 Mdot
.54118 .66353 Mdot
.24532 .46548 Mdot
.41282 .35793 Mdot
.35774 .53659 Mdot
.63539 .42167 Mdot
.188 .58718 Mdot
.37485 .70813 Mdot
.43329 .63685 Mdot
.3459 .44949 Mdot
.61229 .50523 Mdot
.29141 .71761 Mdot
.57808 .452 Mdot
.80424 .6494 Mdot
.68399 .45673 Mdot
.60526 .47387 Mdot
.45234 .68353 Mdot
.58908 .60539 Mdot
.57603 .41343 Mdot
.3841 .33205 Mdot
.63167 .65421 Mdot
.37579 .41132 Mdot
.42332 .68724 Mdot
.57379 .76327 Mdot
.60094 .2472 Mdot
.64483 .42637 Mdot
.4666 .62375 Mdot
.41686 .33909 Mdot
.61174 .78533 Mdot
.37575 .54385 Mdot
.35735 .57696 Mdot
.64694 .51848 Mdot
.51495 .16018 Mdot
.6239 .66218 Mdot
.46111 .30767 Mdot
.6159 .45898 Mdot
.62539 .7084 Mdot
.59527 .38071 Mdot
.2669 .28722 Mdot
.58815 .6536 Mdot
.39374 .39653 Mdot
.34144 .51826 Mdot
.44433 .37656 Mdot
.4972 .29464 Mdot
.43841 .57163 Mdot
.48663 .51843 Mdot
.45457 .63481 Mdot
.42076 .49341 Mdot
.42819 .37037 Mdot
.67129 .42379 Mdot
.43552 .88119 Mdot
.4299 .38484 Mdot
.40441 .32229 Mdot
.67295 .2332 Mdot
.62816 .19294 Mdot
.6173 .50775 Mdot
.39039 .37882 Mdot
.45944 .63629 Mdot
.61484 .62287 Mdot
.65213 .44176 Mdot
.63943 .43651 Mdot
.39001 .37084 Mdot
.46162 .68712 Mdot
.56869 .33914 Mdot
.47567 .6511 Mdot
.42659 .35255 Mdot
.47763 .63761 Mdot
.29683 .64955 Mdot
.50274 .64553 Mdot
.5894 .38962 Mdot
.63289 .42211 Mdot
.47207 .73658 Mdot
.3957 .35502 Mdot
.6635 .41529 Mdot
.63953 .46018 Mdot
.41833 .37725 Mdot
.62599 .58766 Mdot
.53914 .3534 Mdot
.60494 .39457 Mdot
.61851 .44999 Mdot
.63861 .63814 Mdot
.51533 .48042 Mdot
.81253 .52049 Mdot
.6674 .42509 Mdot
.5835 .61945 Mdot
.37953 .35538 Mdot
.592 .42912 Mdot
.22596 .37831 Mdot
.28222 .6056 Mdot
.67481 .41682 Mdot
.50561 .65344 Mdot
.58573 .37225 Mdot
.24616 .70051 Mdot
.57957 .43142 Mdot
.41997 .37088 Mdot
.4149 .32563 Mdot
.72575 .30341 Mdot
.42012 .38708 Mdot
.43886 .65383 Mdot
.36621 .51323 Mdot
.27008 .29442 Mdot
.43791 .63978 Mdot
.6675 .37997 Mdot
.76715 .3261 Mdot
.62302 .47951 Mdot
.66255 .3803 Mdot
.3359 .76769 Mdot
.43985 .6373 Mdot
.43249 .33884 Mdot
.50909 .5768 Mdot
.61635 .48951 Mdot
.38854 .52925 Mdot
.5513 .40626 Mdot
.62773 .38171 Mdot
.39185 .78048 Mdot
.25853 .55644 Mdot
.371 .55941 Mdot
.57151 .47703 Mdot
.66769 .42312 Mdot
.40879 .6105 Mdot
.62872 .41864 Mdot
.62256 .62386 Mdot
.42707 .32793 Mdot
.48635 .62757 Mdot
.61815 .64408 Mdot
.60286 .40432 Mdot
.59841 .63983 Mdot
.49674 .65068 Mdot
.39154 .53027 Mdot
.62027 .39799 Mdot
.61897 .67366 Mdot
.60044 .64357 Mdot
.65556 .42862 Mdot
.39832 .33671 Mdot
.67974 .46649 Mdot
.58973 .43528 Mdot
.65343 .44879 Mdot
.38955 .36616 Mdot
.48586 .11856 Mdot
.57969 .43934 Mdot
.53857 .62929 Mdot
.3994 .32604 Mdot
.42286 .53482 Mdot
.48537 .6253 Mdot
.6227 .3814 Mdot
.38753 .54421 Mdot
.3616 .49134 Mdot
.43767 .6639 Mdot
.42952 .32124 Mdot
.48887 .74238 Mdot
.45951 .33544 Mdot
.65151 .47597 Mdot
.65568 .466 Mdot
.78749 .37127 Mdot
.15452 .48733 Mdot
.44548 .35761 Mdot
.47806 .68973 Mdot
.54786 .57824 Mdot
.34689 .49935 Mdot
.5108 .65877 Mdot
.41788 .31692 Mdot
.42396 .32245 Mdot
.40091 .34166 Mdot
.6018 .65773 Mdot
.48244 .73068 Mdot
.43678 .39977 Mdot
.41186 .40393 Mdot
.63254 .44492 Mdot
.6676 .41864 Mdot
.66429 .61082 Mdot
.71605 .63331 Mdot
.60643 .61564 Mdot
.47274 .6625 Mdot
.69355 .80573 Mdot
.35038 .55435 Mdot
.61414 .22946 Mdot
.65218 .37479 Mdot
.40738 .90079 Mdot
.5779 .44744 Mdot
.62616 .417 Mdot
.38619 .37932 Mdot
.63157 .66882 Mdot
.62737 .64318 Mdot
.4329 .36592 Mdot
.36913 .36537 Mdot
.62392 .62505 Mdot
.36232 .25354 Mdot
.23335 .33629 Mdot
.46496 .57447 Mdot
.41091 .37491 Mdot
.63085 .28035 Mdot
.39244 .51347 Mdot
.44582 .40497 Mdot
.33752 .53883 Mdot
.45704 .62896 Mdot
.43279 .60867 Mdot
.38286 .51165 Mdot
.63166 .44145 Mdot
.48586 .66844 Mdot
.60065 .48324 Mdot
.36674 .26636 Mdot
.53683 .33197 Mdot
.41717 .74841 Mdot
.55961 .41967 Mdot
.58654 .76651 Mdot
.3563 .59252 Mdot
.59113 .41277 Mdot
.20148 .48763 Mdot
.59989 .6494 Mdot
.44013 .40469 Mdot
.36802 .5563 Mdot
.23221 .697 Mdot
.62854 .39013 Mdot
.41603 .36944 Mdot
.35197 .52897 Mdot
.73357 .4532 Mdot
.31106 .36998 Mdot
.62766 .3957 Mdot
.46483 .88719 Mdot
.36894 .31496 Mdot
.48972 .63076 Mdot
.81127 .4393 Mdot
.44823 .37339 Mdot
.65633 .66353 Mdot
.32163 .70243 Mdot
.45816 .17315 Mdot
.42988 .34112 Mdot
.5129 .65997 Mdot
.43859 .35911 Mdot
.61616 .61868 Mdot
.45815 .34985 Mdot
.4508 .62393 Mdot
.60254 .43919 Mdot
.46863 .65862 Mdot
.59856 .6159 Mdot
.6863 .70798 Mdot
.37509 .55755 Mdot
.5072 .64772 Mdot
.36199 .50144 Mdot
.76129 .55583 Mdot
.31342 .71807 Mdot
.36684 .54903 Mdot
.74726 .36418 Mdot
.67609 .40756 Mdot
.44004 .39253 Mdot
.4566 .66723 Mdot
.3225 .69302 Mdot
.49389 .5583 Mdot
.40096 .37656 Mdot
.48669 .65651 Mdot
.6088 .5296 Mdot
.77532 .39151 Mdot
.65428 .35502 Mdot
.76353 .5774 Mdot
.41369 .37829 Mdot
.51486 .6538 Mdot
.62602 .77814 Mdot
.43214 .39072 Mdot
.45005 .66166 Mdot
.34031 .50662 Mdot
.37232 .51824 Mdot
.58046 .40858 Mdot
.39985 .55462 Mdot
.47782 .66608 Mdot
.38559 .59913 Mdot
.38164 .34548 Mdot
.71893 .47913 Mdot
.60681 .66837 Mdot
.47129 .6417 Mdot
.64498 .46789 Mdot
.42369 .41475 Mdot
.28831 .63005 Mdot
.61731 .32073 Mdot
.64164 .81603 Mdot
.46662 .66276 Mdot
.41739 .32224 Mdot
.41197 .36737 Mdot
.67288 .3805 Mdot
.52898 .5636 Mdot
.4889 .73936 Mdot
.76845 .43281 Mdot
.72798 .48625 Mdot
.42267 .64573 Mdot
.41849 .64687 Mdot
.68099 .40641 Mdot
.64637 .42005 Mdot
.34357 .50417 Mdot
.60722 .44159 Mdot
.38888 .3883 Mdot
.58058 .40495 Mdot
.37667 .50903 Mdot
.4516 .63994 Mdot
.61487 .40306 Mdot
.60439 .61901 Mdot
.39055 .54562 Mdot
.35092 .48322 Mdot
.46831 .64664 Mdot
.38574 .36188 Mdot
.56988 .63801 Mdot
.47696 .65264 Mdot
.64399 .42696 Mdot
.30651 .54565 Mdot
.64945 .45864 Mdot
.39272 .25108 Mdot
.42907 .3937 Mdot
.46312 .61795 Mdot
.38142 .34263 Mdot
.35629 .50036 Mdot
.31733 .7073 Mdot
.62535 .43118 Mdot
.44747 .65783 Mdot
.46002 .73172 Mdot
.38779 .26438 Mdot
.39108 .31571 Mdot
.29436 .56503 Mdot
.37623 .38118 Mdot
.42362 .6208 Mdot
.68023 .25556 Mdot
.62182 .66046 Mdot
.43379 .63403 Mdot
.1785 .435 Mdot
.45758 .65277 Mdot
.59924 .44735 Mdot
.59444 .45818 Mdot
.4941 .63361 Mdot
.63537 .65886 Mdot
.59459 .79484 Mdot
.44016 .58945 Mdot
.43069 .33851 Mdot
.4995 .17736 Mdot
.5597 .84426 Mdot
.39197 .57123 Mdot
.34261 .51747 Mdot
.61551 .49049 Mdot
.61459 .47447 Mdot
.33626 .53347 Mdot
.36963 .47796 Mdot
.58755 .64044 Mdot
.43112 .65268 Mdot
.39575 .29662 Mdot
.39523 .51244 Mdot
.6264 .33692 Mdot
.54567 .66983 Mdot
.65578 .36448 Mdot
.63167 .51563 Mdot
.58814 .38588 Mdot
.73962 .47377 Mdot
.37992 .51116 Mdot
.60602 .46742 Mdot
.64054 .35601 Mdot
.38686 .54348 Mdot
.6199 .62204 Mdot
.26674 .51785 Mdot
.47962 .63368 Mdot
.29763 .22922 Mdot
.61517 .47088 Mdot
.5955 .44631 Mdot
.38286 .50303 Mdot
.51013 .75084 Mdot
.39025 .35545 Mdot
.43353 .39158 Mdot
.48646 .67146 Mdot
.47072 .54205 Mdot
.61446 .38436 Mdot
.58625 .42268 Mdot
.48178 .63091 Mdot
.50486 .63884 Mdot
.378 .63714 Mdot
.62665 .45857 Mdot
.35057 .52406 Mdot
.56452 .58664 Mdot
.37884 .50937 Mdot
.64721 .4636 Mdot
.59934 .45112 Mdot
.58905 .39021 Mdot
.64797 .4657 Mdot
.34562 .48503 Mdot
.6102 .46668 Mdot
.68 .35735 Mdot
.38862 .34928 Mdot
.64178 .39223 Mdot
.73705 .47061 Mdot
.61678 .44384 Mdot
.61705 .62296 Mdot
.64062 .3304 Mdot
.62638 .39141 Mdot
.61463 .38226 Mdot
.4578 .59086 Mdot
.61025 .43119 Mdot
.34885 .55384 Mdot
.40013 .36519 Mdot
.35306 .49598 Mdot
.37448 .49414 Mdot
.44975 .67266 Mdot
.59484 .61501 Mdot
.64172 .37526 Mdot
.59174 .64597 Mdot
.61514 .3716 Mdot
.6758 .41532 Mdot
.35388 .72348 Mdot
.81247 .63503 Mdot
.68796 .72423 Mdot
.62679 .43164 Mdot
.44345 .64609 Mdot
.47769 .62128 Mdot
.35289 .35075 Mdot
.6569 .35744 Mdot
.33504 .52819 Mdot
.35646 .4908 Mdot
.69677 .62656 Mdot
.38295 .77126 Mdot
.61793 .62264 Mdot
.53076 .51392 Mdot
.60613 .48483 Mdot
.64264 .4566 Mdot
.62349 .4766 Mdot
.45443 .6807 Mdot
.54715 .59256 Mdot
.43443 .63523 Mdot
.32526 .4555 Mdot
.3755 .50287 Mdot
.63242 .38981 Mdot
.47725 .34706 Mdot
.42812 .38976 Mdot
.39989 .36435 Mdot
.34213 .4927 Mdot
.5067 .62538 Mdot
.6745 .65957 Mdot
.59096 .14757 Mdot
.376 .30293 Mdot
.63926 .66052 Mdot
.59199 .4082 Mdot
.45632 .64322 Mdot
.44075 .3672 Mdot
.63723 .62619 Mdot
.67086 .43108 Mdot
.4805 .7316 Mdot
.6309 .43276 Mdot
.56124 .51441 Mdot
.40847 .33313 Mdot
.254 .30565 Mdot
.43958 .33329 Mdot
.38784 .54893 Mdot
.37274 .55349 Mdot
.59631 .45604 Mdot
.79523 .39717 Mdot
.44068 .38776 Mdot
.41008 .51456 Mdot
.58778 .65138 Mdot
.29734 .62191 Mdot
.62229 .62068 Mdot
.48031 .62505 Mdot
.62995 .65747 Mdot
.45609 .62125 Mdot
.69697 .66109 Mdot
.39665 .30679 Mdot
.61533 .65046 Mdot
.52151 .62008 Mdot
.66424 .3605 Mdot
.62346 .61439 Mdot
.59399 .48949 Mdot
.44486 .22009 Mdot
.48668 .63632 Mdot
.61218 .66529 Mdot
.6706 .42561 Mdot
.1692 .57953 Mdot
.35279 .53974 Mdot
.33821 .53518 Mdot
.65228 .47483 Mdot
.43961 .67049 Mdot
.39173 .32374 Mdot
.22906 .41388 Mdot
.33553 .55424 Mdot
.58616 .44763 Mdot
.57681 .41163 Mdot
.39207 .39945 Mdot
.43439 .42723 Mdot
.60064 .45582 Mdot
.72528 .35474 Mdot
.61832 .46202 Mdot
.33871 .50854 Mdot
.44509 .36982 Mdot
.40669 .36627 Mdot
.48828 .65824 Mdot
.39879 .39178 Mdot
.37764 .28771 Mdot
.29383 .52038 Mdot
.61808 .49254 Mdot
.35424 .50792 Mdot
.30667 .48251 Mdot
.32783 .45414 Mdot
.16754 .48484 Mdot
.39212 .40154 Mdot
.57703 .39797 Mdot
.38356 .34229 Mdot
.60746 .62843 Mdot
.39892 .35332 Mdot
.40626 .31769 Mdot
.593 .42093 Mdot
.6243 .40161 Mdot
.44457 .63649 Mdot
.53253 .56861 Mdot
.38458 .3506 Mdot
.59241 .45915 Mdot
.59824 .47762 Mdot
.60262 .48115 Mdot
.46032 .44728 Mdot
.4447 .35881 Mdot
.59697 .2104 Mdot
.66226 .55039 Mdot
.38426 .35184 Mdot
.26753 .73548 Mdot
.31773 .68598 Mdot
.49489 .62397 Mdot
.39304 .5571 Mdot
.62814 .45835 Mdot
.47942 .62019 Mdot
.62038 .40231 Mdot
.63333 .51532 Mdot
.60528 .4255 Mdot
.62838 .6287 Mdot
.5874 .48066 Mdot
.42451 .61469 Mdot
.47378 .6552 Mdot
.58161 .43838 Mdot
.61171 .40736 Mdot
.67853 .71568 Mdot
.36964 .37394 Mdot
.39228 .35207 Mdot
.48931 .75172 Mdot
.60852 .64506 Mdot
.38803 .53333 Mdot
.63602 .41318 Mdot
.45524 .67467 Mdot
.47177 .65774 Mdot
.44772 .37045 Mdot
.48697 .64826 Mdot
.38488 .52348 Mdot
.62532 .42831 Mdot
.33817 .53655 Mdot
.59877 .65576 Mdot
.44117 .35586 Mdot
.63358 .39334 Mdot
.63211 .44528 Mdot
.41542 .32574 Mdot
.65651 .38291 Mdot
.63816 .6374 Mdot
.45877 .65497 Mdot
.42691 .34151 Mdot
.36769 .51444 Mdot
.46807 .62048 Mdot
.64873 .44778 Mdot
.67366 .81088 Mdot
.60422 .44921 Mdot
.63498 .45421 Mdot
.1728 .4295 Mdot
.58887 .48255 Mdot
.46081 .66634 Mdot
.40308 .40087 Mdot
.56998 .44909 Mdot
.73258 .50719 Mdot
.51997 .12991 Mdot
.43328 .64061 Mdot
.58974 .40764 Mdot
.14744 .53359 Mdot
.58342 .41873 Mdot
.748 .33481 Mdot
.58154 .68397 Mdot
.43399 .50781 Mdot
.69059 .44351 Mdot
.37865 .529 Mdot
.44341 .63762 Mdot
.47622 .62428 Mdot
.55378 .18683 Mdot
.59017 .42176 Mdot
.5612 .52022 Mdot
.66536 .40023 Mdot
.37453 .51433 Mdot
.68132 .60538 Mdot
.46973 .66137 Mdot
.70066 .74255 Mdot
.6487 .43342 Mdot
.44524 .35138 Mdot
.4782 .61016 Mdot
.31108 .66319 Mdot
.65363 .44696 Mdot
.5918 .6415 Mdot
.39822 .53235 Mdot
.57865 .46753 Mdot
.35677 .512 Mdot
.6534 .45195 Mdot
.5895 .34693 Mdot
.82876 .4777 Mdot
.39954 .33838 Mdot
.34084 .51257 Mdot
.31617 .5604 Mdot
.56598 .40343 Mdot
.42799 .34055 Mdot
.39595 .36967 Mdot
.58856 .63718 Mdot
.49547 .50915 Mdot
.29803 .41006 Mdot
.59988 .3117 Mdot
.54417 .18057 Mdot
.48919 .61512 Mdot
.31768 .59266 Mdot
.65905 .43766 Mdot
.44897 .78325 Mdot
.36183 .55942 Mdot
.59695 .44347 Mdot
.45228 .23384 Mdot
.43703 .36917 Mdot
.61712 .4534 Mdot
.62581 .63079 Mdot
.48252 .77948 Mdot
.47479 .78802 Mdot
.26262 .67363 Mdot
.45522 .63308 Mdot
.54435 .43732 Mdot
.55149 .47709 Mdot
.48438 .67617 Mdot
.65075 .38396 Mdot
.4554 .66235 Mdot
.41021 .21309 Mdot
.64035 .63669 Mdot
.44247 .35124 Mdot
.31675 .67938 Mdot
.62888 .37791 Mdot
.64525 .47467 Mdot
.62947 .61255 Mdot
.65066 .41563 Mdot
.83097 .56441 Mdot
.39183 .72169 Mdot
.49622 .66078 Mdot
.40039 .34094 Mdot
.6142 .37975 Mdot
.50952 .50861 Mdot
.58766 .43219 Mdot
.5678 .29134 Mdot
.61289 .38203 Mdot
.30661 .39192 Mdot
.40687 .33025 Mdot
.35749 .5077 Mdot
.57679 .38342 Mdot
.61194 .42261 Mdot
.59103 .57335 Mdot
.6841 .45375 Mdot
.58588 .45651 Mdot
.39042 .32108 Mdot
.44123 .37424 Mdot
.41699 .34795 Mdot
.43373 .61918 Mdot
.38951 .77568 Mdot
.34825 .51134 Mdot
.57296 .37888 Mdot
.3939 .50714 Mdot
.68244 .32549 Mdot
.64175 .64804 Mdot
.17894 .56634 Mdot
.6477 .3994 Mdot
.41763 .35547 Mdot
.23053 .53525 Mdot
.37793 .35759 Mdot
.53723 .5342 Mdot
.36351 .53008 Mdot
.43491 .37442 Mdot
.62019 .4192 Mdot
.52703 .57682 Mdot
.21305 .63032 Mdot
.36182 .49551 Mdot
.6312 .3695 Mdot
.47922 .61788 Mdot
.3764 .74567 Mdot
.65861 .81962 Mdot
.34922 .53792 Mdot
.31822 .55958 Mdot
.58903 .41953 Mdot
.4238 .39394 Mdot
.38137 .52661 Mdot
.36112 .54517 Mdot
.48863 .64927 Mdot
.62686 .40032 Mdot
.63097 .39846 Mdot
.42995 .61444 Mdot
.36304 .49307 Mdot
.68695 .43312 Mdot
.5942 .47082 Mdot
.13047 .54618 Mdot
.64776 .52859 Mdot
.35676 .1739 Mdot
.38234 .28697 Mdot
.45192 .24994 Mdot
.24159 .37854 Mdot
.4171 .32125 Mdot
.62453 .39095 Mdot
.55626 .43688 Mdot
.47756 .66555 Mdot
.61385 .43704 Mdot
.47061 .6898 Mdot
.34574 .52241 Mdot
.26029 .72176 Mdot
.29085 .46823 Mdot
.41975 .19776 Mdot
.61112 .43641 Mdot
.3638 .44393 Mdot
.61634 .63493 Mdot
.34741 .47096 Mdot
.4245 .34638 Mdot
.6629 .44854 Mdot
.67849 .71827 Mdot
.43429 .63401 Mdot
.4032 .38606 Mdot
.62245 .76988 Mdot
.59252 .76188 Mdot
.64868 .46281 Mdot
.44227 .61538 Mdot
.21548 .50321 Mdot
.72655 .36274 Mdot
.32742 .51884 Mdot
.62606 .62533 Mdot
.44237 .63004 Mdot
.36696 .49101 Mdot
.43648 .30031 Mdot
.42896 .38244 Mdot
.44721 .3264 Mdot
.72757 .68064 Mdot
.49017 .67475 Mdot
.61998 .63715 Mdot
.37964 .76645 Mdot
.4597 .79669 Mdot
.62913 .63062 Mdot
.4359 .60892 Mdot
.44133 .37138 Mdot
.42836 .36074 Mdot
.4008 .36611 Mdot
.68268 .75264 Mdot
.43714 .32833 Mdot
.5769 .22091 Mdot
.62373 .47999 Mdot
.53229 .40042 Mdot
.5869 .41108 Mdot
.33306 .52361 Mdot
.41609 .33178 Mdot
.45557 .54254 Mdot
.62293 .36118 Mdot
.25491 .68127 Mdot
.58381 .43243 Mdot
.34202 .47844 Mdot
.62355 .45521 Mdot
.6178 .24499 Mdot
.38666 .33782 Mdot
.62188 .43464 Mdot
.33634 .54086 Mdot
.60305 .63926 Mdot
.45171 .32601 Mdot
.62905 .39381 Mdot
.24628 .44039 Mdot
.58694 .48165 Mdot
.35995 .24494 Mdot
.69205 .50739 Mdot
.6393 .66035 Mdot
.71124 .44637 Mdot
.49617 .67568 Mdot
.52466 .42395 Mdot
.53805 .41643 Mdot
.36465 .49817 Mdot
.28385 .65652 Mdot
.46656 .63495 Mdot
.64057 .69114 Mdot
.56014 .38786 Mdot
.60305 .61352 Mdot
.36685 .36053 Mdot
.33225 .50709 Mdot
.67855 .4084 Mdot
.6482 .36416 Mdot
.41365 .22458 Mdot
.58935 .3596 Mdot
.58185 .40145 Mdot
.6423 .63319 Mdot
.53891 .196 Mdot
.62162 .44447 Mdot
.53147 .52767 Mdot
.45554 .34307 Mdot
.6828 .4503 Mdot
.62107 .22634 Mdot
.58982 .45532 Mdot
.41062 .39198 Mdot
.41197 .30761 Mdot
.26275 .48348 Mdot
.58554 .64292 Mdot
.62047 .38193 Mdot
.72075 .30065 Mdot
.64858 .42918 Mdot
.35157 .52239 Mdot
.62442 .47186 Mdot
.44945 .62659 Mdot
.67289 .75243 Mdot
.48365 .66664 Mdot
.60721 .39019 Mdot
.40414 .37016 Mdot
.38298 .50642 Mdot
.72861 .69653 Mdot
.5337 .69936 Mdot
.56563 .21366 Mdot
.43192 .17507 Mdot
.62916 .66343 Mdot
.60104 .60859 Mdot
.33395 .49958 Mdot
.62283 .43562 Mdot
.68683 .2496 Mdot
.67856 .46213 Mdot
.62014 .45059 Mdot
.60489 .42436 Mdot
.33813 .73926 Mdot
.345 .50504 Mdot
.48384 .64114 Mdot
.60087 .45408 Mdot
.60158 .46551 Mdot
.41003 .32224 Mdot
.60179 .64228 Mdot
.4829 .62379 Mdot
.60904 .65446 Mdot
.44934 .64539 Mdot
.25869 .72613 Mdot
.57854 .37887 Mdot
.60533 .63911 Mdot
.38151 .56006 Mdot
.39013 .36966 Mdot
.29354 .52732 Mdot
.48064 .62572 Mdot
.47471 .66269 Mdot
.5843 .43801 Mdot
.4102 .39292 Mdot
.3848 .37124 Mdot
.60624 .62762 Mdot
.37247 .54861 Mdot
.62304 .39379 Mdot
.67537 .42284 Mdot
.35221 .38219 Mdot
.44644 .67471 Mdot
.59588 .52451 Mdot
.24397 .49006 Mdot
.62651 .43352 Mdot
.38724 .37199 Mdot
.60442 .41486 Mdot
.24944 .34239 Mdot
.41693 .39585 Mdot
.58194 .44982 Mdot
.51037 .81368 Mdot
.52795 .66194 Mdot
.26902 .44241 Mdot
.57886 .40107 Mdot
.33318 .22329 Mdot
.6643 .42607 Mdot
.13193 .5725 Mdot
.59112 .70794 Mdot
.62459 .3866 Mdot
.64705 .44555 Mdot
.54158 .34391 Mdot
.60261 .40106 Mdot
.42444 .61762 Mdot
.66376 .68587 Mdot
.39723 .31916 Mdot
.26196 .38258 Mdot
.51347 .3905 Mdot
.59162 .65679 Mdot
.48783 .67061 Mdot
.41472 .64497 Mdot
.63054 .64323 Mdot
.41365 .37504 Mdot
.63662 .42531 Mdot
.46365 .5192 Mdot
.42858 .66143 Mdot
.68905 .3929 Mdot
.35463 .52465 Mdot
.34845 .63181 Mdot
.51878 .63652 Mdot
.36327 .51108 Mdot
.64947 .39374 Mdot
.54293 .34731 Mdot
.76011 .62018 Mdot
.22898 .32936 Mdot
.37742 .495 Mdot
.36881 .49575 Mdot
.66469 .76875 Mdot
.59718 .66476 Mdot
.44006 .20557 Mdot
.30862 .38065 Mdot
.38783 .51971 Mdot
.74085 .40271 Mdot
.4315 .64756 Mdot
.2529 .43327 Mdot
.44067 .40448 Mdot
.65126 .46831 Mdot
.61778 .42054 Mdot
.37506 .54892 Mdot
.37316 .28071 Mdot
.82134 .46625 Mdot
.36347 .50186 Mdot
.67057 .34889 Mdot
.4534 .46588 Mdot
.31873 .68794 Mdot
.44184 .66678 Mdot
.58584 .63943 Mdot
.64824 .66753 Mdot
.43302 .33624 Mdot
.5889 .62561 Mdot
.47159 .7813 Mdot
.64932 .40911 Mdot
.37026 .50491 Mdot
.29079 .62877 Mdot
.36729 .51819 Mdot
.62882 .64404 Mdot
.64041 .65984 Mdot
.38868 .34964 Mdot
.39378 .35095 Mdot
.46151 .26229 Mdot
.69292 .58735 Mdot
.58178 .42536 Mdot
.22599 .60986 Mdot
.38112 .34665 Mdot
.66727 .49414 Mdot
.60185 .60965 Mdot
.60481 .64287 Mdot
.63103 .55247 Mdot
.638 .40178 Mdot
.73157 .31558 Mdot
.63667 .40656 Mdot
.68398 .60083 Mdot
.60754 .37714 Mdot
.48792 .64895 Mdot
.63906 .39763 Mdot
.56911 .62375 Mdot
.68145 .41343 Mdot
.60478 .47232 Mdot
.44483 .67623 Mdot
.57536 .46225 Mdot
.45161 .62609 Mdot
.59731 .39448 Mdot
.58641 .65363 Mdot
.46509 .67812 Mdot
.73898 .52902 Mdot
.53536 .60863 Mdot
.44886 .60788 Mdot
.59501 .6209 Mdot
.60116 .66403 Mdot
.76 .48847 Mdot
.4256 .34671 Mdot
.46124 .37428 Mdot
.61901 .43771 Mdot
.47052 .68798 Mdot
.34269 .50881 Mdot
.61002 .46582 Mdot
.56654 .46465 Mdot
.57275 .41782 Mdot
.43898 .34339 Mdot
.48106 .74177 Mdot
.6042 .63362 Mdot
.43071 .62026 Mdot
.61405 .58777 Mdot
.4284 .65372 Mdot
.61659 .35517 Mdot
.55064 .43548 Mdot
.44224 .27074 Mdot
.24607 .59147 Mdot
.64499 .7933 Mdot
.42456 .38665 Mdot
.50645 .65054 Mdot
.60227 .66617 Mdot
.69515 .45787 Mdot
.42354 .35395 Mdot
.4507 .6243 Mdot
.63115 .43188 Mdot
.62826 .36924 Mdot
.32124 .47795 Mdot
.52541 .44507 Mdot
.71187 .50653 Mdot
.42898 .65271 Mdot
.51165 .66188 Mdot
.45532 .7931 Mdot
.66003 .6862 Mdot
.48042 .55184 Mdot
.59542 .43286 Mdot
.59237 .64362 Mdot
.44068 .36739 Mdot
.74453 .6493 Mdot
.36254 .55308 Mdot
.53068 .56654 Mdot
.6128 .43566 Mdot
.42811 .52093 Mdot
.40269 .37014 Mdot
.62248 .62692 Mdot
.37711 .548 Mdot
.64566 .63117 Mdot
.4729 .68122 Mdot
.54537 .15179 Mdot
.64996 .42432 Mdot
.57974 .42892 Mdot
.37622 .55841 Mdot
.43701 .36346 Mdot
.6327 .61296 Mdot
.3748 .25479 Mdot
.4976 .64456 Mdot
.70365 .263 Mdot
.39373 .3895 Mdot
.60877 .25434 Mdot
.4279 .62376 Mdot
.34355 .49128 Mdot
.75567 .51174 Mdot
.37706 .51034 Mdot
.60578 .38793 Mdot
.41108 .36082 Mdot
.35099 .53521 Mdot
.56079 .56619 Mdot
.1563 .554 Mdot
.62473 .27285 Mdot
.64258 .41123 Mdot
.18783 .61965 Mdot
.31996 .27998 Mdot
.36361 .3597 Mdot
.38783 .54437 Mdot
.5887 .43687 Mdot
.64904 .38507 Mdot
.64569 .43244 Mdot
.36371 .53589 Mdot
.34672 .70888 Mdot
.48823 .63617 Mdot
.58725 .4155 Mdot
.58819 .64196 Mdot
.45927 .62723 Mdot
.3143 .67783 Mdot
.46568 .66592 Mdot
.37736 .39006 Mdot
.62203 .47303 Mdot
.37532 .46577 Mdot
.18005 .6502 Mdot
.35535 .4949 Mdot
.44297 .60738 Mdot
.62518 .46716 Mdot
.27817 .6254 Mdot
.41828 .34962 Mdot
.49758 .65045 Mdot
.59511 .44556 Mdot
.33075 .684 Mdot
.68746 .71287 Mdot
.46646 .66509 Mdot
.43049 .35437 Mdot
.21103 .40328 Mdot
.61008 .44023 Mdot
.66229 .42491 Mdot
.4322 .36854 Mdot
.54715 .36163 Mdot
.62727 .7733 Mdot
.60867 .41055 Mdot
.35879 .50767 Mdot
.67921 .21822 Mdot
.57367 .44963 Mdot
.64608 .56351 Mdot
.44338 .63403 Mdot
.25532 .46503 Mdot
.60881 .52761 Mdot
.67789 .48382 Mdot
.3585 .27985 Mdot
.48543 .42869 Mdot
.24484 .69 Mdot
.48717 .68401 Mdot
.60093 .74341 Mdot
.24294 .69583 Mdot
.32986 .51296 Mdot
.4753 .38685 Mdot
.3354 .31581 Mdot
.73627 .71943 Mdot
.21216 .41842 Mdot
.52918 .76027 Mdot
.67561 .7238 Mdot
.45142 .4934 Mdot
.45169 .65098 Mdot
.6145 .68304 Mdot
.62343 .39755 Mdot
.31841 .27957 Mdot
.69937 .3011 Mdot
.81621 .42211 Mdot
.18115 .6098 Mdot
.73085 .32659 Mdot
.18433 .58253 Mdot
.17048 .47199 Mdot
.42774 .25554 Mdot
.24298 .57414 Mdot
.72183 .27343 Mdot
.50166 .80771 Mdot
.56638 .17512 Mdot
.57362 .48886 Mdot
.55277 .53542 Mdot
.38169 .21777 Mdot
.57612 .23779 Mdot
.78847 .4071 Mdot
.4895 .6596 Mdot
.406 .40207 Mdot
.3293 .32463 Mdot
.37011 .35325 Mdot
.38264 .58116 Mdot
.21558 .38293 Mdot
.14333 .52374 Mdot
.62023 .24191 Mdot
.31021 .2293 Mdot
.47644 .22494 Mdot
.87139 .55783 Mdot
.42452 .59957 Mdot
.4487 .376 Mdot
.65381 .62399 Mdot
.44279 .79415 Mdot
.3324 .4317 Mdot
.33281 .29733 Mdot
.36631 .73356 Mdot
.73483 .57245 Mdot
.41489 .37005 Mdot
.71062 .45962 Mdot
.38864 .58777 Mdot
.29682 .46724 Mdot
.66076 .69741 Mdot
.18311 .45426 Mdot
.48245 .53136 Mdot
.25139 .42041 Mdot
.33668 .60994 Mdot
.66191 .81311 Mdot
.67246 .54118 Mdot
.40588 .28176 Mdot
.3042 .52887 Mdot
.24446 .35728 Mdot
.7679 .67676 Mdot
.70629 .60353 Mdot
.44814 .79532 Mdot
.39051 .80108 Mdot
.29793 .2817 Mdot
.44014 .83924 Mdot
.46153 .36156 Mdot
.57904 .40483 Mdot
.49735 .35217 Mdot
.71012 .29381 Mdot
.6099 .67845 Mdot
.27296 .67968 Mdot
.60557 .66291 Mdot
.38779 .40686 Mdot
.66429 .75227 Mdot
.59544 .22802 Mdot
.72615 .29851 Mdot
.62283 .60272 Mdot
.55981 .41946 Mdot
.75036 .23454 Mdot
.23851 .67605 Mdot
.27218 .47072 Mdot
.12866 .55211 Mdot
.44479 .54744 Mdot
.73083 .45714 Mdot
.35246 .53522 Mdot
.22007 .67793 Mdot
.42264 .36207 Mdot
.36543 .82068 Mdot
.16479 .61065 Mdot
.81225 .48134 Mdot
.46068 .09245 Mdot
.43181 .77 Mdot
.43409 .51548 Mdot
.47304 .42345 Mdot
.71692 .53118 Mdot
.82511 .53637 Mdot
.79977 .44983 Mdot
.27698 .60959 Mdot
.40721 .18845 Mdot
.22084 .67122 Mdot
.70242 .27803 Mdot
.55173 .15935 Mdot
.75125 .70612 Mdot
.51144 .49407 Mdot
.42001 .42121 Mdot
.43203 .58445 Mdot
.19319 .50312 Mdot
.32767 .76914 Mdot
.65481 .55235 Mdot
.54935 .12567 Mdot
.58315 .60996 Mdot
.57705 .7082 Mdot
.21653 .35643 Mdot
.74872 .55776 Mdot
.70168 .4854 Mdot
.59981 .78122 Mdot
.68081 .38395 Mdot
.57105 .78867 Mdot
.19954 .57837 Mdot
.30125 .55172 Mdot
.5087 .80425 Mdot
.21987 .46343 Mdot
.39708 .23729 Mdot
.53757 .3258 Mdot
.43913 .79865 Mdot
.37841 .34232 Mdot
.71452 .57995 Mdot
.68508 .50563 Mdot
.13716 .52471 Mdot
.32018 .56093 Mdot
.13886 .46809 Mdot
.6408 .75569 Mdot
.57647 .39142 Mdot
.53456 .44017 Mdot
.6943 .36221 Mdot
.69617 .57418 Mdot
.58831 .469 Mdot
.3346 .4495 Mdot
.15104 .48314 Mdot
.4654 .21974 Mdot
.29249 .55766 Mdot
.2877 .66645 Mdot
.22362 .33413 Mdot
.47 .29983 Mdot
.64391 .7198 Mdot
.6681 .60743 Mdot
.71964 .75698 Mdot
.47181 .63501 Mdot
.69256 .26671 Mdot
.32862 .50094 Mdot
.70658 .6851 Mdot
.61423 .30847 Mdot
.8159 .53974 Mdot
.15127 .48172 Mdot
.55926 .77247 Mdot
.66247 .73683 Mdot
.76848 .54089 Mdot
.67865 .23379 Mdot
.2853 .67493 Mdot
.54996 .41165 Mdot
.29626 .32153 Mdot
.6331 .66286 Mdot
.48893 .2907 Mdot
.62373 .2073 Mdot
.53624 .7286 Mdot
.62865 .48488 Mdot
.78466 .58046 Mdot
.43118 .72091 Mdot
.526 .57498 Mdot
.52741 .86022 Mdot
.65912 .36091 Mdot
.39227 .76803 Mdot
.31313 .26864 Mdot
.69312 .54664 Mdot
.23711 .34201 Mdot
.23336 .42302 Mdot
.41907 .82801 Mdot
.15379 .58685 Mdot
.52051 .71249 Mdot
.26802 .71459 Mdot
.13123 .53101 Mdot
.45367 .83379 Mdot
.56009 .37536 Mdot
.36256 .56353 Mdot
.58597 .87216 Mdot
.42206 .62991 Mdot
.33725 .74582 Mdot
.5451 .18094 Mdot
.33497 .68067 Mdot
.40404 .2955 Mdot
.59586 .4987 Mdot
.45893 .50208 Mdot
.36404 .36509 Mdot
.58142 .46726 Mdot
.56129 .84053 Mdot
.4309 .82029 Mdot
.50198 .84748 Mdot
.32159 .24672 Mdot
.26986 .72322 Mdot
.42311 .48054 Mdot
.58503 .23428 Mdot
.35682 .37137 Mdot
.65843 .45869 Mdot
.56128 .66119 Mdot
.43111 .76824 Mdot
.78352 .59205 Mdot
.32722 .41832 Mdot
.36768 .36677 Mdot
.24363 .64023 Mdot
.88693 .6134 Mdot
.4756 .23839 Mdot
.62173 .22191 Mdot
.46904 .79042 Mdot
.68547 .57625 Mdot
.19727 .52768 Mdot
.81376 .5117 Mdot
.16906 .4426 Mdot
.36083 .3478 Mdot
.54898 .17618 Mdot
.54252 .75005 Mdot
.75671 .42596 Mdot
.47175 .74419 Mdot
.15685 .52934 Mdot
.42278 .44314 Mdot
.76358 .64422 Mdot
.3077 .35497 Mdot
.8161 .47376 Mdot
.60354 .7 Mdot
.35459 .632 Mdot
.63108 .20885 Mdot
.27247 .56122 Mdot
.66871 .57632 Mdot
.46523 .47942 Mdot
.70597 .42979 Mdot
.48414 .42799 Mdot
.66666 .56842 Mdot
.75301 .45079 Mdot
.30824 .74595 Mdot
.11662 .57844 Mdot
.64113 .80873 Mdot
.29063 .23901 Mdot
.20233 .5658 Mdot
.66389 .46102 Mdot
.19571 .37257 Mdot
.46046 .85194 Mdot
.15196 .60119 Mdot
.39096 .68122 Mdot
.451 .69257 Mdot
.39162 .49827 Mdot
.6036 .81357 Mdot
.45264 .73672 Mdot
.19125 .4105 Mdot
.58349 .79248 Mdot
.40146 .53371 Mdot
.81812 .62358 Mdot
.41648 .80957 Mdot
.63014 .29934 Mdot
.53237 .46023 Mdot
.688 .40955 Mdot
.64393 .26017 Mdot
.37147 .37211 Mdot
.32401 .59392 Mdot
.70191 .59073 Mdot
.47263 .64561 Mdot
.58393 .68048 Mdot
.32626 .29821 Mdot
.58813 .48105 Mdot
.49397 .4122 Mdot
.40992 .40474 Mdot
.24588 .58635 Mdot
.29249 .49951 Mdot
.30806 .76359 Mdot
.41953 .75494 Mdot
.69609 .43194 Mdot
.68766 .54655 Mdot
.46246 .74964 Mdot
.62311 .78211 Mdot
.34838 .47901 Mdot
.17285 .59088 Mdot
.55409 .54715 Mdot
.71192 .58103 Mdot
.6652 .27612 Mdot
.40233 .24408 Mdot
.55629 .4619 Mdot
.23822 .50909 Mdot
.55003 .28709 Mdot
.53589 .57213 Mdot
.41194 .42034 Mdot
.42629 .42074 Mdot
.20668 .33565 Mdot
.49047 .77916 Mdot
.33256 .6148 Mdot
.17126 .57781 Mdot
.37276 .52726 Mdot
.3823 .35238 Mdot
.55713 .65082 Mdot
.38447 .241 Mdot
.56796 .26703 Mdot
.6877 .71326 Mdot
.37807 .71424 Mdot
.55024 .72148 Mdot
.17906 .58234 Mdot
.18569 .60779 Mdot
.81424 .3968 Mdot
.38891 .31691 Mdot
.40318 .2601 Mdot
.45364 .19446 Mdot
.38201 .38649 Mdot
.34993 .30843 Mdot
.34949 .43089 Mdot
.31253 .75877 Mdot
.40411 .54415 Mdot
.39455 .19074 Mdot
.73943 .48526 Mdot
.33365 .70354 Mdot
.72449 .70208 Mdot
.63633 .2105 Mdot
.17045 .56595 Mdot
.72689 .36964 Mdot
.60971 .31708 Mdot
.59796 .49365 Mdot
.5347 .48285 Mdot
.71673 .77663 Mdot
.53853 .61772 Mdot
.61263 .25394 Mdot
.21755 .45023 Mdot
.64356 .42289 Mdot
.63836 .81617 Mdot
.35803 .26601 Mdot
.66186 .77371 Mdot
.39908 .52517 Mdot
.66702 .41022 Mdot
.67991 .42962 Mdot
.63691 .5743 Mdot
.26241 .47348 Mdot
.35618 .76804 Mdot
.62627 .20059 Mdot
.2103 .48931 Mdot
.69883 .30136 Mdot
.38894 .76471 Mdot
.19201 .42791 Mdot
.31302 .28495 Mdot
.50449 .51826 Mdot
.4344 .76534 Mdot
.75474 .53678 Mdot
.30809 .23447 Mdot
.59581 .56278 Mdot
.39507 .45053 Mdot
.34713 .40911 Mdot
.23916 .46872 Mdot
.74083 .66641 Mdot
.65922 .44932 Mdot
.62232 .76998 Mdot
.17497 .46308 Mdot
.78088 .35138 Mdot
.80765 .59958 Mdot
.61898 .82316 Mdot
.57684 .29816 Mdot
.23436 .451 Mdot
.31363 .29391 Mdot
.74458 .27229 Mdot
.56869 .54629 Mdot
.24063 .65861 Mdot
.75984 .53653 Mdot
.1752 .57965 Mdot
.35578 .56246 Mdot
.31659 .37036 Mdot
.2912 .67192 Mdot
.28674 .73038 Mdot
.49324 .32327 Mdot
.16275 .51224 Mdot
.44107 .5291 Mdot
.39459 .82356 Mdot
.26514 .56267 Mdot
.44407 .48107 Mdot
.50278 .65786 Mdot
.55281 .77731 Mdot
.18925 .57036 Mdot
.22977 .58281 Mdot
.63337 .2133 Mdot
.51627 .66006 Mdot
.59906 .68258 Mdot
.66439 .30103 Mdot
.75466 .58856 Mdot
.23187 .47973 Mdot
.68826 .54637 Mdot
.15314 .50906 Mdot
.62965 .58385 Mdot
.64204 .74598 Mdot
.38574 .7588 Mdot
.51488 .14857 Mdot
.27042 .46783 Mdot
.51031 .78603 Mdot
.34703 .27797 Mdot
.57757 .69752 Mdot
.74122 .41447 Mdot
.16305 .7061 Mdot
.49775 .16183 Mdot
.25419 .56834 Mdot
.32848 .76933 Mdot
.24819 .33279 Mdot
.24947 .59132 Mdot
.82328 .54718 Mdot
.64529 .52891 Mdot
.68328 .67805 Mdot
.60617 .42463 Mdot
.51138 .85642 Mdot
.73534 .59215 Mdot
.35157 .78858 Mdot
.20272 .35771 Mdot
.64583 .26528 Mdot
.58537 .47803 Mdot
.43204 .6253 Mdot
.34082 .58046 Mdot
.73995 .62078 Mdot
.53808 .35739 Mdot
.72091 .45347 Mdot
.39013 .72352 Mdot
.48542 .67595 Mdot
.48091 .74879 Mdot
.36343 .32229 Mdot
.41108 .73642 Mdot
.24193 .48611 Mdot
.52734 .67405 Mdot
.50016 .53997 Mdot
.67386 .56765 Mdot
.62829 .52321 Mdot
.62701 .29757 Mdot
.80982 .55595 Mdot
.4977 .46557 Mdot
.46397 .66761 Mdot
.58833 .31187 Mdot
.41908 .18957 Mdot
.21845 .50296 Mdot
.38287 .79698 Mdot
.59242 .77487 Mdot
.62706 .32059 Mdot
.66119 .57157 Mdot
.82653 .519 Mdot
.75698 .36084 Mdot
.24787 .62232 Mdot
.58056 .51069 Mdot
.74487 .35959 Mdot
.30128 .32833 Mdot
.25377 .71685 Mdot
.56296 .17539 Mdot
.49668 .17619 Mdot
.49481 .59857 Mdot
.56376 .23982 Mdot
.66343 .28457 Mdot
.74263 .51916 Mdot
.49679 .55891 Mdot
.86085 .5847 Mdot
.45097 .394 Mdot
.75156 .76346 Mdot
.33924 .51696 Mdot
.75673 .70887 Mdot
.76182 .51649 Mdot
.46484 .47426 Mdot
.48477 .56222 Mdot
.24206 .51104 Mdot
.3092 .39125 Mdot
.33941 .23212 Mdot
.80512 .41494 Mdot
.43092 .66048 Mdot
.6296 .19797 Mdot
.53013 .14326 Mdot
.55936 .33122 Mdot
.5616 .41982 Mdot
.49098 .16123 Mdot
.49912 .68127 Mdot
.78427 .59217 Mdot
.23673 .33464 Mdot
.22089 .55982 Mdot
.61981 .33954 Mdot
.69013 .5794 Mdot
.23441 .6493 Mdot
.15658 .57698 Mdot
.82454 .59204 Mdot
.19985 .57794 Mdot
.3624 .56301 Mdot
.43282 .48261 Mdot
.17141 .51958 Mdot
.71736 .48493 Mdot
.26234 .40284 Mdot
.70524 .48668 Mdot
.82103 .68066 Mdot
.31843 .73317 Mdot
.35421 .76638 Mdot
.70246 .49614 Mdot
.43769 .32603 Mdot
.27035 .52104 Mdot
.69724 .49093 Mdot
.22753 .55394 Mdot
.37912 .22469 Mdot
.69004 .50001 Mdot
.80125 .34308 Mdot
.43957 .22302 Mdot
.45337 .70226 Mdot
.67563 .29655 Mdot
.44716 .22755 Mdot
.3997 .53428 Mdot
.66485 .69119 Mdot
.21375 .45759 Mdot
.38164 .55611 Mdot
.23192 .48617 Mdot
.24816 .44499 Mdot
.47052 .20345 Mdot
.58075 .2698 Mdot
.20818 .51076 Mdot
.52254 .35256 Mdot
.47604 .39416 Mdot
.73955 .6548 Mdot
.48185 .61409 Mdot
.21001 .4431 Mdot
.50129 .64795 Mdot
.63234 .51004 Mdot
.54041 .56731 Mdot
.65459 .3313 Mdot
.6285 .80718 Mdot
.62859 .66462 Mdot
.44438 .37895 Mdot
.77036 .70359 Mdot
.38816 .3902 Mdot
.53883 .84676 Mdot
.81514 .5272 Mdot
.66616 .27505 Mdot
.53339 .70504 Mdot
.51553 .73961 Mdot
.85743 .45538 Mdot
.48456 .40736 Mdot
.47485 .59262 Mdot
.46609 .41118 Mdot
.44791 .36534 Mdot
.39519 .7546 Mdot
.45426 .6772 Mdot
.60783 .54157 Mdot
.41365 .492 Mdot
.39852 .43579 Mdot
.3869 .3101 Mdot
.54628 .55318 Mdot
.69055 .64521 Mdot
.3048 .75157 Mdot
.45079 .65896 Mdot
.79768 .69406 Mdot
.56126 .46353 Mdot
.5266 .3214 Mdot
.16783 .43918 Mdot
.82385 .60738 Mdot
.41457 .63072 Mdot
.54472 .13868 Mdot
.61519 .37389 Mdot
.20306 .52584 Mdot
.42158 .36822 Mdot
.52027 .17267 Mdot
.62432 .66153 Mdot
.70128 .54133 Mdot
.38198 .48742 Mdot
.7606 .64857 Mdot
.39701 .71628 Mdot
.42555 .31636 Mdot
.21459 .58097 Mdot
.41211 .25282 Mdot
.2922 .37701 Mdot
.49986 .74476 Mdot
.57329 .32556 Mdot
.57567 .26431 Mdot
.39158 .30809 Mdot
.3311 .75468 Mdot
.52797 .17024 Mdot
.24196 .71915 Mdot
.69896 .37295 Mdot
.59174 .75646 Mdot
.35057 .40382 Mdot
.22827 .50739 Mdot
.56231 .50832 Mdot
.16072 .46263 Mdot
.71097 .59447 Mdot
.36567 .43004 Mdot
.68115 .59344 Mdot
.65083 .49756 Mdot
.49146 .52362 Mdot
.35373 .60569 Mdot
.82686 .44045 Mdot
.55684 .51209 Mdot
.78122 .66395 Mdot
.58837 .51383 Mdot
.40336 .77457 Mdot
.3767 .30018 Mdot
.42839 .67904 Mdot
.57702 .24438 Mdot
.31839 .56129 Mdot
.24441 .70526 Mdot
.16318 .45545 Mdot
.36566 .47028 Mdot
.38433 .7445 Mdot
.2408 .36786 Mdot
.69835 .436 Mdot
.42285 .50263 Mdot
.58794 .39567 Mdot
.36301 .30284 Mdot
.82795 .61186 Mdot
.22981 .5361 Mdot
.54633 .4169 Mdot
.24378 .69068 Mdot
.21318 .66634 Mdot
.38154 .81295 Mdot
.69377 .25129 Mdot
.42203 .32297 Mdot
.48317 .8387 Mdot
.72317 .44374 Mdot
.13984 .54778 Mdot
.24255 .61202 Mdot
.19759 .34912 Mdot
.58447 .32528 Mdot
.2236 .43377 Mdot
.80499 .43955 Mdot
.28618 .40798 Mdot
.28751 .29188 Mdot
.43744 .45533 Mdot
.31816 .61328 Mdot
.26906 .30329 Mdot
.80529 .31552 Mdot
.55962 .49789 Mdot
.24821 .43128 Mdot
.31799 .33138 Mdot
.20862 .45167 Mdot
.60684 .71596 Mdot
.62535 .47153 Mdot
.2921 .63871 Mdot
.69907 .72026 Mdot
.67008 .55728 Mdot
.59297 .67886 Mdot
.60379 .71498 Mdot
.71598 .65558 Mdot
.68931 .61332 Mdot
.56618 .17455 Mdot
.59082 .32048 Mdot
.59272 .53459 Mdot
.56708 .40096 Mdot
.38746 .29782 Mdot
.58493 .62679 Mdot
.42241 .6954 Mdot
.591 .39811 Mdot
.45331 .69024 Mdot
.29407 .386 Mdot
.59872 .83146 Mdot
.29069 .54816 Mdot
.35697 .25775 Mdot
.43613 .40585 Mdot
.25312 .48551 Mdot
.47419 .34094 Mdot
.70628 .73676 Mdot
.58973 .74144 Mdot
.6549 .55218 Mdot
.22128 .65386 Mdot
.50499 .80378 Mdot
.41734 .22958 Mdot
.50273 .8169 Mdot
.36725 .55954 Mdot
.62016 .34439 Mdot
.32572 .35178 Mdot
.47276 .75864 Mdot
.39314 .41555 Mdot
.22335 .44006 Mdot
.47741 .59707 Mdot
.50497 .79116 Mdot
.3078 .27174 Mdot
.40834 .24785 Mdot
.66746 .30868 Mdot
.19139 .61926 Mdot
.43348 .64226 Mdot
.4986 .17016 Mdot
.26254 .39182 Mdot
.57937 .75274 Mdot
.39161 .78027 Mdot
.28798 .74847 Mdot
.45894 .54739 Mdot
.73548 .55824 Mdot
.65631 .42987 Mdot
.59671 .21059 Mdot
.23531 .53097 Mdot
.52219 .40821 Mdot
.37673 .67617 Mdot
.39252 .38019 Mdot
.37024 .63221 Mdot
.56155 .53484 Mdot
.69642 .66601 Mdot
.36744 .35357 Mdot
.71492 .30463 Mdot
.57898 .64074 Mdot
.43755 .55408 Mdot
.58004 .46295 Mdot
.7254 .54949 Mdot
.72399 .29154 Mdot
.64705 .34933 Mdot
.19282 .54898 Mdot
.59507 .31484 Mdot
.39815 .23201 Mdot
.21487 .53037 Mdot
.25282 .62978 Mdot
.3056 .39691 Mdot
.59556 .25545 Mdot
.4016 .70134 Mdot
.57349 .41507 Mdot
.42484 .6735 Mdot
.38012 .36758 Mdot
.2234 .37335 Mdot
.57123 .29447 Mdot
.73948 .53246 Mdot
.47651 .4703 Mdot
.48596 .35605 Mdot
.47571 .44848 Mdot
.1868 .39162 Mdot
.28658 .40954 Mdot
.70293 .59434 Mdot
.39085 .57345 Mdot
.75958 .51813 Mdot
.81588 .55291 Mdot
.18418 .63638 Mdot
.82208 .50146 Mdot
.4649 .52833 Mdot
.78924 .65598 Mdot
.26101 .5484 Mdot
.23975 .32964 Mdot
.69973 .60769 Mdot
.46154 .55975 Mdot
.56649 .65215 Mdot
.32779 .47179 Mdot
.50396 .49374 Mdot
.55307 .6229 Mdot
.62691 .53172 Mdot
.354 .67418 Mdot
.39671 .59186 Mdot
.60116 .49852 Mdot
.33946 .74356 Mdot
.20806 .63786 Mdot
.53088 .17616 Mdot
.48799 .43921 Mdot
.64384 .70154 Mdot
.71144 .64601 Mdot
.2546 .25338 Mdot
.67083 .81166 Mdot
.65536 .42876 Mdot
.49242 .44139 Mdot
.71837 .56378 Mdot
.42556 .64645 Mdot
.6776 .50045 Mdot
.4861 .36832 Mdot
.3449 .4941 Mdot
.54621 .6331 Mdot
.52508 .79403 Mdot
.24545 .51266 Mdot
.76413 .56983 Mdot
.30496 .67606 Mdot
.5942 .83628 Mdot
.38603 .21008 Mdot
.22921 .51775 Mdot
.20814 .3057 Mdot
.38608 .5989 Mdot
.44514 .41231 Mdot
.49104 .34847 Mdot
.31482 .75537 Mdot
.6907 .53906 Mdot
.72225 .68235 Mdot
.27016 .65328 Mdot
.70685 .60144 Mdot
.73482 .42891 Mdot
.38933 .76217 Mdot
.37193 .64467 Mdot
.46564 .49735 Mdot
.51735 .7406 Mdot
.4583 .81401 Mdot
.70431 .31363 Mdot
.21912 .63903 Mdot
.70709 .71784 Mdot
.7832 .30909 Mdot
.22188 .68154 Mdot
.56922 .66781 Mdot
.62413 .71668 Mdot
.49198 .34457 Mdot
.72995 .48369 Mdot
.73858 .39431 Mdot
.78195 .60517 Mdot
.55514 .26338 Mdot
.49157 .72522 Mdot
.75105 .69337 Mdot
.66809 .57529 Mdot
.45234 .22255 Mdot
.46373 .55957 Mdot
.61247 .30077 Mdot
.39973 .74645 Mdot
.68453 .51581 Mdot
.57167 .57211 Mdot
.72628 .50781 Mdot
.57991 .31741 Mdot
.36235 .27726 Mdot
.2445 .39008 Mdot
.82734 .36665 Mdot
.25538 .64947 Mdot
.71476 .73105 Mdot
.6152 .48127 Mdot
.26943 .74578 Mdot
.24821 .39688 Mdot
.26697 .65533 Mdot
.34197 .24793 Mdot
.43524 .69535 Mdot
.37491 .43199 Mdot
.57338 .41631 Mdot
.21625 .60517 Mdot
.61867 .25811 Mdot
.44734 .23959 Mdot
.75075 .66826 Mdot
.69048 .55668 Mdot
.64826 .72238 Mdot
.74465 .50364 Mdot
.66181 .34805 Mdot
.40799 .39924 Mdot
.48989 .84702 Mdot
.44989 .52661 Mdot
.60778 .51111 Mdot
.53412 .39435 Mdot
.80678 .44726 Mdot
.43639 .16676 Mdot
.69305 .36216 Mdot
.48159 .80132 Mdot
.72882 .32924 Mdot
.69125 .33998 Mdot
.66958 .4973 Mdot
.34164 .14572 Mdot
.1208 .5711 Mdot
.4086 .31515 Mdot
.63314 .22388 Mdot
.73435 .33028 Mdot
.30622 .74598 Mdot
.54728 .74848 Mdot
.41063 .69492 Mdot
.78375 .41916 Mdot
.7409 .45305 Mdot
.55608 .42272 Mdot
.32055 .26195 Mdot
.17325 .61916 Mdot
.75285 .67329 Mdot
.23773 .68547 Mdot
.54914 .47016 Mdot
.56488 .38532 Mdot
.31228 .19126 Mdot
.17205 .5309 Mdot
.68339 .38994 Mdot
.80934 .44246 Mdot
.42259 .42005 Mdot
.61807 .40658 Mdot
.31035 .70379 Mdot
.62091 .19845 Mdot
.66502 .57567 Mdot
.28799 .73141 Mdot
.37358 .34345 Mdot
.4547 .58475 Mdot
.34269 .49388 Mdot
.48907 .56119 Mdot
.60877 .36942 Mdot
.36114 .53861 Mdot
.6856 .33462 Mdot
.22083 .42483 Mdot
.401 .50513 Mdot
.57199 .16822 Mdot
.15044 .43534 Mdot
.59173 .29234 Mdot
.3141 .49499 Mdot
.70009 .43457 Mdot
.43956 .22805 Mdot
.73362 .63177 Mdot
.35459 .36905 Mdot
.25689 .31043 Mdot
.25266 .77622 Mdot
.32646 .62426 Mdot
.67685 .66407 Mdot
.36553 .37982 Mdot
.5884 .53099 Mdot
.64302 .29023 Mdot
.42401 .55101 Mdot
.4388 .63978 Mdot
.65988 .47505 Mdot
.66939 .35216 Mdot
.39546 .51498 Mdot
.74648 .7624 Mdot
.63405 .46621 Mdot
.64183 .51563 Mdot
.14215 .54969 Mdot
.73887 .65628 Mdot
.51197 .3186 Mdot
.65929 .37824 Mdot
.30259 .4659 Mdot
.46038 .56002 Mdot
.19559 .45396 Mdot
.63813 .74944 Mdot
.26217 .70043 Mdot
.56816 .29345 Mdot
.68594 .3127 Mdot
.59468 .46222 Mdot
.6047 .67281 Mdot
.25718 .42951 Mdot
.28586 .69191 Mdot
.53975 .45386 Mdot
.14762 .57406 Mdot
.43779 .6981 Mdot
.36687 .69916 Mdot
.70363 .36241 Mdot
.40101 .81972 Mdot
.78658 .64284 Mdot
.6446 .27448 Mdot
.69108 .75544 Mdot
.48113 .76804 Mdot
.75317 .58836 Mdot
.43318 .62727 Mdot
.55684 .47594 Mdot
.37828 .33496 Mdot
.59613 .84068 Mdot
.28992 .69996 Mdot
.29101 .61259 Mdot
.35474 .6353 Mdot
.57659 .21103 Mdot
.2868 .36415 Mdot
.18634 .3509 Mdot
.49694 .75767 Mdot
.60714 .83198 Mdot
.49681 .17453 Mdot
.36294 .38002 Mdot
.22937 .45765 Mdot
.61795 .34759 Mdot
.46239 .66295 Mdot
.282 .71465 Mdot
.6872 .36902 Mdot
.6689 .74543 Mdot
.65907 .38509 Mdot
.6435 .7859 Mdot
.55701 .6031 Mdot
.36357 .74159 Mdot
.27261 .57148 Mdot
.8202 .55358 Mdot
.20991 .3827 Mdot
.33626 .46155 Mdot
.22146 .30206 Mdot
.2111 .3955 Mdot
.17263 .59337 Mdot
.69414 .7088 Mdot
.84143 .54734 Mdot
.23363 .58745 Mdot
.21037 .51034 Mdot
.28075 .56166 Mdot
.52572 .37507 Mdot
.54981 .77584 Mdot
.70376 .36779 Mdot
.26568 .43842 Mdot
.35807 .46734 Mdot
.4317 .91 Mdot
.56875 .61556 Mdot
.46413 .35049 Mdot
.51611 .77212 Mdot
.19361 .63325 Mdot
.56208 .35399 Mdot
.2833 .28371 Mdot
.55376 .53675 Mdot
.55025 .41376 Mdot
.57189 .2758 Mdot
.56258 .18549 Mdot
.56677 .77847 Mdot
.87205 .47996 Mdot
.38688 .21268 Mdot
.35622 .66034 Mdot
.50386 .53187 Mdot
.3781 .38211 Mdot
.42085 .30114 Mdot
.5299 .7219 Mdot
.2819 .27069 Mdot
.22254 .43075 Mdot
.17136 .52126 Mdot
.85292 .44635 Mdot
.4359 .2059 Mdot
.31167 .75453 Mdot
.25192 .54624 Mdot
.45445 .33666 Mdot
.59598 .68662 Mdot
.5004 .69932 Mdot
.282 .60319 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo09;ooooo0_l0002eooooo`007?ooool00ol0003oooooooooo`2Boooo
o`;o0000]Oooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0WOooool2o`000:[ooooo000Looooo`03o`000?oooooo
oooo09gooooo0_l0002Zooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0V_ooool2o`000:gooooo
000Looooo`03o`000?oooooooooo09[ooooo0_l0002]ooooo`007?ooool00ol0003oooooooooo`2_
ooooo`;o0000V?ooool001cooooo00?o0000ooooooooool0[oooool3o`0009Oooooo000Looooo`03
o`000?oooooooooo08oooooo0_l0000Dooooo`;o00002Oooool2o`0009Oooooo000Looooo`03o`00
0?oooooooooo08oooooo0_l0000Dooooo`;o0000X_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`2]ooooo`?o0000VOooool001cooooo00?o0000oooo
ooooool0P?ooool2o`0002Kooooo0_l00003ooooo`?o0000VOooool001cooooo00?o0000oooooooo
ool0Joooool2o`0001?ooooo0_l0000Vooooo`;o00004_ooool2o`0008_ooooo000Looooo`03o`00
0?oooooooooo06_ooooo0_l0000cooooo`;o000000?oooooo`000?l000005oooool2o`0000Sooooo
0_l00021ooooo`007?ooool2o`000:7ooooo0_l000000ooooooo0000o`000008ooooo`;o00005ooo
ool2o`00087ooooo000Looooo`03o`000?oooooooooo09Gooooo0_l0000Fooooo`;o00001oooool2
o`0000Kooooo0_l00006ooooo`;o0000POooool001cooooo00?o0000ooooooooool0N?ooool2o`00
01Wooooo1?l0000Hooooo`;o00001Oooool2o`0000Kooooo0_l00029ooooo`007?ooool00ol0003o
ooooooooo`1hooooo`;o00006Oooool2o`0000Oooooo1?l00004ooooo`;o000000?oooooo`000?l0
00001_ooool2o`0000_ooooo0ol0002:ooooo`007?ooool00ol0003oooooooooo`2Looooo`Co0000
1?ooool2o`000003ooooool0003o000001?ooooo0ol0002:ooooo`007?ooool00ol0003ooooooooo
o`2:ooooo`;o00004Oooool2o`0001Oooooo0_l0002Aooooo`007?ooool00ol0003oooooooooo`2:
ooooo`;o00002Oooool3o`0000Cooooo1?l00005ooooo`;o000000?oooooo`000?l000003?ooool2
o`00097ooooo000Looooo`03o`000?oooooooooo073ooooo0_l0000Fooooo`Go00001?ooool2o`00
00;ooooo0ol00004ooooo`Co00001Oooool2o`000003ooooool0003o000000Wooooo1?l0002Boooo
o`007?ooool00ol0003oooooooooo`1`ooooo`;o00005_ooool5o`0000Cooooo0_l00004ooooo`;o
00001Oooool2o`0000Gooooo0_l00002ooooo`;o00001?ooool2o`0000;ooooo1?l0002Booooo`00
7?ooool00ol0003oooooooooo`2Gooooo`;o00001Oooool2o`0000Wooooo0_l00002ooooo`Co0000
5_ooool2o`00083ooooo000Looooo`03o`000?oooooooooo08Cooooo0_l0000=ooooo`;o000000?o
ooooo`000?l000005Oooool2o`0001Sooooo0_l00020ooooo`007?ooool00ol0003oooooooooo`20
ooooo`;o00000_ooool2o`000003ooooool0003o000000[ooooo0_l000000ooooooo0000o`00000H
ooooo`;o000000?oooooo`000?l00000U?ooool001cooooo00?o0000ooooooooool0O?ooool2o`00
00;ooooo1_l000000ooooooo0000o`000003ooooo`;o00002?ooool2o`0001Sooooo0_l000000ooo
oooo0000o`00002Dooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5
o`0000Kooooo00?o0000ooooooooool0H_ooool2o`0001Sooooo0_l00003ooooo`Go00001_ooool3
o`0000Oooooo0_l0000`ooooo`;o00001_ooool2o`0007Oooooo00001_ooooooMgMgoiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003ooooo
ooooo`1Rooooo`;o00007_ooool3o`0000Sooooo0_l000000ooooooo0000o`00000Iooooo`;o0000
6oooool2o`0000Kooooo0_l0001gooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0Loooool2o`00013ooooo0_l0
0009ooooo`;o00006Oooool2o`0000Gooooo1?l0000@ooooo`;o000000?oooooo`000?l00000O_oo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06
ooooo`?o0000Loooool2o`00013ooooo0_l0000Hooooo`;o00004Oooool4o`00013ooooo1Ol0001n
ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo
00Gooooo00?o0000ooooooooool0R_ooool4o`0000Oooooo1?l00006ooooo`;o00002oooool2o`00
01Cooooo0_l00004ooooo`;o0000Ooooool00003ooooool@413ooooo00;ooooo00?o410@oooooooo
ool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08[ooooo1?l00006ooooo`Go
00004oooool2o`0000[ooooo0_l00008ooooo`?o00000_ooool4o`000003ooooool0003o000007_o
oooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4006
ooooo`03o`000?oooooooooo07[ooooo0_l0000Hooooo`Co00008?ooool2o`0000Cooooo0_l00003
ooooo`;o00000_ooool7o`0007_ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo07[ooooo0_l00006ooooo`;o0000
4Oooool3o`0001cooooo0_l00002ooooo`;o00001?ooool2o`0000Oooooo0_l000001?oooooo0000
o`000?l00002ooooo`;o00000_ooool2o`0007Cooooo000Looooo`03o`000?oooooooooo06kooooo
0ol00002ooooo`;o00000oooool4o`0000Kooooo0_l0000?ooooo`Ko00006oooool2o`0001Cooooo
0_l00003ooooo`;o00000_ooool2o`0000Cooooo0_l0001^ooooo`007?ooool00ol0003ooooooooo
o`1Pooooo`;o00002oooool4o`0000;ooooo0_l00003ooooo`;o00004oooool2o`0000Cooooo1_l0
000Oooooo`;o00001Oooool2o`0000;ooooo0_l0000;ooooo`;o00001oooool2o`0006kooooo000L
ooooo`03o`000?oooooooooo063ooooo0_l00007ooooo`;o00000_ooool2o`0000Sooooo0_l0000:
ooooo`;o00001_ooool6o`0000;ooooo0_l0000Sooooo`;o00001Oooool2o`0000;ooooo0_l00000
0ooooooo0000o`000002ooooo`;o00000_ooool4o`0007Oooooo000Looooo`03o`000?oooooooooo
06Wooooo0_l0000<ooooo`;o00002_ooool2o`0000Kooooo0_l000001?oooooo0000o`000?l00006
ooooo`;o00008?ooool2o`0000Sooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool2
o`00013ooooo0_l0001Wooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o00000_ooool2o`00
01cooooo0_l00002ooooo`?o00001Oooool2o`000003ooooool0003o000000Oooooo0_l0000Poooo
o`;o00000oooool3o`0000?ooooo1?l0000Hooooo`;o0000Ioooool001cooooo00?o0000oooooooo
ool0GOooool2o`0000;ooooo0_l00008ooooo`;o00004Oooool3o`0000;ooooo0ol00005ooooo`;o
00000_ooool2o`0002gooooo0ol00003ooooo`;o00004Oooool4o`0000Gooooo0_l0001Wooooo`00
7?ooool00ol0003oooooooooo`1Pooooo`;o00001?ooool2o`000003ooooool0003o000000;o0000
3_ooool2o`000003ooooool0003o000000Cooooo0_l00009ooooo`;o0000:Oooool2o`0000cooooo
0_l0000<ooooo`Go00000_ooool2o`00017ooooo0_l0001Gooooo`007?ooool00ol0003ooooooooo
o`1Kooooo`;o00000oooool2o`0000Cooooo1Ol0000@ooooo`Co00001Oooool2o`0000Sooooo0_l0
0007ooooo`;o00006_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000<ooooo`;o00001ooo
ool2o`0000?ooooo0_l00005ooooo`;o00004Oooool2o`0005Oooooo000Looooo`03o`000?oooooo
oooo05_ooooo0_l0000:ooooo`;o00002_ooool4o`0000;ooooo0_l00002ooooo`;o00003oooool2
o`0000Oooooo0_l0000Jooooo`;o00000_ooool2o`0000gooooo1?l00007ooooo`;o0000M_ooool0
01cooooo00?o0000ooooooooool0Ioooool2o`0000Sooooo1ol000000ooooooo0000o`000004oooo
o`;o00001Oooool2o`0000oooooo0_l0000Oooooo`;o00002oooool3o`00087ooooo000Looooo`03
o`000?oooooooooo06Cooooo1Ol00002ooooo`;o00001?ooool2o`0000?ooooo0_l00007ooooo`Co
00000oooool2o`0000Oooooo0_l00006ooooo`;o00007oooool2o`0000Gooooo0_l00004ooooo`;o
0000P_ooool001cooooo0_l0001Uooooo`?o00001?ooool2o`0000oooooo0_l00003ooooo`;o0000
3?ooool2o`0000Gooooo0_l0000Wooooo`;o00002_ooool2o`0000Oooooo1?l00003ooooo`;o0000
00?oooooo`000?l00000JOooool001cooooo00?o0000ooooooooool0Coooool2o`0001[ooooo0_l0
0005ooooo`;o00000_ooool2o`0000Cooooo0_l00004ooooo`;o00001_ooool3o`0000;ooooo0_l0
0005ooooo`;o00006_ooool2o`0000[ooooo0_l00002ooooo`?o00001_ooool2o`000003ooooool0
003o000000Cooooo1?l00003ooooo`;o000000?oooooo`000?l00000JOooool001cooooo00?o0000
ooooooooool0Coooool2o`0001oooooo1?l00002ooooo`;o00002_ooool2o`0000?ooooo0_l00000
1?oooooo0000o`000?l0000Uooooo`;o00002?ooool4o`0000;ooooo1Ol00006ooooo`?o00002Ooo
ool2o`0006kooooo000Looooo`03o`000?oooooooooo06gooooo0_l000000ooooooo0000o`000008
ooooo`;o00000oooool2o`0000Kooooo0_l0000cooooo`;o00001oooool2o`0000Kooooo0ol00009
ooooo`;o00003Oooool2o`0005oooooo000Looooo`03o`000?oooooooooo06Cooooo0_l00007oooo
o`;o00002oooool2o`0000?ooooo0_l000000ooooooo0000o`00000>ooooo`;o00001_ooool2o`00
01Gooooo0_l00004ooooo`;o00005?ooool3o`00017ooooo1?l00003ooooo`;o0000Goooool001co
oooo00?o0000ooooooooool0H_ooool4o`0000_ooooo1?l00004ooooo`?o00001_ooool2o`0000ko
oooo0_l00006ooooo`;o00005Oooool2o`0000;ooooo1?l00008ooooo`;o00002oooool2o`0000Go
oooo0_l00006ooooo`;o00000_ooool4o`0006Cooooo000Looooo`03o`000?oooooooooo05?ooooo
1?l000000ooooooo0000o`000008ooooo`;o00003?ooool5o`0000Cooooo0_l0000Aooooo`?o0000
2Oooool2o`0001Wooooo2?l00006ooooo`;o00002oooool2o`0000Gooooo0_l00006ooooo`;o0000
J_ooool001cooooo00?o0000ooooooooool0Doooool4o`000003ooooool0003o000000?o00000ooo
ool4o`0000cooooo0_l0000Jooooo`?o00002Oooool2o`0001Wooooo0_l00002ooooo`Co00003?oo
ool2o`0000cooooo0_l0000@ooooo`;o00001Oooool2o`0005Wooooo000Looooo`03o`000?oooooo
oooo05Wooooo1?l00003ooooo`;o00006?ooool2o`0003[ooooo0_l0000?ooooo`;o00001Oooool2
o`0000Cooooo0ol0000@ooooo`;o00001Oooool2o`0005Wooooo000Looooo`03o`000?oooooooooo
04oooooo0_l00004ooooo`;o00003Oooool2o`0000Oooooo0_l00002ooooo`?o00001_ooool2o`00
00[ooooo0_l0000@ooooo`;o00007?ooool2o`0000Gooooo0_l0000=ooooo`Co00001?ooool3o`00
00Wooooo0_l0000Dooooo`;o0000DOooool001cooooo00?o0000ooooooooool0Coooool2o`0000?o
oooo0ol00006ooooo`;o00001Oooool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`?o
000000?oooooo`000?l000002Oooool2o`0000Cooooo0_l00005ooooo`;o00002Oooool2o`0000;o
oooo0_l0000Oooooo`;o000000?oooooo`000?l000000oooool2o`0000;ooooo1Ol0000@ooooo`Co
00005?ooool2o`00057ooooo000Looooo`03o`000?oooooooooo05Cooooo0_l00002ooooo`;o0000
0oooool2o`0000?ooooo0_l00003ooooo`;o00003?ooool2o`0000Gooooo0_l00002ooooo`;o0000
1Oooool2o`0000Cooooo0_l0000<ooooo`Co00007_ooool2o`000003ooooool0003o000000?ooooo
0_l00002ooooo`?o00000oooool2o`0000?ooooo0_l00008ooooo`;o00000oooool2o`0006Cooooo
000Looooo`03o`000?oooooooooo05;ooooo0ol00003ooooo`;o00002?ooool2o`0001?ooooo0ol0
00001?oooooo0000o`000?l00009ooooo`;o00001Oooool2o`0000_ooooo1?l0000@ooooo`;o0000
4oooool2o`0000Wooooo0_l00003ooooo`;o00001_ooool2o`0000Gooooo0_l0001Tooooo`007?oo
ool00ol0003oooooooooo`1Booooo`?o00000oooool4o`0000cooooo0_l0000=ooooo`Ko00004Ooo
ool2o`0000_ooooo0_l0000Booooo`;o00001?ooool2o`0000Gooooo0_l00006ooooo`;o00001ooo
ool2o`0000gooooo0_l00009ooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0E?ooool2
o`0000;ooooo1?l00006ooooo`;o00001?ooool2o`0000Kooooo0_l00007ooooo`?o00001?ooool2
o`0000Wooooo0_l0000>ooooo`;o000000?oooooo`000?l000000_l0000Aooooo`Go00001?ooool2
o`0000oooooo0_l0000Dooooo`;o00000_ooool4o`0005kooooo000Looooo`03o`000?oooooooooo
05;ooooo1?l00008ooooo`;o00000_ooool8o`0000Cooooo1?l00007ooooo`?o000000Coooooo`00
0?l0003ooooo0_l00009ooooo`;o00004Oooool4o`00017ooooo1ol0000>ooooo`;o00001?ooool2
o`0000Sooooo0_l00009ooooo`;o00000_ooool4o`0005kooooo000Looooo`;o0000Doooool3o`00
00Wooooo0_l00004ooooo`Ko00001?ooool4o`0000Gooooo2?l00006ooooo`;o00000oooool2o`00
00Wooooo0_l00006ooooo`Go00004oooool2o`000003ooooool0003o000000Wooooo0_l00003oooo
o`?o00000oooool2o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`00
00Gooooo1?l0001Oooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00003_ooool2o`0000ko
oooo1?l00006ooooo`Ko00000_ooool5o`000003ooooool0003o000000;ooooo0_l00003ooooo`;o
00000oooool2o`0000Wooooo0_l00006ooooo`;o00005_ooool2o`0000cooooo0_l00004ooooo`;o
00002Oooool2o`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l000001_l0001Oooooo`00
7?ooool00ol0003oooooooooo`10ooooo`;o00000_ooool2o`0000Wooooo0_l00003ooooo`;o0000
4?ooool2o`0000[ooooo0_l00002ooooo`Co00000oooool7o`0000Kooooo0_l00006ooooo`;o0000
6_ooool2o`000003ooooool0003o000002Wooooo0_l00004ooooo`Co00000_ooool2o`0005oooooo
000Looooo`03o`000?oooooooooo043ooooo0_l0000=ooooo`?o00002oooool2o`0000oooooo0_l0
0002ooooo`;o00001_ooool6o`0000;ooooo0_l0000>ooooo`;o00004?ooool2o`0000Sooooo0_l0
00000ooooooo0000o`00000Aooooo`;o00003oooool2o`0000Gooooo0_l0000:ooooo`;o000000?o
ooooo`000?l000003_ooool2o`0004cooooo000Looooo`03o`000?oooooooooo053ooooo1?l00009
ooooo`;o00003oooool2o`0000;ooooo0_l00004ooooo`co00001?ooool2o`0000?ooooo0_l0000E
ooooo`;o00005Oooool2o`0000;ooooo0_l00003ooooo`;o00002Oooool2o`0000Cooooo0_l00004
ooooo`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00000oooool2o`0000kooooo0_l0
001<ooooo`007?ooool00ol0003oooooooooo`1Booooo`;o00005Oooool2o`0000?ooooo0_l00004
ooooo`;o00000_ooool6o`000003ooooool0003o000000[o00000_ooool2o`000003ooooool0003o
000000?ooooo0_l0000Tooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000_ooooo0_l0
000:ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000002o`000004oooo
ool0003o0000o`0001Kooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`1Booooo`;o0000
5Oooool3o`0000;ooooo0_l00004ooooo`Co00000_ooool5o`000003ooooool0003o000000Wo0000
1Oooool2o`0000?ooooo0_l0000<ooooo`;o00001_ooool2o`0000cooooo0_l00003ooooo`;o0000
0_ooool2o`00023ooooo0_l00003ooooo`?o00005_ooool2o`0004Gooooo000Looooo`03o`000?oo
oooooooo05;ooooo0_l00009ooooo`;o00002oooool2o`0000Kooooo0_l00002ooooo`;o00000ooo
ool4o`000003ooooool0003o000000Wo00004oooool2o`0000?ooooo0_l00002ooooo`;o00000_oo
ool2o`0000cooooo0_l000000ooooooo0000o`000002o`0000Gooooo0_l000000ooooooo0000o`00
001oooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o00003Oooool2o`0000Sooooo0_l00009
ooooo`;o00001ooooolAo`0000?ooooo0_l0000;ooooo`Co00001oooool2o`0000;ooooo0_l00006
ooooo`;o000000?oooooo`000?l000000_ooool6o`0000Gooooo0_l000000ooooooo0000o`000004
ooooo`;o00002_ooool2o`0001Wooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`17oooo
o`;o00001Oooool2o`0000kooooo0_l00007ooooo`;o000000?oooooo`000?l000002?ooool2o`00
00Gooooo5_l000000ooooooo0000o`000008ooooo`;o00003Oooool2o`0000Kooooo0_l000000ooo
oooo0000o`000002ooooo`;o00004_ooool2o`0000[ooooo0_l00004ooooo`;o00001oooool3o`00
00Oooooo1?l0001Booooo`007?ooool00ol0003oooooooooo`16ooooo`?o000000?oooooo`000?l0
00000_l0000@ooooo`;o00001?ooool2o`000003ooooool0003o000000?o00002?ooool2o`0000?o
oooo6ol00004ooooo`;o00001Oooool2o`0000Wooooo0ol00005ooooo`;o00006?ooool2o`0000?o
oooo0_l00004ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Oooooo1_l00004ooooo`;o
000000?oooooo`000?l00000DOooool001cooooo00?o0000ooooooooool0AOooool3o`000003oooo
ool0003o000000Co00005Oooool2o`000003ooooool0003o000000;o00003?oooolFo`000003oooo
ool0003o000000Co00001?ooool2o`0000Gooooo0_l00009ooooo`?o00001Oooool2o`0001Kooooo
1?l00003ooooo`;o00001?ooool2o`0000;ooooo0_l0000>ooooo`Ko00001Oooool2o`00057ooooo
000Looooo`03o`000?oooooooooo03oooooo0_l00004ooooo`;o000000?oooooo`000?l000001ol0
0005ooooo`;o00005?ooool2o`0000Sooooo5ol000000ooooooo0000o`000004o`0000Kooooo0_l0
000[ooooo`Go00001?ooool2o`0000Wooooo1?l0000@ooooo`;o0000F?ooool001cooooo00?o0000
ooooooooool0?oooool2o`0000Oooooo0_l00003ooooo`Co00000oooool4o`0001Cooooo0_l00008
ooooo`;o00000_ooool7o`0000;ooooo3?l000000ooooooo0000o`000004ooooo`;o00000_ooool2
o`0001Gooooo0_l00002ooooo`;o00002Oooool2o`0000Cooooo1?l00006ooooo`;o00002oooool2
o`0001Oooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`16ooooo`Go00000_ooool2o`00
00Gooooo0_l0000Oooooo`go000000?oooooo`000?l000002_l000000ooooooo0000o`000004oooo
o`;o00001?ooool2o`0000kooooo0_l00003ooooo`;o00000_ooool2o`0000Wooooo0_l00004oooo
o`Co00002_ooool2o`0000Oooooo0ol0000Booooo`;o00000_ooool3o`0000Oooooo0_l00017oooo
o`007?ooool00ol0003oooooooooo`15ooooo`Ko00000_ooool2o`0000Gooooo0_l0000Kooooo`;o
00000_ooool=o`000003ooooool0003o000000[o000000?oooooo`000?l000000ol00002ooooo`;o
00000oooool2o`0000kooooo0ol0000=ooooo`;o00001Oooool7o`0000Wooooo0ol00002ooooo`;o
00001?ooool2o`0001;ooooo0_l00003ooooo`;o00001oooool2o`0004Oooooo000Looooo`;o0000
>_ooool2o`000003ooooool0003o000000Oooooo0_l0000;ooooo`Co00006Oooool4o`0000?ooooo
6_l000000ooooooo0000o`000002o`0000;ooooo0_l00003ooooo`;o00003oooool2o`0000gooooo
0_l00005ooooo`Go000000Coooooo`000?l0003o00000_ooool2o`0000?ooooo0_l000000ooooooo
0000o`000002o`0001Oooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`0iooooo`;o0000
00?oooooo`000?l000000_l0000<ooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`;o
00000oooool2o`0000?ooooo0_l00002ooooo`;o00001oooool2o`0000?ooooo7?l000000ooooooo
0000o`000002o`0000Oooooo1?l00006ooooo`;o00000oooool2o`0000Kooooo0_l0000>ooooo`;o
00001?ooool3o`000004ooooool0003o0000o`0000?ooooo0_l000000ooooooo0000o`000009oooo
o`;o00003?ooool4o`0000Oooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`0nooooo`;o
00000oooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000003ooooo`?o
000000?oooooo`000?l000000_l000001?oooooo0000o`000?ooool4o`0000;ooooo0_l0000<oooo
oa_o00000_ooool4o`0000Gooooo0_l000001?oooooo0000o`000?l00006ooooo`;o00000oooool2
o`0000Kooooo0_l0000>ooooo`Ko00000_ooool:o`000003ooooool0003o000000Wooooo0_l00005
ooooo`Co00000oooool2o`0000Wooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`0moooo
o`?o00000oooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000002o`00
0003ooooool0003o000000Cooooo0_l000001?oooooo0000o`000?ooool2o`0000kooooo1?l00000
0ooooooo0000o`00000No`0000Cooooo0ol000000ooooooo0000o`00000;ooooo`?o00002oooool2
o`0000;ooooo0ol00003ooooo`Oo00000_ooool3o`000003ooooool0003o000000Co00001?ooool2
o`0000gooooo1?l00002ooooo`Co00004oooool2o`0004;ooooo000Looooo`03o`000?oooooooooo
03gooooo0ol0000<ooooo`;o000000?oooooo`000?l000000_l0000:ooooo`Go00003_oooolAo`00
0005ooooool0003o0000o`000?ooool03_l00005ooooo`;o00001?ooool2o`0000Wooooo0ol00000
0ooooooo0000o`000002o`0000Kooooo0_l00002ooooo`?o00000oooool7o`000003ooooool0003o
000000;o00001?ooool4o`0000?ooooo0_l00002ooooo`?o000000?oooooo`000?l000001Oooool2
o`0000Cooooo1_l0000Aooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0AOooool2o`00
01;ooooo0_l00004ooooo`;o000000?oooooo`000?l000003?ooool2o`000003ooooool0003o0000
013o000000?oooooo`000?l000002?l000001?oooooo0000o`000?l0000;ooooo`;o00003Oooool4
o`0000[ooooo1?l000000ooooooo0000o`000006o`000003ooooool0003o000000[o00000oooool2
o`0000;ooooo0ol000000ooooooo0000o`000002o`0000?ooooo0_l00005ooooo`;o000000?ooooo
o`000?l00000EOooool001cooooo00?o0000ooooooooool0AOooool2o`0000Cooooo0_l00007oooo
o`;o00000oooool2o`0000Oooooo0_l0000;ooooo`?o000000?oooooo`000?l000000_l000000ooo
oooo0000o`00000Fo`0000[ooooo0_l00004ooooo`;o00005?ooool3o`0000;ooooo1Ol000001Ooo
oooo0000o`000?l0003ooooo00Go00000_ooool7o`0000Sooooo0_l000001?oooooo0000o`000?oo
ool4o`0000Wooooo0ol000000ooooooo0000o`00000Eooooo`;o0000?_ooool001cooooo00?o0000
ooooooooool0Boooool2o`0000;ooooo1?l000000ooooooo0000o`00000;ooooo`Co00002_ooool3
o`0000;ooooo0ol000000ooooooo0000o`00000Ho`0000Sooooo0_l00004ooooo`;o00005?ooool3
o`000004ooooool0003o0000o`0000;ooooo1ol00002ooooo`?o000000?oooooo`000?l000001Ol0
0004ooooo`;o00000_ooool2o`000003ooooool0003o000000?o00001Oooool2o`0000Cooooo0_l0
000<ooooo`;o00001?ooool2o`0000Gooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0l
ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Cooooo0_l000000ooooooo0000o`000003
o`0000gooooo1Ol0000;ooooo`;o00000_oooolPo`0000Gooooo0_l0000<ooooo`?o00002?ooool2
o`0000Kooooo0_l00002ooooo`Go000000Goooooo`000?l0003o0000ooooo`03o`000003ooooool0
003o000000Go00001?ooool2o`000004ooooool0003o0000o`0000;ooooo0_l00007ooooo`;o0000
3oooool2o`000003ooooool0003o000000Cooooo0_l00015ooooo`007?ooool00ol0003ooooooooo
o`0looooo`;o000000?oooooo`000?l000001?ooool3o`0000?ooooo0_l000000ooooooo0000o`00
0007ooooo`;o00000_ooool2o`0000?ooooo0_l0000Boooooaco00000_ooool2o`0000Gooooo0_l0
0007ooooo`;o00000oooool3o`0000Sooooo1Ol000000ooooooo0000o`00000Bo`000003ooooool0
003o000000Go00001_ooool3o`0000;ooooo0_l0000Hooooo`;o0000C_ooool001cooooo00?o0000
ooooooooool0??ooool2o`0000Sooooo0_l00003ooooo`;o000000?oooooo`000?l000001oooool2
o`0000;ooooo0_l00004ooooo`;o00003oooool3o`000004ooooool0003o0000oooooaOo00000ooo
ool2o`0000gooooo0_l0000?ooooo`Oo00000_ooool4o`0000;ooooo3Ol00003ooooo`Oo00006_oo
ool2o`0005Cooooo000Looooo`03o`000?oooooooooo03cooooo0_l00002ooooo`Co00003?ooool3
o`0000kooooo0_l0000;ooooo`?o000000Goooooo`000?l0003o0000ooooo`0;o`000003ooooool0
003o000000co00000oooool2o`00023ooooo1Ol000001?oooooo0000o`000?oooolMo`0000?ooooo
0ol0000Booooo`;o0000E?ooool001cooooo00?o0000ooooooooool0>oooool2o`0000?ooooo1?l0
0008ooooo`;o000000?oooooo`000?l000000_l00009ooooo`;o00003?ooool2o`0000;ooooo0ol0
0002ooooo`;o000000?oooooo`000?l000004_l000000ooooooo0000o`000003o`0000Oooooo0_l0
000Iooooo`So000000?oooooo`000?l000007_l00003ooooo`?o00001?ooool2o`00023ooooo0_l0
0010ooooo`007?ooool00ol0003oooooooooo`0eooooo`;o00001?ooool2o`0000oooooo0_l00000
0ooooooo0000o`000003ooooo`;o00001_ooool2o`0000Sooooo0_l00002ooooo`;o00002_oooolI
o`0000Sooooo0_l0000:ooooo`;o00003Oooool7o`000003ooooool0003o000000Co000000?ooooo
o`000?l000005_l000000ooooooo0000o`000009ooooo`;o00008?ooool2o`00043ooooo00001_oo
ooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?oo
ool00ol0003oooooooooo`0eooooo`;o00000_ooool4o`0000oooooo0_l00004ooooo`Co00002_oo
ool4o`0000;ooooo0_l00002ooooo`?o00002?oooolLo`000003ooooool0003o000000oooooo0_l0
000;ooooo`;o00001Oooool2o`000003ooooool0003o000001co000000?oooooo`000?l000001?l0
000Hooooo`?o00003Oooool2o`00043ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo
0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>Oooool2o`0000Kooooo
0_l0000:ooooo`;o00000oooool2o`0000;ooooo0_l00007ooooo`Go00001_ooool3o`0000Sooooo
0_l00002oooooaSo000000Coooooo`000?l0003ooooo1_l0000?ooooo`;o00001?ooool4o`0000?o
oooo0_l000001Ooooooo0000o`000?l0003ooooo01go000000Coooooo`000?l0003o00003?ooool3
o`0000Wooooo0ol00002ooooo`Co00001Oooool2o`0004;ooooo00000ooooooo410@ooooo`02oooo
o`03oa0@4?oooooooooo00Wooooo1Ol00006ooooo`03o`000?oooooooooo047ooooo0_l00008oooo
o`Co00001?ooool2o`000003ooooool0003o000000Oooooo0ol0000GoooooaKo00001_ooool6o`00
00oooooo0_l000001?oooooo0000o`000?ooool4o`0000?ooooo9?l000000ooooooo0000o`000003
ooooo`?o00001?ooool2o`000004ooooool0003o0000o`0000?ooooo0_l00008ooooo`Go00001Ooo
ool2o`0004;ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CoA4A4
omgMgOoooooo00001oooool3o`0003Wooooo0_l00006ooooo`;o00002?ooool2o`0000Gooooo0ol0
00000ooooooo0000o`000002ooooo`;o00007Oooool2o`000003ooooool0003o000001;o00003_oo
ool2o`0000Wooooo0_l00002ooooo`Co00000oooool[o`0000;ooooo0ol00004ooooo`;o00000ooo
ool2o`0000;ooooo0_l00008ooooo`;o0000C?ooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool02Oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo03Wooooo0_l0
0006ooooo`;o00001Oooool2o`0000;ooooo0_l00004ooooo`;o00001_ooool2o`0000Gooooo0_l0
000;ooooo`;o00003?oooolDo`0000;ooooo0_l00009ooooo`?o00002Oooool2o`0000Cooooo0_l0
0002ooooobWo000000?oooooo`000?l000003_ooool2o`0005[ooooo00000ooooooo410@ooooo`02
ooooo`03oa0@4?oooooooooo00[ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0k
ooooo`;o00002oooool2o`0000;ooooo1?l00009ooooo`;o00001_ooool2o`0000Sooooo1Ol0000:
oooooaGo00000_ooool3o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000001oooool2
o`0000Kooooo9ol000000ooooooo0000o`000003o`0000;ooooo0_l0000Mooooo`;o0000Boooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oo
oooooooo03Sooooo1Ol0000Aooooo`;o00002Oooool6o`0000cooooo1?l00007ooooo`;o000000Go
ooooo`000?l0003o0000ooooo`05o`000003ooooool0003o000000?o00000oooool8o`000003oooo
ool0003o000000Ko000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l00006ooooo`Oo0000
00?oooooo`000?l000004Ol000000ooooooo0000o`000005o`0000;ooooo2?l000001?oooooo0000
o`000?l0000Aooooo`;o00002_ooool2o`0004_ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^
kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`0hooooo`Co00002oooool2o`00
013ooooo1_l0000Gooooo`;o000000Coooooo`000?l0003ooooo0_l00006ooooo`Co00001Oooool4
o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l0000<ooooo`;o00000_ooool2
o`000003ooooool0003o0000013o000000?oooooo`000?l000005?l0000>ooooo`;o000000?ooooo
o`000?l000004?ooool2o`0000Oooooo0_l0000looooo`007?ooool00ol0003oooooooooo`11oooo
o`;o00001?ooool2o`0001kooooo0_l0000=ooooo`;o00001?ooool2o`0000Cooooo0_l00002oooo
o`;o00004?ooool3o`0000_ooooo0_l00003ooooo`;o000000?oooooo`000?l000000ol00003oooo
oaOo00000_oooolAo`0000Gooooo0_l00005ooooo`?o00003?ooool2o`0000Gooooo0_l00007oooo
o`;o0000??ooool001cooooo00?o0000ooooooooool0@Oooool2o`0000_ooooo0_l0000Gooooo`;o
00001oooool2o`00013ooooo0_l000000ooooooo0000o`000002o`00013ooooo0_l00002ooooo`;o
000000?oooooo`000?l000001?ooool2o`0000?ooooo0_l000000ooooooo0000o`000005o`000003
ooooool0003o000002Go000000?oooooo`000?l000001Oooool2o`0000Gooooo0_l0000<ooooo`?o
00002?ooool2o`0000;ooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`14ooooo`;o0000
0_ooool2o`0000Cooooo0_l0000Pooooo`;o00004?ooool2o`000003ooooool0003o000000;o0000
3Oooool2o`0000Gooooo0_l000000ooooooo0000o`000005ooooo`;o00001?ooool2o`0000;ooooo
:Ol000001?oooooo0000o`000?ooool2o`0000?ooooo0_l0000<ooooo`;o00001oooool3o`000003
ooooool0003o000000Gooooo0_l00002ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0
>oooool2o`0000Oooooo0_l00002ooooo`;o00001_ooool2o`0003Oooooo0_l0000:ooooo`?o0000
0_ooool3o`0000[ooooo0_l00003ooooo`?o00000_ooool2o`000003ooooool0003o000002Co0000
1?ooool2o`0000?ooooo0_l00002ooooo`Co000000?oooooo`000?l000000oooool4o`0000Wooooo
0_l00005ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0=?ooool2o`0000Gooooo0_l0
0007ooooo`?o00002Oooool2o`000003ooooool0003o000000gooooo0_l0000:ooooo`;o00000ooo
ool2o`0000cooooo0_l00006ooooo`;o00002_ooool2o`0000?ooooo0ol0000?ooooo`Ko00000_oo
ool8o`000003ooooool0003o000001ko00001Oooool2o`0000?ooooo1ol00004ooooo`?o0000E?oo
ool001cooooo00?o0000ooooooooool0=?ooool2o`0000kooooo0ol00006ooooo`Go000000?ooooo
o`000?l000003?ooool3o`0000Cooooo0_l00004ooooo`;o00000oooool2o`000003ooooool0003o
000000Wooooo0_l00004ooooo`;o00000_ooool2o`0000gooooo0_l0000>ooooo`;o000000?ooooo
o`000?l000000ol00002oooooaoo00000_ooool8o`000003ooooool0003o000000;ooooo0_l00007
ooooo`;o00000_ooool3o`0000Cooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`0]oooo
o`;o00001oooool2o`0000gooooo0_l00006ooooo`Co00004?ooool2o`0000Gooooo0_l00005oooo
o`;o00001Oooool2o`0000Kooooo0_l00007ooooo`;o00000_ooool2o`0001gooooo0_l00003oooo
oa7o000000?oooooo`000?l000004?l000000ooooooo0000o`000007o`000003ooooool0003o0000
00;o00002Oooool2o`0000;ooooo0ol00004ooooo`;o0000DOooool001cooooo00?o0000oooooooo
ool0;Oooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0000Gooooo0ol00002oooo
o`;o00001oooool3o`0000;ooooo0_l00009ooooo`;o000000?oooooo`000?l000003?ooool2o`00
00Oooooo0_l00004ooooo`;o00006oooool2o`0000gooooo0_l000000ooooooo0000o`00000^o`00
00;ooooo0ol00002ooooo`;o00001?ooool3o`0000?ooooo0_l0000@ooooo`Co0000@oooool001co
oooo00?o0000ooooooooool0<oooool2o`0000Cooooo0_l00005ooooo`?o00000_ooool2o`0000Go
oooo1?l00003ooooo`?o00002?ooool2o`000003ooooool0003o000000Cooooo0_l0000?ooooo`;o
00001?ooool2o`0000Kooooo0ol0000Booooo`?o00003?ooool2o`000003ooooool0003o000000;o
00001?ooool:o`000003ooooool0003o000001_o00001oooool2o`0000Cooooo0_l0000Fooooo`Co
00000oooool2o`0003kooooo000Looooo`03o`000?oooooooooo03?ooooo0_l0000<ooooo`;o0000
2Oooool3o`0000;ooooo0_l000000ooooooo0000o`00000Aooooo`?o000000?oooooo`000?l00000
1Oooool4o`0000Sooooo0_l00006ooooo`?o00004_ooool3o`0000Wooooo0_l00004ooooo`?o0000
0_ooool2o`000003ooooool0003o000002;o00001?ooool3o`0000?ooooo0_l00002ooooo`;o0000
6Oooool3o`0000Cooooo0_l00006ooooo`;o0000=_ooool001cooooo00?o0000ooooooooool0<Ooo
ool4o`0001Kooooo1?l00002ooooo`;o00005Oooool7o`000003ooooool0003o000000Co00002?oo
ool2o`0000Cooooo0_l00005ooooo`;o00001Oooool2o`0000?ooooo0_l00002ooooo`;o00002_oo
ool2o`0000Cooooo0ol00002ooooobOo00000_ooool5o`0000?ooooo0_l00002ooooo`;o00006Ooo
ool2o`0000gooooo0_l0000fooooo`007?ooool2o`0003;ooooo0_l0000=ooooo`;o000000?ooooo
o`000?l000000oooool2o`000004ooooool0003o0000o`0001_ooooo1_l000000ooooooo0000o`00
0002ooooo`;o00001oooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000?ooooo0_l0
000>ooooo`;o00001ooooolYo`000003ooooool0003o000000?o00004_ooool2o`0000gooooo1?l0
0015ooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00001Oooool2o`0000;ooooo0_l00002
ooooo`;o000000?oooooo`000?l000000oooool2o`0000;ooooo0_l0000Hooooo`?o000000?ooooo
o`000?l000002?ooool3o`0000Gooooo0ol0000;ooooo`;o00003_ooool4o`0000Wooooo0_l00003
ooooo`;o00000_ooool5o`0000;ooooo7ol00002ooooo`Co00001Oooool2o`0000?ooooo0_l00002
ooooo`;o000000?oooooo`000?l000000_ooool2o`0000gooooo0ol00005ooooo`;o00002Oooool2
o`0003Cooooo000Looooo`03o`000?oooooooooo037ooooo0_l00005ooooo`;o00000_ooool2o`00
00Cooooo0_l00003ooooo`;o00007Oooool3o`0000cooooo0_l00005ooooo`;o00003?ooool2o`00
00kooooo1?l000000ooooooo0000o`00000;ooooo`?o000000Coooooo`000?l0003ooooo0_l00003
ooooo`Wo00000ooooolBo`0000;ooooo1?l00002ooooo`;o000000?oooooo`000?l000000oooool2
o`0000;ooooo0_l000000ooooooo0000o`00000Iooooo`;o00002?ooool3o`0003Cooooo000Loooo
o`03o`000?oooooooooo03Gooooo0_l0000;ooooo`;o00000oooool2o`0001Sooooo0_l00003oooo
o`;o00000_ooool2o`0000gooooo0_l0000Looooo`;o00000_ooool2o`0000;ooooo0_l00008oooo
o`;o00000_ooool2o`0000Gooooo0_l000001?oooooo0000o`000?ooool8o`000003ooooool0003o
0000017o00000oooool7o`0000?ooooo0_l00005ooooo`;o00009_ooool2o`0003Gooooo000Loooo
o`03o`000?oooooooooo037ooooo0_l00002ooooo`;o00003Oooool2o`00017ooooo0_l000000ooo
oooo0000o`000002ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000002oooo
o`;o00003Oooool2o`0001cooooo0_l00002ooooo`;o00003?ooool2o`0000Kooooo1Ol000000ooo
oooo0000o`000009o`000003ooooool0003o000000ko000000?oooooo`000?l000001Ol000000ooo
oooo0000o`000005ooooo`;o0000I?ooool001cooooo00?o0000ooooooooool0<Oooool2o`0000;o
oooo0_l0000=ooooo`;o00001_ooool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo
0000o`00000<o`0000cooooo0_l00003ooooo`;o00006?ooool2o`0000Oooooo0_l00003ooooo`Co
00003_oooolSo`0000;ooooo1_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Roooo
o`;o0000@?ooool001cooooo00?o0000ooooooooool0:Oooool2o`0000_ooooo0_l000000ooooooo
0000o`00000<ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000003ooooo`?o
000000Coooooo`000?l0003ooooo2Ol00009ooooo`;o00000_ooool4o`000003ooooool0003o0000
01Sooooo0_l00005ooooo`Co00000oooool4o`0000Wooooo0_l00002ooooo`?o00000_ooool3o`00
0003ooooool0003o000001Wo00001_ooool:o`0000Gooooo0_l00002ooooo`;o00001?ooool2o`00
01?ooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0Yooooo`;o00002Oooool4o`000003
ooooool0003o000000[ooooo1?l000000ooooooo0000o`000002ooooo`;o00000_ooool5o`0000Co
oooo0ol00009ooooo`;o00000_ooool4o`0000?ooooo0ol0000Eooooo`;o00002oooool2o`0001;o
oooo0_l00002ooooo`;o000000?oooooo`000?l000000ol00004ooooo`So000000?oooooo`000?l0
00003?l00008ooooo`?o000000Coooooo`000?l0003ooooo0_l00003ooooo`Co000000Coooooo`00
0?l0003o00001?ooool2o`0000gooooo0_l00002ooooo`;o0000@_ooool001cooooo00?o0000oooo
ooooool0<?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000<ooooo`;o00001oooool2o`00
00;ooooo1?l00006ooooo`;o00002Oooool2o`0000;ooooo0_l00005ooooo`Co00001oooool3o`00
00[ooooo0_l00007ooooo`Co00000oooool2o`0001?ooooo1Ol000001?oooooo0000o`000?l00007
oooooa?o000000Coooooo`000?l0003ooooo0_l0000>ooooo`;o00000oooool3o`0000Sooooo0_l0
0004ooooo`;o00000oooool2o`0000;ooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`0`
ooooo`;o00001Oooool2o`0000oooooo0_l0000Kooooo`;o00000oooool6o`000003ooooool0003o
000000Co000000?oooooo`000?l000000oooool3o`0001?ooooo1?l00003ooooo`;o00000oooool3
o`0000gooooo1?l00002ooooo`?o000000Coooooo`000?l0003o00000oooool7o`000003ooooool0
003o000000Wo000000Coooooo`000?l0003ooooo0ol00006ooooo`;o00001Oooool2o`0000kooooo
0_l00004ooooo`;o00001oooool6o`0000cooooo0_l0000`ooooo`007?ooool00ol0003ooooooooo
o`0]ooooo`;o00000oooool2o`00013ooooo0_l00002ooooo`;o00000oooool2o`00017ooooo0_l0
0003ooooo`;o00000oooool=o`000003ooooool0003o000000Gooooo0_l000000ooooooo0000o`00
0002ooooo`;o000000Coooooo`000?l0003ooooo0_l00005ooooo`;o00002_ooool3o`0000;ooooo
0_l00004ooooo`;o00003Oooool:o`000004ooooool0003o0000ooooo`_o00001Oooool3o`0000Go
oooo0_l00005ooooo`;o00001_ooool2o`0000?ooooo0_l000000ooooooo0000o`00000<ooooo`Wo
00002_ooool2o`00033ooooo000Looooo`03o`000?oooooooooo02gooooo0_l00003ooooo`?o0000
3oooool2o`0000;ooooo0_l000000ooooooo0000o`000004o`000003ooooool0003o000000cooooo
0_l00007oooooa3o00001Oooool3o`000003ooooool0003o000000;ooooo0_l000001?oooooo0000
o`000?ooool2o`00017ooooo1?l000000ooooooo0000o`000004ooooo`;o00002OoooolGo`0000?o
oooo0_l000000ooooooo0000o`000004ooooo`;o00001_ooool2o`0000?ooooo0_l00002ooooo`;o
000000?oooooo`000?l000000_l00003ooooo`Go00003?ooool2o`0000Gooooo0_l0000looooo`00
7?ooool00ol0003oooooooooo`0Tooooo`;o00002Oooool2o`0000;ooooo0_l00009ooooo`;o0000
00Coooooo`000?l0003ooooo0_l00002ooooo`Go000000Goooooo`000?l0003o0000ooooo`02o`00
00;ooooo0_l00002ooooo`;o00003OoooolAo`0000Cooooo0_l00005ooooo`?o00006Oooool2o`00
01;ooooo1?l000000ooooooo0000o`00000>o`000003ooooool0003o000000Gooooo1?l00002oooo
o`;o00001_ooool3o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000001Oooool3o`00
0003ooooool0003o0000053ooooo000Looooo`03o`000?oooooooooo02Cooooo0_l00009ooooo`?o
00003?ooool2o`000003ooooool0003o000000Oooooo1_l00006ooooo`;o00000_ooool2o`0000go
oooo4Ol00009ooooo`Co00006Oooool3o`0000Sooooo0_l00006ooooo`?o000000Coooooo`000?l0
003ooooo1ol00003ooooo`?o000000Coooooo`000?l0003ooooo1?l00005ooooo`?o00002?ooool4
o`0000Oooooo0ol00006ooooo`;o00000_ooool2o`0001_ooooo0_l0000cooooo`007?ooool00ol0
003oooooooooo`0/ooooo`;o00000_ooool2o`0001[ooooo0_l0000Dooooo`;o00001OoooolAo`00
00Wooooo1?l00008ooooo`;o00003oooool4o`0000Oooooo0_l00006ooooo`?o000000?oooooo`00
0?l000000oooool4o`0000Cooooo0ol000000ooooooo0000o`000003ooooo`;o00001_ooool2o`00
00Sooooo0_l00009ooooo`?o00009oooool2o`0003?ooooo000Looooo`03o`000?oooooooooo02co
oooo1?l0000/ooooo`;o00001?ooool2o`000004ooooool0003o0000oooooa;o000000?oooooo`00
0?l000002?ooool2o`0000Sooooo0_l00003ooooo`;o00002_ooool4o`0000kooooo0_l00003oooo
o`;o000000?oooooo`000?l000001Ol000000ooooooo0000o`000007ooooo`;o00000oooool3o`00
00;ooooo0ol00007ooooo`?o00002Oooool2o`0005cooooo000Looooo`;o0000;oooool2o`0000co
oooo0_l0000Mooooo`?o00001ooooolHo`00017ooooo0_l00004ooooo`;o00002_ooool6o`0000co
oooo0_l00006ooooo`;o00000_ooool3o`000003ooooool0003o000000Oooooo0_l00003ooooo`?o
00000_ooool5o`0000;ooooo1_l0000@ooooo`;o00004oooool2o`00043ooooo000Looooo`03o`00
0?oooooooooo03_ooooo0ol00004ooooo`?o00005_ooool3o`0000Wooooo1?l000000ooooooo0000
o`00000?o`0000Wooooo0_l00006ooooo`;o000000?oooooo`000?l000003_ooool5o`00017ooooo
0_l00003ooooo`;o00006_ooool2o`0000;ooooo1?l0000>ooooo`;o000000Coooooo`000?l0003o
00004oooool2o`00043ooooo000Looooo`03o`000?oooooooooo02gooooo0ol000000ooooooo0000
o`000008ooooo`;o00000_ooool2o`000005ooooool0003o0000o`000?ooool00_l00009ooooo`;o
00002Oooool2o`0000Wooooo6_l00005ooooo`;o000000?oooooo`000?l000001_ooool2o`0000ko
oooo0_l00007ooooo`;o00002oooool2o`0000;ooooo0ol00005ooooo`Co00001_ooool2o`0000co
oooo1?l00004ooooo`;o00000oooool4o`0000;ooooo0_l000000ooooooo0000o`00000Dooooo`;o
0000@?ooool001cooooo00?o0000ooooooooool0;Oooool3o`000003ooooool0003o000000cooooo
1?l00003ooooo`;o00000_ooool3o`0000Cooooo0_l00003ooooo`?o00003_oooolJo`0000?ooooo
0_l000000ooooooo0000o`000002o`0001;ooooo0_l00003ooooo`;o00001_ooool2o`0000Oooooo
0_l00004ooooo`Co00001Oooool5o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`;o0000
1oooool4o`0000Cooooo0_l00003ooooo`Co00001Oooool3o`0001?ooooo0_l00010ooooo`007?oo
ool00ol0003oooooooooo`0^ooooo`;o000000?oooooo`000?l000003Oooool3o`0000Oooooo1?l0
0008ooooo`?o00003_oooolHo`0000Cooooo0ol000000ooooooo0000o`00000Dooooo`;o00000ooo
ool2o`0000Gooooo0_l00006ooooo`Go00000oooool4o`0000Gooooo1?l00004ooooo`;o00001_oo
ool2o`0000cooooo0_l000000ooooooo0000o`000002ooooo`;o00002?ooool3o`00017ooooo0_l0
0002ooooo`;o00003?ooool2o`00033ooooo000Looooo`03o`000?oooooooooo037ooooo0_l0000I
ooooo`;o00005Oooool2o`0000;ooooo6?l00002ooooo`Co00001?ooool2o`0001[ooooo0_l00002
ooooo`;o00001_ooool5o`0000Gooooo0_l00004ooooo`;o00001_ooool3o`000003ooooool0003o
000000cooooo0_l00003ooooo`Wo00002?ooool5o`0000oooooo0_l00002ooooo`;o00003?ooool2
o`00033ooooo000Looooo`03o`000?oooooooooo03Cooooo0_l0000:ooooo`;o00001Oooool2o`00
00Wooooo0ol00006ooooo`?o00001Oooool2o`0000;ooooo2_l00003ooooo`oo00001_ooool2o`00
00Sooooo0_l00005ooooo`;o00001?ooool2o`000003ooooool0003o000000;o00003?ooool2o`00
00cooooo0_l00006ooooo`?o000000Coooooo`000?l0003o00002oooool3o`0000?ooooo0ol00000
0ooooooo0000o`000006ooooo`;o00000oooool4o`0001?ooooo0_l00002ooooo`;o00004Oooool2
o`0002Oooooo000Looooo`03o`000?oooooooooo02kooooo0_l00004ooooo`;o00002_ooool2o`00
00Gooooo0_l00002ooooo`;o00001Oooool4o`0000Gooooo0ol00009oooooa_o00000_ooool2o`00
0003ooooool0003o000000[ooooo0_l00005ooooo`;o00001?ooool2o`000003ooooool0003o0000
00Wooooo0_l00002ooooo`?o00004oooool2o`0000Cooooo0ol0000;ooooo`;o00003oooool2o`00
00?ooooo0ol0000?ooooo`;o00000oooool2o`0000;ooooo0_l0000Aooooo`;o00009oooool001co
oooo00?o0000ooooooooool0:Oooool4o`000003ooooool0003o000000Cooooo0_l00008ooooo`;o
00002oooool2o`0000Oooooo0_l000000ooooooo0000o`000002ooooo`;o00002_oooolKo`000005
ooooool0003o0000o`000?ooool00_l0000<ooooo`;o00001Oooool2o`0000;ooooo0_l0000<oooo
o`;o00000_ooool2o`0000[ooooo0_l00008ooooo`;o00001Oooool2o`0000Cooooo0_l0000]oooo
o`;o0000@oooool001cooooo00?o0000ooooooooool0:Oooool4o`0000;ooooo0_l0000;ooooo`Co
00001?ooool2o`00017ooooo0_l00003ooooo`;o000000?oooooo`000?l000001_ooool5o`000003
ooooool0003o000001;o00000_ooool2o`0000Oooooo1?l00003ooooo`Co00001Oooool2o`0000;o
oooo0_l00004ooooo`Go00004oooool2o`0000;ooooo0_l00002ooooo`;o00001_ooool3o`0000Co
oooo0_l0000Eooooo`;o00000_ooool2o`0001?ooooo0_l00005ooooo`;o0000>oooool001cooooo
00?o0000ooooooooool09oooool2o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0000Kooooo
0ol00003ooooo`Co00000oooool2o`00017ooooo0_l000000ooooooo0000o`000004ooooo`?o0000
00?oooooo`000?l000005_l0000;ooooo`Co00000oooool2o`000003ooooool0003o000000?o0000
1Oooool3o`0000?ooooo1Ol00004ooooo`;o00002_ooool2o`0000Cooooo0ol00002ooooo`Co0000
1?ooool3o`0000oooooo0_l000000ooooooo0000o`000002o`0000Gooooo0_l00002ooooo`?o0000
4_ooool2o`0000Gooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0Wooooo`;o00000_oo
ool3o`000003ooooool0003o000000?ooooo0_l00005ooooo`Co00000oooool2o`0000?ooooo1?l0
000Cooooo`;o00001Oooool3o`000003ooooool0003o000001Ko00001Oooool2o`0000kooooo1Ol0
0005ooooo`?o00000oooool2o`0000?ooooo0_l00002ooooo`?o000000?oooooo`000?l000001_oo
ool4o`0000;ooooo1?l00003ooooo`;o00002oooool4o`0000Oooooo0_l000000ooooooo0000o`00
0002o`0000Gooooo1?l000000ooooooo0000o`00000@ooooo`;o000000Coooooo`000?l0003o0000
4?ooool2o`0002kooooo000Looooo`03o`000?oooooooooo02Sooooo0ol000000ooooooo0000o`00
000=ooooo`;o00000oooool2o`0000Gooooo0_l00002ooooo`;o00004Oooool2o`0000Sooooo5Ol0
00001?oooooo0000o`000?l00005ooooo`;o00008oooool3o`0000;ooooo0_l000000ooooooo0000
o`000008ooooo`;o00001?ooool2o`00013ooooo1?l0000Eooooo`Oo00003?ooool4o`000003oooo
ool0003o000000;o00003oooool2o`0002kooooo000Looooo`03o`000?oooooooooo02Sooooo0ol0
000Aooooo`;o00000_ooool2o`0000Gooooo0ol000000ooooooo0000o`00000<ooooo`;o00000ooo
ool2o`0000Kooooo5ol0000Rooooo`;o00002oooool6o`0000[ooooo0_l00004ooooo`;o00004ooo
ool2o`0000Cooooo0_l000000ooooooo0000o`00000>ooooo`Go000000?oooooo`000?l000002Ooo
ool2o`0000;ooooo0_l000000ooooooo0000o`00000oooooo`007?ooool00ol0003oooooooooo`0l
ooooo`;o00001oooool2o`000003ooooool0003o000000oooooo0_l00003ooooo`;o00001_ooool2
o`0000;ooooo4_l00003ooooo`?o00003_ooool2o`0000?ooooo0_l00008ooooo`;o00003?ooool3
o`0000cooooo0_l00004ooooo`;o00004oooool2o`0000Cooooo0_l000000ooooooo0000o`000002
o`0000Oooooo0_l00009ooooo`;o00003Oooool2o`0004;ooooo000Looooo`03o`000?oooooooooo
02Oooooo0_l000000ooooooo0000o`00000Iooooo`;o00001oooool2o`0000Cooooo0_l0000:oooo
o`;o00002?oooolCo`000003ooooool0003o000000;o00001_ooool2o`0000?ooooo0_l000000ooo
oooo0000o`000005o`0001Wooooo0_l00003ooooo`;o00009Oooool3o`0000?ooooo0_l000000ooo
oooo0000o`000004ooooo`;o00001?ooool2o`0001Cooooo0ol00003ooooo`;o0000>_ooool001co
oooo0_l0000Xooooo`;o000000?oooooo`000?l000003oooool2o`00017ooooo0_l000000ooooooo
0000o`000003o`0000Gooooo0_l00003ooooo`;o00002?oooolFo`0000Kooooo1?l00003ooooo`;o
000000?oooooo`000?l000001?l0000Fooooo`;o00000_ooool2o`0000?ooooo0_l0000Iooooo`;o
000000?oooooo`000?l000001oooool3o`0000Kooooo0_l000000ooooooo0000o`000007ooooo`;o
00005?ooool3o`0000?ooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`0Vooooo`;o0000
0_ooool2o`0000?ooooo0_l0000:ooooo`;o00002Oooool2o`0000Wooooo0ol00006ooooo`?o0000
00?oooooo`000?l000002OoooolFo`0000Oooooo0_l00002ooooo`;o000000?oooooo`000?l00000
2Oooool2o`0001;ooooo1?l00002ooooo`;o00004Oooool2o`0000;ooooo0_l00005ooooo`Go0000
00?oooooo`000?l000004?ooool2o`0000Sooooo0_l0000Aooooo`Co0000@?ooool001cooooo00?o
0000ooooooooool09_ooool2o`0000Oooooo0_l0000Eooooo`;o00002?ooool4o`000004ooooool0
003o0000o`0000;ooooo2?l00007oooooaOo00002_ooool2o`0000?ooooo0_l00007ooooo`;o0000
00?oooooo`000?l000004Oooool2o`0000;ooooo0_l0000Aooooo`;o00000_ooool5o`0000?ooooo
0_l00003ooooo`;o00001?ooool2o`0000Wooooo0_l00009ooooo`?o00003_ooool6o`0000;ooooo
0_l0000looooo`007?ooool00ol0003oooooooooo`0aooooo`;o00004Oooool2o`0000[ooooo1?l0
00000ooooooo0000o`000003o`000004ooooool0003o0000o`0000;ooooo0_l000001?oooooo0000
o`000?l00002ooooo`;o00000oooool=o`0000;ooooo1?l0000?ooooo`;o000000Coooooo`000?l0
003o00000_ooool2o`0000;ooooo1Ol00006ooooo`;o00003?ooool3o`0000gooooo0_l00002oooo
o`;o000000Coooooo`000?l0003o00002?ooool2o`0000Cooooo0_l000000ooooooo0000o`000006
ooooo`;o00000_ooool2o`0000;ooooo0_l00002ooooo`;o00003_ooool2o`0000Kooooo0_l0000:
ooooo`;o0000<?ooool001cooooo00?o0000ooooooooool0<Oooool3o`00013ooooo0_l0000<oooo
o`;o000000?oooooo`000?l000000ol000000ooooooo0000o`000006ooooo`?o00000_ooool2o`00
00?ooooo3ol0000Fooooo`?o00000_ooool9o`0000Kooooo1?l0000:ooooo`?o000000?oooooo`00
0?l000001?ooool2o`0000Cooooo0_l00002ooooo`?o00000oooool3o`0000?ooooo0_l00009oooo
o`;o00002_ooool2o`0000;ooooo0_l0000>ooooo`;o00005_ooool2o`00033ooooo000Looooo`03
o`000?oooooooooo02Kooooo0_l00009ooooo`Oo00001_ooool2o`0001;ooooo0_l000000ooooooo
0000o`000003o`0000;ooooo1?l00004ooooo`;o00002?ooool9o`000003ooooool0003o000000;o
00002_ooool2o`0000Oooooo0_l00008ooooo`Oo00002?ooool3o`0000Oooooo0_l00004ooooo`?o
00000oooool2o`0000Wooooo1?l000001?oooooo0000o`000?l00003ooooo`;o00004?ooool2o`00
01Oooooo0_l00004ooooo`;o00000oooool2o`0003gooooo000Looooo`03o`000?oooooooooo02Ko
oooo0_l0000:ooooo`Ko00001Oooool3o`0000oooooo0_l00006ooooo`?o00000_ooool4o`0000ko
oooo0_l00004ooooo`Co000000?oooooo`000?l000002oooool2o`0000Oooooo0_l0000<ooooo`?o
00002?ooool3o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000004o`00013o
oooo1Ol00005ooooo`Co00003Oooool2o`0001gooooo0_l00003ooooo`;o0000?Oooool001cooooo
00?o0000ooooooooool09?ooool5o`00013ooooo0ol000000ooooooo0000o`000003ooooo`;o0000
2oooool3o`0000?ooooo0_l0000Oooooo`;o000000Coooooo`000?l0003ooooo0_l0000=ooooo`;o
00002Oooool2o`000003ooooool0003o000000cooooo1ol00002ooooo`;o00000oooool6o`0000Ko
oooo0_l00009ooooo`;o00001Oooool6o`0001;ooooo0_l00002ooooo`;o00000_ooool3o`0005?o
oooo000Looooo`03o`000?oooooooooo02Cooooo0_l000000ooooooo0000o`000003ooooo`;o0000
2oooool3o`0000Kooooo0_l00007ooooo`;o00000oooool2o`000003ooooool0003o000000;o0000
3Oooool4o`00017ooooo1Ol0000:ooooo`;o000000?oooooo`000?l000001?ooool4o`000004oooo
ool0003o0000ooooo`;o00003?ooool5o`0000;ooooo1?l00004ooooo`;o00001?ooool2o`0000?o
oooo0ol00002ooooo`;o00000oooool2o`0000Kooooo1?l00003ooooo`;o000000Coooooo`000?l0
003o00001Oooool2o`0000Cooooo0_l00002ooooo`;o00000_ooool3o`0005?ooooo000Looooo`03
o`000?oooooooooo02;ooooo0_l00008ooooo`;o000000?oooooo`000?l000000oooool2o`0000Oo
oooo0_l0000<ooooo`;o00001_ooool2o`0000oooooo1?l00006ooooo`Co00002Oooool3o`0000?o
oooo0_l00002ooooo`;o000000?oooooo`000?l000001oooool4o`0000gooooo0_l00003ooooo`Co
00000oooool2o`0000;ooooo0_l00008ooooo`;o00001?ooool2o`0000;ooooo0_l00003ooooo`;o
00001?ooool2o`000004ooooool0003o0000o`0000?ooooo1_l00005ooooo`;o00003Oooool2o`00
00Wooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`0Rooooo`;o00001_ooool2o`0000?o
oooo0_l00002ooooo`Co00001_ooool2o`0000?ooooo0_l0000Pooooo`;o00001Oooool2o`000003
ooooool0003o000000;o00001oooool2o`000003ooooool0003o000000;o000000?oooooo`000?l0
00000_ooool2o`0001_ooooo0_l00003ooooo`;o00000oooool:o`0001_ooooo0_l000001?oooooo
0000o`000?l00004ooooo`?o00001Oooool3o`0000kooooo0_l00005ooooo`;o00000_ooool2o`00
04Sooooo000Looooo`03o`000?oooooooooo02[ooooo0_l00007ooooo`Oo00002?ooool2o`0000?o
oooo0_l0000Rooooo`?o00002oooool2o`0000?ooooo0_l00003ooooo`;o00001?ooool2o`0000Go
oooo0_l0000Jooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0001?ooooo0_l00006oooo
o`;o000000?oooooo`000?l000001Oooool3o`0000Gooooo0ol00003ooooo`;o00003?ooool2o`00
00;ooooo0_l0000Gooooo`;o0000<oooool001cooooo00?o0000ooooooooool0:_ooool2o`0000;o
oooo0_l00006ooooo`Go00003?ooool3o`0000;ooooo0_l00008ooooo`;o00005?ooool2o`0000go
oooo0_l00006ooooo`;o00001?ooool2o`0000Gooooo0_l0000Cooooo`;o00002?ooool2o`0000?o
oooo0_l0000>ooooo`;o00000_ooool3o`00013ooooo1?l00002ooooo`;o00001_ooool3o`0000Wo
oooo1?l0000Kooooo`;o0000<oooool001cooooo00?o0000ooooooooool0:_ooool2o`0000;ooooo
0_l00004ooooo`;o00000oooool2o`0000gooooo1_l00008ooooo`?o00002_ooool2o`0000Cooooo
0_l0000;ooooo`;o00000oooool2o`0000_ooooo0_l000000ooooooo0000o`000004ooooo`;o0000
3oooool2o`000003ooooool0003o000000;o00002?ooool2o`000003ooooool0003o000000Wooooo
1?l000000ooooooo0000o`000002ooooo`;o00003oooool2o`0000;ooooo1_l00006ooooo`?o0000
1Oooool3o`000003ooooool0003o000000;o00003?ooool2o`0004;ooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0
003oooooooooo`0dooooo`;o00001Oooool3o`0000cooooo1Ol00008ooooo`;o00002_ooool5o`00
0003ooooool0003o000000Gooooo0_l00004ooooo`;o00001Oooool2o`0000Wooooo0_l000000ooo
oooo0000o`000004ooooo`;o00000oooool2o`0000[ooooo0_l000000ooooooo0000o`000002o`00
00Gooooo1Ol000000ooooooo0000o`000009ooooo`Co00003Oooool2o`0000Oooooo0_l00003oooo
o`Ko00001?ooool2o`000003ooooool0003o000000Cooooo0ol000000ooooooo0000o`000002o`00
00;ooooo0_l00008ooooo`;o000000?oooooo`000?l00000?oooool00006oooooomgMgOoV9RHoooo
oonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oo
oooooooo03Cooooo0ol00004ooooo`?o00000oooool2o`0000Wooooo0ol00008ooooo`Co00002?oo
ool5o`0000Sooooo0_l00009ooooo`Co00005oooool3o`0000kooooo0_l00005ooooo`Co00007_oo
ool2o`0000Oooooo0_l00006ooooo`Co00000_ooool3o`000003ooooool0003o000000Cooooo0_l0
0005ooooo`;o000000?oooooo`000?l000002oooool2o`0003oooooo00000ooooooo410@ooooo`02
ooooo`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo03Gooooo0_l0000:ooooo`;o00002_ooool2o`0000Sooooo1?l0000;ooooo`;o00001?oo
ool2o`0000cooooo0ol000000ooooooo0000o`000005ooooo`?o00003oooool2o`0000Cooooo0_l0
000@ooooo`;o00000_ooool2o`0000Gooooo0ol00008ooooo`;o00007?ooool2o`0000;ooooo0_l0
0007ooooo`;o00001_ooool2o`000003ooooool0003o000000;o00001?ooool2o`0000?ooooo0_l0
000oooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9So
oooooiRHV?lQ8B401_ooool3o`0002kooooo0_l0000Jooooo`;o000000?oooooo`000?l000002?oo
ool5o`00013ooooo0ol0000;ooooo`;o00000_ooool2o`0000Gooooo0ol0000Eooooo`?o00001ooo
ool2o`0000Kooooo1_l00003ooooo`Go00000_ooool4o`0000;ooooo1Ol00003ooooo`;o00002ooo
ool2o`0000Kooooo0_l00003ooooo`;o00001oooool2o`0000Sooooo1Ol000000ooooooo0000o`00
0003o`0000?ooooo0_l0000oooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09
ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0^ooooo`;o00004ooo
ool2o`0000Gooooo0_l0000<ooooo`Co00003?ooool2o`0000?ooooo1?l0000Looooo`;o00003ooo
ool2o`0000Oooooo0_l00006ooooo`Ko00000oooool2o`0000;ooooo0_l000000ooooooo0000o`00
0002o`0000Cooooo0ol00003ooooo`Co00002Oooool2o`000003ooooool0003o000000?ooooo0_l0
0003ooooo`?o00004?ooool2o`0000Cooooo1Ol0000;ooooo`;o0000=oooool00003ooooool@413o
oooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooo
oooo03Wooooo0_l00006ooooo`Ko00003oooool4o`0000kooooo0_l00005ooooo`;o00006?ooool=
o`0001Cooooo1?l0000<ooooo`_o00001Oooool2o`0000?ooooo0_l00004ooooo`;o00000_ooool3
o`000003ooooool0003o000000Co00001?ooool3o`0000Oooooo0_l00007ooooo`;o00001Oooool3
o`0000Cooooo0_l00006ooooo`;o0000=oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2ooo
ool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo03;ooooo0_l00003ooooo`Co00001_oo
ool2o`0000;ooooo0ol00003ooooo`;o00002Oooool4o`000004ooooool0003o0000ooooo`;o0000
2_ooool2o`0001Gooooo0_l00002ooooo`;o00000_ooool=o`0000;ooooo0_l0000@ooooo`Co0000
3?ooool3o`000003ooooool0003o000000co00001Oooool2o`000004ooooool0003o0000o`0000;o
oooo0_l00004ooooo`Co00001?ooool3o`0000Oooooo0_l0000?ooooo`;o00001?ooool3o`0003ko
oooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool0
0ol0003oooooooooo`0booooo`;o00000oooool2o`0000gooooo0_l00003ooooo`;o00000oooool2
o`0000?ooooo0_l00004ooooo`Go00001?ooool8o`0001Gooooo0_l000000ooooooo0000o`00000G
o`0001Sooooo0_l00003oooooa;o00001Oooool2o`000003ooooool0003o000000Kooooo0_l00000
0ooooooo0000o`00000Xooooo`;o00004Oooool2o`0002_ooooo000Looooo`03o`000?oooooooooo
053ooooo0_l00003ooooo`?o00001?ooool2o`0000Kooooo1_l0000?ooooo`;o00001?ooool2o`00
00;ooooo6_l0000>ooooo`;o00002?ooool2o`0000Cooooo4ol0000>ooooo`;o000000?oooooo`00
0?l000003?ooool3o`0000Gooooo1?l0000Sooooo`;o0000:oooool001cooooo00?o0000oooooooo
ool0<_ooool2o`000003ooooool0003o000000;ooooo0ol00006ooooo`;o00000oooool2o`000003
ooooool0003o000000[ooooo0_l00002ooooo`Go00001oooool2o`00017ooooo0_l00004oooooako
00000oooool3o`0000?ooooo0_l00003ooooo`;o00000oooool2o`0000Sooooo5?l000000ooooooo
0000o`00000Booooo`;o00002?ooool3o`0000?ooooo1_l00005ooooo`;o000000?oooooo`000?l0
0000A_ooool001cooooo00?o0000ooooooooool0<_ooool2o`000003ooooool0003o000000;ooooo
0ol00006ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`;o00002oooool5o`0000Oo
oooo0_l0000Gooooo`Co00000_oooolJo`000004ooooool0003o0000o`0000?ooooo0_l00003oooo
o`;o00000oooool2o`0000?ooooo0ol000001Ooooooo0000o`000?l0003ooooo00go00000_ooool2
o`000003ooooool0003o000000;o00004?ooool2o`0000Sooooo0_l00004ooooo`;o00002Oooool2
o`000003ooooool0003o000000?ooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0joooo
o`;o00004Oooool2o`0000Kooooo1?l000000ooooooo0000o`000003o`0000Oooooo0_l0000Foooo
o`Co00000ooooolJo`0000;ooooo0ol00007ooooo`;o00000oooool2o`0000?ooooo0ol000000ooo
oooo0000o`00000?o`000004ooooool0003o0000o`0000?ooooo0_l00008ooooo`;o00000_ooool2
o`000004ooooool0003o0000o`0001Wooooo0ol00005ooooo`;o0000@Oooool001cooooo00?o0000
ooooooooool0@_ooool2o`0000[ooooo0_l00005ooooo`Co000000?oooooo`000?l000001?l0000N
ooooo`;o00000oooool4o`0000;ooooo2ol000000ooooooo0000o`000009o`000004ooooool0003o
0000o`0000Oooooo0_l0000;oooooaSo00002_ooool3o`0000;ooooo0_l000000ooooooo0000o`00
000Cooooo`;o00001_ooool3o`0004Oooooo000Looooo`03o`000?oooooooooo03_ooooo0_l00005
ooooo`;o00002_ooool2o`0000[ooooo1_l0000=ooooo`Ko00000_ooool2o`0000Sooooo0_l00002
oooooa?o00000_ooool:o`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l000002?oooolC
o`000003ooooool0003o000000;o00002_ooool5o`0000Kooooo1?l000000ooooooo0000o`00000;
ooooo`;o00001oooool3o`0004Kooooo000Looooo`03o`000?oooooooooo03Sooooo0_l000000ooo
oooo0000o`00000Booooo`;o00002Oooool5o`000003ooooool0003o000000Oooooo0_l00002oooo
o`Ko00000_ooool4o`0000Cooooo1?l00003oooooako00000oooool2o`0000Oooooo0_l00008oooo
oa;o000000?oooooo`000?l000000_l0000;ooooo`Go00001_ooool4o`000003ooooool0003o0000
00Oooooo0_l0000<ooooo`;o000000?oooooo`000?l00000@oooool001cooooo00?o0000oooooooo
ool0>?ooool2o`0000Kooooo0_l000000ooooooo0000o`000006ooooo`;o00000_ooool2o`0000[o
oooo0_l00003ooooo`;o00001oooool2o`0000Gooooo0_l00005ooooo`;o00001?ooool3o`0000Co
oooo7_l00003ooooo`;o00003_ooool2o`000003ooooool0003o000001Go00004Oooool2o`000003
ooooool0003o000000;o00002Oooool2o`000003ooooool0003o000000oooooo0_l00013ooooo`00
7?ooool00ol0003oooooooooo`10ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Gooooo
0_l00007ooooo`;o00005_ooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l00000
1_ooool<o`000003ooooool0003o000000go00000_ooool2o`0000Gooooo0_l00005ooooo`;o0000
00Coooooo`000?l0003ooooo5ol0000Aooooo`;o000000?oooooo`000?l000002oooool2o`0000[o
oooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o00009Oooool2o`0000Sooooo
0_l000000ooooooo0000o`00000Booooo`Ko00000_ooool2o`0000Kooooo0_l000000ooooooo0000
o`00000No`0000Gooooo0_l00005ooooo`;o00001?oooolGo`0000kooooo0_l00004ooooo`;o0000
3oooool2o`0000Kooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o00006ooo
ool2o`0000Gooooo0_l0000;ooooo`Go000000?oooooo`000?l000004Oooool2o`0000Sooooo0_l0
0002ooooob7o00003Oooool2o`0000Oooooo5Ol0000>ooooo`;o00001?ooool2o`0000Kooooo1Ol0
0003ooooo`?o00002oooool2o`0004Kooooo000Looooo`;o0000>?ooool2o`0000oooooo0_l00005
ooooo`;o00003?ooool3o`0000;ooooo0_l00009ooooo`Co00003_ooool3o`0000;ooooo8?l0000=
ooooo`;o000000Coooooo`000?l0003o00000ooooolEo`0001cooooo1Ol00003ooooo`;o00001ooo
ool2o`0000?ooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00002oooool2
o`0000gooooo0ol0000:ooooo`;o00002oooool4o`000003ooooool0003o000000Wooooo0_l00000
0ooooooo0000o`000003ooooob3o00003?ooool2o`000004ooooool0003o0000o`0000?ooooo5?l0
00001?oooooo0000o`000?l0000Cooooo`;o00001Oooool2o`000003ooooool0003o000000Wooooo
1?l0001;ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00001?ooool2o`0000Oooooo0ol0
0002ooooo`;o00001_ooool2o`00013ooooo0_l00009ooooo`;o00001_oooolQo`0000?ooooo0_l0
0009ooooo`;o00001?oooolDo`000004ooooool0003o0000o`0001?ooooo1?l00003ooooo`;o0000
00?oooooo`000?l000002Oooool2o`000003ooooool0003o000004[ooooo000Looooo`03o`000?oo
oooooooo04[ooooo0_l00009ooooo`;o000000?oooooo`000?l000005_ooool2o`0001Gooooo7ol0
0002ooooo`?o00002?ooool2o`000003ooooool0003o000000;ooooo5?l00003ooooo`;o00001?oo
ool2o`000003ooooool0003o000000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000000ooo
ool2o`0000oooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00003_ooool2
o`0000Sooooo1?l0000=ooooo`;o00003Oooool2o`0000Kooooo7ol00002ooooo`;o00000_ooool2
o`0000Gooooo0_l000000ooooooo0000o`000006oooooa3o00000oooool2o`0000Cooooo1Ol00003
ooooo`;o00000oooool2o`0001Cooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`12oooo
o`;o000000?oooooo`000?l000003_ooool2o`0000?ooooo0_l00003ooooo`Co000000?oooooo`00
0?l000006Oooool2o`0000Oooooo1ol000000ooooooo0000o`00000Ao`0000Wooooo0_l00007oooo
o`;o00001?ooool2o`000003ooooool0003o000000ko000000?oooooo`000?l000000_l00005oooo
o`;o00001?ooool2o`0000[ooooo0_l000001?oooooo0000o`000?ooool2o`0000Sooooo0_l0001=
ooooo`007?ooool00ol0003oooooooooo`12ooooo`Co00003oooool2o`0000?ooooo0_l00008oooo
o`;o00004oooool2o`0000gooooo1ol000000ooooooo0000o`00000?o`0000cooooo0_l00006oooo
o`;o00001?ooool2o`000003ooooool0003o000000Ko000000?oooooo`000?l000000_l00004oooo
o`;o00001oooool2o`0000Cooooo0_l0000:ooooo`;o000000Coooooo`000?l0003ooooo0_l0000;
ooooo`?o0000BOooool001cooooo00?o0000ooooooooool0@oooool3o`0000cooooo0_l00006oooo
o`?o00001?ooool4o`000003ooooool0003o000000Oooooo0ol00005ooooo`Go00002?ooool4o`00
0003ooooool0003o000001Ko00001Oooool4o`0000?ooooo0_l0000>ooooo`;o000000?oooooo`00
0?l000001_l000000ooooooo0000o`000009ooooo`;o00006oooool2o`0000[ooooo0ol00019oooo
o`007?ooool00ol0003oooooooooo`13ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`Co
00000_ooool6o`000003ooooool0003o000000;ooooo0_l00003ooooo`?o00001Oooool2o`000003
ooooool0003o000000Sooooo1?l000001?oooooo0000o`000?ooool9o`000003ooooool0003o0000
00Wo00001Oooool4o`0000[ooooo0_l00007ooooo`co00002oooool2o`0001Wooooo1?l00003oooo
o`;o000000?oooooo`000?l00000C_ooool001cooooo00?o0000ooooooooool0@oooool3o`0000Co
oooo0_l00009ooooo`;o00000_ooool2o`0000Cooooo0_l000001?oooooo0000o`000?l00005oooo
o`;o00002oooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o00000oooool2o`00
00;ooooo5_l0000:ooooo`;o00001oooool2o`0000Cooooo0_l000000ooooooo0000o`000005o`00
00;ooooo0ol00005ooooo`Ko00001_ooool2o`0001?ooooo0_l00005ooooo`;o000000?oooooo`00
0?l00000C_ooool001cooooo00?o0000ooooooooool0@oooool3o`0000Wooooo0_l00004ooooo`;o
00001?ooool2o`000005ooooool0003o0000o`000?ooool01Ol00002ooooo`;o00002oooool2o`00
00;ooooo0ol000000ooooooo0000o`000002ooooo`;o00000oooool2o`0000;ooooo4_l000000ooo
oooo0000o`000006ooooo`;o00000oooool2o`0000gooooo0_l000000ooooooo0000o`000007o`00
00Gooooo0_l000000ooooooo0000o`000004o`0000Kooooo0_l0000;ooooo`Co00003oooool2o`00
00_ooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00001?ooool2o`0000?o
oooo0_l00007ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`Go000000Coooooo`00
0?l0003o00002oooool2o`0000?ooooo0_l0000?oooooa3o00000_ooool2o`0000Kooooo1?l00003
ooooo`;o00002_ooool8o`0000?ooooo0_l00005ooooo`;o00001_ooool5o`0000[ooooo0_l00003
ooooo`Co00003oooool2o`0000_ooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`1:oooo
o`;o00000oooool2o`0000Oooooo0_l00009ooooo`Co000000?oooooo`000?l000004Oooool2o`00
00Kooooo0_l000000ooooooo0000o`000006ooooo`Wo000000?oooooo`000?l000000_l00008oooo
o`;o00000_ooool2o`0000;ooooo0ol0000:ooooo`;o000000?oooooo`000?l000000_l00005oooo
o`;o00001?ooool4o`0000Cooooo1Ol0000:ooooo`;o00005?ooool2o`0004oooooo000Looooo`03
o`000?oooooooooo04_ooooo0ol000000ooooooo0000o`000008ooooo`;o00000_ooool2o`0000Go
oooo0ol0000=ooooo`;o00001Oooool2o`0000Kooooo0_l000000ooooooo0000o`000006ooooo`?o
000000?oooooo`000?l000000ol000000ooooooo0000o`00000:ooooo`;o00001_ooool2o`0001Oo
oooo0_l00005ooooo`?o00001Oooool2o`0000?ooooo0_l0000>ooooo`;o00003Oooool2o`0004oo
oooo000Looooo`03o`000?oooooooooo04_ooooo0ol0000;ooooo`;o00000_ooool2o`0000Kooooo
0ol000000ooooooo0000o`000009ooooo`;o00000_ooool2o`0000Sooooo0_l000000ooooooo0000
o`000003ooooo`;o00000oooool2o`0000Cooooo0_l0000Eooooo`;o00007_ooool2o`0000Kooooo
0_l00003ooooo`;o00003_ooool2o`0000Gooooo0_l00004ooooo`;o00001oooool4o`0004Kooooo
000Looooo`03o`000?oooooooooo04Sooooo0_l000000ooooooo0000o`000002ooooo`;o00004?oo
ool2o`000003ooooool0003o000000;o000000?oooooo`000?l000003Oooool2o`0000Sooooo0_l0
00000ooooooo0000o`000003ooooo`;o00005Oooool2o`0001Gooooo0_l0000Hooooo`?o00005?oo
ool2o`0000Gooooo0_l00004ooooo`;o00001oooool4o`0004Kooooo000Looooo`;o0000BOooool2
o`0000;ooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000Cooooo0_l00005
ooooo`Go00003Oooool2o`0000Wooooo0ol00009ooooo`;o00003_ooool2o`0000?ooooo1?l00007
ooooo`;o00002?ooool2o`0000;ooooo0_l00006ooooo`;o00002oooool2o`0000?ooooo0ol0000>
ooooo`Co000000Coooooo`000?l0003o00000_ooool2o`0005[ooooo000Looooo`03o`000?oooooo
oooo04cooooo0_l00003ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Gooooo1_l00002
ooooo`;o00002?ooool2o`0000Cooooo0_l00003ooooo`?o00002?ooool2o`0000Gooooo0_l00008
ooooo`;o00000oooool2o`0000Sooooo0ol00008ooooo`;o00002_ooool2o`0000Gooooo0_l00003
ooooo`?o00001_ooool2o`000003ooooool0003o000000Wooooo1?l000000ooooooo0000o`000003
ooooo`;o00001oooool2o`00057ooooo000Looooo`03o`000?oooooooooo037ooooo0_l0000Ioooo
o`Co00002Oooool4o`0000Cooooo1_l00002ooooo`;o00002oooool2o`000003ooooool0003o0000
00kooooo0_l00005ooooo`;o00005oooool2o`0000gooooo0_l00002ooooo`;o000000?oooooo`00
0?l000000oooool2o`000003ooooool0003o000000?ooooo0_l00007ooooo`;o000000Coooooo`00
0?l0003ooooo0_l000001?oooooo0000o`000?l0000?ooooo`;o00001?ooool4o`0004oooooo000L
ooooo`03o`000?oooooooooo037ooooo0_l0000Iooooo`Co00002Oooool4o`0000Kooooo0ol00007
ooooo`;o00001oooool2o`0000;ooooo0_l0000looooo`;o00000_ooool2o`000004ooooool0003o
0000ooooo`Co000000Coooooo`000?l0003ooooo0_l0000?ooooo`;o000000Coooooo`000?l0003o
00003oooool4o`0000Cooooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`1Tooooo`;o0000
1oooool2o`0000Sooooo1Ol00006ooooo`;o00008Oooool2o`0000[ooooo0_l0000?ooooo`Co0000
00Coooooo`000?l0003ooooo0_l0000@ooooo`Go00003oooool4o`0005Gooooo000Looooo`03o`00
0?oooooooooo04oooooo0_l00002ooooo`;o00000oooool2o`0000[ooooo0ol00008ooooo`;o0000
0_ooool2o`0000;ooooo1?l00002ooooo`;o00000oooool2o`0000?ooooo0_l0000Looooo`;o0000
2_ooool2o`0000gooooo0ol00004ooooo`;o00004?ooool2o`000004ooooool0003o0000ooooo`;o
00002?ooool2o`0005kooooo000Looooo`03o`000?oooooooooo04_ooooo0_l00002ooooo`;o0000
0_ooool2o`0000?ooooo0_l000000ooooooo0000o`000005ooooo`Go00002?ooool2o`0000;ooooo
0_l00005ooooo`;o000000?oooooo`000?l000002?ooool3o`0003;ooooo0_l00002ooooo`?o0000
1?ooool2o`0000Cooooo0_l00006ooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000
o`000005ooooo`Co00001?ooool2o`0005Kooooo000Looooo`03o`000?oooooooooo04_ooooo0_l0
0004ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Gooooo0_l0000;ooooo`;o00002Ooo
ool4o`0000Wooooo0ol00008ooooo`;o00005?ooool2o`0000Gooooo0_l0000;ooooo`;o00003ooo
ool4o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000
o`000005ooooo`Co00001?ooool2o`0005Kooooo000Looooo`03o`000?oooooooooo053ooooo0ol0
00000ooooooo0000o`00000Booooo`;o00001Oooool2o`0000;ooooo0ol00005ooooo`?o00002_oo
ool2o`0000Sooooo0_l00008ooooo`;o00002_ooool2o`0000Gooooo0_l0000@ooooo`;o00003?oo
ool5o`0000Cooooo0ol000000ooooooo0000o`000006ooooo`;o00001?ooool3o`0005cooooo000L
ooooo`03o`000?oooooooooo053ooooo0_l000000ooooooo0000o`00000Cooooo`;o00002Oooool3
o`0001Kooooo0ol0000=ooooo`;o00003?ooool2o`0001Gooooo0_l0000<ooooo`Go00001?ooool3
o`000003ooooool0003o000000Kooooo0_l00004ooooo`;o0000GOooool001cooooo00?o0000oooo
ooooool0Doooool2o`0000Cooooo0ol0000>ooooo`;o00003oooool4o`0000gooooo0ol00003oooo
o`;o00001?ooool3o`0000oooooo0_l0000Pooooo`Co00002Oooool2o`0000Oooooo1?l0001Soooo
o`007?ooool00ol0003oooooooooo`1Cooooo`;o00001?ooool3o`0000Sooooo0_l00004ooooo`;o
00001oooool2o`0000Kooooo1?l0000=ooooo`;o00001?ooool2o`0000Cooooo0ol0000aooooo`Go
00004Oooool4o`0006?ooooo000Looooo`03o`000?oooooooooo05?ooooo0_l0000?ooooo`;o0000
2_ooool2o`000003ooooool0003o000000?ooooo0_l00008ooooo`;o00002oooool2o`000003oooo
ool0003o000000;ooooo0_l0000eooooo`Co00000_ooool2o`0000gooooo0_l0001Uooooo`007?oo
ool00ol0003oooooooooo`1Zooooo`;o00001?ooool4o`0000Cooooo0_l00008ooooo`;o00002ooo
ool2o`0000Cooooo2_l00005ooooo`;o00005_ooool2o`0000kooooo0ol00004ooooo`;o00003Ooo
ool2o`0000gooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`1Zooooo`?o00001Oooool2
o`0000Gooooo0_l00004ooooo`;o00005?ooool2o`000003ooooool0003o000000Oo00000oooool2
o`0000Sooooo0_l0000<ooooo`;o000000?oooooo`000?l000002oooool2o`0000_ooooo0_l00002
ooooo`;o000000?oooooo`000?l000003oooool2o`0005Kooooo000Looooo`03o`000?oooooooooo
05Cooooo0_l0000:ooooo`;o00002?ooool3o`0000[ooooo1?l00003ooooo`?o00004Oooool2o`00
0003ooooool0003o000000Cooooo1_l0000=ooooo`;o00003oooool2o`000003ooooool0003o0000
00Wooooo0_l00006ooooo`;o00000_ooool2o`000005ooooool0003o0000o`000?ooool00_l0001W
ooooo`007?ooool2o`0005Gooooo0_l00004ooooo`;o00001?ooool2o`0000Sooooo0ol00002oooo
o`;o00001_ooool2o`0000Gooooo0_l00004ooooo`;o00003?ooool2o`0000Cooooo1?l000000ooo
oooo0000o`000003ooooo`;o00002?ooool4o`0000Sooooo0_l00008ooooo`;o00001_ooool5o`00
00;ooooo0_l00002ooooo`;o00001Oooool2o`0000[ooooo0_l0001Oooooo`007?ooool00ol0003o
ooooooooo`1Jooooo`;o00000oooool2o`0000gooooo0ol0000:ooooo`Co00001Oooool2o`0000co
oooo0_l00004ooooo`Go00001Oooool2o`0000Sooooo1?l00008ooooo`;o00004?ooool5o`0000;o
oooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000;o00002_ooool2o`00
05oooooo000Looooo`03o`000?oooooooooo05oooooo0_l000000ooooooo0000o`000003o`000003
ooooool0003o000000;ooooo1?l0000;ooooo`Co00001_ooool2o`0000Cooooo0_l0000>ooooo`;o
00006oooool2o`0000;ooooo0_l0000>ooooo`?o00001Oooool2o`000004ooooool0003o0000oooo
o`Go00001oooool2o`0000Wooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`1Rooooo`Go
000000?oooooo`000?l000000_ooool2o`0000cooooo1Ol00006ooooo`;o00001?ooool2o`0000Wo
oooo0_l00006ooooo`;o00002?ooool2o`0001;ooooo0_l00002ooooo`Go00000oooool2o`0000;o
oooo1?l0000=ooooo`;o00001oooool2o`0000Wooooo0_l0001Fooooo`007?ooool00ol0003ooooo
ooooo`1Pooooo`Co00005_ooool5o`0001Oooooo0_l00006ooooo`;o00002?ooool2o`0000gooooo
0_l00004ooooo`;o000000?oooooo`000?l000000ol00003ooooo`;o00001?ooool2o`0001oooooo
0ol0001Gooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o00003Oooool2o`0000Oooooo1Ol0
000<ooooo`;o00004?ooool2o`0000;ooooo0_l00003ooooo`;o00003_ooool5o`0000;ooooo1?l0
00000ooooooo0000o`00000;ooooo`;o00002?ooool4o`0001Cooooo0ol0001Gooooo`007?ooool0
0ol0003oooooooooo`1Wooooo`Co00001?ooool5o`0000Cooooo0_l000001?oooooo0000o`000?l0
000:ooooo`?o00003_ooool4o`0000;ooooo0_l00003ooooo`;o00001Oooool4o`0000Gooooo1?l0
0003ooooo`;o00000oooool3o`0000?ooooo0_l00005ooooo`;o00001Oooool2o`000003ooooool0
003o000000;o0000K_ooool001cooooo00?o0000ooooooooool0Ioooool4o`0000Gooooo1?l00005
ooooo`;o000000?oooooo`000?l000002_ooool3o`0000kooooo0_l00009ooooo`;o00001Oooool4
o`000003ooooool0003o000000?o000000?oooooo`000?l000001oooool5o`0000;ooooo0_l0000<
ooooo`;o00000_ooool2o`0006oooooo000Looooo`03o`000?oooooooooo06Oooooo0_l0000;oooo
o`;o00000oooool5o`000003ooooool0003o000000Sooooo0_l0000Fooooo`;o000000?oooooo`00
0?l000000oooool2o`000004ooooool0003o0000ooooo`Ko00002?ooool4o`000003ooooool0003o
000000;ooooo1?l00005ooooo`;o00000_ooool2o`0007Cooooo000Looooo`03o`000?oooooooooo
04kooooo0_l0000Gooooo`;o00002oooool2o`0000Cooooo1?l000000ooooooo0000o`00000Koooo
o`;o00000oooool2o`0000Kooooo0_l00004ooooo`?o00000_ooool2o`0000Oooooo0_l00003oooo
o`;o000000?oooooo`000?l000000ol00005ooooo`;o00000_ooool2o`00013ooooo0_l0001Roooo
o`007?ooool00ol0003oooooooooo`1>ooooo`;o0000:_ooool4o`0001Oooooo0_l00002ooooo`;o
000000Coooooo`000?l0003ooooo0_l0000?ooooo`;o00000_ooool2o`0000Wooooo0_l000001?oo
oooo0000o`000?ooool5o`0000kooooo0_l0000;ooooo`;o00002?ooool2o`0005Sooooo000Loooo
o`03o`000?oooooooooo07_ooooo0ol0000@ooooo`;o00001Oooool2o`0000;ooooo0_l000001?oo
oooo0000o`000?ooool2o`0001Wooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l00000
0ooooooo0000o`00000?ooooo`;o00005Oooool2o`0005Sooooo000Looooo`03o`000?oooooooooo
07Wooooo0_l00009ooooo`;o00002?ooool2o`0000Kooooo0_l00007ooooo`Go00005_ooool2o`00
00Kooooo1?l00007ooooo`;o0000N_ooool001cooooo00?o0000ooooooooool0K_ooool2o`0000Ko
oooo0_l000000ooooooo0000o`000009ooooo`;o00002_ooool2o`000003ooooool0003o000000?o
00002?ooool4o`00013ooooo1?l00002ooooo`Ko00000_ooool2o`0000Kooooo0_l000000ooooooo
0000o`00001jooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<
c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0COooool2o`0001oooooo0_l00006
ooooo`;o00005?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00005
ooooo`;o00001Oooool2o`0000_ooooo1?l00002ooooo`Ko00001?ooool3o`0000?ooooo0_l00002
ooooo`;o0000NOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go
8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo04gooooo0_l0000Zooooo`;o0000
4Oooool8o`0000Cooooo0ol0000<ooooo`;o00000_ooool2o`0000Sooooo0_l00003ooooo`Go0000
1Oooool3o`0000Oooooo0_l0001iooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`1iooooo`;o0000
3Oooool5o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o00003?ooool2o`0000?ooooo
0_l0000>ooooo`Co0000R_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Ooo
ool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0001jooooo`?o00001?ooool2o`0000Gooooo
1Ol0000;ooooo`?o00001Oooool2o`0000Cooooo0ol000000ooooooo0000o`000007ooooo`;o0000
8Oooool4o`0006oooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go
c<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo07[ooooo0ol00004ooooo`;o0000
3oooool2o`0000Cooooo0ol00005ooooo`?o00001?ooool2o`000003ooooool0003o000000Kooooo
0ol0000Kooooo`;o00001?ooool4o`0000?ooooo0_l0001Zooooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooo
ooooo`24ooooo`;o00003?ooool2o`000004ooooool0003o0000ooooo`;o00001Oooool5o`0000ko
oooo0_l0000Dooooo`;o00000_ooool2o`0000;ooooo0_l0000;ooooo`;o0000J_ooool00006oooo
oomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000
ooooooooool0N?ooool2o`0000?ooooo0_l00005ooooo`;o000000?oooooo`000?l000001oooool3
o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l000000ooooooo0000o`00
000Tooooo`;o00000_ooool2o`0000Sooooo0ol0001`ooooo`0000Koooooonk^k_lb<S;o0000oc8b
<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`1hooooo`;o
00000oooool2o`0000Sooooo0_l00007ooooo`?o00002?ooool2o`0000Gooooo0_l0000Looooo`;o
00002oooool2o`0000Cooooo0_l000001?oooooo0000o`000?l0001`ooooo`007?ooool00ol0003o
ooooooooo`2Aooooo`;o00003Oooool4o`0001cooooo0_l0000:ooooo`?o00001?ooool2o`0007Co
oooo000Looooo`03o`000?oooooooooo07?ooooo0_l0000:ooooo`;o00001oooool2o`0001Kooooo
0_l00006ooooo`;o00003oooool2o`00017ooooo0_l00004ooooo`;o0000MOooool001cooooo00?o
0000ooooooooool0Loooool2o`0000Oooooo0_l000000ooooooo0000o`000007ooooo`;o00007_oo
ool2o`0000oooooo0_l0000:ooooo`;o00002oooool2o`0007Gooooo000Looooo`03o`000?oooooo
oooo07cooooo0_l00006ooooo`;o00003oooool2o`00013ooooo0_l00008ooooo`;o00004_ooool2
o`0008;ooooo000Looooo`03o`000?oooooooooo08?ooooo0ol0000?ooooo`;o00004?ooool2o`00
00Sooooo0_l0000<ooooo`;o0000R?ooool001cooooo00?o0000ooooooooool0Poooool2o`0000_o
oooo0_l0000]ooooo`Co0000Q_ooool001cooooo00?o0000ooooooooool0N?ooool2o`0001Kooooo
0_l0000[ooooo`;o00000_ooool2o`0008Kooooo000Looooo`03o`000?oooooooooo07Sooooo0_l0
0009ooooo`;o00001_ooool2o`0000cooooo0_l0000Hooooo`;o00002?ooool3o`0008Wooooo000L
ooooo`03o`000?oooooooooo08?ooooo0_l00006ooooo`;o00003?ooool2o`0001Sooooo0_l00009
ooooo`;o0000ROooool001cooooo00?o0000ooooooooool0Zoooool2o`0000Gooooo0_l00004oooo
o`;o0000Soooool001cooooo00?o0000ooooooooool0Voooool2o`0000;ooooo0_l0000:ooooo`;o
00001Oooool2o`0000Cooooo0_l0002?ooooo`007?ooool2o`0009?ooooo0_l00007ooooo`;o0000
0_ooool2o`000:Sooooo000Looooo`03o`000?oooooooooo09;ooooo0_l0002eooooo`007?ooool0
0ol0003oooooooooo`2Rooooo`;o0000YOooool001cooooo00?o0000ooooooooool0Q?ooool2o`00
01cooooo0_l00004ooooo`;o0000Woooool001cooooo00?o0000ooooooooool0Q?ooool2o`0002;o
oooo0_l0002Oooooo`007?ooool00ol0003oooooooooo`32ooooo`;o0000QOooool001cooooo00?o
0000ooooooooool0`_ooool2o`0008Gooooo000Looooo`03o`000?oooooooooo0;_ooooo0_l0002<
ooooo`007?ooool00ol0003oooooooooo`1_ooooo`;o0000@oooool2o`0000Gooooo0_l0002<oooo
o`007?ooool00ol0003oooooooooo`1_ooooo`;o00006oooool2o`0002Kooooo0_l0002Cooooo`00
7?ooool00ol0003oooooooooo`2:ooooo`Co00000oooool2o`000;Kooooo000Looooo`03o`000?oo
oooooooo08[ooooo0_l00005ooooo`;o0000]_ooool001cooooo00?o0000ooooooooool0Roooool2
o`0000Kooooo0_l0002dooooo`007?ooool00ol0003oooooooooo`2:ooooo`?o00001_ooool2o`00
00Wooooo0_l0002Yooooo`007?ooool00ol0003oooooooooo`2:ooooo`;o00004_ooool2o`0000Oo
oooo0_l0002Pooooo`007?ooool00ol0003oooooooooo`2Wooooo`;o0000X?ooool001cooooo0_l0
0022ooooo`;o00008oooool2o`000:7ooooo000Looooo`03o`000?oooooooooo087ooooo0_l0000<
ooooo`;o00005Oooool2o`000:7ooooo000Looooo`03o`000?oooooooooo08oooooo0_l0002hoooo
o`007?ooool00ol0003oooooooooo`28ooooo`;o0000_oooool001cooooo00?o0000ooooooooool0
R?ooool2o`000;oooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o
0000ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Co
oooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo
000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomB
ooooo`004_ooool00omEEEGoIVIVo`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo002Qooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05_oo
ool4o`000004oa0@4?ooooooooooooooo`Co000000Go410@ooooooooooooooooodA4A002o`000009
oc8b<_oMgMgoooooooooooo<c<co8B4Qo`000?lQ8B7oc<c<08cooooo002Rooooo`05o`000?oooooo
ooooooooool000002Oooool6o`0000cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`09ogMgMolb<S;ooooooooooolQ8B7oV9RHoooooonHV9So8B4Q08cooooo002Rooooo`05
o`000?ooooooooooooooool000006oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Oooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`2:ooooo`00X_ooool01Ol0
003ooooooooooooooooo000000Wooooo1_l0000<ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool02OmgMgOo<S8boooooooooooo<S8boiRHV?ooooooV9RHoc8b<P2<ooooo`00
X_ooool01Ol0003oQhN7oooooonYZJWo000001_ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Oo<c<co0000o`000?l0003o
c<c<08cooooo002Qooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool06Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol@
413o^[Zjoooooonj^[[o410@08cooooo0032ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`05o`000?nj^[[ooooookZj^_l00000S?ooool0
0<3ooooo00?oEEEEofIVI_l000001Oooool00omEEEGoIVIVo`000005ooooo`Co00000oooool01OnY
ZJWo410@o`000?l@413oZJVY08cooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1164) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.39755 .34265 Mdot
.44685 .34194 Mdot
.46784 .65146 Mdot
.63321 .46733 Mdot
.19773 .47005 Mdot
.43511 .6344 Mdot
.33917 .49408 Mdot
.38688 .49174 Mdot
.45468 .65334 Mdot
.31185 .32484 Mdot
.3472 .48493 Mdot
.70131 .383 Mdot
.36171 .48204 Mdot
.61528 .45245 Mdot
.18638 .36178 Mdot
.69378 .45968 Mdot
.44728 .38083 Mdot
.55913 .66929 Mdot
.63563 .38154 Mdot
.41003 .65906 Mdot
.44534 .39717 Mdot
.62593 .45475 Mdot
.44348 .31565 Mdot
.6147 .45184 Mdot
.65583 .47383 Mdot
.41565 .3534 Mdot
.48076 .32797 Mdot
.67034 .43766 Mdot
.67503 .46823 Mdot
.38533 .4845 Mdot
.68341 .59063 Mdot
.17173 .42098 Mdot
.60013 .39354 Mdot
.31664 .73397 Mdot
.38249 .50668 Mdot
.57171 .33676 Mdot
.44836 .62818 Mdot
.36962 .50568 Mdot
.3688 .51347 Mdot
.33425 .51759 Mdot
.35654 .5031 Mdot
.42165 .34021 Mdot
.37132 .55654 Mdot
.45212 .56169 Mdot
.69456 .44175 Mdot
.23981 .45128 Mdot
.74774 .34446 Mdot
.63933 .40783 Mdot
.43273 .3819 Mdot
.43982 .73521 Mdot
.25754 .57986 Mdot
.33804 .51493 Mdot
.40595 .60028 Mdot
.50521 .90249 Mdot
.37747 .50054 Mdot
.68995 .4135 Mdot
.46002 .63263 Mdot
.62539 .44383 Mdot
.61248 .44718 Mdot
.48711 .24779 Mdot
.65573 .40299 Mdot
.58032 .64437 Mdot
.39079 .34555 Mdot
.52955 .50171 Mdot
.45536 .64534 Mdot
.35566 .51219 Mdot
.44043 .32903 Mdot
.36922 .48228 Mdot
.62304 .50636 Mdot
.40401 .65552 Mdot
.64351 .40868 Mdot
.34863 .50191 Mdot
.41869 .3848 Mdot
.65394 .42496 Mdot
.51879 .77625 Mdot
.37706 .20298 Mdot
.62006 .63668 Mdot
.53977 .30579 Mdot
.48704 .27123 Mdot
.51948 .71859 Mdot
.61302 .47521 Mdot
.76737 .52673 Mdot
.31805 .24829 Mdot
.45969 .31826 Mdot
.55417 .45778 Mdot
.5536 .60744 Mdot
.64907 .42704 Mdot
.24727 .37254 Mdot
.68042 .46981 Mdot
.53244 .79402 Mdot
.44114 .65457 Mdot
.4425 .35999 Mdot
.63173 .46863 Mdot
.67604 .43246 Mdot
.75278 .39364 Mdot
.58163 .43063 Mdot
.65447 .44944 Mdot
.40645 .36307 Mdot
.34419 .52205 Mdot
.69975 .39874 Mdot
.41974 .55635 Mdot
.42323 .59136 Mdot
.59352 .42363 Mdot
.41537 .60997 Mdot
.42993 .39224 Mdot
.66081 .42322 Mdot
.36814 .51891 Mdot
.59687 .42596 Mdot
.36394 .41703 Mdot
.44955 .34038 Mdot
.67501 .43901 Mdot
.56646 .65602 Mdot
.77964 .65136 Mdot
.45072 .36297 Mdot
.55737 .71377 Mdot
.62309 .48448 Mdot
.64535 .44519 Mdot
.44442 .34299 Mdot
.45689 .61121 Mdot
.26096 .34194 Mdot
.4425 .30938 Mdot
.34199 .52916 Mdot
.40357 .31948 Mdot
.56148 .47569 Mdot
.43964 .64871 Mdot
.29646 .66113 Mdot
.29414 .47638 Mdot
.69561 .56621 Mdot
.64258 .42859 Mdot
.30881 .37695 Mdot
.41433 .64955 Mdot
.43409 .35142 Mdot
.37061 .47852 Mdot
.61611 .37556 Mdot
.46053 .33458 Mdot
.36417 .46619 Mdot
.57059 .643 Mdot
.32557 .62275 Mdot
.46431 .37016 Mdot
.44439 .54553 Mdot
.38981 .47116 Mdot
.33448 .51079 Mdot
.3785 .79074 Mdot
.43745 .33231 Mdot
.58755 .66518 Mdot
.37902 .48197 Mdot
.65628 .58314 Mdot
.68606 .42083 Mdot
.74402 .58694 Mdot
.79122 .37638 Mdot
.33381 .74727 Mdot
.35109 .64125 Mdot
.60839 .65484 Mdot
.36387 .53483 Mdot
.66275 .4625 Mdot
.41302 .36168 Mdot
.41882 .33619 Mdot
.64304 .39961 Mdot
.64191 .47298 Mdot
.65149 .41233 Mdot
.67879 .43442 Mdot
.45503 .22878 Mdot
.5845 .45729 Mdot
.77318 .38528 Mdot
.44413 .36475 Mdot
.64952 .46418 Mdot
.44972 .61243 Mdot
.566 .44169 Mdot
.35359 .50497 Mdot
.63063 .45002 Mdot
.6365 .46727 Mdot
.65262 .40011 Mdot
.33968 .51851 Mdot
.20536 .3608 Mdot
.80063 .4572 Mdot
.18212 .44128 Mdot
.57679 .77097 Mdot
.4179 .62414 Mdot
.64931 .43337 Mdot
.5724 .65926 Mdot
.60798 .31018 Mdot
.60429 .46397 Mdot
.87391 .5563 Mdot
.64552 .45355 Mdot
.19139 .44143 Mdot
.66743 .51201 Mdot
.15508 .50499 Mdot
.74919 .55632 Mdot
.66987 .45577 Mdot
.58787 .54218 Mdot
.48786 .41165 Mdot
.41715 .56551 Mdot
.35706 .49971 Mdot
.45474 .61585 Mdot
.46667 .64032 Mdot
.39771 .52224 Mdot
.43788 .27581 Mdot
.55951 .50184 Mdot
.58546 .48771 Mdot
.3999 .64839 Mdot
.39886 .37599 Mdot
.60011 .6338 Mdot
.40509 .33814 Mdot
.4039 .14991 Mdot
.25758 .53804 Mdot
.38314 .53992 Mdot
.59963 .68974 Mdot
.44169 .66301 Mdot
.42355 .59395 Mdot
.57883 .67609 Mdot
.61768 .4184 Mdot
.43475 .32859 Mdot
.29431 .73484 Mdot
.39292 .26939 Mdot
.35671 .78778 Mdot
.41129 .37069 Mdot
.33801 .33061 Mdot
.3617 .46958 Mdot
.437 .61845 Mdot
.64881 .44613 Mdot
.62141 .42348 Mdot
.46343 .384 Mdot
.64852 .41227 Mdot
.73915 .44641 Mdot
.66132 .44266 Mdot
.27496 .61401 Mdot
.61466 .62782 Mdot
.39657 .52474 Mdot
.70135 .55237 Mdot
.42833 .3164 Mdot
.70068 .68676 Mdot
.41638 .60379 Mdot
.58713 .31191 Mdot
.34593 .50311 Mdot
.57489 .64198 Mdot
.40926 .60869 Mdot
.59858 .6307 Mdot
.60122 .39524 Mdot
.47599 .65691 Mdot
.5697 .6723 Mdot
.47404 .28362 Mdot
.68467 .43546 Mdot
.44912 .22312 Mdot
.35542 .53091 Mdot
.44565 .30751 Mdot
.65999 .40644 Mdot
.41951 .61553 Mdot
.58368 .40164 Mdot
.36271 .5864 Mdot
.29639 .65721 Mdot
.4497 .60114 Mdot
.40312 .7169 Mdot
.58831 .63768 Mdot
.32085 .56462 Mdot
.33249 .35951 Mdot
.4307 .38413 Mdot
.58187 .45085 Mdot
.14287 .50788 Mdot
.37883 .48219 Mdot
.59981 .42657 Mdot
.30385 .70093 Mdot
.37784 .49021 Mdot
.62544 .44177 Mdot
.38745 .51449 Mdot
.41966 .33396 Mdot
.78592 .60833 Mdot
.44311 .38165 Mdot
.6676 .47997 Mdot
.36734 .52178 Mdot
.47425 .63326 Mdot
.41757 .3631 Mdot
.6157 .41419 Mdot
.66439 .43414 Mdot
.50509 .4999 Mdot
.65527 .45945 Mdot
.20281 .38369 Mdot
.66779 .44621 Mdot
.46039 .62473 Mdot
.59415 .41239 Mdot
.70128 .77237 Mdot
.28171 .51309 Mdot
.43906 .32881 Mdot
.47667 .63101 Mdot
.4608 .65036 Mdot
.58228 .71762 Mdot
.32633 .54025 Mdot
.61025 .47825 Mdot
.41715 .62111 Mdot
.738 .63936 Mdot
.36998 .46076 Mdot
.58014 .45043 Mdot
.45295 .54344 Mdot
.44979 .73906 Mdot
.40258 .61436 Mdot
.64694 .37674 Mdot
.45648 .38298 Mdot
.63296 .46975 Mdot
.43405 .59826 Mdot
.43701 .40426 Mdot
.63481 .49 Mdot
.38852 .31663 Mdot
.50421 .49722 Mdot
.35057 .46998 Mdot
.65225 .5197 Mdot
.60565 .41555 Mdot
.43423 .61218 Mdot
.4215 .32098 Mdot
.37866 .46112 Mdot
.42011 .35092 Mdot
.20091 .59144 Mdot
.37401 .42093 Mdot
.45328 .25757 Mdot
.56214 .68465 Mdot
.40274 .74292 Mdot
.16104 .53758 Mdot
.64848 .76377 Mdot
.68995 .671 Mdot
.23424 .6705 Mdot
.44368 .60498 Mdot
.32706 .71603 Mdot
.46445 .64511 Mdot
.64128 .48145 Mdot
.44397 .64676 Mdot
.15718 .53608 Mdot
.66073 .44417 Mdot
.44558 .64083 Mdot
.72223 .67699 Mdot
.64366 .46804 Mdot
.45682 .3607 Mdot
.2489 .30275 Mdot
.67194 .76524 Mdot
.28187 .65024 Mdot
.4487 .67036 Mdot
.66686 .66781 Mdot
.65738 .45035 Mdot
.59425 .4085 Mdot
.43189 .3776 Mdot
.57813 .455 Mdot
.60454 .64146 Mdot
.59722 .69055 Mdot
.4765 .42316 Mdot
.78663 .51161 Mdot
.69938 .47328 Mdot
.41994 .36837 Mdot
.4999 .20986 Mdot
.49848 .77769 Mdot
.42087 .73701 Mdot
.38877 .52125 Mdot
.2452 .31632 Mdot
.73355 .40932 Mdot
.41034 .51768 Mdot
.45949 .57094 Mdot
.45048 .35457 Mdot
.19488 .38443 Mdot
.36062 .49915 Mdot
.65769 .25099 Mdot
.60399 .57019 Mdot
.61564 .42204 Mdot
.34274 .50109 Mdot
.71633 .437 Mdot
.65154 .78523 Mdot
.67607 .24124 Mdot
.76565 .46747 Mdot
.66147 .48518 Mdot
.53928 .77437 Mdot
.63697 .44887 Mdot
.27346 .32662 Mdot
.66925 .44387 Mdot
.42223 .3589 Mdot
.29551 .32291 Mdot
.49424 .4411 Mdot
.79366 .43412 Mdot
.26486 .50935 Mdot
.60842 .65396 Mdot
.65454 .44237 Mdot
.61381 .42301 Mdot
.60055 .64103 Mdot
.46987 .34895 Mdot
.67934 .43398 Mdot
.69004 .69087 Mdot
.64642 .4203 Mdot
.36203 .5067 Mdot
.75312 .47567 Mdot
.44405 .28936 Mdot
.60319 .49396 Mdot
.40232 .3753 Mdot
.34988 .46924 Mdot
.37528 .51127 Mdot
.70048 .44846 Mdot
.33046 .50933 Mdot
.63917 .458 Mdot
.68214 .23766 Mdot
.46379 .36515 Mdot
.70988 .49069 Mdot
.45308 .32017 Mdot
.53365 .30873 Mdot
.37711 .51559 Mdot
.27185 .59272 Mdot
.67179 .37181 Mdot
.35965 .49501 Mdot
.3843 .42015 Mdot
.6914 .48071 Mdot
.66827 .48743 Mdot
.49304 .8033 Mdot
.4599 .66605 Mdot
.50406 .47401 Mdot
.38835 .49541 Mdot
.61267 .4114 Mdot
.59026 .48284 Mdot
.34588 .47378 Mdot
.59463 .20543 Mdot
.70465 .71805 Mdot
.66494 .44415 Mdot
.42971 .36497 Mdot
.43173 .35018 Mdot
.65868 .48897 Mdot
.58883 .43996 Mdot
.42071 .64562 Mdot
.48134 .64906 Mdot
.4535 .67351 Mdot
.50351 .49318 Mdot
.27237 .60176 Mdot
.22066 .51095 Mdot
.33406 .51683 Mdot
.32882 .3949 Mdot
.55215 .7907 Mdot
.56277 .46205 Mdot
.41719 .66046 Mdot
.60148 .43262 Mdot
.63082 .4635 Mdot
.37399 .45681 Mdot
.28409 .66988 Mdot
.72324 .41944 Mdot
.46984 .35991 Mdot
.38755 .47648 Mdot
.55991 .40317 Mdot
.26391 .4685 Mdot
.56918 .65515 Mdot
.40148 .78895 Mdot
.34877 .50567 Mdot
.4551 .35577 Mdot
.38088 .5167 Mdot
.6272 .42111 Mdot
.66108 .38544 Mdot
.44405 .34917 Mdot
.5941 .68708 Mdot
.57775 .41524 Mdot
.62853 .44168 Mdot
.83429 .45029 Mdot
.57511 .78096 Mdot
.28405 .61462 Mdot
.66934 .45298 Mdot
.61346 .49473 Mdot
.5725 .63098 Mdot
.64034 .4193 Mdot
.65976 .41254 Mdot
.8057 .59363 Mdot
.30166 .45492 Mdot
.57589 .68989 Mdot
.6315 .22965 Mdot
.4137 .3748 Mdot
.155 .47108 Mdot
.43242 .61659 Mdot
.34631 .54054 Mdot
.72697 .70359 Mdot
.411 .59015 Mdot
.358 .64776 Mdot
.16338 .45053 Mdot
.50244 .47111 Mdot
.4817 .69117 Mdot
.71123 .38759 Mdot
.66989 .42441 Mdot
.63909 .44479 Mdot
.57578 .65756 Mdot
.43075 .33051 Mdot
.51348 .49655 Mdot
.47347 .18627 Mdot
.63132 .45442 Mdot
.72592 .47691 Mdot
.39338 .25102 Mdot
.45648 .73721 Mdot
.60344 .66295 Mdot
.59781 .68781 Mdot
.65003 .44241 Mdot
.78701 .63086 Mdot
.4151 .35529 Mdot
.61432 .41487 Mdot
.60279 .47747 Mdot
.45955 .66786 Mdot
.45453 .34088 Mdot
.43828 .60207 Mdot
.26983 .57038 Mdot
.18568 .44651 Mdot
.8403 .44451 Mdot
.37709 .51273 Mdot
.32733 .27106 Mdot
.38257 .47521 Mdot
.76502 .52068 Mdot
.41664 .59282 Mdot
.60736 .47052 Mdot
.42414 .31918 Mdot
.60685 .41777 Mdot
.58925 .44956 Mdot
.61558 .41939 Mdot
.57455 .47502 Mdot
.83765 .62875 Mdot
.58637 .68254 Mdot
.64166 .50122 Mdot
.46771 .63615 Mdot
.26894 .3137 Mdot
.36511 .21612 Mdot
.6119 .42891 Mdot
.66036 .4363 Mdot
.46528 .35087 Mdot
.62695 .39915 Mdot
.37478 .46411 Mdot
.417 .32271 Mdot
.67647 .43446 Mdot
.25323 .31642 Mdot
.67962 .45682 Mdot
.16508 .48061 Mdot
.3841 .51301 Mdot
.37038 .3856 Mdot
.65734 .50066 Mdot
.29849 .65578 Mdot
.50412 .47418 Mdot
.40905 .63241 Mdot
.32666 .50485 Mdot
.4501 .63096 Mdot
.55234 .16427 Mdot
.64799 .38667 Mdot
.66125 .46588 Mdot
.5848 .47695 Mdot
.41873 .62206 Mdot
.23154 .39758 Mdot
.29857 .55205 Mdot
.55214 .41677 Mdot
.41966 .63314 Mdot
.39395 .36211 Mdot
.61149 .59528 Mdot
.43767 .31859 Mdot
.59997 .69172 Mdot
.34912 .48332 Mdot
.60852 .67681 Mdot
.28749 .69377 Mdot
.44894 .34244 Mdot
.48681 .3425 Mdot
.42984 .62292 Mdot
.52516 .57582 Mdot
.3961 .85254 Mdot
.57339 .57478 Mdot
.72191 .57861 Mdot
.43262 .37577 Mdot
.6589 .4827 Mdot
.75358 .51089 Mdot
.51592 .56003 Mdot
.45224 .63348 Mdot
.61076 .46398 Mdot
.77639 .6297 Mdot
.42006 .64534 Mdot
.58074 .44856 Mdot
.47098 .65397 Mdot
.35119 .49553 Mdot
.42541 .66251 Mdot
.47835 .35621 Mdot
.66049 .42806 Mdot
.3552 .824 Mdot
.62838 .66214 Mdot
.66303 .45155 Mdot
.38856 .48051 Mdot
.40574 .42869 Mdot
.59428 .44805 Mdot
.57422 .63533 Mdot
.43462 .64279 Mdot
.56511 .57925 Mdot
.66674 .44365 Mdot
.41975 .62441 Mdot
.3982 .33256 Mdot
.32904 .52127 Mdot
.52563 .40603 Mdot
.29437 .65139 Mdot
.42973 .37796 Mdot
.42613 .54368 Mdot
.3404 .4674 Mdot
.60859 .4941 Mdot
.58568 .46403 Mdot
.42976 .36022 Mdot
.79533 .56873 Mdot
.60963 .40183 Mdot
.61273 .47488 Mdot
.46655 .63043 Mdot
.44676 .63351 Mdot
.78633 .5923 Mdot
.46398 .61814 Mdot
.65735 .38513 Mdot
.42799 .3589 Mdot
.62584 .46914 Mdot
.46263 .35147 Mdot
.61605 .40302 Mdot
.46539 .39959 Mdot
.47127 .34499 Mdot
.30189 .53801 Mdot
.61819 .46545 Mdot
.67279 .51172 Mdot
.59684 .43088 Mdot
.65202 .41702 Mdot
.42436 .64862 Mdot
.59081 .67358 Mdot
.67423 .38262 Mdot
.62364 .66877 Mdot
.59601 .631 Mdot
.42627 .42342 Mdot
.45694 .66821 Mdot
.58711 .65746 Mdot
.41171 .23202 Mdot
.45761 .6718 Mdot
.58054 .6476 Mdot
.35756 .22417 Mdot
.38139 .50875 Mdot
.46078 .37755 Mdot
.64373 .46911 Mdot
.23478 .65957 Mdot
.75423 .34808 Mdot
.39387 .59064 Mdot
.66691 .4479 Mdot
.59833 .43738 Mdot
.44669 .31124 Mdot
.61917 .1701 Mdot
.40787 .66049 Mdot
.66222 .47561 Mdot
.44508 .32995 Mdot
.67988 .20978 Mdot
.45757 .62437 Mdot
.57832 .65069 Mdot
.34328 .52555 Mdot
.38631 .34952 Mdot
.29514 .47678 Mdot
.33998 .48866 Mdot
.39695 .60688 Mdot
.26108 .58555 Mdot
.6223 .48436 Mdot
.41482 .65694 Mdot
.42434 .80356 Mdot
.39549 .27327 Mdot
.32297 .46581 Mdot
.66156 .66592 Mdot
.44997 .35668 Mdot
.37627 .46645 Mdot
.6049 .67476 Mdot
.40941 .3661 Mdot
.45739 .367 Mdot
.36418 .45525 Mdot
.56074 .37311 Mdot
.45851 .54534 Mdot
.36701 .51052 Mdot
.50343 .7972 Mdot
.22412 .59075 Mdot
.41546 .65971 Mdot
.602 .64013 Mdot
.2682 .67984 Mdot
.42092 .34133 Mdot
.24149 .31921 Mdot
.43025 .79873 Mdot
.65434 .44959 Mdot
.59168 .65953 Mdot
.22636 .44811 Mdot
.49702 .16946 Mdot
.37774 .49303 Mdot
.48852 .44896 Mdot
.61342 .65229 Mdot
.65611 .40437 Mdot
.63341 .59206 Mdot
.62082 .47488 Mdot
.35449 .47384 Mdot
.47805 .25238 Mdot
.45631 .35538 Mdot
.36906 .45267 Mdot
.39893 .78912 Mdot
.63603 .45797 Mdot
.61465 .46586 Mdot
.68768 .55224 Mdot
.41194 .34165 Mdot
.40887 .63083 Mdot
.61643 .48172 Mdot
.62947 .4452 Mdot
.68455 .3975 Mdot
.64205 .52336 Mdot
.77752 .64964 Mdot
.65102 .48045 Mdot
.26557 .52168 Mdot
.611 .49751 Mdot
.61633 .46106 Mdot
.40283 .37686 Mdot
.8572 .48258 Mdot
.26758 .5606 Mdot
.63097 .44852 Mdot
.65731 .48257 Mdot
.35805 .45631 Mdot
.46945 .54251 Mdot
.51964 .57569 Mdot
.55095 .58461 Mdot
.6795 .67119 Mdot
.57885 .48555 Mdot
.44226 .32343 Mdot
.56603 .66678 Mdot
.62379 .4919 Mdot
.44505 .32484 Mdot
.6643 .40313 Mdot
.41834 .64365 Mdot
.46466 .66943 Mdot
.39101 .41518 Mdot
.58715 .65113 Mdot
.70856 .52074 Mdot
.31775 .40475 Mdot
.46317 .62264 Mdot
.65878 .46915 Mdot
.35895 .54844 Mdot
.43098 .5971 Mdot
.49745 .67063 Mdot
.55411 .48284 Mdot
.41311 .3504 Mdot
.44476 .36203 Mdot
.74583 .58808 Mdot
.33838 .622 Mdot
.82826 .48457 Mdot
.35007 .49377 Mdot
.61268 .39459 Mdot
.32081 .36152 Mdot
.44776 .36269 Mdot
.75422 .52064 Mdot
.58921 .6564 Mdot
.37915 .49126 Mdot
.37585 .69149 Mdot
.46312 .33974 Mdot
.45257 .37834 Mdot
.68528 .46038 Mdot
.62188 .43481 Mdot
.69614 .66821 Mdot
.58032 .61544 Mdot
.35375 .46569 Mdot
.60031 .63899 Mdot
.40651 .61165 Mdot
.65184 .48133 Mdot
.45176 .31674 Mdot
.25281 .63562 Mdot
.64914 .48534 Mdot
.42316 .65013 Mdot
.4459 .35584 Mdot
.59641 .63679 Mdot
.58681 .62898 Mdot
.65141 .4181 Mdot
.50559 .21414 Mdot
.36894 .50017 Mdot
.45534 .36092 Mdot
.26633 .482 Mdot
.59079 .4151 Mdot
.62869 .43393 Mdot
.61 .5163 Mdot
.37157 .45869 Mdot
.35739 .3547 Mdot
.61646 .66937 Mdot
.43196 .33513 Mdot
.6718 .45932 Mdot
.58565 .64369 Mdot
.34635 .35379 Mdot
.4471 .59954 Mdot
.4303 .66344 Mdot
.57711 .63249 Mdot
.59907 .65813 Mdot
.57758 .63418 Mdot
.24203 .31672 Mdot
.47573 .33207 Mdot
.73018 .4048 Mdot
.60715 .40127 Mdot
.73946 .57282 Mdot
.6107 .37474 Mdot
.38583 .46676 Mdot
.45959 .66512 Mdot
.59175 .44078 Mdot
.66041 .48369 Mdot
.63685 .51925 Mdot
.721 .46933 Mdot
.45862 .29729 Mdot
.45146 .34077 Mdot
.64663 .39066 Mdot
.47099 .66077 Mdot
.42922 .13576 Mdot
.2005 .65106 Mdot
.67386 .49252 Mdot
.4914 .56619 Mdot
.45448 .31742 Mdot
.33471 .4836 Mdot
.54425 .59867 Mdot
.37612 .5209 Mdot
.43321 .33982 Mdot
.65026 .48139 Mdot
.32639 .40398 Mdot
.57434 .63253 Mdot
.62875 .40674 Mdot
.3707 .46962 Mdot
.64101 .40699 Mdot
.3396 .49043 Mdot
.18651 .56546 Mdot
.57718 .79407 Mdot
.64658 .45282 Mdot
.64014 .49959 Mdot
.65698 .69169 Mdot
.60956 .43066 Mdot
.63791 .64779 Mdot
.45945 .31986 Mdot
.80637 .48414 Mdot
.68826 .43846 Mdot
.59336 .26172 Mdot
.58847 .41695 Mdot
.75719 .64857 Mdot
.62657 .43113 Mdot
.45791 .74526 Mdot
.67094 .43346 Mdot
.66033 .41576 Mdot
.37014 .52199 Mdot
.36091 .45536 Mdot
.41136 .38066 Mdot
.41631 .61846 Mdot
.17214 .45728 Mdot
.62891 .43892 Mdot
.29356 .65741 Mdot
.3327 .42551 Mdot
.60063 .65751 Mdot
.43033 .33933 Mdot
.61977 .16432 Mdot
.38188 .52286 Mdot
.61026 .74838 Mdot
.76085 .62554 Mdot
.28266 .49818 Mdot
.55416 .60441 Mdot
.29063 .31892 Mdot
.58444 .63868 Mdot
.64628 .39843 Mdot
.27539 .66174 Mdot
.4536 .76166 Mdot
.55185 .48069 Mdot
.3553 .45301 Mdot
.59965 .30139 Mdot
.26211 .65581 Mdot
.61788 .64997 Mdot
.61132 .67512 Mdot
.33702 .50547 Mdot
.38842 .69728 Mdot
.71962 .43519 Mdot
.59181 .65447 Mdot
.4676 .62528 Mdot
.42715 .67031 Mdot
.43234 .57791 Mdot
.41604 .34606 Mdot
.36111 .76618 Mdot
.26107 .43696 Mdot
.34248 .48381 Mdot
.46238 .70025 Mdot
.43642 .29781 Mdot
.48234 .34295 Mdot
.43766 .62338 Mdot
.42861 .65425 Mdot
.4653 .37609 Mdot
.68391 .40784 Mdot
.66332 .51099 Mdot
.6324 .45207 Mdot
.57552 .66571 Mdot
.62186 .42856 Mdot
.42214 .63924 Mdot
.37466 .49015 Mdot
.43876 .65856 Mdot
.38947 .51343 Mdot
.22844 .50643 Mdot
.62688 .41201 Mdot
.66326 .42958 Mdot
.75153 .33584 Mdot
.39863 .3581 Mdot
.25786 .51975 Mdot
.28802 .64291 Mdot
.46573 .6437 Mdot
.65867 .41081 Mdot
.42243 .31587 Mdot
.61917 .67116 Mdot
.74947 .32735 Mdot
.59007 .43062 Mdot
.45521 .31886 Mdot
.66912 .4664 Mdot
.42586 .24792 Mdot
.75485 .71454 Mdot
.423 .35021 Mdot
.78856 .3743 Mdot
.6701 .47278 Mdot
.3494 .27157 Mdot
.5874 .47584 Mdot
.74259 .62271 Mdot
.60854 .40263 Mdot
.41186 .37241 Mdot
.62731 .45043 Mdot
.41113 .33314 Mdot
.44969 .614 Mdot
.3331 .50195 Mdot
.44158 .37562 Mdot
.59441 .47445 Mdot
.13167 .62576 Mdot
.35432 .47749 Mdot
.6512 .44437 Mdot
.35238 .52783 Mdot
.43253 .32537 Mdot
.44057 .38031 Mdot
.45641 .1812 Mdot
.27445 .56806 Mdot
.35198 .49554 Mdot
.65755 .47716 Mdot
.26027 .39926 Mdot
.62522 .47267 Mdot
.70913 .63741 Mdot
.69294 .41759 Mdot
.59745 .40952 Mdot
.38348 .20068 Mdot
.36393 .45965 Mdot
.83214 .51149 Mdot
.44168 .18582 Mdot
.27539 .29726 Mdot
.39225 .37653 Mdot
.61933 .65495 Mdot
.19967 .37426 Mdot
.27314 .5965 Mdot
.41884 .62825 Mdot
.59398 .43596 Mdot
.43049 .29096 Mdot
.37314 .50536 Mdot
.58771 .67471 Mdot
.64703 .45211 Mdot
.43052 .65682 Mdot
.6715 .7376 Mdot
.36913 .53497 Mdot
.42277 .33934 Mdot
.47262 .34916 Mdot
.75301 .28486 Mdot
.67083 .45491 Mdot
.66556 .42789 Mdot
.35114 .4784 Mdot
.37067 .28823 Mdot
.58463 .63655 Mdot
.7083 .69558 Mdot
.35204 .49366 Mdot
.50113 .52352 Mdot
.4422 .33336 Mdot
.59919 .43522 Mdot
.22024 .40837 Mdot
.53117 .76989 Mdot
.67422 .27556 Mdot
.57307 .66027 Mdot
.70431 .63483 Mdot
.41259 .37421 Mdot
.37389 .4785 Mdot
.33188 .64276 Mdot
.55629 .44633 Mdot
.60185 .43829 Mdot
.70519 .62831 Mdot
.49796 .42415 Mdot
.7631 .46923 Mdot
.58867 .42835 Mdot
.50568 .44931 Mdot
.60099 .41225 Mdot
.55912 .42579 Mdot
.67252 .39269 Mdot
.63694 .43113 Mdot
.45524 .31838 Mdot
.54846 .45922 Mdot
.41282 .6344 Mdot
.74863 .44154 Mdot
.51687 .53099 Mdot
.66365 .44806 Mdot
.63078 .47884 Mdot
.67416 .29785 Mdot
.41137 .52494 Mdot
.44502 .37132 Mdot
.47978 .37211 Mdot
.33242 .51811 Mdot
.64999 .51654 Mdot
.4133 .61782 Mdot
.59153 .38618 Mdot
.42786 .65055 Mdot
.43942 .31608 Mdot
.4642 .6349 Mdot
.33709 .51859 Mdot
.4251 .66752 Mdot
.27194 .60248 Mdot
.38287 .48642 Mdot
.41201 .36149 Mdot
.6525 .42408 Mdot
.38827 .48055 Mdot
.68446 .56496 Mdot
.5752 .66445 Mdot
.4408 .18017 Mdot
.67956 .44023 Mdot
.30112 .46004 Mdot
.38444 .32318 Mdot
.43569 .65664 Mdot
.78694 .65952 Mdot
.47119 .35017 Mdot
.57641 .68842 Mdot
.43216 .31506 Mdot
.53074 .80561 Mdot
.59398 .66962 Mdot
.34788 .22826 Mdot
.3562 .69558 Mdot
.61011 .60789 Mdot
.68575 .41297 Mdot
.61412 .58073 Mdot
.40142 .62501 Mdot
.37393 .50475 Mdot
.34827 .65112 Mdot
.65728 .41201 Mdot
.62421 .76792 Mdot
.42652 .39373 Mdot
.41519 .62175 Mdot
.36832 .48032 Mdot
.38227 .46472 Mdot
.5853 .44793 Mdot
.50163 .69445 Mdot
.61177 .40866 Mdot
.32483 .60196 Mdot
.68528 .65996 Mdot
.71755 .45416 Mdot
.6605 .44276 Mdot
.43749 .61141 Mdot
.66863 .46695 Mdot
.5542 .67363 Mdot
.35458 .77142 Mdot
.57292 .44288 Mdot
.28314 .63409 Mdot
.62095 .68923 Mdot
.44591 .34636 Mdot
.70963 .42691 Mdot
.28171 .59813 Mdot
.66951 .46125 Mdot
.73213 .77764 Mdot
.5825 .6461 Mdot
.30001 .66985 Mdot
.58273 .47999 Mdot
.59468 .46979 Mdot
.54936 .52141 Mdot
.48046 .41027 Mdot
.53881 .76984 Mdot
.60854 .43995 Mdot
.66918 .61542 Mdot
.34176 .51006 Mdot
.60508 .4134 Mdot
.64224 .44452 Mdot
.57157 .35936 Mdot
.38318 .47026 Mdot
.46194 .6546 Mdot
.40756 .59773 Mdot
.45346 .67953 Mdot
.56001 .67785 Mdot
.48719 .47101 Mdot
.74403 .54538 Mdot
.6621 .76687 Mdot
.56638 .67329 Mdot
.68346 .45081 Mdot
.62491 .70782 Mdot
.63827 .48488 Mdot
.60366 .67226 Mdot
.38395 .47423 Mdot
.44716 .37199 Mdot
.32813 .34193 Mdot
.4029 .65208 Mdot
.58005 .45488 Mdot
.60362 .63709 Mdot
.41263 .3587 Mdot
.5586 .62432 Mdot
.44088 .34001 Mdot
.35614 .49091 Mdot
.34183 .53369 Mdot
.5946 .6764 Mdot
.44347 .31923 Mdot
.41014 .47591 Mdot
.50169 .17145 Mdot
.6717 .38932 Mdot
.31749 .5136 Mdot
.39885 .34316 Mdot
.472 .37451 Mdot
.40325 .35161 Mdot
.64493 .41113 Mdot
.48882 .56402 Mdot
.69705 .44907 Mdot
.35304 .4669 Mdot
.46878 .65602 Mdot
.65233 .71805 Mdot
.23045 .55722 Mdot
.54287 .68296 Mdot
.61866 .39264 Mdot
.63224 .45837 Mdot
.64975 .44262 Mdot
.68953 .45809 Mdot
.3147 .60606 Mdot
.60466 .42104 Mdot
.36608 .52415 Mdot
.43092 .64404 Mdot
.64955 .39909 Mdot
.41964 .58778 Mdot
.26294 .35448 Mdot
.57047 .67671 Mdot
.48112 .45421 Mdot
.12321 .54439 Mdot
.41658 .3691 Mdot
.45573 .60951 Mdot
.42058 .62668 Mdot
.57108 .64254 Mdot
.36792 .50513 Mdot
.4394 .33486 Mdot
.72438 .64779 Mdot
.58775 .6312 Mdot
.6282 .44846 Mdot
.51173 .59587 Mdot
.61019 .76808 Mdot
.63502 .39682 Mdot
.5971 .46019 Mdot
.4412 .59593 Mdot
.41864 .72377 Mdot
.38631 .82003 Mdot
.7369 .52226 Mdot
.59326 .67482 Mdot
.58621 .68595 Mdot
.46042 .38103 Mdot
.6943 .4713 Mdot
.35098 .46913 Mdot
.76112 .45332 Mdot
.42871 .43437 Mdot
.72006 .51307 Mdot
.51833 .41622 Mdot
.59239 .42897 Mdot
.58178 .19386 Mdot
.63706 .45932 Mdot
.46375 .32019 Mdot
.42307 .32762 Mdot
.42741 .37078 Mdot
.37297 .50216 Mdot
.55476 .31562 Mdot
.36326 .52276 Mdot
.13327 .56088 Mdot
.41736 .37941 Mdot
.31476 .65108 Mdot
.43989 .61417 Mdot
.65831 .50127 Mdot
.59455 .63744 Mdot
.36209 .44425 Mdot
.61994 .50612 Mdot
.78917 .63269 Mdot
.41419 .62736 Mdot
.41301 .36601 Mdot
.29967 .3101 Mdot
.16417 .56932 Mdot
.53233 .58466 Mdot
.57635 .38808 Mdot
.60382 .57805 Mdot
.60229 .6551 Mdot
.67941 .27824 Mdot
.60785 .64309 Mdot
.3765 .47262 Mdot
.65913 .43094 Mdot
.64784 .4275 Mdot
.60547 .40732 Mdot
.61505 .41623 Mdot
.33267 .48748 Mdot
.58514 .41641 Mdot
.70121 .7724 Mdot
.47232 .66548 Mdot
.46764 .27554 Mdot
.58449 .64147 Mdot
.33809 .46893 Mdot
.42903 .64355 Mdot
.38297 .59401 Mdot
.71073 .54938 Mdot
.66531 .44325 Mdot
.59244 .43785 Mdot
.60492 .75549 Mdot
.58838 .42748 Mdot
.62006 .3711 Mdot
.41927 .62547 Mdot
.54874 .68892 Mdot
.58292 .68772 Mdot
.59959 .68247 Mdot
.38554 .4964 Mdot
.43783 .31681 Mdot
.58119 .65716 Mdot
.45404 .61831 Mdot
.62015 .39157 Mdot
.61215 .48349 Mdot
.39916 .34776 Mdot
.4396 .80228 Mdot
.61642 .65089 Mdot
.28219 .32858 Mdot
.42009 .32407 Mdot
.45881 .30713 Mdot
.60166 .44004 Mdot
.58549 .5244 Mdot
.38609 .34077 Mdot
.56412 .67205 Mdot
.33432 .47546 Mdot
.55783 .58926 Mdot
.36055 .46738 Mdot
.42457 .33139 Mdot
.62865 .49105 Mdot
.41888 .33227 Mdot
.66985 .45104 Mdot
.12671 .46638 Mdot
.63881 .42783 Mdot
.66005 .77339 Mdot
.73503 .60427 Mdot
.43268 .63302 Mdot
.38991 .43366 Mdot
.43071 .61841 Mdot
.4181 .32589 Mdot
.61737 .48872 Mdot
.61219 .67699 Mdot
.30928 .2646 Mdot
.44336 .29696 Mdot
.4175 .64801 Mdot
.42559 .67421 Mdot
.3827 .47724 Mdot
.63018 .39399 Mdot
.60251 .43362 Mdot
.446 .63907 Mdot
.71988 .45157 Mdot
.46322 .33369 Mdot
.6629 .4355 Mdot
.62322 .4595 Mdot
.43266 .63062 Mdot
.52255 .1661 Mdot
.47921 .40162 Mdot
.65027 .43257 Mdot
.33635 .69248 Mdot
.38432 .46392 Mdot
.69102 .42264 Mdot
.61564 .50123 Mdot
.59702 .65688 Mdot
.51342 .3431 Mdot
.33706 .75454 Mdot
.39031 .49369 Mdot
.42617 .61421 Mdot
.67184 .45563 Mdot
.4352 .61176 Mdot
.60253 .47839 Mdot
.50891 .36904 Mdot
.40822 .64118 Mdot
.60344 .47276 Mdot
.70188 .46256 Mdot
.41223 .33944 Mdot
.59203 .43329 Mdot
.68261 .31792 Mdot
.42204 .59731 Mdot
.59177 .46553 Mdot
.50324 .21636 Mdot
.36102 .51234 Mdot
.69975 .4673 Mdot
.56822 .66738 Mdot
.72531 .64958 Mdot
.29196 .42675 Mdot
.28948 .67387 Mdot
.57636 .67919 Mdot
.63765 .40559 Mdot
.43717 .67709 Mdot
.33766 .49757 Mdot
.68148 .75433 Mdot
.64496 .40099 Mdot
.35524 .47366 Mdot
.37385 .48802 Mdot
.56963 .65752 Mdot
.82001 .40025 Mdot
.57876 .47882 Mdot
.61312 .42902 Mdot
.64043 .33505 Mdot
.40103 .32265 Mdot
.62897 .42608 Mdot
.67464 .47199 Mdot
.36201 .52572 Mdot
.62093 .36968 Mdot
.6295 .29306 Mdot
.72998 .67029 Mdot
.39008 .46873 Mdot
.55645 .56567 Mdot
.40704 .6517 Mdot
.59006 .64271 Mdot
.44087 .34974 Mdot
.6097 .64198 Mdot
.43261 .66804 Mdot
.68253 .45696 Mdot
.36461 .53085 Mdot
.72485 .3438 Mdot
.33648 .50388 Mdot
.2938 .68032 Mdot
.40038 .32704 Mdot
.30425 .36796 Mdot
.78398 .71955 Mdot
.25363 .44631 Mdot
.40961 .52607 Mdot
.60041 .65786 Mdot
.3835 .61372 Mdot
.62612 .45971 Mdot
.69927 .29125 Mdot
.65521 .42075 Mdot
.50809 .21956 Mdot
.47299 .63633 Mdot
.45355 .67358 Mdot
.65521 .43167 Mdot
.69139 .65466 Mdot
.3369 .49465 Mdot
.36874 .46038 Mdot
.5886 .45819 Mdot
.35933 .49532 Mdot
.61874 .4362 Mdot
.4239 .64535 Mdot
.83736 .54545 Mdot
.6389 .45171 Mdot
.65367 .49401 Mdot
.29941 .48775 Mdot
.39773 .20282 Mdot
.35907 .73511 Mdot
.64064 .2191 Mdot
.17738 .59889 Mdot
.35983 .49414 Mdot
.69858 .45018 Mdot
.56006 .56592 Mdot
.41616 .58706 Mdot
.41255 .48182 Mdot
.63974 .42136 Mdot
.64121 .41865 Mdot
.66356 .41786 Mdot
.61516 .46719 Mdot
.67823 .27185 Mdot
.72662 .38122 Mdot
.51049 .25648 Mdot
.58937 .44567 Mdot
.63608 .57599 Mdot
.38729 .501 Mdot
.43643 .39897 Mdot
.58302 .61917 Mdot
.59262 .42896 Mdot
.73054 .3952 Mdot
.37365 .45239 Mdot
.1338 .56252 Mdot
.38478 .48533 Mdot
.46067 .64968 Mdot
.33479 .48569 Mdot
.6572 .45888 Mdot
.43175 .35099 Mdot
.53411 .55374 Mdot
.32412 .56808 Mdot
.41849 .62905 Mdot
.66326 .45129 Mdot
.30455 .64468 Mdot
.41417 .63379 Mdot
.25972 .35979 Mdot
.4367 .35405 Mdot
.66865 .60712 Mdot
.42148 .32817 Mdot
.60454 .47426 Mdot
.61133 .47653 Mdot
.32075 .49041 Mdot
.33396 .50634 Mdot
.42305 .32625 Mdot
.83338 .41701 Mdot
.60207 .63149 Mdot
.42311 .36701 Mdot
.57415 .40963 Mdot
.44896 .4992 Mdot
.43244 .35832 Mdot
.53493 .66587 Mdot
.37854 .50079 Mdot
.43576 .38805 Mdot
.5594 .43581 Mdot
.44779 .78939 Mdot
.5624 .65482 Mdot
.48978 .65931 Mdot
.51498 .61083 Mdot
.42833 .59718 Mdot
.32772 .49922 Mdot
.42886 .621 Mdot
.34335 .5137 Mdot
.30843 .43374 Mdot
.74378 .46436 Mdot
.3571 .54616 Mdot
.32908 .49714 Mdot
.43016 .62351 Mdot
.66729 .43453 Mdot
.52815 .61277 Mdot
.69702 .43977 Mdot
.56859 .46957 Mdot
.34559 .50997 Mdot
.41082 .36823 Mdot
.4736 .36541 Mdot
.63395 .58724 Mdot
.4721 .33954 Mdot
.42776 .65173 Mdot
.72931 .735 Mdot
.27987 .65396 Mdot
.34493 .49283 Mdot
.34083 .46986 Mdot
.6261 .47456 Mdot
.45081 .63157 Mdot
.43918 .60857 Mdot
.37668 .46946 Mdot
.69879 .5097 Mdot
.67671 .48569 Mdot
.48188 .36556 Mdot
.42586 .3845 Mdot
.42481 .3554 Mdot
.40435 .34819 Mdot
.62316 .26694 Mdot
.38101 .49728 Mdot
.40846 .36041 Mdot
.59728 .46768 Mdot
.63948 .41951 Mdot
.54589 .57693 Mdot
.59202 .68508 Mdot
.66641 .40522 Mdot
.66986 .39254 Mdot
.59893 .44067 Mdot
.42643 .66176 Mdot
.58335 .50389 Mdot
.40735 .63788 Mdot
.4655 .67504 Mdot
.47918 .65328 Mdot
.27319 .59899 Mdot
.63925 .6246 Mdot
.20611 .63595 Mdot
.66343 .47485 Mdot
.38541 .2712 Mdot
.44875 .62184 Mdot
.78761 .648 Mdot
.3573 .34847 Mdot
.65338 .40569 Mdot
.5097 .77064 Mdot
.44419 .63686 Mdot
.47341 .34447 Mdot
.63923 .42333 Mdot
.47532 .67253 Mdot
.56483 .66044 Mdot
.62374 .38499 Mdot
.41338 .59549 Mdot
.44132 .32027 Mdot
.56282 .63476 Mdot
.42206 .38481 Mdot
.4785 .64977 Mdot
.70095 .46451 Mdot
.43629 .87846 Mdot
.41142 .66944 Mdot
.40529 .22654 Mdot
.42403 .41023 Mdot
.66429 .43467 Mdot
.4461 .60271 Mdot
.4107 .3156 Mdot
.32772 .51465 Mdot
.4407 .4438 Mdot
.4609 .36766 Mdot
.45087 .67384 Mdot
.41845 .59466 Mdot
.41867 .62623 Mdot
.4536 .34572 Mdot
.65685 .49057 Mdot
.45986 .34763 Mdot
.33557 .48287 Mdot
.63664 .47018 Mdot
.15817 .53309 Mdot
.3858 .27369 Mdot
.42144 .32485 Mdot
.45772 .65902 Mdot
.57072 .63373 Mdot
.64586 .45613 Mdot
.43688 .22086 Mdot
.67343 .44217 Mdot
.34102 .49813 Mdot
.81199 .56473 Mdot
.72071 .3342 Mdot
.60553 .40301 Mdot
.62508 .47422 Mdot
.36008 .46167 Mdot
.65672 .44917 Mdot
.61322 .39962 Mdot
.27395 .58864 Mdot
.45327 .33739 Mdot
.62665 .45299 Mdot
.4717 .64492 Mdot
.25631 .59378 Mdot
.68353 .47601 Mdot
.56705 .71966 Mdot
.68024 .62218 Mdot
.81561 .50973 Mdot
.65806 .42146 Mdot
.73009 .51575 Mdot
.60832 .46248 Mdot
.62682 .40821 Mdot
.64187 .47962 Mdot
.69581 .27017 Mdot
.41155 .64684 Mdot
.42332 .63356 Mdot
.56149 .65993 Mdot
.67764 .62096 Mdot
.59352 .65852 Mdot
.3794 .50413 Mdot
.52707 .70648 Mdot
.40839 .64069 Mdot
.43773 .31918 Mdot
.62538 .40526 Mdot
.41139 .66991 Mdot
.60039 .43171 Mdot
.65894 .45946 Mdot
.41544 .60976 Mdot
.40314 .64176 Mdot
.29478 .67057 Mdot
.56923 .6728 Mdot
.4342 .37341 Mdot
.67415 .40722 Mdot
.59943 .63459 Mdot
.63761 .49399 Mdot
.7425 .56773 Mdot
.43272 .37135 Mdot
.45572 .33999 Mdot
.47309 .36157 Mdot
.68231 .4568 Mdot
.65499 .45625 Mdot
.36046 .52265 Mdot
.43157 .31669 Mdot
.36057 .51033 Mdot
.50773 .50772 Mdot
.59619 .72722 Mdot
.6398 .42125 Mdot
.29102 .32543 Mdot
.59678 .64472 Mdot
.44614 .65597 Mdot
.62695 .7433 Mdot
.56111 .65712 Mdot
.67001 .44746 Mdot
.43092 .60893 Mdot
.60179 .67634 Mdot
.53692 .45703 Mdot
.24386 .70401 Mdot
.5762 .62625 Mdot
.5947 .4651 Mdot
.6287 .36505 Mdot
.66011 .22135 Mdot
.55942 .64994 Mdot
.34829 .52847 Mdot
.68246 .45425 Mdot
.39556 .30888 Mdot
.61589 .65306 Mdot
.25885 .51167 Mdot
.43686 .64152 Mdot
.38635 .77255 Mdot
.5991 .5041 Mdot
.73523 .33256 Mdot
.6103 .65413 Mdot
.4363 .33499 Mdot
.43941 .4036 Mdot
.60233 .44824 Mdot
.55958 .64879 Mdot
.38896 .46385 Mdot
.43959 .64765 Mdot
.2669 .5637 Mdot
.4548 .34788 Mdot
.28774 .35754 Mdot
.45249 .66329 Mdot
.27821 .34116 Mdot
.7707 .62998 Mdot
.68297 .4974 Mdot
.65228 .22487 Mdot
.36504 .67389 Mdot
.68565 .44563 Mdot
.59693 .62655 Mdot
.38978 .48988 Mdot
.34864 .53086 Mdot
.35368 .48935 Mdot
.32499 .42744 Mdot
.54548 .58675 Mdot
.46468 .61627 Mdot
.37239 .57045 Mdot
.58814 .64459 Mdot
.65016 .56494 Mdot
.60056 .48156 Mdot
.63337 .4571 Mdot
.63055 .39312 Mdot
.59734 .41951 Mdot
.60874 .45698 Mdot
.36275 .50338 Mdot
.2981 .44827 Mdot
.56136 .57868 Mdot
.43287 .36586 Mdot
.49846 .6869 Mdot
.4409 .61487 Mdot
.47346 .62553 Mdot
.59098 .68106 Mdot
.27418 .32857 Mdot
.41879 .58859 Mdot
.46594 .63971 Mdot
.67726 .42471 Mdot
.4621 .33926 Mdot
.563 .40869 Mdot
.61211 .47389 Mdot
.4351 .65236 Mdot
.53892 .51986 Mdot
.65336 .29635 Mdot
.56677 .49442 Mdot
.59315 .70511 Mdot
.487 .55747 Mdot
.56535 .63795 Mdot
.61173 .48948 Mdot
.7926 .63673 Mdot
.42858 .6668 Mdot
.45822 .64169 Mdot
.60802 .6514 Mdot
.48283 .30853 Mdot
.44771 .35385 Mdot
.37773 .60024 Mdot
.34808 .52501 Mdot
.62725 .48368 Mdot
.66867 .7337 Mdot
.44036 .27452 Mdot
.50297 .69868 Mdot
.3511 .4878 Mdot
.44459 .61194 Mdot
.61521 .39548 Mdot
.59534 .46468 Mdot
.60265 .64672 Mdot
.19247 .51074 Mdot
.64405 .38629 Mdot
.26453 .30398 Mdot
.57499 .79638 Mdot
.44738 .7979 Mdot
.60201 .43811 Mdot
.4529 .33911 Mdot
.4166 .59241 Mdot
.60186 .64036 Mdot
.5693 .42826 Mdot
.23135 .68098 Mdot
.40444 .36794 Mdot
.3765 .47647 Mdot
.5391 .54463 Mdot
.54245 .59785 Mdot
.68003 .43608 Mdot
.65431 .42162 Mdot
.63636 .41089 Mdot
.29961 .75301 Mdot
.42476 .6575 Mdot
.44683 .31496 Mdot
.57301 .6671 Mdot
.4705 .33286 Mdot
.42685 .63096 Mdot
.29152 .36634 Mdot
.67176 .43623 Mdot
.4027 .36524 Mdot
.43688 .33744 Mdot
.38341 .4809 Mdot
.33022 .52219 Mdot
.52151 .52641 Mdot
.63671 .42864 Mdot
.40409 .66249 Mdot
.40924 .35071 Mdot
.51541 .59683 Mdot
.59523 .66823 Mdot
.37576 .51563 Mdot
.59033 .44153 Mdot
.41704 .65696 Mdot
.58428 .41706 Mdot
.44578 .36453 Mdot
.46525 .63789 Mdot
.29609 .66469 Mdot
.58128 .68393 Mdot
.6251 .41834 Mdot
.55414 .65488 Mdot
.426 .61373 Mdot
.62458 .46106 Mdot
.323 .28154 Mdot
.60493 .70437 Mdot
.30544 .56068 Mdot
.47503 .63625 Mdot
.29469 .65563 Mdot
.46479 .37152 Mdot
.35074 .41199 Mdot
.45874 .64581 Mdot
.29226 .31158 Mdot
.20651 .54163 Mdot
.63725 .3906 Mdot
.42048 .34515 Mdot
.37879 .65676 Mdot
.15046 .4688 Mdot
.5188 .17226 Mdot
.64911 .44447 Mdot
.46578 .61983 Mdot
.6069 .65378 Mdot
.34422 .49501 Mdot
.57374 .72244 Mdot
.59419 .70686 Mdot
.4107 .66415 Mdot
.64199 .4804 Mdot
.43478 .32731 Mdot
.37505 .49771 Mdot
.29519 .43016 Mdot
.46382 .62692 Mdot
.46347 .66088 Mdot
.61307 .39673 Mdot
.58856 .65552 Mdot
.47472 .20227 Mdot
.42163 .64279 Mdot
.60026 .76351 Mdot
.39834 .61551 Mdot
.60099 .63274 Mdot
.60259 .46222 Mdot
.62441 .59062 Mdot
.69312 .4444 Mdot
.37261 .23167 Mdot
.43461 .6187 Mdot
.44131 .3684 Mdot
.65221 .41343 Mdot
.74769 .648 Mdot
.43943 .65289 Mdot
.49394 .56696 Mdot
.44808 .74583 Mdot
.37995 .49894 Mdot
.62671 .74502 Mdot
.62159 .42538 Mdot
.337 .49653 Mdot
.59712 .64591 Mdot
.64376 .4323 Mdot
.65293 .45838 Mdot
.442 .31021 Mdot
.37413 .46899 Mdot
.21228 .57836 Mdot
.36728 .45236 Mdot
.38217 .51523 Mdot
.46703 .3189 Mdot
.6156 .44563 Mdot
.46122 .65111 Mdot
.44603 .6366 Mdot
.56531 .45151 Mdot
.81295 .62799 Mdot
.45053 .35435 Mdot
.45431 .70006 Mdot
.32274 .77089 Mdot
.69458 .48861 Mdot
.63573 .74271 Mdot
.19568 .50006 Mdot
.3943 .48052 Mdot
.58796 .45266 Mdot
.43621 .32185 Mdot
.38677 .59073 Mdot
.46288 .65952 Mdot
.64898 .49159 Mdot
.37142 .49271 Mdot
.56394 .65951 Mdot
.41142 .60667 Mdot
.50529 .69272 Mdot
.62271 .41176 Mdot
.50671 .77351 Mdot
.44537 .60503 Mdot
.21509 .33221 Mdot
.3749 .62666 Mdot
.4198 .35086 Mdot
.65646 .46181 Mdot
.46977 .35938 Mdot
.57717 .67177 Mdot
.53548 .54289 Mdot
.37339 .4916 Mdot
.68003 .36126 Mdot
.64998 .81745 Mdot
.41946 .62317 Mdot
.45853 .31905 Mdot
.60311 .4044 Mdot
.53222 .48252 Mdot
.61765 .4299 Mdot
.67671 .37068 Mdot
.62254 .69507 Mdot
.34912 .51136 Mdot
.33948 .50864 Mdot
.62897 .46443 Mdot
.58388 .63396 Mdot
.44874 .61566 Mdot
.44268 .64961 Mdot
.33349 .20163 Mdot
.30757 .53412 Mdot
.70093 .6646 Mdot
.63715 .41762 Mdot
.43175 .67349 Mdot
.23668 .56611 Mdot
.3505 .47995 Mdot
.58982 .47516 Mdot
.41318 .61927 Mdot
.47151 .78613 Mdot
.75349 .62017 Mdot
.60498 .45624 Mdot
.59318 .49468 Mdot
.34892 .52645 Mdot
.67139 .55318 Mdot
.47623 .6556 Mdot
.69245 .41441 Mdot
.36116 .54232 Mdot
.80083 .56557 Mdot
.39767 .79997 Mdot
.43357 .37351 Mdot
.42896 .73144 Mdot
.36351 .50394 Mdot
.56917 .47888 Mdot
.57835 .6437 Mdot
.40569 .61056 Mdot
.41948 .65544 Mdot
.65677 .47558 Mdot
.58707 .41473 Mdot
.64868 .69997 Mdot
.46729 .3315 Mdot
.38669 .50085 Mdot
.66206 .42635 Mdot
.32555 .32929 Mdot
.60309 .40941 Mdot
.36082 .52046 Mdot
.42129 .88263 Mdot
.66699 .40136 Mdot
.61466 .43094 Mdot
.47553 .20009 Mdot
.45947 .36898 Mdot
.46876 .32594 Mdot
.61805 .79117 Mdot
.63614 .41755 Mdot
.61626 .75184 Mdot
.43795 .37482 Mdot
.44924 .35728 Mdot
.28362 .57711 Mdot
.64173 .45565 Mdot
.76183 .40831 Mdot
.34017 .49122 Mdot
.37774 .52104 Mdot
.45852 .34906 Mdot
.65788 .39444 Mdot
.38699 .51899 Mdot
.62951 .24002 Mdot
.44976 .62982 Mdot
.80487 .61733 Mdot
.45516 .36419 Mdot
.49547 .44773 Mdot
.34952 .48575 Mdot
.13221 .55829 Mdot
.41982 .57938 Mdot
.66642 .43289 Mdot
.62835 .41584 Mdot
.59446 .64319 Mdot
.66542 .40148 Mdot
.45836 .67276 Mdot
.35905 .49579 Mdot
.46015 .23924 Mdot
.42637 .37047 Mdot
.62855 .4316 Mdot
.2694 .34299 Mdot
.24176 .48609 Mdot
.3679 .72633 Mdot
.44495 .34598 Mdot
.41691 .34662 Mdot
.47452 .65655 Mdot
.46218 .61632 Mdot
.60894 .44763 Mdot
.36199 .46281 Mdot
.4293 .31785 Mdot
.35304 .51855 Mdot
.42934 .66673 Mdot
.4641 .65042 Mdot
.40914 .64639 Mdot
.64114 .37814 Mdot
.46813 .63944 Mdot
.52891 .67946 Mdot
.28171 .36732 Mdot
.48219 .34121 Mdot
.49502 .82862 Mdot
.30216 .42532 Mdot
.40627 .42203 Mdot
.61627 .66754 Mdot
.42551 .61336 Mdot
.34467 .46705 Mdot
.62254 .46993 Mdot
.59601 .4344 Mdot
.49404 .635 Mdot
.34027 .47704 Mdot
.58455 .67448 Mdot
.33581 .49322 Mdot
.56945 .6568 Mdot
.46598 .76429 Mdot
.63762 .39479 Mdot
.61194 .4821 Mdot
.35832 .50114 Mdot
.46608 .63647 Mdot
.42876 .63965 Mdot
.56987 .62975 Mdot
.50881 .40573 Mdot
.41369 .63228 Mdot
.4527 .36488 Mdot
.60962 .25432 Mdot
.4199 .59376 Mdot
.6351 .42406 Mdot
.7488 .53807 Mdot
.71913 .31426 Mdot
.68931 .45954 Mdot
.2787 .58017 Mdot
.77701 .37893 Mdot
.64767 .4068 Mdot
.78018 .36055 Mdot
.29481 .65079 Mdot
.46648 .36213 Mdot
.47449 .64112 Mdot
.45054 .60021 Mdot
.68883 .38616 Mdot
.5981 .62061 Mdot
.56624 .43541 Mdot
.45401 .37279 Mdot
.40632 .38262 Mdot
.48948 .7998 Mdot
.39997 .22681 Mdot
.60762 .66085 Mdot
.5979 .68099 Mdot
.45621 .64694 Mdot
.4963 .15419 Mdot
.55705 .47223 Mdot
.59091 .67533 Mdot
.73168 .48526 Mdot
.64379 .48151 Mdot
.714 .61764 Mdot
.57841 .76882 Mdot
.4549 .34383 Mdot
.61791 .5837 Mdot
.45394 .65264 Mdot
.47034 .34161 Mdot
.33373 .33684 Mdot
.67731 .4146 Mdot
.43084 .37083 Mdot
.35376 .52054 Mdot
.35692 .6374 Mdot
.43963 .37999 Mdot
.74741 .54862 Mdot
.3742 .46609 Mdot
.51271 .59155 Mdot
.65039 .59279 Mdot
.89656 .53816 Mdot
.36278 .49997 Mdot
.40664 .62429 Mdot
.44582 .63756 Mdot
.4445 .64952 Mdot
.47006 .33593 Mdot
.43728 .60897 Mdot
.46361 .32543 Mdot
.59542 .18221 Mdot
.51646 .40055 Mdot
.59545 .67518 Mdot
.27288 .56241 Mdot
.42701 .33591 Mdot
.75974 .70373 Mdot
.73274 .76469 Mdot
.5871 .44928 Mdot
.35325 .45702 Mdot
.60229 .6722 Mdot
.28689 .27073 Mdot
.59727 .65331 Mdot
.59579 .60605 Mdot
.81425 .57589 Mdot
.62437 .43651 Mdot
.59544 .31491 Mdot
.60601 .68146 Mdot
.44297 .33521 Mdot
.62769 .46069 Mdot
.41593 .51317 Mdot
.59359 .65213 Mdot
.56656 .6529 Mdot
.61554 .45281 Mdot
.4127 .36538 Mdot
.45586 .65596 Mdot
.33228 .51094 Mdot
.5781 .69146 Mdot
.47489 .39018 Mdot
.68578 .43542 Mdot
.67533 .45461 Mdot
.52354 .57316 Mdot
.53889 .64206 Mdot
.36048 .49392 Mdot
.73815 .31079 Mdot
.46804 .6243 Mdot
.39084 .67792 Mdot
.57583 .78847 Mdot
.27943 .5964 Mdot
.43473 .62081 Mdot
.42767 .61566 Mdot
.60705 .45382 Mdot
.53812 .65424 Mdot
.81795 .53736 Mdot
.40733 .47623 Mdot
.41876 .59178 Mdot
.43935 .64914 Mdot
.41472 .39264 Mdot
.50228 .80333 Mdot
.57122 .42443 Mdot
.39097 .49963 Mdot
.4164 .65463 Mdot
.50539 .36032 Mdot
.58607 .65263 Mdot
.76892 .67876 Mdot
.64051 .39583 Mdot
.66324 .43016 Mdot
.36427 .48242 Mdot
.36498 .52279 Mdot
.39894 .56223 Mdot
.55763 .79727 Mdot
.76417 .36365 Mdot
.28249 .45092 Mdot
.53286 .37167 Mdot
.41913 .39276 Mdot
.42099 .32528 Mdot
.26879 .51664 Mdot
.36983 .45188 Mdot
.64943 .40947 Mdot
.43297 .31864 Mdot
.35591 .68588 Mdot
.3927 .27611 Mdot
.70569 .64031 Mdot
.64627 .72795 Mdot
.66856 .45073 Mdot
.45594 .33248 Mdot
.45931 .36731 Mdot
.41207 .32391 Mdot
.29498 .64662 Mdot
.60859 .43938 Mdot
.66172 .44394 Mdot
.63072 .40202 Mdot
.68591 .51104 Mdot
.60917 .41762 Mdot
.34494 .42392 Mdot
.50277 .52945 Mdot
.49243 .29278 Mdot
.68744 .40636 Mdot
.3945 .50266 Mdot
.68099 .43914 Mdot
.58084 .63513 Mdot
.6357 .47867 Mdot
.70905 .64216 Mdot
.36335 .47111 Mdot
.45856 .41057 Mdot
.30891 .42915 Mdot
.67119 .42157 Mdot
.57005 .67925 Mdot
.439 .42718 Mdot
.1834 .56553 Mdot
.58691 .61544 Mdot
.45332 .3643 Mdot
.44442 .62438 Mdot
.34494 .46797 Mdot
.46374 .64443 Mdot
.63768 .37898 Mdot
.27452 .52099 Mdot
.23063 .44047 Mdot
.50996 .49483 Mdot
.59543 .4241 Mdot
.61434 .51265 Mdot
.44987 .36206 Mdot
.43007 .60877 Mdot
.42947 .28144 Mdot
.64783 .41292 Mdot
.57355 .66324 Mdot
.59265 .64769 Mdot
.41848 .48303 Mdot
.19735 .41114 Mdot
.36956 .40542 Mdot
.36238 .48491 Mdot
.42017 .64457 Mdot
.60917 .64396 Mdot
.35461 .27605 Mdot
.32732 .51761 Mdot
.35988 .46127 Mdot
.37943 .47765 Mdot
.66604 .47709 Mdot
.40725 .63871 Mdot
.48881 .28393 Mdot
.43737 .67359 Mdot
.65947 .45068 Mdot
.42968 .66119 Mdot
.41382 .62324 Mdot
.58765 .64014 Mdot
.38591 .49197 Mdot
.44717 .66974 Mdot
.60428 .47459 Mdot
.42411 .37485 Mdot
.49143 .42577 Mdot
.74779 .60367 Mdot
.38061 .24173 Mdot
.42435 .25391 Mdot
.43433 .3848 Mdot
.15535 .48127 Mdot
.38552 .46451 Mdot
.69125 .51471 Mdot
.32421 .6905 Mdot
.63565 .4907 Mdot
.77633 .69591 Mdot
.46274 .61402 Mdot
.41213 .61312 Mdot
.60498 .46375 Mdot
.38984 .69957 Mdot
.62439 .43177 Mdot
.44303 .66707 Mdot
.48791 .6918 Mdot
.7088 .44909 Mdot
.45881 .62539 Mdot
.69207 .41065 Mdot
.64272 .46043 Mdot
.45574 .34249 Mdot
.44336 .60153 Mdot
.58704 .4731 Mdot
.29145 .24473 Mdot
.36836 .51943 Mdot
.30013 .63727 Mdot
.76508 .51478 Mdot
.36409 .50534 Mdot
.42325 .3648 Mdot
.56787 .46606 Mdot
.60018 .64616 Mdot
.4278 .33225 Mdot
.75759 .62146 Mdot
.59953 .68395 Mdot
.76172 .70818 Mdot
.4592 .35951 Mdot
.42327 .59383 Mdot
.57753 .64209 Mdot
.69794 .44909 Mdot
.40548 .61271 Mdot
.42261 .44104 Mdot
.43658 .61941 Mdot
.60302 .43247 Mdot
.26359 .55106 Mdot
.38522 .50691 Mdot
.64686 .44303 Mdot
.4151 .60484 Mdot
.27117 .58685 Mdot
.66551 .47659 Mdot
.61741 .46481 Mdot
.44745 .80382 Mdot
.71873 .72615 Mdot
.5996 .66155 Mdot
.41642 .31425 Mdot
.59778 .46816 Mdot
.56603 .6601 Mdot
.51107 .74799 Mdot
.68114 .44919 Mdot
.40076 .3582 Mdot
.59009 .51899 Mdot
.43525 .60177 Mdot
.36612 .51147 Mdot
.50468 .48867 Mdot
.56504 .66123 Mdot
.7903 .30351 Mdot
.42253 .66744 Mdot
.60584 .48706 Mdot
.59198 .42671 Mdot
.36486 .74084 Mdot
.46682 .35883 Mdot
.76707 .39072 Mdot
.62528 .41812 Mdot
.69571 .50345 Mdot
.64086 .43429 Mdot
.47929 .68398 Mdot
.44869 .35484 Mdot
.61127 .4295 Mdot
.28951 .33799 Mdot
.66544 .49098 Mdot
.56574 .66954 Mdot
.50125 .1881 Mdot
.68697 .44272 Mdot
.54311 .88014 Mdot
.60584 .74759 Mdot
.46055 .62622 Mdot
.2646 .52396 Mdot
.47429 .12659 Mdot
.32519 .42338 Mdot
.45944 .32125 Mdot
.20582 .47692 Mdot
.46164 .65141 Mdot
.2498 .53462 Mdot
.15174 .48224 Mdot
.64244 .46317 Mdot
.67999 .43589 Mdot
.60196 .60844 Mdot
.47376 .66735 Mdot
.40008 .65054 Mdot
.6593 .38417 Mdot
.55367 .44796 Mdot
.4671 .65216 Mdot
.59508 .46998 Mdot
.66121 .38046 Mdot
.33193 .49943 Mdot
.42959 .38307 Mdot
.34399 .50196 Mdot
.38406 .47702 Mdot
.58895 .20553 Mdot
.53548 .79352 Mdot
.36434 .51901 Mdot
.39066 .48024 Mdot
.71695 .6198 Mdot
.66181 .66399 Mdot
.61623 .65528 Mdot
.22061 .34716 Mdot
.44349 .64716 Mdot
.61188 .4405 Mdot
.44683 .38233 Mdot
.74129 .34666 Mdot
.56671 .73646 Mdot
.82284 .5424 Mdot
.64809 .41085 Mdot
.44574 .65343 Mdot
.2941 .64604 Mdot
.5783 .39383 Mdot
.3864 .63475 Mdot
.66522 .42628 Mdot
.40363 .65416 Mdot
.59737 .27604 Mdot
.28642 .32154 Mdot
.39818 .63931 Mdot
.48407 .36447 Mdot
.65642 .42788 Mdot
.45627 .36494 Mdot
.34841 .49323 Mdot
.58855 .63591 Mdot
.5968 .66445 Mdot
.62105 .45885 Mdot
.67285 .50773 Mdot
.48137 .76858 Mdot
.64638 .45684 Mdot
.64428 .47766 Mdot
.29473 .65093 Mdot
.64076 .47633 Mdot
.60121 .41668 Mdot
.61115 .4082 Mdot
.6192 .49773 Mdot
.38031 .51757 Mdot
.27161 .34144 Mdot
.60069 .38627 Mdot
.6149 .37712 Mdot
.34657 .53217 Mdot
.19299 .53945 Mdot
.38107 .46678 Mdot
.15811 .53744 Mdot
.34079 .50197 Mdot
.59116 .6711 Mdot
.29188 .6907 Mdot
.64579 .51371 Mdot
.40658 .35297 Mdot
.32864 .48758 Mdot
.57067 .6646 Mdot
.35562 .49274 Mdot
.44595 .66451 Mdot
.34419 .77292 Mdot
.49123 .34649 Mdot
.75793 .46741 Mdot
.40327 .44144 Mdot
.31405 .55542 Mdot
.4458 .67127 Mdot
.45395 .35345 Mdot
.6511 .30257 Mdot
.60156 .41313 Mdot
.5669 .65842 Mdot
.61064 .45126 Mdot
.38722 .50821 Mdot
.45151 .65155 Mdot
.50056 .18163 Mdot
.60196 .64629 Mdot
.49751 .82307 Mdot
.43451 .63955 Mdot
.61913 .40176 Mdot
.39049 .50235 Mdot
.55095 .82818 Mdot
.34575 .5073 Mdot
.68759 .35393 Mdot
.44615 .39267 Mdot
.63831 .21445 Mdot
.42373 .34059 Mdot
.37917 .60286 Mdot
.38701 .8277 Mdot
.28825 .29063 Mdot
.41494 .36808 Mdot
.34876 .56055 Mdot
.67128 .45401 Mdot
.67578 .45234 Mdot
.36493 .26535 Mdot
.41415 .31634 Mdot
.58791 .44283 Mdot
.29794 .66061 Mdot
.27239 .39501 Mdot
.64945 .74883 Mdot
.43445 .61415 Mdot
.62436 .42743 Mdot
.35578 .53931 Mdot
.33762 .48822 Mdot
.424 .66962 Mdot
.37575 .45954 Mdot
.65943 .44485 Mdot
.42637 .33738 Mdot
.4194 .67909 Mdot
.58458 .66488 Mdot
.35439 .21754 Mdot
.60242 .62994 Mdot
.43435 .62137 Mdot
.698 .46918 Mdot
.46475 .64979 Mdot
.51148 .10551 Mdot
.66157 .44008 Mdot
.4404 .37337 Mdot
.61843 .47357 Mdot
.6535 .43012 Mdot
.68065 .43586 Mdot
.45708 .66038 Mdot
.77286 .41878 Mdot
.59979 .47275 Mdot
.37442 .49229 Mdot
.50877 .32596 Mdot
.68219 .4313 Mdot
.47245 .69382 Mdot
.67801 .64897 Mdot
.38267 .57325 Mdot
.4497 .38411 Mdot
.44775 .61773 Mdot
.42215 .36967 Mdot
.43063 .27706 Mdot
.42359 .36493 Mdot
.53469 .33946 Mdot
.63858 .296 Mdot
.78283 .43092 Mdot
.49592 .21875 Mdot
.59356 .548 Mdot
.41556 .31506 Mdot
.63609 .64073 Mdot
.41988 .32336 Mdot
.46097 .36404 Mdot
.22988 .77531 Mdot
.40878 .34215 Mdot
.63207 .42161 Mdot
.66967 .41141 Mdot
.25651 .45253 Mdot
.71039 .58882 Mdot
.63097 .47099 Mdot
.60433 .46987 Mdot
.59018 .63761 Mdot
.71401 .4754 Mdot
.2734 .52658 Mdot
.70719 .7487 Mdot
.24057 .50333 Mdot
.61327 .45294 Mdot
.60176 .47131 Mdot
.55688 .42263 Mdot
.55241 .85054 Mdot
.64081 .234 Mdot
.39419 .34137 Mdot
.56809 .47983 Mdot
.34329 .24484 Mdot
.66957 .42351 Mdot
.6767 .47005 Mdot
.66975 .45108 Mdot
.46101 .6516 Mdot
.40905 .37793 Mdot
.56079 .45982 Mdot
.57344 .77865 Mdot
.67397 .43013 Mdot
.27784 .59236 Mdot
.5949 .16237 Mdot
.62109 .42494 Mdot
.41567 .38406 Mdot
.6699 .46583 Mdot
.4644 .35367 Mdot
.44685 .33232 Mdot
.67822 .48745 Mdot
.52923 .36697 Mdot
.41733 .38886 Mdot
.65967 .4513 Mdot
.449 .65916 Mdot
.20763 .35736 Mdot
.60341 .43046 Mdot
.59989 .6358 Mdot
.6293 .41651 Mdot
.57009 .68115 Mdot
.64576 .47435 Mdot
.41865 .66565 Mdot
.71849 .3266 Mdot
.4569 .64314 Mdot
.67804 .23047 Mdot
.40652 .64636 Mdot
.45726 .80758 Mdot
.39749 .34493 Mdot
.2668 .55779 Mdot
.82326 .45148 Mdot
.29247 .6204 Mdot
.47378 .55915 Mdot
.47554 .528 Mdot
.36261 .46243 Mdot
.46855 .36275 Mdot
.68121 .53479 Mdot
.36218 .71189 Mdot
.35085 .71524 Mdot
.41108 .63124 Mdot
.83075 .41775 Mdot
.83037 .55607 Mdot
.61974 .48203 Mdot
.57573 .32537 Mdot
.52271 .26893 Mdot
.68418 .44715 Mdot
.56906 .47274 Mdot
.49704 .64975 Mdot
.58469 .44073 Mdot
.32174 .32696 Mdot
.43222 .6248 Mdot
.56972 .66315 Mdot
.44788 .36875 Mdot
.5633 .65483 Mdot
.35803 .71111 Mdot
.47265 .52952 Mdot
.43646 .66694 Mdot
.63742 .49752 Mdot
.61247 .47065 Mdot
.46048 .34451 Mdot
.42347 .29456 Mdot
.41308 .33777 Mdot
.60635 .66156 Mdot
.43495 .62918 Mdot
.69976 .28775 Mdot
.59656 .46208 Mdot
.43631 .33939 Mdot
.45041 .55148 Mdot
.5935 .46355 Mdot
.35426 .50217 Mdot
.67109 .44486 Mdot
.42058 .3749 Mdot
.64081 .47617 Mdot
.42355 .33776 Mdot
.44768 .62615 Mdot
.65892 .4073 Mdot
.6036 .45994 Mdot
.52741 .83016 Mdot
.58354 .67305 Mdot
.40046 .3277 Mdot
.40277 .71387 Mdot
.59327 .41794 Mdot
.3062 .58097 Mdot
.65643 .42413 Mdot
.38614 .28626 Mdot
.62208 .49361 Mdot
.28606 .62561 Mdot
.5782 .41469 Mdot
.60449 .43028 Mdot
.4265 .51109 Mdot
.52686 .29074 Mdot
.41854 .30479 Mdot
.39108 .50558 Mdot
.4045 .34386 Mdot
.65632 .73342 Mdot
.41013 .58901 Mdot
.43258 .6067 Mdot
.69315 .55272 Mdot
.60963 .49725 Mdot
.62243 .43709 Mdot
.34247 .53381 Mdot
.58847 .68395 Mdot
.44415 .34397 Mdot
.5696 .65756 Mdot
.58722 .78839 Mdot
.60726 .67395 Mdot
.48001 .63371 Mdot
.50513 .77168 Mdot
.66933 .26727 Mdot
.59023 .63797 Mdot
.41222 .36542 Mdot
.60307 .72403 Mdot
.65523 .48895 Mdot
.63266 .70403 Mdot
.57435 .66039 Mdot
.82802 .38559 Mdot
.60051 .41846 Mdot
.47953 .56418 Mdot
.36078 .51605 Mdot
.58031 .64225 Mdot
.36298 .46605 Mdot
.62683 .46849 Mdot
.30074 .55605 Mdot
.44526 .31656 Mdot
.37849 .52718 Mdot
.6834 .41005 Mdot
.60047 .67479 Mdot
.41547 .65117 Mdot
.32609 .4821 Mdot
.38864 .51559 Mdot
.18991 .50662 Mdot
.54549 .17327 Mdot
.43634 .63107 Mdot
.75346 .65833 Mdot
.33945 .49502 Mdot
.68599 .4535 Mdot
.72297 .46862 Mdot
.66687 .43268 Mdot
.35889 .41833 Mdot
.4438 .61494 Mdot
.25441 .41725 Mdot
.61684 .47448 Mdot
.63346 .40541 Mdot
.41252 .30943 Mdot
.44997 .6407 Mdot
.43089 .35323 Mdot
.40706 .33657 Mdot
.44816 .62779 Mdot
.42107 .34899 Mdot
.59938 .68528 Mdot
.28125 .39611 Mdot
.34107 .51942 Mdot
.37539 .48699 Mdot
.44098 .64982 Mdot
.46512 .63017 Mdot
.46587 .6412 Mdot
.67116 .44451 Mdot
.44704 .34963 Mdot
.65509 .46547 Mdot
.67986 .43783 Mdot
.53521 .37983 Mdot
.43659 .3869 Mdot
.66534 .46171 Mdot
.37788 .6466 Mdot
.56961 .69398 Mdot
.44529 .66034 Mdot
.36448 .51741 Mdot
.24307 .58294 Mdot
.3629 .43951 Mdot
.62788 .42734 Mdot
.46764 .78303 Mdot
.41091 .35389 Mdot
.59681 .64735 Mdot
.61973 .66209 Mdot
.59887 .65567 Mdot
.3963 .52244 Mdot
.40921 .3217 Mdot
.71221 .74569 Mdot
.62243 .43024 Mdot
.52269 .57459 Mdot
.73594 .48309 Mdot
.4732 .77233 Mdot
.36738 .51751 Mdot
.59858 .46779 Mdot
.50372 .47351 Mdot
.6675 .29934 Mdot
.66301 .43241 Mdot
.68132 .47377 Mdot
.30778 .66859 Mdot
.56936 .50815 Mdot
.43765 .39691 Mdot
.58629 .80343 Mdot
.63657 .39217 Mdot
.49469 .33041 Mdot
.39373 .18429 Mdot
.63823 .42645 Mdot
.63738 .40937 Mdot
.59439 .4448 Mdot
.63568 .48059 Mdot
.42436 .38976 Mdot
.67481 .57818 Mdot
.38345 .46173 Mdot
.53824 .58018 Mdot
.34886 .53002 Mdot
.40247 .62808 Mdot
.27035 .35604 Mdot
.46835 .36576 Mdot
.59494 .64322 Mdot
.26588 .32376 Mdot
.6437 .78516 Mdot
.47639 .65322 Mdot
.61225 .23581 Mdot
.5774 .6666 Mdot
.68645 .4571 Mdot
.58592 .68999 Mdot
.40711 .63649 Mdot
.37863 .49503 Mdot
.60542 .49751 Mdot
.41773 .32875 Mdot
.44259 .37943 Mdot
.58739 .44609 Mdot
.32613 .25769 Mdot
.35633 .50619 Mdot
.32763 .52315 Mdot
.67837 .46341 Mdot
.69656 .44223 Mdot
.42954 .35645 Mdot
.42665 .64534 Mdot
.71468 .678 Mdot
.58799 .68053 Mdot
.58102 .43629 Mdot
.64103 .48096 Mdot
.56425 .7975 Mdot
.37884 .50536 Mdot
.48105 .64634 Mdot
.65459 .48246 Mdot
.28015 .46992 Mdot
.65413 .48242 Mdot
.54855 .44031 Mdot
.44684 .65838 Mdot
.59307 .39449 Mdot
.60821 .47944 Mdot
.70244 .38136 Mdot
.34972 .47472 Mdot
.43657 .37146 Mdot
.48034 .32944 Mdot
.56901 .57149 Mdot
.35354 .4999 Mdot
.667 .4639 Mdot
.37335 .50835 Mdot
.68011 .44473 Mdot
.58602 .44735 Mdot
.3609 .52024 Mdot
.43025 .35283 Mdot
.20978 .48689 Mdot
.26955 .34803 Mdot
.63244 .4804 Mdot
.61757 .39264 Mdot
.69171 .57914 Mdot
.79108 .45288 Mdot
.65271 .41576 Mdot
.42894 .37861 Mdot
.60082 .46412 Mdot
.35941 .46919 Mdot
.61082 .67456 Mdot
.42251 .37456 Mdot
.42471 .6361 Mdot
.47161 .66292 Mdot
.31446 .42587 Mdot
.41977 .61667 Mdot
.65935 .48517 Mdot
.4344 .27768 Mdot
.46182 .31053 Mdot
.37936 .20076 Mdot
.44884 .6314 Mdot
.61057 .68032 Mdot
.61919 .46399 Mdot
.4449 .7893 Mdot
.34129 .53493 Mdot
.58562 .87475 Mdot
.74738 .72105 Mdot
.59302 .62269 Mdot
.8211 .50943 Mdot
.4005 .63572 Mdot
.58602 .46317 Mdot
.5878 .63531 Mdot
.475 .6526 Mdot
.63805 .48891 Mdot
.61688 .50248 Mdot
.76919 .39528 Mdot
.5502 .55943 Mdot
.3742 .50959 Mdot
.45101 .61236 Mdot
.62227 .64321 Mdot
.48458 .64885 Mdot
.45037 .3786 Mdot
.60674 .43196 Mdot
.67888 .49873 Mdot
.42431 .64066 Mdot
.47741 .66427 Mdot
.66507 .45298 Mdot
.46961 .36038 Mdot
.49145 .63559 Mdot
.62026 .45432 Mdot
.60118 .54449 Mdot
.47228 .37768 Mdot
.42768 .62461 Mdot
.6206 .40608 Mdot
.60194 .71175 Mdot
.43259 .64196 Mdot
.44296 .66074 Mdot
.58672 .44787 Mdot
.59602 .68656 Mdot
.61286 .39616 Mdot
.3417 .51156 Mdot
.75674 .32171 Mdot
.36561 .46794 Mdot
.57417 .7188 Mdot
.70093 .45784 Mdot
.2968 .51391 Mdot
.46026 .37605 Mdot
.58316 .60978 Mdot
.25428 .62922 Mdot
.66597 .3861 Mdot
.18262 .43237 Mdot
.49119 .45381 Mdot
.31659 .24972 Mdot
.24736 .67496 Mdot
.57822 .65405 Mdot
.35381 .49069 Mdot
.6382 .40976 Mdot
.34098 .46897 Mdot
.59443 .63403 Mdot
.66342 .22694 Mdot
.61337 .40843 Mdot
.44826 .35656 Mdot
.66531 .44794 Mdot
.45468 .36387 Mdot
.58883 .45712 Mdot
.58494 .3902 Mdot
.29017 .65518 Mdot
.75344 .61896 Mdot
.63912 .49118 Mdot
.36813 .79741 Mdot
.57583 .7573 Mdot
.57526 .67207 Mdot
.65181 .46208 Mdot
.39592 .58889 Mdot
.3409 .47884 Mdot
.35675 .29869 Mdot
.46109 .65277 Mdot
.38634 .47591 Mdot
.42445 .3583 Mdot
.44095 .61832 Mdot
.46638 .66827 Mdot
.58714 .40116 Mdot
.56435 .6701 Mdot
.38186 .48666 Mdot
.61079 .42679 Mdot
.61025 .41164 Mdot
.72719 .68489 Mdot
.55182 .72745 Mdot
.45069 .2974 Mdot
.62535 .81932 Mdot
.47687 .32745 Mdot
.58885 .6764 Mdot
.45698 .65653 Mdot
.65351 .4197 Mdot
.64575 .4451 Mdot
.26842 .56934 Mdot
.43805 .31432 Mdot
.53293 .53739 Mdot
.56803 .20889 Mdot
.49292 .64342 Mdot
.68966 .62626 Mdot
.44451 .37451 Mdot
.69156 .62452 Mdot
.62323 .65738 Mdot
.24127 .33678 Mdot
.73569 .63087 Mdot
.36391 .51516 Mdot
.68785 .6227 Mdot
.43865 .33275 Mdot
.617 .47891 Mdot
.42555 .59314 Mdot
.41462 .62286 Mdot
.43536 .36471 Mdot
.45014 .68067 Mdot
.5872 .6414 Mdot
.62653 .40969 Mdot
.70573 .74362 Mdot
.32551 .39832 Mdot
.42229 .64851 Mdot
.5942 .38276 Mdot
.3781 .47562 Mdot
.58687 .44039 Mdot
.60203 .63909 Mdot
.36682 .50012 Mdot
.61379 .7428 Mdot
.26435 .40586 Mdot
.62385 .46243 Mdot
.4775 .80654 Mdot
.35752 .49943 Mdot
.80188 .50462 Mdot
.61477 .4481 Mdot
.34018 .493 Mdot
.56105 .48671 Mdot
.36064 .63998 Mdot
.50803 .47996 Mdot
.15168 .47958 Mdot
.51509 .51395 Mdot
.41342 .59876 Mdot
.35654 .60773 Mdot
.33958 .66306 Mdot
.34105 .47045 Mdot
.4798 .66153 Mdot
.53069 .65028 Mdot
.36258 .46566 Mdot
.68092 .43037 Mdot
.65027 .42498 Mdot
.64247 .23185 Mdot
.48429 .46191 Mdot
.37167 .61761 Mdot
.35642 .37172 Mdot
.59628 .41472 Mdot
.64818 .39259 Mdot
.63848 .44581 Mdot
.40689 .3827 Mdot
.37639 .50286 Mdot
.43992 .82125 Mdot
.35134 .50061 Mdot
.76299 .68074 Mdot
.4451 .64822 Mdot
.44653 .6133 Mdot
.62473 .42521 Mdot
.50371 .59499 Mdot
.64888 .61231 Mdot
.65832 .44671 Mdot
.53717 .60846 Mdot
.48638 .19342 Mdot
.68223 .41309 Mdot
.45017 .38859 Mdot
.6789 .37847 Mdot
.44867 .403 Mdot
.33999 .51824 Mdot
.58497 .65558 Mdot
.57382 .61072 Mdot
.38047 .49481 Mdot
.62357 .43827 Mdot
.28691 .51385 Mdot
.65117 .43421 Mdot
.63148 .48445 Mdot
.78352 .65809 Mdot
.60058 .6283 Mdot
.45905 .63156 Mdot
.60107 .65714 Mdot
.46445 .36073 Mdot
.43408 .90066 Mdot
.58388 .68327 Mdot
.64202 .60825 Mdot
.70022 .25476 Mdot
.68905 .6191 Mdot
.44997 .3773 Mdot
.55915 .65611 Mdot
.36172 .51032 Mdot
.21848 .32486 Mdot
.79366 .4105 Mdot
.33795 .45254 Mdot
.62445 .45214 Mdot
.47386 .35154 Mdot
.41852 .37746 Mdot
.37283 .52974 Mdot
.44554 .33316 Mdot
.57086 .49327 Mdot
.62554 .4802 Mdot
.34781 .46167 Mdot
.28051 .43622 Mdot
.38957 .51445 Mdot
.29423 .36491 Mdot
.65499 .45862 Mdot
.43801 .37624 Mdot
.69274 .39318 Mdot
.41071 .3987 Mdot
.47926 .63837 Mdot
.68835 .44239 Mdot
.58887 .64097 Mdot
.29802 .49583 Mdot
.43508 .63286 Mdot
.45693 .77651 Mdot
.46095 .34764 Mdot
.38289 .56223 Mdot
.45449 .33978 Mdot
.42199 .31144 Mdot
.38232 .47224 Mdot
.44711 .31986 Mdot
.63443 .40896 Mdot
.37939 .61099 Mdot
.46578 .34163 Mdot
.36614 .47621 Mdot
.58839 .65981 Mdot
.42391 .34838 Mdot
.38776 .69759 Mdot
.61181 .46117 Mdot
.46232 .66121 Mdot
.31026 .7069 Mdot
.46437 .31918 Mdot
.56675 .63781 Mdot
.42933 .60809 Mdot
.56683 .6499 Mdot
.44603 .18584 Mdot
.3647 .45042 Mdot
.81472 .56384 Mdot
.57352 .70119 Mdot
.40837 .34809 Mdot
.29351 .68976 Mdot
.65019 .42009 Mdot
.6141 .46292 Mdot
.56705 .68109 Mdot
.41809 .37708 Mdot
.26239 .30656 Mdot
.41093 .4145 Mdot
.27177 .41034 Mdot
.34888 .45565 Mdot
.42722 .80527 Mdot
.29892 .3461 Mdot
.5282 .14974 Mdot
.6514 .3874 Mdot
.40027 .64571 Mdot
.63094 .4336 Mdot
.24654 .61074 Mdot
.60214 .67161 Mdot
.43729 .69698 Mdot
.67855 .48454 Mdot
.45018 .6237 Mdot
.59976 .44789 Mdot
.42742 .48444 Mdot
.66463 .37702 Mdot
.61399 .67469 Mdot
.2706 .52807 Mdot
.40701 .34494 Mdot
.58197 .66532 Mdot
.42161 .66512 Mdot
.66367 .62121 Mdot
.62446 .48918 Mdot
.62945 .37962 Mdot
.49045 .63751 Mdot
.45194 .35408 Mdot
.42965 .59826 Mdot
.33928 .51455 Mdot
.58938 .64747 Mdot
.62196 .47075 Mdot
.62784 .49564 Mdot
.30736 .58383 Mdot
.38231 .48149 Mdot
.4564 .67715 Mdot
.34598 .50443 Mdot
.39919 .63136 Mdot
.59857 .39902 Mdot
.44436 .61178 Mdot
.59405 .47531 Mdot
.26877 .63865 Mdot
.78238 .6562 Mdot
.5422 .3062 Mdot
.44071 .61465 Mdot
.69005 .655 Mdot
.36 .47201 Mdot
.34215 .49913 Mdot
.69933 .27149 Mdot
.71697 .36319 Mdot
.69304 .72758 Mdot
.18121 .54412 Mdot
.34738 .52869 Mdot
.37406 .47303 Mdot
.46595 .66013 Mdot
.45459 .32248 Mdot
.44473 .30739 Mdot
.40193 .64467 Mdot
.75364 .52889 Mdot
.44397 .34388 Mdot
.20574 .38057 Mdot
.66225 .73814 Mdot
.56119 .45136 Mdot
.42716 .56381 Mdot
.59211 .65173 Mdot
.74378 .55127 Mdot
.42571 .48756 Mdot
.63894 .40655 Mdot
.55094 .79723 Mdot
.43189 .64915 Mdot
.68419 .54765 Mdot
.1594 .53808 Mdot
.60824 .41073 Mdot
.6118 .44225 Mdot
.63074 .44061 Mdot
.58363 .62143 Mdot
.73139 .36358 Mdot
.61688 .40945 Mdot
.75721 .52392 Mdot
.58898 .42282 Mdot
.53982 .40698 Mdot
.59855 .6625 Mdot
.53373 .43685 Mdot
.29871 .67018 Mdot
.60944 .78079 Mdot
.71166 .40891 Mdot
.33902 .51112 Mdot
.55685 .59689 Mdot
.34683 .47744 Mdot
.53494 .33113 Mdot
.73703 .62589 Mdot
.48496 .3502 Mdot
.64037 .40782 Mdot
.43358 .62148 Mdot
.42045 .37881 Mdot
.34241 .61017 Mdot
.33381 .8633 Mdot
.33689 .50257 Mdot
.5737 .13392 Mdot
.34277 .5058 Mdot
.45803 .67168 Mdot
.42948 .35804 Mdot
.63114 .29172 Mdot
.52235 .57026 Mdot
.42273 .34631 Mdot
.22634 .45218 Mdot
.3962 .32302 Mdot
.68503 .64267 Mdot
.47657 .33547 Mdot
.36371 .47434 Mdot
.39876 .51172 Mdot
.60672 .50529 Mdot
.63817 .41894 Mdot
.46964 .52299 Mdot
.66071 .64244 Mdot
.64518 .41873 Mdot
.43393 .62641 Mdot
.809 .47673 Mdot
.59728 .58815 Mdot
.43854 .32252 Mdot
.38934 .46641 Mdot
.60848 .44251 Mdot
.64935 .48235 Mdot
.62453 .48732 Mdot
.64447 .81973 Mdot
.24464 .32807 Mdot
.59972 .47243 Mdot
.59368 .41377 Mdot
.44373 .61996 Mdot
.61489 .69008 Mdot
.23753 .60569 Mdot
.59724 .36253 Mdot
.65653 .40907 Mdot
.58717 .66896 Mdot
.60126 .62697 Mdot
.64056 .48894 Mdot
.57044 .77621 Mdot
.30349 .53424 Mdot
.61006 .42692 Mdot
.70887 .36311 Mdot
.35183 .68966 Mdot
.47418 .66655 Mdot
.42624 .63941 Mdot
.41242 .37791 Mdot
.42238 .61856 Mdot
.40729 .65199 Mdot
.63965 .27962 Mdot
.51616 .52603 Mdot
.38534 .53761 Mdot
.60671 .66032 Mdot
.6482 .44231 Mdot
.45246 .30024 Mdot
.2787 .48297 Mdot
.37031 .46314 Mdot
.41354 .35107 Mdot
.34035 .48302 Mdot
.56345 .63103 Mdot
.75081 .47675 Mdot
.40942 .63259 Mdot
.36054 .52982 Mdot
.26543 .40444 Mdot
.59023 .66819 Mdot
.38662 .48778 Mdot
.28808 .52685 Mdot
.68172 .42555 Mdot
.60273 .33111 Mdot
.65605 .45039 Mdot
.29051 .2728 Mdot
.3862 .4957 Mdot
.28113 .61761 Mdot
.6165 .43504 Mdot
.43518 .64129 Mdot
.54966 .46109 Mdot
.66515 .4243 Mdot
.42048 .63439 Mdot
.61879 .48139 Mdot
.58572 .63039 Mdot
.47582 .37654 Mdot
.54493 .57783 Mdot
.86655 .53603 Mdot
.56364 .66897 Mdot
.33673 .60146 Mdot
.6514 .41377 Mdot
.50556 .17641 Mdot
.42492 .34653 Mdot
.60341 .48387 Mdot
.62562 .58104 Mdot
.46666 .33383 Mdot
.41701 .36254 Mdot
.6602 .47319 Mdot
.35818 .51439 Mdot
.43186 .63135 Mdot
.5949 .6651 Mdot
.44706 .17745 Mdot
.6323 .45636 Mdot
.60238 .46188 Mdot
.57875 .66588 Mdot
.37031 .46951 Mdot
.6618 .4775 Mdot
.32295 .72684 Mdot
.29956 .24449 Mdot
.36442 .46 Mdot
.67489 .42263 Mdot
.59791 .34481 Mdot
.46613 .3991 Mdot
.72735 .25122 Mdot
.62411 .72214 Mdot
.45583 .62498 Mdot
.56981 .50471 Mdot
.47756 .89152 Mdot
.58673 .65634 Mdot
.65909 .76712 Mdot
.64007 .48582 Mdot
.59236 .45525 Mdot
.41262 .34105 Mdot
.66011 .46353 Mdot
.46441 .32317 Mdot
.85973 .51517 Mdot
.55616 .80325 Mdot
.45626 .35713 Mdot
.41379 .33122 Mdot
.62722 .59222 Mdot
.23926 .606 Mdot
.43331 .36553 Mdot
.58998 .41211 Mdot
.43143 .26373 Mdot
.67293 .36261 Mdot
.57296 .68643 Mdot
.33441 .70314 Mdot
.45085 .4105 Mdot
.6307 .63965 Mdot
.19639 .50139 Mdot
.46349 .40729 Mdot
.32005 .54344 Mdot
.34438 .51899 Mdot
.61399 .40557 Mdot
.41637 .61995 Mdot
.43546 .60782 Mdot
.68386 .38859 Mdot
.6541 .43825 Mdot
.46373 .35613 Mdot
.60917 .65808 Mdot
.33834 .47745 Mdot
.60467 .46954 Mdot
.602 .5932 Mdot
.58344 .68187 Mdot
.45158 .32728 Mdot
.75497 .3938 Mdot
.61467 .67533 Mdot
.62591 .37126 Mdot
.61784 .41921 Mdot
.66859 .45086 Mdot
.69308 .36854 Mdot
.37052 .52042 Mdot
.28596 .67794 Mdot
.65043 .39894 Mdot
.58748 .78914 Mdot
.49323 .41603 Mdot
.56983 .41052 Mdot
.44903 .34174 Mdot
.34337 .53667 Mdot
.44709 .59936 Mdot
.65069 .55653 Mdot
.62799 .46128 Mdot
.27568 .30953 Mdot
.60726 .21482 Mdot
.47103 .62361 Mdot
.41797 .31455 Mdot
.59763 .65019 Mdot
.65761 .44538 Mdot
.51964 .34737 Mdot
.64337 .42459 Mdot
.55115 .66671 Mdot
.43724 .65767 Mdot
.34537 .51892 Mdot
.31313 .24819 Mdot
.43652 .6081 Mdot
.42069 .36831 Mdot
.12381 .54382 Mdot
.47583 .34137 Mdot
.41495 .32344 Mdot
.52157 .36459 Mdot
.36344 .52372 Mdot
.50572 .89726 Mdot
.78842 .36211 Mdot
.6956 .45319 Mdot
.35454 .47504 Mdot
.44052 .36286 Mdot
.58894 .43574 Mdot
.46818 .37279 Mdot
.40711 .32196 Mdot
.60808 .39278 Mdot
.59463 .43391 Mdot
.27614 .35146 Mdot
.15342 .49626 Mdot
.59957 .65005 Mdot
.46111 .36794 Mdot
.62645 .5457 Mdot
.5906 .43056 Mdot
.62158 .43017 Mdot
.35072 .66722 Mdot
.60045 .68539 Mdot
.33873 .31918 Mdot
.64448 .48465 Mdot
.52737 .80903 Mdot
.6811 .38001 Mdot
.42776 .39178 Mdot
.36898 .46037 Mdot
.61259 .77482 Mdot
.39897 .44782 Mdot
.44512 .31494 Mdot
.60639 .64794 Mdot
.47804 .3243 Mdot
.64264 .61145 Mdot
.38009 .52082 Mdot
.42055 .3749 Mdot
.5045 .48617 Mdot
.36697 .49196 Mdot
.38353 .50381 Mdot
.50798 .32623 Mdot
.42766 .677 Mdot
.58353 .62404 Mdot
.38062 .48284 Mdot
.67999 .52072 Mdot
.35886 .48104 Mdot
.72392 .30582 Mdot
.66037 .40793 Mdot
.72544 .53091 Mdot
.47113 .57114 Mdot
.63087 .51406 Mdot
.38458 .50936 Mdot
.5976 .63708 Mdot
.66182 .47505 Mdot
.44066 .33085 Mdot
.57009 .66922 Mdot
.32413 .47901 Mdot
.46535 .65345 Mdot
.45519 .33754 Mdot
.35708 .44826 Mdot
.45134 .37257 Mdot
.67715 .5384 Mdot
.7369 .28583 Mdot
.36196 .75823 Mdot
.52321 .565 Mdot
.62661 .48717 Mdot
.20188 .56771 Mdot
.56497 .43202 Mdot
.65867 .43576 Mdot
.42909 .62542 Mdot
.69494 .54895 Mdot
.43065 .3537 Mdot
.29832 .25403 Mdot
.35247 .52765 Mdot
.58374 .8047 Mdot
.4053 .28436 Mdot
.61023 .48765 Mdot
.46682 .34253 Mdot
.47663 .34123 Mdot
.51874 .28435 Mdot
.464 .61098 Mdot
.5763 .47936 Mdot
.5748 .48056 Mdot
.62451 .38266 Mdot
.37987 .50783 Mdot
.46687 .78005 Mdot
.40935 .60492 Mdot
.71946 .25676 Mdot
.43028 .65451 Mdot
.53896 .60497 Mdot
.44664 .32108 Mdot
.58552 .68463 Mdot
.61976 .42919 Mdot
.41357 .2981 Mdot
.44287 .31379 Mdot
.55765 .67906 Mdot
.57904 .64188 Mdot
.35982 .66054 Mdot
.36225 .5203 Mdot
.64095 .49213 Mdot
.62122 .40633 Mdot
.65214 .46778 Mdot
.66866 .44124 Mdot
.33677 .50766 Mdot
.67697 .4569 Mdot
.36663 .53901 Mdot
.73134 .47666 Mdot
.53737 .79889 Mdot
.51007 .51551 Mdot
.37779 .302 Mdot
.43814 .32622 Mdot
.63422 .53648 Mdot
.60691 .37402 Mdot
.79556 .63175 Mdot
.42703 .22572 Mdot
.68579 .42062 Mdot
.47524 .64832 Mdot
.72257 .37454 Mdot
.40992 .62404 Mdot
.64468 .1613 Mdot
.30441 .58922 Mdot
.16147 .46567 Mdot
.60714 .41572 Mdot
.35259 .67775 Mdot
.67699 .51464 Mdot
.56539 .44943 Mdot
.33118 .62119 Mdot
.36124 .41486 Mdot
.24404 .45307 Mdot
.61346 .65274 Mdot
.61318 .45709 Mdot
.44041 .29922 Mdot
.63009 .40867 Mdot
.62708 .43107 Mdot
.64684 .48566 Mdot
.39049 .48559 Mdot
.57982 .4808 Mdot
.67417 .43931 Mdot
.48001 .76421 Mdot
.71056 .62699 Mdot
.44698 .60882 Mdot
.68551 .25655 Mdot
.5792 .68059 Mdot
.46445 .3492 Mdot
.21996 .40833 Mdot
.3647 .51532 Mdot
.51816 .2754 Mdot
.66913 .44535 Mdot
.2657 .37703 Mdot
.34497 .45483 Mdot
.58899 .64475 Mdot
.4148 .59493 Mdot
.17653 .41895 Mdot
.43857 .62496 Mdot
.50211 .47437 Mdot
.43827 .63921 Mdot
.6614 .36713 Mdot
.46338 .3573 Mdot
.65329 .48526 Mdot
.37984 .4854 Mdot
.42221 .62656 Mdot
.70308 .58099 Mdot
.63755 .4444 Mdot
.44927 .62838 Mdot
.6543 .48471 Mdot
.75169 .48052 Mdot
.76766 .63259 Mdot
.4118 .65946 Mdot
.3747 .54044 Mdot
.3692 .48601 Mdot
.59754 .68561 Mdot
.46049 .33843 Mdot
.41674 .3347 Mdot
.36539 .4985 Mdot
.79924 .43203 Mdot
.65956 .41286 Mdot
.59242 .42943 Mdot
.59287 .79106 Mdot
.64304 .41335 Mdot
.67339 .63757 Mdot
.50501 .47692 Mdot
.44519 .32588 Mdot
.58677 .4617 Mdot
.64585 .48219 Mdot
.62123 .46294 Mdot
.71133 .51581 Mdot
.42402 .64509 Mdot
.63282 .3997 Mdot
.57626 .64198 Mdot
.38534 .59712 Mdot
.58674 .43899 Mdot
.61717 .38309 Mdot
.41582 .33683 Mdot
.6494 .79826 Mdot
.34532 .51208 Mdot
.43514 .66997 Mdot
.4459 .61467 Mdot
.33731 .70271 Mdot
.49667 .4 Mdot
.50681 .48589 Mdot
.69029 .23055 Mdot
.29516 .65675 Mdot
.57794 .67184 Mdot
.40634 .56719 Mdot
.50579 .41693 Mdot
.46491 .66455 Mdot
.33588 .4979 Mdot
.65999 .40614 Mdot
.65734 .40879 Mdot
.77249 .69511 Mdot
.61995 .49179 Mdot
.59538 .65319 Mdot
.36326 .53672 Mdot
.4381 .33345 Mdot
.59052 .64449 Mdot
.34362 .49847 Mdot
.45263 .35215 Mdot
.67509 .41043 Mdot
.66753 .40603 Mdot
.41448 .35003 Mdot
.41446 .37149 Mdot
.61554 .42345 Mdot
.51227 .65235 Mdot
.40563 .35394 Mdot
.43729 .37809 Mdot
.40892 .6333 Mdot
.41536 .62416 Mdot
.5827 .40367 Mdot
.3518 .48091 Mdot
.67635 .4437 Mdot
.43843 .61952 Mdot
.60865 .6711 Mdot
.43038 .34796 Mdot
.63409 .48139 Mdot
.60979 .47274 Mdot
.59019 .66711 Mdot
.61162 .65357 Mdot
.5833 .64194 Mdot
.3855 .52571 Mdot
.64541 .46497 Mdot
.42762 .36313 Mdot
.35687 .5216 Mdot
.60038 .62596 Mdot
.59493 .6901 Mdot
.48131 .6705 Mdot
.65531 .41916 Mdot
.39088 .58612 Mdot
.41649 .88623 Mdot
.64024 .71359 Mdot
.4643 .61408 Mdot
.48872 .65961 Mdot
.70109 .60721 Mdot
.51775 .59579 Mdot
.35961 .50441 Mdot
.54021 .66063 Mdot
.58015 .60956 Mdot
.68745 .44438 Mdot
.63242 .39252 Mdot
.57479 .4849 Mdot
.5774 .64797 Mdot
.6563 .56478 Mdot
.46652 .37239 Mdot
.5293 .20665 Mdot
.57497 .67664 Mdot
.47683 .66526 Mdot
.43421 .6791 Mdot
.43146 .65551 Mdot
.66168 .40521 Mdot
.54304 .30048 Mdot
.55337 .51228 Mdot
.19935 .57888 Mdot
.38745 .49936 Mdot
.47746 .31921 Mdot
.47676 .18868 Mdot
.41531 .35546 Mdot
.40369 .63229 Mdot
.57018 .66198 Mdot
.42397 .37842 Mdot
.34929 .46943 Mdot
.37641 .47658 Mdot
.42467 .6497 Mdot
.44361 .6508 Mdot
.44673 .66547 Mdot
.4125 .32149 Mdot
.44829 .32066 Mdot
.63288 .46098 Mdot
.43053 .33917 Mdot
.73152 .74356 Mdot
.57153 .62506 Mdot
.49165 .6572 Mdot
.35223 .49168 Mdot
.45619 .36228 Mdot
.64072 .44625 Mdot
.57189 .57939 Mdot
.34729 .40644 Mdot
.56981 .64381 Mdot
.74227 .6665 Mdot
.64315 .16293 Mdot
.63724 .49354 Mdot
.37773 .50765 Mdot
.70452 .742 Mdot
.63101 .44294 Mdot
.45327 .6561 Mdot
.26857 .65104 Mdot
.40901 .58903 Mdot
.67943 .43805 Mdot
.66613 .48673 Mdot
.37449 .459 Mdot
.66871 .22443 Mdot
.63677 .45843 Mdot
.33687 .33782 Mdot
.38421 .45587 Mdot
.40802 .60916 Mdot
.27837 .25512 Mdot
.36193 .73646 Mdot
.74578 .54279 Mdot
.40892 .63633 Mdot
.65398 .42925 Mdot
.41142 .63416 Mdot
.5765 .63726 Mdot
.41783 .65778 Mdot
.45171 .38969 Mdot
.43758 .60262 Mdot
.60125 .46081 Mdot
.43526 .36712 Mdot
.35681 .5 Mdot
.60389 .80411 Mdot
.54402 .75616 Mdot
.43558 .64241 Mdot
.42476 .66916 Mdot
.60171 .4759 Mdot
.32031 .32099 Mdot
.69173 .40584 Mdot
.60036 .41996 Mdot
.35562 .53091 Mdot
.46474 .3371 Mdot
.38619 .4684 Mdot
.58232 .46987 Mdot
.31231 .7232 Mdot
.34802 .50859 Mdot
.26141 .37364 Mdot
.57728 .66755 Mdot
.43915 .47128 Mdot
.6487 .44456 Mdot
.37475 .46783 Mdot
.64627 .46404 Mdot
.46434 .37622 Mdot
.47126 .47154 Mdot
.26542 .51831 Mdot
.3788 .48946 Mdot
.28865 .28528 Mdot
.52086 .63209 Mdot
.70422 .45997 Mdot
.34169 .48874 Mdot
.6225 .57976 Mdot
.46514 .66913 Mdot
.58546 .67945 Mdot
.60687 .63514 Mdot
.56406 .65768 Mdot
.68049 .39756 Mdot
.71176 .42357 Mdot
.59238 .6276 Mdot
.35133 .4647 Mdot
.61598 .66826 Mdot
.49841 .34379 Mdot
.2661 .30322 Mdot
.60112 .67084 Mdot
.61768 .45053 Mdot
.72099 .41708 Mdot
.71343 .61882 Mdot
.36841 .64469 Mdot
.1709 .45425 Mdot
.36774 .296 Mdot
.63866 .42026 Mdot
.48563 .37093 Mdot
.45077 .38023 Mdot
.68632 .7487 Mdot
.66599 .66064 Mdot
.59392 .77346 Mdot
.41343 .32941 Mdot
.26565 .55447 Mdot
.45348 .32997 Mdot
.61903 .48974 Mdot
.5907 .43466 Mdot
.43896 .30861 Mdot
.49238 .79415 Mdot
.31249 .57276 Mdot
.3589 .2184 Mdot
.44386 .37766 Mdot
.3506 .47299 Mdot
.35189 .53378 Mdot
.38302 .50797 Mdot
.66996 .7334 Mdot
.47017 .33139 Mdot
.6407 .47001 Mdot
.43851 .6152 Mdot
.64209 .40187 Mdot
.37169 .49729 Mdot
.29606 .25621 Mdot
.42465 .33079 Mdot
.6058 .42943 Mdot
.78794 .45865 Mdot
.45646 .65028 Mdot
.58691 .67116 Mdot
.7641 .44067 Mdot
.61754 .7456 Mdot
.3733 .52233 Mdot
.46735 .32062 Mdot
.28062 .60282 Mdot
.25595 .36808 Mdot
.65341 .39109 Mdot
.5601 .43184 Mdot
.49149 .157 Mdot
.61548 .74108 Mdot
.67481 .47461 Mdot
.45055 .67145 Mdot
.26898 .57404 Mdot
.61989 .47429 Mdot
.45702 .37496 Mdot
.61611 .64959 Mdot
.56682 .65563 Mdot
.57576 .42717 Mdot
.52303 .57689 Mdot
.44066 .44312 Mdot
.66812 .46285 Mdot
.62357 .37134 Mdot
.4069 .62149 Mdot
.29704 .65887 Mdot
.58233 .79404 Mdot
.60732 .64799 Mdot
.65804 .48181 Mdot
.2199 .49543 Mdot
.42673 .31502 Mdot
.45263 .60803 Mdot
.38471 .51736 Mdot
.74211 .47418 Mdot
.40744 .60849 Mdot
.62098 .47579 Mdot
.65832 .47925 Mdot
.38648 .4822 Mdot
.4283 .39206 Mdot
.57532 .65063 Mdot
.43929 .61313 Mdot
.60617 .64354 Mdot
.46797 .33318 Mdot
.42986 .33111 Mdot
.65344 .35792 Mdot
.67154 .49694 Mdot
.42614 .63742 Mdot
.58076 .44929 Mdot
.40323 .71256 Mdot
.65859 .21129 Mdot
.32828 .4888 Mdot
.63967 .49372 Mdot
.41223 .38844 Mdot
.37938 .49449 Mdot
.59168 .44467 Mdot
.45771 .16812 Mdot
.58998 .42852 Mdot
.38629 .42924 Mdot
.35494 .76056 Mdot
.59461 .63846 Mdot
.50866 .20787 Mdot
.34865 .27249 Mdot
.63711 .41255 Mdot
.46783 .63393 Mdot
.56588 .40729 Mdot
.35809 .51193 Mdot
.44056 .32166 Mdot
.72784 .24821 Mdot
.36265 .47945 Mdot
.61785 .41171 Mdot
.58948 .64649 Mdot
.47352 .33087 Mdot
.53799 .62288 Mdot
.56532 .7799 Mdot
.70411 .42267 Mdot
.58301 .42128 Mdot
.67376 .44969 Mdot
.26277 .67937 Mdot
.43493 .66949 Mdot
.44757 .36457 Mdot
.37779 .5094 Mdot
.36533 .50129 Mdot
.42711 .64922 Mdot
.26039 .43767 Mdot
.44076 .46991 Mdot
.42155 .87389 Mdot
.41828 .63409 Mdot
.56143 .64713 Mdot
.33064 .32533 Mdot
.46725 .6303 Mdot
.45147 .6329 Mdot
.40787 .6196 Mdot
.40792 .4863 Mdot
.44987 .35064 Mdot
.61132 .47482 Mdot
.45018 .38405 Mdot
.65785 .42903 Mdot
.48808 .41492 Mdot
.38105 .49032 Mdot
.43434 .32049 Mdot
.46811 .16891 Mdot
.68803 .33611 Mdot
.62395 .44477 Mdot
.49195 .18183 Mdot
.69027 .47193 Mdot
.6762 .60777 Mdot
.65545 .49901 Mdot
.44078 .64566 Mdot
.61596 .52729 Mdot
.6506 .37925 Mdot
.64767 .78733 Mdot
.35098 .49183 Mdot
.47537 .66305 Mdot
.691 .4535 Mdot
.66419 .37109 Mdot
.43016 .30809 Mdot
.42868 .3792 Mdot
.59811 .62993 Mdot
.75826 .61436 Mdot
.35503 .50122 Mdot
.7612 .34069 Mdot
.63326 .41833 Mdot
.42039 .78056 Mdot
.5017 .21944 Mdot
.59269 .44311 Mdot
.36161 .25819 Mdot
.53416 .29125 Mdot
.65506 .445 Mdot
.57603 .55105 Mdot
.36876 .47008 Mdot
.32192 .73265 Mdot
.58952 .41718 Mdot
.45895 .65347 Mdot
.45542 .32518 Mdot
.46854 .36772 Mdot
.59063 .62882 Mdot
.8261 .58284 Mdot
.38746 .47317 Mdot
.43786 .32021 Mdot
.638 .44044 Mdot
.36802 .52333 Mdot
.42364 .61488 Mdot
.60142 .48716 Mdot
.67095 .66636 Mdot
.43374 .33805 Mdot
.584 .42665 Mdot
.32749 .37093 Mdot
.74333 .58071 Mdot
.20176 .6473 Mdot
.37689 .51323 Mdot
.60757 .67816 Mdot
.56271 .41314 Mdot
.7741 .40234 Mdot
.68456 .41416 Mdot
.72105 .5312 Mdot
.50092 .38234 Mdot
.60867 .67786 Mdot
.61579 .43938 Mdot
.62691 .47071 Mdot
.48071 .57213 Mdot
.61028 .65635 Mdot
.61758 .40624 Mdot
.73428 .4363 Mdot
.45053 .3548 Mdot
.40598 .60163 Mdot
.43977 .33973 Mdot
.6238 .45158 Mdot
.65177 .50423 Mdot
.4101 .3514 Mdot
.61436 .17126 Mdot
.60394 .62279 Mdot
.34773 .51415 Mdot
.69618 .47486 Mdot
.63854 .39576 Mdot
.37458 .80934 Mdot
.48015 .64235 Mdot
.22846 .56867 Mdot
.45794 .7417 Mdot
.20691 .50641 Mdot
.36423 .73713 Mdot
.13503 .51248 Mdot
.55898 .79777 Mdot
.57194 .47162 Mdot
.38388 .38096 Mdot
.5515 .51655 Mdot
.38629 .50871 Mdot
.67442 .27703 Mdot
.63899 .41904 Mdot
.62935 .43187 Mdot
.45498 .60883 Mdot
.2528 .41425 Mdot
.58854 .78006 Mdot
.54111 .59015 Mdot
.57519 .65305 Mdot
.46113 .36547 Mdot
.59095 .46167 Mdot
.54408 .53861 Mdot
.44995 .61015 Mdot
.43027 .78318 Mdot
.60679 .43303 Mdot
.79127 .63307 Mdot
.33093 .42854 Mdot
.36782 .52062 Mdot
.453 .61811 Mdot
.60893 .75379 Mdot
.6589 .4208 Mdot
.383 .52181 Mdot
.63918 .45434 Mdot
.49344 .61198 Mdot
.58307 .46628 Mdot
.59818 .67671 Mdot
.63586 .48734 Mdot
.54824 .59726 Mdot
.15405 .59601 Mdot
.54342 .64854 Mdot
.4727 .3563 Mdot
.48305 .6298 Mdot
.42456 .64346 Mdot
.41876 .37485 Mdot
.42681 .64213 Mdot
.51307 .24921 Mdot
.61085 .27958 Mdot
.57294 .6604 Mdot
.64673 .37124 Mdot
.60243 .66513 Mdot
.47839 .63518 Mdot
.64872 .42149 Mdot
.65248 .1938 Mdot
.42509 .63058 Mdot
.37783 .79029 Mdot
.35748 .48531 Mdot
.48097 .65284 Mdot
.58866 .4224 Mdot
.2873 .60606 Mdot
.44023 .60765 Mdot
.26748 .51817 Mdot
.6228 .46285 Mdot
.43427 .32982 Mdot
.62685 .47373 Mdot
.69476 .47242 Mdot
.40303 .66048 Mdot
.67359 .43409 Mdot
.34369 .49817 Mdot
.40453 .34321 Mdot
.21098 .35337 Mdot
.36651 .41979 Mdot
.63406 .40565 Mdot
.63572 .44101 Mdot
.45605 .30626 Mdot
.62928 .39834 Mdot
.33691 .50807 Mdot
.72757 .80022 Mdot
.57777 .66813 Mdot
.42908 .67249 Mdot
.35823 .73659 Mdot
.68406 .41942 Mdot
.67246 .46486 Mdot
.43394 .17681 Mdot
.35503 .74297 Mdot
.34185 .49241 Mdot
.66569 .38239 Mdot
.43044 .61052 Mdot
.59063 .64833 Mdot
.35137 .46309 Mdot
.66791 .45184 Mdot
.61813 .43213 Mdot
.60554 .67912 Mdot
.48603 .29843 Mdot
.64981 .75037 Mdot
.38781 .48822 Mdot
.63004 .52475 Mdot
.41836 .70927 Mdot
.66258 .41773 Mdot
.68531 .72829 Mdot
.42508 .37645 Mdot
.36711 .52718 Mdot
.21795 .58916 Mdot
.68064 .46574 Mdot
.36808 .46136 Mdot
.35367 .50002 Mdot
.66208 .38259 Mdot
.39924 .37665 Mdot
.40254 .33257 Mdot
.45278 .37168 Mdot
.75449 .73178 Mdot
.73296 .57101 Mdot
.44689 .66539 Mdot
.36989 .46993 Mdot
.40699 .65309 Mdot
.55731 .65582 Mdot
.50795 .4596 Mdot
.41655 .66421 Mdot
.42657 .38275 Mdot
.46919 .61236 Mdot
.62336 .46835 Mdot
.358 .50146 Mdot
.46075 .66569 Mdot
.6935 .44369 Mdot
.30588 .32191 Mdot
.36841 .60628 Mdot
.60389 .68628 Mdot
.61427 .64426 Mdot
.58809 .44145 Mdot
.43915 .59503 Mdot
.61723 .42408 Mdot
.33117 .51316 Mdot
.31915 .3285 Mdot
.6893 .42142 Mdot
.43425 .64399 Mdot
.49075 .36245 Mdot
.61658 .74547 Mdot
.70046 .43505 Mdot
.61753 .44936 Mdot
.6634 .42817 Mdot
.63994 .4545 Mdot
.23867 .43708 Mdot
.34392 .46106 Mdot
.37015 .34264 Mdot
.29139 .68429 Mdot
.42152 .3409 Mdot
.39692 .3554 Mdot
.63546 .7281 Mdot
.32119 .54781 Mdot
.35365 .47758 Mdot
.6622 .43691 Mdot
.28461 .46788 Mdot
.28817 .26243 Mdot
.5694 .14627 Mdot
.61558 .70728 Mdot
.47374 .63114 Mdot
.4617 .31544 Mdot
.45539 .61655 Mdot
.65098 .42726 Mdot
.55559 .42589 Mdot
.13158 .51525 Mdot
.39632 .47351 Mdot
.57094 .65783 Mdot
.66177 .42996 Mdot
.73899 .56418 Mdot
.44275 .61883 Mdot
.41659 .67231 Mdot
.60902 .40905 Mdot
.41406 .38567 Mdot
.28185 .74072 Mdot
.37229 .51862 Mdot
.36429 .29879 Mdot
.64383 .52888 Mdot
.35921 .3559 Mdot
.37477 .50128 Mdot
.5697 .76831 Mdot
.45714 .60857 Mdot
.47637 .25215 Mdot
.42049 .339 Mdot
.57138 .67 Mdot
.56465 .41875 Mdot
.41613 .33129 Mdot
.4096 .60243 Mdot
.43648 .32464 Mdot
.6403 .48831 Mdot
.36753 .4501 Mdot
.45799 .62588 Mdot
.39048 .52918 Mdot
.39792 .37237 Mdot
.60339 .64462 Mdot
.46635 .54483 Mdot
.6826 .3053 Mdot
.53068 .28709 Mdot
.64207 .40044 Mdot
.54135 .53193 Mdot
.64492 .46948 Mdot
.40155 .31989 Mdot
.64002 .44878 Mdot
.48851 .32603 Mdot
.46436 .62853 Mdot
.59287 .41443 Mdot
.67103 .45718 Mdot
.65894 .25471 Mdot
.60435 .44051 Mdot
.57948 .47375 Mdot
.65899 .44315 Mdot
.42963 .28489 Mdot
.64245 .37298 Mdot
.45092 .344 Mdot
.53017 .77623 Mdot
.45224 .63596 Mdot
.61358 .64561 Mdot
.57138 .67738 Mdot
.72719 .53393 Mdot
.50807 .67211 Mdot
.25391 .43156 Mdot
.44005 .34695 Mdot
.34741 .50097 Mdot
.64261 .45092 Mdot
.17927 .5602 Mdot
.34469 .68284 Mdot
.42189 .60965 Mdot
.36583 .41965 Mdot
.58819 .51451 Mdot
.26668 .69149 Mdot
.58258 .43433 Mdot
.78757 .67621 Mdot
.66509 .50324 Mdot
.58627 .47098 Mdot
.40617 .6577 Mdot
.58588 .61634 Mdot
.61148 .40435 Mdot
.43186 .30761 Mdot
.59311 .68155 Mdot
.38556 .37587 Mdot
.38557 .65498 Mdot
.54009 .76901 Mdot
.63358 .25914 Mdot
.64429 .4614 Mdot
.45965 .62793 Mdot
.45623 .33906 Mdot
.57932 .79596 Mdot
.35463 .5214 Mdot
.33156 .54256 Mdot
.62527 .54291 Mdot
.54038 .16341 Mdot
.58181 .68126 Mdot
.50219 .31886 Mdot
.60165 .46252 Mdot
.58504 .72373 Mdot
.64669 .39301 Mdot
.29158 .26212 Mdot
.56014 .65227 Mdot
.40169 .36151 Mdot
.34971 .47528 Mdot
.44992 .38243 Mdot
.53505 .30241 Mdot
.43793 .56428 Mdot
.48497 .51566 Mdot
.44169 .6256 Mdot
.42402 .49491 Mdot
.4411 .36717 Mdot
.66635 .47584 Mdot
.41519 .87427 Mdot
.43287 .3782 Mdot
.45542 .31585 Mdot
.70173 .25284 Mdot
.6563 .20631 Mdot
.59316 .5197 Mdot
.4093 .34311 Mdot
.44418 .63011 Mdot
.60177 .64923 Mdot
.63742 .47717 Mdot
.63295 .46436 Mdot
.41462 .3371 Mdot
.41172 .66737 Mdot
.61298 .34593 Mdot
.44394 .64947 Mdot
.45321 .35491 Mdot
.4574 .64307 Mdot
.27733 .6193 Mdot
.4719 .66052 Mdot
.63711 .39587 Mdot
.64086 .44933 Mdot
.43134 .72819 Mdot
.43027 .33119 Mdot
.66583 .46581 Mdot
.61583 .48116 Mdot
.42985 .36323 Mdot
.61928 .61486 Mdot
.57718 .35486 Mdot
.64736 .41039 Mdot
.60998 .45775 Mdot
.61017 .67502 Mdot
.51547 .47329 Mdot
.80756 .55107 Mdot
.66172 .47499 Mdot
.57788 .62354 Mdot
.41631 .32034 Mdot
.61101 .42484 Mdot
.24191 .34854 Mdot
.26818 .57187 Mdot
.67459 .47242 Mdot
.4688 .66702 Mdot
.63776 .37978 Mdot
.22597 .67383 Mdot
.60079 .41859 Mdot
.43542 .36054 Mdot
.46269 .32695 Mdot
.75224 .33369 Mdot
.42461 .37158 Mdot
.41474 .62296 Mdot
.36893 .494 Mdot
.29466 .26891 Mdot
.42435 .61459 Mdot
.69643 .43351 Mdot
.78765 .35738 Mdot
.59603 .48816 Mdot
.69286 .4331 Mdot
.3077 .74674 Mdot
.42801 .61498 Mdot
.46768 .34998 Mdot
.5036 .58001 Mdot
.58977 .49661 Mdot
.37397 .52253 Mdot
.5851 .39279 Mdot
.67056 .41734 Mdot
.36044 .76446 Mdot
.25266 .51965 Mdot
.34472 .53039 Mdot
.56278 .46295 Mdot
.66345 .47367 Mdot
.39882 .5833 Mdot
.6414 .44372 Mdot
.60619 .65599 Mdot
.4702 .33666 Mdot
.47252 .64038 Mdot
.58795 .6652 Mdot
.63858 .41556 Mdot
.57893 .64644 Mdot
.46141 .66159 Mdot
.37679 .52497 Mdot
.65447 .42414 Mdot
.5735 .68707 Mdot
.57733 .65029 Mdot
.64929 .47071 Mdot
.44394 .32183 Mdot
.65756 .5088 Mdot
.60423 .42746 Mdot
.63358 .48298 Mdot
.41761 .33365 Mdot
.50581 .11823 Mdot
.5941 .42433 Mdot
.51955 .6371 Mdot
.44979 .31493 Mdot
.417 .53374 Mdot
.47337 .63809 Mdot
.66766 .41355 Mdot
.36529 .53124 Mdot
.37984 .47516 Mdot
.40664 .62986 Mdot
.4753 .33115 Mdot
.44987 .73835 Mdot
.49245 .35259 Mdot
.62189 .50303 Mdot
.62829 .49727 Mdot
.8016 .40489 Mdot
.15856 .46128 Mdot
.46401 .37061 Mdot
.42627 .68078 Mdot
.53915 .58426 Mdot
.36464 .46731 Mdot
.47197 .67199 Mdot
.46823 .32051 Mdot
.47087 .32981 Mdot
.44302 .32736 Mdot
.56723 .66163 Mdot
.44099 .72502 Mdot
.43337 .39474 Mdot
.41173 .38125 Mdot
.62232 .46474 Mdot
.66675 .47033 Mdot
.64665 .64709 Mdot
.69506 .66531 Mdot
.60047 .63696 Mdot
.43238 .65381 Mdot
.66919 .82276 Mdot
.33151 .51183 Mdot
.64475 .24241 Mdot
.68926 .42282 Mdot
.39066 .89247 Mdot
.58603 .42999 Mdot
.64136 .44072 Mdot
.40568 .34133 Mdot
.58815 .69133 Mdot
.59589 .67184 Mdot
.44754 .36808 Mdot
.39879 .32408 Mdot
.6063 .65771 Mdot
.39782 .23665 Mdot
.25404 .30853 Mdot
.46525 .57336 Mdot
.42656 .35542 Mdot
.66627 .29842 Mdot
.38807 .51368 Mdot
.44383 .40377 Mdot
.33201 .49062 Mdot
.44821 .62452 Mdot
.43512 .59393 Mdot
.38069 .50747 Mdot
.62455 .46178 Mdot
.43999 .66741 Mdot
.57953 .47995 Mdot
.40433 .24889 Mdot
.57525 .33681 Mdot
.38211 .73271 Mdot
.58891 .40309 Mdot
.55315 .77364 Mdot
.33222 .56047 Mdot
.62386 .41331 Mdot
.20592 .45686 Mdot
.5723 .65404 Mdot
.43659 .4013 Mdot
.34329 .52533 Mdot
.21302 .67061 Mdot
.66552 .42518 Mdot
.43388 .35628 Mdot
.34929 .49095 Mdot
.73062 .49897 Mdot
.33321 .33681 Mdot
.66068 .42844 Mdot
.44484 .88344 Mdot
.41272 .28865 Mdot
.47298 .64434 Mdot
.81534 .47214 Mdot
.45593 .38256 Mdot
.6228 .69684 Mdot
.29491 .67665 Mdot
.48644 .17099 Mdot
.46415 .35013 Mdot
.47404 .67312 Mdot
.45698 .36768 Mdot
.60542 .64716 Mdot
.48246 .36738 Mdot
.44708 .61706 Mdot
.60882 .43877 Mdot
.4325 .64854 Mdot
.59425 .63129 Mdot
.65788 .73348 Mdot
.34905 .53181 Mdot
.47491 .66324 Mdot
.37424 .48272 Mdot
.74989 .58987 Mdot
.28656 .69266 Mdot
.34538 .51796 Mdot
.76529 .40301 Mdot
.68287 .46504 Mdot
.43878 .3916 Mdot
.41784 .64463 Mdot
.29724 .66684 Mdot
.49054 .55929 Mdot
.41861 .34864 Mdot
.4475 .65975 Mdot
.59071 .54267 Mdot
.78718 .4286 Mdot
.69599 .39491 Mdot
.7508 .60994 Mdot
.42606 .35994 Mdot
.47994 .66862 Mdot
.59396 .79142 Mdot
.43259 .38447 Mdot
.41726 .63565 Mdot
.35553 .46691 Mdot
.36897 .5026 Mdot
.61914 .40354 Mdot
.38118 .54459 Mdot
.43416 .66016 Mdot
.36502 .5721 Mdot
.42441 .31503 Mdot
.70842 .52175 Mdot
.56533 .67481 Mdot
.44893 .6414 Mdot
.61734 .49172 Mdot
.42032 .4012 Mdot
.27068 .59823 Mdot
.66122 .34004 Mdot
.61376 .82866 Mdot
.42786 .64938 Mdot
.46642 .32584 Mdot
.43268 .35163 Mdot
.69988 .43495 Mdot
.52238 .56685 Mdot
.44943 .73537 Mdot
.77237 .47328 Mdot
.71842 .52746 Mdot
.40444 .60973 Mdot
.39892 .60946 Mdot
.68869 .46437 Mdot
.65021 .45815 Mdot
.35944 .46788 Mdot
.60985 .44387 Mdot
.40228 .35092 Mdot
.62206 .40107 Mdot
.37804 .50175 Mdot
.43535 .62581 Mdot
.64695 .42325 Mdot
.59734 .63814 Mdot
.36847 .53425 Mdot
.37443 .45831 Mdot
.44236 .64197 Mdot
.41757 .32844 Mdot
.55138 .63618 Mdot
.44353 .65119 Mdot
.64331 .46118 Mdot
.30071 .50037 Mdot
.62472 .48731 Mdot
.43102 .24005 Mdot
.42886 .38438 Mdot
.46087 .62185 Mdot
.42551 .313 Mdot
.37131 .47649 Mdot
.29056 .68139 Mdot
.62928 .45017 Mdot
.41829 .6314 Mdot
.41846 .72018 Mdot
.42825 .25182 Mdot
.44245 .30002 Mdot
.28402 .52586 Mdot
.39625 .33943 Mdot
.41974 .59467 Mdot
.70994 .27761 Mdot
.58077 .67841 Mdot
.4243 .60874 Mdot
.18843 .40695 Mdot
.42933 .63691 Mdot
.60023 .44228 Mdot
.58907 .44847 Mdot
.47442 .64822 Mdot
.59521 .68676 Mdot
.56202 .80274 Mdot
.44361 .58142 Mdot
.46665 .34864 Mdot
.52643 .17985 Mdot
.53299 .8481 Mdot
.3695 .55271 Mdot
.35101 .47573 Mdot
.58901 .4974 Mdot
.5915 .47703 Mdot
.33458 .48539 Mdot
.38964 .4674 Mdot
.57012 .6404 Mdot
.40872 .61821 Mdot
.44556 .28566 Mdot
.39145 .51432 Mdot
.67349 .36148 Mdot
.51096 .67688 Mdot
.69531 .40909 Mdot
.60882 .53446 Mdot
.63753 .39235 Mdot
.734 .51625 Mdot
.37857 .50564 Mdot
.5904 .46434 Mdot
.68655 .39207 Mdot
.36479 .53026 Mdot
.60561 .65273 Mdot
.26825 .47925 Mdot
.46219 .64164 Mdot
.32381 .20958 Mdot
.59393 .47364 Mdot
.59864 .43918 Mdot
.38703 .50112 Mdot
.47319 .75077 Mdot
.42581 .32732 Mdot
.43346 .38618 Mdot
.43886 .66995 Mdot
.46939 .54056 Mdot
.66023 .40988 Mdot
.61263 .41679 Mdot
.46613 .64092 Mdot
.47991 .65534 Mdot
.35611 .6045 Mdot
.60869 .47024 Mdot
.35182 .48655 Mdot
.5559 .5941 Mdot
.37914 .50382 Mdot
.62073 .48967 Mdot
.59741 .44534 Mdot
.63651 .39607 Mdot
.62082 .49196 Mdot
.36917 .45555 Mdot
.5934 .46613 Mdot
.71283 .4018 Mdot
.42862 .32228 Mdot
.67129 .43609 Mdot
.73148 .5137 Mdot
.61396 .45239 Mdot
.60312 .65105 Mdot
.68424 .358 Mdot
.66328 .42449 Mdot
.66159 .40828 Mdot
.46125 .59042 Mdot
.62043 .43919 Mdot
.33079 .51053 Mdot
.42609 .34065 Mdot
.37113 .47043 Mdot
.38641 .48833 Mdot
.40979 .6445 Mdot
.59097 .62787 Mdot
.68274 .41891 Mdot
.56903 .6471 Mdot
.66593 .39797 Mdot
.67655 .47178 Mdot
.32512 .69975 Mdot
.797 .66204 Mdot
.65901 .74794 Mdot
.62972 .45155 Mdot
.42422 .62205 Mdot
.47007 .63156 Mdot
.38522 .31194 Mdot
.69738 .39909 Mdot
.33707 .48029 Mdot
.37619 .46977 Mdot
.67556 .65961 Mdot
.35175 .75338 Mdot
.60391 .65153 Mdot
.52482 .51122 Mdot
.58309 .48504 Mdot
.62031 .48078 Mdot
.59693 .48512 Mdot
.40857 .65553 Mdot
.5369 .59822 Mdot
.42413 .6098 Mdot
.34445 .42038 Mdot
.38174 .49698 Mdot
.6681 .42784 Mdot
.50567 .36084 Mdot
.42955 .38051 Mdot
.42654 .33995 Mdot
.36328 .45871 Mdot
.49099 .64155 Mdot
.64675 .69311 Mdot
.61397 .15652 Mdot
.42137 .28195 Mdot
.59947 .69008 Mdot
.62818 .41072 Mdot
.43619 .63118 Mdot
.45293 .37419 Mdot
.61632 .66486 Mdot
.66088 .48097 Mdot
.43911 .72541 Mdot
.63111 .45538 Mdot
.54962 .51321 Mdot
.45355 .32775 Mdot
.2775 .27955 Mdot
.47658 .34803 Mdot
.36453 .53475 Mdot
.34819 .52654 Mdot
.59183 .44769 Mdot
.80568 .43132 Mdot
.44138 .38837 Mdot
.4065 .51835 Mdot
.56148 .65019 Mdot
.28012 .59017 Mdot
.60824 .6535 Mdot
.46936 .63579 Mdot
.58975 .68241 Mdot
.45326 .61966 Mdot
.67182 .69219 Mdot
.44888 .29602 Mdot
.58147 .66651 Mdot
.50662 .6318 Mdot
.70165 .40498 Mdot
.61299 .64864 Mdot
.57396 .48574 Mdot
.47823 .2177 Mdot
.46576 .64726 Mdot
.57085 .67523 Mdot
.66444 .47684 Mdot
.16163 .55371 Mdot
.34216 .4991 Mdot
.33512 .48732 Mdot
.62282 .50249 Mdot
.40402 .63691 Mdot
.44235 .307 Mdot
.24249 .38278 Mdot
.3215 .50751 Mdot
.59164 .43452 Mdot
.61356 .40353 Mdot
.39928 .36435 Mdot
.43317 .41981 Mdot
.59471 .44989 Mdot
.74802 .39451 Mdot
.60128 .46717 Mdot
.35316 .46696 Mdot
.45515 .37843 Mdot
.42986 .34662 Mdot
.44784 .66182 Mdot
.40761 .35896 Mdot
.42095 .27006 Mdot
.29642 .47629 Mdot
.59078 .50129 Mdot
.36513 .47928 Mdot
.32046 .44137 Mdot
.34727 .41956 Mdot
.17173 .45778 Mdot
.39852 .3669 Mdot
.6213 .39444 Mdot
.42796 .31416 Mdot
.59323 .64684 Mdot
.43381 .33279 Mdot
.45767 .31283 Mdot
.6186 .42015 Mdot
.65371 .42948 Mdot
.43275 .61844 Mdot
.52527 .57252 Mdot
.42414 .3204 Mdot
.58707 .44819 Mdot
.57998 .47158 Mdot
.58122 .47813 Mdot
.46322 .44307 Mdot
.46246 .37107 Mdot
.62686 .22051 Mdot
.64724 .57914 Mdot
.42307 .32101 Mdot
.24431 .71119 Mdot
.2941 .65884 Mdot
.48194 .63885 Mdot
.37067 .54331 Mdot
.60978 .47118 Mdot
.47226 .63163 Mdot
.65087 .42689 Mdot
.61038 .53474 Mdot
.62221 .43181 Mdot
.60714 .6631 Mdot
.57179 .47088 Mdot
.4225 .59185 Mdot
.43904 .65037 Mdot
.59623 .42479 Mdot
.64142 .42382 Mdot
.64864 .73956 Mdot
.39428 .33157 Mdot
.4297 .32679 Mdot
.45137 .74763 Mdot
.58114 .65762 Mdot
.37124 .52467 Mdot
.65003 .44564 Mdot
.41222 .64987 Mdot
.43543 .65035 Mdot
.45725 .38041 Mdot
.4551 .65504 Mdot
.37348 .51654 Mdot
.63159 .44815 Mdot
.33412 .48858 Mdot
.56653 .6584 Mdot
.46141 .36726 Mdot
.66591 .4313 Mdot
.62179 .46465 Mdot
.46301 .32742 Mdot
.68713 .43477 Mdot
.61017 .67425 Mdot
.42847 .63903 Mdot
.46176 .34834 Mdot
.36895 .49613 Mdot
.46323 .62631 Mdot
.6307 .47892 Mdot
.64796 .82656 Mdot
.6019 .44691 Mdot
.61689 .4731 Mdot
.18313 .40205 Mdot
.572 .4739 Mdot
.42132 .64723 Mdot
.40624 .37116 Mdot
.57797 .43002 Mdot
.72158 .5454 Mdot
.54185 .1326 Mdot
.41937 .61137 Mdot
.62705 .4088 Mdot
.14605 .5088 Mdot
.61357 .41237 Mdot
.76998 .36878 Mdot
.54165 .68643 Mdot
.43419 .50844 Mdot
.67833 .49526 Mdot
.36542 .51455 Mdot
.4309 .61799 Mdot
.46668 .63305 Mdot
.58076 .19341 Mdot
.61607 .41877 Mdot
.54965 .52086 Mdot
.67974 .45555 Mdot
.37302 .50254 Mdot
.66337 .63876 Mdot
.43108 .65086 Mdot
.67258 .76531 Mdot
.6412 .46907 Mdot
.46834 .36571 Mdot
.47636 .62045 Mdot
.29096 .63438 Mdot
.63495 .48184 Mdot
.57281 .64338 Mdot
.38411 .52938 Mdot
.57232 .45201 Mdot
.36404 .48407 Mdot
.63161 .48518 Mdot
.63891 .35827 Mdot
.82841 .50775 Mdot
.44394 .32399 Mdot
.35268 .4712 Mdot
.30394 .51686 Mdot
.60618 .39333 Mdot
.46325 .34846 Mdot
.41988 .34034 Mdot
.57301 .63844 Mdot
.49344 .50541 Mdot
.31468 .37672 Mdot
.64163 .32607 Mdot
.57072 .1862 Mdot
.48282 .62834 Mdot
.30029 .55725 Mdot
.64535 .47917 Mdot
.41561 .7732 Mdot
.33714 .5237 Mdot
.60178 .43783 Mdot
.48706 .23359 Mdot
.44817 .37316 Mdot
.60641 .45906 Mdot
.60353 .66301 Mdot
.4478 .77423 Mdot
.44102 .78181 Mdot
.24345 .6444 Mdot
.44356 .62522 Mdot
.5592 .41931 Mdot
.54734 .46349 Mdot
.43427 .67212 Mdot
.68287 .43361 Mdot
.42048 .64033 Mdot
.44314 .20511 Mdot
.61284 .67474 Mdot
.46592 .36458 Mdot
.29435 .65179 Mdot
.67349 .41436 Mdot
.61579 .49793 Mdot
.61824 .64876 Mdot
.65627 .45841 Mdot
.82202 .59219 Mdot
.35901 .69927 Mdot
.45417 .668 Mdot
.44308 .32645 Mdot
.6627 .40584 Mdot
.50625 .5049 Mdot
.60558 .42403 Mdot
.60564 .30018 Mdot
.6605 .40678 Mdot
.32515 .35851 Mdot
.45409 .32432 Mdot
.3674 .48217 Mdot
.62664 .38416 Mdot
.6286 .43452 Mdot
.58372 .58694 Mdot
.66603 .50127 Mdot
.58481 .44208 Mdot
.44126 .30397 Mdot
.44805 .37916 Mdot
.45013 .34477 Mdot
.43272 .60116 Mdot
.35801 .75903 Mdot
.35883 .47638 Mdot
.62224 .37903 Mdot
.39361 .50954 Mdot
.71631 .35827 Mdot
.60789 .68328 Mdot
.17349 .53965 Mdot
.66848 .44529 Mdot
.44505 .34954 Mdot
.22811 .50179 Mdot
.41328 .32093 Mdot
.53002 .53484 Mdot
.35551 .50138 Mdot
.44247 .37522 Mdot
.63617 .43794 Mdot
.51956 .58071 Mdot
.19915 .60227 Mdot
.37777 .47843 Mdot
.67814 .40566 Mdot
.4737 .62954 Mdot
.34551 .72501 Mdot
.63253 .83355 Mdot
.34129 .49479 Mdot
.30593 .51534 Mdot
.61701 .41653 Mdot
.42427 .38032 Mdot
.36873 .5156 Mdot
.34361 .51009 Mdot
.45553 .65658 Mdot
.6563 .4307 Mdot
.66019 .43274 Mdot
.4298 .59553 Mdot
.37997 .47786 Mdot
.67807 .48743 Mdot
.58102 .4616 Mdot
.12774 .5232 Mdot
.62869 .55351 Mdot
.38163 .16168 Mdot
.4268 .27097 Mdot
.48904 .25082 Mdot
.25831 .34832 Mdot
.46676 .3248 Mdot
.66245 .42269 Mdot
.57352 .4169 Mdot
.43425 .65959 Mdot
.61776 .44572 Mdot
.41898 .67624 Mdot
.34984 .4815 Mdot
.23791 .69637 Mdot
.30365 .43051 Mdot
.45077 .19098 Mdot
.61656 .44329 Mdot
.38025 .41858 Mdot
.59376 .65837 Mdot
.37147 .44354 Mdot
.45642 .3496 Mdot
.64219 .48902 Mdot
.64851 .74183 Mdot
.42482 .60912 Mdot
.41391 .35737 Mdot
.59011 .78281 Mdot
.5591 .76996 Mdot
.62235 .49006 Mdot
.44349 .60501 Mdot
.21795 .47098 Mdot
.74767 .4043 Mdot
.33525 .47038 Mdot
.60773 .65921 Mdot
.43581 .61373 Mdot
.38371 .47989 Mdot
.48371 .30683 Mdot
.43329 .37561 Mdot
.4861 .3422 Mdot
.7043 .70859 Mdot
.44066 .67451 Mdot
.59434 .66279 Mdot
.34863 .74777 Mdot
.42702 .78865 Mdot
.60635 .66491 Mdot
.43931 .5964 Mdot
.45035 .37728 Mdot
.44828 .36121 Mdot
.42589 .34174 Mdot
.65305 .77333 Mdot
.47742 .34187 Mdot
.60762 .22917 Mdot
.5965 .48919 Mdot
.56032 .39115 Mdot
.62212 .40937 Mdot
.33829 .47575 Mdot
.45998 .33275 Mdot
.45419 .54003 Mdot
.67325 .39027 Mdot
.23578 .65303 Mdot
.60281 .42185 Mdot
.36614 .44721 Mdot
.60903 .46518 Mdot
.64964 .25915 Mdot
.43294 .31343 Mdot
.62455 .45 Mdot
.3297 .49239 Mdot
.58238 .64965 Mdot
.48989 .34206 Mdot
.66303 .42825 Mdot
.25795 .4078 Mdot
.57109 .47204 Mdot
.39428 .22855 Mdot
.67454 .54314 Mdot
.59956 .68999 Mdot
.70513 .49641 Mdot
.44621 .67843 Mdot
.54142 .41246 Mdot
.56195 .40243 Mdot
.3779 .48307 Mdot
.26453 .62593 Mdot
.45079 .63455 Mdot
.60005 .71298 Mdot
.60337 .38121 Mdot
.59909 .63267 Mdot
.39894 .31979 Mdot
.34716 .46235 Mdot
.68463 .46608 Mdot
.6905 .4063 Mdot
.44824 .21735 Mdot
.6414 .37039 Mdot
.62501 .39948 Mdot
.61687 .67253 Mdot
.56651 .2013 Mdot
.61636 .45631 Mdot
.52495 .52701 Mdot
.48405 .36084 Mdot
.66537 .49865 Mdot
.65123 .24016 Mdot
.58823 .44334 Mdot
.41561 .36826 Mdot
.46391 .30618 Mdot
.26975 .44731 Mdot
.56611 .64189 Mdot
.66587 .41239 Mdot
.74801 .33038 Mdot
.64436 .46611 Mdot
.3536 .4863 Mdot
.59911 .48072 Mdot
.44422 .61751 Mdot
.64241 .77224 Mdot
.43897 .66467 Mdot
.65165 .40895 Mdot
.42529 .34692 Mdot
.38473 .50369 Mdot
.7049 .72335 Mdot
.49308 .70463 Mdot
.59535 .22098 Mdot
.46053 .16991 Mdot
.58671 .68588 Mdot
.59917 .62683 Mdot
.3524 .45794 Mdot
.62429 .45135 Mdot
.71565 .27156 Mdot
.65638 .50537 Mdot
.61046 .45932 Mdot
.62294 .43076 Mdot
.31007 .71627 Mdot
.36018 .46961 Mdot
.45908 .64889 Mdot
.59614 .4486 Mdot
.58872 .45962 Mdot
.46061 .32041 Mdot
.57921 .65054 Mdot
.47242 .63596 Mdot
.57435 .66387 Mdot
.42926 .62651 Mdot
.23629 .70115 Mdot
.62944 .38151 Mdot
.58388 .65142 Mdot
.35505 .53849 Mdot
.41556 .33636 Mdot
.2941 .48325 Mdot
.46913 .63646 Mdot
.43369 .6554 Mdot
.59833 .42614 Mdot
.41485 .3688 Mdot
.41023 .33428 Mdot
.59302 .64528 Mdot
.34988 .52229 Mdot
.65942 .42354 Mdot
.6709 .47703 Mdot
.37312 .34139 Mdot
.40642 .64471 Mdot
.57816 .53294 Mdot
.24877 .45533 Mdot
.62804 .45264 Mdot
.41164 .33624 Mdot
.63069 .42392 Mdot
.27059 .31449 Mdot
.41808 .37658 Mdot
.5872 .43377 Mdot
.47856 .81287 Mdot
.49287 .67426 Mdot
.28206 .40898 Mdot
.62216 .3975 Mdot
.36274 .2062 Mdot
.65806 .47427 Mdot
.12586 .55003 Mdot
.5505 .71488 Mdot
.66558 .41944 Mdot
.63109 .47615 Mdot
.58059 .34709 Mdot
.64117 .41317 Mdot
.42177 .59346 Mdot
.63118 .7137 Mdot
.44889 .30741 Mdot
.27935 .35208 Mdot
.53759 .38822 Mdot
.56059 .65623 Mdot
.44063 .67018 Mdot
.39548 .60753 Mdot
.59882 .67391 Mdot
.42832 .35779 Mdot
.64035 .45446 Mdot
.4633 .51715 Mdot
.40057 .62437 Mdot
.70549 .45042 Mdot
.35397 .49031 Mdot
.32678 .60086 Mdot
.49589 .65231 Mdot
.36868 .48986 Mdot
.67439 .44199 Mdot
.58215 .34989 Mdot
.7429 .65072 Mdot
.25 .30209 Mdot
.38785 .49098 Mdot
.38196 .4853 Mdot
.63439 .78673 Mdot
.56019 .66658 Mdot
.47198 .20197 Mdot
.32878 .3473 Mdot
.37889 .51598 Mdot
.75193 .44776 Mdot
.41274 .61454 Mdot
.2656 .40089 Mdot
.43717 .40142 Mdot
.62325 .49633 Mdot
.63369 .43718 Mdot
.35183 .52469 Mdot
.41413 .26279 Mdot
.82215 .49746 Mdot
.37489 .48446 Mdot
.70748 .38906 Mdot
.45645 .46167 Mdot
.29466 .66104 Mdot
.40792 .6344 Mdot
.56898 .63904 Mdot
.61055 .69819 Mdot
.46984 .34806 Mdot
.57988 .63079 Mdot
.43734 .77432 Mdot
.66088 .45309 Mdot
.3771 .49325 Mdot
.27317 .59704 Mdot
.36609 .49782 Mdot
.59662 .67334 Mdot
.60115 .69021 Mdot
.42844 .32255 Mdot
.43165 .32727 Mdot
.49983 .26559 Mdot
.67694 .61993 Mdot
.60733 .41573 Mdot
.21379 .57972 Mdot
.42333 .31545 Mdot
.64265 .52626 Mdot
.59952 .62835 Mdot
.58063 .65327 Mdot
.61736 .57429 Mdot
.66106 .44015 Mdot
.75671 .34766 Mdot
.65614 .44201 Mdot
.66655 .63367 Mdot
.65835 .39844 Mdot
.45524 .65599 Mdot
.66525 .43825 Mdot
.55649 .6245 Mdot
.68395 .47079 Mdot
.58685 .469 Mdot
.40453 .64557 Mdot
.57305 .44525 Mdot
.44635 .61893 Mdot
.64194 .40476 Mdot
.55868 .65171 Mdot
.41751 .66012 Mdot
.72732 .56493 Mdot
.52271 .61535 Mdot
.45229 .60349 Mdot
.58822 .63222 Mdot
.56347 .66751 Mdot
.7548 .52794 Mdot
.45693 .35061 Mdot
.47223 .38647 Mdot
.62042 .44996 Mdot
.41898 .67413 Mdot
.35625 .47024 Mdot
.59381 .46511 Mdot
.56504 .44663 Mdot
.60504 .4058 Mdot
.46907 .35681 Mdot
.44159 .73575 Mdot
.58744 .6472 Mdot
.42873 .59949 Mdot
.60965 .61056 Mdot
.4054 .61789 Mdot
.66797 .37954 Mdot
.56776 .41618 Mdot
.48373 .27213 Mdot
.23548 .55851 Mdot
.6152 .80796 Mdot
.42802 .37505 Mdot
.47186 .66523 Mdot
.56318 .67031 Mdot
.68044 .50554 Mdot
.45011 .35338 Mdot
.44676 .6172 Mdot
.63196 .45497 Mdot
.67609 .40355 Mdot
.33988 .43844 Mdot
.53428 .43228 Mdot
.69783 .54448 Mdot
.40665 .61728 Mdot
.47157 .67427 Mdot
.42255 .78432 Mdot
.62626 .71352 Mdot
.4785 .55159 Mdot
.60991 .42962 Mdot
.57149 .64543 Mdot
.45273 .37427 Mdot
.72438 .67909 Mdot
.34038 .51814 Mdot
.52371 .57014 Mdot
.61825 .44403 Mdot
.42543 .52225 Mdot
.4243 .34575 Mdot
.60389 .65804 Mdot
.35389 .52568 Mdot
.62148 .6712 Mdot
.42216 .66852 Mdot
.5696 .15736 Mdot
.64897 .46378 Mdot
.603 .41693 Mdot
.34985 .53339 Mdot
.45251 .3694 Mdot
.62035 .64996 Mdot
.41202 .23987 Mdot
.46778 .65784 Mdot
.73195 .2871 Mdot
.40515 .35408 Mdot
.64187 .26764 Mdot
.42378 .59922 Mdot
.36512 .45876 Mdot
.74711 .5493 Mdot
.37734 .50278 Mdot
.65198 .40615 Mdot
.4368 .34711 Mdot
.34431 .49437 Mdot
.55206 .57359 Mdot
.15246 .52888 Mdot
.65951 .28937 Mdot
.65532 .44941 Mdot
.17535 .59345 Mdot
.35045 .25638 Mdot
.39545 .31886 Mdot
.36559 .53156 Mdot
.60218 .42796 Mdot
.68101 .43381 Mdot
.64004 .46623 Mdot
.35154 .50545 Mdot
.31894 .68444 Mdot
.4672 .6479 Mdot
.61889 .41262 Mdot
.56939 .64202 Mdot
.45126 .62533 Mdot
.29225 .64987 Mdot
.425 .65076 Mdot
.39263 .34895 Mdot
.59688 .48023 Mdot
.39427 .45322 Mdot
.16586 .62607 Mdot
.37342 .47179 Mdot
.44743 .59971 Mdot
.60238 .47684 Mdot
.2617 .59279 Mdot
.44975 .34676 Mdot
.46242 .66184 Mdot
.59897 .43834 Mdot
.3065 .65809 Mdot
.65896 .73782 Mdot
.4261 .65078 Mdot
.45447 .359 Mdot
.2245 .37366 Mdot
.61275 .44506 Mdot
.65709 .47242 Mdot
.44507 .36925 Mdot
.5873 .36145 Mdot
.59513 .78696 Mdot
.63689 .42388 Mdot
.36825 .48341 Mdot
.70649 .23719 Mdot
.58073 .43115 Mdot
.63297 .59002 Mdot
.43369 .61636 Mdot
.26443 .43058 Mdot
.59024 .54033 Mdot
.6549 .52109 Mdot
.39598 .25913 Mdot
.49296 .42558 Mdot
.2256 .66274 Mdot
.43561 .68057 Mdot
.56581 .753 Mdot
.2233 .66896 Mdot
.34132 .46608 Mdot
.48857 .39438 Mdot
.36758 .28644 Mdot
.71221 .74453 Mdot
.22459 .38814 Mdot
.49396 .76202 Mdot
.64513 .74647 Mdot
.45295 .49145 Mdot
.42655 .63119 Mdot
.56906 .69428 Mdot
.65673 .42633 Mdot
.34868 .25597 Mdot
.72955 .32946 Mdot
.8228 .45402 Mdot
.16974 .58383 Mdot
.75543 .36028 Mdot
.17633 .55575 Mdot
.17614 .4446 Mdot
.46723 .25241 Mdot
.23489 .5403 Mdot
.74889 .29931 Mdot
.46919 .80578 Mdot
.59262 .18301 Mdot
.56032 .47923 Mdot
.54339 .53813 Mdot
.41452 .20574 Mdot
.60842 .2463 Mdot
.79747 .44284 Mdot
.4482 .66347 Mdot
.40783 .37472 Mdot
.35953 .29385 Mdot
.40693 .31478 Mdot
.35783 .55661 Mdot
.23074 .35361 Mdot
.14322 .49893 Mdot
.65168 .25629 Mdot
.3378 .21015 Mdot
.50922 .22793 Mdot
.8649 .58007 Mdot
.42422 .58216 Mdot
.45513 .38444 Mdot
.63308 .66395 Mdot
.41054 .7839 Mdot
.35026 .39794 Mdot
.3653 .27136 Mdot
.33627 .71107 Mdot
.72095 .60599 Mdot
.43269 .3557 Mdot
.701 .50684 Mdot
.36726 .5639 Mdot
.31063 .42931 Mdot
.6274 .72232 Mdot
.19097 .42573 Mdot
.48086 .52975 Mdot
.26518 .38859 Mdot
.31599 .57784 Mdot
.63541 .82777 Mdot
.65653 .57146 Mdot
.45246 .27484 Mdot
.30474 .48226 Mdot
.26355 .32827 Mdot
.74783 .70377 Mdot
.68833 .63654 Mdot
.41577 .78573 Mdot
.36074 .78596 Mdot
.32557 .25738 Mdot
.41283 .83115 Mdot
.47964 .37698 Mdot
.62058 .40013 Mdot
.52713 .36042 Mdot
.7389 .32188 Mdot
.56469 .68686 Mdot
.25262 .65035 Mdot
.56723 .66881 Mdot
.39419 .37256 Mdot
.63304 .77126 Mdot
.62658 .23845 Mdot
.75281 .32808 Mdot
.6168 .63446 Mdot
.58929 .40297 Mdot
.77208 .25508 Mdot
.22063 .64831 Mdot
.28215 .43443 Mdot
.12525 .52946 Mdot
.4427 .54377 Mdot
.72661 .50277 Mdot
.3452 .49563 Mdot
.20278 .65123 Mdot
.44355 .35734 Mdot
.33933 .80491 Mdot
.15369 .58601 Mdot
.81089 .51337 Mdot
.47584 .08995 Mdot
.39764 .75763 Mdot
.43302 .51615 Mdot
.4785 .42172 Mdot
.70309 .5666 Mdot
.81879 .56552 Mdot
.80196 .48406 Mdot
.26269 .57603 Mdot
.43699 .17994 Mdot
.20401 .64417 Mdot
.73171 .30366 Mdot
.57676 .16558 Mdot
.72884 .73186 Mdot
.5097 .48873 Mdot
.41768 .40672 Mdot
.43242 .57365 Mdot
.19554 .4733 Mdot
.30007 .74799 Mdot
.64014 .57972 Mdot
.57025 .13088 Mdot
.57857 .61651 Mdot
.53754 .71364 Mdot
.23412 .32802 Mdot
.73619 .59178 Mdot
.68628 .52628 Mdot
.56704 .78995 Mdot
.7038 .43988 Mdot
.53803 .79365 Mdot
.19187 .5502 Mdot
.29382 .50888 Mdot
.47598 .80322 Mdot
.22754 .43109 Mdot
.43334 .22729 Mdot
.57613 .33127 Mdot
.40737 .78825 Mdot
.42214 .3111 Mdot
.69962 .61351 Mdot
.66614 .54053 Mdot
.137 .5005 Mdot
.30716 .51674 Mdot
.14471 .44361 Mdot
.6081 .77156 Mdot
.62312 .38964 Mdot
.54648 .42465 Mdot
.72211 .40802 Mdot
.6814 .60713 Mdot
.57813 .45644 Mdot
.35416 .4165 Mdot
.15555 .45734 Mdot
.49803 .2208 Mdot
.28417 .51745 Mdot
.2676 .63627 Mdot
.24378 .3066 Mdot
.51019 .30862 Mdot
.60868 .73825 Mdot
.6507 .64243 Mdot
.69402 .77863 Mdot
.4549 .63795 Mdot
.72204 .29061 Mdot
.34551 .45654 Mdot
.68143 .71335 Mdot
.6553 .32593 Mdot
.80888 .56944 Mdot
.15595 .45588 Mdot
.52554 .77657 Mdot
.6305 .7568 Mdot
.75859 .57569 Mdot
.7071 .25385 Mdot
.2646 .64494 Mdot
.58074 .39689 Mdot
.32221 .29321 Mdot
.59128 .68809 Mdot
.52718 .2982 Mdot
.65285 .22066 Mdot
.49817 .73209 Mdot
.59999 .49801 Mdot
.77329 .61189 Mdot
.39114 .70195 Mdot
.51876 .57865 Mdot
.5028 .8613 Mdot
.69827 .40469 Mdot
.36035 .75124 Mdot
.34274 .24605 Mdot
.67812 .57971 Mdot
.25744 .31393 Mdot
.24623 .39142 Mdot
.3909 .81739 Mdot
.1454 .56251 Mdot
.47925 .71538 Mdot
.24548 .68853 Mdot
.13031 .50765 Mdot
.4251 .82683 Mdot
.60456 .37245 Mdot
.33645 .52864 Mdot
.56427 .87823 Mdot
.41309 .59932 Mdot
.30915 .72332 Mdot
.57168 .18666 Mdot
.31084 .65472 Mdot
.45442 .28867 Mdot
.57385 .49958 Mdot
.45959 .49996 Mdot
.39314 .32335 Mdot
.57444 .45216 Mdot
.53403 .8445 Mdot
.40141 .81039 Mdot
.47503 .84602 Mdot
.35143 .2266 Mdot
.24673 .69788 Mdot
.42854 .47946 Mdot
.61685 .24372 Mdot
.38212 .32923 Mdot
.63312 .49339 Mdot
.53025 .6627 Mdot
.39678 .7557 Mdot
.77074 .62287 Mdot
.34462 .38393 Mdot
.39636 .32502 Mdot
.22774 .61003 Mdot
.8775 .63137 Mdot
.50989 .24186 Mdot
.65163 .23562 Mdot
.43561 .78343 Mdot
.67044 .60848 Mdot
.19618 .49768 Mdot
.80968 .54249 Mdot
.17813 .41533 Mdot
.39692 .30968 Mdot
.57526 .18225 Mdot
.50692 .75333 Mdot
.76188 .46875 Mdot
.43235 .73585 Mdot
.15578 .50382 Mdot
.4254 .43422 Mdot
.74495 .67345 Mdot
.33204 .32302 Mdot
.81576 .5055 Mdot
.56061 .70897 Mdot
.33277 .60089 Mdot
.66 .22341 Mdot
.26494 .52353 Mdot
.65409 .60714 Mdot
.46716 .47537 Mdot
.70418 .48367 Mdot
.49152 .42507 Mdot
.65224 .59866 Mdot
.75269 .4938 Mdot
.28205 .72232 Mdot
.11024 .55837 Mdot
.61244 .82178 Mdot
.31682 .21834 Mdot
.19632 .53682 Mdot
.63822 .49837 Mdot
.21101 .3448 Mdot
.43472 .84643 Mdot
.14205 .57755 Mdot
.36116 .65015 Mdot
.40352 .66911 Mdot
.39687 .50126 Mdot
.57326 .82225 Mdot
.41238 .72395 Mdot
.20334 .38186 Mdot
.55073 .79888 Mdot
.38771 .53167 Mdot
.80385 .65074 Mdot
.38668 .79764 Mdot
.66852 .31918 Mdot
.53615 .44665 Mdot
.69378 .46754 Mdot
.67652 .27873 Mdot
.39728 .33021 Mdot
.3055 .55878 Mdot
.68563 .6237 Mdot
.44649 .64442 Mdot
.54381 .68235 Mdot
.35741 .27197 Mdot
.57209 .47164 Mdot
.50688 .4109 Mdot
.41013 .38083 Mdot
.23598 .55311 Mdot
.30014 .45739 Mdot
.28189 .7413 Mdot
.38474 .74021 Mdot
.69055 .48667 Mdot
.6725 .57905 Mdot
.42392 .73958 Mdot
.59105 .79474 Mdot
.37276 .45235 Mdot
.16369 .56505 Mdot
.54509 .55179 Mdot
.69688 .61455 Mdot
.69765 .2987 Mdot
.43974 .23515 Mdot
.55789 .4435 Mdot
.23986 .4747 Mdot
.58732 .29422 Mdot
.52813 .57658 Mdot
.41121 .40186 Mdot
.42366 .40923 Mdot
.22537 .30892 Mdot
.45571 .77527 Mdot
.31219 .58303 Mdot
.16397 .55182 Mdot
.36289 .50816 Mdot
.42094 .32004 Mdot
.53048 .65292 Mdot
.42059 .2286 Mdot
.60338 .27549 Mdot
.65921 .73818 Mdot
.34724 .68988 Mdot
.51213 .72606 Mdot
.17109 .55591 Mdot
.17439 .58141 Mdot
.82413 .42802 Mdot
.43985 .29959 Mdot
.44378 .25154 Mdot
.48425 .19255 Mdot
.39804 .34654 Mdot
.38632 .28099 Mdot
.36613 .3991 Mdot
.28599 .73621 Mdot
.38823 .5393 Mdot
.4242 .18065 Mdot
.73205 .52619 Mdot
.3065 .67875 Mdot
.70022 .72859 Mdot
.66512 .22592 Mdot
.16504 .53985 Mdot
.74655 .41279 Mdot
.65278 .33411 Mdot
.57597 .49327 Mdot
.53182 .47332 Mdot
.69189 .79633 Mdot
.52376 .6245 Mdot
.64556 .26775 Mdot
.22673 .4185 Mdot
.6463 .458 Mdot
.61025 .82849 Mdot
.39415 .24712 Mdot
.63171 .79114 Mdot
.3886 .52514 Mdot
.6729 .46376 Mdot
.67123 .48376 Mdot
.6261 .60034 Mdot
.27094 .43794 Mdot
.32671 .7477 Mdot
.65498 .21405 Mdot
.21461 .45751 Mdot
.72909 .32971 Mdot
.35722 .74715 Mdot
.20267 .39875 Mdot
.34237 .26049 Mdot
.50094 .51553 Mdot
.39957 .75293 Mdot
.74392 .57221 Mdot
.33578 .21472 Mdot
.58617 .5768 Mdot
.40502 .43725 Mdot
.36324 .37321 Mdot
.24703 .43499 Mdot
.71922 .6951 Mdot
.63825 .48723 Mdot
.58998 .78288 Mdot
.18168 .43531 Mdot
.79761 .3842 Mdot
.7954 .62864 Mdot
.59065 .83337 Mdot
.61569 .3083 Mdot
.24429 .41831 Mdot
.3427 .26821 Mdot
.7687 .29773 Mdot
.55809 .55318 Mdot
.22376 .62972 Mdot
.74949 .57201 Mdot
.16763 .55343 Mdot
.33193 .52394 Mdot
.33903 .33658 Mdot
.27049 .6419 Mdot
.2621 .7055 Mdot
.52893 .33283 Mdot
.1636 .48588 Mdot
.43936 .52759 Mdot
.36692 .81019 Mdot
.25776 .52563 Mdot
.44704 .47873 Mdot
.46281 .66898 Mdot
.51908 .78068 Mdot
.18303 .54288 Mdot
.22091 .55116 Mdot
.66239 .22841 Mdot
.4784 .67341 Mdot
.55562 .68741 Mdot
.69944 .32638 Mdot
.74024 .62079 Mdot
.23785 .44611 Mdot
.6731 .57894 Mdot
.15452 .48337 Mdot
.62153 .61063 Mdot
.60875 .76226 Mdot
.35426 .74027 Mdot
.53919 .15133 Mdot
.28063 .43193 Mdot
.47643 .78527 Mdot
.38211 .25617 Mdot
.53731 .70234 Mdot
.74912 .46012 Mdot
.14865 .68771 Mdot
.52386 .16344 Mdot
.24629 .53285 Mdot
.30082 .74821 Mdot
.27019 .30548 Mdot
.23871 .55805 Mdot
.81561 .57618 Mdot
.62621 .55315 Mdot
.6555 .70796 Mdot
.62349 .43186 Mdot
.48599 .85595 Mdot
.7197 .62519 Mdot
.32326 .76958 Mdot
.21955 .33008 Mdot
.67876 .28446 Mdot
.57172 .46688 Mdot
.42776 .60316 Mdot
.31915 .54327 Mdot
.72167 .65239 Mdot
.57564 .35817 Mdot
.71576 .50092 Mdot
.35757 .7013 Mdot
.43537 .67261 Mdot
.44234 .74277 Mdot
.40498 .2926 Mdot
.37595 .71823 Mdot
.24727 .45165 Mdot
.48758 .68376 Mdot
.49656 .53964 Mdot
.65921 .59869 Mdot
.60757 .54174 Mdot
.66529 .31661 Mdot
.80093 .58563 Mdot
.50121 .45921 Mdot
.42267 .65064 Mdot
.6297 .3238 Mdot
.44923 .18271 Mdot
.22095 .47043 Mdot
.35306 .78079 Mdot
.55944 .7826 Mdot
.67034 .34248 Mdot
.64716 .60127 Mdot
.82226 .54834 Mdot
.77455 .39795 Mdot
.23348 .59078 Mdot
.56385 .51145 Mdot
.76395 .39795 Mdot
.3275 .29903 Mdot
.23207 .69118 Mdot
.58924 .18293 Mdot
.52366 .17838 Mdot
.49121 .60666 Mdot
.59639 .24716 Mdot
.69681 .30782 Mdot
.73206 .55602 Mdot
.49315 .56014 Mdot
.85194 .60775 Mdot
.45195 .39731 Mdot
.72972 .78419 Mdot
.34889 .47282 Mdot
.73465 .73429 Mdot
.75338 .55358 Mdot
.46711 .46999 Mdot
.48231 .56298 Mdot
.2435 .47619 Mdot
.32791 .35766 Mdot
.37025 .21484 Mdot
.81278 .44831 Mdot
.40325 .62431 Mdot
.65807 .21178 Mdot
.55362 .1472 Mdot
.60096 .33735 Mdot
.59121 .40364 Mdot
.51728 .1621 Mdot
.44949 .68428 Mdot
.77153 .62294 Mdot
.25783 .30702 Mdot
.21506 .52826 Mdot
.66826 .36214 Mdot
.67491 .61191 Mdot
.21842 .62026 Mdot
.14948 .5521 Mdot
.81349 .61988 Mdot
.19223 .54972 Mdot
.33646 .52796 Mdot
.43669 .48121 Mdot
.1714 .49246 Mdot
.70578 .52645 Mdot
.27778 .37132 Mdot
.69074 .52758 Mdot
.80481 .70381 Mdot
.29133 .70899 Mdot
.32483 .74589 Mdot
.6869 .53504 Mdot
.47891 .33959 Mdot
.27145 .48175 Mdot
.68041 .53024 Mdot
.22236 .52121 Mdot
.41275 .21206 Mdot
.67162 .53662 Mdot
.81712 .37209 Mdot
.47343 .2199 Mdot
.40557 .68327 Mdot
.70882 .32238 Mdot
.48139 .226 Mdot
.38506 .53133 Mdot
.63252 .71794 Mdot
.22187 .42594 Mdot
.35582 .5356 Mdot
.23696 .45244 Mdot
.2594 .41212 Mdot
.50141 .20447 Mdot
.6163 .27996 Mdot
.20959 .47933 Mdot
.55695 .35563 Mdot
.48766 .3995 Mdot
.71861 .68438 Mdot
.47788 .62641 Mdot
.21975 .41216 Mdot
.46822 .66179 Mdot
.60793 .52851 Mdot
.53257 .5719 Mdot
.69552 .36232 Mdot
.59864 .81903 Mdot
.58577 .68636 Mdot
.44891 .38403 Mdot
.7494 .72883 Mdot
.40072 .35264 Mdot
.51225 .84877 Mdot
.80954 .55734 Mdot
.69843 .29762 Mdot
.4931 .70979 Mdot
.47766 .74074 Mdot
.86016 .48092 Mdot
.49601 .40838 Mdot
.47603 .59711 Mdot
.47072 .41227 Mdot
.46092 .37721 Mdot
.36279 .73701 Mdot
.41023 .65181 Mdot
.59264 .5561 Mdot
.41805 .49403 Mdot
.40405 .41756 Mdot
.4371 .29286 Mdot
.53831 .55737 Mdot
.66654 .67809 Mdot
.27885 .72823 Mdot
.41978 .63463 Mdot
.77912 .71831 Mdot
.56158 .44461 Mdot
.56416 .32758 Mdot
.17719 .41206 Mdot
.81138 .63484 Mdot
.40226 .59755 Mdot
.56749 .14389 Mdot
.66547 .40056 Mdot
.20219 .49515 Mdot
.43838 .36022 Mdot
.54632 .17658 Mdot
.58247 .6811 Mdot
.68641 .57531 Mdot
.39494 .48522 Mdot
.74152 .67773 Mdot
.36335 .69313 Mdot
.47426 .32394 Mdot
.20629 .55113 Mdot
.45137 .24619 Mdot
.31212 .34503 Mdot
.46173 .74317 Mdot
.61591 .33413 Mdot
.61071 .27362 Mdot
.44285 .294 Mdot
.30327 .7326 Mdot
.55379 .17462 Mdot
.22104 .69404 Mdot
.72252 .42229 Mdot
.55806 .76456 Mdot
.36669 .36674 Mdot
.23014 .47397 Mdot
.55041 .50517 Mdot
.1676 .43583 Mdot
.69434 .6277 Mdot
.37907 .40082 Mdot
.66475 .62579 Mdot
.62393 .52298 Mdot
.48907 .52136 Mdot
.3315 .57436 Mdot
.83098 .47102 Mdot
.54624 .50985 Mdot
.76262 .69116 Mdot
.57009 .51762 Mdot
.37105 .75977 Mdot
.4219 .28003 Mdot
.39171 .64407 Mdot
.60996 .25321 Mdot
.30554 .51758 Mdot
.22398 .67895 Mdot
.1708 .42852 Mdot
.38773 .45468 Mdot
.35281 .72446 Mdot
.25849 .33821 Mdot
.6918 .48983 Mdot
.42402 .50492 Mdot
.63311 .39927 Mdot
.40357 .27836 Mdot
.81527 .63869 Mdot
.22724 .50273 Mdot
.57287 .40133 Mdot
.22453 .6635 Mdot
.19698 .63958 Mdot
.35338 .79761 Mdot
.72214 .27383 Mdot
.46927 .32929 Mdot
.45482 .83511 Mdot
.72082 .49235 Mdot
.13674 .52383 Mdot
.2295 .58047 Mdot
.21478 .32229 Mdot
.62824 .33611 Mdot
.23501 .40224 Mdot
.80887 .47322 Mdot
.30238 .37529 Mdot
.31355 .26661 Mdot
.44052 .45034 Mdot
.29952 .58124 Mdot
.29325 .27728 Mdot
.82234 .341 Mdot
.54902 .49092 Mdot
.2609 .39906 Mdot
.34584 .30044 Mdot
.21729 .42067 Mdot
.56698 .72644 Mdot
.59996 .48106 Mdot
.27343 .60766 Mdot
.67159 .74513 Mdot
.65541 .58756 Mdot
.55098 .68146 Mdot
.56374 .72479 Mdot
.69291 .68588 Mdot
.66998 .64676 Mdot
.59238 .18241 Mdot
.63404 .33288 Mdot
.57743 .54427 Mdot
.60857 .39197 Mdot
.43563 .28264 Mdot
.57517 .62947 Mdot
.3837 .66666 Mdot
.63488 .40299 Mdot
.40536 .66694 Mdot
.31288 .35356 Mdot
.57089 .83937 Mdot
.28519 .50665 Mdot
.39216 .23965 Mdot
.43249 .39985 Mdot
.25906 .45021 Mdot
.5049 .35541 Mdot
.67887 .76028 Mdot
.55417 .74931 Mdot
.64021 .57956 Mdot
.20559 .62599 Mdot
.47217 .80226 Mdot
.45264 .22313 Mdot
.47117 .81516 Mdot
.34139 .52772 Mdot
.66952 .36807 Mdot
.35216 .31766 Mdot
.43536 .75101 Mdot
.39709 .38664 Mdot
.23403 .40833 Mdot
.47856 .60347 Mdot
.47127 .78965 Mdot
.3368 .24866 Mdot
.44655 .24026 Mdot
.70298 .33574 Mdot
.17889 .59275 Mdot
.4184 .61239 Mdot
.52515 .17224 Mdot
.279 .36082 Mdot
.54508 .75924 Mdot
.36019 .7642 Mdot
.26323 .72487 Mdot
.45783 .54488 Mdot
.72227 .59229 Mdot
.64887 .47207 Mdot
.62661 .22067 Mdot
.2336 .49693 Mdot
.54399 .39997 Mdot
.34936 .6459 Mdot
.40998 .34539 Mdot
.3485 .60043 Mdot
.55077 .53876 Mdot
.67093 .69667 Mdot
.40335 .31462 Mdot
.74277 .33467 Mdot
.56073 .63841 Mdot
.4346 .54896 Mdot
.5761 .44673 Mdot
.71201 .58395 Mdot
.75106 .32 Mdot
.69124 .38486 Mdot
.18913 .52021 Mdot
.63729 .32821 Mdot
.43368 .22221 Mdot
.21322 .49862 Mdot
.23747 .59826 Mdot
.32357 .36352 Mdot
.6292 .26703 Mdot
.36746 .67469 Mdot
.60778 .40418 Mdot
.39133 .63665 Mdot
.40878 .32905 Mdot
.23968 .34393 Mdot
.60946 .3038 Mdot
.72764 .56809 Mdot
.47878 .46507 Mdot
.51246 .367 Mdot
.47968 .44382 Mdot
.20025 .36389 Mdot
.30269 .37676 Mdot
.6862 .62731 Mdot
.36815 .5539 Mdot
.75078 .55511 Mdot
.8074 .58225 Mdot
.17049 .61111 Mdot
.81924 .53171 Mdot
.46418 .52636 Mdot
.77148 .68326 Mdot
.25682 .51099 Mdot
.26157 .30237 Mdot
.68113 .64068 Mdot
.46046 .55713 Mdot
.53994 .65129 Mdot
.34858 .43513 Mdot
.50285 .48846 Mdot
.53742 .62617 Mdot
.60847 .55069 Mdot
.32876 .64619 Mdot
.37976 .5689 Mdot
.57778 .5013 Mdot
.31127 .72096 Mdot
.19372 .61051 Mdot
.55709 .18075 Mdot
.49432 .43454 Mdot
.60617 .72251 Mdot
.68882 .6773 Mdot
.27785 .23163 Mdot
.64495 .82709 Mdot
.64906 .47066 Mdot
.49898 .43614 Mdot
.70441 .59767 Mdot
.40723 .61121 Mdot
.65632 .53453 Mdot
.50854 .37736 Mdot
.3652 .46192 Mdot
.52623 .63843 Mdot
.4919 .79505 Mdot
.2468 .47734 Mdot
.75209 .60284 Mdot
.28342 .64694 Mdot
.56698 .84363 Mdot
.418 .19881 Mdot
.22955 .4843 Mdot
.22775 .28165 Mdot
.36563 .57201 Mdot
.44331 .40962 Mdot
.5209 .35849 Mdot
.28813 .73263 Mdot
.67521 .57203 Mdot
.69852 .71032 Mdot
.25189 .62251 Mdot
.6892 .63447 Mdot
.73825 .47612 Mdot
.35757 .74446 Mdot
.34907 .61247 Mdot
.46634 .49434 Mdot
.47967 .74191 Mdot
.42709 .80664 Mdot
.73358 .34459 Mdot
.2044 .61072 Mdot
.68056 .74321 Mdot
.80269 .33637 Mdot
.20424 .6549 Mdot
.53554 .66828 Mdot
.58539 .73115 Mdot
.52312 .3545 Mdot
.7211 .52523 Mdot
.7517 .43903 Mdot
.76745 .63521 Mdot
.59029 .27054 Mdot
.44966 .72196 Mdot
.72909 .71992 Mdot
.65354 .60599 Mdot
.48576 .22152 Mdot
.46253 .55727 Mdot
.65209 .31724 Mdot
.36663 .72852 Mdot
.66653 .54929 Mdot
.5633 .58168 Mdot
.71431 .54596 Mdot
.62169 .32758 Mdot
.40038 .25757 Mdot
.26028 .35932 Mdot
.83956 .39371 Mdot
.23821 .6191 Mdot
.68842 .75527 Mdot
.59007 .4855 Mdot
.2461 .72236 Mdot
.26355 .36581 Mdot
.24877 .62477 Mdot
.37418 .22933 Mdot
.39256 .66797 Mdot
.3864 .40545 Mdot
.60678 .40499 Mdot
.2048 .57586 Mdot
.6519 .27294 Mdot
.48307 .23891 Mdot
.72979 .69653 Mdot
.6758 .58939 Mdot
.61394 .74137 Mdot
.73578 .54217 Mdot
.70159 .38659 Mdot
.41035 .37319 Mdot
.46288 .84433 Mdot
.44885 .52506 Mdot
.58552 .5202 Mdot
.56444 .38629 Mdot
.8096 .48062 Mdot
.46402 .162 Mdot
.72121 .40804 Mdot
.44854 .79658 Mdot
.75352 .36342 Mdot
.72292 .37787 Mdot
.64603 .52971 Mdot
.36131 .13424 Mdot
.11515 .55002 Mdot
.46004 .31194 Mdot
.66273 .23939 Mdot
.75827 .36439 Mdot
.28017 .7223 Mdot
.51173 .7522 Mdot
.37512 .66606 Mdot
.7906 .45626 Mdot
.73908 .49777 Mdot
.58252 .40509 Mdot
.35091 .24034 Mdot
.16122 .5941 Mdot
.7318 .70111 Mdot
.21917 .65825 Mdot
.5478 .45486 Mdot
.61078 .38074 Mdot
.33609 .17566 Mdot
.17074 .50393 Mdot
.70235 .44733 Mdot
.81291 .47554 Mdot
.41975 .40654 Mdot
.64582 .42784 Mdot
.28446 .67693 Mdot
.64967 .21106 Mdot
.65067 .60609 Mdot
.26324 .7066 Mdot
.4157 .30947 Mdot
.45721 .582 Mdot
.36333 .46001 Mdot
.48616 .56212 Mdot
.66098 .39124 Mdot
.34805 .50516 Mdot
.71887 .37045 Mdot
.23307 .39377 Mdot
.40146 .50999 Mdot
.59762 .17646 Mdot
.1595 .41018 Mdot
.63013 .30479 Mdot
.32772 .45031 Mdot
.69464 .48872 Mdot
.47411 .22527 Mdot
.71407 .66313 Mdot
.38062 .32735 Mdot
.2804 .28413 Mdot
.23234 .75658 Mdot
.30634 .59336 Mdot
.64902 .69655 Mdot
.38687 .33717 Mdot
.57297 .53894 Mdot
.67885 .31129 Mdot
.41767 .54575 Mdot
.42519 .61527 Mdot
.63133 .50703 Mdot
.70632 .39357 Mdot
.38999 .51641 Mdot
.72406 .7833 Mdot
.6089 .48225 Mdot
.61912 .5382 Mdot
.13877 .52554 Mdot
.71776 .68576 Mdot
.54857 .32595 Mdot
.69201 .42975 Mdot
.31754 .42801 Mdot
.45933 .55722 Mdot
.2036 .42422 Mdot
.60498 .765 Mdot
.24103 .67335 Mdot
.60621 .30235 Mdot
.71858 .3423 Mdot
.58634 .45233 Mdot
.5616 .67831 Mdot
.27046 .39723 Mdot
.26349 .66305 Mdot
.54606 .43743 Mdot
.14105 .54989 Mdot
.39409 .67252 Mdot
.33818 .67288 Mdot
.72919 .40724 Mdot
.37268 .80676 Mdot
.76937 .67089 Mdot
.67845 .29422 Mdot
.66231 .77651 Mdot
.44495 .76225 Mdot
.73868 .62066 Mdot
.4279 .60503 Mdot
.55211 .46127 Mdot
.42418 .30606 Mdot
.56963 .84819 Mdot
.26641 .67184 Mdot
.27547 .57971 Mdot
.33276 .60419 Mdot
.60635 .21932 Mdot
.30812 .3332 Mdot
.20255 .32505 Mdot
.46003 .755 Mdot
.57967 .84081 Mdot
.52369 .17665 Mdot
.38428 .33744 Mdot
.23825 .42496 Mdot
.66812 .37097 Mdot
.42484 .64623 Mdot
.25829 .68835 Mdot
.715 .41818 Mdot
.63782 .76542 Mdot
.6872 .43823 Mdot
.61297 .80096 Mdot
.54626 .60818 Mdot
.33364 .71972 Mdot
.26302 .53488 Mdot
.81173 .58261 Mdot
.22489 .35375 Mdot
.35796 .42894 Mdot
.24252 .27746 Mdot
.22513 .36611 Mdot
.16316 .56761 Mdot
.6667 .73461 Mdot
.83454 .5747 Mdot
.22405 .55557 Mdot
.21183 .4787 Mdot
.2726 .52342 Mdot
.55744 .37333 Mdot
.51595 .77896 Mdot
.72787 .41446 Mdot
.27877 .4054 Mdot
.38123 .44616 Mdot
.41562 .90385 Mdot
.55854 .61812 Mdot
.48893 .36735 Mdot
.48139 .77222 Mdot
.17988 .60701 Mdot
.60673 .35695 Mdot
.30939 .25909 Mdot
.54426 .53988 Mdot
.58003 .39847 Mdot
.60819 .28494 Mdot
.58956 .19298 Mdot
.53342 .78318 Mdot
.87243 .50302 Mdot
.41924 .20144 Mdot
.33217 .63045 Mdot
.5 .53069 Mdot
.39738 .34081 Mdot
.4719 .30305 Mdot
.49061 .72506 Mdot
.30835 .24716 Mdot
.23424 .39938 Mdot
.17115 .49417 Mdot
.85661 .47259 Mdot
.46788 .20166 Mdot
.28522 .73162 Mdot
.24799 .50997 Mdot
.48706 .3542 Mdot
.55316 .69148 Mdot
.45256 .69939 Mdot
.26826 .56927 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Gooooo`;o0000/?oo
ool001cooooo00?o0000ooooooooool0Uoooool2o`000;3ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0X_ooool2o`000:Gooooo000Looooo`03o`000?oooooo
oooo0:;ooooo0_l0002Uooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0XOooool2o`000:Kooooo
000Looooo`03o`000?oooooooooo0:7ooooo0_l0002Vooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo09Kooooo0_l0002aooooo`007?ooool00ol0003o
ooooooooo`2Fooooo`;o00007Oooool2o`0009;ooooo000Looooo`03o`000?oooooooooo07;ooooo
0_l0000hooooo`;o00001oooool4o`00093ooooo000Looooo`03o`000?oooooooooo07;ooooo0_l0
000Dooooo`;o00008_ooool2o`0000Wooooo0_l0002@ooooo`007?ooool00ol0003oooooooooo`28
ooooo`;o0000_oooool001cooooo00?o0000ooooooooool0]Oooool2o`0009;ooooo000Looooo`03
o`000?oooooooooo0;3ooooo0_l00003ooooo`;o0000T_ooool001cooooo00?o0000ooooooooool0
Ooooool2o`0002Oooooo0_l00006ooooo`;o00000oooool2o`0009;ooooo000Looooo`;o0000P?oo
ool2o`0002Oooooo0_l000000ooooooo0000o`00002Looooo`007?ooool00ol0003oooooooooo`2M
ooooo`;o00003?ooool2o`0001Oooooo0_l00023ooooo`007?ooool00ol0003oooooooooo`2Loooo
o`?o00005_ooool2o`0000gooooo0_l00023ooooo`007?ooool00ol0003oooooooooo`1hooooo`;o
00006Oooool2o`0000Oooooo0_l00006ooooo`;o00003oooool2o`0000Kooooo0_l0000>ooooo`?o
0000NOooool001cooooo00?o0000ooooooooool0N?ooool2o`0001Wooooo0_l0000?ooooo`Co0000
1?ooool2o`0000;ooooo0_l00006ooooo`;o00000oooool2o`0000Oooooo0_l00005ooooo`?o0000
NOooool001cooooo00?o0000ooooooooool0TOooool2o`000003ooooool0003o0000013ooooo0_l0
0004ooooo`;o00000_ooool2o`0000Kooooo0_l0000<ooooo`;o0000POooool001cooooo00?o0000
ooooooooool0TOooool5o`0000Cooooo0_l00002ooooo`?o00001?ooool4o`0001_ooooo0ol00022
ooooo`007?ooool00ol0003oooooooooo`2Booooo`;o00001_ooool2o`0000;ooooo0ol00004oooo
o`Co00001?ooool2o`000003ooooool0003o000001;ooooo0ol00022ooooo`007?ooool00ol0003o
ooooooooo`1Yooooo`;o00007_ooool2o`0000;ooooo0_l0000Aooooo`;o00001?ooool2o`0000Go
oooo1Ol0000<ooooo`;o0000ROooool001cooooo00?o0000ooooooooool0JOooool2o`0001_ooooo
0_l000000ooooooo0000o`000004o`0000;ooooo0_l0000=ooooo`;o00001?ooool3o`0000Gooooo
0_l000000ooooooo0000o`00000;ooooo`;o0000ROooool001cooooo00?o0000ooooooooool0O?oo
ool2o`0000Sooooo0_l00002ooooo`?o000000Coooooo`000?l0003ooooo0_l00009ooooo`;o0000
00?oooooo`000?l000001_ooool2o`0000Sooooo0_l00004ooooo`;o00000oooool4o`0008Wooooo
000Looooo`03o`000?oooooooooo07cooooo0_l0000>ooooo`Co00001_ooool2o`0000Cooooo0_l0
00000ooooooo0000o`00000Eooooo`?o00000oooool4o`0008Wooooo000Looooo`03o`000?oooooo
oooo08cooooo0ol00007ooooo`?o00001_ooool2o`0001Gooooo0_l0002Aooooo`0000Koooooonk^
k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0Sooo
ool2o`0000Kooooo0_l000000ooooooo0000o`000003ooooo`;o00006?ooool2o`000003ooooool0
003o000001;ooooo0_l0001gooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q
1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0Soooool2o`0000Wo
oooo0_l0000Mooooo`;o000000?oooooo`000?l000004_ooool2o`0007Oooooo00000ooooooo410@
ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003ooooo
ooooo`24ooooo`;o0000`oooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02ooo
ool00onHV9So8B4Qonk^kP06ooooo`?o0000JOooool2o`0000cooooo1?l00002ooooo`;o00001Ooo
ool2o`0000kooooo1Ol0000Kooooo`;o0000Toooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo06Wooooo0_l00007
ooooo`;o00000oooool4o`0000;ooooo0_l00004ooooo`?o00001_ooool2o`0000Kooooo1Ol00006
ooooo`;o00004oooool2o`0000Kooooo0ol0002:ooooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0L_ooool2o`00
00oooooo0_l00007ooooo`;o00004Oooool4o`0000Gooooo0_l0000;ooooo`;o00001Oooool3o`00
01;ooooo0_l0001fooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`1Uooooo`;o00000oooool2o`0001Kooooo0_l0
000Kooooo`Co00001Oooool2o`0000_ooooo0_l0000Hooooo`Go00001Oooool2o`0006kooooo0000
1_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03
o`000?oooooooooo06Gooooo0_l00002ooooo`?o00002Oooool2o`0000_ooooo0_l0000Kooooo`?o
00007oooool2o`0000Wooooo0_l000000ooooooo0000o`000003o`0000Gooooo0_l0001^ooooo`00
7?ooool00ol0003oooooooooo`1Sooooo`;o00001?ooool2o`0000Cooooo2?l0000Gooooo`;o0000
2?ooool2o`0000Kooooo0_l0000Oooooo`;o00002Oooool2o`0000?ooooo0_l0001fooooo`007?oo
ool00ol0003oooooooooo`1Sooooo`;o00002_ooool6o`0001Gooooo0_l00002ooooo`;o00001_oo
ool6o`000003ooooool0003o000000Co00006oooool2o`000003ooooool0003o000000Gooooo0_l0
0002ooooo`;o00000_ooool2o`000003ooooool0003o000007Cooooo000Looooo`03o`000?oooooo
oooo073ooooo0_l0000Gooooo`?o00000_ooool3o`0000Gooooo0_l00002ooooo`;o000000?ooooo
o`000?l000001?l0000Kooooo`;o000000?oooooo`000?l000001Oooool2o`0000;ooooo0_l00002
ooooo`;o000000?oooooo`000?l000000_l0001booooo`007?ooool00ol0003oooooooooo`1^oooo
o`Co00003?ooool4o`0000Gooooo1?l00003ooooo`?o00001Oooool2o`000003ooooool0003o0000
03Gooooo0_l000000ooooooo0000o`000002o`0007;ooooo000Looooo`03o`000?oooooooooo06go
oooo0ol00006ooooo`;o00001?ooool6o`0000?ooooo1_l00005ooooo`;o00001?ooool2o`000003
ooooool0003o000000Oooooo0_l0000Nooooo`;o00001Oooool2o`0000Gooooo0_l000001?oooooo
0000o`000?l00002ooooo`;o00000_ooool2o`0006_ooooo000Looooo`03o`000?oooooooooo05Oo
oooo0_l0000Dooooo`;o00001_ooool3o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l0
00002Oooool2o`0000Sooooo0_l00006ooooo`;o00007_ooool2o`0000Gooooo0_l00002ooooo`;o
00001?ooool2o`0000?ooooo0_l00002ooooo`;o0000Joooool001cooooo00?o0000ooooooooool0
Eoooool2o`0001cooooo0_l00006ooooo`;o00000oooool2o`0000Oooooo0_l0000=ooooo`;o0000
9oooool2o`0000Oooooo0ol000000ooooooo0000o`00001gooooo`007?ooool00ol0003ooooooooo
o`1looooo`?o00000oooool2o`0000Cooooo0_l000000ooooooo0000o`000005ooooo`;o00001Ooo
ool2o`0002Sooooo0_l00003ooooo`?o000000?oooooo`000?l000000_ooool2o`000003ooooool0
003o000000Gooooo0_l00006ooooo`;o0000IOooool001cooooo00?o0000ooooooooool0K_ooool2
o`0000Sooooo0_l00002ooooo`;o00001?ooool2o`0000Cooooo0_l00003ooooo`;o00000oooool2
o`0000Gooooo0_l00007ooooo`;o00009?ooool3o`0000?ooooo1?l000000ooooooo0000o`000003
ooooo`Co00001_ooool2o`0006Gooooo000Looooo`03o`000?oooooooooo05_ooooo0_l000000ooo
oooo0000o`00000<ooooo`Co00002?ooool2o`0001?ooooo1?l0000Aooooo`;o00008Oooool2o`00
00Oooooo1?l00006ooooo`;o0000Koooool001cooooo00?o0000ooooooooool0Foooool2o`000003
ooooool0003o000000Ko00001?ooool4o`0000kooooo0_l00002ooooo`;o00001Oooool2o`0000Ko
oooo0_l00009ooooo`;o00001oooool2o`0001Wooooo0_l00002ooooo`;o000000?oooooo`000?l0
00008_ooool2o`0005kooooo000Looooo`;o0000HOooool6o`0000Cooooo0_l0000@ooooo`;o0000
0_ooool2o`0000Gooooo0_l00003ooooo`;o00001_ooool2o`000003ooooool0003o000000Co0000
1_ooool2o`0001Wooooo0_l00002ooooo`;o00003_ooool2o`0001Cooooo0ol0001Nooooo`007?oo
ool00ol0003oooooooooo`1Gooooo`;o00001?ooool2o`0000Cooooo0_l0000Gooooo`;o00002?oo
ool3o`0000?ooooo0_l00006ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0002Gooooo
0_l0000>ooooo`;o00003?ooool4o`0000Cooooo0_l0000=ooooo`;o0000D?ooool001cooooo00?o
0000ooooooooool0Eoooool2o`0000?ooooo0ol00007ooooo`;o00001_ooool2o`0000;ooooo0_l0
0004ooooo`;o00001?ooool2o`0000Kooooo0_l00007ooooo`;o00004Oooool2o`0001kooooo0_l0
000<ooooo`Co00001oooool2o`0000?ooooo1?l00002ooooo`;o00003oooool2o`00053ooooo000L
ooooo`03o`000?oooooooooo05cooooo0_l00003ooooo`;o00000oooool2o`0000?ooooo0_l00000
0ooooooo0000o`000002ooooo`;o00001?ooool2o`0000?ooooo0ol0000?ooooo`;o00004Oooool2
o`0002Kooooo0_l00003ooooo`?o00002Oooool2o`0000Wooooo0_l0001Qooooo`007?ooool00ol0
003oooooooooo`1Jooooo`?o00001?ooool2o`0000Sooooo0_l0000@ooooo`;o00001?ooool2o`00
00?ooooo0_l0000cooooo`;o00002oooool2o`0000?ooooo0_l0001hooooo`007?ooool00ol0003o
ooooooooo`1Jooooo`?o00001?ooool3o`0000oooooo0_l0000>ooooo`;o00000oooool2o`0001Go
oooo0_l0000Looooo`;o00002?ooool4o`0000;ooooo0ol00006ooooo`;o0000LOooool001cooooo
00?o0000ooooooooool0FOooool2o`000003ooooool0003o000000Cooooo0_l00008ooooo`;o0000
1Oooool2o`0000Oooooo0_l00007ooooo`;o00006?ooool2o`0000Gooooo0_l0000Dooooo`;o0000
2Oooool4o`0000;ooooo0ol00006ooooo`;o00001_ooool2o`0006Wooooo000Looooo`03o`000?oo
oooooooo05Wooooo1Ol00009ooooo`;o00000oooool6o`000003ooooool0003o000000Cooooo1_l0
0006ooooo`Co00004?ooool3o`0000[ooooo0_l0000Dooooo`;o00001Oooool2o`0000_ooooo0_l0
0007ooooo`;o00000oooool3o`0000Cooooo1?l0001Pooooo`007?ooool00ol0003oooooooooo`1K
ooooo`;o00002_ooool2o`0000Gooooo1?l000000ooooooo0000o`000004ooooo`Ko00002?ooool6
o`0000;ooooo0_l00003ooooo`;o00000oooool3o`0000Wooooo0_l0000Gooooo`Co000000?ooooo
o`000?l000002oooool2o`0000Gooooo1?l00004ooooo`;o00001?ooool4o`00063ooooo000Loooo
o`03o`000?oooooooooo04_ooooo0_l00009ooooo`;o00001?ooool2o`00017ooooo0_l0000;oooo
o`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000?o00000_ooool2o`00
00?ooooo0_l0000?ooooo`;o00005oooool4o`000004ooooool0003o0000o`0000Kooooo0_l00009
ooooo`Co00002?ooool2o`0006Cooooo000Looooo`03o`000?oooooooooo04Kooooo0_l00003oooo
o`;o00002Oooool2o`0000Cooooo0_l00007ooooo`;o00004oooool2o`0000?ooooo0_l00004oooo
o`;o000000?oooooo`000?l000000_l0000gooooo`?o00001_ooool2o`0000[ooooo0ol00008oooo
o`;o0000I?ooool001cooooo00?o0000ooooooooool0A_ooool2o`0000oooooo0_l000000ooooooo
0000o`000009ooooo`;o00004oooool2o`0000Cooooo0_l00003ooooo`;o000000?oooooo`000?l0
00000_l000000ooooooo0000o`000007ooooo`;o00000oooool2o`0000Sooooo0_l0000Kooooo`;o
00005Oooool2o`00017ooooo0_l00003ooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0
Eoooool2o`000003ooooool0003o000001Sooooo0ol00003ooooo`;o00001?ooool4o`0000Cooooo
0_l00002ooooo`?o000000?oooooo`000?l000001?ooool2o`0000?ooooo0_l00008ooooo`;o0000
0_ooool2o`0001Oooooo0_l0000>ooooo`;o00001Oooool2o`0000Gooooo0_l00008ooooo`Co0000
0oooool2o`0005Kooooo000Looooo`03o`000?oooooooooo05[ooooo0_l0000Hooooo`?o00002ooo
ool2o`0000Cooooo0_l00002ooooo`;o00000_ooool2o`0001Gooooo1Ol0000Mooooo`;o00001ooo
ool2o`0000_ooooo0ol00005ooooo`;o000000?oooooo`000?l00000GOooool001cooooo00?o0000
ooooooooool0F_ooool2o`0000Wooooo0_l0000:ooooo`;o00003Oooool2o`0000Cooooo2?l0000>
ooooo`;o00002Oooool2o`000003ooooool0003o000000oooooo0_l0000<ooooo`;o00003_ooool2
o`0000Cooooo0_l00006ooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0E_ooool2o`00
00gooooo0_l0000:ooooo`;o000000?oooooo`000?l000002_ooool2o`000004ooooool0003o0000
ooooo`;o00000_ooool9o`0000Oooooo1?l00009ooooo`;o00004_ooool2o`0000cooooo0_l00000
0ooooooo0000o`000002ooooo`;o00000oooool6o`0000Cooooo0_l0000Eooooo`;o0000DOooool0
01cooooo0_l0001Gooooo`;o00003oooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool3
o`0000gooooo0_l00005ooooo`Wo00001oooool2o`0000_ooooo0_l00004ooooo`;o00004?ooool4
o`0000Wooooo0_l00002ooooo`;o00000oooool4o`0000Kooooo0_l0000>ooooo`;o00001Oooool2
o`00057ooooo000Looooo`03o`000?oooooooooo04gooooo0_l00002ooooo`Co00004_ooool2o`00
00Cooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l0000Booooo`?o000000?ooooo
o`000?l000001Oooool2o`0001;ooooo0_l000000ooooooo0000o`00000@ooooo`Go00003?ooool2
o`0000?ooooo0_l00008ooooo`;o00002Oooool2o`0000?ooooo0_l0000<ooooo`;o0000B_ooool0
01cooooo00?o0000ooooooooool0Boooool4o`000003ooooool0003o000000Co00008Oooool2o`00
00_ooooo1?l000001?oooooo0000o`000?ooool9o`000004ooooool0003o0000ooooo`;o00003ooo
ool4o`0001?ooooo0ol00005ooooo`;o00001Oooool2o`0000Sooooo0_l00003ooooo`;o00001_oo
ool2o`000003ooooool0003o0000017ooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`16
ooooo`;o00000oooool2o`0000;ooooo2Ol00006ooooo`;o00007Oooool2o`0000?ooooo4ol00004
ooooo`;o00001oooool2o`0000Kooooo1?l0000Dooooo`Co00000oooool2o`0000oooooo0_l00003
ooooo`;o00001_ooool2o`0000?ooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`16oooo
o`;o00001oooool3o`0000;ooooo1?l00003ooooo`;o000000?oooooo`000?l000006Oooool2o`00
00;ooooo0_l00003ooooo`go00000_ooool3o`0000Gooooo0_l00007ooooo`;o00001_ooool2o`00
00oooooo0_l00005ooooo`Co00004oooool2o`00017ooooo0_l0001Kooooo`007?ooool00ol0003o
ooooooooo`1;ooooo`?o000000Coooooo`000?l0003o00000_ooool2o`0000Gooooo0_l0000Loooo
o`?o00000ooooolEo`0001cooooo0_l00009ooooo`;o000000?oooooo`000?l000005?ooool2o`00
00?ooooo0_l0000;ooooo`;o0000HOooool001cooooo00?o0000ooooooooool0Boooool3o`000003
ooooool0003o000000?ooooo0_l00005ooooo`;o00003Oooool2o`0000?ooooo0_l00009ooooo`;o
000000?oooooo`000?l000005ol000000ooooooo0000o`000006ooooo`;o00003oooool2o`0000co
oooo0_l0000@ooooo`;o00000_ooool3o`0000?ooooo0_l0000:ooooo`;o00002?ooool2o`0005Oo
oooo000Looooo`03o`000?oooooooooo04;ooooo0_l00007ooooo`;o00003?ooool5o`0000;ooooo
0_l00002ooooo`;o00000_ooool4o`0000?ooooo0_l00008ooooo`;o00000_oooolIo`000003oooo
ool0003o000000Kooooo0_l0000_ooooo`;o00000oooool2o`0000?ooooo0_l00006ooooo`;o0000
2?ooool2o`0000;ooooo1?l0001Eooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00000_oo
ool3o`0000kooooo0_l00004ooooo`Go00000_ooool6o`0000;ooooo0_l0000?ooooo`;o000000?o
ooooo`000?l000007?l000000ooooooo0000o`000004ooooo`?o00002_ooool2o`0000Oooooo0_l0
000@ooooo`;o00000_ooool2o`0000;ooooo0_l0000?ooooo`;o00002?ooool2o`0000Cooooo0_l0
001Eooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00000oooool2o`0000?ooooo0_l00002
ooooo`;o00001?ooool5o`000004ooooool0003o0000ooooo`;o00001Oooool8o`0000kooooo0_l0
0002ooooo`Co000000?oooooo`000?l000003ol000000ooooooo0000o`000005o`000003ooooool0
003o000000Cooooo0ol0000:ooooo`;o00000oooool2o`0000;ooooo0_l0000=ooooo`;o000000?o
ooooo`000?l000001?l00002ooooo`;o00003?ooool2o`0000Gooooo0_l00008ooooo`?o0000E_oo
ool001cooooo00?o0000ooooooooool0@_ooool4o`0000;ooooo0_l00002ooooo`;o00001?ooool2
o`000004ooooool0003o0000ooooo`;o00002_ooool4o`0000;ooooo0_l0000<ooooo`;o00000_oo
ool4o`000003ooooool0003o000000oo000000?oooooo`000?l000001Ol00003ooooo`;o00002ooo
ool2o`0000Oooooo0_l00002ooooo`;o00001oooool2o`0000Cooooo0_l00003ooooo`;o00004_oo
ool2o`0000Gooooo0_l000000ooooooo0000o`000004ooooo`Co0000E_ooool001cooooo00?o0000
ooooooooool0@_ooool4o`0001[ooooo0_l00008ooooo`;o00004?ooool5o`000003ooooool0003o
000000_o000000?oooooo`000?l000002?l00003ooooo`;o00002Oooool4o`0000_ooooo0_l00007
ooooo`;o00000_ooool2o`0000Cooooo1?l00002ooooo`;o00005?ooool2o`000003ooooool0003o
000000So0000E_ooool001cooooo00?o0000ooooooooool0Boooool2o`0000?ooooo0_l00008oooo
o`;o00001?ooool2o`0000Oooooo0ol0000=ooooo`?o00000_oooolKo`0000oooooo0_l0000<oooo
o`?o00001_ooool2o`0000?ooooo0_l00002ooooo`Ko00000_ooool2o`0000[ooooo0_l00003oooo
o`;o00000oooool2o`0000?ooooo1?l000001?oooooo0000o`000?l0000>ooooo`;o0000A_ooool0
01cooooo00?o0000ooooooooool0Boooool2o`0000?ooooo0_l00003ooooo`Co000000?oooooo`00
0?l000003Oooool3o`0000Wooooo0_l00002ooooo`Ko000000?oooooo`000?l000002ol000000ooo
oooo0000o`00000;o`0000oooooo0_l0000:ooooo`?o00001_ooool2o`0000Oooooo0_l00009oooo
o`;o00001oooool2o`0000?ooooo0_l0000=ooooo`;o000000?oooooo`000?l000003?ooool2o`00
00Cooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`11ooooo`;o00001oooool2o`0000Go
oooo0_l000000ooooooo0000o`000003o`0000kooooo0_l0000<ooooo`;o00000oooool:o`000003
ooooool0003o000001Ko000000?oooooo`000?l000000oooool2o`0000Gooooo0_l0000Booooo`;o
00004oooool2o`000003ooooool0003o000000kooooo1_l00003ooooo`;o00000_ooool2o`0001;o
oooo0_l00010ooooo`007?ooool00ol0003oooooooooo`11ooooo`;o000000?oooooo`000?l00000
1?ooool2o`0000Gooooo0_l000000ooooooo0000o`000007ooooo`;o00000oooool2o`0000?ooooo
0_l0000<ooooo`;o00001?oooolUo`0000?ooooo1?l0000Booooo`;o00000oooool2o`0000?ooooo
0_l0000Aooooo`;o00003_ooool6o`000003ooooool0003o000000;o000000?oooooo`000?l00000
EOooool001cooooo0_l00015ooooo`;o00001Oooool2o`0000?ooooo0_l00002ooooo`;o00001ooo
ool2o`0000?ooooo0_l00003ooooo`;o00001oooool2o`0000Sooooo7ol000000ooooooo0000o`00
0002o`0000Oooooo0_l0000Booooo`;o00002?ooool2o`0002Sooooo0_l00002ooooo`?o0000EOoo
ool001cooooo00?o0000ooooooooool0@Oooool2o`0000;ooooo1?l00002ooooo`;o00000oooool2
o`0000;ooooo1Ol00009ooooo`;o00002Oooool2o`000003ooooool0003o000000Sooooo7ol00000
0ooooooo0000o`000002o`0001_ooooo0_l0000Qooooo`;o00004oooool2o`0005Kooooo000Loooo
o`03o`000?oooooooooo047ooooo0_l00002ooooo`Co00002Oooool7o`0000Wooooo0_l00009oooo
o`;o000000Coooooo`000?l0003o00002_ooool8o`000003ooooool0003o000000Co000000?ooooo
o`000?l000000ol000000ooooooo0000o`000009o`0000;ooooo0_l00004ooooo`;o00002Oooool2
o`0000Gooooo0_l00007ooooo`;o00006Oooool2o`0006_ooooo000Looooo`03o`000?oooooooooo
043ooooo0_l0000?ooooo`Go00001?ooool2o`0000[ooooo1?l00006ooooo`?o00002_oooolOo`00
00Cooooo0_l00003ooooo`?o00002Oooool2o`0000?ooooo1?l00007ooooo`;o00002Oooool2o`00
00;ooooo0_l00008ooooo`;o00002Oooool2o`0001Gooooo0_l0001;ooooo`007?ooool00ol0003o
ooooooooo`0iooooo`;o00001?ooool3o`0000oooooo0_l00004ooooo`;o000000?oooooo`000?l0
00002?ooool6o`0001;ooooo7?l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00003oooo
o`Co00003Oooool3o`0000;ooooo0_l000000ooooooo0000o`00000<ooooo`;o00000_ooool2o`00
00?ooooo1ol00002ooooo`;o00000_ooool2o`000003ooooool0003o000000_ooooo0_l00006oooo
o`Co0000Boooool001cooooo00?o0000ooooooooool0>Oooool2o`0000;ooooo1?l00004ooooo`;o
00002oooool2o`0000?ooooo0_l00002ooooo`?o00001_ooool3o`0001Gooooo7?l000001?oooooo
0000o`000?ooool2o`0000;ooooo0_l00004ooooo`?o00004_ooool2o`000003ooooool0003o0000
00Sooooo0_l0000;ooooo`Ko00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000003oooo
o`;o00001Oooool5o`0000Cooooo1?l0001;ooooo`007?ooool00ol0003oooooooooo`0mooooo`;o
00001_ooool2o`0000Sooooo0_l000000ooooooo0000o`000004ooooo`;o000000Goooooo`000?l0
003o0000ooooo`02o`0000Cooooo0_l0000<ooooo`;o00002OoooolJo`000003ooooool0003o0000
00;o00001Oooool3o`000003ooooool0003o000000;o00007_ooool2o`0000Wooooo0_l000000ooo
oooo0000o`000005ooooo`;o00002oooool2o`0000Gooooo1ol0001Aooooo`007?ooool00ol0003o
ooooooooo`1=ooooo`Co00001_ooool3o`0000Gooooo0_l00006ooooo`;o00001oooool2o`000003
ooooool0003o000000Wooooo6?l00002ooooo`Go00001Oooool3o`0000?ooooo0ol0000Fooooo`;o
00000oooool4o`0000?ooooo0ol00003ooooo`Oo00000oooool2o`0000Oooooo0_l0000>ooooo`;o
00003_ooool2o`00047ooooo000Looooo`03o`000?oooooooooo03gooooo0_l00006ooooo`;o0000
1_ooool2o`0000;ooooo0_l00004ooooo`;o00001_ooool2o`0000Kooooo0_l00007ooooo`Co0000
2?oooolPo`0000gooooo0_l00006ooooo`?o00003Oooool9o`0000?ooooo0ol00004ooooo`Ko0000
3?ooool3o`0001?ooooo0_l00008ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0?Ooo
ool2o`0000Kooooo0_l0000:ooooo`Co00002_ooool5o`0000kooooo0_l00006ooooob3o00001ooo
ool2o`0000kooooo0ol0000=ooooo`Go00001_ooool4o`0000Cooooo0_l00003ooooo`;o00003?oo
ool2o`0001?ooooo0ol0001:ooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00004_ooool2
o`0000[ooooo1Ol0000Eoooooaco000000?oooooo`000?l000000_l00007ooooo`;o00001oooool2
o`0001Cooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000Oo000000?ooooo
o`000?l000000_l00002ooooo`;o00001Oooool2o`0000Gooooo0ol0000?ooooo`;o00000_ooool2
o`0004[ooooo000Looooo`03o`000?oooooooooo03cooooo1Ol0000:ooooo`;o00007oooool2o`00
00_ooooo0_l00005oooooaGo00002_ooool2o`0000Wooooo0_l0000Aooooo`;o000000Coooooo`00
0?l0003ooooo2_l00003ooooo`_o00000_ooool2o`000003ooooool0003o000000Kooooo0_l0000?
ooooo`;o00001?ooool2o`0004Sooooo000Looooo`03o`000?oooooooooo03cooooo1?l0000;oooo
o`;o00007oooool2o`0000Oooooo0_l00006ooooo`;o000000Coooooo`000?l0003ooooo2Ol00000
0ooooooo0000o`000006o`000003ooooool0003o000000Oooooo0_l0000Cooooo`;o00001_ooool5
o`0000Cooooo1Ol00003ooooo`co00000oooool3o`000004ooooool0003o0000ooooo`;o00004_oo
ool2o`0000Kooooo0_l00008ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0AOooool2
o`0000_ooooo0_l0000Qooooo`;o00001_ooool2o`0000?ooooo1_l000000ooooooo0000o`000006
o`0000Gooooo0ol0000Booooo`;o00001oooool2o`000004ooooool0003o0000ooooo`Co000000?o
ooooo`000?l000001_ooool2o`0000;ooooo3_l000000ooooooo0000o`000002o`0000;ooooo1Ol0
000@ooooo`Co00004?ooool2o`0003kooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo
0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`15ooooo`;o0000
00?oooooo`000?l000000_ooool2o`0000Cooooo0_l0000^ooooo`oo00001_ooool2o`0001;ooooo
0_l00005ooooo`;o00000oooool5o`0000?ooooo1Ol000000ooooooo0000o`000006o`000003oooo
ool0003o000000;o000000Coooooo`000?l0003ooooo0ol000000ooooooo0000o`000003o`0000?o
oooo0_l0000=ooooo`;o00000_ooool2o`0001Kooooo0_l0000jooooo`0000KoooooogMgMonHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
04Sooooo0_l00002ooooo`;o00001oooool2o`000003ooooool0003o000000gooooo0_l0000Joooo
o`?o000000?oooooo`000?l000001_l0000<ooooo`;o00005Oooool2o`0000Cooooo1?l000000ooo
oooo0000o`000009o`000003ooooool0003o000000[o000000Coooooo`000?l0003o00000_ooool5
o`0000;ooooo0_l00005ooooo`;o00001?ooool4o`0000?ooooo0_l0000Eooooo`;o0000>_ooool0
0003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo00?o0000oooo
ooooool0?_ooool2o`0000Sooooo0_l00007ooooo`;o000000Goooooo`000?l0003o0000ooooo`02
o`0000cooooo0ol00005ooooo`;o00000oooool2o`0000gooooo0_l00005ooooo`?o000000?ooooo
o`000?l000000_l00002ooooo`?o00001Oooool2o`000003ooooool0003o000000gooooo0_l0000:
ooooo`;o00000_ooool5o`000003ooooool0003o000000oo000000?oooooo`000?l000000_ooool4
o`000003ooooool0003o000000;o00001oooool2o`0000Cooooo0_l00003ooooo`Ko00003Oooool2
o`00043ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgM
gOoooooo00001oooool3o`0003Sooooo0_l00004ooooo`;o00002?ooool3o`0000Kooooo1Ol0000@
ooooo`;o00001_ooool2o`0000?ooooo0_l00002ooooo`;o00002Oooool2o`000003ooooool0003o
000000;ooooo0ol00002ooooo`?o00000_ooool3o`0000;ooooo0_l000001?oooooo0000o`000?oo
ool2o`0000Cooooo0_l00007ooooo`;o00000oooool3o`000004ooooool0003o0000ooooo`Go0000
00?oooooo`000?l000002ol000000ooooooo0000o`000008o`0000;ooooo1?l00002ooooo`?o0000
0_ooool2o`0000kooooo0ol000000ooooooo0000o`00000=ooooo`;o0000@?ooool00003ooooool0
003ooooo00;ooooo00?o0000ooooooooool02Oooool01?oMgMgoEEEEooooool00007ooooo`03o`00
0?oooooooooo03Sooooo0_l0000?ooooo`;o00001oooool3o`0000;ooooo0_l0000:ooooo`;o0000
00?oooooo`000?l000003?ooool2o`000004ooooool0003o0000ooooo`;o00001_ooool2o`000003
ooooool0003o000000?ooooo1_l00008ooooo`;o00002?ooool4o`000003ooooool0003o000000Wo
oooo0ol000001?oooooo0000o`000?ooool5o`0000;ooooo5ol000000ooooooo0000o`000002oooo
o`Ko00000_ooool2o`0000?ooooo0_l00004ooooo`;o00001?ooool2o`000003ooooool0003o0000
00Oooooo0_l00016ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03
ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0>_ooool2o`0000Sooooo0_l00002ooooo`;o
00001_ooool5o`0000;ooooo0ol00009ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Go
oooo0_l00004ooooo`;o00002?ooool4o`0000;ooooo1?l00005ooooo`;o00002?ooool2o`0000?o
oooo0_l00003ooooo`;o00000oooool2o`0000Gooooo0ol00003ooooo`Ko000000?oooooo`000?l0
00008?l000001?oooooo0000o`000?ooool6o`0000?ooooo0_l00003ooooo`;o00002oooool2o`00
04Kooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l000001oooool0
0ol0003oooooooooo`0`ooooo`;o00001?ooool2o`0000;ooooo1?l00006ooooo`;o00000_ooool2
o`0000Kooooo0ol00002ooooo`;o000000?oooooo`000?l000004oooool3o`0001Cooooo1?l00004
ooooo`;o000000?oooooo`000?l000001_l000001?oooooo0000o`000?ooool4o`0000;ooooo0_l0
0009ooooo`;o00001Oooool6o`0000?ooooo7Ol000001?oooooo0000o`000?ooool3o`0000?ooooo
0_l000000ooooooo0000o`000004o`0000Sooooo0_l00008ooooo`;o0000BOooool00006ooooooo^
k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo033o
oooo0_l00004ooooo`;o00001?ooool2o`0000Kooooo0_l00008ooooo`;o000000?oooooo`000?l0
00000_ooool2o`0001Oooooo0_l00002ooooo`;o00001oooool2o`0000Gooooo0_l00002ooooo`;o
00001?ooool2o`000003ooooool0003o000000;o00000_ooool2o`000004ooooool0003o0000oooo
o`;o00001?ooool2o`0000Wooooo0_l00005ooooo`Oo000000?oooooo`000?l000003Ol000000ooo
oooo0000o`00000Bo`0000[ooooo0_l00004ooooo`;o00003Oooool2o`0004Wooooo000Looooo`03
o`000?oooooooooo03Kooooo0_l0000>ooooo`;o00001?ooool5o`0001kooooo1Ol00004ooooo`;o
000000?oooooo`000?l000000oooool4o`0001Oooooo0ol00003ooooo`;o00000_ooool2o`0000Wo
oooo0_l000000ooooooo0000o`00000Zo`0000Gooooo1?l000000ooooooo0000o`000004ooooo`;o
00006Oooool3o`0003cooooo000Looooo`03o`000?oooooooooo03Cooooo1?l0000;ooooo`;o0000
00?oooooo`000?l000001?ooool2o`000003ooooool0003o000001_ooooo2Ol000000ooooooo0000
o`000003o`0000Gooooo0_l00007ooooo`;o00003Oooool2o`0000;ooooo0_l00003ooooo`;o0000
0_ooool2o`0000Wooooo2Ol000000ooooooo0000o`00000Lo`0000;ooooo1Ol00005ooooo`Go0000
3_ooool2o`00017ooooo0ol0000looooo`007?ooool00ol0003oooooooooo`0dooooo`Co00001_oo
ool2o`0000?ooooo0_l0000Qooooo`;o00001?ooool3o`0000Cooooo0_l000001?oooooo0000o`00
0?ooool2o`0000Gooooo0_l00005ooooo`Co00003?ooool3o`0000Cooooo0_l0000>ooooo`;o0000
00Coooooo`000?l0003o00000_ooool2o`0000;ooooo9Ol00002ooooo`Co00000_ooool2o`0000ko
oooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`0jooooo`;o00000_ooool2o`0000Cooooo
0_l00004ooooo`;o00003oooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`Co0000
0_ooool2o`0001;ooooo0_l00005ooooo`;o00000_ooool2o`0000[ooooo0_l00003ooooo`Co0000
3_ooool2o`000004ooooool0003o0000o`0000;ooooo0ol000000ooooooo0000o`00000So`0000;o
oooo1?l00002ooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0=?ooool2o`0000Cooooo
0_l00008ooooo`;o00001?ooool2o`0000Kooooo0_l00007ooooo`[o000000?oooooo`000?l00000
0_l00007ooooo`;o00001oooool2o`0000Cooooo0_l00009ooooo`;o00003oooool2o`0001?ooooo
0ol000000ooooooo0000o`00000Uo`000003ooooool0003o000000Cooooo0_l0000Eooooo`Co0000
2_ooool2o`0003oooooo000Looooo`03o`000?oooooooooo03Cooooo0_l00002ooooo`;o00003?oo
ool2o`0000Oooooo0_l000000ooooooo0000o`000003ooooo`;o00000oooool2o`000003ooooool0
003o000000Co00000oooool2o`0000Oooooo0_l00007ooooo`?o00000oooool2o`0002Sooooo0_l0
0006ooooo`Go000000?oooooo`000?l000008_l000001?oooooo0000o`000?l0000Jooooo`[o0000
1?ooool2o`0003oooooo000Looooo`03o`000?oooooooooo03?ooooo0_l00002ooooo`?o00003?oo
ool2o`0000;ooooo0_l000000ooooooo0000o`000004o`0000Cooooo0ol00006ooooo`;o00003?oo
ool2o`0000_ooooo0_l00009ooooo`Co00004oooool3o`0000[ooooo0_l00006ooooo`Co00000ooo
ool:o`000003ooooool0003o000001co00000oooool3o`0000?ooooo0_l0000Aooooo`Ko0000AOoo
ool001cooooo00?o0000ooooooooool0<oooool2o`0000;ooooo0_l0000Aooooo`;o000000?ooooo
o`000?l000000_ooool2o`000004ooooool0003o0000ooooo`?o00004Oooool2o`000003ooooool0
003o000000;ooooo0_l0000<ooooo`;o00001?ooool4o`0001?ooooo0ol0000:ooooo`;o00000_oo
ool2o`0000;ooooo1?l00003oooooaGo00000_ooool>o`000003ooooool0003o000000;o00000_oo
ool3o`0000?ooooo0_l00003ooooo`;o0000Eoooool001cooooo00?o0000ooooooooool0=oooool2
o`000003ooooool0003o000000_ooooo0_l00008ooooo`;o000000?oooooo`000?l000003_ooool2
o`0000Gooooo0_l00005ooooo`;o00002oooool3o`0000Cooooo0_l00003ooooo`;o00001_ooool2
o`0000Sooooo0_l0000?ooooo`;o00001?ooool4o`0000;ooooo:Ol0000<ooooo`?o00000_ooool2
o`0000Wooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o00002Oooool3o`00
0003ooooool0003o000000_ooooo0_l000000ooooooo0000o`000003ooooo`;o00004oooool2o`00
00cooooo0_l000001?oooooo0000o`000?ooool2o`0000Gooooo0_l00005ooooo`;o00000oooool2
o`0000Kooooo0_l00003ooooo`;o00000oooool2o`0001;ooooo1ol00002ooooobKo00003?ooool2
o`000003ooooool0003o000000?ooooo0_l00009ooooo`;o00003?ooool2o`0003[ooooo000Loooo
o`03o`000?oooooooooo02_ooooo0_l00009ooooo`;o000000?oooooo`000?l000002oooool2o`00
00;ooooo0_l00003ooooo`;o00000oooool2o`0000Oooooo0_l0000Aooooo`Oo000000?oooooo`00
0?l000001?ooool2o`0000_ooooo0_l0000;ooooo`;o000000?oooooo`000?l000000_l000000ooo
oooo0000o`000008ooooo`;o00001?ooooldo`0000Sooooo0_l00002ooooo`;o00004_ooool2o`00
00Oooooo0_l0000jooooo`007?ooool2o`0003;ooooo0_l00006ooooo`;o00002oooool2o`000005
ooooool0003o0000o`000?ooool00_l000000ooooooo0000o`000002ooooo`;o00000_ooool2o`00
00?ooooo0_l00008ooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o0000
00?o00001_ooool2o`0000_ooooo0_l0000>ooooo`Co000000?oooooo`000?l000002?ooool2o`00
00Cooooo0_l000000ooooooo0000o`00000Ko`000003ooooool0003o000000Wo00000oooool5o`00
00;ooooo0_l00008ooooo`;o00004_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000loooo
o`007?ooool00ol0003oooooooooo`0aooooo`;o000000?oooooo`000?l000004?ooool2o`000003
ooooool0003o000000Co000000?oooooo`000?l000001_ooool2o`0000Cooooo0_l00007ooooo`;o
000000?oooooo`000?l000003?l00002ooooo`Co00003Oooool2o`0000cooooo0_l000000ooooooo
0000o`00000@ooooo`;o00000oooool<o`0000;ooooo3ol000000ooooooo0000o`00000@o`0000;o
oooo0ol0000;ooooo`;o00002?ooool2o`0000Sooooo0ol000000ooooooo0000o`00000looooo`00
7?ooool00ol0003oooooooooo`0_ooooo`;o00000oooool2o`0000Wooooo0_l000000ooooooo0000
o`000008ooooo`?o00003oooool2o`0000cooooo3?l000000ooooooo0000o`000003o`0001_ooooo
0_l000000ooooooo0000o`00000=ooooo`;o000000?oooooo`000?l000000_l00006ooooo`Oo0000
0_oooolQo`0000?ooooo0_l0000<ooooo`;o00001oooool3o`000003ooooool0003o000000Gooooo
0_l00010ooooo`007?ooool00ol0003oooooooooo`0_ooooo`?o00000_ooool2o`0000Wooooo0_l0
00000ooooooo0000o`00000Jooooo`;o00003?ooool?o`0001Kooooo0_l0000<ooooo`Co00002?oo
ool2o`000003ooooool0003o000000Co00001?ooool[o`0000gooooo0_l0000:ooooo`?o000000?o
ooooo`000?l00000Aoooool001cooooo00?o0000ooooooooool0<?ooool2o`0002cooooo0_l0000<
ooooo`Co000000?oooooo`000?l000002_l0000Dooooo`;o00001oooool2o`0000?ooooo1?l0000;
ooooo`Oo00001?oooolZo`0000_ooooo1?l0001Gooooo`007?ooool00ol0003oooooooooo`0Uoooo
o`;o00002_ooool2o`0002Kooooo0_l0000:ooooo`;o00001?oooolBo`0001_ooooo1?l0000Boooo
o`;o00000oooool5o`0000;ooooo:?l0000<ooooo`;o00000_ooool2o`000003ooooool0003o0000
05;ooooo000Looooo`03o`000?oooooooooo02Gooooo0_l00006ooooo`Ko00002_ooool2o`0000Co
oooo0ol0000<ooooo`;o00000oooool4o`0000[ooooo0_l00002oooooaCo00003_ooool2o`0000Oo
oooo0_l00002ooooo`Co00000oooool2o`0001Cooooo0ol000000ooooooo0000o`00000Ro`000003
ooooool0003o000000;o00001?ooool3o`0000Wooooo1Ol0000Cooooo`;o0000?Oooool001cooooo
00?o0000ooooooooool0;Oooool4o`0000_ooooo0ol00004ooooo`?o000000?oooooo`000?l00000
2Oooool2o`0000?ooooo0_l0000@oooooaKo00003?ooool2o`0000Oooooo0ol00003ooooo`;o0000
0oooool3o`0000;ooooo0_l00003ooooo`;o00001_ooool2o`0000;ooooo;?l00005ooooo`?o0000
1?ooool2o`0000Gooooo0_l000000ooooooo0000o`00000:ooooo`Co00000oooool2o`0000Kooooo
0_l0000eooooo`007?ooool00ol0003oooooooooo`0looooo`;o000000?oooooo`000?l000001_oo
ool2o`000004ooooool0003o0000o`0000oooooo0ol0000:oooooaKo00000_ooool2o`0000Sooooo
0_l00007ooooo`?o00002?ooool3o`0000;ooooo0_l00003ooooo`;o00001_ooool`o`0000?ooooo
0_l00002ooooo`Oo000000Coooooo`000?l0003o00001?ooool2o`0000[ooooo1?l0000;ooooo`;o
0000=Oooool001cooooo00?o0000ooooooooool0;_ooool2o`0000oooooo1?l00007ooooo`Co0000
1Oooool2o`0000Oooooo0ol00007ooooo`;o000000?oooooo`000?l000004_l00004ooooo`;o0000
1?ooool2o`0000Cooooo0_l00005ooooo`;o00002Oooool4o`0000oooooo7_l00002ooooo`Oo0000
00?oooooo`000?l000000_ooool2o`0000Cooooo0_l00002ooooo`Ko00000_ooool3o`00013ooooo
0ol00013ooooo`007?ooool00ol0003oooooooooo`0^ooooo`?o000000?oooooo`000?l000003?oo
ool3o`0000Wooooo0_l00005ooooo`?o000000?oooooo`000?l000000oooool2o`000003ooooool0
003o000000Gooooo0_l000000ooooooo0000o`00000Co`0000Cooooo1?l000001?oooooo0000o`00
0?ooool2o`000003ooooool0003o000001;ooooo0_l00006ooooo`;o00001?ooool5o`000003oooo
ool0003o0000023o00001_ooool2o`0000cooooo0_l00003ooooo`;o00004Oooool2o`0000kooooo
0ol0000cooooo`007?ooool00ol0003oooooooooo`0^ooooo`Ko00004oooool2o`0000;ooooo0_l0
0006ooooo`?o000000?oooooo`000?l000000oooool2o`000003ooooool0003o000000Gooooo0_l0
00000ooooooo0000o`00000Do`0000;ooooo1Ol000001?oooooo0000o`000?ooool2o`0001Cooooo
0ol00006ooooo`;o00001?ooool3o`0000Gooooo7_l000000ooooooo0000o`000003o`0000;ooooo
0_l00002ooooo`;o00001oooool3o`0000?ooooo0_l0000?ooooo`Co00001?ooool2o`0000Sooooo
0ol0000cooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00003Oooool2o`0000Gooooo0_l0
0002ooooo`;o00004Oooool2o`0000Oooooo6?l00002ooooo`;o00001?ooool2o`0001Oooooo1?l0
000>ooooo`;o00000ooooolTo`0000;ooooo0ol000000ooooooo0000o`000007ooooo`;o00005Ooo
ool3o`0000Gooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0dooooo`;o00002_ooool2
o`0001cooooo0_l00004ooooo`;o000000?oooooo`000?l000001?l000000ooooooo0000o`000002
o`000003ooooool0003o000000So00002_ooool2o`0000Kooooo0_l0000?ooooo`Co00002oooool2
o`000003ooooool0003o000000Kooooo0_l00002oooooago00000_ooool3o`0000?ooooo0_l00000
0ooooooo0000o`00001Qooooo`007?ooool00ol0003oooooooooo`0dooooo`;o00002?ooool2o`00
00Cooooo0_l0000Nooooo`;o000000?oooooo`000?l000005?l00007ooooo`Co00001oooool2o`00
00?ooooo0_l0000:ooooo`Co00002oooool2o`0000?ooooo1Ol00004ooooo`;o000000?oooooo`00
0?l000003?l000000ooooooo0000o`000005o`000003ooooool0003o000000;o00000_ooool2o`00
00Cooooo0_l000000ooooooo0000o`000009ooooo`;o0000E_ooool001cooooo00?o0000oooooooo
ool0;_ooool2o`0000Cooooo0_l00006ooooo`Co00000_ooool4o`0000;ooooo0_l0000>ooooo`;o
00000oooool2o`0000Sooooo5_l00007ooooo`Co00003?ooool2o`0000[ooooo1Ol0000?ooooo`Go
00000ooooolBo`0000?ooooo0_l000000ooooooo0000o`000002o`000004ooooool0003o0000o`00
00Gooooo0_l00009ooooo`;o00000oooool2o`0001Cooooo0_l00010ooooo`007?ooool2o`0002[o
oooo1?l000000ooooooo0000o`00000<ooooo`;o00001?ooool2o`0000;ooooo1?l0000>ooooo`;o
00000oooool3o`0000Oooooo6?l0000?ooooo`;o00000_ooool2o`0000cooooo0_l000000ooooooo
0000o`000003ooooo`;o00002?ooool2o`0000?ooooo0ol00002ooooo`;o000000?oooooo`000?l0
00002Ol000000ooooooo0000o`000002o`0000;ooooo1ol000001?oooooo0000o`000?l00005oooo
o`;o00000_ooool2o`0000?ooooo1?l0000Iooooo`;o0000@?ooool001cooooo00?o0000oooooooo
ool0:Oooool4o`0000;ooooo0_l00003ooooo`;o00001_ooool2o`0000Sooooo0_l00002ooooo`;o
00004_ooool2o`0000Kooooo6Ol00007ooooo`;o00001_ooool2o`0000;ooooo0_l0000<ooooo`?o
00001Oooool2o`0000Sooooo0_l000000ooooooo0000o`000007o`000003ooooool0003o000000?o
oooo1Ol00003ooooo`?o000000?oooooo`000?l000001Ol00007ooooo`;o00001Oooool2o`000003
ooooool0003o000000;o00005Oooool2o`0001Gooooo0_l0000_ooooo`007?ooool00ol0003ooooo
ooooo`0Wooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o00001?ooool2o`0000Cooooo
0_l00004ooooo`;o00000_ooool2o`0000gooooo0_l0000:oooooaWo00002?ooool2o`0001Gooooo
0_l00002ooooo`;o00003?ooool2o`0000Cooooo0_l00003ooooo`;o00000oooool4o`0000;ooooo
1_l00005ooooo`?o000000Coooooo`000?l0003ooooo1?l00003ooooo`Co00001_ooool2o`0001Oo
oooo0_l00002ooooo`;o00000_ooool2o`0000gooooo0_l0000_ooooo`007?ooool00ol0003ooooo
ooooo`0Wooooo`;o00000_ooool3o`0000cooooo0ol00003ooooo`;o00000_ooool4o`0000Gooooo
0_l000000ooooooo0000o`000002o`0000Gooooo0_l000000ooooooo0000o`000007ooooo`;o0000
00?oooooo`000?l000005?l000000ooooooo0000o`000006ooooo`Co00004_ooool2o`0000;ooooo
0_l0000;ooooo`?o00001?ooool2o`0000[ooooo0_l00003ooooo`Go00001_ooool5o`000003oooo
ool0003o000000Co00000_ooool3o`0000oooooo0_l0000Booooo`Ko0000?_ooool001cooooo00?o
0000ooooooooool0:?ooool2o`0000;ooooo0_l0000=ooooo`;o00001oooool2o`0000Oooooo0_l0
00000ooooooo0000o`000002o`0000Cooooo0ol000001?oooooo0000o`000?l00004ooooo`;o0000
0ooooolIo`0000;ooooo0_l00002ooooo`Co00006Oooool2o`000003ooooool0003o000000Gooooo
1?l000000ooooooo0000o`000002o`0000gooooo0_l00003ooooo`;o00000oooool2o`0000;ooooo
1ol00002ooooo`;o00000_ooool2o`0000Gooooo0_l00002ooooo`;o00001Oooool2o`0000Wooooo
0_l00006ooooo`Go000000?oooooo`000?l00000?Oooool001cooooo00?o0000ooooooooool09ooo
ool3o`0002Kooooo0_l00002ooooo`;o00000_ooool3o`0000;ooooo1Ol000000ooooooo0000o`00
0002oooooaKo000000?oooooo`000?l000000oooool2o`0000Cooooo0_l00008ooooo`;o00001Ooo
ool2o`0000?ooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000Kooooo0ol0
00000ooooooo0000o`000006ooooo`;o00001Oooool4o`0000?ooooo0_l00003ooooo`?o00001?oo
ool5o`0000?ooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo1?l00008ooooo`;o0000
1Oooool2o`0000Kooooo0_l00004ooooo`;o00001oooool2o`0003Cooooo000Looooo`03o`000?oo
oooooooo02Oooooo0_l0000Aooooo`;o00004_ooool4o`000004ooooool0003o0000o`0000?ooooo
0_l00004ooooo`?o00001Oooool7o`000003ooooool0003o000000co00000oooool4o`0000Gooooo
0_l00008ooooo`;o00001Oooool2o`0000?ooooo0_l000000ooooooo0000o`000007ooooo`;o0000
0_ooool2o`0000Cooooo0_l00003ooooo`Go00000oooool2o`0000Oooooo0_l00002ooooo`?o0000
1_ooool2o`0000?ooooo0_l00004ooooo`;o00001?ooool4o`0000Sooooo0_l0000Looooo`;o0000
=?ooool001cooooo00?o0000ooooooooool09_ooool2o`0001;ooooo0_l00009ooooo`;o00001ooo
ool4o`000003ooooool0003o000000;o00000_ooool2o`0000Gooooo0_l00005oooooaSo000000?o
ooooo`000?l000000_l00002ooooo`;o00003Oooool2o`0000Cooooo0_l0000>ooooo`;o00000_oo
ool2o`0000Cooooo0_l00003ooooo`Go00002?ooool2o`0000;ooooo1?l000001?oooooo0000o`00
0?l00006ooooo`;o00001oooool2o`0000Sooooo0_l00003ooooo`;o00000_ooool2o`0005;ooooo
000Looooo`03o`000?oooooooooo02Kooooo0_l000000ooooooo0000o`00000Jooooo`;o00002Ooo
ool7o`0000;ooooo0_l0000<oooooaSo00000_ooool3o`0000;ooooo0_l00006ooooo`;o00000ooo
ool4o`0000Cooooo0_l00002ooooo`;o00000oooool4o`0000Oooooo0_l00009ooooo`;o00002ooo
ool4o`0000;ooooo0_l00002ooooo`;o00001_ooool4o`0000Cooooo0ol00002ooooo`;o00000_oo
ool4o`0000?ooooo0ol000000ooooooo0000o`00001Booooo`007?ooool00ol0003oooooooooo`0U
ooooo`;o00000_ooool2o`0000?ooooo0_l0000Booooo`;o00003?ooool7o`0000;ooooo0ol0000<
ooooo`Wo000000?oooooo`000?l000002ol00002ooooo`?o00001oooool2o`000003ooooool0003o
000000?ooooo0_l000001?oooooo0000o`000?l00006ooooo`?o00000_ooool5o`00017ooooo0_l0
0006ooooo`Co00000oooool2o`0000;ooooo0_l0000<ooooo`Co00000_ooool2o`0000?ooooo0_l0
0002ooooo`;o00001Oooool3o`000003ooooool0003o000005;ooooo000Looooo`03o`000?oooooo
oooo02Gooooo0_l00007ooooo`;o00004_ooool2o`00013ooooo0ol00003ooooo`;o00003_oooolC
o`0000kooooo0_l00009ooooo`Co00001Oooool3o`0000;ooooo0_l000000ooooooo0000o`000003
ooooo`;o00005?ooool4o`0000Oooooo0ol00009ooooo`;o00000_ooool2o`0000Oooooo1?l00007
ooooo`;o00000_ooool2o`0000oooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0`oooo
o`;o00006_ooool3o`0000?ooooo0_l0000;ooooo`?o00002Oooool<o`0000;ooooo0ol00008oooo
o`;o00004_ooool2o`0000Gooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo0_l0000:oooo
o`;o00002?ooool2o`0000[ooooo0_l000000ooooooo0000o`000006ooooo`Co00002Oooool4o`00
01cooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0_ooooo`Co00002Oooool2o`0000ko
oooo0ol000000ooooooo0000o`000002o`0000[ooooo1?l00009ooooo`_o00000oooool2o`0000Wo
oooo0_l0000Rooooo`?o00000_ooool4o`0000Oooooo0_l00008ooooo`;o000000?oooooo`000?l0
00000oooool2o`0000Gooooo0_l00003ooooo`Oo00002oooool2o`0000Gooooo0_l0000Eooooo`;o
00003_ooool2o`0000Oooooo0_l0000Xooooo`007?ooool00ol0003oooooooooo`0_ooooo`Go0000
00?oooooo`000?l000001?ooool3o`000003ooooool0003o000000Sooooo0_l00005ooooo`;o0000
3?ooool2o`0000Kooooo0_l00004ooooo`?o000000?oooooo`000?l000000ol000001?oooooo0000
o`000?ooool3o`0001Cooooo0_l00003ooooo`;o00001oooool2o`0000Wooooo0_l00002ooooo`Co
00001Oooool2o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l000000oooool2o`0000Wo
oooo1Ol0000Eooooo`;o00005Oooool2o`0000kooooo0_l00007ooooo`;o0000:?ooool001cooooo
00?o0000ooooooooool09?ooool3o`0000_ooooo0_l000000ooooooo0000o`000003o`000003oooo
ool0003o000000;ooooo0_l00008ooooo`;o00006Oooool6o`0000?ooooo0_l000000ooooooo0000
o`00000:o`0000_ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l000001?oooooo0000
o`000?l00007ooooo`;o00002_ooool5o`0000Oooooo1?l000001?oooooo0000o`000?l00002oooo
o`Co00000oooool2o`0000cooooo1?l00006ooooo`;o00002_ooool2o`000003ooooool0003o0000
01?ooooo0_l00002ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool09?ooool3o`00013o
oooo0ol0000Zooooo`?o000000?oooooo`000?l000001_ooool4o`000004ooooool0003o0000oooo
o`;o00002_ooool2o`000003ooooool0003o000000?ooooo1ol000001?oooooo0000o`000?l0000C
ooooo`?o00002oooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000001Oooool3
o`0000gooooo0_l000000ooooooo0000o`000003ooooo`;o00000oooool2o`000003ooooool0003o
000000;ooooo0_l000000ooooooo0000o`00000Cooooo`;o00000_ooool2o`0000?ooooo0_l0000k
ooooo`007?ooool2o`0002?ooooo0_l000000ooooooo0000o`000003ooooo`;o00003oooool2o`00
00;ooooo0_l00003ooooo`;o00003?ooool2o`00017ooooo0_l00009ooooo`?o00004Oooool2o`00
00?ooooo0_l00002ooooo`;o00000_ooool2o`0002Cooooo0_l00004ooooo`;o00000oooool2o`00
00Cooooo0_l0000;ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`?o000000?oooooo`00
0?l000001Oooool3o`00017ooooo0_l00003ooooo`;o00000oooool2o`0003_ooooo000Looooo`03
o`000?oooooooooo02;ooooo0_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l0
00000_ooool4o`0000Kooooo0_l00002ooooo`;o00000oooool2o`0000?ooooo0_l00007ooooo`;o
00002Oooool2o`0001;ooooo0_l000000ooooooo0000o`00000Cooooo`;o00001?ooool2o`0000Oo
oooo0_l0000@ooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo0_l00009ooooo`;o
00001?ooool2o`0000_ooooo0ol00004ooooo`Ko000000?oooooo`000?l000002Oooool5o`0000oo
oooo0_l00003ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0;Oooool2o`0000;ooooo
1ol0000=ooooo`Ko00002?ooool2o`0000Sooooo0ol00002ooooo`;o00003Oooool2o`000004oooo
ool0003o0000o`0000kooooo0_l00008ooooo`Go00001?ooool2o`00013ooooo1Ol00003ooooo`;o
00002Oooool2o`0000Wooooo0_l00006ooooo`;o00001?ooool2o`0000Cooooo0ol000000ooooooo
0000o`000008ooooo`;o00000_ooool5o`00013ooooo0_l00005ooooo`;o00003?ooool2o`0002oo
oooo000Looooo`03o`000?oooooooooo023ooooo0_l00005ooooo`;o00002oooool5o`0000cooooo
1ol00007ooooo`;o00002Oooool6o`0000gooooo0_l00002ooooo`;o00003_ooool2o`0000[ooooo
0ol00002ooooo`;o00000_ooool4o`0000Kooooo0_l00005ooooo`;o00000_ooool2o`0000cooooo
0_l0000Aooooo`;o00006?ooool2o`0000Cooooo0_l0000Aooooo`;o00001Oooool2o`0000cooooo
0_l0000_ooooo`007?ooool00ol0003oooooooooo`0Pooooo`;o00001Oooool3o`0000;ooooo0_l0
0009ooooo`;o00004?ooool3o`0000Oooooo1?l00008ooooo`?o00001_ooool2o`0000Cooooo0_l0
0009ooooo`;o00000oooool2o`0000oooooo0_l00005ooooo`;o000000?oooooo`000?l000000ol0
0006ooooo`;o00002Oooool2o`0009Sooooo000Looooo`03o`000?oooooooooo02Sooooo0_l00002
ooooo`;o00000oooool2o`0000Gooooo0ol0000>ooooo`;o00002?ooool4o`0000Sooooo0_l00003
ooooo`;o00000_ooool2o`0000Cooooo0_l00004ooooo`;o00000oooool2o`0000?ooooo0_l00004
ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00007ooooo`Ko00002?ooool2
o`0000Wooooo0ol0000Kooooo`Co00002?ooool2o`000004ooooool0003o0000ooooo`;o00001Ooo
ool2o`0000;ooooo0_l0000Booooo`;o00000_ooool4o`00047ooooo000Looooo`03o`000?oooooo
oooo037ooooo0ol00004ooooo`?o00000oooool2o`0000Oooooo1?l00008ooooo`Co00003Oooool4
o`0000cooooo0_l00002ooooo`;o00001_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002
ooooo`;o00002oooool2o`000003ooooool0003o000000;o00001oooool2o`0000Wooooo0ol0000K
ooooo`Co00002?ooool2o`000004ooooool0003o0000ooooo`;o00001Oooool3o`000004ooooool0
003o0000o`00013ooooo0ol000000ooooooo0000o`000003o`00047ooooo000Looooo`03o`000?oo
oooooooo037ooooo0ol0000:ooooo`;o00001oooool2o`0000[ooooo1?l0000;ooooo`;o00000_oo
ool2o`0000_ooooo1?l000000ooooooo0000o`000006ooooo`;o00004?ooool2o`000004ooooool0
003o0000ooooo`;o00000oooool2o`0000Oooooo1Ol0000:ooooo`;o00002Oooool2o`0000oooooo
0_l00005ooooo`;o00003oooool3o`000003ooooool0003o000000?o00003Oooool2o`0000;ooooo
0_l00014ooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00004_ooool3o`0000cooooo0_l0
0004ooooo`;o00002Oooool4o`0000;ooooo0_l0000>ooooo`;o00001oooool5o`000003ooooool0
003o000000_ooooo1_l00005ooooo`;o00000oooool3o`0000Sooooo0_l00003ooooo`;o00002_oo
ool2o`0000Gooooo0_l000000ooooooo0000o`00000=ooooo`So000000?oooooo`000?l000005_oo
ool2o`0003cooooo000Looooo`03o`000?oooooooooo02[ooooo0_l0000Aooooo`Ko00003oooool4
o`0000;ooooo0_l00009ooooo`;o00000oooool2o`0000oooooo0_l0000>ooooo`;o00002?ooool2
o`00013ooooo1Ol00003ooooo`Go000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00000ooo
ool2o`0000?ooooo0_l00004ooooo`;o00002_ooool2o`0000;ooooo0_l0000:ooooo`;o00000ooo
ool2o`0000Gooooo0_l0000@ooooo`;o00001?ooool2o`0003cooooo000Looooo`03o`000?oooooo
oooo02[ooooo0_l00009ooooo`;o00001_ooool2o`0000;ooooo0ol00003ooooo`;o00001oooool4
o`0000;ooooo1?l00004ooooo`Co000000?oooooo`000?l000008?ooool2o`0000;ooooo0_l00000
0ooooooo0000o`000003ooooo`;o00003Oooool2o`0000?ooooo1Ol000000ooooooo0000o`000003
o`0000?ooooo1Ol00003ooooo`;o00000oooool2o`0000;ooooo1Ol00002ooooo`Go00001oooool3
o`0000?ooooo0_l00002ooooo`;o00001?ooool2o`0000Gooooo0_l0000Eooooo`;o00003_ooool2
o`0003;ooooo000Looooo`03o`000?oooooooooo03?ooooo1?l0000;ooooo`;o00000oooool2o`00
00;ooooo0_l00003ooooo`;o00001?ooool3o`0000Gooooo1_l0000Jooooo`;o00001Oooool3o`00
00Cooooo0_l00003ooooo`;o00003Oooool2o`0000?ooooo0_l00002ooooo`Co00000_ooool2o`00
00;ooooo1Ol0000<ooooo`Go00000oooool4o`000003ooooool0003o000000Cooooo0ol00003oooo
o`;o00000_ooool4o`0000Wooooo0_l0000Booooo`Co00000oooool2o`0000[ooooo0_l0000boooo
o`007?ooool00ol0003oooooooooo`0^ooooo`;o00000oooool2o`0001Kooooo0_l00004ooooo`;o
000000?oooooo`000?l000002_ooool4o`0000kooooo0_l00007ooooo`;o000000?oooooo`000?l0
00000oooool5o`00027ooooo2?l00009ooooo`;o00000_ooool2o`0000Gooooo0_l00003ooooo`;o
00001Oooool2o`00013ooooo0_l00009ooooo`;o00004?ooool6o`0000?ooooo0_l0000nooooo`00
7?ooool00ol0003oooooooooo`0^ooooo`;o00004oooool4o`000003ooooool0003o000000Oooooo
0_l000000ooooooo0000o`000003o`0000Kooooo0_l0000Aooooo`;o00001_ooool5o`0000;ooooo
1_l0000;ooooo`;o00006?ooool3o`0000;ooooo0_l00007ooooo`;o00000_ooool2o`0000Oooooo
0_l000000ooooooo0000o`000005ooooo`;o00001Oooool4o`0000Oooooo0_l00009ooooo`Co0000
3_ooool2o`0004Oooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05
onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0aooooo`;o00000_ooool3o`00
00Kooooo0_l00003ooooo`Co000000?oooooo`000?l000001_ooool3o`0000;ooooo1?l00006oooo
o`?o00005oooool6o`0000;ooooo1ol00002ooooo`;o00001_ooool2o`0000oooooo0_l00007oooo
o`;o00000oooool2o`0000gooooo0_l00005ooooo`Go00000oooool2o`0000Oooooo1?l00007oooo
o`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o00002_ooool2o`0000Cooooo0_l00003oooo
o`;o0000@?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEE
ogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo02kooooo0_l000000ooooooo0000o`00
0002ooooo`?o00001_ooool2o`00013ooooo0ol00002ooooo`Co00001oooool2o`0001Oooooo0_l0
0008ooooo`_o00002Oooool2o`0000Oooooo1_l00008ooooo`;o000000?oooooo`000?l000003Ooo
ool2o`000003ooooool0003o000000?ooooo1?l00003ooooo`;o00005_ooool2o`0000;ooooo0_l0
000?ooooo`;o00001?ooool2o`0000?ooooo0_l00010ooooo`0000?ooooooa0@4?ooool00_ooool0
0ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`0^ooooo`;o00001_ooool2o`00017ooooo0_l00009ooooo`Ko00004oooool2o`0000Sooooo1?l0
0004oooooa;o00001_ooool2o`0000Oooooo1_l00005ooooo`Go000000?oooooo`000?l000004?oo
ool2o`0000?ooooo0_l00006ooooo`Co00003Oooool2o`0006Kooooo00000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo00Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000=_oo
ool2o`0000Gooooo0_l0000:ooooo`;o00002Oooool6o`0000cooooo1_l000000ooooooo0000o`00
0008ooooo`;o00001_ooool6o`000003ooooool0003o000000Wo00001oooool2o`00017ooooo1?l0
000Iooooo`;o00001?ooool6o`0000gooooo0_l0000=ooooo`;o0000Eoooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o
0000ooooooooool0?Oooool2o`0000[ooooo0ol00009ooooo`Co000000?oooooo`000?l000001ooo
ool2o`000003ooooool0003o000000Co00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`00
0007ooooo`Ko000000?oooooo`000?l000002?l00007ooooo`;o00000_ooool2o`0000gooooo0_l0
0003ooooo`;o00003?ooool2o`0000kooooo1?l0000Dooooo`;o00000oooool2o`0000;ooooo0ol0
001Gooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`03oeEEEOn7QhOo
oooo00Sooooo00?o0000ooooooooool0=oooool2o`00013ooooo0ol00009ooooo`;o00000oooool2
o`0000Oooooo0_l00003ooooo`;o00001_ooool2o`0000;ooooo0_l00007oooooaKo00002Oooool2
o`0000gooooo0_l000000ooooooo0000o`000002o`0000Oooooo0_l00003ooooo`Ko00002Oooool2
o`000004ooooool0003o0000o`0000;ooooo1ol00004ooooo`;o00001?ooool2o`0000?ooooo0_l0
0002ooooo`;o00002_ooool2o`0001Cooooo0_l0000fooooo`0000KoooooogMgMonHV9SooooooiRH
V?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0=?ooool2o`000003oooo
ool0003o000000;ooooo0_l00002ooooo`;o00001Oooool2o`0000Cooooo0_l00007ooooo`;o0000
5?ooool2o`000003ooooool0003o000000;o00001_ooool2o`0000?ooooo6_l00006ooooo`;o0000
1Oooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool4o`0000Gooooo1Ol00004ooooo`Co
00000_ooool2o`0000Gooooo1_l00002ooooo`Oo00001?ooool2o`0000kooooo0_l00005ooooo`;o
00000_ooool2o`0001Cooooo0_l0000fooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<oooo
o`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0=?ooool2o`0000Gooooo0_l00002
ooooo`;o00001Oooool2o`0000Cooooo0_l00008ooooo`;o000000?oooooo`000?l000004?ooool2
o`000003ooooool0003o000000Sooooo0ol00003oooooaWo00001_ooool2o`0000Gooooo1_l0000=
ooooo`Ko00001Oooool2o`000004ooooool0003o0000o`0000Gooooo1?l00005ooooo`?o00001_oo
ool2o`0000oooooo1?l00003ooooo`;o0000D?ooool001cooooo00?o0000ooooooooool0E_ooool5
o`0001[ooooo0_l00002ooooo`;o00000ooooolGo`00017ooooo0_l0000:ooooo`;o00001?ooool5
o`0000Sooooo0_l0000?ooooo`;o00001oooool2o`0000?ooooo0_l0000;ooooo`?o00003_ooool2
o`0004Gooooo000Looooo`03o`000?oooooooooo04?ooooo0_l00005ooooo`;o00002_ooool4o`00
0003ooooool0003o000000_ooooo1?l00009ooooo`;o00002OoooolFo`000003ooooool0003o0000
01Wooooo0_l00004ooooo`Go00000_ooool2o`0001?ooooo0_l00002ooooo`;o00000_ooool2o`00
00Kooooo0ol00005ooooo`?o00000_ooool3o`0000kooooo1?l00013ooooo`007?ooool00ol0003o
ooooooooo`13ooooo`;o00001Oooool2o`000004ooooool0003o0000o`0000Kooooo0_l00003oooo
o`;o00002Oooool6o`0001;ooooo6ol0000=ooooo`;o00000oooool2o`0000Cooooo0ol00002oooo
o`Ko000000?oooooo`000?l000000ol0000:ooooo`;o00001_ooool2o`0000;ooooo1ol00006oooo
o`;o00001Oooool3o`0000;ooooo0ol00003ooooo`;o00002oooool2o`0004?ooooo000Looooo`03
o`000?oooooooooo02Oooooo0_l00009ooooo`;o00002oooool2o`0000cooooo0ol00002ooooo`;o
00001Oooool2o`0000_ooooo0_l0000>ooooo`;o00001_oooolKo`0000gooooo0_l00003ooooo`;o
00001?ooool3o`0000;ooooo3?l00002ooooo`;o00001_ooool2o`0000Kooooo0_l00003ooooo`Oo
00000oooool2o`000003ooooool0003o000000Cooooo0ol00004ooooo`;o00000_ooool2o`0000_o
oooo0_l00013ooooo`007?ooool00ol0003oooooooooo`0Wooooo`;o00002Oooool2o`0000_ooooo
0_l00004ooooo`;o00002?ooool2o`000003ooooool0003o000000Gooooo0_l0000=ooooo`;o0000
3?ooool2o`0000Oooooo7?l0000@ooooo`;o00001_ooool?o`0000;ooooo0_l0000>ooooo`;o0000
1Oooool5o`000003ooooool0003o000000;o000000?oooooo`000?l000000oooool3o`0000Gooooo
0_l00002ooooo`?o00000_ooool2o`000003ooooool0003o000000?ooooo0_l00006ooooo`;o0000
>oooool001cooooo00?o0000ooooooooool0AOooool2o`0000Sooooo0_l00007ooooo`;o000000?o
ooooo`000?l000002oooool2o`0001Cooooo3_l000000ooooooo0000o`00000<o`0000Kooooo0_l0
0002ooooo`;o00003?ooool?o`0001?ooooo0_l0000:ooooo`;o00002?ooool2o`0000Wooooo1?l0
0002ooooo`Go00002oooool2o`0000_ooooo0_l0000^ooooo`007?ooool00ol0003oooooooooo`0o
ooooo`;o00003Oooool2o`0000?ooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l0
000@ooooo`;o00002?ooool3o`000003ooooool0003o000000co000000?oooooo`000?l000002ol0
0002ooooo`?o00000_ooool2o`0000;ooooo0_l00008ooooo`;o00000_ooool2o`000003ooooool0
003o000000_o00000_ooool3o`0000gooooo0_l00005ooooo`;o00000oooool4o`00013ooooo0ol0
0005ooooo`Co00000oooool2o`0001?ooooo0_l0000^ooooo`007?ooool00ol0003oooooooooo`0l
ooooo`;o000000?oooooo`000?l000003Oooool2o`0000?ooooo0ol00008ooooo`;o00004?ooool3
o`0000Oooooo0ol000000ooooooo0000o`00000Bo`000003ooooool0003o000000Ko000000Cooooo
o`000?l0003o00001_ooool4o`0000Kooooo0_l000000ooooooo0000o`00000?o`0000;ooooo0ol0
00000ooooooo0000o`000009ooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo1?l0
0007ooooo`;o00001oooool2o`0000Oooooo0_l00004ooooo`?o0000@_ooool001cooooo00?o0000
ooooooooool0??ooool2o`0001Kooooo0_l00004ooooo`;o00003?ooool2o`0000Cooooo0_l00000
0ooooooo0000o`00000;ooooo`Go00000_oooolFo`000003ooooool0003o000000Wooooo0_l00002
ooooo`;o00001OoooolBo`0000;ooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l00000
1Ooooooo0000o`000?l0003ooooo00Ko00001?ooool4o`0000Oooooo0_l0000Gooooo`;o0000@_oo
ool001cooooo00?o0000ooooooooool0?oooool2o`0000[ooooo0_l00005ooooo`Co00001?ooool4
o`000003ooooool0003o000000Kooooo0ol00004ooooo`;o00001?ooool2o`000003ooooool0003o
000000?ooooo1ol000000ooooooo0000o`00000Eo`000003ooooool0003o000000gooooo0_l00007
oooooaCo00000oooool2o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`Co00001_ooool2
o`0006Cooooo000Looooo`03o`000?oooooooooo03kooooo0ol00003ooooo`;o00001Oooool2o`00
00Gooooo0_l00004ooooo`;o00000_ooool2o`000003ooooool0003o000000Kooooo0_l00005oooo
o`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000003oooooa?o000000?ooooo
o`000?l000002_l00002ooooo`;o00003Oooool2o`0000?ooooo5Ol00004ooooo`;o000000?ooooo
o`000?l000001_ooool4o`0000gooooo0ol00005ooooo`;o000000?oooooo`000?l000001Oooool2
o`000003ooooool0003o000004_ooooo000Looooo`;o0000?_ooool3o`0000Cooooo0_l00008oooo
o`;o00001?ooool2o`0000;ooooo0_l000001?oooooo0000o`000?l00005ooooo`;o00002?ooool2
o`0000;ooooo0ol0000:oooooako000000Coooooo`000?l0003o00000oooool2o`0000Cooooo0_l0
00001?oooooo0000o`000?l00003oooooaKo00000oooool2o`000003ooooool0003o000000Kooooo
1?l0000=ooooo`?o00001?ooool3o`000003ooooool0003o000000Gooooo0_l000000ooooooo0000
o`000003ooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0?Oooool4o`0000Sooooo0_l0
0003ooooo`;o000000Coooooo`000?l0003ooooo0_l000001Ooooooo0000o`000?l0003ooooo00Co
00000_ooool4o`0000Sooooo0_l00003ooooo`;o00001_ooool2o`0000;ooooo7?l00003ooooo`;o
00001?ooool2o`0000Cooooo1Ol00002oooooaSo00005?ooool3o`0000Sooooo0_l00005ooooo`;o
00002Oooool2o`0000Kooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`0oooooo`;o0000
0_ooool2o`0000Cooooo0_l00006ooooo`;o00001?ooool2o`0000;ooooo1?l000001?oooooo0000
o`000?l0000Dooooo`;o000000?oooooo`000?l000000ooooolKo`0000;ooooo0_l0000;ooooo`Co
00000ooooolIo`0001?ooooo0ol0000Booooo`;o00001oooool3o`0004cooooo000Looooo`03o`00
0?oooooooooo04?ooooo0_l00004ooooo`;o00002oooool2o`0000Cooooo0ol000000ooooooo0000
o`00000?ooooo`;o00001?ooool2o`0000Kooooo6ol000001?oooooo0000o`000?l0000>ooooo`;o
00001?oooolBo`0000;ooooo0ol0000<ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Doooo
o`;o00001oooool4o`000003ooooool0003o000004Sooooo000Looooo`03o`000?oooooooooo04Go
oooo0ol000000ooooooo0000o`000007ooooo`;o00000_ooool2o`0000Cooooo0ol0000<ooooo`;o
00001?ooool2o`0000cooooo6ol000000ooooooo0000o`00000;ooooo`;o00000_ooool2o`0000Go
oooo1_l000000ooooooo0000o`00000@o`0000Oooooo1?l000001?oooooo0000o`000?ooool2o`00
00?ooooo0_l00002ooooo`;o00005_ooool2o`000003ooooool0003o000004Sooooo000Looooo`03
o`000?oooooooooo04Gooooo0ol0000:ooooo`;o00002?ooool3o`0000cooooo0_l000000ooooooo
0000o`000006ooooo`;o000000Coooooo`000?l0003ooooo0_l00002oooooaWo00003oooool4o`00
00?ooooo0_l000000ooooooo0000o`00000?o`000003ooooool0003o000000;ooooo1?l00007oooo
o`Go00001_ooool4o`0000;ooooo0_l00007ooooo`;o0000F_ooool001cooooo00?o0000oooooooo
ool0@Oooool2o`0000;ooooo0_l000000ooooooo0000o`00000?ooooo`;o000000?oooooo`000?l0
00001?l0000<ooooo`;o00001_ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`00
0?l000006_l00003ooooo`;o00002_ooool2o`0000?ooooo0_l000000ooooooo0000o`00000=o`00
0003ooooool0003o000000Go00002_ooool5o`000004ooooool0003o0000ooooo`Co00002Oooool2
o`0000;ooooo0_l00007ooooo`;o0000DOooool001cooooo00?o0000ooooooooool0@Oooool2o`00
00;ooooo1Ol000000ooooooo0000o`000006ooooo`;o00001?ooool9o`0000Sooooo0_l00007oooo
o`;o00001oooool2o`000004ooooool0003o0000oooooaWo000000?oooooo`000?l000000_l00000
0ooooooo0000o`000007ooooo`;o00001?oooolIo`00013ooooo0_l000000ooooooo0000o`00000;
ooooo`;o00000oooool2o`0000Kooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`16oooo
o`;o00000oooool4o`0000Cooooo0_l00004ooooo`Go00003?ooool2o`0000Oooooo0ol00006oooo
o`;o00001_ooool2o`000003ooooool0003o000000Co00000_ooool;o`0000;ooooo0_l00003oooo
o`?o00003?ooool2o`000003ooooool0003o000001;o00005Oooool2o`0000Wooooo0_l00005oooo
o`;o00003?ooool2o`0004_ooooo000Looooo`03o`000?oooooooooo04Gooooo0_l00006ooooo`;o
00000oooool3o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o00003Oooool2o`0000?o
oooo0_l00005ooooo`;o00001oooool2o`000003ooooool0003o000000Ko000000?oooooo`000?l0
00000ol0000=ooooo`;o00001?ooool2o`0000Oooooo5Ol0000?ooooo`;o00001Oooool2o`0000Ko
oooo0_l000000ooooooo0000o`000004ooooo`;o00001oooool2o`0000Cooooo0_l0001;ooooo`00
7?ooool00ol0003oooooooooo`15ooooo`Co00002Oooool3o`0000Cooooo1Ol00002ooooo`;o0000
2_ooool2o`000003ooooool0003o000000[ooooo0_l00003ooooo`;o00000_ooool2o`000003oooo
ool0003o000000?o000000?oooooo`000?l000000ol0000Fooooo`;o00000ooooolHo`00013ooooo
0_l0000=ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Gooooo1Ol0001@ooooo`007?oo
ool00ol0003oooooooooo`17ooooo`;o00004_ooool2o`0000Oooooo0_l00006ooooo`;o00000_oo
ool2o`0000kooooo0_l00005ooooo`;o00001Oooool2o`0000Sooooo0_l000000ooooooo0000o`00
000?ooooo`Go00000_ooool5o`000003ooooool0003o000000Wo00006Oooool2o`0000Kooooo1Ol0
000:ooooo`;o000000?oooooo`000?l00000D?ooool001cooooo00?o0000ooooooooool0;Oooool2
o`0001gooooo0_l00002ooooo`;o00002Oooool3o`0000Kooooo0_l00009ooooo`?o00007?ooool2
o`0000Sooooo0_l000001?oooooo0000o`000?ooool2o`0000cooooo1?l000000ooooooo0000o`00
000?o`0000Cooooo0_l0000Eooooo`;o000000?oooooo`000?l000000oooool5o`0005oooooo000L
ooooo`03o`000?oooooooooo02gooooo0_l0000Iooooo`;o00000_ooool2o`0000;ooooo0_l00000
0ooooooo0000o`000004ooooo`Go00002?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002
o`0000Gooooo0_l0000Qooooo`Co000000?oooooo`000?l000000_l0000<ooooo`Go000000Cooooo
o`000?l0003ooooo2_l00003ooooo`Co00002_ooool2o`0000;ooooo0_l00004ooooo`;o00000_oo
ool2o`0001;ooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00000_ooool2
o`0000Wooooo0_l00004ooooo`Co00002Oooool2o`0000;ooooo0_l000001?oooooo0000o`000?oo
ool4o`0000;ooooo0_l0000Nooooo`;o000000?oooooo`000?l000000_l00002ooooo`?o00003_oo
ool2o`0000?ooooo1Ol000000ooooooo0000o`000004o`0000?ooooo1?l00006ooooo`;o00000_oo
ool2o`0000;ooooo0_l00004ooooo`;o00001?ooool2o`0000;ooooo0_l0000<ooooo`;o000000Co
ooooo`000?l0003o0000Coooool001cooooo00?o0000ooooooooool0A?ooool2o`0000Cooooo1?l0
000<ooooo`;o00005?ooool4o`0000Kooooo0_l0000>ooooo`;o00002_ooool2o`0000Oooooo0ol0
000Cooooo`;o00003?ooool2o`000004ooooool0003o0000o`0000Gooooo0ol00005ooooo`;o0000
2_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000<ooooo`?o0000Coooool001cooooo0_l0
001:ooooo`Go00004Oooool2o`0000Gooooo0_l00008ooooo`?o00001oooool3o`0000gooooo0_l0
0003ooooo`Go00003?ooool2o`0001Gooooo0_l0000:ooooo`;o00000_ooool2o`0000Kooooo0_l0
0005ooooo`;o00004Oooool3o`0005gooooo000Looooo`03o`000?oooooooooo04Wooooo0_l00000
0ooooooo0000o`00000Aooooo`;o00001Oooool2o`000004ooooool0003o0000o`0000Cooooo0ol0
0008ooooo`;o00004_ooool5o`0000Sooooo0_l0000=ooooo`;o00002_ooool2o`0000Cooooo0_l0
0002ooooo`;o00001oooool2o`0000?ooooo0_l0000Gooooo`Co00000oooool2o`0000;ooooo0_l0
000=ooooo`;o0000AOooool001cooooo00?o0000ooooooooool0C?ooool2o`0000?ooooo0ol0000=
ooooo`;o00001_ooool3o`00033ooooo0_l00009ooooo`;o00000_ooool2o`00013ooooo0_l00002
ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000005ooooo`;o00005Ooo
ool2o`0000Gooooo0_l00002ooooo`?o00003?ooool2o`0004Gooooo000Looooo`03o`000?oooooo
oooo04cooooo0_l00003ooooo`?o00001oooool2o`0000Cooooo0_l00007ooooo`;o00001Oooool2
o`00017ooooo0_l0000Fooooo`;o00002Oooool2o`0000Wooooo0_l00009ooooo`;o00001Oooool2
o`000003ooooool0003o000000Sooooo0_l0000<ooooo`Co00004Oooool2o`0005?ooooo000Loooo
o`03o`000?oooooooooo04cooooo0_l0000=ooooo`;o00003Oooool2o`0000Gooooo0ol0000;oooo
o`;o00000oooool2o`0001Kooooo0_l0000=ooooo`;o00001?ooool3o`0000_ooooo0ol00006oooo
o`?o000000?oooooo`000?l000003?ooool2o`0000?ooooo1?l0001Vooooo`007?ooool00ol0003o
ooooooooo`1Qooooo`;o00001?ooool2o`0000Gooooo0_l00002ooooo`;o00002oooool2o`0001Oo
oooo0_l0000Aooooo`;o00000_ooool4o`0000cooooo0ol00006ooooo`?o000000?oooooo`000?l0
00003?ooool2o`0001Gooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`1Qooooo`;o0000
1?ooool4o`0000?ooooo0_l00006ooooo`;o00001oooool2o`0000?ooooo0_l0000Booooo`;o0000
2oooool2o`0000Sooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l0000?ooooo`;o0000
1?ooool2o`0000oooooo0_l00006ooooo`;o00001_ooool2o`0000Kooooo1?l0001<ooooo`007?oo
ool00ol0003oooooooooo`1<ooooo`;o00002Oooool3o`0000Oooooo0ol00005ooooo`;o00002ooo
ool2o`0000cooooo0_l00008ooooo`;o00005Oooool2o`0000gooooo0_l000000ooooooo0000o`00
0002o`0000Kooooo0_l00004ooooo`Go00001?ooool2o`0000oooooo0_l00006ooooo`;o00001?oo
ool2o`0000Sooooo1?l0001<ooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00001?ooool2
o`0000?ooooo0ol00007ooooo`?o00002Oooool4o`0000?ooooo0_l0000<ooooo`Co00001Oooool2
o`000003ooooool0003o000000cooooo0_l00005ooooo`;o00003_ooool3o`000004ooooool0003o
0000ooooo`;o00001?ooool3o`0000Cooooo0ol0000Gooooo`;o00000oooool2o`0000Oooooo0_l0
001Hooooo`007?ooool00ol0003oooooooooo`1Booooo`;o00000oooool2o`0000cooooo0_l00006
ooooo`Co00000_ooool3o`0000cooooo1?l00002ooooo`;o000000?oooooo`000?l000003oooool2
o`0000Gooooo0_l0000:ooooo`;o00000_ooool3o`0000Cooooo0_l00002ooooo`Co00002Oooool2
o`000003ooooool0003o000000_ooooo1?l000000ooooooo0000o`000004ooooo`;o00002?ooool2
o`0005Oooooo000Looooo`03o`000?oooooooooo05Oooooo1Ol00003ooooo`;o00001?ooool2o`00
00cooooo0_l00003ooooo`;o00003_ooool2o`0001Cooooo0_l0000?ooooo`;o00002Oooool2o`00
00;ooooo0_l0000;ooooo`;o000000?oooooo`000?l000002oooool4o`000003ooooool0003o0000
00Oooooo0_l00005ooooo`?o0000E_ooool001cooooo00?o0000ooooooooool0FOooool5o`000003
ooooool0003o000000;ooooo1?l0000:ooooo`;o00001Oooool2o`0000kooooo2?l0000>ooooo`;o
00006_ooool2o`0001Gooooo0ol000001?oooooo0000o`000?l0000Aooooo`Co00001?ooool2o`00
05Kooooo000Looooo`03o`000?oooooooooo05Wooooo0_l000000ooooooo0000o`000005ooooo`;o
00003?ooool4o`00013ooooo0_l00002ooooo`Oo000000?oooooo`000?l000008Oooool2o`0000co
oooo0_l0000=ooooo`Oo00004Oooool4o`0005cooooo000Looooo`03o`000?oooooooooo05Sooooo
0ol0000Dooooo`Ko00001?ooool2o`0000[ooooo0ol00006ooooo`;o000000?oooooo`000?l00000
1?ooool3o`0001[ooooo0_l0000<ooooo`Co00002Oooool2o`000005ooooool0003o0000o`000?oo
ool00_l00009ooooo`;o0000I_ooool001cooooo00?o0000ooooooooool0F?ooool2o`0001Gooooo
0ol000000ooooooo0000o`000004ooooo`;o00001?ooool2o`0000Gooooo0_l00004ooooo`;o0000
0oooool3o`0000?ooooo0ol0000Zooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo
0_l00005ooooo`;o000000?oooooo`000?l000001_ooool2o`000003ooooool0003o000000Cooooo
0_l0001Mooooo`007?ooool00ol0003oooooooooo`1Nooooo`Co00001?ooool2o`000003ooooool0
003o000000?ooooo1?l0000=ooooo`;o00002oooool8o`0000kooooo0_l0000Mooooo`;o000000Go
ooooo`000?l0003o0000ooooo`02o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000;o
oooo0_l000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l000001?ooool2o`0005go
oooo000Looooo`;o0000Goooool4o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`Go0000
5oooool2o`0000;ooooo0ol00005ooooo`;o00002_ooool2o`0000cooooo0_l0000?ooooo`?o0000
00?oooooo`000?l000001oooool3o`000003ooooool0003o000000Oooooo0_l00005ooooo`Co0000
Hoooool001cooooo00?o0000ooooooooool0G_ooool2o`0000oooooo1?l0000;ooooo`;o00002_oo
ool2o`0000[ooooo0_l00009ooooo`?o00003?ooool2o`0000;ooooo0_l0000<ooooo`Co00002Ooo
ool2o`0000Wooooo0ol00005ooooo`;o0000IOooool001cooooo00?o0000ooooooooool0B?ooool2
o`0001Cooooo0_l0000:ooooo`;o00000oooool2o`0000cooooo0ol0000Booooo`;o00003Oooool3
o`0000Wooooo0_l00005ooooo`;o000000?oooooo`000?l000002?ooool5o`0000?ooooo0_l0000?
ooooo`Co0000Joooool001cooooo00?o0000ooooooooool0B?ooool2o`00023ooooo0_l00004oooo
o`Co000000?oooooo`000?l000001_ooool2o`0001?ooooo0_l0000Iooooo`;o00002?ooool2o`00
00Sooooo0_l00006ooooo`;o00003_ooool2o`000003ooooool0003o000006_ooooo000Looooo`03
o`000?oooooooooo073ooooo1?l000000ooooooo0000o`000006ooooo`;o00003_ooool2o`000003
ooooool0003o000000_ooooo0_l0000>ooooo`;o00004?ooool2o`000003ooooool0003o000001Go
oooo0_l0001^ooooo`007?ooool00ol0003oooooooooo`1aooooo`?o00006Oooool2o`000003oooo
ool0003o000000;ooooo0_l00002ooooo`;o00000oooool2o`0001?ooooo0_l0000;ooooo`Go0000
1oooool2o`0000;ooooo0_l00005ooooo`?o00004Oooool2o`0005gooooo000Looooo`03o`000?oo
oooooooo06Gooooo0_l0000:ooooo`?o00008?ooool2o`0000;ooooo0ol0000>ooooo`Go00001?oo
ool2o`000004ooooool0003o0000ooooo`;o00001oooool3o`0000?ooooo0_l00002ooooo`;o0000
0_ooool2o`000005ooooool0003o0000o`000?ooool00ol0000Aooooo`;o0000GOooool001cooooo
00?o0000ooooooooool0IOooool2o`0000Gooooo0_l000000ooooooo0000o`000009ooooo`;o0000
6_ooool2o`000003ooooool0003o000000Gooooo1?l00005ooooo`Go00001?ooool2o`000004oooo
ool0003o0000ooooo`;o00002?ooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`00
00?ooooo0ol0000;ooooo`;o0000Ioooool001cooooo00?o0000ooooooooool0Aoooool2o`0001co
oooo0_l00005ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Oooooo0_l00005ooooo`;o
00000_ooool4o`0000Cooooo0_l000000ooooooo0000o`000005ooooo`Co00001oooool2o`0000?o
oooo1?l00004ooooo`;o00000oooool2o`0000?ooooo0ol00005ooooo`;o000000Coooooo`000?l0
003ooooo0_l000000ooooooo0000o`00000;ooooo`;o0000Ioooool001cooooo00?o0000oooooooo
ool0Aoooool2o`0003[ooooo0_l00005ooooo`;o00000_ooool5o`0000_ooooo0_l000001?oooooo
0000o`000?ooool6o`000003ooooool0003o000000?ooooo0_l00004ooooo`;o00001Oooool2o`00
00Cooooo0_l0000;ooooo`;o000000?oooooo`000?l000002Oooool2o`0000[ooooo0_l0001Moooo
o`007?ooool00ol0003oooooooooo`1_ooooo`;o00005?ooool2o`0000Gooooo0_l00003ooooo`;o
000000?oooooo`000?l000002?ooool2o`0000Cooooo1_l0000:ooooo`Go00000_ooool2o`0000Go
oooo0_l0000?ooooo`;o00002Oooool2o`0000[ooooo0_l0001Mooooo`007?ooool00ol0003ooooo
ooooo`1_ooooo`;o00004Oooool2o`000003ooooool0003o000000Oo00001_ooool2o`000003oooo
ool0003o000000cooooo0_l00003ooooo`;o00001_ooool4o`000003ooooool0003o000000;ooooo
0ol00004ooooo`;o00002Oooool2o`000003ooooool0003o000001Gooooo1?l0001Nooooo`007?oo
ool00ol0003oooooooooo`1`ooooo`?o00003_ooool4o`000003ooooool0003o000000Co00002?oo
ool5o`00017ooooo0_l00006ooooo`;o00001oooool5o`0000[ooooo0_l000000ooooooo0000o`00
0003o`0001Gooooo1?l0001Nooooo`007?ooool00ol0003oooooooooo`1`ooooo`?o00001?ooool2
o`0000Gooooo1ol00002ooooo`;o00001?ooool3o`0000Gooooo0_l0000Iooooo`;o00000_ooool2
o`000003ooooool0003o000000;ooooo1Ol00005ooooo`;o00000_ooool3o`0000?ooooo0_l0001h
ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`00
0?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0Moooool2o`0000Gooooo0ol00006ooooo`;o0000
1?ooool3o`0000Gooooo0_l00005ooooo`;o00002oooool4o`0000?ooooo0_l00002ooooo`;o0000
00?oooooo`000?l000001_l00006ooooo`;o00000_ooool2o`0007kooooo00001_ooooooMgMgoiRH
V?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0
003oooooooooo`1_ooooo`;o00000oooool2o`0000Cooooo0_l0000Booooo`;o00003?ooool2o`00
00;ooooo0_l00007ooooo`Co00000_ooool4o`000004ooooool0003o0000ooooo`Co000000?ooooo
o`000?l000007oooool2o`0006[ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo
00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo06oooooo0_l00003
ooooo`;o00001?ooool2o`000003ooooool0003o000000Wooooo0_l00004ooooo`;o00002oooool3
o`0000;ooooo0_l00009ooooo`;o00000_ooool7o`000004ooooool0003o0000o`0000;ooooo0_l0
000Aooooo`;o00003?ooool2o`0000[ooooo0_l0001Nooooo`0000?oooooo`000?ooool00_ooool0
0ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`0007gooooo0_l0
0007ooooo`Co000000Coooooo`000?l0003ooooo0_l00006ooooo`?o00000_ooool3o`000003oooo
ool0003o000000[ooooo0_l00002ooooo`Ko00001_ooool2o`0000Kooooo0_l0000:ooooo`;o0000
6?ooool2o`0005kooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go
c<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo06[ooooo0_l00009ooooo`;o0000
3oooool3o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`Co00000oooool2o`000003oooo
ool0003o000000Sooooo0_l00006ooooo`Co00001Oooool3o`0000?ooooo0_l000000ooooooo0000
o`000024ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj
^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`1Zooooo`;o00002Oooool3o`0000oooooo
0_l00005ooooo`;o000000?oooooo`000?l000000_ooool4o`0000oooooo0ol0000?ooooo`;o0000
1?ooool2o`0000;ooooo0_l00023ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05
o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`1cooooo`;o000000?oooooo`00
0?l000001oooool2o`00013ooooo0_l00005ooooo`;o00003_ooool2o`0001[ooooo0_l00023oooo
o`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_oo
ool00ol0003oooooooooo`1cooooo`;o00002_ooool2o`0001Cooooo0_l000000ooooooo0000o`00
002_ooooo`007?ooool00ol0003oooooooooo`1kooooo`;o00006?ooool2o`0002Sooooo0_l0000>
ooooo`;o0000N?ooool001cooooo00?o0000ooooooooool0N_ooool3o`0000kooooo0_l0000Yoooo
o`;o00001oooool2o`0000;ooooo0_l00002ooooo`;o00001Oooool3o`0007Sooooo000Looooo`03
o`000?oooooooooo073ooooo0_l00008ooooo`;o00003oooool2o`00017ooooo0_l0000Fooooo`;o
00002oooool2o`0000;ooooo0_l00005ooooo`;o00001_ooool2o`00077ooooo000Looooo`03o`00
0?oooooooooo073ooooo0_l00008ooooo`;o00002_ooool2o`0001Kooooo0_l0000?ooooo`;o0000
6_ooool2o`000004ooooool0003o0000o`0000Gooooo0_l0001aooooo`007?ooool00ol0003ooooo
ooooo`1jooooo`;o00001_ooool2o`0000;ooooo0_l0000Eooooo`;o00002Oooool2o`0000Gooooo
0_l0000Aooooo`Co00001Oooool2o`000004ooooool0003o0000o`0007Sooooo000Looooo`03o`00
0?oooooooooo08;ooooo0_l0000Iooooo`;o00002Oooool2o`0001;ooooo0_l00004ooooo`Co0000
1?ooool2o`0007gooooo000Looooo`03o`000?oooooooooo093ooooo0_l0000Zooooo`;o00003?oo
ool2o`0007gooooo000Looooo`03o`000?oooooooooo093ooooo0_l0000Tooooo`;o0000TOooool0
01cooooo00?o0000ooooooooool0]?ooool4o`000003ooooool0003o000008kooooo000Looooo`03
o`000?oooooooooo08Wooooo0_l00008ooooo`;o00000_ooool2o`00017ooooo0_l00008ooooo`;o
00000oooool2o`0008kooooo000Looooo`03o`000?oooooooooo08Wooooo0_l00008ooooo`;o0000
0_ooool2o`0000[ooooo0_l00004ooooo`?o00002Oooool2o`0009;ooooo000Looooo`;o0000O_oo
ool2o`0002Cooooo0_l00004ooooo`;o00001Oooool2o`0000?ooooo0_l0002Booooo`007?ooool0
0ol0003oooooooooo`1mooooo`;o00006oooool2o`0001Cooooo0_l0002Gooooo`007?ooool00ol0
003oooooooooo`2Jooooo`;o0000[Oooool001cooooo00?o0000ooooooooool0X?ooool2o`000:Oo
oooo000Looooo`03o`000?oooooooooo06Wooooo0_l0000eooooo`;o0000Yoooool001cooooo00?o
0000ooooooooool0JOooool2o`000=kooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0Poooool4o`000<;ooooo000Looooo`03o`000?oooooooooo08?o
oooo1?l0000cooooo`;o0000SOooool001cooooo00?o0000ooooooooool0R_ooool2o`00027ooooo
0_l00005ooooo`;o00001?ooool2o`0008gooooo000Looooo`03o`000?oooooooooo08Gooooo0_l0
0003ooooo`;o000000?oooooo`000?l000007_ooool2o`0000Gooooo0_l0002Cooooo`007?ooool0
0ol0003oooooooooo`24ooooo`?o00001_ooool2o`000;[ooooo000Looooo`03o`000?oooooooooo
08Cooooo0_l00033ooooo`007?ooool00ol0003oooooooooo`1kooooo`;o00006_ooool2o`000;3o
oooo000Looooo`03o`000?oooooooooo07_ooooo0_l0000Jooooo`;o0000/?ooool001cooooo00?o
0000ooooooooool0XOooool2o`000:Kooooo000Looooo`;o0000R_ooool2o`0001Kooooo0_l0002V
ooooo`007?ooool00ol0003oooooooooo`23ooooo`;o00001?ooool2o`0001Gooooo0_l0002Woooo
o`007?ooool00ol0003oooooooooo`23ooooo`;o00006oooool2o`000:Oooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooo
od_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001;ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB_ooool0
01Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03
o`000?oooooooooo00Gooooo0ol0003ooooood[ooooo000Dooooo`03o`000?oooooooooo0?oooooo
D_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3o
oooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001;ooooo00?oEEEEofIVI_l0
0000oooooomDooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00XOooool01?l@
413o0000o`000?ooool2o`000003oa0@4?oooooooooo01Kooooo1?l000001?l@413ooooooooooooo
ool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oa0@4?o<c<`5ooooo`;o000000?o410@oooo
ooooool0R_ooool00:;ooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00003?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00GoEEEEogMgMoooooooV9RHob4Q8@06
ooooo`03o`000?oooooooooo08_ooooo002Rooooo`05o`000?ooooooooooooooool000006oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`Go0000S?ooool00:;ooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00003?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Go0000oiRHV?ooooooV9RH
ob4Q8@03ooooo`04odA4A?oMgMgoooooo`0008gooooo002Rooooo`05o`000?n7QhOoooooojVYZOl0
00006oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Go0000oeEEEOl0
003o410@olc<c003ooooo`04omgMgOmEEEGoooooo`0008gooooo002Qooooo`03oa0@4?l0003oMgMg
00;o000000?oV9RHooooooooool06Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo00?oEEEEohN7Qoooool01_ooool00omgMgOoc<c<o`00002=ooooo`00`_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?ogMgMoa0@4?nHV9P01_ooool00oo^k^ko
A4A4o`00002=ooooo`00`?ooool00omEEEGoIVIVo`000005ooooo`03oeEEEOmVIVKo000000Gooooo
00Coc<c<odA4A?l0003o410@1Oooool00omgMgOo0000ooooo`2<ooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1170) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.4357 .30837 Mdot
.4756 .34458 Mdot
.42939 .65362 Mdot
.62106 .47926 Mdot
.20429 .43991 Mdot
.41504 .61972 Mdot
.35376 .45158 Mdot
.38393 .48921 Mdot
.41609 .64522 Mdot
.33849 .29773 Mdot
.36523 .45101 Mdot
.72764 .43053 Mdot
.37543 .46173 Mdot
.62259 .45669 Mdot
.20209 .33571 Mdot
.67645 .51233 Mdot
.44902 .37057 Mdot
.53122 .66215 Mdot
.68313 .41401 Mdot
.37935 .6201 Mdot
.44361 .38602 Mdot
.62726 .46566 Mdot
.4904 .32368 Mdot
.62273 .45588 Mdot
.631 .50041 Mdot
.44648 .32591 Mdot
.51281 .35046 Mdot
.66879 .48684 Mdot
.65055 .50949 Mdot
.38747 .48258 Mdot
.66371 .62104 Mdot
.1831 .39402 Mdot
.65032 .40513 Mdot
.28978 .70959 Mdot
.3699 .49698 Mdot
.61031 .34852 Mdot
.42972 .62758 Mdot
.36237 .4845 Mdot
.3565 .48867 Mdot
.33181 .46974 Mdot
.35746 .47138 Mdot
.4598 .32219 Mdot
.35086 .5292 Mdot
.45223 .55961 Mdot
.68857 .49979 Mdot
.25004 .41758 Mdot
.76974 .37818 Mdot
.67427 .44446 Mdot
.43884 .3607 Mdot
.40149 .72191 Mdot
.24825 .54578 Mdot
.33686 .46793 Mdot
.40718 .57585 Mdot
.48753 .90186 Mdot
.3703 .4887 Mdot
.70412 .4723 Mdot
.43627 .63809 Mdot
.63611 .45818 Mdot
.62524 .45125 Mdot
.52452 .25485 Mdot
.68783 .45054 Mdot
.5666 .656 Mdot
.42615 .30872 Mdot
.52553 .49562 Mdot
.42246 .64152 Mdot
.35002 .47698 Mdot
.48019 .33127 Mdot
.37898 .46919 Mdot
.59425 .51058 Mdot
.37713 .61439 Mdot
.67643 .44811 Mdot
.35395 .46424 Mdot
.42827 .35427 Mdot
.66974 .46719 Mdot
.4848 .77459 Mdot
.40768 .19038 Mdot
.59937 .67295 Mdot
.57592 .31972 Mdot
.52748 .28178 Mdot
.48092 .71651 Mdot
.60218 .47125 Mdot
.75648 .56437 Mdot
.34646 .22787 Mdot
.50078 .33575 Mdot
.56458 .44131 Mdot
.54468 .61326 Mdot
.66517 .46489 Mdot
.26558 .34283 Mdot
.65548 .51375 Mdot
.49902 .79368 Mdot
.40413 .63567 Mdot
.45941 .35181 Mdot
.61907 .47909 Mdot
.677 .48768 Mdot
.7676 .43519 Mdot
.61414 .4213 Mdot
.64862 .48253 Mdot
.43256 .32802 Mdot
.33586 .47693 Mdot
.72058 .45223 Mdot
.41929 .54671 Mdot
.42838 .58121 Mdot
.63131 .42264 Mdot
.41532 .5895 Mdot
.43294 .37076 Mdot
.67525 .471 Mdot
.35258 .49191 Mdot
.63217 .42639 Mdot
.38646 .38965 Mdot
.47859 .34582 Mdot
.67095 .49093 Mdot
.54744 .65431 Mdot
.76102 .67892 Mdot
.46251 .36068 Mdot
.51611 .71263 Mdot
.60228 .48587 Mdot
.64716 .47322 Mdot
.47318 .34322 Mdot
.44892 .62112 Mdot
.28193 .31384 Mdot
.49181 .31636 Mdot
.32983 .4842 Mdot
.45238 .29599 Mdot
.56242 .45839 Mdot
.4072 .63104 Mdot
.27592 .63181 Mdot
.30677 .43457 Mdot
.67509 .59805 Mdot
.65999 .46097 Mdot
.33059 .34644 Mdot
.38918 .6134 Mdot
.46024 .33955 Mdot
.38219 .46757 Mdot
.66651 .39675 Mdot
.49065 .34952 Mdot
.38609 .45079 Mdot
.55993 .64786 Mdot
.30829 .58987 Mdot
.46904 .37532 Mdot
.44395 .54172 Mdot
.39859 .47245 Mdot
.33717 .4631 Mdot
.34921 .77424 Mdot
.47591 .33084 Mdot
.55572 .67461 Mdot
.38457 .4772 Mdot
.63709 .61019 Mdot
.69573 .47989 Mdot
.72692 .61973 Mdot
.80552 .41006 Mdot
.30547 .72405 Mdot
.33091 .60609 Mdot
.57743 .68448 Mdot
.34284 .50287 Mdot
.6435 .49721 Mdot
.43881 .3303 Mdot
.46046 .31738 Mdot
.68203 .43962 Mdot
.6221 .48956 Mdot
.67861 .45662 Mdot
.67768 .49028 Mdot
.49203 .22805 Mdot
.59694 .44264 Mdot
.78764 .42242 Mdot
.45705 .35623 Mdot
.63376 .48875 Mdot
.44221 .61817 Mdot
.58805 .42641 Mdot
.3544 .4703 Mdot
.63416 .46585 Mdot
.62311 .48153 Mdot
.68782 .4459 Mdot
.33535 .47178 Mdot
.22217 .3334 Mdot
.80223 .49293 Mdot
.19139 .41328 Mdot
.54272 .77704 Mdot
.41021 .59979 Mdot
.65986 .46887 Mdot
.5504 .65972 Mdot
.64498 .32628 Mdot
.60609 .45697 Mdot
.86726 .57831 Mdot
.64007 .47866 Mdot
.2009 .41267 Mdot
.63614 .54038 Mdot
.15672 .47947 Mdot
.734 .59195 Mdot
.65374 .49762 Mdot
.57042 .54811 Mdot
.49372 .41289 Mdot
.41823 .55384 Mdot
.36036 .46947 Mdot
.44435 .62404 Mdot
.43675 .64653 Mdot
.38278 .51545 Mdot
.48647 .27493 Mdot
.5502 .49266 Mdot
.57473 .47334 Mdot
.37805 .60645 Mdot
.41893 .33815 Mdot
.58632 .66285 Mdot
.44647 .30892 Mdot
.42786 .14198 Mdot
.25393 .50162 Mdot
.36218 .52046 Mdot
.5528 .70256 Mdot
.39912 .64159 Mdot
.42815 .58371 Mdot
.54149 .67614 Mdot
.65234 .43647 Mdot
.47668 .3263 Mdot
.26904 .71013 Mdot
.43316 .25309 Mdot
.32812 .7693 Mdot
.43153 .33688 Mdot
.36668 .30193 Mdot
.383 .45172 Mdot
.42818 .61311 Mdot
.64831 .47635 Mdot
.65063 .44238 Mdot
.4624 .38493 Mdot
.67684 .4545 Mdot
.73948 .49574 Mdot
.65852 .48329 Mdot
.2607 .58186 Mdot
.5992 .66114 Mdot
.38087 .51665 Mdot
.68064 .58561 Mdot
.47795 .31178 Mdot
.67495 .71347 Mdot
.41885 .58631 Mdot
.62453 .32569 Mdot
.3515 .46293 Mdot
.56399 .65035 Mdot
.40899 .58378 Mdot
.58687 .65839 Mdot
.65127 .40731 Mdot
.43429 .66149 Mdot
.53783 .66842 Mdot
.51802 .29567 Mdot
.68274 .49245 Mdot
.48544 .22089 Mdot
.33761 .49268 Mdot
.4948 .31638 Mdot
.68795 .45629 Mdot
.41686 .59628 Mdot
.62994 .4033 Mdot
.34705 .55439 Mdot
.27667 .62769 Mdot
.44847 .60775 Mdot
.36611 .69502 Mdot
.57668 .65777 Mdot
.3067 .52797 Mdot
.35686 .32884 Mdot
.43648 .3617 Mdot
.60001 .43631 Mdot
.14436 .48326 Mdot
.38428 .47728 Mdot
.6339 .42883 Mdot
.27882 .67391 Mdot
.3779 .48267 Mdot
.63789 .45687 Mdot
.37163 .50519 Mdot
.46259 .3167 Mdot
.77144 .63817 Mdot
.44573 .36795 Mdot
.63816 .51329 Mdot
.3503 .49346 Mdot
.44968 .64508 Mdot
.4412 .33421 Mdot
.65414 .43218 Mdot
.66801 .48032 Mdot
.50319 .49507 Mdot
.64092 .48965 Mdot
.21801 .35539 Mdot
.65986 .49013 Mdot
.44268 .63339 Mdot
.63736 .41578 Mdot
.67527 .79241 Mdot
.28312 .47197 Mdot
.47941 .33004 Mdot
.45376 .64396 Mdot
.42356 .64822 Mdot
.53819 .72308 Mdot
.31418 .49598 Mdot
.59797 .47189 Mdot
.41153 .59749 Mdot
.71745 .66887 Mdot
.39183 .4497 Mdot
.59872 .43537 Mdot
.45221 .54074 Mdot
.41182 .72819 Mdot
.39931 .5823 Mdot
.69196 .4129 Mdot
.45523 .37957 Mdot
.61886 .48072 Mdot
.4373 .59643 Mdot
.43643 .39025 Mdot
.60667 .49857 Mdot
.43155 .28832 Mdot
.50276 .49225 Mdot
.37535 .44182 Mdot
.6212 .54111 Mdot
.64616 .42583 Mdot
.43029 .60686 Mdot
.47078 .30978 Mdot
.39699 .4563 Mdot
.45138 .32766 Mdot
.1913 .56283 Mdot
.39487 .3969 Mdot
.49599 .2592 Mdot
.524 .67826 Mdot
.36807 .72483 Mdot
.15896 .51179 Mdot
.61714 .78132 Mdot
.66394 .69925 Mdot
.21661 .64233 Mdot
.442 .6087 Mdot
.30018 .69027 Mdot
.43089 .64797 Mdot
.61601 .49564 Mdot
.41188 .63339 Mdot
.15525 .51058 Mdot
.65678 .48379 Mdot
.41761 .63154 Mdot
.6988 .70454 Mdot
.627 .48726 Mdot
.46837 .36407 Mdot
.27223 .27702 Mdot
.6427 .78491 Mdot
.26416 .61916 Mdot
.40149 .65271 Mdot
.63933 .69703 Mdot
.64949 .48522 Mdot
.63923 .41324 Mdot
.44072 .35603 Mdot
.59327 .4385 Mdot
.58438 .6724 Mdot
.5503 .70163 Mdot
.4795 .42099 Mdot
.77926 .5475 Mdot
.67907 .5227 Mdot
.43919 .33994 Mdot
.53206 .21541 Mdot
.46461 .77427 Mdot
.38384 .7202 Mdot
.37026 .51019 Mdot
.26721 .2896 Mdot
.74581 .45814 Mdot
.40204 .51567 Mdot
.459 .57261 Mdot
.46839 .35527 Mdot
.20969 .3566 Mdot
.36268 .47212 Mdot
.68655 .2696 Mdot
.58865 .58527 Mdot
.64809 .43736 Mdot
.35118 .45903 Mdot
.7168 .49348 Mdot
.62161 .80167 Mdot
.70376 .26128 Mdot
.76311 .50997 Mdot
.63076 .51332 Mdot
.50523 .77483 Mdot
.63906 .46948 Mdot
.29664 .29995 Mdot
.66285 .48974 Mdot
.44728 .33459 Mdot
.32071 .29657 Mdot
.49977 .43763 Mdot
.79916 .47101 Mdot
.26734 .47064 Mdot
.57811 .68387 Mdot
.65481 .47816 Mdot
.64612 .43668 Mdot
.58199 .66965 Mdot
.48743 .36507 Mdot
.67857 .49009 Mdot
.66312 .71733 Mdot
.66921 .45875 Mdot
.35767 .47823 Mdot
.74743 .52 Mdot
.49491 .29384 Mdot
.58396 .48611 Mdot
.42197 .33828 Mdot
.37516 .4406 Mdot
.36209 .49323 Mdot
.69135 .50588 Mdot
.33471 .46078 Mdot
.63258 .47716 Mdot
.70939 .25796 Mdot
.4717 .37171 Mdot
.69097 .53608 Mdot
.49475 .33395 Mdot
.56961 .32298 Mdot
.36114 .49757 Mdot
.26001 .55936 Mdot
.70932 .41318 Mdot
.36527 .46861 Mdot
.40213 .39806 Mdot
.66619 .5258 Mdot
.63701 .51951 Mdot
.46058 .79985 Mdot
.41313 .65707 Mdot
.50621 .46818 Mdot
.38267 .49298 Mdot
.65388 .42797 Mdot
.58116 .46851 Mdot
.37006 .44123 Mdot
.6222 .21689 Mdot
.6788 .7424 Mdot
.65957 .48684 Mdot
.4478 .34446 Mdot
.45959 .3368 Mdot
.62708 .51452 Mdot
.61437 .43116 Mdot
.39663 .6142 Mdot
.44598 .65857 Mdot
.405 .65884 Mdot
.50269 .48799 Mdot
.2593 .56893 Mdot
.22145 .4782 Mdot
.33222 .46893 Mdot
.3517 .36297 Mdot
.5186 .7927 Mdot
.57166 .44441 Mdot
.38347 .62442 Mdot
.63011 .43392 Mdot
.62287 .47497 Mdot
.39553 .44742 Mdot
.26286 .63993 Mdot
.73206 .4728 Mdot
.48033 .37244 Mdot
.39399 .47658 Mdot
.59509 .39929 Mdot
.27353 .43168 Mdot
.55046 .65512 Mdot
.37084 .77409 Mdot
.35118 .46692 Mdot
.4705 .3597 Mdot
.36382 .50149 Mdot
.65637 .44504 Mdot
.69952 .43026 Mdot
.4683 .34665 Mdot
.54879 .69649 Mdot
.61672 .40989 Mdot
.63992 .45895 Mdot
.83761 .48069 Mdot
.5416 .78677 Mdot
.26956 .58286 Mdot
.65547 .49546 Mdot
.59027 .49107 Mdot
.56646 .64014 Mdot
.66636 .45354 Mdot
.68336 .46223 Mdot
.79254 .62252 Mdot
.31943 .41616 Mdot
.53318 .68844 Mdot
.66069 .24389 Mdot
.4307 .34183 Mdot
.16076 .44515 Mdot
.42605 .60794 Mdot
.32802 .49996 Mdot
.70291 .72913 Mdot
.41426 .57199 Mdot
.33643 .61176 Mdot
.17155 .4239 Mdot
.50504 .46544 Mdot
.43624 .68849 Mdot
.73386 .43558 Mdot
.67979 .47807 Mdot
.6439 .46839 Mdot
.55414 .66084 Mdot
.47268 .32411 Mdot
.51167 .49119 Mdot
.50441 .18632 Mdot
.63085 .46922 Mdot
.71495 .52519 Mdot
.43124 .23685 Mdot
.41826 .72778 Mdot
.56779 .68625 Mdot
.5516 .69967 Mdot
.65225 .4749 Mdot
.77076 .6595 Mdot
.44476 .3269 Mdot
.65275 .43166 Mdot
.59387 .46764 Mdot
.41226 .65823 Mdot
.48158 .35005 Mdot
.43999 .60393 Mdot
.26141 .53563 Mdot
.19445 .41816 Mdot
.84436 .47374 Mdot
.36256 .49581 Mdot
.35648 .24882 Mdot
.3914 .47261 Mdot
.75455 .55909 Mdot
.42164 .57808 Mdot
.60256 .46398 Mdot
.47365 .31059 Mdot
.64564 .42825 Mdot
.60752 .43816 Mdot
.65022 .43562 Mdot
.57441 .45771 Mdot
.8243 .65307 Mdot
.54413 .68691 Mdot
.60936 .51499 Mdot
.44095 .64446 Mdot
.29292 .28787 Mdot
.3961 .20148 Mdot
.64001 .43906 Mdot
.66359 .47871 Mdot
.48194 .36393 Mdot
.67138 .42845 Mdot
.39341 .45737 Mdot
.46601 .30738 Mdot
.67563 .48928 Mdot
.27582 .2898 Mdot
.66139 .50456 Mdot
.16962 .45392 Mdot
.36863 .50189 Mdot
.39197 .3512 Mdot
.62374 .52406 Mdot
.27894 .62637 Mdot
.50624 .46834 Mdot
.39729 .59759 Mdot
.33437 .45571 Mdot
.429 .63025 Mdot
.57779 .17171 Mdot
.69082 .42681 Mdot
.6401 .49854 Mdot
.58167 .46051 Mdot
.41227 .5993 Mdot
.24742 .36705 Mdot
.28937 .51345 Mdot
.57977 .40888 Mdot
.40529 .60613 Mdot
.4215 .32333 Mdot
.59926 .61661 Mdot
.48482 .32186 Mdot
.55287 .70449 Mdot
.36752 .45135 Mdot
.56558 .69899 Mdot
.26363 .66604 Mdot
.47661 .3466 Mdot
.51075 .36381 Mdot
.42005 .60933 Mdot
.51639 .57908 Mdot
.37268 .84134 Mdot
.56205 .58488 Mdot
.70337 .61111 Mdot
.44227 .35488 Mdot
.62912 .50953 Mdot
.74279 .55126 Mdot
.50935 .56195 Mdot
.42884 .6331 Mdot
.61014 .46148 Mdot
.75949 .65874 Mdot
.39639 .61355 Mdot
.60067 .4341 Mdot
.43063 .65699 Mdot
.36021 .46183 Mdot
.38766 .63053 Mdot
.49203 .37318 Mdot
.67088 .47381 Mdot
.33015 .80831 Mdot
.59575 .69682 Mdot
.65198 .49007 Mdot
.39231 .48106 Mdot
.41726 .41525 Mdot
.61277 .43957 Mdot
.56716 .64499 Mdot
.40816 .62364 Mdot
.55484 .58827 Mdot
.66126 .48783 Mdot
.4116 .60142 Mdot
.44103 .30187 Mdot
.32532 .47235 Mdot
.54474 .40556 Mdot
.27597 .62144 Mdot
.43914 .35488 Mdot
.4237 .53694 Mdot
.36766 .43201 Mdot
.58745 .48829 Mdot
.59236 .44876 Mdot
.45121 .34135 Mdot
.78366 .59939 Mdot
.65657 .41844 Mdot
.60227 .47081 Mdot
.44409 .64015 Mdot
.42427 .62891 Mdot
.77267 .62267 Mdot
.45084 .63058 Mdot
.69732 .42861 Mdot
.45102 .33911 Mdot
.61509 .47535 Mdot
.47938 .36251 Mdot
.66122 .42393 Mdot
.46302 .39841 Mdot
.49168 .36278 Mdot
.295 .49604 Mdot
.61353 .4676 Mdot
.64257 .54248 Mdot
.62814 .42958 Mdot
.6752 .46054 Mdot
.39675 .61889 Mdot
.5516 .68261 Mdot
.70874 .42936 Mdot
.58715 .70097 Mdot
.58504 .65683 Mdot
.43099 .41212 Mdot
.4096 .65663 Mdot
.56135 .66967 Mdot
.44869 .22247 Mdot
.40935 .66014 Mdot
.5645 .65826 Mdot
.38852 .20815 Mdot
.36792 .49725 Mdot
.46023 .37814 Mdot
.62622 .48808 Mdot
.21826 .63073 Mdot
.7751 .38211 Mdot
.38924 .56377 Mdot
.65781 .49056 Mdot
.62409 .43484 Mdot
.49444 .32122 Mdot
.64332 .18249 Mdot
.37687 .62074 Mdot
.63495 .50639 Mdot
.48276 .33553 Mdot
.70583 .22815 Mdot
.44052 .63146 Mdot
.5607 .65847 Mdot
.33291 .48042 Mdot
.41897 .31193 Mdot
.30788 .43476 Mdot
.35781 .44839 Mdot
.39348 .57561 Mdot
.25079 .55163 Mdot
.60182 .48524 Mdot
.38423 .62012 Mdot
.39325 .79184 Mdot
.43689 .257 Mdot
.34628 .42447 Mdot
.63383 .69575 Mdot
.46648 .35613 Mdot
.393 .46079 Mdot
.56277 .69492 Mdot
.43304 .33195 Mdot
.46459 .3686 Mdot
.39012 .43835 Mdot
.59846 .37823 Mdot
.45768 .54349 Mdot
.35748 .48509 Mdot
.47045 .79458 Mdot
.21429 .55973 Mdot
.38278 .62296 Mdot
.58358 .66994 Mdot
.24714 .65061 Mdot
.45852 .32227 Mdot
.26303 .29233 Mdot
.39862 .78746 Mdot
.64842 .48253 Mdot
.56247 .67468 Mdot
.23645 .41547 Mdot
.52535 .17165 Mdot
.37586 .48431 Mdot
.49276 .44485 Mdot
.58388 .68517 Mdot
.68711 .45217 Mdot
.61677 .61676 Mdot
.60725 .47606 Mdot
.37624 .4485 Mdot
.51712 .25853 Mdot
.47163 .3604 Mdot
.39398 .43864 Mdot
.36844 .77407 Mdot
.6307 .47492 Mdot
.61099 .4655 Mdot
.66568 .58359 Mdot
.45127 .31547 Mdot
.39821 .59638 Mdot
.59941 .47881 Mdot
.63753 .4619 Mdot
.7097 .45144 Mdot
.61208 .54083 Mdot
.75889 .67734 Mdot
.62344 .50198 Mdot
.26496 .48328 Mdot
.5873 .49328 Mdot
.61607 .46322 Mdot
.42151 .3401 Mdot
.85697 .50895 Mdot
.26057 .52519 Mdot
.63564 .46511 Mdot
.62782 .50827 Mdot
.38561 .43484 Mdot
.46788 .54144 Mdot
.51123 .57864 Mdot
.54112 .59136 Mdot
.65258 .69959 Mdot
.57102 .4702 Mdot
.48522 .32917 Mdot
.53931 .66208 Mdot
.59837 .49338 Mdot
.48617 .33223 Mdot
.69285 .45439 Mdot
.39645 .61127 Mdot
.41728 .66302 Mdot
.40628 .39211 Mdot
.56632 .66597 Mdot
.68809 .55894 Mdot
.34008 .37225 Mdot
.44678 .63343 Mdot
.63622 .49911 Mdot
.33682 .51491 Mdot
.43452 .59249 Mdot
.4589 .67509 Mdot
.55194 .46858 Mdot
.44653 .3221 Mdot
.45934 .35499 Mdot
.72887 .62082 Mdot
.32089 .58807 Mdot
.82685 .51575 Mdot
.36086 .45969 Mdot
.66195 .41411 Mdot
.34431 .33141 Mdot
.46075 .35799 Mdot
.74256 .55987 Mdot
.56343 .67081 Mdot
.37788 .48452 Mdot
.34393 .6621 Mdot
.48882 .35479 Mdot
.454 .37274 Mdot
.66535 .50978 Mdot
.64149 .44991 Mdot
.67088 .69663 Mdot
.57666 .63043 Mdot
.37956 .44073 Mdot
.58326 .66783 Mdot
.40485 .58345 Mdot
.62369 .5033 Mdot
.4958 .33017 Mdot
.2376 .60415 Mdot
.61979 .50465 Mdot
.39485 .61914 Mdot
.46454 .35222 Mdot
.58226 .66298 Mdot
.57989 .64843 Mdot
.67397 .46088 Mdot
.5378 .22081 Mdot
.36602 .48054 Mdot
.4671 .3631 Mdot
.2742 .44379 Mdot
.63254 .41561 Mdot
.64665 .45409 Mdot
.58432 .5193 Mdot
.39349 .44828 Mdot
.38454 .3214 Mdot
.57775 .69858 Mdot
.47027 .3279 Mdot
.65271 .50128 Mdot
.57079 .65993 Mdot
.37258 .32217 Mdot
.44741 .60514 Mdot
.39034 .63426 Mdot
.57074 .64469 Mdot
.568 .67999 Mdot
.57056 .6465 Mdot
.26378 .28999 Mdot
.50543 .3538 Mdot
.74428 .45358 Mdot
.65476 .41632 Mdot
.7224 .60653 Mdot
.66086 .39317 Mdot
.39849 .46595 Mdot
.41315 .65612 Mdot
.6163 .43322 Mdot
.63017 .51139 Mdot
.60639 .53354 Mdot
.7105 .51988 Mdot
.507 .31045 Mdot
.4796 .34757 Mdot
.68864 .43133 Mdot
.42691 .66105 Mdot
.45179 .13036 Mdot
.18591 .62407 Mdot
.64252 .52672 Mdot
.48622 .56848 Mdot
.49741 .33231 Mdot
.3558 .44145 Mdot
.53369 .60398 Mdot
.35762 .50012 Mdot
.46783 .33181 Mdot
.6224 .50219 Mdot
.34932 .37166 Mdot
.56812 .64272 Mdot
.66795 .43611 Mdot
.38804 .45983 Mdot
.67594 .44494 Mdot
.35637 .44939 Mdot
.18006 .53806 Mdot
.54378 .80021 Mdot
.64128 .47897 Mdot
.60825 .51221 Mdot
.6265 .71873 Mdot
.63706 .43849 Mdot
.61198 .68308 Mdot
.49962 .33708 Mdot
.8039 .51829 Mdot
.68407 .49573 Mdot
.62617 .27416 Mdot
.62923 .41549 Mdot
.73725 .67689 Mdot
.64763 .45083 Mdot
.42084 .73633 Mdot
.67273 .48471 Mdot
.68118 .46539 Mdot
.35224 .49593 Mdot
.38787 .43598 Mdot
.42554 .3467 Mdot
.41223 .5953 Mdot
.17941 .43007 Mdot
.64252 .45741 Mdot
.27397 .62764 Mdot
.35687 .39277 Mdot
.5695 .68085 Mdot
.46625 .32905 Mdot
.64336 .17642 Mdot
.36208 .5063 Mdot
.57449 .76104 Mdot
.74301 .65527 Mdot
.28845 .45633 Mdot
.54515 .61072 Mdot
.31572 .29301 Mdot
.57351 .65546 Mdot
.68481 .44042 Mdot
.25607 .63065 Mdot
.41829 .75214 Mdot
.55081 .46648 Mdot
.38362 .42913 Mdot
.6358 .31606 Mdot
.24433 .62468 Mdot
.58967 .68516 Mdot
.56924 .69969 Mdot
.34367 .45874 Mdot
.3535 .66956 Mdot
.72128 .49084 Mdot
.56645 .67187 Mdot
.44896 .63695 Mdot
.38489 .63959 Mdot
.43717 .57319 Mdot
.45174 .32136 Mdot
.33084 .74677 Mdot
.2747 .40316 Mdot
.36244 .44662 Mdot
.41557 .69041 Mdot
.48947 .29979 Mdot
.50504 .36424 Mdot
.42529 .6165 Mdot
.39542 .62592 Mdot
.46624 .37994 Mdot
.70298 .46516 Mdot
.63128 .53746 Mdot
.63351 .46842 Mdot
.54742 .66646 Mdot
.64671 .4459 Mdot
.40249 .61148 Mdot
.37624 .47969 Mdot
.39963 .63639 Mdot
.3745 .50586 Mdot
.23012 .47261 Mdot
.6631 .43872 Mdot
.67125 .47669 Mdot
.77392 .36831 Mdot
.42847 .3206 Mdot
.25785 .48212 Mdot
.27135 .61216 Mdot
.4332 .64801 Mdot
.68403 .45996 Mdot
.47326 .3065 Mdot
.58038 .70111 Mdot
.77275 .3586 Mdot
.62254 .42537 Mdot
.49711 .33402 Mdot
.64582 .50445 Mdot
.46656 .24133 Mdot
.73271 .73893 Mdot
.45381 .32958 Mdot
.80335 .40813 Mdot
.64346 .50959 Mdot
.38141 .24998 Mdot
.58439 .4604 Mdot
.72356 .65294 Mdot
.65527 .41833 Mdot
.43087 .33876 Mdot
.63175 .46381 Mdot
.45533 .30967 Mdot
.44124 .61952 Mdot
.34283 .45443 Mdot
.44834 .36191 Mdot
.59049 .46171 Mdot
.12144 .60644 Mdot
.37423 .45133 Mdot
.65119 .47698 Mdot
.3373 .48745 Mdot
.47743 .3225 Mdot
.44472 .36473 Mdot
.48684 .17874 Mdot
.266 .53309 Mdot
.36066 .46246 Mdot
.63036 .50421 Mdot
.27768 .3682 Mdot
.61176 .47739 Mdot
.68709 .66777 Mdot
.70395 .47703 Mdot
.64199 .41591 Mdot
.41427 .18885 Mdot
.38856 .44346 Mdot
.82773 .54134 Mdot
.47268 .18113 Mdot
.30071 .27273 Mdot
.41314 .33818 Mdot
.58825 .68967 Mdot
.21535 .34657 Mdot
.26071 .56342 Mdot
.40818 .6028 Mdot
.6218 .43122 Mdot
.48244 .28808 Mdot
.36455 .4876 Mdot
.54857 .68098 Mdot
.64214 .47883 Mdot
.39487 .62912 Mdot
.64262 .75973 Mdot
.34735 .50676 Mdot
.46116 .32261 Mdot
.49 .36639 Mdot
.77633 .31046 Mdot
.65515 .49773 Mdot
.6741 .47725 Mdot
.37166 .44927 Mdot
.40724 .26523 Mdot
.57495 .65394 Mdot
.68297 .72159 Mdot
.36211 .46116 Mdot
.49723 .5211 Mdot
.47844 .33541 Mdot
.62642 .43399 Mdot
.23441 .37786 Mdot
.49694 .76944 Mdot
.70423 .29737 Mdot
.55012 .66088 Mdot
.68227 .66532 Mdot
.43028 .34079 Mdot
.38391 .47036 Mdot
.31206 .61046 Mdot
.57335 .43071 Mdot
.62584 .43785 Mdot
.6839 .65907 Mdot
.50579 .42324 Mdot
.75996 .51218 Mdot
.623 .42305 Mdot
.51175 .44425 Mdot
.64405 .42016 Mdot
.58686 .41454 Mdot
.70381 .44353 Mdot
.65437 .45829 Mdot
.49742 .33362 Mdot
.55721 .44398 Mdot
.39904 .60147 Mdot
.75118 .48869 Mdot
.51124 .52932 Mdot
.65536 .48834 Mdot
.61076 .48601 Mdot
.70545 .32174 Mdot
.4031 .52082 Mdot
.45337 .36161 Mdot
.48609 .38435 Mdot
.33001 .46984 Mdot
.61823 .53654 Mdot
.40962 .59245 Mdot
.63992 .39466 Mdot
.39765 .62289 Mdot
.48713 .32098 Mdot
.43843 .64188 Mdot
.33329 .47139 Mdot
.38466 .63546 Mdot
.2588 .56966 Mdot
.38429 .48282 Mdot
.43815 .32959 Mdot
.66964 .46559 Mdot
.39208 .48094 Mdot
.66334 .59544 Mdot
.54821 .66535 Mdot
.47107 .17527 Mdot
.67349 .49456 Mdot
.31822 .42032 Mdot
.4249 .29207 Mdot
.39868 .63288 Mdot
.76822 .68646 Mdot
.48785 .36653 Mdot
.53408 .68709 Mdot
.48161 .31382 Mdot
.49808 .80527 Mdot
.55646 .68257 Mdot
.37823 .21103 Mdot
.32737 .66744 Mdot
.59935 .63287 Mdot
.70108 .47156 Mdot
.59944 .59962 Mdot
.39342 .58887 Mdot
.36541 .48797 Mdot
.32642 .61703 Mdot
.68231 .46026 Mdot
.59093 .78231 Mdot
.43027 .3706 Mdot
.40939 .59621 Mdot
.37986 .46685 Mdot
.39748 .4622 Mdot
.6054 .4352 Mdot
.46135 .69389 Mdot
.65487 .42526 Mdot
.30905 .56854 Mdot
.65976 .68915 Mdot
.71084 .50847 Mdot
.6579 .48275 Mdot
.43323 .60925 Mdot
.64509 .50451 Mdot
.52336 .6662 Mdot
.325 .7517 Mdot
.59595 .42786 Mdot
.26743 .60285 Mdot
.57974 .71424 Mdot
.47163 .34651 Mdot
.7146 .48456 Mdot
.26874 .56553 Mdot
.64951 .50107 Mdot
.7096 .79744 Mdot
.56697 .65888 Mdot
.27761 .64129 Mdot
.57776 .46358 Mdot
.59447 .45741 Mdot
.53976 .51862 Mdot
.48382 .41111 Mdot
.50451 .77021 Mdot
.62883 .44371 Mdot
.64873 .64503 Mdot
.34384 .46448 Mdot
.64701 .42391 Mdot
.64596 .47053 Mdot
.61159 .36812 Mdot
.39482 .46806 Mdot
.42146 .65128 Mdot
.40941 .57521 Mdot
.40363 .6644 Mdot
.526 .67067 Mdot
.48933 .46609 Mdot
.72905 .58202 Mdot
.63197 .78564 Mdot
.53452 .66776 Mdot
.6694 .50283 Mdot
.58648 .72911 Mdot
.61203 .49644 Mdot
.56279 .69228 Mdot
.39293 .47238 Mdot
.45439 .36387 Mdot
.35434 .31265 Mdot
.3784 .61073 Mdot
.59518 .43897 Mdot
.58671 .66821 Mdot
.44052 .32782 Mdot
.55129 .62829 Mdot
.47292 .33845 Mdot
.36642 .46274 Mdot
.32739 .48967 Mdot
.5531 .6877 Mdot
.48868 .32705 Mdot
.41412 .47989 Mdot
.53001 .17428 Mdot
.70471 .43854 Mdot
.31974 .46352 Mdot
.43699 .30924 Mdot
.47496 .38287 Mdot
.43691 .31748 Mdot
.67549 .45104 Mdot
.48407 .5661 Mdot
.68673 .50563 Mdot
.37852 .4412 Mdot
.42686 .65674 Mdot
.62114 .74111 Mdot
.22502 .52448 Mdot
.50767 .67658 Mdot
.66754 .41626 Mdot
.62806 .47251 Mdot
.6519 .47483 Mdot
.67185 .51 Mdot
.29903 .57324 Mdot
.64175 .42883 Mdot
.34817 .4944 Mdot
.40469 .62133 Mdot
.68646 .44297 Mdot
.42538 .57584 Mdot
.28306 .32566 Mdot
.53502 .6724 Mdot
.48436 .44985 Mdot
.12013 .52238 Mdot
.4364 .33836 Mdot
.44881 .61878 Mdot
.41068 .60334 Mdot
.56062 .64793 Mdot
.36187 .48258 Mdot
.47547 .33404 Mdot
.70259 .67723 Mdot
.57967 .65131 Mdot
.63397 .46315 Mdot
.50105 .60058 Mdot
.57609 .78031 Mdot
.67818 .43161 Mdot
.60444 .44996 Mdot
.44389 .59863 Mdot
.38025 .70513 Mdot
.35889 .80614 Mdot
.72249 .56172 Mdot
.55282 .68544 Mdot
.54276 .69012 Mdot
.45898 .3807 Mdot
.6726 .52026 Mdot
.37603 .44142 Mdot
.76165 .49721 Mdot
.43412 .42699 Mdot
.70273 .55367 Mdot
.5328 .41475 Mdot
.62599 .42549 Mdot
.60853 .20413 Mdot
.63017 .47656 Mdot
.50276 .33917 Mdot
.46903 .3157 Mdot
.44231 .34712 Mdot
.36668 .4855 Mdot
.59127 .32881 Mdot
.34706 .49097 Mdot
.12781 .53813 Mdot
.43036 .34796 Mdot
.29494 .62163 Mdot
.43318 .61311 Mdot
.62473 .52523 Mdot
.58069 .66217 Mdot
.38931 .42323 Mdot
.59199 .50872 Mdot
.77287 .66114 Mdot
.40495 .59854 Mdot
.4359 .33373 Mdot
.32604 .28477 Mdot
.15718 .54374 Mdot
.52242 .58897 Mdot
.61982 .3911 Mdot
.59005 .59431 Mdot
.57248 .68065 Mdot
.7092 .30078 Mdot
.58568 .67536 Mdot
.38926 .46677 Mdot
.66757 .47461 Mdot
.66406 .46426 Mdot
.65035 .41976 Mdot
.65225 .43313 Mdot
.35163 .44334 Mdot
.62553 .41359 Mdot
.6752 .79244 Mdot
.4271 .665 Mdot
.51213 .28414 Mdot
.57158 .65747 Mdot
.36489 .4318 Mdot
.40379 .61951 Mdot
.3728 .56315 Mdot
.69094 .58374 Mdot
.6606 .48656 Mdot
.61906 .43163 Mdot
.56964 .76676 Mdot
.62342 .42228 Mdot
.66967 .39372 Mdot
.41047 .60161 Mdot
.51149 .6829 Mdot
.53948 .6898 Mdot
.555 .6966 Mdot
.37929 .49232 Mdot
.48558 .3203 Mdot
.55804 .66461 Mdot
.44209 .62556 Mdot
.66903 .41612 Mdot
.59545 .478 Mdot
.43497 .31261 Mdot
.40775 .79234 Mdot
.58769 .68533 Mdot
.30584 .30194 Mdot
.46836 .31083 Mdot
.50502 .32316 Mdot
.62433 .43885 Mdot
.56715 .52473 Mdot
.42205 .30489 Mdot
.53359 .66596 Mdot
.35892 .43503 Mdot
.54823 .5972 Mdot
.3834 .44858 Mdot
.46793 .31931 Mdot
.60203 .49559 Mdot
.46295 .31505 Mdot
.6574 .49457 Mdot
.13227 .44377 Mdot
.65832 .45767 Mdot
.63 .79149 Mdot
.71667 .63566 Mdot
.41446 .61695 Mdot
.40747 .41946 Mdot
.42363 .60753 Mdot
.46565 .31041 Mdot
.59601 .48648 Mdot
.56955 .70156 Mdot
.33675 .2426 Mdot
.49545 .3029 Mdot
.3926 .6139 Mdot
.38236 .64347 Mdot
.39021 .47465 Mdot
.67598 .42542 Mdot
.63 .43531 Mdot
.41933 .631 Mdot
.71491 .50593 Mdot
.49342 .35021 Mdot
.66589 .48006 Mdot
.62163 .4669 Mdot
.4163 .61574 Mdot
.54943 .17099 Mdot
.48171 .40428 Mdot
.66111 .4691 Mdot
.31005 .66432 Mdot
.39915 .46235 Mdot
.69871 .4827 Mdot
.58926 .49999 Mdot
.56771 .67755 Mdot
.54296 .35946 Mdot
.30845 .73198 Mdot
.38571 .49258 Mdot
.423 .60113 Mdot
.65539 .49887 Mdot
.43129 .60746 Mdot
.59295 .4684 Mdot
.52945 .38129 Mdot
.39034 .60355 Mdot
.59817 .46361 Mdot
.68618 .51587 Mdot
.45287 .3143 Mdot
.62224 .42827 Mdot
.71445 .34537 Mdot
.42611 .58555 Mdot
.59582 .45241 Mdot
.53582 .22288 Mdot
.3529 .4813 Mdot
.68158 .51871 Mdot
.54058 .66368 Mdot
.70348 .67888 Mdot
.31055 .39246 Mdot
.26718 .64469 Mdot
.53739 .67727 Mdot
.67467 .44144 Mdot
.38986 .6524 Mdot
.35027 .45301 Mdot
.65318 .7755 Mdot
.68245 .44225 Mdot
.37683 .44904 Mdot
.37731 .47762 Mdot
.54925 .65698 Mdot
.82985 .43106 Mdot
.57538 .46211 Mdot
.64071 .44002 Mdot
.68015 .35891 Mdot
.44839 .29659 Mdot
.65343 .44939 Mdot
.64838 .51187 Mdot
.34459 .49259 Mdot
.67022 .39252 Mdot
.6637 .31114 Mdot
.70742 .69821 Mdot
.4001 .47012 Mdot
.54591 .57193 Mdot
.38208 .61185 Mdot
.57438 .66299 Mdot
.46581 .3443 Mdot
.5879 .67529 Mdot
.38974 .64015 Mdot
.66419 .5063 Mdot
.3446 .49947 Mdot
.7505 .37758 Mdot
.34448 .45721 Mdot
.27024 .65192 Mdot
.44607 .29915 Mdot
.32621 .33814 Mdot
.76415 .74244 Mdot
.2654 .41222 Mdot
.40074 .52145 Mdot
.56908 .6809 Mdot
.37243 .57724 Mdot
.62322 .46909 Mdot
.72784 .3168 Mdot
.67404 .46546 Mdot
.54068 .22702 Mdot
.44618 .64681 Mdot
.40503 .65895 Mdot
.66466 .47221 Mdot
.66674 .68413 Mdot
.35149 .45059 Mdot
.39122 .44825 Mdot
.59954 .44492 Mdot
.36487 .46851 Mdot
.63831 .44863 Mdot
.39897 .61647 Mdot
.83004 .57353 Mdot
.63782 .47272 Mdot
.62121 .51554 Mdot
.31019 .44327 Mdot
.42982 .19241 Mdot
.329 .71272 Mdot
.66916 .23388 Mdot
.16717 .57275 Mdot
.36599 .46822 Mdot
.68788 .50678 Mdot
.54922 .57269 Mdot
.42128 .57302 Mdot
.41458 .48571 Mdot
.66429 .4544 Mdot
.66741 .45376 Mdot
.68144 .46904 Mdot
.61019 .4668 Mdot
.70776 .29377 Mdot
.74779 .42484 Mdot
.54692 .26717 Mdot
.61065 .43539 Mdot
.61806 .59878 Mdot
.37749 .49699 Mdot
.43633 .38308 Mdot
.57894 .63596 Mdot
.6262 .42562 Mdot
.74762 .44169 Mdot
.3968 .44125 Mdot
.12813 .53976 Mdot
.38651 .48295 Mdot
.42395 .64777 Mdot
.35477 .44305 Mdot
.64255 .49067 Mdot
.45903 .3373 Mdot
.5259 .55598 Mdot
.30931 .53213 Mdot
.40734 .60296 Mdot
.65236 .49008 Mdot
.28671 .61487 Mdot
.40053 .60221 Mdot
.27928 .33059 Mdot
.46002 .34335 Mdot
.64875 .63664 Mdot
.46745 .31469 Mdot
.59765 .46546 Mdot
.60004 .47114 Mdot
.336 .44272 Mdot
.34017 .45872 Mdot
.46975 .31479 Mdot
.84083 .44645 Mdot
.58883 .66167 Mdot
.44216 .34112 Mdot
.61386 .40525 Mdot
.44894 .49812 Mdot
.45426 .34236 Mdot
.50652 .66114 Mdot
.37072 .48985 Mdot
.43804 .36927 Mdot
.58255 .42208 Mdot
.41497 .78009 Mdot
.54423 .65174 Mdot
.45167 .66728 Mdot
.50159 .61603 Mdot
.43197 .59034 Mdot
.33925 .45091 Mdot
.42063 .60741 Mdot
.34191 .46835 Mdot
.32906 .39828 Mdot
.73966 .51135 Mdot
.33529 .51145 Mdot
.34205 .44943 Mdot
.41985 .60993 Mdot
.66949 .48269 Mdot
.515 .61627 Mdot
.69256 .49896 Mdot
.57262 .45179 Mdot
.34609 .4674 Mdot
.43278 .33446 Mdot
.48121 .37805 Mdot
.61707 .61125 Mdot
.49673 .35884 Mdot
.3967 .62356 Mdot
.70514 .75841 Mdot
.26158 .62282 Mdot
.35847 .45502 Mdot
.36741 .43426 Mdot
.6107 .47931 Mdot
.42913 .63108 Mdot
.4364 .60898 Mdot
.39137 .46391 Mdot
.67541 .54885 Mdot
.64678 .52302 Mdot
.49208 .38013 Mdot
.43319 .35885 Mdot
.45142 .33436 Mdot
.44013 .31539 Mdot
.65518 .28256 Mdot
.37475 .48991 Mdot
.43597 .32681 Mdot
.59812 .45649 Mdot
.66565 .45304 Mdot
.53632 .58294 Mdot
.54783 .69324 Mdot
.69274 .45755 Mdot
.70219 .44261 Mdot
.62197 .43741 Mdot
.3888 .63039 Mdot
.56683 .49551 Mdot
.39188 .60062 Mdot
.4166 .66778 Mdot
.44027 .66065 Mdot
.26043 .56604 Mdot
.61956 .65656 Mdot
.19272 .60801 Mdot
.63635 .50667 Mdot
.4243 .25321 Mdot
.43499 .62466 Mdot
.76977 .67558 Mdot
.38566 .31561 Mdot
.6846 .452 Mdot
.47541 .76819 Mdot
.41963 .62847 Mdot
.49421 .36319 Mdot
.66234 .45524 Mdot
.42855 .67138 Mdot
.54306 .65657 Mdot
.67319 .41126 Mdot
.41711 .57773 Mdot
.48669 .3264 Mdot
.5555 .63728 Mdot
.43055 .35655 Mdot
.44211 .65799 Mdot
.6842 .51706 Mdot
.41559 .87196 Mdot
.3744 .63231 Mdot
.44104 .21608 Mdot
.42746 .39282 Mdot
.66748 .48058 Mdot
.44503 .60771 Mdot
.46173 .29779 Mdot
.3286 .4653 Mdot
.44487 .43942 Mdot
.46729 .37144 Mdot
.40245 .6574 Mdot
.42327 .58079 Mdot
.40943 .60156 Mdot
.47724 .35231 Mdot
.62501 .51464 Mdot
.48014 .35821 Mdot
.35706 .44137 Mdot
.62083 .48367 Mdot
.15667 .50754 Mdot
.42505 .25538 Mdot
.4691 .31248 Mdot
.41455 .65056 Mdot
.56426 .64118 Mdot
.63808 .48059 Mdot
.47299 .2162 Mdot
.66726 .49166 Mdot
.35229 .45568 Mdot
.80167 .59436 Mdot
.74752 .36594 Mdot
.65253 .41655 Mdot
.61038 .47839 Mdot
.38549 .44236 Mdot
.65011 .48399 Mdot
.66065 .4191 Mdot
.26257 .55514 Mdot
.48336 .34683 Mdot
.62919 .46502 Mdot
.43837 .65183 Mdot
.24512 .56036 Mdot
.65706 .51958 Mdot
.5249 .72127 Mdot
.65907 .65222 Mdot
.8105 .54167 Mdot
.67513 .46793 Mdot
.71486 .55622 Mdot
.60987 .45868 Mdot
.66571 .4359 Mdot
.61753 .49459 Mdot
.72392 .29343 Mdot
.38903 .60975 Mdot
.40768 .6093 Mdot
.54012 .65488 Mdot
.6566 .65089 Mdot
.56434 .67563 Mdot
.36901 .49267 Mdot
.48848 .70421 Mdot
.39085 .60323 Mdot
.48464 .32247 Mdot
.66668 .43257 Mdot
.37416 .6329 Mdot
.63011 .43256 Mdot
.64316 .49232 Mdot
.41549 .58943 Mdot
.38524 .60193 Mdot
.2726 .64161 Mdot
.53709 .6686 Mdot
.44481 .35412 Mdot
.69634 .46249 Mdot
.58545 .66315 Mdot
.60723 .50442 Mdot
.72596 .60205 Mdot
.44525 .3514 Mdot
.4831 .35036 Mdot
.48274 .37523 Mdot
.66408 .50608 Mdot
.64328 .4873 Mdot
.34536 .48866 Mdot
.48053 .31477 Mdot
.35414 .47953 Mdot
.50476 .50353 Mdot
.55475 .73732 Mdot
.66442 .45437 Mdot
.31563 .29898 Mdot
.57696 .66962 Mdot
.40717 .64028 Mdot
.5924 .75977 Mdot
.54144 .65283 Mdot
.66046 .49245 Mdot
.42994 .60203 Mdot
.55921 .69361 Mdot
.54497 .44474 Mdot
.22297 .67788 Mdot
.57101 .6385 Mdot
.59839 .45316 Mdot
.67641 .39048 Mdot
.68782 .23875 Mdot
.54412 .64729 Mdot
.33435 .48585 Mdot
.66595 .50453 Mdot
.44201 .28502 Mdot
.58585 .68676 Mdot
.26079 .4738 Mdot
.41069 .62479 Mdot
.35538 .75581 Mdot
.57754 .49813 Mdot
.75995 .36435 Mdot
.57971 .68497 Mdot
.47329 .33151 Mdot
.43812 .39048 Mdot
.61804 .44484 Mdot
.54506 .64652 Mdot
.402 .46447 Mdot
.40793 .63039 Mdot
.25958 .52853 Mdot
.47638 .35458 Mdot
.3092 .32892 Mdot
.40773 .64953 Mdot
.30042 .31363 Mdot
.7533 .65914 Mdot
.65396 .53497 Mdot
.68043 .24143 Mdot
.33737 .64072 Mdot
.67573 .50037 Mdot
.5875 .65249 Mdot
.38773 .48921 Mdot
.3333 .4888 Mdot
.36621 .45952 Mdot
.34832 .39367 Mdot
.53553 .5926 Mdot
.45273 .62919 Mdot
.35546 .54228 Mdot
.57182 .66267 Mdot
.62948 .58929 Mdot
.58914 .47072 Mdot
.62983 .47245 Mdot
.67656 .42472 Mdot
.63725 .42253 Mdot
.61473 .45518 Mdot
.36054 .47669 Mdot
.31582 .41089 Mdot
.55117 .58705 Mdot
.44917 .34754 Mdot
.45777 .68764 Mdot
.43348 .61443 Mdot
.45442 .63866 Mdot
.54835 .68882 Mdot
.29724 .30178 Mdot
.42446 .57602 Mdot
.4365 .64578 Mdot
.685 .48141 Mdot
.48838 .35389 Mdot
.59801 .40312 Mdot
.60271 .46967 Mdot
.40131 .62968 Mdot
.5314 .51664 Mdot
.68645 .31755 Mdot
.55807 .48197 Mdot
.54679 .71381 Mdot
.48296 .5588 Mdot
.55814 .64087 Mdot
.59189 .48437 Mdot
.7761 .66482 Mdot
.38742 .6365 Mdot
.4277 .64179 Mdot
.57973 .68178 Mdot
.52295 .32855 Mdot
.46717 .35254 Mdot
.36612 .56716 Mdot
.33633 .4819 Mdot
.60554 .4879 Mdot
.6396 .75603 Mdot
.48854 .27454 Mdot
.46267 .69743 Mdot
.36586 .45625 Mdot
.43842 .61503 Mdot
.66384 .41669 Mdot
.59923 .45304 Mdot
.57915 .6752 Mdot
.19336 .48129 Mdot
.68828 .42446 Mdot
.28899 .27865 Mdot
.54161 .80209 Mdot
.41502 .7888 Mdot
.62608 .43785 Mdot
.48184 .34766 Mdot
.42163 .57772 Mdot
.58333 .67003 Mdot
.6 .41658 Mdot
.21282 .65356 Mdot
.42785 .33146 Mdot
.38673 .47039 Mdot
.53024 .54586 Mdot
.53176 .60303 Mdot
.67744 .49193 Mdot
.67277 .46537 Mdot
.67021 .44478 Mdot
.27362 .72984 Mdot
.39059 .6258 Mdot
.49313 .32529 Mdot
.54446 .66608 Mdot
.50013 .35276 Mdot
.41211 .61088 Mdot
.31261 .33704 Mdot
.67093 .48701 Mdot
.42801 .32832 Mdot
.47197 .3335 Mdot
.38834 .47861 Mdot
.32564 .47364 Mdot
.51573 .52417 Mdot
.65632 .45661 Mdot
.37289 .62226 Mdot
.44303 .31998 Mdot
.50438 .60136 Mdot
.55826 .68278 Mdot
.35999 .49643 Mdot
.61454 .43298 Mdot
.38577 .62112 Mdot
.62424 .41363 Mdot
.45825 .3575 Mdot
.43721 .64429 Mdot
.27485 .63552 Mdot
.53949 .68492 Mdot
.6572 .44174 Mdot
.53496 .64943 Mdot
.42319 .60071 Mdot
.62114 .46891 Mdot
.35168 .25823 Mdot
.55949 .71901 Mdot
.29424 .52337 Mdot
.44836 .6475 Mdot
.2754 .62588 Mdot
.46864 .37653 Mdot
.37433 .38155 Mdot
.4251 .64433 Mdot
.31794 .28629 Mdot
.20346 .51147 Mdot
.68234 .42606 Mdot
.4556 .32429 Mdot
.35386 .61721 Mdot
.15644 .44325 Mdot
.54626 .17713 Mdot
.64992 .47552 Mdot
.45128 .63238 Mdot
.57701 .68282 Mdot
.35646 .456 Mdot
.53139 .72586 Mdot
.54802 .71617 Mdot
.37667 .62575 Mdot
.61712 .4953 Mdot
.47759 .32555 Mdot
.37105 .48469 Mdot
.31401 .39534 Mdot
.44418 .63657 Mdot
.41866 .65593 Mdot
.66166 .41641 Mdot
.56373 .66976 Mdot
.50735 .20319 Mdot
.39941 .61314 Mdot
.56558 .77389 Mdot
.393 .58168 Mdot
.58746 .66235 Mdot
.60649 .45451 Mdot
.60916 .61351 Mdot
.68518 .50134 Mdot
.40561 .21654 Mdot
.42628 .61114 Mdot
.45277 .35632 Mdot
.67819 .45802 Mdot
.7272 .6767 Mdot
.40402 .63333 Mdot
.48843 .56928 Mdot
.411 .73477 Mdot
.37285 .49001 Mdot
.59225 .7613 Mdot
.64918 .44371 Mdot
.35037 .45194 Mdot
.57627 .67074 Mdot
.65754 .4641 Mdot
.64034 .48721 Mdot
.49116 .31689 Mdot
.39025 .46178 Mdot
.20414 .54827 Mdot
.39285 .43705 Mdot
.36571 .50167 Mdot
.50612 .33903 Mdot
.62846 .45248 Mdot
.42339 .64892 Mdot
.42128 .62982 Mdot
.58141 .43453 Mdot
.79819 .6552 Mdot
.46859 .35518 Mdot
.40735 .68731 Mdot
.2956 .74932 Mdot
.66981 .53227 Mdot
.60236 .76056 Mdot
.19798 .47003 Mdot
.39676 .484 Mdot
.60382 .44001 Mdot
.48224 .32339 Mdot
.37816 .56159 Mdot
.41872 .6546 Mdot
.61752 .51007 Mdot
.37274 .47826 Mdot
.5428 .65556 Mdot
.41213 .5842 Mdot
.46581 .69246 Mdot
.66053 .43553 Mdot
.47256 .77079 Mdot
.44319 .60948 Mdot
.23412 .30565 Mdot
.35917 .58803 Mdot
.45121 .32737 Mdot
.63986 .49214 Mdot
.48056 .37208 Mdot
.54373 .67196 Mdot
.52711 .54357 Mdot
.37455 .47941 Mdot
.71578 .39943 Mdot
.62333 .83163 Mdot
.41217 .6005 Mdot
.49943 .33591 Mdot
.64976 .41596 Mdot
.53203 .47296 Mdot
.64289 .4438 Mdot
.71281 .41233 Mdot
.582 .71882 Mdot
.34699 .47118 Mdot
.34324 .46226 Mdot
.62095 .4743 Mdot
.57582 .65114 Mdot
.43941 .6204 Mdot
.40881 .63395 Mdot
.36015 .18558 Mdot
.30096 .49032 Mdot
.6763 .69328 Mdot
.66565 .45008 Mdot
.38698 .64555 Mdot
.22991 .53288 Mdot
.3704 .44997 Mdot
.58665 .46065 Mdot
.40883 .59318 Mdot
.43821 .78 Mdot
.73548 .65042 Mdot
.613 .45209 Mdot
.57687 .48412 Mdot
.3359 .48385 Mdot
.64852 .5813 Mdot
.43527 .66078 Mdot
.70563 .47328 Mdot
.33898 .5091 Mdot
.78984 .59588 Mdot
.36791 .78559 Mdot
.44435 .35374 Mdot
.39068 .71557 Mdot
.36049 .47774 Mdot
.56722 .46214 Mdot
.5655 .65408 Mdot
.4043 .58217 Mdot
.38854 .62104 Mdot
.63058 .50244 Mdot
.62857 .41337 Mdot
.61663 .7257 Mdot
.49831 .35029 Mdot
.37699 .49649 Mdot
.6733 .47383 Mdot
.35311 .30129 Mdot
.64729 .41962 Mdot
.34693 .4871 Mdot
.40158 .87485 Mdot
.69565 .45329 Mdot
.64012 .44234 Mdot
.50789 .20101 Mdot
.46502 .37138 Mdot
.50325 .34616 Mdot
.58621 .80376 Mdot
.66507 .4493 Mdot
.58133 .7656 Mdot
.44636 .35821 Mdot
.46557 .35589 Mdot
.27329 .54298 Mdot
.63611 .47736 Mdot
.77258 .45024 Mdot
.35629 .45035 Mdot
.35896 .5016 Mdot
.47808 .35811 Mdot
.69395 .44136 Mdot
.36909 .50756 Mdot
.65926 .25463 Mdot
.4296 .62943 Mdot
.79052 .64559 Mdot
.46479 .36507 Mdot
.50051 .44372 Mdot
.36625 .45348 Mdot
.12711 .53559 Mdot
.42469 .56813 Mdot
.67036 .48103 Mdot
.66126 .44244 Mdot
.57672 .66681 Mdot
.69462 .45287 Mdot
.40984 .66145 Mdot
.36438 .46856 Mdot
.49847 .24036 Mdot
.44187 .34616 Mdot
.64853 .45252 Mdot
.29085 .31508 Mdot
.24732 .45115 Mdot
.33685 .70362 Mdot
.47128 .34547 Mdot
.45201 .32238 Mdot
.43268 .66054 Mdot
.45046 .62851 Mdot
.62266 .44903 Mdot
.38621 .44526 Mdot
.47827 .31385 Mdot
.34373 .47955 Mdot
.38799 .63684 Mdot
.42653 .65062 Mdot
.38744 .60814 Mdot
.68773 .4124 Mdot
.43888 .64676 Mdot
.49437 .67634 Mdot
.30203 .33808 Mdot
.50601 .3628 Mdot
.46539 .8257 Mdot
.32234 .39093 Mdot
.41688 .40546 Mdot
.5784 .69721 Mdot
.42307 .60009 Mdot
.37175 .43471 Mdot
.61244 .47366 Mdot
.62468 .43137 Mdot
.47052 .64697 Mdot
.36416 .43968 Mdot
.54657 .67859 Mdot
.35137 .44901 Mdot
.54958 .65638 Mdot
.43099 .75697 Mdot
.68095 .43109 Mdot
.59619 .47644 Mdot
.35995 .47147 Mdot
.43909 .64385 Mdot
.40667 .61708 Mdot
.56386 .6374 Mdot
.52199 .40817 Mdot
.40121 .60094 Mdot
.4626 .36357 Mdot
.64124 .26779 Mdot
.42488 .58103 Mdot
.65909 .4526 Mdot
.73497 .57562 Mdot
.74646 .3431 Mdot
.67074 .51088 Mdot
.26829 .54624 Mdot
.79214 .41474 Mdot
.68035 .44936 Mdot
.79738 .39393 Mdot
.27651 .62084 Mdot
.47603 .37159 Mdot
.4442 .65061 Mdot
.44954 .6072 Mdot
.71754 .43541 Mdot
.59025 .64614 Mdot
.59185 .4217 Mdot
.4584 .36993 Mdot
.42105 .34758 Mdot
.4568 .79593 Mdot
.4354 .21549 Mdot
.57271 .68799 Mdot
.55403 .69406 Mdot
.42203 .64301 Mdot
.52287 .1557 Mdot
.5599 .45527 Mdot
.55071 .68398 Mdot
.72042 .53123 Mdot
.61768 .49754 Mdot
.69404 .6487 Mdot
.54413 .77515 Mdot
.47957 .35215 Mdot
.60312 .60392 Mdot
.41596 .64428 Mdot
.49347 .35975 Mdot
.36113 .30776 Mdot
.69333 .47159 Mdot
.44443 .34961 Mdot
.34273 .4817 Mdot
.33746 .60125 Mdot
.44427 .36368 Mdot
.73258 .58499 Mdot
.39207 .45906 Mdot
.50261 .59575 Mdot
.63184 .61993 Mdot
.89224 .55671 Mdot
.3631 .47467 Mdot
.39993 .59074 Mdot
.42036 .63012 Mdot
.41029 .63533 Mdot
.49755 .35511 Mdot
.43469 .60755 Mdot
.49938 .34362 Mdot
.62135 .19346 Mdot
.53323 .4031 Mdot
.55439 .68754 Mdot
.26525 .52697 Mdot
.46641 .32414 Mdot
.73813 .72873 Mdot
.7096 .78567 Mdot
.60594 .43698 Mdot
.38144 .43186 Mdot
.56158 .69116 Mdot
.31286 .24755 Mdot
.57062 .67564 Mdot
.58847 .62589 Mdot
.80283 .60491 Mdot
.64165 .45273 Mdot
.63314 .32952 Mdot
.56141 .70059 Mdot
.4777 .33719 Mdot
.62334 .47086 Mdot
.41038 .51242 Mdot
.56933 .67194 Mdot
.54965 .65217 Mdot
.62245 .45711 Mdot
.43607 .33304 Mdot
.4152 .64752 Mdot
.33515 .46275 Mdot
.53439 .69118 Mdot
.47646 .39491 Mdot
.68391 .49268 Mdot
.65911 .50046 Mdot
.51512 .57612 Mdot
.52196 .6399 Mdot
.36646 .46869 Mdot
.76343 .33967 Mdot
.4501 .63635 Mdot
.35719 .64298 Mdot
.54238 .79438 Mdot
.26676 .5636 Mdot
.42499 .61249 Mdot
.42316 .60327 Mdot
.61631 .45189 Mdot
.51548 .64972 Mdot
.81046 .56778 Mdot
.41121 .48052 Mdot
.42419 .57866 Mdot
.40667 .63106 Mdot
.42283 .363 Mdot
.46973 .80074 Mdot
.60447 .41408 Mdot
.38221 .49782 Mdot
.38701 .6188 Mdot
.52731 .37551 Mdot
.56452 .66596 Mdot
.74857 .70514 Mdot
.68244 .43408 Mdot
.67074 .47703 Mdot
.37642 .46448 Mdot
.34816 .49237 Mdot
.39122 .54466 Mdot
.52416 .8 Mdot
.78243 .39898 Mdot
.2972 .41427 Mdot
.56121 .37921 Mdot
.42561 .36468 Mdot
.46852 .31238 Mdot
.26937 .47761 Mdot
.39464 .43813 Mdot
.6795 .45283 Mdot
.48101 .31774 Mdot
.32794 .65604 Mdot
.43391 .25873 Mdot
.68319 .67053 Mdot
.61418 .74901 Mdot
.65665 .49349 Mdot
.48874 .34514 Mdot
.46602 .37016 Mdot
.46064 .30449 Mdot
.27748 .61649 Mdot
.62933 .44338 Mdot
.65763 .48436 Mdot
.6723 .43367 Mdot
.65894 .54675 Mdot
.64735 .42983 Mdot
.36974 .39338 Mdot
.49843 .52769 Mdot
.53281 .30814 Mdot
.70667 .46327 Mdot
.38508 .50145 Mdot
.67584 .49438 Mdot
.57296 .64972 Mdot
.6141 .48936 Mdot
.68661 .67225 Mdot
.38315 .4547 Mdot
.45695 .40654 Mdot
.32983 .39431 Mdot
.68319 .4763 Mdot
.53283 .67455 Mdot
.44133 .41972 Mdot
.17692 .53844 Mdot
.58212 .63365 Mdot
.46341 .36369 Mdot
.42949 .62271 Mdot
.37173 .43566 Mdot
.43074 .64713 Mdot
.68505 .41184 Mdot
.27377 .48152 Mdot
.24182 .40776 Mdot
.5086 .48948 Mdot
.63257 .42419 Mdot
.58759 .5156 Mdot
.46254 .35937 Mdot
.42941 .60121 Mdot
.47944 .27718 Mdot
.67593 .45453 Mdot
.54801 .66342 Mdot
.57222 .66844 Mdot
.42046 .48631 Mdot
.21018 .38234 Mdot
.39028 .37594 Mdot
.3738 .46445 Mdot
.39705 .6131 Mdot
.58609 .67669 Mdot
.38753 .25408 Mdot
.32629 .46817 Mdot
.38551 .44177 Mdot
.38775 .47337 Mdot
.63781 .51012 Mdot
.39122 .60119 Mdot
.52976 .29727 Mdot
.39101 .64864 Mdot
.65043 .48695 Mdot
.39135 .63194 Mdot
.40729 .5959 Mdot
.57465 .65919 Mdot
.38292 .48889 Mdot
.40037 .65109 Mdot
.59721 .46565 Mdot
.4376 .34832 Mdot
.49763 .42444 Mdot
.73041 .6352 Mdot
.41563 .22653 Mdot
.46639 .24693 Mdot
.43844 .36476 Mdot
.15979 .45536 Mdot
.39955 .46354 Mdot
.66605 .55115 Mdot
.29898 .66272 Mdot
.60681 .49975 Mdot
.75604 .72099 Mdot
.45243 .62668 Mdot
.41049 .58877 Mdot
.60671 .45729 Mdot
.35457 .6726 Mdot
.64566 .4497 Mdot
.39807 .64586 Mdot
.44428 .6904 Mdot
.70178 .50568 Mdot
.44081 .63284 Mdot
.70771 .46871 Mdot
.63262 .48128 Mdot
.48119 .35195 Mdot
.44377 .60554 Mdot
.58624 .45757 Mdot
.31765 .22356 Mdot
.35238 .49247 Mdot
.28354 .60683 Mdot
.75527 .55368 Mdot
.35974 .47912 Mdot
.44379 .3395 Mdot
.57426 .44821 Mdot
.57793 .67316 Mdot
.46949 .32261 Mdot
.73984 .65156 Mdot
.55448 .69777 Mdot
.74015 .73283 Mdot
.47105 .36504 Mdot
.42792 .5834 Mdot
.56597 .65241 Mdot
.68779 .50585 Mdot
.4033 .58328 Mdot
.42998 .43515 Mdot
.42725 .61332 Mdot
.63127 .43494 Mdot
.25795 .51515 Mdot
.37249 .49923 Mdot
.64991 .47297 Mdot
.41701 .58597 Mdot
.2602 .55314 Mdot
.63751 .50938 Mdot
.61358 .46662 Mdot
.41545 .79492 Mdot
.69381 .75012 Mdot
.56579 .68243 Mdot
.46835 .30073 Mdot
.59808 .45712 Mdot
.54437 .6569 Mdot
.47508 .74572 Mdot
.66822 .50068 Mdot
.43051 .32146 Mdot
.57027 .51828 Mdot
.43781 .6012 Mdot
.35631 .48495 Mdot
.50448 .48315 Mdot
.54274 .65722 Mdot
.80948 .32881 Mdot
.3829 .63405 Mdot
.5892 .47888 Mdot
.62745 .4237 Mdot
.33412 .71971 Mdot
.47819 .36978 Mdot
.78113 .42949 Mdot
.65749 .44173 Mdot
.6711 .5434 Mdot
.65409 .46313 Mdot
.43207 .6817 Mdot
.46705 .35395 Mdot
.63913 .43899 Mdot
.31286 .31066 Mdot
.63322 .52061 Mdot
.53691 .66421 Mdot
.53117 .19208 Mdot
.67938 .49865 Mdot
.52161 .88232 Mdot
.56959 .75931 Mdot
.44171 .63442 Mdot
.26348 .48579 Mdot
.49609 .12533 Mdot
.34842 .38996 Mdot
.49871 .33824 Mdot
.21172 .44581 Mdot
.42355 .64938 Mdot
.24697 .49864 Mdot
.1561 .4566 Mdot
.63018 .48295 Mdot
.67756 .49177 Mdot
.5936 .63162 Mdot
.42824 .66708 Mdot
.3769 .60856 Mdot
.69882 .42792 Mdot
.56923 .43248 Mdot
.42812 .65353 Mdot
.59461 .45773 Mdot
.70097 .4232 Mdot
.34358 .45189 Mdot
.43626 .3598 Mdot
.35126 .46061 Mdot
.39127 .47519 Mdot
.6165 .21654 Mdot
.50203 .79349 Mdot
.35006 .48881 Mdot
.39406 .48193 Mdot
.69693 .65075 Mdot
.63435 .69397 Mdot
.58485 .68855 Mdot
.23897 .31959 Mdot
.41122 .63323 Mdot
.63042 .4465 Mdot
.44798 .37153 Mdot
.76392 .38086 Mdot
.52744 .73962 Mdot
.81516 .5722 Mdot
.67765 .45306 Mdot
.40857 .63851 Mdot
.27675 .61583 Mdot
.62254 .3957 Mdot
.37059 .59358 Mdot
.67529 .47599 Mdot
.37772 .61291 Mdot
.63125 .28941 Mdot
.311 .29544 Mdot
.38168 .59846 Mdot
.49574 .3797 Mdot
.66865 .47079 Mdot
.4651 .36641 Mdot
.36029 .458 Mdot
.57787 .65641 Mdot
.56193 .68184 Mdot
.62085 .46493 Mdot
.64209 .53899 Mdot
.44688 .76343 Mdot
.63778 .48142 Mdot
.62046 .49484 Mdot
.2764 .62099 Mdot
.61896 .4912 Mdot
.64209 .42335 Mdot
.65465 .42448 Mdot
.5923 .49697 Mdot
.36288 .50155 Mdot
.29334 .31371 Mdot
.65085 .39901 Mdot
.66547 .3978 Mdot
.33128 .48939 Mdot
.19043 .51087 Mdot
.39557 .46368 Mdot
.15601 .51187 Mdot
.34938 .45811 Mdot
.55345 .68116 Mdot
.26778 .66288 Mdot
.61352 .53125 Mdot
.43918 .32017 Mdot
.34705 .44191 Mdot
.54476 .66275 Mdot
.3648 .46352 Mdot
.4017 .6458 Mdot
.31546 .75234 Mdot
.51402 .36688 Mdot
.75469 .51146 Mdot
.41647 .43405 Mdot
.30189 .51667 Mdot
.39867 .65158 Mdot
.47153 .35737 Mdot
.68507 .32411 Mdot
.64411 .42117 Mdot
.54625 .65617 Mdot
.62069 .45266 Mdot
.37412 .50134 Mdot
.41465 .64186 Mdot
.52987 .18495 Mdot
.57901 .67443 Mdot
.46704 .82029 Mdot
.41062 .62182 Mdot
.66431 .42514 Mdot
.38038 .49947 Mdot
.52092 .8306 Mdot
.34823 .46565 Mdot
.72129 .39008 Mdot
.44491 .38162 Mdot
.6667 .22882 Mdot
.46095 .32419 Mdot
.36791 .56919 Mdot
.36041 .81437 Mdot
.31422 .26662 Mdot
.43593 .33653 Mdot
.32933 .52574 Mdot
.6562 .49745 Mdot
.66121 .49932 Mdot
.39947 .24576 Mdot
.46536 .30067 Mdot
.61147 .43269 Mdot
.27741 .63141 Mdot
.29083 .36431 Mdot
.61799 .76777 Mdot
.42915 .60825 Mdot
.64928 .44695 Mdot
.33529 .50258 Mdot
.3561 .44652 Mdot
.38297 .63727 Mdot
.39575 .4524 Mdot
.65535 .48326 Mdot
.46495 .32449 Mdot
.37655 .6473 Mdot
.55412 .67208 Mdot
.38458 .20173 Mdot
.58981 .66014 Mdot
.42434 .61246 Mdot
.67849 .51965 Mdot
.42762 .65071 Mdot
.5296 .10741 Mdot
.661 .48186 Mdot
.44894 .35918 Mdot
.60689 .47357 Mdot
.66505 .47003 Mdot
.67827 .49188 Mdot
.41309 .65085 Mdot
.78094 .45915 Mdot
.5957 .46208 Mdot
.37461 .48079 Mdot
.54239 .3442 Mdot
.68361 .48856 Mdot
.42533 .68779 Mdot
.65333 .67876 Mdot
.36967 .54772 Mdot
.44941 .37546 Mdot
.43723 .62151 Mdot
.43974 .34258 Mdot
.4794 .27303 Mdot
.44392 .33984 Mdot
.5681 .35245 Mdot
.67263 .3154 Mdot
.78865 .46976 Mdot
.52919 .22432 Mdot
.57579 .55646 Mdot
.46722 .30072 Mdot
.6126 .67606 Mdot
.46845 .31015 Mdot
.46973 .36913 Mdot
.2114 .75679 Mdot
.4481 .31359 Mdot
.65914 .44888 Mdot
.69038 .46568 Mdot
.26763 .41783 Mdot
.6913 .62058 Mdot
.61661 .48017 Mdot
.6012 .46146 Mdot
.57789 .65913 Mdot
.69915 .52502 Mdot
.27123 .48765 Mdot
.68121 .77094 Mdot
.24315 .46802 Mdot
.62092 .45561 Mdot
.59827 .46154 Mdot
.58485 .41242 Mdot
.52604 .8534 Mdot
.66974 .2495 Mdot
.4322 .30638 Mdot
.56574 .46322 Mdot
.37404 .22598 Mdot
.68038 .47717 Mdot
.65138 .51174 Mdot
.65729 .49452 Mdot
.42283 .64903 Mdot
.42546 .34302 Mdot
.57096 .44237 Mdot
.53989 .78416 Mdot
.67753 .48478 Mdot
.26577 .55924 Mdot
.61933 .17282 Mdot
.64922 .44307 Mdot
.42666 .35213 Mdot
.64683 .50456 Mdot
.47931 .36503 Mdot
.48239 .33846 Mdot
.64831 .52519 Mdot
.55721 .37615 Mdot
.42572 .35872 Mdot
.65004 .48748 Mdot
.40735 .64426 Mdot
.22475 .32998 Mdot
.63315 .43394 Mdot
.5851 .66475 Mdot
.66139 .4436 Mdot
.5317 .67647 Mdot
.62369 .49341 Mdot
.38127 .63038 Mdot
.74582 .35709 Mdot
.42545 .64154 Mdot
.70515 .25022 Mdot
.38527 .60697 Mdot
.42543 .80001 Mdot
.43456 .30991 Mdot
.26019 .5222 Mdot
.82641 .48372 Mdot
.27746 .58902 Mdot
.47113 .55976 Mdot
.47403 .52614 Mdot
.38673 .44541 Mdot
.47762 .37333 Mdot
.65637 .56597 Mdot
.33194 .68661 Mdot
.32185 .68997 Mdot
.39985 .5982 Mdot
.83818 .44768 Mdot
.82176 .58466 Mdot
.60149 .48131 Mdot
.61396 .33812 Mdot
.55936 .28126 Mdot
.67295 .50083 Mdot
.57099 .45515 Mdot
.46608 .65917 Mdot
.61001 .42976 Mdot
.34918 .29932 Mdot
.42041 .61243 Mdot
.54524 .66106 Mdot
.45692 .36219 Mdot
.54517 .65208 Mdot
.32832 .68555 Mdot
.47126 .52772 Mdot
.39298 .64132 Mdot
.60636 .50814 Mdot
.60563 .46752 Mdot
.48299 .35664 Mdot
.47582 .28755 Mdot
.45466 .31387 Mdot
.57116 .68754 Mdot
.41899 .61701 Mdot
.72816 .31298 Mdot
.60241 .45123 Mdot
.47022 .3342 Mdot
.45017 .54869 Mdot
.59881 .45132 Mdot
.35693 .46891 Mdot
.66339 .49162 Mdot
.43532 .34592 Mdot
.61909 .49112 Mdot
.46278 .32231 Mdot
.43074 .62607 Mdot
.68672 .45664 Mdot
.60905 .45362 Mdot
.49786 .83016 Mdot
.54703 .6769 Mdot
.4459 .29962 Mdot
.36554 .69135 Mdot
.63397 .41887 Mdot
.29292 .54687 Mdot
.6719 .46848 Mdot
.42699 .26569 Mdot
.59628 .49406 Mdot
.27097 .59431 Mdot
.61752 .4097 Mdot
.63402 .4346 Mdot
.42373 .51053 Mdot
.5638 .30456 Mdot
.47195 .29446 Mdot
.37982 .5018 Mdot
.44275 .31245 Mdot
.62576 .75476 Mdot
.41302 .57052 Mdot
.43264 .60208 Mdot
.67166 .58489 Mdot
.58655 .49241 Mdot
.63991 .45176 Mdot
.32777 .48999 Mdot
.54532 .68967 Mdot
.47226 .34359 Mdot
.54919 .65699 Mdot
.55393 .79646 Mdot
.56541 .69615 Mdot
.45537 .64697 Mdot
.47089 .76884 Mdot
.69903 .28802 Mdot
.5777 .65949 Mdot
.43568 .33281 Mdot
.56176 .7364 Mdot
.62394 .51211 Mdot
.59648 .72761 Mdot
.55091 .66184 Mdot
.83914 .41406 Mdot
.64052 .42406 Mdot
.47582 .56616 Mdot
.35008 .48379 Mdot
.56808 .6546 Mdot
.38544 .44953 Mdot
.61623 .47557 Mdot
.29077 .51805 Mdot
.49128 .32579 Mdot
.35759 .50689 Mdot
.70118 .4679 Mdot
.55869 .69147 Mdot
.38883 .61531 Mdot
.34653 .43707 Mdot
.37256 .50662 Mdot
.19133 .4774 Mdot
.57173 .18057 Mdot
.41848 .61913 Mdot
.73284 .68624 Mdot
.35339 .45242 Mdot
.67036 .50566 Mdot
.71331 .51908 Mdot
.67083 .48124 Mdot
.38232 .39016 Mdot
.43578 .61674 Mdot
.2698 .38507 Mdot
.60515 .4732 Mdot
.67198 .43836 Mdot
.46479 .29431 Mdot
.42127 .63495 Mdot
.4569 .33796 Mdot
.44943 .30904 Mdot
.42986 .62724 Mdot
.45337 .32721 Mdot
.55389 .69873 Mdot
.30031 .36531 Mdot
.33567 .47308 Mdot
.37882 .47842 Mdot
.40737 .63274 Mdot
.44292 .63933 Mdot
.43527 .64663 Mdot
.66372 .49146 Mdot
.46991 .34943 Mdot
.63636 .49373 Mdot
.6758 .49308 Mdot
.56308 .38497 Mdot
.43899 .36848 Mdot
.64594 .49849 Mdot
.35658 .60615 Mdot
.52712 .69112 Mdot
.4036 .6423 Mdot
.35126 .48776 Mdot
.23388 .54958 Mdot
.38956 .41751 Mdot
.65167 .44939 Mdot
.43417 .77638 Mdot
.44235 .3233 Mdot
.57498 .67151 Mdot
.58499 .69501 Mdot
.56976 .67836 Mdot
.38058 .51499 Mdot
.45838 .30106 Mdot
.68666 .76821 Mdot
.64568 .44737 Mdot
.51419 .57759 Mdot
.72596 .52897 Mdot
.43894 .7662 Mdot
.35298 .49026 Mdot
.59899 .45708 Mdot
.50595 .46771 Mdot
.69957 .32259 Mdot
.66866 .47827 Mdot
.65508 .51696 Mdot
.28529 .64035 Mdot
.5564 .50099 Mdot
.43742 .38113 Mdot
.55375 .81098 Mdot
.68137 .42751 Mdot
.52602 .35194 Mdot
.42286 .17412 Mdot
.65911 .4564 Mdot
.67193 .44431 Mdot
.61541 .43741 Mdot
.61287 .49093 Mdot
.43009 .36412 Mdot
.65462 .60746 Mdot
.39971 .45958 Mdot
.5287 .58521 Mdot
.33389 .48793 Mdot
.39308 .59137 Mdot
.29076 .32731 Mdot
.47572 .37508 Mdot
.57698 .66718 Mdot
.28875 .29705 Mdot
.61318 .80078 Mdot
.43708 .65934 Mdot
.64239 .24859 Mdot
.54803 .66829 Mdot
.66862 .50818 Mdot
.54108 .6939 Mdot
.39262 .59947 Mdot
.37493 .48636 Mdot
.58373 .49121 Mdot
.46391 .31194 Mdot
.44667 .3657 Mdot
.60861 .43478 Mdot
.35526 .23677 Mdot
.35496 .47332 Mdot
.32312 .47411 Mdot
.65619 .50818 Mdot
.69053 .50061 Mdot
.45374 .33883 Mdot
.40082 .61865 Mdot
.69058 .7055 Mdot
.54608 .68605 Mdot
.60946 .4251 Mdot
.61613 .49506 Mdot
.53078 .80126 Mdot
.36795 .49289 Mdot
.44762 .65659 Mdot
.62553 .50624 Mdot
.29167 .43092 Mdot
.62515 .50587 Mdot
.56606 .42705 Mdot
.40614 .64223 Mdot
.64214 .40213 Mdot
.59574 .47188 Mdot
.72897 .42815 Mdot
.37251 .44506 Mdot
.44762 .35451 Mdot
.51154 .35191 Mdot
.55773 .58042 Mdot
.35825 .46678 Mdot
.64573 .5012 Mdot
.36266 .48962 Mdot
.67053 .49754 Mdot
.60647 .43509 Mdot
.34712 .48699 Mdot
.45677 .33719 Mdot
.21431 .4553 Mdot
.29058 .3198 Mdot
.61087 .4885 Mdot
.66663 .41551 Mdot
.67165 .61027 Mdot
.79304 .49043 Mdot
.67663 .46011 Mdot
.43824 .35492 Mdot
.60374 .45479 Mdot
.38182 .44913 Mdot
.56893 .69898 Mdot
.43677 .34696 Mdot
.40671 .61183 Mdot
.42704 .66287 Mdot
.33628 .39156 Mdot
.41649 .59713 Mdot
.62878 .51185 Mdot
.4835 .27545 Mdot
.50613 .32848 Mdot
.40986 .1885 Mdot
.42761 .62951 Mdot
.56663 .70283 Mdot
.61538 .46724 Mdot
.41218 .77959 Mdot
.32645 .4911 Mdot
.56404 .88098 Mdot
.72463 .74518 Mdot
.58602 .64544 Mdot
.81637 .54078 Mdot
.38637 .59632 Mdot
.59333 .44815 Mdot
.57774 .65533 Mdot
.43602 .65824 Mdot
.60942 .49976 Mdot
.59009 .50233 Mdot
.7822 .43432 Mdot
.54011 .56419 Mdot
.3624 .49119 Mdot
.4433 .61882 Mdot
.5979 .67999 Mdot
.45018 .65922 Mdot
.4524 .37125 Mdot
.63416 .43728 Mdot
.64874 .5342 Mdot
.40288 .614 Mdot
.43363 .66695 Mdot
.65227 .49245 Mdot
.47987 .37257 Mdot
.46717 .64803 Mdot
.62413 .46143 Mdot
.58153 .55373 Mdot
.47444 .3851 Mdot
.41733 .60832 Mdot
.66284 .4297 Mdot
.55717 .72444 Mdot
.40742 .62152 Mdot
.40149 .64087 Mdot
.60668 .43578 Mdot
.55055 .69737 Mdot
.66166 .41573 Mdot
.34258 .46566 Mdot
.77948 .35208 Mdot
.38611 .45386 Mdot
.53108 .722 Mdot
.68698 .51252 Mdot
.29804 .46924 Mdot
.46076 .37676 Mdot
.57871 .62536 Mdot
.2396 .59752 Mdot
.70231 .43259 Mdot
.19295 .40442 Mdot
.49527 .44939 Mdot
.34488 .22914 Mdot
.2285 .64639 Mdot
.55835 .6604 Mdot
.36531 .46057 Mdot
.6722 .44521 Mdot
.36779 .43366 Mdot
.58253 .65882 Mdot
.69108 .24502 Mdot
.65619 .42625 Mdot
.4655 .35463 Mdot
.65663 .48945 Mdot
.46465 .36449 Mdot
.60064 .44412 Mdot
.63162 .39522 Mdot
.27124 .62497 Mdot
.73553 .64929 Mdot
.60927 .50264 Mdot
.33975 .78048 Mdot
.5403 .76306 Mdot
.54213 .67117 Mdot
.63679 .48893 Mdot
.39238 .56324 Mdot
.36388 .4416 Mdot
.39009 .27318 Mdot
.42203 .6497 Mdot
.39351 .47535 Mdot
.44916 .33593 Mdot
.43118 .6166 Mdot
.4195 .66331 Mdot
.63444 .40454 Mdot
.53529 .6642 Mdot
.38333 .48249 Mdot
.64105 .43692 Mdot
.65193 .42637 Mdot
.70377 .71184 Mdot
.5124 .72733 Mdot
.50111 .30719 Mdot
.59706 .83099 Mdot
.50942 .34962 Mdot
.54853 .68317 Mdot
.41573 .64867 Mdot
.67392 .46354 Mdot
.64746 .47347 Mdot
.26026 .53453 Mdot
.48666 .31809 Mdot
.52507 .53703 Mdot
.59618 .21857 Mdot
.46445 .65453 Mdot
.66815 .65663 Mdot
.45102 .36352 Mdot
.67031 .655 Mdot
.59146 .69259 Mdot
.26138 .30895 Mdot
.71565 .66088 Mdot
.35251 .48567 Mdot
.66674 .65307 Mdot
.47642 .33211 Mdot
.60158 .47657 Mdot
.43015 .58442 Mdot
.40824 .59635 Mdot
.45156 .34878 Mdot
.4004 .66364 Mdot
.57344 .65969 Mdot
.66452 .43682 Mdot
.67963 .76622 Mdot
.34828 .36624 Mdot
.39549 .61736 Mdot
.64308 .39295 Mdot
.38825 .47063 Mdot
.61229 .43051 Mdot
.58431 .66906 Mdot
.36499 .47853 Mdot
.57766 .7566 Mdot
.28149 .37441 Mdot
.61955 .46934 Mdot
.44539 .80138 Mdot
.36083 .46965 Mdot
.79644 .53837 Mdot
.62589 .45348 Mdot
.35517 .45158 Mdot
.55643 .47199 Mdot
.34074 .60317 Mdot
.50917 .47384 Mdot
.15637 .45393 Mdot
.51093 .51032 Mdot
.41662 .58027 Mdot
.34091 .57329 Mdot
.31633 .63158 Mdot
.36745 .43488 Mdot
.43749 .66624 Mdot
.50786 .64856 Mdot
.38538 .44876 Mdot
.6832 .48748 Mdot
.66758 .46451 Mdot
.67125 .24745 Mdot
.48727 .45717 Mdot
.3569 .58083 Mdot
.38069 .3381 Mdot
.6384 .41868 Mdot
.68883 .43452 Mdot
.64265 .46859 Mdot
.42141 .34781 Mdot
.36809 .48911 Mdot
.41002 .81232 Mdot
.35647 .46551 Mdot
.74223 .70715 Mdot
.4117 .63509 Mdot
.43909 .61718 Mdot
.65137 .44582 Mdot
.49374 .60034 Mdot
.62961 .64139 Mdot
.6531 .48361 Mdot
.52545 .61227 Mdot
.51762 .19572 Mdot
.69821 .47115 Mdot
.449 .38026 Mdot
.71293 .4239 Mdot
.44619 .39446 Mdot
.33581 .47156 Mdot
.56157 .66678 Mdot
.56893 .62233 Mdot
.37618 .48787 Mdot
.63965 .45331 Mdot
.28809 .47154 Mdot
.66018 .47075 Mdot
.60786 .49145 Mdot
.76468 .68519 Mdot
.58927 .65709 Mdot
.43626 .63682 Mdot
.57008 .68096 Mdot
.47497 .36935 Mdot
.41655 .89469 Mdot
.54184 .68597 Mdot
.62383 .63667 Mdot
.72733 .2769 Mdot
.6684 .6496 Mdot
.45294 .36998 Mdot
.53996 .65147 Mdot
.35478 .48045 Mdot
.23816 .29854 Mdot
.80305 .44666 Mdot
.36592 .41841 Mdot
.62854 .46293 Mdot
.48968 .36856 Mdot
.43237 .34682 Mdot
.35177 .50465 Mdot
.4809 .33795 Mdot
.56147 .4804 Mdot
.60644 .48352 Mdot
.37589 .4323 Mdot
.2965 .40144 Mdot
.37417 .50654 Mdot
.31563 .33563 Mdot
.6414 .48888 Mdot
.44552 .35939 Mdot
.71772 .4452 Mdot
.41894 .37096 Mdot
.45134 .65038 Mdot
.68116 .49875 Mdot
.57484 .66078 Mdot
.30595 .45078 Mdot
.41621 .61893 Mdot
.42298 .76811 Mdot
.48095 .35898 Mdot
.36714 .53904 Mdot
.48241 .34933 Mdot
.47447 .30261 Mdot
.39307 .46959 Mdot
.4908 .33 Mdot
.67027 .4419 Mdot
.36753 .57526 Mdot
.48949 .35756 Mdot
.38145 .46151 Mdot
.5603 .6721 Mdot
.45568 .32918 Mdot
.35298 .66994 Mdot
.61316 .46017 Mdot
.41738 .65532 Mdot
.28483 .68028 Mdot
.50385 .3385 Mdot
.55962 .64163 Mdot
.4293 .60017 Mdot
.55197 .65022 Mdot
.47703 .18184 Mdot
.39122 .43275 Mdot
.80461 .59336 Mdot
.52871 .70073 Mdot
.44396 .31755 Mdot
.26933 .66195 Mdot
.67164 .4614 Mdot
.61312 .46301 Mdot
.52947 .67529 Mdot
.43231 .34624 Mdot
.28652 .28096 Mdot
.41904 .39519 Mdot
.28909 .37853 Mdot
.37745 .42736 Mdot
.39612 .79397 Mdot
.32228 .31791 Mdot
.55331 .15433 Mdot
.69287 .42937 Mdot
.38 .60424 Mdot
.64841 .45546 Mdot
.23391 .5785 Mdot
.56172 .69064 Mdot
.39071 .67744 Mdot
.64908 .5232 Mdot
.43475 .6266 Mdot
.61672 .44282 Mdot
.42911 .48629 Mdot
.70378 .41918 Mdot
.5724 .70107 Mdot
.26823 .48955 Mdot
.44465 .31452 Mdot
.55211 .67045 Mdot
.38354 .63108 Mdot
.64267 .65086 Mdot
.60039 .49118 Mdot
.67851 .40835 Mdot
.46489 .6499 Mdot
.46972 .35615 Mdot
.43306 .59252 Mdot
.33819 .46778 Mdot
.57044 .6656 Mdot
.6114 .47385 Mdot
.59907 .49958 Mdot
.29371 .55002 Mdot
.38717 .47853 Mdot
.40689 .66401 Mdot
.35053 .46387 Mdot
.38737 .5927 Mdot
.64793 .40896 Mdot
.43834 .61478 Mdot
.58956 .4624 Mdot
.25274 .60683 Mdot
.76358 .68343 Mdot
.57837 .32004 Mdot
.43348 .61413 Mdot
.66528 .68446 Mdot
.38073 .45216 Mdot
.35225 .45723 Mdot
.72718 .2951 Mdot
.74286 .40254 Mdot
.66619 .75116 Mdot
.17816 .517 Mdot
.33365 .48566 Mdot
.38762 .46548 Mdot
.42144 .65722 Mdot
.49437 .33661 Mdot
.49415 .31566 Mdot
.38221 .60392 Mdot
.74113 .56726 Mdot
.47221 .34339 Mdot
.22128 .35226 Mdot
.63239 .75953 Mdot
.57664 .43462 Mdot
.42902 .55558 Mdot
.56876 .67049 Mdot
.72834 .58724 Mdot
.4267 .48953 Mdot
.67488 .44313 Mdot
.5175 .799 Mdot
.40144 .62516 Mdot
.66139 .57864 Mdot
.15723 .51241 Mdot
.65097 .42425 Mdot
.62892 .44756 Mdot
.64225 .45978 Mdot
.57912 .63865 Mdot
.75422 .40191 Mdot
.6581 .42958 Mdot
.74555 .56262 Mdot
.62726 .41941 Mdot
.56455 .4036 Mdot
.56445 .68213 Mdot
.54793 .42764 Mdot
.27633 .64155 Mdot
.57624 .7927 Mdot
.72573 .46325 Mdot
.34083 .4644 Mdot
.54763 .60457 Mdot
.36912 .44495 Mdot
.5692 .34481 Mdot
.71744 .65609 Mdot
.50393 .37003 Mdot
.67498 .4452 Mdot
.42371 .61184 Mdot
.43277 .34926 Mdot
.326 .57618 Mdot
.31525 .85008 Mdot
.34588 .45631 Mdot
.5954 .14182 Mdot
.34765 .46228 Mdot
.40979 .66032 Mdot
.45257 .33977 Mdot
.66511 .30992 Mdot
.51431 .57296 Mdot
.45632 .3269 Mdot
.23594 .41945 Mdot
.44164 .29483 Mdot
.66133 .67256 Mdot
.50395 .35705 Mdot
.38144 .45774 Mdot
.38753 .50911 Mdot
.58272 .50224 Mdot
.66526 .4517 Mdot
.46862 .52072 Mdot
.63667 .67327 Mdot
.66974 .45678 Mdot
.42041 .61474 Mdot
.80778 .51083 Mdot
.58633 .60456 Mdot
.48335 .32567 Mdot
.40087 .46737 Mdot
.62665 .44533 Mdot
.62122 .50229 Mdot
.60154 .48947 Mdot
.61764 .8333 Mdot
.26564 .30067 Mdot
.59592 .46176 Mdot
.63625 .41639 Mdot
.43231 .62003 Mdot
.57114 .71235 Mdot
.22569 .57389 Mdot
.64321 .37607 Mdot
.68406 .45706 Mdot
.55254 .67673 Mdot
.59028 .65596 Mdot
.61125 .50153 Mdot
.53675 .78117 Mdot
.29742 .49119 Mdot
.64046 .43647 Mdot
.73673 .40284 Mdot
.32406 .66063 Mdot
.42896 .66679 Mdot
.40517 .61488 Mdot
.42787 .34425 Mdot
.41751 .60039 Mdot
.38209 .61221 Mdot
.67192 .29797 Mdot
.51086 .52378 Mdot
.36504 .52001 Mdot
.57223 .68703 Mdot
.65131 .4735 Mdot
.50197 .31162 Mdot
.2876 .44276 Mdot
.39113 .45282 Mdot
.44642 .32286 Mdot
.36126 .44448 Mdot
.55673 .63472 Mdot
.7446 .52136 Mdot
.39749 .59794 Mdot
.34177 .49535 Mdot
.28275 .3731 Mdot
.55504 .67862 Mdot
.38639 .48588 Mdot
.28513 .48575 Mdot
.68813 .4833 Mdot
.64273 .34689 Mdot
.64869 .48428 Mdot
.31664 .24963 Mdot
.38044 .4921 Mdot
.2665 .58585 Mdot
.63787 .4463 Mdot
.40972 .62329 Mdot
.55766 .44549 Mdot
.67695 .47468 Mdot
.40499 .60747 Mdot
.60121 .48006 Mdot
.57865 .64914 Mdot
.47916 .38628 Mdot
.53537 .58373 Mdot
.86129 .55976 Mdot
.53554 .66295 Mdot
.3208 .56776 Mdot
.67744 .45771 Mdot
.53409 .17997 Mdot
.45763 .32885 Mdot
.58945 .47423 Mdot
.60939 .60244 Mdot
.49615 .35188 Mdot
.44119 .33342 Mdot
.63447 .50315 Mdot
.34979 .48055 Mdot
.4152 .61541 Mdot
.56029 .68064 Mdot
.47702 .1735 Mdot
.62981 .4712 Mdot
.60665 .45412 Mdot
.54955 .66862 Mdot
.38791 .45943 Mdot
.63371 .50751 Mdot
.29594 .70197 Mdot
.32647 .22361 Mdot
.38874 .44428 Mdot
.68493 .47879 Mdot
.64017 .35953 Mdot
.46405 .39827 Mdot
.75201 .27372 Mdot
.58719 .74061 Mdot
.43856 .63083 Mdot
.55719 .49623 Mdot
.45815 .88848 Mdot
.56201 .66871 Mdot
.62871 .78557 Mdot
.61262 .49849 Mdot
.60511 .44399 Mdot
.45224 .31558 Mdot
.64097 .49603 Mdot
.50142 .34201 Mdot
.8561 .54058 Mdot
.52314 .80585 Mdot
.47033 .36143 Mdot
.45894 .31042 Mdot
.61157 .61593 Mdot
.22735 .57406 Mdot
.44968 .34767 Mdot
.63296 .41323 Mdot
.47631 .25923 Mdot
.71068 .40033 Mdot
.53205 .6835 Mdot
.30751 .67611 Mdot
.44948 .40377 Mdot
.60775 .67583 Mdot
.1985 .47129 Mdot
.46188 .40488 Mdot
.30859 .50068 Mdot
.33829 .4738 Mdot
.65827 .42447 Mdot
.41152 .59619 Mdot
.43408 .60525 Mdot
.71315 .43882 Mdot
.65822 .47532 Mdot
.47712 .36604 Mdot
.57597 .68712 Mdot
.3622 .43879 Mdot
.60169 .46141 Mdot
.59136 .61177 Mdot
.54198 .68427 Mdot
.48908 .33843 Mdot
.76954 .43498 Mdot
.57304 .70185 Mdot
.67499 .39664 Mdot
.65181 .43712 Mdot
.65656 .49359 Mdot
.72452 .41057 Mdot
.35327 .49504 Mdot
.2634 .64885 Mdot
.68709 .4433 Mdot
.55422 .79726 Mdot
.50054 .4167 Mdot
.60738 .40486 Mdot
.47721 .34624 Mdot
.32719 .4939 Mdot
.44748 .60495 Mdot
.62848 .58022 Mdot
.62303 .47148 Mdot
.30039 .28427 Mdot
.63584 .22703 Mdot
.45344 .63656 Mdot
.46974 .30208 Mdot
.57328 .67398 Mdot
.65387 .48228 Mdot
.54925 .36197 Mdot
.66384 .45915 Mdot
.52479 .65906 Mdot
.39908 .6347 Mdot
.33897 .47422 Mdot
.34114 .22759 Mdot
.4347 .60636 Mdot
.43971 .34044 Mdot
.12081 .52172 Mdot
.49898 .36163 Mdot
.46373 .30632 Mdot
.54763 .37558 Mdot
.34661 .49191 Mdot
.48717 .8966 Mdot
.8047 .39468 Mdot
.68237 .50821 Mdot
.37568 .44955 Mdot
.45611 .35193 Mdot
.61757 .42833 Mdot
.47136 .3795 Mdot
.45591 .29987 Mdot
.65819 .40941 Mdot
.62394 .43021 Mdot
.2973 .32319 Mdot
.15605 .47068 Mdot
.57455 .67545 Mdot
.46731 .37176 Mdot
.60327 .56191 Mdot
.62309 .4256 Mdot
.64519 .44673 Mdot
.32585 .63465 Mdot
.5548 .69961 Mdot
.36872 .29166 Mdot
.61629 .50061 Mdot
.4951 .8085 Mdot
.71407 .42636 Mdot
.43166 .36885 Mdot
.39137 .44843 Mdot
.57908 .78729 Mdot
.41317 .44352 Mdot
.49189 .32408 Mdot
.58099 .67832 Mdot
.51232 .34656 Mdot
.62415 .64043 Mdot
.36108 .50342 Mdot
.4353 .3459 Mdot
.50468 .4805 Mdot
.37104 .4736 Mdot
.37231 .49612 Mdot
.5415 .34466 Mdot
.38294 .64775 Mdot
.57867 .64127 Mdot
.38504 .47884 Mdot
.65279 .55307 Mdot
.37472 .45827 Mdot
.75061 .33385 Mdot
.68714 .45802 Mdot
.70825 .56864 Mdot
.46851 .57369 Mdot
.60016 .52438 Mdot
.37077 .50015 Mdot
.58285 .66414 Mdot
.63488 .50569 Mdot
.4791 .3326 Mdot
.54058 .66611 Mdot
.34521 .43429 Mdot
.42543 .6531 Mdot
.48459 .34832 Mdot
.38533 .42502 Mdot
.45679 .36768 Mdot
.65232 .56825 Mdot
.7619 .31186 Mdot
.3314 .73834 Mdot
.51564 .56741 Mdot
.60301 .49069 Mdot
.19522 .53863 Mdot
.59207 .41909 Mdot
.66305 .47717 Mdot
.41774 .60999 Mdot
.67334 .58168 Mdot
.45641 .33806 Mdot
.32517 .23232 Mdot
.33745 .48731 Mdot
.55121 .81177 Mdot
.45178 .26928 Mdot
.59187 .4816 Mdot
.48965 .35876 Mdot
.49992 .36177 Mdot
.55609 .29782 Mdot
.45522 .62396 Mdot
.5729 .46275 Mdot
.57085 .46414 Mdot
.67411 .4091 Mdot
.36721 .49535 Mdot
.43318 .77324 Mdot
.41031 .58147 Mdot
.74508 .27978 Mdot
.39637 .62737 Mdot
.52764 .60917 Mdot
.4897 .33059 Mdot
.54268 .68839 Mdot
.64483 .44484 Mdot
.46519 .28509 Mdot
.49063 .3213 Mdot
.52312 .67172 Mdot
.56733 .6534 Mdot
.33531 .62563 Mdot
.34791 .48811 Mdot
.61043 .50485 Mdot
.66312 .43035 Mdot
.63274 .49325 Mdot
.66462 .48776 Mdot
.34167 .46059 Mdot
.65894 .50299 Mdot
.34425 .50898 Mdot
.72169 .52426 Mdot
.50403 .79899 Mdot
.50611 .51213 Mdot
.41689 .27664 Mdot
.48057 .32768 Mdot
.60814 .55335 Mdot
.65669 .39064 Mdot
.77968 .65997 Mdot
.46375 .21921 Mdot
.69566 .47962 Mdot
.43957 .65562 Mdot
.74574 .41681 Mdot
.40319 .59318 Mdot
.66696 .17445 Mdot
.29058 .55596 Mdot
.16791 .43921 Mdot
.64721 .42705 Mdot
.32603 .64669 Mdot
.64816 .54669 Mdot
.5828 .43269 Mdot
.31384 .5878 Mdot
.38406 .38649 Mdot
.25426 .41907 Mdot
.58363 .68552 Mdot
.61742 .45832 Mdot
.49316 .30397 Mdot
.66759 .43859 Mdot
.64802 .45115 Mdot
.61773 .50321 Mdot
.39095 .48611 Mdot
.57485 .4644 Mdot
.6701 .49052 Mdot
.44519 .75886 Mdot
.68962 .65779 Mdot
.44218 .61356 Mdot
.71367 .27797 Mdot
.53896 .68021 Mdot
.48248 .3623 Mdot
.23411 .37784 Mdot
.35286 .48643 Mdot
.55543 .28813 Mdot
.66155 .49054 Mdot
.28469 .34716 Mdot
.37352 .42412 Mdot
.57226 .6635 Mdot
.41899 .57835 Mdot
.18824 .39166 Mdot
.42476 .61809 Mdot
.50418 .4687 Mdot
.41346 .62477 Mdot
.70252 .40423 Mdot
.47609 .36652 Mdot
.62337 .5076 Mdot
.38268 .48049 Mdot
.41202 .60461 Mdot
.68353 .61281 Mdot
.6433 .46702 Mdot
.43033 .62835 Mdot
.62444 .50787 Mdot
.74481 .52463 Mdot
.74972 .66162 Mdot
.38038 .62119 Mdot
.35201 .51554 Mdot
.37639 .47182 Mdot
.55216 .69763 Mdot
.48775 .35241 Mdot
.45964 .31483 Mdot
.36547 .4762 Mdot
.80517 .4679 Mdot
.683 .46241 Mdot
.62564 .42583 Mdot
.55977 .80014 Mdot
.67266 .45142 Mdot
.65014 .66757 Mdot
.50669 .47101 Mdot
.48557 .33302 Mdot
.59513 .44717 Mdot
.61872 .4996 Mdot
.61752 .46788 Mdot
.69161 .55526 Mdot
.39925 .6164 Mdot
.67514 .433 Mdot
.56505 .65137 Mdot
.37627 .5657 Mdot
.61316 .4295 Mdot
.66783 .4053 Mdot
.4576 .31539 Mdot
.62054 .81366 Mdot
.3443 .46869 Mdot
.3907 .64356 Mdot
.4377 .61795 Mdot
.31017 .67562 Mdot
.50649 .40459 Mdot
.50697 .48007 Mdot
.71674 .25083 Mdot
.27561 .6271 Mdot
.54423 .67242 Mdot
.40359 .55104 Mdot
.51644 .4169 Mdot
.41896 .65961 Mdot
.34845 .45232 Mdot
.68817 .45598 Mdot
.68474 .45727 Mdot
.75193 .72037 Mdot
.59595 .49104 Mdot
.56958 .67404 Mdot
.3419 .50441 Mdot
.47557 .33208 Mdot
.57337 .6646 Mdot
.3536 .45792 Mdot
.47164 .35553 Mdot
.69478 .46648 Mdot
.69287 .45889 Mdot
.44786 .32281 Mdot
.43333 .33921 Mdot
.64686 .43819 Mdot
.48433 .65687 Mdot
.43768 .32044 Mdot
.44392 .36033 Mdot
.39654 .59814 Mdot
.40805 .5977 Mdot
.62791 .40424 Mdot
.37073 .4518 Mdot
.66823 .49455 Mdot
.42853 .61505 Mdot
.56818 .6952 Mdot
.46026 .33431 Mdot
.61136 .49053 Mdot
.60223 .46728 Mdot
.55584 .67794 Mdot
.58133 .68524 Mdot
.57044 .65679 Mdot
.36542 .51109 Mdot
.63057 .48635 Mdot
.44778 .34158 Mdot
.34384 .48502 Mdot
.59008 .6542 Mdot
.54837 .69971 Mdot
.43678 .6726 Mdot
.67543 .46445 Mdot
.38421 .55967 Mdot
.39739 .87815 Mdot
.60659 .73628 Mdot
.45377 .62711 Mdot
.45011 .66733 Mdot
.68144 .63839 Mdot
.50674 .60008 Mdot
.35813 .47473 Mdot
.51536 .6544 Mdot
.57573 .62379 Mdot
.6787 .49996 Mdot
.67817 .42527 Mdot
.5682 .4694 Mdot
.56183 .65609 Mdot
.63529 .59032 Mdot
.46987 .3782 Mdot
.55914 .21489 Mdot
.53835 .67456 Mdot
.43258 .66734 Mdot
.38711 .65328 Mdot
.39647 .62892 Mdot
.68984 .45576 Mdot
.57941 .3143 Mdot
.54391 .50684 Mdot
.19121 .55017 Mdot
.37883 .49577 Mdot
.51456 .34115 Mdot
.50787 .18929 Mdot
.4448 .32717 Mdot
.39206 .59482 Mdot
.54656 .66042 Mdot
.43526 .35138 Mdot
.37463 .44028 Mdot
.38661 .47044 Mdot
.39615 .61987 Mdot
.40868 .63535 Mdot
.40186 .64712 Mdot
.46202 .30318 Mdot
.4911 .33137 Mdot
.62624 .47472 Mdot
.4665 .32913 Mdot
.70759 .76636 Mdot
.56622 .63456 Mdot
.45501 .66589 Mdot
.36369 .45994 Mdot
.46684 .36461 Mdot
.64358 .47051 Mdot
.56128 .58962 Mdot
.37071 .37521 Mdot
.55879 .64781 Mdot
.72063 .69436 Mdot
.66568 .1761 Mdot
.60704 .50369 Mdot
.36586 .49325 Mdot
.67833 .76471 Mdot
.64042 .4615 Mdot
.41292 .64565 Mdot
.25111 .61943 Mdot
.41147 .56981 Mdot
.67521 .49306 Mdot
.63489 .51761 Mdot
.39515 .45075 Mdot
.69606 .24298 Mdot
.63076 .47575 Mdot
.36443 .30847 Mdot
.40195 .45166 Mdot
.40742 .58311 Mdot
.3036 .23274 Mdot
.33155 .71451 Mdot
.7312 .57978 Mdot
.39438 .60031 Mdot
.66608 .46985 Mdot
.39808 .60032 Mdot
.56827 .64822 Mdot
.38575 .62222 Mdot
.45025 .38244 Mdot
.43914 .60381 Mdot
.60685 .4526 Mdot
.44978 .35034 Mdot
.36 .46947 Mdot
.57236 .81431 Mdot
.50865 .75691 Mdot
.40912 .62422 Mdot
.38369 .63711 Mdot
.59442 .46576 Mdot
.34817 .29397 Mdot
.71037 .46244 Mdot
.63956 .42497 Mdot
.33775 .4928 Mdot
.49215 .35361 Mdot
.3978 .46778 Mdot
.58519 .45273 Mdot
.28622 .69791 Mdot
.34851 .46837 Mdot
.28034 .34386 Mdot
.54718 .6689 Mdot
.44235 .47037 Mdot
.64961 .47528 Mdot
.39132 .46109 Mdot
.63185 .48631 Mdot
.46503 .37944 Mdot
.47327 .4676 Mdot
.26566 .47976 Mdot
.37896 .48305 Mdot
.31465 .2615 Mdot
.50245 .63541 Mdot
.69047 .51433 Mdot
.35894 .44971 Mdot
.60651 .6003 Mdot
.41789 .66311 Mdot
.54444 .68328 Mdot
.59023 .66786 Mdot
.54409 .65435 Mdot
.70674 .45148 Mdot
.71855 .48053 Mdot
.58406 .6506 Mdot
.37818 .43776 Mdot
.57769 .69756 Mdot
.52446 .36368 Mdot
.2907 .27801 Mdot
.56125 .68933 Mdot
.62567 .45714 Mdot
.73081 .47077 Mdot
.69337 .64986 Mdot
.34751 .60636 Mdot
.17853 .42712 Mdot
.40367 .27126 Mdot
.66452 .45291 Mdot
.4952 .38428 Mdot
.45169 .37278 Mdot
.65855 .77054 Mdot
.63926 .69055 Mdot
.56015 .78277 Mdot
.45956 .30903 Mdot
.2595 .51868 Mdot
.48866 .34169 Mdot
.5965 .48844 Mdot
.61997 .42852 Mdot
.48935 .31308 Mdot
.45941 .79045 Mdot
.29915 .53746 Mdot
.38955 .20297 Mdot
.44863 .36537 Mdot
.37396 .44438 Mdot
.33416 .49388 Mdot
.3698 .49816 Mdot
.64102 .75584 Mdot
.50086 .3514 Mdot
.62356 .48651 Mdot
.43146 .61248 Mdot
.67999 .44115 Mdot
.36958 .48132 Mdot
.32272 .23424 Mdot
.46837 .31903 Mdot
.6356 .435 Mdot
.78866 .49676 Mdot
.41981 .64495 Mdot
.55067 .67798 Mdot
.76769 .48392 Mdot
.58212 .76003 Mdot
.35459 .49881 Mdot
.50537 .34084 Mdot
.26715 .57043 Mdot
.27487 .33847 Mdot
.69273 .4351 Mdot
.58553 .41894 Mdot
.51857 .15808 Mdot
.57935 .75538 Mdot
.64763 .51384 Mdot
.40275 .65494 Mdot
.26008 .53952 Mdot
.60718 .47502 Mdot
.459 .37372 Mdot
.58824 .68417 Mdot
.54804 .6542 Mdot
.60933 .41681 Mdot
.51427 .58006 Mdot
.44482 .43863 Mdot
.6473 .50124 Mdot
.67292 .39563 Mdot
.40151 .58938 Mdot
.27693 .62951 Mdot
.54903 .80118 Mdot
.5817 .67886 Mdot
.62871 .50819 Mdot
.22318 .4628 Mdot
.47716 .3093 Mdot
.44706 .61569 Mdot
.3673 .50493 Mdot
.73534 .52044 Mdot
.40695 .58224 Mdot
.6066 .47682 Mdot
.62993 .50637 Mdot
.38977 .48134 Mdot
.43193 .36954 Mdot
.55846 .65614 Mdot
.43343 .61192 Mdot
.58407 .67488 Mdot
.49769 .35199 Mdot
.47167 .32369 Mdot
.69583 .38967 Mdot
.63958 .52903 Mdot
.40665 .61372 Mdot
.60013 .43469 Mdot
.3658 .68981 Mdot
.6861 .22791 Mdot
.34599 .44273 Mdot
.60896 .50559 Mdot
.42253 .35647 Mdot
.37573 .48672 Mdot
.61334 .43584 Mdot
.48661 .16555 Mdot
.62414 .42384 Mdot
.40466 .41172 Mdot
.32496 .74006 Mdot
.58011 .66314 Mdot
.54004 .21444 Mdot
.38056 .25073 Mdot
.66952 .44656 Mdot
.44272 .64306 Mdot
.60269 .40239 Mdot
.35157 .47871 Mdot
.48527 .32672 Mdot
.75231 .2704 Mdot
.37763 .46072 Mdot
.65727 .43194 Mdot
.57124 .66505 Mdot
.50414 .35227 Mdot
.52491 .62483 Mdot
.5317 .78396 Mdot
.71142 .48106 Mdot
.6211 .4157 Mdot
.6616 .49635 Mdot
.24225 .6503 Mdot
.39076 .64295 Mdot
.45938 .35906 Mdot
.36492 .49438 Mdot
.36338 .47785 Mdot
.39815 .62143 Mdot
.27387 .40386 Mdot
.44403 .46869 Mdot
.4006 .86576 Mdot
.40353 .6056 Mdot
.54832 .64595 Mdot
.35918 .29756 Mdot
.44487 .64036 Mdot
.42864 .63223 Mdot
.40333 .58909 Mdot
.40792 .49033 Mdot
.47099 .35237 Mdot
.60145 .46985 Mdot
.44981 .37578 Mdot
.66848 .47252 Mdot
.49392 .4154 Mdot
.38003 .485 Mdot
.48147 .32063 Mdot
.49704 .16769 Mdot
.72065 .36723 Mdot
.63441 .45779 Mdot
.52172 .18406 Mdot
.667 .51942 Mdot
.65623 .63774 Mdot
.62197 .52133 Mdot
.41027 .63022 Mdot
.59056 .53577 Mdot
.69417 .41781 Mdot
.61761 .80324 Mdot
.36288 .45901 Mdot
.43145 .66516 Mdot
.67636 .50739 Mdot
.7043 .41054 Mdot
.48247 .30596 Mdot
.43771 .35528 Mdot
.58689 .65718 Mdot
.74121 .645 Mdot
.35808 .46888 Mdot
.78208 .37349 Mdot
.66258 .44769 Mdot
.38823 .76709 Mdot
.53467 .22598 Mdot
.61534 .43532 Mdot
.39523 .23929 Mdot
.57084 .30501 Mdot
.65279 .48018 Mdot
.56174 .55738 Mdot
.38673 .45864 Mdot
.29474 .70823 Mdot
.63027 .41623 Mdot
.41961 .64852 Mdot
.49323 .33921 Mdot
.47477 .37645 Mdot
.58246 .65076 Mdot
.81467 .61082 Mdot
.39589 .47322 Mdot
.4843 .32351 Mdot
.64705 .46483 Mdot
.34998 .49527 Mdot
.42072 .5994 Mdot
.58609 .47721 Mdot
.64388 .69547 Mdot
.46942 .33119 Mdot
.61947 .4196 Mdot
.3507 .34004 Mdot
.72634 .61397 Mdot
.18747 .62007 Mdot
.36212 .49594 Mdot
.56406 .6993 Mdot
.59617 .40605 Mdot
.78542 .44134 Mdot
.69932 .47267 Mdot
.70301 .56861 Mdot
.51503 .39198 Mdot
.56536 .69984 Mdot
.63377 .4486 Mdot
.61442 .47717 Mdot
.47624 .5754 Mdot
.57822 .6865 Mdot
.66056 .42761 Mdot
.73718 .48738 Mdot
.46826 .35545 Mdot
.40703 .57677 Mdot
.47234 .33734 Mdot
.62861 .46212 Mdot
.61832 .5243 Mdot
.44333 .32099 Mdot
.6388 .18342 Mdot
.59356 .65195 Mdot
.34407 .47207 Mdot
.67414 .52317 Mdot
.68114 .43276 Mdot
.3468 .79376 Mdot
.44947 .6535 Mdot
.22148 .53652 Mdot
.42041 .73272 Mdot
.20832 .47518 Mdot
.3336 .7155 Mdot
.13595 .48869 Mdot
.52551 .80069 Mdot
.57439 .45394 Mdot
.40442 .34386 Mdot
.54196 .51243 Mdot
.37287 .501 Mdot
.70451 .29896 Mdot
.66571 .45236 Mdot
.64882 .45326 Mdot
.44855 .6177 Mdot
.2684 .38227 Mdot
.55513 .78841 Mdot
.53083 .59539 Mdot
.55674 .65755 Mdot
.46896 .37016 Mdot
.59844 .44872 Mdot
.53455 .53921 Mdot
.44373 .61625 Mdot
.39783 .77114 Mdot
.63332 .438 Mdot
.77505 .66142 Mdot
.35511 .39537 Mdot
.3513 .49293 Mdot
.44136 .62482 Mdot
.57367 .76594 Mdot
.67618 .46811 Mdot
.36353 .50644 Mdot
.63572 .47469 Mdot
.4805 .62235 Mdot
.58854 .44976 Mdot
.55591 .69096 Mdot
.60897 .49694 Mdot
.53812 .60328 Mdot
.14458 .57206 Mdot
.52491 .6444 Mdot
.48535 .37148 Mdot
.46113 .64352 Mdot
.40088 .61583 Mdot
.43416 .34463 Mdot
.40342 .61688 Mdot
.54854 .25947 Mdot
.64457 .29454 Mdot
.54993 .66089 Mdot
.69201 .40534 Mdot
.56567 .6868 Mdot
.45266 .64772 Mdot
.66961 .4612 Mdot
.67872 .20882 Mdot
.41117 .60918 Mdot
.34854 .77371 Mdot
.37111 .46007 Mdot
.4428 .661 Mdot
.62711 .41899 Mdot
.27325 .57406 Mdot
.43781 .60926 Mdot
.2677 .47937 Mdot
.61856 .46889 Mdot
.47551 .32665 Mdot
.61184 .47924 Mdot
.67289 .52114 Mdot
.37322 .6197 Mdot
.67393 .48704 Mdot
.35386 .45778 Mdot
.44315 .31202 Mdot
.22849 .32598 Mdot
.38885 .39364 Mdot
.67223 .43898 Mdot
.64512 .46354 Mdot
.5031 .32077 Mdot
.67342 .42932 Mdot
.34146 .46102 Mdot
.70602 .81795 Mdot
.54706 .66963 Mdot
.38538 .64303 Mdot
.3282 .71428 Mdot
.69511 .47803 Mdot
.64965 .50556 Mdot
.46364 .17097 Mdot
.32516 .72098 Mdot
.35669 .45242 Mdot
.70331 .42722 Mdot
.42855 .60258 Mdot
.57053 .66718 Mdot
.37873 .4363 Mdot
.65526 .49373 Mdot
.64134 .44557 Mdot
.5617 .6985 Mdot
.5272 .31539 Mdot
.61839 .76921 Mdot
.38709 .48685 Mdot
.60166 .53756 Mdot
.37775 .68805 Mdot
.68095 .46836 Mdot
.65786 .75171 Mdot
.4372 .35037 Mdot
.34777 .49792 Mdot
.20839 .55872 Mdot
.6575 .51106 Mdot
.39045 .4489 Mdot
.35824 .46696 Mdot
.70099 .42649 Mdot
.41889 .33896 Mdot
.44633 .3039 Mdot
.4583 .3682 Mdot
.73222 .75504 Mdot
.71538 .6045 Mdot
.40203 .64717 Mdot
.38742 .45946 Mdot
.38112 .61309 Mdot
.53807 .65072 Mdot
.51271 .45354 Mdot
.38068 .62799 Mdot
.43448 .35741 Mdot
.45895 .62574 Mdot
.61426 .47311 Mdot
.35952 .47144 Mdot
.41414 .65743 Mdot
.6861 .50092 Mdot
.33215 .2953 Mdot
.35417 .57166 Mdot
.55803 .70277 Mdot
.59013 .67902 Mdot
.61262 .43183 Mdot
.44246 .59677 Mdot
.64743 .43979 Mdot
.33257 .46465 Mdot
.34615 .30079 Mdot
.69808 .48118 Mdot
.40699 .62401 Mdot
.50603 .37894 Mdot
.58106 .7597 Mdot
.69965 .49485 Mdot
.62656 .45627 Mdot
.67255 .4759 Mdot
.63604 .47534 Mdot
.25073 .40411 Mdot
.37216 .42909 Mdot
.40164 .30774 Mdot
.26765 .65602 Mdot
.45923 .3225 Mdot
.42828 .31783 Mdot
.60139 .74769 Mdot
.30856 .50652 Mdot
.37374 .45081 Mdot
.6642 .48041 Mdot
.29722 .42859 Mdot
.31425 .23975 Mdot
.59269 .15435 Mdot
.57365 .72593 Mdot
.45069 .64333 Mdot
.50384 .3338 Mdot
.44444 .62499 Mdot
.6661 .46644 Mdot
.58184 .41491 Mdot
.13216 .49186 Mdot
.40196 .47778 Mdot
.55015 .65792 Mdot
.67001 .47588 Mdot
.72227 .59861 Mdot
.43226 .61847 Mdot
.37685 .63758 Mdot
.65245 .42357 Mdot
.42481 .35342 Mdot
.25732 .71632 Mdot
.35561 .4953 Mdot
.39936 .27339 Mdot
.6151 .54793 Mdot
.38628 .32218 Mdot
.36829 .48665 Mdot
.53525 .77311 Mdot
.45047 .61864 Mdot
.51559 .25799 Mdot
.45983 .32046 Mdot
.54095 .66738 Mdot
.59722 .40983 Mdot
.46106 .31227 Mdot
.41121 .57998 Mdot
.48054 .32533 Mdot
.61132 .50077 Mdot
.39333 .43426 Mdot
.43973 .63265 Mdot
.37164 .51677 Mdot
.42001 .33397 Mdot
.58124 .67412 Mdot
.46496 .54368 Mdot
.71351 .33101 Mdot
.56748 .30066 Mdot
.68089 .4398 Mdot
.53265 .53105 Mdot
.6267 .48921 Mdot
.44973 .29508 Mdot
.641 .4716 Mdot
.52158 .34817 Mdot
.44346 .63789 Mdot
.63511 .41634 Mdot
.6536 .49934 Mdot
.68802 .27368 Mdot
.62574 .44104 Mdot
.57976 .45626 Mdot
.6566 .4819 Mdot
.48048 .28092 Mdot
.68891 .40608 Mdot
.47674 .34915 Mdot
.49624 .77572 Mdot
.42689 .63435 Mdot
.58861 .67984 Mdot
.53519 .67338 Mdot
.71016 .57128 Mdot
.47238 .67497 Mdot
.26763 .39845 Mdot
.46733 .34194 Mdot
.35397 .46262 Mdot
.64065 .47485 Mdot
.17355 .53341 Mdot
.31847 .65313 Mdot
.42219 .59477 Mdot
.38829 .39331 Mdot
.56924 .51143 Mdot
.24483 .66354 Mdot
.61244 .42436 Mdot
.76834 .70215 Mdot
.63222 .53105 Mdot
.58732 .45527 Mdot
.37741 .61723 Mdot
.58131 .6342 Mdot
.65686 .42171 Mdot
.48406 .30683 Mdot
.54992 .69087 Mdot
.40751 .33776 Mdot
.36099 .61391 Mdot
.50574 .76951 Mdot
.66438 .27542 Mdot
.63275 .48304 Mdot
.4396 .63496 Mdot
.48417 .3501 Mdot
.546 .8025 Mdot
.34267 .48311 Mdot
.3174 .49956 Mdot
.60161 .55823 Mdot
.56622 .16984 Mdot
.54086 .68252 Mdot
.53752 .33803 Mdot
.60565 .45408 Mdot
.54225 .73042 Mdot
.68772 .43429 Mdot
.31788 .23957 Mdot
.54347 .64913 Mdot
.42936 .32465 Mdot
.37224 .44552 Mdot
.45015 .37406 Mdot
.57133 .31646 Mdot
.4401 .55971 Mdot
.48332 .5127 Mdot
.42648 .62106 Mdot
.42322 .49674 Mdot
.45345 .35528 Mdot
.6386 .50939 Mdot
.39448 .86558 Mdot
.44099 .35725 Mdot
.49893 .33131 Mdot
.72864 .27488 Mdot
.68362 .22236 Mdot
.5725 .5198 Mdot
.44802 .31453 Mdot
.42489 .62522 Mdot
.57666 .67641 Mdot
.61619 .48941 Mdot
.62343 .47706 Mdot
.45644 .3146 Mdot
.37566 .62988 Mdot
.65639 .36419 Mdot
.40989 .63486 Mdot
.4699 .35768 Mdot
.42595 .64188 Mdot
.26266 .58746 Mdot
.42803 .66146 Mdot
.68011 .43197 Mdot
.64101 .47257 Mdot
.39247 .71253 Mdot
.47189 .32409 Mdot
.64353 .50175 Mdot
.59933 .47786 Mdot
.44912 .34338 Mdot
.60562 .6441 Mdot
.61794 .36503 Mdot
.67756 .45218 Mdot
.61487 .45655 Mdot
.56802 .69885 Mdot
.51796 .46643 Mdot
.79843 .58162 Mdot
.63483 .50558 Mdot
.5732 .6371 Mdot
.46629 .3052 Mdot
.64279 .43583 Mdot
.26125 .32008 Mdot
.25966 .53721 Mdot
.64818 .51215 Mdot
.42256 .66395 Mdot
.68504 .4129 Mdot
.20838 .64623 Mdot
.64068 .42435 Mdot
.45458 .34619 Mdot
.49765 .34448 Mdot
.77474 .36586 Mdot
.44002 .34587 Mdot
.40828 .5965 Mdot
.37054 .47674 Mdot
.32105 .2461 Mdot
.42142 .59982 Mdot
.69618 .4937 Mdot
.80452 .38953 Mdot
.58183 .47661 Mdot
.69282 .49253 Mdot
.28112 .72316 Mdot
.42386 .60316 Mdot
.48465 .36471 Mdot
.49586 .58307 Mdot
.57374 .48608 Mdot
.35506 .49953 Mdot
.6319 .39725 Mdot
.68632 .47206 Mdot
.33014 .74485 Mdot
.25258 .48261 Mdot
.33101 .48657 Mdot
.57111 .44525 Mdot
.63695 .50581 Mdot
.3963 .56028 Mdot
.64617 .46942 Mdot
.57472 .68393 Mdot
.49714 .35577 Mdot
.44267 .64936 Mdot
.55594 .67495 Mdot
.66819 .44976 Mdot
.56408 .65627 Mdot
.41634 .65492 Mdot
.3566 .50373 Mdot
.67075 .46707 Mdot
.53226 .68441 Mdot
.56021 .65747 Mdot
.62869 .49331 Mdot
.4874 .32935 Mdot
.62475 .53228 Mdot
.63616 .43261 Mdot
.61011 .49157 Mdot
.46101 .31488 Mdot
.52615 .11984 Mdot
.63125 .42348 Mdot
.49938 .64054 Mdot
.49529 .32716 Mdot
.41135 .5278 Mdot
.44528 .64817 Mdot
.68747 .46704 Mdot
.34502 .50036 Mdot
.38964 .47122 Mdot
.39671 .59441 Mdot
.50563 .35287 Mdot
.4118 .72748 Mdot
.5126 .37162 Mdot
.59367 .50549 Mdot
.59907 .50179 Mdot
.81153 .43928 Mdot
.16558 .435 Mdot
.46844 .37542 Mdot
.38096 .652 Mdot
.52928 .58936 Mdot
.38586 .45235 Mdot
.42476 .66924 Mdot
.50615 .34092 Mdot
.50254 .35034 Mdot
.48308 .33225 Mdot
.5444 .65857 Mdot
.40112 .71139 Mdot
.4346 .37597 Mdot
.42547 .34748 Mdot
.61667 .46988 Mdot
.64162 .50565 Mdot
.62133 .68052 Mdot
.66989 .69399 Mdot
.58472 .66617 Mdot
.39834 .62849 Mdot
.64484 .83779 Mdot
.33384 .46343 Mdot
.67383 .25894 Mdot
.69703 .48246 Mdot
.37331 .88281 Mdot
.61916 .42285 Mdot
.64879 .46748 Mdot
.4454 .31134 Mdot
.5424 .69653 Mdot
.55652 .68562 Mdot
.45712 .36143 Mdot
.44501 .29649 Mdot
.57362 .68515 Mdot
.43434 .22439 Mdot
.27738 .28248 Mdot
.46373 .57603 Mdot
.45254 .33578 Mdot
.69839 .32142 Mdot
.37273 .50511 Mdot
.44174 .39288 Mdot
.34916 .44538 Mdot
.43246 .62566 Mdot
.43906 .59277 Mdot
.36803 .49587 Mdot
.62052 .46939 Mdot
.39549 .64411 Mdot
.5752 .4634 Mdot
.44325 .23713 Mdot
.61424 .34881 Mdot
.3492 .71211 Mdot
.63576 .40669 Mdot
.51906 .77588 Mdot
.31605 .52333 Mdot
.66016 .43745 Mdot
.21431 .42613 Mdot
.55382 .65622 Mdot
.4362 .38614 Mdot
.33305 .48018 Mdot
.19625 .64353 Mdot
.67643 .47551 Mdot
.45662 .34231 Mdot
.36251 .45703 Mdot
.71712 .54249 Mdot
.36056 .30776 Mdot
.67066 .47418 Mdot
.42468 .87791 Mdot
.46225 .27607 Mdot
.44016 .65205 Mdot
.81515 .50552 Mdot
.45479 .37879 Mdot
.58246 .72018 Mdot
.27178 .64809 Mdot
.51529 .17204 Mdot
.48155 .36272 Mdot
.42685 .67112 Mdot
.4638 .36876 Mdot
.58085 .67716 Mdot
.49202 .38144 Mdot
.43711 .62055 Mdot
.62998 .44315 Mdot
.40233 .62528 Mdot
.58376 .65589 Mdot
.62754 .75497 Mdot
.33306 .49009 Mdot
.43084 .66502 Mdot
.38123 .47434 Mdot
.73328 .62252 Mdot
.26283 .66482 Mdot
.33975 .4733 Mdot
.77703 .44366 Mdot
.66034 .51173 Mdot
.43894 .37523 Mdot
.39536 .61162 Mdot
.27554 .6379 Mdot
.48604 .56084 Mdot
.45189 .32501 Mdot
.40574 .64352 Mdot
.57277 .54924 Mdot
.79351 .46658 Mdot
.71943 .44744 Mdot
.73331 .64099 Mdot
.44905 .33823 Mdot
.43554 .67088 Mdot
.56091 .80069 Mdot
.43752 .3633 Mdot
.40161 .60569 Mdot
.38028 .4434 Mdot
.36426 .48204 Mdot
.66334 .42661 Mdot
.36025 .52322 Mdot
.39505 .63405 Mdot
.34721 .54175 Mdot
.47525 .30741 Mdot
.68793 .55976 Mdot
.53253 .66888 Mdot
.41986 .63449 Mdot
.59434 .48961 Mdot
.42466 .37735 Mdot
.25813 .56513 Mdot
.69914 .36892 Mdot
.58582 .83865 Mdot
.39854 .62214 Mdot
.50137 .34518 Mdot
.45918 .33849 Mdot
.69904 .49488 Mdot
.51468 .56934 Mdot
.41094 .7243 Mdot
.76917 .51416 Mdot
.70001 .56529 Mdot
.40308 .58072 Mdot
.39571 .57789 Mdot
.66772 .5138 Mdot
.63893 .48506 Mdot
.38246 .44796 Mdot
.62636 .4472 Mdot
.4364 .31644 Mdot
.66692 .42674 Mdot
.36977 .48997 Mdot
.42186 .6157 Mdot
.6671 .461 Mdot
.58203 .66491 Mdot
.34691 .50559 Mdot
.39533 .44976 Mdot
.41425 .62953 Mdot
.46393 .31162 Mdot
.54009 .63525 Mdot
.40834 .63552 Mdot
.63235 .4822 Mdot
.30744 .45435 Mdot
.60167 .48958 Mdot
.47025 .23462 Mdot
.43519 .36076 Mdot
.44528 .63181 Mdot
.47689 .30663 Mdot
.38387 .4664 Mdot
.26716 .65287 Mdot
.63319 .46501 Mdot
.40548 .6041 Mdot
.37958 .70101 Mdot
.47001 .24592 Mdot
.4947 .30616 Mdot
.28155 .48552 Mdot
.43566 .30565 Mdot
.42454 .58168 Mdot
.73706 .30233 Mdot
.54109 .67901 Mdot
.42472 .59623 Mdot
.20145 .37899 Mdot
.4092 .61611 Mdot
.62165 .43933 Mdot
.60825 .43727 Mdot
.43876 .65517 Mdot
.5498 .69697 Mdot
.52896 .80619 Mdot
.44749 .58186 Mdot
.48474 .3632 Mdot
.55397 .18594 Mdot
.50618 .84897 Mdot
.34798 .52461 Mdot
.37294 .44701 Mdot
.57289 .48706 Mdot
.58639 .46311 Mdot
.3547 .44272 Mdot
.40053 .46854 Mdot
.56131 .64586 Mdot
.40478 .58898 Mdot
.49561 .28996 Mdot
.37661 .50755 Mdot
.71108 .39884 Mdot
.47452 .67828 Mdot
.71135 .46637 Mdot
.58611 .54306 Mdot
.68197 .4283 Mdot
.71951 .55665 Mdot
.36761 .49281 Mdot
.59578 .45082 Mdot
.71369 .44375 Mdot
.34493 .49904 Mdot
.57678 .68129 Mdot
.27673 .44094 Mdot
.4314 .64458 Mdot
.35036 .19234 Mdot
.5908 .46076 Mdot
.62291 .43624 Mdot
.37716 .49691 Mdot
.43691 .74459 Mdot
.47136 .31789 Mdot
.43732 .36573 Mdot
.39345 .64572 Mdot
.46789 .53934 Mdot
.68564 .45992 Mdot
.65025 .43176 Mdot
.43575 .64659 Mdot
.43998 .66228 Mdot
.34056 .57035 Mdot
.60362 .46467 Mdot
.36717 .45598 Mdot
.54639 .60171 Mdot
.36906 .49224 Mdot
.59764 .48934 Mdot
.61728 .43954 Mdot
.67961 .43181 Mdot
.5964 .49169 Mdot
.39306 .4424 Mdot
.59656 .45357 Mdot
.73003 .45398 Mdot
.47611 .31693 Mdot
.67074 .48658 Mdot
.7167 .55454 Mdot
.62181 .45573 Mdot
.57619 .67858 Mdot
.71885 .3953 Mdot
.67566 .47352 Mdot
.68762 .45892 Mdot
.45975 .59866 Mdot
.63685 .45175 Mdot
.33414 .46201 Mdot
.46249 .32625 Mdot
.38774 .46088 Mdot
.38585 .48621 Mdot
.38931 .60693 Mdot
.58303 .64996 Mdot
.69438 .47726 Mdot
.55589 .6495 Mdot
.69707 .44879 Mdot
.65048 .51285 Mdot
.29922 .67253 Mdot
.77887 .68842 Mdot
.6286 .76802 Mdot
.63229 .46621 Mdot
.41662 .60391 Mdot
.4467 .64239 Mdot
.42705 .28447 Mdot
.71856 .45295 Mdot
.35979 .44027 Mdot
.3909 .46387 Mdot
.6495 .68906 Mdot
.322 .73195 Mdot
.57639 .67943 Mdot
.52015 .50698 Mdot
.57457 .46971 Mdot
.6026 .48048 Mdot
.58424 .47336 Mdot
.38067 .61612 Mdot
.52583 .60292 Mdot
.42403 .59676 Mdot
.36886 .38958 Mdot
.37553 .4903 Mdot
.67573 .47904 Mdot
.52753 .37583 Mdot
.43755 .35715 Mdot
.46328 .3262 Mdot
.38848 .44181 Mdot
.46315 .65322 Mdot
.61448 .7201 Mdot
.63709 .16787 Mdot
.47077 .27373 Mdot
.55259 .70274 Mdot
.6649 .43876 Mdot
.41829 .61906 Mdot
.45682 .37006 Mdot
.57973 .6954 Mdot
.63148 .50955 Mdot
.39939 .71136 Mdot
.62992 .46971 Mdot
.54094 .50816 Mdot
.49018 .34011 Mdot
.30308 .25568 Mdot
.49507 .36688 Mdot
.34341 .50327 Mdot
.33539 .48361 Mdot
.61114 .43804 Mdot
.81173 .46611 Mdot
.44164 .37322 Mdot
.39662 .51588 Mdot
.54629 .64815 Mdot
.26825 .55701 Mdot
.57831 .68344 Mdot
.44288 .64497 Mdot
.5469 .68915 Mdot
.44045 .62605 Mdot
.64309 .71884 Mdot
.49974 .30451 Mdot
.55086 .67086 Mdot
.48626 .63982 Mdot
.71903 .46014 Mdot
.58603 .68211 Mdot
.5671 .47044 Mdot
.51237 .2201 Mdot
.43053 .64999 Mdot
.53643 .67138 Mdot
.63638 .50885 Mdot
.15694 .52803 Mdot
.35227 .45722 Mdot
.35423 .44442 Mdot
.59439 .50525 Mdot
.38932 .59844 Mdot
.49248 .31373 Mdot
.26007 .35275 Mdot
.32765 .45707 Mdot
.62092 .42892 Mdot
.65896 .42253 Mdot
.42552 .32621 Mdot
.43567 .40915 Mdot
.61152 .44113 Mdot
.76317 .43709 Mdot
.60145 .45758 Mdot
.37858 .44136 Mdot
.45564 .37475 Mdot
.46084 .33306 Mdot
.4047 .64512 Mdot
.4362 .32525 Mdot
.4668 .26184 Mdot
.30955 .43415 Mdot
.57257 .49265 Mdot
.37896 .46296 Mdot
.34338 .40534 Mdot
.37157 .38922 Mdot
.17895 .4306 Mdot
.4234 .3285 Mdot
.6691 .41987 Mdot
.47845 .30956 Mdot
.57322 .66835 Mdot
.47314 .32808 Mdot
.50204 .32927 Mdot
.65154 .43827 Mdot
.66572 .4698 Mdot
.42509 .60933 Mdot
.51681 .57558 Mdot
.47323 .31156 Mdot
.60674 .43617 Mdot
.58191 .45385 Mdot
.57796 .46135 Mdot
.46628 .43914 Mdot
.46657 .37472 Mdot
.65579 .23408 Mdot
.62854 .6044 Mdot
.47209 .31111 Mdot
.22314 .68561 Mdot
.27419 .62918 Mdot
.45403 .6514 Mdot
.34783 .51582 Mdot
.60352 .4661 Mdot
.44884 .6432 Mdot
.66634 .46613 Mdot
.58742 .54384 Mdot
.64422 .44822 Mdot
.57099 .68904 Mdot
.57476 .45316 Mdot
.42763 .58115 Mdot
.40554 .63153 Mdot
.63263 .42519 Mdot
.66329 .45719 Mdot
.61702 .75936 Mdot
.4363 .29973 Mdot
.47457 .32098 Mdot
.41451 .73733 Mdot
.55764 .66484 Mdot
.35202 .49903 Mdot
.64942 .47692 Mdot
.38737 .61259 Mdot
.40301 .6287 Mdot
.45623 .37787 Mdot
.41521 .64645 Mdot
.35768 .49496 Mdot
.63634 .46529 Mdot
.35253 .44483 Mdot
.54593 .65598 Mdot
.46807 .37151 Mdot
.67141 .47967 Mdot
.61642 .46945 Mdot
.49759 .34501 Mdot
.68579 .4925 Mdot
.56837 .69834 Mdot
.40696 .6165 Mdot
.48104 .35998 Mdot
.36901 .47806 Mdot
.44408 .63588 Mdot
.61066 .48602 Mdot
.6222 .83998 Mdot
.61888 .44364 Mdot
.60633 .47223 Mdot
.19645 .37465 Mdot
.57289 .45643 Mdot
.39581 .61578 Mdot
.42737 .33516 Mdot
.61045 .41943 Mdot
.70324 .58086 Mdot
.56426 .13766 Mdot
.41894 .59373 Mdot
.66547 .43653 Mdot
.14739 .48398 Mdot
.65391 .42933 Mdot
.78713 .40416 Mdot
.50555 .68076 Mdot
.43265 .50781 Mdot
.64799 .5312 Mdot
.3538 .4865 Mdot
.42403 .60744 Mdot
.44224 .64197 Mdot
.6075 .20357 Mdot
.65101 .43557 Mdot
.54003 .51794 Mdot
.66237 .50382 Mdot
.36645 .48579 Mdot
.63993 .66927 Mdot
.3996 .62559 Mdot
.64341 .78501 Mdot
.62461 .4862 Mdot
.47573 .37504 Mdot
.46055 .63415 Mdot
.27515 .60355 Mdot
.61167 .49151 Mdot
.56141 .64972 Mdot
.36334 .51287 Mdot
.58922 .43508 Mdot
.37519 .46546 Mdot
.6075 .49218 Mdot
.68402 .38594 Mdot
.82421 .53823 Mdot
.48598 .33083 Mdot
.37635 .44465 Mdot
.30408 .47069 Mdot
.65636 .4087 Mdot
.48208 .36107 Mdot
.45848 .32078 Mdot
.5648 .64656 Mdot
.49177 .50139 Mdot
.33687 .34603 Mdot
.67959 .34892 Mdot
.59723 .1954 Mdot
.4618 .64213 Mdot
.29024 .51954 Mdot
.62021 .4968 Mdot
.3831 .75879 Mdot
.3298 .47691 Mdot
.62614 .43751 Mdot
.52252 .23906 Mdot
.45432 .36554 Mdot
.61154 .45497 Mdot
.56783 .68636 Mdot
.4138 .76427 Mdot
.40797 .77123 Mdot
.22787 .61393 Mdot
.42817 .62242 Mdot
.58923 .41007 Mdot
.55394 .4484 Mdot
.38928 .64538 Mdot
.6824 .49056 Mdot
.4005 .61078 Mdot
.47673 .20106 Mdot
.57104 .70045 Mdot
.47407 .37276 Mdot
.27586 .62185 Mdot
.69076 .4702 Mdot
.59008 .49571 Mdot
.59079 .68424 Mdot
.64234 .48967 Mdot
.80966 .62 Mdot
.32955 .67178 Mdot
.40716 .65449 Mdot
.48375 .33172 Mdot
.69002 .45685 Mdot
.50367 .50045 Mdot
.63988 .43139 Mdot
.64152 .31554 Mdot
.68802 .45687 Mdot
.34919 .32833 Mdot
.49281 .33778 Mdot
.37815 .46733 Mdot
.67565 .41206 Mdot
.64609 .4544 Mdot
.574 .6001 Mdot
.63312 .52975 Mdot
.60917 .43077 Mdot
.49264 .30975 Mdot
.45051 .36986 Mdot
.47563 .34899 Mdot
.43553 .59819 Mdot
.32775 .73876 Mdot
.37758 .45465 Mdot
.67251 .40379 Mdot
.38144 .50546 Mdot
.74278 .39613 Mdot
.563 .70326 Mdot
.17111 .51298 Mdot
.66113 .49006 Mdot
.46868 .34771 Mdot
.23054 .4681 Mdot
.46302 .30336 Mdot
.5227 .53394 Mdot
.35822 .46938 Mdot
.4492 .36235 Mdot
.64806 .46193 Mdot
.51055 .58395 Mdot
.18844 .57411 Mdot
.38617 .47312 Mdot
.70019 .46171 Mdot
.45179 .64204 Mdot
.31681 .70054 Mdot
.60645 .84514 Mdot
.35482 .45362 Mdot
.30674 .46849 Mdot
.65333 .43474 Mdot
.43429 .35333 Mdot
.35505 .49007 Mdot
.34489 .46592 Mdot
.41447 .64761 Mdot
.66613 .47241 Mdot
.66663 .47646 Mdot
.43368 .58995 Mdot
.38795 .47389 Mdot
.64813 .52509 Mdot
.59058 .44494 Mdot
.12738 .5003 Mdot
.60714 .57158 Mdot
.40637 .1515 Mdot
.4735 .26501 Mdot
.52668 .25852 Mdot
.27863 .31977 Mdot
.50232 .34441 Mdot
.67669 .47177 Mdot
.61039 .40972 Mdot
.39551 .63371 Mdot
.62972 .45408 Mdot
.37717 .64343 Mdot
.36906 .4506 Mdot
.21784 .66982 Mdot
.32373 .39546 Mdot
.48242 .1878 Mdot
.63099 .45166 Mdot
.39913 .39503 Mdot
.5646 .67575 Mdot
.39623 .42753 Mdot
.47618 .35689 Mdot
.61252 .50279 Mdot
.6169 .76137 Mdot
.42498 .59692 Mdot
.44242 .32765 Mdot
.55675 .79143 Mdot
.52473 .77306 Mdot
.59849 .49073 Mdot
.44184 .60865 Mdot
.22497 .43872 Mdot
.76039 .44874 Mdot
.36128 .43157 Mdot
.57387 .68702 Mdot
.43044 .60919 Mdot
.38921 .47782 Mdot
.52405 .32638 Mdot
.44279 .35522 Mdot
.51006 .3636 Mdot
.67849 .73359 Mdot
.39328 .65148 Mdot
.56167 .67881 Mdot
.31921 .72552 Mdot
.39506 .77646 Mdot
.5692 .68961 Mdot
.4424 .59845 Mdot
.4532 .37026 Mdot
.46208 .35747 Mdot
.4616 .32674 Mdot
.62245 .79068 Mdot
.50026 .36251 Mdot
.63735 .24145 Mdot
.58164 .47803 Mdot
.59695 .39111 Mdot
.66175 .43332 Mdot
.36289 .4374 Mdot
.49155 .34781 Mdot
.45334 .53745 Mdot
.70529 .44023 Mdot
.21983 .62372 Mdot
.63988 .42798 Mdot
.39244 .42954 Mdot
.60806 .46116 Mdot
.67952 .27729 Mdot
.48284 .313 Mdot
.6304 .46161 Mdot
.34561 .44588 Mdot
.5644 .66104 Mdot
.51474 .36328 Mdot
.67225 .47569 Mdot
.2745 .37619 Mdot
.57333 .45439 Mdot
.42944 .21629 Mdot
.65023 .57215 Mdot
.5527 .70273 Mdot
.684 .53979 Mdot
.39724 .65903 Mdot
.56548 .40728 Mdot
.59826 .39887 Mdot
.38305 .47745 Mdot
.24972 .59396 Mdot
.42677 .63255 Mdot
.55525 .72484 Mdot
.65365 .39584 Mdot
.58623 .66089 Mdot
.44623 .29374 Mdot
.37515 .43242 Mdot
.66194 .51327 Mdot
.7091 .46311 Mdot
.48368 .21465 Mdot
.68789 .40229 Mdot
.66988 .4274 Mdot
.57693 .701 Mdot
.59407 .21058 Mdot
.62005 .46001 Mdot
.51877 .52488 Mdot
.49734 .37729 Mdot
.63226 .52703 Mdot
.67984 .25737 Mdot
.61138 .43321 Mdot
.43629 .33707 Mdot
.50911 .32369 Mdot
.28302 .4121 Mdot
.55699 .64418 Mdot
.68722 .46509 Mdot
.77126 .36207 Mdot
.629 .48639 Mdot
.36835 .4573 Mdot
.58879 .46937 Mdot
.43438 .6188 Mdot
.61092 .7885 Mdot
.39608 .64103 Mdot
.68123 .4539 Mdot
.45761 .3294 Mdot
.37348 .49697 Mdot
.67901 .74734 Mdot
.45151 .70205 Mdot
.6243 .2324 Mdot
.48963 .16775 Mdot
.54318 .69037 Mdot
.58894 .6544 Mdot
.38059 .43216 Mdot
.6291 .46231 Mdot
.74207 .29592 Mdot
.62309 .52816 Mdot
.61386 .45793 Mdot
.64557 .44806 Mdot
.28438 .69037 Mdot
.38208 .45024 Mdot
.42311 .64619 Mdot
.61365 .44103 Mdot
.59842 .44615 Mdot
.50016 .33807 Mdot
.56148 .65905 Mdot
.44587 .64635 Mdot
.54808 .66438 Mdot
.41707 .6107 Mdot
.21606 .67504 Mdot
.67824 .41058 Mdot
.56412 .66338 Mdot
.33496 .50121 Mdot
.45767 .3149 Mdot
.30508 .44042 Mdot
.44214 .64531 Mdot
.39811 .63052 Mdot
.63316 .4275 Mdot
.43538 .33709 Mdot
.45381 .30976 Mdot
.57429 .66714 Mdot
.33925 .48021 Mdot
.67415 .47024 Mdot
.64266 .51322 Mdot
.40547 .30612 Mdot
.38629 .60559 Mdot
.56199 .53503 Mdot
.25895 .42093 Mdot
.63035 .46575 Mdot
.45414 .31193 Mdot
.65634 .44929 Mdot
.29461 .28866 Mdot
.43262 .34578 Mdot
.61743 .42609 Mdot
.44706 .80796 Mdot
.45155 .67761 Mdot
.30057 .37714 Mdot
.66868 .42353 Mdot
.39267 .19201 Mdot
.6323 .50239 Mdot
.12196 .52785 Mdot
.51017 .71324 Mdot
.68134 .47152 Mdot
.61275 .48405 Mdot
.62116 .35858 Mdot
.67163 .44992 Mdot
.42663 .58205 Mdot
.5952 .73507 Mdot
.49728 .31819 Mdot
.30067 .32384 Mdot
.56499 .39059 Mdot
.54145 .65203 Mdot
.3948 .64713 Mdot
.3911 .57559 Mdot
.55774 .6895 Mdot
.45201 .33868 Mdot
.63633 .4756 Mdot
.46279 .51486 Mdot
.39263 .58817 Mdot
.69676 .50734 Mdot
.36567 .46044 Mdot
.31101 .56735 Mdot
.46309 .66155 Mdot
.3734 .47387 Mdot
.6681 .49222 Mdot
.62326 .36136 Mdot
.72199 .67944 Mdot
.27346 .27642 Mdot
.38531 .4891 Mdot
.38436 .48145 Mdot
.60332 .80127 Mdot
.53431 .65973 Mdot
.50465 .20241 Mdot
.35435 .31758 Mdot
.36244 .49936 Mdot
.7531 .49394 Mdot
.41051 .5901 Mdot
.28321 .36979 Mdot
.4366 .38658 Mdot
.59552 .49747 Mdot
.64713 .45966 Mdot
.33878 .48383 Mdot
.45709 .2527 Mdot
.81883 .52916 Mdot
.38034 .47627 Mdot
.73047 .43805 Mdot
.45955 .4584 Mdot
.27426 .63154 Mdot
.39483 .59838 Mdot
.56118 .64413 Mdot
.56562 .71634 Mdot
.48806 .3644 Mdot
.57389 .64519 Mdot
.40377 .76275 Mdot
.64929 .4895 Mdot
.37536 .48386 Mdot
.26067 .56398 Mdot
.36632 .47644 Mdot
.55624 .68724 Mdot
.55435 .70402 Mdot
.47586 .31698 Mdot
.47554 .32291 Mdot
.53803 .27647 Mdot
.65604 .64983 Mdot
.64733 .42719 Mdot
.20545 .5495 Mdot
.47419 .30688 Mdot
.61335 .54448 Mdot
.58853 .65641 Mdot
.56064 .66183 Mdot
.6012 .59286 Mdot
.6606 .48154 Mdot
.77736 .38152 Mdot
.65602 .47911 Mdot
.64384 .6638 Mdot
.6922 .44664 Mdot
.41465 .64707 Mdot
.66496 .48346 Mdot
.54846 .62794 Mdot
.6593 .51613 Mdot
.5893 .45365 Mdot
.38406 .60552 Mdot
.5946 .42971 Mdot
.4352 .62139 Mdot
.67802 .44365 Mdot
.54211 .64831 Mdot
.38391 .62422 Mdot
.70937 .59863 Mdot
.50881 .61942 Mdot
.44917 .61115 Mdot
.5795 .65264 Mdot
.53655 .66155 Mdot
.7425 .56636 Mdot
.47576 .3579 Mdot
.4734 .39121 Mdot
.62786 .4587 Mdot
.37781 .64068 Mdot
.37926 .44705 Mdot
.59771 .45282 Mdot
.58404 .43032 Mdot
.65074 .41832 Mdot
.48139 .37004 Mdot
.40328 .72289 Mdot
.56948 .66378 Mdot
.43202 .59295 Mdot
.59907 .63647 Mdot
.40143 .58619 Mdot
.70547 .4236 Mdot
.60248 .40837 Mdot
.52481 .28248 Mdot
.22977 .52519 Mdot
.58488 .81923 Mdot
.4399 .35114 Mdot
.42664 .66456 Mdot
.53411 .66407 Mdot
.65135 .54043 Mdot
.46906 .35425 Mdot
.43674 .62044 Mdot
.63078 .47003 Mdot
.70018 .45868 Mdot
.3667 .40652 Mdot
.55006 .42382 Mdot
.67625 .57805 Mdot
.40299 .58681 Mdot
.42361 .67062 Mdot
.39055 .77133 Mdot
.58889 .73397 Mdot
.4757 .55203 Mdot
.63814 .43809 Mdot
.55901 .65004 Mdot
.45664 .36996 Mdot
.70102 .70648 Mdot
.33617 .47158 Mdot
.51559 .57292 Mdot
.63143 .45334 Mdot
.42157 .51976 Mdot
.45776 .32785 Mdot
.57139 .68365 Mdot
.33941 .48626 Mdot
.5834 .70199 Mdot
.38215 .63507 Mdot
.59408 .1659 Mdot
.63374 .48807 Mdot
.64333 .42483 Mdot
.33284 .49232 Mdot
.45956 .36643 Mdot
.59212 .68601 Mdot
.45023 .23017 Mdot
.42447 .6571 Mdot
.75744 .31324 Mdot
.43715 .32032 Mdot
.67293 .28544 Mdot
.4274 .58858 Mdot
.38956 .44334 Mdot
.73219 .58559 Mdot
.36867 .48995 Mdot
.68347 .45164 Mdot
.46509 .33927 Mdot
.35699 .45564 Mdot
.54212 .58023 Mdot
.15141 .50377 Mdot
.69146 .31064 Mdot
.64912 .48313 Mdot
.16567 .56737 Mdot
.38238 .23687 Mdot
.44133 .2918 Mdot
.34516 .50089 Mdot
.63438 .43144 Mdot
.68036 .49034 Mdot
.62617 .48335 Mdot
.35289 .46898 Mdot
.29433 .6566 Mdot
.43145 .65124 Mdot
.65736 .43336 Mdot
.55965 .64638 Mdot
.43439 .6282 Mdot
.27427 .61967 Mdot
.39558 .62086 Mdot
.42683 .31163 Mdot
.58764 .46814 Mdot
.40895 .45112 Mdot
.15395 .6021 Mdot
.38808 .46385 Mdot
.44757 .60544 Mdot
.5941 .4669 Mdot
.25035 .55922 Mdot
.47386 .3499 Mdot
.41723 .65585 Mdot
.62381 .4359 Mdot
.28598 .6293 Mdot
.62871 .75893 Mdot
.39629 .62164 Mdot
.46773 .3612 Mdot
.24153 .3448 Mdot
.62717 .45007 Mdot
.63285 .50029 Mdot
.45471 .36016 Mdot
.6312 .37253 Mdot
.56193 .79646 Mdot
.66039 .45382 Mdot
.37773 .46907 Mdot
.73226 .25822 Mdot
.61282 .42125 Mdot
.61633 .61431 Mdot
.42713 .60891 Mdot
.2791 .39715 Mdot
.5721 .54624 Mdot
.62421 .54378 Mdot
.43533 .24468 Mdot
.4995 .42439 Mdot
.20916 .6346 Mdot
.38789 .65569 Mdot
.52951 .75691 Mdot
.2063 .64123 Mdot
.36883 .43156 Mdot
.49553 .40012 Mdot
.40336 .26355 Mdot
.68665 .76715 Mdot
.24075 .3585 Mdot
.45909 .75818 Mdot
.61313 .76514 Mdot
.45378 .48998 Mdot
.41174 .61074 Mdot
.5266 .69131 Mdot
.67017 .47006 Mdot
.38036 .23638 Mdot
.75525 .36063 Mdot
.82559 .48637 Mdot
.16104 .55804 Mdot
.77493 .39593 Mdot
.17133 .52911 Mdot
.18487 .41707 Mdot
.50749 .25659 Mdot
.23162 .50635 Mdot
.77293 .32672 Mdot
.43703 .7996 Mdot
.61866 .19404 Mdot
.55941 .4628 Mdot
.534 .53858 Mdot
.44789 .19733 Mdot
.63944 .25925 Mdot
.80151 .47912 Mdot
.40407 .64658 Mdot
.42648 .33934 Mdot
.39347 .26922 Mdot
.45723 .29478 Mdot
.33688 .52373 Mdot
.2492 .32535 Mdot
.14579 .4741 Mdot
.68122 .27451 Mdot
.36573 .19362 Mdot
.54256 .23615 Mdot
.85606 .60279 Mdot
.42967 .57325 Mdot
.45387 .3799 Mdot
.60108 .69799 Mdot
.3791 .76956 Mdot
.37336 .36628 Mdot
.40017 .2509 Mdot
.3088 .68492 Mdot
.70187 .63729 Mdot
.45629 .34097 Mdot
.67827 .54699 Mdot
.34793 .53472 Mdot
.3318 .39449 Mdot
.59125 .74145 Mdot
.20222 .39724 Mdot
.47896 .52817 Mdot
.28356 .35818 Mdot
.30192 .54326 Mdot
.60884 .83997 Mdot
.63637 .59758 Mdot
.49949 .2793 Mdot
.31847 .43754 Mdot
.28584 .30115 Mdot
.72542 .72905 Mdot
.66548 .66664 Mdot
.38418 .77205 Mdot
.33177 .7677 Mdot
.35465 .23647 Mdot
.3855 .82012 Mdot
.48449 .38761 Mdot
.66632 .42484 Mdot
.55571 .37145 Mdot
.76379 .35223 Mdot
.52539 .68144 Mdot
.23595 .61955 Mdot
.53866 .66434 Mdot
.41663 .33376 Mdot
.6007 .78652 Mdot
.65638 .25267 Mdot
.77565 .35944 Mdot
.59798 .66985 Mdot
.63627 .4068 Mdot
.79243 .27627 Mdot
.2058 .61984 Mdot
.29857 .39974 Mdot
.12415 .5069 Mdot
.4421 .53972 Mdot
.71178 .54563 Mdot
.3566 .45719 Mdot
.1881 .62405 Mdot
.46198 .35113 Mdot
.31355 .7868 Mdot
.14506 .56176 Mdot
.8051 .54566 Mdot
.49101 .08866 Mdot
.36473 .74066 Mdot
.43073 .51462 Mdot
.48181 .41992 Mdot
.6831 .59907 Mdot
.80867 .59475 Mdot
.79923 .51877 Mdot
.25381 .54163 Mdot
.46718 .17448 Mdot
.18995 .61666 Mdot
.75759 .33159 Mdot
.60182 .17485 Mdot
.70464 .75548 Mdot
.50933 .48295 Mdot
.42287 .38487 Mdot
.4364 .5683 Mdot
.20162 .44336 Mdot
.27404 .72441 Mdot
.62215 .60379 Mdot
.59162 .13835 Mdot
.57477 .63066 Mdot
.49841 .7114 Mdot
.25454 .30086 Mdot
.71835 .62397 Mdot
.66122 .5597 Mdot
.53349 .79422 Mdot
.70055 .4988 Mdot
.50458 .79387 Mdot
.18777 .522 Mdot
.29683 .46457 Mdot
.44356 .79781 Mdot
.2397 .39908 Mdot
.47049 .22208 Mdot
.61479 .34375 Mdot
.37636 .77387 Mdot
.47472 .30244 Mdot
.67964 .64457 Mdot
.6407 .56735 Mdot
.13944 .47625 Mdot
.30736 .46973 Mdot
.15311 .41898 Mdot
.57416 .78341 Mdot
.67182 .41601 Mdot
.56939 .41523 Mdot
.73569 .45958 Mdot
.66149 .63742 Mdot
.5921 .43973 Mdot
.37787 .3871 Mdot
.16302 .43129 Mdot
.53136 .2269 Mdot
.28421 .47615 Mdot
.25183 .60443 Mdot
.26639 .28053 Mdot
.54695 .32515 Mdot
.57133 .75112 Mdot
.6266 .67487 Mdot
.66761 .79793 Mdot
.42762 .63734 Mdot
.74851 .31699 Mdot
.37409 .42604 Mdot
.6537 .73787 Mdot
.69177 .35125 Mdot
.79791 .59902 Mdot
.16358 .42981 Mdot
.49161 .77558 Mdot
.59715 .77275 Mdot
.74331 .60946 Mdot
.73363 .27619 Mdot
.24803 .61323 Mdot
.62602 .39867 Mdot
.35103 .26876 Mdot
.54612 .69546 Mdot
.56387 .31238 Mdot
.68091 .23709 Mdot
.4602 .72884 Mdot
.57997 .49012 Mdot
.7578 .64233 Mdot
.35557 .67573 Mdot
.51009 .58177 Mdot
.47822 .85971 Mdot
.71636 .46027 Mdot
.32989 .73061 Mdot
.37347 .22705 Mdot
.65799 .60944 Mdot
.28058 .28761 Mdot
.26343 .36083 Mdot
.36299 .80369 Mdot
.13957 .53838 Mdot
.43764 .7101 Mdot
.22552 .66109 Mdot
.13182 .48431 Mdot
.39655 .81668 Mdot
.65382 .38802 Mdot
.32633 .48245 Mdot
.54268 .88241 Mdot
.41613 .58045 Mdot
.28327 .69799 Mdot
.5982 .19594 Mdot
.29068 .62575 Mdot
.50339 .29755 Mdot
.56142 .48925 Mdot
.45981 .49794 Mdot
.43727 .29395 Mdot
.59152 .43543 Mdot
.50665 .8454 Mdot
.37219 .79705 Mdot
.44821 .84159 Mdot
.382 .20981 Mdot
.22599 .67117 Mdot
.4312 .48127 Mdot
.6474 .25729 Mdot
.42031 .29619 Mdot
.60385 .50069 Mdot
.50227 .65963 Mdot
.36377 .73854 Mdot
.75408 .65261 Mdot
.36789 .35175 Mdot
.44142 .2962 Mdot
.21573 .57929 Mdot
.86648 .64995 Mdot
.54468 .25124 Mdot
.68005 .25264 Mdot
.40294 .77217 Mdot
.65045 .63812 Mdot
.19883 .46757 Mdot
.80137 .57335 Mdot
.19021 .388 Mdot
.44399 .28605 Mdot
.60151 .19174 Mdot
.47141 .75073 Mdot
.75874 .51197 Mdot
.39442 .72096 Mdot
.15752 .47823 Mdot
.43154 .42636 Mdot
.72321 .70084 Mdot
.36097 .29543 Mdot
.81112 .53761 Mdot
.51864 .70733 Mdot
.31689 .56723 Mdot
.68776 .2409 Mdot
.26391 .4853 Mdot
.63475 .63583 Mdot
.46896 .47194 Mdot
.68377 .53057 Mdot
.49779 .42385 Mdot
.63347 .62653 Mdot
.74379 .5363 Mdot
.25809 .69653 Mdot
.10561 .53885 Mdot
.58353 .83196 Mdot
.34358 .20009 Mdot
.19402 .50775 Mdot
.60688 .50962 Mdot
.22903 .31778 Mdot
.40896 .83817 Mdot
.13449 .55423 Mdot
.33897 .6137 Mdot
.36912 .63051 Mdot
.38841 .50161 Mdot
.54246 .82742 Mdot
.37479 .70437 Mdot
.21868 .35362 Mdot
.51734 .80061 Mdot
.36788 .51697 Mdot
.78682 .67748 Mdot
.35744 .78225 Mdot
.70233 .3453 Mdot
.54789 .43521 Mdot
.67325 .51759 Mdot
.70655 .30101 Mdot
.44076 .29996 Mdot
.29451 .52108 Mdot
.66435 .65395 Mdot
.41559 .63413 Mdot
.5088 .67574 Mdot
.39079 .2508 Mdot
.57452 .45396 Mdot
.51869 .41224 Mdot
.42459 .34647 Mdot
.23099 .51957 Mdot
.3173 .41827 Mdot
.25736 .71696 Mdot
.35182 .72084 Mdot
.66445 .52973 Mdot
.65241 .60807 Mdot
.38694 .72345 Mdot
.55804 .80344 Mdot
.39629 .44065 Mdot
.15726 .53943 Mdot
.53548 .55474 Mdot
.67678 .6455 Mdot
.72666 .32494 Mdot
.47821 .23158 Mdot
.57681 .42821 Mdot
.24687 .44031 Mdot
.62308 .30765 Mdot
.51916 .58021 Mdot
.41884 .37584 Mdot
.42712 .39118 Mdot
.24628 .28329 Mdot
.42167 .76663 Mdot
.29816 .54906 Mdot
.1596 .52594 Mdot
.35702 .47993 Mdot
.47068 .30863 Mdot
.50652 .65088 Mdot
.45753 .22082 Mdot
.63701 .28942 Mdot
.62898 .75928 Mdot
.32003 .66103 Mdot
.474 .72378 Mdot
.16605 .52963 Mdot
.16594 .55518 Mdot
.83045 .45954 Mdot
.49271 .30408 Mdot
.48566 .25003 Mdot
.51549 .19446 Mdot
.43436 .31127 Mdot
.42659 .26148 Mdot
.38751 .36794 Mdot
.26128 .71147 Mdot
.36907 .5229 Mdot
.4542 .17353 Mdot
.71643 .56497 Mdot
.28257 .65084 Mdot
.6739 .75217 Mdot
.69267 .24414 Mdot
.16264 .51378 Mdot
.75701 .45881 Mdot
.69089 .36035 Mdot
.56522 .4805 Mdot
.53428 .46283 Mdot
.66662 .81397 Mdot
.50787 .62772 Mdot
.67641 .28596 Mdot
.24024 .38717 Mdot
.63676 .48214 Mdot
.58207 .83813 Mdot
.43162 .23344 Mdot
.60083 .80516 Mdot
.36932 .51276 Mdot
.65064 .50508 Mdot
.64106 .51846 Mdot
.61094 .62567 Mdot
.28544 .40356 Mdot
.29884 .72436 Mdot
.68277 .2304 Mdot
.22325 .42576 Mdot
.75484 .36091 Mdot
.32709 .7258 Mdot
.21678 .36984 Mdot
.3733 .23997 Mdot
.4977 .51229 Mdot
.36608 .73569 Mdot
.72729 .6062 Mdot
.36392 .19767 Mdot
.57414 .58939 Mdot
.41736 .42797 Mdot
.38723 .33854 Mdot
.25987 .40188 Mdot
.69474 .72127 Mdot
.61057 .49844 Mdot
.55662 .79148 Mdot
.19165 .4074 Mdot
.81045 .41768 Mdot
.77979 .65702 Mdot
.56219 .84072 Mdot
.6523 .32541 Mdot
.25895 .38629 Mdot
.37371 .24674 Mdot
.79035 .32411 Mdot
.54679 .55776 Mdot
.2103 .60014 Mdot
.73341 .6062 Mdot
.163 .52734 Mdot
.32584 .47599 Mdot
.367 .30719 Mdot
.2541 .61013 Mdot
.23988 .67896 Mdot
.56255 .34722 Mdot
.16746 .45934 Mdot
.43798 .52469 Mdot
.33963 .79406 Mdot
.25641 .48826 Mdot
.44919 .47771 Mdot
.41541 .66143 Mdot
.48528 .77905 Mdot
.18015 .51556 Mdot
.21647 .51944 Mdot
.69012 .24645 Mdot
.43207 .67343 Mdot
.51781 .68102 Mdot
.72951 .3563 Mdot
.72122 .65117 Mdot
.24868 .41271 Mdot
.65299 .60803 Mdot
.15871 .45754 Mdot
.60739 .63863 Mdot
.57416 .77429 Mdot
.32451 .71794 Mdot
.56406 .15703 Mdot
.29706 .3976 Mdot
.44309 .77972 Mdot
.41882 .23964 Mdot
.49826 .69925 Mdot
.74669 .50639 Mdot
.13543 .66971 Mdot
.55052 .16831 Mdot
.24383 .49707 Mdot
.27473 .72467 Mdot
.29486 .28029 Mdot
.233 .52432 Mdot
.80423 .60512 Mdot
.6048 .57054 Mdot
.62471 .73267 Mdot
.645 .44913 Mdot
.46066 .85273 Mdot
.69933 .6559 Mdot
.29601 .74789 Mdot
.23898 .3034 Mdot
.70891 .30749 Mdot
.57749 .44901 Mdot
.43017 .59531 Mdot
.3079 .50055 Mdot
.69944 .68161 Mdot
.61644 .36764 Mdot
.69798 .54397 Mdot
.32819 .67415 Mdot
.3899 .6465 Mdot
.40494 .73037 Mdot
.45321 .27614 Mdot
.34357 .69473 Mdot
.25789 .41754 Mdot
.44334 .68383 Mdot
.49243 .53909 Mdot
.64003 .62723 Mdot
.58634 .55186 Mdot
.69923 .34188 Mdot
.78816 .61509 Mdot
.50553 .45396 Mdot
.39415 .61918 Mdot
.66814 .34415 Mdot
.47984 .17916 Mdot
.2281 .4379 Mdot
.32417 .76156 Mdot
.52581 .78572 Mdot
.70704 .3734 Mdot
.62874 .62897 Mdot
.81402 .57799 Mdot
.78668 .43645 Mdot
.22348 .55877 Mdot
.55196 .50545 Mdot
.77686 .43821 Mdot
.357 .27388 Mdot
.2127 .66445 Mdot
.61533 .19364 Mdot
.55125 .18411 Mdot
.47992 .61642 Mdot
.62781 .2592 Mdot
.72633 .33505 Mdot
.71488 .59079 Mdot
.48833 .5618 Mdot
.84064 .63112 Mdot
.44957 .39014 Mdot
.70732 .80338 Mdot
.37281 .4428 Mdot
.7109 .75773 Mdot
.73879 .58947 Mdot
.46933 .46637 Mdot
.47831 .56495 Mdot
.25054 .44132 Mdot
.35219 .32737 Mdot
.40155 .20082 Mdot
.81625 .48221 Mdot
.39604 .58906 Mdot
.68563 .22837 Mdot
.57751 .15396 Mdot
.64201 .35284 Mdot
.63816 .40824 Mdot
.54418 .16621 Mdot
.3996 .66725 Mdot
.75493 .65265 Mdot
.2816 .28121 Mdot
.21354 .49648 Mdot
.70729 .39879 Mdot
.6547 .64179 Mdot
.20585 .59072 Mdot
.14509 .52738 Mdot
.79933 .64733 Mdot
.18821 .52147 Mdot
.32671 .48164 Mdot
.43883 .48164 Mdot
.17452 .46524 Mdot
.68478 .56335 Mdot
.29765 .34184 Mdot
.66669 .56183 Mdot
.78689 .72646 Mdot
.2669 .68235 Mdot
.2971 .7224 Mdot
.66299 .56754 Mdot
.50347 .36109 Mdot
.27982 .44277 Mdot
.65477 .56167 Mdot
.22168 .48829 Mdot
.44692 .20324 Mdot
.64589 .56507 Mdot
.83016 .40137 Mdot
.50808 .22165 Mdot
.36646 .65069 Mdot
.73746 .35198 Mdot
.51637 .22972 Mdot
.36442 .51503 Mdot
.5972 .73873 Mdot
.23429 .39459 Mdot
.3364 .49829 Mdot
.24689 .41888 Mdot
.27563 .38022 Mdot
.53295 .20982 Mdot
.64984 .29558 Mdot
.21525 .44781 Mdot
.5935 .36445 Mdot
.49373 .40359 Mdot
.69454 .71137 Mdot
.45809 .63997 Mdot
.2335 .38152 Mdot
.42344 .65997 Mdot
.58445 .53496 Mdot
.52373 .57577 Mdot
.72687 .40198 Mdot
.56841 .82766 Mdot
.54226 .69024 Mdot
.44883 .37477 Mdot
.72675 .75243 Mdot
.43387 .31697 Mdot
.48566 .84775 Mdot
.79991 .58744 Mdot
.72733 .32379 Mdot
.45214 .70686 Mdot
.4403 .73526 Mdot
.86022 .50677 Mdot
.5048 .41098 Mdot
.46993 .60673 Mdot
.47172 .41096 Mdot
.46064 .37798 Mdot
.33231 .71521 Mdot
.38452 .61326 Mdot
.57621 .56629 Mdot
.41679 .49662 Mdot
.41492 .3983 Mdot
.48928 .29435 Mdot
.52957 .56058 Mdot
.63793 .70635 Mdot
.25494 .70286 Mdot
.40429 .60705 Mdot
.75883 .74158 Mdot
.58087 .42887 Mdot
.60154 .33986 Mdot
.18956 .38489 Mdot
.79601 .66192 Mdot
.4024 .57148 Mdot
.59058 .1517 Mdot
.69524 .45182 Mdot
.2053 .46434 Mdot
.45668 .34847 Mdot
.57273 .18407 Mdot
.54144 .68281 Mdot
.66605 .60596 Mdot
.39492 .48809 Mdot
.71939 .70497 Mdot
.33365 .66443 Mdot
.50915 .34577 Mdot
.20197 .52125 Mdot
.49166 .24611 Mdot
.33667 .31623 Mdot
.42445 .73501 Mdot
.65668 .35248 Mdot
.64389 .28823 Mdot
.49463 .29897 Mdot
.27743 .7079 Mdot
.57987 .18253 Mdot
.20227 .66813 Mdot
.7301 .47622 Mdot
.52324 .76749 Mdot
.39187 .33111 Mdot
.23697 .44054 Mdot
.54256 .49776 Mdot
.17731 .40898 Mdot
.67277 .65821 Mdot
.39762 .37037 Mdot
.64314 .65564 Mdot
.59607 .53284 Mdot
.48661 .5188 Mdot
.31572 .53954 Mdot
.83143 .50199 Mdot
.53879 .50398 Mdot
.74152 .71692 Mdot
.55589 .51419 Mdot
.33997 .74098 Mdot
.47081 .27208 Mdot
.3722 .60192 Mdot
.64148 .26665 Mdot
.30537 .47107 Mdot
.20599 .65174 Mdot
.18135 .4015 Mdot
.40444 .45141 Mdot
.32346 .7004 Mdot
.27959 .31029 Mdot
.6659 .53234 Mdot
.4216 .50554 Mdot
.67556 .43277 Mdot
.44814 .26348 Mdot
.79985 .6652 Mdot
.2295 .46914 Mdot
.61457 .39956 Mdot
.20805 .63545 Mdot
.18347 .61252 Mdot
.32584 .77959 Mdot
.74807 .29856 Mdot
.5015 .34925 Mdot
.42664 .82831 Mdot
.70559 .53747 Mdot
.13619 .49998 Mdot
.22087 .54858 Mdot
.23433 .29635 Mdot
.6691 .35737 Mdot
.25069 .37131 Mdot
.80818 .50745 Mdot
.32377 .34508 Mdot
.34133 .24458 Mdot
.44472 .44681 Mdot
.28694 .54732 Mdot
.31947 .25399 Mdot
.83727 .36643 Mdot
.54484 .47968 Mdot
.27836 .36802 Mdot
.37749 .27475 Mdot
.23001 .38986 Mdot
.52596 .72868 Mdot
.58911 .46997 Mdot
.2597 .57517 Mdot
.64253 .76656 Mdot
.63641 .61485 Mdot
.51584 .67408 Mdot
.52277 .72626 Mdot
.66643 .71275 Mdot
.6454 .67689 Mdot
.61838 .19339 Mdot
.67388 .35506 Mdot
.56223 .54923 Mdot
.65879 .40895 Mdot
.48611 .28158 Mdot
.56947 .64066 Mdot
.35473 .62838 Mdot
.67445 .43727 Mdot
.37146 .62789 Mdot
.33663 .32423 Mdot
.54291 .84427 Mdot
.28864 .46429 Mdot
.42847 .22625 Mdot
.43343 .38214 Mdot
.27076 .41552 Mdot
.52827 .37187 Mdot
.65026 .78081 Mdot
.51756 .75113 Mdot
.62219 .60362 Mdot
.193 .59776 Mdot
.43968 .79637 Mdot
.48885 .22156 Mdot
.43997 .80944 Mdot
.33026 .48235 Mdot
.7082 .40735 Mdot
.38394 .28937 Mdot
.39919 .73767 Mdot
.41304 .35071 Mdot
.24907 .37711 Mdot
.46996 .6146 Mdot
.43815 .78353 Mdot
.36695 .22904 Mdot
.48572 .23851 Mdot
.7328 .36747 Mdot
.16925 .56634 Mdot
.41741 .59353 Mdot
.55226 .17774 Mdot
.29956 .33198 Mdot
.51006 .76025 Mdot
.3299 .74456 Mdot
.24044 .69955 Mdot
.45701 .5429 Mdot
.70365 .62411 Mdot
.62743 .49401 Mdot
.65556 .23423 Mdot
.23702 .46268 Mdot
.57231 .39806 Mdot
.32841 .61122 Mdot
.44726 .31647 Mdot
.3326 .56663 Mdot
.54009 .53993 Mdot
.64203 .72288 Mdot
.45259 .29251 Mdot
.76633 .36692 Mdot
.55237 .63931 Mdot
.43415 .54339 Mdot
.59715 .43138 Mdot
.69294 .61595 Mdot
.77461 .35019 Mdot
.71972 .43356 Mdot
.18896 .49141 Mdot
.67599 .35049 Mdot
.46999 .21696 Mdot
.21588 .46668 Mdot
.22649 .56613 Mdot
.34706 .33318 Mdot
.66092 .28335 Mdot
.33925 .64139 Mdot
.65384 .41901 Mdot
.37544 .59513 Mdot
.45491 .30553 Mdot
.25918 .31576 Mdot
.64567 .31981 Mdot
.70966 .60154 Mdot
.48121 .46045 Mdot
.53488 .3791 Mdot
.48334 .43989 Mdot
.21665 .33663 Mdot
.32402 .34645 Mdot
.66448 .65752 Mdot
.34675 .52518 Mdot
.73583 .59088 Mdot
.79511 .61139 Mdot
.15938 .58597 Mdot
.8123 .56227 Mdot
.46337 .52425 Mdot
.75115 .70931 Mdot
.25881 .47338 Mdot
.28595 .27702 Mdot
.65756 .67059 Mdot
.45942 .55623 Mdot
.51911 .647 Mdot
.3754 .40614 Mdot
.50274 .48302 Mdot
.52361 .62744 Mdot
.58868 .56315 Mdot
.30866 .61467 Mdot
.36471 .54336 Mdot
.5636 .49172 Mdot
.28534 .69547 Mdot
.18237 .58306 Mdot
.58348 .18899 Mdot
.50039 .43206 Mdot
.56504 .73598 Mdot
.66229 .705 Mdot
.30188 .2116 Mdot
.61901 .84023 Mdot
.62857 .4931 Mdot
.50571 .43329 Mdot
.68514 .62906 Mdot
.40581 .58374 Mdot
.62899 .55838 Mdot
.52671 .38751 Mdot
.38849 .4471 Mdot
.50703 .63973 Mdot
.45897 .79133 Mdot
.25387 .44204 Mdot
.73517 .63444 Mdot
.26622 .6159 Mdot
.53963 .84808 Mdot
.45048 .19092 Mdot
.23491 .45075 Mdot
.24905 .25856 Mdot
.34786 .54181 Mdot
.44202 .39981 Mdot
.54815 .371 Mdot
.26339 .70763 Mdot
.65454 .6012 Mdot
.67223 .73515 Mdot
.23791 .59064 Mdot
.66663 .66464 Mdot
.73024 .52276 Mdot
.32745 .72289 Mdot
.33262 .57806 Mdot
.4668 .49159 Mdot
.4425 .73671 Mdot
.39611 .79541 Mdot
.75763 .3785 Mdot
.19295 .58222 Mdot
.65241 .76534 Mdot
.81964 .364 Mdot
.18917 .62773 Mdot
.50618 .66338 Mdot
.54441 .73823 Mdot
.55186 .36742 Mdot
.70334 .56364 Mdot
.75516 .48537 Mdot
.74923 .66405 Mdot
.62393 .28317 Mdot
.40891 .71027 Mdot
.705 .74431 Mdot
.63431 .63457 Mdot
.51993 .22557 Mdot
.46126 .55659 Mdot
.68769 .34069 Mdot
.33577 .70602 Mdot
.64283 .57629 Mdot
.55329 .59045 Mdot
.69494 .58095 Mdot
.6611 .34668 Mdot
.4402 .2442 Mdot
.27991 .33015 Mdot
.84932 .42075 Mdot
.22504 .58789 Mdot
.66077 .7766 Mdot
.57926 .47146 Mdot
.2246 .69761 Mdot
.28294 .33637 Mdot
.2347 .59312 Mdot
.40714 .21458 Mdot
.36136 .62915 Mdot
.40278 .37727 Mdot
.65259 .41893 Mdot
.19705 .54654 Mdot
.68285 .29215 Mdot
.51952 .24426 Mdot
.70612 .72259 Mdot
.65609 .61912 Mdot
.57766 .75529 Mdot
.71977 .57881 Mdot
.72672 .43545 Mdot
.42928 .33881 Mdot
.43595 .83867 Mdot
.44789 .52266 Mdot
.56693 .51924 Mdot
.6032 .38801 Mdot
.80783 .51451 Mdot
.49215 .16006 Mdot
.73485 .45984 Mdot
.41608 .7876 Mdot
.7729 .39973 Mdot
.74543 .42109 Mdot
.61745 .54969 Mdot
.38043 .12399 Mdot
.11141 .5294 Mdot
.5042 .32939 Mdot
.69078 .25798 Mdot
.77704 .40039 Mdot
.25635 .6965 Mdot
.47615 .74997 Mdot
.34756 .62921 Mdot
.79191 .49388 Mdot
.72744 .54104 Mdot
.62705 .40511 Mdot
.38226 .22242 Mdot
.15168 .56933 Mdot
.70818 .72681 Mdot
.20339 .63025 Mdot
.55858 .43999 Mdot
.66147 .39932 Mdot
.35973 .16178 Mdot
.17247 .47688 Mdot
.69446 .50508 Mdot
.81209 .50916 Mdot
.4242 .38526 Mdot
.66259 .46296 Mdot
.26218 .64765 Mdot
.67754 .22661 Mdot
.63165 .63454 Mdot
.24089 .68011 Mdot
.46865 .29652 Mdot
.45735 .58621 Mdot
.38809 .4434 Mdot
.48184 .56398 Mdot
.69731 .43827 Mdot
.35116 .466 Mdot
.74345 .41192 Mdot
.24935 .36341 Mdot
.39175 .50913 Mdot
.62312 .1877 Mdot
.17116 .38481 Mdot
.66577 .32377 Mdot
.35295 .41368 Mdot
.66988 .53236 Mdot
.50946 .22766 Mdot
.69068 .6918 Mdot
.41871 .29477 Mdot
.30609 .26017 Mdot
.21298 .73617 Mdot
.29201 .56031 Mdot
.61708 .72289 Mdot
.42433 .30222 Mdot
.5582 .54218 Mdot
.71063 .33743 Mdot
.41355 .53703 Mdot
.4216 .60093 Mdot
.60058 .51588 Mdot
.728 .44428 Mdot
.37384 .50798 Mdot
.70104 .80255 Mdot
.59412 .475 Mdot
.59531 .55066 Mdot
.13799 .50147 Mdot
.69356 .71265 Mdot
.58438 .33872 Mdot
.6943 .48956 Mdot
.33976 .3936 Mdot
.45843 .55613 Mdot
.21538 .39456 Mdot
.57049 .7763 Mdot
.22273 .64501 Mdot
.64232 .31788 Mdot
.74545 .37575 Mdot
.60274 .43913 Mdot
.52698 .67141 Mdot
.28863 .36639 Mdot
.24474 .63232 Mdot
.5639 .42527 Mdot
.13701 .52586 Mdot
.36096 .6352 Mdot
.31374 .64262 Mdot
.74251 .45678 Mdot
.34479 .79084 Mdot
.74929 .69767 Mdot
.7091 .31819 Mdot
.63263 .79459 Mdot
.40982 .7512 Mdot
.71959 .65109 Mdot
.42962 .59686 Mdot
.56032 .44508 Mdot
.47803 .29975 Mdot
.54305 .85298 Mdot
.2464 .64181 Mdot
.26532 .54566 Mdot
.31672 .57053 Mdot
.6353 .23146 Mdot
.33355 .30551 Mdot
.22096 .29982 Mdot
.42402 .74659 Mdot
.55209 .8468 Mdot
.55115 .18227 Mdot
.42081 .30234 Mdot
.25179 .39274 Mdot
.70694 .41123 Mdot
.39892 .61775 Mdot
.23739 .66038 Mdot
.72441 .47367 Mdot
.60561 .78164 Mdot
.68313 .49529 Mdot
.58175 .81245 Mdot
.53582 .61257 Mdot
.30605 .69441 Mdot
.25971 .49769 Mdot
.7996 .61149 Mdot
.24305 .32573 Mdot
.38328 .40243 Mdot
.26538 .25418 Mdot
.2426 .33757 Mdot
.1564 .54208 Mdot
.63741 .75673 Mdot
.82435 .60212 Mdot
.21897 .52358 Mdot
.21763 .44696 Mdot
.27129 .48435 Mdot
.59406 .37836 Mdot
.48207 .77703 Mdot
.73861 .46576 Mdot
.29716 .374 Mdot
.40265 .43625 Mdot
.39894 .89645 Mdot
.55182 .62355 Mdot
.50137 .38235 Mdot
.44718 .76711 Mdot
.16893 .58082 Mdot
.65255 .37376 Mdot
.33699 .23749 Mdot
.53466 .54073 Mdot
.62503 .39957 Mdot
.6425 .29987 Mdot
.6162 .20399 Mdot
.49973 .78301 Mdot
.87043 .52644 Mdot
.45213 .19373 Mdot
.31385 .59731 Mdot
.49589 .52909 Mdot
.43637 .30704 Mdot
.51567 .321 Mdot
.45135 .72108 Mdot
.33598 .22643 Mdot
.25014 .36864 Mdot
.17405 .46698 Mdot
.85757 .49911 Mdot
.50061 .2014 Mdot
.26073 .70651 Mdot
.24976 .47349 Mdot
.50456 .37312 Mdot
.51467 .68586 Mdot
.40547 .68592 Mdot
.26011 .53446 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0W?ooool2o`000:_ooooo000Looooo`03o`000?oooooooooo09cooooo0_l0
002[ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0Z?ooool2o`0009oooooo000Looooo`03o`000?oooooo
oooo0:Sooooo0_l0002Oooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0Yoooool2o`000:3ooooo
000Looooo`03o`000?oooooooooo0:Oooooo0_l0002Pooooo`007?ooool00ol0003oooooooooo`1h
ooooo`;o00008oooool2o`000:[ooooo000Looooo`03o`000?oooooooooo07Sooooo0_l0000Soooo
o`;o0000Z_ooool001cooooo00?o0000ooooooooool0Soooool2o`000;Sooooo000Looooo`03o`00
0?oooooooooo08oooooo0_l0002hooooo`007?ooool00ol0003oooooooooo`2dooooo`;o00001_oo
ool2o`0008_ooooo000Looooo`03o`000?oooooooooo0;Cooooo0_l00006ooooo`;o0000Roooool0
01cooooo00?o0000ooooooooool0Qoooool2o`0003Gooooo0_l00029ooooo`007?ooool00ol0003o
ooooooooo`27ooooo`;o0000=Oooool2o`0008Wooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo0_l00021ooooo`;o0000>_ooool2o`0008_ooooo000Looooo`03o`000?oooooo
oooo083ooooo0_l0000Tooooo`;o00002?ooool2o`0000Kooooo0_l00002ooooo`?o0000R_ooool0
01cooooo00?o0000ooooooooool0YOooool3o`0000Sooooo0_l000000ooooooo0000o`000003oooo
o`;o00000oooool2o`0008[ooooo000Looooo`03o`000?oooooooooo077ooooo0_l0000Yooooo`;o
00001oooool2o`0000cooooo0_l0002Dooooo`007?ooool00ol0003oooooooooo`1aooooo`;o0000
9oooool4o`0001oooooo0_l0002:ooooo`007?ooool00ol0003oooooooooo`2Jooooo`?o000000?o
ooooo`000?l000003Oooool4o`0000cooooo0_l0000<ooooo`;o0000O?ooool001cooooo00?o0000
ooooooooool0Toooool2o`0000Kooooo0_l000000ooooooo0000o`000004ooooo`;o000000?ooooo
o`000?l000001?ooool4o`0000?ooooo0_l00002ooooo`;o00004Oooool2o`0007cooooo000Loooo
o`03o`000?oooooooooo08Kooooo0_l00008ooooo`;o000000?oooooo`000?l000001?l0000;oooo
o`;o000000Coooooo`000?l0003o00001Oooool2o`0000?ooooo0_l00002ooooo`;o00001_ooool2
o`0000?ooooo0_l0000>ooooo`;o0000L_ooool001cooooo00?o0000ooooooooool0Q_ooool2o`00
00Sooooo0_l00002ooooo`Go00003oooool2o`0000Cooooo1?l0000>ooooo`;o00000oooool2o`00
00Kooooo0_l00005ooooo`?o0000L_ooool001cooooo00?o0000ooooooooool0U_ooool6o`0000ko
oooo0_l00002ooooo`Co00001?ooool2o`0001Gooooo0_l00005ooooo`;o0000Loooool001cooooo
00?o0000ooooooooool0U_ooool6o`0000[ooooo0_l00002ooooo`;o00000oooool2o`0000Gooooo
0_l000000ooooooo0000o`00000Aooooo`?o0000N_ooool001cooooo00?o0000ooooooooool0LOoo
ool2o`0002Cooooo0_l00007ooooo`;o00001?ooool4o`0000Gooooo0ol00004ooooo`;o000000?o
ooooo`000?l000003?ooool2o`0000?ooooo0ol0001jooooo`007?ooool00ol0003oooooooooo`1a
ooooo`;o00003_ooool4o`0001Cooooo0_l00005ooooo`?o00001Oooool2o`0000Kooooo0_l00008
ooooo`;o00002oooool2o`00083ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ
8B44ooooo`Go00001_ooool00ol0003oooooooooo`1^ooooo`;o00000oooool2o`0000Oooooo0_l0
0003ooooo`Co00000oooool2o`0000Gooooo0_l00008ooooo`;o00001_ooool2o`0000Kooooo0_l0
000?ooooo`;o00001?ooool2o`0000;ooooo1?l00021ooooo`0000KoooooogMgMonHV9SooooooiRH
V?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000oooooooo
ool0K_ooool2o`0000?ooooo0_l00007ooooo`;o00002_ooool2o`0000Gooooo0_l0000Cooooo`;o
00000oooool2o`0001?ooooo1?l00002ooooo`Co0000POooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo07;ooooo
0_l0000Jooooo`;o00005?ooool2o`0001Sooooo0ol00004ooooo`;o0000P_ooool00003ooooool0
003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06ooooo`?o0000K?oo
ool2o`0000Cooooo0_l00005ooooo`So00003Oooool2o`0000Oooooo0_l00006ooooo`Co0000Y_oo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`05
ooooo`03o`000?oooooooooo06cooooo0_l0000;ooooo`So00003?ooool2o`0000Sooooo0_l00006
ooooo`Co00007oooool4o`0008?ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo
00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1jooooo`;o00004Oooool2o`00
01;ooooo0_l0000Oooooo`Co00004oooool2o`0006kooooo00001_ooooooMgMgoiRHV?ooooooV9RH
ogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo05kooooo0_l0
000Gooooo`Go0000;Oooool2o`0001;ooooo0_l0000Jooooo`;o0000K_ooool00006ooooooo^k^ko
<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000oooooooo
ool0G_ooool2o`0001Oooooo0ol00007ooooo`;o00005_ooool2o`0000kooooo0_l000000ooooooo
0000o`000004ooooo`;o00002Oooool2o`0008[ooooo000Looooo`03o`000?oooooooooo083ooooo
0ol00005ooooo`Ko00001oooool3o`000003ooooool0003o000000kooooo0_l000000ooooooo0000
o`000004ooooo`;o00004?ooool4o`00087ooooo000Looooo`03o`000?oooooooooo083ooooo0_l0
0006ooooo`Ko00000oooool7o`0000;ooooo0ol00006ooooo`;o00001_ooool2o`00017ooooo0_l0
0004ooooo`Co0000POooool001cooooo00?o0000ooooooooool0Hoooool2o`000003ooooool0003o
0000013ooooo0_l0000?ooooo`;o00000oooool2o`000003ooooool0003o000000Co00000oooool3
o`0000Cooooo1?l00003ooooo`Go00004Oooool2o`0001[ooooo0_l0001]ooooo`007?ooool00ol0
003oooooooooo`1Sooooo`;o000000Coooooo`000?l0003ooooo1?l00009ooooo`Co00002Oooool2
o`0000;ooooo1?l00003ooooo`;o00001Oooool2o`0000[ooooo0ol000001?oooooo0000o`000?oo
ool6o`0001gooooo0_l0000;ooooo`Co0000KOooool001cooooo00?o0000ooooooooool0JOooool6
o`0000Cooooo0_l000000ooooooo0000o`00000;ooooo`;o00000_ooool2o`0000Gooooo0_l0000<
ooooo`;o00001?ooool5o`0000;ooooo1Ol0000Mooooo`;o00002?ooool2o`000003ooooool0003o
000000?o00001?ooool2o`0006Kooooo000Looooo`03o`000?oooooooooo05oooooo0_l00005oooo
o`;o00001?ooool3o`0000Cooooo0_l0000Cooooo`;o00001?ooool2o`0000Sooooo0_l00002oooo
o`;o00001_ooool2o`00027ooooo0_l00002ooooo`;o00002?ooool3o`0000;ooooo0ol00004oooo
o`;o0000I_ooool001cooooo00?o0000ooooooooool0Goooool2o`0000Cooooo0ol00007ooooo`?o
00001_ooool2o`0000kooooo0_l0000;ooooo`;o000000?oooooo`000?l000004_ooool2o`0001Wo
oooo0_l00002ooooo`;o00001?ooool2o`0000?ooooo0_l0001aooooo`007?ooool00ol0003ooooo
ooooo`1Rooooo`Go00000oooool2o`0000?ooooo0ol00004ooooo`Co00000oooool2o`0000Gooooo
0_l00002ooooo`;o00000_ooool2o`0000Oooooo0_l00003ooooo`;o00002_ooool2o`0000Cooooo
0_l0000Sooooo`;o00001_ooool2o`000003ooooool0003o000006_ooooo000Looooo`03o`000?oo
oooooooo06;ooooo1?l00004ooooo`;o00002_ooool2o`0000Gooooo0_l00005ooooo`;o00001_oo
ool2o`0000Kooooo0_l00004ooooo`;o00000_ooool2o`0000Kooooo0_l0000Sooooo`;o00003?oo
ool2o`000003ooooool0003o000000;o0000JOooool001cooooo00?o0000ooooooooool0IOooool2
o`0000?ooooo0ol0000Aooooo`;o00002_ooool3o`0000Oooooo0ol00005ooooo`Co00001Oooool2
o`0002Cooooo0_l00006ooooo`;o00001?ooool2o`000003ooooool0003o000000;o0000JOooool0
01cooooo00?o0000ooooooooool0H_ooool2o`000003ooooool0003o000000Cooooo0_l00003oooo
o`;o00001?ooool2o`0000Kooooo0_l0000:ooooo`?o00001oooool3o`0000Gooooo0_l00007oooo
o`;o00009_ooool2o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`?o0000J_ooool001co
oooo0_l0001Sooooo`?o00002oooool2o`0000Cooooo1?l000001?oooooo0000o`000?ooool2o`00
01Cooooo0_l00004ooooo`;o00004Oooool2o`0001kooooo0_l00007ooooo`;o00001?ooool2o`00
00?ooooo0_l00002ooooo`;o0000H_ooool001cooooo00?o0000ooooooooool0D_ooool2o`0000oo
oooo0ol0000Booooo`Go000000?oooooo`000?l000001_ooool2o`000003ooooool0003o000000Ko
oooo0_l00007ooooo`;o00002oooool2o`0000Cooooo0_l0000Rooooo`?o00000_ooool2o`000003
ooooool0003o000000Kooooo0_l00002ooooo`;o0000H_ooool001cooooo00?o0000ooooooooool0
COooool2o`0000?ooooo0_l0000;ooooo`;o00000oooool2o`0000Wooooo0_l00009ooooo`;o0000
2_ooool2o`000004ooooool0003o0000o`0000Gooooo0_l0000>ooooo`;o000000Coooooo`000?l0
003ooooo0_l0000Vooooo`Go00001Oooool2o`0000;ooooo0_l00004ooooo`;o00001Oooool2o`00
05gooooo000Looooo`03o`000?oooooooooo04gooooo0_l0000@ooooo`Go00002oooool2o`0001Ko
oooo1Ol0000;ooooo`;o00001?ooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`00
00Gooooo0_l0000Hooooo`;o00000_ooool2o`000003ooooool0003o000000Kooooo1?l00002oooo
o`;o00000_ooool4o`0000Gooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1Pooooo`Co
00006oooool2o`0000Kooooo1?l00003ooooo`;o00001?ooool2o`000003ooooool0003o000000Co
oooo0_l0000?ooooo`;o00006?ooool2o`0000;ooooo0_l00009ooooo`;o00002?ooool2o`0006Ko
oooo000Looooo`03o`000?oooooooooo06;ooooo0_l0000Kooooo`Co00001?ooool2o`0000Gooooo
0_l00004ooooo`Co00005_ooool2o`0001gooooo0_l0001jooooo`007?ooool00ol0003ooooooooo
o`1Rooooo`;o00002_ooool2o`0000cooooo0_l00003ooooo`;o00001?ooool2o`0000Kooooo0_l0
0005ooooo`;o00005_ooool2o`0001gooooo0_l0000<ooooo`;o00005?ooool2o`0005Kooooo000L
ooooo`03o`000?oooooooooo05kooooo0_l0000>ooooo`Co00002Oooool6o`0000kooooo0_l00004
ooooo`;o000000?oooooo`000?l00000@Oooool3o`0001;ooooo0ol0001Fooooo`007?ooool00ol0
003oooooooooo`1Eooooo`;o00000_ooool2o`0000?ooooo0_l0000@ooooo`;o00001Oooool2o`00
00;ooooo0_l000001?oooooo0000o`000?l00003ooooo`;o00002Oooool2o`000004ooooool0003o
0000ooooo`;o000000?oooooo`000?l000000ol0000>ooooo`;o00006oooool2o`0000[ooooo0_l0
0003ooooo`;o000000?oooooo`000?l000002_ooool4o`0000Cooooo0_l0000<ooooo`;o0000BOoo
ool001cooooo00?o0000ooooooooool0EOooool2o`0000;ooooo1?l0000Jooooo`;o00002oooool2
o`0000Wooooo0_l000000ooooooo0000o`000004ooooo`Go000000?oooooo`000?l000002oooool2
o`0001_ooooo0_l0000:ooooo`;o00000oooool2o`0000Wooooo0_l00002ooooo`Co00000_ooool2
o`0000kooooo0_l00019ooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o000000?oooooo`00
0?l000001_l0000jooooo`Co00000_ooool2o`0000Oooooo0ol00008ooooo`;o00004oooool2o`00
00Sooooo0_l00006ooooo`;o00002Oooool2o`0000Sooooo0_l0001Iooooo`007?ooool00ol0003o
ooooooooo`1<ooooo`;o00001Oooool2o`000003ooooool0003o000000?o000000?oooooo`000?l0
00000_l00004ooooo`Co00007oooool2o`0000?ooooo0_l00005ooooo`;o00000oooool4o`0000Oo
oooo0_l00002ooooo`?o00002?ooool2o`0001?ooooo0_l00008ooooo`Co00000_ooool3o`0006oo
oooo000Looooo`03o`000?oooooooooo04cooooo0_l00009ooooo`;o00000_ooool5o`0000Cooooo
1?l0000Aooooo`;o00003?ooool3o`0000;ooooo0_l00005ooooo`;o00000_ooool4o`0000Sooooo
0_l0000<ooooo`;o00006_ooool2o`0000Cooooo0_l00002ooooo`?o00001Oooool2o`0006Sooooo
000Looooo`03o`000?oooooooooo05;ooooo0ol000001?oooooo0000o`000?l00002ooooo`?o0000
5_ooool2o`0000?ooooo0_l0000;ooooo`Co00000_ooool2o`0000Wooooo1?l00002ooooo`;o0000
4_ooool2o`0001Kooooo1_l0000;ooooo`;o00000oooool2o`0006Sooooo000Looooo`03o`000?oo
oooooooo05;ooooo0ol000000ooooooo0000o`000009ooooo`Co00000oooool2o`0000?ooooo0_l0
0003ooooo`Co00003_ooool4o`0000;ooooo2ol000000ooooooo0000o`000003ooooo`Co0000:_oo
ool4o`000003ooooool0003o000000[ooooo0_l00006ooooo`;o00000oooool3o`0005oooooo000L
ooooo`03o`000?oooooooooo04Sooooo1?l0000>ooooo`;o00001Oooool5o`0000;ooooo1?l00000
0ooooooo0000o`000002ooooo`?o00004?ooool3o`0000?ooooo3_l00003ooooo`Co000000?ooooo
o`000?l000000oooool2o`000003ooooool0003o000000Oooooo0_l0000Kooooo`?o00001Oooool2
o`0000Wooooo0ol00003ooooo`?o00000oooool4o`0005Sooooo000Looooo`;o0000AOooool2o`00
00;ooooo1?l00003ooooo`;o00000_ooool2o`0000Cooooo0ol000000ooooooo0000o`000004oooo
o`?o00001?ooool2o`000003ooooool0003o000000Co00004_ooool2o`0000?ooooo3?l00002oooo
o`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`00
0?l000001oooool2o`0000;ooooo0_l0000Fooooo`Co00001Oooool2o`0000Wooooo1?l00008oooo
o`Co0000F?ooool001cooooo00?o0000ooooooooool0A?ooool2o`0000Cooooo0_l00003ooooo`;o
00000_ooool2o`0000Cooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l00008oooo
o`Co00000_ooool2o`00013ooooo0ol00002ooooo`Go000000?oooooo`000?l000002?l000000ooo
oooo0000o`000004o`0001;ooooo1?l0000Fooooo`;o00004_ooool4o`0000Oooooo0_l0001Koooo
o`007?ooool00ol0003oooooooooo`18ooooo`Co00004Oooool2o`000003ooooool0003o000000Oo
oooo0_l00006ooooo`Co00002_ooool3o`0000?ooooo0ol000000ooooooo0000o`000004o`000003
ooooool0003o000000Wo000000?oooooo`000?l000000ol0000Booooo`;o000000?oooooo`000?l0
00003oooool2o`0001Wooooo0_l00008ooooo`;o0000Foooool001cooooo00?o0000ooooooooool0
B?ooool2o`0000Oooooo0_l00004ooooo`;o00002Oooool2o`0000Gooooo0_l00006ooooo`Co0000
2_ooool3o`0000?ooooo1ol000000ooooooo0000o`00000<o`000003ooooool0003o000000Go0000
1_ooool2o`0000_ooooo0_l0000?ooooo`;o00002oooool2o`0000Oooooo0_l00003ooooo`;o0000
5?ooool2o`0004oooooo000Looooo`03o`000?oooooooooo057ooooo0_l00004ooooo`?o00000_oo
ool4o`0000;ooooo0_l0000;ooooo`;o00000_ooool2o`0000oooooo0_l000000ooooooo0000o`00
000Eo`000003ooooool0003o000000;o00001_ooool2o`0000Sooooo0_l0000Oooooo`;o00001ooo
ool2o`0000[ooooo0_l00007ooooo`Co00000_ooool2o`0004oooooo000Looooo`03o`000?oooooo
oooo053ooooo0_l00006ooooo`;o000000?oooooo`000?l000000ol0000:ooooo`;o00000oooool2
o`0000Wooooo0_l00008ooooo`;o000000?oooooo`000?l000006?l00006ooooo`;o00002_ooool2
o`000003ooooool0003o000000;o00004Oooool4o`0000Gooooo0_l000000ooooooo0000o`00000@
ooooo`;o00001?ooool2o`000003ooooool0003o000000;o0000Doooool001cooooo00?o0000oooo
ooooool0Aoooool2o`000003ooooool0003o000000Cooooo0ol00004ooooo`;o00000_ooool2o`00
00Sooooo0_l00003ooooo`;o00000oooool2o`0000Wooooo0_l0000;oooooaWo00001oooool2o`00
00gooooo1?l0000Aooooo`Go00001oooool2o`0000;ooooo0_l00006ooooo`;o00001?ooool2o`00
00Cooooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`17ooooo`;o000000?oooooo`000?l0
00001Oooool2o`0000Cooooo0_l00002ooooo`Co00001_ooool2o`0000Sooooo0_l00004ooooo`;o
00000_ooool3o`0000_ooooo6ol00002ooooo`;o00003oooool5o`0001?ooooo0ol0000;ooooo`;o
00000_ooool6o`0006Cooooo000Looooo`03o`000?oooooooooo04Oooooo0_l00002ooooo`Co0000
2Oooool2o`0000?ooooo0ol0000:ooooo`;o00002Oooool2o`0000;ooooo0ol00009oooooa[o0000
00?oooooo`000?l000001?l00008ooooo`;o00001Oooool2o`00013ooooo0_l00005ooooo`Co0000
0_ooool2o`0000Gooooo0_l00002ooooo`Co00001Oooool2o`0001?ooooo0_l0001:ooooo`007?oo
ool00ol0003oooooooooo`17ooooo`;o00000_ooool4o`0000Wooooo0_l000001?oooooo0000o`00
0?ooool2o`000003ooooool0003o000000Oooooo0_l00002ooooo`Co00004ooooolOo`0000;ooooo
0_l00006ooooo`;o00003?ooool2o`0000Wooooo0_l00005ooooo`Co00000_ooool2o`0000Gooooo
0_l0000;ooooo`;o00003Oooool2o`0000Cooooo0_l00004ooooo`;o0000A?ooool001cooooo00?o
0000ooooooooool0AOooool2o`00013ooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo
0_l00009ooooo`Ko00002_ooool2o`0000Sooooo7Ol00003ooooo`;o00005?ooool2o`0000cooooo
0_l0000Hooooo`;o00003?ooool2o`0000?ooooo0_l0000:ooooo`;o0000A?ooool001cooooo00?o
0000ooooooooool0A?ooool3o`00013ooooo0_l00005ooooo`;o00003?ooool3o`0000gooooo0_l0
0006oooooako0000:?ooool2o`0001Sooooo0_l00002ooooo`;o00001_ooool4o`0005Gooooo000L
ooooo`03o`000?oooooooooo03kooooo0_l00003ooooo`?o00001Oooool2o`0000Wooooo1?l00004
ooooo`;o00000_ooool3o`000003ooooool0003o000000Gooooo0_l00009ooooo`Co00001OoooolC
o`000003ooooool0003o000000_o00002Oooool2o`0001Oooooo0_l0000Mooooo`;o00000oooool2
o`0000Kooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00000oooool2o`00
00Kooooo0_l00009ooooo`Co00001?ooool2o`0000;ooooo0ol000000ooooooo0000o`000006oooo
o`;o00002?ooool4o`0000Gooooo5?l000000ooooooo0000o`00000=o`0000Kooooo0_l0000=oooo
o`;o00001?ooool2o`0000;ooooo0_l0000Fooooo`;o00001Oooool2o`0000oooooo0_l0001Coooo
o`007?ooool00ol0003oooooooooo`1;ooooo`;o00001_ooool2o`0000;ooooo0_l00004ooooo`;o
00003oooool2o`00013ooooo0_l00002oooooaGo00000_ooool:o`0000Oooooo0_l00007ooooo`;o
00000oooool2o`0000Cooooo0_l00002ooooo`;o00003oooool2o`0000Gooooo0_l000000ooooooo
0000o`00000>ooooo`;o00000oooool2o`0005?ooooo000Looooo`03o`000?oooooooooo04;ooooo
0_l00007ooooo`;o00001_ooool2o`0000;ooooo1?l00002ooooo`;o00001_ooool7o`0001Cooooo
0_l00003ooooob3o00001oooool2o`0000Gooooo1?l0000=ooooo`;o00001oooool2o`0000Cooooo
1?l00008ooooo`?o00000_ooool2o`0000Wooooo0_l0001Hooooo`007?ooool2o`0004?ooooo0_l0
000Eooooo`;o00002_ooool7o`0001Kooooo0_l000000ooooooo0000o`00000<o`000003ooooool0
003o000000oo000000?oooooo`000?l000002oooool2o`0000gooooo1?l00007ooooo`;o00001?oo
ool2o`0000?ooooo0ol00005ooooo`;o00000_ooool2o`0001;ooooo0_l0001?ooooo`007?ooool0
0ol0003oooooooooo`13ooooo`?o00002oooool2o`00027ooooo0_l00006ooooo`;o00001?ooool2
o`0000;ooooo7ol000001?oooooo0000o`000?l0000<ooooo`;o00002oooool4o`0000Oooooo0_l0
0003ooooo`;o00001?ooool3o`0000;ooooo0_l0000=ooooo`;o00001_ooool2o`0000;ooooo0ol0
001>ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o000000Coooooo`000?l0003o00002ooo
ool2o`00027ooooo0_l00006ooooo`;o00002?oooolNo`0000?ooooo0_l0000<ooooo`;o00005_oo
ool2o`0000?ooooo0_l00003ooooo`;o00001?ooool2o`0000[ooooo0_l000000ooooooo0000o`00
0002o`0000Cooooo0_l00003ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0@?ooool2
o`000003ooooool0003o000000Gooooo0_l0000<ooooo`;o0000;?oooolLo`0000_ooooo0_l0000G
ooooo`;o00001?ooool2o`0000Sooooo1Ol0000>ooooo`;o00000oooool2o`0000Oooooo0ol0001?
ooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o00001_ooool2o`0000Cooooo0_l0000Eoooo
o`;o00005OoooolOo`0000Sooooo1?l0000Eooooo`?o00000oooool2o`0000Sooooo0_l000000ooo
oooo0000o`000002ooooo`;o00004_ooool3o`0000?ooooo0ol0001?ooooo`007?ooool00ol0003o
ooooooooo`1=ooooo`;o00000oooool2o`0000Kooooo0ol000000ooooooo0000o`00000=ooooo`Co
00001Oooool2o`0000kooooo7ol00002ooooo`;o00001_ooool2o`0000cooooo0_l00006ooooo`Co
00002?ooool2o`0000[ooooo0_l0000@ooooo`Ko00000_ooool3o`0000cooooo0_l00011ooooo`00
7?ooool00ol0003oooooooooo`1=ooooo`?o00001_ooool3o`000005ooooool0003o0000o`000?oo
ool00_l0000=ooooo`;o00001oooool2o`0000;ooooo0_l0000;oooooaSo000000?oooooo`000?l0
00000ol00002ooooo`;o00001_ooool2o`0000cooooo0_l00004ooooo`Co00002_ooool2o`0000co
oooo0_l00005ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`Co000000?oooooo`000?l0
00003?ooool2o`0000Cooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`13ooooo`;o0000
2?ooool3o`0000Kooooo1?l0000Aooooo`;o000000?oooooo`000?l000002_ooool2o`000003oooo
ool0003o000000Gooooo0_l00002oooooaOo000000Coooooo`000?l0003ooooo0_l00003ooooo`;o
00001?ooool5o`00013ooooo0ol00003ooooo`;o00005?ooool2o`0000Gooooo0_l00002ooooo`;o
00002Oooool2o`000003ooooool0003o000001;ooooo0_l0000kooooo`007?ooool00ol0003ooooo
ooooo`0looooo`;o00001Oooool2o`0000Wooooo0_l00008ooooo`;o00000oooool2o`0000cooooo
0_l000000ooooooo0000o`000005ooooo`;o00001_ooool2o`0000Gooooo0_l00002oooooaKo0000
0_ooool2o`000003ooooool0003o000000?ooooo0_l00004ooooo`;o000000?oooooo`000?l00000
5_ooool2o`0000Gooooo0_l0000@ooooo`;o00005_ooool2o`0004gooooo000Looooo`03o`000?oo
oooooooo03cooooo0_l0000:ooooo`;o00000oooool2o`0000Kooooo0_l000000ooooooo0000o`00
0002o`000004ooooool0003o0000o`0001Gooooo0_l00004ooooo`;o00000_ooool2o`0000?ooooo
1?l000000ooooooo0000o`00000@o`000003ooooool0003o000000Co00001_ooool2o`0000Cooooo
0_l000000ooooooo0000o`00000:ooooo`Co00003?ooool2o`000003ooooool0003o0000013ooooo
0_l0000:ooooo`Ko00000_ooool2o`0000;ooooo0_l0001=ooooo`007?ooool00ol0003ooooooooo
o`0nooooo`;o00002?ooool2o`0000?ooooo0_l00006ooooo`?o00000_ooool2o`0000;ooooo0_l0
000Fooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`Co000000Goooooo`000?l0003o0000
ooooo`0;o`000004ooooool0003o0000ooooo`Co000000?oooooo`000?l000001Oooool4o`0000Go
oooo1?l00008ooooo`Co00003?ooool2o`0001oooooo2_l000000ooooooo0000o`00001>ooooo`00
7?ooool00ol0003oooooooooo`0dooooo`;o00002?ooool2o`000003ooooool0003o000000Gooooo
0_l00009ooooo`;o000000?oooooo`000?l000007_ooool2o`0000kooooo0_l000001Ooooooo0000
o`000?l0003ooooo00co000000?oooooo`000?l000001ol00005ooooo`Co00001oooool2o`0003oo
oooo0_l00002ooooo`?o0000C_ooool001cooooo00?o0000ooooooooool0=?ooool2o`0000Cooooo
0_l00005ooooo`;o00001oooool2o`0000Cooooo0_l000001?oooooo0000o`000?l0000Qooooo`Co
00002oooool2o`000003ooooool0003o000000?o000000Coooooo`000?l0003ooooo0_l00002oooo
o`Ko000000?oooooo`000?l000000_l00006ooooo`;o00002_ooool2o`0002Gooooo0_l0000Loooo
o`;o0000Coooool001cooooo00?o0000ooooooooool0>_ooool2o`0000_ooooo0_l000000ooooooo
0000o`000004ooooo`;o00000_ooool2o`0000oooooo0_l00006ooooo`;o00001Oooool8o`0000[o
oooo0_l00002ooooo`Ko00000_ooool2o`0000;ooooo1_l0000;ooooo`;o00002_ooool3o`0000[o
oooo0_l0000?ooooo`?o00001?ooool4o`0000;ooooo0_l00006ooooo`;o00006_ooool2o`0004Go
oooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@oooo
ooooool01?ooool00ol0003oooooooooo`0hooooo`Co00002oooool2o`0000Gooooo0_l0000Aoooo
o`;o00000_ooool2o`0000?ooooo1Ol000000ooooooo0000o`000002ooooo`?o000000?oooooo`00
0?l000000ol00003ooooo`;o00001Oooool2o`000003ooooool0003o000000Co00001_ooool2o`00
00cooooo0_l0000>ooooo`;o00002?ooool4o`0000Cooooo0_l00005ooooo`;o00000_ooool4o`00
0003ooooool0003o000000;o00001?ooool2o`0000Kooooo0_l0000Gooooo`;o000000?oooooo`00
0?l00000AOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0hooooo`?o00001oooool2o`0000Cooooo0_l00004
ooooo`;o00001oooool2o`0000Sooooo0ol000000ooooooo0000o`000008o`000003ooooool0003o
000000;ooooo0_l00004ooooo`So00000_ooool2o`000003ooooool0003o000000?ooooo0ol00007
ooooo`?o00002oooool2o`0001Sooooo0_l00006ooooo`;o000000Coooooo`000?l0003ooooo0ol0
0002ooooo`So00003Oooool2o`0000Gooooo0_l00009ooooo`;o00001Oooool2o`000003ooooool0
003o000004Gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006
ooooo`03o`000?oooooooooo03kooooo0_l00002ooooo`;o00001?ooool4o`0000Oooooo0_l00002
ooooo`;o00001?ooool2o`0000?ooooo0_l000000ooooooo0000o`000003o`0000Kooooo0_l0000;
ooooo`Co00000_ooool3o`0000Kooooo0ol00004ooooo`;o00000_ooool2o`0000Cooooo0_l0000G
ooooo`;o00001_ooool3o`0000?ooooo1ol000000ooooooo0000o`000002ooooo`Wo00002Oooool6
o`0000Gooooo0_l00008ooooo`Go00001_ooool2o`0004Gooooo00000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`0003Oooooo0_l00005
ooooo`;o00002_ooool2o`0000Gooooo1?l000000ooooooo0000o`000005ooooo`;o00002?ooool2
o`00013ooooo0_l00004ooooo`;o00000_ooool2o`0000Oooooo0_l00005ooooo`;o00002?ooool2
o`0000[ooooo0_l0000;ooooo`;o00001_ooool4o`0000;ooooo0_l000000ooooooo0000o`000002
o`0000;ooooo0_l000001?oooooo0000o`000?ooool3o`0000Kooooo0_l00004ooooo`Go000000?o
ooooo`000?l000000_ooool3o`0000;ooooo0_l00004ooooo`Go00003_ooool2o`0003gooooo0000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo00001ooo
ool00ol0003oooooooooo`0gooooo`;o00000_ooool2o`00017ooooo0_l000000ooooooo0000o`00
0002ooooo`?o000000?oooooo`000?l000000_ooool2o`0000gooooo0_l00008ooooo`;o000000?o
ooooo`000?l000002Oooool2o`0000Sooooo0_l00002ooooo`;o00001Oooool2o`0000;ooooo0_l0
0002ooooo`;o00001_ooool2o`0000;ooooo0_l00005ooooo`;o00002?ooool8o`0000;ooooo1?l0
00000ooooooo0000o`000002o`0000Cooooo1?l00003ooooo`?o000000Coooooo`000?l0003ooooo
0_l00003ooooo`;o00000_ooool3o`0000;ooooo0_l00006ooooo`;o000000?oooooo`000?l00000
3?ooool2o`0003gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?o
MgMgolc<c?l000001oooool00ol0003oooooooooo`0fooooo`;o00000oooool2o`0000kooooo0_l0
00000ooooooo0000o`000005ooooo`;o00000_ooool2o`00017ooooo0_l00005ooooo`;o000000?o
ooooo`000?l000003?ooool2o`0000Cooooo0_l00002ooooo`;o000000Coooooo`000?l0003o0000
1Oooool2o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0000Gooooo0_l00005ooooo`;o0000
0oooool2o`0000?ooooo2?l00002ooooo`Ko000000?oooooo`000?l000000ol000000ooooooo0000
o`000004o`000005ooooool0003o0000o`000?ooool01?l0000Hooooo`;o00000oooool2o`0004Ko
oooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l000001oooool00ol0
003oooooooooo`0fooooo`;o00000oooool2o`0000kooooo0_l00005ooooo`;o00001?ooool2o`00
00Wooooo0_l0000>ooooo`;o00002oooool2o`0000Kooooo1?l00005ooooo`;o00000_ooool2o`00
00;ooooo0_l00005ooooo`;o00000oooool3o`0000cooooo0_l00003ooooo`_o000000?oooooo`00
0?l000001?ooool3o`000003ooooool0003o000000?o00000oooool7o`0000?ooooo1Ol00002oooo
o`;o00001?ooool2o`00017ooooo0ol00015ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h=
ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0>_ooool2o`0000;ooooo0_l00009
ooooo`;o00000_ooool2o`0000?ooooo1?l00002ooooo`;o00000oooool2o`0000Cooooo0_l0000:
ooooo`;o00003oooool2o`0000;ooooo0_l00002ooooo`;o00002oooool2o`0000;ooooo0_l00002
ooooo`;o000000?oooooo`000?l000000oooool2o`0000;ooooo0_l0000:ooooo`;o00000_ooool7
o`000005ooooool0003o0000o`000?ooool02Ol00005ooooo`co00000_ooool5o`0000;ooooo0_l0
0004ooooo`;o00003Oooool2o`0000?ooooo0_l00009ooooo`;o0000>_ooool001cooooo00?o0000
ooooooooool0>?ooool5o`000003ooooool0003o000000Wooooo0_l00002ooooo`Go000000Cooooo
o`000?l0003o00001oooool2o`0000Cooooo0ol00009ooooo`;o00000_ooool2o`0000Kooooo0_l0
0007ooooo`;o00005oooool4o`0000?ooooo0_l00003ooooo`;o00002_ooool2o`0000;ooooo1?l0
0002ooooo`Go00000_oooolBo`0000;ooooo1_l00003ooooo`;o00002Oooool2o`0000gooooo0_l0
0004ooooo`;o00002?ooool2o`0003[ooooo000Looooo`03o`000?oooooooooo02kooooo0_l00008
ooooo`;o000000?oooooo`000?l000003?ooool2o`000003ooooool0003o000000Co000000?ooooo
o`000?l000003_ooool3o`0000gooooo0_l00006ooooo`;o00001?ooool2o`0000Wooooo0_l0000:
ooooo`?o00001?ooool2o`0000?ooooo0_l0000Dooooo`Oo000000?oooooo`000?l000005?l00006
ooooo`;o000000?oooooo`000?l000002oooool2o`0001?ooooo0_l0000;ooooo`;o0000=oooool0
01cooooo00?o0000ooooooooool0;_ooool2o`0000Cooooo0_l0000Cooooo`;o000000Coooooo`00
0?l0003ooooo0ol0000Booooo`;o00001oooool2o`0000Oooooo0_l00003ooooo`;o00001?ooool2
o`0000Wooooo0_l0000:ooooo`?o00000oooool2o`000003ooooool0003o000000cooooo0_l00008
ooooo`Ko00001?oooolGo`0000;ooooo0_l00002ooooo`?o000000?oooooo`000?l000002?ooool3
o`0000_ooooo0_l0000Booooo`;o0000=oooool001cooooo00?o0000ooooooooool0=?ooool4o`00
00[ooooo0_l000000ooooooo0000o`00000Vooooo`;o00001oooool9o`0000Gooooo0_l00002oooo
o`?o00004oooool2o`000003ooooool0003o000000_ooooo0ol00002ooooo`?o00000oooool4o`00
0003ooooool0003o000000;ooooo8Ol000000ooooooo0000o`000009ooooo`;o00002oooool2o`00
04_ooooo000Looooo`03o`000?oooooooooo037ooooo0_l00003ooooo`?o00002Oooool2o`000003
ooooool0003o000001Cooooo1?l0000Fooooo`Ko000000Coooooo`000?l0003o00001Oooool2o`00
00;ooooo0ol0000Sooooo`;o00000oooool=o`0000;ooooo6_l000000ooooooo0000o`000007o`00
00?ooooo0_l0000?ooooo`;o00003_ooool2o`0003gooooo000Looooo`03o`000?oooooooooo037o
oooo0_l00003ooooo`?o00007?ooool2o`0000Cooooo1?l00002ooooo`;o00003oooool<o`0000Ko
oooo0_l0000Iooooo`Co00004_ooool7o`000003ooooool0003o000000;o000000?oooooo`000?l0
00008?l00002ooooo`;o000000?oooooo`000?l000003oooool2o`0000kooooo0_l0000mooooo`00
7?ooool00ol0003oooooooooo`0aooooo`?o00008Oooool2o`0000Wooooo0ol00009ooooo`?o0000
0_ooool=o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o00005Oooool4o`0000_ooooo
0_l00005ooooo`;o000000?oooooo`000?l000009Ol000000ooooooo0000o`000003ooooo`Go0000
00?oooooo`000?l000001oooool4o`0000;ooooo1?l0001;ooooo`007?ooool00ol0003ooooooooo
o`0booooo`?o00002_ooool2o`0000Cooooo0ol00004ooooo`;o00004_ooool2o`0000;ooooo0_l0
0006ooooo`?o00000_ooool8o`000003ooooool0003o000000;o000000?oooooo`000?l000001ooo
ool2o`0000?ooooo0_l00005ooooo`;o00000oooool2o`0000Cooooo0_l0000=ooooo`;o00000_oo
ool2o`0000Cooooo0ol000000ooooooo0000o`00000Do`000003ooooool0003o000000ko000000Go
ooooo`000?l0003o0000ooooo`05o`0000Oooooo1?l000000ooooooo0000o`000003o`0000Kooooo
0_l00013ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00000_ooool2o`0000Wooooo0ol0
0004ooooo`?o000000Coooooo`000?l0003ooooo1Ol00005ooooo`?o000000?oooooo`000?l00000
0oooool4o`000003ooooool0003o000000?ooooo0_l00002oooooa;o00003_ooool2o`0000Gooooo
0_l00003ooooo`;o00001?ooool2o`00017ooooo1_l00005ooooob3o000000?oooooo`000?l00000
0ol000000ooooooo0000o`000003ooooo`;o00001?ooool2o`0000Sooooo1?l00007ooooo`;o0000
@oooool001cooooo00?o0000ooooooooool09oooool2o`0000Kooooo1?l0000;ooooo`;o000000?o
ooooo`000?l000001_ooool2o`0000?ooooo0ol00004ooooo`Co000000?oooooo`000?l000000ooo
ool4o`0000Kooooo0_l00002oooooa;o00000oooool2o`0001Sooooo0_l000001?oooooo0000o`00
0?ooool2o`0000Wooooo0_l00002ooooo`Oo00001?oooolIo`000003ooooool0003o000000_o0000
00Coooooo`000?l0003o00000_ooool2o`0000Cooooo0_l00008ooooo`Co00004?ooool2o`0003[o
oooo000Looooo`03o`000?oooooooooo02Oooooo0_l00008ooooo`;o00003_ooool4o`00013ooooo
0_l0000DoooooaCo00000oooool2o`0000Wooooo0_l0000=ooooo`Go000000?oooooo`000?l00000
2Oooool2o`000003ooooool0003o000000;o00000_ooool4o`0000;ooooo1ol00002oooooaKo0000
00?oooooo`000?l000001Ol000000ooooooo0000o`000002o`000003ooooool0003o000000Sooooo
0_l00004ooooo`;o00001_ooool2o`0000Wooooo0ol0000jooooo`007?ooool2o`0004?ooooo0ol0
0004ooooo`;o00000_ooool2o`00017ooooo0_l00008oooooaWo00002_ooool2o`0000_ooooo0_l0
00000ooooooo0000o`00000Aooooo`;o00001?ooool4o`000003ooooool0003o000002Co000000Go
ooooo`000?l0003o0000ooooo`02o`0000_ooooo0_l00002ooooo`;o00002?ooool2o`0000Wooooo
0_l0000kooooo`007?ooool00ol0003oooooooooo`0_ooooo`?o000000?oooooo`000?l000003Ooo
ool2o`0000Gooooo0_l00002ooooo`;o00004Oooool2o`0000Oooooo6_l0000Gooooo`;o00001?oo
ool2o`000003ooooool0003o000000gooooo0_l00002oooooa_o000000?oooooo`000?l000003?l0
0002ooooo`?o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00001oooool2o`00053ooooo
000Looooo`03o`000?oooooooooo02oooooo0ol000000ooooooo0000o`00000=ooooo`;o00005_oo
ool2o`0000Cooooo0_l00005oooooaSo00004oooool2o`0000Oooooo0_l00003ooooo`;o000000?o
ooooo`000?l000003Oooool3o`000003ooooool0003o000002[o00001?ooool2o`000003ooooool0
003o000000;ooooo0ol0001Iooooo`007?ooool00ol0003oooooooooo`0_ooooo`?o000000?ooooo
o`000?l000009Oooool2o`0000_ooooo6Ol0000Booooo`;o00001Oooool4o`0001Kooooo0_l00000
0ooooooo0000o`00000Ho`000003ooooool0003o000000co000000?oooooo`000?l000000oooool3
o`0000?ooooo1Ol00002ooooo`;o00001_ooool2o`0000kooooo0_l0000mooooo`007?ooool00ol0
003oooooooooo`0cooooo`;o00002_ooool2o`0000Cooooo0_l00002ooooo`;o00003oooool2o`00
0003ooooool0003o000000Gooooo0_l00002oooooaWo00006?ooool2o`0000oooooo0_l00006oooo
ocSo000000?oooooo`000?l000001Oooool2o`0000Kooooo0_l0000>ooooo`;o0000?Oooool001co
oooo00?o0000ooooooooool0=Oooool2o`0000Kooooo1?l000001?oooooo0000o`000?ooool2o`00
00;ooooo1?l0000=ooooo`;o000000?oooooo`000?l000001Oooool2o`000003ooooool0003o0000
00co000000?oooooo`000?l000002Ol0000Dooooo`?o00000oooool2o`0000?ooooo0ol000000ooo
oooo0000o`000004ooooo`;o00000oooool2o`000003ooooool0003o000000Ko000000?oooooo`00
0?l00000:?l00003ooooo`;o00000_ooool2o`00013ooooo0_l00002ooooo`Co0000@oooool001co
oooo00?o0000ooooooooool0;oooool2o`0000Cooooo0_l00006ooooo`;o00000oooool2o`0000?o
oooo0_l00002ooooo`;o00001_ooool2o`0000Sooooo1Ol00004ooooo`oo000000?oooooo`000?l0
00002?l0000<ooooo`;o00001oooool3o`0000?ooooo0_l00003ooooo`?o000000?oooooo`000?l0
00002Oooool3o`0000;ooooo7Ol00002oooooa;o00001Oooool4o`0000kooooo2_l00013ooooo`00
7?ooool00ol0003oooooooooo`0/ooooo`;o000000?oooooo`000?l000003?ooool2o`0000Sooooo
0_l00004ooooo`;o000000?oooooo`000?l000000ol00003ooooo`Co000000?oooooo`000?l00000
0ol00003oooooa_o00003?ooool2o`0000Oooooo0_l00009ooooo`Co00001Oooool2o`0000Gooooo
0ol000000ooooooo0000o`00000Lo`000003ooooool0003o000000oo00001?ooool4o`00013ooooo
0_l00002ooooo`;o00003?ooool2o`0003Wooooo000Looooo`03o`000?oooooooooo02[ooooo1?l0
0006ooooo`;o00001oooool2o`000003ooooool0003o000000Gooooo0_l00004ooooo`;o000000Co
ooooo`000?l0003o00001Oooool4o`0000Wooooo6ol0000Eooooo`;o00002oooool2o`0000Gooooo
0_l00006ooooo`;o00001?ooool/o`0000Gooooo1?l0000Rooooo`;o0000>Oooool001cooooo00?o
0000ooooooooool0:_ooool2o`0000?ooooo0_l00003ooooo`;o00001?ooool2o`0000Cooooo0_l0
0002ooooo`;o00003Oooool3o`0000?ooooo0_l0000;oooooaSo000000?oooooo`000?l000000_oo
ool2o`0000Wooooo0_l0000Aooooo`;o00002_ooool2o`0000[ooooo9?l000001?oooooo0000o`00
0?ooool2o`0000Kooooo0_l0000Fooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0:ooo
ool2o`0000;ooooo0_l00009ooooo`?o00001oooool2o`0000Sooooo2Ol0000?oooooaSo000000Co
ooooo`000?l0003ooooo0ol00003ooooo`;o000000Coooooo`000?l0003ooooo0_l0000@ooooo`Co
00002Oooool2o`0000?ooooo1?l00003ooooo`;o000000?oooooo`000?l000008ol00002ooooo`;o
000000?oooooo`000?l000006Oooool2o`0000;ooooo0_l00005ooooo`;o0000>oooool001cooooo
00?o0000ooooooooool09oooool2o`0000;ooooo0ol0000=ooooo`;o00004Oooool9o`000004oooo
ool0003o0000o`0000_ooooo6Ol00003ooooo`Go000000Coooooo`000?l0003ooooo0_l0000Coooo
o`Co00003_ooool4o`000003ooooool0003o000001Go000000?oooooo`000?l000002Ol000001Ooo
oooo0000o`000?l0003ooooo00;o00000_ooool5o`0000Wooooo0_l00003ooooo`;o00003Oooool2
o`000005ooooool0003o0000o`000?ooool00_l0000kooooo`007?ooool00ol0003oooooooooo`0W
ooooo`?o00000_ooool2o`0001Kooooo0_l0000:ooooo`Ko00000_ooool3o`0000cooooo6?l00004
ooooo`Oo00005_ooool3o`00013ooooo0_l000000ooooooo0000o`00000To`0000;ooooo0_l00004
ooooo`;o00001_ooool2o`0000;ooooo0ol00003ooooo`;o00004?ooool3o`0003kooooo000Loooo
o`03o`000?oooooooooo02Oooooo0ol0000@ooooo`;o00002?ooool2o`0000[ooooo0_l000001?oo
oooo0000o`000?l00007ooooo`?o00001_oooolFo`000003ooooool0003o000000;ooooo0_l00004
ooooo`;o00001oooool2o`0000;ooooo0_l0000:ooooo`Co00002oooool2o`0000;ooooo0_l00000
1?oooooo0000o`000?oooolWo`0000Kooooo0_l00004ooooo`;o00000_ooool2o`0000cooooo0_l0
0019ooooo`007?ooool00ol0003oooooooooo`0Wooooo`;o00004Oooool2o`00027ooooo0ol00006
oooooaKo00001Oooool2o`0000gooooo0_l00002ooooo`;o00002_ooool4o`0000?ooooo0_l00006
ooooo`;o00000_ooool5o`000003ooooool0003o000001Co000000?oooooo`000?l000003ol00004
ooooo`?o00001?ooool2o`0000?ooooo0_l0000:ooooo`?o000000?oooooo`000?l00000A_ooool0
01cooooo00?o0000ooooooooool0@_ooool2o`0000Oooooo1?l00002ooooo`;o00002Oooool2o`00
00Cooooo0_l00003oooooaCo00002Oooool4o`0000Kooooo0_l00002ooooo`;o00003?ooool2o`00
00Gooooo0_l00003ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo0_l000000ooo
oooo0000o`00000Co`000003ooooool0003o000000Wo00000_ooool4o`0000?ooooo0_l00005oooo
o`;o00000oooool2o`000003ooooool0003o000000Kooooo0ol00002ooooo`;o0000A_ooool001co
oooo0_l0000Wooooo`;o000000?oooooo`000?l000005oooool2o`0000Oooooo2?l00009ooooo`;o
00000_ooool5o`0000;ooooo5Ol00008ooooo`Co00001_ooool2o`0000;ooooo0_l00008ooooo`;o
00000_ooool2o`0000[ooooo0_l00003ooooo`;o00001Oooool2o`0000;ooooo3?l000000ooooooo
0000o`00000Do`000003ooooool0003o000001;ooooo0_l00006ooooo`;o00005Oooool2o`0003Co
oooo000Looooo`03o`000?oooooooooo02Kooooo0_l000000ooooooo0000o`000002ooooo`;o0000
8?ooool2o`0000oooooo1Ol00002ooooo`Oo000000?oooooo`000?l000002ol0000Pooooo`;o0000
0_ooool2o`0000Wooooo0_l00004ooooo`;o00001oooool4o`000003ooooool0003o000001ko0000
:oooool2o`0000Oooooo0_l0000dooooo`007?ooool00ol0003oooooooooo`0Uooooo`;o00001_oo
ool4o`0000[ooooo0_l0000;ooooo`;o00005oooool2o`0000Kooooo4Ol0000;ooooo`;o00000_oo
ool2o`0001Gooooo0_l00003ooooo`;o00001?ooool4o`000003ooooool0003o000000Sooooo1Ol0
0002oooooaWo000000?oooooo`000?l000001Ol00002ooooo`;o00002Oooool2o`0001;ooooo1?l0
0003ooooo`;o00002?ooool2o`0003?ooooo000Looooo`03o`000?oooooooooo02Gooooo0_l00008
ooooo`;o00002Oooool3o`0000_ooooo0_l0000Gooooo`;o00001oooool5o`000003ooooool0003o
000000co00001oooool3o`000003ooooool0003o000001Oooooo0_l000000ooooooo0000o`000005
ooooo`?o000000?oooooo`000?l000002oooool2o`0000;ooooo0ol000000ooooooo0000o`00000K
o`000004ooooool0003o0000o`0000Wooooo0_l00003ooooo`;o00003Oooool4o`0000cooooo0ol0
000cooooo`007?ooool00ol0003oooooooooo`0_ooooo`Co000000?oooooo`000?l000001?ooool2
o`0000;ooooo0_l0000Jooooo`;o00003Oooool5o`0000Cooooo1Ol00003ooooo`Co00001?ooool2
o`0000;ooooo0_l0000Aooooo`;o00000oooool2o`000004ooooool0003o0000o`0000Sooooo0_l0
0003ooooo`;o00000_ooool2o`0000Kooooo0_l00002ooooo`?o000000?oooooo`000?l000005_l0
0006ooooo`;o00001oooool2o`0000?ooooo1ol0000;ooooo`?o00003Oooool2o`0003Cooooo000L
ooooo`03o`000?oooooooooo02oooooo1?l000000ooooooo0000o`000003o`0000Gooooo0_l0000@
ooooo`;o00002?ooool2o`0000;ooooo0_l00009ooooo`?o000000?oooooo`000?l000000_l00000
0ooooooo0000o`000003o`000004ooooool0003o0000o`0000;ooooo1?l000000ooooooo0000o`00
0004ooooo`;o00002Oooool2o`0000Cooooo0_l00003ooooo`;o000000?oooooo`000?l000001_oo
ool2o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o00001?ooool2o`0000;ooooo0_l0
00000ooooooo0000o`000002ooooo`Go000000?oooooo`000?l000002Ol000000ooooooo0000o`00
0004o`0000kooooo0_l00003ooooo`Co000000?oooooo`000?l000002oooool2o`0000Cooooo0_l0
000nooooo`007?ooool00ol0003oooooooooo`0fooooo`?o00002_ooool2o`0000;ooooo0_l00007
ooooo`?o00002?ooool2o`000003ooooool0003o000000[ooooo0_l000000ooooooo0000o`000002
o`0000;ooooo1?l000001?oooooo0000o`000?l00002ooooo`Co00001?ooool2o`000003ooooool0
003o000000Wooooo0_l00005ooooo`;o00003Oooool2o`000003ooooool0003o000000Kooooo1?l0
0002ooooo`?o00000_ooool2o`000003ooooool0003o000000;ooooo2?l00003ooooo`?o000000?o
ooooo`000?l000001ol00005ooooo`?o00002Oooool2o`0000oooooo1Ol00004ooooo`;o0000?_oo
ool001cooooo00?o0000ooooooooool08oooool3o`0001?ooooo0_l00003ooooo`;o00000oooool2
o`0000;ooooo0_l00008ooooo`;o00002?ooool3o`0000Gooooo0_l0000<ooooo`Go00002?ooool3
o`0000Cooooo0_l00007ooooo`;o00001?ooool2o`0000Cooooo0_l00002ooooo`;o00003?ooool2
o`0000Kooooo1?l00002ooooo`;o00002_ooool2o`0000;ooooo1ol000001?oooooo0000o`000?oo
ool7o`0000Oooooo0ol00003ooooo`Co000000Coooooo`000?l0003o00003oooool3o`0004Kooooo
000Looooo`03o`000?oooooooooo02?ooooo0ol00003ooooo`;o00001Oooool2o`0000Oooooo0_l0
0003ooooo`;o00000oooool7o`0000Oooooo0_l00009ooooo`;o00001Oooool2o`0000;ooooo0_l0
00001?oooooo0000o`000?ooool2o`0000;ooooo1Ol00008ooooo`?o00002_ooool2o`000003oooo
ool0003o000000?ooooo1Ol00006ooooo`;o00000_ooool5o`0000gooooo0_l00009ooooo`;o0000
1?ooool4o`000003ooooool0003o000000;ooooo0ol00004ooooo`Ko00001?ooool2o`0000?ooooo
0_l000000ooooooo0000o`000004o`000003ooooool0003o000002Oooooo0_l0000`ooooo`007?oo
ool00ol0003oooooooooo`0Qooooo`;o000000?oooooo`000?l000000oooool4o`0000;ooooo1ol0
000=ooooo`Oo00001oooool3o`0000cooooo0_l00005ooooo`;o000000Coooooo`000?l0003ooooo
0ol0000Booooo`;o00001oooool2o`0000Kooooo1ol00003ooooo`?o00000_ooool5o`0000gooooo
0_l00009ooooo`;o00001?ooool4o`000003ooooool0003o000000Go00001?ooool2o`0000Sooooo
0_l00003ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`0001Kooooo0_l0000?ooooo`;o
0000<?ooool001cooooo00?o0000ooooooooool08Oooool2o`000003ooooool0003o000000Gooooo
0_l00002ooooo`Oo00006oooool3o`0000cooooo0ol0000;ooooo`;o00004_ooool2o`00017ooooo
0_l000000ooooooo0000o`000003ooooo`?o00000_ooool2o`0000Gooooo0_l0000Iooooo`;o0000
00Coooooo`000?l0003ooooo1ol00003ooooo`Co00000_ooool2o`0000[ooooo1?l0000Looooo`;o
0000@Oooool001cooooo00?o0000ooooooooool09_ooool2o`0000gooooo0_l0000@ooooo`;o0000
2?ooool4o`0000cooooo0_l0000:ooooo`;o0000=oooool2o`000003ooooool0003o000000Sooooo
0_l00005ooooo`Ko000000Coooooo`000?l0003ooooo0_l000001?oooooo0000o`000?ooool2o`00
00?ooooo1?l000000ooooooo0000o`000002o`0000;ooooo0_l0000:ooooo`;o0000HOooool001co
oooo00?o0000ooooooooool07oooool2o`0000Gooooo0_l00002ooooo`;o00002Oooool4o`0000?o
oooo0_l00006ooooo`;o000000?oooooo`000?l000002?ooool4o`0000Sooooo0_l0000>ooooo`;o
00005?ooool2o`000003ooooool0003o000000Sooooo0_l0000Dooooo`?o000000?oooooo`000?l0
00001oooool2o`0000Gooooo2Ol00002ooooo`;o00000_ooool2o`0000Cooooo1?l0000:ooooo`;o
00000_ooool2o`0000_ooooo0_l0000?ooooo`;o00000oooool2o`0000;ooooo0_l0000oooooo`00
7?ooool00ol0003oooooooooo`0Oooooo`;o00001Oooool2o`0000;ooooo0_l00003ooooo`;o0000
1Oooool3o`0000?ooooo0_l00006ooooo`;o00002Oooool4o`0000[ooooo0_l00004ooooo`;o0000
2?ooool2o`0000Gooooo0_l0000=ooooo`;o000000?oooooo`000?l000001?ooool2o`000004oooo
ool0003o0000o`0000;ooooo0_l00006ooooo`;o00002Oooool2o`000003ooooool0003o000000;o
00004_ooool2o`000003ooooool0003o000000?o000000?oooooo`000?l000001?l000000ooooooo
0000o`000008ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Gooooo0_l00004ooooo`;o
00003oooool2o`0000;ooooo1?l000001?oooooo0000o`000?l00007ooooo`;o0000=Oooool001co
oooo00?o0000ooooooooool09_ooool2o`0000Oooooo0_l0000Nooooo`Co00000_ooool2o`0000Oo
oooo0_l00003ooooo`;o00002?ooool2o`000004ooooool0003o0000ooooo`?o00001Oooool2o`00
00cooooo0_l000001?oooooo0000o`000?ooool7o`0000Kooooo0_l00009ooooo`;o000000?ooooo
o`000?l000000_l00004ooooo`;o00001oooool2o`0000Kooooo0_l000001?oooooo0000o`000?l0
0002ooooo`Co000000?oooooo`000?l000001?ooool2o`0000;ooooo0_l00003ooooo`;o00001?oo
ool2o`000003ooooool0003o000001Wooooo1?l00002ooooo`;o00001oooool2o`0003Gooooo000L
ooooo`03o`000?oooooooooo02oooooo0_l0000;ooooo`;o00003oooool2o`0000?ooooo1Ol00002
ooooo`Co000000?oooooo`000?l000004?ooool2o`000004ooooool0003o0000o`0000Gooooo0_l0
0007ooooo`;o00000oooool2o`0000Kooooo1?l0000Booooo`?o00002?ooool2o`0000;ooooo0_l0
0003ooooo`;o00001_ooool3o`000003ooooool0003o000000Cooooo1?l000000ooooooo0000o`00
0002ooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo1?l0000Booooo`;o00001ooo
ool2o`0004Gooooo000Looooo`;o0000>oooool4o`000003ooooool0003o000000?ooooo0_l00002
ooooo`;o00000oooool2o`0000?ooooo0ol00004ooooo`Ko00005Oooool2o`0000Wooooo0_l00003
ooooo`;o00002?ooool2o`0001Sooooo0_l00009ooooo`;o000000?oooooo`000?l000001_ooool2
o`0000Cooooo0ol00008ooooo`;o000000Coooooo`000?l0003ooooo0_l000001?oooooo0000o`00
0?l00008ooooo`;o00005?ooool2o`0000Oooooo0_l00015ooooo`007?ooool00ol0003ooooooooo
o`0Xooooo`;o00004?ooool2o`0000?ooooo0_l00003ooooo`;o00000_ooool2o`0000Cooooo0_l0
00000ooooooo0000o`000009ooooo`?o00008?ooool2o`0000?ooooo0_l00008ooooo`;o00001ooo
ool2o`0001[ooooo0_l000001?oooooo0000o`000?ooool4o`000003ooooool0003o000000;ooooo
0_l000000ooooooo0000o`000009ooooo`;o00000oooool2o`000003ooooool0003o000000Kooooo
0_l0000;ooooo`;o00000oooool2o`0005Gooooo000Looooo`03o`000?oooooooooo02Sooooo0_l0
0008ooooo`;o00006_ooool2o`000003ooooool0003o000000;o00001_ooool2o`00013ooooo0_l0
000Eooooo`;o00000_ooool2o`0000Oooooo0ol00003ooooo`;o00003_ooool2o`000003ooooool0
003o000000_ooooo1_l00005ooooo`;o00003?ooool2o`0000_ooooo0_l000000ooooooo0000o`00
0002ooooo`Co00001Oooool2o`0000?ooooo0_l0000Zooooo`;o0000:Oooool001cooooo00?o0000
ooooooooool0<Oooool3o`0000cooooo1?l000000ooooooo0000o`000005ooooo`Co000000?ooooo
o`000?l000000_l00006ooooo`;o00004?ooool2o`0000[ooooo0_l00002ooooo`;o00002Oooool2
o`000003ooooool0003o000000;ooooo1Ol000000ooooooo0000o`000002ooooo`;o00003?ooool2
o`000003ooooool0003o000000;ooooo0_l00003ooooo`;o00000_ooool2o`0000Oooooo0_l00007
ooooo`;o00002?ooool2o`0000Oooooo0ol00005ooooo`Co00001Oooool2o`0000;ooooo0_l0000Q
ooooo`;o00002?ooool2o`0002Wooooo000Looooo`03o`000?oooooooooo02_ooooo0_l00004oooo
o`;o00001oooool2o`0000Cooooo1?l000000ooooooo0000o`000005ooooo`Co000000?oooooo`00
0?l000000_l00006ooooo`;o00006?ooool6o`000004ooooool0003o0000o`0000cooooo0_l00002
ooooo`;o00001?ooool2o`0000;ooooo1?l00005ooooo`;o00001?ooool2o`0000Cooooo0_l00003
ooooo`;o00001_ooool2o`0000?ooooo0_l00007ooooo`;o00001_ooool6o`0000Cooooo0ol00009
ooooo`;o00001?ooool3o`000003ooooool0003o0000017ooooo0_l0000>ooooo`;o0000<oooool0
01cooooo00?o0000ooooooooool0:oooool2o`0000Kooooo0_l00005ooooo`;o00002_ooool2o`00
00Sooooo1_l0000Oooooo`Co00000_ooool3o`0001Wooooo1_l00005ooooo`;o00001?ooool2o`00
00;ooooo0_l00009ooooo`;o00000_ooool2o`0000?ooooo0_l0000<ooooo`;o000000?oooooo`00
0?l000000_ooool2o`0000Cooooo0_l00003ooooo`?o00000_ooool4o`0000Cooooo0ol00002oooo
o`;o00004?ooool2o`0004?ooooo000Looooo`03o`000?oooooooooo02kooooo0_l00002ooooo`?o
00004Oooool2o`0000Sooooo1_l0000;ooooo`Go00000_ooool2o`0000Wooooo1Ol00003ooooo`;o
00002Oooool2o`0000;ooooo0_l0000;ooooo`Ko00001_ooool3o`0000Kooooo0_l00009ooooo`;o
00004oooool7o`000003ooooool0003o000000[ooooo1?l000000ooooooo0000o`000006ooooo`;o
00000oooool2o`0000oooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o0000
00?oooooo`000?l000000_ooool3o`0001_ooooo1Ol0000<ooooo`Go00000_ooool2o`000003oooo
ool0003o000000;ooooo0_l00002ooooo`?o00002Oooool2o`000005ooooool0003o0000o`000?oo
ool00_l00002ooooo`;o00001Oooool2o`0000Oooooo0ol00006ooooo`?o00002?ooool3o`00013o
oooo0_l00009ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0000_ooooo1?l00008oooo
o`;o00005?ooool4o`0004;ooooo000Looooo`03o`000?oooooooooo02_ooooo0_l00006ooooo`;o
00001Oooool2o`0000[ooooo0_l00009ooooo`Ko00001_ooool2o`0000Cooooo0_l00006ooooo`;o
00000_ooool2o`0000?ooooo0_l00005ooooo`?o000000?oooooo`000?l000002ol00005ooooo`;o
000000Coooooo`000?l0003ooooo0_l0000:ooooo`Go00001_ooool3o`00013ooooo0_l0000<oooo
o`;o00004_ooool2o`0000Kooooo0_l0000Cooooo`;o00000oooool2o`0000?ooooo0_l0000moooo
o`007?ooool00ol0003oooooooooo`0jooooo`;o00002_ooool4o`0000Oooooo0_l00002ooooo`;o
00001_ooool2o`0000Oooooo1?l000000ooooooo0000o`000007ooooo`?o00001?ooool4o`000005
ooooool0003o0000o`000?ooool02?l00007ooooo`?o000000?oooooo`000?l000002Oooool6o`00
02Gooooo0_l00004ooooo`;o00000oooool2o`0000cooooo0_l00003ooooo`;o00004oooool2o`00
00?ooooo0_l00003ooooo`;o00002_ooool2o`00037ooooo000Looooo`03o`000?oooooooooo03?o
oooo0_l0000=ooooo`;o00001?ooool2o`0000Oooooo0_l0000Cooooo`Co00001_ooool2o`0000?o
oooo0_l00005ooooo`go00001Oooool2o`0000?ooooo0_l0000=ooooo`Go00001Oooool2o`0000?o
oooo0_l0000Eooooo`;o00000oooool4o`0000;ooooo0_l00002ooooo`?o00001?ooool2o`000003
ooooool0003o000000?ooooo0_l000001?oooooo0000o`000?l0000Dooooo`;o00000oooool2o`00
00oooooo0_l0000aooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00000oooool2o`000003
ooooool0003o000000Gooooo0_l0000=ooooo`;o000000?oooooo`000?l000006_ooool2o`0000[o
oooo3_l00004ooooo`;o00003Oooool2o`0000?ooooo1Ol00003ooooo`Co00000oooool4o`0001?o
oooo0_l00005ooooo`;o00000oooool5o`0000Cooooo0ol000000ooooooo0000o`000006ooooo`?o
00005?ooool2o`0000Gooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o0000
1_ooool2o`000003ooooool0003o000000Sooooo0_l0000;ooooo`Co00003?ooool2o`000003oooo
ool0003o000000[ooooo0_l00009ooooo`[o000000Coooooo`000?l0003o00001oooool2o`0000[o
oooo0_l00003ooooo`;o00001?ooool4o`0000?ooooo0_l00002ooooo`;o00001_ooool2o`0001Oo
oooo1?l000000ooooooo0000o`000002ooooo`;o00002_ooool3o`0001Cooooo0_l00005ooooo`;o
0000@?ooool001cooooo00?o0000ooooooooool0<?ooool2o`0000gooooo0_l00004ooooo`;o0000
0oooool2o`0000Kooooo0ol000000ooooooo0000o`000008ooooo`Co000000?oooooo`000?l00000
2_ooool2o`0000Wooooo2_l000000ooooooo0000o`000002o`0000Kooooo0_l0000Cooooo`Co0000
1Oooool3o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o00003?ooool4o`0000cooooo
0_l00009ooooo`;o00000oooool5o`0001;ooooo0_l00017ooooo`0000Koooooonk^k_lb<S;o0000
oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000oooo
ooooool0?oooool2o`0000Sooooo0ol000000ooooooo0000o`000005ooooo`Co00002?ooool2o`00
01?ooooo0_l00003ooooo`co000000?oooooo`000?l000001?l0000Iooooo`So00000_ooool2o`00
0003ooooool0003o000000;ooooo0_l00003ooooo`;o00000_ooool2o`0000Oooooo1?l0000Goooo
o`;o00001Oooool3o`0001Cooooo0_l00015ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5
ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0BOoo
ool2o`0000;ooooo0_l00005ooooo`;o00003?ooool2o`00017ooooo0ol00002oooooaCo00004_oo
ool2o`0000Oooooo1ol0000<ooooo`;o00000_ooool2o`0001;ooooo0_l0000Eooooo`;o00004?oo
ool2o`0000;ooooo1?l00014ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0kooooo`;o00001?oo
ool2o`0000Oooooo0_l0000Fooooo`;o00004_oooolHo`0000Cooooo0_l00009ooooo`;o000000Co
ooooo`000?l0003o00001_ooool2o`0000?ooooo0_l00007ooooo`;o00001_ooool4o`0000;ooooo
0_l00004ooooo`;o00001oooool2o`000004ooooool0003o0000ooooo`;o00001oooool2o`0000;o
oooo0_l0000Booooo`[o0000A?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
2Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0000^ooooo`;o00002oooool2o`0000Co
oooo0_l00007ooooo`;o00001oooool2o`000003ooooool0003o000001;ooooo0ol00008ooooo`;o
000000?oooooo`000?l000005?l00004ooooo`;o00002Oooool6o`0000Cooooo1_l000000ooooooo
0000o`000007ooooo`;o00001_ooool5o`000003ooooool0003o000000Cooooo0_l00004ooooo`;o
00001?ooool2o`000003ooooool0003o000000Oooooo0_l00002ooooo`?o00004Oooool2o`0000;o
oooo0_l00007ooooo`;o00002?ooool2o`0003Gooooo00000ooooooo0000ooooo`02ooooo`03o`00
0?oooooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo02Co
oooo0_l00008ooooo`;o00006Oooool2o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l0
00004?ooool7o`000003ooooool0003o000000?ooooo6ol0000?ooooo`?o00001Oooool6o`000003
ooooool0003o000000_ooooo0_l00003ooooo`Co00000_ooool4o`0000Oooooo0_l00002ooooo`;o
00003?ooool9o`0001Gooooo0_l00005ooooo`;o00002?ooool2o`0003Gooooo00000ooooooo410@
ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003ooooo
ooooo`0Tooooo`;o00005Oooool2o`0000cooooo0_l00003ooooo`;o00002?ooool2o`0000kooooo
0_l00003ooooo`;o000000?oooooo`000?l000001Oooool6o`0000;ooooo4Ol00005ooooo`;o0000
4Oooool4o`0000;ooooo0_l0000;ooooo`;o00000oooool2o`0000Cooooo1?l00006ooooo`Co0000
00?oooooo`000?l000003_ooool7o`0000;ooooo0_l0000Aooooo`;o0000A_ooool00006oooooomg
MgOoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo03So
oooo0_l000000ooooooo0000o`00000Aooooo`?o00000oooool2o`0000;ooooo0_l00008ooooo`;o
00000oooool2o`000003ooooool0003o000000_ooooo6Ol00005ooooo`;o00004?ooool5o`000003
ooooool0003o000000gooooo0_l00007ooooo`;o00001?ooool2o`0000?ooooo1?l00002ooooo`;o
00000_ooool2o`0000Gooooo0_l0000;ooooo`;o00003_ooool4o`0000?ooooo0_l00012ooooo`00
00Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000
ooooooooool0>?ooool2o`0000cooooo0_l00005ooooo`Co00000_ooool5o`000003ooooool0003o
000000Kooooo0ol00003ooooo`;o000000?oooooo`000?l000001_ooool2o`0000?ooooo6Ol00005
ooooo`;o00004?ooool2o`000004ooooool0003o0000ooooo`;o00003Oooool2o`0000Cooooo1Ol0
0004ooooo`;o00002Oooool2o`0000;ooooo0_l00005ooooo`;o00001Oooool2o`0001;ooooo1_l0
0003ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0>_ooool2o`0000[ooooo0_l00005
ooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`;o00001_ooool2o`0000?ooooo0_l0
0002ooooo`;o00000oooool2o`000003ooooool0003o000000?ooooo6_l00004ooooo`;o000000?o
ooooo`000?l000001Oooool2o`0000?ooooo0_l00007ooooo`;o00004?ooool2o`000003ooooool0
003o000000?o00001?ooool2o`00013ooooo0_l00009ooooo`;o00004_ooool2o`0004_ooooo000L
ooooo`03o`000?oooooooooo03Wooooo0ol00003ooooo`;o00002?ooool2o`0000?ooooo0_l00002
ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`0000Sooooo0_l00007ooooo`;o00001?oo
oolLo`0000Oooooo0_l00005ooooo`;o000000?oooooo`000?l000000_l0000Iooooo`;o00000_oo
ool4o`0000;ooooo0_l00006ooooo`;o000000?oooooo`000?l000001oooool2o`0000Wooooo0ol0
000Hooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0>Oooool2o`0000Cooooo0_l00003
ooooo`;o00000oooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000001Ol00004
ooooo`;o00005ooooolAo`000003ooooool0003o000000Wo00001_ooool2o`0000Sooooo0_l00003
ooooo`;o00001_ooool2o`0000Cooooo1?l0000@ooooo`;o00001_ooool2o`000003ooooool0003o
000000Oooooo0_l00002ooooo`;o00000oooool6o`0000_ooooo0_l00005ooooo`;o00000oooool2
o`0004Cooooo000Looooo`03o`000?oooooooooo03Wooooo0ol00008ooooo`;o00001_ooool2o`00
00?ooooo0_l000000ooooooo0000o`000003o`0000;ooooo0_l0000<ooooo`;o00002_ooool@o`00
0003ooooool0003o000000_o00001Oooool2o`0000Oooooo0_l00003ooooo`?o00001Oooool3o`00
00Cooooo1Ol000000ooooooo0000o`000006ooooo`;o00001Oooool4o`0001?ooooo0_l00003oooo
o`;o00000_ooool2o`0000_ooooo0_l00005ooooo`;o0000BOooool001cooooo00?o0000oooooooo
ool0>_ooool2o`0000;ooooo0_l00003ooooo`;o00002_ooool2o`0000Cooooo2?l0000<ooooo`;o
00000_ooool4o`000003ooooool0003o000001[o000000?oooooo`000?l000000_l0000>ooooo`;o
00000oooool2o`0000Kooooo0ol00006ooooo`?o000000?oooooo`000?l000001_ooool2o`0000?o
oooo1_l0000=ooooo`;o0000<?ooool2o`0003[ooooo000Looooo`03o`000?oooooooooo03kooooo
0_l00003ooooo`;o00001oooool2o`000003ooooool0003o000000Cooooo0ol000000ooooooo0000
o`000008ooooo`;o00002?ooool4o`000003ooooool0003o000001Ko000000?oooooo`000?l00000
1?l000000ooooooo0000o`00000Kooooo`;o00001_ooool4o`0000;ooooo1?l00007ooooo`;o0000
4Oooool2o`00033ooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00002_oo
ool2o`0000Oooooo0ol0000;ooooo`;o000000?oooooo`000?l000002_ooool2o`0000;ooooo7_l0
000;ooooo`;o00002oooool2o`0000?ooooo2_l00002ooooo`Co00001_ooool5o`0000?ooooo0_l0
0002ooooo`;o00002oooool2o`0000?ooooo0_l00002ooooo`Co0000G?ooool001cooooo00?o0000
ooooooooool0@?ooool2o`00013ooooo0_l00002ooooo`;o000000?oooooo`000?l000002oooool2
o`0000[ooooo0_l00003ooooo`Ko000000?oooooo`000?l000001?l000000ooooooo0000o`000002
o`000003ooooool0003o000000Oo00001oooool2o`0000;ooooo1Ol00003ooooo`;o00001?ooool2
o`0000;ooooo2_l00005ooooo`;o000000?oooooo`000?l000000oooool5o`0000?ooooo1_l00005
ooooo`;o00001?ooool2o`0000?ooooo0_l00002ooooo`Co00002_ooool2o`00053ooooo000Loooo
o`03o`000?oooooooooo03cooooo0_l000000ooooooo0000o`000002ooooo`;o00001oooool2o`00
00Cooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00001oooool2o`0000Kooooo0_l00004
ooooo`;o00001OoooolBo`000003ooooool0003o000000So00001_ooool2o`0000;ooooo0_l00000
0ooooooo0000o`000003ooooo`;o00002?ooool:o`0000Sooooo0_l00003ooooo`Co00001?ooool4
o`0000Oooooo0_l0000>ooooo`;o00001_ooool2o`0000?ooooo0_l0001@ooooo`007?ooool00ol0
003oooooooooo`0looooo`;o000000Goooooo`000?l0003o0000ooooo`06o`0000?ooooo0_l00005
ooooo`Go00002_ooool2o`0000;ooooo0_l00002ooooo`;o00001?ooool2o`0000Gooooo7Ol0000C
ooooo`;o00001?ooool3o`000003ooooool0003o000000Oo000000Coooooo`000?l0003o00000ooo
ool2o`0000Kooooo0_l00004ooooo`Co00001Oooool3o`0000oooooo0_l000000ooooooo0000o`00
0003ooooo`;o00002Oooool2o`0004[ooooo000Looooo`03o`000?oooooooooo043ooooo0_l00003
ooooo`Co00002?ooool6o`0000oooooo0_l0000?oooooa_o00000_ooool3o`0000[ooooo0_l00000
0ooooooo0000o`000003o`000003ooooool0003o000000Co000000?oooooo`000?l000002ol00003
ooooo`;o00003?ooool2o`0000Cooooo0_l000001?oooooo0000o`000?l00003ooooo`;o00002ooo
ool4o`0000kooooo0_l000000ooooooo0000o`000017ooooo`007?ooool2o`00043ooooo0_l0000:
ooooo`Co00000_ooool6o`000003ooooool0003o000001Wooooo0_l00002oooooa_o000000?ooooo
o`000?l000000_l0000:ooooo`;o000000Coooooo`000?l0003o00000ooooolEo`0000kooooo0_l0
0002ooooo`?o000000?oooooo`000?l000001_ooool4o`0000Gooooo0_l00003ooooo`Co00000_oo
ool2o`0000gooooo0_l0000Dooooo`;o0000<Oooool001cooooo00?o0000ooooooooool0?oooool4
o`0000Sooooo1?l00004ooooo`?o00000_ooool2o`0000[ooooo0_l0000=ooooo`;o00000ooooolB
o`000003ooooool0003o000000Go000000?oooooo`000?l000003?ooool2o`000003ooooool0003o
000000Gooooo5?l0000>ooooo`;o00000_ooool7o`0000Gooooo1?l00005ooooo`?o00000_ooool5
o`000003ooooool0003o000000cooooo0_l00007ooooo`;o00003?ooool2o`00037ooooo000Loooo
o`03o`000?oooooooooo047ooooo0_l0000@ooooo`;o00001oooool2o`0000Kooooo0_l000000ooo
oooo0000o`00000Aooooo`;o000000?oooooo`000?l000004Ol00003ooooo`;o00001Oooool2o`00
00Sooooo0_l00006oooooa;o00001oooool2o`0000Kooooo0_l00005ooooo`Go00000oooool2o`00
0003ooooool0003o000000Cooooo1?l00005ooooo`;o00000oooool2o`0000Cooooo0_l00004oooo
o`;o00001oooool2o`0003oooooo000Looooo`03o`000?oooooooooo04Kooooo0_l000000ooooooo
0000o`000008ooooo`?o00001_ooool2o`0000Kooooo1Ol00003ooooo`;o00003ooooolCo`0000?o
oooo0ol00004ooooo`;o00000oooool4o`0000Cooooo0_l000000ooooooo0000o`00000Bo`000003
ooooool0003o000000Cooooo0_l0000=ooooo`Go000000?oooooo`000?l000000_l00007ooooo`;o
00002Oooool5o`0000;ooooo1?l00004ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0
@Oooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0000Cooooo1?l00007ooooo`;o
00000_ooool2o`000003ooooool0003o000000;o000000Coooooo`000?l0003ooooo0_l0000@oooo
oa;o00000oooool3o`0000Wooooo1?l00004oooooaOo000000?oooooo`000?l000003?ooool2o`00
00Kooooo0_l00003ooooo`;o00002Oooool2o`0000Wooooo0ol00004ooooo`Co00001?ooool2o`00
04Sooooo000Looooo`03o`000?oooooooooo03kooooo0_l000000ooooooo0000o`000009ooooo`;o
00001?ooool3o`0000Sooooo0_l00002ooooo`;o00001?ooool4o`0001?ooooo1?l00002ooooo`Wo
000000?oooooo`000?l000000_l0000?ooooo`;o00000oooool2o`000003ooooool0003o000000Go
000000?oooooo`000?l000002ol0000?ooooo`Co00000oooool3o`0000?ooooo0ol0000Cooooo`;o
00001_ooool2o`0000Kooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`0Xooooo`;o0000
5?ooool2o`0000?ooooo0_l000000ooooooo0000o`00000:ooooo`;o00004oooool2o`0000Kooooo
0_l0000=ooooo`;o00001?ooool8o`0000;ooooo1?l0000Dooooo`co000000?oooooo`000?l00000
2ol0000<ooooo`;o000000Coooooo`000?l0003ooooo1?l00004ooooo`?o00002?ooool2o`0001Wo
oooo0_l00017ooooo`007?ooool00ol0003oooooooooo`0Xooooo`;o00006Oooool2o`000003oooo
ool0003o000000oooooo0_l00004ooooo`;o00002?ooool2o`0000Kooooo0_l0000Eooooo`Ko0000
6?oooolHo`0000;ooooo0ol0000:ooooo`?o00001?ooool3o`0000Gooooo0ol00008ooooo`;o0000
H_ooool001cooooo00?o0000ooooooooool0@_ooool2o`0001?ooooo0_l00004ooooo`;o000000Co
ooooo`000?l0003o00001?ooool2o`0000Kooooo0ol00009ooooo`;o00002_ooool5o`0000Gooooo
0_l00003ooooo`;o00001Oooool2o`0000;ooooo7?l00002ooooo`;o000000Coooooo`000?l0003o
00000oooool2o`000004ooooool0003o0000ooooo`;o00000oooool2o`0000Kooooo0_l00003oooo
o`;o00001_ooool2o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l000001?ooool2o`00
04_ooooo000Looooo`03o`000?oooooooooo04;ooooo0_l000000ooooooo0000o`000003ooooo`?o
00003?ooool2o`0000Gooooo0ol0000=ooooo`;o00002Oooool2o`0001;ooooo1?l00003ooooo`;o
00001Oooool2o`0000;ooooo0ol00002oooooa[o00000_ooool3o`000003ooooool0003o000000;o
00001?ooool4o`0000kooooo0ol00004ooooo`?o00000_ooool2o`0000Gooooo0_l000000ooooooo
0000o`000004ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0AOooool2o`0000?ooooo
0ol00006ooooo`;o00001?ooool2o`0002kooooo0_l00004ooooo`;o00001Oooool2o`0000Sooooo
8?l00003ooooo`;o000000?oooooo`000?l000002?ooool2o`0000gooooo1?l00004ooooo`;o0000
2_ooool3o`0005?ooooo000Looooo`03o`000?oooooooooo04Gooooo0_l0000<ooooo`;o00003?oo
ool2o`0000Cooooo0ol0000Fooooo`;o00001oooool2o`000003ooooool0003o000001;ooooo1_l0
00000ooooooo0000o`00000Fo`0000Cooooo0_l0000?ooooo`?o00002?ooool2o`0000Wooooo0_l0
0008ooooo`Co0000DOooool001cooooo00?o0000ooooooooool0AOooool2o`0001[ooooo0_l00004
ooooo`?o00002Oooool2o`0000;ooooo0_l00007ooooo`?o00000oooool2o`0000;ooooo1?l00003
ooooo`;o00004?ooool2o`0000Cooooo5_l0000@ooooo`;o00000_ooool4o`0001?ooooo0_l00009
ooooo`?o000000?oooooo`000?l00000C_ooool001cooooo00?o0000ooooooooool0FOooool2o`00
00?ooooo0_l00005ooooo`;o00003?ooool2o`0000;ooooo0_l00008ooooo`Co000000?oooooo`00
0?l000000_ooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`00000Aoooo
oa;o000000?oooooo`000?l000000_l0000>ooooo`;o000000?oooooo`000?l000000_ooool2o`00
00Sooooo0_l0000Jooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0FOooool2o`0000?o
oooo1?l00003ooooo`;o00001Oooool2o`0000Gooooo0_l0000>ooooo`;o00002?ooool2o`0000?o
oooo1?l0000Aooooo`;o000000?oooooo`000?l000002ol00002ooooo`Go00003?ooool5o`0000Oo
oooo1?l00003ooooo`;o00001oooool2o`00067ooooo000Looooo`03o`000?oooooooooo04Gooooo
0_l00009ooooo`;o00001_ooool3o`0000Gooooo0_l0000:ooooo`;o00001Oooool2o`0001gooooo
0ol0000Gooooo`_o000000?oooooo`000?l000000_l00002ooooo`?o00002Oooool5o`0000Oooooo
1?l00008ooooo`;o00000_ooool2o`0000Sooooo0_l0001Gooooo`007?ooool2o`0004Kooooo0_l0
0003ooooo`;o00001?ooool2o`0000Kooooo0ol000000ooooooo0000o`000005ooooo`Co00004Ooo
ool2o`0001Gooooo0_l00002ooooo`;o00002Oooool2o`0000Sooooo0_l00002oooooa7o000000Co
ooooo`000?l0003o00002oooool2o`0000;ooooo0_l00002ooooo`Co00002_ooool2o`0000?ooooo
0_l00007ooooo`;o00001?ooool2o`00057ooooo000Looooo`03o`000?oooooooooo04[ooooo0_l0
0003ooooo`;o00002oooool2o`0000Gooooo1?l00003ooooo`;o00002_ooool4o`0001Gooooo0_l0
000:ooooo`;o000000?oooooo`000?l000002?ooool2o`0000Cooooo3ol0000Cooooo`;o000000Co
ooooo`000?l0003o00002Oooool2o`0000Gooooo0ol00006ooooo`;o00001Oooool2o`00057ooooo
000Looooo`03o`000?oooooooooo04oooooo1Ol00002ooooo`;o00001?ooool2o`0000_ooooo0ol0
000:ooooo`Co00005Oooool2o`0000[ooooo0_l00008ooooo`;o00002Oooool6o`0001Gooooo0_l0
0006ooooo`;o00002?ooool5o`0000Cooooo0_l00005ooooo`Co0000F?ooool001cooooo00?o0000
ooooooooool0DOooool7o`0000;ooooo1?l0000;ooooo`;o00004oooool5o`0000Oooooo0_l00003
ooooo`;o00005?ooool2o`0002Cooooo0_l0000@ooooo`Go00002oooool2o`000003ooooool0003o
000005Oooooo000Looooo`03o`000?oooooooooo057ooooo0_l000000ooooooo0000o`000004oooo
o`;o00002oooool2o`0000Gooooo0_l0000<ooooo`Oo00001oooool2o`0001;ooooo0_l00002oooo
o`Co00002?ooool2o`0000Kooooo0_l000000ooooooo0000o`00000Jooooo`Co00001?ooool3o`00
0003ooooool0003o000000gooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`1@ooooo`?o
00005?ooool4o`0000?ooooo0_l0000;ooooo`?o00006_ooool2o`0000Cooooo0_l00002ooooo`Co
00002?ooool2o`0000Cooooo1?l000000ooooooo0000o`00000Iooooo`Go00001?ooool2o`0000;o
oooo0_l0000:ooooo`;o0000F_ooool001cooooo00?o0000ooooooooool0D?ooool2o`0001Cooooo
1Ol0000>ooooo`Co00006oooool2o`0001Cooooo0_l00002ooooo`Co00000oooool2o`0000Wooooo
0_l00002ooooo`;o00000oooool2o`0000Gooooo0_l0000Gooooo`;o000000?oooooo`000?l00000
Eoooool001cooooo00?o0000ooooooooool0F?ooool2o`0000?ooooo0_l00007ooooo`Go00001?oo
ool2o`0000Sooooo1Ol000000ooooooo0000o`00000>ooooo`;o00005_ooool6o`0000Gooooo0_l0
0005ooooo`;o00002Oooool3o`000003ooooool0003o000000?ooooo0_l0000;ooooo`;o00000_oo
ool2o`0000;ooooo0_l0000<ooooo`Co0000EOooool001cooooo00?o0000ooooooooool0EOooool5
o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`Go00001_ooool2o`0000?ooooo0_l00004
ooooo`Co000000Coooooo`000?l0003ooooo0_l0000;ooooo`;o00001Oooool2o`0000kooooo1ol0
0004ooooo`;o00001?ooool2o`0000cooooo0_l00006ooooo`;o00002oooool2o`0000;ooooo0_l0
0002ooooo`;o00003_ooool2o`0000Sooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`1E
ooooo`?o00001Oooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`00000;
ooooo`;o00003?ooool4o`0000cooooo0_l00002ooooo`;o00002oooool2o`000003ooooool0003o
000000?o00001_ooool2o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l000001Oooool2
o`0001[ooooo0ol00004ooooo`;o00000_ooool2o`0000kooooo0_l0001;ooooo`007?ooool00ol0
003oooooooooo`1Eooooo`;o00002Oooool2o`0000?ooooo1?l0000Gooooo`Oo00002oooool2o`00
00oooooo0_l00002ooooo`;o00000oooool2o`0000gooooo0_l000000ooooooo0000o`000007oooo
o`;o00006?ooool3o`0000Cooooo0_l00002ooooo`?o0000F_ooool001cooooo00?o0000oooooooo
ool0H?ooool2o`0000?ooooo1?l0000:ooooo`;o00002oooool4o`000004ooooool0003o0000o`00
00?ooooo0_l0000Oooooo`;o00001_ooool2o`0000Kooooo1?l00007ooooo`;o00003_ooool4o`00
01;ooooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`11ooooo`;o00009?ooool3o`0000So
oooo0ol00009ooooo`;o00000_ooool6o`0000?ooooo0ol0000Oooooo`;o000000Coooooo`000?l0
003ooooo0ol00006ooooo`Co000000?oooooo`000?l000003_ooool2o`0000Cooooo1?l0000?oooo
o`;o0000GOooool001cooooo00?o0000ooooooooool0@Oooool2o`0002?ooooo1?l000000ooooooo
0000o`000005ooooo`?o00002Oooool2o`0000?ooooo1?l00005ooooo`;o00006_ooool2o`0000?o
oooo0_l000001?oooooo0000o`000?ooool2o`0000Kooooo1Ol000000ooooooo0000o`000003oooo
o`;o00002Oooool2o`0001Oooooo0_l00007ooooo`;o0000E?ooool001cooooo00?o0000oooooooo
ool0I_ooool4o`000003ooooool0003o000000Kooooo0_l0000Eooooo`;o00007?ooool2o`00017o
oooo0ol00008ooooo`;o00004Oooool2o`0000Kooooo0_l00005ooooo`;o00002Oooool3o`0005?o
oooo000Looooo`03o`000?oooooooooo05cooooo0_l00009ooooo`?o00007?ooool2o`0000;ooooo
0_l0000;ooooo`;o00009oooool2o`0001Oooooo0_l00006ooooo`;o00001Oooool2o`0000[ooooo
0_l0001Cooooo`007?ooool2o`0005gooooo0_l0000:ooooo`;o00005oooool2o`0000?ooooo0_l0
000=ooooo`Co00002oooool2o`00013ooooo0_l00008ooooo`;o00000_ooool2o`0000oooooo0_l0
0002ooooo`;o00000oooool2o`0006Wooooo000Looooo`03o`000?oooooooooo05cooooo0_l00005
ooooo`;o000000?oooooo`000?l000006Oooool2o`000003ooooool0003o000000oooooo1?l0000;
ooooo`;o00004?ooool2o`0000cooooo0_l0000<ooooo`;o000000?oooooo`000?l000000_l00005
ooooo`;o00002?ooool2o`0005oooooo000Looooo`03o`000?oooooooooo047ooooo0_l0000Poooo
o`;o000000?oooooo`000?l000002?ooool2o`0001;ooooo0_l00002ooooo`;o00005oooool2o`00
00Gooooo0_l0000>ooooo`;o00003Oooool3o`000004ooooool0003o0000o`0000Cooooo0_l00003
ooooo`;o00002?ooool2o`0000Gooooo1?l0001Mooooo`007?ooool00ol0003oooooooooo`11oooo
o`;o0000;Oooool2o`0000Oooooo0_l0000=ooooo`;o00000oooool2o`0000;ooooo0_l0000>oooo
o`?o00001?ooool2o`0000_ooooo0_l000001?oooooo0000o`000?l00002ooooo`;o000000?ooooo
o`000?l000000oooool:o`0001;ooooo1?l00005ooooo`;o0000GOooool001cooooo00?o0000oooo
ooooool0I_ooool2o`00017ooooo0_l00004ooooo`;o00003?ooool2o`0000;ooooo0_l0000?oooo
o`;o00002?ooool2o`0000Oooooo1_l00002ooooo`;o000000?oooooo`000?l000000oooool2o`00
0003ooooool0003o000000;o000000?oooooo`000?l000004_ooool4o`0006Cooooo000Looooo`03
o`000?oooooooooo06Kooooo0_l0000Gooooo`;o00000_ooool4o`0000Cooooo1?l0000Mooooo`;o
00001oooool6o`0000;ooooo0_l00004ooooo`Co00001_ooool2o`000003ooooool0003o000000Oo
oooo0_l00007ooooo`;o0000IOooool001cooooo00?o0000ooooooooool0Ioooool3o`0000gooooo
0_l000000ooooooo0000o`000007ooooo`Go00000oooool2o`000003ooooool0003o000000Gooooo
1?l00005ooooo`;o000000?oooooo`000?l000000oooool2o`0000gooooo1_l00008ooooo`Co0000
00?oooooo`000?l000000oooool2o`000003ooooool0003o000000Oooooo1?l00005ooooo`;o0000
IOooool001cooooo00?o0000ooooooooool0Ioooool3o`0000gooooo3?l00003ooooo`;o00001_oo
ool2o`0000Gooooo1?l00005ooooo`Go00000oooool2o`0001Kooooo0_l00005ooooo`;o000000?o
ooooo`000?l000002?ooool2o`0000Gooooo1?l0001/ooooo`007?ooool00ol0003oooooooooo`1]
ooooo`?o00001?ooool?o`0000Kooooo0_l00008ooooo`;o000000?oooooo`000?l000000_ooool5
o`000003ooooool0003o000000?ooooo1?l000001?oooooo0000o`000?ooool2o`0000Gooooo0_l0
00000ooooooo0000o`000005ooooo`;o00004?ooool4o`0000Gooooo0_l0001^ooooo`007?ooool0
0ol0003oooooooooo`1]ooooo`?o00001?ooool5o`0000Cooooo0_l0000:ooooo`;o00002?ooool2
o`0000Cooooo1_l000000ooooooo0000o`000003ooooo`Co000000Coooooo`000?l0003ooooo0_l0
0005ooooo`Go00005oooool2o`000003ooooool0003o000007Cooooo000Looooo`03o`000?oooooo
oooo06Kooooo0_l00003ooooo`;o00004?ooool2o`0000?ooooo0ol00004ooooo`Go00002oooool3
o`0000oooooo1?l00007ooooo`?o00002?ooool2o`0000;ooooo0_l00008ooooo`;o00000_ooool2
o`0007Cooooo000Looooo`03o`000?oooooooooo06Kooooo0_l00003ooooo`;o00000oooool2o`00
013ooooo0ol00006ooooo`?o00004Oooool2o`0000Sooooo1Ol00004ooooo`;o00000oooool2o`00
00?ooooo0_l00003ooooo`;o00000_ooool2o`0000Kooooo1?l0001hooooo`007?ooool00ol0003o
ooooooooo`1Rooooo`;o00003?ooool2o`0000;ooooo0_l00008ooooo`;o00000oooool2o`0000Ko
oooo0_l0000Booooo`;o00001_ooool4o`000003ooooool0003o000000?ooooo0ol00003ooooo`?o
00000_ooool2o`000003ooooool0003o000000Oooooo0ol00002ooooo`;o00005?ooool2o`0006Co
oooo000Looooo`03o`000?oooooooooo06;ooooo0_l00008ooooo`;o00001_ooool2o`0000Sooooo
0_l00003ooooo`;o00003?ooool2o`0001Cooooo0_l00003ooooo`;o00000oooool2o`0000Gooooo
0_l00005ooooo`;o00000_ooool2o`000003ooooool0003o000000?o00006?ooool2o`0006Cooooo
00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q
8Oo<c<`01_ooool00ol0003oooooooooo`1[ooooo`Co00003Oooool3o`0000;ooooo1?l0000<oooo
o`;o00002oooool4o`0000?ooooo0_l00003ooooo`Co00000oooool2o`0000Cooooo0_l0000:oooo
o`;o000000Coooooo`000?l0003ooooo0_l0000=ooooo`;o0000Koooool00006oooooomgMgOoV9RH
oooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`00
0?oooooooooo06_ooooo1?l00006ooooo`;o00001Oooool3o`0000;ooooo1?l00006ooooo`;o0000
1?ooool2o`0000;ooooo0_l00007ooooo`Co00000oooool2o`0000?ooooo1?l00002ooooo`;o0000
00?oooooo`000?l000000_ooool2o`00017ooooo0_l0000<ooooo`;o00002Oooool2o`0006Cooooo
00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo07Gooooo0_l00006ooooo`;o00001?ooool2o`000003oooo
ool0003o000000;ooooo1?l00003ooooo`?o000000?oooooo`000?l000002Oooool2o`0000;ooooo
1Ol00004ooooo`;o000000?oooooo`000?l000000ol0000Eooooo`;o00002Oooool2o`0000cooooo
0_l0001Tooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nH
V9SooooooiRHV?lb<S801_ooool3o`0007;ooooo0_l0000Booooo`;o00000_ooool5o`0000?ooooo
0_l000000ooooooo0000o`000009ooooo`;o00000_ooool7o`000003ooooool0003o000000Ko0000
1oooool2o`0000?ooooo0_l000000ooooooo0000o`000003o`0000gooooo0_l00009ooooo`Co0000
IOooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Oo<c<co0000o`00
0?l0003oc<c<00Kooooo00?o0000ooooooooool0LOooool3o`0001Wooooo0_l00006ooooo`;o0000
1oooool2o`0000Kooooo1Ol000000ooooooo0000o`000005o`0000Sooooo0_l00002ooooo`?o0000
00?oooooo`000?l000000ol0000Hooooo`Co0000IOooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0
J?ooool2o`0000Oooooo0_l0000Hooooo`Co00003_ooool3o`0000Kooooo1?l0000Eooooo`;o0000
R?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o0000
00Kooooo00?o0000ooooooooool0J?ooool2o`0001Oooooo0_l00008ooooo`Co00003_ooool2o`00
013ooooo0ol00007ooooo`;o0000S_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool0
1OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0LOooool2o`0000kooooo0_l0
000/ooooo`?o00001?ooool2o`000003ooooool0003o000000_ooooo0_l0000=ooooo`;o0000L_oo
ool001cooooo00?o0000ooooooooool0LOooool2o`0000[ooooo0_l0000gooooo`;o00003_ooool2
o`0000gooooo0_l0000;ooooo`;o0000IOooool001cooooo00?o0000ooooooooool0NOooool2o`00
00;ooooo0_l0000Eooooo`;o00009?ooool2o`0002Kooooo0_l0001Uooooo`007?ooool00ol0003o
ooooooooo`1iooooo`;o00006Oooool2o`0002Cooooo0_l0002=ooooo`007?ooool00ol0003ooooo
ooooo`27ooooo`;o00002_ooool2o`0001Oooooo0_l00007ooooo`;o0000T_ooool001cooooo00?o
0000ooooooooool0Qoooool2o`0000[ooooo0_l00009ooooo`;o00001Oooool2o`0000Gooooo0_l0
0007ooooo`;o00001oooool2o`0008Wooooo000Looooo`03o`000?oooooooooo09kooooo0_l00005
ooooo`;o00004oooool2o`0000;ooooo0_l00005ooooo`Co0000P?ooool001cooooo00?o0000oooo
ooooool0^_ooool2o`0000Wooooo1?l00020ooooo`007?ooool00ol0003oooooooooo`21ooooo`;o
00001oooool2o`0002Oooooo0_l00004ooooo`Co00001Oooool2o`000004ooooool0003o0000o`00
00Kooooo0_l0001iooooo`007?ooool00ol0003oooooooooo`1eooooo`;o00002_ooool2o`0000Oo
oooo0_l00002ooooo`;o00008oooool2o`0000Cooooo1?l00005ooooo`;o000000Coooooo`000?l0
003o00001_ooool2o`0007Wooooo000Looooo`03o`000?oooooooooo07Gooooo0_l0000Gooooo`;o
00004Oooool2o`0000[ooooo0_l000000ooooooo0000o`00000?ooooo`;o0000Q_ooool001cooooo
00?o0000ooooooooool0V_ooool2o`0000Gooooo0_l00009ooooo`?o000000?oooooo`000?l00000
3oooool2o`0008Kooooo000Looooo`;o0000I?ooool2o`0002gooooo0_l00006ooooo`;o00001Ooo
ool2o`0000Wooooo0ol0002Jooooo`007?ooool00ol0003oooooooooo`1Sooooo`;o0000;Oooool2
o`0001?ooooo0_l00004ooooo`;o0000V_ooool001cooooo00?o0000ooooooooool0Yoooool2o`00
0:3ooooo000Looooo`03o`000?oooooooooo09Sooooo0_l0002_ooooo`007?ooool00ol0003ooooo
ooooo`2Hooooo`;o0000[oooool001cooooo00?o0000ooooooooool0O?ooool4o`000<Wooooo000L
ooooo`03o`000?oooooooooo07cooooo1?l00039ooooo`007?ooool00ol0003oooooooooo`23oooo
o`;o0000a?ooool001cooooo00?o0000ooooooooool0Ooooool2o`0000;ooooo0_l00034ooooo`00
7?ooool00ol0003oooooooooo`1mooooo`Co00001Oooool2o`000<7ooooo000Looooo`03o`000?oo
oooooooo07Kooooo0_l00005ooooo`;o00001oooool2o`0001kooooo0_l00005ooooo`;o00001?oo
ool2o`0009Cooooo000Looooo`03o`000?oooooooooo07Kooooo0_l0000^ooooo`;o00001Oooool2
o`0000Cooooo0_l0002Dooooo`007?ooool00ol0003oooooooooo`2Aooooo`;o0000]_ooool001co
oooo00?o0000ooooooooool0TOooool2o`000;Kooooo000Looooo`03o`000?oooooooooo08Cooooo
0_l00033ooooo`007?ooool00ol0003oooooooooo`1nooooo`;o00001?ooool2o`0001Cooooo0_l0
002]ooooo`007?ooool2o`0007oooooo0_l0000Jooooo`?o0000[?ooool001cooooo00?o0000oooo
ooooool0Voooool2o`000:cooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`00
0?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom:
ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool001Co
oooo00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o0000ooooooooool0
oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooo
oooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`004_ooool00omEEEGo
IVIVo`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Qoooo
o`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05_ooool4o`000004oa0@4?oooooo
ooooooooo`Co000000?o410@ooooooooool00_ooool00ol0003ok^k^ooooo`03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h0S?ooool00:;ooooo00Go0000ooooooooooooooooo`000009ooooo`Ko0000
3?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?oEEEEojVYZOooool0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg08cooooo002Rooooo`05o`000?ooooooooooooooool0
00006oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?oZJVYoeEEEOoo
ool00oooool01Ol@413ooooooooooooooooo410@08cooooo002Rooooo`05o`000?oooooooooooooo
ool000002Oooool6o`0000cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03ob4Q8Ooooooooooo00;ooooo00Go0000ooooooooooooooooo`00002<ooooo`00X_ooool01Ol0
003oQhN7oooooonYZJWo000001_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03oeEEEOo<c<cooooo00;ooooo00Go0000ooooooooooooooooo`00002<ooooo`00XOooool0
0ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo01Wooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03ojVYZOmgMgOooooo00;ooooo00Go410@oooooooooooooooooa0@
402<ooooo`00`_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0S?ooool00<3ooooo00?o
EEEEofIVI_l000001Oooool00omEEEGoIVIVo`000004ooooo`Go00000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^08cooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1176) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.48707 .29306 Mdot
.49631 .3497 Mdot
.38704 .63638 Mdot
.6199 .48043 Mdot
.21456 .40981 Mdot
.39799 .60345 Mdot
.38149 .42366 Mdot
.37144 .47689 Mdot
.38134 .61947 Mdot
.36816 .27467 Mdot
.38849 .43244 Mdot
.73846 .48344 Mdot
.38517 .45009 Mdot
.64047 .4679 Mdot
.22016 .31011 Mdot
.64005 .54414 Mdot
.46121 .34734 Mdot
.51493 .65391 Mdot
.71096 .46631 Mdot
.36995 .57856 Mdot
.45076 .36425 Mdot
.63589 .47671 Mdot
.52281 .34639 Mdot
.64125 .46745 Mdot
.60953 .5018 Mdot
.49049 .31359 Mdot
.5299 .37336 Mdot
.64462 .52038 Mdot
.61781 .52294 Mdot
.37766 .47478 Mdot
.63983 .64802 Mdot
.19727 .36707 Mdot
.69289 .44364 Mdot
.26544 .68281 Mdot
.35725 .46989 Mdot
.64775 .36768 Mdot
.40297 .62063 Mdot
.36155 .45448 Mdot
.35493 .45319 Mdot
.3517 .42445 Mdot
.36963 .4418 Mdot
.5028 .32278 Mdot
.33597 .49353 Mdot
.45127 .56037 Mdot
.65691 .54258 Mdot
.26521 .38459 Mdot
.78679 .41305 Mdot
.68275 .49615 Mdot
.46138 .33196 Mdot
.36531 .70242 Mdot
.24446 .51135 Mdot
.35823 .42515 Mdot
.41419 .5639 Mdot
.46964 .89962 Mdot
.36268 .46431 Mdot
.68839 .52874 Mdot
.40094 .63196 Mdot
.6479 .47826 Mdot
.64675 .46604 Mdot
.56173 .26919 Mdot
.68777 .50689 Mdot
.54915 .67405 Mdot
.4748 .28781 Mdot
.5241 .48886 Mdot
.38841 .62223 Mdot
.36083 .44006 Mdot
.50928 .34494 Mdot
.38116 .45884 Mdot
.57812 .49781 Mdot
.3708 .57378 Mdot
.681 .50026 Mdot
.37336 .43389 Mdot
.45725 .32206 Mdot
.661 .50887 Mdot
.45098 .76774 Mdot
.43825 .18105 Mdot
.56452 .70352 Mdot
.61006 .3392 Mdot
.56568 .30138 Mdot
.44348 .70775 Mdot
.61362 .46386 Mdot
.73914 .60058 Mdot
.37556 .21081 Mdot
.5239 .36026 Mdot
.58912 .43275 Mdot
.53573 .61991 Mdot
.66028 .50404 Mdot
.28751 .3148 Mdot
.62044 .53077 Mdot
.46554 .78851 Mdot
.37905 .60373 Mdot
.48107 .34091 Mdot
.61868 .47908 Mdot
.65033 .52722 Mdot
.77494 .47825 Mdot
.65856 .43717 Mdot
.63524 .50167 Mdot
.47696 .30466 Mdot
.35084 .43116 Mdot
.71985 .50957 Mdot
.42203 .53885 Mdot
.43066 .58374 Mdot
.67215 .45023 Mdot
.41789 .58437 Mdot
.45093 .33978 Mdot
.66121 .51534 Mdot
.35008 .45282 Mdot
.67038 .45375 Mdot
.41152 .36417 Mdot
.49735 .35282 Mdot
.64327 .52459 Mdot
.53602 .65758 Mdot
.73953 .70513 Mdot
.47622 .34905 Mdot
.47738 .7023 Mdot
.60107 .47343 Mdot
.64233 .49541 Mdot
.49582 .34691 Mdot
.42451 .62969 Mdot
.30594 .28798 Mdot
.52872 .34099 Mdot
.33896 .43586 Mdot
.50597 .29482 Mdot
.57796 .44493 Mdot
.38456 .60327 Mdot
.25967 .60049 Mdot
.32924 .39645 Mdot
.64987 .62561 Mdot
.66063 .49772 Mdot
.35705 .31951 Mdot
.38391 .57875 Mdot
.49057 .33401 Mdot
.38443 .45964 Mdot
.70554 .43833 Mdot
.50369 .36403 Mdot
.39914 .44765 Mdot
.5495 .66211 Mdot
.29715 .55507 Mdot
.47181 .36635 Mdot
.44427 .53874 Mdot
.39383 .47344 Mdot
.36158 .4217 Mdot
.321 .75459 Mdot
.50665 .34142 Mdot
.52755 .6762 Mdot
.37913 .46869 Mdot
.61457 .63381 Mdot
.67389 .53252 Mdot
.70497 .6502 Mdot
.81566 .44399 Mdot
.27931 .69809 Mdot
.3183 .56857 Mdot
.53548 .70026 Mdot
.33626 .45697 Mdot
.62027 .50756 Mdot
.48171 .31043 Mdot
.50582 .31987 Mdot
.69242 .49515 Mdot
.61195 .48818 Mdot
.67489 .50827 Mdot
.64933 .52931 Mdot
.52957 .23296 Mdot
.63214 .44223 Mdot
.79675 .46034 Mdot
.47632 .34173 Mdot
.62032 .49508 Mdot
.41982 .62468 Mdot
.62702 .42773 Mdot
.36893 .43859 Mdot
.64037 .4817 Mdot
.61937 .48328 Mdot
.69168 .5028 Mdot
.3541 .42725 Mdot
.24168 .3068 Mdot
.79871 .52904 Mdot
.20384 .38527 Mdot
.50808 .7781 Mdot
.40847 .58752 Mdot
.65385 .50264 Mdot
.53601 .66371 Mdot
.67857 .34868 Mdot
.6286 .45727 Mdot
.85827 .60094 Mdot
.63319 .49332 Mdot
.21386 .38394 Mdot
.60321 .55141 Mdot
.16124 .45389 Mdot
.71305 .62534 Mdot
.62683 .51542 Mdot
.55464 .54851 Mdot
.49655 .41313 Mdot
.42277 .54643 Mdot
.37249 .44293 Mdot
.41779 .62961 Mdot
.39661 .6376 Mdot
.36583 .49666 Mdot
.53336 .28714 Mdot
.54878 .4807 Mdot
.58429 .45632 Mdot
.37575 .56831 Mdot
.45688 .30597 Mdot
.5574 .69152 Mdot
.49845 .30174 Mdot
.45153 .13608 Mdot
.25614 .4653 Mdot
.34483 .48834 Mdot
.50799 .69708 Mdot
.37118 .60473 Mdot
.42936 .58631 Mdot
.51566 .6679 Mdot
.67561 .47571 Mdot
.5105 .33912 Mdot
.24615 .68351 Mdot
.47491 .24401 Mdot
.30071 .74811 Mdot
.47124 .31009 Mdot
.39925 .27879 Mdot
.39679 .44644 Mdot
.41191 .61141 Mdot
.64035 .49801 Mdot
.66978 .47849 Mdot
.46263 .37145 Mdot
.67556 .50563 Mdot
.72666 .54338 Mdot
.64074 .50996 Mdot
.25143 .54886 Mdot
.5705 .69358 Mdot
.3637 .49648 Mdot
.65445 .61396 Mdot
.52119 .32918 Mdot
.64663 .73659 Mdot
.42205 .58442 Mdot
.65931 .34587 Mdot
.37284 .43103 Mdot
.55125 .66759 Mdot
.41521 .57364 Mdot
.56095 .68811 Mdot
.69309 .44691 Mdot
.38802 .64624 Mdot
.5183 .6609 Mdot
.55698 .31891 Mdot
.65303 .53433 Mdot
.52227 .22383 Mdot
.33943 .44519 Mdot
.53111 .3421 Mdot
.68313 .51172 Mdot
.41502 .59112 Mdot
.67715 .43033 Mdot
.33624 .52049 Mdot
.26132 .59624 Mdot
.43252 .61904 Mdot
.33357 .66691 Mdot
.55408 .68231 Mdot
.30083 .48906 Mdot
.38601 .30283 Mdot
.45899 .33169 Mdot
.6379 .43955 Mdot
.14859 .45859 Mdot
.37884 .46857 Mdot
.66991 .45684 Mdot
.25712 .64467 Mdot
.37086 .46709 Mdot
.65008 .4787 Mdot
.35486 .47849 Mdot
.50777 .32124 Mdot
.75343 .66691 Mdot
.46092 .34281 Mdot
.60712 .51837 Mdot
.34755 .45241 Mdot
.41078 .64577 Mdot
.48144 .3148 Mdot
.68014 .47387 Mdot
.64909 .51589 Mdot
.50217 .49003 Mdot
.62426 .50045 Mdot
.23623 .32768 Mdot
.63613 .51509 Mdot
.40956 .63433 Mdot
.68035 .44835 Mdot
.64877 .80983 Mdot
.29279 .43114 Mdot
.50964 .34357 Mdot
.41643 .64681 Mdot
.3852 .62764 Mdot
.49494 .71763 Mdot
.31621 .44823 Mdot
.60976 .46183 Mdot
.41064 .58701 Mdot
.69342 .69589 Mdot
.40313 .45006 Mdot
.63683 .43827 Mdot
.45172 .53867 Mdot
.37566 .71123 Mdot
.4064 .56409 Mdot
.71765 .46528 Mdot
.46006 .36098 Mdot
.61714 .48002 Mdot
.42989 .60504 Mdot
.44532 .36808 Mdot
.59407 .48688 Mdot
.48124 .27488 Mdot
.50213 .48717 Mdot
.3994 .43131 Mdot
.59168 .54681 Mdot
.67988 .46327 Mdot
.41795 .60905 Mdot
.51711 .32205 Mdot
.40161 .45946 Mdot
.49326 .31888 Mdot
.18514 .53434 Mdot
.41752 .3744 Mdot
.53838 .26973 Mdot
.49627 .6651 Mdot
.33581 .70203 Mdot
.15978 .48606 Mdot
.58524 .79493 Mdot
.63474 .72343 Mdot
.20199 .61345 Mdot
.42597 .61757 Mdot
.27638 .66173 Mdot
.39101 .63363 Mdot
.6028 .48907 Mdot
.38618 .6085 Mdot
.15617 .48512 Mdot
.63926 .50883 Mdot
.3915 .6122 Mdot
.6727 .72913 Mdot
.61713 .48963 Mdot
.47734 .35642 Mdot
.29756 .25329 Mdot
.6129 .80126 Mdot
.25107 .58666 Mdot
.36622 .61597 Mdot
.60802 .72096 Mdot
.63352 .5039 Mdot
.68278 .44698 Mdot
.46598 .32941 Mdot
.62955 .43781 Mdot
.54891 .69736 Mdot
.50643 .69465 Mdot
.48134 .41756 Mdot
.76605 .58291 Mdot
.64295 .55462 Mdot
.47623 .31712 Mdot
.56475 .22565 Mdot
.43127 .76592 Mdot
.34937 .69781 Mdot
.35271 .48244 Mdot
.29155 .26478 Mdot
.74542 .50872 Mdot
.39297 .50592 Mdot
.4546 .57767 Mdot
.4837 .35054 Mdot
.22739 .32924 Mdot
.3714 .44674 Mdot
.7133 .29124 Mdot
.57149 .59704 Mdot
.67228 .47323 Mdot
.37519 .42783 Mdot
.69723 .54438 Mdot
.59146 .81472 Mdot
.72939 .2837 Mdot
.75208 .55206 Mdot
.60223 .51422 Mdot
.47093 .77001 Mdot
.6405 .48736 Mdot
.32253 .27598 Mdot
.63839 .51731 Mdot
.48562 .31993 Mdot
.34861 .27372 Mdot
.50444 .43554 Mdot
.79934 .50834 Mdot
.27635 .43245 Mdot
.53635 .70039 Mdot
.64273 .50404 Mdot
.67162 .47132 Mdot
.54887 .694 Mdot
.4925 .37152 Mdot
.65021 .52986 Mdot
.63364 .73977 Mdot
.66768 .50293 Mdot
.3642 .44656 Mdot
.73213 .56266 Mdot
.53973 .31508 Mdot
.58463 .46856 Mdot
.46035 .30694 Mdot
.39994 .42974 Mdot
.35494 .46066 Mdot
.65928 .54807 Mdot
.36024 .4189 Mdot
.6295 .48725 Mdot
.73469 .28045 Mdot
.47559 .36526 Mdot
.65957 .57097 Mdot
.51925 .35616 Mdot
.60336 .34258 Mdot
.3514 .46347 Mdot
.25361 .52549 Mdot
.7304 .46467 Mdot
.3753 .44656 Mdot
.42248 .37666 Mdot
.629 .55006 Mdot
.60459 .52491 Mdot
.42853 .79197 Mdot
.37265 .62674 Mdot
.50917 .46328 Mdot
.36893 .47845 Mdot
.68327 .47046 Mdot
.59534 .45346 Mdot
.3968 .42655 Mdot
.64905 .23199 Mdot
.65124 .76351 Mdot
.63855 .5129 Mdot
.47906 .32693 Mdot
.49211 .3317 Mdot
.59912 .51349 Mdot
.65414 .44451 Mdot
.38926 .58497 Mdot
.40068 .65217 Mdot
.36589 .62386 Mdot
.50265 .4828 Mdot
.25154 .53545 Mdot
.22668 .4455 Mdot
.3527 .42396 Mdot
.37962 .33481 Mdot
.48473 .78988 Mdot
.59839 .4354 Mdot
.37125 .58326 Mdot
.66377 .45771 Mdot
.62487 .47916 Mdot
.40714 .44905 Mdot
.24573 .60833 Mdot
.72381 .52591 Mdot
.48164 .37191 Mdot
.38733 .47393 Mdot
.63814 .41036 Mdot
.28942 .39613 Mdot
.53847 .6605 Mdot
.34123 .75571 Mdot
.36975 .43372 Mdot
.48153 .35508 Mdot
.35063 .46883 Mdot
.67119 .48444 Mdot
.71324 .48792 Mdot
.49024 .34508 Mdot
.50803 .68883 Mdot
.66417 .42907 Mdot
.6497 .48152 Mdot
.83743 .5114 Mdot
.50739 .7878 Mdot
.25999 .54999 Mdot
.62942 .51516 Mdot
.58672 .47494 Mdot
.5576 .65878 Mdot
.67033 .49735 Mdot
.67395 .51466 Mdot
.77582 .65081 Mdot
.34589 .38221 Mdot
.49973 .67561 Mdot
.68842 .26137 Mdot
.46764 .31297 Mdot
.16934 .41902 Mdot
.41401 .60679 Mdot
.32645 .4517 Mdot
.67688 .75201 Mdot
.42119 .56514 Mdot
.32318 .57315 Mdot
.18256 .39713 Mdot
.50834 .4607 Mdot
.39029 .67386 Mdot
.7422 .48788 Mdot
.65883 .52319 Mdot
.64442 .49024 Mdot
.53757 .66726 Mdot
.50944 .33466 Mdot
.51118 .4856 Mdot
.5358 .19001 Mdot
.63523 .4814 Mdot
.69104 .56725 Mdot
.46985 .22828 Mdot
.38176 .71211 Mdot
.52757 .69367 Mdot
.50816 .69328 Mdot
.64399 .50023 Mdot
.75142 .68701 Mdot
.48857 .31282 Mdot
.67968 .47249 Mdot
.60969 .45713 Mdot
.37145 .62727 Mdot
.49624 .35775 Mdot
.42736 .61279 Mdot
.25893 .50058 Mdot
.20648 .38981 Mdot
.84528 .5032 Mdot
.35347 .46305 Mdot
.38694 .2306 Mdot
.38779 .46928 Mdot
.73724 .59603 Mdot
.42654 .57671 Mdot
.62029 .45963 Mdot
.51881 .32499 Mdot
.67782 .46481 Mdot
.6444 .44509 Mdot
.67499 .4736 Mdot
.59434 .44466 Mdot
.80855 .67732 Mdot
.51016 .67755 Mdot
.58697 .50695 Mdot
.40147 .63963 Mdot
.31931 .26463 Mdot
.42718 .19038 Mdot
.66594 .46842 Mdot
.64766 .51143 Mdot
.48787 .36696 Mdot
.69378 .48014 Mdot
.3984 .45865 Mdot
.51465 .31619 Mdot
.6482 .52718 Mdot
.30083 .26526 Mdot
.62828 .52666 Mdot
.17714 .42711 Mdot
.35362 .47293 Mdot
.42176 .31953 Mdot
.5942 .52388 Mdot
.26377 .59503 Mdot
.50918 .46343 Mdot
.40018 .57466 Mdot
.3623 .41499 Mdot
.40064 .62147 Mdot
.60367 .1825 Mdot
.70854 .48351 Mdot
.61703 .50617 Mdot
.60168 .44805 Mdot
.41013 .58909 Mdot
.26716 .33766 Mdot
.28781 .47395 Mdot
.61746 .41333 Mdot
.40125 .58713 Mdot
.46613 .29587 Mdot
.583 .63702 Mdot
.51965 .34169 Mdot
.50774 .69944 Mdot
.38942 .43464 Mdot
.51906 .70189 Mdot
.2432 .63654 Mdot
.49542 .35175 Mdot
.52119 .38161 Mdot
.40875 .6025 Mdot
.50673 .5816 Mdot
.34909 .82805 Mdot
.54892 .59308 Mdot
.67976 .64048 Mdot
.46786 .32974 Mdot
.60315 .50953 Mdot
.72428 .58956 Mdot
.50194 .56318 Mdot
.39863 .6229 Mdot
.62804 .46277 Mdot
.73936 .68639 Mdot
.38952 .58439 Mdot
.63941 .4384 Mdot
.38669 .63992 Mdot
.37841 .4372 Mdot
.37052 .5899 Mdot
.4933 .37982 Mdot
.65625 .51406 Mdot
.30541 .79051 Mdot
.55306 .7195 Mdot
.63118 .50882 Mdot
.38297 .47647 Mdot
.43155 .40473 Mdot
.64784 .44944 Mdot
.55628 .66457 Mdot
.3906 .59967 Mdot
.54273 .59585 Mdot
.63882 .51485 Mdot
.40844 .58998 Mdot
.49387 .29174 Mdot
.34247 .42505 Mdot
.56576 .40962 Mdot
.262 .58971 Mdot
.46568 .3275 Mdot
.42419 .53019 Mdot
.39892 .41401 Mdot
.58624 .47153 Mdot
.62258 .4443 Mdot
.48352 .32765 Mdot
.76777 .62933 Mdot
.69136 .46282 Mdot
.61407 .46364 Mdot
.40648 .63932 Mdot
.39801 .61655 Mdot
.75507 .6521 Mdot
.42014 .63693 Mdot
.71247 .48591 Mdot
.48496 .32602 Mdot
.61922 .47432 Mdot
.48624 .36416 Mdot
.69066 .47094 Mdot
.46274 .38886 Mdot
.49765 .37283 Mdot
.29751 .45314 Mdot
.625 .46862 Mdot
.60898 .55668 Mdot
.66553 .45322 Mdot
.66962 .50849 Mdot
.38606 .58789 Mdot
.51867 .67833 Mdot
.72178 .48606 Mdot
.54127 .71876 Mdot
.56057 .686 Mdot
.44054 .40095 Mdot
.3703 .62418 Mdot
.53519 .67781 Mdot
.48609 .21793 Mdot
.36842 .62728 Mdot
.54617 .67398 Mdot
.41972 .19579 Mdot
.35579 .46842 Mdot
.46391 .36214 Mdot
.61593 .48969 Mdot
.20502 .60119 Mdot
.79111 .41711 Mdot
.39112 .54215 Mdot
.63451 .51373 Mdot
.65915 .45402 Mdot
.52781 .34639 Mdot
.66728 .19746 Mdot
.36668 .57847 Mdot
.60891 .50993 Mdot
.50807 .34952 Mdot
.73059 .24849 Mdot
.40894 .63167 Mdot
.54365 .67108 Mdot
.34518 .43285 Mdot
.46463 .28714 Mdot
.33065 .39659 Mdot
.38602 .42396 Mdot
.39961 .55443 Mdot
.24599 .51737 Mdot
.60124 .47273 Mdot
.37512 .58022 Mdot
.36284 .77655 Mdot
.48012 .24874 Mdot
.37948 .39466 Mdot
.60197 .72001 Mdot
.48194 .34949 Mdot
.39592 .46132 Mdot
.51856 .69613 Mdot
.47546 .3076 Mdot
.47215 .35685 Mdot
.40933 .43586 Mdot
.63929 .39348 Mdot
.4565 .54244 Mdot
.35836 .45122 Mdot
.43785 .78728 Mdot
.20866 .52861 Mdot
.37161 .58187 Mdot
.54995 .69522 Mdot
.22971 .62006 Mdot
.50186 .32169 Mdot
.28691 .26727 Mdot
.36768 .77242 Mdot
.63512 .50153 Mdot
.5319 .68144 Mdot
.25099 .38329 Mdot
.5543 .17709 Mdot
.36864 .46635 Mdot
.4966 .44174 Mdot
.54105 .70539 Mdot
.68579 .50801 Mdot
.59685 .63929 Mdot
.61309 .4699 Mdot
.39575 .43902 Mdot
.55579 .27266 Mdot
.48167 .35648 Mdot
.41149 .43799 Mdot
.33899 .75552 Mdot
.63018 .48464 Mdot
.62508 .46574 Mdot
.63903 .60931 Mdot
.49944 .31043 Mdot
.40161 .5745 Mdot
.60488 .467 Mdot
.64578 .48165 Mdot
.70845 .51027 Mdot
.58517 .54397 Mdot
.73733 .70363 Mdot
.60319 .4986 Mdot
.27077 .44517 Mdot
.5827 .47631 Mdot
.63059 .46763 Mdot
.45892 .30816 Mdot
.85391 .53573 Mdot
.25968 .48959 Mdot
.64197 .48231 Mdot
.60292 .50754 Mdot
.40844 .42847 Mdot
.46582 .54077 Mdot
.50182 .58086 Mdot
.53001 .59698 Mdot
.62234 .72339 Mdot
.58203 .45376 Mdot
.51471 .34698 Mdot
.52437 .65774 Mdot
.59177 .47933 Mdot
.5132 .34965 Mdot
.68897 .51196 Mdot
.39116 .58304 Mdot
.37315 .63494 Mdot
.42586 .36821 Mdot
.54117 .67982 Mdot
.65959 .59004 Mdot
.36761 .34356 Mdot
.4135 .63708 Mdot
.61398 .50402 Mdot
.32666 .47162 Mdot
.42974 .59924 Mdot
.41631 .66996 Mdot
.56014 .45502 Mdot
.4925 .31109 Mdot
.47862 .34283 Mdot
.7071 .65132 Mdot
.31008 .55241 Mdot
.82149 .54754 Mdot
.3803 .43611 Mdot
.69716 .46033 Mdot
.37234 .30542 Mdot
.47721 .34588 Mdot
.72367 .59706 Mdot
.53557 .68009 Mdot
.36964 .46832 Mdot
.31832 .62735 Mdot
.49879 .36597 Mdot
.46278 .35238 Mdot
.62986 .53414 Mdot
.65801 .47675 Mdot
.64243 .72122 Mdot
.56652 .65078 Mdot
.4023 .43314 Mdot
.55121 .69361 Mdot
.41147 .56967 Mdot
.60266 .50009 Mdot
.52294 .35408 Mdot
.22683 .57185 Mdot
.59904 .49913 Mdot
.38447 .58658 Mdot
.48379 .34543 Mdot
.55399 .68976 Mdot
.56237 .67511 Mdot
.66862 .50782 Mdot
.57045 .23244 Mdot
.3663 .45517 Mdot
.47718 .3546 Mdot
.28868 .40669 Mdot
.67673 .44486 Mdot
.65791 .48334 Mdot
.56818 .50988 Mdot
.40519 .44926 Mdot
.41835 .2944 Mdot
.5306 .71099 Mdot
.50514 .33513 Mdot
.6238 .5175 Mdot
.54873 .6798 Mdot
.40421 .29614 Mdot
.43312 .61646 Mdot
.36994 .59422 Mdot
.55871 .66619 Mdot
.53176 .68943 Mdot
.55773 .66813 Mdot
.28784 .26507 Mdot
.51821 .37368 Mdot
.74549 .50447 Mdot
.69145 .45952 Mdot
.7001 .63766 Mdot
.70191 .43167 Mdot
.39728 .46847 Mdot
.37313 .6259 Mdot
.65456 .44732 Mdot
.60286 .51198 Mdot
.58144 .53219 Mdot
.68509 .56291 Mdot
.54409 .33763 Mdot
.49669 .35469 Mdot
.70368 .48877 Mdot
.38182 .64029 Mdot
.47415 .12682 Mdot
.17406 .59683 Mdot
.60783 .53728 Mdot
.47911 .57083 Mdot
.52295 .3564 Mdot
.38808 .41596 Mdot
.52278 .60831 Mdot
.34751 .46318 Mdot
.50081 .3355 Mdot
.60231 .49817 Mdot
.37728 .34319 Mdot
.55783 .66264 Mdot
.68564 .48568 Mdot
.39346 .45726 Mdot
.68348 .49737 Mdot
.38457 .42372 Mdot
.17688 .51082 Mdot
.50989 .80182 Mdot
.63371 .49434 Mdot
.58736 .5031 Mdot
.59334 .73984 Mdot
.66459 .46584 Mdot
.5775 .71149 Mdot
.52174 .36079 Mdot
.79652 .55271 Mdot
.653 .53732 Mdot
.65697 .29136 Mdot
.6741 .44251 Mdot
.71414 .70327 Mdot
.66114 .48191 Mdot
.38525 .72157 Mdot
.64892 .52221 Mdot
.66954 .51571 Mdot
.347 .45584 Mdot
.40916 .43128 Mdot
.45955 .31465 Mdot
.41238 .586 Mdot
.1898 .40265 Mdot
.6526 .48246 Mdot
.25878 .596 Mdot
.38574 .36485 Mdot
.53221 .69129 Mdot
.50182 .33248 Mdot
.6669 .191 Mdot
.34716 .47229 Mdot
.5377 .76847 Mdot
.7215 .6832 Mdot
.3028 .41571 Mdot
.53588 .61746 Mdot
.34332 .27043 Mdot
.5538 .67838 Mdot
.69386 .49683 Mdot
.2411 .59825 Mdot
.38441 .73769 Mdot
.55965 .45335 Mdot
.41003 .41939 Mdot
.66901 .33659 Mdot
.23076 .59221 Mdot
.54764 .70881 Mdot
.52228 .70547 Mdot
.36978 .42233 Mdot
.32505 .6354 Mdot
.7041 .54206 Mdot
.53661 .68316 Mdot
.41348 .6405 Mdot
.36154 .59649 Mdot
.4383 .57749 Mdot
.49709 .315 Mdot
.30226 .72421 Mdot
.29372 .37084 Mdot
.3897 .42604 Mdot
.37167 .66838 Mdot
.53456 .32146 Mdot
.51325 .37989 Mdot
.40733 .61086 Mdot
.38003 .59114 Mdot
.46738 .36855 Mdot
.69159 .52309 Mdot
.59893 .54562 Mdot
.63772 .4828 Mdot
.52832 .66547 Mdot
.6645 .47793 Mdot
.39565 .58786 Mdot
.37209 .46362 Mdot
.3753 .60102 Mdot
.35716 .48146 Mdot
.23653 .43886 Mdot
.68047 .48489 Mdot
.65413 .51615 Mdot
.79179 .40176 Mdot
.47566 .29724 Mdot
.26381 .44483 Mdot
.25927 .57998 Mdot
.39284 .63559 Mdot
.67648 .51329 Mdot
.52036 .32071 Mdot
.53314 .71495 Mdot
.79186 .39088 Mdot
.66409 .44604 Mdot
.52145 .35742 Mdot
.61737 .51521 Mdot
.50767 .24146 Mdot
.70895 .76144 Mdot
.49358 .32217 Mdot
.81389 .44224 Mdot
.61268 .51815 Mdot
.4146 .2333 Mdot
.60499 .44871 Mdot
.70058 .68083 Mdot
.69061 .46201 Mdot
.46957 .31098 Mdot
.64047 .47873 Mdot
.50554 .30958 Mdot
.41799 .625 Mdot
.37133 .41846 Mdot
.46671 .33897 Mdot
.61083 .4519 Mdot
.11289 .58776 Mdot
.39267 .44001 Mdot
.64155 .50056 Mdot
.34341 .44002 Mdot
.51379 .33716 Mdot
.46245 .33909 Mdot
.51768 .17965 Mdot
.26356 .49776 Mdot
.3781 .43807 Mdot
.60696 .50506 Mdot
.29947 .33894 Mdot
.61511 .4735 Mdot
.6613 .69482 Mdot
.68574 .53221 Mdot
.6835 .45158 Mdot
.44501 .18032 Mdot
.40568 .44188 Mdot
.81939 .57174 Mdot
.50395 .17986 Mdot
.32802 .25086 Mdot
.44979 .30506 Mdot
.54442 .71115 Mdot
.23388 .31948 Mdot
.25366 .52974 Mdot
.4053 .58769 Mdot
.66 .44979 Mdot
.53137 .30351 Mdot
.36037 .45842 Mdot
.51755 .67509 Mdot
.63438 .49487 Mdot
.37727 .59285 Mdot
.61261 .77804 Mdot
.33719 .46314 Mdot
.50335 .32421 Mdot
.49438 .37407 Mdot
.79685 .33682 Mdot
.62768 .51658 Mdot
.6555 .51864 Mdot
.39292 .43615 Mdot
.44593 .2493 Mdot
.55578 .67802 Mdot
.65542 .74428 Mdot
.37973 .43831 Mdot
.4936 .51804 Mdot
.50502 .34626 Mdot
.6613 .45511 Mdot
.25237 .34809 Mdot
.46266 .76358 Mdot
.73119 .32213 Mdot
.53487 .66417 Mdot
.65636 .69243 Mdot
.46788 .31201 Mdot
.38367 .46289 Mdot
.2984 .57565 Mdot
.60514 .42672 Mdot
.65806 .45736 Mdot
.6586 .68658 Mdot
.51184 .42354 Mdot
.74801 .55445 Mdot
.66572 .44461 Mdot
.51803 .44147 Mdot
.68243 .45704 Mdot
.62743 .41909 Mdot
.708 .50254 Mdot
.65942 .49182 Mdot
.52203 .3573 Mdot
.57738 .43461 Mdot
.3998 .57874 Mdot
.74254 .53541 Mdot
.50583 .52666 Mdot
.6347 .51039 Mdot
.60705 .4786 Mdot
.73274 .34913 Mdot
.39545 .51022 Mdot
.47006 .3423 Mdot
.48491 .38533 Mdot
.3496 .42399 Mdot
.58924 .5397 Mdot
.41223 .58148 Mdot
.68599 .42554 Mdot
.38386 .59094 Mdot
.52208 .34251 Mdot
.40029 .63602 Mdot
.35228 .42614 Mdot
.36436 .59271 Mdot
.25098 .5362 Mdot
.37486 .47269 Mdot
.48151 .30949 Mdot
.66225 .50776 Mdot
.3828 .47624 Mdot
.63801 .62128 Mdot
.52981 .66537 Mdot
.50161 .17365 Mdot
.64324 .52885 Mdot
.34447 .38558 Mdot
.47264 .27492 Mdot
.37724 .59793 Mdot
.74697 .71219 Mdot
.4922 .37277 Mdot
.50129 .67454 Mdot
.52262 .33339 Mdot
.46524 .8003 Mdot
.52222 .68195 Mdot
.40893 .19732 Mdot
.30313 .63529 Mdot
.58175 .65903 Mdot
.68502 .52779 Mdot
.58224 .61591 Mdot
.39872 .56526 Mdot
.36054 .45942 Mdot
.3116 .58006 Mdot
.67476 .5127 Mdot
.557 .79251 Mdot
.44913 .33894 Mdot
.4099 .58408 Mdot
.38343 .45761 Mdot
.39841 .46509 Mdot
.64376 .44178 Mdot
.42051 .68582 Mdot
.68583 .46864 Mdot
.29968 .53356 Mdot
.6307 .71407 Mdot
.68638 .55492 Mdot
.6408 .50915 Mdot
.41852 .61254 Mdot
.61684 .51475 Mdot
.50277 .65533 Mdot
.29693 .72907 Mdot
.63639 .43186 Mdot
.25667 .57043 Mdot
.53262 .72579 Mdot
.49235 .3477 Mdot
.69687 .53794 Mdot
.26104 .53209 Mdot
.62182 .51499 Mdot
.68671 .81543 Mdot
.5472 .67626 Mdot
.25917 .61052 Mdot
.59484 .44913 Mdot
.61813 .451 Mdot
.53276 .51301 Mdot
.48463 .40911 Mdot
.47002 .76517 Mdot
.65522 .46343 Mdot
.62389 .67146 Mdot
.36636 .42673 Mdot
.68178 .4623 Mdot
.64388 .493 Mdot
.65217 .38697 Mdot
.39325 .46786 Mdot
.38194 .62815 Mdot
.41635 .56495 Mdot
.36279 .6295 Mdot
.50339 .65916 Mdot
.49166 .46182 Mdot
.7078 .61602 Mdot
.60135 .80081 Mdot
.51541 .65898 Mdot
.63575 .53144 Mdot
.5452 .7419 Mdot
.59942 .48733 Mdot
.52027 .69415 Mdot
.38916 .47002 Mdot
.46902 .3447 Mdot
.38458 .28821 Mdot
.37415 .57146 Mdot
.63166 .43896 Mdot
.55394 .69583 Mdot
.48459 .31004 Mdot
.54494 .63704 Mdot
.49924 .34376 Mdot
.38039 .44324 Mdot
.33255 .4409 Mdot
.51648 .68352 Mdot
.51901 .34777 Mdot
.40988 .48215 Mdot
.55897 .1804 Mdot
.71241 .49703 Mdot
.34016 .41766 Mdot
.48846 .29458 Mdot
.47317 .37744 Mdot
.48597 .30036 Mdot
.67772 .50224 Mdot
.47749 .56837 Mdot
.65311 .54567 Mdot
.40147 .43293 Mdot
.38355 .63674 Mdot
.58836 .75905 Mdot
.22443 .49183 Mdot
.47784 .66588 Mdot
.69953 .46523 Mdot
.6305 .48138 Mdot
.64384 .49992 Mdot
.63592 .53904 Mdot
.2895 .53896 Mdot
.67493 .4625 Mdot
.34555 .45164 Mdot
.38995 .59547 Mdot
.69304 .49974 Mdot
.42946 .57558 Mdot
.30659 .29908 Mdot
.51229 .66274 Mdot
.48745 .44621 Mdot
.11928 .50054 Mdot
.47494 .31409 Mdot
.42595 .62806 Mdot
.40663 .59039 Mdot
.55008 .66274 Mdot
.36282 .45283 Mdot
.504 .3431 Mdot
.6774 .70376 Mdot
.56048 .67809 Mdot
.64249 .47989 Mdot
.48851 .60337 Mdot
.54127 .78811 Mdot
.69596 .48614 Mdot
.63284 .45154 Mdot
.43393 .60987 Mdot
.34543 .68001 Mdot
.33183 .78954 Mdot
.70043 .59771 Mdot
.51773 .68149 Mdot
.50712 .68007 Mdot
.46178 .36416 Mdot
.63532 .54845 Mdot
.39999 .43134 Mdot
.75298 .54092 Mdot
.44235 .42239 Mdot
.67651 .58833 Mdot
.5475 .41691 Mdot
.66661 .44865 Mdot
.63503 .21799 Mdot
.6284 .48521 Mdot
.52369 .36339 Mdot
.51281 .32589 Mdot
.47344 .32438 Mdot
.36297 .45894 Mdot
.62617 .34776 Mdot
.34751 .44823 Mdot
.12465 .51573 Mdot
.46331 .3176 Mdot
.27999 .58992 Mdot
.41576 .61521 Mdot
.59478 .52595 Mdot
.55342 .68825 Mdot
.41433 .41265 Mdot
.57727 .49502 Mdot
.75353 .68852 Mdot
.40564 .58179 Mdot
.47719 .31068 Mdot
.35479 .26298 Mdot
.15311 .51842 Mdot
.51159 .59189 Mdot
.6663 .41254 Mdot
.57389 .60808 Mdot
.53433 .69361 Mdot
.73582 .32616 Mdot
.54804 .70013 Mdot
.38986 .46348 Mdot
.65355 .51209 Mdot
.66018 .50282 Mdot
.68669 .46071 Mdot
.67822 .47323 Mdot
.38397 .41489 Mdot
.67159 .43815 Mdot
.6487 .80985 Mdot
.38079 .64415 Mdot
.55328 .30418 Mdot
.55111 .67867 Mdot
.39691 .41193 Mdot
.39068 .59367 Mdot
.36827 .53507 Mdot
.66519 .61351 Mdot
.63943 .51357 Mdot
.65769 .44812 Mdot
.53336 .77309 Mdot
.66646 .44431 Mdot
.70803 .43478 Mdot
.40756 .58904 Mdot
.47982 .67066 Mdot
.50459 .67846 Mdot
.51225 .69222 Mdot
.36627 .47504 Mdot
.52135 .34111 Mdot
.53709 .67243 Mdot
.4145 .62937 Mdot
.70057 .46563 Mdot
.60195 .46502 Mdot
.48535 .29565 Mdot
.37662 .77855 Mdot
.54519 .7079 Mdot
.33227 .27829 Mdot
.51482 .32113 Mdot
.53626 .35056 Mdot
.65633 .45697 Mdot
.55423 .51821 Mdot
.46943 .28319 Mdot
.51566 .65732 Mdot
.39185 .41154 Mdot
.53716 .60441 Mdot
.39932 .44386 Mdot
.50986 .32777 Mdot
.59298 .48247 Mdot
.50883 .32022 Mdot
.63126 .51601 Mdot
.1401 .42072 Mdot
.66232 .49431 Mdot
.59952 .80608 Mdot
.69389 .66446 Mdot
.39961 .60147 Mdot
.42526 .41054 Mdot
.41253 .60466 Mdot
.51301 .31856 Mdot
.59515 .47223 Mdot
.52243 .70757 Mdot
.36532 .22405 Mdot
.53783 .32706 Mdot
.38631 .58168 Mdot
.3569 .59952 Mdot
.38547 .47014 Mdot
.69903 .47893 Mdot
.66268 .45859 Mdot
.39308 .61338 Mdot
.69233 .55335 Mdot
.50588 .36612 Mdot
.64795 .51405 Mdot
.63109 .47356 Mdot
.40171 .60249 Mdot
.57692 .17916 Mdot
.48089 .40196 Mdot
.65439 .50374 Mdot
.2878 .63303 Mdot
.39984 .46578 Mdot
.67621 .5353 Mdot
.57995 .48388 Mdot
.53321 .68757 Mdot
.569 .37746 Mdot
.28179 .70672 Mdot
.3721 .48053 Mdot
.41662 .6006 Mdot
.62707 .5176 Mdot
.41829 .61007 Mdot
.60817 .45719 Mdot
.54587 .39405 Mdot
.39054 .57346 Mdot
.61697 .45682 Mdot
.65145 .55287 Mdot
.50131 .31093 Mdot
.66212 .44796 Mdot
.74101 .37663 Mdot
.42714 .58723 Mdot
.62332 .44837 Mdot
.56882 .23448 Mdot
.35886 .44522 Mdot
.64568 .5526 Mdot
.52477 .65944 Mdot
.67829 .7053 Mdot
.33541 .36139 Mdot
.24883 .61365 Mdot
.511 .66717 Mdot
.68563 .49378 Mdot
.35765 .61118 Mdot
.37807 .4223 Mdot
.62407 .79327 Mdot
.69058 .49765 Mdot
.39564 .43992 Mdot
.37419 .4632 Mdot
.53664 .6609 Mdot
.83631 .462 Mdot
.5928 .44774 Mdot
.66559 .46957 Mdot
.71318 .39054 Mdot
.5017 .29239 Mdot
.66593 .48522 Mdot
.61523 .52368 Mdot
.34476 .44773 Mdot
.70846 .43323 Mdot
.6945 .33411 Mdot
.68207 .72338 Mdot
.39646 .47248 Mdot
.53447 .57643 Mdot
.37821 .57324 Mdot
.54857 .6843 Mdot
.49056 .34157 Mdot
.55028 .70135 Mdot
.36506 .59892 Mdot
.63001 .53029 Mdot
.3396 .45362 Mdot
.77017 .41334 Mdot
.37123 .42169 Mdot
.25067 .62148 Mdot
.49942 .29315 Mdot
.3525 .31186 Mdot
.74297 .76418 Mdot
.28254 .37919 Mdot
.39232 .50986 Mdot
.5319 .69097 Mdot
.37054 .54607 Mdot
.63024 .47596 Mdot
.75275 .34473 Mdot
.66494 .51084 Mdot
.57357 .23966 Mdot
.40591 .64481 Mdot
.36586 .62398 Mdot
.65383 .50838 Mdot
.63849 .7096 Mdot
.38042 .42113 Mdot
.40382 .44823 Mdot
.63285 .44518 Mdot
.37521 .44615 Mdot
.65706 .47356 Mdot
.38945 .5881 Mdot
.81918 .60197 Mdot
.63686 .48836 Mdot
.59466 .51177 Mdot
.33264 .40296 Mdot
.46198 .18544 Mdot
.30153 .68682 Mdot
.69638 .25167 Mdot
.15979 .54684 Mdot
.37592 .44692 Mdot
.6545 .54708 Mdot
.53734 .57764 Mdot
.42672 .5702 Mdot
.40973 .48642 Mdot
.66843 .49643 Mdot
.67076 .49827 Mdot
.66689 .51831 Mdot
.62336 .46602 Mdot
.73435 .31846 Mdot
.75904 .4713 Mdot
.58248 .28477 Mdot
.64861 .44508 Mdot
.59765 .61794 Mdot
.36285 .47675 Mdot
.44726 .35689 Mdot
.56719 .65934 Mdot
.66669 .44889 Mdot
.75341 .4907 Mdot
.41194 .44256 Mdot
.12475 .51736 Mdot
.37663 .4744 Mdot
.38574 .62764 Mdot
.38678 .41673 Mdot
.6245 .50222 Mdot
.4914 .33155 Mdot
.51733 .5566 Mdot
.3025 .49388 Mdot
.40464 .58702 Mdot
.63142 .50912 Mdot
.27345 .58321 Mdot
.4006 .58038 Mdot
.30239 .30353 Mdot
.48776 .33621 Mdot
.62474 .66311 Mdot
.51229 .32373 Mdot
.61505 .45766 Mdot
.61216 .46248 Mdot
.36765 .406 Mdot
.36688 .42003 Mdot
.51383 .32575 Mdot
.84517 .47598 Mdot
.56042 .69152 Mdot
.47754 .32022 Mdot
.66123 .42325 Mdot
.44825 .49629 Mdot
.48479 .33084 Mdot
.48229 .65313 Mdot
.36214 .46547 Mdot
.45529 .33987 Mdot
.62088 .42319 Mdot
.38297 .7666 Mdot
.53392 .65354 Mdot
.40674 .6617 Mdot
.48693 .61817 Mdot
.42888 .5954 Mdot
.36944 .41361 Mdot
.41051 .60202 Mdot
.36229 .42835 Mdot
.3565 .3674 Mdot
.72399 .55607 Mdot
.32675 .4669 Mdot
.3728 .41407 Mdot
.4082 .60264 Mdot
.64825 .51846 Mdot
.50216 .6178 Mdot
.6623 .54393 Mdot
.5957 .44044 Mdot
.36603 .43039 Mdot
.47384 .30917 Mdot
.47933 .37668 Mdot
.59721 .63266 Mdot
.50458 .37331 Mdot
.38267 .59064 Mdot
.67973 .77941 Mdot
.24789 .59024 Mdot
.3823 .43027 Mdot
.39823 .41653 Mdot
.6127 .47402 Mdot
.40018 .62204 Mdot
.4212 .61432 Mdot
.39306 .46263 Mdot
.64325 .57717 Mdot
.61164 .53523 Mdot
.49211 .38501 Mdot
.45836 .32779 Mdot
.48857 .32323 Mdot
.48993 .30125 Mdot
.68476 .30233 Mdot
.36452 .46919 Mdot
.4809 .30612 Mdot
.62235 .45227 Mdot
.67034 .4965 Mdot
.5255 .58751 Mdot
.50923 .6853 Mdot
.6864 .51448 Mdot
.70703 .50176 Mdot
.65591 .45428 Mdot
.37158 .59033 Mdot
.56311 .4805 Mdot
.39346 .5727 Mdot
.37156 .64 Mdot
.39376 .64994 Mdot
.253 .53247 Mdot
.593 .68621 Mdot
.18245 .57991 Mdot
.6097 .51106 Mdot
.46466 .24198 Mdot
.40911 .62344 Mdot
.74909 .70202 Mdot
.4203 .28955 Mdot
.68388 .50688 Mdot
.44158 .76048 Mdot
.395 .61222 Mdot
.49995 .37472 Mdot
.66661 .49559 Mdot
.38102 .65179 Mdot
.53075 .65624 Mdot
.70565 .46064 Mdot
.42319 .57397 Mdot
.51788 .34605 Mdot
.54938 .64881 Mdot
.45771 .32483 Mdot
.39673 .64931 Mdot
.64892 .55274 Mdot
.39454 .86351 Mdot
.35683 .58747 Mdot
.47722 .21012 Mdot
.43936 .37086 Mdot
.64855 .51563 Mdot
.42934 .61805 Mdot
.51504 .30391 Mdot
.35064 .42025 Mdot
.45026 .43748 Mdot
.47256 .36159 Mdot
.36468 .62115 Mdot
.4275 .58092 Mdot
.40689 .58802 Mdot
.4914 .35584 Mdot
.59764 .51251 Mdot
.48919 .36182 Mdot
.38907 .41677 Mdot
.61601 .48329 Mdot
.15806 .48202 Mdot
.46594 .24409 Mdot
.51463 .32322 Mdot
.37707 .62221 Mdot
.55558 .65866 Mdot
.6302 .49309 Mdot
.50954 .21639 Mdot
.63997 .52207 Mdot
.378 .42595 Mdot
.7874 .62378 Mdot
.76881 .39977 Mdot
.68995 .45867 Mdot
.61327 .47326 Mdot
.40469 .43897 Mdot
.63494 .50364 Mdot
.69356 .46574 Mdot
.25677 .5211 Mdot
.49997 .35709 Mdot
.63772 .47766 Mdot
.39578 .64242 Mdot
.2392 .52632 Mdot
.62048 .53786 Mdot
.4843 .71313 Mdot
.63361 .67881 Mdot
.80088 .57381 Mdot
.66358 .51325 Mdot
.69123 .59225 Mdot
.63016 .46078 Mdot
.68438 .48422 Mdot
.6047 .48915 Mdot
.74915 .31889 Mdot
.38606 .57637 Mdot
.40064 .59119 Mdot
.52817 .65343 Mdot
.63124 .67743 Mdot
.53239 .68355 Mdot
.35934 .46589 Mdot
.45119 .69528 Mdot
.39119 .57363 Mdot
.51908 .342 Mdot
.68764 .48185 Mdot
.35624 .58799 Mdot
.66477 .45676 Mdot
.6236 .50375 Mdot
.41805 .58447 Mdot
.38595 .56873 Mdot
.25439 .61062 Mdot
.51741 .66064 Mdot
.47014 .33098 Mdot
.68609 .51962 Mdot
.55645 .69139 Mdot
.59037 .49318 Mdot
.70402 .63385 Mdot
.4724 .3295 Mdot
.49712 .35909 Mdot
.48252 .37554 Mdot
.62998 .53002 Mdot
.62779 .50066 Mdot
.34827 .44528 Mdot
.52126 .33357 Mdot
.36111 .44481 Mdot
.50256 .49871 Mdot
.51214 .73889 Mdot
.66852 .4965 Mdot
.34296 .27588 Mdot
.54521 .69029 Mdot
.3779 .60901 Mdot
.55677 .77137 Mdot
.53047 .65273 Mdot
.63477 .51704 Mdot
.421 .60537 Mdot
.51698 .69255 Mdot
.55981 .43664 Mdot
.20459 .65092 Mdot
.56117 .65894 Mdot
.62521 .45019 Mdot
.71287 .43157 Mdot
.71409 .25872 Mdot
.53562 .65023 Mdot
.34202 .43801 Mdot
.6321 .53014 Mdot
.49396 .27737 Mdot
.54252 .70775 Mdot
.26875 .43636 Mdot
.39146 .60245 Mdot
.3258 .73543 Mdot
.57132 .48212 Mdot
.77981 .39765 Mdot
.53696 .70238 Mdot
.50441 .3398 Mdot
.44629 .36883 Mdot
.6473 .45664 Mdot
.53686 .65023 Mdot
.40179 .46791 Mdot
.38555 .60346 Mdot
.25823 .49317 Mdot
.48906 .35662 Mdot
.33437 .30338 Mdot
.37249 .61654 Mdot
.32572 .28894 Mdot
.73257 .68677 Mdot
.61816 .55312 Mdot
.70709 .26077 Mdot
.31701 .60303 Mdot
.64262 .53445 Mdot
.56527 .68255 Mdot
.37532 .47963 Mdot
.33863 .44075 Mdot
.38279 .44051 Mdot
.37709 .36484 Mdot
.52441 .59735 Mdot
.42327 .6367 Mdot
.34257 .51028 Mdot
.54718 .68223 Mdot
.60645 .6086 Mdot
.60225 .45739 Mdot
.63174 .48259 Mdot
.69992 .4784 Mdot
.67633 .45433 Mdot
.63652 .46158 Mdot
.36684 .44791 Mdot
.34145 .37755 Mdot
.5394 .59398 Mdot
.47778 .33001 Mdot
.41539 .6797 Mdot
.41506 .61627 Mdot
.41957 .64368 Mdot
.51227 .68154 Mdot
.32305 .27772 Mdot
.42877 .57539 Mdot
.39673 .63689 Mdot
.66113 .52867 Mdot
.49893 .36512 Mdot
.64198 .41429 Mdot
.6154 .46321 Mdot
.38145 .59781 Mdot
.52572 .51144 Mdot
.71564 .34301 Mdot
.56082 .46687 Mdot
.50199 .70838 Mdot
.47768 .56046 Mdot
.55059 .65416 Mdot
.59318 .46922 Mdot
.75666 .6919 Mdot
.36589 .59477 Mdot
.39209 .62685 Mdot
.53881 .70023 Mdot
.5526 .3553 Mdot
.48508 .34782 Mdot
.36007 .53619 Mdot
.34726 .43511 Mdot
.60182 .47668 Mdot
.6093 .77438 Mdot
.53491 .28726 Mdot
.42241 .68905 Mdot
.38512 .43747 Mdot
.41864 .62006 Mdot
.69694 .46423 Mdot
.62606 .45056 Mdot
.5427 .69547 Mdot
.19785 .45192 Mdot
.7083 .4804 Mdot
.31559 .25575 Mdot
.50784 .80328 Mdot
.38339 .77568 Mdot
.65822 .45754 Mdot
.49824 .35646 Mdot
.42657 .57626 Mdot
.54967 .69512 Mdot
.64465 .42562 Mdot
.19705 .6255 Mdot
.47032 .30434 Mdot
.38569 .46468 Mdot
.52157 .54504 Mdot
.52066 .60702 Mdot
.64812 .53016 Mdot
.66427 .50987 Mdot
.67984 .49414 Mdot
.2495 .70476 Mdot
.37652 .58773 Mdot
.52396 .34917 Mdot
.52627 .66329 Mdot
.51191 .37099 Mdot
.40243 .59616 Mdot
.33773 .31088 Mdot
.646 .5222 Mdot
.47193 .30229 Mdot
.50217 .33993 Mdot
.38111 .47215 Mdot
.34199 .42615 Mdot
.5105 .52081 Mdot
.66198 .49215 Mdot
.36128 .57858 Mdot
.49061 .30676 Mdot
.49185 .6038 Mdot
.52338 .68346 Mdot
.35147 .46167 Mdot
.65327 .44592 Mdot
.37588 .58165 Mdot
.6705 .43731 Mdot
.47609 .34351 Mdot
.39807 .63653 Mdot
.25781 .60432 Mdot
.50753 .67393 Mdot
.67435 .48283 Mdot
.52401 .64734 Mdot
.41704 .60043 Mdot
.62903 .47443 Mdot
.38202 .23902 Mdot
.51181 .72006 Mdot
.29059 .48488 Mdot
.40819 .64649 Mdot
.26053 .59427 Mdot
.4709 .36714 Mdot
.4017 .354 Mdot
.38861 .62625 Mdot
.34593 .26433 Mdot
.20446 .48128 Mdot
.70288 .48153 Mdot
.4985 .3204 Mdot
.34115 .57511 Mdot
.16521 .41744 Mdot
.57439 .18539 Mdot
.64204 .49879 Mdot
.41936 .63835 Mdot
.5362 .69878 Mdot
.38051 .42946 Mdot
.48978 .7196 Mdot
.50272 .71187 Mdot
.36325 .58238 Mdot
.60383 .48945 Mdot
.51168 .33929 Mdot
.36581 .46229 Mdot
.33937 .36399 Mdot
.40868 .63725 Mdot
.37738 .62964 Mdot
.69571 .46297 Mdot
.53659 .67978 Mdot
.54048 .20842 Mdot
.39218 .58643 Mdot
.5302 .77949 Mdot
.39927 .55923 Mdot
.55873 .69161 Mdot
.63086 .45587 Mdot
.5907 .63443 Mdot
.65232 .54177 Mdot
.43895 .20556 Mdot
.41189 .60879 Mdot
.47365 .33837 Mdot
.67343 .50898 Mdot
.70344 .70319 Mdot
.38067 .60217 Mdot
.4811 .57157 Mdot
.3756 .71807 Mdot
.36329 .46751 Mdot
.55673 .77278 Mdot
.6678 .47829 Mdot
.37881 .42149 Mdot
.5439 .69044 Mdot
.65654 .49789 Mdot
.62598 .49859 Mdot
.52791 .3412 Mdot
.39349 .46035 Mdot
.19995 .51823 Mdot
.41153 .43516 Mdot
.35178 .47043 Mdot
.52771 .36412 Mdot
.64776 .46911 Mdot
.38469 .62801 Mdot
.39526 .61441 Mdot
.61542 .43106 Mdot
.7806 .68181 Mdot
.48388 .35065 Mdot
.36459 .66182 Mdot
.26994 .72548 Mdot
.63364 .55855 Mdot
.56794 .77381 Mdot
.20404 .44007 Mdot
.38689 .48091 Mdot
.64018 .44422 Mdot
.5166 .34111 Mdot
.3751 .53555 Mdot
.37809 .62859 Mdot
.59474 .50398 Mdot
.37135 .45959 Mdot
.53089 .65539 Mdot
.418 .577 Mdot
.42574 .68507 Mdot
.68144 .4808 Mdot
.43889 .76294 Mdot
.42652 .61876 Mdot
.25546 .28029 Mdot
.35303 .55157 Mdot
.49331 .31855 Mdot
.62149 .50129 Mdot
.48209 .3718 Mdot
.52086 .66647 Mdot
.51898 .54235 Mdot
.37142 .46193 Mdot
.73959 .44489 Mdot
.59681 .8433 Mdot
.40937 .58987 Mdot
.52237 .35991 Mdot
.68855 .45642 Mdot
.53615 .46443 Mdot
.66383 .47369 Mdot
.73343 .46304 Mdot
.5366 .73098 Mdot
.36382 .43369 Mdot
.36732 .42471 Mdot
.6242 .47744 Mdot
.55818 .67573 Mdot
.41573 .62442 Mdot
.38361 .60634 Mdot
.38668 .17211 Mdot
.30552 .44552 Mdot
.64846 .7183 Mdot
.67274 .49449 Mdot
.35932 .60298 Mdot
.22814 .49973 Mdot
.39181 .43577 Mdot
.60738 .4497 Mdot
.41127 .58132 Mdot
.40564 .76929 Mdot
.71353 .67867 Mdot
.63778 .45832 Mdot
.57897 .46648 Mdot
.34521 .43655 Mdot
.62223 .60315 Mdot
.3891 .6464 Mdot
.68984 .52955 Mdot
.33029 .46409 Mdot
.77469 .62568 Mdot
.33894 .76791 Mdot
.4701 .33038 Mdot
.35505 .69344 Mdot
.36599 .44854 Mdot
.58222 .44741 Mdot
.54984 .6718 Mdot
.4111 .568 Mdot
.37835 .58308 Mdot
.60813 .50349 Mdot
.6742 .43999 Mdot
.58216 .74513 Mdot
.51123 .36863 Mdot
.36262 .47594 Mdot
.65775 .51581 Mdot
.38415 .27807 Mdot
.68486 .45871 Mdot
.35046 .44521 Mdot
.38139 .86532 Mdot
.69229 .51209 Mdot
.66332 .47067 Mdot
.54073 .20614 Mdot
.47096 .35966 Mdot
.51977 .3681 Mdot
.55408 .81247 Mdot
.67303 .49354 Mdot
.54532 .77464 Mdot
.46816 .33488 Mdot
.4816 .34858 Mdot
.26877 .50825 Mdot
.63169 .48983 Mdot
.77585 .49321 Mdot
.38397 .42451 Mdot
.34746 .46545 Mdot
.48753 .36021 Mdot
.70022 .5007 Mdot
.35214 .47881 Mdot
.68725 .27264 Mdot
.40165 .62154 Mdot
.77298 .67308 Mdot
.47448 .35414 Mdot
.50513 .44096 Mdot
.38732 .43547 Mdot
.12431 .51321 Mdot
.42965 .56537 Mdot
.65009 .51814 Mdot
.67629 .48618 Mdot
.54717 .68837 Mdot
.69168 .51139 Mdot
.3683 .629 Mdot
.37495 .44576 Mdot
.53732 .248 Mdot
.47381 .32339 Mdot
.66036 .4837 Mdot
.31538 .28971 Mdot
.25833 .4165 Mdot
.30884 .67686 Mdot
.49293 .34678 Mdot
.4968 .31594 Mdot
.38698 .64423 Mdot
.42115 .63534 Mdot
.64695 .46273 Mdot
.40317 .44252 Mdot
.52023 .33128 Mdot
.35473 .43756 Mdot
.36609 .59532 Mdot
.38619 .63181 Mdot
.38553 .57419 Mdot
.7149 .46435 Mdot
.39845 .63951 Mdot
.46194 .6688 Mdot
.32625 .31165 Mdot
.51511 .37937 Mdot
.43582 .81908 Mdot
.34882 .36033 Mdot
.43168 .38932 Mdot
.53144 .71032 Mdot
.41732 .59981 Mdot
.40085 .42007 Mdot
.61886 .47164 Mdot
.66192 .452 Mdot
.43853 .6511 Mdot
.39423 .42035 Mdot
.51789 .67229 Mdot
.38117 .41969 Mdot
.53718 .66074 Mdot
.39721 .74466 Mdot
.69826 .48661 Mdot
.60406 .46411 Mdot
.37073 .44394 Mdot
.39991 .63782 Mdot
.39438 .59466 Mdot
.55653 .65419 Mdot
.53283 .41264 Mdot
.40184 .58014 Mdot
.47418 .35113 Mdot
.67087 .28538 Mdot
.42851 .58195 Mdot
.66683 .49149 Mdot
.7146 .61075 Mdot
.76932 .37392 Mdot
.63456 .53897 Mdot
.26363 .51173 Mdot
.80224 .45116 Mdot
.68279 .50302 Mdot
.81029 .42777 Mdot
.26264 .58913 Mdot
.47873 .36833 Mdot
.4022 .64585 Mdot
.43389 .6187 Mdot
.7264 .49182 Mdot
.57082 .67588 Mdot
.63354 .42596 Mdot
.46727 .3527 Mdot
.4545 .31393 Mdot
.42464 .78754 Mdot
.47124 .20856 Mdot
.52982 .6989 Mdot
.51314 .68943 Mdot
.38714 .62283 Mdot
.5501 .16015 Mdot
.57613 .44275 Mdot
.5171 .67881 Mdot
.69808 .57234 Mdot
.6024 .49145 Mdot
.66988 .67672 Mdot
.50922 .7764 Mdot
.49314 .35755 Mdot
.58558 .62172 Mdot
.38181 .61871 Mdot
.5006 .37212 Mdot
.39255 .28389 Mdot
.67624 .52572 Mdot
.47311 .32769 Mdot
.35233 .43843 Mdot
.32617 .56334 Mdot
.46287 .33783 Mdot
.71168 .61898 Mdot
.39637 .4593 Mdot
.4908 .59835 Mdot
.60983 .64428 Mdot
.88614 .57599 Mdot
.36958 .44881 Mdot
.40526 .57161 Mdot
.3944 .61378 Mdot
.38369 .60837 Mdot
.50746 .37134 Mdot
.42083 .61222 Mdot
.51686 .36492 Mdot
.64702 .2079 Mdot
.54903 .40871 Mdot
.5175 .68434 Mdot
.26376 .49124 Mdot
.50547 .32964 Mdot
.71469 .75189 Mdot
.68586 .80465 Mdot
.64352 .44332 Mdot
.40761 .42227 Mdot
.52018 .69235 Mdot
.34019 .22719 Mdot
.53649 .68885 Mdot
.575 .64798 Mdot
.7877 .63369 Mdot
.65583 .47874 Mdot
.66786 .35081 Mdot
.51517 .70028 Mdot
.5032 .34683 Mdot
.62879 .4771 Mdot
.4036 .50561 Mdot
.53838 .68561 Mdot
.53888 .65764 Mdot
.64002 .46808 Mdot
.47772 .31034 Mdot
.37928 .62042 Mdot
.35966 .42054 Mdot
.49939 .67862 Mdot
.47489 .39077 Mdot
.65417 .53525 Mdot
.62839 .52155 Mdot
.50582 .5784 Mdot
.5097 .63726 Mdot
.37576 .44765 Mdot
.78477 .36983 Mdot
.41521 .64062 Mdot
.33477 .60075 Mdot
.5083 .79565 Mdot
.25942 .53004 Mdot
.40997 .60845 Mdot
.41522 .60196 Mdot
.64032 .46037 Mdot
.49799 .6438 Mdot
.79887 .59825 Mdot
.40582 .48243 Mdot
.42834 .57865 Mdot
.38418 .60286 Mdot
.44741 .32889 Mdot
.43747 .79362 Mdot
.65018 .42587 Mdot
.36672 .48147 Mdot
.37864 .58057 Mdot
.5435 .39028 Mdot
.54008 .67837 Mdot
.72591 .72983 Mdot
.69707 .49006 Mdot
.65353 .51598 Mdot
.38348 .45315 Mdot
.34708 .45006 Mdot
.38701 .52608 Mdot
.49033 .798 Mdot
.79559 .43514 Mdot
.31892 .38005 Mdot
.59133 .39098 Mdot
.44875 .3312 Mdot
.51424 .32266 Mdot
.27671 .43902 Mdot
.41212 .43746 Mdot
.67899 .50567 Mdot
.51969 .33632 Mdot
.3054 .62221 Mdot
.47703 .2495 Mdot
.65693 .69734 Mdot
.58072 .76512 Mdot
.63159 .51471 Mdot
.50534 .35994 Mdot
.47232 .35943 Mdot
.51206 .30961 Mdot
.26437 .58468 Mdot
.6558 .46357 Mdot
.63931 .50986 Mdot
.69042 .48565 Mdot
.62534 .56864 Mdot
.67777 .4673 Mdot
.39768 .3671 Mdot
.49419 .52526 Mdot
.56799 .33181 Mdot
.69727 .52156 Mdot
.36839 .48634 Mdot
.64549 .53053 Mdot
.55735 .67278 Mdot
.60662 .4832 Mdot
.66047 .69901 Mdot
.39464 .44923 Mdot
.4585 .39748 Mdot
.35722 .3638 Mdot
.66286 .52425 Mdot
.50839 .66375 Mdot
.44798 .41269 Mdot
.17366 .51144 Mdot
.56981 .65745 Mdot
.47458 .35191 Mdot
.40607 .6178 Mdot
.40037 .4212 Mdot
.39131 .63291 Mdot
.7133 .46335 Mdot
.28019 .44239 Mdot
.25752 .37573 Mdot
.50837 .48402 Mdot
.67212 .45238 Mdot
.5717 .50453 Mdot
.47722 .34824 Mdot
.42116 .60447 Mdot
.52821 .28773 Mdot
.67499 .505 Mdot
.53127 .66409 Mdot
.54294 .68593 Mdot
.41768 .48736 Mdot
.22627 .35382 Mdot
.416 .34711 Mdot
.38229 .45096 Mdot
.39035 .58463 Mdot
.54759 .70127 Mdot
.42184 .23749 Mdot
.3462 .42189 Mdot
.40503 .43823 Mdot
.38442 .46763 Mdot
.60869 .51517 Mdot
.39252 .57258 Mdot
.56677 .31974 Mdot
.36062 .60763 Mdot
.63269 .50566 Mdot
.37247 .59286 Mdot
.40864 .58195 Mdot
.5517 .68204 Mdot
.3707 .47585 Mdot
.36617 .61375 Mdot
.6145 .45753 Mdot
.46915 .32181 Mdot
.50195 .42382 Mdot
.70865 .66458 Mdot
.45118 .21592 Mdot
.50896 .24746 Mdot
.45838 .33537 Mdot
.16712 .42922 Mdot
.39958 .4669 Mdot
.63355 .57605 Mdot
.27747 .63214 Mdot
.59327 .48806 Mdot
.73385 .74463 Mdot
.42463 .63478 Mdot
.41492 .57944 Mdot
.62884 .45786 Mdot
.32556 .63914 Mdot
.6608 .4797 Mdot
.36756 .60781 Mdot
.39969 .67865 Mdot
.6738 .55182 Mdot
.40822 .63268 Mdot
.69513 .52602 Mdot
.62598 .48973 Mdot
.49448 .35864 Mdot
.42957 .61579 Mdot
.6091 .4476 Mdot
.34463 .20498 Mdot
.34954 .45312 Mdot
.27187 .57472 Mdot
.73837 .59116 Mdot
.36454 .44879 Mdot
.47983 .32041 Mdot
.60026 .43825 Mdot
.54327 .69324 Mdot
.50851 .33116 Mdot
.71825 .67978 Mdot
.51121 .693 Mdot
.71683 .75572 Mdot
.47859 .35944 Mdot
.42935 .58586 Mdot
.55127 .67083 Mdot
.65449 .54638 Mdot
.41004 .5682 Mdot
.43823 .43376 Mdot
.41105 .6108 Mdot
.66377 .45926 Mdot
.25836 .47914 Mdot
.35768 .4739 Mdot
.64423 .49735 Mdot
.42105 .58293 Mdot
.25484 .51898 Mdot
.60891 .5143 Mdot
.6259 .46806 Mdot
.38419 .78209 Mdot
.66741 .77132 Mdot
.52874 .68932 Mdot
.51919 .31158 Mdot
.62182 .45266 Mdot
.53199 .6573 Mdot
.4398 .73738 Mdot
.63554 .52886 Mdot
.47768 .29896 Mdot
.55802 .50948 Mdot
.42741 .60936 Mdot
.35781 .45029 Mdot
.50516 .47777 Mdot
.53016 .65649 Mdot
.82631 .3541 Mdot
.3638 .59095 Mdot
.59519 .4639 Mdot
.66873 .44831 Mdot
.30575 .69497 Mdot
.48123 .36849 Mdot
.78926 .46924 Mdot
.67454 .48303 Mdot
.63723 .57022 Mdot
.6552 .49467 Mdot
.38476 .66469 Mdot
.48393 .3486 Mdot
.66546 .46772 Mdot
.33934 .28658 Mdot
.6016 .52412 Mdot
.52044 .65778 Mdot
.56162 .19995 Mdot
.64688 .53602 Mdot
.50002 .88255 Mdot
.53239 .76546 Mdot
.40792 .63424 Mdot
.26867 .44785 Mdot
.51818 .126 Mdot
.37695 .36115 Mdot
.51999 .36111 Mdot
.22164 .41473 Mdot
.38457 .62848 Mdot
.24966 .46287 Mdot
.16327 .43074 Mdot
.6229 .48906 Mdot
.64831 .53016 Mdot
.57792 .65673 Mdot
.38132 .64707 Mdot
.37325 .56954 Mdot
.71417 .48503 Mdot
.5985 .42741 Mdot
.386 .63526 Mdot
.61803 .45128 Mdot
.71891 .47905 Mdot
.37315 .41697 Mdot
.4601 .3299 Mdot
.37423 .42911 Mdot
.38598 .47121 Mdot
.64336 .23131 Mdot
.46848 .7886 Mdot
.351 .44871 Mdot
.38439 .47809 Mdot
.67277 .67872 Mdot
.60271 .71846 Mdot
.54078 .70831 Mdot
.26001 .29329 Mdot
.38583 .60786 Mdot
.65393 .46644 Mdot
.46003 .34783 Mdot
.7813 .41641 Mdot
.48797 .73502 Mdot
.80353 .60207 Mdot
.67739 .50503 Mdot
.38017 .60898 Mdot
.2638 .58396 Mdot
.66998 .41853 Mdot
.36822 .55745 Mdot
.65729 .51865 Mdot
.37223 .57287 Mdot
.66276 .30777 Mdot
.33815 .27252 Mdot
.383 .56402 Mdot
.49664 .38667 Mdot
.65738 .51046 Mdot
.47381 .35548 Mdot
.38125 .43425 Mdot
.55585 .68198 Mdot
.52653 .68573 Mdot
.63229 .47185 Mdot
.60798 .55217 Mdot
.41338 .75321 Mdot
.62929 .49338 Mdot
.60648 .49102 Mdot
.26251 .58927 Mdot
.60845 .48749 Mdot
.67895 .45836 Mdot
.68624 .46778 Mdot
.58433 .48147 Mdot
.34998 .46817 Mdot
.31812 .28858 Mdot
.69434 .43593 Mdot
.70471 .43954 Mdot
.33633 .44109 Mdot
.19151 .48227 Mdot
.39623 .46503 Mdot
.15676 .48634 Mdot
.37455 .42577 Mdot
.52097 .67859 Mdot
.24726 .63314 Mdot
.58648 .53068 Mdot
.48711 .30387 Mdot
.37996 .41084 Mdot
.52931 .66146 Mdot
.37907 .44245 Mdot
.37028 .6097 Mdot
.28817 .7292 Mdot
.52504 .38411 Mdot
.74197 .5545 Mdot
.42804 .43398 Mdot
.29865 .47589 Mdot
.36465 .61349 Mdot
.4839 .35446 Mdot
.71481 .35023 Mdot
.68177 .45795 Mdot
.53415 .65807 Mdot
.64267 .46386 Mdot
.35814 .4771 Mdot
.38236 .61602 Mdot
.55978 .19195 Mdot
.54315 .69488 Mdot
.43674 .81361 Mdot
.39355 .60072 Mdot
.69172 .47361 Mdot
.36435 .48113 Mdot
.49057 .82935 Mdot
.36878 .43062 Mdot
.74537 .43175 Mdot
.45304 .35855 Mdot
.6939 .24618 Mdot
.50205 .325 Mdot
.36287 .53841 Mdot
.33406 .79849 Mdot
.34197 .24567 Mdot
.4756 .31255 Mdot
.31947 .48538 Mdot
.62855 .51716 Mdot
.63056 .52231 Mdot
.43507 .23151 Mdot
.51714 .30956 Mdot
.65075 .44369 Mdot
.26118 .60016 Mdot
.31376 .33589 Mdot
.58568 .78247 Mdot
.41612 .60923 Mdot
.66527 .48053 Mdot
.33071 .45567 Mdot
.38601 .42093 Mdot
.36157 .59377 Mdot
.40369 .45469 Mdot
.6388 .50737 Mdot
.50431 .32861 Mdot
.3499 .60345 Mdot
.52849 .67357 Mdot
.41494 .18927 Mdot
.56232 .69058 Mdot
.40951 .60789 Mdot
.64202 .55157 Mdot
.38702 .63278 Mdot
.54824 .1109 Mdot
.64344 .51116 Mdot
.4691 .33736 Mdot
.615 .46816 Mdot
.65591 .50729 Mdot
.6489 .53076 Mdot
.37579 .62134 Mdot
.78227 .50033 Mdot
.61585 .45456 Mdot
.37044 .46288 Mdot
.57116 .36532 Mdot
.65586 .53238 Mdot
.3795 .66873 Mdot
.62466 .70434 Mdot
.35951 .52032 Mdot
.45861 .35305 Mdot
.41313 .62341 Mdot
.47482 .31931 Mdot
.52747 .28237 Mdot
.47968 .32075 Mdot
.6008 .36967 Mdot
.70299 .33953 Mdot
.78829 .50921 Mdot
.56291 .23513 Mdot
.55849 .55966 Mdot
.5184 .31081 Mdot
.57984 .70588 Mdot
.5152 .32058 Mdot
.47552 .36161 Mdot
.19374 .73792 Mdot
.49766 .30645 Mdot
.66982 .48903 Mdot
.67776 .52013 Mdot
.28437 .38419 Mdot
.66753 .64909 Mdot
.61606 .47822 Mdot
.62117 .45726 Mdot
.55382 .68422 Mdot
.66946 .56463 Mdot
.276 .44887 Mdot
.65425 .79028 Mdot
.25109 .4329 Mdot
.64032 .46603 Mdot
.61864 .45559 Mdot
.6246 .41704 Mdot
.49946 .85344 Mdot
.69701 .26818 Mdot
.48291 .28938 Mdot
.57973 .44837 Mdot
.4053 .21097 Mdot
.65994 .52301 Mdot
.61765 .52576 Mdot
.63123 .51589 Mdot
.38421 .62763 Mdot
.4616 .31178 Mdot
.5982 .43398 Mdot
.50563 .78483 Mdot
.65246 .52586 Mdot
.25914 .52546 Mdot
.64399 .18602 Mdot
.66834 .4779 Mdot
.45718 .31966 Mdot
.61798 .51603 Mdot
.48482 .36587 Mdot
.50557 .35115 Mdot
.61258 .53873 Mdot
.586 .38882 Mdot
.45224 .32524 Mdot
.63201 .50568 Mdot
.37533 .61197 Mdot
.24454 .30348 Mdot
.66573 .45993 Mdot
.55496 .69248 Mdot
.67544 .48705 Mdot
.50581 .66501 Mdot
.60982 .49188 Mdot
.36488 .58736 Mdot
.76807 .38959 Mdot
.39059 .62478 Mdot
.73049 .27216 Mdot
.38402 .57191 Mdot
.39419 .7884 Mdot
.48542 .29344 Mdot
.25969 .48644 Mdot
.82554 .51634 Mdot
.26739 .55628 Mdot
.467 .56141 Mdot
.47222 .52405 Mdot
.40334 .44296 Mdot
.47898 .37078 Mdot
.62699 .58842 Mdot
.30529 .65724 Mdot
.29624 .6612 Mdot
.40236 .57709 Mdot
.8424 .47774 Mdot
.80951 .61346 Mdot
.60441 .4696 Mdot
.65035 .35779 Mdot
.59443 .30021 Mdot
.63978 .53267 Mdot
.59131 .44256 Mdot
.42765 .65966 Mdot
.65064 .44071 Mdot
.37992 .27624 Mdot
.4068 .60442 Mdot
.5311 .66072 Mdot
.47179 .34541 Mdot
.53473 .65439 Mdot
.30219 .65609 Mdot
.46958 .52577 Mdot
.36678 .6015 Mdot
.58774 .49732 Mdot
.61942 .46367 Mdot
.49263 .3629 Mdot
.5262 .29983 Mdot
.50296 .31215 Mdot
.52904 .69733 Mdot
.40259 .60555 Mdot
.75304 .34052 Mdot
.63016 .4512 Mdot
.50058 .33893 Mdot
.4498 .54756 Mdot
.62703 .44918 Mdot
.37133 .43965 Mdot
.63733 .51889 Mdot
.46904 .3186 Mdot
.60862 .4875 Mdot
.50457 .32543 Mdot
.40477 .62069 Mdot
.68175 .51155 Mdot
.63357 .45685 Mdot
.46807 .82647 Mdot
.51956 .67156 Mdot
.49928 .29348 Mdot
.33315 .66235 Mdot
.67632 .44891 Mdot
.28633 .51179 Mdot
.6612 .51128 Mdot
.47026 .25388 Mdot
.58957 .47953 Mdot
.2607 .56174 Mdot
.66501 .42937 Mdot
.66577 .46101 Mdot
.42059 .50666 Mdot
.59838 .32458 Mdot
.52328 .30666 Mdot
.363 .48247 Mdot
.49358 .30125 Mdot
.59402 .77169 Mdot
.42013 .56251 Mdot
.42294 .60697 Mdot
.64521 .61174 Mdot
.58264 .47526 Mdot
.65551 .47682 Mdot
.33268 .44126 Mdot
.50944 .6807 Mdot
.49496 .3464 Mdot
.53659 .66087 Mdot
.51992 .80016 Mdot
.5196 .69909 Mdot
.4173 .64929 Mdot
.43718 .76083 Mdot
.72603 .31178 Mdot
.55343 .68435 Mdot
.47749 .30992 Mdot
.51888 .74014 Mdot
.59819 .5093 Mdot
.55748 .74345 Mdot
.53462 .66531 Mdot
.84744 .44243 Mdot
.67747 .45786 Mdot
.47008 .5688 Mdot
.35508 .44502 Mdot
.55109 .67407 Mdot
.39971 .44608 Mdot
.61982 .47516 Mdot
.28831 .47911 Mdot
.52206 .34845 Mdot
.34396 .46988 Mdot
.68754 .52504 Mdot
.51799 .69051 Mdot
.38239 .57965 Mdot
.38003 .40629 Mdot
.35527 .48061 Mdot
.1963 .44825 Mdot
.59844 .19138 Mdot
.40073 .6062 Mdot
.70929 .71213 Mdot
.38071 .42409 Mdot
.63572 .53441 Mdot
.68898 .56261 Mdot
.65025 .51863 Mdot
.40825 .36456 Mdot
.41524 .61947 Mdot
.28994 .35436 Mdot
.61406 .46687 Mdot
.6864 .48978 Mdot
.5176 .30188 Mdot
.39183 .61732 Mdot
.48958 .33018 Mdot
.50092 .30423 Mdot
.40331 .62057 Mdot
.495 .32029 Mdot
.51024 .69358 Mdot
.32405 .33713 Mdot
.35346 .42833 Mdot
.3744 .46508 Mdot
.38345 .60444 Mdot
.40567 .63797 Mdot
.39527 .63641 Mdot
.63768 .51906 Mdot
.48907 .34814 Mdot
.61781 .4999 Mdot
.64608 .52966 Mdot
.59376 .39506 Mdot
.4564 .3395 Mdot
.62108 .51035 Mdot
.34767 .5655 Mdot
.49282 .67729 Mdot
.37394 .60801 Mdot
.35255 .44877 Mdot
.22967 .51624 Mdot
.41452 .40375 Mdot
.66482 .48392 Mdot
.4015 .7651 Mdot
.48846 .30845 Mdot
.54245 .68991 Mdot
.53926 .713 Mdot
.53401 .68983 Mdot
.36311 .49481 Mdot
.51188 .30499 Mdot
.66006 .78794 Mdot
.66269 .47815 Mdot
.50477 .57992 Mdot
.7052 .57079 Mdot
.40572 .75519 Mdot
.35161 .45187 Mdot
.62267 .45313 Mdot
.50897 .46283 Mdot
.72756 .34968 Mdot
.65119 .51515 Mdot
.61936 .53379 Mdot
.26676 .60977 Mdot
.55149 .48917 Mdot
.44866 .35433 Mdot
.52081 .81437 Mdot
.70114 .48295 Mdot
.54797 .3744 Mdot
.45183 .16691 Mdot
.6638 .49404 Mdot
.68134 .49478 Mdot
.65132 .44967 Mdot
.60448 .48361 Mdot
.4526 .33167 Mdot
.63059 .63289 Mdot
.40194 .46341 Mdot
.5181 .58879 Mdot
.33986 .43996 Mdot
.39767 .56691 Mdot
.31466 .3011 Mdot
.47674 .37088 Mdot
.54706 .6888 Mdot
.31426 .27281 Mdot
.58238 .81282 Mdot
.39129 .64666 Mdot
.67104 .26505 Mdot
.52727 .66698 Mdot
.63329 .53515 Mdot
.50367 .68313 Mdot
.39469 .57247 Mdot
.3668 .4669 Mdot
.581 .47337 Mdot
.51102 .31847 Mdot
.46298 .34114 Mdot
.64714 .44331 Mdot
.3853 .21952 Mdot
.36678 .44113 Mdot
.3387 .42632 Mdot
.62278 .52593 Mdot
.65918 .54408 Mdot
.48694 .3281 Mdot
.38924 .5908 Mdot
.66378 .7298 Mdot
.51225 .67773 Mdot
.65216 .43707 Mdot
.60336 .48869 Mdot
.49696 .8004 Mdot
.35857 .46511 Mdot
.40338 .65186 Mdot
.6024 .50415 Mdot
.31087 .39413 Mdot
.60233 .50355 Mdot
.5953 .42361 Mdot
.37581 .60959 Mdot
.68742 .43581 Mdot
.60775 .46076 Mdot
.74065 .48022 Mdot
.39604 .43266 Mdot
.47171 .33332 Mdot
.52738 .37418 Mdot
.54482 .5875 Mdot
.37366 .43923 Mdot
.61922 .51239 Mdot
.35784 .45833 Mdot
.63911 .5285 Mdot
.64488 .4423 Mdot
.35067 .44525 Mdot
.49004 .32958 Mdot
.22289 .42372 Mdot
.31483 .29409 Mdot
.60507 .48053 Mdot
.69935 .46394 Mdot
.64719 .63764 Mdot
.78914 .52829 Mdot
.67081 .50923 Mdot
.46498 .32703 Mdot
.62843 .4544 Mdot
.39808 .44336 Mdot
.5221 .70455 Mdot
.46946 .32029 Mdot
.39822 .59173 Mdot
.38132 .64205 Mdot
.36421 .36169 Mdot
.41427 .59143 Mdot
.60167 .51168 Mdot
.53114 .28689 Mdot
.53436 .35541 Mdot
.44033 .17949 Mdot
.40009 .61985 Mdot
.51964 .70671 Mdot
.62661 .46959 Mdot
.38028 .76573 Mdot
.33074 .44221 Mdot
.54274 .88543 Mdot
.70041 .76729 Mdot
.56813 .67406 Mdot
.80726 .57244 Mdot
.38875 .56576 Mdot
.6241 .4443 Mdot
.55654 .68089 Mdot
.39083 .64507 Mdot
.59505 .48909 Mdot
.57917 .4867 Mdot
.78929 .4743 Mdot
.52942 .5668 Mdot
.35657 .45932 Mdot
.42041 .62569 Mdot
.55973 .70843 Mdot
.40532 .65492 Mdot
.46274 .34989 Mdot
.66377 .46294 Mdot
.61316 .54953 Mdot
.3941 .58969 Mdot
.38621 .65073 Mdot
.62955 .51062 Mdot
.4811 .3717 Mdot
.43344 .65223 Mdot
.63743 .47195 Mdot
.56296 .55658 Mdot
.47268 .37948 Mdot
.40769 .59955 Mdot
.68743 .47721 Mdot
.5111 .72525 Mdot
.39165 .59784 Mdot
.37339 .60553 Mdot
.64481 .4429 Mdot
.50876 .6906 Mdot
.69608 .46216 Mdot
.36465 .42675 Mdot
.7984 .38321 Mdot
.39689 .45046 Mdot
.48929 .71492 Mdot
.65255 .55072 Mdot
.31031 .42535 Mdot
.46502 .36119 Mdot
.56822 .64467 Mdot
.22953 .56501 Mdot
.71417 .4905 Mdot
.20643 .37654 Mdot
.49901 .44605 Mdot
.37391 .2119 Mdot
.21287 .61693 Mdot
.54061 .67036 Mdot
.38159 .44059 Mdot
.68072 .49566 Mdot
.39868 .41608 Mdot
.55725 .68666 Mdot
.71714 .26569 Mdot
.68592 .47032 Mdot
.4825 .34774 Mdot
.63461 .51208 Mdot
.47477 .35357 Mdot
.63445 .44525 Mdot
.67867 .42231 Mdot
.25677 .59305 Mdot
.71365 .67764 Mdot
.5929 .49197 Mdot
.31238 .7607 Mdot
.50379 .76316 Mdot
.52011 .66503 Mdot
.62217 .49724 Mdot
.39534 .54325 Mdot
.39314 .42215 Mdot
.4258 .2542 Mdot
.38323 .62745 Mdot
.38774 .47268 Mdot
.48597 .32236 Mdot
.41169 .61583 Mdot
.37488 .63685 Mdot
.68086 .43428 Mdot
.51866 .6569 Mdot
.37433 .47171 Mdot
.66832 .46775 Mdot
.68322 .46776 Mdot
.67791 .73602 Mdot
.47374 .71919 Mdot
.54053 .33334 Mdot
.56879 .83975 Mdot
.52565 .37226 Mdot
.51601 .67667 Mdot
.37903 .6217 Mdot
.66643 .50951 Mdot
.6423 .49578 Mdot
.25798 .49945 Mdot
.52368 .34004 Mdot
.51772 .53492 Mdot
.62394 .23237 Mdot
.42696 .6564 Mdot
.64246 .68351 Mdot
.46721 .34202 Mdot
.64487 .68207 Mdot
.54787 .71475 Mdot
.28425 .28289 Mdot
.69189 .68833 Mdot
.35497 .44809 Mdot
.64139 .68 Mdot
.50605 .34262 Mdot
.60857 .46673 Mdot
.43037 .58805 Mdot
.40903 .58313 Mdot
.47846 .33268 Mdot
.36071 .62732 Mdot
.55056 .68157 Mdot
.68289 .48431 Mdot
.65245 .78583 Mdot
.37608 .33794 Mdot
.3862 .586 Mdot
.6884 .4248 Mdot
.38666 .46581 Mdot
.65251 .44268 Mdot
.55119 .69511 Mdot
.36739 .45296 Mdot
.54051 .76488 Mdot
.30325 .3448 Mdot
.62761 .47359 Mdot
.41373 .79193 Mdot
.37255 .44346 Mdot
.7859 .57228 Mdot
.64531 .46801 Mdot
.38246 .42472 Mdot
.56386 .45719 Mdot
.32945 .56471 Mdot
.51141 .46857 Mdot
.16386 .42806 Mdot
.50767 .50578 Mdot
.42265 .57675 Mdot
.33153 .53814 Mdot
.29889 .59725 Mdot
.39807 .41729 Mdot
.38993 .65277 Mdot
.48803 .64367 Mdot
.40023 .44534 Mdot
.656 .53145 Mdot
.66196 .50555 Mdot
.69841 .26615 Mdot
.49017 .45327 Mdot
.35022 .5458 Mdot
.41163 .30922 Mdot
.67953 .45182 Mdot
.70143 .49237 Mdot
.64347 .48944 Mdot
.45474 .31424 Mdot
.36118 .46259 Mdot
.38057 .79986 Mdot
.3738 .43685 Mdot
.71916 .73172 Mdot
.38486 .60938 Mdot
.4177 .62206 Mdot
.66748 .48132 Mdot
.48102 .60411 Mdot
.60565 .66813 Mdot
.63711 .50575 Mdot
.51406 .6147 Mdot
.54932 .20196 Mdot
.68196 .52678 Mdot
.45604 .35876 Mdot
.72837 .47851 Mdot
.45077 .37783 Mdot
.35473 .42727 Mdot
.53762 .67642 Mdot
.56051 .63761 Mdot
.36658 .46907 Mdot
.65409 .47765 Mdot
.29833 .42968 Mdot
.65241 .50402 Mdot
.60056 .48088 Mdot
.74322 .71101 Mdot
.56381 .68767 Mdot
.40179 .63125 Mdot
.53253 .69185 Mdot
.47913 .36583 Mdot
.39862 .88721 Mdot
.50887 .67574 Mdot
.601 .66319 Mdot
.75207 .30094 Mdot
.64344 .67675 Mdot
.46389 .34897 Mdot
.52932 .65101 Mdot
.36071 .44594 Mdot
.26004 .27352 Mdot
.80756 .48334 Mdot
.39777 .396 Mdot
.63907 .47593 Mdot
.49304 .3753 Mdot
.4659 .31759 Mdot
.34116 .46344 Mdot
.50487 .34974 Mdot
.5652 .46463 Mdot
.6061 .4741 Mdot
.40444 .41985 Mdot
.31875 .36912 Mdot
.35674 .48185 Mdot
.34108 .30961 Mdot
.62523 .50031 Mdot
.46674 .33513 Mdot
.7209 .50278 Mdot
.44063 .33797 Mdot
.41055 .64991 Mdot
.6487 .53736 Mdot
.55059 .6833 Mdot
.32556 .40881 Mdot
.39935 .60408 Mdot
.39017 .75515 Mdot
.48949 .36291 Mdot
.35364 .51103 Mdot
.49739 .35792 Mdot
.52283 .31759 Mdot
.39099 .46797 Mdot
.51865 .35111 Mdot
.68231 .49187 Mdot
.36328 .5431 Mdot
.49789 .3681 Mdot
.38845 .45426 Mdot
.53259 .67829 Mdot
.49507 .32354 Mdot
.32458 .63595 Mdot
.63126 .46389 Mdot
.37669 .62817 Mdot
.2626 .65126 Mdot
.52541 .36319 Mdot
.55161 .65595 Mdot
.42177 .60365 Mdot
.54162 .65787 Mdot
.50838 .18131 Mdot
.41253 .42797 Mdot
.79061 .62272 Mdot
.49029 .68806 Mdot
.49241 .30581 Mdot
.24878 .63214 Mdot
.66685 .50647 Mdot
.62875 .46559 Mdot
.50425 .66352 Mdot
.46627 .3171 Mdot
.31286 .25774 Mdot
.43378 .37355 Mdot
.31137 .34881 Mdot
.4066 .41389 Mdot
.36569 .7791 Mdot
.34917 .29326 Mdot
.57924 .16173 Mdot
.70836 .48677 Mdot
.37915 .56719 Mdot
.65794 .48556 Mdot
.22586 .54597 Mdot
.5206 .69208 Mdot
.35206 .64463 Mdot
.61344 .53682 Mdot
.40759 .62431 Mdot
.64805 .45435 Mdot
.42756 .48683 Mdot
.72338 .47353 Mdot
.52516 .7092 Mdot
.27254 .45115 Mdot
.49432 .30424 Mdot
.52844 .67116 Mdot
.36651 .58869 Mdot
.61708 .67721 Mdot
.59513 .47768 Mdot
.71039 .45765 Mdot
.42944 .65337 Mdot
.48379 .35219 Mdot
.42865 .59839 Mdot
.35961 .4257 Mdot
.54401 .68289 Mdot
.61796 .47111 Mdot
.58777 .48566 Mdot
.2867 .51516 Mdot
.3802 .47137 Mdot
.36525 .63038 Mdot
.37155 .431 Mdot
.39065 .5639 Mdot
.69034 .44725 Mdot
.41874 .61982 Mdot
.60933 .45193 Mdot
.24157 .57408 Mdot
.7421 .70936 Mdot
.6126 .33946 Mdot
.41528 .61608 Mdot
.63691 .70987 Mdot
.39524 .44538 Mdot
.37707 .42719 Mdot
.75213 .32084 Mdot
.76035 .44524 Mdot
.63784 .77126 Mdot
.17835 .48989 Mdot
.34151 .43773 Mdot
.3895 .46149 Mdot
.37892 .63281 Mdot
.51694 .35775 Mdot
.53098 .34117 Mdot
.38203 .56786 Mdot
.72178 .60356 Mdot
.49508 .34623 Mdot
.23987 .3246 Mdot
.6014 .77678 Mdot
.60875 .42987 Mdot
.43244 .55155 Mdot
.53913 .68432 Mdot
.70691 .62063 Mdot
.42451 .48962 Mdot
.68433 .49533 Mdot
.48379 .79604 Mdot
.38489 .59515 Mdot
.6341 .60322 Mdot
.15793 .48679 Mdot
.68408 .46529 Mdot
.65211 .4661 Mdot
.65051 .48378 Mdot
.56662 .66306 Mdot
.76999 .44252 Mdot
.6846 .47439 Mdot
.72692 .59948 Mdot
.67096 .44472 Mdot
.59539 .408 Mdot
.52804 .68799 Mdot
.56777 .42432 Mdot
.2579 .61074 Mdot
.54239 .80051 Mdot
.72021 .51889 Mdot
.36406 .42471 Mdot
.53756 .61183 Mdot
.39427 .42981 Mdot
.60216 .36291 Mdot
.69399 .68378 Mdot
.50951 .38316 Mdot
.68259 .49711 Mdot
.4095 .60702 Mdot
.46454 .31974 Mdot
.31615 .54069 Mdot
.29633 .83565 Mdot
.37282 .42193 Mdot
.61768 .15207 Mdot
.37062 .42773 Mdot
.36868 .62776 Mdot
.48552 .32775 Mdot
.6957 .33289 Mdot
.50536 .57499 Mdot
.49713 .32267 Mdot
.25005 .38712 Mdot
.49424 .28591 Mdot
.63367 .69854 Mdot
.5147 .37509 Mdot
.39136 .45086 Mdot
.37094 .49421 Mdot
.57349 .48642 Mdot
.6712 .49531 Mdot
.46745 .51811 Mdot
.60772 .69978 Mdot
.6696 .50199 Mdot
.40515 .60563 Mdot
.80178 .54527 Mdot
.57217 .61972 Mdot
.51579 .34341 Mdot
.39887 .47041 Mdot
.65252 .46299 Mdot
.60139 .49757 Mdot
.59744 .47643 Mdot
.59094 .84429 Mdot
.28924 .27515 Mdot
.6163 .45447 Mdot
.67928 .44821 Mdot
.41011 .61873 Mdot
.52291 .71927 Mdot
.21828 .54188 Mdot
.68535 .4042 Mdot
.67905 .51091 Mdot
.52369 .67515 Mdot
.56537 .68693 Mdot
.59499 .49159 Mdot
.50247 .78126 Mdot
.3016 .4474 Mdot
.66832 .46701 Mdot
.75524 .44669 Mdot
.30115 .62782 Mdot
.38201 .64728 Mdot
.395 .59211 Mdot
.46332 .31365 Mdot
.4131 .59495 Mdot
.37803 .5735 Mdot
.70118 .32044 Mdot
.50597 .52055 Mdot
.34728 .48948 Mdot
.53011 .69785 Mdot
.64462 .49871 Mdot
.53941 .33856 Mdot
.30441 .40426 Mdot
.40041 .4529 Mdot
.49204 .31151 Mdot
.39025 .42302 Mdot
.55085 .64677 Mdot
.72861 .56403 Mdot
.40022 .57507 Mdot
.3407 .44841 Mdot
.30468 .34364 Mdot
.52392 .67801 Mdot
.37511 .47643 Mdot
.29067 .44454 Mdot
.66344 .53153 Mdot
.67912 .37089 Mdot
.63381 .50275 Mdot
.34417 .22943 Mdot
.36722 .47593 Mdot
.25676 .55305 Mdot
.65869 .47168 Mdot
.3919 .60078 Mdot
.57748 .43564 Mdot
.65942 .51897 Mdot
.40017 .58766 Mdot
.60529 .46861 Mdot
.56116 .67517 Mdot
.47702 .38335 Mdot
.52457 .5882 Mdot
.85342 .58407 Mdot
.51963 .65628 Mdot
.31132 .53251 Mdot
.67322 .50826 Mdot
.5633 .18703 Mdot
.49656 .32502 Mdot
.59947 .46026 Mdot
.59061 .62093 Mdot
.50774 .36862 Mdot
.4819 .31426 Mdot
.61047 .50661 Mdot
.35764 .44247 Mdot
.40121 .60133 Mdot
.5262 .68348 Mdot
.50734 .17277 Mdot
.63281 .48185 Mdot
.63129 .4557 Mdot
.5281 .66825 Mdot
.3937 .4568 Mdot
.60742 .51026 Mdot
.27168 .67452 Mdot
.35408 .20556 Mdot
.40522 .44283 Mdot
.66268 .52694 Mdot
.67895 .38438 Mdot
.46368 .38915 Mdot
.77457 .29748 Mdot
.54842 .75247 Mdot
.40774 .62978 Mdot
.55401 .48328 Mdot
.43843 .88361 Mdot
.53637 .67782 Mdot
.59784 .80037 Mdot
.59821 .48938 Mdot
.63825 .44778 Mdot
.5002 .31132 Mdot
.61934 .50483 Mdot
.52025 .3648 Mdot
.84961 .56657 Mdot
.48979 .80392 Mdot
.48022 .35612 Mdot
.50804 .31318 Mdot
.5926 .63773 Mdot
.2199 .54191 Mdot
.47802 .3305 Mdot
.67786 .44276 Mdot
.52143 .26424 Mdot
.73562 .44658 Mdot
.50146 .6708 Mdot
.28423 .64606 Mdot
.45299 .39217 Mdot
.57393 .70635 Mdot
.2044 .44127 Mdot
.46218 .3966 Mdot
.30888 .4552 Mdot
.35539 .43008 Mdot
.68847 .46988 Mdot
.41137 .58602 Mdot
.42191 .61016 Mdot
.7202 .49663 Mdot
.64724 .50515 Mdot
.48243 .36499 Mdot
.53267 .70091 Mdot
.3935 .4179 Mdot
.62161 .45751 Mdot
.57682 .6295 Mdot
.51008 .67429 Mdot
.51089 .35574 Mdot
.77687 .47758 Mdot
.52573 .71044 Mdot
.71131 .44009 Mdot
.67476 .47578 Mdot
.63146 .51471 Mdot
.74327 .45876 Mdot
.3483 .45586 Mdot
.24479 .61799 Mdot
.69325 .50026 Mdot
.52024 .80103 Mdot
.50519 .41757 Mdot
.65363 .41972 Mdot
.4961 .352 Mdot
.32953 .44515 Mdot
.4333 .6163 Mdot
.60424 .59762 Mdot
.62804 .47724 Mdot
.3274 .26179 Mdot
.66351 .24277 Mdot
.41933 .64199 Mdot
.51962 .31384 Mdot
.53948 .69001 Mdot
.63869 .5056 Mdot
.57688 .37863 Mdot
.66431 .49929 Mdot
.50772 .65049 Mdot
.37618 .59949 Mdot
.35568 .43073 Mdot
.36985 .21024 Mdot
.42165 .61135 Mdot
.47629 .31785 Mdot
.12006 .49977 Mdot
.50611 .37607 Mdot
.51348 .31351 Mdot
.57279 .38888 Mdot
.3465 .44863 Mdot
.46841 .8942 Mdot
.81706 .42751 Mdot
.64746 .54493 Mdot
.39471 .43953 Mdot
.47901 .33827 Mdot
.65839 .44469 Mdot
.47136 .37172 Mdot
.50992 .30186 Mdot
.69691 .45278 Mdot
.66217 .45063 Mdot
.32181 .29768 Mdot
.16154 .44495 Mdot
.53931 .69193 Mdot
.47241 .36188 Mdot
.58025 .57035 Mdot
.66437 .44661 Mdot
.66288 .47735 Mdot
.30748 .5987 Mdot
.51036 .69485 Mdot
.40193 .26975 Mdot
.59904 .49312 Mdot
.46271 .80348 Mdot
.72806 .48141 Mdot
.45106 .33723 Mdot
.40378 .4485 Mdot
.5449 .79559 Mdot
.42259 .44718 Mdot
.52376 .34757 Mdot
.54207 .69885 Mdot
.5312 .37058 Mdot
.60071 .66746 Mdot
.34784 .46867 Mdot
.46904 .31858 Mdot
.50574 .47517 Mdot
.37399 .45505 Mdot
.35936 .4714 Mdot
.56999 .36585 Mdot
.35482 .60432 Mdot
.56533 .66615 Mdot
.37823 .47029 Mdot
.62076 .57306 Mdot
.38754 .44651 Mdot
.77331 .36361 Mdot
.68096 .51284 Mdot
.68375 .60204 Mdot
.46236 .57829 Mdot
.57792 .51769 Mdot
.35596 .47315 Mdot
.55357 .69089 Mdot
.60927 .50924 Mdot
.50752 .34499 Mdot
.52281 .66095 Mdot
.37861 .40316 Mdot
.38408 .63277 Mdot
.49974 .35895 Mdot
.41179 .41394 Mdot
.46778 .3495 Mdot
.62353 .58969 Mdot
.78381 .3391 Mdot
.3027 .71515 Mdot
.50717 .56908 Mdot
.5976 .47805 Mdot
.19225 .50965 Mdot
.63436 .42419 Mdot
.64863 .5101 Mdot
.40678 .60078 Mdot
.64656 .60879 Mdot
.4892 .32984 Mdot
.35296 .21358 Mdot
.34367 .43995 Mdot
.51828 .8147 Mdot
.50035 .26622 Mdot
.59542 .46686 Mdot
.49747 .36895 Mdot
.50726 .37653 Mdot
.59112 .31797 Mdot
.42961 .63358 Mdot
.58919 .44793 Mdot
.58567 .44885 Mdot
.7072 .45784 Mdot
.35658 .46636 Mdot
.40039 .76174 Mdot
.4168 .57253 Mdot
.76837 .30425 Mdot
.37966 .59273 Mdot
.51645 .6121 Mdot
.51729 .35086 Mdot
.50807 .67834 Mdot
.66419 .47582 Mdot
.51723 .2909 Mdot
.52466 .34482 Mdot
.49917 .65967 Mdot
.55145 .67259 Mdot
.31869 .58703 Mdot
.35025 .44666 Mdot
.59233 .49487 Mdot
.68711 .47795 Mdot
.61587 .49727 Mdot
.64108 .51757 Mdot
.36715 .42243 Mdot
.62702 .52347 Mdot
.33408 .46485 Mdot
.69998 .56692 Mdot
.4706 .79434 Mdot
.50283 .50799 Mdot
.45947 .26045 Mdot
.51222 .34288 Mdot
.58298 .56025 Mdot
.6989 .42689 Mdot
.76081 .68726 Mdot
.50086 .2177 Mdot
.67396 .5323 Mdot
.39523 .6459 Mdot
.75946 .46225 Mdot
.40716 .57633 Mdot
.68907 .18964 Mdot
.28309 .52173 Mdot
.1772 .41262 Mdot
.67968 .46499 Mdot
.30533 .61187 Mdot
.61486 .56403 Mdot
.61788 .43028 Mdot
.30296 .5526 Mdot
.40976 .36012 Mdot
.26958 .38581 Mdot
.54064 .70546 Mdot
.63571 .46548 Mdot
.53576 .3278 Mdot
.68338 .48759 Mdot
.66113 .48241 Mdot
.59834 .49646 Mdot
.37981 .47935 Mdot
.59061 .44928 Mdot
.64285 .52367 Mdot
.41137 .74835 Mdot
.66471 .68545 Mdot
.42289 .62141 Mdot
.7394 .30172 Mdot
.51027 .66987 Mdot
.48921 .36623 Mdot
.25206 .34809 Mdot
.35456 .4489 Mdot
.59076 .30773 Mdot
.63693 .51674 Mdot
.30761 .31943 Mdot
.40407 .40729 Mdot
.5468 .68306 Mdot
.42461 .57583 Mdot
.20284 .36444 Mdot
.40581 .61124 Mdot
.50693 .46387 Mdot
.39335 .60482 Mdot
.72853 .4527 Mdot
.48139 .36454 Mdot
.60012 .5043 Mdot
.37521 .46978 Mdot
.40671 .59247 Mdot
.65928 .64109 Mdot
.64519 .48899 Mdot
.40293 .62157 Mdot
.60074 .50518 Mdot
.72849 .56678 Mdot
.72846 .68904 Mdot
.37039 .57968 Mdot
.33753 .47646 Mdot
.37789 .45856 Mdot
.50972 .6917 Mdot
.4993 .36379 Mdot
.50644 .3172 Mdot
.36942 .45188 Mdot
.80612 .50428 Mdot
.67348 .51462 Mdot
.66616 .44865 Mdot
.52606 .80497 Mdot
.67572 .5005 Mdot
.62257 .69358 Mdot
.50924 .46597 Mdot
.51213 .34978 Mdot
.6268 .44444 Mdot
.60143 .4936 Mdot
.62752 .47137 Mdot
.66327 .5875 Mdot
.38972 .58827 Mdot
.69282 .48632 Mdot
.55134 .66927 Mdot
.37361 .53826 Mdot
.65382 .44252 Mdot
.70456 .45078 Mdot
.50456 .31582 Mdot
.59159 .82599 Mdot
.36381 .4301 Mdot
.36353 .6025 Mdot
.41598 .62164 Mdot
.28673 .64542 Mdot
.51189 .40866 Mdot
.50815 .47465 Mdot
.74146 .27312 Mdot
.26045 .59555 Mdot
.52091 .66705 Mdot
.40552 .53699 Mdot
.52517 .41928 Mdot
.37581 .63291 Mdot
.37708 .42047 Mdot
.68357 .51154 Mdot
.67947 .51133 Mdot
.72944 .74407 Mdot
.59154 .47644 Mdot
.53697 .68702 Mdot
.33473 .45863 Mdot
.5055 .34193 Mdot
.54666 .68454 Mdot
.3775 .42878 Mdot
.48539 .3534 Mdot
.68165 .52215 Mdot
.68545 .51562 Mdot
.49324 .3127 Mdot
.47167 .31273 Mdot
.67085 .4729 Mdot
.45423 .65561 Mdot
.48555 .30296 Mdot
.46501 .33471 Mdot
.39919 .57448 Mdot
.40816 .58397 Mdot
.67529 .43018 Mdot
.39069 .43768 Mdot
.6388 .52468 Mdot
.41077 .61279 Mdot
.52231 .70055 Mdot
.49431 .33069 Mdot
.60376 .48237 Mdot
.61715 .46145 Mdot
.52501 .67817 Mdot
.53837 .70371 Mdot
.55093 .67738 Mdot
.34853 .47985 Mdot
.62026 .49141 Mdot
.48107 .32502 Mdot
.35029 .44158 Mdot
.56627 .68517 Mdot
.50592 .69171 Mdot
.38899 .65828 Mdot
.66658 .51118 Mdot
.38283 .53629 Mdot
.37776 .86844 Mdot
.571 .75294 Mdot
.4259 .63547 Mdot
.40467 .66107 Mdot
.65752 .66642 Mdot
.49443 .60245 Mdot
.36728 .44461 Mdot
.49631 .64698 Mdot
.56592 .64158 Mdot
.64571 .5364 Mdot
.7006 .47958 Mdot
.57917 .45333 Mdot
.54611 .67042 Mdot
.61158 .61084 Mdot
.47093 .36953 Mdot
.58933 .22773 Mdot
.51402 .66544 Mdot
.38519 .65035 Mdot
.35516 .61137 Mdot
.37859 .59375 Mdot
.68523 .51198 Mdot
.61379 .33383 Mdot
.53889 .49848 Mdot
.18657 .52164 Mdot
.36445 .47708 Mdot
.53696 .36686 Mdot
.53945 .19362 Mdot
.48845 .31303 Mdot
.39556 .56874 Mdot
.53266 .66126 Mdot
.46515 .32264 Mdot
.39982 .42895 Mdot
.38557 .46464 Mdot
.38492 .58802 Mdot
.38252 .60711 Mdot
.36959 .61096 Mdot
.51367 .30952 Mdot
.51792 .35223 Mdot
.62735 .48138 Mdot
.50192 .33274 Mdot
.68264 .78687 Mdot
.55876 .65184 Mdot
.4112 .66207 Mdot
.38136 .43872 Mdot
.47604 .35554 Mdot
.64243 .49123 Mdot
.54862 .59838 Mdot
.39861 .34704 Mdot
.54849 .66115 Mdot
.69615 .71987 Mdot
.68802 .19136 Mdot
.59069 .49229 Mdot
.35711 .46361 Mdot
.65103 .78437 Mdot
.64796 .48351 Mdot
.37868 .61724 Mdot
.23815 .58654 Mdot
.4187 .56057 Mdot
.64555 .52919 Mdot
.60332 .52126 Mdot
.4045 .45264 Mdot
.72184 .26401 Mdot
.6295 .48516 Mdot
.3962 .2845 Mdot
.40936 .45504 Mdot
.4139 .57159 Mdot
.32981 .21281 Mdot
.3037 .68896 Mdot
.71027 .6142 Mdot
.39609 .57437 Mdot
.65666 .50795 Mdot
.3997 .57722 Mdot
.55532 .66858 Mdot
.37503 .58249 Mdot
.45592 .36229 Mdot
.42677 .61215 Mdot
.63266 .45479 Mdot
.47617 .33227 Mdot
.37234 .44262 Mdot
.54051 .82059 Mdot
.47302 .75168 Mdot
.39081 .60081 Mdot
.3623 .59386 Mdot
.61177 .4562 Mdot
.37901 .27142 Mdot
.70222 .52046 Mdot
.67624 .45794 Mdot
.33945 .44534 Mdot
.50247 .36751 Mdot
.39576 .46943 Mdot
.61137 .4441 Mdot
.26291 .67026 Mdot
.36695 .43278 Mdot
.3031 .31612 Mdot
.52611 .66679 Mdot
.44406 .4705 Mdot
.64206 .49841 Mdot
.3946 .46051 Mdot
.62114 .49227 Mdot
.46677 .36719 Mdot
.47512 .46411 Mdot
.27235 .44158 Mdot
.37118 .46831 Mdot
.34232 .24076 Mdot
.48437 .63437 Mdot
.65723 .55371 Mdot
.38597 .42606 Mdot
.5881 .61788 Mdot
.37361 .63547 Mdot
.51276 .67455 Mdot
.55756 .69691 Mdot
.53273 .65532 Mdot
.70523 .51061 Mdot
.70351 .53454 Mdot
.5639 .67937 Mdot
.40299 .42835 Mdot
.53069 .71009 Mdot
.54208 .38256 Mdot
.31743 .25527 Mdot
.52114 .69073 Mdot
.64209 .4703 Mdot
.72309 .52441 Mdot
.66912 .67784 Mdot
.33652 .56661 Mdot
.18924 .3998 Mdot
.4421 .2539 Mdot
.66978 .49559 Mdot
.49617 .39 Mdot
.46141 .35116 Mdot
.62984 .78899 Mdot
.60849 .71524 Mdot
.52557 .78748 Mdot
.50916 .31254 Mdot
.25945 .48276 Mdot
.50798 .35763 Mdot
.59402 .47415 Mdot
.66026 .4465 Mdot
.52874 .33664 Mdot
.42691 .78213 Mdot
.29308 .50075 Mdot
.42035 .19101 Mdot
.4644 .34202 Mdot
.39721 .43308 Mdot
.33553 .44598 Mdot
.35649 .47073 Mdot
.61085 .77433 Mdot
.51365 .37042 Mdot
.61547 .48695 Mdot
.41487 .61354 Mdot
.68965 .49583 Mdot
.36748 .45878 Mdot
.3504 .21521 Mdot
.51033 .32792 Mdot
.66644 .46243 Mdot
.78321 .53507 Mdot
.38429 .62226 Mdot
.52141 .67456 Mdot
.76262 .52752 Mdot
.54563 .76936 Mdot
.34645 .4599 Mdot
.52568 .36523 Mdot
.25889 .53715 Mdot
.29747 .31084 Mdot
.70406 .49354 Mdot
.62551 .42189 Mdot
.54628 .16219 Mdot
.54214 .76413 Mdot
.61404 .52522 Mdot
.36606 .61883 Mdot
.25702 .5047 Mdot
.61393 .46923 Mdot
.46534 .3567 Mdot
.54627 .70741 Mdot
.53663 .65795 Mdot
.65526 .43074 Mdot
.50458 .58248 Mdot
.45024 .43653 Mdot
.62025 .51355 Mdot
.71005 .43828 Mdot
.40706 .57189 Mdot
.26116 .59815 Mdot
.51527 .80385 Mdot
.54231 .6997 Mdot
.60359 .50798 Mdot
.2309 .43014 Mdot
.52196 .32627 Mdot
.42618 .62516 Mdot
.35142 .47477 Mdot
.71745 .56385 Mdot
.41357 .57033 Mdot
.61196 .46996 Mdot
.60545 .50689 Mdot
.38045 .4752 Mdot
.45088 .33808 Mdot
.54381 .66772 Mdot
.41681 .61458 Mdot
.5469 .6988 Mdot
.50945 .36942 Mdot
.5091 .33359 Mdot
.72655 .43223 Mdot
.60527 .53861 Mdot
.39681 .59274 Mdot
.63863 .43852 Mdot
.33338 .66044 Mdot
.71235 .24699 Mdot
.37873 .41094 Mdot
.59089 .49515 Mdot
.45077 .32235 Mdot
.36702 .46787 Mdot
.65065 .44717 Mdot
.51587 .16598 Mdot
.66625 .44606 Mdot
.42385 .39765 Mdot
.29672 .71648 Mdot
.55226 .6885 Mdot
.57194 .22565 Mdot
.41366 .23389 Mdot
.67792 .49488 Mdot
.40387 .64008 Mdot
.64787 .41555 Mdot
.36028 .44241 Mdot
.51653 .34535 Mdot
.77479 .29381 Mdot
.38701 .45093 Mdot
.68229 .47587 Mdot
.54495 .68321 Mdot
.51735 .37223 Mdot
.51363 .6256 Mdot
.49751 .78319 Mdot
.69376 .53551 Mdot
.66725 .43715 Mdot
.63277 .52054 Mdot
.22523 .62003 Mdot
.36398 .60196 Mdot
.47559 .34541 Mdot
.35582 .46373 Mdot
.36719 .45112 Mdot
.38528 .59044 Mdot
.29273 .37148 Mdot
.44598 .46861 Mdot
.3793 .85571 Mdot
.40046 .5852 Mdot
.54005 .65188 Mdot
.39109 .27485 Mdot
.40723 .63999 Mdot
.39905 .62224 Mdot
.40875 .57324 Mdot
.39995 .48909 Mdot
.48745 .35087 Mdot
.61431 .46255 Mdot
.45867 .35363 Mdot
.65583 .51146 Mdot
.4971 .41534 Mdot
.37057 .47063 Mdot
.518 .33872 Mdot
.52638 .16963 Mdot
.74625 .40245 Mdot
.64714 .47681 Mdot
.55206 .1899 Mdot
.62943 .54414 Mdot
.63215 .66457 Mdot
.59317 .51921 Mdot
.38729 .60527 Mdot
.57032 .53315 Mdot
.71676 .47215 Mdot
.58735 .81573 Mdot
.38171 .43726 Mdot
.38456 .64743 Mdot
.64115 .5402 Mdot
.72761 .4615 Mdot
.52736 .32611 Mdot
.46434 .32702 Mdot
.56179 .68701 Mdot
.72014 .67383 Mdot
.37192 .44058 Mdot
.79861 .40704 Mdot
.67285 .49067 Mdot
.35718 .74964 Mdot
.56803 .23778 Mdot
.65256 .44814 Mdot
.42969 .22526 Mdot
.60539 .32475 Mdot
.63978 .50357 Mdot
.54742 .55981 Mdot
.39363 .45526 Mdot
.27015 .68125 Mdot
.67469 .44392 Mdot
.38205 .6246 Mdot
.51394 .35883 Mdot
.47536 .37137 Mdot
.56268 .67891 Mdot
.79985 .63864 Mdot
.39108 .47244 Mdot
.51809 .34251 Mdot
.64936 .49044 Mdot
.34605 .45366 Mdot
.41594 .59733 Mdot
.59357 .46167 Mdot
.61314 .71952 Mdot
.50224 .33643 Mdot
.66437 .43938 Mdot
.37878 .31333 Mdot
.70435 .64485 Mdot
.17602 .5926 Mdot
.35311 .46282 Mdot
.51765 .70096 Mdot
.63968 .41591 Mdot
.79095 .4812 Mdot
.68226 .52822 Mdot
.67766 .60131 Mdot
.52334 .40073 Mdot
.51873 .70256 Mdot
.65427 .47025 Mdot
.61716 .47502 Mdot
.46888 .57945 Mdot
.53488 .70225 Mdot
.68758 .47409 Mdot
.72573 .53699 Mdot
.48348 .35054 Mdot
.41399 .56474 Mdot
.49968 .34261 Mdot
.6398 .47547 Mdot
.59034 .52209 Mdot
.49038 .30769 Mdot
.66306 .19829 Mdot
.57041 .68342 Mdot
.36104 .43245 Mdot
.63731 .55214 Mdot
.69715 .48835 Mdot
.31967 .77543 Mdot
.40693 .65087 Mdot
.21913 .50443 Mdot
.38442 .71772 Mdot
.21378 .44406 Mdot
.30547 .6902 Mdot
.13948 .46474 Mdot
.4917 .79892 Mdot
.59674 .44212 Mdot
.43732 .31031 Mdot
.53598 .50545 Mdot
.35719 .4757 Mdot
.73149 .32388 Mdot
.67091 .49608 Mdot
.65996 .48441 Mdot
.42638 .6272 Mdot
.28866 .35176 Mdot
.52084 .79219 Mdot
.51956 .5994 Mdot
.5417 .66733 Mdot
.47443 .36185 Mdot
.62875 .44722 Mdot
.52568 .53737 Mdot
.42256 .62414 Mdot
.36639 .75508 Mdot
.66267 .46282 Mdot
.75581 .68874 Mdot
.38421 .36735 Mdot
.34855 .4527 Mdot
.41435 .62845 Mdot
.5374 .7732 Mdot
.66408 .51411 Mdot
.34808 .47345 Mdot
.63374 .48803 Mdot
.46088 .62858 Mdot
.61749 .44341 Mdot
.51639 .68814 Mdot
.59695 .48628 Mdot
.52746 .6085 Mdot
.13753 .54837 Mdot
.51284 .64079 Mdot
.48721 .37452 Mdot
.42664 .64872 Mdot
.39133 .58918 Mdot
.46897 .31696 Mdot
.39236 .59183 Mdot
.58347 .27627 Mdot
.67564 .3143 Mdot
.53473 .66403 Mdot
.72069 .45444 Mdot
.52577 .69236 Mdot
.41332 .64888 Mdot
.66587 .50485 Mdot
.70412 .2261 Mdot
.40302 .59435 Mdot
.32034 .75399 Mdot
.38452 .44513 Mdot
.3963 .65192 Mdot
.67103 .44425 Mdot
.26444 .54094 Mdot
.42213 .61543 Mdot
.27454 .44095 Mdot
.62733 .47266 Mdot
.50945 .33847 Mdot
.61357 .47468 Mdot
.63572 .54947 Mdot
.3631 .57669 Mdot
.64815 .52456 Mdot
.37775 .42886 Mdot
.49413 .30126 Mdot
.24865 .29958 Mdot
.41321 .36948 Mdot
.68605 .49045 Mdot
.64923 .48824 Mdot
.53581 .34819 Mdot
.69446 .4819 Mdot
.36673 .4226 Mdot
.68447 .83414 Mdot
.52542 .66716 Mdot
.35966 .59995 Mdot
.30073 .68851 Mdot
.67423 .53101 Mdot
.61924 .51883 Mdot
.49353 .16822 Mdot
.29766 .69573 Mdot
.38292 .42662 Mdot
.71842 .48385 Mdot
.41961 .60497 Mdot
.54284 .68386 Mdot
.40401 .42681 Mdot
.63053 .5138 Mdot
.66143 .47373 Mdot
.51575 .69826 Mdot
.56118 .34091 Mdot
.58616 .78384 Mdot
.37539 .47761 Mdot
.57793 .53708 Mdot
.34266 .65843 Mdot
.66705 .51755 Mdot
.62894 .77145 Mdot
.4674 .32298 Mdot
.34274 .45422 Mdot
.20285 .52822 Mdot
.62281 .52958 Mdot
.4029 .44854 Mdot
.37351 .43935 Mdot
.7169 .48314 Mdot
.45647 .30656 Mdot
.49965 .2977 Mdot
.46836 .35113 Mdot
.70873 .77651 Mdot
.69246 .63512 Mdot
.36968 .6111 Mdot
.39339 .45649 Mdot
.37642 .57383 Mdot
.5273 .64964 Mdot
.51809 .44964 Mdot
.36599 .58518 Mdot
.46035 .32713 Mdot
.43288 .63564 Mdot
.62062 .47242 Mdot
.37057 .44356 Mdot
.37319 .62764 Mdot
.6535 .54203 Mdot
.36125 .27249 Mdot
.34628 .5379 Mdot
.51208 .70034 Mdot
.55055 .70505 Mdot
.65223 .44383 Mdot
.43376 .60779 Mdot
.66991 .47441 Mdot
.35568 .42095 Mdot
.3765 .27751 Mdot
.67611 .53408 Mdot
.38954 .5989 Mdot
.5109 .3898 Mdot
.54447 .76878 Mdot
.67297 .54392 Mdot
.64341 .47033 Mdot
.65559 .51662 Mdot
.6334 .48862 Mdot
.2675 .37202 Mdot
.40271 .41321 Mdot
.44095 .28231 Mdot
.24781 .62581 Mdot
.50221 .32248 Mdot
.47613 .29526 Mdot
.5659 .76205 Mdot
.30686 .46237 Mdot
.39285 .43919 Mdot
.64661 .51291 Mdot
.31786 .39195 Mdot
.34151 .21984 Mdot
.61652 .1652 Mdot
.52872 .73402 Mdot
.41268 .64529 Mdot
.52859 .35951 Mdot
.41721 .63028 Mdot
.65951 .50573 Mdot
.62029 .41801 Mdot
.13524 .46837 Mdot
.39412 .47925 Mdot
.53695 .66231 Mdot
.65401 .51471 Mdot
.7 .63033 Mdot
.41118 .6178 Mdot
.35586 .59266 Mdot
.68548 .46561 Mdot
.45466 .32025 Mdot
.23491 .69037 Mdot
.34958 .45774 Mdot
.43693 .25517 Mdot
.58783 .55445 Mdot
.42034 .29484 Mdot
.36298 .46111 Mdot
.50016 .77271 Mdot
.42779 .62847 Mdot
.55444 .27179 Mdot
.50386 .32162 Mdot
.52211 .66197 Mdot
.64113 .41921 Mdot
.50875 .31639 Mdot
.41783 .57178 Mdot
.51391 .34132 Mdot
.59558 .49086 Mdot
.41306 .43108 Mdot
.40742 .63175 Mdot
.35351 .49028 Mdot
.46001 .30315 Mdot
.54509 .69634 Mdot
.46298 .54318 Mdot
.74001 .36009 Mdot
.60219 .32042 Mdot
.69143 .49494 Mdot
.52492 .52796 Mdot
.6153 .49077 Mdot
.50306 .29188 Mdot
.63993 .48995 Mdot
.54321 .37215 Mdot
.40706 .63752 Mdot
.67848 .44737 Mdot
.62558 .5166 Mdot
.71488 .29571 Mdot
.65544 .45946 Mdot
.60227 .44471 Mdot
.64069 .5076 Mdot
.52938 .29309 Mdot
.71827 .45534 Mdot
.49354 .35346 Mdot
.46221 .76996 Mdot
.39636 .62188 Mdot
.54845 .70476 Mdot
.51172 .66354 Mdot
.68605 .60457 Mdot
.4344 .6712 Mdot
.2864 .36661 Mdot
.49324 .34136 Mdot
.37455 .43271 Mdot
.63687 .49155 Mdot
.17105 .50667 Mdot
.29725 .6201 Mdot
.4197 .59435 Mdot
.4128 .369 Mdot
.55903 .50032 Mdot
.22617 .63434 Mdot
.6555 .43835 Mdot
.74689 .72688 Mdot
.59961 .53757 Mdot
.61199 .44654 Mdot
.3694 .57597 Mdot
.56917 .65797 Mdot
.68952 .46643 Mdot
.52807 .32782 Mdot
.51217 .6843 Mdot
.44297 .30483 Mdot
.35093 .57129 Mdot
.47116 .76459 Mdot
.69287 .29545 Mdot
.62455 .4909 Mdot
.40573 .63292 Mdot
.49811 .35974 Mdot
.51231 .80455 Mdot
.35113 .4394 Mdot
.31752 .45159 Mdot
.5785 .56539 Mdot
.59259 .17956 Mdot
.51031 .67235 Mdot
.56666 .36092 Mdot
.63054 .45506 Mdot
.49938 .72733 Mdot
.70075 .49191 Mdot
.34536 .21989 Mdot
.53419 .6512 Mdot
.47507 .30052 Mdot
.39562 .43293 Mdot
.4598 .35179 Mdot
.60546 .33615 Mdot
.44176 .55952 Mdot
.4817 .50945 Mdot
.40495 .61433 Mdot
.41975 .49539 Mdot
.47486 .33824 Mdot
.60963 .51496 Mdot
.37339 .855 Mdot
.46529 .33046 Mdot
.52511 .35622 Mdot
.75324 .29878 Mdot
.70978 .24083 Mdot
.55929 .51138 Mdot
.49715 .30706 Mdot
.40095 .61511 Mdot
.54007 .69426 Mdot
.60803 .48452 Mdot
.62341 .48075 Mdot
.50404 .31423 Mdot
.35962 .58548 Mdot
.6943 .39312 Mdot
.38373 .60775 Mdot
.48272 .35331 Mdot
.39074 .62543 Mdot
.2529 .55465 Mdot
.38261 .64149 Mdot
.69701 .48724 Mdot
.63909 .49051 Mdot
.35635 .69025 Mdot
.50895 .33402 Mdot
.61741 .5113 Mdot
.60566 .46635 Mdot
.48071 .32729 Mdot
.5836 .67404 Mdot
.65826 .38532 Mdot
.67812 .50428 Mdot
.6355 .4626 Mdot
.52127 .70371 Mdot
.5221 .46099 Mdot
.78504 .61199 Mdot
.6093 .5091 Mdot
.56303 .65818 Mdot
.51583 .31443 Mdot
.67027 .4683 Mdot
.28358 .29332 Mdot
.25699 .50229 Mdot
.61498 .52381 Mdot
.37725 .63977 Mdot
.71281 .46486 Mdot
.19359 .61805 Mdot
.67738 .45822 Mdot
.48228 .3335 Mdot
.51437 .36464 Mdot
.79282 .39897 Mdot
.47274 .32173 Mdot
.40897 .58328 Mdot
.37137 .45669 Mdot
.34875 .22633 Mdot
.41622 .59829 Mdot
.66868 .54191 Mdot
.81752 .42193 Mdot
.58979 .45993 Mdot
.66484 .53973 Mdot
.2566 .69743 Mdot
.41581 .60241 Mdot
.49 .36939 Mdot
.48613 .58576 Mdot
.57457 .46889 Mdot
.34628 .46086 Mdot
.67918 .42475 Mdot
.66879 .5231 Mdot
.30157 .72209 Mdot
.25822 .4459 Mdot
.33822 .43829 Mdot
.59721 .43589 Mdot
.6106 .51063 Mdot
.39985 .54253 Mdot
.64495 .49251 Mdot
.53388 .69771 Mdot
.5066 .37157 Mdot
.40113 .64399 Mdot
.52743 .67656 Mdot
.67449 .4961 Mdot
.54739 .67232 Mdot
.37611 .62707 Mdot
.34477 .46589 Mdot
.66168 .50953 Mdot
.50114 .67166 Mdot
.54406 .67004 Mdot
.6132 .49481 Mdot
.51631 .34853 Mdot
.59408 .53588 Mdot
.66862 .4612 Mdot
.60204 .48239 Mdot
.50747 .31845 Mdot
.54701 .12337 Mdot
.67159 .45085 Mdot
.47928 .63913 Mdot
.52456 .35154 Mdot
.4077 .51831 Mdot
.40436 .64505 Mdot
.67382 .52005 Mdot
.33928 .45475 Mdot
.38732 .46712 Mdot
.40078 .57188 Mdot
.51892 .3732 Mdot
.37556 .71047 Mdot
.52152 .38691 Mdot
.58004 .49114 Mdot
.58623 .48797 Mdot
.81714 .47402 Mdot
.17532 .4086 Mdot
.47133 .36599 Mdot
.35116 .60912 Mdot
.51838 .59305 Mdot
.39787 .44892 Mdot
.37795 .64693 Mdot
.52657 .36548 Mdot
.51639 .37041 Mdot
.51075 .3476 Mdot
.53135 .65849 Mdot
.36375 .6905 Mdot
.44937 .34668 Mdot
.45902 .31526 Mdot
.62517 .472 Mdot
.61383 .51344 Mdot
.58943 .70822 Mdot
.64144 .71878 Mdot
.5536 .69339 Mdot
.38025 .59484 Mdot
.62083 .85075 Mdot
.35787 .42049 Mdot
.70099 .27865 Mdot
.67421 .5347 Mdot
.3553 .87178 Mdot
.66249 .44169 Mdot
.64821 .49332 Mdot
.49642 .30261 Mdot
.50327 .68626 Mdot
.52026 .68438 Mdot
.47247 .34508 Mdot
.49807 .28978 Mdot
.53229 .69766 Mdot
.47139 .21696 Mdot
.30297 .25854 Mdot
.45778 .58175 Mdot
.48831 .3251 Mdot
.72647 .34827 Mdot
.35581 .47932 Mdot
.44807 .37382 Mdot
.38108 .41509 Mdot
.4064 .62192 Mdot
.43305 .60235 Mdot
.35674 .46744 Mdot
.62821 .47428 Mdot
.36679 .60511 Mdot
.59173 .44861 Mdot
.48287 .23128 Mdot
.65184 .36847 Mdot
.31922 .68706 Mdot
.68163 .4375 Mdot
.48451 .77295 Mdot
.30918 .48264 Mdot
.67965 .48194 Mdot
.22676 .39557 Mdot
.54056 .66403 Mdot
.44625 .3616 Mdot
.34553 .43269 Mdot
.18209 .6161 Mdot
.65842 .51914 Mdot
.48634 .33275 Mdot
.38298 .43532 Mdot
.69377 .58112 Mdot
.39192 .28389 Mdot
.65581 .51413 Mdot
.40415 .87044 Mdot
.51314 .2786 Mdot
.39735 .64395 Mdot
.81048 .53932 Mdot
.46017 .35981 Mdot
.53756 .73241 Mdot
.25257 .61746 Mdot
.54472 .17634 Mdot
.48813 .36586 Mdot
.37954 .65041 Mdot
.47153 .35631 Mdot
.54271 .698 Mdot
.49213 .38608 Mdot
.41369 .62278 Mdot
.6564 .46387 Mdot
.38542 .59592 Mdot
.56025 .68466 Mdot
.59599 .77209 Mdot
.33742 .44201 Mdot
.38405 .64687 Mdot
.37883 .46428 Mdot
.71193 .65312 Mdot
.24254 .63525 Mdot
.35696 .43055 Mdot
.782 .48525 Mdot
.62498 .5323 Mdot
.45253 .34721 Mdot
.39005 .5824 Mdot
.25793 .60686 Mdot
.48023 .56259 Mdot
.49525 .31759 Mdot
.37467 .61032 Mdot
.55641 .55008 Mdot
.79411 .50514 Mdot
.72139 .50477 Mdot
.71163 .66998 Mdot
.48428 .32381 Mdot
.38764 .65586 Mdot
.52726 .80572 Mdot
.45869 .33359 Mdot
.39911 .58355 Mdot
.40122 .43684 Mdot
.36433 .45458 Mdot
.69004 .47461 Mdot
.34332 .49056 Mdot
.37372 .59662 Mdot
.33459 .5072 Mdot
.52148 .32308 Mdot
.65951 .59075 Mdot
.51236 .65915 Mdot
.39111 .61582 Mdot
.59126 .47464 Mdot
.44207 .347 Mdot
.25094 .53148 Mdot
.72907 .40456 Mdot
.55792 .84583 Mdot
.38505 .59114 Mdot
.51809 .36675 Mdot
.49066 .33244 Mdot
.67215 .54371 Mdot
.50609 .57112 Mdot
.37436 .70687 Mdot
.75831 .5548 Mdot
.674 .59795 Mdot
.41012 .56563 Mdot
.40279 .55772 Mdot
.63093 .53938 Mdot
.6269 .49636 Mdot
.39928 .44271 Mdot
.65081 .46406 Mdot
.48585 .29928 Mdot
.69219 .47639 Mdot
.36153 .46469 Mdot
.40547 .60742 Mdot
.66462 .50289 Mdot
.55237 .69087 Mdot
.33751 .46158 Mdot
.40534 .45161 Mdot
.39054 .6082 Mdot
.51118 .31822 Mdot
.53373 .63861 Mdot
.38216 .60693 Mdot
.625 .49011 Mdot
.32667 .41136 Mdot
.59745 .47658 Mdot
.51003 .23526 Mdot
.45866 .33023 Mdot
.41313 .63518 Mdot
.52303 .32339 Mdot
.38635 .45982 Mdot
.24772 .62242 Mdot
.64042 .48049 Mdot
.40271 .58605 Mdot
.34465 .67501 Mdot
.51223 .24738 Mdot
.53604 .33082 Mdot
.28703 .44513 Mdot
.48733 .29099 Mdot
.42798 .58247 Mdot
.76112 .329 Mdot
.51312 .66977 Mdot
.42068 .59722 Mdot
.21753 .35123 Mdot
.39674 .59633 Mdot
.65423 .45538 Mdot
.64553 .44488 Mdot
.39467 .64499 Mdot
.50847 .68983 Mdot
.49555 .80517 Mdot
.44388 .58975 Mdot
.49084 .36843 Mdot
.58212 .19571 Mdot
.47913 .84681 Mdot
.33349 .4867 Mdot
.39507 .435 Mdot
.57315 .47004 Mdot
.60531 .45117 Mdot
.38683 .41638 Mdot
.39783 .47133 Mdot
.55146 .66133 Mdot
.41006 .57443 Mdot
.5407 .31001 Mdot
.35892 .48482 Mdot
.73623 .44447 Mdot
.4367 .67347 Mdot
.70111 .52371 Mdot
.56665 .54279 Mdot
.70099 .48397 Mdot
.69684 .59313 Mdot
.35842 .46476 Mdot
.62454 .44727 Mdot
.71769 .50189 Mdot
.34012 .45329 Mdot
.53697 .69755 Mdot
.29196 .40389 Mdot
.3932 .63177 Mdot
.37692 .17771 Mdot
.61185 .45144 Mdot
.65738 .45414 Mdot
.3626 .4764 Mdot
.40198 .7327 Mdot
.513 .32951 Mdot
.45698 .33583 Mdot
.36419 .60569 Mdot
.46595 .53844 Mdot
.67796 .51386 Mdot
.67805 .47079 Mdot
.39569 .6368 Mdot
.39303 .65106 Mdot
.33112 .53543 Mdot
.62051 .46069 Mdot
.38592 .43834 Mdot
.53592 .60864 Mdot
.35964 .46562 Mdot
.59429 .47527 Mdot
.65114 .45247 Mdot
.69679 .4869 Mdot
.59143 .47719 Mdot
.40893 .44267 Mdot
.62315 .44951 Mdot
.72963 .50884 Mdot
.51681 .3323 Mdot
.64617 .52179 Mdot
.69342 .59104 Mdot
.64079 .46672 Mdot
.5383 .69527 Mdot
.74266 .43898 Mdot
.65949 .51728 Mdot
.68063 .51376 Mdot
.44769 .60984 Mdot
.6536 .47458 Mdot
.35896 .41957 Mdot
.50152 .32758 Mdot
.39251 .458 Mdot
.37448 .47627 Mdot
.38795 .57483 Mdot
.56356 .67825 Mdot
.67383 .53021 Mdot
.5453 .66031 Mdot
.69694 .50871 Mdot
.61659 .52623 Mdot
.27682 .64255 Mdot
.75835 .71385 Mdot
.59732 .78406 Mdot
.63879 .48059 Mdot
.41027 .59643 Mdot
.40843 .64238 Mdot
.47449 .26982 Mdot
.71718 .51074 Mdot
.39147 .41766 Mdot
.39275 .46232 Mdot
.61971 .71378 Mdot
.29426 .70746 Mdot
.53787 .69598 Mdot
.51698 .50162 Mdot
.58665 .45329 Mdot
.60595 .46971 Mdot
.59491 .45799 Mdot
.37399 .57595 Mdot
.51432 .60594 Mdot
.4199 .59733 Mdot
.39673 .3627 Mdot
.36478 .47017 Mdot
.65523 .52096 Mdot
.54377 .39049 Mdot
.4629 .3284 Mdot
.50204 .32822 Mdot
.4067 .44 Mdot
.4256 .65535 Mdot
.57911 .74016 Mdot
.66031 .18162 Mdot
.52022 .27969 Mdot
.50779 .69718 Mdot
.68155 .48609 Mdot
.40066 .606 Mdot
.4662 .35162 Mdot
.53314 .70984 Mdot
.60476 .51091 Mdot
.36223 .69012 Mdot
.63418 .48103 Mdot
.53597 .50047 Mdot
.51052 .35757 Mdot
.33026 .23446 Mdot
.49926 .37756 Mdot
.33643 .45762 Mdot
.34493 .43621 Mdot
.64754 .44727 Mdot
.81318 .50135 Mdot
.45528 .34625 Mdot
.38517 .50387 Mdot
.53739 .65223 Mdot
.26185 .52314 Mdot
.53675 .70025 Mdot
.40323 .64137 Mdot
.51099 .681 Mdot
.41268 .62849 Mdot
.61178 .74057 Mdot
.54047 .32998 Mdot
.52721 .67051 Mdot
.46219 .6419 Mdot
.7137 .51753 Mdot
.54453 .70484 Mdot
.57723 .45436 Mdot
.54708 .22767 Mdot
.38971 .63472 Mdot
.51457 .6624 Mdot
.60847 .51312 Mdot
.15517 .50249 Mdot
.37709 .4272 Mdot
.38579 .41764 Mdot
.5807 .49101 Mdot
.39148 .56932 Mdot
.53073 .33871 Mdot
.28137 .32414 Mdot
.35342 .41402 Mdot
.66074 .44748 Mdot
.69027 .4684 Mdot
.47004 .29957 Mdot
.44356 .39704 Mdot
.64568 .4497 Mdot
.77011 .48138 Mdot
.62439 .45488 Mdot
.40142 .43317 Mdot
.46258 .3555 Mdot
.49557 .33039 Mdot
.37288 .61093 Mdot
.48191 .30523 Mdot
.51322 .26398 Mdot
.33286 .39614 Mdot
.56975 .47626 Mdot
.38593 .45381 Mdot
.37293 .37567 Mdot
.39917 .36256 Mdot
.18928 .40322 Mdot
.4665 .30029 Mdot
.69845 .47022 Mdot
.52276 .3274 Mdot
.54366 .68667 Mdot
.50684 .33753 Mdot
.52961 .35543 Mdot
.67367 .47638 Mdot
.6565 .50765 Mdot
.4123 .60683 Mdot
.50748 .5779 Mdot
.51801 .32556 Mdot
.64468 .44321 Mdot
.60658 .44374 Mdot
.5966 .44765 Mdot
.46974 .43574 Mdot
.47033 .36392 Mdot
.68354 .25081 Mdot
.60688 .62614 Mdot
.51745 .32432 Mdot
.20431 .65919 Mdot
.25863 .59763 Mdot
.41355 .65172 Mdot
.33437 .47493 Mdot
.61915 .46151 Mdot
.41057 .64414 Mdot
.65991 .50571 Mdot
.56761 .54395 Mdot
.66109 .47764 Mdot
.52796 .69824 Mdot
.59776 .44165 Mdot
.4302 .58333 Mdot
.38305 .60223 Mdot
.67151 .45319 Mdot
.66558 .49758 Mdot
.58435 .77471 Mdot
.4883 .28673 Mdot
.51295 .33406 Mdot
.37925 .72144 Mdot
.53665 .67225 Mdot
.34465 .45821 Mdot
.64054 .49917 Mdot
.38296 .57689 Mdot
.38336 .59851 Mdot
.46145 .35943 Mdot
.37992 .61964 Mdot
.35109 .45892 Mdot
.64228 .48292 Mdot
.38426 .41684 Mdot
.53391 .65771 Mdot
.47309 .36227 Mdot
.65183 .51813 Mdot
.62537 .47158 Mdot
.51393 .36495 Mdot
.65638 .5362 Mdot
.52167 .70349 Mdot
.395 .59458 Mdot
.48902 .36363 Mdot
.36962 .45621 Mdot
.40908 .63678 Mdot
.60696 .47854 Mdot
.59669 .85107 Mdot
.64886 .45639 Mdot
.61576 .46699 Mdot
.21266 .34743 Mdot
.59311 .44362 Mdot
.38755 .58529 Mdot
.46794 .30664 Mdot
.65573 .43349 Mdot
.67847 .61226 Mdot
.58742 .14508 Mdot
.41799 .59113 Mdot
.68372 .48462 Mdot
.15153 .45911 Mdot
.68223 .47154 Mdot
.7992 .44028 Mdot
.47386 .66993 Mdot
.43052 .50497 Mdot
.61217 .54561 Mdot
.35507 .44963 Mdot
.41288 .60494 Mdot
.40384 .63906 Mdot
.63402 .21733 Mdot
.67552 .47413 Mdot
.53314 .51218 Mdot
.62936 .52679 Mdot
.36265 .45892 Mdot
.61174 .69558 Mdot
.38329 .59399 Mdot
.61366 .80142 Mdot
.61644 .48739 Mdot
.47677 .37086 Mdot
.42988 .64237 Mdot
.26414 .57123 Mdot
.60317 .48331 Mdot
.54978 .66499 Mdot
.34657 .48038 Mdot
.62568 .43392 Mdot
.38213 .45292 Mdot
.59972 .48132 Mdot
.71835 .42619 Mdot
.81594 .56926 Mdot
.51408 .34858 Mdot
.39835 .43527 Mdot
.31698 .42525 Mdot
.69604 .45104 Mdot
.48945 .36511 Mdot
.50265 .32061 Mdot
.55388 .66465 Mdot
.4905 .49706 Mdot
.36384 .31911 Mdot
.71185 .37844 Mdot
.62377 .20804 Mdot
.42812 .64793 Mdot
.28757 .48091 Mdot
.60471 .49232 Mdot
.35188 .74023 Mdot
.34454 .42933 Mdot
.65852 .45734 Mdot
.55836 .25069 Mdot
.46777 .34595 Mdot
.63437 .45935 Mdot
.52752 .69379 Mdot
.38111 .74986 Mdot
.37596 .75643 Mdot
.21617 .58264 Mdot
.40528 .61651 Mdot
.63062 .41659 Mdot
.57102 .43805 Mdot
.36122 .60369 Mdot
.65358 .5329 Mdot
.3947 .58583 Mdot
.51071 .20108 Mdot
.52389 .70757 Mdot
.47674 .36786 Mdot
.26182 .59013 Mdot
.67456 .52377 Mdot
.58339 .47959 Mdot
.54931 .70878 Mdot
.62517 .50144 Mdot
.79389 .64758 Mdot
.30454 .64015 Mdot
.36949 .62058 Mdot
.51164 .34772 Mdot
.6845 .51293 Mdot
.5019 .49553 Mdot
.67188 .46305 Mdot
.67431 .33662 Mdot
.68271 .51222 Mdot
.37774 .3025 Mdot
.51466 .35761 Mdot
.3821 .45677 Mdot
.70689 .46233 Mdot
.6573 .48313 Mdot
.5612 .61238 Mdot
.60043 .53628 Mdot
.64938 .44089 Mdot
.5329 .33445 Mdot
.46251 .3474 Mdot
.49294 .35247 Mdot
.42757 .60561 Mdot
.29933 .7153 Mdot
.39173 .44543 Mdot
.70813 .4499 Mdot
.36395 .4869 Mdot
.76141 .43712 Mdot
.51632 .70444 Mdot
.17186 .48636 Mdot
.63702 .51609 Mdot
.48965 .34605 Mdot
.23771 .43444 Mdot
.5143 .3104 Mdot
.51595 .53149 Mdot
.37159 .44105 Mdot
.46693 .33989 Mdot
.65242 .48942 Mdot
.50048 .58621 Mdot
.18113 .5461 Mdot
.38339 .46646 Mdot
.69056 .52018 Mdot
.41467 .6449 Mdot
.29113 .67295 Mdot
.58064 .85435 Mdot
.38093 .42619 Mdot
.32106 .42271 Mdot
.67762 .47521 Mdot
.46299 .32376 Mdot
.35297 .45319 Mdot
.36623 .42849 Mdot
.37868 .6199 Mdot
.65453 .50963 Mdot
.65143 .51249 Mdot
.43029 .59596 Mdot
.38421 .46817 Mdot
.61245 .53851 Mdot
.62359 .44092 Mdot
.12942 .47734 Mdot
.58471 .58317 Mdot
.43076 .1434 Mdot
.52037 .27024 Mdot
.56392 .27373 Mdot
.30213 .29334 Mdot
.51972 .36665 Mdot
.66152 .51687 Mdot
.65728 .42535 Mdot
.37432 .59662 Mdot
.64722 .47107 Mdot
.35255 .59901 Mdot
.39071 .43525 Mdot
.20032 .64255 Mdot
.35044 .36449 Mdot
.5145 .1883 Mdot
.65001 .47034 Mdot
.42063 .37211 Mdot
.53247 .68384 Mdot
.41749 .42169 Mdot
.4871 .35793 Mdot
.59502 .49349 Mdot
.58427 .77652 Mdot
.42049 .59805 Mdot
.48625 .31143 Mdot
.52256 .79562 Mdot
.48982 .77091 Mdot
.59391 .47678 Mdot
.42587 .61746 Mdot
.23641 .40668 Mdot
.76392 .49467 Mdot
.39412 .40927 Mdot
.53125 .69916 Mdot
.41643 .61074 Mdot
.38242 .47204 Mdot
.55458 .35298 Mdot
.46797 .33035 Mdot
.52031 .38128 Mdot
.65074 .75527 Mdot
.36071 .61134 Mdot
.52834 .6833 Mdot
.292 .70028 Mdot
.36395 .7604 Mdot
.52634 .69719 Mdot
.43278 .60938 Mdot
.46386 .34941 Mdot
.47838 .34667 Mdot
.5006 .32712 Mdot
.59138 .80441 Mdot
.50743 .37712 Mdot
.66584 .25741 Mdot
.58847 .46102 Mdot
.6395 .40417 Mdot
.68396 .47981 Mdot
.39433 .41689 Mdot
.50574 .3635 Mdot
.45275 .53534 Mdot
.71181 .4989 Mdot
.20739 .59369 Mdot
.67437 .46051 Mdot
.41459 .42359 Mdot
.62683 .46125 Mdot
.70703 .29885 Mdot
.524 .3334 Mdot
.64142 .47641 Mdot
.37754 .41334 Mdot
.54391 .67554 Mdot
.52736 .38191 Mdot
.65558 .51627 Mdot
.29562 .34624 Mdot
.595 .44229 Mdot
.46499 .20835 Mdot
.62227 .59339 Mdot
.50787 .69722 Mdot
.65132 .57189 Mdot
.36016 .62092 Mdot
.5966 .41049 Mdot
.64215 .41105 Mdot
.37778 .46787 Mdot
.23988 .56108 Mdot
.39745 .62077 Mdot
.50946 .72498 Mdot
.69664 .43281 Mdot
.55872 .68996 Mdot
.49925 .28805 Mdot
.40396 .41955 Mdot
.62593 .53488 Mdot
.7003 .52117 Mdot
.51963 .21677 Mdot
.71887 .44977 Mdot
.69359 .47846 Mdot
.52955 .71249 Mdot
.62144 .22384 Mdot
.63597 .46831 Mdot
.51327 .5215 Mdot
.49872 .38575 Mdot
.60013 .5322 Mdot
.70659 .27758 Mdot
.6504 .444 Mdot
.4756 .31316 Mdot
.53999 .35149 Mdot
.30238 .37857 Mdot
.5483 .65643 Mdot
.67512 .51852 Mdot
.79015 .39483 Mdot
.61917 .49036 Mdot
.38542 .44045 Mdot
.60304 .45628 Mdot
.41263 .61967 Mdot
.57893 .80086 Mdot
.36932 .60266 Mdot
.67941 .50725 Mdot
.49615 .32535 Mdot
.35972 .47312 Mdot
.65155 .76815 Mdot
.4103 .6915 Mdot
.65231 .24768 Mdot
.5191 .16868 Mdot
.50732 .68049 Mdot
.56523 .68505 Mdot
.40702 .42226 Mdot
.63996 .47594 Mdot
.76568 .32202 Mdot
.59334 .52942 Mdot
.63365 .46287 Mdot
.66206 .47853 Mdot
.26164 .6621 Mdot
.3974 .44452 Mdot
.38603 .62586 Mdot
.64734 .45104 Mdot
.63079 .44544 Mdot
.52159 .36171 Mdot
.54368 .67205 Mdot
.40575 .64434 Mdot
.53052 .66471 Mdot
.40582 .60055 Mdot
.19828 .64825 Mdot
.70925 .46077 Mdot
.54188 .67661 Mdot
.33123 .45402 Mdot
.50486 .31551 Mdot
.32642 .40097 Mdot
.40233 .64104 Mdot
.37857 .59595 Mdot
.67031 .45531 Mdot
.47481 .31254 Mdot
.50427 .30839 Mdot
.54529 .68676 Mdot
.35123 .43509 Mdot
.66113 .51406 Mdot
.61038 .52112 Mdot
.44617 .2811 Mdot
.38564 .5718 Mdot
.54893 .53172 Mdot
.27445 .38735 Mdot
.63787 .47893 Mdot
.50348 .31027 Mdot
.6678 .48728 Mdot
.32106 .26548 Mdot
.46686 .31688 Mdot
.65933 .44293 Mdot
.41591 .79892 Mdot
.40663 .66963 Mdot
.32423 .34783 Mdot
.69563 .47397 Mdot
.42257 .18095 Mdot
.60937 .50452 Mdot
.1203 .50589 Mdot
.47203 .70324 Mdot
.66487 .51992 Mdot
.61007 .47846 Mdot
.66034 .37947 Mdot
.67637 .49872 Mdot
.42915 .58382 Mdot
.5571 .74954 Mdot
.53212 .34458 Mdot
.32539 .29845 Mdot
.59638 .39908 Mdot
.5308 .65217 Mdot
.36436 .60763 Mdot
.39635 .55303 Mdot
.5186 .68829 Mdot
.48592 .32655 Mdot
.63336 .48897 Mdot
.46214 .51225 Mdot
.3979 .56415 Mdot
.66656 .55126 Mdot
.38184 .4408 Mdot
.3017 .53232 Mdot
.42302 .66095 Mdot
.37489 .45732 Mdot
.64014 .5231 Mdot
.66297 .38276 Mdot
.69785 .70583 Mdot
.29893 .25279 Mdot
.37284 .47788 Mdot
.37577 .47175 Mdot
.57193 .81205 Mdot
.51962 .65364 Mdot
.53785 .20713 Mdot
.38413 .29264 Mdot
.35099 .46589 Mdot
.74361 .53959 Mdot
.41419 .58049 Mdot
.30534 .34061 Mdot
.44636 .36236 Mdot
.58652 .4828 Mdot
.6537 .48731 Mdot
.34784 .43758 Mdot
.50114 .25078 Mdot
.8112 .5613 Mdot
.37679 .46499 Mdot
.73785 .49157 Mdot
.46232 .45602 Mdot
.25816 .60011 Mdot
.39737 .57336 Mdot
.55202 .65955 Mdot
.51736 .72025 Mdot
.49342 .37149 Mdot
.56044 .66835 Mdot
.37147 .74686 Mdot
.62989 .50638 Mdot
.36868 .4656 Mdot
.25354 .53033 Mdot
.36963 .45278 Mdot
.51901 .68544 Mdot
.50897 .69967 Mdot
.51661 .33215 Mdot
.5122 .33605 Mdot
.5748 .29512 Mdot
.63078 .67639 Mdot
.67966 .46519 Mdot
.20111 .51932 Mdot
.5209 .32176 Mdot
.5863 .54928 Mdot
.56364 .68681 Mdot
.54095 .67296 Mdot
.58299 .60808 Mdot
.64346 .51065 Mdot
.79326 .41628 Mdot
.64266 .50554 Mdot
.61654 .68999 Mdot
.69457 .50514 Mdot
.37912 .61964 Mdot
.64467 .51531 Mdot
.54201 .63544 Mdot
.62301 .53583 Mdot
.61544 .44627 Mdot
.38344 .57015 Mdot
.63416 .43248 Mdot
.41152 .62179 Mdot
.68609 .49717 Mdot
.53306 .64986 Mdot
.37182 .58328 Mdot
.68586 .62911 Mdot
.49478 .62062 Mdot
.43111 .6222 Mdot
.55949 .67932 Mdot
.52146 .65597 Mdot
.72334 .60278 Mdot
.48603 .35825 Mdot
.47195 .38544 Mdot
.6422 .47281 Mdot
.35474 .59592 Mdot
.3983 .43984 Mdot
.62485 .4496 Mdot
.62032 .4291 Mdot
.68779 .45945 Mdot
.48405 .37087 Mdot
.36707 .70383 Mdot
.54484 .68108 Mdot
.42767 .59822 Mdot
.58087 .664 Mdot
.40778 .56918 Mdot
.72236 .47915 Mdot
.64781 .42028 Mdot
.56348 .30225 Mdot
.2291 .49197 Mdot
.55446 .82705 Mdot
.46889 .32535 Mdot
.38049 .64337 Mdot
.51742 .65625 Mdot
.61659 .55812 Mdot
.48487 .35046 Mdot
.41346 .62243 Mdot
.63449 .48184 Mdot
.69265 .51777 Mdot
.39642 .38188 Mdot
.57184 .42158 Mdot
.64914 .6057 Mdot
.40908 .57105 Mdot
.3768 .64771 Mdot
.35955 .75443 Mdot
.54924 .74692 Mdot
.47184 .55285 Mdot
.66558 .46638 Mdot
.54775 .66333 Mdot
.46616 .35139 Mdot
.67505 .73097 Mdot
.35507 .42744 Mdot
.50658 .57499 Mdot
.6489 .47177 Mdot
.4188 .5141 Mdot
.49737 .3245 Mdot
.53173 .69482 Mdot
.34632 .4397 Mdot
.53665 .7175 Mdot
.3624 .59157 Mdot
.61888 .17744 Mdot
.62089 .49464 Mdot
.67877 .46046 Mdot
.33556 .44423 Mdot
.47033 .35071 Mdot
.55036 .71062 Mdot
.48901 .22598 Mdot
.38138 .63511 Mdot
.77974 .34075 Mdot
.48508 .30249 Mdot
.70136 .30703 Mdot
.42653 .59103 Mdot
.40631 .44224 Mdot
.71123 .61949 Mdot
.36093 .46369 Mdot
.68328 .50611 Mdot
.49381 .33786 Mdot
.38106 .42958 Mdot
.53105 .58547 Mdot
.1532 .47864 Mdot
.71986 .33576 Mdot
.63504 .5024 Mdot
.15883 .54155 Mdot
.41502 .22171 Mdot
.49377 .28303 Mdot
.33904 .4554 Mdot
.66834 .45906 Mdot
.65167 .53134 Mdot
.61986 .4865 Mdot
.36917 .43647 Mdot
.27353 .62612 Mdot
.38985 .63638 Mdot
.68122 .47702 Mdot
.54982 .66051 Mdot
.4062 .6249 Mdot
.26074 .58779 Mdot
.3838 .58818 Mdot
.47534 .29022 Mdot
.60279 .45505 Mdot
.41581 .45531 Mdot
.14443 .57837 Mdot
.3908 .46055 Mdot
.43309 .61676 Mdot
.61053 .45677 Mdot
.24438 .52521 Mdot
.4911 .35164 Mdot
.3763 .62847 Mdot
.65821 .45455 Mdot
.2698 .59838 Mdot
.59734 .77581 Mdot
.38377 .58919 Mdot
.47886 .35376 Mdot
.26183 .31709 Mdot
.64895 .46658 Mdot
.61091 .50286 Mdot
.47196 .34234 Mdot
.67338 .39669 Mdot
.52798 .80179 Mdot
.66663 .49324 Mdot
.38055 .45781 Mdot
.75617 .2809 Mdot
.65732 .43629 Mdot
.59654 .63626 Mdot
.41412 .60819 Mdot
.2991 .36539 Mdot
.55601 .54618 Mdot
.5942 .55135 Mdot
.47557 .2367 Mdot
.50418 .42398 Mdot
.19578 .60594 Mdot
.35471 .61448 Mdot
.49256 .75474 Mdot
.19215 .61298 Mdot
.39988 .41423 Mdot
.49717 .40266 Mdot
.44106 .24737 Mdot
.66003 .78695 Mdot
.26046 .32987 Mdot
.425 .749 Mdot
.58022 .77946 Mdot
.45385 .48831 Mdot
.40228 .59574 Mdot
.49226 .67745 Mdot
.65888 .51109 Mdot
.41274 .22107 Mdot
.77607 .39346 Mdot
.8243 .51908 Mdot
.15521 .53255 Mdot
.78906 .43262 Mdot
.1695 .50252 Mdot
.19679 .38942 Mdot
.5475 .26884 Mdot
.23339 .47256 Mdot
.7936 .35504 Mdot
.40546 .7892 Mdot
.64445 .2083 Mdot
.57193 .44854 Mdot
.52526 .53665 Mdot
.48146 .19264 Mdot
.66871 .27614 Mdot
.80036 .51584 Mdot
.37152 .61174 Mdot
.46472 .30939 Mdot
.42957 .25108 Mdot
.51074 .29711 Mdot
.32526 .48355 Mdot
.27063 .29852 Mdot
.15102 .44922 Mdot
.70849 .29601 Mdot
.39368 .18 Mdot
.57604 .24997 Mdot
.84485 .62603 Mdot
.43283 .57414 Mdot
.4591 .36071 Mdot
.56059 .72165 Mdot
.34874 .75144 Mdot
.40157 .33753 Mdot
.43628 .23609 Mdot
.28465 .65572 Mdot
.6784 .6657 Mdot
.48707 .33162 Mdot
.64609 .57644 Mdot
.33421 .4992 Mdot
.35941 .3641 Mdot
.55329 .75433 Mdot
.21677 .36888 Mdot
.47665 .52637 Mdot
.30613 .32982 Mdot
.29495 .50715 Mdot
.58246 .84967 Mdot
.61327 .6194 Mdot
.54362 .29637 Mdot
.3445 .39889 Mdot
.31086 .27641 Mdot
.70114 .75221 Mdot
.63861 .69299 Mdot
.3536 .75454 Mdot
.30407 .74662 Mdot
.38463 .21921 Mdot
.35835 .80625 Mdot
.48305 .38743 Mdot
.6932 .47424 Mdot
.58434 .38539 Mdot
.78441 .38389 Mdot
.49593 .66782 Mdot
.22336 .58768 Mdot
.52227 .65878 Mdot
.45587 .30224 Mdot
.56786 .79774 Mdot
.68448 .2703 Mdot
.79435 .39171 Mdot
.56457 .70068 Mdot
.68203 .43793 Mdot
.81117 .2978 Mdot
.19424 .59099 Mdot
.32125 .36764 Mdot
.12538 .48434 Mdot
.44248 .53643 Mdot
.68722 .58305 Mdot
.37981 .43055 Mdot
.17621 .59661 Mdot
.48312 .34262 Mdot
.28847 .76659 Mdot
.13898 .53775 Mdot
.79474 .57804 Mdot
.50624 .08849 Mdot
.33357 .71956 Mdot
.42871 .51076 Mdot
.4838 .41696 Mdot
.65807 .62752 Mdot
.79477 .62387 Mdot
.79132 .55382 Mdot
.25054 .50701 Mdot
.49759 .17226 Mdot
.17884 .58893 Mdot
.77968 .36099 Mdot
.62718 .1872 Mdot
.67913 .77666 Mdot
.51012 .47734 Mdot
.43828 .35789 Mdot
.43822 .57034 Mdot
.21135 .41341 Mdot
.24999 .69886 Mdot
.60137 .62452 Mdot
.61369 .1481 Mdot
.56517 .65031 Mdot
.46098 .70188 Mdot
.27741 .27534 Mdot
.69571 .65358 Mdot
.63051 .58325 Mdot
.49945 .79381 Mdot
.67307 .54687 Mdot
.47098 .78925 Mdot
.18728 .49388 Mdot
.31038 .42145 Mdot
.41175 .78808 Mdot
.25613 .36771 Mdot
.50806 .22208 Mdot
.65179 .36351 Mdot
.34636 .75585 Mdot
.52308 .31756 Mdot
.65533 .67243 Mdot
.61252 .58532 Mdot
.14452 .45185 Mdot
.32131 .42365 Mdot
.16413 .39399 Mdot
.53956 .79086 Mdot
.70244 .46659 Mdot
.60209 .41606 Mdot
.73358 .5129 Mdot
.63744 .66452 Mdot
.6278 .43812 Mdot
.40469 .36061 Mdot
.17316 .40511 Mdot
.56511 .23834 Mdot
.29272 .43502 Mdot
.24094 .57167 Mdot
.2911 .25633 Mdot
.57951 .34706 Mdot
.53268 .75781 Mdot
.5965 .70252 Mdot
.64086 .81461 Mdot
.39492 .62419 Mdot
.77153 .34503 Mdot
.40444 .41028 Mdot
.62411 .75837 Mdot
.72213 .38247 Mdot
.783 .6283 Mdot
.17388 .4036 Mdot
.45768 .76936 Mdot
.56301 .78429 Mdot
.7231 .64156 Mdot
.75786 .30028 Mdot
.23599 .58039 Mdot
.67374 .42335 Mdot
.38185 .24861 Mdot
.50668 .68664 Mdot
.59804 .33248 Mdot
.70757 .25623 Mdot
.42324 .71913 Mdot
.57824 .47237 Mdot
.73861 .67132 Mdot
.32604 .64302 Mdot
.50032 .58397 Mdot
.45347 .85543 Mdot
.7105 .51794 Mdot
.30151 .70663 Mdot
.40473 .21192 Mdot
.63387 .63539 Mdot
.30611 .2635 Mdot
.28466 .33173 Mdot
.33546 .78715 Mdot
.13637 .51457 Mdot
.39736 .69694 Mdot
.20838 .6328 Mdot
.13582 .46085 Mdot
.36832 .8034 Mdot
.69634 .42247 Mdot
.33673 .43381 Mdot
.52117 .88473 Mdot
.42223 .57661 Mdot
.26016 .67039 Mdot
.62474 .20865 Mdot
.27508 .59465 Mdot
.54523 .32141 Mdot
.56093 .47392 Mdot
.45967 .49561 Mdot
.48916 .28244 Mdot
.62844 .43504 Mdot
.47903 .84317 Mdot
.34354 .78056 Mdot
.4214 .83412 Mdot
.41289 .19658 Mdot
.20793 .64358 Mdot
.4304 .48244 Mdot
.67616 .27459 Mdot
.46661 .27631 Mdot
.59047 .48801 Mdot
.47712 .65291 Mdot
.33256 .71719 Mdot
.73389 .6808 Mdot
.39671 .32343 Mdot
.49404 .28697 Mdot
.20773 .54836 Mdot
.85385 .66912 Mdot
.57933 .26691 Mdot
.70672 .27258 Mdot
.37124 .75678 Mdot
.62632 .66467 Mdot
.20525 .43752 Mdot
.78883 .60408 Mdot
.20523 .36077 Mdot
.49645 .27944 Mdot
.62777 .20455 Mdot
.43657 .7423 Mdot
.74662 .55443 Mdot
.35883 .70015 Mdot
.16217 .45256 Mdot
.44057 .42166 Mdot
.69883 .72594 Mdot
.39317 .27298 Mdot
.80192 .56995 Mdot
.48007 .69584 Mdot
.3075 .53207 Mdot
.71402 .26099 Mdot
.26921 .44731 Mdot
.61123 .66193 Mdot
.47048 .46889 Mdot
.64952 .5638 Mdot
.50213 .42332 Mdot
.61086 .65175 Mdot
.72625 .57674 Mdot
.23673 .66911 Mdot
.1027 .51973 Mdot
.55461 .83911 Mdot
.37054 .18455 Mdot
.19548 .47865 Mdot
.58749 .49938 Mdot
.24955 .29182 Mdot
.38326 .82721 Mdot
.12933 .53139 Mdot
.32546 .57458 Mdot
.35256 .58552 Mdot
.37214 .48873 Mdot
.51144 .82899 Mdot
.34084 .67875 Mdot
.23704 .32598 Mdot
.48368 .79764 Mdot
.34999 .48796 Mdot
.76724 .70343 Mdot
.32908 .76366 Mdot
.73069 .37607 Mdot
.56604 .42947 Mdot
.63607 .54647 Mdot
.7334 .32625 Mdot
.49358 .28991 Mdot
.29118 .48217 Mdot
.63883 .68073 Mdot
.3883 .61201 Mdot
.47951 .66493 Mdot
.42543 .23497 Mdot
.59691 .44215 Mdot
.5282 .41575 Mdot
.45872 .31418 Mdot
.23106 .48612 Mdot
.3433 .38383 Mdot
.23491 .69105 Mdot
.32141 .69714 Mdot
.62764 .55308 Mdot
.62854 .63328 Mdot
.35233 .70181 Mdot
.52457 .80782 Mdot
.41198 .44176 Mdot
.15377 .51405 Mdot
.52569 .55553 Mdot
.65235 .6732 Mdot
.75168 .35374 Mdot
.51719 .23387 Mdot
.61087 .42576 Mdot
.25919 .40627 Mdot
.65635 .32673 Mdot
.50927 .5829 Mdot
.43865 .34451 Mdot
.43945 .36824 Mdot
.26912 .25909 Mdot
.38881 .75343 Mdot
.29092 .51382 Mdot
.15819 .50015 Mdot
.36243 .44719 Mdot
.51753 .32088 Mdot
.48551 .64557 Mdot
.49485 .21808 Mdot
.66819 .30817 Mdot
.59765 .77616 Mdot
.29747 .62864 Mdot
.43678 .71483 Mdot
.16408 .50341 Mdot
.16044 .52922 Mdot
.83313 .49133 Mdot
.53539 .32783 Mdot
.5278 .25632 Mdot
.5472 .20028 Mdot
.48494 .2943 Mdot
.46893 .25001 Mdot
.41465 .33804 Mdot
.23885 .68502 Mdot
.3512 .49508 Mdot
.48429 .16953 Mdot
.69327 .59988 Mdot
.2625 .62059 Mdot
.64612 .77249 Mdot
.71864 .26492 Mdot
.1632 .48776 Mdot
.75735 .50615 Mdot
.72198 .39342 Mdot
.56909 .46426 Mdot
.54129 .45425 Mdot
.64129 .82933 Mdot
.49249 .62739 Mdot
.70462 .30789 Mdot
.25788 .35661 Mdot
.62798 .49312 Mdot
.5539 .8449 Mdot
.46976 .2251 Mdot
.56972 .81549 Mdot
.35153 .48443 Mdot
.62019 .51914 Mdot
.60785 .52613 Mdot
.59146 .64996 Mdot
.30578 .37106 Mdot
.2731 .69839 Mdot
.70928 .24934 Mdot
.23616 .39433 Mdot
.77567 .39379 Mdot
.29917 .70116 Mdot
.23405 .34139 Mdot
.40506 .22366 Mdot
.49493 .50851 Mdot
.33451 .71412 Mdot
.70545 .63778 Mdot
.39213 .18361 Mdot
.55978 .59999 Mdot
.43023 .42465 Mdot
.4189 .30852 Mdot
.27764 .36982 Mdot
.66808 .74445 Mdot
.59686 .48838 Mdot
.52243 .79564 Mdot
.20476 .37952 Mdot
.81926 .45135 Mdot
.76113 .68448 Mdot
.53373 .84507 Mdot
.68529 .34859 Mdot
.27815 .35546 Mdot
.40578 .22976 Mdot
.8092 .35091 Mdot
.53524 .55958 Mdot
.20047 .57018 Mdot
.71217 .63824 Mdot
.16138 .50131 Mdot
.34069 .42811 Mdot
.39921 .28337 Mdot
.24249 .57738 Mdot
.22044 .65123 Mdot
.59457 .36544 Mdot
.17432 .43263 Mdot
.43736 .52083 Mdot
.313 .77534 Mdot
.261 .45117 Mdot
.45006 .47697 Mdot
.37233 .63217 Mdot
.45159 .77233 Mdot
.18058 .4883 Mdot
.21655 .48778 Mdot
.71622 .26709 Mdot
.38421 .65615 Mdot
.48777 .6679 Mdot
.75393 .38912 Mdot
.69818 .67915 Mdot
.26432 .38009 Mdot
.62908 .63331 Mdot
.16577 .43147 Mdot
.58667 .66682 Mdot
.53883 .78169 Mdot
.29724 .69233 Mdot
.58968 .1656 Mdot
.31956 .36578 Mdot
.41044 .76952 Mdot
.45639 .22854 Mdot
.46183 .68944 Mdot
.73346 .55118 Mdot
.12337 .65228 Mdot
.57774 .17641 Mdot
.24677 .46156 Mdot
.25062 .69913 Mdot
.32175 .25772 Mdot
.23245 .4907 Mdot
.78916 .63384 Mdot
.58264 .58148 Mdot
.59205 .75197 Mdot
.66084 .47883 Mdot
.43522 .84674 Mdot
.67501 .68368 Mdot
.27027 .7239 Mdot
.26076 .27804 Mdot
.73563 .33352 Mdot
.60431 .43933 Mdot
.42514 .59958 Mdot
.30829 .45521 Mdot
.6739 .70783 Mdot
.65722 .38761 Mdot
.66971 .57933 Mdot
.30309 .64296 Mdot
.36099 .60501 Mdot
.36938 .71224 Mdot
.50404 .27423 Mdot
.31493 .66659 Mdot
.2737 .38427 Mdot
.39712 .67191 Mdot
.48803 .53813 Mdot
.61689 .65281 Mdot
.56666 .55459 Mdot
.72793 .37186 Mdot
.77155 .6439 Mdot
.51004 .45016 Mdot
.38392 .58606 Mdot
.7016 .37141 Mdot
.51082 .179 Mdot
.23977 .40561 Mdot
.29656 .73962 Mdot
.4917 .78397 Mdot
.73541 .41034 Mdot
.60632 .65432 Mdot
.8019 .60762 Mdot
.7932 .47577 Mdot
.21804 .52668 Mdot
.54617 .49541 Mdot
.78318 .47948 Mdot
.38871 .25341 Mdot
.19586 .63708 Mdot
.64123 .20763 Mdot
.57949 .19348 Mdot
.46221 .62349 Mdot
.65759 .27554 Mdot
.75139 .36503 Mdot
.6918 .62244 Mdot
.48224 .56355 Mdot
.82691 .65475 Mdot
.4534 .37284 Mdot
.68466 .82082 Mdot
.39749 .43044 Mdot
.68592 .77889 Mdot
.7184 .62338 Mdot
.47133 .46325 Mdot
.47248 .56734 Mdot
.26296 .40689 Mdot
.38105 .30158 Mdot
.43291 .19039 Mdot
.81528 .51654 Mdot
.40179 .56729 Mdot
.71192 .24744 Mdot
.60208 .16354 Mdot
.67941 .37731 Mdot
.68325 .44071 Mdot
.57164 .17349 Mdot
.35917 .63173 Mdot
.73482 .68083 Mdot
.30758 .25762 Mdot
.21641 .46484 Mdot
.73348 .44464 Mdot
.63027 .66849 Mdot
.19693 .561 Mdot
.1434 .5028 Mdot
.78212 .6742 Mdot
.1878 .49329 Mdot
.33773 .4331 Mdot
.43891 .48186 Mdot
.18068 .43797 Mdot
.65638 .59341 Mdot
.32144 .315 Mdot
.63655 .58721 Mdot
.76747 .74838 Mdot
.24557 .65383 Mdot
.27155 .69631 Mdot
.6338 .59204 Mdot
.51232 .37738 Mdot
.29529 .40515 Mdot
.62458 .58323 Mdot
.22554 .45554 Mdot
.48136 .19845 Mdot
.6168 .5842 Mdot
.84029 .43053 Mdot
.54334 .2287 Mdot
.34009 .60849 Mdot
.76099 .38398 Mdot
.55187 .2391 Mdot
.34717 .48354 Mdot
.56001 .75325 Mdot
.25076 .36377 Mdot
.3342 .45087 Mdot
.2617 .38596 Mdot
.29658 .34999 Mdot
.56503 .21965 Mdot
.68063 .31591 Mdot
.22503 .41632 Mdot
.63141 .38045 Mdot
.49541 .4051 Mdot
.66797 .73532 Mdot
.42388 .64568 Mdot
.25111 .35157 Mdot
.37929 .63662 Mdot
.56598 .53162 Mdot
.51404 .57851 Mdot
.74754 .44702 Mdot
.53816 .83301 Mdot
.50664 .67998 Mdot
.45865 .35193 Mdot
.70279 .77409 Mdot
.48294 .29798 Mdot
.45891 .84365 Mdot
.78614 .61736 Mdot
.75228 .35248 Mdot
.41184 .69628 Mdot
.40417 .7236 Mdot
.85759 .53303 Mdot
.51011 .41348 Mdot
.45453 .61651 Mdot
.47227 .40621 Mdot
.46429 .36232 Mdot
.30434 .6898 Mdot
.3801 .57527 Mdot
.55931 .57217 Mdot
.41129 .49461 Mdot
.43085 .378 Mdot
.53565 .31423 Mdot
.5203 .56201 Mdot
.60607 .72922 Mdot
.23344 .67592 Mdot
.39999 .58677 Mdot
.73711 .76358 Mdot
.61641 .42721 Mdot
.63767 .35855 Mdot
.20482 .35781 Mdot
.77795 .68834 Mdot
.40964 .55621 Mdot
.61423 .16222 Mdot
.693 .51078 Mdot
.21227 .43359 Mdot
.48194 .3366 Mdot
.59958 .19508 Mdot
.51061 .67282 Mdot
.64143 .63265 Mdot
.38386 .48275 Mdot
.69471 .72981 Mdot
.30906 .6313 Mdot
.52742 .36954 Mdot
.20169 .49136 Mdot
.53234 .25323 Mdot
.36502 .29145 Mdot
.38861 .72086 Mdot
.69261 .37937 Mdot
.67458 .30746 Mdot
.53848 .32185 Mdot
.25408 .68111 Mdot
.60629 .19389 Mdot
.18581 .6418 Mdot
.72009 .52928 Mdot
.48783 .76493 Mdot
.42557 .30147 Mdot
.24869 .40739 Mdot
.54012 .48832 Mdot
.18994 .38195 Mdot
.64709 .68528 Mdot
.42322 .33953 Mdot
.61691 .68195 Mdot
.57446 .52952 Mdot
.48422 .51586 Mdot
.30746 .50235 Mdot
.82809 .53341 Mdot
.53489 .49588 Mdot
.71835 .74086 Mdot
.54738 .50575 Mdot
.31068 .71871 Mdot
.51982 .27771 Mdot
.36913 .56365 Mdot
.67103 .28419 Mdot
.31837 .42529 Mdot
.19068 .62401 Mdot
.1948 .3744 Mdot
.41171 .45505 Mdot
.29721 .67289 Mdot
.30362 .28454 Mdot
.62952 .5566 Mdot
.41771 .50228 Mdot
.69329 .48627 Mdot
.49458 .25883 Mdot
.78188 .69113 Mdot
.23645 .43556 Mdot
.66182 .41852 Mdot
.19458 .60689 Mdot
.17281 .58532 Mdot
.29924 .75904 Mdot
.77118 .32487 Mdot
.51572 .36934 Mdot
.39862 .81829 Mdot
.67895 .57555 Mdot
.13824 .47602 Mdot
.21679 .51669 Mdot
.25595 .27163 Mdot
.70389 .38713 Mdot
.27039 .34156 Mdot
.80272 .54203 Mdot
.34966 .31828 Mdot
.37029 .22612 Mdot
.44937 .44569 Mdot
.28077 .51269 Mdot
.3472 .23379 Mdot
.84995 .39146 Mdot
.54792 .468 Mdot
.30021 .33879 Mdot
.41137 .25488 Mdot
.24661 .35957 Mdot
.48557 .72202 Mdot
.60287 .45683 Mdot
.25119 .54192 Mdot
.6125 .7843 Mdot
.61403 .63897 Mdot
.48879 .66218 Mdot
.48263 .71881 Mdot
.63725 .7357 Mdot
.61653 .70259 Mdot
.64416 .20761 Mdot
.70761 .38505 Mdot
.54814 .54963 Mdot
.69748 .45244 Mdot
.53368 .29592 Mdot
.55947 .66086 Mdot
.33795 .58534 Mdot
.68895 .48997 Mdot
.35648 .58306 Mdot
.36447 .29882 Mdot
.51477 .84619 Mdot
.30104 .42276 Mdot
.46532 .21766 Mdot
.44579 .35482 Mdot
.28812 .38201 Mdot
.54571 .38782 Mdot
.621 .798 Mdot
.48058 .74647 Mdot
.6014 .62432 Mdot
.18364 .56945 Mdot
.40788 .78619 Mdot
.5256 .22523 Mdot
.40914 .7997 Mdot
.34086 .43418 Mdot
.73168 .45664 Mdot
.41928 .26785 Mdot
.36475 .71917 Mdot
.44438 .31568 Mdot
.26823 .34701 Mdot
.45148 .62467 Mdot
.40573 .7729 Mdot
.39773 .21323 Mdot
.5254 .24312 Mdot
.75625 .40221 Mdot
.16255 .54018 Mdot
.41703 .5895 Mdot
.58 .18671 Mdot
.32382 .30593 Mdot
.4747 .75549 Mdot
.30134 .72175 Mdot
.21995 .67298 Mdot
.45595 .5417 Mdot
.68027 .65298 Mdot
.6118 .49454 Mdot
.68332 .25094 Mdot
.24542 .42855 Mdot
.60702 .40476 Mdot
.31477 .5739 Mdot
.49563 .3078 Mdot
.32306 .53158 Mdot
.53037 .53823 Mdot
.61078 .74421 Mdot
.50598 .29132 Mdot
.78517 .40045 Mdot
.54607 .6489 Mdot
.43536 .53877 Mdot
.63651 .4348 Mdot
.66908 .64462 Mdot
.79421 .38131 Mdot
.72949 .48916 Mdot
.19228 .46268 Mdot
.70895 .37987 Mdot
.50672 .21661 Mdot
.22269 .43475 Mdot
.22006 .53384 Mdot
.37519 .30703 Mdot
.69013 .3037 Mdot
.31862 .60337 Mdot
.68933 .46202 Mdot
.37492 .55975 Mdot
.50721 .30607 Mdot
.28159 .28929 Mdot
.67855 .3417 Mdot
.68624 .63186 Mdot
.48364 .45647 Mdot
.55418 .39223 Mdot
.48667 .43655 Mdot
.2357 .31006 Mdot
.34991 .31955 Mdot
.63857 .68417 Mdot
.33252 .48707 Mdot
.7151 .6245 Mdot
.77908 .64009 Mdot
.15085 .56105 Mdot
.80119 .59294 Mdot
.46243 .5219 Mdot
.72863 .73373 Mdot
.26679 .43619 Mdot
.31239 .25401 Mdot
.62993 .69657 Mdot
.45711 .55708 Mdot
.50392 .64209 Mdot
.40375 .38365 Mdot
.5034 .47774 Mdot
.51202 .62752 Mdot
.56895 .56962 Mdot
.29437 .58067 Mdot
.35226 .51442 Mdot
.56189 .4764 Mdot
.26223 .66762 Mdot
.17422 .55574 Mdot
.61012 .20071 Mdot
.50521 .43071 Mdot
.52224 .74083 Mdot
.6328 .72858 Mdot
.32636 .19357 Mdot
.59331 .85099 Mdot
.61329 .49459 Mdot
.51151 .43202 Mdot
.66136 .65726 Mdot
.4123 .57077 Mdot
.60037 .57157 Mdot
.54103 .39821 Mdot
.40309 .44564 Mdot
.48951 .63726 Mdot
.42653 .783 Mdot
.26645 .40725 Mdot
.71391 .66406 Mdot
.25365 .58351 Mdot
.51211 .84965 Mdot
.48313 .1865 Mdot
.24511 .4174 Mdot
.27171 .23676 Mdot
.3352 .50743 Mdot
.44785 .38443 Mdot
.5741 .38554 Mdot
.24106 .68087 Mdot
.63012 .62614 Mdot
.644 .75649 Mdot
.22854 .55815 Mdot
.64002 .69112 Mdot
.71094 .56585 Mdot
.29963 .698 Mdot
.32297 .54248 Mdot
.46694 .48877 Mdot
.40652 .72536 Mdot
.36579 .78064 Mdot
.77614 .41402 Mdot
.18487 .55376 Mdot
.62319 .78385 Mdot
.83381 .39153 Mdot
.17687 .60029 Mdot
.48105 .65495 Mdot
.50273 .73704 Mdot
.57959 .3826 Mdot
.67781 .59701 Mdot
.74801 .53167 Mdot
.72776 .69128 Mdot
.65542 .3008 Mdot
.37044 .69083 Mdot
.6793 .7662 Mdot
.61094 .66056 Mdot
.55463 .23504 Mdot
.45858 .55762 Mdot
.71809 .36948 Mdot
.3078 .67957 Mdot
.61615 .59612 Mdot
.54144 .59802 Mdot
.66932 .61137 Mdot
.69573 .37337 Mdot
.48084 .23746 Mdot
.30307 .30314 Mdot
.85651 .44763 Mdot
.21602 .55625 Mdot
.63235 .79472 Mdot
.59102 .45516 Mdot
.20523 .67196 Mdot
.30606 .30916 Mdot
.2251 .56088 Mdot
.4404 .20392 Mdot
.34496 .58491 Mdot
.42596 .34764 Mdot
.68859 .46122 Mdot
.19299 .51732 Mdot
.71099 .31502 Mdot
.5563 .25625 Mdot
.68034 .74602 Mdot
.63243 .64544 Mdot
.54032 .76359 Mdot
.69729 .61226 Mdot
.73538 .48957 Mdot
.468 .31009 Mdot
.40913 .83 Mdot
.44728 .51953 Mdot
.55519 .51104 Mdot
.64665 .40335 Mdot
.8013 .54872 Mdot
.52066 .16106 Mdot
.7325 .51337 Mdot
.38435 .77455 Mdot
.78669 .43718 Mdot
.75802 .46748 Mdot
.5897 .55742 Mdot
.39886 .11507 Mdot
.10959 .50908 Mdot
.53177 .35597 Mdot
.71694 .27931 Mdot
.79037 .4374 Mdot
.2351 .66913 Mdot
.44117 .74182 Mdot
.33014 .58792 Mdot
.78728 .53178 Mdot
.70651 .58066 Mdot
.67444 .43058 Mdot
.41405 .20849 Mdot
.14478 .54486 Mdot
.68257 .74997 Mdot
.19065 .60186 Mdot
.58062 .43185 Mdot
.70181 .44039 Mdot
.38299 .14981 Mdot
.17729 .44983 Mdot
.66363 .54885 Mdot
.80666 .54317 Mdot
.43902 .35863 Mdot
.66044 .50089 Mdot
.24385 .61667 Mdot
.70423 .24482 Mdot
.60845 .66053 Mdot
.22133 .65242 Mdot
.52049 .30704 Mdot
.45005 .59497 Mdot
.40547 .44159 Mdot
.47579 .56616 Mdot
.70561 .49731 Mdot
.37041 .43305 Mdot
.75874 .4568 Mdot
.26946 .33424 Mdot
.37653 .49652 Mdot
.64844 .20195 Mdot
.18537 .35928 Mdot
.69746 .34818 Mdot
.3849 .38598 Mdot
.63373 .55868 Mdot
.54538 .23564 Mdot
.66415 .71721 Mdot
.46423 .27484 Mdot
.33348 .23898 Mdot
.19479 .71528 Mdot
.28395 .52623 Mdot
.5825 .74276 Mdot
.47256 .28224 Mdot
.54517 .54083 Mdot
.73758 .36728 Mdot
.41284 .52741 Mdot
.41569 .5993 Mdot
.58065 .50605 Mdot
.73233 .49912 Mdot
.35622 .48299 Mdot
.67774 .8199 Mdot
.60341 .46226 Mdot
.57341 .55419 Mdot
.13984 .47731 Mdot
.66689 .73646 Mdot
.61901 .35703 Mdot
.6679 .5384 Mdot
.36805 .36391 Mdot
.45632 .55689 Mdot
.23069 .36519 Mdot
.53532 .78298 Mdot
.20755 .61587 Mdot
.67526 .33923 Mdot
.76612 .41145 Mdot
.63959 .44296 Mdot
.50406 .65993 Mdot
.31133 .33771 Mdot
.23003 .60031 Mdot
.59253 .42233 Mdot
.13555 .50206 Mdot
.3417 .59113 Mdot
.29446 .60942 Mdot
.74233 .50829 Mdot
.31763 .77215 Mdot
.72671 .7228 Mdot
.73594 .3454 Mdot
.60258 .80928 Mdot
.37617 .73534 Mdot
.69646 .67905 Mdot
.42394 .60083 Mdot
.58152 .43523 Mdot
.5265 .31664 Mdot
.51637 .85507 Mdot
.23018 .61047 Mdot
.26097 .51113 Mdot
.30715 .53538 Mdot
.66326 .24718 Mdot
.3623 .2817 Mdot
.24137 .27546 Mdot
.38947 .73281 Mdot
.52447 .84993 Mdot
.57927 .19148 Mdot
.46767 .2809 Mdot
.26981 .36149 Mdot
.72933 .46221 Mdot
.3885 .58882 Mdot
.21959 .63132 Mdot
.71386 .52831 Mdot
.57281 .79376 Mdot
.65219 .53642 Mdot
.55032 .82016 Mdot
.52575 .61708 Mdot
.28153 .66618 Mdot
.26251 .46062 Mdot
.78377 .64003 Mdot
.26408 .29902 Mdot
.40926 .38037 Mdot
.28966 .23253 Mdot
.26321 .31025 Mdot
.15255 .51681 Mdot
.6069 .77478 Mdot
.81088 .62977 Mdot
.2185 .49166 Mdot
.22765 .41527 Mdot
.2769 .44552 Mdot
.63408 .39272 Mdot
.44838 .77001 Mdot
.73454 .51797 Mdot
.32046 .34493 Mdot
.41804 .43634 Mdot
.38171 .88771 Mdot
.54474 .63247 Mdot
.50426 .39094 Mdot
.4139 .75702 Mdot
.16079 .5548 Mdot
.6929 .40394 Mdot
.36554 .21928 Mdot
.52562 .53913 Mdot
.67287 .42378 Mdot
.67407 .31985 Mdot
.64246 .21843 Mdot
.4659 .77779 Mdot
.86605 .55039 Mdot
.48523 .18959 Mdot
.30198 .56201 Mdot
.49181 .5269 Mdot
.48807 .29253 Mdot
.54781 .34898 Mdot
.4132 .71042 Mdot
.3643 .20884 Mdot
.26997 .33909 Mdot
.18001 .43974 Mdot
.85576 .52598 Mdot
.5339 .20536 Mdot
.23865 .6797 Mdot
.25713 .43737 Mdot
.50959 .38539 Mdot
.48222 .67292 Mdot
.36297 .65946 Mdot
.25785 .49938 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0XOooool2o`000:Kooooo000Looooo`03o`000?oooooooooo0:7ooooo0_l0
002Vooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0:kooooo0_l0002Iooooo`007?ooool00ol0003o
ooooooooo`1nooooo`;o0000;_ooool2o`0009Wooooo000Looooo`03o`000?oooooooooo07kooooo
0_l00039ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0:Gooooo0_l00007ooooo`;o0000VOooool001cooooo00?o0000ooooooooool0U_ooool2o`00
00gooooo0_l00007ooooo`;o0000VOooool001cooooo00?o0000ooooooooool0U_ooool2o`000;7o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0Sooo
ool2o`000;Sooooo000Looooo`03o`000?oooooooooo08oooooo0_l0002hooooo`007?ooool00ol0
003oooooooooo`28ooooo`;o0000_oooool001cooooo00?o0000ooooooooool0R?ooool2o`00037o
oooo0_l0002<ooooo`007?ooool00ol0003oooooooooo`1iooooo`;o0000@?ooool2o`0000Oooooo
0_l00023ooooo`007?ooool2o`0007[ooooo0_l00019ooooo`?o0000P_ooool001cooooo00?o0000
ooooooooool0aOooool2o`0008;ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0YOooool2o`0000Oooooo0ol00007ooooo`;o00002_ooool2o`0008?o
oooo000Looooo`03o`000?oooooooooo0:Cooooo0ol00007ooooo`?o00001oooool2o`0000;ooooo
0_l00002ooooo`;o00000_ooool2o`0008?ooooo000Looooo`03o`000?oooooooooo08oooooo0_l0
000<ooooo`;o00001Oooool3o`0001Gooooo0_l00002ooooo`;o00000_ooool2o`0008?ooooo000L
ooooo`03o`000?oooooooooo07[ooooo0_l0000Cooooo`;o00002Oooool2o`000004ooooool0003o
0000o`0000Gooooo1?l0002Pooooo`007?ooool00ol0003oooooooooo`1jooooo`;o00007_ooool2
o`0000;ooooo1Ol00004ooooo`;o00003Oooool2o`00097ooooo000Looooo`03o`000?oooooooooo
07Oooooo0_l0000Vooooo`Co00002_ooool2o`000003ooooool0003o000000Cooooo1?l0000;oooo
o`;o0000P_ooool001cooooo00?o0000ooooooooool0Moooool2o`0000?ooooo0_l00008ooooo`;o
00000oooool4o`00017ooooo1_l00007ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o
00000oooool2o`0000Kooooo0_l00022ooooo`007?ooool00ol0003oooooooooo`1eooooo`;o0000
1Oooool2o`0000Sooooo0_l00003ooooo`Co00004Oooool6o`0000cooooo0_l00004ooooo`;o0000
0oooool2o`000003ooooool0003o0000017ooooo0_l0001dooooo`007?ooool00ol0003ooooooooo
o`1eooooo`;o00001Oooool2o`0001Cooooo0_l00005ooooo`;o00006?ooool2o`0000;ooooo1?l0
0005ooooo`;o00001_ooool2o`0000?ooooo0_l00004ooooo`;o0000M?ooool001cooooo00?o0000
ooooooooool0Poooool2o`0000;ooooo1?l00007ooooo`;o00001Oooool3o`0000Oooooo0_l00005
ooooo`;o00001?ooool2o`000003ooooool0003o000000;ooooo1?l0000=ooooo`;o00000oooool2
o`0000gooooo0_l0001[ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?oo
ool5o`0000Kooooo00?o0000ooooooooool0I_ooool2o`0001_ooooo2?l0000>ooooo`?o00001ooo
ool2o`0000Gooooo0ol00003ooooo`Co00001?ooool2o`0000Gooooo0_l0000Dooooo`;o00001Ooo
ool2o`0006_ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1Vooooo`;o00006_ooool2o`000003
ooooool0003o000001;ooooo0_l0000@ooooo`;o00001Oooool2o`0000Cooooo0ol00004ooooo`Co
00004_ooool2o`0000Gooooo0_l0001[ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooo
ooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0POooool3o`000003oooo
ool0003o000001;ooooo0_l0000Hooooo`;o00001?ooool2o`0000Cooooo1?l0000Aooooo`?o0000
L_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^
kP06ooooo`?o0000POooool2o`0001Kooooo0_l00007ooooo`;o00002_ooool3o`0000;ooooo0_l0
000=ooooo`;o00002oooool2o`0000?ooooo0ol0001booooo`0000?oooooo`000?ooool00_ooool0
0ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0K?ooool2
o`000003ooooool0003o000001[ooooo0_l0000Eooooo`;o00001_ooool7o`00017ooooo0_l00004
ooooo`;o00001Oooool2o`0007Sooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo
00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1/ooooo`;o000000?oooooo`00
0?l000000_ooool2o`0000kooooo0_l00006ooooo`;o00001_ooool4o`0001?ooooo1?l0000Ioooo
o`?o00000oooool3o`0007Wooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000
okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo07?ooooo1Ol00008ooooo`;o000000?o
ooooo`000?l000003_ooool6o`0001;ooooo0ol0000Iooooo`;o00001?ooool3o`0007Wooooo0000
1_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03
o`000?oooooooooo06Oooooo0_l00005ooooo`?o00000oooool4o`0000Gooooo0_l000000ooooooo
0000o`00000Eooooo`;o0000/?ooool001cooooo00?o0000ooooooooool0Ioooool2o`0000Gooooo
0ol0000<ooooo`;o00004?ooool2o`0000;ooooo1?l00003ooooo`;o000000?oooooo`000?l00000
1Ol000000ooooooo0000o`00000Sooooo`;o000000?oooooo`000?l00000N_ooool001cooooo00?o
0000ooooooooool0Joooool3o`0000Gooooo0_l00004ooooo`;o00001oooool2o`0000_ooooo0_l0
0002ooooo`Co00000oooool2o`000003ooooool0003o000000Go000000?oooooo`000?l000003Ooo
ool2o`0001Cooooo0_l000000ooooooo0000o`00001jooooo`007?ooool00ol0003oooooooooo`1[
ooooo`?o00001Oooool2o`0000Cooooo0_l00005ooooo`Go00007?ooool2o`0000?ooooo0_l0000<
ooooo`;o00004?ooool2o`00087ooooo000Looooo`03o`000?oooooooooo06_ooooo0_l000000ooo
oooo0000o`000003ooooo`Co00002Oooool2o`000003ooooool0003o000000?ooooo0_l0000;oooo
o`;o00001?ooool2o`0000Cooooo0_l00003ooooo`?o00001Oooool2o`0000Cooooo1?l00004oooo
o`;o00002?ooool2o`0001Wooooo0_l0001Vooooo`007?ooool00ol0003oooooooooo`1[ooooo`Go
00001Oooool2o`0000?ooooo0_l00004ooooo`;o00001_ooool2o`0000Kooooo0_l00003ooooo`;o
00001?ooool2o`0000[ooooo0_l00004ooooo`?o00001?ooool4o`0000Cooooo0_l0000Sooooo`;o
0000I_ooool001cooooo00?o0000ooooooooool0F_ooool2o`00013ooooo0ol0000;ooooo`;o0000
1?ooool2o`000003ooooool0003o000000Gooooo0_l00004ooooo`;o00000oooool2o`0000;ooooo
0_l00009ooooo`;o00000_ooool2o`0000?ooooo0_l00007ooooo`;o00003oooool2o`0000Cooooo
1?l0001hooooo`007?ooool00ol0003oooooooooo`1Eooooo`;o00000oooool2o`0000cooooo0_l0
0003ooooo`;o00005?ooool2o`000003ooooool0003o000000;ooooo0_l0000;ooooo`Co00001ooo
ool4o`0000;ooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo1Ol0000?ooooo`;o0000
1?ooool4o`0007Sooooo000Looooo`03o`000?oooooooooo05Gooooo0_l0000Aooooo`?o00003Ooo
ool2o`0000_ooooo0ol00002ooooo`;o00002oooool3o`0000Sooooo0_l00009ooooo`Go000000?o
ooooo`000?l000001?l0002@ooooo`007?ooool00ol0003oooooooooo`1Yooooo`Co00002oooool2
o`0000_ooooo0_l0000<ooooo`;o00000oooool2o`0000Oooooo0_l00004ooooo`;o00001_ooool2
o`0000?ooooo1Ol0000Kooooo`;o00003Oooool2o`0006Cooooo000Looooo`03o`000?oooooooooo
06_ooooo0_l0000Vooooo`?o000000?oooooo`000?l000002?ooool2o`0000Cooooo0_l0000[oooo
o`;o00002?ooool2o`000003ooooool0003o000000;o0000I?ooool001cooooo00?o0000oooooooo
ool0Joooool2o`0000_ooooo0_l0000Booooo`?o00001Oooool2o`000004ooooool0003o0000o`00
00Sooooo0ol00006ooooo`;o00008oooool2o`0000;ooooo0_l00008ooooo`;o000000?oooooo`00
0?l000000ol00004ooooo`;o0000GOooool001cooooo0_l0001Xooooo`;o00003oooool2o`0000ko
oooo0_l00002ooooo`?o00001_ooool5o`0000Gooooo0_l000001?oooooo0000o`000?l00006oooo
o`;o00001Oooool2o`0000?ooooo0_l0000Gooooo`;o00000_ooool2o`0000Cooooo0_l00002oooo
o`;o00000oooool3o`0000Cooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o
00000oooool3o`0000;ooooo0_l0000Booooo`;o00001Oooool2o`0000?ooooo1ol00007ooooo`Co
00001_ooool2o`0000Sooooo0_l00007ooooo`;o00000oooool2o`00027ooooo0_l00002ooooo`;o
00000oooool2o`0006Cooooo000Looooo`03o`000?oooooooooo05_ooooo3?l0000Dooooo`;o0000
1Oooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`0000Oooooo0_l0000Aooooo`?o0000
1_ooool2o`00027ooooo0_l0000<ooooo`;o0000IOooool001cooooo00?o0000ooooooooool0E?oo
ool2o`0000Gooooo0_l00002ooooo`So0000:_ooool2o`0000[ooooo0_l00009ooooo`;o00001ooo
ool2o`00027ooooo0_l00006ooooo`;o00001?ooool4o`0006?ooooo000Looooo`03o`000?oooooo
oooo05Cooooo0_l0000:ooooo`;o00000_ooool2o`000003ooooool0003o000000Cooooo0_l00000
0ooooooo0000o`00000Oooooo`;o00002_ooool2o`0000Cooooo0_l000000ooooooo0000o`00000d
ooooo`;o00001?ooool4o`000003ooooool0003o0000063ooooo000Looooo`03o`000?oooooooooo
05Wooooo1?l000000ooooooo0000o`000002o`0000;ooooo1Ol00004ooooo`;o000000?oooooo`00
0?l00000;Oooool2o`0000;ooooo0_l000000ooooooo0000o`00000@ooooo`;o00007?ooool2o`00
00Oooooo0_l00004ooooo`Co0000H?ooool001cooooo00?o0000ooooooooool0FOooool4o`000003
ooooool0003o000000Gooooo0_l00005ooooo`;o00004Oooool2o`0000?ooooo0_l0000@ooooo`;o
00001oooool2o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l000000oooool2o`0000?o
oooo0_l0000Looooo`;o00000oooool2o`0000;ooooo0_l00004ooooo`?o0000HOooool001cooooo
00?o0000ooooooooool0Coooool4o`0000oooooo0_l00006ooooo`Ko00000_ooool2o`0000?ooooo
0_l00003ooooo`;o000000?oooooo`000?l000000oooool2o`00013ooooo0_l0000=ooooo`;o0000
1?ooool2o`000003ooooool0003o000000Go00009_ooool2o`0000;ooooo0_l000000ooooooo0000
o`000005ooooo`;o00000_ooool2o`0005[ooooo000Looooo`03o`000?oooooooooo04_ooooo0_l0
0002ooooo`Co00000oooool2o`0000;ooooo0_l00005ooooo`?o000000?oooooo`000?l000000ooo
ool6o`0000;ooooo1?l000001Ooooooo0000o`000?l0003ooooo00?o00005Oooool5o`000003oooo
ool0003o000000Gooooo0_l0000>ooooo`Go00001Oooool2o`0001Kooooo0_l000001?oooooo0000
o`000?ooool2o`000003ooooool0003o000000Gooooo0_l00005ooooo`;o00000_ooool2o`0005[o
oooo000Looooo`03o`000?oooooooooo04_ooooo0_l00004ooooo`;o00000oooool2o`0000;ooooo
0_l00005ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo0_l00006ooooo`;o0000
00?oooooo`000?l000001?l000000ooooooo0000o`00000Cooooo`Go000000?oooooo`000?l00000
0_ooool5o`000003ooooool0003o000000;o00004oooool2o`0001Kooooo0_l000001?oooooo0000
o`000?ooool2o`0000Kooooo1?l000000ooooooo0000o`00001Rooooo`007?ooool00ol0003ooooo
ooooo`1?ooooo`Co00001_ooool2o`0000[ooooo0_l000000ooooooo0000o`000008ooooo`;o0000
0oooool4o`0000?ooooo0_l0000;ooooo`Co00001Oooool4o`0000?ooooo1Ol00003ooooo`Co0000
00?oooooo`000?l00000=_ooool4o`000003ooooool0003o000000Cooooo0_l00005ooooo`;o0000
EOooool001cooooo00?o0000ooooooooool0Coooool2o`0000Sooooo0_l00004ooooo`;o00004Ooo
ool2o`0000Sooooo1?l0000;ooooo`Co00001Oooool4o`0000?ooooo1?l00009ooooo`;o00003ooo
ool2o`0001_ooooo0_l0000Aooooo`Co00001Oooool2o`0005Gooooo000Looooo`03o`000?oooooo
oooo05Sooooo0_l00005ooooo`?o00000_ooool4o`0000?ooooo0_l0000<ooooo`;o000000?ooooo
o`000?l000000_l0000Cooooo`;o000000Coooooo`000?l0003ooooo1ol00008ooooo`Co00003Ooo
ool2o`0001_ooooo0_l0000Aooooo`;o0000G_ooool001cooooo00?o0000ooooooooool0COooool2
o`0000Wooooo0_l00006ooooo`;o000000?oooooo`000?l000000ol00003ooooo`;o00001_ooool2
o`0000Cooooo0_l0000:ooooo`;o00003?ooool2o`000003ooooool0003o000000_o000000?ooooo
o`000?l000000_ooool4o`0002Kooooo0_l0000@ooooo`;o0000Hoooool001cooooo00?o0000oooo
ooooool0COooool2o`0000;ooooo0_l00005ooooo`;o00001?ooool2o`0000?ooooo0_l00009oooo
o`;o00000oooool2o`0000Cooooo0_l00009ooooo`?o00004?ooool2o`000003ooooool0003o0000
00Oo000000?oooooo`000?l000000_ooool2o`0000gooooo0_l0000Iooooo`;o00002Oooool2o`00
00Gooooo0_l0000Booooo`;o0000Coooool001cooooo00?o0000ooooooooool0DOooool2o`000003
ooooool0003o000000;ooooo0_l00004ooooo`;o00000oooool5o`0000Kooooo0_l00009ooooo`;o
00001Oooool2o`0000;ooooo0ol0000=ooooo`;o000000?oooooo`000?l000001?l000000ooooooo
0000o`000004o`0000Cooooo1?l000000ooooooo0000o`000008ooooo`;o00009?ooool2o`0000?o
oooo1?l0000Booooo`;o00002_ooool2o`0004?ooooo000Looooo`;o0000C_ooool2o`0000?ooooo
1?l0000:ooooo`Co000000Coooooo`000?l0003o00002oooool2o`0000?ooooo0_l00006ooooo`;o
00001?ooool2o`0000cooooo3Ol000000ooooooo0000o`000003ooooo`;o000000Coooooo`000?l0
003ooooo0_l00005ooooo`;o00001oooool2o`0001;ooooo0_l0000?ooooo`Co00002_ooool4o`00
00Cooooo0_l0000:ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0C?ooool3o`0000?o
oooo0_l0000;ooooo`Go00001Oooool2o`0000Sooooo0_l00002ooooo`Go00002_ooool2o`0000So
oooo2Ol000000ooooooo0000o`000005o`000003ooooool0003o000000;o000000?oooooo`000?l0
00000_l00005ooooo`;o000000Coooooo`000?l0003o00001oooool2o`0001;ooooo0_l00008oooo
o`?o00001?ooool2o`0000Sooooo0_l00002ooooo`Co00000_ooool2o`00057ooooo000Looooo`03
o`000?oooooooooo04_ooooo0ol0000Aooooo`;o00001?ooool2o`0000;ooooo0_l0000:ooooo`Co
000000?oooooo`000?l000004?oooolLo`000003ooooool0003o000000Gooooo0_l000000ooooooo
0000o`000007ooooo`;o00005Oooool2o`0000;ooooo0_l00002ooooo`?o00000_ooool2o`0000[o
oooo0_l00008ooooo`;o0000DOooool001cooooo00?o0000ooooooooool0A?ooool2o`0000?ooooo
1?l00005ooooo`;o00002Oooool2o`000003ooooool0003o000000?ooooo0_l00003ooooo`?o0000
2?ooool3o`0000[ooooo1?l00004ooooo`Ko000000?oooooo`000?l000005Ol00004ooooo`;o0000
3_ooool2o`0001Gooooo1_l00007ooooo`?o0000I_ooool001cooooo00?o0000ooooooooool0A?oo
ool2o`0000?ooooo0_l00007ooooo`;o00002Oooool2o`000003ooooool0003o000000Cooooo0_l0
0002ooooo`?o00000_ooool2o`0000Kooooo0_l00009ooooo`Co00001?ooool2o`0000Cooooo5ol0
0005ooooo`;o00009oooool2o`0000[ooooo0_l00005ooooo`;o0000Goooool001cooooo00?o0000
ooooooooool0DOooool2o`0000Oooooo0_l00003ooooo`;o00001?ooool3o`0000Oooooo0_l00006
ooooo`;o00005?ooool2o`000003ooooool0003o000001Oo000000?oooooo`000?l000000_l0000Z
ooooo`?o00002?ooool2o`0000?ooooo0_l0001Oooooo`007?ooool00ol0003oooooooooo`18oooo
o`;o00001oooool2o`0000Oooooo0_l00003ooooo`?o00000oooool2o`0000Oooooo1_l0000Aoooo
o`;o00001_ooool2o`000003ooooool0003o000001Oo000000?oooooo`000?l000000_l00003oooo
o`;o000000?oooooo`000?l000001_ooool2o`0001Wooooo1?l00008ooooo`;o00001_ooool2o`00
00?ooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`18ooooo`;o00005_ooool2o`0000co
oooo1_l0000Aooooo`;o00002?oooolIo`0000;ooooo1Ol00002ooooo`;o000000?oooooo`000?l0
00001_ooool2o`0000;ooooo0_l0000Eooooo`;o00001oooool2o`0000Sooooo0ol00003ooooo`?o
00000_ooool2o`0005;ooooo000Looooo`03o`000?oooooooooo04Wooooo0ol0000<ooooo`;o0000
8oooool2o`00013ooooo8?l0000@ooooo`Co00007Oooool2o`0000Sooooo0ol00004ooooo`;o0000
0_ooool4o`00053ooooo000Looooo`03o`000?oooooooooo04Kooooo0_l000001?oooooo0000o`00
0?l0000<ooooo`;o00008oooool2o`0000oooooo7ol0000Booooo`Co00003_ooool2o`0001Oooooo
0ol00006ooooo`;o00000_ooool2o`00053ooooo000Looooo`03o`000?oooooooooo04Kooooo0_l0
00000ooooooo0000o`000006ooooo`;o00001_ooool2o`0000Gooooo0_l0000/ooooob3o00001ooo
ool2o`0000Oooooo0_l0000Aooooo`;o00008?ooool2o`0005Cooooo000Looooo`03o`000?oooooo
oooo057ooooo0_l000000ooooooo0000o`000003ooooo`;o00001Oooool2o`0001Kooooo0_l0000D
oooooa[o000000?oooooo`000?l000000ol00007ooooo`;o00001oooool2o`0000Cooooo0_l0000H
ooooo`;o00002oooool2o`0005cooooo000Looooo`03o`000?oooooooooo05?ooooo0ol0000;oooo
o`?o00000_ooool2o`0000kooooo1?l00005ooooo`;o00000_ooool2o`0000Kooooo0_l00002oooo
ob3o00004_ooool2o`000003ooooool0003o0000013ooooo0ol00005ooooo`;o00001_ooool2o`00
00?ooooo0_l0000Booooo`;o0000B?ooool001cooooo00?o0000ooooooooool0B?ooool2o`0000Wo
oooo0ol00008ooooo`Ko00000_ooool2o`0000kooooo0_l00007ooooo`;o00000_ooool2o`000003
ooooool0003o000000?ooooo0_l000000ooooooo0000o`00000Oo`0000Cooooo0_l0000<ooooo`Co
00004Oooool5o`0000Kooooo0_l00003ooooo`;o00002Oooool2o`0000Kooooo1?l00002ooooo`;o
0000B?ooool001cooooo00?o0000ooooooooool0B?ooool2o`0000[ooooo0_l00008ooooo`?o0000
4oooool2o`000003ooooool0003o000000gooooo0_l00003ooooo`;o000000?oooooo`000?l00000
2ol000000ooooooo0000o`00000=o`0000Sooooo0_l0000;ooooo`Go00004oooool3o`0000Kooooo
0_l00002ooooo`;o00002_ooool2o`0000Kooooo1?l0001<ooooo`007?ooool00ol0003ooooooooo
o`11ooooo`;o00004?ooool2o`0000Oooooo0_l000000ooooooo0000o`000003ooooo`Co00003?oo
ool2o`000003ooooool0003o000000Gooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo8?l0
000=ooooo`;o00001_ooool2o`0000Kooooo0_l00008ooooo`;o00004Oooool2o`0000Cooooo0_l0
0004ooooo`;o00001?ooool2o`00053ooooo000Looooo`;o0000@_ooool2o`0000_ooooo0_l00003
ooooo`;o00001oooool3o`0000;ooooo0_l000000ooooooo0000o`000002o`0001Kooooo0_l00003
ooooo`;o00000_ooool2o`0000?ooooo4ol000000ooooooo0000o`00000:o`0000;ooooo0_l00008
ooooo`;o00003_ooool2o`0000Sooooo0_l000000ooooooo0000o`000002ooooo`Co00000_ooool2
o`0000?ooooo0_l00002ooooo`Go00002_ooool2o`0000[ooooo0_l00014ooooo`007?ooool00ol0
003oooooooooo`13ooooo`;o000000?oooooo`000?l000001_ooool2o`0000[ooooo0_l000000ooo
oooo0000o`000002ooooo`;o00007?ooool2o`00013ooooo6?l000000ooooooo0000o`000006o`00
02?ooooo0_l00002ooooo`Co00000_ooool2o`0000?ooooo0_l00002ooooo`Co00001?ooool3o`00
013ooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`13ooooo`;o000000?oooooo`000?l0
00001_ooool4o`0000Gooooo0_l000000ooooooo0000o`00000Sooooo`;o00003?ooool3o`000003
ooooool0003o000001_o00000_ooool2o`0001?ooooo0_l0000Yooooo`?o00002oooool2o`0000Wo
oooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00001?ooool2o`0000_ooooo
0_l00002ooooo`;o00001Oooool2o`000003ooooool0003o000002Gooooo0_l00008ooooob7o0000
1?ooool2o`0001?ooooo0_l00004ooooo`;o00000_ooool2o`0001cooooo0_l0000?ooooo`;o0000
2Oooool2o`0003kooooo000Looooo`03o`000?oooooooooo03Wooooo0_l00004ooooo`;o00002ooo
ool2o`0000Kooooo0_l0000Cooooo`;o00000oooool2o`0000?ooooo0_l00002ooooo`;o00001?oo
ool6o`0000Sooooo7ol0000:ooooo`;o00002_ooool2o`0000Wooooo0_l00002ooooo`;o00007?oo
ool2o`0000[ooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`0nooooo`?o00001_ooool2
o`0000Gooooo0_l00004ooooo`;o00001oooool2o`0000Gooooo0_l00003ooooo`Co000000?ooooo
o`000?l000001_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000Go00002Ooo
oolMo`0000[ooooo1?l00005ooooo`;o000000?oooooo`000?l000003_ooool2o`0001kooooo0_l0
0005ooooo`Co0000C_ooool001cooooo00?o0000ooooooooool0??ooool4o`0000?ooooo0_l00002
ooooo`;o00001Oooool3o`0000Sooooo0_l00002ooooo`;o00001Oooool3o`0000Cooooo0_l00000
0ooooooo0000o`000003o`000004ooooool0003o0000ooooo`Go000000?oooooo`000?l000000_oo
ool3o`0000?ooooo0_l00002ooooo`Ko000000?oooooo`000?l000005_l000000ooooooo0000o`00
0008ooooo`?o00001Oooool2o`00013ooooo0ol0000Jooooo`;o00000_ooool2o`0000Gooooo0_l0
001@ooooo`007?ooool00ol0003oooooooooo`0looooo`;o00001Oooool2o`0000[ooooo0_l00002
ooooo`;o000000Coooooo`000?l0003ooooo1Ol00002ooooo`;o00000_ooool3o`0000Wooooo0_l0
0007ooooo`;o00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`0000;ooooo1?l0
0004oooooaco00004?ooool2o`0000kooooo0ol00007ooooo`;o00001Oooool2o`0000?ooooo0_l0
0002ooooo`;o000000?oooooo`000?l000003Oooool2o`0004cooooo000Looooo`03o`000?oooooo
oooo03cooooo0_l0000Eooooo`;o000000?oooooo`000?l000000oooool3o`0000;ooooo0_l0000P
ooooo`Go00000_ooool4o`000003ooooool0003o000000;o000000?oooooo`000?l000005_l00002
ooooo`?o00003oooool2o`0001Sooooo0_l00003ooooo`Co00000oooool2o`0000;ooooo0_l0000;
ooooo`;o00000oooool2o`0004cooooo000Looooo`03o`000?oooooooooo03cooooo0_l000000ooo
oooo0000o`00000?ooooo`;o00003Oooool2o`0000[ooooo0_l00008ooooo`;o00003Oooool3o`00
0004ooooool0003o0000o`0000?ooooo1?l00004oooooa7o000000?oooooo`000?l000001?ooool2
o`0000Gooooo0_l000000ooooooo0000o`00000Oooooo`;o00000oooool2o`0000?ooooo0_l00005
ooooo`;o000000?oooooo`000?l000001oooool2o`00057ooooo000Looooo`03o`000?oooooooooo
03oooooo0_l0000?ooooo`Co00001?ooool2o`0000Gooooo0_l00003ooooo`;o00001Oooool2o`00
00Sooooo0_l0000:ooooo`;o00000_ooool2o`000003ooooool0003o000000Gooooo0_l00005oooo
o`Co00000_ooool4o`000003ooooool0003o000000Go00003Oooool2o`000003ooooool0003o0000
00oooooo0_l00008ooooo`;o00001?ooool2o`0000;ooooo0_l00003ooooo`?o00001Oooool2o`00
0003ooooool0003o000000oooooo0_l00019ooooo`007?ooool00ol0003oooooooooo`0jooooo`;o
00000oooool2o`000003ooooool0003o000000[ooooo0_l00002ooooo`;o000000Coooooo`000?l0
003ooooo1?l00008ooooo`;o00001_ooool3o`0000kooooo1_l0000;ooooo`;o00001_ooool3o`00
00?ooooo0_l00004ooooo`So00000_ooool2o`0000[ooooo0_l0000?ooooo`;o00002?ooool3o`00
00?ooooo0_l00002ooooo`;o00000oooool2o`0000?ooooo0_l0000:ooooo`;o00001_ooool2o`00
0003ooooool0003o000000;o0000Aoooool001cooooo00?o0000ooooooooool0>_ooool2o`0000?o
oooo0_l000000ooooooo0000o`00000:ooooo`;o000000?oooooo`000?l000001?l00002ooooo`?o
00004?ooool3o`0000[ooooo0_l00002ooooo`Co00003Oooool2o`0000Kooooo2_l00002ooooo`;o
00000_ooool4o`0000;ooooo0ol00008ooooo`Go00005?ooool6o`0000?ooooo0_l00006ooooo`?o
00000oooool2o`0000[ooooo0_l00006ooooo`;o00000oooool2o`0004Oooooo000Looooo`03o`00
0?oooooooooo03cooooo0_l000000ooooooo0000o`00000=ooooo`;o000000Coooooo`000?l0003o
oooo0ol0000Eooooo`;o00002oooool2o`0000gooooo0_l00009ooooo`;o000000?oooooo`000?l0
00003?l00002ooooo`;o00001Oooool2o`0000Oooooo0ol000000ooooooo0000o`000002o`0001;o
oooo1?l0000=ooooo`Go00002oooool2o`0000?ooooo0_l00005ooooo`;o0000B_ooool00006oooo
ooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04oooo
o`03o`000?oooooooooo03;ooooo0_l00008ooooo`;o000000?oooooo`000?l000008oooool2o`00
02;ooooo0_l00005ooooo`;o00000_ooool2o`0000;ooooo0_l00004ooooo`;o000000?oooooo`00
0?l000000_l00009ooooo`Go00001?ooool2o`0000?ooooo0ol0000<ooooo`Co00004?ooool2o`00
00Cooooo0_l000000ooooooo0000o`000008ooooo`;o00000oooool4o`0000?ooooo0ol0000;oooo
o`;o00000oooool2o`0003Oooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<_ooool2o`0000Cooooo0_l0000<
ooooo`;o000000?oooooo`000?l000003oooool2o`0000Gooooo0_l000001?oooooo0000o`000?oo
ool3o`0000kooooo0_l00003ooooo`;o00003Oooool2o`000004ooooool0003o0000ooooo`;o0000
6_ooool4o`0000_ooooo0_l0000;ooooo`Co00002Oooool2o`0000Gooooo0_l00007ooooo`;o0000
3oooool2o`0000?ooooo0ol0000;ooooo`;o00000oooool2o`0003Oooooo00000ooooooo410@oooo
o`02ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006ooooo`03o`000?oooooooooo03Sooooo1?l0
000:ooooo`;o000000?oooooo`000?l000003oooool2o`0000Gooooo0_l00004ooooo`?o00000_oo
ool2o`0000[ooooo0_l00003ooooo`;o00001oooool2o`0000Cooooo0_l00003ooooo`?o00006?oo
ool2o`0000oooooo0ol0000Gooooo`;o00007Oooool2o`000003ooooool0003o000000;ooooo0ol0
0019ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04odA4A?oMgMgo
ooooo`0000Oooooo0ol0000jooooo`;o0000:_ooool4o`0000;ooooo0_l00009ooooo`;o00003Ooo
ool2o`0000?ooooo0_l00004ooooo`;o00001Oooool2o`0000Cooooo0_l00006ooooo`;o00001?oo
ool2o`00013ooooo0_l0000>ooooo`;o00007oooool2o`000003ooooool0003o000000;ooooo0_l0
00000ooooooo0000o`000005o`0004Wooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`0eooooo`;o00000ooo
ool2o`0000kooooo0_l00004ooooo`;o00002Oooool3o`000003ooooool0003o000000Gooooo1?l0
000:ooooo`;o000000Coooooo`000?l0003o00002Oooool2o`0000?ooooo0_l000000ooooooo0000
o`000009ooooo`Co00000oooool3o`0000Kooooo0_l0000Iooooo`;o00002Oooool4o`0000_ooooo
1?l0000:ooooo`;o00001?ooool2o`000003ooooool0003o000000Oooooo1?l0001:ooooo`0000?o
oooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o
0000ooooooooool0=Oooool2o`0001;ooooo0ol000001?oooooo0000o`000?ooool5o`0000Gooooo
1?l000000ooooooo0000o`000005ooooo`;o00003?ooool2o`0000;ooooo0_l00002ooooo`;o0000
0_ooool2o`000003ooooool0003o000000?ooooo0_l0000<ooooo`;o00000_ooool2o`000003oooo
ool0003o000000Cooooo0_l0000:ooooo`;o00003Oooool2o`000003ooooool0003o000000Wooooo
0_l0000=ooooo`Co00002_ooool2o`0001Gooooo0_l00017ooooo`0000KoooooogMgMonHV9Sooooo
oiRHV?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0=Oooool2o`0000_o
oooo0_l00005ooooo`;o00000_ooool2o`0000?ooooo0ol00005ooooo`;o00002_ooool2o`0000oo
oooo0ol00002ooooo`?o000000?oooooo`000?l000001?ooool2o`0001;ooooo0_l00007ooooo`;o
00002_ooool2o`0000?ooooo0_l00008ooooo`;o00003?ooool3o`0000Kooooo0_l0000Dooooo`;o
00002?ooool2o`0000Wooooo0_l00017ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h=oooo
o`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0=_ooool2o`0000Wooooo1ol0000Noooo
o`;o00001oooool2o`000003ooooool0003o000000Oo000000?oooooo`000?l000001ol000000ooo
oooo0000o`000006ooooo`;o00003_ooool2o`0000;ooooo0_l00005ooooo`;o00002Oooool2o`00
00Sooooo0_l00005ooooo`;o00001Oooool5o`0000Cooooo0_l0000Dooooo`;o00002?ooool5o`00
00;ooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`0booooo`;o00000_ooool2o`0000Wo
oooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l00002ooooo`;o00003Oooool2o`0000[o
oooo0_l00002ooooo`;o000000?oooooo`000?l000004Ol00009ooooo`;o00002Oooool2o`0000?o
oooo1_l00004ooooo`?o00000oooool2o`00013ooooo0_l00003ooooo`Ko000000?oooooo`000?l0
00000ol00002ooooo`;o000000?oooooo`000?l000007_ooool:o`0004Wooooo000Looooo`03o`00
0?oooooooooo02[ooooo0_l00006ooooo`?o00004?ooool2o`0000Gooooo0_l00002ooooo`;o0000
3Oooool4o`0000Sooooo0_l000000ooooooo0000o`00000Co`000003ooooool0003o000000Gooooo
0_l0000<ooooo`;o00001Oooool2o`0000Gooooo0ol00004ooooo`;o00001_ooool2o`0000Sooooo
0_l00004ooooo`Go000000Coooooo`000?l0003ooooo1_l000000ooooooo0000o`00000Rooooo`;o
000000Coooooo`000?l0003o0000BOooool001cooooo00?o0000ooooooooool0:_ooool2o`0000Oo
oooo0_l0000@ooooo`;o00005oooool2o`000003ooooool0003o000000;ooooo0_l00006oooooaWo
00000_ooool2o`000004ooooool0003o0000o`00017ooooo1Ol00003ooooo`;o00003?ooool3o`00
00Gooooo0ol00006ooooo`So000000?oooooo`000?l000001?l00002ooooo`Co000000?oooooo`00
0?l000000_l0000Vooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0=_ooool2o`0000go
oooo0_l0000Gooooo`;o000000?oooooo`000?l000001?l00003oooooa_o00000oooool2o`0000;o
oooo0_l0000Aooooo`Go00004Oooool2o`0000Kooooo3ol00002ooooo`?o000000Coooooo`000?l0
003o00000_ooool:o`0000Gooooo0_l0000Kooooo`;o000000?oooooo`000?l00000@Oooool001co
oooo00?o0000ooooooooool0<Oooool4o`000003ooooool0003o000000oooooo0_l00003ooooo`;o
00003oooool2o`0000;ooooo1Ol00004ooooo`Co000000?oooooo`000?l000004ol0000Looooo`;o
00004_ooool2o`0000Wooooo3Ol00002ooooo`So000000Goooooo`000?l0003o0000ooooo`02o`00
00;ooooo0_l00005ooooo`;o00006oooool2o`000003ooooool0003o000000Gooooo0_l0000joooo
o`007?ooool00ol0003oooooooooo`0aooooo`Ko00002_ooool2o`0000Cooooo0_l00003ooooo`Co
00001_ooool2o`0000?ooooo1?l0000;oooooa[o00000oooool2o`0000;ooooo0_l0000Cooooo`Co
00004?ooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o0000
00Go000000Coooooo`000?l0003o00001?ooool2o`000004ooooool0003o0000ooooo`?o00001?oo
ool8o`0000;ooooo0_l00004ooooo`;o00003?ooool2o`0000oooooo0_l0000jooooo`007?ooool0
0ol0003oooooooooo`0booooo`;o000000?oooooo`000?l000002_ooool2o`0000;ooooo0_l00002
ooooo`?o00000_ooool2o`0000?ooooo1Ol00003ooooo`;o00003Oooool6o`0000;ooooo5?l00000
0ooooooo0000o`000002ooooo`;o00000_ooool2o`0000Cooooo0_l00003ooooo`;o00001?ooool4
o`0000kooooo0_l00004ooooo`?o000000?oooooo`000?l000000ol00006ooooo`Ko00000oooool4
o`000003ooooool0003o000000;ooooo1?l000000ooooooo0000o`000006o`0000;ooooo0_l00004
ooooo`;o00001?ooool2o`0000Kooooo0_l000000ooooooo0000o`000018ooooo`007?ooool00ol0
003oooooooooo`0gooooo`;o00001_ooool2o`0000Cooooo0_l00002ooooo`?o00001?ooool2o`00
0003ooooool0003o000000?o00000oooool2o`0000gooooo2Ol000000ooooooo0000o`00000@o`00
00Wooooo0_l00004ooooo`;o00000oooool2o`0000Cooooo0_l0000@ooooo`;o00000_ooool5o`00
00?ooooo1Ol00005ooooo`Ko00000_ooool=o`000004ooooool0003o0000ooooo`Co00002?ooool2
o`0000Gooooo0_l00006ooooo`Ko0000Aoooool001cooooo00?o0000ooooooooool0=oooool2o`00
00Kooooo0_l00008ooooo`;o00001Oooool2o`0000?ooooo1?l0000?oooooaco00002oooool2o`00
00gooooo1?l00003ooooo`;o00003oooool3o`0000?ooooo1ol00004oooooaGo00001?ooool5o`00
00Sooooo0_l00007ooooo`;o00001Oooool2o`000003ooooool0003o000000?ooooo0_l00008oooo
o`;o0000>?ooool001cooooo00?o0000ooooooooool0<Oooool2o`0000cooooo0_l000000ooooooo
0000o`000002ooooo`;o00002?ooool9o`000004ooooool0003o0000o`0000?ooooo0_l00005oooo
oaCo000000?oooooo`000?l000001_l0000:ooooo`;o00002oooool2o`000003ooooool0003o0000
00;o00000oooool2o`00013ooooo0ol00002ooooob3o000000Coooooo`000?l0003ooooo0_l00008
ooooo`Co00001Oooool2o`000003ooooool0003o000000gooooo0_l00008ooooo`;o0000>?ooool0
01cooooo00?o0000ooooooooool0;Oooool2o`0000;ooooo0_l00009ooooo`;o00001?ooool2o`00
00;ooooo0_l00008ooooo`So00000_ooool3o`000003ooooool0003o000000;o000000?oooooo`00
0?l000000_oooolAo`000003ooooool0003o000000So00000oooool2o`0000Kooooo0_l0000;oooo
o`;o000000?oooooo`000?l000005_oooolYo`0000_ooooo1?l000001?oooooo0000o`000?ooool3
o`00013ooooo0_l0000;ooooo`;o0000=Oooool001cooooo0_l0000/ooooo`Co00000_ooool2o`00
00?ooooo0_l00004ooooo`?o00004_ooool2o`000003ooooool0003o000000;o00001_ooool2o`00
00?ooooo0_l000001?oooooo0000o`000?oooolJo`0000?ooooo0_l0000Jooooo`;o000000?ooooo
o`000?l000003oooool2o`000003ooooool0003o000002Wo00000_ooool2o`0000?ooooo0_l00002
ooooo`;o000000?oooooo`000?l000003Oooool2o`0000?ooooo0_l0000:ooooo`;o0000=Oooool0
01cooooo00?o0000ooooooooool0:oooool2o`0000Cooooo0_l00003ooooo`;o00001Oooool2o`00
00Oooooo0_l00009ooooo`;o00000_ooool2o`0000Kooooo0_l000000ooooooo0000o`000003o`00
0003ooooool0003o000001go00005_ooool2o`0000Gooooo0_l000000ooooooo0000o`000005oooo
o`;o00001?ooool2o`0000Cooooo5?l00002ooooo`ko00000_ooool6o`0000;ooooo0_l000000ooo
oooo0000o`00000Fooooo`;o00000oooool2o`00047ooooo000Looooo`03o`000?oooooooooo02go
oooo0_l00002ooooo`;o00004oooool2o`0001Gooooo0_l000001?oooooo0000o`000?l00005oooo
oago00003Oooool2o`0000Gooooo1?l0000?ooooo`;o00001?ooool3o`0000?ooooo5Ol000000ooo
oooo0000o`00000>o`000004ooooool0003o0000ooooo`?o000000Coooooo`000?l0003ooooo0ol0
0002ooooo`;o00000oooool2o`0005Cooooo000Looooo`03o`000?oooooooooo02Sooooo0_l00003
ooooo`?o00007?ooool2o`0000Cooooo0_l0000EoooooaSo00004Oooool2o`0000Gooooo0_l00000
0ooooooo0000o`000003ooooo`;o00000oooool2o`0000_ooooo0_l00005ooooob_o00001?ooool3
o`0000;ooooo0_l00003ooooo`;o00002_ooool2o`0004Sooooo000Looooo`03o`000?oooooooooo
02Sooooo1?l00002ooooo`;o00002oooool2o`0000Kooooo0_l00007ooooo`?o00000oooool2o`00
00cooooo0_l00006oooooaWo00005?ooool4o`0000?ooooo0_l00003ooooo`?o00000_ooool2o`00
00;ooooo0_l00008ooooo`?o00001?ooool[o`0000?ooooo0ol00007ooooo`;o00002_ooool2o`00
00_ooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0Zooooo`;o00003oooool2o`0000Ko
oooo0_l00008ooooo`Co00003oooool2o`0000Cooooo6ol0000Dooooo`Co00002?ooool3o`0000Ko
oooo0_l00002ooooo`;o00000_ooool5o`000003ooooool0003o000000Cooooo:Ol00002ooooo`?o
00001_ooool3o`0001Oooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0Xooooo`;o0000
9Oooool2o`0001Gooooo0_l00004oooooaGo00002oooool3o`0000Kooooo0_l0000;ooooo`;o0000
2_ooool2o`0000;ooooo0_l00002ooooo`Ko000000?oooooo`000?l000005?l000000ooooooo0000
o`00000<o`000003ooooool0003o000000;o00002oooool2o`0000Wooooo0_l0001:ooooo`007?oo
ool00ol0003oooooooooo`0Xooooo`;o00007_ooool2o`00013ooooo0_l0000:ooooo`;o00001?oo
oolDo`0000cooooo0ol00006ooooo`;o00002oooool2o`0000kooooo0_l00002ooooob_o00001?oo
ool4o`0000[ooooo0_l00008ooooo`;o00001oooool2o`00047ooooo000Looooo`03o`000?oooooo
oooo02Wooooo0_l0000Mooooo`;o00004?ooool2o`000003ooooool0003o000000Oooooo0_l00000
1Ooooooo0000o`000?l0003ooooo01;o00003oooool2o`00017ooooo0_l0000?ooooo`Go000000?o
ooooo`000?l000009_l00005ooooo`Co00002_ooool2o`0000Sooooo0ol00006ooooo`;o00001ooo
ool2o`0003Sooooo000Looooo`03o`000?oooooooooo02Kooooo0_l000001?oooooo0000o`000?l0
0002ooooo`;o00003?ooool2o`0001;ooooo0_l00008ooooo`;o000000?oooooo`000?l000002_oo
ool3o`000003ooooool0003o000000co000000?oooooo`000?l000004?ooool2o`00013ooooo1?l0
000?ooooo`Co00000_oooolYo`0000Cooooo1Ol00002ooooo`;o00002Oooool8o`0000kooooo0ol0
000hooooo`007?ooool00ol0003oooooooooo`0Vooooo`;o00000_ooool2o`0000;ooooo1?l00009
ooooo`?o000000?oooooo`000?l000003oooool3o`0000Oooooo0ol00004ooooo`;o00002_oooolA
o`0000;ooooo0ol00005ooooo`;o000000?oooooo`000?l000004oooool4o`0000[ooooo1?l00000
1?oooooo0000o`000?ooool2o`0000;ooooo:_l000000ooooooo0000o`000004o`000004ooooool0
003o0000o`0000Oooooo2Ol00003ooooo`;o00002_ooool2o`0003Wooooo000Looooo`03o`000?oo
oooooooo02Gooooo0_l00008ooooo`?o00000_ooool2o`0000Gooooo0_l00002ooooo`;o00001_oo
ool2o`0000Sooooo0_l00007ooooo`?o00001?ooool2o`000003ooooool0003o000000;o00001Ooo
ool:o`0000;ooooo0ol00004ooooo`?o00001Oooool2o`000003ooooool0003o000001?ooooo1?l0
000:ooooo`Co000000Coooooo`000?l0003ooooo=Ol000000ooooooo0000o`000008ooooo`;o0000
0_ooool2o`000003ooooool0003o000000?ooooo0_l00015ooooo`007?ooool00ol0003ooooooooo
o`0Uooooo`;o00002?ooool4o`000004ooooool0003o0000ooooo`;o00002_ooool2o`0000;ooooo
0_l00008ooooo`;o00002?ooool2o`000003ooooool0003o000000Cooooo1ol000000ooooooo0000
o`000002o`000003ooooool0003o000000Co00001oooool2o`000004ooooool0003o0000ooooo`;o
000000?oooooo`000?l000001oooool2o`0000;ooooo0_l00009ooooo`Go00000_ooool2o`0000Co
oooo0_l000000ooooooo0000o`000006ooooocSo00002oooool2o`0004gooooo000Looooo`03o`00
0?oooooooooo033ooooo0ol00003ooooo`?o00001Oooool2o`0000?ooooo1ol00007ooooo`?o0000
2_ooool2o`0000Sooooo0ol000000ooooooo0000o`000003o`000004ooooool0003o0000ooooo`;o
00001oooool2o`0000Cooooo1Ol00007ooooo`;o00000_ooool2o`0000Wooooo0_l00005ooooo`;o
00001?ooool2o`000003ooooool0003o000000Oooooo9_l000000ooooooo0000o`000005o`0000;o
oooo1ol00002ooooo`;o00006?ooool2o`0003cooooo000Looooo`03o`000?oooooooooo03Kooooo
0_l000000ooooooo0000o`000003ooooo`;o00000oooool7o`0000Kooooo1?l0000;ooooo`;o0000
2?ooool2o`000003ooooool0003o000000?o000000Coooooo`000?l0003ooooo0_l0000;ooooo`;o
000000Coooooo`000?l0003o00002_ooool2o`0000_ooooo0_l0000=ooooo`;o00002?ooool3o`00
0003ooooool0003o000002Go000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00003oooo
o`;o000000?oooooo`000?l000000_ooool2o`00017ooooo0_l0000looooo`007?ooool00ol0003o
ooooooooo`0iooooo`;o00005Oooool4o`0000_ooooo0_l00008ooooo`;o00000oooool2o`0000;o
oooo1ol00009ooooo`;o000000?oooooo`000?l000001oooool2o`0000;ooooo0_l00008ooooo`;o
000000?oooooo`000?l000002Oooool3o`000003ooooool0003o000000Sooooo0_l000000ooooooo
0000o`000005o`000003ooooool0003o000001_o000000Coooooo`000?l0003ooooo1?l0000<oooo
o`;o00000_ooool2o`0004oooooo000Looooo`;o00009?ooool2o`0000_ooooo0ol0000Cooooo`;o
00002?ooool4o`0000Oooooo0_l0000<ooooo`;o00001oooool3o`0000;ooooo0_l0000Eooooo`;o
00003?ooool2o`000003ooooool0003o000000?ooooo0_l00004ooooo`?o00001Oooool2o`0000Co
oooo0_l000000ooooooo0000o`000002ooooo`_o000000?oooooo`000?l000000ol000000ooooooo
0000o`00000Eo`0000;ooooo0_l0000>ooooo`;o00002?ooool2o`0004?ooooo000Looooo`03o`00
0?oooooooooo02?ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool6o`0000kooooo
0_l000000ooooooo0000o`000008ooooo`;o00002Oooool2o`0000?ooooo0_l00007ooooo`;o0000
3_ooool2o`0000Wooooo0_l00002ooooo`;o00006_ooool2o`0000Cooooo0_l00006ooooo`;o0000
0_ooool2o`0000?ooooo5?l000000ooooooo0000o`00000:o`000004ooooool0003o0000ooooo`Wo
000000?oooooo`000?l000000_ooool2o`0000[ooooo0_l00006ooooo`Co00002Oooool2o`0003So
oooo000Looooo`03o`000?oooooooooo02?ooooo0_l00003ooooo`;o000000?oooooo`000?l00000
0_ooool2o`000003ooooool0003o000000;o00003Oooool2o`0000Wooooo1?l0000:ooooo`;o0000
0_ooool2o`0000Oooooo0_l0000>ooooo`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`?o
000000?oooooo`000?l000005_ooool3o`0000Oooooo0_l00002ooooo`;o00001_ooool2o`000003
ooooool0003o000002Go00000_ooool2o`0000;ooooo0ol00005ooooo`;o00000_ooool2o`0000[o
oooo0_l00002ooooo`;o00002oooool2o`0003Sooooo000Looooo`03o`000?oooooooooo023ooooo
0_l000000ooooooo0000o`00000?ooooo`Co00000oooool2o`00017ooooo0_l000001?oooooo0000
o`000?ooool2o`0000Kooooo0_l0000;ooooo`;o000000Coooooo`000?l0003ooooo0_l0000;oooo
o`Go00001?ooool2o`000003ooooool0003o000000oooooo0_l00002ooooo`;o000000Coooooo`00
0?l0003o00001oooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool4
o`0000;ooooo2Ol000000ooooooo0000o`00000Io`000005ooooool0003o0000o`000?ooool00_l0
0002ooooo`?o00000_ooool2o`0000Sooooo1_l00017ooooo`007?ooool00ol0003oooooooooo`0P
ooooo`;o00000oooool2o`0000Oooooo0_l00005ooooo`?o00000oooool2o`0000oooooo0_l00003
ooooo`Go000000?oooooo`000?l000001?l0000?ooooo`;o000000?oooooo`000?l000002oooool3
o`0000Gooooo0_l00002ooooo`;o00002?ooool2o`0000Gooooo0_l00002ooooo`;o00002?ooool4
o`0000Kooooo0ol000000ooooooo0000o`000006ooooo`_o000000?oooooo`000?l000006Ol00000
1Ooooooo0000o`000?l0003ooooo00?o000000Coooooo`000?l0003o00003?ooool2o`0000;ooooo
0_l0000:ooooo`;o0000>oooool001cooooo00?o0000ooooooooool09Oooool2o`0000;ooooo0_l0
0003ooooo`;o00001Oooool2o`0000Cooooo0_l00006ooooo`;o00000_ooool2o`0000?ooooo0_l0
0004ooooo`;o00000oooool6o`0001;ooooo0_l0000Cooooo`;o00003?ooool2o`0000Kooooo0_l0
000;ooooo`Co00001oooool2o`0000Wooooo8_l0000;ooooo`;o00005?ooool2o`0000?ooooo0_l0
00000ooooooo0000o`000002ooooo`;o0000>oooool001cooooo00?o0000ooooooooool07_ooool2
o`0000Gooooo0_l00002ooooo`;o00000oooool2o`0000_ooooo1Ol00003ooooo`;o00000_ooool2
o`0000?ooooo0_l000000ooooooo0000o`000008ooooo`;o00005?ooool4o`0000kooooo0_l0000;
ooooo`;o00001?ooool2o`0000Cooooo0_l000000ooooooo0000o`00000Aooooo`;o00001_ooool2
o`0000?ooooo0_l00002oooooaWo000000?oooooo`000?l000000_l00004ooooo`Go00000oooool2
o`0001?ooooo0_l00003ooooo`;o000000?oooooo`000?l00000?oooool001cooooo00?o0000oooo
ooooool07_ooool2o`0000Gooooo0_l00007ooooo`;o00002Oooool2o`0000;ooooo0ol0000<oooo
o`;o000000?oooooo`000?l000000_l00005ooooo`;o00003oooool2o`0000Kooooo0_l0000>oooo
o`;o00001oooool2o`0000;ooooo0_l00002ooooo`Co00001oooool2o`0000;ooooo1?l0000;oooo
o`;o00001_ooool2o`0000;ooooo0ol000000ooooooo0000o`00000Po`000003ooooool0003o0000
00?o00000oooool2o`0001_ooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0iooooo`;o
00003oooool4o`000003ooooool0003o000000;o00001Oooool3o`0000kooooo0_l0000?ooooo`;o
00003_ooool2o`0000Kooooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l00002ooooo`Co
00005oooool3o`000003ooooool0003o0000023o00001Oooool2o`0002Wooooo0_l0000eooooo`00
7?ooool00ol0003oooooooooo`0`ooooo`;o00003?ooool4o`000003ooooool0003o000000Gooooo
1?l000001?oooooo0000o`000?l00007ooooo`;o00007oooool2o`0000Kooooo0_l0000Aooooo`Co
00000oooool3o`0000;ooooo0_l00004ooooo`;o00003_ooool2o`0000Cooooo0_l000000ooooooo
0000o`00000@o`000005ooooool0003o0000o`000?ooool02ol00002ooooo`Go00002oooool2o`00
00Oooooo0_l000000ooooooo0000o`00000@ooooo`;o0000=Oooool001cooooo00?o0000oooooooo
ool09_ooool2o`0000Oooooo0ol0000<ooooo`Co000000?oooooo`000?l000002Oooool5o`0000_o
oooo1Ol00002ooooo`;o00006oooool2o`0000;ooooo0_l0000Dooooo`;o00000oooool2o`000004
ooooool0003o0000ooooo`;o00001_ooool2o`0000?ooooo0_l000000ooooooo0000o`000008o`00
00Gooooo4?l000001?oooooo0000o`000?ooool4o`0000Kooooo1?l00007ooooo`;o00000oooool2
o`0000Kooooo0ol000000ooooooo0000o`000017ooooo`007?ooool00ol0003oooooooooo`0Voooo
o`;o00001oooool2o`0000Oooooo0_l0000:ooooo`;o00002?ooool5o`0000_ooooo1Ol00002oooo
o`;o000000?oooooo`000?l000002_ooool4o`0000kooooo0_l00007ooooo`;o00004oooool2o`00
00Wooooo0_l00003ooooo`?o00000_ooool4o`0000;ooooo0_l00002oooooa3o000000Coooooo`00
0?l0003ooooo0ol000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000[ooooo1?l0
000:ooooo`?o00002oooool2o`0000Oooooo0ol0000dooooo`007?ooool00ol0003oooooooooo`0Y
ooooo`;o00003Oooool2o`0000[ooooo0_l00008ooooo`Co00003?ooool4o`0000Kooooo0_l00003
ooooo`;o00000_ooool7o`000003ooooool0003o000000Gooooo0_l00003ooooo`;o00000oooool7
o`0000?ooooo0_l00005ooooo`;o00001oooool2o`000003ooooool0003o000000;o00002_ooool2
o`000003ooooool0003o000000?ooooo5_l00002ooooo`Go00001?ooool5o`0000Gooooo0_l00003
ooooo`;o00003?ooool2o`0000cooooo0_l00007ooooo`?o0000=?ooool001cooooo00?o0000oooo
ooooool0:Oooool2o`0000Gooooo0ol0000@ooooo`?o00002?ooool6o`0000Kooooo0_l00007oooo
o`;o00000oooool2o`0000?ooooo0_l00002ooooo`?o00000_ooool2o`000003ooooool0003o0000
00Gooooo0_l00003ooooo`;o00000oooool8o`0000;ooooo0_l00005ooooo`;o00002_ooool4o`00
00;ooooo0_l00009ooooo`;o00000_ooool9o`000003ooooool0003o000000_o000000Coooooo`00
0?l0003o00002?ooool2o`0000Oooooo0_l00004ooooo`;o000000?oooooo`000?l000004?ooool2
o`0004Cooooo000Looooo`03o`000?oooooooooo02_ooooo0_l00003ooooo`?o00004?ooool3o`00
00Sooooo0_l00002ooooo`;o00001_ooool2o`0000Oooooo1?l0000;ooooo`;o00001oooool5o`00
013ooooo1_l0000?ooooo`Co00001?ooool2o`0000Gooooo0ol00003ooooo`Co00002oooool5o`00
0003ooooool0003o000000So00001_ooool4o`0000Gooooo0_l00004ooooo`;o000000?oooooo`00
0?l000003_ooool4o`0004Cooooo000Looooo`03o`000?oooooooooo02_ooooo0_l00003ooooo`;o
00001Oooool2o`0000gooooo0_l0000Mooooo`;o00001oooool2o`0000;ooooo0_l000000ooooooo
0000o`000004ooooo`Go00001_ooool2o`0000Kooooo0_l000000ooooooo0000o`000002o`00013o
oooo0ol00009ooooo`;o000000Coooooo`000?l0003o00000oooool4o`000003ooooool0003o0000
00;ooooo0_l00004ooooo`Go000000?oooooo`000?l000001?l00002ooooo`;o00001_ooool4o`00
00Gooooo0_l0000Gooooo`?o00000oooool2o`00043ooooo000Looooo`;o0000:_ooool2o`0000Go
oooo0_l00005ooooo`;o00001oooool2o`0000Cooooo0_l00006ooooo`;o000000?oooooo`000?l0
00006oooool2o`0000Gooooo0_l0000?ooooo`;o00001_ooool2o`0001kooooo1Ol00008ooooo`?o
000000?oooooo`000?l000000_ooool2o`0000Cooooo1?l00003ooooo`Ko000000?oooooo`000?l0
00004Oooool2o`0001Cooooo0ol00004ooooo`;o00003?ooool2o`0003;ooooo000Looooo`03o`00
0?oooooooooo02Wooooo0_l0000=ooooo`;o00001_ooool2o`0000cooooo1Ol0000<ooooo`Co0000
3?ooool2o`0000cooooo0_l0000:ooooo`;o00002oooool2o`0001Kooooo1Ol00003ooooo`;o0000
0oooool4o`000003ooooool0003o000000Go000000?oooooo`000?l000003ol00004ooooo`;o0000
2oooool2o`0000Cooooo0_l0000;ooooo`Go00004oooool2o`0003;ooooo000Looooo`03o`000?oo
oooooooo037ooooo0_l00002ooooo`;o000000?oooooo`000?l000002?ooool2o`0000[ooooo1?l0
00000ooooooo0000o`000008ooooo`Ko00003?ooool2o`0000cooooo0ol000000ooooooo0000o`00
0006ooooo`;o00001Oooool3o`0000?ooooo0_l0000<ooooo`;o000000?oooooo`000?l000002_oo
ool5o`0000?ooooo1?l000000ooooooo0000o`000002o`000004ooooool0003o0000ooooo`co0000
00?oooooo`000?l000000_l00002ooooo`Co00002?ooool2o`0000Cooooo1Ol000000ooooooo0000
o`000008ooooo`Co0000B?ooool001cooooo00?o0000ooooooooool0<Oooool2o`0000;ooooo0_l0
000;ooooo`;o00000oooool2o`0000Gooooo0_l00003ooooo`;o00002?ooool2o`0001Gooooo1?l0
0006ooooo`Go00002Oooool2o`000003ooooool0003o000000;o00004Oooool2o`000004ooooool0
003o0000ooooo`;o00000_ooool2o`0000;ooooo1?l00004ooooo`Co00001?ooool2o`000003oooo
ool0003o000000;ooooo0ol000000ooooooo0000o`00000<ooooo`;o00002_ooool2o`0000Cooooo
1?l00002ooooo`;o0000E?ooool001cooooo00?o0000ooooooooool0;Oooool2o`0000gooooo0_l0
0007ooooo`Co000000?oooooo`000?l000001Oooool2o`0000_ooooo0_l00006ooooo`;o00003?oo
ool4o`0000Kooooo0ol00003ooooo`?o00001Oooool2o`000003ooooool0003o000000;o000000Co
ooooo`000?l0003ooooo0ol00005ooooo`;o00001?ooool2o`0000?ooooo0_l00002ooooo`;o0000
0_ooool2o`0000Kooooo1?l00007ooooo`;o00000oooool2o`0000oooooo0ol0000<ooooo`;o0000
6?ooool2o`0004?ooooo000Looooo`03o`000?oooooooooo02gooooo0_l0000=ooooo`;o00001ooo
ool4o`000003ooooool0003o000000Gooooo0_l0000;ooooo`;o00001_ooool3o`000004ooooool0
003o0000ooooo`;o00001Oooool2o`0000?ooooo1?l000000ooooooo0000o`000007o`000003oooo
ool0003o000000[ooooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l00004ooooo`;o0000
4Oooool2o`0000[ooooo0_l00009ooooo`;o00001Oooool2o`0000?ooooo0ol00005ooooo`Co0000
0_ooool3o`0001Sooooo0_l0000:ooooo`;o0000=oooool001cooooo00?o0000ooooooooool0>?oo
ool2o`0000gooooo0_l0000Kooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000
o`000005oooooa?o000000?oooooo`000?l000002oooool6o`0000Kooooo0_l00005ooooo`;o0000
2oooool2o`000003ooooool0003o000000[ooooo0_l000000ooooooo0000o`000006ooooo`;o0000
1Oooool2o`0000Gooooo0_l000001?oooooo0000o`000?ooool4o`0000;ooooo0_l0000Jooooo`;o
00002Oooool2o`0003Oooooo000Looooo`03o`000?oooooooooo03Sooooo0_l00003ooooo`;o0000
1oooool2o`0000?ooooo0_l00003ooooo`Co00004?ooool2o`0000Sooooo0_l00006oooooa3o0000
00?oooooo`000?l000000_ooool2o`0000Sooooo1_l00006ooooo`;o00001Oooool2o`0000Sooooo
0_l000000ooooooo0000o`000002ooooo`;o00001?ooool2o`0000Kooooo0_l00002ooooo`;o0000
0oooool4o`0000Wooooo1_l00006ooooo`;o00004?ooool2o`0000Cooooo0ol000001?oooooo0000
o`000?l00011ooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00001oooool2o`0000?ooooo
0_l00003ooooo`Co000000?oooooo`000?l000001_ooool2o`0000Cooooo1Ol00003ooooo`;o0000
00?oooooo`000?l000001OoooolHo`0000_ooooo0ol00005ooooo`?o00003oooool2o`0000Gooooo
0_l00004ooooo`;o00001Oooool2o`0000?ooooo0_l00003ooooo`Co00001Oooool2o`0000Cooooo
1?l0000Hooooo`;o00000oooool4o`0000;ooooo0_l00011ooooo`007?ooool00ol0003ooooooooo
o`0[ooooo`;o00007_ooool2o`0000Sooooo0_l00006ooooo`;o00001?ooool5o`0000?ooooo0_l0
0005oooooa_o00000oooool4o`0000cooooo1Ol00005ooooo`?o00006Oooool2o`0000;ooooo0_l0
00001?oooooo0000o`000?l00009ooooo`;o00003Oooool2o`0001Cooooo1?l0000Jooooo`;o0000
:oooool001cooooo00?o0000ooooooooool0:oooool2o`0000_ooooo0_l0000?ooooo`Co00001?oo
ool2o`0000Wooooo0_l00003ooooo`;o00003oooool:o`0000;ooooo2ol00002ooooo`;o00000ooo
ool4o`000003ooooool0003o000000Sooooo1_l00005ooooo`?o00003?ooool2o`0000oooooo0_l0
00001?oooooo0000o`000?l00006ooooo`;o00001_ooool2o`0000;ooooo0_l00004ooooo`;o0000
5?ooool2o`0001cooooo0_l0000[ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00002Ooo
ool2o`0000Cooooo0_l00004ooooo`Go000000?oooooo`000?l000001Oooool2o`0000?ooooo0_l0
0009ooooo`;o00000_ooool4o`000003ooooool0003o000000Ko000000?oooooo`000?l000002_l0
0007ooooo`;o00000_ooool2o`0000Sooooo1Ol0000Eooooo`?o00002Oooool6o`0000_ooooo0_l0
0003ooooo`;o000000?oooooo`000?l000000_ooool2o`00017ooooo0_l0000Jooooo`;o0000=_oo
ool001cooooo00?o0000ooooooooool08Oooool2o`00017ooooo0_l0000=ooooo`Co00000oooool2
o`0000;ooooo1_l000000ooooooo0000o`00000=ooooo`;o00000_ooool6o`000003ooooool0003o
000001Wo00004?ooool2o`0000?ooooo1Ol00003ooooo`Co00000_ooool2o`0000_ooooo0_l00007
ooooo`[o00001oooool2o`0000Gooooo0_l0000Hooooo`;o00006_ooool2o`0003Kooooo000Loooo
o`03o`000?oooooooooo027ooooo0_l0000Aooooo`Co00000oooool2o`0000Sooooo0_l00003oooo
o`;o000000Goooooo`000?l0003o0000ooooo`03o`0000?ooooo0_l0000;ooooo`;o00000_ooool5
o`0000;ooooo5ol000001?oooooo0000o`000?l00002ooooo`;o00003?ooool2o`0000?ooooo0_l0
0004ooooo`Ko00000_ooool2o`0001Cooooo0_l00002ooooo`?o000000?oooooo`000?l000001Ooo
ool4o`0000;ooooo0_l00003ooooo`;o00002?ooool2o`0000?ooooo0_l0001Kooooo`0000Kooooo
onk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Ko
oooo00?o0000ooooooooool0=Oooool3o`0000?ooooo0_l00003ooooo`;o00001Oooool2o`0000Co
oooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l0000Booooo`;o00000ooooolFo`000003
ooooool0003o000000?ooooo0_l0000Dooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o
00000_ooool2o`0001Gooooo1_l00005ooooo`?o00001?ooool2o`0000?ooooo1?l00006ooooo`;o
00000oooool2o`0001;ooooo0_l00017ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5oooo
o`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0=Oooool3
o`0000Sooooo0_l00005ooooo`;o00001oooool4o`0000;ooooo0_l00005ooooo`;o00004OoooolG
o`000003ooooool0003o000000Cooooo0_l0000Booooo`;o000000?oooooo`000?l000000ol00000
0ooooooo0000o`000004o`0000Gooooo0_l0000<ooooo`Co00000_ooool2o`0000Gooooo0_l00005
ooooo`;o00000oooool4o`0000Kooooo0_l00003ooooo`;o00004_ooool2o`0004Oooooo00000ooo
oooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo03Gooooo0ol0000?ooooo`;o00000_ooool2o`0000?ooooo2?l00005
ooooo`;o000000?oooooo`000?l000003Oooool6o`000003ooooool0003o000001;o00001?ooool2
o`0000cooooo0_l00007ooooo`Go00000_ooool4o`0000;ooooo0_l00002ooooo`;o00002?ooool2
o`0000;ooooo0_l0000Aooooo`?o00000oooool2o`000003ooooool0003o000000Gooooo0ol00002
ooooo`;o00004_ooool2o`0004Oooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000=_ooool2o`0000;ooooo0_l00003
ooooo`;o00001_ooool2o`0000;ooooo0_l00003ooooo`?o000000?oooooo`000?l000002_ooool2
o`000004ooooool0003o0000o`0000?ooooo0_l00003oooooago00004?ooool4o`0000Kooooo0_l0
0005ooooo`Co00000_ooool2o`0000cooooo0_l00004ooooo`;o00000_ooool2o`0000_ooooo1Ol0
00001?oooooo0000o`000?ooool2o`0000Gooooo0ol00002ooooo`;o00004_ooool3o`0000?ooooo
0_l0000;ooooo`;o0000=?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0>_ooool4o`000003oooo
ool0003o000000oooooo0_l0000Aooooo`?o00000oooool2o`0000?ooooo7Ol0000=ooooo`;o0000
00?oooooo`000?l000000_l00004ooooo`;o00001_ooool2o`0001Wooooo0_l00002ooooo`;o0000
0oooool2o`0000Oooooo1Ol0000:ooooo`;o00000oooool2o`0000kooooo0_l00003ooooo`;o0000
0oooool2o`0000_ooooo0_l0000dooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0??ooool2o`0000kooooo0_l0
0002ooooo`;o00002_ooool2o`0000gooooo0_l000000ooooooo0000o`00000Ko`0000gooooo0_l0
0002ooooo`;o00001Oooool:o`0000[ooooo0_l000000ooooooo0000o`000005ooooo`;o00002Ooo
ool5o`0000[ooooo0_l0000Oooooo`;o00000oooool2o`0004Kooooo00001_ooooooMgMgoiRHV?oo
ooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0looooo`;o0000
2Oooool2o`0000?ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00001oooool2o`000003
ooooool0003o000000[ooooo0_l000000ooooooo0000o`00000?o`000003ooooool0003o000000Wo
00000oooool2o`0001Cooooo2Ol00006ooooo`;o00000_ooool2o`000003ooooool0003o000000Go
oooo1?l00007ooooo`Co00001_ooool2o`000003ooooool0003o000000Cooooo0_l00003ooooo`;o
00005Oooool2o`0000Cooooo0_l00016ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<oooo
o`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0>oooool2o`000003ooooool0003o
000000;o00001Oooool2o`0000Cooooo1Ol000000ooooooo0000o`00000:ooooo`;o00003_ooool9
o`0000;ooooo4Ol00003ooooo`;o00004oooool3o`0000Gooooo0_l00006ooooo`;o00003_ooool2
o`0000Wooooo0_l000001?oooooo0000o`000?ooool4o`000003ooooool0003o000000Cooooo0_l0
0002ooooo`?o00005Oooool2o`0000Kooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0g
ooooo`;o00000_ooool2o`000003ooooool0003o000000?o00002Oooool4o`0001oooooo0_l00002
ooooo`Oo000000?oooooo`000?l000003_l00005ooooo`;o00002?ooool2o`0000?ooooo0_l00002
ooooo`;o00000_ooool2o`000003ooooool0003o000000gooooo1?l000000ooooooo0000o`00000A
ooooo`;o000000?oooooo`000?l000003?ooool3o`0001Oooooo0_l00005ooooo`;o0000A?ooool0
01cooooo00?o0000ooooooooool0=oooool2o`0000;ooooo0_l00004ooooo`;o00000_ooool4o`00
00?ooooo1?l00002ooooo`;o00002Oooool2o`0001;ooooo2Ol00002ooooo`oo00001Oooool2o`00
00Sooooo0_l000000ooooooo0000o`000002o`0000Kooooo0_l000000ooooooo0000o`00000:oooo
o`;o000000?oooooo`000?l000001Ol00003ooooo`;o00001_ooool2o`0001Gooooo0ol0000Goooo
o`;o0000Boooool001cooooo00?o0000ooooooooool0>_ooool2o`0000Wooooo1?l00004ooooo`?o
00000_ooool2o`0000Wooooo1?l0000@oooooa[o00001?ooool2o`000003ooooool0003o000000Wo
oooo0_l0000;ooooo`;o00002_ooool2o`0000;ooooo1?l00002ooooo`;o000000?oooooo`000?l0
00001_ooool2o`00013ooooo0_l00003ooooo`Ko00005?ooool4o`0004Wooooo000Looooo`03o`00
0?oooooooooo03[ooooo1?l0000?ooooo`;o00001_ooool2o`0000Oooooo0ol00003ooooo`;o0000
2ooooolIo`0000Gooooo0_l000000ooooooo0000o`000008ooooo`;o00001Oooool2o`0001_ooooo
0ol00006ooooo`;o00001?ooool2o`000003ooooool0003o000000Wooooo0_l00005ooooo`Co0000
4?ooool2o`0000;ooooo1?l0000?ooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0??oo
ool2o`0000oooooo0_l00006ooooo`;o00001_ooool3o`000004ooooool0003o0000ooooo`;o0000
2oooool=o`000003ooooool0003o000000So00002Oooool2o`0000Sooooo0_l00005ooooo`;o0000
4oooool2o`0000Oooooo0_l00006ooooo`;o00001?ooool2o`000003ooooool0003o000000Oooooo
0_l00003ooooo`;o00000_ooool2o`00013ooooo1?l000000ooooooo0000o`000007ooooo`;o0000
2Oooool2o`0003Sooooo000Looooo`03o`000?oooooooooo043ooooo0_l00002ooooo`Co00001Ooo
ool2o`0000Oooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000kooooo6Ol0
0008ooooo`;o00001_ooool2o`00017ooooo0_l00009ooooo`;o00001?ooool2o`0000Cooooo0_l0
0002ooooo`?o00000_ooool2o`0000cooooo0_l00003ooooo`?o00004oooool2o`0000?ooooo1?l0
0005ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0??ooool2o`0000;ooooo0_l00002
ooooo`Co00000oooool4o`0000Oooooo0_l00002ooooo`;o00000oooool2o`0000Gooooo0_l00009
ooooo`;o00000_oooolFo`0000oooooo0ol00005ooooo`;o00002?ooool3o`0000_ooooo1_l00004
ooooo`;o00000_ooool4o`000003ooooool0003o000000cooooo1?l00002ooooo`;o00006Oooool3
o`0004[ooooo000Looooo`03o`000?oooooooooo03cooooo0_l0000=ooooo`;o00004_ooool2o`00
00Gooooo0_l0000=oooooaKo00003Oooool2o`000003ooooool0003o000000Gooooo0_l00006oooo
o`Go00000oooool2o`0000Kooooo1_l00004ooooo`;o00001?ooool2o`0000;ooooo0_l00009oooo
o`;o00000_ooool2o`000005ooooool0003o0000o`000?ooool00_l0000Cooooo`Co00000oooool2
o`0004Oooooo000Looooo`03o`000?oooooooooo03Wooooo0_l00002ooooo`;o000000?oooooo`00
0?l000005?ooool2o`0000Oooooo0_l00005ooooo`;o00003Oooool7o`000003ooooool0003o0000
00Oo00000_ooool2o`0000Sooooo0_l00004ooooo`;o00001_ooool2o`000003ooooool0003o0000
00Gooooo0_l00006ooooo`Co00001oooool3o`0000Cooooo0_l00008ooooo`;o00000_ooool2o`00
00Gooooo0_l00005ooooo`?o000000Coooooo`000?l0003ooooo0_l0000@ooooo`Co00000oooool2
o`0004Oooooo000Looooo`03o`000?oooooooooo03Wooooo0_l00002ooooo`;o000000?oooooo`00
0?l000003_ooool2o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`;o00001Oooool2o`00
00Oooooo0_l00007oooooa;o00002?ooool2o`0000Kooooo0ol000000ooooooo0000o`000002o`00
0003ooooool0003o000000oooooo0ol0000;ooooo`;o00001_ooool2o`0000Kooooo0_l00002oooo
o`;o00002Oooool2o`0000Cooooo0_l0000>ooooo`;o0000D?ooool001cooooo00?o0000oooooooo
ool0?Oooool2o`00017ooooo0_l00007ooooo`;o00005?ooool2o`0000Kooooo4_l0000Aooooo`Ko
00001_ooool4o`0000Cooooo0ol00004ooooo`Co00002Oooool2o`0000Kooooo1?l00007ooooo`?o
00002Oooool2o`0001Cooooo0_l00005ooooo`;o0000BOooool001cooooo0_l0000Uooooo`;o0000
5oooool4o`0000?ooooo0_l0000<ooooo`;o00008oooool?o`000003ooooool0003o000000Co0000
4?ooool2o`0000;ooooo0_l00003ooooo`_o000000?oooooo`000?l000000_l000000ooooooo0000
o`000003ooooo`;o00001Oooool4o`0000Gooooo0_l00007ooooo`;o00002_ooool3o`0000gooooo
0_l00005ooooo`;o00001?ooool2o`0004Wooooo000Looooo`03o`000?oooooooooo02Cooooo0_l0
000Iooooo`;o00000oooool2o`0000Kooooo0_l00004ooooo`;o00001Oooool2o`0001gooooo3Ol0
0002ooooo`Ko00000oooool2o`0000Gooooo1?l00005ooooo`?o000000Goooooo`000?l0003o0000
ooooo`06o`000003ooooool0003o000000Go00001_ooool2o`0000?ooooo1_l0000Booooo`;o0000
0oooool2o`000003ooooool0003o000000;o00003?ooool2o`0000Gooooo0_l0000?ooooo`;o0000
?_ooool001cooooo00?o0000ooooooooool0C?ooool2o`0000_ooooo0_l00003ooooo`?o00002ooo
ool2o`0000_ooooo1?l00003ooooo`;o00001Oooool3o`0000Kooooo0_l00005ooooo`Co00001Ooo
ool2o`0000;ooooo4ol000001?oooooo0000o`000?l00006ooooo`;o00004?ooool2o`0000Cooooo
0_l00003ooooo`;o00000oooool2o`0002Cooooo0_l0000nooooo`007?ooool00ol0003ooooooooo
o`0oooooo`;o00004?ooool2o`0000?ooooo0_l00005ooooo`Co00002?ooool2o`000003ooooool0
003o000000Cooooo0ol00004ooooo`Co00000oooool4o`0000;ooooo0ol0000Eooooo`Co000000?o
ooooo`000?l000004_l000001?oooooo0000o`000?l00007ooooo`?o00003_ooool2o`0007Cooooo
000Looooo`03o`000?oooooooooo03oooooo0_l0000@ooooo`;o00000oooool2o`0000Gooooo0_l0
0009ooooo`?o00001oooool3o`0000Cooooo0_l00005ooooo`Co00000_ooool3o`0000oooooo0_l0
00000ooooooo0000o`00000Io`0000?ooooo0_l00004ooooo`;o000000Coooooo`000?l0003o0000
0_ooool6o`00017ooooo0_l00002ooooo`Co0000Hoooool001cooooo00?o0000ooooooooool0DOoo
ool2o`0000Gooooo0_l00009ooooo`;o00000oooool3o`0000kooooo0_l0000Looooo`?o000000?o
ooooo`000?l000000_l000000ooooooo0000o`00000Do`0000?ooooo1?l00002ooooo`Co00001?oo
ool6o`0000Gooooo0_l00005ooooo`;o00000oooool2o`0000;ooooo1?l0000;ooooo`;o0000E_oo
ool001cooooo00?o0000ooooooooool0BOooool2o`0000Kooooo0ol00004ooooo`;o00002Oooool2
o`0000Cooooo0_l0000:ooooo`;o000000?oooooo`000?l000001_ooool2o`000003ooooool0003o
000000Cooooo0_l00007ooooo`;o00000_ooool4o`000003ooooool0003o000000Co000000?ooooo
o`000?l000004_l00005ooooo`;o00000_ooool4o`0000Kooooo0_l00007ooooo`;o00001Oooool2
o`0000Sooooo0_l00007ooooo`;o00000oooool2o`0001oooooo0_l0000eooooo`007?ooool00ol0
003oooooooooo`0oooooo`;o00000oooool2o`0000?ooooo0_l00006ooooo`?o00001oooool4o`00
01Kooooo0_l000001?oooooo0000o`000?ooool4o`000004ooooool0003o0000ooooo`;o00001?oo
ool3o`0000Kooooo0_l00002ooooo`Go00001?ooool;o`000003ooooool0003o000000Oo000000?o
ooooo`000?l000000oooool2o`0000_ooooo1?l00005ooooo`?o00004?ooool2o`000003ooooool0
003o000000Cooooo0_l00009ooooo`;o000000?oooooo`000?l000005_ooool2o`0003Gooooo000L
ooooo`03o`000?oooooooooo03oooooo0_l00003ooooo`;o00000_ooool2o`0000_ooooo0_l00004
ooooo`Co00000_ooool2o`0000Wooooo0_l0000=ooooo`Co00002oooool2o`0000gooooo0_l00000
1?oooooo0000o`000?ooool;o`000003ooooool0003o000000_o00000_ooool2o`0000Wooooo1_l0
0002ooooo`;o000000Coooooo`000?l0003o00000oooool2o`0000kooooo0_l0000?ooooo`;o0000
00?oooooo`000?l000001oooool2o`0004Cooooo000Looooo`03o`000?oooooooooo04Sooooo1?l0
0009ooooo`;o00002Oooool3o`0000Sooooo0ol0000@ooooo`;o00000oooool2o`0001Oooooo6Ol0
00000ooooooo0000o`00000=ooooo`;o00000_ooool3o`000003ooooool0003o000000Oooooo0ol0
0005ooooo`?o00000oooool4o`0001_ooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`1:
ooooo`Co000000?oooooo`000?l000000_ooool3o`0000[ooooo0_l00009ooooo`?o00004?ooool2
o`0000?ooooo0_l0000Ioooooa[o00003Oooool2o`0000?ooooo1_l00006ooooo`?o00001Oooool4
o`0000;ooooo1Ol00002ooooo`;o00003Oooool2o`0004gooooo000Looooo`03o`000?oooooooooo
04[ooooo1?l000000ooooooo0000o`000002ooooo`?o0000;oooool4o`0001Oooooo6?l00005oooo
o`;o00001_ooool2o`0000Gooooo1?l00002ooooo`Co000000?oooooo`000?l000001Oooool4o`00
00Gooooo0_l00002ooooo`?o00001Oooool2o`0000Gooooo0_l0001=ooooo`007?ooool00ol0003o
ooooooooo`1:ooooo`;o00004_ooool3o`0000?ooooo0_l0000Oooooo`Co00002Oooool2o`0000So
oooo0_l00002oooooaKo00001oooool2o`0000gooooo1?l00002ooooo`Co000000?oooooo`000?l0
00001?ooool3o`0000Wooooo1Ol00002ooooo`Go00001?ooool2o`0004kooooo000Looooo`03o`00
0?oooooooooo04Wooooo0_l0000Booooo`Go00000_ooool2o`0000[ooooo1?l000000ooooooo0000
o`00000;ooooo`;o000000?oooooo`000?l000002oooool2o`0000Sooooo0_l00003oooooaGo0000
3_ooool2o`0000Kooooo0_l00003ooooo`;o00002_ooool2o`0000[ooooo0ol00004ooooo`Go0000
1?ooool3o`0004gooooo000Looooo`03o`000?oooooooooo04Wooooo0_l0000Booooo`;o000000?o
ooooo`000?l000003_ooool4o`000003ooooool0003o000000_ooooo0_l0000;ooooo`;o00001ooo
ool2o`0000Oooooo5?l000000ooooooo0000o`00000;ooooo`Go00001?ooool2o`0000?ooooo1?l0
0008ooooo`;o00002_ooool2o`0000Oooooo0_l00006ooooo`;o0000COooool001cooooo00?o0000
ooooooooool0COooool2o`000003ooooool0003o000000;ooooo1Ol00004ooooo`Go00000oooool2
o`0000Oooooo1?l0000;ooooo`;o00000oooool2o`0000_ooooo0_l00007ooooo`;o00001ooooolB
o`0000?ooooo0_l0000;ooooo`;o000000Coooooo`000?l0003ooooo1Ol00004ooooo`?o00002?oo
ool2o`0006[ooooo000Looooo`;o0000C_ooool5o`0000;ooooo1Ol00002ooooo`Go00001Oooool2
o`0000;ooooo0_l00003ooooo`Go00002_ooool2o`0000?ooooo0_l0000>ooooo`;o00003OoooolB
o`000003ooooool0003o000000cooooo0_l00005ooooo`?o00001_ooool3o`0001_ooooo0_l0001G
ooooo`007?ooool00ol0003oooooooooo`1=ooooo`?o00002oooool4o`0000[ooooo0_l00004oooo
o`Oo00007?ooool2o`0000;ooooo0ol00008ooooo`Oo000000?oooooo`000?l000001_l00003oooo
o`;o00002?ooool2o`0000;ooooo1?l000000ooooooo0000o`00000?ooooo`;o00001oooool2o`00
0003ooooool0003o000000Kooooo0_l00002ooooo`;o00000oooool2o`0005;ooooo000Looooo`03
o`000?oooooooooo04gooooo0_l00009ooooo`;o00000_ooool4o`0001?ooooo1Ol0000Dooooo`;o
00002?ooool3o`0000_ooooo1?l00002ooooo`Oo00000oooool2o`000003ooooool0003o000000;o
000000?oooooo`000?l000000_l00004ooooo`;o000000?oooooo`000?l000003_ooool4o`0000Co
oooo1?l000000ooooooo0000o`000006ooooo`;o00001oooool2o`0005;ooooo000Looooo`03o`00
0?oooooooooo05Sooooo0_l00002ooooo`Co00005_ooool2o`0000[ooooo0_l00008ooooo`;o0000
4Oooool2o`0000Cooooo1_l000000ooooooo0000o`000003o`000003ooooool0003o000000?ooooo
1?l000000ooooooo0000o`00000=ooooo`?o00002Oooool4o`0000Cooooo0_l0000<ooooo`?o0000
FOooool001cooooo00?o0000ooooooooool0JOooool2o`0000Wooooo1_l00008ooooo`;o00005_oo
ool2o`0000?ooooo0ol00005ooooo`[o000000?oooooo`000?l000001?ooool2o`0000cooooo0_l0
00000ooooooo0000o`000003o`0001Gooooo0_l00008ooooo`Co00000_ooool2o`0005Cooooo000L
ooooo`03o`000?oooooooooo03cooooo0_l0000Oooooo`Co00001oooool3o`0000Wooooo0_l00002
ooooo`;o00004?ooool2o`0000kooooo0ol00003ooooo`;o00001_ooool5o`000003ooooool0003o
000000Sooooo0_l00008ooooo`;o00000_ooool2o`000003ooooool0003o000000Wooooo0_l0000=
ooooo`;o00002_ooool2o`0000;ooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`0loooo
o`;o00007oooool6o`0000Gooooo0ol00008ooooo`;o000000Coooooo`000?l0003ooooo0_l0000;
ooooo`;o00000_ooool2o`0000[ooooo0_l000000ooooooo0000o`000004o`0000?ooooo1_l00000
0ooooooo0000o`000007o`0000kooooo1Ol00008ooooo`Co00000oooool2o`0000Sooooo0_l0001Y
ooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o000000?oooooo`000?l000001_ooool2o`00
00Sooooo0_l000000ooooooo0000o`000004o`0000Cooooo0_l00004ooooo`;o00003_ooool2o`00
0003ooooool0003o000000Co00000oooool6o`0000Cooooo0_l00002ooooo`Co00003?ooool5o`00
0003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000002o`0000Wooooo0_l00002oooo
o`;o00002?ooool2o`0005oooooo000Looooo`03o`000?oooooooooo05Cooooo0_l00008ooooo`;o
00005oooool5o`0000Cooooo0_l0000Hooooo`;o00001_ooool2o`0000Gooooo0_l00007ooooo`;o
00003_ooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000002oooool2o`0000?o
oooo0_l00007ooooo`;o0000Goooool001cooooo00?o0000ooooooooool0E?ooool2o`0000Cooooo
0_l000001?oooooo0000o`000?l0000Pooooo`;o00007?ooool2o`0000;ooooo0_l00005ooooo`;o
00005_ooool2o`0000Oooooo0_l00008ooooo`;o000000?oooooo`000?l000001Oooool3o`0000Oo
oooo0_l00005ooooo`;o0000F?ooool001cooooo00?o0000ooooooooool0F_ooool2o`000003oooo
ool0003o000001cooooo0_l00002ooooo`;o00007Oooool2o`0000_ooooo0_l0000Dooooo`;o0000
1oooool2o`0000Sooooo0_l000000ooooooo0000o`000005ooooo`;o00001_ooool4o`0000Gooooo
0_l0001Hooooo`007?ooool00ol0003oooooooooo`1Vooooo`;o00003_ooool2o`0000?ooooo0_l0
0002ooooo`;o00006_ooool2o`0000_ooooo0_l000000ooooooo0000o`00000Nooooo`;o00002?oo
ool5o`0000cooooo0_l000000ooooooo0000o`00001Nooooo`007?ooool00ol0003oooooooooo`0k
ooooo`;o0000:Oooool2o`0000kooooo0_l000000ooooooo0000o`00000@ooooo`;o00003_ooool2
o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`;o00008Oooool2o`000003ooooool0003o
000000Gooooo0_l000000ooooooo0000o`00000?ooooo`;o0000G_ooool001cooooo00?o0000oooo
ooooool0>oooool2o`00023ooooo0_l0000@ooooo`;o00002?ooool2o`00013ooooo0ol0000Boooo
o`;o000000?oooooo`000?l000000ol00005ooooo`;o00002Oooool2o`0000?ooooo0_l00004oooo
o`;o00001Oooool2o`0000;ooooo0_l00005ooooo`;o00003oooool2o`00067ooooo000Looooo`03
o`000?oooooooooo05gooooo0_l0000@ooooo`;o00003?ooool2o`0000_ooooo1?l0000Gooooo`?o
00001Oooool2o`0000;ooooo0_l00005ooooo`?o00000_ooool2o`0000Cooooo0_l00005ooooo`;o
00001Oooool2o`0000;ooooo0_l0000?ooooo`;o000000?oooooo`000?l000000_l0001Looooo`00
7?ooool00ol0003oooooooooo`1Nooooo`?o00005?ooool2o`0000Kooooo0_l00003ooooo`;o0000
1_ooool2o`0000cooooo0_l0000Eooooo`Co00001_ooool2o`0000Sooooo0_l0000<ooooo`;o0000
0_ooool2o`0000;ooooo0_l0000>ooooo`Co0000G?ooool001cooooo0_l0001Oooooo`?o00003Ooo
ool4o`0000?ooooo0_l000000ooooooo0000o`000008ooooo`;o00000_ooool2o`00013ooooo0_l0
000Eooooo`Co00009_ooool3o`0001Wooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`1T
ooooo`;o00002?ooool5o`0000Gooooo0_l000000ooooooo0000o`000006ooooo`;o000000?ooooo
o`000?l000003_ooool2o`0001Kooooo1_l00002ooooo`;o00001Oooool2o`0001Wooooo1?l00004
ooooo`;o00000_ooool2o`0000oooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`1Toooo
o`?o00000oooool>o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000004Oooool2o`00
00Cooooo0_l0000@ooooo`Ko00000_ooool2o`0000Gooooo0_l0000>ooooo`;o000000?oooooo`00
0?l000001_ooool2o`0000Kooooo0_l00002ooooo`?o0000H_ooool001cooooo00?o0000oooooooo
ool0GOooool2o`0000Kooooo0_l00003ooooo`Oo000000?oooooo`000?l000001?l00003ooooo`;o
00000oooool2o`000003ooooool0003o000000Oooooo0_l00008ooooo`;o00001?ooool2o`0000_o
oooo0_l0000@ooooo`;o00002_ooool2o`0000Cooooo0_l000000ooooooo0000o`00000Cooooo`;o
0000H_ooool001cooooo00?o0000ooooooooool0GOooool2o`0000?ooooo0_l00003ooooo`;o0000
2Oooool2o`0000[ooooo0_l0000:ooooo`Co00001Oooool2o`0000_ooooo0_l00007ooooo`;o0000
00?oooooo`000?l000001_ooool2o`0000Gooooo0_l0000:ooooo`;o00001oooool2o`00013ooooo
0_l00008ooooo`;o0000Foooool001cooooo00?o0000ooooooooool0F_ooool2o`0000Kooooo0_l0
0003ooooo`;o00003oooool3o`0000?ooooo0ol00007ooooo`Go00001_ooool4o`0000Cooooo0_l0
0003ooooo`;o00001oooool2o`000003ooooool0003o000000Kooooo0_l00003ooooo`;o00005Ooo
ool2o`0000Oooooo0_l00007ooooo`;o00002?ooool4o`0005Wooooo000Looooo`03o`000?oooooo
oooo05[ooooo0_l0000>ooooo`;o00003?ooool3o`0000Cooooo1Ol00004ooooo`;o00001Oooool4
o`0000;ooooo0_l00004ooooo`;o00003?ooool6o`0000[ooooo0_l0000Eooooo`;o00001oooool2
o`0000Gooooo0_l0000<ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0Hoooool2o`00
00Gooooo0_l00008ooooo`;o00002_ooool4o`0000[ooooo1_l000000ooooooo0000o`000003oooo
o`?o00000_ooool2o`0000[ooooo1?l00002ooooo`;o00002_ooool3o`0000Wooooo1?l000000ooo
oooo0000o`000002o`0000?ooooo0_l00009ooooo`;o0000Ioooool001cooooo00?o0000oooooooo
ool0H_ooool4o`0000kooooo0_l00003ooooo`;o00001Oooool2o`0000cooooo0ol000001?oooooo
0000o`000?ooool2o`0000?ooooo0ol00002ooooo`;o00002?ooool6o`0000;ooooo0_l00002oooo
o`;o00000oooool2o`000005ooooool0003o0000o`000?ooool01?l00004ooooo`Co000000?ooooo
o`000?l000001Oooool2o`0000Wooooo0_l0001Wooooo`007?ooool00ol0003oooooooooo`1Roooo
o`Co00003?ooool3o`0000;ooooo1?l0000Iooooo`;o00002oooool3o`0000Gooooo1_l00006oooo
o`;o00000oooool2o`0000;ooooo1ol0000Dooooo`Co00000oooool4o`0006Gooooo000Looooo`03
o`000?oooooooooo06cooooo0_l00004ooooo`?o00000_ooool4o`0000cooooo0_l0000;ooooo`;o
00002Oooool5o`0000Cooooo0_l000000ooooooo0000o`00000<ooooo`?o00000_ooool4o`000003
ooooool0003o000001Cooooo1?l00005ooooo`;o0000IOooool001cooooo00?o0000ooooooooool0
K?ooool2o`0000Gooooo0_l00004ooooo`;o00003?ooool2o`0001?ooooo1_l00006ooooo`Go0000
1_ooool2o`0000Cooooo1?l000000ooooooo0000o`000003ooooo`;o00000_ooool2o`0000Oooooo
0_l00007ooooo`;o0000K_ooool001cooooo00?o0000ooooooooool0JOooool2o`00017ooooo0_l0
0003ooooo`?o00000_ooool3o`000003ooooool0003o0000013ooooo1ol00004ooooo`;o000000?o
ooooo`000?l000000_l00005ooooo`;o00001Oooool3o`000003ooooool0003o000000?ooooo0_l0
0002ooooo`;o00001oooool2o`000003ooooool0003o000000Gooooo0_l0001]ooooo`007?ooool0
0ol0003oooooooooo`1Oooooo`;o00001oooool3o`00017ooooo0_l00002ooooo`Co00000_ooool2
o`0000;ooooo0_l00007ooooo`Co00000oooool2o`0000Gooooo0_l00004ooooo`;o00000_ooool3
o`0001_ooooo0_l00005ooooo`Go00001Oooool2o`0006gooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`1Oooooo`;o00001oooool2o`0001Kooooo0_l000000ooooooo0000o`000002ooooo`;o0000
00?oooooo`000?l000001oooool4o`0000?ooooo0_l00002ooooo`;o00001Oooool2o`0000Cooooo
0_l00004ooooo`;o00000oooool2o`0000oooooo1?l00006ooooo`;o0000M_ooool00006oooooomg
MgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06oooo
o`03o`000?oooooooooo08?ooooo0_l00002ooooo`;o000000?oooooo`000?l000002Oooool2o`00
00;ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool3o`0000Gooooo0_l00002oooo
o`;o00000oooool2o`0000;ooooo0_l0000;ooooo`;o000000?oooooo`000?l00000OOooool00003
ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool0JOooool2o`0000gooooo0_l00007ooooo`Co00003_ooool2o`00
00Cooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000;ooooo0ol00004oooo
o`?o00001_ooool2o`0000?ooooo0_l00002ooooo`;o00001_ooool2o`0000;ooooo0_l0001moooo
o`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRH
V?lb<S801_ooool3o`0006Wooooo0_l00009ooooo`;o00000_ooool2o`0000Oooooo1?l0000>oooo
o`;o00001oooool4o`000005ooooool0003o0000o`000?ooool00_l000000ooooooo0000o`000002
ooooo`;o00001oooool2o`000003ooooool0003o000000Cooooo1?l000000ooooooo0000o`000003
o`00087ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Goc<c<o`00
0?l0003o0000olc<c006ooooo`03o`000?oooooooooo077ooooo0_l000000ooooooo0000o`00000M
ooooo`;o00001_ooool4o`0000;ooooo2Ol0000>ooooo`;o00000_ooool2o`000005ooooool0003o
0000o`000?ooool00ol0000Eooooo`;o0000K?ooool00003ooooool@413ooooo00;ooooo00?o410@
ooooooooool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0LOoo
ool2o`0002Sooooo1?l00004ooooo`?o000000Coooooo`000?l0003o00004_ooool2o`000004oooo
ool0003o0000o`0000gooooo0_l0000:ooooo`;o0000K?ooool00006oooooomgMgOoV9RHoooooonH
V9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0Yoooool2
o`0000Oooooo0_l00004ooooo`;o000000?oooooo`000?l000001Oooool2o`0000gooooo0_l0001h
ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0
1_ooool00ol0003oooooooooo`2:ooooo`;o00006Oooool2o`0000Wooooo0_l00003ooooo`?o0000
00?oooooo`000?l000000ol0000>ooooo`;o00003Oooool2o`0006cooooo000Looooo`03o`000?oo
oooooooo07kooooo0_l0000:ooooo`;o00006Oooool2o`0000kooooo0_l00004ooooo`?o00003_oo
ool2o`0000gooooo0_l0001/ooooo`007?ooool00ol0003oooooooooo`1nooooo`;o00002_ooool2
o`00023ooooo0_l000000ooooooo0000o`00000Wooooo`;o000000?oooooo`000?l00000K?ooool0
01cooooo00?o0000ooooooooool0[?ooool2o`000003ooooool0003o000002Oooooo0_l000000ooo
oooo0000o`00001/ooooo`007?ooool00ol0003oooooooooo`1^ooooo`;o00002Oooool2o`0001Wo
oooo0_l0000Jooooo`;o00002_ooool2o`0008_ooooo000Looooo`03o`000?oooooooooo06kooooo
0_l00009ooooo`;o00001_ooool2o`00017ooooo0_l00006ooooo`;o00001?ooool2o`0000cooooo
0_l0000:ooooo`;o00003oooool2o`0007[ooooo000Looooo`03o`000?oooooooooo087ooooo0_l0
0002ooooo`;o00005Oooool2o`0000Cooooo0_l00007ooooo`;o00008?ooool2o`0000cooooo0_l0
001/ooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o00009_ooool2o`0002Cooooo0_l0000^
ooooo`;o0000K?ooool001cooooo00?o0000ooooooooool0GOooool2o`00057ooooo0_l00003oooo
o`;o0000T_ooool001cooooo00?o0000ooooooooool0TOooool2o`0000Gooooo0_l0000Fooooo`;o
00000oooool2o`0000Oooooo0_l00029ooooo`007?ooool00ol0003oooooooooo`2:ooooo`;o0000
1Oooool2o`0000Gooooo0_l00009ooooo`;o00001Oooool2o`0000Cooooo0ol00009ooooo`Co0000
ROooool001cooooo00?o0000ooooooooool0R_ooool2o`0000cooooo0_l00009ooooo`;o00000_oo
ool2o`000003ooooool0003o000000Cooooo0ol00006ooooo`;o000000?oooooo`000?l00000Rooo
ool001cooooo0_l0002Tooooo`;o00000_ooool2o`00013ooooo0_l00002ooooo`?o00001_ooool2
o`00087ooooo000Looooo`03o`000?oooooooooo07Kooooo0ol0000Gooooo`;o00003?ooool2o`00
00Cooooo0_l0000Cooooo`;o00000_ooool3o`0000Kooooo0_l00021ooooo`007?ooool00ol0003o
ooooooooo`1fooooo`?o00005oooool2o`0000cooooo0_l00004ooooo`;o00004oooool2o`0008ko
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0N?oo
ool2o`0000;ooooo0_l0003;ooooo`007?ooool00ol0003oooooooooo`1gooooo`?o00000_ooool2
o`000<_ooooo000Looooo`03o`000?oooooooooo07Oooooo0_l00007ooooo`;o0000aoooool001co
oooo00?o0000ooooooooool0L?ooool2o`0000kooooo0_l00037ooooo`007?ooool00ol0003ooooo
ooooo`1`ooooo`;o0000eoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`2;ooooo`;o00004_ooool2o`000:Sooooo000Looooo`03o`000?oooooooooo
08_ooooo0_l0000Booooo`;o00001Oooool2o`0000Gooooo0_l0002Jooooo`007?ooool00ol0003o
ooooooooo`1hooooo`;o00001?ooool2o`0002Kooooo0_l00005ooooo`;o0000V_ooool001cooooo
00?o0000ooooooooool0N?ooool2o`0000Cooooo0_l00039ooooo`007?ooool00ol0003ooooooooo
o`2Dooooo`;o0000/oooool001cooooo00?o0000ooooooooool0U?ooool2o`000;?ooooo000Loooo
o`;o0000U_ooool2o`000;;ooooo000Looooo`03o`000?oooooooooo09Gooooo0_l0002booooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001;ooooo1?l000000ol@
413oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo
0ol0003ooooood[ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000
ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03
o`000?oooooooooo0?ooooooD_ooool001;ooooo00?oEEEEofIVI_l00000oooooomDooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00XOooool01?l@413o0000o`000?ooool2o`00
0003oa0@4?oooooooooo01Kooooo1?l000001?l@413oooooooooooooool4o`000003oa0@4?oooooo
oooo00;ooooo00?o0000onk^k_ooool00oooool01Oo^k^ko<S8bo`000?l@413oc<c<08cooooo002R
ooooo`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`03oeEEEOnYZJWooooo00?ooooo00GoEEEEogMgMoooooooV9RH
ob4Q8@2<ooooo`00X_ooool01Ol0003ooooooooooooooooo000001_ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`04ooooo`03ojVYZOmEEEGooooo00?ooooo00Go0000oooooooooooo
ooooo`00002<ooooo`00X_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l0000<ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00olQ8B7oooooooooo`02ooooo`05
o`000?nHV9SooooooiRHV?lQ8B40S?ooool00:;ooooo00Go0000ohN7QoooooooZJVYo`00000Koooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00omEEEGoc<c<ooooo`02oooo
o`05o`000?mEEEGo0000oa0@4?o<c<`0S?ooool00:7ooooo00?o410@o`000?mgMgL00_l000000onH
V9Soooooooooo`0Iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00onY
ZJWoMgMgooooo`02ooooo`03oeEEEOn7QhOooooo08kooooo0032ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo<S8b00?ooooo00?ogMgMoa0@
4?nHV9P0S_ooool00<3ooooo00?oEEEEofIVI_l000001Oooool00omEEEGoIVIVo`000004ooooo`Go
00001?ooool01?o<c<coA4A4o`000?l@412<ooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1182) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.53985 .30113 Mdot
.51337 .35076 Mdot
.35466 .60014 Mdot
.63384 .4862 Mdot
.22836 .37994 Mdot
.38343 .58631 Mdot
.40885 .41382 Mdot
.36174 .44657 Mdot
.36182 .58253 Mdot
.4 .25626 Mdot
.40535 .42644 Mdot
.73261 .53737 Mdot
.38863 .43761 Mdot
.65877 .49361 Mdot
.24038 .28518 Mdot
.60355 .54975 Mdot
.49248 .3231 Mdot
.50499 .65206 Mdot
.712 .52549 Mdot
.3765 .54753 Mdot
.47275 .33662 Mdot
.64819 .49587 Mdot
.53709 .36873 Mdot
.65966 .49385 Mdot
.60822 .49213 Mdot
.535 .32312 Mdot
.53485 .38946 Mdot
.61816 .52877 Mdot
.59854 .51276 Mdot
.36712 .45003 Mdot
.61261 .67109 Mdot
.21419 .34028 Mdot
.71261 .49963 Mdot
.24407 .65419 Mdot
.35767 .43025 Mdot
.68146 .39426 Mdot
.37464 .60164 Mdot
.37324 .42211 Mdot
.37061 .41639 Mdot
.38731 .3943 Mdot
.38821 .41985 Mdot
.53766 .33962 Mdot
.33161 .45147 Mdot
.44722 .56368 Mdot
.61614 .55925 Mdot
.285 .35287 Mdot
.79875 .44821 Mdot
.66127 .54112 Mdot
.5029 .31174 Mdot
.33229 .67765 Mdot
.24615 .4771 Mdot
.39287 .39888 Mdot
.41857 .5648 Mdot
.45133 .89575 Mdot
.36535 .4292 Mdot
.65034 .56691 Mdot
.36619 .60791 Mdot
.65462 .50515 Mdot
.66446 .49661 Mdot
.59747 .29139 Mdot
.65843 .55139 Mdot
.52072 .69154 Mdot
.5284 .28657 Mdot
.5249 .48255 Mdot
.36464 .59005 Mdot
.38493 .41208 Mdot
.52619 .35842 Mdot
.37941 .44088 Mdot
.58088 .4801 Mdot
.37836 .54448 Mdot
.65675 .54298 Mdot
.39677 .41675 Mdot
.50377 .30218 Mdot
.63647 .53444 Mdot
.41781 .75568 Mdot
.46862 .17524 Mdot
.51955 .72062 Mdot
.64157 .36384 Mdot
.59954 .32912 Mdot
.40788 .69273 Mdot
.64199 .47252 Mdot
.71558 .63439 Mdot
.40497 .19734 Mdot
.53114 .37782 Mdot
.62459 .43878 Mdot
.52478 .62715 Mdot
.64002 .53086 Mdot
.31262 .28901 Mdot
.59586 .52292 Mdot
.43211 .77853 Mdot
.37103 .57034 Mdot
.51035 .33298 Mdot
.63405 .48455 Mdot
.61679 .53862 Mdot
.77453 .52184 Mdot
.69344 .48028 Mdot
.6271 .51003 Mdot
.52925 .30454 Mdot
.3832 .39882 Mdot
.69754 .56122 Mdot
.42564 .53443 Mdot
.4197 .5922 Mdot
.69357 .50046 Mdot
.40935 .58843 Mdot
.4884 .31229 Mdot
.6316 .5387 Mdot
.36742 .41297 Mdot
.68963 .50274 Mdot
.44023 .34042 Mdot
.51166 .35346 Mdot
.61449 .53118 Mdot
.52311 .6698 Mdot
.71575 .7295 Mdot
.50122 .33448 Mdot
.44286 .68452 Mdot
.62311 .46978 Mdot
.63675 .51195 Mdot
.51518 .3487 Mdot
.38647 .62537 Mdot
.33248 .26485 Mdot
.54648 .36858 Mdot
.36859 .39556 Mdot
.55411 .31564 Mdot
.6063 .44276 Mdot
.37532 .57419 Mdot
.248 .56784 Mdot
.36097 .36441 Mdot
.62135 .64839 Mdot
.64563 .52711 Mdot
.38735 .29706 Mdot
.39041 .55797 Mdot
.52136 .33663 Mdot
.38079 .4439 Mdot
.72514 .49236 Mdot
.50974 .36596 Mdot
.39905 .44602 Mdot
.52943 .68223 Mdot
.29252 .51938 Mdot
.48548 .34557 Mdot
.44419 .53717 Mdot
.38225 .46121 Mdot
.39719 .39813 Mdot
.29427 .73219 Mdot
.52687 .35423 Mdot
.50463 .67587 Mdot
.37131 .44634 Mdot
.58939 .65397 Mdot
.63344 .56129 Mdot
.67886 .67753 Mdot
.82151 .47792 Mdot
.25588 .66997 Mdot
.31346 .53058 Mdot
.49202 .69653 Mdot
.35164 .40941 Mdot
.61216 .50274 Mdot
.53002 .31298 Mdot
.54188 .34007 Mdot
.67052 .54546 Mdot
.62143 .4853 Mdot
.64633 .54429 Mdot
.61471 .53949 Mdot
.56707 .24367 Mdot
.67063 .46989 Mdot
.80039 .49843 Mdot
.5068 .3296 Mdot
.62244 .49488 Mdot
.38386 .61881 Mdot
.67004 .45337 Mdot
.39057 .41698 Mdot
.64694 .50206 Mdot
.63114 .48744 Mdot
.66479 .5505 Mdot
.38834 .3979 Mdot
.26361 .28134 Mdot
.78977 .56542 Mdot
.21942 .35739 Mdot
.47294 .77388 Mdot
.40145 .58451 Mdot
.63745 .52509 Mdot
.51918 .67458 Mdot
.70749 .3762 Mdot
.65895 .47893 Mdot
.84694 .6243 Mdot
.63262 .50357 Mdot
.2301 .35554 Mdot
.57724 .54715 Mdot
.16878 .42813 Mdot
.68711 .65543 Mdot
.61063 .51213 Mdot
.54156 .54403 Mdot
.49806 .41072 Mdot
.42674 .54402 Mdot
.38863 .42283 Mdot
.37991 .62054 Mdot
.36003 .60871 Mdot
.3534 .46523 Mdot
.57466 .31303 Mdot
.55458 .47031 Mdot
.61194 .45174 Mdot
.38509 .54331 Mdot
.50788 .29045 Mdot
.51508 .70867 Mdot
.5465 .31905 Mdot
.47485 .13228 Mdot
.26415 .42962 Mdot
.33965 .44482 Mdot
.47393 .6789 Mdot
.36406 .56534 Mdot
.41683 .59479 Mdot
.50044 .66214 Mdot
.67331 .52231 Mdot
.53133 .35586 Mdot
.22597 .65551 Mdot
.51683 .24223 Mdot
.27489 .72462 Mdot
.522 .30386 Mdot
.43423 .26179 Mdot
.39824 .44353 Mdot
.38648 .60362 Mdot
.63337 .51192 Mdot
.66756 .52032 Mdot
.47675 .34838 Mdot
.64875 .54303 Mdot
.70087 .58588 Mdot
.62377 .51895 Mdot
.24767 .51547 Mdot
.52994 .71606 Mdot
.35163 .46395 Mdot
.62484 .63659 Mdot
.547 .35662 Mdot
.6165 .75563 Mdot
.41208 .59094 Mdot
.69006 .37157 Mdot
.39875 .41414 Mdot
.52692 .68786 Mdot
.41421 .57641 Mdot
.52054 .70855 Mdot
.71044 .50366 Mdot
.34997 .61081 Mdot
.5074 .65966 Mdot
.588 .34987 Mdot
.61519 .5473 Mdot
.55927 .23217 Mdot
.36341 .40213 Mdot
.54866 .3702 Mdot
.65096 .55206 Mdot
.40281 .5918 Mdot
.70865 .47923 Mdot
.33169 .48518 Mdot
.25059 .56359 Mdot
.40016 .62208 Mdot
.30639 .63352 Mdot
.51798 .70043 Mdot
.30335 .4492 Mdot
.41878 .28249 Mdot
.50081 .31009 Mdot
.67675 .47096 Mdot
.15563 .43387 Mdot
.37121 .44601 Mdot
.68673 .50505 Mdot
.23924 .61376 Mdot
.36749 .43807 Mdot
.65563 .50698 Mdot
.35039 .43755 Mdot
.54231 .34244 Mdot
.73212 .69403 Mdot
.49553 .31938 Mdot
.59395 .50439 Mdot
.36567 .41124 Mdot
.36713 .62735 Mdot
.52767 .31612 Mdot
.67786 .52374 Mdot
.62407 .52926 Mdot
.50194 .48496 Mdot
.62101 .50083 Mdot
.25715 .30092 Mdot
.61688 .51829 Mdot
.37086 .61716 Mdot
.70033 .50254 Mdot
.62213 .82447 Mdot
.31034 .39228 Mdot
.52745 .35788 Mdot
.37206 .63243 Mdot
.35899 .59149 Mdot
.45608 .70122 Mdot
.33304 .40232 Mdot
.64015 .46867 Mdot
.4031 .58558 Mdot
.66651 .71983 Mdot
.40124 .44955 Mdot
.67646 .46915 Mdot
.45073 .53748 Mdot
.3422 .689 Mdot
.4135 .56063 Mdot
.71946 .52424 Mdot
.48178 .33479 Mdot
.63214 .48397 Mdot
.40547 .61083 Mdot
.46647 .34159 Mdot
.60644 .47438 Mdot
.53298 .27676 Mdot
.50224 .48211 Mdot
.41234 .43138 Mdot
.57016 .53983 Mdot
.6875 .51545 Mdot
.39225 .60695 Mdot
.54864 .34914 Mdot
.39298 .45639 Mdot
.53384 .32945 Mdot
.18255 .50603 Mdot
.44298 .35292 Mdot
.57875 .29024 Mdot
.47844 .65176 Mdot
.30658 .67534 Mdot
.16361 .46027 Mdot
.55311 .80435 Mdot
.60329 .74291 Mdot
.19064 .58423 Mdot
.39309 .61843 Mdot
.25621 .63103 Mdot
.3589 .60087 Mdot
.61324 .48011 Mdot
.37266 .5789 Mdot
.16006 .45959 Mdot
.62379 .51717 Mdot
.37339 .58588 Mdot
.64459 .7503 Mdot
.62437 .48955 Mdot
.49626 .34044 Mdot
.32448 .23191 Mdot
.583 .81397 Mdot
.2429 .55321 Mdot
.35234 .57098 Mdot
.57427 .73907 Mdot
.62421 .50996 Mdot
.70301 .50186 Mdot
.50822 .31324 Mdot
.67043 .46457 Mdot
.50424 .70611 Mdot
.47398 .6761 Mdot
.48435 .41292 Mdot
.74691 .61722 Mdot
.60436 .56492 Mdot
.52259 .31322 Mdot
.59761 .24089 Mdot
.39895 .75255 Mdot
.31834 .6708 Mdot
.34704 .44106 Mdot
.31778 .24223 Mdot
.73172 .55804 Mdot
.38537 .48953 Mdot
.44476 .58432 Mdot
.50461 .34125 Mdot
.24767 .30265 Mdot
.3848 .42471 Mdot
.73742 .31534 Mdot
.55308 .60559 Mdot
.67352 .51841 Mdot
.40252 .41327 Mdot
.66166 .58221 Mdot
.56128 .82422 Mdot
.75261 .30805 Mdot
.73216 .59241 Mdot
.59298 .49906 Mdot
.43685 .75993 Mdot
.64231 .50564 Mdot
.35059 .25523 Mdot
.61659 .52145 Mdot
.52812 .32373 Mdot
.3786 .25482 Mdot
.50824 .43401 Mdot
.79397 .54601 Mdot
.29172 .39563 Mdot
.49257 .69735 Mdot
.62981 .51722 Mdot
.67479 .51668 Mdot
.50576 .70382 Mdot
.497 .36385 Mdot
.61499 .54066 Mdot
.60248 .7578 Mdot
.64558 .53566 Mdot
.38138 .41903 Mdot
.70727 .60152 Mdot
.57227 .34833 Mdot
.60734 .45933 Mdot
.51203 .29326 Mdot
.414 .43008 Mdot
.36396 .42131 Mdot
.61799 .56694 Mdot
.39712 .39475 Mdot
.63504 .49729 Mdot
.75767 .30474 Mdot
.48856 .34634 Mdot
.62236 .59232 Mdot
.52772 .3724 Mdot
.63455 .36701 Mdot
.35908 .42162 Mdot
.25273 .49156 Mdot
.73307 .5202 Mdot
.38679 .42759 Mdot
.44623 .35564 Mdot
.59501 .55183 Mdot
.58798 .51089 Mdot
.39698 .77971 Mdot
.35056 .5834 Mdot
.51257 .45954 Mdot
.35909 .44579 Mdot
.68347 .52249 Mdot
.62797 .45466 Mdot
.41475 .42563 Mdot
.67506 .25057 Mdot
.6225 .78114 Mdot
.62009 .51887 Mdot
.51921 .32243 Mdot
.52401 .33652 Mdot
.59092 .49775 Mdot
.68626 .48517 Mdot
.39082 .56701 Mdot
.35717 .62623 Mdot
.34682 .57805 Mdot
.5033 .47778 Mdot
.24932 .50175 Mdot
.23631 .41321 Mdot
.38846 .3945 Mdot
.41187 .31165 Mdot
.45078 .78216 Mdot
.63758 .44492 Mdot
.37644 .55168 Mdot
.68227 .50203 Mdot
.63844 .48918 Mdot
.40598 .45011 Mdot
.23327 .57544 Mdot
.69887 .57301 Mdot
.48856 .35685 Mdot
.37538 .45708 Mdot
.6799 .43967 Mdot
.31125 .36265 Mdot
.52295 .67398 Mdot
.31311 .73416 Mdot
.39485 .41392 Mdot
.49985 .34264 Mdot
.35429 .42581 Mdot
.66332 .52536 Mdot
.69934 .54475 Mdot
.51294 .34311 Mdot
.47905 .67196 Mdot
.7004 .47308 Mdot
.65299 .5085 Mdot
.83376 .54244 Mdot
.47283 .78378 Mdot
.25593 .51667 Mdot
.61257 .51365 Mdot
.60585 .46412 Mdot
.53716 .68243 Mdot
.65195 .53382 Mdot
.64126 .54782 Mdot
.75572 .67814 Mdot
.37926 .35499 Mdot
.47794 .6596 Mdot
.71429 .28171 Mdot
.51755 .30305 Mdot
.1806 .39278 Mdot
.391 .60241 Mdot
.34379 .40422 Mdot
.64947 .77183 Mdot
.42262 .56882 Mdot
.31819 .53423 Mdot
.19636 .37029 Mdot
.5119 .45717 Mdot
.34897 .64765 Mdot
.73515 .54055 Mdot
.62475 .54226 Mdot
.64236 .51028 Mdot
.51785 .67834 Mdot
.53381 .35233 Mdot
.51181 .4803 Mdot
.56763 .19733 Mdot
.64378 .49821 Mdot
.65715 .59939 Mdot
.50857 .2253 Mdot
.34787 .69091 Mdot
.49169 .68637 Mdot
.47637 .67551 Mdot
.63372 .51602 Mdot
.72932 .71293 Mdot
.53393 .32083 Mdot
.67882 .52245 Mdot
.64314 .46578 Mdot
.34927 .58338 Mdot
.50705 .35553 Mdot
.39785 .61556 Mdot
.26216 .46576 Mdot
.22175 .3616 Mdot
.84303 .53289 Mdot
.36086 .42236 Mdot
.41814 .21665 Mdot
.37741 .45374 Mdot
.71341 .63032 Mdot
.42073 .5843 Mdot
.65089 .47479 Mdot
.54792 .35228 Mdot
.68464 .51561 Mdot
.67872 .47972 Mdot
.67477 .52047 Mdot
.62993 .44897 Mdot
.79048 .70126 Mdot
.48856 .66501 Mdot
.58434 .48919 Mdot
.36205 .6144 Mdot
.34759 .24441 Mdot
.45812 .18288 Mdot
.67404 .51094 Mdot
.62666 .5253 Mdot
.49558 .3565 Mdot
.68357 .53471 Mdot
.39105 .4535 Mdot
.5507 .34299 Mdot
.61555 .53696 Mdot
.3278 .24323 Mdot
.60367 .52283 Mdot
.18755 .40021 Mdot
.35317 .43118 Mdot
.45932 .29536 Mdot
.58086 .50845 Mdot
.25324 .56247 Mdot
.51256 .45969 Mdot
.40406 .56773 Mdot
.39969 .3923 Mdot
.37266 .60011 Mdot
.63006 .19653 Mdot
.69657 .5411 Mdot
.61074 .49982 Mdot
.63787 .45502 Mdot
.4013 .58685 Mdot
.29037 .3099 Mdot
.29389 .43456 Mdot
.65966 .43473 Mdot
.39752 .57923 Mdot
.51897 .2882 Mdot
.56269 .65636 Mdot
.53689 .364 Mdot
.47234 .68106 Mdot
.40383 .42896 Mdot
.47989 .6875 Mdot
.22672 .60581 Mdot
.51119 .35127 Mdot
.52183 .39083 Mdot
.39054 .59533 Mdot
.49635 .58262 Mdot
.32548 .81272 Mdot
.53433 .59912 Mdot
.65201 .66581 Mdot
.50955 .3149 Mdot
.597 .49471 Mdot
.69863 .62411 Mdot
.4943 .56316 Mdot
.3705 .59929 Mdot
.65427 .48197 Mdot
.71639 .71221 Mdot
.39136 .56685 Mdot
.67851 .47077 Mdot
.35232 .6032 Mdot
.39641 .42297 Mdot
.37255 .5555 Mdot
.49406 .37213 Mdot
.62962 .53388 Mdot
.28131 .77083 Mdot
.50479 .72719 Mdot
.61881 .51094 Mdot
.37054 .45586 Mdot
.44787 .39804 Mdot
.67855 .48548 Mdot
.53255 .68772 Mdot
.38168 .57725 Mdot
.52903 .60165 Mdot
.61871 .52016 Mdot
.39965 .58637 Mdot
.54574 .30473 Mdot
.37694 .38992 Mdot
.58888 .41855 Mdot
.25286 .55699 Mdot
.50905 .31174 Mdot
.42609 .525 Mdot
.42387 .41082 Mdot
.60749 .46176 Mdot
.66162 .4657 Mdot
.52145 .32672 Mdot
.74774 .65818 Mdot
.69645 .52035 Mdot
.64255 .47272 Mdot
.36601 .6184 Mdot
.37437 .59454 Mdot
.73386 .68 Mdot
.37875 .62738 Mdot
.69973 .5431 Mdot
.5235 .32697 Mdot
.6383 .48232 Mdot
.49609 .35284 Mdot
.68878 .52636 Mdot
.47067 .3733 Mdot
.50028 .36808 Mdot
.30949 .41156 Mdot
.64729 .48331 Mdot
.58025 .55568 Mdot
.68713 .4995 Mdot
.64242 .54067 Mdot
.38677 .56612 Mdot
.49612 .67038 Mdot
.71119 .54311 Mdot
.49127 .71925 Mdot
.52135 .70694 Mdot
.45447 .39148 Mdot
.35033 .57999 Mdot
.50877 .68323 Mdot
.52355 .21842 Mdot
.34682 .58222 Mdot
.51876 .68947 Mdot
.45082 .18713 Mdot
.35792 .42816 Mdot
.48345 .33768 Mdot
.62339 .48878 Mdot
.19533 .5713 Mdot
.8021 .45229 Mdot
.3976 .52678 Mdot
.61697 .5163 Mdot
.68266 .49631 Mdot
.54234 .37176 Mdot
.69097 .21496 Mdot
.37275 .54536 Mdot
.6013 .49739 Mdot
.52194 .36018 Mdot
.75385 .27054 Mdot
.37174 .61466 Mdot
.51926 .68566 Mdot
.37674 .39678 Mdot
.51714 .27975 Mdot
.36282 .36475 Mdot
.41113 .41724 Mdot
.40838 .54522 Mdot
.24666 .48321 Mdot
.62379 .46945 Mdot
.38192 .55224 Mdot
.33351 .7579 Mdot
.52375 .24859 Mdot
.41471 .37602 Mdot
.56748 .73797 Mdot
.50435 .3392 Mdot
.38754 .45364 Mdot
.48339 .68258 Mdot
.52664 .30551 Mdot
.49271 .33727 Mdot
.41576 .43978 Mdot
.6779 .42081 Mdot
.45453 .54206 Mdot
.37441 .41763 Mdot
.4056 .7754 Mdot
.20734 .49763 Mdot
.37739 .55099 Mdot
.50614 .7055 Mdot
.21622 .58874 Mdot
.53777 .33819 Mdot
.3127 .24441 Mdot
.33792 .75387 Mdot
.62714 .50985 Mdot
.50386 .68252 Mdot
.26975 .35207 Mdot
.58391 .1858 Mdot
.36677 .43563 Mdot
.50003 .43912 Mdot
.49483 .70624 Mdot
.65579 .55111 Mdot
.57366 .65953 Mdot
.63672 .47554 Mdot
.40304 .43691 Mdot
.59259 .29536 Mdot
.49887 .34371 Mdot
.41607 .44265 Mdot
.31103 .73386 Mdot
.63764 .49631 Mdot
.64966 .48169 Mdot
.60992 .62905 Mdot
.5432 .32783 Mdot
.40505 .56844 Mdot
.63151 .46835 Mdot
.65042 .50581 Mdot
.68156 .56085 Mdot
.56619 .53583 Mdot
.71341 .72804 Mdot
.60571 .48618 Mdot
.28271 .40818 Mdot
.59975 .46407 Mdot
.65219 .48666 Mdot
.51014 .29322 Mdot
.84799 .56304 Mdot
.26458 .45431 Mdot
.64745 .50353 Mdot
.59829 .49283 Mdot
.42079 .43194 Mdot
.46302 .54025 Mdot
.4916 .58167 Mdot
.51762 .60099 Mdot
.58985 .74207 Mdot
.60952 .44942 Mdot
.52894 .36375 Mdot
.51453 .66165 Mdot
.60912 .46869 Mdot
.52586 .36425 Mdot
.65689 .55544 Mdot
.39331 .56736 Mdot
.34598 .59175 Mdot
.45112 .34386 Mdot
.51099 .68937 Mdot
.62665 .61249 Mdot
.39948 .31973 Mdot
.37276 .62241 Mdot
.61002 .49642 Mdot
.33265 .42396 Mdot
.40877 .60643 Mdot
.3727 .65327 Mdot
.57658 .44826 Mdot
.53775 .32276 Mdot
.5074 .3322 Mdot
.6812 .67878 Mdot
.30618 .51609 Mdot
.81193 .57982 Mdot
.39827 .42354 Mdot
.70338 .51941 Mdot
.40386 .2845 Mdot
.50423 .33307 Mdot
.69817 .6307 Mdot
.50724 .68485 Mdot
.36591 .43792 Mdot
.30056 .58869 Mdot
.50443 .36344 Mdot
.48988 .32824 Mdot
.60017 .53164 Mdot
.66217 .51123 Mdot
.61165 .74137 Mdot
.54729 .67448 Mdot
.41281 .43423 Mdot
.50808 .70547 Mdot
.41386 .56959 Mdot
.60404 .48672 Mdot
.53298 .37342 Mdot
.2206 .53905 Mdot
.60151 .48478 Mdot
.38647 .5639 Mdot
.50863 .33812 Mdot
.5127 .70523 Mdot
.53012 .69991 Mdot
.64225 .53951 Mdot
.60313 .24929 Mdot
.37496 .42629 Mdot
.49756 .33903 Mdot
.30945 .37162 Mdot
.7006 .49744 Mdot
.65651 .51561 Mdot
.56447 .4951 Mdot
.40387 .4496 Mdot
.45654 .27565 Mdot
.48484 .70415 Mdot
.53042 .34924 Mdot
.60691 .51168 Mdot
.51596 .69517 Mdot
.43961 .27695 Mdot
.40202 .62056 Mdot
.36948 .55785 Mdot
.53325 .69036 Mdot
.49762 .68694 Mdot
.53122 .69167 Mdot
.31375 .24238 Mdot
.51876 .38309 Mdot
.73304 .55451 Mdot
.69933 .51761 Mdot
.6733 .66527 Mdot
.72513 .48346 Mdot
.38681 .45988 Mdot
.35148 .58283 Mdot
.68482 .48794 Mdot
.59503 .49694 Mdot
.56738 .51981 Mdot
.64902 .59379 Mdot
.56706 .36914 Mdot
.50977 .35405 Mdot
.68692 .54456 Mdot
.34897 .60085 Mdot
.49627 .12518 Mdot
.16508 .56963 Mdot
.58423 .52789 Mdot
.47052 .57233 Mdot
.53179 .37484 Mdot
.41663 .40846 Mdot
.51132 .61164 Mdot
.35657 .41934 Mdot
.52711 .346 Mdot
.60535 .48537 Mdot
.40951 .31958 Mdot
.53495 .68659 Mdot
.67186 .53519 Mdot
.38861 .44886 Mdot
.66091 .54242 Mdot
.41048 .41597 Mdot
.1771 .48362 Mdot
.47565 .79863 Mdot
.63213 .50459 Mdot
.58712 .48569 Mdot
.55854 .75484 Mdot
.67552 .50831 Mdot
.537 .72976 Mdot
.52836 .37682 Mdot
.78395 .58726 Mdot
.61424 .55042 Mdot
.68519 .31267 Mdot
.70053 .49377 Mdot
.68845 .72718 Mdot
.65965 .51688 Mdot
.35201 .70166 Mdot
.61945 .53367 Mdot
.63708 .54534 Mdot
.36241 .4133 Mdot
.41921 .43507 Mdot
.50929 .29815 Mdot
.40485 .58598 Mdot
.20315 .37522 Mdot
.654 .51118 Mdot
.24823 .56319 Mdot
.41745 .34175 Mdot
.49649 .68838 Mdot
.53002 .34498 Mdot
.69029 .20798 Mdot
.34954 .42727 Mdot
.50044 .77045 Mdot
.69687 .70883 Mdot
.32536 .37806 Mdot
.52445 .62443 Mdot
.37291 .25161 Mdot
.52074 .69757 Mdot
.67072 .54733 Mdot
.23086 .5648 Mdot
.3525 .71879 Mdot
.57624 .44712 Mdot
.428 .42173 Mdot
.6982 .36202 Mdot
.22171 .55918 Mdot
.49964 .71439 Mdot
.48032 .69262 Mdot
.40255 .40428 Mdot
.30486 .59638 Mdot
.67079 .58235 Mdot
.50551 .68745 Mdot
.37117 .62495 Mdot
.36017 .5539 Mdot
.4297 .58631 Mdot
.53892 .32974 Mdot
.27578 .69904 Mdot
.31775 .34078 Mdot
.41143 .42148 Mdot
.33489 .63556 Mdot
.56436 .35468 Mdot
.5127 .38467 Mdot
.38389 .59934 Mdot
.38046 .56306 Mdot
.48135 .34636 Mdot
.65536 .56432 Mdot
.57539 .53839 Mdot
.64429 .50085 Mdot
.51272 .67001 Mdot
.66497 .51641 Mdot
.39335 .57467 Mdot
.37068 .43658 Mdot
.36983 .56595 Mdot
.35026 .44209 Mdot
.24755 .40564 Mdot
.66859 .53175 Mdot
.62681 .53354 Mdot
.80501 .43549 Mdot
.52918 .29657 Mdot
.27547 .40848 Mdot
.25223 .547 Mdot
.35886 .60395 Mdot
.6442 .54866 Mdot
.55215 .34972 Mdot
.48569 .71024 Mdot
.80654 .42348 Mdot
.69173 .49223 Mdot
.52958 .37456 Mdot
.60392 .50642 Mdot
.54882 .24863 Mdot
.684 .78176 Mdot
.53177 .33186 Mdot
.82006 .47636 Mdot
.59818 .50613 Mdot
.44828 .22166 Mdot
.64149 .45747 Mdot
.67429 .70575 Mdot
.69657 .51938 Mdot
.52013 .30316 Mdot
.64951 .50032 Mdot
.54799 .33133 Mdot
.3821 .61758 Mdot
.40567 .4015 Mdot
.50246 .32049 Mdot
.64688 .46326 Mdot
.10596 .5697 Mdot
.40053 .43577 Mdot
.63198 .51432 Mdot
.37095 .40069 Mdot
.53524 .35713 Mdot
.49933 .31759 Mdot
.54883 .18404 Mdot
.26701 .46265 Mdot
.39551 .42341 Mdot
.60353 .49267 Mdot
.32525 .31217 Mdot
.63561 .47895 Mdot
.63256 .71798 Mdot
.64644 .56814 Mdot
.70006 .50705 Mdot
.47553 .17529 Mdot
.40885 .44364 Mdot
.80707 .60254 Mdot
.53539 .18205 Mdot
.35678 .23216 Mdot
.49839 .28679 Mdot
.49597 .7141 Mdot
.25492 .29334 Mdot
.25214 .49593 Mdot
.39947 .5825 Mdot
.68647 .49333 Mdot
.56957 .3343 Mdot
.36925 .42361 Mdot
.49733 .66768 Mdot
.63213 .50542 Mdot
.37686 .5622 Mdot
.58198 .79224 Mdot
.34822 .41459 Mdot
.53704 .34099 Mdot
.49731 .36731 Mdot
.81442 .36348 Mdot
.6103 .51343 Mdot
.6258 .53632 Mdot
.40419 .43257 Mdot
.48542 .24031 Mdot
.52253 .69854 Mdot
.62625 .7633 Mdot
.39607 .42479 Mdot
.49052 .51424 Mdot
.52216 .3558 Mdot
.68303 .49849 Mdot
.27381 .31952 Mdot
.4289 .75232 Mdot
.75458 .34908 Mdot
.51813 .67409 Mdot
.62744 .71549 Mdot
.5182 .30255 Mdot
.37785 .44572 Mdot
.2914 .53945 Mdot
.64647 .44147 Mdot
.67911 .49807 Mdot
.63017 .71013 Mdot
.51563 .42417 Mdot
.72696 .59465 Mdot
.69375 .4917 Mdot
.52357 .44072 Mdot
.69482 .51149 Mdot
.67077 .44478 Mdot
.68416 .5554 Mdot
.65005 .52235 Mdot
.53031 .37484 Mdot
.60665 .43614 Mdot
.4017 .57139 Mdot
.72234 .57964 Mdot
.50102 .52286 Mdot
.61975 .51452 Mdot
.62488 .47646 Mdot
.7555 .3789 Mdot
.3901 .49495 Mdot
.50234 .32524 Mdot
.48621 .3742 Mdot
.38532 .39277 Mdot
.57049 .52984 Mdot
.40792 .58234 Mdot
.71599 .47391 Mdot
.3833 .56611 Mdot
.53869 .36599 Mdot
.36335 .61049 Mdot
.38731 .39594 Mdot
.36499 .55306 Mdot
.24867 .50252 Mdot
.36635 .44592 Mdot
.53033 .31207 Mdot
.63816 .5347 Mdot
.37043 .45554 Mdot
.61002 .64227 Mdot
.51385 .67111 Mdot
.53228 .17529 Mdot
.61154 .5348 Mdot
.37816 .35787 Mdot
.52349 .27231 Mdot
.37348 .5654 Mdot
.72355 .73629 Mdot
.49624 .36481 Mdot
.48048 .65939 Mdot
.54531 .36041 Mdot
.43244 .79075 Mdot
.4966 .67497 Mdot
.43952 .18733 Mdot
.2846 .60011 Mdot
.55644 .68487 Mdot
.64638 .56448 Mdot
.5628 .62942 Mdot
.40758 .5576 Mdot
.36847 .42436 Mdot
.30454 .54178 Mdot
.64316 .54708 Mdot
.52285 .79833 Mdot
.48694 .31109 Mdot
.40474 .58282 Mdot
.38183 .44169 Mdot
.38851 .45823 Mdot
.68016 .47646 Mdot
.38068 .66989 Mdot
.68709 .52227 Mdot
.29702 .49796 Mdot
.59903 .7341 Mdot
.64897 .5872 Mdot
.62447 .51855 Mdot
.39027 .60974 Mdot
.60387 .50579 Mdot
.49002 .64716 Mdot
.2709 .70406 Mdot
.67797 .46256 Mdot
.25102 .53731 Mdot
.48501 .72256 Mdot
.51228 .34638 Mdot
.6608 .57716 Mdot
.25895 .49841 Mdot
.60743 .50879 Mdot
.66374 .83144 Mdot
.51769 .69174 Mdot
.24535 .5782 Mdot
.62892 .45187 Mdot
.65435 .46762 Mdot
.52894 .5058 Mdot
.48666 .40393 Mdot
.43586 .75477 Mdot
.67205 .50044 Mdot
.59545 .69377 Mdot
.39761 .40581 Mdot
.68978 .51552 Mdot
.63971 .51165 Mdot
.68835 .4164 Mdot
.38283 .45664 Mdot
.35647 .58956 Mdot
.41944 .5673 Mdot
.34084 .58285 Mdot
.4901 .64989 Mdot
.49404 .45805 Mdot
.68121 .64615 Mdot
.57064 .81223 Mdot
.50455 .65619 Mdot
.60544 .53234 Mdot
.50233 .74581 Mdot
.61168 .47707 Mdot
.48614 .682 Mdot
.37833 .45533 Mdot
.49985 .32624 Mdot
.41772 .26929 Mdot
.38283 .54484 Mdot
.6719 .46684 Mdot
.50961 .70906 Mdot
.53232 .31513 Mdot
.53514 .65086 Mdot
.5199 .34961 Mdot
.39206 .42897 Mdot
.35781 .39692 Mdot
.49057 .67232 Mdot
.53239 .36717 Mdot
.40063 .47597 Mdot
.58854 .18989 Mdot
.69287 .55184 Mdot
.37551 .38353 Mdot
.54098 .30398 Mdot
.48049 .35944 Mdot
.53791 .30832 Mdot
.65293 .54219 Mdot
.46942 .56995 Mdot
.61261 .5601 Mdot
.4124 .43373 Mdot
.35218 .59827 Mdot
.55472 .7717 Mdot
.22865 .45938 Mdot
.45237 .65215 Mdot
.70136 .52442 Mdot
.64054 .49467 Mdot
.63389 .51573 Mdot
.60167 .54063 Mdot
.28627 .50419 Mdot
.68484 .51233 Mdot
.36458 .40959 Mdot
.38428 .57416 Mdot
.66801 .54901 Mdot
.42363 .58326 Mdot
.33293 .27529 Mdot
.50013 .65668 Mdot
.49058 .44316 Mdot
.12071 .47872 Mdot
.52306 .30988 Mdot
.38875 .62515 Mdot
.39828 .58545 Mdot
.52941 .68308 Mdot
.37528 .42206 Mdot
.52377 .3531 Mdot
.64956 .72684 Mdot
.52626 .70146 Mdot
.64981 .50242 Mdot
.47518 .6035 Mdot
.50602 .79135 Mdot
.68085 .54009 Mdot
.66601 .47769 Mdot
.40699 .61574 Mdot
.31524 .64942 Mdot
.30547 .77045 Mdot
.67194 .62854 Mdot
.49313 .67169 Mdot
.48372 .66528 Mdot
.4807 .3391 Mdot
.59956 .55285 Mdot
.41269 .43166 Mdot
.73461 .58314 Mdot
.45156 .42241 Mdot
.64408 .61497 Mdot
.56129 .42247 Mdot
.69137 .49603 Mdot
.66112 .23538 Mdot
.63594 .49529 Mdot
.52965 .37967 Mdot
.54266 .34929 Mdot
.51692 .31591 Mdot
.37005 .426 Mdot
.65838 .37236 Mdot
.36901 .40845 Mdot
.12384 .49354 Mdot
.51168 .303 Mdot
.27044 .55681 Mdot
.38654 .6092 Mdot
.58026 .51105 Mdot
.51312 .70389 Mdot
.43389 .41132 Mdot
.58162 .47747 Mdot
.73148 .71435 Mdot
.40373 .57813 Mdot
.52648 .30929 Mdot
.38522 .24517 Mdot
.15196 .49325 Mdot
.50002 .59331 Mdot
.70354 .45195 Mdot
.55569 .61906 Mdot
.49606 .69144 Mdot
.75876 .35362 Mdot
.5025 .7075 Mdot
.38182 .4508 Mdot
.62956 .53048 Mdot
.641 .53002 Mdot
.69479 .51647 Mdot
.67707 .52226 Mdot
.41489 .40486 Mdot
.70168 .48771 Mdot
.62205 .82448 Mdot
.34627 .60459 Mdot
.58781 .33398 Mdot
.51854 .69602 Mdot
.42376 .407 Mdot
.38602 .57374 Mdot
.36831 .50866 Mdot
.63527 .63772 Mdot
.62008 .51991 Mdot
.68628 .49052 Mdot
.49679 .77415 Mdot
.69442 .49179 Mdot
.72861 .48723 Mdot
.39981 .58505 Mdot
.45366 .65549 Mdot
.482 .66317 Mdot
.48076 .67645 Mdot
.35943 .44048 Mdot
.53886 .36472 Mdot
.51399 .68151 Mdot
.37724 .61768 Mdot
.70204 .52483 Mdot
.6302 .4653 Mdot
.53832 .30275 Mdot
.34655 .76116 Mdot
.49769 .71179 Mdot
.36092 .25823 Mdot
.54755 .34714 Mdot
.55099 .37751 Mdot
.67838 .49666 Mdot
.54815 .50768 Mdot
.52225 .27891 Mdot
.50514 .65511 Mdot
.42108 .40427 Mdot
.5245 .61028 Mdot
.40189 .4429 Mdot
.53916 .34832 Mdot
.60839 .47112 Mdot
.5438 .34255 Mdot
.61312 .5154 Mdot
.15019 .3974 Mdot
.6496 .52614 Mdot
.5691 .81703 Mdot
.66732 .69003 Mdot
.38581 .58656 Mdot
.44201 .40756 Mdot
.39143 .59985 Mdot
.54796 .3441 Mdot
.61783 .46581 Mdot
.47951 .695 Mdot
.39462 .2091 Mdot
.56472 .36008 Mdot
.39061 .56213 Mdot
.35262 .55536 Mdot
.37509 .45267 Mdot
.68921 .53602 Mdot
.68086 .502 Mdot
.37354 .58806 Mdot
.65623 .58786 Mdot
.5107 .36915 Mdot
.6248 .52714 Mdot
.64753 .49055 Mdot
.38632 .5891 Mdot
.60511 .19066 Mdot
.48286 .39447 Mdot
.63682 .52617 Mdot
.27039 .59949 Mdot
.38987 .45971 Mdot
.6353 .56517 Mdot
.59167 .46861 Mdot
.49995 .6871 Mdot
.59319 .39656 Mdot
.25764 .67927 Mdot
.36029 .45046 Mdot
.39692 .60028 Mdot
.60909 .51374 Mdot
.3918 .6079 Mdot
.6415 .46477 Mdot
.55828 .40671 Mdot
.398 .55929 Mdot
.6501 .4707 Mdot
.61123 .56752 Mdot
.54427 .32966 Mdot
.68914 .49294 Mdot
.76182 .41022 Mdot
.41425 .59518 Mdot
.6602 .4692 Mdot
.60181 .25145 Mdot
.37968 .41413 Mdot
.60638 .56385 Mdot
.51424 .66339 Mdot
.65051 .72831 Mdot
.36591 .33468 Mdot
.23516 .58121 Mdot
.49652 .65858 Mdot
.66542 .54106 Mdot
.34671 .56488 Mdot
.40772 .41002 Mdot
.59457 .80748 Mdot
.66694 .54642 Mdot
.40212 .43767 Mdot
.37214 .43807 Mdot
.52145 .67295 Mdot
.8394 .49292 Mdot
.62675 .45004 Mdot
.67282 .51148 Mdot
.73798 .42731 Mdot
.55157 .31041 Mdot
.65962 .52238 Mdot
.59623 .51247 Mdot
.3669 .40656 Mdot
.72948 .48499 Mdot
.72112 .36093 Mdot
.65461 .74536 Mdot
.38526 .46225 Mdot
.52221 .57886 Mdot
.3869 .54907 Mdot
.51235 .69788 Mdot
.51582 .34129 Mdot
.50428 .71025 Mdot
.36237 .55735 Mdot
.60257 .52766 Mdot
.35754 .40816 Mdot
.78369 .44995 Mdot
.40388 .40468 Mdot
.23547 .58963 Mdot
.5498 .31007 Mdot
.38235 .28991 Mdot
.72075 .78449 Mdot
.30468 .34803 Mdot
.38619 .49319 Mdot
.49653 .68794 Mdot
.37497 .5204 Mdot
.6449 .49134 Mdot
.77362 .37425 Mdot
.63742 .53871 Mdot
.60626 .25785 Mdot
.36332 .62274 Mdot
.34672 .57816 Mdot
.63266 .52847 Mdot
.60752 .73045 Mdot
.40973 .41033 Mdot
.40317 .44823 Mdot
.66972 .47276 Mdot
.3871 .42722 Mdot
.66432 .50845 Mdot
.38899 .56924 Mdot
.8047 .63059 Mdot
.63908 .50351 Mdot
.58824 .49535 Mdot
.36596 .37026 Mdot
.49392 .18208 Mdot
.27731 .65801 Mdot
.72197 .27201 Mdot
.15537 .5211 Mdot
.38676 .42832 Mdot
.61362 .56264 Mdot
.52461 .58041 Mdot
.42416 .57604 Mdot
.40117 .47939 Mdot
.65153 .53188 Mdot
.65144 .53474 Mdot
.63339 .54508 Mdot
.64811 .48065 Mdot
.75753 .34518 Mdot
.75982 .5188 Mdot
.61578 .30919 Mdot
.68191 .48233 Mdot
.57526 .63357 Mdot
.35634 .43983 Mdot
.47433 .3281 Mdot
.54406 .68524 Mdot
.69123 .4963 Mdot
.74697 .54002 Mdot
.41423 .44652 Mdot
.1237 .49519 Mdot
.3666 .44884 Mdot
.35935 .59191 Mdot
.41548 .40875 Mdot
.61971 .50208 Mdot
.52366 .33583 Mdot
.50865 .5555 Mdot
.30393 .45453 Mdot
.39958 .58155 Mdot
.61872 .51129 Mdot
.2654 .55016 Mdot
.40135 .57344 Mdot
.32846 .27911 Mdot
.51796 .33562 Mdot
.59717 .68577 Mdot
.54382 .34746 Mdot
.64792 .46989 Mdot
.64182 .47071 Mdot
.40555 .38574 Mdot
.40183 .40014 Mdot
.54351 .34994 Mdot
.84641 .50556 Mdot
.51822 .71057 Mdot
.52215 .31665 Mdot
.69951 .46449 Mdot
.44733 .49345 Mdot
.51996 .32978 Mdot
.46167 .64297 Mdot
.36411 .42952 Mdot
.49267 .31404 Mdot
.66434 .44579 Mdot
.35229 .7492 Mdot
.52346 .66446 Mdot
.36165 .64023 Mdot
.47235 .61677 Mdot
.41021 .6031 Mdot
.40616 .3952 Mdot
.39196 .59649 Mdot
.39388 .40425 Mdot
.38916 .34218 Mdot
.69721 .59574 Mdot
.33525 .41875 Mdot
.40856 .3976 Mdot
.39011 .59495 Mdot
.62168 .53034 Mdot
.49005 .61729 Mdot
.62074 .56445 Mdot
.63335 .44712 Mdot
.39501 .40859 Mdot
.52458 .30533 Mdot
.48481 .36061 Mdot
.57453 .65144 Mdot
.50613 .37339 Mdot
.38269 .56491 Mdot
.65354 .79771 Mdot
.23909 .5566 Mdot
.40436 .42046 Mdot
.42218 .4143 Mdot
.6332 .47758 Mdot
.37201 .60008 Mdot
.39111 .61295 Mdot
.38469 .45252 Mdot
.6083 .59331 Mdot
.58771 .52593 Mdot
.49205 .37738 Mdot
.50224 .30692 Mdot
.52776 .32833 Mdot
.54038 .31219 Mdot
.71133 .3256 Mdot
.36237 .43418 Mdot
.53152 .30891 Mdot
.65727 .47134 Mdot
.65268 .53324 Mdot
.51386 .59041 Mdot
.4825 .66985 Mdot
.65287 .55583 Mdot
.68325 .5547 Mdot
.68038 .49442 Mdot
.3733 .55653 Mdot
.57199 .46722 Mdot
.40059 .56111 Mdot
.34203 .59654 Mdot
.35258 .61885 Mdot
.25114 .49872 Mdot
.56006 .71022 Mdot
.17543 .55173 Mdot
.60108 .49875 Mdot
.50521 .23751 Mdot
.37661 .60895 Mdot
.72608 .72685 Mdot
.45893 .27179 Mdot
.65465 .5493 Mdot
.40868 .74746 Mdot
.3755 .58904 Mdot
.50124 .37102 Mdot
.65111 .53004 Mdot
.34336 .61424 Mdot
.52012 .66494 Mdot
.71108 .51978 Mdot
.41963 .58055 Mdot
.5324 .36539 Mdot
.53628 .66793 Mdot
.50304 .30443 Mdot
.35489 .62019 Mdot
.60906 .56589 Mdot
.37316 .85312 Mdot
.35821 .54653 Mdot
.51336 .20874 Mdot
.46077 .34576 Mdot
.62395 .52865 Mdot
.3966 .62034 Mdot
.55741 .33054 Mdot
.38745 .39041 Mdot
.45514 .43811 Mdot
.48934 .34138 Mdot
.34747 .57506 Mdot
.41886 .58898 Mdot
.40016 .58383 Mdot
.50533 .35057 Mdot
.59031 .49656 Mdot
.49948 .35305 Mdot
.41677 .41011 Mdot
.62864 .48508 Mdot
.16246 .45642 Mdot
.50705 .23986 Mdot
.54591 .34856 Mdot
.35692 .58165 Mdot
.53583 .68165 Mdot
.63081 .50114 Mdot
.54625 .22157 Mdot
.61423 .52654 Mdot
.40545 .41365 Mdot
.76926 .6526 Mdot
.78444 .4345 Mdot
.69891 .51625 Mdot
.63427 .47754 Mdot
.40967 .44087 Mdot
.62531 .51092 Mdot
.69562 .52364 Mdot
.25651 .48705 Mdot
.5102 .35813 Mdot
.64862 .49775 Mdot
.35676 .61223 Mdot
.23862 .49244 Mdot
.59222 .53167 Mdot
.44767 .69572 Mdot
.60475 .70118 Mdot
.78665 .60603 Mdot
.63464 .5392 Mdot
.66094 .62192 Mdot
.65745 .48222 Mdot
.67208 .53347 Mdot
.61472 .48134 Mdot
.77108 .34595 Mdot
.3931 .55789 Mdot
.39407 .58123 Mdot
.51891 .66049 Mdot
.60243 .69974 Mdot
.50253 .68414 Mdot
.3622 .42782 Mdot
.41593 .68069 Mdot
.39838 .55997 Mdot
.53617 .3638 Mdot
.67676 .53334 Mdot
.3572 .54679 Mdot
.68368 .50192 Mdot
.61779 .50242 Mdot
.40938 .58861 Mdot
.39531 .55135 Mdot
.24089 .57812 Mdot
.50648 .65885 Mdot
.51048 .31753 Mdot
.65018 .55914 Mdot
.5142 .70795 Mdot
.59748 .47802 Mdot
.67745 .6622 Mdot
.51308 .3184 Mdot
.5066 .35705 Mdot
.4877 .36139 Mdot
.60272 .52735 Mdot
.62315 .50366 Mdot
.37181 .407 Mdot
.54395 .35983 Mdot
.38129 .41552 Mdot
.5013 .4936 Mdot
.47012 .73103 Mdot
.65153 .53199 Mdot
.37247 .25661 Mdot
.50538 .69861 Mdot
.36652 .57292 Mdot
.52063 .77791 Mdot
.52096 .6613 Mdot
.61451 .51848 Mdot
.39701 .60666 Mdot
.4846 .67904 Mdot
.57926 .43574 Mdot
.18895 .62349 Mdot
.53962 .68378 Mdot
.66075 .47175 Mdot
.73337 .48214 Mdot
.73852 .2809 Mdot
.52572 .66209 Mdot
.37067 .39858 Mdot
.60401 .52879 Mdot
.54561 .28673 Mdot
.49536 .70959 Mdot
.28254 .40006 Mdot
.38021 .57973 Mdot
.29815 .71202 Mdot
.58156 .46719 Mdot
.79467 .43153 Mdot
.4924 .69984 Mdot
.52648 .35148 Mdot
.46683 .34259 Mdot
.67278 .49062 Mdot
.52674 .66292 Mdot
.39171 .46245 Mdot
.37583 .57512 Mdot
.26264 .45812 Mdot
.50323 .34928 Mdot
.36259 .2816 Mdot
.35733 .57435 Mdot
.35357 .2676 Mdot
.70893 .71239 Mdot
.58713 .55248 Mdot
.73189 .28249 Mdot
.30538 .56299 Mdot
.60767 .53955 Mdot
.52827 .70683 Mdot
.36314 .45232 Mdot
.36547 .39869 Mdot
.39558 .42872 Mdot
.40941 .34137 Mdot
.51231 .6005 Mdot
.38222 .62925 Mdot
.33591 .47397 Mdot
.51302 .69558 Mdot
.58204 .62318 Mdot
.63486 .46099 Mdot
.6404 .4963 Mdot
.6905 .53592 Mdot
.69293 .50636 Mdot
.66144 .48699 Mdot
.38154 .42197 Mdot
.37382 .34996 Mdot
.52609 .59905 Mdot
.5162 .32326 Mdot
.37379 .66257 Mdot
.38533 .60931 Mdot
.37581 .63204 Mdot
.48798 .6687 Mdot
.35108 .25689 Mdot
.42319 .58297 Mdot
.36053 .60823 Mdot
.62373 .54864 Mdot
.50496 .36292 Mdot
.68394 .44582 Mdot
.64405 .47342 Mdot
.37698 .56834 Mdot
.52244 .50511 Mdot
.74034 .37159 Mdot
.57449 .45673 Mdot
.46369 .68993 Mdot
.4712 .56166 Mdot
.53485 .67473 Mdot
.61767 .46303 Mdot
.73463 .71752 Mdot
.36547 .55536 Mdot
.36391 .59649 Mdot
.49452 .69945 Mdot
.57277 .38176 Mdot
.50757 .34063 Mdot
.35901 .50641 Mdot
.37752 .39952 Mdot
.62149 .47219 Mdot
.57834 .78849 Mdot
.5758 .3133 Mdot
.38335 .67337 Mdot
.39932 .42812 Mdot
.38522 .61475 Mdot
.69979 .52327 Mdot
.66123 .47258 Mdot
.49982 .69938 Mdot
.20603 .42276 Mdot
.69843 .53853 Mdot
.34389 .23573 Mdot
.47373 .7997 Mdot
.35289 .75875 Mdot
.67906 .49829 Mdot
.50945 .35636 Mdot
.421 .58377 Mdot
.50593 .7052 Mdot
.68613 .46023 Mdot
.18424 .59712 Mdot
.52333 .29877 Mdot
.37807 .44861 Mdot
.5135 .54207 Mdot
.5091 .60989 Mdot
.61345 .53936 Mdot
.63775 .53758 Mdot
.66073 .53787 Mdot
.22759 .67825 Mdot
.37949 .55833 Mdot
.53672 .37109 Mdot
.51276 .66706 Mdot
.51381 .37697 Mdot
.39143 .58586 Mdot
.36622 .28862 Mdot
.61773 .53132 Mdot
.52532 .29834 Mdot
.5248 .34975 Mdot
.37078 .45078 Mdot
.37607 .39047 Mdot
.50621 .51632 Mdot
.65128 .52445 Mdot
.36632 .54208 Mdot
.53835 .31749 Mdot
.47878 .60385 Mdot
.49643 .67674 Mdot
.36066 .42017 Mdot
.68478 .48592 Mdot
.38209 .55376 Mdot
.70136 .48617 Mdot
.50533 .33058 Mdot
.3616 .60904 Mdot
.24538 .57168 Mdot
.4882 .66134 Mdot
.66652 .52635 Mdot
.51623 .65208 Mdot
.39732 .60045 Mdot
.64534 .48957 Mdot
.41339 .22416 Mdot
.46856 .707 Mdot
.29453 .44606 Mdot
.3647 .62608 Mdot
.25032 .56154 Mdot
.4844 .34601 Mdot
.43316 .32987 Mdot
.3621 .59315 Mdot
.3757 .24608 Mdot
.20956 .45118 Mdot
.6913 .53891 Mdot
.53635 .33472 Mdot
.33963 .535 Mdot
.17656 .39153 Mdot
.60307 .19715 Mdot
.63376 .51368 Mdot
.37738 .62782 Mdot
.4933 .69589 Mdot
.40422 .41858 Mdot
.45157 .70354 Mdot
.46326 .69431 Mdot
.36773 .54583 Mdot
.61376 .48099 Mdot
.53206 .35687 Mdot
.36857 .43046 Mdot
.3705 .33731 Mdot
.36877 .61862 Mdot
.3523 .58832 Mdot
.69983 .52188 Mdot
.50813 .68553 Mdot
.57396 .21817 Mdot
.39194 .5706 Mdot
.49462 .7801 Mdot
.40834 .55089 Mdot
.51638 .70959 Mdot
.66165 .47948 Mdot
.56906 .65329 Mdot
.61274 .55498 Mdot
.47216 .19894 Mdot
.38825 .60193 Mdot
.50754 .32523 Mdot
.64472 .54373 Mdot
.67702 .72693 Mdot
.37336 .57051 Mdot
.47236 .57286 Mdot
.34269 .69643 Mdot
.36304 .43194 Mdot
.52074 .77926 Mdot
.66658 .51887 Mdot
.40861 .40966 Mdot
.50443 .6976 Mdot
.64308 .52413 Mdot
.62362 .50107 Mdot
.54545 .36836 Mdot
.38632 .45112 Mdot
.19983 .48836 Mdot
.41801 .43999 Mdot
.35385 .42791 Mdot
.53429 .38255 Mdot
.66244 .49927 Mdot
.35841 .5914 Mdot
.37416 .59067 Mdot
.65826 .45042 Mdot
.76038 .70745 Mdot
.50464 .34147 Mdot
.33053 .6252 Mdot
.24617 .69988 Mdot
.59767 .56559 Mdot
.53305 .78213 Mdot
.21374 .41039 Mdot
.37316 .46242 Mdot
.676 .47637 Mdot
.53464 .36156 Mdot
.3767 .51212 Mdot
.35349 .58769 Mdot
.59354 .488 Mdot
.37355 .43324 Mdot
.52056 .66422 Mdot
.41424 .58211 Mdot
.38634 .67018 Mdot
.6727 .52942 Mdot
.40616 .74987 Mdot
.39302 .61954 Mdot
.27877 .25643 Mdot
.3545 .51868 Mdot
.5341 .32927 Mdot
.61825 .49942 Mdot
.48895 .35706 Mdot
.50617 .66493 Mdot
.5114 .53911 Mdot
.37163 .43487 Mdot
.75072 .49419 Mdot
.57066 .8523 Mdot
.40028 .58693 Mdot
.52948 .37665 Mdot
.69974 .51361 Mdot
.54337 .45888 Mdot
.6682 .51307 Mdot
.73695 .5176 Mdot
.49005 .73051 Mdot
.39128 .40956 Mdot
.39954 .40475 Mdot
.63939 .48771 Mdot
.5261 .69829 Mdot
.38063 .61529 Mdot
.37252 .57539 Mdot
.4129 .16135 Mdot
.3211 .40235 Mdot
.61821 .73905 Mdot
.65589 .53348 Mdot
.35359 .55842 Mdot
.23136 .46678 Mdot
.40398 .43151 Mdot
.64388 .45959 Mdot
.40747 .58158 Mdot
.37425 .75426 Mdot
.68826 .70434 Mdot
.66499 .4857 Mdot
.6005 .45659 Mdot
.37468 .39936 Mdot
.5944 .61889 Mdot
.35059 .6117 Mdot
.65197 .56821 Mdot
.3405 .41535 Mdot
.75543 .65459 Mdot
.31116 .74723 Mdot
.51083 .31712 Mdot
.32311 .66614 Mdot
.38057 .42173 Mdot
.61189 .4456 Mdot
.52289 .69031 Mdot
.41449 .56754 Mdot
.38391 .55653 Mdot
.60572 .49235 Mdot
.70233 .49107 Mdot
.54632 .75829 Mdot
.51429 .37487 Mdot
.35674 .43891 Mdot
.62918 .53624 Mdot
.41751 .26015 Mdot
.69516 .51393 Mdot
.37375 .4083 Mdot
.36079 .85401 Mdot
.66058 .55707 Mdot
.67053 .5107 Mdot
.57395 .21565 Mdot
.48978 .33881 Mdot
.52265 .38032 Mdot
.52187 .81707 Mdot
.65686 .53299 Mdot
.50892 .77865 Mdot
.50644 .31859 Mdot
.50485 .33834 Mdot
.27025 .47349 Mdot
.63443 .50041 Mdot
.77136 .53641 Mdot
.40965 .4164 Mdot
.35472 .42121 Mdot
.49958 .35065 Mdot
.6752 .5525 Mdot
.34851 .43652 Mdot
.71308 .29365 Mdot
.37323 .60106 Mdot
.75252 .69944 Mdot
.49624 .33678 Mdot
.50927 .43913 Mdot
.40212 .42819 Mdot
.12386 .49101 Mdot
.4285 .57007 Mdot
.623 .53162 Mdot
.66493 .52995 Mdot
.50821 .69912 Mdot
.66021 .55632 Mdot
.3457 .5839 Mdot
.38732 .42674 Mdot
.57577 .26275 Mdot
.51772 .31557 Mdot
.65767 .51759 Mdot
.34247 .26736 Mdot
.27444 .38274 Mdot
.2846 .64672 Mdot
.51337 .34629 Mdot
.53814 .3302 Mdot
.35022 .60784 Mdot
.38055 .62694 Mdot
.66743 .49457 Mdot
.40622 .44321 Mdot
.54465 .3577 Mdot
.38254 .40598 Mdot
.36534 .55584 Mdot
.35696 .59554 Mdot
.39347 .55571 Mdot
.71732 .52355 Mdot
.3601 .6118 Mdot
.43093 .65689 Mdot
.35379 .28869 Mdot
.51473 .38543 Mdot
.40646 .80874 Mdot
.38056 .3347 Mdot
.45026 .37369 Mdot
.48569 .70396 Mdot
.39792 .60022 Mdot
.42195 .42061 Mdot
.64012 .48058 Mdot
.68594 .49634 Mdot
.40046 .64526 Mdot
.41789 .41787 Mdot
.4995 .66629 Mdot
.41092 .40916 Mdot
.52192 .67321 Mdot
.36524 .72779 Mdot
.6827 .54133 Mdot
.63293 .46614 Mdot
.38691 .42222 Mdot
.36206 .61161 Mdot
.38768 .57765 Mdot
.53881 .67667 Mdot
.54016 .41837 Mdot
.40225 .57405 Mdot
.49836 .33443 Mdot
.698 .30662 Mdot
.41902 .59015 Mdot
.65479 .52738 Mdot
.6885 .6422 Mdot
.78756 .40582 Mdot
.60076 .53971 Mdot
.26477 .47724 Mdot
.80732 .48764 Mdot
.65608 .54608 Mdot
.81885 .4615 Mdot
.25361 .55643 Mdot
.48857 .35116 Mdot
.36006 .62073 Mdot
.402 .62232 Mdot
.71383 .54741 Mdot
.53807 .70265 Mdot
.6762 .45485 Mdot
.49269 .3311 Mdot
.50334 .29498 Mdot
.39304 .77477 Mdot
.50698 .20612 Mdot
.48934 .69144 Mdot
.48342 .67478 Mdot
.36342 .58946 Mdot
.57789 .16753 Mdot
.60417 .44097 Mdot
.49438 .66968 Mdot
.66655 .60552 Mdot
.61094 .48133 Mdot
.64238 .70108 Mdot
.47383 .77229 Mdot
.50513 .35298 Mdot
.56549 .63698 Mdot
.36266 .58237 Mdot
.50309 .36951 Mdot
.42664 .2659 Mdot
.63804 .5574 Mdot
.51475 .3178 Mdot
.38009 .40498 Mdot
.32284 .52566 Mdot
.5005 .31697 Mdot
.6855 .64938 Mdot
.38913 .45247 Mdot
.47802 .59883 Mdot
.58455 .66566 Mdot
.87829 .59613 Mdot
.38212 .42471 Mdot
.40888 .5678 Mdot
.37407 .58949 Mdot
.37114 .57679 Mdot
.50966 .37405 Mdot
.39224 .61128 Mdot
.52101 .37638 Mdot
.67232 .2254 Mdot
.56335 .41697 Mdot
.49091 .67346 Mdot
.26819 .45578 Mdot
.53466 .34612 Mdot
.68985 .77289 Mdot
.66185 .82145 Mdot
.67906 .47765 Mdot
.42464 .42485 Mdot
.48736 .68062 Mdot
.36847 .20996 Mdot
.50102 .69054 Mdot
.55457 .67105 Mdot
.76891 .66185 Mdot
.65919 .51108 Mdot
.69808 .37775 Mdot
.47789 .68441 Mdot
.52044 .35465 Mdot
.64293 .49093 Mdot
.39815 .49391 Mdot
.50471 .69031 Mdot
.52502 .6719 Mdot
.65832 .49342 Mdot
.52706 .3095 Mdot
.35974 .58169 Mdot
.39611 .39586 Mdot
.47581 .66164 Mdot
.47839 .37815 Mdot
.61575 .54915 Mdot
.60707 .51772 Mdot
.49584 .57932 Mdot
.50107 .63644 Mdot
.38604 .42873 Mdot
.80196 .40057 Mdot
.37256 .62639 Mdot
.3253 .5565 Mdot
.47389 .79197 Mdot
.25767 .4963 Mdot
.38721 .60012 Mdot
.39505 .6002 Mdot
.66508 .48873 Mdot
.48583 .63839 Mdot
.78301 .62857 Mdot
.39516 .47479 Mdot
.42102 .58667 Mdot
.37536 .57362 Mdot
.48953 .30286 Mdot
.40561 .782 Mdot
.69063 .46311 Mdot
.35609 .44724 Mdot
.38531 .55503 Mdot
.55464 .40391 Mdot
.51144 .68765 Mdot
.70136 .75243 Mdot
.67887 .54349 Mdot
.62658 .53293 Mdot
.38534 .43854 Mdot
.36714 .40942 Mdot
.38661 .5076 Mdot
.45644 .79126 Mdot
.80352 .47135 Mdot
.34726 .3497 Mdot
.6239 .40859 Mdot
.49013 .30504 Mdot
.54602 .34793 Mdot
.29057 .40171 Mdot
.41692 .44243 Mdot
.65124 .54541 Mdot
.54062 .36074 Mdot
.28939 .58564 Mdot
.52064 .24838 Mdot
.62777 .72011 Mdot
.54655 .7761 Mdot
.61435 .51482 Mdot
.51309 .36441 Mdot
.49082 .33941 Mdot
.55257 .33529 Mdot
.2563 .55196 Mdot
.67229 .50092 Mdot
.623 .51778 Mdot
.67602 .53748 Mdot
.59245 .57611 Mdot
.68229 .51749 Mdot
.42799 .34452 Mdot
.49032 .52197 Mdot
.59705 .36029 Mdot
.66299 .56557 Mdot
.35558 .454 Mdot
.61171 .53782 Mdot
.52762 .69546 Mdot
.62112 .4789 Mdot
.63148 .72185 Mdot
.39503 .44395 Mdot
.46696 .38554 Mdot
.38964 .33873 Mdot
.62712 .54635 Mdot
.49527 .655 Mdot
.45785 .408 Mdot
.17372 .48449 Mdot
.54707 .68321 Mdot
.49801 .33527 Mdot
.37844 .60259 Mdot
.42095 .42184 Mdot
.35954 .60054 Mdot
.71644 .52254 Mdot
.29351 .40444 Mdot
.27741 .34486 Mdot
.50911 .47882 Mdot
.69185 .50244 Mdot
.57032 .48846 Mdot
.50246 .33468 Mdot
.39774 .60613 Mdot
.57086 .3132 Mdot
.64884 .54221 Mdot
.51575 .67138 Mdot
.50733 .69429 Mdot
.41216 .48263 Mdot
.24539 .32594 Mdot
.44825 .32105 Mdot
.38639 .43608 Mdot
.39179 .56775 Mdot
.50179 .70807 Mdot
.45669 .22632 Mdot
.38205 .38944 Mdot
.41048 .44033 Mdot
.37549 .44989 Mdot
.59733 .50182 Mdot
.39996 .56022 Mdot
.59785 .34879 Mdot
.35218 .56241 Mdot
.62228 .51031 Mdot
.37261 .55878 Mdot
.4055 .58034 Mdot
.51638 .69868 Mdot
.36185 .44503 Mdot
.3538 .56911 Mdot
.64751 .46942 Mdot
.51482 .3106 Mdot
.5049 .42254 Mdot
.68307 .69113 Mdot
.4867 .21013 Mdot
.55138 .25587 Mdot
.49814 .31241 Mdot
.17719 .40298 Mdot
.38945 .46032 Mdot
.59995 .58864 Mdot
.26026 .59957 Mdot
.60465 .47488 Mdot
.7101 .76649 Mdot
.38451 .62882 Mdot
.41088 .58242 Mdot
.65871 .47948 Mdot
.30439 .60068 Mdot
.6613 .51514 Mdot
.35915 .56489 Mdot
.35796 .65653 Mdot
.63352 .57896 Mdot
.37067 .61479 Mdot
.65941 .56787 Mdot
.63061 .49606 Mdot
.50516 .3547 Mdot
.39819 .61879 Mdot
.64675 .45935 Mdot
.37202 .18926 Mdot
.36674 .41285 Mdot
.26526 .54145 Mdot
.71466 .62606 Mdot
.37963 .42077 Mdot
.52376 .31882 Mdot
.63971 .448 Mdot
.50187 .69862 Mdot
.5357 .34945 Mdot
.6934 .70559 Mdot
.47931 .67659 Mdot
.6922 .77653 Mdot
.49471 .34346 Mdot
.41712 .59433 Mdot
.52461 .69047 Mdot
.61365 .56184 Mdot
.41371 .56712 Mdot
.44452 .43657 Mdot
.38633 .6025 Mdot
.68094 .50321 Mdot
.26468 .44357 Mdot
.35508 .43429 Mdot
.63627 .51453 Mdot
.41238 .58924 Mdot
.25499 .48485 Mdot
.59811 .50111 Mdot
.64843 .48363 Mdot
.35386 .76553 Mdot
.64 .78945 Mdot
.49573 .68446 Mdot
.55673 .34073 Mdot
.65661 .47126 Mdot
.52051 .66675 Mdot
.40602 .72326 Mdot
.60696 .52968 Mdot
.53116 .29994 Mdot
.55463 .49698 Mdot
.40019 .61304 Mdot
.37488 .41661 Mdot
.50651 .47298 Mdot
.5196 .66477 Mdot
.84064 .37902 Mdot
.36518 .55161 Mdot
.6237 .46068 Mdot
.69293 .4969 Mdot
.28038 .6672 Mdot
.49015 .3531 Mdot
.79137 .50943 Mdot
.66645 .52661 Mdot
.60184 .5826 Mdot
.64509 .52106 Mdot
.34369 .63363 Mdot
.50627 .34021 Mdot
.67438 .51014 Mdot
.36833 .26636 Mdot
.58625 .50948 Mdot
.51043 .65869 Mdot
.59239 .21165 Mdot
.6101 .54435 Mdot
.47821 .88083 Mdot
.4947 .76589 Mdot
.36959 .6157 Mdot
.2799 .41096 Mdot
.54059 .12857 Mdot
.40918 .33749 Mdot
.52614 .37596 Mdot
.23533 .38399 Mdot
.35802 .59167 Mdot
.25785 .42782 Mdot
.17316 .40473 Mdot
.62902 .49337 Mdot
.61356 .53949 Mdot
.55402 .68226 Mdot
.3453 .60835 Mdot
.38208 .54271 Mdot
.70239 .54238 Mdot
.63776 .43891 Mdot
.35469 .59845 Mdot
.65413 .46774 Mdot
.71182 .53743 Mdot
.40753 .40101 Mdot
.50289 .30943 Mdot
.401 .41362 Mdot
.37509 .4539 Mdot
.66946 .2497 Mdot
.43495 .77889 Mdot
.37144 .41092 Mdot
.37144 .45828 Mdot
.64532 .70307 Mdot
.56835 .73666 Mdot
.49368 .70874 Mdot
.28338 .26863 Mdot
.37289 .57819 Mdot
.6686 .50161 Mdot
.49125 .3228 Mdot
.79322 .45239 Mdot
.4498 .72217 Mdot
.78779 .6319 Mdot
.65052 .54387 Mdot
.36827 .57449 Mdot
.25589 .55122 Mdot
.70622 .46102 Mdot
.37513 .52965 Mdot
.62684 .53778 Mdot
.38027 .5447 Mdot
.69115 .33042 Mdot
.36733 .2533 Mdot
.39293 .54467 Mdot
.49593 .38143 Mdot
.63305 .53254 Mdot
.4948 .33732 Mdot
.40037 .42282 Mdot
.51959 .70141 Mdot
.497 .68056 Mdot
.64982 .49038 Mdot
.58035 .549 Mdot
.38131 .7382 Mdot
.62996 .50062 Mdot
.61462 .48361 Mdot
.25345 .55656 Mdot
.61916 .48267 Mdot
.69124 .51106 Mdot
.68818 .52179 Mdot
.5986 .46793 Mdot
.35435 .42486 Mdot
.34543 .26657 Mdot
.71805 .48954 Mdot
.72391 .49411 Mdot
.36248 .3981 Mdot
.19627 .45366 Mdot
.38644 .45666 Mdot
.16048 .46075 Mdot
.40354 .41096 Mdot
.4979 .67212 Mdot
.23085 .60205 Mdot
.57191 .51722 Mdot
.53712 .3122 Mdot
.41456 .39765 Mdot
.51621 .66815 Mdot
.39215 .4274 Mdot
.36017 .56791 Mdot
.26286 .70388 Mdot
.52733 .39457 Mdot
.71958 .5949 Mdot
.43449 .43857 Mdot
.30423 .4347 Mdot
.35253 .56838 Mdot
.50175 .34401 Mdot
.73969 .37965 Mdot
.69358 .51197 Mdot
.52158 .66892 Mdot
.66368 .49251 Mdot
.35329 .43775 Mdot
.3649 .58094 Mdot
.59005 .20254 Mdot
.50053 .69941 Mdot
.40669 .80299 Mdot
.38273 .58059 Mdot
.68729 .5289 Mdot
.35477 .44539 Mdot
.45992 .82443 Mdot
.39658 .41078 Mdot
.75958 .47635 Mdot
.47815 .33048 Mdot
.71959 .26614 Mdot
.53556 .34049 Mdot
.36302 .50965 Mdot
.30825 .78025 Mdot
.37104 .22819 Mdot
.52434 .30932 Mdot
.32095 .44134 Mdot
.61043 .51437 Mdot
.60804 .51997 Mdot
.47096 .22261 Mdot
.55624 .33764 Mdot
.68438 .48247 Mdot
.2495 .56759 Mdot
.34073 .31053 Mdot
.55303 .79273 Mdot
.39083 .60565 Mdot
.66321 .5187 Mdot
.34634 .40758 Mdot
.41291 .4137 Mdot
.36158 .55198 Mdot
.39849 .45378 Mdot
.62469 .51601 Mdot
.53459 .34457 Mdot
.342 .55711 Mdot
.50715 .67509 Mdot
.4452 .18026 Mdot
.5209 .71088 Mdot
.38729 .59938 Mdot
.60354 .56052 Mdot
.35688 .597 Mdot
.56749 .11595 Mdot
.6244 .52173 Mdot
.50528 .32103 Mdot
.63972 .47591 Mdot
.63476 .52947 Mdot
.61364 .54049 Mdot
.35656 .58019 Mdot
.77673 .54163 Mdot
.65043 .46845 Mdot
.37035 .4347 Mdot
.5968 .3876 Mdot
.61811 .54772 Mdot
.3402 .63764 Mdot
.593 .72476 Mdot
.35362 .49036 Mdot
.48639 .32653 Mdot
.37933 .61238 Mdot
.52051 .3136 Mdot
.57076 .30579 Mdot
.52348 .31893 Mdot
.63301 .39181 Mdot
.72891 .36731 Mdot
.78158 .54876 Mdot
.59667 .25145 Mdot
.54276 .55785 Mdot
.55653 .33956 Mdot
.54048 .72594 Mdot
.54821 .34696 Mdot
.49116 .3431 Mdot
.17705 .71895 Mdot
.54386 .32288 Mdot
.65868 .52765 Mdot
.64159 .55425 Mdot
.30636 .35248 Mdot
.64 .67365 Mdot
.63275 .48221 Mdot
.65326 .47389 Mdot
.51633 .70154 Mdot
.63127 .58961 Mdot
.28736 .41119 Mdot
.62675 .80655 Mdot
.26411 .39848 Mdot
.66027 .49234 Mdot
.65228 .47107 Mdot
.6678 .44142 Mdot
.4726 .85066 Mdot
.72223 .28951 Mdot
.53619 .29387 Mdot
.60786 .44538 Mdot
.43669 .19994 Mdot
.6256 .54302 Mdot
.59666 .51577 Mdot
.61319 .51531 Mdot
.35834 .59074 Mdot
.51236 .2976 Mdot
.6374 .44375 Mdot
.47105 .78042 Mdot
.61904 .53922 Mdot
.25809 .49158 Mdot
.66868 .20196 Mdot
.66723 .51896 Mdot
.50475 .30039 Mdot
.60376 .50735 Mdot
.49412 .35331 Mdot
.51891 .35913 Mdot
.58669 .53083 Mdot
.61657 .40613 Mdot
.49682 .30189 Mdot
.62183 .50979 Mdot
.36258 .57304 Mdot
.26672 .2782 Mdot
.68151 .50497 Mdot
.51213 .70766 Mdot
.6637 .52999 Mdot
.4915 .65463 Mdot
.61664 .48624 Mdot
.36793 .55011 Mdot
.78504 .42312 Mdot
.36432 .59367 Mdot
.7537 .29596 Mdot
.39279 .55258 Mdot
.36374 .77298 Mdot
.5384 .30029 Mdot
.26503 .45102 Mdot
.8206 .54935 Mdot
.26277 .52285 Mdot
.46076 .56343 Mdot
.47021 .52143 Mdot
.4061 .44364 Mdot
.48729 .3538 Mdot
.59657 .60205 Mdot
.28329 .62447 Mdot
.27472 .62955 Mdot
.40414 .57142 Mdot
.8434 .50787 Mdot
.79358 .6422 Mdot
.62911 .46957 Mdot
.68281 .38393 Mdot
.6268 .32525 Mdot
.60704 .53598 Mdot
.62665 .44626 Mdot
.38523 .6486 Mdot
.68603 .47963 Mdot
.4129 .25823 Mdot
.38799 .59485 Mdot
.51793 .66894 Mdot
.50116 .32867 Mdot
.52372 .66586 Mdot
.28065 .62341 Mdot
.46765 .52339 Mdot
.36242 .56016 Mdot
.59155 .48085 Mdot
.64696 .47653 Mdot
.50103 .35636 Mdot
.56704 .32907 Mdot
.54478 .33195 Mdot
.48998 .68985 Mdot
.38466 .59178 Mdot
.77404 .36961 Mdot
.66418 .47574 Mdot
.52442 .34787 Mdot
.44804 .54805 Mdot
.66281 .47221 Mdot
.39089 .41956 Mdot
.61479 .52184 Mdot
.51622 .30823 Mdot
.61928 .48278 Mdot
.53705 .34273 Mdot
.37568 .60329 Mdot
.64976 .55108 Mdot
.663 .48195 Mdot
.43805 .81904 Mdot
.5015 .66703 Mdot
.54963 .31038 Mdot
.30658 .62785 Mdot
.69726 .50126 Mdot
.28638 .47648 Mdot
.6347 .53611 Mdot
.51437 .25057 Mdot
.60636 .46799 Mdot
.25586 .52861 Mdot
.70088 .47381 Mdot
.68056 .50579 Mdot
.41846 .50042 Mdot
.62985 .34981 Mdot
.5622 .33664 Mdot
.35329 .44612 Mdot
.54308 .31502 Mdot
.56167 .78398 Mdot
.42317 .56531 Mdot
.39756 .60901 Mdot
.61585 .63275 Mdot
.60034 .46334 Mdot
.66064 .50959 Mdot
.35776 .39721 Mdot
.48575 .66671 Mdot
.515 .34771 Mdot
.52144 .67288 Mdot
.48551 .79916 Mdot
.48218 .68539 Mdot
.37263 .63515 Mdot
.40448 .74759 Mdot
.74977 .33777 Mdot
.51592 .70137 Mdot
.52709 .30899 Mdot
.47602 .73445 Mdot
.59293 .49351 Mdot
.51678 .75152 Mdot
.5172 .67474 Mdot
.85291 .47053 Mdot
.69067 .50994 Mdot
.46199 .57127 Mdot
.37739 .41129 Mdot
.52206 .69278 Mdot
.40068 .44493 Mdot
.63807 .48322 Mdot
.29339 .44005 Mdot
.53508 .3695 Mdot
.34903 .4233 Mdot
.64997 .56377 Mdot
.48692 .67803 Mdot
.38887 .5574 Mdot
.41542 .39176 Mdot
.3495 .44014 Mdot
.20485 .4193 Mdot
.62556 .2057 Mdot
.3831 .59048 Mdot
.68334 .73545 Mdot
.40816 .41375 Mdot
.60358 .53528 Mdot
.65367 .59475 Mdot
.62274 .53209 Mdot
.43734 .34112 Mdot
.38325 .61154 Mdot
.31441 .32579 Mdot
.63995 .47453 Mdot
.66924 .53855 Mdot
.56007 .3293 Mdot
.3701 .58956 Mdot
.52346 .33345 Mdot
.54732 .32325 Mdot
.37488 .60191 Mdot
.53406 .33181 Mdot
.47806 .67664 Mdot
.35204 .31238 Mdot
.38716 .39834 Mdot
.37091 .43961 Mdot
.37375 .57405 Mdot
.36607 .61667 Mdot
.35991 .60665 Mdot
.61488 .52224 Mdot
.50983 .34401 Mdot
.61645 .49621 Mdot
.61262 .53748 Mdot
.62765 .41223 Mdot
.49393 .3143 Mdot
.61054 .50514 Mdot
.34914 .52895 Mdot
.46819 .66009 Mdot
.36413 .56944 Mdot
.37259 .41196 Mdot
.2305 .48314 Mdot
.43734 .39688 Mdot
.66008 .52075 Mdot
.37014 .74956 Mdot
.53595 .31715 Mdot
.50392 .69609 Mdot
.49096 .71218 Mdot
.49873 .68904 Mdot
.35109 .46155 Mdot
.55471 .33033 Mdot
.63286 .80466 Mdot
.66372 .51534 Mdot
.49463 .58084 Mdot
.67497 .60564 Mdot
.37395 .73965 Mdot
.36937 .41332 Mdot
.65704 .47216 Mdot
.5124 .45913 Mdot
.7509 .37938 Mdot
.62585 .5305 Mdot
.59356 .52618 Mdot
.25275 .57756 Mdot
.555 .47751 Mdot
.47715 .32554 Mdot
.48754 .81354 Mdot
.68832 .53961 Mdot
.56253 .39443 Mdot
.48059 .16275 Mdot
.65074 .52702 Mdot
.66125 .53929 Mdot
.68096 .48789 Mdot
.61894 .47786 Mdot
.49425 .30681 Mdot
.60375 .65428 Mdot
.39245 .45942 Mdot
.50667 .59092 Mdot
.36733 .39872 Mdot
.40635 .55871 Mdot
.34143 .27794 Mdot
.48574 .35267 Mdot
.50779 .69928 Mdot
.34191 .25151 Mdot
.55152 .8211 Mdot
.35189 .61341 Mdot
.6978 .28484 Mdot
.51089 .67013 Mdot
.60169 .53464 Mdot
.4781 .66602 Mdot
.4016 .56191 Mdot
.36534 .43446 Mdot
.59934 .46169 Mdot
.54657 .3427 Mdot
.49824 .31951 Mdot
.68183 .47989 Mdot
.41578 .20621 Mdot
.38734 .41722 Mdot
.37209 .38907 Mdot
.60025 .51864 Mdot
.61783 .56251 Mdot
.52327 .32993 Mdot
.38704 .57074 Mdot
.63497 .75045 Mdot
.49056 .66618 Mdot
.68904 .47685 Mdot
.614 .48023 Mdot
.4629 .79474 Mdot
.36238 .42676 Mdot
.35945 .62783 Mdot
.60047 .4897 Mdot
.33734 .36084 Mdot
.60089 .48917 Mdot
.6334 .43472 Mdot
.36453 .57183 Mdot
.71331 .48869 Mdot
.63912 .46666 Mdot
.73659 .53372 Mdot
.40909 .4311 Mdot
.50994 .32033 Mdot
.53115 .38866 Mdot
.53088 .59218 Mdot
.39239 .42099 Mdot
.60752 .50545 Mdot
.36792 .42166 Mdot
.60936 .53167 Mdot
.68071 .4776 Mdot
.37389 .40846 Mdot
.52419 .33347 Mdot
.23549 .39243 Mdot
.34176 .2714 Mdot
.62172 .47639 Mdot
.7023 .52314 Mdot
.61941 .66079 Mdot
.77916 .56608 Mdot
.64266 .54202 Mdot
.50873 .31088 Mdot
.66078 .47686 Mdot
.40122 .44192 Mdot
.48062 .69154 Mdot
.51582 .30978 Mdot
.3922 .57936 Mdot
.34771 .60252 Mdot
.3966 .33723 Mdot
.40212 .59152 Mdot
.59426 .49641 Mdot
.57305 .31248 Mdot
.54618 .38033 Mdot
.47056 .17394 Mdot
.37341 .59854 Mdot
.47782 .69264 Mdot
.64767 .48502 Mdot
.34971 .74801 Mdot
.35471 .39744 Mdot
.5217 .88806 Mdot
.67513 .78709 Mdot
.53636 .70063 Mdot
.79376 .60431 Mdot
.39851 .55083 Mdot
.6629 .46666 Mdot
.52095 .70111 Mdot
.35227 .61134 Mdot
.60582 .47621 Mdot
.58899 .47053 Mdot
.79031 .51469 Mdot
.51841 .56724 Mdot
.36623 .42142 Mdot
.384 .61992 Mdot
.51237 .72193 Mdot
.36061 .63239 Mdot
.4917 .32614 Mdot
.67764 .50577 Mdot
.58435 .5462 Mdot
.39104 .5744 Mdot
.34713 .61528 Mdot
.6163 .51085 Mdot
.48828 .35625 Mdot
.39302 .64508 Mdot
.65327 .49405 Mdot
.54686 .55373 Mdot
.4794 .36204 Mdot
.39206 .59253 Mdot
.68066 .52967 Mdot
.46762 .71361 Mdot
.38366 .5771 Mdot
.36536 .56743 Mdot
.68029 .47808 Mdot
.47861 .67363 Mdot
.70086 .52113 Mdot
.39645 .40461 Mdot
.8133 .41443 Mdot
.39566 .44648 Mdot
.45178 .69771 Mdot
.61202 .56562 Mdot
.33316 .38497 Mdot
.48485 .33711 Mdot
.55045 .6664 Mdot
.22421 .5322 Mdot
.6988 .54687 Mdot
.22293 .34889 Mdot
.50237 .44328 Mdot
.40327 .19825 Mdot
.20067 .58688 Mdot
.5178 .6829 Mdot
.39495 .42789 Mdot
.66011 .53953 Mdot
.42267 .41384 Mdot
.51767 .70542 Mdot
.7412 .28852 Mdot
.68564 .52364 Mdot
.50606 .33854 Mdot
.61835 .5154 Mdot
.49686 .33658 Mdot
.67093 .47379 Mdot
.71192 .46827 Mdot
.24702 .56005 Mdot
.68841 .7034 Mdot
.60118 .47766 Mdot
.28633 .73845 Mdot
.46711 .75734 Mdot
.50654 .66352 Mdot
.62208 .49744 Mdot
.40263 .53025 Mdot
.41623 .41955 Mdot
.46277 .24184 Mdot
.35779 .58988 Mdot
.37609 .45638 Mdot
.52672 .32561 Mdot
.38336 .60623 Mdot
.34614 .59436 Mdot
.70955 .48557 Mdot
.5086 .65678 Mdot
.36653 .44464 Mdot
.67602 .51207 Mdot
.6859 .52037 Mdot
.65027 .757 Mdot
.43745 .70336 Mdot
.56454 .36581 Mdot
.54067 .84556 Mdot
.52915 .38647 Mdot
.49482 .6677 Mdot
.35871 .58246 Mdot
.63945 .53897 Mdot
.63643 .51214 Mdot
.26142 .46463 Mdot
.54176 .36552 Mdot
.51122 .5311 Mdot
.65116 .25034 Mdot
.38434 .64592 Mdot
.61352 .70618 Mdot
.50059 .32304 Mdot
.61617 .70498 Mdot
.49806 .71962 Mdot
.30944 .25902 Mdot
.66503 .71263 Mdot
.37489 .41317 Mdot
.61274 .70279 Mdot
.52557 .35448 Mdot
.63518 .47065 Mdot
.41653 .59671 Mdot
.4049 .58151 Mdot
.5147 .32552 Mdot
.34022 .58015 Mdot
.51588 .69761 Mdot
.67085 .53273 Mdot
.62463 .80226 Mdot
.4082 .31457 Mdot
.38804 .56501 Mdot
.71781 .47315 Mdot
.37811 .4502 Mdot
.68625 .48257 Mdot
.50735 .70642 Mdot
.3774 .42573 Mdot
.50278 .76751 Mdot
.32925 .31785 Mdot
.64505 .48806 Mdot
.38276 .7784 Mdot
.3882 .42326 Mdot
.77022 .60581 Mdot
.66183 .49692 Mdot
.40871 .41559 Mdot
.58146 .44952 Mdot
.32661 .52688 Mdot
.51429 .46445 Mdot
.17404 .40205 Mdot
.50551 .50053 Mdot
.41766 .58389 Mdot
.32876 .50301 Mdot
.28812 .56117 Mdot
.42169 .41533 Mdot
.34918 .62 Mdot
.4719 .63662 Mdot
.40167 .4445 Mdot
.61855 .54693 Mdot
.6398 .5331 Mdot
.72358 .28745 Mdot
.49297 .44992 Mdot
.3501 .51302 Mdot
.44791 .28772 Mdot
.69711 .50561 Mdot
.68175 .54674 Mdot
.64244 .50909 Mdot
.50357 .29531 Mdot
.36607 .42687 Mdot
.3517 .78413 Mdot
.39449 .41931 Mdot
.69424 .75405 Mdot
.37119 .5784 Mdot
.38338 .61533 Mdot
.66382 .52073 Mdot
.46672 .60482 Mdot
.57718 .69125 Mdot
.62496 .5138 Mdot
.50276 .6164 Mdot
.58137 .21224 Mdot
.64336 .56193 Mdot
.48038 .3313 Mdot
.72332 .53514 Mdot
.46598 .35541 Mdot
.38887 .39831 Mdot
.51138 .68446 Mdot
.54623 .65535 Mdot
.36363 .43587 Mdot
.65905 .50913 Mdot
.31718 .39011 Mdot
.63544 .52479 Mdot
.61739 .47393 Mdot
.71956 .73511 Mdot
.524 .70969 Mdot
.36716 .60811 Mdot
.49627 .68896 Mdot
.49042 .34906 Mdot
.38006 .87817 Mdot
.48842 .66317 Mdot
.57344 .68672 Mdot
.77404 .32641 Mdot
.61515 .69983 Mdot
.49317 .32612 Mdot
.52028 .65882 Mdot
.38016 .41596 Mdot
.28375 .25012 Mdot
.80718 .52023 Mdot
.42767 .38269 Mdot
.65098 .49763 Mdot
.49579 .36768 Mdot
.51399 .305 Mdot
.35158 .41623 Mdot
.51945 .35772 Mdot
.58135 .45461 Mdot
.62732 .47326 Mdot
.42424 .42122 Mdot
.34676 .34036 Mdot
.34982 .44235 Mdot
.36986 .28757 Mdot
.62175 .50149 Mdot
.50522 .31777 Mdot
.70151 .55627 Mdot
.47788 .30931 Mdot
.36602 .631 Mdot
.61106 .54726 Mdot
.51455 .69877 Mdot
.35631 .37348 Mdot
.38379 .58793 Mdot
.35892 .73801 Mdot
.49897 .35414 Mdot
.34551 .4781 Mdot
.50771 .35656 Mdot
.55619 .34789 Mdot
.38075 .45508 Mdot
.52999 .36895 Mdot
.66431 .53779 Mdot
.365 .51434 Mdot
.50264 .36438 Mdot
.38755 .44301 Mdot
.50674 .68131 Mdot
.5318 .33393 Mdot
.3043 .59713 Mdot
.6558 .48486 Mdot
.35272 .58664 Mdot
.24405 .62046 Mdot
.53181 .38059 Mdot
.5346 .67711 Mdot
.39878 .60592 Mdot
.52679 .67404 Mdot
.53994 .1843 Mdot
.42404 .43238 Mdot
.77277 .65157 Mdot
.46048 .66877 Mdot
.54015 .31814 Mdot
.23237 .60095 Mdot
.64214 .53735 Mdot
.65256 .48416 Mdot
.49005 .65306 Mdot
.51451 .30494 Mdot
.34095 .23735 Mdot
.45556 .35016 Mdot
.33815 .32211 Mdot
.42849 .41232 Mdot
.33627 .76084 Mdot
.3789 .27276 Mdot
.60582 .17203 Mdot
.69405 .54367 Mdot
.38884 .54469 Mdot
.65461 .51709 Mdot
.22264 .51338 Mdot
.48788 .68069 Mdot
.32546 .60165 Mdot
.58816 .52849 Mdot
.37509 .60821 Mdot
.67511 .48941 Mdot
.42424 .48389 Mdot
.72046 .53151 Mdot
.48106 .69859 Mdot
.28316 .4138 Mdot
.5423 .31828 Mdot
.50881 .6736 Mdot
.36903 .55202 Mdot
.58767 .69932 Mdot
.61404 .46914 Mdot
.71761 .51645 Mdot
.38763 .64457 Mdot
.5034 .3424 Mdot
.40819 .60543 Mdot
.39365 .40025 Mdot
.51041 .69344 Mdot
.63982 .47965 Mdot
.60002 .4717 Mdot
.28629 .48002 Mdot
.37055 .44939 Mdot
.34244 .58431 Mdot
.39803 .41316 Mdot
.40058 .5505 Mdot
.70814 .50374 Mdot
.38544 .61468 Mdot
.64521 .46226 Mdot
.2354 .54057 Mdot
.7184 .73354 Mdot
.64421 .3641 Mdot
.38561 .60937 Mdot
.60582 .73061 Mdot
.39795 .44163 Mdot
.40407 .41413 Mdot
.77376 .34811 Mdot
.76931 .48961 Mdot
.60857 .78769 Mdot
.1819 .46285 Mdot
.3703 .39811 Mdot
.38277 .44902 Mdot
.35144 .59198 Mdot
.52448 .37185 Mdot
.54902 .36952 Mdot
.39162 .54747 Mdot
.69622 .63642 Mdot
.51521 .34771 Mdot
.26117 .29799 Mdot
.56991 .78976 Mdot
.65089 .44589 Mdot
.43369 .55225 Mdot
.50618 .69022 Mdot
.68034 .65027 Mdot
.42094 .48606 Mdot
.66314 .54147 Mdot
.45006 .78834 Mdot
.38119 .56953 Mdot
.60478 .62126 Mdot
.1616 .46112 Mdot
.6888 .51886 Mdot
.66778 .50019 Mdot
.65158 .51053 Mdot
.54151 .68927 Mdot
.77868 .4842 Mdot
.68088 .52619 Mdot
.70185 .63306 Mdot
.69698 .49453 Mdot
.63197 .42274 Mdot
.49628 .68311 Mdot
.59208 .42831 Mdot
.24414 .57837 Mdot
.50821 .80397 Mdot
.69512 .56794 Mdot
.39731 .40246 Mdot
.52539 .61855 Mdot
.4106 .42749 Mdot
.63394 .38582 Mdot
.66732 .70835 Mdot
.50881 .38534 Mdot
.6604 .54171 Mdot
.38787 .59883 Mdot
.51192 .30548 Mdot
.31315 .5048 Mdot
.27723 .82009 Mdot
.4048 .40603 Mdot
.6407 .16466 Mdot
.39979 .40976 Mdot
.34675 .58278 Mdot
.52263 .32851 Mdot
.72216 .35964 Mdot
.49588 .57567 Mdot
.53382 .33504 Mdot
.26842 .35572 Mdot
.54611 .29767 Mdot
.60294 .71984 Mdot
.5148 .38175 Mdot
.39183 .44272 Mdot
.35772 .46517 Mdot
.58203 .47037 Mdot
.65423 .533 Mdot
.46616 .51513 Mdot
.57505 .72044 Mdot
.6476 .53643 Mdot
.38614 .59414 Mdot
.79083 .57995 Mdot
.55486 .63319 Mdot
.53232 .36239 Mdot
.38819 .46234 Mdot
.67076 .49838 Mdot
.60509 .48446 Mdot
.61738 .46954 Mdot
.56458 .85258 Mdot
.31498 .25188 Mdot
.65088 .46871 Mdot
.69972 .50194 Mdot
.38036 .60673 Mdot
.47685 .70975 Mdot
.21548 .50987 Mdot
.71704 .44384 Mdot
.6478 .5489 Mdot
.50243 .67219 Mdot
.52611 .70993 Mdot
.60376 .4779 Mdot
.46781 .77619 Mdot
.31592 .40506 Mdot
.67667 .51158 Mdot
.7642 .4925 Mdot
.28414 .59227 Mdot
.34567 .60895 Mdot
.38991 .57667 Mdot
.51339 .30018 Mdot
.39881 .59344 Mdot
.38666 .54914 Mdot
.72684 .34621 Mdot
.50186 .5163 Mdot
.34094 .44745 Mdot
.49028 .69095 Mdot
.63536 .51563 Mdot
.5607 .36974 Mdot
.32875 .36892 Mdot
.39652 .45075 Mdot
.5372 .32273 Mdot
.41406 .4189 Mdot
.53792 .66575 Mdot
.70301 .60252 Mdot
.40387 .56814 Mdot
.36249 .40498 Mdot
.33084 .31691 Mdot
.50064 .67401 Mdot
.36451 .44929 Mdot
.30441 .40488 Mdot
.62449 .55301 Mdot
.70958 .40157 Mdot
.62532 .50953 Mdot
.37268 .21248 Mdot
.3595 .44208 Mdot
.25257 .51975 Mdot
.66691 .50828 Mdot
.38168 .57911 Mdot
.60678 .43681 Mdot
.62786 .5397 Mdot
.39644 .57865 Mdot
.63068 .46956 Mdot
.52898 .69944 Mdot
.48087 .36828 Mdot
.51295 .59103 Mdot
.84291 .60911 Mdot
.50984 .65692 Mdot
.3086 .49669 Mdot
.64512 .5431 Mdot
.59296 .19762 Mdot
.53175 .33607 Mdot
.63058 .46092 Mdot
.56955 .63649 Mdot
.51118 .37232 Mdot
.52828 .31611 Mdot
.60514 .49596 Mdot
.3811 .41141 Mdot
.38687 .58794 Mdot
.49848 .67897 Mdot
.53784 .17529 Mdot
.64175 .49668 Mdot
.66209 .47966 Mdot
.51061 .67157 Mdot
.3891 .4487 Mdot
.59988 .49683 Mdot
.25069 .64502 Mdot
.38208 .19056 Mdot
.40788 .44424 Mdot
.62577 .54841 Mdot
.71058 .41765 Mdot
.47121 .3739 Mdot
.79474 .32207 Mdot
.50879 .75738 Mdot
.37192 .61223 Mdot
.55986 .47138 Mdot
.41821 .87687 Mdot
.50951 .68423 Mdot
.56688 .81133 Mdot
.6089 .4777 Mdot
.67246 .47815 Mdot
.54324 .32916 Mdot
.61365 .50034 Mdot
.52482 .37848 Mdot
.84026 .59321 Mdot
.45616 .79728 Mdot
.49826 .34235 Mdot
.54774 .3362 Mdot
.5703 .65751 Mdot
.21714 .50974 Mdot
.516 .32378 Mdot
.7028 .49559 Mdot
.56512 .27996 Mdot
.74649 .49727 Mdot
.4829 .65693 Mdot
.26519 .61365 Mdot
.46385 .3774 Mdot
.53215 .72553 Mdot
.21396 .41154 Mdot
.46955 .38465 Mdot
.32145 .41034 Mdot
.38778 .40089 Mdot
.68801 .52449 Mdot
.40424 .58531 Mdot
.39451 .61069 Mdot
.7034 .55163 Mdot
.63153 .52139 Mdot
.49312 .35076 Mdot
.48988 .69502 Mdot
.41871 .41402 Mdot
.65342 .47436 Mdot
.5586 .64605 Mdot
.49068 .6628 Mdot
.52011 .36612 Mdot
.77677 .52066 Mdot
.48118 .70043 Mdot
.72882 .49403 Mdot
.67276 .52179 Mdot
.61427 .51473 Mdot
.74865 .50989 Mdot
.36343 .41399 Mdot
.23062 .58591 Mdot
.66791 .54947 Mdot
.4859 .8001 Mdot
.50777 .41722 Mdot
.69393 .45714 Mdot
.51145 .35196 Mdot
.35143 .39939 Mdot
.40231 .62051 Mdot
.57939 .60911 Mdot
.64229 .49046 Mdot
.35613 .2425 Mdot
.68989 .26178 Mdot
.37597 .63052 Mdot
.5558 .34322 Mdot
.50197 .69367 Mdot
.62606 .51494 Mdot
.60402 .39755 Mdot
.6465 .53085 Mdot
.49747 .64571 Mdot
.37156 .56561 Mdot
.38763 .40159 Mdot
.3989 .19635 Mdot
.3935 .61129 Mdot
.5223 .31381 Mdot
.1216 .47783 Mdot
.50622 .37654 Mdot
.55143 .33987 Mdot
.59844 .40482 Mdot
.36779 .40814 Mdot
.44922 .89004 Mdot
.82541 .46027 Mdot
.60861 .55548 Mdot
.40198 .43674 Mdot
.51099 .32956 Mdot
.68906 .4878 Mdot
.48192 .35152 Mdot
.55467 .32586 Mdot
.7092 .51109 Mdot
.68715 .4953 Mdot
.34912 .27541 Mdot
.16992 .41902 Mdot
.50038 .69459 Mdot
.48903 .34155 Mdot
.55901 .57185 Mdot
.6915 .49294 Mdot
.66451 .51493 Mdot
.29657 .56081 Mdot
.47735 .67779 Mdot
.43714 .25392 Mdot
.60663 .4805 Mdot
.43025 .79389 Mdot
.72135 .53799 Mdot
.48982 .31042 Mdot
.40296 .44844 Mdot
.51032 .79957 Mdot
.42332 .45212 Mdot
.53739 .37001 Mdot
.49772 .70126 Mdot
.5372 .38842 Mdot
.57232 .69114 Mdot
.35255 .4242 Mdot
.51623 .30821 Mdot
.50743 .47054 Mdot
.37879 .43244 Mdot
.35777 .43265 Mdot
.59521 .38806 Mdot
.3474 .55875 Mdot
.53861 .69231 Mdot
.36985 .44683 Mdot
.58938 .58085 Mdot
.3927 .43676 Mdot
.79172 .39434 Mdot
.64832 .55144 Mdot
.65355 .62954 Mdot
.45195 .58323 Mdot
.57034 .50205 Mdot
.35446 .43261 Mdot
.51166 .70563 Mdot
.60213 .49711 Mdot
.52488 .35705 Mdot
.51176 .66298 Mdot
.4145 .387 Mdot
.35497 .59498 Mdot
.50867 .3591 Mdot
.43169 .41321 Mdot
.49544 .32893 Mdot
.59389 .60276 Mdot
.80238 .36694 Mdot
.27639 .68923 Mdot
.49837 .5694 Mdot
.61644 .4706 Mdot
.19312 .48084 Mdot
.67709 .45339 Mdot
.62828 .5253 Mdot
.3906 .59255 Mdot
.61682 .62975 Mdot
.52346 .33291 Mdot
.38129 .19806 Mdot
.37124 .40079 Mdot
.48505 .81341 Mdot
.54852 .27574 Mdot
.62196 .46263 Mdot
.50189 .36474 Mdot
.50705 .37768 Mdot
.62279 .34379 Mdot
.39093 .63066 Mdot
.62171 .44858 Mdot
.61641 .44773 Mdot
.71457 .51667 Mdot
.36006 .42672 Mdot
.36898 .74597 Mdot
.41583 .57627 Mdot
.78898 .32974 Mdot
.37903 .56382 Mdot
.50508 .61428 Mdot
.52877 .36789 Mdot
.48586 .66455 Mdot
.66658 .51476 Mdot
.56271 .31521 Mdot
.5399 .36892 Mdot
.48417 .649 Mdot
.52343 .69192 Mdot
.31079 .54719 Mdot
.37251 .40912 Mdot
.59821 .47987 Mdot
.67975 .53009 Mdot
.61707 .49337 Mdot
.61805 .52378 Mdot
.40069 .40254 Mdot
.60482 .51872 Mdot
.34387 .41586 Mdot
.66811 .60133 Mdot
.43728 .78507 Mdot
.50042 .50319 Mdot
.50352 .2535 Mdot
.52988 .35944 Mdot
.56132 .55852 Mdot
.72444 .47677 Mdot
.73926 .71315 Mdot
.53808 .22126 Mdot
.63359 .56116 Mdot
.35488 .61528 Mdot
.76328 .50916 Mdot
.4076 .5738 Mdot
.71094 .20683 Mdot
.28189 .48724 Mdot
.18935 .38589 Mdot
.68578 .51667 Mdot
.29161 .5748 Mdot
.58438 .56709 Mdot
.66093 .45103 Mdot
.29866 .51646 Mdot
.43953 .33579 Mdot
.28967 .35394 Mdot
.49446 .70597 Mdot
.65761 .48888 Mdot
.56212 .36048 Mdot
.66853 .53535 Mdot
.65922 .51722 Mdot
.60309 .48258 Mdot
.36683 .4558 Mdot
.62321 .44996 Mdot
.61488 .5301 Mdot
.37914 .733 Mdot
.63663 .70933 Mdot
.38816 .61891 Mdot
.76227 .32725 Mdot
.49395 .65994 Mdot
.49689 .35679 Mdot
.27346 .31952 Mdot
.37394 .41341 Mdot
.62297 .33336 Mdot
.61609 .51989 Mdot
.334 .29457 Mdot
.43006 .4014 Mdot
.51212 .69576 Mdot
.41972 .58306 Mdot
.22025 .33748 Mdot
.38269 .59822 Mdot
.51007 .46005 Mdot
.37967 .5829 Mdot
.73738 .50667 Mdot
.49274 .34959 Mdot
.59833 .48927 Mdot
.36827 .44386 Mdot
.39677 .58698 Mdot
.63141 .66518 Mdot
.64389 .51005 Mdot
.37398 .60223 Mdot
.5982 .49019 Mdot
.7029 .6048 Mdot
.7043 .71435 Mdot
.37673 .54863 Mdot
.33962 .42859 Mdot
.37782 .438 Mdot
.4788 .67492 Mdot
.50592 .36223 Mdot
.54414 .33859 Mdot
.37934 .42664 Mdot
.80198 .54099 Mdot
.64091 .54746 Mdot
.69108 .49578 Mdot
.49202 .80524 Mdot
.6529 .53964 Mdot
.59162 .71465 Mdot
.5123 .46203 Mdot
.52487 .36353 Mdot
.66512 .46849 Mdot
.60838 .48204 Mdot
.64685 .48671 Mdot
.6299 .61081 Mdot
.38905 .56958 Mdot
.67773 .53898 Mdot
.52579 .6893 Mdot
.37599 .51421 Mdot
.6873 .48318 Mdot
.71712 .50865 Mdot
.54368 .33614 Mdot
.56279 .83509 Mdot
.39378 .40677 Mdot
.3587 .55908 Mdot
.38235 .61361 Mdot
.26763 .61278 Mdot
.51347 .4105 Mdot
.51005 .47005 Mdot
.76409 .29704 Mdot
.24993 .56283 Mdot
.50581 .66533 Mdot
.41037 .52718 Mdot
.53111 .42249 Mdot
.34913 .59067 Mdot
.40817 .40738 Mdot
.65148 .55223 Mdot
.64785 .54946 Mdot
.70537 .76589 Mdot
.61077 .46682 Mdot
.50273 .68991 Mdot
.34883 .41039 Mdot
.52568 .35363 Mdot
.51087 .69651 Mdot
.40316 .41582 Mdot
.50344 .3444 Mdot
.64457 .55831 Mdot
.6513 .55605 Mdot
.53746 .3247 Mdot
.52109 .30613 Mdot
.67298 .51724 Mdot
.42234 .64818 Mdot
.53642 .31021 Mdot
.50417 .31628 Mdot
.40354 .56695 Mdot
.4038 .58158 Mdot
.70749 .47854 Mdot
.40171 .43239 Mdot
.61175 .52799 Mdot
.38481 .60352 Mdot
.48313 .68801 Mdot
.52618 .33772 Mdot
.61922 .47669 Mdot
.64692 .47365 Mdot
.50137 .67496 Mdot
.49312 .70236 Mdot
.5194 .69502 Mdot
.34563 .43578 Mdot
.6253 .49272 Mdot
.52181 .32298 Mdot
.37619 .40581 Mdot
.52811 .70897 Mdot
.47526 .67334 Mdot
.34734 .62655 Mdot
.63824 .54015 Mdot
.38606 .51635 Mdot
.35768 .85704 Mdot
.53439 .76353 Mdot
.3856 .63008 Mdot
.35966 .63841 Mdot
.63009 .69056 Mdot
.48154 .60268 Mdot
.38463 .42005 Mdot
.48288 .64015 Mdot
.54949 .66183 Mdot
.60913 .5439 Mdot
.69025 .53699 Mdot
.60545 .44826 Mdot
.52137 .68688 Mdot
.58635 .62661 Mdot
.48291 .3487 Mdot
.61954 .24517 Mdot
.50061 .6595 Mdot
.34653 .6143 Mdot
.34385 .56467 Mdot
.37739 .56372 Mdot
.65291 .5535 Mdot
.64544 .3586 Mdot
.53843 .48974 Mdot
.18555 .49322 Mdot
.35712 .44118 Mdot
.54653 .38825 Mdot
.57142 .20161 Mdot
.53374 .32089 Mdot
.40412 .55915 Mdot
.51859 .6704 Mdot
.5111 .30798 Mdot
.41459 .42926 Mdot
.37801 .44848 Mdot
.38591 .56521 Mdot
.37124 .57504 Mdot
.35878 .56839 Mdot
.55377 .33596 Mdot
.52856 .36914 Mdot
.63835 .49231 Mdot
.5299 .34522 Mdot
.65707 .80485 Mdot
.54139 .67442 Mdot
.36614 .64297 Mdot
.39648 .4263 Mdot
.49614 .33889 Mdot
.6403 .50947 Mdot
.53421 .6053 Mdot
.43101 .32294 Mdot
.52936 .68087 Mdot
.66947 .7425 Mdot
.71007 .20868 Mdot
.59851 .47739 Mdot
.36277 .42479 Mdot
.62307 .80081 Mdot
.65022 .50852 Mdot
.36146 .57904 Mdot
.23006 .55298 Mdot
.42315 .56256 Mdot
.61264 .53671 Mdot
.58923 .5065 Mdot
.40085 .45225 Mdot
.74567 .28704 Mdot
.63674 .49609 Mdot
.43072 .26665 Mdot
.4046 .45592 Mdot
.41444 .57327 Mdot
.35668 .19558 Mdot
.27906 .66044 Mdot
.68386 .6448 Mdot
.40156 .56469 Mdot
.63467 .53046 Mdot
.4024 .56986 Mdot
.52914 .69088 Mdot
.38082 .55375 Mdot
.47791 .33505 Mdot
.39769 .61479 Mdot
.66378 .47994 Mdot
.51357 .32331 Mdot
.38882 .4225 Mdot
.50857 .82304 Mdot
.43789 .74027 Mdot
.381 .57814 Mdot
.36239 .55238 Mdot
.64574 .46666 Mdot
.41192 .25383 Mdot
.66977 .56656 Mdot
.68978 .50941 Mdot
.36333 .40224 Mdot
.50699 .36751 Mdot
.38507 .45954 Mdot
.65059 .45844 Mdot
.24285 .64078 Mdot
.39392 .41114 Mdot
.32923 .29108 Mdot
.51016 .6691 Mdot
.44378 .47007 Mdot
.63408 .51348 Mdot
.387 .45206 Mdot
.62525 .49386 Mdot
.48183 .3445 Mdot
.47672 .46087 Mdot
.28524 .40461 Mdot
.36681 .43924 Mdot
.37121 .22341 Mdot
.46783 .62955 Mdot
.61659 .57194 Mdot
.40961 .41927 Mdot
.56754 .63246 Mdot
.34601 .59246 Mdot
.4932 .66441 Mdot
.51289 .71239 Mdot
.5219 .6654 Mdot
.67707 .56056 Mdot
.67001 .57672 Mdot
.52867 .70399 Mdot
.41721 .42975 Mdot
.48516 .70318 Mdot
.55269 .39883 Mdot
.34582 .23544 Mdot
.48929 .68005 Mdot
.65775 .49619 Mdot
.69809 .57193 Mdot
.64156 .70216 Mdot
.33489 .52849 Mdot
.20286 .37246 Mdot
.48165 .24377 Mdot
.65309 .53223 Mdot
.49564 .3851 Mdot
.48981 .32642 Mdot
.60062 .80388 Mdot
.57491 .73403 Mdot
.49054 .78732 Mdot
.54889 .33633 Mdot
.26529 .44721 Mdot
.51657 .365 Mdot
.61521 .46647 Mdot
.68904 .49055 Mdot
.54921 .36546 Mdot
.39505 .76928 Mdot
.29423 .46364 Mdot
.45104 .1826 Mdot
.49864 .32111 Mdot
.40941 .4321 Mdot
.35839 .4013 Mdot
.35657 .43062 Mdot
.58 .78861 Mdot
.51563 .37779 Mdot
.62526 .48685 Mdot
.38705 .6074 Mdot
.66742 .54463 Mdot
.37236 .42954 Mdot
.37866 .19938 Mdot
.53939 .34877 Mdot
.67967 .50722 Mdot
.77134 .57309 Mdot
.36195 .58677 Mdot
.50099 .67014 Mdot
.74851 .57037 Mdot
.50859 .77343 Mdot
.35846 .4161 Mdot
.5313 .38204 Mdot
.25619 .50358 Mdot
.32324 .28567 Mdot
.68409 .54824 Mdot
.66894 .44672 Mdot
.57446 .16929 Mdot
.50436 .7672 Mdot
.59446 .5138 Mdot
.35025 .57342 Mdot
.25961 .47007 Mdot
.63797 .47575 Mdot
.48842 .33328 Mdot
.49882 .71219 Mdot
.52332 .67055 Mdot
.69364 .47127 Mdot
.49414 .58337 Mdot
.45533 .43702 Mdot
.6074 .50685 Mdot
.72866 .49177 Mdot
.40988 .56919 Mdot
.24997 .56553 Mdot
.48117 .80186 Mdot
.49761 .70217 Mdot
.59852 .49342 Mdot
.24296 .39787 Mdot
.54971 .35473 Mdot
.39017 .62338 Mdot
.35055 .43188 Mdot
.68935 .60152 Mdot
.41488 .57165 Mdot
.63569 .4748 Mdot
.60086 .49308 Mdot
.36898 .45277 Mdot
.4892 .31099 Mdot
.52177 .68331 Mdot
.38769 .60966 Mdot
.50192 .70552 Mdot
.51234 .37413 Mdot
.53435 .35141 Mdot
.74391 .48074 Mdot
.58193 .52925 Mdot
.39058 .57869 Mdot
.67782 .47043 Mdot
.30704 .62542 Mdot
.73706 .26821 Mdot
.4137 .39713 Mdot
.59648 .47976 Mdot
.49619 .29921 Mdot
.36475 .43537 Mdot
.68208 .48536 Mdot
.54541 .16957 Mdot
.69304 .4934 Mdot
.44397 .38709 Mdot
.27085 .69039 Mdot
.51191 .70324 Mdot
.60399 .24173 Mdot
.44729 .22209 Mdot
.65889 .53715 Mdot
.36365 .61683 Mdot
.68911 .44974 Mdot
.38276 .41329 Mdot
.53163 .36407 Mdot
.79496 .31805 Mdot
.38911 .43956 Mdot
.67769 .52625 Mdot
.51076 .69439 Mdot
.51827 .3815 Mdot
.50368 .62684 Mdot
.46305 .77733 Mdot
.65665 .57423 Mdot
.69926 .48448 Mdot
.6107 .51983 Mdot
.21201 .58902 Mdot
.35953 .55881 Mdot
.50359 .3315 Mdot
.36183 .42416 Mdot
.37891 .42437 Mdot
.3846 .56703 Mdot
.31661 .34132 Mdot
.44599 .46821 Mdot
.35765 .84368 Mdot
.39839 .57733 Mdot
.52862 .66693 Mdot
.42519 .25775 Mdot
.36625 .61954 Mdot
.37119 .59921 Mdot
.41026 .57166 Mdot
.38886 .47757 Mdot
.50669 .34439 Mdot
.64365 .47228 Mdot
.48602 .32706 Mdot
.63137 .53192 Mdot
.49889 .4131 Mdot
.36493 .44055 Mdot
.53752 .36107 Mdot
.55611 .1748 Mdot
.76446 .43977 Mdot
.65538 .50371 Mdot
.5828 .19931 Mdot
.59633 .54386 Mdot
.60454 .68749 Mdot
.5826 .50301 Mdot
.37565 .57775 Mdot
.55809 .52267 Mdot
.71391 .53123 Mdot
.55706 .82461 Mdot
.39791 .42545 Mdot
.34725 .61037 Mdot
.605 .54534 Mdot
.73195 .51743 Mdot
.55474 .35658 Mdot
.5082 .31036 Mdot
.5221 .70824 Mdot
.69563 .70027 Mdot
.39038 .42069 Mdot
.8106 .44067 Mdot
.65912 .53083 Mdot
.32777 .72869 Mdot
.60131 .25512 Mdot
.68287 .4874 Mdot
.46436 .21628 Mdot
.63699 .34976 Mdot
.62841 .51465 Mdot
.53392 .5584 Mdot
.39017 .44754 Mdot
.24864 .65233 Mdot
.69994 .49554 Mdot
.35887 .58681 Mdot
.52113 .37037 Mdot
.48459 .35256 Mdot
.52773 .70314 Mdot
.78169 .66616 Mdot
.37956 .45857 Mdot
.53494 .36343 Mdot
.64522 .51401 Mdot
.36338 .41127 Mdot
.39882 .59732 Mdot
.6227 .45861 Mdot
.57989 .73805 Mdot
.52742 .34772 Mdot
.69629 .4857 Mdot
.41077 .29192 Mdot
.67805 .6725 Mdot
.16753 .56516 Mdot
.36081 .42199 Mdot
.4794 .68608 Mdot
.68208 .44673 Mdot
.79048 .52138 Mdot
.64328 .56321 Mdot
.64697 .62771 Mdot
.52572 .40678 Mdot
.47924 .68799 Mdot
.6655 .50437 Mdot
.63611 .48123 Mdot
.45822 .58303 Mdot
.4908 .69797 Mdot
.68352 .52736 Mdot
.70009 .5811 Mdot
.50448 .34108 Mdot
.41802 .56563 Mdot
.52106 .34928 Mdot
.65184 .49785 Mdot
.57883 .50596 Mdot
.53775 .31809 Mdot
.68705 .21575 Mdot
.53382 .70893 Mdot
.3904 .4066 Mdot
.60021 .55877 Mdot
.68029 .54222 Mdot
.29354 .75465 Mdot
.36263 .62939 Mdot
.22144 .47247 Mdot
.35088 .69741 Mdot
.22321 .41325 Mdot
.28052 .66185 Mdot
.14565 .4406 Mdot
.45778 .79241 Mdot
.63405 .44868 Mdot
.48049 .28784 Mdot
.53372 .49717 Mdot
.35361 .43587 Mdot
.75483 .351 Mdot
.65339 .53335 Mdot
.65682 .5178 Mdot
.38959 .62482 Mdot
.31314 .32335 Mdot
.48612 .79114 Mdot
.50747 .6019 Mdot
.52062 .6815 Mdot
.4903 .34263 Mdot
.66532 .47187 Mdot
.51818 .53329 Mdot
.38672 .62046 Mdot
.33648 .73535 Mdot
.67709 .50496 Mdot
.7339 .71456 Mdot
.41605 .34442 Mdot
.36626 .41201 Mdot
.37753 .61692 Mdot
.50079 .77527 Mdot
.63429 .54014 Mdot
.34934 .42885 Mdot
.63727 .50094 Mdot
.43696 .62809 Mdot
.65715 .46179 Mdot
.48724 .67545 Mdot
.60998 .4752 Mdot
.5159 .61281 Mdot
.133 .52505 Mdot
.50518 .64096 Mdot
.49172 .36339 Mdot
.38392 .64003 Mdot
.38954 .57159 Mdot
.51687 .30699 Mdot
.3884 .57413 Mdot
.61668 .29967 Mdot
.70338 .33807 Mdot
.51812 .67388 Mdot
.72913 .51089 Mdot
.49145 .68422 Mdot
.36877 .63203 Mdot
.64283 .53559 Mdot
.72836 .24545 Mdot
.39313 .58525 Mdot
.29363 .73152 Mdot
.39235 .43347 Mdot
.35382 .62279 Mdot
.69735 .49408 Mdot
.26114 .5074 Mdot
.39112 .61436 Mdot
.28775 .40378 Mdot
.64563 .48732 Mdot
.53104 .35466 Mdot
.63342 .47854 Mdot
.59964 .55442 Mdot
.36873 .54186 Mdot
.61739 .53489 Mdot
.40323 .41608 Mdot
.54349 .31545 Mdot
.27115 .27453 Mdot
.44056 .34682 Mdot
.66841 .53886 Mdot
.64702 .51249 Mdot
.55149 .37576 Mdot
.68273 .53632 Mdot
.4003 .40242 Mdot
.66314 .84867 Mdot
.50939 .66878 Mdot
.35583 .55611 Mdot
.27646 .65988 Mdot
.63431 .56027 Mdot
.6026 .51006 Mdot
.52352 .16858 Mdot
.27306 .6678 Mdot
.40763 .41776 Mdot
.70831 .54143 Mdot
.39618 .60548 Mdot
.50889 .69304 Mdot
.41906 .42858 Mdot
.61439 .51352 Mdot
.66675 .51149 Mdot
.47969 .68304 Mdot
.58741 .36967 Mdot
.5536 .79408 Mdot
.36419 .45059 Mdot
.56291 .52694 Mdot
.31496 .62161 Mdot
.63399 .54469 Mdot
.59917 .78735 Mdot
.51282 .31002 Mdot
.35998 .41008 Mdot
.20142 .49786 Mdot
.59813 .5227 Mdot
.40206 .44816 Mdot
.39222 .42097 Mdot
.7069 .54084 Mdot
.50729 .29067 Mdot
.54891 .31565 Mdot
.4946 .33054 Mdot
.68438 .79592 Mdot
.66507 .6619 Mdot
.35877 .56854 Mdot
.38912 .44825 Mdot
.38487 .54825 Mdot
.51881 .65625 Mdot
.52317 .44779 Mdot
.36998 .54944 Mdot
.50456 .30763 Mdot
.39441 .63331 Mdot
.64089 .48229 Mdot
.38716 .42182 Mdot
.35041 .58451 Mdot
.61356 .5561 Mdot
.39241 .25407 Mdot
.34411 .50466 Mdot
.47535 .68322 Mdot
.50357 .7134 Mdot
.68534 .48345 Mdot
.40804 .61409 Mdot
.67113 .51763 Mdot
.39238 .39381 Mdot
.40914 .25917 Mdot
.63532 .56406 Mdot
.38157 .57583 Mdot
.51042 .39245 Mdot
.50732 .77255 Mdot
.63163 .57102 Mdot
.65857 .4971 Mdot
.62733 .53503 Mdot
.63656 .50101 Mdot
.28862 .3414 Mdot
.42648 .41053 Mdot
.4847 .26764 Mdot
.23218 .59426 Mdot
.53745 .33897 Mdot
.52966 .29494 Mdot
.52965 .77094 Mdot
.31658 .41803 Mdot
.40136 .43519 Mdot
.62489 .52534 Mdot
.34612 .35939 Mdot
.36955 .20301 Mdot
.64089 .17875 Mdot
.48343 .73054 Mdot
.36894 .62836 Mdot
.53705 .38024 Mdot
.37911 .62053 Mdot
.63816 .53133 Mdot
.66342 .44049 Mdot
.14084 .44456 Mdot
.38135 .4658 Mdot
.52072 .67421 Mdot
.62782 .5325 Mdot
.67302 .65836 Mdot
.3817 .60704 Mdot
.35464 .5501 Mdot
.68956 .51977 Mdot
.50164 .2995 Mdot
.21494 .66329 Mdot
.36273 .41609 Mdot
.47577 .24412 Mdot
.56593 .55056 Mdot
.45896 .27601 Mdot
.36819 .42737 Mdot
.4647 .76682 Mdot
.39074 .6264 Mdot
.59146 .29423 Mdot
.53923 .33968 Mdot
.51047 .66309 Mdot
.68343 .4512 Mdot
.54629 .33948 Mdot
.41689 .57612 Mdot
.53233 .35975 Mdot
.60497 .47761 Mdot
.42222 .43611 Mdot
.37061 .61341 Mdot
.34472 .45141 Mdot
.51199 .29017 Mdot
.50134 .70212 Mdot
.46008 .54302 Mdot
.76164 .39134 Mdot
.63389 .34558 Mdot
.66971 .54486 Mdot
.51896 .52309 Mdot
.622 .48902 Mdot
.55262 .31049 Mdot
.6398 .50685 Mdot
.5553 .39242 Mdot
.36734 .61747 Mdot
.69984 .50074 Mdot
.60885 .51216 Mdot
.73897 .32021 Mdot
.67568 .49785 Mdot
.63993 .45332 Mdot
.62567 .51761 Mdot
.57096 .32057 Mdot
.72632 .51257 Mdot
.5086 .35079 Mdot
.42858 .75899 Mdot
.36979 .59659 Mdot
.50165 .71163 Mdot
.49918 .65679 Mdot
.6563 .63232 Mdot
.39503 .65957 Mdot
.30986 .33681 Mdot
.51771 .34333 Mdot
.39839 .41673 Mdot
.63648 .5054 Mdot
.17175 .47998 Mdot
.28185 .58478 Mdot
.40342 .5977 Mdot
.44032 .34624 Mdot
.55896 .48702 Mdot
.21108 .60435 Mdot
.69074 .47995 Mdot
.72358 .75004 Mdot
.57858 .52711 Mdot
.65027 .46049 Mdot
.37637 .54525 Mdot
.54632 .68378 Mdot
.6919 .52228 Mdot
.55432 .35826 Mdot
.48602 .67056 Mdot
.48882 .28462 Mdot
.35335 .53397 Mdot
.43691 .75429 Mdot
.71858 .31862 Mdot
.6287 .49564 Mdot
.36877 .61281 Mdot
.5069 .35828 Mdot
.47828 .80195 Mdot
.37845 .40489 Mdot
.33316 .40506 Mdot
.55784 .56525 Mdot
.61961 .19258 Mdot
.49227 .66161 Mdot
.59119 .38462 Mdot
.66198 .47873 Mdot
.45868 .71395 Mdot
.6813 .5462 Mdot
.37357 .2034 Mdot
.52436 .66218 Mdot
.52864 .29936 Mdot
.40861 .43115 Mdot
.48819 .32603 Mdot
.63681 .36091 Mdot
.43944 .5635 Mdot
.48023 .50568 Mdot
.38008 .59939 Mdot
.41586 .49008 Mdot
.50842 .32612 Mdot
.59817 .50201 Mdot
.35193 .84252 Mdot
.50704 .31348 Mdot
.53436 .37609 Mdot
.77515 .32407 Mdot
.73456 .26142 Mdot
.55526 .49882 Mdot
.5432 .32304 Mdot
.37711 .59626 Mdot
.49904 .69651 Mdot
.62128 .48056 Mdot
.63609 .489 Mdot
.54429 .33447 Mdot
.36258 .54574 Mdot
.72318 .42995 Mdot
.3716 .57643 Mdot
.50191 .34234 Mdot
.364 .59427 Mdot
.24866 .52135 Mdot
.34884 .60257 Mdot
.68101 .54132 Mdot
.63879 .50653 Mdot
.32413 .66244 Mdot
.53393 .35155 Mdot
.60697 .50364 Mdot
.63275 .46849 Mdot
.51997 .32407 Mdot
.55273 .70072 Mdot
.69339 .41565 Mdot
.65161 .54386 Mdot
.65988 .48695 Mdot
.48048 .69028 Mdot
.52721 .4573 Mdot
.76746 .64174 Mdot
.60226 .49702 Mdot
.5414 .68331 Mdot
.55262 .3419 Mdot
.67667 .51374 Mdot
.30851 .26875 Mdot
.25997 .46759 Mdot
.59597 .51253 Mdot
.34615 .59822 Mdot
.7149 .52405 Mdot
.18177 .5896 Mdot
.69031 .51018 Mdot
.51648 .32929 Mdot
.5189 .37444 Mdot
.80636 .43236 Mdot
.51776 .31351 Mdot
.40476 .58159 Mdot
.37608 .43137 Mdot
.37731 .20989 Mdot
.39829 .59828 Mdot
.62698 .56649 Mdot
.82664 .45426 Mdot
.61839 .45595 Mdot
.62325 .56181 Mdot
.2346 .67006 Mdot
.39516 .60095 Mdot
.49604 .36025 Mdot
.47502 .58666 Mdot
.59294 .45763 Mdot
.35754 .41678 Mdot
.71166 .47185 Mdot
.63239 .55005 Mdot
.27515 .69671 Mdot
.26941 .41001 Mdot
.36641 .39683 Mdot
.63596 .44469 Mdot
.60213 .49899 Mdot
.40687 .53137 Mdot
.64077 .51212 Mdot
.49272 .69351 Mdot
.50878 .37359 Mdot
.35993 .61809 Mdot
.50429 .67598 Mdot
.65567 .53579 Mdot
.52082 .68914 Mdot
.353 .58533 Mdot
.35246 .42017 Mdot
.63637 .53538 Mdot
.48201 .65739 Mdot
.5203 .6852 Mdot
.61694 .49017 Mdot
.52933 .36581 Mdot
.57545 .52452 Mdot
.68208 .50772 Mdot
.61767 .47568 Mdot
.54404 .34026 Mdot
.56849 .12874 Mdot
.69274 .50075 Mdot
.4604 .6333 Mdot
.53609 .37291 Mdot
.40686 .5078 Mdot
.36203 .62173 Mdot
.63813 .55143 Mdot
.35639 .40881 Mdot
.37799 .45171 Mdot
.4059 .56539 Mdot
.51962 .38321 Mdot
.34204 .68814 Mdot
.52232 .39517 Mdot
.58733 .47403 Mdot
.5966 .47304 Mdot
.81836 .50886 Mdot
.1879 .38205 Mdot
.48542 .34497 Mdot
.34059 .56202 Mdot
.50664 .59529 Mdot
.39733 .44609 Mdot
.34316 .60689 Mdot
.53237 .38271 Mdot
.51808 .37966 Mdot
.52531 .36117 Mdot
.51948 .66736 Mdot
.33026 .66345 Mdot
.48266 .3181 Mdot
.50847 .29827 Mdot
.64462 .48537 Mdot
.60254 .50307 Mdot
.55289 .72805 Mdot
.61057 .73908 Mdot
.51036 .7072 Mdot
.37808 .56559 Mdot
.59735 .86146 Mdot
.39453 .39473 Mdot
.72584 .30102 Mdot
.6332 .56337 Mdot
.33671 .85931 Mdot
.69369 .48717 Mdot
.64206 .51502 Mdot
.5446 .31836 Mdot
.47581 .6682 Mdot
.4933 .67514 Mdot
.50185 .32895 Mdot
.54921 .30502 Mdot
.49179 .69237 Mdot
.5084 .21444 Mdot
.33029 .23716 Mdot
.44651 .58784 Mdot
.52626 .32928 Mdot
.74996 .37778 Mdot
.3505 .43893 Mdot
.4658 .34957 Mdot
.41317 .40349 Mdot
.37587 .60554 Mdot
.41036 .60976 Mdot
.35929 .42777 Mdot
.64489 .48889 Mdot
.3602 .56248 Mdot
.62498 .45006 Mdot
.52264 .23142 Mdot
.68537 .39564 Mdot
.29278 .6584 Mdot
.70856 .49012 Mdot
.44981 .76467 Mdot
.31231 .44011 Mdot
.67045 .52922 Mdot
.2429 .36549 Mdot
.52203 .67818 Mdot
.4707 .33325 Mdot
.37718 .39685 Mdot
.17076 .58855 Mdot
.62714 .53902 Mdot
.51955 .33228 Mdot
.40022 .4249 Mdot
.66257 .61233 Mdot
.42593 .26587 Mdot
.62931 .53358 Mdot
.38323 .86107 Mdot
.56038 .29684 Mdot
.35715 .61499 Mdot
.80112 .57347 Mdot
.48267 .33361 Mdot
.49138 .73257 Mdot
.23793 .58534 Mdot
.57473 .18399 Mdot
.49635 .35569 Mdot
.3428 .61183 Mdot
.49273 .33646 Mdot
.49858 .70116 Mdot
.49205 .37867 Mdot
.3801 .61243 Mdot
.67238 .50151 Mdot
.38101 .57043 Mdot
.52177 .70588 Mdot
.56385 .78463 Mdot
.36325 .39911 Mdot
.34716 .60945 Mdot
.37395 .44276 Mdot
.68654 .68086 Mdot
.22623 .60446 Mdot
.38872 .40232 Mdot
.78017 .52717 Mdot
.59807 .5269 Mdot
.48532 .31919 Mdot
.39288 .56591 Mdot
.24493 .57432 Mdot
.47323 .56368 Mdot
.53604 .33016 Mdot
.36316 .57148 Mdot
.54274 .54586 Mdot
.7888 .54393 Mdot
.70143 .55772 Mdot
.6863 .69628 Mdot
.52465 .32503 Mdot
.34689 .6227 Mdot
.4933 .80622 Mdot
.49947 .3113 Mdot
.39856 .57501 Mdot
.40877 .43744 Mdot
.37451 .42435 Mdot
.68506 .52889 Mdot
.33794 .44757 Mdot
.37134 .56204 Mdot
.32938 .46944 Mdot
.55146 .35202 Mdot
.6267 .61321 Mdot
.50112 .6543 Mdot
.37068 .58793 Mdot
.61165 .46558 Mdot
.47522 .31763 Mdot
.24927 .49768 Mdot
.75007 .44412 Mdot
.5303 .85019 Mdot
.38398 .56726 Mdot
.52139 .37839 Mdot
.52254 .33574 Mdot
.63072 .57034 Mdot
.4971 .57157 Mdot
.34065 .68398 Mdot
.73945 .59409 Mdot
.64274 .6237 Mdot
.41508 .56437 Mdot
.41101 .55084 Mdot
.59817 .53811 Mdot
.626 .50049 Mdot
.40263 .44192 Mdot
.66875 .49798 Mdot
.53813 .30713 Mdot
.68537 .53118 Mdot
.36446 .42851 Mdot
.38508 .59553 Mdot
.64365 .5334 Mdot
.51056 .70471 Mdot
.34966 .41332 Mdot
.40246 .45165 Mdot
.37558 .58246 Mdot
.54685 .34261 Mdot
.52595 .64798 Mdot
.37111 .57465 Mdot
.62964 .49554 Mdot
.35772 .37553 Mdot
.61729 .46963 Mdot
.54972 .2422 Mdot
.50127 .30885 Mdot
.37334 .62072 Mdot
.55258 .35289 Mdot
.38188 .44545 Mdot
.2326 .59064 Mdot
.64799 .50136 Mdot
.39918 .57953 Mdot
.31485 .64308 Mdot
.55427 .25664 Mdot
.56075 .36308 Mdot
.30027 .406 Mdot
.54009 .29892 Mdot
.41824 .59065 Mdot
.78177 .35695 Mdot
.49685 .66153 Mdot
.40202 .60067 Mdot
.23643 .324 Mdot
.38788 .58081 Mdot
.67839 .49415 Mdot
.6797 .48025 Mdot
.3548 .61385 Mdot
.47883 .67291 Mdot
.46184 .79948 Mdot
.42863 .59916 Mdot
.49709 .35994 Mdot
.61069 .20913 Mdot
.45172 .84162 Mdot
.33162 .44227 Mdot
.40641 .4328 Mdot
.59031 .45831 Mdot
.64086 .45919 Mdot
.4157 .40832 Mdot
.38693 .46231 Mdot
.53131 .68254 Mdot
.41047 .57377 Mdot
.57506 .34245 Mdot
.34979 .44689 Mdot
.74789 .49448 Mdot
.39822 .66175 Mdot
.66772 .56845 Mdot
.55244 .53552 Mdot
.6874 .54034 Mdot
.66744 .62379 Mdot
.3626 .42641 Mdot
.66178 .46917 Mdot
.69751 .55563 Mdot
.35829 .40817 Mdot
.49468 .69582 Mdot
.3136 .36909 Mdot
.36146 .6012 Mdot
.40329 .16584 Mdot
.64814 .46364 Mdot
.68144 .49527 Mdot
.35643 .43934 Mdot
.36897 .71579 Mdot
.5402 .35177 Mdot
.49657 .31195 Mdot
.35726 .56184 Mdot
.46336 .53763 Mdot
.64513 .55008 Mdot
.67923 .52033 Mdot
.35993 .6073 Mdot
.35178 .61975 Mdot
.32815 .50029 Mdot
.65022 .47557 Mdot
.39892 .42939 Mdot
.52367 .61469 Mdot
.36262 .42779 Mdot
.61474 .46728 Mdot
.67866 .48994 Mdot
.68106 .54098 Mdot
.61013 .46724 Mdot
.41137 .4455 Mdot
.65948 .46993 Mdot
.71115 .56035 Mdot
.54112 .35624 Mdot
.61811 .53113 Mdot
.6633 .62125 Mdot
.65999 .49308 Mdot
.49721 .69562 Mdot
.75546 .48608 Mdot
.62913 .53863 Mdot
.64752 .55185 Mdot
.42435 .61651 Mdot
.66138 .50678 Mdot
.3958 .39458 Mdot
.53335 .3417 Mdot
.38741 .44869 Mdot
.36415 .44862 Mdot
.39527 .55822 Mdot
.52905 .70298 Mdot
.6342 .55935 Mdot
.52774 .67839 Mdot
.6676 .55673 Mdot
.59564 .51589 Mdot
.25848 .61045 Mdot
.73579 .73795 Mdot
.56567 .79592 Mdot
.64686 .50029 Mdot
.39597 .59248 Mdot
.36621 .62252 Mdot
.52393 .26801 Mdot
.69337 .56201 Mdot
.41768 .41261 Mdot
.38462 .45206 Mdot
.5872 .73318 Mdot
.26907 .68049 Mdot
.49641 .69567 Mdot
.51541 .49566 Mdot
.61629 .45075 Mdot
.63046 .47062 Mdot
.62577 .45708 Mdot
.38181 .54825 Mdot
.50252 .60771 Mdot
.40137 .60024 Mdot
.42755 .33954 Mdot
.36179 .43513 Mdot
.62401 .53774 Mdot
.55506 .40408 Mdot
.50619 .31032 Mdot
.53326 .34253 Mdot
.41079 .44252 Mdot
.38263 .64453 Mdot
.54205 .75337 Mdot
.68358 .19775 Mdot
.56554 .30065 Mdot
.4737 .67893 Mdot
.66838 .53324 Mdot
.3832 .59029 Mdot
.49279 .3296 Mdot
.48715 .70466 Mdot
.59731 .49646 Mdot
.32899 .66282 Mdot
.64337 .49721 Mdot
.53489 .49211 Mdot
.51878 .36696 Mdot
.35854 .21625 Mdot
.49944 .37303 Mdot
.35137 .40994 Mdot
.3746 .39897 Mdot
.67972 .48351 Mdot
.80995 .53693 Mdot
.48846 .31919 Mdot
.37498 .48375 Mdot
.52651 .66547 Mdot
.26109 .48917 Mdot
.4929 .69755 Mdot
.36259 .61741 Mdot
.48709 .66769 Mdot
.37619 .61557 Mdot
.57893 .75713 Mdot
.56613 .36287 Mdot
.50836 .67223 Mdot
.43584 .63729 Mdot
.68638 .56652 Mdot
.49806 .70861 Mdot
.60219 .44855 Mdot
.58203 .24067 Mdot
.35738 .60073 Mdot
.50274 .65803 Mdot
.59861 .49985 Mdot
.15625 .47697 Mdot
.40408 .41415 Mdot
.41447 .40938 Mdot
.58817 .47406 Mdot
.40045 .55653 Mdot
.55016 .36769 Mdot
.30602 .29759 Mdot
.39112 .38654 Mdot
.68865 .49173 Mdot
.69074 .52417 Mdot
.52338 .2944 Mdot
.45702 .38523 Mdot
.67677 .48432 Mdot
.76843 .52625 Mdot
.65731 .4745 Mdot
.41215 .43395 Mdot
.48745 .33081 Mdot
.52724 .33859 Mdot
.36139 .57059 Mdot
.53269 .30904 Mdot
.55857 .27732 Mdot
.36565 .36474 Mdot
.5824 .46289 Mdot
.38632 .44082 Mdot
.4062 .35257 Mdot
.42975 .33932 Mdot
.20256 .37581 Mdot
.51953 .29237 Mdot
.69581 .52916 Mdot
.54964 .35593 Mdot
.50721 .69531 Mdot
.52985 .35206 Mdot
.53994 .37841 Mdot
.67161 .52148 Mdot
.63481 .53015 Mdot
.38984 .60104 Mdot
.4975 .57888 Mdot
.54688 .35227 Mdot
.68001 .47827 Mdot
.64543 .45528 Mdot
.63175 .45192 Mdot
.47378 .43314 Mdot
.48625 .34241 Mdot
.7097 .27043 Mdot
.58288 .64439 Mdot
.54731 .35102 Mdot
.18806 .63227 Mdot
.2477 .56484 Mdot
.36865 .63478 Mdot
.33776 .42705 Mdot
.64848 .47509 Mdot
.36741 .62575 Mdot
.63841 .53163 Mdot
.55293 .53693 Mdot
.66322 .51392 Mdot
.48863 .68968 Mdot
.63553 .44893 Mdot
.41957 .59174 Mdot
.37503 .57235 Mdot
.69081 .50285 Mdot
.64876 .53064 Mdot
.5512 .78531 Mdot
.54096 .29463 Mdot
.53685 .35459 Mdot
.34638 .70061 Mdot
.51381 .68103 Mdot
.35846 .41389 Mdot
.63251 .51273 Mdot
.39031 .55575 Mdot
.37786 .57026 Mdot
.4838 .33381 Mdot
.36073 .58158 Mdot
.36281 .41779 Mdot
.64713 .50412 Mdot
.41404 .4075 Mdot
.52162 .66844 Mdot
.48915 .34226 Mdot
.62403 .53302 Mdot
.64511 .48528 Mdot
.51837 .37433 Mdot
.61721 .55194 Mdot
.48089 .69027 Mdot
.38811 .57817 Mdot
.49824 .35441 Mdot
.37566 .42962 Mdot
.36932 .6186 Mdot
.62484 .47637 Mdot
.57165 .85972 Mdot
.67403 .49144 Mdot
.6413 .4758 Mdot
.23154 .32067 Mdot
.62868 .44775 Mdot
.38942 .56573 Mdot
.52036 .29869 Mdot
.69306 .47472 Mdot
.64881 .63837 Mdot
.6113 .15489 Mdot
.40466 .59389 Mdot
.67124 .5334 Mdot
.15856 .43419 Mdot
.68167 .52287 Mdot
.80615 .4764 Mdot
.44608 .65586 Mdot
.42886 .50027 Mdot
.58436 .54032 Mdot
.37372 .41421 Mdot
.39148 .60032 Mdot
.36414 .61598 Mdot
.66015 .23462 Mdot
.67463 .52118 Mdot
.52947 .50486 Mdot
.60432 .52364 Mdot
.36992 .42573 Mdot
.57982 .7166 Mdot
.38091 .56745 Mdot
.58383 .8142 Mdot
.62564 .48777 Mdot
.48577 .35267 Mdot
.38842 .63675 Mdot
.25831 .53824 Mdot
.61801 .47689 Mdot
.52769 .68488 Mdot
.34411 .43538 Mdot
.66794 .45875 Mdot
.38472 .43738 Mdot
.61631 .47368 Mdot
.73903 .474 Mdot
.80354 .60058 Mdot
.5273 .36427 Mdot
.40816 .43473 Mdot
.34206 .38445 Mdot
.70979 .50906 Mdot
.49767 .35597 Mdot
.53909 .3381 Mdot
.53079 .68672 Mdot
.4897 .49248 Mdot
.39467 .29688 Mdot
.73719 .4125 Mdot
.65023 .22422 Mdot
.38587 .64009 Mdot
.29235 .44214 Mdot
.6121 .4833 Mdot
.32251 .71813 Mdot
.37773 .39398 Mdot
.67941 .49835 Mdot
.59368 .26902 Mdot
.49809 .32627 Mdot
.66171 .48414 Mdot
.49158 .68641 Mdot
.35011 .73141 Mdot
.34547 .73779 Mdot
.20861 .55082 Mdot
.37882 .60107 Mdot
.67367 .44356 Mdot
.59652 .43727 Mdot
.35536 .55938 Mdot
.61614 .54632 Mdot
.39406 .5725 Mdot
.54494 .2053 Mdot
.4806 .69589 Mdot
.48756 .34949 Mdot
.25258 .55741 Mdot
.63727 .55475 Mdot
.59861 .46643 Mdot
.50126 .71554 Mdot
.62082 .50211 Mdot
.77493 .67464 Mdot
.285 .60528 Mdot
.35205 .57631 Mdot
.5259 .36193 Mdot
.65169 .55371 Mdot
.50101 .49046 Mdot
.68238 .51105 Mdot
.70298 .3624 Mdot
.6503 .55213 Mdot
.40976 .28197 Mdot
.52237 .37014 Mdot
.38169 .4401 Mdot
.71098 .52148 Mdot
.65632 .51502 Mdot
.54563 .62295 Mdot
.57969 .5254 Mdot
.68501 .47909 Mdot
.55512 .36521 Mdot
.49336 .32401 Mdot
.50897 .34971 Mdot
.40279 .6103 Mdot
.27329 .68923 Mdot
.39577 .43911 Mdot
.72065 .50745 Mdot
.35234 .452 Mdot
.77219 .47964 Mdot
.47641 .68882 Mdot
.17582 .45977 Mdot
.61663 .51952 Mdot
.51182 .34321 Mdot
.24949 .4013 Mdot
.55375 .33716 Mdot
.51003 .52749 Mdot
.38982 .42078 Mdot
.50195 .3213 Mdot
.64795 .51559 Mdot
.48959 .58693 Mdot
.17724 .51826 Mdot
.37538 .44817 Mdot
.65506 .56183 Mdot
.37075 .62953 Mdot
.269 .64274 Mdot
.55519 .86104 Mdot
.40689 .41597 Mdot
.34831 .38276 Mdot
.6749 .52331 Mdot
.50869 .30708 Mdot
.36927 .41506 Mdot
.39642 .40719 Mdot
.35965 .58089 Mdot
.63206 .52977 Mdot
.62802 .52901 Mdot
.4112 .60402 Mdot
.37506 .45014 Mdot
.58671 .53051 Mdot
.6639 .46369 Mdot
.13383 .45413 Mdot
.56267 .58882 Mdot
.4547 .13751 Mdot
.56513 .28764 Mdot
.59943 .29687 Mdot
.32831 .26953 Mdot
.5233 .37935 Mdot
.63068 .53995 Mdot
.69628 .46559 Mdot
.37186 .56247 Mdot
.6604 .50015 Mdot
.34747 .55412 Mdot
.40391 .43033 Mdot
.18559 .61493 Mdot
.38258 .33877 Mdot
.54686 .19252 Mdot
.66281 .50158 Mdot
.44589 .34966 Mdot
.50236 .68437 Mdot
.43184 .42506 Mdot
.50104 .34875 Mdot
.6022 .47937 Mdot
.55122 .78697 Mdot
.40134 .60117 Mdot
.53288 .31768 Mdot
.48793 .79506 Mdot
.45474 .76333 Mdot
.61329 .46803 Mdot
.39307 .61828 Mdot
.2521 .37518 Mdot
.75769 .54082 Mdot
.42352 .40202 Mdot
.49005 .69262 Mdot
.39002 .60688 Mdot
.37183 .45177 Mdot
.57609 .37989 Mdot
.50927 .31538 Mdot
.52055 .39013 Mdot
.62163 .77331 Mdot
.34995 .56552 Mdot
.50007 .68062 Mdot
.26749 .67259 Mdot
.33428 .74078 Mdot
.4883 .68788 Mdot
.40596 .61504 Mdot
.49283 .32644 Mdot
.50436 .33452 Mdot
.53303 .34067 Mdot
.56034 .81429 Mdot
.50694 .37824 Mdot
.69268 .27676 Mdot
.61621 .45605 Mdot
.68012 .43299 Mdot
.6755 .53003 Mdot
.41972 .41305 Mdot
.51182 .3672 Mdot
.45175 .53382 Mdot
.69105 .5532 Mdot
.19863 .56327 Mdot
.68628 .5105 Mdot
.42852 .42734 Mdot
.65457 .48024 Mdot
.73172 .32316 Mdot
.54662 .36102 Mdot
.65208 .49953 Mdot
.41203 .39945 Mdot
.51608 .68894 Mdot
.53062 .39401 Mdot
.62758 .53478 Mdot
.32091 .31863 Mdot
.63171 .44788 Mdot
.50039 .20491 Mdot
.59335 .60704 Mdot
.47374 .679 Mdot
.61446 .59011 Mdot
.34339 .57375 Mdot
.63397 .42506 Mdot
.68365 .44204 Mdot
.37101 .44457 Mdot
.2352 .52785 Mdot
.3712 .5968 Mdot
.4664 .71282 Mdot
.72093 .48519 Mdot
.51721 .70852 Mdot
.55021 .30348 Mdot
.4241 .42065 Mdot
.59725 .53027 Mdot
.66705 .56647 Mdot
.55584 .22391 Mdot
.73004 .50542 Mdot
.68484 .53335 Mdot
.48361 .7052 Mdot
.64849 .24105 Mdot
.65539 .49081 Mdot
.5088 .51689 Mdot
.49769 .3813 Mdot
.58123 .51971 Mdot
.73106 .3003 Mdot
.68393 .48252 Mdot
.52404 .30977 Mdot
.55587 .37881 Mdot
.32744 .34775 Mdot
.5321 .67624 Mdot
.64011 .55128 Mdot
.80449 .42796 Mdot
.62533 .49136 Mdot
.39684 .43065 Mdot
.6362 .46084 Mdot
.38138 .60947 Mdot
.54686 .80913 Mdot
.36383 .56271 Mdot
.65055 .54672 Mdot
.53124 .33594 Mdot
.35684 .43451 Mdot
.62302 .78554 Mdot
.37117 .67344 Mdot
.67909 .26663 Mdot
.5489 .17283 Mdot
.48366 .66565 Mdot
.52695 .70854 Mdot
.42427 .42473 Mdot
.65156 .49825 Mdot
.78613 .34926 Mdot
.5776 .51545 Mdot
.65834 .48585 Mdot
.66303 .51518 Mdot
.24235 .63204 Mdot
.3999 .44252 Mdot
.3607 .59078 Mdot
.67713 .48645 Mdot
.66792 .47172 Mdot
.5278 .37731 Mdot
.51857 .68639 Mdot
.36337 .62217 Mdot
.51481 .67123 Mdot
.3902 .59157 Mdot
.18317 .62114 Mdot
.71438 .51992 Mdot
.51395 .68805 Mdot
.34802 .40629 Mdot
.54409 .33613 Mdot
.35751 .36762 Mdot
.36205 .61636 Mdot
.37592 .5651 Mdot
.68827 .504 Mdot
.52371 .30863 Mdot
.54775 .32946 Mdot
.50819 .6967 Mdot
.38118 .40191 Mdot
.6325 .5378 Mdot
.59446 .50806 Mdot
.4915 .26773 Mdot
.39431 .5538 Mdot
.53998 .52443 Mdot
.29492 .3553 Mdot
.64765 .49863 Mdot
.5462 .3307 Mdot
.65896 .52508 Mdot
.34941 .24537 Mdot
.5151 .30527 Mdot
.69081 .48668 Mdot
.3853 .78594 Mdot
.36257 .64888 Mdot
.3526 .32207 Mdot
.69029 .5309 Mdot
.45227 .17317 Mdot
.60591 .49383 Mdot
.12093 .48401 Mdot
.43729 .68627 Mdot
.63087 .54463 Mdot
.62762 .47831 Mdot
.69433 .40915 Mdot
.65475 .53887 Mdot
.41833 .59216 Mdot
.5178 .75716 Mdot
.5485 .37225 Mdot
.35295 .27643 Mdot
.63171 .41595 Mdot
.52134 .66095 Mdot
.35617 .56344 Mdot
.40555 .54187 Mdot
.48904 .6768 Mdot
.52372 .32812 Mdot
.63625 .50119 Mdot
.46133 .50926 Mdot
.40709 .55587 Mdot
.62558 .57468 Mdot
.39489 .42823 Mdot
.29914 .49658 Mdot
.37941 .64777 Mdot
.37729 .43469 Mdot
.61365 .52757 Mdot
.69705 .41344 Mdot
.67113 .72931 Mdot
.32597 .23154 Mdot
.36213 .44862 Mdot
.36746 .44592 Mdot
.54053 .81895 Mdot
.51034 .65475 Mdot
.57141 .21632 Mdot
.41706 .27325 Mdot
.3568 .42341 Mdot
.7231 .58285 Mdot
.40977 .58285 Mdot
.33159 .31419 Mdot
.47036 .33414 Mdot
.60046 .46936 Mdot
.65054 .51515 Mdot
.37663 .40157 Mdot
.54515 .2575 Mdot
.79916 .59373 Mdot
.37232 .44156 Mdot
.72828 .54495 Mdot
.46455 .45433 Mdot
.24668 .56735 Mdot
.40295 .56468 Mdot
.53283 .68109 Mdot
.47256 .70873 Mdot
.4977 .3644 Mdot
.53312 .69318 Mdot
.34095 .72711 Mdot
.61995 .50856 Mdot
.36734 .43511 Mdot
.25194 .49653 Mdot
.37865 .4274 Mdot
.49146 .67506 Mdot
.47322 .68162 Mdot
.54107 .35601 Mdot
.53484 .35527 Mdot
.60838 .32117 Mdot
.60206 .69873 Mdot
.68558 .51682 Mdot
.20086 .4893 Mdot
.55188 .35076 Mdot
.56586 .54325 Mdot
.52424 .70903 Mdot
.51614 .68498 Mdot
.56307 .61986 Mdot
.62482 .52146 Mdot
.80423 .45119 Mdot
.62853 .51801 Mdot
.58554 .71132 Mdot
.6666 .55336 Mdot
.36015 .58102 Mdot
.62191 .52524 Mdot
.53297 .64775 Mdot
.59486 .53014 Mdot
.65398 .46254 Mdot
.3926 .55059 Mdot
.67587 .46197 Mdot
.37924 .60992 Mdot
.66324 .54376 Mdot
.52361 .65999 Mdot
.37704 .55208 Mdot
.65777 .65538 Mdot
.48152 .61925 Mdot
.39721 .6237 Mdot
.52452 .70181 Mdot
.51191 .65792 Mdot
.69793 .63583 Mdot
.50016 .34819 Mdot
.47719 .37015 Mdot
.65565 .49782 Mdot
.35177 .55223 Mdot
.40383 .43908 Mdot
.6608 .47109 Mdot
.66352 .45121 Mdot
.69666 .51593 Mdot
.49086 .35753 Mdot
.33393 .67948 Mdot
.51235 .69308 Mdot
.40736 .60496 Mdot
.55377 .69051 Mdot
.41175 .56681 Mdot
.71589 .53715 Mdot
.68913 .45543 Mdot
.5974 .33039 Mdot
.23341 .45897 Mdot
.52408 .83132 Mdot
.51281 .31281 Mdot
.34649 .60357 Mdot
.50732 .65544 Mdot
.58528 .55929 Mdot
.5054 .34212 Mdot
.38015 .612 Mdot
.6429 .49792 Mdot
.65856 .56109 Mdot
.42645 .36258 Mdot
.59853 .42704 Mdot
.61889 .62686 Mdot
.41161 .56958 Mdot
.34209 .60756 Mdot
.33008 .73403 Mdot
.5082 .75221 Mdot
.4668 .5536 Mdot
.67563 .50933 Mdot
.52741 .68231 Mdot
.49293 .3294 Mdot
.64714 .75214 Mdot
.38906 .39865 Mdot
.49704 .57572 Mdot
.66087 .50175 Mdot
.41785 .50716 Mdot
.53267 .33639 Mdot
.49352 .69011 Mdot
.37394 .40214 Mdot
.4876 .71514 Mdot
.36345 .55107 Mdot
.64409 .19198 Mdot
.62321 .49502 Mdot
.68927 .5127 Mdot
.35958 .40007 Mdot
.49621 .33151 Mdot
.50174 .71776 Mdot
.5279 .22742 Mdot
.35175 .59548 Mdot
.79856 .36899 Mdot
.5363 .30945 Mdot
.72668 .3317 Mdot
.41105 .59849 Mdot
.40921 .44418 Mdot
.68502 .64979 Mdot
.36501 .42737 Mdot
.65457 .54845 Mdot
.52069 .34171 Mdot
.40439 .41905 Mdot
.51895 .58876 Mdot
.15794 .45341 Mdot
.7441 .36367 Mdot
.62639 .51029 Mdot
.15496 .51591 Mdot
.44787 .2111 Mdot
.5457 .29378 Mdot
.35568 .40915 Mdot
.68383 .50592 Mdot
.61534 .54323 Mdot
.62891 .48964 Mdot
.39237 .41558 Mdot
.25697 .59376 Mdot
.35645 .60223 Mdot
.67581 .5266 Mdot
.5307 .68097 Mdot
.37384 .60741 Mdot
.25209 .55496 Mdot
.38502 .56434 Mdot
.52893 .28932 Mdot
.6364 .45994 Mdot
.4119 .45814 Mdot
.13728 .55483 Mdot
.38432 .44928 Mdot
.40183 .62075 Mdot
.6442 .46614 Mdot
.24385 .4912 Mdot
.50842 .34776 Mdot
.35224 .58673 Mdot
.68164 .49613 Mdot
.25833 .56593 Mdot
.56547 .78827 Mdot
.38438 .56496 Mdot
.49923 .3397 Mdot
.28503 .29095 Mdot
.66539 .49842 Mdot
.60847 .4937 Mdot
.50356 .32665 Mdot
.70734 .43236 Mdot
.49367 .8025 Mdot
.65316 .52846 Mdot
.3799 .43969 Mdot
.77791 .30487 Mdot
.69302 .47868 Mdot
.5737 .65581 Mdot
.39015 .60338 Mdot
.32396 .33613 Mdot
.54307 .54097 Mdot
.57104 .54643 Mdot
.51603 .23507 Mdot
.50734 .42312 Mdot
.18554 .57695 Mdot
.34158 .56724 Mdot
.45564 .746 Mdot
.18102 .58446 Mdot
.42431 .41148 Mdot
.49715 .3999 Mdot
.47951 .2378 Mdot
.63278 .80373 Mdot
.28332 .30275 Mdot
.39236 .73467 Mdot
.54693 .7891 Mdot
.4533 .48587 Mdot
.39165 .58547 Mdot
.46741 .6602 Mdot
.63345 .53414 Mdot
.44533 .21023 Mdot
.79184 .42702 Mdot
.81889 .55222 Mdot
.15235 .50724 Mdot
.79785 .46952 Mdot
.17082 .47598 Mdot
.21164 .36181 Mdot
.58581 .29005 Mdot
.2401 .43916 Mdot
.81068 .38368 Mdot
.37462 .77478 Mdot
.6699 .22569 Mdot
.59586 .44408 Mdot
.51793 .53252 Mdot
.51498 .19176 Mdot
.69577 .29659 Mdot
.79382 .55286 Mdot
.35982 .57015 Mdot
.51637 .29817 Mdot
.46675 .2395 Mdot
.55689 .32073 Mdot
.32622 .43855 Mdot
.29464 .27355 Mdot
.15899 .42423 Mdot
.73302 .32019 Mdot
.42141 .16939 Mdot
.60897 .26974 Mdot
.83125 .64976 Mdot
.42697 .58187 Mdot
.48129 .33418 Mdot
.51501 .73303 Mdot
.31999 .73 Mdot
.43492 .31337 Mdot
.47278 .22692 Mdot
.26454 .62412 Mdot
.65127 .69051 Mdot
.52083 .3322 Mdot
.61068 .59346 Mdot
.32944 .45917 Mdot
.39191 .33922 Mdot
.51466 .76063 Mdot
.23446 .34098 Mdot
.47409 .52395 Mdot
.33247 .30422 Mdot
.2951 .4706 Mdot
.55642 .85676 Mdot
.58817 .63709 Mdot
.58129 .32531 Mdot
.38044 .36995 Mdot
.33813 .25453 Mdot
.67547 .77291 Mdot
.60861 .71489 Mdot
.32456 .73369 Mdot
.27798 .72313 Mdot
.41505 .20588 Mdot
.33155 .78967 Mdot
.48447 .376 Mdot
.68801 .53003 Mdot
.61412 .40329 Mdot
.80053 .41609 Mdot
.47685 .6535 Mdot
.21503 .5551 Mdot
.5122 .6609 Mdot
.50681 .28719 Mdot
.53487 .8047 Mdot
.7105 .29098 Mdot
.80872 .42423 Mdot
.52015 .7187 Mdot
.70858 .49074 Mdot
.82811 .31937 Mdot
.18596 .56179 Mdot
.34969 .33924 Mdot
.12894 .46161 Mdot
.4426 .53451 Mdot
.65523 .61262 Mdot
.40298 .41896 Mdot
.16726 .56918 Mdot
.51034 .33578 Mdot
.26449 .74457 Mdot
.13551 .51405 Mdot
.77963 .61031 Mdot
.52158 .08943 Mdot
.30469 .69499 Mdot
.42769 .50566 Mdot
.4866 .41265 Mdot
.6294 .65125 Mdot
.77714 .65257 Mdot
.77801 .58876 Mdot
.25283 .47259 Mdot
.52812 .17325 Mdot
.17079 .56117 Mdot
.79769 .39113 Mdot
.65272 .20262 Mdot
.65276 .79509 Mdot
.5118 .47253 Mdot
.46593 .32903 Mdot
.43272 .57755 Mdot
.22455 .38366 Mdot
.22833 .67183 Mdot
.57829 .64194 Mdot
.63648 .16011 Mdot
.54648 .67376 Mdot
.42608 .68614 Mdot
.30232 .25183 Mdot
.66906 .67985 Mdot
.59866 .5966 Mdot
.46519 .78845 Mdot
.63209 .57389 Mdot
.43741 .77983 Mdot
.19039 .46579 Mdot
.33409 .382 Mdot
.38064 .77418 Mdot
.27657 .33753 Mdot
.54576 .22744 Mdot
.68476 .39025 Mdot
.31786 .7346 Mdot
.55641 .34794 Mdot
.62763 .69636 Mdot
.58455 .59491 Mdot
.15216 .42744 Mdot
.34846 .38343 Mdot
.1775 .36885 Mdot
.50449 .7938 Mdot
.70314 .52573 Mdot
.64192 .43143 Mdot
.71509 .56314 Mdot
.60992 .68769 Mdot
.66876 .46384 Mdot
.43489 .33676 Mdot
.18605 .37877 Mdot
.59878 .25541 Mdot
.30928 .39578 Mdot
.23509 .53824 Mdot
.31741 .23441 Mdot
.60842 .37216 Mdot
.49364 .75792 Mdot
.56187 .72331 Mdot
.61407 .82847 Mdot
.3674 .59694 Mdot
.79082 .37408 Mdot
.42889 .40618 Mdot
.59336 .7746 Mdot
.74552 .4175 Mdot
.76424 .65687 Mdot
.18694 .37722 Mdot
.42424 .75796 Mdot
.52856 .7913 Mdot
.6985 .67111 Mdot
.77941 .32564 Mdot
.22883 .547 Mdot
.70839 .46868 Mdot
.41393 .23307 Mdot
.4791 .66973 Mdot
.62919 .35749 Mdot
.73246 .27772 Mdot
.38824 .70359 Mdot
.59621 .46043 Mdot
.71614 .69838 Mdot
.30392 .60518 Mdot
.48971 .58473 Mdot
.42838 .84842 Mdot
.68181 .56646 Mdot
.27573 .67991 Mdot
.43614 .20076 Mdot
.60681 .65729 Mdot
.33355 .24208 Mdot
.30944 .30473 Mdot
.30867 .76798 Mdot
.13578 .49099 Mdot
.35996 .67679 Mdot
.19434 .60403 Mdot
.14236 .43709 Mdot
.34055 .78717 Mdot
.72382 .47039 Mdot
.36686 .39321 Mdot
.49968 .8852 Mdot
.41742 .58364 Mdot
.24026 .64102 Mdot
.65117 .22492 Mdot
.26453 .56182 Mdot
.5752 .35426 Mdot
.57185 .46229 Mdot
.45926 .49272 Mdot
.54172 .29013 Mdot
.67017 .46134 Mdot
.45106 .8378 Mdot
.31578 .76113 Mdot
.39463 .82363 Mdot
.44367 .18706 Mdot
.19275 .6155 Mdot
.42729 .48026 Mdot
.70274 .29517 Mdot
.51676 .27075 Mdot
.60151 .47407 Mdot
.45452 .6431 Mdot
.30374 .69235 Mdot
.71067 .70699 Mdot
.43031 .30078 Mdot
.54595 .29888 Mdot
.20391 .51739 Mdot
.83957 .68883 Mdot
.6127 .28917 Mdot
.73124 .29498 Mdot
.34105 .73766 Mdot
.59862 .68735 Mdot
.2153 .40774 Mdot
.77194 .63436 Mdot
.22304 .33385 Mdot
.54786 .29076 Mdot
.65396 .22078 Mdot
.40321 .7283 Mdot
.72527 .59469 Mdot
.32653 .67432 Mdot
.16982 .4267 Mdot
.45026 .4219 Mdot
.67241 .74827 Mdot
.42749 .25622 Mdot
.78813 .60244 Mdot
.44705 .67737 Mdot
.30487 .49627 Mdot
.7384 .28332 Mdot
.28059 .41038 Mdot
.58378 .68472 Mdot
.47163 .46597 Mdot
.61109 .57981 Mdot
.50508 .4221 Mdot
.58474 .67395 Mdot
.70047 .61314 Mdot
.21836 .64054 Mdot
.10154 .50087 Mdot
.52584 .84319 Mdot
.39746 .17183 Mdot
.2007 .44957 Mdot
.58978 .4825 Mdot
.27224 .26724 Mdot
.35762 .81358 Mdot
.12652 .50888 Mdot
.32062 .5353 Mdot
.35298 .54435 Mdot
.3586 .45947 Mdot
.4802 .82688 Mdot
.31154 .64788 Mdot
.25808 .29932 Mdot
.45001 .78997 Mdot
.34312 .4467 Mdot
.74551 .72817 Mdot
.30198 .74223 Mdot
.75298 .40983 Mdot
.58917 .4314 Mdot
.60043 .55061 Mdot
.75655 .35365 Mdot
.54558 .30226 Mdot
.2956 .44295 Mdot
.61001 .70331 Mdot
.37155 .58301 Mdot
.45489 .65123 Mdot
.46049 .2245 Mdot
.63424 .44878 Mdot
.53455 .42006 Mdot
.50848 .29733 Mdot
.23618 .45294 Mdot
.37656 .35604 Mdot
.21489 .66404 Mdot
.29412 .66994 Mdot
.59356 .5555 Mdot
.60188 .65452 Mdot
.32094 .67565 Mdot
.49078 .80776 Mdot
.41466 .4459 Mdot
.1532 .48877 Mdot
.51605 .55403 Mdot
.62455 .69695 Mdot
.77234 .38419 Mdot
.55608 .24221 Mdot
.65337 .44338 Mdot
.27646 .37322 Mdot
.68609 .35068 Mdot
.49867 .5841 Mdot
.47295 .31504 Mdot
.46197 .34208 Mdot
.29349 .23668 Mdot
.35757 .73605 Mdot
.29049 .47822 Mdot
.15965 .47437 Mdot
.37993 .41811 Mdot
.54979 .34844 Mdot
.468 .63786 Mdot
.53228 .22043 Mdot
.69623 .33106 Mdot
.56582 .78864 Mdot
.28043 .59365 Mdot
.40146 .69979 Mdot
.16513 .47723 Mdot
.15796 .50342 Mdot
.83215 .52333 Mdot
.56171 .36043 Mdot
.56897 .27117 Mdot
.57924 .21004 Mdot
.53797 .30091 Mdot
.51185 .24638 Mdot
.44861 .31237 Mdot
.21902 .65736 Mdot
.34254 .4568 Mdot
.51437 .16873 Mdot
.66398 .62926 Mdot
.24673 .58867 Mdot
.6174 .78933 Mdot
.74264 .28782 Mdot
.16681 .46173 Mdot
.74686 .55309 Mdot
.74492 .43075 Mdot
.58701 .45418 Mdot
.55109 .44992 Mdot
.61617 .84228 Mdot
.47874 .62442 Mdot
.72971 .33279 Mdot
.27929 .32733 Mdot
.62928 .49949 Mdot
.52601 .84882 Mdot
.50796 .22214 Mdot
.53856 .82197 Mdot
.34541 .44292 Mdot
.60307 .51079 Mdot
.58961 .51305 Mdot
.56742 .67277 Mdot
.33154 .34139 Mdot
.25001 .67046 Mdot
.73419 .27051 Mdot
.25304 .36353 Mdot
.79144 .4274 Mdot
.27398 .67384 Mdot
.25426 .31377 Mdot
.43721 .21179 Mdot
.49281 .50411 Mdot
.30546 .68893 Mdot
.67907 .66605 Mdot
.42022 .17266 Mdot
.54365 .60825 Mdot
.44075 .42725 Mdot
.45673 .28681 Mdot
.29996 .33952 Mdot
.63984 .76428 Mdot
.60829 .47647 Mdot
.48781 .79505 Mdot
.22091 .35183 Mdot
.82388 .48502 Mdot
.73973 .71052 Mdot
.50537 .84647 Mdot
.71347 .37655 Mdot
.30149 .32643 Mdot
.43839 .2175 Mdot
.82507 .37766 Mdot
.52375 .55847 Mdot
.19441 .54002 Mdot
.68639 .66724 Mdot
.16269 .47531 Mdot
.37388 .39118 Mdot
.43415 .26582 Mdot
.23589 .54378 Mdot
.20408 .62276 Mdot
.62563 .38775 Mdot
.184 .40586 Mdot
.43746 .51678 Mdot
.28737 .75435 Mdot
.27129 .41491 Mdot
.44968 .47543 Mdot
.34698 .58861 Mdot
.41843 .76056 Mdot
.1844 .46101 Mdot
.22112 .45628 Mdot
.7403 .28994 Mdot
.3445 .62164 Mdot
.46539 .65299 Mdot
.77238 .4236 Mdot
.67178 .70408 Mdot
.28443 .34876 Mdot
.60238 .6546 Mdot
.17557 .40529 Mdot
.55841 .69281 Mdot
.50312 .78431 Mdot
.27295 .66404 Mdot
.61592 .17714 Mdot
.34763 .33753 Mdot
.37893 .75488 Mdot
.49411 .22289 Mdot
.42815 .67428 Mdot
.70919 .59218 Mdot
.11252 .63558 Mdot
.60573 .18776 Mdot
.25504 .42679 Mdot
.22891 .67209 Mdot
.35031 .23817 Mdot
.23701 .45732 Mdot
.77045 .66197 Mdot
.56094 .58655 Mdot
.55828 .76574 Mdot
.66206 .51457 Mdot
.40959 .8379 Mdot
.64748 .70785 Mdot
.24646 .69814 Mdot
.28448 .25431 Mdot
.75843 .36169 Mdot
.64446 .45105 Mdot
.40422 .60489 Mdot
.3208 .41052 Mdot
.64581 .73053 Mdot
.69285 .41817 Mdot
.63508 .60432 Mdot
.28319 .60857 Mdot
.35424 .56039 Mdot
.33653 .68914 Mdot
.55326 .2874 Mdot
.29073 .63454 Mdot
.29436 .35254 Mdot
.35422 .64756 Mdot
.48344 .53652 Mdot
.59037 .67512 Mdot
.55012 .55101 Mdot
.75078 .4049 Mdot
.75137 .67166 Mdot
.51425 .44781 Mdot
.3864 .56309 Mdot
.72867 .40368 Mdot
.54202 .1823 Mdot
.25578 .37392 Mdot
.27074 .71543 Mdot
.4574 .77718 Mdot
.75474 .45073 Mdot
.5801 .67683 Mdot
.78575 .63716 Mdot
.79395 .5154 Mdot
.21725 .4947 Mdot
.54702 .4851 Mdot
.78286 .52119 Mdot
.42179 .23793 Mdot
.18185 .60944 Mdot
.66684 .22478 Mdot
.60814 .20647 Mdot
.43992 .62418 Mdot
.68526 .29571 Mdot
.77161 .39675 Mdot
.66383 .6498 Mdot
.475 .56451 Mdot
.8108 .67855 Mdot
.46999 .34823 Mdot
.66203 .83633 Mdot
.41189 .42969 Mdot
.66015 .79748 Mdot
.69288 .65422 Mdot
.47294 .46042 Mdot
.46471 .5694 Mdot
.28051 .37354 Mdot
.41338 .28123 Mdot
.46411 .18364 Mdot
.8097 .55121 Mdot
.40893 .56142 Mdot
.73666 .26867 Mdot
.62726 .17595 Mdot
.71035 .40913 Mdot
.70771 .49452 Mdot
.59986 .18393 Mdot
.33662 .5847 Mdot
.7117 .70704 Mdot
.33528 .23673 Mdot
.22357 .43352 Mdot
.7454 .49534 Mdot
.60231 .6912 Mdot
.19174 .53119 Mdot
.14442 .47823 Mdot
.76211 .70017 Mdot
.19101 .46514 Mdot
.36834 .39319 Mdot
.43728 .48019 Mdot
.18987 .41061 Mdot
.62408 .61523 Mdot
.34865 .29149 Mdot
.60452 .60321 Mdot
.7468 .76927 Mdot
.22769 .62397 Mdot
.24871 .6683 Mdot
.60296 .6082 Mdot
.51188 .3819 Mdot
.31747 .36996 Mdot
.59378 .59488 Mdot
.23392 .42323 Mdot
.51573 .19772 Mdot
.58776 .59433 Mdot
.84739 .45938 Mdot
.57881 .24124 Mdot
.32854 .56256 Mdot
.77917 .41736 Mdot
.58729 .25451 Mdot
.34306 .43963 Mdot
.52195 .76142 Mdot
.27105 .33403 Mdot
.35359 .40446 Mdot
.28105 .35419 Mdot
.32182 .32211 Mdot
.59735 .23414 Mdot
.70801 .34012 Mdot
.23874 .38522 Mdot
.66758 .40528 Mdot
.4959 .40204 Mdot
.63956 .75579 Mdot
.38051 .63625 Mdot
.27222 .32275 Mdot
.3494 .59587 Mdot
.55494 .52134 Mdot
.5036 .58005 Mdot
.75713 .49479 Mdot
.50797 .83498 Mdot
.48327 .66502 Mdot
.48721 .32559 Mdot
.67792 .79356 Mdot
.53603 .30334 Mdot
.43184 .83641 Mdot
.76835 .64665 Mdot
.77293 .38279 Mdot
.37359 .67876 Mdot
.37017 .70651 Mdot
.85223 .55979 Mdot
.51241 .41453 Mdot
.43111 .62074 Mdot
.47644 .39896 Mdot
.48357 .33803 Mdot
.27956 .66138 Mdot
.38825 .55215 Mdot
.54278 .57384 Mdot
.40497 .48679 Mdot
.45203 .35682 Mdot
.56892 .34743 Mdot
.51079 .56164 Mdot
.57214 .74632 Mdot
.21468 .64789 Mdot
.39698 .57794 Mdot
.71432 .78401 Mdot
.65953 .4474 Mdot
.67078 .38368 Mdot
.22279 .33105 Mdot
.75738 .71372 Mdot
.41643 .5525 Mdot
.63848 .17539 Mdot
.66201 .5565 Mdot
.22304 .40308 Mdot
.51402 .33096 Mdot
.6268 .2097 Mdot
.49226 .66207 Mdot
.61372 .65502 Mdot
.36988 .46196 Mdot
.66811 .75181 Mdot
.29092 .59485 Mdot
.53227 .38572 Mdot
.20544 .46155 Mdot
.57228 .26824 Mdot
.39625 .2714 Mdot
.35511 .70141 Mdot
.72141 .41268 Mdot
.70213 .33058 Mdot
.56801 .35529 Mdot
.23361 .65275 Mdot
.63307 .20877 Mdot
.17188 .6153 Mdot
.69328 .57531 Mdot
.45247 .75679 Mdot
.46543 .28111 Mdot
.26507 .37497 Mdot
.5426 .47949 Mdot
.2053 .35495 Mdot
.6182 .70817 Mdot
.45759 .31234 Mdot
.58686 .70379 Mdot
.56257 .51728 Mdot
.48201 .51234 Mdot
.30703 .46395 Mdot
.82078 .56534 Mdot
.53491 .48778 Mdot
.69352 .76261 Mdot
.54509 .49536 Mdot
.28365 .69349 Mdot
.56521 .29776 Mdot
.3773 .53547 Mdot
.69813 .30534 Mdot
.34396 .38443 Mdot
.17822 .596 Mdot
.21099 .34741 Mdot
.40728 .45666 Mdot
.2746 .64253 Mdot
.33009 .26145 Mdot
.5945 .56112 Mdot
.41424 .49535 Mdot
.67821 .53912 Mdot
.54115 .26445 Mdot
.76152 .71613 Mdot
.24798 .4025 Mdot
.70029 .45856 Mdot
.18423 .57802 Mdot
.16508 .55816 Mdot
.27398 .73632 Mdot
.79112 .35216 Mdot
.51796 .37848 Mdot
.3709 .80512 Mdot
.64461 .60343 Mdot
.14292 .45177 Mdot
.21733 .48492 Mdot
.27933 .24842 Mdot
.73063 .42286 Mdot
.29374 .31351 Mdot
.79231 .57688 Mdot
.3793 .29574 Mdot
.39998 .21142 Mdot
.4528 .44653 Mdot
.28098 .47792 Mdot
.37598 .21699 Mdot
.86032 .41584 Mdot
.55718 .45969 Mdot
.32605 .31209 Mdot
.44653 .24101 Mdot
.26683 .33029 Mdot
.44779 .70639 Mdot
.63578 .46105 Mdot
.24814 .50839 Mdot
.58197 .79803 Mdot
.58873 .65981 Mdot
.46869 .649 Mdot
.44554 .70257 Mdot
.60625 .75426 Mdot
.58438 .72292 Mdot
.66961 .22493 Mdot
.73363 .42042 Mdot
.53605 .54597 Mdot
.70994 .51073 Mdot
.57362 .32477 Mdot
.53726 .68541 Mdot
.33377 .54296 Mdot
.67126 .53999 Mdot
.35907 .54334 Mdot
.39547 .27817 Mdot
.48649 .84509 Mdot
.32197 .3839 Mdot
.5021 .21403 Mdot
.47428 .32584 Mdot
.31079 .35057 Mdot
.55816 .40262 Mdot
.59149 .81167 Mdot
.44422 .73506 Mdot
.57831 .6417 Mdot
.17762 .54114 Mdot
.37682 .77187 Mdot
.56249 .23435 Mdot
.37887 .78617 Mdot
.37161 .39534 Mdot
.73839 .51063 Mdot
.4566 .25344 Mdot
.33275 .69612 Mdot
.48954 .29253 Mdot
.29113 .31851 Mdot
.42461 .62712 Mdot
.3744 .75799 Mdot
.42872 .20128 Mdot
.56493 .25468 Mdot
.77306 .43845 Mdot
.15885 .5142 Mdot
.40522 .59193 Mdot
.60828 .19916 Mdot
.35118 .28322 Mdot
.43965 .74467 Mdot
.27493 .69633 Mdot
.20207 .64561 Mdot
.45416 .54117 Mdot
.65299 .67812 Mdot
.61603 .48912 Mdot
.7095 .27056 Mdot
.25872 .39498 Mdot
.64611 .42339 Mdot
.30892 .53571 Mdot
.5417 .32252 Mdot
.32013 .49579 Mdot
.52224 .53385 Mdot
.57812 .76043 Mdot
.55476 .3112 Mdot
.79915 .4344 Mdot
.534 .66679 Mdot
.43664 .53633 Mdot
.67743 .46564 Mdot
.64138 .66928 Mdot
.8097 .41268 Mdot
.71912 .54457 Mdot
.19917 .43401 Mdot
.73478 .41412 Mdot
.54357 .22126 Mdot
.23369 .40313 Mdot
.21837 .50164 Mdot
.40692 .28606 Mdot
.7163 .32742 Mdot
.30694 .56297 Mdot
.69561 .51878 Mdot
.3843 .53536 Mdot
.55091 .32883 Mdot
.30646 .26496 Mdot
.70707 .36835 Mdot
.65832 .65806 Mdot
.48606 .453 Mdot
.57109 .40624 Mdot
.49 .43357 Mdot
.25715 .2845 Mdot
.37959 .29692 Mdot
.60939 .70655 Mdot
.33074 .4428 Mdot
.68931 .65488 Mdot
.75941 .66791 Mdot
.14507 .53633 Mdot
.78578 .62355 Mdot
.46136 .51917 Mdot
.70431 .75617 Mdot
.28046 .40009 Mdot
.3405 .23379 Mdot
.59915 .71776 Mdot
.45285 .55927 Mdot
.49421 .63856 Mdot
.43177 .3654 Mdot
.50467 .47296 Mdot
.50221 .62818 Mdot
.55041 .57063 Mdot
.28657 .54519 Mdot
.34508 .48158 Mdot
.57209 .46415 Mdot
.24245 .63795 Mdot
.16923 .52849 Mdot
.637 .21606 Mdot
.50882 .42961 Mdot
.47911 .73635 Mdot
.60122 .74748 Mdot
.35102 .17774 Mdot
.56805 .85927 Mdot
.61719 .4901 Mdot
.51579 .43174 Mdot
.63404 .68156 Mdot
.41382 .57131 Mdot
.57403 .5749 Mdot
.55089 .40892 Mdot
.40417 .44577 Mdot
.47456 .63189 Mdot
.39471 .77017 Mdot
.28429 .37362 Mdot
.68884 .69101 Mdot
.24603 .55023 Mdot
.48444 .84831 Mdot
.51574 .1857 Mdot
.26002 .38461 Mdot
.29538 .21651 Mdot
.32987 .46977 Mdot
.46203 .36564 Mdot
.60023 .40249 Mdot
.22145 .65283 Mdot
.60312 .64675 Mdot
.61446 .77405 Mdot
.22396 .52543 Mdot
.61026 .71322 Mdot
.68148 .60235 Mdot
.27466 .67037 Mdot
.32009 .50658 Mdot
.46678 .48562 Mdot
.37263 .70862 Mdot
.33643 .7625 Mdot
.78889 .45015 Mdot
.1803 .52542 Mdot
.59339 .79861 Mdot
.84514 .41861 Mdot
.16748 .57284 Mdot
.45949 .64424 Mdot
.46212 .72664 Mdot
.60773 .40067 Mdot
.64666 .6236 Mdot
.72986 .5762 Mdot
.70343 .71637 Mdot
.68404 .32277 Mdot
.3358 .66477 Mdot
.65251 .78523 Mdot
.58369 .68335 Mdot
.58939 .2502 Mdot
.45399 .55979 Mdot
.74251 .40198 Mdot
.28346 .64984 Mdot
.58873 .60923 Mdot
.52795 .60393 Mdot
.63926 .63617 Mdot
.72381 .40568 Mdot
.52166 .23724 Mdot
.32919 .27879 Mdot
.86114 .4742 Mdot
.21147 .52447 Mdot
.60351 .8094 Mdot
.62165 .45364 Mdot
.18822 .64578 Mdot
.33233 .28473 Mdot
.22014 .5283 Mdot
.47352 .19755 Mdot
.34278 .5425 Mdot
.4582 .31982 Mdot
.69575 .51779 Mdot
.19277 .48826 Mdot
.73576 .34071 Mdot
.59228 .27542 Mdot
.65304 .76645 Mdot
.60553 .66796 Mdot
.50242 .76614 Mdot
.66936 .64118 Mdot
.72615 .54367 Mdot
.5192 .30126 Mdot
.3824 .81837 Mdot
.44697 .51619 Mdot
.5513 .49938 Mdot
.68637 .43442 Mdot
.78982 .58315 Mdot
.54949 .16509 Mdot
.7135 .56358 Mdot
.35377 .75765 Mdot
.79491 .47498 Mdot
.76005 .51508 Mdot
.56668 .55484 Mdot
.41655 .10748 Mdot
.10972 .48888 Mdot
.54241 .37982 Mdot
.74074 .30286 Mdot
.79829 .47462 Mdot
.21681 .64064 Mdot
.40764 .72799 Mdot
.32362 .54608 Mdot
.77651 .56949 Mdot
.67749 .61438 Mdot
.70679 .47884 Mdot
.44588 .19859 Mdot
.14055 .52056 Mdot
.65553 .77021 Mdot
.18101 .57318 Mdot
.61174 .43524 Mdot
.72123 .49554 Mdot
.40565 .13983 Mdot
.18508 .42273 Mdot
.62234 .57048 Mdot
.79648 .5775 Mdot
.46624 .3298 Mdot
.64279 .529 Mdot
.22998 .58449 Mdot
.72941 .26534 Mdot
.58123 .68342 Mdot
.20484 .62395 Mdot
.55996 .33626 Mdot
.43324 .60336 Mdot
.40882 .44333 Mdot
.46821 .5678 Mdot
.68385 .55125 Mdot
.39577 .4139 Mdot
.76434 .50334 Mdot
.29296 .30677 Mdot
.36355 .47144 Mdot
.67351 .21912 Mdot
.20197 .33377 Mdot
.72428 .37677 Mdot
.41777 .36627 Mdot
.59775 .56581 Mdot
.58132 .24945 Mdot
.63529 .73888 Mdot
.51338 .26826 Mdot
.36203 .22096 Mdot
.17794 .69424 Mdot
.28212 .49183 Mdot
.54642 .7562 Mdot
.52578 .27974 Mdot
.53492 .53561 Mdot
.75924 .39956 Mdot
.41468 .51886 Mdot
.39719 .59868 Mdot
.57878 .48797 Mdot
.71818 .55248 Mdot
.34896 .44345 Mdot
.65443 .83519 Mdot
.63372 .46463 Mdot
.55538 .55029 Mdot
.14439 .45291 Mdot
.63841 .75678 Mdot
.65157 .38112 Mdot
.62635 .56261 Mdot
.40055 .33978 Mdot
.45221 .55909 Mdot
.24939 .33646 Mdot
.49977 .78485 Mdot
.19571 .58628 Mdot
.70397 .36536 Mdot
.78045 .44822 Mdot
.67625 .47495 Mdot
.49087 .65064 Mdot
.33811 .31202 Mdot
.21969 .56762 Mdot
.62953 .43276 Mdot
.13669 .47828 Mdot
.33673 .54706 Mdot
.2812 .57438 Mdot
.72793 .55823 Mdot
.29155 .75102 Mdot
.7021 .74582 Mdot
.75843 .37484 Mdot
.57257 .82049 Mdot
.34461 .71519 Mdot
.66998 .70394 Mdot
.40241 .60515 Mdot
.61302 .43772 Mdot
.5598 .34819 Mdot
.48958 .85442 Mdot
.21817 .57839 Mdot
.26233 .47665 Mdot
.30432 .49956 Mdot
.68984 .26624 Mdot
.39349 .26245 Mdot
.26347 .25225 Mdot
.35698 .71426 Mdot
.49681 .8502 Mdot
.60783 .20427 Mdot
.51952 .27575 Mdot
.29199 .33184 Mdot
.73329 .51776 Mdot
.38785 .56885 Mdot
.2052 .60159 Mdot
.68478 .57405 Mdot
.53981 .80155 Mdot
.61387 .54881 Mdot
.51883 .82401 Mdot
.51487 .62152 Mdot
.26062 .63566 Mdot
.27113 .42423 Mdot
.76438 .6678 Mdot
.28763 .27403 Mdot
.43593 .36112 Mdot
.31499 .21282 Mdot
.28658 .28456 Mdot
.15162 .49168 Mdot
.57578 .78861 Mdot
.79415 .6573 Mdot
.22258 .45989 Mdot
.24165 .38401 Mdot
.28916 .40784 Mdot
.67277 .41869 Mdot
.41533 .75786 Mdot
.71497 .56691 Mdot
.3483 .3193 Mdot
.42284 .44275 Mdot
.36376 .87757 Mdot
.53495 .64479 Mdot
.5034 .38999 Mdot
.38194 .74219 Mdot
.15558 .52893 Mdot
.72253 .44417 Mdot
.39469 .20458 Mdot
.51786 .53521 Mdot
.7077 .46905 Mdot
.70213 .34402 Mdot
.6682 .23626 Mdot
.43219 .76746 Mdot
.85925 .575 Mdot
.51828 .1892 Mdot
.29673 .52561 Mdot
.48798 .52389 Mdot
.54074 .30128 Mdot
.56786 .3775 Mdot
.37725 .69367 Mdot
.393 .19455 Mdot
.29338 .31123 Mdot
.18896 .41242 Mdot
.85115 .55329 Mdot
.56757 .21373 Mdot
.21928 .65167 Mdot
.26983 .40205 Mdot
.50894 .38752 Mdot
.45609 .65694 Mdot
.32975 .62163 Mdot
.2613 .46456 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Vooooo`;o0000XOoo
ool001cooooo00?o0000ooooooooool0Y_ooool2o`000:7ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0Q?ooool2o`000<?ooooo000Looooo`03o`000?oooooo
oooo08Cooooo0_l00033ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0;Gooooo0_l0002Booooo`007?ooool00ol0003oooooooooo`2eooooo`;o0000
T_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2M
ooooo`;o0000Z_ooool001cooooo00?o0000ooooooooool0WOooool2o`0000gooooo0_l00007oooo
o`;o0000T_ooool001cooooo00?o0000ooooooooool0U_ooool2o`0001Cooooo0_l00007ooooo`;o
0000T_ooool001cooooo00?o0000ooooooooool0U_ooool2o`000;7ooooo000Looooo`03o`000?oo
oooooooo093ooooo0_l0002gooooo`007?ooool00ol0003oooooooooo`20ooooo`;o00003_ooool2
o`000;Oooooo000Looooo`03o`000?oooooooooo083ooooo0_l00037ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0
003ooooood_ooooo000Looooo`03o`000?oooooooooo0<?ooooo0_l00024ooooo`007?ooool00ol0
003oooooooooo`33ooooo`;o0000Q?ooool001cooooo00?o0000ooooooooool0P_ooool2o`0001Co
oooo0_l0000aooooo`;o0000O?ooool001cooooo00?o0000ooooooooool0Ooooool2o`000003oooo
ool0003o000001Cooooo0_l0000Eooooo`;o00006_ooool3o`0007_ooooo000Looooo`03o`000?oo
oooooooo07oooooo0_l0000Rooooo`;o000000?oooooo`000?l000001oooool2o`0000Oooooo0_l0
000Booooo`;o0000Noooool001cooooo00?o0000ooooooooool0OOooool2o`0000Kooooo0_l0000L
ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Sooooo0ol00007ooooo`;o0000Q_ooool0
01cooooo00?o0000ooooooooool0OOooool2o`0000Kooooo0_l00008ooooo`;o00000oooool5o`00
00oooooo2ol00004ooooo`;o00002?ooool2o`0000Wooooo0_l0001kooooo`007?ooool00ol0003o
ooooooooo`1^ooooo`;o00005Oooool2o`0000Sooooo0_l00003ooooo`Go00003oooool5o`0000;o
oooo1?l0000Aooooo`;o00000_ooool2o`0000;ooooo0_l0001kooooo`007?ooool00ol0003ooooo
ooooo`1^ooooo`;o00007Oooool2o`0003Gooooo0_l00002ooooo`;o00000_ooool2o`0007_ooooo
000Looooo`03o`000?oooooooooo08gooooo2?l00008ooooo`;o00002oooool4o`000003ooooool0
003o000000Kooooo0_l00006ooooo`;o00002oooool2o`0007_ooooo000Looooo`03o`000?oooooo
oooo08_ooooo0ol000000ooooooo0000o`000004o`0000Sooooo0_l00005ooooo`;o00001?ooool4
o`000003ooooool0003o000000Kooooo0_l000000ooooooo0000o`000003ooooo`;o0000R?ooool0
01cooooo00?o0000ooooooooool0MOooool2o`000003ooooool0003o0000017ooooo0ol000000ooo
oooo0000o`00000Cooooo`?o00004oooool3o`0000Cooooo0_l00026ooooo`0000Koooooonk^k_lb
<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0MOooool2
o`000003ooooool0003o000002[ooooo0ol00007ooooo`;o00002oooool2o`0000Cooooo0_l00002
ooooo`;o00001_ooool2o`0007[ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ
8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1`ooooo`;o0000
2_ooool4o`0002Cooooo0_l00008ooooo`;o00005Oooool2o`0000;ooooo0_l00002ooooo`;o0000
N_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^
kP07ooooo`03o`000?oooooooooo073ooooo0_l00005ooooo`?o00000_ooool6o`0000Sooooo0_l0
00000ooooooo0000o`000007ooooo`;o00003?ooool2o`0000oooooo0_l00003ooooo`;o000000Co
ooooo`000?l0003ooooo1?l00005ooooo`;o00003oooool2o`0006gooooo00000ooooooo0000oooo
o`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0007Cooooo0_l0
00001?oooooo0000o`000?l00005ooooo`?o00001_ooool4o`000003ooooool0003o000000Oooooo
0_l0000<ooooo`;o00003oooool3o`0000;ooooo1Ol000000ooooooo0000o`000002o`0000cooooo
0_l00003ooooo`;o00000oooool2o`0006gooooo00000ooooooo0000ooooo`02ooooo`03o`000?oo
oooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`1dooooo`Co00001?oo
ool2o`0000Gooooo0_l00003ooooo`Co00004oooool4o`0000[ooooo0_l00007ooooo`;o00001?oo
ool2o`0000Cooooo0_l00003ooooo`;o00001oooool2o`0000?ooooo0_l0001booooo`0000?ooooo
oa0@4?ooool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0M_ooool2o`0000Cooooo0_l00005ooooo`;o00006_ooool6o`0000Sooooo0_l0000C
ooooo`?o00000_ooool2o`000003ooooool0003o0000013ooooo0_l00005ooooo`;o0000I?ooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo
00?o0000ooooooooool0M?ooool2o`000003ooooool0003o000000?ooooo1?l0000:ooooo`;o0000
00Coooooo`000?l0003o00002_ooool2o`0000Oooooo0_l0000Cooooo`?o00000_ooool2o`0000?o
oooo0ol00003ooooo`Co00004?ooool2o`0000Gooooo0_l0001Tooooo`0000Koooooonk^k_lb<S;o
0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1S
ooooo`;o00003oooool5o`0000Gooooo0_l0000:ooooo`;o000000Coooooo`000?l0003o00002_oo
ool2o`0000?ooooo1?l0000Booooo`;o000000Coooooo`000?l0003o00000_ooool2o`0000Wooooo
0_l0000Cooooo`;o0000J_ooool001cooooo00?o0000ooooooooool0G?ooool2o`0000Gooooo0_l0
000<ooooo`;o00000_ooool3o`0000cooooo0_l00005ooooo`;o00001_ooool2o`0000[ooooo1?l0
0003ooooo`;o00003Oooool4o`0001;ooooo0_l0000>ooooo`Co0000J_ooool001cooooo00?o0000
ooooooooool0G?ooool2o`0001?ooooo0ol00002ooooo`;o00003?ooool2o`0000Gooooo0_l00006
ooooo`;o00004Oooool2o`000003ooooool0003o000000Go00001_ooool3o`0001;ooooo0_l00004
ooooo`;o00001?ooool2o`0000;ooooo0_l0001/ooooo`007?ooool00ol0003oooooooooo`1boooo
o`;o000000?oooooo`000?l000003?ooool2o`0000Wooooo0_l00002ooooo`;o000000?oooooo`00
0?l000001_ooool2o`0000;ooooo0_l00006ooooo`Oo000000?oooooo`000?l000007?ooool4o`00
00Cooooo0_l0001`ooooo`007?ooool00ol0003oooooooooo`1eooooo`;o00003?ooool2o`0000Wo
oooo0_l000001Ooooooo0000o`000?l0003ooooo00?o00001Oooool2o`0000;ooooo0_l00005oooo
o`;o00001?ooool2o`000003ooooool0003o000001cooooo0ol00003ooooo`Co0000L?ooool001co
oooo00?o0000ooooooooool0MOooool2o`0001[ooooo0_l00003ooooo`;o00002Oooool2o`0000Go
oooo0_l00004ooooo`;o00008?ooool2o`0000?ooooo1?l0001`ooooo`007?ooool00ol0003ooooo
ooooo`1Vooooo`;o00000oooool2o`0000?ooooo0_l00003ooooo`;o00003?ooool2o`00027ooooo
0_l0000:ooooo`;o0000UOooool001cooooo00?o0000ooooooooool0G?ooool2o`0000Gooooo0_l0
00001?oooooo0000o`000?ooool6o`000003ooooool0003o0000017ooooo0_l0000Oooooo`Co0000
2_ooool3o`0000Wooooo0_l0000Cooooo`Co0000L_ooool001cooooo00?o0000ooooooooool0G?oo
ool2o`0000Gooooo0_l00003ooooo`So00005Oooool2o`0000gooooo0_l00002ooooo`;o00001_oo
ool3o`000003ooooool0003o000000;o00002oooool2o`0000Wooooo0_l0000Cooooo`Co0000L_oo
ool001cooooo00?o0000ooooooooool0H_ooool4o`0000;ooooo1Ol000000ooooooo0000o`000002
o`0001?ooooo0_l00006ooooo`;o00001?ooool3o`0000;ooooo1?l00004ooooo`?o000000?ooooo
o`000?l000000_l00007ooooo`Co00001Oooool3o`0000?ooooo1?l0000=ooooo`;o0000N?ooool0
01cooooo00?o0000ooooooooool0H_ooool4o`000003ooooool0003o000000;o00000_ooool5o`00
00Cooooo0_l000000ooooooo0000o`00000Booooo`;o00001?ooool2o`0000;ooooo1Ol00008oooo
o`;o00002Oooool4o`000003ooooool0003o000000;ooooo0ol00003ooooo`Co00000oooool2o`00
00Sooooo0_l0000Hooooo`;o0000G_ooool001cooooo00?o0000ooooooooool0Eoooool2o`0000Wo
oooo0_l00003ooooo`;o00001?ooool3o`0000Kooooo0_l000000ooooooo0000o`00000Looooo`Co
00002?ooool5o`0000Oooooo0_l00003ooooo`;o00002_ooool2o`0000?ooooo0_l0000Rooooo`;o
0000G_ooool001cooooo0_l0001Cooooo`;o00000oooool3o`0000Cooooo0_l00003ooooo`;o0000
1_ooool2o`0000Sooooo0_l0000/ooooo`Go00001oooool2o`0000Sooooo0_l000000ooooooo0000
o`000004o`0000kooooo0_l00004ooooo`?o0000L?ooool001cooooo00?o0000ooooooooool0D_oo
ool2o`0000Cooooo0ol00003ooooo`;o00000oooool2o`0000Gooooo0ol000000ooooooo0000o`00
0004ooooo`Go00000oooool2o`0000Cooooo0_l00006ooooo`;o00001Oooool2o`0000gooooo0_l0
00000ooooooo0000o`00000?ooooo`;o00000oooool9o`0000kooooo0_l00004ooooo`?o0000L?oo
ool001cooooo00?o0000ooooooooool0Eoooool4o`0000oooooo0_l00002ooooo`;o00000_ooool7
o`0000?ooooo1?l00002ooooo`;o00000_ooool3o`000003ooooool0003o000000Gooooo0_l0000=
ooooo`;o00002oooool5o`0000;ooooo0_l00005ooooo`;o00000_ooool4o`0008Kooooo000Loooo
o`03o`000?oooooooooo05Oooooo0_l00008ooooo`;o00001?ooool2o`0000Gooooo0_l00002oooo
o`;o000000?oooooo`000?l000001oooool2o`000003ooooool0003o000000Ko00009?ooool5o`00
00oooooo0_l0000Xooooo`;o0000G?ooool001cooooo00?o0000ooooooooool0HOooool2o`0000Co
oooo0_l0000Cooooo`;o00000oooool2o`000003ooooool0003o000000?ooooo0_l0000Qooooo`;o
00002Oooool2o`0002?ooooo0_l0000=ooooo`;o0000G?ooool001cooooo00?o0000ooooooooool0
EOooool2o`0000Wooooo0_l00006ooooo`;o00000_ooool2o`000003ooooool0003o000000?ooooo
0_l00006ooooo`;o00002Oooool4o`0000oooooo1?l0000>ooooo`;o00002Oooool2o`00023ooooo
0_l000000ooooooo0000o`000008ooooo`;o000000?oooooo`000?l00000G_ooool001cooooo00?o
0000ooooooooool0EOooool2o`000003ooooool0003o000000Kooooo0_l00005ooooo`?o00000_oo
ool2o`000003ooooool0003o000000?ooooo0_l0000>ooooo`;o000000?oooooo`000?l000000_l0
000?ooooo`Co00001Oooool5o`0000kooooo0_l00005ooooo`;o00000oooool2o`0001Gooooo0_l0
00000ooooooo0000o`000005ooooo`;o000000Coooooo`000?l0003ooooo1Ol00003ooooo`;o0000
E_ooool001cooooo00?o0000ooooooooool0F?ooool2o`0000;ooooo0_l00002ooooo`;o00001Ooo
ool2o`0000;ooooo0_l0000:ooooo`;o00001?ooool2o`0000Gooooo0_l0000;ooooo`;o00004?oo
ool5o`0000gooooo0ol00005ooooo`;o00000oooool2o`0001oooooo0_l00002ooooo`;o00000_oo
ool3o`0000?ooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o00001?ooool4
o`0000[ooooo0_l000001?oooooo0000o`000?ooool3o`0000Kooooo0_l00004ooooo`;o00001Ooo
ool2o`0000Gooooo0_l00004ooooo`;o00004_ooool3o`000003ooooool0003o000000?ooooo0_l0
0005ooooo`;o00001_ooool2o`0001kooooo0_l00008ooooo`;o0000H?ooool001cooooo00?o0000
ooooooooool0Doooool3o`0000Cooooo0_l0000;ooooo`?o000000Coooooo`000?l0003ooooo0ol0
000<ooooo`;o00003?ooool2o`0000Cooooo0_l0000Aooooo`Oo00000oooool2o`0000;ooooo1?l0
0007ooooo`;o00007_ooool2o`0000_ooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1B
ooooo`?o00004_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00002Oooool2
o`0000;ooooo1Ol0000=ooooo`;o00003oooool5o`0000Wooooo1?l0000^ooooo`;o00001?ooool4
o`0005_ooooo000Looooo`03o`000?oooooooooo04[ooooo0_l00004ooooo`Co00001Oooool2o`00
00[ooooo0_l000000ooooooo0000o`000004ooooo`;o00000_ooool2o`0000_ooooo1ol0000=oooo
o`;o00001_ooool2o`0004;ooooo0_l00003ooooo`;o00001?ooool4o`0005_ooooo000Looooo`03
o`000?oooooooooo04[ooooo0_l00004ooooo`;o00001oooool2o`0000Oooooo0_l000001?oooooo
0000o`000?ooool2o`0000Gooooo0_l00002ooooo`?o00002Oooool3o`0000cooooo0_l000000ooo
oooo0000o`000005ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000002
ooooo`;o000000?oooooo`000?l000000oooool2o`000003ooooool0003o000000;ooooo0_l0000=
ooooo`;o00006_ooool2o`0000Kooooo0_l00003ooooo`Co0000FOooool001cooooo00?o0000oooo
ooooool0FOooool2o`0000Oooooo0_l00003ooooo`;o00001Oooool3o`0000;ooooo0ol00002oooo
o`;o00002?ooool2o`0000[ooooo0_l000000ooooooo0000o`000005ooooo`;o00001?ooool2o`00
0003ooooool0003o000000Co000000?oooooo`000?l000000_ooool6o`0000;ooooo0_l00002oooo
o`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00007_ooool2o`0000;ooooo0_l00004
ooooo`?o0000FOooool001cooooo00?o0000ooooooooool0Coooool2o`0000Sooooo0_l0000<oooo
o`Co00000oooool2o`0000Sooooo0_l00008ooooo`;o00003Oooool2o`0000Sooooo0_l00003oooo
oa3o00002?ooool2o`000003ooooool0003o000000?o00008?ooool2o`000005ooooool0003o0000
o`000?ooool00_l000001?oooooo0000o`000?ooool2o`0005[ooooo000Looooo`03o`000?oooooo
oooo04oooooo1?l0000=ooooo`;o00001oooool2o`0000cooooo1ol0000Cooooo`;o00002?ooool2
o`0000?ooooo4?l00002ooooo`Co00001_ooool5o`0001[ooooo0_l000000ooooooo0000o`000002
o`0000;ooooo0_l00004ooooo`;o00001Oooool2o`000003ooooool0003o000005?ooooo000Loooo
o`;o0000DOooool3o`0000gooooo0_l0000Eooooo`Oo00002_ooool2o`0001?ooooo4ol00002oooo
o`Co00002Oooool2o`0000Cooooo0_l0000Dooooo`;o000000?oooooo`000?l000002?ooool4o`00
00Gooooo0_l000000ooooooo0000o`00001Cooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o
000000?oooooo`000?l000001_ooool2o`0000Oooooo0_l00005ooooo`;o00007_ooool2o`00017o
oooo5_l00003ooooo`;o00003oooool2o`00027ooooo1?l000000ooooooo0000o`000003ooooo`;o
0000EOooool001cooooo00?o0000ooooooooool0COooool2o`0000Wooooo0_l000000ooooooo0000
o`000004ooooo`;o00001Oooool2o`00037ooooo5_l00005ooooo`;o00009oooool2o`0000cooooo
0_l00003ooooo`;o00001Oooool2o`0004kooooo000Looooo`03o`000?oooooooooo05_ooooo0_l0
000>ooooo`;o0000:_ooool2o`0000;ooooo4_l00002ooooo`?o00001?ooool2o`0000cooooo0_l0
000Iooooo`;o00004?ooool2o`0000Kooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`1?
ooooo`;o00002_ooool3o`0000Sooooo0_l00002ooooo`?o00000_ooool2o`00017ooooo0_l00006
ooooo`;o00000_ooool2o`000003ooooool0003o000000Cooooo0_l000001Ooooooo0000o`000?l0
003ooooo013o000000Coooooo`000?l0003o00001?ooool3o`0000_ooooo0_l0000Eooooo`;o0000
5?ooool2o`0005Kooooo000Looooo`03o`000?oooooooooo04oooooo0_l0000;ooooo`;o00002?oo
ool6o`0000?ooooo0_l0000@ooooo`?o00001_ooool2o`0000;ooooo0_l000000ooooooo0000o`00
0003ooooo`;o00000_oooolHo`000004ooooool0003o0000ooooo`?o00008_ooool2o`0000oooooo
0_l0001Kooooo`007?ooool00ol0003oooooooooo`1Eooooo`;o00001?ooool2o`0000Sooooo1Ol0
0003ooooo`;o00003oooool2o`000003ooooool0003o000000kooooo0_l00003oooooaco000000?o
ooooo`000?l00000<Oooool2o`0000Cooooo0_l0000@ooooo`;o00002Oooool2o`0003kooooo000L
ooooo`03o`000?oooooooooo04Sooooo0_l0000;ooooo`;o00001?ooool2o`0000Sooooo1?l00000
1?oooooo0000o`000?ooool4o`0000gooooo0_l000000ooooooo0000o`000005ooooo`;o00001?oo
ool2o`000003ooooool0003o000000Cooooo4Ol000000ooooooo0000o`000005o`000003ooooool0
003o000000?ooooo0_l0000:ooooo`;o00005_ooool2o`0000[ooooo0_l00002ooooo`Co00004?oo
ool2o`0000Wooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`18ooooo`?o000000?ooooo
o`000?l000001oooool2o`0000_ooooo0_l000000ooooooo0000o`000003ooooo`;o00000oooool2
o`0001Oooooo0_l00004ooooo`;o00001_ooool3o`0000;ooooo6?l00003ooooo`Go00001oooool2
o`0000Cooooo0_l0000@ooooo`;o00001oooool2o`0000Gooooo1?l0000:ooooo`?o00000oooool2
o`0004Wooooo000Looooo`03o`000?oooooooooo04Wooooo0_l000000ooooooo0000o`000009oooo
o`;o00001Oooool2o`0000;ooooo0_l0000`ooooo`Go000000?oooooo`000?l000006_l000000ooo
oooo0000o`000002o`0000Cooooo0_l00007ooooo`;o00006Oooool4o`0000gooooo0_l00002oooo
o`?o0000C_ooool001cooooo00?o0000ooooooooool0AOooool2o`0000cooooo0_l00002ooooo`;o
00000_ooool2o`000003ooooool0003o000002Wooooo0_l00009ooooob;o00002?ooool3o`0001co
oooo1Ol00003ooooo`;o000000?oooooo`000?l000002_ooool2o`0000;ooooo0_l00002ooooo`;o
0000Boooool001cooooo00?o0000ooooooooool0?_ooool2o`0000Gooooo0_l0000<ooooo`?o0000
1Oooool2o`0001Kooooo0_l00003ooooo`;o00003oooool2o`0000Wooooo7ol00002ooooo`;o0000
1?ooool2o`000003ooooool0003o000000Oooooo0_l0000Dooooo`Go00001_ooool3o`00017ooooo
0_l0001;ooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00001?ooool3o`0000Kooooo0_l0
0005ooooo`Co00002Oooool2o`0000?ooooo0_l00005ooooo`;o00001?ooool4o`000003ooooool0
003o000000?ooooo0_l00002ooooo`;o00001oooool3o`0000Sooooo8_l00004ooooo`;o00002_oo
ool2o`0001Sooooo0_l00006ooooo`;o00001Oooool2o`0005Oooooo000Looooo`03o`000?oooooo
oooo04;ooooo1?l00002ooooo`;o00000oooool2o`0000Oooooo0_l00002ooooo`;o00000_ooool2
o`000003ooooool0003o000000;o000000?oooooo`000?l000000_l00003ooooo`?o00001Oooool2
o`0000;ooooo1ol000000ooooooo0000o`000004ooooo`Ko00001ooooolQo`0002cooooo0ol00007
ooooo`;o00000oooool2o`0005Oooooo000Looooo`03o`000?oooooooooo04;ooooo0_l00004oooo
o`;o00004?ooool2o`0000;ooooo0_l00003ooooo`;o00000oooool2o`0000?ooooo0ol00009oooo
o`Oo000000?oooooo`000?l000000ol000000ooooooo0000o`000004o`0000;ooooo0_l000000ooo
oooo0000o`000002o`0000;ooooo3ol00002ooooo`[o00001?ooool2o`0000kooooo0_l0000Goooo
o`Co00001oooool2o`0005cooooo000Looooo`03o`000?oooooooooo047ooooo0_l0000Cooooo`;o
00003oooool2o`0001;ooooo0_l00006ooooo`?o000000?oooooo`000?l000000_ooool2o`0000;o
oooo0_l000000ooooooo0000o`000002o`0000?ooooo3Ol000000ooooooo0000o`00000:o`0000;o
oooo1?l0000>ooooo`;o000000?oooooo`000?l000005?ooool2o`0000Kooooo0_l00008ooooo`;o
00000oooool2o`00053ooooo000Looooo`;o0000@_ooool2o`0000;ooooo0_l0000?ooooo`;o0000
00?oooooo`000?l000001?ooool4o`0000Cooooo0_l00004ooooo`;o00001oooool2o`0001?ooooo
1?l000000ooooooo0000o`00000<o`000003ooooool0003o000001?o000000Coooooo`000?l0003o
00000oooool2o`000003ooooool0003o000000Wooooo1?l0000>ooooo`;o00002oooool2o`0000Oo
oooo0ol00003ooooo`?o00000_ooool2o`0004_ooooo000Looooo`03o`000?oooooooooo04Cooooo
0ol0000=ooooo`;o00000oooool5o`000003ooooool0003o000000;o00002_ooool2o`0000Oooooo
0_l00008ooooo`;o00002_ooool3o`000003ooooool0003o000000;ooooo8?l00002ooooo`;o0000
0oooool2o`000003ooooool0003o000000Wooooo1?l0000>ooooo`;o00005?ooool4o`0000?ooooo
0_l00002ooooo`?o0000B_ooool001cooooo00?o0000ooooooooool0?oooool2o`0000?ooooo0_l0
00000ooooooo0000o`00000:ooooo`?o00000_ooool6o`0000;ooooo0_l0000Eooooo`;o00001ooo
ool2o`0000[ooooo1Ol00003ooooo`;o00000oooool;o`000003ooooool0003o000000_o00000_oo
ool5o`0003Sooooo1?l00005ooooo`;o000000?oooooo`000?l00000B_ooool001cooooo00?o0000
ooooooooool0?oooool2o`0000?ooooo0_l000000ooooooo0000o`00000:ooooo`;o00000oooool2
o`0000;ooooo0_l0000?ooooo`;o00002?ooool2o`0001Cooooo1?l00003ooooo`;o00000_ooool2
o`000003ooooool0003o000000Oo000000?oooooo`000?l000002ol00002ooooo`Go00004?ooool2
o`0000?ooooo0_l0000Gooooo`;o00004Oooool2o`0004gooooo000Looooo`03o`000?oooooooooo
047ooooo0_l000000ooooooo0000o`00000Kooooo`;o00001oooool2o`000003ooooool0003o0000
00Sooooo0_l0000>ooooo`;o000000?oooooo`000?l000003?ooool<o`000003ooooool0003o0000
00oo00002?ooool2o`0000Wooooo1?l000000ooooooo0000o`00000?ooooo`Co00000oooool3o`00
00[ooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`11ooooo`;o000000?oooooo`000?l0
00001Oooool2o`000003ooooool0003o0000017ooooo0_l00007ooooo`;o00001_ooool3o`0000oo
oooo0_l000000ooooooo0000o`000003o`0000Kooooo0_l00004oooooako00002?ooool2o`0000_o
oooo1?l0000@ooooo`Co00000oooool2o`0000Kooooo0_l00003ooooo`;o00004?ooool2o`0004;o
oooo000Looooo`03o`000?oooooooooo03Kooooo0_l0000Cooooo`;o000000?oooooo`000?l00000
4_ooool2o`0000?ooooo0_l00007ooooo`Go00003oooool2o`0000?ooooo0_l00007ooooo`;o0000
1?ooool2o`0000;ooooo5ol000000ooooooo0000o`00000Dooooo`;o000000?oooooo`000?l00000
4_ooool3o`0000Gooooo0_l00003ooooo`;o00004?ooool3o`0000;ooooo0_l00012ooooo`007?oo
ool00ol0003oooooooooo`0fooooo`;o00001?ooool4o`00027ooooo1?l00002ooooo`;o00001ooo
ool2o`000003ooooool0003o000000?ooooo0_l0000Mooooo`?o00000oooool7o`000003ooooool0
003o000000[o000000?oooooo`000?l000000_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l0
0006ooooo`;o00002?ooool2o`0000Cooooo0_l00005ooooo`;o00000_ooool2o`0000Wooooo0_l0
0006ooooo`?o0000A_ooool001cooooo00?o0000ooooooooool0??ooool4o`0000kooooo0ol00000
0ooooooo0000o`000002ooooo`Go00001_ooool4o`0000_ooooo0_l000000ooooooo0000o`000003
ooooo`;o00005Oooool2o`0000Cooooo1?l000001?oooooo0000o`000?oooolDo`000003ooooool0
003o000000Oooooo0_l00005ooooo`;o00003_ooool2o`0000Sooooo0_l0000?ooooo`;o00001?oo
ool2o`0000;ooooo0ol00003ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0>Oooool2
o`0000?ooooo0_l0000>ooooo`?o000000?oooooo`000?l000000_ooool5o`0000_ooooo0_l00008
ooooo`;o00004Oooool2o`0000[ooooo0_l00002ooooo`Co000000?oooooo`000?l000001_l00000
0ooooooo0000o`00000;o`000003ooooool0003o000000Cooooo0_l0000Xooooo`;o000000?ooooo
o`000?l000000_l000000ooooooo0000o`000007ooooo`;o000000?oooooo`000?l000000_ooool2
o`0000Cooooo0_l00009ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0>Oooool2o`00
00?ooooo0_l00006ooooo`;o00007_ooool2o`0001_ooooo0_l0000>ooooo`;o00000oooool8o`00
0003ooooool0003o0000013o00000_ooool4o`0001Oooooo0_l0000=ooooo`;o000000?oooooo`00
0?l000000_l000000ooooooo0000o`000003ooooo`;o00000_ooool4o`0001Cooooo0_l00003oooo
o`;o0000>_ooool001cooooo00?o0000ooooooooool0>Oooool2o`0000[ooooo0ol000000ooooooo
0000o`000002o`0000Cooooo0_l00002ooooo`;o00003_ooool2o`0000;ooooo1_l00007ooooo`;o
00003oooool2o`0000cooooo0_l00006ooooo`?o00000oooool=o`000003ooooool0003o000000?o
oooo0ol00003ooooo`;o00004_ooool2o`0000Cooooo0_l00002ooooo`;o00004?ooool2o`0000;o
oooo1?l00003ooooo`;o00002oooool2o`0000Oooooo0_l0000jooooo`007?ooool00ol0003ooooo
ooooo`0iooooo`?o00002Oooool2o`0000;ooooo1?l00004ooooo`;o00000_ooool2o`0000kooooo
0_l000000ooooooo0000o`000005o`0000Oooooo0_l00003ooooo`;o00000oooool2o`000003oooo
ool0003o000000;ooooo0_l00003ooooo`;o00000oooool2o`000004ooooool0003o0000o`0000Ko
oooo0_l00003ooooo`Go000000?oooooo`000?l000000_l0000@ooooo`Co00001oooool2o`000003
ooooool0003o000000[ooooo0_l00002ooooo`;o00006oooool2o`0000_ooooo0_l00013ooooo`00
7?ooool00ol0003oooooooooo`0jooooo`;o00003_ooool2o`0001Oooooo0_l00003ooooo`;o0000
2oooool8o`0000?ooooo0_l000000ooooooo0000o`000007ooooo`;o00000oooool2o`000003oooo
ool0003o000000Oooooo0_l000000ooooooo0000o`00000;o`000003ooooool0003o000000kooooo
0_l00007ooooo`;o000000?oooooo`000?l000003oooool2o`0006cooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003o
ooooooooo`0fooooo`?o00004?ooool2o`0001Kooooo1?l0000>ooooo`go00000oooool2o`0000_o
oooo0_l0000>ooooo`Co000000Goooooo`000?l0003o0000ooooo`04o`000004ooooool0003o0000
ooooo`;o00002oooool2o`0000[ooooo0_l0000?ooooo`;o00005oooool2o`0000Wooooo0_l00018
ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo03Kooooo0ol0000@ooooo`;o00001Oooool2o`0000Wooooo0_l0
0004ooooo`;o00003Oooool2o`000003ooooool0003o000000go000000?oooooo`000?l000001Ooo
ool2o`0000Cooooo0_l00007ooooo`;o00001oooool2o`0000;ooooo1Ol00006ooooo`Co00002?oo
ool2o`0000_ooooo0_l0000>ooooo`?o00005oooool2o`000003ooooool0003o000000Cooooo1?l0
0018ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`Go00001_ooool0
0ol0003oooooooooo`0]ooooo`;o00002_ooool2o`00013ooooo0_l00003ooooo`Co00000oooool3
o`000003ooooool0003o000000Cooooo0_l0000;oooooaOo00001Oooool2o`0000;ooooo0_l00007
ooooo`Co00000oooool2o`0000Kooooo1?l00006ooooo`;o000000?oooooo`000?l000002?ooool2
o`000003ooooool0003o000001Sooooo0ol0000Fooooo`;o00000_ooool2o`0000Cooooo0_l0001:
ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04odA4A?oMgMgooooo
o`0000Oooooo0ol0000]ooooo`;o00001_ooool3o`000003ooooool0003o000000[ooooo0_l00000
1?oooooo0000o`000?ooool4o`0000?ooooo1?l000001Ooooooo0000o`000?l0003ooooo00;o0000
2?ooool2o`000003ooooool0003o000000Cooooo5ol000000ooooooo0000o`000002o`0000Cooooo
0_l00007ooooo`;o00001?ooool3o`00013ooooo1?l0000;ooooo`Oo00007Oooool2o`0000Sooooo
0_l00004ooooo`;o00003?ooool2o`0004Kooooo00000ooooooo0000ooooo`02ooooo`03o`000?oo
oooooooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`0eooooo`Go0000
2oooool2o`000003ooooool0003o000000?ooooo0_l00005ooooo`;o00000oooool8o`0000;ooooo
1?l000000ooooooo0000o`000002ooooo`So000000?oooooo`000?l000004ol0000@ooooo`;o0000
00?oooooo`000?l000004Oooool4o`0000;ooooo0_l00007ooooo`;o000000?oooooo`000?l00000
0_l0000?ooooo`;o00003?ooool2o`0000;ooooo1?l00002ooooo`;o000000?oooooo`000?l00000
2_ooool2o`0000?ooooo0_l00016ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0=Oooool2o`000003ooooool0
003o000000Sooooo0_l00009ooooo`;o00001oooool;o`0000;ooooo0_l00003ooooo`;o00000_oo
oolNo`0000;ooooo0_l00003ooooo`;o00001oooool2o`0000_ooooo0_l00006ooooo`Go00000_oo
ool2o`0000Oooooo0_l00003ooooo`;o000000?oooooo`000?l000003?ooool2o`0000Oooooo0_l0
0003ooooo`;o00000_ooool4o`0000Gooooo0_l0000:ooooo`;o0000Boooool00006oooooomgMgOo
V9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo03[ooooo
0_l00006ooooo`;o00004?ooool8o`0000Gooooo0_l000001?oooooo0000o`000?l00006oooooako
000000?oooooo`000?l000000oooool2o`0000_ooooo0_l00003ooooo`;o00000_ooool2o`0000Ko
oooo0_l000000ooooooo0000o`00000Cooooo`?o00005?ooool2o`0000?ooooo0_l00007ooooo`;o
00000oooool2o`000003ooooool0003o000005?ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^
kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`0jooooo`;o00001_ooool2o`00
0003ooooool0003o000000;ooooo0_l00009ooooo`;o000000?oooooo`000?l000000ol00005oooo
o`;o000000Coooooo`000?l0003o00001?ooool5o`000003ooooool0003o000001So00003oooool2
o`0000;ooooo0_l00003ooooo`;o00008oooool2o`0001?ooooo1?l00006ooooo`;o00000_ooool3
o`0000?ooooo0_l000000ooooooo0000o`00000=ooooo`?o0000@oooool001cooooo00?o0000oooo
ooooool0AOooool2o`0000;ooooo0_l00009ooooo`;o00000_ooool2o`0000Wooooo0_l00004oooo
ob7o00004?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000Oooooo0_l00005oooo
o`;o00001oooool2o`0000_ooooo0_l0000<ooooo`;o00000oooool5o`0000;ooooo0_l00002oooo
o`;o00000_ooool2o`000003ooooool0003o000000Wooooo0_l00005ooooo`;o000000Coooooo`00
0?l0003o00002Oooool2o`0000?ooooo0_l0000cooooo`007?ooool00ol0003oooooooooo`0doooo
o`;o00002Oooool2o`0002;ooooo0_l00004ooooo`;o000000?oooooo`000?l000006ol0000Hoooo
o`;o00001oooool4o`0000Gooooo0_l00007ooooo`;o00002oooool2o`0000cooooo0ol00002oooo
o`?o00001?ooool2o`0000Gooooo0_l00002ooooo`;o00002Oooool2o`0000Gooooo0_l0000=oooo
o`;o00000oooool2o`0003?ooooo000Looooo`03o`000?oooooooooo033ooooo0_l00002ooooo`;o
00000_ooool2o`0000Gooooo0_l00007ooooo`;o00002_ooool2o`0001;ooooo0_l00004oooooa_o
00001_ooool2o`0000oooooo0ol000000ooooooo0000o`000003ooooo`?o00001oooool2o`0001Co
oooo0_l00003ooooo`;o00002?ooool2o`00013ooooo0_l0000;ooooo`;o00000_ooool2o`0000Go
oooo0ol00014ooooo`007?ooool00ol0003oooooooooo`0^ooooo`Co000000?oooooo`000?l00000
0oooool2o`0000Gooooo0_l00007ooooo`;o00001Oooool3o`0000;ooooo0_l0000Booooo`Co0000
0_oooolGo`000003ooooool0003o000000Go00000_ooool2o`0000oooooo0ol000000ooooooo0000
o`000003ooooo`;o00002?ooool2o`0000[ooooo0_l00008ooooo`?o00000_ooool2o`0001[ooooo
1?l00009ooooo`;o00000_ooool4o`0000?ooooo0ol00014ooooo`007?ooool00ol0003ooooooooo
o`0^ooooo`;o00000oooool2o`0001[ooooo1Ol0000Fooooo`?o000000?oooooo`000?l000002Ol0
00000ooooooo0000o`00000:o`000003ooooool0003o000000Co00005Oooool2o`0001Wooooo1?l0
0009ooooo`;o00006oooool2o`0000?ooooo1?l0000=ooooo`;o00000oooool2o`0004Gooooo000L
ooooo`03o`000?oooooooooo02oooooo0_l00002ooooo`;o00002?ooool2o`0000Kooooo0_l0000;
ooooo`;o00005oooool2o`000003ooooool0003o000000Wo000000?oooooo`000?l000003?l0000>
ooooo`;o00000oooool2o`0000Cooooo1Ol0000Fooooo`?o00002_ooool2o`0000;ooooo0_l0000:
ooooo`;o00001oooool2o`0000?ooooo0_l00005ooooo`;o00003_ooool2o`0000;ooooo0_l00015
ooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o00000_ooool3o`0000_ooooo0_l00006oooo
o`;o00005Oooool2o`000003ooooool0003o000000_ooooo3Ol000000ooooooo0000o`00000<o`00
00Gooooo0_l000000ooooooo0000o`000004ooooo`;o00000oooool2o`0000Cooooo0_l000000ooo
oooo0000o`00000Booooo`;o00000_ooool2o`0000?ooooo1?l00004ooooo`?o000000?oooooo`00
0?l000000oooool2o`0000Gooooo1?l00005ooooo`;o00005oooool2o`000003ooooool0003o0000
00Co0000AOooool001cooooo00?o0000ooooooooool0:oooool2o`0000?ooooo0_l0000Hooooo`;o
00004?ooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000Cooooo6ol00002oooo
o`;o00000_ooool2o`000003ooooool0003o000000gooooo0_l000000ooooooo0000o`00000Doooo
o`;o00001?ooool2o`000003ooooool0003o000000;o00000_ooool2o`000004ooooool0003o0000
o`0000Gooooo0_l00005ooooo`Co00006?ooool4o`0000;ooooo0_l00003ooooo`Co0000AOooool0
01cooooo00?o0000ooooooooool0;?ooool2o`0001cooooo0_l0000?ooooo`?o00001?ooool2o`00
0003ooooool0003o000000?o00000_oooolLo`000003ooooool0003o000000Gooooo0_l0000:oooo
o`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00005_ooool7o`0000;ooooo0_l00002
ooooo`;o000000?oooooo`000?l000000_l00002ooooo`?o00000_ooool3o`0001Wooooo1?l0000:
ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0:_ooool4o`0002Cooooo0_l00007oooo
o`?o00001oooool2o`000004ooooool0003o0000oooooago00005?ooool2o`000003ooooool0003o
000000Gooooo0_l0000Fooooo`Oo00000oooool2o`000004ooooool0003o0000ooooo`Co00000_oo
ool5o`000003ooooool0003o000000Wooooo1?l00007ooooo`;o00004Oooool2o`0004Cooooo000L
ooooo`03o`000?oooooooooo02[ooooo0_l0000Vooooo`;o00002?ooool2o`000003ooooool0003o
000000Wooooo6ol0000:ooooo`;o00004_ooool2o`000003ooooool0003o000000oooooo1?l00003
oooooa3o00000_ooool9o`000003ooooool0003o000000Wooooo1?l00007ooooo`;o00002?ooool2
o`0000Cooooo0_l00017ooooo`007?ooool2o`0002cooooo0_l0000@ooooo`;o000000?oooooo`00
0?l000004?ooool2o`0000_ooooo0_l00007oooooa[o000000Coooooo`000?l0003ooooo0_l00007
ooooo`;o00002oooool2o`0000Gooooo0_l000000ooooooo0000o`000007ooooo`;o00001_ooool4
o`0000Gooooo4?l00002ooooo`Go00000oooool4o`0000?ooooo0_l0000>ooooo`;o00001oooool9
o`0004Kooooo000Looooo`03o`000?oooooooooo02Sooooo0_l000000ooooooo0000o`000003oooo
o`;o00002_ooool3o`000003ooooool0003o000000Oooooo0_l00007ooooo`;o00002oooool2o`00
00Oooooo0_l00002ooooo`;o000000?oooooo`000?l000004Ol00004ooooo`;o00002oooool2o`00
00Gooooo1?l0000Aooooo`;o00002?ooool4o`0000Kooooo3Ol00002ooooo`co00000oooool2o`00
00kooooo0_l00008ooooo`Go000000?oooooo`000?l000001_ooool2o`0003kooooo000Looooo`03
o`000?oooooooooo02Sooooo0_l000000ooooooo0000o`000003ooooo`?o00002Oooool2o`0000Ko
oooo0_l00003ooooo`;o00001oooool3o`0000[ooooo0_l0000;ooooo`;o00000_ooool2o`000003
ooooool0003o000000oo00003oooool2o`0000Gooooo0_l000000ooooooo0000o`000004ooooo`;o
00000_ooool2o`0000kooooo2_l00003ooooo`Ko000000?oooooo`000?l000001Ol00003ooooo`Go
00000_ooool6o`0002Oooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0Vooooo`;o0000
2?ooool4o`000004ooooool0003o0000ooooo`;o00001Oooool2o`0000?ooooo1ol00007ooooo`?o
00004_ooool2o`0000?ooooo1?l000000ooooooo0000o`00000;o`0000;ooooo1?l0000Booooo`?o
00001?ooool2o`0000?ooooo0ol00002ooooo`;o00001?ooool2o`0000;ooooo0_l00004ooooo`;o
00000oooool5o`000003ooooool0003o0000013o000000Coooooo`000?l0003o00000oooool2o`00
0003ooooool0003o000000Co00008_ooool4o`0000Gooooo0_l0000hooooo`007?ooool00ol0003o
ooooooooo`0Vooooo`;o00002?ooool4o`000003ooooool0003o000000?o00001Oooool2o`0000Co
oooo1Ol00007ooooo`Co00001oooool2o`0000;ooooo0_l00005ooooo`;o00001Oooool2o`000004
ooooool0003o0000ooooo`?o000000?oooooo`000?l000001?l0000Hooooo`?o00002Oooool3o`00
00Sooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000000?ooooo1_l000000ooo
oooo0000o`00000Co`000003ooooool0003o000000Co000000?oooooo`000?l000008_ooool4o`00
00Gooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0gooooo`;o000000?oooooo`000?l0
00002oooool2o`0000Sooooo1?l00007ooooo`;o00000_ooool2o`0000cooooo1?l00002ooooo`?o
000000?oooooo`000?l000001?l0000Gooooo`;o00003?ooool2o`00017ooooo0_l000000ooooooo
0000o`000004ooooo`Wo000000?oooooo`000?l000003ol00003ooooo`Co0000J?ooool001cooooo
00?o0000ooooooooool0>_ooool2o`0000_ooooo0_l00008ooooo`;o00002Oooool2o`0000Wooooo
0_l00006ooooo`?o00001_ooool2o`0001;ooooo0ol00006ooooo`;o00002_ooool3o`0000cooooo
0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00000Jo`0000?o
oooo0_l00002ooooo`?o00000_ooool2o`0001Kooooo0_l0000@ooooo`;o0000=_ooool001cooooo
00?o0000ooooooooool0A?ooool2o`0000Sooooo0_l000001?oooooo0000o`000?ooool2o`0000Ko
oooo0_l00009ooooo`Co00001oooool2o`0001Sooooo0ol0000Aooooo`Co00003?ooool4o`0000Go
oooo8_l00003ooooo`_o00000oooool2o`00017ooooo1?l0000>ooooo`;o000000?oooooo`000?l0
0000<oooool001cooooo00?o0000ooooooooool0;oooool7o`0000kooooo0_l00006ooooo`Co0000
0_ooool4o`0000?ooooo0_l0000>ooooo`;o00001oooool2o`0000Wooooo0ol0000>ooooo`;o0000
4?ooool4o`0000kooooo0_l00007ooooo`;o000000?oooooo`000?l000002_l000000ooooooo0000
o`00000>o`000003ooooool0003o000000Co000000?oooooo`000?l000000_l000000ooooooo0000
o`000002ooooo`;o00001Oooool2o`0000Wooooo1_l00003ooooo`;o00002oooool2o`0003?ooooo
000Looooo`03o`000?oooooooooo02Cooooo0_l00003ooooo`Co00000_ooool7o`0001Kooooo0_l0
0004ooooo`;o00001?ooool5o`00013ooooo0_l0000<ooooo`Ko00001_ooool2o`000003ooooool0
003o000000;ooooo0_l0000@ooooo`Co00002?ooool2o`0000?ooooo0_l00006ooooo`;o00000ooo
oolQo`0000?ooooo0_l00004ooooo`;o00002Oooool2o`0000;ooooo0_l00005ooooo`?o000000?o
ooooo`000?l000000oooool2o`00043ooooo000Looooo`03o`000?oooooooooo02Cooooo0_l00003
ooooo`Co00001oooool2o`0000Gooooo0_l0000:ooooo`;o00000oooool2o`0000[ooooo1Ol0000?
ooooo`?o00003?ooool2o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o000000?ooooo
o`000?l000004oooool5o`0000?ooooo0_l00003ooooo`;o00000oooool2o`0000Kooooo0_l00000
0ooooooo0000o`00000Qo`0000?ooooo0_l00006ooooo`;o00000_ooool2o`0000Oooooo0_l0000>
ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool09?ooool2o`0000oooooo0ol00003oooo
o`;o00001_ooool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000005oooool2o`00
00;ooooo0_l00008ooooo`;o00002_ooool2o`000004ooooool0003o0000o`0000Oooooo0_l00003
ooooo`;o00002Oooool2o`0000Kooooo0_l00005ooooo`;o00002oooool3o`0000;ooooo5_l00002
ooooo`Go000000?oooooo`000?l000000_l000001?oooooo0000o`000?ooool6o`0000;ooooo0_l0
0002ooooo`;o00001Oooool2o`0000gooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0P
ooooo`;o00000_ooool2o`0000Sooooo0_l00005ooooo`?o00000oooool5o`0000?ooooo0_l0000:
ooooo`Co00001Oooool2o`0000kooooo0_l0000<ooooo`;o000000?oooooo`000?l000001Oooool2
o`0000?ooooo0ol00007ooooo`;o00000oooool2o`0000Wooooo0_l00009ooooo`;o00000_ooool2
o`0000;ooooo0_l000001?oooooo0000o`000?ooool;o`000003ooooool0003o0000013o00000_oo
ool:o`000003ooooool0003o000000Ko00001oooool2o`0000Gooooo0_l00007ooooo`;o00001?oo
ool2o`0003oooooo000Looooo`03o`000?oooooooooo023ooooo0_l00003ooooo`;o000000?ooooo
o`000?l000001?ooool2o`0000_ooooo1Ol0000:ooooo`Wo00001Oooool2o`0001Gooooo0_l00008
ooooo`;o00001Oooool2o`000003ooooool0003o000001Kooooo0_l00002ooooo`;o00002Oooool3
o`0000Gooooo0_l000001?oooooo0000o`000?ooool4o`000003ooooool0003o000001Oo000000?o
ooooo`000?l000003_l000001?oooooo0000o`000?l00009ooooo`Co00002_ooool2o`0004Gooooo
000Looooo`03o`000?oooooooooo02Cooooo0ol000000ooooooo0000o`000004ooooo`;o00002Ooo
ool2o`0000Sooooo0_l00005ooooo`So00001_ooool2o`0001Gooooo0_l00009ooooo`?o000000?o
ooooo`000?l000000oooool2o`0000Wooooo0_l000000ooooooo0000o`000008ooooo`;o00000_oo
ool2o`0000?ooooo0_l00004ooooo`Go00001Oooool2o`0000Gooooo2Ol000000ooooooo0000o`00
000Mo`0000;ooooo1Ol00003ooooo`[o00005Oooool2o`0003[ooooo000Looooo`03o`000?oooooo
oooo02Cooooo0ol00007ooooo`;o00002Oooool2o`0000?ooooo1?l000000ooooooo0000o`000008
ooooo`Go00002oooool6o`000003ooooool0003o000001Cooooo0ol000000ooooooo0000o`000003
ooooo`;o00002Oooool2o`000003ooooool0003o000000cooooo0_l00003ooooo`;o00001?ooool2
o`000004ooooool0003o0000ooooo`?o000000?oooooo`000?l000001OoooolYo`0000;ooooo1Ol0
0003ooooo`Ko00003?ooool2o`0000_ooooo0_l0000jooooo`007?ooool2o`0001kooooo0_l0000O
ooooo`Co000000?oooooo`000?l000002?ooool5o`0000_ooooo1_l000001?oooooo0000o`000?oo
ool2o`0001_ooooo0_l00002ooooo`;o00005_ooool2o`0000Sooooo0_l00003ooooo`Co00002Ooo
oolWo`000003ooooool0003o000000Wooooo0_l0000?ooooo`;o0000Aoooool001cooooo00?o0000
ooooooooool07Oooool2o`00017ooooo0_l0000Aooooo`;o00002?ooool2o`000003ooooool0003o
000000Oooooo0_l00004ooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo0_l0000F
ooooo`;o00000_ooool2o`0001;ooooo0_l000001?oooooo0000o`000?l00006ooooo`;o00001Ooo
ool2o`0000Cooooo0_l00002ooooo`;o00000_oooolYo`0000kooooo0_l0001Cooooo`007?ooool0
0ol0003oooooooooo`0^ooooo`Co00001_ooool2o`0001?ooooo0_l000001?oooooo0000o`000?l0
0006ooooo`;o00001oooool4o`000003ooooool0003o000000?ooooo0_l00003ooooo`;o00001ooo
ool2o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l000003oooool2o`0000;ooooo0_l0
00000ooooooo0000o`000005ooooo`Co00001?ooool2o`0000Gooooo0_l000001Ooooooo0000o`00
0?l0003ooooo00go000000?oooooo`000?l000002_l00002ooooo`go000000Coooooo`000?l0003o
oooo0_l000000ooooooo0000o`000006ooooo`;o00006?ooool3o`0003Sooooo000Looooo`03o`00
0?oooooooooo02Gooooo0_l00007ooooo`;o00002?ooool2o`0000Sooooo0ol00008ooooo`;o0000
0_ooool2o`00017ooooo0_l0000;ooooo`Go00001?ooool2o`0000Cooooo0_l00002ooooo`;o0000
00?oooooo`000?l000002Oooool2o`0000Cooooo0_l0000<ooooo`Co00001?ooool2o`0000Sooooo
:_l000000ooooooo0000o`000003o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l0
00000oooool2o`0000Oooooo0_l00007ooooo`;o00001_ooool3o`0003Sooooo000Looooo`03o`00
0?oooooooooo02Gooooo0_l000000ooooooo0000o`000006ooooo`;o00004?ooool5o`0000Kooooo
0_l0000Oooooo`;o00000_ooool7o`0001Wooooo0_l00005ooooo`;o000000?oooooo`000?l00000
6ooooolXo`0000;ooooo1?l000001Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`000?l0
00000oooool2o`0000Oooooo0_l00007ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0
:?ooool2o`0000Gooooo0ol0000Cooooo`;o00001_ooool4o`0000cooooo0_l000000ooooooo0000
o`00000<ooooo`;o00000oooool2o`000005ooooool0003o0000o`000?ooool00_l0000>ooooo`;o
000000?oooooo`000?l000001Oooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool5o`00
00oooooo0_l000000ooooooo0000o`000002o`0000;ooooo7_l000000ooooooo0000o`000004o`00
00?ooooo0ol000000ooooooo0000o`000009ooooo`;o00002?ooool3o`0004Wooooo000Looooo`03
o`000?oooooooooo02oooooo0_l00005ooooo`;o00001oooool2o`0000cooooo1?l0000:ooooo`Co
000000?oooooo`000?l000003Oooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o
00001oooool2o`0000Gooooo0_l000000ooooooo0000o`000003ooooo`Co00002Oooool5o`0000oo
oooo2?l00003ooooobWo00000oooool4o`0000Gooooo0_l00008ooooo`?o00000_ooool2o`0004Go
oooo000Looooo`03o`000?oooooooooo02[ooooo0_l00003ooooo`;o00001Oooool2o`0000Oooooo
0_l0000<ooooo`?o00000_ooool2o`0000Oooooo0_l0000Booooo`;o00001Oooool2o`0000_ooooo
0_l0000=ooooo`Go00001Oooool2o`000003ooooool0003o000000Cooooo0_l00009ooooo`Co0000
00?oooooo`000?l000000_ooool2o`0000?ooooo3Ol00003ooooo`?o000000?oooooo`000?l00000
4ol00003ooooo`Co00001Oooool2o`0000?ooooo1?l000000ooooooo0000o`000003ooooo`;o0000
1_ooool2o`0003gooooo000Looooo`03o`000?oooooooooo02Sooooo1?l00003ooooo`;o00001_oo
ool2o`0000Sooooo0_l00002ooooo`;o00001_ooool2o`0000?ooooo0_l00009ooooo`;o00001_oo
ool2o`00023ooooo0_l0000;ooooo`Co00000oooool3o`000003ooooool0003o000000Cooooo0_l0
0005ooooo`;o00000_ooool4o`0000?ooooo3?l000000ooooooo0000o`00000Ro`0000kooooo1_l0
00000ooooooo0000o`00000;ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0:?ooool2
o`0000Gooooo0_l00002ooooo`;o00000_ooool2o`0000Sooooo0_l000001?oooooo0000o`000?l0
0002ooooo`;o00001?ooool2o`0000cooooo0_l00006ooooo`?o000000?oooooo`000?l000000ooo
ool2o`0000Kooooo0_l00005ooooo`;o00000oooool2o`0000?ooooo0_l0000=ooooo`;o00000ooo
ool2o`0000Gooooo0_l00008ooooo`;o00001Oooool2o`0000;ooooo<Ol0000>ooooo`;o00000_oo
ool2o`0004gooooo000Looooo`03o`000?oooooooooo02oooooo0_l00002ooooo`;o00001_ooool2
o`0000Oooooo0ol00002ooooo`;o00001?ooool2o`00017ooooo0_l00002ooooo`;o000000?ooooo
o`000?l000000oooool2o`0000Kooooo0_l00005ooooo`Oo00007_ooool4o`0000gooooo0_l00000
0ooooooo0000o`00000Xo`0000Cooooo1?l0000Booooo`;o0000COooool001cooooo00?o0000oooo
ooooool0>oooool2o`0000Sooooo0_l0000Jooooo`Go00001Oooool2o`0000;ooooo0_l00006oooo
o`Co00001?ooool3o`0000Gooooo0_l00003ooooo`;o000000?oooooo`000?l000004Oooool6o`00
00;ooooo0_l00004ooooo`;o00001?ooool2o`0000?ooooo8ol00006ooooo`Go00000_ooool2o`00
027ooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o00007?ooool2o`0000?o
oooo1?l0000?ooooo`;o000000?oooooo`000?l000001Oooool2o`0000;ooooo0_l00006ooooo`Co
00003?ooool2o`000003ooooool0003o000000Go00000_ooool2o`0000Cooooo0_l00009ooooo`Co
00000_ooool2o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l000001_oooolOo`000003
ooooool0003o000000;ooooo1_l000001?oooooo0000o`000?l0000:ooooo`;o00002_ooool2o`00
00Wooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o00002Oooool2o`0000?o
oooo0_l00007ooooo`;o00000oooool2o`0000?ooooo1_l00007ooooo`;o00000_ooool2o`0001?o
oooo0_l0000:ooooo`;o00002?ooool2o`000003ooooool0003o000000?o000000?oooooo`000?l0
00001?ooool2o`0000Oooooo0_l00009ooooo`;o000000?oooooo`000?l000000_ooool5o`000003
ooooool0003o000000?ooooo8_l000000ooooooo0000o`000005o`000004ooooool0003o0000o`00
00;ooooo0_l000000ooooooo0000o`000003ooooo`?o00001oooool4o`0004Cooooo000Looooo`03
o`000?oooooooooo03Kooooo0_l00003ooooo`;o00001oooool2o`0000?ooooo0_l00007ooooo`;o
00001oooool2o`0000;ooooo0_l00008ooooo`;o000000Coooooo`000?l0003ooooo1ol000000ooo
oooo0000o`000005o`0000;ooooo0_l00005ooooo`;o00001oooool5o`0000gooooo0ol00007oooo
o`?o00001Oooool3o`0000?ooooo0_l00002ooooobOo000000?oooooo`000?l000001Ol00002oooo
o`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo0_l00003ooooo`;o00002?ooool2o`00
03cooooo000Looooo`03o`000?oooooooooo04Oooooo1?l00003ooooo`;o00002Oooool2o`0000Ko
oooo0_l00002ooooo`;o00000_ooool5o`000003ooooool0003o000000go00000oooool2o`0000Co
oooo0_l00005ooooo`Ko00003oooool2o`0000Gooooo1Ol00005ooooo`So00000_ooool2o`000003
ooooool0003o000001Go000000?oooooo`000?l000000_l000000ooooooo0000o`000002o`000003
ooooool0003o000000Ko00004Oooool4o`0000_ooooo0_l0000looooo`007?ooool2o`00047ooooo
0_l00005ooooo`;o00000oooool4o`0000;ooooo0_l00005ooooo`;o00001_ooool2o`0000;ooooo
0_l00003ooooo`;o00000ooooolAo`000004ooooool0003o0000o`0000[ooooo0_l0000Jooooo`;o
000000?oooooo`000?l000001?l000000ooooooo0000o`000006o`0000?ooooo5?l000000ooooooo
0000o`000002o`0000;ooooo0_l00003ooooo`;o00000oooool2o`0001Cooooo0_l00002ooooo`;o
00000oooool2o`0000;ooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0eooooo`;o0000
2Oooool2o`0000Gooooo0_l00002ooooo`?o000000?oooooo`000?l000000ol0000Iooooo`Wo0000
00?oooooo`000?l000001ol000000ooooooo0000o`000003o`0000?ooooo0_l00009ooooo`;o0000
3_ooool2o`0000Sooooo1Ol000000ooooooo0000o`000003ooooo`Wo00000_ooool5o`000003oooo
ool0003o000000_o000000?oooooo`000?l000000_l000000ooooooo0000o`000002ooooo`;o0000
0_ooool2o`0000Sooooo0_l00009ooooo`;o00000_ooool2o`0000?ooooo0_l000001?oooooo0000
o`000?l00008ooooo`;o0000=_ooool001cooooo00?o0000ooooooooool0:Oooool2o`0000[ooooo
0_l0000;ooooo`;o00000oooool2o`000005ooooool0003o0000o`000?ooool01?l00002ooooo`;o
00004?ooool2o`0000?ooooo5ol00002ooooo`;o00000oooool2o`0000Wooooo0_l0000;ooooo`;o
000000?oooooo`000?l000002?ooool2o`0000Cooooo0_l00003ooooo`So000000?oooooo`000?l0
00001Ol00002ooooo`co000000?oooooo`000?l000000_l000000ooooooo0000o`000004o`0000;o
oooo0_l00003ooooo`;o00000oooool2o`0000gooooo0_l00006ooooo`;o00002Oooool2o`0003Ko
oooo000Looooo`03o`000?oooooooooo02Wooooo0_l00007ooooo`;o00003_ooool4o`0000Cooooo
0_l000000ooooooo0000o`000002o`0000?ooooo0_l0000@ooooo`;o00000ooooolHo`0000cooooo
0ol0000?ooooo`;o00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`?o0000
0oooool3o`000003ooooool0003o000000;o000000?oooooo`000?l000000_l00004ooooo`?o0000
00?oooooo`000?l000001ol00003ooooo`;o00000oooool3o`000003ooooool0003o000000Cooooo
0ol0000Uooooo`;o0000=_ooool001cooooo00?o0000ooooooooool0<_ooool4o`0000?ooooo0_l0
0002ooooo`;o00001Oooool2o`0000Oooooo1?l000000ooooooo0000o`000006ooooo`;o000000?o
ooooo`000?l000000ol00005ooooo`;o00000_oooolJo`000003ooooool0003o000000?ooooo0_l0
0002ooooo`Go000000?oooooo`000?l000001_ooool2o`0000?ooooo0_l00002ooooo`;o00000_oo
ool2o`000003ooooool0003o000000Cooooo0_l00005ooooo`;o000000?oooooo`000?l000000ol0
00000ooooooo0000o`00000?o`0000Cooooo1?l000000ooooooo0000o`000003o`000004ooooool0
003o0000o`0000?ooooo0ol0000Tooooo`?o0000=_ooool001cooooo00?o0000ooooooooool0<ooo
ool3o`0000?ooooo0_l00002ooooo`;o00002?ooool2o`0000Cooooo1ol00006ooooo`;o000000?o
ooooo`000?l000000ol00005ooooo`;o00000_oooolMo`0000?ooooo0_l000000ooooooo0000o`00
0002ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o00000oooool2o`0000gooooo0_l0
000:ooooobCo00000oooool2o`0001?ooooo0_l00002ooooo`;o00002?ooool2o`0000Oooooo0_l0
000gooooo`007?ooool00ol0003oooooooooo`0Oooooo`;o00004Oooool3o`0000oooooo0_l00000
0ooooooo0000o`000003ooooo`Ko00006OoooolCo`000003ooooool0003o000000Oo00001_ooool2
o`0000?ooooo1_l00005ooooo`;o00001Oooool2o`0000[ooooo0_l00007ooooo`;o00000_ooool2
o`000003ooooool0003o000000Oo000000Coooooo`000?l0003ooooo2_l00002ooooo`?o000000?o
ooooo`000?l000001?ooool2o`0001;ooooo0ol00002ooooo`;o00002?ooool2o`00043ooooo000L
ooooo`03o`000?oooooooooo01oooooo0_l0000Aooooo`?o00001oooool2o`0000Kooooo0_l00006
ooooo`?o00007?ooool2o`0000;ooooo3ol000000ooooooo0000o`000008o`0000Wooooo1Ol00007
ooooo`;o00001Oooool2o`0000Sooooo0_l000000ooooooo0000o`000006ooooo`;o00001oooool5
o`000003ooooool0003o000000?ooooo1_l000000ooooooo0000o`000007ooooo`?o00000oooool2
o`0000Wooooo0_l00007ooooo`;o0000Coooool001cooooo00?o0000ooooooooool0<oooool2o`00
00;ooooo0_l00003ooooo`;o00002_ooool2o`0000;ooooo0_l0000:ooooo`;o000000?oooooo`00
0?l000003ooooolIo`0000;ooooo0_l00009ooooo`;o000000Coooooo`000?l0003o00001Oooool3
o`0000gooooo1?l000000ooooooo0000o`000003ooooo`;o00003?ooool7o`0000Kooooo0_l00007
ooooo`Ko00003_ooool2o`0000Kooooo0_l00007ooooo`;o00004Oooool2o`0003Cooooo000Loooo
o`03o`000?oooooooooo03?ooooo0_l00002ooooo`Co00002?ooool2o`0000?ooooo0_l000000ooo
oooo0000o`000003o`0000Sooooo0_l000000ooooooo0000o`00000?oooooaco000000?oooooo`00
0?l000002oooool2o`0000Gooooo0ol00006ooooo`;o00001Oooool2o`0000Sooooo0_l00004oooo
o`;o00002?ooool2o`000003ooooool0003o000000Kooooo0ol000000ooooooo0000o`000003oooo
o`Ko00002?ooool2o`0000cooooo0_l00005ooooo`Co00004Oooool2o`0003Cooooo000Looooo`03
o`000?oooooooooo03Sooooo0ol00008ooooo`;o00001?ooool7o`0001_ooooo8?l0000Aooooo`Ko
00001?ooool3o`0001?ooooo0ol00004ooooo`;o00001Oooool2o`0000Oooooo0_l000000ooooooo
0000o`000008ooooo`;o00001Oooool4o`0001;ooooo1?l00003ooooo`;o0000@oooool001cooooo
00?o0000ooooooooool0=oooool2o`000003ooooool0003o000000_ooooo1?l0000=ooooo`;o0000
4?oooolOo`0000Cooooo1_l00008ooooo`Oo00001Oooool2o`0001?ooooo0_l00002ooooo`;o0000
00?oooooo`000?l000001Oooool2o`0000Oooooo0_l000000ooooooo0000o`000008ooooo`;o0000
1Oooool2o`0000;ooooo0_l0000@ooooo`;o00001Oooool2o`0004?ooooo000Looooo`03o`000?oo
oooooooo03Oooooo0_l000000ooooooo0000o`000003o`0000Sooooo0_l000000ooooooo0000o`00
000<ooooo`Co00003_ooool:o`000003ooooool0003o000001?o00000oooool6o`0000Cooooo0_l0
0002ooooo`Go00004_ooool2o`0000cooooo0_l0000=ooooo`Ko000000?oooooo`000?l000002?oo
ool2o`0000Gooooo0_l00002ooooo`;o00003_ooool4o`0004[ooooo000Looooo`03o`000?oooooo
oooo03Cooooo0_l000000ooooooo0000o`000003ooooo`?o00000_ooool4o`0000;ooooo1ol0000<
ooooo`;o00000_ooool2o`0000gooooo2ol000000ooooooo0000o`00000<o`000003ooooool0003o
000000?ooooo0_l00008ooooo`;o00000_ooool2o`0000Cooooo1_l0000;ooooo`?o00002_ooool2
o`0000?ooooo0_l00003ooooo`;o00001?ooool4o`0000gooooo0_l0000Gooooo`Co0000C?ooool0
0006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@
olc<c006ooooo`03o`000?oooooooooo03Cooooo0_l000000ooooooo0000o`000008ooooo`Co0000
0oooool3o`000003ooooool0003o000000;ooooo0_l00005ooooo`Co00000oooool2o`0000gooooo
2ol000000ooooooo0000o`00000<o`0001Sooooo2?l00002ooooo`;o00002?ooool2o`0000Kooooo
0_l00002ooooo`;o000000?oooooo`000?l000001?l000000ooooooo0000o`000004ooooo`;o0000
4_ooool2o`0000Gooooo1?l0000;ooooo`;o00001Oooool2o`0000_ooooo0_l0000jooooo`0000Ko
ooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q
00Kooooo00?o0000ooooooooool0=_ooool4o`0000kooooo0_l00006ooooo`;o00001Oooool6o`00
00;ooooo0_l0000:oooooaOo000000?oooooo`000?l000000_l0000Hooooo`Co00001_ooool2o`00
00oooooo1ol000001Ooooooo0000o`000?l0003ooooo00;o00001oooool4o`0000cooooo0_l00002
ooooo`;o000000?oooooo`000?l000001_l0000Booooo`;o00002oooool2o`0000[ooooo0_l0000^
ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`0fooooo`Co00005oooool2o`000003ooooool0003o
000000?ooooo1?l00002ooooo`;o00002_oooolFo`000003ooooool0003o000000;o000000?ooooo
o`000?l000003oooool2o`0000Oooooo1?l00002ooooo`;o000000?oooooo`000?l000003_ooool2
o`000003ooooool0003o000000;o00004?ooool3o`0000_ooooo0_l00005ooooo`Co0000;oooool2
o`0002kooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oiRH
V?ooooooV9RHob4Q8@06ooooo`?o0000?oooool2o`0000Kooooo0ol00007ooooo`;o000000?ooooo
o`000?l000000oooool2o`0000Cooooo0_l00005ooooo`;o00001Oooool7o`000003ooooool0003o
000000[o000000?oooooo`000?l000000oooool4o`0000cooooo1?l00006ooooo`Go000000?ooooo
o`000?l000000ol0000Aooooo`?o000000?oooooo`000?l000002oooool2o`0000;ooooo0_l00000
0ooooooo0000o`000003ooooo`Co00000oooool3o`0001Sooooo0_l00003ooooo`?o0000AOooool0
0003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oEEEEo`000?l@413o
c<c<00Kooooo00?o0000ooooooooool0>oooool2o`0000;ooooo1?l00003ooooo`Co00003oooool2
o`0000Cooooo0_l00005ooooo`;o00001Oooool7o`0000;ooooo3_l00005ooooo`;o00002Oooool2
o`000003ooooool0003o000000;o00001_ooool2o`000003ooooool0003o000000;ooooo1?l00004
ooooo`;o00002oooool3o`000003ooooool0003o000000Sooooo0_l000000ooooooo0000o`000005
ooooo`Co000000?oooooo`000?l000000_l00003ooooo`?o00004_ooool2o`0000Cooooo1?l00000
1?oooooo0000o`000?l00015ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09
ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0=oooool2o`0000;ooooo0_l00004
ooooo`;o00000oooool2o`00013ooooo0ol00004ooooo`;o00002_ooool5o`000003ooooool0003o
0000017o00004?ooool2o`0000;ooooo0_l00005ooooo`;o00001oooool4o`000004ooooool0003o
0000ooooo`;o00001_ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000002Ooo
ool2o`0000Sooooo1?l00008ooooo`;o00004oooool2o`0000Cooooo1?l0000>ooooo`;o0000>Ooo
ool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`00
0?oooooooooo03Oooooo0_l0000Gooooo`;o000000?oooooo`000?l000000oooool2o`00017ooooo
6Ol0000Kooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000004ooooo`;o0000
2Oooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000001_ooool3o`0000Kooooo
1?l0000Tooooo`;o00004oooool2o`0003Wooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPco
oooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`0dooooo`;o00000oooool4o`00
00gooooo0_l00004ooooo`Go00005ooooolHo`0001cooooo2Ol0000Nooooo`Co00000_ooool2o`00
00;ooooo1?l00003ooooo`;o00001_ooool2o`0001Oooooo0_l0001>ooooo`007?ooool00ol0003o
ooooooooo`0dooooo`;o00000oooool4o`0000gooooo0_l00006ooooo`;o00006?oooolGo`0000?o
oooo0_l0000>ooooo`;o00000oooool2o`0000?ooooo0_l00004ooooo`?o00005?ooool2o`0000So
oooo0ol00003ooooo`;o00002Oooool2o`0000Kooooo0_l0000=ooooo`;o0000F?ooool001cooooo
00?o0000ooooooooool0>?ooool2o`0001;ooooo0_l0000Eooooo`;o00000_ooool2o`0000?ooooo
5Ol00005ooooo`Co00003?ooool2o`000003ooooool0003o000000;o00000oooool2o`000003oooo
ool0003o000000;ooooo0_l00008ooooo`Co00002?ooool2o`0000;ooooo0_l0000@ooooo`?o0000
6Oooool2o`0005Sooooo000Looooo`03o`000?oooooooooo03Sooooo1?l00003ooooo`;o00001Ooo
ool2o`0000Cooooo0_l00004ooooo`;o00000oooool3o`0000Wooooo0_l00002ooooo`;o00000ooo
oolEo`0000Oooooo0_l000000ooooooo0000o`00000;ooooo`?o00002?ooool2o`0000;ooooo0_l0
0004ooooo`;o00000_ooool4o`0000Cooooo0_l00006ooooo`;o00002_ooool3o`0000?ooooo1?l0
0008ooooo`;o00006_ooool2o`0001;ooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0j
ooooo`;o00000oooool2o`0000Gooooo0_l0000:ooooo`;o00000oooool3o`0000Kooooo0_l00006
ooooo`;o00000ooooolDo`0000Gooooo0_l00002ooooo`?o00002oooool2o`0000Gooooo0ol00005
ooooo`;o00001?ooool2o`0000[ooooo1?l00008ooooo`;o00001_ooool3o`0000Gooooo0_l00008
ooooo`;o00000oooool2o`0001Gooooo0_l0000Booooo`;o0000>?ooool001cooooo00?o0000oooo
ooooool0D?ooool2o`0000Cooooo0_l00008ooooo`;o00001_ooool2o`0000?ooooo0_l000000ooo
oooo0000o`00000;o`0000Wooooo0_l00002ooooo`;o00002?ooool2o`0000Wooooo0ol00005oooo
o`;o00002_ooool2o`0000Kooooo0_l00005ooooo`;o000000?oooooo`000?l000001oooool2o`00
0004ooooool0003o0000ooooo`Co00001oooool2o`0000?ooooo0_l0000Eooooo`;o00001Oooool2
o`0004Gooooo000Looooo`03o`000?oooooooooo03Wooooo0_l0000@ooooo`;o00000oooool2o`00
00Cooooo0_l00008ooooo`;o00002_ooool2o`0000?ooooo3Ol0000Dooooo`Ko00006?ooool2o`00
0003ooooool0003o000000Co00002Oooool5o`0000[ooooo0_l000000ooooooo0000o`000002o`00
00Oooooo0ol00002ooooo`;o00004Oooool2o`0000;ooooo0ol00004ooooo`;o0000AOooool001co
oooo00?o0000ooooooooool08Oooool2o`0001Kooooo0_l0000@ooooo`;o00001?ooool2o`0000So
oooo0_l00003ooooo`;o00001oooool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo
0000o`000008o`0000cooooo0_l00006ooooo`;o00000_ooool2o`0000Oooooo0_l0000?ooooo`;o
00000_ooool5o`0000;ooooo0_l00007ooooo`;o000000?oooooo`000?l000000oooool2o`0000?o
oooo0_l0000;ooooo`Co00000oooool2o`00013ooooo0_l00002ooooo`?o0000Boooool001cooooo
00?o0000ooooooooool08Oooool2o`00023ooooo0_l00006ooooo`;o00001?ooool2o`0000Sooooo
0_l0000<ooooo`Co00001?ooool6o`000003ooooool0003o000000;o00003_ooool2o`0000Sooooo
1?l000001Ooooooo0000o`000?l0003ooooo00Co00004oooool3o`0000Cooooo0_l0000:ooooo`;o
00000_ooool3o`000003ooooool0003o000000gooooo0ol00004ooooo`;o00005?ooool2o`0004co
oooo000Looooo`03o`000?oooooooooo04?ooooo0_l00005ooooo`?o00001oooool3o`0000cooooo
0_l00006ooooo`;o00001?ooool4o`0000Cooooo0ol0000Dooooo`Ko00000oooool3o`000004oooo
ool0003o0000ooooo`;o00005_ooool2o`0000Sooooo0_l00007ooooo`;o00000_ooool2o`0000Go
oooo0_l00004ooooo`;o00005oooool2o`0000Oooooo0_l00019ooooo`007?ooool00ol0003ooooo
ooooo`0iooooo`;o00000oooool2o`0000?ooooo0_l00005ooooo`?o000000?oooooo`000?l00000
1?ooool3o`0000cooooo0_l0000>ooooo`;o00001?ooool7o`00013ooooo1?l0000:ooooo`Co0000
2?ooool2o`0000Kooooo0_l00004ooooo`Co00001_ooool2o`0001;ooooo0_l000000ooooooo0000
o`000003o`0001Oooooo0ol00006ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0>Ooo
ool2o`0000?ooooo0_l00002ooooo`;o00002_ooool2o`0000Wooooo0_l00006ooooo`Co00002Ooo
ool3o`000003ooooool0003o000000Cooooo2?l00005ooooo`;o00002oooool4o`0000Cooooo0ol0
00000ooooooo0000o`000007ooooo`Go00001_ooool2o`0000Kooooo0_l00004ooooo`;o00001?oo
ool2o`00017ooooo1?l0000Iooooo`;o00004_ooool2o`0003gooooo000Looooo`;o0000@oooool4
o`0000;ooooo0_l00003ooooo`;o00002Oooool3o`0000Kooooo1?l00009ooooo`?o000000?ooooo
o`000?l000001?ooool3o`0000[ooooo0_l00008ooooo`?o00000_ooool2o`0000;ooooo1_l00002
ooooo`;o00000_ooool2o`000003ooooool0003o000000?o00002oooool2o`0000Oooooo0_l00004
ooooo`;o000000?oooooo`000?l000002Oooool2o`0000?ooooo1?l0000Iooooo`Go00003oooool2
o`0003gooooo000Looooo`03o`000?oooooooooo04Cooooo1_l00002ooooo`?o00002Oooool2o`00
01_ooooo0_l0000Fooooo`Go000000?oooooo`000?l000000_ooool3o`000003ooooool0003o0000
00Wo00001?ooool2o`0000;ooooo0_l00005ooooo`Co00000oooool2o`0000;ooooo0_l00002oooo
o`;o00000oooool2o`0000Oooooo1?l00003ooooo`Ko00004oooool2o`0000;ooooo1Ol0001>oooo
o`007?ooool00ol0003oooooooooo`13ooooo`;o000000?oooooo`000?l000001?ooool2o`0000So
oooo0_l00003ooooo`;o00005?ooool2o`0000;ooooo0_l0000Aooooo`;o00000oooool2o`000004
ooooool0003o0000ooooo`;o00000_ooool@o`0000Oooooo0_l00003ooooo`Ko00000oooool2o`00
00;ooooo0ol000000ooooooo0000o`00000<ooooo`;o00000oooool2o`0000;ooooo1?l0000@oooo
o`;o000000?oooooo`000?l000000_l00008ooooo`;o0000BOooool001cooooo00?o0000oooooooo
ool0@oooool2o`00017ooooo0ol00002ooooo`;o00005?ooool2o`0000[ooooo0ol00008ooooo`;o
00001_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000@o`0000Kooooo0_l00002ooooo`Ko
00000_ooool2o`0000Cooooo0_l00002ooooo`;o00002oooool4o`000003ooooool0003o000001Ko
oooo0_l00003ooooo`Co00001_ooool2o`0004Wooooo000Looooo`03o`000?oooooooooo04;ooooo
0_l0000Aooooo`Co00003Oooool5o`0000_ooooo0_l00005ooooo`?o00005?ooool2o`000003oooo
ool0003o0000013o00001_ooool2o`0000Kooooo0_l00002ooooo`;o00002?ooool2o`0000;ooooo
0_l00009ooooo`;o00000_ooool2o`0001cooooo0_l0001Aooooo`007?ooool00ol0003ooooooooo
o`12ooooo`;o00004Oooool4o`0000cooooo1_l0000;ooooo`;o00007ooooolFo`0000;ooooo0_l0
0009ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool6o`0001Kooooo0ol0
0004ooooo`;o0000COooool001cooooo00?o0000ooooooooool0B?ooool2o`0000?ooooo1?l00004
ooooo`Co00000oooool2o`0000Kooooo0ol0000Aooooo`Co00005_ooool2o`0000?ooooo5_l00002
ooooo`?o00002?ooool2o`0000Gooooo1?l00008ooooo`;o000000?oooooo`000?l000001Oooool6
o`0000;ooooo0_l0000Booooo`?o00001?ooool2o`0004gooooo000Looooo`03o`000?oooooooooo
04Kooooo1?l00003ooooo`Co00000_ooool5o`0000Cooooo0_l00006ooooo`Co00003Oooool2o`00
0003ooooool0003o000000;o00002oooool2o`0000Wooooo0_l00003oooooa;o00000oooool6o`00
00?ooooo0_l00003ooooo`;o00001oooool2o`0000Oooooo0ol00009ooooo`;o00001Oooool2o`00
00oooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`16ooooo`?o00002_ooool4o`0000Wo
oooo0_l00003ooooo`?o00002Oooool2o`0000;ooooo0_l00002ooooo`;o00003?ooool2o`0000Co
oooo0_l00007oooooa[o00001Oooool2o`0000;ooooo1Ol0000>ooooo`;o00002_ooool2o`0001Ko
oooo0_l00006ooooo`;o0000Coooool001cooooo00?o0000ooooooooool0A_ooool2o`0000Sooooo
0_l00002ooooo`Co00002?ooool2o`0000?ooooo0_l000001?oooooo0000o`000?l00006ooooo`;o
00000oooool2o`0001Gooooo0_l00007ooooo`go000000?oooooo`000?l000001ol000000ooooooo
0000o`000009ooooo`;o000000?oooooo`000?l000004_ooool2o`0000Cooooo0_l000000ooooooo
0000o`00000@ooooo`;o00001Oooool2o`0000Cooooo0_l0000:ooooo`;o0000@oooool001cooooo
00?o0000ooooooooool0A_ooool2o`0000Sooooo0_l00002ooooo`Co00004?ooool3o`0000_ooooo
0_l0000;ooooo`;o00004OoooolLo`0000Oooooo0ol0000>ooooo`;o00001?ooool2o`0000Cooooo
0_l000000ooooooo0000o`000002o`0000kooooo0_l00005ooooo`;o00004?ooool2o`0004?ooooo
000Looooo`03o`000?oooooooooo06_ooooo0_l0000Fooooo`;o00000_ooool2o`000003ooooool0
003o000000;o00002?oooolMo`0000?ooooo0_l000001?oooooo0000o`000?l00002ooooo`;o0000
2_ooool2o`0000oooooo0_l0001/ooooo`007?ooool00ol0003oooooooooo`1Eooooo`?o00002?oo
ool2o`0000Sooooo0ol0000Jooooo`;o000000?oooooo`000?l000000_l00009oooooaWo000000?o
ooooo`000?l000000oooool2o`0000;ooooo0_l00002ooooo`Ko0000BOooool2o`0003[ooooo000L
ooooo`03o`000?oooooooooo05Cooooo1?l00007ooooo`?o00002?ooool5o`0001;ooooo0_l0000@
ooooo`;o00000_oooolGo`0000;ooooo1?l00002ooooo`Co00001Oooool5o`0000Gooooo0_l00005
ooooo`;o00000oooool2o`0000?ooooo1?l0000_ooooo`;o0000>_ooool001cooooo00?o0000oooo
ooooool0=_ooool2o`0001cooooo0_l00002ooooo`;o00001Oooool2o`0000cooooo0_l00008oooo
o`;o00002?ooool2o`0000_ooooo0_l00003ooooo`;o00000_ooool3o`000003ooooool0003o0000
013o00000oooool4o`0000;ooooo1?l00004ooooo`Co00001oooool2o`0000Gooooo0_l00003oooo
o`;o00000oooool4o`0000cooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`0fooooo`;o
00005?ooool2o`0000Sooooo1?l00005ooooo`;o00001oooool2o`0000;ooooo1?l00007ooooo`;o
00005Oooool3o`0000;ooooo0_l00003oooooa?o00004oooool4o`0000Gooooo0ol0000Aooooo`;o
00002?ooool2o`0000?ooooo0_l0001Mooooo`007?ooool2o`0004gooooo0_l00008ooooo`;o0000
4?ooool2o`0000;ooooo1_l0000=ooooo`;o00003_ooool3o`0000Oooooo0_l000000ooooooo0000
o`00000>o`0000Cooooo0_l00009ooooo`;o00000oooool3o`000004ooooool0003o0000ooooo`?o
00000oooool2o`0000cooooo0_l000000ooooooo0000o`000005ooooo`;o00002_ooool2o`000003
ooooool0003o000000Oooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o0000
1?ooool4o`0001Oooooo1Ol00008ooooo`;o00000oooool2o`0000Wooooo0_l000000ooooooo0000
o`000003o`0000Oooooo5?l00003ooooo`;o00002Oooool2o`0000?ooooo1_l00007ooooo`?o0000
1_ooool2o`0000Cooooo1?l0000Aooooo`;o000000?oooooo`000?l000001oooool2o`0004[ooooo
000Looooo`03o`000?oooooooooo05;ooooo1?l0000Oooooo`;o00000oooool2o`0000kooooo0_l0
00000ooooooo0000o`000002o`0000?ooooo0_l00003oooooa7o000000?oooooo`000?l000003_oo
ool2o`0000Gooooo1Ol00006ooooo`Co00001Oooool3o`0000?ooooo0ol00004ooooo`;o00003_oo
ool2o`0005Cooooo000Looooo`03o`000?oooooooooo07Gooooo0_l0000Gooooo`;o00001?ooool5
o`000004ooooool0003o0000ooooo`oo00001_ooool2o`0000Kooooo0_l00006ooooo`Go00000_oo
ool4o`0000;ooooo0_l00004ooooo`Co00001?ooool4o`0000;ooooo0_l00007ooooo`;o00001Ooo
ool2o`0005Cooooo000Looooo`03o`000?oooooooooo05gooooo0_l0000Aooooo`;o00000oooool2
o`0001[ooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o0000013o00001_ooool2
o`0000Kooooo0_l00006ooooo`;o00001Oooool4o`0000Oooooo0ol00008ooooo`Go000000?ooooo
o`000?l000000_ooool5o`0000Cooooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`1Doooo
o`;o00001oooool2o`0000gooooo0_l00002ooooo`;o00000_ooool2o`0001_ooooo0_l000000ooo
oooo0000o`000005ooooo`Oo000000?oooooo`000?l000000oooool2o`0000oooooo0_l000000ooo
oooo0000o`000004ooooo`;o00001?ooool2o`0000[ooooo0_l0000;ooooo`?o000000?oooooo`00
0?l000000_ooool5o`0000Cooooo1?l0001Cooooo`007?ooool00ol0003oooooooooo`0fooooo`;o
00007?ooool2o`0000oooooo0_l00005ooooo`;o000000?oooooo`000?l000000oooool2o`0002Go
oooo1_l00004ooooo`;o000000?oooooo`000?l000003Oooool4o`000004ooooool0003o0000oooo
o`Go00001?ooool4o`0000Wooooo0_l0000:ooooo`;o00002?ooool2o`0000Oooooo0_l0001Coooo
o`007?ooool00ol0003oooooooooo`0fooooo`;o00007oooool2o`0000cooooo0_l00008ooooo`;o
00003oooool2o`0000cooooo0_l0000:ooooo`Oo00000_ooool4o`0000cooooo0_l00002ooooo`;o
000000?oooooo`000?l000000oooool3o`0000Kooooo1?l00009ooooo`;o0000L_ooool001cooooo
00?o0000ooooooooool0E_ooool3o`0002Oooooo0_l0000<ooooo`;o00000_ooool2o`0000Kooooo
0_l00007ooooo`;o00001?ooool2o`000003ooooool0003o000000Gooooo0_l00005ooooo`;o0000
00?oooooo`000?l000002_ooool2o`0007kooooo000Looooo`03o`000?oooooooooo05Kooooo0_l0
000?ooooo`;o00000_ooool2o`0000Kooooo0_l0000:ooooo`Co00003oooool2o`0000cooooo0_l0
0007ooooo`Go00000_ooool2o`0000_ooooo0_l0000@ooooo`?o00001?ooool4o`0000;ooooo0_l0
0006ooooo`?o000000?oooooo`000?l000001?ooool2o`0005Wooooo000Looooo`03o`000?oooooo
oooo05cooooo0_l00006ooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o
000000?ooooo0_l0000:ooooo`Co00004_ooool2o`0000;ooooo1Ol00002ooooo`;o00002Oooool2
o`0000?ooooo0_l0000?ooooo`?o00002_ooool4o`0000Cooooo1?l00002ooooo`;o00001_ooool3
o`000003ooooool0003o000000Cooooo0_l0001Iooooo`007?ooool00ol0003oooooooooo`1Loooo
o`;o00000oooool8o`000003ooooool0003o000000;ooooo0_l00007ooooo`;o00000oooool2o`00
00oooooo0_l00006ooooo`Wo00001_ooool2o`00017ooooo0_l00002ooooo`;o00000_ooool5o`00
00[ooooo0_l0000:ooooo`;o00002_ooool2o`00067ooooo000Looooo`03o`000?oooooooooo05Go
oooo0_l00002ooooo`;o00001_ooool8o`000003ooooool0003o000000;o00000_ooool3o`0000Co
oooo0ol00002ooooo`;o00003oooool2o`0000Sooooo0ol0000:ooooo`;o00003oooool8o`0000;o
oooo0_l00002ooooo`Co00001?ooool2o`0000gooooo0_l0000:ooooo`?o00000_ooool2o`0005co
oooo000Looooo`03o`000?oooooooooo05Gooooo0_l00002ooooo`;o00003_ooool5o`0000;ooooo
0ol00003ooooo`Co00004?ooool2o`0000cooooo0_l0000Kooooo`Ko000000?oooooo`000?l00000
1Oooool4o`0000Cooooo0_l0000Jooooo`;o00000_ooool2o`0005cooooo000Looooo`03o`000?oo
oooooooo05;ooooo0_l0000:ooooo`;o00002Oooool2o`0000_ooooo1?l0000@ooooo`?o0000;ooo
ool2o`0000;ooooo0_l000000ooooooo0000o`00000Aooooo`;o0000LOooool001cooooo00?o0000
ooooooooool0D_ooool2o`0000[ooooo0_l000000ooooooo0000o`00000;ooooo`;o00001?ooool2
o`0000[ooooo0ol00008ooooo`;o00000oooool2o`0000gooooo0_l0000Eooooo`;o00002?ooool2
o`0000oooooo0_l00003ooooo`?o00001oooool2o`0006Oooooo000Looooo`;o0000G?ooool2o`00
00Cooooo0_l0000;ooooo`?o00000oooool2o`0000[ooooo0ol0000=ooooo`;o00003Oooool2o`00
01Gooooo0_l00008ooooo`;o00002?ooool2o`0000;ooooo0_l000000ooooooo0000o`000004oooo
o`;o00001oooool2o`0000Gooooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`1Jooooo`?o
00003Oooool2o`0000?ooooo0_l00003ooooo`Co00001_ooool4o`0000Kooooo1?l0000Eooooo`;o
000000?oooooo`000?l000001_ooool2o`0001?ooooo0_l00007ooooo`;o00000_ooool2o`0000Go
oooo0_l00007ooooo`Co00001Oooool2o`00063ooooo000Looooo`03o`000?oooooooooo05[ooooo
1?l0000<ooooo`;o00002_ooool3o`0000Gooooo0_l00004ooooo`;o00000_ooool4o`0000?ooooo
0_l00003ooooo`;o00002oooool5o`0000Kooooo1?l00002ooooo`;o00001?ooool2o`0000Oooooo
0_l000000ooooooo0000o`000006ooooo`Go00001?ooool2o`0000Oooooo1Ol0001Vooooo`007?oo
ool00ol0003oooooooooo`1Looooo`;o00002oooool2o`0000Cooooo0_l00005ooooo`?o00002_oo
ool6o`000003ooooool0003o000000?ooooo0_l00003ooooo`;o00001oooool2o`0000?ooooo1?l0
0008ooooo`;o00000_ooool2o`0000Cooooo0_l00006ooooo`;o00000_ooool2o`0000Kooooo0_l0
00000ooooooo0000o`00000@ooooo`;o0000I_ooool001cooooo00?o0000ooooooooool0Hoooool2
o`0000Cooooo0ol000000ooooooo0000o`000002o`0000Gooooo0_l0000;ooooo`Ko000000?ooooo
o`000?l000001?ooool2o`0000_ooooo0_l00004ooooo`;o000000?oooooo`000?l000000_ooool2
o`0000;ooooo0_l00008ooooo`;o00001_ooool2o`0000Kooooo0_l0000Cooooo`;o0000J_ooool0
01cooooo00?o0000ooooooooool0Hoooool2o`0000Gooooo0_l000000ooooooo0000o`000002o`00
01gooooo1?l000000ooooooo0000o`000008ooooo`Co00001Oooool2o`0000;ooooo0_l00006oooo
o`;o00005?ooool2o`0000;ooooo0_l00002ooooo`;o00002oooool2o`0000;ooooo1?l0001Toooo
o`007?ooool00ol0003oooooooooo`1Qooooo`;o00003?ooool2o`0000cooooo0_l0000:ooooo`;o
00000oooool2o`0000?ooooo0_l00008ooooo`Go00004?ooool2o`0001Sooooo0_l00002ooooo`;o
00003oooool4o`0000[ooooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o0000
1_ooool3o`0000oooooo0_l00003ooooo`;o00000oooool3o`0000[ooooo0_l0000;ooooo`;o0000
1oooool4o`0000Gooooo0_l00006ooooo`;o00007Oooool4o`0000Gooooo0_l00002ooooo`;o0000
4Oooool2o`0005Sooooo000Looooo`03o`000?oooooooooo05Sooooo0_l00006ooooo`;o00004?oo
ool2o`0000;ooooo1?l00002ooooo`;o00000_ooool2o`0001Cooooo0_l00006ooooo`Go00001Ooo
ool2o`0000Kooooo0_l0000;ooooo`;o00001Oooool4o`0000Oooooo1?l00005ooooo`;o00000_oo
ool2o`0006_ooooo000Looooo`03o`000?oooooooooo07Kooooo1Ol000000ooooooo0000o`000002
ooooo`;o00001oooool3o`0000Gooooo1ol00006ooooo`Ko000000?oooooo`000?l000001oooool2
o`0000gooooo0_l00005ooooo`Co00005Oooool2o`0006[ooooo000Looooo`03o`000?oooooooooo
063ooooo0_l0000Gooooo`;o00000_ooool2o`000003ooooool0003o000000Oooooo0ol00003oooo
o`So00001_ooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool2o`00
01Kooooo0_l0000Booooo`;o000000?oooooo`000?l00000J_ooool001cooooo00?o0000oooooooo
ool0H?ooool2o`0000gooooo0_l0000<ooooo`;o000000?oooooo`000?l000002?ooool2o`0000?o
oooo0_l00004ooooo`?o00001Oooool5o`0000?ooooo0_l00002ooooo`;o00001?ooool2o`0000;o
oooo0_l0000Aooooo`;o00002?ooool2o`0000Sooooo0_l00008ooooo`Co0000HOooool001cooooo
00?o0000ooooooooool0Joooool2o`0000;ooooo0_l00006ooooo`Co00003oooool2o`0000;ooooo
0_l00006ooooo`;o00001?ooool2o`000004ooooool0003o0000o`0000gooooo0_l00002ooooo`?o
00002Oooool2o`000003ooooool0003o000000?ooooo0_l00007ooooo`;o00001_ooool2o`0000[o
oooo1?l0001Qooooo`007?ooool00ol0003oooooooooo`1Xooooo`;o000000?oooooo`000?l00000
2_ooool4o`0000kooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l00005ooooo`Co0000
0oooool2o`0000Gooooo0_l00004ooooo`?o00000oooool7o`0000Cooooo0_l000001?oooooo0000
o`000?ooool4o`0000?ooooo0_l0000:ooooo`;o0000Koooool00006ooooooo^k^ko<S8bo`000?lb
<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooo
oooo06Sooooo0_l0000Nooooo`?o00000oooool2o`000003ooooool0003o000000;o000000?ooooo
o`000?l000000_ooool2o`0000Cooooo0ol00005ooooo`;o00001?ooool4o`0000;ooooo1ol0000:
ooooo`;o00001Oooool2o`0000[ooooo0_l0001_ooooo`0000KoooooogMgMonHV9SooooooiRHV?mg
MgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0
R?ooool2o`0000Kooooo1Ol000000ooooooo0000o`000003ooooo`;o00000oooool2o`0000kooooo
0_l00002ooooo`;o00000oooool2o`0001Gooooo0_l000000ooooooo0000o`000003ooooo`;o0000
00?oooooo`000?l00000K?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0T?ooool5o`000005oooo
ool0003o0000o`000?ooool00ol00005ooooo`;o00000_ooool2o`0000cooooo0_l00003ooooo`;o
00000_ooool2o`00017ooooo0_l000000ooooooo0000o`000006ooooo`;o0000K?ooool00003oooo
ool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Olb<S;oV9RHoooooonHV9So<S8b00Ko
oooo0ol00020ooooo`;o00004?ooool2o`0000;ooooo1_l000000ooooooo0000o`000003ooooo`;o
00000_ooool2o`0000Cooooo0_l0000;ooooo`;o00000_ooool2o`0000Sooooo0_l000000ooooooo
0000o`000004ooooo`;o0000Moooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
2Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0MOooool2o`0000Wo
oooo0_l0000Fooooo`?o000000Coooooo`000?l0003o00000_ooool2o`0000Oooooo1?l00002oooo
o`;o00003Oooool2o`0000Kooooo1Ol00006ooooo`;o0000MOooool00003ooooool@413ooooo00;o
oooo00?o410@ooooooooool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000oooo
ooooool0MOooool2o`0000Wooooo0_l0000Jooooo`;o00000oooool2o`0000Oooooo0_l00002oooo
o`Co00002oooool5o`0000Kooooo1?l00006ooooo`;o0000MOooool00006oooooomgMgOoV9RHoooo
oonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0I_oo
ool2o`0001Sooooo0_l0000Jooooo`;o00004?ooool2o`0000Cooooo1?l00004ooooo`?o000000?o
ooooo`000?l00000Qoooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@
o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0I_ooool2o`0000Sooooo0_l0000Xooooo`?o
00005Oooool6o`0000;ooooo1?l0002;ooooo`007?ooool00ol0003oooooooooo`1`ooooo`;o0000
1_ooool2o`00017ooooo0_l0000=ooooo`?o00002Oooool2o`0000Cooooo0_l00004ooooo`;o0000
00?oooooo`000?l000000oooool2o`0008gooooo000Looooo`03o`000?oooooooooo05Kooooo0_l0
000Pooooo`;o00004Oooool2o`0001Wooooo0_l00003ooooo`?o000000?oooooo`000?l000001?oo
ool3o`0001_ooooo0_l0001dooooo`007?ooool00ol0003oooooooooo`1Fooooo`;o00009?ooool2
o`0001Cooooo0_l0000=ooooo`;o00000_ooool2o`0000Cooooo0_l00002ooooo`Ko000000?ooooo
o`000?l000003_ooool2o`0000_ooooo0_l0001dooooo`007?ooool00ol0003oooooooooo`1loooo
o`;o00005?ooool2o`0000Cooooo0_l00007ooooo`;o00000_ooool2o`0000[ooooo1?l0000Aoooo
o`;o0000POooool001cooooo00?o0000ooooooooool0V?ooool2o`0000cooooo0_l0000Looooo`;o
00003_ooool2o`0007?ooooo000Looooo`03o`000?oooooooooo0:Kooooo0_l0000Looooo`;o0000
3_ooool2o`0007?ooooo000Looooo`03o`000?oooooooooo08Wooooo0_l0000Fooooo`;o00004?oo
ool2o`0001cooooo1?l0001dooooo`007?ooool00ol0003oooooooooo`21ooooo`;o00001_ooool2
o`0000Cooooo0_l0000@ooooo`;o00004?ooool2o`0001cooooo1?l0001dooooo`007?ooool00ol0
003oooooooooo`1_ooooo`?o00003oooool2o`0000cooooo0_l0000Fooooo`;o00006oooool2o`00
08?ooooo000Looooo`03o`000?oooooooooo06oooooo0ol0000Mooooo`;o00002Oooool2o`0000Co
oooo0_l00005ooooo`;o00000oooool2o`0001Kooooo0_l00023ooooo`007?ooool00ol0003ooooo
ooooo`27ooooo`;o00004Oooool2o`0000Cooooo0_l00005ooooo`;o00000oooool2o`0002Kooooo
0_l0001cooooo`007?ooool2o`0008Sooooo0_l0000=ooooo`;o00000_ooool2o`0000;ooooo0_l0
0007ooooo`?o00002_ooool4o`0001cooooo0_l0001cooooo`007?ooool00ol0003oooooooooo`1a
ooooo`;o00000_ooool2o`0001oooooo0_l00003ooooo`;o000000?oooooo`000?l000002?ooool2
o`0000[ooooo1?l0002Aooooo`007?ooool00ol0003oooooooooo`1`ooooo`?o00000_ooool2o`00
02Cooooo0_l0000Dooooo`;o0000U_ooool001cooooo00?o0000ooooooooool0J_ooool2o`0000Co
oooo0_l00007ooooo`;o0000=_ooool2o`0000;ooooo0ol00006ooooo`;o0000ROooool001cooooo
00?o0000ooooooooool0J_ooool2o`0000gooooo0_l0000fooooo`;o00000_ooool3o`0000Kooooo
0_l00029ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`1booooo`;o00004?ooool2o`000<?ooooo000Looooo`03o`000?oooooooooo07;ooooo
0_l00004ooooo`;o00002_ooool2o`000<?ooooo000Looooo`03o`000?oooooooooo07Sooooo0_l0
000Nooooo`;o0000[oooool001cooooo00?o0000ooooooooool0V?ooool2o`0000Gooooo0_l0002X
ooooo`007?ooool00ol0003oooooooooo`2>ooooo`;o00003oooool2o`0000Gooooo0_l0002Qoooo
o`007?ooool00ol0003oooooooooo`2>ooooo`;o00005_ooool2o`000:7ooooo000Looooo`03o`00
0?oooooooooo08oooooo0_l0002hooooo`007?ooool00ol0003oooooooooo`2?ooooo`;o0000^?oo
ool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Booooo`Co000000?o410@
ooooooooool00oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`?o
0000oooooom:ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oo
oooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0
003oooooooooo`3ooooooe;ooooo000Booooo`03oeEEEOmVIVKo00000?ooooooE?ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00:7ooooo00Co410@o`000?l0003ooooo0_l00000
0ol@413oooooooooo`0Fooooo`Co000000Co410@oooooooooooooooo1?l000002?l@413ooooooooo
ooo<c<co8B4Qo`000?lQ8B7oc<c<0oooool5o`0008cooooo002Rooooo`05o`000?oooooooooooooo
ool000002Oooool6o`0000cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02oooo
o`05ob4Q8OnHV9SooooooiRHV?lQ8B400oooool01OnHV9So8B4Qonk^k_ooooooA4A408cooooo002R
ooooo`05o`000?ooooooooooooooool000006oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`03oiRHV?lQ8B7ok^k^08gooooo
002Rooooo`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`02ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801Oooool00onHV9So
8B4Qonk^kP2<ooooo`00X_ooool01Ol0003oQhN7oooooonYZJWo000001_ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`02ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00omg
MgOoIVIVooooo`2;ooooo`00XOooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo01Wo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`05oa0@4?nj^[[ooooookZj
^_l@41001oooool00ol0003oooooooooo`2:ooooo`00`_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00Go0000okZj^_oooooo^[Zjo`000003ooooo`05o`000?nj^[[ooooo
oiRHV?l@4100S?ooool00<3ooooo00?oEEEEofIVI_l000001Oooool00omEEEGoIVIVo`000004oooo
o`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01OnHV9So410@o`000?lQ8B7oc<c<08cooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1188) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.58326 .33041 Mdot
.53411 .34778 Mdot
.34309 .55623 Mdot
.65253 .50822 Mdot
.24556 .3507 Mdot
.37033 .56772 Mdot
.42385 .41464 Mdot
.36781 .40464 Mdot
.36033 .54688 Mdot
.43325 .24287 Mdot
.41118 .42199 Mdot
.7098 .5874 Mdot
.3914 .41705 Mdot
.66351 .53066 Mdot
.26238 .26129 Mdot
.58254 .53589 Mdot
.5396 .31356 Mdot
.49541 .65864 Mdot
.68613 .5784 Mdot
.38883 .53261 Mdot
.51154 .31405 Mdot
.65428 .52457 Mdot
.53972 .37957 Mdot
.66395 .53139 Mdot
.62818 .49241 Mdot
.56785 .34863 Mdot
.5334 .39539 Mdot
.6081 .5224 Mdot
.6055 .49923 Mdot
.36879 .41128 Mdot
.58286 .68972 Mdot
.23359 .31401 Mdot
.70376 .55859 Mdot
.22605 .62422 Mdot
.3787 .39018 Mdot
.70887 .42716 Mdot
.35421 .57143 Mdot
.39597 .39592 Mdot
.39876 .39043 Mdot
.42418 .38407 Mdot
.40655 .40594 Mdot
.55875 .36185 Mdot
.34042 .40612 Mdot
.43885 .56698 Mdot
.58502 .55188 Mdot
.30889 .32323 Mdot
.80561 .48313 Mdot
.62508 .5621 Mdot
.55289 .31274 Mdot
.30337 .64873 Mdot
.25319 .44357 Mdot
.42576 .3923 Mdot
.41082 .57138 Mdot
.43245 .89026 Mdot
.38499 .3944 Mdot
.60673 .57905 Mdot
.3449 .5698 Mdot
.65061 .53447 Mdot
.66505 .53611 Mdot
.6298 .32145 Mdot
.61745 .56829 Mdot
.48125 .69956 Mdot
.5789 .30538 Mdot
.52758 .47734 Mdot
.35721 .55465 Mdot
.41143 .39846 Mdot
.53795 .36299 Mdot
.38318 .41176 Mdot
.60069 .47194 Mdot
.3908 .5307 Mdot
.62065 .56029 Mdot
.41406 .40976 Mdot
.5579 .30534 Mdot
.61379 .5393 Mdot
.3858 .7386 Mdot
.4986 .17293 Mdot
.46968 .72079 Mdot
.66964 .39316 Mdot
.62712 .36234 Mdot
.37493 .67228 Mdot
.66861 .50591 Mdot
.6865 .66452 Mdot
.43445 .18754 Mdot
.53119 .38195 Mdot
.66381 .46462 Mdot
.51137 .63489 Mdot
.61894 .53986 Mdot
.34032 .26592 Mdot
.59514 .50689 Mdot
.39923 .76375 Mdot
.37413 .54642 Mdot
.54476 .33453 Mdot
.65396 .50744 Mdot
.59905 .52844 Mdot
.76624 .56512 Mdot
.70129 .53858 Mdot
.62916 .51732 Mdot
.57462 .3278 Mdot
.41908 .38618 Mdot
.65741 .59823 Mdot
.4273 .53394 Mdot
.39348 .595 Mdot
.68373 .55534 Mdot
.38541 .58791 Mdot
.53972 .30269 Mdot
.60748 .5384 Mdot
.39891 .38585 Mdot
.6784 .55514 Mdot
.47405 .32059 Mdot
.53105 .34803 Mdot
.60372 .52161 Mdot
.49966 .68599 Mdot
.69006 .7516 Mdot
.53817 .32777 Mdot
.4132 .66232 Mdot
.65506 .4901 Mdot
.63324 .526 Mdot
.53677 .34808 Mdot
.34646 .60104 Mdot
.36105 .24487 Mdot
.54984 .38638 Mdot
.40899 .37362 Mdot
.58676 .35152 Mdot
.64242 .4581 Mdot
.37452 .55271 Mdot
.24153 .53414 Mdot
.39971 .34075 Mdot
.59071 .66615 Mdot
.62561 .54183 Mdot
.42059 .27992 Mdot
.39441 .55252 Mdot
.54925 .34642 Mdot
.3816 .41481 Mdot
.72255 .55004 Mdot
.52132 .3558 Mdot
.3922 .43138 Mdot
.49554 .69914 Mdot
.29458 .48381 Mdot
.51808 .32545 Mdot
.44261 .5368 Mdot
.37367 .43205 Mdot
.42894 .39358 Mdot
.26951 .70751 Mdot
.54116 .36088 Mdot
.48281 .67721 Mdot
.37401 .41073 Mdot
.56191 .67044 Mdot
.59521 .562 Mdot
.64934 .701 Mdot
.82308 .51152 Mdot
.23556 .64042 Mdot
.31627 .49351 Mdot
.45849 .6795 Mdot
.38691 .37298 Mdot
.62472 .50149 Mdot
.57072 .33663 Mdot
.56164 .36548 Mdot
.63058 .57169 Mdot
.64394 .49835 Mdot
.61282 .55395 Mdot
.59712 .52809 Mdot
.60396 .26061 Mdot
.69128 .52068 Mdot
.79875 .53637 Mdot
.54513 .32933 Mdot
.63805 .50456 Mdot
.34739 .59288 Mdot
.6992 .50177 Mdot
.41036 .40571 Mdot
.6481 .52737 Mdot
.64966 .50688 Mdot
.62334 .572 Mdot
.42311 .38852 Mdot
.28754 .25743 Mdot
.77536 .60164 Mdot
.23785 .33003 Mdot
.43765 .76422 Mdot
.38185 .58038 Mdot
.62252 .53438 Mdot
.49354 .68766 Mdot
.73077 .40739 Mdot
.6762 .52187 Mdot
.83326 .64833 Mdot
.63763 .51768 Mdot
.24942 .32785 Mdot
.56295 .53285 Mdot
.17909 .40227 Mdot
.6571 .68124 Mdot
.61602 .50646 Mdot
.5322 .53558 Mdot
.50159 .40546 Mdot
.42677 .54614 Mdot
.40418 .40814 Mdot
.3439 .59127 Mdot
.34059 .56632 Mdot
.35214 .42448 Mdot
.60596 .34952 Mdot
.56531 .46522 Mdot
.64963 .46853 Mdot
.39644 .53384 Mdot
.56158 .29643 Mdot
.46866 .70706 Mdot
.57887 .35188 Mdot
.49789 .13062 Mdot
.27731 .39511 Mdot
.35161 .39761 Mdot
.45254 .65786 Mdot
.372 .537 Mdot
.38846 .59593 Mdot
.48834 .66487 Mdot
.64858 .55727 Mdot
.54323 .36574 Mdot
.20882 .62657 Mdot
.5583 .24747 Mdot
.2512 .69936 Mdot
.57006 .32181 Mdot
.47057 .25128 Mdot
.39295 .42876 Mdot
.3588 .58282 Mdot
.63135 .52335 Mdot
.64621 .55216 Mdot
.50826 .32481 Mdot
.61524 .55469 Mdot
.66416 .61934 Mdot
.62028 .52008 Mdot
.24942 .48214 Mdot
.48179 .72298 Mdot
.35129 .42253 Mdot
.59338 .65331 Mdot
.55587 .37909 Mdot
.58523 .77036 Mdot
.38621 .59109 Mdot
.71543 .40174 Mdot
.41755 .40909 Mdot
.48902 .70173 Mdot
.39837 .58097 Mdot
.47345 .71125 Mdot
.69831 .56209 Mdot
.33203 .56384 Mdot
.49499 .66798 Mdot
.61077 .38285 Mdot
.59168 .53655 Mdot
.59586 .24601 Mdot
.40217 .37542 Mdot
.55196 .38893 Mdot
.61107 .56343 Mdot
.37735 .58666 Mdot
.71509 .53776 Mdot
.33419 .44871 Mdot
.24515 .52993 Mdot
.35933 .60761 Mdot
.28564 .59595 Mdot
.47404 .70294 Mdot
.31376 .40979 Mdot
.45395 .26852 Mdot
.55206 .30964 Mdot
.69515 .52407 Mdot
.16545 .40889 Mdot
.37419 .41038 Mdot
.67389 .55527 Mdot
.22557 .58176 Mdot
.37841 .40187 Mdot
.64972 .53622 Mdot
.36638 .3923 Mdot
.56043 .36713 Mdot
.70798 .71901 Mdot
.5438 .31303 Mdot
.6061 .49174 Mdot
.39882 .38343 Mdot
.33266 .58937 Mdot
.56734 .33761 Mdot
.6507 .5612 Mdot
.6113 .52679 Mdot
.50255 .47993 Mdot
.63267 .50702 Mdot
.2804 .27555 Mdot
.61595 .51474 Mdot
.34093 .58118 Mdot
.68784 .55977 Mdot
.59563 .83623 Mdot
.33521 .35683 Mdot
.53918 .36372 Mdot
.33408 .5986 Mdot
.35222 .55207 Mdot
.42366 .67646 Mdot
.36353 .36339 Mdot
.66955 .5018 Mdot
.38226 .58225 Mdot
.63742 .74016 Mdot
.39249 .43609 Mdot
.69606 .52211 Mdot
.44852 .53693 Mdot
.31236 .66244 Mdot
.40964 .56596 Mdot
.69692 .57838 Mdot
.52275 .31532 Mdot
.65304 .50565 Mdot
.36893 .60233 Mdot
.50162 .31809 Mdot
.63649 .48056 Mdot
.58179 .29439 Mdot
.50314 .47718 Mdot
.41266 .42985 Mdot
.55999 .52533 Mdot
.66525 .5622 Mdot
.35981 .59008 Mdot
.56163 .37585 Mdot
.38366 .43528 Mdot
.56287 .35243 Mdot
.18352 .47777 Mdot
.47308 .33358 Mdot
.61445 .32113 Mdot
.46757 .64226 Mdot
.28114 .64571 Mdot
.17043 .4343 Mdot
.52122 .80952 Mdot
.5704 .75743 Mdot
.18263 .55479 Mdot
.35446 .59971 Mdot
.24016 .59873 Mdot
.34556 .55933 Mdot
.64074 .48918 Mdot
.36971 .55358 Mdot
.16688 .43382 Mdot
.62164 .51903 Mdot
.36521 .55899 Mdot
.61511 .76768 Mdot
.64321 .50295 Mdot
.53036 .32777 Mdot
.35257 .2133 Mdot
.55315 .82309 Mdot
.24004 .51937 Mdot
.3583 .53267 Mdot
.53908 .75102 Mdot
.62745 .51503 Mdot
.69129 .55993 Mdot
.55598 .31862 Mdot
.6944 .5152 Mdot
.46087 .69561 Mdot
.45407 .65597 Mdot
.49021 .40821 Mdot
.72192 .6495 Mdot
.57551 .55663 Mdot
.56574 .33116 Mdot
.63007 .2613 Mdot
.36806 .73452 Mdot
.2916 .64028 Mdot
.36057 .39489 Mdot
.34541 .22232 Mdot
.70432 .60257 Mdot
.38138 .46821 Mdot
.4293 .58795 Mdot
.535 .33491 Mdot
.2702 .27724 Mdot
.40035 .40633 Mdot
.7585 .34137 Mdot
.53393 .61061 Mdot
.65204 .55492 Mdot
.42056 .41068 Mdot
.61884 .60218 Mdot
.53137 .83005 Mdot
.77303 .33389 Mdot
.70351 .62912 Mdot
.60809 .48777 Mdot
.4035 .74446 Mdot
.64185 .52633 Mdot
.38034 .23811 Mdot
.61327 .51651 Mdot
.56275 .34375 Mdot
.41006 .24033 Mdot
.51162 .43246 Mdot
.78299 .58365 Mdot
.31287 .36113 Mdot
.45833 .68044 Mdot
.62504 .52378 Mdot
.65447 .55471 Mdot
.46308 .69481 Mdot
.51355 .34638 Mdot
.59636 .52926 Mdot
.57022 .7712 Mdot
.61858 .54717 Mdot
.40338 .40035 Mdot
.67394 .63416 Mdot
.59097 .38284 Mdot
.64316 .47153 Mdot
.56582 .30268 Mdot
.41488 .42999 Mdot
.39048 .38854 Mdot
.5839 .56322 Mdot
.43054 .38936 Mdot
.64433 .51566 Mdot
.77796 .33041 Mdot
.52 .32751 Mdot
.58653 .60039 Mdot
.53109 .37486 Mdot
.6626 .39599 Mdot
.38669 .38529 Mdot
.25746 .45806 Mdot
.71686 .57402 Mdot
.39893 .40956 Mdot
.47522 .33617 Mdot
.57518 .53758 Mdot
.59529 .49549 Mdot
.36627 .76319 Mdot
.35024 .54093 Mdot
.51601 .45691 Mdot
.36666 .40253 Mdot
.65601 .56407 Mdot
.66574 .48207 Mdot
.41853 .42739 Mdot
.69987 .27245 Mdot
.59312 .79505 Mdot
.61785 .51736 Mdot
.55768 .33526 Mdot
.55119 .34862 Mdot
.60635 .48619 Mdot
.69149 .5403 Mdot
.38924 .56033 Mdot
.32705 .58348 Mdot
.34955 .53483 Mdot
.50465 .47314 Mdot
.25256 .46834 Mdot
.25014 .3818 Mdot
.42489 .38493 Mdot
.44735 .29463 Mdot
.417 .76947 Mdot
.67601 .478 Mdot
.38777 .53654 Mdot
.67313 .55093 Mdot
.65332 .51343 Mdot
.39704 .43998 Mdot
.22555 .54196 Mdot
.65989 .60803 Mdot
.51225 .33646 Mdot
.37057 .42355 Mdot
.709 .4851 Mdot
.33841 .33241 Mdot
.49663 .68947 Mdot
.28702 .70998 Mdot
.41551 .40647 Mdot
.531 .33187 Mdot
.3793 .38534 Mdot
.6389 .55274 Mdot
.66157 .58708 Mdot
.53902 .34301 Mdot
.46239 .65579 Mdot
.71218 .53081 Mdot
.6466 .53538 Mdot
.82667 .57366 Mdot
.43821 .77477 Mdot
.25737 .48332 Mdot
.61634 .50878 Mdot
.63964 .47373 Mdot
.50274 .70223 Mdot
.62424 .5506 Mdot
.60714 .5532 Mdot
.73244 .70397 Mdot
.41705 .33565 Mdot
.46555 .64745 Mdot
.73794 .30446 Mdot
.56735 .31751 Mdot
.19455 .36654 Mdot
.36212 .58561 Mdot
.37836 .36666 Mdot
.62108 .78838 Mdot
.41178 .57618 Mdot
.32129 .49659 Mdot
.2128 .34365 Mdot
.51536 .45469 Mdot
.31606 .61181 Mdot
.71232 .58956 Mdot
.60085 .53643 Mdot
.63786 .52929 Mdot
.48983 .68934 Mdot
.54734 .36578 Mdot
.51339 .47561 Mdot
.59964 .2082 Mdot
.64931 .52275 Mdot
.61854 .61926 Mdot
.54675 .22789 Mdot
.31752 .66521 Mdot
.46561 .67282 Mdot
.45733 .65649 Mdot
.62819 .5261 Mdot
.70489 .73675 Mdot
.56859 .34616 Mdot
.65246 .56102 Mdot
.67351 .50159 Mdot
.34912 .54018 Mdot
.52635 .34591 Mdot
.35977 .60094 Mdot
.271 .43172 Mdot
.24 .33391 Mdot
.8377 .56275 Mdot
.38746 .38698 Mdot
.44975 .20706 Mdot
.37355 .4214 Mdot
.68375 .6607 Mdot
.39987 .58909 Mdot
.67351 .51368 Mdot
.55916 .37719 Mdot
.66271 .56058 Mdot
.6903 .53291 Mdot
.65117 .55705 Mdot
.66858 .47783 Mdot
.77022 .72463 Mdot
.47673 .65778 Mdot
.60245 .47852 Mdot
.33769 .57249 Mdot
.37727 .22756 Mdot
.48879 .17916 Mdot
.65903 .55075 Mdot
.61628 .52619 Mdot
.51768 .33927 Mdot
.64781 .57204 Mdot
.38317 .43102 Mdot
.5675 .37304 Mdot
.59963 .52648 Mdot
.35625 .22416 Mdot
.60262 .50846 Mdot
.20086 .37341 Mdot
.37406 .38857 Mdot
.50215 .28175 Mdot
.58853 .4923 Mdot
.24803 .5289 Mdot
.516 .45704 Mdot
.39705 .56981 Mdot
.43337 .38717 Mdot
.35434 .56866 Mdot
.65673 .21374 Mdot
.65908 .58332 Mdot
.6255 .49873 Mdot
.67448 .48878 Mdot
.38003 .58196 Mdot
.31654 .28441 Mdot
.30716 .39657 Mdot
.69455 .47442 Mdot
.38357 .57374 Mdot
.57159 .30168 Mdot
.53811 .67404 Mdot
.54241 .37604 Mdot
.44947 .65892 Mdot
.40819 .42274 Mdot
.45406 .6661 Mdot
.21435 .5743 Mdot
.53223 .34633 Mdot
.52103 .38857 Mdot
.36716 .58 Mdot
.48563 .58191 Mdot
.30211 .79546 Mdot
.51868 .60254 Mdot
.62119 .68646 Mdot
.55617 .32118 Mdot
.61529 .48678 Mdot
.66692 .65332 Mdot
.48628 .56171 Mdot
.35379 .56629 Mdot
.67027 .52071 Mdot
.69106 .73561 Mdot
.38968 .56064 Mdot
.69661 .5245 Mdot
.33929 .55729 Mdot
.40837 .41385 Mdot
.38319 .53684 Mdot
.50677 .35428 Mdot
.61044 .53378 Mdot
.25821 .74956 Mdot
.45675 .71914 Mdot
.62321 .51148 Mdot
.3678 .41925 Mdot
.46427 .39582 Mdot
.6853 .53741 Mdot
.49456 .70465 Mdot
.37613 .56015 Mdot
.51418 .6052 Mdot
.61582 .51719 Mdot
.37926 .58044 Mdot
.58566 .33691 Mdot
.41781 .37345 Mdot
.61402 .4333 Mdot
.24892 .52344 Mdot
.55727 .31806 Mdot
.42798 .52206 Mdot
.43793 .41569 Mdot
.64246 .47328 Mdot
.68737 .51269 Mdot
.55621 .34011 Mdot
.72382 .68525 Mdot
.66989 .57004 Mdot
.6689 .50644 Mdot
.33723 .57874 Mdot
.35938 .56598 Mdot
.70942 .70574 Mdot
.34015 .59738 Mdot
.66237 .58612 Mdot
.55743 .34205 Mdot
.65874 .50938 Mdot
.52069 .3366 Mdot
.65818 .56967 Mdot
.48924 .35452 Mdot
.51337 .35229 Mdot
.3303 .37292 Mdot
.6642 .51662 Mdot
.5619 .5435 Mdot
.67935 .55165 Mdot
.61282 .54831 Mdot
.38736 .55653 Mdot
.47975 .66686 Mdot
.67806 .58991 Mdot
.44699 .70245 Mdot
.47483 .71063 Mdot
.47133 .38412 Mdot
.3519 .53823 Mdot
.48026 .68502 Mdot
.56064 .22396 Mdot
.34751 .53792 Mdot
.48159 .69677 Mdot
.48165 .18232 Mdot
.38066 .38889 Mdot
.52235 .31828 Mdot
.64299 .50178 Mdot
.18924 .54112 Mdot
.80818 .48714 Mdot
.40568 .51872 Mdot
.61757 .51355 Mdot
.67874 .54725 Mdot
.54377 .38564 Mdot
.71418 .2349 Mdot
.38574 .52764 Mdot
.61813 .49102 Mdot
.53382 .36053 Mdot
.77528 .29401 Mdot
.34317 .57963 Mdot
.48496 .6949 Mdot
.41544 .38003 Mdot
.56943 .29029 Mdot
.40185 .34162 Mdot
.42209 .41899 Mdot
.41264 .54594 Mdot
.25272 .44966 Mdot
.65581 .4904 Mdot
.39146 .54083 Mdot
.3057 .73632 Mdot
.56675 .25636 Mdot
.44711 .36639 Mdot
.53153 .74936 Mdot
.53643 .33339 Mdot
.38051 .4282 Mdot
.46063 .66478 Mdot
.57244 .32694 Mdot
.5303 .32321 Mdot
.40938 .43793 Mdot
.70774 .45907 Mdot
.45128 .54196 Mdot
.40035 .39413 Mdot
.37428 .75907 Mdot
.2104 .46687 Mdot
.38874 .53658 Mdot
.46254 .69664 Mdot
.20689 .55705 Mdot
.5598 .36108 Mdot
.33993 .22409 Mdot
.30981 .73225 Mdot
.62932 .51724 Mdot
.47773 .68048 Mdot
.29228 .3225 Mdot
.61384 .1978 Mdot
.38014 .39972 Mdot
.50348 .43655 Mdot
.45415 .6888 Mdot
.61536 .56609 Mdot
.54716 .67699 Mdot
.66265 .50414 Mdot
.40117 .42777 Mdot
.62528 .32654 Mdot
.52951 .33185 Mdot
.40925 .44025 Mdot
.2851 .7096 Mdot
.64682 .51702 Mdot
.66719 .51733 Mdot
.58 .64301 Mdot
.57085 .35754 Mdot
.39723 .57078 Mdot
.66289 .49542 Mdot
.64719 .53204 Mdot
.63764 .59072 Mdot
.55815 .52146 Mdot
.68757 .75011 Mdot
.6297 .48712 Mdot
.30048 .37304 Mdot
.63238 .46981 Mdot
.6648 .5221 Mdot
.564 .30114 Mdot
.83926 .59087 Mdot
.27492 .41988 Mdot
.64716 .52863 Mdot
.61788 .4863 Mdot
.41945 .43492 Mdot
.4594 .53954 Mdot
.48105 .58075 Mdot
.50416 .60308 Mdot
.55602 .75532 Mdot
.64691 .46515 Mdot
.53685 .36929 Mdot
.49863 .67366 Mdot
.64164 .47889 Mdot
.53435 .36705 Mdot
.6146 .5709 Mdot
.39044 .56248 Mdot
.34176 .54459 Mdot
.48405 .32228 Mdot
.4768 .69024 Mdot
.59294 .62609 Mdot
.43464 .30183 Mdot
.33863 .58759 Mdot
.62705 .49622 Mdot
.35557 .37903 Mdot
.37398 .60101 Mdot
.33385 .62532 Mdot
.59854 .45088 Mdot
.57002 .35022 Mdot
.54357 .33151 Mdot
.65188 .70247 Mdot
.30917 .48013 Mdot
.7982 .61237 Mdot
.40891 .41548 Mdot
.67821 .57235 Mdot
.43785 .26926 Mdot
.54104 .32939 Mdot
.66708 .65939 Mdot
.47804 .68461 Mdot
.37756 .40073 Mdot
.29184 .548 Mdot
.51907 .35034 Mdot
.53455 .31533 Mdot
.59283 .51545 Mdot
.65047 .54299 Mdot
.57934 .75676 Mdot
.51785 .69664 Mdot
.41093 .43214 Mdot
.46403 .69826 Mdot
.40348 .57454 Mdot
.62771 .48627 Mdot
.53423 .37984 Mdot
.21916 .50586 Mdot
.62648 .48333 Mdot
.38856 .55461 Mdot
.53986 .33632 Mdot
.46796 .70214 Mdot
.48615 .71156 Mdot
.61354 .54731 Mdot
.63509 .27151 Mdot
.39336 .39969 Mdot
.53232 .32781 Mdot
.33597 .33982 Mdot
.69253 .55597 Mdot
.64279 .54201 Mdot
.57294 .48331 Mdot
.39497 .43812 Mdot
.49716 .26552 Mdot
.44811 .68201 Mdot
.54701 .3611 Mdot
.61342 .50362 Mdot
.4753 .69765 Mdot
.47731 .26514 Mdot
.36173 .60744 Mdot
.37973 .53616 Mdot
.49374 .70685 Mdot
.46993 .67771 Mdot
.49087 .70677 Mdot
.34106 .22225 Mdot
.51959 .37765 Mdot
.70663 .59995 Mdot
.67482 .56969 Mdot
.64298 .68846 Mdot
.72803 .53994 Mdot
.37743 .43355 Mdot
.35137 .54103 Mdot
.68791 .54187 Mdot
.61171 .48724 Mdot
.56668 .50431 Mdot
.60936 .61024 Mdot
.57827 .3961 Mdot
.5293 .34695 Mdot
.64672 .58084 Mdot
.33847 .55359 Mdot
.5182 .12551 Mdot
.15901 .54229 Mdot
.58055 .50954 Mdot
.46072 .57222 Mdot
.53265 .38 Mdot
.43398 .41195 Mdot
.49875 .61387 Mdot
.38625 .38218 Mdot
.54691 .35652 Mdot
.62989 .48639 Mdot
.44495 .302 Mdot
.4978 .70468 Mdot
.6373 .56497 Mdot
.38362 .425 Mdot
.62404 .56281 Mdot
.42287 .41747 Mdot
.18062 .45638 Mdot
.4414 .79066 Mdot
.63651 .51792 Mdot
.6079 .47684 Mdot
.52302 .76381 Mdot
.66246 .55022 Mdot
.49357 .73769 Mdot
.52911 .37883 Mdot
.76615 .62135 Mdot
.58913 .54006 Mdot
.7102 .33759 Mdot
.69572 .55287 Mdot
.66071 .74814 Mdot
.64379 .54483 Mdot
.32189 .67749 Mdot
.60476 .52658 Mdot
.60627 .54819 Mdot
.39492 .38238 Mdot
.41553 .43672 Mdot
.5631 .30589 Mdot
.38332 .58364 Mdot
.21938 .348 Mdot
.64496 .53767 Mdot
.24292 .52946 Mdot
.4517 .32387 Mdot
.46798 .67764 Mdot
.54963 .35845 Mdot
.71338 .22729 Mdot
.37356 .38426 Mdot
.46316 .76677 Mdot
.6697 .73156 Mdot
.35559 .34541 Mdot
.51083 .63147 Mdot
.40388 .23697 Mdot
.47758 .70331 Mdot
.62996 .57329 Mdot
.22546 .53086 Mdot
.32332 .69611 Mdot
.59803 .45009 Mdot
.43414 .42721 Mdot
.72249 .39123 Mdot
.21736 .52536 Mdot
.45432 .70071 Mdot
.45127 .67019 Mdot
.42855 .40287 Mdot
.29418 .55456 Mdot
.62845 .60613 Mdot
.47491 .68454 Mdot
.33626 .58914 Mdot
.37201 .5252 Mdot
.40983 .59154 Mdot
.56631 .35636 Mdot
.252 .67195 Mdot
.3462 .314 Mdot
.41896 .42249 Mdot
.30823 .59398 Mdot
.5779 .38622 Mdot
.51489 .37686 Mdot
.36062 .57748 Mdot
.38499 .54919 Mdot
.51396 .32437 Mdot
.61124 .57916 Mdot
.56566 .5227 Mdot
.64737 .52474 Mdot
.49224 .67961 Mdot
.64784 .54798 Mdot
.38475 .56746 Mdot
.38167 .40293 Mdot
.3759 .54239 Mdot
.36256 .39645 Mdot
.26294 .37343 Mdot
.63733 .56047 Mdot
.60916 .53152 Mdot
.81361 .46895 Mdot
.57772 .31878 Mdot
.2925 .37383 Mdot
.25046 .51352 Mdot
.34327 .56178 Mdot
.60838 .55587 Mdot
.56475 .37838 Mdot
.4458 .68893 Mdot
.81675 .45583 Mdot
.68953 .54837 Mdot
.53122 .37803 Mdot
.6149 .49824 Mdot
.58917 .26301 Mdot
.65828 .79959 Mdot
.5598 .35226 Mdot
.82186 .51016 Mdot
.60962 .49461 Mdot
.48211 .21509 Mdot
.67649 .49337 Mdot
.64534 .72719 Mdot
.6707 .5695 Mdot
.5691 .31966 Mdot
.65134 .52812 Mdot
.57252 .36301 Mdot
.34707 .59041 Mdot
.4327 .40124 Mdot
.54871 .3195 Mdot
.67777 .50189 Mdot
.10063 .55216 Mdot
.40025 .42534 Mdot
.62862 .52372 Mdot
.40926 .37961 Mdot
.54526 .36996 Mdot
.54763 .31454 Mdot
.58015 .1919 Mdot
.27614 .42833 Mdot
.40748 .41352 Mdot
.62333 .48952 Mdot
.35436 .28871 Mdot
.65944 .50541 Mdot
.6017 .73664 Mdot
.60346 .57827 Mdot
.68382 .5628 Mdot
.50568 .17383 Mdot
.4015 .43659 Mdot
.79072 .63354 Mdot
.56688 .18781 Mdot
.3866 .21688 Mdot
.55149 .28657 Mdot
.45167 .69812 Mdot
.27812 .26854 Mdot
.25619 .46247 Mdot
.38207 .57752 Mdot
.68444 .54679 Mdot
.59293 .37137 Mdot
.3922 .39381 Mdot
.48237 .66611 Mdot
.63584 .51843 Mdot
.38303 .5457 Mdot
.5512 .80227 Mdot
.38029 .37504 Mdot
.55736 .36212 Mdot
.51166 .34999 Mdot
.82888 .39008 Mdot
.61476 .50706 Mdot
.60622 .53264 Mdot
.40561 .42548 Mdot
.52471 .23809 Mdot
.47891 .70539 Mdot
.59614 .77838 Mdot
.40657 .41481 Mdot
.48809 .50963 Mdot
.53682 .35794 Mdot
.67702 .549 Mdot
.29826 .29273 Mdot
.39617 .73561 Mdot
.77409 .37751 Mdot
.4932 .68653 Mdot
.59633 .73397 Mdot
.56803 .31755 Mdot
.37849 .41437 Mdot
.29156 .50305 Mdot
.68392 .47846 Mdot
.67437 .54667 Mdot
.59942 .72911 Mdot
.51813 .42381 Mdot
.6971 .63073 Mdot
.6916 .54888 Mdot
.52821 .44093 Mdot
.67512 .5636 Mdot
.70182 .49054 Mdot
.64098 .58755 Mdot
.63253 .54203 Mdot
.53158 .37882 Mdot
.64232 .453 Mdot
.39231 .57137 Mdot
.69085 .6183 Mdot
.4971 .51793 Mdot
.62105 .51438 Mdot
.65274 .49581 Mdot
.77337 .41014 Mdot
.38839 .47687 Mdot
.5458 .32275 Mdot
.50024 .3558 Mdot
.42355 .38128 Mdot
.56529 .51386 Mdot
.38846 .58278 Mdot
.72475 .53075 Mdot
.38506 .55374 Mdot
.54268 .37889 Mdot
.34131 .56998 Mdot
.42333 .3858 Mdot
.37687 .52842 Mdot
.25181 .46911 Mdot
.3712 .40711 Mdot
.57143 .33603 Mdot
.61457 .54078 Mdot
.36791 .41886 Mdot
.58046 .65833 Mdot
.49234 .68126 Mdot
.56301 .18024 Mdot
.59888 .52239 Mdot
.41643 .33851 Mdot
.57336 .28413 Mdot
.37883 .54517 Mdot
.69836 .75836 Mdot
.51238 .347 Mdot
.46894 .64859 Mdot
.55221 .38018 Mdot
.39997 .77669 Mdot
.47727 .67004 Mdot
.46997 .18102 Mdot
.27237 .56276 Mdot
.52329 .70563 Mdot
.60416 .57389 Mdot
.54134 .64013 Mdot
.40708 .56117 Mdot
.39107 .39367 Mdot
.30541 .50382 Mdot
.60883 .55389 Mdot
.48872 .79959 Mdot
.53865 .30088 Mdot
.38549 .58133 Mdot
.38394 .41417 Mdot
.37942 .43327 Mdot
.69396 .53059 Mdot
.34416 .64671 Mdot
.65931 .56616 Mdot
.30105 .46261 Mdot
.56564 .74884 Mdot
.60779 .60257 Mdot
.62101 .52038 Mdot
.35684 .59065 Mdot
.61528 .49782 Mdot
.48171 .64448 Mdot
.24737 .6773 Mdot
.70106 .51547 Mdot
.25067 .5039 Mdot
.44189 .70461 Mdot
.53635 .34434 Mdot
.617 .59618 Mdot
.26253 .46501 Mdot
.61607 .50212 Mdot
.64093 .84536 Mdot
.47909 .6972 Mdot
.2364 .5448 Mdot
.66716 .48003 Mdot
.68098 .51048 Mdot
.52841 .49815 Mdot
.49282 .39734 Mdot
.40253 .73877 Mdot
.66713 .54336 Mdot
.56422 .71124 Mdot
.42439 .40201 Mdot
.6672 .56353 Mdot
.63514 .52812 Mdot
.71559 .45423 Mdot
.37588 .42761 Mdot
.35149 .54913 Mdot
.40984 .57405 Mdot
.34137 .5355 Mdot
.48136 .64685 Mdot
.49651 .45453 Mdot
.65037 .67134 Mdot
.54006 .81977 Mdot
.49438 .66284 Mdot
.59665 .51742 Mdot
.45947 .74039 Mdot
.64093 .48612 Mdot
.46366 .66623 Mdot
.37342 .42356 Mdot
.54365 .32133 Mdot
.45271 .25636 Mdot
.39445 .53409 Mdot
.69412 .51811 Mdot
.46402 .70288 Mdot
.571 .34031 Mdot
.51795 .66797 Mdot
.53944 .35251 Mdot
.40069 .41448 Mdot
.39784 .36785 Mdot
.47401 .66371 Mdot
.53733 .37468 Mdot
.39218 .46094 Mdot
.61848 .2027 Mdot
.65186 .58914 Mdot
.41719 .36586 Mdot
.5827 .33407 Mdot
.50419 .33663 Mdot
.57852 .33721 Mdot
.61863 .55704 Mdot
.46005 .56997 Mdot
.58247 .55196 Mdot
.41097 .43152 Mdot
.34263 .55321 Mdot
.52059 .77907 Mdot
.2376 .42729 Mdot
.43041 .63677 Mdot
.67275 .57487 Mdot
.65015 .51821 Mdot
.62853 .52606 Mdot
.58726 .5249 Mdot
.28939 .46962 Mdot
.66576 .5587 Mdot
.39901 .38152 Mdot
.37991 .56015 Mdot
.62678 .57289 Mdot
.40389 .58882 Mdot
.36159 .25473 Mdot
.49027 .65997 Mdot
.49392 .44053 Mdot
.12437 .45675 Mdot
.5679 .32855 Mdot
.34835 .60246 Mdot
.37908 .57874 Mdot
.49486 .69979 Mdot
.39724 .39746 Mdot
.53977 .3577 Mdot
.6198 .74591 Mdot
.4816 .71019 Mdot
.64972 .52959 Mdot
.46187 .60103 Mdot
.47058 .78985 Mdot
.64224 .57412 Mdot
.68246 .52542 Mdot
.36895 .60661 Mdot
.29066 .61459 Mdot
.28024 .7492 Mdot
.63873 .65279 Mdot
.47657 .66531 Mdot
.47127 .65452 Mdot
.51873 .31812 Mdot
.57802 .5392 Mdot
.41272 .43027 Mdot
.70662 .62175 Mdot
.45848 .42553 Mdot
.60886 .63264 Mdot
.57313 .43105 Mdot
.6859 .55103 Mdot
.68648 .25617 Mdot
.64659 .51513 Mdot
.52953 .38246 Mdot
.55636 .3713 Mdot
.56047 .32853 Mdot
.39072 .39583 Mdot
.68646 .4023 Mdot
.40321 .38401 Mdot
.12542 .47133 Mdot
.56322 .31258 Mdot
.2668 .52267 Mdot
.35493 .58717 Mdot
.58647 .49427 Mdot
.46879 .70139 Mdot
.44615 .41687 Mdot
.60244 .47045 Mdot
.70715 .73813 Mdot
.38827 .57738 Mdot
.57042 .33054 Mdot
.41683 .23175 Mdot
.15381 .46808 Mdot
.48824 .59288 Mdot
.72365 .50303 Mdot
.53584 .62719 Mdot
.46531 .67914 Mdot
.77777 .38241 Mdot
.45895 .69545 Mdot
.37803 .42136 Mdot
.61336 .53159 Mdot
.62027 .5401 Mdot
.67104 .56683 Mdot
.65135 .55973 Mdot
.43576 .40759 Mdot
.70214 .54693 Mdot
.59555 .83624 Mdot
.33349 .55645 Mdot
.61365 .36901 Mdot
.47647 .7004 Mdot
.44075 .41139 Mdot
.38124 .56121 Mdot
.37234 .48375 Mdot
.60302 .65587 Mdot
.61702 .51799 Mdot
.68679 .54455 Mdot
.46014 .76977 Mdot
.69205 .54927 Mdot
.72938 .54323 Mdot
.38034 .57961 Mdot
.43176 .63904 Mdot
.46996 .65204 Mdot
.46173 .65948 Mdot
.37125 .39832 Mdot
.54363 .37813 Mdot
.48486 .6883 Mdot
.34416 .58658 Mdot
.67336 .57543 Mdot
.66347 .49228 Mdot
.58149 .33142 Mdot
.31794 .74052 Mdot
.45362 .69642 Mdot
.39124 .24211 Mdot
.56186 .37384 Mdot
.55351 .3953 Mdot
.67513 .54537 Mdot
.54928 .49675 Mdot
.57367 .29205 Mdot
.49515 .6621 Mdot
.44066 .40806 Mdot
.5102 .61464 Mdot
.39574 .43123 Mdot
.55407 .36797 Mdot
.63989 .47993 Mdot
.56155 .36835 Mdot
.61538 .51027 Mdot
.16253 .37368 Mdot
.62899 .54407 Mdot
.53874 .82416 Mdot
.63774 .71166 Mdot
.37137 .56984 Mdot
.4556 .41031 Mdot
.36424 .58403 Mdot
.56415 .37216 Mdot
.65203 .48334 Mdot
.44907 .6719 Mdot
.4243 .19797 Mdot
.57661 .38977 Mdot
.39245 .55661 Mdot
.36359 .52127 Mdot
.37257 .41894 Mdot
.65281 .57617 Mdot
.67206 .55011 Mdot
.36371 .56065 Mdot
.6148 .60618 Mdot
.52033 .35947 Mdot
.61358 .52597 Mdot
.65834 .521 Mdot
.36968 .57204 Mdot
.63369 .20536 Mdot
.49165 .38397 Mdot
.62123 .53455 Mdot
.2582 .56428 Mdot
.38007 .43582 Mdot
.59589 .56826 Mdot
.61982 .46838 Mdot
.47154 .67967 Mdot
.61679 .41788 Mdot
.23637 .65038 Mdot
.3641 .40739 Mdot
.36703 .58868 Mdot
.61357 .50642 Mdot
.35894 .59045 Mdot
.67278 .49967 Mdot
.56613 .4191 Mdot
.39919 .56021 Mdot
.67579 .51012 Mdot
.57945 .5621 Mdot
.57051 .35962 Mdot
.68687 .54772 Mdot
.77684 .44496 Mdot
.38537 .59522 Mdot
.68418 .51525 Mdot
.63399 .27394 Mdot
.4065 .39599 Mdot
.57712 .55549 Mdot
.49741 .6751 Mdot
.62082 .74735 Mdot
.40089 .31364 Mdot
.22614 .54804 Mdot
.48635 .65893 Mdot
.62833 .56489 Mdot
.3543 .52537 Mdot
.42661 .4105 Mdot
.56507 .81802 Mdot
.62701 .57009 Mdot
.39983 .42772 Mdot
.38123 .40492 Mdot
.4963 .6878 Mdot
.83907 .52366 Mdot
.66541 .47689 Mdot
.65768 .55023 Mdot
.75411 .46694 Mdot
.58729 .34515 Mdot
.63893 .54836 Mdot
.60333 .49827 Mdot
.40277 .38115 Mdot
.73156 .54045 Mdot
.74304 .39048 Mdot
.62558 .76375 Mdot
.37565 .4351 Mdot
.50983 .57886 Mdot
.3964 .54129 Mdot
.471 .69609 Mdot
.54223 .34439 Mdot
.45931 .69971 Mdot
.37342 .52974 Mdot
.59797 .51221 Mdot
.39398 .37558 Mdot
.79128 .48674 Mdot
.42898 .40375 Mdot
.22495 .55687 Mdot
.58613 .34421 Mdot
.41487 .27298 Mdot
.69779 .80314 Mdot
.33121 .31957 Mdot
.38375 .47301 Mdot
.46834 .67743 Mdot
.38358 .50048 Mdot
.6559 .51952 Mdot
.7902 .40465 Mdot
.61109 .543 Mdot
.63788 .28166 Mdot
.33288 .58188 Mdot
.3494 .53486 Mdot
.61686 .53271 Mdot
.57472 .74626 Mdot
.4276 .41166 Mdot
.39459 .4365 Mdot
.68873 .52305 Mdot
.39944 .40959 Mdot
.65442 .54275 Mdot
.38645 .56042 Mdot
.78669 .65922 Mdot
.64156 .52264 Mdot
.60434 .48372 Mdot
.40644 .34804 Mdot
.52552 .18236 Mdot
.25675 .62706 Mdot
.74559 .29457 Mdot
.15402 .49542 Mdot
.39826 .40997 Mdot
.58205 .55574 Mdot
.51177 .58066 Mdot
.4086 .58327 Mdot
.39381 .46472 Mdot
.62551 .54904 Mdot
.62317 .55084 Mdot
.60421 .54535 Mdot
.66697 .51562 Mdot
.77697 .37331 Mdot
.75013 .56575 Mdot
.6452 .33971 Mdot
.69058 .5363 Mdot
.55128 .6458 Mdot
.36946 .3963 Mdot
.51773 .30791 Mdot
.50868 .70622 Mdot
.68555 .55117 Mdot
.72802 .58728 Mdot
.40671 .44206 Mdot
.12505 .47302 Mdot
.36929 .40988 Mdot
.35223 .5526 Mdot
.4329 .41197 Mdot
.63085 .50679 Mdot
.55142 .3479 Mdot
.50038 .55231 Mdot
.31318 .41552 Mdot
.38288 .57692 Mdot
.62286 .51163 Mdot
.2629 .51656 Mdot
.39043 .57257 Mdot
.35691 .25784 Mdot
.54765 .3429 Mdot
.56677 .7038 Mdot
.55848 .37114 Mdot
.67477 .50806 Mdot
.66961 .50447 Mdot
.44003 .37958 Mdot
.43101 .39813 Mdot
.55669 .37234 Mdot
.84455 .53504 Mdot
.47064 .71109 Mdot
.56339 .3336 Mdot
.71616 .52009 Mdot
.44648 .48973 Mdot
.55311 .34085 Mdot
.445 .63123 Mdot
.38389 .39378 Mdot
.54336 .30675 Mdot
.69708 .4902 Mdot
.32343 .72832 Mdot
.50326 .68113 Mdot
.32524 .6041 Mdot
.459 .61234 Mdot
.37663 .59936 Mdot
.4361 .39294 Mdot
.36706 .58199 Mdot
.4234 .39859 Mdot
.42519 .32358 Mdot
.66128 .62701 Mdot
.36151 .37495 Mdot
.43653 .39704 Mdot
.3672 .57937 Mdot
.60894 .52584 Mdot
.47891 .61545 Mdot
.58612 .56055 Mdot
.67201 .47804 Mdot
.42038 .40269 Mdot
.57119 .32527 Mdot
.50674 .339 Mdot
.54909 .66746 Mdot
.51497 .36127 Mdot
.38539 .55236 Mdot
.62691 .81311 Mdot
.23543 .52268 Mdot
.41518 .41725 Mdot
.43358 .41931 Mdot
.65856 .50276 Mdot
.35401 .5681 Mdot
.35553 .59385 Mdot
.37903 .4249 Mdot
.57605 .59837 Mdot
.58513 .50821 Mdot
.50307 .3604 Mdot
.55458 .30815 Mdot
.5594 .34663 Mdot
.57819 .34247 Mdot
.73437 .35166 Mdot
.37867 .39581 Mdot
.57394 .33383 Mdot
.68062 .51529 Mdot
.62518 .55073 Mdot
.50145 .59117 Mdot
.46762 .65659 Mdot
.61117 .56843 Mdot
.64005 .58652 Mdot
.67873 .54487 Mdot
.38342 .5383 Mdot
.59033 .4627 Mdot
.39983 .56298 Mdot
.3349 .54792 Mdot
.32837 .57325 Mdot
.25478 .46528 Mdot
.5224 .72576 Mdot
.17169 .52353 Mdot
.61708 .49169 Mdot
.54527 .2395 Mdot
.34981 .57872 Mdot
.70114 .74962 Mdot
.49958 .26255 Mdot
.61529 .56367 Mdot
.3773 .72949 Mdot
.36406 .56301 Mdot
.51251 .35595 Mdot
.62673 .54757 Mdot
.32451 .56604 Mdot
.50055 .6799 Mdot
.68782 .57445 Mdot
.40098 .58594 Mdot
.53836 .37337 Mdot
.51128 .68878 Mdot
.55633 .30668 Mdot
.32906 .57545 Mdot
.57833 .55915 Mdot
.35139 .84072 Mdot
.37108 .51772 Mdot
.54903 .21194 Mdot
.49332 .32272 Mdot
.61176 .52631 Mdot
.35663 .60378 Mdot
.58164 .36674 Mdot
.42627 .37999 Mdot
.45767 .43965 Mdot
.52451 .32404 Mdot
.35157 .53301 Mdot
.39472 .59228 Mdot
.38147 .57899 Mdot
.52868 .34135 Mdot
.60627 .48519 Mdot
.5229 .33883 Mdot
.43266 .41378 Mdot
.64962 .50363 Mdot
.16978 .4306 Mdot
.54762 .24233 Mdot
.55958 .37344 Mdot
.3568 .5433 Mdot
.50198 .70113 Mdot
.63852 .51478 Mdot
.58269 .23172 Mdot
.60746 .51816 Mdot
.42195 .41271 Mdot
.74736 .68037 Mdot
.79452 .46958 Mdot
.67535 .56862 Mdot
.65941 .50355 Mdot
.40338 .43491 Mdot
.62737 .51646 Mdot
.66692 .57166 Mdot
.26197 .45347 Mdot
.52674 .34986 Mdot
.65296 .52599 Mdot
.33586 .56778 Mdot
.24328 .45894 Mdot
.58559 .51433 Mdot
.41642 .67208 Mdot
.57339 .7186 Mdot
.76783 .63786 Mdot
.60899 .54118 Mdot
.62636 .64398 Mdot
.67238 .52299 Mdot
.63861 .56391 Mdot
.64119 .49101 Mdot
.78945 .37402 Mdot
.39634 .55463 Mdot
.38002 .57256 Mdot
.50233 .67496 Mdot
.57106 .71711 Mdot
.47561 .68021 Mdot
.38404 .39139 Mdot
.38296 .6608 Mdot
.39913 .56119 Mdot
.54198 .37531 Mdot
.64255 .56684 Mdot
.36997 .51728 Mdot
.67435 .55162 Mdot
.62926 .50551 Mdot
.3853 .58806 Mdot
.40108 .54957 Mdot
.23215 .54475 Mdot
.49478 .66668 Mdot
.55547 .3242 Mdot
.60811 .57008 Mdot
.4682 .70574 Mdot
.62471 .4768 Mdot
.64721 .68617 Mdot
.55659 .32715 Mdot
.52496 .34662 Mdot
.50842 .3406 Mdot
.59833 .51197 Mdot
.63176 .5104 Mdot
.40626 .38511 Mdot
.55122 .37875 Mdot
.40632 .39808 Mdot
.501 .48837 Mdot
.43057 .71313 Mdot
.62541 .54911 Mdot
.40352 .24158 Mdot
.4662 .6907 Mdot
.36941 .54428 Mdot
.48439 .77944 Mdot
.50329 .67685 Mdot
.61405 .51319 Mdot
.36307 .59363 Mdot
.46409 .66342 Mdot
.60234 .44315 Mdot
.17618 .59585 Mdot
.50446 .70411 Mdot
.68291 .51775 Mdot
.73698 .5361 Mdot
.76078 .30493 Mdot
.50629 .67966 Mdot
.41002 .37763 Mdot
.59829 .51368 Mdot
.59088 .31317 Mdot
.45286 .69258 Mdot
.30184 .36569 Mdot
.37351 .56057 Mdot
.27295 .68614 Mdot
.60501 .46402 Mdot
.80452 .46546 Mdot
.45641 .68199 Mdot
.54275 .35899 Mdot
.50145 .31902 Mdot
.6765 .53809 Mdot
.50658 .68088 Mdot
.38134 .44018 Mdot
.37423 .55377 Mdot
.27252 .42391 Mdot
.52816 .33893 Mdot
.39325 .26406 Mdot
.36151 .53795 Mdot
.38341 .25013 Mdot
.68293 .73542 Mdot
.5688 .53853 Mdot
.75446 .30623 Mdot
.30318 .52282 Mdot
.59252 .52527 Mdot
.48203 .71528 Mdot
.36468 .41081 Mdot
.40535 .37423 Mdot
.4029 .41702 Mdot
.44416 .32363 Mdot
.49934 .6018 Mdot
.34221 .60195 Mdot
.33806 .43463 Mdot
.47317 .69537 Mdot
.55685 .63332 Mdot
.6695 .49223 Mdot
.64865 .51908 Mdot
.65428 .5768 Mdot
.678 .55916 Mdot
.67127 .52853 Mdot
.40092 .40222 Mdot
.41105 .32948 Mdot
.51172 .60193 Mdot
.55525 .33323 Mdot
.33646 .63684 Mdot
.35416 .58625 Mdot
.33682 .60061 Mdot
.47412 .65962 Mdot
.38084 .23973 Mdot
.40353 .58853 Mdot
.34125 .56624 Mdot
.59595 .54227 Mdot
.51978 .3502 Mdot
.71087 .49411 Mdot
.66953 .50797 Mdot
.37945 .55024 Mdot
.52153 .4984 Mdot
.76008 .40223 Mdot
.59527 .45611 Mdot
.43537 .66473 Mdot
.46357 .56175 Mdot
.50584 .69488 Mdot
.65294 .48124 Mdot
.71042 .74119 Mdot
.37681 .53073 Mdot
.35204 .55916 Mdot
.45826 .68315 Mdot
.58606 .4053 Mdot
.53729 .33701 Mdot
.36252 .47743 Mdot
.41473 .3831 Mdot
.65238 .49047 Mdot
.54714 .79823 Mdot
.60693 .34969 Mdot
.34739 .65097 Mdot
.40569 .41926 Mdot
.35065 .59054 Mdot
.67162 .57346 Mdot
.68268 .5187 Mdot
.46207 .68678 Mdot
.21769 .39392 Mdot
.66239 .58248 Mdot
.37336 .21886 Mdot
.43957 .79137 Mdot
.32394 .73841 Mdot
.67412 .54679 Mdot
.52746 .34816 Mdot
.40051 .58874 Mdot
.46252 .69619 Mdot
.70815 .51394 Mdot
.17453 .56863 Mdot
.5731 .31748 Mdot
.3768 .41699 Mdot
.50636 .53683 Mdot
.49672 .61156 Mdot
.59645 .52739 Mdot
.6121 .54241 Mdot
.62701 .55945 Mdot
.20826 .65081 Mdot
.38681 .54452 Mdot
.5382 .38101 Mdot
.49413 .67729 Mdot
.51867 .36891 Mdot
.37485 .57381 Mdot
.39739 .27082 Mdot
.60566 .52386 Mdot
.57459 .3184 Mdot
.54276 .35663 Mdot
.37064 .41429 Mdot
.41694 .37349 Mdot
.50316 .51084 Mdot
.63154 .54418 Mdot
.37959 .51947 Mdot
.57375 .34627 Mdot
.46589 .60144 Mdot
.476 .67096 Mdot
.38902 .38547 Mdot
.68967 .54028 Mdot
.39081 .54233 Mdot
.70316 .54532 Mdot
.54354 .32872 Mdot
.34131 .56763 Mdot
.23798 .53805 Mdot
.47764 .65496 Mdot
.64031 .55548 Mdot
.50416 .66429 Mdot
.36714 .58913 Mdot
.65768 .51882 Mdot
.44527 .21375 Mdot
.43346 .68211 Mdot
.30563 .4081 Mdot
.3318 .58647 Mdot
.24537 .52788 Mdot
.51682 .32539 Mdot
.46905 .31107 Mdot
.35333 .55531 Mdot
.40668 .23201 Mdot
.2187 .42125 Mdot
.65376 .57924 Mdot
.56112 .35783 Mdot
.34723 .49967 Mdot
.19054 .36556 Mdot
.63209 .21231 Mdot
.63014 .52472 Mdot
.33906 .59686 Mdot
.45992 .67999 Mdot
.41678 .41574 Mdot
.41865 .67958 Mdot
.43326 .66885 Mdot
.38082 .52423 Mdot
.6406 .49008 Mdot
.5431 .36703 Mdot
.38587 .39747 Mdot
.40618 .31663 Mdot
.33871 .581 Mdot
.34893 .54568 Mdot
.67247 .57263 Mdot
.47805 .68572 Mdot
.60732 .23237 Mdot
.38711 .56361 Mdot
.45879 .77562 Mdot
.41041 .55306 Mdot
.46942 .70887 Mdot
.6778 .52401 Mdot
.54411 .66987 Mdot
.58547 .54536 Mdot
.50512 .19659 Mdot
.36096 .58301 Mdot
.54874 .32713 Mdot
.61217 .55238 Mdot
.64856 .74741 Mdot
.37562 .54856 Mdot
.46255 .57261 Mdot
.3131 .67071 Mdot
.38109 .39471 Mdot
.48467 .78078 Mdot
.64679 .55059 Mdot
.42748 .41055 Mdot
.46637 .68936 Mdot
.62661 .53814 Mdot
.63413 .50918 Mdot
.54873 .38551 Mdot
.38083 .42495 Mdot
.20374 .45872 Mdot
.41163 .43945 Mdot
.37732 .38655 Mdot
.53355 .38869 Mdot
.66121 .53629 Mdot
.35183 .55167 Mdot
.36212 .56304 Mdot
.69169 .49418 Mdot
.73777 .73175 Mdot
.53486 .33508 Mdot
.30838 .58021 Mdot
.22472 .67309 Mdot
.57086 .55681 Mdot
.49803 .78558 Mdot
.22698 .38116 Mdot
.36684 .42816 Mdot
.69088 .52895 Mdot
.54214 .37244 Mdot
.38209 .49145 Mdot
.35029 .5459 Mdot
.61535 .48075 Mdot
.38638 .40277 Mdot
.50129 .67944 Mdot
.39451 .58545 Mdot
.34971 .64819 Mdot
.64227 .56158 Mdot
.3749 .73195 Mdot
.35387 .60056 Mdot
.30361 .23444 Mdot
.36165 .48922 Mdot
.56317 .35252 Mdot
.63194 .50404 Mdot
.5124 .33679 Mdot
.49081 .67111 Mdot
.50484 .53392 Mdot
.38378 .40244 Mdot
.74931 .54432 Mdot
.54497 .85863 Mdot
.37925 .58131 Mdot
.53004 .37959 Mdot
.67816 .5672 Mdot
.55205 .45696 Mdot
.65302 .54806 Mdot
.7229 .57082 Mdot
.44533 .71692 Mdot
.41735 .40102 Mdot
.42639 .40205 Mdot
.65516 .5133 Mdot
.48248 .70791 Mdot
.34763 .58726 Mdot
.37191 .55111 Mdot
.4388 .15344 Mdot
.34702 .36387 Mdot
.58635 .75518 Mdot
.62713 .55312 Mdot
.3642 .52414 Mdot
.2395 .43423 Mdot
.4063 .4246 Mdot
.67741 .49679 Mdot
.3886 .582 Mdot
.34445 .73515 Mdot
.66023 .72687 Mdot
.67503 .53004 Mdot
.63509 .4653 Mdot
.41274 .38107 Mdot
.56661 .62907 Mdot
.33186 .56497 Mdot
.60787 .58147 Mdot
.37014 .3731 Mdot
.73226 .68198 Mdot
.28507 .72403 Mdot
.55591 .32416 Mdot
.29588 .63483 Mdot
.40058 .40133 Mdot
.6497 .46341 Mdot
.48382 .7005 Mdot
.40554 .57279 Mdot
.39063 .54613 Mdot
.62567 .49079 Mdot
.69988 .5504 Mdot
.50985 .76522 Mdot
.52003 .36705 Mdot
.37058 .39579 Mdot
.60817 .53496 Mdot
.45232 .24793 Mdot
.67343 .56539 Mdot
.40685 .3875 Mdot
.33977 .8409 Mdot
.61731 .57508 Mdot
.65677 .54821 Mdot
.60707 .22949 Mdot
.52694 .32232 Mdot
.5233 .37728 Mdot
.4898 .81753 Mdot
.62816 .55347 Mdot
.47245 .77758 Mdot
.5523 .32148 Mdot
.5374 .33325 Mdot
.27759 .43938 Mdot
.64132 .51714 Mdot
.75888 .57889 Mdot
.42196 .41743 Mdot
.38319 .38245 Mdot
.52472 .33707 Mdot
.63213 .58019 Mdot
.36544 .39092 Mdot
.73633 .31717 Mdot
.35392 .56985 Mdot
.72945 .72423 Mdot
.53322 .32535 Mdot
.51294 .43773 Mdot
.40758 .4211 Mdot
.12581 .46877 Mdot
.41712 .57741 Mdot
.60862 .52758 Mdot
.63616 .55687 Mdot
.46755 .69327 Mdot
.6172 .57411 Mdot
.34565 .53854 Mdot
.39998 .40948 Mdot
.61268 .28515 Mdot
.56119 .32896 Mdot
.64182 .54401 Mdot
.37164 .24846 Mdot
.29541 .35061 Mdot
.26465 .61403 Mdot
.53716 .34519 Mdot
.56544 .35613 Mdot
.33433 .56086 Mdot
.34156 .59821 Mdot
.66906 .53689 Mdot
.39918 .43455 Mdot
.55309 .37794 Mdot
.41452 .39221 Mdot
.37657 .53101 Mdot
.34796 .55402 Mdot
.39768 .55275 Mdot
.69429 .57783 Mdot
.33837 .56897 Mdot
.40069 .64082 Mdot
.384 .26987 Mdot
.51621 .3787 Mdot
.37726 .79476 Mdot
.4163 .31516 Mdot
.47319 .35878 Mdot
.44886 .68209 Mdot
.36766 .58943 Mdot
.42868 .42534 Mdot
.66144 .50977 Mdot
.68129 .54878 Mdot
.36009 .62774 Mdot
.42667 .42225 Mdot
.48498 .66691 Mdot
.42943 .41092 Mdot
.49644 .68828 Mdot
.33564 .70689 Mdot
.64359 .57612 Mdot
.66527 .49488 Mdot
.40374 .40647 Mdot
.3397 .57008 Mdot
.37916 .5652 Mdot
.50817 .69788 Mdot
.54373 .42361 Mdot
.39054 .57358 Mdot
.53641 .32546 Mdot
.72213 .3309 Mdot
.39411 .59321 Mdot
.63138 .54841 Mdot
.65782 .66878 Mdot
.80101 .43812 Mdot
.58723 .52376 Mdot
.27168 .44335 Mdot
.80747 .52386 Mdot
.61822 .56212 Mdot
.82302 .49489 Mdot
.24979 .52291 Mdot
.51639 .33141 Mdot
.33211 .57791 Mdot
.36126 .60885 Mdot
.68101 .59338 Mdot
.49482 .71737 Mdot
.70312 .50542 Mdot
.53515 .31905 Mdot
.55758 .29778 Mdot
.36243 .75772 Mdot
.5422 .20815 Mdot
.46001 .67426 Mdot
.4656 .66012 Mdot
.35681 .55333 Mdot
.60609 .17783 Mdot
.63948 .45564 Mdot
.47883 .66506 Mdot
.62938 .6286 Mdot
.63784 .48815 Mdot
.61234 .7211 Mdot
.43837 .76268 Mdot
.52683 .3428 Mdot
.54309 .64964 Mdot
.36104 .54737 Mdot
.51462 .35545 Mdot
.4624 .25422 Mdot
.5993 .55995 Mdot
.55799 .32814 Mdot
.41349 .38963 Mdot
.32695 .48948 Mdot
.5488 .31499 Mdot
.65509 .6752 Mdot
.3822 .4285 Mdot
.46512 .59687 Mdot
.55633 .68334 Mdot
.86869 .61715 Mdot
.39884 .40426 Mdot
.40079 .57138 Mdot
.36295 .56212 Mdot
.37011 .55086 Mdot
.51718 .36385 Mdot
.35727 .59343 Mdot
.52404 .37254 Mdot
.69701 .24588 Mdot
.57542 .42751 Mdot
.47357 .66464 Mdot
.27826 .42117 Mdot
.55213 .36301 Mdot
.66401 .7914 Mdot
.63787 .83591 Mdot
.69219 .53124 Mdot
.42877 .42931 Mdot
.46571 .66625 Mdot
.3974 .19603 Mdot
.46956 .68251 Mdot
.52657 .69237 Mdot
.74665 .6889 Mdot
.64858 .54098 Mdot
.72258 .40894 Mdot
.45385 .66311 Mdot
.5364 .35586 Mdot
.65491 .5178 Mdot
.39598 .47925 Mdot
.47215 .68545 Mdot
.49966 .6887 Mdot
.66334 .53026 Mdot
.57069 .33116 Mdot
.35922 .54494 Mdot
.42933 .39029 Mdot
.46225 .64769 Mdot
.49317 .3607 Mdot
.59084 .53903 Mdot
.609 .50755 Mdot
.48549 .57857 Mdot
.49301 .63929 Mdot
.3975 .40965 Mdot
.81486 .43133 Mdot
.3364 .59172 Mdot
.3282 .51501 Mdot
.4395 .78345 Mdot
.2616 .46287 Mdot
.36176 .5808 Mdot
.36601 .58716 Mdot
.67246 .5319 Mdot
.47773 .63473 Mdot
.76302 .65831 Mdot
.38606 .45649 Mdot
.39872 .59099 Mdot
.37491 .55237 Mdot
.54295 .29589 Mdot
.37446 .76607 Mdot
.71015 .51809 Mdot
.36323 .40291 Mdot
.39235 .54579 Mdot
.56026 .41604 Mdot
.47844 .68966 Mdot
.67535 .77258 Mdot
.63898 .57543 Mdot
.60955 .53097 Mdot
.3886 .41498 Mdot
.40112 .38329 Mdot
.3898 .49027 Mdot
.42269 .7798 Mdot
.80641 .50722 Mdot
.38136 .32475 Mdot
.65704 .43453 Mdot
.54367 .298 Mdot
.56005 .37315 Mdot
.31051 .36661 Mdot
.4102 .44058 Mdot
.61523 .5582 Mdot
.54756 .37676 Mdot
.2808 .54738 Mdot
.56368 .25519 Mdot
.59655 .73832 Mdot
.51212 .78194 Mdot
.61677 .51077 Mdot
.52467 .35652 Mdot
.52727 .32335 Mdot
.57419 .36847 Mdot
.2534 .51856 Mdot
.66686 .54379 Mdot
.6207 .51878 Mdot
.63939 .56926 Mdot
.56529 .57189 Mdot
.65922 .56023 Mdot
.4612 .32615 Mdot
.48697 .51766 Mdot
.62083 .39042 Mdot
.61813 .58506 Mdot
.35833 .41039 Mdot
.59657 .52519 Mdot
.48522 .7071 Mdot
.64818 .49445 Mdot
.6005 .74019 Mdot
.39064 .42644 Mdot
.48226 .3728 Mdot
.4255 .32007 Mdot
.59951 .54209 Mdot
.48563 .65467 Mdot
.46905 .40665 Mdot
.17703 .45748 Mdot
.51322 .70485 Mdot
.53554 .32573 Mdot
.35543 .5753 Mdot
.42685 .42625 Mdot
.34626 .55944 Mdot
.69354 .57704 Mdot
.31331 .36879 Mdot
.301 .31582 Mdot
.51068 .47423 Mdot
.68052 .55595 Mdot
.58306 .47726 Mdot
.53876 .32891 Mdot
.36387 .59378 Mdot
.60247 .34993 Mdot
.61588 .55415 Mdot
.49349 .68279 Mdot
.47071 .68985 Mdot
.40736 .47252 Mdot
.26719 .29917 Mdot
.4871 .30184 Mdot
.39132 .41433 Mdot
.38924 .56157 Mdot
.45818 .69548 Mdot
.49171 .22058 Mdot
.42229 .37588 Mdot
.40436 .43501 Mdot
.37434 .41652 Mdot
.61137 .49141 Mdot
.40006 .56202 Mdot
.62275 .38068 Mdot
.36145 .5263 Mdot
.62599 .51374 Mdot
.38184 .53957 Mdot
.38787 .58001 Mdot
.47334 .70019 Mdot
.36911 .40347 Mdot
.3607 .53207 Mdot
.67474 .5074 Mdot
.56194 .32214 Mdot
.50797 .42037 Mdot
.65431 .71421 Mdot
.52187 .20911 Mdot
.59247 .27239 Mdot
.54891 .30941 Mdot
.18999 .3767 Mdot
.37956 .43608 Mdot
.56984 .59025 Mdot
.24791 .5655 Mdot
.63426 .47964 Mdot
.68518 .78625 Mdot
.34408 .60314 Mdot
.39106 .58428 Mdot
.67558 .52209 Mdot
.29238 .55905 Mdot
.64646 .54479 Mdot
.36801 .53257 Mdot
.32274 .62549 Mdot
.59344 .58579 Mdot
.34248 .57893 Mdot
.6146 .58538 Mdot
.64254 .51153 Mdot
.52563 .34399 Mdot
.35871 .60365 Mdot
.67975 .49833 Mdot
.39964 .17652 Mdot
.39849 .38527 Mdot
.26427 .50777 Mdot
.68481 .65694 Mdot
.40088 .40005 Mdot
.56306 .33662 Mdot
.67758 .48256 Mdot
.46397 .68794 Mdot
.55066 .36575 Mdot
.66588 .72837 Mdot
.46007 .65871 Mdot
.66665 .79496 Mdot
.52691 .32868 Mdot
.3891 .5957 Mdot
.48513 .70188 Mdot
.58236 .55464 Mdot
.40521 .57217 Mdot
.4455 .44009 Mdot
.35953 .58185 Mdot
.671 .55088 Mdot
.27635 .40891 Mdot
.3732 .39162 Mdot
.63083 .52718 Mdot
.38775 .58993 Mdot
.26083 .45125 Mdot
.61263 .49135 Mdot
.66473 .51762 Mdot
.32493 .7456 Mdot
.61194 .80439 Mdot
.47031 .67484 Mdot
.57524 .37426 Mdot
.68019 .5148 Mdot
.49975 .68183 Mdot
.37447 .70377 Mdot
.59992 .51555 Mdot
.57797 .32416 Mdot
.55982 .48635 Mdot
.36288 .60066 Mdot
.40146 .39388 Mdot
.50847 .4688 Mdot
.50028 .67943 Mdot
.85239 .40338 Mdot
.37737 .52737 Mdot
.65978 .484 Mdot
.68639 .5524 Mdot
.25845 .63721 Mdot
.51616 .33377 Mdot
.78753 .54957 Mdot
.64004 .55561 Mdot
.57109 .58211 Mdot
.63047 .53777 Mdot
.31507 .59077 Mdot
.53682 .33563 Mdot
.65998 .55051 Mdot
.39922 .25035 Mdot
.59418 .49405 Mdot
.49764 .66882 Mdot
.62318 .22736 Mdot
.59053 .53119 Mdot
.45607 .87716 Mdot
.45719 .76036 Mdot
.34123 .57895 Mdot
.29684 .37583 Mdot
.56325 .13302 Mdot
.44416 .3196 Mdot
.52799 .37638 Mdot
.25266 .35401 Mdot
.35135 .55166 Mdot
.27109 .39393 Mdot
.18572 .37866 Mdot
.64362 .50871 Mdot
.59641 .52756 Mdot
.52149 .70357 Mdot
.33 .5601 Mdot
.39398 .53114 Mdot
.66606 .58675 Mdot
.67659 .47151 Mdot
.34429 .55491 Mdot
.68073 .51043 Mdot
.6806 .58625 Mdot
.4342 .40132 Mdot
.55393 .31079 Mdot
.41934 .41007 Mdot
.37192 .42014 Mdot
.69446 .27153 Mdot
.40192 .76436 Mdot
.40335 .38755 Mdot
.36725 .42239 Mdot
.61535 .72315 Mdot
.53245 .74825 Mdot
.45211 .69083 Mdot
.30864 .24595 Mdot
.37033 .55329 Mdot
.66359 .54172 Mdot
.5386 .3125 Mdot
.79971 .48823 Mdot
.41448 .7012 Mdot
.76811 .66127 Mdot
.61583 .55657 Mdot
.36966 .54685 Mdot
.25317 .51781 Mdot
.72285 .51513 Mdot
.38666 .5114 Mdot
.60557 .53433 Mdot
.39236 .53221 Mdot
.71577 .35659 Mdot
.398 .23808 Mdot
.40256 .54075 Mdot
.50415 .36602 Mdot
.61352 .53552 Mdot
.5318 .32466 Mdot
.41075 .41636 Mdot
.47513 .70509 Mdot
.47404 .67366 Mdot
.66003 .5226 Mdot
.56483 .53462 Mdot
.35124 .71878 Mdot
.63843 .5138 Mdot
.63955 .49223 Mdot
.2496 .52304 Mdot
.644 .49514 Mdot
.6723 .56151 Mdot
.66069 .5665 Mdot
.62953 .47149 Mdot
.38006 .38474 Mdot
.37477 .24812 Mdot
.7166 .54893 Mdot
.72013 .55219 Mdot
.40256 .3717 Mdot
.20473 .42512 Mdot
.37844 .43011 Mdot
.16714 .43493 Mdot
.42325 .40937 Mdot
.48006 .66935 Mdot
.21877 .57008 Mdot
.5731 .50106 Mdot
.57593 .34062 Mdot
.44047 .3988 Mdot
.49588 .68051 Mdot
.40212 .41359 Mdot
.36763 .53545 Mdot
.23996 .67704 Mdot
.52573 .39616 Mdot
.68807 .63027 Mdot
.43245 .4421 Mdot
.31813 .39461 Mdot
.35966 .53087 Mdot
.53113 .33427 Mdot
.7592 .41118 Mdot
.67358 .56332 Mdot
.49915 .68439 Mdot
.66811 .53323 Mdot
.36876 .39343 Mdot
.36342 .5483 Mdot
.62058 .21684 Mdot
.46252 .68734 Mdot
.3769 .78855 Mdot
.37425 .56325 Mdot
.655 .57042 Mdot
.36366 .40076 Mdot
.42901 .81578 Mdot
.41932 .40527 Mdot
.7642 .52179 Mdot
.52121 .31081 Mdot
.74346 .28832 Mdot
.55662 .36063 Mdot
.36746 .48265 Mdot
.28333 .75995 Mdot
.40096 .21444 Mdot
.56903 .32901 Mdot
.33392 .39724 Mdot
.61412 .50775 Mdot
.60808 .5096 Mdot
.50679 .21912 Mdot
.57648 .37183 Mdot
.69238 .53735 Mdot
.24308 .53392 Mdot
.37103 .28901 Mdot
.52038 .79844 Mdot
.35978 .58794 Mdot
.64461 .54828 Mdot
.38091 .36973 Mdot
.42662 .41633 Mdot
.37375 .52479 Mdot
.38915 .43745 Mdot
.62307 .51904 Mdot
.55313 .36208 Mdot
.35022 .51759 Mdot
.4851 .67883 Mdot
.47518 .17485 Mdot
.47295 .7133 Mdot
.36236 .58032 Mdot
.57665 .5503 Mdot
.34686 .55512 Mdot
.58736 .1225 Mdot
.61818 .52228 Mdot
.55036 .3224 Mdot
.6647 .5066 Mdot
.61717 .53493 Mdot
.59567 .5285 Mdot
.35741 .54194 Mdot
.76406 .5825 Mdot
.67754 .5086 Mdot
.38318 .40143 Mdot
.62089 .4116 Mdot
.59317 .53829 Mdot
.31158 .59658 Mdot
.55935 .73954 Mdot
.35319 .45774 Mdot
.53221 .31197 Mdot
.34882 .58375 Mdot
.56414 .3297 Mdot
.60471 .34129 Mdot
.56281 .33646 Mdot
.66349 .4201 Mdot
.74992 .39757 Mdot
.76844 .58793 Mdot
.62959 .27356 Mdot
.52988 .55181 Mdot
.57569 .37336 Mdot
.49754 .73562 Mdot
.56257 .37418 Mdot
.5246 .3263 Mdot
.16149 .70015 Mdot
.57452 .35384 Mdot
.63376 .55121 Mdot
.60299 .55888 Mdot
.33299 .32353 Mdot
.60968 .69358 Mdot
.65484 .50511 Mdot
.67588 .51462 Mdot
.47226 .70233 Mdot
.59321 .59928 Mdot
.30499 .37544 Mdot
.59903 .81962 Mdot
.28184 .3654 Mdot
.66573 .53091 Mdot
.67713 .51182 Mdot
.70019 .48529 Mdot
.44542 .84507 Mdot
.74503 .31312 Mdot
.58326 .31949 Mdot
.64464 .46097 Mdot
.46795 .19307 Mdot
.6008 .53774 Mdot
.60125 .50107 Mdot
.61551 .51026 Mdot
.3522 .55113 Mdot
.56569 .30783 Mdot
.67593 .47663 Mdot
.43632 .77087 Mdot
.59992 .53021 Mdot
.26277 .45807 Mdot
.69323 .22054 Mdot
.64716 .55108 Mdot
.55916 .30446 Mdot
.61412 .49871 Mdot
.51894 .33587 Mdot
.5323 .35722 Mdot
.58107 .51264 Mdot
.64826 .43039 Mdot
.55142 .29966 Mdot
.62612 .51309 Mdot
.36657 .54098 Mdot
.29086 .25455 Mdot
.66982 .55227 Mdot
.46662 .70373 Mdot
.63524 .55609 Mdot
.48198 .65176 Mdot
.63948 .49525 Mdot
.38041 .52835 Mdot
.79676 .45707 Mdot
.35437 .55727 Mdot
.77442 .32123 Mdot
.39874 .54904 Mdot
.33449 .754 Mdot
.58266 .32869 Mdot
.2758 .41647 Mdot
.8116 .58254 Mdot
.26364 .48932 Mdot
.45255 .56451 Mdot
.46814 .51811 Mdot
.39888 .43482 Mdot
.51345 .33321 Mdot
.56766 .60794 Mdot
.26642 .58906 Mdot
.25778 .59566 Mdot
.39406 .57272 Mdot
.84119 .53791 Mdot
.77408 .67057 Mdot
.66022 .49447 Mdot
.7095 .41547 Mdot
.65516 .35535 Mdot
.59488 .52154 Mdot
.6657 .47317 Mdot
.3443 .62496 Mdot
.69598 .53556 Mdot
.44727 .24569 Mdot
.36614 .57758 Mdot
.49659 .68226 Mdot
.54257 .32399 Mdot
.50264 .68263 Mdot
.26413 .58822 Mdot
.46557 .52038 Mdot
.37273 .53196 Mdot
.6159 .47558 Mdot
.66938 .51215 Mdot
.52162 .34243 Mdot
.59234 .36652 Mdot
.56941 .36169 Mdot
.46169 .67368 Mdot
.36676 .57261 Mdot
.79089 .39958 Mdot
.68254 .52284 Mdot
.54377 .35527 Mdot
.44391 .54923 Mdot
.68407 .51925 Mdot
.40831 .4077 Mdot
.61167 .51548 Mdot
.56404 .32123 Mdot
.64402 .4953 Mdot
.55617 .36311 Mdot
.35351 .57353 Mdot
.61057 .56167 Mdot
.67676 .52644 Mdot
.40793 .80781 Mdot
.48607 .66897 Mdot
.58586 .34452 Mdot
.28694 .58902 Mdot
.68612 .5576 Mdot
.29288 .44154 Mdot
.61136 .539 Mdot
.55795 .2556 Mdot
.63877 .47654 Mdot
.25629 .49526 Mdot
.71208 .53163 Mdot
.66834 .55217 Mdot
.41815 .49309 Mdot
.65754 .3794 Mdot
.58356 .37296 Mdot
.36192 .4012 Mdot
.5786 .34652 Mdot
.52911 .79162 Mdot
.41462 .57266 Mdot
.36227 .59582 Mdot
.58531 .64796 Mdot
.63336 .46972 Mdot
.65088 .54102 Mdot
.39773 .36804 Mdot
.47296 .6568 Mdot
.53732 .34736 Mdot
.49634 .68774 Mdot
.45098 .79329 Mdot
.45764 .66577 Mdot
.33385 .60235 Mdot
.37332 .7295 Mdot
.76993 .3654 Mdot
.47198 .70184 Mdot
.57098 .33069 Mdot
.43525 .7185 Mdot
.61126 .48408 Mdot
.47559 .7517 Mdot
.49211 .68634 Mdot
.8555 .4982 Mdot
.67281 .56048 Mdot
.45193 .57213 Mdot
.40724 .39235 Mdot
.48143 .70132 Mdot
.39382 .43186 Mdot
.65787 .50972 Mdot
.30559 .4021 Mdot
.53789 .37856 Mdot
.37585 .38126 Mdot
.60707 .57522 Mdot
.46695 .66442 Mdot
.3936 .55074 Mdot
.44366 .39018 Mdot
.36345 .39433 Mdot
.2168 .39066 Mdot
.65288 .22338 Mdot
.36697 .57039 Mdot
.65552 .75574 Mdot
.42348 .41425 Mdot
.59285 .5198 Mdot
.61399 .61292 Mdot
.60806 .52771 Mdot
.47095 .3217 Mdot
.35156 .58629 Mdot
.34267 .3002 Mdot
.66578 .50585 Mdot
.63293 .56562 Mdot
.58492 .36639 Mdot
.36072 .55877 Mdot
.55293 .34627 Mdot
.57701 .3559 Mdot
.35414 .57184 Mdot
.56143 .35414 Mdot
.45864 .65804 Mdot
.38354 .29197 Mdot
.42207 .38824 Mdot
.37914 .4052 Mdot
.37359 .55127 Mdot
.3385 .57722 Mdot
.34202 .56452 Mdot
.61141 .51581 Mdot
.53631 .34096 Mdot
.63272 .5008 Mdot
.59742 .52531 Mdot
.66199 .4391 Mdot
.54441 .30783 Mdot
.62148 .50188 Mdot
.358 .49759 Mdot
.45202 .64367 Mdot
.36975 .53987 Mdot
.40341 .38912 Mdot
.2363 .45038 Mdot
.45669 .39673 Mdot
.64068 .54758 Mdot
.34051 .73002 Mdot
.57228 .34445 Mdot
.46718 .68807 Mdot
.44878 .69341 Mdot
.46912 .67981 Mdot
.35163 .41924 Mdot
.57915 .36553 Mdot
.60537 .81828 Mdot
.64792 .5465 Mdot
.48411 .58007 Mdot
.6383 .63097 Mdot
.34419 .71989 Mdot
.4001 .38754 Mdot
.67989 .51579 Mdot
.51584 .45652 Mdot
.76922 .41073 Mdot
.61124 .52887 Mdot
.5906 .5094 Mdot
.24398 .54397 Mdot
.56476 .47069 Mdot
.52233 .3069 Mdot
.45421 .80852 Mdot
.65014 .5781 Mdot
.57079 .41134 Mdot
.50909 .16177 Mdot
.629 .54542 Mdot
.62631 .56078 Mdot
.68498 .54024 Mdot
.64704 .49215 Mdot
.54793 .30198 Mdot
.57481 .67141 Mdot
.38251 .43769 Mdot
.49486 .59107 Mdot
.40709 .37554 Mdot
.40559 .5621 Mdot
.3706 .25828 Mdot
.51303 .33163 Mdot
.46717 .693 Mdot
.37124 .23351 Mdot
.52082 .82553 Mdot
.3316 .56718 Mdot
.72226 .30751 Mdot
.49088 .67832 Mdot
.59181 .51875 Mdot
.46391 .65168 Mdot
.39992 .56395 Mdot
.3803 .39797 Mdot
.6327 .46811 Mdot
.56379 .37038 Mdot
.54599 .31522 Mdot
.69254 .53423 Mdot
.4465 .19696 Mdot
.40832 .40357 Mdot
.41358 .36979 Mdot
.60273 .50402 Mdot
.58468 .55677 Mdot
.55523 .34385 Mdot
.38416 .55994 Mdot
.60484 .76706 Mdot
.47799 .66003 Mdot
.70047 .53399 Mdot
.64133 .48983 Mdot
.42897 .78433 Mdot
.38507 .3908 Mdot
.32771 .5863 Mdot
.62218 .48569 Mdot
.37032 .33285 Mdot
.62296 .48563 Mdot
.67243 .46488 Mdot
.36868 .54183 Mdot
.71258 .54802 Mdot
.66992 .49959 Mdot
.71633 .58416 Mdot
.41039 .4276 Mdot
.55354 .32595 Mdot
.53 .39242 Mdot
.51624 .59427 Mdot
.40789 .40972 Mdot
.61877 .50001 Mdot
.39293 .39165 Mdot
.6 .51848 Mdot
.69348 .5318 Mdot
.40684 .38772 Mdot
.55342 .34692 Mdot
.25181 .36193 Mdot
.37088 .25217 Mdot
.65022 .49336 Mdot
.67461 .57444 Mdot
.58922 .67931 Mdot
.76298 .60337 Mdot
.61205 .54955 Mdot
.55744 .31704 Mdot
.67917 .52162 Mdot
.39583 .42997 Mdot
.45223 .66944 Mdot
.56303 .32229 Mdot
.38042 .56984 Mdot
.33621 .55479 Mdot
.43216 .31901 Mdot
.37707 .58599 Mdot
.61113 .48654 Mdot
.60467 .34906 Mdot
.54691 .39445 Mdot
.50042 .17188 Mdot
.35591 .56811 Mdot
.44883 .6695 Mdot
.66306 .51791 Mdot
.321 .72687 Mdot
.39424 .36646 Mdot
.50083 .88886 Mdot
.6492 .80426 Mdot
.49316 .71534 Mdot
.77581 .63602 Mdot
.4035 .55044 Mdot
.68772 .51422 Mdot
.47646 .70598 Mdot
.33337 .56513 Mdot
.63511 .48126 Mdot
.61531 .46843 Mdot
.78531 .55499 Mdot
.50766 .56516 Mdot
.39197 .39027 Mdot
.34679 .59395 Mdot
.46272 .71748 Mdot
.32641 .59274 Mdot
.53739 .31512 Mdot
.66626 .5502 Mdot
.56965 .53057 Mdot
.38363 .56552 Mdot
.32678 .56783 Mdot
.6214 .5096 Mdot
.51246 .33581 Mdot
.3516 .62458 Mdot
.65925 .52718 Mdot
.53445 .54633 Mdot
.50171 .33959 Mdot
.3701 .57915 Mdot
.64836 .5669 Mdot
.43076 .68999 Mdot
.37733 .56166 Mdot
.37179 .53955 Mdot
.69278 .53208 Mdot
.46098 .65654 Mdot
.67407 .57262 Mdot
.42478 .4004 Mdot
.82413 .4454 Mdot
.38963 .42893 Mdot
.42023 .67347 Mdot
.58031 .55953 Mdot
.36578 .3512 Mdot
.52401 .31858 Mdot
.52448 .68771 Mdot
.22382 .49919 Mdot
.6605 .58831 Mdot
.24225 .32186 Mdot
.50582 .44091 Mdot
.43273 .18828 Mdot
.19212 .55662 Mdot
.4862 .69208 Mdot
.40325 .41601 Mdot
.62533 .56017 Mdot
.43442 .41887 Mdot
.47201 .70654 Mdot
.76288 .31312 Mdot
.65697 .56613 Mdot
.53798 .3344 Mdot
.6193 .51396 Mdot
.53379 .32567 Mdot
.68891 .52452 Mdot
.72408 .52411 Mdot
.24249 .52627 Mdot
.66038 .72601 Mdot
.62932 .47891 Mdot
.26207 .71416 Mdot
.43071 .74506 Mdot
.49197 .67036 Mdot
.63596 .50579 Mdot
.40969 .52478 Mdot
.42398 .42329 Mdot
.50005 .23593 Mdot
.35233 .55015 Mdot
.3714 .42327 Mdot
.56054 .34388 Mdot
.35526 .5822 Mdot
.34035 .54674 Mdot
.71134 .54466 Mdot
.49726 .66594 Mdot
.37233 .4062 Mdot
.65941 .55276 Mdot
.65977 .56426 Mdot
.62135 .77444 Mdot
.40475 .68102 Mdot
.57506 .39329 Mdot
.51281 .84827 Mdot
.52837 .38892 Mdot
.4804 .66418 Mdot
.35783 .54496 Mdot
.61215 .54477 Mdot
.6329 .52587 Mdot
.27044 .4306 Mdot
.54599 .3809 Mdot
.50593 .52561 Mdot
.67739 .27232 Mdot
.34303 .62158 Mdot
.58219 .72402 Mdot
.54615 .3198 Mdot
.58505 .72313 Mdot
.45163 .70593 Mdot
.33642 .23767 Mdot
.63579 .73322 Mdot
.40414 .39172 Mdot
.58162 .72077 Mdot
.54008 .35996 Mdot
.66454 .49975 Mdot
.38676 .59727 Mdot
.38656 .58049 Mdot
.55276 .33345 Mdot
.34197 .53317 Mdot
.47343 .699 Mdot
.63821 .5626 Mdot
.59653 .81538 Mdot
.44353 .29724 Mdot
.38892 .55673 Mdot
.7268 .52943 Mdot
.37593 .41848 Mdot
.69375 .53819 Mdot
.4631 .6985 Mdot
.39526 .40124 Mdot
.46506 .76429 Mdot
.35879 .29442 Mdot
.65875 .51773 Mdot
.35279 .76092 Mdot
.40356 .40808 Mdot
.74934 .63843 Mdot
.66284 .53456 Mdot
.42213 .41619 Mdot
.60622 .45271 Mdot
.33129 .49095 Mdot
.51751 .46146 Mdot
.18689 .37598 Mdot
.50463 .49497 Mdot
.39685 .58792 Mdot
.33232 .46828 Mdot
.28475 .52439 Mdot
.43222 .42039 Mdot
.32527 .57358 Mdot
.45954 .62844 Mdot
.39476 .43231 Mdot
.59394 .53753 Mdot
.61688 .54105 Mdot
.74639 .311 Mdot
.4959 .44686 Mdot
.35523 .48209 Mdot
.48771 .2748 Mdot
.68236 .56051 Mdot
.64057 .57956 Mdot
.63894 .52861 Mdot
.55784 .29829 Mdot
.38742 .39346 Mdot
.32375 .76532 Mdot
.41052 .41004 Mdot
.66789 .77378 Mdot
.36912 .55198 Mdot
.34918 .58951 Mdot
.64326 .54999 Mdot
.4522 .60208 Mdot
.54492 .70914 Mdot
.62493 .51792 Mdot
.49122 .61727 Mdot
.6134 .22662 Mdot
.6023 .56891 Mdot
.5234 .31214 Mdot
.69774 .58614 Mdot
.49369 .33245 Mdot
.42328 .38928 Mdot
.48091 .68784 Mdot
.52489 .67432 Mdot
.37797 .39781 Mdot
.65018 .53972 Mdot
.34401 .35467 Mdot
.62164 .53265 Mdot
.64787 .48849 Mdot
.69412 .75707 Mdot
.4765 .71457 Mdot
.34531 .57067 Mdot
.46737 .6778 Mdot
.51938 .33059 Mdot
.36093 .86756 Mdot
.47734 .65645 Mdot
.54164 .70537 Mdot
.79295 .35285 Mdot
.58436 .71819 Mdot
.53868 .31614 Mdot
.50423 .67405 Mdot
.40526 .39752 Mdot
.30887 .22867 Mdot
.80197 .55709 Mdot
.45499 .37546 Mdot
.65465 .52758 Mdot
.51035 .3498 Mdot
.56394 .31635 Mdot
.38318 .37753 Mdot
.53363 .35684 Mdot
.60607 .45599 Mdot
.65664 .4956 Mdot
.43062 .4262 Mdot
.37977 .31653 Mdot
.36199 .39665 Mdot
.40129 .27009 Mdot
.63261 .508 Mdot
.55182 .31971 Mdot
.66289 .59606 Mdot
.52781 .29529 Mdot
.33034 .59326 Mdot
.58913 .53493 Mdot
.4718 .69857 Mdot
.39589 .34764 Mdot
.36928 .56914 Mdot
.3298 .71713 Mdot
.52177 .33935 Mdot
.34536 .44075 Mdot
.52609 .34707 Mdot
.57045 .37902 Mdot
.37516 .42477 Mdot
.53463 .37406 Mdot
.62958 .5618 Mdot
.37105 .48875 Mdot
.51722 .35011 Mdot
.38655 .41966 Mdot
.4805 .68226 Mdot
.55842 .35361 Mdot
.29336 .55548 Mdot
.6689 .5235 Mdot
.35026 .54465 Mdot
.2296 .58838 Mdot
.5314 .38504 Mdot
.504 .69692 Mdot
.36472 .59441 Mdot
.49951 .69136 Mdot
.57157 .19088 Mdot
.42298 .4357 Mdot
.75118 .67947 Mdot
.43871 .64815 Mdot
.57462 .34797 Mdot
.22035 .56885 Mdot
.61504 .54567 Mdot
.66717 .52087 Mdot
.48081 .64949 Mdot
.56434 .31675 Mdot
.37031 .22006 Mdot
.48606 .32816 Mdot
.36873 .29936 Mdot
.44075 .41814 Mdot
.30831 .73962 Mdot
.41073 .25693 Mdot
.633 .18504 Mdot
.65516 .58386 Mdot
.39941 .53809 Mdot
.64018 .54173 Mdot
.22442 .48093 Mdot
.46616 .66666 Mdot
.31451 .55339 Mdot
.58393 .51064 Mdot
.34956 .57688 Mdot
.67929 .53875 Mdot
.42126 .4776 Mdot
.69511 .58356 Mdot
.44827 .67544 Mdot
.29984 .37821 Mdot
.57614 .34915 Mdot
.48721 .67917 Mdot
.38108 .53095 Mdot
.55532 .71598 Mdot
.64683 .48279 Mdot
.69848 .57255 Mdot
.34596 .62164 Mdot
.53338 .33463 Mdot
.37363 .60006 Mdot
.42564 .39433 Mdot
.47325 .69197 Mdot
.66196 .509 Mdot
.63002 .47461 Mdot
.29228 .44527 Mdot
.37138 .41289 Mdot
.34246 .53706 Mdot
.41802 .40792 Mdot
.40508 .55062 Mdot
.69557 .56213 Mdot
.35083 .59066 Mdot
.67701 .49996 Mdot
.23459 .50706 Mdot
.69287 .75553 Mdot
.67227 .3935 Mdot
.35428 .58653 Mdot
.5729 .74624 Mdot
.39397 .42713 Mdot
.4207 .41225 Mdot
.79183 .37631 Mdot
.76995 .53421 Mdot
.57877 .80022 Mdot
.18889 .43566 Mdot
.40984 .37698 Mdot
.37964 .42039 Mdot
.346 .54798 Mdot
.52906 .37178 Mdot
.55258 .38872 Mdot
.4004 .54297 Mdot
.66554 .66446 Mdot
.53746 .34753 Mdot
.28478 .27286 Mdot
.53827 .79828 Mdot
.68708 .48564 Mdot
.4301 .55601 Mdot
.47315 .68663 Mdot
.64968 .67516 Mdot
.41809 .47909 Mdot
.62632 .56364 Mdot
.41649 .77585 Mdot
.38143 .55453 Mdot
.57514 .63305 Mdot
.16824 .43523 Mdot
.66355 .56505 Mdot
.66428 .54036 Mdot
.64388 .53568 Mdot
.50373 .70886 Mdot
.7804 .52583 Mdot
.65099 .56479 Mdot
.67124 .66212 Mdot
.69177 .55246 Mdot
.66893 .45126 Mdot
.47172 .67451 Mdot
.62048 .44126 Mdot
.23518 .54499 Mdot
.47398 .80292 Mdot
.65461 .60263 Mdot
.4268 .39873 Mdot
.51099 .62437 Mdot
.41417 .42606 Mdot
.66357 .41429 Mdot
.63811 .72925 Mdot
.51194 .37593 Mdot
.62407 .56193 Mdot
.36308 .5804 Mdot
.56225 .31501 Mdot
.31693 .46929 Mdot
.2582 .80352 Mdot
.42835 .4054 Mdot
.66434 .17954 Mdot
.42211 .40644 Mdot
.34718 .5383 Mdot
.55578 .34235 Mdot
.744 .38905 Mdot
.48605 .57476 Mdot
.55909 .35596 Mdot
.29064 .32592 Mdot
.58886 .32842 Mdot
.57014 .73585 Mdot
.51719 .37434 Mdot
.38945 .42295 Mdot
.35513 .42499 Mdot
.60489 .46609 Mdot
.6264 .55166 Mdot
.46476 .51169 Mdot
.53983 .7345 Mdot
.61931 .54918 Mdot
.3657 .57556 Mdot
.77474 .61446 Mdot
.53484 .64458 Mdot
.54002 .3711 Mdot
.37814 .43725 Mdot
.66807 .5413 Mdot
.63023 .48567 Mdot
.65 .48557 Mdot
.53862 .85815 Mdot
.34237 .23119 Mdot
.67771 .50909 Mdot
.68774 .55915 Mdot
.35335 .58007 Mdot
.43929 .68615 Mdot
.21742 .47802 Mdot
.73528 .4905 Mdot
.6105 .5585 Mdot
.48352 .67307 Mdot
.47864 .71614 Mdot
.63218 .48084 Mdot
.43297 .76577 Mdot
.33975 .3666 Mdot
.66031 .55291 Mdot
.76396 .53866 Mdot
.2737 .55491 Mdot
.32989 .56081 Mdot
.3812 .56623 Mdot
.56573 .3114 Mdot
.37337 .58506 Mdot
.3962 .5412 Mdot
.74843 .37437 Mdot
.49878 .51115 Mdot
.35113 .40065 Mdot
.46115 .67458 Mdot
.62942 .52714 Mdot
.56838 .39475 Mdot
.3599 .33847 Mdot
.38841 .4332 Mdot
.56965 .34984 Mdot
.42269 .42192 Mdot
.51384 .68687 Mdot
.66911 .6343 Mdot
.39656 .57006 Mdot
.40018 .37681 Mdot
.3605 .29373 Mdot
.48102 .67274 Mdot
.36765 .40893 Mdot
.3258 .36797 Mdot
.59365 .54755 Mdot
.73269 .43686 Mdot
.62846 .51563 Mdot
.40184 .19899 Mdot
.36997 .39963 Mdot
.2538 .48643 Mdot
.6564 .54437 Mdot
.37477 .56139 Mdot
.64257 .45361 Mdot
.60455 .53637 Mdot
.38341 .57253 Mdot
.66154 .49564 Mdot
.48506 .71058 Mdot
.4993 .34756 Mdot
.50058 .59175 Mdot
.82979 .63479 Mdot
.49806 .66672 Mdot
.31271 .46108 Mdot
.61286 .55218 Mdot
.62296 .2117 Mdot
.55693 .35487 Mdot
.66595 .48925 Mdot
.54643 .64915 Mdot
.51911 .3629 Mdot
.56774 .33807 Mdot
.62278 .4926 Mdot
.40957 .39522 Mdot
.37086 .57166 Mdot
.47625 .67396 Mdot
.56845 .18111 Mdot
.64925 .52031 Mdot
.678 .52442 Mdot
.48977 .67916 Mdot
.38405 .42528 Mdot
.61707 .48975 Mdot
.23339 .61409 Mdot
.41028 .17876 Mdot
.40035 .43645 Mdot
.59731 .5432 Mdot
.73291 .45646 Mdot
.48943 .35528 Mdot
.81228 .3471 Mdot
.46914 .75529 Mdot
.34498 .57769 Mdot
.5723 .46573 Mdot
.39736 .86821 Mdot
.47993 .68619 Mdot
.53607 .81836 Mdot
.63782 .48442 Mdot
.68689 .52899 Mdot
.57002 .35862 Mdot
.62772 .50111 Mdot
.52568 .37735 Mdot
.82804 .62042 Mdot
.42267 .78604 Mdot
.53018 .3305 Mdot
.56912 .36664 Mdot
.5445 .67484 Mdot
.21919 .47774 Mdot
.55477 .3334 Mdot
.69651 .55468 Mdot
.60501 .30688 Mdot
.74342 .54883 Mdot
.4724 .64815 Mdot
.25089 .57953 Mdot
.48253 .36149 Mdot
.48648 .73233 Mdot
.22708 .38225 Mdot
.48444 .37105 Mdot
.34555 .36995 Mdot
.42122 .39129 Mdot
.65865 .56807 Mdot
.38333 .58278 Mdot
.35923 .59472 Mdot
.66581 .59345 Mdot
.62241 .52759 Mdot
.52012 .33328 Mdot
.4579 .677 Mdot
.43074 .41845 Mdot
.67568 .51508 Mdot
.53652 .66128 Mdot
.47968 .65789 Mdot
.52906 .36353 Mdot
.76912 .56353 Mdot
.44726 .67712 Mdot
.72564 .55068 Mdot
.64862 .55657 Mdot
.61678 .51066 Mdot
.7404 .56056 Mdot
.39521 .38357 Mdot
.22105 .55306 Mdot
.62651 .57321 Mdot
.45138 .79434 Mdot
.51023 .41503 Mdot
.71513 .51042 Mdot
.53193 .34696 Mdot
.38986 .36624 Mdot
.36206 .60757 Mdot
.55471 .61533 Mdot
.65487 .51705 Mdot
.38614 .22677 Mdot
.71466 .28378 Mdot
.33733 .59895 Mdot
.57271 .37566 Mdot
.46776 .6851 Mdot
.62471 .51946 Mdot
.63127 .42041 Mdot
.62303 .54476 Mdot
.48911 .64728 Mdot
.37734 .54365 Mdot
.42073 .39187 Mdot
.42803 .18607 Mdot
.35817 .5944 Mdot
.56521 .33142 Mdot
.12539 .45576 Mdot
.51358 .36467 Mdot
.57018 .37132 Mdot
.62516 .42504 Mdot
.40246 .38289 Mdot
.42947 .88414 Mdot
.8297 .49251 Mdot
.5826 .54477 Mdot
.40051 .42697 Mdot
.54765 .33288 Mdot
.69134 .5436 Mdot
.51075 .32917 Mdot
.5817 .36158 Mdot
.69097 .56803 Mdot
.68318 .54857 Mdot
.37871 .25691 Mdot
.18099 .39307 Mdot
.46601 .68436 Mdot
.52411 .32402 Mdot
.54081 .56744 Mdot
.68872 .5488 Mdot
.64883 .54676 Mdot
.29386 .52247 Mdot
.45718 .65839 Mdot
.47327 .24423 Mdot
.63425 .48446 Mdot
.39813 .77994 Mdot
.69397 .58811 Mdot
.54193 .3021 Mdot
.39433 .4365 Mdot
.47566 .79897 Mdot
.41651 .45066 Mdot
.53921 .38074 Mdot
.45924 .6866 Mdot
.53571 .39579 Mdot
.53961 .70947 Mdot
.37881 .38342 Mdot
.56405 .32122 Mdot
.50967 .46661 Mdot
.39013 .40622 Mdot
.37679 .39187 Mdot
.61878 .41179 Mdot
.35667 .52127 Mdot
.49885 .71035 Mdot
.37276 .41021 Mdot
.56241 .57845 Mdot
.3946 .41979 Mdot
.80578 .42543 Mdot
.60929 .56094 Mdot
.61984 .65018 Mdot
.43804 .58557 Mdot
.57813 .48787 Mdot
.37404 .39018 Mdot
.46695 .70156 Mdot
.61912 .49137 Mdot
.53787 .36093 Mdot
.49597 .67331 Mdot
.44512 .38284 Mdot
.34688 .55238 Mdot
.52497 .34947 Mdot
.44291 .41941 Mdot
.53873 .31966 Mdot
.56566 .60851 Mdot
.81744 .39496 Mdot
.25291 .66132 Mdot
.48933 .56813 Mdot
.64861 .48557 Mdot
.19778 .45214 Mdot
.70422 .50364 Mdot
.61719 .52741 Mdot
.36926 .57801 Mdot
.58598 .64461 Mdot
.5533 .34594 Mdot
.40991 .18589 Mdot
.40943 .37988 Mdot
.45175 .80792 Mdot
.59306 .29817 Mdot
.65734 .48414 Mdot
.51647 .35 Mdot
.51364 .36632 Mdot
.65033 .37389 Mdot
.34916 .60937 Mdot
.66047 .4721 Mdot
.65487 .46794 Mdot
.69435 .57269 Mdot
.38352 .38922 Mdot
.33942 .7262 Mdot
.39999 .58136 Mdot
.80669 .3558 Mdot
.3836 .54867 Mdot
.49326 .61551 Mdot
.53437 .37226 Mdot
.47405 .65549 Mdot
.65041 .54802 Mdot
.59434 .35224 Mdot
.54211 .38187 Mdot
.47539 .6429 Mdot
.48317 .70185 Mdot
.31187 .50817 Mdot
.40541 .38717 Mdot
.62507 .4783 Mdot
.64726 .5666 Mdot
.63507 .49964 Mdot
.61237 .519 Mdot
.42892 .4005 Mdot
.60652 .50662 Mdot
.37424 .37442 Mdot
.63016 .62473 Mdot
.40425 .77101 Mdot
.4991 .49786 Mdot
.5474 .25523 Mdot
.53997 .3669 Mdot
.54539 .54996 Mdot
.73107 .53214 Mdot
.71541 .73719 Mdot
.57502 .22989 Mdot
.59533 .5619 Mdot
.33238 .57015 Mdot
.75742 .55574 Mdot
.39481 .57621 Mdot
.73241 .22593 Mdot
.28688 .45305 Mdot
.20423 .3593 Mdot
.66278 .56191 Mdot
.28574 .5366 Mdot
.56114 .55861 Mdot
.69346 .49595 Mdot
.30119 .48048 Mdot
.47454 .31612 Mdot
.314 .32428 Mdot
.45405 .6883 Mdot
.6668 .52716 Mdot
.57266 .38929 Mdot
.63449 .56291 Mdot
.64321 .54477 Mdot
.62951 .48314 Mdot
.36528 .41683 Mdot
.66184 .47437 Mdot
.60488 .5211 Mdot
.34908 .71322 Mdot
.60622 .72873 Mdot
.35034 .59638 Mdot
.7819 .35406 Mdot
.48363 .65817 Mdot
.51842 .34023 Mdot
.29788 .29272 Mdot
.40331 .39112 Mdot
.65096 .36383 Mdot
.61413 .51518 Mdot
.36319 .27314 Mdot
.44925 .40451 Mdot
.47249 .69471 Mdot
.39953 .58788 Mdot
.24018 .31116 Mdot
.36086 .57566 Mdot
.51334 .45719 Mdot
.37088 .56226 Mdot
.72863 .5607 Mdot
.52073 .33215 Mdot
.62017 .48409 Mdot
.37402 .40672 Mdot
.37698 .57875 Mdot
.60089 .68452 Mdot
.63907 .53022 Mdot
.35343 .57134 Mdot
.61945 .48459 Mdot
.6693 .63634 Mdot
.67783 .73699 Mdot
.38881 .53386 Mdot
.36182 .38274 Mdot
.38468 .40878 Mdot
.46051 .6574 Mdot
.5209 .35018 Mdot
.56444 .36609 Mdot
.39556 .40326 Mdot
.79273 .57783 Mdot
.60717 .55267 Mdot
.68589 .55072 Mdot
.45778 .80095 Mdot
.62042 .5552 Mdot
.55828 .73005 Mdot
.51562 .45916 Mdot
.53404 .36565 Mdot
.68819 .51697 Mdot
.635 .48665 Mdot
.6611 .5183 Mdot
.59554 .62479 Mdot
.38622 .5607 Mdot
.63999 .5714 Mdot
.48697 .70196 Mdot
.38222 .49359 Mdot
.69404 .53913 Mdot
.70263 .56631 Mdot
.5657 .36415 Mdot
.53426 .84093 Mdot
.42131 .40056 Mdot
.36954 .52808 Mdot
.34971 .58724 Mdot
.25339 .57836 Mdot
.51445 .40867 Mdot
.51248 .46627 Mdot
.78428 .32218 Mdot
.24468 .52916 Mdot
.4903 .67112 Mdot
.41535 .52254 Mdot
.53417 .4253 Mdot
.34496 .54561 Mdot
.42924 .4081 Mdot
.6114 .56395 Mdot
.61014 .55896 Mdot
.68011 .7855 Mdot
.64421 .47885 Mdot
.47118 .68357 Mdot
.38293 .37249 Mdot
.54074 .35956 Mdot
.47116 .69407 Mdot
.41864 .41299 Mdot
.53188 .33594 Mdot
.60396 .56538 Mdot
.60984 .56755 Mdot
.56856 .35155 Mdot
.56845 .3234 Mdot
.6527 .55383 Mdot
.38899 .63408 Mdot
.57652 .3382 Mdot
.55175 .31756 Mdot
.39729 .56896 Mdot
.38566 .57987 Mdot
.71454 .53695 Mdot
.40393 .42374 Mdot
.60458 .51743 Mdot
.35799 .58135 Mdot
.45686 .66803 Mdot
.55188 .35116 Mdot
.64796 .49164 Mdot
.67142 .51012 Mdot
.48097 .67392 Mdot
.45524 .68435 Mdot
.47774 .70055 Mdot
.36324 .38968 Mdot
.64159 .50548 Mdot
.559 .33786 Mdot
.41019 .38745 Mdot
.48114 .7167 Mdot
.45707 .65464 Mdot
.32043 .58147 Mdot
.61056 .54475 Mdot
.39247 .50055 Mdot
.33713 .84393 Mdot
.49723 .7681 Mdot
.34463 .60522 Mdot
.32426 .60082 Mdot
.60005 .71019 Mdot
.46889 .60046 Mdot
.40435 .40342 Mdot
.47451 .63519 Mdot
.52539 .68238 Mdot
.59023 .53033 Mdot
.65345 .57739 Mdot
.64159 .46191 Mdot
.48545 .69726 Mdot
.56033 .6379 Mdot
.51358 .32705 Mdot
.64916 .26736 Mdot
.49 .66308 Mdot
.32698 .56665 Mdot
.351 .52382 Mdot
.38256 .54731 Mdot
.61205 .56618 Mdot
.67334 .38806 Mdot
.54202 .48261 Mdot
.18816 .46489 Mdot
.36894 .39775 Mdot
.54701 .40066 Mdot
.60359 .2134 Mdot
.56842 .34607 Mdot
.4037 .56197 Mdot
.49608 .68396 Mdot
.56049 .31654 Mdot
.41591 .42979 Mdot
.37684 .41685 Mdot
.38736 .55516 Mdot
.3713 .54977 Mdot
.36614 .53467 Mdot
.57494 .36953 Mdot
.53352 .37304 Mdot
.65067 .51518 Mdot
.54938 .35847 Mdot
.63125 .82006 Mdot
.51202 .69631 Mdot
.32799 .60948 Mdot
.40548 .41609 Mdot
.53149 .32666 Mdot
.63728 .52727 Mdot
.51843 .6098 Mdot
.46763 .30478 Mdot
.49654 .69807 Mdot
.64112 .76187 Mdot
.73169 .22794 Mdot
.62621 .47703 Mdot
.38693 .38986 Mdot
.59479 .81388 Mdot
.6447 .53355 Mdot
.3623 .54406 Mdot
.22691 .51914 Mdot
.41632 .56984 Mdot
.59804 .52462 Mdot
.59936 .49223 Mdot
.39155 .43806 Mdot
.76718 .3117 Mdot
.64643 .51621 Mdot
.46689 .25534 Mdot
.39452 .44384 Mdot
.4011 .57815 Mdot
.38391 .18114 Mdot
.25803 .62972 Mdot
.65309 .67052 Mdot
.39766 .56636 Mdot
.61625 .53546 Mdot
.39404 .57068 Mdot
.48918 .70501 Mdot
.38997 .54143 Mdot
.51837 .31411 Mdot
.35996 .60024 Mdot
.67904 .52568 Mdot
.55361 .331 Mdot
.40458 .40808 Mdot
.47678 .82159 Mdot
.40419 .72258 Mdot
.3751 .56017 Mdot
.37446 .52576 Mdot
.67497 .50396 Mdot
.44605 .24155 Mdot
.62512 .58979 Mdot
.67253 .55967 Mdot
.40205 .37544 Mdot
.5185 .3557 Mdot
.37627 .43202 Mdot
.68315 .49976 Mdot
.22643 .61002 Mdot
.41746 .40386 Mdot
.35805 .26929 Mdot
.49101 .67703 Mdot
.44191 .46781 Mdot
.63048 .52486 Mdot
.38088 .42635 Mdot
.64072 .5061 Mdot
.51574 .32301 Mdot
.47813 .4577 Mdot
.30398 .36961 Mdot
.37696 .40225 Mdot
.40089 .20972 Mdot
.45374 .62209 Mdot
.58212 .57009 Mdot
.4193 .41978 Mdot
.54507 .64408 Mdot
.34138 .54515 Mdot
.48117 .66088 Mdot
.46554 .70851 Mdot
.50157 .6813 Mdot
.63262 .58808 Mdot
.62649 .60003 Mdot
.48339 .71353 Mdot
.4176 .43176 Mdot
.44888 .68112 Mdot
.5566 .41144 Mdot
.37538 .2188 Mdot
.46785 .6673 Mdot
.6605 .53147 Mdot
.65878 .60691 Mdot
.61149 .72211 Mdot
.34102 .49322 Mdot
.21931 .34535 Mdot
.52117 .24069 Mdot
.62625 .55037 Mdot
.50271 .37078 Mdot
.53552 .31405 Mdot
.57128 .81509 Mdot
.53962 .74647 Mdot
.45536 .78219 Mdot
.57007 .36737 Mdot
.27653 .41255 Mdot
.52699 .35963 Mdot
.64909 .48184 Mdot
.68892 .54581 Mdot
.55415 .38626 Mdot
.36427 .75202 Mdot
.3023 .42711 Mdot
.48148 .1779 Mdot
.5456 .31677 Mdot
.40988 .4285 Mdot
.39752 .37146 Mdot
.37748 .38983 Mdot
.5489 .79857 Mdot
.51951 .37059 Mdot
.64577 .5021 Mdot
.35644 .5862 Mdot
.62821 .56899 Mdot
.38896 .39965 Mdot
.40728 .18687 Mdot
.55395 .36841 Mdot
.66638 .55242 Mdot
.7529 .61023 Mdot
.35763 .55024 Mdot
.48373 .67058 Mdot
.72507 .61097 Mdot
.47146 .77207 Mdot
.38993 .38139 Mdot
.53085 .38608 Mdot
.25906 .47021 Mdot
.35155 .26354 Mdot
.64254 .58201 Mdot
.70016 .49269 Mdot
.60305 .17939 Mdot
.46654 .7644 Mdot
.60041 .49903 Mdot
.35509 .53332 Mdot
.26787 .43618 Mdot
.66348 .50522 Mdot
.53008 .31768 Mdot
.45438 .69767 Mdot
.4993 .68675 Mdot
.70797 .52839 Mdot
.48338 .58254 Mdot
.45823 .43859 Mdot
.61756 .50084 Mdot
.72677 .54836 Mdot
.40049 .57295 Mdot
.24406 .53185 Mdot
.44687 .79513 Mdot
.45855 .68722 Mdot
.61776 .4868 Mdot
.25909 .36648 Mdot
.55941 .38002 Mdot
.3501 .60185 Mdot
.37103 .38803 Mdot
.6532 .63054 Mdot
.40276 .57677 Mdot
.66235 .5029 Mdot
.6204 .48807 Mdot
.36836 .41511 Mdot
.54106 .30217 Mdot
.48857 .69532 Mdot
.35532 .58848 Mdot
.45952 .69314 Mdot
.51903 .36533 Mdot
.54834 .36571 Mdot
.74794 .53142 Mdot
.57744 .51114 Mdot
.38002 .56815 Mdot
.6963 .5239 Mdot
.2879 .58599 Mdot
.7599 .29126 Mdot
.44013 .3978 Mdot
.62289 .47728 Mdot
.55051 .29678 Mdot
.37912 .39821 Mdot
.68809 .53876 Mdot
.57507 .17625 Mdot
.68955 .54985 Mdot
.46499 .37977 Mdot
.24778 .66247 Mdot
.46802 .69974 Mdot
.63562 .26274 Mdot
.48109 .21537 Mdot
.6263 .55768 Mdot
.33692 .57576 Mdot
.71368 .49997 Mdot
.40908 .39771 Mdot
.53857 .37176 Mdot
.81262 .34272 Mdot
.39011 .41863 Mdot
.64852 .56273 Mdot
.47273 .6928 Mdot
.51966 .37561 Mdot
.49364 .6292 Mdot
.42852 .76621 Mdot
.61245 .59079 Mdot
.70265 .54354 Mdot
.61019 .51136 Mdot
.2028 .55775 Mdot
.37041 .52853 Mdot
.54184 .32784 Mdot
.38677 .3888 Mdot
.39732 .40161 Mdot
.38532 .55546 Mdot
.34491 .31439 Mdot
.44432 .46611 Mdot
.33574 .8297 Mdot
.38557 .57308 Mdot
.50569 .68563 Mdot
.46053 .24653 Mdot
.3366 .57999 Mdot
.35422 .56679 Mdot
.3988 .57535 Mdot
.38039 .45586 Mdot
.53395 .33859 Mdot
.67002 .50689 Mdot
.53155 .31213 Mdot
.61312 .53385 Mdot
.50229 .40836 Mdot
.37468 .40198 Mdot
.54465 .37451 Mdot
.58611 .18325 Mdot
.77542 .47797 Mdot
.65239 .53414 Mdot
.61383 .21229 Mdot
.5808 .52771 Mdot
.57427 .70576 Mdot
.59334 .48841 Mdot
.37231 .55535 Mdot
.55539 .50892 Mdot
.68602 .58253 Mdot
.52701 .82983 Mdot
.40703 .41652 Mdot
.33021 .56264 Mdot
.5864 .53081 Mdot
.7167 .57191 Mdot
.56387 .38429 Mdot
.5573 .31614 Mdot
.47509 .71216 Mdot
.66833 .72368 Mdot
.40703 .40807 Mdot
.81812 .47401 Mdot
.63141 .55359 Mdot
.30063 .70475 Mdot
.63359 .27822 Mdot
.68688 .54065 Mdot
.4989 .21219 Mdot
.66491 .37925 Mdot
.62633 .52112 Mdot
.52212 .55345 Mdot
.38541 .42524 Mdot
.2306 .62198 Mdot
.69354 .55429 Mdot
.35524 .54838 Mdot
.52743 .36778 Mdot
.51219 .33109 Mdot
.48264 .71235 Mdot
.76036 .69294 Mdot
.37271 .42757 Mdot
.54128 .37402 Mdot
.63656 .53358 Mdot
.39703 .38176 Mdot
.3704 .58796 Mdot
.65958 .48163 Mdot
.54517 .7506 Mdot
.54596 .35772 Mdot
.69896 .54461 Mdot
.44545 .2766 Mdot
.64829 .69611 Mdot
.16209 .53762 Mdot
.38771 .38672 Mdot
.45443 .66489 Mdot
.70937 .4952 Mdot
.78404 .56144 Mdot
.60204 .57045 Mdot
.61315 .64698 Mdot
.52533 .40827 Mdot
.45309 .66621 Mdot
.65888 .54121 Mdot
.65805 .50711 Mdot
.44514 .58421 Mdot
.45654 .67969 Mdot
.65249 .5672 Mdot
.66245 .61505 Mdot
.53505 .3347 Mdot
.4098 .57203 Mdot
.54047 .35329 Mdot
.65504 .52832 Mdot
.5873 .49015 Mdot
.57296 .34641 Mdot
.71058 .23574 Mdot
.48781 .7198 Mdot
.41935 .39825 Mdot
.57536 .54742 Mdot
.64084 .57534 Mdot
.26884 .73181 Mdot
.32896 .58968 Mdot
.22844 .44083 Mdot
.3206 .67272 Mdot
.2365 .38305 Mdot
.25918 .63127 Mdot
.15446 .41629 Mdot
.42401 .78118 Mdot
.67243 .48004 Mdot
.52944 .27988 Mdot
.53521 .48962 Mdot
.37062 .39211 Mdot
.77425 .37958 Mdot
.62557 .55131 Mdot
.64105 .5436 Mdot
.34915 .60276 Mdot
.34132 .29789 Mdot
.45129 .78514 Mdot
.49492 .60262 Mdot
.48919 .69337 Mdot
.5243 .32548 Mdot
.68611 .52017 Mdot
.51233 .52724 Mdot
.34847 .59658 Mdot
.3087 .71251 Mdot
.66662 .54936 Mdot
.70971 .73839 Mdot
.45014 .32674 Mdot
.39873 .38436 Mdot
.34485 .58615 Mdot
.46408 .77199 Mdot
.60812 .54167 Mdot
.37218 .38534 Mdot
.64263 .51964 Mdot
.40991 .62047 Mdot
.68644 .50673 Mdot
.46896 .6631 Mdot
.64006 .48367 Mdot
.50276 .61601 Mdot
.13094 .50188 Mdot
.49679 .64628 Mdot
.51004 .34393 Mdot
.34203 .61485 Mdot
.38495 .56244 Mdot
.56507 .32064 Mdot
.38231 .56331 Mdot
.64659 .32937 Mdot
.72707 .36501 Mdot
.49335 .68638 Mdot
.71637 .56691 Mdot
.46693 .67137 Mdot
.33194 .59619 Mdot
.61683 .54501 Mdot
.75122 .26662 Mdot
.37624 .57471 Mdot
.26891 .7068 Mdot
.39702 .41746 Mdot
.32681 .57834 Mdot
.69247 .55229 Mdot
.26347 .474 Mdot
.35475 .59498 Mdot
.30694 .36868 Mdot
.65977 .51774 Mdot
.54381 .36474 Mdot
.65804 .5035 Mdot
.57724 .54136 Mdot
.38205 .52104 Mdot
.60247 .52614 Mdot
.41845 .41323 Mdot
.57866 .34714 Mdot
.29557 .25119 Mdot
.47258 .32721 Mdot
.63207 .56529 Mdot
.63907 .53387 Mdot
.55435 .3944 Mdot
.6461 .57263 Mdot
.42876 .40021 Mdot
.64224 .86145 Mdot
.49067 .67624 Mdot
.3671 .52377 Mdot
.25575 .62915 Mdot
.59596 .56113 Mdot
.61115 .49965 Mdot
.55344 .1721 Mdot
.25175 .63789 Mdot
.41952 .41732 Mdot
.67436 .58813 Mdot
.36319 .59208 Mdot
.47263 .69047 Mdot
.42007 .43174 Mdot
.61782 .50997 Mdot
.65342 .54615 Mdot
.45663 .66286 Mdot
.6079 .39796 Mdot
.5211 .79979 Mdot
.36655 .40989 Mdot
.55881 .5122 Mdot
.2961 .5794 Mdot
.60485 .54543 Mdot
.56889 .79915 Mdot
.56078 .31984 Mdot
.39507 .3785 Mdot
.20414 .46767 Mdot
.59755 .50703 Mdot
.39365 .43559 Mdot
.40781 .40958 Mdot
.67252 .58735 Mdot
.56102 .29622 Mdot
.58265 .34972 Mdot
.53697 .32006 Mdot
.65952 .81303 Mdot
.63421 .6839 Mdot
.36605 .53477 Mdot
.38431 .42494 Mdot
.39537 .53912 Mdot
.50448 .67047 Mdot
.52778 .4471 Mdot
.38256 .52945 Mdot
.55597 .31068 Mdot
.35219 .6141 Mdot
.66061 .51132 Mdot
.40424 .4064 Mdot
.34948 .54169 Mdot
.58532 .54708 Mdot
.42497 .24039 Mdot
.34737 .47197 Mdot
.45175 .66144 Mdot
.45769 .70239 Mdot
.69229 .53854 Mdot
.37072 .60594 Mdot
.65105 .55283 Mdot
.42788 .3861 Mdot
.44323 .24622 Mdot
.59611 .5668 Mdot
.37712 .55911 Mdot
.51209 .38588 Mdot
.47009 .77082 Mdot
.59231 .57432 Mdot
.66029 .53253 Mdot
.60817 .53287 Mdot
.64212 .51915 Mdot
.31353 .31297 Mdot
.44035 .41579 Mdot
.52981 .26354 Mdot
.22117 .56182 Mdot
.55904 .36129 Mdot
.57853 .31708 Mdot
.49303 .77436 Mdot
.33712 .37695 Mdot
.40136 .42547 Mdot
.61523 .52489 Mdot
.38112 .33296 Mdot
.39808 .18938 Mdot
.66574 .19496 Mdot
.44042 .71495 Mdot
.33325 .59166 Mdot
.53621 .38851 Mdot
.34343 .59062 Mdot
.61746 .5387 Mdot
.69712 .48296 Mdot
.14903 .42049 Mdot
.37227 .43697 Mdot
.49487 .68845 Mdot
.61062 .53157 Mdot
.64236 .68171 Mdot
.35382 .58144 Mdot
.36675 .51837 Mdot
.66346 .56606 Mdot
.55636 .30102 Mdot
.19757 .63551 Mdot
.3933 .38439 Mdot
.51472 .24002 Mdot
.55188 .53911 Mdot
.50011 .26609 Mdot
.38838 .39527 Mdot
.42956 .75529 Mdot
.34974 .60509 Mdot
.62444 .32529 Mdot
.55986 .36317 Mdot
.49499 .6726 Mdot
.70929 .50154 Mdot
.56568 .36808 Mdot
.40111 .58156 Mdot
.54152 .36919 Mdot
.63365 .48151 Mdot
.41796 .43871 Mdot
.34342 .57768 Mdot
.35185 .40575 Mdot
.56555 .29914 Mdot
.46112 .68979 Mdot
.45616 .54272 Mdot
.77816 .42374 Mdot
.6618 .3752 Mdot
.63012 .57069 Mdot
.51495 .51666 Mdot
.64179 .50088 Mdot
.58805 .34557 Mdot
.63915 .52529 Mdot
.55949 .40781 Mdot
.33865 .57886 Mdot
.68882 .55837 Mdot
.6146 .50525 Mdot
.75991 .34662 Mdot
.6721 .5443 Mdot
.67677 .48835 Mdot
.62243 .52075 Mdot
.59992 .35785 Mdot
.71188 .56889 Mdot
.53077 .34402 Mdot
.39583 .74279 Mdot
.35541 .56371 Mdot
.45677 .6991 Mdot
.48929 .65933 Mdot
.62288 .65351 Mdot
.35676 .63946 Mdot
.33741 .30989 Mdot
.54215 .34713 Mdot
.41501 .41077 Mdot
.63843 .52182 Mdot
.17567 .45321 Mdot
.27301 .54797 Mdot
.37324 .59156 Mdot
.4725 .32664 Mdot
.56814 .47765 Mdot
.19966 .57398 Mdot
.69941 .53769 Mdot
.69877 .77128 Mdot
.57517 .50949 Mdot
.68192 .50157 Mdot
.389 .53014 Mdot
.51207 .70526 Mdot
.66394 .56888 Mdot
.56262 .38515 Mdot
.47102 .65933 Mdot
.53972 .28029 Mdot
.36412 .50371 Mdot
.40349 .73832 Mdot
.74104 .3443 Mdot
.64163 .50981 Mdot
.3428 .57579 Mdot
.5243 .34767 Mdot
.44407 .79461 Mdot
.41238 .38837 Mdot
.36309 .36529 Mdot
.54082 .55897 Mdot
.64699 .20879 Mdot
.4816 .65823 Mdot
.61308 .4089 Mdot
.67864 .5237 Mdot
.42315 .69067 Mdot
.64028 .57889 Mdot
.40227 .19019 Mdot
.50522 .67924 Mdot
.57644 .32176 Mdot
.41 .42732 Mdot
.53418 .31276 Mdot
.66475 .39016 Mdot
.43126 .56826 Mdot
.4791 .50121 Mdot
.35867 .57431 Mdot
.41345 .48152 Mdot
.54861 .32845 Mdot
.61216 .49195 Mdot
.33023 .82815 Mdot
.55505 .31778 Mdot
.53445 .38302 Mdot
.79405 .35029 Mdot
.75764 .28384 Mdot
.56008 .48776 Mdot
.5739 .35365 Mdot
.35952 .56955 Mdot
.46365 .68446 Mdot
.64716 .49554 Mdot
.65187 .51155 Mdot
.56733 .3633 Mdot
.37561 .52021 Mdot
.74173 .47154 Mdot
.37065 .55101 Mdot
.53251 .33335 Mdot
.35372 .5575 Mdot
.24985 .48804 Mdot
.33711 .55518 Mdot
.64191 .57512 Mdot
.63884 .52431 Mdot
.29693 .63035 Mdot
.54795 .36543 Mdot
.61955 .49851 Mdot
.66384 .49645 Mdot
.55706 .33702 Mdot
.51435 .71869 Mdot
.7195 .4536 Mdot
.61657 .55733 Mdot
.67014 .5275 Mdot
.45289 .66841 Mdot
.53248 .45561 Mdot
.74577 .67037 Mdot
.6193 .4914 Mdot
.50669 .7042 Mdot
.57013 .37329 Mdot
.65839 .55419 Mdot
.33549 .24674 Mdot
.26861 .43365 Mdot
.60301 .49824 Mdot
.33785 .55022 Mdot
.69075 .57789 Mdot
.1731 .56107 Mdot
.67227 .56045 Mdot
.55122 .33748 Mdot
.52353 .36926 Mdot
.81535 .46548 Mdot
.5624 .32727 Mdot
.38639 .58046 Mdot
.38952 .40353 Mdot
.40645 .19693 Mdot
.36934 .58827 Mdot
.58991 .56594 Mdot
.83176 .48606 Mdot
.656 .47634 Mdot
.58827 .55777 Mdot
.21545 .64158 Mdot
.36552 .58781 Mdot
.51529 .34262 Mdot
.46322 .58559 Mdot
.62438 .46209 Mdot
.3887 .38122 Mdot
.72216 .52884 Mdot
.60025 .54919 Mdot
.25148 .66941 Mdot
.28569 .37569 Mdot
.40669 .37333 Mdot
.67456 .47687 Mdot
.61796 .49251 Mdot
.41286 .52732 Mdot
.63536 .52922 Mdot
.46121 .67799 Mdot
.51678 .36291 Mdot
.3338 .57495 Mdot
.48249 .677 Mdot
.62516 .5545 Mdot
.48325 .6982 Mdot
.35124 .54382 Mdot
.38165 .3806 Mdot
.61294 .53982 Mdot
.47121 .64798 Mdot
.48601 .69544 Mdot
.63709 .49772 Mdot
.53595 .37115 Mdot
.57322 .50744 Mdot
.66772 .55426 Mdot
.64718 .48982 Mdot
.56326 .36711 Mdot
.59056 .13594 Mdot
.68278 .55516 Mdot
.44348 .62414 Mdot
.53694 .38187 Mdot
.40887 .49794 Mdot
.33272 .58003 Mdot
.60277 .55419 Mdot
.39247 .37528 Mdot
.37502 .41982 Mdot
.40036 .56831 Mdot
.52017 .37817 Mdot
.31219 .66148 Mdot
.5209 .3939 Mdot
.61184 .46991 Mdot
.62524 .47335 Mdot
.81531 .54355 Mdot
.20313 .35563 Mdot
.51849 .32493 Mdot
.34773 .52041 Mdot
.49443 .59558 Mdot
.39096 .43 Mdot
.32912 .55823 Mdot
.53176 .38751 Mdot
.52023 .37354 Mdot
.53572 .36424 Mdot
.49865 .68179 Mdot
.30185 .63176 Mdot
.53154 .30379 Mdot
.56242 .30533 Mdot
.66068 .51587 Mdot
.6158 .49527 Mdot
.51373 .73945 Mdot
.5781 .75455 Mdot
.46529 .70179 Mdot
.38191 .54924 Mdot
.57449 .86987 Mdot
.42885 .38821 Mdot
.74797 .32561 Mdot
.59473 .56467 Mdot
.31761 .84544 Mdot
.69552 .54513 Mdot
.63372 .53193 Mdot
.57782 .35033 Mdot
.46009 .65178 Mdot
.4745 .66749 Mdot
.54276 .32474 Mdot
.58799 .3382 Mdot
.46133 .67654 Mdot
.54487 .21684 Mdot
.35894 .21873 Mdot
.43043 .59052 Mdot
.55773 .34596 Mdot
.76845 .40897 Mdot
.36532 .3935 Mdot
.49655 .32609 Mdot
.43574 .40564 Mdot
.35193 .57542 Mdot
.3748 .60402 Mdot
.38204 .38946 Mdot
.65795 .51809 Mdot
.36992 .53176 Mdot
.66363 .47569 Mdot
.56188 .23751 Mdot
.71227 .429 Mdot
.27045 .62694 Mdot
.70684 .5495 Mdot
.41565 .75093 Mdot
.32522 .3982 Mdot
.64077 .55998 Mdot
.26258 .33639 Mdot
.49281 .69213 Mdot
.51082 .31113 Mdot
.41572 .38037 Mdot
.1623 .56098 Mdot
.6047 .53537 Mdot
.55108 .34217 Mdot
.40888 .41767 Mdot
.62655 .63454 Mdot
.46162 .25411 Mdot
.61053 .53337 Mdot
.36184 .84975 Mdot
.59915 .33001 Mdot
.33413 .57067 Mdot
.78701 .60778 Mdot
.52436 .31491 Mdot
.44679 .72009 Mdot
.22794 .55233 Mdot
.60505 .19493 Mdot
.51881 .33903 Mdot
.3256 .56338 Mdot
.53095 .32268 Mdot
.45991 .68712 Mdot
.50254 .36208 Mdot
.34921 .58441 Mdot
.66639 .54419 Mdot
.38069 .55503 Mdot
.47562 .71016 Mdot
.53149 .79257 Mdot
.4031 .37303 Mdot
.33078 .56164 Mdot
.37837 .40954 Mdot
.65773 .70505 Mdot
.21406 .57291 Mdot
.42108 .39331 Mdot
.77135 .56882 Mdot
.5944 .51074 Mdot
.53413 .30607 Mdot
.39131 .56119 Mdot
.2369 .54078 Mdot
.46526 .56358 Mdot
.56395 .3546 Mdot
.3679 .54043 Mdot
.53281 .5375 Mdot
.77759 .58253 Mdot
.66265 .59707 Mdot
.65796 .71928 Mdot
.55952 .3417 Mdot
.32211 .57642 Mdot
.45916 .80221 Mdot
.55047 .30955 Mdot
.3875 .57162 Mdot
.40522 .43184 Mdot
.39481 .39821 Mdot
.65287 .5691 Mdot
.34841 .40056 Mdot
.37918 .54092 Mdot
.33319 .4293 Mdot
.56269 .37951 Mdot
.59307 .62692 Mdot
.49156 .65834 Mdot
.36221 .55811 Mdot
.64567 .47866 Mdot
.52248 .30065 Mdot
.25309 .46422 Mdot
.76204 .48548 Mdot
.50292 .85164 Mdot
.38476 .55512 Mdot
.52323 .37451 Mdot
.5507 .3469 Mdot
.59181 .573 Mdot
.4878 .57045 Mdot
.31082 .65668 Mdot
.71259 .63059 Mdot
.60869 .64187 Mdot
.40829 .56997 Mdot
.41235 .5537 Mdot
.58626 .52177 Mdot
.63608 .51066 Mdot
.39685 .43104 Mdot
.66697 .53973 Mdot
.57927 .33608 Mdot
.65159 .57076 Mdot
.38498 .39335 Mdot
.36411 .5757 Mdot
.6191 .54422 Mdot
.46636 .69978 Mdot
.38269 .37475 Mdot
.39319 .43878 Mdot
.36894 .55849 Mdot
.56411 .3705 Mdot
.51208 .66281 Mdot
.37147 .5494 Mdot
.64232 .51048 Mdot
.39793 .34998 Mdot
.64987 .48557 Mdot
.5889 .25575 Mdot
.55296 .30898 Mdot
.33995 .58633 Mdot
.56338 .38073 Mdot
.38128 .41682 Mdot
.22211 .55801 Mdot
.64941 .52769 Mdot
.38427 .57519 Mdot
.29118 .60665 Mdot
.59495 .27399 Mdot
.56998 .39055 Mdot
.32072 .36945 Mdot
.58436 .32794 Mdot
.39293 .59328 Mdot
.79881 .38558 Mdot
.48583 .66173 Mdot
.37002 .59283 Mdot
.25783 .29772 Mdot
.37686 .56754 Mdot
.67747 .54375 Mdot
.69061 .53376 Mdot
.33334 .56865 Mdot
.46161 .65624 Mdot
.42812 .78907 Mdot
.40174 .60135 Mdot
.51626 .34289 Mdot
.63944 .2262 Mdot
.42392 .83339 Mdot
.34479 .39555 Mdot
.40707 .42706 Mdot
.62031 .46146 Mdot
.67528 .49462 Mdot
.43342 .41157 Mdot
.37705 .4363 Mdot
.49704 .70015 Mdot
.39723 .57735 Mdot
.59645 .37812 Mdot
.35859 .40146 Mdot
.74617 .54548 Mdot
.36077 .64227 Mdot
.62308 .59058 Mdot
.54496 .52409 Mdot
.64884 .5781 Mdot
.63333 .64726 Mdot
.3855 .39074 Mdot
.68534 .51604 Mdot
.65758 .59401 Mdot
.39471 .37608 Mdot
.461 .68094 Mdot
.34104 .33779 Mdot
.34702 .56119 Mdot
.42941 .15682 Mdot
.67855 .50306 Mdot
.67877 .54595 Mdot
.36996 .39597 Mdot
.33866 .69442 Mdot
.55267 .37081 Mdot
.54777 .30784 Mdot
.36724 .52901 Mdot
.46001 .53657 Mdot
.60797 .55764 Mdot
.6545 .55994 Mdot
.34156 .56508 Mdot
.32724 .57402 Mdot
.33158 .46539 Mdot
.67245 .51377 Mdot
.4044 .41986 Mdot
.50945 .61956 Mdot
.38435 .39164 Mdot
.64829 .48205 Mdot
.68144 .54082 Mdot
.6421 .57489 Mdot
.64335 .47867 Mdot
.40372 .43961 Mdot
.6832 .51548 Mdot
.67578 .60191 Mdot
.55067 .37424 Mdot
.60606 .52398 Mdot
.62869 .64384 Mdot
.66487 .53116 Mdot
.463 .6826 Mdot
.75729 .53402 Mdot
.60611 .53649 Mdot
.60846 .56072 Mdot
.39194 .61238 Mdot
.65382 .53987 Mdot
.42976 .38858 Mdot
.55421 .35945 Mdot
.38292 .42388 Mdot
.36789 .40808 Mdot
.39772 .5568 Mdot
.4841 .71306 Mdot
.59607 .55987 Mdot
.49707 .69535 Mdot
.62371 .57928 Mdot
.60009 .50098 Mdot
.24469 .57681 Mdot
.71152 .76029 Mdot
.53411 .80346 Mdot
.64959 .52623 Mdot
.37239 .58216 Mdot
.33471 .5832 Mdot
.57249 .27902 Mdot
.65197 .59717 Mdot
.43116 .41669 Mdot
.37919 .42441 Mdot
.55298 .7468 Mdot
.24682 .6517 Mdot
.46238 .68207 Mdot
.51541 .48994 Mdot
.65454 .47049 Mdot
.66077 .49621 Mdot
.66299 .48263 Mdot
.393 .53701 Mdot
.4905 .60802 Mdot
.36983 .59205 Mdot
.46167 .321 Mdot
.37746 .39608 Mdot
.60402 .53235 Mdot
.56089 .4163 Mdot
.5559 .31436 Mdot
.55358 .35983 Mdot
.40375 .43692 Mdot
.34124 .61918 Mdot
.50432 .75995 Mdot
.7068 .21615 Mdot
.60202 .33501 Mdot
.45225 .65781 Mdot
.63597 .56134 Mdot
.36716 .57034 Mdot
.53629 .31815 Mdot
.4496 .68335 Mdot
.61456 .48805 Mdot
.30085 .63093 Mdot
.64988 .52184 Mdot
.53748 .48503 Mdot
.52758 .36304 Mdot
.38762 .20125 Mdot
.5102 .35709 Mdot
.38633 .37321 Mdot
.41287 .38066 Mdot
.6879 .5364 Mdot
.80206 .57266 Mdot
.53737 .30799 Mdot
.36961 .45666 Mdot
.50497 .68343 Mdot
.26611 .45558 Mdot
.45844 .68081 Mdot
.33588 .57575 Mdot
.47385 .65837 Mdot
.34501 .58392 Mdot
.54518 .76835 Mdot
.5781 .39191 Mdot
.48777 .67788 Mdot
.40787 .62667 Mdot
.64368 .59794 Mdot
.45523 .69331 Mdot
.63723 .46032 Mdot
.61653 .25929 Mdot
.34459 .55833 Mdot
.49231 .66336 Mdot
.61392 .49084 Mdot
.16028 .45129 Mdot
.42069 .41228 Mdot
.43164 .41234 Mdot
.61307 .47023 Mdot
.40227 .55784 Mdot
.55451 .38831 Mdot
.33345 .27367 Mdot
.42999 .37678 Mdot
.68757 .54657 Mdot
.66155 .56941 Mdot
.57437 .31237 Mdot
.47504 .37419 Mdot
.68497 .53578 Mdot
.75801 .57042 Mdot
.67842 .51774 Mdot
.41062 .43152 Mdot
.53083 .31547 Mdot
.55204 .35255 Mdot
.36709 .5383 Mdot
.57464 .33474 Mdot
.60033 .30244 Mdot
.40498 .34248 Mdot
.60748 .46165 Mdot
.38739 .41721 Mdot
.44096 .33581 Mdot
.46385 .32063 Mdot
.21872 .34861 Mdot
.57195 .3072 Mdot
.66392 .57515 Mdot
.55871 .38069 Mdot
.46985 .69031 Mdot
.54471 .36217 Mdot
.53909 .38898 Mdot
.64806 .5556 Mdot
.61661 .53539 Mdot
.36248 .58364 Mdot
.48718 .57817 Mdot
.55823 .37637 Mdot
.69242 .53215 Mdot
.68049 .49354 Mdot
.6698 .48189 Mdot
.47829 .43148 Mdot
.52113 .32331 Mdot
.73394 .29257 Mdot
.55686 .65913 Mdot
.55932 .37597 Mdot
.17454 .60512 Mdot
.24199 .53111 Mdot
.33116 .5997 Mdot
.36048 .38136 Mdot
.67154 .51223 Mdot
.3336 .5876 Mdot
.61734 .53908 Mdot
.54494 .52557 Mdot
.64883 .54528 Mdot
.46065 .67265 Mdot
.67371 .48113 Mdot
.39364 .5946 Mdot
.37555 .55123 Mdot
.67929 .55575 Mdot
.62469 .54628 Mdot
.51789 .79124 Mdot
.58631 .32283 Mdot
.54813 .36975 Mdot
.31666 .67568 Mdot
.48514 .68788 Mdot
.39139 .37997 Mdot
.63021 .52317 Mdot
.39545 .55027 Mdot
.37879 .55229 Mdot
.52537 .31561 Mdot
.3601 .54545 Mdot
.39225 .38553 Mdot
.64643 .52877 Mdot
.43297 .4102 Mdot
.49949 .68397 Mdot
.52365 .32463 Mdot
.60802 .5292 Mdot
.66109 .51619 Mdot
.5232 .3688 Mdot
.59001 .54305 Mdot
.45328 .66859 Mdot
.37901 .56589 Mdot
.52107 .3391 Mdot
.39082 .40218 Mdot
.33904 .58138 Mdot
.65276 .49572 Mdot
.54712 .86594 Mdot
.6767 .53941 Mdot
.66589 .50767 Mdot
.2528 .29478 Mdot
.6675 .47585 Mdot
.38935 .55837 Mdot
.57112 .31523 Mdot
.70517 .53234 Mdot
.61597 .65842 Mdot
.63592 .16693 Mdot
.37721 .58941 Mdot
.63798 .56331 Mdot
.16838 .409 Mdot
.65424 .56316 Mdot
.80816 .51221 Mdot
.42114 .63947 Mdot
.42839 .49469 Mdot
.57298 .52343 Mdot
.40252 .39146 Mdot
.36391 .58442 Mdot
.33783 .57532 Mdot
.68558 .25532 Mdot
.65046 .55741 Mdot
.52916 .49716 Mdot
.60254 .50941 Mdot
.39088 .39556 Mdot
.54531 .73125 Mdot
.38262 .55283 Mdot
.55404 .82341 Mdot
.64542 .5029 Mdot
.51306 .33163 Mdot
.34629 .61397 Mdot
.2577 .50489 Mdot
.64681 .49085 Mdot
.49198 .70021 Mdot
.36202 .38912 Mdot
.69571 .50788 Mdot
.38925 .4138 Mdot
.64702 .48751 Mdot
.74578 .52488 Mdot
.78692 .63207 Mdot
.53538 .3683 Mdot
.4069 .42954 Mdot
.3782 .35242 Mdot
.69329 .56652 Mdot
.51955 .33998 Mdot
.56082 .36212 Mdot
.49338 .70323 Mdot
.48943 .48763 Mdot
.42842 .28018 Mdot
.7552 .44926 Mdot
.67636 .24382 Mdot
.34384 .61598 Mdot
.30415 .40441 Mdot
.63755 .49015 Mdot
.29567 .69302 Mdot
.4174 .378 Mdot
.67433 .54703 Mdot
.62727 .29442 Mdot
.54244 .31997 Mdot
.67392 .52696 Mdot
.46549 .67276 Mdot
.32142 .70943 Mdot
.31712 .71579 Mdot
.20535 .51868 Mdot
.35677 .57448 Mdot
.70411 .48957 Mdot
.62857 .44944 Mdot
.36595 .52595 Mdot
.59291 .53582 Mdot
.38686 .56652 Mdot
.57913 .21378 Mdot
.44952 .67301 Mdot
.51683 .32956 Mdot
.24855 .52385 Mdot
.60006 .55669 Mdot
.63007 .47059 Mdot
.45522 .70312 Mdot
.63153 .50766 Mdot
.75288 .70079 Mdot
.27163 .56806 Mdot
.35542 .53645 Mdot
.53571 .36534 Mdot
.61099 .56552 Mdot
.50101 .4853 Mdot
.66495 .55642 Mdot
.72677 .39175 Mdot
.61053 .56302 Mdot
.44416 .26735 Mdot
.52847 .36866 Mdot
.38514 .41303 Mdot
.68671 .57558 Mdot
.64317 .54153 Mdot
.52765 .63169 Mdot
.57735 .50752 Mdot
.69561 .53466 Mdot
.56127 .38993 Mdot
.53992 .31483 Mdot
.53178 .34364 Mdot
.36643 .60035 Mdot
.25007 .66126 Mdot
.39459 .42372 Mdot
.70779 .56523 Mdot
.35722 .40761 Mdot
.77525 .52236 Mdot
.44963 .66603 Mdot
.18306 .43314 Mdot
.61481 .51534 Mdot
.53819 .34213 Mdot
.26561 .36916 Mdot
.57419 .37042 Mdot
.50533 .52198 Mdot
.40664 .40772 Mdot
.54798 .31969 Mdot
.637 .53642 Mdot
.47856 .58578 Mdot
.17681 .49042 Mdot
.37532 .41491 Mdot
.61145 .57625 Mdot
.33394 .59416 Mdot
.25094 .61063 Mdot
.53014 .86525 Mdot
.42071 .41544 Mdot
.38692 .35278 Mdot
.64889 .55897 Mdot
.55916 .31371 Mdot
.39881 .38858 Mdot
.42247 .40247 Mdot
.35966 .54427 Mdot
.61539 .53305 Mdot
.61378 .52952 Mdot
.37755 .60038 Mdot
.37391 .41648 Mdot
.58129 .51233 Mdot
.6902 .51172 Mdot
.14069 .43049 Mdot
.54208 .58913 Mdot
.47824 .13388 Mdot
.60436 .31759 Mdot
.63109 .32773 Mdot
.35662 .24881 Mdot
.52412 .37684 Mdot
.60601 .53869 Mdot
.71309 .52147 Mdot
.37933 .54168 Mdot
.65893 .53545 Mdot
.35747 .51789 Mdot
.40717 .42374 Mdot
.17379 .58714 Mdot
.41862 .3194 Mdot
.57922 .20046 Mdot
.65943 .53784 Mdot
.47684 .3294 Mdot
.47531 .68019 Mdot
.43635 .43055 Mdot
.52709 .33686 Mdot
.62993 .48062 Mdot
.51803 .79278 Mdot
.3692 .59274 Mdot
.56985 .3429 Mdot
.45317 .78959 Mdot
.42013 .75012 Mdot
.64647 .4815 Mdot
.35451 .59959 Mdot
.27169 .3448 Mdot
.74132 .58565 Mdot
.44408 .40553 Mdot
.45974 .67551 Mdot
.35847 .58824 Mdot
.37083 .41597 Mdot
.59108 .40444 Mdot
.55574 .32134 Mdot
.51997 .38691 Mdot
.59176 .78748 Mdot
.35788 .52744 Mdot
.47647 .67625 Mdot
.24616 .64311 Mdot
.3066 .71813 Mdot
.46164 .6713 Mdot
.36799 .60561 Mdot
.5382 .31611 Mdot
.54001 .33042 Mdot
.55469 .35861 Mdot
.52936 .82021 Mdot
.51331 .36686 Mdot
.71747 .29911 Mdot
.65371 .47491 Mdot
.70958 .47579 Mdot
.64389 .56382 Mdot
.43245 .41762 Mdot
.52212 .35817 Mdot
.44982 .5327 Mdot
.64941 .58927 Mdot
.19368 .53253 Mdot
.66858 .55843 Mdot
.43144 .43197 Mdot
.67192 .51983 Mdot
.75312 .34962 Mdot
.55317 .38159 Mdot
.65376 .52946 Mdot
.43797 .40071 Mdot
.48031 .69424 Mdot
.52892 .39738 Mdot
.60852 .53287 Mdot
.34978 .29421 Mdot
.67039 .47782 Mdot
.53533 .20587 Mdot
.56537 .61395 Mdot
.45226 .65787 Mdot
.58042 .59533 Mdot
.34771 .52998 Mdot
.67141 .4545 Mdot
.71136 .4888 Mdot
.37515 .40906 Mdot
.23583 .4947 Mdot
.35602 .56501 Mdot
.42997 .68899 Mdot
.7226 .54317 Mdot
.47051 .70864 Mdot
.58935 .33666 Mdot
.43083 .4257 Mdot
.59117 .51377 Mdot
.62226 .58825 Mdot
.5918 .23603 Mdot
.72055 .56159 Mdot
.6498 .57188 Mdot
.44659 .68268 Mdot
.67483 .26215 Mdot
.66351 .52679 Mdot
.5057 .51123 Mdot
.50543 .36614 Mdot
.58245 .50175 Mdot
.75284 .32508 Mdot
.69198 .53722 Mdot
.56859 .32921 Mdot
.55988 .3989 Mdot
.35754 .32085 Mdot
.50237 .69533 Mdot
.60405 .55532 Mdot
.81422 .46085 Mdot
.6426 .50472 Mdot
.40206 .41924 Mdot
.67069 .49302 Mdot
.35194 .58308 Mdot
.51497 .81318 Mdot
.37297 .53496 Mdot
.61381 .55868 Mdot
.55665 .35437 Mdot
.37451 .39261 Mdot
.5939 .79931 Mdot
.33608 .64873 Mdot
.70415 .28893 Mdot
.57888 .18018 Mdot
.47104 .65472 Mdot
.48 .71568 Mdot
.42845 .42915 Mdot
.6545 .52835 Mdot
.80323 .3771 Mdot
.58076 .49832 Mdot
.66993 .5258 Mdot
.64759 .54595 Mdot
.22686 .60073 Mdot
.39457 .42936 Mdot
.35399 .55254 Mdot
.68338 .53753 Mdot
.6881 .52125 Mdot
.52844 .37878 Mdot
.48393 .69478 Mdot
.33325 .58127 Mdot
.49295 .68202 Mdot
.36977 .57698 Mdot
.17086 .59389 Mdot
.69213 .57501 Mdot
.47969 .69195 Mdot
.38364 .36946 Mdot
.56604 .36439 Mdot
.39628 .34273 Mdot
.33629 .57439 Mdot
.38073 .54709 Mdot
.67612 .5554 Mdot
.56897 .32787 Mdot
.57352 .36134 Mdot
.46939 .69191 Mdot
.41606 .38776 Mdot
.6087 .53843 Mdot
.60438 .49452 Mdot
.53797 .26552 Mdot
.39922 .55148 Mdot
.53596 .51468 Mdot
.31979 .3256 Mdot
.65155 .52581 Mdot
.57142 .36149 Mdot
.63613 .54971 Mdot
.37917 .22869 Mdot
.56461 .31754 Mdot
.69369 .54346 Mdot
.35547 .76908 Mdot
.32541 .61638 Mdot
.38494 .30091 Mdot
.65683 .57338 Mdot
.4816 .16881 Mdot
.6249 .4918 Mdot
.12385 .46205 Mdot
.40662 .66452 Mdot
.60295 .54308 Mdot
.65371 .499 Mdot
.72019 .44556 Mdot
.62224 .55597 Mdot
.392 .59446 Mdot
.47837 .75786 Mdot
.5512 .39018 Mdot
.38281 .25833 Mdot
.66719 .44406 Mdot
.50377 .67671 Mdot
.36555 .5294 Mdot
.41201 .5411 Mdot
.46972 .66521 Mdot
.55679 .34303 Mdot
.64178 .51903 Mdot
.46043 .50576 Mdot
.40746 .5589 Mdot
.58755 .57695 Mdot
.40293 .41618 Mdot
.30333 .46111 Mdot
.33875 .62143 Mdot
.38729 .40641 Mdot
.60622 .51845 Mdot
.72236 .451 Mdot
.64244 .74941 Mdot
.35418 .21308 Mdot
.36659 .40675 Mdot
.37191 .40785 Mdot
.50921 .82182 Mdot
.4992 .66461 Mdot
.60488 .22988 Mdot
.45201 .25992 Mdot
.38343 .38505 Mdot
.69193 .62093 Mdot
.38976 .58405 Mdot
.36124 .29131 Mdot
.50995 .31178 Mdot
.63137 .47347 Mdot
.63914 .53786 Mdot
.41299 .38429 Mdot
.58767 .27299 Mdot
.78261 .62619 Mdot
.37834 .40756 Mdot
.70191 .59308 Mdot
.46587 .4528 Mdot
.24034 .53362 Mdot
.3987 .56684 Mdot
.49954 .69959 Mdot
.43623 .6844 Mdot
.5137 .34725 Mdot
.49211 .70882 Mdot
.31279 .70403 Mdot
.6259 .51089 Mdot
.38096 .39974 Mdot
.2559 .46308 Mdot
.3945 .40317 Mdot
.47299 .66601 Mdot
.4502 .65957 Mdot
.55077 .37405 Mdot
.54616 .36845 Mdot
.63703 .35317 Mdot
.57077 .71615 Mdot
.66249 .56188 Mdot
.2047 .4595 Mdot
.56386 .37894 Mdot
.55456 .53019 Mdot
.47699 .71424 Mdot
.48349 .692 Mdot
.54179 .62834 Mdot
.61867 .52244 Mdot
.81041 .48575 Mdot
.62369 .52325 Mdot
.5519 .72667 Mdot
.62385 .57567 Mdot
.36 .54465 Mdot
.61354 .52266 Mdot
.51706 .66357 Mdot
.58906 .5133 Mdot
.6837 .50579 Mdot
.39958 .54686 Mdot
.69982 .51415 Mdot
.3505 .58167 Mdot
.62517 .56545 Mdot
.50598 .67675 Mdot
.3881 .53733 Mdot
.62632 .67661 Mdot
.46983 .61573 Mdot
.35613 .60704 Mdot
.47975 .70918 Mdot
.499 .66877 Mdot
.6673 .66416 Mdot
.52693 .33579 Mdot
.49563 .34973 Mdot
.65764 .53096 Mdot
.36311 .51844 Mdot
.39995 .42983 Mdot
.68339 .51722 Mdot
.69525 .497 Mdot
.67326 .56744 Mdot
.5135 .33794 Mdot
.3048 .65098 Mdot
.47472 .69342 Mdot
.37288 .5993 Mdot
.51829 .71069 Mdot
.40386 .5713 Mdot
.68646 .5868 Mdot
.71222 .50787 Mdot
.6247 .36392 Mdot
.24261 .42642 Mdot
.4939 .83204 Mdot
.55946 .32228 Mdot
.33442 .55547 Mdot
.49679 .66382 Mdot
.56433 .54791 Mdot
.53483 .33612 Mdot
.34952 .58411 Mdot
.64896 .52192 Mdot
.6145 .57773 Mdot
.45694 .34727 Mdot
.62952 .44237 Mdot
.58756 .6415 Mdot
.40161 .57383 Mdot
.32771 .55881 Mdot
.30275 .71064 Mdot
.467 .7495 Mdot
.4606 .55362 Mdot
.66161 .55089 Mdot
.49375 .69824 Mdot
.53653 .31812 Mdot
.61787 .76961 Mdot
.42326 .38976 Mdot
.48717 .57482 Mdot
.65786 .53665 Mdot
.41876 .50034 Mdot
.55736 .35583 Mdot
.46435 .67645 Mdot
.41073 .38288 Mdot
.44535 .69547 Mdot
.37578 .52552 Mdot
.66959 .20942 Mdot
.63849 .50522 Mdot
.66915 .56149 Mdot
.3992 .37133 Mdot
.53727 .32192 Mdot
.4549 .70591 Mdot
.56633 .23449 Mdot
.3441 .55082 Mdot
.81375 .3975 Mdot
.57684 .33737 Mdot
.74842 .35871 Mdot
.37952 .5964 Mdot
.40168 .43724 Mdot
.65461 .67552 Mdot
.3863 .39303 Mdot
.61569 .5629 Mdot
.54532 .34872 Mdot
.41645 .4162 Mdot
.50615 .58978 Mdot
.16554 .42794 Mdot
.76383 .39346 Mdot
.62852 .51692 Mdot
.15417 .49033 Mdot
.48066 .20512 Mdot
.58971 .32311 Mdot
.39156 .37506 Mdot
.67075 .55421 Mdot
.59461 .53203 Mdot
.6464 .50645 Mdot
.41262 .40601 Mdot
.24539 .55995 Mdot
.34285 .55901 Mdot
.64685 .56173 Mdot
.49768 .69866 Mdot
.34949 .57521 Mdot
.24862 .52141 Mdot
.38731 .55379 Mdot
.57906 .30936 Mdot
.67129 .49239 Mdot
.40224 .44977 Mdot
.13256 .53136 Mdot
.3805 .42178 Mdot
.36148 .60749 Mdot
.67409 .50255 Mdot
.24867 .45768 Mdot
.53276 .34202 Mdot
.3498 .54444 Mdot
.67812 .54666 Mdot
.25224 .53246 Mdot
.53346 .79622 Mdot
.38651 .55375 Mdot
.5329 .32949 Mdot
.31066 .26684 Mdot
.66412 .53776 Mdot
.62739 .49352 Mdot
.54544 .32469 Mdot
.72933 .47578 Mdot
.45912 .79854 Mdot
.6294 .54799 Mdot
.38446 .41136 Mdot
.79715 .32972 Mdot
.70218 .53675 Mdot
.54778 .67264 Mdot
.36095 .58567 Mdot
.35322 .31039 Mdot
.53443 .53194 Mdot
.55783 .53304 Mdot
.55594 .23971 Mdot
.51025 .42138 Mdot
.17868 .5479 Mdot
.3477 .52453 Mdot
.4197 .73057 Mdot
.17305 .55587 Mdot
.43779 .4165 Mdot
.50128 .39185 Mdot
.51794 .23468 Mdot
.60523 .81739 Mdot
.30891 .27767 Mdot
.36174 .71554 Mdot
.51357 .79412 Mdot
.45248 .48244 Mdot
.37528 .57371 Mdot
.45083 .64355 Mdot
.61236 .53682 Mdot
.47789 .20397 Mdot
.80255 .46077 Mdot
.80931 .58553 Mdot
.1525 .482 Mdot
.80118 .50604 Mdot
.17536 .44934 Mdot
.22929 .33457 Mdot
.62016 .3205 Mdot
.25167 .40659 Mdot
.82409 .41226 Mdot
.34492 .75657 Mdot
.69475 .24609 Mdot
.62812 .454 Mdot
.51221 .52647 Mdot
.5482 .1947 Mdot
.72013 .32006 Mdot
.7817 .58988 Mdot
.36615 .53667 Mdot
.56852 .31165 Mdot
.50416 .23432 Mdot
.58653 .35735 Mdot
.34072 .39291 Mdot
.32077 .25085 Mdot
.16968 .39902 Mdot
.75435 .34644 Mdot
.4488 .16201 Mdot
.6403 .29558 Mdot
.8153 .67386 Mdot
.40869 .58806 Mdot
.52261 .31467 Mdot
.46833 .73142 Mdot
.29343 .70574 Mdot
.4727 .29613 Mdot
.50927 .22341 Mdot
.24887 .59069 Mdot
.62137 .7111 Mdot
.552 .34322 Mdot
.57783 .59911 Mdot
.33549 .41621 Mdot
.42769 .32075 Mdot
.47593 .76051 Mdot
.25498 .31396 Mdot
.47147 .5207 Mdot
.36187 .2821 Mdot
.30218 .43452 Mdot
.53072 .86118 Mdot
.56175 .65077 Mdot
.60876 .36163 Mdot
.4207 .3524 Mdot
.36718 .23587 Mdot
.64884 .79079 Mdot
.57642 .73173 Mdot
.29762 .70993 Mdot
.25407 .69777 Mdot
.4457 .19658 Mdot
.30551 .77063 Mdot
.49829 .35807 Mdot
.65496 .57156 Mdot
.64482 .4273 Mdot
.81211 .44826 Mdot
.46513 .64276 Mdot
.21124 .52215 Mdot
.49753 .67177 Mdot
.56026 .29221 Mdot
.50207 .80727 Mdot
.73402 .31422 Mdot
.81868 .45649 Mdot
.46988 .71921 Mdot
.70637 .55013 Mdot
.84313 .34075 Mdot
.18126 .53254 Mdot
.3831 .31588 Mdot
.13484 .43856 Mdot
.44141 .53377 Mdot
.61926 .63291 Mdot
.41569 .41524 Mdot
.16129 .54166 Mdot
.54268 .33631 Mdot
.242 .72111 Mdot
.13465 .4905 Mdot
.75983 .64195 Mdot
.53706 .09148 Mdot
.27882 .66768 Mdot
.42788 .50025 Mdot
.4921 .40786 Mdot
.59832 .66988 Mdot
.75584 .68045 Mdot
.7592 .62305 Mdot
.26073 .43891 Mdot
.55864 .17751 Mdot
.16591 .53337 Mdot
.81155 .42151 Mdot
.67826 .22098 Mdot
.62589 .81058 Mdot
.5141 .46859 Mdot
.50669 .30743 Mdot
.41764 .58442 Mdot
.24112 .35447 Mdot
.20942 .64385 Mdot
.55317 .65606 Mdot
.65999 .17432 Mdot
.51739 .69594 Mdot
.3941 .66539 Mdot
.32882 .23069 Mdot
.63919 .70199 Mdot
.56902 .60115 Mdot
.43096 .77822 Mdot
.59213 .57843 Mdot
.40425 .76553 Mdot
.19721 .43772 Mdot
.36713 .34912 Mdot
.35065 .75632 Mdot
.3005 .30915 Mdot
.58307 .23819 Mdot
.71149 .42275 Mdot
.29141 .7106 Mdot
.57069 .37915 Mdot
.5974 .71577 Mdot
.5586 .59715 Mdot
.16247 .40276 Mdot
.38716 .35335 Mdot
.19325 .34368 Mdot
.46924 .79202 Mdot
.67425 .57639 Mdot
.67985 .46462 Mdot
.68114 .60472 Mdot
.57974 .70624 Mdot
.6936 .5138 Mdot
.46954 .31761 Mdot
.2015 .35256 Mdot
.63144 .2784 Mdot
.33332 .3598 Mdot
.23456 .50481 Mdot
.34493 .21505 Mdot
.6344 .39992 Mdot
.45461 .75125 Mdot
.52454 .73635 Mdot
.58751 .8394 Mdot
.3538 .56209 Mdot
.8062 .40359 Mdot
.44535 .41065 Mdot
.56196 .78641 Mdot
.76172 .45461 Mdot
.7418 .68419 Mdot
.20255 .351 Mdot
.3918 .74139 Mdot
.4941 .79364 Mdot
.67026 .69726 Mdot
.79797 .35182 Mdot
.22669 .51333 Mdot
.72101 .52502 Mdot
.44668 .22224 Mdot
.46357 .6545 Mdot
.65677 .38676 Mdot
.75525 .3012 Mdot
.35611 .68281 Mdot
.62896 .4656 Mdot
.69093 .7229 Mdot
.29053 .56389 Mdot
.47889 .58364 Mdot
.40285 .83871 Mdot
.63834 .59581 Mdot
.25294 .65117 Mdot
.46743 .19381 Mdot
.57754 .67486 Mdot
.36246 .22368 Mdot
.33726 .2805 Mdot
.28308 .74654 Mdot
.13788 .46738 Mdot
.32682 .65077 Mdot
.18349 .57499 Mdot
.1514 .41311 Mdot
.31359 .76818 Mdot
.73348 .52431 Mdot
.40787 .37048 Mdot
.47816 .8838 Mdot
.39675 .58766 Mdot
.22396 .61043 Mdot
.67724 .24459 Mdot
.25943 .52839 Mdot
.59313 .38724 Mdot
.59111 .45946 Mdot
.45871 .4892 Mdot
.58777 .31688 Mdot
.69603 .51158 Mdot
.42272 .82924 Mdot
.28937 .73919 Mdot
.36792 .81015 Mdot
.47425 .18129 Mdot
.18068 .58717 Mdot
.42398 .47472 Mdot
.72666 .31857 Mdot
.56676 .27912 Mdot
.63095 .47699 Mdot
.43457 .63065 Mdot
.27798 .66478 Mdot
.68492 .73059 Mdot
.46745 .28523 Mdot
.58831 .32992 Mdot
.20437 .48643 Mdot
.82369 .70894 Mdot
.64338 .31792 Mdot
.7532 .31944 Mdot
.31297 .7153 Mdot
.56815 .70537 Mdot
.22888 .37842 Mdot
.75085 .66366 Mdot
.24331 .30762 Mdot
.59177 .31942 Mdot
.67985 .24026 Mdot
.37194 .7091 Mdot
.69501 .63068 Mdot
.29847 .64451 Mdot
.18023 .40077 Mdot
.45729 .42534 Mdot
.64446 .76746 Mdot
.46295 .24536 Mdot
.76966 .63458 Mdot
.41942 .65567 Mdot
.30903 .46071 Mdot
.76053 .30748 Mdot
.29771 .37524 Mdot
.55295 .70265 Mdot
.47237 .46291 Mdot
.57738 .58005 Mdot
.50812 .41996 Mdot
.55544 .69204 Mdot
.66767 .64349 Mdot
.20319 .61123 Mdot
.10212 .48209 Mdot
.49731 .84415 Mdot
.42413 .16209 Mdot
.20973 .4206 Mdot
.61288 .47581 Mdot
.29669 .24439 Mdot
.33223 .79736 Mdot
.12612 .48645 Mdot
.32407 .49761 Mdot
.36513 .51281 Mdot
.35762 .41754 Mdot
.44872 .82115 Mdot
.28775 .61304 Mdot
.28143 .27408 Mdot
.41651 .77756 Mdot
.35336 .4002 Mdot
.72191 .75129 Mdot
.27666 .71841 Mdot
.76899 .44521 Mdot
.61672 .44267 Mdot
.57986 .53636 Mdot
.77573 .38244 Mdot
.58665 .33396 Mdot
.3073 .40472 Mdot
.57873 .72101 Mdot
.36624 .55539 Mdot
.43414 .63619 Mdot
.49565 .21942 Mdot
.67259 .48025 Mdot
.53753 .42384 Mdot
.56252 .30433 Mdot
.24619 .42032 Mdot
.41461 .33623 Mdot
.19746 .63631 Mdot
.27049 .64001 Mdot
.57226 .54262 Mdot
.57312 .67157 Mdot
.29361 .64586 Mdot
.45681 .80326 Mdot
.40727 .44184 Mdot
.15561 .46346 Mdot
.50715 .55008 Mdot
.59423 .71616 Mdot
.78839 .41552 Mdot
.59441 .257 Mdot
.68932 .48361 Mdot
.29835 .34187 Mdot
.71138 .37872 Mdot
.48777 .58352 Mdot
.52009 .29821 Mdot
.49639 .31893 Mdot
.31898 .21638 Mdot
.32851 .71497 Mdot
.29669 .44303 Mdot
.16413 .44845 Mdot
.40333 .39869 Mdot
.56316 .37615 Mdot
.45424 .62846 Mdot
.5694 .22788 Mdot
.72047 .35728 Mdot
.53385 .79662 Mdot
.26956 .55692 Mdot
.36887 .67932 Mdot
.16931 .45094 Mdot
.1586 .47768 Mdot
.82757 .55536 Mdot
.57207 .38916 Mdot
.60775 .29532 Mdot
.61133 .22384 Mdot
.5821 .32917 Mdot
.5543 .25042 Mdot
.48859 .2948 Mdot
.20201 .62893 Mdot
.3474 .41184 Mdot
.54432 .1711 Mdot
.63039 .65193 Mdot
.23571 .55554 Mdot
.58817 .80249 Mdot
.76428 .31243 Mdot
.17352 .43556 Mdot
.7252 .59764 Mdot
.75954 .47026 Mdot
.61501 .45745 Mdot
.56158 .45001 Mdot
.59143 .85271 Mdot
.46701 .6199 Mdot
.75119 .35994 Mdot
.30401 .29993 Mdot
.63894 .51258 Mdot
.49835 .84978 Mdot
.54561 .22457 Mdot
.50755 .82456 Mdot
.3578 .39653 Mdot
.611 .50044 Mdot
.59571 .49753 Mdot
.53854 .69247 Mdot
.36201 .31576 Mdot
.22997 .64118 Mdot
.75715 .29361 Mdot
.27367 .33392 Mdot
.80212 .46122 Mdot
.25196 .6445 Mdot
.27698 .28747 Mdot
.46942 .20444 Mdot
.49156 .49908 Mdot
.27957 .66097 Mdot
.64908 .69011 Mdot
.44797 .16503 Mdot
.52617 .61375 Mdot
.44505 .43237 Mdot
.49847 .27481 Mdot
.32623 .31177 Mdot
.61054 .78049 Mdot
.63775 .4832 Mdot
.45305 .78956 Mdot
.23988 .3247 Mdot
.82441 .51836 Mdot
.71595 .73471 Mdot
.47713 .84487 Mdot
.73603 .40788 Mdot
.32844 .29998 Mdot
.47114 .20994 Mdot
.83789 .40405 Mdot
.51334 .55455 Mdot
.19221 .50968 Mdot
.6569 .6923 Mdot
.16712 .44919 Mdot
.41488 .37291 Mdot
.47067 .25495 Mdot
.23463 .51016 Mdot
.19098 .59393 Mdot
.6551 .41516 Mdot
.19663 .37913 Mdot
.43776 .51345 Mdot
.26317 .73145 Mdot
.28685 .38023 Mdot
.44849 .47262 Mdot
.34429 .54281 Mdot
.38632 .74385 Mdot
.1917 .4336 Mdot
.23012 .42504 Mdot
.76196 .31457 Mdot
.32098 .57464 Mdot
.44921 .63854 Mdot
.78491 .45872 Mdot
.64271 .72545 Mdot
.30849 .31949 Mdot
.57356 .67169 Mdot
.1881 .37907 Mdot
.52323 .71226 Mdot
.46722 .78202 Mdot
.25207 .63377 Mdot
.64274 .19146 Mdot
.38055 .31413 Mdot
.34897 .73606 Mdot
.5314 .22272 Mdot
.39693 .65486 Mdot
.67517 .6264 Mdot
.10285 .61969 Mdot
.6341 .20224 Mdot
.26829 .39319 Mdot
.20994 .64409 Mdot
.38005 .22194 Mdot
.24655 .42451 Mdot
.74831 .68905 Mdot
.54082 .58631 Mdot
.52387 .774 Mdot
.64748 .54493 Mdot
.38373 .82628 Mdot
.61755 .72784 Mdot
.22502 .67117 Mdot
.30973 .23258 Mdot
.77704 .3912 Mdot
.68108 .48847 Mdot
.3697 .59744 Mdot
.34462 .37017 Mdot
.6159 .74917 Mdot
.71908 .45681 Mdot
.59901 .61839 Mdot
.26917 .57182 Mdot
.36445 .52598 Mdot
.30728 .66208 Mdot
.59601 .3159 Mdot
.27169 .59952 Mdot
.31931 .32313 Mdot
.31959 .61266 Mdot
.47873 .53394 Mdot
.5609 .69321 Mdot
.53802 .54252 Mdot
.76749 .43965 Mdot
.72782 .69781 Mdot
.51802 .44636 Mdot
.38899 .55391 Mdot
.74868 .43911 Mdot
.57335 .1891 Mdot
.27579 .34342 Mdot
.24722 .68953 Mdot
.42316 .7652 Mdot
.76507 .49253 Mdot
.55038 .6952 Mdot
.76573 .66614 Mdot
.78898 .55495 Mdot
.22122 .46303 Mdot
.55356 .47754 Mdot
.77587 .56271 Mdot
.45558 .22759 Mdot
.17075 .58171 Mdot
.6919 .245 Mdot
.63702 .22306 Mdot
.41458 .61781 Mdot
.71027 .31929 Mdot
.78684 .42928 Mdot
.63215 .67189 Mdot
.46692 .56426 Mdot
.79236 .70229 Mdot
.50158 .32436 Mdot
.63963 .84983 Mdot
.41355 .42839 Mdot
.63399 .81328 Mdot
.66314 .6809 Mdot
.47413 .45758 Mdot
.45522 .56988 Mdot
.30279 .34202 Mdot
.44806 .26694 Mdot
.49502 .18072 Mdot
.7995 .58609 Mdot
.40565 .56548 Mdot
.75952 .29174 Mdot
.65303 .19103 Mdot
.73317 .44592 Mdot
.70255 .55372 Mdot
.62848 .19749 Mdot
.33516 .53723 Mdot
.68604 .73068 Mdot
.36432 .21884 Mdot
.23494 .40268 Mdot
.74311 .54713 Mdot
.57168 .70917 Mdot
.19039 .50136 Mdot
.14825 .45358 Mdot
.73955 .72484 Mdot
.19795 .43702 Mdot
.4093 .37137 Mdot
.43513 .47623 Mdot
.20213 .38342 Mdot
.59103 .62879 Mdot
.37863 .27192 Mdot
.57378 .61058 Mdot
.72517 .7889 Mdot
.21358 .59324 Mdot
.22893 .63893 Mdot
.57286 .61666 Mdot
.51512 .37318 Mdot
.34572 .33858 Mdot
.56542 .59813 Mdot
.2466 .39174 Mdot
.54973 .20102 Mdot
.56099 .59667 Mdot
.85148 .48771 Mdot
.61378 .25952 Mdot
.33159 .51965 Mdot
.79201 .45127 Mdot
.62175 .27625 Mdot
.35804 .3928 Mdot
.48354 .76332 Mdot
.29462 .30595 Mdot
.39117 .37081 Mdot
.30446 .32438 Mdot
.35078 .2975 Mdot
.62944 .25347 Mdot
.73131 .36737 Mdot
.2562 .35493 Mdot
.69791 .43881 Mdot
.50009 .39485 Mdot
.60992 .77244 Mdot
.33951 .60859 Mdot
.29641 .29565 Mdot
.34206 .54972 Mdot
.55249 .50832 Mdot
.49297 .57966 Mdot
.75586 .54303 Mdot
.47796 .83357 Mdot
.47086 .65406 Mdot
.53344 .31184 Mdot
.65254 .81054 Mdot
.57969 .33083 Mdot
.40447 .8261 Mdot
.74659 .67488 Mdot
.78902 .41398 Mdot
.3392 .65514 Mdot
.33913 .68466 Mdot
.84417 .58706 Mdot
.51405 .41296 Mdot
.40141 .61553 Mdot
.48599 .39071 Mdot
.52219 .3186 Mdot
.25837 .63076 Mdot
.39581 .54522 Mdot
.52746 .57157 Mdot
.40054 .47416 Mdot
.48012 .33645 Mdot
.58695 .38201 Mdot
.50162 .55905 Mdot
.53719 .75754 Mdot
.1989 .61919 Mdot
.38427 .57244 Mdot
.69076 .80263 Mdot
.69337 .49087 Mdot
.69874 .4147 Mdot
.24318 .30499 Mdot
.7346 .7377 Mdot
.41571 .55731 Mdot
.66328 .19117 Mdot
.61875 .57549 Mdot
.23745 .37315 Mdot
.54848 .33642 Mdot
.65415 .22772 Mdot
.48146 .65857 Mdot
.58388 .67282 Mdot
.36464 .42563 Mdot
.64005 .77064 Mdot
.2801 .5562 Mdot
.53135 .39029 Mdot
.21329 .4319 Mdot
.61018 .29183 Mdot
.42953 .25652 Mdot
.32473 .6776 Mdot
.74202 .45011 Mdot
.72591 .35684 Mdot
.58288 .38756 Mdot
.21635 .62326 Mdot
.65993 .22697 Mdot
.16065 .58889 Mdot
.653 .60807 Mdot
.41763 .74257 Mdot
.5088 .27122 Mdot
.28578 .34392 Mdot
.54899 .47346 Mdot
.22319 .32832 Mdot
.58696 .72632 Mdot
.49978 .29472 Mdot
.554 .71994 Mdot
.56235 .50284 Mdot
.48009 .50809 Mdot
.31433 .42561 Mdot
.80957 .59756 Mdot
.53834 .48121 Mdot
.66745 .78185 Mdot
.54876 .48649 Mdot
.25945 .66607 Mdot
.60258 .33132 Mdot
.38969 .51943 Mdot
.72225 .32951 Mdot
.3809 .3529 Mdot
.16876 .56802 Mdot
.22971 .32087 Mdot
.3972 .44612 Mdot
.25615 .61004 Mdot
.35852 .24142 Mdot
.57023 .55043 Mdot
.41295 .48652 Mdot
.64033 .57181 Mdot
.58591 .28089 Mdot
.73904 .73987 Mdot
.26383 .37042 Mdot
.7193 .51227 Mdot
.17721 .54909 Mdot
.16041 .53089 Mdot
.25055 .71192 Mdot
.80774 .37995 Mdot
.52074 .37234 Mdot
.3436 .78888 Mdot
.60735 .6199 Mdot
.15032 .42734 Mdot
.22254 .45346 Mdot
.30407 .22704 Mdot
.74856 .46213 Mdot
.32018 .28783 Mdot
.77676 .61162 Mdot
.41186 .27824 Mdot
.43009 .20065 Mdot
.45365 .44727 Mdot
.28734 .44351 Mdot
.40544 .20382 Mdot
.86835 .43943 Mdot
.5701 .4572 Mdot
.35521 .28873 Mdot
.48228 .23311 Mdot
.29016 .30254 Mdot
.41447 .68314 Mdot
.67024 .49292 Mdot
.25057 .47502 Mdot
.55144 .80778 Mdot
.56084 .67693 Mdot
.45476 .63666 Mdot
.41292 .67931 Mdot
.57404 .76822 Mdot
.55014 .73715 Mdot
.69449 .24527 Mdot
.75133 .45895 Mdot
.52662 .53854 Mdot
.69216 .56784 Mdot
.60096 .36201 Mdot
.50096 .70464 Mdot
.34042 .50494 Mdot
.63376 .568 Mdot
.37208 .51552 Mdot
.42875 .26277 Mdot
.45806 .84095 Mdot
.3509 .34979 Mdot
.53837 .21528 Mdot
.51859 .30627 Mdot
.33815 .3221 Mdot
.56527 .4161 Mdot
.562 .82174 Mdot
.40959 .71662 Mdot
.55321 .65578 Mdot
.17499 .5128 Mdot
.34696 .75364 Mdot
.59893 .24904 Mdot
.34942 .76893 Mdot
.4118 .37539 Mdot
.72786 .56417 Mdot
.49469 .24589 Mdot
.3041 .66951 Mdot
.54167 .28719 Mdot
.31727 .2923 Mdot
.3914 .61945 Mdot
.34458 .73904 Mdot
.45971 .19349 Mdot
.60335 .27346 Mdot
.78336 .47516 Mdot
.15829 .48827 Mdot
.37919 .58824 Mdot
.63689 .21503 Mdot
.38104 .26446 Mdot
.40582 .72773 Mdot
.2513 .66899 Mdot
.18694 .61778 Mdot
.45114 .54098 Mdot
.62277 .69887 Mdot
.63703 .49644 Mdot
.73374 .2927 Mdot
.27648 .3626 Mdot
.68227 .4565 Mdot
.31088 .49816 Mdot
.57307 .35246 Mdot
.32402 .46006 Mdot
.51616 .52743 Mdot
.54462 .77142 Mdot
.58939 .34688 Mdot
.80825 .46824 Mdot
.51006 .68711 Mdot
.43618 .53606 Mdot
.69896 .51876 Mdot
.61083 .68922 Mdot
.82097 .44383 Mdot
.68909 .59235 Mdot
.2096 .40553 Mdot
.75301 .45131 Mdot
.58015 .23089 Mdot
.24857 .37226 Mdot
.22151 .46971 Mdot
.44117 .27094 Mdot
.73891 .35379 Mdot
.30499 .5225 Mdot
.67014 .56866 Mdot
.39545 .52329 Mdot
.57664 .36246 Mdot
.33328 .24313 Mdot
.7304 .39852 Mdot
.62706 .67931 Mdot
.48861 .44993 Mdot
.58556 .42151 Mdot
.49387 .43082 Mdot
.28061 .26033 Mdot
.41225 .27935 Mdot
.57781 .72398 Mdot
.34358 .39628 Mdot
.6594 .68104 Mdot
.73638 .69438 Mdot
.142 .51165 Mdot
.76618 .6537 Mdot
.46006 .5161 Mdot
.6786 .77627 Mdot
.29952 .36584 Mdot
.36982 .21663 Mdot
.56619 .73356 Mdot
.44581 .5615 Mdot
.48639 .63852 Mdot
.46066 .35041 Mdot
.50652 .46872 Mdot
.49253 .63025 Mdot
.53406 .56682 Mdot
.28573 .50924 Mdot
.34514 .44521 Mdot
.59116 .4607 Mdot
.22635 .60703 Mdot
.16754 .50128 Mdot
.66379 .23483 Mdot
.51196 .42813 Mdot
.43783 .72157 Mdot
.56832 .76147 Mdot
.37563 .16418 Mdot
.54326 .86507 Mdot
.63735 .49787 Mdot
.51896 .43129 Mdot
.60401 .70134 Mdot
.40211 .57613 Mdot
.5521 .57019 Mdot
.55607 .4187 Mdot
.39632 .43522 Mdot
.4626 .62532 Mdot
.36395 .75294 Mdot
.30698 .34197 Mdot
.66062 .71466 Mdot
.24376 .51653 Mdot
.45658 .84402 Mdot
.54814 .18851 Mdot
.27933 .35306 Mdot
.31971 .19808 Mdot
.33355 .42968 Mdot
.48535 .34561 Mdot
.62716 .42359 Mdot
.20483 .62398 Mdot
.57438 .66296 Mdot
.58418 .78759 Mdot
.22437 .49267 Mdot
.57826 .73031 Mdot
.64468 .62943 Mdot
.25293 .64071 Mdot
.32394 .47121 Mdot
.46647 .48193 Mdot
.34163 .68709 Mdot
.30849 .74141 Mdot
.79606 .48633 Mdot
.17927 .49713 Mdot
.56346 .80947 Mdot
.8536 .44506 Mdot
.16103 .5453 Mdot
.44171 .63185 Mdot
.42444 .70672 Mdot
.63641 .42367 Mdot
.6124 .64255 Mdot
.70065 .61618 Mdot
.67685 .7388 Mdot
.70915 .34848 Mdot
.30628 .63367 Mdot
.62503 .80123 Mdot
.55306 .70133 Mdot
.62338 .27135 Mdot
.44679 .56188 Mdot
.76059 .43662 Mdot
.26326 .61764 Mdot
.56188 .61624 Mdot
.51322 .60773 Mdot
.60661 .65473 Mdot
.74446 .44164 Mdot
.56193 .24345 Mdot
.35767 .25762 Mdot
.86321 .50039 Mdot
.21147 .49265 Mdot
.57462 .82057 Mdot
.65974 .47663 Mdot
.17368 .61935 Mdot
.36114 .26359 Mdot
.22005 .49557 Mdot
.50638 .19538 Mdot
.3519 .507 Mdot
.49948 .30038 Mdot
.671 .56812 Mdot
.19636 .45934 Mdot
.75671 .3685 Mdot
.62614 .30222 Mdot
.62467 .78355 Mdot
.57611 .68618 Mdot
.46454 .76273 Mdot
.63733 .66445 Mdot
.69922 .59219 Mdot
.56927 .31703 Mdot
.35586 .80378 Mdot
.4466 .51303 Mdot
.5552 .48887 Mdot
.71393 .47829 Mdot
.77324 .61736 Mdot
.57845 .1721 Mdot
.67894 .60472 Mdot
.32478 .73732 Mdot
.79751 .51244 Mdot
.75167 .56223 Mdot
.55105 .54446 Mdot
.43353 .10127 Mdot
.11179 .46863 Mdot
.54202 .39171 Mdot
.76184 .32819 Mdot
.80075 .51145 Mdot
.20168 .61145 Mdot
.37615 .7088 Mdot
.3272 .50676 Mdot
.75941 .6066 Mdot
.64263 .6402 Mdot
.71374 .53731 Mdot
.47746 .19291 Mdot
.13901 .49635 Mdot
.62749 .78725 Mdot
.1747 .54451 Mdot
.6487 .45462 Mdot
.71619 .55436 Mdot
.42781 .13193 Mdot
.196 .39569 Mdot
.58613 .56982 Mdot
.78135 .61183 Mdot
.50677 .30803 Mdot
.62223 .54086 Mdot
.2207 .55157 Mdot
.75278 .28787 Mdot
.55047 .70152 Mdot
.19161 .59511 Mdot
.58121 .3722 Mdot
.40775 .6041 Mdot
.40157 .43632 Mdot
.45924 .56796 Mdot
.64135 .58415 Mdot
.41605 .40706 Mdot
.76055 .54983 Mdot
.31938 .28163 Mdot
.3584 .43482 Mdot
.69809 .23913 Mdot
.22074 .30861 Mdot
.74558 .40814 Mdot
.44996 .35254 Mdot
.57086 .55713 Mdot
.61654 .26949 Mdot
.6048 .75631 Mdot
.56251 .27468 Mdot
.39145 .20631 Mdot
.16255 .67334 Mdot
.28652 .45766 Mdot
.50969 .7633 Mdot
.57653 .29497 Mdot
.52804 .52741 Mdot
.7754 .43308 Mdot
.41784 .51314 Mdot
.36841 .58769 Mdot
.59513 .47688 Mdot
.68635 .59767 Mdot
.36043 .39767 Mdot
.63134 .8483 Mdot
.6667 .4943 Mdot
.5428 .54069 Mdot
.15168 .42835 Mdot
.60874 .77328 Mdot
.68049 .41105 Mdot
.59016 .5602 Mdot
.43591 .32181 Mdot
.44524 .56141 Mdot
.27105 .30887 Mdot
.46402 .78179 Mdot
.18732 .55644 Mdot
.72765 .39508 Mdot
.78855 .4852 Mdot
.69211 .52777 Mdot
.48199 .64793 Mdot
.36823 .29008 Mdot
.21396 .53421 Mdot
.66828 .46097 Mdot
.1405 .45435 Mdot
.34421 .50849 Mdot
.27464 .5382 Mdot
.69916 .60267 Mdot
.26698 .72784 Mdot
.6759 .76633 Mdot
.77625 .40562 Mdot
.54276 .828 Mdot
.31578 .6914 Mdot
.64082 .72519 Mdot
.36797 .59645 Mdot
.65062 .45742 Mdot
.57473 .38054 Mdot
.46269 .85102 Mdot
.21055 .54584 Mdot
.26942 .4428 Mdot
.30827 .46403 Mdot
.71467 .28833 Mdot
.42639 .24812 Mdot
.28688 .23052 Mdot
.32727 .69167 Mdot
.46917 .84759 Mdot
.63667 .22063 Mdot
.57078 .28654 Mdot
.31773 .30446 Mdot
.71824 .57187 Mdot
.38609 .55928 Mdot
.19438 .57157 Mdot
.64255 .60384 Mdot
.50699 .80487 Mdot
.58988 .53788 Mdot
.48753 .82399 Mdot
.50247 .6258 Mdot
.24384 .60344 Mdot
.28515 .3892 Mdot
.74168 .69437 Mdot
.31324 .25113 Mdot
.46476 .34459 Mdot
.34102 .19528 Mdot
.31224 .26094 Mdot
.15366 .46653 Mdot
.54443 .798 Mdot
.77421 .68442 Mdot
.23124 .42841 Mdot
.25948 .35363 Mdot
.30771 .37223 Mdot
.70359 .45574 Mdot
.38345 .74081 Mdot
.68097 .60748 Mdot
.37992 .29795 Mdot
.41686 .44379 Mdot
.34523 .86601 Mdot
.5188 .65955 Mdot
.50715 .37966 Mdot
.35188 .72299 Mdot
.15347 .50314 Mdot
.73943 .49014 Mdot
.42412 .19363 Mdot
.51168 .52925 Mdot
.72028 .52555 Mdot
.72594 .37149 Mdot
.69314 .25734 Mdot
.39919 .75214 Mdot
.85009 .6003 Mdot
.55111 .19254 Mdot
.29846 .48935 Mdot
.48451 .51985 Mdot
.58379 .33099 Mdot
.57849 .40158 Mdot
.34453 .67165 Mdot
.42178 .18376 Mdot
.31981 .28573 Mdot
.20101 .38525 Mdot
.84378 .58104 Mdot
.60119 .22635 Mdot
.2029 .62289 Mdot
.2875 .36826 Mdot
.51161 .3788 Mdot
.43497 .64004 Mdot
.3092 .57558 Mdot
.27034 .43054 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2[ooooo`;o0000W?oo
ool001cooooo00?o0000ooooooooool0Zoooool2o`0009cooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo0_l0002:ooooo`;o0000__ooool001cooooo00?o0000ooooooooool0
ROooool2o`000;kooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`2kooooo`;o0000S?ooool001cooooo00?o0000ooooooooool0YOooool2
o`0001Cooooo0_l0002<ooooo`007?ooool00ol0003oooooooooo`2Uooooo`;o0000X_ooool001co
oooo00?o0000ooooooooool0Qoooool2o`0001Gooooo0_l0002Yooooo`007?ooool00ol0003ooooo
ooooo`27ooooo`;o00003oooool2o`0000Cooooo0_l0000Cooooo`;o0000U?ooool001cooooo00?o
0000ooooooooool0V?ooool2o`0001Wooooo0_l00007ooooo`;o0000Roooool001cooooo00?o0000
ooooooooool0_?ooool2o`0008_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`;o0000S?ooool2o`000;cooooo000Looooo`03o`000?oooooooooo08Sooooo0_l00000
0ooooooo0000o`00002looooo`007?ooool00ol0003oooooooooo`28ooooo`;o0000_oooool001co
oooo00?o0000ooooooooool0Q_ooool2o`0000Kooooo0_l0000Booooo`;o0000YOooool001cooooo
00?o0000ooooooooool0M_ooool2o`0000kooooo0_l00006ooooo`;o00004_ooool2o`000:Gooooo
000Looooo`03o`000?oooooooooo07Kooooo0_l0000Fooooo`;o00002Oooool2o`00033ooooo0_l0
001looooo`007?ooool00ol0003oooooooooo`2Iooooo`;o00001?ooool2o`0000cooooo0_l00000
0ooooooo0000o`000006ooooo`;o00004Oooool2o`0007cooooo000Looooo`03o`000?oooooooooo
09Oooooo0_l00005ooooo`Co00002oooool2o`000003ooooool0003o000000Kooooo0_l0000Ioooo
o`;o0000M?ooool001cooooo00?o0000ooooooooool0O_ooool2o`0001Oooooo1?l00003ooooo`Co
00004?ooool2o`0000?ooooo0_l00008ooooo`;o00004?ooool2o`0007Cooooo000Looooo`03o`00
0?oooooooooo07Wooooo0_l00003ooooo`;o00000_ooool2o`00017ooooo0ol000000ooooooo0000
o`000004o`0001?ooooo2?l00006ooooo`?o00004Oooool2o`0007?ooooo000Looooo`03o`000?oo
oooooooo07Wooooo0_l00007ooooo`;o000000?oooooo`000?l000003_ooool3o`000003ooooool0
003o000000Co00002?ooool2o`0000[ooooo1?l000001?oooooo0000o`000?ooool2o`0000?ooooo
0_l0000Booooo`;o0000Loooool001cooooo00?o0000ooooooooool0POooool2o`0000;ooooo1_l0
000>ooooo`;o00003?ooool2o`0001;ooooo0_l0000=ooooo`;o0000OOooool001cooooo00?o0000
ooooooooool0O_ooool5o`0000Cooooo1?l0000Sooooo`;o00001?ooool4o`0001;ooooo0_l0001m
ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o
0000ooooooooool0O_ooool3o`0000Gooooo0_l000000ooooooo0000o`000007ooooo`Co000000?o
ooooo`000?l000005Oooool3o`0000?ooooo1?l000000ooooooo0000o`00000Booooo`;o000000?o
ooooo`000?l000000_ooool2o`0007?ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1[ooooo`;o
00004?ooool2o`000003ooooool0003o000000Cooooo0_l00005ooooo`;o00000oooool4o`000003
ooooool0003o000000Oooooo0ol0000;ooooo`?o00001Oooool2o`000003ooooool0003o000000Ko
oooo0_l0000:ooooo`;o000000?oooooo`000?l000000_ooool2o`0007?ooooo00000ooooooo410@
ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003ooooo
ooooo`1Tooooo`;o00001Oooool2o`00013ooooo1Ol00004ooooo`;o00001Oooool2o`00017ooooo
0ol0000;ooooo`;o00004Oooool2o`000003ooooool0003o000000;ooooo0_l0000:ooooo`;o0000
Loooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^
kP06ooooo`?o0000I?ooool2o`0001Cooooo0_l00003ooooo`;o00001Oooool4o`0002Gooooo0_l0
0007ooooo`;o00002_ooool3o`000003ooooool0003o000000;o0000OOooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooo
oooo07[ooooo0_l00004ooooo`;o00001_ooool2o`0000_ooooo1Ol0000@ooooo`;o00000oooool2
o`0000Oooooo0_l0000;ooooo`;o00000oooool2o`0007gooooo00000ooooooo410@ooooo`02oooo
o`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1koooo
o`;o00000oooool2o`0000cooooo0_l00005ooooo`Go00003?ooool2o`0000;ooooo1?l0000Aoooo
o`;o00002Oooool2o`0000;ooooo0_l0001iooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;
ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`1kooooo`;o000000?o
ooooo`000?l000003_ooool2o`0000Gooooo0_l00007ooooo`;o00001_ooool2o`0000Cooooo0_l0
00000ooooooo0000o`00000>ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`;o0000
0_ooool2o`0000Kooooo0_l0001aooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1/ooooo`;o000000?oooooo`00
0?l000003Oooool3o`0000cooooo0_l00006ooooo`;o00000_ooool2o`0000?ooooo0_l0000;oooo
o`;o00000_ooool2o`0000Oooooo0_l00006ooooo`;o00000_ooool2o`000004ooooool0003o0000
ooooo`?o00001Oooool2o`0000;ooooo0_l0001aooooo`007?ooool00ol0003oooooooooo`1Toooo
o`;o00001_ooool2o`000003ooooool0003o000000?ooooo0_l00004ooooo`;o00000oooool2o`00
00cooooo0_l0000:ooooo`;o00004?ooool4o`0000Wooooo0_l00006ooooo`;o00001?ooool2o`00
00?ooooo0_l00005ooooo`;o00003_ooool2o`0006Gooooo000Looooo`03o`000?oooooooooo06Co
oooo0_l0000;ooooo`Oo00000_ooool2o`00023ooooo0ol00002ooooo`;o00002_ooool2o`0001Oo
oooo0_l00003ooooo`;o00003?ooool2o`0000;ooooo0_l00003ooooo`;o0000IOooool001cooooo
00?o0000ooooooooool0Joooool3o`0000;ooooo2_l0000Cooooo`;o00003Oooool3o`0000;ooooo
0ol00005ooooo`;o00000_ooool2o`0000?ooooo0_l0000?ooooo`;o00001_ooool2o`0000?ooooo
0_l00007ooooo`;o00000_ooool2o`0006[ooooo000Looooo`03o`000?oooooooooo05oooooo0_l0
000:ooooo`?o00000_ooool4o`0000?ooooo1Ol0000Aooooo`;o000000?oooooo`000?l000004?oo
ool2o`0000Gooooo0_l00002ooooo`;o00000oooool2o`0000cooooo0_l000000ooooooo0000o`00
0002ooooo`;o00000_ooool3o`0000;ooooo1Ol0000?ooooo`;o00001?ooool2o`0005gooooo000L
ooooo`03o`000?oooooooooo05Wooooo0_l00004ooooo`Co00001?ooool2o`0000kooooo0_l00000
0ooooooo0000o`00000Dooooo`;o00007?ooool2o`0000Gooooo1?l00007ooooo`Go00000_ooool2
o`0000?ooooo0_l00003ooooo`Co00003oooool2o`0000Cooooo0_l0001Mooooo`007?ooool00ol0
003oooooooooo`1Iooooo`;o00001_ooool2o`0000Cooooo0_l00002ooooo`;o00002?ooool4o`00
00Oooooo0_l00002ooooo`;o00004oooool2o`0001?ooooo0_l00005ooooo`Ko00001_ooool2o`00
02Oooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1Oooooo`Co00002?ooool2o`0000Oo
oooo0ol00008ooooo`?o00000_ooool2o`0001?ooooo0_l00004ooooo`?o00000_ooool2o`0000ko
oooo0_l00003ooooo`;o000000?oooooo`000?l000000oooool2o`00017ooooo0_l0000=ooooo`?o
0000Hoooool001cooooo00?o0000ooooooooool0Goooool2o`0000Wooooo0_l00008ooooo`;o0000
0_ooool2o`0000Cooooo0ol0000Nooooo`?o000000Goooooo`000?l0003o0000ooooo`02o`0000Co
oooo0_l00002ooooo`Go00001?ooool4o`0001Kooooo0_l00009ooooo`;o00000_ooool3o`0006?o
oooo000Looooo`03o`000?oooooooooo06Wooooo0ol00005ooooo`;o00001Oooool2o`000004oooo
ool0003o0000ooooo`Go00000oooool2o`000003ooooool0003o000000;ooooo0_l0000Dooooo`;o
000000Coooooo`000?l0003o00001?ooool3o`000003ooooool0003o000000;o00001Oooool2o`00
01gooooo0_l00004ooooo`;o0000J?ooool001cooooo00?o0000ooooooooool0GOooool2o`0000;o
oooo0_l00006ooooo`;o00001_ooool3o`0000Oooooo0_l00002ooooo`Co00000oooool2o`000004
ooooool0003o0000ooooo`Co00000oooool2o`000003ooooool0003o000000Gooooo0_l00007oooo
o`;o00001_ooool2o`0000?ooooo0_l00009ooooo`;o00006?ooool3o`0000;ooooo1?l0001Xoooo
o`007?ooool00ol0003oooooooooo`1Mooooo`;o00000_ooool2o`0000Kooooo0_l00005ooooo`Co
000000Coooooo`000?l0003o00003oooool2o`0000?ooooo1Ol000001Ooooooo0000o`000?l0003o
oooo00;o00001Oooool2o`0001?ooooo0ol00009ooooo`?o00005oooool2o`0000?ooooo1?l0001X
ooooo`007?ooool2o`0005gooooo0_l00004ooooo`Co00000oooool2o`0000Gooooo0_l00003oooo
o`?o000000?oooooo`000?l000000oooool2o`0000Oooooo0_l00006ooooo`;o000000Coooooo`00
0?l0003ooooo0_l0000Iooooo`Co00002oooool2o`0008Sooooo000Looooo`03o`000?oooooooooo
05_ooooo0ol00004ooooo`Co00003?ooool2o`000003ooooool0003o000000;ooooo0_l00003oooo
o`;o00004_ooool5o`0001Oooooo1?l000000ooooooo0000o`00000Dooooo`;o00004?ooool2o`00
06cooooo000Looooo`03o`000?oooooooooo05[ooooo0ol0000Cooooo`Co000000?oooooo`000?l0
00001?l00007ooooo`;o00001?ooool2o`0000Gooooo0_l000000ooooooo0000o`000003o`0001Oo
oooo0_l000000ooooooo0000o`000003o`0000Kooooo0ol0000:ooooo`;o00004?ooool4o`0006[o
oooo000Looooo`03o`000?oooooooooo05;ooooo0_l00003ooooo`;o000000?oooooo`000?l00000
1_ooool2o`0000cooooo0_l00003ooooo`Ko00001oooool2o`0000Cooooo0_l00005ooooo`;o0000
8?ooool2o`000003ooooool0003o000000Kooooo0ol000000ooooooo0000o`000002ooooo`;o0000
0oooool2o`00013ooooo1?l0001Zooooo`007?ooool00ol0003oooooooooo`1Booooo`;o00000ooo
ool2o`0000Wooooo0_l0000:ooooo`;o00000_ooool2o`0000Cooooo0_l00002ooooo`;o00002_oo
ool2o`0000Gooooo0_l0000>ooooo`;o00001oooool2o`0001;ooooo0_l00002ooooo`;o00000_oo
ool2o`0000?ooooo1?l0000:ooooo`;o0000L?ooool001cooooo00?o0000ooooooooool0HOooool2
o`0000Sooooo0_l000000ooooooo0000o`000002ooooo`;o00001?ooool2o`0000;ooooo0_l0000:
ooooo`;o00000oooool3o`0000Oooooo0_l00005ooooo`?o00001oooool2o`000003ooooool0003o
000000oooooo0_l0000=ooooo`;o00000_ooool2o`0000Kooooo0_l0000Gooooo`;o0000Eoooool0
01cooooo00?o0000ooooooooool0Eoooool2o`0000Sooooo0_l00008ooooo`;o00001?ooool2o`00
00Kooooo0_l00002ooooo`Co00002Oooool2o`000003ooooool0003o000000?o00001Oooool2o`00
00Gooooo0ol0000:ooooo`;o00005oooool2o`0000Wooooo0_l0000Oooooo`;o0000Eoooool001co
oooo00?o0000ooooooooool0Eoooool4o`0000kooooo0_l00006ooooo`?o00000oooool4o`0000;o
oooo1?l00002ooooo`;o00001Oooool4o`0000;ooooo0_l0000@ooooo`;o00005oooool4o`000003
ooooool0003o000000;ooooo0_l000000ooooooo0000o`000004o`0000_ooooo0_l00004ooooo`Co
0000Ioooool001cooooo00?o0000ooooooooool0Eoooool4o`0000kooooo0_l00007ooooo`;o0000
0oooool2o`0000[ooooo0_l00007ooooo`?o00003?ooool2o`000003ooooool0003o000000;ooooo
0_l0000?ooooo`;o00001_ooool4o`000003ooooool0003o000000Cooooo1ol0000;ooooo`;o0000
1?ooool4o`0006Oooooo000Looooo`03o`000?oooooooooo05Cooooo0_l000001?oooooo0000o`00
0?l00007ooooo`;o00007oooool2o`000003ooooool0003o000000Kooooo0_l0000<ooooo`;o0000
00?oooooo`000?l000002?ooool2o`0000Wooooo1Ol00005ooooo`;o00001oooool2o`000004oooo
ool0003o0000o`0007gooooo000Looooo`03o`000?oooooooooo05Cooooo0_l0000;ooooo`;o0000
00?oooooo`000?l000001?ooool2o`0000Kooooo0_l0000>ooooo`;o000000?oooooo`000?l00000
0_l0000Fooooo`;o00001oooool2o`0000;ooooo0_l00006ooooo`Co00000oooool2o`0000cooooo
1?l0001looooo`007?ooool00ol0003oooooooooo`1Sooooo`?o00001?ooool2o`0000Kooooo0_l0
000Cooooo`;o00002oooool2o`0000Wooooo0_l0000;ooooo`;o00002?ooool2o`0000?ooooo0_l0
0006ooooo`;o00001_ooool2o`0001Oooooo0_l0000<ooooo`;o0000EOooool001cooooo00?o0000
ooooooooool0E_ooool2o`0000_ooooo0ol00009ooooo`?o00000oooool2o`0001gooooo0_l0000F
ooooo`;o000000?oooooo`000?l000001Oooool2o`0000_ooooo0_l0000Looooo`;o000000?ooooo
o`000?l000002?ooool2o`000004ooooool0003o0000o`0005Gooooo000Looooo`03o`000?oooooo
oooo05Kooooo0_l0000;ooooo`?o00002Oooool8o`0000;ooooo0_l0000aooooo`;o000000Cooooo
o`000?l0003ooooo0_l000000ooooooo0000o`000002o`0000Wooooo0_l0000Mooooo`;o000000?o
ooooo`000?l000002?ooool2o`000003ooooool0003o000000;o0000E?ooool001cooooo00?o0000
ooooooooool0C_ooool2o`0000gooooo0_l00004ooooo`;o00002Oooool2o`000003ooooool0003o
000000?o00000oooool2o`0001?ooooo0_l0000;ooooo`;o00000_ooool2o`0000Oooooo0_l00008
ooooo`;o000000?oooooo`000?l000001?l00007ooooo`;o00001?ooool2o`00027ooooo0_l00000
0ooooooo0000o`000002ooooo`?o00000oooool2o`0004oooooo000Looooo`03o`000?oooooooooo
04kooooo1?l0000;ooooo`;o00003?ooool2o`000004ooooool0003o0000ooooo`;o00001Oooool2
o`0001;ooooo1?l00006ooooo`;o00000oooool2o`0000;ooooo0_l00004ooooo`;o000000?ooooo
o`000?l000000oooool8o`0000;ooooo1?l00002ooooo`;o00000oooool2o`0000Cooooo0_l00002
ooooo`;o00007Oooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o0000Coooool0
01cooooo0_l0001Aooooo`;o000000?oooooo`000?l000002?ooool4o`0000Kooooo0_l00002oooo
o`Go00001?ooool2o`0000;ooooo0ol0000Aooooo`;o00002?ooool2o`0000Kooooo0_l00005oooo
o`?o00000oooool=o`0000Gooooo0_l0000=ooooo`;o00005oooool2o`0000_ooooo0_l0001Eoooo
o`007?ooool00ol0003oooooooooo`1Cooooo`;o00001_ooool2o`0000;ooooo0_l00002ooooo`;o
00000_ooool2o`0000?ooooo0_l00006ooooo`;o00000oooool2o`0000kooooo0_l00002ooooo`;o
00001Oooool2o`0000Cooooo0_l00002ooooo`;o00001_ooool2o`000003ooooool0003o000000go
00001oooool2o`0000Oooooo0_l0000Kooooo`;o00001Oooool2o`0000Cooooo0_l0001Eooooo`00
7?ooool00ol0003oooooooooo`1;ooooo`;o00003_ooool3o`0000Gooooo0_l0000Tooooo`;o0000
0_ooool2o`0000Gooooo0_l00004ooooo`;o00001Oooool2o`0000;ooooo0ol000000ooooooo0000
o`000005o`000003ooooool0003o000000Oo00001Oooool4o`0000Gooooo0_l0000Mooooo`;o0000
0oooool2o`0000?ooooo1?l0001Dooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00001Ooo
ool2o`0000Oooooo0_l00006ooooo`Co00002_ooool2o`0000?ooooo0_l0000`ooooo`;o000000?o
ooooo`000?l000000_l00002oooooa3o00001oooool2o`0002Cooooo0_l00008ooooo`Co0000E?oo
ool001cooooo00?o0000ooooooooool0A?ooool2o`0000;ooooo1?l00003ooooo`;o00000oooool2
o`0000Sooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002
o`0000gooooo0_l0000Eooooo`;o00002_ooool7o`000003ooooool0003o000000oo00000_ooool2
o`00033ooooo0ol00003ooooo`?o0000D_ooool001cooooo00?o0000ooooooooool0B?ooool4o`00
00?ooooo0_l0000=ooooo`;o00000_ooool2o`0000;ooooo0_l00004ooooo`?o00000oooool2o`00
00Cooooo0ol00003ooooo`Co000000?oooooo`000?l000004?ooool3o`0000[ooooo0_l000000ooo
oooo0000o`00000Co`000003ooooool0003o000000?o0000:oooool2o`000004ooooool0003o0000
o`0000?ooooo0ol0001Booooo`007?ooool00ol0003oooooooooo`1Nooooo`Co00001_ooool2o`00
00;ooooo0_l00004ooooo`;o00001?ooool3o`0000Gooooo0_l000000ooooooo0000o`000003o`00
0003ooooool0003o000000;ooooo0_l00006ooooo`?o00001Oooool4o`000004ooooool0003o0000
oooooa_o000000?oooooo`000?l000002_ooool2o`0001Cooooo0_l000000ooooooo0000o`000002
o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`00001Cooooo`007?ooool00ol0
003oooooooooo`17ooooo`;o00000_ooool2o`0000kooooo0_l00003ooooo`?o000000?oooooo`00
0?l000000_ooool4o`0000Cooooo0_l0000Booooo`So000000?oooooo`000?l000000oooool6o`00
0004ooooool0003o0000ooooo`Go00000ooooolJo`0000?ooooo0_l000000ooooooo0000o`000002
o`000003ooooool0003o000000;ooooo0_l0000Dooooo`;o000000?oooooo`000?l000000_l00000
0ooooooo0000o`000004ooooo`;o00001Oooool2o`000003ooooool0003o000004cooooo000Loooo
o`03o`000?oooooooooo04Oooooo0_l000001?oooooo0000o`000?l0000>ooooo`;o00000_ooool7
o`0000;ooooo1?l00004ooooo`;o00001_ooool2o`0000cooooo0ol000001?oooooo0000o`000?oo
ool4o`000003ooooool0003o000000Co000000Coooooo`000?l0003ooooo7_l000001?oooooo0000
o`000?l00006ooooo`Oo00009?ooool4o`0000Gooooo0_l000000ooooooo0000o`00001<ooooo`00
7?ooool00ol0003oooooooooo`15ooooo`;o00000oooool2o`000003ooooool0003o000000cooooo
0_l00002ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00003_ooool2o`0000cooooo
0_l00005ooooo`Co000000?oooooo`000?l000000_ooool3o`000003ooooool0003o000000;ooooo
8?l00009ooooo`Co00000oooool2o`0001oooooo1?l000000ooooooo0000o`00001Cooooo`007?oo
ool00ol0003oooooooooo`15ooooo`;o00000oooool2o`000003ooooool0003o000001_ooooo0_l0
000Fooooo`;o00002_ooool2o`0000Kooooo0ol000001?oooooo0000o`000?ooool2o`0000?ooooo
7?l000001?oooooo0000o`000?l00005ooooo`Co00000oooool2o`0001Oooooo0_l0000;ooooo`;o
00000oooool2o`0000Cooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`17ooooo`;o0000
00?oooooo`000?l000002Oooool2o`0001?ooooo0_l00009ooooo`;o000000?oooooo`000?l00000
2?ooool2o`0001;ooooo0_l00005ooooo`;o00001?ooool4o`000003ooooool0003o000001?o0000
0_ooool3o`0002Gooooo0_l0000>ooooo`Co00001?ooool2o`0004Sooooo000Looooo`03o`000?oo
oooooooo04Oooooo0_l000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l000005?oo
ool4o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000002Oooool3o`0000Gooooo0_l0
0009ooooo`Co00001_ooool2o`000003ooooool0003o000001Wo00000_ooool2o`00027ooooo0_l0
000Booooo`;o0000D?ooool001cooooo00?o0000ooooooooool0D_ooool2o`0001Gooooo1_l00002
ooooo`;o00002oooool3o`0000;ooooo0ol00005ooooo`;o00002_ooool3o`0000Gooooo7ol00003
ooooo`;o00002oooool2o`0001?ooooo0_l0000>ooooo`;o00006Oooool2o`0003Wooooo000Loooo
o`03o`000?oooooooooo03_ooooo0_l00004ooooo`;o00004_ooool3o`000003ooooool0003o0000
00;ooooo1Ol00007ooooo`;o00004_ooool5o`00017ooooo0_l0000:oooooa_o000000?oooooo`00
0?l000001?ooool2o`0000_ooooo0_l0000Mooooo`;o00001?ooool2o`0000oooooo0_l00008oooo
o`;o0000>Oooool001cooooo00?o0000ooooooooool0>oooool2o`0000Cooooo0_l000000ooooooo
0000o`00000?ooooo`?o000000?oooooo`000?l000000_ooool5o`0000kooooo0_l0000;ooooo`;o
000000?oooooo`000?l000003oooool4o`0000Gooooo0_l00002ooooo`;o00000_oooolHo`000004
ooooool0003o0000o`0002oooooo0_l00002ooooo`Co00003oooool2o`0004?ooooo000Looooo`;o
0000A?ooool3o`0000Kooooo0_l0000>ooooo`;o00004?ooool4o`0000;ooooo0_l00007ooooo`Go
00003oooool3o`0000Kooooo0_l000001?oooooo0000o`000?l00002oooooa;o000000?oooooo`00
0?l000001ol00002ooooo`?o00008?ooool2o`0000cooooo1?l00009ooooo`;o00001?ooool2o`00
04?ooooo000Looooo`03o`000?oooooooooo03kooooo0_l00003ooooo`?o00001_ooool4o`000003
ooooool0003o000000Cooooo0_l00003ooooo`;o00004?ooool2o`0000?ooooo0ol000000ooooooo
0000o`000003o`0000;ooooo1?l00003ooooo`;o00001oooool2o`0000;ooooo0_l00009ooooo`;o
00000ooooolMo`000004ooooool0003o0000o`0000Sooooo0_l0000Fooooo`;o00001_ooool3o`00
00?ooooo0_l00007ooooo`;o00000_ooool3o`0004Sooooo000Looooo`03o`000?oooooooooo03ko
oooo0_l0000;ooooo`;o000000?oooooo`000?l000000ol00004ooooo`;o00004?ooool2o`000003
ooooool0003o000000Gooooo0_l00002ooooo`Go00002Oooool2o`0000Oooooo0_l0000;ooooo`;o
00000_ooool:o`000003ooooool0003o000000ko000000?oooooo`000?l000000_l0000<ooooo`;o
00001?ooool2o`0001;ooooo0_l000001?oooooo0000o`000?ooool3o`0000cooooo0_l00002oooo
o`?o000000?oooooo`000?l00000AOooool001cooooo00?o0000ooooooooool0?_ooool3o`0000[o
oooo0_l00003ooooo`;o00005oooool2o`000003ooooool0003o000002Sooooo0_l00003ooooo`;o
000000?oooooo`000?l000006_l000000ooooooo0000o`000002ooooo`;o00004?ooool2o`0001;o
oooo1Ol00005ooooo`?o00004?ooool2o`0004Gooooo000Looooo`03o`000?oooooooooo03oooooo
0_l0000=ooooo`;o00001_ooool2o`0000[ooooo0_l00005ooooo`;o0000:oooool2o`000004oooo
ool0003o0000ooooo`Ko00000_ooool@o`000003ooooool0003o000000Ko00000_ooool2o`000003
ooooool0003o000000Cooooo0_l0000Looooo`;o00001oooool3o`0005Oooooo000Looooo`03o`00
0?oooooooooo03[ooooo0_l0000Booooo`;o00001_ooool4o`0000Cooooo0_l00002ooooo`;o0000
2Oooool2o`0000?ooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l0000:ooooo`;o0000
00Coooooo`000?l0003ooooo0ol000000ooooooo0000o`000002o`000003ooooool0003o000001;o
00000oooool2o`000003ooooool0003o000000?ooooo0ol00006ooooo`;o00005_ooool2o`0000co
oooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`0jooooo`?o00004oooool2o`000003oooo
ool0003o000000?ooooo1?l00002ooooo`[o00000oooool4o`0000?ooooo0_l00003ooooo`So0000
1Oooool2o`0000Oooooo0_l0000Aooooo`;o000000?oooooo`000?l000005ol000000ooooooo0000
o`000005ooooo`;o000000?oooooo`000?l000001oooool2o`0001Kooooo1?l00006ooooo`;o0000
0_ooool2o`00057ooooo000Looooo`03o`000?oooooooooo03_ooooo0_l0000@ooooo`;o000000?o
ooooo`000?l000000ol00005ooooo`;o00000oooool9o`0000?ooooo1?l00008ooooo`ko00005Ooo
ool2o`0000Cooooo0_l000000ooooooo0000o`00000Fo`0000;ooooo0_l00005ooooo`;o00008_oo
ool4o`0000Kooooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00002oooool2
o`0000Wooooo0_l00002ooooo`;o00000oooool2o`0000Oooooo1ol00006ooooo`;o00000_ooool3
o`0000?ooooo5?l0000:ooooo`;o00001Oooool5o`0000Cooooo0_l00002oooooaSo000000?ooooo
o`000?l000004?ooool2o`0000;ooooo0_l0000Cooooo`;o00001Oooool2o`0000Sooooo0_l00002
ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0<Oooool2o`0000Kooooo0ol00002oooo
o`;o00001oooool4o`0000Oooooo0_l00005ooooo`So00001oooool4o`0000Kooooo5Ol000000ooo
oooo0000o`000006ooooo`;o00001Oooool4o`0000Sooooo5_l000000ooooooo0000o`000002oooo
o`;o00003oooool2o`0000;ooooo0_l0000Jooooo`;o00001oooool3o`0000;ooooo0_l00002oooo
o`;o0000A_ooool001cooooo00?o0000ooooooooool0>Oooool5o`0000Sooooo0ol0000@ooooo`;o
00000_ooool3o`0000[ooooo0_l00004ooooo`?o00000ooooolDo`000003ooooool0003o000000Ko
oooo0_l0000<oooooaSo00001Oooool2o`0000Oooooo0_l00009ooooo`Co00003Oooool2o`0001?o
oooo0_l00003ooooo`;o00000_ooool4o`0004Cooooo000Looooo`03o`000?oooooooooo03Wooooo
0_l000000ooooooo0000o`000002o`0000Kooooo0_l000000ooooooo0000o`000003ooooo`;o0000
2Oooool2o`0001Gooooo1?l00002ooooo`oo000000Coooooo`000?l0003o00000_ooool4o`0000Co
oooo1?l00005ooooo`;o00000oooool3o`0000Cooooo3Ol000001?oooooo0000o`000?l00002oooo
o`?o00001Oooool2o`0000;ooooo0_l00009ooooo`Co00003Oooool2o`0001?ooooo0ol00008oooo
o`;o0000A?ooool001cooooo00?o0000ooooooooool0?_ooool2o`0000Kooooo0_l000000ooooooo
0000o`000003ooooo`;o00008_ooool2o`000003ooooool0003o000001Co00000_ooool2o`0000Ko
oooo0_l00005ooooo`;o00001Oooool4o`000003ooooool0003o000000So000000?oooooo`000?l0
00000oooool7o`0000Cooooo0_l0000=ooooo`;o00009?ooool3o`0000Gooooo0_l00017ooooo`00
7?ooool00ol0003oooooooooo`0nooooo`;o00000oooool2o`0001Cooooo0_l0000GoooooaWo0000
00?oooooo`000?l000003?ooool2o`0000Oooooo1?l000000ooooooo0000o`000008o`000003oooo
ool0003o000000Oo000000?oooooo`000?l000001oooool2o`0000[ooooo1?l000000ooooooo0000
o`00000Eooooo`;o00004?ooool2o`0000Oooooo0_l0000nooooo`0000Koooooonk^k_lb<S;o0000
oc8b<_o^k^h5ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000oooooooo
ool0=oooool2o`0000[ooooo0_l00007ooooo`;o00001Oooool3o`0000?ooooo0_l0000@ooooo`;o
00001?oooolMo`0000cooooo0_l00003ooooo`;o00001?ooool2o`000003ooooool0003o000000Co
000000Goooooo`000?l0003o0000ooooo`07o`0000cooooo0_l0000<ooooo`Go00003_ooool3o`00
00Cooooo0_l00004ooooo`;o00000oooool2o`0000kooooo0_l0000nooooo`0000KoooooogMgMonH
V9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo03Oooooo0_l00003ooooo`;o00001Oooool2o`0000Oooooo0_l00005ooooo`Go00002?ooool2
o`0000;ooooo0_l00005ooooo`?o00000_oooolLo`0000Gooooo1?l0000:ooooo`;o00001?ooool=
o`0000?ooooo1Ol0000Iooooo`;o000000Coooooo`000?l0003o00003_ooool4o`0000Wooooo0_l0
0003ooooo`;o00002oooool2o`00047ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooo
oooo00Wooooo1Ol00006ooooo`03o`000?oooooooooo03?ooooo0_l00007ooooo`;o00006?ooool2
o`0000Sooooo0_l00002ooooo`Co000000Coooooo`000?l0003ooooo8Ol00004ooooo`Co00001ooo
ool2o`000003ooooool0003o000000Kooooo1Ol00002ooooo`Ko000000Coooooo`000?l0003ooooo
0_l00008ooooo`;o00001_ooool2o`0000Oooooo0_l0000Dooooo`;o00001Oooool2o`0000_ooooo
0_l00006ooooo`?o0000@Oooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Ooo
ool01?m4A4CogMgMooooool00007ooooo`?o0000<Oooool4o`000004ooooool0003o0000o`00013o
oooo0_l0000Eooooo`;o00001?ooool2o`000003ooooool0003o000000;ooooo8?l0000?ooooo`;o
00002_ooool2o`0000Cooooo0_l00002ooooo`;o00001?ooool2o`0000Sooooo0_l00006ooooo`;o
00003oooool2o`0000Sooooo0_l00002ooooo`;o00001Oooool2o`000003ooooool0003o000000So
oooo0_l00006ooooo`;o0000@_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
2Oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo037ooooo0_l00003ooooo`?o
00001oooool2o`0000Oooooo0_l0000Dooooo`?o00002OoooolUo`0000oooooo0_l0000=ooooo`;o
00002?ooool2o`000004ooooool0003o0000o`0001gooooo0_l00008ooooo`;o00003?ooool2o`00
00?ooooo0_l00003ooooo`;o00000oooool2o`0000Sooooo0_l00003ooooo`;o0000=_ooool00003
ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00omgMgOoc<c<o`000007ooooo`03
o`000?oooooooooo03;ooooo0ol0000;ooooo`;o00003?ooool2o`0000Kooooo0_l00007ooooo`?o
00002Oooool2o`0000;ooooo0ol000000ooooooo0000o`000008o`000003ooooool0003o0000013o
00001Oooool2o`0000Cooooo0ol000000ooooooo0000o`000002ooooo`;o00000_ooool2o`0000Wo
oooo0_l00007ooooo`?o00001Oooool2o`0002;ooooo0_l000001Ooooooo0000o`000?l0003ooooo
00;o00001_ooool4o`0000?ooooo0_l00003ooooo`;o00002?ooool2o`0000?ooooo0_l0000foooo
o`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000
ooooooooool0<_ooool3o`0001Wooooo0_l00006ooooo`;o00002?ooool4o`0000Wooooo0_l00000
0ooooooo0000o`000009o`0000;ooooo4_l000000ooooooo0000o`000003ooooo`;o00001?ooool3
o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o00002?ooool3o`0000;ooooo0_l0000;
ooooo`Go00004Oooool2o`0000cooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00000ooo
ool2o`000004ooooool0003o0000o`0000oooooo0_l0000oooooo`0000Koooooonk^k_lb<S;o0000
oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0;Oooool2o`0002Oo
oooo0_l0000:ooooo`;o00002Oooool2o`0000;ooooo7_l000000ooooooo0000o`00000@ooooo`?o
00003?ooool2o`0000?ooooo0_l0000=ooooo`?o00002Oooool2o`000003ooooool0003o000000?o
oooo0_l00004ooooo`;o00000_ooool2o`0000kooooo0_l000001?oooooo0000o`000?l00003oooo
o`;o00002_ooool2o`0003oooooo000Looooo`03o`000?oooooooooo02gooooo0ol0000Vooooo`;o
00002_ooool2o`0000Gooooo0_l00005ooooo`;o000000?oooooo`000?l000006_l0000Cooooo`?o
00003?ooool5o`0000oooooo0_l0000:ooooo`;o000000?oooooo`000?l000002Oooool2o`0000;o
oooo0_l0000Gooooo`;o0000Boooool001cooooo00?o0000ooooooooool0;Oooool3o`00013ooooo
0_l000000ooooooo0000o`000007ooooo`;o00002?ooool3o`00013ooooo0_l00003ooooo`Co0000
00?oooooo`000?l000006_l0000Booooo`?o00003Oooool5o`0000Cooooo0_l00009ooooo`;o0000
0_ooool2o`0000Wooooo0_l0000^ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0;Ooo
ool2o`00017ooooo0_l000000ooooooo0000o`000007ooooo`;o00001oooool4o`0001Gooooo0ol0
0003ooooo`[o000000?oooooo`000?l000002_l000000ooooooo0000o`00000Cooooo`?o000000?o
ooooo`000?l000001?ooool4o`0000Gooooo0_l00004ooooo`;o00003?ooool5o`0000Oooooo0_l0
000=ooooo`;o00005?ooool2o`0000Wooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`0]
ooooo`;o00000oooool2o`0000_ooooo0_l00006ooooo`Oo00001oooool2o`0000Oooooo0_l00002
ooooo`;o00002_ooool4o`000003ooooool0003o000001Ko00001_ooool2o`0001;ooooo0_l00003
ooooo`Go00002?ooool2o`0000kooooo0ol000001?oooooo0000o`000?ooool2o`0001;ooooo0ol0
000Dooooo`;o00001oooool2o`0004Gooooo000Looooo`03o`000?oooooooooo02[ooooo0_l00000
1?oooooo0000o`000?l00002ooooo`?o00002_ooool2o`0000Kooooo1_l00007ooooo`Co00001_oo
ool2o`0000;ooooo0_l00005ooooo`;o00001Oooool2o`000003ooooool0003o0000017o000000?o
ooooo`000?l000000ol00005ooooo`;o00002_ooool2o`0000Cooooo0_l00005ooooo`;o00002_oo
ool3o`0000kooooo0_l00005ooooo`?o00004Oooool4o`0001Kooooo0_l00004ooooo`;o0000AOoo
ool001cooooo00?o0000ooooooooool0:_ooool2o`0000;ooooo0_l00003ooooo`;o00000oooool2
o`000003ooooool0003o000000Gooooo0_l00003ooooo`;o00002oooool4o`00017ooooo0_l00008
ooooo`;o000000?oooooo`000?l000005?l000000ooooooo0000o`000009ooooo`;o00000oooool2
o`0000?ooooo1Ol0000?ooooo`;o00003?ooool2o`0000Wooooo0_l0000Cooooo`;o00004_ooool2
o`0000;ooooo0_l00007ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0<oooool4o`00
0003ooooool0003o000000Go00000oooool2o`0000Kooooo0_l00007ooooo`?o00002?ooool2o`00
00[ooooo0_l00005ooooo`;o00000_oooolEo`0000?ooooo0_l00009ooooo`;o00001_ooool4o`00
0003ooooool0003o000001gooooo0_l0000<ooooo`;o00005_ooool2o`0000Oooooo0_l00003oooo
o`;o00002oooool2o`0004;ooooo000Looooo`03o`000?oooooooooo02Sooooo0_l00009ooooo`Co
00000oooool5o`0000_ooooo0_l00005ooooo`Co000000?oooooo`000?l000001_ooool2o`0000[o
oooo0_l00005ooooo`;o00000_oooolCo`0000Gooooo0_l00002ooooo`;o00003Oooool2o`000003
ooooool0003o000002gooooo0ol0000:ooooo`;o00002Oooool2o`0000?ooooo0_l00002ooooo`Co
00002Oooool2o`0001Cooooo0_l0000aooooo`007?ooool00ol0003oooooooooo`0Xooooo`;o0000
4_ooool2o`0000Sooooo0_l00009ooooo`;o000000?oooooo`000?l000000_l00003ooooo`Co0000
3Oooool2o`0000Wooooo3ol00003ooooo`;o00000_ooool2o`0000;ooooo0_l0000:ooooo`;o0000
0_ooool4o`0000?ooooo0_l0000Fooooo`;o00000oooool3o`000003ooooool0003o000000Sooooo
0_l0000:ooooo`;o00003Oooool3o`0000Cooooo0_l00009ooooo`;o00005?ooool2o`00037ooooo
000Looooo`03o`000?oooooooooo04Kooooo0_l00007ooooo`;o00000oooool3o`0000?ooooo1Ol0
000=ooooo`;o00003_ooool3o`000003ooooool0003o000000Co00000oooool2o`0001;ooooo0_l0
0002ooooo`;o00000_ooool2o`000003ooooool0003o000001Kooooo0_l00003ooooo`?o000000?o
ooooo`000?l000002_ooool2o`0000oooooo0_l00002ooooo`;o00000_ooool2o`0000Kooooo0_l0
00000ooooooo0000o`00000<ooooo`?o00001oooool2o`0003Kooooo000Looooo`03o`000?oooooo
oooo03;ooooo1Ol0000Hooooo`;o00002Oooool3o`0000cooooo0_l000000ooooooo0000o`00000>
ooooo`?o00001Oooool2o`0000[ooooo0_l0000;ooooo`;o00001_ooool2o`000003ooooool0003o
000001kooooo0_l0000;ooooo`;o00003oooool2o`0000;ooooo0_l00006ooooo`;o00000_ooool2
o`000003ooooool0003o000000Wooooo0_l000001?oooooo0000o`000?l00007ooooo`;o0000=_oo
ool001cooooo0_l0000aooooo`Oo00001_ooool2o`0000[ooooo0_l00003ooooo`;o000000?ooooo
o`000?l000005_ooool2o`0001Cooooo0_l00003ooooo`;o00002_ooool2o`0000Wooooo1?l00009
ooooo`;o00002Oooool2o`0000Wooooo0ol00007ooooo`;o00002oooool2o`00013ooooo0_l00004
ooooo`;o00000_ooool3o`0000Wooooo0_l00005ooooo`;o0000@oooool001cooooo00?o0000oooo
ooooool0:_ooool4o`0000;ooooo0_l000000ooooooo0000o`000002o`0000Kooooo0_l00006oooo
o`;o00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l0000Toooo
o`;o00000oooool2o`0000kooooo0_l00005ooooo`;o000000?oooooo`000?l000001?ooool2o`00
00?ooooo0_l00008ooooo`;o00002Oooool5o`0000Gooooo0_l00002ooooo`Go00001?ooool3o`00
00gooooo1?l00004ooooo`;o00000_ooool2o`000003ooooool0003o000000Oooooo0_l0001:oooo
o`007?ooool00ol0003oooooooooo`0Uooooo`;o00000oooool4o`0000Oooooo1?l00005ooooo`;o
00001Oooool2o`0000Kooooo0_l000000ooooooo0000o`000003o`0000Cooooo0_l0000Dooooo`;o
00000oooool2o`0000;ooooo1?l0000Hooooo`Ko00001?ooool2o`0000?ooooo0ol00003ooooo`;o
00001Oooool2o`0000?ooooo0_l00007ooooo`;o000000Coooooo`000?l0003ooooo0_l00002oooo
o`;o00000_ooool6o`0000Cooooo0_l00002ooooo`;o00001Oooool2o`0000;ooooo0ol00002oooo
o`;o00002?ooool2o`0000Gooooo0_l00002ooooo`;o00001?ooool3o`00047ooooo000Looooo`03
o`000?oooooooooo02Gooooo0_l0000?ooooo`?o00000oooool5o`0000[ooooo1?l000000ooooooo
0000o`000002o`0000Gooooo0_l00004ooooo`Go00000_ooool2o`0000Oooooo0_l00003ooooo`;o
00000_ooool6o`0001Sooooo1?l00009ooooo`?o00002_ooool2o`0000?ooooo0_l00005ooooo`Co
000000?oooooo`000?l000001Ol00003ooooo`Oo00000oooool2o`0000?ooooo0_l00005ooooo`?o
00000_ooool2o`0000;ooooo0_l00004ooooo`;o00002Oooool2o`0000;ooooo1?l00002ooooo`?o
0000@Oooool001cooooo00?o0000ooooooooool09Oooool2o`0000Sooooo0_l00008ooooo`;o0000
00Coooooo`000?l0003ooooo0_l00003ooooo`;o00001Oooool2o`0000;ooooo1?l0000;ooooo`Ko
00000_ooool2o`0001Cooooo0_l0000Hooooo`;o00003?ooool2o`0001Kooooo0_l00003ooooo`?o
00000_ooool3o`0000;ooooo1_l00003ooooo`Oo00001oooool2o`0000_ooooo0ol0000?ooooo`;o
00000_ooool2o`0004;ooooo000Looooo`03o`000?oooooooooo02Gooooo0_l00002ooooo`;o0000
0oooool3o`0000Sooooo0_l00004ooooo`Co000000?oooooo`000?l000002Oooool5o`0000[ooooo
1?l00006ooooo`;o00004_ooool2o`0000kooooo0ol00007ooooo`;o00002_ooool3o`0000oooooo
1?l00004ooooo`;o00000oooool2o`0000Cooooo3?l000001?oooooo0000o`000?ooool4o`0001Co
oooo1?l0000?ooooo`;o000000?oooooo`000?l00000@_ooool001cooooo00?o0000ooooooooool0
8Oooool2o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0000oooooo1?l000000ooooooo0000
o`000008ooooo`Ko00001_ooool2o`0000Oooooo0_l00003ooooo`;o00003_ooool2o`0001;ooooo
0ol0000Booooo`Co00003oooool4o`0000Sooooo2?l000000ooooooo0000o`000002o`000003oooo
ool0003o000000?o00007_ooool4o`0000Wooooo0_l00002ooooo`Go0000@_ooool001cooooo00?o
0000ooooooooool08Oooool2o`0000;ooooo0_l00007ooooo`;o00005?ooool2o`0000Sooooo1_l0
0006ooooo`;o00001oooool2o`000003ooooool0003o000000;o00000oooool2o`0000Wooooo0ol0
0003ooooo`;o000000?oooooo`000?l000002oooool2o`00013ooooo1Ol0000:ooooo`;o00000ooo
ool2o`0000Wooooo0ol000000ooooooo0000o`00000Ao`0000;ooooo0_l0000Cooooo`;o00001?oo
ool2o`0000Wooooo0_l00003ooooo`Go0000@Oooool001cooooo00?o0000ooooooooool09Oooool2
o`0002Oooooo0_l00002ooooo`;o00004_ooool2o`0000Gooooo0_l0000:ooooo`?o00000_ooool2
o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o00000_ooool2o`00013ooooo1Ol0000:
ooooo`;o00002Oooool2o`0000;ooooo0ol000000ooooooo0000o`000002o`000003ooooool0003o
000000;o000000Coooooo`000?l0003o00000_ooool9o`0000Cooooo0_l00003ooooo`;o00001?oo
ool2o`0000;ooooo0_l0000<ooooo`;o00002Oooool2o`00047ooooo000Looooo`03o`000?oooooo
oooo033ooooo0_l00006ooooo`;o00002Oooool2o`0000Wooooo0_l0000Aooooo`;o00003oooool2
o`0000Kooooo0_l000000ooooooo0000o`000005ooooo`Co00000_ooool2o`0001?ooooo1_l00003
ooooo`;o00001_ooool2o`0000?ooooo0_l00003ooooo`;o00000_ooool8o`000003ooooool0003o
000000Oo000000?oooooo`000?l000002Ol00002ooooo`;o00000oooool3o`0000?ooooo0_l0000=
ooooo`;o000000?oooooo`000?l00000C?ooool001cooooo00?o0000ooooooooool07Oooool2o`00
00oooooo1?l00006ooooo`;o00002Oooool4o`0000Kooooo0_l000000ooooooo0000o`00000<oooo
o`;o000000?oooooo`000?l000003Oooool6o`0000Oooooo0_l00004ooooo`Co00002?ooool2o`00
00?ooooo0_l00009ooooo`;o00001oooool2o`000004ooooool0003o0000o`0000;ooooo0_l00003
ooooo`?o00002?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000Co`0000?ooooo0_l00003
ooooo`;o00004_ooool2o`0000Sooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`0Moooo
o`;o00001_ooool2o`0000Oooooo0_l0000?ooooo`;o00001?ooool2o`0000Kooooo1Ol0000:oooo
o`Co00004?ooool2o`0000;ooooo0ol0000;ooooo`?o00002_ooool2o`0000?ooooo0_l00009oooo
o`;o00002_ooool5o`0000;ooooo0_l00002ooooo`;o00002OoooolIo`000005ooooool0003o0000
o`000?ooool00ol000000ooooooo0000o`00000?ooooo`;o00001_ooool2o`000004ooooool0003o
0000ooooo`?o00001Oooool2o`0003gooooo000Looooo`03o`000?oooooooooo02Gooooo0_l00009
ooooo`;o00003Oooool2o`0000cooooo1?l000000ooooooo0000o`000008ooooo`?o00001oooool2
o`0000[ooooo0_l000000ooooooo0000o`00000;ooooo`;o00003Oooool2o`0000Sooooo0_l00002
ooooo`;o00002_ooool2o`000004ooooool0003o0000ooooo`?o00001?ooool2o`0000?ooooo0_l0
0002oooooa3o000000?oooooo`000?l000002_l00002ooooo`Go00003oooool2o`0000Kooooo1_l0
00000ooooooo0000o`000005ooooo`;o00001Oooool2o`0003Kooooo000Looooo`03o`000?oooooo
oooo02Sooooo0_l00004ooooo`Co00001?ooool2o`0000Wooooo0_l00002ooooo`;o00001_ooool2
o`0000?ooooo0_l00009ooooo`;o00001oooool4o`0000Sooooo0_l000001?oooooo0000o`000?oo
ool2o`000003ooooool0003o0000013ooooo0_l00002ooooo`;o00002?ooool2o`0000;ooooo0_l0
0003ooooo`;o00001?ooool2o`0000Gooooo0ol00004ooooo`;o000000?oooooo`000?l000005_l0
00000ooooooo0000o`000005o`0000;ooooo2?l00006ooooo`?o00001oooool2o`0000Kooooo0_l0
00001?oooooo0000o`000?ooool2o`0000Gooooo0_l00005ooooo`;o0000=_ooool001cooooo00?o
0000ooooooooool0:?ooool2o`0000Cooooo0_l00006ooooo`;o00002Oooool2o`000004ooooool0
003o0000o`0000;ooooo0_l00005ooooo`;o00004Oooool2o`0000?ooooo0_l000000ooooooo0000
o`00000;ooooo`;o000000?oooooo`000?l000001oooool2o`000003ooooool0003o000000Cooooo
0_l0000Aooooo`;o00000_ooool2o`0000Cooooo0_l0000?ooooo`oo000000?oooooo`000?l00000
3_l00002ooooo`Go000000?oooooo`000?l000001_ooool3o`0000Oooooo0_l0000Aooooo`Co0000
?Oooool001cooooo00?o0000ooooooooool0:Oooool2o`0000?ooooo0_l00007ooooo`;o00002ooo
ool2o`0000?ooooo0_l00005ooooo`;o00003oooool7o`0000?ooooo0_l00004ooooo`;o00001Ooo
ool2o`0000Oooooo0_l000001?oooooo0000o`000?ooool2o`0001Gooooo1?l00004ooooo`Co0000
1Oooool2o`0000Sooooo4Ol000000ooooooo0000o`00000>o`0000;ooooo0ol00003ooooo`;o0000
8oooool2o`0000Sooooo0_l0000eooooo`007?ooool2o`0002Sooooo1?l00008ooooo`;o00000_oo
ool2o`000003ooooool0003o000000Wooooo0_l0000Jooooo`;o00000_ooool3o`0000Gooooo0_l0
0002ooooo`;o00001_ooool2o`000003ooooool0003o000000?ooooo0_l000001?oooooo0000o`00
0?ooool2o`0000oooooo0_l00002ooooo`Co00001_ooool4o`0000Gooooo0_l00005ooooo`;o0000
00?oooooo`000?l000000ooooolAo`000003ooooool0003o000000[o000000?oooooo`000?l00000
0_l00002ooooo`?o0000;?ooool2o`000003ooooool0003o000003;ooooo000Looooo`03o`000?oo
oooooooo02Oooooo0_l00005ooooo`;o00000oooool2o`0000Gooooo0_l00009ooooo`;o000000?o
ooooo`000?l000001?ooool4o`0000Wooooo0_l00002ooooo`;o00002_ooool4o`0000Cooooo0_l0
0004ooooo`;o000000?oooooo`000?l000001_ooool2o`000003ooooool0003o000000oooooo0_l0
0002ooooo`;o00005Oooool5o`000003ooooool0003o000000Cooooo7Ol00003ooooo`Oo000000?o
ooooo`000?l00000;?ooool2o`0003;ooooo000Looooo`03o`000?oooooooooo02kooooo0_l0000C
ooooo`;o00000oooool2o`0000Cooooo1_l00007ooooo`;o00000_ooool2o`0000Kooooo0_l00002
ooooo`;o00000_ooool2o`0000;ooooo0_l0000Mooooo`;o00001?ooool2o`0001Wooooo1ol00004
ooooo`So00000ooooolDo`000004ooooool0003o0000ooooo`;o000000Coooooo`000?l0003ooooo
0_l0000Gooooo`Co0000AOooool001cooooo00?o0000ooooooooool0>oooool2o`0000Kooooo0_l0
0003ooooo`?o00001oooool2o`0000Gooooo0_l00007ooooo`;o00000oooool2o`0000?ooooo0_l0
00000ooooooo0000o`00000Qooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`Co0000
3_ooool3o`0000?ooooo9ol000001?oooooo0000o`000?ooool2o`000003ooooool0003o000001[o
oooo1?l00003ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0:_ooool2o`0000Wooooo
0_l00004ooooo`;o00002Oooool2o`000003ooooool0003o000000?ooooo0_l00009ooooo`;o0000
1oooool2o`0000Sooooo0_l00005ooooo`;o00001Oooool2o`0000Sooooo0_l00004ooooo`;o0000
00?oooooo`000?l000001?ooool2o`0000Kooooo0_l000000ooooooo0000o`000003o`0000gooooo
1_l000000ooooooo0000o`00000Fo`000003ooooool0003o000000?o000000?oooooo`000?l00000
4?l0000Gooooo`?o000000?oooooo`000?l000000_ooool3o`0003oooooo000Looooo`03o`000?oo
oooooooo02[ooooo0_l00009ooooo`;o00003oooool2o`0000?ooooo0_l000000ooooooo0000o`00
0002ooooo`;o00004oooool2o`0000[ooooo1?l00003ooooo`;o00002?ooool2o`0000Cooooo0_l0
00000ooooooo0000o`000003ooooo`?o00003?ooool2o`000003ooooool0003o000000Cooooo0_l0
0006ooooo`Co00000oooool8o`000003ooooool0003o000000Oo000000?oooooo`000?l000005_l0
0002ooooo`?o00005_ooool3o`000003ooooool0003o000000?ooooo0_l0000oooooo`007?ooool0
0ol0003oooooooooo`0oooooo`;o00001Oooool2o`0000;ooooo0ol00002ooooo`;o000000?ooooo
o`000?l000004oooool3o`0000?ooooo3Ol000000ooooooo0000o`000003ooooo`;o00004?ooool4
o`0000Cooooo0_l00002ooooo`;o00001?ooool2o`0000Cooooo0_l0000>ooooobSo000000?ooooo
o`000?l000001?l0000Oooooo`;o0000?oooool001cooooo00?o0000ooooooooool0?oooool4o`00
00?ooooo0_l000001Ooooooo0000o`000?l0003ooooo00Co00000_ooool2o`0000Oooooo0_l00000
0ooooooo0000o`000007ooooo`;o00000oooool=o`000003ooooool0003o000000;o000000Cooooo
o`000?l0003ooooo0_l00002ooooo`;o00002_ooool4o`0000?ooooo0_l00002ooooo`Co00004?oo
ool6o`0000?ooooo9_l00002ooooo`Co00003Oooool2o`0000;ooooo0_l0000>ooooo`;o0000?ooo
ool001cooooo00?o0000ooooooooool0=?ooool2o`0000_ooooo1?l00004ooooo`Ko00001?ooool2
o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0000cooooo3Ol00003ooooo`;o00000_oo
ool4o`0000;ooooo0_l0000<ooooo`;o00002Oooool5o`0000Sooooo0_l00003ooooo`Ko00000ooo
oolUo`0000Cooooo1Ol000000ooooooo0000o`000002ooooo`;o00001?ooool2o`0000;ooooo1?l0
0006ooooo`;o00002Oooool2o`0003[ooooo000Looooo`03o`000?oooooooooo03Cooooo0_l0000=
ooooo`;o00001_ooool4o`0000;ooooo0_l00006ooooo`;o00004_ooool?o`0000Gooooo0ol0000M
ooooo`Go00000_ooool2o`0000?ooooo0_l00003ooooo`;o00001OoooolWo`0000;ooooo0_l00002
ooooo`Ko00000_ooool2o`0000[ooooo0_l00006ooooo`;o00002Oooool2o`0003[ooooo000Loooo
o`03o`000?oooooooooo02Oooooo0_l00007ooooo`;o00001Oooool2o`0000;ooooo0_l00009oooo
o`;o00000oooool5o`000003ooooool0003o000001[ooooo0_l00002ooooo`go00001?ooool2o`00
00[ooooo0_l0000Booooo`Co00000_ooool4o`0000Cooooo0_l00003ooooo`;o00000_ooool?o`00
0003ooooool0003o000000ko00000_ooool5o`000003ooooool0003o000000?o000000?oooooo`00
0?l000000ol00003ooooo`;o0000F?ooool001cooooo00?o0000ooooooooool09oooool2o`0000Oo
oooo1?l00003ooooo`;o00000_ooool2o`0000Gooooo0_l00002ooooo`;o00000_ooool6o`0001_o
oooo3ol000000ooooooo0000o`000002o`0000Sooooo0_l00003ooooo`Co00002?ooool2o`0000Ko
oooo0_l00007ooooo`?o00001?ooool7o`0000Cooooo3Ol00002ooooo`oo00000_ooool8o`000003
ooooool0003o000000;ooooo1?l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`0001Oo
oooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0aooooo`?o00003_ooool2o`0000Kooooo
0ol00008ooooo`;o00000_ooool2o`0000kooooo3_l000000ooooooo0000o`000006o`0000Oooooo
0_l000000ooooooo0000o`000004o`0000;ooooo0_l00004ooooo`;o00001_ooool3o`0000Cooooo
1?l00006ooooo`[o000000?oooooo`000?l000009?l00002ooooo`;o00001_ooool2o`0000Cooooo
1_l00008ooooo`;o00002oooool4o`0003Sooooo000Looooo`03o`000?oooooooooo037ooooo0_l0
0007ooooo`;o00002_ooool2o`000004ooooool0003o0000o`0000Wooooo0_l00002ooooo`;o0000
3_ooool2o`000003ooooool0003o000001?o000000?oooooo`000?l000001_ooool:o`0000gooooo
0_l00004ooooo`Co00000_ooool4o`0000Cooooo1_l000000ooooooo0000o`00000To`0000;ooooo
0_l00003ooooo`Go00001_ooool2o`0000[ooooo0_l0000;ooooo`;o0000>_ooool001cooooo00?o
0000ooooooooool0<?ooool3o`0000;ooooo0_l00003ooooo`;o00002_ooool5o`000003ooooool0
003o000001gooooo5_l000000ooooooo0000o`00000;ooooo`Co00006?ooool6o`0000;ooooo0_l0
00000ooooooo0000o`000003o`000003ooooool0003o000002Co000000?oooooo`000?l000000_oo
ool5o`0000Cooooo1?l0000Aooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0<?ooool3
o`0000;ooooo0ol00009ooooo`;o00000oooool5o`000003ooooool0003o000000Oooooo1?l00002
ooooo`;o00003?oooolGo`0000;ooooo0_l00003ooooo`;o00001oooool2o`0001Sooooo0ol00002
ooooo`;o00000_oooolPo`0000;ooooo4Ol000000ooooooo0000o`000002o`0000?ooooo1_l0000A
ooooo`;o0000@_ooool001cooooo0_l0000booooo`;o00000oooool2o`0000Wooooo0_l00003oooo
o`;o00003Oooool4o`0000;ooooo0_l0000<oooooa_o00000oooool2o`0000?ooooo0_l0000Coooo
o`;o00001oooool2o`000003ooooool0003o000000Gooooo2?l000000ooooooo0000o`00000[o`00
00Cooooo0ol00002ooooo`;o00001oooool2o`0004_ooooo000Looooo`03o`000?oooooooooo01go
oooo0_l0000Gooooo`;o00003?ooool4o`0001[ooooo0_l00006oooooa[o00002?ooool2o`0000Co
oooo0_l0000;ooooo`Co00000oooool4o`0000?ooooo0_l00006ooooo`;o000000?oooooo`000?l0
00000_l00003ooooobGo000000?oooooo`000?l000000ol00004ooooo`;o00000oooool2o`0000Oo
oooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`0Mooooo`;o00005_ooool2o`000003oooo
ool0003o000000?o00000oooool2o`0000;ooooo1?l000000ooooooo0000o`000009ooooo`Go0000
0oooool2o`0000Cooooo0_l00005ooooo`Wo000000?oooooo`000?l000002ol00002ooooo`?o0000
0oooool2o`0000Sooooo0_l0000;ooooo`;o00000_ooool2o`000003ooooool0003o000000;o0000
3?ooool6o`0000?ooooo8ol00003ooooo`?o00002_ooool2o`0000Oooooo0ol00003ooooo`;o0000
1_ooool2o`0003kooooo000Looooo`03o`000?oooooooooo03Gooooo0_l000000ooooooo0000o`00
0003o`000003ooooool0003o000000;o00000_ooool3o`0000;ooooo0_l000000ooooooo0000o`00
0006ooooo`Go00000_ooool3o`0000Wooooo7_l00003ooooo`;o00005Oooool2o`0000;ooooo0_l0
0007ooooo`;o00001Oooool2o`000003ooooool0003o000001;o000000Goooooo`000?l0003o0000
ooooo`0Ao`000003ooooool0003o000000;ooooo0_l0000;ooooo`;o00001oooool3o`0000?ooooo
0_l00006ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0<Oooool2o`0000;ooooo0_l0
0007ooooo`;o00001?ooool2o`0000Kooooo0_l00007ooooo`;o00001?ooool2o`0000Wooooo1Ol0
00000ooooooo0000o`00000?o`000003ooooool0003o000000?o00002_ooool2o`0000Cooooo0_l0
0005ooooo`;o00000oooool2o`0000_ooooo0_l00005ooooo`;o00000oooool[o`0000?ooooo0_l0
00000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000001?ooool4o`000003ooooool0
003o000000oooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00000_ooool2
o`0000gooooo0_l00007ooooo`;o000000?oooooo`000?l000000oooool2o`0000Cooooo0_l00009
oooooago00002_ooool4o`0000;ooooo0ol00004ooooo`;o00001Oooool2o`0001Gooooo9?l00000
0ooooooo0000o`000005o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o000000?ooooo
o`000?l000000oooool5o`000003ooooool0003o000000oooooo0_l0000kooooo`007?ooool00ol0
003oooooooooo`0cooooo`Co00003Oooool2o`0000Oooooo0_l000000ooooooo0000o`000003oooo
o`;o00001?ooool2o`0000Wooooo1ol00002ooooo`Co000000?oooooo`000?l000001_l000000ooo
oooo0000o`000004o`0000Gooooo0_l000000ooooooo0000o`000002ooooo`Oo00001Oooool2o`00
00Cooooo0_l00007ooooo`Co00003_oooolNo`0000?ooooo0_l000000ooooooo0000o`000005o`00
00;ooooo0_l00005ooooo`;o00000oooool4o`00053ooooo000Looooo`03o`000?oooooooooo03?o
oooo1?l00004ooooo`;o00001_ooool3o`0000kooooo0ol0000?ooooo`So000000?oooooo`000?l0
00005?l00003ooooo`;o000000?oooooo`000?l000000_ooool5o`0000Oooooo0_l0000;ooooo`Ko
00000_ooool2o`0000;ooooo0_l00003ooooo`Co000000?oooooo`000?l000006ol00002ooooo`Co
00000_ooool6o`0000Wooooo0_l00003ooooo`;o00002?ooool2o`0004Kooooo000Looooo`03o`00
0?oooooooooo03Sooooo0_l000000ooooooo0000o`000002o`0000?ooooo0ol0000?ooooo`;o0000
2oooool2o`0000;ooooo8?l0000:ooooo`Go00001_ooool3o`0000_ooooo0_l00006ooooo`;o0000
0_ooool2o`0000?ooooo1_l000000ooooooo0000o`000009o`000003ooooool0003o000001?o0000
1?ooool4o`0000Wooooo0_l0000=ooooo`;o00001_ooool2o`0003kooooo000Looooo`03o`000?oo
oooooooo03Sooooo0_l00003ooooo`;o00000oooool2o`0000Sooooo0_l000000ooooooo0000o`00
000@ooooo`;o00000_oooolQo`0001Cooooo0_l00006ooooo`;o00003oooool2o`0000Kooooo1?l0
00000ooooooo0000o`000009o`000003ooooool0003o000000_o00000_ooool6o`0000Cooooo0_l0
000<ooooo`;o00002Oooool2o`0000Wooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0d
ooooo`;o00004?ooool2o`0000Cooooo1Ol0000;ooooo`;o00000_ooool2o`0000;ooooo4_l00000
0ooooooo0000o`000003o`000003ooooool0003o000000;o000000?oooooo`000?l000000_l0000C
ooooo`Go00001?ooool2o`0000oooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l00000
0ooooooo0000o`000004o`000004ooooool0003o0000ooooo`Wo00001?ooool2o`0000;ooooo1_l0
000Booooo`;o00002Oooool2o`0000kooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`0d
ooooo`;o00004?ooool2o`0000Kooooo0_l0000<ooooo`;o00000_ooool2o`0000;ooooo0_l00000
0ooooooo0000o`00000Do`000003ooooool0003o000000?o000000?oooooo`000?l000001oooool2
o`0000Wooooo1_l00004ooooo`;o00004_ooool4o`0000Oooooo2?l000000ooooooo0000o`000004
o`000003ooooool0003o000000;o00001_ooool2o`000003ooooool0003o000000Gooooo0_l0000=
ooooo`;o00000oooool4o`0000Oooooo0_l00008ooooo`;o0000>Oooool001cooooo00?o0000oooo
ooooool0=Oooool4o`00027ooooo0_l0000;oooooaco000000?oooooo`000?l000000_ooool2o`00
0003ooooool0003o000000;o00001?ooool2o`0000?ooooo1Ol0000?ooooo`;o00002?ooool2o`00
00Gooooo0_l00005ooooo`?o00000oooool5o`0000;ooooo3?l000001?oooooo0000o`000?l00002
ooooo`Co00000_ooool2o`0000;ooooo0_l00005ooooo`Co000000?oooooo`000?l000000_l00003
ooooo`;o000000Coooooo`000?l0003o00002?ooool2o`0003Wooooo000Looooo`03o`000?oooooo
oooo033ooooo0_l00003ooooo`Co00003_ooool2o`0000Cooooo0_l00003ooooo`?o00001?ooool3
o`0000Oooooo0_l00002oooooaco00001Oooool2o`000003ooooool0003o000000Kooooo0_l00003
ooooo`;o00000oooool6o`0000Wooooo0_l00007ooooo`;o00001_ooool2o`0000Cooooo1_l00000
0ooooooo0000o`000002o`000005ooooool0003o0000o`000?ooool02_l000001?oooooo0000o`00
0?l00002ooooo`?o00000oooool2o`0000;ooooo0_l00007ooooo`;o00000_ooool2o`0000Cooooo
0_l000000ooooooo0000o`000008ooooo`?o0000>Oooool00006ooooooo^k^ko<S8bo`000?lb<S;o
k^k^1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo
033ooooo0_l00002ooooo`;o00001?ooool2o`0000Kooooo0_l00003ooooo`;o00001?ooool2o`00
00?ooooo0ol00004ooooo`;o00001Oooool2o`000004ooooool0003o0000oooooa?o000000?ooooo
o`000?l000001ol00005ooooo`;o00004Oooool8o`000003ooooool0003o000000Kooooo0_l00007
ooooo`;o00003?ooool2o`000004ooooool0003o0000o`0000;ooooo0_l00002ooooo`Oo00000_oo
ool3o`000004ooooool0003o0000ooooo`?o00000_ooool2o`0001Cooooo0_l0000Aooooo`;o0000
>_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMgMooo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo03Cooooo1?l00002ooooo`?o00001Oooool2o`00
00cooooo0_l00007ooooo`;o00001Oooool3o`0000?ooooo6?l00003ooooo`;o00004?ooool2o`00
00Kooooo1_l00003ooooo`;o00003?ooool2o`0000Gooooo0_l0000:ooooo`;o00001Oooool2o`00
00;ooooo1_l00003ooooo`;o000000Coooooo`000?l0003ooooo0ol0001Wooooo`0000?ooooooa0@
4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`0fooooo`;o00000oooool2o`0000gooooo0_l00004ooooo`;o00000oooool2
o`0000;ooooo0_l00006ooooo`;o00001OoooolFo`0001Gooooo1?l00006ooooo`;o00004oooool4
o`000003ooooool0003o000000Ko00001_ooool2o`000003ooooool0003o000000;ooooo0ol00000
0ooooooo0000o`000004o`0000Gooooo0_l00005ooooo`;o00001?ooool2o`0001Wooooo0_l0000;
ooooo`;o0000=oooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0
003oV9RHoooooonHV9So8B4Q00Kooooo0ol00016ooooo`;o00000_ooool3o`0000Sooooo0_l0000?
oooooa?o00001_ooool2o`0000kooooo0_l000000ooooooo0000o`000003o`0000Kooooo1ol00000
0ooooooo0000o`00000=ooooo`Ko000000?oooooo`000?l000000_l00003ooooo`;o000000Cooooo
o`000?l0003ooooo0_l00003ooooo`;o00000_ooool3o`0000Cooooo0_l000000ooooooo0000o`00
0002ooooo`Go00001?ooool2o`0000[ooooo0_l00002ooooo`;o00002Oooool2o`0000_ooooo0_l0
000gooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?mEEEGo
0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0eooooo`;o00003oooool2o`0000?ooooo0_l0
000>ooooo`;o00002Oooool2o`000003ooooool0003o000000go00001oooool4o`0000cooooo0_l0
00000ooooooo0000o`000002o`0000Oooooo2_l0000>ooooo`;o00002oooool5o`000003ooooool0
003o000000?ooooo0_l00002ooooo`;o00001Oooool3o`0000Cooooo1?l0000@ooooo`?o00000_oo
ool2o`0004oooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEE
ohN7Qoooool02?ooool00ol0003oooooooooo`0eooooo`;o00003oooool2o`0001?ooooo0_l00009
ooooo`?o00000_ooool=o`0000Wooooo0_l0000Iooooo`;o00001Oooool2o`0000oooooo0ol0000=
ooooo`;o00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000003o`0000Cooooo0_l0000H
ooooo`;o00001oooool2o`0004_ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00?o
gMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0nooooo`;o00001Oooool3o`0000Kooooo0ol0
000Booooo`?o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000Co00002?oo
ool2o`0001?ooooo0_l00009ooooo`Co00000oooool4o`0000?ooooo0_l00008ooooo`Go00002Ooo
ool2o`0000cooooo1Ol00004ooooo`;o00003Oooool2o`0000Oooooo0_l00006ooooo`Go000000?o
ooooo`000?l00000B?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4
o`000?l@4106ooooo`03o`000?oooooooooo03kooooo0_l00005ooooo`Go00001?ooool3o`000003
ooooool0003o000000Kooooo0ol00006ooooo`?o00001Oooool6o`0000_ooooo0_l000000ooooooo
0000o`00000@ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo1?l00002ooooo`;o
000000?oooooo`000?l000000_l000000ooooooo0000o`000004ooooo`;o00000_ooool2o`000003
ooooool0003o000000Wooooo1?l0000=ooooo`;o00004oooool2o`0000Oooooo0_l00005ooooo`Co
00000oooool2o`0004Sooooo000Looooo`03o`000?oooooooooo03Wooooo0_l0000=ooooo`;o0000
2?ooool2o`0000Kooooo0ol00009ooooo`;o00000oooool6o`0000kooooo0_l00002ooooo`;o0000
4?ooool2o`000003ooooool0003o000000;ooooo2?l00003ooooo`;o00001oooool2o`000003oooo
ool0003o000000?o00001oooool2o`0000?ooooo0_l0000=ooooo`;o00002?ooool2o`000003oooo
ool0003o000001Gooooo0ol0000Looooo`;o0000<Oooool001cooooo00?o0000ooooooooool07_oo
ool2o`0001Gooooo0_l00002ooooo`;o00000_ooool2o`0000Sooooo0_l00009ooooo`;o00004_oo
ool2o`0000;ooooo1Ol0000<ooooo`;o00001?ooool4o`0000oooooo0_l00006ooooo`;o00000_oo
ool4o`0000oooooo0_l000000ooooooo0000o`000007ooooo`;o000000Coooooo`000?l0003ooooo
0_l0000=ooooo`;o00001oooool2o`000003ooooool0003o000000;o00004Oooool4o`00013ooooo
0_l0000;ooooo`;o0000<Oooool001cooooo00?o0000ooooooooool07_ooool2o`0001Gooooo0_l0
0006ooooo`Co00000_ooool2o`000004ooooool0003o0000o`00027ooooo1_l0000;ooooo`;o0000
1?ooool2o`0000Wooooo0_l00002ooooo`;o00000_ooool2o`0000cooooo0_l0000Jooooo`;o0000
0_ooool2o`000003ooooool0003o000000;ooooo0_l00009ooooo`;o00001oooool2o`0000?ooooo
0_l0000?ooooo`Co00004_ooool2o`0003kooooo000Looooo`03o`000?oooooooooo03kooooo1?l0
00001?oooooo0000o`000?ooool2o`0000Sooooo0_l00002ooooo`;o00003oooool2o`0000;ooooo
0_l000000ooooooo0000o`000002o`000003ooooool0003o000000kooooo0_l00009ooooo`;o0000
0_ooool2o`000003ooooool0003o000000[ooooo0_l000000ooooooo0000o`000006ooooo`;o0000
4Oooool3o`0000Wooooo0_l00008ooooo`;o00000oooool2o`0001Wooooo0_l00005ooooo`;o0000
COooool001cooooo00?o0000ooooooooool0?_ooool4o`0000gooooo0ol00002ooooo`;o00001ooo
ool3o`0000Gooooo0_l00002ooooo`;o00001_ooool2o`0000kooooo0_l00006ooooo`;o00000_oo
ool2o`000003ooooool0003o000000?o00001oooool5o`0000Wooooo1?l00006ooooo`;o00001_oo
ool3o`0000[ooooo0_l000000ooooooo0000o`000004o`000003ooooool0003o000000?ooooo0_l0
0002ooooo`Oo000000?oooooo`000?l000005?ooool2o`0004gooooo000Looooo`03o`000?oooooo
oooo03kooooo0_l0000>ooooo`Co00002oooool5o`0001Wooooo0_l0000<ooooo`;o000000Gooooo
o`000?l0003o0000ooooo`04o`0000Sooooo0ol00003ooooo`;o00001?ooool2o`0000;ooooo0_l0
0003ooooo`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00001?ooool2o`000003oooo
ool0003o000000;ooooo0_l000000ooooooo0000o`000004o`0000Cooooo0ol00003ooooo`Oo0000
00?oooooo`000?l000005_ooool3o`0004[ooooo000Looooo`03o`000?oooooooooo03cooooo0_l0
000@ooooo`Co00002_ooool6o`0000Sooooo0_l0000?ooooo`;o00002oooool3o`000003ooooool0
003o000000;ooooo0_l00004ooooo`?o00002Oooool2o`0000Cooooo0_l00007ooooo`;o00001?oo
ool2o`0000Wooooo0_l000001?oooooo0000o`000?ooool2o`0000cooooo0ol0000Mooooo`Co0000
0_ooool3o`0000_ooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0looooo`;o00002Ooo
ool4o`0000?ooooo1?l00002ooooo`;o00001Oooool3o`0000cooooo0_l00004ooooo`;o00004ooo
ool2o`000003ooooool0003o000000;o00000_ooool4o`0000Cooooo0ol000000ooooooo0000o`00
0002o`0000Cooooo0_l00008ooooo`;o00001?ooool2o`0001Cooooo0_l00003ooooo`;o00001ooo
ool2o`0001Sooooo0_l00004ooooo`Co00004?ooool2o`0003gooooo000Looooo`03o`000?oooooo
oooo04;ooooo0_l00003ooooo`Co000000?oooooo`000?l000000_l00004ooooo`;o00001Oooool2
o`0001?ooooo0ol0000;ooooo`;o00001Oooool2o`0000;ooooo0ol00002ooooo`?o00000_ooool3
o`000004ooooool0003o0000ooooo`Co00003_ooool2o`0000Cooooo0_l00005ooooo`Co00001Ooo
ool3o`0000Sooooo0_l00006ooooo`;o00006Oooool2o`000004ooooool0003o0000ooooo`;o0000
DOooool001cooooo00?o0000ooooooooool0@?ooool4o`0000?ooooo0_l00003ooooo`Co00002?oo
ool2o`0000;ooooo0ol0000=ooooo`;o00000oooool2o`0000_ooooo0_l0000?ooooo`;o00000_oo
ool3o`000003ooooool0003o000000;o00000oooool2o`0000[ooooo0_l000000ooooooo0000o`00
0002o`0000Sooooo1?l00005ooooo`?o00000oooool2o`0000_ooooo0_l0000Looooo`;o0000E?oo
ool001cooooo00?o0000ooooooooool0@?ooool2o`0000cooooo0_l00008ooooo`;o00000_ooool5
o`0000Sooooo0_l000000ooooooo0000o`000002o`0001_ooooo0_l00002ooooo`;o000000?ooooo
o`000?l000002Ol000000ooooooo0000o`00000:ooooo`;o000000?oooooo`000?l000000_l00009
ooooo`?o00001_ooool2o`0000?ooooo1?l0000Kooooo`;o00008_ooool2o`0003cooooo000Loooo
o`;o0000@Oooool2o`0000Oooooo0_l000000ooooooo0000o`000002o`0000oooooo0_l00005oooo
o`;o000000?oooooo`000?l000000_ooool3o`0001_ooooo0_l00005ooooo`_o00004?ooool3o`00
00?ooooo0_l00005ooooo`;o00001oooool2o`000004ooooool0003o0000ooooo`Go00006Oooool2
o`0002;ooooo0_l0000looooo`007?ooool00ol0003oooooooooo`10ooooo`;o00001oooool2o`00
0003ooooool0003o000000;o00003oooool2o`0000Gooooo0_l00002ooooo`;o000000?oooooo`00
0?l000003_ooool2o`0000Gooooo0_l0000;ooooo`_o00005?ooool2o`000003ooooool0003o0000
00Sooooo0_l000001?oooooo0000o`000?l00003ooooo`Go000000?oooooo`000?l000001oooool2
o`0001kooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`1Qooooo`;o00001oooool2o`00
017ooooo0_l00005ooooo`;o00002?oooolAo`00017ooooo0_l00007ooooo`;o00000_ooool2o`00
0005ooooool0003o0000o`000?ooool00_l000000ooooooo0000o`00000<ooooo`;o00001?ooool2
o`0001Oooooo0ol0001Booooo`007?ooool00ol0003oooooooooo`1>ooooo`;o00001oooool2o`00
00Oooooo1?l0000Eooooo`;o00004ooooolAo`0000Kooooo0_l00004ooooo`;o00000oooool3o`00
00Kooooo0_l00009ooooo`;o00003oooool2o`0000?ooooo0ol0000Gooooo`Co00001?ooool2o`00
04_ooooo000Looooo`03o`000?oooooooooo04gooooo0ol00007ooooo`;o00001oooool4o`0001Go
oooo0_l00005ooooo`Co00001_ooool2o`0000;ooooo5?l000000ooooooo0000o`000002o`0000Co
oooo0_l00004ooooo`;o00001?ooool2o`0001;ooooo0_l00007ooooo`Co00000_ooool3o`0001?o
oooo0_l00004ooooo`;o00001?ooool2o`0004_ooooo000Looooo`03o`000?oooooooooo04gooooo
0_l00002ooooo`;o00001?ooool2o`0000Wooooo0ol0000Gooooo`;o00000_ooool4o`0000Kooooo
0_l00002oooooaCo000000Coooooo`000?l0003o00002Oooool2o`0000Kooooo0_l00003ooooo`;o
00003Oooool2o`0000Oooooo1?l00003ooooo`;o00004oooool2o`0000?ooooo0_l0001Booooo`00
7?ooool00ol0003oooooooooo`15ooooo`;o00001oooool2o`000003ooooool0003o000000Cooooo
0_l00006ooooo`;o000000Coooooo`000?l0003o00005oooool2o`0000_ooooo0_l00003oooooaCo
00000_ooool2o`0000Oooooo1?l00002ooooo`;o00001oooool2o`000003ooooool0003o000000ko
oooo1Ol0000Jooooo`;o00001Oooool2o`000003ooooool0003o000004oooooo000Looooo`03o`00
0?oooooooooo037ooooo0_l0000Booooo`;o00001oooool2o`0000oooooo0_l000000ooooooo0000
o`000002o`0000Kooooo0_l00008ooooo`;o00003?ooool3o`0000;ooooo0_l00003ooooo`?o0000
00?oooooo`000?l000003_l00005ooooo`;o00000_ooool5o`0000?ooooo0_l000001Ooooooo0000
o`000?l0003ooooo00;o00000oooool2o`0000Wooooo0_l00003ooooo`Go00006_ooool2o`0000So
oooo0_l0000;ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0<Oooool2o`0001;ooooo
0_l00003ooooo`;o000000Coooooo`000?l0003o00004oooool4o`0000Gooooo0_l00008ooooo`;o
00003?ooool4o`0000Kooooo0_l000000ooooooo0000o`000008o`000003ooooool0003o000000Go
00001?ooool2o`0000;ooooo1Ol00002ooooo`;o00000_ooool6o`0000cooooo1?l00003ooooo`Co
00007?ooool2o`0001Cooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o0000
00?oooooo`000?l000005?ooool5o`0000cooooo0_l0000<ooooo`Ko00001_ooool2o`000003oooo
ool0003o0000013o00002_ooool3o`0000;ooooo0_l00004ooooo`;o00000_ooool2o`0000[ooooo
0_l00005ooooo`Co00007?ooool5o`0005Gooooo000Looooo`03o`000?oooooooooo06Kooooo0_l0
0008ooooo`;o00000_ooool2o`0000[ooooo1_l00003ooooo`;o00000_ooool3o`000003ooooool0
003o0000013o00001?ooool2o`0000Sooooo0_l00009ooooo`;o00002_ooool2o`0000?ooooo0_l0
0003ooooo`Co00005?ooool2o`0000?ooooo1Ol0001Eooooo`007?ooool00ol0003oooooooooo`1E
ooooo`;o00004oooool2o`0000Cooooo0_l0000>ooooo`;o000000?oooooo`000?l000001?oooolA
o`0000;ooooo1ol00004ooooo`;o00002?ooool2o`0000Cooooo0_l00006ooooo`;o00001Oooool2
o`0000;ooooo0_l000001?oooooo0000o`000?l00002ooooo`Co00004Oooool2o`000004ooooool0
003o0000ooooo`;o00002Oooool2o`0004oooooo000Looooo`03o`000?oooooooooo04gooooo0_l0
0006ooooo`;o00004oooool3o`0001_ooooo1ol000000ooooooo0000o`00000Co`0000;ooooo0_l0
000>ooooo`;o000000?oooooo`000?l000000oooool2o`0000;ooooo0_l000000ooooooo0000o`00
0002ooooo`;o000000Coooooo`000?l0003o00005oooool2o`0000Cooooo1?l00007ooooo`;o0000
Coooool001cooooo00?o0000ooooooooool0COooool2o`0001Cooooo0_l00002ooooo`;o00000_oo
ool2o`0001Wooooo1?l00003oooooaCo000000Coooooo`000?l0003o00000_ooool2o`0000;ooooo
0_l00004ooooo`;o00001oooool2o`0000Oooooo0_l00008ooooo`Co000000?oooooo`000?l00000
6oooool2o`0005Sooooo000Looooo`03o`000?oooooooooo05cooooo0_l00005ooooo`;o00000_oo
ool2o`000003ooooool0003o000001[ooooo1?l00003oooooaKo000000Coooooo`000?l0003ooooo
0_l00002ooooo`;o00000_ooool5o`0000kooooo0_l0000;ooooo`;o000000?oooooo`000?l00000
5oooool4o`0000Cooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`1?ooooo`;o00002ooo
ool2o`0000Oooooo0_l00003ooooo`;o00008OoooolIo`0000Wooooo0_l000000ooooooo0000o`00
000>ooooo`;o00000oooool2o`0000Kooooo0_l00005ooooo`;o00004Oooool6o`0000Cooooo0_l0
001Dooooo`007?ooool2o`0003;ooooo0_l0000Kooooo`?o00005?ooool2o`0001cooooo0_l0000:
oooooaOo00002Oooool3o`0000kooooo0_l00005ooooo`;o00000oooool2o`000003ooooool0003o
000000Gooooo0_l0000Aooooo`;o00001_ooool2o`0005Kooooo000Looooo`03o`000?oooooooooo
037ooooo0_l0000Kooooo`;o00003_ooool2o`0000;ooooo0_l0000Booooo`;o00002oooool2o`00
00Oooooo0ol000000ooooooo0000o`00000Co`000003ooooool0003o000000Oooooo0ol00002oooo
o`;o00002_ooool2o`0000[ooooo0_l000000ooooooo0000o`000003o`0001Kooooo0_l00005oooo
o`;o00002oooool2o`0004Wooooo000Looooo`03o`000?oooooooooo05Cooooo0_l00006ooooo`Co
00000_ooool2o`0000Gooooo0_l0000;ooooo`;o00003_ooool2o`0000Cooooo6Ol000000ooooooo
0000o`000004ooooo`;o00000_ooool2o`0000;ooooo1ol0000Eooooo`Co00003oooool2o`0000Go
oooo0_l0000Booooo`;o0000BOooool001cooooo00?o0000ooooooooool0E?ooool2o`0000?ooooo
2?l00004ooooo`;o00000_ooool2o`0000[ooooo0ol0000>ooooo`;o00001oooool3o`000003oooo
ool0003o000001?o00001?ooool3o`0000Gooooo1ol00004ooooo`;o00001Oooool2o`0001_ooooo
0_l0000Sooooo`;o0000?oooool001cooooo00?o0000ooooooooool0C_ooool2o`000003ooooool0
003o000000Kooooo2_l00002ooooo`;o00001oooool2o`0000Gooooo0ol0000@ooooo`;o00002Ooo
ool?o`0000?ooooo0ol00004ooooo`?o00001Oooool4o`0000Oooooo0_l00005ooooo`;o00000ooo
ool2o`0000Cooooo0_l0000eooooo`;o0000?oooool001cooooo00?o0000ooooooooool0C_ooool2
o`000003ooooool0003o000000kooooo1?l00002ooooo`;o00001Oooool2o`0000;ooooo0_l0000=
ooooo`;o00001Oooool2o`000003ooooool0003o000000;o00001?ooool2o`000003ooooool0003o
000000Oo00001oooool2o`0000Wooooo0_l00003ooooo`;o00001Oooool3o`0000_ooooo0_l00004
ooooo`Co0000M?ooool001cooooo00?o0000ooooooooool0E_ooool2o`0000Sooooo1Ol00002oooo
o`;o00000oooool4o`0000;ooooo0_l0000=ooooo`;o00001oooool5o`0000;ooooo3_l00004oooo
o`;o00002oooool3o`0000?ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00004_ooool3
o`0000gooooo0_l0001Uooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o00002Oooool2o`00
00Sooooo0_l0000:ooooo`Go00003oooool2o`0000Sooooo0_l000000ooooooo0000o`000002oooo
o`;o00000_ooool2o`0000;ooooo1?l00006ooooo`;o00002oooool2o`0000Cooooo1_l00007oooo
o`?o00003?ooool2o`000003ooooool0003o000000Kooooo0_l00003ooooo`;o0000IOooool001co
oooo00?o0000ooooooooool0Boooool2o`0000cooooo0_l0000@ooooo`;o00000_ooool2o`0000oo
oooo0_l00008ooooo`;o00002Oooool2o`0000;ooooo0_l0000;ooooo`;o00002?ooool2o`0000Ko
oooo1Ol00006ooooo`?o00001_ooool3o`0000Cooooo1?l00006ooooo`;o00002_ooool2o`000003
ooooool0003o000000Sooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o0000
1?ooool2o`0000[ooooo0_l00004ooooo`;o00002Oooool3o`0000Oooooo0_l0000Tooooo`;o0000
2?ooool2o`0000Kooooo1Ol00002ooooo`Co00000_ooool2o`0000Cooooo1Ol00003ooooo`Co0000
4_ooool2o`000003ooooool0003o000000Sooooo0_l0001Aooooo`007?ooool00ol0003ooooooooo
o`1Booooo`Co00002oooool2o`0000;ooooo0_l00004ooooo`;o00002Oooool3o`0000Oooooo0_l0
0003ooooo`;o00003Oooool2o`0000Cooooo0_l0000Aooooo`;o00000oooool2o`0000?ooooo0ol0
0005ooooo`Co00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`Go00000ooo
ool2o`0000oooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`1Booooo`Co00002oooool2
o`0000Sooooo0ol00006ooooo`Co00001Oooool2o`0000Kooooo0_l0000=ooooo`;o00001?ooool2
o`0000;ooooo0_l0000<ooooo`?o00000oooool8o`0000Cooooo0_l0000;ooooo`;o00002Oooool2
o`0000;ooooo1Ol00006ooooo`;o00001Oooool2o`0005_ooooo000Looooo`03o`000?oooooooooo
063ooooo0_l00004ooooo`;o00001?ooool4o`0000Cooooo0_l00004ooooo`;o000000?oooooo`00
0?l000000_l0000Looooo`?o00001oooool2o`0000?ooooo0_l000000ooooooo0000o`000003oooo
o`?o00001oooool4o`0000Wooooo0_l0000;ooooo`Co000000?oooooo`000?l000000_ooool6o`00
00Cooooo0_l0001Looooo`007?ooool00ol0003oooooooooo`1Jooooo`;o00001?ooool2o`0000;o
oooo1?l00004ooooo`Co00002Oooool5o`000003ooooool0003o0000013ooooo0_l0000:ooooo`;o
00001?ooool2o`0000;ooooo0_l00006ooooo`;o000000?oooooo`000?l000002_ooool4o`0000Wo
oooo0_l0000;ooooo`;o00001oooool6o`0000Cooooo0ol0001Kooooo`007?ooool00ol0003ooooo
ooooo`1Jooooo`;o00001?ooool2o`0000;ooooo0_l0000Cooooo`So00000oooool2o`0000;ooooo
0_l00007ooooo`;o00004?ooool2o`0000gooooo0_l0000;ooooo`;o00002_ooool2o`0001Kooooo
0_l00007ooooo`;o0000Foooool001cooooo00?o0000ooooooooool0F?ooool2o`0000cooooo0_l0
000Booooo`;o000000?oooooo`000?l000000_l00003ooooo`;o00000_ooool2o`0001oooooo0_l0
00000ooooooo0000o`000002ooooo`;o00001?ooool3o`0000gooooo0_l00007ooooo`;o00000_oo
ool2o`0007Cooooo000Looooo`;o0000DOooool2o`0000Gooooo0ol0000<ooooo`;o00006oooool4
o`0000Wooooo0_l00002ooooo`;o00004oooool6o`000003ooooool0003o000000;ooooo1Ol0000;
ooooo`Co00001Oooool4o`0000;ooooo0_l00007ooooo`;o00000_ooool2o`0000Gooooo0_l0001P
ooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00001Oooool2o`00013ooooo0_l00002oooo
o`;o00000oooool3o`0000Wooooo0_l00003ooooo`Co00002Oooool2o`0000;ooooo0_l000000ooo
oooo0000o`00000@ooooo`Ko00001Oooool2o`0000kooooo0_l00007ooooo`;o00003Oooool2o`00
00;ooooo0_l00005ooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0JOooool2o`000003
ooooool0003o000000;o00000_ooool3o`0000Wooooo0_l00008ooooo`;o00002oooool4o`0001;o
oooo0_l00004ooooo`;o00000oooool4o`000003ooooool0003o000000Cooooo0_l0000>ooooo`;o
00002Oooool4o`0006Wooooo000Looooo`03o`000?oooooooooo05Sooooo0_l0000Booooo`Co0000
0_ooool2o`0000;ooooo0_l0000@ooooo`;o00001oooool2o`0000;ooooo1Ol00006ooooo`;o0000
2Oooool2o`0000Cooooo0_l00003ooooo`Co000000?oooooo`000?l000001?ooool2o`0000kooooo
0_l0000:ooooo`Co00000_ooool2o`0006Cooooo000Looooo`03o`000?oooooooooo05Sooooo0_l0
000Eooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000Kooooo0_l0000;ooooo`;o0000
1?ooool4o`0000;ooooo1?l00005ooooo`Co00004Oooool2o`00013ooooo0_l00003ooooo`;o0000
4Oooool2o`0000;ooooo0_l0001Tooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o00002?oo
ool2o`0000;ooooo0_l000000ooooooo0000o`000006ooooo`Co00001?ooool7o`0000Kooooo0ol0
0003ooooo`;o00001oooool2o`0000;ooooo0_l0000=ooooo`;o00004?ooool2o`0000?ooooo0_l0
000:ooooo`;o0000Koooool001cooooo00?o0000ooooooooool0H_ooool2o`000003ooooool0003o
000000Oooooo1?l00004ooooo`;o00001oooool3o`0000;ooooo2?l00006ooooo`Co00002?ooool2
o`0000;ooooo0_l00002ooooo`;o00001Oooool2o`0000Sooooo0_l00008ooooo`;o000000Cooooo
o`000?l0003o00001oooool2o`0000Sooooo0_l0001_ooooo`007?ooool00ol0003oooooooooo`1P
ooooo`Co00002_ooool4o`0000kooooo0_l00002ooooo`;o00001?ooool2o`0000Kooooo1Ol00007
ooooo`;o00003Oooool2o`0000Kooooo1?l000000ooooooo0000o`000005ooooo`Ko00001Oooool4
o`0000Sooooo0_l00005ooooo`;o0000J?ooool001cooooo00?o0000ooooooooool0H?ooool2o`00
01kooooo0_l00002ooooo`;o00001?ooool3o`0000Cooooo1_l00005ooooo`;o00002?ooool2o`00
00Gooooo0_l00006ooooo`;o00000oooool2o`0000Kooooo0_l00002ooooo`;o00001?ooool2o`00
00Oooooo0_l000000ooooooo0000o`000005ooooo`;o0000J?ooool001cooooo00?o0000oooooooo
ool0O_ooool2o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l000001?ooool2o`0000?o
oooo0_l00004ooooo`;o00001oooool3o`0001Kooooo0_l00002ooooo`;o00000_ooool2o`0000go
oooo0_l00002ooooo`;o0000K_ooool001cooooo00?o0000ooooooooool0O_ooool2o`0000Cooooo
1_l00006ooooo`;o000000?oooooo`000?l000000ol00002ooooo`;o00001oooool4o`0001Oooooo
0_l00003ooooo`;o00004?ooool2o`0000;ooooo0_l0001^ooooo`007?ooool00ol0003ooooooooo
o`1nooooo`;o00001_ooool4o`000003ooooool0003o000000;ooooo0ol000001?oooooo0000o`00
0?l00004ooooo`;o00001oooool2o`0001kooooo0_l00002ooooo`;o00003?ooool2o`0007;ooooo
000Looooo`03o`000?oooooooooo08Kooooo1?l000000ooooooo0000o`000002ooooo`;o00003Ooo
ool2o`0001?ooooo0_l00005ooooo`Co00002?ooool4o`0000oooooo1?l0001/ooooo`007?ooool0
0ol0003oooooooooo`1/ooooo`;o00002Oooool2o`0000gooooo0ol00002ooooo`?o000000?ooooo
o`000?l000001?ooool2o`0000Oooooo0_l00004ooooo`;o00003Oooool2o`0000Gooooo1?l00008
ooooo`Co00001Oooool2o`0000?ooooo0_l00003ooooo`Co00002oooool2o`0005oooooo00001_oo
ooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0
1_ooool00ol0003oooooooooo`1/ooooo`;o00002Oooool2o`0000kooooo0_l00002ooooo`?o0000
00?oooooo`000?l000001?ooool2o`0000Kooooo0_l00004ooooo`Co000000Coooooo`000?l0003o
00009?ooool2o`0000?ooooo0_l0000Booooo`;o0000Goooool00006oooooomgMgOoV9RHoooooonH
V9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooo
oooo05kooooo0_l00008ooooo`;o00003Oooool2o`0001?ooooo1Ol00004ooooo`;o00001_ooool2
o`0000Cooooo1?l000000ooooooo0000o`000002o`00017ooooo0_l0000Fooooo`;o0000L_ooool0
0003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool0G_ooool2o`0000Sooooo0_l0000=ooooo`;o00004oooool3
o`0000;ooooo0_l00004ooooo`;o00000_ooool2o`0000Sooooo0ol00002ooooo`Oo00001?ooool2
o`000003ooooool0003o000000?ooooo0_l0000Cooooo`;o000000?oooooo`000?l00000L_ooool0
0003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Olb<S;oV9RHoooooonHV9So
<S8b00Kooooo0ol0001@ooooo`;o00007_ooool2o`0001oooooo0_l00003ooooo`?o00000_ooool2
o`0000Sooooo0ol00002ooooo`Oo00001?ooool2o`000004ooooool0003o0000ooooo`Co00002?oo
ool2o`0000Wooooo0_l00009ooooo`Co0000J?ooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool02Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0D?oo
ool2o`0001kooooo0_l0000Oooooo`;o00000oooool2o`0000Wooooo0_l00007ooooo`;o00000ooo
ool2o`0000[ooooo0_l00006ooooo`;o00000_ooool2o`0000Kooooo0_l0000<ooooo`Co0000J?oo
ool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol@413o^[Zjoooooonj
^[[o410@00Kooooo00?o0000ooooooooool0POooool2o`0000cooooo0ol0000=ooooo`Co00000ooo
ool2o`0000Oooooo0_l00002ooooo`;o00003_ooool2o`0000[ooooo0_l0001hooooo`0000Kooooo
ogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003o
ooooooooo`1dooooo`;o00002oooool2o`0000cooooo0ol0000=ooooo`;o00001Oooool2o`0000Oo
oooo0_l00002ooooo`;o00004oooool2o`0000Kooooo1?l0001eooooo`0000Koooooonk^k_lb<S;o
0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`1d
ooooo`;o00004_ooool2o`0001[ooooo0_l0000@ooooo`;o00001Oooool3o`0000Sooooo1?l00004
ooooo`Co0000MOooool001cooooo00?o0000ooooooooool0R?ooool2o`00017ooooo0_l00007oooo
o`;o00001?ooool2o`0000Sooooo1?l00005ooooo`?o000000?oooooo`000?l000001Oooool4o`00
07gooooo000Looooo`03o`000?oooooooooo08kooooo0_l00007ooooo`;o00000_ooool2o`0000Go
oooo0_l00004ooooo`Ko00001Oooool3o`000003ooooool0003o000000Kooooo1?l00006ooooo`;o
0000O_ooool001cooooo00?o0000ooooooooool0S_ooool2o`0000Oooooo0_l00002ooooo`;o0000
1?ooool3o`0000Cooooo0_l000001?oooooo0000o`000?l00002ooooo`;o000000?oooooo`000?l0
00000_ooool2o`0000Kooooo0_l00008ooooo`;o0000O_ooool001cooooo00?o0000ooooooooool0
J?ooool2o`0000oooooo0_l00005ooooo`;o00006Oooool2o`0000Cooooo0_l00002ooooo`;o0000
1?ooool4o`000003ooooool0003o000009Oooooo000Looooo`03o`000?oooooooooo06Sooooo0ol0
000>ooooo`;o00001Oooool2o`0000Cooooo0_l0000Mooooo`Ko00000_ooool2o`0009[ooooo000L
ooooo`03o`000?oooooooooo06Wooooo0_l0000Kooooo`;o00004?ooool2o`0000?ooooo0_l00008
ooooo`Co0000W_ooool001cooooo00?o0000ooooooooool0Q_ooool2o`00013ooooo0_l00003oooo
o`;o00007oooool2o`0000_ooooo0_l0001looooo`007?ooool00ol0003oooooooooo`1^ooooo`;o
00003oooool2o`0003[ooooo0_l000000ooooooo0000o`00000;ooooo`;o0000O?ooool001cooooo
00?o0000ooooooooool0Joooool2o`000003ooooool0003o000000oooooo0_l0000@ooooo`;o0000
5oooool2o`0000oooooo0_l0002<ooooo`007?ooool00ol0003oooooooooo`1Sooooo`;o00001Ooo
ool3o`00023ooooo0_l00002ooooo`;o00001?ooool2o`0000Gooooo0_l0000:ooooo`;o00008?oo
ool2o`0007_ooooo000Looooo`03o`000?oooooooooo06?ooooo0_l00005ooooo`;o00001_ooool2
o`0001Wooooo0_l00002ooooo`;o00000_ooool4o`0000Gooooo0_l00003ooooo`;o00009?ooool2
o`000003ooooool0003o000007_ooooo000Looooo`;o0000Loooool2o`0001oooooo1?l00007oooo
o`Co000000?oooooo`000?l000005oooool2o`0000_ooooo0_l000000ooooooo0000o`00001koooo
o`007?ooool00ol0003oooooooooo`2Cooooo`;o00002oooool2o`0001[ooooo0_l0002;ooooo`00
7?ooool00ol0003oooooooooo`2[ooooo`Co0000V_ooool001cooooo00?o0000ooooooooool0ZOoo
ool6o`0001kooooo0_l0001jooooo`007?ooool00ol0003oooooooooo`2Xooooo`?o00000_ooool2
o`0001kooooo0_l0001jooooo`007?ooool00ol0003oooooooooo`1/ooooo`;o00001?ooool2o`00
00Wooooo0_l0000Yooooo`;o00000oooool3o`0009Wooooo000Looooo`03o`000?oooooooooo06co
oooo0_l00004ooooo`;o00002Oooool2o`0002oooooo0_l00007ooooo`;o0000T?ooool001cooooo
00?o0000ooooooooool0]oooool2o`00093ooooo000Looooo`03o`000?oooooooooo093ooooo0_l0
002gooooo`007?ooool00ol0003oooooooooo`2@ooooo`;o0000]oooool001cooooo00?o0000oooo
ooooool0V?ooool2o`000:oooooo000Looooo`03o`000?oooooooooo08Sooooo0_l0000>ooooo`;o
0000[oooool001cooooo00?o0000ooooooooool0R?ooool2o`0001Gooooo0_l0002Xooooo`007?oo
ool00ol0003oooooooooo`29ooooo`;o00005?ooool2o`000:Sooooo000Looooo`03o`000?oooooo
oooo08Wooooo0_l0002nooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o
0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?o
oooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool3o`000?ooooooB_oo
ool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooo
oe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0
oooooomBooooo`004_ooool00omEEEGoIVIVo`00003ooooooeCooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo002Qooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@oooooooo
ool05_ooool4o`000004oa0@4?ooooooooooooooo`Co000000So410@ooooooooooooc<c<ob4Q8Ol0
003o8B4Qolc<c0?ooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c02<ooooo`00X_ooool01Ol0003ooooo
oooooooooooo000000Wooooo1_l0000<ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00_ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00?ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@2<
ooooo`00X_ooool01Ol0003ooooooooooooooooo000001_ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000008cooooo002Rooooo`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`05oc8b<_nHV9SooooooiRHV?lb
<S800oooool01Olb<S;oV9RHoooooonHV9So<S8b08cooooo002Rooooo`05o`000?n7QhOoooooojVY
ZOl000006oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Goc<c<o`00
0?l0003o0000olc<c003ooooo`05olc<c?l0003o0000o`000?o<c<`0S?ooool00:7ooooo00?o410@
o`000?mgMgL00_l000000onHV9Soooooooooo`0Iooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool01Ol@413o^[Zjoooooonj^[[o410@00?ooooo00Go410@okZj^_oooooo^[Zj
oa0@402<ooooo`00`_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Go
0000okZj^_oooooo^[Zjo`000003ooooo`05o`000?nj^[[ooooookZj^_l00000S?ooool00<3ooooo
00?oEEEEofIVI_l000001Oooool00omEEEGoIVIVo`000004ooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT00oooool01OnYZJWo410@o`000?l@413oZJVY08cooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1194) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.6082 .37039 Mdot
.563 .34709 Mdot
.35128 .51835 Mdot
.65988 .54602 Mdot
.26575 .32262 Mdot
.35858 .54694 Mdot
.42601 .41213 Mdot
.39546 .36607 Mdot
.36846 .52368 Mdot
.46742 .23466 Mdot
.41109 .40786 Mdot
.67166 .62785 Mdot
.40241 .38929 Mdot
.64951 .5664 Mdot
.28577 .23883 Mdot
.58452 .5179 Mdot
.58936 .32788 Mdot
.47766 .67115 Mdot
.64054 .61177 Mdot
.39468 .5308 Mdot
.56177 .30815 Mdot
.64793 .55629 Mdot
.54463 .3748 Mdot
.64923 .56712 Mdot
.65407 .51696 Mdot
.58383 .37654 Mdot
.53448 .3907 Mdot
.61896 .52083 Mdot
.63242 .50426 Mdot
.39121 .37099 Mdot
.55117 .70323 Mdot
.25517 .28868 Mdot
.66848 .6068 Mdot
.21166 .59352 Mdot
.41554 .36388 Mdot
.72832 .46453 Mdot
.34707 .53765 Mdot
.42291 .38079 Mdot
.42922 .37963 Mdot
.45069 .38829 Mdot
.42061 .39473 Mdot
.56886 .37826 Mdot
.36247 .36339 Mdot
.42707 .56742 Mdot
.57549 .53302 Mdot
.33628 .29645 Mdot
.80754 .51761 Mdot
.59643 .55821 Mdot
.5979 .33763 Mdot
.2794 .61694 Mdot
.2657 .41095 Mdot
.44542 .39698 Mdot
.39014 .57324 Mdot
.41295 .88318 Mdot
.41713 .3713 Mdot
.5743 .5687 Mdot
.34336 .52982 Mdot
.63714 .55903 Mdot
.64614 .57052 Mdot
.65639 .3582 Mdot
.58732 .56004 Mdot
.43944 .69035 Mdot
.6181 .34222 Mdot
.53148 .4736 Mdot
.36134 .52727 Mdot
.43 .39377 Mdot
.55505 .36111 Mdot
.40175 .38008 Mdot
.63057 .48153 Mdot
.39687 .5297 Mdot
.59472 .55395 Mdot
.42225 .40279 Mdot
.60466 .33305 Mdot
.6079 .53509 Mdot
.35566 .71658 Mdot
.52831 .17428 Mdot
.42378 .70366 Mdot
.6928 .4267 Mdot
.64807 .39817 Mdot
.34539 .64695 Mdot
.67351 .55537 Mdot
.65284 .68997 Mdot
.46392 .18157 Mdot
.53785 .37317 Mdot
.69225 .51068 Mdot
.49434 .64243 Mdot
.61057 .539 Mdot
.37001 .24606 Mdot
.61766 .50283 Mdot
.36735 .74423 Mdot
.3774 .5352 Mdot
.57859 .34747 Mdot
.66153 .54654 Mdot
.60766 .51809 Mdot
.75043 .60702 Mdot
.67723 .59307 Mdot
.63655 .53373 Mdot
.60245 .36482 Mdot
.44538 .38901 Mdot
.61013 .61393 Mdot
.42508 .53602 Mdot
.35854 .58126 Mdot
.64695 .59475 Mdot
.35261 .57134 Mdot
.59273 .31705 Mdot
.60477 .53009 Mdot
.43282 .37661 Mdot
.64207 .59094 Mdot
.51301 .30813 Mdot
.56091 .34478 Mdot
.61624 .51725 Mdot
.46352 .69608 Mdot
.6629 .77098 Mdot
.57948 .33728 Mdot
.38761 .63772 Mdot
.67507 .53465 Mdot
.63196 .5415 Mdot
.56445 .34951 Mdot
.31901 .55851 Mdot
.39114 .22836 Mdot
.54998 .38994 Mdot
.44634 .37081 Mdot
.60048 .38893 Mdot
.67624 .49383 Mdot
.373 .5399 Mdot
.24024 .49984 Mdot
.44179 .32725 Mdot
.55879 .67857 Mdot
.61325 .54494 Mdot
.45585 .26866 Mdot
.38634 .55278 Mdot
.57309 .35952 Mdot
.39819 .38089 Mdot
.6989 .60254 Mdot
.54897 .3438 Mdot
.393 .4011 Mdot
.45137 .70187 Mdot
.30327 .44916 Mdot
.56657 .31971 Mdot
.43909 .53659 Mdot
.37969 .39129 Mdot
.44689 .39929 Mdot
.24725 .6811 Mdot
.55843 .36235 Mdot
.45644 .679 Mdot
.39621 .37328 Mdot
.53234 .6827 Mdot
.57626 .54514 Mdot
.61722 .71989 Mdot
.82042 .54464 Mdot
.21867 .61007 Mdot
.32619 .4584 Mdot
.43766 .65935 Mdot
.43085 .35671 Mdot
.64578 .52066 Mdot
.59371 .3694 Mdot
.56876 .38306 Mdot
.59436 .56994 Mdot
.66142 .53346 Mdot
.59497 .5447 Mdot
.60603 .51689 Mdot
.63937 .28375 Mdot
.68073 .57694 Mdot
.79199 .57373 Mdot
.58252 .34436 Mdot
.65247 .53299 Mdot
.32521 .5502 Mdot
.70182 .56146 Mdot
.4231 .39756 Mdot
.64126 .55322 Mdot
.65888 .54306 Mdot
.58918 .56662 Mdot
.44643 .39251 Mdot
.31296 .23546 Mdot
.75547 .63709 Mdot
.25883 .30364 Mdot
.40298 .74904 Mdot
.35478 .56359 Mdot
.61746 .53824 Mdot
.45711 .69314 Mdot
.74789 .441 Mdot
.66628 .57047 Mdot
.81735 .67286 Mdot
.64185 .54028 Mdot
.27142 .30138 Mdot
.56268 .51669 Mdot
.19231 .37639 Mdot
.62391 .70192 Mdot
.63612 .51687 Mdot
.52727 .5252 Mdot
.50895 .39978 Mdot
.42066 .54969 Mdot
.41735 .39411 Mdot
.3245 .5468 Mdot
.34323 .52435 Mdot
.36634 .37962 Mdot
.62494 .38927 Mdot
.57881 .46661 Mdot
.6809 .50994 Mdot
.39942 .53657 Mdot
.60989 .32341 Mdot
.42683 .68691 Mdot
.59154 .38586 Mdot
.52074 .13117 Mdot
.29548 .36249 Mdot
.38081 .35612 Mdot
.44118 .64142 Mdot
.3815 .52534 Mdot
.35256 .57921 Mdot
.46865 .67384 Mdot
.61732 .57068 Mdot
.55635 .36762 Mdot
.19491 .59711 Mdot
.59836 .25945 Mdot
.23004 .67281 Mdot
.60318 .35719 Mdot
.50739 .24708 Mdot
.39496 .3992 Mdot
.33953 .54899 Mdot
.63294 .53865 Mdot
.6195 .56594 Mdot
.5552 .31414 Mdot
.5959 .54663 Mdot
.62107 .64015 Mdot
.62858 .52849 Mdot
.25658 .4493 Mdot
.43321 .71313 Mdot
.36647 .37755 Mdot
.56128 .66422 Mdot
.55705 .38793 Mdot
.5533 .78055 Mdot
.35188 .57423 Mdot
.73466 .43505 Mdot
.42528 .40478 Mdot
.44433 .69857 Mdot
.36863 .57459 Mdot
.42846 .69474 Mdot
.65991 .60688 Mdot
.33679 .5188 Mdot
.47187 .68001 Mdot
.62728 .41482 Mdot
.59315 .52148 Mdot
.63132 .26536 Mdot
.44078 .3689 Mdot
.55094 .39385 Mdot
.58619 .5521 Mdot
.34731 .56505 Mdot
.69566 .59378 Mdot
.3443 .41173 Mdot
.24512 .49569 Mdot
.32367 .57368 Mdot
.2721 .55559 Mdot
.43251 .68688 Mdot
.33144 .37266 Mdot
.49042 .26113 Mdot
.599 .33384 Mdot
.68183 .58068 Mdot
.17792 .38373 Mdot
.39665 .37316 Mdot
.63799 .58775 Mdot
.21621 .54897 Mdot
.40689 .37068 Mdot
.63506 .55935 Mdot
.40226 .35753 Mdot
.5667 .38317 Mdot
.6815 .74138 Mdot
.59225 .33081 Mdot
.63496 .49931 Mdot
.43433 .37459 Mdot
.31844 .54028 Mdot
.59057 .36787 Mdot
.61603 .57466 Mdot
.61716 .52576 Mdot
.504 .47501 Mdot
.64695 .53046 Mdot
.30546 .25204 Mdot
.63003 .52201 Mdot
.33106 .53644 Mdot
.64865 .60005 Mdot
.56925 .84503 Mdot
.36648 .32624 Mdot
.5553 .36268 Mdot
.31267 .5512 Mdot
.35987 .52155 Mdot
.39846 .64856 Mdot
.40531 .33617 Mdot
.67748 .55318 Mdot
.35364 .56516 Mdot
.6067 .75642 Mdot
.39085 .40595 Mdot
.68431 .57953 Mdot
.4448 .5362 Mdot
.2869 .63281 Mdot
.39203 .56915 Mdot
.65424 .6172 Mdot
.57424 .31571 Mdot
.66226 .54476 Mdot
.33222 .57317 Mdot
.54807 .30716 Mdot
.6666 .51405 Mdot
.62314 .32716 Mdot
.50481 .47247 Mdot
.40789 .41509 Mdot
.56235 .51049 Mdot
.62627 .58578 Mdot
.33407 .55549 Mdot
.56339 .38998 Mdot
.38515 .39888 Mdot
.57789 .37524 Mdot
.18807 .44948 Mdot
.50888 .31985 Mdot
.64204 .36043 Mdot
.46061 .63821 Mdot
.26003 .61414 Mdot
.18024 .40817 Mdot
.48946 .81049 Mdot
.53666 .76676 Mdot
.17803 .5254 Mdot
.32446 .56155 Mdot
.22842 .56544 Mdot
.35107 .52256 Mdot
.66515 .52423 Mdot
.3696 .53664 Mdot
.17664 .40786 Mdot
.63033 .52895 Mdot
.36295 .53688 Mdot
.58474 .78098 Mdot
.65736 .53585 Mdot
.57448 .33071 Mdot
.38144 .19765 Mdot
.52366 .8284 Mdot
.24256 .48529 Mdot
.37366 .5096 Mdot
.50331 .75687 Mdot
.63729 .53116 Mdot
.65234 .60216 Mdot
.59625 .34536 Mdot
.68796 .57354 Mdot
.42842 .67201 Mdot
.44333 .6411 Mdot
.49885 .40448 Mdot
.69156 .67856 Mdot
.56287 .53882 Mdot
.59385 .36184 Mdot
.66124 .28683 Mdot
.33927 .7121 Mdot
.26985 .60747 Mdot
.39408 .35642 Mdot
.37403 .20543 Mdot
.66493 .63805 Mdot
.38249 .44282 Mdot
.41031 .58566 Mdot
.57248 .33915 Mdot
.2945 .25351 Mdot
.41656 .3901 Mdot
.77622 .36879 Mdot
.51469 .6122 Mdot
.6216 .57173 Mdot
.4264 .40762 Mdot
.57921 .60416 Mdot
.50176 .83229 Mdot
.79036 .36078 Mdot
.66717 .6599 Mdot
.63816 .49782 Mdot
.37167 .7237 Mdot
.63771 .54802 Mdot
.41127 .22493 Mdot
.62684 .52107 Mdot
.58333 .36905 Mdot
.44257 .23048 Mdot
.51562 .43046 Mdot
.76657 .62076 Mdot
.33915 .32995 Mdot
.43689 .65983 Mdot
.62841 .53414 Mdot
.62351 .57334 Mdot
.43057 .67275 Mdot
.54892 .33204 Mdot
.60431 .51731 Mdot
.53751 .77985 Mdot
.60434 .54349 Mdot
.42349 .38908 Mdot
.63472 .65819 Mdot
.59923 .41196 Mdot
.6751 .50958 Mdot
.61068 .33385 Mdot
.40955 .41697 Mdot
.4253 .372 Mdot
.56638 .54566 Mdot
.45155 .39511 Mdot
.64816 .54413 Mdot
.79529 .35702 Mdot
.5671 .32239 Mdot
.55629 .59754 Mdot
.54242 .36604 Mdot
.68609 .42929 Mdot
.42474 .36675 Mdot
.26779 .42536 Mdot
.68292 .61937 Mdot
.41301 .3908 Mdot
.51045 .322 Mdot
.57465 .51971 Mdot
.62122 .49541 Mdot
.33678 .74271 Mdot
.36433 .51086 Mdot
.51952 .45475 Mdot
.39587 .36415 Mdot
.61786 .58028 Mdot
.68752 .53258 Mdot
.41343 .41775 Mdot
.72302 .29735 Mdot
.56341 .80518 Mdot
.6293 .52507 Mdot
.58577 .35905 Mdot
.57277 .36275 Mdot
.63657 .49551 Mdot
.66504 .59018 Mdot
.37631 .55603 Mdot
.31859 .53279 Mdot
.36547 .50503 Mdot
.50667 .46878 Mdot
.26134 .43557 Mdot
.26783 .35174 Mdot
.45057 .38931 Mdot
.48489 .28466 Mdot
.38396 .75186 Mdot
.6968 .53089 Mdot
.3921 .5346 Mdot
.64043 .58467 Mdot
.6563 .54954 Mdot
.3922 .41302 Mdot
.2229 .50772 Mdot
.61412 .62618 Mdot
.55364 .32416 Mdot
.3829 .38156 Mdot
.71905 .53961 Mdot
.37022 .30651 Mdot
.45833 .69639 Mdot
.26355 .68369 Mdot
.42595 .40176 Mdot
.57201 .33389 Mdot
.41911 .36113 Mdot
.61372 .56109 Mdot
.6136 .60425 Mdot
.56928 .34801 Mdot
.45261 .64686 Mdot
.69639 .58829 Mdot
.63354 .55659 Mdot
.81618 .60483 Mdot
.40386 .76054 Mdot
.26434 .45047 Mdot
.63465 .51859 Mdot
.6717 .50969 Mdot
.4586 .70874 Mdot
.60518 .54955 Mdot
.59187 .54117 Mdot
.70638 .72779 Mdot
.45631 .32475 Mdot
.45794 .64197 Mdot
.75905 .32926 Mdot
.60417 .35185 Mdot
.2111 .34057 Mdot
.33884 .55348 Mdot
.42344 .34554 Mdot
.59217 .80139 Mdot
.38833 .57686 Mdot
.33178 .46174 Mdot
.23167 .31759 Mdot
.5189 .45259 Mdot
.29384 .56902 Mdot
.67512 .62984 Mdot
.602 .52446 Mdot
.6324 .54672 Mdot
.4529 .69157 Mdot
.55882 .37114 Mdot
.51562 .47155 Mdot
.63149 .22268 Mdot
.64592 .55162 Mdot
.58061 .62693 Mdot
.58393 .23589 Mdot
.29154 .63621 Mdot
.44768 .66136 Mdot
.44687 .64375 Mdot
.62847 .5378 Mdot
.67861 .75806 Mdot
.58594 .37521 Mdot
.61743 .57578 Mdot
.68058 .55531 Mdot
.36365 .50943 Mdot
.55932 .33962 Mdot
.32676 .56607 Mdot
.28498 .39901 Mdot
.26088 .30722 Mdot
.82931 .59255 Mdot
.4242 .36853 Mdot
.48149 .2018 Mdot
.3869 .38063 Mdot
.6494 .68602 Mdot
.36775 .5807 Mdot
.67091 .56377 Mdot
.56034 .38892 Mdot
.6252 .58282 Mdot
.66953 .58507 Mdot
.61938 .57238 Mdot
.69161 .52876 Mdot
.74801 .74712 Mdot
.46431 .65994 Mdot
.63334 .48751 Mdot
.33571 .52819 Mdot
.40799 .21442 Mdot
.51916 .17927 Mdot
.62985 .57433 Mdot
.62076 .52899 Mdot
.55704 .32906 Mdot
.6066 .58038 Mdot
.38698 .39419 Mdot
.57057 .39275 Mdot
.60971 .51726 Mdot
.38576 .2082 Mdot
.62398 .50838 Mdot
.21697 .34693 Mdot
.41252 .35957 Mdot
.54759 .27936 Mdot
.61242 .49045 Mdot
.24834 .49475 Mdot
.5195 .45487 Mdot
.3757 .56676 Mdot
.45551 .39301 Mdot
.34944 .53577 Mdot
.68329 .23402 Mdot
.61194 .5989 Mdot
.6483 .51944 Mdot
.68994 .54283 Mdot
.3523 .56342 Mdot
.3451 .26174 Mdot
.32673 .36122 Mdot
.71167 .52733 Mdot
.36144 .56055 Mdot
.61468 .33493 Mdot
.50917 .68853 Mdot
.54877 .37441 Mdot
.43738 .6402 Mdot
.40869 .40602 Mdot
.44049 .64809 Mdot
.20629 .54229 Mdot
.56282 .34451 Mdot
.52813 .377 Mdot
.3463 .55302 Mdot
.47501 .57924 Mdot
.27929 .77642 Mdot
.50271 .603 Mdot
.58816 .70175 Mdot
.59461 .34752 Mdot
.64617 .50225 Mdot
.63086 .67578 Mdot
.47879 .55861 Mdot
.35102 .53368 Mdot
.66276 .56568 Mdot
.66388 .75614 Mdot
.37638 .55655 Mdot
.68298 .58146 Mdot
.34804 .51657 Mdot
.41544 .40074 Mdot
.38881 .53231 Mdot
.5375 .33699 Mdot
.61057 .52936 Mdot
.23647 .72701 Mdot
.4147 .69576 Mdot
.63735 .52577 Mdot
.38387 .37665 Mdot
.47867 .39759 Mdot
.66113 .58515 Mdot
.4491 .7053 Mdot
.36812 .54627 Mdot
.49865 .6061 Mdot
.6281 .52343 Mdot
.35302 .56185 Mdot
.60677 .37674 Mdot
.45241 .37396 Mdot
.64028 .4558 Mdot
.25057 .48952 Mdot
.59739 .34586 Mdot
.42847 .52173 Mdot
.43835 .42077 Mdot
.67401 .51101 Mdot
.68338 .56939 Mdot
.58154 .36124 Mdot
.69638 .70988 Mdot
.62626 .59481 Mdot
.6733 .55592 Mdot
.33034 .53289 Mdot
.35427 .53748 Mdot
.6822 .72876 Mdot
.31754 .55114 Mdot
.61446 .6038 Mdot
.58097 .36359 Mdot
.66344 .55099 Mdot
.56135 .32913 Mdot
.61626 .58591 Mdot
.51913 .33733 Mdot
.54504 .3368 Mdot
.35875 .33884 Mdot
.66159 .55905 Mdot
.55611 .52686 Mdot
.64516 .58953 Mdot
.59973 .54035 Mdot
.37802 .55189 Mdot
.46119 .66943 Mdot
.63079 .61681 Mdot
.41339 .67243 Mdot
.42962 .695 Mdot
.49016 .37951 Mdot
.36664 .50971 Mdot
.44914 .68131 Mdot
.59689 .23441 Mdot
.36293 .50637 Mdot
.44166 .689 Mdot
.51226 .18136 Mdot
.41794 .3645 Mdot
.57317 .31769 Mdot
.65813 .53497 Mdot
.18684 .51081 Mdot
.8094 .52153 Mdot
.41126 .51777 Mdot
.63206 .52255 Mdot
.64784 .58658 Mdot
.54519 .38444 Mdot
.73664 .25708 Mdot
.39493 .52361 Mdot
.6472 .50772 Mdot
.55412 .35601 Mdot
.79463 .31857 Mdot
.33396 .53626 Mdot
.4453 .69078 Mdot
.44767 .38182 Mdot
.61539 .31752 Mdot
.4438 .32875 Mdot
.42063 .41405 Mdot
.40693 .55079 Mdot
.26434 .41699 Mdot
.67544 .53538 Mdot
.39259 .54147 Mdot
.27997 .71216 Mdot
.60772 .27176 Mdot
.47668 .36269 Mdot
.495 .75439 Mdot
.57444 .33941 Mdot
.38705 .38978 Mdot
.44804 .65233 Mdot
.60142 .36281 Mdot
.57767 .3277 Mdot
.40253 .41971 Mdot
.72496 .50456 Mdot
.44656 .54131 Mdot
.427 .38305 Mdot
.34423 .73849 Mdot
.21795 .43645 Mdot
.39276 .53521 Mdot
.42893 .67383 Mdot
.20177 .52505 Mdot
.57011 .37864 Mdot
.36817 .20663 Mdot
.28392 .70793 Mdot
.63672 .53381 Mdot
.4507 .67657 Mdot
.31807 .29522 Mdot
.64381 .2129 Mdot
.40983 .37072 Mdot
.50763 .43403 Mdot
.42747 .66333 Mdot
.58722 .55681 Mdot
.51739 .69043 Mdot
.6705 .5502 Mdot
.4009 .40409 Mdot
.65118 .36445 Mdot
.57102 .33267 Mdot
.40169 .4218 Mdot
.26178 .68326 Mdot
.64882 .54671 Mdot
.66323 .56156 Mdot
.55004 .65139 Mdot
.58082 .38535 Mdot
.37515 .56747 Mdot
.67728 .54393 Mdot
.63675 .55513 Mdot
.59335 .59524 Mdot
.56145 .50753 Mdot
.66024 .76939 Mdot
.65805 .51412 Mdot
.32329 .34068 Mdot
.66643 .50079 Mdot
.65752 .56263 Mdot
.61017 .33105 Mdot
.8278 .61897 Mdot
.29054 .38703 Mdot
.63956 .55321 Mdot
.64883 .50391 Mdot
.41212 .42451 Mdot
.45495 .53808 Mdot
.47058 .57782 Mdot
.49018 .60309 Mdot
.5214 .76299 Mdot
.67926 .50445 Mdot
.54999 .3649 Mdot
.47124 .68677 Mdot
.67124 .51605 Mdot
.54996 .36139 Mdot
.58393 .56168 Mdot
.37545 .55831 Mdot
.35562 .50821 Mdot
.52464 .30903 Mdot
.44309 .68111 Mdot
.56067 .63163 Mdot
.47206 .2907 Mdot
.32404 .54094 Mdot
.651 .51889 Mdot
.39317 .3446 Mdot
.33683 .57492 Mdot
.30399 .58914 Mdot
.62408 .46457 Mdot
.58447 .37933 Mdot
.58006 .34442 Mdot
.61996 .7217 Mdot
.31885 .44557 Mdot
.78037 .64475 Mdot
.41454 .40213 Mdot
.63295 .60225 Mdot
.47334 .26005 Mdot
.58008 .34082 Mdot
.6319 .68191 Mdot
.44794 .67909 Mdot
.40712 .36942 Mdot
.29312 .50685 Mdot
.55114 .33792 Mdot
.58496 .3252 Mdot
.60962 .50711 Mdot
.63 .56377 Mdot
.54609 .76715 Mdot
.47913 .71019 Mdot
.40559 .41564 Mdot
.42888 .67599 Mdot
.37884 .57306 Mdot
.65698 .51186 Mdot
.54103 .37221 Mdot
.22274 .47255 Mdot
.65732 .50852 Mdot
.38044 .55105 Mdot
.57444 .34428 Mdot
.42904 .68171 Mdot
.43922 .70469 Mdot
.60103 .54015 Mdot
.66519 .29917 Mdot
.41816 .38092 Mdot
.57578 .33235 Mdot
.36752 .31248 Mdot
.65598 .60028 Mdot
.62528 .55761 Mdot
.59068 .48083 Mdot
.39157 .40969 Mdot
.53858 .26382 Mdot
.42595 .65529 Mdot
.56179 .36756 Mdot
.63627 .51304 Mdot
.43685 .6842 Mdot
.51599 .26073 Mdot
.32547 .57482 Mdot
.38686 .52973 Mdot
.44777 .70639 Mdot
.44734 .6679 Mdot
.44492 .70417 Mdot
.36933 .205 Mdot
.53313 .36366 Mdot
.66771 .63652 Mdot
.63097 .59802 Mdot
.60999 .70653 Mdot
.7111 .59376 Mdot
.38156 .39384 Mdot
.36526 .51175 Mdot
.66023 .58924 Mdot
.64229 .49996 Mdot
.57855 .49425 Mdot
.5728 .61324 Mdot
.58077 .41635 Mdot
.56052 .34264 Mdot
.60258 .58854 Mdot
.34926 .51314 Mdot
.54008 .12789 Mdot
.15597 .51489 Mdot
.59682 .49932 Mdot
.45056 .56961 Mdot
.53995 .37171 Mdot
.43739 .41607 Mdot
.48509 .6148 Mdot
.42624 .36409 Mdot
.56484 .36433 Mdot
.65857 .5137 Mdot
.48276 .29135 Mdot
.45244 .70762 Mdot
.60372 .56851 Mdot
.39129 .38933 Mdot
.59523 .55824 Mdot
.42269 .41347 Mdot
.18756 .42899 Mdot
.40734 .77801 Mdot
.64092 .53958 Mdot
.64035 .48956 Mdot
.48733 .76682 Mdot
.63277 .57652 Mdot
.44936 .73515 Mdot
.53853 .36908 Mdot
.74321 .65425 Mdot
.5879 .52338 Mdot
.73144 .36544 Mdot
.66146 .59989 Mdot
.6314 .76575 Mdot
.6237 .55998 Mdot
.29571 .64993 Mdot
.61327 .52089 Mdot
.59557 .53646 Mdot
.43229 .37077 Mdot
.40823 .42322 Mdot
.60769 .33678 Mdot
.35343 .56685 Mdot
.23821 .32144 Mdot
.63045 .55669 Mdot
.24295 .49519 Mdot
.48847 .31222 Mdot
.44606 .66614 Mdot
.5652 .36803 Mdot
.73588 .24875 Mdot
.4145 .3564 Mdot
.42644 .75751 Mdot
.64056 .75093 Mdot
.39247 .31972 Mdot
.49411 .63805 Mdot
.43585 .22677 Mdot
.43466 .69005 Mdot
.59296 .57109 Mdot
.22516 .49635 Mdot
.29746 .67027 Mdot
.62314 .46376 Mdot
.43029 .42655 Mdot
.74129 .42309 Mdot
.21798 .4912 Mdot
.42012 .67313 Mdot
.43568 .64877 Mdot
.43945 .40699 Mdot
.29421 .51188 Mdot
.58684 .61209 Mdot
.44592 .67621 Mdot
.32115 .54145 Mdot
.38643 .51316 Mdot
.3809 .58613 Mdot
.57795 .38082 Mdot
.23129 .64358 Mdot
.37838 .29148 Mdot
.4158 .41434 Mdot
.29408 .54682 Mdot
.57991 .40917 Mdot
.53014 .36152 Mdot
.34513 .54652 Mdot
.38218 .54464 Mdot
.56231 .31655 Mdot
.5772 .57006 Mdot
.57068 .50786 Mdot
.64291 .55125 Mdot
.46191 .68731 Mdot
.62403 .56471 Mdot
.36727 .55756 Mdot
.40826 .3737 Mdot
.38108 .53351 Mdot
.39541 .35835 Mdot
.28232 .34292 Mdot
.60678 .5651 Mdot
.61173 .52707 Mdot
.81756 .50205 Mdot
.6107 .35771 Mdot
.31429 .34167 Mdot
.25414 .48 Mdot
.34804 .5228 Mdot
.59047 .54404 Mdot
.56576 .39429 Mdot
.41949 .65978 Mdot
.8226 .48792 Mdot
.65739 .59402 Mdot
.54037 .36919 Mdot
.64109 .51058 Mdot
.6276 .28462 Mdot
.63209 .81472 Mdot
.57583 .37264 Mdot
.81938 .54346 Mdot
.63804 .50384 Mdot
.51582 .21351 Mdot
.68865 .54843 Mdot
.61437 .74456 Mdot
.62725 .59499 Mdot
.60394 .35482 Mdot
.64293 .55605 Mdot
.57972 .39018 Mdot
.32702 .54772 Mdot
.4443 .40744 Mdot
.59135 .34042 Mdot
.68359 .55716 Mdot
.09682 .53499 Mdot
.40182 .40149 Mdot
.63081 .53681 Mdot
.44363 .37807 Mdot
.55471 .37237 Mdot
.59375 .33534 Mdot
.61122 .20322 Mdot
.29063 .39546 Mdot
.41513 .39985 Mdot
.65202 .51083 Mdot
.38607 .26924 Mdot
.66712 .54895 Mdot
.56944 .75042 Mdot
.57253 .56704 Mdot
.64294 .59947 Mdot
.53554 .17597 Mdot
.39666 .41248 Mdot
.77047 .66426 Mdot
.59809 .19701 Mdot
.41709 .20524 Mdot
.60232 .30431 Mdot
.41953 .66976 Mdot
.30297 .24551 Mdot
.26584 .42976 Mdot
.35731 .56189 Mdot
.65331 .59016 Mdot
.60282 .40484 Mdot
.42242 .37662 Mdot
.46349 .67089 Mdot
.64006 .53935 Mdot
.38352 .54076 Mdot
.5204 .80812 Mdot
.42427 .35397 Mdot
.5677 .37726 Mdot
.54493 .33424 Mdot
.84021 .41636 Mdot
.63475 .51627 Mdot
.60893 .52563 Mdot
.40525 .40591 Mdot
.56328 .24225 Mdot
.43458 .69298 Mdot
.5654 .78927 Mdot
.41356 .39988 Mdot
.48651 .50422 Mdot
.55779 .35654 Mdot
.64512 .58634 Mdot
.32516 .26828 Mdot
.36534 .71359 Mdot
.78949 .40681 Mdot
.45766 .69222 Mdot
.56378 .74739 Mdot
.6046 .35228 Mdot
.39654 .3784 Mdot
.29897 .46742 Mdot
.70225 .53271 Mdot
.64469 .58313 Mdot
.5671 .74309 Mdot
.52157 .42184 Mdot
.65981 .6602 Mdot
.65929 .59543 Mdot
.53218 .44127 Mdot
.63417 .59397 Mdot
.71059 .54765 Mdot
.59655 .59306 Mdot
.61792 .55008 Mdot
.54007 .37012 Mdot
.67591 .4877 Mdot
.37025 .56489 Mdot
.65027 .64769 Mdot
.49439 .51194 Mdot
.63371 .52582 Mdot
.66956 .53774 Mdot
.78628 .4421 Mdot
.39086 .45725 Mdot
.58749 .34042 Mdot
.53014 .33758 Mdot
.45233 .38531 Mdot
.5735 .50123 Mdot
.35814 .56965 Mdot
.71186 .58642 Mdot
.37864 .54831 Mdot
.54695 .37674 Mdot
.34097 .52762 Mdot
.44874 .38985 Mdot
.38899 .52003 Mdot
.26049 .43634 Mdot
.39678 .3694 Mdot
.59466 .36938 Mdot
.60712 .53654 Mdot
.38427 .37633 Mdot
.54995 .66937 Mdot
.4608 .68839 Mdot
.59361 .18845 Mdot
.61183 .51444 Mdot
.4559 .32799 Mdot
.61802 .30972 Mdot
.38118 .53796 Mdot
.67183 .77801 Mdot
.54747 .33199 Mdot
.46037 .64508 Mdot
.55375 .38599 Mdot
.36821 .7581 Mdot
.45743 .66966 Mdot
.5002 .17849 Mdot
.26699 .52411 Mdot
.48442 .71722 Mdot
.57523 .56144 Mdot
.51809 .64808 Mdot
.39197 .56522 Mdot
.42181 .37567 Mdot
.31417 .46765 Mdot
.59242 .54257 Mdot
.45488 .79623 Mdot
.59228 .31441 Mdot
.35668 .56669 Mdot
.4002 .38216 Mdot
.38313 .3941 Mdot
.67518 .58511 Mdot
.31335 .61755 Mdot
.61914 .58412 Mdot
.31151 .42849 Mdot
.53138 .75803 Mdot
.5713 .60252 Mdot
.62877 .52921 Mdot
.33202 .55397 Mdot
.64163 .51057 Mdot
.47163 .64865 Mdot
.22677 .64939 Mdot
.69437 .57531 Mdot
.25592 .47066 Mdot
.40816 .67428 Mdot
.56674 .34655 Mdot
.57786 .59545 Mdot
.27176 .43234 Mdot
.63935 .51413 Mdot
.61842 .85713 Mdot
.43966 .68715 Mdot
.23265 .51059 Mdot
.6896 .53086 Mdot
.67945 .56561 Mdot
.53069 .49139 Mdot
.50409 .39031 Mdot
.37097 .71732 Mdot
.64177 .57605 Mdot
.5311 .72284 Mdot
.43661 .40408 Mdot
.62715 .58814 Mdot
.63148 .54407 Mdot
.73174 .49738 Mdot
.38406 .38713 Mdot
.3612 .51859 Mdot
.38714 .57491 Mdot
.35743 .50053 Mdot
.47082 .65128 Mdot
.49941 .4509 Mdot
.61638 .69067 Mdot
.50964 .82338 Mdot
.47448 .67496 Mdot
.61265 .51021 Mdot
.41835 .72554 Mdot
.66701 .52188 Mdot
.45027 .65582 Mdot
.38513 .38251 Mdot
.58724 .33764 Mdot
.48855 .24957 Mdot
.3979 .53569 Mdot
.68551 .57581 Mdot
.42594 .67993 Mdot
.59152 .37242 Mdot
.49179 .6847 Mdot
.56307 .35493 Mdot
.41009 .39501 Mdot
.4414 .35839 Mdot
.45944 .66279 Mdot
.54654 .36939 Mdot
.389 .43784 Mdot
.64838 .21869 Mdot
.60475 .60073 Mdot
.45538 .36349 Mdot
.60542 .37355 Mdot
.54468 .32152 Mdot
.59975 .37435 Mdot
.5961 .55033 Mdot
.45019 .56762 Mdot
.57298 .5331 Mdot
.40589 .41515 Mdot
.3527 .51562 Mdot
.48661 .78122 Mdot
.25114 .396 Mdot
.41141 .61975 Mdot
.62681 .60049 Mdot
.6502 .54981 Mdot
.62874 .53802 Mdot
.59717 .51129 Mdot
.29877 .43593 Mdot
.62888 .58389 Mdot
.43557 .37303 Mdot
.37026 .54919 Mdot
.591 .5691 Mdot
.37304 .58244 Mdot
.392 .23781 Mdot
.47315 .67065 Mdot
.49768 .43792 Mdot
.13024 .4345 Mdot
.59712 .36126 Mdot
.31933 .56133 Mdot
.35433 .56061 Mdot
.4505 .70181 Mdot
.42233 .38266 Mdot
.55977 .35888 Mdot
.58874 .76061 Mdot
.43531 .69979 Mdot
.64057 .55565 Mdot
.44969 .59582 Mdot
.43531 .78357 Mdot
.60112 .57854 Mdot
.6684 .57648 Mdot
.33126 .57782 Mdot
.27258 .57674 Mdot
.25657 .72611 Mdot
.60267 .66966 Mdot
.46007 .66584 Mdot
.4607 .65239 Mdot
.56948 .315 Mdot
.57695 .52087 Mdot
.40775 .41549 Mdot
.67 .65411 Mdot
.46143 .42913 Mdot
.5739 .64162 Mdot
.5823 .44188 Mdot
.65182 .59354 Mdot
.71071 .28016 Mdot
.65018 .54551 Mdot
.53653 .37305 Mdot
.56087 .3825 Mdot
.59217 .35625 Mdot
.41982 .37663 Mdot
.70873 .43664 Mdot
.43694 .3783 Mdot
.1294 .44889 Mdot
.60446 .34462 Mdot
.26955 .48834 Mdot
.33388 .5497 Mdot
.60922 .49103 Mdot
.43006 .68173 Mdot
.44806 .42227 Mdot
.63282 .48137 Mdot
.68098 .75948 Mdot
.36208 .566 Mdot
.59754 .36446 Mdot
.44917 .22289 Mdot
.15872 .44269 Mdot
.47641 .59061 Mdot
.72477 .55827 Mdot
.51476 .63246 Mdot
.44316 .66468 Mdot
.79259 .41196 Mdot
.42707 .6708 Mdot
.39036 .3828 Mdot
.61427 .53011 Mdot
.61118 .54007 Mdot
.62888 .5933 Mdot
.61753 .57416 Mdot
.44243 .41355 Mdot
.67279 .59893 Mdot
.56917 .84503 Mdot
.34294 .513 Mdot
.63133 .4043 Mdot
.43568 .68689 Mdot
.44506 .41738 Mdot
.37018 .55092 Mdot
.37965 .46015 Mdot
.5697 .66785 Mdot
.62825 .52482 Mdot
.65718 .59022 Mdot
.42388 .75997 Mdot
.65954 .5959 Mdot
.71125 .59619 Mdot
.35439 .56204 Mdot
.41343 .62151 Mdot
.46028 .64907 Mdot
.45102 .64934 Mdot
.40349 .36389 Mdot
.54807 .37696 Mdot
.44998 .68702 Mdot
.32851 .54259 Mdot
.62717 .60133 Mdot
.67988 .54167 Mdot
.60591 .37085 Mdot
.29132 .71701 Mdot
.42216 .66922 Mdot
.42277 .23029 Mdot
.56448 .38877 Mdot
.55043 .40078 Mdot
.64631 .58293 Mdot
.55628 .48899 Mdot
.6181 .32161 Mdot
.47551 .67459 Mdot
.44743 .41441 Mdot
.49452 .617 Mdot
.39541 .40341 Mdot
.5615 .37831 Mdot
.66947 .51587 Mdot
.56701 .38487 Mdot
.63287 .51879 Mdot
.17705 .34986 Mdot
.61375 .54875 Mdot
.50876 .82752 Mdot
.60591 .72881 Mdot
.35733 .54917 Mdot
.4634 .41619 Mdot
.34129 .55382 Mdot
.56753 .3895 Mdot
.67681 .52676 Mdot
.43227 .64874 Mdot
.45416 .19075 Mdot
.57818 .41084 Mdot
.38174 .55498 Mdot
.38017 .50209 Mdot
.38809 .37823 Mdot
.60895 .58769 Mdot
.64018 .58344 Mdot
.36082 .53687 Mdot
.57659 .60876 Mdot
.5457 .34614 Mdot
.61929 .52692 Mdot
.65373 .55738 Mdot
.35452 .54939 Mdot
.66227 .22318 Mdot
.50778 .37237 Mdot
.61652 .53742 Mdot
.25153 .52797 Mdot
.38233 .39715 Mdot
.57255 .55262 Mdot
.65437 .49042 Mdot
.44711 .67045 Mdot
.63987 .4433 Mdot
.21836 .62066 Mdot
.38974 .3662 Mdot
.33934 .55944 Mdot
.63433 .51495 Mdot
.33332 .55521 Mdot
.68149 .55327 Mdot
.56957 .42954 Mdot
.38449 .56166 Mdot
.67548 .56309 Mdot
.56318 .54458 Mdot
.57946 .38644 Mdot
.65503 .59215 Mdot
.78605 .48002 Mdot
.34949 .57691 Mdot
.67846 .57044 Mdot
.66416 .30204 Mdot
.42908 .38865 Mdot
.56519 .53737 Mdot
.46926 .68729 Mdot
.58986 .76206 Mdot
.43903 .29941 Mdot
.22221 .51405 Mdot
.47089 .66786 Mdot
.59705 .56272 Mdot
.37181 .49953 Mdot
.43188 .41093 Mdot
.53563 .82485 Mdot
.59284 .56659 Mdot
.40006 .4031 Mdot
.40636 .3745 Mdot
.45929 .69511 Mdot
.83532 .55412 Mdot
.68971 .52662 Mdot
.62928 .57306 Mdot
.76172 .50776 Mdot
.604 .38415 Mdot
.61732 .55849 Mdot
.63047 .50206 Mdot
.43834 .37534 Mdot
.71542 .59345 Mdot
.75988 .42178 Mdot
.59555 .77821 Mdot
.37959 .39532 Mdot
.49787 .57639 Mdot
.39567 .54456 Mdot
.43507 .67957 Mdot
.57027 .35182 Mdot
.42454 .67429 Mdot
.38619 .51927 Mdot
.61724 .50777 Mdot
.43504 .36377 Mdot
.79307 .52325 Mdot
.43916 .40782 Mdot
.21935 .5233 Mdot
.60325 .38304 Mdot
.44932 .26161 Mdot
.67439 .81992 Mdot
.36152 .2948 Mdot
.38585 .45032 Mdot
.44645 .66633 Mdot
.3939 .48623 Mdot
.65321 .55477 Mdot
.8024 .43539 Mdot
.6031 .53554 Mdot
.66705 .3112 Mdot
.32441 .53357 Mdot
.36534 .50496 Mdot
.61545 .53326 Mdot
.54093 .75666 Mdot
.43182 .41227 Mdot
.39206 .40777 Mdot
.67626 .57788 Mdot
.41329 .39122 Mdot
.633 .56651 Mdot
.37423 .5542 Mdot
.76525 .6874 Mdot
.64054 .54582 Mdot
.63477 .49246 Mdot
.44847 .33742 Mdot
.55672 .18634 Mdot
.24031 .59472 Mdot
.76696 .31901 Mdot
.15572 .46961 Mdot
.41228 .39051 Mdot
.56988 .5372 Mdot
.49931 .57828 Mdot
.381 .58062 Mdot
.39141 .44361 Mdot
.60733 .54941 Mdot
.60428 .54899 Mdot
.59653 .53313 Mdot
.66447 .56038 Mdot
.79246 .40227 Mdot
.73018 .61032 Mdot
.66927 .37498 Mdot
.66709 .58732 Mdot
.52577 .6546 Mdot
.40302 .36166 Mdot
.5706 .30687 Mdot
.46497 .71432 Mdot
.65138 .5934 Mdot
.69681 .62922 Mdot
.39903 .42177 Mdot
.12878 .45061 Mdot
.39279 .37027 Mdot
.35953 .52198 Mdot
.43638 .41547 Mdot
.64593 .52892 Mdot
.57339 .36247 Mdot
.49277 .54727 Mdot
.32968 .37851 Mdot
.35837 .56207 Mdot
.63701 .52559 Mdot
.26636 .48286 Mdot
.3677 .56444 Mdot
.38724 .24011 Mdot
.57453 .35567 Mdot
.53436 .71616 Mdot
.56263 .38417 Mdot
.67637 .561 Mdot
.67541 .5551 Mdot
.46586 .38388 Mdot
.44509 .40433 Mdot
.56053 .38348 Mdot
.83959 .56436 Mdot
.42652 .69259 Mdot
.59057 .36211 Mdot
.70803 .57806 Mdot
.44605 .48537 Mdot
.57917 .3591 Mdot
.43217 .61843 Mdot
.41685 .37008 Mdot
.59456 .32412 Mdot
.70667 .54785 Mdot
.29694 .70434 Mdot
.4704 .69461 Mdot
.30345 .55768 Mdot
.44758 .60586 Mdot
.33975 .57506 Mdot
.45352 .39984 Mdot
.34455 .55437 Mdot
.43841 .40127 Mdot
.46315 .3119 Mdot
.61995 .64744 Mdot
.40191 .34379 Mdot
.45093 .40426 Mdot
.34687 .55261 Mdot
.61653 .52349 Mdot
.46808 .61305 Mdot
.57005 .54259 Mdot
.69396 .52999 Mdot
.43276 .40235 Mdot
.60164 .36067 Mdot
.5463 .32393 Mdot
.52086 .67995 Mdot
.54018 .34562 Mdot
.37998 .5474 Mdot
.60006 .82553 Mdot
.23703 .48841 Mdot
.41711 .40808 Mdot
.43185 .42082 Mdot
.66858 .54661 Mdot
.34972 .53514 Mdot
.32905 .55615 Mdot
.38832 .38607 Mdot
.54902 .59443 Mdot
.60407 .49959 Mdot
.53 .34254 Mdot
.60129 .33406 Mdot
.57923 .3684 Mdot
.5963 .37825 Mdot
.75347 .37984 Mdot
.41163 .36732 Mdot
.59802 .36921 Mdot
.6752 .56924 Mdot
.6057 .55028 Mdot
.4889 .58988 Mdot
.45717 .65166 Mdot
.58297 .55742 Mdot
.59604 .59132 Mdot
.64955 .5852 Mdot
.38823 .53401 Mdot
.61444 .47053 Mdot
.38319 .56378 Mdot
.34792 .50692 Mdot
.32691 .52492 Mdot
.264 .43255 Mdot
.4823 .73258 Mdot
.17128 .49519 Mdot
.64603 .50739 Mdot
.58433 .24768 Mdot
.33862 .53957 Mdot
.67464 .76995 Mdot
.5408 .26157 Mdot
.58879 .55433 Mdot
.34814 .70676 Mdot
.35909 .5388 Mdot
.54177 .33988 Mdot
.60935 .54933 Mdot
.32772 .5179 Mdot
.46868 .69252 Mdot
.64323 .60983 Mdot
.36996 .57924 Mdot
.5481 .36911 Mdot
.47403 .70318 Mdot
.60307 .33358 Mdot
.326 .52687 Mdot
.564 .54133 Mdot
.32934 .82637 Mdot
.38637 .50313 Mdot
.58387 .2197 Mdot
.53624 .30938 Mdot
.61787 .52581 Mdot
.32349 .56752 Mdot
.58879 .39747 Mdot
.45524 .38419 Mdot
.45694 .43978 Mdot
.57305 .32354 Mdot
.36774 .5048 Mdot
.36077 .58002 Mdot
.35567 .56242 Mdot
.56391 .33817 Mdot
.63673 .49474 Mdot
.56154 .33223 Mdot
.43476 .41656 Mdot
.6614 .54106 Mdot
.18006 .40463 Mdot
.58723 .25123 Mdot
.5624 .38664 Mdot
.36836 .51782 Mdot
.45791 .70756 Mdot
.64477 .53936 Mdot
.61829 .24672 Mdot
.62136 .51782 Mdot
.42594 .40972 Mdot
.72202 .70647 Mdot
.7992 .5044 Mdot
.63194 .59762 Mdot
.66859 .54771 Mdot
.39869 .4121 Mdot
.63609 .5319 Mdot
.62284 .59394 Mdot
.27291 .4208 Mdot
.55684 .34285 Mdot
.64584 .55608 Mdot
.33774 .52357 Mdot
.25317 .42629 Mdot
.60113 .5038 Mdot
.39051 .64548 Mdot
.54039 .7305 Mdot
.74449 .66862 Mdot
.60333 .53288 Mdot
.58996 .65776 Mdot
.66247 .56845 Mdot
.60542 .56855 Mdot
.66445 .52604 Mdot
.80408 .40265 Mdot
.38623 .55567 Mdot
.36 .55733 Mdot
.47364 .68957 Mdot
.53802 .72887 Mdot
.44945 .67445 Mdot
.41868 .36872 Mdot
.35277 .63596 Mdot
.38379 .56224 Mdot
.549 .3735 Mdot
.60628 .57325 Mdot
.38553 .50184 Mdot
.64094 .58595 Mdot
.64587 .52688 Mdot
.35243 .57138 Mdot
.39366 .55398 Mdot
.22861 .51057 Mdot
.4725 .67871 Mdot
.5921 .34928 Mdot
.57996 .55807 Mdot
.42718 .68525 Mdot
.65807 .50166 Mdot
.61417 .70496 Mdot
.59074 .35233 Mdot
.55789 .33912 Mdot
.54725 .32555 Mdot
.61775 .50784 Mdot
.64374 .5318 Mdot
.43806 .38115 Mdot
.55343 .38394 Mdot
.42717 .38986 Mdot
.5017 .48304 Mdot
.39632 .68555 Mdot
.60721 .54939 Mdot
.43571 .23111 Mdot
.43565 .67208 Mdot
.37578 .52947 Mdot
.4483 .77587 Mdot
.4733 .69149 Mdot
.62978 .5196 Mdot
.33341 .56092 Mdot
.45197 .6543 Mdot
.62743 .45985 Mdot
.16647 .56819 Mdot
.46025 .71094 Mdot
.67523 .57186 Mdot
.72429 .58832 Mdot
.78055 .33039 Mdot
.47439 .6947 Mdot
.44509 .37622 Mdot
.61663 .50887 Mdot
.62403 .35374 Mdot
.4239 .6657 Mdot
.32597 .33414 Mdot
.3663 .54453 Mdot
.25072 .65849 Mdot
.63559 .47784 Mdot
.80945 .49908 Mdot
.43415 .65961 Mdot
.56067 .36241 Mdot
.54771 .30776 Mdot
.65323 .57978 Mdot
.47388 .69576 Mdot
.38121 .40271 Mdot
.37202 .54038 Mdot
.28762 .39116 Mdot
.56521 .33617 Mdot
.42571 .2513 Mdot
.37426 .51725 Mdot
.41474 .23684 Mdot
.65511 .75543 Mdot
.56654 .52126 Mdot
.77448 .33158 Mdot
.31073 .48437 Mdot
.60319 .51308 Mdot
.43456 .70512 Mdot
.3877 .36893 Mdot
.44355 .36954 Mdot
.40953 .39827 Mdot
.48103 .31224 Mdot
.48591 .6011 Mdot
.31594 .55772 Mdot
.34998 .39409 Mdot
.43704 .68095 Mdot
.53142 .63937 Mdot
.68427 .54471 Mdot
.64844 .54918 Mdot
.60994 .58931 Mdot
.63913 .59313 Mdot
.65705 .57077 Mdot
.42041 .38825 Mdot
.45064 .31687 Mdot
.49685 .60222 Mdot
.5857 .35565 Mdot
.30619 .60453 Mdot
.33425 .54841 Mdot
.31326 .55435 Mdot
.4617 .65968 Mdot
.41182 .22654 Mdot
.37264 .5821 Mdot
.34379 .52468 Mdot
.59233 .52754 Mdot
.5518 .3382 Mdot
.71684 .55065 Mdot
.67253 .55736 Mdot
.3777 .54214 Mdot
.52271 .49215 Mdot
.7747 .43409 Mdot
.62055 .46743 Mdot
.41639 .63968 Mdot
.45533 .55991 Mdot
.46443 .70536 Mdot
.67864 .52542 Mdot
.68444 .76252 Mdot
.38779 .52239 Mdot
.35516 .52708 Mdot
.43497 .66154 Mdot
.59415 .42603 Mdot
.57241 .34245 Mdot
.3697 .44905 Mdot
.44494 .38451 Mdot
.67287 .53322 Mdot
.51601 .80375 Mdot
.62608 .38934 Mdot
.31669 .62285 Mdot
.40961 .4018 Mdot
.32887 .54993 Mdot
.6263 .59861 Mdot
.67422 .57242 Mdot
.43548 .6665 Mdot
.23285 .3657 Mdot
.61497 .60021 Mdot
.40372 .20542 Mdot
.40563 .77842 Mdot
.29703 .71499 Mdot
.6444 .58302 Mdot
.55848 .34213 Mdot
.36864 .5808 Mdot
.42923 .67348 Mdot
.70308 .57307 Mdot
.16792 .54015 Mdot
.60807 .35472 Mdot
.39307 .37903 Mdot
.50067 .53007 Mdot
.48341 .61186 Mdot
.60591 .51612 Mdot
.60422 .53586 Mdot
.59971 .55729 Mdot
.19168 .62291 Mdot
.38689 .54191 Mdot
.54278 .37517 Mdot
.46506 .68695 Mdot
.53806 .35431 Mdot
.3559 .55441 Mdot
.43054 .25809 Mdot
.61612 .51993 Mdot
.60858 .35624 Mdot
.56227 .36077 Mdot
.39044 .3739 Mdot
.45179 .37378 Mdot
.50158 .50468 Mdot
.61546 .55065 Mdot
.39261 .51044 Mdot
.59002 .3787 Mdot
.45403 .59659 Mdot
.45598 .66925 Mdot
.42633 .3687 Mdot
.66317 .58928 Mdot
.39112 .54234 Mdot
.6751 .59813 Mdot
.58202 .34256 Mdot
.34286 .52578 Mdot
.23574 .50374 Mdot
.46578 .65768 Mdot
.61261 .56375 Mdot
.48136 .67959 Mdot
.33908 .55988 Mdot
.65503 .55571 Mdot
.47749 .20788 Mdot
.40875 .65257 Mdot
.32312 .37232 Mdot
.32003 .53708 Mdot
.24587 .4937 Mdot
.56521 .31887 Mdot
.50875 .30012 Mdot
.35848 .52496 Mdot
.4385 .22231 Mdot
.23173 .3917 Mdot
.60873 .59136 Mdot
.5732 .37752 Mdot
.36072 .47001 Mdot
.20702 .33982 Mdot
.66098 .23074 Mdot
.63096 .53849 Mdot
.31722 .55026 Mdot
.43852 .66071 Mdot
.41925 .40843 Mdot
.39192 .65153 Mdot
.4125 .64243 Mdot
.39301 .51731 Mdot
.66454 .52487 Mdot
.55539 .36844 Mdot
.41539 .3738 Mdot
.44471 .30302 Mdot
.32959 .53532 Mdot
.36125 .51392 Mdot
.62746 .59856 Mdot
.44715 .67972 Mdot
.64 .25096 Mdot
.37206 .55681 Mdot
.423 .76593 Mdot
.40057 .55837 Mdot
.42654 .68933 Mdot
.66574 .57277 Mdot
.51579 .68311 Mdot
.58067 .52651 Mdot
.53773 .19852 Mdot
.34047 .5507 Mdot
.58616 .34598 Mdot
.59588 .54308 Mdot
.61855 .76423 Mdot
.3768 .53796 Mdot
.45251 .56986 Mdot
.28759 .64197 Mdot
.4142 .36847 Mdot
.44875 .77728 Mdot
.62117 .56545 Mdot
.43261 .41147 Mdot
.43673 .67142 Mdot
.6169 .54342 Mdot
.64624 .53287 Mdot
.54933 .38826 Mdot
.3895 .38726 Mdot
.2118 .42931 Mdot
.40403 .42282 Mdot
.41666 .36053 Mdot
.53666 .38227 Mdot
.64319 .56783 Mdot
.35988 .52094 Mdot
.35807 .53733 Mdot
.6999 .55278 Mdot
.71311 .75434 Mdot
.57227 .33913 Mdot
.30088 .5313 Mdot
.20594 .64561 Mdot
.5583 .53948 Mdot
.4632 .784 Mdot
.24361 .35277 Mdot
.37693 .38541 Mdot
.67342 .58273 Mdot
.55108 .37154 Mdot
.39025 .47368 Mdot
.36223 .51505 Mdot
.64808 .49774 Mdot
.41139 .3772 Mdot
.46969 .69252 Mdot
.36264 .57525 Mdot
.31843 .62004 Mdot
.60968 .56922 Mdot
.34578 .70938 Mdot
.32362 .56216 Mdot
.32957 .21462 Mdot
.37193 .46308 Mdot
.57805 .37554 Mdot
.64875 .52803 Mdot
.55359 .32446 Mdot
.46655 .68037 Mdot
.49964 .5273 Mdot
.41005 .37502 Mdot
.73615 .59261 Mdot
.51968 .86227 Mdot
.35232 .56244 Mdot
.53861 .37023 Mdot
.63526 .5986 Mdot
.56071 .45832 Mdot
.62768 .56849 Mdot
.69219 .61748 Mdot
.40716 .69044 Mdot
.43175 .39949 Mdot
.43825 .40525 Mdot
.6577 .55083 Mdot
.43664 .69834 Mdot
.32995 .54512 Mdot
.37273 .5367 Mdot
.46446 .14835 Mdot
.38223 .33272 Mdot
.55346 .76642 Mdot
.60505 .55315 Mdot
.38038 .50584 Mdot
.25237 .40251 Mdot
.40623 .40581 Mdot
.687 .55212 Mdot
.35875 .56921 Mdot
.31677 .71244 Mdot
.6301 .74577 Mdot
.65867 .57421 Mdot
.6694 .49784 Mdot
.44527 .38182 Mdot
.53949 .63408 Mdot
.33583 .51968 Mdot
.57395 .57217 Mdot
.41325 .34635 Mdot
.70555 .70719 Mdot
.2612 .69875 Mdot
.5924 .34958 Mdot
.27414 .60082 Mdot
.42097 .38749 Mdot
.68176 .50383 Mdot
.44064 .69314 Mdot
.38258 .57269 Mdot
.38831 .54536 Mdot
.65313 .51372 Mdot
.66782 .60025 Mdot
.47321 .76614 Mdot
.54029 .35308 Mdot
.40452 .36193 Mdot
.60815 .52846 Mdot
.48786 .24156 Mdot
.63172 .59399 Mdot
.43644 .38319 Mdot
.31846 .82601 Mdot
.58339 .56733 Mdot
.63024 .57128 Mdot
.63958 .24758 Mdot
.57598 .32438 Mdot
.53581 .36497 Mdot
.45805 .81399 Mdot
.60547 .55408 Mdot
.43611 .77137 Mdot
.59212 .34486 Mdot
.57513 .34015 Mdot
.29037 .40654 Mdot
.64484 .54271 Mdot
.7385 .61957 Mdot
.42189 .41291 Mdot
.42376 .36195 Mdot
.56403 .33242 Mdot
.59104 .5792 Mdot
.40201 .35617 Mdot
.75662 .34272 Mdot
.34823 .53631 Mdot
.70408 .74704 Mdot
.5781 .33149 Mdot
.51689 .43607 Mdot
.40944 .40444 Mdot
.13014 .44628 Mdot
.39501 .57867 Mdot
.61481 .5243 Mdot
.60848 .56177 Mdot
.43472 .67487 Mdot
.58386 .56622 Mdot
.36104 .50571 Mdot
.41371 .39158 Mdot
.64617 .31558 Mdot
.59233 .35707 Mdot
.62295 .55806 Mdot
.4023 .23343 Mdot
.3204 .32091 Mdot
.24942 .57966 Mdot
.56666 .34785 Mdot
.57744 .37993 Mdot
.34114 .5171 Mdot
.31784 .55277 Mdot
.64849 .57384 Mdot
.39599 .4089 Mdot
.55521 .38479 Mdot
.43733 .39142 Mdot
.38749 .52254 Mdot
.35582 .52005 Mdot
.38866 .55489 Mdot
.65083 .61563 Mdot
.33919 .52557 Mdot
.37084 .6199 Mdot
.41626 .25567 Mdot
.53001 .36381 Mdot
.34854 .77719 Mdot
.45451 .30262 Mdot
.50124 .34589 Mdot
.42673 .65564 Mdot
.33919 .5605 Mdot
.4246 .42246 Mdot
.66511 .55303 Mdot
.64898 .58922 Mdot
.3241 .59876 Mdot
.42325 .41908 Mdot
.46485 .67331 Mdot
.43405 .41282 Mdot
.45905 .69551 Mdot
.30911 .68247 Mdot
.60138 .58141 Mdot
.67945 .54497 Mdot
.41849 .39282 Mdot
.33953 .52699 Mdot
.36567 .55197 Mdot
.46622 .70839 Mdot
.54508 .42652 Mdot
.367 .56513 Mdot
.58002 .33426 Mdot
.7428 .35769 Mdot
.3598 .58033 Mdot
.61189 .55312 Mdot
.62364 .68957 Mdot
.80983 .47031 Mdot
.59784 .5105 Mdot
.28388 .41064 Mdot
.80278 .5594 Mdot
.59179 .5543 Mdot
.82285 .52772 Mdot
.25156 .48904 Mdot
.56099 .32282 Mdot
.32681 .53005 Mdot
.32484 .57625 Mdot
.63431 .62151 Mdot
.44632 .71553 Mdot
.70331 .56483 Mdot
.58362 .32883 Mdot
.60699 .32321 Mdot
.33323 .73675 Mdot
.57668 .21461 Mdot
.44237 .65752 Mdot
.45451 .65311 Mdot
.36197 .52592 Mdot
.63448 .19097 Mdot
.67366 .48951 Mdot
.46173 .66743 Mdot
.5909 .64072 Mdot
.66361 .5213 Mdot
.58051 .73626 Mdot
.40353 .74745 Mdot
.56168 .33781 Mdot
.5184 .65959 Mdot
.36859 .52469 Mdot
.54395 .34012 Mdot
.4988 .24881 Mdot
.58084 .5441 Mdot
.5909 .35412 Mdot
.43882 .38889 Mdot
.33753 .45563 Mdot
.5942 .33668 Mdot
.62144 .69549 Mdot
.38796 .39127 Mdot
.45334 .59224 Mdot
.52547 .69631 Mdot
.85742 .63899 Mdot
.41742 .38777 Mdot
.3782 .56974 Mdot
.35922 .5373 Mdot
.37184 .53504 Mdot
.54025 .34881 Mdot
.3303 .55689 Mdot
.5394 .36052 Mdot
.72073 .26911 Mdot
.58441 .43975 Mdot
.45855 .66311 Mdot
.29374 .38815 Mdot
.56366 .37329 Mdot
.63753 .80721 Mdot
.61402 .84797 Mdot
.67283 .58482 Mdot
.4235 .42545 Mdot
.45204 .65762 Mdot
.42668 .18569 Mdot
.44383 .67027 Mdot
.49141 .70743 Mdot
.72122 .71433 Mdot
.6303 .56123 Mdot
.74064 .44301 Mdot
.44133 .646 Mdot
.55894 .35473 Mdot
.65389 .55311 Mdot
.39783 .46317 Mdot
.44345 .67423 Mdot
.46152 .69788 Mdot
.64972 .56605 Mdot
.59731 .36512 Mdot
.36898 .52117 Mdot
.44986 .39587 Mdot
.45477 .64005 Mdot
.52013 .34323 Mdot
.59032 .52316 Mdot
.62995 .51227 Mdot
.47536 .57586 Mdot
.48076 .6457 Mdot
.41209 .38973 Mdot
.82365 .46189 Mdot
.31929 .54395 Mdot
.34131 .4789 Mdot
.40527 .77001 Mdot
.27114 .43021 Mdot
.3428 .54969 Mdot
.33987 .5575 Mdot
.65516 .5735 Mdot
.46895 .63483 Mdot
.73904 .68687 Mdot
.38347 .4285 Mdot
.36588 .58132 Mdot
.37349 .53998 Mdot
.59631 .31146 Mdot
.34441 .74599 Mdot
.7026 .57689 Mdot
.39201 .36282 Mdot
.38976 .54604 Mdot
.56093 .42433 Mdot
.44459 .68224 Mdot
.64828 .78997 Mdot
.59794 .57776 Mdot
.61245 .52701 Mdot
.40241 .38598 Mdot
.43598 .3762 Mdot
.39608 .47497 Mdot
.38936 .76351 Mdot
.80435 .54249 Mdot
.41988 .30688 Mdot
.68564 .47052 Mdot
.59676 .31455 Mdot
.56299 .38683 Mdot
.33576 .33472 Mdot
.40245 .42285 Mdot
.59298 .54941 Mdot
.55146 .3792 Mdot
.28017 .50856 Mdot
.60473 .26959 Mdot
.56399 .75152 Mdot
.47779 .78263 Mdot
.63351 .52019 Mdot
.55082 .34654 Mdot
.57546 .32534 Mdot
.57917 .39492 Mdot
.25612 .48498 Mdot
.64122 .5761 Mdot
.62994 .52809 Mdot
.60233 .57309 Mdot
.54681 .55883 Mdot
.62282 .58006 Mdot
.49794 .31391 Mdot
.48433 .51232 Mdot
.64066 .4214 Mdot
.58002 .57997 Mdot
.38155 .36664 Mdot
.60765 .51482 Mdot
.4394 .69994 Mdot
.66723 .53364 Mdot
.5682 .75366 Mdot
.39487 .39558 Mdot
.50429 .36041 Mdot
.46339 .30829 Mdot
.59564 .52854 Mdot
.47232 .66309 Mdot
.47921 .40829 Mdot
.18363 .43034 Mdot
.47117 .71493 Mdot
.57929 .3337 Mdot
.34438 .54123 Mdot
.42224 .42218 Mdot
.35146 .52315 Mdot
.65 .61472 Mdot
.33868 .33647 Mdot
.32778 .28935 Mdot
.51289 .47014 Mdot
.64349 .59294 Mdot
.60554 .47868 Mdot
.57904 .33854 Mdot
.33377 .56159 Mdot
.62048 .38971 Mdot
.59676 .54658 Mdot
.46061 .69008 Mdot
.4393 .67545 Mdot
.40591 .45898 Mdot
.29126 .27403 Mdot
.53091 .29316 Mdot
.4046 .38761 Mdot
.37529 .55691 Mdot
.42645 .67043 Mdot
.52654 .22013 Mdot
.45445 .37834 Mdot
.39936 .41292 Mdot
.39157 .37733 Mdot
.64078 .50277 Mdot
.38406 .56329 Mdot
.64245 .41362 Mdot
.37773 .50589 Mdot
.63738 .52929 Mdot
.38655 .53449 Mdot
.3596 .5674 Mdot
.43376 .68416 Mdot
.3976 .36597 Mdot
.37577 .51107 Mdot
.67688 .56055 Mdot
.59752 .35235 Mdot
.51255 .41754 Mdot
.62324 .73324 Mdot
.5565 .21276 Mdot
.63092 .2972 Mdot
.59713 .33121 Mdot
.20545 .35061 Mdot
.38183 .3973 Mdot
.54577 .58331 Mdot
.24051 .5305 Mdot
.6653 .51165 Mdot
.65941 .80369 Mdot
.31643 .56004 Mdot
.35969 .57234 Mdot
.66564 .57017 Mdot
.29073 .51613 Mdot
.62564 .56189 Mdot
.38125 .51793 Mdot
.29616 .58807 Mdot
.5631 .57663 Mdot
.33412 .53537 Mdot
.5775 .57936 Mdot
.65018 .54049 Mdot
.56008 .33774 Mdot
.32478 .56854 Mdot
.68772 .55433 Mdot
.42729 .16679 Mdot
.43294 .37585 Mdot
.26929 .47417 Mdot
.65003 .68258 Mdot
.42225 .38699 Mdot
.58826 .36412 Mdot
.69572 .53668 Mdot
.43606 .66861 Mdot
.56088 .37391 Mdot
.63627 .74769 Mdot
.44946 .64744 Mdot
.6405 .8108 Mdot
.57145 .32853 Mdot
.35331 .5794 Mdot
.44094 .69535 Mdot
.57096 .53598 Mdot
.38262 .57214 Mdot
.44068 .43912 Mdot
.34074 .54882 Mdot
.63874 .58311 Mdot
.2932 .37599 Mdot
.40979 .36096 Mdot
.62931 .54036 Mdot
.35385 .5743 Mdot
.27215 .41856 Mdot
.6421 .50366 Mdot
.66116 .56001 Mdot
.29784 .72262 Mdot
.58366 .81592 Mdot
.44956 .66659 Mdot
.57835 .39942 Mdot
.67522 .56873 Mdot
.46658 .69339 Mdot
.34598 .67941 Mdot
.61695 .51105 Mdot
.60747 .36306 Mdot
.57157 .48156 Mdot
.32886 .56768 Mdot
.42787 .38371 Mdot
.51097 .46503 Mdot
.46875 .69205 Mdot
.86155 .42712 Mdot
.38977 .51918 Mdot
.68224 .53205 Mdot
.65146 .59466 Mdot
.24046 .60581 Mdot
.5592 .32434 Mdot
.77799 .58895 Mdot
.61231 .56365 Mdot
.5483 .57202 Mdot
.61995 .54605 Mdot
.30201 .54177 Mdot
.5731 .34116 Mdot
.63073 .57488 Mdot
.43152 .23901 Mdot
.61996 .49392 Mdot
.47349 .68208 Mdot
.65349 .24685 Mdot
.59644 .51681 Mdot
.43362 .87156 Mdot
.42017 .74881 Mdot
.33322 .53478 Mdot
.31877 .34331 Mdot
.58608 .13938 Mdot
.48132 .30825 Mdot
.53943 .36616 Mdot
.27318 .32535 Mdot
.35956 .52058 Mdot
.2891 .36182 Mdot
.2009 .35273 Mdot
.65317 .53964 Mdot
.60574 .51621 Mdot
.48247 .71556 Mdot
.337 .515 Mdot
.39885 .53197 Mdot
.61805 .60673 Mdot
.69955 .52261 Mdot
.35286 .51815 Mdot
.67927 .5655 Mdot
.63363 .61505 Mdot
.44564 .40785 Mdot
.59959 .33643 Mdot
.42588 .40651 Mdot
.38656 .3789 Mdot
.71786 .29655 Mdot
.36985 .74501 Mdot
.43431 .38098 Mdot
.38106 .37955 Mdot
.58358 .73843 Mdot
.4959 .75349 Mdot
.42433 .66395 Mdot
.33533 .22562 Mdot
.37018 .53695 Mdot
.64047 .57256 Mdot
.58909 .32606 Mdot
.80095 .52358 Mdot
.38385 .67323 Mdot
.74462 .68964 Mdot
.59471 .54843 Mdot
.37432 .53171 Mdot
.25604 .48424 Mdot
.71822 .57179 Mdot
.39772 .50243 Mdot
.60707 .52621 Mdot
.39727 .5323 Mdot
.73605 .38547 Mdot
.42971 .22726 Mdot
.40093 .54551 Mdot
.52763 .34845 Mdot
.61098 .53259 Mdot
.57766 .32987 Mdot
.41502 .4041 Mdot
.43207 .68962 Mdot
.45284 .66921 Mdot
.65362 .55948 Mdot
.56404 .51809 Mdot
.32381 .69544 Mdot
.64549 .53875 Mdot
.66248 .52578 Mdot
.25135 .48916 Mdot
.66375 .5312 Mdot
.63265 .59051 Mdot
.62006 .58539 Mdot
.66357 .50042 Mdot
.42009 .36125 Mdot
.40558 .2336 Mdot
.69136 .60202 Mdot
.69454 .6044 Mdot
.44293 .36511 Mdot
.21683 .39671 Mdot
.3843 .39051 Mdot
.17675 .40893 Mdot
.42985 .40825 Mdot
.45978 .67142 Mdot
.21113 .53754 Mdot
.58836 .49242 Mdot
.59539 .37562 Mdot
.45361 .40609 Mdot
.46424 .69014 Mdot
.41167 .39562 Mdot
.37952 .52023 Mdot
.21991 .64923 Mdot
.529 .38917 Mdot
.64934 .65795 Mdot
.42457 .43689 Mdot
.33951 .35789 Mdot
.37527 .50901 Mdot
.57041 .33553 Mdot
.77325 .4439 Mdot
.63289 .59267 Mdot
.46423 .69469 Mdot
.65078 .57115 Mdot
.4042 .35946 Mdot
.36949 .52748 Mdot
.65082 .23459 Mdot
.43541 .66719 Mdot
.3477 .77034 Mdot
.36454 .54692 Mdot
.61324 .5841 Mdot
.394 .3616 Mdot
.39807 .80345 Mdot
.42984 .40339 Mdot
.7598 .56654 Mdot
.57371 .31118 Mdot
.76519 .31241 Mdot
.56818 .37563 Mdot
.37513 .45711 Mdot
.25969 .73785 Mdot
.43144 .2046 Mdot
.59759 .36236 Mdot
.35774 .35714 Mdot
.63378 .51622 Mdot
.62776 .5129 Mdot
.54225 .22079 Mdot
.58049 .39871 Mdot
.66816 .58884 Mdot
.24192 .49961 Mdot
.40396 .2722 Mdot
.48792 .79954 Mdot
.33568 .55365 Mdot
.62146 .56256 Mdot
.42591 .34982 Mdot
.42711 .41486 Mdot
.38782 .51387 Mdot
.38791 .40504 Mdot
.63122 .53005 Mdot
.56493 .37355 Mdot
.36759 .48934 Mdot
.45699 .68185 Mdot
.50486 .17305 Mdot
.42752 .69668 Mdot
.34352 .54978 Mdot
.56805 .53191 Mdot
.35444 .52015 Mdot
.60778 .13057 Mdot
.62535 .52813 Mdot
.59036 .34393 Mdot
.67004 .55317 Mdot
.61372 .5348 Mdot
.60419 .51651 Mdot
.36954 .51719 Mdot
.74437 .62188 Mdot
.67808 .56291 Mdot
.41047 .374 Mdot
.64372 .43897 Mdot
.59312 .52338 Mdot
.29589 .54924 Mdot
.52459 .74846 Mdot
.35957 .42249 Mdot
.58399 .32027 Mdot
.33363 .54291 Mdot
.59377 .35966 Mdot
.62597 .38236 Mdot
.5882 .36382 Mdot
.6891 .45506 Mdot
.76572 .42939 Mdot
.74889 .62595 Mdot
.66051 .30147 Mdot
.52054 .54261 Mdot
.57913 .39916 Mdot
.45321 .73462 Mdot
.56506 .38959 Mdot
.57149 .3251 Mdot
.14717 .68177 Mdot
.58608 .38508 Mdot
.61129 .55653 Mdot
.58433 .54447 Mdot
.36362 .29842 Mdot
.57735 .70835 Mdot
.66399 .54565 Mdot
.67194 .56601 Mdot
.43174 .68509 Mdot
.56109 .59643 Mdot
.32801 .34259 Mdot
.57131 .82937 Mdot
.30375 .33439 Mdot
.65093 .56815 Mdot
.67513 .56514 Mdot
.71167 .5412 Mdot
.41798 .83663 Mdot
.76505 .33858 Mdot
.61473 .35987 Mdot
.67789 .49832 Mdot
.49904 .19017 Mdot
.60073 .5255 Mdot
.62753 .50262 Mdot
.63297 .51888 Mdot
.36046 .52076 Mdot
.60842 .34039 Mdot
.69734 .52919 Mdot
.40201 .75606 Mdot
.60696 .51965 Mdot
.273 .42542 Mdot
.7174 .24156 Mdot
.62105 .566 Mdot
.60585 .33283 Mdot
.64021 .51032 Mdot
.56036 .3275 Mdot
.5554 .35246 Mdot
.59592 .5015 Mdot
.67699 .46373 Mdot
.60225 .32181 Mdot
.63797 .52901 Mdot
.3759 .52425 Mdot
.31645 .23288 Mdot
.63671 .58305 Mdot
.42723 .6823 Mdot
.60837 .56061 Mdot
.47018 .65742 Mdot
.66044 .52793 Mdot
.39122 .52181 Mdot
.80341 .49077 Mdot
.35784 .52727 Mdot
.79236 .3476 Mdot
.39212 .5524 Mdot
.30686 .73179 Mdot
.60867 .36869 Mdot
.29182 .38357 Mdot
.79868 .61568 Mdot
.27031 .45619 Mdot
.44293 .56332 Mdot
.46601 .51414 Mdot
.39566 .40895 Mdot
.55697 .32234 Mdot
.54175 .60711 Mdot
.25517 .55196 Mdot
.24575 .56027 Mdot
.37076 .5668 Mdot
.83576 .56777 Mdot
.75116 .69811 Mdot
.67596 .54153 Mdot
.72911 .4509 Mdot
.67853 .3894 Mdot
.6083 .51177 Mdot
.69127 .52214 Mdot
.31137 .59065 Mdot
.67336 .58928 Mdot
.48245 .23882 Mdot
.34786 .5506 Mdot
.46357 .69171 Mdot
.58477 .33855 Mdot
.46875 .69538 Mdot
.2531 .55144 Mdot
.46335 .51671 Mdot
.38463 .52099 Mdot
.64969 .49393 Mdot
.66906 .55994 Mdot
.55821 .3338 Mdot
.60297 .40132 Mdot
.57749 .38691 Mdot
.4441 .65856 Mdot
.3525 .5476 Mdot
.80345 .42991 Mdot
.67063 .57501 Mdot
.56379 .36071 Mdot
.43738 .54931 Mdot
.67505 .5734 Mdot
.4202 .39713 Mdot
.62638 .51923 Mdot
.59951 .353 Mdot
.66365 .53134 Mdot
.56622 .37689 Mdot
.34492 .53861 Mdot
.58718 .55015 Mdot
.66295 .57338 Mdot
.3778 .79287 Mdot
.46431 .6756 Mdot
.6028 .38319 Mdot
.27518 .54747 Mdot
.64801 .59765 Mdot
.30565 .40803 Mdot
.60666 .53319 Mdot
.59964 .26853 Mdot
.67004 .51193 Mdot
.26227 .46225 Mdot
.69572 .58902 Mdot
.63566 .58191 Mdot
.41987 .48645 Mdot
.68062 .41267 Mdot
.58953 .40248 Mdot
.39182 .36107 Mdot
.59431 .38158 Mdot
.49659 .79451 Mdot
.39435 .57481 Mdot
.33152 .56244 Mdot
.55441 .65747 Mdot
.66732 .50137 Mdot
.6319 .56293 Mdot
.44126 .35853 Mdot
.46146 .6559 Mdot
.56528 .34948 Mdot
.45936 .6951 Mdot
.41658 .78276 Mdot
.44446 .65065 Mdot
.31032 .55613 Mdot
.3444 .7068 Mdot
.78624 .39409 Mdot
.43184 .68446 Mdot
.59784 .36493 Mdot
.39916 .69238 Mdot
.6427 .4973 Mdot
.43505 .74419 Mdot
.4569 .69137 Mdot
.8552 .52551 Mdot
.6337 .59021 Mdot
.44081 .57019 Mdot
.43262 .38679 Mdot
.43845 .69171 Mdot
.39381 .40267 Mdot
.66253 .55061 Mdot
.32407 .36655 Mdot
.54418 .37285 Mdot
.41802 .35586 Mdot
.5765 .56389 Mdot
.45402 .65753 Mdot
.38708 .55084 Mdot
.46247 .39638 Mdot
.39774 .35741 Mdot
.23217 .36264 Mdot
.67992 .24432 Mdot
.35449 .54621 Mdot
.62633 .77267 Mdot
.42601 .41165 Mdot
.60711 .50976 Mdot
.57645 .6178 Mdot
.61435 .52398 Mdot
.5093 .30924 Mdot
.33288 .5467 Mdot
.37399 .27843 Mdot
.67145 .55341 Mdot
.60004 .56624 Mdot
.59318 .39851 Mdot
.36056 .53308 Mdot
.57539 .36267 Mdot
.58753 .38793 Mdot
.34669 .53788 Mdot
.57579 .37526 Mdot
.448 .64588 Mdot
.41776 .27675 Mdot
.44588 .39196 Mdot
.40471 .37313 Mdot
.3736 .53818 Mdot
.33263 .5322 Mdot
.34541 .52395 Mdot
.62597 .51924 Mdot
.56903 .34421 Mdot
.65175 .52656 Mdot
.60844 .51532 Mdot
.69047 .47698 Mdot
.59489 .32608 Mdot
.64332 .5183 Mdot
.37102 .47152 Mdot
.44252 .63078 Mdot
.37857 .52606 Mdot
.43304 .38204 Mdot
.247 .41815 Mdot
.47079 .40165 Mdot
.61921 .55931 Mdot
.31319 .70694 Mdot
.58991 .3764 Mdot
.43821 .67137 Mdot
.41977 .66466 Mdot
.44539 .66837 Mdot
.36856 .3741 Mdot
.58601 .39567 Mdot
.57784 .82864 Mdot
.6253 .56393 Mdot
.47376 .5773 Mdot
.59911 .64563 Mdot
.31707 .69647 Mdot
.43238 .37872 Mdot
.67414 .56926 Mdot
.51935 .45437 Mdot
.78242 .44293 Mdot
.61532 .52696 Mdot
.6106 .50234 Mdot
.24025 .50961 Mdot
.57838 .47058 Mdot
.5758 .30885 Mdot
.42087 .79939 Mdot
.60612 .58779 Mdot
.57368 .42489 Mdot
.53736 .16403 Mdot
.61266 .54958 Mdot
.59824 .5579 Mdot
.65857 .58663 Mdot
.66791 .53104 Mdot
.59909 .32215 Mdot
.54414 .68389 Mdot
.38311 .40053 Mdot
.48278 .58927 Mdot
.44409 .37207 Mdot
.38973 .56551 Mdot
.40156 .24265 Mdot
.55754 .321 Mdot
.43466 .6744 Mdot
.40176 .21917 Mdot
.49035 .82622 Mdot
.33407 .52139 Mdot
.74397 .33262 Mdot
.46174 .68559 Mdot
.60649 .50869 Mdot
.45526 .64457 Mdot
.38262 .56446 Mdot
.41126 .3698 Mdot
.66697 .49926 Mdot
.56804 .38803 Mdot
.5924 .33461 Mdot
.67074 .58694 Mdot
.47717 .19171 Mdot
.42368 .39474 Mdot
.45121 .36793 Mdot
.62715 .5056 Mdot
.57158 .53831 Mdot
.57841 .36299 Mdot
.37306 .55223 Mdot
.57387 .77938 Mdot
.46437 .66316 Mdot
.67963 .5896 Mdot
.66523 .52519 Mdot
.39531 .76916 Mdot
.41982 .36916 Mdot
.31695 .53587 Mdot
.65283 .5069 Mdot
.40868 .31205 Mdot
.65348 .50749 Mdot
.69836 .51289 Mdot
.37676 .5268 Mdot
.68631 .60124 Mdot
.67949 .55182 Mdot
.68084 .62642 Mdot
.40728 .41141 Mdot
.58975 .34911 Mdot
.53307 .38571 Mdot
.50154 .59344 Mdot
.41832 .39796 Mdot
.64283 .5149 Mdot
.42464 .37594 Mdot
.61522 .51288 Mdot
.67367 .58576 Mdot
.43625 .38335 Mdot
.57526 .36354 Mdot
.27154 .33273 Mdot
.40162 .23685 Mdot
.66943 .53416 Mdot
.62868 .6014 Mdot
.55732 .69272 Mdot
.74065 .63921 Mdot
.5982 .54077 Mdot
.59815 .34512 Mdot
.66874 .57238 Mdot
.39618 .40233 Mdot
.43711 .64888 Mdot
.59812 .35317 Mdot
.3625 .5559 Mdot
.34657 .51288 Mdot
.46966 .30759 Mdot
.34758 .56434 Mdot
.64187 .49902 Mdot
.62348 .38896 Mdot
.54494 .39592 Mdot
.53 .17342 Mdot
.3507 .53651 Mdot
.43304 .647 Mdot
.65969 .55902 Mdot
.29469 .70269 Mdot
.43867 .35474 Mdot
.48001 .88781 Mdot
.62294 .81863 Mdot
.44515 .71282 Mdot
.7535 .667 Mdot
.39532 .55541 Mdot
.68251 .57071 Mdot
.43255 .69149 Mdot
.33722 .52038 Mdot
.6652 .51365 Mdot
.64936 .48743 Mdot
.77449 .59454 Mdot
.49776 .56078 Mdot
.42508 .37432 Mdot
.32406 .55093 Mdot
.41918 .69584 Mdot
.31111 .54308 Mdot
.58713 .32745 Mdot
.63563 .57927 Mdot
.57209 .51399 Mdot
.3681 .55553 Mdot
.32892 .5201 Mdot
.6376 .52318 Mdot
.55427 .32377 Mdot
.31683 .59228 Mdot
.64932 .56138 Mdot
.52649 .53558 Mdot
.54034 .32333 Mdot
.34863 .55455 Mdot
.61041 .57699 Mdot
.40293 .65976 Mdot
.36758 .54822 Mdot
.38005 .52754 Mdot
.67274 .58564 Mdot
.45095 .6464 Mdot
.62893 .59965 Mdot
.43815 .40326 Mdot
.83095 .47582 Mdot
.39264 .39699 Mdot
.39487 .64636 Mdot
.56561 .54156 Mdot
.40656 .32691 Mdot
.57475 .31918 Mdot
.49042 .70358 Mdot
.22861 .46621 Mdot
.61247 .60482 Mdot
.26404 .29593 Mdot
.50973 .4387 Mdot
.46219 .18212 Mdot
.18721 .52618 Mdot
.44819 .69023 Mdot
.41052 .39795 Mdot
.59795 .55672 Mdot
.43295 .42097 Mdot
.42932 .68878 Mdot
.78188 .33908 Mdot
.61728 .58237 Mdot
.57468 .34139 Mdot
.63291 .52417 Mdot
.57824 .33219 Mdot
.6752 .57899 Mdot
.71481 .58039 Mdot
.24335 .49206 Mdot
.63023 .74499 Mdot
.66163 .50718 Mdot
.24008 .68832 Mdot
.39562 .72641 Mdot
.46796 .68041 Mdot
.6501 .5322 Mdot
.41284 .52577 Mdot
.4199 .41835 Mdot
.53724 .2362 Mdot
.36114 .52004 Mdot
.38376 .3815 Mdot
.58175 .36742 Mdot
.33829 .54596 Mdot
.35374 .50899 Mdot
.68652 .59882 Mdot
.47491 .67916 Mdot
.39851 .36944 Mdot
.62856 .57575 Mdot
.62059 .58311 Mdot
.59165 .78809 Mdot
.37627 .65411 Mdot
.57623 .41244 Mdot
.48516 .84794 Mdot
.53303 .38052 Mdot
.46337 .66802 Mdot
.36807 .52003 Mdot
.60228 .53746 Mdot
.63184 .54118 Mdot
.2846 .3979 Mdot
.54854 .38151 Mdot
.50221 .5188 Mdot
.70202 .29808 Mdot
.31057 .58565 Mdot
.54933 .73652 Mdot
.58969 .33857 Mdot
.55237 .73599 Mdot
.41541 .67753 Mdot
.36472 .21917 Mdot
.60477 .74959 Mdot
.43129 .38422 Mdot
.54893 .73341 Mdot
.55844 .36073 Mdot
.67538 .54839 Mdot
.35032 .57931 Mdot
.35818 .56684 Mdot
.58406 .35375 Mdot
.35842 .49893 Mdot
.43467 .68345 Mdot
.60601 .5673 Mdot
.56836 .82508 Mdot
.48102 .28686 Mdot
.379 .55298 Mdot
.71513 .58472 Mdot
.39113 .37955 Mdot
.669 .58999 Mdot
.42806 .6756 Mdot
.41793 .38329 Mdot
.42791 .7553 Mdot
.39113 .27528 Mdot
.65668 .5559 Mdot
.32415 .73978 Mdot
.41703 .39359 Mdot
.72338 .6691 Mdot
.6458 .56806 Mdot
.42313 .41217 Mdot
.63524 .46938 Mdot
.34232 .45749 Mdot
.52093 .45917 Mdot
.20233 .35007 Mdot
.50497 .48937 Mdot
.36445 .57826 Mdot
.34198 .43427 Mdot
.28935 .48777 Mdot
.43002 .42081 Mdot
.32389 .52393 Mdot
.45032 .62082 Mdot
.39417 .40373 Mdot
.5945 .52304 Mdot
.60832 .53832 Mdot
.76649 .33637 Mdot
.49928 .44376 Mdot
.36453 .45266 Mdot
.52906 .27053 Mdot
.64258 .59701 Mdot
.59786 .58322 Mdot
.63373 .54713 Mdot
.60709 .32408 Mdot
.41951 .37265 Mdot
.29707 .74366 Mdot
.41975 .40023 Mdot
.64055 .79061 Mdot
.37044 .53503 Mdot
.32894 .54809 Mdot
.6191 .56257 Mdot
.43871 .59595 Mdot
.51009 .72018 Mdot
.63333 .53085 Mdot
.47887 .61748 Mdot
.64489 .245 Mdot
.57667 .55462 Mdot
.57565 .31371 Mdot
.65504 .62328 Mdot
.53383 .31691 Mdot
.44596 .3933 Mdot
.44756 .68341 Mdot
.49599 .69109 Mdot
.40963 .36801 Mdot
.63249 .56169 Mdot
.37799 .3253 Mdot
.61842 .5366 Mdot
.67085 .52861 Mdot
.6673 .77648 Mdot
.43005 .70047 Mdot
.34293 .53072 Mdot
.44552 .66571 Mdot
.56438 .32408 Mdot
.34117 .85538 Mdot
.46515 .65903 Mdot
.5068 .71707 Mdot
.80864 .37984 Mdot
.55192 .73126 Mdot
.58752 .32944 Mdot
.47593 .68941 Mdot
.42702 .38874 Mdot
.335 .20945 Mdot
.79209 .59345 Mdot
.47957 .37355 Mdot
.64572 .55821 Mdot
.54379 .33372 Mdot
.60267 .34878 Mdot
.42623 .3581 Mdot
.55653 .35319 Mdot
.6358 .47205 Mdot
.67253 .54013 Mdot
.42656 .42409 Mdot
.41678 .29899 Mdot
.39465 .3582 Mdot
.43463 .25777 Mdot
.64616 .53101 Mdot
.59303 .34312 Mdot
.61515 .6144 Mdot
.58198 .30156 Mdot
.31381 .54411 Mdot
.59196 .5193 Mdot
.4339 .68188 Mdot
.43935 .33372 Mdot
.35678 .5471 Mdot
.30341 .69295 Mdot
.56035 .33176 Mdot
.35471 .40065 Mdot
.55835 .34027 Mdot
.57176 .39908 Mdot
.38555 .38421 Mdot
.54526 .3672 Mdot
.60006 .56097 Mdot
.38008 .46599 Mdot
.5498 .33671 Mdot
.39725 .38751 Mdot
.45129 .68002 Mdot
.57404 .37242 Mdot
.29297 .51284 Mdot
.65943 .56629 Mdot
.36277 .51398 Mdot
.21941 .55546 Mdot
.53644 .37683 Mdot
.46149 .70572 Mdot
.33389 .56276 Mdot
.4594 .69954 Mdot
.60288 .20097 Mdot
.41517 .42745 Mdot
.72615 .70584 Mdot
.42349 .62917 Mdot
.58972 .38056 Mdot
.21284 .53612 Mdot
.60334 .54009 Mdot
.66031 .5636 Mdot
.46976 .65399 Mdot
.60267 .34938 Mdot
.40058 .20618 Mdot
.52572 .31369 Mdot
.40238 .28151 Mdot
.44051 .42312 Mdot
.28233 .71576 Mdot
.44404 .24615 Mdot
.66038 .20067 Mdot
.60866 .59706 Mdot
.39982 .54265 Mdot
.62365 .55553 Mdot
.2312 .4488 Mdot
.45218 .65827 Mdot
.32084 .50724 Mdot
.60097 .50091 Mdot
.34009 .53807 Mdot
.65489 .58209 Mdot
.42015 .46935 Mdot
.65155 .62027 Mdot
.42956 .65079 Mdot
.32173 .34531 Mdot
.59037 .38237 Mdot
.45831 .68362 Mdot
.39037 .52492 Mdot
.52107 .72651 Mdot
.6732 .52294 Mdot
.65729 .61384 Mdot
.31262 .58656 Mdot
.57164 .33761 Mdot
.33687 .57378 Mdot
.44365 .3989 Mdot
.43948 .67897 Mdot
.66611 .55289 Mdot
.66344 .5038 Mdot
.30454 .41182 Mdot
.39223 .37329 Mdot
.35824 .50248 Mdot
.42662 .40432 Mdot
.39676 .55581 Mdot
.65642 .60565 Mdot
.32886 .55014 Mdot
.68445 .55512 Mdot
.23929 .47349 Mdot
.66595 .77492 Mdot
.69534 .42714 Mdot
.33408 .54873 Mdot
.53902 .75644 Mdot
.39664 .39853 Mdot
.42521 .40873 Mdot
.80615 .405 Mdot
.76263 .57781 Mdot
.54879 .80889 Mdot
.19924 .40844 Mdot
.44528 .37533 Mdot
.39227 .38304 Mdot
.35784 .51377 Mdot
.54323 .36214 Mdot
.55152 .39407 Mdot
.39758 .5478 Mdot
.63094 .68672 Mdot
.56525 .34972 Mdot
.31021 .24968 Mdot
.50676 .80246 Mdot
.70106 .54198 Mdot
.42047 .55936 Mdot
.44325 .67579 Mdot
.61598 .69439 Mdot
.4176 .47011 Mdot
.59635 .56033 Mdot
.38355 .7586 Mdot
.37556 .54651 Mdot
.54627 .63924 Mdot
.17785 .40917 Mdot
.62326 .5865 Mdot
.6421 .57231 Mdot
.63133 .55476 Mdot
.45825 .71397 Mdot
.7754 .5667 Mdot
.61378 .57725 Mdot
.63649 .68541 Mdot
.65719 .59771 Mdot
.697 .49376 Mdot
.45072 .66765 Mdot
.65045 .46551 Mdot
.23145 .51079 Mdot
.43997 .7973 Mdot
.6082 .61771 Mdot
.44107 .40328 Mdot
.49457 .62903 Mdot
.41069 .41322 Mdot
.68846 .44864 Mdot
.60701 .74593 Mdot
.52837 .36007 Mdot
.59584 .55746 Mdot
.34382 .55036 Mdot
.60244 .34646 Mdot
.32721 .43489 Mdot
.2395 .78606 Mdot
.43737 .40855 Mdot
.68841 .19653 Mdot
.43123 .40569 Mdot
.36251 .50648 Mdot
.57976 .36242 Mdot
.76083 .42019 Mdot
.47651 .57201 Mdot
.57296 .37458 Mdot
.31621 .29835 Mdot
.61467 .36974 Mdot
.53606 .74624 Mdot
.53347 .35933 Mdot
.39655 .39196 Mdot
.36896 .37998 Mdot
.63569 .47939 Mdot
.60576 .55172 Mdot
.46333 .50767 Mdot
.50334 .74171 Mdot
.60314 .5453 Mdot
.3494 .54887 Mdot
.75357 .64816 Mdot
.51208 .65394 Mdot
.55071 .36875 Mdot
.38028 .39842 Mdot
.64414 .57557 Mdot
.65921 .5134 Mdot
.67407 .52748 Mdot
.51301 .861 Mdot
.37095 .21349 Mdot
.67782 .56339 Mdot
.64889 .5996 Mdot
.3392 .54303 Mdot
.41399 .65598 Mdot
.22414 .44646 Mdot
.73977 .54018 Mdot
.58969 .54731 Mdot
.45974 .67671 Mdot
.43145 .7036 Mdot
.66308 .51106 Mdot
.39875 .75003 Mdot
.37198 .33406 Mdot
.62909 .57649 Mdot
.75498 .58364 Mdot
.2703 .51654 Mdot
.33644 .51556 Mdot
.36599 .55417 Mdot
.60672 .34474 Mdot
.34591 .56109 Mdot
.39559 .54437 Mdot
.76558 .40407 Mdot
.49702 .50522 Mdot
.37861 .35829 Mdot
.44306 .65864 Mdot
.62839 .53929 Mdot
.56746 .40938 Mdot
.39695 .31482 Mdot
.38948 .40018 Mdot
.58442 .37877 Mdot
.41915 .41654 Mdot
.47813 .70202 Mdot
.62966 .65711 Mdot
.37507 .56664 Mdot
.43872 .36917 Mdot
.39293 .27491 Mdot
.45821 .67451 Mdot
.39204 .36884 Mdot
.35386 .33524 Mdot
.58614 .53116 Mdot
.74795 .47476 Mdot
.63747 .53227 Mdot
.43134 .1892 Mdot
.40135 .36402 Mdot
.26051 .45355 Mdot
.63309 .56885 Mdot
.36635 .54606 Mdot
.67616 .48854 Mdot
.60468 .52674 Mdot
.3623 .55969 Mdot
.67611 .54327 Mdot
.43843 .70296 Mdot
.5336 .32976 Mdot
.48803 .59043 Mdot
.81415 .66091 Mdot
.47508 .6803 Mdot
.32348 .42657 Mdot
.59648 .54331 Mdot
.65281 .22909 Mdot
.57223 .37203 Mdot
.68357 .54008 Mdot
.52131 .65883 Mdot
.54238 .34871 Mdot
.59056 .36849 Mdot
.65006 .51273 Mdot
.43161 .39031 Mdot
.35549 .55001 Mdot
.45412 .67131 Mdot
.59894 .1902 Mdot
.64787 .55028 Mdot
.66556 .57312 Mdot
.46027 .6854 Mdot
.39136 .38985 Mdot
.64681 .5059 Mdot
.22001 .58228 Mdot
.43845 .17022 Mdot
.39593 .41158 Mdot
.59274 .52877 Mdot
.74543 .49826 Mdot
.51897 .3381 Mdot
.82709 .37233 Mdot
.42993 .74627 Mdot
.33684 .53574 Mdot
.58847 .4681 Mdot
.37584 .85772 Mdot
.44808 .68166 Mdot
.50535 .82139 Mdot
.66559 .51822 Mdot
.6695 .58092 Mdot
.57957 .3854 Mdot
.6481 .52281 Mdot
.53731 .3661 Mdot
.81309 .64802 Mdot
.38947 .77014 Mdot
.57242 .33234 Mdot
.5749 .38985 Mdot
.5152 .68844 Mdot
.22605 .44607 Mdot
.58529 .3554 Mdot
.66135 .60137 Mdot
.63739 .34473 Mdot
.72708 .59779 Mdot
.46323 .64678 Mdot
.24146 .54424 Mdot
.50915 .34648 Mdot
.44028 .72652 Mdot
.24363 .35381 Mdot
.50702 .35742 Mdot
.37978 .33692 Mdot
.44279 .39445 Mdot
.6175 .58502 Mdot
.35403 .56625 Mdot
.33047 .55939 Mdot
.61791 .61329 Mdot
.62336 .53427 Mdot
.56317 .32643 Mdot
.43877 .65747 Mdot
.42921 .41866 Mdot
.67141 .56614 Mdot
.51067 .67413 Mdot
.46662 .66253 Mdot
.54894 .35498 Mdot
.75425 .60518 Mdot
.42756 .65153 Mdot
.70276 .60265 Mdot
.61787 .57027 Mdot
.6336 .52012 Mdot
.7188 .60796 Mdot
.43181 .37201 Mdot
.21633 .51955 Mdot
.59062 .56927 Mdot
.41702 .78395 Mdot
.51494 .41124 Mdot
.71249 .56851 Mdot
.5622 .34472 Mdot
.43485 .35199 Mdot
.32569 .57515 Mdot
.53096 .61696 Mdot
.65448 .55267 Mdot
.41704 .21496 Mdot
.73741 .30841 Mdot
.31465 .55227 Mdot
.57517 .39848 Mdot
.44075 .67016 Mdot
.63191 .53154 Mdot
.6575 .44924 Mdot
.60918 .54496 Mdot
.47661 .65532 Mdot
.38123 .53568 Mdot
.44196 .3947 Mdot
.45721 .17951 Mdot
.33011 .55841 Mdot
.59331 .36169 Mdot
.1314 .43339 Mdot
.53675 .34849 Mdot
.57397 .39371 Mdot
.65164 .45194 Mdot
.43713 .37678 Mdot
.40909 .87654 Mdot
.82996 .52424 Mdot
.57823 .5258 Mdot
.40095 .40294 Mdot
.58146 .34894 Mdot
.66252 .59212 Mdot
.55646 .31816 Mdot
.59054 .39398 Mdot
.64889 .60721 Mdot
.65085 .59037 Mdot
.41002 .24261 Mdot
.19492 .36714 Mdot
.44006 .66823 Mdot
.57276 .32322 Mdot
.52679 .55829 Mdot
.65623 .59385 Mdot
.62573 .56474 Mdot
.29983 .48483 Mdot
.44627 .64509 Mdot
.50972 .2408 Mdot
.66289 .51562 Mdot
.36663 .76154 Mdot
.65007 .62326 Mdot
.59461 .31801 Mdot
.39189 .40761 Mdot
.44129 .79366 Mdot
.40844 .438 Mdot
.5436 .37549 Mdot
.43341 .66443 Mdot
.53594 .39194 Mdot
.50392 .72048 Mdot
.41973 .35942 Mdot
.59953 .353 Mdot
.51237 .46312 Mdot
.4107 .38204 Mdot
.41286 .36356 Mdot
.64113 .43866 Mdot
.37436 .497 Mdot
.45219 .71252 Mdot
.39558 .37226 Mdot
.54262 .56817 Mdot
.40216 .39334 Mdot
.81548 .45642 Mdot
.5869 .54889 Mdot
.58452 .66361 Mdot
.42205 .58313 Mdot
.59771 .48472 Mdot
.41149 .3606 Mdot
.42873 .6805 Mdot
.64789 .5088 Mdot
.55642 .35955 Mdot
.46926 .68506 Mdot
.46817 .38678 Mdot
.3561 .51796 Mdot
.55591 .3413 Mdot
.44285 .42413 Mdot
.58552 .33232 Mdot
.54017 .60786 Mdot
.82898 .42286 Mdot
.23272 .63209 Mdot
.48063 .56513 Mdot
.67302 .52654 Mdot
.20632 .42365 Mdot
.70552 .5627 Mdot
.62025 .53036 Mdot
.34916 .55316 Mdot
.55503 .65354 Mdot
.57584 .36276 Mdot
.43873 .17718 Mdot
.44362 .37851 Mdot
.41837 .79828 Mdot
.63013 .33366 Mdot
.68035 .53074 Mdot
.54927 .33621 Mdot
.53574 .35014 Mdot
.67308 .40741 Mdot
.31668 .57071 Mdot
.68789 .5192 Mdot
.68502 .51189 Mdot
.65175 .61206 Mdot
.41984 .36693 Mdot
.31228 .70291 Mdot
.37021 .57579 Mdot
.82138 .38211 Mdot
.38164 .54344 Mdot
.48052 .61581 Mdot
.54634 .36557 Mdot
.46269 .65541 Mdot
.62584 .56659 Mdot
.60939 .39116 Mdot
.5451 .37906 Mdot
.46691 .64306 Mdot
.43944 .69361 Mdot
.32137 .47151 Mdot
.43586 .38204 Mdot
.65803 .50327 Mdot
.60984 .57606 Mdot
.65422 .5276 Mdot
.62442 .52193 Mdot
.44152 .40557 Mdot
.6286 .50988 Mdot
.41794 .34963 Mdot
.59095 .6362 Mdot
.37205 .75225 Mdot
.49894 .49226 Mdot
.58963 .26515 Mdot
.55359 .36564 Mdot
.53625 .53722 Mdot
.71892 .58619 Mdot
.68966 .75895 Mdot
.61113 .24338 Mdot
.57642 .54506 Mdot
.33274 .5241 Mdot
.74217 .60066 Mdot
.36875 .56941 Mdot
.7533 .24675 Mdot
.29795 .41983 Mdot
.22171 .33313 Mdot
.62443 .58375 Mdot
.28839 .4983 Mdot
.54827 .54334 Mdot
.70029 .55494 Mdot
.31043 .44587 Mdot
.51426 .30437 Mdot
.34193 .29766 Mdot
.42771 .66289 Mdot
.65483 .56684 Mdot
.57301 .40796 Mdot
.60305 .56512 Mdot
.62332 .55951 Mdot
.65985 .5108 Mdot
.38361 .37378 Mdot
.68808 .52239 Mdot
.61746 .51777 Mdot
.32183 .68955 Mdot
.5742 .74328 Mdot
.32435 .55548 Mdot
.79813 .38167 Mdot
.46933 .66562 Mdot
.55706 .33016 Mdot
.32474 .26825 Mdot
.4313 .38326 Mdot
.67392 .39788 Mdot
.6284 .52089 Mdot
.39457 .25573 Mdot
.45944 .41118 Mdot
.43705 .67995 Mdot
.36764 .57973 Mdot
.26234 .2859 Mdot
.34684 .54542 Mdot
.51674 .45475 Mdot
.36346 .54363 Mdot
.70283 .6098 Mdot
.56441 .32611 Mdot
.65173 .50403 Mdot
.39953 .37075 Mdot
.35305 .55915 Mdot
.5685 .69857 Mdot
.63247 .54813 Mdot
.34674 .53702 Mdot
.65089 .50384 Mdot
.63031 .65923 Mdot
.64957 .75651 Mdot
.39408 .53221 Mdot
.40092 .34919 Mdot
.40522 .37932 Mdot
.45022 .64673 Mdot
.55265 .33889 Mdot
.57086 .38575 Mdot
.41637 .38465 Mdot
.77845 .6143 Mdot
.59235 .54071 Mdot
.65202 .59335 Mdot
.42352 .79219 Mdot
.59879 .55006 Mdot
.52362 .7395 Mdot
.51904 .45683 Mdot
.55074 .36009 Mdot
.68076 .57304 Mdot
.66232 .51795 Mdot
.65792 .55789 Mdot
.56272 .63026 Mdot
.37385 .55423 Mdot
.60131 .5751 Mdot
.4424 .69703 Mdot
.391 .47653 Mdot
.6686 .5907 Mdot
.66446 .61133 Mdot
.573 .38551 Mdot
.50605 .84346 Mdot
.43519 .40149 Mdot
.38391 .51458 Mdot
.3311 .54638 Mdot
.24415 .5427 Mdot
.51876 .40361 Mdot
.51534 .46304 Mdot
.80179 .34819 Mdot
.24484 .49493 Mdot
.46615 .68004 Mdot
.41763 .52314 Mdot
.53605 .4261 Mdot
.35804 .51115 Mdot
.43607 .41083 Mdot
.58603 .55278 Mdot
.58907 .54753 Mdot
.65399 .80267 Mdot
.67316 .51766 Mdot
.44416 .67231 Mdot
.42745 .35363 Mdot
.55909 .36104 Mdot
.4366 .67842 Mdot
.42281 .40801 Mdot
.56974 .33721 Mdot
.58007 .55118 Mdot
.58262 .5559 Mdot
.58254 .37926 Mdot
.601 .35748 Mdot
.62291 .57157 Mdot
.35544 .61231 Mdot
.59741 .37406 Mdot
.59437 .34128 Mdot
.37658 .56632 Mdot
.35797 .56584 Mdot
.69546 .59317 Mdot
.40528 .40331 Mdot
.61958 .51536 Mdot
.34039 .54734 Mdot
.44262 .65147 Mdot
.57149 .36511 Mdot
.66891 .53125 Mdot
.67222 .56005 Mdot
.45738 .67529 Mdot
.43147 .66061 Mdot
.43642 .68807 Mdot
.40004 .35431 Mdot
.65424 .5362 Mdot
.58479 .36196 Mdot
.43853 .3853 Mdot
.43345 .7059 Mdot
.44706 .64216 Mdot
.31353 .53072 Mdot
.60131 .53634 Mdot
.40065 .48974 Mdot
.31625 .82914 Mdot
.46014 .76686 Mdot
.31563 .56302 Mdot
.30429 .55311 Mdot
.56815 .72479 Mdot
.45709 .596 Mdot
.42145 .3916 Mdot
.46613 .63387 Mdot
.49354 .69878 Mdot
.5968 .51606 Mdot
.60907 .58932 Mdot
.67531 .49786 Mdot
.44396 .69254 Mdot
.53395 .64495 Mdot
.56079 .31814 Mdot
.67732 .29408 Mdot
.47103 .67319 Mdot
.32985 .51925 Mdot
.36884 .49584 Mdot
.382 .54178 Mdot
.58496 .55539 Mdot
.69631 .42155 Mdot
.54876 .47819 Mdot
.19438 .43654 Mdot
.40153 .36229 Mdot
.54429 .40265 Mdot
.63549 .2288 Mdot
.58587 .37501 Mdot
.38776 .56483 Mdot
.4619 .69251 Mdot
.60035 .34677 Mdot
.4105 .41762 Mdot
.39322 .37895 Mdot
.37914 .55079 Mdot
.37333 .53525 Mdot
.37895 .51826 Mdot
.57954 .39616 Mdot
.54525 .3657 Mdot
.65302 .54855 Mdot
.56503 .36782 Mdot
.60532 .83247 Mdot
.47164 .70876 Mdot
.30313 .56549 Mdot
.41189 .39977 Mdot
.57603 .33092 Mdot
.63369 .54517 Mdot
.50182 .61161 Mdot
.50771 .29462 Mdot
.45272 .70186 Mdot
.61156 .77764 Mdot
.75268 .24898 Mdot
.65939 .50305 Mdot
.42183 .37002 Mdot
.56642 .82348 Mdot
.63371 .55415 Mdot
.37143 .52312 Mdot
.22893 .48495 Mdot
.39817 .57271 Mdot
.60954 .51526 Mdot
.62699 .49532 Mdot
.38926 .40731 Mdot
.78606 .33766 Mdot
.64919 .54598 Mdot
.5037 .25044 Mdot
.38945 .41598 Mdot
.37338 .57434 Mdot
.41133 .16962 Mdot
.24111 .59758 Mdot
.61905 .69037 Mdot
.37885 .5648 Mdot
.6127 .53448 Mdot
.3723 .56553 Mdot
.44369 .70141 Mdot
.39118 .54115 Mdot
.56994 .31183 Mdot
.32726 .56542 Mdot
.66532 .57453 Mdot
.58627 .35275 Mdot
.41765 .39439 Mdot
.44532 .81628 Mdot
.37315 .69873 Mdot
.36752 .54549 Mdot
.38816 .5155 Mdot
.67982 .55802 Mdot
.48091 .23474 Mdot
.58439 .58896 Mdot
.63393 .58948 Mdot
.44069 .36886 Mdot
.54696 .342 Mdot
.38153 .39179 Mdot
.68948 .55655 Mdot
.21386 .57847 Mdot
.42954 .40136 Mdot
.38899 .25125 Mdot
.46275 .68483 Mdot
.43949 .46319 Mdot
.63108 .53882 Mdot
.38854 .38843 Mdot
.65314 .53594 Mdot
.56488 .31662 Mdot
.47955 .45446 Mdot
.32781 .33753 Mdot
.40551 .36986 Mdot
.43105 .19987 Mdot
.44248 .61344 Mdot
.56104 .55426 Mdot
.41769 .41275 Mdot
.52073 .65273 Mdot
.35512 .50841 Mdot
.46599 .66618 Mdot
.42407 .6866 Mdot
.46865 .69396 Mdot
.59015 .5897 Mdot
.58463 .60331 Mdot
.43619 .70441 Mdot
.41141 .42056 Mdot
.42729 .65495 Mdot
.55594 .41861 Mdot
.40581 .20564 Mdot
.45303 .66011 Mdot
.64667 .56465 Mdot
.61281 .62445 Mdot
.57964 .73719 Mdot
.35276 .46151 Mdot
.23832 .31889 Mdot
.56011 .24424 Mdot
.60673 .55078 Mdot
.52365 .35368 Mdot
.58619 .32489 Mdot
.54189 .82258 Mdot
.50365 .75271 Mdot
.42018 .77216 Mdot
.57551 .39107 Mdot
.29299 .37961 Mdot
.55024 .3505 Mdot
.67542 .52358 Mdot
.65847 .59215 Mdot
.55358 .39291 Mdot
.33509 .73069 Mdot
.31687 .3921 Mdot
.51163 .17693 Mdot
.59129 .33567 Mdot
.40645 .41172 Mdot
.4396 .36195 Mdot
.41474 .36277 Mdot
.51785 .80429 Mdot
.53759 .35634 Mdot
.65986 .53725 Mdot
.33545 .54991 Mdot
.59436 .56622 Mdot
.4156 .37745 Mdot
.43614 .17781 Mdot
.56112 .37852 Mdot
.63397 .58062 Mdot
.7279 .64537 Mdot
.36461 .52411 Mdot
.46154 .67509 Mdot
.69259 .64711 Mdot
.43464 .76531 Mdot
.42933 .36617 Mdot
.53563 .37787 Mdot
.2676 .43748 Mdot
.38185 .2449 Mdot
.59896 .58733 Mdot
.70802 .55062 Mdot
.63177 .19241 Mdot
.4293 .75582 Mdot
.62707 .50065 Mdot
.37076 .50765 Mdot
.28124 .4035 Mdot
.67025 .55146 Mdot
.58049 .32341 Mdot
.422 .67054 Mdot
.46265 .69636 Mdot
.69294 .58637 Mdot
.47273 .57974 Mdot
.45794 .43903 Mdot
.64136 .51448 Mdot
.7054 .60067 Mdot
.37669 .57065 Mdot
.24349 .49757 Mdot
.41278 .78382 Mdot
.4324 .66445 Mdot
.64855 .5042 Mdot
.2789 .33661 Mdot
.55961 .39128 Mdot
.3207 .56152 Mdot
.40987 .35731 Mdot
.61276 .64894 Mdot
.37631 .57426 Mdot
.67128 .54917 Mdot
.65037 .5073 Mdot
.38776 .37349 Mdot
.59392 .31746 Mdot
.44763 .69396 Mdot
.33299 .55108 Mdot
.42907 .66933 Mdot
.54068 .35099 Mdot
.55948 .37194 Mdot
.73933 .58099 Mdot
.59157 .49969 Mdot
.36366 .55453 Mdot
.68313 .58092 Mdot
.27699 .54388 Mdot
.78058 .31575 Mdot
.45392 .40514 Mdot
.6563 .50066 Mdot
.60201 .31746 Mdot
.41021 .36908 Mdot
.66272 .58752 Mdot
.60483 .18605 Mdot
.65643 .59494 Mdot
.48639 .37598 Mdot
.22788 .63337 Mdot
.43062 .67984 Mdot
.66591 .28876 Mdot
.51478 .21363 Mdot
.60066 .55559 Mdot
.33246 .53045 Mdot
.71663 .55714 Mdot
.42917 .39163 Mdot
.54935 .36807 Mdot
.82764 .36758 Mdot
.4003 .38939 Mdot
.61342 .57421 Mdot
.43855 .679 Mdot
.53446 .36156 Mdot
.48125 .63279 Mdot
.39468 .74983 Mdot
.57538 .58658 Mdot
.67553 .59684 Mdot
.62817 .51555 Mdot
.19765 .52616 Mdot
.38447 .51577 Mdot
.58164 .34049 Mdot
.42248 .36922 Mdot
.41881 .3851 Mdot
.37745 .54979 Mdot
.37695 .29167 Mdot
.44195 .46169 Mdot
.31372 .8138 Mdot
.36345 .56152 Mdot
.46975 .69888 Mdot
.49646 .24132 Mdot
.3288 .53363 Mdot
.35087 .53435 Mdot
.37317 .57127 Mdot
.37909 .42472 Mdot
.56923 .34059 Mdot
.67376 .55699 Mdot
.58336 .31988 Mdot
.61217 .5313 Mdot
.50913 .40319 Mdot
.40382 .36825 Mdot
.55121 .37515 Mdot
.61606 .19481 Mdot
.77942 .51627 Mdot
.63868 .56015 Mdot
.64466 .22872 Mdot
.58772 .51138 Mdot
.54202 .71853 Mdot
.61969 .48974 Mdot
.36971 .53996 Mdot
.56185 .49787 Mdot
.64011 .61496 Mdot
.49721 .83143 Mdot
.41255 .40126 Mdot
.33567 .51717 Mdot
.59219 .51525 Mdot
.6831 .61789 Mdot
.56323 .39807 Mdot
.59861 .3442 Mdot
.42939 .69683 Mdot
.63881 .74358 Mdot
.41913 .39633 Mdot
.82107 .50695 Mdot
.60765 .55639 Mdot
.2764 .67837 Mdot
.66362 .30714 Mdot
.66012 .58795 Mdot
.53313 .213 Mdot
.68803 .41256 Mdot
.63154 .53366 Mdot
.51281 .54581 Mdot
.39227 .3908 Mdot
.21631 .59084 Mdot
.65808 .59974 Mdot
.3642 .52075 Mdot
.54493 .35762 Mdot
.557 .32018 Mdot
.43577 .70271 Mdot
.73607 .71855 Mdot
.38171 .38616 Mdot
.54946 .37197 Mdot
.62785 .54816 Mdot
.43408 .37177 Mdot
.34194 .56125 Mdot
.68342 .52962 Mdot
.5098 .75721 Mdot
.56345 .36431 Mdot
.67035 .59623 Mdot
.48183 .26774 Mdot
.61583 .71496 Mdot
.15973 .50993 Mdot
.42456 .36854 Mdot
.44133 .6476 Mdot
.71498 .55215 Mdot
.77177 .60077 Mdot
.57557 .55645 Mdot
.57834 .65897 Mdot
.52718 .40467 Mdot
.43941 .64743 Mdot
.63746 .56886 Mdot
.66476 .54912 Mdot
.43098 .58129 Mdot
.43582 .65819 Mdot
.61313 .57986 Mdot
.6183 .63491 Mdot
.57267 .33905 Mdot
.38842 .57347 Mdot
.56317 .35638 Mdot
.64539 .5589 Mdot
.61096 .48861 Mdot
.58926 .37834 Mdot
.73333 .25805 Mdot
.43885 .71335 Mdot
.43557 .39876 Mdot
.56852 .52909 Mdot
.5994 .57879 Mdot
.24603 .7073 Mdot
.31539 .5398 Mdot
.23993 .40967 Mdot
.29443 .64465 Mdot
.25344 .3539 Mdot
.24194 .59923 Mdot
.16586 .39157 Mdot
.39061 .76514 Mdot
.69331 .53247 Mdot
.57931 .28637 Mdot
.53951 .48385 Mdot
.40703 .35961 Mdot
.78951 .40902 Mdot
.60549 .55092 Mdot
.62274 .55726 Mdot
.31964 .56213 Mdot
.37245 .27613 Mdot
.41649 .7743 Mdot
.48184 .60151 Mdot
.4495 .69334 Mdot
.57185 .32433 Mdot
.67618 .57491 Mdot
.50854 .51981 Mdot
.32312 .55463 Mdot
.28368 .68701 Mdot
.63657 .57905 Mdot
.68368 .75985 Mdot
.48657 .31515 Mdot
.43368 .3753 Mdot
.32928 .54261 Mdot
.42766 .76334 Mdot
.60238 .53259 Mdot
.41256 .35628 Mdot
.64375 .54503 Mdot
.38045 .60574 Mdot
.68711 .56385 Mdot
.45628 .65838 Mdot
.66765 .51921 Mdot
.48834 .61782 Mdot
.13136 .4786 Mdot
.48229 .65599 Mdot
.54702 .32867 Mdot
.31077 .5757 Mdot
.37153 .5545 Mdot
.60059 .3532 Mdot
.3691 .55312 Mdot
.67156 .36423 Mdot
.74626 .39431 Mdot
.45789 .69222 Mdot
.68381 .61442 Mdot
.44961 .66166 Mdot
.31287 .54785 Mdot
.60502 .54088 Mdot
.77243 .28935 Mdot
.35594 .55602 Mdot
.2467 .68034 Mdot
.40551 .39384 Mdot
.32206 .52815 Mdot
.65807 .59796 Mdot
.27161 .44119 Mdot
.32783 .55678 Mdot
.33134 .33661 Mdot
.6574 .55664 Mdot
.55739 .3674 Mdot
.66762 .54676 Mdot
.57458 .52299 Mdot
.39424 .51373 Mdot
.61209 .51899 Mdot
.42246 .40805 Mdot
.594 .38209 Mdot
.32141 .22993 Mdot
.51004 .31402 Mdot
.59961 .56542 Mdot
.6294 .55018 Mdot
.55134 .40043 Mdot
.60493 .57975 Mdot
.4416 .40529 Mdot
.62188 .87248 Mdot
.46302 .68405 Mdot
.38284 .50779 Mdot
.2391 .59708 Mdot
.57747 .54437 Mdot
.63731 .50872 Mdot
.58321 .1787 Mdot
.23424 .6068 Mdot
.41977 .41143 Mdot
.62671 .61305 Mdot
.33457 .55962 Mdot
.44014 .67752 Mdot
.41354 .42238 Mdot
.63486 .52051 Mdot
.62951 .56771 Mdot
.44446 .64793 Mdot
.62452 .42574 Mdot
.48876 .80096 Mdot
.39025 .36898 Mdot
.56529 .50021 Mdot
.28783 .53411 Mdot
.59692 .5335 Mdot
.53853 .807 Mdot
.59835 .3498 Mdot
.43441 .36732 Mdot
.21109 .43775 Mdot
.62021 .50424 Mdot
.39186 .40622 Mdot
.41838 .39782 Mdot
.62477 .61123 Mdot
.60954 .32285 Mdot
.59668 .38589 Mdot
.58418 .33113 Mdot
.63442 .82771 Mdot
.6009 .70062 Mdot
.37885 .51827 Mdot
.39178 .38978 Mdot
.39628 .54203 Mdot
.47829 .68609 Mdot
.53198 .44692 Mdot
.39204 .52402 Mdot
.6009 .33782 Mdot
.31778 .57851 Mdot
.66325 .55343 Mdot
.41884 .39317 Mdot
.36341 .51095 Mdot
.57927 .52817 Mdot
.45843 .23167 Mdot
.35573 .43958 Mdot
.43946 .64334 Mdot
.42172 .67612 Mdot
.66719 .58951 Mdot
.33286 .57806 Mdot
.62249 .5698 Mdot
.45195 .39109 Mdot
.47821 .23885 Mdot
.57362 .55086 Mdot
.36948 .54632 Mdot
.52292 .37213 Mdot
.43322 .76364 Mdot
.56673 .56034 Mdot
.64565 .56508 Mdot
.60995 .52717 Mdot
.64379 .54438 Mdot
.34164 .28751 Mdot
.44121 .42125 Mdot
.57446 .26925 Mdot
.21478 .52876 Mdot
.56943 .37814 Mdot
.61229 .35619 Mdot
.4566 .77231 Mdot
.367 .34145 Mdot
.40245 .40247 Mdot
.62125 .52748 Mdot
.42113 .3145 Mdot
.42695 .17912 Mdot
.6908 .21365 Mdot
.40392 .68749 Mdot
.31715 .54287 Mdot
.53854 .38307 Mdot
.32473 .54596 Mdot
.61066 .53728 Mdot
.71029 .53854 Mdot
.15975 .39607 Mdot
.37637 .39689 Mdot
.45764 .69452 Mdot
.61259 .52814 Mdot
.60899 .69964 Mdot
.33824 .54438 Mdot
.38297 .50101 Mdot
.62264 .58716 Mdot
.60539 .32675 Mdot
.18304 .60744 Mdot
.42998 .37118 Mdot
.55326 .24246 Mdot
.54715 .52471 Mdot
.54205 .26483 Mdot
.41876 .37447 Mdot
.39521 .73797 Mdot
.31871 .56532 Mdot
.65061 .36323 Mdot
.56879 .38008 Mdot
.46893 .68396 Mdot
.71167 .55961 Mdot
.57096 .38805 Mdot
.37144 .57651 Mdot
.55295 .36865 Mdot
.66394 .51278 Mdot
.40979 .42665 Mdot
.33587 .53487 Mdot
.37668 .36226 Mdot
.61178 .32896 Mdot
.43263 .66785 Mdot
.45122 .54165 Mdot
.78955 .45662 Mdot
.68494 .40856 Mdot
.59465 .56879 Mdot
.51311 .50945 Mdot
.65798 .5335 Mdot
.60463 .3847 Mdot
.63666 .54547 Mdot
.55822 .41619 Mdot
.33137 .53356 Mdot
.65048 .59977 Mdot
.63596 .51499 Mdot
.77739 .37439 Mdot
.6448 .58015 Mdot
.69185 .54302 Mdot
.62935 .5305 Mdot
.61502 .39584 Mdot
.6769 .6153 Mdot
.56349 .34165 Mdot
.36472 .72151 Mdot
.35387 .53296 Mdot
.42298 .67274 Mdot
.4728 .66962 Mdot
.58757 .66772 Mdot
.3234 .6114 Mdot
.36842 .28669 Mdot
.56836 .35362 Mdot
.42206 .40411 Mdot
.63904 .54308 Mdot
.18285 .42626 Mdot
.27116 .51036 Mdot
.3414 .56611 Mdot
.51008 .31351 Mdot
.58354 .47609 Mdot
.19205 .54333 Mdot
.67567 .59189 Mdot
.67284 .79027 Mdot
.589 .49825 Mdot
.68718 .55801 Mdot
.39592 .5281 Mdot
.46959 .71482 Mdot
.62155 .58961 Mdot
.56158 .3978 Mdot
.45924 .65688 Mdot
.59003 .29105 Mdot
.37834 .4816 Mdot
.37184 .71686 Mdot
.75989 .37192 Mdot
.65089 .53882 Mdot
.33717 .53304 Mdot
.55671 .33945 Mdot
.41009 .78272 Mdot
.43916 .38729 Mdot
.40475 .33747 Mdot
.529 .54843 Mdot
.67433 .22803 Mdot
.46785 .66431 Mdot
.63334 .43511 Mdot
.66664 .57317 Mdot
.3945 .66122 Mdot
.5978 .58228 Mdot
.43126 .18046 Mdot
.47359 .69407 Mdot
.60785 .36025 Mdot
.40715 .41087 Mdot
.58555 .3226 Mdot
.68799 .42347 Mdot
.41782 .57006 Mdot
.47847 .4961 Mdot
.34688 .54288 Mdot
.41403 .4715 Mdot
.58516 .3468 Mdot
.64145 .50375 Mdot
.30844 .81193 Mdot
.59621 .34394 Mdot
.53934 .37571 Mdot
.80981 .37706 Mdot
.77868 .30774 Mdot
.57174 .48256 Mdot
.5856 .38457 Mdot
.35139 .54013 Mdot
.43828 .66632 Mdot
.66574 .53376 Mdot
.65677 .54741 Mdot
.57487 .38628 Mdot
.38972 .50926 Mdot
.75002 .51539 Mdot
.37206 .53559 Mdot
.57198 .33608 Mdot
.3573 .52699 Mdot
.2565 .45513 Mdot
.34733 .51362 Mdot
.60037 .57925 Mdot
.63726 .54472 Mdot
.27553 .59535 Mdot
.55943 .37141 Mdot
.6444 .51449 Mdot
.67726 .54536 Mdot
.58417 .3598 Mdot
.47079 .72524 Mdot
.73496 .49617 Mdot
.59454 .54942 Mdot
.65705 .5694 Mdot
.43831 .64864 Mdot
.53751 .45531 Mdot
.72026 .69725 Mdot
.64803 .50897 Mdot
.46293 .7121 Mdot
.57321 .39496 Mdot
.62672 .57585 Mdot
.36397 .22764 Mdot
.28233 .40098 Mdot
.63012 .50183 Mdot
.35005 .51018 Mdot
.64633 .61391 Mdot
.1675 .53251 Mdot
.63323 .5898 Mdot
.58034 .35516 Mdot
.54126 .35703 Mdot
.81977 .49826 Mdot
.59429 .35664 Mdot
.35807 .56672 Mdot
.41263 .38006 Mdot
.43589 .18772 Mdot
.34106 .56075 Mdot
.56951 .54912 Mdot
.83295 .51735 Mdot
.68312 .52218 Mdot
.57397 .5396 Mdot
.19931 .61247 Mdot
.33907 .55765 Mdot
.55287 .33002 Mdot
.45166 .58167 Mdot
.65912 .48761 Mdot
.42855 .36513 Mdot
.70977 .5852 Mdot
.59027 .53475 Mdot
.23091 .64084 Mdot
.30658 .34365 Mdot
.44492 .36932 Mdot
.69627 .52922 Mdot
.64641 .50873 Mdot
.41443 .52903 Mdot
.63069 .54483 Mdot
.44083 .66063 Mdot
.54055 .34777 Mdot
.33044 .52847 Mdot
.45637 .6786 Mdot
.60255 .55272 Mdot
.44178 .69124 Mdot
.36391 .514 Mdot
.42362 .35942 Mdot
.60694 .53481 Mdot
.46233 .64587 Mdot
.44565 .69197 Mdot
.65701 .52783 Mdot
.54812 .3657 Mdot
.58692 .49667 Mdot
.63355 .58267 Mdot
.66954 .52926 Mdot
.56925 .38545 Mdot
.61311 .14493 Mdot
.64614 .59401 Mdot
.4295 .61273 Mdot
.54149 .37543 Mdot
.41305 .4904 Mdot
.32576 .53193 Mdot
.58799 .54014 Mdot
.43413 .36252 Mdot
.38929 .38002 Mdot
.37999 .56751 Mdot
.53321 .36445 Mdot
.28676 .63171 Mdot
.52636 .38434 Mdot
.64528 .48646 Mdot
.65922 .49893 Mdot
.80806 .57777 Mdot
.22084 .32964 Mdot
.56724 .31962 Mdot
.36531 .49076 Mdot
.4819 .59394 Mdot
.39293 .39893 Mdot
.33709 .51317 Mdot
.5358 .38006 Mdot
.53619 .35968 Mdot
.55278 .36025 Mdot
.46566 .69268 Mdot
.27947 .59672 Mdot
.58545 .3124 Mdot
.6075 .33573 Mdot
.6596 .55619 Mdot
.64336 .50907 Mdot
.47304 .74242 Mdot
.54466 .76493 Mdot
.42746 .67972 Mdot
.38008 .54293 Mdot
.55215 .87598 Mdot
.4511 .39354 Mdot
.76704 .35193 Mdot
.57401 .54814 Mdot
.29815 .83015 Mdot
.66604 .59507 Mdot
.62723 .54512 Mdot
.59132 .38416 Mdot
.4513 .64196 Mdot
.4573 .66577 Mdot
.58435 .33922 Mdot
.60844 .37848 Mdot
.44189 .65991 Mdot
.58043 .22413 Mdot
.38848 .20341 Mdot
.41154 .58738 Mdot
.57858 .36655 Mdot
.78185 .44106 Mdot
.4004 .35776 Mdot
.53965 .31216 Mdot
.44391 .41187 Mdot
.34251 .53878 Mdot
.33685 .5784 Mdot
.41861 .36594 Mdot
.65582 .55551 Mdot
.38296 .51872 Mdot
.68887 .52457 Mdot
.60002 .2492 Mdot
.73115 .46658 Mdot
.25274 .59367 Mdot
.6775 .60165 Mdot
.38258 .7317 Mdot
.34695 .35969 Mdot
.60967 .56706 Mdot
.28531 .30879 Mdot
.45317 .69544 Mdot
.56144 .30579 Mdot
.44765 .38234 Mdot
.15673 .53338 Mdot
.60563 .52623 Mdot
.57707 .35823 Mdot
.41285 .40341 Mdot
.58922 .64708 Mdot
.49797 .24861 Mdot
.61098 .52916 Mdot
.34006 .83652 Mdot
.62418 .3722 Mdot
.33399 .52523 Mdot
.76824 .6417 Mdot
.57591 .31659 Mdot
.40751 .69494 Mdot
.22309 .51847 Mdot
.63531 .20903 Mdot
.55817 .32959 Mdot
.33037 .5162 Mdot
.57848 .32788 Mdot
.4336 .66519 Mdot
.52849 .34422 Mdot
.33326 .54369 Mdot
.64055 .57598 Mdot
.37471 .5463 Mdot
.43033 .69504 Mdot
.49918 .79581 Mdot
.44263 .36687 Mdot
.33687 .51654 Mdot
.40054 .37525 Mdot
.62631 .72503 Mdot
.2062 .54088 Mdot
.44103 .396 Mdot
.7557 .60942 Mdot
.61432 .50492 Mdot
.58721 .31639 Mdot
.37715 .55798 Mdot
.23404 .50651 Mdot
.45685 .56149 Mdot
.57732 .37762 Mdot
.37707 .52494 Mdot
.52736 .52697 Mdot
.76049 .62042 Mdot
.61504 .61537 Mdot
.62738 .73845 Mdot
.58252 .36509 Mdot
.31884 .52568 Mdot
.42495 .79378 Mdot
.59805 .33255 Mdot
.36609 .56193 Mdot
.40143 .41072 Mdot
.42026 .3812 Mdot
.61225 .58153 Mdot
.37506 .35812 Mdot
.38404 .53434 Mdot
.34679 .38895 Mdot
.56317 .39349 Mdot
.56079 .63268 Mdot
.47503 .66956 Mdot
.3619 .53381 Mdot
.67433 .51837 Mdot
.57729 .30385 Mdot
.26247 .43148 Mdot
.76538 .52744 Mdot
.4757 .85016 Mdot
.37733 .54918 Mdot
.53756 .36212 Mdot
.57364 .36113 Mdot
.56698 .55844 Mdot
.47887 .56759 Mdot
.28562 .62621 Mdot
.6784 .66217 Mdot
.57419 .65241 Mdot
.38786 .57165 Mdot
.40219 .55899 Mdot
.59785 .50888 Mdot
.64638 .53522 Mdot
.39623 .40399 Mdot
.6446 .5739 Mdot
.60106 .37388 Mdot
.61031 .58196 Mdot
.41794 .37067 Mdot
.34846 .5478 Mdot
.6071 .5419 Mdot
.42947 .67866 Mdot
.42661 .3554 Mdot
.39005 .40919 Mdot
.36539 .53948 Mdot
.56829 .38837 Mdot
.48873 .67866 Mdot
.3737 .53512 Mdot
.65086 .53972 Mdot
.44156 .33709 Mdot
.67397 .52739 Mdot
.6265 .27574 Mdot
.59988 .33379 Mdot
.32601 .54036 Mdot
.56356 .39495 Mdot
.39627 .38191 Mdot
.2164 .52469 Mdot
.64193 .55438 Mdot
.36078 .56194 Mdot
.2746 .56695 Mdot
.63287 .29966 Mdot
.56951 .40713 Mdot
.34738 .33668 Mdot
.61067 .36843 Mdot
.35839 .57975 Mdot
.81204 .41449 Mdot
.46877 .66985 Mdot
.33837 .56498 Mdot
.28137 .2729 Mdot
.36239 .55177 Mdot
.64945 .58366 Mdot
.66915 .58576 Mdot
.33471 .52327 Mdot
.45171 .64663 Mdot
.39467 .77407 Mdot
.36714 .5896 Mdot
.55356 .33073 Mdot
.66781 .24682 Mdot
.39579 .82218 Mdot
.37248 .35452 Mdot
.40527 .4083 Mdot
.65475 .48448 Mdot
.68693 .54933 Mdot
.43716 .41549 Mdot
.37999 .39706 Mdot
.45263 .7037 Mdot
.3701 .57159 Mdot
.60726 .41008 Mdot
.38776 .35998 Mdot
.73186 .59434 Mdot
.32759 .61529 Mdot
.58281 .58933 Mdot
.54487 .51191 Mdot
.60506 .58694 Mdot
.5968 .66277 Mdot
.42017 .36946 Mdot
.67887 .57142 Mdot
.60988 .60929 Mdot
.43529 .36473 Mdot
.43872 .66213 Mdot
.37362 .31132 Mdot
.35074 .52503 Mdot
.45534 .15069 Mdot
.68332 .55847 Mdot
.6488 .58585 Mdot
.40376 .36171 Mdot
.31179 .66935 Mdot
.5587 .37914 Mdot
.5971 .32868 Mdot
.38187 .51369 Mdot
.45595 .53479 Mdot
.58873 .54541 Mdot
.61965 .57653 Mdot
.34476 .52404 Mdot
.32537 .52504 Mdot
.34125 .4311 Mdot
.67005 .56308 Mdot
.40833 .40113 Mdot
.49355 .62277 Mdot
.41872 .36912 Mdot
.6747 .52324 Mdot
.655 .58475 Mdot
.60062 .57915 Mdot
.67261 .51695 Mdot
.39717 .41703 Mdot
.67737 .57032 Mdot
.62953 .62692 Mdot
.55513 .37994 Mdot
.61631 .52028 Mdot
.59209 .65805 Mdot
.65009 .56766 Mdot
.4391 .66472 Mdot
.74893 .58089 Mdot
.60556 .52793 Mdot
.58654 .54835 Mdot
.35485 .59427 Mdot
.63495 .56443 Mdot
.45153 .39412 Mdot
.5674 .37274 Mdot
.39166 .38796 Mdot
.39295 .36836 Mdot
.38567 .55831 Mdot
.43694 .70451 Mdot
.57851 .54308 Mdot
.45449 .70041 Mdot
.58529 .57429 Mdot
.62636 .50176 Mdot
.23564 .54224 Mdot
.68593 .78051 Mdot
.50262 .80674 Mdot
.64325 .5537 Mdot
.34751 .55828 Mdot
.32474 .5355 Mdot
.61699 .30211 Mdot
.60506 .60998 Mdot
.43104 .4177 Mdot
.38882 .38578 Mdot
.51797 .75456 Mdot
.22802 .62182 Mdot
.43899 .66391 Mdot
.51669 .48465 Mdot
.68406 .5148 Mdot
.67513 .54325 Mdot
.68527 .5321 Mdot
.39556 .53821 Mdot
.47798 .60702 Mdot
.33873 .56418 Mdot
.49922 .30908 Mdot
.41047 .36661 Mdot
.6078 .52387 Mdot
.56184 .42485 Mdot
.59882 .34147 Mdot
.56674 .37244 Mdot
.39809 .41432 Mdot
.30955 .58179 Mdot
.46654 .76012 Mdot
.72968 .23664 Mdot
.62524 .37685 Mdot
.44086 .64119 Mdot
.60519 .56486 Mdot
.35464 .54632 Mdot
.58487 .32906 Mdot
.42671 .65691 Mdot
.64505 .50265 Mdot
.27874 .59576 Mdot
.64707 .55156 Mdot
.54277 .48007 Mdot
.54828 .35362 Mdot
.41719 .18971 Mdot
.53886 .34042 Mdot
.4303 .35653 Mdot
.44559 .38143 Mdot
.66438 .58601 Mdot
.78965 .6081 Mdot
.58949 .32069 Mdot
.37155 .42349 Mdot
.47049 .697 Mdot
.27663 .42295 Mdot
.43673 .66014 Mdot
.3316 .52998 Mdot
.46179 .65819 Mdot
.3313 .54083 Mdot
.51127 .77429 Mdot
.58018 .41324 Mdot
.45963 .68321 Mdot
.37837 .60991 Mdot
.59792 .60699 Mdot
.42545 .66736 Mdot
.67175 .49369 Mdot
.64975 .28355 Mdot
.35103 .52109 Mdot
.4726 .67457 Mdot
.64355 .50426 Mdot
.16743 .42532 Mdot
.42517 .40874 Mdot
.43495 .41502 Mdot
.64678 .48751 Mdot
.38891 .56153 Mdot
.55326 .39499 Mdot
.36305 .25287 Mdot
.45964 .38041 Mdot
.65653 .59187 Mdot
.61922 .58822 Mdot
.61189 .34963 Mdot
.49729 .36472 Mdot
.66215 .58399 Mdot
.7391 .61278 Mdot
.67133 .56963 Mdot
.40562 .41486 Mdot
.58184 .32218 Mdot
.57066 .36619 Mdot
.37769 .52234 Mdot
.59799 .37035 Mdot
.63464 .33933 Mdot
.44663 .33054 Mdot
.63865 .4773 Mdot
.3998 .38654 Mdot
.47677 .32551 Mdot
.50164 .30864 Mdot
.23749 .32206 Mdot
.61271 .34243 Mdot
.61869 .59462 Mdot
.55888 .39133 Mdot
.43839 .67499 Mdot
.55969 .36634 Mdot
.54036 .38472 Mdot
.6182 .56929 Mdot
.61298 .53469 Mdot
.34071 .55226 Mdot
.47707 .57552 Mdot
.5599 .3876 Mdot
.6723 .58552 Mdot
.69155 .54968 Mdot
.69048 .53381 Mdot
.48274 .43063 Mdot
.57062 .32041 Mdot
.75593 .31683 Mdot
.52914 .67015 Mdot
.56098 .38818 Mdot
.16394 .57797 Mdot
.24154 .49681 Mdot
.30994 .55211 Mdot
.3995 .34775 Mdot
.67061 .5615 Mdot
.32046 .53887 Mdot
.61027 .53743 Mdot
.5444 .51326 Mdot
.62694 .5639 Mdot
.44389 .65713 Mdot
.69366 .53409 Mdot
.35885 .58106 Mdot
.37473 .53972 Mdot
.64247 .59195 Mdot
.60904 .54709 Mdot
.48472 .79232 Mdot
.61546 .36374 Mdot
.55662 .37463 Mdot
.2909 .64761 Mdot
.45047 .68702 Mdot
.43115 .36607 Mdot
.63233 .5377 Mdot
.38878 .55152 Mdot
.37574 .54299 Mdot
.57672 .31792 Mdot
.36922 .52234 Mdot
.42853 .37122 Mdot
.63893 .55274 Mdot
.4378 .41432 Mdot
.46482 .69463 Mdot
.57197 .32326 Mdot
.61303 .52484 Mdot
.65965 .55666 Mdot
.54134 .35642 Mdot
.58642 .52611 Mdot
.43865 .64905 Mdot
.365 .55231 Mdot
.55997 .33111 Mdot
.41454 .38033 Mdot
.32952 .53577 Mdot
.66964 .5377 Mdot
.52305 .86968 Mdot
.65233 .58066 Mdot
.67008 .55467 Mdot
.27607 .27023 Mdot
.6916 .52599 Mdot
.37799 .55456 Mdot
.60808 .3515 Mdot
.68656 .58932 Mdot
.58153 .67208 Mdot
.66098 .18114 Mdot
.34544 .56708 Mdot
.60536 .56769 Mdot
.18094 .38367 Mdot
.61723 .57844 Mdot
.80529 .54739 Mdot
.39829 .62082 Mdot
.42927 .48946 Mdot
.57988 .50787 Mdot
.43055 .38293 Mdot
.34079 .55388 Mdot
.33359 .53046 Mdot
.7099 .27923 Mdot
.6186 .5721 Mdot
.53165 .49049 Mdot
.62325 .50894 Mdot
.42014 .3766 Mdot
.50948 .73937 Mdot
.3777 .54611 Mdot
.52462 .82882 Mdot
.65897 .53748 Mdot
.55757 .32102 Mdot
.31373 .57584 Mdot
.26275 .47173 Mdot
.6686 .52984 Mdot
.44755 .69978 Mdot
.39875 .35342 Mdot
.69439 .56769 Mdot
.40377 .38571 Mdot
.67077 .52719 Mdot
.73933 .57515 Mdot
.76625 .66318 Mdot
.54975 .36309 Mdot
.40382 .41016 Mdot
.422 .33207 Mdot
.65215 .60744 Mdot
.55818 .33069 Mdot
.57022 .38017 Mdot
.44829 .70328 Mdot
.48983 .48249 Mdot
.46409 .26957 Mdot
.76596 .48724 Mdot
.70171 .26657 Mdot
.31178 .57791 Mdot
.32216 .36893 Mdot
.66224 .52265 Mdot
.27193 .66561 Mdot
.45002 .37997 Mdot
.64438 .5833 Mdot
.65733 .32691 Mdot
.58749 .33567 Mdot
.66035 .57172 Mdot
.44762 .66122 Mdot
.29567 .68442 Mdot
.29147 .69088 Mdot
.20649 .48625 Mdot
.34576 .54163 Mdot
.71302 .54602 Mdot
.66182 .4773 Mdot
.38152 .50928 Mdot
.59497 .5213 Mdot
.36955 .55845 Mdot
.61294 .22632 Mdot
.43227 .64971 Mdot
.56268 .32179 Mdot
.2501 .4899 Mdot
.584 .54137 Mdot
.66421 .49993 Mdot
.41947 .67581 Mdot
.64571 .52998 Mdot
.72804 .72555 Mdot
.26495 .52937 Mdot
.37015 .51078 Mdot
.55202 .36107 Mdot
.5847 .55419 Mdot
.50197 .48009 Mdot
.62985 .58192 Mdot
.7451 .42356 Mdot
.58614 .55144 Mdot
.47991 .25892 Mdot
.54501 .359 Mdot
.40191 .38228 Mdot
.6417 .61002 Mdot
.62596 .55761 Mdot
.50759 .63831 Mdot
.59296 .4973 Mdot
.67362 .58856 Mdot
.55864 .40058 Mdot
.58896 .32929 Mdot
.56438 .3422 Mdot
.33136 .56958 Mdot
.2301 .63205 Mdot
.39925 .39618 Mdot
.67193 .61219 Mdot
.38213 .36418 Mdot
.77089 .56435 Mdot
.43543 .6451 Mdot
.19351 .40636 Mdot
.62878 .52151 Mdot
.56937 .34668 Mdot
.28567 .33875 Mdot
.57845 .39617 Mdot
.50219 .51527 Mdot
.41917 .39581 Mdot
.59081 .33997 Mdot
.62578 .55011 Mdot
.46757 .58265 Mdot
.17984 .46254 Mdot
.39372 .3768 Mdot
.57889 .56663 Mdot
.31575 .54589 Mdot
.23721 .57727 Mdot
.50542 .86698 Mdot
.42248 .41085 Mdot
.43152 .33592 Mdot
.61631 .57196 Mdot
.60121 .34312 Mdot
.43076 .37849 Mdot
.43466 .40333 Mdot
.36965 .52099 Mdot
.61425 .53242 Mdot
.61633 .52917 Mdot
.34022 .57656 Mdot
.39127 .37708 Mdot
.59638 .50136 Mdot
.68668 .56946 Mdot
.14999 .40652 Mdot
.52392 .58482 Mdot
.50148 .13257 Mdot
.63387 .35804 Mdot
.65662 .36476 Mdot
.38657 .23147 Mdot
.53663 .3649 Mdot
.60362 .52922 Mdot
.70371 .57974 Mdot
.38372 .53517 Mdot
.64226 .5657 Mdot
.3749 .49393 Mdot
.40737 .4059 Mdot
.16504 .5594 Mdot
.45695 .3071 Mdot
.61132 .21215 Mdot
.64064 .56739 Mdot
.51436 .3156 Mdot
.44927 .67417 Mdot
.43191 .42989 Mdot
.56589 .334 Mdot
.66137 .50909 Mdot
.48499 .79381 Mdot
.33787 .56433 Mdot
.58898 .3736 Mdot
.41847 .7794 Mdot
.38662 .7312 Mdot
.67358 .52153 Mdot
.32457 .56144 Mdot
.29476 .31615 Mdot
.71487 .62707 Mdot
.45312 .41209 Mdot
.44131 .65803 Mdot
.33476 .55298 Mdot
.38917 .37523 Mdot
.60152 .42707 Mdot
.59425 .34732 Mdot
.52814 .37437 Mdot
.56145 .7977 Mdot
.37455 .50419 Mdot
.45271 .67289 Mdot
.22838 .61259 Mdot
.28148 .69285 Mdot
.44558 .65717 Mdot
.33064 .57617 Mdot
.5872 .329 Mdot
.57874 .3406 Mdot
.56828 .3726 Mdot
.49855 .82219 Mdot
.53511 .3506 Mdot
.73978 .32401 Mdot
.68199 .51941 Mdot
.72271 .52725 Mdot
.60936 .5719 Mdot
.43152 .41905 Mdot
.54787 .34628 Mdot
.44673 .53144 Mdot
.60273 .59957 Mdot
.19259 .50154 Mdot
.63135 .5858 Mdot
.4258 .4287 Mdot
.66472 .56634 Mdot
.77092 .37765 Mdot
.55415 .38801 Mdot
.64353 .55857 Mdot
.44979 .40775 Mdot
.44258 .68646 Mdot
.53081 .39185 Mdot
.61016 .52743 Mdot
.38143 .27378 Mdot
.69291 .52931 Mdot
.56962 .21121 Mdot
.53942 .61495 Mdot
.44087 .64124 Mdot
.55267 .59008 Mdot
.36478 .49949 Mdot
.69882 .49849 Mdot
.71951 .54396 Mdot
.3985 .3729 Mdot
.24205 .4616 Mdot
.35325 .53435 Mdot
.4024 .65887 Mdot
.70233 .59729 Mdot
.42738 .68986 Mdot
.61072 .37739 Mdot
.42694 .42384 Mdot
.60865 .50533 Mdot
.58254 .5858 Mdot
.62685 .25313 Mdot
.69132 .61102 Mdot
.6083 .58165 Mdot
.42391 .65519 Mdot
.69991 .28689 Mdot
.6527 .56427 Mdot
.5042 .5049 Mdot
.5287 .34866 Mdot
.60226 .49472 Mdot
.77162 .35146 Mdot
.66785 .58857 Mdot
.59714 .36224 Mdot
.55698 .40768 Mdot
.39183 .29916 Mdot
.4602 .70377 Mdot
.58797 .54165 Mdot
.81943 .49347 Mdot
.65555 .53649 Mdot
.4073 .3989 Mdot
.68463 .54599 Mdot
.33586 .54437 Mdot
.48327 .81312 Mdot
.38319 .52411 Mdot
.59167 .54907 Mdot
.57237 .37145 Mdot
.41037 .36244 Mdot
.56451 .80938 Mdot
.3068 .61894 Mdot
.72705 .31421 Mdot
.60887 .1907 Mdot
.46046 .65242 Mdot
.43265 .70403 Mdot
.42318 .42518 Mdot
.64498 .55852 Mdot
.81682 .40518 Mdot
.60022 .49208 Mdot
.65829 .5683 Mdot
.62551 .56338 Mdot
.21537 .56861 Mdot
.3957 .4009 Mdot
.3607 .52321 Mdot
.6593 .58406 Mdot
.67718 .57636 Mdot
.53814 .36874 Mdot
.44468 .68985 Mdot
.32518 .53322 Mdot
.46073 .68925 Mdot
.35033 .55282 Mdot
.16148 .56668 Mdot
.64852 .61257 Mdot
.44379 .68463 Mdot
.42864 .35131 Mdot
.57317 .38595 Mdot
.43888 .32844 Mdot
.33299 .5291 Mdot
.38097 .54058 Mdot
.63987 .58945 Mdot
.59832 .3614 Mdot
.58139 .38982 Mdot
.43693 .67556 Mdot
.44206 .38898 Mdot
.6055 .53096 Mdot
.6324 .50015 Mdot
.58351 .27376 Mdot
.39076 .55472 Mdot
.53662 .50505 Mdot
.34843 .29919 Mdot
.64499 .55493 Mdot
.57937 .38837 Mdot
.61422 .55729 Mdot
.40997 .21579 Mdot
.60233 .35025 Mdot
.66515 .59318 Mdot
.32678 .74865 Mdot
.29939 .57525 Mdot
.42033 .2853 Mdot
.61336 .58794 Mdot
.51069 .16788 Mdot
.65203 .51386 Mdot
.12903 .43982 Mdot
.37944 .63962 Mdot
.59758 .53068 Mdot
.66794 .54076 Mdot
.73657 .48605 Mdot
.59935 .55178 Mdot
.35695 .58008 Mdot
.43921 .75196 Mdot
.54992 .39451 Mdot
.41441 .24455 Mdot
.69523 .48405 Mdot
.47383 .69159 Mdot
.3804 .5126 Mdot
.4089 .54571 Mdot
.45568 .66044 Mdot
.57993 .36373 Mdot
.64365 .54407 Mdot
.45958 .50171 Mdot
.39375 .56373 Mdot
.56215 .56379 Mdot
.41018 .39779 Mdot
.31396 .42693 Mdot
.30764 .58445 Mdot
.40885 .37995 Mdot
.62021 .51712 Mdot
.73765 .4926 Mdot
.61226 .76572 Mdot
.38317 .1976 Mdot
.39271 .36686 Mdot
.39678 .37027 Mdot
.47815 .82084 Mdot
.47718 .6786 Mdot
.63771 .24776 Mdot
.48793 .25285 Mdot
.42248 .36404 Mdot
.652 .65034 Mdot
.35854 .57136 Mdot
.39358 .27276 Mdot
.56019 .30588 Mdot
.66493 .50377 Mdot
.6261 .55252 Mdot
.44289 .38462 Mdot
.62735 .29723 Mdot
.76174 .65819 Mdot
.40218 .37402 Mdot
.66092 .62998 Mdot
.46612 .45076 Mdot
.23918 .49931 Mdot
.37946 .56566 Mdot
.45547 .70501 Mdot
.4112 .65443 Mdot
.54853 .33277 Mdot
.44568 .70675 Mdot
.28771 .67821 Mdot
.63956 .52755 Mdot
.41038 .37135 Mdot
.26546 .43036 Mdot
.41584 .38377 Mdot
.45729 .66361 Mdot
.43815 .64107 Mdot
.55532 .37988 Mdot
.55629 .37204 Mdot
.6596 .38896 Mdot
.53777 .72795 Mdot
.62422 .58351 Mdot
.21272 .42997 Mdot
.56461 .39399 Mdot
.55401 .51571 Mdot
.4305 .70046 Mdot
.44636 .68792 Mdot
.51957 .6336 Mdot
.62552 .52857 Mdot
.81179 .51986 Mdot
.62799 .53283 Mdot
.51686 .73586 Mdot
.58741 .57058 Mdot
.36965 .52161 Mdot
.62217 .52495 Mdot
.49271 .67951 Mdot
.60629 .5042 Mdot
.68548 .56223 Mdot
.39425 .55104 Mdot
.69396 .57412 Mdot
.33636 .54231 Mdot
.59439 .5613 Mdot
.47593 .69218 Mdot
.39195 .53567 Mdot
.59256 .69215 Mdot
.4596 .61136 Mdot
.32186 .57129 Mdot
.43385 .69726 Mdot
.47463 .68274 Mdot
.63269 .68674 Mdot
.56652 .33316 Mdot
.52842 .33167 Mdot
.64505 .56226 Mdot
.37995 .49844 Mdot
.39889 .40501 Mdot
.67611 .57169 Mdot
.70119 .55619 Mdot
.63056 .59531 Mdot
.55402 .32578 Mdot
.28053 .61952 Mdot
.43944 .68114 Mdot
.33669 .57261 Mdot
.47673 .72013 Mdot
.38165 .57103 Mdot
.64062 .61869 Mdot
.71095 .56614 Mdot
.6452 .3997 Mdot
.25655 .39483 Mdot
.46395 .82922 Mdot
.59583 .35083 Mdot
.3444 .51261 Mdot
.47577 .67692 Mdot
.55651 .53085 Mdot
.57152 .33976 Mdot
.3337 .54363 Mdot
.64635 .55092 Mdot
.5801 .56937 Mdot
.48937 .33628 Mdot
.66109 .4704 Mdot
.55639 .64998 Mdot
.37725 .57176 Mdot
.3352 .51321 Mdot
.27818 .68475 Mdot
.42677 .73896 Mdot
.45364 .55213 Mdot
.63163 .57628 Mdot
.44987 .69982 Mdot
.58504 .32925 Mdot
.58774 .78311 Mdot
.44555 .39376 Mdot
.47758 .57209 Mdot
.6405 .56559 Mdot
.42114 .49513 Mdot
.57188 .37304 Mdot
.44427 .66234 Mdot
.44261 .38224 Mdot
.41553 .66525 Mdot
.38918 .51608 Mdot
.69503 .22958 Mdot
.65226 .53373 Mdot
.62998 .5882 Mdot
.44084 .36285 Mdot
.58306 .33264 Mdot
.41787 .67867 Mdot
.60373 .24681 Mdot
.35502 .51473 Mdot
.82526 .42594 Mdot
.59819 .37358 Mdot
.7662 .38741 Mdot
.34348 .57433 Mdot
.39651 .41325 Mdot
.62097 .69571 Mdot
.41908 .37151 Mdot
.58958 .55375 Mdot
.56917 .35756 Mdot
.41869 .40845 Mdot
.49331 .58859 Mdot
.17602 .40225 Mdot
.77881 .42438 Mdot
.63646 .53303 Mdot
.15642 .46462 Mdot
.51318 .20371 Mdot
.61833 .36459 Mdot
.43358 .3617 Mdot
.63607 .58486 Mdot
.60007 .51876 Mdot
.65691 .54037 Mdot
.42431 .39943 Mdot
.23872 .52532 Mdot
.3495 .52038 Mdot
.6129 .5724 Mdot
.45375 .70308 Mdot
.34148 .53688 Mdot
.25072 .48755 Mdot
.38019 .54966 Mdot
.61668 .34756 Mdot
.68546 .54561 Mdot
.39501 .42832 Mdot
.13025 .50785 Mdot
.39174 .38469 Mdot
.32527 .57473 Mdot
.68027 .55642 Mdot
.25892 .42499 Mdot
.56611 .34184 Mdot
.36249 .51348 Mdot
.64774 .5858 Mdot
.25181 .4982 Mdot
.50155 .79966 Mdot
.37966 .54916 Mdot
.57497 .33391 Mdot
.33821 .24524 Mdot
.64411 .57076 Mdot
.65287 .51716 Mdot
.58595 .34151 Mdot
.73859 .52317 Mdot
.42467 .78999 Mdot
.61085 .55146 Mdot
.40289 .38073 Mdot
.81373 .35514 Mdot
.67968 .59199 Mdot
.51874 .68581 Mdot
.33817 .55267 Mdot
.38602 .28915 Mdot
.53072 .52123 Mdot
.55659 .51773 Mdot
.59477 .25029 Mdot
.5145 .4188 Mdot
.17514 .51882 Mdot
.36542 .49454 Mdot
.38605 .70814 Mdot
.16822 .52726 Mdot
.43774 .42122 Mdot
.51259 .38133 Mdot
.55585 .23771 Mdot
.57762 .82777 Mdot
.33663 .25512 Mdot
.33384 .69215 Mdot
.48038 .79438 Mdot
.45194 .47808 Mdot
.35623 .55465 Mdot
.44101 .63007 Mdot
.60914 .53257 Mdot
.51016 .20223 Mdot
.80834 .49425 Mdot
.79576 .61882 Mdot
.15566 .45661 Mdot
.79932 .54193 Mdot
.18311 .42252 Mdot
.24943 .30815 Mdot
.64751 .35872 Mdot
.26775 .3752 Mdot
.83385 .4405 Mdot
.31673 .73484 Mdot
.71865 .26931 Mdot
.66233 .48182 Mdot
.50858 .51906 Mdot
.58083 .20141 Mdot
.74133 .34604 Mdot
.76419 .62635 Mdot
.37793 .52007 Mdot
.60839 .34631 Mdot
.5414 .23523 Mdot
.59798 .39298 Mdot
.3679 .35278 Mdot
.34851 .2308 Mdot
.18303 .37375 Mdot
.77217 .37424 Mdot
.47607 .15782 Mdot
.66834 .32741 Mdot
.79708 .69809 Mdot
.38003 .58364 Mdot
.57425 .31511 Mdot
.4233 .71697 Mdot
.26968 .67925 Mdot
.5133 .28735 Mdot
.5454 .22532 Mdot
.23788 .55609 Mdot
.5894 .72689 Mdot
.57691 .35975 Mdot
.5502 .59548 Mdot
.3531 .37415 Mdot
.46543 .30915 Mdot
.43753 .75419 Mdot
.27799 .2883 Mdot
.46893 .51658 Mdot
.3937 .26412 Mdot
.3158 .39987 Mdot
.50535 .86298 Mdot
.53422 .66036 Mdot
.62593 .39878 Mdot
.45943 .34588 Mdot
.39751 .22078 Mdot
.62161 .80567 Mdot
.54283 .74309 Mdot
.27342 .68381 Mdot
.23277 .67105 Mdot
.47631 .19127 Mdot
.2806 .74936 Mdot
.52676 .33985 Mdot
.61264 .58501 Mdot
.67311 .45959 Mdot
.81921 .48021 Mdot
.45842 .63744 Mdot
.21214 .48886 Mdot
.47155 .68461 Mdot
.60929 .31667 Mdot
.46954 .80544 Mdot
.75465 .33957 Mdot
.82435 .48841 Mdot
.42418 .70181 Mdot
.67647 .60199 Mdot
.85621 .36179 Mdot
.17999 .50323 Mdot
.42037 .29893 Mdot
.14313 .41506 Mdot
.43848 .53337 Mdot
.58271 .64375 Mdot
.41896 .4073 Mdot
.15838 .51399 Mdot
.5761 .34679 Mdot
.22138 .6966 Mdot
.13638 .46678 Mdot
.73546 .67218 Mdot
.55276 .09473 Mdot
.25644 .63847 Mdot
.42925 .49564 Mdot
.50065 .40365 Mdot
.5657 .68312 Mdot
.73117 .70696 Mdot
.73503 .65581 Mdot
.27387 .40626 Mdot
.58907 .18495 Mdot
.16417 .50543 Mdot
.82127 .45178 Mdot
.70351 .2421 Mdot
.59877 .82303 Mdot
.51686 .46526 Mdot
.55681 .30153 Mdot
.39397 .58332 Mdot
.2607 .32634 Mdot
.19333 .61532 Mdot
.52629 .66676 Mdot
.68398 .19058 Mdot
.47875 .70959 Mdot
.36509 .6404 Mdot
.35646 .2122 Mdot
.60687 .71944 Mdot
.54342 .59823 Mdot
.3971 .76301 Mdot
.56474 .56609 Mdot
.37202 .7464 Mdot
.20768 .40984 Mdot
.40792 .32552 Mdot
.32215 .7348 Mdot
.32741 .28329 Mdot
.61936 .25419 Mdot
.73065 .4593 Mdot
.26761 .6844 Mdot
.57198 .39934 Mdot
.56539 .7301 Mdot
.5361 .59328 Mdot
.17535 .37791 Mdot
.43183 .33661 Mdot
.2112 .31876 Mdot
.43413 .78548 Mdot
.6277 .6027 Mdot
.70369 .5136 Mdot
.63624 .63202 Mdot
.54767 .7194 Mdot
.68824 .57216 Mdot
.50831 .30577 Mdot
.21937 .32675 Mdot
.66182 .30733 Mdot
.364 .32858 Mdot
.23958 .47134 Mdot
.37324 .19864 Mdot
.65751 .43082 Mdot
.41642 .73768 Mdot
.48567 .74152 Mdot
.56118 .84736 Mdot
.35418 .53059 Mdot
.81761 .43309 Mdot
.45116 .41674 Mdot
.53032 .79386 Mdot
.77094 .49255 Mdot
.71601 .7097 Mdot
.22056 .3252 Mdot
.36106 .71982 Mdot
.45989 .79118 Mdot
.63911 .71924 Mdot
.81341 .37845 Mdot
.2297 .47947 Mdot
.71064 .58191 Mdot
.47984 .21625 Mdot
.45415 .64669 Mdot
.67998 .4198 Mdot
.77565 .32629 Mdot
.32777 .65761 Mdot
.66368 .49414 Mdot
.6635 .74437 Mdot
.287 .52094 Mdot
.46807 .58055 Mdot
.37692 .82636 Mdot
.59333 .60193 Mdot
.23373 .62115 Mdot
.49856 .19084 Mdot
.54649 .68767 Mdot
.39238 .20856 Mdot
.36746 .25958 Mdot
.25912 .72316 Mdot
.14266 .44347 Mdot
.29928 .62039 Mdot
.17597 .54596 Mdot
.16297 .38874 Mdot
.28786 .74671 Mdot
.72565 .57808 Mdot
.4471 .36648 Mdot
.45652 .8805 Mdot
.3644 .57803 Mdot
.21144 .57909 Mdot
.7025 .26742 Mdot
.26017 .49453 Mdot
.60259 .41563 Mdot
.61516 .46847 Mdot
.45828 .48503 Mdot
.61983 .35767 Mdot
.69209 .5711 Mdot
.3941 .81761 Mdot
.26485 .71511 Mdot
.34143 .79374 Mdot
.50464 .17929 Mdot
.17177 .55881 Mdot
.42222 .46675 Mdot
.74751 .34427 Mdot
.61276 .30046 Mdot
.66373 .50679 Mdot
.41722 .61598 Mdot
.25574 .63536 Mdot
.65719 .75114 Mdot
.50671 .27755 Mdot
.61332 .37103 Mdot
.20916 .45553 Mdot
.80632 .72928 Mdot
.66957 .3524 Mdot
.77226 .3455 Mdot
.28758 .69016 Mdot
.53569 .71771 Mdot
.24584 .34999 Mdot
.72574 .69138 Mdot
.26581 .28253 Mdot
.62203 .36096 Mdot
.70501 .26273 Mdot
.34358 .68516 Mdot
.65737 .65975 Mdot
.27543 .61213 Mdot
.19357 .37483 Mdot
.46 .4291 Mdot
.61539 .78323 Mdot
.49894 .24053 Mdot
.74663 .66573 Mdot
.39589 .63265 Mdot
.3198 .42632 Mdot
.7801 .33308 Mdot
.31984 .34275 Mdot
.51965 .71465 Mdot
.47283 .45937 Mdot
.55358 .56853 Mdot
.51272 .41706 Mdot
.52344 .705 Mdot
.63003 .66608 Mdot
.19142 .58149 Mdot
.1044 .4632 Mdot
.46896 .84197 Mdot
.45076 .1553 Mdot
.22241 .39185 Mdot
.64638 .49202 Mdot
.32244 .22361 Mdot
.3073 .77868 Mdot
.12814 .46387 Mdot
.33494 .46302 Mdot
.38123 .49312 Mdot
.3759 .37257 Mdot
.4173 .81189 Mdot
.2703 .57532 Mdot
.30657 .25071 Mdot
.38358 .76042 Mdot
.38182 .3581 Mdot
.69678 .77245 Mdot
.2536 .69271 Mdot
.77887 .48112 Mdot
.64629 .46525 Mdot
.58116 .518 Mdot
.79068 .41206 Mdot
.6094 .37443 Mdot
.32546 .3688 Mdot
.54587 .73333 Mdot
.36622 .53512 Mdot
.41678 .61983 Mdot
.53057 .21956 Mdot
.69331 .53276 Mdot
.53889 .42516 Mdot
.60798 .3345 Mdot
.26092 .38874 Mdot
.45427 .32514 Mdot
.18285 .6083 Mdot
.25104 .60837 Mdot
.56808 .52471 Mdot
.54258 .68404 Mdot
.27107 .6138 Mdot
.42277 .79438 Mdot
.39957 .42194 Mdot
.16112 .43789 Mdot
.49935 .54403 Mdot
.56215 .73022 Mdot
.79982 .44715 Mdot
.6312 .27813 Mdot
.70387 .53964 Mdot
.32423 .31309 Mdot
.73153 .40977 Mdot
.47692 .58101 Mdot
.57395 .30011 Mdot
.54097 .30693 Mdot
.3452 .19842 Mdot
.30224 .69062 Mdot
.30929 .40926 Mdot
.17175 .42227 Mdot
.42488 .38803 Mdot
.56483 .39143 Mdot
.44384 .61904 Mdot
.6057 .2402 Mdot
.74039 .38606 Mdot
.50199 .80011 Mdot
.26523 .51915 Mdot
.33985 .6541 Mdot
.17668 .42443 Mdot
.16241 .4518 Mdot
.81944 .58714 Mdot
.57226 .40747 Mdot
.64158 .32917 Mdot
.64296 .24156 Mdot
.60786 .36898 Mdot
.59515 .26169 Mdot
.53221 .28758 Mdot
.18806 .60008 Mdot
.36798 .36755 Mdot
.57397 .17668 Mdot
.59451 .66726 Mdot
.22996 .52148 Mdot
.55873 .81193 Mdot
.78325 .33839 Mdot
.18327 .40924 Mdot
.69253 .63693 Mdot
.76602 .51063 Mdot
.64793 .47789 Mdot
.57146 .45417 Mdot
.56705 .8606 Mdot
.45738 .6149 Mdot
.76874 .3887 Mdot
.33147 .27515 Mdot
.64681 .53844 Mdot
.47084 .84777 Mdot
.5823 .23224 Mdot
.4768 .82339 Mdot
.38964 .35649 Mdot
.63669 .50915 Mdot
.62146 .497 Mdot
.50518 .7064 Mdot
.39643 .29534 Mdot
.21324 .61113 Mdot
.7779 .31824 Mdot
.2975 .30608 Mdot
.80787 .49475 Mdot
.23357 .61397 Mdot
.30177 .263 Mdot
.50147 .20156 Mdot
.49119 .49364 Mdot
.2574 .63111 Mdot
.6163 .7092 Mdot
.47558 .1607 Mdot
.50792 .61638 Mdot
.4421 .43353 Mdot
.54174 .27234 Mdot
.35586 .28737 Mdot
.58063 .79278 Mdot
.66614 .51715 Mdot
.41835 .77934 Mdot
.26134 .29862 Mdot
.82081 .55127 Mdot
.6902 .75661 Mdot
.44895 .84028 Mdot
.75254 .44136 Mdot
.35835 .27685 Mdot
.50385 .2071 Mdot
.84762 .43002 Mdot
.50444 .54818 Mdot
.19393 .47923 Mdot
.6245 .71269 Mdot
.1747 .42284 Mdot
.45065 .37242 Mdot
.50776 .25053 Mdot
.23879 .47644 Mdot
.1812 .56481 Mdot
.68072 .44858 Mdot
.21206 .35265 Mdot
.43774 .51102 Mdot
.2408 .70702 Mdot
.3072 .34777 Mdot
.44712 .46833 Mdot
.35845 .50842 Mdot
.35588 .7223 Mdot
.20243 .40625 Mdot
.24344 .39441 Mdot
.78089 .34059 Mdot
.31875 .52415 Mdot
.43864 .62536 Mdot
.79181 .494 Mdot
.61158 .74265 Mdot
.33592 .29306 Mdot
.54298 .68418 Mdot
.2033 .35299 Mdot
.48312 .72199 Mdot
.4314 .77482 Mdot
.2351 .60229 Mdot
.66979 .20847 Mdot
.41728 .29691 Mdot
.32107 .71348 Mdot
.5679 .22788 Mdot
.36778 .6313 Mdot
.63433 .65085 Mdot
.09435 .60463 Mdot
.66252 .21975 Mdot
.28621 .36132 Mdot
.1938 .61554 Mdot
.41072 .20938 Mdot
.26093 .39274 Mdot
.723 .71455 Mdot
.52326 .58149 Mdot
.4895 .77683 Mdot
.62626 .56271 Mdot
.35772 .81188 Mdot
.5859 .74314 Mdot
.20628 .6435 Mdot
.33609 .21314 Mdot
.79123 .42147 Mdot
.69497 .54416 Mdot
.3353 .56883 Mdot
.37844 .33698 Mdot
.58474 .7634 Mdot
.73414 .50034 Mdot
.56524 .62265 Mdot
.26152 .53359 Mdot
.38026 .50804 Mdot
.28234 .63215 Mdot
.62716 .35698 Mdot
.25824 .56246 Mdot
.3479 .29698 Mdot
.29625 .56981 Mdot
.4743 .53006 Mdot
.52901 .70606 Mdot
.53125 .53092 Mdot
.77823 .47504 Mdot
.70124 .72173 Mdot
.52186 .44499 Mdot
.3813 .55074 Mdot
.76164 .4761 Mdot
.60443 .19936 Mdot
.29935 .31473 Mdot
.22637 .66248 Mdot
.38969 .74804 Mdot
.76689 .53466 Mdot
.51769 .70805 Mdot
.74199 .69407 Mdot
.77849 .59383 Mdot
.22988 .43179 Mdot
.56352 .47455 Mdot
.76222 .60333 Mdot
.48968 .22235 Mdot
.16266 .55402 Mdot
.71604 .26808 Mdot
.66556 .24318 Mdot
.38712 .6047 Mdot
.73209 .34573 Mdot
.7972 .46203 Mdot
.59803 .68811 Mdot
.45851 .56204 Mdot
.77179 .72568 Mdot
.54672 .31156 Mdot
.61757 .86127 Mdot
.40917 .41459 Mdot
.60763 .82622 Mdot
.63006 .70268 Mdot
.47509 .45453 Mdot
.44488 .56792 Mdot
.32914 .31326 Mdot
.48401 .25898 Mdot
.52564 .18173 Mdot
.78478 .6208 Mdot
.38766 .56779 Mdot
.7802 .31627 Mdot
.67904 .20871 Mdot
.74733 .48545 Mdot
.66934 .60332 Mdot
.65722 .21396 Mdot
.35056 .49867 Mdot
.65841 .75129 Mdot
.3942 .2042 Mdot
.25036 .37276 Mdot
.72734 .59644 Mdot
.53915 .72155 Mdot
.19293 .47143 Mdot
.15494 .42864 Mdot
.71472 .74782 Mdot
.20852 .40908 Mdot
.44762 .36816 Mdot
.43368 .47045 Mdot
.21737 .35655 Mdot
.55919 .63481 Mdot
.41072 .25693 Mdot
.54619 .61065 Mdot
.70284 .80703 Mdot
.20338 .56198 Mdot
.21251 .60881 Mdot
.54498 .61862 Mdot
.5326 .35754 Mdot
.37942 .31258 Mdot
.54117 .59423 Mdot
.26338 .36147 Mdot
.58311 .20828 Mdot
.53803 .59249 Mdot
.8525 .51558 Mdot
.64744 .28356 Mdot
.34612 .48342 Mdot
.79969 .48513 Mdot
.65393 .30445 Mdot
.39192 .35418 Mdot
.44546 .75924 Mdot
.32101 .28018 Mdot
.43516 .35743 Mdot
.33137 .29727 Mdot
.38266 .27698 Mdot
.6605 .27755 Mdot
.75009 .39681 Mdot
.27694 .32605 Mdot
.71902 .47887 Mdot
.51077 .38558 Mdot
.57951 .78499 Mdot
.31102 .56598 Mdot
.32311 .27087 Mdot
.35388 .51248 Mdot
.55835 .49768 Mdot
.48229 .57725 Mdot
.74435 .58984 Mdot
.44818 .82874 Mdot
.46048 .65164 Mdot
.58512 .32115 Mdot
.6269 .8249 Mdot
.60465 .36972 Mdot
.37685 .81275 Mdot
.72119 .70139 Mdot
.80054 .44547 Mdot
.30995 .62668 Mdot
.31186 .65894 Mdot
.83353 .61462 Mdot
.51825 .40884 Mdot
.36765 .60008 Mdot
.50046 .38327 Mdot
.57295 .31782 Mdot
.24127 .59871 Mdot
.39261 .54752 Mdot
.51426 .56578 Mdot
.4 .45853 Mdot
.51592 .32158 Mdot
.59328 .40987 Mdot
.49311 .55452 Mdot
.50171 .76274 Mdot
.18625 .59012 Mdot
.363 .56024 Mdot
.66674 .81926 Mdot
.70323 .54889 Mdot
.7198 .45023 Mdot
.26576 .28005 Mdot
.70995 .75991 Mdot
.40379 .56251 Mdot
.68832 .20938 Mdot
.58411 .56829 Mdot
.25528 .34428 Mdot
.57945 .35204 Mdot
.68115 .24907 Mdot
.46757 .66454 Mdot
.55241 .68567 Mdot
.37678 .38221 Mdot
.61098 .78599 Mdot
.27711 .51658 Mdot
.53465 .38346 Mdot
.22505 .4025 Mdot
.64378 .32443 Mdot
.46402 .24719 Mdot
.2983 .65027 Mdot
.75431 .48961 Mdot
.74546 .38547 Mdot
.58726 .41209 Mdot
.20254 .59316 Mdot
.68644 .2484 Mdot
.15211 .56262 Mdot
.60766 .62341 Mdot
.38427 .72245 Mdot
.55322 .27134 Mdot
.31028 .31496 Mdot
.55766 .47117 Mdot
.24341 .3024 Mdot
.5542 .73919 Mdot
.54643 .28935 Mdot
.5194 .72998 Mdot
.57278 .49318 Mdot
.47869 .50302 Mdot
.32898 .38867 Mdot
.79452 .62984 Mdot
.54417 .47699 Mdot
.64056 .79829 Mdot
.55694 .48127 Mdot
.23849 .63718 Mdot
.62722 .37323 Mdot
.39972 .51529 Mdot
.74296 .35618 Mdot
.42518 .33358 Mdot
.16228 .54001 Mdot
.25073 .29517 Mdot
.39128 .42063 Mdot
.24214 .5761 Mdot
.38842 .22475 Mdot
.56126 .53264 Mdot
.41468 .47725 Mdot
.60129 .57562 Mdot
.6265 .30791 Mdot
.71476 .76196 Mdot
.2836 .34003 Mdot
.71582 .56979 Mdot
.17346 .52013 Mdot
.15883 .50351 Mdot
.22932 .68623 Mdot
.82089 .40788 Mdot
.53731 .35871 Mdot
.31698 .76973 Mdot
.57182 .62567 Mdot
.16031 .40256 Mdot
.23234 .42244 Mdot
.32974 .20778 Mdot
.75782 .50301 Mdot
.34913 .26512 Mdot
.75615 .64564 Mdot
.44653 .26638 Mdot
.46032 .19388 Mdot
.45171 .44588 Mdot
.29971 .4103 Mdot
.43527 .19448 Mdot
.87401 .46225 Mdot
.58443 .46145 Mdot
.38698 .26938 Mdot
.51803 .2311 Mdot
.31614 .27698 Mdot
.38665 .65509 Mdot
.68437 .54571 Mdot
.25851 .44222 Mdot
.52088 .81343 Mdot
.53065 .68964 Mdot
.4454 .62625 Mdot
.38547 .65185 Mdot
.5413 .7774 Mdot
.5147 .74517 Mdot
.71842 .26842 Mdot
.76083 .49891 Mdot
.52065 .52918 Mdot
.65037 .60773 Mdot
.61551 .39896 Mdot
.45595 .70952 Mdot
.35425 .47305 Mdot
.59907 .56868 Mdot
.38722 .5009 Mdot
.46342 .25301 Mdot
.42961 .8338 Mdot
.38684 .32238 Mdot
.57381 .22142 Mdot
.57192 .30612 Mdot
.36955 .29769 Mdot
.56758 .42657 Mdot
.53275 .82813 Mdot
.37814 .69147 Mdot
.52636 .66643 Mdot
.17577 .48438 Mdot
.31868 .73183 Mdot
.63421 .26934 Mdot
.32113 .74825 Mdot
.44738 .3743 Mdot
.70077 .61242 Mdot
.53284 .24503 Mdot
.2794 .6402 Mdot
.59384 .30004 Mdot
.34599 .26904 Mdot
.35526 .60003 Mdot
.31675 .71651 Mdot
.49061 .18958 Mdot
.63931 .29982 Mdot
.78751 .51199 Mdot
.16088 .46222 Mdot
.34752 .56749 Mdot
.66531 .23423 Mdot
.41281 .25013 Mdot
.37434 .70472 Mdot
.23076 .64039 Mdot
.17471 .58969 Mdot
.44664 .54034 Mdot
.59032 .71457 Mdot
.65791 .52692 Mdot
.75573 .31697 Mdot
.29823 .3321 Mdot
.70659 .50229 Mdot
.32035 .46252 Mdot
.58561 .38311 Mdot
.33431 .42527 Mdot
.51247 .51963 Mdot
.51102 .77721 Mdot
.60545 .38614 Mdot
.81256 .50173 Mdot
.47356 .7016 Mdot
.43307 .53687 Mdot
.68975 .57787 Mdot
.57829 .70392 Mdot
.82815 .47453 Mdot
.64401 .62451 Mdot
.22344 .37742 Mdot
.76368 .48985 Mdot
.61591 .24537 Mdot
.26707 .34271 Mdot
.22942 .4382 Mdot
.47695 .26198 Mdot
.7576 .38214 Mdot
.31294 .48401 Mdot
.62713 .59396 Mdot
.40309 .52292 Mdot
.58417 .39239 Mdot
.36151 .22414 Mdot
.74804 .431 Mdot
.59347 .69499 Mdot
.49137 .44697 Mdot
.59742 .43813 Mdot
.49865 .42823 Mdot
.30558 .23795 Mdot
.44702 .26746 Mdot
.54474 .736 Mdot
.37051 .35509 Mdot
.62624 .70216 Mdot
.71025 .71891 Mdot
.14163 .4868 Mdot
.74251 .68275 Mdot
.45845 .51264 Mdot
.65188 .79375 Mdot
.32332 .33432 Mdot
.39993 .20277 Mdot
.53193 .74361 Mdot
.43618 .56127 Mdot
.47622 .64315 Mdot
.49204 .33923 Mdot
.50894 .46481 Mdot
.48045 .63393 Mdot
.5209 .55888 Mdot
.29216 .47376 Mdot
.35375 .40641 Mdot
.6154 .46938 Mdot
.21415 .5753 Mdot
.16913 .47398 Mdot
.6901 .25684 Mdot
.51597 .42597 Mdot
.40075 .69651 Mdot
.53476 .77037 Mdot
.40011 .15298 Mdot
.5189 .8684 Mdot
.65709 .52813 Mdot
.52257 .42985 Mdot
.57201 .71601 Mdot
.37606 .57353 Mdot
.53608 .55939 Mdot
.55697 .42539 Mdot
.3938 .40765 Mdot
.45349 .61892 Mdot
.33476 .73167 Mdot
.3338 .31326 Mdot
.63 .73446 Mdot
.24689 .48269 Mdot
.42865 .83683 Mdot
.58005 .19499 Mdot
.30237 .32335 Mdot
.34441 .18166 Mdot
.34704 .3893 Mdot
.51863 .32912 Mdot
.6536 .45116 Mdot
.19142 .59467 Mdot
.54432 .67445 Mdot
.55351 .79709 Mdot
.22991 .46002 Mdot
.54484 .74197 Mdot
.60456 .64548 Mdot
.23495 .60983 Mdot
.33396 .43706 Mdot
.46635 .47761 Mdot
.3143 .66167 Mdot
.28249 .7177 Mdot
.79775 .52208 Mdot
.18175 .46878 Mdot
.53344 .81644 Mdot
.85917 .47079 Mdot
.1576 .51765 Mdot
.42752 .61816 Mdot
.39218 .6782 Mdot
.66391 .45379 Mdot
.57745 .65376 Mdot
.66187 .64829 Mdot
.64854 .75811 Mdot
.73013 .37712 Mdot
.28291 .5989 Mdot
.59718 .81401 Mdot
.5199 .7135 Mdot
.65544 .29854 Mdot
.43717 .56148 Mdot
.77244 .47223 Mdot
.24761 .58383 Mdot
.53648 .61794 Mdot
.49762 .60907 Mdot
.57285 .66691 Mdot
.75765 .4794 Mdot
.60104 .25584 Mdot
.38803 .24 Mdot
.8627 .52627 Mdot
.21608 .46081 Mdot
.54581 .82814 Mdot
.68573 .52428 Mdot
.1618 .59293 Mdot
.39194 .24623 Mdot
.22493 .4629 Mdot
.53888 .19746 Mdot
.36739 .47938 Mdot
.5469 .29385 Mdot
.62816 .59419 Mdot
.20379 .43057 Mdot
.77355 .39767 Mdot
.65568 .33644 Mdot
.59567 .7971 Mdot
.5447 .69937 Mdot
.42722 .75344 Mdot
.60257 .68136 Mdot
.65722 .62846 Mdot
.60574 .35241 Mdot
.32971 .78635 Mdot
.44596 .51012 Mdot
.56494 .48308 Mdot
.72541 .52984 Mdot
.75164 .65071 Mdot
.60755 .18209 Mdot
.6337 .63109 Mdot
.29787 .71388 Mdot
.79465 .54926 Mdot
.73306 .6072 Mdot
.54409 .53014 Mdot
.44993 .09643 Mdot
.11581 .44809 Mdot
.54171 .38957 Mdot
.77995 .35487 Mdot
.79797 .54764 Mdot
.18992 .58184 Mdot
.34758 .68471 Mdot
.33926 .47174 Mdot
.73611 .64205 Mdot
.60459 .65696 Mdot
.6942 .59347 Mdot
.50879 .19127 Mdot
.14016 .472 Mdot
.59886 .80085 Mdot
.17162 .51574 Mdot
.68134 .49246 Mdot
.68802 .60587 Mdot
.44946 .12611 Mdot
.20994 .36887 Mdot
.56432 .55385 Mdot
.76139 .64562 Mdot
.55679 .30198 Mdot
.61182 .54193 Mdot
.21628 .51801 Mdot
.77404 .31204 Mdot
.51709 .71365 Mdot
.1817 .56596 Mdot
.58652 .40106 Mdot
.37549 .59365 Mdot
.39682 .41225 Mdot
.44964 .56587 Mdot
.59759 .5892 Mdot
.42585 .40249 Mdot
.74776 .5948 Mdot
.34812 .25936 Mdot
.36728 .3914 Mdot
.72188 .26179 Mdot
.24145 .28412 Mdot
.76109 .44121 Mdot
.48214 .34395 Mdot
.55812 .53984 Mdot
.64982 .29589 Mdot
.57325 .76924 Mdot
.60858 .29314 Mdot
.42138 .19527 Mdot
.14877 .65283 Mdot
.29698 .42443 Mdot
.47278 .76425 Mdot
.61967 .32686 Mdot
.5251 .51796 Mdot
.7861 .46707 Mdot
.42027 .51125 Mdot
.34089 .55963 Mdot
.62321 .48249 Mdot
.64121 .62783 Mdot
.39227 .35813 Mdot
.60857 .8592 Mdot
.68091 .54534 Mdot
.53678 .52816 Mdot
.1616 .40341 Mdot
.57831 .78567 Mdot
.70354 .44617 Mdot
.57367 .54244 Mdot
.47316 .31051 Mdot
.43557 .56127 Mdot
.29527 .28299 Mdot
.42831 .77381 Mdot
.18246 .52655 Mdot
.74576 .42723 Mdot
.79071 .52203 Mdot
.67565 .58243 Mdot
.47107 .65292 Mdot
.40103 .27276 Mdot
.21291 .50062 Mdot
.69613 .50678 Mdot
.147 .43016 Mdot
.35922 .47779 Mdot
.27524 .50143 Mdot
.65816 .63677 Mdot
.24436 .70302 Mdot
.64851 .78403 Mdot
.78931 .4371 Mdot
.51336 .83188 Mdot
.29041 .66466 Mdot
.60962 .74222 Mdot
.33469 .56678 Mdot
.68292 .49681 Mdot
.57624 .4032 Mdot
.4357 .84489 Mdot
.20738 .51303 Mdot
.28176 .4101 Mdot
.31876 .4297 Mdot
.73735 .31306 Mdot
.46039 .23905 Mdot
.31124 .21054 Mdot
.30106 .6657 Mdot
.44154 .8421 Mdot
.6652 .24044 Mdot
.61632 .31246 Mdot
.34646 .28014 Mdot
.68532 .618 Mdot
.37489 .55312 Mdot
.18717 .54134 Mdot
.59783 .614 Mdot
.47441 .80375 Mdot
.59032 .52193 Mdot
.45652 .82015 Mdot
.48791 .63004 Mdot
.23139 .57014 Mdot
.30421 .35628 Mdot
.7159 .71916 Mdot
.34044 .2307 Mdot
.49739 .33188 Mdot
.36736 .18011 Mdot
.33972 .23984 Mdot
.15876 .44115 Mdot
.51318 .80316 Mdot
.75132 .71067 Mdot
.24426 .39754 Mdot
.28063 .32471 Mdot
.33165 .33967 Mdot
.72224 .50048 Mdot
.35336 .71893 Mdot
.63663 .63455 Mdot
.41453 .28189 Mdot
.40797 .43076 Mdot
.32607 .85302 Mdot
.49567 .67457 Mdot
.52234 .36441 Mdot
.32431 .69987 Mdot
.15435 .47721 Mdot
.74361 .53864 Mdot
.4537 .18649 Mdot
.50746 .52189 Mdot
.70945 .58252 Mdot
.74502 .40137 Mdot
.71686 .28147 Mdot
.36749 .73181 Mdot
.83858 .6261 Mdot
.58341 .19957 Mdot
.30709 .45425 Mdot
.48159 .51469 Mdot
.60836 .37105 Mdot
.58201 .42059 Mdot
.31607 .64533 Mdot
.45064 .17657 Mdot
.34868 .26316 Mdot
.21604 .35838 Mdot
.83377 .60901 Mdot
.63424 .24322 Mdot
.18969 .59366 Mdot
.30961 .33679 Mdot
.52639 .36334 Mdot
.41815 .62271 Mdot
.30414 .52688 Mdot
.28451 .39784 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0;3ooooo0_l0002Gooooo`007?ooool00ol0003oooooooooo`2>oooo
o`;o00008?ooool2o`0009Oooooo000Looooo`;o0000Soooool2o`000;Wooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0S_ooool2
o`000;Wooooo000Looooo`03o`000?oooooooooo08kooooo0_l0000Looooo`;o0000Voooool001co
oooo00?o0000ooooooooool0YOooool2o`0000Gooooo0_l0000Dooooo`;o0000QOooool001cooooo
00?o0000ooooooooool0Woooool2o`0000Cooooo0_l0000Kooooo`;o0000QOooool001cooooo00?o
0000ooooooooool0Woooool2o`000:Sooooo000Looooo`03o`000?oooooooooo0;_ooooo0_l0002<
ooooo`007?ooool00ol0003oooooooooo`2kooooo`;o0000S?ooool001cooooo00?o0000oooooooo
ool0`oooool2o`0008Cooooo000Looooo`03o`000?oooooooooo093ooooo0_l000000ooooooo0000
o`00000^ooooo`;o0000Q?ooool001cooooo0_l0001oooooo`;o00004?ooool2o`000003ooooool0
003o00000;Cooooo000Looooo`03o`000?oooooooooo07kooooo0_l0000?ooooo`;o0000^?ooool0
01cooooo00?o0000ooooooooool0Soooool2o`0000Kooooo0_l0002`ooooo`007?ooool00ol0003o
ooooooooo`2Gooooo`;o0000/?ooool001cooooo00?o0000ooooooooool0Uoooool2o`0001;ooooo
0_l0002Looooo`007?ooool00ol0003oooooooooo`27ooooo`;o00006Oooool2o`0000Oooooo0_l0
002Looooo`007?ooool00ol0003oooooooooo`22ooooo`;o00000oooool2o`0000;ooooo0_l0000E
ooooo`;o0000YOooool001cooooo00?o0000ooooooooool0P_ooool2o`0000Oooooo0_l0000Coooo
o`;o00001_ooool2o`0009oooooo000Looooo`03o`000?oooooooooo08[ooooo0ol00002ooooo`;o
00003oooool4o`0000Cooooo1?l0000;ooooo`;o0000T?ooool001cooooo00?o0000ooooooooool0
M?ooool2o`00017ooooo1_l00002ooooo`Co00003?ooool8o`0000?ooooo0_l0000;ooooo`;o0000
00?oooooo`000?l000005oooool2o`0007Cooooo000Looooo`03o`000?oooooooooo06cooooo0_l0
0006ooooo`;o00004Oooool3o`0000Oooooo1?l0000:ooooo`?o000000?oooooo`000?l000001?l0
000Aooooo`;o00001_ooool2o`0000oooooo0_l0001dooooo`007?ooool00ol0003oooooooooo`1/
ooooo`;o00006Oooool2o`000003ooooool0003o000000Cooooo1Ol0000Booooo`;o00002?ooool2
o`0000Wooooo0_l00003ooooo`?o0000QOooool001cooooo00?o0000ooooooooool0Q?ooool2o`00
0003ooooool0003o000000?o00001?ooool2o`0000[ooooo1?l0000Aooooo`;o00002Oooool8o`00
01Kooooo0_l0001]ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5
o`0000Kooooo00?o0000ooooooooool0Q?ooool2o`0000;ooooo0_l00006ooooo`Co00000oooool2
o`0000?ooooo1?l00002ooooo`;o00006Oooool4o`000003ooooool0003o000000Gooooo0ol0000>
ooooo`;o0000KOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo08Gooooo0_l00003ooooo`;o0000
1_ooool2o`0000?ooooo0_l00005ooooo`;o00000_ooool2o`0001Gooooo0_l00009ooooo`;o0000
0oooool3o`00013ooooo0_l0001[ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0K?ooool2o`0000Sooooo1Ol0
000:ooooo`;o000000?oooooo`000?l000000_l0000Oooooo`;o00003?ooool3o`0000;ooooo0_l0
00001?oooooo0000o`000?ooool2o`0001Kooooo0_l0001[ooooo`0000?oooooo`000?ooool00_oo
ool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0001/ooooo`;o00002?oo
ool5o`0000?ooooo0_l00008ooooo`;o00003oooool2o`0000Cooooo0_l000000ooooooo0000o`00
0007ooooo`;o00003?ooool3o`0000;ooooo1Ol0000@ooooo`;o0000M?ooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooo
oooo07Cooooo1?l00002ooooo`So00000_ooool2o`0000;ooooo0_l0000?ooooo`;o00001?ooool2
o`000004ooooool0003o0000o`0001Cooooo0_l00005ooooo`;o000000?oooooo`000?l000003_oo
ool2o`0007Cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`1Wooooo`;o00002oooool4o`0000;ooooo2?l00002
ooooo`;o00000_ooool2o`0000gooooo0_l00007ooooo`;o000000?oooooo`000?l000005Oooool2
o`0000Oooooo0_l00006ooooo`;o00002Oooool2o`000003ooooool0003o000006kooooo00001_oo
ooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`00
0?oooooooooo067ooooo0_l00004ooooo`Co00001Oooool2o`0000;ooooo0_l00004ooooo`Co0000
1?ooool2o`0001?ooooo0_l00007ooooo`;o00004oooool2o`0000?ooooo0_l00007ooooo`;o0000
1_ooool2o`0000Wooooo0_l000001?oooooo0000o`000?ooool2o`0006_ooooo00001_ooooook^k^
oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooo
oooo067ooooo0_l00004ooooo`Co00001Oooool2o`0000?ooooo0_l0000:ooooo`Go00007Oooool3
o`0000?ooooo0_l00006ooooo`;o00000_ooool2o`000003ooooool0003o000000Wooooo0_l00008
ooooo`;o00000oooool2o`0000Sooooo0ol0001Zooooo`007?ooool00ol0003oooooooooo`1Woooo
o`Co00002_ooool2o`0000[ooooo0_l000000ooooooo0000o`00000Booooo`;o00002Oooool3o`00
00?ooooo0_l00006ooooo`;o00001Oooool2o`0001?ooooo0_l00003ooooo`;o00002Oooool2o`00
06[ooooo000Looooo`03o`000?oooooooooo07?ooooo0_l00008ooooo`Ko00005Oooool2o`0000go
oooo1?l000000ooooooo0000o`000009ooooo`;o000000?oooooo`000?l000004oooool2o`0000;o
oooo0_l0001dooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o00002oooool3o`0000Sooooo
1?l0000:ooooo`;o000000?oooooo`000?l000002oooool2o`0000[ooooo1?l000000ooooooo0000
o`000009ooooo`Go00003Oooool2o`0000Cooooo0_l00002ooooo`;o0000M?ooool001cooooo00?o
0000ooooooooool0IOooool2o`0000;ooooo0_l00007ooooo`;o00001_ooool2o`0000Kooooo0_l0
0004ooooo`Go000000?oooooo`000?l000002oooool2o`00013ooooo0_l0000:ooooo`;o00002?oo
ool2o`0000Cooooo0_l00008ooooo`;o0000M?ooool001cooooo00?o0000ooooooooool0IOooool2
o`0000;ooooo1_l00003ooooo`;o00001_ooool3o`0000Gooooo0_l00002ooooo`So00007oooool2
o`0000Kooooo0_l0000<ooooo`;o00001_ooool2o`000003ooooool0003o000000;o000000?ooooo
o`000?l000000_ooool2o`0000Gooooo0_l0001Yooooo`007?ooool00ol0003oooooooooo`1Soooo
o`Co00001?ooool4o`0000_ooooo0ol00002ooooo`?o00001?ooool2o`0000;ooooo1?l00003oooo
o`;o00004_ooool2o`0000kooooo0_l00002ooooo`;o00004?ooool2o`000003ooooool0003o0000
00;o000000?oooooo`000?l000000_ooool2o`0000Gooooo0_l0001Yooooo`007?ooool00ol0003o
ooooooooo`1Rooooo`?o00005Oooool2o`0000?ooooo0ol000000ooooooo0000o`000005ooooo`;o
00001Oooool2o`000003ooooool0003o000000;ooooo0_l0000;ooooo`;o00001?ooool3o`0000_o
oooo0ol00002ooooo`;o00004?ooool2o`0000;ooooo0_l00004ooooo`;o00003Oooool2o`0005ko
oooo000Looooo`03o`000?oooooooooo05Wooooo0_l00005ooooo`Co00001oooool2o`0000gooooo
1?l000000ooooooo0000o`000002ooooo`;o00000oooool2o`0000Sooooo1?l00002ooooo`?o0000
4?ooool3o`0000?ooooo0_l00007ooooo`;o00000_ooool2o`00013ooooo0_l00002ooooo`;o0000
1?ooool2o`0000gooooo0_l0001Nooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o00001Ooo
ool2o`0000Wooooo0_l0000=ooooo`Co000000?oooooo`000?l000000_l00005ooooo`;o00002?oo
ool2o`0000Cooooo1Ol000000ooooooo0000o`000002ooooo`;o00003?ooool5o`0000cooooo0_l0
000:ooooo`;o00001Oooool2o`0000_ooooo0_l00002ooooo`;o0000H_ooool001cooooo00?o0000
ooooooooool0Goooool2o`0000Wooooo0_l00008ooooo`;o00000_ooool6o`000003ooooool0003o
000000Co00001oooool2o`0000gooooo0_l000000ooooooo0000o`000002ooooo`;o00001Oooool2
o`0000Gooooo1Ol0000<ooooo`Go00001?ooool2o`000004ooooool0003o0000o`0000Cooooo0_l0
0003ooooo`;o00001_ooool2o`0000;ooooo0_l0001Rooooo`007?ooool00ol0003oooooooooo`1O
ooooo`;o00002Oooool2o`0000Sooooo0_l00002ooooo`;o00000_ooool2o`0000Gooooo0_l00007
ooooo`;o00001Oooool2o`0000Wooooo0_l000000ooooooo0000o`000006ooooo`;o00001oooool2
o`0000Kooooo0_l00003ooooo`?o000000?oooooo`000?l000000_l00003ooooo`So00000_ooool3
o`0000;ooooo1?l0000>ooooo`;o00001?ooool2o`0005Kooooo000Looooo`;o0000HOooool3o`00
01Sooooo0_l00005ooooo`;o00000oooool2o`0000[ooooo0_l00006ooooo`;o000000?oooooo`00
0?l000000ol0000Gooooo`So00000oooool2o`0000Cooooo0ol00002ooooo`;o00000oooool2o`00
00;ooooo1?l0000>ooooo`;o00001?ooool2o`0005Kooooo000Looooo`03o`000?oooooooooo05co
oooo0_l00002ooooo`?o00001oooool2o`0000Kooooo0_l00007ooooo`;o00001Oooool2o`0000?o
oooo0_l0000:ooooo`;o00001_ooool2o`0000?ooooo0ol0000Hooooo`Co00001_ooool2o`000003
ooooool0003o000000;ooooo0_l0001kooooo`007?ooool00ol0003oooooooooo`1Looooo`;o0000
3?ooool2o`0000Kooooo0_l00008ooooo`;o00001?ooool3o`0000?ooooo0ol00008ooooo`;o0000
1_ooool2o`0002;ooooo0_l00004ooooo`;o000000?oooooo`000?l000004_ooool2o`0000cooooo
0ol0001Looooo`007?ooool00ol0003oooooooooo`1]ooooo`;o00001Oooool2o`0000Kooooo0_l0
0004ooooo`?o00000oooool3o`0000?ooooo0_l00006ooooo`Go000000?oooooo`000?l000001_oo
ool2o`0000Kooooo0_l0000Aooooo`;o00006oooool2o`0000cooooo0ol0001Looooo`007?ooool0
0ol0003oooooooooo`1Nooooo`;o00003?ooool4o`0000Cooooo0_l00006ooooo`;o00004?ooool2
o`0000Kooooo1Ol000000ooooooo0000o`000006ooooo`;o00001Oooool3o`00013ooooo0ol0000P
ooooo`;o00001?ooool2o`00063ooooo000Looooo`03o`000?oooooooooo05kooooo0_l0000<oooo
o`Co00003?ooool2o`0000oooooo0_l00008ooooo`Co00004?ooool3o`0000kooooo1?l00009oooo
o`;o00005Oooool3o`0000Cooooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`1Fooooo`;o
00003Oooool3o`0000Gooooo0ol0000:ooooo`;o00004Oooool2o`000004ooooool0003o0000oooo
o`;o00001?ooool2o`0000gooooo0_l00002ooooo`;o00002Oooool2o`0000?ooooo0_l000000ooo
oooo0000o`000002o`0000Kooooo0ol0000Dooooo`;o00000oooool3o`00067ooooo000Looooo`03
o`000?oooooooooo05Kooooo1?l0000;ooooo`?o00001Oooool2o`0000Wooooo1_l000000ooooooo
0000o`00000?ooooo`;o000000?oooooo`000?l000004oooool2o`0000;ooooo0_l00002ooooo`;o
00001Oooool2o`000003ooooool0003o000000?ooooo1Ol00006ooooo`;o00006Oooool3o`00067o
oooo000Looooo`03o`000?oooooooooo05Sooooo0_l000000ooooooo0000o`000006ooooo`;o0000
0oooool2o`0000Oooooo0_l00002ooooo`;o000000?oooooo`000?l000001?l000000ooooooo0000
o`000003ooooo`;o00009_ooool2o`0000;ooooo0_l00008ooooo`;o00001_ooool2o`0000Cooooo
0_l0001oooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00001_ooool2o`0000Kooooo0_l0
0003ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`?o000000?oooooo`000?l000000ol0
0006ooooo`;o00006oooool2o`0000_ooooo0_l0000Hooooo`?o00002?ooool2o`0000kooooo0_l0
001Tooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00001oooool2o`0000Oooooo0_l00006
ooooo`;o00001oooool2o`0000Oooooo0_l00002ooooo`;o00007?ooool2o`0000_ooooo0_l0000I
ooooo`;o00002?ooool2o`0000kooooo1?l0001Rooooo`007?ooool00ol0003oooooooooo`1;oooo
o`;o00001Oooool3o`0000Oooooo0_l00007ooooo`Co00005_ooool2o`0000;ooooo1?l0000Coooo
o`;o0000;?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000Booooo`Co0000H_ooool001co
oooo00?o0000ooooooooool0Boooool2o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o
00003_ooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000Cooooo0_l00009ooooo`;o
00004Oooool4o`0000Oooooo0_l00004ooooo`;o00000oooool2o`0000Sooooo0_l0000>ooooo`;o
00000_ooool2o`000003ooooool0003o000000;ooooo1?l00009ooooo`;o00005Oooool2o`00053o
oooo000Looooo`03o`000?oooooooooo04oooooo0_l00006ooooo`;o00003_ooool2o`0000;ooooo
0_l00003ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o00006_ooool5o`0000So
oooo0_l00004ooooo`;o00000oooool2o`0000Sooooo0_l00002ooooo`;o00005Oooool4o`0000Wo
oooo0_l0000Eooooo`;o0000D?ooool001cooooo00?o0000ooooooooool0C_ooool2o`0001Cooooo
0_l00003ooooo`;o00001oooool2o`0000?ooooo0_l00004ooooo`;o00005oooool2o`000003oooo
ool0003o000000Kooooo0_l00006ooooo`;o00000oooool2o`0000cooooo0_l00004ooooo`;o0000
5?ooool2o`0006oooooo000Looooo`03o`000?oooooooooo04kooooo0_l000001?oooooo0000o`00
0?l0000?ooooo`?o00000_ooool7o`0000?ooooo1?l00007ooooo`;o00001Oooool2o`0001_ooooo
0_l00006ooooo`;o00000oooool2o`0001;ooooo0_l00004ooooo`?o00001?ooool4o`0000Gooooo
0_l00006ooooo`;o00000oooool4o`00063ooooo000Looooo`;o0000D_ooool5o`0000gooooo0_l0
0003ooooo`Oo00000oooool4o`0000Kooooo0_l00006ooooo`?o00001?ooool2o`0001Cooooo0_l0
000>ooooo`;o00001?ooool4o`0000;ooooo0_l00004ooooo`;o00000oooool6o`000003ooooool0
003o000000Go00002_ooool2o`0000?ooooo1?l0001Pooooo`007?ooool00ol0003oooooooooo`1;
ooooo`;o00000oooool2o`0000;ooooo0_l0000Gooooo`;o00003Oooool2o`0000Kooooo0ol00004
ooooo`Co000000?oooooo`000?l000003oooool4o`0000cooooo0_l00004ooooo`Co00000_ooool2
o`000004ooooool0003o0000ooooo`Co00000oooool4o`0000?ooooo1Ol0001cooooo`007?ooool0
0ol0003oooooooooo`1;ooooo`;o00000oooool3o`0000[ooooo0_l0000Fooooo`;o00003_ooool2
o`0000Kooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00002_ooool4o`0000Oooooo1?l0
00000ooooooo0000o`000002o`000003ooooool0003o000000;o00001_ooool2o`0000?ooooo0_l0
000:ooooo`Go00008oooool2o`0004kooooo000Looooo`03o`000?oooooooooo04gooooo0_l00002
ooooo`;o00001_ooool2o`0000;ooooo0_l0000Fooooo`;o00003_ooool2o`0000[ooooo1ol00000
0ooooooo0000o`000003ooooo`Oo00000_ooool2o`000003ooooool0003o000000Co00000_ooool3
o`000004ooooool0003o0000o`0000cooooo0_l000000ooooooo0000o`000009ooooo`?o00005_oo
ool2o`0000_ooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00002_ooool2
o`0000_ooooo1Ol00009ooooo`Ko00001oooool2o`00013ooooo0_l000000ooooooo0000o`000005
o`000005ooooool0003o0000o`000?ooool00ol00002ooooo`;o000000?oooooo`000?l000001?l0
0003ooooo`Ko000000?oooooo`000?l000000_ooool2o`0000Cooooo0ol000000ooooooo0000o`00
000;ooooo`;o00005Oooool2o`0000Oooooo0_l000000ooooooo0000o`00001?ooooo`007?ooool0
0ol0003oooooooooo`1Looooo`Co000000?oooooo`000?l000000oooool5o`0000Wooooo1_l00003
ooooo`;o00000_ooool2o`0000;ooooo0_l00008ooooo`;o00000_ooool2o`0000?ooooo1Ol00000
0ooooooo0000o`000002ooooo`?o00000_ooool2o`000003ooooool0003o000000Co000000?ooooo
o`000?l000001_l000000ooooooo0000o`000004o`0000;ooooo1?l00008ooooo`;o00001Oooool2
o`00017ooooo0_l00002ooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`Co0000COoo
ool001cooooo00?o0000ooooooooool0@Oooool2o`0000Gooooo1?l0000@ooooo`Co000000?ooooo
o`000?l000006Oooool3o`0000Kooooo0_l00008ooooo`;o00002Oooool2o`0000Kooooo0ol00005
ooooo`;o00001OoooolEo`0000Sooooo0_l0000Hooooo`;o00002?ooool2o`000003ooooool0003o
000000;ooooo0ol00002ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0@Oooool2o`00
00Gooooo1?l00007ooooo`;o00003oooool2o`0001Cooooo1?l0000Tooooo`Co00001oooool2o`00
00;ooooo5_l0000^ooooo`;o00000_ooool2o`0000?ooooo0_l00019ooooo`007?ooool00ol0003o
ooooooooo`14ooooo`;o00000oooool3o`0000Gooooo2?l00005ooooo`;o00001?ooool2o`0000go
oooo0_l00002ooooo`;o000000?oooooo`000?l000001Oooool2o`0000gooooo0_l00005ooooo`;o
00002Oooool4o`0000Kooooo6?l000000ooooooo0000o`000006ooooo`;o00007Oooool2o`0000[o
oooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00002oooool2o`0000;ooooo
1?l00005ooooo`;o00004oooool2o`0000;ooooo0_l00007ooooo`?o00002?ooool3o`0000;ooooo
0_l00005ooooo`;o00003?ooool2o`0000Gooooo5?l000000ooooooo0000o`000002o`000004oooo
ool0003o0000o`0000Cooooo0_l00003ooooo`;o000000?oooooo`000?l000005Oooool2o`0000Go
oooo0_l00003ooooo`;o0000Coooool001cooooo00?o0000ooooooooool0A?ooool2o`0001Oooooo
0_l0000;ooooo`;o00001oooool2o`0000_ooooo0_l00003ooooo`;o00001?ooool4o`000003oooo
ool0003o000000cooooo0_l00005ooooo`;o000000?oooooo`000?l000000_l00002ooooo`Oo0000
00?oooooo`000?l000002?l000000ooooooo0000o`000002o`000004ooooool0003o0000o`0000Co
oooo0_l00003ooooo`;o000000?oooooo`000?l000007?ooool2o`0000?ooooo1?l0001=ooooo`00
7?ooool00ol0003oooooooooo`14ooooo`;o00003_ooool2o`0000Oooooo1?l00004ooooo`?o0000
00Coooooo`000?l0003o00000oooool2o`0000Cooooo0_l000000ooooooo0000o`00000;ooooo`?o
00000oooool4o`0000oooooo0_l00008ooooo`Co000000?oooooo`000?l000005ol00003ooooo`;o
00008oooool2o`0000Sooooo1?l0001=ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o0000
3_ooool2o`000003ooooool0003o000000Kooooo1?l00002ooooo`Oo000000?oooooo`000?l00000
0_l00004ooooo`Go00001_ooool2o`0000Cooooo2_l0000;ooooo`;o00002?ooool2o`000004oooo
ool0003o0000ooooo`Ko000000?oooooo`000?l000004_l00003ooooo`;o00001_ooool2o`0001_o
oooo0_l00005ooooo`;o00000oooool4o`0004_ooooo000Looooo`03o`000?oooooooooo043ooooo
0ol0000Dooooo`Co00001_ooool3o`000003ooooool0003o000000Go000000?oooooo`000?l00000
0_ooool4o`0000;ooooo0ol00006ooooo`;o00001_ooool3o`000003ooooool0003o000000;o0000
2oooool3o`0000Oooooo1Ol000000ooooooo0000o`00000Do`000003ooooool0003o000000Kooooo
0_l00005ooooo`;o00007_ooool2o`0000;ooooo0_l00003ooooo`Co0000Boooool001cooooo00?o
0000ooooooooool0@?ooool3o`0000cooooo0_l00002ooooo`;o00000oooool3o`0000Gooooo2_l0
0007ooooo`Co00001oooool2o`000003ooooool0003o000001Sooooo0_l000000ooooooo0000o`00
0007ooooo`Go000000?oooooo`000?l000006_l00003ooooo`?o00008_ooool5o`0000Kooooo0_l0
001=ooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00002_ooool2o`0000;ooooo0_l00003
ooooo`;o00001_ooool2o`0000;ooooo1Ol0000Cooooo`Go000000?oooooo`000?l000000_ooool2
o`0000Wooooo0_l00006ooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`;o000000?o
ooooo`000?l000000_oooolKo`0000Cooooo0_l0000Mooooo`;o000000?oooooo`000?l000000_l0
00000ooooooo0000o`000003ooooo`;o00001Oooool2o`0004Wooooo000Looooo`;o0000=oooool2
o`0000Kooooo0ol00002ooooo`;o00001oooool2o`0001;ooooo0_l00003ooooo`;o00005oooool2
o`0000;ooooo1ol00008ooooo`;o00003?ooool2o`000003ooooool0003o000000Cooooo2Ol00002
oooooaCo00008oooool2o`000003ooooool0003o000000Sooooo0_l00005ooooo`;o000000?ooooo
o`000?l00000A_ooool001cooooo00?o0000ooooooooool0=_ooool2o`0000Kooooo1Ol00008oooo
o`?o000000?oooooo`000?l000000_ooool2o`0001oooooo0_l00008ooooo`;o00001?ooool5o`00
0003ooooool0003o000001[ooooo3Ol000001Ooooooo0000o`000?l0003ooooo00go00000_ooool2
o`0000gooooo0_l0000Mooooo`Co00002?ooool2o`0004Kooooo000Looooo`03o`000?oooooooooo
03kooooo0_l000000ooooooo0000o`000002o`0000Kooooo0_l00002ooooo`;o00000_ooool2o`00
00[ooooo0_l0000?ooooo`;o00000_ooool3o`000004ooooool0003o0000ooooo`Ko000000?ooooo
o`000?l000002Ol0000Iooooo`;o00000ooooolJo`0000;ooooo0ol0000<ooooo`;o00005_ooool2
o`0000Gooooo1?l000000ooooooo0000o`000003ooooo`;o00001?ooool2o`0004;ooooo000Loooo
o`03o`000?oooooooooo04;ooooo0ol0000Jooooo`;o00002_ooool4o`000003ooooool0003o0000
00?ooooo6Ol0000Cooooo`;o00001OoooolTo`0000?ooooo1?l0000Jooooo`?o00002_ooool2o`00
00?ooooo0_l00004ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0@_ooool2o`0000Co
oooo0_l00008ooooo`;o00001Oooool5o`0000Sooooo0_l00003ooooo`Co00001ooooolHo`0000Wo
oooo0_l00007ooooo`?o00001OoooolPo`0000;ooooo0_l000000ooooooo0000o`000004o`0001[o
oooo0_l0000>ooooo`;o00004oooool2o`0003Gooooo000Looooo`03o`000?oooooooooo04Sooooo
0_l00008ooooo`;o00001Oooool5o`0000Sooooo0_l0000:ooooo`;o00000oooool3o`000003oooo
ool0003o0000017o00000_ooool2o`0000Gooooo0_l00005ooooo`Co00001?oooolRo`0000Gooooo
0_l000001?oooooo0000o`000?l00003ooooo`;o00004_ooool2o`00017ooooo0_l0000Cooooo`;o
0000=Oooool001cooooo00?o0000ooooooooool0??ooool2o`0000;ooooo0_l00006ooooo`;o0000
6oooool3o`0000[ooooo1?l00002oooooa[o00003?ooool2o`0000Kooooo8Ol00009ooooo`?o0000
0oooool2o`0001;ooooo0_l0000<ooooo`;o00003oooool2o`0003kooooo000Looooo`03o`000?oo
oooooooo03cooooo0_l00002ooooo`;o00008oooool3o`0000cooooo0_l00002oooooaWo00004?oo
ool2o`0000?ooooo0_l00003oooooaGo000000?oooooo`000?l000000ol000000ooooooo0000o`00
000Zooooo`;o00000oooool2o`0000oooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0h
ooooo`;o000000?oooooo`000?l000004Oooool2o`0000?ooooo0_l0000@ooooo`;o000000?ooooo
o`000?l000001Oooool2o`0000?ooooo1?l000000ooooooo0000o`00000Fo`0000Oooooo0_l00007
ooooo`;o00000oooool4o`000003ooooool0003o000000go000000?oooooo`000?l000002Ol00000
1?oooooo0000o`000?l0000<ooooo`;o00006oooool2o`0000;ooooo1?l0000>ooooo`;o0000?_oo
ool001cooooo00?o0000ooooooooool0=Oooool2o`000004ooooool0003o0000ooooo`;o00002?oo
ool2o`0000Oooooo0_l00003ooooo`;o00001oooool2o`0000Wooooo0ol00005ooooo`;o00000_oo
ool5o`000003ooooool0003o000001Oo00001_ooool4o`0000cooooo7Ol00002ooooo`?o00003?oo
ool2o`00017ooooo0_l0000<ooooo`Co00002?ooool3o`0004?ooooo000Looooo`03o`000?oooooo
oooo03Gooooo0_l00004ooooo`;o00002?ooool2o`0001Cooooo0ol00009ooooo`;o00002_ooool3
o`0000;ooooo7?l00006ooooo`?o00001_ooool2o`0000?ooooo6?l000000ooooooo0000o`000002
o`0000;ooooo0_l0000Pooooo`;o00001_ooool2o`0000Cooooo0_l00006ooooo`;o00000_ooool3
o`0004?ooooo000Looooo`03o`000?oooooooooo03Kooooo0ol0000Rooooo`;o00005_ooool3o`00
0003ooooool0003o000001go00001Oooool2o`0000;ooooo0_l00002ooooo`;o00000_ooool@o`00
0003ooooool0003o000000Go000000Coooooo`000?l0003o00001Oooool2o`0002Oooooo0ol0000;
ooooo`;o00000_ooool2o`0000;ooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0foooo
o`?o00008_ooool2o`0001[ooooo6ol00002ooooo`;o00002Oooool2o`000003ooooool0003o0000
00?ooooo2?l000000ooooooo0000o`00000Ao`0000Gooooo0_l0000Qooooo`Go00000_ooool2o`00
0003ooooool0003o0000013ooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0aooooo`;o
00007_ooool2o`0000Sooooo0ol00009ooooo`;o00001?ooool2o`0000Sooooo6_l00003ooooo`;o
00002_ooool4o`0000Cooooo1_l000000ooooooo0000o`00000Bo`0000?ooooo1?l00008ooooo`;o
00001Oooool2o`00013ooooo1Ol00005ooooo`?o0000DOooool00006ooooooo^k^ko<S8bo`000?lb
<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo
037ooooo0ol0000Aooooo`;o000000?oooooo`000?l000001oooool2o`0000Oooooo1?l00005oooo
o`;o00000_ooool2o`0000Cooooo0ol00004ooooo`;o00000_oooolJo`0000kooooo0_l00006oooo
o`Ko000000?oooooo`000?l000004?l000000ooooooo0000o`000002ooooo`Co00002?ooool2o`00
00Gooooo0_l0000Kooooo`;o00001?ooool2o`0004_ooooo00001_ooooooMgMgoiRHV?ooooooV9RH
ogMgM`Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<?ooool4
o`0000oooooo1?l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000?o00001ooo
ool3o`0000Kooooo0_l00009ooooo`;o00001?ooool2o`000003ooooool0003o000001_o00005Ooo
ool3o`000003ooooool0003o0000017o00000_ooool4o`0002Wooooo0ol0000:ooooo`;o0000Booo
ool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo00?o0000
ooooooooool0<?ooool2o`00017ooooo0_l00006ooooo`Oo00001oooool4o`0000Kooooo0_l0000B
ooooo`Wo000000?oooooo`000?l000004Ol00004ooooo`;o00002?ooool2o`0000Wooooo1Ol00000
0ooooooo0000o`00000:o`0000Gooooo0_l00002ooooo`;o00001?ooool3o`0000Kooooo0_l0000F
ooooo`?o00001Oooool2o`00053ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`00033ooooo0_l00003ooooo`;o00003_ooool2
o`0000Gooooo1?l00008ooooo`?o00002?ooool2o`0000[ooooo0_l00007oooooaOo000000?ooooo
o`000?l000000oooool2o`000003ooooool0003o000000Sooooo0_l00009ooooo`Co000000Gooooo
o`000?l0003o0000ooooo`09o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o00001?oo
ool3o`0000Kooooo0_l0000Eooooo`;o00001oooool2o`0000Gooooo0_l000000ooooooo0000o`00
0016ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGo
ooooo`0000Oooooo00?o0000ooooooooool0<?ooool3o`0000;ooooo1?l00002ooooo`;o000000?o
ooooo`000?l000001Oooool2o`0000Oooooo0_l00005ooooo`;o000000?oooooo`000?l000005Ooo
ool2o`0000Oooooo6_l00003ooooo`;o00001oooool3o`000004ooooool0003o0000ooooo`Co0000
1?ooool4o`000003ooooool0003o000000?ooooo0_l00002ooooo`?o00000_ooool2o`0000Oooooo
0_l0000Sooooo`;o00001Oooool2o`0000Oooooo0_l000001?oooooo0000o`000?l00002ooooo`;o
0000@Oooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00omgMgOoc<c<
o`000007ooooo`03o`000?oooooooooo02gooooo0_l00002ooooo`;o00000oooool4o`000003oooo
ool0003o000000Go00004oooool2o`000004ooooool0003o0000ooooo`;o00000oooool3o`0000co
oooo0_l00009oooooaSo00001_ooool2o`0000Cooooo0ol00004ooooo`Co00002?ooool2o`0000;o
oooo0ol000000ooooooo0000o`000005ooooo`;o00001oooool2o`0000cooooo0_l00002ooooo`;o
00006?ooool2o`0000Kooooo0_l00003ooooo`;o00000_ooool3o`00043ooooo00001_ooooooMgMg
oiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0]oooo
o`;o00001oooool4o`0000?ooooo0_l000000ooooooo0000o`000008ooooo`;o00001oooool2o`00
00?ooooo0_l000001?oooooo0000o`000?ooool5o`0000Wooooo0_l0000=oooooaSo00001Oooool2
o`0000[ooooo0ol0000:ooooo`;o00000_ooool>o`0001Cooooo0_l00002ooooo`?o00003?ooool2
o`00017ooooo0ol00007ooooo`;o0000@?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Ooo
ool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo02_ooooo0_l0000Cooooo`;o00002?oo
ool2o`0000Oooooo0_l00003ooooo`;o00001?ooool3o`0000_ooooo0_l0000=oooooaSo00004Ooo
ool2o`00017ooooo3?l00005ooooo`;o00000oooool2o`0000[ooooo0_l000000ooooooo0000o`00
000<ooooo`;o00004Oooool3o`0000Cooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`0[
ooooo`;o00008?ooool2o`0000?ooooo0_l000000ooooooo0000o`00000ToooooaKo00000_ooool2
o`0000kooooo0_l0000<ooooo`?o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00000oooool2
o`0000[ooooo0_l0000Yooooo`;o00001oooool2o`0003[ooooo000Looooo`03o`000?oooooooooo
04gooooo0_l00003ooooo`;o000000?oooooo`000?l000001_ooool2o`0001cooooo5_l00002oooo
o`;o00003_ooool2o`000003ooooool0003o000000Wooooo0ol00005ooooo`;o00004Oooool2o`00
00_ooooo0_l00003ooooo`;o00004oooool2o`0000Sooooo0_l0000>ooooo`;o0000>_ooool001co
oooo00?o0000ooooooooool0=?ooool6o`0000Gooooo0_l00007ooooo`;o00002oooool3o`0000Go
oooo0_l0000Booooo`;o00000_ooool4o`0000;ooooo0_l000000ooooooo0000o`00000@o`0001?o
oooo0_l000000ooooooo0000o`00000:ooooo`?o00000_ooool4o`00017ooooo0_l0000;ooooo`;o
000000?oooooo`000?l000000_l0000=ooooo`?o00000oooool2o`0000Cooooo0_l00002ooooo`;o
00002_ooool2o`0003kooooo000Looooo`03o`000?oooooooooo03?ooooo1ol00005ooooo`;o0000
1oooool2o`0000Gooooo0ol000000ooooooo0000o`000003o`0000Gooooo0_l00003ooooo`Go0000
0_ooool2o`0000Kooooo0_l00002ooooo`Co00001Oooool<o`000003ooooool0003o000000?o0000
5?ooool2o`0000Cooooo1Ol00002ooooo`So00001?ooool2o`000003ooooool0003o000000Gooooo
0_l0000Cooooo`Co00003Oooool3o`0000Wooooo0_l0000=ooooo`?o00002Oooool2o`0003?ooooo
000Looooo`03o`000?oooooooooo02cooooo0_l000000ooooooo0000o`000002ooooo`;o00000ooo
ool3o`0000?ooooo0_l000000ooooooo0000o`00000<ooooo`?o000000?oooooo`000?l000000_l0
000:ooooo`Ko00000_ooool2o`0000kooooo0_l00002ooooo`;o00000_ooool4o`000003ooooool0
003o000000?o00001oooool2o`0000Gooooo0_l00003ooooo`;o00001?ooool4o`0000;ooooo1Ol0
0002ooooo`;o00000_ooool2o`0000Kooooo0_l000000ooooooo0000o`000005ooooo`;o00002Ooo
ool2o`0000Oooooo1Ol0000>ooooo`?o00001?ooool2o`0000[ooooo0_l00005ooooo`;o00001_oo
ool2o`0000;ooooo0_l0000cooooo`007?ooool00ol0003oooooooooo`0Wooooo`;o00000oooool2
o`000003ooooool0003o000000Oooooo0ol00003ooooo`;o000000?oooooo`000?l000001?ooool2
o`0000Wooooo1Ol0000:ooooo`;o000000?oooooo`000?l000001Oooool2o`0000cooooo0_l00002
ooooo`;o00000_ooool2o`0000Cooooo1?l000000ooooooo0000o`000004ooooo`;o00001Oooool2
o`0000?ooooo0_l000001?oooooo0000o`000?ooool4o`0000gooooo0_l0000Kooooo`;o00001ooo
ool2o`0001;ooooo0_l00004ooooo`;o000000?oooooo`000?l000001oooool2o`0000?ooooo0_l0
0008ooooo`;o0000=oooool001cooooo00?o0000ooooooooool09oooool2o`0001;ooooo0_l00006
ooooo`;o00000_ooool2o`0000Sooooo0ol000000ooooooo0000o`000006ooooo`;o00002?ooool6
o`0001Wooooo0_l00004ooooo`;o00004oooool2o`000003ooooool0003o000002Cooooo0_l0000F
ooooo`;o00001oooool2o`0000_ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00011
ooooo`007?ooool00ol0003oooooooooo`0Vooooo`?o00002?ooool2o`0000Sooooo0_l00004oooo
o`Co00000_ooool2o`0000Sooooo1?l00008ooooo`;o00002?ooool6o`0000?ooooo0_l00009oooo
o`;o00001?ooool2o`0000?ooooo0_l00003ooooo`;o00001?ooool2o`0000_ooooo0_l00002oooo
o`Co00005?ooool2o`0000;ooooo0_l0000:ooooo`Go00004oooool2o`0000Oooooo0_l0000@oooo
o`;o00000_ooool2o`0004Kooooo000Looooo`03o`000?oooooooooo02Kooooo0_l00008ooooo`?o
00003_ooool2o`0000Cooooo0_l00007ooooo`;o000000?oooooo`000?l000000_l0000Iooooo`;o
00001oooool4o`0000Cooooo0_l00008ooooo`;o00001?ooool2o`0000_ooooo0_l00002ooooo`;o
00001Oooool2o`0000kooooo0ol00002ooooo`;o00003?ooool3o`0001kooooo2?l00005ooooo`Co
00003Oooool2o`0003cooooo000Looooo`03o`000?oooooooooo02Oooooo0_l00002ooooo`;o0000
0oooool2o`0001?ooooo0ol00008ooooo`;o00000oooool2o`0000[ooooo0_l000000ooooooo0000
o`00000Cooooo`Co00004_ooool2o`0000gooooo0_l00006ooooo`;o000000?oooooo`000?l00000
3_ooool2o`00017ooooo0_l0000Cooooo`;o00002_ooool8o`0000;ooooo0_l000000ooooooo0000
o`000002o`0000;ooooo0_l00009ooooo`;o0000??ooool001cooooo00?o0000ooooooooool08_oo
ool2o`0000;ooooo0ol00002ooooo`;o00003?ooool2o`0000[ooooo1?l00007ooooo`;o00003Ooo
ool4o`000003ooooool0003o000000kooooo0_l00005ooooo`;o00004_ooool2o`0000_ooooo1?l0
0006ooooo`;o000000?oooooo`000?l000009oooool2o`0000Gooooo0_l000000ooooooo0000o`00
0003ooooo`;o00005?ooool2o`0000Oooooo0_l00017ooooo`007?ooool2o`0002?ooooo0_l00002
ooooo`;o00002Oooool2o`0000Kooooo0_l0000<ooooo`;o00001oooool4o`0000_ooooo0_l0000C
ooooo`;o00001?ooool2o`0001Sooooo0_l00006ooooo`Co00001Oooool2o`0000;ooooo0_l0000U
ooooo`Co00001Oooool2o`000003ooooool0003o000000Sooooo0_l000000ooooooo0000o`00000E
ooooo`;o00001Oooool2o`00043ooooo000Looooo`03o`000?oooooooooo02Kooooo0_l00009oooo
o`;o00003Oooool2o`0000kooooo1?l0000<ooooo`;o00002?ooool2o`0000Oooooo0_l00005oooo
o`;o00006?ooool2o`000004ooooool0003o0000o`0000Cooooo0_l00004ooooo`?o00001?ooool2
o`0000Wooooo0_l0000Hooooo`?o000000?oooooo`000?l000001_ooool2o`0000Sooooo0_l00000
0ooooooo0000o`00000Looooo`;o0000@?ooool001cooooo00?o0000ooooooooool0;oooool2o`00
00oooooo0_l0000>ooooo`?o000000?oooooo`000?l000002_ooool2o`0000Cooooo0_l00002oooo
o`?o00001_ooool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`00000Goooo
o`?o00002_ooool3o`0000Cooooo0_l00005ooooo`;o00000_ooool2o`0001Cooooo0_l00006oooo
o`;o00001_ooool2o`0001oooooo0_l00006ooooo`;o0000@_ooool001cooooo00?o0000oooooooo
ool0;oooool2o`00017ooooo0_l00003ooooo`;o00000_ooool2o`0000Oooooo0_l0000@ooooo`Co
000000?oooooo`000?l000000_ooool2o`0000Gooooo1?l000001?oooooo0000o`000?ooool4o`00
00[ooooo0_l00008ooooo`;o00003Oooool2o`0000_ooooo0_l00006ooooo`;o00003?ooool2o`00
00;ooooo0_l00009ooooo`;o00004Oooool2o`00017ooooo0_l00006ooooo`;o0000@_ooool001co
oooo00?o0000ooooooooool07_ooool2o`0000Kooooo0_l00007ooooo`Co00001?ooool2o`0000Wo
oooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00004ooooo`;o00004Oooool2o`0000;o
oooo0ol00004ooooo`;o00001?ooool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo
0000o`000009ooooo`?o00002?ooool2o`0000[ooooo1Ol0000Cooooo`;o00002oooool3o`0000go
oooo0ol0000?ooooo`?o00004oooool2o`0000Oooooo0_l0000>ooooo`;o0000;oooool001cooooo
00?o0000ooooooooool07_ooool2o`0000Kooooo0_l000000ooooooo0000o`000004ooooo`Co0000
1?ooool2o`0000cooooo1?l00008ooooo`;o00002_ooool2o`0000?ooooo1?l00003ooooo`;o0000
2_ooool2o`000003ooooool0003o000000?ooooo0_l00006ooooo`;o00001?ooool2o`0001Gooooo
1?l0000Booooo`;o00003?ooool3o`0000Gooooo0ol00007ooooo`;o00003oooool3o`00013ooooo
0_l000000ooooooo0000o`000007ooooo`;o00003_ooool2o`0002oooooo000Looooo`03o`000?oo
oooooooo02Wooooo0_l00004ooooo`;o00001_ooool2o`0000kooooo0_l00006ooooo`;o00003?oo
ool2o`0000?ooooo0_l0000=ooooo`;o00001Oooool2o`0000[ooooo0ol00002ooooo`;o00000_oo
ool2o`0001;ooooo1Ol0000Booooo`;o000000?oooooo`000?l000001oooool4o`0000?ooooo0_l0
00001?oooooo0000o`000?l00002ooooo`;o00001_ooool2o`0000gooooo0_l0000@ooooo`;o0000
1Oooool2o`0000kooooo0_l0000dooooo`007?ooool00ol0003oooooooooo`0Zooooo`;o00000ooo
ool2o`0000;ooooo0_l00002ooooo`;o00000_ooool2o`0000Sooooo0_l00003ooooo`;o00000ooo
ool2o`000003ooooool0003o000000;o00001Oooool2o`0000Sooooo0_l00003ooooo`;o00000ooo
ool4o`0000;ooooo0_l00004ooooo`;o00001_ooool4o`0000;ooooo0_l00002ooooo`;o00004Ooo
ool6o`0000?ooooo0_l00006ooooo`;o00001Oooool2o`000003ooooool0003o000000Oooooo0_l0
0005ooooo`;o00001_ooool2o`0000Kooooo0_l0000Jooooo`;o00002_ooool2o`0000kooooo0_l0
000dooooo`007?ooool00ol0003oooooooooo`0Zooooo`;o00000_ooool2o`0000?ooooo0_l00006
ooooo`;o00002?ooool2o`0000?ooooo0_l00006ooooo`Co00001Oooool2o`0000Sooooo0_l00003
ooooo`;o00000oooool2o`0000Cooooo0_l00004ooooo`Co00001?ooool2o`0001_ooooo0_l00002
ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`Co00001Oooool2o`0000oooooo0_l0000?
ooooo`;o00004Oooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`0000kooooo0ol0000m
ooooo`007?ooool00ol0003oooooooooo`0Wooooo`;o00001Oooool2o`0000_ooooo0_l0000:oooo
o`;o000000?oooooo`000?l000000oooool2o`0001[ooooo0_l00004ooooo`;o000000?oooooo`00
0?l000001Oooool4o`0000Cooooo0_l0000:ooooo`;o00000oooool2o`0000Wooooo0ol0000;oooo
o`?o00000oooool2o`0000Gooooo0_l00005ooooo`;o00002?ooool3o`000003ooooool0003o0000
00;ooooo0_l00007ooooo`;o00002?ooool2o`0000Oooooo0_l000000ooooooo0000o`000002o`00
00?ooooo0_l000000ooooooo0000o`000008ooooo`;o000000Coooooo`000?l0003o0000?Oooool0
01cooooo00?o0000ooooooooool09oooool2o`0001;ooooo0_l0000:ooooo`;o00000oooool2o`00
0003ooooool0003o000000;ooooo0_l0000Fooooo`Co00000_ooool2o`000004ooooool0003o0000
ooooo`;o00005_ooool2o`0000?ooooo0_l00005ooooo`;o00000_ooool2o`0000cooooo0ol00000
1?oooooo0000o`000?ooool4o`0000Cooooo0_l00003ooooo`;o00001?ooool7o`000003ooooool0
003o000000;ooooo0_l0000Aooooo`;o00002_ooool2o`0000Gooooo0_l000000ooooooo0000o`00
0008ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0=Oooool2o`0000Sooooo0_l00006
ooooo`;o00000_ooool3o`000003ooooool0003o000000;ooooo0_l00009ooooo`;o000000Cooooo
o`000?l0003o00002Oooool2o`0000Sooooo0_l00003ooooo`;o00001oooool2o`0000Kooooo0_l0
0002ooooo`;o00002?ooool2o`0000;ooooo0_l00003ooooo`;o00001Oooool2o`0000Cooooo0_l0
00000ooooooo0000o`000002o`0000Cooooo1?l00007ooooo`Go00000_ooool2o`000003ooooool0
003o000000;o00002Oooool2o`0000_ooooo0_l00002ooooo`;o00002?ooool2o`0000Gooooo0_l0
0017ooooo`007?ooool00ol0003oooooooooo`0Zooooo`;o00002Oooool2o`0000Sooooo1?l00004
ooooo`Ko000000Coooooo`000?l0003o00000oooool2o`0000Cooooo0_l00002ooooo`;o000000Co
ooooo`000?l0003o00004?ooool2o`0000Kooooo0_l00007ooooo`;o000000?oooooo`000?l00000
0oooool2o`0000;ooooo0_l0000=ooooo`;o00000_ooool2o`0000Gooooo0_l00004ooooo`;o0000
2oooool2o`0000?ooooo0_l00005ooooo`[o00000oooool3o`0000Cooooo0_l0000;ooooo`;o0000
0_ooool2o`0000Cooooo0_l00009ooooo`;o00001Oooool3o`0003oooooo000Looooo`03o`000?oo
oooooooo02[ooooo0_l0000Eooooo`Co00001?ooool4o`000003ooooool0003o000000Cooooo0_l0
0004ooooo`;o00005oooool3o`0000Sooooo0_l00002ooooo`;o00001?ooool2o`0001Cooooo1?l0
0004ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Sooooo0_l00002ooooo`;o000000Go
ooooo`000?l0003o0000ooooo`02o`0000;ooooo2_l00003ooooo`Go00004?ooool2o`0000?ooooo
0_l000000ooooooo0000o`000003o`0000Sooooo0_l00004ooooo`?o0000?oooool001cooooo00?o
0000ooooooooool0=?ooool2o`0000gooooo0_l00006ooooo`Go000000?oooooo`000?l000008?oo
ool2o`000003ooooool0003o000000;o00001?ooool2o`0000;ooooo0_l000001?oooooo0000o`00
0?ooool2o`0001;ooooo1?l00006ooooo`;o000000?oooooo`000?l000002oooool4o`000003oooo
ool0003o000000;ooooo1_l000000ooooooo0000o`000005o`000003ooooool0003o000000?o0000
00?oooooo`000?l000001_l00003ooooo`;o00002oooool2o`0000?ooooo0_l000001?oooooo0000
o`000?ooool2o`0000Cooooo0_l00002ooooo`Co000000?oooooo`000?l00000@Oooool001cooooo
00?o0000ooooooooool0=?ooool2o`0000oooooo0_l00004ooooo`Go000000?oooooo`000?l00000
1oooool2o`0001;ooooo0_l00003ooooo`Oo00002oooool2o`000003ooooool0003o000000kooooo
0_l00002ooooo`;o00005?ooool3o`000003ooooool0003o000000;o000000?oooooo`000?l00000
0_l000000ooooooo0000o`000004ooooo`Co000000?oooooo`000?l000001?l00003ooooo`So0000
0oooool2o`0000Wooooo0ol000000ooooooo0000o`00000=ooooo`;o00001?ooool2o`000003oooo
ool0003o0000047ooooo000Looooo`;o0000??ooool2o`0000Cooooo0_l00002ooooo`;o00000ooo
ool3o`000003ooooool0003o000000Kooooo0_l00002ooooo`;o00004_ooool>o`0001Kooooo0_l0
0004ooooo`;o00006?ooool4o`000003ooooool0003o000000;ooooo1ol00004oooooaKo00000ooo
ool2o`0000Kooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00000oooool2o`0000kooooo
1Ol00011ooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00001Oooool2o`0000;ooooo0_l0
0004ooooo`;o00001_ooool4o`0000Wooooo0_l0000Hooooo`co000000?oooooo`000?l000004ooo
ool2o`0000Cooooo1?l00003ooooo`?o00004_ooool2o`000003ooooool0003o000000?ooooo6ol0
0002ooooo`?o00001_ooool2o`0000?ooooo0ol000000ooooooo0000o`000005ooooo`?o00002ooo
ool2o`000003ooooool0003o000000?o0000@Oooool001cooooo00?o0000ooooooooool09oooool2
o`0000Oooooo1?l00003ooooo`;o00003?ooool2o`000004ooooool0003o0000o`00013ooooo0_l0
0007ooooo`;o00001oooool2o`0000;ooooo2ol000000ooooooo0000o`00000Dooooo`;o00000ooo
ool4o`0000;ooooo1?l00009ooooo`;o00001_ooool2o`000004ooooool0003o0000ooooo`;o0000
1?oooolGo`0000?ooooo0ol00002ooooo`;o00000_ooool2o`0000Cooooo0_l00008ooooo`Co0000
2_ooool2o`0000Cooooo0ol00010ooooo`007?ooool00ol0003oooooooooo`0Wooooo`;o00001ooo
ool4o`0000Gooooo0_l0000:ooooo`Oo00002?ooool2o`000003ooooool0003o000000;ooooo0_l0
0007ooooo`;o00001ooooolAo`0000cooooo0_l000000ooooooo0000o`000004ooooo`;o00002Ooo
ool2o`0000?ooooo0_l00006ooooo`;o00001_ooool2o`000004ooooool0003o0000ooooo`;o0000
0oooool2o`000003ooooool0003o000000Oo000000?oooooo`000?l000003_l00002ooooo`?o0000
5?ooool3o`00013ooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00001ooo
ool2o`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l000000ol00008ooooo`;o000000?o
ooooo`000?l000000_ooool3o`0000_ooooo5Ol00007ooooo`;o00000oooool2o`000003ooooool0
003o000000;ooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000001?oo
ool2o`0000Sooooo0_l00004ooooo`;o000000?oooooo`000?l000000oooool2o`000003ooooool0
003o000002?o00004_ooool2o`0000Gooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`0_
ooooo`?o00000_ooool2o`0000[ooooo0_l00002ooooo`;o00003_ooool4o`0000?ooooo0ol0000:
oooooaSo00001Oooool2o`0000[ooooo1_l00002ooooo`?o000000?oooooo`000?l000000_l0000<
ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000003oooooako000000Co
ooooo`000?l0003o00000_ooool4o`0000gooooo0_l00007ooooo`;o000000?oooooo`000?l00000
4oooool2o`0003Kooooo000Looooo`03o`000?oooooooooo02oooooo0ol00002ooooo`?o00003?oo
ool4o`0000_ooooo1_l00003ooooo`;o00002_oooolIo`0000;ooooo0_l0000?ooooo`Co00000_oo
ool2o`0000Cooooo1_l00002ooooo`;o00001oooool5o`0000;ooooo1Ol000000ooooooo0000o`00
000Jo`000003ooooool0003o000000;o00004_ooool2o`0000Oooooo0_l00007ooooo`Co00001Ooo
ool2o`0000Cooooo0_l0000fooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00000oooool2
o`0000cooooo1_l00009ooooo`;o00001_ooool2o`0000_ooooo1Ol000000ooooooo0000o`00000>
o`0000;ooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000001Kooooo1_l00002
ooooo`Co00001_ooool5o`000003ooooool0003o000001Wo000000?oooooo`000?l000001?l00000
0ooooooo0000o`000005o`0000_ooooo0_l0000?ooooo`Co000000?oooooo`000?l000000_l00005
ooooo`;o0000??ooool001cooooo00?o0000ooooooooool0=_ooool5o`0000;ooooo0ol00003oooo
o`?o000000Coooooo`000?l0003ooooo0_l00007ooooo`;o00001Oooool2o`0000Sooooo3?l00000
0ooooooo0000o`00000>o`000003ooooool0003o000000;o000000?oooooo`000?l000006?ooool2
o`0000Gooooo0ol00003ooooo`;o00001?oooolIo`000003ooooool0003o000000;o000000?ooooo
o`000?l000003?l0000;ooooo`;o00003oooool5o`000003ooooool0003o000000Gooooo0_l00006
ooooo`Co0000<oooool001cooooo00?o0000ooooooooool0<oooool2o`000003ooooool0003o0000
00?o00000_ooool3o`0000;ooooo0ol00005ooooo`;o00000_ooool2o`0000;ooooo0ol0000:oooo
o`;o00000ooooolKo`0000?ooooo0ol0000Jooooo`;o00001?ooool2o`000004ooooool0003o0000
ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o000000?oooooo`000?l000009ol0
0002ooooo`;o00000_ooool2o`0000cooooo0_l00009ooooo`;o00001Oooool2o`000003ooooool0
003o000000Kooooo1?l0000cooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00003Oooool2
o`0000Kooooo0_l00002ooooo`;o00000_ooool2o`0000[ooooo0ol000001?oooooo0000o`000?oo
ool9o`000003ooooool0003o000000oo00000oooool2o`0000Sooooo0_l00007ooooo`;o00001ooo
ool2o`0000Cooooo0_l000000ooooooo0000o`000005o`0000;ooooo1_l000001?oooooo0000o`00
0?oooolWo`000003ooooool0003o000000;ooooo0ol0000;ooooo`;o00004?ooool2o`00043ooooo
000Looooo`03o`000?oooooooooo01cooooo0_l0000Aooooo`;o00000_ooool2o`0001Gooooo0_l0
0005ooooo`;o00001oooool2o`0000;ooooo0_l00002oooooako00002oooool4o`000003ooooool0
003o000000Cooooo0_l00007ooooo`;o00001_ooool4o`0000;ooooo0_l00002ooooo`So00000_oo
oolWo`0000Kooooo0_l0000;ooooo`;o0000D_ooool001cooooo00?o0000ooooooooool07?ooool2
o`00017ooooo0_l0000@ooooo`;o00003_ooool2o`0000Oooooo0_l00007oooooago00001_ooool2
o`000003ooooool0003o000000Co000000?oooooo`000?l000005Oooool2o`000003ooooool0003o
000000Oooooo1_l00003oooooa7o000000?oooooo`000?l000002_l00002ooooo`Co00000oooool2
o`0000Wooooo0_l00005ooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0<Oooool4o`00
00Cooooo0_l00004ooooo`Co00006oooool2o`0000?ooooo7Ol00006ooooo`;o000000?oooooo`00
0?l000001ol0000Hooooo`;o00001_ooool7o`000003ooooool0003o000000_o000000?oooooo`00
0?l000004_l00002ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000004oooo
o`Co00004?ooool2o`0004Oooooo000Looooo`03o`000?oooooooooo037ooooo1?l00004ooooo`Co
00000_ooool2o`0000Sooooo1Ol00008ooooo`;o00001_ooool2o`000003ooooool0003o000000go
00000_ooool>o`0000gooooo1?l0000=ooooo`;o00001Oooool2o`0000Oooooo0_l00002oooooaGo
000000?oooooo`000?l000006ol000000ooooooo0000o`000004ooooo`;o00004_ooool3o`0000?o
oooo0ol00010ooooo`007?ooool00ol0003oooooooooo`0eooooo`;o00001?ooool2o`0000;ooooo
0_l00008ooooo`Go00002?ooool2o`0000Cooooo0_l00003oooooaoo000000?oooooo`000?l00000
6Oooool4o`0000?ooooo1?l00007ooooo`;o00000ooooolNo`000003ooooool0003o000000?o0000
00?oooooo`000?l000003_l0000Gooooo`Go00000_ooool3o`00043ooooo000Looooo`;o0000=_oo
ool2o`0000cooooo0_l0000Aooooo`;o00001?ooool2o`0000Cooooo0ol000000ooooooo0000o`00
000Ko`0000;ooooo0_l00003ooooo`;o00004?ooool2o`0000;ooooo0_l000000ooooooo0000o`00
0003ooooo`;o00002_ooool[o`0000;ooooo1_l0000Gooooo`?o000000?oooooo`000?l00000AOoo
ool001cooooo00?o0000ooooooooool0<Oooool2o`00013ooooo0_l0000:ooooo`;o00002oooool2
o`000003ooooool0003o000001go00000_ooool2o`0000?ooooo0_l00003ooooo`;o00001?ooool2
o`0000kooooo0_l00006ooooo`;o00002?ooool]o`000003ooooool0003o000000Go00005oooool2
o`0000Oooooo0_l00003ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0<Oooool2o`00
017ooooo0_l00004ooooo`;o00000oooool2o`0000Cooooo0_l00008ooooob3o00004Oooool2o`00
00[ooooo0_l0000DoooooaCo000000?oooooo`000?l000005Ol00002ooooo`;o00000_ooool3o`00
023ooooo0_l00003ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0<_ooool4o`0000ko
oooo0_l00004ooooo`Co00001oooool2o`0000Sooooo8_l00004ooooo`;o00002Oooool2o`0000Ko
oooo0_l00002ooooo`;o00001oooool4o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o
000000?oooooo`000?l000002?l000000ooooooo0000o`00000Jo`0000;ooooo0_l000000ooooooo
0000o`000002o`000003ooooool0003o000001Oooooo0_l00016ooooo`007?ooool00ol0003ooooo
ooooo`0^ooooo`;o00000_ooool4o`0000Sooooo0_l0000<ooooo`;o00000_ooool2o`0000gooooo
0_l00002oooooa[o000000Coooooo`000?l0003o00001?ooool2o`0000?ooooo1?l00002ooooo`?o
00001Oooool2o`0000Cooooo0_l00005ooooo`Co000000?oooooo`000?l000000_ooool2o`0000Co
oooo0_l000000ooooooo0000o`000008o`000003ooooool0003o000001Wo00000oooool5o`0000?o
oooo0_l0000Gooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0;_ooool2o`0000Oooooo
0_l00005ooooo`;o00001_ooool2o`0000Sooooo0_l0000=oooooaoo000000?oooooo`000?l00000
2Oooool6o`000003ooooool0003o000000Gooooo0_l00004ooooo`;o00000oooool2o`0000kooooo
0ol000001?oooooo0000o`000?oooolSo`0000?ooooo1Ol0000>ooooo`;o00000_ooool2o`0001Co
oooo0_l0000jooooo`007?ooool00ol0003oooooooooo`0aooooo`?o00000oooool2o`0000Wooooo
0_l00002ooooo`;o00003Oooool2o`0000Gooooo0_l000000ooooooo0000o`000002o`000003oooo
ool0003o000001So00002Oooool2o`0000Cooooo1?l00007ooooo`;o00002Oooool2o`0000Oooooo
0_l00002ooooo`;o000000?oooooo`000?l00000:?l000001?oooooo0000o`000?ooool5o`0000go
oooo0_l00002ooooo`?o00004_ooool3o`0003[ooooo000Looooo`03o`000?oooooooooo037ooooo
0ol0000>ooooo`;o00000oooool2o`0000cooooo0_l00005ooooo`?o00001?ooool@o`000003oooo
ool0003o000000[o00001?ooool2o`000003ooooool0003o000000;ooooo1_l00006ooooo`?o0000
4_ooool6o`0000Cooooo:_l00004ooooo`?o00004Oooool2o`0001;ooooo0_l0000kooooo`007?oo
ool00ol0003oooooooooo`12ooooo`;o00000oooool2o`0000_ooooo0_l00007ooooo`?o000000?o
ooooo`000?l000002ol000000ooooooo0000o`00000?o`0000Cooooo0_l00005ooooo`;o00000_oo
ool2o`0000Kooooo0_l0000Eooooo`;o00001oooool8o`000003ooooool0003o000000Wo000000?o
ooooo`000?l000004_l000000ooooooo0000o`000002ooooo`;o00001Oooool2o`0000oooooo0_l0
001:ooooo`007?ooool00ol0003oooooooooo`0booooo`;o00003_ooool2o`0000Gooooo1?l00007
ooooo`?o00001oooool2o`000003ooooool0003o000000ko000000?oooooo`000?l000001Ol00000
0ooooooo0000o`000003o`0001Kooooo1_l00003ooooo`;o00004oooool2o`0000Gooooo0_l00002
ooooobKo00001?ooool2o`0000;ooooo0_l00006ooooo`;o00001oooool2o`0000Cooooo0_l00014
ooooo`007?ooool00ol0003oooooooooo`0booooo`;o00001_ooool2o`0000Gooooo0ol00005oooo
o`Ko00001_ooool2o`0000[ooooo3?l000000ooooooo0000o`000007o`000003ooooool0003o0000
00;o000000?oooooo`000?l000002Oooool2o`0000Gooooo0_l00003ooooo`Oo00000oooool2o`00
00Kooooo0_l0000;ooooo`;o00000oooool3o`000003ooooool0003o000001Co00000oooool9o`00
00;ooooo1_l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000?ooooo0_l0000=oooo
o`;o0000A?ooool001cooooo00?o0000ooooooooool0>_ooool2o`0000Gooooo0_l000000ooooooo
0000o`000007ooooo`;o00004Oooool3o`0000_ooooo2Ol000000ooooooo0000o`000002ooooo`;o
00001oooool2o`000003ooooool0003o000000Gooooo0_l00003ooooo`Go00003Oooool2o`0000Ko
oooo0_l00008ooooo`?o000000?oooooo`000?l000005ol000000ooooooo0000o`000004o`0000Go
oooo1Ol00006ooooo`;o000000?oooooo`000?l000000_l0001Fooooo`007?ooool00ol0003ooooo
ooooo`14ooooo`;o00001oooool2o`0000gooooo0_l00002ooooo`Co00004Oooool2o`000003oooo
ool0003o000000;ooooo0_l00004ooooo`;o000000?oooooo`000?l000003Oooool2o`00013ooooo
0_l00006ooooo`;o00001oooool4o`0000?ooooo7?l00003ooooo`;o00001?ooool5o`0000Wooooo
0_l0000Cooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0=Oooool2o`0000;ooooo0_l0
0008ooooo`;o00005oooool2o`000003ooooool0003o000000?o00004?ooool2o`0000;ooooo0_l0
0008ooooo`;o00004oooool7o`0001;ooooo0_l00005ooooobWo00000oooool2o`000004ooooool0
003o0000o`0000Gooooo0_l00009ooooo`;o00002oooool2o`00047ooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0
003oooooooooo`0aooooo`;o00000_ooool2o`0000;ooooo0ol00002ooooo`;o000000?oooooo`00
0?l000000_l00009ooooo`;o00003oooool6o`0000_ooooo0_l00002ooooo`Co00006?ooool2o`00
00Gooooo1ol000000ooooooo0000o`000009ooooo`Co00000_ooool2o`0000Sooooo2_l000000ooo
oooo0000o`00000Fo`000003ooooool0003o000000?ooooo1_l000001Ooooooo0000o`000?l0003o
oooo00;o00002Oooool2o`0000;ooooo0_l0000;ooooo`;o0000?Oooool00006oooooomgMgOoV9RH
oooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`00
0?oooooooooo037ooooo0_l00007ooooo`Ko000000?oooooo`000?l000001oooool2o`0000;ooooo
0_l00006ooooo`?o00002_ooool2o`0000_ooooo0_l00004ooooo`;o00004oooool2o`000003oooo
ool0003o000000?o00001_ooool2o`0000Cooooo0_l00009ooooo`Co000000Coooooo`000?l0003o
oooo0_l00004ooooo`;o00000oooool3o`0000;ooooo0_l000000ooooooo0000o`00000Do`0000?o
oooo1?l000000ooooooo0000o`000002o`000003ooooool0003o000000?o00000_ooool2o`0000Oo
oooo0ol00002ooooo`;o00002oooool2o`0003gooooo00000ooooooo410@ooooo`02ooooo`03oa0@
4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo03Wo
oooo1Ol0000<ooooo`?o00002Oooool4o`0000cooooo0_l00008ooooo`;o00000_ooool2o`0001Go
oooo0_l000000ooooooo0000o`000003o`0001[ooooo1ol00004ooooo`;o00000oooool2o`000003
ooooool0003o000000Go000000?oooooo`000?l000004?l000000ooooooo0000o`000003ooooo`;o
000000?oooooo`000?l000000oooool2o`0000Gooooo0_l00007ooooo`;o0000Coooool00003oooo
ool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Ko
oooo0ol0000iooooo`;o00003_ooool4o`0000Sooooo0_l000000ooooooo0000o`00000<ooooo`;o
00002?ooool2o`0000;ooooo0_l0000Sooooo`Co000000?oooooo`000?l000000_l0000;ooooo`;o
00000_ooool2o`0000?ooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo1_l00002oooo
oa;o000000?oooooo`000?l000001_l00005ooooo`;o00000oooool2o`0000Gooooo0_l000000ooo
oooo0000o`00001@ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05
o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0Kooooo`;o0000;?ooool3o`00
00Wooooo0_l00009ooooo`;o00005_ooool4o`0001;ooooo0_l00009ooooo`Co000000?oooooo`00
0?l000000_l0000Dooooo`Ko000000?oooooo`000?l000000_ooool5o`0000;ooooo1?l00004oooo
o`Go000000?oooooo`000?l000000_l000000ooooooo0000o`000006o`0000[ooooo0_l00002oooo
o`;o000000Coooooo`000?l0003ooooo0_l0000<ooooo`;o0000@_ooool00003ooooool@413ooooo
00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo
01_ooooo0_l0000Kooooo`;o00001oooool2o`0000Gooooo1?l00002ooooo`;o00001?ooool2o`00
00[ooooo0_l0000Fooooo`Co00004_ooool2o`0000Sooooo0_l00004ooooo`;o00003?ooool2o`00
00[ooooo0_l00004ooooo`;o00000_ooool5o`0000Sooooo2?l00005ooooo`Co00001_ooool2o`00
00;ooooo0_l00004ooooo`Co00002Oooool2o`0000Kooooo0_l00004ooooo`;o0000??ooool00006
oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooo
oooo03Sooooo0_l00003ooooo`;o00000_ooool4o`000003ooooool0003o000000?o00000oooool2
o`0000Cooooo1?l0000=ooooo`;o00002Oooool2o`0000Gooooo0_l0000?ooooo`;o00002?ooool2
o`0000Cooooo0ol00003ooooo`?o00000_ooool2o`0000Oooooo1?l00008ooooo`;o000000Cooooo
o`000?l0003ooooo0_l000001Ooooooo0000o`000?l0003ooooo00Co00000oooool6o`000003oooo
ool0003o000000?o00001Oooool2o`000004ooooool0003o0000o`0000?ooooo0_l000000ooooooo
0000o`000003o`0000;ooooo1?l00009ooooo`;o00003?ooool2o`0003cooooo00001_ooooook^k^
oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`0k
ooooo`Co00000oooool3o`000003ooooool0003o000000?o00001_ooool2o`000003ooooool0003o
000000;o00003Oooool4o`0000Oooooo0_l00005ooooo`;o00003oooool2o`0000;ooooo0_l00003
ooooo`Go00000_ooool4o`0000?ooooo0_l00002ooooo`;o00001_ooool2o`000003ooooool0003o
000000Kooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo6ol000001?oooooo0000o`00
0?ooool3o`0000Kooooo0_l000000ooooooo0000o`00000;ooooo`;o00001Oooool2o`0000Wooooo
0_l0000looooo`007?ooool00ol0003oooooooooo`0kooooo`;o00002oooool2o`0000Oooooo0_l0
00001?oooooo0000o`000?ooool2o`0000Oooooo1?l00003ooooo`;o00006oooool2o`000003oooo
ool0003o000000;o000000?oooooo`000?l000000_ooool3o`000003ooooool0003o000000;ooooo
1ol00002ooooo`;o00001_ooool6o`0000Oooooo0ol00005ooooo`;o00000_ooool5o`000003oooo
ool0003o000000[o00001?ooool7o`0001[ooooo0_l00004ooooo`?o00001oooool4o`0003cooooo
000Looooo`03o`000?oooooooooo04?ooooo0_l000000ooooooo0000o`000002o`0000gooooo0_l0
0004ooooo`;o000000?oooooo`000?l000001?l0000?ooooo`;o00001oooool2o`0000;ooooo1?l0
00000ooooooo0000o`000002o`000004ooooool0003o0000ooooo`?o00001_ooool2o`000003oooo
ool0003o000000;o00000_ooool2o`0000Kooooo0ol000000ooooooo0000o`000008ooooo`;o0000
2Oooool2o`0000Gooooo1Ol00002ooooo`?o00001oooool5o`0000gooooo1?l00003ooooo`Co0000
1?ooool2o`0000;ooooo0_l00008ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0>ooo
ool2o`0000Kooooo0_l000000ooooooo0000o`000002o`0000gooooo0_l00004ooooo`;o00001?oo
ool3o`0000oooooo0_l00007ooooo`;o00000_ooool4o`0000Kooooo0_l000000ooooooo0000o`00
000<ooooo`;o00005Oooool2o`0000cooooo0ol00005ooooo`;o000000?oooooo`000?l000001?l0
0007ooooo`;o00004?ooool4o`0000?ooooo1?l00004ooooo`;o0000C?ooool001cooooo00?o0000
ooooooooool0>oooool2o`0001cooooo0_l00006ooooo`Co00007oooool2o`0000Gooooo1?l0000>
ooooo`;o00005Oooool4o`000003ooooool0003o000000Oooooo1?l00003ooooo`;o000000?ooooo
o`000?l000001Ol00003ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Wooooo0_l00003
ooooo`;o00005oooool2o`0003[ooooo000Looooo`03o`000?oooooooooo053ooooo0_l00007oooo
o`;o00001_ooool2o`00017ooooo0_l0000@ooooo`;o00000oooool4o`0000cooooo1?l0000Doooo
o`;o000000Coooooo`000?l0003ooooo0_l00009ooooo`;o00000oooool5o`0000Cooooo0ol00000
0ooooooo0000o`000003o`0000Cooooo0_l00003ooooo`;o00002Oooool2o`0000?ooooo0_l00008
ooooo`;o00003Oooool2o`0003[ooooo000Looooo`03o`000?oooooooooo04Kooooo1?l00006oooo
o`;o00001_ooool3o`0001Wooooo0_l00007ooooo`;o00001oooool2o`0000Cooooo0_l00006oooo
o`;o00000_ooool7o`0000Cooooo1?l00004ooooo`;o00001Oooool3o`0001Gooooo0ol00005oooo
o`?o00000oooool2o`0000Gooooo0_l0000Mooooo`;o0000BOooool001cooooo00?o0000oooooooo
ool0A_ooool6o`0000?ooooo0_l00007ooooo`Go00004_ooool2o`0000cooooo0_l0000Booooo`;o
000000Goooooo`000?l0003o0000ooooo`03o`0000Sooooo1?l00004ooooo`;o00001Oooool2o`00
00Sooooo0_l00007ooooo`;o00001?ooool2o`0000Gooooo0_l000000ooooooo0000o`000006oooo
o`;o00004oooool2o`0005Gooooo000Looooo`03o`000?oooooooooo04Oooooo0_l000000ooooooo
0000o`000003ooooo`?o00001Oooool2o`0000;ooooo0_l0000Booooo`;o00000_ooool2o`0000?o
oooo1?l00008ooooo`;o00001?ooool2o`0000Cooooo1?l000000ooooooo0000o`000006ooooo`;o
00000_ooool2o`0000Kooooo0_l00003ooooo`;o00000_ooool2o`0000Sooooo0_l00007ooooo`?o
00000oooool2o`0000Gooooo1Ol00006ooooo`;o00003_ooool2o`0000?ooooo0_l0000Oooooo`;o
0000=?ooool001cooooo00?o0000ooooooooool0?oooool2o`0000Kooooo0_l00007ooooo`;o0000
1Oooool2o`000003ooooool0003o000001Oooooo0_l00003ooooo`Co00001_ooool4o`0000Cooooo
3?l000000ooooooo0000o`000004ooooo`;o00000_ooool2o`0000Kooooo0_l00003ooooo`;o0000
1oooool2o`0000?ooooo0_l00008ooooo`;o00003?ooool2o`0001Gooooo1?l00007ooooo`;o0000
6oooool2o`0003Cooooo000Looooo`03o`000?oooooooooo03oooooo0_l00006ooooo`;o00004Ooo
ool4o`0000Gooooo0_l0000Fooooo`Co00000oooool2o`0000Kooooo3?l000001?oooooo0000o`00
0?l00003ooooo`;o00002oooool2o`0000_ooooo0_l000000ooooooo0000o`000002o`000003oooo
ool0003o000000;o00009_ooool4o`0000Gooooo1_l00002ooooo`;o0000COooool001cooooo00?o
0000ooooooooool0?oooool2o`0000?ooooo1?l0000Cooooo`?o00001Oooool2o`0000Oooooo0_l0
000=ooooo`Go00002Oooool>o`000003ooooool0003o000000_ooooo0_l00003ooooo`;o00003_oo
ool4o`000003ooooool0003o000000Co000000?oooooo`000?l000001oooool2o`0000;ooooo0_l0
0008ooooo`;o00002_ooool2o`0000Kooooo1Ol00004ooooo`;o00002?ooool2o`0004?ooooo000L
ooooo`;o0000;_ooool2o`0001Gooooo1?l0000Cooooo`Co00003Oooool2o`0000_ooooo0_l00000
0ooooooo0000o`000002o`000003ooooool0003o000000Cooooo4?l0000>ooooo`;o00002?ooool4
o`0000Cooooo0_l00003ooooo`;o00001Oooool2o`000003ooooool0003o000000;ooooo0_l00003
ooooo`?o000000?oooooo`000?l000002?ooool2o`00017ooooo0ol0000Aooooo`;o0000@oooool0
01cooooo00?o0000ooooooooool0;Oooool2o`0002gooooo0ol0000<ooooo`;o00002Oooool2o`00
0003ooooool0003o000000?o00000oooool3o`0000;ooooo1?l00002ooooo`go00002_ooool6o`00
00Kooooo1?l00004ooooo`?o00004?ooool2o`0000Cooooo0_l00004ooooo`;o00004oooool2o`00
0003ooooool0003o000000;o0000Eoooool001cooooo00?o0000ooooooooool0C_ooool2o`0001;o
oooo0_l00003ooooo`;o00000_ooool2o`0000Wooooo0_l00002ooooo`;o00000oooool2o`000005
ooooool0003o0000o`000?ooool00ol000000ooooooo0000o`00000?o`0000Sooooo0_l000001?oo
oooo0000o`000?l00007ooooo`?o00001Oooool2o`0000;ooooo0ol00002ooooo`;o00001_ooool3
o`0000?ooooo0_l00005ooooo`;o00004oooool2o`000003ooooool0003o000000Cooooo0_l0001C
ooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o00004_ooool2o`0000?ooooo0_l0000Coooo
o`;o000000?oooooo`000?l000000_oooolDo`0000;ooooo0_l0000:ooooo`?o00000_ooool2o`00
00Cooooo0_l00006ooooo`;o00000_ooool3o`0000;ooooo0_l00006ooooo`?o00000oooool2o`00
0003ooooool0003o000000?o00007Oooool2o`0000oooooo0_l00012ooooo`007?ooool00ol0003o
ooooooooo`16ooooo`;o00004oooool2o`0000Gooooo0_l0000Hooooo`;o000000?oooooo`000?l0
00001?oooolCo`0000gooooo0_l00003ooooo`;o00001oooool2o`0000Gooooo0_l00002ooooo`;o
00002Oooool2o`0000Oooooo1Ol00002ooooo`;o00006_ooool3o`0000gooooo0_l00012ooooo`00
7?ooool00ol0003oooooooooo`16ooooo`;o00003Oooool2o`0000Cooooo0_l000000ooooooo0000
o`00000SoooooaGo00003oooool2o`0000[ooooo1Ol00002ooooo`Ko00002Oooool2o`0000kooooo
0_l0000Dooooo`Co00000_ooool3o`00057ooooo000Looooo`03o`000?oooooooooo04Sooooo0_l0
000;ooooo`;o00001_ooool3o`0000;ooooo0_l0000OoooooaKo00003_ooool3o`0000Gooooo0_l0
0004ooooo`?o00000oooool4o`000003ooooool0003o000000Oooooo0_l0000Looooo`;o00001Ooo
ool5o`0005Kooooo000Looooo`03o`000?oooooooooo04Oooooo0ol0000Cooooo`;o00000oooool2
o`0001Gooooo0_l00006oooooaSo00002Oooool2o`0000Cooooo0_l00005ooooo`;o00002?ooool2
o`0000Gooooo0_l0000Uooooo`;o00000_ooool2o`000003ooooool0003o000001Kooooo0_l00011
ooooo`007?ooool00ol0003oooooooooo`17ooooo`;o0000<?ooool2o`0000Kooooo6?l00004oooo
o`;o00000oooool2o`0000Wooooo0_l0000:ooooo`;o00003_ooool2o`00023ooooo0_l0000Ioooo
o`;o0000@Oooool001cooooo00?o0000ooooooooool0C?ooool2o`0000Kooooo1?l00002ooooo`;o
00004Oooool2o`0000gooooo0_l00005oooooaco00001_ooool2o`0000Kooooo0_l00003ooooo`;o
00005Oooool2o`0001;ooooo0_l0001Zooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o0000
7_ooool3o`0000;ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00005ooooo`;o0000
2_ooool2o`0000gooooo0_l00005ooooo`?o000000?oooooo`000?l000005Ol00006ooooo`?o0000
0_ooool2o`0000Oooooo1?l0000:ooooo`;o00001oooool2o`0000Cooooo0_l0000<ooooo`;o0000
3_ooool2o`0005[ooooo000Looooo`03o`000?oooooooooo02cooooo0_l0000Iooooo`;o00001?oo
ool2o`0000;ooooo2?l00003ooooo`;o00000oooool2o`0000Wooooo0ol0000>ooooo`;o00001ooo
ool:o`000003ooooool0003o000000Oo00000_ooool2o`0000Kooooo0ol00002ooooo`;o000000Go
ooooo`000?l0003o0000ooooo`02o`0000;ooooo0_l0000:ooooo`;o00001oooool4o`0000;ooooo
0_l0000Looooo`;o0000F_ooool001cooooo00?o0000ooooooooool0Aoooool2o`000003ooooool0
003o000000Kooooo2?l00002ooooo`;o00001oooool2o`0000Gooooo0ol0000>ooooo`Co00001Ooo
ool;o`000003ooooool0003o000000Ko00000_ooool2o`0000Cooooo1Ol00002ooooo`;o000000?o
ooooo`000?l000001?l0000<ooooo`;o00001oooool6o`0000;ooooo0_l0000Kooooo`Co00001Ooo
ool2o`0005;ooooo000Looooo`03o`000?oooooooooo04[ooooo0_l00003ooooo`;o00001oooool5
o`000003ooooool0003o000000Gooooo0_l00002ooooo`;o00003?ooool2o`0000Gooooo1Ol00004
oooooa;o00001?ooool2o`0000?ooooo1?l00003ooooo`;o00000oooool2o`000003ooooool0003o
000000[ooooo0ol00004ooooo`Go00001oooool2o`0001Kooooo0_l00002ooooo`Co00001Oooool2
o`0005;ooooo000Looooo`03o`000?oooooooooo04oooooo0_l00007ooooo`Go000000Coooooo`00
0?l0003o00001?ooool2o`0000;ooooo0_l0000<ooooo`;o00001Oooool2o`000003ooooool0003o
000000?o000000?oooooo`000?l000004?l00004ooooo`;o00001Oooool2o`0000_ooooo0_l0000:
ooooo`;o00001Oooool4o`0000Sooooo0_l0000Fooooo`;o00000oooool2o`0005[ooooo000Loooo
o`03o`000?oooooooooo04Cooooo0_l0000;ooooo`;o00003?ooool2o`0000;ooooo1?l0000>oooo
o`;o00001oooool2o`000003ooooool0003o000000?o000000?oooooo`000?l000003ol00005oooo
o`;o00002?ooool2o`0000cooooo0_l00006ooooo`;o00001Oooool4o`0001kooooo0_l00005oooo
o`;o000000?oooooo`000?l000003Oooool2o`0004Sooooo000Looooo`;o0000AOooool2o`0000_o
oooo0_l0000@ooooo`;o000000?oooooo`000?l000003Oooool2o`0000Oooooo0_l00006oooooaCo
00000oooool2o`0000Sooooo0_l00004ooooo`;o00001_ooool2o`0000Cooooo0_l00002ooooo`;o
000000?oooooo`000?l000000oooool2o`0001gooooo0_l00008ooooo`;o00003Oooool2o`0004So
oooo000Looooo`03o`000?oooooooooo04cooooo0_l0000>ooooo`?o00000oooool2o`0000;ooooo
0_l0000>ooooo`;o00003_ooool>o`0000;ooooo1?l00002ooooo`;o00002?ooool2o`0000Gooooo
1?l00007ooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000;o0000
00?oooooo`000?l000000_l0000Kooooo`;o0000HOooool001cooooo00?o0000ooooooooool0Booo
ool3o`0000_ooooo0_l000001?oooooo0000o`000?l00003ooooo`;o00002?ooool3o`0000Oooooo
0_l00002ooooo`;o00002_ooool?o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o0000
0_ooool6o`0000Gooooo0_l00007ooooo`;o00002?ooool4o`0000;ooooo0ol0000Fooooo`;o0000
1?ooool5o`0005gooooo000Looooo`03o`000?oooooooooo04_ooooo0ol0000;ooooo`;o00001ooo
ool2o`0000Sooooo0ol0000;ooooo`;o00003Oooool2o`0000;ooooo2_l000000ooooooo0000o`00
0002ooooo`;o00000_ooool2o`0000;ooooo0_l00002ooooo`;o00003_ooool2o`0000Sooooo1?l0
000Hooooo`;o000000?oooooo`000?l000000_ooool7o`0000Cooooo0_l0001Gooooo`007?ooool0
0ol0003oooooooooo`1Gooooo`;o00001?ooool2o`0000Cooooo1?l00003ooooo`;o000000?ooooo
o`000?l000001?ooool2o`0001Cooooo3_l000000ooooooo0000o`00000:ooooo`?o00004Oooool2
o`0000[ooooo0_l000000ooooooo0000o`00000Eooooo`;o00001Oooool3o`0000Sooooo0_l0001G
ooooo`007?ooool00ol0003oooooooooo`1Booooo`;o00000oooool3o`000003ooooool0003o0000
00;o00001?ooool4o`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l000000_l0000?oooo
o`;o000000?oooooo`000?l000003?l00002ooooo`?o00001Oooool2o`000004ooooool0003o0000
o`0000?ooooo0_l0000:ooooo`;o00001?ooool2o`0000Kooooo0_l000000ooooooo0000o`00000M
ooooo`?o0000H?ooool001cooooo00?o0000ooooooooool0D_ooool2o`0000Cooooo0_l000000ooo
oooo0000o`000002o`0000Cooooo0_l0000:ooooo`Go000000?oooooo`000?l000003oooool2o`00
00Gooooo0_l00006ooooo`Oo00001?ooool4o`000003ooooool0003o000000?ooooo1_l00006oooo
o`;o00001?ooool2o`0000?ooooo0_l000001?oooooo0000o`000?l00005ooooo`;o00005Oooool6
o`0000;ooooo0_l0001Looooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00001_ooool2o`00
00?ooooo0_l0000@ooooo`So00000_ooool2o`0001cooooo1?l00005ooooo`Co00001Oooool7o`00
017ooooo0_l00002ooooo`?o00001?ooool2o`0001;ooooo0_l000000ooooooo0000o`000002o`00
00Cooooo0_l0001Looooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00002oooool2o`00017o
oooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00002ooooo`;o00001Oooool2o`0000Go
oooo0_l00008ooooo`;o00000_ooool2o`0000[ooooo0_l00002ooooo`Co00002?ooool2o`0000oo
oooo1?l0000Fooooo`;o00001oooool2o`0000cooooo0_l0001@ooooo`007?ooool00ol0003ooooo
ooooo`19ooooo`;o00001Oooool2o`0002_ooooo0_l00005ooooo`;o00001Oooool2o`0000Sooooo
0_l0000>ooooo`;o00001?ooool2o`0000Sooooo0_l00005ooooo`;o00000oooool2o`0000Gooooo
0_l0000@ooooo`;o00001_ooool2o`0000Gooooo0_l0000<ooooo`;o00002Oooool2o`0004Gooooo
000Looooo`03o`000?oooooooooo04Wooooo0_l0000Eooooo`;o00000_ooool2o`0000?ooooo0_l0
0009ooooo`;o00000oooool3o`0001gooooo0_l0000:ooooo`;o00001?ooool3o`0000;ooooo0_l0
00001?oooooo0000o`000?l00006ooooo`;o00000oooool2o`0001Oooooo0_l00006ooooo`;o0000
7_ooool2o`0004Gooooo000Looooo`03o`000?oooooooooo063ooooo0_l000000ooooooo0000o`00
0002o`0000;ooooo0_l00009ooooo`;o00000oooool3o`0001;ooooo0ol00008ooooo`;o00002Ooo
ool3o`0000Gooooo1_l000001?oooooo0000o`000?l0000Aooooo`Co0000O_ooool001cooooo00?o
0000ooooooooool0DOooool2o`00013ooooo1?l00002ooooo`;o000000?oooooo`000?l000003ooo
ool2o`0000Gooooo0_l000000ooooooo0000o`000005ooooo`?o00004oooool2o`0000Oooooo1Ol0
0007ooooo`?o00002oooool4o`0007kooooo000Looooo`03o`000?oooooooooo057ooooo0_l0000C
ooooo`;o000000Coooooo`000?l0003ooooo0_l0000?ooooo`;o00001Oooool2o`000003ooooool0
003o0000017ooooo0_l00004ooooo`Co00000_ooool2o`0000Gooooo1Ol00007ooooo`?o00003?oo
ool2o`00013ooooo0_l0001]ooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o00001oooool2
o`0000;ooooo0_l00008ooooo`;o00005?ooool2o`0000[ooooo0_l00002ooooo`;o00001?ooool5
o`000004ooooool0003o0000ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo0_l0
00000ooooooo0000o`000002ooooo`;o00001Oooool4o`0000?ooooo0_l000000ooooooo0000o`00
0006ooooo`;o00001?ooool2o`0006gooooo000Looooo`03o`000?oooooooooo05[ooooo0_l00000
0ooooooo0000o`000006ooooo`;o00000oooool4o`0000Kooooo0ol00004ooooo`;o00000_ooool2
o`0000Oooooo1?l0000:ooooo`;o00002oooool2o`0000Cooooo0ol000000ooooooo0000o`000004
ooooo`?o000000?oooooo`000?l000000_ooool2o`0000Cooooo1Ol00003ooooo`Go00001_ooool2
o`0000_ooooo0_l000000ooooooo0000o`000009ooooo`;o0000F?ooool001cooooo0_l0001Hoooo
o`;o000000?oooooo`000?l000002Oooool3o`0000Cooooo0_l00007ooooo`;o00001?ooool6o`00
00Cooooo0_l000000ooooooo0000o`00000Mooooo`;o000000?oooooo`000?l000001oooool4o`00
00[ooooo0_l00006ooooo`Go00001?ooool2o`0000gooooo0_l000000ooooooo0000o`000009oooo
o`;o0000F?ooool001cooooo00?o0000ooooooooool0Eoooool2o`0000gooooo0_l0000=ooooo`;o
00000_ooool2o`000003ooooool0003o000000?o00001?ooool4o`000004ooooool0003o0000o`00
013ooooo0_l000000ooooooo0000o`000005ooooo`;o00002_ooool4o`0000[ooooo0_l00009oooo
o`;o00001?ooool2o`00013ooooo0_l0001Sooooo`007?ooool00ol0003oooooooooo`1eooooo`;o
00000_ooool2o`0000Cooooo0_l00006ooooo`Ko00004?ooool2o`000003ooooool0003o000000Co
00001Oooool3o`0000Gooooo1?l0000:ooooo`;o00003?ooool4o`000003ooooool0003o000000Ko
oooo0_l00006ooooo`;o0000Hoooool001cooooo00?o0000ooooooooool0M?ooool2o`0000?ooooo
0_l00004ooooo`;o00001Oooool4o`0000?ooooo0_l00005ooooo`;o00002_ooool6o`0000?ooooo
1Ol0000=ooooo`;o00001?ooool2o`0000cooooo1?l000000ooooooo0000o`000003ooooo`Go0000
1Oooool2o`0006Cooooo000Looooo`03o`000?oooooooooo07?ooooo0ol00003ooooo`So00001Ooo
ool5o`0000;ooooo0_l00005ooooo`;o00002Oooool2o`0000Gooooo0_l000000ooooooo0000o`00
000?ooooo`Co00004Oooool2o`0000Sooooo1Ol00005ooooo`?o0000Hoooool001cooooo00?o0000
ooooooooool0Loooool2o`0000Kooooo1?l00007ooooo`Go00002oooool2o`0000?ooooo0_l00002
ooooo`;o00001Oooool2o`0000?ooooo1?l000000ooooooo0000o`000008ooooo`Co00001Oooool4
o`0000;ooooo0_l0000@ooooo`;o00001oooool2o`0006?ooooo000Looooo`03o`000?oooooooooo
06?ooooo0_l0000Fooooo`Co00001oooool2o`000003ooooool0003o000000Oooooo0_l00002oooo
o`;o00000oooool2o`0000kooooo1ol00004ooooo`;o00002oooool4o`0000;ooooo0_l00008oooo
o`;o0000M?ooool001cooooo00?o0000ooooooooool0Hoooool2o`0000Sooooo0_l0000<ooooo`Co
000000?oooooo`000?l000000oooool2o`0000?ooooo0_l00005ooooo`?o00005_ooool2o`0000;o
oooo0_l00006ooooo`;o00004?ooool2o`0000Wooooo0ol000000ooooooo0000o`000006ooooo`;o
0000J?ooool001cooooo00?o0000ooooooooool0KOooool2o`0000cooooo0ol00002ooooo`;o0000
0_ooool8o`0000;ooooo0_l000000ooooooo0000o`00000?ooooo`;o00001_ooool2o`0001cooooo
0_l0000:ooooo`Go00001_ooool2o`0006Sooooo000Looooo`03o`000?oooooooooo05Oooooo0_l0
0007ooooo`;o00002oooool2o`0000gooooo0_l00002ooooo`?o000000Coooooo`000?l0003ooooo
0ol00004ooooo`;o00002oooool2o`0000Gooooo0_l00008ooooo`;o00004?ooool2o`0000?ooooo
0_l0000@ooooo`?o0000LOooool001cooooo00?o0000ooooooooool0Eoooool2o`0000Oooooo0_l0
000;ooooo`;o00004Oooool3o`000003ooooool0003o000000Sooooo0_l0000:ooooo`?o00001Ooo
ool2o`0000Oooooo0ol00002ooooo`;o00001Oooool2o`000003ooooool0003o000000;ooooo0_l0
0003ooooo`;o00004?ooool3o`0000?ooooo0_l0001/ooooo`007?ooool00ol0003oooooooooo`21
ooooo`Go00001?ooool2o`0000Oooooo0_l00002ooooo`;o000000?oooooo`000?l000003oooool2
o`0000?ooooo0_l00005ooooo`Ko00001oooool2o`0000Wooooo0_l0000:ooooo`;o0000K?ooool0
01cooooo00?o0000ooooooooool0B_ooool2o`0001_ooooo0_l0000Hooooo`Go00000oooool3o`00
00Oooooo0_l00002ooooo`;o00007oooool2o`000004ooooool0003o0000o`0000Gooooo0ol00009
ooooo`;o0000N?ooool001cooooo00?o0000ooooooooool0B_ooool2o`0001_ooooo0_l0000Moooo
o`;o000000?oooooo`000?l000001oooool2o`00023ooooo0_l00002ooooo`;o00000_ooool2o`00
00Gooooo0_l00007ooooo`;o000000?oooooo`000?l000001_ooool2o`00073ooooo00001_oooooo
k^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_oo
ool00ol0003oooooooooo`1[ooooo`;o00002_ooool2o`0000gooooo0_l00004ooooo`;o00001?oo
ool2o`0000Cooooo1?l00002ooooo`;o00002?ooool2o`0000[ooooo0_l00003ooooo`;o00004Ooo
ool2o`000004ooooool0003o0000o`0000Gooooo0_l0001`ooooo`0000KoooooogMgMonHV9Sooooo
oiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000oooo
ooooool0Joooool2o`0000[ooooo0_l0000=ooooo`;o00000oooool3o`0000;ooooo0_l00006oooo
o`Co00000_ooool2o`0000Sooooo0_l00006ooooo`;o00001oooool2o`0000?ooooo0_l0000@oooo
o`;o0000Moooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool0Q?ooool3o`0000Cooooo0_l00003oooo
o`;o00002Oooool2o`000004ooooool0003o0000o`0000oooooo0_l000000ooooooo0000o`000009
ooooo`;o00003?ooool2o`0007_ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000O_ooool2o`0000Cooooo0ol0000?
ooooo`;o00000oooool2o`0000;ooooo1ol0000=ooooo`;o00002?ooool4o`0000_ooooo0_l00003
ooooo`?o0000MOooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Oo<
c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0O_ooool2o`0001Gooooo0ol00003
ooooo`;o00000oooool6o`0000gooooo0_l00008ooooo`Co00001Oooool2o`0000Wooooo0ol0001e
ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooo
okZj^_l@41001_ooool00ol0003oooooooooo`2Eooooo`;o00002Oooool2o`0000;ooooo0ol00004
ooooo`;o000000?oooooo`000?l000000oooool3o`00013ooooo0_l00003ooooo`;o00005?ooool2
o`0006Kooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zj
o`000006ooooo`03o`000?oooooooooo063ooooo0_l0000>ooooo`;o00001Oooool2o`0000_ooooo
0_l0000Eooooo`;o00002?ooool2o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`Co0000
5Oooool3o`0001?ooooo0_l0001Vooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05
ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`1Pooooo`Co00003?ooool2o`00
00Gooooo0_l0000;ooooo`;o00002oooool2o`0000Kooooo1?l00008ooooo`;o00002oooool2o`00
00Kooooo0_l00002ooooo`;o00002_ooool4o`0007_ooooo000Looooo`03o`000?oooooooooo06;o
oooo0_l0000Hooooo`;o00003oooool2o`0000;ooooo0_l00006ooooo`;o00002_ooool2o`0000?o
oooo0_l0000>ooooo`;o00000_ooool2o`0000Oooooo0_l000000ooooooo0000o`00001mooooo`00
7?ooool00ol0003oooooooooo`1looooo`?o00003_ooool2o`0000;ooooo0_l00005ooooo`;o0000
1?ooool4o`0000Sooooo0_l0000Kooooo`;o00003?ooool4o`00073ooooo000Looooo`03o`000?oo
oooooooo07gooooo0_l0000Booooo`;o00001?ooool3o`0000Cooooo1_l00006ooooo`Co00001_oo
ool3o`0000Sooooo0_l00007ooooo`;o00002oooool4o`00073ooooo000Looooo`03o`000?oooooo
oooo06Cooooo0_l000000ooooooo0000o`00000>ooooo`;o00007_ooool2o`0000?ooooo0_l00003
ooooo`?o00000_ooool2o`000003ooooool0003o000000Go00001?ooool3o`000003ooooool0003o
000000Gooooo0_l000000ooooooo0000o`000004ooooo`Co0000OOooool001cooooo00?o0000oooo
ooooool0GOooool2o`0000Cooooo0ol000000ooooooo0000o`00000>ooooo`;o00005Oooool2o`00
00?ooooo0_l00007ooooo`Co000000?oooooo`000?l000000oooool5o`0000?ooooo0_l00006oooo
o`Co00001Oooool2o`000003ooooool0003o000000Kooooo0_l0001mooooo`007?ooool00ol0003o
ooooooooo`1Mooooo`;o00001?ooool2o`0002?ooooo0_l00004ooooo`;o00000oooool2o`0000Wo
oooo0ol00002ooooo`;o00000_ooool2o`0000gooooo1?l00007ooooo`;o0000Q_ooool001cooooo
00?o0000ooooooooool0Joooool2o`0001Oooooo0_l000001?oooooo0000o`000?l0000Eooooo`;o
00000_ooool2o`0001cooooo0_l00026ooooo`007?ooool00ol0003oooooooooo`1[ooooo`;o0000
5oooool2o`000003ooooool0003o000000Gooooo0_l0002iooooo`007?ooool00ol0003ooooooooo
o`2<ooooo`Co00001Oooool2o`0000[ooooo0_l0002Vooooo`007?ooool00ol0003oooooooooo`2:
ooooo`Co00001oooool2o`0000[ooooo0_l0000Booooo`;o0000T_ooool001cooooo00?o0000oooo
ooooool0R_ooool2o`0000Wooooo0_l00003ooooo`;o00005oooool4o`0000gooooo0_l00023oooo
o`007?ooool2o`0006Oooooo0_l0000]ooooo`Co000000?oooooo`000?l000005oooool2o`0000oo
oooo0_l00023ooooo`007?ooool00ol0003oooooooooo`1Vooooo`;o00000oooool2o`0002[ooooo
0_l0002`ooooo`007?ooool00ol0003oooooooooo`1[ooooo`;o00002Oooool2o`0004[ooooo0_l0
00000ooooooo0000o`000022ooooo`007?ooool00ol0003oooooooooo`1fooooo`;o0000:oooool4
o`0000gooooo0_l0000<ooooo`;o000000?oooooo`000?l00000P_ooool001cooooo00?o0000oooo
ooooool0X?ooool2o`000003ooooool0003o000000;o00003Oooool2o`0000oooooo0_l00022oooo
o`007?ooool00ol0003oooooooooo`2Pooooo`;o00000oooool2o`000:;ooooo000Looooo`03o`00
0?oooooooooo08Wooooo0_l0000Eooooo`;o00000oooool3o`000:7ooooo000Looooo`03o`000?oo
oooooooo08Wooooo0_l0000Kooooo`;o00007_ooool2o`00087ooooo000Looooo`03o`000?oooooo
oooo087ooooo0_l0000]ooooo`;o00005?ooool2o`00087ooooo000Looooo`03o`000?oooooooooo
087ooooo0_l0000>ooooo`;o00007Oooool2o`0009Oooooo000Looooo`03o`000?oooooooooo08;o
oooo0_l0000=ooooo`;o0000]_ooool001cooooo00?o0000ooooooooool0P_ooool2o`000<Gooooo
000Looooo`03o`000?oooooooooo09Sooooo0_l0002_ooooo`007?ooool00ol0003oooooooooo`2H
ooooo`;o0000[oooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBooo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
4_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom:ooooo`005?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000
ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o0000ooooooooool0oooooomBoooo
o`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?oooooo
D_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`004_ooool00omEEEGoIVIVo`00003o
oooooeCooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Qooooo`04oa0@4?l0
003o0000ooooo`;o000000?o410@ooooooooool05_ooool4o`000004oa0@4?ooooooooooooooo`Co
000000Oo410@oooooooooooo410@o`000?m4A4Coc<c<00Kooooo0_l000000ol@413oooooooooo`2:
ooooo`00X_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l0000<ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00onHV9So410@omgMg@06ooooo`03o`000?oooooo
oooo08_ooooo002Rooooo`05o`000?ooooooooooooooool000006oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?oQhN7oeEEEOooool00_ooool5o`0008cooooo002Roooo
o`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`02ooooo`05olc<c?lQ8B7o0000oeEEEOl000000oooool01?m4A4CogMgMoooo
ool0002=ooooo`00X_ooool01Ol0003oQhN7oooooonYZJWo000001_ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`02ooooo`05ob4Q8On7QhOooooooiRHV?l000000oooool01?oMgMgo
EEEEooooool0002=ooooo`00XOooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo01Wo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000001?ooool00omgMgOoc<c<o`00002=ooooo`00`_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00Go8B4QoiRHV?ooooooMgMgoeEEE@04ooooo`03onk^k_m4A4Co0000
08gooooo0030ooooo`03oeEEEOmVIVKo000000Gooooo00?oEEEEofIVI_l000001?ooool01Oo<c<co
410@o`000?lb<S;ok^k^00Gooooo00?oMgMgo`000?ooool0S?ooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1200) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.61456 .40717 Mdot
.59783 .35682 Mdot
.36794 .49657 Mdot
.64583 .58638 Mdot
.28859 .29631 Mdot
.34983 .52309 Mdot
.42503 .39703 Mdot
.43776 .3437 Mdot
.37442 .51374 Mdot
.50191 .23178 Mdot
.41808 .38187 Mdot
.62309 .65287 Mdot
.42732 .36272 Mdot
.62283 .5894 Mdot
.31014 .21817 Mdot
.60492 .51461 Mdot
.62676 .36337 Mdot
.44718 .68177 Mdot
.59119 .6182 Mdot
.38806 .53305 Mdot
.6144 .32305 Mdot
.62936 .58242 Mdot
.56473 .3655 Mdot
.62209 .5896 Mdot
.66425 .56316 Mdot
.58938 .39489 Mdot
.54611 .3791 Mdot
.63811 .54019 Mdot
.65784 .53782 Mdot
.43097 .3437 Mdot
.51825 .71109 Mdot
.27863 .26478 Mdot
.61798 .63203 Mdot
.20107 .56252 Mdot
.45537 .35806 Mdot
.73926 .50431 Mdot
.35106 .50877 Mdot
.44628 .37443 Mdot
.45095 .37828 Mdot
.46122 .39617 Mdot
.43359 .38089 Mdot
.57807 .38423 Mdot
.39604 .32877 Mdot
.4135 .56319 Mdot
.58687 .52073 Mdot
.36639 .2733 Mdot
.80475 .5516 Mdot
.5905 .54614 Mdot
.62548 .37747 Mdot
.26096 .58344 Mdot
.28304 .37987 Mdot
.44947 .39996 Mdot
.36085 .56166 Mdot
.39284 .87453 Mdot
.45073 .36423 Mdot
.5616 .54841 Mdot
.3553 .50037 Mdot
.61989 .57531 Mdot
.61742 .58912 Mdot
.67521 .39911 Mdot
.58083 .54244 Mdot
.4054 .6669 Mdot
.63948 .3886 Mdot
.53622 .47109 Mdot
.3677 .51155 Mdot
.43996 .3881 Mdot
.58301 .36179 Mdot
.43422 .35689 Mdot
.66005 .51264 Mdot
.39068 .53282 Mdot
.59265 .54244 Mdot
.42823 .38717 Mdot
.63359 .37608 Mdot
.61845 .53971 Mdot
.32822 .69013 Mdot
.55783 .17918 Mdot
.38738 .67211 Mdot
.70959 .46371 Mdot
.66284 .43506 Mdot
.32012 .61752 Mdot
.64915 .60145 Mdot
.61601 .70967 Mdot
.49342 .17946 Mdot
.56093 .36126 Mdot
.69792 .56883 Mdot
.47343 .64949 Mdot
.61738 .54385 Mdot
.40112 .22981 Mdot
.64678 .52616 Mdot
.3372 .72028 Mdot
.37104 .52877 Mdot
.60607 .3698 Mdot
.64664 .58794 Mdot
.63115 .52975 Mdot
.72752 .64642 Mdot
.63022 .62726 Mdot
.63967 .56132 Mdot
.61122 .39987 Mdot
.45587 .39414 Mdot
.56928 .60842 Mdot
.4185 .53734 Mdot
.32626 .54779 Mdot
.60217 .60574 Mdot
.32631 .5351 Mdot
.63499 .35343 Mdot
.61984 .53461 Mdot
.45579 .37858 Mdot
.60025 .59896 Mdot
.5556 .30559 Mdot
.59835 .35333 Mdot
.63869 .53586 Mdot
.4203 .69113 Mdot
.63468 .78731 Mdot
.61424 .36345 Mdot
.36511 .61126 Mdot
.66627 .58794 Mdot
.63004 .56167 Mdot
.59688 .35987 Mdot
.31302 .50847 Mdot
.42227 .2156 Mdot
.55796 .38266 Mdot
.47075 .37928 Mdot
.60027 .4164 Mdot
.69345 .54638 Mdot
.36464 .52903 Mdot
.24447 .46503 Mdot
.48308 .32382 Mdot
.526 .68557 Mdot
.61443 .54916 Mdot
.49226 .26365 Mdot
.36554 .54624 Mdot
.59421 .37404 Mdot
.43098 .35451 Mdot
.6575 .64281 Mdot
.59122 .34379 Mdot
.41125 .36395 Mdot
.40758 .68549 Mdot
.31829 .4166 Mdot
.61641 .33855 Mdot
.43391 .53551 Mdot
.40642 .35084 Mdot
.4498 .40229 Mdot
.22792 .65333 Mdot
.58404 .36503 Mdot
.42401 .67436 Mdot
.43434 .34865 Mdot
.501 .68983 Mdot
.58034 .52876 Mdot
.58315 .73376 Mdot
.81371 .57725 Mdot
.20554 .57938 Mdot
.34228 .42638 Mdot
.42455 .64506 Mdot
.46966 .36011 Mdot
.65605 .56034 Mdot
.60052 .39749 Mdot
.57524 .38807 Mdot
.57932 .55322 Mdot
.65682 .57973 Mdot
.6008 .53664 Mdot
.63031 .5277 Mdot
.6719 .31301 Mdot
.64136 .61894 Mdot
.78031 .61004 Mdot
.61069 .37086 Mdot
.65082 .57291 Mdot
.32571 .50318 Mdot
.67618 .61604 Mdot
.43283 .38465 Mdot
.62712 .57532 Mdot
.64744 .58389 Mdot
.5773 .54848 Mdot
.45405 .39719 Mdot
.3394 .21575 Mdot
.73036 .67085 Mdot
.28203 .27877 Mdot
.3695 .72836 Mdot
.33308 .53019 Mdot
.62269 .54843 Mdot
.41637 .68388 Mdot
.75873 .47586 Mdot
.63205 .60506 Mdot
.79938 .69753 Mdot
.63777 .56888 Mdot
.29572 .27672 Mdot
.57423 .50737 Mdot
.20836 .35067 Mdot
.58852 .71683 Mdot
.65282 .55086 Mdot
.52689 .51491 Mdot
.52049 .39509 Mdot
.40917 .54973 Mdot
.43218 .37781 Mdot
.32807 .50043 Mdot
.3592 .496 Mdot
.39614 .34039 Mdot
.63318 .42582 Mdot
.59274 .47445 Mdot
.68893 .56697 Mdot
.38849 .54005 Mdot
.64301 .36676 Mdot
.39891 .65587 Mdot
.59156 .40784 Mdot
.54356 .13398 Mdot
.31786 .33251 Mdot
.42364 .3281 Mdot
.43485 .633 Mdot
.38135 .52329 Mdot
.32236 .54265 Mdot
.43711 .6802 Mdot
.59703 .56719 Mdot
.57863 .36725 Mdot
.18427 .56759 Mdot
.63618 .27768 Mdot
.21176 .64538 Mdot
.61629 .39495 Mdot
.5441 .24918 Mdot
.41424 .36365 Mdot
.33635 .51089 Mdot
.63307 .56097 Mdot
.60225 .56588 Mdot
.6079 .32459 Mdot
.60015 .53832 Mdot
.57761 .64699 Mdot
.63871 .55218 Mdot
.26936 .4173 Mdot
.39144 .68755 Mdot
.39712 .33888 Mdot
.52902 .66931 Mdot
.56413 .38333 Mdot
.52108 .7862 Mdot
.32425 .53738 Mdot
.74735 .47021 Mdot
.42874 .39106 Mdot
.40396 .67733 Mdot
.33743 .54819 Mdot
.39526 .66387 Mdot
.60899 .62621 Mdot
.35716 .48687 Mdot
.43681 .68628 Mdot
.63898 .44597 Mdot
.61544 .52154 Mdot
.66458 .28996 Mdot
.46777 .37622 Mdot
.55661 .38741 Mdot
.58633 .5367 Mdot
.32687 .52658 Mdot
.65445 .6361 Mdot
.36191 .37568 Mdot
.25067 .46114 Mdot
.30499 .52642 Mdot
.26628 .51366 Mdot
.40308 .65948 Mdot
.35531 .33952 Mdot
.52727 .26048 Mdot
.62894 .37472 Mdot
.64061 .62192 Mdot
.19321 .3585 Mdot
.4348 .34892 Mdot
.59954 .59383 Mdot
.21129 .51587 Mdot
.44461 .3558 Mdot
.61821 .57384 Mdot
.44777 .3427 Mdot
.57375 .38652 Mdot
.65312 .76065 Mdot
.62663 .3681 Mdot
.66218 .53496 Mdot
.45849 .37805 Mdot
.3281 .4928 Mdot
.59924 .39396 Mdot
.59305 .5689 Mdot
.63284 .5415 Mdot
.50634 .47019 Mdot
.64907 .5672 Mdot
.33186 .23085 Mdot
.64501 .54968 Mdot
.34165 .49691 Mdot
.60138 .61169 Mdot
.54323 .85088 Mdot
.4031 .30202 Mdot
.58192 .36307 Mdot
.3127 .50126 Mdot
.37091 .50557 Mdot
.37919 .62054 Mdot
.4525 .32389 Mdot
.65415 .60253 Mdot
.33111 .53058 Mdot
.57483 .76831 Mdot
.40597 .36696 Mdot
.64402 .62263 Mdot
.44007 .53436 Mdot
.26654 .60102 Mdot
.36415 .55995 Mdot
.60306 .63287 Mdot
.62351 .34061 Mdot
.64859 .58747 Mdot
.31106 .52771 Mdot
.59902 .31415 Mdot
.67528 .56708 Mdot
.65148 .37201 Mdot
.50731 .46784 Mdot
.41161 .38583 Mdot
.57482 .50309 Mdot
.59258 .58393 Mdot
.32687 .51199 Mdot
.56752 .38974 Mdot
.4063 .35881 Mdot
.58602 .38926 Mdot
.19622 .42102 Mdot
.54976 .31484 Mdot
.65913 .4035 Mdot
.45027 .64095 Mdot
.24364 .58149 Mdot
.19306 .38193 Mdot
.45804 .80735 Mdot
.50274 .77086 Mdot
.17678 .4959 Mdot
.31492 .51236 Mdot
.22118 .53151 Mdot
.36519 .50019 Mdot
.66667 .57475 Mdot
.36516 .52429 Mdot
.18933 .38175 Mdot
.63952 .55384 Mdot
.36107 .51985 Mdot
.55384 .79008 Mdot
.65199 .57844 Mdot
.61588 .35429 Mdot
.41067 .18511 Mdot
.49456 .83014 Mdot
.25045 .45124 Mdot
.38638 .50303 Mdot
.46761 .75671 Mdot
.64227 .56048 Mdot
.60364 .61638 Mdot
.61864 .38223 Mdot
.6517 .6207 Mdot
.41011 .64612 Mdot
.43683 .63421 Mdot
.50916 .40258 Mdot
.65658 .70294 Mdot
.56654 .52244 Mdot
.60532 .39214 Mdot
.68982 .31726 Mdot
.31321 .68575 Mdot
.25349 .57344 Mdot
.44018 .33605 Mdot
.40322 .19161 Mdot
.61789 .66016 Mdot
.38927 .41423 Mdot
.38921 .57599 Mdot
.60889 .35879 Mdot
.32012 .23185 Mdot
.43499 .37479 Mdot
.79036 .39723 Mdot
.49599 .61046 Mdot
.59932 .57091 Mdot
.42773 .394 Mdot
.54985 .59218 Mdot
.47242 .83097 Mdot
.80438 .38841 Mdot
.6254 .6824 Mdot
.66512 .53543 Mdot
.34229 .69785 Mdot
.62873 .56967 Mdot
.44302 .21587 Mdot
.64366 .54666 Mdot
.5936 .38907 Mdot
.4757 .22554 Mdot
.5211 .4279 Mdot
.74496 .65655 Mdot
.36944 .30313 Mdot
.42375 .64474 Mdot
.63377 .55503 Mdot
.59945 .57329 Mdot
.41147 .6481 Mdot
.59611 .33495 Mdot
.62856 .52669 Mdot
.50461 .78372 Mdot
.60953 .54189 Mdot
.43979 .37987 Mdot
.59272 .67205 Mdot
.60046 .43431 Mdot
.68457 .56573 Mdot
.63777 .3787 Mdot
.41154 .38883 Mdot
.45499 .37033 Mdot
.56744 .52774 Mdot
.45694 .40153 Mdot
.63903 .57592 Mdot
.80946 .3843 Mdot
.61559 .34128 Mdot
.53407 .58636 Mdot
.57038 .35743 Mdot
.70333 .46636 Mdot
.459 .3663 Mdot
.28324 .39404 Mdot
.63533 .65001 Mdot
.43244 .37227 Mdot
.5515 .31667 Mdot
.59096 .51197 Mdot
.65155 .52182 Mdot
.30904 .71858 Mdot
.38024 .49848 Mdot
.52352 .45256 Mdot
.43909 .34276 Mdot
.59018 .57384 Mdot
.67902 .59044 Mdot
.41357 .39235 Mdot
.74404 .3249 Mdot
.53354 .81136 Mdot
.64209 .5509 Mdot
.60178 .38387 Mdot
.59169 .37615 Mdot
.66467 .53197 Mdot
.61938 .61659 Mdot
.35479 .54149 Mdot
.33246 .48788 Mdot
.38324 .49254 Mdot
.50943 .46452 Mdot
.27546 .4039 Mdot
.28906 .32352 Mdot
.46032 .39693 Mdot
.52345 .28212 Mdot
.35232 .72939 Mdot
.68959 .5902 Mdot
.38311 .53563 Mdot
.60339 .59357 Mdot
.6405 .58548 Mdot
.40238 .37455 Mdot
.22532 .47316 Mdot
.57121 .62644 Mdot
.60376 .33213 Mdot
.41596 .34552 Mdot
.70924 .59545 Mdot
.40573 .28596 Mdot
.41561 .68709 Mdot
.24319 .65569 Mdot
.43124 .38961 Mdot
.61232 .35458 Mdot
.45946 .35836 Mdot
.60175 .55867 Mdot
.57367 .59579 Mdot
.6006 .36259 Mdot
.44138 .64588 Mdot
.65701 .63273 Mdot
.61925 .57105 Mdot
.80246 .63558 Mdot
.37041 .74124 Mdot
.27711 .41853 Mdot
.65061 .55097 Mdot
.68194 .56502 Mdot
.41185 .69771 Mdot
.60516 .54591 Mdot
.60032 .53285 Mdot
.67795 .74902 Mdot
.49511 .32174 Mdot
.44711 .64384 Mdot
.77725 .35569 Mdot
.62042 .39185 Mdot
.23007 .31522 Mdot
.33177 .51344 Mdot
.46877 .34297 Mdot
.56293 .81078 Mdot
.3577 .56314 Mdot
.34815 .4303 Mdot
.25278 .29254 Mdot
.523 .45039 Mdot
.28322 .52255 Mdot
.62759 .65615 Mdot
.62196 .52939 Mdot
.62611 .56475 Mdot
.4138 .67902 Mdot
.57731 .37144 Mdot
.51855 .46787 Mdot
.66258 .24055 Mdot
.63154 .5782 Mdot
.54709 .62372 Mdot
.6197 .249 Mdot
.27058 .60488 Mdot
.43049 .6558 Mdot
.4392 .63924 Mdot
.63072 .55697 Mdot
.65084 .77647 Mdot
.59165 .39557 Mdot
.59323 .57054 Mdot
.65529 .60566 Mdot
.38046 .49644 Mdot
.60121 .34802 Mdot
.31266 .5179 Mdot
.30396 .36824 Mdot
.28406 .28211 Mdot
.81792 .62208 Mdot
.4572 .36722 Mdot
.51313 .20087 Mdot
.42082 .34696 Mdot
.61185 .70523 Mdot
.33419 .55261 Mdot
.64069 .60462 Mdot
.56596 .38638 Mdot
.59377 .58089 Mdot
.62599 .61652 Mdot
.59722 .56968 Mdot
.68589 .58745 Mdot
.72413 .76842 Mdot
.44257 .66694 Mdot
.6629 .52102 Mdot
.3515 .4937 Mdot
.43931 .20507 Mdot
.54931 .1831 Mdot
.60317 .57868 Mdot
.63285 .54614 Mdot
.60469 .33833 Mdot
.58177 .56735 Mdot
.41151 .35601 Mdot
.57095 .3976 Mdot
.63335 .53076 Mdot
.41594 .19563 Mdot
.64952 .53536 Mdot
.23571 .32117 Mdot
.45515 .352 Mdot
.59259 .28744 Mdot
.64258 .51112 Mdot
.2543 .46033 Mdot
.5235 .45267 Mdot
.34724 .54774 Mdot
.46253 .40128 Mdot
.35402 .5092 Mdot
.70922 .257 Mdot
.57472 .58859 Mdot
.65861 .56136 Mdot
.67397 .59972 Mdot
.33152 .52843 Mdot
.37539 .24243 Mdot
.3516 .32979 Mdot
.7073 .58437 Mdot
.34012 .53298 Mdot
.64042 .3808 Mdot
.47643 .69688 Mdot
.56805 .3673 Mdot
.43091 .629 Mdot
.41796 .37857 Mdot
.43253 .63853 Mdot
.20243 .51012 Mdot
.59961 .35468 Mdot
.54915 .36351 Mdot
.3368 .51773 Mdot
.46486 .57452 Mdot
.25731 .75575 Mdot
.48703 .60054 Mdot
.55377 .71128 Mdot
.61589 .3826 Mdot
.66872 .54494 Mdot
.59239 .69062 Mdot
.47163 .55379 Mdot
.3567 .5089 Mdot
.63282 .59963 Mdot
.63532 .77339 Mdot
.35446 .54184 Mdot
.64154 .62307 Mdot
.36653 .49257 Mdot
.42581 .38016 Mdot
.38194 .53234 Mdot
.58287 .33263 Mdot
.6249 .5384 Mdot
.21644 .70349 Mdot
.38375 .66156 Mdot
.64667 .5574 Mdot
.41987 .34284 Mdot
.48888 .40216 Mdot
.61866 .61004 Mdot
.40466 .68709 Mdot
.3565 .52978 Mdot
.48302 .60424 Mdot
.64261 .54901 Mdot
.33326 .52781 Mdot
.61066 .41075 Mdot
.47369 .38348 Mdot
.66407 .48802 Mdot
.25787 .45557 Mdot
.61908 .38338 Mdot
.42622 .52272 Mdot
.432 .41324 Mdot
.68283 .56714 Mdot
.64875 .61587 Mdot
.59776 .38203 Mdot
.66599 .73131 Mdot
.58684 .59138 Mdot
.64856 .60165 Mdot
.34386 .49382 Mdot
.35542 .51399 Mdot
.65278 .74846 Mdot
.31794 .5016 Mdot
.57438 .59542 Mdot
.59577 .38328 Mdot
.64459 .59191 Mdot
.60821 .3418 Mdot
.58526 .5776 Mdot
.55952 .32885 Mdot
.59077 .33613 Mdot
.39349 .31105 Mdot
.63695 .595 Mdot
.5626 .51352 Mdot
.60345 .60035 Mdot
.60843 .5369 Mdot
.35908 .54022 Mdot
.43405 .67233 Mdot
.58305 .61938 Mdot
.39355 .63956 Mdot
.39594 .66476 Mdot
.50995 .37817 Mdot
.3823 .49895 Mdot
.4176 .66895 Mdot
.63191 .24946 Mdot
.38108 .49237 Mdot
.4077 .66759 Mdot
.54259 .18423 Mdot
.45676 .36038 Mdot
.62211 .34194 Mdot
.65322 .57851 Mdot
.18813 .48039 Mdot
.80596 .5554 Mdot
.4107 .52112 Mdot
.6459 .55156 Mdot
.60736 .60041 Mdot
.55766 .37475 Mdot
.75798 .2812 Mdot
.39287 .52658 Mdot
.66624 .55097 Mdot
.58612 .35712 Mdot
.81171 .34392 Mdot
.34403 .49853 Mdot
.40889 .67182 Mdot
.46339 .38994 Mdot
.64951 .35946 Mdot
.48459 .32594 Mdot
.41992 .39397 Mdot
.39087 .55179 Mdot
.28082 .38576 Mdot
.666 .58869 Mdot
.37882 .54172 Mdot
.25676 .68586 Mdot
.64574 .29438 Mdot
.50392 .36384 Mdot
.45859 .75318 Mdot
.60979 .36065 Mdot
.41478 .35298 Mdot
.43562 .64828 Mdot
.61129 .39784 Mdot
.61971 .35458 Mdot
.40555 .38636 Mdot
.72862 .55339 Mdot
.44096 .53927 Mdot
.44671 .37891 Mdot
.31608 .71405 Mdot
.22988 .40636 Mdot
.38325 .53643 Mdot
.40937 .6477 Mdot
.2009 .49296 Mdot
.5787 .38553 Mdot
.39702 .19225 Mdot
.26068 .68135 Mdot
.63971 .56149 Mdot
.42199 .66765 Mdot
.34638 .27092 Mdot
.67325 .23094 Mdot
.44672 .35823 Mdot
.51274 .43152 Mdot
.41447 .63952 Mdot
.58343 .5403 Mdot
.48491 .69801 Mdot
.65072 .5963 Mdot
.41465 .37105 Mdot
.66859 .40574 Mdot
.61256 .35283 Mdot
.40398 .38814 Mdot
.24155 .65526 Mdot
.63744 .57788 Mdot
.63627 .59769 Mdot
.52043 .65456 Mdot
.5823 .39917 Mdot
.34639 .5478 Mdot
.66102 .5959 Mdot
.62257 .57279 Mdot
.56344 .5801 Mdot
.57405 .50092 Mdot
.63183 .78553 Mdot
.66908 .5629 Mdot
.35038 .31198 Mdot
.68363 .55325 Mdot
.63128 .59372 Mdot
.639 .37561 Mdot
.81367 .64704 Mdot
.31097 .3564 Mdot
.62596 .57395 Mdot
.66965 .54819 Mdot
.41006 .39881 Mdot
.45007 .53537 Mdot
.46068 .57294 Mdot
.47599 .60063 Mdot
.48678 .76514 Mdot
.69084 .56038 Mdot
.57675 .36111 Mdot
.43267 .69068 Mdot
.67726 .5712 Mdot
.57942 .35856 Mdot
.57624 .54286 Mdot
.35244 .54221 Mdot
.3753 .48923 Mdot
.57004 .30798 Mdot
.41405 .66335 Mdot
.53125 .63009 Mdot
.51045 .28687 Mdot
.33248 .49613 Mdot
.66077 .56286 Mdot
.44026 .32604 Mdot
.31294 .53111 Mdot
.28465 .5476 Mdot
.64946 .49094 Mdot
.58829 .39746 Mdot
.60919 .36888 Mdot
.58605 .736 Mdot
.33457 .41318 Mdot
.75873 .6764 Mdot
.42423 .38029 Mdot
.58834 .60303 Mdot
.50953 .25711 Mdot
.61195 .36642 Mdot
.5942 .69745 Mdot
.41845 .66655 Mdot
.44566 .35525 Mdot
.30498 .46758 Mdot
.59602 .34069 Mdot
.62577 .35805 Mdot
.63745 .52344 Mdot
.61137 .57251 Mdot
.51252 .77241 Mdot
.43549 .71145 Mdot
.40986 .38464 Mdot
.40787 .64913 Mdot
.34742 .55454 Mdot
.66995 .56032 Mdot
.56425 .36163 Mdot
.23132 .43947 Mdot
.67248 .55737 Mdot
.3615 .54141 Mdot
.60615 .3641 Mdot
.40409 .65319 Mdot
.39769 .67984 Mdot
.60958 .53769 Mdot
.69212 .33195 Mdot
.44349 .37088 Mdot
.61556 .35664 Mdot
.4031 .29069 Mdot
.60719 .61736 Mdot
.61277 .56521 Mdot
.61308 .49091 Mdot
.40398 .37082 Mdot
.57946 .26991 Mdot
.4161 .63287 Mdot
.5819 .37115 Mdot
.65565 .54811 Mdot
.40791 .66043 Mdot
.55465 .26347 Mdot
.30545 .52817 Mdot
.38225 .52925 Mdot
.40333 .68727 Mdot
.42602 .65963 Mdot
.40195 .68298 Mdot
.39817 .1908 Mdot
.56367 .35164 Mdot
.6206 .65968 Mdot
.58809 .59689 Mdot
.57514 .71892 Mdot
.67671 .63856 Mdot
.40668 .35345 Mdot
.38027 .50003 Mdot
.61567 .61211 Mdot
.66715 .5402 Mdot
.5981 .4961 Mdot
.54317 .60537 Mdot
.57811 .42785 Mdot
.59971 .35133 Mdot
.57353 .57344 Mdot
.36879 .49005 Mdot
.56206 .13237 Mdot
.15585 .48743 Mdot
.62484 .50899 Mdot
.4406 .5647 Mdot
.56387 .36068 Mdot
.43302 .40905 Mdot
.47051 .61422 Mdot
.46207 .36532 Mdot
.58612 .37117 Mdot
.66975 .56279 Mdot
.52148 .28827 Mdot
.40671 .69196 Mdot
.58823 .55699 Mdot
.41904 .35494 Mdot
.58942 .54552 Mdot
.42173 .39521 Mdot
.1979 .40152 Mdot
.37387 .76069 Mdot
.63772 .56778 Mdot
.66892 .52741 Mdot
.45192 .76412 Mdot
.60359 .58231 Mdot
.40634 .72278 Mdot
.56487 .3578 Mdot
.71535 .68494 Mdot
.60819 .51972 Mdot
.74839 .39555 Mdot
.61183 .62106 Mdot
.60105 .77969 Mdot
.60985 .56542 Mdot
.27407 .61993 Mdot
.63374 .53574 Mdot
.60741 .53201 Mdot
.46037 .3739 Mdot
.40764 .39453 Mdot
.6335 .38073 Mdot
.32973 .53176 Mdot
.25943 .29601 Mdot
.61704 .56867 Mdot
.24851 .46061 Mdot
.52711 .30807 Mdot
.42645 .65744 Mdot
.58352 .37403 Mdot
.75747 .27204 Mdot
.45785 .35018 Mdot
.39054 .74262 Mdot
.61001 .76649 Mdot
.43467 .303 Mdot
.4743 .644 Mdot
.46846 .22129 Mdot
.40245 .66352 Mdot
.5773 .55364 Mdot
.22993 .4618 Mdot
.27553 .6419 Mdot
.6482 .48969 Mdot
.42361 .41308 Mdot
.75425 .4566 Mdot
.2235 .45699 Mdot
.40108 .64224 Mdot
.42769 .63522 Mdot
.43847 .40429 Mdot
.30557 .47129 Mdot
.55362 .60307 Mdot
.4193 .66303 Mdot
.32976 .49486 Mdot
.3925 .5123 Mdot
.3474 .56599 Mdot
.58273 .39345 Mdot
.21402 .61453 Mdot
.41347 .274 Mdot
.41682 .39085 Mdot
.29404 .49855 Mdot
.57636 .4204 Mdot
.5619 .34926 Mdot
.34207 .51305 Mdot
.36716 .53872 Mdot
.61418 .33216 Mdot
.56361 .54994 Mdot
.58708 .50309 Mdot
.62975 .57555 Mdot
.42354 .68428 Mdot
.60645 .56852 Mdot
.34676 .53566 Mdot
.4434 .35867 Mdot
.37471 .53007 Mdot
.44114 .33841 Mdot
.30515 .3147 Mdot
.59336 .55645 Mdot
.62761 .538 Mdot
.81715 .53468 Mdot
.62318 .3996 Mdot
.34016 .31277 Mdot
.26355 .44684 Mdot
.36324 .49821 Mdot
.59678 .53392 Mdot
.56675 .39535 Mdot
.40663 .63282 Mdot
.82431 .51945 Mdot
.61096 .61334 Mdot
.56632 .3587 Mdot
.66045 .54955 Mdot
.66264 .3133 Mdot
.60561 .82701 Mdot
.58637 .3857 Mdot
.81279 .57622 Mdot
.66218 .54138 Mdot
.54925 .21679 Mdot
.66854 .60378 Mdot
.58196 .75758 Mdot
.58739 .59207 Mdot
.61839 .39377 Mdot
.6261 .57823 Mdot
.57883 .40211 Mdot
.32911 .50253 Mdot
.44361 .40692 Mdot
.61909 .37518 Mdot
.65695 .60833 Mdot
.09441 .51807 Mdot
.4172 .36991 Mdot
.63316 .55834 Mdot
.46275 .38552 Mdot
.57377 .36941 Mdot
.62438 .37313 Mdot
.64183 .21783 Mdot
.3101 .3647 Mdot
.42634 .37933 Mdot
.66733 .55669 Mdot
.41977 .25441 Mdot
.64903 .5933 Mdot
.53629 .75903 Mdot
.56083 .54663 Mdot
.59696 .60686 Mdot
.5652 .18179 Mdot
.4059 .3755 Mdot
.74663 .69408 Mdot
.62882 .20957 Mdot
.44813 .19757 Mdot
.64439 .33829 Mdot
.40225 .63964 Mdot
.32901 .22467 Mdot
.2807 .39831 Mdot
.33616 .53076 Mdot
.60962 .60721 Mdot
.60385 .42998 Mdot
.44944 .37142 Mdot
.4348 .675 Mdot
.63732 .56699 Mdot
.37088 .53707 Mdot
.48969 .80984 Mdot
.46613 .35364 Mdot
.57794 .38253 Mdot
.59149 .33418 Mdot
.84845 .4423 Mdot
.6524 .54945 Mdot
.62658 .5351 Mdot
.41596 .37579 Mdot
.60069 .25234 Mdot
.40054 .66592 Mdot
.53442 .79598 Mdot
.42541 .37805 Mdot
.48596 .49821 Mdot
.58804 .36024 Mdot
.60559 .59821 Mdot
.35386 .24679 Mdot
.33746 .68662 Mdot
.80065 .43659 Mdot
.4173 .68376 Mdot
.5304 .75556 Mdot
.62051 .39241 Mdot
.43137 .35184 Mdot
.31358 .43376 Mdot
.69427 .59201 Mdot
.60746 .59577 Mdot
.53387 .75179 Mdot
.52699 .41889 Mdot
.61762 .68093 Mdot
.61187 .6159 Mdot
.53617 .44086 Mdot
.5927 .59554 Mdot
.69519 .60455 Mdot
.56676 .57758 Mdot
.61353 .55547 Mdot
.56531 .3593 Mdot
.69489 .53783 Mdot
.34384 .54239 Mdot
.60506 .66502 Mdot
.49303 .5053 Mdot
.64434 .55473 Mdot
.65968 .5873 Mdot
.79428 .47434 Mdot
.39739 .43684 Mdot
.61667 .37218 Mdot
.57392 .33074 Mdot
.46519 .39401 Mdot
.59176 .49947 Mdot
.33146 .53702 Mdot
.67987 .63356 Mdot
.36202 .53851 Mdot
.56481 .36823 Mdot
.35557 .49695 Mdot
.45825 .39641 Mdot
.39057 .52121 Mdot
.27451 .40463 Mdot
.43718 .34679 Mdot
.60126 .39819 Mdot
.61678 .53997 Mdot
.4205 .34286 Mdot
.5187 .67527 Mdot
.42197 .68404 Mdot
.62376 .1999 Mdot
.63664 .53049 Mdot
.49441 .32564 Mdot
.65386 .34821 Mdot
.37133 .53348 Mdot
.64431 .7949 Mdot
.5947 .33405 Mdot
.44729 .64889 Mdot
.56278 .37974 Mdot
.33777 .73524 Mdot
.43125 .66947 Mdot
.53022 .17972 Mdot
.26872 .48513 Mdot
.44184 .71817 Mdot
.56728 .54164 Mdot
.49317 .65301 Mdot
.36478 .55741 Mdot
.44988 .37038 Mdot
.33008 .43435 Mdot
.59986 .534 Mdot
.42153 .78841 Mdot
.6358 .34979 Mdot
.33213 .53371 Mdot
.4316 .35677 Mdot
.408 .3543 Mdot
.63132 .6206 Mdot
.28979 .58413 Mdot
.58851 .57778 Mdot
.32797 .39636 Mdot
.49669 .76165 Mdot
.5444 .59083 Mdot
.63823 .55273 Mdot
.32693 .50975 Mdot
.6608 .54991 Mdot
.45368 .6573 Mdot
.20945 .62085 Mdot
.65926 .6239 Mdot
.26686 .438 Mdot
.38646 .64035 Mdot
.60028 .35946 Mdot
.55179 .5803 Mdot
.28637 .401 Mdot
.65686 .55114 Mdot
.59624 .86677 Mdot
.40768 .66464 Mdot
.23434 .47579 Mdot
.68237 .58918 Mdot
.64705 .61138 Mdot
.53499 .48618 Mdot
.51959 .38517 Mdot
.34219 .69067 Mdot
.61029 .589 Mdot
.49693 .72834 Mdot
.43729 .40012 Mdot
.59166 .5864 Mdot
.62761 .56263 Mdot
.73652 .5428 Mdot
.41368 .34974 Mdot
.3736 .50378 Mdot
.35655 .56118 Mdot
.37848 .48141 Mdot
.45198 .6604 Mdot
.50297 .44715 Mdot
.58038 .70363 Mdot
.47963 .82321 Mdot
.44203 .68373 Mdot
.6393 .52809 Mdot
.38054 .70136 Mdot
.66983 .57387 Mdot
.43524 .65327 Mdot
.41776 .34722 Mdot
.6186 .36999 Mdot
.52475 .24893 Mdot
.38765 .5387 Mdot
.64748 .62091 Mdot
.40273 .64998 Mdot
.59729 .39793 Mdot
.45736 .69501 Mdot
.5922 .36301 Mdot
.42736 .3723 Mdot
.47606 .36533 Mdot
.43725 .66629 Mdot
.57065 .36228 Mdot
.39335 .40831 Mdot
.67774 .23768 Mdot
.56899 .58877 Mdot
.48359 .37167 Mdot
.6101 .40779 Mdot
.59562 .32448 Mdot
.6032 .4052 Mdot
.59708 .54081 Mdot
.4404 .56294 Mdot
.58343 .52017 Mdot
.41032 .38438 Mdot
.37022 .49494 Mdot
.45286 .77826 Mdot
.26906 .36593 Mdot
.3956 .6014 Mdot
.58414 .59712 Mdot
.63596 .5807 Mdot
.63072 .5573 Mdot
.62257 .51743 Mdot
.31409 .40408 Mdot
.59567 .58434 Mdot
.46065 .37758 Mdot
.35555 .53308 Mdot
.57706 .55124 Mdot
.33909 .55778 Mdot
.4237 .22487 Mdot
.44323 .67967 Mdot
.50215 .4351 Mdot
.13836 .41175 Mdot
.60827 .39403 Mdot
.31095 .51128 Mdot
.33514 .52784 Mdot
.40693 .68472 Mdot
.44439 .37512 Mdot
.58746 .36352 Mdot
.55676 .77066 Mdot
.39708 .67243 Mdot
.62479 .57611 Mdot
.43907 .58866 Mdot
.4005 .77262 Mdot
.5788 .56317 Mdot
.62984 .61021 Mdot
.30763 .53323 Mdot
.26128 .53712 Mdot
.23483 .70152 Mdot
.56543 .67878 Mdot
.43565 .66903 Mdot
.44403 .65733 Mdot
.62012 .33613 Mdot
.59399 .51348 Mdot
.4113 .38611 Mdot
.62724 .67749 Mdot
.45975 .42942 Mdot
.54095 .64276 Mdot
.58887 .45357 Mdot
.60672 .6086 Mdot
.73328 .30698 Mdot
.63935 .5783 Mdot
.55988 .36076 Mdot
.57005 .3812 Mdot
.60787 .38692 Mdot
.44792 .36955 Mdot
.72387 .47407 Mdot
.45722 .38236 Mdot
.13569 .42599 Mdot
.62544 .38652 Mdot
.27908 .45419 Mdot
.33202 .50799 Mdot
.63908 .50963 Mdot
.4049 .65382 Mdot
.44265 .41968 Mdot
.66217 .51374 Mdot
.65336 .77801 Mdot
.33668 .53693 Mdot
.60668 .39661 Mdot
.48202 .21887 Mdot
.16664 .41709 Mdot
.46497 .58629 Mdot
.708 .61115 Mdot
.49289 .63488 Mdot
.42554 .65379 Mdot
.80318 .44186 Mdot
.40966 .6444 Mdot
.42288 .35026 Mdot
.62713 .5416 Mdot
.61693 .5449 Mdot
.58955 .59166 Mdot
.59453 .56954 Mdot
.43875 .41059 Mdot
.62375 .62848 Mdot
.54314 .85087 Mdot
.36393 .48566 Mdot
.64287 .43853 Mdot
.40523 .66163 Mdot
.44008 .41459 Mdot
.35413 .53405 Mdot
.38979 .43765 Mdot
.53616 .67371 Mdot
.64159 .54993 Mdot
.61266 .61032 Mdot
.38847 .74479 Mdot
.61187 .61646 Mdot
.6763 .64023 Mdot
.33404 .52885 Mdot
.39873 .60321 Mdot
.44535 .65335 Mdot
.43913 .64746 Mdot
.446 .34856 Mdot
.56542 .36897 Mdot
.41428 .67329 Mdot
.33459 .49988 Mdot
.58416 .59835 Mdot
.66484 .59567 Mdot
.61177 .4062 Mdot
.2672 .69104 Mdot
.40554 .64054 Mdot
.45515 .22296 Mdot
.56898 .38954 Mdot
.5528 .39525 Mdot
.60875 .59687 Mdot
.56701 .48623 Mdot
.64984 .36515 Mdot
.44325 .68381 Mdot
.44423 .41337 Mdot
.478 .61711 Mdot
.41136 .36696 Mdot
.5732 .37836 Mdot
.67608 .57015 Mdot
.57299 .3882 Mdot
.64934 .5498 Mdot
.19371 .32607 Mdot
.61171 .55168 Mdot
.47913 .82721 Mdot
.57243 .74104 Mdot
.34711 .52346 Mdot
.4633 .41934 Mdot
.33299 .51511 Mdot
.57069 .39254 Mdot
.67351 .58279 Mdot
.42434 .63258 Mdot
.48419 .18755 Mdot
.57474 .42111 Mdot
.35983 .54467 Mdot
.39379 .49689 Mdot
.42357 .34613 Mdot
.57875 .57523 Mdot
.60405 .59256 Mdot
.35986 .51838 Mdot
.54682 .5988 Mdot
.58704 .34362 Mdot
.63352 .54384 Mdot
.63257 .58774 Mdot
.34514 .52152 Mdot
.69031 .24386 Mdot
.53156 .36244 Mdot
.62273 .54728 Mdot
.25064 .49106 Mdot
.405 .3564 Mdot
.5706 .53386 Mdot
.67912 .53552 Mdot
.4241 .66087 Mdot
.66061 .47484 Mdot
.2039 .59061 Mdot
.43194 .33977 Mdot
.32656 .5177 Mdot
.65307 .54816 Mdot
.32664 .51135 Mdot
.65765 .6047 Mdot
.5702 .43652 Mdot
.35766 .55067 Mdot
.64513 .60733 Mdot
.56395 .5265 Mdot
.5806 .39894 Mdot
.60997 .61007 Mdot
.79 .51485 Mdot
.32101 .53871 Mdot
.64296 .61356 Mdot
.6909 .33547 Mdot
.44347 .38415 Mdot
.57038 .52182 Mdot
.43044 .6897 Mdot
.558 .77219 Mdot
.47885 .29278 Mdot
.2233 .47965 Mdot
.44296 .67633 Mdot
.58722 .54941 Mdot
.38868 .48912 Mdot
.43048 .40106 Mdot
.50649 .82795 Mdot
.58052 .54995 Mdot
.41489 .36968 Mdot
.44146 .35755 Mdot
.41707 .68706 Mdot
.82812 .58428 Mdot
.68559 .58514 Mdot
.60374 .5775 Mdot
.76146 .54869 Mdot
.60558 .4146 Mdot
.60637 .5598 Mdot
.65745 .5345 Mdot
.46066 .38094 Mdot
.68296 .63844 Mdot
.7715 .45408 Mdot
.56481 .78856 Mdot
.4037 .35405 Mdot
.48695 .57118 Mdot
.38036 .54487 Mdot
.41007 .6559 Mdot
.59834 .36623 Mdot
.40503 .6453 Mdot
.38894 .51926 Mdot
.64449 .52985 Mdot
.46783 .36936 Mdot
.78938 .55928 Mdot
.43789 .40462 Mdot
.21856 .48942 Mdot
.60478 .41339 Mdot
.48488 .25609 Mdot
.65078 .83469 Mdot
.39473 .27436 Mdot
.39254 .42579 Mdot
.42656 .65791 Mdot
.40439 .47794 Mdot
.63421 .58589 Mdot
.81025 .46616 Mdot
.61446 .53654 Mdot
.69225 .34615 Mdot
.33785 .4912 Mdot
.38317 .49236 Mdot
.62545 .54421 Mdot
.50651 .76162 Mdot
.42986 .40199 Mdot
.40566 .36915 Mdot
.63622 .61664 Mdot
.43226 .37274 Mdot
.61137 .57647 Mdot
.35455 .53891 Mdot
.74071 .71461 Mdot
.63241 .57075 Mdot
.66404 .52755 Mdot
.48766 .33711 Mdot
.58746 .19394 Mdot
.22824 .56167 Mdot
.78582 .34493 Mdot
.1604 .44359 Mdot
.43226 .37149 Mdot
.5768 .52242 Mdot
.48797 .57316 Mdot
.34788 .56153 Mdot
.39529 .41753 Mdot
.60674 .54739 Mdot
.60499 .54494 Mdot
.61073 .53064 Mdot
.63812 .59796 Mdot
.80386 .43169 Mdot
.70054 .65017 Mdot
.68691 .4134 Mdot
.62261 .61619 Mdot
.49891 .65981 Mdot
.44668 .34653 Mdot
.62211 .32754 Mdot
.4183 .70733 Mdot
.60642 .60814 Mdot
.65491 .66203 Mdot
.40226 .38682 Mdot
.13483 .42777 Mdot
.43294 .34436 Mdot
.37043 .50571 Mdot
.4324 .40787 Mdot
.64962 .56553 Mdot
.59224 .37642 Mdot
.48647 .54054 Mdot
.35247 .34499 Mdot
.33673 .53161 Mdot
.6466 .55703 Mdot
.27634 .44935 Mdot
.34212 .54017 Mdot
.41885 .22632 Mdot
.59779 .37239 Mdot
.5007 .72256 Mdot
.57033 .38409 Mdot
.64735 .60673 Mdot
.65096 .60246 Mdot
.48145 .39219 Mdot
.44581 .40503 Mdot
.56924 .38177 Mdot
.83151 .59351 Mdot
.39512 .66082 Mdot
.60281 .38987 Mdot
.67721 .62783 Mdot
.44655 .48084 Mdot
.59791 .37856 Mdot
.42315 .606 Mdot
.45157 .36325 Mdot
.63229 .36251 Mdot
.69016 .60515 Mdot
.27327 .67772 Mdot
.42775 .69521 Mdot
.29895 .5066 Mdot
.43792 .59813 Mdot
.31477 .53221 Mdot
.45678 .40566 Mdot
.33449 .51746 Mdot
.43993 .39966 Mdot
.50189 .30785 Mdot
.57773 .65584 Mdot
.45009 .33024 Mdot
.45234 .40757 Mdot
.33751 .51786 Mdot
.63417 .53974 Mdot
.45692 .61028 Mdot
.57398 .52608 Mdot
.68735 .58897 Mdot
.43517 .39574 Mdot
.61272 .39646 Mdot
.59646 .32726 Mdot
.49004 .6876 Mdot
.58287 .34007 Mdot
.36361 .53891 Mdot
.57321 .83482 Mdot
.24398 .45395 Mdot
.4214 .38655 Mdot
.42621 .40857 Mdot
.65201 .59282 Mdot
.35471 .50897 Mdot
.32302 .50947 Mdot
.41864 .35118 Mdot
.52891 .58359 Mdot
.63331 .5139 Mdot
.57252 .33429 Mdot
.63041 .37591 Mdot
.59136 .38536 Mdot
.59824 .40576 Mdot
.76831 .40954 Mdot
.45038 .35753 Mdot
.60424 .40038 Mdot
.64065 .61071 Mdot
.60492 .5467 Mdot
.4767 .58622 Mdot
.44198 .65401 Mdot
.57884 .53908 Mdot
.56722 .57532 Mdot
.60955 .60083 Mdot
.38015 .53369 Mdot
.64046 .49259 Mdot
.35529 .55122 Mdot
.36972 .48271 Mdot
.34518 .48611 Mdot
.2785 .401 Mdot
.44121 .7309 Mdot
.17414 .46674 Mdot
.66569 .54994 Mdot
.62179 .26162 Mdot
.3445 .50397 Mdot
.64697 .78743 Mdot
.58138 .26813 Mdot
.58694 .53949 Mdot
.32201 .67983 Mdot
.35718 .51842 Mdot
.58668 .3366 Mdot
.60821 .54881 Mdot
.34862 .4811 Mdot
.42709 .6927 Mdot
.59384 .61774 Mdot
.33676 .55288 Mdot
.57198 .36299 Mdot
.42959 .70376 Mdot
.63204 .37615 Mdot
.34339 .48711 Mdot
.56675 .52432 Mdot
.30713 .81013 Mdot
.39754 .50059 Mdot
.61758 .23182 Mdot
.58463 .31104 Mdot
.63333 .54209 Mdot
.30918 .5188 Mdot
.58643 .41528 Mdot
.46909 .39328 Mdot
.45415 .43663 Mdot
.61925 .34721 Mdot
.38486 .49381 Mdot
.32846 .54774 Mdot
.33462 .52998 Mdot
.60483 .35079 Mdot
.66498 .5312 Mdot
.60687 .34432 Mdot
.43054 .40746 Mdot
.65085 .58466 Mdot
.19335 .37855 Mdot
.62503 .26603 Mdot
.56874 .38603 Mdot
.37818 .50817 Mdot
.41132 .69603 Mdot
.6405 .57062 Mdot
.65233 .26626 Mdot
.64218 .54033 Mdot
.42623 .39517 Mdot
.69361 .73023 Mdot
.79886 .53873 Mdot
.58899 .59715 Mdot
.65115 .59352 Mdot
.40758 .3761 Mdot
.64088 .55999 Mdot
.58503 .58869 Mdot
.28901 .38966 Mdot
.5973 .34865 Mdot
.62807 .58059 Mdot
.35582 .49146 Mdot
.26816 .39465 Mdot
.62902 .51496 Mdot
.36902 .61763 Mdot
.50646 .73653 Mdot
.71699 .69751 Mdot
.61661 .53519 Mdot
.55369 .66363 Mdot
.63058 .60095 Mdot
.58957 .55801 Mdot
.66475 .57576 Mdot
.81488 .43147 Mdot
.36346 .54798 Mdot
.3418 .53004 Mdot
.43378 .69385 Mdot
.50403 .73472 Mdot
.42271 .6653 Mdot
.45377 .36367 Mdot
.3263 .60654 Mdot
.35665 .55059 Mdot
.56897 .36676 Mdot
.58672 .5619 Mdot
.39733 .49849 Mdot
.60287 .5948 Mdot
.65121 .56424 Mdot
.32615 .53503 Mdot
.37251 .55082 Mdot
.23035 .47589 Mdot
.43811 .68563 Mdot
.6129 .38194 Mdot
.57507 .53914 Mdot
.40028 .65468 Mdot
.67735 .55078 Mdot
.57914 .71808 Mdot
.60973 .38305 Mdot
.6006 .34655 Mdot
.59685 .32907 Mdot
.64489 .53029 Mdot
.64588 .56558 Mdot
.45581 .385 Mdot
.56377 .37754 Mdot
.44136 .38339 Mdot
.50354 .47768 Mdot
.3698 .65119 Mdot
.60668 .54729 Mdot
.4686 .22545 Mdot
.41569 .65164 Mdot
.37443 .52343 Mdot
.41271 .7672 Mdot
.43239 .69504 Mdot
.64675 .54803 Mdot
.3215 .51548 Mdot
.4372 .65318 Mdot
.65172 .48743 Mdot
.15973 .54049 Mdot
.41343 .70109 Mdot
.63893 .61229 Mdot
.69701 .63456 Mdot
.79755 .35696 Mdot
.43192 .69784 Mdot
.46543 .38435 Mdot
.6435 .53023 Mdot
.6405 .39917 Mdot
.40947 .63899 Mdot
.35404 .30635 Mdot
.35678 .52738 Mdot
.232 .62964 Mdot
.66444 .51117 Mdot
.80977 .53229 Mdot
.42181 .64219 Mdot
.58528 .36668 Mdot
.59865 .3145 Mdot
.61579 .60021 Mdot
.43082 .69824 Mdot
.40024 .36124 Mdot
.36364 .52867 Mdot
.30753 .36052 Mdot
.60689 .3504 Mdot
.45959 .24369 Mdot
.38203 .5117 Mdot
.44718 .22807 Mdot
.62593 .77198 Mdot
.57904 .51111 Mdot
.79166 .3582 Mdot
.32736 .44954 Mdot
.62899 .52294 Mdot
.3943 .67772 Mdot
.42839 .3401 Mdot
.46947 .37741 Mdot
.42439 .37378 Mdot
.51929 .30825 Mdot
.47243 .59812 Mdot
.31076 .50751 Mdot
.37167 .35575 Mdot
.41037 .65833 Mdot
.5061 .6415 Mdot
.66671 .59962 Mdot
.63522 .57892 Mdot
.57853 .57737 Mdot
.59669 .59833 Mdot
.62494 .59795 Mdot
.43866 .37687 Mdot
.49049 .31258 Mdot
.48197 .59965 Mdot
.60417 .38137 Mdot
.2843 .56805 Mdot
.33345 .50734 Mdot
.31088 .50411 Mdot
.44081 .66533 Mdot
.44365 .21754 Mdot
.33873 .55721 Mdot
.35937 .49668 Mdot
.61063 .52474 Mdot
.5965 .34135 Mdot
.7013 .60611 Mdot
.64686 .60199 Mdot
.36581 .53397 Mdot
.52554 .48676 Mdot
.78418 .46651 Mdot
.64647 .49231 Mdot
.40493 .61776 Mdot
.447 .55603 Mdot
.41823 .69903 Mdot
.67604 .58242 Mdot
.65704 .78117 Mdot
.38815 .52291 Mdot
.36433 .50694 Mdot
.42145 .64426 Mdot
.59821 .44415 Mdot
.60638 .3611 Mdot
.38068 .42063 Mdot
.45898 .39073 Mdot
.66567 .58569 Mdot
.48495 .80497 Mdot
.63477 .42609 Mdot
.29266 .59054 Mdot
.42163 .37614 Mdot
.32849 .50514 Mdot
.58457 .59476 Mdot
.63765 .61194 Mdot
.41911 .64802 Mdot
.25127 .33843 Mdot
.57609 .5911 Mdot
.43468 .19562 Mdot
.3723 .76082 Mdot
.2727 .68894 Mdot
.60734 .59548 Mdot
.59885 .34935 Mdot
.33496 .55328 Mdot
.40986 .64766 Mdot
.67229 .62421 Mdot
.16449 .51163 Mdot
.62224 .39613 Mdot
.42793 .3497 Mdot
.49672 .52224 Mdot
.46938 .61062 Mdot
.63057 .52709 Mdot
.61509 .53752 Mdot
.59415 .54723 Mdot
.17806 .59497 Mdot
.37297 .53973 Mdot
.56308 .36506 Mdot
.42654 .6866 Mdot
.5748 .34612 Mdot
.34159 .52536 Mdot
.46518 .25084 Mdot
.63669 .53743 Mdot
.62187 .39752 Mdot
.58738 .36673 Mdot
.42848 .3449 Mdot
.47324 .38326 Mdot
.50157 .49825 Mdot
.61136 .554 Mdot
.39808 .51144 Mdot
.59281 .40132 Mdot
.44335 .58996 Mdot
.43057 .668 Mdot
.45835 .36867 Mdot
.61819 .61447 Mdot
.3768 .54191 Mdot
.62651 .62943 Mdot
.61175 .36922 Mdot
.35806 .49689 Mdot
.23893 .46892 Mdot
.44501 .66566 Mdot
.59888 .55947 Mdot
.44709 .68985 Mdot
.32599 .51787 Mdot
.63478 .58789 Mdot
.5097 .20651 Mdot
.39292 .62456 Mdot
.34612 .34005 Mdot
.33173 .49134 Mdot
.25196 .45928 Mdot
.61576 .33671 Mdot
.55088 .29847 Mdot
.36775 .50756 Mdot
.47091 .21726 Mdot
.24857 .36293 Mdot
.57648 .57892 Mdot
.58146 .38712 Mdot
.37661 .4451 Mdot
.22585 .31462 Mdot
.68916 .25226 Mdot
.63185 .55932 Mdot
.31836 .50076 Mdot
.42453 .64681 Mdot
.42242 .38848 Mdot
.37051 .62239 Mdot
.39929 .6185 Mdot
.395 .51971 Mdot
.66572 .57491 Mdot
.57737 .36715 Mdot
.44766 .36444 Mdot
.48473 .29703 Mdot
.3414 .49522 Mdot
.3766 .49933 Mdot
.58537 .59532 Mdot
.41752 .66617 Mdot
.67117 .27371 Mdot
.35096 .53884 Mdot
.38801 .75116 Mdot
.3784 .55637 Mdot
.39712 .65774 Mdot
.63003 .60596 Mdot
.48441 .69116 Mdot
.59739 .51849 Mdot
.5699 .20462 Mdot
.33536 .51258 Mdot
.61164 .37492 Mdot
.60295 .53612 Mdot
.58747 .7771 Mdot
.36852 .53034 Mdot
.44269 .56496 Mdot
.26675 .6111 Mdot
.45131 .3603 Mdot
.4133 .76872 Mdot
.60383 .56682 Mdot
.43087 .40204 Mdot
.41689 .65211 Mdot
.61814 .55094 Mdot
.64669 .56808 Mdot
.55838 .38053 Mdot
.4189 .35261 Mdot
.22399 .40016 Mdot
.40509 .39112 Mdot
.45788 .35592 Mdot
.55287 .36956 Mdot
.6174 .58521 Mdot
.37133 .50503 Mdot
.35782 .5167 Mdot
.67863 .60926 Mdot
.68676 .77485 Mdot
.60879 .3586 Mdot
.30963 .48488 Mdot
.19009 .61785 Mdot
.56023 .52266 Mdot
.42873 .77753 Mdot
.2634 .32563 Mdot
.40686 .34563 Mdot
.63083 .61782 Mdot
.57204 .36653 Mdot
.40021 .45907 Mdot
.37641 .5011 Mdot
.67215 .54109 Mdot
.44252 .36324 Mdot
.42812 .69337 Mdot
.33216 .54463 Mdot
.29405 .5873 Mdot
.59242 .56111 Mdot
.31956 .6827 Mdot
.31375 .51281 Mdot
.35623 .19722 Mdot
.38446 .43946 Mdot
.58594 .38961 Mdot
.65217 .56709 Mdot
.60358 .33233 Mdot
.43142 .68349 Mdot
.49613 .51959 Mdot
.44345 .36089 Mdot
.71214 .63659 Mdot
.49472 .86325 Mdot
.33231 .52776 Mdot
.564 .35885 Mdot
.59111 .60037 Mdot
.56849 .46205 Mdot
.60613 .57355 Mdot
.64756 .65172 Mdot
.3791 .65524 Mdot
.43649 .39303 Mdot
.43817 .4022 Mdot
.6405 .58732 Mdot
.3988 .67191 Mdot
.3334 .50249 Mdot
.36701 .52654 Mdot
.49002 .14613 Mdot
.4247 .31112 Mdot
.5202 .7726 Mdot
.60212 .54784 Mdot
.39251 .50174 Mdot
.26988 .372 Mdot
.41663 .37649 Mdot
.66407 .60609 Mdot
.33216 .53703 Mdot
.29178 .68646 Mdot
.59845 .76059 Mdot
.62359 .60123 Mdot
.68716 .55049 Mdot
.46129 .38903 Mdot
.51358 .63435 Mdot
.35601 .48703 Mdot
.55924 .55193 Mdot
.46084 .33915 Mdot
.67578 .72944 Mdot
.23995 .67179 Mdot
.61287 .38239 Mdot
.25827 .56543 Mdot
.4396 .37687 Mdot
.69312 .55979 Mdot
.40446 .67001 Mdot
.35149 .55687 Mdot
.37222 .54264 Mdot
.66603 .55991 Mdot
.61804 .62607 Mdot
.43695 .76131 Mdot
.57769 .34623 Mdot
.44779 .34792 Mdot
.62374 .53611 Mdot
.52365 .24099 Mdot
.59105 .59403 Mdot
.45291 .38551 Mdot
.29701 .80941 Mdot
.57144 .54784 Mdot
.60579 .57718 Mdot
.6707 .2697 Mdot
.62068 .35039 Mdot
.56547 .3534 Mdot
.42674 .80657 Mdot
.60165 .54867 Mdot
.40047 .76005 Mdot
.61623 .37884 Mdot
.60963 .36177 Mdot
.30846 .37563 Mdot
.63786 .57253 Mdot
.71062 .65688 Mdot
.42145 .39409 Mdot
.46233 .36227 Mdot
.60843 .34658 Mdot
.57021 .56087 Mdot
.44807 .34141 Mdot
.77367 .3699 Mdot
.35286 .50869 Mdot
.6768 .76749 Mdot
.6175 .35797 Mdot
.52195 .43381 Mdot
.41954 .37793 Mdot
.1368 .42334 Mdot
.36656 .56743 Mdot
.63221 .53884 Mdot
.59739 .55534 Mdot
.41315 .65264 Mdot
.57268 .54688 Mdot
.37994 .49018 Mdot
.43219 .37329 Mdot
.67389 .35383 Mdot
.60741 .38763 Mdot
.61078 .56371 Mdot
.43415 .22247 Mdot
.34879 .29451 Mdot
.2392 .54438 Mdot
.59929 .36038 Mdot
.58287 .39236 Mdot
.36125 .48826 Mdot
.31686 .50306 Mdot
.61664 .59293 Mdot
.40779 .3718 Mdot
.56456 .37926 Mdot
.44677 .39184 Mdot
.38783 .52295 Mdot
.36963 .50136 Mdot
.36646 .5489 Mdot
.59987 .62902 Mdot
.35575 .49407 Mdot
.34244 .5933 Mdot
.45013 .24663 Mdot
.56029 .35116 Mdot
.32062 .75625 Mdot
.49403 .29748 Mdot
.53525 .33755 Mdot
.41693 .63359 Mdot
.32552 .51839 Mdot
.41928 .40447 Mdot
.64428 .59429 Mdot
.60664 .6031 Mdot
.2981 .56097 Mdot
.41953 .4003 Mdot
.43423 .67767 Mdot
.43152 .40416 Mdot
.41667 .68713 Mdot
.28622 .65516 Mdot
.577 .56568 Mdot
.66204 .59778 Mdot
.43386 .37799 Mdot
.35515 .49543 Mdot
.35018 .53128 Mdot
.42004 .70296 Mdot
.54698 .42612 Mdot
.34113 .54009 Mdot
.61672 .36171 Mdot
.75957 .38651 Mdot
.32756 .54751 Mdot
.60689 .5528 Mdot
.58725 .70393 Mdot
.81416 .50219 Mdot
.62357 .51734 Mdot
.30137 .3797 Mdot
.7934 .59412 Mdot
.58969 .54109 Mdot
.8185 .56015 Mdot
.25902 .45517 Mdot
.61077 .33658 Mdot
.34235 .48987 Mdot
.30416 .52992 Mdot
.5861 .62715 Mdot
.40083 .69702 Mdot
.67654 .61849 Mdot
.62262 .36019 Mdot
.64107 .36585 Mdot
.30595 .71214 Mdot
.61015 .22535 Mdot
.42894 .64777 Mdot
.43948 .6537 Mdot
.36906 .51091 Mdot
.66266 .20679 Mdot
.69286 .54001 Mdot
.43581 .67127 Mdot
.55443 .64266 Mdot
.66775 .57166 Mdot
.54747 .74631 Mdot
.36995 .72663 Mdot
.60378 .34863 Mdot
.49136 .66621 Mdot
.37378 .5147 Mdot
.58874 .33792 Mdot
.5353 .24968 Mdot
.58673 .52923 Mdot
.60851 .38445 Mdot
.45012 .39085 Mdot
.3534 .42455 Mdot
.62369 .37452 Mdot
.58564 .7097 Mdot
.4146 .35442 Mdot
.44253 .58563 Mdot
.49265 .70339 Mdot
.84451 .66137 Mdot
.43739 .37416 Mdot
.34802 .55168 Mdot
.35853 .51752 Mdot
.36778 .52472 Mdot
.58068 .34274 Mdot
.32316 .51072 Mdot
.57186 .35154 Mdot
.74304 .29476 Mdot
.59077 .45247 Mdot
.43646 .66591 Mdot
.31412 .35741 Mdot
.57847 .37658 Mdot
.61062 .82016 Mdot
.59043 .85758 Mdot
.62918 .61877 Mdot
.41771 .40697 Mdot
.43546 .6564 Mdot
.45635 .17881 Mdot
.42228 .65774 Mdot
.45198 .71258 Mdot
.69297 .7375 Mdot
.61351 .57123 Mdot
.75205 .4787 Mdot
.43409 .63743 Mdot
.59002 .35965 Mdot
.63598 .58554 Mdot
.40381 .44691 Mdot
.41924 .65965 Mdot
.41751 .69073 Mdot
.62323 .58938 Mdot
.60608 .39693 Mdot
.37642 .51189 Mdot
.45474 .40127 Mdot
.44575 .63977 Mdot
.55941 .33333 Mdot
.61134 .52091 Mdot
.65181 .54289 Mdot
.4657 .57119 Mdot
.46156 .65464 Mdot
.43279 .37088 Mdot
.82831 .49199 Mdot
.32615 .49576 Mdot
.36044 .44975 Mdot
.37178 .75172 Mdot
.286 .3989 Mdot
.33774 .51339 Mdot
.32869 .51667 Mdot
.6216 .59801 Mdot
.45645 .639 Mdot
.71142 .71354 Mdot
.39046 .39311 Mdot
.33237 .55204 Mdot
.36487 .52944 Mdot
.63935 .34733 Mdot
.31605 .72211 Mdot
.66996 .62666 Mdot
.43592 .33911 Mdot
.37321 .5438 Mdot
.56008 .42683 Mdot
.41415 .66536 Mdot
.62051 .80434 Mdot
.5768 .56126 Mdot
.62822 .53852 Mdot
.42998 .3608 Mdot
.45824 .38026 Mdot
.4046 .46261 Mdot
.35707 .74258 Mdot
.79751 .57705 Mdot
.46106 .29738 Mdot
.70375 .51493 Mdot
.63855 .35179 Mdot
.56904 .38667 Mdot
.36514 .30712 Mdot
.40404 .39002 Mdot
.59501 .53853 Mdot
.56596 .37242 Mdot
.28815 .47022 Mdot
.64299 .29113 Mdot
.53059 .75953 Mdot
.44379 .77829 Mdot
.64869 .55121 Mdot
.59058 .34724 Mdot
.61981 .35078 Mdot
.57693 .40586 Mdot
.26468 .45157 Mdot
.60987 .58861 Mdot
.63999 .55307 Mdot
.58368 .5596 Mdot
.53845 .54236 Mdot
.59388 .57701 Mdot
.53739 .3096 Mdot
.48263 .5062 Mdot
.65675 .45429 Mdot
.5604 .56047 Mdot
.42219 .33526 Mdot
.63276 .52753 Mdot
.39972 .67496 Mdot
.66106 .58299 Mdot
.53501 .76202 Mdot
.41705 .36121 Mdot
.53328 .35066 Mdot
.5023 .30404 Mdot
.61326 .52736 Mdot
.44706 .67276 Mdot
.48634 .41142 Mdot
.19355 .40305 Mdot
.42524 .71131 Mdot
.61669 .36067 Mdot
.34641 .50921 Mdot
.41757 .40256 Mdot
.36501 .50097 Mdot
.59912 .62748 Mdot
.36847 .30865 Mdot
.35699 .26618 Mdot
.5158 .46634 Mdot
.6002 .60153 Mdot
.63229 .49612 Mdot
.61306 .36396 Mdot
.32113 .51622 Mdot
.62694 .4253 Mdot
.60101 .53874 Mdot
.42089 .68495 Mdot
.41584 .65666 Mdot
.40907 .44353 Mdot
.31707 .25105 Mdot
.57632 .29603 Mdot
.43006 .36351 Mdot
.35335 .54127 Mdot
.4093 .64377 Mdot
.56094 .22479 Mdot
.47254 .38795 Mdot
.40754 .3773 Mdot
.42763 .34767 Mdot
.66469 .54213 Mdot
.35637 .55147 Mdot
.65757 .44769 Mdot
.39089 .5008 Mdot
.64384 .55947 Mdot
.37831 .53353 Mdot
.33389 .5362 Mdot
.40584 .65824 Mdot
.4398 .34527 Mdot
.38676 .50574 Mdot
.64813 .60677 Mdot
.61455 .38803 Mdot
.5196 .41434 Mdot
.59036 .74781 Mdot
.59041 .22086 Mdot
.66479 .33005 Mdot
.62947 .37119 Mdot
.22346 .32501 Mdot
.40443 .35641 Mdot
.52926 .57043 Mdot
.2384 .49495 Mdot
.67601 .56418 Mdot
.63311 .81859 Mdot
.30935 .50979 Mdot
.3312 .54024 Mdot
.63174 .60439 Mdot
.30023 .47481 Mdot
.60976 .56804 Mdot
.38619 .51581 Mdot
.27884 .54698 Mdot
.54717 .55847 Mdot
.3449 .49798 Mdot
.55853 .55981 Mdot
.64333 .5755 Mdot
.60286 .34723 Mdot
.30934 .52029 Mdot
.66331 .60793 Mdot
.45505 .16016 Mdot
.45651 .3781 Mdot
.28051 .44115 Mdot
.61192 .70181 Mdot
.44074 .37761 Mdot
.60002 .38948 Mdot
.68459 .59519 Mdot
.41822 .64983 Mdot
.57634 .37488 Mdot
.60521 .76305 Mdot
.4391 .64453 Mdot
.61396 .8239 Mdot
.61539 .35 Mdot
.32287 .54323 Mdot
.40336 .67206 Mdot
.57896 .52176 Mdot
.35165 .55652 Mdot
.43497 .4316 Mdot
.33728 .51152 Mdot
.60326 .59126 Mdot
.31461 .34555 Mdot
.4524 .35118 Mdot
.62917 .55898 Mdot
.32572 .53854 Mdot
.28857 .38743 Mdot
.66513 .54386 Mdot
.63589 .59519 Mdot
.2731 .69702 Mdot
.55518 .82401 Mdot
.42828 .66087 Mdot
.57553 .40956 Mdot
.64103 .61042 Mdot
.42452 .69181 Mdot
.32139 .65102 Mdot
.64271 .5321 Mdot
.61717 .40167 Mdot
.58682 .48441 Mdot
.31279 .52029 Mdot
.44671 .37999 Mdot
.51408 .46142 Mdot
.42742 .69244 Mdot
.86816 .45028 Mdot
.39162 .52059 Mdot
.67419 .58901 Mdot
.60588 .60919 Mdot
.22664 .57367 Mdot
.60864 .33637 Mdot
.7629 .62693 Mdot
.59874 .5592 Mdot
.53527 .55639 Mdot
.61814 .55464 Mdot
.30656 .49257 Mdot
.60774 .36075 Mdot
.60336 .57969 Mdot
.46473 .23259 Mdot
.65045 .51948 Mdot
.43746 .68844 Mdot
.68259 .27001 Mdot
.62045 .52062 Mdot
.41082 .86398 Mdot
.38436 .73125 Mdot
.34473 .49698 Mdot
.34498 .31424 Mdot
.60905 .1477 Mdot
.51992 .30438 Mdot
.56789 .35588 Mdot
.29653 .29867 Mdot
.37139 .50448 Mdot
.31118 .33218 Mdot
.2186 .3272 Mdot
.64609 .57738 Mdot
.63037 .52702 Mdot
.43941 .71645 Mdot
.35844 .48364 Mdot
.39097 .53559 Mdot
.5762 .60082 Mdot
.69769 .58218 Mdot
.36907 .49751 Mdot
.64696 .6112 Mdot
.58532 .61845 Mdot
.44494 .40781 Mdot
.62751 .37737 Mdot
.42804 .39278 Mdot
.42156 .34569 Mdot
.73913 .32439 Mdot
.33948 .72119 Mdot
.45318 .38265 Mdot
.41514 .34326 Mdot
.55061 .74866 Mdot
.45948 .75245 Mdot
.41089 .63801 Mdot
.36294 .20796 Mdot
.36527 .52491 Mdot
.61196 .58587 Mdot
.62772 .3614 Mdot
.79722 .55841 Mdot
.35905 .64125 Mdot
.71765 .71639 Mdot
.59748 .53882 Mdot
.37185 .52405 Mdot
.26474 .45088 Mdot
.69403 .62298 Mdot
.40514 .50269 Mdot
.62467 .53405 Mdot
.38934 .53535 Mdot
.75154 .41638 Mdot
.46215 .221 Mdot
.38572 .54708 Mdot
.56719 .33814 Mdot
.62266 .54051 Mdot
.61832 .35634 Mdot
.42302 .38203 Mdot
.40097 .66141 Mdot
.42854 .66528 Mdot
.63089 .58881 Mdot
.57597 .50856 Mdot
.29961 .66865 Mdot
.64148 .57084 Mdot
.66349 .57454 Mdot
.25877 .45527 Mdot
.6603 .57931 Mdot
.59391 .59192 Mdot
.58838 .57946 Mdot
.68189 .55186 Mdot
.46014 .35918 Mdot
.43754 .22325 Mdot
.64686 .64024 Mdot
.65106 .64293 Mdot
.47239 .37276 Mdot
.23252 .36879 Mdot
.41162 .35216 Mdot
.18931 .38277 Mdot
.42993 .39741 Mdot
.43164 .67257 Mdot
.20796 .50478 Mdot
.6121 .49892 Mdot
.59847 .40323 Mdot
.4547 .41001 Mdot
.42412 .68792 Mdot
.42777 .37397 Mdot
.38358 .51778 Mdot
.20301 .62093 Mdot
.54237 .37746 Mdot
.60654 .67577 Mdot
.41868 .42135 Mdot
.36701 .32616 Mdot
.38767 .50321 Mdot
.6103 .35441 Mdot
.78184 .47712 Mdot
.59268 .59373 Mdot
.42168 .6908 Mdot
.62021 .59317 Mdot
.44862 .34571 Mdot
.37225 .51756 Mdot
.6802 .25572 Mdot
.41865 .64838 Mdot
.31949 .74861 Mdot
.35366 .52753 Mdot
.58421 .57423 Mdot
.43845 .33969 Mdot
.3673 .7876 Mdot
.4326 .39398 Mdot
.74696 .6096 Mdot
.6242 .33496 Mdot
.78456 .33804 Mdot
.57939 .38172 Mdot
.38591 .43238 Mdot
.23773 .71424 Mdot
.46234 .19894 Mdot
.60797 .39513 Mdot
.3905 .32432 Mdot
.65183 .54871 Mdot
.6499 .54177 Mdot
.57704 .22741 Mdot
.57751 .41035 Mdot
.62286 .61804 Mdot
.24632 .46482 Mdot
.4389 .26064 Mdot
.45571 .79626 Mdot
.32959 .51171 Mdot
.60626 .5653 Mdot
.46884 .34923 Mdot
.42474 .4001 Mdot
.39307 .51365 Mdot
.40428 .36509 Mdot
.63919 .55515 Mdot
.57902 .37773 Mdot
.38638 .47259 Mdot
.42244 .67662 Mdot
.53429 .17488 Mdot
.39351 .66546 Mdot
.3381 .51392 Mdot
.5773 .51857 Mdot
.36877 .50046 Mdot
.62861 .14018 Mdot
.63679 .54939 Mdot
.6158 .37686 Mdot
.64805 .5978 Mdot
.62292 .54376 Mdot
.6288 .52606 Mdot
.37926 .50839 Mdot
.71796 .65855 Mdot
.6476 .60891 Mdot
.44454 .36065 Mdot
.66363 .47148 Mdot
.61454 .5227 Mdot
.29503 .50032 Mdot
.48952 .75143 Mdot
.37373 .38568 Mdot
.6281 .35253 Mdot
.33798 .50317 Mdot
.60666 .39053 Mdot
.63511 .42107 Mdot
.60017 .38922 Mdot
.70646 .49572 Mdot
.77626 .46198 Mdot
.72324 .66171 Mdot
.68786 .33502 Mdot
.51507 .53207 Mdot
.57625 .40985 Mdot
.40971 .72355 Mdot
.56892 .39071 Mdot
.61737 .34723 Mdot
.13418 .66396 Mdot
.58674 .40306 Mdot
.60371 .55429 Mdot
.59014 .53114 Mdot
.39735 .27788 Mdot
.54371 .71753 Mdot
.64921 .58921 Mdot
.63997 .60662 Mdot
.40378 .65752 Mdot
.53831 .5841 Mdot
.35554 .31371 Mdot
.54366 .83581 Mdot
.32921 .3063 Mdot
.62253 .59155 Mdot
.64341 .60827 Mdot
.69998 .59854 Mdot
.39045 .82549 Mdot
.78198 .36546 Mdot
.62659 .40262 Mdot
.69288 .55254 Mdot
.52994 .1913 Mdot
.62013 .52907 Mdot
.65492 .53298 Mdot
.64933 .54994 Mdot
.37178 .50528 Mdot
.63172 .38444 Mdot
.69126 .58868 Mdot
.3687 .73606 Mdot
.62968 .53023 Mdot
.28846 .39424 Mdot
.74075 .26472 Mdot
.60333 .56706 Mdot
.63463 .37621 Mdot
.66007 .54874 Mdot
.60818 .33973 Mdot
.58946 .35521 Mdot
.62331 .51001 Mdot
.69708 .50575 Mdot
.63863 .36292 Mdot
.64445 .55974 Mdot
.3784 .51961 Mdot
.34303 .21351 Mdot
.60187 .58969 Mdot
.40223 .65251 Mdot
.59827 .55454 Mdot
.44856 .66699 Mdot
.66032 .57512 Mdot
.39111 .52363 Mdot
.80523 .52416 Mdot
.36571 .50904 Mdot
.80731 .37475 Mdot
.37176 .54908 Mdot
.28133 .70671 Mdot
.61573 .40628 Mdot
.31261 .35297 Mdot
.78202 .64825 Mdot
.28283 .42408 Mdot
.43268 .55922 Mdot
.46407 .50957 Mdot
.40752 .3717 Mdot
.60761 .33313 Mdot
.51978 .6006 Mdot
.24978 .51386 Mdot
.23884 .52409 Mdot
.34313 .54407 Mdot
.8271 .59738 Mdot
.72517 .72426 Mdot
.6618 .59349 Mdot
.74115 .48862 Mdot
.69595 .42632 Mdot
.63458 .52586 Mdot
.69017 .58104 Mdot
.28976 .54947 Mdot
.62761 .62212 Mdot
.51785 .23753 Mdot
.33994 .51736 Mdot
.42268 .68837 Mdot
.61644 .36866 Mdot
.42562 .69462 Mdot
.24779 .51368 Mdot
.46114 .51249 Mdot
.38677 .52052 Mdot
.6748 .53757 Mdot
.64207 .60111 Mdot
.60364 .34278 Mdot
.60334 .42719 Mdot
.57898 .39784 Mdot
.4296 .6502 Mdot
.34548 .51902 Mdot
.81179 .46026 Mdot
.63267 .61102 Mdot
.58827 .36783 Mdot
.42913 .5474 Mdot
.63783 .61309 Mdot
.43143 .38199 Mdot
.64477 .5452 Mdot
.61568 .38981 Mdot
.66013 .57936 Mdot
.57721 .38108 Mdot
.34901 .50785 Mdot
.58884 .53599 Mdot
.62736 .60414 Mdot
.34804 .7743 Mdot
.43219 .67885 Mdot
.60418 .41327 Mdot
.27194 .50459 Mdot
.6018 .60907 Mdot
.32406 .37665 Mdot
.61894 .53775 Mdot
.63861 .28883 Mdot
.67928 .56688 Mdot
.27426 .42991 Mdot
.65584 .63301 Mdot
.60188 .58811 Mdot
.4232 .48164 Mdot
.6979 .44902 Mdot
.58708 .4203 Mdot
.43649 .33783 Mdot
.59531 .40669 Mdot
.46428 .79284 Mdot
.36631 .56467 Mdot
.31894 .51572 Mdot
.52357 .66165 Mdot
.68392 .55422 Mdot
.61333 .57349 Mdot
.47587 .3655 Mdot
.44282 .66171 Mdot
.59735 .36052 Mdot
.41713 .68712 Mdot
.3826 .76771 Mdot
.43411 .64393 Mdot
.30663 .50547 Mdot
.31846 .68002 Mdot
.7985 .42343 Mdot
.4043 .65709 Mdot
.60667 .39714 Mdot
.37084 .65813 Mdot
.66855 .53755 Mdot
.39635 .72943 Mdot
.41714 .68254 Mdot
.85204 .55254 Mdot
.59483 .5924 Mdot
.42959 .56511 Mdot
.44726 .38551 Mdot
.4039 .66729 Mdot
.4107 .36557 Mdot
.6442 .59101 Mdot
.34789 .3347 Mdot
.56604 .36372 Mdot
.46077 .35201 Mdot
.5669 .54399 Mdot
.43687 .65795 Mdot
.36755 .54545 Mdot
.4692 .40386 Mdot
.44375 .33934 Mdot
.25071 .33558 Mdot
.70608 .26824 Mdot
.34794 .51966 Mdot
.59616 .78593 Mdot
.42524 .39666 Mdot
.63408 .5235 Mdot
.54504 .61146 Mdot
.63212 .5383 Mdot
.55108 .30614 Mdot
.33407 .50534 Mdot
.40766 .26106 Mdot
.64899 .5989 Mdot
.58695 .55335 Mdot
.59121 .41924 Mdot
.36276 .51548 Mdot
.59322 .37815 Mdot
.58703 .40639 Mdot
.35064 .50865 Mdot
.58463 .38756 Mdot
.43897 .64207 Mdot
.45411 .26743 Mdot
.45398 .39651 Mdot
.44127 .35541 Mdot
.36636 .52821 Mdot
.3463 .49468 Mdot
.36085 .49726 Mdot
.64447 .54487 Mdot
.60324 .35956 Mdot
.65532 .56844 Mdot
.63322 .52847 Mdot
.70705 .52342 Mdot
.63132 .36481 Mdot
.65629 .55697 Mdot
.38549 .45018 Mdot
.43648 .62259 Mdot
.37866 .52279 Mdot
.45143 .38256 Mdot
.26255 .38702 Mdot
.47791 .40742 Mdot
.60712 .56166 Mdot
.2887 .6807 Mdot
.59392 .39955 Mdot
.41794 .65333 Mdot
.40516 .63622 Mdot
.42453 .65811 Mdot
.4014 .33647 Mdot
.58362 .41163 Mdot
.55032 .83576 Mdot
.60795 .56901 Mdot
.4639 .57256 Mdot
.56084 .64974 Mdot
.29311 .66978 Mdot
.45369 .37982 Mdot
.63966 .61002 Mdot
.52337 .45216 Mdot
.79055 .47546 Mdot
.63047 .5407 Mdot
.63975 .52053 Mdot
.2421 .47461 Mdot
.5933 .47767 Mdot
.62606 .33345 Mdot
.38785 .78634 Mdot
.57657 .57384 Mdot
.57319 .43333 Mdot
.56544 .16955 Mdot
.61029 .55136 Mdot
.59236 .54687 Mdot
.61577 .60899 Mdot
.66356 .58139 Mdot
.63636 .3624 Mdot
.51225 .69102 Mdot
.40332 .35959 Mdot
.47113 .58538 Mdot
.46788 .38009 Mdot
.36194 .55638 Mdot
.43386 .23129 Mdot
.60872 .3325 Mdot
.41343 .65229 Mdot
.43306 .20858 Mdot
.46017 .8232 Mdot
.3537 .48735 Mdot
.7625 .35973 Mdot
.4243 .68308 Mdot
.63368 .52227 Mdot
.44418 .64507 Mdot
.35444 .55127 Mdot
.44837 .3588 Mdot
.68481 .55158 Mdot
.57188 .39168 Mdot
.62407 .37163 Mdot
.62618 .61865 Mdot
.50785 .19052 Mdot
.43542 .38344 Mdot
.47706 .3767 Mdot
.65326 .53532 Mdot
.57846 .52341 Mdot
.5947 .38079 Mdot
.35512 .53693 Mdot
.54245 .78729 Mdot
.44058 .6695 Mdot
.63421 .62645 Mdot
.66599 .57552 Mdot
.36255 .74939 Mdot
.45407 .36477 Mdot
.32899 .48937 Mdot
.67049 .55342 Mdot
.45069 .30012 Mdot
.67054 .55433 Mdot
.702 .57105 Mdot
.37702 .52212 Mdot
.63999 .63771 Mdot
.65692 .60264 Mdot
.63388 .65531 Mdot
.41347 .38199 Mdot
.61151 .37999 Mdot
.54765 .37301 Mdot
.48753 .58981 Mdot
.42967 .38091 Mdot
.65855 .55422 Mdot
.45131 .37255 Mdot
.64033 .53205 Mdot
.62952 .61997 Mdot
.45264 .38551 Mdot
.59251 .37868 Mdot
.29424 .30552 Mdot
.43361 .22567 Mdot
.66233 .58456 Mdot
.58528 .59932 Mdot
.52423 .70054 Mdot
.71237 .67239 Mdot
.6068 .53615 Mdot
.62017 .38338 Mdot
.63274 .60804 Mdot
.41276 .36659 Mdot
.42905 .63644 Mdot
.61445 .38901 Mdot
.34475 .53111 Mdot
.36683 .48795 Mdot
.50831 .30355 Mdot
.32761 .52618 Mdot
.66725 .53894 Mdot
.63115 .42531 Mdot
.55136 .38789 Mdot
.55939 .1785 Mdot
.35413 .51066 Mdot
.42547 .63178 Mdot
.63557 .59348 Mdot
.27125 .67594 Mdot
.47586 .36007 Mdot
.45916 .88487 Mdot
.59653 .83007 Mdot
.40008 .693 Mdot
.7272 .69647 Mdot
.37359 .55248 Mdot
.64697 .6162 Mdot
.4001 .66334 Mdot
.3569 .4885 Mdot
.67455 .566 Mdot
.67609 .5294 Mdot
.75803 .63264 Mdot
.48931 .55424 Mdot
.45291 .37179 Mdot
.32429 .50301 Mdot
.38755 .66205 Mdot
.31708 .49404 Mdot
.62567 .36154 Mdot
.60366 .58631 Mdot
.58813 .50749 Mdot
.34898 .53513 Mdot
.34933 .48346 Mdot
.64888 .556 Mdot
.60452 .33227 Mdot
.29334 .55178 Mdot
.62645 .58639 Mdot
.52333 .52444 Mdot
.59011 .32359 Mdot
.33683 .52023 Mdot
.58713 .56698 Mdot
.38393 .62888 Mdot
.35455 .53055 Mdot
.37855 .52477 Mdot
.62866 .61924 Mdot
.44055 .64438 Mdot
.58595 .59736 Mdot
.43889 .40081 Mdot
.83392 .50571 Mdot
.41415 .36085 Mdot
.37458 .61861 Mdot
.56875 .52472 Mdot
.45206 .31459 Mdot
.62267 .34471 Mdot
.45107 .70964 Mdot
.23861 .43347 Mdot
.57274 .59625 Mdot
.28793 .2716 Mdot
.51446 .43625 Mdot
.4917 .17985 Mdot
.18596 .49576 Mdot
.41116 .67395 Mdot
.42522 .3744 Mdot
.59312 .54597 Mdot
.42712 .40953 Mdot
.39952 .65898 Mdot
.79794 .3661 Mdot
.58832 .57513 Mdot
.60845 .36225 Mdot
.64515 .55315 Mdot
.61711 .35862 Mdot
.63456 .61661 Mdot
.686 .6294 Mdot
.2497 .45765 Mdot
.59855 .75987 Mdot
.67637 .55815 Mdot
.22075 .66127 Mdot
.36298 .70109 Mdot
.43273 .68446 Mdot
.64982 .57061 Mdot
.40895 .5291 Mdot
.41744 .39732 Mdot
.5737 .24227 Mdot
.37265 .50514 Mdot
.41693 .34592 Mdot
.59365 .38665 Mdot
.33838 .50816 Mdot
.37366 .48879 Mdot
.64056 .63612 Mdot
.44035 .68704 Mdot
.43871 .34816 Mdot
.60116 .57855 Mdot
.59024 .57789 Mdot
.56145 .79779 Mdot
.35196 .62437 Mdot
.57297 .42166 Mdot
.45764 .84457 Mdot
.55105 .36733 Mdot
.43664 .67274 Mdot
.37663 .51016 Mdot
.61244 .53706 Mdot
.63023 .56141 Mdot
.3037 .36716 Mdot
.56206 .37307 Mdot
.50014 .51126 Mdot
.72437 .32729 Mdot
.29039 .54247 Mdot
.51555 .74336 Mdot
.61943 .37257 Mdot
.51872 .74325 Mdot
.39345 .64392 Mdot
.3939 .20387 Mdot
.57248 .76143 Mdot
.44848 .38284 Mdot
.51525 .74035 Mdot
.58531 .36388 Mdot
.65608 .59802 Mdot
.32056 .54164 Mdot
.33317 .53482 Mdot
.60459 .37867 Mdot
.37945 .48002 Mdot
.40698 .65833 Mdot
.59101 .5575 Mdot
.54022 .83135 Mdot
.51945 .28387 Mdot
.35903 .54157 Mdot
.68506 .6324 Mdot
.4258 .3487 Mdot
.62307 .61945 Mdot
.40742 .64833 Mdot
.44141 .37202 Mdot
.39165 .7405 Mdot
.42565 .26114 Mdot
.6358 .58933 Mdot
.29734 .71531 Mdot
.43241 .37723 Mdot
.69283 .69669 Mdot
.61901 .58741 Mdot
.42279 .39459 Mdot
.66245 .50122 Mdot
.35806 .42711 Mdot
.52482 .45703 Mdot
.22027 .3246 Mdot
.5065 .48381 Mdot
.33228 .54837 Mdot
.35734 .40143 Mdot
.30223 .45231 Mdot
.4246 .40717 Mdot
.34236 .48396 Mdot
.44282 .61467 Mdot
.41018 .36656 Mdot
.61627 .52335 Mdot
.61634 .54184 Mdot
.78357 .36314 Mdot
.50329 .44055 Mdot
.37694 .42452 Mdot
.57043 .27462 Mdot
.59759 .60425 Mdot
.57311 .56639 Mdot
.62669 .56603 Mdot
.64067 .36694 Mdot
.45102 .36681 Mdot
.27214 .71951 Mdot
.42866 .38345 Mdot
.61255 .80427 Mdot
.36695 .52373 Mdot
.33013 .50392 Mdot
.60454 .56356 Mdot
.42713 .58724 Mdot
.47387 .72402 Mdot
.63994 .55725 Mdot
.46545 .6168 Mdot
.67518 .26715 Mdot
.574 .53599 Mdot
.62509 .33933 Mdot
.60428 .64016 Mdot
.58199 .31627 Mdot
.45297 .39753 Mdot
.41513 .66875 Mdot
.46039 .70018 Mdot
.44844 .35636 Mdot
.61468 .57319 Mdot
.4178 .30368 Mdot
.62475 .54829 Mdot
.66761 .58107 Mdot
.6395 .79301 Mdot
.39318 .67051 Mdot
.35436 .50074 Mdot
.42639 .65667 Mdot
.61279 .34037 Mdot
.32092 .84167 Mdot
.44375 .6666 Mdot
.47013 .7211 Mdot
.82091 .40716 Mdot
.51842 .73866 Mdot
.62463 .36366 Mdot
.43644 .69484 Mdot
.44215 .38258 Mdot
.36176 .19273 Mdot
.77771 .6288 Mdot
.50162 .37588 Mdot
.62637 .58169 Mdot
.59052 .33315 Mdot
.62112 .38883 Mdot
.4659 .3597 Mdot
.58964 .35663 Mdot
.66364 .50453 Mdot
.66016 .59065 Mdot
.42053 .40765 Mdot
.4565 .28893 Mdot
.44038 .33776 Mdot
.4694 .25097 Mdot
.6481 .56693 Mdot
.61813 .37833 Mdot
.57258 .61029 Mdot
.63098 .32718 Mdot
.31961 .49505 Mdot
.61444 .51944 Mdot
.40758 .65665 Mdot
.4811 .33177 Mdot
.34857 .52186 Mdot
.28024 .66601 Mdot
.60625 .34297 Mdot
.37475 .36119 Mdot
.60015 .34779 Mdot
.56974 .40446 Mdot
.41712 .34854 Mdot
.57157 .3599 Mdot
.59126 .54978 Mdot
.39128 .4456 Mdot
.59524 .33896 Mdot
.42527 .35762 Mdot
.41988 .67019 Mdot
.58541 .38409 Mdot
.30379 .4721 Mdot
.62992 .59732 Mdot
.37741 .50046 Mdot
.21362 .52216 Mdot
.5568 .3643 Mdot
.41499 .69708 Mdot
.32019 .51727 Mdot
.4148 .6901 Mdot
.63372 .21443 Mdot
.41156 .40441 Mdot
.69805 .73 Mdot
.41407 .61193 Mdot
.59164 .40246 Mdot
.20988 .50316 Mdot
.61138 .53929 Mdot
.63256 .59653 Mdot
.44996 .66328 Mdot
.62073 .38924 Mdot
.4315 .19586 Mdot
.57145 .31182 Mdot
.43838 .26933 Mdot
.43369 .41683 Mdot
.25883 .68971 Mdot
.47834 .24072 Mdot
.68755 .21874 Mdot
.57345 .58539 Mdot
.38584 .54473 Mdot
.6132 .56276 Mdot
.24311 .41716 Mdot
.43521 .65713 Mdot
.34204 .47016 Mdot
.62957 .5128 Mdot
.34674 .50395 Mdot
.61551 .60299 Mdot
.42227 .46037 Mdot
.60076 .63473 Mdot
.42114 .63212 Mdot
.34807 .31602 Mdot
.59155 .40431 Mdot
.42244 .67892 Mdot
.38844 .52613 Mdot
.48594 .73056 Mdot
.67364 .57794 Mdot
.60591 .63123 Mdot
.29158 .54375 Mdot
.60954 .35697 Mdot
.31369 .5298 Mdot
.44651 .40049 Mdot
.41341 .65894 Mdot
.64517 .59493 Mdot
.67982 .55551 Mdot
.32245 .38041 Mdot
.43059 .34578 Mdot
.3787 .48431 Mdot
.4299 .39188 Mdot
.37506 .55333 Mdot
.60596 .62254 Mdot
.3283 .50529 Mdot
.65925 .60729 Mdot
.24919 .44013 Mdot
.63802 .79138 Mdot
.71194 .46417 Mdot
.33305 .50745 Mdot
.50452 .76114 Mdot
.41604 .36422 Mdot
.42625 .3938 Mdot
.81665 .43382 Mdot
.74783 .61946 Mdot
.51872 .81357 Mdot
.21298 .38138 Mdot
.46629 .38356 Mdot
.4245 .35156 Mdot
.37457 .49675 Mdot
.57383 .35498 Mdot
.5569 .38786 Mdot
.38071 .54776 Mdot
.5939 .70242 Mdot
.59716 .36068 Mdot
.33693 .22888 Mdot
.47541 .80237 Mdot
.68694 .60038 Mdot
.40592 .55753 Mdot
.41799 .66035 Mdot
.5803 .70746 Mdot
.42029 .46081 Mdot
.58859 .54746 Mdot
.3518 .73668 Mdot
.36113 .53524 Mdot
.51853 .64027 Mdot
.19041 .38297 Mdot
.58997 .5825 Mdot
.61328 .58699 Mdot
.61911 .56826 Mdot
.41137 .70271 Mdot
.76388 .60636 Mdot
.58944 .56924 Mdot
.59906 .70218 Mdot
.60922 .61614 Mdot
.7087 .54594 Mdot
.42827 .66252 Mdot
.67562 .5025 Mdot
.23311 .47603 Mdot
.4065 .78744 Mdot
.56725 .61334 Mdot
.44183 .40242 Mdot
.4762 .63235 Mdot
.41441 .38617 Mdot
.70582 .48812 Mdot
.57454 .75807 Mdot
.56084 .3478 Mdot
.59063 .54534 Mdot
.33774 .51447 Mdot
.62244 .38702 Mdot
.34343 .40249 Mdot
.22134 .76784 Mdot
.4361 .40374 Mdot
.71251 .21541 Mdot
.43228 .39676 Mdot
.38075 .49218 Mdot
.59588 .38146 Mdot
.77253 .45231 Mdot
.46742 .56739 Mdot
.58324 .38476 Mdot
.34437 .27372 Mdot
.62242 .40993 Mdot
.50152 .75089 Mdot
.56691 .34818 Mdot
.4212 .35997 Mdot
.39947 .34071 Mdot
.66473 .51301 Mdot
.60379 .54755 Mdot
.46214 .50312 Mdot
.4666 .74229 Mdot
.60724 .54204 Mdot
.34246 .5175 Mdot
.72761 .68019 Mdot
.4866 .6608 Mdot
.57409 .3643 Mdot
.40221 .35695 Mdot
.61231 .59056 Mdot
.67041 .56286 Mdot
.67089 .5819 Mdot
.4877 .86115 Mdot
.40029 .19896 Mdot
.64702 .60903 Mdot
.60175 .61147 Mdot
.34171 .5067 Mdot
.39982 .6282 Mdot
.2356 .41532 Mdot
.73156 .58972 Mdot
.59353 .53553 Mdot
.42789 .67596 Mdot
.39266 .67465 Mdot
.67481 .56255 Mdot
.36575 .72893 Mdot
.411 .30926 Mdot
.60097 .57939 Mdot
.7378 .62621 Mdot
.27434 .47806 Mdot
.35777 .4838 Mdot
.34859 .53277 Mdot
.62729 .3876 Mdot
.32928 .52277 Mdot
.38038 .54471 Mdot
.77808 .4348 Mdot
.49671 .49887 Mdot
.42026 .32862 Mdot
.42885 .6493 Mdot
.62943 .55768 Mdot
.56525 .41306 Mdot
.43858 .29967 Mdot
.40909 .36153 Mdot
.58856 .39701 Mdot
.4177 .39513 Mdot
.43492 .70504 Mdot
.58791 .66964 Mdot
.34677 .54718 Mdot
.46605 .37578 Mdot
.42752 .26113 Mdot
.42839 .67322 Mdot
.43294 .34296 Mdot
.38715 .30786 Mdot
.60108 .52379 Mdot
.75555 .51366 Mdot
.64147 .56122 Mdot
.46122 .1831 Mdot
.44414 .3469 Mdot
.27304 .42148 Mdot
.60964 .57793 Mdot
.35554 .52836 Mdot
.69485 .53903 Mdot
.62235 .53262 Mdot
.34142 .53312 Mdot
.66059 .59481 Mdot
.39776 .67747 Mdot
.58013 .32596 Mdot
.47583 .58682 Mdot
.79618 .68709 Mdot
.43999 .68793 Mdot
.34022 .39401 Mdot
.60335 .53661 Mdot
.68193 .24969 Mdot
.58456 .38235 Mdot
.66946 .59589 Mdot
.49418 .66501 Mdot
.58254 .34382 Mdot
.59886 .39439 Mdot
.66472 .55725 Mdot
.44371 .38718 Mdot
.3452 .52258 Mdot
.42792 .66765 Mdot
.62903 .20245 Mdot
.63395 .57905 Mdot
.62964 .60603 Mdot
.42311 .68174 Mdot
.4187 .35533 Mdot
.66712 .54899 Mdot
.21079 .55001 Mdot
.46674 .16498 Mdot
.40592 .37423 Mdot
.61016 .52572 Mdot
.74856 .54111 Mdot
.55914 .32942 Mdot
.83904 .39755 Mdot
.39237 .73057 Mdot
.34655 .50003 Mdot
.60618 .47935 Mdot
.35379 .84542 Mdot
.41669 .66817 Mdot
.47499 .82058 Mdot
.67151 .57017 Mdot
.62813 .61378 Mdot
.5813 .39824 Mdot
.65586 .56338 Mdot
.56607 .35483 Mdot
.79555 .67559 Mdot
.35718 .74977 Mdot
.6136 .35378 Mdot
.57556 .39834 Mdot
.48292 .69628 Mdot
.23773 .41485 Mdot
.60411 .38085 Mdot
.61134 .62224 Mdot
.65835 .38943 Mdot
.69844 .64122 Mdot
.44846 .65234 Mdot
.23719 .50832 Mdot
.54431 .33649 Mdot
.39677 .70841 Mdot
.26336 .32663 Mdot
.53747 .347 Mdot
.42209 .31371 Mdot
.44909 .39679 Mdot
.58673 .57752 Mdot
.33058 .53167 Mdot
.32101 .51258 Mdot
.5747 .60964 Mdot
.63019 .55104 Mdot
.61081 .34122 Mdot
.4263 .64456 Mdot
.42485 .4048 Mdot
.63943 .60633 Mdot
.48081 .6831 Mdot
.44272 .67012 Mdot
.58319 .35285 Mdot
.73254 .64457 Mdot
.41898 .6312 Mdot
.663 .64363 Mdot
.59775 .5673 Mdot
.6488 .55124 Mdot
.68506 .64863 Mdot
.45903 .37454 Mdot
.21631 .48585 Mdot
.57661 .55127 Mdot
.38305 .76907 Mdot
.52326 .40695 Mdot
.68749 .62094 Mdot
.59912 .35433 Mdot
.47418 .35527 Mdot
.3054 .52865 Mdot
.509 .61424 Mdot
.63674 .58576 Mdot
.44852 .20711 Mdot
.7577 .33524 Mdot
.31394 .50237 Mdot
.57282 .40636 Mdot
.42043 .65488 Mdot
.63839 .55647 Mdot
.67914 .48543 Mdot
.61163 .54623 Mdot
.4547 .66633 Mdot
.37314 .53182 Mdot
.44808 .39659 Mdot
.4864 .17674 Mdot
.32167 .51166 Mdot
.60502 .39163 Mdot
.1397 .41051 Mdot
.57752 .34092 Mdot
.57289 .40091 Mdot
.67418 .48708 Mdot
.45858 .38136 Mdot
.38813 .86724 Mdot
.8263 .55556 Mdot
.59439 .51707 Mdot
.41555 .37027 Mdot
.60661 .37317 Mdot
.6162 .61598 Mdot
.60869 .32926 Mdot
.58875 .41356 Mdot
.59917 .6188 Mdot
.60752 .60542 Mdot
.4426 .23285 Mdot
.21154 .34145 Mdot
.42126 .65311 Mdot
.61924 .3467 Mdot
.51788 .54676 Mdot
.61012 .61231 Mdot
.60764 .56982 Mdot
.31459 .44954 Mdot
.43829 .64024 Mdot
.54594 .2434 Mdot
.67145 .56661 Mdot
.33634 .73894 Mdot
.59972 .63745 Mdot
.63569 .35541 Mdot
.40563 .36892 Mdot
.40744 .784 Mdot
.40644 .41518 Mdot
.56342 .36568 Mdot
.4188 .64486 Mdot
.54668 .38072 Mdot
.46667 .7238 Mdot
.46066 .35702 Mdot
.61569 .38983 Mdot
.51564 .45978 Mdot
.43825 .36542 Mdot
.45355 .35578 Mdot
.66081 .47052 Mdot
.39067 .48681 Mdot
.40588 .69712 Mdot
.43442 .34757 Mdot
.5311 .55338 Mdot
.4239 .36496 Mdot
.82095 .48721 Mdot
.58954 .53509 Mdot
.54911 .66978 Mdot
.40559 .57513 Mdot
.62369 .49735 Mdot
.45391 .35219 Mdot
.40467 .65211 Mdot
.66599 .55239 Mdot
.58507 .36159 Mdot
.4316 .68827 Mdot
.48237 .39454 Mdot
.37111 .49958 Mdot
.59785 .34672 Mdot
.43621 .4191 Mdot
.62143 .36458 Mdot
.51833 .60175 Mdot
.83699 .45048 Mdot
.21627 .60222 Mdot
.47261 .56038 Mdot
.6708 .58062 Mdot
.21872 .39529 Mdot
.68055 .61701 Mdot
.63134 .54646 Mdot
.33842 .51976 Mdot
.52445 .65697 Mdot
.5934 .37857 Mdot
.46765 .17196 Mdot
.46241 .38588 Mdot
.38541 .78474 Mdot
.65509 .37884 Mdot
.67343 .58746 Mdot
.59493 .33826 Mdot
.5754 .34179 Mdot
.69024 .44379 Mdot
.30182 .52198 Mdot
.68906 .57764 Mdot
.69122 .56953 Mdot
.60082 .6257 Mdot
.45592 .36333 Mdot
.2881 .67648 Mdot
.33835 .5503 Mdot
.83291 .40848 Mdot
.36754 .53763 Mdot
.46681 .61503 Mdot
.57368 .35933 Mdot
.44396 .66193 Mdot
.60629 .57101 Mdot
.61175 .42233 Mdot
.5616 .36948 Mdot
.45264 .6492 Mdot
.40339 .66951 Mdot
.33814 .43872 Mdot
.45341 .38436 Mdot
.67633 .55244 Mdot
.58738 .56598 Mdot
.65618 .57095 Mdot
.64129 .54522 Mdot
.44131 .40429 Mdot
.65218 .53996 Mdot
.46325 .34518 Mdot
.55451 .63677 Mdot
.34136 .72909 Mdot
.49992 .48641 Mdot
.62952 .28253 Mdot
.5785 .36397 Mdot
.53399 .52408 Mdot
.69003 .63335 Mdot
.66239 .77809 Mdot
.64579 .26144 Mdot
.58061 .52872 Mdot
.35124 .48869 Mdot
.71825 .64216 Mdot
.34003 .54437 Mdot
.77335 .26906 Mdot
.31457 .38852 Mdot
.2416 .30778 Mdot
.5926 .58107 Mdot
.30012 .46116 Mdot
.54618 .52723 Mdot
.67788 .61097 Mdot
.3259 .41335 Mdot
.55733 .30272 Mdot
.37268 .27488 Mdot
.41493 .63936 Mdot
.62624 .59392 Mdot
.57031 .41503 Mdot
.59033 .55423 Mdot
.60994 .56486 Mdot
.67267 .5608 Mdot
.42113 .3409 Mdot
.68706 .58087 Mdot
.63927 .53716 Mdot
.29804 .66251 Mdot
.54117 .75259 Mdot
.32044 .50647 Mdot
.81072 .40979 Mdot
.44303 .67379 Mdot
.60424 .33918 Mdot
.35339 .24674 Mdot
.44927 .38219 Mdot
.69104 .43468 Mdot
.64484 .54778 Mdot
.42756 .24277 Mdot
.4598 .41571 Mdot
.41111 .65766 Mdot
.33442 .55167 Mdot
.28638 .26221 Mdot
.34407 .51364 Mdot
.52066 .45225 Mdot
.35575 .52474 Mdot
.66244 .64863 Mdot
.6119 .34201 Mdot
.67155 .54996 Mdot
.43879 .34974 Mdot
.33554 .52604 Mdot
.53493 .707 Mdot
.62503 .56555 Mdot
.35141 .50809 Mdot
.67111 .54932 Mdot
.58891 .67218 Mdot
.62002 .77251 Mdot
.38658 .53413 Mdot
.44892 .33476 Mdot
.43704 .35935 Mdot
.43993 .64427 Mdot
.59696 .34243 Mdot
.57513 .39194 Mdot
.43941 .37153 Mdot
.75941 .64971 Mdot
.60115 .53281 Mdot
.60697 .60861 Mdot
.38971 .77918 Mdot
.59977 .54208 Mdot
.48835 .74262 Mdot
.52293 .45451 Mdot
.5809 .35807 Mdot
.64368 .61659 Mdot
.66932 .56832 Mdot
.63516 .59143 Mdot
.53303 .6283 Mdot
.35424 .53866 Mdot
.5814 .5606 Mdot
.40339 .67458 Mdot
.40117 .46331 Mdot
.62236 .61965 Mdot
.61323 .63342 Mdot
.57674 .39337 Mdot
.47808 .84274 Mdot
.43732 .39721 Mdot
.38999 .51298 Mdot
.33312 .50404 Mdot
.24019 .50642 Mdot
.52816 .3975 Mdot
.51872 .46002 Mdot
.81643 .37476 Mdot
.25056 .46041 Mdot
.43121 .68301 Mdot
.41479 .5259 Mdot
.53937 .42427 Mdot
.37595 .49417 Mdot
.43407 .40431 Mdot
.58564 .53705 Mdot
.59274 .53535 Mdot
.62737 .81716 Mdot
.67751 .57355 Mdot
.42103 .6592 Mdot
.46844 .35463 Mdot
.58545 .36457 Mdot
.41193 .65632 Mdot
.42505 .39123 Mdot
.60875 .35506 Mdot
.58071 .53364 Mdot
.57975 .53775 Mdot
.58691 .3959 Mdot
.61409 .39385 Mdot
.60038 .57179 Mdot
.325 .58226 Mdot
.60089 .40356 Mdot
.62038 .37808 Mdot
.34819 .54809 Mdot
.33365 .53392 Mdot
.65431 .63565 Mdot
.4179 .37386 Mdot
.64248 .53728 Mdot
.33846 .51033 Mdot
.43238 .64308 Mdot
.58926 .37684 Mdot
.66416 .58208 Mdot
.64455 .60338 Mdot
.42729 .67295 Mdot
.41932 .64062 Mdot
.40493 .66304 Mdot
.44702 .33853 Mdot
.64954 .5762 Mdot
.59923 .38516 Mdot
.45283 .38814 Mdot
.39329 .67825 Mdot
.43968 .63765 Mdot
.32729 .48501 Mdot
.6125 .53573 Mdot
.40885 .48444 Mdot
.29518 .81273 Mdot
.4236 .76002 Mdot
.30636 .51285 Mdot
.30257 .50225 Mdot
.53502 .73389 Mdot
.44633 .58977 Mdot
.43658 .3797 Mdot
.45457 .63709 Mdot
.45558 .7064 Mdot
.62106 .52037 Mdot
.57787 .57693 Mdot
.69125 .55166 Mdot
.40697 .67212 Mdot
.50748 .64785 Mdot
.61251 .3325 Mdot
.70293 .32515 Mdot
.43969 .68081 Mdot
.3505 .48325 Mdot
.38712 .48219 Mdot
.36898 .53679 Mdot
.58253 .53815 Mdot
.71296 .45822 Mdot
.55704 .47675 Mdot
.20426 .40815 Mdot
.44511 .3458 Mdot
.5479 .3959 Mdot
.66658 .2477 Mdot
.59172 .39538 Mdot
.35977 .55481 Mdot
.42074 .68755 Mdot
.62055 .38605 Mdot
.41178 .39013 Mdot
.42812 .34976 Mdot
.36068 .54034 Mdot
.36851 .52592 Mdot
.3844 .51529 Mdot
.57701 .40726 Mdot
.57278 .35879 Mdot
.63894 .58228 Mdot
.58358 .37376 Mdot
.57942 .84197 Mdot
.42627 .70663 Mdot
.29393 .51565 Mdot
.42454 .3766 Mdot
.61666 .35576 Mdot
.62823 .56496 Mdot
.48496 .61072 Mdot
.54927 .29342 Mdot
.40862 .68656 Mdot
.58122 .78955 Mdot
.77278 .27154 Mdot
.67741 .55289 Mdot
.45455 .36671 Mdot
.53807 .8296 Mdot
.62122 .56982 Mdot
.37655 .51545 Mdot
.23613 .45077 Mdot
.37208 .56488 Mdot
.63422 .52927 Mdot
.65681 .52556 Mdot
.4038 .36768 Mdot
.80208 .36462 Mdot
.63828 .57778 Mdot
.54052 .25194 Mdot
.39887 .37752 Mdot
.34185 .55151 Mdot
.43884 .16112 Mdot
.22852 .56471 Mdot
.58292 .70385 Mdot
.35087 .54878 Mdot
.62245 .54283 Mdot
.3451 .54437 Mdot
.40215 .67936 Mdot
.37757 .54106 Mdot
.62112 .33293 Mdot
.31357 .51729 Mdot
.6285 .60668 Mdot
.60664 .37976 Mdot
.43212 .37822 Mdot
.41432 .80739 Mdot
.34599 .66934 Mdot
.35676 .52886 Mdot
.39244 .51569 Mdot
.65257 .60709 Mdot
.5159 .23335 Mdot
.55943 .57128 Mdot
.59549 .59205 Mdot
.46773 .37615 Mdot
.59084 .34105 Mdot
.40798 .35198 Mdot
.66388 .61001 Mdot
.20531 .54659 Mdot
.43373 .39236 Mdot
.42145 .23742 Mdot
.4256 .68343 Mdot
.4386 .45666 Mdot
.63165 .55958 Mdot
.41717 .35282 Mdot
.64898 .57519 Mdot
.61622 .33428 Mdot
.48103 .45091 Mdot
.35582 .30934 Mdot
.4441 .35415 Mdot
.46163 .19408 Mdot
.43423 .60467 Mdot
.55617 .5347 Mdot
.41884 .39079 Mdot
.49472 .65813 Mdot
.37487 .4891 Mdot
.43992 .67271 Mdot
.39691 .654 Mdot
.42629 .69362 Mdot
.56356 .5726 Mdot
.55404 .59067 Mdot
.39567 .67782 Mdot
.41083 .39371 Mdot
.41776 .63346 Mdot
.55495 .4192 Mdot
.43681 .19617 Mdot
.4348 .65961 Mdot
.62217 .58614 Mdot
.5702 .62377 Mdot
.54661 .74716 Mdot
.36817 .43317 Mdot
.25966 .29356 Mdot
.59793 .25388 Mdot
.60522 .54773 Mdot
.55907 .34203 Mdot
.62669 .35848 Mdot
.51271 .82636 Mdot
.46769 .75279 Mdot
.38563 .75721 Mdot
.57529 .39979 Mdot
.31414 .34907 Mdot
.58736 .35001 Mdot
.67484 .5796 Mdot
.61275 .61279 Mdot
.55893 .38722 Mdot
.30801 .70563 Mdot
.33732 .35977 Mdot
.54154 .17967 Mdot
.62259 .37161 Mdot
.41277 .38163 Mdot
.4723 .36891 Mdot
.45537 .35652 Mdot
.48687 .80576 Mdot
.57299 .34748 Mdot
.65268 .58124 Mdot
.33285 .50908 Mdot
.58212 .55048 Mdot
.44481 .36681 Mdot
.46511 .17223 Mdot
.57281 .37821 Mdot
.60154 .58593 Mdot
.69665 .67706 Mdot
.37186 .51129 Mdot
.4304 .67636 Mdot
.65231 .67596 Mdot
.39867 .75328 Mdot
.46229 .36867 Mdot
.55531 .36509 Mdot
.28156 .40593 Mdot
.41354 .23012 Mdot
.57152 .5711 Mdot
.6902 .60742 Mdot
.66027 .20816 Mdot
.39292 .74142 Mdot
.65537 .53087 Mdot
.38586 .4993 Mdot
.29967 .37264 Mdot
.64954 .59692 Mdot
.62408 .35309 Mdot
.40463 .64137 Mdot
.41934 .69063 Mdot
.6527 .63059 Mdot
.46253 .57489 Mdot
.45536 .4363 Mdot
.6579 .55284 Mdot
.66705 .64274 Mdot
.34628 .55121 Mdot
.24849 .46288 Mdot
.37911 .76805 Mdot
.41804 .64401 Mdot
.66929 .54832 Mdot
.30193 .30894 Mdot
.5641 .38794 Mdot
.31196 .51163 Mdot
.45392 .34791 Mdot
.57202 .65619 Mdot
.3446 .55359 Mdot
.65215 .59612 Mdot
.6686 .55243 Mdot
.42592 .343 Mdot
.63555 .35444 Mdot
.40861 .67617 Mdot
.33018 .50839 Mdot
.41241 .64474 Mdot
.57949 .34475 Mdot
.57708 .37247 Mdot
.71932 .62694 Mdot
.61779 .50626 Mdot
.34668 .53121 Mdot
.64198 .62282 Mdot
.275 .5007 Mdot
.79889 .34137 Mdot
.4554 .40948 Mdot
.67672 .54886 Mdot
.64061 .35728 Mdot
.44815 .35751 Mdot
.61872 .61291 Mdot
.63421 .19879 Mdot
.60976 .61329 Mdot
.50762 .37569 Mdot
.21162 .60373 Mdot
.40662 .65289 Mdot
.69363 .31942 Mdot
.54821 .21678 Mdot
.59647 .54665 Mdot
.3473 .49331 Mdot
.69804 .61169 Mdot
.44114 .38612 Mdot
.57373 .36296 Mdot
.8399 .39246 Mdot
.42592 .36106 Mdot
.59146 .5669 Mdot
.41279 .6582 Mdot
.56648 .35022 Mdot
.46537 .63754 Mdot
.36209 .72825 Mdot
.55325 .56884 Mdot
.62731 .62878 Mdot
.64853 .54405 Mdot
.19655 .49455 Mdot
.3897 .51456 Mdot
.61311 .36749 Mdot
.45561 .36662 Mdot
.44039 .37376 Mdot
.36012 .53856 Mdot
.41191 .2739 Mdot
.44072 .45542 Mdot
.29176 .79605 Mdot
.34083 .53508 Mdot
.42485 .69763 Mdot
.53243 .24203 Mdot
.34197 .49352 Mdot
.35605 .50926 Mdot
.34293 .54905 Mdot
.38853 .38686 Mdot
.60602 .35708 Mdot
.64815 .6026 Mdot
.62792 .35174 Mdot
.62458 .54066 Mdot
.51948 .39899 Mdot
.44381 .35174 Mdot
.56913 .36924 Mdot
.64569 .20945 Mdot
.77703 .55423 Mdot
.62009 .57717 Mdot
.67473 .24849 Mdot
.61038 .51196 Mdot
.50873 .72555 Mdot
.65009 .51501 Mdot
.36257 .52674 Mdot
.57499 .49406 Mdot
.59041 .62168 Mdot
.46771 .82946 Mdot
.42377 .37811 Mdot
.35663 .48475 Mdot
.61549 .51694 Mdot
.63541 .64887 Mdot
.56286 .39683 Mdot
.62117 .38305 Mdot
.39472 .66644 Mdot
.6077 .75949 Mdot
.43144 .38062 Mdot
.8198 .53934 Mdot
.60127 .55155 Mdot
.2556 .65011 Mdot
.6898 .34163 Mdot
.61628 .61114 Mdot
.56688 .21854 Mdot
.70521 .44897 Mdot
.63632 .55729 Mdot
.50643 .53632 Mdot
.41872 .3565 Mdot
.20599 .55932 Mdot
.60909 .61847 Mdot
.37392 .508 Mdot
.5783 .35248 Mdot
.60861 .33145 Mdot
.39601 .67568 Mdot
.70919 .7424 Mdot
.41189 .34796 Mdot
.57055 .3659 Mdot
.62183 .56191 Mdot
.46068 .37576 Mdot
.32661 .52055 Mdot
.67721 .58713 Mdot
.47436 .75791 Mdot
.58536 .3701 Mdot
.62183 .62483 Mdot
.51889 .26564 Mdot
.5814 .7286 Mdot
.16042 .4821 Mdot
.45741 .36745 Mdot
.43348 .6388 Mdot
.69823 .60778 Mdot
.75388 .63861 Mdot
.57137 .53735 Mdot
.54383 .66397 Mdot
.53446 .39803 Mdot
.43177 .63711 Mdot
.61268 .58134 Mdot
.64707 .59178 Mdot
.41703 .57411 Mdot
.42371 .64255 Mdot
.58703 .57068 Mdot
.57478 .63954 Mdot
.60907 .35888 Mdot
.35851 .56092 Mdot
.59118 .3642 Mdot
.62562 .58182 Mdot
.64076 .5084 Mdot
.59242 .40046 Mdot
.75495 .28237 Mdot
.39528 .69015 Mdot
.43937 .39577 Mdot
.57933 .51675 Mdot
.57727 .56264 Mdot
.22547 .68151 Mdot
.32482 .49166 Mdot
.2559 .37942 Mdot
.27295 .61421 Mdot
.27376 .32619 Mdot
.22902 .56644 Mdot
.1799 .36664 Mdot
.35822 .74448 Mdot
.68499 .59113 Mdot
.62608 .30583 Mdot
.54581 .48038 Mdot
.45079 .34793 Mdot
.80049 .4389 Mdot
.60425 .54691 Mdot
.61124 .56308 Mdot
.31056 .51215 Mdot
.40585 .25866 Mdot
.38227 .75866 Mdot
.46878 .59826 Mdot
.41035 .67735 Mdot
.61804 .3469 Mdot
.63797 .61477 Mdot
.50692 .51178 Mdot
.32026 .50538 Mdot
.26192 .65939 Mdot
.60448 .58689 Mdot
.65618 .77856 Mdot
.52483 .31087 Mdot
.45746 .37816 Mdot
.33514 .50035 Mdot
.39211 .74945 Mdot
.61608 .53435 Mdot
.45642 .34877 Mdot
.63524 .57289 Mdot
.34994 .58298 Mdot
.6564 .61417 Mdot
.43795 .66052 Mdot
.6723 .57204 Mdot
.47284 .61797 Mdot
.13419 .45505 Mdot
.45905 .66763 Mdot
.59546 .3313 Mdot
.29449 .52833 Mdot
.35229 .53712 Mdot
.61643 .39064 Mdot
.35162 .53451 Mdot
.69023 .40277 Mdot
.76059 .42525 Mdot
.41748 .68396 Mdot
.6361 .64637 Mdot
.43159 .65781 Mdot
.31556 .49825 Mdot
.61206 .54092 Mdot
.79179 .31333 Mdot
.34022 .52629 Mdot
.22743 .65255 Mdot
.42559 .36789 Mdot
.33857 .48624 Mdot
.60983 .61701 Mdot
.2852 .40966 Mdot
.32166 .50919 Mdot
.35992 .30863 Mdot
.63575 .59031 Mdot
.57944 .36782 Mdot
.65114 .5923 Mdot
.59018 .51408 Mdot
.39765 .51596 Mdot
.63424 .53372 Mdot
.42479 .39095 Mdot
.5949 .40684 Mdot
.34822 .21104 Mdot
.55161 .31012 Mdot
.58723 .55256 Mdot
.62129 .56421 Mdot
.55357 .39508 Mdot
.58092 .56599 Mdot
.44152 .40413 Mdot
.60202 .88173 Mdot
.42625 .68318 Mdot
.393 .50477 Mdot
.22673 .56429 Mdot
.58241 .52841 Mdot
.65901 .54526 Mdot
.61266 .18851 Mdot
.22074 .57505 Mdot
.42084 .39115 Mdot
.58092 .61284 Mdot
.3234 .51516 Mdot
.41487 .65861 Mdot
.4116 .39721 Mdot
.64929 .5524 Mdot
.60801 .57448 Mdot
.43558 .64157 Mdot
.63809 .45447 Mdot
.4567 .79779 Mdot
.43102 .34182 Mdot
.58003 .49653 Mdot
.29135 .48925 Mdot
.61084 .53111 Mdot
.50807 .81071 Mdot
.61694 .38683 Mdot
.46459 .37239 Mdot
.22225 .40801 Mdot
.64841 .52918 Mdot
.40657 .36759 Mdot
.42982 .38088 Mdot
.57997 .60964 Mdot
.64305 .36598 Mdot
.59663 .41166 Mdot
.62143 .36257 Mdot
.60931 .83977 Mdot
.56599 .71139 Mdot
.38432 .51527 Mdot
.41911 .35553 Mdot
.38238 .54321 Mdot
.44072 .69355 Mdot
.53619 .44643 Mdot
.39034 .52592 Mdot
.62748 .3792 Mdot
.29807 .53223 Mdot
.64254 .59315 Mdot
.43378 .37849 Mdot
.3796 .49792 Mdot
.59476 .51895 Mdot
.49231 .2281 Mdot
.36921 .40743 Mdot
.43284 .63354 Mdot
.40107 .6451 Mdot
.62163 .61777 Mdot
.3086 .53393 Mdot
.60145 .57042 Mdot
.46025 .39886 Mdot
.51346 .237 Mdot
.5731 .53263 Mdot
.35733 .5308 Mdot
.54745 .35842 Mdot
.39722 .75113 Mdot
.55888 .53986 Mdot
.62114 .58557 Mdot
.62616 .53672 Mdot
.63579 .57258 Mdot
.37221 .2657 Mdot
.43456 .41561 Mdot
.61691 .28368 Mdot
.21304 .49547 Mdot
.57854 .3846 Mdot
.62577 .39899 Mdot
.42067 .76492 Mdot
.40471 .31396 Mdot
.41683 .3711 Mdot
.63446 .54572 Mdot
.46371 .30564 Mdot
.45602 .17227 Mdot
.71562 .23457 Mdot
.37694 .65218 Mdot
.32459 .49436 Mdot
.55382 .3708 Mdot
.32894 .5 Mdot
.6188 .54294 Mdot
.69987 .59625 Mdot
.17301 .37125 Mdot
.39929 .35492 Mdot
.41605 .68525 Mdot
.62743 .53925 Mdot
.57382 .71159 Mdot
.33981 .50703 Mdot
.39579 .49631 Mdot
.58911 .58267 Mdot
.63798 .36957 Mdot
.17144 .57938 Mdot
.45854 .37281 Mdot
.59088 .25093 Mdot
.55138 .51241 Mdot
.58336 .27159 Mdot
.44907 .36741 Mdot
.36257 .71485 Mdot
.3072 .51566 Mdot
.66817 .40471 Mdot
.57694 .38562 Mdot
.43185 .68735 Mdot
.69036 .61437 Mdot
.57389 .39392 Mdot
.33922 .55177 Mdot
.57564 .36566 Mdot
.67425 .56458 Mdot
.40797 .40001 Mdot
.34659 .49875 Mdot
.41676 .33042 Mdot
.64143 .37367 Mdot
.41624 .64645 Mdot
.44569 .53923 Mdot
.79595 .48946 Mdot
.70222 .44494 Mdot
.58042 .55252 Mdot
.51346 .50227 Mdot
.65425 .57751 Mdot
.6063 .41532 Mdot
.63002 .56747 Mdot
.55689 .41666 Mdot
.34426 .49493 Mdot
.60296 .6128 Mdot
.65408 .54938 Mdot
.79117 .40311 Mdot
.60953 .59392 Mdot
.67592 .60023 Mdot
.63753 .55388 Mdot
.61935 .42823 Mdot
.6273 .64395 Mdot
.60209 .35306 Mdot
.33616 .69541 Mdot
.35898 .5105 Mdot
.40436 .64341 Mdot
.44356 .67864 Mdot
.55182 .67478 Mdot
.29778 .57712 Mdot
.40207 .26795 Mdot
.59599 .36609 Mdot
.42715 .38788 Mdot
.63358 .56811 Mdot
.19324 .39918 Mdot
.27674 .47275 Mdot
.32212 .52408 Mdot
.5517 .3097 Mdot
.60201 .48428 Mdot
.1881 .51266 Mdot
.62892 .62544 Mdot
.64613 .80675 Mdot
.61406 .50379 Mdot
.6603 .61026 Mdot
.39089 .53102 Mdot
.42341 .71039 Mdot
.5868 .58409 Mdot
.56185 .39534 Mdot
.44075 .66121 Mdot
.63547 .31555 Mdot
.39317 .46636 Mdot
.34301 .69013 Mdot
.77481 .40095 Mdot
.64515 .5751 Mdot
.34901 .49831 Mdot
.59962 .34589 Mdot
.37657 .7663 Mdot
.45171 .3899 Mdot
.45218 .32506 Mdot
.52272 .53607 Mdot
.70112 .25009 Mdot
.4426 .67209 Mdot
.65129 .46507 Mdot
.63049 .60689 Mdot
.37285 .62984 Mdot
.57365 .56541 Mdot
.46047 .17418 Mdot
.43137 .69693 Mdot
.61893 .39996 Mdot
.41374 .38141 Mdot
.62765 .35578 Mdot
.70509 .46027 Mdot
.40092 .56558 Mdot
.47838 .49051 Mdot
.34638 .51209 Mdot
.41772 .46183 Mdot
.61042 .37467 Mdot
.66463 .54353 Mdot
.28675 .79394 Mdot
.61967 .38121 Mdot
.56008 .36412 Mdot
.82222 .40415 Mdot
.79749 .33278 Mdot
.58717 .4852 Mdot
.58653 .4023 Mdot
.35144 .51366 Mdot
.4212 .65037 Mdot
.65985 .58229 Mdot
.64251 .58466 Mdot
.57756 .3954 Mdot
.3967 .50898 Mdot
.74857 .55967 Mdot
.36747 .52527 Mdot
.61081 .35615 Mdot
.3656 .50841 Mdot
.26888 .42299 Mdot
.36714 .48921 Mdot
.57771 .56337 Mdot
.63104 .56755 Mdot
.26032 .55878 Mdot
.57747 .37207 Mdot
.65985 .55503 Mdot
.65994 .5969 Mdot
.60031 .3831 Mdot
.42549 .72037 Mdot
.7396 .54057 Mdot
.59647 .53937 Mdot
.62594 .59717 Mdot
.43028 .63723 Mdot
.54232 .45546 Mdot
.69137 .72154 Mdot
.66596 .55262 Mdot
.41621 .70403 Mdot
.57183 .40147 Mdot
.59979 .5772 Mdot
.3935 .21186 Mdot
.30108 .37017 Mdot
.6573 .53406 Mdot
.37047 .48755 Mdot
.59579 .62419 Mdot
.16511 .50391 Mdot
.59478 .59178 Mdot
.6014 .37667 Mdot
.57576 .34988 Mdot
.81994 .5306 Mdot
.60912 .38876 Mdot
.33317 .53464 Mdot
.441 .3659 Mdot
.46564 .18221 Mdot
.32649 .51966 Mdot
.56926 .53075 Mdot
.83031 .5482 Mdot
.68264 .58003 Mdot
.58091 .52461 Mdot
.18652 .58326 Mdot
.32804 .51633 Mdot
.6006 .33603 Mdot
.44059 .57539 Mdot
.68318 .53391 Mdot
.46266 .36743 Mdot
.67726 .6327 Mdot
.6032 .52801 Mdot
.21384 .61161 Mdot
.33142 .31461 Mdot
.47074 .37747 Mdot
.69018 .58855 Mdot
.66509 .55142 Mdot
.40922 .53215 Mdot
.62645 .5624 Mdot
.42627 .64881 Mdot
.5817 .34203 Mdot
.3468 .49067 Mdot
.42425 .67405 Mdot
.60062 .54589 Mdot
.40637 .66941 Mdot
.37805 .50127 Mdot
.46349 .35957 Mdot
.61793 .53886 Mdot
.44825 .65086 Mdot
.40841 .673 Mdot
.65792 .57314 Mdot
.57484 .36049 Mdot
.61081 .50154 Mdot
.59988 .58704 Mdot
.66612 .58088 Mdot
.5742 .39045 Mdot
.63602 .15573 Mdot
.60185 .6045 Mdot
.4188 .60008 Mdot
.56191 .36477 Mdot
.41782 .48632 Mdot
.34011 .49072 Mdot
.59698 .5303 Mdot
.46821 .36787 Mdot
.42367 .34791 Mdot
.35059 .55146 Mdot
.56322 .35231 Mdot
.26646 .59981 Mdot
.54273 .37182 Mdot
.67296 .5262 Mdot
.67962 .54833 Mdot
.79664 .61124 Mdot
.2409 .30444 Mdot
.61694 .33901 Mdot
.38475 .47336 Mdot
.46972 .59024 Mdot
.41287 .36231 Mdot
.35902 .48205 Mdot
.55376 .36721 Mdot
.56942 .34945 Mdot
.5822 .35958 Mdot
.42406 .69064 Mdot
.26355 .55992 Mdot
.63212 .34375 Mdot
.63404 .37963 Mdot
.63769 .59183 Mdot
.66292 .54982 Mdot
.43235 .73778 Mdot
.51088 .77009 Mdot
.40416 .65077 Mdot
.36677 .53622 Mdot
.53019 .87984 Mdot
.4576 .40021 Mdot
.78273 .37959 Mdot
.57547 .53062 Mdot
.27849 .81352 Mdot
.61796 .62084 Mdot
.62387 .55982 Mdot
.59183 .40638 Mdot
.44286 .63992 Mdot
.43385 .66679 Mdot
.61568 .3688 Mdot
.61226 .41285 Mdot
.42741 .64925 Mdot
.61483 .23599 Mdot
.41861 .19144 Mdot
.39116 .57737 Mdot
.59225 .38352 Mdot
.7902 .47351 Mdot
.44608 .34151 Mdot
.58911 .31438 Mdot
.44122 .41 Mdot
.34749 .5062 Mdot
.31113 .53534 Mdot
.456 .3618 Mdot
.63549 .58842 Mdot
.38692 .51735 Mdot
.68625 .58306 Mdot
.63645 .26617 Mdot
.74152 .50635 Mdot
.23995 .55945 Mdot
.62866 .63351 Mdot
.35167 .70702 Mdot
.37603 .32689 Mdot
.59408 .55962 Mdot
.31059 .28339 Mdot
.41205 .68199 Mdot
.61383 .32037 Mdot
.46299 .39034 Mdot
.1542 .50589 Mdot
.62352 .533 Mdot
.59735 .37624 Mdot
.42228 .37979 Mdot
.55308 .65042 Mdot
.53443 .24936 Mdot
.62537 .5386 Mdot
.31796 .82142 Mdot
.63432 .41343 Mdot
.35185 .49035 Mdot
.74501 .67452 Mdot
.62445 .34284 Mdot
.37776 .66033 Mdot
.22325 .48416 Mdot
.66508 .22611 Mdot
.60542 .33961 Mdot
.35179 .481 Mdot
.62009 .35539 Mdot
.4185 .64551 Mdot
.57008 .33514 Mdot
.33701 .50349 Mdot
.60948 .58802 Mdot
.36073 .53451 Mdot
.39642 .66522 Mdot
.46708 .79457 Mdot
.47082 .37451 Mdot
.3579 .48494 Mdot
.43669 .35318 Mdot
.59289 .7403 Mdot
.20255 .50869 Mdot
.44608 .39712 Mdot
.73361 .64792 Mdot
.64296 .52536 Mdot
.63189 .34981 Mdot
.35399 .54325 Mdot
.2366 .4717 Mdot
.44843 .55746 Mdot
.58416 .39054 Mdot
.37858 .52094 Mdot
.52658 .51646 Mdot
.73786 .65672 Mdot
.57231 .61163 Mdot
.59508 .75335 Mdot
.59571 .38559 Mdot
.336 .48309 Mdot
.39124 .78114 Mdot
.62918 .37297 Mdot
.34257 .53735 Mdot
.41026 .37678 Mdot
.44444 .37269 Mdot
.5852 .57143 Mdot
.41522 .32716 Mdot
.37635 .5323 Mdot
.36949 .35157 Mdot
.56539 .39267 Mdot
.53123 .63142 Mdot
.44563 .67938 Mdot
.36295 .51695 Mdot
.67787 .57472 Mdot
.62751 .3279 Mdot
.27708 .3999 Mdot
.76078 .56902 Mdot
.44858 .84578 Mdot
.36045 .53812 Mdot
.56907 .35192 Mdot
.59334 .37564 Mdot
.5603 .53806 Mdot
.47045 .56293 Mdot
.26575 .5937 Mdot
.63843 .6868 Mdot
.54061 .65588 Mdot
.35816 .55939 Mdot
.38028 .55718 Mdot
.62397 .51625 Mdot
.64492 .56954 Mdot
.41153 .36784 Mdot
.61385 .5899 Mdot
.6049 .40559 Mdot
.58346 .57068 Mdot
.45172 .36441 Mdot
.34287 .51622 Mdot
.61269 .543 Mdot
.40657 .65129 Mdot
.4672 .35651 Mdot
.40318 .36985 Mdot
.36038 .52337 Mdot
.57186 .39216 Mdot
.45587 .69013 Mdot
.36883 .52608 Mdot
.64442 .5756 Mdot
.48265 .33628 Mdot
.67088 .58178 Mdot
.66139 .30196 Mdot
.62957 .37511 Mdot
.3345 .49685 Mdot
.56484 .39427 Mdot
.42874 .35363 Mdot
.21538 .49114 Mdot
.62669 .57649 Mdot
.33853 .53331 Mdot
.26559 .5253 Mdot
.66598 .33343 Mdot
.56724 .41184 Mdot
.37906 .30889 Mdot
.61809 .40723 Mdot
.32665 .54617 Mdot
.82145 .44342 Mdot
.43986 .67705 Mdot
.32114 .52155 Mdot
.30658 .25 Mdot
.34815 .52871 Mdot
.6105 .59975 Mdot
.62529 .61669 Mdot
.3534 .48924 Mdot
.44091 .64508 Mdot
.36204 .75463 Mdot
.33274 .56126 Mdot
.60093 .33706 Mdot
.69517 .27068 Mdot
.36754 .80818 Mdot
.41179 .32406 Mdot
.41429 .37774 Mdot
.68053 .52807 Mdot
.66602 .60397 Mdot
.43306 .40847 Mdot
.40288 .35567 Mdot
.40788 .68817 Mdot
.3401 .547 Mdot
.611 .43604 Mdot
.43212 .33452 Mdot
.70591 .63833 Mdot
.30144 .58212 Mdot
.55803 .57171 Mdot
.55085 .50275 Mdot
.57629 .57257 Mdot
.55973 .67019 Mdot
.45404 .36522 Mdot
.64274 .61442 Mdot
.57001 .60176 Mdot
.46725 .37034 Mdot
.42392 .64799 Mdot
.4103 .29076 Mdot
.3633 .50205 Mdot
.48116 .14748 Mdot
.65575 .6091 Mdot
.60857 .60068 Mdot
.44728 .34717 Mdot
.28899 .64122 Mdot
.57084 .37678 Mdot
.63114 .36866 Mdot
.38912 .5112 Mdot
.45156 .53193 Mdot
.594 .53388 Mdot
.59426 .57249 Mdot
.3604 .49685 Mdot
.34351 .48545 Mdot
.35683 .39792 Mdot
.64051 .6036 Mdot
.42139 .37468 Mdot
.47637 .62429 Mdot
.45345 .36396 Mdot
.67455 .57896 Mdot
.614 .60481 Mdot
.57797 .56339 Mdot
.67762 .57266 Mdot
.4035 .38058 Mdot
.642 .61277 Mdot
.58283 .63234 Mdot
.56786 .37499 Mdot
.63656 .53778 Mdot
.5555 .66422 Mdot
.62229 .5906 Mdot
.42274 .65007 Mdot
.73126 .62498 Mdot
.62213 .53394 Mdot
.5896 .53457 Mdot
.32189 .5612 Mdot
.61431 .57675 Mdot
.45757 .40083 Mdot
.58112 .37906 Mdot
.42037 .35428 Mdot
.43413 .34329 Mdot
.36107 .54927 Mdot
.39617 .67835 Mdot
.58461 .52783 Mdot
.41053 .68673 Mdot
.56847 .55489 Mdot
.65431 .53138 Mdot
.23165 .50696 Mdot
.65933 .79834 Mdot
.47137 .80586 Mdot
.62811 .57718 Mdot
.33275 .52184 Mdot
.33707 .49271 Mdot
.65441 .33674 Mdot
.56656 .60165 Mdot
.42686 .40548 Mdot
.41932 .35127 Mdot
.48274 .75645 Mdot
.21294 .59143 Mdot
.42313 .64945 Mdot
.51898 .47994 Mdot
.68857 .57254 Mdot
.65981 .59427 Mdot
.67711 .58971 Mdot
.38368 .5402 Mdot
.46513 .60432 Mdot
.32207 .52108 Mdot
.53929 .3054 Mdot
.44995 .35609 Mdot
.62709 .53326 Mdot
.56111 .42787 Mdot
.62331 .38118 Mdot
.58096 .37833 Mdot
.4058 .37806 Mdot
.29086 .53698 Mdot
.4291 .75428 Mdot
.75186 .25896 Mdot
.63485 .41698 Mdot
.43456 .63252 Mdot
.59227 .55532 Mdot
.34793 .51983 Mdot
.62322 .36137 Mdot
.41649 .63447 Mdot
.66772 .54466 Mdot
.26306 .55884 Mdot
.63239 .57911 Mdot
.54983 .47765 Mdot
.58366 .35134 Mdot
.44719 .18162 Mdot
.58352 .33565 Mdot
.46933 .35962 Mdot
.46187 .38887 Mdot
.62095 .6132 Mdot
.77293 .64266 Mdot
.63115 .35612 Mdot
.38324 .38537 Mdot
.42657 .69685 Mdot
.29243 .39186 Mdot
.42348 .64483 Mdot
.34686 .49245 Mdot
.44178 .66411 Mdot
.33817 .5003 Mdot
.47746 .775 Mdot
.57688 .42451 Mdot
.42374 .67984 Mdot
.34857 .58605 Mdot
.56225 .59631 Mdot
.41014 .64105 Mdot
.69035 .54547 Mdot
.68042 .31319 Mdot
.36617 .49888 Mdot
.4404 .68259 Mdot
.66578 .54534 Mdot
.17745 .39913 Mdot
.42622 .39377 Mdot
.43136 .40646 Mdot
.67413 .52823 Mdot
.36239 .5533 Mdot
.55763 .38943 Mdot
.39421 .23569 Mdot
.47656 .38977 Mdot
.61132 .61105 Mdot
.58599 .58142 Mdot
.62906 .39356 Mdot
.52405 .35768 Mdot
.62013 .61008 Mdot
.71217 .65166 Mdot
.63692 .60828 Mdot
.41032 .3839 Mdot
.62569 .35299 Mdot
.588 .37697 Mdot
.38091 .51908 Mdot
.60356 .40119 Mdot
.65736 .38437 Mdot
.48668 .32845 Mdot
.66715 .512 Mdot
.42785 .359 Mdot
.51363 .32175 Mdot
.5421 .30513 Mdot
.25865 .29663 Mdot
.63418 .38762 Mdot
.58176 .58713 Mdot
.56354 .38756 Mdot
.41556 .65565 Mdot
.58163 .36873 Mdot
.55406 .37315 Mdot
.59874 .56694 Mdot
.62249 .54315 Mdot
.33407 .51375 Mdot
.46745 .57091 Mdot
.56641 .38486 Mdot
.62832 .61885 Mdot
.67082 .6055 Mdot
.68115 .59194 Mdot
.48611 .4299 Mdot
.6191 .34249 Mdot
.77537 .34283 Mdot
.49953 .67674 Mdot
.56685 .38624 Mdot
.1561 .55078 Mdot
.24662 .46212 Mdot
.30913 .50185 Mdot
.44756 .33259 Mdot
.64215 .60311 Mdot
.33106 .49273 Mdot
.61841 .54274 Mdot
.54998 .50377 Mdot
.60914 .57024 Mdot
.4302 .64884 Mdot
.68423 .59261 Mdot
.32657 .54775 Mdot
.36584 .53014 Mdot
.59991 .59997 Mdot
.60981 .54732 Mdot
.45181 .78873 Mdot
.62565 .40578 Mdot
.57316 .37226 Mdot
.26966 .61728 Mdot
.41461 .67375 Mdot
.46353 .36964 Mdot
.63345 .56 Mdot
.36877 .54683 Mdot
.36391 .53312 Mdot
.62457 .34491 Mdot
.37579 .51315 Mdot
.4576 .37193 Mdot
.62588 .57319 Mdot
.43409 .4081 Mdot
.42226 .69123 Mdot
.61871 .34609 Mdot
.6304 .53776 Mdot
.63736 .59213 Mdot
.57625 .34945 Mdot
.60503 .52068 Mdot
.43043 .63782 Mdot
.34944 .53097 Mdot
.60625 .34217 Mdot
.4419 .36761 Mdot
.34097 .49552 Mdot
.65977 .58731 Mdot
.49933 .87098 Mdot
.61455 .60004 Mdot
.64692 .59873 Mdot
.30093 .24749 Mdot
.68784 .58479 Mdot
.35714 .54181 Mdot
.62417 .39364 Mdot
.64302 .62991 Mdot
.54648 .67926 Mdot
.68611 .19739 Mdot
.32409 .52719 Mdot
.59019 .55737 Mdot
.1963 .35831 Mdot
.59108 .57218 Mdot
.79772 .58182 Mdot
.37735 .59964 Mdot
.43121 .48543 Mdot
.6001 .50614 Mdot
.44905 .38145 Mdot
.33263 .51484 Mdot
.34826 .49402 Mdot
.73258 .30598 Mdot
.59687 .56896 Mdot
.53617 .48544 Mdot
.64871 .53528 Mdot
.44813 .36977 Mdot
.47317 .74081 Mdot
.36289 .53651 Mdot
.49559 .83068 Mdot
.65187 .58071 Mdot
.60873 .33254 Mdot
.2966 .5285 Mdot
.27386 .43896 Mdot
.66498 .58084 Mdot
.40566 .68068 Mdot
.44593 .33693 Mdot
.66332 .61886 Mdot
.43106 .36176 Mdot
.66861 .57994 Mdot
.72091 .62208 Mdot
.7418 .69327 Mdot
.57804 .35966 Mdot
.41214 .37818 Mdot
.46732 .32576 Mdot
.60179 .62121 Mdot
.60495 .34045 Mdot
.57786 .38684 Mdot
.40472 .68445 Mdot
.49118 .47707 Mdot
.50078 .26538 Mdot
.76989 .52532 Mdot
.72568 .29215 Mdot
.29408 .53136 Mdot
.34548 .33702 Mdot
.66571 .57202 Mdot
.25195 .63647 Mdot
.467 .38895 Mdot
.60713 .59566 Mdot
.68145 .36588 Mdot
.62023 .36874 Mdot
.62661 .60114 Mdot
.43053 .65564 Mdot
.27339 .65699 Mdot
.26902 .6636 Mdot
.21206 .45366 Mdot
.34686 .51049 Mdot
.69904 .60264 Mdot
.68604 .52093 Mdot
.39135 .50605 Mdot
.61764 .52258 Mdot
.34781 .53791 Mdot
.64587 .24274 Mdot
.42409 .63333 Mdot
.61256 .33712 Mdot
.25729 .4559 Mdot
.5919 .52912 Mdot
.6826 .55152 Mdot
.39891 .64378 Mdot
.64863 .56599 Mdot
.70078 .74843 Mdot
.26516 .49025 Mdot
.38366 .50231 Mdot
.58111 .35968 Mdot
.58324 .53724 Mdot
.50399 .47488 Mdot
.59772 .58368 Mdot
.7577 .45688 Mdot
.58681 .53626 Mdot
.51626 .25686 Mdot
.5774 .35362 Mdot
.4326 .35826 Mdot
.59259 .61697 Mdot
.61324 .56572 Mdot
.48568 .64284 Mdot
.61954 .50517 Mdot
.62822 .62181 Mdot
.55855 .39719 Mdot
.62563 .3645 Mdot
.60217 .35423 Mdot
.31299 .52321 Mdot
.21381 .60225 Mdot
.41976 .36452 Mdot
.62149 .63869 Mdot
.42371 .33402 Mdot
.75949 .60501 Mdot
.42832 .63201 Mdot
.20716 .37972 Mdot
.64459 .54842 Mdot
.60162 .36167 Mdot
.30911 .31071 Mdot
.57606 .4065 Mdot
.50065 .508 Mdot
.43188 .38035 Mdot
.61909 .37445 Mdot
.61886 .56132 Mdot
.45708 .57742 Mdot
.18635 .43449 Mdot
.42994 .34887 Mdot
.5675 .54668 Mdot
.32049 .4967 Mdot
.22801 .54314 Mdot
.48091 .86621 Mdot
.42307 .39302 Mdot
.47522 .33313 Mdot
.59531 .5673 Mdot
.62389 .38378 Mdot
.45285 .37858 Mdot
.43601 .39801 Mdot
.37693 .51222 Mdot
.62527 .54285 Mdot
.62947 .54269 Mdot
.31435 .53411 Mdot
.42751 .34732 Mdot
.62394 .5102 Mdot
.65251 .61759 Mdot
.16172 .38203 Mdot
.50917 .57665 Mdot
.52458 .13362 Mdot
.65038 .40251 Mdot
.67444 .40527 Mdot
.41761 .2179 Mdot
.56632 .3536 Mdot
.61959 .53329 Mdot
.6704 .6287 Mdot
.37543 .53283 Mdot
.61836 .58323 Mdot
.39144 .4826 Mdot
.41725 .37746 Mdot
.15932 .53162 Mdot
.49633 .30242 Mdot
.64275 .22731 Mdot
.61598 .58293 Mdot
.55684 .31175 Mdot
.4228 .66496 Mdot
.42519 .41781 Mdot
.60865 .34936 Mdot
.67492 .55988 Mdot
.45221 .79021 Mdot
.32138 .52076 Mdot
.59477 .3968 Mdot
.38425 .76453 Mdot
.35527 .70658 Mdot
.67498 .57702 Mdot
.3151 .51227 Mdot
.32063 .28994 Mdot
.6789 .66243 Mdot
.45191 .41402 Mdot
.42793 .64723 Mdot
.3296 .51072 Mdot
.42646 .34486 Mdot
.60827 .44812 Mdot
.6158 .38219 Mdot
.55104 .36079 Mdot
.53099 .80377 Mdot
.3896 .49716 Mdot
.42588 .66736 Mdot
.21448 .58155 Mdot
.25942 .66545 Mdot
.43133 .65039 Mdot
.30809 .53098 Mdot
.62472 .36303 Mdot
.61135 .36515 Mdot
.58175 .37963 Mdot
.46809 .82035 Mdot
.57446 .34191 Mdot
.75913 .35106 Mdot
.68362 .57717 Mdot
.71852 .58133 Mdot
.59013 .56275 Mdot
.42667 .4069 Mdot
.58866 .34504 Mdot
.44284 .52942 Mdot
.56814 .58691 Mdot
.19542 .47037 Mdot
.59615 .58757 Mdot
.41917 .41223 Mdot
.63382 .60152 Mdot
.78484 .40677 Mdot
.56196 .38202 Mdot
.6246 .58014 Mdot
.44971 .40955 Mdot
.40998 .66645 Mdot
.54261 .38077 Mdot
.62611 .53702 Mdot
.41526 .25791 Mdot
.68677 .58816 Mdot
.60301 .22081 Mdot
.51639 .61073 Mdot
.43456 .63258 Mdot
.5332 .57736 Mdot
.3839 .48484 Mdot
.70864 .55204 Mdot
.70774 .59948 Mdot
.43656 .35021 Mdot
.25355 .42908 Mdot
.35744 .51103 Mdot
.38335 .62822 Mdot
.6633 .63993 Mdot
.39741 .65872 Mdot
.61535 .41328 Mdot
.42093 .40768 Mdot
.63687 .52138 Mdot
.55944 .56734 Mdot
.66008 .27487 Mdot
.64624 .64658 Mdot
.58216 .56932 Mdot
.4136 .63169 Mdot
.72308 .31491 Mdot
.62664 .59075 Mdot
.5044 .4984 Mdot
.56842 .33848 Mdot
.63134 .50859 Mdot
.78708 .37905 Mdot
.6227 .61762 Mdot
.60766 .39475 Mdot
.5566 .40565 Mdot
.42955 .28381 Mdot
.41406 .69427 Mdot
.59591 .53121 Mdot
.82038 .52566 Mdot
.65023 .5774 Mdot
.42257 .3724 Mdot
.66613 .6007 Mdot
.33819 .50555 Mdot
.45192 .80901 Mdot
.38352 .5228 Mdot
.59405 .53764 Mdot
.58507 .38206 Mdot
.45217 .35287 Mdot
.53497 .81561 Mdot
.28436 .58559 Mdot
.74725 .34201 Mdot
.6385 .20424 Mdot
.44384 .65721 Mdot
.39335 .67566 Mdot
.41751 .40645 Mdot
.62563 .58127 Mdot
.8268 .43328 Mdot
.62856 .50502 Mdot
.62762 .59754 Mdot
.60852 .56884 Mdot
.20803 .53616 Mdot
.41349 .36527 Mdot
.37026 .50767 Mdot
.61776 .60784 Mdot
.63802 .61633 Mdot
.5648 .35737 Mdot
.40908 .67063 Mdot
.33879 .49134 Mdot
.42145 .68452 Mdot
.33944 .52039 Mdot
.15498 .53947 Mdot
.59783 .62412 Mdot
.41198 .66623 Mdot
.47014 .35218 Mdot
.5766 .39386 Mdot
.48078 .32498 Mdot
.34864 .49266 Mdot
.36914 .53527 Mdot
.59971 .59634 Mdot
.60923 .39491 Mdot
.58048 .40308 Mdot
.41418 .6548 Mdot
.45289 .39251 Mdot
.61974 .53564 Mdot
.65986 .53405 Mdot
.62612 .29136 Mdot
.3688 .54992 Mdot
.54133 .49736 Mdot
.38001 .27684 Mdot
.62836 .57927 Mdot
.57941 .40037 Mdot
.60516 .55685 Mdot
.44137 .20674 Mdot
.61988 .38964 Mdot
.618 .61878 Mdot
.29968 .7249 Mdot
.28553 .52909 Mdot
.45798 .27619 Mdot
.58188 .57785 Mdot
.53957 .1704 Mdot
.6652 .5594 Mdot
.13647 .41712 Mdot
.3552 .61197 Mdot
.6135 .5299 Mdot
.6561 .58864 Mdot
.74333 .52822 Mdot
.59873 .54349 Mdot
.32538 .54572 Mdot
.40117 .73959 Mdot
.55555 .38784 Mdot
.44727 .23551 Mdot
.70966 .53272 Mdot
.43294 .69538 Mdot
.38875 .50947 Mdot
.39558 .548 Mdot
.43634 .66197 Mdot
.59503 .38255 Mdot
.63594 .5723 Mdot
.45904 .49721 Mdot
.36749 .55729 Mdot
.55224 .54405 Mdot
.42515 .37402 Mdot
.33061 .39473 Mdot
.28863 .54084 Mdot
.43881 .36271 Mdot
.6418 .53895 Mdot
.74283 .53579 Mdot
.5811 .77797 Mdot
.41252 .18526 Mdot
.43469 .34219 Mdot
.43668 .34732 Mdot
.4474 .81605 Mdot
.443 .68758 Mdot
.66911 .26974 Mdot
.52426 .25204 Mdot
.45986 .363 Mdot
.60744 .66845 Mdot
.33084 .53872 Mdot
.42797 .25919 Mdot
.61259 .31968 Mdot
.6809 .55613 Mdot
.6172 .56289 Mdot
.4571 .38982 Mdot
.66221 .33 Mdot
.73671 .68897 Mdot
.43877 .35381 Mdot
.61147 .65021 Mdot
.46566 .44746 Mdot
.2435 .46451 Mdot
.35094 .54981 Mdot
.40972 .69164 Mdot
.39617 .62631 Mdot
.59546 .33526 Mdot
.40169 .68627 Mdot
.2662 .65017 Mdot
.64663 .56004 Mdot
.44663 .35904 Mdot
.28024 .39889 Mdot
.43983 .3706 Mdot
.4353 .66535 Mdot
.43168 .63039 Mdot
.56804 .37505 Mdot
.57504 .37027 Mdot
.6757 .42686 Mdot
.50381 .73383 Mdot
.5926 .58073 Mdot
.22491 .4007 Mdot
.56611 .39421 Mdot
.56227 .5055 Mdot
.39349 .67069 Mdot
.41138 .67069 Mdot
.49689 .63572 Mdot
.63653 .54976 Mdot
.80859 .55345 Mdot
.63461 .55401 Mdot
.48113 .73847 Mdot
.57285 .55162 Mdot
.37653 .51279 Mdot
.63721 .54508 Mdot
.46013 .6906 Mdot
.63464 .51885 Mdot
.65558 .61247 Mdot
.375 .54907 Mdot
.65929 .62301 Mdot
.34044 .50441 Mdot
.58607 .54707 Mdot
.43502 .69683 Mdot
.38218 .53657 Mdot
.55752 .70165 Mdot
.44971 .60666 Mdot
.30528 .52313 Mdot
.39753 .66924 Mdot
.43834 .68943 Mdot
.59559 .70281 Mdot
.60953 .34929 Mdot
.57313 .32602 Mdot
.62286 .58348 Mdot
.39416 .49146 Mdot
.41268 .3702 Mdot
.6399 .61276 Mdot
.67832 .61199 Mdot
.58943 .59435 Mdot
.60341 .33363 Mdot
.26172 .58629 Mdot
.41181 .66027 Mdot
.31433 .5284 Mdot
.43162 .71796 Mdot
.35094 .55508 Mdot
.59094 .62658 Mdot
.6864 .6193 Mdot
.65951 .43618 Mdot
.27495 .36461 Mdot
.4343 .82292 Mdot
.6143 .38585 Mdot
.36521 .48624 Mdot
.44234 .68574 Mdot
.56168 .5164 Mdot
.60791 .35842 Mdot
.33737 .50372 Mdot
.63239 .57817 Mdot
.56689 .54939 Mdot
.5245 .3308 Mdot
.6851 .51172 Mdot
.52593 .65268 Mdot
.3464 .55243 Mdot
.35726 .48102 Mdot
.2569 .6569 Mdot
.38854 .7207 Mdot
.44646 .54884 Mdot
.60294 .58126 Mdot
.40736 .68254 Mdot
.62321 .36166 Mdot
.55708 .79249 Mdot
.45222 .39766 Mdot
.46848 .56749 Mdot
.61725 .58177 Mdot
.42389 .49264 Mdot
.58362 .38278 Mdot
.42767 .65327 Mdot
.4587 .38804 Mdot
.3995 .6349 Mdot
.39285 .51675 Mdot
.71993 .25219 Mdot
.65009 .57319 Mdot
.59358 .58838 Mdot
.47252 .37007 Mdot
.6197 .36288 Mdot
.39556 .64535 Mdot
.6395 .26411 Mdot
.37222 .49571 Mdot
.83311 .45412 Mdot
.60189 .40371 Mdot
.77976 .41721 Mdot
.31783 .53302 Mdot
.40533 .37625 Mdot
.58521 .70984 Mdot
.45171 .36577 Mdot
.58815 .53954 Mdot
.5935 .36962 Mdot
.42207 .38804 Mdot
.4809 .58472 Mdot
.18944 .3764 Mdot
.789 .45584 Mdot
.64019 .56087 Mdot
.16165 .43869 Mdot
.54543 .20677 Mdot
.62889 .40703 Mdot
.46849 .36692 Mdot
.60017 .59044 Mdot
.624 .52446 Mdot
.64814 .58078 Mdot
.43206 .38679 Mdot
.23746 .49004 Mdot
.36573 .49718 Mdot
.59245 .56533 Mdot
.40894 .68847 Mdot
.34851 .50413 Mdot
.25847 .45376 Mdot
.36226 .5404 Mdot
.63518 .39296 Mdot
.66726 .60069 Mdot
.39771 .39519 Mdot
.13027 .48418 Mdot
.42285 .35225 Mdot
.30537 .52803 Mdot
.65418 .60629 Mdot
.27426 .39345 Mdot
.60338 .3554 Mdot
.37758 .49979 Mdot
.60783 .59983 Mdot
.25715 .46359 Mdot
.46987 .79877 Mdot
.36219 .53973 Mdot
.61404 .35713 Mdot
.36709 .22657 Mdot
.61584 .58764 Mdot
.66329 .56262 Mdot
.61491 .37168 Mdot
.73546 .57149 Mdot
.39062 .77709 Mdot
.60751 .55111 Mdot
.43444 .35821 Mdot
.82755 .38094 Mdot
.63336 .62804 Mdot
.48704 .69347 Mdot
.33208 .51252 Mdot
.4216 .27334 Mdot
.53172 .51106 Mdot
.5654 .50711 Mdot
.63183 .26643 Mdot
.52124 .41557 Mdot
.17489 .4896 Mdot
.38497 .47846 Mdot
.35635 .67901 Mdot
.16658 .49854 Mdot
.43134 .4132 Mdot
.53189 .37122 Mdot
.5927 .24645 Mdot
.55002 .83489 Mdot
.3659 .23559 Mdot
.30934 .66497 Mdot
.44751 .79004 Mdot
.45217 .47326 Mdot
.3416 .52574 Mdot
.43501 .62103 Mdot
.6213 .53917 Mdot
.54218 .2049 Mdot
.80948 .52737 Mdot
.77839 .65152 Mdot
.16181 .43099 Mdot
.79248 .57724 Mdot
.19403 .39557 Mdot
.27181 .28304 Mdot
.66562 .40107 Mdot
.28794 .34565 Mdot
.83998 .46841 Mdot
.29056 .70999 Mdot
.74112 .295 Mdot
.68636 .52709 Mdot
.50707 .51111 Mdot
.6128 .21183 Mdot
.75896 .37413 Mdot
.7416 .6615 Mdot
.3826 .51689 Mdot
.62778 .38954 Mdot
.57784 .24184 Mdot
.59692 .41801 Mdot
.40535 .32195 Mdot
.37732 .21377 Mdot
.19901 .34855 Mdot
.78622 .40312 Mdot
.5032 .15687 Mdot
.69138 .36465 Mdot
.77684 .72209 Mdot
.34644 .56337 Mdot
.6237 .33994 Mdot
.38412 .69009 Mdot
.24923 .65099 Mdot
.55515 .2876 Mdot
.58075 .23236 Mdot
.23177 .52076 Mdot
.55602 .73746 Mdot
.59616 .37721 Mdot
.52961 .58471 Mdot
.3808 .33748 Mdot
.50417 .30503 Mdot
.39999 .74166 Mdot
.30303 .26455 Mdot
.46668 .5118 Mdot
.4273 .25083 Mdot
.33537 .36768 Mdot
.48019 .86215 Mdot
.50562 .66573 Mdot
.63484 .43309 Mdot
.49425 .34768 Mdot
.4287 .20939 Mdot
.59401 .81738 Mdot
.50863 .74879 Mdot
.25248 .65585 Mdot
.2144 .64341 Mdot
.50693 .19001 Mdot
.25719 .72613 Mdot
.56917 .33157 Mdot
.58317 .57467 Mdot
.6937 .50017 Mdot
.82211 .51173 Mdot
.44868 .63861 Mdot
.2177 .45542 Mdot
.43412 .68938 Mdot
.64571 .35768 Mdot
.43741 .79933 Mdot
.77207 .36658 Mdot
.82594 .51976 Mdot
.38846 .66997 Mdot
.62742 .63314 Mdot
.86733 .3824 Mdot
.18222 .47377 Mdot
.46019 .28955 Mdot
.15376 .39115 Mdot
.43394 .53242 Mdot
.54793 .64575 Mdot
.42302 .38746 Mdot
.15846 .48624 Mdot
.60519 .36726 Mdot
.20297 .67137 Mdot
.14063 .44269 Mdot
.70685 .70011 Mdot
.5688 .09924 Mdot
.23808 .60812 Mdot
.43099 .49277 Mdot
.51111 .40135 Mdot
.53223 .69056 Mdot
.7035 .73144 Mdot
.70568 .68589 Mdot
.29197 .3753 Mdot
.61903 .19566 Mdot
.16559 .47734 Mdot
.82693 .48172 Mdot
.72791 .26568 Mdot
.57161 .83229 Mdot
.52018 .46221 Mdot
.60867 .31345 Mdot
.36457 .57016 Mdot
.28293 .29987 Mdot
.18042 .58677 Mdot
.49741 .6732 Mdot
.70807 .20866 Mdot
.43505 .71086 Mdot
.33923 .61159 Mdot
.38483 .19665 Mdot
.5728 .73167 Mdot
.5232 .58927 Mdot
.3642 .74295 Mdot
.55367 .54605 Mdot
.34145 .72278 Mdot
.22178 .3821 Mdot
.4531 .31361 Mdot
.29567 .70999 Mdot
.35656 .26065 Mdot
.65375 .27516 Mdot
.74178 .49807 Mdot
.24697 .65644 Mdot
.5699 .4049 Mdot
.53222 .739 Mdot
.51812 .58449 Mdot
.1909 .35299 Mdot
.47549 .33409 Mdot
.23119 .29447 Mdot
.39949 .77434 Mdot
.58423 .60036 Mdot
.70649 .57052 Mdot
.5887 .64164 Mdot
.51453 .7269 Mdot
.65282 .61996 Mdot
.55016 .30319 Mdot
.23953 .30171 Mdot
.68821 .34201 Mdot
.40007 .30355 Mdot
.24984 .43815 Mdot
.40195 .18521 Mdot
.67638 .46583 Mdot
.38008 .71701 Mdot
.44654 .73946 Mdot
.5352 .8524 Mdot
.36108 .50898 Mdot
.82505 .46251 Mdot
.44774 .41658 Mdot
.4987 .79691 Mdot
.77352 .53044 Mdot
.68723 .7327 Mdot
.24084 .30018 Mdot
.33295 .69357 Mdot
.42609 .7841 Mdot
.60581 .73654 Mdot
.82558 .40534 Mdot
.23792 .44565 Mdot
.67954 .63049 Mdot
.51304 .2151 Mdot
.44244 .64667 Mdot
.69738 .45622 Mdot
.79334 .35262 Mdot
.30389 .6288 Mdot
.68459 .54401 Mdot
.63439 .76231 Mdot
.29427 .47898 Mdot
.45782 .57543 Mdot
.35077 .81154 Mdot
.56064 .589 Mdot
.21834 .59051 Mdot
.5295 .19191 Mdot
.51424 .695 Mdot
.42302 .1969 Mdot
.39939 .24249 Mdot
.2372 .69819 Mdot
.1501 .41923 Mdot
.27804 .58715 Mdot
.17175 .5169 Mdot
.17707 .36414 Mdot
.26375 .72305 Mdot
.702 .62684 Mdot
.47469 .37468 Mdot
.4347 .87526 Mdot
.33233 .54814 Mdot
.20287 .54747 Mdot
.72638 .29307 Mdot
.26709 .46018 Mdot
.60601 .43873 Mdot
.64065 .49088 Mdot
.45852 .48038 Mdot
.63371 .40193 Mdot
.6584 .62049 Mdot
.36542 .80301 Mdot
.24264 .68928 Mdot
.31538 .77453 Mdot
.53478 .1811 Mdot
.16609 .53045 Mdot
.42379 .45752 Mdot
.76494 .37186 Mdot
.65173 .33395 Mdot
.67813 .55871 Mdot
.40303 .59976 Mdot
.23761 .60481 Mdot
.62799 .76816 Mdot
.54682 .27791 Mdot
.62024 .41037 Mdot
.21831 .42465 Mdot
.78763 .74961 Mdot
.68951 .39125 Mdot
.78818 .37279 Mdot
.26539 .66277 Mdot
.50206 .72414 Mdot
.26591 .32286 Mdot
.69708 .71663 Mdot
.29014 .25906 Mdot
.63507 .40476 Mdot
.72889 .28791 Mdot
.31896 .6572 Mdot
.61501 .67985 Mdot
.25794 .57826 Mdot
.20973 .34908 Mdot
.45798 .42924 Mdot
.58563 .79527 Mdot
.53492 .24163 Mdot
.71938 .69507 Mdot
.37551 .60833 Mdot
.33658 .3939 Mdot
.79685 .3598 Mdot
.34624 .31375 Mdot
.48488 .71984 Mdot
.47344 .45529 Mdot
.54155 .55115 Mdot
.51987 .41379 Mdot
.4898 .71137 Mdot
.58997 .67978 Mdot
.18302 .55174 Mdot
.10832 .44398 Mdot
.44071 .83667 Mdot
.47727 .15158 Mdot
.23869 .36372 Mdot
.67285 .53348 Mdot
.34904 .20517 Mdot
.28317 .75774 Mdot
.1325 .44092 Mdot
.35142 .43198 Mdot
.39561 .48399 Mdot
.41212 .3367 Mdot
.38605 .79921 Mdot
.2595 .53601 Mdot
.33303 .22966 Mdot
.35181 .73866 Mdot
.42475 .32992 Mdot
.67045 .79132 Mdot
.23324 .66551 Mdot
.78292 .51689 Mdot
.67185 .50078 Mdot
.60028 .51326 Mdot
.80135 .44205 Mdot
.61448 .41058 Mdot
.34915 .33662 Mdot
.51208 .73988 Mdot
.36439 .52086 Mdot
.40313 .60272 Mdot
.565 .22475 Mdot
.68479 .59139 Mdot
.54177 .42341 Mdot
.6352 .3786 Mdot
.28001 .35869 Mdot
.49333 .32217 Mdot
.17116 .58032 Mdot
.23605 .57583 Mdot
.58038 .5137 Mdot
.51076 .69116 Mdot
.25381 .58039 Mdot
.38921 .78136 Mdot
.40252 .38718 Mdot
.16962 .41211 Mdot
.49323 .53635 Mdot
.52893 .7388 Mdot
.80665 .47872 Mdot
.66529 .30538 Mdot
.69174 .59829 Mdot
.35319 .28762 Mdot
.74604 .44284 Mdot
.46649 .57638 Mdot
.62463 .32131 Mdot
.59037 .31072 Mdot
.37183 .18303 Mdot
.27926 .66358 Mdot
.32769 .37762 Mdot
.18221 .39587 Mdot
.44144 .38039 Mdot
.56771 .39213 Mdot
.4368 .61087 Mdot
.64063 .25706 Mdot
.7556 .41674 Mdot
.47037 .79929 Mdot
.26773 .48109 Mdot
.31517 .62498 Mdot
.18697 .39774 Mdot
.16933 .42572 Mdot
.80785 .61843 Mdot
.56967 .41402 Mdot
.66695 .37148 Mdot
.67345 .26298 Mdot
.61471 .40602 Mdot
.63374 .27967 Mdot
.57688 .29121 Mdot
.17721 .5712 Mdot
.40286 .33185 Mdot
.60332 .1855 Mdot
.55796 .67502 Mdot
.22946 .48682 Mdot
.52918 .81755 Mdot
.79932 .36537 Mdot
.19607 .38286 Mdot
.65041 .66739 Mdot
.76502 .55095 Mdot
.6751 .5168 Mdot
.58003 .46121 Mdot
.54304 .86595 Mdot
.44812 .6101 Mdot
.78205 .4185 Mdot
.36093 .25355 Mdot
.64263 .57169 Mdot
.44342 .84283 Mdot
.61763 .24487 Mdot
.44632 .81848 Mdot
.43499 .33325 Mdot
.65833 .5452 Mdot
.65163 .52357 Mdot
.46927 .71236 Mdot
.43402 .28123 Mdot
.20014 .58083 Mdot
.79623 .34408 Mdot
.32396 .28069 Mdot
.80894 .52794 Mdot
.21913 .5828 Mdot
.3281 .24086 Mdot
.5333 .20306 Mdot
.49175 .48786 Mdot
.23944 .60011 Mdot
.58148 .72285 Mdot
.50315 .15972 Mdot
.48949 .61603 Mdot
.43602 .42713 Mdot
.5846 .27895 Mdot
.38801 .26697 Mdot
.55034 .80114 Mdot
.67271 .56955 Mdot
.38414 .76444 Mdot
.28493 .27409 Mdot
.81324 .58369 Mdot
.66287 .77589 Mdot
.42091 .83268 Mdot
.76288 .47591 Mdot
.39043 .25763 Mdot
.53636 .20888 Mdot
.85435 .45548 Mdot
.49754 .54004 Mdot
.19956 .4486 Mdot
.58993 .72787 Mdot
.18515 .39628 Mdot
.4732 .38173 Mdot
.54479 .25259 Mdot
.24821 .44284 Mdot
.17484 .53576 Mdot
.69928 .48769 Mdot
.23015 .32679 Mdot
.43711 .50926 Mdot
.22064 .68144 Mdot
.33166 .31836 Mdot
.44672 .46293 Mdot
.37727 .49146 Mdot
.32793 .69634 Mdot
.21659 .37905 Mdot
.2609 .36481 Mdot
.79685 .36768 Mdot
.33646 .48199 Mdot
.4321 .61512 Mdot
.7934 .52889 Mdot
.57899 .75539 Mdot
.36597 .2702 Mdot
.51113 .69131 Mdot
.22106 .32738 Mdot
.44048 .72177 Mdot
.39619 .76261 Mdot
.22219 .57015 Mdot
.69655 .22794 Mdot
.45668 .28699 Mdot
.29584 .68754 Mdot
.6032 .23806 Mdot
.34103 .60338 Mdot
.59079 .66364 Mdot
.08695 .5904 Mdot
.69048 .24005 Mdot
.30814 .33183 Mdot
.18085 .58696 Mdot
.44192 .20063 Mdot
.27975 .36248 Mdot
.69488 .73786 Mdot
.50926 .57297 Mdot
.45537 .77437 Mdot
.60957 .56901 Mdot
.33178 .79486 Mdot
.55311 .75341 Mdot
.19052 .61554 Mdot
.36314 .19625 Mdot
.801 .45204 Mdot
.67862 .60156 Mdot
.31609 .52376 Mdot
.42022 .31336 Mdot
.5528 .77298 Mdot
.73785 .54582 Mdot
.53581 .61847 Mdot
.26029 .49493 Mdot
.39124 .50423 Mdot
.26241 .60028 Mdot
.64291 .40208 Mdot
.25068 .52427 Mdot
.37936 .27482 Mdot
.28511 .52291 Mdot
.47042 .52504 Mdot
.49565 .71261 Mdot
.53006 .51939 Mdot
.78321 .51039 Mdot
.67216 .7428 Mdot
.52626 .44336 Mdot
.36241 .5418 Mdot
.76779 .5135 Mdot
.63504 .21291 Mdot
.32572 .28859 Mdot
.20854 .63473 Mdot
.35762 .72573 Mdot
.76085 .57625 Mdot
.48328 .71393 Mdot
.71488 .72031 Mdot
.76263 .63135 Mdot
.24322 .40117 Mdot
.575 .47658 Mdot
.74242 .6421 Mdot
.52377 .22227 Mdot
.1576 .52633 Mdot
.73879 .29368 Mdot
.69317 .26651 Mdot
.35839 .58427 Mdot
.75022 .37453 Mdot
.80268 .49454 Mdot
.56248 .69796 Mdot
.45017 .55796 Mdot
.74932 .74837 Mdot
.59777 .31724 Mdot
.59592 .87066 Mdot
.41268 .38632 Mdot
.58125 .83612 Mdot
.59466 .71879 Mdot
.47598 .45096 Mdot
.43448 .56315 Mdot
.35861 .28804 Mdot
.52051 .25749 Mdot
.55597 .18644 Mdot
.76579 .65474 Mdot
.35872 .55673 Mdot
.7985 .34193 Mdot
.70484 .22872 Mdot
.75317 .52596 Mdot
.61922 .62963 Mdot
.68554 .23319 Mdot
.37314 .47516 Mdot
.62931 .7684 Mdot
.42477 .19298 Mdot
.26957 .34417 Mdot
.69914 .64023 Mdot
.50557 .72806 Mdot
.19932 .44135 Mdot
.16445 .4033 Mdot
.68803 .76873 Mdot
.22276 .38132 Mdot
.47387 .37659 Mdot
.43421 .46378 Mdot
.23542 .33037 Mdot
.5297 .63416 Mdot
.44445 .24696 Mdot
.52275 .60451 Mdot
.68008 .82349 Mdot
.19706 .53055 Mdot
.19973 .57845 Mdot
.52025 .61475 Mdot
.56713 .34653 Mdot
.41742 .29311 Mdot
.5223 .58472 Mdot
.28387 .33293 Mdot
.61563 .2195 Mdot
.52 .58315 Mdot
.8505 .54311 Mdot
.67852 .31312 Mdot
.36635 .4561 Mdot
.80243 .5186 Mdot
.682 .33905 Mdot
.43807 .33296 Mdot
.40801 .74922 Mdot
.34951 .25734 Mdot
.47231 .3627 Mdot
.36099 .27367 Mdot
.41682 .26117 Mdot
.68954 .30612 Mdot
.76402 .42774 Mdot
.30059 .29924 Mdot
.72952 .52255 Mdot
.52811 .37694 Mdot
.54869 .7934 Mdot
.30047 .51573 Mdot
.35166 .249 Mdot
.37246 .4926 Mdot
.5701 .49316 Mdot
.47234 .57282 Mdot
.72347 .63326 Mdot
.41874 .82055 Mdot
.44424 .65636 Mdot
.62827 .35407 Mdot
.60125 .83647 Mdot
.61086 .40469 Mdot
.34922 .79652 Mdot
.69256 .72543 Mdot
.8075 .47691 Mdot
.28697 .59475 Mdot
.28906 .63008 Mdot
.82032 .6422 Mdot
.52665 .40375 Mdot
.33411 .57259 Mdot
.5189 .37813 Mdot
.6219 .34189 Mdot
.22849 .56592 Mdot
.3753 .54602 Mdot
.50404 .55711 Mdot
.40439 .44119 Mdot
.55853 .31668 Mdot
.59242 .42919 Mdot
.48583 .54815 Mdot
.46647 .7622 Mdot
.17681 .56105 Mdot
.34147 .53397 Mdot
.64247 .83374 Mdot
.68516 .60623 Mdot
.73298 .48867 Mdot
.29012 .25673 Mdot
.68376 .78002 Mdot
.38178 .55979 Mdot
.71319 .22976 Mdot
.57144 .54885 Mdot
.27622 .31693 Mdot
.60316 .37374 Mdot
.70715 .27341 Mdot
.44224 .67216 Mdot
.51989 .693 Mdot
.40849 .34336 Mdot
.58129 .79761 Mdot
.28251 .47707 Mdot
.55039 .37057 Mdot
.24075 .3737 Mdot
.67003 .36534 Mdot
.49926 .24354 Mdot
.27646 .62039 Mdot
.75862 .52971 Mdot
.76041 .41586 Mdot
.58527 .4276 Mdot
.19227 .56289 Mdot
.71202 .27266 Mdot
.14631 .53652 Mdot
.5665 .62123 Mdot
.35357 .69642 Mdot
.5966 .2807 Mdot
.33777 .28885 Mdot
.56698 .47222 Mdot
.26568 .27768 Mdot
.52054 .74656 Mdot
.59388 .29689 Mdot
.48403 .7335 Mdot
.58977 .49331 Mdot
.47806 .4973 Mdot
.35022 .35468 Mdot
.77586 .66159 Mdot
.55132 .47522 Mdot
.61312 .81173 Mdot
.56761 .48055 Mdot
.22126 .60752 Mdot
.63822 .41465 Mdot
.40115 .51926 Mdot
.75982 .3849 Mdot
.47008 .32855 Mdot
.1589 .51198 Mdot
.27368 .27083 Mdot
.39784 .38373 Mdot
.2329 .54141 Mdot
.41926 .21173 Mdot
.56744 .51801 Mdot
.41877 .46931 Mdot
.58101 .56098 Mdot
.66021 .34525 Mdot
.68903 .78207 Mdot
.30676 .31197 Mdot
.69153 .62167 Mdot
.17298 .49102 Mdot
.16032 .47595 Mdot
.21067 .65961 Mdot
.83051 .4357 Mdot
.57111 .34921 Mdot
.2914 .7479 Mdot
.54054 .62218 Mdot
.17296 .37738 Mdot
.24668 .39208 Mdot
.35599 .19086 Mdot
.75881 .54422 Mdot
.37991 .24593 Mdot
.73073 .67811 Mdot
.48245 .2605 Mdot
.49071 .19121 Mdot
.4486 .44104 Mdot
.3176 .37912 Mdot
.46547 .18908 Mdot
.87731 .48447 Mdot
.59863 .47213 Mdot
.42073 .2547 Mdot
.55341 .23472 Mdot
.34409 .25415 Mdot
.36387 .62517 Mdot
.66608 .60039 Mdot
.2719 .41037 Mdot
.4905 .81507 Mdot
.49863 .69683 Mdot
.4392 .61896 Mdot
.36261 .62251 Mdot
.50827 .78177 Mdot
.479 .74699 Mdot
.74096 .29403 Mdot
.7626 .53914 Mdot
.51831 .51947 Mdot
.6002 .62029 Mdot
.62028 .43074 Mdot
.40932 .69654 Mdot
.37166 .44684 Mdot
.58426 .55461 Mdot
.3986 .49779 Mdot
.49894 .24913 Mdot
.40126 .82369 Mdot
.42851 .30371 Mdot
.60816 .23214 Mdot
.62323 .32751 Mdot
.40412 .2781 Mdot
.56736 .43245 Mdot
.50384 .83087 Mdot
.35132 .66067 Mdot
.49753 .67284 Mdot
.17995 .4558 Mdot
.29251 .70681 Mdot
.66723 .29502 Mdot
.29445 .72444 Mdot
.46888 .38313 Mdot
.65935 .65012 Mdot
.57039 .25045 Mdot
.25927 .60911 Mdot
.63917 .32952 Mdot
.37665 .24927 Mdot
.32263 .56826 Mdot
.2915 .69071 Mdot
.52137 .18973 Mdot
.67088 .33359 Mdot
.78588 .54848 Mdot
.16655 .43597 Mdot
.32521 .52877 Mdot
.693 .25646 Mdot
.44604 .24068 Mdot
.34645 .67604 Mdot
.21373 .61114 Mdot
.16545 .56173 Mdot
.44121 .53835 Mdot
.55641 .72485 Mdot
.65925 .57301 Mdot
.77517 .34298 Mdot
.32333 .30433 Mdot
.71369 .55518 Mdot
.33637 .42992 Mdot
.58721 .4012 Mdot
.35087 .392 Mdot
.51124 .51138 Mdot
.47749 .77786 Mdot
.60718 .41679 Mdot
.81234 .53477 Mdot
.42913 .70225 Mdot
.42718 .53682 Mdot
.65172 .62418 Mdot
.54444 .71296 Mdot
.83138 .50469 Mdot
.59443 .63571 Mdot
.2406 .34998 Mdot
.76725 .52857 Mdot
.65016 .26437 Mdot
.28878 .31497 Mdot
.24214 .40726 Mdot
.51336 .25946 Mdot
.77204 .41186 Mdot
.3299 .44939 Mdot
.58794 .59112 Mdot
.40049 .52741 Mdot
.58238 .4074 Mdot
.39073 .20836 Mdot
.75976 .46479 Mdot
.55855 .70472 Mdot
.4944 .44372 Mdot
.60687 .45629 Mdot
.50428 .42591 Mdot
.33157 .21774 Mdot
.48308 .26163 Mdot
.51078 .74226 Mdot
.40889 .32395 Mdot
.59083 .71754 Mdot
.6815 .74083 Mdot
.14393 .46171 Mdot
.71511 .71002 Mdot
.4568 .50873 Mdot
.62449 .80834 Mdot
.35104 .30643 Mdot
.43066 .19243 Mdot
.49719 .74775 Mdot
.42502 .55783 Mdot
.45916 .65083 Mdot
.52673 .33311 Mdot
.51199 .46101 Mdot
.46464 .63905 Mdot
.51187 .54855 Mdot
.30601 .43968 Mdot
.37214 .36761 Mdot
.64122 .49189 Mdot
.206 .54326 Mdot
.17401 .4465 Mdot
.71527 .28174 Mdot
.52176 .42319 Mdot
.37118 .66266 Mdot
.50106 .77412 Mdot
.42433 .14412 Mdot
.49487 .86925 Mdot
.65774 .5734 Mdot
.52749 .42757 Mdot
.53878 .72522 Mdot
.34463 .55286 Mdot
.52714 .54559 Mdot
.55685 .42714 Mdot
.40706 .3697 Mdot
.44526 .61351 Mdot
.30765 .70668 Mdot
.36377 .28829 Mdot
.5976 .7499 Mdot
.2555 .44903 Mdot
.40076 .82677 Mdot
.61142 .20491 Mdot
.32863 .29642 Mdot
.36922 .16743 Mdot
.36968 .35184 Mdot
.56074 .32267 Mdot
.67587 .48668 Mdot
.18122 .56533 Mdot
.51312 .68102 Mdot
.52273 .80238 Mdot
.24069 .42769 Mdot
.51075 .74799 Mdot
.56512 .65036 Mdot
.22097 .57829 Mdot
.34985 .40469 Mdot
.46675 .47283 Mdot
.29136 .63305 Mdot
.2589 .69178 Mdot
.79427 .55736 Mdot
.18779 .44021 Mdot
.50355 .81948 Mdot
.86188 .49596 Mdot
.15716 .48994 Mdot
.41748 .60419 Mdot
.36713 .64474 Mdot
.68541 .49185 Mdot
.54325 .65769 Mdot
.61708 .66949 Mdot
.61897 .7739 Mdot
.74644 .408 Mdot
.26617 .56219 Mdot
.56912 .82344 Mdot
.48524 .71883 Mdot
.684 .33166 Mdot
.42617 .55795 Mdot
.77822 .50797 Mdot
.23684 .54916 Mdot
.5134 .61481 Mdot
.4817 .60773 Mdot
.53894 .67279 Mdot
.76362 .51767 Mdot
.63807 .27398 Mdot
.41967 .22634 Mdot
.85961 .55191 Mdot
.22531 .42896 Mdot
.51721 .83214 Mdot
.68351 .58236 Mdot
.1525 .56662 Mdot
.42415 .23301 Mdot
.23488 .43053 Mdot
.57095 .20367 Mdot
.38437 .45923 Mdot
.59564 .30152 Mdot
.5885 .59191 Mdot
.21515 .4019 Mdot
.78602 .42772 Mdot
.67838 .37689 Mdot
.56625 .80698 Mdot
.51194 .70697 Mdot
.39089 .73823 Mdot
.56632 .69143 Mdot
.60733 .6469 Mdot
.62143 .3932 Mdot
.30418 .7662 Mdot
.44507 .50731 Mdot
.57819 .4838 Mdot
.72022 .58336 Mdot
.72526 .6823 Mdot
.63638 .19489 Mdot
.58652 .63949 Mdot
.27356 .68778 Mdot
.78658 .58535 Mdot
.70493 .64775 Mdot
.54571 .51694 Mdot
.46593 .09292 Mdot
.12172 .42699 Mdot
.55219 .37917 Mdot
.79474 .38252 Mdot
.79021 .58318 Mdot
.1815 .55223 Mdot
.32281 .65648 Mdot
.35695 .44171 Mdot
.70672 .6746 Mdot
.566 .66465 Mdot
.65241 .63553 Mdot
.53984 .19373 Mdot
.14395 .44739 Mdot
.56987 .81092 Mdot
.17177 .48684 Mdot
.69748 .54485 Mdot
.6419 .64168 Mdot
.47084 .12233 Mdot
.22684 .34249 Mdot
.56009 .53387 Mdot
.73686 .67812 Mdot
.60869 .31388 Mdot
.61587 .54642 Mdot
.21657 .48426 Mdot
.79298 .33749 Mdot
.48212 .7188 Mdot
.17521 .53688 Mdot
.58373 .41691 Mdot
.34181 .56987 Mdot
.40615 .37534 Mdot
.43997 .56139 Mdot
.56946 .57298 Mdot
.43066 .39001 Mdot
.7266 .63683 Mdot
.37856 .24048 Mdot
.392 .35002 Mdot
.74441 .28673 Mdot
.2638 .26075 Mdot
.77078 .47512 Mdot
.51553 .34016 Mdot
.55984 .52296 Mdot
.67972 .32843 Mdot
.54115 .77745 Mdot
.64899 .32272 Mdot
.45174 .18797 Mdot
.13666 .63289 Mdot
.31307 .39305 Mdot
.43626 .75937 Mdot
.64868 .37196 Mdot
.52566 .50893 Mdot
.79164 .50094 Mdot
.4205 .51236 Mdot
.32736 .51871 Mdot
.65285 .50949 Mdot
.59233 .63845 Mdot
.4378 .33609 Mdot
.58613 .86786 Mdot
.66304 .59876 Mdot
.53724 .51613 Mdot
.17422 .37814 Mdot
.54749 .79392 Mdot
.71888 .48502 Mdot
.57878 .5265 Mdot
.5115 .30661 Mdot
.4243 .55787 Mdot
.32149 .2594 Mdot
.39323 .76084 Mdot
.18108 .49666 Mdot
.758 .46083 Mdot
.78723 .55838 Mdot
.63319 .61914 Mdot
.45145 .66244 Mdot
.43586 .26063 Mdot
.21657 .46682 Mdot
.70299 .56358 Mdot
.15616 .40562 Mdot
.37714 .4541 Mdot
.28344 .4649 Mdot
.61027 .65615 Mdot
.22406 .67695 Mdot
.62034 .7986 Mdot
.79763 .46885 Mdot
.4843 .8322 Mdot
.26909 .63562 Mdot
.57698 .75475 Mdot
.31729 .52139 Mdot
.69718 .55082 Mdot
.5735 .41206 Mdot
.40869 .83602 Mdot
.20863 .48009 Mdot
.29933 .37915 Mdot
.33529 .39732 Mdot
.75742 .33998 Mdot
.49496 .23533 Mdot
.33612 .19254 Mdot
.27896 .63706 Mdot
.41394 .83374 Mdot
.69285 .26341 Mdot
.65192 .35219 Mdot
.37743 .25947 Mdot
.63839 .64981 Mdot
.35584 .53877 Mdot
.18351 .51114 Mdot
.56087 .60646 Mdot
.4422 .79832 Mdot
.61178 .52014 Mdot
.42592 .81266 Mdot
.47074 .63393 Mdot
.22341 .53614 Mdot
.32758 .3263 Mdot
.68749 .74157 Mdot
.36869 .21311 Mdot
.53411 .32554 Mdot
.39383 .16747 Mdot
.36842 .22164 Mdot
.16687 .41556 Mdot
.48202 .80399 Mdot
.72576 .73558 Mdot
.26156 .36772 Mdot
.30472 .29795 Mdot
.36002 .31126 Mdot
.72746 .549 Mdot
.32587 .69271 Mdot
.58947 .6449 Mdot
.45142 .27194 Mdot
.40615 .40452 Mdot
.30645 .83866 Mdot
.46498 .68584 Mdot
.55159 .3509 Mdot
.29983 .67328 Mdot
.15822 .45107 Mdot
.73606 .58687 Mdot
.48341 .18328 Mdot
.50541 .51375 Mdot
.67763 .6309 Mdot
.75901 .4329 Mdot
.73888 .30826 Mdot
.33793 .70679 Mdot
.82487 .65213 Mdot
.61508 .21022 Mdot
.32232 .42138 Mdot
.4795 .50869 Mdot
.61449 .4077 Mdot
.58085 .43275 Mdot
.29268 .61559 Mdot
.47952 .17296 Mdot
.37934 .24408 Mdot
.23389 .33216 Mdot
.82113 .63692 Mdot
.66598 .26408 Mdot
.17968 .56442 Mdot
.33546 .30842 Mdot
.55666 .35025 Mdot
.40554 .60532 Mdot
.31585 .48173 Mdot
.30362 .3671 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo09Cooooo0_l0002cooooo`007?ooool00ol0003oooooooooo`2Doooo
o`;o0000/oooool001cooooo0_l0002fooooo`;o0000T_ooool001cooooo00?o0000ooooooooool0
]Oooool2o`0009;ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`2Eooooo`;o0000/_ooool001cooooo00?o0000ooooooooool0UOooool2
o`000;;ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Wooooo`;o00001?ooool2o`0000Cooooo
0_l0002Dooooo`007?ooool00ol0003oooooooooo`2Wooooo`;o00001?ooool2o`0000Cooooo0_l0
002Dooooo`007?ooool00ol0003oooooooooo`38ooooo`;o0000Ooooool001cooooo00?o0000oooo
ooooool0Q_ooool2o`00043ooooo0_l0001oooooo`007?ooool00ol0003oooooooooo`26ooooo`;o
00004Oooool4o`000:cooooo000Looooo`03o`000?oooooooooo09Wooooo1?l0000Uooooo`;o0000
QOooool001cooooo0_l0002Hooooo`;o0000:Oooool2o`0008Gooooo000Looooo`03o`000?oooooo
oooo09Oooooo0_l00007ooooo`;o0000:Oooool2o`0007cooooo000Looooo`03o`000?oooooooooo
0:3ooooo0_l0000Yooooo`;o0000O?ooool001cooooo00?o0000ooooooooool0Roooool2o`0000?o
oooo0_l0000>ooooo`;o0000Yoooool001cooooo00?o0000ooooooooool0Roooool2o`0000?ooooo
0_l00002ooooo`;o0000/oooool001cooooo00?o0000ooooooooool0M?ooool2o`0000Kooooo0_l0
000Fooooo`;o0000/oooool001cooooo00?o0000ooooooooool0M?ooool2o`0000Kooooo0_l0000B
ooooo`;o000000Coooooo`000?l0003o00005_ooool2o`0000Kooooo0_l0002Cooooo`007?ooool0
0ol0003oooooooooo`2@ooooo`Ko00000_ooool2o`00013ooooo1?l00006ooooo`;o0000Toooool0
01cooooo00?o0000ooooooooool0T_ooool2o`0000Cooooo1?l0000>ooooo`;o0000WOooool001co
oooo00?o0000ooooooooool0T?ooool2o`0000Sooooo1Ol00009ooooo`Ko00000oooool3o`0009Go
oooo000Looooo`03o`000?oooooooooo07Gooooo0_l0000Gooooo`So00000oooool2o`000004oooo
ool0003o0000o`0000Wooooo1_l000000ooooooo0000o`000005o`0009?ooooo000Looooo`03o`00
0?oooooooooo07Gooooo0_l00008ooooo`;o000000?oooooo`000?l000002_ooool2o`0000;ooooo
1?l00003ooooo`?o00004?ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l00000
2_ooool2o`0008Oooooo000Looooo`03o`000?oooooooooo07kooooo0ol000000ooooooo0000o`00
000;ooooo`;o00000_ooool2o`0000Gooooo0_l00005ooooo`;o00000oooool2o`0000Wooooo0_l0
000=ooooo`;o000000?oooooo`000?l00000Q?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^
1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo06Wooooo0_l00005ooooo`Co0000
2Oooool4o`0000?ooooo1_l00005ooooo`;o00000_ooool2o`0000Oooooo0_l00003ooooo`;o0000
0oooool4o`0000;ooooo0_l0000Eooooo`;o0000Q?ooool00006oooooomgMgOoV9RHoooooonHV9So
MgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo
06Wooooo0_l00005ooooo`Co00001Oooool2o`0000;ooooo1?l00002ooooo`Wo00001_ooool2o`00
00Sooooo0_l0000:ooooo`;o00000_ooool2o`0000gooooo0_l00008ooooo`;o00001?ooool2o`00
07cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^
k^h01oooool00ol0003oooooooooo`1`ooooo`Co00001Oooool2o`0000?ooooo0_l00003ooooo`;o
000000?oooooo`000?l000001?l00002ooooo`;o00000_ooool2o`0002Oooooo0_l00008ooooo`Co
000000Coooooo`000?l0003o00003_ooool2o`0006cooooo00000ooooooo0000ooooo`02ooooo`03
o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`00073ooooo0_l0000<ooooo`;o
00003?ooool4o`0000;ooooo0_l0000?ooooo`;o00001?ooool2o`0001cooooo1Ol0000?ooooo`;o
0000K?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIV
ooooo`05ooooo`03o`000?oooooooooo06kooooo0_l0000<ooooo`;o00003Oooool3o`0001Gooooo
0_l00004ooooo`;o000000?oooooo`000?l000001oooool3o`0000_ooooo0_l00004ooooo`;o0000
00?oooooo`000?l00000Noooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool03Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06kooooo0_l00002ooooo`;o00001ooo
ool3o`0000_ooooo1ol0000Booooo`;o00001_ooool5o`0000Kooooo0ol0000;ooooo`;o00001ooo
ool2o`0000Gooooo0_l0000=ooooo`;o0000IOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
2oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0KOooool2o`0000?o
oooo0_l00007ooooo`?o00001_ooool2o`0000;ooooo0ol000000ooooooo0000o`000002o`0001;o
oooo0_l00006ooooo`;o000000?oooooo`000?l000005?ooool3o`0000;ooooo0_l00004ooooo`;o
00000oooool2o`0000gooooo0_l0001Uooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1/ooooo`?o00001Oooool2
o`000003ooooool0003o000000?ooooo0_l00006ooooo`;o00000_ooool2o`0001Wooooo0_l0000N
ooooo`?o00000_ooool4o`0000;ooooo0_l0000Dooooo`;o0000Hoooool001cooooo00?o0000oooo
ooooool0HOooool2o`0000Gooooo0_l000001?oooooo0000o`000?l00006ooooo`;o000000?ooooo
o`000?l000002oooool3o`0000Gooooo0_l00007ooooo`;o00003?ooool2o`0000Wooooo0ol0000I
ooooo`;o000000?oooooo`000?l000005Oooool2o`0006?ooooo000Looooo`03o`000?oooooooooo
067ooooo0_l00005ooooo`;o000000?oooooo`000?l000005oooool3o`0000Gooooo0_l00004oooo
o`Go00000_ooool2o`0001?ooooo0ol00003ooooo`;o00001_ooool2o`0000;ooooo0_l00002oooo
o`;o00001oooool2o`0000gooooo0_l0001[ooooo`007?ooool00ol0003oooooooooo`1Wooooo`;o
00002oooool2o`0001?ooooo0ol00004ooooo`Ko00000oooool2o`0000_ooooo0_l0000<ooooo`;o
00001_ooool2o`0000;ooooo0_l00002ooooo`;o00005_ooool2o`0006_ooooo000Looooo`03o`00
0?oooooooooo06Oooooo0_l0000;ooooo`;o00003_ooool4o`000004ooooool0003o0000o`0000Co
oooo0_l00002ooooo`;o000000?oooooo`000?l000003Oooool2o`0000[ooooo1?l00002ooooo`;o
00002?ooool2o`0000Wooooo0_l00005ooooo`;o0000Loooool001cooooo00?o0000ooooooooool0
J?ooool4o`0000Sooooo0_l00009ooooo`;o00000_ooool5o`000003ooooool0003o000000?ooooo
0_l00004ooooo`;o000000?oooooo`000?l000000oooool2o`0001Cooooo1?l00002ooooo`;o0000
2?ooool2o`0000Wooooo0_l00005ooooo`;o00002?ooool2o`000004ooooool0003o0000ooooo`;o
0000Hoooool001cooooo00?o0000ooooooooool0I?ooool2o`0000;ooooo1?l0000Cooooo`;o0000
0_ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o
00001oooool2o`000003ooooool0003o000000?ooooo0_l0000Cooooo`;o00001oooool2o`000003
ooooool0003o0000013ooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooo
oooo0000o`00001Sooooo`007?ooool00ol0003oooooooooo`1Tooooo`;o00003Oooool2o`0000Oo
oooo0_l00008ooooo`;o000000Coooooo`000?l0003ooooo1?l00003ooooo`;o00002?ooool4o`00
00;ooooo0ol0000:ooooo`;o00001oooool2o`0000Oooooo1Ol0000@ooooo`;o00000_ooool2o`00
00Sooooo0_l0001Rooooo`007?ooool00ol0003oooooooooo`1cooooo`;o00001oooool2o`0000Oo
oooo0_l00007ooooo`;o00003Oooool2o`0000Cooooo0ol0000:ooooo`;o00003_ooool2o`0000;o
oooo0_l0000Booooo`;o00000_ooool2o`0000Oooooo0_l0001Rooooo`007?ooool00ol0003ooooo
ooooo`1Wooooo`;o00003Oooool3o`0000Gooooo0_l00005ooooo`Co00001?ooool2o`0000Wooooo
0_l0000:ooooo`Co000000Coooooo`000?l0003o00002oooool3o`0000Kooooo0_l0000<ooooo`;o
00000oooool2o`0000?ooooo0_l00002ooooo`;o0000Joooool001cooooo00?o0000ooooooooool0
Ioooool2o`0000gooooo1?l00004ooooo`;o00001oooool2o`0000Cooooo0_l00003ooooo`;o0000
1?ooool2o`0000Cooooo0_l00006ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0000Oo
oooo0ol0000;ooooo`;o00001oooool2o`0000?ooooo0_l00007ooooo`;o0000Joooool001cooooo
00?o0000ooooooooool0G_ooool2o`0000oooooo0_l00006ooooo`?o00004oooool3o`0000;ooooo
0_l0000:ooooo`;o00001oooool2o`0000Cooooo0ol0000=ooooo`;o00001_ooool3o`0000gooooo
1?l00003ooooo`;o0000Joooool001cooooo0_l0001Oooooo`Co000000?oooooo`000?l000002_oo
ool2o`0000Kooooo0_l0000>ooooo`;o00001?ooool3o`0000?ooooo1?l00007ooooo`;o00001ooo
ool2o`000003ooooool0003o000000?o00001oooool2o`0000Cooooo1Ol00005ooooo`;o000000?o
ooooo`000?l000002_ooool4o`000003ooooool0003o000000;o00000_ooool2o`0000Cooooo0_l0
001Qooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o000000?oooooo`000?l000001oooool2
o`0000Cooooo0_l0000Aooooo`Co00002_ooool4o`00013ooooo0_l000000ooooooo0000o`000003
o`0000Oooooo0_l00004ooooo`Go00002?ooool2o`0000oooooo1?l00002ooooo`;o00001?ooool2
o`00067ooooo000Looooo`03o`000?oooooooooo05_ooooo0_l0000?ooooo`Co00000_ooool2o`00
00Oooooo0_l00006ooooo`Co00004oooool2o`0000Kooooo1Ol00006ooooo`;o00003oooool2o`00
00cooooo0_l0000;ooooo`;o00000_ooool2o`0000Cooooo0_l0001Tooooo`007?ooool00ol0003o
ooooooooo`1Booooo`;o00001oooool2o`0000Sooooo0_l00007ooooo`Co00001Oooool2o`0000;o
oooo0_l00003ooooo`Ko000000Coooooo`000?l0003ooooo0ol0000<ooooo`?o00001_ooool5o`00
0003ooooool0003o000001cooooo0_l00004ooooo`Co00002Oooool2o`0000;ooooo0_l00004oooo
o`;o00002oooool2o`0005Oooooo000Looooo`03o`000?oooooooooo05;ooooo0_l00005ooooo`Co
00000_ooool2o`0000Cooooo0_l00009ooooo`;o00001Oooool2o`0000Oooooo0ol000001?oooooo
0000o`000?ooool2o`000004ooooool0003o0000o`0000cooooo0_l000000ooooooo0000o`000005
ooooo`;o00000oooool2o`0000Kooooo0_l0000Dooooo`;o00001?ooool5o`0000Cooooo1?l00004
ooooo`;o00003_ooool2o`000003ooooool0003o000005Oooooo000Looooo`03o`000?oooooooooo
05Oooooo1?l00004ooooo`;o00003oooool2o`0000?ooooo0_l00003ooooo`;o00005?ooool2o`00
00[ooooo0_l000000ooooooo0000o`000004ooooo`;o00002Oooool2o`0001Gooooo1ol000001?oo
oooo0000o`000?l00003ooooo`Go00000oooool2o`0000[ooooo0_l00002ooooo`;o0000F_ooool0
01cooooo00?o0000ooooooooool0EOooool4o`0001Oooooo0_l000000ooooooo0000o`000002o`00
00?ooooo0_l00003ooooo`;o00002_ooool2o`0000?ooooo0_l0000=ooooo`;o00001?ooool2o`00
017ooooo0ol0000<ooooo`Ko00000oooool2o`0000Cooooo1_l000001?oooooo0000o`000?l00002
ooooo`;o00001Oooool2o`0000cooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`1Eoooo
o`;o00000oooool2o`00013ooooo0ol00003ooooo`?o00002_ooool2o`000004ooooool0003o0000
ooooo`;o00001?ooool2o`0000;ooooo0_l0000Wooooo`Co00003oooool2o`0000Wooooo0_l00002
ooooo`;o00000_ooool2o`0000;ooooo0ol0000=ooooo`;o00000oooool2o`00053ooooo000Loooo
o`03o`000?oooooooooo05Wooooo1Ol0000>ooooo`?o00000oooool8o`0000;ooooo0_l00004oooo
o`Go00002?ooool4o`0002?ooooo0_l00002ooooo`;o00003oooool2o`0000Cooooo1?l000000ooo
oooo0000o`00000:ooooo`?o00003Oooool2o`0000?ooooo0_l0001@ooooo`007?ooool00ol0003o
ooooooooo`1Cooooo`;o00000oooool3o`000003ooooool0003o000001Oooooo1Ol00002ooooo`?o
000000Coooooo`000?l0003ooooo0_l0000<ooooo`;o00006oooool2o`0000Kooooo0_l00002oooo
o`;o00003_ooool3o`0000Cooooo1?l0001dooooo`007?ooool00ol0003oooooooooo`1Cooooo`Co
000000Coooooo`000?l0003o00002oooool2o`0001Gooooo0_l000000ooooooo0000o`000007oooo
o`;o00006oooool2o`0000Kooooo0_l0000:ooooo`;o00000_ooool2o`0000Wooooo1?l0000Hoooo
o`;o00002_ooool3o`0005Gooooo000Looooo`03o`000?oooooooooo05Gooooo0_l00002ooooo`;o
00001_ooool2o`0000?ooooo0_l0000Hooooo`;o00001_ooool3o`0001[ooooo0ol0000Fooooo`;o
00001Oooool2o`0000;ooooo0_l0000Jooooo`;o00002_ooool3o`0005Gooooo000Looooo`03o`00
0?oooooooooo067ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo1Ol0000<ooooo`;o0000
1_ooool2o`0000Oooooo0_l0000?ooooo`;o000000Coooooo`000?l0003o00002Oooool2o`0000[o
oooo0_l00006ooooo`;o00001Oooool2o`0001_ooooo0_l00003ooooo`;o0000FOooool001cooooo
00?o0000ooooooooool0I?ooool4o`0000;ooooo0_l00003ooooo`Go00002oooool2o`000003oooo
ool0003o000000gooooo0ol0000>ooooo`;o00000_ooool2o`0000Wooooo0_l00005ooooo`;o0000
0oooool2o`0000Wooooo0_l00002ooooo`?o00001Oooool2o`0001;ooooo0ol00003ooooo`;o0000
FOooool001cooooo00?o0000ooooooooool0Aoooool2o`0000Gooooo0_l000000ooooooo0000o`00
000Aooooo`;o00002?ooool2o`0000oooooo0_l000000ooooooo0000o`000002o`0000cooooo0_l0
0004ooooo`;o00005Oooool2o`0000Oooooo0_l0000>ooooo`;o00000oooool3o`0000Cooooo0ol0
000Aooooo`;o00000_ooool4o`0005Wooooo000Looooo`03o`000?oooooooooo04Oooooo0_l00005
ooooo`Go00001oooool2o`0000?ooooo0_l00006ooooo`;o00001Oooool2o`0001Cooooo0_l0000<
ooooo`;o00001?ooool4o`000003ooooool0003o0000013ooooo0_l00006ooooo`;o00001?ooool2
o`0000oooooo0_l00005ooooo`;o00004Oooool2o`0000;ooooo1?l0001Iooooo`007?ooool2o`00
04cooooo0_l00003ooooo`?o00001Oooool4o`000003ooooool0003o000000;o00001_ooool2o`00
02;ooooo0_l00002ooooo`;o000000?oooooo`000?l000001_ooool2o`000003ooooool0003o0000
013ooooo0_l00006ooooo`;o00001?ooool3o`0008Wooooo000Looooo`03o`000?oooooooooo04[o
oooo0ol0000;ooooo`;o00000oooool3o`0000Gooooo0_l0000=ooooo`;o00002?ooool3o`0000?o
oooo0_l000000ooooooo0000o`000004o`0000;ooooo0_l0000<ooooo`Ko00000_ooool2o`0000So
oooo1?l0000;ooooo`;o00004oooool2o`0007Cooooo000Looooo`03o`000?oooooooooo04[ooooo
0ol0000?ooooo`;o00001oooool4o`0000Gooooo0ol00002ooooo`?o00001?ooool2o`0000;ooooo
0ol00003ooooo`;o000000?oooooo`000?l000000_l00008ooooo`;o00002?ooool7o`000003oooo
ool0003o000000Cooooo0ol000000ooooooo0000o`000002o`0001Gooooo0_l00009ooooo`?o0000
1_ooool2o`0000cooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o00003ooo
ool4o`000003ooooool0003o000000Cooooo1?l00003ooooo`So000000Coooooo`000?l0003ooooo
0_l00006ooooo`;o00003oooool2o`0000[ooooo1Ol000000ooooooo0000o`000002o`0000;ooooo
0ol000000ooooooo0000o`000002o`0000;ooooo0_l00005ooooo`;o00002_ooool2o`0000[ooooo
0_l00006ooooo`;o00003?ooool4o`0005_ooooo000Looooo`03o`000?oooooooooo05kooooo1Ol0
0006ooooo`[o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00000_ooool4o`000004oooo
ool0003o0000o`0000Oooooo0_l0000;ooooo`;o00001oooool4o`0000;ooooo0_l00002ooooo`Co
00000_ooool3o`0000;ooooo1?l00004ooooo`;o00003oooool2o`000004ooooool0003o0000oooo
o`;o00004Oooool2o`0000oooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`16ooooo`?o
00003Oooool2o`0000;ooooo0_l00003ooooo`?o00001_ooool2o`000003ooooool0003o000000Ko
00002Oooool2o`0000;ooooo0_l00003ooooo`?o00001oooool2o`0000_ooooo0_l0000Aooooo`Go
00000_ooool2o`000003ooooool0003o000000?o000000Coooooo`000?l0003ooooo0_l00007oooo
o`;o00001_ooool2o`000004ooooool0003o0000ooooo`;o00003?ooool2o`0001Cooooo0_l0001:
ooooo`007?ooool00ol0003oooooooooo`16ooooo`?o00003Oooool2o`0000;ooooo0_l00003oooo
o`;o00001oooool2o`0000;ooooo0ol0000Pooooo`;o00007_ooool2o`000003ooooool0003o0000
00Gooooo0_l000000ooooooo0000o`000003o`0000;ooooo0_l00006ooooo`;o00003oooool4o`00
00Oooooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00002?ooool2o`0001?o
oooo0_l0000Fooooo`;o00006_ooool3o`0000Cooooo0_l0000=ooooo`;o00002_ooool2o`0000?o
oooo0ol000000ooooooo0000o`000006ooooo`;o00002oooool4o`0006Wooooo000Looooo`03o`00
0?oooooooooo03_ooooo0_l00007ooooo`?o00000_ooool2o`0000Oooooo1Ol00003ooooo`;o0000
2oooool2o`0000[ooooo0_l00006ooooo`;o00000oooool4o`0000Oooooo0_l00002ooooo`;o0000
0oooool2o`0000;ooooo1ol00004ooooo`;o00001Oooool2o`0000Kooooo0_l00002ooooo`;o0000
00Coooooo`000?l0003ooooo1?l00002ooooo`Co000000?oooooo`000?l000001_ooool2o`00013o
oooo0_l00009ooooo`Co0000FOooool001cooooo00?o0000ooooooooool0>oooool2o`0000Kooooo
1_l00009ooooo`;o000000?oooooo`000?l000000oooool2o`0000_ooooo0_l0000:ooooo`;o0000
00?oooooo`000?l000000oooool4o`0000;ooooo1ol00003ooooo`;o00000_ooool2o`0000?ooooo
0ol000000ooooooo0000o`000002o`000003ooooool0003o000000_ooooo0_l00006ooooo`;o0000
0_ooool2o`000004ooooool0003o0000ooooo`Co00000_ooool2o`0000;ooooo1Ol0000>ooooo`;o
00001_ooool2o`0000Cooooo0_l00003ooooo`Co0000FOooool001cooooo00?o0000ooooooooool0
@oooool3o`000003ooooool0003o000000;o00001oooool2o`0000cooooo0ol0000;ooooo`;o0000
1_ooool2o`0000Gooooo1?l00002ooooo`Go00001_ooool2o`0000Gooooo0_l00002ooooo`?o0000
2oooool2o`0000Wooooo0_l000000ooooooo0000o`000002o`0000Gooooo3Ol000000ooooooo0000
o`000005ooooo`?o00000oooool3o`000003ooooool0003o000000Sooooo0_l0001Pooooo`007?oo
ool00ol0003oooooooooo`18ooooo`?o00000oooool2o`0000Sooooo0_l00006ooooo`?o000000?o
ooooo`000?l000001oooool3o`0000oooooo0_l00003ooooo`Co000000?oooooo`000?l000000_l0
00000ooooooo0000o`000007ooooo`Co00003?ooool2o`0000Wooooo0_l000000ooooooo0000o`00
0002o`000003ooooool0003o000000ko00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`00
0003o`0000;ooooo1Ol0000Cooooo`;o00002oooool2o`0004Sooooo000Looooo`03o`000?oooooo
oooo04kooooo0_l00008ooooo`;o00002_ooool2o`0000Kooooo1?l00008ooooo`;o00001Oooool2
o`000004ooooool0003o0000ooooo`?o000000?oooooo`000?l000001Ol00007ooooo`Ko00002_oo
ool2o`000004ooooool0003o0000ooooo`;o00000oooool6o`0000;ooooo4?l00004ooooo`Go0000
0_ooool3o`0000Cooooo0ol0000Cooooo`;o00001oooool2o`000004ooooool0003o0000o`0004So
oooo000Looooo`03o`000?oooooooooo047ooooo0_l0000;ooooo`;o00007?ooool6o`0000Kooooo
0_l00003ooooo`Co000000Coooooo`000?l0003ooooo2ol00002ooooo`;o00001Oooool4o`0000Oo
oooo0_l00004ooooo`;o000000?oooooo`000?l000001Oooool3o`000003ooooool0003o000000oo
00001Oooool2o`000003ooooool0003o000000Oooooo1?l0000Dooooo`;o00001oooool2o`000003
ooooool0003o000000;o0000Aoooool001cooooo00?o0000ooooooooool0@Oooool2o`0000?ooooo
0_l0000<ooooo`;o00005oooool2o`000003ooooool0003o000000_ooooo0ol000000ooooooo0000
o`00000=o`0000;ooooo0_l000000ooooooo0000o`00000=ooooo`;o00003?ooool2o`0000?ooooo
4_l000000ooooooo0000o`00000>ooooo`Co00004Oooool2o`000003ooooool0003o000000Cooooo
0_l00005ooooo`?o00000_ooool2o`0004?ooooo000Looooo`03o`000?oooooooooo04Kooooo0_l0
000<ooooo`;o00001?ooool2o`0000Kooooo0_l0000;ooooo`;o00003ooooolBo`000003ooooool0
003o000000;o00001_ooool2o`0000cooooo0_l00005oooooaOo000000?oooooo`000?l000000_l0
0005ooooo`;o00001oooool3o`00013ooooo0_l00007ooooo`;o000000?oooooo`000?l000000_oo
ool3o`0000;ooooo0_l00013ooooo`007?ooool2o`0003kooooo0_l000000ooooooo0000o`000008
ooooo`;o00003_ooool2o`0000Kooooo0_l0000;ooooo`;o00002oooool2o`0000;ooooo5ol00006
ooooo`;o00002_ooool4o`0000;ooooo2ol000000ooooooo0000o`00000Ao`0000?ooooo1?l00008
ooooo`;o00007?ooool2o`0004cooooo000Looooo`03o`000?oooooooooo03[ooooo0_l000001?oo
oooo0000o`000?ooool2o`0000Sooooo0_l0000Fooooo`;o00004?ooool2o`0000Kooooo0_l00000
0ooooooo0000o`00000Fo`0001;ooooo0_l00004ooooo`ko000000?oooooo`000?l000003_l00002
ooooo`?o00001?ooool2o`0001[ooooo0_l00009ooooo`;o0000BOooool001cooooo00?o0000oooo
ooooool0>_ooool2o`0002Gooooo0ol0000:ooooo`;o00001?ooool3o`0000Oooooo6_l0000Joooo
oaco00000_ooool2o`0000Gooooo0_l0000Jooooo`;o00001?ooool2o`0000?ooooo0ol00018oooo
o`007?ooool00ol0003oooooooooo`0kooooo`?o00006Oooool2o`0000Sooooo0ol00006ooooo`;o
00000_ooool2o`0000Gooooo0_l00007oooooa_o00003Oooool2o`0000Kooooo0_l00003oooooako
00008oooool2o`0000?ooooo0_l00002ooooo`Co0000B?ooool001cooooo00?o0000ooooooooool0
>oooool3o`0000oooooo0_l00008ooooo`;o00001oooool4o`0000Kooooo0_l0000:ooooo`;o0000
1_oooolKo`0000gooooo0_l000000ooooooo0000o`000003ooooo`?o000000?oooooo`000?l00000
4?l000000ooooooo0000o`00000:o`0002?ooooo0_l00005ooooo`Ko0000B?ooool001cooooo00?o
0000ooooooooool0=_ooool2o`0001;ooooo0_l000000ooooooo0000o`000002ooooo`;o000000?o
ooooo`000?l000000ol00007ooooo`?o00004oooool2o`0000Kooooo3?l000000ooooooo0000o`00
0007o`0000;ooooo0ol00007ooooo`;o00001oooool2o`0000Cooooo8_l00005ooooo`;o00000_oo
ool2o`000003ooooool0003o000001_ooooo0ol00002ooooo`Co0000A_ooool001cooooo00?o0000
ooooooooool0=_ooool3o`0000oooooo1?l00005ooooo`;o000000?oooooo`000?l000000_l00007
ooooo`Co00001_ooool2o`0000[ooooo0_l00008ooooo`_o000000?oooooo`000?l000003?l00007
ooooo`;o00003OoooolLo`000003ooooool0003o000000?o00001Oooool2o`0000;ooooo0_l00000
0ooooooo0000o`00000Hooooo`;o000000?oooooo`000?l000000oooool4o`0004Kooooo000Loooo
o`03o`000?oooooooooo03Gooooo1?l0000?ooooo`;o00001oooool2o`000003ooooool0003o0000
00Sooooo0ol00008ooooo`;o00002_ooool2o`0000Sooooo6Ol000000ooooooo0000o`00000>oooo
o`;o00000_ooool5o`000003ooooool0003o000000_o000000?oooooo`000?l000003ol00003oooo
o`;o00007_ooool4o`0000Kooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`0eooooo`;o
00004oooool2o`0000Sooooo0_l00005ooooo`;o000000?oooooo`000?l000000_l0000MoooooaWo
000000?oooooo`000?l000003_ooool2o`0000;ooooo9Ol00003ooooo`;o00006Oooool2o`000003
ooooool0003o000000Co00000oooool2o`0000Cooooo0_l000000ooooooo0000o`000012ooooo`00
7?ooool00ol0003oooooooooo`0dooooo`?o00000oooool3o`0000gooooo0_l0000?ooooo`;o0000
00?oooooo`000?l000000_l00004ooooo`?o00002Oooool2o`0000[ooooo6ol00006ooooo`Go0000
00Coooooo`000?l0003ooooo0_l00002ooooob?o00002_ooool2o`0001Gooooo0_l000000ooooooo
0000o`000007ooooo`;o00001?ooool2o`000003ooooool0003o000004;ooooo000Looooo`03o`00
0?oooooooooo03Cooooo0ol00003ooooo`?o00000oooool7o`0000Sooooo0_l00007ooooo`;o0000
1?ooool2o`0000?ooooo1_l00009ooooo`;o00002_oooolKo`0000Kooooo1Ol000001?oooooo0000
o`000?ooool2o`0000;ooooo8_l00003ooooo`;o00001_ooool2o`0001oooooo1?l0000;ooooo`;o
0000?_ooool001cooooo00?o0000ooooooooool0<Oooool2o`0000Oooooo1?l00002ooooo`Oo0000
2?ooool2o`0000Oooooo0_l00004ooooo`;o00000oooool4o`0001Kooooo6ol0000Dooooo`_o0000
00?oooooo`000?l000000_l000000ooooooo0000o`00000?o`0000?ooooo0ol0000Vooooo`Ko0000
0oooool2o`0000Cooooo0_l0000;ooooo`;o0000<Oooool001cooooo00?o0000ooooooooool0<Ooo
ool2o`0000Oooooo1?l00006ooooo`;o00003?ooool2o`0000Cooooo1?l0000Jooooo`;o000000Go
ooooo`000?l0003o0000ooooo`0Ko`0000gooooo0_l00008oooooago00001_ooool2o`0001oooooo
0_l00009ooooo`;o00000oooool2o`00017ooooo0_l0000aooooo`007?ooool00ol0003ooooooooo
o`1Booooo`;o00001?ooool4o`0000Kooooo0_l0000Booooo`;o000000Coooooo`000?l0003o0000
0ooooolJo`0000cooooo0_l00008oooooaoo00001?ooool2o`0001oooooo0_l0000<ooooo`;o0000
A_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413o
ooooooooo`04ooooo`03o`000?oooooooooo02kooooo0_l0000Looooo`;o00001oooool2o`000003
ooooool0003o000000?o00001Oooool2o`0000Kooooo0ol000000ooooooo0000o`00000;ooooo`;o
00000_oooolLo`0001Kooooo0_l000000ooooooo0000o`00000Ho`0000Cooooo0_l00008ooooo`;o
00008oooool2o`0000[ooooo0_l0000jooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5oooo
o`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02kooooo0_l00007oooo
o`?o000000?oooooo`000?l000001_ooool2o`0000Oooooo0_l00005ooooo`Co000000?oooooo`00
0?l000000ol00005ooooo`;o00000oooool6o`000003ooooool0003o000000_ooooo1?l000000ooo
oooo0000o`00000Eo`0000;ooooo0_l0000:ooooo`;o00001ooooolOo`0000oooooo0_l0000Aoooo
o`;o00007?ooool2o`0003[ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wo
oooo1Ol00006ooooo`03o`000?oooooooooo03Kooooo1ol00006ooooo`Co00003?ooool2o`000003
ooooool0003o000000Co00002oooool4o`0000Gooooo0_l0000;ooooo`;o00000_oooolCo`0000Go
oooo0_l0000:ooooo`;o000000?oooooo`000?l000000_l00002oooooa_o00000oooool2o`0000[o
oooo0_l0000Eooooo`;o00003?ooool2o`0000kooooo0_l0000jooooo`0000?oooooo`000?ooool0
0_ooool00ol0003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0000booooo`;o
00000_ooool2o`000003ooooool0003o000000Co00000oooool2o`000003ooooool0003o000000Co
oooo0_l00009ooooo`Go00003_ooool2o`000003ooooool0003o000000;ooooo0_l0000?oooooa?o
00001oooool2o`0000Gooooo0_l000001?oooooo0000o`000?ooool4o`0000[ooooo3?l000000ooo
oooo0000o`00000<o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`0001[ooooo0_l00002oooo
o`?o00003_ooool2o`0003[ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wo
oooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`0_ooooo`;o000000?oooooo`00
0?l000001oooool4o`0000?ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00008oooo
o`Ko00001oooool2o`0000Sooooo1_l0000>oooooaCo000000?oooooo`000?l000001?ooool2o`00
00Gooooo0_l00003ooooo`;o00002?ooool2o`0000;ooooo7?l000000ooooooo0000o`000005o`00
00?ooooo0_l0000Jooooo`;o00000_ooool3o`0000Sooooo0ol0000oooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooooooo
ool0;oooool2o`0000kooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`0000So
oooo1Ol00008ooooo`;o00002_ooool2o`0000Cooooo0_l00006ooooo`;o00000_oooolCo`0000;o
oooo1?l0000=ooooo`?o00002?ooool2o`0000;ooooo5Ol000000ooooooo0000o`000005ooooo`;o
000000?oooooo`000?l000000_l0000Fooooo`;o00002_ooool2o`0000[ooooo0ol000000ooooooo
0000o`00000looooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co0000
00Oooooo00?o0000ooooooooool0:Oooool3o`0000Oooooo0_l0000:ooooo`;o00000oooool2o`00
00Gooooo0_l00008ooooo`;o00000_ooool2o`0001Wooooo0_l00006ooooo`;o00001_ooool>o`00
00Gooooo0_l000000ooooooo0000o`00000:ooooo`;o00003?ooool2o`000003ooooool0003o0000
00Oo00000_ooool8o`0002Gooooo0_l00005ooooo`?o00000_ooool2o`0000Oooooo0_l000000ooo
oooo0000o`000002ooooo`;o0000??ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool0
0omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo02Wooooo0ol00007ooooo`;o00005?ooool3
o`0000Wooooo0_l00002ooooo`;o00002oooool2o`000003ooooool0003o0000013ooooo0_l00003
ooooo`;o00000_ooool>o`0000Sooooo0_l00009ooooo`?o00003?ooool9o`000003ooooool0003o
000000So00000_ooool4o`0000gooooo0_l0000Iooooo`?o00002oooool2o`0004?ooooo000Loooo
o`03o`000?oooooooooo02Wooooo0_l00007ooooo`?o00005?ooool4o`0000Oooooo1?l0000<oooo
o`Co000000?oooooo`000?l000004?ooool4o`000003ooooool0003o000000Cooooo2ol000000ooo
oooo0000o`00000Aooooo`?o00002Oooool2o`000004ooooool0003o0000o`0000?ooooo0ol00000
0ooooooo0000o`000006o`0000Cooooo1?l0000=ooooo`;o00004oooool5o`0000Cooooo0ol0001=
ooooo`007?ooool00ol0003oooooooooo`0Yooooo`;o00000_ooool2o`0000?ooooo0_l00008oooo
o`;o00003Oooool2o`0000Oooooo1?l0000<ooooo`?o00004Oooool2o`0000?ooooo0_l00005oooo
o`Co000000?oooooo`000?l000001Ol00002ooooo`?o00004_ooool2o`0000Oooooo0ol00003oooo
o`?o000000?oooooo`000?l000001ol00007ooooo`?o00008oooool5o`0000Cooooo0ol0001=oooo
o`007?ooool00ol0003oooooooooo`0Yooooo`;o00000_ooool2o`0000gooooo0_l00005ooooo`;o
00003oooool3o`000003ooooool0003o000000_ooooo0_l00008ooooo`;o00001_ooool3o`0000[o
oooo0_l00004ooooo`Co00001Oooool2o`00017ooooo0ol00002ooooo`?o00000_ooool2o`0000Co
oooo1?l000001?oooooo0000o`000?l00005ooooo`;o00001_ooool2o`0003?ooooo0_l00017oooo
o`007?ooool00ol0003oooooooooo`0Tooooo`;o00000_ooool3o`0000Sooooo0_l0000>ooooo`;o
00001Oooool2o`0000Sooooo0_l00002ooooo`;o00004Oooool2o`0000;ooooo1?l00004ooooo`;o
00000oooool2o`0000cooooo0_l0000Dooooo`;o00001?ooool4o`000003ooooool0003o000000?o
000000Coooooo`000?l0003o00001?ooool4o`0000Cooooo0_l000000ooooooo0000o`000003oooo
o`Co00003?ooool2o`0000Cooooo0_l0000Cooooo`?o00001_ooool2o`0000;ooooo0_l00017oooo
o`007?ooool00ol0003oooooooooo`0Tooooo`;o00000_ooool2o`0000Oooooo1?l0000@ooooo`;o
00000_ooool3o`0000?ooooo0_l00004ooooo`;o00004oooool5o`0000;ooooo0_l00009ooooo`;o
00003?ooool2o`0000Gooooo0ol00006ooooo`;o00001?ooool2o`0000Cooooo1?l00004ooooo`;o
000000Coooooo`000?l0003o00001?ooool4o`000004ooooool0003o0000ooooo`;o00000oooool7
o`0000cooooo0_l00004ooooo`;o00004oooool3o`0000Kooooo0_l0001;ooooo`007?ooool00ol0
003oooooooooo`0aooooo`;o00004_ooool2o`0000;ooooo0ol00003ooooo`;o00001?ooool2o`00
00_ooooo0_l00006ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`0000Cooooo0_l0000>
ooooo`;o00001Oooool3o`0000Kooooo0_l00007ooooo`;o000000?oooooo`000?l000003Oooool3
o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000003ooooo`?o00000_ooool2
o`0002Oooooo0_l0000<ooooo`;o00000_ooool2o`0000;ooooo0_l0000nooooo`007?ooool00ol0
003oooooooooo`0booooo`;o00001Oooool2o`0000oooooo0_l0000Fooooo`;o00000oooool2o`00
00Gooooo0_l00004ooooo`;o00001?ooool2o`000003ooooool0003o000000_ooooo0_l00004oooo
o`;o00003Oooool2o`0000;ooooo0_l000000ooooooo0000o`00000=ooooo`?o000000?oooooo`00
0?l000001?ooool2o`0000;ooooo0_l00005ooooo`;o00001_ooool4o`0000Oooooo0_l0000Doooo
o`;o00001?ooool2o`0000Gooooo0ol00002ooooo`;o00000_ooool3o`0003gooooo000Looooo`03
o`000?oooooooooo037ooooo0ol00005ooooo`;o00003?ooool2o`0000Cooooo0_l00004ooooo`Co
00002Oooool2o`0000Gooooo0_l000000ooooooo0000o`00000=ooooo`Ko00004Oooool2o`0000go
oooo0_l00002ooooo`;o00004?ooool2o`0000Sooooo1_l00008ooooo`;o00000oooool4o`0000Oo
oooo0_l0000Jooooo`;o00001Oooool2o`0000Sooooo0_l0000mooooo`007?ooool00ol0003ooooo
ooooo`0Wooooo`;o000000?oooooo`000?l000001Oooool2o`0000Kooooo0_l00002ooooo`;o0000
2?ooool2o`0000Cooooo0_l00004ooooo`Ko00001oooool2o`0000Sooooo0_l00004ooooo`;o0000
1oooool4o`0000?ooooo0_l0000<ooooo`;o00004?ooool2o`0000Gooooo0_l000000ooooooo0000
o`00000Eooooo`;o00002_ooool2o`00023ooooo0_l0000?ooooo`?o00003Oooool2o`0003Oooooo
000Looooo`03o`000?oooooooooo023ooooo0_l00005ooooo`;o000000?oooooo`000?l000001?oo
ool2o`0000_ooooo0_l0000;ooooo`;o000000?oooooo`000?l000002?ooool2o`0001Oooooo0_l0
0005ooooo`;o00000_ooool2o`0000?ooooo0ol0000;ooooo`;o00003Oooool2o`000003ooooool0
003o000000Gooooo0_l000000ooooooo0000o`00000Cooooo`;o00002oooool2o`0000kooooo0_l0
0002ooooo`;o00003Oooool2o`0000oooooo0ol00004ooooo`;o00001oooool2o`0003Oooooo000L
ooooo`03o`000?oooooooooo023ooooo0_l00009ooooo`;o00000oooool2o`0000?ooooo0_l00006
ooooo`;o00002oooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o00002_ooool2
o`0000?ooooo0_l0000<ooooo`Co00000_ooool2o`0000;ooooo1?l0000Aooooo`;o00001oooool2
o`000003ooooool0003o000000Sooooo0_l0000Cooooo`;o000000?oooooo`000?l000002?ooool2
o`0000Cooooo0_l00008ooooo`;o000000?oooooo`000?l000000_l0000Tooooo`;o0000@?ooool0
01cooooo0_l0000/ooooo`;o00000oooool2o`0000?ooooo0_l00006ooooo`;o00002_ooool2o`00
00?ooooo0ol000000ooooooo0000o`000002ooooo`;o00001_ooool2o`0000;ooooo0_l00003oooo
o`;o00002?ooool2o`0000;ooooo0_l00002ooooo`;o00001?ooool2o`0001?ooooo0_l000001?oo
oooo0000o`000?l00006ooooo`;o00000oooool3o`0001Cooooo0_l00004ooooo`;o00003_ooool2
o`0000_ooooo1?l0000Dooooo`;o00001oooool2o`0000[ooooo0_l00008ooooo`;o0000<Oooool0
01cooooo00?o0000ooooooooool0:?ooool2o`0000Kooooo0_l0000?ooooo`Co00001?ooool2o`00
0003ooooool0003o000000Ko00000oooool2o`0000Gooooo0_l0000Aooooo`;o00001?ooool4o`00
013ooooo0_l00009ooooo`Co00002oooool3o`0000Cooooo0_l0000>ooooo`;o00003Oooool2o`00
00Gooooo0_l0000Sooooo`;o00001oooool2o`0000Wooooo0ol00004ooooo`;o00000_ooool2o`00
037ooooo000Looooo`03o`000?oooooooooo02Sooooo0_l0000=ooooo`;o00002?ooool6o`0000Go
oooo0ol000000ooooooo0000o`000005ooooo`;o00006_ooool2o`0000;ooooo0_l0000=ooooo`;o
00000oooool2o`0000Wooooo0_l0000>ooooo`?o00000oooool2o`0000kooooo0_l00003ooooo`;o
00002?ooool2o`0000Gooooo0_l0000;ooooo`;o00000oooool2o`0000_ooooo0ol00003ooooo`;o
00000oooool2o`0000gooooo0_l00005ooooo`;o0000=Oooool001cooooo00?o0000ooooooooool0
:oooool2o`0000[ooooo0_l0000<ooooo`Co00001?ooool5o`000003ooooool0003o000000Wooooo
0_l0000Cooooo`;o00001?ooool2o`0000?ooooo0_l00004ooooo`Co00000oooool2o`0001Kooooo
1_l0000@ooooo`;o00001_ooool2o`0001cooooo1?l000000ooooooo0000o`00000;ooooo`?o0000
2?ooool2o`0000Kooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o00006_oo
ool2o`0000;ooooo1ol000000ooooooo0000o`000003ooooo`;o00001?ooool2o`0001Wooooo0_l0
0003ooooo`Co00000_ooool3o`0000;ooooo0_l00002ooooo`;o00004oooool5o`0000kooooo0_l0
0002ooooo`;o00009_ooool4o`0000gooooo0ol00003ooooo`;o00002_ooool2o`0000;ooooo0_l0
000oooooo`007?ooool00ol0003oooooooooo`0eooooo`;o00003?ooool2o`0000Kooooo1?l00000
0ooooooo0000o`000006ooooo`;o00001Oooool2o`0001_ooooo0_l000001?oooooo0000o`000?l0
0007ooooo`;o00000_ooool2o`0001;ooooo1_l0000>ooooo`;o00006Oooool2o`0000Kooooo0_l0
0007ooooo`Co00003_ooool2o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`;o00000ooo
ool2o`0003oooooo000Looooo`03o`000?oooooooooo03Gooooo0_l00005ooooo`;o00001Oooool2
o`0000Gooooo1?l0000<ooooo`;o00000oooool2o`0000[ooooo0_l0000?ooooo`;o00001_ooool2
o`0001_ooooo0_l000001?oooooo0000o`000?l00003ooooo`;o00009?ooool2o`000003ooooool0
003o000000?ooooo0_l00007ooooo`;o00003?ooool2o`0000[ooooo0_l00002ooooo`;o00000_oo
ool2o`0000Sooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00000oooool2
o`0000Oooooo0_l00002ooooo`?o00002_ooool2o`0000;ooooo0_l00003ooooo`?o00002Oooool2
o`0000cooooo0ol00008ooooo`;o00002Oooool2o`0000?ooooo0_l0000;ooooo`;o00001oooool2
o`0000Sooooo0_l00009ooooo`;o00004_ooool3o`00017ooooo0_l00006ooooo`;o00003?ooool4
o`0000cooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00001Oooool2o`00
00cooooo2?l00009ooooo`Co00001?ooool4o`0001?ooooo0_l00002ooooo`?o00004oooool2o`00
00?ooooo0_l00006ooooo`;o00000_ooool2o`0000gooooo1?l000001?oooooo0000o`000?ooool2
o`0000Cooooo1?l0000Booooo`?o00004Oooool2o`0000[ooooo0ol000001?oooooo0000o`000?oo
ool2o`000004ooooool0003o0000o`0000;ooooo0_l00015ooooo`007?ooool00ol0003ooooooooo
o`0`ooooo`Co00003?ooool2o`0000?ooooo1Ol000000ooooooo0000o`000008ooooo`;o000000?o
ooooo`000?l000000_ooool4o`0001Gooooo0_l000001?oooooo0000o`000?l00005ooooo`;o0000
6_ooool2o`0000;ooooo0_l00003ooooo`;o00002?ooool4o`0000Cooooo0_l00004ooooo`;o0000
0_ooool2o`00013ooooo0_l0000Kooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`000004
ooooool0003o0000ooooo`?o00000_ooool2o`0004Gooooo000Looooo`03o`000?oooooooooo033o
oooo1?l00005ooooo`;o00001Oooool2o`0000?ooooo0_l0000<ooooo`Co00001Oooool2o`0000Go
oooo0_l00004ooooo`?o00000_ooool5o`000004ooooool0003o0000ooooo`Ko00000oooool2o`00
00Cooooo0_l00005ooooo`;o00000_ooool2o`0000gooooo0_l00003ooooo`;o00001oooool3o`00
00Cooooo0_l00006ooooo`;o00000_ooool2o`0002gooooo0_l0000@ooooo`;o00001Oooool2o`00
03kooooo000Looooo`03o`000?oooooooooo02Oooooo0_l00007ooooo`;o00001oooool2o`0000So
oooo1?l0000<ooooo`?o00002oooool4o`0000;ooooo3ol000000ooooooo0000o`000006o`0000;o
oooo0_l000000ooooooo0000o`000004o`0000?ooooo0_l00002ooooo`;o00003?ooool4o`0000Oo
oooo0_l00002ooooo`;o00001?ooool3o`000004ooooool0003o0000ooooo`;o00000oooool2o`00
01Oooooo0_l0000;ooooo`;o00008Oooool2o`0000kooooo0_l0000^ooooo`007?ooool00ol0003o
ooooooooo`0Wooooo`;o00001_ooool3o`0000;ooooo0ol0000<ooooo`Ko00002oooool2o`0000Go
oooo0_l00004ooooo`;o00001?oooolHo`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o
00004_ooool2o`000003ooooool0003o000000;o00001?ooool2o`000003ooooool0003o000000So
oooo0_l00002ooooo`;o000000?oooooo`000?l000000oooool2o`0000kooooo0_l00002ooooo`;o
000000?oooooo`000?l000000_l00004ooooo`Co00000oooool2o`0000;ooooo0_l000000ooooooo
0000o`00000@ooooo`;o00001_ooool2o`00013ooooo0_l0000^ooooo`007?ooool00ol0003ooooo
ooooo`0_ooooo`;o00000oooool3o`0000_ooooo0ol00002ooooo`Co00000oooool2o`0000;ooooo
0_l00007ooooo`;o00000oooool2o`0000Cooooo6?l00008ooooo`;o00004?ooool2o`0000;ooooo
0_l00009ooooo`;o00006_ooool2o`0000Oooooo1_l00002ooooo`;o000000Goooooo`000?l0003o
0000ooooo`02o`0000;ooooo1?l00007ooooo`;o000000?oooooo`000?l000004?ooool2o`0000Ko
oooo1?l0000nooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00000oooool2o`0000?ooooo
0_l000000ooooooo0000o`000002o`000004ooooool0003o0000o`0000Gooooo0ol00002ooooo`;o
000000Coooooo`000?l0003o00003?ooool2o`000003ooooool0003o000000go000000?oooooo`00
0?l000001_l000000ooooooo0000o`000008ooooo`Co00003_ooool2o`0001_ooooo1?l00003oooo
o`;o00001Oooool2o`0000Oooooo1Ol0000:ooooo`;o00001Oooool2o`0001gooooo0_l00006oooo
o`;o0000?_ooool001cooooo00?o0000ooooooooool0<_ooool2o`0000;ooooo1Ol000000ooooooo
0000o`000002o`000003ooooool0003o000000Oooooo0_l00005ooooo`;o00002Oooool2o`0000Go
oooo7Ol00008ooooo`;o00001oooool2o`0000Gooooo1?l00003ooooo`?o00002_ooool2o`0000Oo
oooo1_l000001?oooooo0000o`000?ooool2o`0000Kooooo0_l000000ooooooo0000o`00000Foooo
o`;o00002Oooool2o`0001;ooooo0_l0000Aooooo`;o0000<oooool001cooooo0_l0000cooooo`;o
00000_ooool3o`0001gooooo0_l00004ooooo`;o00000oooool5o`000003ooooool0003o000001Oo
00004Oooool2o`0000Gooooo1?l00002ooooo`Co00002_ooool2o`0000Wooooo1?l000001?oooooo
0000o`000?ooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000001oooool2o`00
0003ooooool0003o000000Kooooo0_l0000=ooooo`;o00003_ooool2o`0001Gooooo0_l0000coooo
o`007?ooool00ol0003oooooooooo`0booooo`;o00003?ooool2o`0001?ooooo0ol00004ooooo`;o
000000?oooooo`000?l000007_l000000ooooooo0000o`00000@ooooo`;o00002_ooool2o`0000?o
oooo0_l0000:ooooo`;o00001_ooool2o`0000;ooooo0ol00005ooooo`?o00003Oooool7o`0000Co
oooo0_l0000<ooooo`;o00003oooool2o`0000Kooooo0_l00003ooooo`;o0000?Oooool001cooooo
00?o0000ooooooooool0;_ooool2o`0000;ooooo0_l0000<ooooo`;o00001_ooool4o`0000Wooooo
0_l00006oooooa?o00000_ooool6o`000003ooooool0003o000000?o00000_ooool2o`0000_ooooo
0_l00003ooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000[o
oooo0_l00002ooooo`?o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00003ooooo`?o
000000?oooooo`000?l000002_ooool2o`0000;ooooo0_l00005ooooo`;o00002oooool3o`0000[o
oooo0_l0000:ooooo`;o00000oooool3o`0003cooooo000Looooo`03o`000?oooooooooo02kooooo
0_l00008ooooo`;o00001?ooool2o`0000Sooooo1?l0000Aooooo`;o000000?oooooo`000?l00000
5ol000000ooooooo0000o`000003o`0000_ooooo0_l000000ooooooo0000o`000002ooooo`Co0000
0oooool3o`000004ooooool0003o0000ooooo`Co00001?ooool4o`0000Sooooo0ol000001Ooooooo
0000o`000?l0003ooooo00;o00000_ooool2o`0000Cooooo1_l000001Ooooooo0000o`000?l0003o
oooo00;o00000_ooool2o`0000Wooooo0_l0000<ooooo`;o00002_ooool4o`0000kooooo0_l0000l
ooooo`007?ooool00ol0003oooooooooo`0`ooooo`Co00001?ooool3o`0000?ooooo0_l00009oooo
o`;o00000_ooool2o`0000Cooooo0_l0000;oooooa[o000000?oooooo`000?l000000ol00005oooo
o`;o00000oooool2o`0000Gooooo1Ol00002ooooo`;o00001Oooool5o`0000?ooooo1?l00004oooo
o`;o00000_ooool2o`0000;ooooo1?l000000ooooooo0000o`000003o`000003ooooool0003o0000
00?ooooo2?l000001?oooooo0000o`000?ooool4o`0000Cooooo0_l0000Eooooo`;o00000_ooool2
o`0000?ooooo0_l0000:ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0<?ooool6o`00
00?ooooo0_l00006ooooo`;o00002_ooool2o`0000Cooooo0_l00007ooooobCo00001Oooool2o`00
00_ooooo1?l00009ooooo`Go00000oooool2o`0000;ooooo1_l00002ooooo`;o00000oooool3o`00
0003ooooool0003o000000So000000?oooooo`000?l000000ol00003ooooo`;o00000_ooool6o`00
00;ooooo0_l00004ooooo`;o00003oooool2o`0000;ooooo0_l00003ooooo`Co00002?ooool2o`00
043ooooo000Looooo`03o`000?oooooooooo01_ooooo0_l0000Gooooo`;o00002oooool2o`0001Wo
oooo4ol000000ooooooo0000o`000002o`000003ooooool0003o000000[o00007?ooool2o`0000Ko
oooo1Ol000000ooooooo0000o`000002o`0000Cooooo1?l000000ooooooo0000o`000002o`000005
ooooool0003o0000o`000?ooool02ol00003ooooo`;o00001_ooool2o`0000Sooooo0_l0000Aoooo
o`;o00001Oooool4o`0000;ooooo0_l00005ooooo`;o0000?oooool001cooooo00?o0000oooooooo
ool06oooool2o`0002Gooooo0_l00004ooooo`;o00003_ooool3o`0000?ooooo8ol000000ooooooo
0000o`000003ooooo`;o00005?ooool3o`0000Gooooo0_l000000ooooooo0000o`000008ooooo`ko
000000?oooooo`000?l000002ol000001?oooooo0000o`000?l00002ooooo`;o00001Oooool2o`00
00Gooooo0_l00005ooooo`;o00002Oooool2o`0000_ooooo0_l00005ooooo`;o0000?oooool001co
oooo00?o0000ooooooooool0<?ooool2o`00013ooooo0_l00004ooooo`Co00000_ooool2o`0000?o
oooo0_l00003ooooo`?o00000oooool3o`000003ooooool0003o000001Wo00001Oooool3o`0000;o
oooo0_l0000<ooooo`;o00001oooool2o`0000Kooooo0_l00002ooooo`;o00001_ooool;o`0000;o
oooo5ol000000ooooooo0000o`000002ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o
00000oooool2o`0000[ooooo0_l00003ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0
<?ooool2o`0001Sooooo0_l00002ooooo`;o00000oooool2o`0000Cooooo0_l000000ooooooo0000
o`00000Ro`000003ooooool0003o000000;o00001oooool2o`0000Oooooo0_l0000?ooooo`;o0000
0_ooool2o`0000;ooooo0_l00003ooooo`_o000000?oooooo`000?l000001?l000000ooooooo0000
o`00000Eo`00017ooooo0_l000000ooooooo0000o`000002ooooo`?o00001_ooool2o`0000;ooooo
0ol00002ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0<?ooool4o`0000Sooooo0_l0
0006ooooo`;o00004oooool2o`000003ooooool0003o000000Oo000000?oooooo`000?l000004_l0
00000ooooooo0000o`000003o`000003ooooool0003o000000Kooooo0_l000001?oooooo0000o`00
0?ooool2o`0001?ooooo0_l00008ooooo`;o00001OoooolNo`000003ooooool0003o000000Oo0000
1_ooool2o`0000Wooooo0_l00003ooooo`Ko00001Oooool2o`0000?ooooo0_l00002ooooo`;o0000
@?ooool001cooooo00?o0000ooooooooool0<?ooool4o`000003ooooool0003o000000Gooooo0_l0
0006ooooo`;o00005_oooolQo`0000Cooooo0_l00006ooooo`Co000000Coooooo`000?l0003o0000
4oooool2o`0000_ooooo0ol000000ooooooo0000o`000004o`000003ooooool0003o000000?o0000
00?oooooo`000?l000004_l000000ooooooo0000o`000003o`0000Oooooo0_l00008ooooo`;o0000
1?ooool2o`0000;ooooo0_l0000:ooooo`Ko0000@?ooool001cooooo00?o0000ooooooooool0;?oo
ool2o`0000Oooooo0_l00009ooooo`;o00000oooool2o`0000[ooooo0_l00008ooooo`;o00000ooo
oolMo`0000Oooooo0_l000000ooooooo0000o`000007o`0000cooooo0_l00003ooooo`;o00000ooo
ool2o`0000Wooooo0ol00002ooooobKo00000_ooool2o`0000gooooo0_l0000Aooooo`;o00000_oo
ool4o`00047ooooo000Looooo`03o`000?oooooooooo02cooooo0_l000001?oooooo0000o`000?l0
0003ooooo`;o00002Oooool2o`0000?ooooo0_l000000ooooooo0000o`000007ooooo`;o00001ooo
ool3o`0000Oooooo6?l00008ooooo`;o000000?oooooo`000?l000000_ooool4o`0000_ooooo1_l0
00000ooooooo0000o`000003ooooo`;o00002_oooolWo`0000Cooooo0ol0000<ooooo`;o000000?o
ooooo`000?l000000oooool2o`0000[ooooo0_l00004ooooo`;o0000@Oooool001cooooo00?o0000
ooooooooool0;oooool3o`0000gooooo0_l00005ooooo`Ko00003_ooool3o`0000Oooooo0ol00000
1?oooooo0000o`000?ooool3o`000003ooooool0003o000000?o000000?oooooo`000?l000001Ol0
000?ooooo`Co00002oooool2o`0000;ooooo0_l0000;ooooo`;o00000oooool6o`000003ooooool0
003o000001Wo000000?oooooo`000?l000001?l00002ooooo`Ko00002_ooool3o`000003ooooool0
003o000000;ooooo0ol0000@ooooo`;o00002?ooool2o`0003Oooooo000Looooo`03o`000?oooooo
oooo03kooooo0ol00005ooooo`;o00000_ooool2o`0000_ooooo1_l00008ooooo`Go000000?ooooo
o`000?l000003ol000000ooooooo0000o`000009ooooo`;o00006_ooool2o`000003ooooool0003o
000000;ooooo0_l00003ooooobOo00001?ooool6o`000003ooooool0003o000000Oooooo0ol00005
ooooo`;o00006oooool2o`0003Oooooo000Looooo`;o0000<?ooool2o`0000gooooo1Ol00006oooo
o`;o00003?ooool5o`0000[ooooo5_l000000ooooooo0000o`000002ooooo`;o00001Oooool2o`00
00?ooooo0_l0000;ooooo`;o00001oooool3o`000003ooooool0003o000000?ooooo0_l00002oooo
oc7o000000?oooooo`000?l000001?ooool2o`0000;ooooo0_l00006ooooo`?o00001?ooool2o`00
00gooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00001_ooool3o`0000Oo
oooo0_l00006ooooo`;o00003oooool4o`0000[ooooo4?l00003ooooo`;o00001?ooool2o`0000[o
oooo0_l00006ooooo`;o00000oooool3o`0000Kooooo0_l00004ooooo`;o000000?oooooo`000?l0
00001?ooool<o`0000;ooooo8Ol000000ooooooo0000o`000004ooooo`?o00002Oooool3o`0000;o
oooo1?l00005ooooo`?o00001Oooool2o`0000Gooooo1?l0000dooooo`007?ooool00ol0003ooooo
ooooo`0gooooo`?o00008_ooool2o`0000[ooooo4_l000000ooooooo0000o`00000@ooooo`;o0000
1_ooool2o`0000Cooooo0_l00003ooooo`;o00001oooool3o`0000Kooooo0_l000000ooooooo0000
o`00000@o`0000;ooooo5_l00003ooooo`Co00000oooool2o`0000kooooo0_l00003ooooo`;o0000
0_ooool3o`0000Cooooo0_l00006ooooo`Co0000=?ooool001cooooo00?o0000ooooooooool0?ooo
ool2o`0000Wooooo0_l00005ooooo`?o00005_ooool2o`000005ooooool0003o0000o`000?ooool0
1Ol000001?oooooo0000o`000?l00006ooooo`;o00001?ooool5o`0000;ooooo0ol00006ooooo`;o
00002?ooool2o`0000Sooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000?o
oooo2Ol000000ooooooo0000o`00000Eo`0000;ooooo0_l00005ooooo`;o00002Oooool2o`0000_o
oooo1Ol000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l00000?_ooool001cooooo
00?o0000ooooooooool0<_ooool2o`0000;ooooo0_l00003ooooo`;o000000Coooooo`000?l0003o
00001Oooool2o`0000;ooooo0_l00005ooooo`Co00002?ooool2o`0000Kooooo0_l000000ooooooo
0000o`000002o`000004ooooool0003o0000ooooo`Go00000oooool2o`0000Kooooo0_l000001?oo
oooo0000o`000?ooool7o`000003ooooool0003o000000Gooooo0ol0000Fooooo`;o00000_ooool2
o`000004ooooool0003o0000oooooaSo000000?oooooo`000?l000001ol00003ooooo`;o00004?oo
ool2o`0000_ooooo1Ol00005ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0;_ooool2
o`0000;ooooo0_l00002ooooo`?o00000_ooool2o`000003ooooool0003o000000Kooooo0ol00007
ooooo`;o000000?oooooo`000?l000002?ooool2o`0000Kooooo0_l000000ooooooo0000o`000003
ooooo`;o000000?oooooo`000?l000001Ol00007ooooo`;o00000oooool2o`0000?ooooo1_l00007
ooooo`;o00006oooool2o`000003ooooool0003o000000So000000?oooooo`000?l000006ol00004
ooooo`;o0000I_ooool001cooooo00?o0000ooooooooool0;_ooool2o`0000Oooooo0ol0000<oooo
o`?o00001oooool2o`0000Oooooo0_l0000:ooooo`;o00001_ooool2o`0000Cooooo1?l00007oooo
o`;o00002?ooool2o`000004ooooool0003o0000o`0000Kooooo0_l0000Jooooo`Co00000_oooolG
o`000003ooooool0003o000000?o00000oooool=o`00013ooooo0_l0001Dooooo`007?ooool00ol0
003oooooooooo`0fooooo`Co00002_ooool2o`0001?ooooo0_l0000:ooooo`;o00000_ooool4o`00
00Kooooo0_l0000Nooooo`?o00001?ooool2o`0000cooooo0_l00006ooooo`Go000000?oooooo`00
0?l000006ol000000ooooooo0000o`00000>o`0000Oooooo0_l00006ooooo`;o0000E?ooool001co
oooo00?o0000ooooooooool0=_ooool2o`0000cooooo1?l000000ooooooo0000o`000004ooooo`;o
00006?ooool4o`0000Kooooo0_l0000;ooooo`;o00000_ooool2o`0000Gooooo0_l00004ooooo`Oo
00000_ooool3o`0000Gooooo0_l00004ooooo`;o00001ooooolYo`0000;ooooo0_l00002ooooo`Co
00001oooool2o`0005cooooo000Looooo`03o`000?oooooooooo03gooooo0_l00005ooooo`Co0000
00?oooooo`000?l000001?ooool3o`0000_ooooo0_l0000Looooo`;o00000oooool2o`0000;ooooo
0_l00005ooooo`;o00001?ooool7o`0000?ooooo0_l00005ooooo`;o00001Oooool2o`0000Wooooo
:_l0000Eooooo`;o00002Oooool3o`0000?ooooo0_l00013ooooo`007?ooool00ol0003ooooooooo
o`0dooooo`;o00001oooool4o`000003ooooool0003o000000;o00001Oooool2o`0000;ooooo0ol0
000;ooooo`;o00007?ooool2o`0001Cooooo0_l000000ooooooo0000o`00000<ooooo`;o00001Ooo
ool2o`0000Cooooo0_l00002ooooo`?o000000?oooooo`000?l000008?l000000ooooooo0000o`00
0002o`0000Sooooo0_l0000;ooooo`;o00002Oooool3o`0000?ooooo0_l00013ooooo`007?ooool0
0ol0003oooooooooo`0dooooo`;o00000oooool2o`0000;ooooo1?l000001?oooooo0000o`000?l0
0006ooooo`;o00000_ooool4o`0000Oooooo0_l00002ooooo`;o00001_ooool2o`0000Kooooo0_l0
00000ooooooo0000o`00000Uooooo`;o00002oooool5o`000003ooooool0003o000000;ooooo0_l0
0002ooooo`;o00001_ooool7o`000003ooooool0003o000001Wo000000Coooooo`000?l0003ooooo
0_l00002ooooo`;o00005Oooool4o`0000?ooooo0_l00003ooooo`;o0000?_ooool001cooooo00?o
0000ooooooooool0=oooool4o`0000Sooooo0_l0000<ooooo`;o00001?ooool9o`0000Kooooo0_l0
0005ooooo`?o000000?oooooo`000?l000005?ooool2o`0000?ooooo0_l00005ooooo`Oo00002ooo
ool8o`0000Sooooo:Ol000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00003ooooo`;o0000
3oooool3o`0000Gooooo0_l00003ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool06Ooo
ool2o`0001cooooo0_l00006ooooo`;o00000_ooool2o`0000cooooo0_l00004ooooo`Oo00003ooo
ool2o`0001Sooooo0_l00002ooooo`Co00001?ooool6o`0000;ooooo0_l00009ooooo`;o00000_oo
ool2o`000004ooooool0003o0000ooooo`Co000000?oooooo`000?l00000:?l0000;ooooo`?o0000
3oooool2o`0004_ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05
onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0Iooooo`;o00009?ooool6o`00
00kooooo0_l00006ooooo`;o00003oooool2o`0001gooooo1?l00006ooooo`;o00001?ooool2o`00
00Wooooo0_l00005ooooo`Oo000000?oooooo`000?l000000_l000000ooooooo0000o`00000To`00
00[ooooo0_l0000Booooo`;o00002_ooool2o`0003gooooo00001_ooooooMgMgoiRHV?ooooooV9RH
ogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003ooooooooo
o`0fooooo`;o00002Oooool2o`00013ooooo0_l00004ooooo`;o00004Oooool2o`00047ooooo0_l0
0002ooooo`;o000000Goooooo`000?l0003o0000ooooo`0:o`000003ooooool0003o000000_o0000
00?oooooo`000?l000000ol000000ooooooo0000o`000002o`000003ooooool0003o000000;o0000
00?oooooo`000?l000006Oooool2o`0000Wooooo0ol0000mooooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`0fooooo`;o00004_ooool2o`0000Kooooo0ol00004ooooo`;o00007?ooool2o`0000Kooooo
0_l00003ooooo`;o00001Oooool2o`0000Sooooo0ol000000ooooooo0000o`00000Cooooo`;o0000
0oooool2o`000005ooooool0003o0000o`000?ooool04ol000000ooooooo0000o`00000:o`000003
ooooool0003o000000;o000000?oooooo`000?l000000ol0000Tooooo`;o0000?_ooool00003oooo
ool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Ko
oooo0ol00012ooooo`?o00001Oooool2o`0000Kooooo0ol0000Fooooo`;o00002_ooool2o`0000Co
oooo1?l00003ooooo`;o00001Oooool2o`0000Sooooo1ol00009ooooo`;o00001oooool4o`0000;o
oooo1Ol000000ooooooo0000o`00000Xo`0006Gooooo00000ooooooo0000ooooo`02ooooo`03o`00
0?oooooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo047o
oooo1?l00004ooooo`;o00002?ooool3o`00013ooooo0_l00003ooooo`;o00004?ooool5o`0000;o
oooo1?l000000ooooooo0000o`000003ooooo`;o00000oooool2o`0000;ooooo1Ol00009ooooo`?o
00001Oooool2o`000003ooooool0003o000000Oo00000_ooool2o`000003ooooool0003o000000Ko
000000?oooooo`000?l000003ol000000ooooooo0000o`000007o`00017ooooo0ol0001Cooooo`00
00?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo
00?o0000ooooooooool0@Oooool2o`000003ooooool0003o000000?ooooo0ol00005ooooo`;o0000
00?oooooo`000?l000004?ooool2o`0000kooooo0_l00008ooooo`;o00000_ooool4o`000003oooo
ool0003o000000?ooooo0_l00003ooooo`;o00001?ooool2o`0000_ooooo0_l00005ooooo`;o0000
0oooool2o`000003ooooool0003o000000Co00000oooool9o`000003ooooool0003o000000ko0000
00?oooooo`000?l000001ol0000=ooooo`;o00000_ooool3o`0005?ooooo00001_ooooooMgMgoiRH
V?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`12ooooo`Co
00001?ooool2o`0000Gooooo1?l0000Eooooo`;o00001?ooool2o`000004ooooool0003o0000oooo
o`;o00002oooool2o`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`00
00;ooooo0ol000000ooooooo0000o`000005ooooo`;o00001oooool2o`0000Kooooo1_l00003oooo
oaSo00000_ooool3o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000002oooool2
o`0000Wooooo0_l00003ooooo`;o0000B?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?oo
ool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo03[ooooo0_l00006ooooo`;o0000
3oooool4o`0000Cooooo0_l0000=ooooo`;o00001?ooool2o`000003ooooool0003o000000kooooo
0_l00004ooooo`Oo000000Coooooo`000?l0003ooooo0ol00003ooooo`;o000000?oooooo`000?l0
00000oooool5o`0000Kooooo0_l00005ooooo`Co000000?oooooo`000?l000001OoooolFo`0000;o
oooo0ol000001?oooooo0000o`000?ooool2o`000003ooooool0003o000001Kooooo0_l00003oooo
o`;o0000B?ooool001cooooo00?o0000ooooooooool0>_ooool2o`0000Kooooo0_l0000@ooooo`?o
00001?ooool2o`0000Oooooo0_l0000>ooooo`Co00001_ooool4o`0000Oooooo1_l00004ooooo`Oo
000000?oooooo`000?l000001Oooool5o`0000?ooooo0_l00008ooooo`;o00000ooooolJo`000003
ooooool0003o000000;ooooo0ol000000ooooooo0000o`00000Uooooo`;o0000A?ooool001cooooo
00?o0000ooooooooool0>_ooool2o`0000;ooooo1?l0000Booooo`Co00003?ooool2o`0000kooooo
1Ol00005ooooo`Co00002?ooool3o`0000Kooooo0_l000000ooooooo0000o`000002o`000003oooo
ool0003o000000gooooo0_l00008ooooo`;o00001?oooolLo`0000;ooooo1ol0000@ooooo`;o0000
4_ooool2o`0004Cooooo000Looooo`03o`000?oooooooooo03kooooo1?l0000Cooooo`?o00002ooo
ool2o`0000[ooooo0_l000001?oooooo0000o`000?ooool4o`0000?ooooo0_l0000<ooooo`;o0000
2oooool2o`0001?ooooo1?l00004ooooo`?o00000ooooolJo`0000?ooooo0_l00002ooooo`Go0000
1_ooool2o`0000;ooooo0_l00003ooooo`;o00005Oooool2o`00047ooooo000Looooo`03o`000?oo
oooooooo06?ooooo0_l0000:ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o0000
00?oooooo`000?l000000_l0000:ooooo`;o00002oooool2o`0001?ooooo1?l00005ooooo`?o0000
0ooooolAo`000004ooooool0003o0000ooooo`Co00000_ooool4o`0000Cooooo1?l00004ooooo`;o
00000_ooool4o`0000Kooooo0_l0000@ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0
B?ooool2o`00013ooooo0_l00003ooooo`;o00004Oooool2o`000003ooooool0003o000000;ooooo
0_l00002ooooo`?o00001?ooool2o`0000;ooooo0_l0000Oooooo`;o00002oooool2o`0000?ooooo
0ol000000ooooooo0000o`000003o`000003ooooool0003o000000Go000000Coooooo`000?l0003o
oooo0_l00004ooooo`Oo00000oooool2o`0000Cooooo0_l00004ooooo`;o00001_ooool2o`0000?o
oooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`0Yooooo`;o00007Oooool2o`00013ooooo
0ol00002ooooo`;o00005?ooool2o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l00000
1ol00009ooooo`Co00002_ooool2o`0000?ooooo0ol0000?ooooo`;o00000oooool;o`0000?ooooo
0_l000000ooooooo0000o`000002o`0000;ooooo2?l00009ooooo`;o00002Oooool4o`0000?ooooo
0_l0001>ooooo`007?ooool00ol0003oooooooooo`0Yooooo`;o00005Oooool2o`0000cooooo0_l0
0004ooooo`;o000000?oooooo`000?l000000_ooool2o`00027ooooo1?l000000ooooooo0000o`00
0007o`0000Cooooo0_l00003ooooo`Co00000oooool4o`0000?ooooo0_l00003ooooo`?o00001Ooo
ool2o`0000Sooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000;o000000?o
ooooo`000?l000000_ooool2o`0000;ooooo1?l00004ooooo`Ko000000?oooooo`000?l000000ooo
ool2o`000004ooooool0003o0000o`0000Sooooo1?l0000;ooooo`;o00001?ooool2o`00043ooooo
000Looooo`03o`000?oooooooooo043ooooo0_l0000<ooooo`;o00001?ooool2o`000003ooooool0
003o0000027ooooo3?l000000ooooooo0000o`00000<o`0000Oooooo1?l00005ooooo`;o00002Ooo
ool2o`0000Gooooo0_l00002ooooo`So00000oooool2o`0000Cooooo1ol000000ooooooo0000o`00
0002ooooo`Co00000oooool2o`000003ooooool0003o000000;o00000_ooool2o`0000Oooooo0_l0
000>ooooo`;o00001?ooool2o`00043ooooo000Looooo`03o`000?oooooooooo04;ooooo0_l0000B
ooooo`;o00000_ooool2o`0001Gooooo0_l00007ooooo`Co000000?oooooo`000?l000005?l00005
ooooo`;o00001Oooool2o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`0000Gooooo0_l00002
ooooo`Co00000_ooool2o`0000?ooooo0_l00004ooooo`_o000000?oooooo`000?l000000_l00003
ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Gooooo0_l00002ooooo`;o00001?ooool2
o`0000kooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`11ooooo`?o00004_ooool2o`00
00;ooooo0_l0000Eooooo`;o000000?oooooo`000?l000001_oooolEo`0000Gooooo0_l00002oooo
o`;o00001Oooool2o`0000Wooooo1_l00009ooooo`?o00002_ooool2o`000003ooooool0003o0000
00[o00002?ooool2o`0000Gooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00002?ooool2
o`0000kooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`11ooooo`;o0000<Oooool2o`00
00Kooooo5Ol00005ooooo`;o00002Oooool2o`0000_ooooo0_l00002ooooo`;o00001?ooool2o`00
00;ooooo0_l00003ooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`;o00000oooool2
o`0000Kooooo0_l00004ooooo`;o00001_ooool3o`0000Oooooo0_l00005ooooo`;o00002?ooool2
o`0004?ooooo000Looooo`;o0000Aoooool2o`0000Gooooo1?l00002ooooo`;o00004?ooool2o`00
00gooooo0_l000000ooooooo0000o`000006ooooo`ko000000?oooooo`000?l000000ol00003oooo
o`;o00002Oooool2o`0000Cooooo0_l00007ooooo`Ko00000_ooool2o`0000Oooooo1?l00002oooo
o`;o00000_ooool3o`000004ooooool0003o0000ooooo`?o00001_ooool2o`0000?ooooo0ol00000
0ooooooo0000o`000004ooooo`;o00001oooool2o`0000Cooooo0ol00008ooooo`;o00000_ooool2
o`0003oooooo000Looooo`03o`000?oooooooooo04Kooooo0_l00003ooooo`Ko00000_ooool2o`00
00Cooooo0_l0000:ooooo`;o00003Oooool2o`000003ooooool0003o000000Cooooo4ol000001?oo
oooo0000o`000?l00008ooooo`;o00001oooool4o`0000?ooooo0_l00002ooooo`;o00000_ooool2
o`0000;ooooo0_l00009ooooo`;o00000_ooool2o`000003ooooool0003o000000;o000000Cooooo
o`000?l0003ooooo0_l0000<ooooo`;o00000_ooool2o`0000oooooo0_l00002ooooo`;o00003Ooo
ool2o`0003oooooo000Looooo`03o`000?oooooooooo04Kooooo0_l00003ooooo`Oo00000oooool2
o`0000;ooooo0_l00009ooooo`?o00003_ooool4o`0000Cooooo4_l000000ooooooo0000o`000002
o`0000Sooooo0ol00006ooooo`Co00000oooool3o`0000Oooooo1?l00008ooooo`;o00001?ooool4
o`0001Oooooo1?l00005ooooo`Co00001Oooool2o`0005;ooooo000Looooo`03o`000?oooooooooo
047ooooo0_l000000ooooooo0000o`000007ooooo`;o000000Coooooo`000?l0003o00000_ooool2
o`0000gooooo0ol00007ooooo`;o00001Oooool7o`000003ooooool0003o000001?o00002?ooool2
o`000004ooooool0003o0000o`0000Kooooo0ol00004ooooo`;o00001oooool2o`0000[ooooo0_l0
00000ooooooo0000o`000003o`0000Oooooo0_l0000@ooooo`Ko00000oooool4o`0000Sooooo0_l0
000Dooooo`;o0000>Oooool001cooooo00?o0000ooooooooool0:?ooool2o`0001Oooooo0_l00000
0ooooooo0000o`00000;ooooo`Go000000?oooooo`000?l000001?ooool2o`0000;ooooo0_l0000;
ooooo`;o00001Oooool7o`000003ooooool0003o000001;o00002Oooool2o`000004ooooool0003o
0000o`0000Kooooo0_l00005ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000Kooooo
0_l00003ooooo`;o00000_ooool3o`0000Wooooo0_l00006ooooo`;o00003?ooool2o`0000Cooooo
0_l00009ooooo`;o00005?ooool2o`0003Wooooo000Looooo`03o`000?oooooooooo02Sooooo0_l0
000Nooooo`;o00001oooool5o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o00004_oo
ool2o`0000Gooooo5ol00009ooooo`?o000000?oooooo`000?l000002oooool2o`000005ooooool0
003o0000o`000?ooool00_l00006ooooo`;o00000oooool2o`0000cooooo0_l00008ooooo`;o0000
K_ooool001cooooo00?o0000ooooooooool0B?ooool2o`0000Oooooo0_l00004ooooo`;o00000_oo
ool2o`000003ooooool0003o000000gooooo0_l0000;oooooaWo00002Oooool2o`0000;ooooo0_l0
0006ooooo`;o00001Oooool2o`000003ooooool0003o000000Oooooo0_l00005ooooo`;o000000?o
ooooo`000?l000002?ooool2o`0001Sooooo0_l0001Nooooo`007?ooool00ol0003oooooooooo`0n
ooooo`;o00002_ooool2o`0000oooooo0_l000000ooooooo0000o`00000=ooooo`;o00002ooooolE
o`0000oooooo0_l00008ooooo`Go00000_ooool2o`000003ooooool0003o000000Oooooo1?l00003
ooooo`;o000000?oooooo`000?l000007Oooool2o`0000?ooooo0_l0001Nooooo`007?ooool00ol0
003oooooooooo`0nooooo`;o00001Oooool2o`0000?ooooo0_l00008ooooo`;o00001?ooool2o`00
00;ooooo0_l0000=ooooo`;o00002ooooolEo`0000oooooo0ol00004ooooo`;o00000oooool3o`00
00;ooooo1?l00009ooooo`?o00000_ooool2o`0000Gooooo0_l00006ooooo`;o00003?ooool2o`00
00;ooooo1?l00008ooooo`;o00000oooool2o`0000[ooooo0_l00018ooooo`007?ooool00ol0003o
ooooooooo`15ooooo`;o00003Oooool3o`0000?ooooo0_l00008ooooo`?o00001_ooool2o`000003
ooooool0003o000000[ooooo4ol0000@ooooo`;o00001?ooool2o`0000Oooooo1Ol000000ooooooo
0000o`000006ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo0_l00006ooooo`;o
00003?ooool2o`0000;ooooo0_l00005ooooo`Oo00000oooool2o`0000[ooooo0_l00018ooooo`00
7?ooool00ol0003oooooooooo`14ooooo`Co00002Oooool2o`0000;ooooo0_l00003ooooo`;o0000
2?ooool3o`0000Wooooo0_l0000:oooooaCo00002?ooool2o`0000Wooooo0_l00009ooooo`;o0000
1?ooool2o`0000Kooooo0_l00006ooooo`Go00007oooool6o`0005_ooooo000Looooo`03o`000?oo
oooooooo04Cooooo1?l00008ooooo`?o00001oooool3o`0000Gooooo1?l00004ooooo`;o00004ooo
oolAo`0000?ooooo0_l00003ooooo`;o00002Oooool2o`0000;ooooo0_l0000Looooo`Co00006?oo
ool2o`0000;ooooo0_l000000ooooooo0000o`00001Oooooo`007?ooool00ol0003oooooooooo`1;
ooooo`;o00000oooool2o`0000?ooooo0_l00004ooooo`?o00001?ooool2o`0000Kooooo0_l0000?
ooooo`;o00000_ooool?o`0000Gooooo0_l00006ooooo`;o00000_ooool2o`0000Kooooo0_l0000S
ooooo`;o00004oooool2o`0000;ooooo0_l00004ooooo`;o00004_ooool2o`0004Sooooo000Loooo
o`03o`000?oooooooooo04_ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l00004oooo
o`?o00002?ooool3o`0000;ooooo0ol0000;oooooaKo000000?oooooo`000?l000000_l00006oooo
o`?o00000_ooool2o`000004ooooool0003o0000o`0000Cooooo0_l00009ooooo`;o00001oooool2
o`0000gooooo0_l0000Mooooo`;o00004_ooool2o`0004Sooooo000Looooo`03o`000?oooooooooo
053ooooo0_l000000ooooooo0000o`000006ooooo`;o00002Oooool8o`0000_ooooo0_l00002oooo
oa;o000000?oooooo`000?l000000_l00006ooooo`;o00001_ooool5o`0000;ooooo0_l00009oooo
o`;o00001oooool2o`0002Oooooo0_l00005ooooo`Co0000F?ooool001cooooo00?o0000oooooooo
ool0BOooool2o`0000[ooooo0_l0000@ooooo`Ko00000_ooool2o`0000gooooo3ol00004ooooo`;o
00001?ooool5o`0000;ooooo0_l00003ooooo`Co00003?ooool2o`0000Sooooo0_l0000Nooooo`;o
00001_ooool5o`0000?ooooo1?l0000?ooooo`;o0000Aoooool001cooooo0_l0001:ooooo`;o0000
2_ooool2o`00013ooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000Cooooo
0_l00004ooooo`ko00001_ooool2o`0000?ooooo1Ol00002ooooo`;o00001oooool2o`0000Sooooo
1?l00008ooooo`;o00001?ooool2o`0001Sooooo0_l00003ooooo`;o000000Coooooo`000?l0003o
oooo0_l0000Fooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0@oooool2o`0000Cooooo
0_l0000Wooooo`;o00001?ooool2o`0000Sooooo1Ol000000ooooooo0000o`000002o`0000Kooooo
0_l00008ooooo`;o00002Oooool2o`0000Sooooo0ol00005ooooo`So00000_ooool2o`0000cooooo
0_l0000?ooooo`;o0000IOooool001cooooo00?o0000ooooooooool0@oooool2o`0001?ooooo0_l0
00000ooooooo0000o`000003ooooo`;o00002?ooool2o`0000?ooooo0ol0000@ooooo`[o00001?oo
ool2o`0000[ooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`So00000_oo
ool2o`0000cooooo0_l0001fooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o000000Cooooo
o`000?l0003o00000_ooool2o`0000Sooooo0_l00003ooooo`?o00002oooool2o`0000Gooooo1Ol0
00000ooooooo0000o`000003ooooo`?o00002Oooool2o`0000Kooooo1?l00003ooooo`;o00001?oo
ool2o`0000;ooooo0_l00003ooooo`?o00002?ooool2o`0001kooooo0_l0001Sooooo`007?ooool0
0ol0003oooooooooo`1:ooooo`;o00003oooool3o`0000;ooooo0_l000000ooooooo0000o`00000H
ooooo`;o00001oooool2o`0000;ooooo0_l00003ooooo`;o00001?ooool2o`0000;ooooo1_l00006
ooooo`;o00001_ooool2o`000003ooooool0003o000000;ooooo0_l000001?oooooo0000o`000?oo
ool2o`0000Sooooo0_l0000Mooooo`?o0000Hoooool001cooooo00?o0000ooooooooool0B_ooool2
o`00017ooooo0_l000001?oooooo0000o`000?ooool2o`0000gooooo0_l00004ooooo`;o00004?oo
ool3o`0000;ooooo0_l00004ooooo`;o00000_ooool2o`0000;ooooo0_l0000>ooooo`;o00002?oo
ool2o`0000;ooooo0ol0000Qooooo`;o00000_ooool4o`0000Kooooo0_l0001Jooooo`007?ooool0
0ol0003oooooooooo`1Eooooo`;o00001_ooool2o`0000;ooooo0_l00007ooooo`;o00001_ooool2
o`0000Cooooo0_l0000<ooooo`Co000000Coooooo`000?l0003o00002oooool3o`00017ooooo0_l0
0008ooooo`?o000000?oooooo`000?l000000_l0000Pooooo`;o00000oooool3o`0000Kooooo0_l0
001Jooooo`007?ooool00ol0003oooooooooo`1Booooo`;o000000?oooooo`000?l000002_ooool4
o`0000Gooooo0ol0000=ooooo`;o00001?ooool3o`0000?ooooo1?l000001?oooooo0000o`000?l0
0007ooooo`;o00000_ooool3o`0000?ooooo0_l0000Fooooo`Co00000_ooool2o`0001kooooo0_l0
0005ooooo`;o00004oooool2o`0004kooooo000Looooo`03o`000?oooooooooo053ooooo1?l00008
ooooo`Co00000oooool2o`0000Kooooo0_l00003ooooo`;o00000_ooool2o`0000Cooooo0_l00004
ooooo`?o00002?ooool2o`0000Oooooo1?l00007ooooo`Co00002?ooool2o`0000Cooooo0_l00006
ooooo`;o00008_ooool2o`0000Wooooo0_l0000?ooooo`;o0000C_ooool001cooooo00?o0000oooo
ooooool0D?ooool2o`0000[ooooo1?l0000;ooooo`;o00000_ooool7o`0000Oooooo0_l0000Eoooo
o`Co00001_ooool7o`0000Kooooo0_l00004ooooo`;o00001_ooool2o`000003ooooool0003o0000
01[ooooo0_l00003ooooo`;o00002Oooool2o`0005oooooo000Looooo`03o`000?oooooooooo06_o
oooo0_l00002ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o000000Coooooo`000?l0
003o00003Oooool2o`0000cooooo0_l00002ooooo`Co000000?oooooo`000?l000004Oooool2o`00
0004ooooool0003o0000ooooo`;o00005oooool2o`000004ooooool0003o0000ooooo`;o000000?o
ooooo`000?l000000ol0001Vooooo`007?ooool00ol0003oooooooooo`1Zooooo`;o00003Oooool2
o`000003ooooool0003o000000kooooo0_l0000;ooooo`?o00001?ooool2o`0000Sooooo0_l0000:
ooooo`;o00000_ooool3o`0001Sooooo0_l00004ooooo`;o000000?oooooo`000?l000000ol00005
ooooo`;o0000Goooool001cooooo00?o0000ooooooooool0J_ooool2o`0000?ooooo0_l00003oooo
o`;o00001Oooool2o`0000cooooo0_l0000>ooooo`;o00001Oooool3o`0000;ooooo0_l000000ooo
oooo0000o`000002o`0000Gooooo0_l00007ooooo`?o00001?ooool2o`0001[ooooo0ol00008oooo
o`;o0000Goooool001cooooo00?o0000ooooooooool0J_ooool2o`0000?ooooo0_l00003ooooo`?o
00001?ooool6o`0000Sooooo0_l00002ooooo`;o00001oooool2o`000003ooooool0003o000000Ko
oooo1_l000001?oooooo0000o`000?l00006ooooo`;o00000oooool2o`0000Gooooo0_l00002oooo
o`;o00005oooool6o`0006Wooooo000Looooo`03o`000?oooooooooo073ooooo1ol00003ooooo`Oo
00003?ooool2o`0000Gooooo1?l00003ooooo`;o00001Oooool5o`0000oooooo0_l00005ooooo`;o
00006?ooool2o`000003ooooool0003o000000;o00001Oooool2o`0006Cooooo000Looooo`03o`00
0?oooooooooo05_ooooo0_l0000Cooooo`Go00001Oooool3o`0001Oooooo0_l00002ooooo`;o0000
00Coooooo`000?l0003ooooo0_l00002ooooo`Go00001oooool2o`0000cooooo0_l0000Iooooo`;o
00002_ooool2o`0006Cooooo000Looooo`;o0000G?ooool2o`0000Oooooo0_l0000:ooooo`Co0000
1_ooool5o`0000;ooooo0_l0000Eooooo`;o000000Coooooo`000?l0003ooooo1_l000000ooooooo
0000o`000007ooooo`?o00002oooool4o`00013ooooo0_l00006ooooo`;o00001_ooool2o`0000ko
oooo0_l0000:ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0I?ooool2o`0000[ooooo
1?l000000ooooooo0000o`000003ooooo`Ko000000?oooooo`000?l000001Oooool2o`0000Oooooo
1Ol00005ooooo`;o00000_ooool4o`0000Oooooo1?l000001?oooooo0000o`000?l0000<ooooo`;o
00004?ooool2o`0000Kooooo0_l00006ooooo`;o00003_ooool2o`0000[ooooo0_l0001;ooooo`00
7?ooool00ol0003oooooooooo`1@ooooo`;o00004_ooool2o`0000cooooo0_l000000ooooooo0000
o`000003ooooo`;o00000_ooool2o`0000Sooooo0_l00007ooooo`Go00000oooool2o`0000kooooo
1Ol00002ooooo`;o00001_ooool3o`0000?ooooo0_l00029ooooo`007?ooool00ol0003ooooooooo
o`1@ooooo`;o00001_ooool2o`0000[ooooo0_l0000<ooooo`;o00001?ooool4o`0000;ooooo0_l0
0006ooooo`;o00000_ooool2o`0000Sooooo1?l000000ooooooo0000o`00000>ooooo`?o00002ooo
ool4o`0000Cooooo0_l000000ooooooo0000o`00000<ooooo`;o0000Moooool001cooooo00?o0000
ooooooooool0F?ooool2o`0001_ooooo1Ol00002ooooo`Co00001_ooool2o`0000;ooooo0_l00008
ooooo`Co00001_ooool5o`0000Kooooo0ol0000:ooooo`?o00001_ooool5o`0000Kooooo0_l00004
ooooo`;o0000Moooool001cooooo00?o0000ooooooooool0Goooool2o`0001Cooooo1_l000001?oo
oooo0000o`000?l00006ooooo`;o00000oooool2o`0000?ooooo0_l00003ooooo`;o00001?ooool2
o`0000;ooooo1Ol00007ooooo`;o00002_ooool2o`0000Wooooo0ol00006ooooo`;o0000OOooool0
01cooooo00?o0000ooooooooool0A?ooool2o`0001Wooooo0_l0000Fooooo`Co00001oooool5o`00
00Sooooo0_l00009ooooo`;o00006oooool2o`0000Wooooo0_l00004ooooo`?o00003Oooool2o`00
00;ooooo0_l00009ooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0A?ooool2o`00037o
oooo1?l00003ooooo`;o00000_ooool3o`0001_ooooo1ol00009ooooo`?o00001?ooool2o`0000go
oooo1Ol0000=ooooo`;o00000_ooool2o`0000Wooooo0_l0001Pooooo`007?ooool00ol0003ooooo
ooooo`1Sooooo`;o00002?ooool2o`0000oooooo0_l0000@ooooo`;o00001Oooool2o`0000Kooooo
2?l00009ooooo`?o00004_ooool5o`000003ooooool0003o000000Oooooo0_l00005ooooo`;o0000
K?ooool001cooooo00?o0000ooooooooool0Hoooool2o`0000Sooooo0_l0000<ooooo`;o000000?o
ooooo`000?l000002?ooool2o`0000;ooooo0_l000001?oooooo0000o`000?l00005ooooo`;o0000
1_ooool2o`0000_ooooo0_l0000;ooooo`Co00002?ooool2o`0000Cooooo0_l00003ooooo`Ko0000
1Oooool2o`0006cooooo000Looooo`03o`000?oooooooooo07_ooooo0_l0000;ooooo`;o00000_oo
ool2o`000003ooooool0003o000000Kooooo0_l00008ooooo`;o00002Oooool2o`0000_ooooo1?l0
0002ooooo`;o00003oooool5o`0000Gooooo1?l0001[ooooo`007?ooool00ol0003oooooooooo`1i
ooooo`Co00001?ooool2o`0000Cooooo0_l0000Gooooo`?o00007?ooool2o`00017ooooo0_l00006
ooooo`Co0000Joooool001cooooo00?o0000ooooooooool0M?ooool2o`0000?ooooo0ol00004oooo
o`?o00000_ooool4o`0001Oooooo0_l00003ooooo`;o00001Oooool2o`00013ooooo0_l00009oooo
o`?o00000_ooool2o`0007Wooooo000Looooo`03o`000?oooooooooo07Cooooo0_l00004ooooo`;o
00001?ooool2o`0000?ooooo0_l00007ooooo`?o00005?ooool2o`0000Gooooo0_l00002ooooo`;o
00000_ooool2o`0000?ooooo0_l00003ooooo`;o00002Oooool4o`000003ooooool0003o000000Ko
oooo0_l0001aooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<
c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0FOooool2o`0003?ooooo0ol00002
ooooo`?o00006?ooool5o`000003ooooool0003o000000?ooooo0_l0000@ooooo`?o00002?ooool2
o`00077ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1Iooooo`Co00002oooool2o`0000Cooooo
0_l0000Pooooo`;o000000Coooooo`000?l0003o00002?ooool2o`0000[ooooo0_l00002ooooo`;o
000000?oooooo`000?l000001_ooool3o`00013ooooo1?l0001iooooo`0000?ooooooa0@4?ooool0
0_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`1Kooooo`;o00002oooool2o`0000Cooooo0_l0000:ooooo`;o00003_ooool4o`0000;o
oooo0ol00002ooooo`;o00001oooool2o`0000[ooooo0_l00007ooooo`;o00001?ooool3o`0000[o
oooo0_l00006ooooo`;o00000_ooool2o`0007Gooooo00000ooooooo0000ooooo`02ooooo`03o`00
0?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000Loooool2o`0000Go
oooo0_l0000>ooooo`Co00000oooool2o`0000;ooooo1?l0000=ooooo`;o000000?oooooo`000?l0
00001?ooool2o`0000;ooooo0_l0000Aooooo`;o00002_ooool2o`0007Gooooo00000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03
o`000?oooooooooo07?ooooo0_l0000Booooo`;o00003?ooool7o`0000[ooooo0_l000000ooooooo
0000o`000004ooooo`;o00004_ooool2o`000003ooooool0003o000000Kooooo0_l0001iooooo`00
00?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@
41001_ooool00ol0003oooooooooo`1Mooooo`;o00005Oooool2o`0000gooooo0_l00002ooooo`;o
00001_ooool4o`0000;ooooo0_l00002ooooo`Co00005oooool2o`0000gooooo0_l000001?oooooo
0000o`000?l00005ooooo`;o0000NOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool0
1Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0G?ooool3o`000003ooooool0
003o000000cooooo0_l00004ooooo`;o00003Oooool2o`0000;ooooo0_l00006ooooo`Co00002?oo
ool2o`0000Cooooo0_l00007ooooo`;o00001oooool4o`0000cooooo0_l00002ooooo`;o0000P?oo
ool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Ko
oooo00?o0000ooooooooool0Eoooool2o`0000?ooooo0_l00002ooooo`;o00003?ooool2o`0001Oo
oooo0_l00005ooooo`;o00003?ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000Oo
oooo1?l0000<ooooo`;o0000Q?ooool001cooooo00?o0000ooooooooool0Eoooool2o`0003Cooooo
0ol0000<ooooo`;o00001oooool2o`000003ooooool0003o000000;o00004Oooool2o`0000Wooooo
1?l0001mooooo`007?ooool00ol0003oooooooooo`1Tooooo`;o00007_ooool2o`0000Oooooo0_l0
0005ooooo`;o000000?oooooo`000?l000001oooool2o`0000Kooooo0_l0000Cooooo`;o00001?oo
ool2o`0000?ooooo1?l0001mooooo`007?ooool00ol0003oooooooooo`1Tooooo`;o00006Oooool2
o`0000?ooooo0_l00003ooooo`;o00001oooool4o`000004ooooool0003o0000o`0000Kooooo0_l0
000?ooooo`;o00000_ooool2o`0000cooooo0ol0000Cooooo`;o0000K_ooool001cooooo00?o0000
ooooooooool0Noooool2o`000004ooooool0003o0000o`0000Sooooo0_l00007ooooo`;o00001?oo
ool2o`0000Oooooo1?l0000<ooooo`;o00000_ooool2o`0000[ooooo0_l000000ooooooo0000o`00
000Cooooo`;o0000K_ooool001cooooo00?o0000ooooooooool0Noooool2o`000003ooooool0003o
000001Cooooo1_l00003ooooo`;o000000?oooooo`000?l000000ol00006ooooo`?o00004?ooool2
o`000003ooooool0003o000008Kooooo000Looooo`03o`000?oooooooooo08?ooooo1?l0000=oooo
o`Co00000_ooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000Gooooo0ol00008
ooooo`;o00001_ooool2o`0000gooooo0_l0001jooooo`007?ooool00ol0003oooooooooo`21oooo
o`Ko00001?ooool2o`0000gooooo0_l00008ooooo`;o00001oooool4o`0000Gooooo0_l000000ooo
oooo0000o`000005ooooo`;o00002oooool2o`000003ooooool0003o000007Oooooo000Looooo`03
o`000?oooooooooo063ooooo0_l0000Oooooo`;o00002?ooool2o`00023ooooo1?l00005ooooo`;o
000000?oooooo`000?l000001Oooool4o`0000cooooo0_l0001gooooo`007?ooool00ol0003ooooo
ooooo`1Pooooo`;o00000oooool2o`0002Gooooo0_l0000:ooooo`;o00007_ooool2o`0000Sooooo
0_l00025ooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o00002?ooool2o`0001_ooooo1?l0
00000ooooooo0000o`000005ooooo`;o00007_ooool2o`0008oooooo000Looooo`03o`000?oooooo
oooo06oooooo0_l0000Mooooo`;o000000?oooooo`000?l00000]_ooool001cooooo0_l0002[oooo
o`;o000000?oooooo`000?l00000V_ooool001cooooo00?o0000ooooooooool0Z_ooool2o`000003
ooooool0003o000009[ooooo000Looooo`03o`000?oooooooooo0;cooooo0_l0002;ooooo`007?oo
ool00ol0003oooooooooo`2Hooooo`;o000000?oooooo`000?l000007oooool2o`0008_ooooo000L
ooooo`03o`000?oooooooooo08;ooooo0_l0000Dooooo`;o000000?oooooo`000?l000000_l0002Z
ooooo`007?ooool00ol0003oooooooooo`1jooooo`;o00001_ooool2o`0001Cooooo0_l00003oooo
o`;o00003_ooool2o`0000cooooo0_l000000ooooooo0000o`000029ooooo`007?ooool00ol0003o
ooooooooo`1jooooo`;o00007?ooool2o`0000?ooooo0ol0000=ooooo`;o00003?ooool2o`000003
ooooool0003o000008Wooooo000Looooo`03o`000?oooooooooo07cooooo0_l0000Oooooo`?o0000
7_ooool2o`0008Wooooo000Looooo`03o`000?oooooooooo07cooooo0_l0000;ooooo`;o0000__oo
ool001cooooo00?o0000ooooooooool0ROooool2o`0001gooooo0_l0002Oooooo`007?ooool00ol0
003oooooooooo`2Xooooo`;o00005_ooool2o`0008Oooooo000Looooo`03o`000?oooooooooo097o
oooo0_l0000]ooooo`;o0000Qoooool001cooooo00?o0000ooooooooool0TOooool2o`000;Kooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooooooo
ool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
B_ooool001Cooooo00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o0000
ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03
o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`004_oo
ool00omEEEGoIVIVo`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo002Qooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05_ooool4o`000003
oa0@4?oooooooooo00Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP2<ooooo`00X_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l0000<
ooooo`03o`000?oooooooooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg08cooooo002Rooooo`05o`00
0?ooooooooooooooool000006oooool00ol0003oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00Co
oooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100S?ooool0
0:;ooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00003?ooool00ol0003oooooooooo`04
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool00000S?ooool00:;ooooo00Go0000ohN7QoooooooZJVYo`00000Kooooo`03o`00
0?oooooooooo00Gooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`00002<ooooo`00XOooool00ol@413o0000ogMgM`02o`000003
oiRHV?oooooooooo01Wooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo08[ooooo0032oooo
o`03o`000?oooooooooo00;ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg08cooooo0030ooooo`03oeEEEOmV
IVKo000000Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^08cooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1206) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.61042 .43049 Mdot
.63051 .38133 Mdot
.37945 .48959 Mdot
.61375 .61316 Mdot
.31365 .2723 Mdot
.34614 .49563 Mdot
.43419 .36947 Mdot
.48175 .34359 Mdot
.36989 .50687 Mdot
.53646 .23428 Mdot
.44098 .35218 Mdot
.57289 .65948 Mdot
.46148 .34781 Mdot
.59681 .59667 Mdot
.33508 .19961 Mdot
.63057 .53606 Mdot
.64273 .40716 Mdot
.40666 .68189 Mdot
.5563 .60195 Mdot
.36921 .52793 Mdot
.65824 .35722 Mdot
.60633 .59766 Mdot
.60102 .3643 Mdot
.59618 .5962 Mdot
.64577 .61196 Mdot
.59531 .40089 Mdot
.57148 .36966 Mdot
.64518 .58071 Mdot
.66155 .59123 Mdot
.4766 .33829 Mdot
.48471 .71304 Mdot
.30357 .24274 Mdot
.56879 .63057 Mdot
.19439 .53152 Mdot
.48345 .36645 Mdot
.74172 .54472 Mdot
.3592 .48805 Mdot
.46343 .37011 Mdot
.46283 .37596 Mdot
.4592 .39572 Mdot
.45104 .36357 Mdot
.59621 .38531 Mdot
.43801 .30499 Mdot
.39936 .55402 Mdot
.60969 .52865 Mdot
.3984 .25439 Mdot
.79755 .58497 Mdot
.60367 .54653 Mdot
.6328 .41615 Mdot
.24828 .54905 Mdot
.30495 .3509 Mdot
.44812 .3902 Mdot
.33088 .53255 Mdot
.37221 .86427 Mdot
.47496 .36732 Mdot
.56781 .53198 Mdot
.36865 .48507 Mdot
.60542 .58581 Mdot
.59337 .59221 Mdot
.68541 .44159 Mdot
.59533 .5372 Mdot
.38467 .63729 Mdot
.64229 .43217 Mdot
.54153 .46942 Mdot
.36726 .50103 Mdot
.4491 .37346 Mdot
.61743 .37397 Mdot
.46998 .34991 Mdot
.67527 .56217 Mdot
.37246 .52881 Mdot
.60839 .54613 Mdot
.44303 .36347 Mdot
.64049 .42075 Mdot
.63182 .56479 Mdot
.30447 .65978 Mdot
.58712 .18766 Mdot
.36536 .63345 Mdot
.71877 .50301 Mdot
.67175 .47273 Mdot
.3 .58484 Mdot
.6055 .62563 Mdot
.57736 .72286 Mdot
.52297 .18121 Mdot
.60045 .35913 Mdot
.67763 .62576 Mdot
.44806 .65467 Mdot
.62798 .56606 Mdot
.43308 .21743 Mdot
.66083 .57506 Mdot
.30968 .69219 Mdot
.35574 .51513 Mdot
.62519 .39661 Mdot
.61314 .61477 Mdot
.64775 .5685 Mdot
.69832 .68199 Mdot
.57929 .63267 Mdot
.62906 .59325 Mdot
.6091 .42178 Mdot
.45619 .3906 Mdot
.54433 .58853 Mdot
.40832 .53478 Mdot
.31077 .49999 Mdot
.57104 .59316 Mdot
.31998 .48736 Mdot
.65664 .40185 Mdot
.63627 .56293 Mdot
.46554 .37963 Mdot
.57427 .58619 Mdot
.5996 .31358 Mdot
.63336 .37909 Mdot
.64884 .57823 Mdot
.37983 .66885 Mdot
.60574 .80034 Mdot
.63467 .39854 Mdot
.3456 .58238 Mdot
.62895 .62848 Mdot
.62277 .58575 Mdot
.62764 .38278 Mdot
.32914 .46339 Mdot
.45423 .20677 Mdot
.58181 .37364 Mdot
.47945 .38858 Mdot
.59549 .42857 Mdot
.68632 .60446 Mdot
.35095 .51067 Mdot
.25435 .43027 Mdot
.52161 .32943 Mdot
.49293 .6868 Mdot
.62183 .56644 Mdot
.52902 .26511 Mdot
.34034 .52269 Mdot
.61459 .39035 Mdot
.46961 .34575 Mdot
.60519 .66462 Mdot
.63491 .36593 Mdot
.44893 .33578 Mdot
.37392 .65386 Mdot
.33899 .38685 Mdot
.65379 .3783 Mdot
.42756 .53236 Mdot
.44979 .32449 Mdot
.44725 .3925 Mdot
.2118 .62463 Mdot
.61545 .37687 Mdot
.39114 .65848 Mdot
.47599 .34452 Mdot
.46849 .6912 Mdot
.59914 .52895 Mdot
.54789 .74223 Mdot
.80315 .60923 Mdot
.19624 .54876 Mdot
.36304 .39777 Mdot
.41185 .63877 Mdot
.49339 .37287 Mdot
.64148 .6049 Mdot
.60202 .4112 Mdot
.59135 .38622 Mdot
.58794 .54215 Mdot
.62649 .61699 Mdot
.61935 .54918 Mdot
.64821 .56609 Mdot
.70023 .34786 Mdot
.59055 .6328 Mdot
.76395 .64495 Mdot
.62699 .4009 Mdot
.62725 .60852 Mdot
.34594 .46666 Mdot
.62925 .65215 Mdot
.44765 .36532 Mdot
.61032 .59158 Mdot
.61667 .61279 Mdot
.58835 .53813 Mdot
.45309 .3915 Mdot
.36641 .19862 Mdot
.70069 .70182 Mdot
.30702 .25592 Mdot
.33818 .70236 Mdot
.32898 .48833 Mdot
.62827 .57276 Mdot
.38063 .65901 Mdot
.7632 .51117 Mdot
.59146 .61452 Mdot
.77959 .72191 Mdot
.62195 .59615 Mdot
.32182 .25439 Mdot
.59241 .50968 Mdot
.22712 .32537 Mdot
.55186 .7256 Mdot
.64715 .59709 Mdot
.52993 .50653 Mdot
.53539 .39291 Mdot
.39416 .54406 Mdot
.45268 .36059 Mdot
.34987 .46638 Mdot
.37437 .48382 Mdot
.43818 .31318 Mdot
.63439 .45779 Mdot
.60598 .48874 Mdot
.66803 .62401 Mdot
.36603 .53289 Mdot
.6562 .41553 Mdot
.38569 .62545 Mdot
.5907 .41446 Mdot
.5665 .13907 Mdot
.34386 .30593 Mdot
.47355 .31833 Mdot
.42399 .63148 Mdot
.36727 .51807 Mdot
.31093 .49364 Mdot
.39691 .67393 Mdot
.59488 .5633 Mdot
.61012 .37447 Mdot
.17711 .5381 Mdot
.67089 .30139 Mdot
.19663 .61737 Mdot
.61528 .42209 Mdot
.58012 .25733 Mdot
.45178 .33772 Mdot
.34844 .47868 Mdot
.62522 .58778 Mdot
.59985 .56653 Mdot
.65358 .35608 Mdot
.61792 .54968 Mdot
.53891 .64104 Mdot
.63573 .58764 Mdot
.28751 .3867 Mdot
.36116 .65047 Mdot
.43967 .31244 Mdot
.49717 .66887 Mdot
.58669 .37652 Mdot
.48885 .7873 Mdot
.31644 .48879 Mdot
.75334 .50628 Mdot
.44046 .36695 Mdot
.37652 .64419 Mdot
.31864 .50438 Mdot
.37781 .62879 Mdot
.56443 .61835 Mdot
.37914 .47408 Mdot
.39462 .67854 Mdot
.64692 .47811 Mdot
.63942 .54973 Mdot
.69469 .31933 Mdot
.47832 .38508 Mdot
.57721 .37764 Mdot
.60384 .53795 Mdot
.32753 .48195 Mdot
.60108 .65679 Mdot
.38682 .34284 Mdot
.26178 .42682 Mdot
.30677 .4758 Mdot
.26846 .4718 Mdot
.38773 .63045 Mdot
.38405 .31155 Mdot
.5639 .26628 Mdot
.63725 .41668 Mdot
.58894 .63489 Mdot
.21115 .33343 Mdot
.4761 .34505 Mdot
.57741 .58181 Mdot
.21084 .48281 Mdot
.47764 .35719 Mdot
.60537 .58359 Mdot
.48897 .3486 Mdot
.59151 .38416 Mdot
.62322 .77637 Mdot
.63948 .41049 Mdot
.66692 .58962 Mdot
.46818 .38103 Mdot
.35361 .46082 Mdot
.60298 .40747 Mdot
.59052 .56124 Mdot
.64053 .57764 Mdot
.50954 .46548 Mdot
.63053 .60385 Mdot
.35905 .21232 Mdot
.64231 .59083 Mdot
.36255 .4732 Mdot
.56685 .59853 Mdot
.51735 .85381 Mdot
.4436 .28541 Mdot
.6157 .37405 Mdot
.33303 .45869 Mdot
.37428 .49892 Mdot
.36476 .59286 Mdot
.49792 .32709 Mdot
.60909 .6301 Mdot
.32724 .48731 Mdot
.54223 .77564 Mdot
.44171 .3348 Mdot
.59151 .63795 Mdot
.43486 .5309 Mdot
.25148 .56803 Mdot
.33423 .53303 Mdot
.55857 .62504 Mdot
.65691 .38411 Mdot
.61482 .61595 Mdot
.31203 .47787 Mdot
.64702 .33856 Mdot
.65304 .62011 Mdot
.66332 .42099 Mdot
.51063 .46332 Mdot
.43333 .35139 Mdot
.59288 .50669 Mdot
.57933 .56999 Mdot
.3403 .4729 Mdot
.58448 .38352 Mdot
.44647 .32957 Mdot
.59744 .39454 Mdot
.20778 .39252 Mdot
.5934 .32044 Mdot
.66592 .44579 Mdot
.43114 .64669 Mdot
.23224 .54841 Mdot
.20887 .35571 Mdot
.42711 .80026 Mdot
.46895 .76976 Mdot
.17882 .46647 Mdot
.32862 .46655 Mdot
.21859 .49765 Mdot
.37494 .49109 Mdot
.63855 .62046 Mdot
.35501 .50807 Mdot
.20496 .35561 Mdot
.63492 .58912 Mdot
.35599 .50233 Mdot
.52263 .79484 Mdot
.62388 .61275 Mdot
.64258 .39314 Mdot
.44013 .17588 Mdot
.46572 .82827 Mdot
.26381 .41774 Mdot
.38758 .50393 Mdot
.43253 .75079 Mdot
.63138 .59482 Mdot
.56567 .60443 Mdot
.62421 .41471 Mdot
.59915 .64173 Mdot
.40095 .62674 Mdot
.42481 .63403 Mdot
.5198 .40306 Mdot
.61805 .72135 Mdot
.58232 .51697 Mdot
.60857 .41114 Mdot
.71462 .35198 Mdot
.29067 .65601 Mdot
.24275 .53881 Mdot
.48636 .33739 Mdot
.43266 .18118 Mdot
.56985 .66672 Mdot
.40326 .3824 Mdot
.36792 .55904 Mdot
.63524 .39126 Mdot
.34659 .21263 Mdot
.45669 .36117 Mdot
.80064 .42642 Mdot
.47838 .60537 Mdot
.59393 .56721 Mdot
.43782 .36874 Mdot
.53443 .57267 Mdot
.44336 .82616 Mdot
.81496 .41654 Mdot
.58111 .69513 Mdot
.66888 .59077 Mdot
.31666 .66736 Mdot
.61575 .5894 Mdot
.47542 .21112 Mdot
.64386 .58817 Mdot
.60239 .39979 Mdot
.50935 .22564 Mdot
.52788 .42547 Mdot
.71872 .69003 Mdot
.40269 .28156 Mdot
.41155 .63789 Mdot
.63035 .58513 Mdot
.59228 .56869 Mdot
.40097 .62933 Mdot
.64256 .36096 Mdot
.64744 .56396 Mdot
.47183 .7829 Mdot
.62325 .55888 Mdot
.45533 .36804 Mdot
.55114 .67544 Mdot
.59805 .44851 Mdot
.66385 .62233 Mdot
.64368 .42433 Mdot
.43115 .35393 Mdot
.47242 .37396 Mdot
.5825 .52081 Mdot
.4532 .39708 Mdot
.61728 .60136 Mdot
.82032 .41207 Mdot
.65165 .38084 Mdot
.52098 .57019 Mdot
.61138 .36216 Mdot
.71289 .50608 Mdot
.47895 .37391 Mdot
.30363 .36471 Mdot
.58316 .66143 Mdot
.45725 .35759 Mdot
.59569 .32243 Mdot
.6147 .52417 Mdot
.66635 .57213 Mdot
.28368 .6912 Mdot
.38611 .49767 Mdot
.52825 .45031 Mdot
.48329 .34378 Mdot
.58471 .562 Mdot
.64171 .63671 Mdot
.43015 .35807 Mdot
.76244 .35457 Mdot
.50362 .81369 Mdot
.63913 .58945 Mdot
.61166 .40264 Mdot
.61128 .38982 Mdot
.67069 .58703 Mdot
.57552 .61357 Mdot
.33493 .51065 Mdot
.35974 .45944 Mdot
.39227 .49189 Mdot
.51294 .46035 Mdot
.29471 .37391 Mdot
.31332 .29776 Mdot
.45782 .3958 Mdot
.56188 .28704 Mdot
.32291 .70236 Mdot
.6556 .64037 Mdot
.3623 .52724 Mdot
.58037 .58436 Mdot
.611 .6084 Mdot
.43308 .33862 Mdot
.23271 .43877 Mdot
.53852 .61191 Mdot
.64914 .36308 Mdot
.46216 .3274 Mdot
.6815 .64537 Mdot
.44379 .27165 Mdot
.37847 .66129 Mdot
.22628 .62645 Mdot
.44293 .36757 Mdot
.64035 .39073 Mdot
.48619 .36866 Mdot
.60491 .56199 Mdot
.5552 .57365 Mdot
.62771 .38748 Mdot
.42142 .64921 Mdot
.60394 .65526 Mdot
.60826 .58272 Mdot
.78562 .66552 Mdot
.3386 .71717 Mdot
.29533 .3882 Mdot
.64539 .59557 Mdot
.66144 .62115 Mdot
.37164 .67005 Mdot
.61679 .55766 Mdot
.62068 .54644 Mdot
.64759 .76716 Mdot
.53268 .32621 Mdot
.42697 .64908 Mdot
.79234 .38342 Mdot
.62023 .423 Mdot
.2513 .29084 Mdot
.34297 .47697 Mdot
.50376 .35447 Mdot
.5335 .81645 Mdot
.32794 .53216 Mdot
.3687 .40245 Mdot
.27584 .26897 Mdot
.52784 .44811 Mdot
.28462 .47568 Mdot
.57739 .66533 Mdot
.64103 .56108 Mdot
.61789 .58434 Mdot
.38185 .65298 Mdot
.60579 .37627 Mdot
.52227 .46441 Mdot
.69236 .26146 Mdot
.61093 .59684 Mdot
.52033 .61193 Mdot
.6536 .26673 Mdot
.2549 .57215 Mdot
.40743 .65105 Mdot
.4243 .64176 Mdot
.62688 .58369 Mdot
.62197 .79161 Mdot
.5965 .40308 Mdot
.58947 .56235 Mdot
.60863 .63313 Mdot
.38772 .49549 Mdot
.63878 .37697 Mdot
.32177 .46971 Mdot
.32737 .3402 Mdot
.30914 .25908 Mdot
.8036 .6511 Mdot
.4768 .37341 Mdot
.54473 .2042 Mdot
.46646 .33231 Mdot
.57261 .71748 Mdot
.31392 .50778 Mdot
.59722 .62116 Mdot
.58587 .37991 Mdot
.58244 .56895 Mdot
.57987 .61836 Mdot
.5932 .56491 Mdot
.65193 .63764 Mdot
.69894 .7882 Mdot
.40906 .668 Mdot
.67482 .57368 Mdot
.37127 .47719 Mdot
.47121 .19972 Mdot
.57913 .19062 Mdot
.59112 .57463 Mdot
.63683 .57994 Mdot
.6471 .37066 Mdot
.58194 .55203 Mdot
.45335 .33107 Mdot
.58107 .39209 Mdot
.64858 .5708 Mdot
.44644 .18655 Mdot
.65713 .58496 Mdot
.25689 .2965 Mdot
.48776 .36097 Mdot
.63489 .3049 Mdot
.66307 .55501 Mdot
.2659 .4262 Mdot
.52821 .45042 Mdot
.32582 .51008 Mdot
.4587 .40042 Mdot
.36062 .49047 Mdot
.73391 .28235 Mdot
.56058 .56662 Mdot
.64256 .6073 Mdot
.63116 .64021 Mdot
.32933 .48617 Mdot
.40686 .22687 Mdot
.38064 .30328 Mdot
.68262 .63727 Mdot
.33168 .49455 Mdot
.64592 .42654 Mdot
.44114 .69754 Mdot
.60229 .36751 Mdot
.42296 .62465 Mdot
.44342 .34984 Mdot
.42029 .63722 Mdot
.20278 .47804 Mdot
.63311 .38107 Mdot
.58548 .35647 Mdot
.34264 .48301 Mdot
.45581 .56826 Mdot
.23646 .73367 Mdot
.47222 .59517 Mdot
.51876 .71479 Mdot
.62198 .41293 Mdot
.66482 .60064 Mdot
.55308 .69738 Mdot
.46555 .54755 Mdot
.36251 .49216 Mdot
.59576 .61131 Mdot
.60574 .78706 Mdot
.33446 .51064 Mdot
.58934 .63661 Mdot
.38162 .48515 Mdot
.44708 .3568 Mdot
.36298 .52437 Mdot
.63207 .34975 Mdot
.63747 .56944 Mdot
.19834 .67926 Mdot
.36605 .62379 Mdot
.63694 .59644 Mdot
.46696 .32844 Mdot
.49367 .40627 Mdot
.57943 .60785 Mdot
.37112 .65391 Mdot
.34495 .50472 Mdot
.46782 .59961 Mdot
.64112 .58876 Mdot
.3311 .4869 Mdot
.60611 .43065 Mdot
.48039 .39261 Mdot
.67969 .52989 Mdot
.27094 .42203 Mdot
.62391 .41585 Mdot
.42113 .52239 Mdot
.4312 .39258 Mdot
.66085 .62296 Mdot
.59809 .63587 Mdot
.61054 .3983 Mdot
.63319 .74874 Mdot
.56937 .57299 Mdot
.60491 .62532 Mdot
.36587 .47217 Mdot
.35738 .49441 Mdot
.62161 .76431 Mdot
.33919 .46117 Mdot
.55606 .57329 Mdot
.60832 .3976 Mdot
.60885 .61574 Mdot
.64703 .37656 Mdot
.57799 .56111 Mdot
.60657 .3345 Mdot
.63793 .35846 Mdot
.43282 .29072 Mdot
.60171 .6116 Mdot
.57661 .50906 Mdot
.57554 .58924 Mdot
.62574 .55528 Mdot
.33871 .51323 Mdot
.39927 .66566 Mdot
.54998 .60209 Mdot
.38521 .61141 Mdot
.37797 .62977 Mdot
.52997 .38025 Mdot
.38731 .49883 Mdot
.39082 .64897 Mdot
.66508 .26872 Mdot
.39091 .4911 Mdot
.38576 .63958 Mdot
.57261 .19087 Mdot
.48249 .36884 Mdot
.65516 .385 Mdot
.62473 .61367 Mdot
.19302 .4499 Mdot
.79818 .58866 Mdot
.4024 .5232 Mdot
.64139 .59253 Mdot
.57824 .5919 Mdot
.58737 .36721 Mdot
.77786 .30687 Mdot
.37809 .52515 Mdot
.6579 .60478 Mdot
.62304 .37297 Mdot
.82629 .3698 Mdot
.36312 .47619 Mdot
.38358 .64363 Mdot
.46571 .392 Mdot
.66682 .4095 Mdot
.52244 .33191 Mdot
.43327 .36304 Mdot
.36776 .54184 Mdot
.30208 .35652 Mdot
.62822 .62879 Mdot
.35454 .52888 Mdot
.23645 .65781 Mdot
.67976 .32344 Mdot
.529 .36868 Mdot
.42295 .74605 Mdot
.63432 .39326 Mdot
.45806 .33151 Mdot
.41609 .64854 Mdot
.61011 .42028 Mdot
.64461 .3959 Mdot
.42811 .34936 Mdot
.71941 .60213 Mdot
.4351 .53529 Mdot
.45999 .37301 Mdot
.29057 .68611 Mdot
.24619 .37692 Mdot
.36199 .52786 Mdot
.39968 .62727 Mdot
.20411 .46095 Mdot
.59563 .38666 Mdot
.42612 .1811 Mdot
.2405 .65293 Mdot
.62895 .59339 Mdot
.3942 .65202 Mdot
.37654 .25023 Mdot
.70163 .2516 Mdot
.47732 .36055 Mdot
.51884 .42922 Mdot
.40707 .62509 Mdot
.59921 .5379 Mdot
.45074 .69865 Mdot
.60995 .62337 Mdot
.44673 .34263 Mdot
.67712 .44749 Mdot
.64179 .38953 Mdot
.42565 .35048 Mdot
.22475 .62606 Mdot
.61482 .60131 Mdot
.59933 .61283 Mdot
.49161 .65276 Mdot
.58757 .39896 Mdot
.3252 .50957 Mdot
.61902 .63037 Mdot
.60923 .58641 Mdot
.55467 .55743 Mdot
.59175 .50462 Mdot
.6027 .79833 Mdot
.65039 .61442 Mdot
.38061 .28778 Mdot
.67187 .61208 Mdot
.59908 .60615 Mdot
.64671 .42212 Mdot
.79705 .67466 Mdot
.33558 .32883 Mdot
.61062 .58982 Mdot
.66301 .60365 Mdot
.4234 .36346 Mdot
.44543 .53119 Mdot
.45184 .56651 Mdot
.46216 .59566 Mdot
.45247 .76182 Mdot
.6746 .61884 Mdot
.61385 .36913 Mdot
.38972 .67882 Mdot
.65179 .62378 Mdot
.61767 .36925 Mdot
.5895 .53429 Mdot
.33286 .50936 Mdot
.38928 .48573 Mdot
.61654 .32002 Mdot
.3927 .64199 Mdot
.50557 .62248 Mdot
.54892 .29048 Mdot
.35596 .46613 Mdot
.64301 .60966 Mdot
.48853 .32553 Mdot
.31123 .48133 Mdot
.27603 .50367 Mdot
.66828 .53051 Mdot
.59293 .40211 Mdot
.62766 .3984 Mdot
.55095 .74499 Mdot
.35557 .38371 Mdot
.73365 .70656 Mdot
.44602 .35564 Mdot
.56266 .5844 Mdot
.54574 .26041 Mdot
.63109 .39885 Mdot
.55546 .70557 Mdot
.39297 .64809 Mdot
.47876 .35756 Mdot
.32759 .43299 Mdot
.64008 .36664 Mdot
.64608 .40215 Mdot
.65551 .56684 Mdot
.60152 .57745 Mdot
.47898 .7726 Mdot
.39046 .70013 Mdot
.43282 .34965 Mdot
.39779 .627 Mdot
.3226 .51674 Mdot
.65338 .61312 Mdot
.60366 .36131 Mdot
.24478 .40665 Mdot
.65814 .61199 Mdot
.33973 .51601 Mdot
.62966 .39282 Mdot
.39228 .6269 Mdot
.3701 .64364 Mdot
.62618 .55662 Mdot
.71424 .36944 Mdot
.46479 .36584 Mdot
.64062 .39466 Mdot
.44149 .27535 Mdot
.56739 .60708 Mdot
.60813 .57424 Mdot
.63517 .51596 Mdot
.43715 .33661 Mdot
.61864 .28319 Mdot
.41073 .62016 Mdot
.60905 .37934 Mdot
.65158 .59749 Mdot
.39093 .63468 Mdot
.59262 .27287 Mdot
.30596 .47747 Mdot
.36496 .52249 Mdot
.3701 .65349 Mdot
.40204 .65015 Mdot
.3715 .64836 Mdot
.42725 .17984 Mdot
.60713 .35392 Mdot
.57202 .66699 Mdot
.56658 .57849 Mdot
.53926 .72536 Mdot
.62879 .66882 Mdot
.44906 .32632 Mdot
.38504 .49939 Mdot
.57606 .60734 Mdot
.66716 .59599 Mdot
.62003 .51363 Mdot
.52265 .58975 Mdot
.57658 .43005 Mdot
.63557 .37853 Mdot
.56917 .55379 Mdot
.3848 .48386 Mdot
.58427 .13899 Mdot
.15863 .45985 Mdot
.6498 .54297 Mdot
.43133 .55739 Mdot
.60372 .36044 Mdot
.433 .38798 Mdot
.45509 .61201 Mdot
.48224 .37496 Mdot
.61177 .38244 Mdot
.65111 .61467 Mdot
.56024 .29282 Mdot
.37034 .66037 Mdot
.59426 .55088 Mdot
.46103 .33611 Mdot
.60306 .54536 Mdot
.43349 .36546 Mdot
.21144 .37402 Mdot
.34158 .73917 Mdot
.62277 .59546 Mdot
.67629 .58263 Mdot
.41726 .75601 Mdot
.58877 .57711 Mdot
.36674 .70132 Mdot
.60587 .35902 Mdot
.68312 .71239 Mdot
.63321 .54295 Mdot
.76061 .42749 Mdot
.56828 .61339 Mdot
.56995 .78965 Mdot
.60583 .57212 Mdot
.25731 .58818 Mdot
.64555 .57483 Mdot
.62751 .5514 Mdot
.47327 .37953 Mdot
.42443 .3581 Mdot
.63812 .42401 Mdot
.32528 .4872 Mdot
.28275 .2722 Mdot
.60853 .57959 Mdot
.25961 .42626 Mdot
.56673 .31184 Mdot
.40388 .64898 Mdot
.60772 .38239 Mdot
.77776 .29679 Mdot
.49099 .36031 Mdot
.35626 .7224 Mdot
.57846 .77796 Mdot
.47957 .29688 Mdot
.45079 .64843 Mdot
.50167 .2206 Mdot
.38462 .6328 Mdot
.58538 .54121 Mdot
.23974 .42733 Mdot
.25798 .6116 Mdot
.66713 .52852 Mdot
.4257 .38711 Mdot
.76123 .49086 Mdot
.2338 .42321 Mdot
.39444 .61723 Mdot
.41847 .63073 Mdot
.43818 .38608 Mdot
.3285 .43596 Mdot
.53303 .58455 Mdot
.3959 .64651 Mdot
.35417 .46339 Mdot
.38625 .51377 Mdot
.31914 .52962 Mdot
.59215 .39515 Mdot
.20045 .58517 Mdot
.45065 .26218 Mdot
.43345 .35834 Mdot
.30841 .45394 Mdot
.57484 .4203 Mdot
.60616 .35127 Mdot
.35014 .48406 Mdot
.34603 .51869 Mdot
.65572 .36935 Mdot
.56989 .53369 Mdot
.60844 .51377 Mdot
.61183 .59381 Mdot
.38512 .66542 Mdot
.60097 .5713 Mdot
.33403 .50076 Mdot
.47471 .35836 Mdot
.35784 .51842 Mdot
.48664 .3408 Mdot
.33088 .28943 Mdot
.59925 .55444 Mdot
.63969 .5715 Mdot
.81265 .56668 Mdot
.62037 .43063 Mdot
.36913 .28788 Mdot
.27891 .41445 Mdot
.37521 .48813 Mdot
.61671 .5443 Mdot
.5797 .38859 Mdot
.40205 .61351 Mdot
.82205 .55044 Mdot
.57223 .60543 Mdot
.60699 .36049 Mdot
.65414 .60142 Mdot
.69281 .3486 Mdot
.57909 .83636 Mdot
.60037 .3923 Mdot
.8023 .60835 Mdot
.66228 .59563 Mdot
.58223 .22483 Mdot
.62314 .64013 Mdot
.54858 .76587 Mdot
.56935 .57384 Mdot
.61743 .42291 Mdot
.6074 .59254 Mdot
.58355 .39948 Mdot
.34939 .46844 Mdot
.44073 .39239 Mdot
.62912 .41011 Mdot
.60895 .6362 Mdot
.09335 .50131 Mdot
.44949 .34382 Mdot
.62735 .5864 Mdot
.46776 .3885 Mdot
.60495 .37253 Mdot
.63449 .41236 Mdot
.67144 .23556 Mdot
.33405 .33685 Mdot
.44804 .3567 Mdot
.65403 .60941 Mdot
.45485 .24451 Mdot
.61086 .62008 Mdot
.50265 .76232 Mdot
.56747 .53052 Mdot
.56665 .5917 Mdot
.59456 .19104 Mdot
.43581 .34091 Mdot
.7196 .72227 Mdot
.6587 .2253 Mdot
.47947 .19374 Mdot
.6729 .38484 Mdot
.39658 .61604 Mdot
.35574 .20636 Mdot
.3006 .36875 Mdot
.33068 .49067 Mdot
.5752 .59901 Mdot
.60046 .44571 Mdot
.46783 .37075 Mdot
.39825 .66818 Mdot
.62315 .59468 Mdot
.35022 .52036 Mdot
.45924 .80744 Mdot
.49518 .36597 Mdot
.59743 .38402 Mdot
.63909 .35695 Mdot
.8536 .46792 Mdot
.64802 .59597 Mdot
.64109 .56893 Mdot
.44414 .34665 Mdot
.63623 .26778 Mdot
.38153 .63319 Mdot
.50335 .79836 Mdot
.4485 .35519 Mdot
.48652 .49193 Mdot
.62188 .37654 Mdot
.57858 .58909 Mdot
.3838 .2286 Mdot
.3137 .6554 Mdot
.80752 .46655 Mdot
.3813 .65966 Mdot
.49654 .7583 Mdot
.62001 .42348 Mdot
.47177 .34435 Mdot
.33472 .40328 Mdot
.6614 .64246 Mdot
.58166 .58883 Mdot
.50012 .75499 Mdot
.53495 .41587 Mdot
.57363 .69163 Mdot
.57123 .60833 Mdot
.54104 .43954 Mdot
.57109 .57942 Mdot
.65841 .6508 Mdot
.55961 .55498 Mdot
.6163 .56917 Mdot
.60573 .36034 Mdot
.69247 .59453 Mdot
.32701 .50338 Mdot
.56018 .66916 Mdot
.49322 .49856 Mdot
.63751 .5932 Mdot
.62322 .62387 Mdot
.79744 .50655 Mdot
.40775 .41618 Mdot
.62955 .40633 Mdot
.62347 .34278 Mdot
.46512 .39584 Mdot
.61346 .51328 Mdot
.32221 .49178 Mdot
.63282 .66615 Mdot
.34207 .51453 Mdot
.5989 .3662 Mdot
.37141 .48242 Mdot
.45656 .39399 Mdot
.37781 .52074 Mdot
.29368 .37457 Mdot
.47918 .34537 Mdot
.60224 .41236 Mdot
.63035 .56357 Mdot
.46757 .32897 Mdot
.48706 .67588 Mdot
.38421 .66384 Mdot
.65331 .21438 Mdot
.65102 .57277 Mdot
.53121 .33063 Mdot
.67627 .39616 Mdot
.35288 .51839 Mdot
.6161 .80881 Mdot
.64175 .35904 Mdot
.42391 .65419 Mdot
.58822 .3732 Mdot
.30936 .70841 Mdot
.39891 .66137 Mdot
.56006 .18468 Mdot
.27782 .44678 Mdot
.39886 .70926 Mdot
.578 .52949 Mdot
.46659 .65462 Mdot
.33557 .53123 Mdot
.46902 .37043 Mdot
.35173 .40507 Mdot
.61975 .54681 Mdot
.38889 .77639 Mdot
.65969 .39836 Mdot
.32537 .49 Mdot
.4684 .3477 Mdot
.45027 .32764 Mdot
.58231 .6266 Mdot
.27367 .54809 Mdot
.5806 .56311 Mdot
.34969 .36706 Mdot
.46218 .7597 Mdot
.52965 .5725 Mdot
.635 .58754 Mdot
.3422 .47156 Mdot
.65413 .60183 Mdot
.42464 .66389 Mdot
.19563 .59204 Mdot
.60692 .64928 Mdot
.2835 .40642 Mdot
.37535 .60885 Mdot
.62996 .38508 Mdot
.54182 .55963 Mdot
.30609 .37169 Mdot
.64997 .60013 Mdot
.57437 .87425 Mdot
.38786 .63742 Mdot
.24139 .44085 Mdot
.6465 .6374 Mdot
.59854 .63116 Mdot
.54057 .4826 Mdot
.53846 .38323 Mdot
.31755 .65944 Mdot
.58856 .58656 Mdot
.46247 .72763 Mdot
.43957 .38103 Mdot
.57682 .57126 Mdot
.62049 .58432 Mdot
.73069 .58814 Mdot
.45835 .32857 Mdot
.37749 .49937 Mdot
.32738 .52938 Mdot
.39548 .47727 Mdot
.42151 .66625 Mdot
.50701 .44353 Mdot
.54338 .70978 Mdot
.44988 .8193 Mdot
.40054 .68032 Mdot
.65437 .57242 Mdot
.34886 .66791 Mdot
.64225 .62173 Mdot
.41221 .65244 Mdot
.46341 .32998 Mdot
.6324 .40624 Mdot
.56063 .25434 Mdot
.36573 .53159 Mdot
.59508 .63898 Mdot
.3928 .62375 Mdot
.59936 .40913 Mdot
.4173 .69475 Mdot
.62229 .38144 Mdot
.4542 .35339 Mdot
.49561 .37827 Mdot
.4051 .66381 Mdot
.60846 .36575 Mdot
.4075 .37366 Mdot
.70598 .25932 Mdot
.55513 .56605 Mdot
.50013 .38358 Mdot
.606 .42756 Mdot
.64428 .34902 Mdot
.60063 .4198 Mdot
.61372 .54868 Mdot
.43124 .55583 Mdot
.6057 .52594 Mdot
.43338 .34964 Mdot
.38213 .48945 Mdot
.41961 .7704 Mdot
.29103 .33765 Mdot
.38309 .58173 Mdot
.56328 .57716 Mdot
.61178 .60185 Mdot
.62662 .58386 Mdot
.64694 .55114 Mdot
.33472 .37486 Mdot
.58138 .57256 Mdot
.47049 .382 Mdot
.34173 .50594 Mdot
.58655 .5396 Mdot
.31504 .51557 Mdot
.45618 .21607 Mdot
.40269 .67806 Mdot
.50681 .43255 Mdot
.14875 .38854 Mdot
.60973 .41493 Mdot
.32466 .46462 Mdot
.33242 .48815 Mdot
.37391 .65267 Mdot
.46179 .36901 Mdot
.61886 .37833 Mdot
.52427 .77591 Mdot
.37437 .63651 Mdot
.60816 .59021 Mdot
.42944 .57985 Mdot
.36668 .75723 Mdot
.58137 .54799 Mdot
.58646 .61644 Mdot
.30448 .4826 Mdot
.25707 .49699 Mdot
.21529 .67578 Mdot
.52841 .68041 Mdot
.40233 .66459 Mdot
.41541 .66128 Mdot
.65734 .37742 Mdot
.61846 .52758 Mdot
.43289 .35149 Mdot
.58174 .69015 Mdot
.45623 .42416 Mdot
.51127 .63689 Mdot
.59331 .4648 Mdot
.57236 .5984 Mdot
.75356 .33616 Mdot
.61567 .60307 Mdot
.59952 .35825 Mdot
.59291 .378 Mdot
.61366 .40953 Mdot
.46854 .36849 Mdot
.73118 .51314 Mdot
.4643 .38319 Mdot
.14426 .40262 Mdot
.62785 .42255 Mdot
.29542 .42115 Mdot
.34781 .47387 Mdot
.66081 .55148 Mdot
.39268 .6279 Mdot
.43821 .40602 Mdot
.67654 .56395 Mdot
.62464 .79334 Mdot
.32608 .49504 Mdot
.60717 .41558 Mdot
.51521 .21969 Mdot
.17741 .39118 Mdot
.45414 .58007 Mdot
.67594 .65651 Mdot
.47044 .63435 Mdot
.40604 .64569 Mdot
.80945 .47188 Mdot
.40141 .62511 Mdot
.46678 .33635 Mdot
.63662 .57302 Mdot
.62688 .56624 Mdot
.57138 .57445 Mdot
.59121 .56276 Mdot
.4363 .39336 Mdot
.57402 .62965 Mdot
.51726 .8538 Mdot
.38446 .47674 Mdot
.64941 .47215 Mdot
.38811 .63346 Mdot
.43661 .39883 Mdot
.34005 .50539 Mdot
.40252 .41613 Mdot
.503 .67367 Mdot
.63959 .58856 Mdot
.57523 .60376 Mdot
.35458 .72444 Mdot
.5709 .60885 Mdot
.62837 .66998 Mdot
.33078 .48808 Mdot
.38775 .58423 Mdot
.41929 .65795 Mdot
.41885 .64961 Mdot
.4838 .35276 Mdot
.59882 .36706 Mdot
.38593 .64918 Mdot
.35565 .47041 Mdot
.56247 .57834 Mdot
.62292 .63262 Mdot
.60793 .4275 Mdot
.24596 .66304 Mdot
.39963 .61894 Mdot
.48821 .22037 Mdot
.58572 .38404 Mdot
.56833 .38535 Mdot
.58176 .59051 Mdot
.57925 .48885 Mdot
.66448 .4149 Mdot
.40186 .68113 Mdot
.44013 .39984 Mdot
.461 .61504 Mdot
.44699 .33775 Mdot
.5974 .37801 Mdot
.65141 .62253 Mdot
.58968 .385 Mdot
.64542 .59398 Mdot
.21247 .30256 Mdot
.61784 .56571 Mdot
.44977 .82328 Mdot
.53792 .74801 Mdot
.34414 .49378 Mdot
.45866 .41569 Mdot
.34233 .47882 Mdot
.58469 .38737 Mdot
.63972 .62929 Mdot
.41728 .62591 Mdot
.51442 .18835 Mdot
.57367 .42075 Mdot
.3365 .51697 Mdot
.39726 .50045 Mdot
.46925 .334 Mdot
.57349 .55678 Mdot
.58158 .58416 Mdot
.35645 .50049 Mdot
.52863 .58108 Mdot
.63177 .3628 Mdot
.63911 .57937 Mdot
.60438 .60344 Mdot
.34459 .4912 Mdot
.71722 .26707 Mdot
.56295 .35707 Mdot
.62918 .57221 Mdot
.25563 .45414 Mdot
.44597 .32734 Mdot
.58493 .52596 Mdot
.68001 .59365 Mdot
.40007 .64936 Mdot
.67554 .51325 Mdot
.19316 .56058 Mdot
.47863 .33543 Mdot
.3351 .4762 Mdot
.6496 .59568 Mdot
.34062 .47237 Mdot
.61123 .63414 Mdot
.57053 .43881 Mdot
.33197 .52021 Mdot
.59899 .62666 Mdot
.57788 .5187 Mdot
.58664 .39757 Mdot
.57363 .60182 Mdot
.78882 .54906 Mdot
.31263 .48943 Mdot
.59409 .62962 Mdot
.71251 .37375 Mdot
.45409 .37361 Mdot
.58787 .51847 Mdot
.38801 .67613 Mdot
.52562 .77756 Mdot
.51888 .29429 Mdot
.22933 .44537 Mdot
.40417 .67537 Mdot
.59822 .54587 Mdot
.39801 .48944 Mdot
.43491 .37722 Mdot
.47758 .82745 Mdot
.59119 .54113 Mdot
.44792 .34195 Mdot
.47424 .35608 Mdot
.37946 .66244 Mdot
.81766 .61413 Mdot
.65268 .63612 Mdot
.59239 .57438 Mdot
.75397 .58873 Mdot
.60071 .43038 Mdot
.60758 .56616 Mdot
.6636 .58798 Mdot
.46837 .38423 Mdot
.63718 .67073 Mdot
.77785 .4869 Mdot
.53368 .79467 Mdot
.44519 .32515 Mdot
.47792 .56401 Mdot
.35497 .5321 Mdot
.39538 .63341 Mdot
.62351 .38822 Mdot
.39728 .62208 Mdot
.37703 .51884 Mdot
.65704 .5771 Mdot
.48371 .38036 Mdot
.78068 .59458 Mdot
.4377 .38606 Mdot
.22259 .45547 Mdot
.59996 .42852 Mdot
.52106 .25673 Mdot
.62711 .84736 Mdot
.42998 .25886 Mdot
.40432 .39934 Mdot
.40359 .6494 Mdot
.41332 .47564 Mdot
.6068 .60363 Mdot
.81382 .49681 Mdot
.63081 .55975 Mdot
.71161 .38584 Mdot
.36291 .46576 Mdot
.39234 .49165 Mdot
.63341 .57292 Mdot
.47214 .76106 Mdot
.43403 .37775 Mdot
.43999 .33615 Mdot
.58745 .62677 Mdot
.45677 .35771 Mdot
.59853 .57977 Mdot
.33659 .50871 Mdot
.71349 .74023 Mdot
.61721 .593 Mdot
.67253 .58177 Mdot
.52243 .34496 Mdot
.61766 .20504 Mdot
.22081 .5285 Mdot
.80183 .37202 Mdot
.16804 .41733 Mdot
.45776 .357 Mdot
.59669 .52285 Mdot
.47855 .56592 Mdot
.32039 .52456 Mdot
.40699 .38709 Mdot
.61702 .55965 Mdot
.61735 .55702 Mdot
.63107 .55301 Mdot
.60028 .61452 Mdot
.81108 .46132 Mdot
.66216 .68293 Mdot
.69735 .45358 Mdot
.57785 .61554 Mdot
.47071 .66108 Mdot
.48569 .35156 Mdot
.66222 .36672 Mdot
.37452 .68558 Mdot
.57245 .59779 Mdot
.60613 .68203 Mdot
.42505 .34866 Mdot
.14314 .40444 Mdot
.47801 .34046 Mdot
.37385 .49871 Mdot
.43304 .38618 Mdot
.63227 .6033 Mdot
.61141 .39042 Mdot
.48212 .53274 Mdot
.38033 .31637 Mdot
.33038 .49158 Mdot
.6372 .59618 Mdot
.29271 .41703 Mdot
.32743 .50059 Mdot
.45132 .21656 Mdot
.61815 .39196 Mdot
.46662 .72274 Mdot
.59093 .38031 Mdot
.60113 .62797 Mdot
.60643 .6277 Mdot
.48602 .3994 Mdot
.44312 .39212 Mdot
.59187 .37796 Mdot
.82038 .62238 Mdot
.37925 .6266 Mdot
.60816 .4075 Mdot
.62948 .66097 Mdot
.44826 .47682 Mdot
.61331 .39613 Mdot
.41671 .59494 Mdot
.47638 .36728 Mdot
.64795 .40918 Mdot
.65084 .65009 Mdot
.25292 .64897 Mdot
.38425 .67889 Mdot
.31188 .45961 Mdot
.42903 .58975 Mdot
.31214 .4826 Mdot
.45267 .40065 Mdot
.34124 .48128 Mdot
.44144 .38246 Mdot
.54052 .31128 Mdot
.53849 .65312 Mdot
.49497 .33477 Mdot
.44831 .39943 Mdot
.34302 .48358 Mdot
.64281 .57765 Mdot
.44469 .60669 Mdot
.59185 .52323 Mdot
.65312 .63905 Mdot
.44088 .37552 Mdot
.61185 .42037 Mdot
.64463 .3527 Mdot
.45741 .68918 Mdot
.63014 .3568 Mdot
.34302 .51607 Mdot
.54632 .84099 Mdot
.25622 .41997 Mdot
.43951 .35804 Mdot
.42885 .38288 Mdot
.61331 .62203 Mdot
.36124 .49082 Mdot
.33898 .469 Mdot
.46261 .33337 Mdot
.51672 .56851 Mdot
.65588 .55379 Mdot
.62194 .34522 Mdot
.63781 .41854 Mdot
.60383 .39566 Mdot
.59661 .41685 Mdot
.77861 .44045 Mdot
.48037 .36272 Mdot
.60349 .41657 Mdot
.59361 .62554 Mdot
.61603 .5579 Mdot
.46533 .5801 Mdot
.41615 .65722 Mdot
.59403 .53385 Mdot
.56137 .55318 Mdot
.57949 .59381 Mdot
.36046 .52423 Mdot
.66129 .52972 Mdot
.32995 .51896 Mdot
.3894 .47583 Mdot
.37062 .4657 Mdot
.29809 .37125 Mdot
.4007 .72135 Mdot
.18019 .43819 Mdot
.65827 .60375 Mdot
.65694 .28076 Mdot
.35925 .48028 Mdot
.61847 .80182 Mdot
.62022 .28165 Mdot
.60367 .54004 Mdot
.29979 .64929 Mdot
.3547 .49846 Mdot
.63446 .35617 Mdot
.61719 .56151 Mdot
.37487 .46228 Mdot
.38429 .67602 Mdot
.55837 .60215 Mdot
.31555 .50898 Mdot
.60888 .36711 Mdot
.38415 .68854 Mdot
.63906 .41983 Mdot
.36889 .46559 Mdot
.58239 .51834 Mdot
.28499 .79217 Mdot
.39821 .50531 Mdot
.64984 .24795 Mdot
.63267 .32858 Mdot
.64039 .57833 Mdot
.31706 .46991 Mdot
.58358 .4187 Mdot
.46999 .39703 Mdot
.45205 .42974 Mdot
.64977 .38898 Mdot
.39259 .49384 Mdot
.31247 .50044 Mdot
.33025 .48918 Mdot
.63892 .38203 Mdot
.67135 .58623 Mdot
.6446 .37803 Mdot
.43202 .38445 Mdot
.6185 .61582 Mdot
.20957 .35252 Mdot
.66033 .28613 Mdot
.58827 .38096 Mdot
.37697 .50535 Mdot
.37187 .66779 Mdot
.62226 .59933 Mdot
.68409 .28987 Mdot
.64798 .58352 Mdot
.43616 .36869 Mdot
.66261 .75095 Mdot
.79379 .57253 Mdot
.56711 .5791 Mdot
.61216 .62186 Mdot
.43696 .34209 Mdot
.63088 .59346 Mdot
.56975 .56989 Mdot
.30995 .36069 Mdot
.63595 .37454 Mdot
.60688 .59554 Mdot
.37569 .47792 Mdot
.28799 .3647 Mdot
.65248 .55252 Mdot
.35125 .58848 Mdot
.47232 .73664 Mdot
.68578 .72352 Mdot
.63335 .56064 Mdot
.51898 .66206 Mdot
.5934 .61041 Mdot
.59482 .55245 Mdot
.63601 .61992 Mdot
.82179 .46043 Mdot
.33777 .52242 Mdot
.33523 .4938 Mdot
.38999 .68239 Mdot
.46983 .73458 Mdot
.3962 .65109 Mdot
.4775 .36902 Mdot
.30507 .57322 Mdot
.33124 .51941 Mdot
.60348 .36769 Mdot
.58982 .55247 Mdot
.39917 .50337 Mdot
.57911 .58483 Mdot
.63449 .60372 Mdot
.31991 .48725 Mdot
.34511 .53129 Mdot
.2373 .44118 Mdot
.39605 .67904 Mdot
.62039 .4101 Mdot
.58925 .53146 Mdot
.38772 .62545 Mdot
.66761 .60861 Mdot
.54302 .72515 Mdot
.61753 .40835 Mdot
.63938 .37523 Mdot
.64466 .355 Mdot
.65708 .57776 Mdot
.62966 .60052 Mdot
.46152 .38411 Mdot
.59076 .37209 Mdot
.45345 .37143 Mdot
.5064 .47248 Mdot
.35158 .61535 Mdot
.61704 .55955 Mdot
.50211 .22472 Mdot
.40179 .63555 Mdot
.36201 .51369 Mdot
.37817 .75373 Mdot
.38847 .68233 Mdot
.64499 .59112 Mdot
.33294 .47165 Mdot
.41353 .65362 Mdot
.66973 .52661 Mdot
.15607 .51294 Mdot
.37166 .6749 Mdot
.59146 .62535 Mdot
.6569 .67128 Mdot
.81161 .3844 Mdot
.38738 .68444 Mdot
.47124 .38909 Mdot
.65609 .57682 Mdot
.64166 .44008 Mdot
.40327 .62063 Mdot
.38501 .2831 Mdot
.34705 .50352 Mdot
.217 .60002 Mdot
.67866 .56076 Mdot
.80572 .56487 Mdot
.41162 .63405 Mdot
.61489 .37886 Mdot
.64673 .33881 Mdot
.58423 .59803 Mdot
.38627 .68399 Mdot
.43812 .32828 Mdot
.35053 .50969 Mdot
.33175 .33278 Mdot
.64038 .3833 Mdot
.49438 .24151 Mdot
.37701 .50995 Mdot
.48045 .22399 Mdot
.5958 .78475 Mdot
.59911 .51549 Mdot
.80583 .38581 Mdot
.35093 .42022 Mdot
.64953 .56085 Mdot
.36856 .64061 Mdot
.47545 .33298 Mdot
.47924 .38675 Mdot
.45123 .35184 Mdot
.55817 .31185 Mdot
.45933 .59299 Mdot
.32698 .46204 Mdot
.40182 .32349 Mdot
.394 .6353 Mdot
.48115 .63978 Mdot
.62283 .63633 Mdot
.61267 .60019 Mdot
.57176 .55838 Mdot
.57211 .58381 Mdot
.59193 .60374 Mdot
.45711 .36539 Mdot
.52955 .3163 Mdot
.46776 .59452 Mdot
.61503 .40283 Mdot
.27104 .52914 Mdot
.34944 .47448 Mdot
.32915 .4599 Mdot
.40839 .66572 Mdot
.47614 .2129 Mdot
.31501 .51475 Mdot
.37395 .48449 Mdot
.63371 .54863 Mdot
.64 .36758 Mdot
.6672 .65281 Mdot
.60335 .62423 Mdot
.34815 .51467 Mdot
.52964 .48245 Mdot
.78858 .49912 Mdot
.66603 .53138 Mdot
.39939 .59933 Mdot
.43941 .55009 Mdot
.37561 .67549 Mdot
.64276 .63031 Mdot
.62859 .79676 Mdot
.37431 .5211 Mdot
.36892 .49569 Mdot
.41028 .63551 Mdot
.59937 .45843 Mdot
.6321 .39096 Mdot
.39597 .39175 Mdot
.46045 .39042 Mdot
.62975 .62672 Mdot
.45421 .80201 Mdot
.63651 .45877 Mdot
.2756 .5555 Mdot
.44768 .35105 Mdot
.34714 .46972 Mdot
.56521 .57509 Mdot
.5907 .62404 Mdot
.40638 .63617 Mdot
.27275 .31255 Mdot
.56025 .56925 Mdot
.466 .18939 Mdot
.34014 .73904 Mdot
.25135 .66073 Mdot
.58178 .58854 Mdot
.63645 .37628 Mdot
.31411 .5088 Mdot
.40005 .62765 Mdot
.62321 .65625 Mdot
.16418 .48317 Mdot
.62035 .4274 Mdot
.47104 .34017 Mdot
.49491 .51411 Mdot
.45469 .60765 Mdot
.6487 .56573 Mdot
.63068 .56084 Mdot
.60639 .54993 Mdot
.16759 .5672 Mdot
.35031 .52355 Mdot
.6 .36297 Mdot
.38611 .67004 Mdot
.62039 .3565 Mdot
.33907 .4908 Mdot
.50084 .24938 Mdot
.64629 .57796 Mdot
.61944 .4282 Mdot
.61621 .38043 Mdot
.47399 .33721 Mdot
.48001 .39229 Mdot
.50297 .49184 Mdot
.61581 .56671 Mdot
.39227 .51468 Mdot
.5945 .40901 Mdot
.43365 .58187 Mdot
.39928 .65977 Mdot
.47636 .37502 Mdot
.57615 .61104 Mdot
.35257 .52764 Mdot
.57574 .63248 Mdot
.62883 .4006 Mdot
.37298 .48389 Mdot
.24765 .43392 Mdot
.41195 .66841 Mdot
.60197 .56028 Mdot
.40505 .68776 Mdot
.33452 .47593 Mdot
.60566 .60532 Mdot
.54186 .20962 Mdot
.38424 .60007 Mdot
.37366 .31228 Mdot
.35763 .46188 Mdot
.26359 .42516 Mdot
.65447 .37581 Mdot
.59351 .30621 Mdot
.37059 .4983 Mdot
.50379 .21689 Mdot
.26899 .33536 Mdot
.56862 .55899 Mdot
.59618 .38976 Mdot
.39352 .42407 Mdot
.2469 .29032 Mdot
.71606 .27646 Mdot
.62575 .58587 Mdot
.34012 .46086 Mdot
.41059 .64001 Mdot
.43868 .36029 Mdot
.35363 .59264 Mdot
.39221 .59765 Mdot
.3836 .52079 Mdot
.63755 .61999 Mdot
.60934 .37353 Mdot
.47281 .36522 Mdot
.52474 .29913 Mdot
.36338 .47166 Mdot
.38295 .49718 Mdot
.5655 .57589 Mdot
.3927 .647 Mdot
.69998 .30015 Mdot
.33431 .5059 Mdot
.35431 .73146 Mdot
.35089 .53928 Mdot
.38282 .6257 Mdot
.58955 .61355 Mdot
.45097 .69255 Mdot
.6222 .53433 Mdot
.60154 .21473 Mdot
.3463 .47898 Mdot
.62444 .40435 Mdot
.62152 .55058 Mdot
.55566 .78575 Mdot
.35275 .51437 Mdot
.43364 .55778 Mdot
.25091 .57887 Mdot
.4788 .36529 Mdot
.37889 .75539 Mdot
.60031 .56829 Mdot
.43463 .37851 Mdot
.40223 .63695 Mdot
.6232 .57029 Mdot
.62819 .60259 Mdot
.58374 .37196 Mdot
.46213 .33451 Mdot
.2402 .37154 Mdot
.42467 .35366 Mdot
.48693 .36585 Mdot
.58612 .36178 Mdot
.59623 .58983 Mdot
.37499 .49881 Mdot
.35656 .49787 Mdot
.63393 .64862 Mdot
.65905 .793 Mdot
.63533 .39104 Mdot
.33374 .44684 Mdot
.17736 .59012 Mdot
.57307 .51467 Mdot
.39504 .76637 Mdot
.28606 .30021 Mdot
.45194 .32136 Mdot
.58296 .62352 Mdot
.60604 .36948 Mdot
.41158 .44787 Mdot
.3815 .4989 Mdot
.67057 .59833 Mdot
.47063 .36064 Mdot
.38501 .67748 Mdot
.31718 .49848 Mdot
.277 .55163 Mdot
.59535 .55631 Mdot
.2971 .65246 Mdot
.32694 .46642 Mdot
.38313 .18251 Mdot
.39874 .41783 Mdot
.59712 .39472 Mdot
.63284 .60608 Mdot
.64895 .36319 Mdot
.39103 .67172 Mdot
.49463 .51169 Mdot
.47314 .35993 Mdot
.67855 .67429 Mdot
.46996 .86158 Mdot
.33047 .48625 Mdot
.60457 .35924 Mdot
.56652 .58291 Mdot
.5748 .46644 Mdot
.59698 .57395 Mdot
.59568 .66886 Mdot
.36228 .61856 Mdot
.44351 .37427 Mdot
.43898 .38369 Mdot
.60963 .60956 Mdot
.37618 .6368 Mdot
.353 .47136 Mdot
.35447 .51082 Mdot
.51568 .14675 Mdot
.47136 .30168 Mdot
.48686 .77377 Mdot
.61292 .55638 Mdot
.39341 .50473 Mdot
.29159 .34331 Mdot
.4441 .34754 Mdot
.61719 .63918 Mdot
.32271 .49223 Mdot
.26998 .65776 Mdot
.56585 .77106 Mdot
.58874 .60498 Mdot
.6774 .60964 Mdot
.46402 .39029 Mdot
.48926 .63027 Mdot
.37823 .47354 Mdot
.56332 .53383 Mdot
.50003 .34925 Mdot
.64347 .748 Mdot
.22178 .6435 Mdot
.62009 .41039 Mdot
.24849 .52937 Mdot
.45764 .36616 Mdot
.67753 .61818 Mdot
.38183 .63888 Mdot
.32478 .52176 Mdot
.34796 .52503 Mdot
.65013 .61094 Mdot
.57069 .62321 Mdot
.40161 .75114 Mdot
.62294 .35848 Mdot
.48548 .35335 Mdot
.63833 .56717 Mdot
.55911 .2462 Mdot
.57088 .57726 Mdot
.4592 .38223 Mdot
.27564 .79124 Mdot
.58117 .53491 Mdot
.59408 .57578 Mdot
.69963 .29541 Mdot
.64835 .39272 Mdot
.60829 .35622 Mdot
.39598 .79535 Mdot
.61194 .55647 Mdot
.36591 .74391 Mdot
.62464 .41055 Mdot
.63337 .39391 Mdot
.33119 .34742 Mdot
.61918 .5984 Mdot
.67596 .6891 Mdot
.43409 .36426 Mdot
.48512 .37276 Mdot
.64396 .3812 Mdot
.57268 .54346 Mdot
.49 .34754 Mdot
.7872 .39842 Mdot
.36035 .48932 Mdot
.64802 .78516 Mdot
.64074 .39704 Mdot
.5281 .43147 Mdot
.44499 .3505 Mdot
.14576 .39992 Mdot
.33675 .54173 Mdot
.64219 .57565 Mdot
.60358 .55687 Mdot
.39951 .63394 Mdot
.58325 .53475 Mdot
.39157 .48832 Mdot
.45629 .35797 Mdot
.69288 .39827 Mdot
.61288 .40965 Mdot
.60783 .57183 Mdot
.46671 .21586 Mdot
.37954 .27214 Mdot
.23415 .50886 Mdot
.62869 .38496 Mdot
.59307 .39448 Mdot
.38138 .47814 Mdot
.33711 .46158 Mdot
.59006 .59395 Mdot
.44021 .33917 Mdot
.59009 .37369 Mdot
.45116 .38185 Mdot
.37393 .521 Mdot
.37687 .49492 Mdot
.33997 .52543 Mdot
.55751 .6183 Mdot
.37374 .48014 Mdot
.31794 .56053 Mdot
.48508 .24297 Mdot
.60362 .3518 Mdot
.29399 .73219 Mdot
.53352 .30013 Mdot
.57445 .33707 Mdot
.41113 .62149 Mdot
.3337 .47594 Mdot
.42614 .373 Mdot
.6069 .61704 Mdot
.57588 .59346 Mdot
.28358 .51799 Mdot
.42872 .36853 Mdot
.39623 .66965 Mdot
.43401 .38129 Mdot
.37916 .66218 Mdot
.2674 .62548 Mdot
.57776 .5492 Mdot
.61895 .63227 Mdot
.4535 .36208 Mdot
.37231 .4809 Mdot
.33969 .50063 Mdot
.37622 .68121 Mdot
.55183 .4229 Mdot
.32679 .49988 Mdot
.63744 .39917 Mdot
.77216 .41693 Mdot
.31193 .49994 Mdot
.61326 .56264 Mdot
.54972 .71136 Mdot
.8141 .53361 Mdot
.64772 .55169 Mdot
.32346 .35127 Mdot
.77969 .62794 Mdot
.60623 .54308 Mdot
.81031 .59203 Mdot
.27231 .42172 Mdot
.65163 .37282 Mdot
.36694 .46759 Mdot
.30342 .47896 Mdot
.54898 .61269 Mdot
.36446 .66418 Mdot
.62932 .65401 Mdot
.64225 .40219 Mdot
.65456 .41448 Mdot
.28126 .68439 Mdot
.64236 .24003 Mdot
.41243 .64392 Mdot
.41459 .65564 Mdot
.36868 .50146 Mdot
.69016 .2251 Mdot
.68955 .59738 Mdot
.40117 .66633 Mdot
.52214 .63568 Mdot
.64202 .61916 Mdot
.51375 .75084 Mdot
.33863 .70036 Mdot
.63983 .37942 Mdot
.46204 .66856 Mdot
.36868 .50713 Mdot
.63569 .35887 Mdot
.57128 .25664 Mdot
.60676 .53378 Mdot
.61577 .40834 Mdot
.45409 .38379 Mdot
.37323 .39634 Mdot
.63311 .41283 Mdot
.54864 .71735 Mdot
.45721 .33228 Mdot
.43271 .57713 Mdot
.45874 .70392 Mdot
.83006 .68407 Mdot
.45858 .36279 Mdot
.32423 .51422 Mdot
.35632 .49893 Mdot
.35642 .51018 Mdot
.62712 .35762 Mdot
.3381 .46985 Mdot
.61531 .35879 Mdot
.76345 .32243 Mdot
.59488 .46441 Mdot
.40472 .66292 Mdot
.33878 .3298 Mdot
.60242 .38041 Mdot
.58356 .83007 Mdot
.56696 .86475 Mdot
.58134 .62311 Mdot
.424 .37558 Mdot
.41003 .65511 Mdot
.48619 .17566 Mdot
.40131 .64559 Mdot
.41053 .7075 Mdot
.66241 .75776 Mdot
.60403 .57836 Mdot
.75671 .51502 Mdot
.42175 .63668 Mdot
.6236 .37757 Mdot
.60817 .60483 Mdot
.41317 .43162 Mdot
.39826 .64418 Mdot
.37809 .66629 Mdot
.5971 .59697 Mdot
.60655 .41534 Mdot
.37275 .50686 Mdot
.45146 .39524 Mdot
.4284 .64467 Mdot
.60665 .33803 Mdot
.63601 .54621 Mdot
.65306 .59168 Mdot
.45719 .56502 Mdot
.43375 .66219 Mdot
.45856 .3571 Mdot
.82899 .52165 Mdot
.3504 .46184 Mdot
.38161 .42692 Mdot
.33966 .72896 Mdot
.30592 .36962 Mdot
.34718 .48113 Mdot
.33765 .47696 Mdot
.58971 .60106 Mdot
.43708 .64499 Mdot
.68067 .73747 Mdot
.4109 .35473 Mdot
.31294 .50648 Mdot
.3508 .5111 Mdot
.66405 .39643 Mdot
.29 .69475 Mdot
.62006 .65701 Mdot
.48217 .33784 Mdot
.3483 .52654 Mdot
.56263 .42399 Mdot
.39133 .64346 Mdot
.59227 .81548 Mdot
.58021 .54599 Mdot
.63974 .5723 Mdot
.46457 .34891 Mdot
.46649 .38237 Mdot
.41489 .45335 Mdot
.32653 .71723 Mdot
.78619 .61097 Mdot
.50308 .29716 Mdot
.70818 .56378 Mdot
.66074 .40114 Mdot
.588 .38165 Mdot
.3977 .28463 Mdot
.42453 .35231 Mdot
.61296 .54573 Mdot
.59651 .36974 Mdot
.30534 .43392 Mdot
.67738 .31903 Mdot
.49679 .76219 Mdot
.4104 .76911 Mdot
.64375 .59433 Mdot
.63246 .36843 Mdot
.6475 .39263 Mdot
.58056 .40298 Mdot
.27933 .41873 Mdot
.58856 .58598 Mdot
.63585 .58908 Mdot
.58843 .5489 Mdot
.5393 .52774 Mdot
.5853 .56671 Mdot
.57839 .31393 Mdot
.48219 .4997 Mdot
.6684 .49041 Mdot
.56107 .54026 Mdot
.4708 .32376 Mdot
.65011 .5677 Mdot
.37495 .63988 Mdot
.62745 .62205 Mdot
.50151 .76511 Mdot
.45567 .33838 Mdot
.56875 .34737 Mdot
.54121 .30734 Mdot
.63489 .55262 Mdot
.4102 .67495 Mdot
.48897 .41334 Mdot
.20661 .37568 Mdot
.38033 .69448 Mdot
.63822 .39842 Mdot
.35603 .48496 Mdot
.42614 .37012 Mdot
.37422 .49162 Mdot
.55748 .61588 Mdot
.40158 .28618 Mdot
.38793 .24675 Mdot
.51947 .4627 Mdot
.57243 .58826 Mdot
.65511 .53091 Mdot
.6336 .39801 Mdot
.33204 .47184 Mdot
.62608 .45429 Mdot
.61841 .5506 Mdot
.38301 .66364 Mdot
.39844 .63907 Mdot
.41647 .42784 Mdot
.34411 .2307 Mdot
.6207 .31004 Mdot
.46262 .35058 Mdot
.33411 .50937 Mdot
.40141 .62434 Mdot
.59464 .23439 Mdot
.47682 .39494 Mdot
.43608 .34294 Mdot
.472 .33856 Mdot
.66372 .59702 Mdot
.33065 .51998 Mdot
.66809 .48406 Mdot
.39269 .50345 Mdot
.63323 .59546 Mdot
.35892 .52297 Mdot
.32462 .49278 Mdot
.39079 .63159 Mdot
.48198 .34613 Mdot
.38592 .50637 Mdot
.60178 .62861 Mdot
.61776 .41569 Mdot
.52875 .41213 Mdot
.55635 .75744 Mdot
.62327 .23314 Mdot
.69164 .37066 Mdot
.63968 .41462 Mdot
.2439 .30024 Mdot
.44526 .32706 Mdot
.52131 .5549 Mdot
.24179 .45924 Mdot
.65602 .61841 Mdot
.60649 .83079 Mdot
.32369 .46319 Mdot
.31953 .4939 Mdot
.59173 .6138 Mdot
.32124 .43789 Mdot
.60375 .57358 Mdot
.37728 .51493 Mdot
.27095 .5042 Mdot
.54548 .54016 Mdot
.36406 .47635 Mdot
.55905 .53995 Mdot
.62026 .60445 Mdot
.64029 .37755 Mdot
.31614 .47111 Mdot
.61567 .64002 Mdot
.48299 .15662 Mdot
.46648 .3798 Mdot
.29807 .40965 Mdot
.57215 .71379 Mdot
.4577 .3675 Mdot
.60645 .40499 Mdot
.64652 .642 Mdot
.40461 .63662 Mdot
.60236 .37783 Mdot
.57313 .77421 Mdot
.42084 .64681 Mdot
.5873 .83409 Mdot
.6455 .38916 Mdot
.31096 .49433 Mdot
.37962 .63968 Mdot
.59968 .52388 Mdot
.32505 .52152 Mdot
.43336 .41802 Mdot
.34852 .47973 Mdot
.58197 .5827 Mdot
.33998 .31834 Mdot
.48636 .3588 Mdot
.62432 .58352 Mdot
.31671 .49023 Mdot
.30975 .35847 Mdot
.66273 .59863 Mdot
.60091 .61087 Mdot
.25114 .6692 Mdot
.52673 .82859 Mdot
.40242 .65293 Mdot
.57806 .40697 Mdot
.59406 .62563 Mdot
.38265 .67306 Mdot
.30146 .61948 Mdot
.65433 .57793 Mdot
.6138 .42793 Mdot
.60283 .49586 Mdot
.32002 .47161 Mdot
.4591 .37362 Mdot
.5179 .45788 Mdot
.38463 .67605 Mdot
.87225 .47302 Mdot
.37931 .52055 Mdot
.63685 .63348 Mdot
.57143 .59845 Mdot
.21727 .54142 Mdot
.65046 .37114 Mdot
.7427 .66287 Mdot
.60204 .56002 Mdot
.53198 .54035 Mdot
.62035 .57222 Mdot
.32792 .45128 Mdot
.63311 .39176 Mdot
.59052 .57536 Mdot
.4987 .23123 Mdot
.66664 .56899 Mdot
.39477 .68075 Mdot
.70976 .29635 Mdot
.64418 .55277 Mdot
.38778 .85442 Mdot
.35067 .70767 Mdot
.36459 .47543 Mdot
.37441 .28944 Mdot
.63209 .15805 Mdot
.55903 .3082 Mdot
.60967 .35945 Mdot
.32218 .27455 Mdot
.37549 .49846 Mdot
.33681 .30571 Mdot
.23871 .3024 Mdot
.62063 .6077 Mdot
.64859 .56553 Mdot
.39575 .70677 Mdot
.38133 .47108 Mdot
.37145 .53082 Mdot
.5543 .57924 Mdot
.67049 .63623 Mdot
.37945 .49114 Mdot
.59854 .63096 Mdot
.55207 .6011 Mdot
.44158 .39434 Mdot
.63454 .41752 Mdot
.43885 .36791 Mdot
.46762 .33201 Mdot
.75775 .35452 Mdot
.31172 .69312 Mdot
.46106 .38048 Mdot
.46198 .32517 Mdot
.51693 .75345 Mdot
.4238 .74546 Mdot
.4047 .62088 Mdot
.39106 .1932 Mdot
.35458 .50854 Mdot
.592 .5859 Mdot
.64497 .40608 Mdot
.78882 .59272 Mdot
.34009 .60738 Mdot
.6877 .74071 Mdot
.61524 .54786 Mdot
.35974 .51244 Mdot
.27952 .41812 Mdot
.65325 .66281 Mdot
.40456 .50678 Mdot
.64041 .56664 Mdot
.36955 .53003 Mdot
.76189 .44868 Mdot
.4952 .21948 Mdot
.36097 .53649 Mdot
.61593 .3457 Mdot
.63431 .56872 Mdot
.64245 .39642 Mdot
.44393 .35586 Mdot
.38467 .63039 Mdot
.39958 .65618 Mdot
.60251 .60275 Mdot
.59479 .51158 Mdot
.2793 .63906 Mdot
.6227 .60023 Mdot
.63584 .61839 Mdot
.272 .4218 Mdot
.62951 .61921 Mdot
.57459 .57699 Mdot
.57927 .56415 Mdot
.6711 .61069 Mdot
.48601 .36962 Mdot
.47022 .21734 Mdot
.593 .65652 Mdot
.5979 .66155 Mdot
.48554 .3844 Mdot
.25163 .34163 Mdot
.45513 .32868 Mdot
.2048 .35657 Mdot
.43681 .37335 Mdot
.39735 .66389 Mdot
.20914 .47207 Mdot
.63658 .52422 Mdot
.59792 .41468 Mdot
.45043 .40327 Mdot
.38386 .66912 Mdot
.45314 .3547 Mdot
.37317 .51536 Mdot
.18947 .59247 Mdot
.56819 .36851 Mdot
.56308 .68294 Mdot
.42087 .39679 Mdot
.39927 .30047 Mdot
.3885 .50449 Mdot
.63936 .38907 Mdot
.78509 .5104 Mdot
.57235 .57783 Mdot
.38095 .66967 Mdot
.59231 .59688 Mdot
.48752 .35178 Mdot
.36527 .50815 Mdot
.70808 .27982 Mdot
.40583 .636 Mdot
.29278 .72363 Mdot
.34492 .50115 Mdot
.57958 .55805 Mdot
.48419 .34038 Mdot
.33716 .76842 Mdot
.4406 .37217 Mdot
.72672 .64991 Mdot
.66047 .37747 Mdot
.8013 .36485 Mdot
.599 .38449 Mdot
.39953 .40825 Mdot
.21774 .68944 Mdot
.49359 .19741 Mdot
.6089 .41551 Mdot
.43006 .3005 Mdot
.64821 .59512 Mdot
.65253 .58968 Mdot
.61085 .23873 Mdot
.57912 .40852 Mdot
.57691 .61733 Mdot
.25634 .43011 Mdot
.47529 .25495 Mdot
.42396 .78881 Mdot
.34285 .47444 Mdot
.60327 .56928 Mdot
.50022 .36178 Mdot
.43199 .37208 Mdot
.38581 .51512 Mdot
.44097 .33271 Mdot
.63368 .58953 Mdot
.60187 .38154 Mdot
.40185 .4656 Mdot
.38879 .65864 Mdot
.56364 .18023 Mdot
.37517 .62927 Mdot
.34694 .48168 Mdot
.59745 .52032 Mdot
.37701 .49361 Mdot
.64975 .15137 Mdot
.63677 .58472 Mdot
.62569 .40885 Mdot
.60694 .62232 Mdot
.63203 .5706 Mdot
.64792 .56358 Mdot
.37751 .50618 Mdot
.68549 .69101 Mdot
.6002 .62974 Mdot
.47405 .36062 Mdot
.67776 .50989 Mdot
.6381 .54999 Mdot
.30919 .45512 Mdot
.45466 .74857 Mdot
.39701 .34994 Mdot
.65189 .39826 Mdot
.35583 .47508 Mdot
.61055 .41109 Mdot
.63578 .4546 Mdot
.60674 .40494 Mdot
.71354 .53975 Mdot
.7815 .49491 Mdot
.69217 .69393 Mdot
.70992 .37364 Mdot
.51366 .52185 Mdot
.57844 .40754 Mdot
.36944 .70335 Mdot
.58478 .38501 Mdot
.64864 .38791 Mdot
.12258 .64677 Mdot
.58919 .40632 Mdot
.60962 .56106 Mdot
.61014 .53743 Mdot
.43329 .26252 Mdot
.50945 .72076 Mdot
.61396 .61755 Mdot
.59541 .62198 Mdot
.38948 .62962 Mdot
.52613 .56672 Mdot
.38632 .28962 Mdot
.51609 .83887 Mdot
.35746 .28178 Mdot
.59504 .59772 Mdot
.5971 .62597 Mdot
.66725 .64768 Mdot
.36309 .81171 Mdot
.79566 .39354 Mdot
.62395 .43513 Mdot
.6819 .61111 Mdot
.56059 .19648 Mdot
.63976 .55935 Mdot
.6627 .58561 Mdot
.6453 .59406 Mdot
.37508 .49927 Mdot
.63478 .42539 Mdot
.65869 .63971 Mdot
.33723 .7111 Mdot
.64645 .56785 Mdot
.30891 .36517 Mdot
.76277 .28967 Mdot
.59976 .56804 Mdot
.64148 .42131 Mdot
.6545 .60071 Mdot
.64835 .37449 Mdot
.62657 .37397 Mdot
.64853 .54327 Mdot
.70426 .55346 Mdot
.65376 .41153 Mdot
.63342 .59608 Mdot
.36769 .51358 Mdot
.37016 .19679 Mdot
.5821 .58062 Mdot
.39087 .62518 Mdot
.60493 .55709 Mdot
.41477 .67097 Mdot
.63269 .61666 Mdot
.37733 .52261 Mdot
.80248 .55698 Mdot
.36804 .49803 Mdot
.81909 .40242 Mdot
.34493 .52944 Mdot
.25835 .67919 Mdot
.61167 .43063 Mdot
.3375 .32551 Mdot
.76198 .6797 Mdot
.30105 .39372 Mdot
.4229 .55221 Mdot
.46276 .50454 Mdot
.44002 .33895 Mdot
.65135 .36669 Mdot
.50262 .58961 Mdot
.25041 .47556 Mdot
.23714 .4877 Mdot
.32534 .50423 Mdot
.81532 .62667 Mdot
.69651 .74842 Mdot
.62113 .62927 Mdot
.74559 .52727 Mdot
.70669 .46533 Mdot
.65224 .56736 Mdot
.6609 .63449 Mdot
.27987 .50486 Mdot
.57903 .62536 Mdot
.55309 .24191 Mdot
.34508 .485 Mdot
.38265 .66826 Mdot
.632 .40375 Mdot
.38261 .67665 Mdot
.24833 .47576 Mdot
.4594 .50776 Mdot
.37395 .51893 Mdot
.6751 .59554 Mdot
.60056 .61982 Mdot
.6437 .37419 Mdot
.59927 .44237 Mdot
.58641 .39569 Mdot
.41104 .64621 Mdot
.34696 .49002 Mdot
.81588 .49051 Mdot
.58767 .61925 Mdot
.61589 .3818 Mdot
.4202 .54238 Mdot
.59026 .6251 Mdot
.44894 .36248 Mdot
.64589 .58811 Mdot
.61753 .41787 Mdot
.62933 .61912 Mdot
.59806 .38249 Mdot
.35874 .48599 Mdot
.60703 .53941 Mdot
.58914 .61011 Mdot
.31913 .75236 Mdot
.39398 .66886 Mdot
.59937 .42792 Mdot
.27747 .4623 Mdot
.5687 .59614 Mdot
.3474 .34823 Mdot
.63354 .5641 Mdot
.67375 .31559 Mdot
.65723 .62159 Mdot
.29179 .39901 Mdot
.60259 .65482 Mdot
.58327 .57958 Mdot
.42723 .47979 Mdot
.70826 .48778 Mdot
.58368 .42492 Mdot
.48289 .33684 Mdot
.59402 .41582 Mdot
.43237 .78673 Mdot
.33626 .53888 Mdot
.33042 .47032 Mdot
.49325 .66059 Mdot
.67148 .61295 Mdot
.60218 .57955 Mdot
.49527 .37842 Mdot
.41206 .66414 Mdot
.62742 .38358 Mdot
.37948 .66254 Mdot
.3497 .74839 Mdot
.41825 .64374 Mdot
.32279 .45976 Mdot
.29635 .64974 Mdot
.80662 .45318 Mdot
.39017 .6297 Mdot
.60691 .41599 Mdot
.35145 .62099 Mdot
.67011 .59378 Mdot
.36002 .70768 Mdot
.38186 .65849 Mdot
.84607 .5794 Mdot
.57495 .57791 Mdot
.41901 .55696 Mdot
.45538 .37763 Mdot
.38331 .63646 Mdot
.44744 .33637 Mdot
.60926 .61484 Mdot
.37605 .30753 Mdot
.60357 .36385 Mdot
.49196 .36321 Mdot
.57665 .53086 Mdot
.40975 .65735 Mdot
.34244 .52363 Mdot
.46704 .40497 Mdot
.48833 .34346 Mdot
.27223 .30989 Mdot
.73068 .29471 Mdot
.34789 .49223 Mdot
.56542 .7953 Mdot
.43457 .3693 Mdot
.65301 .56478 Mdot
.52224 .59679 Mdot
.64254 .57526 Mdot
.59434 .31303 Mdot
.35142 .47368 Mdot
.44284 .24862 Mdot
.60694 .62377 Mdot
.59538 .54787 Mdot
.58736 .42623 Mdot
.36076 .50057 Mdot
.61066 .39228 Mdot
.58792 .4099 Mdot
.35905 .48767 Mdot
.59785 .39235 Mdot
.42239 .6444 Mdot
.49184 .26459 Mdot
.45344 .39094 Mdot
.47566 .35447 Mdot
.35277 .51143 Mdot
.36705 .47459 Mdot
.37443 .48588 Mdot
.64593 .58772 Mdot
.63154 .38744 Mdot
.6341 .60914 Mdot
.64993 .56885 Mdot
.70892 .5736 Mdot
.64551 .41064 Mdot
.64456 .60311 Mdot
.40048 .4327 Mdot
.42885 .61873 Mdot
.36549 .51599 Mdot
.45992 .37901 Mdot
.28263 .35745 Mdot
.47791 .41042 Mdot
.6067 .56782 Mdot
.26754 .65186 Mdot
.59609 .40814 Mdot
.40202 .63873 Mdot
.40021 .61527 Mdot
.40231 .64781 Mdot
.44589 .31226 Mdot
.58303 .41299 Mdot
.52288 .83956 Mdot
.6017 .57275 Mdot
.45516 .56631 Mdot
.52624 .6445 Mdot
.27291 .64046 Mdot
.46314 .37893 Mdot
.5932 .6242 Mdot
.52811 .4499 Mdot
.79371 .508 Mdot
.63959 .57534 Mdot
.65857 .56529 Mdot
.24975 .43937 Mdot
.6079 .49234 Mdot
.66236 .37619 Mdot
.35557 .76959 Mdot
.57212 .5551 Mdot
.57289 .43559 Mdot
.59337 .17829 Mdot
.61698 .56445 Mdot
.60495 .54835 Mdot
.57822 .6049 Mdot
.63074 .6227 Mdot
.65183 .4105 Mdot
.4795 .6925 Mdot
.44262 .32857 Mdot
.46014 .57923 Mdot
.47611 .38758 Mdot
.33328 .52836 Mdot
.46708 .22454 Mdot
.65228 .36666 Mdot
.39991 .63395 Mdot
.46505 .20196 Mdot
.4303 .81654 Mdot
.37641 .47241 Mdot
.77756 .38855 Mdot
.38625 .66511 Mdot
.65335 .56335 Mdot
.42396 .64949 Mdot
.32928 .51837 Mdot
.47802 .36223 Mdot
.67426 .6107 Mdot
.58621 .38719 Mdot
.63527 .4111 Mdot
.57912 .62059 Mdot
.53849 .19336 Mdot
.45008 .36665 Mdot
.48837 .38811 Mdot
.65997 .58727 Mdot
.59851 .52452 Mdot
.60954 .39514 Mdot
.33848 .50792 Mdot
.51082 .79072 Mdot
.40591 .66867 Mdot
.58255 .63457 Mdot
.63732 .62053 Mdot
.33131 .72515 Mdot
.47673 .36991 Mdot
.35587 .45863 Mdot
.65952 .60823 Mdot
.4941 .29817 Mdot
.65882 .60895 Mdot
.6814 .62731 Mdot
.36478 .51446 Mdot
.58598 .64986 Mdot
.61151 .63219 Mdot
.58289 .6669 Mdot
.43757 .34943 Mdot
.62076 .40765 Mdot
.57733 .36435 Mdot
.4749 .58352 Mdot
.44876 .36038 Mdot
.64863 .60313 Mdot
.46801 .37278 Mdot
.65267 .57644 Mdot
.58114 .62456 Mdot
.45901 .38201 Mdot
.60978 .39209 Mdot
.31945 .28087 Mdot
.46637 .21891 Mdot
.62738 .62389 Mdot
.56272 .57961 Mdot
.49051 .70262 Mdot
.67878 .70154 Mdot
.62481 .55357 Mdot
.62481 .41662 Mdot
.58979 .61718 Mdot
.44843 .3385 Mdot
.41886 .63286 Mdot
.61709 .4163 Mdot
.33631 .49648 Mdot
.38512 .48083 Mdot
.54712 .30701 Mdot
.32842 .48218 Mdot
.66812 .5948 Mdot
.63161 .45637 Mdot
.57165 .3776 Mdot
.58859 .18714 Mdot
.35945 .49145 Mdot
.41837 .62561 Mdot
.60197 .60949 Mdot
.25116 .64714 Mdot
.49939 .37348 Mdot
.43812 .88003 Mdot
.57006 .83851 Mdot
.36537 .65889 Mdot
.69733 .72357 Mdot
.34586 .5333 Mdot
.59637 .6348 Mdot
.38272 .63114 Mdot
.37818 .47568 Mdot
.65316 .61905 Mdot
.68089 .58617 Mdot
.73638 .66849 Mdot
.48306 .54621 Mdot
.4697 .37346 Mdot
.34474 .46566 Mdot
.37034 .62481 Mdot
.34161 .45574 Mdot
.64335 .40504 Mdot
.58587 .57972 Mdot
.61043 .5183 Mdot
.33587 .50204 Mdot
.37468 .46538 Mdot
.6398 .59723 Mdot
.64959 .36371 Mdot
.28219 .50697 Mdot
.60145 .59774 Mdot
.52451 .51461 Mdot
.63944 .34482 Mdot
.34035 .48454 Mdot
.587 .55565 Mdot
.37179 .60016 Mdot
.34308 .50364 Mdot
.36416 .51728 Mdot
.58077 .62316 Mdot
.42186 .6474 Mdot
.56458 .57804 Mdot
.44014 .3828 Mdot
.83311 .53511 Mdot
.45351 .33593 Mdot
.35846 .59034 Mdot
.58518 .51954 Mdot
.49751 .31541 Mdot
.65366 .38819 Mdot
.40908 .70478 Mdot
.25355 .40123 Mdot
.55411 .57409 Mdot
.31348 .24941 Mdot
.52028 .43377 Mdot
.52129 .18143 Mdot
.18826 .46542 Mdot
.38358 .64702 Mdot
.45125 .35288 Mdot
.60632 .54844 Mdot
.4291 .38472 Mdot
.38467 .62786 Mdot
.81087 .39389 Mdot
.58233 .56136 Mdot
.63234 .39333 Mdot
.63947 .5929 Mdot
.64003 .39724 Mdot
.58623 .6254 Mdot
.64137 .6651 Mdot
.26155 .42358 Mdot
.5659 .77039 Mdot
.66111 .61406 Mdot
.20437 .63338 Mdot
.33473 .66942 Mdot
.39163 .67367 Mdot
.62835 .60642 Mdot
.39788 .52938 Mdot
.42937 .3646 Mdot
.60908 .25368 Mdot
.37577 .49972 Mdot
.46302 .32842 Mdot
.60431 .39821 Mdot
.3521 .4785 Mdot
.38857 .48465 Mdot
.58642 .64849 Mdot
.398 .68178 Mdot
.4792 .3475 Mdot
.58974 .57304 Mdot
.58186 .56449 Mdot
.53095 .80345 Mdot
.33202 .59226 Mdot
.57236 .42096 Mdot
.43015 .83825 Mdot
.58567 .35965 Mdot
.40092 .66809 Mdot
.37431 .50577 Mdot
.62887 .55847 Mdot
.62309 .58574 Mdot
.32721 .33914 Mdot
.59274 .36804 Mdot
.4999 .5038 Mdot
.74369 .35939 Mdot
.28294 .49597 Mdot
.48156 .74455 Mdot
.63117 .40858 Mdot
.48481 .7449 Mdot
.38425 .61434 Mdot
.42354 .19188 Mdot
.53938 .76851 Mdot
.45793 .3768 Mdot
.4813 .74158 Mdot
.61718 .37702 Mdot
.61328 .62841 Mdot
.31012 .49231 Mdot
.32522 .49139 Mdot
.61735 .40136 Mdot
.39637 .47547 Mdot
.39162 .63251 Mdot
.59645 .55325 Mdot
.51216 .83413 Mdot
.55785 .28833 Mdot
.33773 .51409 Mdot
.63998 .66693 Mdot
.46999 .33774 Mdot
.57649 .61896 Mdot
.39788 .62609 Mdot
.46262 .36487 Mdot
.35709 .72017 Mdot
.46169 .25252 Mdot
.60521 .60704 Mdot
.27297 .68801 Mdot
.45328 .36044 Mdot
.65811 .71997 Mdot
.59571 .59244 Mdot
.43455 .36568 Mdot
.67851 .54685 Mdot
.37742 .39949 Mdot
.52933 .4549 Mdot
.24059 .29988 Mdot
.5092 .47856 Mdot
.31489 .50236 Mdot
.37825 .37047 Mdot
.32336 .41979 Mdot
.42834 .37999 Mdot
.36935 .46178 Mdot
.43365 .61071 Mdot
.44624 .33675 Mdot
.63937 .55185 Mdot
.62867 .56418 Mdot
.79746 .39109 Mdot
.50769 .43747 Mdot
.39295 .39694 Mdot
.61048 .28645 Mdot
.56874 .58942 Mdot
.57292 .54839 Mdot
.61727 .58557 Mdot
.65347 .41531 Mdot
.47288 .3691 Mdot
.24933 .69327 Mdot
.44617 .36119 Mdot
.58411 .81463 Mdot
.35664 .50896 Mdot
.34935 .47004 Mdot
.60332 .56694 Mdot
.41736 .57668 Mdot
.4374 .72062 Mdot
.63246 .59123 Mdot
.45061 .6153 Mdot
.70346 .29271 Mdot
.58879 .52901 Mdot
.65868 .38324 Mdot
.55749 .63587 Mdot
.63098 .33303 Mdot
.45211 .39095 Mdot
.38953 .64668 Mdot
.42071 .69913 Mdot
.47988 .36047 Mdot
.60337 .58043 Mdot
.46164 .29168 Mdot
.62979 .57438 Mdot
.63471 .625 Mdot
.61101 .80642 Mdot
.37198 .6334 Mdot
.36778 .48475 Mdot
.40441 .6484 Mdot
.65061 .37828 Mdot
.30032 .82655 Mdot
.41031 .66842 Mdot
.43306 .71751 Mdot
.82972 .43466 Mdot
.48459 .7404 Mdot
.64103 .40604 Mdot
.39225 .68519 Mdot
.45453 .37155 Mdot
.38871 .1787 Mdot
.75908 .66266 Mdot
.52067 .38166 Mdot
.60493 .59485 Mdot
.63853 .35525 Mdot
.62258 .42123 Mdot
.4904 .37167 Mdot
.62567 .37514 Mdot
.67906 .55154 Mdot
.6214 .62635 Mdot
.42553 .37767 Mdot
.4976 .28733 Mdot
.48615 .33952 Mdot
.5051 .25004 Mdot
.63008 .60298 Mdot
.62633 .4116 Mdot
.54613 .59066 Mdot
.66787 .36855 Mdot
.34417 .45763 Mdot
.63945 .54726 Mdot
.39311 .63186 Mdot
.51813 .33964 Mdot
.3464 .49397 Mdot
.26083 .63684 Mdot
.64514 .37633 Mdot
.40457 .3273 Mdot
.6383 .37596 Mdot
.57597 .39892 Mdot
.46228 .3304 Mdot
.61103 .36477 Mdot
.60187 .54914 Mdot
.40419 .4275 Mdot
.64038 .36443 Mdot
.46373 .34301 Mdot
.3913 .65183 Mdot
.60099 .39049 Mdot
.32616 .43632 Mdot
.59558 .60738 Mdot
.38268 .49872 Mdot
.2123 .48888 Mdot
.59441 .35918 Mdot
.37394 .67106 Mdot
.33041 .47188 Mdot
.37655 .66357 Mdot
.66359 .23112 Mdot
.42127 .37071 Mdot
.66731 .7513 Mdot
.40822 .59764 Mdot
.59316 .40929 Mdot
.21133 .47024 Mdot
.62658 .55893 Mdot
.59783 .60902 Mdot
.41808 .66823 Mdot
.62198 .42127 Mdot
.46275 .18911 Mdot
.61888 .32426 Mdot
.47613 .26351 Mdot
.43186 .39814 Mdot
.23814 .66186 Mdot
.5132 .2408 Mdot
.71398 .23893 Mdot
.56142 .56342 Mdot
.36148 .53491 Mdot
.61035 .57312 Mdot
.25997 .3864 Mdot
.40934 .65549 Mdot
.36988 .44637 Mdot
.65331 .5503 Mdot
.36062 .48187 Mdot
.58213 .59997 Mdot
.42775 .4524 Mdot
.55655 .62692 Mdot
.41517 .62331 Mdot
.37775 .29118 Mdot
.59226 .41101 Mdot
.38741 .66028 Mdot
.3731 .52339 Mdot
.45069 .72816 Mdot
.64308 .62636 Mdot
.56092 .62387 Mdot
.2835 .49726 Mdot
.63699 .39042 Mdot
.31299 .48021 Mdot
.44565 .38837 Mdot
.39546 .6384 Mdot
.60702 .61816 Mdot
.66635 .61327 Mdot
.34532 .35192 Mdot
.4754 .33967 Mdot
.39448 .48122 Mdot
.44054 .36848 Mdot
.34729 .53491 Mdot
.56385 .61216 Mdot
.34687 .46968 Mdot
.61158 .63706 Mdot
.26451 .40755 Mdot
.60939 .80467 Mdot
.72091 .50343 Mdot
.34903 .47427 Mdot
.47009 .76031 Mdot
.4528 .33943 Mdot
.43711 .3675 Mdot
.82329 .46273 Mdot
.72629 .65829 Mdot
.48873 .81436 Mdot
.2301 .35471 Mdot
.47259 .38901 Mdot
.46738 .33859 Mdot
.38353 .49351 Mdot
.61564 .36266 Mdot
.57718 .37812 Mdot
.35467 .53438 Mdot
.55566 .71098 Mdot
.62718 .38355 Mdot
.36439 .2108 Mdot
.44443 .79801 Mdot
.64758 .64603 Mdot
.38933 .54914 Mdot
.39706 .64353 Mdot
.54352 .71393 Mdot
.42619 .45278 Mdot
.60089 .54582 Mdot
.32202 .71039 Mdot
.34384 .51179 Mdot
.49247 .63651 Mdot
.20594 .35674 Mdot
.57832 .5673 Mdot
.59209 .58765 Mdot
.61032 .58094 Mdot
.36997 .67594 Mdot
.7465 .64414 Mdot
.58744 .55867 Mdot
.5603 .71176 Mdot
.5694 .60697 Mdot
.70184 .60051 Mdot
.40124 .65406 Mdot
.6882 .54999 Mdot
.24009 .44116 Mdot
.37377 .77358 Mdot
.54039 .59493 Mdot
.44118 .38643 Mdot
.45589 .63422 Mdot
.43516 .35313 Mdot
.71375 .53079 Mdot
.54119 .76541 Mdot
.60557 .34969 Mdot
.60436 .54618 Mdot
.34622 .48176 Mdot
.62481 .42081 Mdot
.36483 .37267 Mdot
.20392 .74899 Mdot
.43701 .38394 Mdot
.73619 .23591 Mdot
.43858 .37441 Mdot
.3908 .49081 Mdot
.60979 .39649 Mdot
.779 .48494 Mdot
.45952 .56123 Mdot
.5991 .3894 Mdot
.37446 .25268 Mdot
.61814 .43841 Mdot
.46702 .74982 Mdot
.61188 .35329 Mdot
.45952 .34103 Mdot
.44302 .31441 Mdot
.67853 .56333 Mdot
.61449 .55749 Mdot
.46159 .49823 Mdot
.43039 .73644 Mdot
.62129 .55721 Mdot
.34647 .48692 Mdot
.69739 .7095 Mdot
.45826 .66396 Mdot
.60938 .36939 Mdot
.44237 .32628 Mdot
.58882 .58911 Mdot
.65168 .61503 Mdot
.6375 .62734 Mdot
.46254 .85859 Mdot
.42998 .18782 Mdot
.59965 .62939 Mdot
.56723 .5985 Mdot
.35534 .48001 Mdot
.39418 .60596 Mdot
.25181 .38487 Mdot
.71203 .63609 Mdot
.6126 .54273 Mdot
.39276 .66306 Mdot
.36899 .63721 Mdot
.65612 .61678 Mdot
.33496 .70265 Mdot
.45493 .29435 Mdot
.58899 .57339 Mdot
.71334 .66522 Mdot
.28612 .4406 Mdot
.38078 .47087 Mdot
.33749 .5003 Mdot
.62909 .42462 Mdot
.33263 .48114 Mdot
.35503 .532 Mdot
.78578 .46608 Mdot
.49774 .49241 Mdot
.46994 .31675 Mdot
.41126 .64501 Mdot
.6255 .58303 Mdot
.56947 .40811 Mdot
.48265 .2946 Mdot
.44825 .33284 Mdot
.59339 .40193 Mdot
.43105 .36268 Mdot
.38917 .69331 Mdot
.54697 .67167 Mdot
.32584 .50928 Mdot
.47697 .38385 Mdot
.46362 .25295 Mdot
.39471 .66158 Mdot
.47856 .33926 Mdot
.42443 .28714 Mdot
.62467 .54089 Mdot
.75576 .55238 Mdot
.63026 .59462 Mdot
.49132 .18078 Mdot
.48372 .35022 Mdot
.29099 .3909 Mdot
.59623 .57924 Mdot
.34547 .50312 Mdot
.69184 .59596 Mdot
.63949 .56374 Mdot
.33247 .49549 Mdot
.61921 .62936 Mdot
.37166 .64141 Mdot
.62977 .34165 Mdot
.46439 .58075 Mdot
.77613 .71283 Mdot
.39742 .68222 Mdot
.36245 .36427 Mdot
.62161 .55118 Mdot
.70974 .27309 Mdot
.60178 .38867 Mdot
.62779 .63539 Mdot
.4651 .667 Mdot
.62813 .3598 Mdot
.60245 .40748 Mdot
.65121 .60855 Mdot
.45205 .37589 Mdot
.34372 .49185 Mdot
.3977 .65727 Mdot
.65844 .21773 Mdot
.61179 .59926 Mdot
.58925 .61328 Mdot
.38618 .66298 Mdot
.46052 .33607 Mdot
.66024 .60346 Mdot
.20575 .51777 Mdot
.49523 .16311 Mdot
.43672 .33999 Mdot
.63286 .54903 Mdot
.743 .58339 Mdot
.6061 .33482 Mdot
.84811 .42279 Mdot
.35705 .70829 Mdot
.36365 .47906 Mdot
.6232 .50036 Mdot
.33138 .83142 Mdot
.39084 .64764 Mdot
.44497 .81599 Mdot
.64683 .62028 Mdot
.58294 .61777 Mdot
.58762 .39756 Mdot
.63871 .60654 Mdot
.6083 .3576 Mdot
.77569 .70264 Mdot
.32645 .72517 Mdot
.64166 .39106 Mdot
.58371 .39441 Mdot
.44872 .69709 Mdot
.25421 .38439 Mdot
.61539 .40243 Mdot
.56744 .61451 Mdot
.66658 .43478 Mdot
.65894 .6762 Mdot
.42263 .65792 Mdot
.23817 .47225 Mdot
.58652 .33656 Mdot
.35945 .67892 Mdot
.28599 .30115 Mdot
.57538 .34429 Mdot
.46917 .30317 Mdot
.44978 .38744 Mdot
.57933 .56182 Mdot
.32596 .48769 Mdot
.33473 .46966 Mdot
.54818 .58973 Mdot
.63123 .5802 Mdot
.64891 .37779 Mdot
.41325 .6397 Mdot
.42952 .37729 Mdot
.59523 .62133 Mdot
.44787 .68562 Mdot
.40743 .67055 Mdot
.62399 .36764 Mdot
.70475 .68046 Mdot
.41375 .62072 Mdot
.6119 .66783 Mdot
.59535 .56392 Mdot
.64381 .59443 Mdot
.64082 .67899 Mdot
.4716 .37914 Mdot
.22099 .45211 Mdot
.58601 .53937 Mdot
.35015 .74996 Mdot
.53429 .40414 Mdot
.64404 .65969 Mdot
.63308 .38043 Mdot
.50107 .36883 Mdot
.30556 .47792 Mdot
.48943 .60757 Mdot
.60847 .60558 Mdot
.48045 .20347 Mdot
.7752 .36386 Mdot
.334 .45988 Mdot
.57743 .40226 Mdot
.40236 .64201 Mdot
.63211 .58959 Mdot
.69183 .52829 Mdot
.62183 .56274 Mdot
.42173 .67184 Mdot
.35544 .51854 Mdot
.44918 .3865 Mdot
.51571 .1777 Mdot
.33602 .46952 Mdot
.60866 .41053 Mdot
.15028 .3872 Mdot
.62519 .35403 Mdot
.58004 .39592 Mdot
.68779 .53007 Mdot
.46613 .38334 Mdot
.36669 .85622 Mdot
.81891 .58652 Mdot
.61893 .53101 Mdot
.44802 .34279 Mdot
.62288 .39926 Mdot
.57387 .61089 Mdot
.65316 .36258 Mdot
.58606 .41838 Mdot
.5614 .60507 Mdot
.57495 .59605 Mdot
.47613 .22784 Mdot
.23073 .31632 Mdot
.40411 .64155 Mdot
.65013 .38848 Mdot
.51426 .53474 Mdot
.57232 .60397 Mdot
.60085 .57298 Mdot
.33719 .41836 Mdot
.42317 .64231 Mdot
.58148 .25169 Mdot
.64963 .61798 Mdot
.30792 .71247 Mdot
.55514 .63056 Mdot
.6559 .40396 Mdot
.44012 .33598 Mdot
.37436 .77018 Mdot
.41449 .38517 Mdot
.59979 .3636 Mdot
.40803 .63352 Mdot
.57109 .37104 Mdot
.42923 .71949 Mdot
.48819 .36794 Mdot
.61754 .41789 Mdot
.51964 .45647 Mdot
.46621 .35853 Mdot
.4839 .3636 Mdot
.67512 .50834 Mdot
.40058 .48718 Mdot
.36784 .66618 Mdot
.47681 .34383 Mdot
.52794 .53847 Mdot
.45767 .34627 Mdot
.82225 .51763 Mdot
.60814 .53939 Mdot
.5147 .66916 Mdot
.39057 .5624 Mdot
.64775 .52843 Mdot
.48673 .36055 Mdot
.39343 .62656 Mdot
.6565 .60581 Mdot
.61888 .37531 Mdot
.38943 .67589 Mdot
.48614 .40107 Mdot
.37919 .49435 Mdot
.63756 .37332 Mdot
.43351 .40227 Mdot
.63823 .4045 Mdot
.50095 .59125 Mdot
.84147 .47791 Mdot
.20362 .57211 Mdot
.46567 .55402 Mdot
.63823 .62652 Mdot
.23489 .36734 Mdot
.63494 .65464 Mdot
.63559 .57888 Mdot
.3419 .48532 Mdot
.49477 .65517 Mdot
.61044 .39269 Mdot
.49671 .17036 Mdot
.46718 .38857 Mdot
.35315 .76746 Mdot
.66508 .4266 Mdot
.63685 .63214 Mdot
.64044 .36351 Mdot
.62289 .35341 Mdot
.70074 .48252 Mdot
.3065 .47141 Mdot
.66141 .63191 Mdot
.66902 .6263 Mdot
.55923 .61403 Mdot
.4793 .37019 Mdot
.26739 .64751 Mdot
.31808 .50693 Mdot
.84125 .4349 Mdot
.34707 .51828 Mdot
.45193 .61309 Mdot
.61305 .36579 Mdot
.41292 .66497 Mdot
.59898 .57262 Mdot
.60733 .44272 Mdot
.59514 .36526 Mdot
.42832 .65559 Mdot
.38138 .63776 Mdot
.35999 .41052 Mdot
.46021 .38184 Mdot
.66545 .60958 Mdot
.58785 .55527 Mdot
.63274 .61123 Mdot
.64331 .58572 Mdot
.43995 .38795 Mdot
.65572 .59016 Mdot
.49825 .35634 Mdot
.52338 .6279 Mdot
.31294 .70169 Mdot
.50222 .48061 Mdot
.66584 .30633 Mdot
.61271 .37223 Mdot
.53751 .51362 Mdot
.64689 .66896 Mdot
.63394 .79426 Mdot
.67832 .28353 Mdot
.59948 .52912 Mdot
.37397 .47223 Mdot
.68656 .67858 Mdot
.323 .50252 Mdot
.79229 .29249 Mdot
.33627 .35987 Mdot
.26372 .28364 Mdot
.58141 .56818 Mdot
.32114 .42724 Mdot
.55288 .5159 Mdot
.63246 .64943 Mdot
.34683 .38376 Mdot
.60129 .31142 Mdot
.40533 .25657 Mdot
.40749 .62534 Mdot
.59572 .60214 Mdot
.57227 .41205 Mdot
.59798 .55092 Mdot
.60633 .57186 Mdot
.65551 .61469 Mdot
.46869 .32789 Mdot
.65685 .63375 Mdot
.64829 .5795 Mdot
.27831 .63278 Mdot
.50754 .75651 Mdot
.33872 .46562 Mdot
.81961 .43824 Mdot
.40566 .67351 Mdot
.64638 .37125 Mdot
.38329 .22851 Mdot
.45884 .37701 Mdot
.70151 .47357 Mdot
.6438 .58963 Mdot
.46162 .23461 Mdot
.45509 .41124 Mdot
.39493 .63548 Mdot
.31459 .50681 Mdot
.31187 .24054 Mdot
.35082 .48586 Mdot
.52538 .4497 Mdot
.34854 .50115 Mdot
.61203 .6721 Mdot
.64902 .37933 Mdot
.66322 .6058 Mdot
.47812 .34866 Mdot
.33424 .48727 Mdot
.50083 .70953 Mdot
.61656 .58396 Mdot
.35998 .48788 Mdot
.66335 .6051 Mdot
.54802 .67498 Mdot
.58957 .78466 Mdot
.36695 .52798 Mdot
.49325 .3402 Mdot
.47007 .35382 Mdot
.42152 .64702 Mdot
.63964 .3689 Mdot
.58831 .38905 Mdot
.46186 .36296 Mdot
.73603 .68326 Mdot
.62148 .54708 Mdot
.57253 .59856 Mdot
.35681 .76216 Mdot
.61514 .55147 Mdot
.45323 .7397 Mdot
.52753 .45218 Mdot
.61902 .36994 Mdot
.59338 .63261 Mdot
.64621 .61794 Mdot
.60325 .60785 Mdot
.50746 .62001 Mdot
.33656 .50829 Mdot
.5857 .54775 Mdot
.37796 .64166 Mdot
.41251 .45394 Mdot
.57588 .61861 Mdot
.56517 .63007 Mdot
.58832 .39106 Mdot
.45029 .83884 Mdot
.44132 .3784 Mdot
.38332 .51362 Mdot
.35166 .47218 Mdot
.24159 .47004 Mdot
.54268 .39315 Mdot
.52282 .45704 Mdot
.82807 .40184 Mdot
.26183 .42614 Mdot
.39109 .67116 Mdot
.40633 .52635 Mdot
.54568 .42081 Mdot
.38628 .49138 Mdot
.43551 .3832 Mdot
.60289 .53764 Mdot
.61176 .542 Mdot
.60038 .82885 Mdot
.65032 .62545 Mdot
.39957 .64548 Mdot
.49643 .36747 Mdot
.61671 .37758 Mdot
.39633 .63531 Mdot
.43822 .36445 Mdot
.63801 .38841 Mdot
.59801 .53206 Mdot
.59554 .53374 Mdot
.59295 .39985 Mdot
.61418 .41952 Mdot
.5941 .56852 Mdot
.30209 .54506 Mdot
.59956 .41658 Mdot
.62822 .41303 Mdot
.32625 .51102 Mdot
.32629 .49111 Mdot
.6009 .65628 Mdot
.447 .34676 Mdot
.65049 .58164 Mdot
.35029 .47986 Mdot
.41782 .64211 Mdot
.60914 .38845 Mdot
.63077 .62351 Mdot
.6008 .62338 Mdot
.39413 .66043 Mdot
.41044 .63035 Mdot
.38696 .63419 Mdot
.49084 .34402 Mdot
.62383 .60956 Mdot
.60906 .4015 Mdot
.45759 .384 Mdot
.36737 .64088 Mdot
.42535 .64012 Mdot
.35552 .45414 Mdot
.62975 .55772 Mdot
.41508 .4843 Mdot
.27414 .79483 Mdot
.38805 .74797 Mdot
.31788 .46503 Mdot
.31892 .45704 Mdot
.50127 .73736 Mdot
.43644 .58204 Mdot
.45367 .36533 Mdot
.43644 .64274 Mdot
.41463 .70329 Mdot
.64477 .55297 Mdot
.5714 .55784 Mdot
.68077 .61041 Mdot
.3821 .64237 Mdot
.48116 .6467 Mdot
.65459 .36891 Mdot
.72477 .35999 Mdot
.3988 .67655 Mdot
.37561 .46585 Mdot
.40077 .4806 Mdot
.3488 .5188 Mdot
.59878 .536 Mdot
.72227 .49701 Mdot
.5655 .47756 Mdot
.21768 .37987 Mdot
.48514 .35002 Mdot
.56321 .38644 Mdot
.69619 .26974 Mdot
.59666 .40298 Mdot
.332 .52543 Mdot
.38168 .66581 Mdot
.62363 .41882 Mdot
.43041 .3552 Mdot
.47112 .34037 Mdot
.33975 .51462 Mdot
.35598 .51148 Mdot
.37604 .5138 Mdot
.58003 .40468 Mdot
.61267 .36478 Mdot
.61243 .60518 Mdot
.60798 .38226 Mdot
.5536 .84851 Mdot
.38105 .68961 Mdot
.3006 .46679 Mdot
.44911 .35363 Mdot
.64192 .3948 Mdot
.61908 .58619 Mdot
.46829 .60701 Mdot
.59109 .30117 Mdot
.37408 .65564 Mdot
.55036 .79749 Mdot
.79172 .29526 Mdot
.66608 .61032 Mdot
.47535 .37143 Mdot
.5098 .8322 Mdot
.6106 .58352 Mdot
.36991 .50945 Mdot
.2484 .41678 Mdot
.34296 .54247 Mdot
.65012 .57019 Mdot
.66828 .57808 Mdot
.43895 .33427 Mdot
.81507 .39219 Mdot
.61542 .60191 Mdot
.57672 .25966 Mdot
.42761 .33959 Mdot
.31986 .51009 Mdot
.46644 .15556 Mdot
.22056 .53171 Mdot
.54574 .71047 Mdot
.32771 .5135 Mdot
.63239 .56973 Mdot
.32645 .50573 Mdot
.37385 .64501 Mdot
.35369 .52757 Mdot
.65956 .37372 Mdot
.32331 .46938 Mdot
.58807 .61284 Mdot
.61778 .40368 Mdot
.45232 .36078 Mdot
.38389 .79489 Mdot
.32415 .63571 Mdot
.34585 .50438 Mdot
.38363 .51671 Mdot
.6055 .63215 Mdot
.55073 .23743 Mdot
.55483 .54966 Mdot
.5757 .57799 Mdot
.47833 .38502 Mdot
.63598 .36322 Mdot
.45114 .32616 Mdot
.61545 .64181 Mdot
.20085 .51471 Mdot
.44234 .3716 Mdot
.45492 .22806 Mdot
.38692 .66653 Mdot
.44041 .44949 Mdot
.62542 .58586 Mdot
.46042 .33326 Mdot
.62422 .60853 Mdot
.65601 .37315 Mdot
.48255 .4467 Mdot
.38688 .28584 Mdot
.47849 .35562 Mdot
.49252 .19226 Mdot
.42633 .59608 Mdot
.56465 .52154 Mdot
.43483 .35956 Mdot
.4669 .65996 Mdot
.38909 .48545 Mdot
.40352 .6706 Mdot
.38435 .62312 Mdot
.3834 .67623 Mdot
.55885 .55044 Mdot
.53924 .57009 Mdot
.36968 .64107 Mdot
.42729 .35829 Mdot
.41186 .62202 Mdot
.55961 .41426 Mdot
.46818 .19031 Mdot
.40725 .65708 Mdot
.59879 .59418 Mdot
.53861 .6084 Mdot
.51292 .75161 Mdot
.38613 .40754 Mdot
.28304 .26985 Mdot
.63385 .26904 Mdot
.61553 .55868 Mdot
.60582 .34474 Mdot
.6464 .40304 Mdot
.48371 .82649 Mdot
.43232 .74693 Mdot
.35226 .73759 Mdot
.58243 .39553 Mdot
.33931 .32173 Mdot
.6286 .3684 Mdot
.64322 .62799 Mdot
.57372 .60601 Mdot
.5795 .378 Mdot
.28371 .67735 Mdot
.36272 .33113 Mdot
.57126 .18604 Mdot
.63417 .41009 Mdot
.43729 .3488 Mdot
.48856 .38114 Mdot
.48464 .36516 Mdot
.45617 .80304 Mdot
.61815 .35641 Mdot
.62229 .61499 Mdot
.34758 .4751 Mdot
.59248 .54263 Mdot
.469 .36449 Mdot
.49423 .17027 Mdot
.59724 .37767 Mdot
.58462 .57788 Mdot
.65973 .70349 Mdot
.37021 .50352 Mdot
.39421 .66554 Mdot
.60686 .69489 Mdot
.36388 .73619 Mdot
.47952 .37724 Mdot
.59224 .35915 Mdot
.30077 .37622 Mdot
.44613 .21938 Mdot
.5684 .55135 Mdot
.65036 .65154 Mdot
.68806 .2265 Mdot
.3582 .72152 Mdot
.66427 .58353 Mdot
.38974 .50045 Mdot
.32252 .34438 Mdot
.60865 .62287 Mdot
.64862 .39693 Mdot
.3985 .61891 Mdot
.37938 .66761 Mdot
.59913 .65076 Mdot
.45342 .56852 Mdot
.45318 .42971 Mdot
.64932 .60187 Mdot
.61682 .66867 Mdot
.32311 .51255 Mdot
.25907 .42836 Mdot
.34652 .74813 Mdot
.4079 .63213 Mdot
.6626 .60364 Mdot
.32764 .28408 Mdot
.58321 .38054 Mdot
.32566 .46513 Mdot
.48965 .35652 Mdot
.53419 .65326 Mdot
.32086 .51389 Mdot
.61116 .62432 Mdot
.6587 .60677 Mdot
.47243 .33349 Mdot
.65643 .40298 Mdot
.38046 .6467 Mdot
.34603 .47285 Mdot
.40333 .62767 Mdot
.62519 .35849 Mdot
.60479 .37677 Mdot
.68951 .66729 Mdot
.64345 .53562 Mdot
.3375 .49793 Mdot
.58978 .63668 Mdot
.28217 .45839 Mdot
.81458 .36781 Mdot
.45113 .40322 Mdot
.66853 .60669 Mdot
.65918 .40698 Mdot
.47883 .36112 Mdot
.57754 .61016 Mdot
.66307 .21442 Mdot
.57148 .60465 Mdot
.52822 .37882 Mdot
.19904 .57388 Mdot
.39468 .62855 Mdot
.71756 .35425 Mdot
.58119 .22469 Mdot
.60896 .55139 Mdot
.3686 .47405 Mdot
.66103 .656 Mdot
.45128 .37305 Mdot
.61021 .36827 Mdot
.8494 .41737 Mdot
.46177 .34566 Mdot
.59071 .55885 Mdot
.39562 .63733 Mdot
.61061 .35453 Mdot
.44495 .64278 Mdot
.33177 .70162 Mdot
.54871 .5484 Mdot
.57656 .63231 Mdot
.64963 .59007 Mdot
.19938 .46305 Mdot
.38178 .51491 Mdot
.63093 .40046 Mdot
.47615 .37206 Mdot
.46061 .36502 Mdot
.34067 .51304 Mdot
.44894 .26173 Mdot
.44212 .44826 Mdot
.27012 .77662 Mdot
.33052 .49638 Mdot
.38127 .67899 Mdot
.56792 .24851 Mdot
.36473 .47061 Mdot
.3618 .49195 Mdot
.32205 .50845 Mdot
.41172 .34815 Mdot
.63497 .38781 Mdot
.60404 .62566 Mdot
.65232 .39742 Mdot
.63556 .57041 Mdot
.53274 .39704 Mdot
.48003 .35364 Mdot
.60158 .36947 Mdot
.67451 .22691 Mdot
.76886 .59148 Mdot
.60414 .58711 Mdot
.70341 .27123 Mdot
.63629 .53704 Mdot
.47494 .7265 Mdot
.66761 .56297 Mdot
.35134 .50769 Mdot
.59134 .49902 Mdot
.55407 .60601 Mdot
.43845 .82398 Mdot
.44745 .35394 Mdot
.3796 .47131 Mdot
.64111 .5457 Mdot
.58306 .66016 Mdot
.5758 .38877 Mdot
.62589 .41707 Mdot
.37581 .63055 Mdot
.57553 .77114 Mdot
.45002 .36163 Mdot
.81455 .57114 Mdot
.60958 .55774 Mdot
.23865 .62036 Mdot
.71029 .38109 Mdot
.57712 .607 Mdot
.59996 .22863 Mdot
.71535 .48753 Mdot
.63017 .58837 Mdot
.50338 .52651 Mdot
.45987 .33683 Mdot
.19968 .52781 Mdot
.56794 .60913 Mdot
.37427 .50253 Mdot
.62058 .36385 Mdot
.65254 .3653 Mdot
.37132 .63919 Mdot
.68014 .76399 Mdot
.45702 .3261 Mdot
.60543 .3681 Mdot
.61726 .57926 Mdot
.47191 .38087 Mdot
.33262 .47799 Mdot
.64137 .63379 Mdot
.43945 .75289 Mdot
.61214 .38118 Mdot
.57381 .62416 Mdot
.55584 .27021 Mdot
.54583 .73656 Mdot
.1641 .45418 Mdot
.47675 .37368 Mdot
.4208 .63806 Mdot
.66221 .65344 Mdot
.73085 .67411 Mdot
.58489 .52842 Mdot
.51066 .66239 Mdot
.54904 .39185 Mdot
.42036 .63506 Mdot
.59583 .58371 Mdot
.61062 .61758 Mdot
.40467 .56334 Mdot
.41274 .63598 Mdot
.58446 .5577 Mdot
.53791 .63058 Mdot
.63527 .39145 Mdot
.32905 .53034 Mdot
.62069 .3815 Mdot
.60434 .59433 Mdot
.6622 .55069 Mdot
.59456 .4079 Mdot
.77504 .30832 Mdot
.36295 .65434 Mdot
.44354 .3788 Mdot
.60009 .52025 Mdot
.57992 .54712 Mdot
.20748 .6547 Mdot
.35084 .45807 Mdot
.27602 .3505 Mdot
.25653 .58211 Mdot
.29707 .3005 Mdot
.22074 .53351 Mdot
.1965 .34159 Mdot
.32751 .7194 Mdot
.64889 .6396 Mdot
.66623 .3363 Mdot
.55303 .47906 Mdot
.48748 .35493 Mdot
.80714 .46896 Mdot
.61533 .5575 Mdot
.60866 .57181 Mdot
.3236 .46509 Mdot
.44067 .24601 Mdot
.34923 .73848 Mdot
.45601 .59313 Mdot
.38077 .6489 Mdot
.64927 .38798 Mdot
.58959 .6266 Mdot
.50737 .50421 Mdot
.33925 .46482 Mdot
.24389 .63002 Mdot
.58604 .58072 Mdot
.62757 .79414 Mdot
.56413 .31436 Mdot
.4672 .38048 Mdot
.35578 .47113 Mdot
.35788 .73049 Mdot
.63346 .55969 Mdot
.49088 .35834 Mdot
.61729 .59655 Mdot
.32283 .55106 Mdot
.60594 .64003 Mdot
.40876 .66014 Mdot
.64613 .62188 Mdot
.45645 .61643 Mdot
.13929 .43114 Mdot
.42604 .67365 Mdot
.64305 .35658 Mdot
.29412 .47883 Mdot
.33649 .50582 Mdot
.61765 .41907 Mdot
.33805 .50367 Mdot
.7016 .44357 Mdot
.76983 .45726 Mdot
.38131 .65999 Mdot
.58339 .65759 Mdot
.4066 .65338 Mdot
.338 .4579 Mdot
.62597 .56033 Mdot
.80912 .33826 Mdot
.33733 .49045 Mdot
.21138 .62385 Mdot
.45653 .34937 Mdot
.36566 .46173 Mdot
.56927 .60815 Mdot
.30424 .38001 Mdot
.338 .46801 Mdot
.39159 .28555 Mdot
.60445 .60762 Mdot
.6102 .37541 Mdot
.61304 .62105 Mdot
.61392 .52552 Mdot
.38882 .51847 Mdot
.64727 .5737 Mdot
.43827 .36404 Mdot
.59364 .41569 Mdot
.37554 .19488 Mdot
.59528 .31667 Mdot
.59617 .54765 Mdot
.61506 .58022 Mdot
.56917 .38514 Mdot
.58195 .55073 Mdot
.44016 .38791 Mdot
.58269 .88928 Mdot
.38748 .66689 Mdot
.3919 .50746 Mdot
.21893 .53143 Mdot
.60181 .53022 Mdot
.65661 .59785 Mdot
.64156 .20127 Mdot
.21143 .54329 Mdot
.43581 .36132 Mdot
.55151 .59362 Mdot
.33482 .47263 Mdot
.39653 .63951 Mdot
.42548 .36217 Mdot
.6432 .59545 Mdot
.59763 .57597 Mdot
.42071 .64225 Mdot
.64843 .48601 Mdot
.42507 .79049 Mdot
.47728 .33666 Mdot
.59845 .50394 Mdot
.30697 .44762 Mdot
.63093 .55341 Mdot
.47777 .81044 Mdot
.6202 .41676 Mdot
.47825 .38089 Mdot
.23754 .37876 Mdot
.66033 .57896 Mdot
.44197 .33553 Mdot
.44887 .36048 Mdot
.55243 .58962 Mdot
.65669 .41489 Mdot
.5929 .42138 Mdot
.63972 .40311 Mdot
.58421 .84926 Mdot
.53025 .71594 Mdot
.37599 .51374 Mdot
.46076 .33653 Mdot
.3577 .53208 Mdot
.39698 .68702 Mdot
.54106 .44534 Mdot
.37537 .52395 Mdot
.63344 .41878 Mdot
.29562 .4822 Mdot
.60661 .61491 Mdot
.45306 .36231 Mdot
.38606 .49684 Mdot
.61918 .53282 Mdot
.52643 .22974 Mdot
.38817 .37582 Mdot
.42246 .63118 Mdot
.39335 .61929 Mdot
.57621 .61615 Mdot
.30491 .48339 Mdot
.5959 .56853 Mdot
.45663 .39717 Mdot
.54862 .2408 Mdot
.58865 .52654 Mdot
.34467 .50598 Mdot
.58514 .35272 Mdot
.36247 .7335 Mdot
.56699 .52547 Mdot
.59852 .59302 Mdot
.63961 .56955 Mdot
.61787 .59679 Mdot
.40442 .24811 Mdot
.43256 .39707 Mdot
.65568 .30558 Mdot
.21588 .46215 Mdot
.59624 .3859 Mdot
.62358 .43184 Mdot
.38576 .7526 Mdot
.44801 .29612 Mdot
.44833 .34426 Mdot
.6382 .58105 Mdot
.5062 .30694 Mdot
.48525 .16898 Mdot
.73969 .25742 Mdot
.36034 .61613 Mdot
.34954 .45992 Mdot
.58628 .36297 Mdot
.35092 .46665 Mdot
.6297 .56675 Mdot
.66788 .64613 Mdot
.18872 .3462 Mdot
.43921 .32378 Mdot
.37971 .65997 Mdot
.63863 .57204 Mdot
.53765 .7173 Mdot
.35393 .47885 Mdot
.3991 .50046 Mdot
.57751 .56691 Mdot
.649 .4169 Mdot
.16285 .5515 Mdot
.4728 .37775 Mdot
.62683 .26488 Mdot
.56117 .50526 Mdot
.62272 .28568 Mdot
.47111 .36805 Mdot
.33304 .68602 Mdot
.31701 .46723 Mdot
.67668 .44663 Mdot
.59438 .38553 Mdot
.38993 .67532 Mdot
.64912 .65612 Mdot
.58592 .38998 Mdot
.31786 .50883 Mdot
.60937 .37135 Mdot
.65397 .61798 Mdot
.42123 .36449 Mdot
.36462 .47811 Mdot
.46589 .31616 Mdot
.65066 .42096 Mdot
.40529 .63238 Mdot
.4403 .53506 Mdot
.79744 .52201 Mdot
.71256 .48349 Mdot
.58953 .5425 Mdot
.51571 .49584 Mdot
.62624 .6138 Mdot
.6014 .43165 Mdot
.61826 .58912 Mdot
.56209 .41087 Mdot
.36549 .47339 Mdot
.56728 .60047 Mdot
.64934 .59712 Mdot
.80103 .43253 Mdot
.58446 .58913 Mdot
.63332 .64146 Mdot
.63364 .58755 Mdot
.61718 .45313 Mdot
.57536 .6502 Mdot
.63573 .38174 Mdot
.31127 .66503 Mdot
.36254 .49476 Mdot
.39747 .62022 Mdot
.4034 .67751 Mdot
.51667 .67506 Mdot
.28095 .53892 Mdot
.43748 .25415 Mdot
.62218 .38636 Mdot
.44189 .36324 Mdot
.61997 .59235 Mdot
.20675 .37202 Mdot
.29009 .43634 Mdot
.32618 .47728 Mdot
.59536 .31632 Mdot
.6204 .50345 Mdot
.18785 .48209 Mdot
.57892 .62984 Mdot
.61893 .82051 Mdot
.63943 .53058 Mdot
.61142 .63985 Mdot
.37359 .52765 Mdot
.37862 .69233 Mdot
.57453 .56684 Mdot
.57607 .38698 Mdot
.41058 .66254 Mdot
.67292 .35165 Mdot
.40703 .45728 Mdot
.31839 .65876 Mdot
.78556 .43107 Mdot
.62173 .6056 Mdot
.36641 .47937 Mdot
.63921 .37392 Mdot
.34416 .74577 Mdot
.45577 .38436 Mdot
.49747 .32858 Mdot
.52164 .52464 Mdot
.72674 .27459 Mdot
.40623 .67196 Mdot
.66516 .50055 Mdot
.58919 .61457 Mdot
.35691 .59885 Mdot
.57411 .54787 Mdot
.48983 .17157 Mdot
.38709 .68323 Mdot
.61572 .42791 Mdot
.43821 .34915 Mdot
.64917 .40107 Mdot
.71476 .49942 Mdot
.38254 .55396 Mdot
.47929 .48465 Mdot
.35354 .48664 Mdot
.42424 .45386 Mdot
.62393 .40324 Mdot
.66258 .5982 Mdot
.26541 .77432 Mdot
.62566 .41472 Mdot
.59807 .3606 Mdot
.83121 .43141 Mdot
.81388 .35866 Mdot
.60351 .4968 Mdot
.58937 .4054 Mdot
.35524 .49127 Mdot
.40608 .63966 Mdot
.62695 .62078 Mdot
.61287 .60948 Mdot
.58733 .39306 Mdot
.39252 .51216 Mdot
.73819 .60292 Mdot
.35578 .51033 Mdot
.63832 .39077 Mdot
.3685 .49752 Mdot
.28667 .39221 Mdot
.38442 .48223 Mdot
.57998 .54779 Mdot
.61883 .58998 Mdot
.2516 .52153 Mdot
.60539 .37678 Mdot
.64894 .60451 Mdot
.61738 .63034 Mdot
.61132 .40098 Mdot
.38201 .70504 Mdot
.73432 .58479 Mdot
.614 .54738 Mdot
.59315 .60402 Mdot
.41934 .63444 Mdot
.5472 .45537 Mdot
.65955 .74248 Mdot
.65628 .60598 Mdot
.37319 .68009 Mdot
.57897 .39619 Mdot
.5897 .57123 Mdot
.42367 .19947 Mdot
.32421 .34202 Mdot
.66377 .58749 Mdot
.38752 .48205 Mdot
.55657 .61042 Mdot
.16577 .47532 Mdot
.57536 .57737 Mdot
.61695 .39757 Mdot
.61957 .36009 Mdot
.81605 .56231 Mdot
.61341 .41183 Mdot
.32536 .49128 Mdot
.46745 .36102 Mdot
.49559 .18052 Mdot
.33331 .47735 Mdot
.58407 .52344 Mdot
.82405 .57862 Mdot
.65175 .63188 Mdot
.60121 .52691 Mdot
.177 .55407 Mdot
.33746 .47633 Mdot
.64562 .36531 Mdot
.43092 .5672 Mdot
.68446 .59119 Mdot
.4809 .37664 Mdot
.62935 .66456 Mdot
.62544 .54549 Mdot
.2005 .5821 Mdot
.35935 .28932 Mdot
.48045 .38746 Mdot
.65724 .63941 Mdot
.65655 .60474 Mdot
.39733 .53159 Mdot
.61992 .58325 Mdot
.41012 .64276 Mdot
.62827 .35771 Mdot
.36973 .47127 Mdot
.39148 .65847 Mdot
.6131 .55419 Mdot
.38357 .63988 Mdot
.38249 .49979 Mdot
.48845 .37094 Mdot
.632 .56389 Mdot
.42343 .65639 Mdot
.38246 .64413 Mdot
.63235 .61376 Mdot
.61305 .3674 Mdot
.63573 .5263 Mdot
.5826 .57735 Mdot
.63344 .62398 Mdot
.5888 .3874 Mdot
.65903 .16831 Mdot
.57161 .59183 Mdot
.41085 .58751 Mdot
.59921 .3621 Mdot
.42151 .48601 Mdot
.3649 .46687 Mdot
.61818 .54213 Mdot
.48542 .37924 Mdot
.46857 .33539 Mdot
.32628 .51581 Mdot
.60635 .35416 Mdot
.25153 .56671 Mdot
.5721 .36347 Mdot
.67997 .58191 Mdot
.67148 .60722 Mdot
.78141 .64372 Mdot
.26312 .28045 Mdot
.65383 .37913 Mdot
.40071 .46639 Mdot
.45805 .5845 Mdot
.45141 .33591 Mdot
.38221 .46942 Mdot
.58895 .3602 Mdot
.61385 .35572 Mdot
.6187 .37193 Mdot
.38272 .67155 Mdot
.25436 .52237 Mdot
.66071 .39078 Mdot
.63911 .42362 Mdot
.60451 .61015 Mdot
.65603 .60266 Mdot
.39281 .72628 Mdot
.47715 .77008 Mdot
.39372 .62527 Mdot
.34735 .51681 Mdot
.50845 .88148 Mdot
.45404 .39638 Mdot
.79482 .40831 Mdot
.59237 .52677 Mdot
.25884 .79566 Mdot
.5723 .61674 Mdot
.62024 .57967 Mdot
.59155 .41322 Mdot
.42626 .64402 Mdot
.40231 .66155 Mdot
.63144 .40329 Mdot
.60754 .43379 Mdot
.41045 .64395 Mdot
.64765 .25212 Mdot
.449 .18292 Mdot
.37098 .56071 Mdot
.60585 .39509 Mdot
.79359 .506 Mdot
.48867 .34675 Mdot
.63772 .33425 Mdot
.43809 .39416 Mdot
.3592 .48386 Mdot
.30623 .48509 Mdot
.4807 .36928 Mdot
.6057 .60622 Mdot
.37667 .51648 Mdot
.65463 .63497 Mdot
.67043 .28786 Mdot
.74356 .54662 Mdot
.23233 .525 Mdot
.57597 .63829 Mdot
.32408 .67713 Mdot
.41056 .3012 Mdot
.59776 .55674 Mdot
.33785 .26075 Mdot
.37886 .65389 Mdot
.65836 .35327 Mdot
.46501 .3921 Mdot
.15452 .47846 Mdot
.64016 .56498 Mdot
.61479 .39418 Mdot
.44523 .35379 Mdot
.52001 .64564 Mdot
.57037 .25619 Mdot
.63766 .56995 Mdot
.29577 .80461 Mdot
.6336 .44795 Mdot
.37358 .47432 Mdot
.71785 .70537 Mdot
.65608 .38691 Mdot
.35915 .62243 Mdot
.22837 .44987 Mdot
.6938 .24591 Mdot
.64684 .3725 Mdot
.37723 .46396 Mdot
.64424 .39681 Mdot
.40745 .63375 Mdot
.61928 .34466 Mdot
.35491 .47458 Mdot
.58872 .5853 Mdot
.34409 .511 Mdot
.37817 .63032 Mdot
.43534 .78889 Mdot
.4825 .3854 Mdot
.38045 .4723 Mdot
.47426 .3494 Mdot
.55827 .75042 Mdot
.20311 .4766 Mdot
.44743 .38535 Mdot
.70575 .68313 Mdot
.65847 .57199 Mdot
.65661 .3971 Mdot
.33319 .51131 Mdot
.24462 .43668 Mdot
.44076 .5514 Mdot
.59528 .39412 Mdot
.36674 .51464 Mdot
.5294 .50781 Mdot
.71027 .69031 Mdot
.54527 .59233 Mdot
.56177 .76363 Mdot
.60648 .39907 Mdot
.36464 .4572 Mdot
.35838 .76453 Mdot
.63842 .41564 Mdot
.32989 .49897 Mdot
.43881 .34398 Mdot
.46383 .36765 Mdot
.58243 .55676 Mdot
.46387 .31248 Mdot
.35792 .52092 Mdot
.39982 .32045 Mdot
.58064 .38555 Mdot
.50528 .62411 Mdot
.40531 .67939 Mdot
.35964 .5017 Mdot
.64985 .62639 Mdot
.66545 .3689 Mdot
.29674 .37011 Mdot
.74895 .60937 Mdot
.42147 .83852 Mdot
.34125 .51303 Mdot
.61245 .35734 Mdot
.61275 .39074 Mdot
.56945 .52477 Mdot
.4632 .55667 Mdot
.25152 .56 Mdot
.59496 .70274 Mdot
.50895 .65286 Mdot
.32912 .52859 Mdot
.35316 .54095 Mdot
.64834 .55081 Mdot
.62588 .60211 Mdot
.44649 .33847 Mdot
.59036 .58989 Mdot
.60182 .42147 Mdot
.5814 .55513 Mdot
.47547 .3681 Mdot
.34785 .48648 Mdot
.62499 .5619 Mdot
.39554 .62741 Mdot
.49404 .36903 Mdot
.43697 .33552 Mdot
.35264 .50398 Mdot
.58583 .38758 Mdot
.41609 .69087 Mdot
.35609 .51181 Mdot
.62089 .60534 Mdot
.51828 .34496 Mdot
.63757 .62726 Mdot
.69223 .33408 Mdot
.63755 .41739 Mdot
.35732 .46808 Mdot
.57906 .38692 Mdot
.46878 .34337 Mdot
.21904 .45754 Mdot
.60913 .59195 Mdot
.33029 .49379 Mdot
.26445 .4834 Mdot
.69177 .3749 Mdot
.57133 .40719 Mdot
.41435 .28716 Mdot
.61385 .43319 Mdot
.31207 .49827 Mdot
.82699 .47221 Mdot
.40092 .6738 Mdot
.32759 .47506 Mdot
.33301 .22949 Mdot
.34046 .49756 Mdot
.5809 .5937 Mdot
.57929 .61795 Mdot
.37526 .4742 Mdot
.42164 .64823 Mdot
.33077 .73085 Mdot
.30938 .51805 Mdot
.64546 .36666 Mdot
.72074 .29742 Mdot
.3395 .79156 Mdot
.45916 .30792 Mdot
.44137 .34693 Mdot
.68505 .58414 Mdot
.62021 .63887 Mdot
.43324 .38732 Mdot
.44361 .32579 Mdot
.37279 .65687 Mdot
.32128 .50475 Mdot
.61037 .45632 Mdot
.47989 .3301 Mdot
.66969 .67512 Mdot
.28349 .54492 Mdot
.55298 .5503 Mdot
.56088 .49819 Mdot
.57265 .55404 Mdot
.52373 .66993 Mdot
.47632 .37016 Mdot
.59351 .63011 Mdot
.54845 .58041 Mdot
.48229 .38092 Mdot
.40937 .64035 Mdot
.44985 .2772 Mdot
.37228 .49141 Mdot
.50707 .14712 Mdot
.60747 .63591 Mdot
.5789 .59298 Mdot
.48565 .35242 Mdot
.27075 .61077 Mdot
.5969 .37554 Mdot
.64271 .41368 Mdot
.38388 .5118 Mdot
.44739 .52784 Mdot
.61369 .54208 Mdot
.58886 .56431 Mdot
.37446 .48526 Mdot
.36967 .46401 Mdot
.37823 .36674 Mdot
.59778 .6203 Mdot
.44868 .34997 Mdot
.45806 .624 Mdot
.47703 .36899 Mdot
.64334 .62745 Mdot
.57985 .60024 Mdot
.58027 .54789 Mdot
.65107 .62491 Mdot
.43017 .34369 Mdot
.59367 .62822 Mdot
.54522 .62009 Mdot
.59604 .37255 Mdot
.64593 .57809 Mdot
.52045 .66278 Mdot
.59558 .59696 Mdot
.40718 .64079 Mdot
.70536 .66491 Mdot
.63848 .56441 Mdot
.60838 .53912 Mdot
.30162 .51622 Mdot
.6004 .58224 Mdot
.45387 .3969 Mdot
.60214 .38391 Mdot
.46255 .33678 Mdot
.47945 .34053 Mdot
.33523 .52161 Mdot
.36977 .64174 Mdot
.60469 .53142 Mdot
.37528 .65707 Mdot
.57382 .5387 Mdot
.66321 .58374 Mdot
.23275 .47156 Mdot
.63203 .81351 Mdot
.44051 .80084 Mdot
.60951 .5935 Mdot
.33599 .48284 Mdot
.36147 .4665 Mdot
.68136 .38131 Mdot
.54547 .58058 Mdot
.4305 .37955 Mdot
.46322 .33399 Mdot
.44787 .75257 Mdot
.20171 .56097 Mdot
.40785 .64069 Mdot
.52225 .47576 Mdot
.66379 .62826 Mdot
.61878 .6285 Mdot
.63986 .63534 Mdot
.36027 .53068 Mdot
.45202 .59987 Mdot
.32871 .47536 Mdot
.58051 .31042 Mdot
.48114 .36132 Mdot
.64269 .5681 Mdot
.56337 .42557 Mdot
.62878 .41723 Mdot
.60262 .38332 Mdot
.43397 .34272 Mdot
.2858 .48931 Mdot
.39264 .74284 Mdot
.77295 .28275 Mdot
.63474 .45109 Mdot
.42398 .63074 Mdot
.59903 .55299 Mdot
.34774 .49232 Mdot
.64178 .40345 Mdot
.41044 .622 Mdot
.66421 .60009 Mdot
.25411 .5212 Mdot
.61077 .59806 Mdot
.55737 .47714 Mdot
.62522 .36679 Mdot
.47745 .17716 Mdot
.63209 .35311 Mdot
.4935 .37236 Mdot
.46474 .39045 Mdot
.57878 .61198 Mdot
.75224 .67574 Mdot
.6516 .403 Mdot
.40684 .34746 Mdot
.38288 .67954 Mdot
.31316 .36298 Mdot
.41132 .63774 Mdot
.36881 .47299 Mdot
.4099 .66536 Mdot
.35806 .47328 Mdot
.44406 .77058 Mdot
.57544 .42557 Mdot
.38769 .66209 Mdot
.32217 .55413 Mdot
.54446 .57488 Mdot
.4031 .62286 Mdot
.68392 .60379 Mdot
.70719 .34768 Mdot
.37655 .49055 Mdot
.39901 .67843 Mdot
.66208 .60005 Mdot
.19034 .37264 Mdot
.43711 .36746 Mdot
.4329 .3838 Mdot
.67988 .58461 Mdot
.33473 .52599 Mdot
.57675 .37981 Mdot
.42633 .22239 Mdot
.48043 .39774 Mdot
.57389 .60356 Mdot
.5758 .56434 Mdot
.62874 .42998 Mdot
.55517 .35523 Mdot
.58037 .60894 Mdot
.67799 .68526 Mdot
.59225 .62067 Mdot
.43373 .34924 Mdot
.64982 .3976 Mdot
.60822 .38758 Mdot
.36987 .51482 Mdot
.60263 .41671 Mdot
.66639 .43088 Mdot
.52367 .33474 Mdot
.68047 .56233 Mdot
.46448 .34604 Mdot
.55108 .32487 Mdot
.58377 .31056 Mdot
.28191 .2728 Mdot
.63631 .42915 Mdot
.56799 .56734 Mdot
.58305 .37997 Mdot
.39901 .63813 Mdot
.61088 .37758 Mdot
.58475 .36499 Mdot
.59639 .56446 Mdot
.63218 .56993 Mdot
.34435 .47874 Mdot
.45897 .56472 Mdot
.58739 .37884 Mdot
.58065 .6225 Mdot
.62515 .64247 Mdot
.64356 .6386 Mdot
.48791 .42815 Mdot
.65292 .38415 Mdot
.79195 .37022 Mdot
.4684 .67829 Mdot
.58667 .38022 Mdot
.15127 .52385 Mdot
.25726 .4276 Mdot
.32811 .4579 Mdot
.49265 .33678 Mdot
.59923 .62127 Mdot
.35634 .46256 Mdot
.62957 .56632 Mdot
.55974 .49889 Mdot
.60163 .57438 Mdot
.41239 .6456 Mdot
.64719 .64025 Mdot
.31103 .50001 Mdot
.35094 .51227 Mdot
.57331 .58678 Mdot
.61956 .56194 Mdot
.41946 .78073 Mdot
.62255 .43704 Mdot
.6022 .37402 Mdot
.2533 .58539 Mdot
.38583 .64978 Mdot
.47973 .37852 Mdot
.62623 .58754 Mdot
.34293 .52559 Mdot
.34738 .51267 Mdot
.65477 .38914 Mdot
.3713 .50734 Mdot
.47287 .37661 Mdot
.61117 .5893 Mdot
.43402 .38755 Mdot
.3812 .67057 Mdot
.65023 .38758 Mdot
.6418 .57363 Mdot
.60409 .61008 Mdot
.62019 .36008 Mdot
.62967 .54145 Mdot
.41921 .63524 Mdot
.33946 .49987 Mdot
.64569 .37558 Mdot
.46656 .36271 Mdot
.3629 .47159 Mdot
.62329 .62395 Mdot
.47579 .86986 Mdot
.5835 .59695 Mdot
.60547 .62207 Mdot
.32697 .22697 Mdot
.65586 .63649 Mdot
.33627 .51273 Mdot
.62332 .42684 Mdot
.589 .64386 Mdot
.51163 .68009 Mdot
.71089 .21547 Mdot
.32495 .48054 Mdot
.59579 .55256 Mdot
.21437 .33316 Mdot
.5866 .56169 Mdot
.78577 .61555 Mdot
.35858 .57522 Mdot
.43365 .48321 Mdot
.62476 .52472 Mdot
.45925 .37635 Mdot
.34231 .47841 Mdot
.36884 .47533 Mdot
.753 .33509 Mdot
.59345 .56422 Mdot
.54192 .48207 Mdot
.65657 .58434 Mdot
.46847 .36878 Mdot
.43723 .7359 Mdot
.34417 .51398 Mdot
.46681 .82893 Mdot
.6221 .61405 Mdot
.65228 .36671 Mdot
.2963 .47849 Mdot
.29085 .40755 Mdot
.63242 .62325 Mdot
.37548 .64806 Mdot
.49061 .34158 Mdot
.61232 .64783 Mdot
.46455 .35039 Mdot
.63652 .62486 Mdot
.69232 .66363 Mdot
.71401 .72156 Mdot
.6159 .36906 Mdot
.43935 .34597 Mdot
.50845 .3321 Mdot
.56182 .60872 Mdot
.64609 .37305 Mdot
.59407 .38701 Mdot
.37257 .65121 Mdot
.49349 .47153 Mdot
.53765 .26775 Mdot
.76744 .56274 Mdot
.74766 .32009 Mdot
.29197 .48223 Mdot
.37318 .30961 Mdot
.63981 .61821 Mdot
.236 .60608 Mdot
.47022 .39304 Mdot
.58151 .5885 Mdot
.69737 .40954 Mdot
.63438 .40656 Mdot
.59075 .60734 Mdot
.40757 .65097 Mdot
.25502 .62751 Mdot
.25029 .63438 Mdot
.22199 .42116 Mdot
.3552 .48604 Mdot
.66464 .65023 Mdot
.6923 .5741 Mdot
.38963 .50804 Mdot
.6409 .55228 Mdot
.33297 .50296 Mdot
.6773 .26268 Mdot
.4168 .62657 Mdot
.65241 .37454 Mdot
.27022 .42231 Mdot
.61282 .53748 Mdot
.67205 .61049 Mdot
.39124 .61715 Mdot
.6312 .60283 Mdot
.67149 .76892 Mdot
.27246 .45151 Mdot
.38594 .50246 Mdot
.61794 .37123 Mdot
.59993 .536 Mdot
.50695 .4698 Mdot
.58342 .57361 Mdot
.76447 .49085 Mdot
.60454 .53804 Mdot
.55249 .26107 Mdot
.61924 .36411 Mdot
.468 .34948 Mdot
.5579 .60095 Mdot
.60808 .57491 Mdot
.46187 .64488 Mdot
.64498 .53539 Mdot
.57958 .62548 Mdot
.57227 .3878 Mdot
.64109 .40732 Mdot
.63493 .38269 Mdot
.31776 .47415 Mdot
.20128 .57224 Mdot
.45532 .34257 Mdot
.56988 .64063 Mdot
.4725 .32373 Mdot
.74177 .64368 Mdot
.42013 .62718 Mdot
.22404 .35334 Mdot
.64307 .58983 Mdot
.62901 .38764 Mdot
.33536 .28575 Mdot
.57968 .40347 Mdot
.5009 .50083 Mdot
.45049 .36182 Mdot
.62962 .40961 Mdot
.6156 .57661 Mdot
.44758 .57053 Mdot
.19622 .40618 Mdot
.47295 .34126 Mdot
.57641 .53283 Mdot
.34438 .45923 Mdot
.2236 .50893 Mdot
.45649 .86293 Mdot
.43579 .36452 Mdot
.51305 .34203 Mdot
.59346 .56204 Mdot
.62791 .4195 Mdot
.46367 .37755 Mdot
.44006 .3782 Mdot
.37282 .50741 Mdot
.63436 .57208 Mdot
.63733 .57548 Mdot
.3102 .48432 Mdot
.47208 .3382 Mdot
.64906 .54387 Mdot
.60096 .63986 Mdot
.17582 .35727 Mdot
.49869 .56571 Mdot
.54775 .13706 Mdot
.65467 .44418 Mdot
.68404 .44695 Mdot
.4495 .20815 Mdot
.60906 .35687 Mdot
.6369 .56188 Mdot
.62053 .65876 Mdot
.35679 .52071 Mdot
.59836 .5894 Mdot
.40324 .48196 Mdot
.44379 .34861 Mdot
.15668 .50399 Mdot
.53563 .30544 Mdot
.67302 .24577 Mdot
.59694 .58732 Mdot
.60179 .31943 Mdot
.39648 .65094 Mdot
.42569 .39469 Mdot
.64213 .38377 Mdot
.65837 .61486 Mdot
.41997 .78226 Mdot
.32845 .47472 Mdot
.59809 .40637 Mdot
.35113 .74527 Mdot
.32734 .67647 Mdot
.64515 .62646 Mdot
.3289 .46656 Mdot
.34868 .26684 Mdot
.6348 .68871 Mdot
.44749 .40539 Mdot
.41224 .64281 Mdot
.34367 .47384 Mdot
.47224 .33544 Mdot
.61216 .46781 Mdot
.62219 .41256 Mdot
.58899 .35493 Mdot
.50047 .80577 Mdot
.39393 .4993 Mdot
.39663 .6553 Mdot
.20447 .55053 Mdot
.24091 .63633 Mdot
.41193 .64756 Mdot
.30658 .48054 Mdot
.64156 .40562 Mdot
.63172 .39754 Mdot
.60208 .38476 Mdot
.43799 .81475 Mdot
.62196 .35292 Mdot
.77518 .37989 Mdot
.65479 .63033 Mdot
.69824 .63233 Mdot
.5923 .55551 Mdot
.42977 .38111 Mdot
.63236 .36519 Mdot
.43869 .52616 Mdot
.55543 .5641 Mdot
.202 .43918 Mdot
.57942 .57504 Mdot
.42306 .38332 Mdot
.59504 .61343 Mdot
.79471 .43668 Mdot
.58584 .37448 Mdot
.60493 .59251 Mdot
.44567 .39957 Mdot
.38804 .64062 Mdot
.56649 .37143 Mdot
.63936 .56969 Mdot
.45054 .24701 Mdot
.65274 .63838 Mdot
.63529 .23432 Mdot
.49692 .6021 Mdot
.42396 .63081 Mdot
.52324 .561 Mdot
.39735 .48305 Mdot
.69887 .60751 Mdot
.6782 .64845 Mdot
.47632 .34727 Mdot
.27046 .39752 Mdot
.36114 .49407 Mdot
.37094 .59954 Mdot
.6117 .66465 Mdot
.38263 .62651 Mdot
.61063 .43644 Mdot
.42577 .37801 Mdot
.65608 .56444 Mdot
.55672 .54615 Mdot
.69071 .30082 Mdot
.59322 .6629 Mdot
.58105 .55357 Mdot
.40893 .61723 Mdot
.74365 .34576 Mdot
.59833 .60051 Mdot
.50603 .49206 Mdot
.61719 .34666 Mdot
.65515 .54616 Mdot
.799 .40761 Mdot
.57702 .6168 Mdot
.60887 .41497 Mdot
.56579 .39671 Mdot
.46956 .27579 Mdot
.37431 .66732 Mdot
.61669 .54188 Mdot
.81723 .55725 Mdot
.62342 .61081 Mdot
.45119 .34953 Mdot
.62171 .63671 Mdot
.35418 .47679 Mdot
.4211 .80106 Mdot
.36955 .51893 Mdot
.61234 .54443 Mdot
.60233 .38883 Mdot
.48503 .36021 Mdot
.50539 .81811 Mdot
.26888 .55009 Mdot
.76429 .37192 Mdot
.66744 .22069 Mdot
.41531 .66111 Mdot
.36899 .63838 Mdot
.42408 .37482 Mdot
.60476 .59401 Mdot
.83324 .46124 Mdot
.65282 .5402 Mdot
.59395 .60565 Mdot
.60225 .57309 Mdot
.2049 .50374 Mdot
.45002 .3382 Mdot
.37213 .49997 Mdot
.58032 .60546 Mdot
.58895 .62795 Mdot
.60597 .35867 Mdot
.38454 .64289 Mdot
.36357 .46653 Mdot
.38361 .66377 Mdot
.34204 .48639 Mdot
.15149 .5125 Mdot
.55792 .61096 Mdot
.38944 .64216 Mdot
.4995 .36518 Mdot
.58785 .39135 Mdot
.51938 .33107 Mdot
.36994 .47437 Mdot
.34991 .51797 Mdot
.57574 .58383 Mdot
.60996 .41637 Mdot
.58438 .40157 Mdot
.39876 .63631 Mdot
.45505 .38717 Mdot
.63554 .56349 Mdot
.66571 .58819 Mdot
.66427 .31686 Mdot
.34177 .52798 Mdot
.54843 .49268 Mdot
.41357 .2592 Mdot
.60808 .59496 Mdot
.58488 .39797 Mdot
.60891 .56356 Mdot
.47333 .20176 Mdot
.62094 .42099 Mdot
.57325 .61449 Mdot
.27467 .69828 Mdot
.28421 .48188 Mdot
.49703 .27417 Mdot
.57469 .55986 Mdot
.56831 .17627 Mdot
.64982 .61018 Mdot
.14617 .39393 Mdot
.33426 .58132 Mdot
.63382 .55463 Mdot
.61945 .62219 Mdot
.7411 .57031 Mdot
.61324 .55142 Mdot
.31136 .49751 Mdot
.36493 .72117 Mdot
.5759 .37786 Mdot
.48112 .23137 Mdot
.70826 .5844 Mdot
.38888 .68304 Mdot
.38486 .5102 Mdot
.37457 .54076 Mdot
.40682 .65995 Mdot
.60841 .39656 Mdot
.61818 .59675 Mdot
.45903 .49259 Mdot
.33835 .53304 Mdot
.55686 .52812 Mdot
.4515 .35261 Mdot
.35257 .3654 Mdot
.282 .49442 Mdot
.4687 .35739 Mdot
.64876 .58235 Mdot
.73874 .57872 Mdot
.54924 .78594 Mdot
.44211 .17624 Mdot
.48033 .34 Mdot
.47847 .34537 Mdot
.41715 .80765 Mdot
.40083 .68379 Mdot
.69829 .29536 Mdot
.56031 .2574 Mdot
.48246 .37235 Mdot
.56264 .67406 Mdot
.32043 .49255 Mdot
.46386 .25111 Mdot
.65762 .3518 Mdot
.66696 .61405 Mdot
.61316 .57628 Mdot
.45957 .38845 Mdot
.68957 .37099 Mdot
.7081 .71763 Mdot
.47517 .35144 Mdot
.5634 .65182 Mdot
.46558 .4425 Mdot
.25343 .42976 Mdot
.32725 .51447 Mdot
.37249 .66182 Mdot
.3889 .60281 Mdot
.64196 .36083 Mdot
.36948 .65171 Mdot
.2487 .62037 Mdot
.6347 .59789 Mdot
.47665 .36106 Mdot
.30007 .36929 Mdot
.46286 .36278 Mdot
.40417 .66163 Mdot
.42293 .62672 Mdot
.59612 .3727 Mdot
.60518 .37394 Mdot
.68513 .46606 Mdot
.46962 .73372 Mdot
.58165 .56797 Mdot
.24118 .37199 Mdot
.58006 .38728 Mdot
.57615 .50319 Mdot
.37219 .63366 Mdot
.38594 .64483 Mdot
.47394 .63464 Mdot
.6363 .58469 Mdot
.80114 .58643 Mdot
.63169 .58528 Mdot
.44559 .73478 Mdot
.58111 .53792 Mdot
.37208 .50756 Mdot
.64055 .58281 Mdot
.42163 .69198 Mdot
.6554 .56032 Mdot
.60583 .63822 Mdot
.34818 .53163 Mdot
.60705 .64861 Mdot
.35648 .47766 Mdot
.59866 .54369 Mdot
.39043 .68584 Mdot
.3608 .52736 Mdot
.52195 .70487 Mdot
.4392 .60144 Mdot
.3095 .47291 Mdot
.37684 .63393 Mdot
.39543 .68218 Mdot
.55722 .71175 Mdot
.64269 .38438 Mdot
.62235 .33814 Mdot
.60124 .59313 Mdot
.40051 .4939 Mdot
.44573 .34081 Mdot
.59197 .62651 Mdot
.63276 .6503 Mdot
.5694 .57672 Mdot
.64842 .36459 Mdot
.24862 .55211 Mdot
.39358 .63787 Mdot
.31475 .47899 Mdot
.38761 .70498 Mdot
.32503 .51959 Mdot
.55244 .61267 Mdot
.6427 .65823 Mdot
.66832 .47349 Mdot
.29746 .33636 Mdot
.40494 .81326 Mdot
.61891 .41395 Mdot
.38511 .47816 Mdot
.40047 .68202 Mdot
.57529 .51079 Mdot
.63498 .39023 Mdot
.35501 .47499 Mdot
.61149 .59749 Mdot
.57446 .53442 Mdot
.56203 .33214 Mdot
.69392 .562 Mdot
.49679 .65006 Mdot
.32269 .51389 Mdot
.38121 .46709 Mdot
.2393 .62745 Mdot
.35358 .69487 Mdot
.4398 .54369 Mdot
.58907 .57598 Mdot
.37549 .65085 Mdot
.64155 .40367 Mdot
.5261 .79763 Mdot
.45149 .39049 Mdot
.46054 .56129 Mdot
.59868 .58763 Mdot
.42563 .49264 Mdot
.60085 .3883 Mdot
.40765 .64702 Mdot
.46196 .38823 Mdot
.3935 .61097 Mdot
.38322 .51776 Mdot
.74374 .27692 Mdot
.62651 .60816 Mdot
.57688 .57396 Mdot
.4878 .3822 Mdot
.63837 .40214 Mdot
.38658 .61646 Mdot
.67298 .28589 Mdot
.3828 .49127 Mdot
.83727 .48205 Mdot
.60027 .4175 Mdot
.78894 .44786 Mdot
.31438 .48371 Mdot
.43475 .3412 Mdot
.54825 .71742 Mdot
.47425 .36893 Mdot
.60508 .54099 Mdot
.61776 .38688 Mdot
.4388 .35969 Mdot
.46962 .57847 Mdot
.20568 .35055 Mdot
.79441 .48755 Mdot
.62974 .59342 Mdot
.16987 .41252 Mdot
.57738 .21422 Mdot
.62652 .43994 Mdot
.48651 .37853 Mdot
.58033 .57987 Mdot
.6451 .55868 Mdot
.61945 .61135 Mdot
.44555 .36613 Mdot
.24172 .45462 Mdot
.37756 .48876 Mdot
.5926 .5587 Mdot
.37335 .65784 Mdot
.36155 .48327 Mdot
.272 .42042 Mdot
.34096 .51594 Mdot
.63592 .43342 Mdot
.62296 .63735 Mdot
.41641 .35695 Mdot
.13253 .46029 Mdot
.46568 .33761 Mdot
.30598 .47733 Mdot
.60732 .63277 Mdot
.29448 .36372 Mdot
.63476 .38453 Mdot
.38329 .4981 Mdot
.57898 .59182 Mdot
.26831 .42921 Mdot
.43852 .79353 Mdot
.34133 .51544 Mdot
.63937 .39391 Mdot
.39687 .21111 Mdot
.59336 .59007 Mdot
.64538 .61108 Mdot
.62881 .40467 Mdot
.72119 .61839 Mdot
.35755 .76007 Mdot
.61498 .56221 Mdot
.46921 .35095 Mdot
.83842 .40694 Mdot
.58138 .6356 Mdot
.45359 .69461 Mdot
.34402 .47663 Mdot
.45926 .26351 Mdot
.5361 .50331 Mdot
.58049 .50544 Mdot
.66641 .28753 Mdot
.53009 .41314 Mdot
.1779 .46041 Mdot
.40006 .47438 Mdot
.33242 .64447 Mdot
.16804 .46986 Mdot
.43077 .39213 Mdot
.55907 .36509 Mdot
.62805 .26039 Mdot
.52248 .83868 Mdot
.3962 .21943 Mdot
.28907 .63476 Mdot
.41521 .78139 Mdot
.45369 .46849 Mdot
.33874 .49103 Mdot
.42788 .61623 Mdot
.63434 .56686 Mdot
.57395 .21191 Mdot
.8062 .55989 Mdot
.75758 .68303 Mdot
.17089 .40511 Mdot
.78093 .61179 Mdot
.20807 .36856 Mdot
.29604 .25976 Mdot
.67387 .44371 Mdot
.31186 .31852 Mdot
.84257 .49601 Mdot
.2669 .68246 Mdot
.76167 .32275 Mdot
.6902 .58212 Mdot
.50763 .5036 Mdot
.64382 .22575 Mdot
.77266 .40395 Mdot
.71446 .69431 Mdot
.37309 .51418 Mdot
.62879 .42632 Mdot
.61312 .25371 Mdot
.59248 .4283 Mdot
.45039 .30306 Mdot
.40687 .1999 Mdot
.21756 .32364 Mdot
.79629 .43278 Mdot
.53039 .15916 Mdot
.70742 .40612 Mdot
.75488 .74544 Mdot
.31879 .5259 Mdot
.65746 .38344 Mdot
.35439 .65274 Mdot
.23249 .62138 Mdot
.59674 .29659 Mdot
.61497 .24421 Mdot
.23063 .48527 Mdot
.52179 .74263 Mdot
.61327 .39391 Mdot
.51705 .56953 Mdot
.41633 .30916 Mdot
.54295 .30839 Mdot
.36416 .72335 Mdot
.32961 .2432 Mdot
.46515 .50652 Mdot
.4622 .2426 Mdot
.36006 .33891 Mdot
.45514 .85867 Mdot
.47619 .66646 Mdot
.63823 .46486 Mdot
.52467 .35537 Mdot
.4606 .20192 Mdot
.56625 .82576 Mdot
.47435 .74883 Mdot
.23517 .6264 Mdot
.19929 .61517 Mdot
.53752 .19278 Mdot
.23563 .70126 Mdot
.61824 .34109 Mdot
.57828 .55792 Mdot
.70239 .54665 Mdot
.82088 .54272 Mdot
.43121 .64399 Mdot
.22785 .42219 Mdot
.39131 .67893 Mdot
.66395 .40785 Mdot
.40585 .78928 Mdot
.78604 .395 Mdot
.82363 .55055 Mdot
.36754 .6317 Mdot
.57516 .63715 Mdot
.87652 .40261 Mdot
.18777 .44414 Mdot
.50116 .28864 Mdot
.1667 .36688 Mdot
.42812 .52969 Mdot
.51653 .64003 Mdot
.4398 .35992 Mdot
.16151 .45838 Mdot
.62667 .39422 Mdot
.18699 .64566 Mdot
.14732 .41833 Mdot
.67452 .72467 Mdot
.5853 .10508 Mdot
.22398 .57707 Mdot
.4323 .4915 Mdot
.52246 .40147 Mdot
.49844 .69217 Mdot
.67323 .7533 Mdot
.67176 .71209 Mdot
.31444 .34676 Mdot
.64848 .20937 Mdot
.17004 .44918 Mdot
.82859 .51131 Mdot
.75093 .29132 Mdot
.54442 .83838 Mdot
.5242 .45933 Mdot
.65465 .3417 Mdot
.3349 .54338 Mdot
.30747 .27555 Mdot
.17066 .5583 Mdot
.46688 .67489 Mdot
.7318 .22833 Mdot
.38988 .69931 Mdot
.31758 .57921 Mdot
.41352 .18423 Mdot
.5377 .73841 Mdot
.5093 .57596 Mdot
.33297 .71825 Mdot
.55813 .52955 Mdot
.31341 .69484 Mdot
.2395 .35494 Mdot
.49822 .31448 Mdot
.27173 .68236 Mdot
.38729 .24161 Mdot
.68543 .30059 Mdot
.74497 .53755 Mdot
.22983 .62712 Mdot
.57591 .39951 Mdot
.49852 .74234 Mdot
.50571 .5719 Mdot
.20896 .32823 Mdot
.513 .34322 Mdot
.25303 .27121 Mdot
.36583 .75884 Mdot
.56119 .58028 Mdot
.68735 .62601 Mdot
.547 .63458 Mdot
.4808 .7284 Mdot
.60044 .64191 Mdot
.59305 .31026 Mdot
.26177 .27785 Mdot
.70878 .38178 Mdot
.44011 .28594 Mdot
.26548 .40576 Mdot
.43087 .17495 Mdot
.68869 .50515 Mdot
.34716 .68904 Mdot
.40824 .73076 Mdot
.50938 .85451 Mdot
.36515 .49505 Mdot
.82855 .49161 Mdot
.44326 .40551 Mdot
.46728 .79561 Mdot
.77001 .5676 Mdot
.65599 .75247 Mdot
.2632 .27638 Mdot
.30849 .66322 Mdot
.39303 .77262 Mdot
.57115 .7487 Mdot
.83438 .43233 Mdot
.25125 .41215 Mdot
.63245 .66379 Mdot
.54611 .2187 Mdot
.42163 .65043 Mdot
.70761 .4953 Mdot
.80813 .37993 Mdot
.28503 .59726 Mdot
.67944 .60281 Mdot
.60396 .77634 Mdot
.31273 .44047 Mdot
.44857 .56869 Mdot
.32468 .79439 Mdot
.54678 .56703 Mdot
.20693 .55975 Mdot
.56021 .19705 Mdot
.4811 .69663 Mdot
.45399 .1888 Mdot
.43242 .2296 Mdot
.21761 .67201 Mdot
.1601 .39473 Mdot
.2632 .55219 Mdot
.17082 .4879 Mdot
.19367 .33935 Mdot
.24161 .69754 Mdot
.66475 .66672 Mdot
.48679 .38632 Mdot
.41259 .86805 Mdot
.31506 .50213 Mdot
.19833 .51583 Mdot
.74825 .32107 Mdot
.28052 .42634 Mdot
.6058 .45648 Mdot
.66119 .52759 Mdot
.45981 .47567 Mdot
.63285 .4389 Mdot
.60632 .64607 Mdot
.33702 .78566 Mdot
.22307 .66204 Mdot
.29012 .75273 Mdot
.56469 .18663 Mdot
.16359 .50212 Mdot
.42871 .4489 Mdot
.77862 .40108 Mdot
.68025 .3779 Mdot
.66233 .61516 Mdot
.39254 .58255 Mdot
.22377 .57361 Mdot
.59771 .78134 Mdot
.58644 .28591 Mdot
.61568 .43736 Mdot
.23169 .39399 Mdot
.76789 .76961 Mdot
.70187 .4328 Mdot
.80071 .40106 Mdot
.24689 .63351 Mdot
.46802 .72439 Mdot
.2888 .29753 Mdot
.66529 .73862 Mdot
.31585 .23769 Mdot
.63445 .44177 Mdot
.75088 .31536 Mdot
.29886 .62603 Mdot
.5711 .68976 Mdot
.24617 .54365 Mdot
.22858 .32378 Mdot
.45442 .42337 Mdot
.55537 .80359 Mdot
.57037 .24845 Mdot
.68836 .72163 Mdot
.35805 .58207 Mdot
.35877 .36434 Mdot
.81059 .38739 Mdot
.37585 .28908 Mdot
.44958 .71819 Mdot
.47453 .45056 Mdot
.54081 .53459 Mdot
.52917 .41156 Mdot
.45534 .71107 Mdot
.54972 .68438 Mdot
.17817 .52203 Mdot
.11385 .4243 Mdot
.4127 .82823 Mdot
.50383 .15085 Mdot
.25838 .33652 Mdot
.67619 .5907 Mdot
.37603 .1894 Mdot
.26017 .73477 Mdot
.13906 .41756 Mdot
.37178 .40461 Mdot
.40532 .48426 Mdot
.45998 .31821 Mdot
.35534 .78335 Mdot
.25556 .49615 Mdot
.36025 .21128 Mdot
.32192 .71257 Mdot
.47439 .32067 Mdot
.6432 .80763 Mdot
.21595 .63714 Mdot
.78154 .55203 Mdot
.68553 .54747 Mdot
.62565 .53169 Mdot
.80766 .4722 Mdot
.60989 .43338 Mdot
.37731 .3092 Mdot
.47805 .74066 Mdot
.3573 .50531 Mdot
.39345 .58518 Mdot
.59867 .23479 Mdot
.6485 .63969 Mdot
.54775 .41977 Mdot
.64082 .42342 Mdot
.3031 .33078 Mdot
.53095 .32681 Mdot
.16246 .5525 Mdot
.22589 .54297 Mdot
.6012 .51848 Mdot
.47804 .69263 Mdot
.24199 .54636 Mdot
.35646 .76441 Mdot
.42504 .34909 Mdot
.18099 .386 Mdot
.4895 .52794 Mdot
.49524 .74184 Mdot
.80903 .51014 Mdot
.6953 .33842 Mdot
.65522 .64605 Mdot
.38441 .26622 Mdot
.75461 .47715 Mdot
.45712 .57012 Mdot
.66514 .35846 Mdot
.63826 .33061 Mdot
.39854 .1703 Mdot
.26011 .63433 Mdot
.35112 .34902 Mdot
.19566 .36928 Mdot
.45586 .36966 Mdot
.5828 .38581 Mdot
.42886 .60422 Mdot
.67358 .27803 Mdot
.76577 .4487 Mdot
.43907 .79413 Mdot
.27737 .44359 Mdot
.29561 .59287 Mdot
.20037 .37089 Mdot
.17928 .39936 Mdot
.79297 .64896 Mdot
.57221 .41062 Mdot
.68109 .41824 Mdot
.70207 .28774 Mdot
.61073 .42963 Mdot
.66901 .30344 Mdot
.62021 .30513 Mdot
.1696 .54245 Mdot
.44793 .30956 Mdot
.63208 .19739 Mdot
.52199 .67556 Mdot
.23417 .45208 Mdot
.49964 .81945 Mdot
.8123 .39309 Mdot
.21194 .35654 Mdot
.60254 .68594 Mdot
.75709 .59033 Mdot
.68524 .56948 Mdot
.58673 .46918 Mdot
.51924 .8688 Mdot
.43777 .60568 Mdot
.79106 .44906 Mdot
.3918 .23555 Mdot
.62275 .60163 Mdot
.41604 .83491 Mdot
.6512 .26203 Mdot
.41628 .81 Mdot
.48265 .33072 Mdot
.65611 .59751 Mdot
.66557 .5742 Mdot
.4321 .71011 Mdot
.47373 .27434 Mdot
.19075 .55063 Mdot
.81182 .3708 Mdot
.3524 .25841 Mdot
.80557 .56051 Mdot
.20872 .5516 Mdot
.35544 .22147 Mdot
.56492 .20889 Mdot
.49353 .48195 Mdot
.22595 .5685 Mdot
.54554 .73057 Mdot
.53074 .16208 Mdot
.4713 .61269 Mdot
.43349 .41258 Mdot
.62534 .29383 Mdot
.42186 .25116 Mdot
.5199 .80539 Mdot
.6485 .62051 Mdot
.35102 .74515 Mdot
.31023 .25164 Mdot
.8019 .61545 Mdot
.63431 .79216 Mdot
.39308 .8221 Mdot
.76714 .51084 Mdot
.42394 .2428 Mdot
.56858 .21519 Mdot
.85808 .48063 Mdot
.49343 .53101 Mdot
.20899 .418 Mdot
.55413 .73733 Mdot
.19866 .36956 Mdot
.48076 .39125 Mdot
.58111 .26088 Mdot
.26301 .40997 Mdot
.17183 .50668 Mdot
.7082 .53091 Mdot
.25078 .30188 Mdot
.43567 .5076 Mdot
.20297 .65497 Mdot
.35937 .29272 Mdot
.44855 .45731 Mdot
.389 .48892 Mdot
.3034 .66648 Mdot
.23417 .35233 Mdot
.28224 .33675 Mdot
.80963 .39556 Mdot
.36525 .4564 Mdot
.42533 .60805 Mdot
.79 .56315 Mdot
.54543 .76331 Mdot
.39782 .25149 Mdot
.47839 .69278 Mdot
.24127 .30253 Mdot
.39789 .71214 Mdot
.36208 .74574 Mdot
.21361 .53799 Mdot
.72252 .24955 Mdot
.49745 .28528 Mdot
.27382 .65874 Mdot
.63701 .25286 Mdot
.31835 .57107 Mdot
.54871 .66467 Mdot
.08062 .57698 Mdot
.71739 .2628 Mdot
.33357 .30542 Mdot
.17105 .55846 Mdot
.47356 .19576 Mdot
.30269 .33433 Mdot
.66445 .75833 Mdot
.49964 .56189 Mdot
.42177 .76684 Mdot
.60288 .574 Mdot
.30621 .77539 Mdot
.51958 .75844 Mdot
.17791 .58763 Mdot
.39044 .18213 Mdot
.80632 .4827 Mdot
.63612 .64359 Mdot
.32058 .47509 Mdot
.467 .30197 Mdot
.52039 .77776 Mdot
.7311 .59108 Mdot
.51221 .60751 Mdot
.26562 .45637 Mdot
.39075 .50646 Mdot
.24769 .56735 Mdot
.64473 .44257 Mdot
.2492 .48568 Mdot
.41272 .25728 Mdot
.28658 .47557 Mdot
.4674 .5193 Mdot
.46153 .71278 Mdot
.5333 .51005 Mdot
.78278 .54519 Mdot
.641 .76046 Mdot
.5314 .44139 Mdot
.34021 .51701 Mdot
.76749 .55047 Mdot
.66474 .22964 Mdot
.35429 .26568 Mdot
.19402 .60655 Mdot
.32793 .69853 Mdot
.7477 .61643 Mdot
.44811 .71275 Mdot
.6849 .74406 Mdot
.74183 .66683 Mdot
.26114 .37155 Mdot
.58635 .48297 Mdot
.71704 .67802 Mdot
.55751 .22721 Mdot
.15557 .49884 Mdot
.75962 .32137 Mdot
.71912 .29272 Mdot
.33134 .55532 Mdot
.7642 .40528 Mdot
.80351 .52667 Mdot
.52645 .70132 Mdot
.44258 .55188 Mdot
.72533 .76997 Mdot
.64631 .34175 Mdot
.5746 .87799 Mdot
.43379 .35234 Mdot
.55485 .84298 Mdot
.55792 .72883 Mdot
.47703 .44656 Mdot
.42456 .55562 Mdot
.39035 .2671 Mdot
.55681 .2623 Mdot
.58595 .19489 Mdot
.74289 .68709 Mdot
.33051 .52646 Mdot
.81417 .36842 Mdot
.72992 .2507 Mdot
.75112 .56612 Mdot
.57039 .62827 Mdot
.71285 .25482 Mdot
.39306 .46605 Mdot
.59912 .7817 Mdot
.45556 .18526 Mdot
.29226 .31745 Mdot
.65993 .6756 Mdot
.4716 .72852 Mdot
.20946 .41126 Mdot
.17659 .37772 Mdot
.65982 .78722 Mdot
.24061 .35414 Mdot
.48452 .3877 Mdot
.43751 .45762 Mdot
.25614 .30525 Mdot
.5034 .62767 Mdot
.47932 .24224 Mdot
.50426 .59345 Mdot
.65709 .83816 Mdot
.19466 .49914 Mdot
.19069 .54817 Mdot
.49943 .60603 Mdot
.61279 .3522 Mdot
.45853 .28143 Mdot
.50979 .57122 Mdot
.30769 .30667 Mdot
.64704 .23434 Mdot
.50796 .57007 Mdot
.84557 .57041 Mdot
.70562 .34769 Mdot
.38738 .43653 Mdot
.80054 .55153 Mdot
.70389 .37928 Mdot
.48528 .3324 Mdot
.372 .73375 Mdot
.37947 .23793 Mdot
.49383 .37554 Mdot
.39254 .2541 Mdot
.45252 .25054 Mdot
.71526 .3386 Mdot
.77291 .45966 Mdot
.32658 .27512 Mdot
.72944 .56705 Mdot
.55179 .37182 Mdot
.51763 .7975 Mdot
.30884 .46634 Mdot
.38149 .23045 Mdot
.3852 .48821 Mdot
.58485 .49598 Mdot
.46342 .56648 Mdot
.69434 .67191 Mdot
.38963 .80914 Mdot
.4162 .66046 Mdot
.6509 .3998 Mdot
.57556 .84529 Mdot
.60741 .4255 Mdot
.32193 .77754 Mdot
.66114 .74629 Mdot
.81005 .5082 Mdot
.27041 .56053 Mdot
.2711 .59893 Mdot
.80469 .66945 Mdot
.53865 .40004 Mdot
.30866 .53365 Mdot
.54061 .37646 Mdot
.65505 .38487 Mdot
.22032 .533 Mdot
.34943 .52957 Mdot
.4974 .54694 Mdot
.41293 .4237 Mdot
.60451 .32431 Mdot
.58932 .43874 Mdot
.48048 .54045 Mdot
.4318 .75609 Mdot
.17065 .53206 Mdot
.33184 .49608 Mdot
.61812 .84597 Mdot
.64352 .64918 Mdot
.73804 .52835 Mdot
.31579 .23549 Mdot
.65633 .79775 Mdot
.35487 .54359 Mdot
.73739 .25202 Mdot
.5807 .53559 Mdot
.29989 .29168 Mdot
.62036 .39698 Mdot
.73147 .30034 Mdot
.40587 .67176 Mdot
.48671 .69465 Mdot
.45444 .3208 Mdot
.55115 .80547 Mdot
.29702 .43929 Mdot
.5824 .36237 Mdot
.26015 .34586 Mdot
.68599 .41157 Mdot
.53469 .24566 Mdot
.25953 .58866 Mdot
.75554 .56924 Mdot
.77047 .44748 Mdot
.5827 .43286 Mdot
.18569 .53263 Mdot
.73597 .29942 Mdot
.14325 .51058 Mdot
.53669 .60537 Mdot
.32709 .66483 Mdot
.63716 .29821 Mdot
.36751 .26623 Mdot
.57582 .47601 Mdot
.28964 .25466 Mdot
.48661 .74835 Mdot
.63836 .316 Mdot
.44864 .7306 Mdot
.60943 .50621 Mdot
.47837 .49128 Mdot
.3769 .32516 Mdot
.75395 .69219 Mdot
.55874 .4751 Mdot
.58535 .82201 Mdot
.57874 .48415 Mdot
.2079 .57748 Mdot
.63893 .45095 Mdot
.39096 .52199 Mdot
.77253 .41521 Mdot
.51001 .33599 Mdot
.15852 .48406 Mdot
.29822 .2483 Mdot
.42286 .34487 Mdot
.22856 .50651 Mdot
.4509 .20248 Mdot
.5836 .51416 Mdot
.42469 .46389 Mdot
.58511 .54768 Mdot
.68312 .3913 Mdot
.66213 .79994 Mdot
.33275 .2869 Mdot
.64975 .66134 Mdot
.17571 .46196 Mdot
.16473 .44827 Mdot
.19484 .63235 Mdot
.83664 .46339 Mdot
.61561 .35656 Mdot
.26726 .7237 Mdot
.51529 .61119 Mdot
.18812 .35194 Mdot
.2654 .36283 Mdot
.3824 .17649 Mdot
.75236 .58464 Mdot
.41192 .23068 Mdot
.70105 .70794 Mdot
.51898 .2609 Mdot
.52124 .19262 Mdot
.44753 .43303 Mdot
.34035 .35078 Mdot
.49595 .18761 Mdot
.87826 .50629 Mdot
.61166 .48905 Mdot
.45588 .24502 Mdot
.58811 .24373 Mdot
.37338 .2346 Mdot
.3457 .59403 Mdot
.62178 .63648 Mdot
.29056 .38005 Mdot
.46037 .81271 Mdot
.46538 .69799 Mdot
.43095 .61512 Mdot
.34399 .59162 Mdot
.47532 .78138 Mdot
.44364 .74271 Mdot
.76158 .32169 Mdot
.7573 .57859 Mdot
.51922 .51064 Mdot
.56127 .60704 Mdot
.61899 .45605 Mdot
.37036 .66725 Mdot
.38998 .42545 Mdot
.59201 .54656 Mdot
.40062 .5027 Mdot
.53468 .25121 Mdot
.37319 .8107 Mdot
.47342 .29554 Mdot
.64107 .24713 Mdot
.66292 .36706 Mdot
.44091 .26401 Mdot
.56818 .43297 Mdot
.47516 .83008 Mdot
.33034 .62598 Mdot
.46706 .67451 Mdot
.18743 .42708 Mdot
.26896 .67905 Mdot
.69697 .32556 Mdot
.26985 .69792 Mdot
.47551 .39005 Mdot
.60864 .67226 Mdot
.60673 .26171 Mdot
.24401 .57695 Mdot
.67248 .37278 Mdot
.4086 .23345 Mdot
.30079 .52606 Mdot
.26932 .66221 Mdot
.552 .19386 Mdot
.69574 .37433 Mdot
.77901 .58424 Mdot
.1753 .40946 Mdot
.32446 .48229 Mdot
.71933 .28141 Mdot
.48027 .23624 Mdot
.32364 .64286 Mdot
.20043 .5816 Mdot
.15919 .53378 Mdot
.43554 .53444 Mdot
.5217 .72931 Mdot
.63347 .61464 Mdot
.79174 .37039 Mdot
.35113 .27995 Mdot
.70288 .60915 Mdot
.35758 .40104 Mdot
.59035 .4048 Mdot
.37324 .36123 Mdot
.51224 .50381 Mdot
.44436 .77349 Mdot
.60227 .4338 Mdot
.80787 .56718 Mdot
.38391 .68666 Mdot
.41951 .53384 Mdot
.59862 .64462 Mdot
.51003 .71604 Mdot
.83073 .53435 Mdot
.55216 .62675 Mdot
.26089 .3236 Mdot
.76423 .56661 Mdot
.68219 .28742 Mdot
.31327 .28971 Mdot
.25956 .37727 Mdot
.54973 .26328 Mdot
.78198 .44267 Mdot
.35352 .4205 Mdot
.57046 .57324 Mdot
.38726 .5275 Mdot
.58394 .40761 Mdot
.42053 .1959 Mdot
.7655 .49914 Mdot
.52301 .70817 Mdot
.49764 .44011 Mdot
.61409 .47589 Mdot
.50986 .42422 Mdot
.35813 .19999 Mdot
.51973 .26213 Mdot
.47667 .74279 Mdot
.4554 .30638 Mdot
.55413 .72679 Mdot
.65058 .75957 Mdot
.14886 .4364 Mdot
.68449 .73463 Mdot
.45553 .50447 Mdot
.59666 .81987 Mdot
.38165 .28295 Mdot
.46166 .1856 Mdot
.46255 .7461 Mdot
.41419 .55068 Mdot
.43333 .65806 Mdot
.56437 .33391 Mdot
.51576 .45727 Mdot
.44376 .64463 Mdot
.50738 .53729 Mdot
.32694 .40859 Mdot
.39999 .33317 Mdot
.66179 .5291 Mdot
.20197 .51121 Mdot
.18207 .41883 Mdot
.7386 .30915 Mdot
.529 .42064 Mdot
.35081 .62489 Mdot
.4675 .7728 Mdot
.44833 .1376 Mdot
.47102 .86765 Mdot
.63202 .61379 Mdot
.53411 .42494 Mdot
.50485 .72859 Mdot
.32117 .51313 Mdot
.52508 .53222 Mdot
.56002 .42415 Mdot
.44097 .33729 Mdot
.43548 .60966 Mdot
.28328 .67849 Mdot
.39605 .26785 Mdot
.56409 .76064 Mdot
.26976 .416 Mdot
.37309 .81392 Mdot
.64196 .2183 Mdot
.35729 .27284 Mdot
.39387 .15545 Mdot
.40001 .32064 Mdot
.6078 .32997 Mdot
.68916 .52969 Mdot
.17444 .53604 Mdot
.48113 .68219 Mdot
.49198 .8035 Mdot
.25646 .39605 Mdot
.47654 .74835 Mdot
.52947 .64527 Mdot
.21114 .54671 Mdot
.37084 .37462 Mdot
.46808 .46776 Mdot
.2732 .60206 Mdot
.23809 .66407 Mdot
.786 .59206 Mdot
.19724 .41144 Mdot
.47387 .81872 Mdot
.86178 .52072 Mdot
.15965 .46216 Mdot
.41028 .59115 Mdot
.34922 .61018 Mdot
.69662 .53629 Mdot
.51091 .65496 Mdot
.57089 .67802 Mdot
.58855 .78587 Mdot
.75764 .44057 Mdot
.25631 .52462 Mdot
.541 .82949 Mdot
.45003 .71733 Mdot
.70724 .37009 Mdot
.41555 .55084 Mdot
.77823 .54323 Mdot
.23112 .51425 Mdot
.49327 .60742 Mdot
.46597 .60376 Mdot
.50556 .67259 Mdot
.76279 .55549 Mdot
.67225 .29722 Mdot
.45216 .21673 Mdot
.854 .57742 Mdot
.23912 .39752 Mdot
.48876 .83261 Mdot
.65149 .63367 Mdot
.14596 .54067 Mdot
.45731 .22423 Mdot
.24968 .3986 Mdot
.60248 .21386 Mdot
.40065 .44515 Mdot
.64117 .3219 Mdot
.57035 .57417 Mdot
.23025 .37357 Mdot
.7941 .45831 Mdot
.69213 .42108 Mdot
.5366 .81308 Mdot
.47848 .70858 Mdot
.35633 .71734 Mdot
.52974 .69447 Mdot
.55998 .64601 Mdot
.62055 .42468 Mdot
.27963 .74359 Mdot
.44402 .50441 Mdot
.59224 .49106 Mdot
.69974 .6336 Mdot
.69469 .71114 Mdot
.66481 .21045 Mdot
.54597 .63115 Mdot
.25226 .65949 Mdot
.77361 .62044 Mdot
.66822 .68174 Mdot
.55338 .50823 Mdot
.48166 .09068 Mdot
.12953 .40537 Mdot
.57831 .36979 Mdot
.80601 .41096 Mdot
.77772 .61782 Mdot
.17659 .52267 Mdot
.30264 .62499 Mdot
.37741 .41648 Mdot
.67193 .7027 Mdot
.52908 .66361 Mdot
.59879 .65506 Mdot
.57057 .20026 Mdot
.15031 .42255 Mdot
.54065 .81732 Mdot
.17513 .45794 Mdot
.69105 .60233 Mdot
.58823 .65534 Mdot
.49215 .12056 Mdot
.24653 .31693 Mdot
.57032 .522 Mdot
.70825 .70828 Mdot
.65472 .34227 Mdot
.62497 .56616 Mdot
.22156 .45048 Mdot
.80937 .36393 Mdot
.44659 .71693 Mdot
.17209 .50777 Mdot
.58083 .41874 Mdot
.31442 .53206 Mdot
.43616 .3409 Mdot
.43091 .55445 Mdot
.56508 .5521 Mdot
.44231 .36746 Mdot
.698 .67453 Mdot
.41012 .22537 Mdot
.43044 .31858 Mdot
.76521 .31358 Mdot
.28748 .23894 Mdot
.77474 .50926 Mdot
.55015 .34199 Mdot
.57248 .51472 Mdot
.70423 .36668 Mdot
.50872 .78087 Mdot
.68122 .36231 Mdot
.48237 .1844 Mdot
.12624 .6136 Mdot
.33432 .36427 Mdot
.40063 .74908 Mdot
.66009 .42081 Mdot
.52909 .50164 Mdot
.7921 .53437 Mdot
.41728 .51385 Mdot
.3348 .47735 Mdot
.67067 .55631 Mdot
.55008 .63052 Mdot
.48437 .33578 Mdot
.564 .87433 Mdot
.6194 .63354 Mdot
.54227 .50722 Mdot
.18938 .35259 Mdot
.51645 .79787 Mdot
.72544 .526 Mdot
.59791 .52655 Mdot
.55013 .31014 Mdot
.41331 .55066 Mdot
.34914 .23864 Mdot
.35928 .74319 Mdot
.18309 .46684 Mdot
.76431 .49503 Mdot
.77865 .59397 Mdot
.58421 .62662 Mdot
.42004 .66784 Mdot
.47217 .25431 Mdot
.2249 .4331 Mdot
.68659 .62052 Mdot
.16785 .38077 Mdot
.39505 .43638 Mdot
.29978 .42991 Mdot
.56303 .65934 Mdot
.20644 .64991 Mdot
.59163 .80979 Mdot
.80128 .50059 Mdot
.4555 .82901 Mdot
.25213 .60489 Mdot
.54338 .76241 Mdot
.32398 .47337 Mdot
.68729 .60899 Mdot
.57564 .40936 Mdot
.38181 .82448 Mdot
.21422 .44717 Mdot
.32146 .35069 Mdot
.35714 .36778 Mdot
.77454 .36872 Mdot
.52973 .2371 Mdot
.36118 .17671 Mdot
.26139 .60642 Mdot
.38654 .82255 Mdot
.71895 .28922 Mdot
.6727 .40122 Mdot
.40986 .243 Mdot
.58597 .66264 Mdot
.33756 .50963 Mdot
.18338 .48104 Mdot
.53805 .58713 Mdot
.41054 .78889 Mdot
.63671 .54592 Mdot
.39579 .80162 Mdot
.45069 .63721 Mdot
.22015 .5022 Mdot
.35447 .30001 Mdot
.65692 .76098 Mdot
.3976 .19856 Mdot
.57405 .32729 Mdot
.4202 .15742 Mdot
.39795 .2066 Mdot
.1778 .38965 Mdot
.45122 .80063 Mdot
.69795 .75864 Mdot
.28281 .33943 Mdot
.33113 .27398 Mdot
.3916 .28781 Mdot
.7197 .59768 Mdot
.30191 .66269 Mdot
.54728 .63927 Mdot
.48986 .26872 Mdot
.41771 .36986 Mdot
.28655 .82301 Mdot
.42858 .68879 Mdot
.59299 .34838 Mdot
.27908 .64381 Mdot
.16503 .42469 Mdot
.71803 .63246 Mdot
.51328 .18399 Mdot
.50544 .50598 Mdot
.62989 .66337 Mdot
.7677 .46539 Mdot
.75867 .33726 Mdot
.31154 .67741 Mdot
.809 .67801 Mdot
.64586 .22428 Mdot
.34319 .39159 Mdot
.47863 .50228 Mdot
.61028 .4309 Mdot
.57913 .43691 Mdot
.27475 .58342 Mdot
.50853 .17304 Mdot
.4112 .22886 Mdot
.25444 .30697 Mdot
.80597 .66449 Mdot
.6957 .2885 Mdot
.17305 .53525 Mdot
.36421 .28379 Mdot
.5996 .34964 Mdot
.39718 .58828 Mdot
.34234 .44643 Mdot
.32713 .33908 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Iooooo`;o0000[_oo
ool001cooooo00?o0000ooooooooool0VOooool2o`000:kooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0^_ooool2o`0008gooooo000Looooo`03o`000?oooooo
oooo0;[ooooo0_l0002=ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`2Looooo`;o0000Zoooool001cooooo00?o0000ooooooooool0W?ooool2
o`000:_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo08kooooo0_l0000Nooooo`;o0000VOooool001cooooo00?o0000ooooooooool0S_ooool2
o`0001kooooo0_l00004ooooo`;o00001?ooool2o`0008gooooo000Looooo`03o`000?oooooooooo
0;Cooooo0_l00004ooooo`;o0000SOooool001cooooo00?o0000ooooooooool0XOooool2o`000003
ooooool0003o00000:?ooooo000Looooo`03o`000?oooooooooo0:7ooooo0_l000000ooooooo0000
o`00002Sooooo`007?ooool2o`000:7ooooo0_l0000]ooooo`;o0000N?ooool001cooooo00?o0000
ooooooooool0O?ooool2o`0001Kooooo0_l00003ooooo`;o00001Oooool2o`0002gooooo0_l0001h
ooooo`007?ooool00ol0003oooooooooo`1looooo`;o00001oooool2o`0000gooooo0_l00003oooo
o`;o00003_ooool2o`0001oooooo0_l0001mooooo`007?ooool00ol0003oooooooooo`25ooooo`;o
00008_ooool2o`0001oooooo0_l0001mooooo`007?ooool00ol0003oooooooooo`2Mooooo`;o0000
2_ooool2o`0009kooooo000Looooo`03o`000?oooooooooo09[ooooo0_l000000ooooooo0000o`00
000cooooo`;o0000MOooool001cooooo00?o0000ooooooooool0O_ooool2o`0001[ooooo1_l0000b
ooooo`;o0000MOooool001cooooo00?o0000ooooooooool0O_ooool2o`0000Sooooo0_l0000Aoooo
o`Go000000?oooooo`000?l00000Y_ooool001cooooo00?o0000ooooooooool0L_ooool2o`0000Co
oooo0_l0000>ooooo`;o000000Coooooo`000?l0003o00002Oooool2o`000003ooooool0003o0000
00Gooooo0_l000000ooooooo0000o`00000?ooooo`;o00001_ooool2o`0008[ooooo000Looooo`03
o`000?oooooooooo07;ooooo0_l00004ooooo`;o000000?oooooo`000?l000002_ooool7o`0000Wo
oooo0_l000000ooooooo0000o`000003o`0000Gooooo1?l0000;ooooo`Co00001_ooool2o`0008[o
oooo000Looooo`03o`000?oooooooooo07Wooooo1?l00006ooooo`;o00000_ooool4o`0000?ooooo
0_l00009ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`000003ooooool0003o000000_o
oooo0_l0002Dooooo`007?ooool00ol0003oooooooooo`1iooooo`Co00001_ooool2o`0000Sooooo
1ol00005ooooo`;o00000_ooool2o`0000Cooooo0_l0000=ooooo`Ko00000oooool2o`0008cooooo
000Looooo`03o`000?oooooooooo07Kooooo0_l0000@ooooo`;o00000oooool2o`000003ooooool0
003o000000Co00001oooool2o`0000Cooooo0_l0000=ooooo`So000000?oooooo`000?l00000S?oo
ool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`00
0?oooooooooo07Kooooo0_l00003ooooo`;o00002Oooool4o`0000Kooooo0_l000001?oooooo0000
o`000?l00002ooooo`;o00000_ooool2o`0000Gooooo0_l000000ooooooo0000o`000003ooooo`;o
00000oooool2o`0000Cooooo1?l00003ooooo`;o0000R_ooool00006oooooomgMgOoV9RHoooooonH
V9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooo
oooo07Gooooo0ol00003ooooo`;o00002?ooool3o`0000kooooo1?l00002ooooo`;o00002?ooool2
o`0000?ooooo0_l00003ooooo`Co00000_ooool2o`0000?ooooo1?l0002:ooooo`0000?ooooooa0@
4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000oooo
ooooool0JOooool2o`0000Kooooo1ol00005ooooo`;o000000?oooooo`000?l000000oooool3o`00
00gooooo0ol00005ooooo`;o00004oooool2o`0000Oooooo0_l0000=ooooo`;o0000OOooool00003
ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06ooooo`?o
0000JOooool2o`0000Kooooo1?l00008ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Oo
oooo0_l000000ooooooo0000o`000004o`0000Gooooo0_l0000Cooooo`;o00000_ooool2o`0001;o
oooo0_l000000ooooooo0000o`00001jooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooo
ooooo`0<ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0Soooool2o`000005oooo
ool0003o0000o`000?ooool01?l0000Cooooo`;o00001oooool2o`0000gooooo0_l00006ooooo`;o
0000N_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool03Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo073ooooo0_l0000<ooooo`;o00003_ooool4o`0000Kooooo
0_l0000Cooooo`;o00001Oooool2o`0000oooooo0_l00022ooooo`0000KoooooogMgMonHV9Sooooo
oiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`1`oooo
o`Go00002?ooool3o`0000kooooo1?l00005ooooo`;o00004oooool2o`0000Kooooo0_l000000ooo
oooo0000o`00000Fooooo`;o00000oooool2o`0007?ooooo00001_ooooook^k^oc8b<_l0003o<S8b
onk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo06gooooo0_l0
0002ooooo`Co00002?ooool2o`0001Sooooo0_l0000Cooooo`;o00001oooool5o`0000Kooooo0_l0
000=ooooo`?o00000_ooool2o`0007?ooooo000Looooo`03o`000?oooooooooo06gooooo0_l0000J
ooooo`;o00001?ooool3o`0000;ooooo1Ol00007ooooo`;o00004oooool2o`000003ooooool0003o
000000Kooooo0_l0000;ooooo`;o000000?oooooo`000?l000001?l0000=ooooo`;o0000I?ooool0
01cooooo00?o0000ooooooooool0L?ooool2o`0000_ooooo0_l0000:ooooo`;o00000_ooool5o`00
00;ooooo0ol00004ooooo`Oo00000_ooool2o`0000Sooooo0_l0000Mooooo`;o00000oooool2o`00
0003ooooool0003o000000cooooo0_l0001Tooooo`007?ooool00ol0003oooooooooo`1`ooooo`;o
00002oooool2o`0000Sooooo0_l00004ooooo`;o00000_ooool2o`000003ooooool0003o000000;o
oooo0_l000000ooooooo0000o`000004o`0000?ooooo0_l00008ooooo`;o00002Oooool2o`0001?o
oooo0_l00005ooooo`;o0000L_ooool001cooooo00?o0000ooooooooool0I_ooool2o`0001Sooooo
0ol00004ooooo`;o00002?ooool2o`000003ooooool0003o000000;ooooo0_l00005ooooo`;o0000
00?oooooo`000?l000003Oooool2o`0000Kooooo0_l0000Booooo`?o00000_ooool2o`0000?ooooo
0_l00003ooooo`;o0000Joooool001cooooo00?o0000ooooooooool0I_ooool4o`0000;ooooo0_l0
000:ooooo`?o00001Oooool4o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l0
00000ooooooo0000o`000003ooooo`;o00002?ooool2o`0000Kooooo0_l00004ooooo`;o00003?oo
ool2o`0000?ooooo1?l000000ooooooo0000o`000003ooooo`;o00003?ooool2o`0005gooooo000L
ooooo`03o`000?oooooooooo06Sooooo0_l00002ooooo`;o00002_ooool3o`0000Kooooo0ol00005
ooooo`;o00001Oooool2o`0000Gooooo1?l00003ooooo`;o00001oooool2o`0001Kooooo0_l00006
ooooo`;o00002oooool2o`0001Cooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1Soooo
o`;o00004Oooool2o`0000Cooooo0_l00003ooooo`;o00003oooool2o`0000Cooooo0ol00003oooo
o`;o00002_ooool2o`00017ooooo1?l00006ooooo`;o00000_ooool2o`000003ooooool0003o0000
00Cooooo1?l0000Cooooo`;o0000G?ooool001cooooo00?o0000ooooooooool0F_ooool2o`0000Oo
oooo0_l00009ooooo`;o00001_ooool4o`0000;ooooo0_l0000Dooooo`;o00001?ooool2o`0000ko
oooo1?l00003ooooo`;o00003?ooool4o`0000;ooooo0_l00006ooooo`Go00001_ooool2o`0000co
oooo0_l00005ooooo`;o0000G?ooool001cooooo00?o0000ooooooooool0F_ooool2o`0000?ooooo
0_l000001?oooooo0000o`000?l00009ooooo`;o00002?ooool4o`0000Gooooo0_l00003ooooo`;o
00002_ooool2o`0000Cooooo1?l000000ooooooo0000o`000004ooooo`;o00000oooool2o`0000Co
oooo1?l0000Aooooo`;o00002?ooool2o`0001Gooooo0_l0001Sooooo`007?ooool00ol0003ooooo
ooooo`1Oooooo`;o000000?oooooo`000?l000000oooool2o`00017ooooo0_l00005ooooo`;o0000
0oooool2o`0000?ooooo0_l00003ooooo`Co00001?ooool4o`000003ooooool0003o000000Cooooo
0_l00005ooooo`;o00000_ooool6o`0000Oooooo0_l00007ooooo`;o00004Oooool2o`0000Gooooo
0_l0001Yooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o00002?ooool2o`00017ooooo0_l0
0004ooooo`;o00002Oooool3o`000004ooooool0003o0000o`0001Sooooo0_l00006ooooo`;o0000
00Coooooo`000?l0003o00000oooool2o`0000Oooooo0_l00006ooooo`;o000000?oooooo`000?l0
00001_ooool2o`0000Gooooo0_l0001Yooooo`007?ooool2o`0005kooooo0_l00002ooooo`?o0000
4oooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000000oooool2o`0000Go
oooo0_l000000ooooooo0000o`000002ooooo`;o00002_ooool3o`0000Sooooo0_l00009ooooo`?o
000000?oooooo`000?l000004Oooool2o`000003ooooool0003o000000oooooo0_l00005ooooo`Co
000000?oooooo`000?l00000Foooool001cooooo00?o0000ooooooooool0F_ooool2o`0000Gooooo
0ol000000ooooooo0000o`00000?ooooo`?o00000oooool4o`0000Gooooo0_l00003ooooo`;o0000
0oooool2o`000005ooooool0003o0000o`000?ooool00ol00006ooooo`?o00002?ooool2o`0000Ko
oooo0_l00005ooooo`;o00001oooool3o`0000Kooooo0_l00002ooooo`;o00003oooool2o`0000;o
oooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000005_ooooo000Looooo`03o`00
0?oooooooooo05[ooooo0_l00004ooooo`;o00000oooool2o`0000Sooooo0_l00005ooooo`;o0000
1?ooool8o`0000Kooooo0_l00006ooooo`?o000000Coooooo`000?l0003o00003?ooool2o`0000_o
oooo0_l00002ooooo`;o000000?oooooo`000?l000001oooool3o`0000Kooooo0_l0000Gooooo`;o
00001_ooool2o`0005_ooooo000Looooo`03o`000?oooooooooo05cooooo0_l00002ooooo`?o0000
1oooool2o`0000?ooooo0_l0000?ooooo`Go00000oooool2o`0001_ooooo0_l00007ooooo`Ko0000
0_ooool5o`0000gooooo0_l0000Cooooo`;o00000oooool2o`0000Sooooo0_l0001Kooooo`007?oo
ool00ol0003oooooooooo`1Looooo`;o00000oooool2o`0000Oooooo0_l0000Gooooo`;o00000ooo
ool5o`000003ooooool0003o000000?o00001?ooool2o`0000?ooooo0_l00007ooooo`;o00001ooo
ool5o`0000Gooooo0ol00006ooooo`;o00001Oooool2o`0000Kooooo0_l00006ooooo`;o00000ooo
ool2o`0000?ooooo0_l000000ooooooo0000o`00001Rooooo`007?ooool00ol0003oooooooooo`1^
ooooo`?o00000oooool2o`0000?ooooo1?l0000<ooooo`Co000000?oooooo`000?l000000ol00004
ooooo`;o00000oooool2o`0000Oooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo1_l0
000<ooooo`;o00001Oooool2o`000003ooooool0003o000000?ooooo0ol00005ooooo`;o00002ooo
ool2o`0006;ooooo000Looooo`03o`000?oooooooooo05Kooooo1?l0000Dooooo`?o00000oooool2
o`0000?ooooo1_l0000Looooo`;o00002oooool2o`000003ooooool0003o000000Cooooo1?l0000C
ooooo`Go00001?ooool2o`000003ooooool0003o000000Sooooo0_l00005ooooo`;o0000H_ooool0
01cooooo00?o0000ooooooooool0C_ooool2o`0000Kooooo1?l00008ooooo`;o00001?ooool2o`00
00Kooooo0_l00006ooooo`;o00000oooool2o`0000gooooo0_l0000=ooooo`;o00005?ooool2o`00
00[ooooo0_l0000;ooooo`;o00002?ooool2o`0000Sooooo0_l000000ooooooo0000o`000002o`00
06Cooooo000Looooo`03o`000?oooooooooo04kooooo0_l00002ooooo`;o00001?ooool2o`0000Ko
oooo1?l000000ooooooo0000o`000003o`0000Kooooo0_l00006ooooo`;o00004_ooool2o`0000Oo
oooo0ol00006ooooo`;o00007Oooool2o`0002;ooooo1_l000000ooooooo0000o`000004ooooo`;o
0000FOooool001cooooo00?o0000ooooooooool0DOooool3o`0000cooooo0_l00003ooooo`?o0000
1_ooool2o`0001cooooo1?l00005ooooo`?o00001_ooool2o`0003Oooooo0_l00009ooooo`;o0000
00Coooooo`000?l0003ooooo0_l00004ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0
DOooool3o`00013ooooo0_l00008ooooo`Co00001_ooool3o`0000Cooooo0_l0000=ooooo`;o0000
00?oooooo`000?l00000<_ooool3o`0000[ooooo0_l00003ooooo`;o00002Oooool2o`0000;ooooo
0_l00003ooooo`;o00002_ooool2o`00053ooooo000Looooo`03o`000?oooooooooo05;ooooo0_l0
000@ooooo`;o000000?oooooo`000?l000000_l00005ooooo`;o000000?oooooo`000?l000000ooo
ool9o`0000[ooooo0ol00003ooooo`;o00002oooool2o`0001_ooooo0_l00008ooooo`?o00002_oo
ool3o`0000;ooooo1?l0000;ooooo`;o00000oooool2o`0000[ooooo0_l0001@ooooo`007?ooool0
0ol0003oooooooooo`1Booooo`;o00004oooool4o`0000Kooooo4?l00002ooooo`;o000000?ooooo
o`000?l000000oooool3o`00013ooooo0ol0000@ooooo`Co00001_ooool2o`0000Kooooo0_l00000
0ooooooo0000o`00000;ooooo`Wo00000_ooool4o`0000Cooooo0_l0001Qooooo`007?ooool00ol0
003oooooooooo`1<ooooo`Co00003_ooool2o`0000;ooooo0_l00004ooooo`;o00001oooool2o`00
0003ooooool0003o000000Oo00001_ooool2o`000004ooooool0003o0000ooooo`;o00001oooool2
o`0000[ooooo0ol0000>ooooo`Ko00003_ooool2o`00013ooooo0ol00002ooooo`;o00000_ooool4
o`0000Cooooo0_l00008ooooo`;o00000_ooool2o`0005?ooooo000Looooo`03o`000?oooooooooo
04cooooo1?l0000>ooooo`;o00000_ooool2o`0000Cooooo0_l00007ooooo`;o00000oooool3o`00
0003ooooool0003o000000gooooo0_l00005ooooo`Co00000_ooool2o`000003ooooool0003o0000
00[ooooo0_l00008ooooo`;o000000?oooooo`000?l000004oooool2o`00017ooooo0_l00003oooo
o`Co00000oooool2o`0000;ooooo0_l00004ooooo`;o00000_ooool2o`0000Oooooo0ol00019oooo
o`007?ooool00ol0003oooooooooo`1@ooooo`;o00002?ooool2o`0000Kooooo0_l0000=ooooo`;o
00006oooool4o`0000Cooooo1Ol00002ooooo`;o000000?oooooo`000?l000000oooool2o`0000_o
oooo0_l0000:ooooo`;o00001oooool2o`0000;ooooo0_l0000:ooooo`;o00001_ooool6o`000003
ooooool0003o000000;ooooo0_l0000=ooooo`;o00000_ooool3o`0004Wooooo000Looooo`;o0000
Boooool4o`0000;ooooo0_l00007ooooo`?o000000?oooooo`000?l000000oooool2o`0000_ooooo
0_l0000=ooooo`;o00000_ooool2o`0000Cooooo0_l00004ooooo`;o00001Oooool2o`000003oooo
ool0003o000000?ooooo0_l000000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l00000
4?ooool4o`0000_ooooo0_l00009ooooo`?o00000_ooool4o`000004ooooool0003o0000ooooo`;o
000000?oooooo`000?l000000_ooool3o`0000cooooo0_l0001>ooooo`007?ooool00ol0003ooooo
ooooo`11ooooo`;o00001oooool6o`0000Wooooo0_l00002ooooo`;o00004?ooool2o`0000Oooooo
0_l00004ooooo`;o00000_ooool2o`0000Cooooo0_l00005ooooo`;o00000oooool3o`00013ooooo
0_l000000ooooooo0000o`00000@ooooo`;o00006?ooool2o`0000?ooooo1?l000000ooooooo0000
o`000008ooooo`?o0000G?ooool001cooooo00?o0000ooooooooool0@Oooool2o`0000Oooooo0ol0
00001?oooooo0000o`000?l0000?ooooo`;o00001oooool5o`0000Sooooo1?l0000Aooooo`;o0000
0_ooool3o`0000;ooooo0ol0000:ooooo`;o00001oooool6o`0000gooooo0_l00007ooooo`;o0000
0_ooool2o`0000Gooooo0_l000000ooooooo0000o`000002o`00027ooooo0_l0001>ooooo`007?oo
ool00ol0003oooooooooo`1?ooooo`;o00001?ooool2o`0000Wooooo0_l00007ooooo`Go00001ooo
ool4o`0000[ooooo0_l00006ooooo`;o000000?oooooo`000?l000000ol0000>ooooo`;o00001ooo
ool7o`000003ooooool0003o000000Gooooo0ol000000ooooooo0000o`000007ooooo`;o00000_oo
ool2o`0000Gooooo0_l000000ooooooo0000o`00000Fooooo`;o00002_ooool3o`0004kooooo000L
ooooo`03o`000?oooooooooo05Gooooo0_l0000Nooooo`Ko00002?ooool2o`0000Kooooo1Ol00000
0ooooooo0000o`000002o`0001Oooooo1Ol000000ooooooo0000o`000002o`0000;ooooo1?l00000
0ooooooo0000o`000003o`0000Cooooo0_l0000Tooooo`;o00001oooool2o`000003ooooool0003o
000004oooooo000Looooo`03o`000?oooooooooo04Oooooo0_l00003ooooo`;o00001oooool2o`00
01oooooo1Ol0000@ooooo`Co00001?ooool4o`0000Oooooo0_l00008ooooo`;o00000_ooool2o`00
00Cooooo1?l00002ooooo`;o00000oooool5o`0000[ooooo0_l00006ooooo`;o000000?oooooo`00
0?l000005oooool2o`0000?ooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`17ooooo`;o
00000oooool2o`0000gooooo0_l00005ooooo`;o00001oooool2o`0000_ooooo0_l0000>ooooo`;o
00000_ooool2o`0000Cooooo1_l00006ooooo`;o00002?ooool2o`0000Wooooo0_l00009ooooo`Co
00000_ooool2o`0000Kooooo0_l00006ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`00
00oooooo0ol0001Gooooo`007?ooool00ol0003oooooooooo`1Kooooo`;o00001Oooool2o`0000Ko
oooo0ol0000Aooooo`;o00002?ooool2o`0000Gooooo1Ol00002ooooo`;o00009Oooool5o`0000;o
oooo0_l00006ooooo`;o00002_ooool2o`0000Cooooo0_l0000?ooooo`;o00000_ooool3o`0005?o
oooo000Looooo`03o`000?oooooooooo04?ooooo0_l000001?oooooo0000o`000?l00008ooooo`;o
00005oooool2o`0000_ooooo0_l00005ooooo`?o00002_ooool9o`000004ooooool0003o0000o`00
00?ooooo0_l0000<ooooo`;o00001?ooool2o`0000cooooo0ol000000ooooooo0000o`000002oooo
o`;o00001Oooool2o`0000_ooooo0_l00004ooooo`;o00003_ooool2o`0000;ooooo0ol0001Coooo
o`007?ooool00ol0003oooooooooo`10ooooo`;o000000Coooooo`000?l0003ooooo0ol00008oooo
o`;o00005_ooool3o`0000_ooooo0_l00006ooooo`?o00002Oooool=o`0000?ooooo0_l000000ooo
oooo0000o`000009ooooo`;o00001?ooool2o`0000Kooooo0_l00008ooooo`;o00000_ooool2o`00
00?ooooo0_l0000=ooooo`;o00001?ooool2o`0006Sooooo000Looooo`03o`000?oooooooooo043o
oooo0_l0000Mooooo`;o00002?ooool3o`0000Kooooo0_l0000<ooooo`;o00002Oooool;o`0000;o
oooo1?l00002ooooo`;o000000?oooooo`000?l000000_ooool3o`000003ooooool0003o000000So
oooo0_l00002ooooo`;o00002Oooool2o`0000Kooooo1?l0001kooooo`007?ooool00ol0003ooooo
ooooo`11ooooo`?o00004?ooool2o`0000Wooooo0_l00007ooooo`Co00001_ooool2o`0000[ooooo
0_l0000:oooooa;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0ol000000ooooooo0000
o`000008ooooo`?o00002oooool3o`0000Gooooo1Ol0000?ooooo`;o00004_ooool2o`0005Kooooo
000Looooo`03o`000?oooooooooo047ooooo0ol0000<ooooo`;o00000_ooool2o`0000;ooooo0_l0
00000ooooooo0000o`000004o`0000Oooooo0ol0000Cooooo`;o00002OoooolFo`0000?ooooo0_l0
0002ooooo`;o00003?ooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o00000ooo
ool2o`000003ooooool0003o000000;o000000?oooooo`000?l000001Oooool2o`0000Kooooo0ol0
0005ooooo`;o00002_ooool4o`0000kooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0k
ooooo`?o00004?ooool4o`0000Kooooo0_l000000ooooooo0000o`000002o`0000Sooooo1?l00006
ooooo`;o00005?oooolGo`0000Cooooo0_l000000ooooooo0000o`00000@ooooo`;o00000_ooool2
o`0000Cooooo0_l00002ooooo`?o000000?oooooo`000?l000000oooool2o`000003ooooool0003o
000000;ooooo0_l00007ooooo`;o00001Oooool2o`0000[ooooo1?l0000>ooooo`;o0000A?ooool0
01cooooo00?o0000ooooooooool0>oooool3o`00013ooooo0_l00008ooooo`;o000000?oooooo`00
0?l000002?ooool4o`0000Sooooo0_l00007ooooo`;o00002ooooolGo`0000Gooooo1?l00008oooo
o`;o00001_ooool2o`0000Sooooo0_l00002ooooo`Ko000000?oooooo`000?l000000_l000000ooo
oooo0000o`00001fooooo`007?ooool00ol0003oooooooooo`0jooooo`;o00005Oooool2o`0000So
oooo0_l00005ooooo`;o000000?oooooo`000?l000000ol0000@ooooo`;o00001?ooool2o`0000Co
oooo6?l00005ooooo`Go00001oooool2o`0000Cooooo1?l00008ooooo`;o000000?oooooo`000?l0
00000ol00003ooooo`Co000000?oooooo`000?l000003Oooool4o`0000[ooooo0_l0001Iooooo`00
7?ooool2o`0003_ooooo0_l00003ooooo`;o00004?ooool2o`0000?ooooo0_l00007ooooo`;o0000
00Coooooo`000?l0003ooooo0_l000001?oooooo0000o`000?ooool5o`0000gooooo0_l000000ooo
oooo0000o`000002o`0000;ooooo5ol00002ooooo`;o00001?ooool3o`0000gooooo0_l00006oooo
o`Ko000000?oooooo`000?l000000_l00002ooooo`;o000000?oooooo`000?l000003_ooool2o`00
0003ooooool0003o000000;o00002_ooool2o`0005Wooooo000Looooo`03o`000?oooooooooo03Wo
oooo0ol00003ooooo`?o00000oooool2o`000003ooooool0003o000000cooooo0_l00007ooooo`;o
00001?ooool2o`0000Cooooo1Ol0000=ooooo`;o00000oooool2o`0000;ooooo5ol00002ooooo`;o
00006Oooool2o`000003ooooool0003o000000Ko000000Goooooo`000?l0003o0000ooooo`02o`00
0004ooooool0003o0000o`0000;ooooo0_l00003ooooo`;o00001?ooool2o`0000Gooooo0_l0001S
ooooo`007?ooool00ol0003oooooooooo`0iooooo`?o00000oooool4o`0000;ooooo1ol0000Boooo
o`;o00001Oooool2o`0000Gooooo0_l0000Doooooa7o00000_ooool8o`000003ooooool0003o0000
00;o00001Oooool2o`0000Sooooo1?l00005ooooo`Co00000_ooool@o`000004ooooool0003o0000
o`0000?ooooo0_l0000;ooooo`?o00002oooool4o`0005?ooooo000Looooo`03o`000?oooooooooo
03Gooooo0_l00008ooooo`Co00001?ooool2o`000003ooooool0003o000000cooooo0_l00004oooo
o`;o000000?oooooo`000?l000001oooool2o`0001Kooooo4Ol000000ooooooo0000o`00000<o`00
00Gooooo0_l00008ooooo`Co00001OoooolFo`000003ooooool0003o000000?o00003oooool2o`00
0003ooooool0003o000000Cooooo0_l00002ooooo`Co00003oooool2o`0004;ooooo000Looooo`03
o`000?oooooooooo03Gooooo0_l0000Kooooo`;o00001?ooool2o`0000Oooooo0ol00006ooooo`;o
00002_ooool2o`0000kooooo6?l000000ooooooo0000o`00000Hoooooago00000oooool2o`0000go
oooo0_l00004ooooo`;o00005Oooool2o`0004;ooooo000Looooo`03o`000?oooooooooo05;ooooo
0_l00006ooooo`Co000000?oooooo`000?l000000ol00005ooooo`;o00001?ooool5o`0000;ooooo
0_l0000=oooooaco00004Oooool2o`0000;ooooo1ol000000ooooooo0000o`000008o`000003oooo
ool0003o000000Oo00001oooool2o`0001gooooo0_l00006ooooo`;o000000?oooooo`000?l00000
A?ooool001cooooo00?o0000ooooooooool0<_ooool2o`0000Sooooo0_l00002ooooo`;o00001ooo
ool2o`0000oooooo2Ol00006ooooo`;o00000oooool6o`0000?ooooo0_l0000<oooooaco00001ooo
ool2o`0000Sooooo0_l000000ooooooo0000o`00000Po`0000[ooooo0_l000000ooooooo0000o`00
000Booooo`;o00001_ooool2o`000003ooooool0003o000000;o0000@_ooool001cooooo00?o0000
ooooooooool0<_ooool2o`0000Sooooo1_l00007ooooo`Co00001?ooool2o`0000[ooooo1Ol0000<
ooooo`Co00001Oooool2o`0000_ooooo7Ol00007ooooo`;o00001Oooool2o`0000?ooooo8ol00005
ooooo`?o00000_ooool5o`0000kooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00000
1?oooooo0000o`000?l00002ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0>_ooool2
o`000003ooooool0003o000000Co00001?ooool2o`000004ooooool0003o0000o`0000Cooooo0_l0
0009ooooo`?o000000?oooooo`000?l000001oooool2o`0000Sooooo1_l00008ooooo`;o000000?o
ooooo`000?l000006_l0000?ooooo`;o00000ooooolFo`000003ooooool0003o000000Oo00000ooo
ool2o`0000?ooooo1?l00002ooooo`Co00003_ooool2o`0000Oooooo0_l00002ooooo`;o000000?o
ooooo`000?l000000oooool2o`0003kooooo000Looooo`03o`000?oooooooooo03Kooooo0_l00002
ooooo`;o00000oooool4o`0000Cooooo0_l00003ooooo`;o00000oooool2o`0000Wooooo1?l00009
ooooo`;o00002?ooool4o`0000?ooooo0_l00005ooooo`;o00000ooooolFo`000004ooooool0003o
0000o`0000cooooo0_l00008oooooaCo000000?oooooo`000?l000002?l00002ooooo`Co00000_oo
ool3o`0000?ooooo0ol0001Sooooo`007?ooool00ol0003oooooooooo`0cooooo`;o000000?ooooo
o`000?l000001oooool2o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l000000oooool2
o`0000Sooooo0_l000001?oooooo0000o`000?l0000Iooooo`;o00002_ooool8o`000003ooooool0
003o000000ko00001_ooool2o`000003ooooool0003o000000;ooooo0_l00008oooooaoo00001?oo
ool3o`0000Gooooo1?l0000Cooooo`;o00002Oooool2o`0004Cooooo000Looooo`03o`000?oooooo
oooo03?ooooo0_l0000>ooooo`;o00001?ooool2o`0000?ooooo0ol0000:ooooo`;o00000_ooool2
o`0000cooooo0_l000000ooooooo0000o`00000=ooooo`;o00001Oooool8o`000003ooooool0003o
000000co00000_ooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0000_ooooo7?l0
0003ooooo`;o000000?oooooo`000?l000001Oooool4o`0001?ooooo0_l00004ooooo`;o00000ooo
ool3o`0004?ooooo000Looooo`03o`000?oooooooooo02gooooo0_l00008ooooo`;o00005Oooool5
o`0000Oooooo0_l0000>ooooo`;o000000Coooooo`000?l0003ooooo0_l0000=ooooo`?o000000Co
ooooo`000?l0003ooooo5ol00002ooooo`;o00002_ooool2o`0000Kooooo8Ol00003ooooo`;o0000
2_ooool2o`0001Wooooo0_l00002ooooo`Co0000@oooool001cooooo00?o0000ooooooooool0;Ooo
ool2o`0000Oooooo0ol0000Hooooo`;o00001oooool4o`0000cooooo0_l0000Dooooo`;o000000?o
ooooo`000?l000000_oooolFo`0001Kooooo8_l0000>ooooo`;o00005?ooool2o`0000Oooooo0ol0
0014ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool2o`000003oa0@
4?oooooooooo00Cooooo00?o0000ooooooooool0;?ooool3o`0000Oooooo0_l00008ooooo`;o0000
1_ooool2o`0000oooooo1ol0000<ooooo`;o00003oooool2o`0000Wooooo4_l000000ooooooo0000
o`00000=ooooo`;o000000?oooooo`000?l000000_l00006ooooo`Ko000000?oooooo`000?l00000
5Ol00005ooooo`;o00007Oooool2o`0000Cooooo0_l00003ooooo`?o0000@_ooool00006oooooomg
MgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0/ooooo`;o00000_ooool2o`0000Cooooo0_l00008ooooo`;o00001_ooool2o`0000Ko
oooo0_l00007ooooo`;o00000oooool2o`0000cooooo0_l00008ooooo`;o00001?ooool3o`0000Ko
oooo5Ol0000?ooooo`?o000000?oooooo`000?l000000_l00003ooooo`;o00000_oooolKo`000003
ooooool0003o000000;ooooo1?l0000Pooooo`;o000000?oooooo`000?l000000_ooool4o`0004;o
oooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006ooooo`03o`00
0?oooooooooo02cooooo0_l00002ooooo`;o00001Oooool2o`00017ooooo0_l000001?oooooo0000
o`000?ooool2o`0000;ooooo0_l00005ooooo`;o00005Oooool2o`0000;ooooo0ol00003ooooo`;o
00000_ooool2o`0000?ooooo5ol0000=ooooo`Co00001oooool2o`000003ooooool0003o000001go
00000_ooool2o`0000?ooooo0_l0000Mooooo`;o00001Oooool2o`0004Cooooo00000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`0002_o
oooo0ol00009ooooo`;o00004Oooool2o`000003ooooool0003o000000;o00000oooool2o`0000Go
oooo0_l0000<ooooo`;o00001Oooool6o`000003ooooool0003o000000Oooooo0_l00007ooooo`[o
00001Oooool4o`0000Wooooo0ol00003ooooo`;o00002_oooolNo`0000;ooooo0_l00004ooooo`;o
00006_ooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o000000?oooooo`000?l0
00003_ooool2o`0002kooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo
00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`0Vooooo`;o00000oooool2o`0000Oo
oooo0_l00006ooooo`;o00004Oooool2o`0000;ooooo0_l00003ooooo`;o00003oooool2o`0000Co
oooo0ol00002ooooo`?o00004_ooool:o`000003ooooool0003o000000Cooooo0_l000000ooooooo
0000o`000006ooooo`?o00000_ooool2o`0000cooooo2?l000000ooooooo0000o`00000Bo`0000;o
oooo0_l00009ooooo`;o00004?ooool2o`000003ooooool0003o000000;o00001Oooool2o`0000Co
oooo0_l000000ooooooo0000o`00000>ooooo`;o0000;_ooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool02_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo02Kooooo
0_l00003ooooo`;o00001oooool3o`0000Gooooo0_l0000>ooooo`;o00001?ooool3o`0000?ooooo
0_l000000ooooooo0000o`000009ooooo`;o00001oooool2o`0000Cooooo0_l00003ooooo`;o0000
0_ooool2o`0000_ooooo1Ol00004ooooo`;o00001oooool2o`0000_ooooo0_l00009ooooob;o0000
2oooool2o`00013ooooo0_l000000ooooooo0000o`000005ooooo`Co00002oooool2o`0003[ooooo
00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l000001oooool00ol0003o
ooooooooo`0cooooo`Co00001Oooool2o`0000;ooooo0_l0000:ooooo`Co00000_ooool2o`0000Oo
oooo1?l00007ooooo`;o00002Oooool2o`0000Oooooo0_l00002ooooo`;o00002Oooool2o`0000Go
oooo0_l00005ooooo`;o00003oooool2o`0000Wooooo9?l00004ooooo`;o00000_ooool2o`0001go
oooo1_l00003ooooo`;o00001?ooool2o`0003[ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^
kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`0cooooo`;o00001oooool2o`00
00;ooooo0_l0000<ooooo`;o00000_ooool2o`0000?ooooo0_l00004ooooo`;o00004_ooool2o`00
01Kooooo0_l00005ooooo`;o00001Oooool2o`0000;ooooo0_l0000;ooooo`;o00002?ooool3o`00
0003ooooool0003o000000;ooooo7?l00005ooooo`;o00000_ooool2o`0001Kooooo0_l00009oooo
o`;o00000oooool2o`00043ooooo000Looooo`03o`000?oooooooooo02Wooooo0_l000000ooooooo
0000o`000005ooooo`;o00002oooool2o`0000_ooooo0_l00003ooooo`Co000000?oooooo`000?l0
00000_ooool2o`0000gooooo0_l0000;ooooo`;o00001Oooool5o`0000Kooooo0_l00006ooooo`;o
00002?ooool2o`0000_ooooo1?l00006ooooo`;o00001Oooool;o`000003ooooool0003o000000oo
00000oooool2o`0001cooooo0_l0000<ooooo`;o00002Oooool2o`0003Oooooo000Looooo`03o`00
0?oooooooooo02Wooooo0_l000000ooooooo0000o`000005ooooo`;o00000_ooool2o`0000Oooooo
0_l00002ooooo`;o00001oooool2o`000003ooooool0003o000000Oo00000_ooool3o`0000Oooooo
0_l00003ooooo`;o00000_ooool3o`0000Kooooo0_l00005ooooo`Go00001_ooool2o`0000Kooooo
0_l0000Eooooo`Co000000Coooooo`000?l0003o00001_oooolLo`000004ooooool0003o0000o`00
00?ooooo0_l00002ooooo`;o00006?ooool2o`0000cooooo0_l00009ooooo`;o0000=oooool001co
oooo00?o0000ooooooooool08Oooool2o`0000[ooooo0_l00003ooooo`;o00000oooool2o`0000_o
oooo1_l00006ooooo`?o000000Coooooo`000?l0003o00001Oooool2o`0000Oooooo0_l00007oooo
o`?o00002oooool2o`0000Cooooo0_l0000<ooooo`;o00004?ooool2o`0000Cooooo0_l00003oooo
o`Co000000Goooooo`000?l0003o0000ooooo`03o`000004ooooool0003o0000oooooaGo000000Co
ooooo`000?l0003o00001oooool2o`00037ooooo0_l0000gooooo`007?ooool00ol0003ooooooooo
o`0Qooooo`;o00002_ooool2o`0000?ooooo0_l00005ooooo`;o00002oooool6o`0000Cooooo1_l0
00000ooooooo0000o`00000<ooooo`;o00004Oooool2o`000004ooooool0003o0000o`0000;ooooo
1_l0000:ooooo`;o00004?ooool2o`0000Cooooo1?l00003ooooo`;o000000Coooooo`000?l0003o
00000_ooool2o`000004ooooool0003o0000o`0000;ooooo4Ol00004ooooo`;o00007Oooool2o`00
00_ooooo0_l0000>ooooo`;o0000=oooool001cooooo00?o0000ooooooooool0>Oooool2o`0000oo
oooo0_l00003ooooo`Ko00000_ooool2o`0000Gooooo0_l00005ooooo`;o00004Oooool2o`000003
ooooool0003o000000?ooooo0_l00002ooooo`;o00002Oooool2o`0000[ooooo0_l00008ooooo`;o
000000?oooooo`000?l000000_l00007ooooo`;o00000_ooool3o`000003ooooool0003o0000013o
000000?oooooo`000?l000001?ooool3o`0001cooooo0_l00006ooooo`;o00000oooool2o`0004Oo
oooo000Looooo`03o`000?oooooooooo02[ooooo0_l0000Iooooo`;o00001_ooool5o`000003oooo
ool0003o000000Wooooo0ol00006ooooo`;o00005Oooool2o`0000;ooooo0_l0000:ooooo`?o0000
2_ooool2o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l000002oooool2o`000003oooo
ool0003o000000;o000000?oooooo`000?l000002ol000000ooooooo0000o`000002o`0000Kooooo
0_l00009ooooo`;o00006Oooool2o`0000;ooooo0ol00008ooooo`?o0000??ooool001cooooo00?o
0000ooooooooool0:_ooool2o`000003ooooool0003o000001Kooooo0_l00005ooooo`?o00003?oo
ool2o`0000;ooooo0_l00005ooooo`?o00004Oooool2o`000004ooooool0003o0000o`0000;ooooo
0_l0000:ooooo`;o00004Oooool2o`0000;ooooo0_l000000ooooooo0000o`00000;ooooo`Oo0000
1?ooool9o`0000;ooooo1?l00006ooooo`;o00002Oooool2o`0001cooooo1?l00008ooooo`Go0000
>_ooool001cooooo00?o0000ooooooooool0;Oooool2o`0000Sooooo0_l00005ooooo`;o00002?oo
ool2o`0000;ooooo0ol0000<ooooo`Co00001_ooool4o`00017ooooo0_l000000ooooooo0000o`00
000Oooooo`;o000000?oooooo`000?l000002Oooool2o`0000Sooooo1?l00002ooooo`;o00001Ooo
ool9o`000003ooooool0003o000000Kooooo0_l0000Wooooo`;o00001_ooool2o`0000;ooooo0_l0
00000ooooooo0000o`00000jooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00001Oooool2
o`0000Sooooo1ol0000:ooooo`;o00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`00000/
ooooo`;o00002Oooool2o`000003ooooool0003o000000Kooooo0_l000000ooooooo0000o`000008
ooooo`;o00001?ooool2o`000003ooooool0003o000000;o000000Goooooo`000?l0003o0000oooo
o`04o`000004ooooool0003o0000o`0000_ooooo0_l0000Eooooo`;o00001Oooool3o`0000[ooooo
0_l00011ooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00003?ooool6o`0000Wooooo0_l0
00000ooooooo0000o`000007ooooo`;o00001oooool2o`0000Oooooo0_l00008ooooo`;o00004ooo
ool2o`0000cooooo0_l00006ooooo`;o000000?oooooo`000?l000004Oooool4o`0000Oooooo0_l0
0002ooooo`;o000000?oooooo`000?l000000_ooool4o`0000;ooooo0_l00003ooooo`;o00004?oo
ool2o`0000Gooooo0ol0001=ooooo`007?ooool00ol0003oooooooooo`0booooo`Co00000oooool2
o`0000Oooooo0_l00003ooooo`;o00003Oooool3o`0000Oooooo0_l00007ooooo`Co00001oooool2
o`0000Sooooo0_l00002ooooo`;o00001?ooool2o`000004ooooool0003o0000o`0000Wooooo1?l0
0006ooooo`;o00001Oooool2o`0000;ooooo0_l0000@ooooo`?o00002Oooool2o`0000Gooooo0_l0
0002ooooo`Oo00001?ooool2o`0001;ooooo1?l00004ooooo`?o0000B_ooool001cooooo0_l0000c
ooooo`Co00001Oooool2o`0000Gooooo2?l0000;ooooo`Co00001oooool2o`0000Gooooo1?l0000G
ooooo`;o00000oooool3o`000004ooooool0003o0000o`0000Sooooo1Ol0000<ooooo`?o00005?oo
ool2o`0000[ooooo1?l0000:ooooo`Co00006?ooool4o`0000Cooooo0ol0001:ooooo`007?ooool0
0ol0003oooooooooo`0booooo`;o00001oooool2o`0000Oooooo1_l000000ooooooo0000o`000002
ooooo`;o00001?ooool2o`0000Wooooo0ol00004ooooo`;o00001oooool2o`00013ooooo0ol00000
1?oooooo0000o`000?l0000=ooooo`;o00003oooool3o`0000Cooooo0_l0000Eooooo`;o000000?o
ooooo`000?l000001?l0000Aooooo`;o00008Oooool2o`0004Gooooo000Looooo`03o`000?oooooo
oooo037ooooo0ol000000ooooooo0000o`00000<ooooo`Co00001?ooool2o`0000;ooooo0_l00002
ooooo`;o00000oooool2o`0000Kooooo0ol000001?oooooo0000o`000?ooool;o`000003ooooool0
003o000000_ooooo1Ol000001Ooooooo0000o`000?l0003ooooo00;o00000_ooool2o`0001Cooooo
1_l00004ooooo`;o00003oooool5o`000004ooooool0003o0000ooooo`Go00004_ooool2o`0001Go
oooo0_l00006ooooo`;o00000_ooool2o`0004Gooooo000Looooo`03o`000?oooooooooo02Oooooo
0_l00007ooooo`?o00000_ooool3o`0000Oooooo0_l00002ooooo`;o00001_ooool2o`0000Kooooo
0_l00003ooooo`;o00002?oooolDo`0000[ooooo0_l00008ooooo`;o00000_ooool2o`0001?ooooo
1_l0000Fooooo`Go000000?oooooo`000?l000000_ooool4o`0002Wooooo0ol00005ooooo`;o0000
1?ooool2o`000003ooooool0003o000000;ooooo0_l0000looooo`007?ooool00ol0003ooooooooo
o`0Wooooo`;o00001oooool2o`0000?ooooo0ol00005ooooo`Co000000?oooooo`000?l000001ooo
ool2o`0000Wooooo0_l0000:ooooo`;o000000?oooooo`000?l000004_l0000=ooooo`;o00006_oo
ool7o`0001Cooooo0_l0000=ooooo`;o0000:Oooool2o`0000_ooooo0_l000001Ooooooo0000o`00
0?l0003ooooo00?o0000>oooool001cooooo00?o0000ooooooooool0<?ooool2o`0000?ooooo1_l0
0002ooooo`;o00000oooool2o`0001;ooooo0_l00006ooooo`;o000000?oooooo`000?l000001_l0
00000ooooooo0000o`00000>o`0000;ooooo1Ol00005ooooo`;o00003?ooool2o`0000cooooo0_l0
00001?oooooo0000o`000?l0000?ooooo`;o00001?ooool2o`0000Cooooo0_l00007ooooo`;o0000
3Oooool2o`0000Gooooo0_l0000Booooo`;o00000oooool2o`0000Gooooo0_l00004ooooo`;o0000
0_ooool2o`0000?ooooo0_l0000fooooo`007?ooool00ol0003oooooooooo`0cooooo`;o000000?o
ooooo`000?l000000ol00006ooooo`;o00002?ooool2o`00017ooooo0_l000000ooooooo0000o`00
000Go`0000;ooooo1Ol0000?ooooo`;o00000_ooool2o`0000_ooooo0ol00008ooooo`;o00002Ooo
ool2o`0000;ooooo0_l00006ooooo`;o00005_ooool2o`0000Gooooo0_l0000Booooo`;o00000ooo
ool2o`0000Gooooo0_l0000=ooooo`;o0000=_ooool001cooooo00?o0000ooooooooool0<oooool2
o`0000_ooooo0ol00005ooooo`Go00001_ooool2o`0000_ooooo6_l0000Fooooo`;o00002oooool2
o`0000;ooooo0_l00009ooooo`;o00003Oooool2o`0001;ooooo0_l00004ooooo`?o00002?ooool2
o`00023ooooo0ol00004ooooo`;o00003?ooool2o`00033ooooo000Looooo`03o`000?oooooooooo
03;ooooo0_l0000:ooooo`Co00001_ooool4o`000004ooooool0003o0000o`0000?ooooo0_l00004
ooooo`;o00001OoooolPo`0000?ooooo0_l00009ooooo`;o00000_ooool2o`0000Wooooo0_l00002
ooooo`;o00000oooool2o`0000Wooooo0ol00003ooooo`;o00002oooool2o`0000Wooooo0_l00004
ooooo`?o00002?ooool2o`0000oooooo0_l0000@ooooo`;o00001?ooool2o`0000cooooo0_l0000`
ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o000000?oooooo`000?l000002_ooool2o`00
00gooooo0ol00009ooooo`;o000000?oooooo`000?l000008_l00003ooooo`;o00000_ooool2o`00
00Gooooo0_l00002ooooo`;o00003_ooool2o`0000;ooooo0_l00008ooooo`Ko000000?oooooo`00
0?l000002oooool2o`0000Sooooo0_l0000Qooooo`;o00006oooool2o`0003Wooooo000Looooo`03
o`000?oooooooooo02oooooo0_l000000ooooooo0000o`000004ooooo`?o00000oooool2o`000003
ooooool0003o000000oooooo0_l00005ooooo`co000000?oooooo`000?l000006Ol00006ooooo`Co
00004_ooool4o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o00000_ooool2o`0000;o
oooo0_l00005ooooo`;o00004Oooool2o`00013ooooo0_l0000Pooooo`;o00002?ooool4o`0000?o
oooo0_l0000dooooo`007?ooool00ol0003oooooooooo`0`ooooo`Co00001?ooool3o`0000Kooooo
0_l00004ooooo`;o00001?ooool2o`0000?ooooo0_l00005ooooo`Go000000?oooooo`000?l00000
0ol00002oooooaco000000?oooooo`000?l000000_l00002ooooo`;o00003Oooool2o`0000?ooooo
1?l00007ooooo`;o00000_ooool2o`0000[ooooo0_l000000ooooooo0000o`00000Booooo`;o0000
1?ooool2o`0000Wooooo0_l00002ooooo`;o00004oooool2o`0000Oooooo0_l00008ooooo`;o0000
1Oooool2o`0003Cooooo000Looooo`03o`000?oooooooooo033ooooo0_l00002ooooo`;o00002ooo
ool2o`0000Cooooo1?l00002ooooo`;o00002_ooool2o`0000Gooooo4ol000000ooooooo0000o`00
0007o`000003ooooool0003o000000;o000000?oooooo`000?l000000_l0000Aooooo`;o00007_oo
ool2o`0000Oooooo1?l0000:ooooo`;o00001?ooool2o`0000_ooooo1Ol0000Booooo`;o00000ooo
ool2o`0004Wooooo000Looooo`03o`000?oooooooooo03Cooooo0_l0000;ooooo`;o00001_ooool2
o`0000kooooo0_l00006oooooa?o000000?oooooo`000?l000002Ol00007ooooo`Co00001_ooool2
o`0000Gooooo1?l00002ooooo`Go00002oooool2o`0000Sooooo0_l00003ooooo`;o00000_ooool4
o`00013ooooo0_l0000;ooooo`;o000000?oooooo`000?l000003?ooool4o`0000;ooooo0_l00003
ooooo`;o00001Oooool2o`0000;ooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`1Hoooo
o`;o00001oooool>o`000003ooooool0003o000000ko00001oooool4o`0000Kooooo0_l00005oooo
o`Co00000_ooool5o`0000_ooooo0_l0000=ooooo`;o00000oooool2o`00017ooooo0_l0000;oooo
o`;o00003oooool4o`0000?ooooo0_l00009ooooo`;o00000_ooool2o`0003kooooo000Looooo`03
o`000?oooooooooo02oooooo0_l0000Booooo`;o00002_ooool3o`0000Kooooo0_l00007oooooaoo
00004_ooool2o`0000Sooooo0_l00006ooooo`;o00003?ooool2o`0000Kooooo0_l00004ooooo`;o
00008?ooool2o`0000?ooooo0_l0000;ooooo`;o00001?ooool2o`0000Wooooo0_l00007ooooo`;o
0000>Oooool001cooooo0_l0000Looooo`;o00004_ooool2o`0000_ooooo0_l00005ooooo`;o0000
2_ooool3o`0000Kooooo0_l00007ooooo`Co000000?oooooo`000?l000002ol000000ooooooo0000
o`00000:o`0001;ooooo0_l00005ooooo`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o
00000_ooool2o`0000Sooooo0_l00006ooooo`Co00000_ooool2o`0000Gooooo0_l0000;ooooo`;o
00003_ooool2o`000003ooooool0003o000000cooooo0_l00005ooooo`;o00000_ooool2o`0000?o
oooo0_l00007ooooo`;o0000>Oooool001cooooo00?o0000ooooooooool06oooool2o`0001;ooooo
1?l00009ooooo`;o000000?oooooo`000?l000000oooool2o`0000kooooo1Ol00008oooooa;o0000
00?oooooo`000?l000002_l0000<ooooo`;o00000_ooool2o`000003ooooool0003o000000?ooooo
0ol00004ooooo`Ko00000oooool4o`0000Kooooo0_l00003ooooo`;o00000oooool2o`000003oooo
ool0003o000000Gooooo0ol0000;ooooo`;o00003_ooool4o`0000gooooo0_l00005ooooo`;o0000
0_ooool2o`0004Oooooo000Looooo`03o`000?oooooooooo02oooooo1?l000000ooooooo0000o`00
0009ooooo`;o00000oooool2o`000003ooooool0003o000000_ooooo1_l00008oooooa3o00000_oo
ool5o`000003ooooool0003o000000Ko00002?ooool4o`0000;ooooo1Ol00003ooooo`;o00001Ooo
ool6o`0000?ooooo1_l00005ooooo`;o00000_ooool4o`000003ooooool0003o000000?o000000?o
ooooo`000?l000000_ooool2o`0001Cooooo0_l00006ooooo`Co00002Oooool2o`0000_ooooo0ol0
000Hooooo`;o0000;_ooool001cooooo00?o0000ooooooooool0:oooool2o`0000Oooooo0_l0000?
ooooo`Go00003_ooool2o`0000Sooooo4?l000000ooooooo0000o`00000=o`0000Sooooo0_l00005
ooooo`Co00002oooool2o`0000?ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00000_oo
ool2o`000003ooooool0003o000000;ooooo1?l00002ooooo`;o00000oooool2o`0001Cooooo0_l0
0002ooooo`;o00001_ooool2o`0000_ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o0000
00Coooooo`000?l0003ooooo0ol00002ooooo`;o00005?ooool2o`0002kooooo000Looooo`03o`00
0?oooooooooo02_ooooo0_l000001?oooooo0000o`000?l0000=ooooo`;o00001Oooool5o`0001So
oooo7?l00006ooooo`;o00005oooool2o`0000Kooooo0_l00002ooooo`Co00000oooool2o`0000Go
oooo1Ol000000ooooooo0000o`000003ooooo`?o000000?oooooo`000?l000004?ooool2o`00013o
oooo0_l00008ooooo`?o000000Coooooo`000?l0003ooooo0_l00006ooooo`;o00001?ooool2o`00
03kooooo000Looooo`03o`000?oooooooooo02kooooo0ol0000<ooooo`?o00001oooool2o`0001Go
oooo0_l00003oooooa_o00001_ooool2o`0001Oooooo0_l00008ooooo`;o00000_ooool2o`0000?o
oooo0_l00004ooooo`;o000000Goooooo`000?l0003o0000ooooo`04o`000005ooooool0003o0000
o`000?ooool00_l00003ooooo`;o00002oooool2o`00013ooooo0_l00006ooooo`;o00005Oooool2
o`0003kooooo000Looooo`03o`000?oooooooooo03gooooo1?l0000Gooooo`;o00001?ooool2o`00
0003ooooool0003o000001_o00005_ooool2o`00017ooooo0_l00007ooooo`;o00001?ooool7o`00
0003ooooool0003o000000;o000000?oooooo`000?l000001_ooool2o`0002Gooooo0_l0000Coooo
o`;o0000@?ooool001cooooo00?o0000ooooooooool0=_ooool2o`0000Oooooo0_l0000=ooooo`?o
00001oooool2o`0000Oooooo0_l00003oooooaOo00000_ooool2o`0000Cooooo0_l0000=ooooo`;o
00003Oooool2o`0000oooooo0ol000000ooooooo0000o`000008o`000003ooooool0003o000003[o
oooo0_l00006ooooo`Co00002Oooool2o`0003?ooooo000Looooo`03o`000?oooooooooo02gooooo
0_l00007ooooo`;o00004?ooool2o`0000Cooooo1?l0000<ooooo`;o00001?oooolIo`0000;ooooo
0ol00003ooooo`;o00001?ooool2o`0001?ooooo0_l000001?oooooo0000o`000?ooool2o`0000co
oooo0ol00002ooooo`[o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00006oooool2o`00
01Gooooo0_l00008ooooo`;o00002Oooool2o`0003?ooooo000Looooo`03o`000?oooooooooo02go
oooo0_l0000>ooooo`;o00001Oooool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l0
00000_ooool2o`0000Sooooo0_l00004ooooo`;o000000?oooooo`000?l000004?l000000ooooooo
0000o`000002ooooo`Co00002Oooool2o`000003ooooool0003o000000_ooooo0_l00003ooooo`;o
00001?ooool2o`0000?ooooo0_l00004ooooo`Ko000000?oooooo`000?l000003ol00002ooooo`;o
00000_ooool2o`0000;ooooo1Ol00005ooooo`;o00002Oooool2o`0000;ooooo1?l0000Aooooo`;o
0000A_ooool001cooooo00?o0000ooooooooool0=?ooool2o`0000?ooooo1_l00004ooooo`?o0000
1oooool2o`0000Gooooo0_l0000<ooooo`Co000000?oooooo`000?l000003ol00002ooooo`;o0000
00Coooooo`000?l0003o00001oooool2o`000004ooooool0003o0000ooooo`?o00002oooool4o`00
00Sooooo0_l00002ooooo`;o00001?ooool3o`000004ooooool0003o0000ooooo`co000000?ooooo
o`000?l000000_l00003ooooo`;o000000?oooooo`000?l000001ol000001?oooooo0000o`000?oo
ool3o`0000?ooooo1?l00006ooooo`Co00004Oooool2o`0004Kooooo000Looooo`03o`000?oooooo
oooo033ooooo0_l00002ooooo`?o00000_ooool4o`0000Kooooo0ol0000Kooooo`?o00000oooool@
o`0000Kooooo0_l00002ooooo`;o00000_ooool4o`000003ooooool0003o000000?o00002_ooool2
o`0000;ooooo0_l00004ooooo`;o00000_ooool2o`0000?ooooo0_l00005oooooa3o00000_ooool4
o`0000?ooooo1?l000000ooooooo0000o`000004o`0000;ooooo0_l000000ooooooo0000o`000004
ooooo`Co00005oooool2o`0000Kooooo0_l00003ooooo`?o0000??ooool001cooooo00?o0000oooo
ooooool0<?ooool2o`0000?ooooo0ol0000:ooooo`Co00001Oooool2o`0001Cooooo0_l00006oooo
o`?o000000?oooooo`000?l000000_l000001?oooooo0000o`000?l0000<ooooo`;o00000_ooool2
o`0000?ooooo0ol0000<ooooo`;o00001_ooool4o`0000?ooooo0_l00002ooooo`;o00001OoooolE
o`000003ooooool0003o000000Go00003_ooool2o`0000kooooo0_l0000=ooooo`;o00001_ooool2
o`0000?ooooo0ol0000looooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00001oooool3o`00
00[ooooo0ol00006ooooo`;o00002oooool2o`00013ooooo0_l00002ooooo`?o000000?oooooo`00
0?l000001?l0000Pooooo`;o00001oooool2o`0000Gooooo0ol00002ooooo`;o00000oooool2o`00
00?ooooo5_l00003ooooo`;o00003?ooool2o`0000Cooooo0_l00008ooooo`;o0000FOooool001co
oooo00?o0000ooooooooool0;?ooool2o`0000Gooooo0_l0000<ooooo`Co000000?oooooo`000?l0
00001?ooool2o`0000[ooooo0_l0000?ooooo`Wo00000_ooool4o`0000Cooooo0_l00007ooooo`;o
00001?ooool2o`0000_ooooo0_l0000?ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o
00000_oooolBo`0000?ooooo0ol0000Booooo`;o00001oooool2o`0000[ooooo0_l0000<ooooo`;o
0000@?ooool001cooooo00?o0000ooooooooool0<oooool2o`0000cooooo0_l00003ooooo`;o0000
0oooool3o`0000Oooooo0_l000000ooooooo0000o`000004ooooo`;o00002Oooool2o`000003oooo
ool0003o000000;ooooo0_l0000:ooooo`;o00001oooool2o`0000Cooooo0_l00006ooooo`;o0000
1?ooool2o`0000?ooooo0_l0000Aooooo`;o00000ooooolCo`000003ooooool0003o000000;o0000
00?oooooo`000?l000000_l00006ooooo`Co00000oooool2o`0000_ooooo0ol00009ooooo`?o0000
2oooool2o`00043ooooo000Looooo`;o0000>oooool4o`000003ooooool0003o000000;o00001Ooo
ool2o`000003ooooool0003o000000;o00001Oooool3o`0000Oooooo0_l00005ooooo`;o00005?oo
ool2o`0000Kooooo0_l00006ooooo`;o00001_ooool2o`0000Cooooo0_l00003ooooo`;o00003_oo
ool6o`0000;ooooo4ol000000ooooooo0000o`000009o`0000Cooooo1Ol00002ooooo`;o00003?oo
ool2o`0000Gooooo0_l00003ooooo`Co00002Oooool3o`0003oooooo000Looooo`03o`000?oooooo
oooo037ooooo0_l00003ooooo`;o00000_ooool4o`000004ooooool0003o0000o`0000Kooooo0_l0
0003ooooo`;o00000oooool6o`0000gooooo0_l0000Booooo`Co000000?oooooo`000?l000000ooo
ool2o`000003ooooool0003o000000?ooooo0ol00006ooooo`;o00006?oooolWo`0000Cooooo0_l0
00000ooooooo0000o`000003ooooo`;o00003oooool2o`000003ooooool0003o000000?ooooo1?l0
0002ooooo`;o00001Oooool3o`0003oooooo000Looooo`03o`000?oooooooooo037ooooo0_l00003
ooooo`;o00002?ooool2o`0000_ooooo0_l00003ooooo`;o00000_ooool2o`0000gooooo0_l00000
0ooooooo0000o`00000?ooooo`;o00000oooool2o`0000Cooooo1_l000001?oooooo0000o`000?l0
0005ooooo`?o00004?ooool2o`0000[ooooo9_l000000ooooooo0000o`000006ooooo`;o00003ooo
ool4o`0000Cooooo0_l00004ooooo`?o00000oooool2o`00047ooooo000Looooo`03o`000?oooooo
oooo03Cooooo0_l0000:ooooo`;o00003?ooool2o`0000Kooooo0_l0000@ooooo`;o00002_ooool2
o`0000kooooo1ol00008ooooo`;o00004Oooool2o`0000Cooooo0_l00002ooooo`Co000000?ooooo
o`000?l000006Ol000001?oooooo0000o`000?ooool4o`0001cooooo0_l0000;ooooo`?o00000_oo
ool2o`00047ooooo000Looooo`03o`000?oooooooooo03Cooooo0_l00005ooooo`;o000000?ooooo
o`000?l000000_l0000<ooooo`;o00001?ooool2o`0000kooooo0_l0000>ooooo`?o00001?ooool2
o`0000?ooooo0_l00006ooooo`?o00001oooool2o`0000_ooooo0_l00005ooooo`;o00001?ooool2
o`0000;ooooo0_l000000ooooooo0000o`00000:o`000003ooooool0003o0000017o00000_ooool2
o`000004ooooool0003o0000o`0000?ooooo0_l0000Eooooo`;o00001_ooool2o`0000?ooooo0_l0
00000ooooooo0000o`000012ooooo`007?ooool00ol0003oooooooooo`0kooooo`;o000000?ooooo
o`000?l000005?ooool2o`0000kooooo0_l0000?ooooo`;o00001?ooool2o`0000?ooooo0_l0000=
ooooo`Ko00000_ooool3o`0000Cooooo0ol00005ooooo`;o00002Oooool4o`0000;ooooo5ol00000
0ooooooo0000o`000003o`000004ooooool0003o0000ooooo`?o00000oooool2o`0000;ooooo0_l0
000<ooooo`;o00000_ooool3o`0000Kooooo0_l00003ooooo`;o000000?oooooo`000?l00000@_oo
ool001cooooo00?o0000ooooooooool0<oooool2o`00017ooooo0_l00005ooooo`?o0000>?ooool2
o`0000Cooooo1ol00002ooooo`?o00001?ooool2o`0000Cooooo0_l000000ooooooo0000o`000005
ooooo`;o000000Goooooo`000?l0003o0000ooooo`0Oo`000004ooooool0003o0000ooooo`;o0000
00?oooooo`000?l000001Oooool2o`0000Gooooo0_l00005ooooo`So00002_ooool4o`0004?ooooo
000Looooo`03o`000?oooooooooo03?ooooo0_l00009ooooo`;o00001_ooool2o`0000Gooooo1?l0
000Cooooo`;o00008_ooool2o`0000Cooooo1Ol0000>ooooo`co000000?oooooo`000?l000000_oo
ool2o`000003ooooool0003o000001go000000?oooooo`000?l000001?ooool2o`0000cooooo0_l0
0002ooooo`;o00000oooool2o`0000;ooooo0_l00006ooooo`;o00000oooool4o`0000Sooooo0_l0
000hooooo`007?ooool00ol0003oooooooooo`0mooooo`?o00001Oooool2o`0000Sooooo0_l0000>
ooooo`;o00000oooool2o`0000_ooooo0_l0000Kooooo`;o000000?oooooo`000?l000003_ooool3
o`000004ooooool0003o0000ooooo`Oo000000Goooooo`000?l0003o0000ooooo`0@o`0000;ooooo
4ol00004ooooo`;o00000oooool2o`0000Wooooo0_l0000?ooooo`;o00001Oooool2o`0000Sooooo
0_l0000hooooo`007?ooool00ol0003oooooooooo`0Gooooo`;o00009?ooool2o`000003ooooool0
003o000000?ooooo0_l00005ooooo`Co00003oooool2o`00013ooooo0_l0000Aooooo`;o00000ooo
ool2o`0000[ooooo0_l0000;ooooo`;o00002Oooool2o`000003ooooool0003o000001Co00000ooo
ool@o`0000Cooooo0_l00003ooooo`;o00002?ooool2o`0000Cooooo0_l0000Dooooo`;o00002?oo
ool2o`0003Gooooo000Looooo`03o`000?oooooooooo01Oooooo0_l0000Tooooo`;o000000?ooooo
o`000?l000000oooool2o`0000Gooooo1?l0000Cooooo`;o00001?ooool2o`0000kooooo0_l00009
ooooo`;o00000_ooool3o`0000Gooooo1ol0000;ooooo`;o00001?ooool2o`0000?ooooo1Ol00000
0ooooooo0000o`00000Co`000003ooooool0003o0000013o00004Oooool2o`0000Cooooo0_l0000D
ooooo`;o00001Oooool2o`000003ooooool0003o000003Gooooo000Looooo`03o`000?oooooooooo
03gooooo0_l0000Aooooo`;o00001?ooool2o`0000Kooooo0_l00003ooooo`;o00001?ooool2o`00
00;ooooo0_l00002ooooo`;o00001_ooool5o`0000[ooooo1?l00004ooooo`Go00000_ooool2o`00
00oooooo0ol00002ooooo`Go000000?oooooo`000?l000002?l000000ooooooo0000o`00000Fo`00
0003ooooool0003o000000Go00001?ooool2o`0000Oooooo0_l000001?oooooo0000o`000?ooool2
o`0000Kooooo0_l00004ooooo`;o00003_ooool2o`0003Sooooo000Looooo`03o`000?oooooooooo
03Kooooo0_l00005ooooo`;o00004?ooool3o`0000Cooooo0_l00006ooooo`;o00003Oooool2o`00
00;ooooo0_l00007ooooo`Co00001?ooool2o`0000Kooooo0_l00005ooooo`;o00001?ooool2o`00
013ooooo1?l00006ooooob_o00001?ooool2o`0000Kooooo0ol000001?oooooo0000o`000?ooool2
o`0000Kooooo0_l00004ooooo`?o00001?ooool2o`00047ooooo000Looooo`03o`000?oooooooooo
03Kooooo0_l00005ooooo`;o00004?ooool4o`0001_ooooo0_l000000ooooooo0000o`000009oooo
o`?o00000oooool2o`0000Cooooo0_l0000Eooooo`?o00001?ooool2o`0000?ooooo1ol00003oooo
obSo00003Oooool2o`0000Gooooo0ol0000;ooooo`?o00001?ooool2o`00047ooooo00001_oooooo
k^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_oo
ool00ol0003oooooooooo`0fooooo`;o00000_ooool4o`0001?ooooo0_l00009ooooo`;o00002_oo
ool2o`0000;ooooo2Ol00008ooooo`;o00000oooool2o`0000Cooooo0_l00006ooooo`?o00003?oo
ool3o`0000Cooooo0_l00005ooooo`Go00000_oooolDo`000003ooooool0003o000001;o00003Ooo
ool2o`0000Gooooo0ol00002ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000
o`000002ooooo`;o0000A?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Co
oooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo03[ooooo1?l0000Koooo
o`;o000000?oooooo`000?l000002_ooool2o`0000;ooooo1Ol00002ooooo`;o00003oooool2o`00
0003ooooool0003o000000Oooooo2?l00008ooooo`;o00001?ooool2o`0000Cooooo1Ol00003oooo
oako000000?oooooo`000?l000001_l000001?oooooo0000o`000?l0000Gooooo`;o000000?ooooo
o`000?l000000ol00005ooooo`;o0000A?ooool00003ooooool@413ooooo00;ooooo00?o410@oooo
ooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0@oooool2
o`0000oooooo0_l00003ooooo`;o00005Oooool2o`0000?ooooo0_l00002ooooo`;o000000?ooooo
o`000?l000000_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000Kooooo0_l0
00000ooooooo0000o`000004o`0000kooooo0_l00004ooooo`;o00001_ooool8o`000003ooooool0
003o000001[o00000oooool3o`0000Oooooo0_l0000Booooo`;o0000COooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0
0013ooooo`;o00003oooool3o`0001Wooooo0_l00003ooooo`;o00000_ooool7o`000003ooooool0
003o000000Sooooo0_l00002ooooo`;o00000oooool2o`0000Sooooo0_l0000?oooooago00000_oo
ool:o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000004ooooo`;o00001?oo
ool2o`0005_ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000
oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo03_ooooo0_l0000<ooooo`;o00000ooo
ool2o`000003ooooool0003o000000;ooooo0_l0000Tooooo`?o00002_ooool5o`0000Oooooo0_l0
0002ooooo`;o00001?ooool2o`0000_ooooo0_l00002ooooobOo00000oooool6o`000003ooooool0
003o000000Cooooo0_l00004ooooo`;o0000Foooool00003ooooool@413ooooo00;ooooo00?o410@
ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo03_ooooo0_l0000<
ooooo`;o00000oooool2o`000003ooooool0003o000001Sooooo0_l00009ooooo`;o00001?ooool2
o`0000Sooooo1_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00002ooooo`;o000000?o
ooooo`000?l000000ol00003ooooo`;o00001_ooool2o`0000?ooooo0_l000000ooooooo0000o`00
000@o`000003ooooool0003o000001Go00000_ooool4o`0000cooooo0_l0000@ooooo`;o0000A_oo
ool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`00
0?oooooooooo053ooooo0_l00002ooooo`;o00005Oooool2o`000003ooooool0003o000000Kooooo
0_l000001?oooooo0000o`000?ooool2o`0000Sooooo0_l000001Ooooooo0000o`000?l0003ooooo
00;o000000?oooooo`000?l000000_ooool3o`0000Cooooo0ol00005ooooo`Co00001?ooool2o`00
00;ooooo3?l000000ooooooo0000o`00000>o`000003ooooool0003o000000ko00000_ooool4o`00
00cooooo0_l00009ooooo`Co00000oooool2o`0004Kooooo00001_ooooook^k^oc8b<_l0003o<S8b
onk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`0Uooooo`;o00005_oo
ool2o`00017ooooo0_l00002ooooo`;o00006?ooool2o`0000Wooooo0_l000000ooooooo0000o`00
0003o`0000Oooooo0ol00004ooooo`Go000000?oooooo`000?l000003Oooool3o`0000Cooooo0_l0
0002ooooo`_o000000?oooooo`000?l000003ol00002ooooo`ko00007_ooool4o`0000?ooooo0_l0
0003ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool09Oooool2o`0001Gooooo0ol0000_
ooooo`;o000000Coooooo`000?l0003o00001Oooool:o`0000Cooooo0ol00005ooooo`Go00007Ooo
oolYo`0000cooooo0_l00007ooooo`;o00002?ooool4o`0000Cooooo0_l00003ooooo`;o0000@Ooo
ool001cooooo00?o0000ooooooooool0??ooool2o`0000[ooooo1?l000000ooooooo0000o`00000?
ooooo`;o00003_ooool2o`000004ooooool0003o0000o`0000Kooooo2ol00002ooooo`?o00001ooo
ool2o`0000kooooo0_l0000:ooooo`;o00000_ooool2o`000003ooooool0003o0000013o00000_oo
ool=o`0000;ooooo0ol000000ooooooo0000o`000009ooooo`;o00001oooool2o`0000Kooooo1?l0
001>ooooo`007?ooool00ol0003oooooooooo`11ooooo`;o00001Oooool4o`000003ooooool0003o
000000oooooo0ol0000=ooooo`;o000000?oooooo`000?l000001?l00002ooooo`;o000000?ooooo
o`000?l000001ol000000ooooooo0000o`000009ooooo`;o00003Oooool3o`0000[ooooo0_l00003
ooooo`;o00000_oooolQo`0000Cooooo0_l0000Jooooo`;o00003_ooool2o`00043ooooo000Loooo
o`03o`000?oooooooooo047ooooo0_l00002ooooo`Oo00000oooool2o`0000;ooooo0_l00008oooo
o`Co00001oooool2o`0000Cooooo0_l000000ooooooo0000o`00000Eo`0000Wooooo0_l0000=oooo
o`;o00001?ooool2o`0000Sooooo1?l00002oooooaco000000?oooooo`000?l000002?l0000Loooo
o`;o00002_ooool4o`00043ooooo000Looooo`03o`000?oooooooooo04Gooooo2Ol000000ooooooo
0000o`000002ooooo`;o00002?ooool2o`0000Wooooo0_l0000<oooooa;o00004oooool2o`0000?o
oooo0_l00004ooooo`;o00000oooool2o`000003ooooool0003o000000?o000000?oooooo`000?l0
00007Ol000000ooooooo0000o`000007o`0001cooooo0_l0000:ooooo`;o0000@_ooool001cooooo
00?o0000ooooooooool0??ooool2o`000003ooooool0003o000000_ooooo1?l000000ooooooo0000
o`000004ooooo`;o00006_oooolEo`0000Sooooo0_l00003ooooo`;o00001?ooool2o`0000kooooo
0_l000000ooooooo0000o`000003o`000003ooooool0003o000000Co00000_oooolCo`000003oooo
ool0003o000000Co00002Oooool2o`0000Cooooo0_l0001Rooooo`007?ooool00ol0003ooooooooo
o`0looooo`;o000000Coooooo`000?l0003ooooo0_l00007ooooo`Go000000?oooooo`000?l00000
1?ooool2o`000003ooooool0003o000000[ooooo0_l0000;oooooaGo00001oooool3o`0000?ooooo
0ol00004ooooo`;o00001?ooool2o`0000;ooooo0_l00006ooooo`;o000000?oooooo`000?l00000
1?ooool4o`000003ooooool0003o000000;o000000?oooooo`000?l000001ol000000ooooooo0000
o`000008o`000003ooooool0003o000000;ooooo0_l00003ooooo`;o00000_ooool4o`0006;ooooo
000Looooo`03o`000?oooooooooo04;ooooo0_l00007ooooo`;o00001?ooool2o`0000;ooooo1?l0
00000ooooooo0000o`00000:ooooo`;o00003?oooolDo`0000Oooooo0_l00005ooooo`;o000000Co
ooooo`000?l0003ooooo0_l00004ooooo`Ko00001_ooool2o`000003ooooool0003o000000Cooooo
1?l000000ooooooo0000o`00000=o`000003ooooool0003o000000Oo000000?oooooo`000?l00000
0_ooool2o`0000Oooooo0_l0001Tooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00003ooo
ool4o`0000cooooo0_l0000=oooooaCo00000_ooool2o`000003ooooool0003o000000[ooooo0_l0
0009ooooo`;o00001Oooool2o`000003ooooool0003o000000Gooooo1?l00003oooooaWo0000M?oo
ool001cooooo00?o0000ooooooooool0>Oooool2o`0000Wooooo0_l0000Aooooo`;o00003?ooool2
o`000003ooooool0003o000000[ooooo6ol00003ooooo`;o00001Oooool2o`0000[ooooo1Ol00000
0ooooooo0000o`000005ooooo`;o000000?oooooo`000?l000001Oooool2o`000003ooooool0003o
000000;o000000Coooooo`000?l0003ooooo0_l000001Ooooooo0000o`000?l0003ooooo00Wo0000
0oooool2o`00017ooooo1?l00003ooooo`;o00001?ooool2o`0004gooooo000Looooo`03o`000?oo
oooooooo02Cooooo0_l0000Cooooo`;o00004oooool2o`0000?ooooo0_l00002ooooo`;o00001?oo
ool3o`0000Sooooo0_l0000:oooooa[o000000Coooooo`000?l0003ooooo0_l00005ooooo`;o0000
2_ooool5o`0000Sooooo0_l00007ooooo`?o000000?oooooo`000?l000001?l00005ooooo`;o0000
00?oooooo`000?l000001?l00002ooooo`;o00000_ooool3o`00017ooooo1?l00003ooooo`;o0000
1?ooool2o`0000;ooooo0_l00019ooooo`007?ooool2o`0002Gooooo0_l0000Iooooo`;o00003Ooo
ool2o`0000?ooooo0_l00008ooooo`?o00003oooool2o`000003ooooool0003o000001Go00001_oo
ool2o`0000_ooooo1?l00002ooooo`;o00003oooool2o`0000;ooooo0_l00002ooooo`;o00000_oo
ool6o`0000Cooooo0ol000000ooooooo0000o`000008o`0000;ooooo0_l0000=ooooo`;o00005?oo
ool2o`000003ooooool0003o000004Kooooo000Looooo`03o`000?oooooooooo03kooooo1?l00008
ooooo`;o00001oooool2o`0000Sooooo0_l00003ooooo`;o00002oooool2o`000003ooooool0003o
000000Ko000000?oooooo`000?l000003?l00005ooooo`;o00001?ooool2o`0000Kooooo1?l00002
ooooo`;o00001_ooool3o`0000Kooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo0ol00007
ooooo`?o00000oooool8o`00017ooooo0_l0000Gooooo`;o0000A_ooool001cooooo00?o0000oooo
ooooool0?_ooool4o`0000Oooooo0ol00008ooooo`?o00001?ooool2o`0000Gooooo1?l0000<oooo
o`So000000?oooooo`000?l000003_l00003ooooo`;o00001?ooool2o`0000Oooooo0_l00003oooo
o`;o00001_ooool3o`0000gooooo2?l00004ooooo`Ko000000?oooooo`000?l000000_l00002oooo
o`;o00000oooool2o`0000kooooo0_l0001Oooooo`007?ooool00ol0003oooooooooo`15ooooo`;o
00000_ooool3o`0000;ooooo0_l00004ooooo`?o00001?ooool2o`0000;ooooo0_l00002ooooo`?o
00003OoooolEo`000003ooooool0003o000000Wooooo0ol00005ooooo`;o00001oooool2o`0000co
oooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000_l00005ooooo`Go
00000_ooool4o`0000;ooooo0_l00003ooooo`;o00003_ooool2o`0005oooooo000Looooo`03o`00
0?oooooooooo04Gooooo0_l00003ooooo`Ko00001?ooool2o`0000Sooooo1ol00002ooooo`;o0000
2_oooolBo`000004ooooool0003o0000ooooo`;o00001_ooool2o`000004ooooool0003o0000o`00
00Gooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o00000oooool2
o`000003ooooool0003o000000;ooooo1_l000000ooooooo0000o`000002o`0000Cooooo0ol00000
0ooooooo0000o`000003o`0000_ooooo0_l00002ooooo`;o00002_ooool2o`0000Cooooo0_l0000=
ooooo`;o0000AOooool001cooooo00?o0000ooooooooool0B_ooool4o`0000Kooooo0_l00008oooo
o`Oo00000_ooool2o`0000Gooooo0_l00003oooooaGo000000?oooooo`000?l000001_ooool4o`00
00;ooooo0_l00009ooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o00001Oooool:
o`0000;ooooo1?l00004ooooo`Ko000000?oooooo`000?l000000_ooool2o`0000Kooooo0ol00002
ooooo`;o000000?oooooo`000?l000001oooool2o`0000Cooooo0_l00006ooooo`;o00001Oooool2
o`0004Gooooo000Looooo`03o`000?oooooooooo04kooooo0_l0000?ooooo`;o00000_ooool2o`00
00Cooooo0_l00003ooooo`;o00001?oooolCo`0000_ooooo0ol00002ooooo`;o00001Oooool2o`00
00?ooooo0_l000000ooooooo0000o`00000:ooooo`;o000000?oooooo`000?l000001Ol00002oooo
o`;o00000oooool4o`000003ooooool0003o000000Ko00000_ooool4o`0000Kooooo0_l00006oooo
o`;o00001Oooool4o`0000cooooo0_l00005ooooo`;o0000AOooool001cooooo00?o0000oooooooo
ool0@oooool2o`0000Wooooo0_l0000Iooooo`;o00002_oooolDo`0000Wooooo0_l0000:ooooo`Co
000000Coooooo`000?l0003ooooo0_l00006ooooo`;o00000_ooool3o`0000Wooooo0_l00002oooo
o`Go000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000002ooooo`;o00001Oooool2
o`0000?ooooo0_l0000:ooooo`?o00005Oooool2o`0004Gooooo000Looooo`03o`000?oooooooooo
04;ooooo0ol0000Cooooo`;o00001oooool2o`0000?ooooo0ol0000;ooooo`Co000000?oooooo`00
0?l000002Ol000000ooooooo0000o`000002o`0000_ooooo0_l00004ooooo`;o00001?ooool2o`00
00;ooooo1?l00006ooooo`?o00000_ooool2o`0000gooooo0ol0000=ooooo`?o000000Coooooo`00
0?l0003ooooo0_l00003ooooo`?o00002Oooool2o`0000Gooooo0_l0000<ooooo`;o0000B?ooool0
01cooooo00?o0000ooooooooool0?Oooool2o`0000?ooooo0_l0000<ooooo`;o00000_ooool2o`00
00;ooooo0_l00007ooooo`;o00000oooool3o`0000Sooooo0_l000000ooooooo0000o`00000>o`00
013ooooo0_l00004ooooo`;o00001_ooool8o`0000Cooooo0ol00005ooooo`;o00005?ooool2o`00
00Cooooo0ol000000ooooooo0000o`000003ooooo`;o00000_ooool4o`0000;ooooo0_l0000:oooo
o`;o000000?oooooo`000?l000002Oooool2o`0000;ooooo0_l00014ooooo`007?ooool00ol0003o
ooooooooo`0mooooo`;o00004Oooool2o`000003ooooool0003o000000;o000000?oooooo`000?l0
00005oooool2o`0000;ooooo3Ol0000Booooo`;o00000oooool2o`0000Oooooo0_l00004ooooo`;o
00002Oooool2o`000003ooooool0003o000000Wooooo0_l00009ooooo`;o00001Oooool4o`0000Co
oooo0_l00002ooooo`Co00000_ooool2o`0000Cooooo0_l00005ooooo`Co00003Oooool2o`0004Co
oooo000Looooo`03o`000?oooooooooo05?ooooo1?l000001?oooooo0000o`000?ooool2o`0000_o
oooo0_l0000<ooooo`;o000000?oooooo`000?l000001ol0000<ooooo`;o00002Oooool2o`0001Co
oooo0_l00002ooooo`;o00002oooool3o`00013ooooo1?l000000ooooooo0000o`000005ooooo`Co
00002?ooool2o`0000Gooooo0_l0000Fooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0
@oooool2o`00013ooooo0_l000001?oooooo0000o`000?ooool2o`0000_ooooo0_l00003ooooo`;o
00001oooool<o`0000Gooooo0_l00005ooooo`;o000000?oooooo`000?l000002Oooool2o`00017o
oooo0_l00005ooooo`;o00002?ooool2o`0000Sooooo0_l0000<ooooo`;o00005?ooool2o`0001[o
oooo0_l0000mooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00004?ooool2o`000003oooo
ool0003o000000Oooooo0_l0000:ooooo`;o00002?ooool4o`0000;ooooo0_l000001?oooooo0000
o`000?ooool6o`0000Kooooo1?l000000ooooooo0000o`000002ooooo`;o00000_ooool4o`0001Ko
oooo1Ol0000?ooooo`;o00003?ooool2o`000003ooooool0003o000000Kooooo0_l000000ooooooo
0000o`000006ooooo`;o000000?oooooo`000?l00000E_ooool001cooooo00?o0000ooooooooool0
COooool2o`0000Wooooo1?l00005ooooo`?o00002oooool2o`0000Kooooo0ol000000ooooooo0000
o`000006ooooo`Co00002?ooool3o`0000;ooooo0_l00002ooooo`Co00000_ooool2o`0000Sooooo
0_l0000=ooooo`Co00001_ooool2o`0001Sooooo1?l00004ooooo`Go00002Oooool2o`0005Kooooo
000Looooo`03o`000?oooooooooo04_ooooo1?l00005ooooo`Co00000_ooool2o`0000Kooooo0_l0
0003ooooo`;o00001_ooool2o`0000Oooooo0_l000000ooooooo0000o`000007ooooo`;o00001_oo
ool6o`000003ooooool0003o000000Cooooo0ol0000<ooooo`;o00001_ooool2o`0000Oooooo0_l0
0006ooooo`;o00006_ooool2o`0000Gooooo0_l0001Sooooo`007?ooool2o`0004[ooooo1?l00007
ooooo`Co00002_ooool2o`0000?ooooo1Ol00007ooooo`;o00001_ooool2o`0000Sooooo0_l00005
ooooo`Go00000_ooool2o`0000Cooooo0_l0000<ooooo`;o00001oooool2o`0002Oooooo0_l00005
ooooo`;o0000Ioooool001cooooo00?o0000ooooooooool0BOooool2o`0001Oooooo0_l000001?oo
oooo0000o`000?ooool4o`0000Oooooo0ol00002ooooo`Go00001?ooool6o`0000[ooooo0_l00009
ooooo`;o00002?ooool3o`0001Cooooo0_l0000Dooooo`;o000000Coooooo`000?l0003ooooo0_l0
0005ooooo`;o00005_ooool2o`0004oooooo000Looooo`03o`000?oooooooooo06Gooooo0_l00002
ooooo`?o00000_ooool5o`000003ooooool0003o000000;ooooo1?l000000ooooooo0000o`000002
ooooo`Co00003?ooool2o`0000Wooooo0_l00008ooooo`;o00002Oooool2o`0000[ooooo0_l0000D
ooooo`;o000000?oooooo`000?l000002?ooool4o`000003ooooool0003o000000Cooooo0_l0000;
ooooo`;o0000Coooool001cooooo00?o0000ooooooooool0HOooool2o`0000;ooooo0_l00003oooo
o`;o00000_ooool5o`0000[ooooo0ol00002ooooo`;o00001Oooool2o`0000Gooooo0_l00006oooo
o`;o00001Oooool2o`0000Gooooo0_l00005ooooo`Ko0000:oooool6o`000003ooooool0003o0000
00Cooooo0_l0001Looooo`007?ooool00ol0003oooooooooo`1Pooooo`?o00000_ooool2o`0000?o
oooo0_l0000Booooo`;o00002Oooool2o`0000?ooooo1_l00004ooooo`Co00000oooool2o`0000co
oooo1ol00002ooooo`;o00007_ooool2o`0000;ooooo0_l00002ooooo`?o00005oooool2o`0004oo
oooo000Looooo`03o`000?oooooooooo063ooooo0_l00003ooooo`?o00000_ooool2o`0000Cooooo
0_l0000<ooooo`;o00002Oooool2o`0000;ooooo0ol00002ooooo`;o00001_ooool2o`0000Kooooo
0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000?o000000Coooooo`000?l0
003o00000_ooool2o`0001kooooo0_l00002ooooo`;o00007?ooool2o`0004oooooo000Looooo`03
o`000?oooooooooo06Kooooo1_l00004ooooo`;o00005_ooool4o`000004ooooool0003o0000o`00
01;ooooo0_l000001?oooooo0000o`000?ooool2o`000004ooooool0003o0000ooooo`;o00001_oo
ool2o`0001[ooooo0_l0000>ooooo`;o0000IOooool001cooooo00?o0000ooooooooool0Doooool2
o`0000Kooooo0_l0000:ooooo`?o00001_ooool5o`0000Wooooo0_l00008ooooo`Co00000_ooool2
o`0000Cooooo0_l0000<ooooo`;o00005?ooool2o`0000_ooooo0_l0000;ooooo`;o00001oooool3
o`000004ooooool0003o0000ooooo`Ko00004Oooool2o`0004kooooo000Looooo`03o`000?oooooo
oooo05?ooooo0_l00006ooooo`;o00002Oooool4o`0000Gooooo1_l00007ooooo`Co00005?ooool2
o`000003ooooool0003o000000Wooooo0_l00007ooooo`Oo00001_ooool2o`0000_ooooo0_l0000@
ooooo`;o00000_ooool3o`000003ooooool0003o000000?ooooo1?l0000Aooooo`;o0000C_ooool0
01cooooo00?o0000ooooooooool0I_ooool4o`000003ooooool0003o000000;ooooo0_l0000;oooo
o`;o00004Oooool2o`000003ooooool0003o000000Ko00001_ooool2o`0000Cooooo0_l00003oooo
o`So00009?ooool2o`00073ooooo000Looooo`03o`000?oooooooooo05cooooo0_l0000:ooooo`;o
000000?oooooo`000?l000000_ooool4o`0000kooooo0_l0000;ooooo`?o000000Coooooo`000?l0
003ooooo0_l000000ooooooo0000o`000006ooooo`;o00001?ooool2o`0000Gooooo0_l00002oooo
o`;o0000U_ooool001cooooo00?o0000ooooooooool0BOooool2o`0000Kooooo0_l00009ooooo`;o
00002_ooool2o`0000Gooooo1Ol000000ooooooo0000o`00000:ooooo`;o00001oooool2o`000004
ooooool0003o0000o`0000Gooooo0_l0000Fooooo`;o0000;?ooool2o`0006cooooo000Looooo`03
o`000?oooooooooo04Wooooo0_l00006ooooo`;o00006?ooool2o`000005ooooool0003o0000o`00
0?ooool00_l000000ooooooo0000o`00000Aooooo`Co000000?oooooo`000?l000001_ooool3o`00
00Oooooo0_l0000:ooooo`;o000000?oooooo`000?l000000_l0000Rooooo`;o00000oooool4o`00
06cooooo000Looooo`03o`000?oooooooooo06_ooooo0_l000001Ooooooo0000o`000?l0003ooooo
00;o00005?ooool2o`0000Gooooo0_l00005ooooo`Ko000000?oooooo`000?l000000_l0000:oooo
o`;o000000?oooooo`000?l000000_l0000Rooooo`;o00000oooool2o`000003ooooool0003o0000
00Kooooo0_l0001Sooooo`007?ooool00ol0003oooooooooo`1Gooooo`;o00004_ooool2o`000004
ooooool0003o0000ooooo`Co00001oooool2o`0000kooooo0_l000000ooooooo0000o`000006oooo
o`Go000000Coooooo`000?l0003o00001_ooool2o`0000Kooooo0ol0000Qooooo`;o00001oooool3
o`0000Kooooo0_l0001Sooooo`007?ooool00ol0003oooooooooo`1Gooooo`;o00004oooool4o`00
0003ooooool0003o000000;o00001Oooool4o`0000Sooooo0_l000001?oooooo0000o`000?ooool2
o`0000Cooooo0_l00003ooooo`Go00000_ooool2o`0000Kooooo0_l00003ooooo`;o000000Cooooo
o`000?l0003o00007?ooool2o`0000?ooooo0ol00006ooooo`;o00005?ooool2o`0005Kooooo000L
ooooo`;o0000@?ooool2o`0002_ooooo1?l00002ooooo`;o00001_ooool2o`0000;ooooo0ol00005
ooooo`;o000000?oooooo`000?l000001Oooool9o`000003ooooool0003o000000Oooooo0_l00006
ooooo`;o00001Oooool2o`0000;ooooo0_l0000Booooo`;o000000?oooooo`000?l000001?ooool4
o`0000Oooooo0_l0000Aooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0?oooool2o`00
01[ooooo0_l00007ooooo`;o00002?ooool2o`0000Oooooo0_l000000ooooooo0000o`000002oooo
o`?o00002?ooool4o`000003ooooool0003o000000;o00000_ooool4o`0000_ooooo0ol0000<oooo
o`;o00000_ooool2o`0001;ooooo0_l00005ooooo`So00001Oooool2o`0006Wooooo000Looooo`03
o`000?oooooooooo05_ooooo0_l00007ooooo`;o00003Oooool2o`0000;ooooo0_l000000ooooooo
0000o`000008ooooo`;o00000oooool4o`000003ooooool0003o000000oooooo1ol0000;ooooo`;o
00007_ooool2o`0000Cooooo0_l0001`ooooo`007?ooool00ol0003oooooooooo`1`ooooo`;o0000
00?oooooo`000?l000000_ooool2o`0000_ooooo0_l00003ooooo`;o00001oooool2o`000003oooo
ool0003o000000Oooooo1Ol00002ooooo`;o00002_ooool4o`0001Oooooo0_l00002ooooo`;o0000
00Coooooo`000?l0003o00002Oooool2o`0006Sooooo000Looooo`03o`000?oooooooooo073ooooo
0_l000000ooooooo0000o`00000Jooooo`;o000000Coooooo`000?l0003ooooo0ol00006ooooo`Co
00000oooool2o`0000Kooooo0_l00004ooooo`;o00005oooool2o`0000;ooooo1_l00009ooooo`;o
0000J?ooool001cooooo00?o0000ooooooooool0L?ooool3o`0000[ooooo0_l00006ooooo`;o0000
2?ooool2o`0000Gooooo0_l00006ooooo`Co00002_ooool4o`0000?ooooo0_l0000Aooooo`;o0000
2_ooool2o`0000Gooooo0_l0001^ooooo`007?ooool00ol0003oooooooooo`1Zooooo`;o00000ooo
ool4o`0000[ooooo0_l00003ooooo`;o000000?oooooo`000?l000003_ooool2o`0000Sooooo0_l0
000:ooooo`Go00005_ooool2o`0000Oooooo0_l00005ooooo`;o000000?oooooo`000?l000006ooo
ool2o`00057ooooo000Looooo`03o`000?oooooooooo06[ooooo0_l00003ooooo`?o00001?ooool2
o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Kooooo1_l0000A
ooooo`;o00001oooool2o`000003ooooool0003o000001Kooooo0_l00005ooooo`;o00004?ooool2
o`0000cooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00002oooool2o`00
01Cooooo0_l00004ooooo`;o00001oooool2o`0000Gooooo0ol00005ooooo`;o000000?oooooo`00
0?l000000ol0000;ooooo`;o00000oooool2o`0000Kooooo1Ol0000_ooooo`;o0000Goooool001co
oooo00?o0000ooooooooool0Doooool3o`0000[ooooo0_l00003ooooo`;o00003oooool2o`0000?o
oooo0_l0000@ooooo`;o00002oooool2o`0000Wooooo1?l00003ooooo`;o00002?ooool4o`0000Ko
oooo0_l00005ooooo`;o0000P?ooool001cooooo00?o0000ooooooooool0E?ooool2o`0000oooooo
0_l0000Dooooo`;o00001_ooool4o`00013ooooo0_l00008ooooo`;o00000_ooool4o`0000oooooo
0_l00004ooooo`Co00001Oooool2o`00083ooooo000Looooo`03o`000?oooooooooo073ooooo0_l0
000Aooooo`Co00003oooool3o`0000Sooooo0_l0000Iooooo`Go00003_ooool2o`0007Sooooo000L
ooooo`03o`000?oooooooooo06[ooooo0_l00004ooooo`;o00004oooool2o`0000;ooooo0_l0000;
ooooo`;o00000oooool2o`0001;ooooo1?l00008ooooo`Go000000?oooooo`000?l000003?ooool2
o`0000;ooooo0_l0000:ooooo`;o0000J?ooool001cooooo00?o0000ooooooooool0E_ooool2o`00
01;ooooo0_l0000Dooooo`Co00000_ooool2o`000004ooooool0003o0000o`0000oooooo0_l00005
ooooo`;o00002oooool4o`0000;ooooo0_l00004ooooo`;o00001?ooool2o`00013ooooo0_l0000:
ooooo`;o0000J?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Go
c<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo05Kooooo0_l000000ooooooo0000
o`00000;ooooo`;o00000oooool2o`0001?ooooo1?l00002ooooo`;o00000_ooool3o`0001Gooooo
0_l0000Aooooo`;o00003oooool6o`0000Kooooo0_l0001eooooo`0000KoooooogMgMonHV9Sooooo
oiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000oooo
ooooool0D?ooool2o`0000?ooooo0_l00002ooooo`;o00002oooool2o`0000?ooooo0_l0000<oooo
o`;o00000_ooool2o`0000cooooo0_l00007ooooo`;o00003_ooool5o`000003ooooool0003o0000
00?ooooo0_l00003ooooo`;o00004?ooool6o`0000Kooooo0_l0001eooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`1@ooooo`;o00000oooool2o`0002;ooooo0_l00002ooooo`;o00002?ooool2o`00
00Cooooo1?l00003ooooo`;o00002_ooool2o`0000;ooooo1Ol000000ooooooo0000o`000003oooo
o`;o00000oooool2o`0000[ooooo0ol00005ooooo`;o00001oooool4o`0007Cooooo00000ooooooo
0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06oooo
o`?o0000OOooool2o`0000Kooooo1?l00002ooooo`Oo00002_ooool2o`0000;ooooo0_l00002oooo
o`;o00000oooool2o`0000Kooooo0_l0000=ooooo`?o00000_ooool2o`0000[ooooo1?l0001doooo
o`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05olc<c?l0003o0000o`00
0?o<c<`01_ooool00ol0003oooooooooo`1Looooo`;o00007oooool2o`0000Kooooo0_l00004oooo
o`;o00000oooool2o`0000[ooooo0_l000000ooooooo0000o`000004ooooo`;o00000_ooool2o`00
00Cooooo1?l0000?ooooo`Go0000P_ooool00003ooooool@413ooooo00;ooooo00?o410@oooooooo
ool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0G?ooool2o`00
01gooooo0_l00007ooooo`;o00002oooool2o`0000cooooo0_l00004ooooo`;o00002?ooool2o`00
00_ooooo0_l00004ooooo`Co00001oooool2o`0007[ooooo00001_ooooooMgMgoiRHV?ooooooV9RH
ogMgM`_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo07;ooooo0_l0
00000ooooooo0000o`000004ooooo`;o00001_ooool3o`0000_ooooo0ol00003ooooo`;o00008ooo
ool2o`0000Kooooo0_l00007ooooo`;o0000N_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^
2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0L_ooool2o`000003
ooooool0003o000000Wooooo0_l000000ooooooo0000o`000006ooooo`Co00000oooool2o`0000?o
oooo0_l00002ooooo`;o00000oooool2o`0000Wooooo0_l0000=ooooo`;o000000?oooooo`000?l0
00002oooool2o`0007gooooo000Looooo`03o`000?oooooooooo07Gooooo0_l00009ooooo`;o0000
1_ooool2o`000003ooooool0003o000000;o00001oooool2o`0000?ooooo0_l00003ooooo`;o0000
2?ooool4o`0000cooooo0_l000000ooooooo0000o`00000;ooooo`;o0000OOooool001cooooo00?o
0000ooooooooool0O?ooool2o`0000[ooooo0_l00004ooooo`;o00001_ooool2o`0000Oooooo0ol0
0008ooooo`Co00003?ooool2o`0000;ooooo0_l00005ooooo`;o0000P_ooool001cooooo00?o0000
ooooooooool0FOooool2o`0001gooooo1_l0000=ooooo`;o000000?oooooo`000?l000003oooool2
o`0001Wooooo0_l00002ooooo`;o00001Oooool2o`0008;ooooo000Looooo`03o`000?oooooooooo
05Wooooo0_l00003ooooo`;o00006?ooool4o`0000Kooooo0_l00007ooooo`Go00001?ooool2o`00
0003ooooool0003o000000;o00006Oooool2o`0009?ooooo000Looooo`03o`000?oooooooooo05ko
oooo0_l00008ooooo`;o00006?ooool2o`0000Sooooo0_l00002ooooo`;o00000_ooool2o`000003
ooooool0003o000000;o00003?ooool2o`0000?ooooo0_l00006ooooo`;o00001?ooool2o`0000?o
oooo1?l00026ooooo`007?ooool00ol0003oooooooooo`1Xooooo`;o00009_ooool2o`0000;ooooo
0_l000000ooooooo0000o`000002ooooo`;o00001Oooool3o`0000;ooooo0_l00003ooooo`;o0000
3?ooool3o`0000;ooooo1?l00026ooooo`007?ooool00ol0003oooooooooo`23ooooo`;o00005_oo
ool2o`0000Gooooo0ol0000Cooooo`;o000000?oooooo`000?l00000S?ooool001cooooo00?o0000
ooooooooool0Poooool4o`000003ooooool0003o000000Gooooo0_l0000Cooooo`Co00001Oooool2
o`0000Kooooo0_l000000ooooooo0000o`00000Hooooo`;o0000MOooool001cooooo00?o0000oooo
ooooool0QOooool2o`000003ooooool0003o000000Gooooo0_l0000Cooooo`Co00001Oooool5o`00
00?ooooo0_l0000Kooooo`;o0000MOooool001cooooo00?o0000ooooooooool0[_ooool4o`0000Go
oooo0_l0000<ooooo`;o0000P_ooool001cooooo00?o0000ooooooooool0/?ooool2o`0000Gooooo
0_l000000ooooooo0000o`000009ooooo`;o000000?oooooo`000?l00000Ooooool001cooooo0_l0
002aooooo`;o00002?ooool2o`0000cooooo0_l0001oooooo`007?ooool00ol0003oooooooooo`1j
ooooo`;o00009_ooool4o`000:?ooooo000Looooo`03o`000?oooooooooo07?ooooo0_l00005oooo
o`;o00005?ooool4o`0000kooooo1?l0002Sooooo`007?ooool00ol0003oooooooooo`1cooooo`;o
00006oooool4o`000003ooooool0003o00000;;ooooo000Looooo`03o`000?oooooooooo07Gooooo
0_l0000Jooooo`;o00000_ooool2o`0001gooooo0_l0002Cooooo`007?ooool00ol0003ooooooooo
o`1eooooo`;o00002oooool2o`0000gooooo0_l00002ooooo`;o00007Oooool2o`0009?ooooo000L
ooooo`03o`000?oooooooooo08;ooooo0_l0000Aooooo`Co00003?ooool2o`000:;ooooo000Loooo
o`03o`000?oooooooooo09Oooooo0_l0000<ooooo`;o00003?ooool2o`0000;ooooo0_l0002@oooo
o`007?ooool00ol0003oooooooooo`2cooooo`;o00000_ooool2o`00093ooooo000Looooo`03o`00
0?oooooooooo08_ooooo0_l0000Zooooo`;o0000T?ooool001cooooo00?o0000ooooooooool0Rooo
ool2o`0001Cooooo0_l0000Dooooo`;o0000T?ooool001cooooo00?o0000ooooooooool0XOooool2
o`000:Kooooo000Looooo`03o`000?oooooooooo0;Wooooo0_l0002>ooooo`007?ooool00ol0003o
ooooooooo`2iooooo`;o0000S_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`00
0?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom:
ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool001Co
oooo00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o0000ooooooooool0
oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooo
oooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`004_ooool00omEEEGo
IVIVo`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Qoooo
o`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05_ooool4o`000003oa0@4?oooooo
oooo00Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o410@
olc<c02<ooooo`00X_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l0000<ooooo`03o`00
0?oooooooooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmEEEGoMgMgoooooonHV9So8B4Q08cooooo002Rooooo`05o`000?oooooooooo
ooooool000006oooool00ol0003oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@
oooooooooooooooooa0@4003ooooo`05o`000?ooooooooooooooool00000S?ooool00:;ooooo00Go
0000ooooooooooooooooo`000009ooooo`Ko00003?ooool00ol0003oooooooooo`04ooooo`03oiRH
V?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?nHV9SooooooiRH
V?lQ8B40S?ooool00:;ooooo00Go0000ohN7QoooooooZJVYo`00000Kooooo`03o`000?oooooooooo
00Gooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
oeEEEOl0003o410@olc<c02<ooooo`00XOooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooo
oooo01Wooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo410@00?ooooo00Ko
410@oooooooooooooooooeEEEOn7QhN?ooooo`00`_ooool00ol0003oooooooooo`02ooooo`05o`00
0?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?ogMgMoa0@
4?nHV9P0S_ooool00<3ooooo00?oEEEEofIVI_l000001?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`04olc<c?m4A4Co0000oa0@48cooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1212) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.6064 .43811 Mdot
.65158 .41659 Mdot
.37838 .48715 Mdot
.57824 .61942 Mdot
.34047 .25107 Mdot
.34988 .46728 Mdot
.46176 .34035 Mdot
.51212 .35781 Mdot
.35723 .49127 Mdot
.57074 .24213 Mdot
.47942 .33318 Mdot
.52962 .64925 Mdot
.49559 .34758 Mdot
.58069 .59596 Mdot
.36025 .18335 Mdot
.64448 .58104 Mdot
.64074 .44358 Mdot
.36352 .66609 Mdot
.54484 .57784 Mdot
.34623 .50607 Mdot
.68652 .40527 Mdot
.58622 .60399 Mdot
.643 .38225 Mdot
.5806 .59517 Mdot
.60384 .64262 Mdot
.61269 .40225 Mdot
.60887 .37011 Mdot
.62648 .62587 Mdot
.63314 .64236 Mdot
.51271 .351 Mdot
.45126 .70903 Mdot
.32961 .22295 Mdot
.53624 .60867 Mdot
.1916 .50071 Mdot
.49553 .375 Mdot
.73624 .58446 Mdot
.36446 .4725 Mdot
.47878 .36245 Mdot
.47378 .3656 Mdot
.45948 .38003 Mdot
.47687 .34825 Mdot
.62564 .39275 Mdot
.48546 .29382 Mdot
.38626 .54058 Mdot
.62858 .56057 Mdot
.4316 .24018 Mdot
.78626 .61752 Mdot
.61813 .57167 Mdot
.62833 .44213 Mdot
.24129 .51455 Mdot
.33081 .32482 Mdot
.45517 .36757 Mdot
.31338 .48792 Mdot
.35118 .85238 Mdot
.48803 .37 Mdot
.58457 .52969 Mdot
.37384 .47726 Mdot
.59429 .59645 Mdot
.58156 .5904 Mdot
.68697 .48371 Mdot
.61439 .55662 Mdot
.37542 .61129 Mdot
.63371 .46347 Mdot
.54731 .4683 Mdot
.35951 .48577 Mdot
.46773 .35318 Mdot
.64833 .40185 Mdot
.49899 .35556 Mdot
.66688 .6189 Mdot
.34938 .50888 Mdot
.62212 .57567 Mdot
.47233 .34184 Mdot
.63301 .45222 Mdot
.62953 .60635 Mdot
.28543 .6262 Mdot
.61614 .1995 Mdot
.35703 .59656 Mdot
.71966 .54339 Mdot
.67453 .51161 Mdot
.28591 .54995 Mdot
.56427 .62247 Mdot
.53803 .72897 Mdot
.55271 .1868 Mdot
.64517 .37777 Mdot
.63566 .66985 Mdot
.418 .65523 Mdot
.62567 .60395 Mdot
.46552 .20916 Mdot
.64445 .63092 Mdot
.2857 .66045 Mdot
.3408 .48659 Mdot
.63642 .42217 Mdot
.57654 .62001 Mdot
.63837 .61948 Mdot
.66386 .71241 Mdot
.54244 .61401 Mdot
.60501 .61945 Mdot
.60928 .42822 Mdot
.45965 .37259 Mdot
.53921 .56521 Mdot
.39636 .52754 Mdot
.31815 .45014 Mdot
.56496 .57551 Mdot
.33749 .44439 Mdot
.65615 .44885 Mdot
.63429 .60897 Mdot
.4725 .37012 Mdot
.57197 .57253 Mdot
.64193 .33182 Mdot
.65512 .4171 Mdot
.63143 .62699 Mdot
.35128 .63319 Mdot
.57623 .80975 Mdot
.64074 .43138 Mdot
.32989 .55047 Mdot
.57972 .64084 Mdot
.60674 .61034 Mdot
.64861 .41538 Mdot
.36 .43478 Mdot
.48656 .20184 Mdot
.62002 .37632 Mdot
.47847 .38762 Mdot
.59644 .42798 Mdot
.65608 .65667 Mdot
.34062 .4801 Mdot
.2696 .39618 Mdot
.55654 .3425 Mdot
.4601 .68245 Mdot
.62068 .5993 Mdot
.56546 .27318 Mdot
.32498 .48203 Mdot
.63435 .40986 Mdot
.50218 .35259 Mdot
.55286 .66533 Mdot
.66576 .40747 Mdot
.49427 .32852 Mdot
.35664 .61613 Mdot
.36433 .36077 Mdot
.66919 .42803 Mdot
.42108 .52688 Mdot
.5 .32006 Mdot
.45339 .3697 Mdot
.19911 .59518 Mdot
.6449 .40233 Mdot
.36452 .63205 Mdot
.50725 .35586 Mdot
.43542 .68656 Mdot
.6192 .55228 Mdot
.51202 .74493 Mdot
.78905 .64046 Mdot
.19081 .51832 Mdot
.38736 .37263 Mdot
.39024 .63403 Mdot
.50048 .38497 Mdot
.60514 .6354 Mdot
.61043 .4142 Mdot
.62111 .39014 Mdot
.60615 .55377 Mdot
.58475 .63118 Mdot
.62972 .58635 Mdot
.64059 .6178 Mdot
.7225 .38744 Mdot
.54993 .61932 Mdot
.74348 .67794 Mdot
.63434 .42638 Mdot
.59142 .62651 Mdot
.37245 .44895 Mdot
.57382 .66239 Mdot
.47351 .34663 Mdot
.59343 .60359 Mdot
.58048 .62134 Mdot
.60778 .55102 Mdot
.45736 .37185 Mdot
.3936 .18434 Mdot
.66729 .72899 Mdot
.33342 .23553 Mdot
.31021 .67124 Mdot
.3446 .45041 Mdot
.62089 .60791 Mdot
.35819 .62433 Mdot
.7616 .54641 Mdot
.5635 .60405 Mdot
.75832 .74552 Mdot
.5977 .61536 Mdot
.34926 .23485 Mdot
.61085 .52625 Mdot
.24842 .30086 Mdot
.5148 .72783 Mdot
.61536 .63567 Mdot
.53559 .50087 Mdot
.55211 .39452 Mdot
.37722 .53101 Mdot
.48022 .3478 Mdot
.37556 .45153 Mdot
.37916 .48045 Mdot
.48716 .30114 Mdot
.63169 .48531 Mdot
.61687 .50923 Mdot
.62232 .66518 Mdot
.3421 .50835 Mdot
.65153 .45798 Mdot
.38166 .60334 Mdot
.59965 .41137 Mdot
.58966 .1465 Mdot
.37271 .28334 Mdot
.52005 .32793 Mdot
.40435 .63298 Mdot
.34826 .49705 Mdot
.32301 .44504 Mdot
.35837 .65102 Mdot
.60215 .57449 Mdot
.64306 .39667 Mdot
.17339 .50888 Mdot
.70157 .32967 Mdot
.1848 .58897 Mdot
.6135 .43304 Mdot
.61483 .27115 Mdot
.49556 .33243 Mdot
.36567 .45912 Mdot
.6068 .61342 Mdot
.60377 .58079 Mdot
.68379 .4032 Mdot
.62824 .58569 Mdot
.50857 .62528 Mdot
.61417 .62193 Mdot
.31068 .35831 Mdot
.3458 .60921 Mdot
.48889 .30126 Mdot
.46623 .6632 Mdot
.62387 .38084 Mdot
.45679 .78382 Mdot
.33286 .44349 Mdot
.75271 .5425 Mdot
.46802 .34223 Mdot
.36452 .61049 Mdot
.32319 .45492 Mdot
.37271 .60046 Mdot
.54105 .59441 Mdot
.39034 .4739 Mdot
.35485 .65386 Mdot
.65113 .51258 Mdot
.64519 .59938 Mdot
.72051 .35279 Mdot
.47876 .38421 Mdot
.61296 .3769 Mdot
.62182 .56531 Mdot
.3481 .44568 Mdot
.54937 .65382 Mdot
.41804 .31557 Mdot
.27859 .39342 Mdot
.32832 .43184 Mdot
.27842 .43136 Mdot
.38118 .60885 Mdot
.41636 .28956 Mdot
.59948 .27821 Mdot
.63148 .44634 Mdot
.54772 .6207 Mdot
.23152 .30882 Mdot
.50688 .35633 Mdot
.5773 .57137 Mdot
.21474 .4501 Mdot
.49802 .36574 Mdot
.59586 .59517 Mdot
.51403 .36462 Mdot
.62289 .38889 Mdot
.59221 .78825 Mdot
.63596 .44369 Mdot
.64035 .6432 Mdot
.47302 .37318 Mdot
.38109 .44864 Mdot
.61373 .41223 Mdot
.6003 .56942 Mdot
.62548 .62067 Mdot
.51364 .4611 Mdot
.59753 .62635 Mdot
.38661 .19672 Mdot
.61624 .62879 Mdot
.37945 .46508 Mdot
.55793 .57725 Mdot
.4915 .85383 Mdot
.48627 .27747 Mdot
.64709 .40061 Mdot
.36542 .43359 Mdot
.36667 .48928 Mdot
.35443 .56496 Mdot
.53528 .34314 Mdot
.56393 .62856 Mdot
.34402 .44865 Mdot
.50923 .77823 Mdot
.48917 .32186 Mdot
.54774 .62537 Mdot
.42962 .52569 Mdot
.24177 .53456 Mdot
.31546 .48975 Mdot
.53171 .60117 Mdot
.66751 .43441 Mdot
.57685 .62203 Mdot
.33435 .43481 Mdot
.68435 .37729 Mdot
.6064 .65304 Mdot
.65936 .46488 Mdot
.51481 .4591 Mdot
.47353 .32714 Mdot
.61052 .52315 Mdot
.58657 .56473 Mdot
.36445 .44938 Mdot
.61732 .38433 Mdot
.49533 .32166 Mdot
.6192 .39949 Mdot
.22274 .3642 Mdot
.63663 .33691 Mdot
.66425 .48519 Mdot
.40196 .64847 Mdot
.22581 .51531 Mdot
.22744 .32982 Mdot
.39664 .78935 Mdot
.43559 .7636 Mdot
.18412 .43721 Mdot
.35831 .43675 Mdot
.22057 .46413 Mdot
.37364 .48509 Mdot
.59239 .64219 Mdot
.34537 .4814 Mdot
.22329 .32974 Mdot
.61243 .62203 Mdot
.35048 .47856 Mdot
.49127 .79525 Mdot
.5857 .62659 Mdot
.65012 .43334 Mdot
.46948 .16989 Mdot
.43706 .82286 Mdot
.28258 .3855 Mdot
.37548 .50061 Mdot
.39853 .73935 Mdot
.60535 .62213 Mdot
.55238 .58203 Mdot
.62338 .4335 Mdot
.55076 .63337 Mdot
.39274 .61729 Mdot
.40326 .63589 Mdot
.52952 .40553 Mdot
.57707 .73262 Mdot
.60137 .5267 Mdot
.615 .41875 Mdot
.73419 .39027 Mdot
.27245 .62357 Mdot
.2377 .50428 Mdot
.52051 .35359 Mdot
.46213 .17407 Mdot
.52683 .65883 Mdot
.42615 .34983 Mdot
.34795 .53432 Mdot
.64669 .42686 Mdot
.37349 .19614 Mdot
.48205 .3515 Mdot
.80704 .45629 Mdot
.46246 .59705 Mdot
.59896 .57596 Mdot
.4649 .34173 Mdot
.53345 .55342 Mdot
.41442 .81788 Mdot
.82183 .44523 Mdot
.53735 .69753 Mdot
.64178 .64457 Mdot
.29597 .63291 Mdot
.59886 .6067 Mdot
.50825 .21073 Mdot
.61951 .62866 Mdot
.61877 .40642 Mdot
.5432 .23078 Mdot
.53555 .42403 Mdot
.68861 .72023 Mdot
.43793 .26583 Mdot
.39074 .63311 Mdot
.61251 .61622 Mdot
.59682 .57539 Mdot
.39099 .61923 Mdot
.67388 .40594 Mdot
.64164 .61572 Mdot
.43945 .77745 Mdot
.62708 .596 Mdot
.47567 .35447 Mdot
.51245 .66898 Mdot
.59592 .45394 Mdot
.61767 .66183 Mdot
.63577 .45755 Mdot
.46992 .32747 Mdot
.48098 .37207 Mdot
.60199 .53047 Mdot
.45505 .37848 Mdot
.59024 .61473 Mdot
.82768 .44029 Mdot
.66561 .42964 Mdot
.5173 .55338 Mdot
.65184 .38843 Mdot
.71391 .54711 Mdot
.48544 .37688 Mdot
.32841 .33813 Mdot
.53636 .65401 Mdot
.48524 .34986 Mdot
.63947 .33958 Mdot
.6331 .5587 Mdot
.65208 .62971 Mdot
.26134 .66111 Mdot
.37785 .49572 Mdot
.53374 .44833 Mdot
.51316 .35852 Mdot
.5956 .56471 Mdot
.58882 .65644 Mdot
.46655 .32959 Mdot
.77781 .3859 Mdot
.47367 .81208 Mdot
.61508 .62559 Mdot
.62331 .4151 Mdot
.63251 .40698 Mdot
.64658 .64222 Mdot
.55355 .59386 Mdot
.33007 .46919 Mdot
.38602 .45059 Mdot
.38885 .49339 Mdot
.51731 .45648 Mdot
.31865 .34638 Mdot
.34009 .27495 Mdot
.45854 .3794 Mdot
.59926 .29916 Mdot
.29678 .6711 Mdot
.60312 .669 Mdot
.33972 .50077 Mdot
.57809 .57493 Mdot
.58039 .61432 Mdot
.47959 .31837 Mdot
.24498 .40485 Mdot
.52057 .58905 Mdot
.67691 .41044 Mdot
.50825 .33181 Mdot
.63946 .68361 Mdot
.48339 .26408 Mdot
.35519 .6251 Mdot
.21307 .59626 Mdot
.46897 .34454 Mdot
.65038 .43016 Mdot
.49623 .37813 Mdot
.61061 .58266 Mdot
.5598 .55445 Mdot
.645 .4185 Mdot
.39037 .64776 Mdot
.55172 .65308 Mdot
.59857 .59703 Mdot
.76601 .69423 Mdot
.30933 .68864 Mdot
.31867 .36032 Mdot
.61504 .63356 Mdot
.61517 .65965 Mdot
.34486 .6312 Mdot
.62265 .59036 Mdot
.63216 .58505 Mdot
.61565 .78172 Mdot
.56837 .33732 Mdot
.396 .64973 Mdot
.80418 .41224 Mdot
.61642 .43739 Mdot
.27458 .26784 Mdot
.36346 .45399 Mdot
.52571 .37155 Mdot
.50397 .81834 Mdot
.31154 .48655 Mdot
.39226 .37799 Mdot
.30056 .24725 Mdot
.53345 .4461 Mdot
.29761 .4316 Mdot
.53219 .65806 Mdot
.63913 .61057 Mdot
.60438 .60567 Mdot
.36314 .62052 Mdot
.63893 .3945 Mdot
.52688 .46144 Mdot
.72023 .28499 Mdot
.58978 .60708 Mdot
.50229 .59428 Mdot
.68512 .28855 Mdot
.24462 .53875 Mdot
.37847 .64008 Mdot
.39768 .64308 Mdot
.61126 .6126 Mdot
.5922 .80323 Mdot
.61206 .40459 Mdot
.59883 .56915 Mdot
.56175 .63075 Mdot
.38138 .49462 Mdot
.66016 .41925 Mdot
.34964 .43445 Mdot
.35453 .31556 Mdot
.33568 .2386 Mdot
.78659 .67933 Mdot
.48421 .37509 Mdot
.57615 .21184 Mdot
.50913 .33933 Mdot
.53296 .72255 Mdot
.31566 .45753 Mdot
.56179 .61289 Mdot
.62137 .38263 Mdot
.58954 .56684 Mdot
.55296 .5998 Mdot
.5999 .57396 Mdot
.5993 .66442 Mdot
.67283 .8062 Mdot
.36937 .65514 Mdot
.65984 .631 Mdot
.38227 .47354 Mdot
.50332 .19837 Mdot
.6087 .20177 Mdot
.59218 .5779 Mdot
.62111 .61883 Mdot
.67029 .41772 Mdot
.59703 .55541 Mdot
.49992 .32832 Mdot
.60736 .38873 Mdot
.63723 .62172 Mdot
.47712 .18105 Mdot
.63348 .63608 Mdot
.28029 .27333 Mdot
.5033 .37412 Mdot
.67267 .33025 Mdot
.65983 .61179 Mdot
.28336 .39314 Mdot
.5337 .44844 Mdot
.32441 .46276 Mdot
.45755 .38531 Mdot
.36334 .47492 Mdot
.75677 .30962 Mdot
.5692 .55089 Mdot
.60432 .63754 Mdot
.57777 .65222 Mdot
.3466 .44936 Mdot
.43894 .21532 Mdot
.41265 .28224 Mdot
.64139 .67835 Mdot
.34149 .45606 Mdot
.638 .46078 Mdot
.40491 .69029 Mdot
.64226 .38565 Mdot
.40802 .62548 Mdot
.48272 .33374 Mdot
.3972 .63759 Mdot
.2072 .44628 Mdot
.65342 .41832 Mdot
.63119 .36614 Mdot
.35857 .45729 Mdot
.44795 .56013 Mdot
.217 .71047 Mdot
.45875 .58709 Mdot
.48388 .71206 Mdot
.62298 .43018 Mdot
.6302 .6495 Mdot
.51448 .69602 Mdot
.46134 .54015 Mdot
.36326 .47725 Mdot
.56869 .60488 Mdot
.57531 .79672 Mdot
.32977 .46887 Mdot
.54706 .62283 Mdot
.38401 .48451 Mdot
.47997 .34094 Mdot
.34135 .49882 Mdot
.67202 .38848 Mdot
.62998 .61368 Mdot
.18237 .65459 Mdot
.35979 .58998 Mdot
.60803 .6274 Mdot
.51123 .33574 Mdot
.49334 .40731 Mdot
.56082 .59127 Mdot
.35424 .61483 Mdot
.34135 .47188 Mdot
.45348 .59232 Mdot
.61701 .62682 Mdot
.34744 .45099 Mdot
.60337 .43534 Mdot
.47789 .39127 Mdot
.68204 .57835 Mdot
.28989 .38989 Mdot
.6225 .43409 Mdot
.41421 .51887 Mdot
.44342 .36281 Mdot
.61377 .66047 Mdot
.55305 .62656 Mdot
.62569 .41145 Mdot
.59847 .76154 Mdot
.5756 .56025 Mdot
.56406 .6218 Mdot
.38255 .46639 Mdot
.35782 .47493 Mdot
.58902 .77587 Mdot
.37017 .43969 Mdot
.56105 .55425 Mdot
.62464 .40932 Mdot
.57305 .61749 Mdot
.66574 .42352 Mdot
.59027 .5581 Mdot
.65306 .35662 Mdot
.67217 .40131 Mdot
.47501 .27902 Mdot
.57205 .60944 Mdot
.59266 .51495 Mdot
.57104 .57548 Mdot
.6315 .59555 Mdot
.33054 .47349 Mdot
.36403 .64513 Mdot
.53816 .57705 Mdot
.38347 .59053 Mdot
.37254 .60128 Mdot
.54927 .38575 Mdot
.37809 .49706 Mdot
.37126 .62455 Mdot
.6958 .29159 Mdot
.38809 .49229 Mdot
.37494 .61374 Mdot
.60239 .20124 Mdot
.49281 .3759 Mdot
.66529 .43469 Mdot
.58568 .62779 Mdot
.20142 .41965 Mdot
.78641 .62112 Mdot
.3881 .5183 Mdot
.61422 .62892 Mdot
.57135 .57903 Mdot
.62899 .37496 Mdot
.79586 .33369 Mdot
.35595 .50939 Mdot
.61997 .64755 Mdot
.65289 .40525 Mdot
.83833 .39594 Mdot
.37737 .46752 Mdot
.37087 .61485 Mdot
.46598 .38082 Mdot
.66621 .45676 Mdot
.55672 .34502 Mdot
.46599 .33474 Mdot
.34345 .51753 Mdot
.32747 .33007 Mdot
.57889 .64054 Mdot
.33233 .4968 Mdot
.21943 .6284 Mdot
.70836 .35813 Mdot
.55201 .37662 Mdot
.38862 .73327 Mdot
.64456 .42751 Mdot
.50326 .33248 Mdot
.38643 .64412 Mdot
.61064 .42742 Mdot
.64967 .43668 Mdot
.46938 .32267 Mdot
.699 .64763 Mdot
.42946 .52947 Mdot
.47441 .36139 Mdot
.26835 .65527 Mdot
.26671 .34848 Mdot
.33926 .5011 Mdot
.39152 .6166 Mdot
.21125 .4293 Mdot
.62411 .39323 Mdot
.45526 .17326 Mdot
.22382 .62307 Mdot
.60482 .61944 Mdot
.37068 .62969 Mdot
.40786 .23352 Mdot
.72838 .2745 Mdot
.49514 .36757 Mdot
.52548 .42765 Mdot
.39781 .61983 Mdot
.61771 .56088 Mdot
.41598 .69222 Mdot
.56873 .62385 Mdot
.48945 .33183 Mdot
.67776 .48845 Mdot
.65229 .43029 Mdot
.46601 .32238 Mdot
.21162 .59592 Mdot
.58868 .61281 Mdot
.56963 .60852 Mdot
.46398 .64642 Mdot
.60788 .39665 Mdot
.32438 .46198 Mdot
.57068 .6354 Mdot
.59652 .59985 Mdot
.56444 .54249 Mdot
.60868 .52004 Mdot
.57299 .80736 Mdot
.6067 .64757 Mdot
.41308 .26861 Mdot
.63252 .65944 Mdot
.57483 .60384 Mdot
.63937 .45757 Mdot
.77813 .70146 Mdot
.36366 .30499 Mdot
.59495 .60285 Mdot
.62624 .65023 Mdot
.45646 .3311 Mdot
.44147 .52579 Mdot
.44413 .55822 Mdot
.44898 .58853 Mdot
.41883 .75322 Mdot
.63324 .66456 Mdot
.64924 .39574 Mdot
.35172 .65058 Mdot
.60371 .65455 Mdot
.65174 .3986 Mdot
.60952 .54866 Mdot
.32973 .46689 Mdot
.3905 .48747 Mdot
.65958 .34407 Mdot
.37733 .62126 Mdot
.48445 .60997 Mdot
.58658 .30141 Mdot
.38025 .45565 Mdot
.60309 .63921 Mdot
.52835 .34057 Mdot
.33143 .43674 Mdot
.27764 .45937 Mdot
.67314 .57953 Mdot
.60996 .40173 Mdot
.63657 .42534 Mdot
.51524 .74829 Mdot
.38079 .35776 Mdot
.70583 .7344 Mdot
.48026 .33938 Mdot
.56312 .56428 Mdot
.58133 .26984 Mdot
.63832 .42853 Mdot
.51691 .70589 Mdot
.37298 .62576 Mdot
.49853 .36672 Mdot
.35821 .40612 Mdot
.66859 .41085 Mdot
.64669 .44215 Mdot
.64575 .62183 Mdot
.5976 .58861 Mdot
.44575 .76779 Mdot
.349 .67755 Mdot
.47405 .32568 Mdot
.39032 .61469 Mdot
.31679 .46718 Mdot
.61029 .64904 Mdot
.64664 .38197 Mdot
.26299 .37478 Mdot
.61587 .65183 Mdot
.32918 .4762 Mdot
.64204 .42348 Mdot
.38626 .60983 Mdot
.35875 .60594 Mdot
.63094 .59678 Mdot
.73004 .41074 Mdot
.48299 .361 Mdot
.6476 .43309 Mdot
.48165 .26703 Mdot
.55193 .58495 Mdot
.60479 .59231 Mdot
.64936 .55691 Mdot
.48437 .31975 Mdot
.65515 .3027 Mdot
.40241 .61567 Mdot
.63884 .39895 Mdot
.61894 .63915 Mdot
.3812 .61458 Mdot
.62875 .28833 Mdot
.3265 .43274 Mdot
.3439 .4987 Mdot
.3536 .614 Mdot
.37587 .63509 Mdot
.35776 .61027 Mdot
.45633 .17219 Mdot
.65226 .37772 Mdot
.52838 .65953 Mdot
.56984 .56247 Mdot
.50312 .72549 Mdot
.57474 .67994 Mdot
.49885 .32109 Mdot
.37527 .4964 Mdot
.55875 .58895 Mdot
.63604 .64763 Mdot
.63706 .54847 Mdot
.51277 .57066 Mdot
.58137 .42525 Mdot
.65694 .41826 Mdot
.58322 .54667 Mdot
.38784 .48453 Mdot
.60678 .14779 Mdot
.16428 .43218 Mdot
.65574 .59502 Mdot
.42346 .54843 Mdot
.64717 .38132 Mdot
.44737 .3575 Mdot
.43898 .60781 Mdot
.48759 .3796 Mdot
.63835 .40294 Mdot
.60725 .64827 Mdot
.59814 .30483 Mdot
.34946 .62062 Mdot
.60845 .56594 Mdot
.50328 .33885 Mdot
.61814 .57024 Mdot
.46438 .33671 Mdot
.22823 .3468 Mdot
.3112 .71374 Mdot
.59884 .61563 Mdot
.65592 .63928 Mdot
.38381 .74276 Mdot
.5889 .57732 Mdot
.33223 .67187 Mdot
.64947 .38168 Mdot
.64742 .73552 Mdot
.64422 .58987 Mdot
.76772 .46086 Mdot
.54793 .59093 Mdot
.53845 .79555 Mdot
.60457 .5892 Mdot
.24572 .55546 Mdot
.63157 .62274 Mdot
.63529 .59398 Mdot
.47711 .37616 Mdot
.46062 .32735 Mdot
.6304 .45311 Mdot
.3424 .4474 Mdot
.30782 .2504 Mdot
.60115 .59556 Mdot
.27625 .39279 Mdot
.60613 .32366 Mdot
.37773 .63575 Mdot
.6357 .39977 Mdot
.79637 .32263 Mdot
.50697 .37483 Mdot
.32421 .69723 Mdot
.54634 .785 Mdot
.52428 .30246 Mdot
.42331 .64919 Mdot
.53518 .22479 Mdot
.37772 .60808 Mdot
.60415 .55078 Mdot
.25453 .39351 Mdot
.24508 .57992 Mdot
.67265 .57693 Mdot
.44279 .35483 Mdot
.76225 .52535 Mdot
.24879 .38996 Mdot
.3911 .60232 Mdot
.4008 .63011 Mdot
.45202 .35727 Mdot
.3598 .40937 Mdot
.52711 .56367 Mdot
.3756 .62717 Mdot
.38039 .45177 Mdot
.36949 .50623 Mdot
.30642 .48181 Mdot
.61461 .39653 Mdot
.1906 .5557 Mdot
.48878 .25657 Mdot
.46934 .33169 Mdot
.336 .41775 Mdot
.58326 .41373 Mdot
.65219 .37434 Mdot
.36223 .46359 Mdot
.33145 .4823 Mdot
.67728 .41931 Mdot
.58723 .53222 Mdot
.62721 .54241 Mdot
.59274 .60603 Mdot
.35663 .63307 Mdot
.60146 .58457 Mdot
.33767 .46173 Mdot
.49507 .36444 Mdot
.34011 .49042 Mdot
.51821 .35686 Mdot
.35897 .26761 Mdot
.61071 .57297 Mdot
.62989 .61668 Mdot
.80422 .59791 Mdot
.61355 .44502 Mdot
.40037 .2676 Mdot
.30002 .38379 Mdot
.37627 .48354 Mdot
.62981 .58058 Mdot
.60878 .38552 Mdot
.39831 .6037 Mdot
.81584 .58094 Mdot
.55723 .58547 Mdot
.64962 .3838 Mdot
.61848 .64308 Mdot
.71614 .38954 Mdot
.55236 .84267 Mdot
.6231 .40015 Mdot
.78827 .6397 Mdot
.63075 .64528 Mdot
.61449 .23741 Mdot
.57029 .6468 Mdot
.51473 .76924 Mdot
.57506 .56084 Mdot
.6146 .43536 Mdot
.59076 .60184 Mdot
.60404 .3953 Mdot
.37396 .45288 Mdot
.44957 .36572 Mdot
.62938 .43445 Mdot
.56009 .63353 Mdot
.09358 .48465 Mdot
.49083 .33502 Mdot
.6094 .61442 Mdot
.46895 .37914 Mdot
.64096 .39135 Mdot
.63156 .44075 Mdot
.69965 .25605 Mdot
.36163 .31264 Mdot
.48061 .34167 Mdot
.6132 .64741 Mdot
.49065 .23985 Mdot
.57134 .622 Mdot
.46901 .76033 Mdot
.58411 .52836 Mdot
.56237 .5718 Mdot
.62358 .20376 Mdot
.48129 .3219 Mdot
.6901 .74808 Mdot
.68739 .24395 Mdot
.5111 .19384 Mdot
.68338 .43711 Mdot
.39316 .60265 Mdot
.38279 .19081 Mdot
.32504 .34182 Mdot
.34405 .45294 Mdot
.56406 .58235 Mdot
.59754 .45093 Mdot
.48085 .36645 Mdot
.36206 .64659 Mdot
.59974 .6155 Mdot
.33317 .48637 Mdot
.42913 .80111 Mdot
.50742 .38025 Mdot
.6275 .39287 Mdot
.6737 .40007 Mdot
.85566 .49344 Mdot
.61692 .63576 Mdot
.63297 .61614 Mdot
.48525 .33233 Mdot
.66935 .28793 Mdot
.3748 .60606 Mdot
.47231 .79642 Mdot
.48208 .34115 Mdot
.48857 .48575 Mdot
.64952 .40692 Mdot
.57354 .57721 Mdot
.41441 .21411 Mdot
.29527 .62075 Mdot
.81 .49674 Mdot
.35817 .62534 Mdot
.46273 .75561 Mdot
.61605 .43769 Mdot
.50466 .35323 Mdot
.36094 .37701 Mdot
.61028 .67422 Mdot
.57605 .57894 Mdot
.46635 .75274 Mdot
.54511 .41474 Mdot
.53078 .69187 Mdot
.55422 .58751 Mdot
.54713 .438 Mdot
.57336 .56583 Mdot
.60643 .67885 Mdot
.57137 .54252 Mdot
.61453 .59631 Mdot
.64876 .38273 Mdot
.66878 .64787 Mdot
.33062 .45885 Mdot
.51969 .66117 Mdot
.49507 .49197 Mdot
.61097 .62619 Mdot
.57793 .63357 Mdot
.79589 .53855 Mdot
.42183 .39576 Mdot
.63215 .43221 Mdot
.66723 .37518 Mdot
.46407 .38416 Mdot
.63155 .54475 Mdot
.33623 .44843 Mdot
.5785 .679 Mdot
.33183 .47663 Mdot
.64027 .38207 Mdot
.37812 .47757 Mdot
.45831 .37659 Mdot
.35701 .50587 Mdot
.31755 .34694 Mdot
.50873 .35823 Mdot
.60978 .41518 Mdot
.62932 .60445 Mdot
.51144 .33664 Mdot
.45567 .67132 Mdot
.35713 .63101 Mdot
.6819 .23172 Mdot
.63764 .62448 Mdot
.56603 .34212 Mdot
.68218 .44719 Mdot
.33641 .48675 Mdot
.58735 .81953 Mdot
.67444 .40351 Mdot
.38954 .65276 Mdot
.62708 .37943 Mdot
.2838 .67805 Mdot
.36647 .64108 Mdot
.58969 .19334 Mdot
.29428 .41037 Mdot
.35806 .69128 Mdot
.59699 .53443 Mdot
.43872 .65213 Mdot
.31714 .48821 Mdot
.48179 .36722 Mdot
.37722 .38021 Mdot
.63119 .58471 Mdot
.35741 .76045 Mdot
.66101 .44742 Mdot
.34027 .44922 Mdot
.49982 .35296 Mdot
.49917 .32309 Mdot
.54833 .60862 Mdot
.26476 .51073 Mdot
.59186 .5617 Mdot
.37579 .3414 Mdot
.42832 .75239 Mdot
.52742 .55399 Mdot
.61375 .62128 Mdot
.36668 .44988 Mdot
.61819 .6433 Mdot
.38588 .66068 Mdot
.18544 .56308 Mdot
.55503 .64712 Mdot
.30581 .37683 Mdot
.37148 .58307 Mdot
.6483 .41866 Mdot
.54665 .54273 Mdot
.33043 .34514 Mdot
.61558 .63936 Mdot
.55271 .87961 Mdot
.37763 .61396 Mdot
.25373 .40641 Mdot
.59342 .66037 Mdot
.55615 .62242 Mdot
.54695 .48057 Mdot
.55941 .3856 Mdot
.2983 .62446 Mdot
.58237 .58284 Mdot
.42846 .72089 Mdot
.45645 .35303 Mdot
.58359 .56364 Mdot
.60628 .60773 Mdot
.7154 .63125 Mdot
.50488 .33015 Mdot
.36879 .49172 Mdot
.31238 .48285 Mdot
.40145 .48197 Mdot
.38193 .66115 Mdot
.51154 .44008 Mdot
.5065 .70893 Mdot
.42043 .81177 Mdot
.35861 .66028 Mdot
.64068 .62587 Mdot
.32639 .62749 Mdot
.59516 .64587 Mdot
.38087 .64456 Mdot
.50797 .33512 Mdot
.63403 .43463 Mdot
.5956 .26546 Mdot
.34202 .50699 Mdot
.54943 .62822 Mdot
.38793 .60754 Mdot
.60999 .41083 Mdot
.37546 .68324 Mdot
.64612 .41045 Mdot
.48684 .34483 Mdot
.50078 .3892 Mdot
.36846 .64836 Mdot
.6477 .38912 Mdot
.43388 .33972 Mdot
.73247 .28321 Mdot
.56264 .54866 Mdot
.50568 .39305 Mdot
.60457 .43199 Mdot
.68043 .39154 Mdot
.60371 .41958 Mdot
.6252 .58182 Mdot
.42346 .54705 Mdot
.62531 .55464 Mdot
.47462 .32601 Mdot
.38097 .48798 Mdot
.38731 .75782 Mdot
.31665 .31181 Mdot
.37402 .5611 Mdot
.56749 .55958 Mdot
.58627 .6108 Mdot
.61094 .61248 Mdot
.64963 .6034 Mdot
.35991 .34908 Mdot
.58648 .56805 Mdot
.47389 .37579 Mdot
.33829 .47038 Mdot
.60577 .55063 Mdot
.31112 .46529 Mdot
.48925 .21152 Mdot
.3611 .65964 Mdot
.51127 .43021 Mdot
.16125 .36492 Mdot
.6132 .42232 Mdot
.35477 .43283 Mdot
.34743 .45264 Mdot
.35742 .61507 Mdot
.47869 .36041 Mdot
.64616 .40585 Mdot
.4916 .77627 Mdot
.36602 .60375 Mdot
.59298 .60111 Mdot
.42097 .57024 Mdot
.33441 .73778 Mdot
.59793 .55205 Mdot
.55885 .60201 Mdot
.32178 .43606 Mdot
.25971 .45727 Mdot
.19824 .64919 Mdot
.49301 .67478 Mdot
.36639 .64677 Mdot
.37733 .65366 Mdot
.67274 .42821 Mdot
.63609 .5649 Mdot
.47303 .32694 Mdot
.53713 .69141 Mdot
.45625 .41426 Mdot
.48587 .62531 Mdot
.59568 .47345 Mdot
.56239 .58011 Mdot
.77103 .36713 Mdot
.58779 .61453 Mdot
.64473 .37634 Mdot
.62873 .38582 Mdot
.61962 .42117 Mdot
.48307 .36567 Mdot
.73056 .55267 Mdot
.46918 .37172 Mdot
.15506 .37891 Mdot
.62193 .44314 Mdot
.31868 .39074 Mdot
.36904 .4556 Mdot
.65981 .60774 Mdot
.38606 .61096 Mdot
.44252 .38347 Mdot
.66709 .6207 Mdot
.59503 .80527 Mdot
.33688 .45276 Mdot
.61095 .42094 Mdot
.5485 .22538 Mdot
.191 .3651 Mdot
.44434 .57188 Mdot
.63163 .6901 Mdot
.44757 .63053 Mdot
.38143 .63502 Mdot
.81136 .50201 Mdot
.394 .61631 Mdot
.50741 .3435 Mdot
.62656 .61496 Mdot
.6247 .60316 Mdot
.57657 .5625 Mdot
.59983 .57093 Mdot
.44627 .36503 Mdot
.54056 .60896 Mdot
.49141 .8538 Mdot
.39265 .47812 Mdot
.65199 .50668 Mdot
.37996 .61137 Mdot
.44367 .3724 Mdot
.33768 .46887 Mdot
.41811 .3956 Mdot
.47097 .66803 Mdot
.61609 .62551 Mdot
.56072 .58582 Mdot
.32279 .69932 Mdot
.55355 .58783 Mdot
.57448 .68099 Mdot
.34622 .45147 Mdot
.38022 .56503 Mdot
.38261 .65341 Mdot
.38786 .64671 Mdot
.50622 .3662 Mdot
.63976 .38264 Mdot
.36844 .6207 Mdot
.37711 .45883 Mdot
.56611 .55993 Mdot
.57233 .63971 Mdot
.60596 .4333 Mdot
.22799 .63342 Mdot
.39493 .60841 Mdot
.52174 .2225 Mdot
.61804 .38535 Mdot
.59774 .38074 Mdot
.57493 .58023 Mdot
.59004 .49588 Mdot
.66185 .46052 Mdot
.35948 .66206 Mdot
.44536 .37482 Mdot
.4435 .61065 Mdot
.49193 .32845 Mdot
.6321 .38913 Mdot
.6038 .65342 Mdot
.62068 .38833 Mdot
.61624 .63278 Mdot
.23318 .27961 Mdot
.61808 .59577 Mdot
.42055 .81576 Mdot
.5029 .74944 Mdot
.35028 .46468 Mdot
.45701 .40439 Mdot
.36167 .45462 Mdot
.61438 .38714 Mdot
.58944 .64928 Mdot
.4034 .62469 Mdot
.54485 .19321 Mdot
.58196 .41428 Mdot
.32629 .47492 Mdot
.38859 .50175 Mdot
.51041 .34282 Mdot
.58706 .55163 Mdot
.57915 .57557 Mdot
.35225 .47779 Mdot
.52301 .56144 Mdot
.66562 .4028 Mdot
.62312 .6204 Mdot
.58031 .60612 Mdot
.35279 .4635 Mdot
.7424 .2924 Mdot
.60095 .36068 Mdot
.62196 .60836 Mdot
.26652 .41788 Mdot
.49582 .31949 Mdot
.60485 .53701 Mdot
.65337 .64861 Mdot
.37545 .63284 Mdot
.68069 .55751 Mdot
.18612 .53072 Mdot
.51609 .34922 Mdot
.3583 .44756 Mdot
.61851 .63677 Mdot
.36503 .44926 Mdot
.56294 .63327 Mdot
.57389 .43623 Mdot
.32086 .47457 Mdot
.55922 .61872 Mdot
.59644 .52512 Mdot
.60815 .39523 Mdot
.56093 .5834 Mdot
.78271 .58237 Mdot
.32801 .44249 Mdot
.55408 .61806 Mdot
.72733 .41597 Mdot
.47044 .35702 Mdot
.60776 .53243 Mdot
.35205 .64638 Mdot
.49307 .77809 Mdot
.55793 .30391 Mdot
.2402 .41153 Mdot
.36308 .65819 Mdot
.61392 .56608 Mdot
.39633 .49341 Mdot
.45632 .3473 Mdot
.44883 .82333 Mdot
.60946 .55598 Mdot
.49068 .33237 Mdot
.49658 .36268 Mdot
.35513 .62667 Mdot
.80412 .64347 Mdot
.60045 .66382 Mdot
.59325 .57887 Mdot
.74004 .62702 Mdot
.59963 .43156 Mdot
.60994 .58736 Mdot
.63784 .64102 Mdot
.47125 .37589 Mdot
.58363 .68565 Mdot
.77884 .51984 Mdot
.50228 .79649 Mdot
.49546 .31699 Mdot
.47126 .55493 Mdot
.33188 .50029 Mdot
.3848 .61742 Mdot
.64176 .41565 Mdot
.39209 .60976 Mdot
.35721 .50405 Mdot
.63946 .63069 Mdot
.48629 .38404 Mdot
.76741 .62868 Mdot
.45173 .357 Mdot
.23133 .42194 Mdot
.59979 .42914 Mdot
.55716 .26363 Mdot
.60349 .85789 Mdot
.46634 .24872 Mdot
.42178 .37158 Mdot
.37726 .63582 Mdot
.4182 .47786 Mdot
.58167 .60809 Mdot
.81313 .52736 Mdot
.63253 .60257 Mdot
.72339 .42918 Mdot
.38547 .45962 Mdot
.3891 .49323 Mdot
.62441 .61224 Mdot
.4382 .75513 Mdot
.45528 .3474 Mdot
.48717 .32151 Mdot
.55162 .61132 Mdot
.48487 .34952 Mdot
.59393 .5874 Mdot
.33271 .4689 Mdot
.68422 .76361 Mdot
.59699 .60984 Mdot
.65226 .63841 Mdot
.55235 .35797 Mdot
.64713 .21954 Mdot
.21802 .49552 Mdot
.81491 .40001 Mdot
.17849 .3909 Mdot
.48601 .34995 Mdot
.6171 .54389 Mdot
.47154 .55674 Mdot
.30989 .47555 Mdot
.42778 .35469 Mdot
.62157 .59176 Mdot
.62351 .59037 Mdot
.63729 .59805 Mdot
.56886 .61037 Mdot
.81408 .49119 Mdot
.61644 .70607 Mdot
.70027 .49482 Mdot
.55376 .59651 Mdot
.44146 .6579 Mdot
.50879 .36598 Mdot
.68407 .41746 Mdot
.33971 .65133 Mdot
.56288 .57973 Mdot
.55617 .68692 Mdot
.46615 .32086 Mdot
.15367 .38078 Mdot
.51196 .35356 Mdot
.36652 .48887 Mdot
.44855 .35542 Mdot
.59928 .62741 Mdot
.63216 .40743 Mdot
.47993 .52443 Mdot
.41185 .2935 Mdot
.34308 .45329 Mdot
.60842 .62747 Mdot
.31552 .38699 Mdot
.33323 .45723 Mdot
.48432 .21107 Mdot
.63552 .41365 Mdot
.43284 .71681 Mdot
.62555 .38597 Mdot
.55985 .62135 Mdot
.56361 .6248 Mdot
.48213 .39902 Mdot
.45115 .36683 Mdot
.62791 .38505 Mdot
.80642 .65086 Mdot
.37518 .5997 Mdot
.61733 .41592 Mdot
.57453 .67178 Mdot
.4509 .47344 Mdot
.6292 .41229 Mdot
.41033 .58544 Mdot
.48905 .37099 Mdot
.64469 .44846 Mdot
.59707 .67372 Mdot
.23632 .61848 Mdot
.34839 .64705 Mdot
.34027 .42281 Mdot
.42048 .58127 Mdot
.33184 .43786 Mdot
.45348 .38267 Mdot
.35908 .45523 Mdot
.45648 .35554 Mdot
.57817 .3219 Mdot
.50517 .64104 Mdot
.52912 .35229 Mdot
.45097 .37882 Mdot
.35832 .45791 Mdot
.62715 .62245 Mdot
.43135 .60217 Mdot
.61216 .54021 Mdot
.60036 .66629 Mdot
.46146 .34922 Mdot
.61185 .42881 Mdot
.67934 .39656 Mdot
.42363 .68418 Mdot
.66782 .39581 Mdot
.33132 .47835 Mdot
.5194 .84404 Mdot
.2737 .38694 Mdot
.47433 .33561 Mdot
.44781 .35062 Mdot
.57185 .62523 Mdot
.36349 .47556 Mdot
.36594 .44572 Mdot
.50579 .3377 Mdot
.51287 .5526 Mdot
.65461 .60984 Mdot
.6657 .37748 Mdot
.63126 .44824 Mdot
.62292 .40477 Mdot
.60259 .41532 Mdot
.7842 .47216 Mdot
.49576 .37087 Mdot
.60774 .41908 Mdot
.55639 .61395 Mdot
.62189 .58993 Mdot
.45522 .57201 Mdot
.38056 .65088 Mdot
.61388 .5524 Mdot
.57403 .54218 Mdot
.57092 .58117 Mdot
.3391 .49686 Mdot
.66805 .5786 Mdot
.32037 .47219 Mdot
.39726 .47868 Mdot
.39039 .46276 Mdot
.32229 .34405 Mdot
.36248 .70484 Mdot
.18939 .40964 Mdot
.62099 .64724 Mdot
.68913 .30429 Mdot
.37127 .4678 Mdot
.58931 .81289 Mdot
.65638 .30123 Mdot
.62098 .56691 Mdot
.28248 .61595 Mdot
.35276 .47532 Mdot
.67102 .39726 Mdot
.62044 .59297 Mdot
.39538 .46057 Mdot
.34993 .64376 Mdot
.54688 .57832 Mdot
.31637 .45886 Mdot
.64717 .3905 Mdot
.34511 .65941 Mdot
.63196 .4503 Mdot
.38937 .46204 Mdot
.60166 .5281 Mdot
.26321 .77269 Mdot
.38805 .50523 Mdot
.68028 .26773 Mdot
.67419 .35981 Mdot
.62483 .62092 Mdot
.34412 .43191 Mdot
.59144 .41347 Mdot
.46769 .38861 Mdot
.45368 .42024 Mdot
.65818 .43531 Mdot
.38771 .49507 Mdot
.31973 .45069 Mdot
.34491 .45177 Mdot
.65627 .42309 Mdot
.6479 .64174 Mdot
.66301 .42362 Mdot
.449 .3532 Mdot
.57953 .62463 Mdot
.22851 .32683 Mdot
.6924 .3107 Mdot
.62277 .38476 Mdot
.36414 .49512 Mdot
.34629 .62884 Mdot
.59526 .61737 Mdot
.71278 .31681 Mdot
.62648 .62936 Mdot
.4638 .34074 Mdot
.62948 .76805 Mdot
.78425 .6055 Mdot
.56998 .56321 Mdot
.57117 .62428 Mdot
.4818 .32355 Mdot
.6061 .62102 Mdot
.57776 .55829 Mdot
.3351 .33467 Mdot
.6603 .4155 Mdot
.58819 .60315 Mdot
.38488 .4764 Mdot
.31219 .33702 Mdot
.65285 .60707 Mdot
.33729 .55744 Mdot
.43851 .73099 Mdot
.65165 .74591 Mdot
.63384 .60521 Mdot
.48696 .65393 Mdot
.56797 .60257 Mdot
.60821 .56757 Mdot
.59056 .63997 Mdot
.8248 .48946 Mdot
.32342 .48027 Mdot
.34467 .45803 Mdot
.35041 .65493 Mdot
.436 .72865 Mdot
.37232 .63073 Mdot
.48841 .37285 Mdot
.29042 .53701 Mdot
.32094 .47342 Mdot
.64301 .38672 Mdot
.60404 .56293 Mdot
.38994 .50427 Mdot
.57677 .5745 Mdot
.60064 .62935 Mdot
.3375 .44429 Mdot
.3239 .49331 Mdot
.24936 .40692 Mdot
.35562 .65553 Mdot
.62379 .42679 Mdot
.60952 .54579 Mdot
.38326 .6049 Mdot
.6289 .65548 Mdot
.50661 .72584 Mdot
.62311 .42322 Mdot
.66191 .41831 Mdot
.67831 .39947 Mdot
.63901 .63119 Mdot
.59953 .62384 Mdot
.46682 .37019 Mdot
.63001 .38038 Mdot
.47184 .35511 Mdot
.51028 .46765 Mdot
.34046 .58044 Mdot
.62165 .59171 Mdot
.53596 .229 Mdot
.38677 .62434 Mdot
.3464 .49024 Mdot
.34521 .73587 Mdot
.34944 .65381 Mdot
.61807 .63101 Mdot
.35938 .44311 Mdot
.38105 .64635 Mdot
.67491 .57442 Mdot
.15549 .48561 Mdot
.3424 .63682 Mdot
.55514 .61239 Mdot
.60706 .69468 Mdot
.82265 .41254 Mdot
.34809 .65568 Mdot
.47158 .38233 Mdot
.63882 .63003 Mdot
.63395 .47057 Mdot
.39718 .61293 Mdot
.41803 .26497 Mdot
.34369 .47271 Mdot
.20599 .56989 Mdot
.67071 .61699 Mdot
.79747 .59669 Mdot
.39378 .62997 Mdot
.64307 .40316 Mdot
.68414 .3776 Mdot
.5713 .58731 Mdot
.34744 .65445 Mdot
.48765 .31421 Mdot
.34107 .47917 Mdot
.35949 .30863 Mdot
.65617 .425 Mdot
.52976 .24501 Mdot
.36167 .49813 Mdot
.51427 .22474 Mdot
.56491 .7934 Mdot
.6188 .53789 Mdot
.81687 .4142 Mdot
.3779 .39728 Mdot
.64544 .61401 Mdot
.35846 .60295 Mdot
.51533 .34521 Mdot
.47893 .38609 Mdot
.48634 .34144 Mdot
.59667 .32304 Mdot
.44691 .58572 Mdot
.35815 .4324 Mdot
.43834 .2998 Mdot
.38273 .61759 Mdot
.45677 .63426 Mdot
.57096 .64292 Mdot
.5882 .61046 Mdot
.58468 .55153 Mdot
.57164 .56953 Mdot
.57232 .59687 Mdot
.47886 .35434 Mdot
.56696 .32728 Mdot
.45451 .5869 Mdot
.62548 .4178 Mdot
.2659 .48908 Mdot
.36967 .4572 Mdot
.36108 .43211 Mdot
.36978 .65263 Mdot
.50908 .21266 Mdot
.31167 .46447 Mdot
.37829 .48056 Mdot
.64181 .59588 Mdot
.66788 .41172 Mdot
.61858 .68453 Mdot
.56369 .6198 Mdot
.33576 .48081 Mdot
.53488 .4793 Mdot
.788 .53164 Mdot
.67129 .58072 Mdot
.39649 .58564 Mdot
.43289 .54262 Mdot
.34476 .63896 Mdot
.59202 .65228 Mdot
.59929 .80911 Mdot
.35339 .50392 Mdot
.36523 .48372 Mdot
.39179 .63038 Mdot
.59879 .46745 Mdot
.645 .42424 Mdot
.41701 .36275 Mdot
.46243 .37504 Mdot
.58137 .64013 Mdot
.42382 .79497 Mdot
.6342 .48751 Mdot
.26551 .51901 Mdot
.48481 .33801 Mdot
.37148 .45221 Mdot
.57043 .55927 Mdot
.55559 .61071 Mdot
.38891 .62827 Mdot
.29693 .28852 Mdot
.56787 .55247 Mdot
.4975 .18688 Mdot
.30991 .7134 Mdot
.23342 .63077 Mdot
.57634 .57882 Mdot
.65924 .41716 Mdot
.31509 .45854 Mdot
.39157 .61723 Mdot
.56802 .66348 Mdot
.16697 .45489 Mdot
.61445 .44169 Mdot
.50761 .34962 Mdot
.49539 .50632 Mdot
.43975 .60257 Mdot
.64124 .61774 Mdot
.63164 .60314 Mdot
.6187 .57656 Mdot
.16024 .53973 Mdot
.33136 .4891 Mdot
.64285 .38046 Mdot
.35432 .63842 Mdot
.66125 .38963 Mdot
.34982 .45907 Mdot
.53697 .25397 Mdot
.6296 .62511 Mdot
.61352 .44186 Mdot
.64282 .40517 Mdot
.51171 .34875 Mdot
.47765 .3908 Mdot
.50597 .48589 Mdot
.61585 .59462 Mdot
.37648 .50959 Mdot
.60635 .40797 Mdot
.42486 .57268 Mdot
.36771 .6401 Mdot
.48255 .37577 Mdot
.55601 .59199 Mdot
.33109 .4943 Mdot
.54008 .61275 Mdot
.63567 .42775 Mdot
.37804 .47954 Mdot
.26165 .39957 Mdot
.37163 .65757 Mdot
.60944 .57905 Mdot
.36149 .67103 Mdot
.35799 .44696 Mdot
.57957 .60829 Mdot
.5738 .2172 Mdot
.38095 .57917 Mdot
.40443 .28974 Mdot
.38365 .45242 Mdot
.28096 .39207 Mdot
.67163 .42577 Mdot
.63447 .3227 Mdot
.36434 .4864 Mdot
.53697 .22126 Mdot
.29268 .3096 Mdot
.58094 .55007 Mdot
.62204 .3956 Mdot
.41136 .40628 Mdot
.26995 .26729 Mdot
.74106 .30293 Mdot
.60871 .61283 Mdot
.37104 .44002 Mdot
.38847 .6342 Mdot
.47212 .33639 Mdot
.34079 .56179 Mdot
.38868 .58024 Mdot
.3631 .5094 Mdot
.59177 .64114 Mdot
.64319 .39543 Mdot
.48834 .36712 Mdot
.56342 .30922 Mdot
.38128 .46451 Mdot
.37516 .49385 Mdot
.57026 .56 Mdot
.37366 .62475 Mdot
.72565 .3297 Mdot
.33349 .4654 Mdot
.32256 .70733 Mdot
.32688 .50541 Mdot
.37925 .60141 Mdot
.56308 .60205 Mdot
.41635 .68688 Mdot
.63816 .57472 Mdot
.63244 .22872 Mdot
.36412 .45771 Mdot
.63032 .42649 Mdot
.63079 .58895 Mdot
.52354 .79012 Mdot
.33916 .48387 Mdot
.42591 .54896 Mdot
.24022 .54597 Mdot
.49249 .37141 Mdot
.346 .73771 Mdot
.60296 .58223 Mdot
.45513 .34833 Mdot
.38595 .6257 Mdot
.619 .6025 Mdot
.5968 .62383 Mdot
.62287 .37622 Mdot
.50489 .33834 Mdot
.26034 .34374 Mdot
.46318 .32432 Mdot
.49899 .37685 Mdot
.63027 .37051 Mdot
.58518 .59131 Mdot
.36732 .4897 Mdot
.35444 .47635 Mdot
.57874 .66174 Mdot
.63029 .80855 Mdot
.64691 .42678 Mdot
.36681 .42257 Mdot
.16789 .56258 Mdot
.5897 .5182 Mdot
.36261 .75088 Mdot
.3112 .27698 Mdot
.50233 .3187 Mdot
.55099 .6059 Mdot
.6437 .39005 Mdot
.42329 .44082 Mdot
.37238 .49411 Mdot
.63873 .65017 Mdot
.49067 .36273 Mdot
.34958 .64585 Mdot
.32645 .45005 Mdot
.26721 .51441 Mdot
.60671 .57064 Mdot
.27932 .61941 Mdot
.35665 .43554 Mdot
.41005 .17053 Mdot
.41533 .39789 Mdot
.61881 .39939 Mdot
.59758 .62937 Mdot
.67671 .41051 Mdot
.35609 .64393 Mdot
.49534 .50411 Mdot
.4928 .36424 Mdot
.63724 .7035 Mdot
.44526 .85725 Mdot
.34746 .45017 Mdot
.64839 .38092 Mdot
.56735 .56554 Mdot
.57986 .46952 Mdot
.59684 .58265 Mdot
.5457 .6675 Mdot
.35482 .58494 Mdot
.46393 .34988 Mdot
.45415 .35517 Mdot
.57857 .61403 Mdot
.36779 .60514 Mdot
.37453 .45767 Mdot
.34296 .48279 Mdot
.54161 .1502 Mdot
.51805 .30582 Mdot
.45372 .76994 Mdot
.6204 .58658 Mdot
.38223 .50328 Mdot
.31715 .31708 Mdot
.48467 .33288 Mdot
.56528 .64187 Mdot
.33631 .449 Mdot
.25198 .6269 Mdot
.53268 .77681 Mdot
.56932 .5954 Mdot
.64135 .65927 Mdot
.46522 .37782 Mdot
.46684 .62217 Mdot
.39005 .47308 Mdot
.57866 .52897 Mdot
.52454 .36724 Mdot
.60906 .76213 Mdot
.20682 .61425 Mdot
.6234 .42672 Mdot
.24481 .49332 Mdot
.47855 .35524 Mdot
.63768 .66494 Mdot
.3723 .61029 Mdot
.31486 .47303 Mdot
.32884 .48885 Mdot
.60847 .64538 Mdot
.54243 .60102 Mdot
.36774 .73596 Mdot
.66203 .39325 Mdot
.50717 .36733 Mdot
.63239 .61311 Mdot
.5937 .25691 Mdot
.57443 .56419 Mdot
.46668 .3668 Mdot
.25463 .77171 Mdot
.60082 .54171 Mdot
.59359 .58119 Mdot
.72562 .32412 Mdot
.65459 .43699 Mdot
.65241 .38083 Mdot
.36604 .78063 Mdot
.61958 .58577 Mdot
.33316 .72339 Mdot
.62623 .43084 Mdot
.64346 .4272 Mdot
.35786 .32266 Mdot
.59394 .61445 Mdot
.63565 .71453 Mdot
.46579 .33607 Mdot
.49207 .38004 Mdot
.66012 .42582 Mdot
.59061 .54177 Mdot
.51578 .36402 Mdot
.797 .42813 Mdot
.36415 .47405 Mdot
.618 .79978 Mdot
.64596 .43484 Mdot
.53512 .42985 Mdot
.48336 .33546 Mdot
.15694 .37616 Mdot
.31521 .50179 Mdot
.62833 .62087 Mdot
.61274 .57845 Mdot
.38672 .6213 Mdot
.60317 .54343 Mdot
.39078 .4903 Mdot
.48438 .34927 Mdot
.70077 .44579 Mdot
.619 .42071 Mdot
.60628 .59073 Mdot
.49985 .21359 Mdot
.41199 .25434 Mdot
.23438 .47363 Mdot
.64759 .41761 Mdot
.61588 .39664 Mdot
.38916 .47863 Mdot
.3683 .43867 Mdot
.57811 .58878 Mdot
.4861 .32393 Mdot
.62863 .38098 Mdot
.46237 .361 Mdot
.35307 .50361 Mdot
.37198 .48867 Mdot
.323 .48428 Mdot
.53512 .59341 Mdot
.38171 .47749 Mdot
.30098 .52272 Mdot
.52073 .24496 Mdot
.64999 .37314 Mdot
.26912 .70539 Mdot
.57173 .31041 Mdot
.61687 .34708 Mdot
.40224 .61752 Mdot
.35731 .44636 Mdot
.45261 .34021 Mdot
.57081 .61691 Mdot
.56847 .57873 Mdot
.28041 .47297 Mdot
.45809 .33709 Mdot
.36014 .64627 Mdot
.45264 .35065 Mdot
.3551 .62627 Mdot
.25315 .59411 Mdot
.59405 .54972 Mdot
.56946 .63679 Mdot
.47948 .34938 Mdot
.38005 .47722 Mdot
.34156 .46546 Mdot
.34239 .64615 Mdot
.56086 .41911 Mdot
.33336 .45634 Mdot
.64203 .43401 Mdot
.78022 .44871 Mdot
.31949 .45021 Mdot
.61663 .59032 Mdot
.5122 .71163 Mdot
.8098 .5645 Mdot
.64989 .60431 Mdot
.3496 .32613 Mdot
.762 .66037 Mdot
.62177 .57154 Mdot
.79851 .62321 Mdot
.29151 .38973 Mdot
.67181 .42173 Mdot
.3867 .46305 Mdot
.32228 .43334 Mdot
.53069 .58791 Mdot
.34225 .62281 Mdot
.57387 .66431 Mdot
.64355 .43956 Mdot
.64993 .45629 Mdot
.25971 .65403 Mdot
.67297 .25835 Mdot
.3867 .6384 Mdot
.38047 .64859 Mdot
.36026 .487 Mdot
.71658 .24559 Mdot
.66371 .65077 Mdot
.36475 .64736 Mdot
.49606 .62169 Mdot
.59623 .64403 Mdot
.47979 .74986 Mdot
.31081 .66884 Mdot
.6589 .42185 Mdot
.43104 .66572 Mdot
.35607 .49061 Mdot
.67047 .4008 Mdot
.60613 .26934 Mdot
.62535 .56383 Mdot
.62192 .42184 Mdot
.46261 .36454 Mdot
.39658 .37089 Mdot
.63038 .43991 Mdot
.51147 .71825 Mdot
.50224 .33248 Mdot
.42412 .56771 Mdot
.4246 .69779 Mdot
.81417 .70674 Mdot
.48182 .35403 Mdot
.32003 .46513 Mdot
.35343 .47679 Mdot
.34479 .4838 Mdot
.6654 .39508 Mdot
.36477 .4457 Mdot
.65654 .38833 Mdot
.78146 .3516 Mdot
.59693 .47351 Mdot
.36873 .64728 Mdot
.36695 .30602 Mdot
.63369 .39448 Mdot
.55628 .83685 Mdot
.54366 .86945 Mdot
.55022 .60474 Mdot
.44897 .34204 Mdot
.37742 .64513 Mdot
.5163 .17617 Mdot
.37897 .63113 Mdot
.36981 .69298 Mdot
.62995 .77463 Mdot
.59874 .59119 Mdot
.75487 .55127 Mdot
.39877 .63764 Mdot
.6499 .40887 Mdot
.58154 .6099 Mdot
.42511 .41823 Mdot
.37852 .62755 Mdot
.35168 .62977 Mdot
.58067 .59638 Mdot
.61067 .42032 Mdot
.35962 .49322 Mdot
.45457 .37528 Mdot
.40011 .64643 Mdot
.65356 .36057 Mdot
.64466 .59445 Mdot
.62457 .63715 Mdot
.44994 .55698 Mdot
.39752 .66148 Mdot
.4864 .35067 Mdot
.82581 .55103 Mdot
.37824 .44762 Mdot
.40277 .40928 Mdot
.30971 .7021 Mdot
.33038 .34311 Mdot
.36289 .45966 Mdot
.35974 .44993 Mdot
.57285 .59336 Mdot
.40937 .64756 Mdot
.64738 .75809 Mdot
.44553 .32233 Mdot
.31565 .45621 Mdot
.3402 .48028 Mdot
.66743 .44626 Mdot
.26697 .66447 Mdot
.56506 .66276 Mdot
.51701 .35283 Mdot
.32835 .4905 Mdot
.57079 .41898 Mdot
.37558 .6211 Mdot
.56374 .82322 Mdot
.59757 .54959 Mdot
.62928 .61716 Mdot
.49655 .3507 Mdot
.4711 .37285 Mdot
.42499 .44841 Mdot
.29856 .68789 Mdot
.77083 .64368 Mdot
.54384 .30639 Mdot
.6985 .61269 Mdot
.66105 .44973 Mdot
.62197 .38507 Mdot
.43233 .26795 Mdot
.46373 .32329 Mdot
.62603 .57901 Mdot
.63642 .38282 Mdot
.33158 .40195 Mdot
.70661 .35239 Mdot
.46304 .75951 Mdot
.3781 .75535 Mdot
.61463 .63168 Mdot
.66251 .40825 Mdot
.65403 .43635 Mdot
.59899 .39726 Mdot
.29999 .38765 Mdot
.58278 .58248 Mdot
.61311 .62277 Mdot
.60411 .5591 Mdot
.54669 .51872 Mdot
.59303 .56804 Mdot
.61919 .32713 Mdot
.48328 .49319 Mdot
.67361 .53011 Mdot
.57574 .5328 Mdot
.51605 .33293 Mdot
.64082 .61995 Mdot
.36521 .60646 Mdot
.58233 .63528 Mdot
.46801 .76298 Mdot
.49817 .33627 Mdot
.60956 .35393 Mdot
.579 .31794 Mdot
.64044 .60032 Mdot
.36853 .66198 Mdot
.48799 .41189 Mdot
.22286 .34851 Mdot
.34175 .66581 Mdot
.64312 .43406 Mdot
.36509 .46842 Mdot
.45467 .33757 Mdot
.37265 .48492 Mdot
.5367 .59088 Mdot
.4369 .26979 Mdot
.41993 .23158 Mdot
.52397 .45944 Mdot
.56918 .57287 Mdot
.66324 .58009 Mdot
.64048 .43013 Mdot
.35848 .44259 Mdot
.62178 .47657 Mdot
.6282 .58676 Mdot
.35656 .62998 Mdot
.38239 .62407 Mdot
.42748 .41319 Mdot
.37192 .21334 Mdot
.66134 .33365 Mdot
.49404 .35017 Mdot
.33055 .46773 Mdot
.3944 .61563 Mdot
.62732 .24854 Mdot
.4741 .39101 Mdot
.48057 .3235 Mdot
.50943 .34888 Mdot
.63132 .64689 Mdot
.32012 .47351 Mdot
.67252 .52309 Mdot
.38187 .50218 Mdot
.60614 .62396 Mdot
.33823 .49464 Mdot
.33747 .4505 Mdot
.38283 .61222 Mdot
.51021 .36004 Mdot
.3725 .50134 Mdot
.5599 .62234 Mdot
.61846 .42892 Mdot
.5388 .41211 Mdot
.52182 .76198 Mdot
.65476 .24931 Mdot
.70867 .41727 Mdot
.63418 .44681 Mdot
.26653 .27665 Mdot
.49523 .31868 Mdot
.52121 .54044 Mdot
.25072 .42386 Mdot
.61031 .6542 Mdot
.57961 .84021 Mdot
.35414 .43122 Mdot
.33234 .44813 Mdot
.56425 .60374 Mdot
.35201 .40889 Mdot
.60198 .58827 Mdot
.35945 .50158 Mdot
.27223 .46123 Mdot
.55464 .52871 Mdot
.37789 .46824 Mdot
.57303 .53162 Mdot
.58968 .61885 Mdot
.66065 .42071 Mdot
.34245 .43226 Mdot
.5638 .64171 Mdot
.51098 .15612 Mdot
.47291 .37098 Mdot
.32169 .38071 Mdot
.53209 .71822 Mdot
.47748 .35609 Mdot
.61794 .41297 Mdot
.59246 .66403 Mdot
.38753 .62731 Mdot
.63557 .39283 Mdot
.54047 .78075 Mdot
.39138 .64565 Mdot
.56041 .84134 Mdot
.65511 .43252 Mdot
.32253 .44558 Mdot
.3699 .60934 Mdot
.61998 .5475 Mdot
.31521 .47282 Mdot
.43867 .40084 Mdot
.36488 .45982 Mdot
.5804 .57481 Mdot
.36856 .29505 Mdot
.5037 .37191 Mdot
.60961 .61041 Mdot
.33213 .44452 Mdot
.33508 .33248 Mdot
.62911 .64725 Mdot
.57216 .60835 Mdot
.23237 .63963 Mdot
.49826 .82963 Mdot
.37408 .63749 Mdot
.59419 .40028 Mdot
.55662 .61434 Mdot
.35056 .63946 Mdot
.28695 .58567 Mdot
.63639 .62998 Mdot
.60981 .43781 Mdot
.6167 .51642 Mdot
.34692 .43457 Mdot
.47339 .36105 Mdot
.52263 .45462 Mdot
.35012 .64401 Mdot
.87384 .4956 Mdot
.35858 .50669 Mdot
.58513 .65042 Mdot
.56167 .57956 Mdot
.21235 .5092 Mdot
.67221 .41957 Mdot
.7181 .69609 Mdot
.60967 .57897 Mdot
.5368 .52809 Mdot
.61543 .60119 Mdot
.36048 .42386 Mdot
.64498 .42555 Mdot
.59128 .57782 Mdot
.5331 .23516 Mdot
.65448 .62673 Mdot
.35413 .65634 Mdot
.73422 .3254 Mdot
.64679 .60412 Mdot
.36456 .8428 Mdot
.32 .67846 Mdot
.37902 .46795 Mdot
.40615 .26944 Mdot
.65517 .17045 Mdot
.59751 .31961 Mdot
.65217 .38491 Mdot
.34966 .25347 Mdot
.368 .48983 Mdot
.36528 .283 Mdot
.26103 .27867 Mdot
.58725 .62109 Mdot
.64131 .61753 Mdot
.35457 .68743 Mdot
.39406 .47137 Mdot
.348 .50995 Mdot
.55602 .55877 Mdot
.62343 .67425 Mdot
.37707 .48817 Mdot
.55627 .62223 Mdot
.54098 .57636 Mdot
.44902 .36861 Mdot
.62902 .44469 Mdot
.46624 .34175 Mdot
.51011 .33976 Mdot
.77321 .38643 Mdot
.2875 .66134 Mdot
.46914 .36705 Mdot
.50913 .32954 Mdot
.48299 .7528 Mdot
.38942 .73277 Mdot
.39811 .61397 Mdot
.41939 .18151 Mdot
.34472 .48139 Mdot
.58515 .58539 Mdot
.64331 .44428 Mdot
.77623 .62598 Mdot
.32663 .57264 Mdot
.65533 .7621 Mdot
.62687 .58233 Mdot
.34556 .48774 Mdot
.30027 .38712 Mdot
.60081 .68592 Mdot
.3958 .50772 Mdot
.63431 .61429 Mdot
.34617 .50808 Mdot
.76677 .48207 Mdot
.52866 .22276 Mdot
.33645 .50842 Mdot
.661 .37449 Mdot
.62832 .61064 Mdot
.6477 .43555 Mdot
.47884 .33779 Mdot
.37891 .60637 Mdot
.37031 .63755 Mdot
.57971 .60424 Mdot
.61374 .53013 Mdot
.26346 .60723 Mdot
.59483 .61823 Mdot
.59141 .63887 Mdot
.29115 .38977 Mdot
.58573 .63481 Mdot
.57789 .56625 Mdot
.59023 .56114 Mdot
.63219 .65832 Mdot
.49534 .37862 Mdot
.50346 .21586 Mdot
.54374 .65031 Mdot
.54677 .65879 Mdot
.48702 .38789 Mdot
.27399 .31576 Mdot
.5024 .32776 Mdot
.22302 .33064 Mdot
.46059 .34496 Mdot
.36407 .64191 Mdot
.21463 .43971 Mdot
.65072 .56808 Mdot
.60507 .41409 Mdot
.45129 .38503 Mdot
.35356 .63597 Mdot
.48517 .34472 Mdot
.35522 .49919 Mdot
.17945 .5639 Mdot
.60482 .36884 Mdot
.52158 .67956 Mdot
.43463 .36724 Mdot
.43474 .28159 Mdot
.37631 .50138 Mdot
.651 .42832 Mdot
.78317 .54345 Mdot
.57541 .56548 Mdot
.35148 .63469 Mdot
.57753 .5925 Mdot
.51023 .36684 Mdot
.35267 .4889 Mdot
.73388 .30644 Mdot
.38871 .62775 Mdot
.26807 .6958 Mdot
.34435 .46966 Mdot
.59279 .55741 Mdot
.51662 .35577 Mdot
.30819 .74636 Mdot
.46393 .34624 Mdot
.70024 .68641 Mdot
.67542 .42896 Mdot
.81516 .39255 Mdot
.62824 .39432 Mdot
.41673 .38455 Mdot
.19995 .66378 Mdot
.5251 .20007 Mdot
.61225 .42216 Mdot
.47406 .28682 Mdot
.61772 .63546 Mdot
.62562 .63572 Mdot
.6433 .25436 Mdot
.59415 .40209 Mdot
.55164 .59766 Mdot
.27182 .3961 Mdot
.51265 .25543 Mdot
.39289 .77727 Mdot
.36515 .45227 Mdot
.60457 .5854 Mdot
.51678 .37747 Mdot
.45807 .34155 Mdot
.36834 .50687 Mdot
.48953 .31971 Mdot
.61124 .62123 Mdot
.63247 .39472 Mdot
.41256 .46653 Mdot
.36319 .63023 Mdot
.59286 .18915 Mdot
.36959 .59915 Mdot
.36228 .4598 Mdot
.61774 .54195 Mdot
.37316 .48799 Mdot
.67104 .16421 Mdot
.61724 .62126 Mdot
.62801 .43059 Mdot
.56731 .62086 Mdot
.62523 .60981 Mdot
.64229 .61563 Mdot
.36415 .49602 Mdot
.6481 .71789 Mdot
.55813 .62226 Mdot
.49284 .36531 Mdot
.68266 .55343 Mdot
.64415 .59916 Mdot
.33696 .4188 Mdot
.42051 .7401 Mdot
.42905 .32013 Mdot
.65379 .44329 Mdot
.37335 .46202 Mdot
.61638 .42009 Mdot
.63202 .48249 Mdot
.61818 .41314 Mdot
.70983 .58464 Mdot
.78152 .52783 Mdot
.65662 .72127 Mdot
.72491 .41639 Mdot
.51576 .51309 Mdot
.59418 .40093 Mdot
.33402 .67527 Mdot
.61638 .38553 Mdot
.65817 .43377 Mdot
.11231 .63023 Mdot
.60396 .40332 Mdot
.61489 .58631 Mdot
.62725 .57 Mdot
.47039 .25281 Mdot
.47522 .71799 Mdot
.57511 .62246 Mdot
.56007 .61226 Mdot
.38286 .60964 Mdot
.52468 .54964 Mdot
.41946 .27093 Mdot
.4885 .83858 Mdot
.38771 .26134 Mdot
.57875 .5952 Mdot
.55837 .61677 Mdot
.61849 .68087 Mdot
.3362 .7954 Mdot
.8059 .42252 Mdot
.61602 .45252 Mdot
.64689 .66113 Mdot
.59106 .20553 Mdot
.63952 .60864 Mdot
.63863 .6391 Mdot
.61609 .63273 Mdot
.367 .49003 Mdot
.62721 .45162 Mdot
.60698 .67051 Mdot
.30858 .68152 Mdot
.63788 .61835 Mdot
.33371 .33899 Mdot
.78302 .31596 Mdot
.60271 .5816 Mdot
.63383 .45345 Mdot
.61931 .64296 Mdot
.66824 .42212 Mdot
.65456 .40849 Mdot
.65472 .59501 Mdot
.69763 .60233 Mdot
.64978 .4537 Mdot
.60579 .62443 Mdot
.35115 .49423 Mdot
.39744 .18293 Mdot
.58187 .57354 Mdot
.38584 .60718 Mdot
.61367 .57981 Mdot
.37383 .66145 Mdot
.58996 .63548 Mdot
.35584 .50695 Mdot
.79541 .58906 Mdot
.36261 .4845 Mdot
.82754 .43066 Mdot
.32452 .49129 Mdot
.23834 .64966 Mdot
.60719 .4391 Mdot
.36579 .30186 Mdot
.73898 .70944 Mdot
.32464 .36603 Mdot
.41442 .5431 Mdot
.46246 .49924 Mdot
.48603 .32362 Mdot
.67598 .41508 Mdot
.49123 .57555 Mdot
.2571 .43792 Mdot
.24075 .45176 Mdot
.32875 .45833 Mdot
.80065 .65544 Mdot
.66581 .77003 Mdot
.57291 .63599 Mdot
.74269 .56575 Mdot
.70996 .50547 Mdot
.64276 .62069 Mdot
.61044 .66823 Mdot
.28122 .45962 Mdot
.54697 .60589 Mdot
.58758 .25178 Mdot
.35839 .46031 Mdot
.35337 .63429 Mdot
.63541 .43258 Mdot
.34859 .64354 Mdot
.25481 .43842 Mdot
.45859 .50264 Mdot
.35415 .50215 Mdot
.64617 .64928 Mdot
.56481 .61422 Mdot
.66542 .4197 Mdot
.59632 .44607 Mdot
.6094 .39377 Mdot
.3842 .63912 Mdot
.35522 .46461 Mdot
.81578 .5207 Mdot
.55737 .60487 Mdot
.64158 .40575 Mdot
.41138 .53441 Mdot
.55456 .61143 Mdot
.47654 .34588 Mdot
.62115 .63018 Mdot
.61709 .43065 Mdot
.58563 .63463 Mdot
.62914 .3924 Mdot
.36596 .47096 Mdot
.62398 .56933 Mdot
.56557 .59931 Mdot
.29165 .72736 Mdot
.35937 .64361 Mdot
.59957 .42828 Mdot
.29141 .42231 Mdot
.56121 .57619 Mdot
.37489 .32365 Mdot
.63137 .60737 Mdot
.70382 .34782 Mdot
.61024 .65711 Mdot
.31487 .37045 Mdot
.55079 .65193 Mdot
.58337 .57394 Mdot
.43008 .48031 Mdot
.7109 .52791 Mdot
.58858 .42029 Mdot
.51826 .35205 Mdot
.6013 .41359 Mdot
.40111 .7764 Mdot
.31522 .49791 Mdot
.35787 .44046 Mdot
.46386 .65468 Mdot
.63154 .65988 Mdot
.59656 .59033 Mdot
.50028 .3892 Mdot
.37319 .65399 Mdot
.64784 .41574 Mdot
.35508 .62677 Mdot
.31853 .7253 Mdot
.39118 .64189 Mdot
.35393 .42812 Mdot
.27898 .61671 Mdot
.81047 .48328 Mdot
.38334 .61028 Mdot
.6105 .42107 Mdot
.34033 .58483 Mdot
.64115 .64699 Mdot
.32723 .67944 Mdot
.35932 .62482 Mdot
.83736 .60612 Mdot
.57764 .56711 Mdot
.40995 .5467 Mdot
.46803 .36072 Mdot
.37477 .60967 Mdot
.49285 .32776 Mdot
.57403 .6172 Mdot
.40728 .28565 Mdot
.64527 .38389 Mdot
.5058 .37733 Mdot
.59544 .53455 Mdot
.37567 .64668 Mdot
.3258 .48414 Mdot
.46326 .39517 Mdot
.5175 .35981 Mdot
.29639 .28605 Mdot
.75305 .32334 Mdot
.35388 .46659 Mdot
.53423 .80069 Mdot
.46217 .34041 Mdot
.64527 .61896 Mdot
.50976 .57771 Mdot
.62892 .62091 Mdot
.63634 .32982 Mdot
.37165 .4581 Mdot
.47883 .24132 Mdot
.56641 .622 Mdot
.6107 .56486 Mdot
.59104 .42291 Mdot
.35507 .48096 Mdot
.63025 .40794 Mdot
.60049 .40624 Mdot
.36468 .47217 Mdot
.62123 .3984 Mdot
.39426 .64459 Mdot
.5302 .26866 Mdot
.45787 .37144 Mdot
.49881 .36269 Mdot
.34132 .48194 Mdot
.38144 .46897 Mdot
.37752 .48169 Mdot
.6215 .63001 Mdot
.64743 .42145 Mdot
.59631 .63205 Mdot
.63979 .6208 Mdot
.69614 .62284 Mdot
.64155 .44797 Mdot
.60887 .63683 Mdot
.41619 .41892 Mdot
.41555 .61926 Mdot
.34781 .49434 Mdot
.46962 .36516 Mdot
.30683 .32999 Mdot
.47439 .40608 Mdot
.60817 .58753 Mdot
.25031 .62095 Mdot
.6082 .40811 Mdot
.38452 .62682 Mdot
.39639 .60463 Mdot
.37778 .63357 Mdot
.49552 .3048 Mdot
.59454 .40771 Mdot
.49543 .84006 Mdot
.60102 .58604 Mdot
.44761 .55817 Mdot
.49707 .63185 Mdot
.25699 .60905 Mdot
.47162 .36775 Mdot
.55707 .61254 Mdot
.53362 .44792 Mdot
.79201 .54032 Mdot
.62671 .61867 Mdot
.64933 .62199 Mdot
.26279 .40468 Mdot
.62017 .51488 Mdot
.67806 .42793 Mdot
.32473 .74954 Mdot
.58613 .5495 Mdot
.5767 .43226 Mdot
.62125 .19015 Mdot
.61827 .59441 Mdot
.61829 .57412 Mdot
.56211 .58842 Mdot
.58461 .63805 Mdot
.64807 .4518 Mdot
.44661 .68821 Mdot
.49234 .31782 Mdot
.4503 .5712 Mdot
.47609 .38458 Mdot
.31687 .48378 Mdot
.5009 .22243 Mdot
.67666 .41534 Mdot
.38693 .62165 Mdot
.49726 .19929 Mdot
.40089 .8064 Mdot
.38953 .47136 Mdot
.78891 .41871 Mdot
.35746 .63366 Mdot
.64656 .61793 Mdot
.3926 .64914 Mdot
.32034 .47127 Mdot
.49434 .36903 Mdot
.63649 .6592 Mdot
.61592 .3878 Mdot
.63282 .44052 Mdot
.55064 .60141 Mdot
.56911 .20017 Mdot
.47381 .34938 Mdot
.48911 .39188 Mdot
.63451 .63905 Mdot
.61886 .54716 Mdot
.62734 .40877 Mdot
.33458 .46959 Mdot
.47916 .78961 Mdot
.36662 .65339 Mdot
.5436 .61748 Mdot
.59127 .64133 Mdot
.30233 .69708 Mdot
.48713 .37286 Mdot
.38358 .44751 Mdot
.6196 .65061 Mdot
.53627 .30673 Mdot
.6184 .65054 Mdot
.641 .67161 Mdot
.34816 .49278 Mdot
.53994 .63848 Mdot
.56432 .63185 Mdot
.53612 .66139 Mdot
.47844 .32887 Mdot
.6257 .42549 Mdot
.61881 .36831 Mdot
.46415 .57455 Mdot
.47813 .34446 Mdot
.61229 .63997 Mdot
.47934 .36783 Mdot
.63608 .6281 Mdot
.549 .60602 Mdot
.46673 .36648 Mdot
.62979 .40716 Mdot
.34666 .25921 Mdot
.49971 .21658 Mdot
.58118 .63651 Mdot
.5657 .56096 Mdot
.4569 .69874 Mdot
.64089 .72534 Mdot
.63177 .59359 Mdot
.62269 .43551 Mdot
.56034 .60482 Mdot
.4927 .33024 Mdot
.3995 .63247 Mdot
.61764 .42895 Mdot
.34302 .46046 Mdot
.39035 .48225 Mdot
.585 .31778 Mdot
.3487 .44641 Mdot
.63805 .64711 Mdot
.62832 .48219 Mdot
.60593 .37532 Mdot
.61749 .19908 Mdot
.36164 .4747 Mdot
.40429 .62484 Mdot
.57391 .60823 Mdot
.23482 .61664 Mdot
.50826 .38631 Mdot
.41681 .87322 Mdot
.54348 .84384 Mdot
.34591 .61769 Mdot
.66465 .74754 Mdot
.32401 .49601 Mdot
.55256 .62454 Mdot
.37689 .60541 Mdot
.38845 .4752 Mdot
.60705 .65248 Mdot
.65895 .6422 Mdot
.71027 .70136 Mdot
.47945 .53716 Mdot
.47979 .3696 Mdot
.3721 .44726 Mdot
.36507 .59306 Mdot
.37373 .43595 Mdot
.6426 .44241 Mdot
.58516 .57632 Mdot
.62955 .54922 Mdot
.3378 .46384 Mdot
.39324 .46374 Mdot
.60946 .63006 Mdot
.6768 .41128 Mdot
.28289 .46116 Mdot
.58304 .60027 Mdot
.52893 .50725 Mdot
.67825 .38451 Mdot
.35593 .45643 Mdot
.60034 .56255 Mdot
.36534 .57396 Mdot
.3411 .46982 Mdot
.3459 .49429 Mdot
.5498 .6045 Mdot
.39193 .64659 Mdot
.56824 .56097 Mdot
.45549 .35502 Mdot
.82867 .56409 Mdot
.4977 .33242 Mdot
.34616 .56101 Mdot
.60494 .53139 Mdot
.53845 .32829 Mdot
.66168 .43695 Mdot
.36765 .68983 Mdot
.2735 .37021 Mdot
.55821 .5547 Mdot
.3403 .22975 Mdot
.52671 .43188 Mdot
.55106 .18688 Mdot
.1941 .43533 Mdot
.36854 .61728 Mdot
.48552 .34207 Mdot
.61936 .57545 Mdot
.44673 .35269 Mdot
.37996 .60446 Mdot
.82055 .4224 Mdot
.59412 .56217 Mdot
.64328 .42599 Mdot
.61256 .62759 Mdot
.64527 .4345 Mdot
.55177 .60933 Mdot
.5872 .68211 Mdot
.27897 .39053 Mdot
.53267 .77616 Mdot
.61815 .65504 Mdot
.19109 .60488 Mdot
.31274 .63225 Mdot
.3554 .64639 Mdot
.59388 .6261 Mdot
.38157 .52142 Mdot
.46148 .33415 Mdot
.6427 .27001 Mdot
.36716 .49076 Mdot
.5084 .33335 Mdot
.62132 .40676 Mdot
.36811 .46166 Mdot
.39063 .48638 Mdot
.54045 .6367 Mdot
.35628 .65995 Mdot
.50696 .35998 Mdot
.5922 .57574 Mdot
.59196 .56366 Mdot
.50026 .80501 Mdot
.31692 .5579 Mdot
.58067 .41464 Mdot
.40284 .82896 Mdot
.63076 .36873 Mdot
.36366 .64876 Mdot
.36163 .49358 Mdot
.63186 .60014 Mdot
.60697 .6106 Mdot
.35442 .31454 Mdot
.63389 .37892 Mdot
.50172 .4968 Mdot
.75931 .39375 Mdot
.28801 .44971 Mdot
.44779 .74011 Mdot
.6317 .43517 Mdot
.45108 .74092 Mdot
.3825 .59265 Mdot
.45343 .18336 Mdot
.50587 .77065 Mdot
.47017 .36214 Mdot
.44757 .73714 Mdot
.64597 .40373 Mdot
.56788 .63005 Mdot
.32297 .44392 Mdot
.33904 .45 Mdot
.62807 .41873 Mdot
.4032 .47979 Mdot
.3829 .61359 Mdot
.60911 .5696 Mdot
.48407 .83345 Mdot
.59532 .30005 Mdot
.32925 .47352 Mdot
.58595 .68321 Mdot
.50871 .34687 Mdot
.55003 .59889 Mdot
.39085 .614 Mdot
.48251 .35861 Mdot
.32489 .69473 Mdot
.49869 .24966 Mdot
.57788 .60906 Mdot
.25149 .6583 Mdot
.48068 .34821 Mdot
.61994 .73782 Mdot
.58297 .59247 Mdot
.46501 .33745 Mdot
.67632 .60024 Mdot
.39998 .37439 Mdot
.53459 .45302 Mdot
.26306 .27627 Mdot
.51304 .47382 Mdot
.3209 .45261 Mdot
.40463 .34265 Mdot
.3513 .39235 Mdot
.44942 .34744 Mdot
.3918 .45796 Mdot
.42152 .60781 Mdot
.4918 .32703 Mdot
.64398 .60152 Mdot
.62757 .60343 Mdot
.808 .41992 Mdot
.51232 .43464 Mdot
.41338 .36988 Mdot
.64809 .30503 Mdot
.56546 .57145 Mdot
.58924 .5454 Mdot
.60297 .60585 Mdot
.6485 .45627 Mdot
.48521 .3695 Mdot
.22903 .66535 Mdot
.47597 .34285 Mdot
.55546 .8214 Mdot
.34585 .48317 Mdot
.3729 .45408 Mdot
.60618 .5841 Mdot
.40943 .56528 Mdot
.40173 .7104 Mdot
.60901 .62112 Mdot
.43413 .61252 Mdot
.72905 .32108 Mdot
.60914 .54309 Mdot
.6698 .43402 Mdot
.52511 .61536 Mdot
.67333 .36523 Mdot
.45709 .37071 Mdot
.37227 .62182 Mdot
.38013 .68809 Mdot
.49709 .36922 Mdot
.59675 .59179 Mdot
.5073 .29075 Mdot
.62072 .61005 Mdot
.58667 .64247 Mdot
.58201 .81651 Mdot
.36458 .60011 Mdot
.37349 .47647 Mdot
.37847 .63574 Mdot
.66683 .4268 Mdot
.27964 .81016 Mdot
.37023 .65642 Mdot
.39673 .70693 Mdot
.83501 .46241 Mdot
.45092 .73644 Mdot
.63999 .44158 Mdot
.35134 .65987 Mdot
.47236 .35603 Mdot
.41558 .16745 Mdot
.73681 .69451 Mdot
.53619 .38944 Mdot
.58743 .60125 Mdot
.67417 .39785 Mdot
.61878 .43744 Mdot
.498 .3826 Mdot
.6531 .40871 Mdot
.67506 .60607 Mdot
.57498 .63408 Mdot
.44881 .34444 Mdot
.53838 .29465 Mdot
.51881 .35557 Mdot
.54118 .25514 Mdot
.59788 .62552 Mdot
.62664 .43307 Mdot
.54027 .56695 Mdot
.68769 .41954 Mdot
.37528 .43941 Mdot
.64651 .59681 Mdot
.38429 .61437 Mdot
.5496 .35388 Mdot
.35148 .46649 Mdot
.24554 .60587 Mdot
.66468 .42236 Mdot
.44193 .30264 Mdot
.66066 .41815 Mdot
.59734 .39276 Mdot
.50696 .33478 Mdot
.65006 .39028 Mdot
.61543 .57181 Mdot
.41888 .41179 Mdot
.67027 .40874 Mdot
.50083 .34638 Mdot
.36939 .62705 Mdot
.62497 .39947 Mdot
.3573 .40899 Mdot
.57171 .60207 Mdot
.3736 .49469 Mdot
.21538 .45597 Mdot
.63976 .3736 Mdot
.34594 .63318 Mdot
.35697 .44148 Mdot
.35232 .62637 Mdot
.69214 .25066 Mdot
.44986 .33661 Mdot
.63447 .76915 Mdot
.40371 .58646 Mdot
.6051 .40756 Mdot
.21717 .43765 Mdot
.62971 .59862 Mdot
.57177 .60484 Mdot
.37782 .66105 Mdot
.61836 .43701 Mdot
.49422 .18603 Mdot
.66247 .34984 Mdot
.51485 .26452 Mdot
.441 .3706 Mdot
.22066 .63257 Mdot
.54828 .24656 Mdot
.73918 .26094 Mdot
.57124 .54919 Mdot
.33722 .50725 Mdot
.60725 .59353 Mdot
.28163 .35713 Mdot
.37669 .64492 Mdot
.39593 .43558 Mdot
.6546 .60486 Mdot
.37086 .46974 Mdot
.56845 .58729 Mdot
.43512 .44675 Mdot
.52892 .60365 Mdot
.40383 .62121 Mdot
.40981 .27133 Mdot
.60319 .40865 Mdot
.3613 .63044 Mdot
.35135 .50489 Mdot
.41609 .71957 Mdot
.59396 .64969 Mdot
.53438 .5997 Mdot
.28813 .45079 Mdot
.64843 .42759 Mdot
.3343 .43666 Mdot
.45489 .36415 Mdot
.38131 .62105 Mdot
.57002 .61776 Mdot
.62478 .65764 Mdot
.37237 .32712 Mdot
.51083 .35167 Mdot
.39826 .48551 Mdot
.46685 .34336 Mdot
.32476 .4986 Mdot
.54504 .58849 Mdot
.37131 .45199 Mdot
.56142 .63592 Mdot
.28505 .37645 Mdot
.58025 .81455 Mdot
.7217 .54359 Mdot
.36957 .45676 Mdot
.43615 .75409 Mdot
.49558 .33467 Mdot
.46542 .34031 Mdot
.82603 .49165 Mdot
.69906 .69339 Mdot
.45889 .81123 Mdot
.25038 .32865 Mdot
.47271 .38324 Mdot
.50646 .34596 Mdot
.37886 .49158 Mdot
.65452 .39193 Mdot
.61272 .3772 Mdot
.3311 .5024 Mdot
.51738 .71217 Mdot
.64771 .41553 Mdot
.39222 .19575 Mdot
.41383 .78956 Mdot
.59337 .66819 Mdot
.37188 .53361 Mdot
.37841 .62607 Mdot
.50673 .71358 Mdot
.43387 .44728 Mdot
.61614 .56853 Mdot
.29514 .68007 Mdot
.33502 .47584 Mdot
.46843 .62845 Mdot
.22422 .33079 Mdot
.58748 .56226 Mdot
.58396 .58653 Mdot
.60145 .59775 Mdot
.3407 .6375 Mdot
.72403 .67938 Mdot
.59941 .56503 Mdot
.52149 .71385 Mdot
.55374 .58559 Mdot
.67819 .65093 Mdot
.37266 .63735 Mdot
.6839 .60209 Mdot
.25229 .40676 Mdot
.34233 .75602 Mdot
.53133 .57153 Mdot
.45358 .35936 Mdot
.43328 .63371 Mdot
.47418 .32943 Mdot
.71158 .57454 Mdot
.50739 .76775 Mdot
.65197 .37229 Mdot
.61885 .57206 Mdot
.36178 .45929 Mdot
.62049 .43896 Mdot
.39083 .34624 Mdot
.18736 .72972 Mdot
.45274 .35447 Mdot
.75898 .25773 Mdot
.46093 .34683 Mdot
.3882 .49202 Mdot
.62651 .40976 Mdot
.78016 .51772 Mdot
.45302 .55345 Mdot
.62449 .39739 Mdot
.40575 .23562 Mdot
.6112 .45243 Mdot
.43304 .74316 Mdot
.65618 .3804 Mdot
.49975 .3418 Mdot
.49269 .3051 Mdot
.66928 .61984 Mdot
.62093 .5885 Mdot
.46197 .49321 Mdot
.39537 .72466 Mdot
.62661 .59344 Mdot
.35759 .46246 Mdot
.66379 .73516 Mdot
.4275 .66201 Mdot
.64604 .39257 Mdot
.49246 .31574 Mdot
.58072 .58464 Mdot
.60762 .64891 Mdot
.58817 .64622 Mdot
.43749 .85335 Mdot
.45984 .18013 Mdot
.55797 .62157 Mdot
.5583 .57737 Mdot
.36891 .46493 Mdot
.39216 .59023 Mdot
.2726 .35564 Mdot
.68308 .67702 Mdot
.62708 .57633 Mdot
.36222 .63722 Mdot
.36011 .60084 Mdot
.61124 .65328 Mdot
.30738 .67155 Mdot
.50133 .29088 Mdot
.59144 .57529 Mdot
.68284 .69965 Mdot
.30597 .40562 Mdot
.39379 .47104 Mdot
.3404 .46375 Mdot
.62237 .4461 Mdot
.35296 .44873 Mdot
.33195 .50022 Mdot
.78862 .4978 Mdot
.50038 .48616 Mdot
.51765 .32448 Mdot
.38514 .63841 Mdot
.61083 .61111 Mdot
.58507 .40091 Mdot
.52647 .30053 Mdot
.49514 .32566 Mdot
.61045 .40184 Mdot
.46435 .33337 Mdot
.34802 .66833 Mdot
.50936 .6641 Mdot
.32505 .46219 Mdot
.47809 .38231 Mdot
.5007 .25058 Mdot
.36419 .63764 Mdot
.51331 .3528 Mdot
.46417 .27386 Mdot
.63816 .58295 Mdot
.74907 .5901 Mdot
.60473 .62114 Mdot
.52169 .18229 Mdot
.50821 .36413 Mdot
.31415 .36261 Mdot
.59276 .58513 Mdot
.34303 .47128 Mdot
.66732 .64921 Mdot
.63599 .61185 Mdot
.34122 .45722 Mdot
.57143 .63477 Mdot
.36125 .60537 Mdot
.67197 .37654 Mdot
.45416 .57268 Mdot
.75436 .73764 Mdot
.35572 .65999 Mdot
.38928 .3382 Mdot
.63051 .58945 Mdot
.73562 .29887 Mdot
.62693 .39898 Mdot
.57586 .64559 Mdot
.43465 .66405 Mdot
.66492 .39787 Mdot
.61334 .41186 Mdot
.61093 .64489 Mdot
.46747 .35706 Mdot
.35171 .46323 Mdot
.36861 .63675 Mdot
.68686 .23578 Mdot
.58839 .60921 Mdot
.56311 .60166 Mdot
.35882 .63176 Mdot
.50291 .33841 Mdot
.62325 .64843 Mdot
.2049 .4857 Mdot
.52398 .16457 Mdot
.4826 .32192 Mdot
.64099 .59585 Mdot
.72964 .62379 Mdot
.65266 .35675 Mdot
.85432 .44809 Mdot
.32495 .6799 Mdot
.37536 .46989 Mdot
.63659 .53232 Mdot
.3089 .8158 Mdot
.37225 .62361 Mdot
.41537 .80777 Mdot
.60018 .64845 Mdot
.55548 .60093 Mdot
.609 .39567 Mdot
.6018 .63415 Mdot
.65193 .38219 Mdot
.75388 .72864 Mdot
.29796 .69677 Mdot
.65104 .43127 Mdot
.60798 .39165 Mdot
.41374 .69068 Mdot
.27532 .35524 Mdot
.626 .41783 Mdot
.54639 .59168 Mdot
.66378 .47605 Mdot
.6107 .6995 Mdot
.38577 .65513 Mdot
.24446 .43663 Mdot
.63163 .35002 Mdot
.33169 .63948 Mdot
.31114 .27786 Mdot
.61829 .3529 Mdot
.51632 .30688 Mdot
.45781 .36561 Mdot
.59129 .55973 Mdot
.34264 .44811 Mdot
.36206 .44307 Mdot
.54313 .56647 Mdot
.61709 .61435 Mdot
.66603 .42559 Mdot
.39041 .63571 Mdot
.45227 .34528 Mdot
.56043 .61161 Mdot
.41288 .68065 Mdot
.36709 .65625 Mdot
.65714 .4018 Mdot
.67192 .71175 Mdot
.40428 .6177 Mdot
.55902 .67184 Mdot
.6021 .57527 Mdot
.6146 .63177 Mdot
.58942 .69527 Mdot
.47645 .37461 Mdot
.23028 .41877 Mdot
.60531 .54994 Mdot
.31896 .7271 Mdot
.54732 .4043 Mdot
.58949 .67825 Mdot
.6539 .41785 Mdot
.51332 .38289 Mdot
.32576 .43293 Mdot
.47288 .59739 Mdot
.58112 .6106 Mdot
.51269 .20402 Mdot
.78954 .39386 Mdot
.36615 .43525 Mdot
.59658 .39578 Mdot
.38226 .62945 Mdot
.6101 .61999 Mdot
.69262 .57492 Mdot
.62327 .59721 Mdot
.38121 .66562 Mdot
.33817 .48869 Mdot
.45806 .36427 Mdot
.54525 .18257 Mdot
.36327 .44393 Mdot
.6155 .4184 Mdot
.16299 .36347 Mdot
.66571 .39012 Mdot
.60354 .39125 Mdot
.68888 .57756 Mdot
.47025 .37332 Mdot
.34493 .84348 Mdot
.80809 .61684 Mdot
.63613 .56915 Mdot
.49033 .33305 Mdot
.63303 .42192 Mdot
.55436 .59088 Mdot
.67998 .41106 Mdot
.59356 .41383 Mdot
.54787 .58147 Mdot
.56595 .58004 Mdot
.5103 .22779 Mdot
.25235 .29209 Mdot
.38354 .63053 Mdot
.65878 .4352 Mdot
.51547 .52407 Mdot
.5584 .58428 Mdot
.60023 .58544 Mdot
.36522 .39305 Mdot
.39627 .64319 Mdot
.61578 .26546 Mdot
.6041 .64916 Mdot
.28218 .68259 Mdot
.5258 .60854 Mdot
.65461 .4498 Mdot
.48735 .32149 Mdot
.34262 .75254 Mdot
.43515 .3515 Mdot
.64235 .38079 Mdot
.39194 .62736 Mdot
.6078 .37091 Mdot
.39265 .70815 Mdot
.49856 .37895 Mdot
.61708 .43067 Mdot
.52452 .45346 Mdot
.48974 .35788 Mdot
.49808 .37353 Mdot
.68047 .55152 Mdot
.40045 .49171 Mdot
.34403 .62574 Mdot
.50836 .35579 Mdot
.53185 .52672 Mdot
.49458 .34353 Mdot
.81948 .54779 Mdot
.6249 .5702 Mdot
.48214 .66233 Mdot
.37708 .54548 Mdot
.65835 .57565 Mdot
.50271 .37332 Mdot
.38728 .61052 Mdot
.61788 .64715 Mdot
.64837 .40386 Mdot
.35298 .64713 Mdot
.48252 .40053 Mdot
.37424 .4899 Mdot
.66225 .4156 Mdot
.44046 .37694 Mdot
.63883 .43845 Mdot
.48903 .57763 Mdot
.84244 .50521 Mdot
.19498 .54199 Mdot
.46047 .54639 Mdot
.58922 .64615 Mdot
.25473 .3401 Mdot
.57962 .66819 Mdot
.62113 .61724 Mdot
.35621 .45807 Mdot
.46646 .6486 Mdot
.62979 .40802 Mdot
.52604 .17232 Mdot
.46846 .37875 Mdot
.32237 .74689 Mdot
.66158 .46937 Mdot
.58561 .64937 Mdot
.67091 .40783 Mdot
.66436 .38798 Mdot
.70365 .52281 Mdot
.32954 .42896 Mdot
.61165 .66676 Mdot
.62319 .66711 Mdot
.53955 .5892 Mdot
.48888 .37477 Mdot
.2507 .61649 Mdot
.32049 .45715 Mdot
.84641 .46141 Mdot
.33245 .48269 Mdot
.43588 .60957 Mdot
.65082 .39259 Mdot
.37357 .65528 Mdot
.59912 .5836 Mdot
.60284 .4509 Mdot
.63741 .37863 Mdot
.39341 .65544 Mdot
.37245 .6092 Mdot
.38486 .38702 Mdot
.46759 .36732 Mdot
.62566 .65497 Mdot
.60124 .56308 Mdot
.5937 .63219 Mdot
.62101 .62703 Mdot
.45186 .3602 Mdot
.62819 .63812 Mdot
.51793 .37308 Mdot
.49954 .6119 Mdot
.28771 .67059 Mdot
.50584 .47529 Mdot
.6976 .3355 Mdot
.64636 .39711 Mdot
.54451 .50725 Mdot
.59413 .68833 Mdot
.60454 .80725 Mdot
.708 .3091 Mdot
.61949 .55275 Mdot
.38794 .47031 Mdot
.64848 .70823 Mdot
.32845 .45565 Mdot
.80983 .31669 Mdot
.36214 .33467 Mdot
.28781 .26115 Mdot
.58928 .56546 Mdot
.35009 .39901 Mdot
.56411 .51132 Mdot
.57721 .66163 Mdot
.37212 .35779 Mdot
.64326 .33003 Mdot
.4392 .24318 Mdot
.39787 .62025 Mdot
.57597 .59864 Mdot
.58559 .40499 Mdot
.61147 .56944 Mdot
.60512 .58947 Mdot
.61169 .65156 Mdot
.51274 .33621 Mdot
.60575 .66504 Mdot
.62994 .6274 Mdot
.26314 .60091 Mdot
.47378 .75504 Mdot
.36765 .44303 Mdot
.82471 .46704 Mdot
.3648 .6576 Mdot
.66937 .41804 Mdot
.41386 .21398 Mdot
.47055 .36301 Mdot
.70454 .51378 Mdot
.61832 .62934 Mdot
.4964 .23139 Mdot
.45375 .39766 Mdot
.3831 .61851 Mdot
.31706 .45669 Mdot
.33843 .22129 Mdot
.3611 .46512 Mdot
.53084 .44745 Mdot
.34662 .47236 Mdot
.55965 .67696 Mdot
.66487 .42712 Mdot
.62518 .65158 Mdot
.50525 .36026 Mdot
.34952 .45342 Mdot
.46694 .70607 Mdot
.60372 .60441 Mdot
.36515 .47295 Mdot
.62574 .65125 Mdot
.50998 .66829 Mdot
.55845 .79266 Mdot
.34399 .50463 Mdot
.52415 .35801 Mdot
.49583 .35812 Mdot
.39186 .64613 Mdot
.66673 .41282 Mdot
.61626 .39023 Mdot
.48361 .35686 Mdot
.70897 .71408 Mdot
.63256 .58613 Mdot
.56241 .58033 Mdot
.32542 .74156 Mdot
.62496 .58499 Mdot
.41886 .73109 Mdot
.5329 .45012 Mdot
.6522 .40009 Mdot
.5519 .62071 Mdot
.60078 .64651 Mdot
.576 .6081 Mdot
.487 .6068 Mdot
.33302 .46859 Mdot
.60205 .55578 Mdot
.36726 .60965 Mdot
.42315 .44934 Mdot
.54985 .59837 Mdot
.53387 .60759 Mdot
.61467 .39158 Mdot
.42267 .83178 Mdot
.45947 .35187 Mdot
.36626 .50451 Mdot
.37299 .45727 Mdot
.24855 .43405 Mdot
.56108 .39276 Mdot
.52776 .45438 Mdot
.83662 .42927 Mdot
.27878 .39283 Mdot
.35645 .64342 Mdot
.39374 .52127 Mdot
.55509 .4178 Mdot
.38333 .4909 Mdot
.45228 .35314 Mdot
.62107 .56414 Mdot
.62674 .57514 Mdot
.57315 .83761 Mdot
.60156 .65458 Mdot
.37817 .6296 Mdot
.50784 .38164 Mdot
.64525 .40374 Mdot
.38398 .61958 Mdot
.46858 .33887 Mdot
.65064 .42692 Mdot
.61782 .55436 Mdot
.61529 .55368 Mdot
.61158 .40004 Mdot
.6139 .4297 Mdot
.59824 .57689 Mdot
.28936 .50305 Mdot
.60501 .41639 Mdot
.62703 .43579 Mdot
.32397 .46373 Mdot
.34015 .45048 Mdot
.54931 .65308 Mdot
.48726 .3348 Mdot
.63009 .63006 Mdot
.36586 .46121 Mdot
.39187 .64041 Mdot
.63211 .40451 Mdot
.58415 .63863 Mdot
.56251 .61722 Mdot
.36465 .63615 Mdot
.39589 .62612 Mdot
.37877 .61096 Mdot
.51926 .36099 Mdot
.58805 .62459 Mdot
.62232 .41241 Mdot
.46446 .36701 Mdot
.35702 .60265 Mdot
.39965 .64202 Mdot
.38487 .44183 Mdot
.63306 .60033 Mdot
.41684 .48697 Mdot
.2534 .77565 Mdot
.35422 .73117 Mdot
.34686 .4291 Mdot
.34964 .42388 Mdot
.46751 .73515 Mdot
.42742 .57306 Mdot
.47694 .35145 Mdot
.40973 .64563 Mdot
.37353 .69009 Mdot
.64708 .60454 Mdot
.58445 .55093 Mdot
.64561 .66052 Mdot
.37051 .61291 Mdot
.45524 .64163 Mdot
.67673 .41854 Mdot
.74176 .39787 Mdot
.35845 .6552 Mdot
.39354 .46449 Mdot
.40443 .48525 Mdot
.33327 .48425 Mdot
.61779 .55878 Mdot
.72371 .53665 Mdot
.57287 .48 Mdot
.2345 .35194 Mdot
.50956 .36453 Mdot
.59034 .38181 Mdot
.72374 .29444 Mdot
.61226 .40463 Mdot
.31763 .47987 Mdot
.35433 .63122 Mdot
.62071 .43625 Mdot
.46851 .32783 Mdot
.5075 .34981 Mdot
.33023 .47519 Mdot
.34352 .48432 Mdot
.35881 .50002 Mdot
.59743 .3986 Mdot
.65119 .39152 Mdot
.58395 .61337 Mdot
.63597 .39989 Mdot
.52778 .8521 Mdot
.34289 .65933 Mdot
.32266 .42477 Mdot
.48368 .34072 Mdot
.64846 .43406 Mdot
.60378 .60762 Mdot
.45223 .60041 Mdot
.63132 .3171 Mdot
.3556 .61779 Mdot
.5192 .80134 Mdot
.80919 .31978 Mdot
.62602 .65573 Mdot
.48489 .37279 Mdot
.48149 .83128 Mdot
.59968 .59938 Mdot
.35556 .49297 Mdot
.2656 .38378 Mdot
.31989 .50523 Mdot
.63893 .62198 Mdot
.65011 .63494 Mdot
.48705 .31934 Mdot
.82488 .42047 Mdot
.58857 .61363 Mdot
.61166 .27314 Mdot
.47291 .31586 Mdot
.3197 .46025 Mdot
.49401 .15299 Mdot
.2172 .49887 Mdot
.50864 .71002 Mdot
.32303 .46653 Mdot
.62617 .60963 Mdot
.3283 .46009 Mdot
.36168 .60928 Mdot
.33205 .49499 Mdot
.67726 .42493 Mdot
.35145 .4352 Mdot
.56273 .60052 Mdot
.62666 .42052 Mdot
.47985 .34761 Mdot
.35433 .77906 Mdot
.30861 .5995 Mdot
.3422 .47234 Mdot
.36511 .5067 Mdot
.56023 .62788 Mdot
.58502 .24694 Mdot
.56647 .5371 Mdot
.57824 .56763 Mdot
.47879 .38417 Mdot
.66815 .40546 Mdot
.50056 .32255 Mdot
.56334 .64357 Mdot
.20045 .48299 Mdot
.46539 .347 Mdot
.489 .22328 Mdot
.35693 .63554 Mdot
.44541 .44307 Mdot
.60849 .61256 Mdot
.50419 .33588 Mdot
.58915 .62427 Mdot
.67482 .42347 Mdot
.4847 .44178 Mdot
.4201 .26766 Mdot
.49985 .36533 Mdot
.52368 .19451 Mdot
.41801 .58864 Mdot
.58025 .52011 Mdot
.46972 .33332 Mdot
.43771 .6573 Mdot
.39054 .48718 Mdot
.3642 .65323 Mdot
.38133 .60044 Mdot
.34928 .6435 Mdot
.57164 .53904 Mdot
.54043 .55062 Mdot
.35944 .60388 Mdot
.46349 .3286 Mdot
.40253 .61848 Mdot
.57203 .40888 Mdot
.49974 .1882 Mdot
.37417 .64462 Mdot
.5838 .59602 Mdot
.5224 .58525 Mdot
.479 .75057 Mdot
.40654 .3841 Mdot
.30813 .24815 Mdot
.66731 .28905 Mdot
.621 .59003 Mdot
.6528 .36723 Mdot
.64642 .44302 Mdot
.45484 .82299 Mdot
.39805 .73537 Mdot
.32075 .71381 Mdot
.60597 .3919 Mdot
.3678 .29827 Mdot
.65987 .40561 Mdot
.59341 .65095 Mdot
.55797 .58668 Mdot
.61552 .37808 Mdot
.26288 .64642 Mdot
.39211 .3071 Mdot
.60071 .19603 Mdot
.6327 .43884 Mdot
.47857 .32826 Mdot
.49163 .38733 Mdot
.49753 .37497 Mdot
.42584 .79628 Mdot
.65975 .38806 Mdot
.58291 .62685 Mdot
.36793 .45622 Mdot
.61006 .55827 Mdot
.48659 .36369 Mdot
.52362 .17184 Mdot
.63221 .38878 Mdot
.58542 .57411 Mdot
.6181 .72314 Mdot
.35985 .48934 Mdot
.36145 .64071 Mdot
.55964 .70241 Mdot
.33104 .71451 Mdot
.48307 .37938 Mdot
.63772 .37216 Mdot
.3247 .34913 Mdot
.47922 .213 Mdot
.58312 .5445 Mdot
.5965 .67465 Mdot
.71471 .24705 Mdot
.32581 .69653 Mdot
.64187 .63823 Mdot
.37956 .49917 Mdot
.34924 .31938 Mdot
.56814 .62252 Mdot
.65199 .44016 Mdot
.39402 .60741 Mdot
.35175 .63171 Mdot
.54889 .64505 Mdot
.44545 .56029 Mdot
.45458 .4204 Mdot
.61377 .63982 Mdot
.56347 .67473 Mdot
.32053 .46321 Mdot
.27522 .39464 Mdot
.31566 .72446 Mdot
.39293 .62616 Mdot
.62577 .64998 Mdot
.35551 .26251 Mdot
.61843 .38154 Mdot
.35571 .4338 Mdot
.50852 .37143 Mdot
.50162 .64174 Mdot
.31757 .46406 Mdot
.56897 .62544 Mdot
.61962 .64923 Mdot
.51291 .3443 Mdot
.6555 .44947 Mdot
.36656 .61476 Mdot
.36853 .4536 Mdot
.39362 .61979 Mdot
.66361 .39477 Mdot
.63792 .39405 Mdot
.65177 .7002 Mdot
.65389 .58418 Mdot
.34252 .46221 Mdot
.5473 .62313 Mdot
.29841 .41892 Mdot
.82755 .39485 Mdot
.45177 .38529 Mdot
.63107 .65483 Mdot
.65701 .45372 Mdot
.49581 .36891 Mdot
.55771 .59195 Mdot
.69101 .23261 Mdot
.55722 .58445 Mdot
.54739 .38513 Mdot
.19034 .54407 Mdot
.38724 .61321 Mdot
.73638 .39248 Mdot
.61346 .23715 Mdot
.61998 .57986 Mdot
.3829 .46942 Mdot
.61006 .68425 Mdot
.46929 .35452 Mdot
.64732 .39235 Mdot
.85612 .44234 Mdot
.4975 .34651 Mdot
.60185 .56811 Mdot
.38215 .62043 Mdot
.6548 .3808 Mdot
.41883 .64518 Mdot
.3047 .6703 Mdot
.55833 .53517 Mdot
.54076 .61278 Mdot
.62274 .63392 Mdot
.20604 .43191 Mdot
.36398 .50444 Mdot
.63706 .42944 Mdot
.48489 .37379 Mdot
.4812 .35702 Mdot
.33199 .47462 Mdot
.48695 .25566 Mdot
.44692 .44166 Mdot
.24908 .75573 Mdot
.33903 .45651 Mdot
.34656 .64552 Mdot
.60242 .26046 Mdot
.38302 .46451 Mdot
.36293 .47663 Mdot
.323 .45921 Mdot
.44884 .31744 Mdot
.64924 .4243 Mdot
.56326 .62146 Mdot
.65464 .44299 Mdot
.62787 .61263 Mdot
.54744 .39851 Mdot
.50249 .3651 Mdot
.64057 .38653 Mdot
.70216 .24696 Mdot
.75533 .62725 Mdot
.59246 .59615 Mdot
.73009 .29647 Mdot
.64851 .58426 Mdot
.44135 .72147 Mdot
.65929 .62048 Mdot
.34316 .47848 Mdot
.6065 .51349 Mdot
.53986 .58104 Mdot
.4094 .81502 Mdot
.48245 .33954 Mdot
.39262 .47121 Mdot
.64843 .59564 Mdot
.53642 .6522 Mdot
.60446 .38435 Mdot
.62317 .43683 Mdot
.36987 .60049 Mdot
.54266 .77802 Mdot
.47785 .34625 Mdot
.80551 .60216 Mdot
.61694 .58439 Mdot
.22578 .58959 Mdot
.72328 .42448 Mdot
.55977 .5893 Mdot
.63204 .24298 Mdot
.71786 .52736 Mdot
.60974 .61777 Mdot
.50352 .5173 Mdot
.50206 .33853 Mdot
.19743 .49644 Mdot
.55086 .58697 Mdot
.3638 .49148 Mdot
.65717 .39639 Mdot
.67778 .41394 Mdot
.36186 .60363 Mdot
.64935 .78292 Mdot
.50505 .32698 Mdot
.64416 .38857 Mdot
.60788 .60243 Mdot
.47545 .37606 Mdot
.35513 .44685 Mdot
.5894 .6539 Mdot
.40552 .74242 Mdot
.63953 .40247 Mdot
.54408 .60297 Mdot
.5918 .28122 Mdot
.50965 .73866 Mdot
.17063 .42633 Mdot
.48394 .37522 Mdot
.39695 .63866 Mdot
.61147 .68285 Mdot
.7034 .70645 Mdot
.60488 .5392 Mdot
.47955 .65495 Mdot
.56955 .3898 Mdot
.39891 .63543 Mdot
.5893 .58736 Mdot
.57282 .62004 Mdot
.39434 .54993 Mdot
.393 .63227 Mdot
.59733 .56163 Mdot
.51148 .6116 Mdot
.64655 .42701 Mdot
.31308 .48458 Mdot
.64503 .40927 Mdot
.58742 .60048 Mdot
.66137 .60653 Mdot
.60718 .40712 Mdot
.79318 .33551 Mdot
.34603 .61286 Mdot
.46041 .35362 Mdot
.62037 .54405 Mdot
.59689 .55012 Mdot
.19228 .62719 Mdot
.38005 .44382 Mdot
.29996 .32352 Mdot
.24536 .54917 Mdot
.32295 .2773 Mdot
.21707 .50073 Mdot
.21557 .31672 Mdot
.29925 .69038 Mdot
.59546 .66377 Mdot
.69777 .37544 Mdot
.56025 .47894 Mdot
.50769 .36943 Mdot
.80938 .49921 Mdot
.62159 .58915 Mdot
.60692 .59141 Mdot
.35344 .43251 Mdot
.47624 .23835 Mdot
.31805 .71423 Mdot
.44385 .58592 Mdot
.36525 .61664 Mdot
.65856 .43425 Mdot
.55311 .61244 Mdot
.50999 .49753 Mdot
.36849 .44277 Mdot
.22984 .59937 Mdot
.58464 .57707 Mdot
.59806 .80641 Mdot
.60335 .32579 Mdot
.47282 .372 Mdot
.37662 .45941 Mdot
.32565 .70689 Mdot
.63464 .60472 Mdot
.50835 .37327 Mdot
.59419 .61191 Mdot
.30439 .5111 Mdot
.55601 .63529 Mdot
.37306 .64814 Mdot
.59879 .64898 Mdot
.43906 .61299 Mdot
.14676 .40695 Mdot
.38601 .66862 Mdot
.6765 .40094 Mdot
.30922 .43273 Mdot
.33499 .46681 Mdot
.61654 .43183 Mdot
.33784 .4664 Mdot
.70501 .48529 Mdot
.77376 .49007 Mdot
.35795 .62561 Mdot
.53702 .64864 Mdot
.37633 .64123 Mdot
.37022 .43595 Mdot
.62827 .59903 Mdot
.82421 .36385 Mdot
.349 .45755 Mdot
.19877 .59441 Mdot
.49141 .34444 Mdot
.38926 .4563 Mdot
.55272 .58657 Mdot
.32806 .35309 Mdot
.36573 .44429 Mdot
.42538 .26799 Mdot
.57693 .60886 Mdot
.64244 .39735 Mdot
.57226 .6243 Mdot
.63243 .55983 Mdot
.37037 .51057 Mdot
.63387 .62309 Mdot
.46893 .33862 Mdot
.6011 .41336 Mdot
.403 .1816 Mdot
.63796 .33374 Mdot
.61145 .56543 Mdot
.60552 .60119 Mdot
.59898 .3806 Mdot
.59749 .5545 Mdot
.452 .36029 Mdot
.56375 .89516 Mdot
.357 .63634 Mdot
.37919 .5046 Mdot
.21566 .4987 Mdot
.62152 .55599 Mdot
.6234 .64285 Mdot
.66967 .21689 Mdot
.20644 .51156 Mdot
.46927 .33508 Mdot
.54481 .57011 Mdot
.36031 .4451 Mdot
.38109 .62276 Mdot
.4594 .33073 Mdot
.61336 .63181 Mdot
.59595 .58441 Mdot
.3941 .64217 Mdot
.65463 .52206 Mdot
.39409 .77914 Mdot
.51433 .34978 Mdot
.61532 .52361 Mdot
.33437 .41287 Mdot
.63692 .59825 Mdot
.44771 .80616 Mdot
.61951 .4316 Mdot
.48014 .38105 Mdot
.25682 .35025 Mdot
.64115 .63365 Mdot
.48904 .3226 Mdot
.47811 .34461 Mdot
.54814 .56697 Mdot
.65223 .4578 Mdot
.59706 .41874 Mdot
.64087 .43852 Mdot
.55915 .85601 Mdot
.49458 .7141 Mdot
.35878 .49995 Mdot
.50287 .339 Mdot
.33423 .50202 Mdot
.3545 .66514 Mdot
.54682 .44404 Mdot
.35345 .50675 Mdot
.62766 .44474 Mdot
.30977 .43518 Mdot
.57235 .61528 Mdot
.47905 .34914 Mdot
.37853 .49506 Mdot
.63595 .5713 Mdot
.56046 .23656 Mdot
.41355 .34612 Mdot
.40332 .63226 Mdot
.38974 .60366 Mdot
.55206 .59634 Mdot
.32192 .43667 Mdot
.59954 .57848 Mdot
.4573 .3804 Mdot
.58313 .25012 Mdot
.60891 .54066 Mdot
.34012 .47248 Mdot
.63105 .36293 Mdot
.32971 .7112 Mdot
.58342 .52418 Mdot
.58444 .5951 Mdot
.63139 .61553 Mdot
.59438 .6125 Mdot
.43765 .23512 Mdot
.44196 .36917 Mdot
.68955 .3337 Mdot
.22321 .42915 Mdot
.62519 .39314 Mdot
.61599 .44864 Mdot
.35241 .73572 Mdot
.49446 .28972 Mdot
.48972 .33432 Mdot
.62116 .62053 Mdot
.54629 .318 Mdot
.51475 .16913 Mdot
.7625 .2818 Mdot
.35207 .5827 Mdot
.37844 .44512 Mdot
.62986 .37143 Mdot
.3762 .45255 Mdot
.62648 .60573 Mdot
.61934 .68001 Mdot
.20681 .32123 Mdot
.48927 .31128 Mdot
.35693 .62452 Mdot
.62873 .6161 Mdot
.50144 .71649 Mdot
.36898 .46318 Mdot
.39084 .50238 Mdot
.58704 .56137 Mdot
.64308 .45481 Mdot
.1574 .52392 Mdot
.47823 .37469 Mdot
.66047 .2837 Mdot
.5731 .50505 Mdot
.65921 .30607 Mdot
.48498 .36748 Mdot
.30791 .65175 Mdot
.3452 .43013 Mdot
.67718 .48761 Mdot
.62405 .39167 Mdot
.35357 .64687 Mdot
.59511 .67787 Mdot
.61342 .38959 Mdot
.31874 .45893 Mdot
.64474 .39398 Mdot
.60843 .65242 Mdot
.45367 .33116 Mdot
.37682 .46986 Mdot
.51452 .32182 Mdot
.6441 .4589 Mdot
.39117 .62466 Mdot
.43546 .52939 Mdot
.79421 .55418 Mdot
.71536 .52334 Mdot
.60745 .55547 Mdot
.51947 .49035 Mdot
.58674 .62896 Mdot
.59965 .43332 Mdot
.60085 .60855 Mdot
.57605 .40493 Mdot
.38133 .46709 Mdot
.55683 .57908 Mdot
.61722 .63732 Mdot
.80691 .46256 Mdot
.57778 .58112 Mdot
.57955 .65479 Mdot
.61281 .62018 Mdot
.61276 .4701 Mdot
.53277 .63621 Mdot
.65452 .42069 Mdot
.29117 .63102 Mdot
.36112 .47881 Mdot
.39285 .608 Mdot
.36185 .65963 Mdot
.48317 .66893 Mdot
.27279 .49876 Mdot
.47388 .24561 Mdot
.64233 .41345 Mdot
.47184 .34077 Mdot
.59944 .61169 Mdot
.22339 .34507 Mdot
.3115 .40251 Mdot
.3499 .44199 Mdot
.63797 .33341 Mdot
.63508 .53527 Mdot
.19118 .45176 Mdot
.54389 .61067 Mdot
.59131 .83139 Mdot
.65214 .57693 Mdot
.56032 .6387 Mdot
.35075 .50861 Mdot
.34091 .66221 Mdot
.58429 .55912 Mdot
.60617 .3829 Mdot
.37285 .6515 Mdot
.69951 .39677 Mdot
.41877 .45454 Mdot
.29924 .62364 Mdot
.79194 .4621 Mdot
.58974 .62065 Mdot
.37705 .472 Mdot
.66282 .41713 Mdot
.31352 .72148 Mdot
.46316 .36612 Mdot
.53429 .34498 Mdot
.52494 .51553 Mdot
.75064 .30104 Mdot
.36566 .65663 Mdot
.67183 .54148 Mdot
.56204 .60254 Mdot
.34593 .5681 Mdot
.5907 .54591 Mdot
.51946 .17251 Mdot
.34822 .65395 Mdot
.61111 .43909 Mdot
.47915 .32916 Mdot
.6499 .44347 Mdot
.71627 .53981 Mdot
.36445 .53537 Mdot
.48163 .4788 Mdot
.36207 .46759 Mdot
.43222 .44875 Mdot
.63079 .42533 Mdot
.62924 .64693 Mdot
.2447 .75332 Mdot
.62433 .43479 Mdot
.64239 .37724 Mdot
.83678 .45895 Mdot
.82773 .38511 Mdot
.61772 .518 Mdot
.60475 .40262 Mdot
.35913 .47152 Mdot
.38606 .63069 Mdot
.58269 .63404 Mdot
.5807 .61641 Mdot
.61222 .39245 Mdot
.37794 .50798 Mdot
.72007 .64381 Mdot
.34424 .48343 Mdot
.64902 .42877 Mdot
.36338 .48452 Mdot
.30968 .36356 Mdot
.38872 .48313 Mdot
.59672 .55065 Mdot
.60056 .60948 Mdot
.2492 .48429 Mdot
.6383 .39451 Mdot
.6116 .64094 Mdot
.56952 .63429 Mdot
.62427 .41376 Mdot
.34293 .68076 Mdot
.72013 .62711 Mdot
.62608 .58105 Mdot
.57288 .59797 Mdot
.39865 .63432 Mdot
.55261 .45474 Mdot
.62529 .75936 Mdot
.61755 .64709 Mdot
.34094 .64368 Mdot
.60228 .39119 Mdot
.59333 .57462 Mdot
.45413 .19071 Mdot
.35116 .31717 Mdot
.63839 .64075 Mdot
.39156 .48397 Mdot
.53944 .58545 Mdot
.16957 .44692 Mdot
.57833 .56699 Mdot
.63059 .41605 Mdot
.65882 .39256 Mdot
.80827 .59331 Mdot
.61783 .42264 Mdot
.33925 .45001 Mdot
.48846 .36039 Mdot
.5258 .1827 Mdot
.35613 .44695 Mdot
.60384 .53405 Mdot
.81428 .60855 Mdot
.60069 .6601 Mdot
.62127 .55202 Mdot
.17103 .52524 Mdot
.36005 .44941 Mdot
.67308 .41162 Mdot
.42257 .55738 Mdot
.66034 .6463 Mdot
.48492 .37985 Mdot
.57484 .67561 Mdot
.63674 .58754 Mdot
.19092 .55251 Mdot
.38955 .2683 Mdot
.47986 .38736 Mdot
.60523 .66936 Mdot
.61859 .64658 Mdot
.38085 .52283 Mdot
.60672 .60671 Mdot
.38605 .63594 Mdot
.66612 .39578 Mdot
.38578 .46759 Mdot
.36469 .63233 Mdot
.62179 .58528 Mdot
.3732 .61226 Mdot
.37253 .49524 Mdot
.49655 .38099 Mdot
.63035 .60598 Mdot
.38758 .65431 Mdot
.36972 .61437 Mdot
.59162 .63342 Mdot
.6498 .39381 Mdot
.64992 .57056 Mdot
.5843 .57201 Mdot
.58608 .64085 Mdot
.61799 .38942 Mdot
.68198 .18268 Mdot
.56628 .57491 Mdot
.40466 .57535 Mdot
.64261 .37921 Mdot
.42278 .4876 Mdot
.38595 .46154 Mdot
.63204 .57976 Mdot
.48865 .38429 Mdot
.50917 .34374 Mdot
.32025 .46739 Mdot
.65159 .37741 Mdot
.24196 .53316 Mdot
.61229 .36618 Mdot
.66042 .63851 Mdot
.63464 .65619 Mdot
.76264 .67478 Mdot
.28723 .25809 Mdot
.66859 .42885 Mdot
.4113 .46772 Mdot
.44734 .57652 Mdot
.49612 .33067 Mdot
.3958 .46981 Mdot
.63395 .37101 Mdot
.65686 .3843 Mdot
.65065 .40135 Mdot
.35146 .63783 Mdot
.25169 .48472 Mdot
.66682 .44107 Mdot
.63134 .45356 Mdot
.57491 .61057 Mdot
.6194 .64508 Mdot
.35586 .70867 Mdot
.44375 .76499 Mdot
.38803 .60965 Mdot
.33369 .4818 Mdot
.48674 .8809 Mdot
.45584 .37808 Mdot
.80318 .43791 Mdot
.61285 .5441 Mdot
.23943 .77677 Mdot
.54861 .59539 Mdot
.60979 .60503 Mdot
.60114 .41045 Mdot
.39829 .6454 Mdot
.36819 .64411 Mdot
.63539 .43179 Mdot
.60308 .43963 Mdot
.38537 .63705 Mdot
.67856 .27206 Mdot
.47959 .17792 Mdot
.35212 .53708 Mdot
.62479 .40592 Mdot
.79214 .53829 Mdot
.5152 .36293 Mdot
.67825 .36898 Mdot
.44698 .36664 Mdot
.36816 .47 Mdot
.32271 .43805 Mdot
.49083 .37509 Mdot
.57886 .60891 Mdot
.35806 .50222 Mdot
.60291 .66437 Mdot
.70117 .31349 Mdot
.73776 .5861 Mdot
.22993 .49068 Mdot
.5373 .62004 Mdot
.30129 .64266 Mdot
.44892 .28333 Mdot
.60833 .57309 Mdot
.36659 .24136 Mdot
.36044 .61915 Mdot
.68833 .39985 Mdot
.46537 .38039 Mdot
.15778 .45111 Mdot
.63549 .61308 Mdot
.63164 .41229 Mdot
.48118 .33764 Mdot
.49145 .6342 Mdot
.60522 .26876 Mdot
.62971 .61412 Mdot
.27376 .78632 Mdot
.62762 .47389 Mdot
.38612 .4721 Mdot
.68757 .73335 Mdot
.66472 .43668 Mdot
.35054 .5872 Mdot
.23837 .416 Mdot
.72097 .26806 Mdot
.66875 .41951 Mdot
.39585 .46293 Mdot
.64875 .43706 Mdot
.3914 .62718 Mdot
.66377 .37523 Mdot
.37317 .46108 Mdot
.58338 .5822 Mdot
.33576 .47545 Mdot
.37256 .60183 Mdot
.40419 .77902 Mdot
.48308 .38694 Mdot
.39258 .47245 Mdot
.50206 .35841 Mdot
.52303 .7551 Mdot
.20775 .44482 Mdot
.45786 .36208 Mdot
.67316 .71399 Mdot
.64449 .62757 Mdot
.6584 .44557 Mdot
.3284 .46852 Mdot
.25792 .4023 Mdot
.43424 .54388 Mdot
.61789 .3978 Mdot
.34969 .49429 Mdot
.53494 .5019 Mdot
.67858 .72015 Mdot
.5384 .56845 Mdot
.52787 .76896 Mdot
.62225 .40889 Mdot
.38993 .44962 Mdot
.32699 .74438 Mdot
.6328 .44652 Mdot
.33635 .45778 Mdot
.48257 .32621 Mdot
.48099 .36128 Mdot
.59582 .55912 Mdot
.51258 .31619 Mdot
.33856 .4923 Mdot
.43575 .29748 Mdot
.61216 .38367 Mdot
.4837 .61185 Mdot
.36293 .66277 Mdot
.35343 .48083 Mdot
.60072 .65487 Mdot
.68544 .42 Mdot
.32098 .34283 Mdot
.73075 .64763 Mdot
.3945 .82838 Mdot
.33238 .47499 Mdot
.65522 .38496 Mdot
.63282 .40866 Mdot
.58653 .52492 Mdot
.45755 .54912 Mdot
.24278 .526 Mdot
.55057 .70894 Mdot
.48002 .6442 Mdot
.31396 .48243 Mdot
.32867 .50846 Mdot
.6508 .60356 Mdot
.59551 .62176 Mdot
.49126 .32858 Mdot
.5812 .58644 Mdot
.60398 .42236 Mdot
.59544 .55706 Mdot
.48774 .37084 Mdot
.35879 .46325 Mdot
.62638 .59918 Mdot
.38844 .61304 Mdot
.50371 .38242 Mdot
.48464 .31882 Mdot
.34693 .4771 Mdot
.61525 .38788 Mdot
.37346 .67937 Mdot
.34335 .48461 Mdot
.58937 .61985 Mdot
.54757 .35915 Mdot
.58827 .64622 Mdot
.71776 .37114 Mdot
.63145 .44713 Mdot
.38 .45822 Mdot
.60942 .38402 Mdot
.50362 .35043 Mdot
.22728 .42427 Mdot
.59235 .60286 Mdot
.34115 .45464 Mdot
.27104 .44245 Mdot
.70726 .42212 Mdot
.58751 .39986 Mdot
.45208 .27219 Mdot
.60802 .44335 Mdot
.32089 .44886 Mdot
.82868 .5009 Mdot
.36104 .65418 Mdot
.35248 .44156 Mdot
.36023 .21169 Mdot
.34476 .46413 Mdot
.57202 .58198 Mdot
.55287 .59921 Mdot
.3874 .47269 Mdot
.39121 .64711 Mdot
.30167 .70341 Mdot
.30467 .46736 Mdot
.67203 .41298 Mdot
.74377 .32661 Mdot
.3121 .77257 Mdot
.50816 .30819 Mdot
.48301 .3302 Mdot
.66506 .63989 Mdot
.56798 .64362 Mdot
.44795 .3568 Mdot
.49381 .31628 Mdot
.35373 .61831 Mdot
.32541 .45605 Mdot
.60779 .47045 Mdot
.52002 .34407 Mdot
.62508 .70196 Mdot
.27394 .50562 Mdot
.56387 .53711 Mdot
.57163 .49881 Mdot
.58706 .54914 Mdot
.49002 .66272 Mdot
.48662 .37272 Mdot
.55341 .61822 Mdot
.54816 .55909 Mdot
.4845 .3836 Mdot
.38747 .63362 Mdot
.49117 .27137 Mdot
.37133 .48348 Mdot
.53326 .14957 Mdot
.55927 .63236 Mdot
.57108 .58021 Mdot
.50807 .36665 Mdot
.2574 .57866 Mdot
.63338 .38711 Mdot
.6373 .44839 Mdot
.36773 .50367 Mdot
.44386 .52262 Mdot
.62829 .57661 Mdot
.59714 .56977 Mdot
.37805 .48135 Mdot
.39097 .46079 Mdot
.40521 .33894 Mdot
.56275 .61261 Mdot
.48626 .3382 Mdot
.43847 .62165 Mdot
.4881 .3725 Mdot
.59375 .65066 Mdot
.56664 .58601 Mdot
.59695 .55098 Mdot
.60252 .65477 Mdot
.4743 .32008 Mdot
.55463 .61642 Mdot
.52289 .59685 Mdot
.63452 .38442 Mdot
.62921 .62494 Mdot
.48812 .65465 Mdot
.57965 .59516 Mdot
.38584 .63234 Mdot
.67286 .69947 Mdot
.63473 .61166 Mdot
.62519 .57015 Mdot
.29876 .46532 Mdot
.59341 .59037 Mdot
.45556 .37863 Mdot
.63085 .39637 Mdot
.5041 .34068 Mdot
.51291 .3543 Mdot
.32219 .47797 Mdot
.35924 .60439 Mdot
.62389 .55968 Mdot
.35561 .61967 Mdot
.59221 .53889 Mdot
.64056 .63804 Mdot
.23894 .4366 Mdot
.60415 .82587 Mdot
.4101 .79187 Mdot
.59144 .60403 Mdot
.35429 .45216 Mdot
.38404 .45954 Mdot
.69408 .43191 Mdot
.54439 .55891 Mdot
.45136 .34773 Mdot
.50596 .33875 Mdot
.41385 .74321 Mdot
.19449 .5306 Mdot
.38631 .63276 Mdot
.52674 .47226 Mdot
.61574 .66567 Mdot
.57166 .63384 Mdot
.58741 .65405 Mdot
.33685 .50242 Mdot
.43909 .59352 Mdot
.35333 .44248 Mdot
.62114 .32418 Mdot
.49746 .37049 Mdot
.63483 .61656 Mdot
.57105 .42078 Mdot
.62504 .43948 Mdot
.63162 .39638 Mdot
.4787 .32183 Mdot
.29411 .44278 Mdot
.35809 .72634 Mdot
.79255 .30761 Mdot
.62979 .47803 Mdot
.40485 .63219 Mdot
.61128 .57181 Mdot
.3537 .46653 Mdot
.64235 .44016 Mdot
.40158 .61783 Mdot
.62984 .64889 Mdot
.25168 .48348 Mdot
.58872 .60769 Mdot
.56461 .47769 Mdot
.65854 .40195 Mdot
.50796 .17633 Mdot
.67076 .39262 Mdot
.50091 .38468 Mdot
.46576 .37857 Mdot
.55723 .59402 Mdot
.72808 .70666 Mdot
.65087 .44646 Mdot
.4424 .31708 Mdot
.34724 .64706 Mdot
.33816 .33715 Mdot
.39071 .63284 Mdot
.38387 .46866 Mdot
.37106 .65344 Mdot
.37634 .46231 Mdot
.41129 .76124 Mdot
.58165 .41976 Mdot
.36022 .6322 Mdot
.30394 .51499 Mdot
.54549 .55444 Mdot
.39626 .61533 Mdot
.6531 .65632 Mdot
.72849 .38623 Mdot
.37532 .48587 Mdot
.35803 .65723 Mdot
.62745 .64766 Mdot
.20604 .34621 Mdot
.46546 .34028 Mdot
.45007 .3528 Mdot
.65872 .64088 Mdot
.31912 .48186 Mdot
.61152 .37814 Mdot
.45898 .21327 Mdot
.47614 .39533 Mdot
.55989 .58484 Mdot
.58679 .55844 Mdot
.62093 .45093 Mdot
.59023 .35953 Mdot
.56068 .59264 Mdot
.63782 .7119 Mdot
.5591 .60902 Mdot
.47518 .32596 Mdot
.6525 .44143 Mdot
.63214 .40328 Mdot
.35236 .49659 Mdot
.60705 .41857 Mdot
.66334 .47289 Mdot
.55722 .34769 Mdot
.67162 .61853 Mdot
.49883 .34884 Mdot
.58843 .33478 Mdot
.62472 .32495 Mdot
.30694 .25098 Mdot
.62809 .45629 Mdot
.57712 .55552 Mdot
.61855 .38108 Mdot
.38336 .62387 Mdot
.64133 .39926 Mdot
.62729 .37197 Mdot
.60252 .57651 Mdot
.62587 .60956 Mdot
.36304 .4561 Mdot
.45185 .55677 Mdot
.6234 .38279 Mdot
.55022 .60382 Mdot
.57168 .65043 Mdot
.5901 .65921 Mdot
.48859 .42473 Mdot
.66405 .43313 Mdot
.80554 .3987 Mdot
.43637 .6743 Mdot
.62193 .38331 Mdot
.14939 .49716 Mdot
.27336 .39387 Mdot
.36018 .42976 Mdot
.52595 .35432 Mdot
.56296 .6144 Mdot
.38239 .45235 Mdot
.62669 .60538 Mdot
.5704 .4991 Mdot
.59983 .58693 Mdot
.38555 .63962 Mdot
.59345 .66308 Mdot
.31843 .45018 Mdot
.33942 .48114 Mdot
.57081 .57236 Mdot
.62203 .59501 Mdot
.38793 .76837 Mdot
.61476 .45371 Mdot
.63812 .39021 Mdot
.24203 .55268 Mdot
.36794 .62106 Mdot
.48257 .38036 Mdot
.60769 .61411 Mdot
.32497 .48621 Mdot
.33672 .47888 Mdot
.66196 .43821 Mdot
.35808 .49254 Mdot
.47916 .37405 Mdot
.59573 .60299 Mdot
.44833 .35731 Mdot
.35109 .63581 Mdot
.6595 .43461 Mdot
.62971 .61945 Mdot
.57472 .6102 Mdot
.65927 .39297 Mdot
.64217 .58664 Mdot
.39795 .63506 Mdot
.34208 .46482 Mdot
.66562 .42192 Mdot
.48657 .36065 Mdot
.38101 .46418 Mdot
.57794 .63367 Mdot
.45231 .86629 Mdot
.57156 .58603 Mdot
.56648 .6196 Mdot
.35379 .20902 Mdot
.60401 .66632 Mdot
.3293 .47155 Mdot
.61687 .44329 Mdot
.54345 .6314 Mdot
.47797 .67479 Mdot
.73492 .23519 Mdot
.34682 .44318 Mdot
.60893 .56854 Mdot
.2349 .30852 Mdot
.59717 .56622 Mdot
.7698 .64805 Mdot
.34249 .54694 Mdot
.43566 .48237 Mdot
.64138 .56471 Mdot
.47132 .36291 Mdot
.36195 .45436 Mdot
.38206 .47061 Mdot
.77061 .36601 Mdot
.60052 .57377 Mdot
.5484 .48027 Mdot
.63344 .63538 Mdot
.4828 .36578 Mdot
.40237 .7251 Mdot
.33362 .47762 Mdot
.43821 .82365 Mdot
.58343 .62612 Mdot
.67661 .4154 Mdot
.31239 .43246 Mdot
.31369 .37836 Mdot
.58566 .63962 Mdot
.36144 .61254 Mdot
.52089 .35864 Mdot
.5597 .64849 Mdot
.49534 .3516 Mdot
.5884 .64371 Mdot
.65546 .6978 Mdot
.6836 .7472 Mdot
.65066 .39719 Mdot
.48195 .32794 Mdot
.54281 .34785 Mdot
.54567 .58486 Mdot
.66784 .41974 Mdot
.62262 .39243 Mdot
.35719 .6131 Mdot
.49689 .46599 Mdot
.57397 .2767 Mdot
.75907 .59892 Mdot
.76702 .34987 Mdot
.30483 .43547 Mdot
.404 .28736 Mdot
.59478 .64175 Mdot
.22434 .5749 Mdot
.46932 .38509 Mdot
.57617 .57862 Mdot
.70348 .45517 Mdot
.63507 .43656 Mdot
.56878 .59851 Mdot
.37862 .64013 Mdot
.24094 .59657 Mdot
.23556 .60364 Mdot
.23614 .38913 Mdot
.36362 .46846 Mdot
.61483 .68157 Mdot
.67825 .62838 Mdot
.3761 .50417 Mdot
.64479 .6025 Mdot
.33507 .46252 Mdot
.70663 .28567 Mdot
.40264 .62517 Mdot
.67106 .42377 Mdot
.28902 .39007 Mdot
.62943 .57199 Mdot
.6336 .65845 Mdot
.38849 .59988 Mdot
.59884 .62631 Mdot
.64063 .78657 Mdot
.28674 .41433 Mdot
.37428 .49889 Mdot
.65059 .40027 Mdot
.61882 .55985 Mdot
.5109 .46507 Mdot
.58728 .57049 Mdot
.7654 .52506 Mdot
.62242 .56605 Mdot
.58798 .27132 Mdot
.65609 .39565 Mdot
.49814 .35376 Mdot
.54722 .5772 Mdot
.60427 .59263 Mdot
.43629 .64352 Mdot
.65503 .58422 Mdot
.54727 .60623 Mdot
.60101 .38302 Mdot
.63922 .44258 Mdot
.65326 .42077 Mdot
.3432 .43497 Mdot
.19269 .54226 Mdot
.49581 .33923 Mdot
.53205 .62223 Mdot
.51729 .33369 Mdot
.71866 .67956 Mdot
.40436 .62725 Mdot
.24391 .3275 Mdot
.6176 .62888 Mdot
.64569 .41963 Mdot
.36385 .26432 Mdot
.59789 .3974 Mdot
.50308 .49413 Mdot
.47796 .34674 Mdot
.63003 .43454 Mdot
.60865 .59969 Mdot
.43919 .56208 Mdot
.20937 .37799 Mdot
.50792 .35164 Mdot
.59519 .53601 Mdot
.37485 .44116 Mdot
.22395 .47501 Mdot
.43211 .85712 Mdot
.46688 .33722 Mdot
.54306 .35752 Mdot
.60193 .57249 Mdot
.62325 .44055 Mdot
.47302 .36729 Mdot
.45889 .35086 Mdot
.35931 .49363 Mdot
.62572 .61256 Mdot
.62506 .61686 Mdot
.32839 .43833 Mdot
.50975 .34862 Mdot
.65483 .5959 Mdot
.55263 .6321 Mdot
.19222 .33238 Mdot
.49309 .55313 Mdot
.57119 .1429 Mdot
.65053 .48056 Mdot
.68555 .48837 Mdot
.48177 .20239 Mdot
.65279 .38204 Mdot
.63559 .6089 Mdot
.56566 .66495 Mdot
.33782 .49129 Mdot
.58692 .5928 Mdot
.40614 .48623 Mdot
.48376 .33328 Mdot
.15713 .47657 Mdot
.57355 .31592 Mdot
.70165 .26712 Mdot
.58745 .59041 Mdot
.64533 .33857 Mdot
.37256 .63087 Mdot
.43871 .36493 Mdot
.65691 .42647 Mdot
.61465 .65371 Mdot
.38854 .77001 Mdot
.35349 .44192 Mdot
.61097 .408 Mdot
.31978 .7221 Mdot
.30443 .64149 Mdot
.59596 .65136 Mdot
.35858 .43694 Mdot
.37837 .24734 Mdot
.58549 .70297 Mdot
.44884 .38656 Mdot
.38737 .63744 Mdot
.36615 .45251 Mdot
.51165 .34617 Mdot
.61384 .48605 Mdot
.62334 .43009 Mdot
.63527 .36678 Mdot
.46999 .80364 Mdot
.38505 .49987 Mdot
.36947 .63429 Mdot
.19867 .5196 Mdot
.22617 .6059 Mdot
.38394 .64073 Mdot
.32581 .4349 Mdot
.64072 .44162 Mdot
.6397 .42823 Mdot
.63016 .39683 Mdot
.40837 .80558 Mdot
.66388 .38683 Mdot
.7877 .41011 Mdot
.60446 .66123 Mdot
.66483 .67555 Mdot
.60474 .56733 Mdot
.44972 .34902 Mdot
.66452 .40534 Mdot
.43451 .52151 Mdot
.56367 .54734 Mdot
.21231 .40826 Mdot
.58337 .56795 Mdot
.44313 .34993 Mdot
.56656 .60585 Mdot
.80035 .46727 Mdot
.62393 .37904 Mdot
.58912 .59988 Mdot
.44914 .37756 Mdot
.37581 .61631 Mdot
.60128 .37081 Mdot
.63111 .61539 Mdot
.48661 .24137 Mdot
.60006 .66553 Mdot
.66613 .25149 Mdot
.48186 .58988 Mdot
.40478 .63226 Mdot
.52241 .54525 Mdot
.39973 .48787 Mdot
.67192 .65726 Mdot
.63458 .68505 Mdot
.50519 .35817 Mdot
.29251 .36768 Mdot
.36063 .47744 Mdot
.36409 .57307 Mdot
.55848 .66797 Mdot
.37876 .60188 Mdot
.60514 .44494 Mdot
.44877 .34483 Mdot
.64792 .62011 Mdot
.56952 .5352 Mdot
.71788 .33019 Mdot
.54343 .65902 Mdot
.59567 .55566 Mdot
.40196 .61112 Mdot
.76091 .37876 Mdot
.57893 .59958 Mdot
.50921 .48628 Mdot
.66183 .37641 Mdot
.65799 .60063 Mdot
.80731 .43696 Mdot
.55213 .59725 Mdot
.61256 .42172 Mdot
.58749 .3905 Mdot
.51097 .27588 Mdot
.34836 .62928 Mdot
.63089 .57856 Mdot
.81015 .58819 Mdot
.58681 .62506 Mdot
.48816 .34005 Mdot
.56984 .64252 Mdot
.37084 .46202 Mdot
.39075 .78935 Mdot
.34992 .49924 Mdot
.62609 .5775 Mdot
.62718 .3995 Mdot
.50149 .37221 Mdot
.47576 .8168 Mdot
.26022 .51363 Mdot
.77777 .40352 Mdot
.69534 .23973 Mdot
.37734 .65345 Mdot
.35975 .60161 Mdot
.44958 .34132 Mdot
.58793 .60062 Mdot
.83604 .48922 Mdot
.65902 .59244 Mdot
.5721 .59968 Mdot
.60119 .58671 Mdot
.20595 .47153 Mdot
.49402 .33134 Mdot
.36413 .48845 Mdot
.56322 .59009 Mdot
.55179 .61338 Mdot
.6497 .38144 Mdot
.37203 .61506 Mdot
.38537 .46061 Mdot
.35683 .63051 Mdot
.35537 .45878 Mdot
.15095 .48571 Mdot
.54039 .58615 Mdot
.3755 .61857 Mdot
.51357 .38006 Mdot
.61404 .39154 Mdot
.55385 .3447 Mdot
.38356 .47041 Mdot
.33463 .48439 Mdot
.57464 .57176 Mdot
.6125 .42366 Mdot
.60324 .39729 Mdot
.38456 .62235 Mdot
.46094 .36836 Mdot
.63331 .60869 Mdot
.64004 .64186 Mdot
.69668 .34891 Mdot
.32299 .48797 Mdot
.55652 .49092 Mdot
.44834 .24672 Mdot
.5894 .60375 Mdot
.60631 .39474 Mdot
.61268 .58706 Mdot
.50556 .2009 Mdot
.61781 .43597 Mdot
.55108 .59375 Mdot
.25228 .66922 Mdot
.29503 .43667 Mdot
.53645 .27976 Mdot
.58738 .55463 Mdot
.59706 .18555 Mdot
.60864 .64473 Mdot
.15799 .37037 Mdot
.31798 .54742 Mdot
.63842 .60146 Mdot
.5761 .62971 Mdot
.73067 .61097 Mdot
.62342 .58349 Mdot
.32064 .44817 Mdot
.33132 .6973 Mdot
.61126 .37661 Mdot
.51562 .23238 Mdot
.69174 .634 Mdot
.34947 .65496 Mdot
.36957 .5032 Mdot
.35128 .52012 Mdot
.37192 .64649 Mdot
.62549 .40875 Mdot
.59463 .61272 Mdot
.45998 .48793 Mdot
.31826 .49156 Mdot
.57008 .52199 Mdot
.48589 .34212 Mdot
.37892 .33974 Mdot
.28752 .44851 Mdot
.49213 .35923 Mdot
.62807 .62928 Mdot
.7263 .62004 Mdot
.51709 .78954 Mdot
.4716 .1705 Mdot
.51397 .35426 Mdot
.50823 .35789 Mdot
.38734 .7957 Mdot
.35809 .66415 Mdot
.72448 .32401 Mdot
.59544 .26856 Mdot
.48995 .37807 Mdot
.52134 .6679 Mdot
.33414 .44784 Mdot
.50068 .24876 Mdot
.68839 .39776 Mdot
.62517 .65842 Mdot
.60707 .59754 Mdot
.46287 .37243 Mdot
.70662 .4182 Mdot
.67657 .7434 Mdot
.50096 .36037 Mdot
.52422 .63759 Mdot
.46744 .43645 Mdot
.26871 .39569 Mdot
.32195 .46693 Mdot
.35033 .6229 Mdot
.38633 .58412 Mdot
.67356 .40561 Mdot
.35401 .61221 Mdot
.23553 .58935 Mdot
.60528 .6264 Mdot
.49425 .36743 Mdot
.32446 .3423 Mdot
.48434 .3576 Mdot
.36919 .64573 Mdot
.40668 .62767 Mdot
.6345 .38458 Mdot
.64015 .39248 Mdot
.68758 .50613 Mdot
.4358 .72779 Mdot
.58959 .56555 Mdot
.2614 .34413 Mdot
.61019 .38469 Mdot
.59073 .50911 Mdot
.3647 .60042 Mdot
.37162 .61753 Mdot
.45093 .6301 Mdot
.61695 .62087 Mdot
.78974 .61862 Mdot
.61331 .6174 Mdot
.41091 .72521 Mdot
.60065 .54427 Mdot
.3586 .49322 Mdot
.62134 .62335 Mdot
.38036 .68221 Mdot
.65021 .61618 Mdot
.55676 .63337 Mdot
.32629 .49554 Mdot
.55524 .64636 Mdot
.37161 .46416 Mdot
.61519 .56488 Mdot
.34993 .65949 Mdot
.33827 .49978 Mdot
.48679 .70168 Mdot
.42808 .59549 Mdot
.33309 .43081 Mdot
.36957 .60357 Mdot
.35423 .65844 Mdot
.51879 .71331 Mdot
.65679 .42728 Mdot
.66691 .36865 Mdot
.5862 .59734 Mdot
.39604 .49788 Mdot
.48964 .32968 Mdot
.55467 .61378 Mdot
.57744 .66265 Mdot
.57341 .56292 Mdot
.67542 .41187 Mdot
.24116 .51778 Mdot
.3807 .61909 Mdot
.3371 .4366 Mdot
.34722 .68245 Mdot
.31651 .47068 Mdot
.53403 .5876 Mdot
.58795 .67614 Mdot
.67122 .51191 Mdot
.3236 .31074 Mdot
.37604 .80035 Mdot
.6203 .42831 Mdot
.3922 .4798 Mdot
.35812 .662 Mdot
.59151 .51583 Mdot
.64733 .42596 Mdot
.37288 .46141 Mdot
.58963 .6079 Mdot
.59288 .53584 Mdot
.60113 .34144 Mdot
.68494 .61476 Mdot
.46946 .6427 Mdot
.3191 .46439 Mdot
.39658 .46711 Mdot
.22566 .59687 Mdot
.3234 .66163 Mdot
.43401 .53699 Mdot
.58984 .5769 Mdot
.35983 .61458 Mdot
.64201 .44017 Mdot
.49493 .79854 Mdot
.45699 .36985 Mdot
.45409 .55353 Mdot
.5884 .59202 Mdot
.4253 .49326 Mdot
.62658 .39803 Mdot
.38138 .63726 Mdot
.46465 .37418 Mdot
.39154 .59512 Mdot
.36413 .50716 Mdot
.76595 .30328 Mdot
.59114 .62575 Mdot
.58188 .56549 Mdot
.49042 .38761 Mdot
.64052 .43685 Mdot
.38459 .59604 Mdot
.70336 .31142 Mdot
.38008 .48961 Mdot
.83779 .50991 Mdot
.6049 .4175 Mdot
.79354 .47907 Mdot
.33389 .43942 Mdot
.48015 .32135 Mdot
.51112 .71826 Mdot
.48623 .37045 Mdot
.62172 .56892 Mdot
.63905 .41028 Mdot
.47265 .33609 Mdot
.45987 .57007 Mdot
.22458 .32501 Mdot
.79504 .5193 Mdot
.60534 .62008 Mdot
.1809 .38617 Mdot
.60869 .22591 Mdot
.61835 .45987 Mdot
.49016 .38447 Mdot
.58099 .57175 Mdot
.64373 .61016 Mdot
.58351 .62248 Mdot
.47165 .34554 Mdot
.2515 .41951 Mdot
.37755 .4855 Mdot
.60335 .56971 Mdot
.35356 .61945 Mdot
.37032 .47124 Mdot
.29138 .38857 Mdot
.33004 .47694 Mdot
.62746 .46007 Mdot
.5708 .64398 Mdot
.45184 .32431 Mdot
.13705 .43621 Mdot
.50595 .34399 Mdot
.32659 .43265 Mdot
.56107 .6296 Mdot
.31908 .33647 Mdot
.6517 .42191 Mdot
.3747 .49463 Mdot
.57196 .57942 Mdot
.28556 .39589 Mdot
.40764 .78418 Mdot
.33067 .47682 Mdot
.64726 .43171 Mdot
.42708 .19912 Mdot
.58309 .58908 Mdot
.6041 .64183 Mdot
.63282 .43046 Mdot
.69743 .66138 Mdot
.326 .7394 Mdot
.61826 .59156 Mdot
.49766 .35564 Mdot
.84641 .4333 Mdot
.54229 .61824 Mdot
.41921 .68886 Mdot
.3644 .45456 Mdot
.49789 .26026 Mdot
.54281 .4987 Mdot
.59626 .51372 Mdot
.6977 .31279 Mdot
.54016 .41286 Mdot
.1841 .43135 Mdot
.40697 .47816 Mdot
.31588 .6066 Mdot
.17259 .44133 Mdot
.44339 .36214 Mdot
.59313 .3664 Mdot
.66118 .27899 Mdot
.49495 .83913 Mdot
.42705 .20692 Mdot
.27357 .60218 Mdot
.38379 .76846 Mdot
.45673 .46418 Mdot
.34941 .45896 Mdot
.41551 .61571 Mdot
.62981 .60963 Mdot
.60513 .22314 Mdot
.79872 .59168 Mdot
.7338 .7127 Mdot
.18275 .37902 Mdot
.76509 .64504 Mdot
.22518 .34181 Mdot
.32175 .2387 Mdot
.6736 .48465 Mdot
.3389 .29438 Mdot
.84163 .52343 Mdot
.24621 .6527 Mdot
.77978 .35205 Mdot
.67216 .63699 Mdot
.51032 .497 Mdot
.67358 .24298 Mdot
.78216 .43518 Mdot
.68351 .72369 Mdot
.35574 .49833 Mdot
.62168 .44742 Mdot
.64658 .27037 Mdot
.59426 .42683 Mdot
.49909 .29797 Mdot
.43669 .18945 Mdot
.2385 .29935 Mdot
.80225 .46315 Mdot
.5577 .16469 Mdot
.71481 .45013 Mdot
.73161 .76769 Mdot
.30794 .47712 Mdot
.6685 .43393 Mdot
.3373 .61084 Mdot
.21967 .59082 Mdot
.63642 .31348 Mdot
.64763 .26046 Mdot
.23453 .45018 Mdot
.48725 .74206 Mdot
.63082 .41094 Mdot
.51298 .55344 Mdot
.45728 .29046 Mdot
.58074 .31905 Mdot
.33079 .69977 Mdot
.35729 .22469 Mdot
.46475 .50096 Mdot
.49782 .23965 Mdot
.389 .31456 Mdot
.43017 .85261 Mdot
.44624 .66255 Mdot
.63808 .49521 Mdot
.55117 .36703 Mdot
.49276 .1983 Mdot
.53828 .83076 Mdot
.44045 .74327 Mdot
.22175 .59591 Mdot
.18754 .58649 Mdot
.56809 .19951 Mdot
.21619 .67512 Mdot
.66349 .37026 Mdot
.5916 .55618 Mdot
.69772 .59497 Mdot
.81558 .5732 Mdot
.40349 .64626 Mdot
.24245 .38949 Mdot
.35264 .65182 Mdot
.66287 .45515 Mdot
.37516 .77532 Mdot
.79632 .42467 Mdot
.81742 .58089 Mdot
.36021 .59624 Mdot
.53728 .61835 Mdot
.88384 .4225 Mdot
.1967 .41457 Mdot
.54163 .29656 Mdot
.18191 .34241 Mdot
.42199 .5247 Mdot
.48979 .62806 Mdot
.4732 .33695 Mdot
.16744 .43055 Mdot
.63913 .42191 Mdot
.17357 .61965 Mdot
.15653 .39372 Mdot
.6392 .74507 Mdot
.60238 .11232 Mdot
.21432 .54586 Mdot
.43264 .49075 Mdot
.53311 .40386 Mdot
.46504 .68798 Mdot
.64094 .77198 Mdot
.63408 .73318 Mdot
.34081 .32131 Mdot
.67702 .22596 Mdot
.17746 .42107 Mdot
.82636 .54065 Mdot
.77205 .31861 Mdot
.51713 .84129 Mdot
.52905 .45678 Mdot
.68914 .38298 Mdot
.31368 .50337 Mdot
.33387 .2539 Mdot
.16424 .53019 Mdot
.4353 .67119 Mdot
.75472 .24932 Mdot
.34845 .67631 Mdot
.30183 .54383 Mdot
.44233 .17497 Mdot
.50203 .73941 Mdot
.50228 .56072 Mdot
.30424 .68944 Mdot
.57175 .5235 Mdot
.28889 .66311 Mdot
.26059 .32858 Mdot
.53915 .32716 Mdot
.25084 .65237 Mdot
.41894 .22668 Mdot
.71352 .32963 Mdot
.74061 .57655 Mdot
.21646 .5968 Mdot
.59688 .39322 Mdot
.46481 .74002 Mdot
.49936 .55759 Mdot
.22938 .30391 Mdot
.54244 .35876 Mdot
.2765 .24932 Mdot
.33368 .73937 Mdot
.56389 .56059 Mdot
.65012 .67144 Mdot
.51745 .61501 Mdot
.44729 .72403 Mdot
.55154 .63426 Mdot
.63457 .32669 Mdot
.28583 .2556 Mdot
.72162 .42557 Mdot
.48242 .27683 Mdot
.28639 .37492 Mdot
.45965 .1679 Mdot
.69222 .54747 Mdot
.31933 .65402 Mdot
.37173 .71589 Mdot
.48359 .8537 Mdot
.36287 .48077 Mdot
.82816 .52057 Mdot
.44595 .38471 Mdot
.43615 .79002 Mdot
.76082 .6035 Mdot
.62271 .76845 Mdot
.28733 .25422 Mdot
.28878 .62939 Mdot
.36116 .75702 Mdot
.53572 .75525 Mdot
.83985 .45959 Mdot
.26948 .37975 Mdot
.57787 .67634 Mdot
.57873 .22702 Mdot
.38978 .6488 Mdot
.70983 .53583 Mdot
.81995 .40801 Mdot
.27171 .56393 Mdot
.64751 .65519 Mdot
.57265 .78613 Mdot
.34184 .40871 Mdot
.44045 .56026 Mdot
.29907 .77519 Mdot
.55129 .54866 Mdot
.19971 .52902 Mdot
.59073 .20607 Mdot
.44794 .69239 Mdot
.48522 .18429 Mdot
.46602 .22101 Mdot
.20062 .6449 Mdot
.17256 .36984 Mdot
.2548 .51658 Mdot
.17311 .45909 Mdot
.21263 .31471 Mdot
.22177 .67059 Mdot
.61685 .69402 Mdot
.48783 .38987 Mdot
.39021 .85883 Mdot
.32128 .45242 Mdot
.19778 .48437 Mdot
.76748 .35092 Mdot
.30044 .39426 Mdot
.60379 .46819 Mdot
.66834 .57575 Mdot
.46226 .47108 Mdot
.62451 .4634 Mdot
.5551 .64285 Mdot
.30936 .7659 Mdot
.20642 .63371 Mdot
.26606 .72865 Mdot
.59436 .19587 Mdot
.1643 .47398 Mdot
.43615 .44226 Mdot
.78832 .43155 Mdot
.69442 .42859 Mdot
.61901 .65645 Mdot
.38505 .56494 Mdot
.21442 .54227 Mdot
.56662 .79031 Mdot
.6244 .3009 Mdot
.60919 .44952 Mdot
.24918 .36392 Mdot
.74743 .78897 Mdot
.70581 .47543 Mdot
.80975 .43012 Mdot
.23235 .60285 Mdot
.43429 .71859 Mdot
.31413 .27445 Mdot
.63096 .75662 Mdot
.34258 .21878 Mdot
.62674 .46761 Mdot
.7704 .34455 Mdot
.28408 .5925 Mdot
.52854 .68914 Mdot
.24014 .50903 Mdot
.24997 .29931 Mdot
.4547 .41288 Mdot
.52487 .80789 Mdot
.6048 .26073 Mdot
.65437 .74458 Mdot
.34384 .55339 Mdot
.38547 .33852 Mdot
.82122 .41569 Mdot
.40777 .26926 Mdot
.41479 .70997 Mdot
.47669 .44528 Mdot
.54844 .52403 Mdot
.53941 .41158 Mdot
.42093 .70413 Mdot
.51104 .68007 Mdot
.17676 .49253 Mdot
.12097 .40415 Mdot
.38487 .81676 Mdot
.53069 .15304 Mdot
.28123 .31083 Mdot
.65055 .64586 Mdot
.40312 .17641 Mdot
.23865 .71008 Mdot
.1479 .39386 Mdot
.39486 .38055 Mdot
.40703 .48822 Mdot
.50965 .321 Mdot
.32573 .76462 Mdot
.25834 .45673 Mdot
.38783 .19584 Mdot
.29484 .68251 Mdot
.51989 .33102 Mdot
.61525 .8212 Mdot
.20189 .60798 Mdot
.77498 .58613 Mdot
.68235 .59957 Mdot
.64151 .57364 Mdot
.80958 .50246 Mdot
.60491 .44078 Mdot
.40864 .28717 Mdot
.44429 .73575 Mdot
.34904 .48134 Mdot
.38677 .56784 Mdot
.63124 .2493 Mdot
.59499 .66357 Mdot
.55757 .4165 Mdot
.63294 .45476 Mdot
.32962 .30568 Mdot
.56649 .33815 Mdot
.1569 .52501 Mdot
.22045 .51017 Mdot
.62125 .54296 Mdot
.44513 .68829 Mdot
.23571 .51231 Mdot
.32522 .74398 Mdot
.46594 .32117 Mdot
.19519 .35982 Mdot
.48831 .51938 Mdot
.46156 .73916 Mdot
.80701 .5413 Mdot
.71978 .37631 Mdot
.60243 .67322 Mdot
.41714 .24944 Mdot
.75709 .51201 Mdot
.44896 .56203 Mdot
.69105 .40686 Mdot
.67854 .36406 Mdot
.42512 .16036 Mdot
.24512 .60336 Mdot
.37878 .32435 Mdot
.21193 .34278 Mdot
.47467 .3559 Mdot
.61392 .38504 Mdot
.41953 .59879 Mdot
.70384 .3025 Mdot
.77061 .48173 Mdot
.40823 .78487 Mdot
.29416 .40789 Mdot
.2818 .55874 Mdot
.21672 .34419 Mdot
.19213 .37287 Mdot
.77502 .67838 Mdot
.58637 .40346 Mdot
.68312 .4646 Mdot
.72818 .3153 Mdot
.60698 .43744 Mdot
.70007 .33211 Mdot
.66002 .32783 Mdot
.16528 .51397 Mdot
.49739 .30333 Mdot
.66019 .21227 Mdot
.48786 .66929 Mdot
.24399 .41769 Mdot
.47008 .81756 Mdot
.82205 .42152 Mdot
.23063 .33058 Mdot
.55382 .69068 Mdot
.74303 .62805 Mdot
.6729 .62531 Mdot
.59117 .47654 Mdot
.49553 .86913 Mdot
.42611 .60092 Mdot
.7955 .48016 Mdot
.42344 .22156 Mdot
.59372 .61908 Mdot
.38888 .8241 Mdot
.68256 .2832 Mdot
.38668 .79805 Mdot
.52173 .34556 Mdot
.62316 .64233 Mdot
.64988 .63133 Mdot
.395 .70003 Mdot
.51472 .27544 Mdot
.1851 .52063 Mdot
.82463 .39822 Mdot
.38221 .23965 Mdot
.798 .59235 Mdot
.20259 .52041 Mdot
.38328 .20511 Mdot
.59615 .21891 Mdot
.49675 .47628 Mdot
.217 .5368 Mdot
.50915 .73211 Mdot
.55837 .16775 Mdot
.45371 .60631 Mdot
.43874 .39279 Mdot
.66271 .31571 Mdot
.45665 .2403 Mdot
.48934 .80558 Mdot
.60171 .64988 Mdot
.31969 .72195 Mdot
.33683 .23167 Mdot
.78706 .64644 Mdot
.60474 .80521 Mdot
.36555 .80867 Mdot
.76549 .54564 Mdot
.45816 .23269 Mdot
.60019 .22587 Mdot
.85884 .50569 Mdot
.49225 .52193 Mdot
.22217 .38759 Mdot
.51763 .74091 Mdot
.21506 .34297 Mdot
.47875 .39042 Mdot
.61608 .27489 Mdot
.28301 .37852 Mdot
.17214 .47777 Mdot
.70655 .57561 Mdot
.2737 .27832 Mdot
.43347 .50523 Mdot
.18801 .62789 Mdot
.38945 .2714 Mdot
.45242 .45226 Mdot
.38788 .48991 Mdot
.28328 .63327 Mdot
.25495 .3263 Mdot
.30707 .31086 Mdot
.81911 .42416 Mdot
.39058 .44874 Mdot
.41584 .60402 Mdot
.78186 .59645 Mdot
.51138 .7662 Mdot
.4308 .23737 Mdot
.44547 .68845 Mdot
.26371 .27879 Mdot
.35778 .6942 Mdot
.32971 .72466 Mdot
.20939 .5059 Mdot
.74715 .2729 Mdot
.53805 .2923 Mdot
.25562 .62766 Mdot
.66884 .27179 Mdot
.30193 .53501 Mdot
.51125 .65524 Mdot
.0753 .56431 Mdot
.74264 .2876 Mdot
.36183 .28265 Mdot
.1646 .53031 Mdot
.50543 .1948 Mdot
.32916 .30899 Mdot
.63213 .7755 Mdot
.49489 .54942 Mdot
.38917 .75444 Mdot
.60104 .58777 Mdot
.28142 .75374 Mdot
.48579 .75819 Mdot
.16861 .5599 Mdot
.41776 .17088 Mdot
.8072 .51336 Mdot
.58172 .65848 Mdot
.34579 .4371 Mdot
.51443 .30449 Mdot
.48786 .77767 Mdot
.71507 .63406 Mdot
.49561 .59178 Mdot
.27781 .41883 Mdot
.37818 .50355 Mdot
.23824 .53403 Mdot
.63805 .47473 Mdot
.25383 .44765 Mdot
.44725 .24482 Mdot
.3002 .43117 Mdot
.46571 .51303 Mdot
.42753 .70655 Mdot
.5395 .50399 Mdot
.77711 .57905 Mdot
.60816 .77413 Mdot
.53741 .43966 Mdot
.32875 .47725 Mdot
.76116 .58644 Mdot
.69315 .24916 Mdot
.38442 .24645 Mdot
.18292 .57815 Mdot
.30169 .66672 Mdot
.72833 .65438 Mdot
.41315 .70474 Mdot
.65258 .7649 Mdot
.71677 .69958 Mdot
.28342 .34345 Mdot
.59535 .49258 Mdot
.68688 .71009 Mdot
.5907 .23709 Mdot
.15659 .47151 Mdot
.778 .35066 Mdot
.74266 .32135 Mdot
.31126 .5179 Mdot
.77365 .43779 Mdot
.79985 .55835 Mdot
.49095 .69808 Mdot
.43618 .54443 Mdot
.70024 .79014 Mdot
.68349 .38179 Mdot
.55354 .88332 Mdot
.47339 .32804 Mdot
.52842 .84676 Mdot
.52063 .73241 Mdot
.47892 .44138 Mdot
.4162 .54628 Mdot
.42359 .25102 Mdot
.59229 .27316 Mdot
.6156 .20696 Mdot
.71672 .7171 Mdot
.31602 .48039 Mdot
.8271 .39553 Mdot
.75374 .2743 Mdot
.7418 .60487 Mdot
.5388 .60642 Mdot
.73859 .27849 Mdot
.40565 .46768 Mdot
.5681 .79081 Mdot
.48665 .18111 Mdot
.31795 .29314 Mdot
.61185 .69935 Mdot
.43792 .72303 Mdot
.22324 .38137 Mdot
.19141 .35203 Mdot
.63041 .80302 Mdot
.26184 .3278 Mdot
.48461 .38968 Mdot
.44261 .45287 Mdot
.27925 .2816 Mdot
.48095 .61626 Mdot
.51491 .24313 Mdot
.49182 .57911 Mdot
.63403 .85096 Mdot
.19614 .46795 Mdot
.1854 .5181 Mdot
.48329 .59345 Mdot
.65717 .37984 Mdot
.50126 .27853 Mdot
.50419 .55622 Mdot
.33426 .28323 Mdot
.67698 .25261 Mdot
.5024 .55549 Mdot
.83779 .59747 Mdot
.72715 .38647 Mdot
.40711 .42343 Mdot
.79421 .58374 Mdot
.71755 .42403 Mdot
.52277 .34814 Mdot
.33809 .7133 Mdot
.4103 .22232 Mdot
.49969 .38678 Mdot
.4253 .23909 Mdot
.4891 .24536 Mdot
.73665 .37434 Mdot
.77655 .49224 Mdot
.35444 .25416 Mdot
.71945 .61029 Mdot
.58085 .37244 Mdot
.48646 .79731 Mdot
.33453 .42632 Mdot
.41204 .21558 Mdot
.38484 .48806 Mdot
.59843 .50646 Mdot
.45612 .55859 Mdot
.65842 .70411 Mdot
.36113 .79461 Mdot
.3784 .65349 Mdot
.65206 .44371 Mdot
.54987 .85115 Mdot
.60645 .43084 Mdot
.29545 .75613 Mdot
.62744 .76329 Mdot
.80824 .53926 Mdot
.26028 .52523 Mdot
.25836 .56627 Mdot
.78681 .696 Mdot
.55373 .39957 Mdot
.2972 .48679 Mdot
.5646 .37931 Mdot
.6653 .43454 Mdot
.21675 .50023 Mdot
.32787 .49416 Mdot
.49499 .53615 Mdot
.42511 .40697 Mdot
.64911 .34461 Mdot
.58851 .43848 Mdot
.47746 .53191 Mdot
.3982 .74468 Mdot
.16778 .50333 Mdot
.34025 .45718 Mdot
.59381 .85591 Mdot
.5887 .66826 Mdot
.73518 .56798 Mdot
.34244 .21669 Mdot
.62798 .81285 Mdot
.3302 .51232 Mdot
.76041 .27578 Mdot
.60029 .54187 Mdot
.32589 .26896 Mdot
.6332 .41846 Mdot
.75339 .32945 Mdot
.36542 .65618 Mdot
.45363 .69054 Mdot
.50474 .3201 Mdot
.52078 .80934 Mdot
.32065 .40517 Mdot
.6259 .36901 Mdot
.28301 .31951 Mdot
.68989 .45864 Mdot
.5697 .25355 Mdot
.24783 .5559 Mdot
.74569 .60735 Mdot
.77539 .48005 Mdot
.58544 .42962 Mdot
.18277 .50259 Mdot
.75764 .32825 Mdot
.14291 .48475 Mdot
.5218 .58256 Mdot
.30648 .62869 Mdot
.67365 .32251 Mdot
.39881 .24777 Mdot
.58296 .48088 Mdot
.31495 .23372 Mdot
.45284 .74457 Mdot
.67705 .34459 Mdot
.41398 .72161 Mdot
.62633 .53344 Mdot
.48005 .48522 Mdot
.40765 .3011 Mdot
.72923 .72092 Mdot
.56576 .47586 Mdot
.55737 .82895 Mdot
.5881 .49064 Mdot
.19856 .54731 Mdot
.63412 .48031 Mdot
.37185 .5139 Mdot
.78077 .44689 Mdot
.54272 .35188 Mdot
.1612 .45626 Mdot
.32399 .22794 Mdot
.4652 .31729 Mdot
.22922 .4719 Mdot
.48279 .19702 Mdot
.60229 .52478 Mdot
.43135 .46164 Mdot
.60152 .55519 Mdot
.6919 .44137 Mdot
.63435 .81539 Mdot
.36102 .26531 Mdot
.59627 .68285 Mdot
.1816 .43303 Mdot
.172 .42061 Mdot
.182 .6047 Mdot
.83917 .49108 Mdot
.65791 .38646 Mdot
.24497 .69746 Mdot
.49749 .59495 Mdot
.2057 .32659 Mdot
.28822 .33522 Mdot
.40867 .16475 Mdot
.7392 .62327 Mdot
.44455 .21959 Mdot
.66798 .73429 Mdot
.55552 .26786 Mdot
.55191 .1981 Mdot
.45042 .42353 Mdot
.36717 .32606 Mdot
.52668 .19016 Mdot
.87684 .52802 Mdot
.62239 .51271 Mdot
.49176 .2406 Mdot
.62167 .25776 Mdot
.4035 .21865 Mdot
.33173 .5613 Mdot
.56998 .64235 Mdot
.31404 .35205 Mdot
.43054 .80655 Mdot
.43182 .69284 Mdot
.41818 .61411 Mdot
.32957 .55885 Mdot
.44277 .7763 Mdot
.40915 .73268 Mdot
.77979 .3509 Mdot
.74559 .61647 Mdot
.52285 .5036 Mdot
.54635 .58321 Mdot
.6154 .47468 Mdot
.34547 .62765 Mdot
.40879 .40793 Mdot
.6082 .56072 Mdot
.39198 .50431 Mdot
.57 .25919 Mdot
.34566 .79497 Mdot
.51889 .29911 Mdot
.6722 .26597 Mdot
.68443 .41789 Mdot
.47882 .2559 Mdot
.57337 .42928 Mdot
.44667 .82572 Mdot
.31589 .58947 Mdot
.43555 .67084 Mdot
.19812 .3984 Mdot
.24852 .64903 Mdot
.72216 .36034 Mdot
.24783 .66912 Mdot
.47473 .38615 Mdot
.55666 .67593 Mdot
.64121 .27822 Mdot
.23376 .54429 Mdot
.6894 .42425 Mdot
.4412 .2218 Mdot
.2935 .47774 Mdot
.25079 .63152 Mdot
.58247 .20188 Mdot
.71126 .42044 Mdot
.76729 .61883 Mdot
.18693 .38281 Mdot
.34513 .44391 Mdot
.74367 .30861 Mdot
.51521 .23718 Mdot
.30723 .60656 Mdot
.19089 .552 Mdot
.15607 .50619 Mdot
.43005 .52874 Mdot
.48683 .72778 Mdot
.59192 .63477 Mdot
.80531 .39888 Mdot
.3809 .25944 Mdot
.67668 .65777 Mdot
.3824 .37608 Mdot
.60598 .40256 Mdot
.40083 .33426 Mdot
.51544 .49741 Mdot
.41185 .76433 Mdot
.59945 .43621 Mdot
.7993 .5988 Mdot
.34535 .65675 Mdot
.41109 .52772 Mdot
.54952 .63672 Mdot
.47573 .71307 Mdot
.82636 .5636 Mdot
.52534 .604 Mdot
.28403 .2988 Mdot
.75508 .60332 Mdot
.71124 .31384 Mdot
.34001 .26733 Mdot
.28153 .34877 Mdot
.58542 .27328 Mdot
.78727 .47421 Mdot
.38018 .39799 Mdot
.57646 .56108 Mdot
.36658 .51621 Mdot
.59877 .40278 Mdot
.4506 .18694 Mdot
.76541 .53357 Mdot
.4878 .70523 Mdot
.50088 .43638 Mdot
.61907 .49718 Mdot
.51496 .4229 Mdot
.38492 .18494 Mdot
.55634 .26925 Mdot
.44285 .73763 Mdot
.50454 .30425 Mdot
.51696 .72952 Mdot
.61787 .77458 Mdot
.15643 .41088 Mdot
.65127 .756 Mdot
.45494 .4999 Mdot
.56853 .82816 Mdot
.41432 .26442 Mdot
.49291 .18237 Mdot
.42846 .73875 Mdot
.40408 .54057 Mdot
.39803 .65823 Mdot
.60408 .3431 Mdot
.52042 .45382 Mdot
.41685 .64703 Mdot
.50729 .52664 Mdot
.35364 .38178 Mdot
.43526 .30696 Mdot
.66855 .57776 Mdot
.20204 .47935 Mdot
.1932 .39112 Mdot
.75941 .33855 Mdot
.53736 .41933 Mdot
.33927 .58776 Mdot
.43439 .76654 Mdot
.47207 .13333 Mdot
.44722 .86356 Mdot
.59134 .63319 Mdot
.54239 .42335 Mdot
.47092 .72611 Mdot
.31844 .46336 Mdot
.52868 .52177 Mdot
.56846 .41938 Mdot
.48749 .32314 Mdot
.42324 .60633 Mdot
.26232 .64766 Mdot
.4298 .25248 Mdot
.52997 .76634 Mdot
.28956 .38445 Mdot
.34589 .7984 Mdot
.67143 .23485 Mdot
.38769 .25319 Mdot
.41815 .14576 Mdot
.436 .29763 Mdot
.65345 .35213 Mdot
.69011 .57692 Mdot
.17102 .50703 Mdot
.44897 .67792 Mdot
.46138 .80047 Mdot
.2772 .36572 Mdot
.44267 .74313 Mdot
.49956 .63232 Mdot
.20563 .51515 Mdot
.39663 .34768 Mdot
.47081 .46273 Mdot
.26021 .56946 Mdot
.2204 .63491 Mdot
.77339 .62563 Mdot
.21002 .3828 Mdot
.44439 .81412 Mdot
.85886 .5453 Mdot
.16505 .43434 Mdot
.40466 .57936 Mdot
.33729 .57587 Mdot
.69515 .5839 Mdot
.48132 .6464 Mdot
.52744 .67425 Mdot
.55749 .79372 Mdot
.7634 .47433 Mdot
.25313 .48686 Mdot
.51279 .83214 Mdot
.41526 .70925 Mdot
.72336 .41293 Mdot
.40572 .5409 Mdot
.77284 .57765 Mdot
.23053 .4796 Mdot
.47674 .59641 Mdot
.45083 .59704 Mdot
.47347 .66668 Mdot
.75565 .59219 Mdot
.7027 .32465 Mdot
.48521 .21139 Mdot
.84588 .60286 Mdot
.25736 .3668 Mdot
.46041 .8296 Mdot
.59977 .66118 Mdot
.1421 .51498 Mdot
.49103 .21993 Mdot
.26931 .36777 Mdot
.63328 .22788 Mdot
.41601 .43687 Mdot
.67988 .35286 Mdot
.5758 .56168 Mdot
.24904 .34582 Mdot
.79754 .48933 Mdot
.69579 .46599 Mdot
.50681 .81533 Mdot
.44502 .70414 Mdot
.32427 .69114 Mdot
.49399 .69061 Mdot
.52318 .62948 Mdot
.61585 .43921 Mdot
.25643 .71887 Mdot
.44298 .50111 Mdot
.60453 .50474 Mdot
.66684 .67637 Mdot
.66075 .7362 Mdot
.69238 .22845 Mdot
.51808 .61061 Mdot
.23443 .62945 Mdot
.7562 .65407 Mdot
.62423 .70676 Mdot
.56394 .50527 Mdot
.49724 .08963 Mdot
.1392 .38332 Mdot
.61762 .37228 Mdot
.81372 .44006 Mdot
.76091 .65112 Mdot
.17507 .49332 Mdot
.28788 .59112 Mdot
.39934 .39527 Mdot
.63269 .72501 Mdot
.49536 .65503 Mdot
.54798 .65057 Mdot
.60104 .21071 Mdot
.15925 .39747 Mdot
.51129 .82004 Mdot
.18158 .42916 Mdot
.66341 .65455 Mdot
.54064 .64696 Mdot
.5135 .12071 Mdot
.26881 .29258 Mdot
.58757 .52322 Mdot
.6764 .7353 Mdot
.68908 .38383 Mdot
.62329 .6016 Mdot
.23118 .41712 Mdot
.823 .39107 Mdot
.41157 .70838 Mdot
.17228 .47884 Mdot
.58928 .41275 Mdot
.30199 .48482 Mdot
.48162 .32215 Mdot
.42318 .54581 Mdot
.57885 .54331 Mdot
.4687 .34399 Mdot
.66331 .70648 Mdot
.44228 .21429 Mdot
.47796 .30193 Mdot
.78378 .34192 Mdot
.31216 .21903 Mdot
.77311 .54322 Mdot
.58566 .34969 Mdot
.58898 .51791 Mdot
.72156 .40962 Mdot
.47627 .77946 Mdot
.70244 .40975 Mdot
.51333 .18461 Mdot
.11755 .59493 Mdot
.35985 .33889 Mdot
.36656 .73373 Mdot
.65523 .46389 Mdot
.5347 .49667 Mdot
.78774 .56718 Mdot
.41064 .5124 Mdot
.35731 .44805 Mdot
.66575 .6126 Mdot
.52171 .60915 Mdot
.52007 .35142 Mdot
.54205 .87856 Mdot
.56899 .63806 Mdot
.55023 .50273 Mdot
.20699 .32715 Mdot
.48531 .79753 Mdot
.72323 .56738 Mdot
.61822 .54873 Mdot
.58808 .32098 Mdot
.40303 .54043 Mdot
.3777 .22105 Mdot
.3271 .72136 Mdot
.1885 .43719 Mdot
.76476 .52941 Mdot
.76534 .62836 Mdot
.54958 .60955 Mdot
.37996 .66178 Mdot
.50946 .25407 Mdot
.23762 .40004 Mdot
.65016 .6678 Mdot
.18205 .35571 Mdot
.41236 .42385 Mdot
.3242 .39814 Mdot
.52272 .64811 Mdot
.19166 .62219 Mdot
.56262 .81748 Mdot
.80039 .53222 Mdot
.42687 .82236 Mdot
.23991 .573 Mdot
.50928 .765 Mdot
.35008 .43817 Mdot
.65548 .65987 Mdot
.59043 .40232 Mdot
.35514 .81031 Mdot
.22408 .41454 Mdot
.34761 .32549 Mdot
.38348 .34191 Mdot
.78838 .39885 Mdot
.56434 .24435 Mdot
.38606 .16324 Mdot
.24866 .5744 Mdot
.35941 .80862 Mdot
.74277 .31741 Mdot
.67613 .45122 Mdot
.44312 .23105 Mdot
.53824 .65645 Mdot
.3326 .47019 Mdot
.18668 .45116 Mdot
.53221 .56499 Mdot
.37972 .77551 Mdot
.6453 .59444 Mdot
.36637 .78719 Mdot
.42691 .6385 Mdot
.22151 .46857 Mdot
.38395 .27796 Mdot
.62456 .77694 Mdot
.4268 .18724 Mdot
.61552 .33847 Mdot
.44625 .14999 Mdot
.42785 .19496 Mdot
.19155 .36359 Mdot
.42076 .79316 Mdot
.66844 .77937 Mdot
.30766 .31334 Mdot
.35938 .25329 Mdot
.42542 .26999 Mdot
.70056 .64342 Mdot
.28245 .62943 Mdot
.5159 .62148 Mdot
.52897 .27278 Mdot
.44688 .33501 Mdot
.26659 .80625 Mdot
.38868 .68122 Mdot
.63998 .36322 Mdot
.26267 .61206 Mdot
.17463 .39816 Mdot
.69123 .6734 Mdot
.54338 .18867 Mdot
.5077 .49903 Mdot
.57525 .67461 Mdot
.77093 .49858 Mdot
.77571 .36792 Mdot
.28939 .64428 Mdot
.79115 .7034 Mdot
.67541 .2416 Mdot
.36862 .36562 Mdot
.47928 .49579 Mdot
.60613 .43843 Mdot
.58159 .43373 Mdot
.26256 .54978 Mdot
.53779 .17678 Mdot
.44367 .21777 Mdot
.27741 .2832 Mdot
.78849 .69137 Mdot
.72268 .31591 Mdot
.16973 .50634 Mdot
.39507 .26356 Mdot
.64681 .36835 Mdot
.39167 .57233 Mdot
.37485 .42613 Mdot
.35435 .31448 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Nooooo`;o0000ZOoo
ool001cooooo00?o0000ooooooooool0W_ooool2o`000:Wooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0<3ooooo0_l00027ooooo`007?ooool00ol0003o
ooooooooo`30ooooo`;o0000Qoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`2Sooooo`;o0000Y?ooool001cooooo00?o0000ooooooooool0Xoooool2
o`000:Cooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Fooooo`;o0000/Oooool001cooooo00?o
0000ooooooooool0U_ooool2o`000;7ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0]_ooool2o`00097ooooo000Looooo`03o`000?oooooooooo08Co
oooo0_l0000`ooooo`;o00001?ooool2o`0008_ooooo000Looooo`03o`000?oooooooooo08Cooooo
0_l00007ooooo`;o00006_ooool2o`000003ooooool0003o000000kooooo0_l00003ooooo`;o0000
Q_ooool001cooooo0_l0002>ooooo`;o00003_ooool2o`0000[ooooo0_l000000ooooooo0000o`00
000Cooooo`;o0000Q_ooool001cooooo00?o0000ooooooooool0WOooool2o`0000?ooooo0_l00005
ooooo`;o0000W_ooool001cooooo00?o0000ooooooooool0X_ooool2o`000:Gooooo000Looooo`03
o`000?oooooooooo08Kooooo0_l00031ooooo`007?ooool00ol0003oooooooooo`1jooooo`;o0000
1Oooool2o`0000?ooooo0_l0000Nooooo`;o00002Oooool2o`0002?ooooo0_l0001aooooo`007?oo
ool00ol0003oooooooooo`1jooooo`;o00001Oooool4o`0000gooooo0_l0000?ooooo`;o000000?o
ooooo`000?l000002Oooool3o`0002;ooooo0_l0001aooooo`007?ooool00ol0003oooooooooo`21
ooooo`Go00002_ooool4o`000003ooooool0003o000000cooooo0_l000001?oooooo0000o`000?l0
0009ooooo`;o00007Oooool2o`0007Kooooo000Looooo`03o`000?oooooooooo087ooooo0_l00000
0ooooooo0000o`000006ooooo`;o00000_ooool4o`000003ooooool0003o000000kooooo1?l0000X
ooooo`;o0000M_ooool001cooooo00?o0000ooooooooool0Ooooool2o`0000_ooooo0_l00002oooo
o`Co00001?ooool2o`0000Oooooo0_l000001?oooooo0000o`000?l00004ooooo`;o0000W?ooool0
01cooooo00?o0000ooooooooool0Ooooool2o`0000?ooooo0_l0000<ooooo`;o00000oooool5o`00
00Gooooo0_l000000ooooooo0000o`000005ooooo`;o0000W?ooool001cooooo00?o0000oooooooo
ool0LOooool2o`0000Wooooo1Ol00003ooooo`;o00002_ooool4o`0000?ooooo0_l000000ooooooo
0000o`000002o`0000Gooooo0_l000001?oooooo0000o`000?l00004ooooo`;o0000:oooool2o`00
06gooooo000Looooo`03o`000?oooooooooo077ooooo0_l00006ooooo`;o000000?oooooo`000?l0
00000ol00006ooooo`;o00001_ooool3o`0000Sooooo1_l00003ooooo`;o000000Coooooo`000?l0
003o00001?ooool5o`0000cooooo0_l0000Jooooo`;o0000KOooool001cooooo00?o0000oooooooo
ool0NOooool2o`0000cooooo0_l000000ooooooo0000o`000003ooooo`?o00002oooool4o`0000Ko
oooo0_l00004ooooo`Go00002oooool3o`0000Kooooo0_l00021ooooo`0000Koooooonk^k_lb<S;o
0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0NOooool2o`00
00oooooo0_l00004ooooo`;o00003Oooool2o`000003ooooool0003o000000?ooooo0_l00004oooo
o`;o00003Oooool3o`0000Oooooo0_l00021ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5
ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0M_oo
ool2o`000003ooooool0003o000000?o00002Oooool2o`0001Oooooo1?l00002ooooo`;o00001Ooo
ool2o`0000gooooo1Ol00028ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0M_ooool2o`0000;ooooo1?l00009
ooooo`;o00004?ooool2o`000003ooooool0003o000000Co00001?ooool2o`0000Sooooo0_l00003
ooooo`;o00001_ooool4o`0000?ooooo0ol00022ooooo`0000?oooooo`000?ooool00_ooool00ol0
003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol00027ooooo`;o00004?ooool9o`00
00Gooooo0_l00007ooooo`;o00000oooool2o`0000;ooooo0_l00005ooooo`Oo0000P_ooool00003
ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03
o`000?oooooooooo07Wooooo0_l0000Nooooo`?o00001?ooool2o`000003ooooool0003o000000;o
oooo0_l0000<ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo1?l00003ooooo`;o
0000P?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool03Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo06oooooo0_l00008ooooo`;o00003?ooool2o`0000[ooooo
0_l0000>ooooo`;o00005oooool2o`0000Kooooo0_l000000ooooooo0000o`000020ooooo`0000Ko
ooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0
003oooooooooo`1_ooooo`Co00005?ooool2o`0000[ooooo0_l00005ooooo`?o00001?ooool2o`00
01Cooooo0_l00006ooooo`;o00000oooool2o`0000gooooo0_l0001dooooo`0000Koooooonk^k_lb
<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooooooo
o`1aooooo`;o00000_ooool2o`0000cooooo0_l00006ooooo`?o00000oooool2o`0000Gooooo1Ol0
0002ooooo`Go00004oooool2o`0000Kooooo0_l0000Booooo`;o0000M?ooool001cooooo00?o0000
ooooooooool0K?ooool2o`0000Oooooo0_l0000;ooooo`?o00001_ooool3o`0000?ooooo0_l00005
ooooo`;o00001Oooool5o`0001?ooooo0_l0000Mooooo`;o0000LOooool001cooooo00?o0000oooo
ooooool0H_ooool2o`0000Kooooo1?l00009ooooo`;o00001_ooool2o`000003ooooool0003o0000
00;ooooo0_l00004ooooo`?o00001Oooool2o`0000Kooooo0_l000001?oooooo0000o`000?l00009
ooooo`;o00002_ooool2o`0000Gooooo0_l0000>ooooo`;o00001_ooool2o`00077ooooo000Loooo
o`03o`000?oooooooooo06;ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l00002oooo
o`;o00001Oooool2o`0000Kooooo0_l000000ooooooo0000o`000002ooooo`;o00001?ooool3o`00
00Gooooo0_l00005ooooo`?o000000?oooooo`000?l000001Oooool4o`000003ooooool0003o0000
017ooooo0_l000000ooooooo0000o`00000;ooooo`;o0000NOooool001cooooo00?o0000oooooooo
ool0Ioooool2o`0000Oooooo0_l0000@ooooo`Co00001_ooool2o`0000gooooo0_l00002ooooo`;o
00000_ooool2o`000003ooooool0003o000000Co00000_ooool2o`0000Sooooo0_l00005ooooo`Go
00005?ooool2o`0006oooooo000Looooo`03o`000?oooooooooo06Kooooo0_l00003ooooo`;o0000
5oooool2o`0001cooooo0ol00005ooooo`;o000000Coooooo`000?l0003o00002?ooool2o`0000Go
oooo0_l000000ooooooo0000o`000006ooooo`;o00003?ooool2o`0000?ooooo0_l0001Zooooo`00
7?ooool00ol0003oooooooooo`1Sooooo`;o000000?oooooo`000?l000000_ooool3o`0001Cooooo
0_l00002ooooo`;o00001Oooool2o`0000?ooooo0_l0000:ooooo`;o00000oooool4o`0000Cooooo
0_l000000ooooooo0000o`00000Kooooo`;o00003_ooool2o`000003ooooool0003o000006[ooooo
000Looooo`03o`000?oooooooooo06?ooooo0_l00004ooooo`?o00000_ooool2o`00013ooooo0ol0
0002ooooo`;o00000oooool4o`0000?ooooo0_l0000:ooooo`;o00001Oooool2o`0000?ooooo0_l0
0007ooooo`;o00008_ooool2o`0000;ooooo1Ol0000<ooooo`;o0000G?ooool001cooooo00?o0000
ooooooooool0IOooool2o`0000;ooooo0_l00003ooooo`;o00002?ooool2o`0000Kooooo0_l00004
ooooo`Ko00002oooool2o`0000?ooooo1?l00004ooooo`;o00000oooool2o`0000Oooooo0_l00008
ooooo`;o00001Oooool3o`00013ooooo0_l00003ooooo`;o000000?oooooo`000?l000002oooool2
o`0005cooooo000Looooo`03o`000?oooooooooo06Gooooo0_l00002ooooo`;o00002?ooool2o`00
00?ooooo0_l0000<ooooo`Co00001oooool2o`0000Cooooo2Ol00003ooooo`?o00004?ooool2o`00
00Cooooo0_l00005ooooo`?o00001?ooool2o`0000_ooooo0ol00004ooooo`;o0000JOooool001co
oooo00?o0000ooooooooool0Loooool2o`0001?ooooo0_l000001?oooooo0000o`000?ooool2o`00
0003ooooool0003o000000?ooooo2?l00005ooooo`Co000000?oooooo`000?l000002_ooool4o`00
01;ooooo0_l0000;ooooo`?o000000?oooooo`000?l000002?ooool2o`0006;ooooo000Looooo`03
o`000?oooooooooo05Kooooo0_l00006ooooo`Co00005Oooool4o`0000?ooooo0_l0000;ooooo`;o
000000?oooooo`000?l000001?ooool4o`0000?ooooo0_l00002ooooo`;o00001?ooool2o`000003
ooooool0003o000000Cooooo0_l00004ooooo`;o00001?ooool2o`0000cooooo0ol00006ooooo`;o
00002?ooool4o`000003ooooool0003o000000;ooooo0ol0000:ooooo`;o0000E_ooool001cooooo
0_l0001Gooooo`;o00001_ooool4o`0000Wooooo0_l0000:ooooo`Co00000oooool2o`0000Cooooo
1?l00006ooooo`;o00001?ooool2o`0000Sooooo0ol0000=ooooo`;o00002_ooool3o`0000_ooooo
0ol00006ooooo`;o00000_ooool2o`0000Kooooo0_l000000ooooooo0000o`000002ooooo`;o0000
2oooool2o`0005Kooooo000Looooo`03o`000?oooooooooo05[ooooo0_l00004ooooo`;o00001ooo
ool4o`000003ooooool0003o000000?o00001oooool2o`0000Kooooo2?l0000;ooooo`;o00001ooo
ool3o`000004ooooool0003o0000o`0000Kooooo0ol00007ooooo`;o00000oooool3o`00013ooooo
0_l00006ooooo`;o000000?oooooo`000?l000000oooool2o`0006[ooooo000Looooo`03o`000?oo
oooooooo05Wooooo0ol0000=ooooo`;o00000oooool5o`0000Oooooo0_l00006ooooo`;o00001?oo
ool2o`0000_ooooo0_l000000ooooooo0000o`000003o`0000Gooooo0ol00006ooooo`?o00001ooo
ool2o`0000Kooooo0_l00007ooooo`;o00001Oooool2o`0000Sooooo0ol00005ooooo`;o00004_oo
ool2o`0005Cooooo000Looooo`03o`000?oooooooooo05Wooooo0ol0000Aooooo`;o00002Oooool4
o`0001cooooo1Ol000000ooooooo0000o`00000Eooooo`;o00001_ooool2o`000004ooooool0003o
0000o`0000?ooooo0_l00007ooooo`;o00001_ooool2o`0000Kooooo0_l0000;ooooo`;o00001Ooo
ool2o`0005Cooooo000Looooo`03o`000?oooooooooo05[ooooo0_l0000Aooooo`;o000000?ooooo
o`000?l000000_l00004ooooo`Co000000?oooooo`000?l000001?ooool2o`0001Cooooo0_l00003
ooooo`;o00000oooool2o`0000cooooo0_l00002ooooo`;o00002Oooool3o`0000cooooo0_l0000K
ooooo`;o0000Foooool001cooooo00?o0000ooooooooool0E?ooool2o`0001Gooooo0_l00003oooo
o`Co00002Oooool3o`0000?ooooo1?l00004ooooo`;o00003?ooool2o`0000Sooooo0_l0000<oooo
o`;o00002oooool2o`0000Cooooo0_l0000Aooooo`Co00001Oooool2o`0006Oooooo000Looooo`03
o`000?oooooooooo05Cooooo0ol0000?ooooo`;o00000oooool2o`0000Cooooo0ol00007ooooo`;o
000000?oooooo`000?l000002?l000000ooooooo0000o`000002o`0000cooooo0_l0000=ooooo`;o
00001oooool2o`0000Kooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l00007oooo
o`?o00001oooool4o`0000Gooooo0_l00004ooooo`;o0000HOooool001cooooo00?o0000oooooooo
ool0EOooool4o`0000gooooo0_l0000Cooooo`;o00000oooool4o`000005ooooool0003o0000o`00
0?ooool00ol00003ooooo`;o00000_ooool2o`0000Oooooo0_l0000:ooooo`;o00001oooool2o`00
0003ooooool0003o000000?ooooo1ol000000ooooooo0000o`000003o`0000Oooooo0ol00005oooo
o`;o00000_ooool2o`0000_ooooo0_l00007ooooo`;o0000F?ooool001cooooo00?o0000oooooooo
ool0D_ooool3o`0000;ooooo0_l00008ooooo`?o00001oooool2o`0000kooooo0_l00004ooooo`;o
00000_ooool2o`0000Sooooo0_l00002ooooo`;o00001?ooool2o`000003ooooool0003o000000Co
oooo0ol00003ooooo`;o00002_ooool2o`000004ooooool0003o0000ooooo`Go00001?ooool3o`00
00oooooo0_l00002ooooo`;o00003_ooool2o`0000Cooooo1_l0001Dooooo`007?ooool00ol0003o
ooooooooo`18ooooo`;o00001oooool6o`0000[ooooo0ol000000ooooooo0000o`000004ooooo`;o
00003?ooool2o`0001cooooo1Ol00003ooooo`;o000000Coooooo`000?l0003o00001Oooool2o`00
00_ooooo0_l00006ooooo`;o00000oooool2o`0000Kooooo0_l00005ooooo`;o00005?ooool2o`00
0003ooooool0003o000000?ooooo1?l0001Dooooo`007?ooool00ol0003oooooooooo`18ooooo`;o
00001oooool3o`000003ooooool0003o000000;o00002?ooool2o`0000;ooooo0_l0000;ooooo`?o
00001?ooool2o`0000Oooooo0_l00005ooooo`;o00003?ooool2o`000003ooooool0003o000000?o
oooo0_l00009ooooo`;o00004?ooool2o`000003ooooool0003o000000_ooooo0_l00005ooooo`;o
00001Oooool2o`0000kooooo1?l00006ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0
E_ooool3o`0000Cooooo0_l0000:ooooo`;o00001oooool5o`0000[ooooo0ol00005ooooo`;o0000
0oooool2o`0002cooooo0_l0000Eooooo`;o00001Oooool2o`0000Kooooo0_l00002ooooo`;o0000
0_ooool2o`0000Sooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o00002_oo
ool2o`0000[ooooo0_l00008ooooo`Co00002oooool2o`0000Kooooo0_l0000`ooooo`;o00002Ooo
ool5o`0000?ooooo0_l00005ooooo`;o00000_ooool2o`0000Gooooo0_l0001Jooooo`007?ooool0
0ol0003oooooooooo`1>ooooo`;o00003Oooool2o`00023ooooo1?l000000ooooooo0000o`00000;
ooooo`;o00000oooool2o`0000Gooooo1_l00008ooooo`;o00006oooool2o`0000_ooooo0ol00003
ooooo`;o000000?oooooo`000?l000003Oooool2o`0005[ooooo000Looooo`03o`000?oooooooooo
04kooooo0_l00004ooooo`;o00003_ooool2o`0000Cooooo0_l00008ooooo`;o00002_ooool6o`00
00_ooooo0_l00007ooooo`;o000000?oooooo`000?l000001?l00008ooooo`;o0000<Oooool2o`00
00Oooooo0_l00004ooooo`;o0000F_ooool001cooooo00?o0000ooooooooool0E?ooool2o`0000ko
oooo0_l00004ooooo`;o00002?ooool2o`0000cooooo0_l00006ooooo`;o00003_ooool2o`0000;o
oooo0_l0000;ooooo`?o0000>Oooool4o`0005kooooo000Looooo`;o0000Boooool2o`000003oooo
ool0003o000000[ooooo0_l0000Iooooo`;o00002oooool2o`0000Oooooo0ol0000=ooooo`?o0000
00?oooooo`000?l000001Oooool4o`0000?ooooo0_l0000=ooooo`;o000000Coooooo`000?l0003o
00001_ooool2o`0000Sooooo0_l0000Fooooo`Co00000oooool2o`0005Oooooo000Looooo`03o`00
0?oooooooooo04Oooooo0_l000001?oooooo0000o`000?ooool2o`0000[ooooo0_l0000Hooooo`;o
00003?ooool2o`0000Sooooo0ol0000:ooooo`Go000000?oooooo`000?l000000_l000000ooooooo
0000o`000004o`0000Sooooo0_l00008ooooo`;o000000Coooooo`000?l0003o00001_ooool2o`00
00Sooooo0_l00009ooooo`;o00000oooool2o`0000Sooooo1?l000000ooooooo0000o`000003oooo
o`;o0000D_ooool001cooooo00?o0000ooooooooool0Aoooool2o`0001kooooo0_l00009ooooo`?o
00001oooool2o`0000cooooo1?l0000:ooooo`;o00000_ooool6o`000003ooooool0003o000000Co
000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00003?ooool2o`0000kooooo1Ol00008oooo
o`;o00000oooool2o`0000Sooooo1?l00006ooooo`;o00001oooool2o`0004Wooooo000Looooo`03
o`000?oooooooooo04Oooooo1?l0000=ooooo`;o000000?oooooo`000?l000000oooool2o`0000?o
oooo1?l00008ooooo`Co00001oooool2o`0000cooooo0_l0000@ooooo`?o00000_ooool2o`000004
ooooool0003o0000o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`00
0?l000001oooool2o`0000kooooo0_l000000ooooooo0000o`000009ooooo`;o00000oooool2o`00
00Oooooo0_l000000ooooooo0000o`000002ooooo`;o00002_ooool2o`0004Wooooo000Looooo`03
o`000?oooooooooo04Oooooo1?l0000=ooooo`;o000000?oooooo`000?l000000oooool2o`000003
ooooool0003o000000Co00002?ooool3o`0002Oooooo0_l00004ooooo`;o00004?ooool2o`000003
ooooool0003o000001?ooooo0_l0000@ooooo`So00002Oooool2o`0000;ooooo0_l0001Eooooo`00
7?ooool00ol0003oooooooooo`11ooooo`?o00004Oooool2o`0000Wooooo0_l000000ooooooo0000
o`00000:ooooo`;o000000?oooooo`000?l000001oooool2o`0000Oooooo0_l00006ooooo`;o0000
2?ooool2o`0000?ooooo1?l00004ooooo`;o00004_ooool2o`00013ooooo1?l00006ooooo`;o0000
2_ooool7o`000003ooooool0003o000000;o00004?ooool2o`0000Kooooo0_l00014ooooo`007?oo
ool00ol0003oooooooooo`11ooooo`?o00004Oooool2o`000003ooooool0003o000000Wooooo0_l0
0009ooooo`?o00002_ooool2o`0000Oooooo0_l00002ooooo`;o00000_ooool4o`0000?ooooo0_l0
00000ooooooo0000o`00000:o`000003ooooool0003o000000Wooooo0_l00007ooooo`Go00000_oo
ool2o`0000Wooooo0_l00008ooooo`;o00003oooool2o`000003ooooool0003o000000;o00000_oo
ool2o`0000Sooooo0_l00002ooooo`;o00001_ooool2o`0004Cooooo000Looooo`03o`000?oooooo
oooo03oooooo0_l0000Gooooo`;o00004Oooool2o`000004ooooool0003o0000ooooo`;o00005Ooo
ool2o`0000?ooooo0ol00003oooooa;o00002Oooool2o`0000Sooooo1Ol000000ooooooo0000o`00
000:ooooo`;o00002oooool2o`00013ooooo0_l00002ooooo`;o00002?ooool2o`0000Kooooo0_l0
0002ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0?oooool2o`0000Cooooo0_l00008
ooooo`;o00003Oooool2o`0000Sooooo0_l000000ooooooo0000o`000003o`000004ooooool0003o
0000ooooo`Go00005?ooool4o`0000;ooooo3_l000000ooooooo0000o`000002o`0001;ooooo0_l0
00001?oooooo0000o`000?ooool5o`0000?ooooo0ol000000ooooooo0000o`00000;ooooo`;o0000
1oooool2o`0000Kooooo1ol00002ooooo`;o00003?ooool2o`0004Sooooo000Looooo`03o`000?oo
oooooooo03oooooo0ol00003ooooo`Co00000oooool7o`0000_ooooo0_l00008ooooo`;o00000ooo
ool3o`0000Cooooo1Ol0000Fooooo`;o000000?oooooo`000?l000003_l00002ooooo`?o00001?oo
ool2o`0000Oooooo0_l0000:ooooo`?o00000_ooool4o`000003ooooool0003o000000Oooooo0_l0
000;ooooo`;o00001_ooool2o`000004ooooool0003o0000ooooo`;o000000Coooooo`000?l0003o
0000EOooool001cooooo00?o0000ooooooooool0>oooool2o`0000;ooooo0ol00003ooooo`Co0000
0oooool4o`000003ooooool0003o000000gooooo0_l00005ooooo`Co00002_ooool2o`0001Wooooo
5?l000000ooooooo0000o`000004ooooo`;o00001oooool2o`0000oooooo0_l00003ooooo`Go0000
1?ooool2o`0000;ooooo0_l00007ooooo`;o00000_ooool3o`000003ooooool0003o000000Cooooo
0_l000001?oooooo0000o`000?l0001Eooooo`007?ooool00ol0003oooooooooo`0kooooo`;o0000
2?ooool4o`00017ooooo0_l00004ooooo`;o00001Oooool4o`0000Oooooo0_l0000:ooooo`;o0000
3Oooool2o`000003ooooool0003o000001Go00005?ooool2o`0000kooooo1?l00004ooooo`;o0000
0_ooool2o`0000?ooooo0_l000001?oooooo0000o`000?l00002ooooo`?o000000?oooooo`000?l0
00001oooool2o`0000_ooooo0ol00018ooooo`007?ooool00ol0003oooooooooo`1Jooooo`;o0000
1_ooool4o`000003ooooool0003o000000?o00001_ooool2o`0000Gooooo1?l000000ooooooo0000
o`00000=oooooaWo00003_ooool3o`0000Cooooo0_l00007ooooo`;o00001Oooool2o`000003oooo
ool0003o000000?ooooo0_l00007ooooo`;o000000?oooooo`000?l000004_ooool2o`0000Wooooo
0ol00018ooooo`007?ooool00ol0003oooooooooo`1?ooooo`;o00004Oooool4o`000003ooooool0
003o000000?o00001Oooool2o`0000?ooooo1ol00003ooooo`;o00001oooool2o`0000?ooooo5ol0
0003ooooo`;o00002_ooool3o`0000Sooooo0_l00003ooooo`;o00001Oooool5o`0002?ooooo0_l0
001Dooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00002?ooool6o`0000Sooooo1?l00005
ooooo`;o00002oooool6o`0000Kooooo0_l00003ooooo`Go00001Oooool2o`0000Oooooo0_l00003
oooooaWo000000?oooooo`000?l000000_l00004ooooo`?o000000?oooooo`000?l000002Oooool3
o`0000[ooooo0_l000001?oooooo0000o`000?ooool2o`0000Cooooo0_l0000Looooo`;o00000ooo
ool2o`0004cooooo000Looooo`03o`000?oooooooooo03Oooooo0_l00006ooooo`Wo00001Oooool2
o`0000;ooooo0_l00005ooooo`;o00002Oooool7o`0000oooooo1_l000001?oooooo0000o`000?oo
ool2o`0000Wooooo6_l00002ooooo`;o000000Coooooo`000?l0003ooooo0ol000000ooooooo0000
o`00000:ooooo`;o00000oooool2o`0000Sooooo0_l000000ooooooo0000o`000004ooooo`;o0000
1oooool2o`0001?ooooo0_l00003ooooo`;o0000C?ooool001cooooo0_l00010ooooo`;o00001?oo
ool3o`0000Gooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l00009ooooo`Oo0000
1oooool2o`0000Sooooo1?l00004ooooo`;o00000_ooool2o`0000?ooooo4?l000000ooooooo0000
o`000009o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00001oooool2o`0000Wooooo
0_l00002ooooo`;o00002?ooool2o`0000[ooooo1?l0000Booooo`;o00000_ooool2o`0004kooooo
000Looooo`03o`000?oooooooooo03[ooooo0_l00009ooooo`;o000000?oooooo`000?l000001_oo
ool2o`000003ooooool0003o000000?ooooo0_l00008ooooo`;o00000_ooool3o`0000Sooooo0_l0
000Dooooo`;o000000?oooooo`000?l000004?l000000ooooooo0000o`00000;o`0000?ooooo1?l0
0009ooooo`;o00001_ooool2o`000003ooooool0003o000000;ooooo0_l00005ooooo`;o000000?o
ooooo`000?l000001?ooool2o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o00003Ooo
ool2o`0000;ooooo0ol0001=ooooo`007?ooool00ol0003oooooooooo`0gooooo`;o000000?ooooo
o`000?l000003?ooool2o`0000_ooooo1Ol00008ooooo`;o00000oooool2o`0001kooooo0_l00000
0ooooooo0000o`00000?o`0000;ooooo3Ol00003ooooo`Co00004Oooool2o`000003ooooool0003o
000000Wooooo0_l00007ooooo`;o00001oooool2o`0000;ooooo0_l0000Aooooo`?o0000COooool0
01cooooo00?o0000ooooooooool0=oooool2o`0000?ooooo0_l0000Gooooo`Go00001oooool2o`00
01;ooooo0_l000000ooooooo0000o`00000=ooooo`;o00000oooool7o`000003ooooool0003o0000
01?o00000oooool6o`0000[ooooo0_l0000Booooo`;o00001Oooool2o`0000Wooooo0_l0001Uoooo
o`007?ooool00ol0003oooooooooo`0looooo`;o00008oooool5o`0000gooooo1?l000000ooooooo
0000o`00000:ooooo`;o00001_oooolLo`0000Cooooo1_l0000:ooooo`;o000000?oooooo`000?l0
00002?ooool2o`000003ooooool0003o000000?ooooo0_l00004ooooo`;o00002Oooool2o`0000?o
oooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00001oooool3o`0000Sooooo
0_l00006ooooo`;o00001oooool2o`0000Wooooo1ol0000;ooooo`?o00003_ooool2o`0000Gooooo
7?l0000Hooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`;o0000
1?ooool4o`0000cooooo0_l0000>ooooo`;o00003oooool2o`0003oooooo000Looooo`03o`000?oo
oooooooo037ooooo0_l00007ooooo`?o00002?ooool2o`0000Kooooo0_l000000ooooooo0000o`00
0002ooooo`Co00000oooool2o`0000Cooooo0_l00003ooooo`;o00003?ooool2o`0001?ooooo7Ol0
00000ooooooo0000o`000006ooooo`;o00003?ooool2o`0000;ooooo1_l000000ooooooo0000o`00
0003o`000003ooooool0003o000000;o00000oooool6o`0001cooooo0ol0000>ooooo`;o0000?ooo
ool001cooooo00?o0000ooooooooool0<?ooool2o`0000;ooooo0_l0000Jooooo`;o00000_ooool3
o`0000Cooooo0_l00006ooooo`;o00006?ooool2o`0000Cooooo1?l00002ooooo`;o000000?ooooo
o`000?l000005_l00003ooooo`;o00001_ooool2o`0000Sooooo0_l00002ooooo`;o000000?ooooo
o`000?l000000_l000001?oooooo0000o`000?ooool5o`000003ooooool0003o000000;o00000_oo
ool3o`0000;ooooo0_l0000:ooooo`;o00004?ooool3o`0004oooooo000Looooo`03o`000?oooooo
oooo033ooooo0_l00002ooooo`;o00001Oooool2o`0001Gooooo0_l000000ooooooo0000o`000002
ooooo`;o00002?ooool2o`0001Gooooo0_l000001?oooooo0000o`000?l00003ooooo`Co00001Ooo
ool3o`000003ooooool0003o0000017o000000Coooooo`000?l0003ooooo0_l0000@ooooo`;o0000
1Oooool4o`000004ooooool0003o0000ooooo`Ko000000Goooooo`000?l0003o0000ooooo`04o`00
00Sooooo0_l00004ooooo`;o00001?ooool2o`0005cooooo000Looooo`03o`000?oooooooooo02oo
oooo0_l0000:ooooo`;o00000oooool2o`00013ooooo0_l00004ooooo`?o00001Oooool4o`0000ko
oooo0_l00004ooooo`So00002ooooolHo`000003ooooool0003o000000[ooooo0_l0000?oooooa7o
000000?oooooo`000?l000000ol00002ooooo`?o00000_ooool2o`0000Gooooo0_l00003ooooo`;o
0000G?ooool001cooooo00?o0000ooooooooool0;_ooool3o`0000Oooooo0_l00006ooooo`;o0000
0oooool2o`0000gooooo0_l00002ooooo`?o00001Oooool4o`000003ooooool0003o000000Sooooo
0_l000000ooooooo0000o`000003ooooo`?o00000_ooool3o`0000cooooo0_l000000ooooooo0000
o`00000@o`000003ooooool0003o000000?o00002_ooool2o`0000;ooooo0_l00008ooooo`?o0000
0_oooolEo`0000;ooooo0ol00009ooooo`;o00002oooool2o`0005Cooooo000Looooo`03o`000?oo
oooooooo02[ooooo0_l00002ooooo`?o00001oooool3o`0000Kooooo0_l00002ooooo`;o00003?oo
ool3o`0000Cooooo0_l00002ooooo`;o00001Oooool2o`0000Sooooo0_l00006ooooo`;o00001?oo
ool2o`000003ooooool0003o000000;ooooo0_l00006oooooaWo00003oooool2o`0000Kooooo6?l0
0005ooooo`Go00005Oooool2o`0005Cooooo000Looooo`03o`000?oooooooooo02[ooooo0_l0000;
ooooo`Co00001_ooool2o`000003ooooool0003o000000gooooo1?l000000ooooooo0000o`000002
o`0000;ooooo0_l00003ooooo`;o00005?ooool2o`0000Gooooo0_l00002ooooo`;o00001_oooolI
o`0000Wooooo0ol000000ooooooo0000o`000008ooooo`;o000000?oooooo`000?l000005Ol00003
ooooo`;o000000?oooooo`000?l000002Oooool4o`0000cooooo1?l0000>ooooo`;o0000?_ooool0
01cooooo00?o0000ooooooooool0=_ooool3o`0000_ooooo0_l00003ooooo`Ko00001_ooool8o`00
0003ooooool0003o000000?ooooo0ol0000Cooooo`;o00004oooool5o`000003ooooool0003o0000
00So000000?oooooo`000?l000000_l00007ooooo`;o00000_ooool3o`000004ooooool0003o0000
ooooo`;o00001?ooool2o`0000Gooooo5_l0000=ooooo`So00002_ooool4o`0000kooooo0_l0000n
ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo00Cooooo00?o0000ooooooooool0;?ooool2o`000003ooooool0003o000000Gooooo0_l0
0003ooooo`;o00003?ooool8o`0000Cooooo2?l00007ooooo`;o00002?ooool2o`0000?ooooo0_l0
000Fooooo`;o00001oooool9o`0000;ooooo0ol00008ooooo`;o00001_ooool2o`000003ooooool0
003o000000Cooooo0_l000000ooooooo0000o`00000Ho`000003ooooool0003o000000[ooooo0_l0
0004ooooo`;o00001_ooool2o`0000Sooooo0_l00006ooooo`;o000000?oooooo`000?l00000?ooo
ool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0/ooooo`;o000000?oooooo`000?l000002_ooool2o`0001;ooooo
0_l00003ooooo`Oo00000oooool2o`0000kooooo0_l00003ooooo`;o00002Oooool2o`0000Cooooo
0ol00004ooooo`;o00001_ooool2o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0000kooooo
1?l0000:oooooa[o000000?oooooo`000?l000001?ooool2o`0000[ooooo0_l00006ooooo`;o0000
2?ooool2o`0000Kooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o0000>oooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo00?o0000ooooooooool0
<?ooool2o`0000?ooooo0_l00006ooooo`;o00002_ooool2o`0000Kooooo0_l000000ooooooo0000
o`000002o`000003ooooool0003o000000?ooooo0_l00006ooooo`;o00001_ooool2o`0000Oooooo
0ol00004ooooo`;o00000oooool4o`0000Wooooo0_l000000ooooooo0000o`000002ooooo`Co0000
4oooool4o`0000Wooooo0_l000000ooooooo0000o`00000Ko`000004ooooool0003o0000ooooo`;o
00003?ooool2o`0000gooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0ol000000ooo
oooo0000o`00000kooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04
odA4A?oMgMgoooooo`0000Oooooo0ol0000`ooooo`;o00000oooool2o`0000Kooooo0_l0000:oooo
o`;o00001Oooool3o`0000kooooo0_l00003ooooo`Co00001?ooool2o`0000Oooooo0ol00009oooo
o`;o00001_ooool2o`0000?ooooo0_l00007ooooo`;o00004oooool4o`0000Sooooo9?l0000?oooo
o`;o00003Oooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0003oooooo00000ooo
oooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo00001oooool0
0ol0003oooooooooo`0Tooooo`;o00009_ooool2o`000003ooooool0003o000000?o00003?ooool3
o`000003ooooool0003o000000;ooooo0_l00007ooooo`;o00003oooool2o`0000Oooooo0_l00004
ooooo`;o00000oooool2o`000003ooooool0003o000000gooooo0ol00003ooooo`;o00001oooool2
o`000003ooooool0003o000000go000000?oooooo`000?l000004Ol0000Looooo`;o0000C_ooool0
0003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00omgMgOoc<c<o`000007oooo
o`03o`000?oooooooooo02Cooooo0_l00006ooooo`;o00004oooool2o`0000Wooooo1Ol000000ooo
oooo0000o`000008ooooo`;o00000_ooool2o`0000;ooooo0_l00005ooooo`;o00000_ooool4o`00
00cooooo1Ol00002ooooo`;o00002Oooool2o`0000?ooooo0_l00004ooooo`;o00002_ooool3o`00
00?ooooo0_l00006ooooo`?o000000?oooooo`000?l000004?l000000ooooooo0000o`00000:o`00
00;ooooo1?l0000Jooooo`;o00003?ooool2o`00043ooooo00001_ooooooMgMgoiRHV?ooooooV9RH
ogMgM`cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0/ooooo`;o000000?ooooo
o`000?l000002Oooool2o`0000Gooooo0_l00007ooooo`;o000000Coooooo`000?l0003o00003?oo
ool2o`0000gooooo0_l00002ooooo`Co00003?ooool4o`000003ooooool0003o000000;o00004ooo
ool3o`0000gooooo0_l00009ooooo`;o00001OoooolNo`0000;ooooo0_l000000ooooooo0000o`00
0005ooooo`Co00004Oooool2o`0000?ooooo0_l00004ooooo`;o0000@?ooool00006ooooooo^k^ko
<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo02oooooo
0_l00009ooooo`Co00001oooool2o`0000?ooooo0_l0000=ooooo`;o000000?oooooo`000?l00000
2oooool2o`0001Wooooo0_l000000ooooooo0000o`000007ooooo`;o00002Oooool2o`0000kooooo
1?l0000:oooooaSo00000_ooool8o`0000Gooooo0_l00005ooooo`Co00004Oooool2o`0000?ooooo
0_l00003ooooo`?o0000@?ooool001cooooo00?o0000ooooooooool0??ooool2o`0000Oooooo1?l0
00000ooooooo0000o`000002o`0000Gooooo0_l00004ooooo`;o00003_ooool2o`0001_ooooo0ol0
0007ooooo`;o00006_ooool3o`0000;ooooo0_l00006ooooobCo00001Oooool2o`0000?ooooo0ol0
000Booooo`;o00002?ooool3o`00043ooooo000Looooo`03o`000?oooooooooo03Cooooo1?l00006
ooooo`;o00001oooool2o`000003ooooool0003o000000Co00000oooool2o`0000;ooooo0_l00004
ooooo`;o00002_ooool3o`0001Oooooo0_l000000ooooooo0000o`000008ooooo`;o00006Oooool2
o`0000Cooooo0ol000001Ooooooo0000o`000?l0003ooooo00Co000000?oooooo`000?l000003?l0
0002oooooa3o00001?ooool3o`0000?ooooo0_l0000Booooo`;o00001Oooool2o`0000;ooooo0ol0
000oooooo`007?ooool00ol0003oooooooooo`0dooooo`Co00001_ooool2o`0000Kooooo0ol00005
ooooo`;o00001oooool2o`0000;ooooo1?l00006ooooo`;o00000oooool3o`000004ooooool0003o
0000ooooo`Co00003?ooool4o`0000[ooooo0ol00009ooooo`;o00001oooool2o`0000Cooooo1?l0
0004ooooo`;o000000Goooooo`000?l0003o0000ooooo`05o`0000;ooooo6_l000001?oooooo0000
o`000?l00004ooooo`Oo00005_ooool2o`000005ooooool0003o0000o`000?ooool01?l0000Aoooo
o`;o0000;?ooool001cooooo00?o0000ooooooooool0=?ooool2o`00013ooooo0ol00005ooooo`;o
00002oooool2o`0000Sooooo0_l00002ooooo`Co000000Coooooo`000?l0003ooooo1?l000000ooo
oooo0000o`000009ooooo`?o00002oooool2o`0000[ooooo0_l00007ooooo`;o000000Coooooo`00
0?l0003ooooo1?l0000;ooooo`;o000000?oooooo`000?l000001?l000000ooooooo0000o`00000E
o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l000000_l0000Fooooo`;o000000?ooooo
o`000?l000000_ooool3o`0001;ooooo0_l0000/ooooo`007?ooool00ol0003oooooooooo`0coooo
o`?o000000?oooooo`000?l000002?ooool2o`0000;ooooo0_l0000Pooooo`Co000000?oooooo`00
0?l000001Ol00003ooooo`;o0000:_ooool2o`0000?ooooo0_l000000ooooooo0000o`00000:oooo
o`;o000000Goooooo`000?l0003o0000ooooo`0Mo`0000Cooooo0_l00007ooooo`;o00005_ooool2
o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l00000>oooool001cooooo00?o0000oooo
ooooool0<_ooool3o`0000;ooooo0ol00005ooooo`Co00000_ooool2o`0000Kooooo0_l00008oooo
o`;o00001?ooool3o`000005ooooool0003o0000o`000?ooool01Ol00002ooooo`Wo0000;Oooool2
o`0000?ooooo0_l000000ooooooo0000o`00000:ooooo`Ko00000ooooolKo`0000Cooooo0_l00007
ooooo`;o00004oooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o000000Cooooo
o`000?l0003ooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0Yooooo`;o00001oooool2
o`0000?ooooo1_l00002ooooo`;o00002Oooool5o`0000Sooooo0_l00003ooooo`So000000?ooooo
o`000?l000004Ol00005ooooo`;o00001?ooool2o`0000oooooo0_l00009ooooo`;o00000_ooool2
o`0000;ooooo0_l0000>ooooo`Co00001?ooool4o`000003ooooool0003o000001;o00000_ooool2
o`0000;ooooo0_l0000Jooooo`Co00001?ooool2o`0000_ooooo0_l0000hooooo`007?ooool00ol0
003oooooooooo`0Yooooo`;o00001oooool2o`0000Cooooo1Ol00005ooooo`?o00001Oooool4o`00
0004ooooool0003o0000o`0000[ooooo0_l000000ooooooo0000o`000002o`0000;ooooo4ol00005
ooooo`;o00001?ooool2o`0000oooooo0_l00009ooooo`;o000000Coooooo`000?l0003o00001_oo
ool2o`000003ooooool0003o000000Oooooo0_l00002ooooo`;o00000_oooolHo`0000?ooooo0_l0
000Kooooo`;o000000?oooooo`000?l000001Oooool5o`0000?ooooo0_l0000nooooo`007?ooool0
0ol0003oooooooooo`0dooooo`;o00003?ooool3o`0000[ooooo0ol00002ooooo`;o00001_ooool2
o`0000Oooooo1_l00002ooooo`_o000000?oooooo`000?l000002oooool2o`0000;ooooo0_l00000
0ooooooo0000o`000009ooooo`Co00001_ooool2o`0000Oooooo0_l000000ooooooo0000o`00000;
ooooo`;o00000ooooolGo`0000Kooooo0_l0000Hooooo`;o00002?ooool2o`000003ooooool0003o
000000?ooooo0_l00007ooooo`;o0000=Oooool001cooooo00?o0000ooooooooool0=?ooool2o`00
00[ooooo0_l0000Booooo`;o00001_ooool2o`0000Oooooo5_l0000;ooooo`;o00000_ooool2o`00
0003ooooool0003o000000Sooooo1Ol0000>ooooo`;o00000_ooool2o`0000kooooo0_l000000ooo
oooo0000o`00000Ao`000003ooooool0003o000000Kooooo0_l000000ooooooo0000o`00000Uoooo
o`;o00002Oooool2o`0003Gooooo000Looooo`03o`000?oooooooooo03?ooooo0_l0000;ooooo`;o
00003Oooool2o`0000Wooooo0_l00008ooooo`?o000000?oooooo`000?l000004ol00009ooooo`;o
000000Coooooo`000?l0003o00002oooool2o`00013ooooo0ol00002ooooo`;o00003_ooool2o`00
0003ooooool0003o000001Co00000oooool2o`0000Cooooo0_l0000Hooooo`;o00002oooool2o`00
00Wooooo0_l0000eooooo`007?ooool2o`00037ooooo0_l000000ooooooo0000o`000004ooooo`?o
00001_ooool2o`0000Cooooo1?l00003ooooo`;o00002Oooool2o`0000Sooooo6Ol00009ooooo`;o
000000Coooooo`000?l0003o00000oooool2o`0001Sooooo0ol0000BoooooaOo00000oooool4o`00
00Sooooo0_l0000Dooooo`;o00005_ooool2o`0003Gooooo000Looooo`03o`000?oooooooooo033o
oooo0_l000000ooooooo0000o`000004ooooo`?o00001_ooool2o`0000Cooooo1?l0000>ooooo`;o
00002?ooool5o`000003ooooool0003o0000017o00001oooool2o`0000Kooooo0_l000000ooooooo
0000o`00000Dooooo`Oo00001?ooool2o`0000cooooo1?l000000ooooooo0000o`000007o`000003
ooooool0003o000000Oo00000_ooool2o`0000Oooooo0_l000000ooooooo0000o`00001Sooooo`00
7?ooool00ol0003oooooooooo`0aooooo`Co00003Oooool2o`0000cooooo0ol0000@oooooaOo0000
00Coooooo`000?l0003o00001_ooool2o`0000Kooooo0_l0000Fooooo`So00001?ooool2o`0000co
oooo0_l00004ooooo`;o00000_ooool?o`0000Gooooo0_l00003ooooo`;o00007oooool2o`0004Go
oooo000Looooo`03o`000?oooooooooo037ooooo0_l00002ooooo`;o00002oooool2o`0000cooooo
0ol00002ooooo`Go00002OoooolLo`0000Wooooo0_l0000Iooooo`Oo00006oooool2o`000004oooo
ool0003o0000ooooo`Oo000000?oooooo`000?l000000_l00005ooooo`;o00006?ooool2o`0000[o
oooo0_l00008ooooo`Go0000>?ooool001cooooo00?o0000ooooooooool0=Oooool2o`0000gooooo
0_l0000?ooooo`Go00002?oooolMo`0000Wooooo0_l00007ooooo`;o00000_ooool2o`0000cooooo
0_l000001?oooooo0000o`000?l0000Looooo`[o00000_ooool4o`0000Gooooo0_l0000Jooooo`;o
00001Oooool2o`0000;ooooo0ol00007ooooo`Ko0000>?ooool001cooooo00?o0000ooooooooool0
??ooool2o`0000Kooooo0_l0000Gooooob;o000000?oooooo`000?l000000_l0000=ooooo`;o0000
0_ooool2o`0000Oooooo0_l00002ooooo`;o00006oooool2o`0000Kooooo1Ol00005ooooo`?o0000
1_ooool2o`0000;ooooo0_l0000Mooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o0000
00?oooooo`000?l00000??ooool001cooooo00?o0000ooooooooool0??ooool2o`0000Kooooo0_l0
000GoooooaCo000000?oooooo`000?l000002ol000000ooooooo0000o`000002o`0000kooooo0_l0
000:ooooo`;o00000_ooool2o`0000[ooooo0_l00009ooooo`;o00001?ooool6o`0000?ooooo1?l0
0007ooooo`;o00002Oooool2o`00023ooooo0_l00006ooooo`;o0000?oooool001cooooo00?o0000
ooooooooool0;oooool2o`000003ooooool0003o000000_ooooo0_l00003ooooo`;o000000Cooooo
o`000?l0003o00003Oooool2o`0000[ooooo3?l00002ooooo`ko00004?ooool2o`000003ooooool0
003o000000oooooo0_l00002ooooo`;o00001Oooool2o`0000Wooooo0_l00003ooooo`Oo00000ooo
ool4o`0000Oooooo0ol0000Uooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0;oooool2
o`000003ooooool0003o000000_ooooo0_l00004ooooo`Go00003Oooool2o`0000Oooooo7_l0000A
ooooo`;o00003Oooool2o`000003ooooool0003o000000;o00000_ooool2o`0000_ooooo0_l00006
ooooo`Co00001?ooool6o`000003ooooool0003o000000Oooooo0_l0000;ooooo`;o00004Oooool2
o`0000Gooooo0ol0001;ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00000oooool2o`00
00Sooooo0_l00005ooooo`Co00004oooool2o`0000;ooooo5?l00002ooooo`co00000_ooool2o`00
00;ooooo0_l0000?ooooo`;o00000oooool2o`000003ooooool0003o000000Oooooo0_l00002oooo
o`;o00000_ooool6o`0000Cooooo0_l00006ooooo`Co000000?oooooo`000?l000000_l00007oooo
o`;o00002oooool2o`00017ooooo0_l00002ooooo`;o00000_ooool5o`0004Sooooo000Looooo`03
o`000?oooooooooo03Cooooo0_l00007ooooo`?o00001oooool2o`0001?ooooo0_l00002oooooaCo
00000oooool3o`000003ooooool0003o000000Go00000_ooool2o`0000;ooooo1?l0000=ooooo`;o
00003oooool2o`0000;ooooo0_l00002ooooo`Ko00000_ooool2o`0000cooooo1?l00004ooooo`;o
00008oooool5o`0000Cooooo0ol00002ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0
6oooool2o`0000kooooo1_l0000<ooooo`Co00003?ooool3o`0000kooooo7ol000000ooooooo0000
o`000002o`0000Sooooo0_l0000<ooooo`;o000000?oooooo`000?l000000_ooool5o`0000[ooooo
0_l0000:ooooo`;o00002?ooool2o`0000;ooooo1?l00004ooooo`;o00000_ooool2o`000003oooo
ool0003o000000;ooooo0_l00004ooooo`;o00004_ooool4o`0000[ooooo0_l00014ooooo`007?oo
ool00ol0003oooooooooo`0Kooooo`;o00003_ooool6o`0000cooooo1?l0000<ooooo`Co00000_oo
ool2o`0000Sooooo0ol000000ooooooo0000o`00000Jo`000003ooooool0003o000000;o00000_oo
ool4o`0000[ooooo0_l00004ooooo`;o000000?oooooo`000?l000000_ooool5o`00023ooooo0_l0
0003ooooo`?o00002?ooool2o`000005ooooool0003o0000o`000?ooool00_l00004ooooo`;o0000
7?ooool2o`0000Oooooo0_l00002ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0=_oo
ool2o`0000oooooo0_l00006ooooo`;o00000_ooool2o`0000Sooooo0_l00002oooooaco000000?o
ooooo`000?l000000_l00002ooooo`Co000000?oooooo`000?l000001oooool2o`0000Wooooo0_l0
0006ooooo`;o00002_ooool2o`0000Sooooo0_l000000ooooooo0000o`00000:ooooo`;o00003?oo
ool2o`000003ooooool0003o000001_ooooo0_l00005ooooo`;o00001?ooool2o`000003ooooool0
003o000000;ooooo0ol0000jooooo`007?ooool00ol0003oooooooooo`0eooooo`?o00002oooool2
o`0000;ooooo0_l00003ooooo`;o00005OoooolMo`0000Kooooo0_l000000ooooooo0000o`000007
ooooo`;o00001Oooool2o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o00002_ooool2
o`0000Sooooo0_l000000ooooooo0000o`00000;ooooo`;o00004oooool2o`0001Kooooo0_l0000;
ooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo0_l00004ooooo`;o0000;oooool0
01cooooo00?o0000ooooooooool0;Oooool2o`0000Kooooo0_l00005ooooo`;o00001?ooool3o`00
00Oooooo0_l00007ooooo`;o00003?oooolLo`0000Oooooo0_l0000:ooooo`;o00001?ooool3o`00
00Cooooo1ol00004ooooo`;o000000?oooooo`000?l000001oooool2o`0000Cooooo0_l00007oooo
o`;o00001?ooool2o`0001?ooooo0_l0000Eooooo`;o00000oooool2o`0000Gooooo0_l0000=oooo
o`;o00001?ooool2o`0002oooooo000Looooo`;o0000;_ooool2o`0000cooooo0ol00004ooooo`?o
00004?ooool2o`0000cooooo0_l000000ooooooo0000o`00000Do`000003ooooool0003o000000go
oooo0_l00002ooooo`Go00000oooool2o`0000Gooooo1ol00004ooooo`;o000000?oooooo`000?l0
00001oooool2o`0000Cooooo0_l00007ooooo`;o0000<?ooool2o`0000?ooooo0_l00005ooooo`;o
00001?ooool2o`0003kooooo000Looooo`03o`000?oooooooooo03?ooooo0_l00003ooooo`;o0000
00?oooooo`000?l000001_ooool2o`0000Gooooo0_l0000>ooooo`;o00001_ooool3o`0000?ooooo
5_l0000>ooooo`;o00000_ooool5o`0000Sooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo
0ol00002ooooo`;o00001Oooool2o`0000Wooooo0_l00010ooooo`?o00000oooool2o`0003kooooo
000Looooo`03o`000?oooooooooo02oooooo0_l00002ooooo`?o00000_ooool2o`0000Kooooo0_l0
0008ooooo`;o00002Oooool2o`0000?ooooo0_l00006oooooago00002_ooool2o`0000Kooooo0_l0
000:ooooo`;o00001oooool4o`000003ooooool0003o000000Co00000_ooool2o`000003ooooool0
003o000000Oooooo1?l0000=ooooo`;o00002_ooool2o`0000Gooooo0_l0000Nooooo`?o00002?oo
ool2o`0000?ooooo0_l0000dooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00000_ooool4
o`0000Wooooo0ol000000ooooooo0000o`000004ooooo`;o00001_ooool2o`000003ooooool0003o
000000Sooooo0_l00003ooooo`Go000000?oooooo`000?l000003Ol000001?oooooo0000o`000?oo
ool2o`0000[ooooo0_l0000Booooo`;o00002Oooool2o`0000?ooooo0_l00004ooooo`;o000000?o
ooooo`000?l000001?ooool2o`000003ooooool0003o000000Cooooo0_l00009ooooo`;o00002_oo
ool2o`0000Gooooo0_l0000Wooooo`Co00000oooool2o`0003Cooooo000Looooo`03o`000?oooooo
oooo03;ooooo0_l000000ooooooo0000o`000008ooooo`Co000000?oooooo`000?l000000oooool3
o`0000Gooooo0ol0000;ooooo`;o00001_ooool=o`000003ooooool0003o000000;o00002Oooool2
o`00013ooooo0_l0000>ooooo`;o00003Oooool2o`0000Oooooo1?l000000ooooooo0000o`000002
ooooo`?o00002?ooool2o`0000Cooooo0ol00008ooooo`;o00003oooool2o`0000kooooo0_l00008
ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0:_ooool2o`0000Kooooo0_l0000;oooo
o`;o00001Oooool2o`000003ooooool0003o000000;o00000_ooool6o`0000[ooooo0_l00007oooo
o`;o00002Oooool4o`0000_ooooo0_l0000@ooooo`;o00002_ooool2o`0000;ooooo0_l000000ooo
oooo0000o`00000:ooooo`;o00001oooool4o`000003ooooool0003o000000;ooooo0ol00008oooo
o`;o00001?ooool3o`0000Sooooo0_l0000?ooooo`;o00003_ooool2o`0004Gooooo000Looooo`03
o`000?oooooooooo02[ooooo0_l0000=ooooo`?o000000?oooooo`000?l000000_l00005ooooo`;o
00000oooool2o`0000;ooooo0_l00002ooooo`;o00002_ooool4o`0000Wooooo1?l00003ooooo`;o
00001Oooool2o`0000Oooooo0_l0000Fooooo`;o00000oooool2o`0000Gooooo0_l00005ooooo`;o
00002Oooool2o`000004ooooool0003o0000o`0000?ooooo0_l000001?oooooo0000o`000?l0000a
ooooo`?o00000_ooool2o`0004Wooooo000Looooo`03o`000?oooooooooo03Sooooo1?l000001?oo
oooo0000o`000?l0000;ooooo`;o00001_ooool2o`0000Wooooo0_l000000ooooooo0000o`000009
ooooo`Co00002?ooool6o`0000Gooooo0_l00004ooooo`;o000000?oooooo`000?l000003Oooool3
o`0000[ooooo0_l00004ooooo`;o00001Oooool2o`0000;ooooo1Ol00004ooooo`Go00002_ooool2
o`0000Cooooo0_l00008ooooo`;o00000_ooool2o`0001;ooooo0ol00002ooooo`;o00001Oooool2
o`0000;ooooo0_l00003ooooo`;o0000>Oooool001cooooo00?o0000ooooooooool0;oooool2o`00
00?ooooo0_l00002ooooo`;o00004Oooool2o`0000Cooooo0_l0000;ooooo`;o00006?ooool2o`00
00;ooooo0_l00007ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000[ooooo0_l00002
ooooo`;o00001_ooool2o`0000;ooooo0_l00004ooooo`;o00001Oooool3o`0000;ooooo0ol00000
0ooooooo0000o`000002o`000004ooooool0003o0000o`0000_ooooo0_l00004ooooo`;o00002?oo
ool2o`0000;ooooo0_l0000=ooooo`?o00003_ooool2o`0000;ooooo0_l00003ooooo`;o0000>Ooo
ool001cooooo00?o0000ooooooooool0;oooool2o`0000?ooooo0_l00007ooooo`;o00003?ooool2
o`0000Cooooo0_l0000Zooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`Ko00002_oo
ool2o`0000Oooooo0_l000000ooooooo0000o`000003ooooo`Co000000?oooooo`000?l000000_l0
0004ooooo`Oo000000?oooooo`000?l000000_l000001?oooooo0000o`000?l0000Mooooo`Co0000
3Oooool3o`0000?ooooo0_l00008ooooo`;o00004oooool2o`0002kooooo000Looooo`03o`000?oo
oooooooo03;ooooo0_l00005ooooo`Ko0000>?ooool2o`0000Cooooo0_l00003ooooo`;o000000Co
ooooo`000?l0003ooooo1?l0000;ooooo`;o00002?ooool2o`0000Kooooo1?l00003ooooo`;o0000
1?ooool7o`0000?ooooo1_l00005ooooo`;o00002_ooool2o`0000[ooooo1?l0000>ooooo`;o0000
0oooool4o`0000;ooooo0_l00002ooooo`;o00004oooool2o`0002kooooo000Looooo`03o`000?oo
oooooooo03;ooooo0_l00005ooooo`Co00003Oooool3o`00017ooooo0_l0000=ooooo`;o00001?oo
ool6o`0000Wooooo0_l0000Cooooo`;o00006Oooool2o`000003ooooool0003o000000;o000000Go
ooooo`000?l0003o0000ooooo`08o`0000;ooooo0_l000000ooooooo0000o`00000:ooooo`;o0000
7?ooool2o`0000Gooooo0_l00002ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0@ooo
ool2o`0000Gooooo1?l0000=ooooo`;o000000?oooooo`000?l000003Oooool4o`0000;ooooo1?l0
000;ooooo`;o00001Oooool2o`0000gooooo0_l00003ooooo`;o00004oooool7o`0000Cooooo1_l0
0002ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Fooooo`;o00000_ooool2o`0000cooooo
0_l00006ooooo`Co0000B?ooool001cooooo00?o0000ooooooooool0<?ooool2o`00017ooooo0_l0
0007ooooo`;o00003Oooool2o`0001;ooooo0_l00009ooooo`;o00000oooool3o`0000Oooooo0_l0
0007ooooo`;o00001?ooool2o`0000?ooooo0_l00007ooooo`;o00002oooool5o`0000Cooooo2ol0
000?ooooo`;o00002oooool6o`0001Cooooo1?l000001?oooooo0000o`000?l00004ooooo`;o0000
?_ooool001cooooo00?o0000ooooooooool0<?ooool2o`0000Sooooo1?l00004ooooo`;o00001?oo
ool2o`0001Cooooo0_l0000Jooooo`;o00000oooool3o`000003ooooool0003o000000Cooooo0ol0
0006ooooo`;o00004_ooool2o`0000Kooooo0_l00004ooooo`[o000000?oooooo`000?l000002_l0
000;ooooo`;o00003Oooool4o`0000Sooooo0_l00004ooooo`;o00000_ooool4o`0000?ooooo0ol0
0004ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0>_ooool5o`0000?ooooo0_l00004
ooooo`Co00004_ooool2o`0000Cooooo0_l00006ooooo`;o00002Oooool2o`0000Sooooo1?l00000
1?oooooo0000o`000?ooool3o`0000Kooooo0_l0000Booooo`;o00001_ooool2o`0000?ooooo2ol0
00000ooooooo0000o`00000:o`0001;ooooo0_l00005ooooo`Go00002?ooool2o`000003ooooool0
003o000000?o00000_ooool2o`0000Wooooo0_l0000;ooooo`;o0000=?ooool001cooooo0_l0000n
ooooo`;o00000oooool2o`0000Kooooo1?l00004ooooo`;o00001Oooool2o`0000Wooooo0_l00000
0ooooooo0000o`000003ooooo`;o00002Oooool2o`0000?ooooo0_l00003ooooo`Co000000Cooooo
o`000?l0003o00002?ooool3o`0000Wooooo0_l00007ooooo`?o00000oooool2o`000003ooooool0
003o000000;ooooo1Ol000000ooooooo0000o`000009o`000005ooooool0003o0000o`000?ooool0
1?l0000@ooooo`;o00001Oooool2o`0000kooooo0ol0000?ooooo`Co00002Oooool2o`0003Cooooo
000Looooo`03o`000?oooooooooo03[ooooo0_l0000?ooooo`?o00001?ooool2o`0000Gooooo0_l0
000<ooooo`;o00000oooool2o`0000kooooo0_l00008ooooo`?o00001_ooool4o`0000Wooooo0ol0
0004ooooo`?o000000?oooooo`000?l000001Ol000001?oooooo0000o`000?ooool6o`000003oooo
ool0003o000000go000000?oooooo`000?l000000_l0000<ooooo`?o00003_ooool2o`0000Gooooo
0_l0000;ooooo`;o00002?ooool2o`0003oooooo000Looooo`03o`000?oooooooooo03[ooooo0_l0
000?ooooo`Co00007Oooool2o`00023ooooo1?l00003ooooo`;o00001Oooool2o`000005ooooool0
003o0000o`000?ooool00ol00002ooooo`Co000000?oooooo`000?l000000oooool2o`000004oooo
ool0003o0000oooooa7o00001_ooool2o`0000Sooooo0ol0000>ooooo`;o00001Oooool2o`0000_o
oooo0_l00019ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00001Oooool2o`00013ooooo
0ol00009ooooo`;o00002Oooool2o`0000;ooooo0_l000000ooooooo0000o`00000Jooooo`;o0000
0oooool7o`0000?ooooo0_l00007ooooo`Co00002oooool3o`000003ooooool0003o000001Ko0000
00?oooooo`000?l000000oooool2o`0000Sooooo0_l0000Uooooo`;o0000Aoooool001cooooo00?o
0000ooooooooool0<oooool2o`0000Cooooo0_l0000Mooooo`;o00002Oooool2o`0000;ooooo2?l0
0007ooooo`;o00003_ooool2o`0000?ooooo1ol0000<ooooo`?o00001Oooool2o`0000Gooooo0ol0
00000ooooooo0000o`00000Ao`000003ooooool0003o000000Go00003Oooool2o`0002Gooooo0_l0
0017ooooo`007?ooool00ol0003oooooooooo`0Eooooo`;o00007?ooool2o`0000;ooooo1?l0000E
ooooo`;o00000oooool2o`00017ooooo0_l000000ooooooo0000o`000004o`0000Gooooo1Ol00006
ooooo`;o00002?ooool2o`000003ooooool0003o000000oooooo0_l00005ooooo`Wo00001?oooolG
o`000003ooooool0003o000000;o00007_ooool2o`0001Cooooo0_l00004ooooo`;o0000?_ooool0
01cooooo00?o0000ooooooooool05Oooool2o`00023ooooo0_l0000Gooooo`?o00000_ooool2o`00
01Kooooo1?l00007ooooo`Co00001Oooool2o`0000?ooooo0_l0000Oooooo`Wo00000ooooolFo`00
00;ooooo1?l000000ooooooo0000o`00000Eooooo`;o00000_ooool4o`0000gooooo0_l00005oooo
o`;o00001?ooool2o`0003kooooo000Looooo`03o`000?oooooooooo03oooooo0_l0000@ooooo`;o
00004oooool2o`0000Gooooo0_l0000;ooooo`?o00002?ooool3o`0000Gooooo1ol0000?ooooo`;o
00001?ooool7o`0000?ooooo6_l00002ooooo`?o00005Oooool2o`0000;ooooo0_l0000?ooooo`;o
0000Boooool001cooooo00?o0000ooooooooool0?oooool2o`0000Cooooo0_l00003ooooo`;o0000
00?oooooo`000?l000005oooool2o`0000_ooooo0_l00006ooooo`;o00000oooool2o`0000?ooooo
1?l00004ooooo`So00001oooool2o`0000Gooooo0_l00004ooooo`;o00000_ooool2o`0000Cooooo
7_l000001?oooooo0000o`000?ooool4o`0000Cooooo0_l00003ooooo`?o00008?ooool2o`0004;o
oooo000Looooo`03o`000?oooooooooo03Sooooo0_l0000;ooooo`;o00000oooool2o`000004oooo
ool0003o0000ooooo`;o00006?ooool2o`0000Oooooo0_l0000;ooooo`;o00001Oooool2o`0000Go
oooo0_l00003ooooo`;o00001_ooool3o`0000Cooooo0_l00007ooooo`Go000000?oooooo`000?l0
00006?l000001Ooooooo0000o`000?l0003ooooo00Co000000?oooooo`000?l000000_l000000ooo
oooo0000o`000003o`0000?ooooo0ol00008ooooo`;o00002?ooool2o`0000cooooo0_l00012oooo
o`007?ooool00ol0003oooooooooo`0hooooo`;o00004_ooool2o`0000;ooooo0_l0000Hooooo`?o
00002oooool2o`000003ooooool0003o000000?ooooo0_l00003ooooo`;o00001oooool2o`0000_o
oooo0ol00004ooooo`;o00001oooool5o`000003ooooool0003o000001Wo00000_ooool4o`0000;o
oooo1Ol000000ooooooo0000o`000002o`0000oooooo0_l00008ooooo`Co00002_ooool3o`00047o
oooo000Looooo`03o`000?oooooooooo04cooooo0_l0000Mooooo`;o00000_ooool3o`0000?ooooo
0_l000000ooooooo0000o`000003o`0000?ooooo0_l00003ooooo`;o00005Oooool2o`0000Sooooo
0_l00004oooooa3o000000?oooooo`000?l000005?l000000ooooooo0000o`000003o`0000Gooooo
0_l00003ooooo`;o00001_ooool2o`0000cooooo0ol00002ooooo`;o00001Oooool3o`00047ooooo
000Looooo`03o`000?oooooooooo03Wooooo0_l0000Nooooo`;o00003oooool3o`000003ooooool0
003o000000;o00000oooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`000003ooooool0
003o000000Sooooo0ol000001?oooooo0000o`000?l0000Cooooo`;o000000?oooooo`000?l00000
3Ol000000ooooooo0000o`00000Ho`0000_ooooo0_l00003ooooo`;o00001_ooool3o`0000Gooooo
0_l00003ooooo`Co00000_ooool2o`0004Wooooo000Looooo`03o`000?oooooooooo03Sooooo0ol0
0009ooooo`Co000000?oooooo`000?l000003_ooool3o`0000Oooooo0_l00005ooooo`;o00000_oo
ool2o`000003ooooool0003o000000Kooooo0_l000000ooooooo0000o`000003o`000003ooooool0
003o000000;o00001_ooool7o`0000Kooooo0_l0000:ooooo`?o000000?oooooo`000?l000009?l0
000Mooooo`;o00000_ooool2o`000003ooooool0003o000000?ooooo0_l00005ooooo`;o00000_oo
ool2o`0004Cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^
k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0hooooo`;o00002_ooool4o`000003
ooooool0003o000000Cooooo0_l00008ooooo`?o00001oooool2o`0000cooooo1?l00004ooooo`;o
000000?oooooo`000?l000001_ooool2o`0000Gooooo0_l000000ooooooo0000o`000002o`0000Oo
oooo0_l00002ooooo`Co00001?ooool2o`0000?ooooo2ol000000ooooooo0000o`00000;o`0000;o
oooo2_l00003ooooo`;o00007?ooool4o`0000_ooooo0ol000000ooooooo0000o`000014ooooo`00
00KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So
8B4Q00Kooooo00?o0000ooooooooool08oooool2o`0001Sooooo0_l00002ooooo`Oo00000oooool2
o`0000;ooooo0_l00008ooooo`;o00005Oooool5o`0000Cooooo1?l0000:ooooo`;o00000_ooool2
o`0000;ooooo1Ol00002ooooo`Go00000_ooool4o`0000Gooooo0_l00002ooooo`[o000000?ooooo
o`000?l000003?l000000ooooooo0000o`00000>o`0000_ooooo0_l0000Aooooo`;o00001_ooool2
o`0000?ooooo0ol000000ooooooo0000o`000014ooooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0S
ooooo`;o00006?ooool2o`0000;ooooo2?l00002ooooo`;o00005?ooool2o`0000gooooo3Ol00008
ooooo`Co00001_ooool2o`000003ooooool0003o000000;ooooo0ol00005ooooo`;o00001_ooool2
o`0000;ooooo2?l00002oooooaoo00001Oooool4o`0000?ooooo0_l0000Booooo`;o00001Oooool2
o`0000?ooooo1?l00009ooooo`;o0000>oooool00003ooooool0003ooooo00;ooooo00?o0000oooo
ooooool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol00017ooooo`?o00000_ooool2
o`0000Cooooo0_l000000ooooooo0000o`00000:ooooo`;o00003Oooool>o`0000Oooooo1Ol00000
0ooooooo0000o`000002ooooo`;o00006?ooool[o`0000Cooooo1?l00003ooooo`;o00004?ooool4
o`0000_ooooo1?l00008ooooo`;o000000?oooooo`000?l00000>?ooool00003ooooool0003ooooo
00;ooooo00?o0000ooooooooool02Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000
ooooooooool0=oooool2o`000003ooooool0003o000000[ooooo1Ol000000ooooooo0000o`000004
ooooo`;o000000?oooooo`000?l000002Oooool2o`000003ooooool0003o000000_ooooo4?l00003
ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000003ooooo`;o00005Oooool^
o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o00003?ooool2o`0000;ooooo1?l00006
ooooo`;o00001Oooool2o`0000Sooooo0_l000000ooooooo0000o`00000hooooo`0000?ooooooa0@
4?ooool00_ooool00ol@413oooooooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000oooo
ooooool0=oooool2o`000003ooooool0003o000000;ooooo0_l00006ooooo`;o000000Coooooo`00
0?l0003ooooo0_l00002ooooo`Co00003?ooool2o`000003ooooool0003o000000Sooooo0_l00002
ooooo`oo00000oooool5o`0000;ooooo0ol00003ooooo`;o00002?ooool2o`0000[ooooo7_l00002
ooooo`oo00000_ooool2o`0001Cooooo0ol0000;ooooo`;o00002?ooool2o`0000Gooooo0_l0000k
ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o
0000ooooooooool0?_ooool2o`00013ooooo1?l0000Fooooo`;o000000?oooooo`000?l000004_l0
0004ooooo`;o00000_ooool5o`0000_ooooo0ol00003ooooo`;o000000Coooooo`000?l0003ooooo
1?l000000ooooooo0000o`00000Io`000003ooooool0003o000000Oo000000?oooooo`000?l00000
1?l00009ooooo`;o00001Oooool2o`0000;ooooo0_l00002ooooo`;o00005Oooool2o`0004;ooooo
00001_ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0
003oooooooooo`0oooooo`;o00004Oooool2o`0001Kooooo0_l000000ooooooo0000o`00000Bo`00
00;ooooo0ol00003ooooo`Go00002oooool3o`0000?ooooo0_l000000ooooooo0000o`000005o`00
00?ooooo9?l000000ooooooo0000o`000003o`0000Gooooo0_l00002ooooo`;o00001Oooool2o`00
00;ooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00002?ooool2o`0000?o
oooo0_l00007ooooo`?o00004ooooolEo`000004ooooool0003o0000o`0000Gooooo0_l0000;oooo
o`;o00002_ooool2o`000003ooooool0003o000000;ooooo9_l00004ooooo`?o00000oooool2o`00
017ooooo0_l00005ooooo`;o00001Oooool3o`0000Cooooo0_l00014ooooo`007?ooool00ol0003o
ooooooooo`0eooooo`;o00004_ooool2o`0000?ooooo0_l00007ooooo`?o00000_ooool2o`0000oo
oooo5Ol000000ooooooo0000o`000006ooooo`;o00002oooool2o`0000?ooooo0_l00005ooooo`;o
00001OoooolEo`000003ooooool0003o000000ko000000Coooooo`000?l0003ooooo0ol0000@oooo
o`;o00001?ooool2o`0000Gooooo0_l00005ooooo`?o00001?ooool2o`0004Cooooo000Looooo`03
o`000?oooooooooo03Gooooo0_l00004ooooo`;o00002?ooool2o`0000Oooooo0_l00005ooooo`Co
00000oooool3o`0000cooooo0_l000000ooooooo0000o`00000Bo`000003ooooool0003o000000Ko
oooo0_l00007ooooo`;o00001oooool2o`0000Gooooo0_l00003ooooo`Co000000?oooooo`000?l0
00008Ol000001?oooooo0000o`000?ooool3o`0000Kooooo0_l00008ooooo`?o000000?oooooo`00
0?l000003_ooool2o`0000;ooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`0iooooo`Co
00002?ooool2o`0000Oooooo0ol00004ooooo`;o00000_ooool2o`0000;ooooo0_l00007ooooo`;o
00000oooool8o`000003ooooool0003o000000go00004Oooool2o`0000Cooooo0ol00004ooooo`;o
00001_ooool2o`0000?ooooo8_l000000ooooooo0000o`000004ooooo`;o00001Oooool2o`0000Ko
oooo0_l000001?oooooo0000o`000?ooool4o`0000;ooooo0_l00003ooooo`?o00001_ooool2o`00
04Oooooo000Looooo`03o`000?oooooooooo027ooooo0_l0000Fooooo`Co00001oooool2o`0000;o
oooo0_l00004ooooo`?o00001oooool5o`0000?ooooo0_l00004ooooo`;o00001?oooolGo`0000_o
oooo0ol00003ooooo`;o00001?ooool3o`0000Cooooo0_l00003ooooo`;o00001_ooool;o`000003
ooooool0003o000001Wo00000_ooool4o`0000[ooooo0ol00005ooooo`?o00000_ooool2o`000003
ooooool0003o000000?o0000Coooool001cooooo00?o0000ooooooooool08Oooool2o`0001cooooo
0_l00003ooooo`Ko00001?ooool2o`0000Sooooo1_l00002ooooo`Co00002?oooolFo`0000Oooooo
0_l00003ooooo`Go000000?oooooo`000?l000001_ooool5o`0000Gooooo0_l00005ooooobGo0000
00?oooooo`000?l000001?ooool2o`0000;ooooo0_l00005ooooo`?o00003_ooool2o`0005;ooooo
000Looooo`03o`000?oooooooooo03oooooo0_l00003ooooo`Co00001_ooool2o`0000Sooooo0_l0
0002ooooo`;o00001?ooool2o`0000Oooooo5ol00007ooooo`;o00001_ooool2o`0000Wooooo1Ol0
0008ooooo`;o000000?oooooo`000?l000006ol000000ooooooo0000o`000002o`000003ooooool0
003o000000Kooooo0_l00004ooooo`;o00001Oooool2o`0006?ooooo000Looooo`03o`000?oooooo
oooo04Cooooo0_l00002ooooo`;o00007_ooool2o`000003ooooool0003o000001Co00001_ooool2
o`0001kooooo1?l000001?oooooo0000o`000?ooool?o`0000;ooooo5_l000000ooooooo0000o`00
000Sooooo`;o0000Boooool001cooooo00?o0000ooooooooool0B?ooool2o`0001Cooooo0ol00007
ooooo`;o000000?oooooo`000?l000004ol00007ooooo`;o000000?oooooo`000?l000001?ooool2
o`0000?ooooo0_l00008ooooo`?o00001Oooool2o`0000?ooooo0_l00003ooooo`ko000000?ooooo
o`000?l000005?l0000:ooooo`;o00006_ooool2o`0000?ooooo0_l00016ooooo`007?ooool00ol0
003oooooooooo`0mooooo`;o00004oooool2o`0000Kooooo0_l00002ooooo`?o00002_oooolHo`00
0003ooooool0003o000000Cooooo0_l00004ooooo`;o000000?oooooo`000?l000000_l000001?oo
oooo0000o`000?l00004ooooo`?o00003OoooolVo`0000_ooooo0_l00004ooooo`;o00003Oooool4
o`0000?ooooo0_l00003ooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0?Oooool2o`00
00_ooooo0_l000000ooooooo0000o`000002ooooo`?o00001_ooool2o`0000oooooo6?l000000ooo
oooo0000o`000002o`0000_ooooo0ol00002ooooo`?o00002oooool4o`000005ooooool0003o0000
o`000?ooool01Ol000000ooooooo0000o`000002o`000003ooooool0003o000001Ko000000?ooooo
o`000?l000000_l00008ooooo`;o00001Oooool2o`0000;ooooo0_l00009ooooo`Co00000oooool2
o`0004_ooooo000Looooo`;o0000?_ooool2o`0000_ooooo1_l000000ooooooo0000o`00000=oooo
o`;o00002Oooool<o`000004ooooool0003o0000ooooo`So000000?oooooo`000?l000000_l00003
ooooo`;o00001oooool2o`00013ooooo3_l000000ooooooo0000o`00000Ko`0000;ooooo0ol00002
ooooo`;o00001?ooool2o`0000Wooooo0_l00007ooooo`;o000000?oooooo`000?l000002_ooool2
o`0004Gooooo000Looooo`03o`000?oooooooooo03Sooooo0_l0000Booooo`Co000000?oooooo`00
0?l000000_l0000;ooooo`;o00000_ooool2o`0000Gooooo4ol00006ooooo`;o00001Oooool2o`00
00Kooooo0_l00003ooooo`Oo00000oooool2o`0000Kooooo0_l000000ooooooo0000o`000002o`00
00Gooooo5Ol000001?oooooo0000o`000?ooool2o`0000?ooooo0_l00003ooooo`;o00003_ooool2
o`0000Oooooo0ol0000;ooooo`Co0000AOooool001cooooo00?o0000ooooooooool0>?ooool2o`00
01Cooooo0_l000000ooooooo0000o`000002o`0000oooooo0_l00006oooooaCo00001?ooool2o`00
00Cooooo1?l00005ooooo`;o00000oooool7o`0000?ooooo0_l00003ooooo`[o00001oooool6o`00
0003ooooool0003o000000_o00000oooool4o`000003ooooool0003o000000Co00003oooool2o`00
00Oooooo0_l0000<ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0C_ooool2o`000003
ooooool0003o000000Kooooo0ol00009ooooo`;o00001Oooool@o`000004ooooool0003o0000o`00
00Oooooo0_l000000ooooooo0000o`000002o`0001Oooooo2ol00008oooooa_o00000oooool4o`00
00Gooooo0_l0000Cooooo`;o0000Doooool001cooooo00?o0000ooooooooool0?Oooool2o`0001;o
oooo1?l00004ooooo`?o00002Oooool2o`0000Cooooo4Ol000000ooooooo0000o`000008ooooo`Co
00000_ooool2o`0000Gooooo0_l00003ooooo`Co00001Oooool2o`000004ooooool0003o0000oooo
o`Co00002?ooool6o`0000;ooooo1ol000000ooooooo0000o`000002o`000003ooooool0003o0000
00Go000000?oooooo`000?l000003?ooool2o`0001?ooooo0_l0001Cooooo`007?ooool00ol0003o
ooooooooo`0mooooo`;o00002?ooool2o`0000[ooooo0_l00005ooooo`;o00000_ooool2o`0000_o
oooo0_l00002ooooo`Go00001?ooool2o`0000kooooo0ol00002ooooo`;o00001Oooool4o`000003
ooooool0003o000000;o00001Oooool2o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l0
00005ol000001?oooooo0000o`000?l00002ooooo`;o0000N?ooool001cooooo00?o0000oooooooo
ool0A?ooool2o`000003ooooool0003o000000Cooooo0ol0000:ooooo`;o000000?oooooo`000?l0
00001?l00008ooooo`Co00000oooool2o`0000Cooooo1?l0000<ooooo`Co00001?ooool2o`0000?o
oooo0ol000000ooooooo0000o`000002o`0000Gooooo0ol000000ooooooo0000o`000005ooooo`;o
000000?oooooo`000?l000000_l00005ooooo`go000000?oooooo`000?l000000_ooool2o`0000;o
oooo0_l0001hooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00001oooool3o`0000[ooooo
0_l000000ooooooo0000o`000004o`0000Gooooo0_l00003ooooo`;o00000oooool2o`0000Kooooo
0_l0000>ooooo`;o00001?ooool2o`0000Oooooo1?l00005ooooo`?o00000oooool2o`0000Sooooo
0_l00003ooooo`;o00001Oooool6o`0000?ooooo0_l00002ooooo`?o000000?oooooo`000?l00000
3?ooool2o`0006[ooooo000Looooo`03o`000?oooooooooo04?ooooo0_l0000Kooooo`;o00001_oo
ool3o`0000;ooooo0_l0000Kooooo`;o00003?ooool2o`0000;ooooo0_l0000:ooooo`;o00001ooo
ool4o`0000;ooooo0ol000001?oooooo0000o`000?ooool6o`0000?ooooo0_l00003ooooo`;o0000
00?oooooo`000?l000000oooool3o`0000?ooooo0_l000000ooooooo0000o`00000Eooooo`;o0000
Doooool001cooooo00?o0000ooooooooool0@oooool2o`0001?ooooo0_l00002ooooo`;o00001_oo
ool7o`0000;ooooo0ol00006ooooo`;o00005_ooool2o`0000Sooooo0_l00002ooooo`;o00001?oo
ool2o`0000;ooooo0_l00009ooooo`Co00000_ooool3o`000003ooooool0003o000000?o000000?o
ooooo`000?l000000_ooool2o`0000Kooooo0_l00005ooooo`?o00000oooool2o`0000[ooooo0ol0
0005ooooo`;o00001?ooool2o`0000;ooooo0_l00002ooooo`;o0000Boooool001cooooo00?o0000
ooooooooool0F?ooool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000000ol00003
ooooo`Co00001_ooool4o`000003ooooool0003o000000Gooooo0_l0000:ooooo`;o00000_ooool2
o`0000kooooo0_l00002ooooo`;o00003oooool3o`000003ooooool0003o000000?o000000?ooooo
o`000?l000001?l00005ooooo`?o00005oooool3o`0000Gooooo0_l00008ooooo`;o00000_ooool2
o`0004_ooooo000Looooo`03o`000?oooooooooo05Sooooo0_l00002ooooo`;o00000oooool2o`00
00Wooooo0ol00007ooooo`Co000000?oooooo`000?l000001Oooool2o`0000;ooooo0_l00002oooo
o`;o00001_ooool2o`0002?ooooo0_l000001Ooooooo0000o`000?l0003ooooo00?o000000?ooooo
o`000?l000000ol00003ooooo`Co00004_ooool2o`0006Oooooo000Looooo`03o`000?oooooooooo
05gooooo1_l0000<ooooo`;o00000oooool2o`0000;ooooo0_l0000:ooooo`Co00000_ooool2o`00
0003ooooool0003o000000Cooooo0_l0000Cooooo`;o00001oooool2o`0000Oooooo0_l000000ooo
oooo0000o`000002o`000004ooooool0003o0000ooooo`;o00000oooool2o`0001Cooooo0_l0001W
ooooo`007?ooool00ol0003oooooooooo`1Mooooo`Ko00000oooool2o`0000Oooooo1?l000000ooo
oooo0000o`000004o`0000Kooooo0_l000001?oooooo0000o`000?l00003ooooo`;o00000_ooool5
o`000003ooooool0003o000000Sooooo0_l00009ooooo`Go00000oooool3o`0000[ooooo0_l0000:
ooooo`;o0000<Oooool2o`0004_ooooo000Looooo`03o`000?oooooooooo05?ooooo0_l00008oooo
o`;o00001oooool2o`0000Sooooo0ol000000ooooooo0000o`000002o`0000Sooooo0_l000000ooo
oooo0000o`000004ooooo`;o00000oooool4o`0000_ooooo0_l0000:ooooo`Co00000oooool2o`00
00[ooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo0_l0000Dooooo`;o00002oooool2o`00
00Oooooo0_l00005ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0C?ooool2o`0000Go
oooo0_l00008ooooo`?o00001_ooool4o`0000Kooooo0_l00002ooooo`;o00004?ooool2o`0000Wo
oooo0_l00009ooooo`;o00001Oooool2o`0000Kooooo0_l0000?ooooo`;o00000oooool2o`0000;o
oooo0_l0000:ooooo`;o00003?ooool2o`0000Cooooo0_l00005ooooo`;o00001oooool2o`0000Go
oooo0_l0001;ooooo`007?ooool2o`0004gooooo0_l0000?ooooo`?o000000?oooooo`000?l00000
0_ooool5o`0001?ooooo0_l00007ooooo`;o00002Oooool2o`0000Oooooo1?l00005ooooo`;o0000
1_ooool2o`0001Kooooo0_l00002ooooo`;o00001oooool3o`0000Cooooo0_l000000ooooooo0000
o`000007ooooo`Co00004_ooool2o`000003ooooool0003o000004_ooooo000Looooo`03o`000?oo
oooooooo05kooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000002?oo
ool2o`0000Wooooo0_l00003ooooo`;o000000?oooooo`000?l000001_ooool2o`0000_ooooo0ol0
000Eooooo`;o00001_ooool2o`0000Oooooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo1?l0
0003ooooo`;o000000?oooooo`000?l000001oooool4o`0001;ooooo0_l00002ooooo`;o0000B_oo
ool001cooooo00?o0000ooooooooool0E?ooool2o`0000Sooooo0_l00005ooooo`?o00002_ooool2
o`0000Sooooo0ol00003ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o00001Oooool2
o`0000Gooooo0_l00007ooooo`;o00003?ooool2o`0000Kooooo0_l00008ooooo`;o000000?ooooo
o`000?l000000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000_ooooo0_l00006
ooooo`;o00004_ooool2o`0000Kooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`13oooo
o`;o00001Oooool2o`0000Sooooo0_l0000?ooooo`Co00001oooool2o`0000[ooooo1Ol000001?oo
oooo0000o`000?l00002ooooo`;o00001_ooool2o`0000?ooooo0_l0000;ooooo`;o000000?ooooo
o`000?l000002Oooool2o`0001?ooooo0_l000000ooooooo0000o`000006ooooo`;o00000oooool2
o`0000Gooooo0_l00004ooooo`;o00001_ooool2o`000003ooooool0003o000001Oooooo0_l00012
ooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00001Oooool2o`0001Gooooo0_l000001?oo
oooo0000o`000?ooool2o`000003ooooool0003o000000Cooooo0_l0000=ooooo`;o000000Cooooo
o`000?l0003o00002_ooool2o`0000Kooooo1?l00002ooooo`;o00000_ooool7o`0000Oooooo0_l0
000Jooooo`;o00001oooool5o`0000;ooooo0_l00005ooooo`;o00001oooool3o`0005_ooooo000L
ooooo`03o`000?oooooooooo067ooooo0_l000000ooooooo0000o`000002ooooo`Co00002Oooool2
o`0001;ooooo0_l0000<ooooo`Co00000_ooool;o`0002?ooooo0_l00007ooooo`Go00002Oooool2
o`000003ooooool0003o000000Cooooo0_l0001Looooo`007?ooool00ol0003oooooooooo`1@oooo
o`;o00005_ooool2o`0000_ooooo0_l0000<ooooo`;o00001?ooool2o`0000cooooo0_l00006oooo
o`;o000000?oooooo`000?l000001Oooool2o`00023ooooo0_l00002ooooo`;o00002?ooool2o`00
0003ooooool0003o000000Oooooo0_l0001Rooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o
00004?ooool4o`000004ooooool0003o0000o`0001Wooooo0_l00002ooooo`Oo00002Oooool2o`00
00Wooooo0_l00005ooooo`;o00006_ooool2o`0000Sooooo1?l00006ooooo`Go00002oooool2o`00
05kooooo000Looooo`03o`000?oooooooooo06;ooooo1?l000001?oooooo0000o`000?l00007oooo
o`;o00002_ooool4o`000004ooooool0003o0000o`0000;ooooo0_l00002ooooo`Go00001Oooool2
o`0000Wooooo0ol00006ooooo`;o00006_ooool2o`0000?ooooo1?l00003ooooo`;o00001oooool2
o`0000gooooo0_l0001Nooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00006?ooool2o`00
00Kooooo0_l00006ooooo`?o000000?oooooo`000?l000002?ooool2o`0000[ooooo1?l000000ooo
oooo0000o`000006ooooo`;o00000_ooool2o`0000Gooooo0_l00003ooooo`;o00001?ooool6o`00
00Gooooo0_l0000Mooooo`Co00001oooool2o`0001[ooooo0_l0001Fooooo`007?ooool00ol0003o
ooooooooo`0iooooo`;o00006?ooool2o`0000Kooooo0_l00007ooooo`;o00002Oooool2o`0000[o
oooo0_l00004ooooo`;o000000?oooooo`000?l000001?ooool3o`0000gooooo0_l00006ooooo`Go
00001?ooool2o`0000_ooooo0_l0000Kooooo`;o00006_ooool2o`0005Kooooo000Looooo`03o`00
0?oooooooooo06cooooo0_l000000ooooooo0000o`000002ooooo`?o00001?ooool3o`000004oooo
ool0003o0000ooooo`;o000000?oooooo`000?l000001Oooool4o`0000Gooooo0_l0000<ooooo`;o
000000?oooooo`000?l000004Oooool2o`00013ooooo0_l00003ooooo`;o00000oooool3o`000003
ooooool0003o000000;ooooo0_l00003ooooo`;o0000I_ooool001cooooo00?o0000ooooooooool0
JOooool2o`000003ooooool0003o000000?o00000_ooool3o`0000Cooooo0_l00002ooooo`;o0000
1oooool2o`0000?ooooo1Ol00003ooooo`;o00003?ooool2o`0002;ooooo0_l00002ooooo`;o0000
0oooool2o`0000;ooooo1?l000000ooooooo0000o`000002ooooo`;o00000oooool2o`0000kooooo
0_l0001Fooooo`007?ooool00ol0003oooooooooo`1Vooooo`;o000000?oooooo`000?l000000_oo
ool2o`0000oooooo0_l00005ooooo`Co00000oooool5o`000004ooooool0003o0000o`0000Kooooo
0_l00002ooooo`;o000000?oooooo`000?l000000_l0000Pooooo`;o00002oooool2o`0001cooooo
0_l0001Fooooo`007?ooool00ol0003oooooooooo`1Vooooo`;o000000?oooooo`000?l000003_oo
ool2o`0000?ooooo1?l000000ooooooo0000o`000002o`0000;ooooo2?l000001?oooooo0000o`00
0?l00006ooooo`;o00000_ooool2o`0000;ooooo0ol0000Vooooo`;o00000oooool2o`0000Gooooo
0_l0001_ooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o00000oooool3o`00017ooooo0_l0
0003ooooo`Co000000?oooooo`000?l000001?ooool5o`000003ooooool0003o000001;ooooo0ol0
000Vooooo`;o00000_ooool3o`000003ooooool0003o000000;ooooo1_l0000Eooooo`;o0000E?oo
ool001cooooo0_l0001Qooooo`;o00000oooool3o`0000[ooooo0_l0000Tooooo`;o00001_ooool2
o`0000;ooooo0_l0000Zooooo`;o00000_ooool2o`0000Cooooo1?l0000Eooooo`;o0000E?ooool0
01cooooo00?o0000ooooooooool0C?ooool2o`0000[ooooo0_l0000<ooooo`;o00001?ooool2o`00
00Cooooo0_l00007ooooo`;o00001oooool2o`000004ooooool0003o0000ooooo`;o00002?ooool2
o`0000;ooooo0ol00005ooooo`;o0000Yoooool001cooooo00?o0000ooooooooool0C?ooool3o`00
00Wooooo0_l00002ooooo`;o00003Oooool3o`0000Cooooo0_l00003ooooo`;o00000_ooool2o`00
00Oooooo0_l000001?oooooo0000o`000?ooool3o`0000Kooooo1Ol000000ooooooo0000o`00000;
ooooo`;o00000_ooool2o`0001gooooo0_l00005ooooo`;o0000Moooool001cooooo00?o0000oooo
ooooool0COooool2o`0000gooooo0_l0000=ooooo`;o00000oooool4o`0000?ooooo0_l000000ooo
oooo0000o`00000?ooooo`;o00001_ooool5o`0000;ooooo0_l0000:ooooo`;o00000_ooool2o`00
01_ooooo1?l00004ooooo`?o0000Moooool001cooooo00?o0000ooooooooool0L?ooool2o`0000So
oooo0_l00006ooooo`;o00001_ooool2o`0000Oooooo1?l00003ooooo`;o00002_ooool2o`0001Oo
oooo0_l000000ooooooo0000o`000003ooooo`?o00001Oooool4o`0000Oooooo0_l0001]ooooo`00
7?ooool00ol0003oooooooooo`1Qooooo`;o00000oooool2o`0001[ooooo0_l00005ooooo`Go0000
1_ooool2o`0000cooooo0_l00002ooooo`Co00005Oooool2o`000003ooooool0003o000000Cooooo
0_l00006ooooo`?o00001oooool2o`0006gooooo000Looooo`03o`000?oooooooooo067ooooo0_l0
0003ooooo`;o00004Oooool3o`0000Kooooo0_l00005ooooo`;o000000Coooooo`000?l0003o0000
4_ooool4o`0000?ooooo0_l0000Looooo`;o000000Coooooo`000?l0003o00001?ooool2o`0001So
oooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1?ooooo`;o000000?oooooo`000?l00000
3_ooool2o`0001Gooooo0ol0000Aooooo`;o000000?oooooo`000?l000003oooool4o`0000?ooooo
0_l0000Looooo`;o000000?oooooo`000?l000000ol00006ooooo`;o00005?ooool2o`0005gooooo
000Looooo`03o`000?oooooooooo04oooooo0_l000000ooooooo0000o`000009ooooo`;o00000ooo
ool2o`0001;ooooo1_l0000Dooooo`;o00003oooool2o`0001Wooooo0_l00004ooooo`;o000000?o
ooooo`000?l000000_ooool5o`0000Kooooo0_l0001cooooo`007?ooool00ol0003oooooooooo`1:
ooooo`;o00000oooool2o`0000cooooo0_l0000@ooooo`;o00001Oooool4o`0000;ooooo0_l00000
1?oooooo0000o`000?l00009ooooo`?o00003Oooool3o`0000Cooooo0_l00005ooooo`;o00000_oo
ool2o`0000gooooo0_l00004ooooo`;o000000?oooooo`000?l000001Ol0001mooooo`007?ooool0
0ol0003oooooooooo`1:ooooo`;o00008oooool2o`0000;ooooo0_l00007ooooo`;o000000Cooooo
o`000?l0003o00002Oooool3o`0000Wooooo0_l00002ooooo`?o00001?ooool2o`0000Gooooo0_l0
00001?oooooo0000o`000?l0000Eooooo`;o000000?oooooo`000?l000003?ooool2o`0007;ooooo
000Looooo`03o`000?oooooooooo07?ooooo0_l0000<ooooo`;o00003_ooool2o`0000Cooooo0_l0
000Cooooo`Co00005?ooool2o`0000Wooooo0_l00004ooooo`;o0000L_ooool001cooooo00?o0000
ooooooooool0EOooool2o`0001cooooo0_l0000<ooooo`;o00003_ooool2o`0001_ooooo0_l00006
ooooo`;o00001Oooool2o`0000gooooo0_l000000ooooooo0000o`00001hooooo`007?ooool00ol0
003oooooooooo`1Eooooo`;o00007?ooool2o`0000Kooooo1?l00004ooooo`;o00001Oooool2o`00
00cooooo0_l0000:ooooo`Co00003?ooool4o`0000Gooooo0_l0000=ooooo`;o00004_ooool2o`00
00gooooo0_l0001Hooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool0
1Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0Noooool4o`0000;ooooo1_l0
0003ooooo`;o00003?ooool2o`0000[ooooo1?l00009ooooo`Ko0000:Oooool2o`0000gooooo0_l0
001Hooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RH
oooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0JOooool2o`0000;ooooo0_l00003ooooo`;o
00001_ooool2o`0000Gooooo0_l00002ooooo`Co00003Oooool2o`0000;ooooo1?l000000ooooooo
0000o`00000:ooooo`;o00001?ooool5o`000003ooooool0003o0000093ooooo00000ooooooo410@
ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo06Wooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`;o
00002_ooool3o`0000Wooooo0_l00002ooooo`;o00000_ooool7o`0000Wooooo0ol0000:ooooo`;o
00003?ooool2o`0008;ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo
00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000KOooool2o`0000Oooooo0_l00002ooooo`;o
00003?ooool2o`0000Sooooo0_l000000ooooooo0000o`000006ooooo`;o00001_ooool2o`0000?o
oooo0_l0000Aooooo`;o00001_ooool2o`0000;ooooo0_l0001nooooo`0000?oooooo`000?ooool0
0_ooool00ol0003oooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003o
ooooooooo`1Cooooo`;o0000:Oooool2o`000003ooooool0003o000000Gooooo0_l00004ooooo`;o
00001Oooool2o`0000Cooooo0_l00002ooooo`;o00001?ooool2o`0001Kooooo0ol000000ooooooo
0000o`000006ooooo`;o00003?ooool2o`00073ooooo00000ooooooo410@ooooo`02ooooo`03oa0@
4?oooooooooo00Wooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo05?o
oooo0_l0000Looooo`Co00002Oooool2o`000003ooooool0003o000000;o00000oooool2o`0000Co
oooo0_l0000;ooooo`;o00000_ooool2o`0000Cooooo1?l0000=ooooo`?o00001Oooool5o`0000Ko
oooo0_l0000<ooooo`;o0000L?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0
003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0Eoooool2o`0001Oooooo1Ol0000>
ooooo`Co00002_ooool2o`0000?ooooo0_l0000=ooooo`Co00003Oooool3o`0000?ooooo0_l00000
0ooooooo0000o`000002o`0000Gooooo0ol0001nooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^
k^h;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`1Gooooo`;o0000
2?ooool2o`0000gooooo0_l0000?ooooo`;o00000_ooool2o`0000Kooooo0_l00002ooooo`;o0000
0oooool2o`0000Wooooo0_l0000Fooooo`;o000000?oooooo`000?l000002_ooool4o`0007gooooo
000Looooo`03o`000?oooooooooo067ooooo0_l0000Fooooo`;o00001_ooool6o`0000Kooooo0_l0
0006ooooo`Co00001oooool3o`00013ooooo0_l00004ooooo`;o00003oooool2o`0007gooooo000L
ooooo`03o`000?oooooooooo07Wooooo0_l00008ooooo`;o00004?ooool4o`0000Oooooo1?l0000=
ooooo`Co00001?ooool4o`0000Oooooo0_l00023ooooo`007?ooool00ol0003oooooooooo`1koooo
o`;o00002_ooool2o`000005ooooool0003o0000o`000?ooool01?l0000@ooooo`;o00003Oooool4
o`0000Kooooo0_l00007ooooo`;o0000Poooool001cooooo00?o0000ooooooooool0Noooool3o`00
00Wooooo0_l000000ooooooo0000o`000006o`00027ooooo1?l00009ooooo`;o0000Qoooool001co
oooo00?o0000ooooooooool0O?ooool2o`000003ooooool0003o000000cooooo0_l00003ooooo`;o
00001Oooool2o`0000?ooooo0_l0000;ooooo`;o00001?ooool2o`0000;ooooo0_l00005ooooo`;o
00000_ooool2o`0008Oooooo000Looooo`03o`000?oooooooooo07oooooo0_l00005ooooo`;o0000
2_ooool2o`0000Gooooo0_l00003ooooo`;o00000oooool2o`0000Kooooo0_l00004ooooo`;o0000
2Oooool2o`0008_ooooo000Looooo`03o`000?oooooooooo08Kooooo0_l0000Aooooo`;o00002?oo
ool2o`0000cooooo0_l00003ooooo`;o0000TOooool001cooooo00?o0000ooooooooool0Voooool4
o`0001;ooooo0_l00003ooooo`Co0000Soooool001cooooo00?o0000ooooooooool0K?ooool2o`00
00Gooooo0_l0000Vooooo`Co00001Oooool2o`0000Oooooo0_l000000ooooooo0000o`000002o`00
00Cooooo0_l0002?ooooo`007?ooool00ol0003oooooooooo`1/ooooo`;o00001Oooool2o`0002oo
oooo0ol000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000000_l0002Eooooo`00
7?ooool00ol0003oooooooooo`2Uooooo`;o000000?oooooo`000?l00000Woooool001cooooo0_l0
001_ooooo`;o00006?ooool2o`0001kooooo0_l00005ooooo`;o00006Oooool2o`0007gooooo000L
ooooo`03o`000?oooooooooo06kooooo0_l0000Hooooo`Co00003Oooool2o`000003ooooool0003o
000000[ooooo0_l00005ooooo`;o000000?oooooo`000?l000002Oooool2o`0000_ooooo0_l0001m
ooooo`007?ooool00ol0003oooooooooo`1kooooo`;o00003?ooool3o`000003ooooool0003o0000
00[ooooo0_l000000ooooooo0000o`00000Dooooo`;o00002Oooool2o`000003ooooool0003o0000
08Oooooo000Looooo`03o`000?oooooooooo07_ooooo0_l0000<ooooo`;o00000_ooool2o`00037o
oooo0_l00027ooooo`007?ooool00ol0003oooooooooo`2>ooooo`;o0000^Oooool001cooooo00?o
0000ooooooooool0S_ooool3o`000;Sooooo000Looooo`03o`000?oooooooooo08oooooo0_l0000<
ooooo`;o00003_ooool2o`0009[ooooo000Looooo`03o`000?oooooooooo08Cooooo0_l0000Goooo
o`;o00003_ooool2o`0009[ooooo000Looooo`03o`000?oooooooooo08Cooooo0_l00033ooooo`00
7?ooool00ol0003oooooooooo`2/ooooo`;o00000_ooool2o`0009Oooooo000Looooo`03o`000?oo
oooooooo09[ooooo0_l0000@ooooo`;o00000_ooool2o`0009Oooooo000Looooo`03o`000?oooooo
oooo09[ooooo0_l0000Dooooo`;o0000Uoooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0;?ooooo
0_l0002Dooooo`007?ooool00ol0003oooooooooo`2cooooo`;o0000U?ooool001cooooo0_l0003o
oooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Booooo`Co000000?o410@ooooooooool00oooool0
0ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`?o0000oooooom:ooooo`00
5?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_oo
ool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooo
oe;ooooo000Booooo`03oeEEEOmVIVKo00000?ooooooE?ooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00:7ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0F
ooooo`Co000000?o410@ooooooooool01Ol00004ooooo`Co000000?o410@ooooooooool01Ol0002<
ooooo`00X_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l0000<ooooo`03o`000?oooooo
oooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo00;ooooo00Go
V9RHob4Q8Oo^k^koooooodA4A02<ooooo`00X_ooool01Ol0003ooooooooooooooooo000001_ooooo
00?o0000ooooooooool00oooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo00?ooooo
00?oV9RHob4Q8Oo^k^h0SOooool00:;ooooo00Go0000ooooooooooooooooo`000009ooooo`Ko0000
3?ooool00ol0003oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0
1?ooool00onHV9So8B4Qonk^kP2<ooooo`00X_ooool01Ol0003oQhN7oooooonYZJWo000001_ooooo
00?o0000ooooooooool01Oooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?oMgMgofIVI_ooool0Roooool00:7ooooo00?o410@o`000?mgMgL00_l000000onHV9Sooooooooo
o`0Iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo08[ooooo0032ooooo`03o`000?oooooooooo00;ooooo00Go0000
okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo00;ooooo00Go0000okZj^_ooooooV9RH
oa0@402<ooooo`00`?ooool00omEEEGoIVIVo`000004ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
1?ooool00omEEEGoIVIVo`000004ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0S?ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1218) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.61251 .43568 Mdot
.65722 .45284 Mdot
.36689 .47486 Mdot
.55462 .6107 Mdot
.3686 .23295 Mdot
.36112 .44166 Mdot
.50502 .32489 Mdot
.5253 .37306 Mdot
.34766 .46137 Mdot
.60426 .2552 Mdot
.52193 .33371 Mdot
.49868 .62728 Mdot
.52026 .35623 Mdot
.57405 .59907 Mdot
.38542 .16958 Mdot
.63178 .63566 Mdot
.63285 .46319 Mdot
.32622 .63548 Mdot
.55474 .56227 Mdot
.33102 .46657 Mdot
.69498 .45849 Mdot
.57191 .60843 Mdot
.67627 .42075 Mdot
.57457 .59846 Mdot
.55842 .64533 Mdot
.64238 .4122 Mdot
.65218 .38675 Mdot
.58531 .65511 Mdot
.58146 .67038 Mdot
.53098 .36865 Mdot
.41854 .69919 Mdot
.35642 .20571 Mdot
.52757 .58215 Mdot
.19265 .47027 Mdot
.49913 .37377 Mdot
.72356 .62252 Mdot
.36691 .45556 Mdot
.49859 .352 Mdot
.49324 .35039 Mdot
.47326 .3545 Mdot
.50969 .34166 Mdot
.65819 .41583 Mdot
.53377 .29665 Mdot
.37472 .52319 Mdot
.62848 .61004 Mdot
.46548 .23085 Mdot
.77115 .64886 Mdot
.61486 .61599 Mdot
.62582 .45209 Mdot
.23997 .48035 Mdot
.36002 .30231 Mdot
.47961 .34088 Mdot
.31587 .43755 Mdot
.32989 .83884 Mdot
.49813 .36453 Mdot
.60138 .54399 Mdot
.37006 .46552 Mdot
.58272 .61102 Mdot
.57866 .59606 Mdot
.68074 .52466 Mdot
.61998 .59972 Mdot
.36943 .59431 Mdot
.62367 .48074 Mdot
.55372 .46768 Mdot
.35315 .45936 Mdot
.50037 .33774 Mdot
.6659 .44021 Mdot
.5159 .36339 Mdot
.63508 .6695 Mdot
.33253 .47122 Mdot
.61573 .62161 Mdot
.51178 .33402 Mdot
.62412 .46559 Mdot
.6015 .64714 Mdot
.27201 .5902 Mdot
.64473 .21474 Mdot
.35781 .56772 Mdot
.71239 .58346 Mdot
.67071 .5522 Mdot
.2785 .51385 Mdot
.5422 .60311 Mdot
.49896 .7276 Mdot
.58252 .19611 Mdot
.68027 .41765 Mdot
.58019 .69258 Mdot
.38435 .64814 Mdot
.60029 .64277 Mdot
.498 .20511 Mdot
.59922 .67152 Mdot
.26612 .62567 Mdot
.33865 .4466 Mdot
.64408 .44429 Mdot
.55296 .60981 Mdot
.59946 .66109 Mdot
.62553 .73662 Mdot
.53063 .58733 Mdot
.57456 .63253 Mdot
.62136 .42857 Mdot
.4789 .34739 Mdot
.551 .55128 Mdot
.38392 .51461 Mdot
.34632 .40983 Mdot
.57612 .57247 Mdot
.36885 .41845 Mdot
.6435 .48076 Mdot
.6034 .65212 Mdot
.48881 .35277 Mdot
.58325 .57548 Mdot
.67946 .35878 Mdot
.65902 .45606 Mdot
.58837 .66 Mdot
.33925 .59348 Mdot
.5462 .8155 Mdot
.64019 .45384 Mdot
.31929 .51525 Mdot
.54076 .62681 Mdot
.5822 .62951 Mdot
.65627 .44964 Mdot
.39049 .42557 Mdot
.51889 .20098 Mdot
.66251 .39916 Mdot
.48046 .37223 Mdot
.61024 .42347 Mdot
.60868 .69286 Mdot
.34382 .44199 Mdot
.29019 .36375 Mdot
.58778 .36018 Mdot
.42823 .67277 Mdot
.59988 .63604 Mdot
.60069 .28761 Mdot
.33062 .43464 Mdot
.65159 .43434 Mdot
.52053 .36386 Mdot
.51084 .64771 Mdot
.6741 .45526 Mdot
.53423 .34165 Mdot
.3526 .58365 Mdot
.3931 .33899 Mdot
.66354 .47272 Mdot
.41525 .51908 Mdot
.54298 .33688 Mdot
.47649 .34222 Mdot
.19 .56527 Mdot
.66344 .43792 Mdot
.34859 .60118 Mdot
.52218 .36915 Mdot
.40263 .67589 Mdot
.625 .59721 Mdot
.47624 .74169 Mdot
.77172 .67049 Mdot
.18923 .4883 Mdot
.41464 .3511 Mdot
.36133 .62245 Mdot
.49928 .38513 Mdot
.56364 .64124 Mdot
.63227 .41872 Mdot
.65674 .41043 Mdot
.6157 .58981 Mdot
.55107 .62299 Mdot
.61548 .63418 Mdot
.60271 .66166 Mdot
.73709 .43063 Mdot
.53356 .59369 Mdot
.71952 .7084 Mdot
.63976 .44533 Mdot
.55937 .62519 Mdot
.39111 .44671 Mdot
.52694 .64722 Mdot
.50916 .33801 Mdot
.57725 .6143 Mdot
.55471 .61351 Mdot
.61784 .58825 Mdot
.47787 .34567 Mdot
.42065 .173 Mdot
.63126 .75143 Mdot
.36082 .21792 Mdot
.28676 .63557 Mdot
.3705 .42793 Mdot
.59402 .64093 Mdot
.34985 .59094 Mdot
.75414 .58103 Mdot
.55652 .59077 Mdot
.73597 .76789 Mdot
.57194 .62434 Mdot
.37764 .21841 Mdot
.62267 .55779 Mdot
.27206 .27753 Mdot
.47808 .72336 Mdot
.57069 .65054 Mdot
.54294 .49789 Mdot
.56869 .40026 Mdot
.36118 .51029 Mdot
.5118 .3441 Mdot
.39135 .45038 Mdot
.37152 .47136 Mdot
.53697 .3061 Mdot
.62732 .50948 Mdot
.62366 .53671 Mdot
.56444 .67967 Mdot
.32719 .46734 Mdot
.63797 .48633 Mdot
.37806 .5925 Mdot
.62414 .41115 Mdot
.61313 .15633 Mdot
.40366 .26521 Mdot
.55436 .3511 Mdot
.37455 .62946 Mdot
.33697 .45914 Mdot
.35405 .4093 Mdot
.33069 .61434 Mdot
.60197 .60395 Mdot
.66641 .43251 Mdot
.17317 .47998 Mdot
.7275 .3617 Mdot
.1763 .56027 Mdot
.62124 .43431 Mdot
.64756 .29012 Mdot
.53248 .34601 Mdot
.37848 .4493 Mdot
.5801 .63111 Mdot
.59914 .60969 Mdot
.69349 .45641 Mdot
.61469 .6328 Mdot
.48878 .60375 Mdot
.5794 .64181 Mdot
.33834 .33307 Mdot
.34364 .57204 Mdot
.53835 .30713 Mdot
.43669 .65264 Mdot
.66413 .4059 Mdot
.42511 .77585 Mdot
.36509 .41453 Mdot
.74575 .57824 Mdot
.50859 .33085 Mdot
.36203 .58448 Mdot
.3495 .41563 Mdot
.37215 .58217 Mdot
.54302 .57147 Mdot
.38741 .47375 Mdot
.32683 .61609 Mdot
.65069 .55124 Mdot
.62053 .6518 Mdot
.74128 .38952 Mdot
.48236 .36858 Mdot
.65559 .39484 Mdot
.62108 .61214 Mdot
.37624 .42739 Mdot
.51216 .63235 Mdot
.45384 .29573 Mdot
.30085 .36191 Mdot
.36327 .4027 Mdot
.29583 .39355 Mdot
.37477 .59734 Mdot
.45084 .27387 Mdot
.63317 .2959 Mdot
.62552 .45846 Mdot
.53056 .59422 Mdot
.25418 .28503 Mdot
.52153 .36923 Mdot
.58791 .57902 Mdot
.22288 .4181 Mdot
.50777 .36919 Mdot
.58464 .61163 Mdot
.52268 .37859 Mdot
.65878 .41098 Mdot
.56007 .79589 Mdot
.62978 .45958 Mdot
.58911 .67645 Mdot
.4867 .35548 Mdot
.39756 .45015 Mdot
.63627 .41951 Mdot
.60384 .59855 Mdot
.5882 .65147 Mdot
.5188 .45722 Mdot
.56417 .62998 Mdot
.41424 .18426 Mdot
.57602 .6473 Mdot
.38379 .46266 Mdot
.56942 .56868 Mdot
.46558 .8509 Mdot
.52938 .27872 Mdot
.66603 .4384 Mdot
.39462 .42679 Mdot
.35625 .46697 Mdot
.34789 .53687 Mdot
.56246 .36514 Mdot
.53715 .60744 Mdot
.37126 .42632 Mdot
.47618 .77596 Mdot
.535 .33195 Mdot
.52705 .59863 Mdot
.42519 .51871 Mdot
.23758 .50107 Mdot
.31661 .43954 Mdot
.52706 .57555 Mdot
.65862 .47679 Mdot
.5516 .61129 Mdot
.36923 .40875 Mdot
.70744 .42656 Mdot
.55444 .65548 Mdot
.64709 .49883 Mdot
.52002 .45539 Mdot
.52198 .32439 Mdot
.62197 .55318 Mdot
.5977 .58244 Mdot
.38549 .44233 Mdot
.65675 .40345 Mdot
.53899 .33578 Mdot
.64929 .41512 Mdot
.24084 .3365 Mdot
.67551 .36331 Mdot
.65681 .52203 Mdot
.36461 .63985 Mdot
.22428 .48246 Mdot
.24863 .30464 Mdot
.36697 .77484 Mdot
.403 .75251 Mdot
.19265 .40821 Mdot
.38844 .42673 Mdot
.22696 .43119 Mdot
.36428 .46981 Mdot
.5499 .63603 Mdot
.34608 .44627 Mdot
.2442 .30453 Mdot
.5781 .64031 Mdot
.35209 .44838 Mdot
.45991 .79126 Mdot
.5549 .62073 Mdot
.64482 .46293 Mdot
.49867 .16727 Mdot
.40852 .81391 Mdot
.3066 .35546 Mdot
.35818 .48157 Mdot
.36603 .72288 Mdot
.57294 .6342 Mdot
.56166 .56883 Mdot
.62775 .44091 Mdot
.52394 .6076 Mdot
.37562 .61137 Mdot
.37149 .63114 Mdot
.53653 .40916 Mdot
.53478 .73586 Mdot
.61535 .55194 Mdot
.63272 .42475 Mdot
.74724 .4312 Mdot
.25922 .58897 Mdot
.23803 .47009 Mdot
.53791 .37308 Mdot
.49144 .17041 Mdot
.49304 .63987 Mdot
.45942 .32226 Mdot
.33227 .50132 Mdot
.64702 .45572 Mdot
.40051 .18262 Mdot
.50961 .34778 Mdot
.80939 .48683 Mdot
.44872 .58617 Mdot
.59894 .60219 Mdot
.50661 .32817 Mdot
.54386 .54134 Mdot
.3859 .80631 Mdot
.82514 .47442 Mdot
.49634 .68962 Mdot
.59042 .67829 Mdot
.28146 .59545 Mdot
.57895 .62073 Mdot
.54121 .21472 Mdot
.5784 .65026 Mdot
.64405 .41927 Mdot
.57705 .241 Mdot
.54348 .42459 Mdot
.65564 .74634 Mdot
.47428 .25633 Mdot
.36238 .62213 Mdot
.58225 .63754 Mdot
.59798 .59989 Mdot
.37289 .61217 Mdot
.68181 .45817 Mdot
.60518 .66113 Mdot
.40768 .76752 Mdot
.60697 .63914 Mdot
.50374 .34452 Mdot
.47848 .65424 Mdot
.59818 .45141 Mdot
.56074 .67295 Mdot
.62537 .47428 Mdot
.51914 .32182 Mdot
.49234 .36045 Mdot
.61628 .5575 Mdot
.47124 .35143 Mdot
.5668 .61774 Mdot
.83165 .46896 Mdot
.65909 .47211 Mdot
.52198 .53955 Mdot
.67777 .43199 Mdot
.70627 .58796 Mdot
.49157 .36749 Mdot
.35687 .31511 Mdot
.50222 .63276 Mdot
.51265 .3494 Mdot
.67845 .36723 Mdot
.63266 .60977 Mdot
.60985 .6745 Mdot
.24253 .62876 Mdot
.36258 .48003 Mdot
.53997 .4473 Mdot
.52589 .374 Mdot
.60361 .59079 Mdot
.54025 .64692 Mdot
.51523 .32079 Mdot
.78963 .41831 Mdot
.44378 .80656 Mdot
.57746 .6445 Mdot
.64091 .42867 Mdot
.65254 .43086 Mdot
.59745 .67952 Mdot
.55599 .57771 Mdot
.34524 .42862 Mdot
.40009 .45373 Mdot
.37522 .48607 Mdot
.52265 .45311 Mdot
.34668 .3221 Mdot
.36884 .25552 Mdot
.47308 .35348 Mdot
.6344 .31778 Mdot
.27482 .63631 Mdot
.54733 .66984 Mdot
.32858 .45815 Mdot
.5867 .5825 Mdot
.56007 .60949 Mdot
.53019 .32137 Mdot
.26198 .37205 Mdot
.51838 .56594 Mdot
.68139 .46304 Mdot
.54214 .35224 Mdot
.58769 .70608 Mdot
.52315 .26365 Mdot
.34698 .58969 Mdot
.2038 .56538 Mdot
.50773 .33312 Mdot
.6471 .46098 Mdot
.49733 .37653 Mdot
.60293 .61695 Mdot
.57703 .55188 Mdot
.65187 .44879 Mdot
.35261 .63311 Mdot
.51417 .63154 Mdot
.58527 .61509 Mdot
.74395 .72124 Mdot
.28344 .65636 Mdot
.34644 .33591 Mdot
.57188 .64894 Mdot
.5591 .66886 Mdot
.33488 .58918 Mdot
.60723 .63226 Mdot
.61839 .63433 Mdot
.58244 .79243 Mdot
.60203 .35405 Mdot
.35754 .63793 Mdot
.81251 .44203 Mdot
.62032 .43907 Mdot
.29961 .24658 Mdot
.38116 .44457 Mdot
.53511 .38594 Mdot
.47432 .81641 Mdot
.31504 .4361 Mdot
.41855 .35681 Mdot
.3266 .22775 Mdot
.53978 .44508 Mdot
.3212 .39305 Mdot
.49752 .63841 Mdot
.60641 .65645 Mdot
.58367 .625 Mdot
.35605 .5912 Mdot
.66545 .42774 Mdot
.53236 .45919 Mdot
.74561 .31061 Mdot
.57215 .61313 Mdot
.49372 .57456 Mdot
.71372 .31366 Mdot
.23985 .50525 Mdot
.34924 .61821 Mdot
.36134 .63371 Mdot
.5839 .63465 Mdot
.56163 .81119 Mdot
.64022 .41334 Mdot
.60307 .59707 Mdot
.53395 .60833 Mdot
.36646 .48199 Mdot
.66104 .46108 Mdot
.38325 .41892 Mdot
.38458 .29506 Mdot
.36327 .22097 Mdot
.76715 .70641 Mdot
.49212 .36522 Mdot
.60716 .2236 Mdot
.53724 .35882 Mdot
.49388 .71991 Mdot
.33964 .41353 Mdot
.54815 .59535 Mdot
.66118 .40529 Mdot
.5986 .58693 Mdot
.55105 .58142 Mdot
.60082 .60158 Mdot
.54535 .66189 Mdot
.64627 .8222 Mdot
.33459 .62554 Mdot
.62026 .67738 Mdot
.37958 .46957 Mdot
.53544 .20094 Mdot
.63777 .21639 Mdot
.59355 .59743 Mdot
.58644 .6466 Mdot
.67063 .46565 Mdot
.60903 .58373 Mdot
.53817 .34516 Mdot
.64495 .39971 Mdot
.59687 .66159 Mdot
.50779 .17915 Mdot
.58465 .6668 Mdot
.30558 .25204 Mdot
.50609 .37838 Mdot
.70453 .36161 Mdot
.62936 .66406 Mdot
.30646 .36215 Mdot
.53993 .4474 Mdot
.34538 .42119 Mdot
.46875 .3601 Mdot
.36422 .45596 Mdot
.77725 .33829 Mdot
.58729 .5549 Mdot
.56167 .64194 Mdot
.53353 .63691 Mdot
.37272 .42879 Mdot
.47128 .20799 Mdot
.4465 .26697 Mdot
.58901 .70256 Mdot
.36426 .42906 Mdot
.62678 .48006 Mdot
.36912 .67536 Mdot
.67358 .42327 Mdot
.38327 .62415 Mdot
.5236 .33691 Mdot
.36442 .62929 Mdot
.21555 .41508 Mdot
.65712 .45549 Mdot
.67384 .39603 Mdot
.37512 .44276 Mdot
.44162 .55085 Mdot
.19914 .68646 Mdot
.44734 .57661 Mdot
.44998 .70321 Mdot
.62988 .43845 Mdot
.57598 .67288 Mdot
.47792 .68661 Mdot
.45885 .53202 Mdot
.36237 .45714 Mdot
.55946 .59508 Mdot
.54424 .80238 Mdot
.34526 .42824 Mdot
.52836 .596 Mdot
.37331 .47746 Mdot
.5172 .33982 Mdot
.33084 .45702 Mdot
.69211 .44006 Mdot
.59653 .65156 Mdot
.16859 .62966 Mdot
.36084 .56321 Mdot
.57118 .63919 Mdot
.54183 .35687 Mdot
.49127 .40262 Mdot
.56455 .58031 Mdot
.35081 .58118 Mdot
.35144 .43789 Mdot
.44064 .58259 Mdot
.57795 .64693 Mdot
.37219 .4305 Mdot
.61187 .43214 Mdot
.47872 .37644 Mdot
.66929 .62763 Mdot
.31454 .36015 Mdot
.62678 .44056 Mdot
.40659 .51175 Mdot
.4727 .33349 Mdot
.55777 .66853 Mdot
.53049 .60131 Mdot
.64505 .42811 Mdot
.56218 .76921 Mdot
.59214 .56868 Mdot
.5426 .60253 Mdot
.38561 .46492 Mdot
.36033 .45168 Mdot
.5553 .78268 Mdot
.39552 .43692 Mdot
.57841 .55251 Mdot
.6459 .42582 Mdot
.55252 .60579 Mdot
.66282 .46751 Mdot
.60342 .58037 Mdot
.69104 .39332 Mdot
.68371 .45339 Mdot
.51815 .27661 Mdot
.55815 .60035 Mdot
.60534 .53107 Mdot
.58105 .57707 Mdot
.61082 .6419 Mdot
.34199 .43168 Mdot
.33802 .61164 Mdot
.54693 .55904 Mdot
.38299 .57759 Mdot
.37174 .58285 Mdot
.56673 .39453 Mdot
.36225 .48112 Mdot
.35795 .60083 Mdot
.72358 .31742 Mdot
.37475 .48493 Mdot
.36759 .5958 Mdot
.63173 .21515 Mdot
.49682 .37238 Mdot
.65624 .47581 Mdot
.55408 .62147 Mdot
.21325 .38986 Mdot
.7709 .65233 Mdot
.37149 .50401 Mdot
.57451 .64548 Mdot
.57956 .58009 Mdot
.67043 .40432 Mdot
.81161 .36131 Mdot
.33779 .47553 Mdot
.56709 .66282 Mdot
.66629 .44594 Mdot
.8478 .42233 Mdot
.38005 .4631 Mdot
.3643 .5932 Mdot
.47683 .35878 Mdot
.65326 .49454 Mdot
.5874 .36247 Mdot
.51159 .32405 Mdot
.32649 .47898 Mdot
.35634 .30712 Mdot
.54031 .62609 Mdot
.32538 .45111 Mdot
.20589 .59796 Mdot
.73065 .39733 Mdot
.57275 .38775 Mdot
.35609 .71543 Mdot
.64524 .4544 Mdot
.53782 .35054 Mdot
.35134 .62741 Mdot
.62306 .42846 Mdot
.6426 .46497 Mdot
.52023 .31754 Mdot
.66973 .68719 Mdot
.42477 .52202 Mdot
.49713 .348 Mdot
.25015 .62204 Mdot
.29113 .32168 Mdot
.32809 .45831 Mdot
.37534 .61007 Mdot
.22235 .39819 Mdot
.65687 .41491 Mdot
.48425 .1688 Mdot
.21078 .5921 Mdot
.57443 .63236 Mdot
.35362 .60414 Mdot
.43985 .22109 Mdot
.75301 .29918 Mdot
.50434 .36831 Mdot
.53165 .42699 Mdot
.37728 .61637 Mdot
.62031 .60615 Mdot
.38168 .67892 Mdot
.54436 .60694 Mdot
.529 .34094 Mdot
.67155 .52808 Mdot
.64824 .46265 Mdot
.51678 .31472 Mdot
.20239 .56512 Mdot
.5671 .61538 Mdot
.55724 .59801 Mdot
.43795 .63587 Mdot
.64185 .40532 Mdot
.34594 .4207 Mdot
.53728 .6171 Mdot
.58197 .61492 Mdot
.58259 .54427 Mdot
.62001 .54759 Mdot
.54276 .81266 Mdot
.55768 .65154 Mdot
.44691 .25476 Mdot
.57598 .68204 Mdot
.5643 .59935 Mdot
.62801 .47701 Mdot
.75719 .72698 Mdot
.39445 .28549 Mdot
.57882 .61522 Mdot
.57163 .67014 Mdot
.50427 .31493 Mdot
.43866 .51945 Mdot
.43789 .54909 Mdot
.43698 .57914 Mdot
.38638 .73966 Mdot
.57682 .68669 Mdot
.67093 .43631 Mdot
.32696 .61092 Mdot
.55176 .65463 Mdot
.67045 .44025 Mdot
.61976 .58701 Mdot
.34686 .42699 Mdot
.37968 .483 Mdot
.69522 .37779 Mdot
.3635 .60353 Mdot
.4688 .59427 Mdot
.62209 .31906 Mdot
.3918 .45606 Mdot
.55977 .64206 Mdot
.55579 .36342 Mdot
.36586 .40849 Mdot
.28886 .41684 Mdot
.66021 .63087 Mdot
.64045 .41006 Mdot
.64189 .4465 Mdot
.47957 .74569 Mdot
.40946 .33587 Mdot
.67596 .75933 Mdot
.51839 .33896 Mdot
.57984 .56242 Mdot
.61551 .28519 Mdot
.64068 .44999 Mdot
.47982 .69854 Mdot
.35785 .60316 Mdot
.50744 .3702 Mdot
.39133 .38879 Mdot
.67398 .45944 Mdot
.63772 .46677 Mdot
.60569 .66704 Mdot
.59004 .60911 Mdot
.41303 .75808 Mdot
.31481 .64597 Mdot
.5233 .32371 Mdot
.37603 .60768 Mdot
.33456 .42036 Mdot
.55935 .65566 Mdot
.67876 .42282 Mdot
.28551 .34451 Mdot
.56198 .66249 Mdot
.33863 .43276 Mdot
.64653 .44971 Mdot
.37719 .60121 Mdot
.35879 .57667 Mdot
.6095 .6424 Mdot
.73803 .45467 Mdot
.50205 .35435 Mdot
.64337 .46067 Mdot
.52211 .26622 Mdot
.55972 .57069 Mdot
.5927 .6178 Mdot
.64656 .60854 Mdot
.53332 .32657 Mdot
.68797 .32735 Mdot
.38398 .61399 Mdot
.66218 .43078 Mdot
.57095 .65601 Mdot
.37051 .60171 Mdot
.66218 .30914 Mdot
.36097 .4024 Mdot
.33277 .45813 Mdot
.35051 .58017 Mdot
.35182 .6124 Mdot
.35611 .57965 Mdot
.48526 .16788 Mdot
.68484 .42162 Mdot
.49404 .64064 Mdot
.5865 .56581 Mdot
.46745 .71921 Mdot
.52433 .67049 Mdot
.54163 .33728 Mdot
.35982 .47851 Mdot
.56438 .57742 Mdot
.58281 .6762 Mdot
.63876 .59882 Mdot
.51362 .55297 Mdot
.59535 .42082 Mdot
.65933 .45831 Mdot
.60086 .56219 Mdot
.37759 .47979 Mdot
.62966 .15877 Mdot
.17264 .40479 Mdot
.63463 .64983 Mdot
.41696 .53832 Mdot
.67952 .42256 Mdot
.4802 .32989 Mdot
.42237 .60155 Mdot
.49093 .37116 Mdot
.659 .43304 Mdot
.55767 .65252 Mdot
.63376 .32353 Mdot
.34418 .58281 Mdot
.6112 .60289 Mdot
.53288 .35564 Mdot
.61566 .61488 Mdot
.50918 .32423 Mdot
.24798 .32028 Mdot
.28356 .6852 Mdot
.57262 .62542 Mdot
.61159 .68176 Mdot
.35205 .7248 Mdot
.59195 .59409 Mdot
.30408 .63569 Mdot
.68076 .42429 Mdot
.60923 .75339 Mdot
.62596 .64365 Mdot
.76933 .49548 Mdot
.55222 .57266 Mdot
.5066 .79704 Mdot
.59447 .61569 Mdot
.23934 .52228 Mdot
.59137 .65784 Mdot
.61506 .64315 Mdot
.48697 .36057 Mdot
.51014 .31478 Mdot
.62191 .46443 Mdot
.37085 .42421 Mdot
.33428 .23097 Mdot
.58803 .61646 Mdot
.29825 .36116 Mdot
.64363 .34302 Mdot
.35219 .61439 Mdot
.65968 .42875 Mdot
.81295 .34919 Mdot
.50927 .38112 Mdot
.29559 .66779 Mdot
.51371 .78739 Mdot
.56503 .31992 Mdot
.39232 .64383 Mdot
.5688 .23387 Mdot
.37289 .59372 Mdot
.61541 .58485 Mdot
.274 .36117 Mdot
.2371 .54736 Mdot
.66071 .62812 Mdot
.47702 .32671 Mdot
.75732 .55962 Mdot
.26818 .35812 Mdot
.38478 .59521 Mdot
.37286 .62585 Mdot
.48504 .33105 Mdot
.39301 .39321 Mdot
.53441 .54802 Mdot
.35804 .60637 Mdot
.39479 .45274 Mdot
.35078 .48183 Mdot
.31298 .43127 Mdot
.64786 .40972 Mdot
.18468 .5263 Mdot
.52716 .25735 Mdot
.51604 .32446 Mdot
.37237 .3939 Mdot
.60318 .41073 Mdot
.68653 .41748 Mdot
.37251 .44908 Mdot
.33529 .43844 Mdot
.6759 .4706 Mdot
.6043 .54904 Mdot
.63331 .58748 Mdot
.57501 .61507 Mdot
.34288 .59683 Mdot
.59515 .60999 Mdot
.35725 .42948 Mdot
.50663 .36615 Mdot
.33538 .44927 Mdot
.53287 .37464 Mdot
.38876 .24965 Mdot
.60879 .61038 Mdot
.5943 .65315 Mdot
.79204 .62837 Mdot
.6143 .44606 Mdot
.43306 .25217 Mdot
.32671 .35618 Mdot
.36728 .47093 Mdot
.6192 .6295 Mdot
.64784 .39838 Mdot
.3889 .59974 Mdot
.80597 .6107 Mdot
.565 .57409 Mdot
.67947 .42639 Mdot
.56834 .65834 Mdot
.73068 .43459 Mdot
.52548 .84581 Mdot
.65143 .41865 Mdot
.77093 .66985 Mdot
.57804 .67041 Mdot
.6457 .25424 Mdot
.53035 .62809 Mdot
.48082 .76746 Mdot
.59146 .5687 Mdot
.62042 .43668 Mdot
.57662 .61104 Mdot
.63865 .40214 Mdot
.38917 .45065 Mdot
.4764 .33739 Mdot
.63099 .44659 Mdot
.53079 .61032 Mdot
.09514 .46802 Mdot
.52769 .34466 Mdot
.58129 .63389 Mdot
.47981 .35857 Mdot
.66893 .42696 Mdot
.62861 .45348 Mdot
.72597 .27896 Mdot
.3921 .29272 Mdot
.51709 .34086 Mdot
.56225 .65688 Mdot
.52665 .2406 Mdot
.5477 .60741 Mdot
.43574 .75314 Mdot
.60062 .54208 Mdot
.57566 .56773 Mdot
.65204 .21972 Mdot
.53036 .32632 Mdot
.65886 .77084 Mdot
.71451 .26512 Mdot
.54275 .19789 Mdot
.67539 .48534 Mdot
.38604 .59646 Mdot
.40984 .17819 Mdot
.3533 .31835 Mdot
.36831 .42911 Mdot
.57231 .5769 Mdot
.60038 .44745 Mdot
.49647 .35633 Mdot
.33588 .61172 Mdot
.5734 .62609 Mdot
.33333 .44252 Mdot
.39943 .79091 Mdot
.50812 .3852 Mdot
.65937 .4174 Mdot
.68592 .45257 Mdot
.85466 .5191 Mdot
.57171 .65201 Mdot
.59716 .65523 Mdot
.52608 .33801 Mdot
.69946 .31198 Mdot
.37173 .58936 Mdot
.44139 .79025 Mdot
.51829 .34178 Mdot
.49228 .47999 Mdot
.66292 .4447 Mdot
.58215 .58041 Mdot
.44533 .20346 Mdot
.28323 .58365 Mdot
.80814 .52717 Mdot
.34923 .5917 Mdot
.42952 .74769 Mdot
.61984 .43918 Mdot
.52198 .36588 Mdot
.39054 .35561 Mdot
.55217 .68022 Mdot
.58306 .58383 Mdot
.43309 .74517 Mdot
.55558 .41646 Mdot
.49118 .68201 Mdot
.56076 .57372 Mdot
.55461 .43751 Mdot
.58767 .57129 Mdot
.54903 .68305 Mdot
.58993 .54862 Mdot
.59738 .62895 Mdot
.67961 .42485 Mdot
.62879 .6896 Mdot
.35376 .42276 Mdot
.48646 .6437 Mdot
.49873 .48581 Mdot
.57412 .64105 Mdot
.54417 .62011 Mdot
.78969 .5703 Mdot
.43987 .3762 Mdot
.63426 .44737 Mdot
.69586 .42301 Mdot
.47358 .36159 Mdot
.63576 .5921 Mdot
.36542 .42027 Mdot
.52715 .67025 Mdot
.34031 .43455 Mdot
.67465 .41882 Mdot
.37294 .46903 Mdot
.47498 .3506 Mdot
.33959 .47273 Mdot
.34554 .32252 Mdot
.5218 .37156 Mdot
.63104 .41902 Mdot
.60271 .64592 Mdot
.54135 .35769 Mdot
.42503 .66166 Mdot
.34474 .59548 Mdot
.7092 .25155 Mdot
.59538 .66347 Mdot
.59875 .35858 Mdot
.67265 .49265 Mdot
.33538 .4445 Mdot
.55815 .82691 Mdot
.6841 .45604 Mdot
.35022 .63684 Mdot
.6673 .40721 Mdot
.26176 .64479 Mdot
.34244 .60985 Mdot
.61912 .20556 Mdot
.31813 .37729 Mdot
.32213 .66585 Mdot
.61275 .55915 Mdot
.41003 .6449 Mdot
.31919 .4378 Mdot
.49641 .35763 Mdot
.4052 .35977 Mdot
.61779 .63358 Mdot
.32751 .74088 Mdot
.64813 .48323 Mdot
.36811 .42382 Mdot
.51848 .36249 Mdot
.54074 .33952 Mdot
.54056 .58452 Mdot
.26289 .47343 Mdot
.60285 .58497 Mdot
.40538 .32016 Mdot
.39556 .73995 Mdot
.53559 .54101 Mdot
.57956 .64112 Mdot
.38655 .44409 Mdot
.56802 .65823 Mdot
.34497 .64183 Mdot
.17895 .53415 Mdot
.51918 .62435 Mdot
.33324 .35047 Mdot
.37168 .56262 Mdot
.65375 .45156 Mdot
.56095 .53654 Mdot
.3586 .32227 Mdot
.56854 .65316 Mdot
.53108 .8829 Mdot
.36905 .59825 Mdot
.2712 .37315 Mdot
.54192 .65347 Mdot
.53615 .59864 Mdot
.55371 .47971 Mdot
.58097 .3929 Mdot
.28567 .58684 Mdot
.58439 .59189 Mdot
.39548 .70846 Mdot
.49222 .33011 Mdot
.59615 .57874 Mdot
.58366 .62777 Mdot
.69209 .67053 Mdot
.54064 .34923 Mdot
.35645 .47023 Mdot
.31839 .4322 Mdot
.39547 .48423 Mdot
.34134 .64009 Mdot
.51657 .43685 Mdot
.47082 .70111 Mdot
.39142 .80073 Mdot
.32534 .62559 Mdot
.59761 .66636 Mdot
.31562 .58439 Mdot
.55012 .64116 Mdot
.34749 .62375 Mdot
.53957 .35498 Mdot
.63385 .45064 Mdot
.62906 .28206 Mdot
.32754 .46572 Mdot
.52639 .60188 Mdot
.37993 .5997 Mdot
.63416 .4162 Mdot
.33608 .66115 Mdot
.65832 .44438 Mdot
.5177 .34778 Mdot
.49887 .38883 Mdot
.33812 .61791 Mdot
.67466 .4299 Mdot
.47253 .31381 Mdot
.75669 .30885 Mdot
.58032 .54867 Mdot
.50418 .39417 Mdot
.61494 .42981 Mdot
.69727 .44436 Mdot
.62267 .41905 Mdot
.61463 .62814 Mdot
.41704 .53703 Mdot
.62843 .60212 Mdot
.52347 .32442 Mdot
.36875 .47745 Mdot
.35632 .7409 Mdot
.34529 .28906 Mdot
.36807 .53987 Mdot
.58518 .56156 Mdot
.56689 .61228 Mdot
.58376 .6343 Mdot
.6225 .65608 Mdot
.3886 .32753 Mdot
.59597 .58501 Mdot
.48526 .35816 Mdot
.35062 .4348 Mdot
.61659 .58608 Mdot
.32913 .41745 Mdot
.52245 .21133 Mdot
.32715 .62599 Mdot
.51541 .42777 Mdot
.17588 .34113 Mdot
.62879 .42608 Mdot
.38778 .42052 Mdot
.37101 .43155 Mdot
.35375 .58328 Mdot
.50026 .35061 Mdot
.66165 .44134 Mdot
.45895 .77172 Mdot
.36575 .57998 Mdot
.57866 .61255 Mdot
.41337 .55988 Mdot
.30444 .71488 Mdot
.61077 .58095 Mdot
.55445 .58645 Mdot
.35492 .40236 Mdot
.269 .41873 Mdot
.18379 .622 Mdot
.46048 .66269 Mdot
.33809 .61485 Mdot
.34032 .62964 Mdot
.66697 .47464 Mdot
.63236 .61752 Mdot
.52178 .32385 Mdot
.49611 .68162 Mdot
.46186 .40211 Mdot
.46558 .60968 Mdot
.59706 .47785 Mdot
.57202 .57403 Mdot
.78518 .39937 Mdot
.56516 .61558 Mdot
.68079 .41587 Mdot
.66478 .41344 Mdot
.6342 .42981 Mdot
.49834 .35757 Mdot
.72219 .59154 Mdot
.48554 .35189 Mdot
.16803 .35492 Mdot
.62105 .44765 Mdot
.34829 .36461 Mdot
.3836 .44966 Mdot
.63169 .66085 Mdot
.3762 .60212 Mdot
.45902 .35646 Mdot
.63459 .67086 Mdot
.56462 .81363 Mdot
.3631 .42353 Mdot
.62803 .42373 Mdot
.58168 .23583 Mdot
.20723 .33915 Mdot
.43577 .56236 Mdot
.57934 .70816 Mdot
.42453 .62324 Mdot
.35469 .6168 Mdot
.80895 .53233 Mdot
.37726 .61105 Mdot
.53227 .36093 Mdot
.59305 .64949 Mdot
.60013 .64153 Mdot
.59178 .57134 Mdot
.60264 .59929 Mdot
.47394 .33599 Mdot
.53237 .58277 Mdot
.46549 .85087 Mdot
.38659 .4778 Mdot
.65043 .54399 Mdot
.37227 .5983 Mdot
.46639 .34307 Mdot
.35144 .43351 Mdot
.43712 .37637 Mdot
.44052 .65721 Mdot
.57823 .64539 Mdot
.56792 .57674 Mdot
.29429 .67013 Mdot
.55987 .57358 Mdot
.52403 .67185 Mdot
.37095 .42986 Mdot
.37583 .54643 Mdot
.34418 .63305 Mdot
.35106 .63057 Mdot
.51445 .37492 Mdot
.67396 .41897 Mdot
.35929 .59559 Mdot
.3868 .45713 Mdot
.58377 .56086 Mdot
.53575 .62171 Mdot
.61521 .43147 Mdot
.21356 .60255 Mdot
.38368 .60333 Mdot
.55551 .2295 Mdot
.65698 .40472 Mdot
.63696 .3895 Mdot
.58155 .58387 Mdot
.59699 .50574 Mdot
.6488 .49576 Mdot
.32503 .62826 Mdot
.46622 .34588 Mdot
.42592 .60373 Mdot
.53272 .33997 Mdot
.66492 .41851 Mdot
.55242 .65377 Mdot
.65752 .40885 Mdot
.57324 .64958 Mdot
.25566 .25756 Mdot
.60035 .63173 Mdot
.39177 .80482 Mdot
.46796 .7452 Mdot
.36356 .44054 Mdot
.46259 .38814 Mdot
.37941 .44358 Mdot
.65279 .40325 Mdot
.54401 .64044 Mdot
.3789 .62262 Mdot
.57538 .20201 Mdot
.6013 .4113 Mdot
.33737 .4303 Mdot
.37171 .49144 Mdot
.5354 .36192 Mdot
.60321 .57092 Mdot
.58707 .58394 Mdot
.354 .44924 Mdot
.52888 .54596 Mdot
.67738 .45168 Mdot
.58672 .64922 Mdot
.56626 .60487 Mdot
.36621 .44178 Mdot
.76532 .31929 Mdot
.64226 .37558 Mdot
.59446 .6421 Mdot
.28351 .38305 Mdot
.54053 .33394 Mdot
.61869 .56846 Mdot
.60564 .68661 Mdot
.35341 .61038 Mdot
.67358 .60429 Mdot
.18289 .50119 Mdot
.53591 .36872 Mdot
.3827 .43685 Mdot
.57216 .65409 Mdot
.38595 .44263 Mdot
.533 .6112 Mdot
.58294 .43249 Mdot
.33309 .42714 Mdot
.54151 .59751 Mdot
.61114 .54652 Mdot
.64285 .40453 Mdot
.56933 .57526 Mdot
.77199 .61459 Mdot
.36048 .41061 Mdot
.53802 .5943 Mdot
.73385 .46078 Mdot
.49867 .34223 Mdot
.62089 .56444 Mdot
.33013 .60641 Mdot
.46049 .77377 Mdot
.5944 .32118 Mdot
.25573 .37861 Mdot
.32915 .62527 Mdot
.61492 .60791 Mdot
.38481 .48953 Mdot
.49593 .32612 Mdot
.42016 .81567 Mdot
.61699 .59501 Mdot
.52944 .34239 Mdot
.50899 .3661 Mdot
.34603 .59086 Mdot
.78775 .67199 Mdot
.54638 .66199 Mdot
.59358 .59904 Mdot
.72038 .66269 Mdot
.61112 .42745 Mdot
.59957 .61936 Mdot
.58696 .67321 Mdot
.48355 .35666 Mdot
.53093 .68072 Mdot
.77459 .55275 Mdot
.4708 .79393 Mdot
.54145 .33093 Mdot
.46744 .5448 Mdot
.32298 .45429 Mdot
.3704 .60659 Mdot
.65195 .4443 Mdot
.3809 .60358 Mdot
.34044 .47116 Mdot
.5935 .66832 Mdot
.48754 .37409 Mdot
.74993 .66109 Mdot
.48495 .33075 Mdot
.24453 .38914 Mdot
.61275 .42544 Mdot
.59255 .27685 Mdot
.57993 .8663 Mdot
.50304 .24433 Mdot
.44668 .34453 Mdot
.35191 .61407 Mdot
.41791 .48078 Mdot
.56571 .60706 Mdot
.80822 .55779 Mdot
.60663 .64716 Mdot
.72616 .47453 Mdot
.39328 .46174 Mdot
.37558 .4861 Mdot
.59345 .64624 Mdot
.40529 .7441 Mdot
.49492 .32555 Mdot
.53402 .33025 Mdot
.54127 .58826 Mdot
.51273 .3489 Mdot
.58843 .60512 Mdot
.34761 .43011 Mdot
.65359 .78428 Mdot
.57539 .62085 Mdot
.6066 .67984 Mdot
.57848 .37412 Mdot
.67561 .23716 Mdot
.21979 .46295 Mdot
.82502 .42867 Mdot
.19174 .36455 Mdot
.51298 .35007 Mdot
.62607 .58578 Mdot
.46745 .54644 Mdot
.32075 .42543 Mdot
.4596 .32624 Mdot
.60551 .63229 Mdot
.6079 .63291 Mdot
.61387 .64738 Mdot
.55526 .59854 Mdot
.81289 .52135 Mdot
.56619 .71706 Mdot
.69541 .53605 Mdot
.5542 .57965 Mdot
.41206 .64976 Mdot
.51687 .37644 Mdot
.68479 .46981 Mdot
.31802 .60816 Mdot
.57258 .57411 Mdot
.5104 .67672 Mdot
.51702 .31352 Mdot
.16637 .35682 Mdot
.52824 .37009 Mdot
.3564 .46658 Mdot
.48283 .32858 Mdot
.56477 .63196 Mdot
.65199 .43086 Mdot
.48025 .51598 Mdot
.44576 .27683 Mdot
.36735 .42859 Mdot
.57141 .63955 Mdot
.34431 .36091 Mdot
.35706 .42359 Mdot
.51742 .2099 Mdot
.6496 .43784 Mdot
.39997 .70507 Mdot
.66245 .41105 Mdot
.53985 .59964 Mdot
.53986 .60438 Mdot
.48033 .38797 Mdot
.47688 .33889 Mdot
.66469 .41225 Mdot
.78982 .67859 Mdot
.37435 .5834 Mdot
.63641 .4245 Mdot
.52539 .65948 Mdot
.4541 .47052 Mdot
.64667 .4316 Mdot
.4034 .57723 Mdot
.49804 .36603 Mdot
.63393 .47104 Mdot
.54168 .67171 Mdot
.22376 .5867 Mdot
.32719 .60567 Mdot
.37674 .40115 Mdot
.41218 .5724 Mdot
.36601 .40964 Mdot
.46735 .3559 Mdot
.37714 .44199 Mdot
.49039 .33187 Mdot
.61374 .3391 Mdot
.47966 .62238 Mdot
.54982 .37318 Mdot
.46796 .35095 Mdot
.37445 .44292 Mdot
.58819 .65387 Mdot
.41695 .59654 Mdot
.62344 .57815 Mdot
.54576 .66482 Mdot
.49903 .33071 Mdot
.62301 .43014 Mdot
.69328 .44969 Mdot
.38992 .6725 Mdot
.68401 .44677 Mdot
.33845 .43547 Mdot
.49237 .84385 Mdot
.29626 .3558 Mdot
.51703 .33125 Mdot
.48511 .32462 Mdot
.54556 .60997 Mdot
.36382 .45642 Mdot
.38923 .4406 Mdot
.53584 .35598 Mdot
.51651 .53904 Mdot
.62413 .6618 Mdot
.6938 .42581 Mdot
.62433 .46001 Mdot
.64801 .42146 Mdot
.62443 .41536 Mdot
.78491 .50471 Mdot
.50227 .37104 Mdot
.6267 .42055 Mdot
.54308 .59283 Mdot
.60691 .63139 Mdot
.44699 .56213 Mdot
.34379 .62926 Mdot
.62136 .59466 Mdot
.59259 .55015 Mdot
.57819 .58138 Mdot
.33038 .45427 Mdot
.65558 .63096 Mdot
.33452 .42531 Mdot
.39144 .48041 Mdot
.39556 .46615 Mdot
.35044 .32023 Mdot
.32783 .6824 Mdot
.20158 .38142 Mdot
.56809 .66348 Mdot
.71778 .33135 Mdot
.37537 .45851 Mdot
.55954 .82051 Mdot
.68892 .32579 Mdot
.6196 .61335 Mdot
.27082 .58051 Mdot
.35643 .44823 Mdot
.68555 .44916 Mdot
.6039 .63211 Mdot
.40165 .46648 Mdot
.33058 .60288 Mdot
.55696 .56353 Mdot
.33968 .41467 Mdot
.67336 .43067 Mdot
.31748 .6193 Mdot
.6239 .46259 Mdot
.39511 .46519 Mdot
.61577 .55404 Mdot
.24215 .752 Mdot
.37061 .49371 Mdot
.70845 .29059 Mdot
.70505 .40168 Mdot
.58755 .65102 Mdot
.3792 .41271 Mdot
.61338 .41084 Mdot
.47344 .36878 Mdot
.46017 .41015 Mdot
.64966 .47115 Mdot
.37319 .48649 Mdot
.34791 .411 Mdot
.36977 .42904 Mdot
.65558 .46105 Mdot
.59939 .67989 Mdot
.6603 .46607 Mdot
.48476 .32696 Mdot
.5516 .61489 Mdot
.25004 .30189 Mdot
.72064 .33874 Mdot
.66107 .40794 Mdot
.35072 .46912 Mdot
.33759 .58752 Mdot
.56865 .62336 Mdot
.73781 .34643 Mdot
.58291 .65702 Mdot
.50639 .32666 Mdot
.59477 .78111 Mdot
.77058 .63722 Mdot
.58626 .56652 Mdot
.54579 .60883 Mdot
.52963 .32808 Mdot
.57426 .63426 Mdot
.59442 .56879 Mdot
.36379 .3124 Mdot
.66394 .45828 Mdot
.5739 .6096 Mdot
.37981 .47278 Mdot
.34025 .31242 Mdot
.62381 .65941 Mdot
.32765 .52422 Mdot
.4057 .71987 Mdot
.61546 .76392 Mdot
.60579 .64963 Mdot
.45886 .64034 Mdot
.56076 .5931 Mdot
.61014 .60401 Mdot
.5497 .63291 Mdot
.8239 .51871 Mdot
.33079 .4324 Mdot
.36504 .43265 Mdot
.32344 .61549 Mdot
.4032 .71719 Mdot
.35359 .60626 Mdot
.49631 .36686 Mdot
.28317 .4994 Mdot
.33405 .42642 Mdot
.67335 .42469 Mdot
.60991 .59656 Mdot
.37305 .49403 Mdot
.58595 .581 Mdot
.56445 .63411 Mdot
.36891 .41838 Mdot
.32149 .44372 Mdot
.26639 .37379 Mdot
.32628 .61843 Mdot
.63281 .43691 Mdot
.62044 .58349 Mdot
.37847 .59499 Mdot
.5728 .67629 Mdot
.47063 .72003 Mdot
.63496 .434 Mdot
.66318 .4613 Mdot
.69052 .45257 Mdot
.59274 .66828 Mdot
.56742 .63025 Mdot
.48534 .34919 Mdot
.66887 .41011 Mdot
.50112 .34202 Mdot
.51528 .46336 Mdot
.33516 .5468 Mdot
.6056 .63233 Mdot
.56991 .23836 Mdot
.36617 .61331 Mdot
.33988 .45263 Mdot
.31453 .71421 Mdot
.32347 .61373 Mdot
.57573 .65025 Mdot
.38625 .43404 Mdot
.34652 .62545 Mdot
.66374 .62481 Mdot
.15802 .45841 Mdot
.32921 .59372 Mdot
.54329 .59109 Mdot
.55261 .70128 Mdot
.83054 .44116 Mdot
.32148 .61559 Mdot
.47924 .36317 Mdot
.59323 .66748 Mdot
.62486 .49055 Mdot
.38203 .60893 Mdot
.45224 .25221 Mdot
.35233 .44009 Mdot
.19898 .53955 Mdot
.64091 .66753 Mdot
.7853 .62762 Mdot
.36697 .62186 Mdot
.66172 .43705 Mdot
.70715 .42702 Mdot
.57416 .58585 Mdot
.32178 .61383 Mdot
.5369 .32249 Mdot
.34494 .44177 Mdot
.39002 .28873 Mdot
.65422 .46226 Mdot
.56536 .25429 Mdot
.34701 .46951 Mdot
.54839 .23046 Mdot
.5334 .79772 Mdot
.62829 .57837 Mdot
.82464 .44327 Mdot
.40583 .38037 Mdot
.61045 .66216 Mdot
.35911 .57399 Mdot
.53816 .36565 Mdot
.48142 .37066 Mdot
.52025 .34544 Mdot
.63344 .34132 Mdot
.43559 .57636 Mdot
.39029 .42195 Mdot
.47917 .28542 Mdot
.36907 .60518 Mdot
.43333 .62504 Mdot
.53284 .62422 Mdot
.56852 .61369 Mdot
.60144 .56865 Mdot
.58447 .57285 Mdot
.56784 .59294 Mdot
.50554 .34693 Mdot
.60164 .34465 Mdot
.44304 .57685 Mdot
.64036 .43224 Mdot
.26853 .44931 Mdot
.38275 .45118 Mdot
.39236 .42304 Mdot
.33621 .62315 Mdot
.54218 .21689 Mdot
.33035 .41699 Mdot
.3708 .47075 Mdot
.61953 .64793 Mdot
.6728 .45971 Mdot
.5624 .69632 Mdot
.54395 .60095 Mdot
.33968 .43968 Mdot
.54105 .47732 Mdot
.78248 .56394 Mdot
.65792 .63258 Mdot
.39278 .57554 Mdot
.42773 .53387 Mdot
.32994 .59633 Mdot
.54455 .64487 Mdot
.56921 .81806 Mdot
.33738 .4684 Mdot
.35893 .46232 Mdot
.36512 .62094 Mdot
.59921 .46991 Mdot
.64779 .45259 Mdot
.44494 .33583 Mdot
.4788 .35121 Mdot
.5425 .62719 Mdot
.39388 .784 Mdot
.63011 .51361 Mdot
.26221 .4825 Mdot
.52206 .34192 Mdot
.38795 .44872 Mdot
.58802 .56352 Mdot
.54495 .59026 Mdot
.36448 .61761 Mdot
.32342 .26681 Mdot
.58585 .5554 Mdot
.52911 .18805 Mdot
.28242 .68465 Mdot
.2192 .59946 Mdot
.58333 .58397 Mdot
.66187 .45893 Mdot
.33833 .41397 Mdot
.37486 .61067 Mdot
.52239 .64721 Mdot
.17289 .42688 Mdot
.61651 .44262 Mdot
.52726 .36529 Mdot
.49821 .49914 Mdot
.42469 .59568 Mdot
.60341 .66205 Mdot
.6055 .64686 Mdot
.61251 .62002 Mdot
.15607 .51248 Mdot
.32998 .44381 Mdot
.67728 .41899 Mdot
.3375 .59974 Mdot
.68331 .43832 Mdot
.36783 .43716 Mdot
.573 .26464 Mdot
.58822 .65741 Mdot
.61575 .44241 Mdot
.66012 .43817 Mdot
.53176 .36668 Mdot
.47873 .37577 Mdot
.51051 .4808 Mdot
.59946 .6291 Mdot
.35723 .48963 Mdot
.63288 .41214 Mdot
.41671 .5628 Mdot
.34383 .60992 Mdot
.4906 .36441 Mdot
.55967 .57782 Mdot
.32613 .44822 Mdot
.52909 .58588 Mdot
.6396 .44732 Mdot
.37138 .47001 Mdot
.28089 .36668 Mdot
.33475 .62967 Mdot
.60427 .61355 Mdot
.32407 .64107 Mdot
.38288 .43618 Mdot
.56411 .60551 Mdot
.60529 .22906 Mdot
.38025 .56305 Mdot
.43746 .27289 Mdot
.39693 .4545 Mdot
.30379 .36096 Mdot
.66712 .47229 Mdot
.67169 .3469 Mdot
.35637 .46333 Mdot
.57022 .2304 Mdot
.31921 .28619 Mdot
.59862 .56364 Mdot
.65391 .41483 Mdot
.43049 .39171 Mdot
.29471 .24589 Mdot
.76353 .33111 Mdot
.58191 .6325 Mdot
.39602 .43777 Mdot
.35989 .62139 Mdot
.51505 .33002 Mdot
.33207 .52943 Mdot
.38662 .56652 Mdot
.34427 .48045 Mdot
.55 .63472 Mdot
.66739 .43169 Mdot
.50041 .36276 Mdot
.59953 .32662 Mdot
.38589 .46312 Mdot
.3608 .4767 Mdot
.58776 .56406 Mdot
.35899 .603 Mdot
.74752 .36166 Mdot
.35113 .42857 Mdot
.2938 .6794 Mdot
.31695 .45852 Mdot
.37702 .58873 Mdot
.55781 .58915 Mdot
.38182 .674 Mdot
.62947 .62812 Mdot
.6623 .2463 Mdot
.37856 .44724 Mdot
.63716 .44209 Mdot
.61468 .63674 Mdot
.49123 .78998 Mdot
.33965 .44374 Mdot
.41955 .53908 Mdot
.23475 .51292 Mdot
.49983 .36895 Mdot
.31534 .71626 Mdot
.59766 .6099 Mdot
.4942 .32611 Mdot
.36459 .61368 Mdot
.59647 .63638 Mdot
.56534 .62803 Mdot
.66503 .40118 Mdot
.5346 .35602 Mdot
.28409 .3173 Mdot
.5135 .31423 Mdot
.49994 .37762 Mdot
.67248 .40045 Mdot
.5803 .59984 Mdot
.35651 .46775 Mdot
.35676 .45003 Mdot
.53071 .64785 Mdot
.6008 .82128 Mdot
.64721 .45585 Mdot
.39852 .41303 Mdot
.1616 .53515 Mdot
.60353 .53345 Mdot
.33193 .73138 Mdot
.33841 .25634 Mdot
.54528 .33648 Mdot
.5448 .58432 Mdot
.67153 .42794 Mdot
.43454 .43851 Mdot
.35816 .47467 Mdot
.58525 .67986 Mdot
.50502 .3616 Mdot
.32885 .60486 Mdot
.35547 .41459 Mdot
.26455 .47709 Mdot
.60737 .60512 Mdot
.26697 .58419 Mdot
.38782 .42443 Mdot
.43672 .16147 Mdot
.43464 .37984 Mdot
.64908 .41476 Mdot
.56214 .63168 Mdot
.68114 .46308 Mdot
.33449 .6058 Mdot
.49826 .49712 Mdot
.50526 .36427 Mdot
.59029 .72223 Mdot
.4205 .85024 Mdot
.37278 .42998 Mdot
.68055 .42292 Mdot
.58293 .56639 Mdot
.5846 .47035 Mdot
.59334 .60468 Mdot
.50498 .65033 Mdot
.35397 .55629 Mdot
.50038 .3329 Mdot
.48856 .33043 Mdot
.55904 .60791 Mdot
.36668 .58262 Mdot
.38579 .45472 Mdot
.34322 .44533 Mdot
.56794 .15645 Mdot
.56004 .32381 Mdot
.42106 .76125 Mdot
.60787 .62808 Mdot
.36417 .48854 Mdot
.34591 .294 Mdot
.52537 .33793 Mdot
.52925 .62079 Mdot
.36511 .4207 Mdot
.23814 .59428 Mdot
.49926 .7776 Mdot
.56696 .58961 Mdot
.58716 .68784 Mdot
.47845 .35533 Mdot
.44688 .61069 Mdot
.38775 .47305 Mdot
.59536 .53902 Mdot
.53536 .38294 Mdot
.57296 .77142 Mdot
.19539 .58421 Mdot
.63262 .43654 Mdot
.24695 .45772 Mdot
.5046 .34723 Mdot
.58247 .68991 Mdot
.36783 .59081 Mdot
.32818 .4239 Mdot
.32832 .44228 Mdot
.56017 .65138 Mdot
.54051 .57657 Mdot
.33597 .7163 Mdot
.68141 .4421 Mdot
.51453 .37627 Mdot
.59885 .6531 Mdot
.62706 .27289 Mdot
.58932 .57087 Mdot
.48808 .3464 Mdot
.2343 .75111 Mdot
.61522 .57132 Mdot
.59227 .60084 Mdot
.74806 .35516 Mdot
.6461 .4694 Mdot
.6832 .42526 Mdot
.33722 .76256 Mdot
.60775 .62686 Mdot
.30306 .69911 Mdot
.63144 .44154 Mdot
.64478 .45331 Mdot
.38761 .30211 Mdot
.56974 .62074 Mdot
.59117 .73145 Mdot
.51063 .32485 Mdot
.49342 .37486 Mdot
.65628 .46601 Mdot
.60754 .56314 Mdot
.52514 .37881 Mdot
.80297 .45879 Mdot
.36547 .45614 Mdot
.58699 .81115 Mdot
.64116 .46051 Mdot
.54255 .42995 Mdot
.52286 .33876 Mdot
.17029 .35215 Mdot
.3095 .45357 Mdot
.59014 .65408 Mdot
.60703 .61606 Mdot
.36857 .61102 Mdot
.61648 .57526 Mdot
.37888 .48502 Mdot
.51269 .34836 Mdot
.69671 .49269 Mdot
.63412 .42901 Mdot
.59477 .6182 Mdot
.53317 .21577 Mdot
.44542 .24133 Mdot
.23977 .43907 Mdot
.65406 .4503 Mdot
.64879 .41073 Mdot
.38243 .47642 Mdot
.39456 .43455 Mdot
.57756 .59219 Mdot
.53191 .33159 Mdot
.66754 .4096 Mdot
.49038 .33928 Mdot
.33726 .46791 Mdot
.36081 .47074 Mdot
.32736 .4353 Mdot
.53581 .57005 Mdot
.37583 .47165 Mdot
.29341 .48158 Mdot
.55674 .25278 Mdot
.68566 .41492 Mdot
.24657 .67643 Mdot
.60765 .32766 Mdot
.65866 .36839 Mdot
.38252 .61591 Mdot
.38278 .4352 Mdot
.49635 .31913 Mdot
.5514 .60387 Mdot
.57745 .57761 Mdot
.28787 .42864 Mdot
.50353 .32011 Mdot
.33511 .61023 Mdot
.49019 .32653 Mdot
.34625 .59054 Mdot
.24384 .56136 Mdot
.60876 .57509 Mdot
.53543 .6176 Mdot
.51008 .34444 Mdot
.37463 .47034 Mdot
.357 .4345 Mdot
.3232 .60305 Mdot
.57335 .41844 Mdot
.35777 .42314 Mdot
.63923 .4567 Mdot
.78362 .48168 Mdot
.34786 .41058 Mdot
.60275 .62713 Mdot
.47576 .7047 Mdot
.80138 .59487 Mdot
.62219 .6568 Mdot
.37893 .30498 Mdot
.74083 .69089 Mdot
.61776 .61796 Mdot
.7833 .65338 Mdot
.31646 .36022 Mdot
.66949 .46945 Mdot
.39195 .46464 Mdot
.35591 .40063 Mdot
.53253 .56556 Mdot
.33612 .5813 Mdot
.52644 .64961 Mdot
.63668 .46199 Mdot
.63642 .48333 Mdot
.24192 .62153 Mdot
.70152 .27981 Mdot
.35551 .62316 Mdot
.34486 .62706 Mdot
.35283 .4607 Mdot
.7415 .26797 Mdot
.6208 .69088 Mdot
.33677 .61422 Mdot
.47719 .60336 Mdot
.55192 .6403 Mdot
.44613 .74334 Mdot
.28774 .63259 Mdot
.65813 .46231 Mdot
.39906 .65679 Mdot
.3472 .46006 Mdot
.68263 .45243 Mdot
.63921 .28731 Mdot
.62451 .61207 Mdot
.63518 .43212 Mdot
.48744 .34211 Mdot
.42333 .34854 Mdot
.62831 .45174 Mdot
.47501 .71217 Mdot
.53706 .35005 Mdot
.41645 .55726 Mdot
.3912 .68547 Mdot
.79696 .72902 Mdot
.50734 .34912 Mdot
.33943 .42043 Mdot
.35567 .44954 Mdot
.34369 .44729 Mdot
.68265 .44516 Mdot
.3885 .43989 Mdot
.68094 .43474 Mdot
.79665 .38186 Mdot
.59804 .47817 Mdot
.33902 .61708 Mdot
.39787 .28668 Mdot
.66224 .42352 Mdot
.5287 .8404 Mdot
.5203 .87169 Mdot
.54501 .58309 Mdot
.49122 .31878 Mdot
.34517 .62164 Mdot
.54669 .18036 Mdot
.35647 .61202 Mdot
.3326 .67049 Mdot
.59606 .78774 Mdot
.58916 .61171 Mdot
.74689 .58688 Mdot
.36577 .63024 Mdot
.66173 .44636 Mdot
.56425 .60796 Mdot
.43923 .40773 Mdot
.35915 .60907 Mdot
.3415 .59111 Mdot
.57372 .59933 Mdot
.62826 .4231 Mdot
.34826 .46446 Mdot
.47321 .34805 Mdot
.36277 .63755 Mdot
.69112 .39907 Mdot
.62333 .64771 Mdot
.57635 .65984 Mdot
.44421 .54791 Mdot
.35695 .64799 Mdot
.51257 .35081 Mdot
.81886 .58026 Mdot
.39616 .44817 Mdot
.42386 .39627 Mdot
.28271 .67186 Mdot
.35862 .32025 Mdot
.37616 .44742 Mdot
.38195 .43947 Mdot
.57077 .59107 Mdot
.37412 .64162 Mdot
.61235 .77478 Mdot
.49119 .30395 Mdot
.34031 .41269 Mdot
.34337 .44182 Mdot
.65481 .48615 Mdot
.24753 .63177 Mdot
.52044 .64573 Mdot
.53427 .37151 Mdot
.32677 .44345 Mdot
.58541 .41664 Mdot
.36273 .60193 Mdot
.53483 .82735 Mdot
.61124 .57792 Mdot
.59347 .65294 Mdot
.51825 .35877 Mdot
.48581 .35399 Mdot
.43405 .44761 Mdot
.27398 .65518 Mdot
.75185 .6748 Mdot
.58127 .32459 Mdot
.67651 .65757 Mdot
.64774 .48527 Mdot
.6603 .40753 Mdot
.46817 .25736 Mdot
.51427 .3138 Mdot
.61699 .6264 Mdot
.67169 .41676 Mdot
.36507 .37712 Mdot
.72988 .3902 Mdot
.42983 .75167 Mdot
.34728 .73736 Mdot
.57287 .64742 Mdot
.671 .45403 Mdot
.64597 .46844 Mdot
.63222 .40077 Mdot
.32651 .35951 Mdot
.58488 .59203 Mdot
.57805 .64127 Mdot
.61201 .59337 Mdot
.55737 .51604 Mdot
.60013 .59112 Mdot
.65755 .34854 Mdot
.48615 .48699 Mdot
.67026 .57329 Mdot
.59331 .54136 Mdot
.54795 .35573 Mdot
.60146 .66305 Mdot
.36416 .5817 Mdot
.54646 .62421 Mdot
.43481 .75573 Mdot
.5313 .3508 Mdot
.65203 .37274 Mdot
.61477 .33529 Mdot
.61512 .65071 Mdot
.33079 .63292 Mdot
.48699 .40575 Mdot
.242 .32194 Mdot
.31244 .62757 Mdot
.63988 .45762 Mdot
.37057 .45391 Mdot
.4998 .31843 Mdot
.36364 .46891 Mdot
.53926 .56832 Mdot
.47354 .25972 Mdot
.45255 .22079 Mdot
.52942 .45685 Mdot
.58084 .5736 Mdot
.6502 .63357 Mdot
.64089 .4528 Mdot
.38588 .43291 Mdot
.61665 .49203 Mdot
.61396 .63355 Mdot
.34507 .5943 Mdot
.3639 .60977 Mdot
.44143 .40058 Mdot
.40014 .19921 Mdot
.69577 .3647 Mdot
.5172 .35655 Mdot
.34686 .42801 Mdot
.37807 .61053 Mdot
.65854 .26692 Mdot
.47643 .37459 Mdot
.52896 .32712 Mdot
.52952 .3657 Mdot
.57808 .67197 Mdot
.33328 .42604 Mdot
.66938 .56517 Mdot
.36403 .48746 Mdot
.57223 .63581 Mdot
.33112 .45192 Mdot
.36509 .42254 Mdot
.37326 .60116 Mdot
.5219 .3736 Mdot
.35505 .4799 Mdot
.53909 .60035 Mdot
.62787 .43406 Mdot
.54836 .41465 Mdot
.48717 .76105 Mdot
.68447 .26893 Mdot
.71341 .46681 Mdot
.62694 .46095 Mdot
.29106 .25464 Mdot
.54056 .33271 Mdot
.52783 .52984 Mdot
.26501 .38953 Mdot
.55668 .65966 Mdot
.55244 .84674 Mdot
.38797 .41848 Mdot
.36224 .4173 Mdot
.55732 .59106 Mdot
.38651 .39051 Mdot
.5932 .61277 Mdot
.3434 .47062 Mdot
.28207 .41972 Mdot
.56848 .52694 Mdot
.37989 .46388 Mdot
.59021 .53839 Mdot
.56329 .61951 Mdot
.66039 .46248 Mdot
.37762 .41191 Mdot
.52827 .62012 Mdot
.53917 .15866 Mdot
.48836 .3537 Mdot
.35067 .35598 Mdot
.49287 .71474 Mdot
.50332 .34695 Mdot
.6389 .42297 Mdot
.54019 .65723 Mdot
.36429 .61597 Mdot
.66458 .4239 Mdot
.50744 .78251 Mdot
.35437 .632 Mdot
.53333 .84545 Mdot
.64879 .46656 Mdot
.35334 .40937 Mdot
.36655 .58798 Mdot
.62709 .59166 Mdot
.32872 .42383 Mdot
.4509 .38235 Mdot
.37738 .44909 Mdot
.58831 .58453 Mdot
.39956 .27621 Mdot
.50812 .3771 Mdot
.58424 .63209 Mdot
.36392 .41474 Mdot
.36391 .31022 Mdot
.57566 .67043 Mdot
.55908 .59981 Mdot
.21708 .60867 Mdot
.46969 .82712 Mdot
.34904 .61278 Mdot
.62519 .40101 Mdot
.54297 .59321 Mdot
.33423 .5988 Mdot
.27851 .55044 Mdot
.59084 .66568 Mdot
.61525 .43678 Mdot
.62552 .54691 Mdot
.38088 .41714 Mdot
.49687 .34701 Mdot
.5282 .45199 Mdot
.33053 .60321 Mdot
.87293 .5183 Mdot
.34075 .47464 Mdot
.54011 .63893 Mdot
.57167 .57308 Mdot
.21191 .47731 Mdot
.67109 .46811 Mdot
.69 .7259 Mdot
.60448 .61369 Mdot
.54658 .52191 Mdot
.59479 .63253 Mdot
.39401 .41267 Mdot
.64686 .45345 Mdot
.59307 .59657 Mdot
.56768 .24441 Mdot
.61452 .67338 Mdot
.32487 .61883 Mdot
.75537 .3565 Mdot
.61886 .65584 Mdot
.34125 .82919 Mdot
.29381 .64433 Mdot
.3811 .46431 Mdot
.43937 .25457 Mdot
.67821 .18488 Mdot
.63415 .33814 Mdot
.6804 .42904 Mdot
.37852 .23581 Mdot
.35696 .46835 Mdot
.39585 .26452 Mdot
.28526 .25638 Mdot
.55986 .61876 Mdot
.60362 .66197 Mdot
.31893 .66037 Mdot
.3931 .4738 Mdot
.33114 .47173 Mdot
.57273 .55327 Mdot
.56581 .68887 Mdot
.36526 .47448 Mdot
.5364 .59853 Mdot
.55068 .5596 Mdot
.47367 .34003 Mdot
.62488 .45503 Mdot
.50762 .32917 Mdot
.53775 .35956 Mdot
.78503 .4195 Mdot
.2677 .62643 Mdot
.48936 .3482 Mdot
.54431 .35054 Mdot
.44929 .74665 Mdot
.35683 .71501 Mdot
.38193 .61041 Mdot
.44758 .17303 Mdot
.34563 .44579 Mdot
.58432 .59601 Mdot
.63437 .46589 Mdot
.75965 .65779 Mdot
.31859 .53703 Mdot
.62137 .77992 Mdot
.61568 .6295 Mdot
.34116 .45037 Mdot
.32686 .35909 Mdot
.54511 .68833 Mdot
.38111 .49926 Mdot
.59957 .65521 Mdot
.33034 .46879 Mdot
.76596 .51625 Mdot
.5623 .23087 Mdot
.32296 .46536 Mdot
.69202 .42082 Mdot
.59746 .64857 Mdot
.64185 .46246 Mdot
.51852 .33659 Mdot
.37464 .5933 Mdot
.34715 .60987 Mdot
.56727 .60335 Mdot
.62522 .56502 Mdot
.25265 .57376 Mdot
.56771 .62344 Mdot
.55104 .63272 Mdot
.31604 .36021 Mdot
.5494 .6261 Mdot
.59091 .5755 Mdot
.60199 .58299 Mdot
.57582 .68093 Mdot
.49644 .37623 Mdot
.53691 .21891 Mdot
.50943 .62753 Mdot
.50839 .63882 Mdot
.48682 .37859 Mdot
.29926 .29173 Mdot
.54034 .34584 Mdot
.24383 .30536 Mdot
.50126 .32722 Mdot
.34056 .60883 Mdot
.2243 .40799 Mdot
.64368 .62146 Mdot
.62758 .4157 Mdot
.46452 .35878 Mdot
.33878 .59718 Mdot
.51692 .34635 Mdot
.34118 .46562 Mdot
.17294 .53547 Mdot
.64758 .38363 Mdot
.48457 .66654 Mdot
.46129 .33732 Mdot
.4723 .26972 Mdot
.3587 .48276 Mdot
.6487 .46024 Mdot
.77623 .57606 Mdot
.58943 .57272 Mdot
.3383 .59492 Mdot
.57447 .59423 Mdot
.51759 .3779 Mdot
.34569 .45638 Mdot
.75691 .335 Mdot
.36474 .61711 Mdot
.24597 .66573 Mdot
.35537 .43889 Mdot
.60541 .582 Mdot
.5317 .37342 Mdot
.28105 .72178 Mdot
.50293 .33052 Mdot
.669 .71818 Mdot
.66937 .47649 Mdot
.82619 .42086 Mdot
.65887 .41898 Mdot
.43843 .36164 Mdot
.18448 .63753 Mdot
.55674 .20676 Mdot
.62816 .4254 Mdot
.51958 .2843 Mdot
.57244 .65255 Mdot
.57805 .65991 Mdot
.67389 .27393 Mdot
.62409 .40237 Mdot
.55146 .57919 Mdot
.2927 .36379 Mdot
.55024 .26229 Mdot
.36276 .76185 Mdot
.38367 .44473 Mdot
.59683 .61334 Mdot
.51964 .38822 Mdot
.50104 .32326 Mdot
.34958 .48161 Mdot
.53646 .33014 Mdot
.57781 .63886 Mdot
.6613 .42269 Mdot
.41624 .4705 Mdot
.34929 .59876 Mdot
.62184 .20148 Mdot
.36998 .57837 Mdot
.37563 .44703 Mdot
.62694 .5835 Mdot
.36216 .47125 Mdot
.69238 .17869 Mdot
.58203 .64427 Mdot
.63276 .44285 Mdot
.54571 .60398 Mdot
.59579 .64561 Mdot
.60593 .66145 Mdot
.35021 .46977 Mdot
.60702 .73781 Mdot
.5378 .59939 Mdot
.50451 .36502 Mdot
.67603 .59923 Mdot
.61961 .65131 Mdot
.37346 .39539 Mdot
.38756 .72635 Mdot
.46812 .29949 Mdot
.64298 .47387 Mdot
.38138 .45706 Mdot
.63276 .42664 Mdot
.62662 .50579 Mdot
.63894 .42326 Mdot
.69594 .62787 Mdot
.77639 .56056 Mdot
.61786 .74266 Mdot
.73123 .46179 Mdot
.52091 .50621 Mdot
.62487 .40147 Mdot
.30476 .64059 Mdot
.65535 .40361 Mdot
.65034 .47 Mdot
.10329 .61432 Mdot
.63385 .4076 Mdot
.6039 .62306 Mdot
.62289 .61881 Mdot
.50787 .24909 Mdot
.44172 .70934 Mdot
.55003 .61031 Mdot
.54735 .59387 Mdot
.37527 .59916 Mdot
.53217 .53749 Mdot
.45395 .25787 Mdot
.46083 .83498 Mdot
.41934 .24537 Mdot
.57331 .597 Mdot
.54242 .59578 Mdot
.56146 .69245 Mdot
.31012 .77673 Mdot
.81254 .45245 Mdot
.61263 .45571 Mdot
.59492 .69211 Mdot
.62108 .21843 Mdot
.60817 .65551 Mdot
.58856 .67263 Mdot
.57317 .6494 Mdot
.35605 .46773 Mdot
.61997 .46008 Mdot
.55001 .67402 Mdot
.28366 .648 Mdot
.5998 .66008 Mdot
.36214 .31654 Mdot
.80112 .34319 Mdot
.59788 .60926 Mdot
.62444 .46767 Mdot
.56897 .65897 Mdot
.66598 .46782 Mdot
.66499 .44944 Mdot
.63354 .64974 Mdot
.6783 .6482 Mdot
.63672 .48045 Mdot
.57165 .63576 Mdot
.34098 .45899 Mdot
.42456 .17204 Mdot
.58995 .58493 Mdot
.37888 .59852 Mdot
.6069 .61781 Mdot
.33467 .63539 Mdot
.5522 .6295 Mdot
.33823 .47294 Mdot
.78417 .62024 Mdot
.3564 .46084 Mdot
.83275 .45929 Mdot
.32338 .44216 Mdot
.22174 .61866 Mdot
.61249 .43681 Mdot
.3967 .2826 Mdot
.71363 .73682 Mdot
.35281 .34215 Mdot
.40727 .53207 Mdot
.46342 .49384 Mdot
.53207 .33126 Mdot
.67723 .46686 Mdot
.48605 .56037 Mdot
.26972 .40158 Mdot
.24965 .41663 Mdot
.35244 .4212 Mdot
.78328 .68334 Mdot
.63372 .78863 Mdot
.53865 .61891 Mdot
.73297 .60304 Mdot
.70552 .54596 Mdot
.60297 .66473 Mdot
.55338 .67397 Mdot
.29314 .41616 Mdot
.54139 .58193 Mdot
.621 .26689 Mdot
.37257 .4443 Mdot
.33985 .59571 Mdot
.63607 .45032 Mdot
.32979 .60212 Mdot
.26705 .40232 Mdot
.45891 .49729 Mdot
.33875 .46728 Mdot
.59503 .6838 Mdot
.54931 .59812 Mdot
.66514 .46439 Mdot
.60078 .4411 Mdot
.64484 .4043 Mdot
.3533 .62187 Mdot
.36694 .4442 Mdot
.81149 .55082 Mdot
.55094 .58749 Mdot
.65894 .43756 Mdot
.40349 .52407 Mdot
.54356 .59011 Mdot
.51153 .33999 Mdot
.57848 .65262 Mdot
.62565 .43434 Mdot
.54945 .62591 Mdot
.66078 .41841 Mdot
.36917 .45594 Mdot
.62067 .61683 Mdot
.56166 .58916 Mdot
.26622 .69992 Mdot
.33669 .60721 Mdot
.61309 .42463 Mdot
.31355 .3861 Mdot
.57272 .57022 Mdot
.40557 .30375 Mdot
.60217 .64911 Mdot
.72806 .38456 Mdot
.55568 .66225 Mdot
.34277 .34538 Mdot
.51398 .62997 Mdot
.59069 .58664 Mdot
.43073 .48082 Mdot
.70536 .56837 Mdot
.60604 .41595 Mdot
.5363 .37136 Mdot
.62432 .41351 Mdot
.37071 .76198 Mdot
.3114 .44885 Mdot
.38652 .43042 Mdot
.43607 .64427 Mdot
.57476 .68166 Mdot
.58824 .60927 Mdot
.49837 .38857 Mdot
.33758 .62699 Mdot
.65556 .44926 Mdot
.34592 .59091 Mdot
.28985 .69907 Mdot
.35624 .62882 Mdot
.38852 .4149 Mdot
.26709 .58159 Mdot
.81013 .51378 Mdot
.37506 .59997 Mdot
.62758 .42355 Mdot
.33571 .55061 Mdot
.58898 .67941 Mdot
.29921 .64591 Mdot
.35048 .59198 Mdot
.82594 .63253 Mdot
.59028 .57597 Mdot
.40253 .53466 Mdot
.49409 .34293 Mdot
.36993 .59245 Mdot
.53375 .33998 Mdot
.55343 .60633 Mdot
.44056 .26945 Mdot
.67663 .42367 Mdot
.50693 .38216 Mdot
.61152 .55814 Mdot
.34321 .62171 Mdot
.3296 .43675 Mdot
.4682 .37584 Mdot
.53001 .37646 Mdot
.32279 .2645 Mdot
.77263 .35353 Mdot
.36441 .44425 Mdot
.5028 .80177 Mdot
.50531 .32523 Mdot
.60693 .6651 Mdot
.50798 .55889 Mdot
.59056 .6546 Mdot
.67426 .35521 Mdot
.38338 .45317 Mdot
.51495 .23937 Mdot
.54414 .60415 Mdot
.61332 .604 Mdot
.60744 .41824 Mdot
.35343 .45314 Mdot
.65044 .42958 Mdot
.62847 .40777 Mdot
.36732 .45557 Mdot
.65145 .41601 Mdot
.35753 .63283 Mdot
.56833 .27988 Mdot
.47857 .34549 Mdot
.51064 .36771 Mdot
.34278 .4436 Mdot
.38252 .46612 Mdot
.36944 .47081 Mdot
.57885 .65284 Mdot
.65125 .45271 Mdot
.55934 .63218 Mdot
.59987 .66287 Mdot
.67105 .66717 Mdot
.63167 .46799 Mdot
.56542 .64547 Mdot
.43254 .40924 Mdot
.39444 .61912 Mdot
.33833 .45672 Mdot
.49122 .34715 Mdot
.33466 .30549 Mdot
.47441 .39493 Mdot
.59815 .6179 Mdot
.23734 .58838 Mdot
.63448 .41328 Mdot
.36288 .61337 Mdot
.38711 .59998 Mdot
.35394 .61282 Mdot
.54345 .31521 Mdot
.62077 .4069 Mdot
.46786 .83728 Mdot
.59394 .61051 Mdot
.44157 .54903 Mdot
.4748 .61403 Mdot
.24586 .57601 Mdot
.49023 .3504 Mdot
.54472 .59231 Mdot
.53988 .44688 Mdot
.78556 .57232 Mdot
.59052 .65152 Mdot
.61003 .66882 Mdot
.28134 .37136 Mdot
.62777 .54612 Mdot
.67253 .47702 Mdot
.29578 .72659 Mdot
.60296 .56782 Mdot
.58735 .42814 Mdot
.64884 .2051 Mdot
.60137 .63108 Mdot
.6136 .61794 Mdot
.56742 .57946 Mdot
.54638 .62768 Mdot
.63573 .47716 Mdot
.41429 .6783 Mdot
.53909 .32994 Mdot
.44204 .56153 Mdot
.48055 .36772 Mdot
.32222 .43307 Mdot
.53496 .22508 Mdot
.67766 .46742 Mdot
.36843 .61145 Mdot
.52953 .20057 Mdot
.37196 .79289 Mdot
.38852 .47162 Mdot
.79631 .45011 Mdot
.343 .59781 Mdot
.60913 .6651 Mdot
.35413 .63561 Mdot
.33517 .4247 Mdot
.50271 .36871 Mdot
.58078 .68468 Mdot
.65387 .40484 Mdot
.62954 .45431 Mdot
.54783 .58113 Mdot
.59958 .21097 Mdot
.50712 .3399 Mdot
.48795 .38427 Mdot
.58423 .66941 Mdot
.62645 .59079 Mdot
.64802 .42768 Mdot
.34849 .43177 Mdot
.44764 .78398 Mdot
.33394 .62183 Mdot
.52922 .59048 Mdot
.5495 .63452 Mdot
.27651 .66562 Mdot
.49552 .36586 Mdot
.40023 .44988 Mdot
.56552 .66478 Mdot
.57453 .32542 Mdot
.56454 .66368 Mdot
.58751 .69702 Mdot
.33956 .45573 Mdot
.51234 .61223 Mdot
.53502 .61055 Mdot
.49946 .64255 Mdot
.52412 .32966 Mdot
.63496 .43762 Mdot
.66278 .39082 Mdot
.45579 .56407 Mdot
.51355 .34045 Mdot
.5659 .65066 Mdot
.49453 .3561 Mdot
.59166 .66439 Mdot
.54303 .58321 Mdot
.48838 .34619 Mdot
.65072 .42868 Mdot
.37541 .241 Mdot
.53326 .21879 Mdot
.54474 .62434 Mdot
.58327 .56145 Mdot
.42427 .68906 Mdot
.5999 .74261 Mdot
.61239 .64071 Mdot
.62591 .44164 Mdot
.55347 .58923 Mdot
.53209 .34217 Mdot
.37004 .62694 Mdot
.62728 .43352 Mdot
.36204 .43281 Mdot
.38161 .47948 Mdot
.62099 .33543 Mdot
.37623 .42838 Mdot
.58527 .67731 Mdot
.62351 .50352 Mdot
.64834 .3894 Mdot
.64598 .21441 Mdot
.3632 .4545 Mdot
.37972 .62293 Mdot
.56034 .60109 Mdot
.22254 .5849 Mdot
.50838 .39015 Mdot
.39518 .86438 Mdot
.51675 .84594 Mdot
.34178 .57853 Mdot
.62999 .7677 Mdot
.3197 .44668 Mdot
.53165 .59923 Mdot
.37361 .59062 Mdot
.38445 .47372 Mdot
.55519 .65556 Mdot
.61526 .68444 Mdot
.68072 .73054 Mdot
.47858 .52765 Mdot
.49341 .3577 Mdot
.39213 .44516 Mdot
.36623 .5692 Mdot
.39938 .43355 Mdot
.63464 .46364 Mdot
.59033 .59002 Mdot
.63321 .59712 Mdot
.35569 .43077 Mdot
.39758 .46814 Mdot
.57036 .64183 Mdot
.68066 .46383 Mdot
.29471 .41705 Mdot
.57246 .60374 Mdot
.5358 .50268 Mdot
.69932 .43622 Mdot
.37403 .44028 Mdot
.60776 .59308 Mdot
.36318 .54997 Mdot
.35303 .43656 Mdot
.33696 .45552 Mdot
.54483 .58268 Mdot
.35444 .63311 Mdot
.58572 .56334 Mdot
.48992 .33097 Mdot
.82062 .59279 Mdot
.53388 .34739 Mdot
.33764 .53009 Mdot
.61864 .56088 Mdot
.57195 .34989 Mdot
.6518 .47518 Mdot
.33007 .66636 Mdot
.29795 .34118 Mdot
.57523 .55114 Mdot
.36799 .21294 Mdot
.53302 .43097 Mdot
.58093 .19606 Mdot
.20336 .40568 Mdot
.36143 .59311 Mdot
.51931 .34514 Mdot
.61363 .61979 Mdot
.4826 .32597 Mdot
.37636 .59252 Mdot
.82694 .45145 Mdot
.60404 .58737 Mdot
.6455 .45236 Mdot
.57428 .64323 Mdot
.64094 .4597 Mdot
.54288 .58704 Mdot
.53335 .67748 Mdot
.30172 .35942 Mdot
.49918 .77693 Mdot
.56277 .66712 Mdot
.18109 .57591 Mdot
.29909 .59171 Mdot
.33221 .60799 Mdot
.56155 .62695 Mdot
.36373 .50323 Mdot
.50835 .32025 Mdot
.67398 .29065 Mdot
.35574 .46835 Mdot
.5412 .35365 Mdot
.64556 .42146 Mdot
.37809 .45272 Mdot
.3803 .48233 Mdot
.51378 .61002 Mdot
.32412 .62421 Mdot
.51918 .37149 Mdot
.59495 .59597 Mdot
.60189 .58667 Mdot
.4695 .80242 Mdot
.30768 .52168 Mdot
.59955 .4117 Mdot
.37565 .8167 Mdot
.67319 .39877 Mdot
.3352 .61493 Mdot
.34964 .46619 Mdot
.60787 .64521 Mdot
.58219 .62984 Mdot
.38453 .29407 Mdot
.67235 .4116 Mdot
.50556 .49057 Mdot
.77051 .42972 Mdot
.30449 .40663 Mdot
.41478 .7302 Mdot
.63202 .44908 Mdot
.41803 .73143 Mdot
.38185 .5799 Mdot
.48326 .17837 Mdot
.4723 .7677 Mdot
.49413 .3454 Mdot
.41464 .72721 Mdot
.66308 .43972 Mdot
.53896 .611 Mdot
.35437 .40853 Mdot
.36665 .4234 Mdot
.64136 .43499 Mdot
.3984 .48307 Mdot
.37224 .60226 Mdot
.60962 .60647 Mdot
.45591 .82932 Mdot
.63058 .31834 Mdot
.34092 .43099 Mdot
.53248 .6784 Mdot
.53052 .36397 Mdot
.54914 .57908 Mdot
.37691 .60734 Mdot
.50381 .35246 Mdot
.29625 .66486 Mdot
.53599 .25282 Mdot
.56238 .60463 Mdot
.2334 .62668 Mdot
.51168 .34472 Mdot
.57921 .74929 Mdot
.57809 .59864 Mdot
.50924 .32523 Mdot
.65491 .65175 Mdot
.42593 .35206 Mdot
.54063 .452 Mdot
.28741 .25417 Mdot
.51802 .46971 Mdot
.3483 .41284 Mdot
.43609 .31944 Mdot
.38327 .37134 Mdot
.4888 .32277 Mdot
.40006 .46335 Mdot
.40572 .60488 Mdot
.53351 .33858 Mdot
.61776 .65303 Mdot
.60211 .64397 Mdot
.81501 .44966 Mdot
.51698 .43194 Mdot
.43928 .34446 Mdot
.68196 .3292 Mdot
.57844 .56971 Mdot
.60609 .56609 Mdot
.58253 .62385 Mdot
.63522 .48223 Mdot
.49679 .36197 Mdot
.2115 .63613 Mdot
.51343 .33767 Mdot
.52639 .82452 Mdot
.34496 .44769 Mdot
.38748 .45099 Mdot
.5988 .61394 Mdot
.403 .55334 Mdot
.36762 .69399 Mdot
.57629 .63685 Mdot
.41605 .60766 Mdot
.75132 .35164 Mdot
.62077 .57979 Mdot
.66122 .47758 Mdot
.51113 .58841 Mdot
.7034 .4097 Mdot
.47857 .3445 Mdot
.36051 .59967 Mdot
.34152 .66782 Mdot
.50445 .37089 Mdot
.58743 .61035 Mdot
.55183 .30126 Mdot
.59239 .64187 Mdot
.54526 .63245 Mdot
.55251 .8231 Mdot
.36553 .57562 Mdot
.37041 .46483 Mdot
.35256 .61497 Mdot
.66195 .47056 Mdot
.25919 .79268 Mdot
.33443 .62751 Mdot
.36207 .68979 Mdot
.83675 .4905 Mdot
.41798 .72691 Mdot
.63334 .46087 Mdot
.32119 .62207 Mdot
.50061 .34301 Mdot
.44224 .15912 Mdot
.71151 .72372 Mdot
.54751 .39802 Mdot
.57475 .6079 Mdot
.68784 .45042 Mdot
.62195 .44011 Mdot
.4974 .38152 Mdot
.66387 .44859 Mdot
.65104 .65741 Mdot
.54153 .61864 Mdot
.48983 .32038 Mdot
.57708 .31089 Mdot
.5345 .37393 Mdot
.57706 .26634 Mdot
.565 .62982 Mdot
.63015 .44334 Mdot
.55215 .55288 Mdot
.688 .47166 Mdot
.39924 .43896 Mdot
.62365 .6501 Mdot
.37246 .60383 Mdot
.57616 .37147 Mdot
.36286 .4424 Mdot
.2348 .57361 Mdot
.66265 .46603 Mdot
.48447 .28846 Mdot
.66225 .4605 Mdot
.63187 .39721 Mdot
.53904 .35423 Mdot
.67534 .43246 Mdot
.61283 .6137 Mdot
.43531 .39904 Mdot
.6768 .4588 Mdot
.52462 .35924 Mdot
.35506 .60112 Mdot
.65313 .41972 Mdot
.39098 .39213 Mdot
.56358 .59579 Mdot
.35895 .47603 Mdot
.22273 .42374 Mdot
.67878 .40988 Mdot
.33479 .59125 Mdot
.38537 .43078 Mdot
.34398 .5889 Mdot
.71895 .27273 Mdot
.49445 .31545 Mdot
.60009 .78317 Mdot
.3979 .57845 Mdot
.632 .41116 Mdot
.22727 .40573 Mdot
.60724 .64269 Mdot
.56151 .59751 Mdot
.33792 .63752 Mdot
.62196 .43959 Mdot
.52578 .1866 Mdot
.69766 .38591 Mdot
.5538 .27269 Mdot
.46528 .34076 Mdot
.20659 .60222 Mdot
.58315 .25799 Mdot
.76271 .28438 Mdot
.58945 .55478 Mdot
.32388 .46422 Mdot
.59375 .62078 Mdot
.30775 .33007 Mdot
.34492 .62089 Mdot
.41484 .43552 Mdot
.62727 .65805 Mdot
.3736 .4592 Mdot
.57234 .58362 Mdot
.44319 .44382 Mdot
.52214 .57721 Mdot
.38143 .61996 Mdot
.44335 .25678 Mdot
.62947 .4109 Mdot
.34796 .59765 Mdot
.33537 .46807 Mdot
.38275 .70527 Mdot
.54727 .64374 Mdot
.53128 .5747 Mdot
.30432 .40746 Mdot
.64759 .45763 Mdot
.36879 .41026 Mdot
.48223 .33771 Mdot
.3657 .60671 Mdot
.55017 .60384 Mdot
.56819 .67481 Mdot
.40266 .30688 Mdot
.5286 .36827 Mdot
.39021 .48523 Mdot
.50705 .33072 Mdot
.31863 .44977 Mdot
.55044 .56955 Mdot
.38801 .44845 Mdot
.53014 .61323 Mdot
.3104 .34775 Mdot
.55059 .82087 Mdot
.71437 .58343 Mdot
.38303 .45081 Mdot
.40327 .74276 Mdot
.53083 .34788 Mdot
.50791 .32757 Mdot
.8249 .52078 Mdot
.6675 .72387 Mdot
.42926 .80421 Mdot
.27364 .30368 Mdot
.47935 .36471 Mdot
.52933 .3622 Mdot
.36526 .4781 Mdot
.67707 .43674 Mdot
.65526 .39493 Mdot
.32137 .45625 Mdot
.4802 .70586 Mdot
.65563 .44902 Mdot
.42004 .18383 Mdot
.38382 .77721 Mdot
.54005 .66292 Mdot
.35591 .51052 Mdot
.36029 .60792 Mdot
.47091 .70635 Mdot
.442 .44462 Mdot
.61516 .61181 Mdot
.27191 .64647 Mdot
.34342 .43583 Mdot
.44692 .61677 Mdot
.24509 .30551 Mdot
.59954 .58129 Mdot
.58283 .59568 Mdot
.58682 .61801 Mdot
.32711 .59407 Mdot
.69746 .71122 Mdot
.6058 .59431 Mdot
.48372 .70829 Mdot
.56135 .5721 Mdot
.64176 .69185 Mdot
.34846 .61154 Mdot
.66278 .65158 Mdot
.26959 .37352 Mdot
.31265 .73522 Mdot
.53897 .55408 Mdot
.48494 .33326 Mdot
.40823 .62935 Mdot
.52093 .32662 Mdot
.69978 .61711 Mdot
.47354 .76491 Mdot
.68725 .41472 Mdot
.61518 .61685 Mdot
.37569 .44635 Mdot
.62227 .44238 Mdot
.42077 .32418 Mdot
.17178 .71026 Mdot
.48774 .32925 Mdot
.78048 .2805 Mdot
.50027 .32874 Mdot
.37499 .48482 Mdot
.64678 .42765 Mdot
.77614 .55051 Mdot
.44804 .54458 Mdot
.65429 .41798 Mdot
.43774 .22286 Mdot
.60955 .45382 Mdot
.40002 .73116 Mdot
.68588 .42659 Mdot
.52772 .35565 Mdot
.54125 .31408 Mdot
.63787 .66998 Mdot
.60707 .62972 Mdot
.46355 .48819 Mdot
.36213 .70738 Mdot
.60834 .63716 Mdot
.37027 .44485 Mdot
.62779 .7563 Mdot
.39527 .65369 Mdot
.67119 .43157 Mdot
.53991 .32757 Mdot
.58218 .59158 Mdot
.55757 .65332 Mdot
.54448 .63673 Mdot
.41235 .84544 Mdot
.48961 .176 Mdot
.53824 .59877 Mdot
.56971 .56902 Mdot
.37599 .45512 Mdot
.38898 .5801 Mdot
.29765 .32827 Mdot
.64723 .71078 Mdot
.61939 .62455 Mdot
.34324 .6037 Mdot
.36134 .57313 Mdot
.55777 .65969 Mdot
.28425 .63612 Mdot
.54703 .29967 Mdot
.59477 .59497 Mdot
.64791 .72854 Mdot
.33358 .37509 Mdot
.39307 .47344 Mdot
.3576 .43267 Mdot
.61978 .45104 Mdot
.37788 .43337 Mdot
.32307 .45426 Mdot
.78648 .52982 Mdot
.50467 .4806 Mdot
.55403 .34708 Mdot
.35441 .62205 Mdot
.58464 .63353 Mdot
.61268 .40047 Mdot
.56689 .31754 Mdot
.53654 .33952 Mdot
.64081 .41043 Mdot
.51115 .32183 Mdot
.31564 .63259 Mdot
.47684 .64874 Mdot
.3464 .42123 Mdot
.48313 .36632 Mdot
.53808 .25431 Mdot
.34401 .60538 Mdot
.53023 .37013 Mdot
.50519 .26839 Mdot
.62484 .63554 Mdot
.73618 .62608 Mdot
.57317 .63316 Mdot
.55228 .18767 Mdot
.51758 .3749 Mdot
.34187 .33766 Mdot
.58917 .60264 Mdot
.35309 .43881 Mdot
.62644 .69037 Mdot
.60276 .65499 Mdot
.36322 .42954 Mdot
.5383 .61703 Mdot
.36145 .57776 Mdot
.69857 .42565 Mdot
.44575 .56283 Mdot
.73127 .761 Mdot
.32376 .62405 Mdot
.41997 .3168 Mdot
.61412 .63694 Mdot
.75899 .32646 Mdot
.65475 .42099 Mdot
.53508 .62907 Mdot
.40336 .65537 Mdot
.68033 .44742 Mdot
.63622 .41902 Mdot
.56218 .65312 Mdot
.49693 .34008 Mdot
.36571 .44083 Mdot
.34696 .60794 Mdot
.7139 .25626 Mdot
.56958 .61315 Mdot
.55815 .5889 Mdot
.34537 .5971 Mdot
.53296 .35513 Mdot
.56956 .6663 Mdot
.20821 .45406 Mdot
.55292 .16935 Mdot
.53111 .3273 Mdot
.61878 .64756 Mdot
.70956 .66124 Mdot
.69075 .39338 Mdot
.85765 .47372 Mdot
.29746 .64638 Mdot
.37676 .46284 Mdot
.64085 .57653 Mdot
.28668 .79865 Mdot
.35917 .60098 Mdot
.38622 .79602 Mdot
.55251 .64695 Mdot
.55238 .58371 Mdot
.64347 .40533 Mdot
.56202 .63765 Mdot
.68202 .42629 Mdot
.73054 .75304 Mdot
.27263 .66521 Mdot
.64678 .46228 Mdot
.64438 .40202 Mdot
.37911 .67712 Mdot
.30074 .32806 Mdot
.64067 .43269 Mdot
.55019 .57233 Mdot
.65412 .51231 Mdot
.55791 .70805 Mdot
.34613 .63668 Mdot
.25607 .40186 Mdot
.67344 .37711 Mdot
.31688 .59515 Mdot
.33837 .25717 Mdot
.66132 .37501 Mdot
.55861 .32492 Mdot
.48329 .34023 Mdot
.6034 .58277 Mdot
.37058 .42488 Mdot
.38818 .43583 Mdot
.55598 .55358 Mdot
.5868 .64073 Mdot
.66187 .46922 Mdot
.36023 .62375 Mdot
.49314 .32256 Mdot
.54815 .59368 Mdot
.37733 .66799 Mdot
.33265 .62535 Mdot
.67175 .44618 Mdot
.63533 .7374 Mdot
.38421 .61665 Mdot
.51396 .65663 Mdot
.60145 .60447 Mdot
.57279 .64745 Mdot
.53673 .69507 Mdot
.4877 .35891 Mdot
.24393 .38619 Mdot
.61645 .58487 Mdot
.29022 .70112 Mdot
.56014 .40813 Mdot
.53524 .67352 Mdot
.65774 .45557 Mdot
.51493 .3901 Mdot
.36008 .40215 Mdot
.45981 .58453 Mdot
.56342 .60802 Mdot
.54501 .20876 Mdot
.80056 .42483 Mdot
.39443 .42917 Mdot
.62981 .39888 Mdot
.35953 .61346 Mdot
.57788 .63724 Mdot
.6808 .62149 Mdot
.6032 .63696 Mdot
.3401 .64434 Mdot
.33524 .44696 Mdot
.48462 .33918 Mdot
.575 .19109 Mdot
.38857 .43741 Mdot
.63335 .42484 Mdot
.17785 .33961 Mdot
.68625 .44029 Mdot
.6397 .39921 Mdot
.67636 .62519 Mdot
.48492 .35387 Mdot
.323 .82902 Mdot
.79386 .64644 Mdot
.63044 .62177 Mdot
.52878 .34269 Mdot
.64219 .44128 Mdot
.55881 .57613 Mdot
.68413 .46396 Mdot
.61568 .41146 Mdot
.55684 .56621 Mdot
.57488 .57666 Mdot
.54479 .23278 Mdot
.27616 .26913 Mdot
.35938 .61524 Mdot
.65018 .47157 Mdot
.52067 .51581 Mdot
.56673 .57404 Mdot
.59377 .60943 Mdot
.39546 .37395 Mdot
.35998 .63295 Mdot
.64825 .28419 Mdot
.55495 .65063 Mdot
.25971 .64985 Mdot
.51568 .5816 Mdot
.64191 .48044 Mdot
.53414 .33036 Mdot
.31273 .73157 Mdot
.46981 .32295 Mdot
.67677 .41898 Mdot
.36732 .61897 Mdot
.65092 .38686 Mdot
.35793 .69038 Mdot
.49846 .37885 Mdot
.62563 .43435 Mdot
.5302 .45112 Mdot
.50827 .35776 Mdot
.50186 .37461 Mdot
.67435 .59741 Mdot
.39084 .4902 Mdot
.33685 .58416 Mdot
.52318 .36977 Mdot
.54044 .51999 Mdot
.52301 .35316 Mdot
.81271 .57767 Mdot
.62093 .61801 Mdot
.45231 .65009 Mdot
.36606 .52477 Mdot
.64748 .62931 Mdot
.50615 .37745 Mdot
.3773 .60235 Mdot
.56563 .6607 Mdot
.66445 .44166 Mdot
.33019 .60764 Mdot
.48038 .39004 Mdot
.36196 .47335 Mdot
.66546 .45942 Mdot
.46099 .34811 Mdot
.63446 .45746 Mdot
.48302 .56266 Mdot
.83993 .53267 Mdot
.19028 .51207 Mdot
.45716 .53789 Mdot
.54534 .63736 Mdot
.27793 .31405 Mdot
.5297 .65619 Mdot
.58758 .64583 Mdot
.37291 .44141 Mdot
.43997 .6377 Mdot
.6501 .42925 Mdot
.55565 .17785 Mdot
.47978 .35793 Mdot
.29354 .72342 Mdot
.6503 .5046 Mdot
.54097 .63819 Mdot
.67794 .45848 Mdot
.68665 .43767 Mdot
.69841 .56369 Mdot
.36508 .40098 Mdot
.55473 .67335 Mdot
.56512 .68202 Mdot
.54395 .5675 Mdot
.49521 .36859 Mdot
.2384 .58388 Mdot
.34543 .41538 Mdot
.84831 .48816 Mdot
.33572 .43929 Mdot
.41879 .60404 Mdot
.6742 .4349 Mdot
.33714 .62859 Mdot
.5942 .60729 Mdot
.60443 .44869 Mdot
.67488 .41371 Mdot
.35351 .6412 Mdot
.36848 .59003 Mdot
.41148 .3677 Mdot
.4882 .34738 Mdot
.56963 .67329 Mdot
.60803 .59428 Mdot
.55727 .63022 Mdot
.5806 .65076 Mdot
.48274 .33328 Mdot
.5787 .66361 Mdot
.52259 .38572 Mdot
.48443 .59218 Mdot
.26647 .63639 Mdot
.51061 .47053 Mdot
.72396 .36898 Mdot
.66812 .43528 Mdot
.55337 .50515 Mdot
.53976 .68828 Mdot
.5743 .81688 Mdot
.7342 .3374 Mdot
.62503 .59789 Mdot
.38774 .47014 Mdot
.60562 .72965 Mdot
.35396 .41937 Mdot
.82571 .34131 Mdot
.39134 .31374 Mdot
.31351 .24068 Mdot
.5992 .58561 Mdot
.38318 .3785 Mdot
.57569 .51375 Mdot
.52964 .64724 Mdot
.40084 .33604 Mdot
.68039 .35702 Mdot
.47367 .2349 Mdot
.37701 .61683 Mdot
.56894 .59702 Mdot
.61104 .40369 Mdot
.61135 .60841 Mdot
.5947 .61637 Mdot
.55888 .65869 Mdot
.54277 .35789 Mdot
.55027 .6671 Mdot
.58694 .65894 Mdot
.25313 .56752 Mdot
.44039 .74818 Mdot
.39219 .43929 Mdot
.82601 .49618 Mdot
.33051 .62553 Mdot
.66964 .46537 Mdot
.44472 .20326 Mdot
.4936 .34626 Mdot
.69971 .55451 Mdot
.57708 .64954 Mdot
.53146 .23328 Mdot
.46146 .37751 Mdot
.36859 .60618 Mdot
.34186 .41352 Mdot
.36572 .20472 Mdot
.37048 .44901 Mdot
.537 .44608 Mdot
.35463 .44207 Mdot
.51377 .6636 Mdot
.65989 .46977 Mdot
.5702 .67028 Mdot
.5176 .3705 Mdot
.37193 .43364 Mdot
.43393 .69672 Mdot
.58405 .62375 Mdot
.36703 .45635 Mdot
.57084 .6705 Mdot
.47652 .65367 Mdot
.52675 .79626 Mdot
.32993 .464 Mdot
.53994 .37683 Mdot
.51177 .36261 Mdot
.35457 .6327 Mdot
.6711 .45987 Mdot
.65287 .40676 Mdot
.50587 .35227 Mdot
.67904 .74153 Mdot
.61802 .6354 Mdot
.57193 .5742 Mdot
.29612 .71782 Mdot
.61247 .63031 Mdot
.38577 .71709 Mdot
.53902 .44894 Mdot
.66966 .44172 Mdot
.53413 .59552 Mdot
.554 .64585 Mdot
.56185 .60264 Mdot
.47254 .59048 Mdot
.34812 .43014 Mdot
.61222 .58842 Mdot
.36445 .58603 Mdot
.43219 .44911 Mdot
.54935 .57863 Mdot
.52555 .58098 Mdot
.6508 .40649 Mdot
.39515 .82156 Mdot
.4956 .33113 Mdot
.34824 .47804 Mdot
.385 .45345 Mdot
.26092 .39905 Mdot
.58151 .39769 Mdot
.53352 .45244 Mdot
.84208 .45718 Mdot
.30116 .36141 Mdot
.33508 .60551 Mdot
.37924 .50863 Mdot
.56681 .41825 Mdot
.36998 .481 Mdot
.48818 .3281 Mdot
.62111 .61074 Mdot
.61977 .62333 Mdot
.54558 .84335 Mdot
.55028 .65316 Mdot
.35733 .61026 Mdot
.5085 .38647 Mdot
.66263 .43916 Mdot
.36829 .6077 Mdot
.51104 .329 Mdot
.64944 .459 Mdot
.62326 .59907 Mdot
.62183 .59702 Mdot
.64305 .40996 Mdot
.62396 .43187 Mdot
.59791 .60219 Mdot
.28724 .45927 Mdot
.626 .41729 Mdot
.62859 .44555 Mdot
.34423 .42156 Mdot
.36722 .42456 Mdot
.51241 .63138 Mdot
.5257 .34165 Mdot
.58529 .66055 Mdot
.37692 .45066 Mdot
.35785 .62811 Mdot
.65406 .42887 Mdot
.54564 .6278 Mdot
.5452 .59858 Mdot
.34543 .60453 Mdot
.37127 .6204 Mdot
.37181 .59695 Mdot
.53154 .37772 Mdot
.55808 .62141 Mdot
.6422 .42602 Mdot
.48651 .34518 Mdot
.3575 .57295 Mdot
.36378 .63399 Mdot
.40474 .44424 Mdot
.60869 .64619 Mdot
.41393 .48793 Mdot
.23326 .75547 Mdot
.32279 .71011 Mdot
.38225 .41172 Mdot
.38539 .40768 Mdot
.43429 .7272 Mdot
.41909 .56329 Mdot
.50699 .34365 Mdot
.37495 .6403 Mdot
.33553 .66818 Mdot
.6189 .65623 Mdot
.60136 .5678 Mdot
.59304 .69107 Mdot
.36516 .59138 Mdot
.42991 .6326 Mdot
.67584 .46977 Mdot
.75277 .43791 Mdot
.32817 .61931 Mdot
.39736 .4688 Mdot
.39825 .48694 Mdot
.33508 .44093 Mdot
.62135 .60399 Mdot
.71727 .57614 Mdot
.57902 .48212 Mdot
.25455 .32483 Mdot
.51849 .37601 Mdot
.6266 .38798 Mdot
.74866 .32122 Mdot
.64035 .4135 Mdot
.32593 .42969 Mdot
.34267 .59385 Mdot
.62412 .44047 Mdot
.51785 .32101 Mdot
.52702 .36535 Mdot
.34031 .43265 Mdot
.34235 .44666 Mdot
.3436 .46885 Mdot
.62983 .40102 Mdot
.6752 .43424 Mdot
.5633 .61181 Mdot
.65976 .42905 Mdot
.50182 .85268 Mdot
.31603 .61867 Mdot
.35717 .39425 Mdot
.51948 .34286 Mdot
.64327 .46204 Mdot
.58191 .62551 Mdot
.43737 .59129 Mdot
.66808 .34023 Mdot
.35099 .58431 Mdot
.48787 .80092 Mdot
.82495 .34476 Mdot
.5698 .6742 Mdot
.4942 .36407 Mdot
.45312 .82687 Mdot
.5845 .61739 Mdot
.34525 .46133 Mdot
.28756 .35247 Mdot
.31177 .45774 Mdot
.59827 .66294 Mdot
.60488 .67679 Mdot
.53512 .32808 Mdot
.83152 .44917 Mdot
.56641 .61574 Mdot
.64462 .2919 Mdot
.52391 .3136 Mdot
.34255 .41704 Mdot
.52151 .15338 Mdot
.2184 .46641 Mdot
.47268 .70253 Mdot
.3412 .42294 Mdot
.5966 .64629 Mdot
.35088 .42198 Mdot
.36034 .58125 Mdot
.32638 .44931 Mdot
.67302 .47454 Mdot
.38426 .42084 Mdot
.55877 .58787 Mdot
.63917 .43506 Mdot
.51177 .34369 Mdot
.32596 .76012 Mdot
.30019 .56209 Mdot
.35163 .43878 Mdot
.34661 .47921 Mdot
.53499 .60503 Mdot
.61825 .26154 Mdot
.58423 .54022 Mdot
.59047 .57691 Mdot
.4824 .36856 Mdot
.67743 .45513 Mdot
.542 .3397 Mdot
.52692 .62204 Mdot
.20409 .45172 Mdot
.50347 .3321 Mdot
.52324 .22326 Mdot
.34125 .59898 Mdot
.4527 .43879 Mdot
.58195 .63217 Mdot
.53601 .35379 Mdot
.55916 .62211 Mdot
.67136 .47228 Mdot
.48843 .43677 Mdot
.45457 .25502 Mdot
.50953 .37018 Mdot
.55494 .20075 Mdot
.40888 .58135 Mdot
.5948 .53006 Mdot
.51528 .32593 Mdot
.40795 .64949 Mdot
.37985 .48282 Mdot
.33267 .62016 Mdot
.37889 .58906 Mdot
.33031 .60236 Mdot
.59022 .54541 Mdot
.55309 .54092 Mdot
.36008 .57532 Mdot
.51284 .31775 Mdot
.38206 .61704 Mdot
.59108 .40814 Mdot
.5314 .18981 Mdot
.34379 .61871 Mdot
.57608 .6017 Mdot
.52217 .56286 Mdot
.44538 .74402 Mdot
.43 .36268 Mdot
.33455 .22881 Mdot
.6977 .31305 Mdot
.60616 .63074 Mdot
.68959 .40831 Mdot
.63718 .46732 Mdot
.42601 .81593 Mdot
.36537 .71871 Mdot
.29204 .6865 Mdot
.64209 .40104 Mdot
.39879 .27927 Mdot
.67091 .45064 Mdot
.54623 .64449 Mdot
.56502 .57539 Mdot
.65772 .39751 Mdot
.2461 .61335 Mdot
.42442 .28837 Mdot
.62987 .20949 Mdot
.63042 .45279 Mdot
.52461 .3293 Mdot
.49099 .38138 Mdot
.50038 .37522 Mdot
.39591 .78558 Mdot
.6833 .43618 Mdot
.55258 .61883 Mdot
.38237 .44928 Mdot
.61631 .59771 Mdot
.50184 .35901 Mdot
.55329 .17697 Mdot
.66522 .41834 Mdot
.59184 .58866 Mdot
.57317 .73443 Mdot
.35095 .46196 Mdot
.34008 .60603 Mdot
.51383 .69787 Mdot
.30107 .68887 Mdot
.48828 .36751 Mdot
.67796 .40702 Mdot
.35271 .32553 Mdot
.51243 .21091 Mdot
.60089 .55982 Mdot
.54107 .67256 Mdot
.73981 .26955 Mdot
.29692 .66715 Mdot
.59265 .67436 Mdot
.36275 .48366 Mdot
.37899 .29838 Mdot
.54497 .60563 Mdot
.64263 .46965 Mdot
.38378 .60194 Mdot
.34046 .59263 Mdot
.51575 .62083 Mdot
.43897 .55102 Mdot
.46083 .41037 Mdot
.56701 .65187 Mdot
.51686 .66115 Mdot
.34134 .41942 Mdot
.29679 .36271 Mdot
.28731 .6978 Mdot
.36891 .61875 Mdot
.57126 .66957 Mdot
.38497 .24467 Mdot
.65903 .40223 Mdot
.38797 .42206 Mdot
.51294 .37981 Mdot
.47606 .624 Mdot
.33763 .41859 Mdot
.54329 .60823 Mdot
.56607 .66375 Mdot
.5365 .36405 Mdot
.64278 .48083 Mdot
.36143 .58951 Mdot
.38486 .44792 Mdot
.37427 .61417 Mdot
.68152 .44414 Mdot
.66516 .42661 Mdot
.60821 .72382 Mdot
.63904 .63887 Mdot
.36029 .43341 Mdot
.52835 .59634 Mdot
.32332 .38402 Mdot
.83771 .42225 Mdot
.46473 .35919 Mdot
.57535 .67744 Mdot
.64343 .48593 Mdot
.50378 .36973 Mdot
.56134 .57878 Mdot
.71766 .25312 Mdot
.56551 .57338 Mdot
.56421 .39435 Mdot
.18549 .51445 Mdot
.37518 .60473 Mdot
.7488 .43319 Mdot
.6447 .25388 Mdot
.61156 .62343 Mdot
.38355 .46712 Mdot
.55355 .69123 Mdot
.50016 .33975 Mdot
.67215 .43229 Mdot
.86011 .46765 Mdot
.52232 .35704 Mdot
.60561 .59887 Mdot
.36662 .60693 Mdot
.68475 .42643 Mdot
.38723 .64079 Mdot
.28211 .63483 Mdot
.57409 .53422 Mdot
.52977 .58602 Mdot
.57707 .65623 Mdot
.21644 .40126 Mdot
.34617 .47634 Mdot
.63926 .44956 Mdot
.49348 .3648 Mdot
.50447 .35044 Mdot
.34218 .43324 Mdot
.5252 .25593 Mdot
.45412 .43703 Mdot
.22897 .73371 Mdot
.36217 .42745 Mdot
.32689 .6035 Mdot
.63545 .27754 Mdot
.38748 .46389 Mdot
.3626 .45654 Mdot
.34653 .41817 Mdot
.49563 .30164 Mdot
.65037 .45609 Mdot
.54228 .60181 Mdot
.64378 .47431 Mdot
.59568 .64931 Mdot
.56146 .40358 Mdot
.51201 .37174 Mdot
.67195 .42282 Mdot
.7282 .26923 Mdot
.73705 .66098 Mdot
.58169 .60927 Mdot
.75423 .32364 Mdot
.63375 .63908 Mdot
.40872 .71083 Mdot
.62406 .67032 Mdot
.34699 .44294 Mdot
.61653 .53705 Mdot
.54777 .56222 Mdot
.38083 .80279 Mdot
.51963 .34098 Mdot
.39175 .473 Mdot
.62644 .64955 Mdot
.50297 .63039 Mdot
.64357 .39513 Mdot
.62537 .44297 Mdot
.36986 .57994 Mdot
.5094 .78004 Mdot
.5119 .34126 Mdot
.79283 .63242 Mdot
.60659 .62365 Mdot
.21733 .55796 Mdot
.72724 .47014 Mdot
.56511 .57831 Mdot
.66273 .26131 Mdot
.71241 .5673 Mdot
.57919 .63584 Mdot
.5069 .50927 Mdot
.53221 .35477 Mdot
.19913 .46548 Mdot
.55751 .57154 Mdot
.35264 .46631 Mdot
.67573 .44196 Mdot
.67974 .46648 Mdot
.36245 .57672 Mdot
.61746 .79879 Mdot
.54277 .34638 Mdot
.67285 .42706 Mdot
.58844 .62641 Mdot
.48602 .35939 Mdot
.38081 .43382 Mdot
.54183 .64481 Mdot
.37293 .72687 Mdot
.66005 .4337 Mdot
.54082 .57853 Mdot
.62595 .29825 Mdot
.47368 .7346 Mdot
.18 .39867 Mdot
.49185 .3651 Mdot
.36341 .62993 Mdot
.55471 .69049 Mdot
.67262 .73495 Mdot
.61847 .57137 Mdot
.45154 .64252 Mdot
.59419 .39417 Mdot
.36746 .62873 Mdot
.58554 .60098 Mdot
.55031 .60718 Mdot
.38629 .53442 Mdot
.36471 .623 Mdot
.60634 .58973 Mdot
.49763 .58837 Mdot
.64683 .45571 Mdot
.31787 .43398 Mdot
.65851 .44269 Mdot
.57529 .60746 Mdot
.63428 .65995 Mdot
.63423 .41202 Mdot
.80898 .36355 Mdot
.34328 .57494 Mdot
.49504 .3329 Mdot
.62828 .58735 Mdot
.61062 .57795 Mdot
.17997 .59917 Mdot
.40006 .44537 Mdot
.32726 .29921 Mdot
.23951 .5159 Mdot
.35089 .25701 Mdot
.21795 .46831 Mdot
.23688 .29239 Mdot
.27435 .658 Mdot
.54254 .65868 Mdot
.71868 .42161 Mdot
.5671 .47941 Mdot
.51355 .37797 Mdot
.80725 .52968 Mdot
.60716 .63066 Mdot
.59483 .6192 Mdot
.387 .41943 Mdot
.51199 .23585 Mdot
.28964 .6866 Mdot
.43259 .57681 Mdot
.35958 .58987 Mdot
.65042 .47068 Mdot
.54161 .58989 Mdot
.51451 .49187 Mdot
.39292 .43952 Mdot
.2201 .56767 Mdot
.58955 .59008 Mdot
.56774 .81518 Mdot
.64085 .34471 Mdot
.48751 .35442 Mdot
.38596 .4573 Mdot
.29648 .67934 Mdot
.60681 .64991 Mdot
.51157 .38091 Mdot
.5718 .61957 Mdot
.2983 .46607 Mdot
.5266 .61093 Mdot
.34086 .6211 Mdot
.55122 .64641 Mdot
.42078 .60714 Mdot
.15655 .38258 Mdot
.34458 .64978 Mdot
.68783 .45389 Mdot
.33829 .39547 Mdot
.35115 .43043 Mdot
.62439 .43484 Mdot
.35362 .43224 Mdot
.70032 .5269 Mdot
.77225 .5234 Mdot
.3489 .59178 Mdot
.50494 .62567 Mdot
.3473 .61746 Mdot
.39696 .43205 Mdot
.60582 .64192 Mdot
.83685 .38979 Mdot
.36842 .43567 Mdot
.18974 .56452 Mdot
.52049 .35119 Mdot
.39891 .46068 Mdot
.55973 .57225 Mdot
.35605 .32983 Mdot
.39009 .43935 Mdot
.46042 .25622 Mdot
.56189 .60378 Mdot
.66554 .43251 Mdot
.54656 .6096 Mdot
.63171 .61076 Mdot
.35092 .48641 Mdot
.59305 .65982 Mdot
.51144 .32911 Mdot
.62427 .41325 Mdot
.43028 .17137 Mdot
.67624 .36004 Mdot
.61353 .60514 Mdot
.58755 .62361 Mdot
.63861 .38988 Mdot
.60967 .58319 Mdot
.48281 .33341 Mdot
.54507 .89939 Mdot
.34071 .59967 Mdot
.36073 .48742 Mdot
.21691 .46635 Mdot
.62518 .60231 Mdot
.57211 .66247 Mdot
.6968 .23513 Mdot
.20573 .4802 Mdot
.51381 .32684 Mdot
.5574 .55682 Mdot
.38576 .43645 Mdot
.36427 .60777 Mdot
.50783 .31641 Mdot
.5719 .64635 Mdot
.59165 .60502 Mdot
.35859 .63082 Mdot
.6543 .56365 Mdot
.36401 .76395 Mdot
.53361 .36846 Mdot
.62567 .55654 Mdot
.36996 .38839 Mdot
.61341 .64729 Mdot
.41803 .79799 Mdot
.62667 .43658 Mdot
.48523 .36651 Mdot
.27982 .32301 Mdot
.59389 .67116 Mdot
.53448 .33255 Mdot
.51341 .34053 Mdot
.56244 .55581 Mdot
.63866 .48664 Mdot
.61657 .41599 Mdot
.63565 .45912 Mdot
.53392 .86007 Mdot
.45985 .70592 Mdot
.34362 .46877 Mdot
.53243 .35554 Mdot
.3239 .45721 Mdot
.32075 .63043 Mdot
.55379 .44344 Mdot
.33638 .47124 Mdot
.62397 .45398 Mdot
.33879 .39723 Mdot
.55378 .60398 Mdot
.51006 .34395 Mdot
.3635 .48012 Mdot
.62932 .62384 Mdot
.5941 .24858 Mdot
.44544 .32115 Mdot
.37396 .62852 Mdot
.38331 .59623 Mdot
.55281 .57854 Mdot
.35499 .40288 Mdot
.59771 .60441 Mdot
.47152 .35409 Mdot
.61664 .26471 Mdot
.6211 .5765 Mdot
.3501 .43731 Mdot
.67398 .3922 Mdot
.2999 .68491 Mdot
.5989 .5367 Mdot
.57717 .60165 Mdot
.59633 .65367 Mdot
.57151 .62006 Mdot
.47148 .22693 Mdot
.46704 .33942 Mdot
.71775 .36658 Mdot
.23488 .39684 Mdot
.65764 .41573 Mdot
.61434 .45121 Mdot
.32132 .71475 Mdot
.54084 .2957 Mdot
.52753 .34323 Mdot
.58527 .6475 Mdot
.58214 .33723 Mdot
.54448 .17274 Mdot
.78359 .30724 Mdot
.35 .55302 Mdot
.39805 .44598 Mdot
.67199 .40119 Mdot
.39104 .45156 Mdot
.59962 .64441 Mdot
.56218 .69206 Mdot
.22712 .29663 Mdot
.53828 .31992 Mdot
.34872 .59033 Mdot
.59382 .6519 Mdot
.46607 .70908 Mdot
.37745 .45425 Mdot
.37439 .49313 Mdot
.59967 .58015 Mdot
.63112 .4765 Mdot
.15507 .49665 Mdot
.48873 .36023 Mdot
.69127 .30661 Mdot
.58375 .51009 Mdot
.69181 .33161 Mdot
.49812 .36037 Mdot
.28897 .61285 Mdot
.38052 .41167 Mdot
.67085 .52713 Mdot
.65786 .41382 Mdot
.33075 .60761 Mdot
.53941 .67583 Mdot
.65072 .40424 Mdot
.34236 .41573 Mdot
.66939 .43174 Mdot
.55617 .65664 Mdot
.50086 .31348 Mdot
.37784 .46397 Mdot
.55276 .34369 Mdot
.63137 .48202 Mdot
.36874 .61657 Mdot
.43157 .52233 Mdot
.78637 .58586 Mdot
.71022 .56342 Mdot
.61587 .59275 Mdot
.52473 .48606 Mdot
.5541 .62299 Mdot
.61007 .42896 Mdot
.57912 .62346 Mdot
.5983 .40422 Mdot
.38391 .46483 Mdot
.56762 .56931 Mdot
.57093 .65329 Mdot
.80867 .49322 Mdot
.58279 .5868 Mdot
.53389 .64044 Mdot
.57966 .63974 Mdot
.60898 .47894 Mdot
.50732 .61042 Mdot
.65613 .45797 Mdot
.27694 .59426 Mdot
.35959 .45629 Mdot
.38263 .60209 Mdot
.32761 .62638 Mdot
.45209 .65708 Mdot
.27294 .45833 Mdot
.51047 .24263 Mdot
.65387 .44329 Mdot
.51215 .3329 Mdot
.57588 .6239 Mdot
.24285 .31875 Mdot
.34058 .37347 Mdot
.37976 .42589 Mdot
.67621 .35967 Mdot
.63957 .58035 Mdot
.19814 .4218 Mdot
.53464 .58479 Mdot
.56334 .83933 Mdot
.64114 .63123 Mdot
.52754 .61565 Mdot
.33366 .47164 Mdot
.31338 .62234 Mdot
.59882 .57568 Mdot
.64613 .39507 Mdot
.3387 .62422 Mdot
.71229 .44776 Mdot
.42669 .45655 Mdot
.28681 .58593 Mdot
.79381 .49402 Mdot
.56209 .62054 Mdot
.37639 .46527 Mdot
.66479 .46091 Mdot
.28544 .6942 Mdot
.48645 .34368 Mdot
.56033 .36685 Mdot
.53159 .50944 Mdot
.77226 .32894 Mdot
.33158 .62492 Mdot
.66807 .58687 Mdot
.55664 .58878 Mdot
.33903 .53693 Mdot
.60712 .56793 Mdot
.54936 .17704 Mdot
.32258 .61348 Mdot
.61537 .43835 Mdot
.52439 .33047 Mdot
.63972 .4707 Mdot
.70949 .58011 Mdot
.34859 .50921 Mdot
.48533 .47329 Mdot
.36915 .45108 Mdot
.44026 .44663 Mdot
.6383 .44171 Mdot
.57591 .67031 Mdot
.22493 .73125 Mdot
.62747 .44254 Mdot
.67882 .41543 Mdot
.83886 .48684 Mdot
.83884 .41187 Mdot
.62659 .54962 Mdot
.63509 .40754 Mdot
.36397 .45084 Mdot
.36078 .61725 Mdot
.54757 .62357 Mdot
.55868 .61088 Mdot
.64813 .40532 Mdot
.35893 .48929 Mdot
.69549 .68086 Mdot
.3436 .44665 Mdot
.64714 .4589 Mdot
.35698 .46142 Mdot
.33731 .33813 Mdot
.37926 .47928 Mdot
.61035 .57838 Mdot
.57826 .6237 Mdot
.25294 .44759 Mdot
.66506 .42725 Mdot
.56487 .65075 Mdot
.53712 .61546 Mdot
.6425 .42852 Mdot
.31025 .64927 Mdot
.69831 .66593 Mdot
.61583 .62808 Mdot
.56739 .59411 Mdot
.36801 .62779 Mdot
.55927 .45433 Mdot
.58928 .77164 Mdot
.5654 .66037 Mdot
.3235 .60022 Mdot
.63832 .3985 Mdot
.59634 .59621 Mdot
.48461 .18564 Mdot
.38106 .29637 Mdot
.58766 .67345 Mdot
.38241 .48117 Mdot
.54551 .56497 Mdot
.17637 .41878 Mdot
.59085 .57649 Mdot
.64486 .43528 Mdot
.67959 .4398 Mdot
.79679 .62357 Mdot
.63194 .42943 Mdot
.36681 .42356 Mdot
.50545 .35829 Mdot
.55625 .18873 Mdot
.38148 .43469 Mdot
.61797 .56371 Mdot
.80126 .63779 Mdot
.54731 .65778 Mdot
.62652 .59763 Mdot
.16851 .49673 Mdot
.38259 .4394 Mdot
.67709 .46261 Mdot
.41555 .54677 Mdot
.61651 .68739 Mdot
.48908 .36929 Mdot
.52504 .66471 Mdot
.62065 .63863 Mdot
.18527 .52302 Mdot
.42132 .25189 Mdot
.48142 .37254 Mdot
.54891 .67162 Mdot
.56646 .66091 Mdot
.36313 .50412 Mdot
.58469 .62762 Mdot
.35692 .62092 Mdot
.6827 .44612 Mdot
.38772 .46727 Mdot
.34846 .60153 Mdot
.60975 .62832 Mdot
.36736 .59316 Mdot
.35769 .47556 Mdot
.49638 .37909 Mdot
.60239 .64756 Mdot
.348 .63703 Mdot
.36379 .59186 Mdot
.55483 .62933 Mdot
.67267 .43523 Mdot
.64199 .62436 Mdot
.59236 .58604 Mdot
.54572 .6307 Mdot
.65473 .40753 Mdot
.70466 .19879 Mdot
.57748 .57299 Mdot
.39898 .56468 Mdot
.67786 .4176 Mdot
.42122 .48804 Mdot
.39235 .46327 Mdot
.62155 .62985 Mdot
.48916 .37616 Mdot
.53354 .36201 Mdot
.33798 .42206 Mdot
.68458 .42092 Mdot
.23795 .4996 Mdot
.65617 .38508 Mdot
.6185 .68238 Mdot
.57901 .68115 Mdot
.74078 .70393 Mdot
.31288 .23772 Mdot
.66248 .47304 Mdot
.41432 .47176 Mdot
.43789 .56695 Mdot
.53406 .34483 Mdot
.39598 .47354 Mdot
.67533 .40332 Mdot
.68387 .43107 Mdot
.66773 .44153 Mdot
.33601 .59773 Mdot
.25535 .44763 Mdot
.65534 .48164 Mdot
.62253 .46575 Mdot
.55922 .60316 Mdot
.56785 .66055 Mdot
.32243 .6858 Mdot
.41093 .75493 Mdot
.37843 .60185 Mdot
.33735 .43929 Mdot
.46487 .87809 Mdot
.47211 .35122 Mdot
.80763 .46843 Mdot
.62311 .5837 Mdot
.22053 .75711 Mdot
.55019 .57596 Mdot
.58806 .62949 Mdot
.62626 .41113 Mdot
.36111 .63584 Mdot
.34093 .61372 Mdot
.6366 .44976 Mdot
.60909 .43563 Mdot
.35561 .62123 Mdot
.70703 .29522 Mdot
.51006 .17642 Mdot
.33699 .50606 Mdot
.64841 .4237 Mdot
.78591 .5703 Mdot
.52518 .37785 Mdot
.70572 .41534 Mdot
.47335 .33771 Mdot
.37146 .45718 Mdot
.35572 .40432 Mdot
.49618 .37031 Mdot
.56317 .60531 Mdot
.34197 .47018 Mdot
.54819 .66438 Mdot
.7281 .34222 Mdot
.72491 .62388 Mdot
.23258 .45681 Mdot
.52107 .5919 Mdot
.28465 .60446 Mdot
.48968 .27381 Mdot
.60704 .60838 Mdot
.39629 .22557 Mdot
.35466 .58829 Mdot
.69993 .45324 Mdot
.47674 .35799 Mdot
.16398 .42389 Mdot
.60146 .65535 Mdot
.64819 .43367 Mdot
.52009 .33849 Mdot
.46851 .61792 Mdot
.63832 .2866 Mdot
.59601 .65159 Mdot
.2523 .7668 Mdot
.62057 .49136 Mdot
.38455 .47048 Mdot
.655 .75774 Mdot
.65479 .47698 Mdot
.34889 .5564 Mdot
.25302 .38296 Mdot
.7461 .29214 Mdot
.6681 .46614 Mdot
.4006 .46858 Mdot
.64172 .46447 Mdot
.36704 .61852 Mdot
.69351 .42242 Mdot
.38202 .45633 Mdot
.58542 .59238 Mdot
.34433 .43604 Mdot
.37159 .58341 Mdot
.37385 .7651 Mdot
.48393 .37452 Mdot
.39079 .47384 Mdot
.51624 .3672 Mdot
.48769 .75403 Mdot
.21633 .41362 Mdot
.48636 .33725 Mdot
.63701 .73942 Mdot
.60105 .66963 Mdot
.64626 .4796 Mdot
.34444 .42717 Mdot
.2764 .36922 Mdot
.42912 .53512 Mdot
.64952 .41301 Mdot
.33979 .45796 Mdot
.54228 .49874 Mdot
.6439 .74534 Mdot
.54943 .55329 Mdot
.49374 .76901 Mdot
.64465 .42358 Mdot
.40379 .45379 Mdot
.29767 .72112 Mdot
.62625 .45964 Mdot
.35922 .4262 Mdot
.52841 .33088 Mdot
.50075 .35296 Mdot
.60672 .58628 Mdot
.55357 .33652 Mdot
.33294 .45008 Mdot
.47542 .28306 Mdot
.65209 .39932 Mdot
.46743 .59636 Mdot
.32688 .63091 Mdot
.35233 .45186 Mdot
.54955 .65282 Mdot
.68502 .47203 Mdot
.34916 .31887 Mdot
.70717 .68276 Mdot
.36767 .81542 Mdot
.34216 .43371 Mdot
.68235 .43091 Mdot
.65151 .43224 Mdot
.60216 .53961 Mdot
.45358 .54048 Mdot
.2397 .49209 Mdot
.50747 .70507 Mdot
.45461 .63098 Mdot
.32031 .43172 Mdot
.31714 .46277 Mdot
.62372 .65642 Mdot
.56579 .62587 Mdot
.53221 .33958 Mdot
.58122 .59316 Mdot
.62101 .42142 Mdot
.60734 .58402 Mdot
.49735 .3649 Mdot
.37044 .4462 Mdot
.60425 .64058 Mdot
.37609 .6052 Mdot
.5035 .38483 Mdot
.53377 .32574 Mdot
.35081 .44495 Mdot
.65327 .4044 Mdot
.33359 .65611 Mdot
.34199 .44672 Mdot
.56235 .6198 Mdot
.5718 .37596 Mdot
.54456 .63679 Mdot
.73649 .41221 Mdot
.62506 .45916 Mdot
.3896 .45813 Mdot
.64913 .39779 Mdot
.52332 .36351 Mdot
.2399 .39175 Mdot
.57701 .61297 Mdot
.36502 .42794 Mdot
.28502 .40357 Mdot
.71006 .47173 Mdot
.61638 .39986 Mdot
.49128 .2643 Mdot
.61102 .44169 Mdot
.35011 .41051 Mdot
.82653 .52976 Mdot
.3303 .61939 Mdot
.38197 .4275 Mdot
.3879 .19688 Mdot
.36029 .43616 Mdot
.57847 .58284 Mdot
.55141 .58097 Mdot
.38536 .4715 Mdot
.35356 .6331 Mdot
.27547 .67273 Mdot
.31967 .41862 Mdot
.67531 .46305 Mdot
.76375 .35755 Mdot
.28591 .75153 Mdot
.5525 .32481 Mdot
.52611 .33446 Mdot
.62492 .68403 Mdot
.53025 .62362 Mdot
.48126 .3295 Mdot
.54064 .32907 Mdot
.34906 .58358 Mdot
.35091 .41766 Mdot
.60561 .47745 Mdot
.54394 .36622 Mdot
.57484 .71636 Mdot
.27249 .46587 Mdot
.58116 .53883 Mdot
.58071 .50309 Mdot
.60376 .56829 Mdot
.45964 .6496 Mdot
.49531 .36537 Mdot
.53736 .59412 Mdot
.56317 .54982 Mdot
.4865 .37224 Mdot
.35962 .62028 Mdot
.53278 .27379 Mdot
.36361 .467 Mdot
.55981 .1548 Mdot
.531 .6089 Mdot
.57879 .58079 Mdot
.51578 .37641 Mdot
.24936 .54544 Mdot
.66707 .418 Mdot
.62847 .46499 Mdot
.34982 .47835 Mdot
.44149 .51651 Mdot
.62023 .62534 Mdot
.60165 .5961 Mdot
.37006 .47101 Mdot
.39743 .46508 Mdot
.4373 .3161 Mdot
.5491 .59578 Mdot
.52274 .34331 Mdot
.4173 .61667 Mdot
.49638 .36637 Mdot
.54663 .64446 Mdot
.5721 .58137 Mdot
.61041 .57895 Mdot
.55084 .654 Mdot
.52538 .31902 Mdot
.53976 .59343 Mdot
.51814 .57185 Mdot
.66948 .41673 Mdot
.58804 .65698 Mdot
.45977 .64096 Mdot
.57394 .59769 Mdot
.35944 .61822 Mdot
.63539 .7274 Mdot
.60183 .65399 Mdot
.62119 .61809 Mdot
.3132 .41714 Mdot
.58615 .60653 Mdot
.4715 .35173 Mdot
.65912 .42247 Mdot
.53198 .35734 Mdot
.52863 .37102 Mdot
.33158 .43014 Mdot
.35976 .57565 Mdot
.62538 .6073 Mdot
.35014 .58576 Mdot
.609 .56108 Mdot
.59117 .67341 Mdot
.25013 .40243 Mdot
.57593 .83532 Mdot
.38027 .7791 Mdot
.57553 .61285 Mdot
.37633 .43662 Mdot
.39206 .46102 Mdot
.69098 .48168 Mdot
.55821 .5484 Mdot
.49069 .32387 Mdot
.53512 .35683 Mdot
.38109 .72869 Mdot
.19118 .50057 Mdot
.35945 .61886 Mdot
.5323 .46966 Mdot
.55841 .6753 Mdot
.53909 .61639 Mdot
.54025 .6438 Mdot
.3257 .45876 Mdot
.42635 .58558 Mdot
.38211 .42896 Mdot
.6591 .34589 Mdot
.50375 .37204 Mdot
.59837 .65688 Mdot
.58503 .41808 Mdot
.62507 .44682 Mdot
.65959 .4231 Mdot
.52883 .32433 Mdot
.31442 .40084 Mdot
.3261 .70534 Mdot
.81033 .33316 Mdot
.62345 .49845 Mdot
.37565 .62893 Mdot
.60987 .61003 Mdot
.36434 .44408 Mdot
.63556 .46152 Mdot
.38174 .61599 Mdot
.57578 .67214 Mdot
.25557 .44636 Mdot
.57094 .61258 Mdot
.57111 .47855 Mdot
.67264 .44714 Mdot
.53862 .17911 Mdot
.68851 .44436 Mdot
.4998 .38511 Mdot
.47823 .35633 Mdot
.55925 .57996 Mdot
.70122 .7348 Mdot
.63962 .47428 Mdot
.48664 .29938 Mdot
.32635 .60531 Mdot
.36672 .31512 Mdot
.36255 .62192 Mdot
.38508 .46707 Mdot
.33654 .62491 Mdot
.38337 .45919 Mdot
.3796 .74726 Mdot
.5982 .41587 Mdot
.34596 .59833 Mdot
.29703 .47127 Mdot
.55964 .54534 Mdot
.37962 .61102 Mdot
.60423 .6915 Mdot
.74288 .42787 Mdot
.36511 .47162 Mdot
.32668 .62155 Mdot
.57379 .66933 Mdot
.22435 .3201 Mdot
.50796 .32757 Mdot
.48619 .32693 Mdot
.61527 .68354 Mdot
.32593 .43163 Mdot
.65376 .39491 Mdot
.49171 .20844 Mdot
.47681 .38105 Mdot
.56779 .57547 Mdot
.60087 .57743 Mdot
.61647 .45567 Mdot
.62815 .37228 Mdot
.5634 .58111 Mdot
.59316 .72976 Mdot
.54913 .59121 Mdot
.52389 .32483 Mdot
.64256 .47117 Mdot
.65496 .42809 Mdot
.34046 .46159 Mdot
.62642 .41985 Mdot
.65291 .50891 Mdot
.58734 .36476 Mdot
.64149 .66863 Mdot
.52121 .35937 Mdot
.62485 .35154 Mdot
.6627 .34739 Mdot
.33338 .2315 Mdot
.61959 .46647 Mdot
.59454 .56557 Mdot
.65937 .40199 Mdot
.3646 .61039 Mdot
.66348 .433 Mdot
.66976 .40008 Mdot
.60095 .60572 Mdot
.59642 .646 Mdot
.37913 .44548 Mdot
.44626 .5477 Mdot
.66264 .40698 Mdot
.5457 .58248 Mdot
.52976 .6327 Mdot
.53996 .65034 Mdot
.49025 .41962 Mdot
.65571 .4739 Mdot
.81595 .42807 Mdot
.40441 .66465 Mdot
.66124 .40622 Mdot
.15044 .47063 Mdot
.29479 .36189 Mdot
.39277 .41994 Mdot
.54447 .37461 Mdot
.54781 .59704 Mdot
.39597 .45397 Mdot
.60003 .64438 Mdot
.57951 .5031 Mdot
.59258 .61001 Mdot
.35376 .62323 Mdot
.54117 .65666 Mdot
.34663 .41001 Mdot
.34207 .44192 Mdot
.58241 .57443 Mdot
.60374 .63465 Mdot
.35752 .75198 Mdot
.61132 .45664 Mdot
.66797 .42399 Mdot
.23595 .51963 Mdot
.35876 .59544 Mdot
.48724 .36786 Mdot
.58028 .63223 Mdot
.32738 .43798 Mdot
.34202 .43882 Mdot
.65149 .47633 Mdot
.34749 .46286 Mdot
.48977 .36045 Mdot
.57927 .61597 Mdot
.4813 .33001 Mdot
.33722 .5957 Mdot
.65101 .47174 Mdot
.59215 .65453 Mdot
.55936 .60281 Mdot
.67961 .44041 Mdot
.62607 .64027 Mdot
.36689 .6279 Mdot
.35788 .43453 Mdot
.66376 .46622 Mdot
.50423 .35695 Mdot
.3859 .46278 Mdot
.54411 .62019 Mdot
.42869 .86023 Mdot
.57526 .5852 Mdot
.54614 .60262 Mdot
.38104 .19388 Mdot
.54862 .66738 Mdot
.34262 .42969 Mdot
.61747 .44548 Mdot
.51936 .60407 Mdot
.4464 .66386 Mdot
.75785 .25627 Mdot
.37673 .42451 Mdot
.61009 .60545 Mdot
.25775 .28476 Mdot
.60373 .59334 Mdot
.75033 .67893 Mdot
.3305 .51432 Mdot
.43662 .48151 Mdot
.63687 .61854 Mdot
.49411 .34675 Mdot
.37982 .44365 Mdot
.38179 .4675 Mdot
.78491 .39821 Mdot
.60134 .60199 Mdot
.55521 .47956 Mdot
.58499 .66636 Mdot
.49809 .35743 Mdot
.3691 .70874 Mdot
.34081 .43624 Mdot
.40973 .81485 Mdot
.55347 .61875 Mdot
.67758 .46745 Mdot
.34296 .39604 Mdot
.34176 .35284 Mdot
.54615 .62947 Mdot
.35869 .58371 Mdot
.53516 .37654 Mdot
.52187 .62687 Mdot
.51675 .35839 Mdot
.54595 .63461 Mdot
.61257 .72286 Mdot
.65137 .76964 Mdot
.67078 .43842 Mdot
.52694 .33183 Mdot
.56968 .36789 Mdot
.55287 .56745 Mdot
.66716 .4658 Mdot
.6564 .41318 Mdot
.35436 .58159 Mdot
.50162 .46064 Mdot
.60878 .29191 Mdot
.74533 .63344 Mdot
.78324 .38106 Mdot
.33143 .39643 Mdot
.43697 .27069 Mdot
.55201 .6373 Mdot
.21724 .54313 Mdot
.47624 .36521 Mdot
.58333 .58367 Mdot
.69903 .50025 Mdot
.63328 .45293 Mdot
.56432 .59119 Mdot
.34928 .61836 Mdot
.23141 .56449 Mdot
.22518 .57177 Mdot
.25426 .35814 Mdot
.36952 .45276 Mdot
.55785 .69106 Mdot
.64687 .67527 Mdot
.35767 .48477 Mdot
.61788 .65405 Mdot
.35464 .42802 Mdot
.73329 .31114 Mdot
.37786 .62277 Mdot
.66763 .47054 Mdot
.31351 .3602 Mdot
.62364 .62164 Mdot
.57739 .68207 Mdot
.38384 .59116 Mdot
.56519 .63102 Mdot
.60865 .80116 Mdot
.30813 .37982 Mdot
.35778 .47944 Mdot
.66849 .44072 Mdot
.6216 .60559 Mdot
.51595 .46087 Mdot
.59511 .58765 Mdot
.76052 .55905 Mdot
.62116 .61307 Mdot
.62192 .2874 Mdot
.67549 .44073 Mdot
.5167 .36174 Mdot
.55778 .56289 Mdot
.59212 .61752 Mdot
.40884 .6377 Mdot
.64012 .63883 Mdot
.5414 .58233 Mdot
.64016 .39239 Mdot
.63235 .46112 Mdot
.65529 .45699 Mdot
.37756 .41493 Mdot
.188 .51247 Mdot
.52737 .35137 Mdot
.51445 .5942 Mdot
.54859 .35668 Mdot
.6912 .71172 Mdot
.37831 .62486 Mdot
.26659 .30262 Mdot
.57691 .64861 Mdot
.65148 .45009 Mdot
.39392 .24684 Mdot
.63083 .40043 Mdot
.50715 .48819 Mdot
.51153 .34165 Mdot
.63135 .4472 Mdot
.59084 .62562 Mdot
.43222 .55244 Mdot
.22562 .35013 Mdot
.52593 .36678 Mdot
.61138 .55981 Mdot
.39825 .44106 Mdot
.22894 .44162 Mdot
.40762 .84881 Mdot
.51077 .32652 Mdot
.5663 .37565 Mdot
.60306 .60229 Mdot
.6233 .44624 Mdot
.49141 .35104 Mdot
.49582 .3301 Mdot
.34778 .46454 Mdot
.59417 .6475 Mdot
.5906 .64914 Mdot
.36216 .40783 Mdot
.53001 .36568 Mdot
.63313 .65053 Mdot
.52621 .60673 Mdot
.21075 .30769 Mdot
.49234 .54057 Mdot
.59499 .15122 Mdot
.64215 .51189 Mdot
.67962 .52902 Mdot
.51402 .20062 Mdot
.68268 .42668 Mdot
.60453 .653 Mdot
.52028 .64863 Mdot
.33313 .4489 Mdot
.58036 .60234 Mdot
.40017 .48762 Mdot
.52454 .33746 Mdot
.16071 .44924 Mdot
.60929 .33319 Mdot
.72811 .29094 Mdot
.58233 .60128 Mdot
.68325 .3676 Mdot
.3536 .60656 Mdot
.46678 .3347 Mdot
.6537 .46388 Mdot
.56031 .66301 Mdot
.3582 .75376 Mdot
.38254 .42859 Mdot
.63691 .41493 Mdot
.291 .69567 Mdot
.28808 .60268 Mdot
.54793 .64654 Mdot
.38855 .42711 Mdot
.40908 .23183 Mdot
.53492 .70327 Mdot
.46206 .36084 Mdot
.35671 .62292 Mdot
.38414 .44557 Mdot
.5338 .36485 Mdot
.61331 .50217 Mdot
.63017 .43869 Mdot
.67704 .39908 Mdot
.43965 .79743 Mdot
.36817 .48796 Mdot
.34936 .60668 Mdot
.19686 .48909 Mdot
.21556 .57439 Mdot
.35194 .62288 Mdot
.35983 .40368 Mdot
.63376 .46147 Mdot
.64173 .45092 Mdot
.65836 .42222 Mdot
.37922 .7929 Mdot
.68704 .43631 Mdot
.7964 .44154 Mdot
.55005 .66189 Mdot
.62203 .7079 Mdot
.60795 .60077 Mdot
.48822 .32401 Mdot
.6747 .45295 Mdot
.43103 .51533 Mdot
.58152 .54811 Mdot
.2262 .37791 Mdot
.59388 .58199 Mdot
.48021 .32285 Mdot
.55725 .59408 Mdot
.80169 .49854 Mdot
.66498 .40447 Mdot
.57689 .60856 Mdot
.46741 .34931 Mdot
.36632 .59849 Mdot
.643 .38362 Mdot
.5962 .65338 Mdot
.5228 .2412 Mdot
.54569 .66372 Mdot
.69507 .27187 Mdot
.47184 .57542 Mdot
.37553 .62897 Mdot
.52934 .53383 Mdot
.39125 .48741 Mdot
.63216 .69624 Mdot
.58165 .70507 Mdot
.51893 .36918 Mdot
.31928 .34047 Mdot
.36033 .45515 Mdot
.3616 .54856 Mdot
.51431 .65148 Mdot
.37648 .5888 Mdot
.60823 .44233 Mdot
.48959 .32064 Mdot
.60934 .66708 Mdot
.58724 .54005 Mdot
.7409 .36238 Mdot
.50581 .63914 Mdot
.60801 .58279 Mdot
.38671 .60898 Mdot
.77431 .41331 Mdot
.57021 .60003 Mdot
.51388 .48143 Mdot
.69166 .42358 Mdot
.63374 .65493 Mdot
.81178 .46717 Mdot
.5522 .5792 Mdot
.62873 .42527 Mdot
.61947 .39362 Mdot
.55224 .28443 Mdot
.33916 .58877 Mdot
.62129 .62825 Mdot
.79935 .61835 Mdot
.5568 .62066 Mdot
.52233 .34613 Mdot
.53223 .6233 Mdot
.37966 .45511 Mdot
.36124 .77416 Mdot
.33698 .46198 Mdot
.61792 .62513 Mdot
.65455 .42152 Mdot
.50588 .37589 Mdot
.44614 .81163 Mdot
.25814 .47736 Mdot
.78729 .43632 Mdot
.72181 .26111 Mdot
.34043 .62944 Mdot
.36082 .57358 Mdot
.49228 .31854 Mdot
.57555 .60796 Mdot
.83521 .51738 Mdot
.63951 .64716 Mdot
.56562 .59459 Mdot
.59364 .61108 Mdot
.21106 .43986 Mdot
.53222 .34404 Mdot
.35485 .46452 Mdot
.56694 .58139 Mdot
.53984 .58971 Mdot
.68105 .4242 Mdot
.36492 .59434 Mdot
.39248 .46238 Mdot
.34487 .59489 Mdot
.37177 .44118 Mdot
.15339 .45906 Mdot
.54637 .56575 Mdot
.36454 .59996 Mdot
.51543 .38829 Mdot
.65025 .406 Mdot
.58411 .36269 Mdot
.38339 .4681 Mdot
.33596 .44176 Mdot
.58571 .57705 Mdot
.62727 .42664 Mdot
.63689 .40303 Mdot
.36647 .61023 Mdot
.48315 .34424 Mdot
.6028 .65126 Mdot
.58915 .67539 Mdot
.7224 .38628 Mdot
.32456 .43836 Mdot
.56456 .49134 Mdot
.48367 .23965 Mdot
.57431 .61096 Mdot
.64125 .40311 Mdot
.60179 .62159 Mdot
.5378 .20402 Mdot
.62232 .43854 Mdot
.55367 .57625 Mdot
.23299 .6382 Mdot
.31685 .39653 Mdot
.57489 .29323 Mdot
.60263 .57431 Mdot
.62555 .19808 Mdot
.56067 .65104 Mdot
.17195 .34657 Mdot
.30785 .51065 Mdot
.61246 .65034 Mdot
.54538 .61605 Mdot
.71307 .64903 Mdot
.61216 .62824 Mdot
.35019 .40994 Mdot
.30129 .66881 Mdot
.65392 .39354 Mdot
.55046 .23863 Mdot
.66295 .67743 Mdot
.32281 .61518 Mdot
.35166 .47926 Mdot
.33281 .48532 Mdot
.3413 .6187 Mdot
.64684 .42613 Mdot
.57153 .62039 Mdot
.46202 .48337 Mdot
.31795 .44147 Mdot
.58483 .52682 Mdot
.51945 .34546 Mdot
.40881 .31855 Mdot
.30418 .40578 Mdot
.50851 .36045 Mdot
.5842 .65837 Mdot
.70657 .65833 Mdot
.4848 .7886 Mdot
.50094 .16813 Mdot
.52982 .3714 Mdot
.5216 .37104 Mdot
.35829 .78042 Mdot
.32331 .63045 Mdot
.74709 .35503 Mdot
.62898 .2853 Mdot
.49349 .37182 Mdot
.48612 .65198 Mdot
.364 .41839 Mdot
.53781 .25239 Mdot
.70109 .45105 Mdot
.56837 .67576 Mdot
.59107 .62296 Mdot
.48108 .349 Mdot
.71071 .46825 Mdot
.64305 .76554 Mdot
.51398 .36769 Mdot
.49898 .61365 Mdot
.47185 .43046 Mdot
.28927 .36328 Mdot
.3399 .42264 Mdot
.34392 .58506 Mdot
.38518 .57055 Mdot
.68176 .45779 Mdot
.35163 .57899 Mdot
.22693 .55737 Mdot
.5699 .63635 Mdot
.50385 .36754 Mdot
.35269 .31876 Mdot
.50563 .35331 Mdot
.34033 .61596 Mdot
.38054 .62569 Mdot
.66936 .41684 Mdot
.66764 .42723 Mdot
.68282 .54687 Mdot
.403 .71631 Mdot
.59935 .58597 Mdot
.28527 .31767 Mdot
.64963 .39873 Mdot
.60183 .52256 Mdot
.36559 .57598 Mdot
.36314 .59589 Mdot
.42818 .62213 Mdot
.5821 .64381 Mdot
.77462 .64966 Mdot
.58198 .63882 Mdot
.37764 .71006 Mdot
.6146 .57426 Mdot
.34746 .46371 Mdot
.58341 .64911 Mdot
.34058 .66166 Mdot
.61468 .66538 Mdot
.52845 .60912 Mdot
.32174 .44696 Mdot
.51969 .62345 Mdot
.37845 .45687 Mdot
.61646 .60805 Mdot
.3205 .62109 Mdot
.32801 .45657 Mdot
.45296 .69221 Mdot
.4157 .58906 Mdot
.3687 .40459 Mdot
.36865 .58264 Mdot
.32371 .62149 Mdot
.48142 .70735 Mdot
.65311 .46434 Mdot
.69814 .41377 Mdot
.57673 .60457 Mdot
.38269 .49238 Mdot
.5305 .33925 Mdot
.54184 .59172 Mdot
.52949 .64853 Mdot
.58915 .569 Mdot
.67889 .46408 Mdot
.23934 .4837 Mdot
.36686 .60472 Mdot
.37154 .41211 Mdot
.3132 .65234 Mdot
.33169 .42269 Mdot
.53726 .56566 Mdot
.5345 .67007 Mdot
.66774 .55234 Mdot
.35267 .28844 Mdot
.3478 .78435 Mdot
.62953 .43506 Mdot
.38487 .47873 Mdot
.32422 .62759 Mdot
.60455 .53154 Mdot
.64804 .45564 Mdot
.38155 .45634 Mdot
.57143 .61346 Mdot
.6095 .55784 Mdot
.64015 .35891 Mdot
.65969 .66287 Mdot
.4444 .63121 Mdot
.33904 .41949 Mdot
.39858 .47203 Mdot
.21628 .56531 Mdot
.30023 .62199 Mdot
.42939 .52897 Mdot
.59278 .59465 Mdot
.35627 .58432 Mdot
.63535 .46127 Mdot
.46372 .79512 Mdot
.47917 .34366 Mdot
.44916 .54465 Mdot
.58183 .60316 Mdot
.42305 .49223 Mdot
.6552 .42009 Mdot
.353 .61837 Mdot
.48083 .35156 Mdot
.3872 .58621 Mdot
.3456 .47896 Mdot
.78604 .3308 Mdot
.55968 .62454 Mdot
.59406 .57862 Mdot
.48987 .38081 Mdot
.63647 .45757 Mdot
.38226 .58484 Mdot
.73007 .33991 Mdot
.36721 .47779 Mdot
.83468 .53786 Mdot
.62517 .41801 Mdot
.79352 .5109 Mdot
.36769 .41223 Mdot
.53002 .32499 Mdot
.47471 .71214 Mdot
.49672 .36345 Mdot
.61913 .61551 Mdot
.65415 .43852 Mdot
.5156 .33023 Mdot
.45223 .56013 Mdot
.24601 .30015 Mdot
.79089 .55103 Mdot
.57436 .63313 Mdot
.19469 .3599 Mdot
.63925 .24165 Mdot
.61246 .46609 Mdot
.49026 .37749 Mdot
.59035 .58274 Mdot
.61126 .65891 Mdot
.55607 .61652 Mdot
.50879 .33587 Mdot
.2666 .38545 Mdot
.3671 .47316 Mdot
.60566 .60143 Mdot
.34841 .58436 Mdot
.37207 .45955 Mdot
.31642 .35921 Mdot
.33868 .43376 Mdot
.61892 .47121 Mdot
.53215 .62526 Mdot
.49969 .30778 Mdot
.14383 .41206 Mdot
.53063 .36053 Mdot
.36109 .40238 Mdot
.53431 .60695 Mdot
.34747 .31248 Mdot
.65354 .45648 Mdot
.36003 .47686 Mdot
.57985 .58087 Mdot
.30868 .36474 Mdot
.37748 .77088 Mdot
.33926 .43402 Mdot
.64408 .45945 Mdot
.45743 .19074 Mdot
.58055 .59653 Mdot
.55904 .64494 Mdot
.63589 .44674 Mdot
.66629 .69837 Mdot
.29661 .71552 Mdot
.60317 .62931 Mdot
.5149 .36248 Mdot
.85141 .45986 Mdot
.52736 .59091 Mdot
.38514 .67624 Mdot
.38134 .44562 Mdot
.53679 .26376 Mdot
.55063 .49696 Mdot
.60816 .53154 Mdot
.72515 .34131 Mdot
.54993 .41519 Mdot
.19346 .40256 Mdot
.40374 .48166 Mdot
.30763 .56785 Mdot
.18012 .41305 Mdot
.47311 .3329 Mdot
.63201 .37774 Mdot
.69163 .3015 Mdot
.46729 .83629 Mdot
.45811 .19825 Mdot
.26365 .56788 Mdot
.35353 .75159 Mdot
.46096 .46064 Mdot
.36763 .43679 Mdot
.39635 .61504 Mdot
.59934 .64917 Mdot
.63563 .23841 Mdot
.78722 .62262 Mdot
.70765 .73988 Mdot
.19729 .35298 Mdot
.7455 .67652 Mdot
.24507 .31572 Mdot
.34858 .2202 Mdot
.66662 .52348 Mdot
.36838 .27383 Mdot
.8372 .55089 Mdot
.229 .62124 Mdot
.79503 .38246 Mdot
.63597 .68225 Mdot
.51488 .49141 Mdot
.70174 .26309 Mdot
.78722 .46782 Mdot
.64986 .74896 Mdot
.34212 .46536 Mdot
.61867 .45211 Mdot
.67765 .29123 Mdot
.6087 .42206 Mdot
.54636 .3077 Mdot
.46658 .18242 Mdot
.26166 .27606 Mdot
.804 .4942 Mdot
.5852 .17344 Mdot
.71248 .49476 Mdot
.70749 .78838 Mdot
.31753 .42686 Mdot
.65989 .47689 Mdot
.33302 .57123 Mdot
.21107 .55952 Mdot
.67241 .33707 Mdot
.6782 .28066 Mdot
.24335 .41597 Mdot
.453 .73578 Mdot
.64865 .43206 Mdot
.51654 .53968 Mdot
.50141 .28217 Mdot
.61653 .33642 Mdot
.30085 .67174 Mdot
.38567 .20933 Mdot
.4657 .4953 Mdot
.53373 .24214 Mdot
.42107 .2953 Mdot
.4051 .84395 Mdot
.41645 .65367 Mdot
.63581 .5255 Mdot
.57428 .38101 Mdot
.52497 .19862 Mdot
.51009 .83225 Mdot
.4074 .73233 Mdot
.21252 .56452 Mdot
.17923 .55751 Mdot
.59854 .21022 Mdot
.1991 .64807 Mdot
.69538 .4155 Mdot
.60506 .57972 Mdot
.68048 .64103 Mdot
.80647 .60304 Mdot
.36683 .6389 Mdot
.26122 .35805 Mdot
.32668 .61267 Mdot
.64944 .49127 Mdot
.3456 .75782 Mdot
.80282 .45527 Mdot
.80757 .61052 Mdot
.36155 .56911 Mdot
.52219 .59041 Mdot
.8894 .44223 Mdot
.2088 .38549 Mdot
.57984 .31322 Mdot
.19925 .318 Mdot
.41644 .51734 Mdot
.46871 .61167 Mdot
.51543 .33128 Mdot
.17613 .40298 Mdot
.64589 .44633 Mdot
.16277 .59352 Mdot
.16811 .3689 Mdot
.60172 .76058 Mdot
.62012 .12102 Mdot
.2091 .51455 Mdot
.43195 .4892 Mdot
.54156 .4082 Mdot
.4327 .67833 Mdot
.60717 .78713 Mdot
.59371 .74814 Mdot
.37035 .29964 Mdot
.70439 .2451 Mdot
.18785 .39315 Mdot
.82034 .56992 Mdot
.7908 .34707 Mdot
.48976 .84088 Mdot
.53474 .45495 Mdot
.70893 .43327 Mdot
.30767 .45563 Mdot
.36166 .23524 Mdot
.1611 .5023 Mdot
.40347 .66178 Mdot
.77643 .2713 Mdot
.31457 .64409 Mdot
.29312 .50629 Mdot
.47102 .16903 Mdot
.46664 .73442 Mdot
.50204 .5459 Mdot
.27889 .65704 Mdot
.58697 .52915 Mdot
.26874 .62819 Mdot
.28487 .30359 Mdot
.57299 .34857 Mdot
.23352 .62055 Mdot
.45116 .21596 Mdot
.73732 .36171 Mdot
.72934 .61405 Mdot
.20713 .56573 Mdot
.63112 .39734 Mdot
.43163 .73207 Mdot
.49894 .5436 Mdot
.25201 .28039 Mdot
.56499 .37667 Mdot
.30134 .22911 Mdot
.30378 .7165 Mdot
.58137 .55988 Mdot
.60039 .70087 Mdot
.50277 .59009 Mdot
.41465 .71407 Mdot
.52396 .60873 Mdot
.67227 .35133 Mdot
.31137 .23529 Mdot
.72517 .47154 Mdot
.52534 .27675 Mdot
.31204 .34652 Mdot
.48832 .16413 Mdot
.68561 .59112 Mdot
.29909 .61303 Mdot
.33792 .69557 Mdot
.45773 .84994 Mdot
.35937 .45875 Mdot
.82389 .54952 Mdot
.46089 .3582 Mdot
.40548 .78029 Mdot
.74648 .63768 Mdot
.58786 .78021 Mdot
.31292 .23402 Mdot
.27482 .59295 Mdot
.3309 .73761 Mdot
.50005 .75589 Mdot
.84189 .48716 Mdot
.29243 .34918 Mdot
.52712 .66649 Mdot
.61076 .23989 Mdot
.35172 .63361 Mdot
.70354 .5766 Mdot
.82864 .43664 Mdot
.2643 .52962 Mdot
.59605 .68835 Mdot
.54039 .79133 Mdot
.37698 .38685 Mdot
.43375 .5508 Mdot
.27443 .75422 Mdot
.56704 .54285 Mdot
.19656 .49864 Mdot
.62078 .21896 Mdot
.41553 .68247 Mdot
.51645 .18346 Mdot
.49974 .21705 Mdot
.18636 .61713 Mdot
.18743 .34492 Mdot
.25251 .48112 Mdot
.17863 .43054 Mdot
.23376 .29055 Mdot
.20448 .64257 Mdot
.56289 .7051 Mdot
.48717 .38128 Mdot
.36758 .84758 Mdot
.34879 .41295 Mdot
.20121 .45332 Mdot
.78356 .38216 Mdot
.32675 .36512 Mdot
.6028 .47257 Mdot
.65699 .62772 Mdot
.4659 .46695 Mdot
.61689 .47421 Mdot
.52137 .61915 Mdot
.28302 .74401 Mdot
.19286 .60461 Mdot
.24365 .70275 Mdot
.62377 .20865 Mdot
.16827 .44601 Mdot
.4449 .43849 Mdot
.79384 .46336 Mdot
.69264 .47904 Mdot
.56312 .66909 Mdot
.38051 .54784 Mdot
.20955 .5109 Mdot
.53481 .79483 Mdot
.65942 .32204 Mdot
.60935 .44956 Mdot
.2705 .33504 Mdot
.7266 .80736 Mdot
.70113 .51778 Mdot
.81513 .46001 Mdot
.22211 .57109 Mdot
.40147 .70702 Mdot
.34146 .25401 Mdot
.59481 .77006 Mdot
.36995 .20261 Mdot
.6186 .48179 Mdot
.78698 .37509 Mdot
.27522 .55739 Mdot
.48942 .67846 Mdot
.2397 .47477 Mdot
.27368 .27606 Mdot
.46074 .4002 Mdot
.49415 .80815 Mdot
.63771 .27808 Mdot
.6183 .76318 Mdot
.33333 .52152 Mdot
.41587 .31723 Mdot
.82865 .44452 Mdot
.44112 .25462 Mdot
.38116 .69568 Mdot
.48066 .44012 Mdot
.56025 .52116 Mdot
.54916 .41421 Mdot
.38743 .69101 Mdot
.47583 .66764 Mdot
.17885 .46334 Mdot
.12972 .38365 Mdot
.35744 .80237 Mdot
.55791 .15814 Mdot
.30689 .28718 Mdot
.60197 .68372 Mdot
.42997 .16637 Mdot
.21895 .6841 Mdot
.15894 .36993 Mdot
.42054 .35965 Mdot
.40073 .48904 Mdot
.54941 .34152 Mdot
.2976 .74331 Mdot
.26759 .4185 Mdot
.41545 .18352 Mdot
.27129 .6492 Mdot
.55257 .3543 Mdot
.58683 .83196 Mdot
.19134 .57811 Mdot
.76356 .61909 Mdot
.66192 .64958 Mdot
.63296 .62801 Mdot
.8071 .53292 Mdot
.60981 .4374 Mdot
.44207 .27095 Mdot
.41139 .72539 Mdot
.34874 .44894 Mdot
.38285 .55146 Mdot
.66228 .26797 Mdot
.54223 .65816 Mdot
.57013 .41686 Mdot
.62356 .46854 Mdot
.35893 .284 Mdot
.59985 .35499 Mdot
.15444 .49784 Mdot
.21971 .47766 Mdot
.62911 .58616 Mdot
.41276 .6783 Mdot
.23472 .47853 Mdot
.29601 .72047 Mdot
.51677 .31363 Mdot
.21204 .3338 Mdot
.48987 .51114 Mdot
.42846 .73088 Mdot
.80068 .57222 Mdot
.73722 .41806 Mdot
.54587 .67427 Mdot
.45075 .23745 Mdot
.75343 .54695 Mdot
.44238 .55264 Mdot
.69878 .46014 Mdot
.7073 .40814 Mdot
.45141 .15325 Mdot
.23472 .57112 Mdot
.40971 .30441 Mdot
.23082 .31669 Mdot
.50197 .34467 Mdot
.65327 .40146 Mdot
.40742 .59417 Mdot
.73082 .32978 Mdot
.76993 .51551 Mdot
.37809 .77167 Mdot
.31811 .37539 Mdot
.27431 .52347 Mdot
.23577 .31797 Mdot
.20773 .34648 Mdot
.7544 .70632 Mdot
.61299 .40251 Mdot
.67456 .507 Mdot
.75115 .34501 Mdot
.61337 .43535 Mdot
.72613 .36472 Mdot
.69427 .35743 Mdot
.16428 .48576 Mdot
.54494 .31414 Mdot
.68739 .22987 Mdot
.45643 .65704 Mdot
.25878 .38422 Mdot
.4406 .81184 Mdot
.82857 .45044 Mdot
.25199 .30537 Mdot
.50877 .68162 Mdot
.72347 .66324 Mdot
.64068 .67364 Mdot
.59371 .48121 Mdot
.47175 .86691 Mdot
.41253 .59593 Mdot
.79536 .51185 Mdot
.45553 .21176 Mdot
.56625 .62297 Mdot
.3619 .81043 Mdot
.71115 .30765 Mdot
.35778 .78283 Mdot
.54485 .36759 Mdot
.57218 .66191 Mdot
.60609 .67451 Mdot
.35936 .68281 Mdot
.5555 .2848 Mdot
.18321 .49102 Mdot
.83455 .42605 Mdot
.41283 .22481 Mdot
.7864 .62332 Mdot
.20061 .48965 Mdot
.41134 .19208 Mdot
.62669 .23304 Mdot
.50124 .47082 Mdot
.2127 .50512 Mdot
.47307 .7273 Mdot
.58621 .17675 Mdot
.43735 .59726 Mdot
.45282 .37007 Mdot
.69558 .34312 Mdot
.49181 .23463 Mdot
.45874 .80165 Mdot
.55284 .6493 Mdot
.29091 .69549 Mdot
.36436 .21451 Mdot
.76912 .67619 Mdot
.5743 .81486 Mdot
.33852 .79247 Mdot
.75813 .57981 Mdot
.49272 .22745 Mdot
.63109 .24077 Mdot
.85663 .53088 Mdot
.49408 .51337 Mdot
.2389 .35789 Mdot
.48122 .73825 Mdot
.23411 .31684 Mdot
.47955 .37573 Mdot
.64893 .29413 Mdot
.30791 .34936 Mdot
.17586 .44909 Mdot
.69449 .61925 Mdot
.29859 .25651 Mdot
.43094 .50134 Mdot
.17584 .60039 Mdot
.42122 .25476 Mdot
.45789 .4484 Mdot
.37547 .48327 Mdot
.26847 .59753 Mdot
.27875 .3015 Mdot
.33485 .28777 Mdot
.82524 .45334 Mdot
.40483 .45287 Mdot
.40253 .60111 Mdot
.76933 .6285 Mdot
.4773 .76387 Mdot
.46444 .22803 Mdot
.41312 .67848 Mdot
.28808 .25658 Mdot
.32229 .66931 Mdot
.29993 .69996 Mdot
.20952 .47415 Mdot
.76997 .29756 Mdot
.57683 .30809 Mdot
.24166 .59471 Mdot
.69821 .29423 Mdot
.29334 .49627 Mdot
.48083 .63771 Mdot
.07095 .55228 Mdot
.76569 .31392 Mdot
.39221 .264 Mdot
.16145 .5024 Mdot
.5373 .19771 Mdot
.35851 .28709 Mdot
.59843 .789 Mdot
.49495 .53721 Mdot
.35792 .73757 Mdot
.59287 .6116 Mdot
.25787 .73029 Mdot
.45217 .75251 Mdot
.16253 .53233 Mdot
.44485 .16266 Mdot
.80363 .54409 Mdot
.53407 .64538 Mdot
.37903 .41868 Mdot
.55743 .32131 Mdot
.4554 .7727 Mdot
.69118 .67309 Mdot
.48687 .57392 Mdot
.29658 .38341 Mdot
.35991 .48583 Mdot
.23414 .50076 Mdot
.62917 .49845 Mdot
.26433 .41083 Mdot
.48232 .23767 Mdot
.32499 .39287 Mdot
.46575 .50647 Mdot
.3944 .69433 Mdot
.54745 .50131 Mdot
.76663 .61191 Mdot
.57399 .78338 Mdot
.54427 .43914 Mdot
.33742 .43324 Mdot
.74928 .62096 Mdot
.71987 .27117 Mdot
.41555 .23136 Mdot
.17528 .54955 Mdot
.28006 .63094 Mdot
.70373 .68904 Mdot
.37923 .69035 Mdot
.61872 .78218 Mdot
.68834 .72893 Mdot
.30966 .31759 Mdot
.60077 .50338 Mdot
.65325 .73756 Mdot
.62297 .2517 Mdot
.16069 .44428 Mdot
.7935 .38111 Mdot
.76328 .35177 Mdot
.30211 .47483 Mdot
.77829 .47174 Mdot
.79176 .58953 Mdot
.45695 .68838 Mdot
.43121 .53579 Mdot
.6746 .80854 Mdot
.70485 .43265 Mdot
.53255 .88667 Mdot
.5213 .32496 Mdot
.50185 .84738 Mdot
.48357 .72928 Mdot
.4826 .43608 Mdot
.40927 .53524 Mdot
.45768 .23994 Mdot
.62609 .28978 Mdot
.64465 .22254 Mdot
.68795 .74409 Mdot
.32389 .42986 Mdot
.83721 .42301 Mdot
.77584 .29909 Mdot
.72607 .64144 Mdot
.53216 .5805 Mdot
.76229 .3037 Mdot
.40812 .47228 Mdot
.53635 .7955 Mdot
.51773 .18054 Mdot
.34614 .27173 Mdot
.55911 .70838 Mdot
.40521 .71192 Mdot
.24052 .35214 Mdot
.20868 .32649 Mdot
.60016 .81589 Mdot
.28624 .30288 Mdot
.48436 .37873 Mdot
.44881 .45001 Mdot
.30443 .25984 Mdot
.46318 .60152 Mdot
.55093 .24976 Mdot
.4859 .56339 Mdot
.61109 .86196 Mdot
.20144 .43718 Mdot
.18387 .48843 Mdot
.47242 .57851 Mdot
.68684 .42639 Mdot
.54405 .28482 Mdot
.50513 .54215 Mdot
.36302 .26311 Mdot
.70505 .27379 Mdot
.50298 .54163 Mdot
.82716 .62422 Mdot
.74159 .42843 Mdot
.42542 .41635 Mdot
.78362 .61508 Mdot
.72118 .47102 Mdot
.54437 .36969 Mdot
.3072 .68862 Mdot
.44161 .21072 Mdot
.49821 .38619 Mdot
.45876 .22881 Mdot
.52588 .24589 Mdot
.7527 .41258 Mdot
.77486 .52527 Mdot
.38368 .23679 Mdot
.70091 .65052 Mdot
.6145 .38108 Mdot
.45532 .79278 Mdot
.37078 .40141 Mdot
.4429 .20457 Mdot
.37275 .48024 Mdot
.60777 .52307 Mdot
.45047 .54936 Mdot
.61755 .72867 Mdot
.33343 .77711 Mdot
.34107 .63023 Mdot
.64141 .47277 Mdot
.52401 .85406 Mdot
.61723 .42961 Mdot
.27032 .73272 Mdot
.59204 .77599 Mdot
.80212 .57012 Mdot
.25642 .48993 Mdot
.25105 .53277 Mdot
.76691 .72149 Mdot
.56969 .40373 Mdot
.30082 .43746 Mdot
.58995 .38762 Mdot
.65631 .4757 Mdot
.21772 .46783 Mdot
.32387 .44649 Mdot
.49629 .52575 Mdot
.44042 .39196 Mdot
.68716 .37616 Mdot
.59655 .43314 Mdot
.47691 .52302 Mdot
.366 .72837 Mdot
.16829 .47484 Mdot
.36256 .42878 Mdot
.56947 .86352 Mdot
.5365 .66036 Mdot
.72489 .60636 Mdot
.36969 .20058 Mdot
.59897 .82523 Mdot
.31721 .46814 Mdot
.78179 .30061 Mdot
.61482 .57109 Mdot
.35371 .24918 Mdot
.64476 .43909 Mdot
.77235 .36014 Mdot
.33169 .62426 Mdot
.42129 .6808 Mdot
.54629 .33911 Mdot
.49022 .80919 Mdot
.35248 .37739 Mdot
.66914 .39604 Mdot
.30899 .2953 Mdot
.68228 .50266 Mdot
.60394 .26707 Mdot
.24138 .52263 Mdot
.72978 .64328 Mdot
.77502 .51334 Mdot
.5977 .42474 Mdot
.18355 .47289 Mdot
.77646 .35856 Mdot
.14532 .45906 Mdot
.52227 .56089 Mdot
.29329 .58964 Mdot
.70504 .35208 Mdot
.43107 .23366 Mdot
.58783 .48495 Mdot
.34128 .21513 Mdot
.41973 .73532 Mdot
.70806 .38049 Mdot
.38066 .70695 Mdot
.6338 .57471 Mdot
.48334 .47944 Mdot
.44131 .28322 Mdot
.70235 .74718 Mdot
.57212 .47666 Mdot
.52902 .83244 Mdot
.59397 .49842 Mdot
.19326 .51727 Mdot
.62759 .50386 Mdot
.35215 .49051 Mdot
.78438 .4798 Mdot
.568 .37129 Mdot
.16693 .42869 Mdot
.35065 .21008 Mdot
.51588 .30966 Mdot
.23475 .43792 Mdot
.51471 .19552 Mdot
.61577 .54994 Mdot
.43656 .46187 Mdot
.61213 .58737 Mdot
.68566 .489 Mdot
.60605 .82827 Mdot
.39091 .24761 Mdot
.54075 .68249 Mdot
.19061 .40434 Mdot
.18214 .3931 Mdot
.17221 .57671 Mdot
.83817 .51895 Mdot
.68313 .43373 Mdot
.22493 .66967 Mdot
.48803 .57637 Mdot
.22556 .30162 Mdot
.31473 .30996 Mdot
.43473 .15574 Mdot
.72009 .65932 Mdot
.47748 .21292 Mdot
.6325 .75623 Mdot
.59125 .28129 Mdot
.58262 .20765 Mdot
.45774 .41449 Mdot
.3972 .30574 Mdot
.55756 .19666 Mdot
.87305 .54991 Mdot
.62883 .54381 Mdot
.52786 .24164 Mdot
.65357 .27642 Mdot
.434 .20655 Mdot
.32267 .52696 Mdot
.53243 .62319 Mdot
.34184 .32722 Mdot
.40113 .79661 Mdot
.39879 .68159 Mdot
.39973 .61274 Mdot
.32014 .52396 Mdot
.41079 .76666 Mdot
.37612 .71735 Mdot
.79515 .38123 Mdot
.72813 .65203 Mdot
.52876 .49867 Mdot
.55438 .56667 Mdot
.61146 .48665 Mdot
.33745 .58621 Mdot
.4284 .39412 Mdot
.61385 .59834 Mdot
.37569 .49511 Mdot
.60444 .27302 Mdot
.31894 .77662 Mdot
.56111 .31483 Mdot
.70103 .28811 Mdot
.68498 .47018 Mdot
.51701 .25406 Mdot
.58474 .42578 Mdot
.41824 .81789 Mdot
.30822 .55254 Mdot
.40378 .66146 Mdot
.21191 .37007 Mdot
.23169 .61726 Mdot
.74192 .39841 Mdot
.22881 .6385 Mdot
.47892 .36892 Mdot
.51171 .66195 Mdot
.67311 .2993 Mdot
.22854 .51158 Mdot
.6879 .47556 Mdot
.47421 .21462 Mdot
.30087 .42906 Mdot
.2363 .59912 Mdot
.61265 .21378 Mdot
.71519 .46921 Mdot
.75112 .65177 Mdot
.20135 .35629 Mdot
.37505 .42381 Mdot
.76541 .33749 Mdot
.55054 .24354 Mdot
.29807 .56876 Mdot
.18529 .5225 Mdot
.15606 .47884 Mdot
.42548 .52142 Mdot
.4525 .72023 Mdot
.55415 .6304 Mdot
.8157 .42828 Mdot
.41201 .24323 Mdot
.6389 .6967 Mdot
.40992 .35509 Mdot
.63632 .40817 Mdot
.4329 .31249 Mdot
.52044 .49217 Mdot
.38034 .75058 Mdot
.6082 .43135 Mdot
.78689 .62957 Mdot
.31909 .61597 Mdot
.40282 .51828 Mdot
.52087 .61103 Mdot
.44227 .70416 Mdot
.81828 .59259 Mdot
.51765 .57753 Mdot
.30966 .27604 Mdot
.74044 .63819 Mdot
.73671 .34294 Mdot
.36851 .24825 Mdot
.30765 .32244 Mdot
.61953 .28922 Mdot
.78776 .50653 Mdot
.40759 .38139 Mdot
.5924 .5701 Mdot
.34684 .48951 Mdot
.62902 .40448 Mdot
.48067 .18155 Mdot
.75951 .56759 Mdot
.4538 .69601 Mdot
.50433 .43245 Mdot
.62138 .5204 Mdot
.51911 .42154 Mdot
.41162 .17274 Mdot
.59208 .28283 Mdot
.40991 .72706 Mdot
.55019 .31831 Mdot
.4801 .72555 Mdot
.58377 .7855 Mdot
.16642 .38518 Mdot
.61628 .77346 Mdot
.45527 .49503 Mdot
.54006 .83307 Mdot
.4482 .2511 Mdot
.52426 .18272 Mdot
.39547 .7261 Mdot
.39547 .52806 Mdot
.35812 .64559 Mdot
.64384 .36103 Mdot
.52595 .45093 Mdot
.38426 .64204 Mdot
.51107 .51768 Mdot
.38413 .36023 Mdot
.47589 .29051 Mdot
.65641 .62992 Mdot
.20616 .44795 Mdot
.20727 .36366 Mdot
.77715 .36948 Mdot
.54598 .42033 Mdot
.33487 .55294 Mdot
.40201 .75544 Mdot
.49556 .13131 Mdot
.42329 .85696 Mdot
.55477 .62899 Mdot
.55128 .42386 Mdot
.4376 .71786 Mdot
.33906 .4185 Mdot
.5363 .51541 Mdot
.58241 .41737 Mdot
.53323 .33192 Mdot
.40792 .60287 Mdot
.24537 .61468 Mdot
.46438 .24234 Mdot
.49559 .76663 Mdot
.31474 .35543 Mdot
.3194 .78032 Mdot
.69951 .25422 Mdot
.41924 .23785 Mdot
.44209 .13837 Mdot
.47577 .28323 Mdot
.69127 .38718 Mdot
.67777 .62422 Mdot
.17105 .4783 Mdot
.41748 .66833 Mdot
.43102 .79332 Mdot
.30251 .33751 Mdot
.40961 .7325 Mdot
.47713 .61394 Mdot
.20438 .48396 Mdot
.4267 .32506 Mdot
.47502 .45822 Mdot
.25269 .53595 Mdot
.20609 .60468 Mdot
.7567 .65767 Mdot
.22599 .35454 Mdot
.41524 .80581 Mdot
.85313 .56991 Mdot
.1732 .40683 Mdot
.39904 .56948 Mdot
.33078 .5421 Mdot
.68094 .63049 Mdot
.45532 .63311 Mdot
.48992 .65957 Mdot
.52586 .79721 Mdot
.76334 .50907 Mdot
.25638 .44962 Mdot
.48445 .83128 Mdot
.38163 .69505 Mdot
.73066 .45862 Mdot
.39736 .5287 Mdot
.76239 .61099 Mdot
.23496 .44547 Mdot
.46433 .58274 Mdot
.43677 .58794 Mdot
.44314 .65557 Mdot
.74274 .62729 Mdot
.72875 .35555 Mdot
.51834 .2104 Mdot
.83528 .62816 Mdot
.27964 .33746 Mdot
.43208 .8232 Mdot
.54639 .65838 Mdot
.14093 .4895 Mdot
.52491 .22026 Mdot
.29332 .33875 Mdot
.66305 .24546 Mdot
.42939 .43423 Mdot
.70978 .39192 Mdot
.5916 .57002 Mdot
.27124 .31915 Mdot
.79636 .52076 Mdot
.68968 .50924 Mdot
.47688 .81368 Mdot
.41233 .6939 Mdot
.29593 .66045 Mdot
.45999 .68021 Mdot
.50172 .60431 Mdot
.61873 .44045 Mdot
.23498 .69247 Mdot
.44226 .49704 Mdot
.61219 .52385 Mdot
.62494 .70886 Mdot
.62443 .75668 Mdot
.71878 .24869 Mdot
.50563 .58549 Mdot
.22037 .59804 Mdot
.73491 .68564 Mdot
.57534 .72057 Mdot
.57418 .50766 Mdot
.51274 .08974 Mdot
.15071 .36082 Mdot
.66116 .39387 Mdot
.81764 .46986 Mdot
.74034 .6825 Mdot
.17703 .46427 Mdot
.27918 .55573 Mdot
.42259 .37758 Mdot
.59026 .74019 Mdot
.46644 .64025 Mdot
.5125 .62796 Mdot
.63088 .22495 Mdot
.17066 .37224 Mdot
.48178 .81897 Mdot
.19113 .40061 Mdot
.6199 .69331 Mdot
.50856 .62315 Mdot
.53496 .12276 Mdot
.29338 .26988 Mdot
.60274 .53824 Mdot
.64225 .7583 Mdot
.70851 .43438 Mdot
.6002 .63951 Mdot
.24514 .38454 Mdot
.8338 .41863 Mdot
.37774 .69361 Mdot
.1759 .45014 Mdot
.61118 .41006 Mdot
.30679 .43444 Mdot
.5304 .32677 Mdot
.4168 .53587 Mdot
.5971 .55495 Mdot
.50791 .33255 Mdot
.62411 .73161 Mdot
.47464 .20742 Mdot
.52903 .3022 Mdot
.79973 .37129 Mdot
.33753 .20127 Mdot
.7661 .57668 Mdot
.62189 .36428 Mdot
.60277 .53266 Mdot
.72984 .45559 Mdot
.44407 .77327 Mdot
.70958 .46092 Mdot
.54439 .18869 Mdot
.11047 .57678 Mdot
.38873 .31773 Mdot
.33466 .71387 Mdot
.6426 .4953 Mdot
.54173 .49377 Mdot
.77869 .5992 Mdot
.4019 .50661 Mdot
.38162 .4364 Mdot
.63652 .66463 Mdot
.51062 .58306 Mdot
.53886 .37149 Mdot
.52005 .88062 Mdot
.5343 .61856 Mdot
.55912 .50208 Mdot
.22692 .3021 Mdot
.45421 .79287 Mdot
.71262 .60756 Mdot
.62551 .59246 Mdot
.62422 .33866 Mdot
.39425 .5277 Mdot
.40676 .20696 Mdot
.29757 .69593 Mdot
.19724 .40788 Mdot
.75937 .56345 Mdot
.74775 .66097 Mdot
.54091 .58588 Mdot
.33949 .6396 Mdot
.54702 .26014 Mdot
.25468 .36797 Mdot
.60012 .69826 Mdot
.19858 .33071 Mdot
.42913 .41652 Mdot
.35574 .37206 Mdot
.49332 .62685 Mdot
.17984 .59397 Mdot
.53319 .82134 Mdot
.79493 .56368 Mdot
.39838 .81226 Mdot
.23247 .54046 Mdot
.47516 .76234 Mdot
.38184 .42268 Mdot
.60756 .69476 Mdot
.61913 .40195 Mdot
.32893 .79363 Mdot
.23798 .38272 Mdot
.37696 .30422 Mdot
.41346 .32045 Mdot
.79873 .43004 Mdot
.59831 .25702 Mdot
.41064 .15218 Mdot
.24096 .54151 Mdot
.33277 .79204 Mdot
.76378 .34738 Mdot
.66504 .49373 Mdot
.47691 .22383 Mdot
.50277 .63582 Mdot
.34643 .43082 Mdot
.19351 .42159 Mdot
.54147 .54951 Mdot
.34997 .75848 Mdot
.62399 .64788 Mdot
.33792 .76955 Mdot
.39924 .63492 Mdot
.22733 .43546 Mdot
.4154 .26063 Mdot
.59082 .78907 Mdot
.45599 .17924 Mdot
.65559 .35924 Mdot
.4719 .1452 Mdot
.45784 .1868 Mdot
.20794 .33766 Mdot
.39079 .78177 Mdot
.63781 .79739 Mdot
.33554 .29009 Mdot
.38897 .23629 Mdot
.46056 .25803 Mdot
.6723 .68352 Mdot
.26835 .59374 Mdot
.49799 .59735 Mdot
.56769 .2843 Mdot
.49111 .31316 Mdot
.24686 .78856 Mdot
.34903 .6632 Mdot
.68107 .39718 Mdot
.25113 .57857 Mdot
.18703 .37171 Mdot
.65784 .70803 Mdot
.57363 .19719 Mdot
.51198 .49308 Mdot
.52549 .66347 Mdot
.76857 .53213 Mdot
.78956 .39973 Mdot
.27246 .60802 Mdot
.77156 .72789 Mdot
.70341 .26171 Mdot
.39733 .34395 Mdot
.48169 .48947 Mdot
.61211 .43584 Mdot
.59185 .42906 Mdot
.25629 .51569 Mdot
.56736 .18427 Mdot
.4764 .21101 Mdot
.30247 .26128 Mdot
.76889 .71719 Mdot
.74636 .34562 Mdot
.16984 .47771 Mdot
.42728 .24791 Mdot
.68535 .40732 Mdot
.38807 .55785 Mdot
.40355 .42047 Mdot
.38446 .29401 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Sooooo`;o0000Y?oo
ool001cooooo00?o0000ooooooooool0Xoooool2o`000:Cooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0:[ooooo0_l0000Jooooo`;o0000POooool001cooooo00?o0000ooooooooool0Z_ooool2
o`0001[ooooo0_l00021ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo09gooooo0_l0002Zooooo`007?ooool00ol0003oooooooooo`2Mooooo`;o0000
Z_ooool001cooooo00?o0000ooooooooool0S?ooool2o`000;_ooooo000Looooo`03o`000?oooooo
oooo08cooooo0_l0002kooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo09Kooooo0_l0002aooooo`007?ooool00ol0003oooooooooo`2Fooooo`;o0000
/Oooool001cooooo0_l00023ooooo`;o00002oooool2o`0001Gooooo0_l0000Eooooo`;o0000R_oo
ool001cooooo00?o0000ooooooooool0P_ooool2o`0000Gooooo0_l00004ooooo`;o00005Oooool2
o`0000[ooooo0_l000000ooooooo0000o`000006ooooo`;o00001?ooool2o`0008Cooooo000Loooo
o`03o`000?oooooooooo08Wooooo0_l000000ooooooo0000o`00000Mooooo`;o00001?ooool3o`00
0003ooooool0003o000000cooooo0_l00004ooooo`;o0000O_ooool001cooooo00?o0000oooooooo
ool0R_ooool5o`0001cooooo0_l00004ooooo`;o00005_ooool2o`0007kooooo000Looooo`03o`00
0?oooooooooo08[ooooo0_l000000ooooooo0000o`00000<ooooo`;o0000[?ooool001cooooo00?o
0000ooooooooool0R?ooool2o`0000_ooooo0_l00003ooooo`?o000000Coooooo`000?l0003o0000
Z?ooool001cooooo00?o0000ooooooooool0NOooool2o`0000_ooooo1?l0000;ooooo`;o00000ooo
ool7o`0000oooooo0_l0002Gooooo`007?ooool00ol0003oooooooooo`1iooooo`;o00001oooool2
o`000003ooooool0003o000000?o00001?ooool2o`0000cooooo0_l0000?ooooo`;o000000?ooooo
o`000?l000002?ooool2o`0008gooooo000Looooo`03o`000?oooooooooo087ooooo0ol000000ooo
oooo0000o`000007ooooo`;o00002Oooool4o`0000Gooooo0_l00009ooooo`Ko00001oooool3o`00
08cooooo000Looooo`03o`000?oooooooooo087ooooo0_l0000=ooooo`;o00001_ooool5o`0000Co
oooo1Ol00005ooooo`;o000000?oooooo`000?l000000ol00008ooooo`;o00008?ooool2o`0006[o
oooo000Looooo`03o`000?oooooooooo07kooooo0_l00003ooooo`Co00002Oooool2o`0000;ooooo
0_l00002ooooo`;o00001oooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`000003
ooooool0003o000000Gooooo0_l0000Vooooo`;o0000J_ooool001cooooo00?o0000ooooooooool0
O_ooool2o`0000?ooooo1?l0000:ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Sooooo
0_l000000ooooooo0000o`000007ooooo`;o00000oooool2o`0002;ooooo0_l0001^ooooo`007?oo
ool00ol0003oooooooooo`2Aooooo`;o00001oooool2o`0000_ooooo1?l00002ooooo`;o000000Co
ooooo`000?l0003o00009_ooool2o`0006kooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGo
oooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`1hooooo`;o00002?ooool2o`0000go
oooo0_l0000Eooooo`?o00000_ooool2o`0000;ooooo0_l00004ooooo`;o0000T?ooool00006oooo
oomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006
ooooo`03o`000?oooooooooo07Sooooo1?l00006ooooo`;o00007oooool2o`0000cooooo0_l00004
ooooo`Co0000S_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00onH
V9So8B4Qonk^kP07ooooo`03o`000?oooooooooo07[ooooo0_l00002ooooo`;o00004Oooool2o`00
013ooooo0_l00002ooooo`;o00000_ooool4o`0000;ooooo0_l00004ooooo`Co00003?ooool2o`00
01Sooooo0_l0001Vooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03
oiRHV?lQ8B7ok^k^00Kooooo0ol0001Zooooo`;o00002?ooool2o`0000Sooooo0_l0000Aooooo`;o
00004?ooool<o`000003ooooool0003o000000Gooooo0_l0000=ooooo`?o00006?ooool2o`0006Ko
oooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool0
1Oooool00ol0003oooooooooo`1Zooooo`;o00001?ooool2o`000004ooooool0003o0000o`0001Ko
oooo0ol0000?ooooo`;o00000oooool4o`000003ooooool0003o000000?o00000oooool2o`0000Go
oooo0_l0000<ooooo`?o00001oooool2o`0007Sooooo00000ooooooo410@ooooo`02ooooo`03oa0@
4?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1`ooooo`;o0000
00?oooooo`000?l000002oooool2o`0000Oooooo0_l000001?oooooo0000o`000?l00006ooooo`?o
00001?ooool4o`0000_ooooo1?l00002ooooo`;o00001_ooool2o`0000[ooooo1?l00006ooooo`;o
0000N?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So
410@00Kooooo00?o0000ooooooooool0K_ooool2o`0000[ooooo0_l00004ooooo`;o00001oooool2
o`000003ooooool0003o000000;ooooo0_l00003ooooo`Co00000oooool2o`0000Gooooo1Ol00005
ooooo`;o00000_ooool2o`0000Kooooo0_l00004ooooo`;o00001_ooool4o`0007kooooo00001_oo
ooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`00
0?oooooooooo06_ooooo0_l000000ooooooo0000o`000003ooooo`?o00001?ooool2o`00013ooooo
0_l00002ooooo`;o00001?ooool3o`0000[ooooo1Ol00004ooooo`;o00004Oooool2o`0000;ooooo
0_l00004ooooo`;o00000oooool2o`0007Wooooo000Looooo`03o`000?oooooooooo06_ooooo0_l0
0004ooooo`Go000000?oooooo`000?l000005_ooool2o`0000Gooooo0ol00006ooooo`;o00002?oo
ool2o`000003ooooool0003o000001Gooooo0_l000001?oooooo0000o`000?ooool4o`000003oooo
ool0003o000007Wooooo000Looooo`03o`000?oooooooooo06kooooo0_l000001?oooooo0000o`00
0?l00003ooooo`;o00004_ooool2o`0000;ooooo0_l0000>ooooo`;o00001_ooool7o`0001Sooooo
0_l00003ooooo`;o00000oooool2o`0007Oooooo000Looooo`03o`000?oooooooooo06kooooo0_l0
0002ooooo`;o00005_ooool3o`0000;ooooo0_l00006ooooo`;o00003Oooool7o`0001Cooooo0_l0
0003ooooo`;o00001_ooool4o`0007Oooooo000Looooo`03o`000?oooooooooo06Kooooo0_l0000E
ooooo`;o00000oooool2o`0000Kooooo0_l00009ooooo`Co00000oooool2o`0000Sooooo0_l00002
ooooo`;o00005Oooool2o`0000Kooooo0_l00003ooooo`;o0000NOooool001cooooo00?o0000oooo
ooooool0G_ooool2o`0000Kooooo0_l000000ooooooo0000o`00000Booooo`;o00000oooool2o`00
00gooooo1_l00005ooooo`;o00003?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002oooo
o`;o00002_ooool2o`0000Kooooo0_l0000@ooooo`;o0000K?ooool001cooooo00?o0000oooooooo
ool0G_ooool2o`0000Wooooo0_l00009ooooo`;o00002oooool4o`0000?ooooo0_l00007ooooo`Co
00005?ooool2o`0000;ooooo0ol000000ooooooo0000o`000004o`0000[ooooo0_l00005ooooo`;o
00004Oooool2o`0006cooooo000Looooo`03o`000?oooooooooo067ooooo0ol00005ooooo`;o0000
1oooool4o`000003ooooool0003o000000Co00001?ooool4o`0000?ooooo0_l0000<ooooo`;o0000
1?ooool2o`0000Gooooo0_l00004ooooo`;o00000_ooool2o`0000Cooooo1?l00002ooooo`;o0000
3Oooool2o`0001Gooooo0_l0001Xooooo`007?ooool00ol0003oooooooooo`1Qooooo`?o00003_oo
ool2o`0000?ooooo1_l00007ooooo`;o00002Oooool4o`0000?ooooo0_l000001?oooooo0000o`00
0?ooool2o`0000Gooooo0ol00009ooooo`;o00001?ooool2o`0000;ooooo0_l00008ooooo`;o0000
1_ooool2o`0000_ooooo0_l00005ooooo`;o0000J?ooool001cooooo00?o0000ooooooooool0H_oo
ool2o`0001;ooooo0_l0000<ooooo`;o00001oooool8o`0000Cooooo0_l00007ooooo`[o00000ooo
ool2o`0000Cooooo0_l000000ooooooo0000o`000009ooooo`;o00001?ooool5o`0000[ooooo0_l0
001_ooooo`007?ooool00ol0003oooooooooo`1Looooo`;o00001?ooool2o`0001;ooooo0_l00000
0ooooooo0000o`000007ooooo`Co00001oooool2o`0000Cooooo0_l0000;ooooo`Co00000_ooool6
o`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l000003oooool2o`000003ooooool0003o
000000Kooooo0_l0000;ooooo`;o0000I_ooool001cooooo00?o0000ooooooooool0G?ooool4o`00
00oooooo0_l00003ooooo`;o00000oooool5o`0000Cooooo1?l000000ooooooo0000o`00000Goooo
o`?o00001?ooool2o`0000Kooooo0_l00004ooooo`;o00001_ooool2o`0001Cooooo0ol0000;oooo
o`;o00000oooool2o`00067ooooo000Looooo`;o0000Goooool4o`0000gooooo0_l00003ooooo`;o
00001Oooool3o`0000Oooooo1_l00003ooooo`?o00004?ooool2o`0000Sooooo0_l00002ooooo`;o
00003?ooool2o`0000Sooooo0_l0000:ooooo`;o00003_ooool2o`000003ooooool0003o0000067o
oooo000Looooo`03o`000?oooooooooo05[ooooo0ol00003ooooo`;o00002Oooool2o`0000kooooo
0_l00008ooooo`;o00000_ooool9o`0001;ooooo0_l00004ooooo`?o00000_ooool4o`000003oooo
ool0003o000000_ooooo0_l00004ooooo`;o00001Oooool2o`0000oooooo0_l00002ooooo`Co0000
H_ooool001cooooo00?o0000ooooooooool0Coooool2o`0000Sooooo1_l0000;ooooo`?o000000?o
ooooo`000?l000001?ooool2o`0000oooooo0_l00004ooooo`Co000000?oooooo`000?l000001_l0
000<ooooo`;o000000Coooooo`000?l0003ooooo0ol00004ooooo`;o000000?oooooo`000?l00000
1?ooool2o`0000?ooooo1?l0000;ooooo`;o00003oooool2o`0000?ooooo0ol0000;ooooo`;o0000
EOooool001cooooo00?o0000ooooooooool0Coooool2o`0000Sooooo0ol000000ooooooo0000o`00
0002o`0000Wooooo0_l00002ooooo`;o00001?ooool2o`0000gooooo0_l00007ooooo`;o00000_oo
ool8o`0000oooooo0_l00005ooooo`;o00002_ooool2o`0000?ooooo0_l00004ooooo`;o00003?oo
ool2o`0000oooooo0_l000000ooooooo0000o`000009ooooo`;o0000EOooool001cooooo00?o0000
ooooooooool0Goooool2o`0000Cooooo0_l0000;ooooo`;o00002?ooool3o`0000Cooooo0_l0000A
ooooo`;o00001?ooool2o`0000Sooooo0_l00003ooooo`;o000000Coooooo`000?l0003o00001Ooo
ool2o`0000gooooo0_l0000<ooooo`;o00002oooool3o`0000Cooooo0_l0001Pooooo`007?ooool0
0ol0003oooooooooo`1Uooooo`;o00002oooool2o`0000Sooooo1Ol0000<ooooo`;o00003Oooool2
o`0000Sooooo0_l00003ooooo`;o00000_ooool2o`0000Gooooo1?l00006ooooo`;o00000oooool3
o`0000[ooooo0_l0000<ooooo`?o000000?oooooo`000?l00000Hoooool001cooooo00?o0000oooo
ooooool0E_ooool2o`0000Cooooo0_l00007ooooo`;o00006?ooool2o`0000Wooooo1Ol00007oooo
o`;o00002?ooool2o`0000Cooooo0_l0000@ooooo`;o00001_ooool2o`0000Cooooo0_l0000:oooo
o`?o00001_ooool2o`0000Oooooo0_l00003ooooo`;o00000_ooool2o`0005[ooooo000Looooo`03
o`000?oooooooooo05Kooooo0_l00004ooooo`;o00003oooool2o`0000Gooooo0_l0000Dooooo`Co
000000?oooooo`000?l000001Oooool2o`0000?ooooo0_l00003ooooo`;o00001oooool2o`0000Go
oooo0_l0000?ooooo`;o00001Oooool2o`0000Wooooo0_l00002ooooo`;o00000_ooool2o`000004
ooooool0003o0000ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo0_l00009oooo
o`;o0000Coooool001cooooo00?o0000ooooooooool0DOooool2o`0000;ooooo0_l0000:ooooo`;o
00002_ooool2o`0000Gooooo0_l00008ooooo`;o00002_ooool7o`0000[ooooo0_l00008ooooo`Ko
00001Oooool2o`0000_ooooo0_l00002ooooo`;o00001Oooool2o`0000Oooooo0_l00004ooooo`;o
00001Oooool2o`000003ooooool0003o000000?ooooo0_l0000@ooooo`;o0000Coooool001cooooo
00?o0000ooooooooool0DOooool2o`0000;ooooo0_l0000:ooooo`;o00006oooool2o`0000gooooo
0_l0000Fooooo`Go00002oooool2o`0000Kooooo0_l0000<ooooo`;o00001?ooool2o`0000gooooo
0_l00006ooooo`;o0000Goooool001cooooo00?o0000ooooooooool0C_ooool2o`0000Gooooo0_l0
000Vooooo`?o00003?ooool2o`0000Wooooo0_l00006ooooo`;o00001oooool2o`0000_ooooo0_l0
0005ooooo`?o00002_ooool4o`0000cooooo0_l00005ooooo`;o00001_ooool2o`00013ooooo0_l0
001=ooooo`007?ooool00ol0003oooooooooo`1>ooooo`Co00004_ooool2o`0000_ooooo0_l00009
ooooo`?o00003Oooool2o`0000Wooooo0ol00005ooooo`;o00001?ooool2o`0000Kooooo0_l00000
1?oooooo0000o`000?l00002ooooo`;o00001Oooool3o`0000Gooooo0_l00003ooooo`;o00001?oo
ool2o`0000Sooooo0_l0000Iooooo`;o00001?ooool2o`0004gooooo000Looooo`03o`000?oooooo
oooo04oooooo0ol0000>ooooo`;o00000_ooool2o`0000?ooooo0_l000001?oooooo0000o`000?oo
ool4o`0000Sooooo1Ol00006ooooo`;o00003oooool5o`0000Wooooo0_l00006ooooo`;o000000Co
ooooo`000?l0003o00000_ooool2o`0000Sooooo0_l00003ooooo`Co000000Coooooo`000?l0003o
oooo0_l000000ooooooo0000o`00000?ooooo`;o00004_ooool2o`0005?ooooo000Looooo`03o`00
0?oooooooooo04Sooooo0ol0000Booooo`;o000000?oooooo`000?l000001oooool2o`000004oooo
ool0003o0000ooooo`Co00002?ooool2o`000003ooooool0003o000000Kooooo0_l0000?ooooo`;o
000000?oooooo`000?l000008oooool2o`000004ooooool0003o0000ooooo`Go00000_ooool5o`00
00Kooooo0ol00006ooooo`Co00001Oooool2o`0000Cooooo0_l0001Hooooo`007?ooool00ol0003o
ooooooooo`18ooooo`?o00004_ooool2o`0000;ooooo0_l00006ooooo`;o00000_ooool2o`0000[o
oooo0_l000000ooooooo0000o`000007ooooo`;o00004?ooool2o`0001kooooo0_l00009ooooo`;o
00001?ooool2o`0000Cooooo0ol00006ooooo`?o00001Oooool2o`000003ooooool0003o000000Go
oooo0_l00004ooooo`;o0000F?ooool001cooooo00?o0000ooooooooool0A_ooool2o`0001Wooooo
0_l0000:ooooo`;o00002?ooool4o`000003ooooool0003o000000Oooooo0_l00009ooooo`;o0000
6?ooool4o`0000Wooooo0_l0000?ooooo`Co00000oooool2o`0000kooooo0_l000000ooooooo0000
o`00000Booooo`;o0000DOooool001cooooo0_l00017ooooo`;o00001?ooool2o`0000Wooooo0_l0
000>ooooo`;o00003?ooool5o`0001Kooooo0_l00002ooooo`;o00001?ooool2o`000003ooooool0
003o000000_ooooo1ol0000Gooooo`Co00002oooool2o`0000Cooooo0_l0000Booooo`;o00000ooo
ool6o`0004gooooo000Looooo`03o`000?oooooooooo04Kooooo0_l00004ooooo`Co00000oooool8
o`0000cooooo0_l00008ooooo`;o00000_ooool4o`000003ooooool0003o000000Cooooo0ol0000A
ooooo`;o00001?ooool5o`0000Wooooo0_l00004ooooo`?o00009_ooool2o`0000Cooooo0_l0000B
ooooo`;o000000?oooooo`000?l000000_ooool4o`0004gooooo000Looooo`03o`000?oooooooooo
047ooooo0_l00003ooooo`;o00000oooool5o`0000?ooooo1?l00002ooooo`;o00003_ooool2o`00
00Gooooo0ol00004ooooo`;o000000Coooooo`000?l0003ooooo1_l0000Iooooo`;o000000?ooooo
o`000?l000001oooool2o`000004ooooool0003o0000ooooo`;o0000;Oooool2o`0000Cooooo0_l0
000?ooooo`;o00001Oooool2o`0004cooooo000Looooo`03o`000?oooooooooo047ooooo0_l00008
ooooo`Go00004oooool2o`0000Cooooo0_l00005ooooo`Co00000oooool2o`0000Cooooo1?l0000N
ooooo`;o00000oooool2o`0000Gooooo0_l000000ooooooo0000o`000008ooooo`;o00006Oooool2
o`0000Sooooo0_l00004ooooo`;o00002Oooool2o`0000;ooooo0_l00007ooooo`;o0000C?ooool0
01cooooo00?o0000ooooooooool0Hoooool2o`0000Kooooo1?l00003ooooo`;o00001oooool2o`00
00cooooo0_l0000;ooooo`;o00001?ooool2o`000003ooooool0003o000000;ooooo1Ol0000@oooo
o`?o00006?ooool2o`0000[ooooo0_l00003ooooo`;o00001?ooool2o`0000;ooooo0_l00002oooo
o`;o000000?oooooo`000?l00000D_ooool001cooooo00?o0000ooooooooool0Aoooool3o`0000;o
oooo0_l00009ooooo`;o00004_ooool4o`000003ooooool0003o000000?o00001_ooool2o`0000So
oooo0_l00002ooooo`?o00002_ooool2o`0000Cooooo3?l00004ooooo`?o00000oooool2o`0000Go
oooo0_l0000Tooooo`;o00000oooool2o`0000Cooooo0_l00009ooooo`;o0000D_ooool001cooooo
00?o0000ooooooooool0?Oooool2o`0000Kooooo2Ol00006ooooo`;o000000?oooooo`000?l00000
0_l00006ooooo`;o00002oooool7o`0000Kooooo0_l00003ooooo`Oo00000oooool2o`00013ooooo
3Ol00002ooooo`Ko000000?oooooo`000?l000000_l0000@ooooo`;o000000Coooooo`000?l0003o
00006oooool2o`0000cooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`0mooooo`;o0000
1_ooool2o`0000;ooooo1_l00005ooooo`;o000000?oooooo`000?l000001?l00003ooooo`?o0000
2_ooool6o`0000Sooooo0_l00003ooooo`Go00001Oooool2o`000003ooooool0003o000000;ooooo
0_l00002ooooo`;o000000Coooooo`000?l0003ooooo3ol000000ooooooo0000o`000002ooooo`Co
000000?oooooo`000?l000001oooool2o`0000Oooooo0_l000001?oooooo0000o`000?l00006oooo
o`;o00004oooool2o`0000Kooooo0_l00004ooooo`;o0000D_ooool001cooooo00?o0000oooooooo
ool0Boooool6o`0000Kooooo0_l00002ooooo`;o00000oooool2o`0000_ooooo1_l0000@ooooo`Ko
00001?ooool2o`0000;ooooo0ol000001?oooooo0000o`000?oooolEo`0000?ooooo1?l00003oooo
o`Co00000_ooool2o`0000_ooooo0_l00006ooooo`;o00002?ooool2o`00017ooooo1?l0001Foooo
o`007?ooool00ol0003oooooooooo`10ooooo`;o00003Oooool2o`0000cooooo0ol0000;ooooo`;o
00000_ooool2o`0000Wooooo0_l00009ooooo`Co00002Oooool2o`0000?ooooo5ol00002ooooo`Co
00000oooool4o`0000Cooooo0_l000000ooooooo0000o`000006ooooo`;o00003_ooool4o`0001?o
oooo1?l00002ooooo`;o0000D?ooool001cooooo00?o0000ooooooooool0?Oooool2o`000003oooo
ool0003o000001_ooooo1Ol00009ooooo`;o00000oooool2o`0000Sooooo0_l0000KoooooaOo0000
4Oooool2o`000003ooooool0003o000001Kooooo1Ol00006ooooo`;o00000oooool2o`0000Oooooo
0ol000000ooooooo0000o`000003ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0?Ooo
ool2o`0000;ooooo0_l0000Aooooo`;o00002_ooool2o`0000Sooooo0_l00004ooooo`;o00008_oo
oolJo`0001Cooooo1_l0000Eooooo`;o00001_ooool2o`0000?ooooo0_l00006ooooo`Co00001_oo
ool2o`0000Gooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`10ooooo`?o00002?ooool2
o`0000Oooooo0_l000000ooooooo0000o`000006ooooo`;o00002Oooool5o`0000oooooo0_l00000
0ooooooo0000o`00000:ooooo`;o00000oooool:o`000003ooooool0003o000000[o000000?ooooo
o`000?l000000ol000000ooooooo0000o`000007ooooo`;o00001oooool7o`000003ooooool0003o
000000_ooooo0_l0000Booooo`;o00001Oooool2o`000003ooooool0003o000000;ooooo0_l00008
ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0=Oooool3o`0000Sooooo0_l00009oooo
o`;o00002_ooool2o`0000?ooooo1Ol00003ooooo`;o00001?ooool5o`0000gooooo1?l000000ooo
oooo0000o`00000:ooooo`;o00000ooooolPo`0000Oooooo0_l00009ooooo`;o000000Coooooo`00
0?l0003ooooo0_l00009ooooo`Co00003Oooool7o`0000Sooooo0_l00002ooooo`;o00003Oooool2
o`0003oooooo000Looooo`03o`000?oooooooooo03Gooooo0ol00008ooooo`;o00005oooool2o`00
0004ooooool0003o0000o`0000Gooooo0_l00009ooooo`;o00002oooool3o`0000cooooo1?l00004
oooooaoo00003_ooool2o`0000;ooooo0_l00004ooooo`Go00001_ooool2o`0000Oooooo0_l00006
ooooo`Oo00004oooool2o`0000Kooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0doooo
o`;o00000oooool2o`0000Gooooo0_l0000Gooooo`;o00001_ooool3o`0000Sooooo0_l000000ooo
oooo0000o`00000<ooooo`;o00003?ooool4o`0000Gooooo0_l000000ooooooo0000o`00000Fo`00
0003ooooool0003o000000kooooo0_l0000:ooooo`?o00000oooool3o`000003ooooool0003o0000
00Kooooo0_l00009ooooo`Go000000Coooooo`000?l0003o00000_ooool2o`0000Oooooo0_l00000
0ooooooo0000o`000006ooooo`;o0000?oooool001cooooo0_l0000eooooo`;o00000oooool2o`00
00Gooooo0_l00004ooooo`;o00004oooool2o`0000?ooooo1?l00005ooooo`;o000000?oooooo`00
0?l000006?ooool2o`0000[ooooo5_l000000ooooooo0000o`000004o`000003ooooool0003o0000
00Cooooo0_l0000Jooooo`?o000000?oooooo`000?l000005?ooool2o`000004ooooool0003o0000
o`0000;ooooo0_l00007ooooo`;o00001Oooool2o`0004?ooooo000Looooo`03o`000?oooooooooo
03Cooooo0_l00006ooooo`;o00002?ooool2o`0000;ooooo0_l0000>ooooo`?o00000oooool2o`00
00Oooooo1?l0000Fooooo`;o000000Coooooo`000?l0003o00002OoooolMo`000003ooooool0003o
000000Cooooo0_l00008ooooo`;o00001Oooool2o`0000Wooooo0_l00003ooooo`;o00002?ooool2
o`0000gooooo0_l00002ooooo`;o000000?oooooo`000?l000002oooool2o`0004?ooooo000Loooo
o`03o`000?oooooooooo03;ooooo1?l00006ooooo`Co00001_ooool2o`0000;ooooo0_l0000>oooo
o`;o000000Coooooo`000?l0003ooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l0
00000ooooooo0000o`00000;ooooo`;o00001?ooool5o`000003ooooool0003o000000Sooooo0_l0
00000ooooooo0000o`00000=o`000003ooooool0003o000000co00003Oooool3o`0000Gooooo0_l0
000>ooooo`Co00001_ooool2o`0000Kooooo0_l00004ooooo`Oo000000?oooooo`000?l00000D?oo
ool001cooooo00?o0000ooooooooool0<_ooool3o`0000Oooooo1?l00006ooooo`;o00000_ooool2
o`0000?ooooo1_l00008ooooo`So000000?oooooo`000?l000001_ooool2o`0000Wooooo1?l00003
ooooo`?o000000Coooooo`000?l0003o00002_oooolBo`000003ooooool0003o000000co00002Ooo
ool2o`0000;ooooo0_l0000;ooooo`;o00000oooool2o`0000Cooooo1?l00003ooooo`;o00002Ooo
ool2o`0000Cooooo0_l000000ooooooo0000o`000002o`000004ooooool0003o0000o`0004oooooo
000Looooo`03o`000?oooooooooo02gooooo0_l0000=ooooo`;o00003?ooool2o`0000?ooooo2?l0
0003ooooo`_o000000?oooooo`000?l000001?ooool2o`0000_ooooo0_l00005ooooo`;o00000ooo
ool2o`000004ooooool0003o0000ooooo`;o00001OoooolMo`0000_ooooo0ol00002ooooo`;o0000
2oooool3o`0000;ooooo0_l00005ooooo`?o00000oooool2o`000003ooooool0003o000000Kooooo
0_l000000ooooooo0000o`000003o`0000?ooooo0_l000001?oooooo0000o`000?l0000:ooooo`;o
0000@oooool001cooooo00?o0000ooooooooool0;Oooool2o`0000cooooo0_l00003ooooo`;o0000
4oooool2o`0000?ooooo2Ol00003ooooo`;o00001?ooool3o`0001Wooooo0_l000000ooooooo0000
o`000005ooooo`;o00000_oooolIo`0000;ooooo1?l00005ooooo`?o00002Oooool2o`0000Gooooo
0_l00009ooooo`;o00001?ooool2o`000003ooooool0003o000000Gooooo0ol000000ooooooo0000
o`000003o`0001;ooooo0ol00013ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00001_oo
ool2o`0000?ooooo0_l0000=ooooo`;o00001Oooool4o`000003ooooool0003o000000Cooooo0_l0
0003ooooo`;o00001Oooool2o`0001?ooooo0_l0000BoooooaWo00000_ooool6o`0000Cooooo0_l0
0009ooooo`;o00002_ooool2o`0000Gooooo0ol00002ooooo`;o00001Oooool5o`0001Wooooo0_l0
0014ooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o000000Coooooo`000?l0003o00000ooo
ool2o`0000Kooooo0_l0000<ooooo`Co00000oooool4o`0001Kooooo0_l00007ooooo`;o00001ooo
ool2o`0000_ooooo0_l00005oooooaWo00000oooool2o`000003ooooool0003o000000;o00003ooo
ool2o`0000Sooooo0_l00005ooooo`?o00002Oooool4o`00013ooooo0_l00005ooooo`;o0000Aooo
ool001cooooo00?o0000ooooooooool0<?ooool2o`0000;ooooo0_l00003ooooo`;o00001_ooool2
o`0000kooooo1Ol00002ooooo`;o00002_ooool2o`0000?ooooo1?l00003ooooo`;o00001oooool2
o`0000;ooooo0_l0000@ooooo`;o00001_oooolJo`0000Cooooo1Ol0000>ooooo`;o00000oooool2
o`000004ooooool0003o0000ooooo`;o00009?ooool2o`000003ooooool0003o000000;ooooo0_l0
0017ooooo`007?ooool00ol0003oooooooooo`16ooooo`;o00001oooool2o`0000;ooooo0ol0000>
ooooo`;o00000oooool4o`0000;ooooo0_l00002ooooo`;o00001?ooool2o`0000;ooooo0_l00007
ooooo`;o00000_ooool3o`0000Gooooo1?l000000ooooooo0000o`00000Ho`0000?ooooo1_l0000@
ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000002ooooo`;o00000_oo
ool2o`000003ooooool0003o000001cooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`0n
ooooo`;o00001_ooool2o`0000Oooooo0_l0000?ooooo`;o00000_ooool2o`0000Wooooo0_l00002
ooooo`;o00001?ooool2o`0000Gooooo0ol00003ooooo`;o000000?oooooo`000?l000000_l00005
ooooo`Co000000?oooooo`000?l000005Ol00006ooooo`Go00002oooool2o`0000Cooooo0_l0000;
ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo0_l0000Gooooo`;o000000?ooooo
o`000?l00000BOooool001cooooo00?o0000ooooooooool09_ooool2o`0000Oooooo0_l0000=oooo
o`;o00002_ooool8o`0000Kooooo0_l00003ooooo`;o000000?oooooo`000?l000000oooool2o`00
01Wooooo0ol00006ooooo`;o00001?ooool2o`0000Kooooo0_l000000ooooooo0000o`000009o`00
00;ooooo0_l000000ooooooo0000o`00000;ooooo`;o00002oooool2o`0000Oooooo1?l0000Aoooo
o`;o00001Oooool2o`00013ooooo0_l000001?oooooo0000o`000?l00018ooooo`007?ooool00ol0
003oooooooooo`0Vooooo`;o00001oooool2o`000003ooooool0003o000000cooooo0_l00008oooo
o`So000000?oooooo`000?l000000oooool2o`0000?ooooo0_l00003ooooo`;o000000?oooooo`00
0?l000004?ooool2o`0001Kooooo0_l0000:ooooo`;o000000?oooooo`000?l000000ol00003oooo
o`;o00000_ooool2o`0000[ooooo0_l00004ooooo`;o00003oooool6o`0000[ooooo1?l00006oooo
o`Co00004?ooool2o`000004ooooool0003o0000o`0004Sooooo000Looooo`03o`000?oooooooooo
03;ooooo0_l0000<ooooo`Co00002?ooool2o`0000Cooooo0ol0000=ooooo`;o00004?ooool2o`00
0004ooooool0003o0000ooooo`?o00005_ooool2o`0000?ooooo0_l00004ooooo`Go000000?ooooo
o`000?l000000_l00002ooooo`;o00002_ooool2o`0000Cooooo0_l0000:ooooo`;o000000Gooooo
o`000?l0003o0000ooooo`06o`0000Sooooo1?l00006ooooo`Co00000_ooool2o`0001gooooo0_l0
000kooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool2o`000003oa0@
4?oooooooooo00Cooooo00?o0000ooooooooool0=oooool4o`0000Oooooo0_l00006ooooo`Co0000
1?ooool2o`0000Sooooo0_l00007ooooo`?o00003?ooool3o`0000?ooooo1?l0000:ooooo`;o0000
00?oooooo`000?l000001_ooool2o`0000?ooooo0_l00004ooooo`;o000000Coooooo`000?l0003o
oooo0ol0000Booooo`;o00002_ooool2o`000004ooooool0003o0000ooooo`?o000000?oooooo`00
0?l000001?l00002ooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00000_ooool2o`00
01gooooo0_l0000kooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Oooooo1?l0000>ooooo`?o00004?ooool2
o`0000Gooooo2ol00002ooooo`;o00000oooool3o`0000?ooooo0ol00008ooooo`Co000000?ooooo
o`000?l000002Oooool2o`0000Sooooo0_l0000Booooo`;o00000oooool2o`0000;ooooo0_l00006
ooooo`;o00001Oooool4o`000003ooooool0003o000000;o000000?oooooo`000?l000000ol00002
ooooo`;o00001?ooool2o`0006Cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo
00Wooooo1Ol00006ooooo`03o`000?oooooooooo03Oooooo0_l0000<ooooo`;o00000_ooool2o`00
00Kooooo0_l0000@ooooo`;o00000oooool6o`0000;ooooo0_l00004ooooo`;o00003_ooool3o`00
0003ooooool0003o000000Kooooo0_l00002ooooo`;o00002?ooool2o`0000cooooo0_l00004oooo
o`?o00000_ooool2o`0000;ooooo0_l00005ooooo`;o00000oooool2o`000003ooooool0003o0000
00Oo000000?oooooo`000?l000000ol00002ooooo`;o00002oooool2o`000003ooooool0003o0000
00cooooo1?l0001:ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04
odA4A?oMgMgoooooo`0000Oooooo0ol0000fooooo`?o000000Coooooo`000?l0003o00001_ooool4
o`0000Oooooo2?l0000<ooooo`;o00001_ooool2o`0000Cooooo2Ol0000Aooooo`Co00001?ooool2
o`0000Sooooo0_l0000@ooooo`;o00001Oooool2o`0000;ooooo0_l00008oooooaOo00000oooool2
o`0000;ooooo0_l00007ooooo`;o000000?oooooo`000?l000003?ooool4o`0004[ooooo00000ooo
oooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo00001oooool0
0ol0003oooooooooo`0dooooo`Co00000_ooool3o`000003ooooool0003o000000?ooooo0_l00000
0ooooooo0000o`000006ooooo`?o00000_ooool3o`0000?ooooo0_l00004ooooo`;o000000?ooooo
o`000?l000003?ooool9o`0001?ooooo0_l00004ooooo`;o00001_ooool4o`0001Gooooo1?l00008
ooooo`;o00000_oooolGo`0000Oooooo0_l0001Vooooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0=?ooool3o`00
00?ooooo1_l00005ooooo`?o00004Oooool2o`0000Cooooo0_l0000>ooooo`Oo00000oooool2o`00
00kooooo1?l0000=ooooo`;o00003oooool3o`0000Cooooo1Ol00005ooooo`;o000000?oooooo`00
0?l000000_ooool2o`000003ooooool0003o000001;o000000Coooooo`000?l0003o00001?ooool2
o`0006Gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l000001ooo
ool00ol0003oooooooooo`0[ooooo`;o00002?ooool2o`0000Cooooo0ol00007ooooo`;o00002ooo
ool2o`0000_ooooo0_l0000<ooooo`ko00003_ooool4o`0000Gooooo0_l0000Gooooo`?o00001?oo
ool2o`0000Sooooo0_l000001Ooooooo0000o`000?l0003ooooo01_o00000oooool3o`0000Oooooo
0_l00004ooooo`;o00006_ooool2o`0003[ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPgo
oooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`0[ooooo`;o00002_ooool2o`0000Wo
oooo0ol0000=ooooo`;o00005_oooolFo`00017ooooo0ol0000Jooooo`?o00003_ooool3o`000005
ooooool0003o0000o`000?ooool05_l000000ooooooo0000o`000003o`0000Sooooo0_l00004oooo
o`;o00001Oooool2o`0001?ooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`0gooooo`;o
00002Oooool5o`0000Cooooo1?l00004ooooo`?o00001?ooool4o`0000Cooooo1?l000000ooooooo
0000o`00000=o`000003ooooool0003o000000Oo00001_ooool4o`0000Oooooo0_l0000Kooooo`Go
000000?oooooo`000?l000000_l000001?oooooo0000o`000?l00003ooooo`Oo000000?oooooo`00
0?l000001Ol000000ooooooo0000o`00000<o`000003ooooool0003o000000?o00002Oooool2o`00
00[ooooo0_l00003ooooo`;o00003?ooool2o`0003cooooo000Looooo`03o`000?oooooooooo03Ko
oooo0_l00003ooooo`Co00001_ooool2o`0000Cooooo1?l00004ooooo`?o00000_ooool6o`0000Co
oooo1?l000000ooooooo0000o`000008o`000003ooooool0003o000000;o000000?oooooo`000?l0
00001Ol000000ooooooo0000o`000005ooooo`Co00004Oooool2o`0000Sooooo0_l00007ooooo`;o
000000Coooooo`000?l0003ooooo1?l000001?oooooo0000o`000?l00002ooooob7o00001oooool2
o`0000Cooooo0_l0000=ooooo`Co00002_ooool4o`0003cooooo000Looooo`03o`000?oooooooooo
03;ooooo0_l00002ooooo`;o00000oooool4o`0000Kooooo0_l0000Aooooo`;o00003OoooolGo`00
0003ooooool0003o000001[ooooo0_l00008ooooo`;o00001_ooool4o`0000gooooo0_l00002oooo
o`?o000000?oooooo`000?l000006?l00006ooooo`;o00004oooool2o`0000?ooooo0_l00007oooo
o`;o000000?oooooo`000?l000000_ooool2o`0003Oooooo000Looooo`03o`000?oooooooooo03;o
oooo1?l0000?ooooo`;o00007?ooool3o`000003ooooool0003o000001Go00009_ooool2o`0000?o
oooo0_l00002ooooo`Co00002Oooool2o`0000;ooooo0_l00002ooooo`?o00000oooool9o`000003
ooooool0003o000000go000000?oooooo`000?l000002_ooool2o`00013ooooo0_l00009ooooo`?o
00000_ooool2o`0003Oooooo000Looooo`03o`000?oooooooooo03?ooooo1Ol0000Rooooo`;o0000
0_ooool2o`0000?ooooo6ol0000Hooooo`;o00003?ooool2o`0000?ooooo0_l000000ooooooo0000
o`00000<ooooo`Co00001?oooolKo`000005ooooool0003o0000o`000?ooool00_l00008ooooo`Co
00001_ooool2o`0000Sooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l0000loooo
o`007?ooool00ol0003oooooooooo`0cooooo`;o000000?oooooo`000?l000003_ooool2o`0001;o
oooo0_l00002ooooo`;o00000_oooolNo`0001Kooooo0_l00008ooooo`;o00000_ooool2o`0000?o
oooo0_l000000ooooooo0000o`00000<ooooo`Ko00000_oooolJo`0000Gooooo0ol00008ooooo`Go
00001Oooool2o`0000Sooooo0_l00003ooooo`;o000000?oooooo`000?l00000?oooool001cooooo
00?o0000ooooooooool0?_ooool2o`0000Kooooo0_l0000Hooooob3o00000oooool2o`0000?ooooo
0_l00006ooooo`;o00001oooool4o`0000?ooooo0_l00002ooooo`;o00005?ooool2o`0000;ooooo
0_l00002oooooa_o00000_ooool5o`0000Kooooo0_l00003ooooo`;o00002oooool2o`0000_ooooo
0_l0000nooooo`007?ooool00ol0003oooooooooo`0nooooo`;o000000?oooooo`000?l000000ooo
ool2o`000004ooooool0003o0000o`0001;ooooo1?l000000ooooooo0000o`00000>o`000003oooo
ool0003o000000[o00000oooool2o`0000?ooooo0ol00002ooooo`Go00001_ooool5o`0000Oooooo
0_l00007ooooo`;o000000?oooooo`000?l000004?oooolOo`000003ooooool0003o000000Kooooo
0_l00005ooooo`;o00002Oooool2o`0000_ooooo0_l0000nooooo`007?ooool00ol0003ooooooooo
o`11ooooo`;o00001?ooool5o`0001;ooooo0_l00003oooooago00002Oooool2o`0000;ooooo1?l0
0007ooooo`;o00004oooool2o`000003ooooool0003o000000gooooo0_l000000ooooooo0000o`00
000Ko`0001;ooooo0_l0000<ooooo`;o00000oooool2o`0000;ooooo1?l0000Aooooo`;o0000:_oo
ool001cooooo00?o0000ooooooooool0<Oooool4o`0001;ooooo1?l00004ooooo`;o00004oooool=
o`000003ooooool0003o000000ko00002_ooool2o`0001gooooo0ol00002ooooo`;o00003Oooool2
o`000003ooooool0003o000001[o000000?oooooo`000?l000007_ooool2o`0000?ooooo0_l00002
ooooo`Co00004Oooool2o`0002[ooooo000Looooo`03o`000?oooooooooo037ooooo1_l00008oooo
o`;o00002?ooool2o`0000?ooooo0ol00003ooooo`;o00002oooool2o`000003ooooool0003o0000
00co000000?oooooo`000?l000003Ol00007ooooo`Go00000oooool2o`0001Sooooo0ol00002oooo
o`;o00003OoooolOo`000003ooooool0003o000000?ooooo0_l0000Sooooo`?o0000?Oooool001co
oooo0_l0000booooo`;o00000_ooool2o`0000Sooooo0_l0000=ooooo`Co00000_ooool2o`0000_o
oooo0_l000000ooooooo0000o`00000Jo`0000Wooooo1?l000001?oooooo0000o`000?ooool2o`00
01Cooooo1ol0000AoooooaCo000000?oooooo`000?l000002Ol000000ooooooo0000o`000002oooo
o`;o00006Oooool2o`0000?ooooo0ol00002ooooo`?o0000?Oooool001cooooo00?o0000oooooooo
ool0=Oooool2o`0000Oooooo1?l0000>ooooo`;o00003_ooool3o`000003ooooool0003o000000Oo
00000_oooolCo`0000cooooo0_l0000Eooooo`Wo00001?ooool2o`0000_ooooo0_l000000ooooooo
0000o`00000@o`0000;ooooo2Ol000000ooooooo0000o`000007ooooo`;o000000?oooooo`000?l0
00004Oooool4o`000005ooooool0003o0000o`000?ooool00ol0000nooooo`007?ooool00ol0003o
ooooooooo`0`ooooo`;o00003?ooool4o`0000Kooooo0_l00003ooooo`;o00001_ooool2o`0000Wo
oooo8_l00005ooooo`;o00003_ooool2o`0000cooooo1ol00006ooooo`;o00003_ooool4o`000003
ooooool0003o000001Wo00001oooool5o`0001?ooooo0_l00005ooooo`;o00001?ooool2o`0003Wo
oooo000Looooo`03o`000?oooooooooo02cooooo1_l0000Fooooo`;o00000oooool2o`0000Kooooo
0_l00003ooooo`;o00001_oooolNo`0000Oooooo0_l000000ooooooo0000o`000006ooooo`;o0000
0oooool2o`0000Kooooo0_l00003ooooo`?o000000Coooooo`000?l0003o00006?ooool2o`000003
ooooool0003o000001Co000000?oooooo`000?l000000_l00002ooooo`;o00001Oooool3o`0001Co
oooo0_l00002ooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`;o0000=_ooool001co
oooo00?o0000ooooooooool0;?ooool4o`0000Kooooo0_l0000<ooooo`;o00005?ooool2o`0000Oo
oooo1_l000000ooooooo0000o`000007o`0000;ooooo2ol0000:ooooo`;o00001_ooool2o`0000_o
oooo0_l00003ooooo`;o00000oooool2o`0001_ooooo5_l00003ooooo`;o00000_ooool2o`0000Go
oooo0ol0000Aooooo`;o00001Oooool2o`0000Cooooo0_l00004ooooo`;o0000=_ooool001cooooo
00?o0000ooooooooool06oooool2o`0001Wooooo0_l00005ooooo`;o00001?ooool3o`0000oooooo
0_l00006ooooo`;o00001?oooolNo`0001?ooooo0_l0000>ooooo`;o00002_ooool2o`00017ooooo
6Ol00008ooooo`;o00005_ooool4o`0000Cooooo0_l0000>ooooo`;o0000<oooool001cooooo00?o
0000ooooooooool06oooool2o`00013ooooo0_l0000<ooooo`Co00001?ooool2o`0000Gooooo0_l0
0009ooooo`;o00001_ooool2o`0000Cooooo6Ol000000ooooooo0000o`000002o`0000;ooooo0_l0
000;ooooo`;o00000_ooool2o`0000Wooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo
0_l00005ooooo`;o00002?ooool2o`0000?ooooo0_l00002oooooa[o00001_ooool7o`0001;ooooo
0_l00005ooooo`Go00000_ooool2o`0000Sooooo0_l0000cooooo`007?ooool00ol0003ooooooooo
o`0]ooooo`;o00002Oooool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`00
0005ooooo`;o00001_ooool2o`0000Wooooo0_l00004ooooo`;o00000ooooolHo`000003ooooool0
003o000000;o00002oooool2o`0000Sooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo
0_l00002ooooo`;o00003oooool2o`0000?ooooo0ol00003ooooo`Co000000?oooooo`000?l00000
3_l000001?oooooo0000o`000?l00005ooooo`Oo00003oooool2o`0000Sooooo0_l000000ooooooo
0000o`000002ooooo`;o00001oooool2o`0003Cooooo000Looooo`03o`000?oooooooooo03?ooooo
0_l00003ooooo`;o00001_ooool2o`0000Sooooo0_l00006ooooo`;o00002Oooool3o`0000Sooooo
1ol000000ooooooo0000o`00000>o`000003ooooool0003o000000;o00005Oooool2o`0001[ooooo
0_l00008ooooo`;o00000ooooolDo`0000;ooooo0ol00005ooooo`;o00000oooool2o`0000oooooo
0_l0000=ooooo`;o00002Oooool2o`0003Cooooo000Looooo`03o`000?oooooooooo02oooooo0_l0
0002ooooo`Co00002?ooool4o`000003ooooool0003o000000?ooooo0ol00004ooooo`Co00002_oo
ool2o`0000Kooooo0_l00002oooooa;o00007Oooool2o`000003ooooool0003o000000kooooo0_l0
0002ooooo`?o000000?oooooo`000?l000000_l00006ooooo`;o000000Goooooo`000?l0003o0000
ooooo`0Do`0000?ooooo0ol00009ooooo`;o00004Oooool2o`0000_ooooo0_l0000oooooo`007?oo
ool00ol0003oooooooooo`0_ooooo`;o00000_ooool4o`0000Sooooo1?l000001?oooooo0000o`00
0?l00002ooooo`?o00000_ooool5o`0000Wooooo0_l00008ooooo`;o00001?oooolAo`000004oooo
ool0003o0000o`0000?ooooo0_l00002ooooo`Co00001_ooool2o`0000Gooooo0_l000000ooooooo
0000o`000002ooooo`Go00001oooool2o`0000;ooooo0ol000000ooooooo0000o`000004o`0000?o
oooo0ol000001Ooooooo0000o`000?l0003ooooo013o00002?ooool2o`0001cooooo0_l0001<oooo
o`007?ooool00ol0003oooooooooo`0booooo`;o00002oooool2o`0000Cooooo0_l00003ooooo`;o
00000_ooool2o`000003ooooool0003o000000Wooooo0_l0000:ooooo`;o00000_ooool>o`000003
ooooool0003o000000Co00000oooool2o`0000;ooooo1?l00006ooooo`;o00002_ooool7o`0000;o
oooo0_l0000?ooooo`;o000000?oooooo`000?l000000_l00006ooooo`ko00001Oooool2o`0000?o
oooo0_l0000Looooo`;o0000C?ooool001cooooo00?o0000ooooooooool0:_ooool2o`0000Kooooo
0_l00004ooooo`Ko000000?oooooo`000?l000002Oooool2o`0001cooooo0_l00003oooooa?o0000
0oooool4o`0000;ooooo0_l00008ooooo`;o00001?ooool3o`0000;ooooo0_l000000ooooooo0000
o`000004ooooo`;o00004_ooool2o`0000Kooooo0_l00006ooooo`So00001Oooool2o`000003oooo
ool0003o000002Kooooo0_l00008ooooo`Go0000=oooool001cooooo00?o0000ooooooooool0:_oo
ool2o`0000cooooo1ol0000;ooooo`;o00001?ooool2o`0001_ooooo2_l00002ooooo`Co000000?o
ooooo`000?l000000oooool5o`000003ooooool0003o000000Sooooo0_l00004ooooo`?o00001?oo
ool7o`0000gooooo0_l0000=ooooo`Ko00000oooool2o`000003ooooool0003o000000Kooooo0_l0
0002ooooo`;o00000_ooool2o`0002;ooooo0_l00007ooooo`Ko0000=oooool001cooooo00?o0000
ooooooooool0>?ooool2o`0000?ooooo0_l0000;ooooo`;o00001?ooool2o`0001gooooo0ol00003
ooooo`?o000000?oooooo`000?l000000_l00009ooooo`;o00002?ooool2o`000004ooooool0003o
0000o`0000[ooooo0_l000000ooooooo0000o`000002o`0000Gooooo0_l00006ooooo`;o00003ooo
ool4o`0000Cooooo1Ol00002ooooo`;o000000?oooooo`000?l000001_ooool2o`0000?ooooo0_l0
000@ooooo`;o00001_ooool2o`000003ooooool0003o000000;o00001oooool2o`0003_ooooo000L
ooooo`03o`000?oooooooooo02kooooo0ol00002ooooo`;o00001oooool2o`0001kooooo0_l0000G
ooooo`?o00005?ooool2o`0000;ooooo1_l00008ooooo`;o00000oooool2o`0000?ooooo0_l00002
ooooo`Go00003?ooool2o`0000Sooooo1?l00002ooooo`Go00000_ooool2o`0000kooooo0_l0000@
ooooo`;o00001_ooool2o`000003ooooool0003o000000;o00000oooool2o`0003oooooo000Loooo
o`;o0000;oooool3o`0000;ooooo0_l00003ooooo`Ko00002_ooool4o`0000cooooo0_l00002oooo
o`;o00002_ooool2o`0000kooooo0_l0000>ooooo`;o00000_ooool2o`0000?ooooo0_l0000;oooo
o`;o00002?ooool2o`0000;ooooo1Ol0000<ooooo`;o00002?ooool4o`0000?ooooo0_l0000?oooo
o`;o00008?ooool2o`0000Gooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0aooooo`;o
00001Oooool4o`0000cooooo1?l0000<ooooo`;o00003_ooool2o`0000Sooooo0_l000001?oooooo
0000o`000?ooool2o`0000kooooo0_l0000Dooooo`;o00002_ooool2o`0000;ooooo0_l00002oooo
o`;o00001?ooool3o`0000Cooooo0_l00002ooooo`;o00000_ooool3o`0000Gooooo0_l00009oooo
o`;o00000oooool2o`0001[ooooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`0aooooo`;o
00003_ooool2o`0000Oooooo0_l0000?ooooo`;o00003Oooool2o`0000Kooooo0_l000000ooooooo
0000o`000008ooooo`;o00004oooool2o`0000oooooo0_l00003ooooo`;o00001?ooool4o`0000?o
oooo1?l00003ooooo`?o00000_ooool2o`0000;ooooo0ol00005ooooo`;o00001_ooool2o`000003
ooooool0003o000001oooooo0ol0001;ooooo`007?ooool00ol0003oooooooooo`10ooooo`?o0000
1oooool2o`0000oooooo0_l00003ooooo`;o00002?ooool2o`0000;ooooo1_l00003ooooo`;o0000
1_ooool2o`0001?ooooo0_l00005ooooo`;o00001?ooool2o`0000;ooooo0_l00002ooooo`;o0000
1Oooool2o`0000Gooooo0_l000000ooooooo0000o`000002ooooo`;o00002?ooool2o`0000Kooooo
0_l00005ooooo`;o00000oooool2o`0001Kooooo0_l00006ooooo`Co0000BOooool001cooooo00?o
0000ooooooooool0;oooool2o`0000Sooooo0ol00004ooooo`;o00001Oooool4o`0000cooooo0_l0
0007ooooo`;o00003?ooool6o`0000?ooooo0_l00007ooooo`;o00006Oooool4o`0000;ooooo0_l0
0006ooooo`;o00003?ooool2o`000003ooooool0003o000000cooooo0ol00002ooooo`;o000000Co
ooooo`000?l0003o00002Oooool2o`0001Kooooo0_l00002ooooo`;o00001?ooool3o`0000;ooooo
0_l00014ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00002?ooool4o`0000?ooooo0_l0
0005ooooo`Go00001?ooool2o`0000Gooooo0_l0000;ooooo`;o00000_ooool2o`0000oooooo0_l0
0005ooooo`;o00001_ooool2o`0000;ooooo0_l0000:ooooo`;o00000oooool2o`0000Kooooo0_l0
0003ooooo`;o00001Oooool2o`0000Cooooo0_l0000@ooooo`;o00000_ooool2o`0000;ooooo0_l0
000Rooooo`Go00001Oooool2o`0000;ooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0i
ooooo`Co00000oooool2o`0000Oooooo0ol00004ooooo`;o00004_ooool2o`0000;ooooo0_l0000?
ooooo`;o00001?ooool2o`0000;ooooo1ol000001?oooooo0000o`000?l0000:ooooo`;o00002?oo
ool2o`000003ooooool0003o000000?ooooo1?l00003ooooo`;o00004oooool2o`0001Sooooo0_l0
000Cooooo`?o00004?ooool2o`000004ooooool0003o0000o`0000Cooooo0_l00004ooooo`;o0000
;oooool001cooooo00?o0000ooooooooool0>?ooool2o`0000oooooo1?l00008ooooo`;o00002Ooo
ool2o`0000Oooooo0_l0000;ooooo`;o00001oooool2o`0000;ooooo1ol000000ooooooo0000o`00
000:ooooo`;o00002Oooool2o`0000Sooooo1?l00002ooooo`;o00003?ooool4o`0000;ooooo0_l0
000:ooooo`;o000000?oooooo`000?l000002Oooool2o`0001Gooooo0_l00006ooooo`;o00000ooo
ool2o`0000;ooooo0_l000001?oooooo0000o`000?l00004ooooo`;o00001?ooool2o`0002oooooo
000Looooo`03o`000?oooooooooo03Sooooo0_l0000@ooooo`?o00002?ooool2o`0000Wooooo0_l0
0002ooooo`;o000000?oooooo`000?l000000_l00008ooooo`;o000000?oooooo`000?l000001ooo
ool2o`0000Gooooo1?l0000=ooooo`;o00001?ooool2o`0000oooooo0_l00002ooooo`;o00003?oo
ool5o`0000Kooooo0_l00005ooooo`;o000000?oooooo`000?l000000_ooool2o`0001cooooo0ol0
0005ooooo`;o00000oooool2o`0000;ooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0h
ooooo`;o00006?ooool2o`00013ooooo1_l00009ooooo`;o00001oooool5o`0000Oooooo0_l0000>
ooooo`;o00000oooool2o`0001Kooooo0_l00003ooooo`?o00001_ooool2o`0000Kooooo0_l00009
ooooo`;o000000?oooooo`000?l000001Oooool2o`0001Kooooo0_l00009ooooo`;o0000A?ooool0
01cooooo00?o0000ooooooooool0<Oooool2o`0001oooooo0_l0000Aooooo`;o000000?oooooo`00
0?l000000_l0000@ooooo`?o00000_ooool2o`0000Gooooo0_l00007ooooo`;o00001Oooool2o`00
00kooooo0_l0000;ooooo`;o00000oooool5o`000003ooooool0003o000000;o00004_ooool2o`00
0003ooooool0003o000000Gooooo0_l0000Dooooo`;o00001?ooool2o`0000Cooooo0ol00004oooo
o`;o00000_ooool2o`0000?ooooo0_l0000eooooo`007?ooool00ol0003oooooooooo`0aooooo`;o
000000?oooooo`000?l000000_l0000Fooooo`;o00006_ooool2o`0000kooooo0_l00003ooooo`Co
00001?ooool3o`0000Oooooo0_l0000Eooooo`;o00003Oooool2o`0000Cooooo0_l000000ooooooo
0000o`000002o`0003;ooooo0_l00004ooooo`;o00001?ooool3o`0000Cooooo0_l00002ooooo`;o
00000oooool2o`0003Gooooo000Looooo`03o`000?oooooooooo037ooooo0_l000000ooooooo0000
o`000002o`0001Kooooo0_l0000Dooooo`;o00001?ooool2o`000003ooooool0003o000000_ooooo
0_l00003ooooo`Co000000Coooooo`000?l0003ooooo0ol00007ooooo`;o00002_ooool2o`0000Wo
oooo0ol00007ooooo`;o00000oooool4o`000004ooooool0003o0000ooooo`?o00000_ooool2o`00
0003ooooool0003o000001Gooooo0_l0000Rooooo`;o00001oooool2o`0003cooooo000Looooo`03
o`000?oooooooooo03gooooo0_l00009ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Doooo
o`;o00001?ooool2o`000003ooooool0003o000000Gooooo0_l0000>ooooo`?o00002Oooool3o`00
00Wooooo0ol000000ooooooo0000o`000002ooooo`Co000000Goooooo`000?l0003o0000ooooo`02
o`000003ooooool0003o000000;o00001Oooool9o`0000;ooooo0_l000000ooooooo0000o`00000E
ooooo`;o0000:oooool2o`0003cooooo000Looooo`03o`000?oooooooooo03gooooo0_l00004oooo
o`;o00000oooool2o`000003ooooool0003o000001_ooooo0_l0000:ooooo`;o00003oooool2o`00
00Oooooo1?l00002ooooo`;o00001_ooool6o`0000;ooooo1?l00002ooooo`;o000000Coooooo`00
0?l0003ooooo0_l00002ooooo`;o00000oooool9o`0000Kooooo0_l00005ooooo`;o0000<?ooool2
o`0004Kooooo000Looooo`03o`000?oooooooooo04?ooooo0_l00004ooooo`;o00000_ooool2o`00
01Wooooo0ol0000;ooooo`Co00002Oooool2o`0000Sooooo0ol00004ooooo`;o00002?ooool4o`00
00Kooooo1?l00006ooooo`Co00000oooool2o`000004ooooool0003o0000ooooo`?o000000Cooooo
o`000?l0003ooooo1?l00005ooooo`;o00002Oooool2o`0000Gooooo0_l0000>ooooo`;o00003_oo
ool2o`0004Kooooo000Looooo`;o0000=_ooool2o`0001;ooooo0_l00002ooooo`;o00002?ooool2
o`00013ooooo0_l00007ooooo`;o00000_ooool4o`0000Wooooo0_l00004ooooo`So00000oooool2
o`0000Wooooo0_l00007ooooo`Ko00001?ooool3o`0000;ooooo1?l000001?oooooo0000o`000?l0
0002ooooo`Wo00004?ooool2o`0000Gooooo0_l0000>ooooo`;o00001Oooool2o`0000?ooooo0_l0
0005ooooo`;o00000_ooool2o`0000;ooooo0_l0000:ooooo`;o0000;oooool001cooooo00?o0000
ooooooooool04oooool2o`00023ooooo0_l0000Pooooo`;o00001oooool2o`0000Oooooo0_l00003
ooooo`;o00000_ooool2o`0000Gooooo0_l00004ooooo`;o00002?ooool5o`000003ooooool0003o
000001;ooooo0_l00006ooooo`?o000000?oooooo`000?l000001?l000000ooooooo0000o`000003
o`000004ooooool0003o0000o`0000;ooooo0_l000000ooooooo0000o`000004o`0000Kooooo0_l0
0003ooooo`?o00008?ooool2o`0000?ooooo0_l00005ooooo`;o00000_ooool2o`0000;ooooo0_l0
000:ooooo`;o0000;oooool001cooooo00?o0000ooooooooool04oooool2o`00037ooooo0_l0000?
ooooo`;o00001oooool2o`0000Oooooo0_l00003ooooo`?o00002?ooool2o`0000Cooooo0_l00003
ooooo`;o00000oooool2o`000003ooooool0003o000001Gooooo0_l00006ooooo`;o00000_ooool6
o`000003ooooool0003o000000;o000000?oooooo`000?l000000ol00004ooooo`Go00001oooool2
o`0000?ooooo0ol00007ooooo`;o00005oooool2o`0004oooooo000Looooo`03o`000?oooooooooo
03Kooooo0ol00008ooooo`Co000000?oooooo`000?l000003_ooool3o`0001Gooooo0ol00009oooo
o`;o00001oooool3o`0000Wooooo0_l00009ooooo`;o00001Oooool2o`0000_ooooo1ol00004oooo
o`So000000?oooooo`000?l000001Ol0000Fooooo`;o00004Oooool3o`0000kooooo0_l00014oooo
o`007?ooool00ol0003oooooooooo`0fooooo`?o00002?ooool4o`0000Kooooo0_l00009ooooo`;o
00001_ooool2o`00017ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l00007ooooo`?o
00001?ooool7o`0000Sooooo0ol00005ooooo`;o00000oooool2o`0000Kooooo1Ol00006ooooo`Co
00000_ooool2o`000003ooooool0003o000000Co00006oooool2o`0000gooooo0ol00003ooooo`;o
00002Oooool2o`0004Cooooo000Looooo`03o`000?oooooooooo03[ooooo0_l00002ooooo`Oo0000
0_ooool2o`0000;ooooo0_l0000Aooooo`;o00004Oooool2o`0000;ooooo0_l000000ooooooo0000
o`000002o`0000;ooooo0_l00004ooooo`;o00001?ooool5o`000003ooooool0003o000000Oooooo
0ol00009ooooo`?o000000?oooooo`000?l000002?l00006ooooo`_o000000?oooooo`000?l00000
0_l00008ooooo`;o00000oooool2o`0000Oooooo0_l00002ooooo`;o00003_ooool2o`0000?ooooo
1?l00002ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0>_ooool2o`0000;ooooo2?l0
00000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l000002Oooool2o`000003ooooool0
003o000000kooooo1Ol00005ooooo`;o00000_ooool2o`0000[ooooo0_l00004ooooo`;o00004ooo
ool2o`0000;ooooo4?l000000ooooooo0000o`000007o`0000;ooooo1?l00008ooooo`;o00000ooo
ool2o`0000Oooooo1?l000000ooooooo0000o`00000=ooooo`;o00001Oooool2o`0000;ooooo0_l0
0019ooooo`007?ooool00ol0003oooooooooo`14ooooo`?o00000_ooool2o`0000Cooooo0_l00000
0ooooooo0000o`000009ooooo`;o000000?oooooo`000?l000001_ooool2o`0000;ooooo0_l00002
ooooo`Go00001?ooool2o`0000?ooooo0_l00002ooooo`;o00001_ooool2o`0001Wooooo0_l00003
oooooa3o000000?oooooo`000?l000000_l000001Ooooooo0000o`000?l0003ooooo00?o00006_oo
ool2o`000003ooooool0003o000000gooooo0_l00006ooooo`Co000000Coooooo`000?l0003o0000
1?ooool2o`0000Sooooo0_l0000fooooo`007?ooool00ol0003oooooooooo`12ooooo`Go00000_oo
ool2o`0000?ooooo0_l0000Hooooo`;o00000_ooool2o`0000;ooooo1Ol00004ooooo`;o000000?o
ooooo`000?l000001?ooool2o`0001;ooooo0_l00002ooooo`;o000000?oooooo`000?l000001_oo
ool7o`000003ooooool0003o000001So00000oooool2o`0000[ooooo0_l0000Sooooo`Co000000Co
ooooo`000?l0003o00001?ooool2o`0000Sooooo0_l0000fooooo`007?ooool00ol0003ooooooooo
o`0Pooooo`;o00004_ooool2o`000004ooooool0003o0000ooooo`;o00001_ooool2o`0000Gooooo
0_l000000ooooooo0000o`000002o`0001_ooooo0ol00002ooooo`Ko00000oooool2o`000003oooo
ool0003o000000?o00002?ooool7o`0000Kooooo0_l00002ooooo`Go00001Oooool7o`000004oooo
ool0003o0000oooooaoo00002?ooool2o`0000Wooooo0_l00002ooooo`;o00001oooool2o`0000Go
oooo0_l000000ooooooo0000o`00000:ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0
8?ooool2o`0001;ooooo0_l000001?oooooo0000o`000?ooool2o`00013ooooo1?l00003ooooo`?o
00004oooool4o`000003ooooool0003o000000Ko00000_ooool5o`000003ooooool0003o000000?o
00001_ooool7o`0000Kooooo0_l00003ooooo`;o00001oooool7o`000003ooooool0003o000001Oo
000000?oooooo`000?l000000_l00002ooooo`;o00004oooool6o`0000Oooooo0_l000001Ooooooo
0000o`000?l0003ooooo00;o000000?oooooo`000?l000002_ooool4o`00047ooooo000Looooo`03
o`000?oooooooooo03cooooo0_l00007ooooo`;o00000oooool2o`0000Oooooo0ol00002ooooo`;o
00002Oooool2o`0000Cooooo4Ol000000ooooooo0000o`000004ooooo`;o00001oooool3o`0000Go
oooo0ol0000=ooooo`Co000000?oooooo`000?l000008Ol00002ooooo`;o00005Oooool3o`0000_o
oooo0ol0000Booooo`;o0000@Oooool001cooooo00?o0000ooooooooool0??ooool2o`0000Oooooo
0_l00003ooooo`;o00001oooool2o`0000?ooooo0ol00008ooooo`;o00001OoooolBo`0000_ooooo
0_l000001Ooooooo0000o`000?l0003ooooo00;o00000_ooool3o`0000_ooooo1?l00004ooooo`co
00000_oooolFo`0000Wooooo0_l0000;ooooo`Co00002Oooool2o`0000_ooooo0_l0001;ooooo`00
7?ooool00ol0003oooooooooo`15ooooo`;o00000_ooool2o`0000Gooooo0_l00003ooooo`;o0000
0_ooool2o`000003ooooool0003o000000_ooooo4ol00007ooooo`;o00000_ooool2o`000003oooo
ool0003o000000;ooooo0_l00006ooooo`;o00001_ooool6o`0000;ooooo1Ol000000ooooooo0000
o`00000;o`000003ooooool0003o0000013o00002Oooool2o`0000Cooooo0_l00005ooooo`;o0000
2oooool2o`0000_ooooo0ol0001:ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o
8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0<Oooool2o`00
00Cooooo0_l00008ooooo`;o00001_ooool3o`0000Cooooo0_l000000ooooooo0000o`000003o`00
00Cooooo0ol00008oooooaCo00001_ooool4o`0000Gooooo0_l00009ooooo`?o00000_ooool2o`00
00;ooooo;?l000000ooooooo0000o`00000>ooooo`;o00002_ooool2o`0001Cooooo0_l00007oooo
o`?o0000@?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEE
ogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo037ooooo0_l00004ooooo`;o00002?oo
ool2o`0000Oooooo0ol00006ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o00001?oo
ool2o`0000;ooooo0_l000000ooooooo0000o`000004o`000003ooooool0003o000000Wo00001Ooo
ool7o`0000;ooooo0_l00008ooooo`?o00000oooool2o`0000;ooooo0_l00003ooooo`Co000000?o
ooooo`000?l000004_l000000ooooooo0000o`00000>o`0000[ooooo0_l0000>ooooo`;o00005ooo
ool2o`0000Cooooo0ol00010ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0eooooo`Co00001_oo
ool2o`0000;ooooo0ol00003ooooo`Co00001_ooool2o`0000?ooooo0_l00009ooooo`go000000?o
ooooo`000?l000002_l00005ooooo`Ko00000_ooool2o`0000Sooooo0_l00008ooooo`;o00001ooo
oolEo`000003ooooool0003o000000oo00002Oooool3o`0001oooooo0_l00005ooooo`;o0000Aooo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oV9RHoooooonH
V9So8B4Q00Kooooo0ol0000eooooo`Co00001_ooool2o`000003ooooool0003o000000;o00000ooo
ool2o`0000Sooooo0_l00005ooooo`;o00002OoooolHo`0000;ooooo1?l00002ooooo`;o00003?oo
ool2o`0000;ooooo0_l0000>ooooob?o00000_ooool2o`0000[ooooo0_l0000@ooooo`;o00003Ooo
ool2o`0000Oooooo0_l00015ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09
ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0kooooo`;o00000_oo
ool2o`000003ooooool0003o000001Gooooo0ol00009oooooaKo00001?ooool4o`000003ooooool0
003o000000?o00002_ooool2o`0000;ooooo0_l00002ooooo`;o00000_ooool2o`0000Cooooo9Ol0
000=ooooo`;o00003oooool4o`0001Kooooo0_l00015ooooo`0000?ooooooa0@4?ooool00_ooool0
0ol@413oooooooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0>oooool2
o`0000;ooooo0_l00002ooooo`;o00004?ooool2o`0000;ooooo0_l00009oooooaSo00001?ooool2
o`000003ooooool0003o000000Co00002_ooool2o`0000Kooooo0_l00002ooooo`;o00001?oooolT
o`0000Gooooo0_l00007ooooo`;o00002oooool2o`0000;ooooo0_l0001Oooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0@ooo
ool2o`00013ooooo0_l0000=oooooaSo00000_ooool2o`0000?ooooo1?l00006ooooo`;o00001?oo
ool3o`0000_ooooo:ol00002ooooo`;o00005?ooool2o`0000kooooo0ol0000;ooooo`?o0000A?oo
ool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03
o`000?oooooooooo01kooooo0_l0000/ooooo`;o00003?ooool2o`000003ooooool0003o000000Ko
oooo5_l00002ooooo`?o00003Oooool2o`0000Gooooo1Ol00005ooooo`;o000000?oooooo`000?l0
0000:Ol0000Mooooo`;o00002Oooool5o`0000;ooooo0_l00005ooooo`?o0000A?ooool001cooooo
00?o0000ooooooooool07_ooool2o`0001Wooooo0_l00009ooooo`;o00000_ooool2o`0000;ooooo
0_l0000<ooooo`;o000000?oooooo`000?l000001?oooolHo`0000;ooooo0_l00005ooooo`;o0000
1oooool2o`0000Gooooo1Ol00005ooooo`;o00002?oooolQo`000004ooooool0003o0000o`0001?o
oooo0_l00007ooooo`;o00003?ooool2o`0000;ooooo0_l00003ooooo`;o0000Aoooool001cooooo
00?o0000ooooooooool0>?ooool3o`0000Wooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o
000000?oooooo`000?l000003_ooool2o`0000?ooooo6?l000000ooooooo0000o`000006ooooo`;o
00001oooool2o`0000Gooooo0_l0000>ooooo`_o000000?oooooo`000?l000007Ol0000:ooooo`;o
00000oooool4o`0000kooooo0_l00002ooooo`;o00001Oooool2o`0000?ooooo0_l00017ooooo`00
7?ooool00ol0003oooooooooo`0hooooo`;o00003Oooool3o`000004ooooool0003o0000ooooo`;o
00003_ooool2o`0000;ooooo6Ol000000ooooooo0000o`000008ooooo`Go00003?ooool3o`0000Oo
oooo0_l000000ooooooo0000o`000006o`000003ooooool0003o000001co00000_ooool2o`0000Go
oooo0_l00002ooooo`?o00000oooool2o`0000Oooooo0ol00006ooooo`;o00000_ooool2o`0000Go
oooo0ol000000ooooooo0000o`000008ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0
B?ooool2o`0000Wooooo0ol0000<ooooo`;o000000?oooooo`000?l000005?l0000;ooooo`Go0000
3?ooool3o`0000;ooooo3ol000000ooooooo0000o`00000@o`0000;ooooo2?l000001Ooooooo0000
o`000?l0003ooooo00;o00000oooool8o`0000Cooooo0_l00007ooooo`?o000000?oooooo`000?l0
00000_l0000<ooooo`?o000000?oooooo`000?l000002?ooool4o`0003cooooo000Looooo`03o`00
0?oooooooooo03?ooooo0_l0000Cooooo`;o000000?oooooo`000?l000001_ooool3o`000003oooo
ool0003o000000Wooooo6?l00007ooooo`;o00002_ooool2o`000003ooooool0003o000000[ooooo
2Ol000001?oooooo0000o`000?ooool?o`000003ooooool0003o000000go000000?oooooo`000?l0
00000ol000000ooooooo0000o`000004o`000003ooooool0003o000000?o00000oooool2o`0000_o
oooo1?l00007ooooo`;o00000oooool4o`0000cooooo0_l0000looooo`007?ooool00ol0003ooooo
ooooo`0cooooo`;o00005_ooool4o`0000Sooooo0_l000000ooooooo0000o`000007oooooaGo0000
2Oooool2o`0000Gooooo0_l00003ooooo`;o000000?oooooo`000?l000003Oooool3o`000003oooo
ool0003o000000?ooooo1?l000000ooooooo0000o`00000Io`0000Cooooo0_l000000ooooooo0000
o`000004o`0000Cooooo0_l0000Cooooo`;o00001_ooool2o`0000Cooooo1?l00008ooooo`;o0000
?oooool001cooooo00?o0000ooooooooool0@Oooool2o`0000[ooooo0_l00004ooooo`;o000000?o
ooooo`000?l000001?l00003ooooo`;o00000_ooool2o`000003ooooool0003o000000?o000000?o
ooooo`000?l000001_l0000:ooooo`;o00002?ooool2o`000003ooooool0003o000000?ooooo0_l0
000=ooooo`?o000000?oooooo`000?l000000oooool4o`000003ooooool0003o000000go000000?o
ooooo`000?l000003?l00004ooooo`;o000000?oooooo`000?l000006_ooool2o`0000Kooooo0_l0
0006ooooo`;o00002?ooool2o`0003oooooo000Looooo`03o`000?oooooooooo03Sooooo0_l00007
ooooo`;o00001?ooool3o`0000Wooooo0_l000000ooooooo0000o`000003o`0000Cooooo0_l00005
ooooo`;o000000?oooooo`000?l000002_l000000ooooooo0000o`000006ooooo`;o000000?ooooo
o`000?l000002?ooool2o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool7
o`0000Oooooo2?l000000ooooooo0000o`000007o`0000;ooooo4?l0000Oooooo`Co00001Oooool2
o`0000Sooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00001Oooool2o`00
00Kooooo0ol0000Eooooo`;o00001Oooool2o`0000;ooooo1?l000000ooooooo0000o`000004o`00
0004ooooool0003o0000ooooo`?o00001Oooool2o`0000Sooooo0_l00002ooooo`Oo00000_ooool2
o`0000;ooooo1?l000000ooooooo0000o`000007ooooobCo00002oooool2o`0000gooooo0ol00002
ooooo`Co00003oooool2o`0004Oooooo000Looooo`03o`000?oooooooooo03oooooo0_l0000@oooo
o`;o00000_ooool2o`0000Gooooo1Ol000001Ooooooo0000o`000?l0003ooooo00;o00000oooool3
o`000003ooooool0003o000000;o00000oooool2o`000003ooooool0003o000000?o00000oooool2
o`0000Oooooo0_l00003ooooo`;o000000?oooooo`000?l000001_ooool2o`000004ooooool0003o
0000o`0000Gooooo0_l00003oooooaco00000_ooool2o`0000oooooo0_l0000=ooooo`?o00004ooo
ool2o`0004Wooooo000Looooo`03o`000?oooooooooo03gooooo0_l0000Booooo`;o000000Gooooo
o`000?l0003o0000ooooo`02o`0000;ooooo0ol00002ooooo`Co00001_ooool3o`0000;ooooo0ol0
0006ooooo`;o000000?oooooo`000?l000000oooool3o`0000Kooooo0_l00006ooooo`;o00000ooo
ool2o`000003ooooool0003o000000Kooooo0_l000000ooooooo0000o`00000Wo`0000Gooooo0_l0
0004ooooo`;o00002Oooool2o`00017ooooo0ol00004ooooo`;o0000BOooool001cooooo0_l0000n
ooooo`;o00004_ooool2o`000003ooooool0003o000000;ooooo0_l00007ooooo`?o00002?ooool2
o`0000;ooooo0_l00007ooooo`;o00001_ooool3o`0000Kooooo0_l00003ooooo`;o000000?ooooo
o`000?l000000oooool2o`000003ooooool0003o000000Cooooo2ol000001?oooooo0000o`000?oo
oolOo`0000?ooooo1?l00004ooooo`;o00001Oooool2o`0000;ooooo0_l00003ooooo`;o00001Ooo
ool2o`0000Gooooo0ol0001?ooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o00000_ooool2
o`0000_ooooo0_l0000Iooooo`Co00000oooool2o`0000Cooooo1?l000000ooooooo0000o`000006
ooooo`Go00001?ooool2o`000003ooooool0003o000000Oooooo0_l000000ooooooo0000o`00000H
o`000003ooooool0003o000000Gooooo1?l0000;ooooo`;o00001oooool2o`0000Gooooo0_l00005
ooooo`;o00000_ooool2o`0004cooooo000Looooo`03o`000?oooooooooo05Gooooo1Ol0000?oooo
o`;o00004_ooool4o`0000?ooooo0_l00005ooooo`?o000000?oooooo`000?l000000_l00004oooo
o`?o00002Oooool2o`0000?ooooo0_l00002ooooob3o00001?ooool2o`0000Kooooo0_l00008oooo
o`;o00003_ooool3o`0000Kooooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`1Eooooo`Go
00000_ooool2o`0000Kooooo0_l00003ooooo`Co00004Oooool3o`0000Gooooo0_l00003ooooo`;o
00000_ooool4o`0000Sooooo0_l00005ooooo`Co000000Goooooo`000?l0003o0000ooooo`0Qo`00
00Cooooo0_l00006ooooo`;o00002?ooool3o`000003ooooool0003o000000Cooooo0_l000000ooo
oooo0000o`000004o`0005Cooooo000Looooo`03o`000?oooooooooo05cooooo0ol00005ooooo`;o
00000oooool4o`000003ooooool0003o000000oooooo0ol00004ooooo`;o00001Oooool2o`0000?o
oooo0_l00007ooooo`;o00001Oooool4o`000003ooooool0003o000000;ooooo6_l00002ooooo`Ko
00001Oooool2o`0000oooooo0_l000001?oooooo0000o`000?l00003ooooo`;o000000Coooooo`00
0?l0003o0000Eoooool001cooooo00?o0000ooooooooool0C?ooool2o`0000Oooooo0ol00004oooo
o`?o00001_ooool8o`000003ooooool0003o000000Oooooo0_l00007ooooo`;o00002oooool2o`00
00?ooooo0_l00003ooooo`;o000000?oooooo`000?l000001oooool2o`0000;ooooo0_l00003oooo
oa[o00000oooool5o`0000Cooooo0_l00002ooooo`;o00001oooool2o`0000Gooooo0ol0001Poooo
o`007?ooool00ol0003oooooooooo`15ooooo`;o00001Oooool2o`0000Oooooo0ol00004ooooo`Co
00001Oooool8o`0000[ooooo0_l0000;ooooo`;o00004Oooool2o`000003ooooool0003o000000_o
oooo0_l000000ooooooo0000o`000002oooooaSo000000Coooooo`000?l0003ooooo1Ol00007oooo
o`;o00001Oooool4o`0001Kooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`15ooooo`;o
00003oooool4o`0000;ooooo1?l00005ooooo`;o000000?oooooo`000?l000003_ooool2o`000003
ooooool0003o000000Oooooo0_l000000ooooooo0000o`00000Mooooo`?o000000?oooooo`000?l0
00005Ol000000ooooooo0000o`000002o`000004ooooool0003o0000ooooo`Go00003_ooool2o`00
01Sooooo0_l00003ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0C?ooool2o`0000So
oooo1?l00004ooooo`;o00005?ooool2o`000003ooooool0003o000000Co00000_ooool2o`0000Ko
oooo0_l0000Iooooo`;o00000_ooool2o`000003ooooool0003o000000Wo000000?oooooo`000?l0
00004Ol00004ooooo`Co00001?ooool2o`0000Oooooo0_l0000?ooooo`Co00001?ooool2o`0000Co
oooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00003_ooool3o`0001Gooooo
0_l000000ooooooo0000o`000002o`0000Cooooo0_l000001?oooooo0000o`000?l00004ooooo`;o
00001oooool2o`0000Oooooo0_l00005ooooo`;o00001Oooool4o`0000?ooooo2Ol000000ooooooo
0000o`000008o`0000;ooooo0_l00006ooooo`;o00001?ooool2o`0001Sooooo1?l00004ooooo`;o
00001Oooool2o`0004[ooooo000Looooo`03o`000?oooooooooo05cooooo0ol00008ooooo`;o0000
2?ooool2o`0000Gooooo0_l00004ooooo`;o00000_ooool5o`0000;ooooo0_l00007ooooo`;o0000
1oooool4o`0000?ooooo0_l00005ooooo`;o000000Coooooo`000?l0003ooooo0ol00002ooooo`;o
000000?oooooo`000?l000003_l00004ooooo`;o00002_ooool2o`0000Gooooo0_l00002ooooo`;o
00002Oooool2o`000003ooooool0003o000000Wooooo1?l0001:ooooo`007?ooool00ol0003ooooo
ooooo`0mooooo`;o00001?ooool2o`0001?ooooo1Ol000000ooooooo0000o`000005ooooo`Co0000
2?ooool2o`0000Sooooo0_l000000ooooooo0000o`000003ooooo`Co00004?ooool2o`0000?ooooo
0ol00003ooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`;o00000oooool2o`000003
ooooool0003o000000;o00000oooool;o`0000;ooooo0_l0000:ooooo`;o00001Oooool2o`0000;o
oooo0_l00007ooooo`Co00003?ooool2o`0004cooooo000Looooo`03o`000?oooooooooo03gooooo
0_l00004ooooo`;o00004oooool5o`000003ooooool0003o000000;o00000oooool2o`0000_ooooo
0_l00007ooooo`;o00002Oooool2o`0000Wooooo0_l00004ooooo`;o00001?ooool2o`0000gooooo
0ol00005ooooo`;o00000_ooool5o`000003ooooool0003o000000?o000000Coooooo`000?l0003o
oooo0ol0000<ooooo`;o00002Oooool2o`0000Sooooo0_l0001Looooo`007?ooool00ol0003ooooo
ooooo`19ooooo`;o00004oooool4o`0000oooooo0ol00003ooooo`;o000000?oooooo`000?l00000
2_ooool2o`0000Oooooo1?l0000:ooooo`;o00003Oooool3o`000003ooooool0003o000000Co0000
0ooooolAo`0000?ooooo0_l00007ooooo`;o00002Oooool2o`0000[ooooo0_l0001Jooooo`007?oo
ool00ol0003oooooooooo`19ooooo`;o00003_ooool6o`0000_ooooo0_l00005ooooo`;o000000Co
ooooo`000?l0003ooooo1ol00004ooooo`;o00002oooool2o`0001[ooooo0_l00003ooooo`Go0000
1?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000;ooooo1?l00003ooooo`;o0000
7_ooool2o`0005[ooooo000Looooo`03o`000?oooooooooo05Wooooo1_l0000;ooooo`;o00002?oo
ool2o`000004ooooool0003o0000o`0000;ooooo0_l00004ooooo`;o00001Oooool2o`0000Gooooo
0_l00006ooooo`;o00002Oooool2o`0000Kooooo0_l00006ooooo`;o00001_ooool2o`0000;ooooo
0_l000000ooooooo0000o`000002ooooo`;o00000_ooool4o`0000Oooooo0_l0001booooo`007?oo
ool2o`0005Cooooo0_l00005ooooo`?o000000Coooooo`000?l0003o00008oooool2o`0000?ooooo
0_l00005ooooo`;o00000oooool2o`000003ooooool0003o000000Wooooo0_l0000;ooooo`;o0000
00?oooooo`000?l000001_ooool2o`0000;ooooo0_l00009ooooo`Co00001oooool2o`0007;ooooo
000Looooo`03o`000?oooooooooo04_ooooo0_l00006ooooo`;o00001_ooool2o`000004ooooool0
003o0000o`0001gooooo0_l00004ooooo`;o00001_ooool4o`0000Gooooo1?l00008ooooo`;o0000
1oooool2o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`;o000000Coooooo`000?l0003o
oooo0_l0000/ooooo`;o0000F_ooool001cooooo00?o0000ooooooooool0Boooool2o`0001Wooooo
0_l0000:ooooo`;o00001?ooool3o`0000?ooooo0ol0000;ooooo`Co00000_ooool2o`000003oooo
ool0003o000000Co00001_ooool2o`0000Oooooo0_l00005ooooo`Co00000oooool6o`0000Sooooo
0_l0000:ooooo`;o00006Oooool2o`0000;ooooo0_l00002ooooo`;o0000D_ooool001cooooo00?o
0000ooooooooool0=?ooool2o`0002oooooo0ol0000:ooooo`Co000000?oooooo`000?l000000_l0
0002ooooo`Ko00002Oooool2o`0000Cooooo1Ol000001?oooooo0000o`000?l0000Fooooo`?o0000
1?ooool2o`000003ooooool0003o000000Wooooo0ol00005ooooo`;o00000_ooool2o`0000_ooooo
0_l00005ooooo`;o00002Oooool2o`0000;ooooo0_l0001Booooo`007?ooool00ol0003ooooooooo
o`0dooooo`;o0000;?ooool2o`000003ooooool0003o000000;ooooo0_l00009ooooo`;o000000?o
ooooo`000?l000001?ooool2o`000003ooooool0003o000000?o00001oooool2o`0000Kooooo1Ol0
000Iooooo`;o00004oooool2o`0000Gooooo0_l0000=ooooo`Co00001Oooool2o`00067ooooo000L
ooooo`03o`000?oooooooooo05gooooo1?l000000ooooooo0000o`000003o`0000;ooooo0_l00005
ooooo`;o00001?ooool2o`0000;ooooo0_l00003ooooo`?o000000?oooooo`000?l000004Oooool3
o`0000?ooooo0_l0000Fooooo`;o000000?oooooo`000?l000009?ooool2o`0001Oooooo0_l0001A
ooooo`007?ooool00ol0003oooooooooo`1Looooo`Go00000_ooool4o`0000;ooooo0_l00005oooo
o`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00000oooool3o`0000Sooooo0_l00003
ooooo`;o00000oooool3o`0000Gooooo0ol0000Eooooo`;o000000?oooooo`000?l000007Oooool2
o`0001kooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o00000_ooool3o`00
01Cooooo0_l0000;ooooo`;o00002?ooool2o`0000?ooooo0_l00003ooooo`?o000000?oooooo`00
0?l000000oooool2o`0001Sooooo0_l00003ooooo`;o00001Oooool2o`00017ooooo0_l0000;oooo
o`;o00002Oooool2o`0000Gooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`1Hooooo`;o
00000_ooool3o`00013ooooo0_l00002ooooo`;o00001Oooool2o`000003ooooool0003o000000?o
oooo0_l0000Dooooo`;o00008_ooool2o`0000Cooooo0ol0000@ooooo`;o00001Oooool2o`0000Go
oooo0_l00009ooooo`;o00001Oooool2o`0005;ooooo000Looooo`03o`000?oooooooooo05cooooo
0_l0000Aooooo`;o00000_ooool4o`000003ooooool0003o000000;o000000?oooooo`000?l00000
0_ooool5o`0000?ooooo0_l0000;ooooo`Go00000oooool2o`0001gooooo0_l00002ooooo`?o0000
00?oooooo`000?l000001?ooool2o`0000;ooooo0_l00004ooooo`;o00001Oooool2o`0001Cooooo
0_l00003ooooo`;o00001_ooool2o`0004Sooooo000Looooo`03o`000?oooooooooo04Gooooo0_l0
0009ooooo`;o00000_ooool2o`0000cooooo0_l00004ooooo`;o00002Oooool4o`000003ooooool0
003o000000Cooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000;o00002ooo
ool2o`000003ooooool0003o000000?ooooo0_l0000Looooo`?o00000_ooool2o`0000;ooooo1?l0
0002ooooo`;o00000_ooool2o`0000Sooooo0_l000000ooooooo0000o`00000Dooooo`;o00000ooo
ool2o`0000Kooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`15ooooo`Co00001oooool2
o`0000;ooooo0_l0000<ooooo`;o00001?ooool2o`0001Cooooo0_l000000ooooooo0000o`000007
o`0000Gooooo0_l00003ooooo`Co00004_ooool2o`0000[ooooo0_l00004ooooo`;o00002Oooool2
o`0000kooooo1?l00005ooooo`;o0000Ioooool001cooooo00?o0000ooooooooool0Aoooool2o`00
01Wooooo0_l00004ooooo`;o00000oooool2o`0000;ooooo0_l0000Booooo`;o00002?ooool2o`00
00?ooooo1?l000000ooooooo0000o`00000?ooooo`;o00002_ooool2o`0000Wooooo0_l00004oooo
o`;o00000_ooool2o`0000?ooooo0_l00005ooooo`;o00001oooool2o`0000;ooooo0_l0001Soooo
o`007?ooool00ol0003oooooooooo`1Wooooo`?o00000oooool2o`000004ooooool0003o0000o`00
00Oooooo0_l000000ooooooo0000o`00000Hooooo`Co00008Oooool2o`0000?ooooo0_l00004oooo
o`;o00000_ooool2o`0000?ooooo0_l00007ooooo`;o00001oooool4o`0006?ooooo000Looooo`03
o`000?oooooooooo05Sooooo0_l00003ooooo`;o00002?ooool2o`0000Oooooo0_l00008ooooo`;o
000000?oooooo`000?l000000ol00007ooooo`;o00000_ooool2o`0000Gooooo0_l000000ooooooo
0000o`00000Sooooo`;o000000?oooooo`000?l000001?ooool2o`0000Cooooo0_l0000<ooooo`;o
000000?oooooo`000?l000001?ooool2o`0006Gooooo000Looooo`03o`000?oooooooooo05Sooooo
0_l00003ooooo`;o00006Oooool2o`0000Gooooo0ol00006ooooo`So00001?ooool2o`0000;ooooo
0_l0000Sooooo`Co00001?ooool2o`0000Kooooo0_l00002ooooo`;o00002Oooool2o`0000;ooooo
0_l0001Wooooo`007?ooool2o`0004Wooooo0_l0000^ooooo`;o00003_ooool2o`000004ooooool0
003o0000ooooo`;o00002?ooool2o`0001kooooo0_l00003ooooo`;o00002_ooool2o`0000;ooooo
1_l0000=ooooo`;o0000Ioooool001cooooo00?o0000ooooooooool0B?ooool2o`000003ooooool0
003o000000Sooooo0_l00002ooooo`;o00005?ooool4o`0000Gooooo0_l00005ooooo`;o00001ooo
ool4o`0000?ooooo0_l0000:ooooo`;o00006oooool2o`0000Sooooo0_l00005ooooo`;o00001?oo
ool2o`0001Sooooo0_l0001Nooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00000_ooool2
o`000003ooooool0003o000000Sooooo0_l00002ooooo`;o00005?ooool4o`0000cooooo0_l00000
0ooooooo0000o`000004ooooo`Co00000oooool2o`0000[ooooo0_l00002ooooo`;o00008Oooool2
o`0000?ooooo1Ol0000Mooooo`;o0000G_ooool001cooooo00?o0000ooooooooool0A?ooool2o`00
00;ooooo0_l0000Looooo`;o00001Oooool3o`0000oooooo0_l000000ooooooo0000o`000005oooo
o`;o00005?ooool2o`0001oooooo0_l00005ooooo`Go000000?oooooo`000?l000000_ooool2o`00
00Gooooo0_l0001_ooooo`007?ooool00ol0003oooooooooo`1Vooooo`;o00000_ooool2o`000004
ooooool0003o0000o`0000;ooooo0_l000000ooooooo0000o`00000;ooooo`;o000000?oooooo`00
0?l000004?ooool2o`000003ooooool0003o000002Cooooo0_l00003ooooo`;o00001_ooool2o`00
00;ooooo0_l00005ooooo`;o00004?ooool2o`0005gooooo000Looooo`03o`000?oooooooooo04ko
oooo0_l0000Jooooo`;o00001_ooool6o`0000[ooooo0_l000000ooooooo0000o`00000?ooooo`?o
000000Coooooo`000?l0003ooooo0_l0000Uooooo`?o00001_ooool2o`0001_ooooo0_l0001Moooo
o`007?ooool00ol0003oooooooooo`1>ooooo`;o00006_ooool2o`0000Oooooo0_l000000ooooooo
0000o`000009ooooo`?o00004_ooool4o`0000?ooooo0_l0000Dooooo`;o00003oooool2o`0000?o
oooo0_l00002ooooo`;o000000?oooooo`000?l000006Oooool2o`0005cooooo000Looooo`03o`00
0?oooooooooo06[ooooo0_l0000;ooooo`;o00002?ooool2o`0000gooooo0ol00003ooooo`Co0000
0oooool2o`0001Cooooo0_l000000ooooooo0000o`000004ooooo`?o00002_ooool2o`0000Gooooo
1?l0000Gooooo`;o0000G?ooool001cooooo00?o0000ooooooooool0L_ooool3o`0000;ooooo0_l0
000=ooooo`;o00001?ooool2o`0000;ooooo1?l00003ooooo`;o00007Oooool2o`0000Cooooo0ol0
0004ooooo`?o00003?ooool2o`0007Gooooo000Looooo`03o`000?oooooooooo067ooooo0_l00000
0ooooooo0000o`000003ooooo`;o00001oooool3o`0000?ooooo0ol0000;ooooo`;o00001?ooool2
o`0000Cooooo0_l00003ooooo`;o00001Oooool2o`0001gooooo0_l00004ooooo`?o0000Poooool0
01cooooo00?o0000ooooooooool0HOooool2o`000003ooooool0003o000000?ooooo0_l00006oooo
o`;o00001Oooool5o`0000?ooooo0_l0000Looooo`;o00000_ooool2o`0001Oooooo1?l00006oooo
o`?o0000POooool001cooooo00?o0000ooooooooool0I?ooool2o`0000Oooooo0_l000001?oooooo
0000o`000?l00008ooooo`?o00000_ooool2o`0000cooooo0_l0000Aooooo`?o00003Oooool2o`00
00Cooooo0_l00002ooooo`Ko00001?ooool3o`0000Wooooo0_l0001fooooo`007?ooool00ol0003o
ooooooooo`1]ooooo`;o000000?oooooo`000?l000002_ooool3o`0000oooooo0_l0000Aooooo`Co
00003?ooool2o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`Go00003_ooool2o`0000oo
oooo0_l0001Uooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o0000;oooool3o`0000cooooo
0_l00004ooooo`;o00001_ooool4o`0000Gooooo0_l00007ooooo`;o00003?ooool9o`0000Oooooo
0_l0000Fooooo`;o0000IOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Co
oooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo04cooooo0_l00002oooo
o`;o00005Oooool5o`0000Wooooo1?l00005ooooo`;o00002?ooool2o`0000;ooooo0_l00002oooo
o`Co000000?oooooo`000?l000000oooool4o`0000kooooo0_l0000;ooooo`;o000000Coooooo`00
0?l0003ooooo0_l00009ooooo`;o0000OOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Ooo
ool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo053ooooo
0_l0000Eooooo`Go00002Oooool4o`000003ooooool0003o000000?ooooo0_l00007ooooo`;o0000
00?oooooo`000?l000000oooool2o`000003ooooool0003o000000;o00002_ooool2o`0000Cooooo
0_l000000ooooooo0000o`000006ooooo`;o00001Oooool2o`00013ooooo0_l0001looooo`0000?o
oooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`1Iooooo`;o00007oooool3o`0000;ooooo0_l00003ooooo`;o0000
1Oooool2o`0000Kooooo0_l0000<ooooo`;o00001?ooool5o`0000Kooooo0_l0000Aooooo`;o0000
1?ooool2o`0007cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go
<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000FOooool2o`0001Gooooo0_l00006ooooo`;o0000
00?oooooo`000?l000001oooool2o`0000_ooooo0_l00002ooooo`;o00001?ooool2o`0000?ooooo
0_l00007ooooo`;o00000_ooool2o`0001?ooooo0_l000000ooooooo0000o`000022ooooo`0000?o
ooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<c<`0
1_ooool00ol0003oooooooooo`1`ooooo`;o00001_ooool6o`0000Gooooo0_l00003ooooo`;o0000
0_ooool2o`0000?ooooo0_l00002ooooo`;o00001?ooool2o`0000?ooooo0_l0000;ooooo`;o0000
4oooool2o`0008Gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go
410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo07[ooooo1?l00005ooooo`;o0000
0oooool2o`0000;ooooo0_l0000=ooooo`Co0000>?ooool2o`0000oooooo0_l0001Oooooo`0000Ko
ooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0
003oooooooooo`1booooo`;o00002_ooool2o`0000_ooooo1?l0000<ooooo`Co00003_ooool2o`00
00Cooooo0_l00006ooooo`;o00006_ooool2o`0000oooooo0_l0001Oooooo`0000Koooooonk^k_lb
<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003ooooooooo
o`1booooo`Co00002?ooool2o`000003ooooool0003o000000;ooooo1?l00002ooooo`Co00002?oo
ool2o`0001Cooooo0ol00003ooooo`Ko00000_ooool2o`0000;ooooo0_l00028ooooo`007?ooool0
0ol0003oooooooooo`1dooooo`Co00002Oooool2o`000003ooooool0003o000000?o00003Oooool5
o`0001?ooooo0_l00004ooooo`Go00001_ooool2o`0008Sooooo000Looooo`03o`000?oooooooooo
07Kooooo0_l00005ooooo`;o00001Oooool2o`00013ooooo0_l000000ooooooo0000o`00000>oooo
o`;o00001?ooool2o`000004ooooool0003o0000ooooo`Co00001_ooool2o`0000gooooo0_l0001i
ooooo`007?ooool00ol0003oooooooooo`1mooooo`;o00002_ooool2o`0001cooooo1?l00004oooo
o`Go00002oooool2o`0000gooooo0_l0001iooooo`007?ooool00ol0003oooooooooo`29ooooo`;o
00001?ooool2o`0000Cooooo0_l0000@ooooo`;o000000?oooooo`000?l000001?ooool4o`0000_o
oooo1?l00026ooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o00001?ooool2o`0002;ooooo
0ol00003ooooo`;o00000oooool2o`0000kooooo0_l00006ooooo`;o00003Oooool2o`0008Kooooo
000Looooo`03o`000?oooooooooo06Gooooo0_l00004ooooo`;o00008oooool2o`0000Sooooo0_l0
0006ooooo`;o00001?ooool2o`0000;ooooo0_l0000=ooooo`;o0000S?ooool001cooooo00?o0000
ooooooooool0T_ooool4o`0000cooooo0_l00004ooooo`;o00000_ooool2o`0000Wooooo0_l00002
ooooo`;o0000S?ooool001cooooo00?o0000ooooooooool0Ioooool2o`0002Wooooo1?l0000Boooo
o`;o00002Oooool2o`0000;ooooo0_l0002@ooooo`007?ooool00ol0003oooooooooo`1Wooooo`;o
0000<_ooool3o`0000[ooooo0_l00003ooooo`;o00001?ooool2o`0009Cooooo000Looooo`03o`00
0?oooooooooo083ooooo1?l0000Gooooo`?o00001_ooool2o`000003ooooool0003o000000;o0000
0_ooool2o`000003ooooool0003o000009Oooooo000Looooo`03o`000?oooooooooo07Cooooo0_l0
000:ooooo`Co00003Oooool2o`0000cooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l0
0005ooooo`;o0000Uoooool001cooooo0_l0001eooooo`;o00002oooool2o`0000;ooooo0_l0000:
ooooo`Co00002_ooool2o`000:Sooooo000Looooo`03o`000?oooooooooo08Gooooo0_l0000<oooo
o`;o00002_ooool2o`0000Gooooo0_l0002Qooooo`007?ooool00ol0003oooooooooo`26ooooo`;o
00007_ooool2o`000:7ooooo000Looooo`03o`000?oooooooooo08Kooooo1?l0000Pooooo`;o0000
5oooool2o`0008Cooooo000Looooo`03o`000?oooooooooo07gooooo0_l00009ooooo`;o00008?oo
ool2o`0000Wooooo0_l0000<ooooo`;o0000Q?ooool001cooooo00?o0000ooooooooool0OOooool2
o`0001Kooooo0_l0000Nooooo`;o00000_ooool2o`0008kooooo000Looooo`03o`000?oooooooooo
09Gooooo0_l0000Rooooo`;o0000S_ooool001cooooo00?o0000ooooooooool0YOooool2o`000:;o
oooo000Looooo`03o`000?oooooooooo0:Gooooo0_l0002Rooooo`007?ooool00ol0003ooooooooo
o`2Cooooo`;o00004?ooool2o`000:;ooooo000Looooo`03o`000?oooooooooo09?ooooo0_l0000@
ooooo`;o00000_ooool2o`0009kooooo000Looooo`03o`000?oooooooooo0:Wooooo0_l0002Noooo
o`007?ooool00ol0003oooooooooo`2Yooooo`;o0000W_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo0_l0002^ooooo`;o0000V_ooool001cooooo00?o0000oooooooo
ool0[Oooool2o`0009[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?oo
ooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom:oooo
o`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo
00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o0000ooooooooool0oooo
oomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo
0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`004_ooool00omEEEGoIVIV
o`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Qooooo`04
oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05_ooool4o`000003oa0@4?oooooooooo
00Go00001?ooool4o`000008oa0@4?ooooooooooolc<c?lQ8B7o0000ob4Q8Oo<c<b<ooooo`00X_oo
ool01Ol0003ooooooooooooooooo000000Wooooo1_l0000<ooooo`03o`000?oooooooooo00;ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo00;ooooo00Go8B4QoiRHV?oo
ooooV9RHob4Q8@2<ooooo`00X_ooool01Ol0003ooooooooooooooooo000001_ooooo00?o0000oooo
ooooool00oooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00002<ooooo`00X_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l0000<
ooooo`03o`000?oooooooooo00Cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`02
ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80S?ooool00:;ooooo00Go0000ohN7QoooooooZJVYo`00
000Kooooo`03o`000?oooooooooo00Gooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`02ooooo`05olc<c?l0003o0000o`000?o<c<`0S?ooool00:7ooooo00?o410@o`000?mgMgL00_l0
00000onHV9Soooooooooo`0Iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`05oa0@4?nj^[[ooooookZj^_l@4100S?ooool00<;ooooo00?o
0000ooooooooool00_ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
0_ooool01Ol0003o^[Zjoooooonj^[[o000008cooooo0030ooooo`03oeEEEOmVIVKo000000Cooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`03oeEEEOmVIVKo000000Cooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@2<ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1224) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.63345 .43652 Mdot
.65308 .48117 Mdot
.3582 .44573 Mdot
.5476 .6021 Mdot
.39765 .21831 Mdot
.37716 .42158 Mdot
.55143 .33206 Mdot
.52856 .37742 Mdot
.35218 .42264 Mdot
.63656 .27328 Mdot
.55672 .35092 Mdot
.48269 .60051 Mdot
.53585 .36334 Mdot
.56849 .6118 Mdot
.4104 .15841 Mdot
.59112 .68032 Mdot
.6322 .46983 Mdot
.30098 .59377 Mdot
.57328 .56721 Mdot
.33487 .41923 Mdot
.68326 .50795 Mdot
.56088 .61583 Mdot
.68852 .4706 Mdot
.56923 .61186 Mdot
.52791 .62862 Mdot
.67364 .43966 Mdot
.69024 .42111 Mdot
.53797 .65725 Mdot
.5274 .66634 Mdot
.53639 .37861 Mdot
.38747 .68398 Mdot
.38369 .19121 Mdot
.53877 .56535 Mdot
.19758 .4403 Mdot
.50886 .36013 Mdot
.7045 .65776 Mdot
.37075 .43392 Mdot
.52679 .34471 Mdot
.52503 .33987 Mdot
.50547 .3313 Mdot
.54263 .34705 Mdot
.68108 .45502 Mdot
.57843 .31348 Mdot
.36623 .50211 Mdot
.59977 .66 Mdot
.49954 .22648 Mdot
.75257 .67862 Mdot
.5837 .65777 Mdot
.63462 .45558 Mdot
.24397 .44692 Mdot
.39182 .28408 Mdot
.52098 .32504 Mdot
.33857 .39133 Mdot
.30848 .82367 Mdot
.51529 .35234 Mdot
.60923 .57337 Mdot
.36589 .44231 Mdot
.56585 .62732 Mdot
.57348 .61385 Mdot
.66791 .56418 Mdot
.59754 .64855 Mdot
.35873 .5832 Mdot
.61838 .48449 Mdot
.56105 .46811 Mdot
.35792 .42512 Mdot
.53971 .33737 Mdot
.66727 .47854 Mdot
.52751 .36454 Mdot
.5871 .70337 Mdot
.3334 .42417 Mdot
.58104 .66247 Mdot
.55008 .34374 Mdot
.62516 .46634 Mdot
.55437 .66776 Mdot
.26504 .55256 Mdot
.67261 .23307 Mdot
.36224 .54776 Mdot
.69725 .62197 Mdot
.65922 .59429 Mdot
.27792 .47739 Mdot
.54355 .58699 Mdot
.46092 .71872 Mdot
.61232 .20924 Mdot
.69383 .46948 Mdot
.52238 .68985 Mdot
.34851 .63176 Mdot
.55616 .66414 Mdot
.53038 .2053 Mdot
.54047 .6821 Mdot
.25175 .58868 Mdot
.3564 .40722 Mdot
.65194 .46366 Mdot
.54698 .60013 Mdot
.54507 .67466 Mdot
.58481 .75395 Mdot
.54085 .57012 Mdot
.54676 .63375 Mdot
.64722 .43628 Mdot
.5161 .32891 Mdot
.56905 .55348 Mdot
.37283 .49673 Mdot
.38472 .3884 Mdot
.58641 .59372 Mdot
.3984 .41191 Mdot
.63042 .49593 Mdot
.55295 .67243 Mdot
.51998 .3384 Mdot
.58937 .60196 Mdot
.71003 .39241 Mdot
.65197 .48511 Mdot
.53738 .66357 Mdot
.34032 .56036 Mdot
.51554 .81724 Mdot
.64296 .46676 Mdot
.3153 .47708 Mdot
.52621 .60318 Mdot
.55355 .63905 Mdot
.65479 .47802 Mdot
.40911 .42958 Mdot
.55113 .20415 Mdot
.69404 .44197 Mdot
.49771 .34979 Mdot
.63769 .42778 Mdot
.55191 .70807 Mdot
.36395 .40808 Mdot
.31575 .33387 Mdot
.6159 .38142 Mdot
.39815 .65798 Mdot
.56027 .65968 Mdot
.63373 .30808 Mdot
.3578 .39501 Mdot
.66331 .463 Mdot
.53073 .36819 Mdot
.48531 .61941 Mdot
.66324 .4959 Mdot
.55843 .36426 Mdot
.35464 .56191 Mdot
.42433 .32209 Mdot
.64672 .50248 Mdot
.41033 .50947 Mdot
.5699 .36441 Mdot
.51699 .32423 Mdot
.18458 .53488 Mdot
.66746 .47492 Mdot
.34188 .57346 Mdot
.52854 .37271 Mdot
.37125 .65975 Mdot
.60351 .64835 Mdot
.44125 .73247 Mdot
.75147 .6989 Mdot
.19156 .45867 Mdot
.44461 .33372 Mdot
.33134 .59837 Mdot
.50174 .37124 Mdot
.53412 .62961 Mdot
.66258 .43685 Mdot
.68404 .44959 Mdot
.60056 .63735 Mdot
.53693 .60659 Mdot
.57352 .67114 Mdot
.54749 .67795 Mdot
.74266 .47612 Mdot
.54119 .57572 Mdot
.69282 .73574 Mdot
.64884 .46082 Mdot
.54161 .6149 Mdot
.39485 .44784 Mdot
.50127 .61789 Mdot
.54545 .34445 Mdot
.56032 .62435 Mdot
.5458 .60385 Mdot
.60303 .6371 Mdot
.51624 .32724 Mdot
.44749 .16468 Mdot
.59366 .7686 Mdot
.38886 .20332 Mdot
.26916 .59656 Mdot
.39387 .42098 Mdot
.55329 .6571 Mdot
.34907 .56633 Mdot
.74113 .61464 Mdot
.5624 .59157 Mdot
.71291 .78859 Mdot
.55049 .62588 Mdot
.40656 .20527 Mdot
.62105 .60259 Mdot
.2977 .25581 Mdot
.44243 .71218 Mdot
.53223 .64199 Mdot
.55098 .49703 Mdot
.58328 .40997 Mdot
.34888 .48148 Mdot
.54161 .35004 Mdot
.39255 .45032 Mdot
.36341 .44737 Mdot
.58073 .32753 Mdot
.62133 .53109 Mdot
.6237 .57153 Mdot
.51153 .66477 Mdot
.33112 .41904 Mdot
.62597 .50062 Mdot
.36584 .5855 Mdot
.65913 .42591 Mdot
.63695 .16855 Mdot
.43605 .25181 Mdot
.57419 .37718 Mdot
.33856 .61276 Mdot
.34524 .41435 Mdot
.3918 .39333 Mdot
.31974 .57224 Mdot
.5821 .63948 Mdot
.67318 .47317 Mdot
.17645 .45139 Mdot
.74814 .39637 Mdot
.17124 .53128 Mdot
.64361 .43991 Mdot
.67759 .31351 Mdot
.5535 .36584 Mdot
.38329 .44046 Mdot
.5512 .63808 Mdot
.57666 .64122 Mdot
.68223 .50599 Mdot
.57356 .6697 Mdot
.48036 .58121 Mdot
.54357 .64402 Mdot
.36971 .31195 Mdot
.34896 .54368 Mdot
.58155 .32931 Mdot
.40913 .63773 Mdot
.69142 .45006 Mdot
.39412 .76356 Mdot
.39769 .40552 Mdot
.73275 .61283 Mdot
.55002 .33904 Mdot
.36071 .56982 Mdot
.38566 .39582 Mdot
.36846 .57219 Mdot
.55951 .56678 Mdot
.3755 .46263 Mdot
.3154 .57224 Mdot
.64241 .5947 Mdot
.56999 .68584 Mdot
.75627 .42864 Mdot
.50173 .34685 Mdot
.69126 .43303 Mdot
.59112 .65892 Mdot
.39807 .42448 Mdot
.4949 .60321 Mdot
.4926 .28396 Mdot
.32822 .33341 Mdot
.40073 .39169 Mdot
.32021 .35926 Mdot
.35987 .58859 Mdot
.48674 .26457 Mdot
.66411 .31868 Mdot
.63012 .45995 Mdot
.53735 .57471 Mdot
.27882 .2625 Mdot
.52794 .3723 Mdot
.59022 .60881 Mdot
.23505 .38707 Mdot
.51794 .36275 Mdot
.5666 .62949 Mdot
.52275 .37933 Mdot
.68485 .4515 Mdot
.52722 .79924 Mdot
.63236 .46401 Mdot
.53007 .6776 Mdot
.51611 .33881 Mdot
.39796 .45456 Mdot
.66504 .44036 Mdot
.58679 .63702 Mdot
.54232 .65776 Mdot
.52493 .45399 Mdot
.54179 .62236 Mdot
.44175 .17504 Mdot
.5377 .64436 Mdot
.37714 .45255 Mdot
.58337 .58485 Mdot
.43943 .84499 Mdot
.57125 .28967 Mdot
.66867 .47727 Mdot
.41139 .43187 Mdot
.355 .43237 Mdot
.34476 .50805 Mdot
.58045 .38693 Mdot
.53583 .58719 Mdot
.39555 .42043 Mdot
.44326 .76875 Mdot
.56692 .35734 Mdot
.53094 .57604 Mdot
.42188 .5106 Mdot
.2387 .46803 Mdot
.33853 .39281 Mdot
.53979 .56066 Mdot
.64165 .50256 Mdot
.54501 .59983 Mdot
.4035 .40214 Mdot
.71323 .48016 Mdot
.51828 .63435 Mdot
.63263 .52372 Mdot
.52613 .45237 Mdot
.56355 .34342 Mdot
.62164 .59572 Mdot
.59381 .61968 Mdot
.39348 .44118 Mdot
.68816 .44312 Mdot
.56706 .36238 Mdot
.67629 .44748 Mdot
.26178 .30983 Mdot
.70706 .39758 Mdot
.64601 .55773 Mdot
.32623 .61605 Mdot
.22759 .45021 Mdot
.27216 .28065 Mdot
.33831 .7569 Mdot
.37162 .73689 Mdot
.20437 .3798 Mdot
.40681 .43016 Mdot
.23772 .3992 Mdot
.35927 .43998 Mdot
.52779 .6156 Mdot
.36239 .41222 Mdot
.26741 .2804 Mdot
.54381 .64196 Mdot
.36537 .4178 Mdot
.42868 .7829 Mdot
.5412 .60831 Mdot
.63938 .4778 Mdot
.52767 .16801 Mdot
.38033 .80159 Mdot
.33546 .32876 Mdot
.3482 .44553 Mdot
.33564 .70183 Mdot
.54465 .63332 Mdot
.57705 .57857 Mdot
.64436 .44877 Mdot
.52251 .5808 Mdot
.34988 .60031 Mdot
.33494 .61237 Mdot
.53968 .41223 Mdot
.49253 .73046 Mdot
.61753 .59202 Mdot
.65903 .44144 Mdot
.75284 .47408 Mdot
.25162 .55283 Mdot
.24357 .43677 Mdot
.54125 .38579 Mdot
.52059 .1702 Mdot
.47077 .61458 Mdot
.50149 .30501 Mdot
.32518 .46107 Mdot
.64542 .47415 Mdot
.42749 .17205 Mdot
.53697 .3505 Mdot
.80767 .51808 Mdot
.43761 .57307 Mdot
.58138 .63563 Mdot
.5504 .33562 Mdot
.55965 .54032 Mdot
.35776 .79156 Mdot
.82481 .50419 Mdot
.45989 .6722 Mdot
.53112 .68056 Mdot
.27412 .55629 Mdot
.55719 .6302 Mdot
.57404 .22313 Mdot
.53709 .64822 Mdot
.67024 .44634 Mdot
.61036 .2563 Mdot
.55024 .42678 Mdot
.62091 .76779 Mdot
.51127 .25275 Mdot
.33225 .59889 Mdot
.54828 .6441 Mdot
.58231 .63314 Mdot
.34708 .5992 Mdot
.66824 .50319 Mdot
.54977 .67971 Mdot
.37683 .75333 Mdot
.56338 .66785 Mdot
.53662 .34417 Mdot
.45116 .63339 Mdot
.60917 .44722 Mdot
.51181 .65502 Mdot
.62157 .47674 Mdot
.56314 .33928 Mdot
.51533 .34566 Mdot
.61688 .60066 Mdot
.50548 .32838 Mdot
.55152 .6169 Mdot
.83217 .49816 Mdot
.64375 .49835 Mdot
.53273 .53164 Mdot
.68072 .48085 Mdot
.69023 .62713 Mdot
.50872 .35032 Mdot
.38824 .29641 Mdot
.48396 .60528 Mdot
.53725 .35372 Mdot
.7094 .40311 Mdot
.60454 .66062 Mdot
.55182 .69316 Mdot
.22774 .59477 Mdot
.35221 .44679 Mdot
.54661 .44751 Mdot
.52844 .37844 Mdot
.59181 .63083 Mdot
.51323 .61996 Mdot
.56109 .33586 Mdot
.79775 .45149 Mdot
.41396 .79717 Mdot
.54052 .64391 Mdot
.66164 .45052 Mdot
.66642 .46126 Mdot
.53794 .68777 Mdot
.56964 .58196 Mdot
.37474 .40149 Mdot
.39812 .45826 Mdot
.36023 .46216 Mdot
.52876 .45054 Mdot
.37791 .30203 Mdot
.39903 .23983 Mdot
.50603 .33044 Mdot
.66629 .34205 Mdot
.25795 .59894 Mdot
.50443 .64613 Mdot
.33841 .41088 Mdot
.58729 .61063 Mdot
.55236 .60609 Mdot
.57093 .34478 Mdot
.28331 .34105 Mdot
.52908 .55104 Mdot
.6659 .50666 Mdot
.55827 .37478 Mdot
.53209 .70983 Mdot
.56251 .27071 Mdot
.34784 .56295 Mdot
.1986 .53387 Mdot
.54792 .33999 Mdot
.64193 .47821 Mdot
.50571 .36145 Mdot
.57445 .64963 Mdot
.59226 .57042 Mdot
.65297 .4735 Mdot
.31969 .60205 Mdot
.49748 .60219 Mdot
.56472 .63242 Mdot
.71992 .74612 Mdot
.26202 .6212 Mdot
.37781 .31599 Mdot
.53405 .64186 Mdot
.51288 .64962 Mdot
.33823 .5544 Mdot
.56778 .6637 Mdot
.57612 .67321 Mdot
.54836 .79903 Mdot
.63339 .37573 Mdot
.32107 .6101 Mdot
.81731 .4726 Mdot
.63975 .44249 Mdot
.32602 .22739 Mdot
.38873 .43953 Mdot
.53619 .39313 Mdot
.4446 .81058 Mdot
.33818 .39021 Mdot
.44753 .33943 Mdot
.3536 .21072 Mdot
.54646 .44534 Mdot
.35429 .36243 Mdot
.47613 .61205 Mdot
.55319 .67774 Mdot
.55738 .6375 Mdot
.35296 .57166 Mdot
.67618 .46904 Mdot
.53853 .45805 Mdot
.76811 .33773 Mdot
.55794 .61893 Mdot
.49444 .55666 Mdot
.73894 .34124 Mdot
.24052 .4721 Mdot
.32783 .58639 Mdot
.32552 .60828 Mdot
.55124 .64391 Mdot
.53034 .8153 Mdot
.67155 .43882 Mdot
.58727 .63531 Mdot
.53212 .58623 Mdot
.35425 .45128 Mdot
.65028 .49064 Mdot
.40835 .42027 Mdot
.41677 .27925 Mdot
.39155 .20646 Mdot
.7456 .7319 Mdot
.51099 .34886 Mdot
.63753 .23944 Mdot
.54846 .3764 Mdot
.45632 .70948 Mdot
.37713 .38673 Mdot
.55307 .58737 Mdot
.68997 .44774 Mdot
.59133 .62396 Mdot
.56417 .58092 Mdot
.5829 .63681 Mdot
.50763 .63646 Mdot
.61969 .83601 Mdot
.31311 .58446 Mdot
.56528 .70232 Mdot
.37006 .45334 Mdot
.56756 .20753 Mdot
.66616 .23434 Mdot
.58134 .62757 Mdot
.5446 .65329 Mdot
.65537 .50169 Mdot
.59992 .628 Mdot
.55913 .36852 Mdot
.68183 .43106 Mdot
.54286 .67267 Mdot
.53833 .1809 Mdot
.53136 .66572 Mdot
.33236 .233 Mdot
.5105 .36878 Mdot
.72963 .39728 Mdot
.57935 .6978 Mdot
.33482 .33455 Mdot
.54656 .4476 Mdot
.37958 .39688 Mdot
.49684 .33501 Mdot
.36861 .43181 Mdot
.795 .36779 Mdot
.59928 .5812 Mdot
.53237 .62848 Mdot
.51366 .60894 Mdot
.39471 .42311 Mdot
.50362 .20494 Mdot
.48142 .25767 Mdot
.53232 .7065 Mdot
.38877 .41706 Mdot
.62048 .48508 Mdot
.33538 .65344 Mdot
.68464 .47135 Mdot
.34956 .61336 Mdot
.55515 .35429 Mdot
.32965 .60625 Mdot
.22768 .38484 Mdot
.65122 .48301 Mdot
.70264 .44307 Mdot
.38599 .43395 Mdot
.43714 .54068 Mdot
.18307 .66202 Mdot
.43816 .56434 Mdot
.41786 .68842 Mdot
.64774 .44865 Mdot
.52243 .66464 Mdot
.44486 .66979 Mdot
.45843 .52351 Mdot
.36647 .43084 Mdot
.56162 .5968 Mdot
.51245 .80372 Mdot
.37502 .40128 Mdot
.53383 .57491 Mdot
.36157 .45325 Mdot
.54868 .35162 Mdot
.34134 .41056 Mdot
.68878 .4926 Mdot
.54804 .66574 Mdot
.15707 .60472 Mdot
.36447 .54362 Mdot
.54028 .63495 Mdot
.555 .37744 Mdot
.49378 .39305 Mdot
.57458 .59114 Mdot
.35436 .55802 Mdot
.3728 .41161 Mdot
.42967 .57075 Mdot
.53913 .64582 Mdot
.39311 .4239 Mdot
.63469 .43403 Mdot
.49367 .35387 Mdot
.64258 .67179 Mdot
.34447 .3343 Mdot
.64391 .44783 Mdot
.39925 .50153 Mdot
.51726 .31651 Mdot
.51219 .64863 Mdot
.53313 .57951 Mdot
.66435 .45342 Mdot
.5247 .77124 Mdot
.59828 .60194 Mdot
.54423 .58698 Mdot
.37741 .45546 Mdot
.36907 .42619 Mdot
.5206 .78456 Mdot
.40494 .44293 Mdot
.59325 .57214 Mdot
.6665 .45249 Mdot
.54935 .59736 Mdot
.64842 .49735 Mdot
.5986 .62166 Mdot
.71514 .44095 Mdot
.67231 .50055 Mdot
.56061 .28381 Mdot
.5571 .59897 Mdot
.61074 .55581 Mdot
.58718 .60172 Mdot
.56501 .6726 Mdot
.37014 .40081 Mdot
.32697 .57432 Mdot
.56585 .55887 Mdot
.37759 .571 Mdot
.36787 .57276 Mdot
.58124 .40591 Mdot
.35146 .44759 Mdot
.34699 .58059 Mdot
.74796 .34541 Mdot
.36008 .46069 Mdot
.35634 .58357 Mdot
.66043 .23249 Mdot
.50825 .35746 Mdot
.64029 .49959 Mdot
.54012 .60804 Mdot
.22836 .36087 Mdot
.752 .68195 Mdot
.35672 .47888 Mdot
.53804 .64193 Mdot
.58456 .6031 Mdot
.69637 .45167 Mdot
.82488 .38939 Mdot
.33526 .42956 Mdot
.52171 .64861 Mdot
.66347 .48324 Mdot
.85467 .44868 Mdot
.37403 .44965 Mdot
.35645 .57951 Mdot
.50567 .33564 Mdot
.63682 .52095 Mdot
.61515 .38325 Mdot
.55653 .3361 Mdot
.32468 .43132 Mdot
.38799 .2884 Mdot
.52628 .60239 Mdot
.34056 .40414 Mdot
.19604 .56674 Mdot
.74558 .43987 Mdot
.59109 .40158 Mdot
.32597 .6931 Mdot
.64535 .47162 Mdot
.55484 .37162 Mdot
.32198 .59558 Mdot
.64881 .4373 Mdot
.63686 .47789 Mdot
.56633 .33579 Mdot
.63425 .71939 Mdot
.42137 .51345 Mdot
.52961 .34122 Mdot
.23644 .58704 Mdot
.31903 .29721 Mdot
.33783 .41088 Mdot
.35048 .59928 Mdot
.23705 .36806 Mdot
.68097 .45331 Mdot
.51311 .16773 Mdot
.20171 .56034 Mdot
.5468 .63352 Mdot
.34216 .57954 Mdot
.47204 .21305 Mdot
.77512 .32512 Mdot
.51624 .35965 Mdot
.53697 .427 Mdot
.34797 .6047 Mdot
.59392 .65394 Mdot
.34913 .65935 Mdot
.5426 .59105 Mdot
.55522 .36054 Mdot
.65961 .56694 Mdot
.64149 .48057 Mdot
.565 .33052 Mdot
.1972 .53371 Mdot
.55327 .61577 Mdot
.55802 .59672 Mdot
.41383 .62167 Mdot
.67691 .43361 Mdot
.38032 .39698 Mdot
.5295 .59423 Mdot
.56282 .62922 Mdot
.59601 .56339 Mdot
.62119 .58717 Mdot
.5119 .81387 Mdot
.5232 .63311 Mdot
.48139 .24633 Mdot
.51897 .67434 Mdot
.56201 .60361 Mdot
.62197 .4815 Mdot
.73461 .75083 Mdot
.4271 .27084 Mdot
.5607 .62644 Mdot
.52072 .65893 Mdot
.55507 .32252 Mdot
.43734 .51226 Mdot
.43345 .53885 Mdot
.42669 .56777 Mdot
.35551 .72152 Mdot
.51949 .68064 Mdot
.67312 .47941 Mdot
.31942 .56767 Mdot
.51694 .63217 Mdot
.67003 .48199 Mdot
.60514 .63702 Mdot
.3771 .40176 Mdot
.3648 .46314 Mdot
.7211 .4186 Mdot
.34767 .58677 Mdot
.45907 .57718 Mdot
.65449 .34261 Mdot
.3889 .45424 Mdot
.53101 .6271 Mdot
.57084 .3857 Mdot
.4013 .40001 Mdot
.30862 .37769 Mdot
.63057 .6762 Mdot
.67353 .43642 Mdot
.64914 .46332 Mdot
.44454 .73717 Mdot
.44091 .31882 Mdot
.64484 .7807 Mdot
.55014 .35198 Mdot
.59268 .58567 Mdot
.64747 .30597 Mdot
.64598 .46459 Mdot
.44544 .68375 Mdot
.34505 .58217 Mdot
.51702 .36327 Mdot
.42214 .38005 Mdot
.66095 .49903 Mdot
.63296 .47647 Mdot
.54831 .68425 Mdot
.57151 .63273 Mdot
.38148 .74382 Mdot
.28899 .60771 Mdot
.56489 .34364 Mdot
.35262 .59803 Mdot
.36976 .38839 Mdot
.52153 .63751 Mdot
.68879 .47344 Mdot
.31211 .31672 Mdot
.51862 .64496 Mdot
.36669 .39894 Mdot
.64937 .46946 Mdot
.35849 .59345 Mdot
.36176 .55909 Mdot
.56359 .67187 Mdot
.73688 .4998 Mdot
.52661 .34869 Mdot
.64005 .47464 Mdot
.56206 .2733 Mdot
.57493 .57874 Mdot
.56753 .64114 Mdot
.62146 .65962 Mdot
.56962 .35155 Mdot
.71634 .35581 Mdot
.35609 .60628 Mdot
.67197 .4687 Mdot
.52864 .64599 Mdot
.35338 .59027 Mdot
.69204 .33439 Mdot
.39898 .39009 Mdot
.34229 .41201 Mdot
.35454 .55677 Mdot
.33421 .58395 Mdot
.35882 .56059 Mdot
.51406 .16695 Mdot
.6946 .47455 Mdot
.47147 .61517 Mdot
.59578 .59434 Mdot
.43312 .70659 Mdot
.4868 .6442 Mdot
.56829 .36441 Mdot
.35099 .44377 Mdot
.57602 .58872 Mdot
.52558 .67269 Mdot
.61674 .6516 Mdot
.52274 .54056 Mdot
.61779 .4234 Mdot
.65076 .48703 Mdot
.60611 .59921 Mdot
.36406 .45874 Mdot
.65283 .17198 Mdot
.18382 .37751 Mdot
.58996 .69048 Mdot
.41208 .52726 Mdot
.68957 .47354 Mdot
.52763 .31794 Mdot
.40549 .59294 Mdot
.50532 .35313 Mdot
.66841 .46789 Mdot
.52252 .6339 Mdot
.66606 .34802 Mdot
.34864 .55458 Mdot
.58891 .64568 Mdot
.54636 .3719 Mdot
.585 .6575 Mdot
.55474 .33456 Mdot
.27034 .29496 Mdot
.25935 .65414 Mdot
.5502 .62723 Mdot
.55392 .70022 Mdot
.32249 .70266 Mdot
.58265 .62377 Mdot
.28419 .59398 Mdot
.68923 .47546 Mdot
.56959 .76533 Mdot
.58013 .68351 Mdot
.7652 .53093 Mdot
.56791 .57457 Mdot
.47445 .794 Mdot
.56995 .64131 Mdot
.23834 .48907 Mdot
.54073 .66486 Mdot
.56827 .67659 Mdot
.51171 .34242 Mdot
.55996 .32637 Mdot
.62426 .4635 Mdot
.39673 .41863 Mdot
.36174 .21421 Mdot
.56552 .63592 Mdot
.32525 .33238 Mdot
.67735 .36897 Mdot
.33269 .58567 Mdot
.67202 .46534 Mdot
.82722 .37612 Mdot
.51097 .37316 Mdot
.27109 .63499 Mdot
.48072 .78488 Mdot
.59935 .34694 Mdot
.35863 .63004 Mdot
.60216 .2478 Mdot
.36145 .58425 Mdot
.60344 .6326 Mdot
.29781 .33093 Mdot
.2343 .51421 Mdot
.63204 .67381 Mdot
.5248 .31397 Mdot
.7466 .59332 Mdot
.29159 .32828 Mdot
.36916 .59068 Mdot
.3383 .60892 Mdot
.53172 .3219 Mdot
.42277 .38659 Mdot
.54945 .54233 Mdot
.34246 .58454 Mdot
.39384 .45426 Mdot
.34237 .44116 Mdot
.3375 .38674 Mdot
.67871 .44205 Mdot
.18258 .49695 Mdot
.56511 .26478 Mdot
.55937 .33951 Mdot
.40837 .38405 Mdot
.63212 .41765 Mdot
.69886 .47138 Mdot
.37944 .43532 Mdot
.35962 .40013 Mdot
.65852 .50922 Mdot
.61097 .58224 Mdot
.61683 .64022 Mdot
.55844 .62274 Mdot
.3413 .56559 Mdot
.57404 .63793 Mdot
.38333 .41168 Mdot
.51927 .35971 Mdot
.35158 .4069 Mdot
.53514 .38364 Mdot
.41977 .2358 Mdot
.58255 .64944 Mdot
.54548 .66458 Mdot
.77629 .65778 Mdot
.62906 .44453 Mdot
.46652 .24186 Mdot
.35826 .33291 Mdot
.36067 .44329 Mdot
.57953 .67038 Mdot
.68453 .43192 Mdot
.36994 .59604 Mdot
.79242 .63985 Mdot
.57795 .58634 Mdot
.68654 .47676 Mdot
.52545 .64576 Mdot
.73473 .48217 Mdot
.49822 .84575 Mdot
.67502 .45179 Mdot
.75067 .69834 Mdot
.525 .66368 Mdot
.67536 .27493 Mdot
.51619 .59995 Mdot
.44713 .76042 Mdot
.59783 .60143 Mdot
.64138 .44096 Mdot
.56209 .62168 Mdot
.67583 .42848 Mdot
.39057 .44894 Mdot
.51957 .32097 Mdot
.64239 .455 Mdot
.52775 .5861 Mdot
.09807 .45132 Mdot
.55107 .36191 Mdot
.55013 .64102 Mdot
.50839 .33686 Mdot
.67881 .47115 Mdot
.63563 .45841 Mdot
.75 .30372 Mdot
.42456 .27765 Mdot
.54767 .35213 Mdot
.5226 .64038 Mdot
.56245 .24687 Mdot
.54474 .59418 Mdot
.40333 .74082 Mdot
.60874 .5702 Mdot
.58805 .58856 Mdot
.67967 .23877 Mdot
.56781 .34986 Mdot
.62671 .79006 Mdot
.73965 .28843 Mdot
.57437 .20579 Mdot
.65632 .52231 Mdot
.36944 .59221 Mdot
.43672 .16864 Mdot
.38459 .2992 Mdot
.39154 .42017 Mdot
.58177 .59485 Mdot
.6132 .44353 Mdot
.52161 .34585 Mdot
.3254 .57321 Mdot
.55025 .62842 Mdot
.35485 .40146 Mdot
.37025 .77707 Mdot
.5086 .37674 Mdot
.68057 .45707 Mdot
.67505 .50087 Mdot
.8506 .54508 Mdot
.53184 .64381 Mdot
.54636 .66862 Mdot
.55583 .35668 Mdot
.72599 .33901 Mdot
.364 .57959 Mdot
.41083 .77986 Mdot
.54756 .35356 Mdot
.4975 .47469 Mdot
.66227 .47975 Mdot
.58594 .60538 Mdot
.4763 .19679 Mdot
.2785 .5454 Mdot
.80193 .55791 Mdot
.34823 .56646 Mdot
.39719 .73461 Mdot
.63926 .44225 Mdot
.5306 .3705 Mdot
.42202 .33931 Mdot
.50308 .6607 Mdot
.5843 .60873 Mdot
.40067 .73232 Mdot
.56464 .42135 Mdot
.45669 .66319 Mdot
.57485 .58243 Mdot
.56252 .43973 Mdot
.59423 .60126 Mdot
.50007 .6635 Mdot
.60152 .57403 Mdot
.56332 .65282 Mdot
.68786 .47552 Mdot
.57877 .71543 Mdot
.38512 .40451 Mdot
.46247 .62022 Mdot
.50409 .48035 Mdot
.54086 .63889 Mdot
.53343 .59992 Mdot
.77896 .60159 Mdot
.46241 .35817 Mdot
.64403 .45786 Mdot
.70309 .47862 Mdot
.50042 .33718 Mdot
.61688 .64506 Mdot
.39501 .41128 Mdot
.4892 .64371 Mdot
.36676 .4012 Mdot
.68888 .4681 Mdot
.36569 .44708 Mdot
.51001 .32912 Mdot
.33829 .42706 Mdot
.37677 .3023 Mdot
.52656 .374 Mdot
.66146 .43618 Mdot
.55605 .66814 Mdot
.55393 .37772 Mdot
.39584 .6473 Mdot
.3432 .56597 Mdot
.73482 .27353 Mdot
.54088 .67269 Mdot
.62942 .37962 Mdot
.65409 .52841 Mdot
.3552 .40389 Mdot
.52838 .8309 Mdot
.67145 .50278 Mdot
.31635 .60456 Mdot
.69255 .45307 Mdot
.24391 .60944 Mdot
.33139 .57549 Mdot
.64809 .22122 Mdot
.34882 .34924 Mdot
.29238 .63483 Mdot
.61428 .60119 Mdot
.38089 .63232 Mdot
.34276 .39207 Mdot
.52039 .34664 Mdot
.43499 .34362 Mdot
.57595 .67232 Mdot
.29962 .71817 Mdot
.6327 .50227 Mdot
.39498 .4163 Mdot
.53005 .36584 Mdot
.56574 .36597 Mdot
.55317 .57453 Mdot
.26769 .43695 Mdot
.5952 .62548 Mdot
.43755 .30402 Mdot
.36428 .72286 Mdot
.54984 .53671 Mdot
.54415 .64376 Mdot
.39308 .44301 Mdot
.52532 .64545 Mdot
.31072 .60793 Mdot
.17614 .5052 Mdot
.50707 .59519 Mdot
.36513 .32859 Mdot
.37266 .5472 Mdot
.65205 .47716 Mdot
.5763 .54248 Mdot
.38974 .30385 Mdot
.52912 .64206 Mdot
.50932 .88413 Mdot
.35526 .58649 Mdot
.29338 .34186 Mdot
.51039 .62688 Mdot
.54086 .5804 Mdot
.56109 .47969 Mdot
.60231 .40504 Mdot
.28067 .548 Mdot
.57978 .61584 Mdot
.36436 .69092 Mdot
.53842 .32627 Mdot
.5953 .61531 Mdot
.5556 .6393 Mdot
.66252 .70455 Mdot
.55864 .37226 Mdot
.35307 .43491 Mdot
.34448 .38814 Mdot
.38184 .47515 Mdot
.30891 .60422 Mdot
.52176 .43364 Mdot
.43732 .68655 Mdot
.36286 .78632 Mdot
.30667 .5816 Mdot
.54112 .67681 Mdot
.31715 .54413 Mdot
.52464 .61986 Mdot
.32229 .58972 Mdot
.55357 .37523 Mdot
.6413 .45982 Mdot
.66026 .30362 Mdot
.3324 .41755 Mdot
.52841 .57793 Mdot
.36168 .59342 Mdot
.66557 .43636 Mdot
.30298 .63103 Mdot
.6597 .47597 Mdot
.54176 .35658 Mdot
.50027 .37579 Mdot
.32164 .5792 Mdot
.68008 .47743 Mdot
.51952 .30245 Mdot
.77822 .33573 Mdot
.59465 .56811 Mdot
.50417 .38521 Mdot
.6397 .43374 Mdot
.69207 .49748 Mdot
.6543 .43072 Mdot
.57621 .66642 Mdot
.41221 .52608 Mdot
.60407 .65352 Mdot
.56458 .3444 Mdot
.35814 .44919 Mdot
.3271 .72003 Mdot
.37629 .27005 Mdot
.36528 .51848 Mdot
.59641 .5884 Mdot
.55516 .61373 Mdot
.55138 .64357 Mdot
.57122 .6896 Mdot
.41981 .31083 Mdot
.59107 .62023 Mdot
.51269 .33975 Mdot
.37444 .40926 Mdot
.60349 .6344 Mdot
.36422 .38321 Mdot
.55544 .21552 Mdot
.30771 .58248 Mdot
.51948 .4247 Mdot
.19253 .31736 Mdot
.65513 .43954 Mdot
.41061 .42358 Mdot
.39155 .42372 Mdot
.35561 .56248 Mdot
.52905 .34511 Mdot
.66389 .47616 Mdot
.42656 .76222 Mdot
.3651 .56643 Mdot
.56235 .62454 Mdot
.40707 .54909 Mdot
.27732 .68906 Mdot
.60278 .6263 Mdot
.56376 .58708 Mdot
.39396 .38647 Mdot
.28443 .38217 Mdot
.17202 .5945 Mdot
.43158 .64531 Mdot
.32425 .57684 Mdot
.31373 .59113 Mdot
.64903 .50681 Mdot
.60016 .66696 Mdot
.56374 .34279 Mdot
.46082 .66212 Mdot
.47285 .39094 Mdot
.45098 .59165 Mdot
.60044 .4771 Mdot
.583 .59207 Mdot
.79567 .43248 Mdot
.55185 .61417 Mdot
.69553 .46796 Mdot
.68673 .4576 Mdot
.65675 .44606 Mdot
.52157 .34796 Mdot
.70672 .62869 Mdot
.51835 .33578 Mdot
.1831 .33092 Mdot
.63412 .44927 Mdot
.38256 .34479 Mdot
.38687 .44435 Mdot
.58316 .69665 Mdot
.35701 .5938 Mdot
.48893 .33119 Mdot
.58623 .7041 Mdot
.53352 .8183 Mdot
.39149 .41229 Mdot
.656 .43741 Mdot
.61438 .25112 Mdot
.2259 .31368 Mdot
.4289 .5514 Mdot
.52456 .70826 Mdot
.40149 .61231 Mdot
.33193 .58926 Mdot
.80218 .56291 Mdot
.35149 .60102 Mdot
.54225 .37476 Mdot
.54685 .66114 Mdot
.55684 .66328 Mdot
.59687 .60462 Mdot
.58553 .63663 Mdot
.51766 .31874 Mdot
.5448 .5679 Mdot
.43933 .84494 Mdot
.37305 .46472 Mdot
.64262 .5853 Mdot
.35735 .58833 Mdot
.50491 .32102 Mdot
.376 .4092 Mdot
.46002 .35901 Mdot
.41242 .64191 Mdot
.54037 .64512 Mdot
.57883 .59109 Mdot
.26982 .63765 Mdot
.57417 .58154 Mdot
.486 .64598 Mdot
.39275 .42258 Mdot
.37397 .52862 Mdot
.31416 .59693 Mdot
.31999 .59847 Mdot
.51859 .37139 Mdot
.6883 .46787 Mdot
.35176 .57774 Mdot
.38383 .4513 Mdot
.59573 .5866 Mdot
.5251 .59692 Mdot
.63902 .43495 Mdot
.203 .57081 Mdot
.36231 .59808 Mdot
.58921 .24133 Mdot
.68758 .44449 Mdot
.67684 .41542 Mdot
.58338 .60756 Mdot
.60021 .51546 Mdot
.63351 .52021 Mdot
.30455 .58452 Mdot
.50313 .32313 Mdot
.40868 .59432 Mdot
.55872 .36228 Mdot
.68298 .46192 Mdot
.51799 .6318 Mdot
.68557 .44877 Mdot
.53443 .64338 Mdot
.27961 .23676 Mdot
.56339 .65735 Mdot
.36337 .7906 Mdot
.43372 .73539 Mdot
.37974 .42306 Mdot
.47646 .37037 Mdot
.38822 .43771 Mdot
.68566 .44019 Mdot
.52041 .61578 Mdot
.34544 .6101 Mdot
.60591 .2148 Mdot
.62921 .41767 Mdot
.36729 .39657 Mdot
.35636 .46488 Mdot
.5446 .37732 Mdot
.60386 .61134 Mdot
.58658 .61205 Mdot
.36618 .41973 Mdot
.54232 .53883 Mdot
.66764 .49543 Mdot
.54296 .65507 Mdot
.55963 .6087 Mdot
.38068 .42599 Mdot
.78553 .34723 Mdot
.68131 .40319 Mdot
.55278 .65819 Mdot
.30617 .35063 Mdot
.56982 .36117 Mdot
.61434 .61668 Mdot
.54701 .70054 Mdot
.33675 .58371 Mdot
.65351 .64929 Mdot
.18346 .47198 Mdot
.54082 .38197 Mdot
.39547 .43545 Mdot
.53068 .6456 Mdot
.39363 .44169 Mdot
.52933 .58784 Mdot
.59666 .43289 Mdot
.36498 .39185 Mdot
.54666 .58314 Mdot
.61545 .58184 Mdot
.678 .4337 Mdot
.58058 .59101 Mdot
.75693 .64544 Mdot
.39649 .39897 Mdot
.54572 .57862 Mdot
.73057 .5064 Mdot
.53552 .33896 Mdot
.61759 .61199 Mdot
.32495 .56591 Mdot
.42818 .76455 Mdot
.62736 .34496 Mdot
.27559 .34729 Mdot
.3097 .58224 Mdot
.58858 .65188 Mdot
.36887 .47294 Mdot
.54396 .3263 Mdot
.39179 .80445 Mdot
.59821 .64277 Mdot
.55426 .36171 Mdot
.52087 .36136 Mdot
.34659 .5632 Mdot
.76874 .69934 Mdot
.50832 .63689 Mdot
.58028 .62875 Mdot
.69592 .69494 Mdot
.63647 .43071 Mdot
.57078 .6484 Mdot
.52988 .6731 Mdot
.51283 .3377 Mdot
.48799 .65787 Mdot
.76515 .58533 Mdot
.43937 .78692 Mdot
.57281 .35857 Mdot
.46691 .53458 Mdot
.33585 .40608 Mdot
.3493 .59378 Mdot
.65624 .47036 Mdot
.35955 .59729 Mdot
.33989 .42571 Mdot
.53712 .6747 Mdot
.50098 .35462 Mdot
.72872 .69128 Mdot
.53183 .32164 Mdot
.26192 .3576 Mdot
.63974 .42995 Mdot
.62623 .29601 Mdot
.55647 .87267 Mdot
.53966 .24571 Mdot
.47974 .32213 Mdot
.33281 .58522 Mdot
.41336 .47935 Mdot
.55784 .60955 Mdot
.79908 .58818 Mdot
.55845 .6723 Mdot
.71871 .51975 Mdot
.38668 .45893 Mdot
.36055 .46249 Mdot
.5493 .65965 Mdot
.37362 .72829 Mdot
.54353 .32518 Mdot
.56748 .35536 Mdot
.55216 .57745 Mdot
.53775 .3535 Mdot
.5732 .62854 Mdot
.37553 .40422 Mdot
.62235 .80176 Mdot
.5549 .62687 Mdot
.54777 .69513 Mdot
.60158 .39234 Mdot
.70276 .2576 Mdot
.2261 .43102 Mdot
.8318 .45781 Mdot
.20759 .33854 Mdot
.53682 .35436 Mdot
.61112 .63782 Mdot
.46672 .53604 Mdot
.35057 .38459 Mdot
.50134 .30783 Mdot
.5665 .66228 Mdot
.5679 .66466 Mdot
.56488 .67828 Mdot
.55621 .59534 Mdot
.80747 .55187 Mdot
.51514 .71397 Mdot
.68312 .57636 Mdot
.56754 .58214 Mdot
.38276 .63645 Mdot
.51924 .37397 Mdot
.668 .51354 Mdot
.31219 .56366 Mdot
.58333 .59258 Mdot
.47345 .65386 Mdot
.56549 .32922 Mdot
.18117 .33285 Mdot
.5331 .3776 Mdot
.35538 .4322 Mdot
.53096 .31876 Mdot
.5409 .62423 Mdot
.66612 .46083 Mdot
.48313 .50798 Mdot
.48129 .26652 Mdot
.39129 .41914 Mdot
.54018 .63541 Mdot
.37773 .34049 Mdot
.38704 .40767 Mdot
.55034 .21303 Mdot
.65964 .46384 Mdot
.36891 .68817 Mdot
.687 .45399 Mdot
.54394 .58313 Mdot
.54063 .58627 Mdot
.4888 .36957 Mdot
.51929 .32223 Mdot
.68754 .45647 Mdot
.77076 .70524 Mdot
.36937 .57471 Mdot
.66184 .44403 Mdot
.493 .63067 Mdot
.45756 .46782 Mdot
.66267 .45714 Mdot
.39448 .57008 Mdot
.51399 .35333 Mdot
.62828 .4784 Mdot
.49949 .6469 Mdot
.21547 .55389 Mdot
.32297 .56376 Mdot
.41092 .39564 Mdot
.40384 .56329 Mdot
.40082 .40125 Mdot
.49824 .3313 Mdot
.3879 .43505 Mdot
.53578 .32614 Mdot
.64642 .36218 Mdot
.46307 .60024 Mdot
.55864 .39063 Mdot
.5021 .32739 Mdot
.38543 .43352 Mdot
.54067 .65916 Mdot
.40137 .58898 Mdot
.6131 .62941 Mdot
.50615 .63984 Mdot
.54334 .3317 Mdot
.64773 .43837 Mdot
.68503 .50058 Mdot
.35747 .6546 Mdot
.67616 .49554 Mdot
.36456 .4004 Mdot
.4651 .84039 Mdot
.32347 .3275 Mdot
.5555 .34564 Mdot
.53465 .31747 Mdot
.54146 .59385 Mdot
.368 .43172 Mdot
.39742 .44273 Mdot
.54892 .37387 Mdot
.52585 .52997 Mdot
.57214 .69406 Mdot
.69932 .48137 Mdot
.62834 .4604 Mdot
.67096 .4511 Mdot
.65778 .42917 Mdot
.78057 .53787 Mdot
.51294 .36023 Mdot
.65691 .43434 Mdot
.5509 .58165 Mdot
.5681 .66283 Mdot
.4409 .55099 Mdot
.31603 .59245 Mdot
.6018 .6448 Mdot
.60331 .57781 Mdot
.58292 .60302 Mdot
.34303 .40815 Mdot
.62459 .677 Mdot
.36748 .39159 Mdot
.37733 .46989 Mdot
.38768 .46318 Mdot
.3817 .30068 Mdot
.29761 .65537 Mdot
.21677 .35373 Mdot
.52194 .64989 Mdot
.74236 .36093 Mdot
.37427 .44294 Mdot
.52917 .82456 Mdot
.7171 .35408 Mdot
.58912 .65894 Mdot
.26557 .54369 Mdot
.36879 .42109 Mdot
.67648 .49803 Mdot
.5655 .66078 Mdot
.39473 .46706 Mdot
.32745 .56343 Mdot
.5748 .56994 Mdot
.37688 .38766 Mdot
.67867 .47714 Mdot
.30443 .57381 Mdot
.62662 .46292 Mdot
.38751 .4623 Mdot
.61744 .59537 Mdot
.22215 .73042 Mdot
.35528 .46664 Mdot
.73389 .31593 Mdot
.72284 .45101 Mdot
.54222 .65689 Mdot
.40838 .41123 Mdot
.64677 .42024 Mdot
.4948 .34425 Mdot
.47058 .40169 Mdot
.6376 .48918 Mdot
.35834 .46082 Mdot
.38589 .39059 Mdot
.39257 .42118 Mdot
.64684 .48579 Mdot
.53982 .68966 Mdot
.64731 .49406 Mdot
.53364 .31893 Mdot
.54263 .60198 Mdot
.27384 .27815 Mdot
.74453 .36929 Mdot
.68828 .45029 Mdot
.34929 .43023 Mdot
.34166 .55427 Mdot
.54904 .62213 Mdot
.75871 .37796 Mdot
.53515 .65627 Mdot
.55122 .33436 Mdot
.55912 .78975 Mdot
.75306 .66742 Mdot
.59535 .59497 Mdot
.54239 .59338 Mdot
.56607 .35116 Mdot
.54544 .63461 Mdot
.59972 .60386 Mdot
.3952 .29451 Mdot
.65387 .49091 Mdot
.56135 .61833 Mdot
.36867 .45572 Mdot
.37141 .29166 Mdot
.57212 .69237 Mdot
.32321 .48865 Mdot
.3745 .70368 Mdot
.57804 .7771 Mdot
.55634 .67304 Mdot
.4351 .62272 Mdot
.56381 .5966 Mdot
.58746 .64576 Mdot
.5296 .61302 Mdot
.81909 .5484 Mdot
.35932 .39375 Mdot
.38673 .41985 Mdot
.31293 .57083 Mdot
.37206 .70068 Mdot
.34036 .58098 Mdot
.51224 .35275 Mdot
.28354 .46146 Mdot
.36642 .39198 Mdot
.68336 .47238 Mdot
.59213 .63982 Mdot
.35742 .4687 Mdot
.58781 .60885 Mdot
.53929 .62539 Mdot
.39848 .41189 Mdot
.34167 .39715 Mdot
.28797 .34254 Mdot
.31306 .5743 Mdot
.65085 .44984 Mdot
.60775 .63407 Mdot
.36428 .58808 Mdot
.51871 .666 Mdot
.43592 .70776 Mdot
.65431 .44953 Mdot
.65164 .49261 Mdot
.68035 .50222 Mdot
.53658 .674 Mdot
.54372 .62554 Mdot
.52033 .33397 Mdot
.69161 .45688 Mdot
.53738 .3407 Mdot
.52147 .45968 Mdot
.33462 .51482 Mdot
.56655 .66239 Mdot
.60351 .25274 Mdot
.34127 .59541 Mdot
.35275 .41173 Mdot
.28673 .68925 Mdot
.31423 .56924 Mdot
.53548 .64591 Mdot
.39998 .43577 Mdot
.32042 .59057 Mdot
.63677 .67043 Mdot
.16369 .43122 Mdot
.3308 .55546 Mdot
.5522 .58078 Mdot
.50119 .68977 Mdot
.83525 .47028 Mdot
.31098 .57063 Mdot
.50396 .34033 Mdot
.53735 .67382 Mdot
.6175 .50012 Mdot
.35726 .60179 Mdot
.48699 .24481 Mdot
.37185 .4135 Mdot
.19626 .50902 Mdot
.59588 .70355 Mdot
.76937 .65737 Mdot
.33562 .60195 Mdot
.66706 .47294 Mdot
.71268 .48068 Mdot
.57749 .60297 Mdot
.31252 .56906 Mdot
.57481 .34846 Mdot
.36497 .40878 Mdot
.42251 .2736 Mdot
.6453 .48555 Mdot
.6003 .26931 Mdot
.34613 .42801 Mdot
.58245 .24103 Mdot
.50125 .79756 Mdot
.61701 .63018 Mdot
.82912 .47287 Mdot
.43358 .3685 Mdot
.55489 .68473 Mdot
.36272 .55605 Mdot
.54527 .38119 Mdot
.4995 .34855 Mdot
.54546 .35712 Mdot
.66699 .36606 Mdot
.42586 .56516 Mdot
.41141 .42572 Mdot
.52231 .28067 Mdot
.34956 .5919 Mdot
.41113 .61243 Mdot
.52093 .59743 Mdot
.55529 .61602 Mdot
.604 .60779 Mdot
.59147 .60039 Mdot
.56862 .60243 Mdot
.53541 .34693 Mdot
.6333 .36724 Mdot
.4334 .56499 Mdot
.65876 .45257 Mdot
.27831 .41099 Mdot
.38508 .44467 Mdot
.41218 .42736 Mdot
.31607 .58274 Mdot
.57515 .2256 Mdot
.36588 .38351 Mdot
.36323 .44631 Mdot
.57042 .68283 Mdot
.65985 .49843 Mdot
.50834 .6859 Mdot
.54626 .58719 Mdot
.36251 .40377 Mdot
.54789 .47653 Mdot
.7722 .59579 Mdot
.62711 .67797 Mdot
.38617 .56828 Mdot
.42398 .52427 Mdot
.33029 .55792 Mdot
.51798 .61977 Mdot
.53851 .82359 Mdot
.33907 .42246 Mdot
.36028 .43099 Mdot
.33488 .59996 Mdot
.60424 .46717 Mdot
.64802 .4726 Mdot
.48003 .31524 Mdot
.51333 .33133 Mdot
.52742 .60438 Mdot
.36462 .76931 Mdot
.62417 .53847 Mdot
.26546 .44669 Mdot
.54977 .35634 Mdot
.39095 .44687 Mdot
.59764 .5928 Mdot
.55402 .58164 Mdot
.33689 .59712 Mdot
.35177 .24788 Mdot
.59821 .58091 Mdot
.56056 .19299 Mdot
.25838 .65345 Mdot
.20902 .56721 Mdot
.58436 .60906 Mdot
.65203 .48971 Mdot
.37565 .3862 Mdot
.34971 .59939 Mdot
.49699 .61757 Mdot
.18184 .39909 Mdot
.63367 .44285 Mdot
.53538 .37392 Mdot
.5031 .49279 Mdot
.40981 .5864 Mdot
.54789 .67882 Mdot
.55771 .67114 Mdot
.57939 .6591 Mdot
.15516 .48546 Mdot
.35063 .40051 Mdot
.69063 .46947 Mdot
.33529 .56472 Mdot
.68091 .48831 Mdot
.38527 .42474 Mdot
.60804 .28144 Mdot
.53863 .66155 Mdot
.63307 .4423 Mdot
.66527 .47257 Mdot
.5383 .37794 Mdot
.49411 .35308 Mdot
.51631 .47672 Mdot
.56452 .65483 Mdot
.34475 .45363 Mdot
.66672 .43237 Mdot
.40986 .55217 Mdot
.33215 .57645 Mdot
.51072 .34737 Mdot
.57248 .58514 Mdot
.34343 .40199 Mdot
.53945 .56848 Mdot
.64731 .46195 Mdot
.36405 .44633 Mdot
.30493 .33595 Mdot
.31023 .58905 Mdot
.57747 .64827 Mdot
.29703 .60112 Mdot
.39609 .43508 Mdot
.55781 .60724 Mdot
.63604 .2452 Mdot
.37904 .55128 Mdot
.47189 .26181 Mdot
.39452 .4569 Mdot
.33176 .33308 Mdot
.64978 .50479 Mdot
.7033 .37711 Mdot
.35758 .42993 Mdot
.60323 .24426 Mdot
.34813 .26572 Mdot
.60426 .59995 Mdot
.67925 .45092 Mdot
.45101 .38057 Mdot
.32084 .22646 Mdot
.78312 .3604 Mdot
.55143 .64073 Mdot
.40484 .44384 Mdot
.33112 .59649 Mdot
.5551 .34327 Mdot
.3279 .49551 Mdot
.38379 .55642 Mdot
.33783 .4361 Mdot
.52869 .61463 Mdot
.67436 .47334 Mdot
.51811 .35277 Mdot
.63216 .35011 Mdot
.37868 .4545 Mdot
.35274 .4429 Mdot
.59727 .59325 Mdot
.34575 .58294 Mdot
.76509 .39525 Mdot
.37928 .40611 Mdot
.26874 .64841 Mdot
.32683 .4086 Mdot
.36783 .5814 Mdot
.56439 .59159 Mdot
.34882 .65459 Mdot
.59153 .67437 Mdot
.69068 .26715 Mdot
.38489 .43929 Mdot
.64974 .45666 Mdot
.57134 .67233 Mdot
.45887 .78513 Mdot
.35938 .40618 Mdot
.41471 .52823 Mdot
.23457 .48004 Mdot
.5128 .35679 Mdot
.2875 .69152 Mdot
.57563 .64008 Mdot
.54259 .32502 Mdot
.33997 .59451 Mdot
.55789 .65669 Mdot
.54383 .62214 Mdot
.69471 .44552 Mdot
.54766 .37318 Mdot
.31103 .2929 Mdot
.56268 .32793 Mdot
.50674 .36394 Mdot
.69994 .44824 Mdot
.57192 .6178 Mdot
.35469 .43311 Mdot
.36769 .42232 Mdot
.50433 .619 Mdot
.57089 .83116 Mdot
.64544 .47442 Mdot
.42152 .41531 Mdot
.1586 .5077 Mdot
.60987 .55862 Mdot
.30351 .70843 Mdot
.36718 .23868 Mdot
.57247 .36453 Mdot
.55723 .57778 Mdot
.6796 .47381 Mdot
.44345 .43966 Mdot
.35186 .43957 Mdot
.52647 .67827 Mdot
.52171 .35535 Mdot
.32482 .56403 Mdot
.39085 .39926 Mdot
.26867 .44055 Mdot
.58485 .64458 Mdot
.26074 .54747 Mdot
.40799 .42763 Mdot
.46305 .15535 Mdot
.45703 .36405 Mdot
.67642 .44703 Mdot
.53933 .62167 Mdot
.66564 .50654 Mdot
.32883 .56785 Mdot
.50322 .4909 Mdot
.51973 .35738 Mdot
.54023 .72867 Mdot
.39556 .8406 Mdot
.39388 .42396 Mdot
.69011 .47423 Mdot
.59326 .59239 Mdot
.59108 .46916 Mdot
.57643 .63259 Mdot
.47829 .62328 Mdot
.35696 .53208 Mdot
.5429 .33419 Mdot
.53513 .32392 Mdot
.55267 .60427 Mdot
.36464 .57 Mdot
.38483 .44906 Mdot
.36094 .40965 Mdot
.59472 .16546 Mdot
.5933 .3521 Mdot
.3893 .74795 Mdot
.57088 .66138 Mdot
.35046 .45648 Mdot
.37713 .27474 Mdot
.55543 .35616 Mdot
.5198 .5931 Mdot
.39456 .41144 Mdot
.22892 .56035 Mdot
.46574 .77326 Mdot
.57021 .59946 Mdot
.52843 .68881 Mdot
.50984 .33399 Mdot
.42982 .59656 Mdot
.37615 .46241 Mdot
.60501 .56309 Mdot
.53669 .39106 Mdot
.53565 .77536 Mdot
.18755 .55362 Mdot
.65099 .44945 Mdot
.25453 .42311 Mdot
.5346 .3464 Mdot
.52434 .68813 Mdot
.3605 .57917 Mdot
.3607 .38702 Mdot
.35009 .39865 Mdot
.52503 .63456 Mdot
.55553 .56883 Mdot
.30692 .69275 Mdot
.67643 .49076 Mdot
.51774 .37244 Mdot
.54883 .66888 Mdot
.65841 .2937 Mdot
.59548 .60211 Mdot
.5246 .33396 Mdot
.21498 .72975 Mdot
.61086 .61824 Mdot
.57831 .62892 Mdot
.76644 .38776 Mdot
.63618 .48453 Mdot
.69056 .47709 Mdot
.30983 .74145 Mdot
.57156 .66044 Mdot
.27626 .67172 Mdot
.64651 .4519 Mdot
.64585 .47043 Mdot
.41959 .28634 Mdot
.55146 .62143 Mdot
.5442 .73847 Mdot
.55535 .33605 Mdot
.50423 .35789 Mdot
.64464 .49048 Mdot
.60978 .60389 Mdot
.52546 .38132 Mdot
.80485 .49039 Mdot
.36934 .433 Mdot
.55531 .8192 Mdot
.63894 .47278 Mdot
.5493 .43154 Mdot
.55308 .35502 Mdot
.18574 .32813 Mdot
.32158 .40467 Mdot
.54195 .66117 Mdot
.57777 .65223 Mdot
.34463 .59558 Mdot
.60964 .62344 Mdot
.36365 .46424 Mdot
.53823 .35316 Mdot
.68157 .53524 Mdot
.65723 .44544 Mdot
.56855 .64331 Mdot
.5663 .22247 Mdot
.47928 .23339 Mdot
.25004 .40554 Mdot
.6531 .47653 Mdot
.67876 .44363 Mdot
.36956 .4605 Mdot
.40579 .4403 Mdot
.57546 .61028 Mdot
.56498 .35555 Mdot
.69112 .4556 Mdot
.5312 .33104 Mdot
.33927 .42197 Mdot
.35618 .4382 Mdot
.35384 .39368 Mdot
.55234 .56096 Mdot
.36628 .45138 Mdot
.29555 .43966 Mdot
.59221 .26649 Mdot
.69993 .46864 Mdot
.22688 .64589 Mdot
.64033 .35097 Mdot
.69449 .4002 Mdot
.35331 .60711 Mdot
.39674 .43431 Mdot
.54736 .32109 Mdot
.54982 .59526 Mdot
.58467 .59942 Mdot
.3048 .38722 Mdot
.55338 .32738 Mdot
.32595 .57163 Mdot
.53899 .32245 Mdot
.34692 .5631 Mdot
.23972 .52778 Mdot
.60495 .61903 Mdot
.52748 .59372 Mdot
.54031 .34893 Mdot
.36615 .44945 Mdot
.37951 .41429 Mdot
.32107 .55968 Mdot
.58702 .42291 Mdot
.38783 .4079 Mdot
.64036 .46815 Mdot
.78207 .51572 Mdot
.38598 .39017 Mdot
.56792 .65642 Mdot
.44138 .69081 Mdot
.78896 .62469 Mdot
.57061 .68989 Mdot
.41059 .28854 Mdot
.71668 .71892 Mdot
.58487 .66116 Mdot
.76496 .68228 Mdot
.3467 .33472 Mdot
.65283 .50404 Mdot
.38416 .45983 Mdot
.395 .38507 Mdot
.5489 .5559 Mdot
.34146 .54815 Mdot
.49943 .62023 Mdot
.63532 .47121 Mdot
.62576 .49555 Mdot
.2283 .58745 Mdot
.72757 .30388 Mdot
.32725 .59472 Mdot
.31827 .59099 Mdot
.3567 .42576 Mdot
.76455 .29185 Mdot
.56783 .71307 Mdot
.32392 .57564 Mdot
.46646 .58343 Mdot
.52653 .6203 Mdot
.41324 .73147 Mdot
.27081 .59284 Mdot
.64777 .48907 Mdot
.36727 .64183 Mdot
.35275 .42143 Mdot
.67171 .49928 Mdot
.66977 .31 Mdot
.59443 .66048 Mdot
.65577 .44842 Mdot
.52709 .3308 Mdot
.45354 .33009 Mdot
.63666 .45696 Mdot
.44023 .69925 Mdot
.55443 .37093 Mdot
.41019 .54628 Mdot
.35948 .66738 Mdot
.77856 .75058 Mdot
.53443 .34957 Mdot
.37473 .39183 Mdot
.36723 .42118 Mdot
.35979 .41116 Mdot
.67575 .49371 Mdot
.39733 .44178 Mdot
.68131 .48444 Mdot
.8087 .41281 Mdot
.60118 .47746 Mdot
.32293 .57905 Mdot
.43064 .27229 Mdot
.67754 .46362 Mdot
.50072 .84064 Mdot
.49661 .8715 Mdot
.55794 .57711 Mdot
.54188 .3169 Mdot
.32268 .58639 Mdot
.5771 .18813 Mdot
.33687 .58718 Mdot
.30085 .64192 Mdot
.56131 .79676 Mdot
.56927 .63372 Mdot
.73311 .62117 Mdot
.33032 .608 Mdot
.66033 .48016 Mdot
.55627 .60883 Mdot
.45454 .40092 Mdot
.34072 .58724 Mdot
.34337 .55985 Mdot
.5681 .61168 Mdot
.65657 .43714 Mdot
.35045 .42515 Mdot
.50986 .32664 Mdot
.32533 .61284 Mdot
.71325 .44925 Mdot
.57517 .68478 Mdot
.5293 .6528 Mdot
.44055 .538 Mdot
.31902 .621 Mdot
.53589 .35448 Mdot
.8082 .60928 Mdot
.39805 .45231 Mdot
.44488 .38787 Mdot
.25961 .63895 Mdot
.38981 .30182 Mdot
.38313 .43752 Mdot
.39302 .43682 Mdot
.5718 .60366 Mdot
.33588 .62244 Mdot
.57633 .78712 Mdot
.54188 .3032 Mdot
.37808 .38652 Mdot
.36373 .40767 Mdot
.6376 .51079 Mdot
.23219 .59733 Mdot
.49595 .61606 Mdot
.53782 .38259 Mdot
.34762 .39876 Mdot
.60421 .42081 Mdot
.34857 .58507 Mdot
.50543 .82787 Mdot
.60487 .62345 Mdot
.54501 .66364 Mdot
.5324 .36335 Mdot
.51677 .3373 Mdot
.44051 .44897 Mdot
.2537 .62008 Mdot
.7296 .70379 Mdot
.61391 .3498 Mdot
.64496 .69555 Mdot
.63225 .50478 Mdot
.68808 .44945 Mdot
.50466 .25264 Mdot
.56338 .32792 Mdot
.57927 .66677 Mdot
.68851 .46471 Mdot
.40142 .36111 Mdot
.74626 .43134 Mdot
.39754 .73877 Mdot
.31841 .71556 Mdot
.5357 .6417 Mdot
.66154 .49282 Mdot
.6366 .48352 Mdot
.67055 .4229 Mdot
.35812 .33595 Mdot
.57997 .61634 Mdot
.54312 .6425 Mdot
.59567 .63853 Mdot
.56807 .51859 Mdot
.58942 .62849 Mdot
.69114 .37684 Mdot
.49066 .48133 Mdot
.65638 .61791 Mdot
.60377 .56544 Mdot
.56309 .37942 Mdot
.5458 .67783 Mdot
.36336 .56768 Mdot
.53257 .60435 Mdot
.40249 .74343 Mdot
.54865 .368 Mdot
.68969 .40351 Mdot
.6475 .35854 Mdot
.56445 .68128 Mdot
.30547 .59158 Mdot
.49067 .39654 Mdot
.26369 .29643 Mdot
.29486 .58267 Mdot
.64012 .46935 Mdot
.37445 .43623 Mdot
.55074 .32295 Mdot
.35936 .43884 Mdot
.55662 .56181 Mdot
.51086 .25589 Mdot
.48538 .21452 Mdot
.53561 .4553 Mdot
.58884 .59834 Mdot
.61666 .67982 Mdot
.64408 .46667 Mdot
.40055 .43465 Mdot
.61208 .50005 Mdot
.57248 .66972 Mdot
.34402 .56527 Mdot
.34269 .59134 Mdot
.45766 .391 Mdot
.42849 .18841 Mdot
.72257 .40127 Mdot
.5334 .36129 Mdot
.3764 .40238 Mdot
.35253 .60111 Mdot
.68772 .28906 Mdot
.49321 .35118 Mdot
.56632 .34993 Mdot
.53701 .37577 Mdot
.52429 .66519 Mdot
.36578 .39126 Mdot
.65677 .60906 Mdot
.35058 .4552 Mdot
.54314 .63372 Mdot
.34559 .40667 Mdot
.39353 .41304 Mdot
.35571 .59143 Mdot
.52522 .37538 Mdot
.34657 .442 Mdot
.5427 .58313 Mdot
.6494 .4442 Mdot
.55565 .41897 Mdot
.45278 .75452 Mdot
.71195 .29157 Mdot
.70462 .51485 Mdot
.62964 .46337 Mdot
.31713 .2346 Mdot
.57076 .36004 Mdot
.53852 .52444 Mdot
.28432 .35692 Mdot
.51699 .63923 Mdot
.52502 .8503 Mdot
.41184 .42117 Mdot
.39424 .40627 Mdot
.56277 .59242 Mdot
.41859 .38204 Mdot
.57105 .63814 Mdot
.34257 .42639 Mdot
.29967 .38095 Mdot
.58099 .53438 Mdot
.37344 .44999 Mdot
.60115 .55946 Mdot
.548 .61481 Mdot
.64911 .49118 Mdot
.40767 .40959 Mdot
.51927 .59223 Mdot
.56749 .16417 Mdot
.51884 .3387 Mdot
.38373 .33675 Mdot
.45555 .70332 Mdot
.53415 .34526 Mdot
.6645 .44488 Mdot
.5067 .63008 Mdot
.33795 .59586 Mdot
.6786 .46565 Mdot
.47416 .77927 Mdot
.32143 .60209 Mdot
.50589 .84643 Mdot
.63938 .48422 Mdot
.39116 .39289 Mdot
.36167 .57578 Mdot
.60871 .64377 Mdot
.3614 .38725 Mdot
.4696 .36396 Mdot
.38269 .43947 Mdot
.58691 .6135 Mdot
.4322 .26221 Mdot
.51277 .36906 Mdot
.55315 .64265 Mdot
.39676 .40499 Mdot
.3954 .29234 Mdot
.52335 .66199 Mdot
.55814 .59944 Mdot
.20562 .57676 Mdot
.44099 .82103 Mdot
.33245 .5822 Mdot
.66304 .41896 Mdot
.55056 .58179 Mdot
.33302 .56216 Mdot
.27658 .51453 Mdot
.53649 .6703 Mdot
.63596 .43834 Mdot
.62488 .587 Mdot
.40752 .4173 Mdot
.53037 .34044 Mdot
.5344 .45034 Mdot
.32721 .56366 Mdot
.86955 .54135 Mdot
.33807 .42915 Mdot
.51819 .61259 Mdot
.58317 .5909 Mdot
.21588 .44595 Mdot
.65475 .50404 Mdot
.65944 .75165 Mdot
.57752 .64854 Mdot
.55806 .52185 Mdot
.55939 .65273 Mdot
.41846 .41447 Mdot
.64691 .47239 Mdot
.58163 .62653 Mdot
.6018 .25896 Mdot
.55788 .6957 Mdot
.31156 .57436 Mdot
.77274 .38903 Mdot
.56663 .68711 Mdot
.31802 .81358 Mdot
.27313 .60648 Mdot
.37401 .45133 Mdot
.47332 .24496 Mdot
.70108 .20126 Mdot
.66744 .36299 Mdot
.68527 .47935 Mdot
.40827 .22184 Mdot
.35465 .43384 Mdot
.42795 .25056 Mdot
.31107 .23596 Mdot
.54609 .61138 Mdot
.5481 .67895 Mdot
.29011 .62742 Mdot
.382 .46648 Mdot
.33199 .42439 Mdot
.589 .56951 Mdot
.51077 .67721 Mdot
.35726 .44418 Mdot
.54119 .58044 Mdot
.56997 .56186 Mdot
.51531 .32131 Mdot
.63193 .45708 Mdot
.55043 .3371 Mdot
.54854 .37712 Mdot
.79298 .45345 Mdot
.25317 .58925 Mdot
.52422 .3359 Mdot
.56182 .37471 Mdot
.41626 .73521 Mdot
.32666 .69272 Mdot
.35622 .60287 Mdot
.47561 .16777 Mdot
.36242 .41162 Mdot
.57694 .61872 Mdot
.63151 .47351 Mdot
.73953 .68769 Mdot
.31615 .50111 Mdot
.58648 .7938 Mdot
.57634 .66807 Mdot
.35548 .41125 Mdot
.3585 .33563 Mdot
.49624 .66981 Mdot
.36577 .4797 Mdot
.54816 .67085 Mdot
.33296 .42124 Mdot
.75929 .55079 Mdot
.59579 .24377 Mdot
.32858 .41601 Mdot
.70105 .47621 Mdot
.55051 .66483 Mdot
.63806 .47508 Mdot
.55224 .35053 Mdot
.36294 .58466 Mdot
.33402 .57869 Mdot
.56128 .60863 Mdot
.6205 .61301 Mdot
.24729 .53902 Mdot
.54839 .6213 Mdot
.53074 .61379 Mdot
.34621 .33463 Mdot
.53365 .60766 Mdot
.59413 .60808 Mdot
.59601 .62322 Mdot
.51902 .6729 Mdot
.50532 .36071 Mdot
.5702 .22657 Mdot
.4946 .5987 Mdot
.48742 .61039 Mdot
.4976 .35943 Mdot
.32702 .27009 Mdot
.5607 .37005 Mdot
.26694 .28116 Mdot
.5473 .33102 Mdot
.33103 .57358 Mdot
.23786 .37729 Mdot
.61254 .671 Mdot
.66042 .43143 Mdot
.49338 .3335 Mdot
.33787 .56328 Mdot
.54259 .35519 Mdot
.34408 .42111 Mdot
.16999 .50702 Mdot
.68659 .41492 Mdot
.45376 .64588 Mdot
.50092 .31591 Mdot
.51103 .26479 Mdot
.34807 .44699 Mdot
.64332 .47904 Mdot
.76444 .60796 Mdot
.59468 .60414 Mdot
.33865 .56109 Mdot
.57208 .60898 Mdot
.51878 .37548 Mdot
.35437 .41809 Mdot
.77688 .36487 Mdot
.33745 .59696 Mdot
.22694 .63402 Mdot
.37503 .41531 Mdot
.59876 .62431 Mdot
.53435 .38206 Mdot
.25632 .69514 Mdot
.5463 .33454 Mdot
.63447 .74439 Mdot
.65085 .51021 Mdot
.83401 .44958 Mdot
.67908 .45782 Mdot
.46545 .34104 Mdot
.17145 .61101 Mdot
.5884 .2176 Mdot
.65506 .43864 Mdot
.56418 .29341 Mdot
.53191 .64476 Mdot
.5303 .6542 Mdot
.70214 .29685 Mdot
.66148 .41938 Mdot
.56525 .57946 Mdot
.31861 .3341 Mdot
.58723 .27583 Mdot
.33394 .74284 Mdot
.39047 .44137 Mdot
.57292 .64177 Mdot
.51861 .38641 Mdot
.5497 .32801 Mdot
.3415 .44016 Mdot
.56936 .35624 Mdot
.54464 .64084 Mdot
.67764 .46232 Mdot
.41349 .47173 Mdot
.34398 .57221 Mdot
.65044 .21714 Mdot
.3684 .56646 Mdot
.38308 .43686 Mdot
.61317 .63565 Mdot
.35689 .43951 Mdot
.71364 .19475 Mdot
.54348 .64788 Mdot
.6464 .45375 Mdot
.54557 .59046 Mdot
.55125 .6615 Mdot
.55028 .68058 Mdot
.34848 .43039 Mdot
.56363 .74989 Mdot
.54207 .58175 Mdot
.5187 .35735 Mdot
.65726 .64376 Mdot
.56908 .68492 Mdot
.40905 .38652 Mdot
.35641 .7078 Mdot
.51194 .28983 Mdot
.63224 .48691 Mdot
.37943 .44729 Mdot
.65786 .44277 Mdot
.62008 .52509 Mdot
.66432 .44513 Mdot
.67327 .66707 Mdot
.76625 .59284 Mdot
.57705 .75749 Mdot
.7273 .50785 Mdot
.52799 .5016 Mdot
.66256 .41914 Mdot
.28305 .60059 Mdot
.68716 .44232 Mdot
.63859 .48867 Mdot
.09541 .59907 Mdot
.66963 .4295 Mdot
.57125 .65466 Mdot
.589 .66492 Mdot
.54523 .25148 Mdot
.40979 .69489 Mdot
.54451 .5979 Mdot
.55345 .58581 Mdot
.35876 .59058 Mdot
.54507 .53236 Mdot
.48908 .25046 Mdot
.43303 .82808 Mdot
.45171 .23411 Mdot
.56943 .60981 Mdot
.54847 .58287 Mdot
.50754 .68023 Mdot
.28517 .7559 Mdot
.81547 .48315 Mdot
.62133 .45233 Mdot
.53589 .69868 Mdot
.65045 .23496 Mdot
.55527 .67864 Mdot
.53127 .67381 Mdot
.53451 .6432 Mdot
.35435 .43279 Mdot
.62516 .4576 Mdot
.50416 .65211 Mdot
.2636 .61147 Mdot
.5458 .67425 Mdot
.39342 .29848 Mdot
.81676 .37094 Mdot
.57617 .63982 Mdot
.62429 .46884 Mdot
.52541 .6467 Mdot
.65068 .50008 Mdot
.66021 .48501 Mdot
.58845 .69013 Mdot
.64873 .68769 Mdot
.6265 .49157 Mdot
.54281 .63313 Mdot
.34871 .4164 Mdot
.45146 .1642 Mdot
.58761 .61517 Mdot
.36186 .5917 Mdot
.57661 .65338 Mdot
.30676 .59596 Mdot
.53364 .61211 Mdot
.33709 .42706 Mdot
.76904 .6503 Mdot
.35937 .42829 Mdot
.83462 .48847 Mdot
.34485 .39647 Mdot
.20879 .58649 Mdot
.63281 .43723 Mdot
.4294 .26822 Mdot
.68654 .76131 Mdot
.38444 .32322 Mdot
.40188 .52002 Mdot
.46569 .48846 Mdot
.56533 .35534 Mdot
.66087 .50702 Mdot
.48699 .5461 Mdot
.28791 .3672 Mdot
.26352 .3829 Mdot
.38508 .40238 Mdot
.7635 .71002 Mdot
.60094 .80379 Mdot
.52951 .59616 Mdot
.71696 .63839 Mdot
.69346 .58586 Mdot
.54633 .68032 Mdot
.50645 .65318 Mdot
.31427 .3767 Mdot
.5549 .57342 Mdot
.65264 .28689 Mdot
.38314 .43278 Mdot
.33964 .56258 Mdot
.643 .46115 Mdot
.32726 .56242 Mdot
.28475 .36805 Mdot
.46049 .49182 Mdot
.34091 .4217 Mdot
.5358 .69026 Mdot
.55209 .59002 Mdot
.65161 .49663 Mdot
.61651 .43787 Mdot
.67953 .43505 Mdot
.32701 .59212 Mdot
.37934 .4279 Mdot
.80301 .581 Mdot
.56045 .58487 Mdot
.66502 .47119 Mdot
.39715 .51169 Mdot
.55306 .58041 Mdot
.54522 .34751 Mdot
.53551 .64973 Mdot
.64746 .44281 Mdot
.53381 .60755 Mdot
.68063 .45887 Mdot
.372 .4361 Mdot
.58804 .6622 Mdot
.56696 .59476 Mdot
.2435 .67067 Mdot
.32943 .5702 Mdot
.64065 .42954 Mdot
.34325 .35537 Mdot
.58511 .58895 Mdot
.43847 .28893 Mdot
.55371 .66953 Mdot
.74567 .42465 Mdot
.51459 .641 Mdot
.37461 .32503 Mdot
.49816 .60063 Mdot
.58692 .61711 Mdot
.42955 .47916 Mdot
.69174 .60792 Mdot
.63523 .4216 Mdot
.53998 .38384 Mdot
.65844 .42775 Mdot
.34153 .74379 Mdot
.32642 .40007 Mdot
.40281 .43288 Mdot
.40995 .62975 Mdot
.51814 .67312 Mdot
.57032 .63121 Mdot
.50002 .37533 Mdot
.31395 .58712 Mdot
.65467 .47711 Mdot
.34649 .56315 Mdot
.26439 .67031 Mdot
.3243 .60027 Mdot
.41374 .41654 Mdot
.26134 .54505 Mdot
.80552 .54468 Mdot
.35796 .59128 Mdot
.65574 .43699 Mdot
.33626 .51882 Mdot
.52977 .6806 Mdot
.27726 .60808 Mdot
.34889 .56771 Mdot
.81186 .65862 Mdot
.59349 .60802 Mdot
.39699 .52185 Mdot
.53173 .33598 Mdot
.36053 .58168 Mdot
.55946 .36294 Mdot
.54965 .59846 Mdot
.47507 .25903 Mdot
.68649 .47325 Mdot
.50875 .37271 Mdot
.61379 .5991 Mdot
.3215 .58525 Mdot
.3553 .39573 Mdot
.48602 .3522 Mdot
.53143 .38294 Mdot
.35099 .24568 Mdot
.78902 .38485 Mdot
.37752 .42575 Mdot
.47109 .79847 Mdot
.55141 .33252 Mdot
.55009 .68392 Mdot
.51518 .54458 Mdot
.54193 .6619 Mdot
.70577 .38728 Mdot
.38406 .44635 Mdot
.55082 .2429 Mdot
.5443 .58922 Mdot
.58975 .64794 Mdot
.63662 .42343 Mdot
.3628 .42151 Mdot
.66623 .45871 Mdot
.66466 .426 Mdot
.37102 .43429 Mdot
.67695 .44986 Mdot
.32314 .60495 Mdot
.60482 .29819 Mdot
.51704 .3275 Mdot
.52087 .36365 Mdot
.36191 .40831 Mdot
.37408 .45369 Mdot
.36224 .44512 Mdot
.53557 .65018 Mdot
.64986 .47576 Mdot
.53713 .61955 Mdot
.54457 .6763 Mdot
.6369 .70366 Mdot
.62866 .4739 Mdot
.53245 .63413 Mdot
.44894 .40403 Mdot
.36599 .61214 Mdot
.34831 .41333 Mdot
.52643 .33648 Mdot
.36543 .28457 Mdot
.48304 .37945 Mdot
.57082 .64612 Mdot
.22904 .5545 Mdot
.66741 .43438 Mdot
.33918 .59302 Mdot
.36796 .596 Mdot
.33492 .58583 Mdot
.58306 .34112 Mdot
.65669 .4209 Mdot
.44016 .8312 Mdot
.57296 .63722 Mdot
.43744 .539 Mdot
.46029 .59359 Mdot
.23978 .54179 Mdot
.52304 .33783 Mdot
.55249 .58269 Mdot
.54652 .44709 Mdot
.77449 .60378 Mdot
.54379 .65993 Mdot
.55288 .68903 Mdot
.30492 .3402 Mdot
.6264 .58618 Mdot
.65383 .51274 Mdot
.26946 .70126 Mdot
.60525 .60754 Mdot
.6036 .42898 Mdot
.67592 .22288 Mdot
.56449 .65784 Mdot
.58151 .65835 Mdot
.57702 .59287 Mdot
.53028 .60694 Mdot
.62673 .48649 Mdot
.38347 .66304 Mdot
.57154 .35693 Mdot
.43557 .5506 Mdot
.50119 .34516 Mdot
.34889 .39005 Mdot
.56892 .23257 Mdot
.66115 .50772 Mdot
.3442 .59577 Mdot
.56174 .20591 Mdot
.34379 .77623 Mdot
.37755 .46204 Mdot
.79957 .48235 Mdot
.34078 .56645 Mdot
.55259 .68569 Mdot
.31963 .60563 Mdot
.36847 .39163 Mdot
.51487 .35875 Mdot
.52272 .68067 Mdot
.68552 .44246 Mdot
.63569 .4596 Mdot
.56131 .578 Mdot
.62972 .22555 Mdot
.54273 .34407 Mdot
.49514 .36682 Mdot
.52981 .66767 Mdot
.60862 .64278 Mdot
.66631 .45547 Mdot
.37501 .40586 Mdot
.41649 .77391 Mdot
.3157 .58045 Mdot
.53761 .57162 Mdot
.52844 .61417 Mdot
.25464 .63179 Mdot
.51258 .3515 Mdot
.40105 .45498 Mdot
.51948 .64935 Mdot
.60701 .35161 Mdot
.51953 .64768 Mdot
.52911 .6993 Mdot
.35009 .41341 Mdot
.50592 .58461 Mdot
.53169 .58838 Mdot
.47625 .61596 Mdot
.56127 .34925 Mdot
.6517 .452 Mdot
.69712 .43149 Mdot
.45053 .5523 Mdot
.54596 .34927 Mdot
.52921 .63825 Mdot
.52064 .34437 Mdot
.53775 .67004 Mdot
.55602 .5756 Mdot
.525 .33401 Mdot
.66706 .4583 Mdot
.40517 .22647 Mdot
.56663 .22563 Mdot
.5311 .60341 Mdot
.59519 .58694 Mdot
.3933 .67406 Mdot
.55688 .7524 Mdot
.56702 .67313 Mdot
.64239 .44804 Mdot
.56119 .58805 Mdot
.55637 .36326 Mdot
.33524 .60801 Mdot
.64929 .44341 Mdot
.38451 .41752 Mdot
.36762 .46195 Mdot
.65387 .35908 Mdot
.39734 .42519 Mdot
.52686 .67557 Mdot
.61765 .52015 Mdot
.687 .42223 Mdot
.67377 .23279 Mdot
.36899 .43016 Mdot
.34613 .6108 Mdot
.55818 .60133 Mdot
.21453 .55217 Mdot
.50828 .3826 Mdot
.37311 .85352 Mdot
.48961 .84484 Mdot
.34721 .54888 Mdot
.59419 .78359 Mdot
.33769 .39895 Mdot
.53568 .57861 Mdot
.36426 .58164 Mdot
.37252 .46031 Mdot
.51875 .63487 Mdot
.5591 .70481 Mdot
.64881 .75543 Mdot
.48079 .51845 Mdot
.51852 .34461 Mdot
.3967 .44759 Mdot
.36848 .55329 Mdot
.4108 .43998 Mdot
.63304 .47147 Mdot
.58446 .61938 Mdot
.61173 .64981 Mdot
.38122 .41113 Mdot
.38933 .46571 Mdot
.538 .63595 Mdot
.66495 .50682 Mdot
.31617 .3772 Mdot
.56434 .61339 Mdot
.54404 .50059 Mdot
.69853 .49134 Mdot
.38712 .43161 Mdot
.59296 .63557 Mdot
.3639 .52854 Mdot
.37499 .41215 Mdot
.34806 .41183 Mdot
.55793 .57668 Mdot
.32091 .60324 Mdot
.59618 .59091 Mdot
.53596 .32522 Mdot
.80908 .62123 Mdot
.55358 .36751 Mdot
.33323 .4975 Mdot
.61739 .60664 Mdot
.59805 .37488 Mdot
.63737 .49516 Mdot
.29858 .63655 Mdot
.32664 .31499 Mdot
.59093 .56829 Mdot
.39618 .19917 Mdot
.53877 .43099 Mdot
.61079 .20908 Mdot
.21599 .37674 Mdot
.35486 .57752 Mdot
.54515 .35626 Mdot
.58041 .65973 Mdot
.53154 .31676 Mdot
.36468 .58472 Mdot
.83002 .48101 Mdot
.59436 .62834 Mdot
.64692 .47042 Mdot
.53945 .64035 Mdot
.63935 .47188 Mdot
.55421 .57799 Mdot
.49087 .65344 Mdot
.32945 .3314 Mdot
.46562 .77256 Mdot
.5163 .64995 Mdot
.17438 .54659 Mdot
.29518 .55042 Mdot
.3255 .56828 Mdot
.54202 .61795 Mdot
.34942 .47383 Mdot
.55666 .33083 Mdot
.70233 .31488 Mdot
.3537 .43303 Mdot
.5563 .3752 Mdot
.66953 .44913 Mdot
.3804 .44217 Mdot
.3655 .46308 Mdot
.50883 .58267 Mdot
.30678 .57981 Mdot
.52434 .3721 Mdot
.58313 .6277 Mdot
.59348 .62629 Mdot
.43873 .79562 Mdot
.30503 .48405 Mdot
.62649 .41767 Mdot
.34879 .8017 Mdot
.70116 .44644 Mdot
.32228 .5753 Mdot
.35033 .4273 Mdot
.56063 .67219 Mdot
.55333 .63926 Mdot
.41676 .27828 Mdot
.69278 .46014 Mdot
.5111 .48544 Mdot
.7767 .46683 Mdot
.33119 .36951 Mdot
.38317 .7152 Mdot
.64122 .45749 Mdot
.38634 .71684 Mdot
.376 .57387 Mdot
.51303 .17703 Mdot
.43903 .75956 Mdot
.52992 .3375 Mdot
.38312 .71215 Mdot
.66593 .47602 Mdot
.53513 .59059 Mdot
.3923 .39279 Mdot
.39416 .41487 Mdot
.6573 .45526 Mdot
.38579 .4759 Mdot
.3541 .59172 Mdot
.58555 .64721 Mdot
.42763 .82178 Mdot
.66266 .34239 Mdot
.36978 .39959 Mdot
.48986 .65468 Mdot
.53894 .37541 Mdot
.56318 .57747 Mdot
.35358 .59827 Mdot
.52934 .34888 Mdot
.27192 .63156 Mdot
.57286 .26214 Mdot
.55723 .60521 Mdot
.21907 .59357 Mdot
.54098 .35031 Mdot
.53678 .7535 Mdot
.57134 .61505 Mdot
.55414 .33538 Mdot
.61791 .69319 Mdot
.45554 .33328 Mdot
.54721 .4521 Mdot
.31328 .23396 Mdot
.52414 .46635 Mdot
.38567 .39252 Mdot
.47153 .30278 Mdot
.41628 .3569 Mdot
.53902 .31867 Mdot
.39374 .46437 Mdot
.38573 .59985 Mdot
.56046 .36183 Mdot
.56629 .68463 Mdot
.55678 .66646 Mdot
.81845 .48011 Mdot
.52158 .42893 Mdot
.47118 .3235 Mdot
.71127 .35759 Mdot
.58908 .59265 Mdot
.60779 .60698 Mdot
.55741 .63565 Mdot
.62526 .4933 Mdot
.5167 .34966 Mdot
.19704 .60613 Mdot
.54829 .34747 Mdot
.49687 .82384 Mdot
.36045 .41229 Mdot
.38895 .44795 Mdot
.57374 .64396 Mdot
.39776 .54178 Mdot
.336 .67202 Mdot
.54503 .6382 Mdot
.39653 .60014 Mdot
.76981 .38368 Mdot
.6101 .63049 Mdot
.6435 .50545 Mdot
.51465 .5659 Mdot
.71797 .46173 Mdot
.51769 .32686 Mdot
.34921 .58175 Mdot
.30785 .64017 Mdot
.51453 .36169 Mdot
.56912 .6312 Mdot
.59192 .32334 Mdot
.55162 .65611 Mdot
.5264 .61 Mdot
.52246 .82609 Mdot
.36645 .56095 Mdot
.36658 .4422 Mdot
.33238 .58637 Mdot
.64643 .49931 Mdot
.23928 .77426 Mdot
.31155 .58651 Mdot
.33013 .6669 Mdot
.83498 .51908 Mdot
.38643 .71225 Mdot
.63392 .46784 Mdot
.30592 .577 Mdot
.53626 .3409 Mdot
.4685 .1537 Mdot
.68396 .74971 Mdot
.55298 .40575 Mdot
.56301 .61803 Mdot
.67833 .49977 Mdot
.64036 .44432 Mdot
.50239 .36639 Mdot
.66008 .48351 Mdot
.61157 .69752 Mdot
.53221 .5974 Mdot
.54037 .31739 Mdot
.61183 .33517 Mdot
.53713 .38426 Mdot
.61184 .28361 Mdot
.54244 .62301 Mdot
.64425 .45216 Mdot
.57046 .55579 Mdot
.6714 .51623 Mdot
.40717 .44542 Mdot
.5747 .68643 Mdot
.35294 .59309 Mdot
.59881 .39056 Mdot
.37783 .42345 Mdot
.22883 .54024 Mdot
.64899 .49599 Mdot
.52961 .28514 Mdot
.65141 .49122 Mdot
.67104 .41969 Mdot
.5535 .3745 Mdot
.67854 .47992 Mdot
.58348 .65472 Mdot
.45323 .38977 Mdot
.66359 .50042 Mdot
.5371 .36829 Mdot
.34532 .57852 Mdot
.67522 .4539 Mdot
.4215 .38486 Mdot
.56391 .6007 Mdot
.35169 .44115 Mdot
.23418 .39246 Mdot
.69827 .46117 Mdot
.33727 .55613 Mdot
.40176 .43261 Mdot
.34613 .55988 Mdot
.74358 .29685 Mdot
.54532 .31605 Mdot
.56479 .79294 Mdot
.38952 .57187 Mdot
.66643 .43099 Mdot
.2413 .37485 Mdot
.56152 .67019 Mdot
.56141 .60007 Mdot
.30778 .59969 Mdot
.64076 .44394 Mdot
.55715 .19092 Mdot
.72164 .42997 Mdot
.59162 .28816 Mdot
.50472 .31911 Mdot
.19615 .57106 Mdot
.617 .27497 Mdot
.78418 .30884 Mdot
.60083 .58252 Mdot
.33008 .41513 Mdot
.56628 .64412 Mdot
.33768 .30609 Mdot
.32316 .58561 Mdot
.42467 .44182 Mdot
.57734 .69313 Mdot
.37259 .44175 Mdot
.57768 .59987 Mdot
.45064 .44357 Mdot
.53269 .55997 Mdot
.34942 .60952 Mdot
.47765 .24764 Mdot
.66437 .42906 Mdot
.34388 .57027 Mdot
.3376 .42169 Mdot
.35142 .68583 Mdot
.52081 .62029 Mdot
.54563 .56182 Mdot
.33086 .37007 Mdot
.64445 .47608 Mdot
.40246 .4035 Mdot
.5252 .32453 Mdot
.34625 .5906 Mdot
.54893 .59418 Mdot
.51619 .66142 Mdot
.43522 .29172 Mdot
.53459 .37671 Mdot
.37505 .47283 Mdot
.54903 .33778 Mdot
.33444 .40121 Mdot
.56726 .57059 Mdot
.39119 .44674 Mdot
.52531 .5879 Mdot
.34034 .32252 Mdot
.52036 .82345 Mdot
.69937 .62172 Mdot
.38557 .44464 Mdot
.37167 .72667 Mdot
.55064 .36596 Mdot
.55169 .33614 Mdot
.81986 .55033 Mdot
.63301 .74914 Mdot
.39988 .79338 Mdot
.2995 .28036 Mdot
.50276 .34179 Mdot
.53904 .37349 Mdot
.35525 .44703 Mdot
.67655 .4843 Mdot
.69101 .43296 Mdot
.33289 .40725 Mdot
.44518 .69236 Mdot
.65488 .47699 Mdot
.4477 .17525 Mdot
.35468 .76114 Mdot
.50309 .63603 Mdot
.34456 .47967 Mdot
.34227 .58734 Mdot
.43699 .69245 Mdot
.44929 .44453 Mdot
.5864 .65494 Mdot
.25319 .61043 Mdot
.36822 .40429 Mdot
.42838 .60227 Mdot
.26829 .28134 Mdot
.59565 .6202 Mdot
.57629 .61722 Mdot
.56379 .63585 Mdot
.32863 .55473 Mdot
.66782 .73895 Mdot
.59086 .63521 Mdot
.44803 .69534 Mdot
.57581 .58141 Mdot
.59725 .72085 Mdot
.33324 .58087 Mdot
.62843 .69236 Mdot
.29155 .34223 Mdot
.28523 .71158 Mdot
.5558 .54956 Mdot
.53027 .32331 Mdot
.38102 .61982 Mdot
.56139 .34469 Mdot
.67929 .65633 Mdot
.44004 .75678 Mdot
.70128 .46889 Mdot
.58343 .65861 Mdot
.38364 .43651 Mdot
.63891 .4462 Mdot
.45389 .30752 Mdot
.15727 .69087 Mdot
.53516 .32257 Mdot
.80032 .30384 Mdot
.54558 .3313 Mdot
.36033 .46081 Mdot
.66565 .45447 Mdot
.76695 .58304 Mdot
.44532 .53497 Mdot
.67718 .45357 Mdot
.46997 .21451 Mdot
.61946 .45034 Mdot
.36862 .7143 Mdot
.69189 .47917 Mdot
.54204 .36845 Mdot
.58186 .33927 Mdot
.59114 .70454 Mdot
.56927 .66183 Mdot
.46622 .48328 Mdot
.33141 .68519 Mdot
.56567 .66772 Mdot
.38117 .43112 Mdot
.5904 .7724 Mdot
.36263 .63857 Mdot
.67671 .47615 Mdot
.57382 .35486 Mdot
.57871 .6138 Mdot
.52191 .63449 Mdot
.52312 .61303 Mdot
.38711 .83485 Mdot
.51926 .17548 Mdot
.54292 .58161 Mdot
.58345 .58541 Mdot
.3772 .44165 Mdot
.38171 .57429 Mdot
.32647 .30357 Mdot
.607 .7364 Mdot
.58245 .66706 Mdot
.33691 .57128 Mdot
.36445 .55602 Mdot
.51771 .63992 Mdot
.26674 .59756 Mdot
.58835 .32053 Mdot
.5837 .62681 Mdot
.6102 .75129 Mdot
.36789 .35111 Mdot
.3821 .46623 Mdot
.38131 .41378 Mdot
.63079 .45091 Mdot
.39477 .4298 Mdot
.33597 .40607 Mdot
.77939 .56204 Mdot
.51034 .47595 Mdot
.57586 .37414 Mdot
.32748 .59304 Mdot
.55244 .64391 Mdot
.64799 .413 Mdot
.60164 .34392 Mdot
.56202 .36421 Mdot
.67356 .437 Mdot
.55762 .334 Mdot
.29476 .589 Mdot
.45111 .62782 Mdot
.38042 .3977 Mdot
.50408 .34496 Mdot
.57501 .26427 Mdot
.33609 .5731 Mdot
.5348 .37901 Mdot
.54633 .27104 Mdot
.58247 .67763 Mdot
.7178 .65972 Mdot
.54547 .63286 Mdot
.58282 .19675 Mdot
.52075 .37326 Mdot
.37333 .31711 Mdot
.5753 .62749 Mdot
.37338 .41342 Mdot
.57557 .71513 Mdot
.55081 .6736 Mdot
.3877 .41655 Mdot
.53046 .59464 Mdot
.36308 .56169 Mdot
.70415 .48104 Mdot
.43935 .55169 Mdot
.70731 .78246 Mdot
.30662 .57956 Mdot
.4535 .30102 Mdot
.57073 .67204 Mdot
.77939 .35529 Mdot
.67518 .45607 Mdot
.51991 .60238 Mdot
.37238 .64109 Mdot
.67221 .49429 Mdot
.66532 .43996 Mdot
.52514 .63737 Mdot
.53573 .33632 Mdot
.38106 .42505 Mdot
.33562 .57711 Mdot
.7392 .27881 Mdot
.55632 .61664 Mdot
.56479 .5917 Mdot
.34264 .56777 Mdot
.5468 .37165 Mdot
.52125 .6536 Mdot
.21556 .42306 Mdot
.58203 .17744 Mdot
.56761 .35117 Mdot
.5698 .68206 Mdot
.68392 .69473 Mdot
.71492 .44105 Mdot
.85814 .4998 Mdot
.27571 .60881 Mdot
.37208 .44659 Mdot
.62834 .62795 Mdot
.265 .7801 Mdot
.34748 .58165 Mdot
.35765 .7809 Mdot
.52261 .62608 Mdot
.56406 .58363 Mdot
.67804 .43487 Mdot
.53539 .62571 Mdot
.68878 .47757 Mdot
.70611 .77536 Mdot
.25117 .63139 Mdot
.64091 .47899 Mdot
.68036 .43271 Mdot
.34625 .65712 Mdot
.32993 .30365 Mdot
.6586 .45312 Mdot
.56618 .57275 Mdot
.64181 .54479 Mdot
.50607 .70002 Mdot
.31363 .60212 Mdot
.27252 .36856 Mdot
.70577 .41573 Mdot
.31692 .55263 Mdot
.36718 .23947 Mdot
.69723 .40949 Mdot
.59156 .35348 Mdot
.52472 .3269 Mdot
.59702 .62391 Mdot
.3961 .41896 Mdot
.4 .43852 Mdot
.5744 .55883 Mdot
.5489 .6502 Mdot
.64694 .49805 Mdot
.32978 .59863 Mdot
.54374 .32173 Mdot
.55418 .58636 Mdot
.34306 .6479 Mdot
.31201 .58348 Mdot
.66686 .48741 Mdot
.59647 .75682 Mdot
.35462 .60839 Mdot
.48402 .62872 Mdot
.58144 .63942 Mdot
.53563 .64165 Mdot
.48969 .67808 Mdot
.51369 .34172 Mdot
.26169 .35488 Mdot
.60413 .63321 Mdot
.26467 .67263 Mdot
.57081 .41534 Mdot
.49393 .64818 Mdot
.65151 .48362 Mdot
.51421 .38598 Mdot
.3983 .3893 Mdot
.4509 .57006 Mdot
.55568 .60814 Mdot
.57727 .21763 Mdot
.80788 .45648 Mdot
.4096 .43443 Mdot
.66858 .41988 Mdot
.33722 .59052 Mdot
.54577 .63994 Mdot
.65742 .66405 Mdot
.56192 .66325 Mdot
.3067 .60942 Mdot
.3532 .40534 Mdot
.52648 .32706 Mdot
.60477 .20339 Mdot
.3991 .44003 Mdot
.65943 .44197 Mdot
.19474 .31579 Mdot
.68257 .49093 Mdot
.67797 .4267 Mdot
.65147 .66831 Mdot
.5162 .3367 Mdot
.30111 .81289 Mdot
.77657 .67495 Mdot
.5958 .66983 Mdot
.55355 .36143 Mdot
.65312 .46016 Mdot
.57251 .58297 Mdot
.66858 .50879 Mdot
.64958 .42161 Mdot
.57389 .57234 Mdot
.58355 .59664 Mdot
.57919 .24273 Mdot
.30182 .24785 Mdot
.33567 .59164 Mdot
.63775 .49002 Mdot
.52859 .5104 Mdot
.57925 .58775 Mdot
.57356 .63631 Mdot
.42599 .36073 Mdot
.3248 .60668 Mdot
.67822 .30723 Mdot
.5219 .63065 Mdot
.24119 .61512 Mdot
.52284 .56111 Mdot
.62954 .49451 Mdot
.56748 .35551 Mdot
.28521 .70769 Mdot
.51595 .3081 Mdot
.69025 .46925 Mdot
.33796 .6001 Mdot
.68923 .42056 Mdot
.32613 .66699 Mdot
.50487 .36418 Mdot
.64744 .4428 Mdot
.53643 .44981 Mdot
.52699 .35536 Mdot
.51017 .36278 Mdot
.65588 .64232 Mdot
.37583 .47742 Mdot
.34178 .551 Mdot
.52897 .37383 Mdot
.5511 .51833 Mdot
.54045 .36358 Mdot
.80205 .6073 Mdot
.5876 .66324 Mdot
.42585 .6334 Mdot
.35809 .50064 Mdot
.61453 .6768 Mdot
.51117 .36805 Mdot
.35765 .59452 Mdot
.52215 .64575 Mdot
.66537 .47855 Mdot
.32423 .56688 Mdot
.48812 .37258 Mdot
.3555 .44097 Mdot
.65432 .49295 Mdot
.49562 .32412 Mdot
.63681 .46545 Mdot
.48294 .54822 Mdot
.83393 .56043 Mdot
.18963 .48241 Mdot
.45605 .52889 Mdot
.52342 .61397 Mdot
.3041 .28975 Mdot
.49855 .6274 Mdot
.54585 .65388 Mdot
.38554 .4314 Mdot
.41566 .62309 Mdot
.66629 .45821 Mdot
.58543 .18693 Mdot
.50888 .33641 Mdot
.26741 .69761 Mdot
.63654 .53324 Mdot
.51935 .61241 Mdot
.6647 .50094 Mdot
.68469 .48889 Mdot
.68511 .60394 Mdot
.40233 .3905 Mdot
.50765 .65295 Mdot
.51122 .66798 Mdot
.56167 .56432 Mdot
.51014 .35338 Mdot
.23085 .54998 Mdot
.38205 .39246 Mdot
.84701 .51536 Mdot
.3594 .40091 Mdot
.40074 .59622 Mdot
.6761 .48083 Mdot
.31251 .58872 Mdot
.57522 .63519 Mdot
.61698 .44508 Mdot
.69292 .46346 Mdot
.317 .61132 Mdot
.36149 .57874 Mdot
.43968 .3523 Mdot
.52394 .33465 Mdot
.51787 .66076 Mdot
.59236 .63673 Mdot
.53693 .61648 Mdot
.53809 .65043 Mdot
.52831 .32184 Mdot
.52874 .65796 Mdot
.52199 .38576 Mdot
.47841 .57233 Mdot
.24999 .59996 Mdot
.51662 .46649 Mdot
.74444 .40563 Mdot
.67218 .47653 Mdot
.56247 .5062 Mdot
.49251 .6688 Mdot
.54342 .82316 Mdot
.75657 .36764 Mdot
.60315 .64895 Mdot
.3773 .4605 Mdot
.55983 .74167 Mdot
.38725 .40213 Mdot
.83974 .36601 Mdot
.42294 .2977 Mdot
.34043 .22256 Mdot
.59255 .62343 Mdot
.41642 .36574 Mdot
.58449 .52077 Mdot
.50371 .61826 Mdot
.43213 .31914 Mdot
.71074 .39033 Mdot
.50834 .23186 Mdot
.34742 .60485 Mdot
.5666 .60607 Mdot
.64507 .41469 Mdot
.58561 .64982 Mdot
.56967 .64199 Mdot
.51915 .63975 Mdot
.55554 .37849 Mdot
.50797 .64396 Mdot
.53689 .66144 Mdot
.24873 .53302 Mdot
.40775 .73606 Mdot
.40051 .44389 Mdot
.82355 .52586 Mdot
.31043 .58296 Mdot
.65469 .50077 Mdot
.47564 .19652 Mdot
.52886 .33764 Mdot
.68713 .59468 Mdot
.53679 .64664 Mdot
.56632 .24032 Mdot
.47984 .35512 Mdot
.34844 .59228 Mdot
.37935 .38827 Mdot
.39338 .19105 Mdot
.37811 .43351 Mdot
.54349 .44597 Mdot
.3721 .41639 Mdot
.48069 .63679 Mdot
.64528 .49688 Mdot
.51965 .65804 Mdot
.52381 .37034 Mdot
.39062 .42576 Mdot
.40268 .68184 Mdot
.55842 .63703 Mdot
.37025 .43446 Mdot
.52 .65873 Mdot
.44938 .63316 Mdot
.49448 .79526 Mdot
.33557 .41652 Mdot
.54295 .38913 Mdot
.52517 .361 Mdot
.3212 .60291 Mdot
.65837 .4974 Mdot
.68379 .44348 Mdot
.53069 .35031 Mdot
.64725 .76496 Mdot
.57519 .67369 Mdot
.58286 .59216 Mdot
.26971 .69159 Mdot
.5731 .66646 Mdot
.35457 .69819 Mdot
.54556 .449 Mdot
.66853 .48251 Mdot
.54073 .57723 Mdot
.5244 .62615 Mdot
.55819 .60356 Mdot
.46456 .57313 Mdot
.37591 .40465 Mdot
.59902 .63412 Mdot
.36148 .57271 Mdot
.43808 .45095 Mdot
.5635 .57727 Mdot
.53643 .56377 Mdot
.68254 .44162 Mdot
.36785 .80834 Mdot
.54043 .32942 Mdot
.34211 .43585 Mdot
.38514 .44769 Mdot
.27834 .36565 Mdot
.60233 .40821 Mdot
.53978 .45164 Mdot
.84433 .48544 Mdot
.32863 .33303 Mdot
.32948 .56797 Mdot
.36601 .48839 Mdot
.57862 .42291 Mdot
.35729 .45303 Mdot
.53627 .32211 Mdot
.59195 .65788 Mdot
.58344 .66646 Mdot
.51769 .84596 Mdot
.51686 .63004 Mdot
.3388 .58663 Mdot
.50868 .3784 Mdot
.66607 .47525 Mdot
.34703 .59312 Mdot
.55297 .33955 Mdot
.64456 .47876 Mdot
.60081 .64939 Mdot
.60075 .64707 Mdot
.67535 .4384 Mdot
.64752 .44009 Mdot
.58077 .63475 Mdot
.29545 .41612 Mdot
.65824 .43157 Mdot
.64143 .45267 Mdot
.37842 .39624 Mdot
.39388 .41622 Mdot
.4957 .6022 Mdot
.55239 .3587 Mdot
.53488 .66112 Mdot
.38119 .44002 Mdot
.32571 .60071 Mdot
.66876 .46106 Mdot
.52961 .60659 Mdot
.54874 .58683 Mdot
.33762 .57346 Mdot
.33999 .60381 Mdot
.35815 .58682 Mdot
.53283 .38487 Mdot
.54307 .61143 Mdot
.66428 .44969 Mdot
.5242 .33219 Mdot
.36164 .55387 Mdot
.32726 .61007 Mdot
.40991 .45012 Mdot
.56079 .67345 Mdot
.40761 .48417 Mdot
.21407 .73457 Mdot
.29437 .68551 Mdot
.41083 .41084 Mdot
.41459 .40623 Mdot
.40226 .71383 Mdot
.41201 .5526 Mdot
.53926 .34614 Mdot
.33696 .62171 Mdot
.30304 .63961 Mdot
.56656 .68737 Mdot
.60429 .60667 Mdot
.53403 .69635 Mdot
.35843 .57848 Mdot
.40555 .61981 Mdot
.6587 .5085 Mdot
.75683 .47957 Mdot
.31377 .57574 Mdot
.38885 .46598 Mdot
.3857 .47879 Mdot
.35766 .4015 Mdot
.59615 .65269 Mdot
.70331 .6143 Mdot
.58505 .48289 Mdot
.27743 .29909 Mdot
.52064 .37462 Mdot
.66597 .40874 Mdot
.77049 .34946 Mdot
.67156 .43905 Mdot
.35522 .38956 Mdot
.34268 .563 Mdot
.64187 .446 Mdot
.56275 .33772 Mdot
.53514 .37379 Mdot
.36815 .40011 Mdot
.35924 .40984 Mdot
.34383 .42513 Mdot
.66805 .42162 Mdot
.67718 .4811 Mdot
.55307 .61029 Mdot
.67183 .46562 Mdot
.47555 .85018 Mdot
.30343 .57309 Mdot
.39645 .37814 Mdot
.5473 .35506 Mdot
.63911 .47577 Mdot
.55596 .63615 Mdot
.42429 .57972 Mdot
.6998 .369 Mdot
.35321 .56127 Mdot
.45648 .7961 Mdot
.83877 .36984 Mdot
.51758 .66182 Mdot
.51329 .34935 Mdot
.42463 .81898 Mdot
.56276 .63326 Mdot
.35032 .42093 Mdot
.31381 .32379 Mdot
.32174 .40833 Mdot
.54329 .67492 Mdot
.54596 .69124 Mdot
.56986 .35376 Mdot
.83493 .47837 Mdot
.55257 .61537 Mdot
.67484 .31522 Mdot
.57026 .33287 Mdot
.3789 .3916 Mdot
.54897 .15674 Mdot
.22415 .43457 Mdot
.43884 .68822 Mdot
.37508 .39483 Mdot
.55136 .66266 Mdot
.38341 .40167 Mdot
.36107 .56532 Mdot
.34288 .40296 Mdot
.65468 .51078 Mdot
.40804 .42286 Mdot
.56588 .59153 Mdot
.65604 .45357 Mdot
.54197 .34979 Mdot
.29913 .73836 Mdot
.29903 .52471 Mdot
.37229 .41224 Mdot
.34018 .4358 Mdot
.53533 .58438 Mdot
.64989 .28098 Mdot
.59677 .55873 Mdot
.59303 .60902 Mdot
.50178 .34684 Mdot
.66592 .49806 Mdot
.56687 .36644 Mdot
.5167 .59366 Mdot
.21161 .42107 Mdot
.54563 .33603 Mdot
.55724 .22801 Mdot
.33887 .56617 Mdot
.46075 .4368 Mdot
.55167 .64055 Mdot
.55065 .37263 Mdot
.54341 .61278 Mdot
.65362 .50772 Mdot
.49398 .43206 Mdot
.48961 .24788 Mdot
.51844 .36469 Mdot
.58619 .211 Mdot
.39857 .57416 Mdot
.60334 .54965 Mdot
.5579 .34018 Mdot
.37805 .63621 Mdot
.36499 .46313 Mdot
.31624 .57824 Mdot
.36883 .58257 Mdot
.32755 .56288 Mdot
.60172 .56957 Mdot
.56966 .54387 Mdot
.36308 .55813 Mdot
.56106 .33141 Mdot
.35209 .6077 Mdot
.61444 .41506 Mdot
.56294 .19521 Mdot
.32438 .58316 Mdot
.568 .61527 Mdot
.53454 .54999 Mdot
.41253 .73213 Mdot
.45717 .344 Mdot
.36193 .21213 Mdot
.72444 .34013 Mdot
.56797 .66177 Mdot
.70716 .46137 Mdot
.63232 .47667 Mdot
.39745 .80524 Mdot
.33489 .69739 Mdot
.2668 .65638 Mdot
.67907 .4301 Mdot
.43149 .26514 Mdot
.6635 .49017 Mdot
.51954 .6203 Mdot
.57741 .58751 Mdot
.69162 .43735 Mdot
.23387 .57873 Mdot
.45867 .2754 Mdot
.65847 .22631 Mdot
.63737 .45909 Mdot
.56186 .34928 Mdot
.49853 .36417 Mdot
.50872 .36223 Mdot
.36664 .77118 Mdot
.68247 .48646 Mdot
.54075 .60516 Mdot
.3862 .44322 Mdot
.59596 .64477 Mdot
.52224 .35139 Mdot
.58313 .18563 Mdot
.68329 .46201 Mdot
.58624 .6196 Mdot
.52662 .73602 Mdot
.35433 .42531 Mdot
.33295 .57113 Mdot
.47283 .68186 Mdot
.27466 .66004 Mdot
.50656 .34856 Mdot
.69959 .45781 Mdot
.38388 .30636 Mdot
.54543 .21318 Mdot
.60694 .59605 Mdot
.49864 .64784 Mdot
.76298 .29358 Mdot
.27227 .63431 Mdot
.53371 .67875 Mdot
.35077 .45036 Mdot
.41094 .28202 Mdot
.54393 .5908 Mdot
.634 .48224 Mdot
.36333 .59696 Mdot
.34187 .56031 Mdot
.50522 .59208 Mdot
.43426 .54072 Mdot
.47106 .40195 Mdot
.52907 .63995 Mdot
.48455 .63338 Mdot
.37692 .39252 Mdot
.32342 .33355 Mdot
.26217 .66865 Mdot
.33932 .60105 Mdot
.52072 .65807 Mdot
.4155 .23076 Mdot
.6903 .44336 Mdot
.40971 .42523 Mdot
.51429 .37422 Mdot
.45841 .60268 Mdot
.37361 .38921 Mdot
.54093 .59095 Mdot
.52048 .64877 Mdot
.54443 .37929 Mdot
.62997 .49556 Mdot
.35741 .57464 Mdot
.38911 .44417 Mdot
.34687 .60139 Mdot
.67526 .4924 Mdot
.67685 .46801 Mdot
.56104 .73704 Mdot
.59966 .68378 Mdot
.38279 .41643 Mdot
.53362 .57512 Mdot
.35606 .35596 Mdot
.84498 .4499 Mdot
.49333 .33387 Mdot
.51992 .66881 Mdot
.62931 .50302 Mdot
.51488 .36032 Mdot
.57323 .58733 Mdot
.74267 .27555 Mdot
.57862 .58611 Mdot
.57761 .40562 Mdot
.18456 .48506 Mdot
.35417 .59537 Mdot
.75392 .47575 Mdot
.6744 .27449 Mdot
.57659 .66087 Mdot
.37444 .45522 Mdot
.50177 .67596 Mdot
.53828 .33855 Mdot
.67676 .47739 Mdot
.86138 .49339 Mdot
.53684 .36531 Mdot
.58771 .63862 Mdot
.34661 .59141 Mdot
.69104 .47862 Mdot
.35202 .62673 Mdot
.26508 .59634 Mdot
.58765 .54554 Mdot
.54028 .56887 Mdot
.53216 .65085 Mdot
.2304 .37155 Mdot
.34134 .43296 Mdot
.6455 .46312 Mdot
.51221 .3494 Mdot
.53158 .34818 Mdot
.36915 .40186 Mdot
.56303 .26272 Mdot
.46234 .43457 Mdot
.21013 .71089 Mdot
.38835 .41439 Mdot
.32397 .56194 Mdot
.6663 .29929 Mdot
.37976 .45618 Mdot
.36707 .43073 Mdot
.382 .39555 Mdot
.5466 .3033 Mdot
.64703 .47742 Mdot
.54447 .58629 Mdot
.63257 .48798 Mdot
.54879 .66358 Mdot
.57287 .41203 Mdot
.51906 .36748 Mdot
.68392 .47002 Mdot
.75222 .29325 Mdot
.71461 .69202 Mdot
.5664 .62521 Mdot
.77532 .35216 Mdot
.59236 .68313 Mdot
.37769 .69494 Mdot
.57097 .69955 Mdot
.36564 .41096 Mdot
.61896 .5701 Mdot
.56699 .56249 Mdot
.35271 .78739 Mdot
.54908 .35407 Mdot
.38072 .46509 Mdot
.57862 .68743 Mdot
.48598 .60272 Mdot
.68225 .42548 Mdot
.64094 .44866 Mdot
.36781 .56837 Mdot
.47587 .77693 Mdot
.54427 .3485 Mdot
.77667 .66163 Mdot
.57274 .6573 Mdot
.21337 .5258 Mdot
.72085 .51583 Mdot
.57608 .59005 Mdot
.69156 .28311 Mdot
.69919 .60616 Mdot
.54753 .64028 Mdot
.51269 .50287 Mdot
.54639 .37095 Mdot
.20484 .435 Mdot
.57285 .57774 Mdot
.35262 .42945 Mdot
.67215 .48716 Mdot
.6634 .50831 Mdot
.36407 .56089 Mdot
.58494 .81136 Mdot
.56286 .37138 Mdot
.68112 .47401 Mdot
.55942 .64294 Mdot
.51211 .34104 Mdot
.39641 .43205 Mdot
.51586 .61857 Mdot
.34232 .70673 Mdot
.66853 .46918 Mdot
.55534 .57053 Mdot
.65736 .32068 Mdot
.43865 .72432 Mdot
.19223 .37126 Mdot
.51092 .34861 Mdot
.32862 .60613 Mdot
.50265 .67524 Mdot
.63958 .75893 Mdot
.61285 .62007 Mdot
.42683 .62601 Mdot
.62178 .40597 Mdot
.33232 .60781 Mdot
.57427 .62317 Mdot
.54681 .59628 Mdot
.38097 .51796 Mdot
.33325 .60125 Mdot
.59426 .63181 Mdot
.49643 .56672 Mdot
.64532 .47397 Mdot
.34294 .38922 Mdot
.66102 .47482 Mdot
.56365 .61824 Mdot
.58708 .69694 Mdot
.66789 .43324 Mdot
.82221 .39211 Mdot
.34865 .54634 Mdot
.53885 .33018 Mdot
.61222 .63972 Mdot
.60447 .62313 Mdot
.17069 .57078 Mdot
.40392 .45106 Mdot
.35733 .27828 Mdot
.2391 .48274 Mdot
.38038 .24005 Mdot
.22338 .4365 Mdot
.26016 .26898 Mdot
.25362 .62323 Mdot
.50756 .63226 Mdot
.72703 .47215 Mdot
.57405 .47967 Mdot
.51594 .37314 Mdot
.80073 .56043 Mdot
.56875 .66255 Mdot
.56794 .64404 Mdot
.41068 .4221 Mdot
.54749 .23868 Mdot
.26466 .65625 Mdot
.42271 .56587 Mdot
.35602 .5735 Mdot
.63832 .48937 Mdot
.5516 .57871 Mdot
.52052 .4875 Mdot
.40095 .44442 Mdot
.21486 .53527 Mdot
.58397 .61878 Mdot
.53675 .8204 Mdot
.6748 .37032 Mdot
.51762 .33862 Mdot
.38299 .45079 Mdot
.27107 .6486 Mdot
.55704 .67408 Mdot
.51277 .37439 Mdot
.55351 .62261 Mdot
.30462 .42029 Mdot
.52326 .58449 Mdot
.32063 .58332 Mdot
.52202 .62486 Mdot
.40196 .59865 Mdot
.16857 .35806 Mdot
.30913 .61819 Mdot
.6765 .50262 Mdot
.37729 .37059 Mdot
.378 .40722 Mdot
.64609 .44227 Mdot
.37858 .41026 Mdot
.68797 .5674 Mdot
.76519 .55704 Mdot
.34796 .56626 Mdot
.49061 .59759 Mdot
.32743 .5845 Mdot
.40967 .43808 Mdot
.56083 .66853 Mdot
.8471 .41591 Mdot
.38678 .42431 Mdot
.18439 .53416 Mdot
.54038 .36062 Mdot
.39326 .46206 Mdot
.57447 .5802 Mdot
.38716 .31117 Mdot
.39888 .44253 Mdot
.49602 .2501 Mdot
.55746 .60428 Mdot
.67267 .47251 Mdot
.54244 .59449 Mdot
.60293 .66131 Mdot
.34071 .44611 Mdot
.54092 .66784 Mdot
.55318 .33993 Mdot
.6585 .42753 Mdot
.45732 .16422 Mdot
.70751 .39352 Mdot
.5892 .64893 Mdot
.56066 .64025 Mdot
.67841 .41677 Mdot
.60067 .62785 Mdot
.52829 .32197 Mdot
.52653 .90209 Mdot
.33802 .56641 Mdot
.34795 .45308 Mdot
.22263 .43462 Mdot
.60072 .65278 Mdot
.5251 .65187 Mdot
.72261 .25566 Mdot
.20928 .44933 Mdot
.5563 .33987 Mdot
.57619 .56333 Mdot
.39787 .43727 Mdot
.34454 .59026 Mdot
.55774 .32661 Mdot
.53586 .6402 Mdot
.57519 .63134 Mdot
.3248 .60372 Mdot
.64367 .60986 Mdot
.33519 .74517 Mdot
.5388 .38031 Mdot
.62339 .60106 Mdot
.40679 .37585 Mdot
.56449 .67787 Mdot
.38868 .78599 Mdot
.64675 .44502 Mdot
.50535 .34611 Mdot
.30608 .29771 Mdot
.53599 .67722 Mdot
.56607 .35766 Mdot
.54581 .34921 Mdot
.58062 .56569 Mdot
.62629 .50141 Mdot
.64941 .42515 Mdot
.63648 .46776 Mdot
.50839 .86144 Mdot
.42694 .69148 Mdot
.34389 .42509 Mdot
.54603 .37156 Mdot
.33467 .40878 Mdot
.29996 .58645 Mdot
.56145 .44516 Mdot
.33655 .42501 Mdot
.63199 .45574 Mdot
.37816 .3724 Mdot
.55148 .59737 Mdot
.54075 .34863 Mdot
.35284 .44748 Mdot
.59341 .67118 Mdot
.62675 .26559 Mdot
.48289 .3037 Mdot
.3383 .61167 Mdot
.36713 .59131 Mdot
.56663 .58003 Mdot
.39396 .3871 Mdot
.57921 .63617 Mdot
.50396 .33052 Mdot
.64848 .28426 Mdot
.61212 .62705 Mdot
.37221 .41022 Mdot
.70402 .43782 Mdot
.27375 .65542 Mdot
.60721 .56139 Mdot
.56872 .6162 Mdot
.54665 .66686 Mdot
.55301 .62266 Mdot
.50545 .22365 Mdot
.50768 .31841 Mdot
.73969 .40304 Mdot
.25052 .36563 Mdot
.68083 .45452 Mdot
.62571 .44871 Mdot
.29308 .69038 Mdot
.58367 .31404 Mdot
.55222 .36091 Mdot
.54325 .65275 Mdot
.61272 .36216 Mdot
.57433 .17972 Mdot
.80256 .33328 Mdot
.35191 .52662 Mdot
.40134 .45138 Mdot
.69924 .44889 Mdot
.39147 .45085 Mdot
.55465 .66445 Mdot
.50808 .68 Mdot
.24934 .27282 Mdot
.57734 .34608 Mdot
.34867 .5649 Mdot
.54589 .66335 Mdot
.43245 .69522 Mdot
.37882 .44246 Mdot
.35871 .46873 Mdot
.59648 .61928 Mdot
.62408 .48279 Mdot
.15593 .46961 Mdot
.5132 .34324 Mdot
.71854 .33277 Mdot
.59043 .51821 Mdot
.71978 .36088 Mdot
.51891 .34955 Mdot
.27771 .57104 Mdot
.40971 .41033 Mdot
.65887 .5658 Mdot
.68234 .45322 Mdot
.32468 .56717 Mdot
.49596 .65171 Mdot
.68373 .43958 Mdot
.3792 .39043 Mdot
.67551 .4749 Mdot
.5187 .63638 Mdot
.5518 .31851 Mdot
.37204 .44822 Mdot
.57614 .37141 Mdot
.62299 .49078 Mdot
.34075 .59945 Mdot
.42915 .51427 Mdot
.77413 .61683 Mdot
.69728 .60257 Mdot
.59884 .64013 Mdot
.53117 .48324 Mdot
.53917 .609 Mdot
.63428 .43133 Mdot
.55554 .63214 Mdot
.62625 .41272 Mdot
.37596 .45404 Mdot
.5818 .58404 Mdot
.53049 .64407 Mdot
.80631 .52452 Mdot
.58223 .61077 Mdot
.51176 .61233 Mdot
.54518 .64303 Mdot
.60866 .47942 Mdot
.50078 .58317 Mdot
.64903 .48395 Mdot
.2695 .55576 Mdot
.36517 .42801 Mdot
.36214 .59674 Mdot
.30774 .58301 Mdot
.42422 .64053 Mdot
.28094 .41915 Mdot
.54685 .24535 Mdot
.65802 .47131 Mdot
.55114 .34324 Mdot
.55323 .62933 Mdot
.26484 .29349 Mdot
.37572 .35142 Mdot
.40151 .42556 Mdot
.70748 .39306 Mdot
.62579 .63238 Mdot
.20843 .39254 Mdot
.54678 .57054 Mdot
.53484 .84426 Mdot
.60535 .67838 Mdot
.52136 .58841 Mdot
.33411 .42484 Mdot
.29866 .57657 Mdot
.59877 .6144 Mdot
.68442 .42728 Mdot
.31676 .58485 Mdot
.70908 .49915 Mdot
.42957 .45957 Mdot
.28217 .54705 Mdot
.79107 .52668 Mdot
.54648 .61438 Mdot
.37029 .44775 Mdot
.65301 .49358 Mdot
.26063 .66445 Mdot
.5252 .3312 Mdot
.57669 .38806 Mdot
.54024 .50633 Mdot
.79117 .35774 Mdot
.31164 .58266 Mdot
.65163 .63305 Mdot
.5638 .59039 Mdot
.33615 .50533 Mdot
.60762 .60985 Mdot
.57941 .18507 Mdot
.31357 .56885 Mdot
.6352 .43937 Mdot
.56083 .35006 Mdot
.63176 .48143 Mdot
.69464 .61901 Mdot
.33823 .47495 Mdot
.49046 .46835 Mdot
.37562 .43347 Mdot
.44711 .44677 Mdot
.65068 .45733 Mdot
.52358 .66204 Mdot
.20643 .70845 Mdot
.6429 .44973 Mdot
.69441 .4668 Mdot
.83747 .51524 Mdot
.84726 .4388 Mdot
.62525 .59112 Mdot
.67068 .43035 Mdot
.37223 .42886 Mdot
.33484 .59412 Mdot
.53387 .60455 Mdot
.55042 .60572 Mdot
.68136 .43854 Mdot
.34615 .45417 Mdot
.6658 .71304 Mdot
.3602 .41071 Mdot
.64334 .47663 Mdot
.35939 .42907 Mdot
.36881 .31694 Mdot
.36566 .45983 Mdot
.60406 .62345 Mdot
.55485 .63148 Mdot
.26242 .41223 Mdot
.67631 .46839 Mdot
.52849 .63756 Mdot
.53044 .59297 Mdot
.66263 .45168 Mdot
.28498 .61218 Mdot
.67043 .70001 Mdot
.57726 .66719 Mdot
.56756 .60282 Mdot
.33317 .60737 Mdot
.56709 .4553 Mdot
.55204 .77888 Mdot
.52223 .64533 Mdot
.32271 .55771 Mdot
.67695 .42506 Mdot
.58378 .62906 Mdot
.51507 .1844 Mdot
.41312 .28023 Mdot
.53024 .67383 Mdot
.36771 .46386 Mdot
.56401 .56332 Mdot
.18618 .39089 Mdot
.59352 .60895 Mdot
.65898 .45824 Mdot
.67623 .4882 Mdot
.78174 .65288 Mdot
.65546 .44408 Mdot
.39418 .41512 Mdot
.52492 .35358 Mdot
.58664 .19851 Mdot
.39623 .43311 Mdot
.61591 .61021 Mdot
.78504 .6662 Mdot
.51172 .63294 Mdot
.60473 .64915 Mdot
.16949 .46848 Mdot
.39351 .43719 Mdot
.66221 .50357 Mdot
.41028 .53525 Mdot
.56128 .70798 Mdot
.50561 .35052 Mdot
.49002 .63681 Mdot
.57616 .67747 Mdot
.18347 .49365 Mdot
.454 .24044 Mdot
.49813 .35055 Mdot
.50459 .64878 Mdot
.52253 .6465 Mdot
.34901 .47465 Mdot
.55633 .64019 Mdot
.32972 .59396 Mdot
.6752 .4945 Mdot
.37843 .4586 Mdot
.34155 .57361 Mdot
.57209 .66311 Mdot
.35835 .58115 Mdot
.351 .43999 Mdot
.50334 .36345 Mdot
.55481 .66883 Mdot
.31473 .60352 Mdot
.35723 .57813 Mdot
.53571 .61397 Mdot
.67495 .47993 Mdot
.60917 .6732 Mdot
.58829 .61803 Mdot
.52785 .6089 Mdot
.68459 .44558 Mdot
.72686 .21651 Mdot
.58703 .59523 Mdot
.39375 .55478 Mdot
.69209 .46845 Mdot
.41774 .48527 Mdot
.3851 .45924 Mdot
.58169 .67202 Mdot
.50062 .35751 Mdot
.54275 .37625 Mdot
.37258 .39188 Mdot
.69491 .47383 Mdot
.23926 .46653 Mdot
.69335 .42089 Mdot
.56321 .70509 Mdot
.52131 .67513 Mdot
.71636 .73066 Mdot
.33969 .21966 Mdot
.64578 .50196 Mdot
.41048 .47246 Mdot
.4302 .55582 Mdot
.55575 .36607 Mdot
.38554 .4681 Mdot
.70015 .4527 Mdot
.68683 .48227 Mdot
.66747 .48092 Mdot
.33513 .56223 Mdot
.26491 .41192 Mdot
.63814 .50542 Mdot
.62401 .4654 Mdot
.55597 .6016 Mdot
.52365 .64715 Mdot
.29313 .65877 Mdot
.37932 .74028 Mdot
.35889 .59465 Mdot
.36086 .40195 Mdot
.44266 .87304 Mdot
.50657 .32844 Mdot
.80809 .49976 Mdot
.60977 .63514 Mdot
.20244 .73695 Mdot
.56505 .57576 Mdot
.5572 .64458 Mdot
.66122 .42722 Mdot
.32451 .61017 Mdot
.32707 .57757 Mdot
.64374 .46117 Mdot
.62937 .43537 Mdot
.32877 .59326 Mdot
.73263 .32094 Mdot
.54038 .17848 Mdot
.32883 .46804 Mdot
.6695 .453 Mdot
.77506 .60179 Mdot
.52573 .38058 Mdot
.71731 .46826 Mdot
.51613 .31961 Mdot
.37265 .43879 Mdot
.39436 .38915 Mdot
.5094 .35535 Mdot
.55731 .60629 Mdot
.34169 .42522 Mdot
.50816 .64009 Mdot
.75075 .37321 Mdot
.7058 .65886 Mdot
.24006 .42386 Mdot
.52682 .56907 Mdot
.27539 .56399 Mdot
.53155 .27257 Mdot
.58258 .64669 Mdot
.42659 .21356 Mdot
.35378 .56799 Mdot
.69131 .50496 Mdot
.50622 .33499 Mdot
.173 .3969 Mdot
.54959 .67267 Mdot
.66198 .4598 Mdot
.55158 .3529 Mdot
.4519 .59869 Mdot
.66894 .30918 Mdot
.54764 .66526 Mdot
.23175 .74632 Mdot
.61469 .49988 Mdot
.37387 .45824 Mdot
.62111 .77794 Mdot
.63886 .49965 Mdot
.3518 .52985 Mdot
.27202 .35141 Mdot
.76879 .31763 Mdot
.65311 .50028 Mdot
.39275 .46784 Mdot
.6367 .47683 Mdot
.33809 .59958 Mdot
.70129 .47801 Mdot
.38052 .44731 Mdot
.58004 .61705 Mdot
.36876 .40508 Mdot
.36751 .57333 Mdot
.34464 .74741 Mdot
.49837 .35369 Mdot
.37926 .46503 Mdot
.52511 .36722 Mdot
.45274 .74703 Mdot
.2287 .38339 Mdot
.52909 .32693 Mdot
.59873 .75894 Mdot
.54281 .68222 Mdot
.6324 .49621 Mdot
.37511 .40001 Mdot
.29963 .33821 Mdot
.42543 .52551 Mdot
.67783 .44604 Mdot
.34856 .41495 Mdot
.55036 .49778 Mdot
.60738 .76544 Mdot
.56768 .55463 Mdot
.45971 .76369 Mdot
.66744 .44993 Mdot
.40276 .45847 Mdot
.2711 .69533 Mdot
.6299 .46147 Mdot
.38699 .4112 Mdot
.56316 .35294 Mdot
.52716 .34688 Mdot
.59677 .62907 Mdot
.58105 .36576 Mdot
.34874 .40618 Mdot
.51717 .27755 Mdot
.68714 .43583 Mdot
.45685 .57929 Mdot
.30413 .58816 Mdot
.36292 .41996 Mdot
.51656 .62933 Mdot
.66782 .51537 Mdot
.38044 .29914 Mdot
.67926 .71385 Mdot
.34119 .79979 Mdot
.36878 .40212 Mdot
.68558 .48161 Mdot
.66483 .46144 Mdot
.60966 .56725 Mdot
.45189 .53126 Mdot
.24205 .45881 Mdot
.46754 .69162 Mdot
.43313 .61428 Mdot
.34722 .38842 Mdot
.32453 .4127 Mdot
.5728 .69044 Mdot
.54554 .62112 Mdot
.55868 .3617 Mdot
.57708 .61411 Mdot
.65138 .43131 Mdot
.59866 .62732 Mdot
.51451 .35206 Mdot
.38024 .43198 Mdot
.56044 .66637 Mdot
.35448 .59624 Mdot
.50502 .37338 Mdot
.57051 .35091 Mdot
.36702 .41494 Mdot
.68537 .44162 Mdot
.30111 .6239 Mdot
.35892 .40961 Mdot
.54715 .61416 Mdot
.5917 .39383 Mdot
.52314 .61312 Mdot
.74734 .45606 Mdot
.62936 .46015 Mdot
.38546 .45397 Mdot
.68571 .43221 Mdot
.5333 .36998 Mdot
.25657 .36038 Mdot
.56105 .62326 Mdot
.39008 .41693 Mdot
.30592 .36759 Mdot
.6994 .51913 Mdot
.65298 .41389 Mdot
.53104 .26357 Mdot
.62843 .43988 Mdot
.388 .39169 Mdot
.82049 .55899 Mdot
.31525 .57656 Mdot
.40184 .42804 Mdot
.41575 .18516 Mdot
.38072 .41791 Mdot
.58221 .60435 Mdot
.56465 .58086 Mdot
.37429 .45956 Mdot
.32033 .60266 Mdot
.25307 .63981 Mdot
.35129 .37986 Mdot
.66049 .50275 Mdot
.78025 .38975 Mdot
.26137 .72872 Mdot
.58605 .35361 Mdot
.55881 .35423 Mdot
.57246 .70969 Mdot
.51897 .59585 Mdot
.52895 .31835 Mdot
.5734 .35653 Mdot
.35213 .55902 Mdot
.38593 .39856 Mdot
.60681 .47719 Mdot
.55267 .38409 Mdot
.52282 .71625 Mdot
.2788 .42704 Mdot
.5942 .55513 Mdot
.58695 .50868 Mdot
.6055 .60854 Mdot
.43351 .6319 Mdot
.51287 .35101 Mdot
.54513 .57808 Mdot
.58062 .55907 Mdot
.50164 .35225 Mdot
.33172 .59543 Mdot
.57324 .28482 Mdot
.36054 .43753 Mdot
.58686 .16279 Mdot
.52886 .58517 Mdot
.58366 .60303 Mdot
.51852 .3733 Mdot
.24686 .51163 Mdot
.68466 .46296 Mdot
.62836 .4687 Mdot
.34322 .43717 Mdot
.44061 .50972 Mdot
.58279 .66813 Mdot
.58702 .63346 Mdot
.36256 .44582 Mdot
.39018 .46374 Mdot
.47314 .30003 Mdot
.55349 .58843 Mdot
.54897 .35765 Mdot
.3951 .60785 Mdot
.51268 .35243 Mdot
.51986 .62052 Mdot
.57896 .5981 Mdot
.60377 .62408 Mdot
.51671 .63108 Mdot
.56899 .33995 Mdot
.54795 .57931 Mdot
.52811 .55507 Mdot
.68713 .46337 Mdot
.53874 .66108 Mdot
.43589 .62319 Mdot
.56936 .61081 Mdot
.33328 .59381 Mdot
.5949 .74812 Mdot
.55062 .67215 Mdot
.5878 .66344 Mdot
.34226 .37746 Mdot
.57089 .62745 Mdot
.50557 .32867 Mdot
.67654 .46051 Mdot
.54434 .37236 Mdot
.53283 .37845 Mdot
.36154 .39279 Mdot
.36275 .55837 Mdot
.59805 .65691 Mdot
.35193 .56195 Mdot
.61141 .60191 Mdot
.53284 .67665 Mdot
.26597 .36957 Mdot
.54719 .84182 Mdot
.35132 .76272 Mdot
.56023 .62182 Mdot
.39134 .43095 Mdot
.38573 .45761 Mdot
.67404 .52501 Mdot
.57577 .55446 Mdot
.54086 .32093 Mdot
.5476 .37398 Mdot
.35016 .70946 Mdot
.19185 .47087 Mdot
.33275 .59427 Mdot
.53864 .46825 Mdot
.50923 .65671 Mdot
.53161 .59455 Mdot
.51524 .61701 Mdot
.33529 .41061 Mdot
.41442 .57569 Mdot
.40087 .42924 Mdot
.69228 .37416 Mdot
.51325 .36208 Mdot
.54639 .67083 Mdot
.60334 .4218 Mdot
.63783 .45128 Mdot
.67632 .46132 Mdot
.56813 .34711 Mdot
.34544 .36654 Mdot
.29731 .6806 Mdot
.82604 .35901 Mdot
.61693 .51208 Mdot
.33983 .613 Mdot
.58352 .64998 Mdot
.3776 .4256 Mdot
.63492 .47001 Mdot
.35245 .60682 Mdot
.52264 .66377 Mdot
.26535 .41064 Mdot
.55755 .6175 Mdot
.57791 .47883 Mdot
.66688 .48876 Mdot
.56934 .18544 Mdot
.68244 .49499 Mdot
.50208 .37139 Mdot
.50883 .33458 Mdot
.57125 .58657 Mdot
.6724 .75959 Mdot
.63006 .48524 Mdot
.53573 .29658 Mdot
.32248 .56304 Mdot
.39799 .29756 Mdot
.33251 .59885 Mdot
.37584 .45645 Mdot
.31486 .58456 Mdot
.37934 .45008 Mdot
.34937 .72896 Mdot
.62352 .42024 Mdot
.34226 .56921 Mdot
.30171 .42663 Mdot
.57665 .55183 Mdot
.35356 .60232 Mdot
.54614 .70409 Mdot
.74933 .47169 Mdot
.35877 .44193 Mdot
.31083 .57755 Mdot
.52259 .65963 Mdot
.24501 .29473 Mdot
.55172 .33618 Mdot
.53513 .31993 Mdot
.55896 .70407 Mdot
.35414 .39078 Mdot
.68999 .43206 Mdot
.52435 .20794 Mdot
.48957 .35929 Mdot
.57937 .58989 Mdot
.59888 .61728 Mdot
.62489 .45298 Mdot
.66591 .39501 Mdot
.57331 .59075 Mdot
.54582 .73745 Mdot
.55657 .58567 Mdot
.56459 .34504 Mdot
.63318 .48371 Mdot
.66986 .46122 Mdot
.34635 .41777 Mdot
.65713 .43366 Mdot
.63989 .53998 Mdot
.61482 .38503 Mdot
.59659 .70437 Mdot
.53428 .36588 Mdot
.65886 .37494 Mdot
.69558 .37636 Mdot
.36082 .21468 Mdot
.62152 .4647 Mdot
.6011 .60003 Mdot
.69065 .44332 Mdot
.34259 .59228 Mdot
.67109 .47128 Mdot
.69833 .44658 Mdot
.58033 .6399 Mdot
.55142 .66233 Mdot
.38661 .43865 Mdot
.44285 .5378 Mdot
.68984 .45029 Mdot
.55883 .57724 Mdot
.51272 .60417 Mdot
.51081 .6232 Mdot
.49455 .41342 Mdot
.64064 .4972 Mdot
.82304 .45799 Mdot
.37326 .64938 Mdot
.68946 .4487 Mdot
.15445 .4442 Mdot
.32119 .33264 Mdot
.41446 .42404 Mdot
.55031 .38944 Mdot
.55169 .58811 Mdot
.39403 .45588 Mdot
.55497 .66482 Mdot
.586 .50848 Mdot
.57246 .63565 Mdot
.3262 .59355 Mdot
.50781 .62981 Mdot
.38496 .38877 Mdot
.36265 .40682 Mdot
.58939 .60034 Mdot
.56376 .66229 Mdot
.32865 .73188 Mdot
.61959 .45311 Mdot
.6805 .46833 Mdot
.23517 .48663 Mdot
.3516 .57721 Mdot
.50558 .34833 Mdot
.55058 .63898 Mdot
.35208 .3954 Mdot
.36497 .40494 Mdot
.63678 .49622 Mdot
.35098 .42353 Mdot
.51369 .34401 Mdot
.56048 .62736 Mdot
.5288 .31871 Mdot
.33725 .56118 Mdot
.63821 .49089 Mdot
.54312 .66337 Mdot
.55632 .60151 Mdot
.67585 .48867 Mdot
.58176 .68135 Mdot
.33223 .60673 Mdot
.38016 .41503 Mdot
.64972 .49705 Mdot
.52546 .35188 Mdot
.3789 .45428 Mdot
.53333 .59994 Mdot
.40477 .85167 Mdot
.57865 .60345 Mdot
.54679 .59002 Mdot
.40846 .18167 Mdot
.50669 .64365 Mdot
.37199 .40011 Mdot
.63257 .44551 Mdot
.51912 .57739 Mdot
.41734 .64804 Mdot
.77935 .27839 Mdot
.40051 .42266 Mdot
.58652 .64679 Mdot
.2826 .26233 Mdot
.59016 .63298 Mdot
.72768 .70763 Mdot
.32455 .47741 Mdot
.43657 .47929 Mdot
.60518 .66833 Mdot
.52882 .33829 Mdot
.38845 .43805 Mdot
.37277 .45395 Mdot
.79555 .43128 Mdot
.58295 .63755 Mdot
.56261 .47963 Mdot
.53181 .66562 Mdot
.52155 .3477 Mdot
.33817 .68745 Mdot
.36592 .40254 Mdot
.38157 .80267 Mdot
.54146 .60589 Mdot
.66107 .5077 Mdot
.38269 .37331 Mdot
.37412 .33227 Mdot
.52896 .6082 Mdot
.3589 .56704 Mdot
.53713 .38638 Mdot
.50842 .59767 Mdot
.5316 .36203 Mdot
.52561 .61213 Mdot
.56595 .73768 Mdot
.61814 .78831 Mdot
.67151 .48087 Mdot
.56144 .35279 Mdot
.5904 .38844 Mdot
.57007 .57054 Mdot
.65252 .49931 Mdot
.68191 .45157 Mdot
.35676 .56123 Mdot
.50769 .45603 Mdot
.64122 .31297 Mdot
.72683 .66579 Mdot
.7959 .41318 Mdot
.36891 .36854 Mdot
.47124 .25969 Mdot
.52854 .61803 Mdot
.21481 .51106 Mdot
.49986 .34126 Mdot
.58455 .60882 Mdot
.68487 .54218 Mdot
.63921 .46108 Mdot
.56742 .5983 Mdot
.32772 .58654 Mdot
.22677 .53154 Mdot
.21935 .53903 Mdot
.27605 .3287 Mdot
.37461 .43469 Mdot
.50484 .67695 Mdot
.60383 .70972 Mdot
.34649 .44843 Mdot
.56608 .68532 Mdot
.38235 .40865 Mdot
.75687 .33843 Mdot
.34436 .60962 Mdot
.65083 .50364 Mdot
.34325 .33415 Mdot
.58818 .66739 Mdot
.52002 .67526 Mdot
.37113 .58642 Mdot
.54178 .62398 Mdot
.57607 .81241 Mdot
.33612 .34951 Mdot
.34892 .44332 Mdot
.6685 .48087 Mdot
.59541 .65409 Mdot
.52214 .45726 Mdot
.58882 .62157 Mdot
.74998 .59245 Mdot
.59065 .65965 Mdot
.65349 .30876 Mdot
.67282 .48608 Mdot
.52924 .36407 Mdot
.57567 .56992 Mdot
.56735 .64042 Mdot
.38045 .62651 Mdot
.60116 .68388 Mdot
.55479 .57371 Mdot
.67967 .42032 Mdot
.63313 .4674 Mdot
.64919 .48248 Mdot
.40626 .41317 Mdot
.1873 .48294 Mdot
.54512 .3657 Mdot
.51711 .57007 Mdot
.5634 .38023 Mdot
.66059 .73943 Mdot
.34388 .61143 Mdot
.29175 .27925 Mdot
.53733 .64593 Mdot
.65183 .47409 Mdot
.42512 .23354 Mdot
.66924 .42177 Mdot
.51278 .48337 Mdot
.54371 .34845 Mdot
.64218 .45568 Mdot
.56141 .64466 Mdot
.42679 .54176 Mdot
.24478 .32304 Mdot
.53329 .37391 Mdot
.61326 .60141 Mdot
.40483 .44715 Mdot
.23847 .40907 Mdot
.38297 .83798 Mdot
.55438 .33746 Mdot
.58359 .39378 Mdot
.58384 .63917 Mdot
.63689 .4497 Mdot
.5233 .33901 Mdot
.54127 .3289 Mdot
.35002 .42487 Mdot
.54891 .66106 Mdot
.54547 .65862 Mdot
.39879 .39713 Mdot
.53744 .3761 Mdot
.58762 .69053 Mdot
.52535 .58128 Mdot
.23121 .28357 Mdot
.49623 .52943 Mdot
.61928 .162 Mdot
.63209 .54026 Mdot
.6672 .56871 Mdot
.54619 .20292 Mdot
.68906 .4781 Mdot
.55339 .67396 Mdot
.49419 .6191 Mdot
.3498 .40547 Mdot
.57026 .61949 Mdot
.38844 .48038 Mdot
.55529 .35529 Mdot
.1674 .42201 Mdot
.64189 .35639 Mdot
.752 .31662 Mdot
.57217 .62054 Mdot
.71299 .40412 Mdot
.34011 .58119 Mdot
.5092 .31515 Mdot
.64407 .48641 Mdot
.51721 .64439 Mdot
.32936 .73383 Mdot
.40143 .4292 Mdot
.6683 .43748 Mdot
.26553 .66661 Mdot
.27965 .56169 Mdot
.51949 .62302 Mdot
.40662 .43057 Mdot
.44036 .22045 Mdot
.48826 .68947 Mdot
.48962 .33526 Mdot
.32814 .5954 Mdot
.39023 .44222 Mdot
.5412 .37822 Mdot
.6107 .51478 Mdot
.64777 .44902 Mdot
.70358 .44816 Mdot
.40951 .78723 Mdot
.35383 .45854 Mdot
.33792 .57799 Mdot
.19914 .459 Mdot
.20919 .54216 Mdot
.32547 .592 Mdot
.3979 .39097 Mdot
.63382 .46874 Mdot
.64588 .46612 Mdot
.6763 .45975 Mdot
.35078 .77694 Mdot
.68598 .48789 Mdot
.8011 .47375 Mdot
.51097 .63821 Mdot
.57354 .72771 Mdot
.58803 .64176 Mdot
.53816 .31924 Mdot
.66491 .49456 Mdot
.42864 .50804 Mdot
.59549 .56808 Mdot
.24346 .34852 Mdot
.59185 .61611 Mdot
.52936 .3129 Mdot
.56071 .59428 Mdot
.79868 .53041 Mdot
.69285 .44904 Mdot
.56391 .62037 Mdot
.50252 .32599 Mdot
.35338 .585 Mdot
.68256 .41248 Mdot
.54672 .66654 Mdot
.55878 .24658 Mdot
.50676 .63857 Mdot
.72173 .29498 Mdot
.46713 .56036 Mdot
.33969 .61296 Mdot
.54101 .52833 Mdot
.37624 .4753 Mdot
.58446 .72161 Mdot
.52585 .70569 Mdot
.52577 .37043 Mdot
.35032 .31699 Mdot
.36652 .42804 Mdot
.3621 .52636 Mdot
.48685 .62297 Mdot
.36742 .58123 Mdot
.62483 .43961 Mdot
.54009 .31745 Mdot
.5524 .68726 Mdot
.59907 .56016 Mdot
.75931 .39646 Mdot
.48454 .61117 Mdot
.59987 .62652 Mdot
.36223 .60315 Mdot
.7833 .4488 Mdot
.56538 .60909 Mdot
.51975 .47767 Mdot
.69889 .47878 Mdot
.58738 .69355 Mdot
.8124 .49811 Mdot
.5659 .58008 Mdot
.6556 .43895 Mdot
.65742 .41041 Mdot
.59162 .3018 Mdot
.34266 .55621 Mdot
.58228 .67076 Mdot
.78491 .64772 Mdot
.54262 .6099 Mdot
.54618 .35904 Mdot
.52098 .59641 Mdot
.37962 .44483 Mdot
.3328 .75563 Mdot
.3431 .41657 Mdot
.58081 .6665 Mdot
.67464 .45629 Mdot
.51205 .36661 Mdot
.41658 .80264 Mdot
.2623 .44194 Mdot
.79264 .47015 Mdot
.74645 .28435 Mdot
.31394 .59098 Mdot
.364 .55635 Mdot
.54302 .31744 Mdot
.56347 .61878 Mdot
.83077 .5459 Mdot
.59771 .68965 Mdot
.56606 .60164 Mdot
.57241 .63735 Mdot
.22019 .40888 Mdot
.55493 .36448 Mdot
.35556 .4297 Mdot
.57548 .59384 Mdot
.55013 .5772 Mdot
.68955 .47548 Mdot
.35589 .5808 Mdot
.38557 .45878 Mdot
.34359 .5656 Mdot
.38495 .43033 Mdot
.15884 .4324 Mdot
.56461 .56453 Mdot
.35117 .58495 Mdot
.51481 .38434 Mdot
.68245 .44077 Mdot
.61094 .38363 Mdot
.37383 .45573 Mdot
.3578 .40256 Mdot
.59009 .60536 Mdot
.65357 .43887 Mdot
.674 .42795 Mdot
.34385 .59355 Mdot
.52205 .32943 Mdot
.55295 .67137 Mdot
.53038 .67661 Mdot
.74075 .42761 Mdot
.34873 .39434 Mdot
.57187 .49283 Mdot
.51913 .23806 Mdot
.56071 .61954 Mdot
.67753 .43126 Mdot
.5708 .65185 Mdot
.57004 .21123 Mdot
.64182 .44343 Mdot
.56808 .57879 Mdot
.21716 .60579 Mdot
.34858 .36392 Mdot
.61089 .31429 Mdot
.60177 .61496 Mdot
.65375 .21382 Mdot
.52559 .63466 Mdot
.18794 .32275 Mdot
.30517 .47173 Mdot
.56203 .67897 Mdot
.5372 .59777 Mdot
.68944 .68343 Mdot
.57406 .6648 Mdot
.38823 .3912 Mdot
.27581 .63658 Mdot
.69049 .43051 Mdot
.58516 .2501 Mdot
.62565 .71195 Mdot
.31258 .57042 Mdot
.34422 .43921 Mdot
.32756 .44005 Mdot
.32293 .58163 Mdot
.6668 .45345 Mdot
.55281 .62289 Mdot
.46492 .47895 Mdot
.33902 .3945 Mdot
.59484 .54061 Mdot
.54494 .35655 Mdot
.44129 .30259 Mdot
.33082 .36887 Mdot
.52467 .35716 Mdot
.53521 .65841 Mdot
.68088 .69247 Mdot
.4525 .78298 Mdot
.53007 .16914 Mdot
.53363 .37952 Mdot
.52674 .37352 Mdot
.33019 .76198 Mdot
.30187 .58686 Mdot
.76562 .38764 Mdot
.66016 .30706 Mdot
.50649 .35506 Mdot
.45929 .62927 Mdot
.39496 .40853 Mdot
.57453 .26212 Mdot
.69364 .50338 Mdot
.51589 .66255 Mdot
.56325 .64312 Mdot
.51693 .33121 Mdot
.70091 .5163 Mdot
.6084 .78363 Mdot
.52316 .36594 Mdot
.48924 .58758 Mdot
.47886 .42556 Mdot
.31475 .33338 Mdot
.3741 .39365 Mdot
.34784 .55646 Mdot
.38162 .56171 Mdot
.66836 .50287 Mdot
.35568 .55638 Mdot
.22317 .5247 Mdot
.54132 .63189 Mdot
.51645 .35871 Mdot
.38398 .29953 Mdot
.5296 .35074 Mdot
.32474 .57892 Mdot
.34596 .61324 Mdot
.68697 .4634 Mdot
.67785 .47035 Mdot
.67055 .5878 Mdot
.37188 .69977 Mdot
.5924 .62384 Mdot
.31236 .29329 Mdot
.68572 .43355 Mdot
.60685 .54154 Mdot
.36636 .56143 Mdot
.3536 .58084 Mdot
.40599 .6107 Mdot
.54385 .64767 Mdot
.75614 .6792 Mdot
.54723 .64462 Mdot
.34648 .68996 Mdot
.60898 .6213 Mdot
.35035 .42409 Mdot
.54097 .65198 Mdot
.30646 .63257 Mdot
.55922 .69021 Mdot
.5262 .58407 Mdot
.33971 .39976 Mdot
.50816 .59436 Mdot
.37749 .44475 Mdot
.5897 .65295 Mdot
.30604 .57587 Mdot
.33903 .40939 Mdot
.42137 .67688 Mdot
.40272 .58137 Mdot
.40463 .39709 Mdot
.36592 .571 Mdot
.30852 .57678 Mdot
.44612 .69414 Mdot
.64344 .48626 Mdot
.71103 .4679 Mdot
.56648 .61769 Mdot
.36673 .47414 Mdot
.55773 .36041 Mdot
.55068 .57998 Mdot
.50281 .61953 Mdot
.5962 .59995 Mdot
.66318 .50587 Mdot
.24286 .45035 Mdot
.34859 .59004 Mdot
.40347 .40699 Mdot
.28666 .61637 Mdot
.36551 .38813 Mdot
.55485 .55855 Mdot
.49497 .6437 Mdot
.6565 .59468 Mdot
.38412 .27008 Mdot
.32048 .76545 Mdot
.64992 .4461 Mdot
.37096 .46405 Mdot
.30442 .58356 Mdot
.61028 .55617 Mdot
.64604 .475 Mdot
.38014 .44697 Mdot
.55728 .61848 Mdot
.61265 .59764 Mdot
.67603 .38462 Mdot
.62252 .70117 Mdot
.42202 .61628 Mdot
.37471 .39087 Mdot
.3892 .46874 Mdot
.21133 .53314 Mdot
.28631 .57774 Mdot
.42626 .52002 Mdot
.58276 .62489 Mdot
.35692 .56561 Mdot
.63494 .46961 Mdot
.43261 .78737 Mdot
.51883 .32663 Mdot
.44654 .53503 Mdot
.5706 .62133 Mdot
.41983 .48854 Mdot
.67612 .45578 Mdot
.32968 .58916 Mdot
.51483 .33272 Mdot
.37718 .58175 Mdot
.33954 .43507 Mdot
.80366 .35895 Mdot
.54225 .61475 Mdot
.59414 .61349 Mdot
.49817 .36311 Mdot
.63802 .46696 Mdot
.37396 .57976 Mdot
.75271 .37052 Mdot
.35682 .44822 Mdot
.82798 .56607 Mdot
.65712 .43155 Mdot
.78874 .54319 Mdot
.4007 .40488 Mdot
.56847 .34837 Mdot
.43996 .6992 Mdot
.51537 .35061 Mdot
.58744 .66027 Mdot
.66163 .4681 Mdot
.55532 .34383 Mdot
.44724 .54894 Mdot
.26966 .27642 Mdot
.78206 .58261 Mdot
.54624 .63396 Mdot
.21108 .334 Mdot
.66855 .26117 Mdot
.61603 .46356 Mdot
.50049 .35944 Mdot
.58928 .61378 Mdot
.55685 .68327 Mdot
.54481 .60683 Mdot
.5468 .34272 Mdot
.28666 .35321 Mdot
.35927 .44465 Mdot
.58608 .64056 Mdot
.35135 .55927 Mdot
.37131 .4406 Mdot
.34668 .33381 Mdot
.36602 .39955 Mdot
.61875 .47068 Mdot
.51968 .59794 Mdot
.55065 .31177 Mdot
.15292 .38792 Mdot
.5411 .3734 Mdot
.39907 .39013 Mdot
.53337 .58542 Mdot
.37883 .29259 Mdot
.64854 .48055 Mdot
.35206 .44253 Mdot
.58426 .60392 Mdot
.33731 .33717 Mdot
.34834 .75387 Mdot
.3663 .40013 Mdot
.64126 .47431 Mdot
.48775 .18597 Mdot
.57434 .61582 Mdot
.5286 .62877 Mdot
.64554 .45867 Mdot
.63008 .72816 Mdot
.27017 .68908 Mdot
.56681 .65826 Mdot
.52743 .36322 Mdot
.85349 .48685 Mdot
.53511 .57109 Mdot
.35259 .65737 Mdot
.3881 .44028 Mdot
.57519 .27448 Mdot
.55874 .49725 Mdot
.61272 .55777 Mdot
.74827 .3722 Mdot
.55764 .41965 Mdot
.20592 .37434 Mdot
.39307 .47755 Mdot
.30751 .53024 Mdot
.19071 .38508 Mdot
.518 .3163 Mdot
.67118 .4015 Mdot
.71874 .3272 Mdot
.4395 .83012 Mdot
.48917 .19346 Mdot
.25977 .53248 Mdot
.32485 .7311 Mdot
.46588 .45797 Mdot
.38542 .42436 Mdot
.37054 .60907 Mdot
.5515 .66696 Mdot
.66494 .25749 Mdot
.77193 .65247 Mdot
.67981 .76406 Mdot
.21439 .32731 Mdot
.72254 .70566 Mdot
.26748 .29074 Mdot
.37615 .20459 Mdot
.65452 .56113 Mdot
.39971 .25736 Mdot
.82936 .57851 Mdot
.21554 .58841 Mdot
.80708 .4136 Mdot
.5882 .71245 Mdot
.5209 .48711 Mdot
.72791 .28563 Mdot
.7876 .50164 Mdot
.61454 .76952 Mdot
.34501 .42154 Mdot
.62915 .45108 Mdot
.70574 .31558 Mdot
.63647 .42634 Mdot
.58707 .33147 Mdot
.49641 .17891 Mdot
.28668 .25416 Mdot
.8015 .52592 Mdot
.61295 .18543 Mdot
.70034 .53784 Mdot
.68295 .80714 Mdot
.34569 .3844 Mdot
.64255 .50369 Mdot
.33776 .53795 Mdot
.20677 .5277 Mdot
.70345 .36586 Mdot
.70619 .30419 Mdot
.25695 .38299 Mdot
.41969 .72387 Mdot
.66341 .45903 Mdot
.52596 .53053 Mdot
.5462 .28467 Mdot
.64931 .35974 Mdot
.27526 .64004 Mdot
.4144 .19724 Mdot
.46807 .48969 Mdot
.5695 .2502 Mdot
.45522 .28168 Mdot
.37996 .83264 Mdot
.38735 .63996 Mdot
.63048 .55787 Mdot
.59442 .39714 Mdot
.55706 .20295 Mdot
.48151 .83015 Mdot
.37583 .71644 Mdot
.2076 .53257 Mdot
.17444 .52822 Mdot
.62868 .22471 Mdot
.18453 .6205 Mdot
.7075 .47025 Mdot
.6 .62191 Mdot
.65277 .68139 Mdot
.79357 .63233 Mdot
.3285 .6164 Mdot
.28385 .32837 Mdot
.31789 .56911 Mdot
.63356 .51425 Mdot
.31755 .73697 Mdot
.80526 .48684 Mdot
.7941 .63955 Mdot
.36507 .55116 Mdot
.52881 .56858 Mdot
.89332 .46185 Mdot
.22407 .35705 Mdot
.6141 .33762 Mdot
.21857 .29398 Mdot
.41166 .50818 Mdot
.45398 .5928 Mdot
.55444 .3445 Mdot
.18769 .37554 Mdot
.65144 .46657 Mdot
.15463 .56726 Mdot
.18205 .34413 Mdot
.56288 .77056 Mdot
.63857 .13122 Mdot
.20842 .48349 Mdot
.43055 .48592 Mdot
.54603 .41257 Mdot
.40229 .66338 Mdot
.57258 .7983 Mdot
.55161 .75613 Mdot
.4022 .28248 Mdot
.73021 .26646 Mdot
.20109 .36569 Mdot
.81053 .5991 Mdot
.80681 .37625 Mdot
.46215 .83714 Mdot
.54098 .45428 Mdot
.71138 .48663 Mdot
.31848 .40705 Mdot
.39045 .21993 Mdot
.1613 .47457 Mdot
.37226 .64669 Mdot
.79659 .29393 Mdot
.28935 .60507 Mdot
.2921 .46783 Mdot
.4996 .16641 Mdot
.43221 .72342 Mdot
.50786 .53407 Mdot
.25786 .62202 Mdot
.59706 .5447 Mdot
.25383 .59096 Mdot
.3119 .28059 Mdot
.59969 .37363 Mdot
.22012 .58727 Mdot
.4835 .20966 Mdot
.75635 .39587 Mdot
.71182 .64918 Mdot
.20194 .53404 Mdot
.67025 .41936 Mdot
.39957 .71873 Mdot
.50401 .53191 Mdot
.27654 .25807 Mdot
.58138 .39443 Mdot
.32721 .21087 Mdot
.2767 .69076 Mdot
.59437 .58373 Mdot
.5442 .71108 Mdot
.50267 .56736 Mdot
.38349 .69879 Mdot
.52189 .58163 Mdot
.70398 .38236 Mdot
.33805 .21723 Mdot
.71814 .51738 Mdot
.56717 .28617 Mdot
.34224 .32164 Mdot
.51681 .16363 Mdot
.66865 .63358 Mdot
.28869 .56888 Mdot
.30762 .67067 Mdot
.43161 .84323 Mdot
.36319 .42914 Mdot
.81578 .57869 Mdot
.48997 .33274 Mdot
.37552 .76663 Mdot
.72757 .6697 Mdot
.55201 .78738 Mdot
.33961 .21609 Mdot
.26751 .5548 Mdot
.30275 .71489 Mdot
.46454 .75045 Mdot
.84054 .51521 Mdot
.31971 .32135 Mdot
.4909 .63895 Mdot
.64175 .2572 Mdot
.31883 .60197 Mdot
.68889 .61623 Mdot
.83412 .46579 Mdot
.26304 .49506 Mdot
.5369 .69564 Mdot
.50737 .79178 Mdot
.41208 .37553 Mdot
.4287 .54025 Mdot
.25121 .73184 Mdot
.58308 .55293 Mdot
.19751 .46862 Mdot
.65019 .2355 Mdot
.38461 .66717 Mdot
.54756 .18629 Mdot
.53329 .21769 Mdot
.17493 .58897 Mdot
.20457 .3202 Mdot
.25615 .44645 Mdot
.18737 .40228 Mdot
.2568 .26725 Mdot
.18993 .61392 Mdot
.50945 .69781 Mdot
.49621 .36277 Mdot
.34473 .83429 Mdot
.38607 .39299 Mdot
.20845 .42287 Mdot
.79609 .41432 Mdot
.35869 .34094 Mdot
.60625 .4708 Mdot
.62747 .67412 Mdot
.47046 .46347 Mdot
.61595 .47428 Mdot
.5126 .59049 Mdot
.25849 .72035 Mdot
.18252 .57495 Mdot
.22333 .67551 Mdot
.65266 .22487 Mdot
.17543 .41827 Mdot
.45341 .43771 Mdot
.79498 .49617 Mdot
.6762 .52328 Mdot
.51541 .65218 Mdot
.37824 .53189 Mdot
.20922 .47981 Mdot
.50231 .79475 Mdot
.69048 .34821 Mdot
.62168 .44632 Mdot
.29527 .30801 Mdot
.70574 .8245 Mdot
.6884 .55864 Mdot
.81679 .49059 Mdot
.21635 .53853 Mdot
.37045 .69031 Mdot
.37026 .23663 Mdot
.55741 .77851 Mdot
.39766 .18937 Mdot
.61485 .48493 Mdot
.80021 .40652 Mdot
.27287 .52149 Mdot
.45577 .65908 Mdot
.24454 .44133 Mdot
.29938 .25444 Mdot
.4724 .38824 Mdot
.46324 .80418 Mdot
.66842 .30002 Mdot
.58097 .777 Mdot
.32781 .48671 Mdot
.449 .30144 Mdot
.83285 .47385 Mdot
.4752 .24527 Mdot
.34958 .67593 Mdot
.48673 .43583 Mdot
.57183 .52498 Mdot
.55661 .41877 Mdot
.35579 .67227 Mdot
.44542 .64851 Mdot
.18443 .4345 Mdot
.14013 .3628 Mdot
.33055 .78515 Mdot
.58552 .16612 Mdot
.33495 .26612 Mdot
.54285 .69535 Mdot
.45657 .1593 Mdot
.20137 .65729 Mdot
.17217 .34587 Mdot
.44893 .34225 Mdot
.38934 .48173 Mdot
.57349 .36938 Mdot
.27152 .71979 Mdot
.28287 .38218 Mdot
.44294 .17445 Mdot
.25213 .61351 Mdot
.57012 .37932 Mdot
.55796 .83986 Mdot
.18432 .54779 Mdot
.74766 .65039 Mdot
.62776 .69089 Mdot
.59601 .67495 Mdot
.80022 .56361 Mdot
.62932 .43672 Mdot
.4768 .26062 Mdot
.37997 .70991 Mdot
.36238 .41569 Mdot
.38073 .53681 Mdot
.69122 .29027 Mdot
.50766 .63165 Mdot
.583 .42186 Mdot
.62327 .46922 Mdot
.39047 .26637 Mdot
.63084 .37653 Mdot
.15515 .47088 Mdot
.22364 .44573 Mdot
.61364 .63862 Mdot
.38188 .66295 Mdot
.23892 .44552 Mdot
.26961 .6945 Mdot
.56528 .3292 Mdot
.2313 .30832 Mdot
.49389 .50369 Mdot
.39655 .71731 Mdot
.79009 .60287 Mdot
.74644 .46251 Mdot
.5012 .65115 Mdot
.48465 .23044 Mdot
.74359 .58151 Mdot
.43762 .54234 Mdot
.68755 .50997 Mdot
.72204 .45898 Mdot
.4773 .14895 Mdot
.22915 .53784 Mdot
.44292 .28973 Mdot
.25208 .29145 Mdot
.53549 .3429 Mdot
.6869 .4388 Mdot
.39219 .58855 Mdot
.75408 .35908 Mdot
.76355 .54971 Mdot
.34896 .75476 Mdot
.34873 .34769 Mdot
.27326 .4879 Mdot
.25727 .29269 Mdot
.22593 .32061 Mdot
.73146 .7323 Mdot
.64797 .4145 Mdot
.6592 .54433 Mdot
.77057 .3762 Mdot
.63464 .43665 Mdot
.74667 .40019 Mdot
.72172 .39197 Mdot
.16666 .45777 Mdot
.58447 .33995 Mdot
.71342 .24996 Mdot
.42862 .63996 Mdot
.27819 .35237 Mdot
.41122 .80233 Mdot
.8318 .47987 Mdot
.27572 .28141 Mdot
.47102 .66056 Mdot
.69932 .69515 Mdot
.59501 .70764 Mdot
.59714 .4815 Mdot
.44764 .86213 Mdot
.3969 .58931 Mdot
.79053 .54396 Mdot
.4877 .20624 Mdot
.54775 .61963 Mdot
.33534 .79402 Mdot
.73652 .33461 Mdot
.3298 .76449 Mdot
.55332 .38532 Mdot
.52549 .65142 Mdot
.54746 .6903 Mdot
.32664 .65934 Mdot
.59437 .30272 Mdot
.18512 .46177 Mdot
.84142 .45424 Mdot
.44392 .21403 Mdot
.771 .65318 Mdot
.20283 .4593 Mdot
.43942 .18236 Mdot
.65626 .25105 Mdot
.50712 .46601 Mdot
.21298 .47378 Mdot
.4379 .71612 Mdot
.61423 .18905 Mdot
.42276 .58558 Mdot
.47594 .3471 Mdot
.72306 .37456 Mdot
.52705 .23423 Mdot
.42819 .79364 Mdot
.52129 .62825 Mdot
.26546 .6664 Mdot
.39244 .20035 Mdot
.7483 .70428 Mdot
.54318 .82109 Mdot
.31224 .77368 Mdot
.74535 .61304 Mdot
.52726 .22721 Mdot
.6608 .25966 Mdot
.85146 .55637 Mdot
.49856 .50574 Mdot
.25891 .32927 Mdot
.44569 .72916 Mdot
.25559 .29161 Mdot
.4947 .35332 Mdot
.67891 .31785 Mdot
.33741 .32358 Mdot
.18287 .42072 Mdot
.67316 .65934 Mdot
.32506 .23683 Mdot
.42873 .49579 Mdot
.16657 .57261 Mdot
.45396 .24314 Mdot
.46436 .44605 Mdot
.36112 .45979 Mdot
.25971 .55991 Mdot
.30517 .27848 Mdot
.36501 .26804 Mdot
.82801 .48305 Mdot
.40469 .45771 Mdot
.38365 .59701 Mdot
.75268 .65905 Mdot
.44354 .75617 Mdot
.49827 .22354 Mdot
.38224 .66314 Mdot
.31403 .23629 Mdot
.29254 .63913 Mdot
.27342 .67233 Mdot
.21398 .44296 Mdot
.79058 .32309 Mdot
.61189 .33194 Mdot
.23244 .56047 Mdot
.72462 .31955 Mdot
.29322 .45659 Mdot
.45884 .61525 Mdot
.06752 .54079 Mdot
.78614 .34128 Mdot
.42413 .24978 Mdot
.16164 .47464 Mdot
.56915 .20455 Mdot
.39017 .26927 Mdot
.56388 .7985 Mdot
.49937 .52653 Mdot
.32848 .71663 Mdot
.5716 .63702 Mdot
.23604 .70542 Mdot
.41915 .74155 Mdot
.15975 .50473 Mdot
.47166 .15748 Mdot
.7956 .5749 Mdot
.50885 .61714 Mdot
.40555 .41834 Mdot
.59192 .34942 Mdot
.42322 .76288 Mdot
.66121 .70679 Mdot
.48586 .55698 Mdot
.32158 .35115 Mdot
.34785 .45087 Mdot
.23523 .46794 Mdot
.62067 .5147 Mdot
.28039 .37581 Mdot
.51754 .2359 Mdot
.35956 .36346 Mdot
.46746 .4999 Mdot
.36305 .67664 Mdot
.55584 .5012 Mdot
.75155 .64326 Mdot
.53879 .7881 Mdot
.55136 .44012 Mdot
.36532 .39837 Mdot
.73244 .65357 Mdot
.74446 .29519 Mdot
.44716 .22049 Mdot
.17117 .5208 Mdot
.26407 .59222 Mdot
.6751 .71952 Mdot
.34741 .67026 Mdot
.58398 .79552 Mdot
.65757 .75425 Mdot
.33935 .29469 Mdot
.60251 .51304 Mdot
.61741 .75977 Mdot
.65386 .27075 Mdot
.16788 .41715 Mdot
.80576 .41231 Mdot
.78057 .38342 Mdot
.30531 .42957 Mdot
.77786 .50682 Mdot
.77943 .62007 Mdot
.42546 .67271 Mdot
.42771 .52627 Mdot
.64888 .82484 Mdot
.707 .48684 Mdot
.51147 .88808 Mdot
.56273 .34349 Mdot
.47497 .84479 Mdot
.44741 .71937 Mdot
.4885 .43137 Mdot
.40408 .52341 Mdot
.49207 .23404 Mdot
.65742 .31162 Mdot
.67284 .24133 Mdot
.65751 .76749 Mdot
.35264 .38873 Mdot
.8444 .45076 Mdot
.79583 .32462 Mdot
.70485 .675 Mdot
.54528 .56627 Mdot
.78347 .32999 Mdot
.40166 .47225 Mdot
.50391 .79563 Mdot
.54869 .18358 Mdot
.37625 .25379 Mdot
.50709 .70077 Mdot
.37419 .69566 Mdot
.26092 .32401 Mdot
.2282 .30148 Mdot
.56943 .82583 Mdot
.31339 .27999 Mdot
.49593 .35868 Mdot
.45501 .4489 Mdot
.33129 .24034 Mdot
.45049 .58469 Mdot
.58655 .26218 Mdot
.48642 .54857 Mdot
.58845 .87115 Mdot
.21038 .4071 Mdot
.18613 .45913 Mdot
.46719 .56288 Mdot
.69287 .47936 Mdot
.58496 .30081 Mdot
.51181 .53129 Mdot
.39345 .24673 Mdot
.73084 .29744 Mdot
.50911 .53065 Mdot
.81376 .65063 Mdot
.74787 .47261 Mdot
.44156 .41531 Mdot
.76901 .64533 Mdot
.71346 .51747 Mdot
.55181 .38637 Mdot
.28002 .66045 Mdot
.47301 .2033 Mdot
.50066 .37223 Mdot
.49244 .22333 Mdot
.56239 .25227 Mdot
.76265 .45257 Mdot
.76775 .5586 Mdot
.41379 .22319 Mdot
.67543 .68632 Mdot
.65041 .39903 Mdot
.42436 .78399 Mdot
.40663 .39384 Mdot
.47384 .19754 Mdot
.35975 .45477 Mdot
.61099 .54465 Mdot
.44721 .53929 Mdot
.57354 .74464 Mdot
.30683 .7569 Mdot
.31376 .59213 Mdot
.63175 .48464 Mdot
.49776 .85402 Mdot
.64243 .43464 Mdot
.24705 .7077 Mdot
.5556 .78391 Mdot
.79177 .60074 Mdot
.25872 .45517 Mdot
.24942 .49894 Mdot
.74532 .74553 Mdot
.58421 .41247 Mdot
.31865 .39182 Mdot
.61613 .40149 Mdot
.64039 .49953 Mdot
.22322 .43603 Mdot
.34231 .39998 Mdot
.5011 .51686 Mdot
.45875 .37927 Mdot
.71547 .416 Mdot
.61435 .43208 Mdot
.47917 .5144 Mdot
.33578 .70761 Mdot
.17216 .44664 Mdot
.38775 .41557 Mdot
.54514 .86892 Mdot
.50178 .63265 Mdot
.70788 .64246 Mdot
.39724 .18738 Mdot
.56957 .83477 Mdot
.32169 .41855 Mdot
.80114 .32604 Mdot
.61073 .61776 Mdot
.38286 .2327 Mdot
.65611 .46078 Mdot
.78794 .39198 Mdot
.31224 .582 Mdot
.39059 .66583 Mdot
.57173 .36688 Mdot
.45951 .80488 Mdot
.38954 .35832 Mdot
.69956 .44112 Mdot
.33763 .27382 Mdot
.66632 .54182 Mdot
.63664 .28598 Mdot
.24037 .48931 Mdot
.70868 .67634 Mdot
.76914 .54714 Mdot
.61953 .42621 Mdot
.18795 .44361 Mdot
.79205 .38997 Mdot
.1505 .43345 Mdot
.53464 .54854 Mdot
.28889 .54947 Mdot
.73062 .3854 Mdot
.46362 .2241 Mdot
.59214 .48642 Mdot
.36829 .19921 Mdot
.38789 .721 Mdot
.73036 .42162 Mdot
.34937 .68722 Mdot
.62322 .62577 Mdot
.48805 .47424 Mdot
.47669 .2718 Mdot
.67402 .77046 Mdot
.57901 .47685 Mdot
.50024 .83241 Mdot
.59665 .50469 Mdot
.1921 .48742 Mdot
.62037 .5225 Mdot
.3406 .45173 Mdot
.78309 .51381 Mdot
.58713 .39085 Mdot
.1756 .40137 Mdot
.37786 .19496 Mdot
.5653 .3238 Mdot
.24497 .40498 Mdot
.54654 .19794 Mdot
.61813 .58924 Mdot
.43955 .46225 Mdot
.59963 .6331 Mdot
.6681 .52983 Mdot
.57747 .83851 Mdot
.42196 .23403 Mdot
.4945 .66093 Mdot
.20272 .37619 Mdot
.19504 .36593 Mdot
.16553 .54854 Mdot
.83362 .54713 Mdot
.68414 .48429 Mdot
.20745 .64081 Mdot
.48682 .55879 Mdot
.24744 .27739 Mdot
.34444 .28778 Mdot
.4603 .1495 Mdot
.69598 .69193 Mdot
.51038 .21068 Mdot
.59562 .77327 Mdot
.62511 .30088 Mdot
.61324 .22114 Mdot
.46825 .40735 Mdot
.42941 .2904 Mdot
.5884 .20706 Mdot
.86686 .57224 Mdot
.62718 .58298 Mdot
.56376 .24826 Mdot
.68315 .29916 Mdot
.46462 .19835 Mdot
.31906 .49069 Mdot
.52122 .59642 Mdot
.3731 .3065 Mdot
.37214 .7831 Mdot
.36728 .66473 Mdot
.37573 .60734 Mdot
.31651 .48711 Mdot
.37974 .7527 Mdot
.34516 .69723 Mdot
.80733 .4123 Mdot
.70577 .68456 Mdot
.53608 .49572 Mdot
.57165 .57094 Mdot
.60939 .49103 Mdot
.34195 .55309 Mdot
.44886 .3842 Mdot
.59373 .64386 Mdot
.35993 .47183 Mdot
.63716 .29239 Mdot
.29335 .75588 Mdot
.59709 .34121 Mdot
.72714 .31295 Mdot
.66814 .51391 Mdot
.55492 .25867 Mdot
.6008 .42751 Mdot
.39007 .80658 Mdot
.30724 .51607 Mdot
.37263 .64644 Mdot
.22868 .34241 Mdot
.21881 .58412 Mdot
.75543 .4389 Mdot
.21314 .60661 Mdot
.49908 .34574 Mdot
.47952 .63514 Mdot
.70168 .32412 Mdot
.22842 .47905 Mdot
.67075 .51924 Mdot
.50721 .21191 Mdot
.32151 .38537 Mdot
.22629 .56539 Mdot
.64231 .22935 Mdot
.70635 .51659 Mdot
.73097 .68256 Mdot
.21843 .3302 Mdot
.39989 .42115 Mdot
.78425 .36746 Mdot
.58566 .25541 Mdot
.29662 .53091 Mdot
.18354 .49312 Mdot
.1592 .4516 Mdot
.4222 .51298 Mdot
.41947 .70692 Mdot
.53453 .61424 Mdot
.82276 .45823 Mdot
.44392 .2315 Mdot
.5938 .72385 Mdot
.43972 .33825 Mdot
.67135 .43176 Mdot
.46822 .29712 Mdot
.52682 .48845 Mdot
.35021 .73259 Mdot
.63056 .43234 Mdot
.77079 .65919 Mdot
.30831 .57073 Mdot
.39562 .50637 Mdot
.51693 .5833 Mdot
.4105 .68943 Mdot
.80667 .62123 Mdot
.52644 .55875 Mdot
.3374 .25583 Mdot
.72096 .67067 Mdot
.75818 .37396 Mdot
.39826 .23284 Mdot
.33736 .29907 Mdot
.65124 .31054 Mdot
.78331 .5394 Mdot
.43483 .36969 Mdot
.59783 .60375 Mdot
.33684 .44785 Mdot
.66632 .4238 Mdot
.5107 .17984 Mdot
.74803 .60088 Mdot
.42192 .68087 Mdot
.50887 .42814 Mdot
.61967 .54589 Mdot
.52252 .41922 Mdot
.43811 .16348 Mdot
.62587 .30262 Mdot
.37846 .71142 Mdot
.58708 .34584 Mdot
.4442 .71484 Mdot
.54868 .79206 Mdot
.17896 .3596 Mdot
.58028 .78659 Mdot
.45665 .48994 Mdot
.5111 .83457 Mdot
.48265 .2431 Mdot
.5554 .18675 Mdot
.36421 .70856 Mdot
.38916 .51354 Mdot
.32003 .61878 Mdot
.68002 .38768 Mdot
.53211 .44893 Mdot
.34811 .62682 Mdot
.51785 .51089 Mdot
.41643 .34427 Mdot
.51966 .28423 Mdot
.626 .67602 Mdot
.2142 .4172 Mdot
.22417 .33676 Mdot
.79139 .40144 Mdot
.55313 .42328 Mdot
.33597 .52092 Mdot
.37083 .73992 Mdot
.51888 .13155 Mdot
.3991 .84785 Mdot
.53588 .61367 Mdot
.55926 .42723 Mdot
.40565 .70401 Mdot
.37507 .39016 Mdot
.5461 .5129 Mdot
.59978 .42151 Mdot
.56563 .35653 Mdot
.38898 .59763 Mdot
.23291 .58016 Mdot
.49923 .23759 Mdot
.4613 .76144 Mdot
.3449 .33012 Mdot
.29394 .75989 Mdot
.72582 .27601 Mdot
.45132 .22696 Mdot
.46557 .13329 Mdot
.51763 .27779 Mdot
.71684 .43201 Mdot
.65333 .66716 Mdot
.17451 .44987 Mdot
.38728 .65358 Mdot
.401 .78219 Mdot
.3319 .31228 Mdot
.378 .7169 Mdot
.46304 .59296 Mdot
.20739 .45325 Mdot
.46036 .308 Mdot
.48054 .45435 Mdot
.25088 .50202 Mdot
.19533 .57365 Mdot
.73638 .68774 Mdot
.24495 .32707 Mdot
.38638 .79383 Mdot
.84455 .59476 Mdot
.18419 .37945 Mdot
.39285 .56074 Mdot
.32898 .50884 Mdot
.65555 .67217 Mdot
.43332 .61622 Mdot
.46048 .63687 Mdot
.4937 .79614 Mdot
.75727 .54433 Mdot
.26563 .41372 Mdot
.4559 .82693 Mdot
.35004 .67538 Mdot
.72746 .50513 Mdot
.39124 .51463 Mdot
.74719 .64274 Mdot
.24415 .41229 Mdot
.45661 .56784 Mdot
.42449 .57652 Mdot
.41537 .64001 Mdot
.72476 .66022 Mdot
.74988 .38883 Mdot
.5513 .21372 Mdot
.82218 .65326 Mdot
.30562 .31024 Mdot
.40377 .8133 Mdot
.51065 .63317 Mdot
.14252 .46422 Mdot
.55858 .22528 Mdot
.32141 .31238 Mdot
.69135 .26627 Mdot
.4397 .43612 Mdot
.72946 .43688 Mdot
.59735 .60301 Mdot
.29642 .29415 Mdot
.79051 .55254 Mdot
.67525 .54959 Mdot
.44687 .80807 Mdot
.38129 .67824 Mdot
.27214 .62625 Mdot
.42902 .66385 Mdot
.49652 .57876 Mdot
.63737 .44246 Mdot
.21574 .66491 Mdot
.44215 .49227 Mdot
.61412 .54764 Mdot
.57759 .72952 Mdot
.58675 .77205 Mdot
.74365 .27078 Mdot
.50791 .56388 Mdot
.21039 .56567 Mdot
.71033 .71449 Mdot
.52454 .72133 Mdot
.58225 .51304 Mdot
.52825 .09104 Mdot
.16407 .33808 Mdot
.69528 .43486 Mdot
.81783 .5003 Mdot
.71652 .71135 Mdot
.18245 .43556 Mdot
.27707 .51958 Mdot
.44745 .36325 Mdot
.54582 .74708 Mdot
.44301 .62115 Mdot
.49769 .59876 Mdot
.65991 .24281 Mdot
.18452 .34709 Mdot
.45211 .81409 Mdot
.20372 .37261 Mdot
.5671 .71462 Mdot
.49599 .59449 Mdot
.55661 .12673 Mdot
.31984 .24925 Mdot
.60996 .56546 Mdot
.60677 .77689 Mdot
.71034 .48778 Mdot
.55819 .66214 Mdot
.26321 .35326 Mdot
.84168 .44651 Mdot
.34608 .67329 Mdot
.1828 .42174 Mdot
.6439 .41902 Mdot
.32762 .3888 Mdot
.56752 .35031 Mdot
.412 .52496 Mdot
.60589 .58731 Mdot
.54842 .33973 Mdot
.58211 .74911 Mdot
.50699 .20485 Mdot
.57513 .31964 Mdot
.81278 .40136 Mdot
.36333 .18587 Mdot
.75389 .60923 Mdot
.65715 .38622 Mdot
.60925 .55708 Mdot
.72734 .50256 Mdot
.41232 .76238 Mdot
.70113 .51063 Mdot
.5754 .19646 Mdot
.10493 .5591 Mdot
.42013 .30143 Mdot
.3056 .69011 Mdot
.62902 .51631 Mdot
.54949 .49277 Mdot
.76521 .63021 Mdot
.39269 .49584 Mdot
.39506 .43442 Mdot
.58975 .70064 Mdot
.51546 .56209 Mdot
.54314 .38521 Mdot
.49776 .88053 Mdot
.52582 .59386 Mdot
.56754 .50392 Mdot
.24889 .27783 Mdot
.42329 .78396 Mdot
.69442 .64518 Mdot
.60678 .6442 Mdot
.6573 .36254 Mdot
.38781 .51287 Mdot
.43598 .19647 Mdot
.27139 .66758 Mdot
.20923 .37923 Mdot
.74833 .59685 Mdot
.72636 .6913 Mdot
.55296 .57569 Mdot
.3079 .6029 Mdot
.58402 .27277 Mdot
.27572 .33754 Mdot
.54302 .70822 Mdot
.21729 .30607 Mdot
.44458 .4146 Mdot
.39175 .35364 Mdot
.47678 .60129 Mdot
.17113 .5654 Mdot
.50325 .82139 Mdot
.78499 .59484 Mdot
.37027 .79894 Mdot
.23023 .50753 Mdot
.44141 .75428 Mdot
.40517 .42379 Mdot
.55095 .70916 Mdot
.65588 .41655 Mdot
.30343 .77459 Mdot
.25569 .35204 Mdot
.40864 .28763 Mdot
.44619 .30434 Mdot
.8053 .46194 Mdot
.63108 .27487 Mdot
.4347 .14358 Mdot
.23855 .50817 Mdot
.30689 .773 Mdot
.7816 .37853 Mdot
.64683 .52619 Mdot
.51079 .22143 Mdot
.48302 .60831 Mdot
.37414 .40372 Mdot
.20359 .39265 Mdot
.55809 .54675 Mdot
.3217 .73805 Mdot
.57597 .6852 Mdot
.31074 .74898 Mdot
.36885 .62435 Mdot
.23757 .40327 Mdot
.44799 .24825 Mdot
.55619 .7971 Mdot
.48513 .17459 Mdot
.69062 .38842 Mdot
.49725 .14307 Mdot
.48781 .18215 Mdot
.22675 .31221 Mdot
.36156 .76665 Mdot
.60669 .81239 Mdot
.36586 .27025 Mdot
.4194 .22315 Mdot
.4963 .25184 Mdot
.6375 .71642 Mdot
.26035 .55632 Mdot
.49424 .57383 Mdot
.60454 .30333 Mdot
.54172 .31164 Mdot
.22767 .77011 Mdot
.3136 .63636 Mdot
.70702 .44631 Mdot
.24493 .54373 Mdot
.20208 .34555 Mdot
.62011 .73539 Mdot
.60387 .20961 Mdot
.51785 .48839 Mdot
.49101 .63525 Mdot
.76056 .56575 Mdot
.79985 .43232 Mdot
.26172 .56949 Mdot
.75049 .75111 Mdot
.72946 .28422 Mdot
.42842 .32702 Mdot
.48578 .48365 Mdot
.6329 .43647 Mdot
.60946 .4293 Mdot
.25597 .48156 Mdot
.59698 .19529 Mdot
.5091 .20863 Mdot
.32924 .24159 Mdot
.7475 .74157 Mdot
.76626 .37694 Mdot
.17337 .44937 Mdot
.46025 .23726 Mdot
.70463 .4598 Mdot
.38527 .5455 Mdot
.42231 .42529 Mdot
.41669 .27821 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Xooooo`;o0000Wooo
ool001cooooo00?o0000ooooooooool0Z?ooool2o`0009oooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`2aooooo`;o0000U_ooool001cooooo00?o0000ooooooooool0YOooool2o`0000[o
oooo0_l0000Iooooo`;o0000Noooool001cooooo00?o0000ooooooooool0Toooool2o`00013ooooo
0_l0000Uooooo`;o0000Noooool001cooooo00?o0000ooooooooool0Toooool2o`000;Cooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0ROooool2o`00
01?ooooo0_l0002Yooooo`007?ooool00ol0003oooooooooo`29ooooo`;o00004oooool2o`000:Wo
oooo000Looooo`03o`000?oooooooooo09;ooooo0_l00003ooooo`;o0000/?ooool001cooooo0_l0
002Cooooo`Co000000?oooooo`000?l00000/?ooool001cooooo00?o0000ooooooooool0Toooool3
o`0001Wooooo0_l0002Hooooo`007?ooool00ol0003oooooooooo`22ooooo`;o00003Oooool6o`00
01Sooooo0_l0002Hooooo`007?ooool00ol0003oooooooooo`22ooooo`;o00003Oooool2o`0000;o
oooo0_l0000Tooooo`;o00002?ooool2o`0008;ooooo000Looooo`03o`000?oooooooooo08_ooooo
0_l000000ooooooo0000o`000003o`00017ooooo0_l0000?ooooo`;o00000oooool5o`0000Kooooo
0_l00022ooooo`007?ooool00ol0003oooooooooo`2:ooooo`?o000000?oooooo`000?l000000ol0
0004ooooo`;o00001_ooool2o`0000;ooooo0ol00002ooooo`;o00002oooool2o`0000?ooooo0_l0
00000ooooooo0000o`00000<ooooo`;o0000O?ooool001cooooo00?o0000ooooooooool0Qoooool2
o`000003ooooool0003o000000_ooooo0_l00006ooooo`;o00000_ooool4o`000003ooooool0003o
0000027ooooo0_l00003ooooo`;o0000Moooool001cooooo00?o0000ooooooooool0Qoooool2o`00
00?ooooo1?l0000:ooooo`;o00002Oooool2o`0002Wooooo0_l0001gooooo`007?ooool00ol0003o
ooooooooo`2<ooooo`Co00002_ooool2o`0000Oooooo1?l00005ooooo`;o00002oooool2o`0008ko
oooo000Looooo`03o`000?oooooooooo09gooooo0_l00003ooooo`Go00001?ooool3o`0000Wooooo
1?l0002>ooooo`007?ooool00ol0003oooooooooo`21ooooo`;o00002?ooool2o`0000kooooo1?l0
0003ooooo`Co00001Oooool2o`000003ooooool0003o000000Oooooo0_l0002@ooooo`007?ooool0
0ol0003oooooooooo`1booooo`;o00002Oooool2o`0000;ooooo1?l00006ooooo`;o00003_ooool2
o`0000Oooooo0_l00008ooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o
000000;o00001oooool2o`0008Cooooo000Looooo`03o`000?oooooooooo07;ooooo0_l00009oooo
o`;o00001?ooool2o`0000;ooooo0_l0000Booooo`;o00004Oooool2o`000003ooooool0003o0000
00;ooooo0_l000000ooooooo0000o`000002o`0000Oooooo0ol00023ooooo`0000Koooooonk^k_lb
<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0NOooool2
o`000004ooooool0003o0000o`0000Sooooo0_l0000Booooo`;o00005?ooool3o`0000Cooooo0_l0
000:ooooo`;o0000Poooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo
00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo07Oooooo1?l000000ooooooo
0000o`00000<ooooo`;o00002oooool2o`0000;ooooo0_l0000Dooooo`Co00000_ooool2o`000003
ooooool0003o000000;ooooo0_l0000Tooooo`;o0000Hoooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo07Cooooo
0_l000000ooooooo0000o`000004ooooo`;o00001?ooool2o`0000Gooooo0_l00007ooooo`;o0000
00Coooooo`000?l0003o00005Oooool2o`0000?ooooo0_l00002ooooo`;o000000Goooooo`000?l0
003o0000ooooo`02o`0002Cooooo0_l0001Sooooo`0000?oooooo`000?ooool00_ooool00ol0003o
ooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0001dooooo`;o00001_ooool3o`0000Co
oooo0_l0000>ooooo`;o000000?oooooo`000?l000005_ooool2o`000003ooooool0003o000000So
oooo0_l0000Sooooo`;o0000Ioooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
3?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo07Kooooo0_l00003ooooo`?o0000
0_ooool2o`0001Cooooo0_l00008ooooo`?o00001_ooool2o`0000?ooooo2ol00008ooooo`;o0000
7Oooool2o`0006Oooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`1fooooo`;o00000oooool2o`0000?ooooo0_l0
000Dooooo`;o00000oooool2o`0000?ooooo1?l00003ooooo`Co00001?ooool2o`0000;ooooo1_l0
0002ooooo`;o00001?ooool4o`0008Cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo
00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo06Oooooo0_l00006ooooo`;o
000000?oooooo`000?l000001oooool2o`0001cooooo1?l00004ooooo`?o00000oooool2o`0000co
oooo0_l00004ooooo`;o00000oooool2o`000003ooooool0003o000008Cooooo00001_ooooook^k^
oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooo
oooo06Oooooo0_l00006ooooo`Go00004oooool2o`0000?ooooo0_l00007ooooo`?o000000Cooooo
o`000?l0003o00001Oooool3o`0000Wooooo1?l00004ooooo`;o00001?ooool2o`0000?ooooo0ol0
000>ooooo`;o0000M_ooool001cooooo00?o0000ooooooooool0J_ooool3o`0000Cooooo0ol00009
ooooo`;o00002?ooool2o`0000?ooooo0_l00007ooooo`?o00000_ooool2o`0000gooooo0_l00002
ooooo`Ko00001Oooool2o`000003ooooool0003o000000Cooooo0_l0000<ooooo`Co00005Oooool2
o`0005oooooo000Looooo`03o`000?oooooooooo06[ooooo0ol0000>ooooo`Co00003?ooool2o`00
0003ooooool0003o000001;ooooo0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l000000ooo
oooo0000o`000006ooooo`;o00002_ooool2o`0001Oooooo0_l0001Oooooo`007?ooool00ol0003o
ooooooooo`1[ooooo`;o00003_ooool2o`0000Cooooo1Ol00005ooooo`;o000000?oooooo`000?l0
00000oooool2o`0000Oooooo2?l0000@ooooo`;o000000?oooooo`000?l000002_ooool2o`0000[o
oooo0_l00007ooooo`;o0000Koooool001cooooo00?o0000ooooooooool0I?ooool4o`0000?ooooo
0_l0000Cooooo`Ko00002Oooool2o`0000;ooooo0_l00007ooooo`Ko00001_ooool2o`0000Sooooo
1ol0000?ooooo`?o00001Oooool4o`0000Cooooo0_l0001_ooooo`007?ooool00ol0003ooooooooo
o`1Tooooo`Co00006?ooool2o`000003ooooool0003o000000[ooooo0_l00009ooooo`;o00000ooo
ool2o`0000Oooooo0_l00007ooooo`So00003oooool3o`0000;ooooo0_l000000ooooooo0000o`00
0002o`0007Gooooo000Looooo`03o`000?oooooooooo06Sooooo0_l0000?ooooo`;o00000oooool2
o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`;o00002_ooool4o`0000Gooooo0_l0000>
ooooo`;o00000_ooool2o`0001Kooooo0_l00004ooooo`;o00000_ooool2o`00073ooooo000Loooo
o`03o`000?oooooooooo05Oooooo0_l00008ooooo`Co000000?oooooo`000?l000000_l0000;oooo
o`;o00000_ooool2o`0000?ooooo0_l00005ooooo`?o00001?ooool2o`000003ooooool0003o0000
00Oooooo0_l00002ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`;o00003?ooool2
o`0001Sooooo0_l00002ooooo`Ko0000L?ooool001cooooo00?o0000ooooooooool0Eoooool2o`00
00Sooooo1?l000000ooooooo0000o`00000<ooooo`?o000000?oooooo`000?l000001?ooool2o`00
00Gooooo0_l00008ooooo`;o000000?oooooo`000?l000002?ooool4o`0000Cooooo1Ol00005oooo
o`;o00006oooool2o`0000;ooooo0_l00004ooooo`;o00000_ooool2o`0006kooooo000Looooo`03
o`000?oooooooooo06Oooooo0ol0000:ooooo`;o00000_ooool2o`0000Cooooo0_l0000@ooooo`Ko
00000oooool2o`0000?ooooo0_l00005ooooo`;o00001oooool3o`0000?ooooo0_l00002ooooo`?o
000000?oooooo`000?l000003Oooool2o`0000Kooooo0_l00002ooooo`Co0000K_ooool001cooooo
00?o0000ooooooooool0Ioooool3o`0000Cooooo0_l0000Pooooo`;o00000_ooool8o`00013ooooo
1Ol00003ooooo`;o00000_ooool3o`000003ooooool0003o000000Co00002Oooool2o`0000Kooooo
0_l00002ooooo`;o0000L?ooool001cooooo00?o0000ooooooooool0G_ooool2o`0000Cooooo0_l0
0008ooooo`?o00002oooool2o`00013ooooo0_l00006ooooo`Oo00003oooool4o`0000;ooooo0ol0
0009ooooo`Co00002Oooool2o`0007cooooo000Looooo`;o0000Goooool2o`0000Cooooo0_l00009
ooooo`;o00002oooool2o`0000Sooooo0ol000000ooooooo0000o`000002ooooo`;o00001oooool8
o`0000kooooo0_l00003ooooo`Go00000oooool2o`0000Cooooo0_l00002ooooo`;o00002oooool2
o`00017ooooo0_l0001Sooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o00000oooool2o`00
01Kooooo0_l0000>ooooo`?o000000?oooooo`000?l000003oooool4o`000003ooooool0003o0000
00;o00002Oooool2o`0000Cooooo1?l00003ooooo`;o00001?ooool2o`0000;ooooo0_l0000;oooo
o`;o00004Oooool2o`0006?ooooo000Looooo`03o`000?oooooooooo05Kooooo0_l000000ooooooo
0000o`000002ooooo`?o00002_ooool2o`0000[ooooo0_l00006ooooo`;o00006Oooool2o`0000Go
oooo1?l0000Fooooo`;o00001?ooool4o`0000Wooooo0_l00005ooooo`;o00002_ooool2o`0000Go
oooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`1Fooooo`;o00001Oooool2o`0000_ooooo
0_l0000Booooo`;o00005Oooool6o`0000Oooooo0_l0000<ooooo`;o00003_ooool4o`0000Wooooo
0_l00004ooooo`Co00002Oooool2o`0000Gooooo0_l0001Pooooo`007?ooool00ol0003ooooooooo
o`1Gooooo`?o0000;oooool2o`0000[ooooo1?l000000ooooooo0000o`00000=ooooo`;o00001Ooo
ool2o`000004ooooool0003o0000ooooo`?o00000_ooool2o`0000?ooooo0_l0000Aooooo`Co0000
L_ooool001cooooo00?o0000ooooooooool0D?ooool2o`0000Gooooo0ol0000?ooooo`;o00000_oo
ool2o`0000cooooo0_l0000;ooooo`?o00002oooool2o`000004ooooool0003o0000o`0000Kooooo
0_l00005ooooo`;o00002?ooool6o`0000;ooooo1?l00009ooooo`;o00004oooool2o`0000[ooooo
0_l0001Nooooo`007?ooool00ol0003oooooooooo`1@ooooo`?o00005?ooool4o`0000;ooooo0_l0
0004ooooo`;o000000Coooooo`000?l0003ooooo1?l0000:ooooo`?o00003oooool2o`0000Oooooo
0_l0000?ooooo`?o00001oooool4o`0000Oooooo0_l00007ooooo`;o00002_ooool2o`0000[ooooo
0_l00003ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0COooool2o`0000;ooooo0_l0
000Dooooo`;o000000?oooooo`000?l000001oooool2o`000004ooooool0003o0000ooooo`Co0000
2Oooool4o`0000gooooo0_l0000@ooooo`;o00000oooool2o`0000?ooooo0_l00005ooooo`;o0000
0oooool2o`0000[ooooo0_l00004ooooo`;o00006?ooool2o`000003ooooool0003o000005Wooooo
000Looooo`03o`000?oooooooooo04gooooo0_l00005ooooo`;o00005?ooool2o`0000_ooooo0_l0
000=ooooo`Co00001oooool2o`0000Cooooo0_l0000@ooooo`;o00000oooool2o`0000?ooooo0_l0
0002ooooo`;o000000Coooooo`000?l0003o00002?ooool2o`0000;ooooo1?l0000:ooooo`?o0000
3_ooool2o`000003ooooool0003o000000;o0000F_ooool001cooooo00?o0000ooooooooool0COoo
ool2o`0000Gooooo0ol00004ooooo`;o00000_ooool2o`000003ooooool0003o000000cooooo0_l0
0005ooooo`;o00002oooool4o`0000Wooooo0_l0000Aooooo`;o00004Oooool2o`0000;ooooo0_l0
0008ooooo`;o00000_ooool2o`0000cooooo0ol0000>ooooo`;o00000_ooool3o`0000[ooooo0_l0
001>ooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00001?ooool5o`0000?ooooo0_l00000
1Ooooooo0000o`000?l0003ooooo00;o00003?ooool2o`0000gooooo0_l000000ooooooo0000o`00
0004o`0000Sooooo0_l0000Booooo`Co00006_ooool2o`0000_ooooo0_l0000<ooooo`;o00003Ooo
ool2o`0000_ooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`17ooooo`;o00002_ooool5
o`0000Kooooo0_l00002ooooo`;o00003oooool2o`0000Oooooo0_l000001?oooooo0000o`000?oo
ool2o`0000cooooo0_l0000:ooooo`;o00001oooool5o`0000Cooooo0_l00002ooooo`Ko00002_oo
ool3o`0000Kooooo0_l00002ooooo`;o00003?ooool2o`0000[ooooo0_l00004ooooo`;o0000F?oo
ool001cooooo00?o0000ooooooooool0Aoooool2o`0002?ooooo0_l00005ooooo`;o00001Oooool4
o`0000?ooooo0ol000000ooooooo0000o`000004ooooo`;o00003oooool2o`0000Oooooo0_l00000
0ooooooo0000o`000004ooooo`;o00000_ooool6o`0000Cooooo0_l00005ooooo`;o00001_ooool2
o`0000;ooooo0ol0000:ooooo`;o00002oooool2o`000004ooooool0003o0000ooooo`;o0000F?oo
ool001cooooo00?o0000ooooooooool0C_ooool3o`0000;ooooo0_l0000:ooooo`;o00002oooool2
o`0000Oooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool3o`000004ooooool0003o
0000ooooo`Ko00005Oooool2o`00017ooooo0_l00004ooooo`;o00003Oooool2o`0000?ooooo0_l0
000:ooooo`?o00001?ooool2o`0000Oooooo0_l00007ooooo`;o0000D_ooool001cooooo00?o0000
ooooooooool0@oooool2o`0000Oooooo2_l00007ooooo`Oo00001oooool2o`0000Sooooo1?l00004
ooooo`;o00002Oooool6o`0001Gooooo0_l0000>ooooo`;o000000?oooooo`000?l000004oooool2
o`0000Gooooo0_l00009ooooo`;o00001?ooool2o`0000;ooooo0_l00005ooooo`;o000000Cooooo
o`000?l0003ooooo0ol00008ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0@oooool2
o`0000Oooooo0_l00002ooooo`Ko00001oooool2o`000003ooooool0003o000000Co00001Oooool2
o`0000[ooooo0_l000000ooooooo0000o`000004o`0000Kooooo0_l0000<ooooo`;o00005?ooool2
o`0000Oooooo0_l0000<ooooo`;o00001Oooool2o`0000Sooooo0_l0000<ooooo`;o00001Oooool2
o`000003ooooool0003o000000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000Wooooo0_l0
0018ooooo`007?ooool2o`0004Oooooo0_l0000:ooooo`;o00000_ooool2o`0000Sooooo0_l00002
ooooo`;o00001?ooool2o`0000cooooo2?l00005ooooo`?o00001_ooool4o`0000;ooooo1?l0000B
ooooo`;o00003_ooool2o`0000Gooooo0_l00004ooooo`?o00002oooool2o`0000?ooooo0_l00004
ooooo`;o00002?ooool2o`0000;ooooo0_l0001Iooooo`007?ooool00ol0003oooooooooo`16oooo
o`;o00003_ooool2o`0000kooooo0ol000000ooooooo0000o`00000;ooooo`Ko00002?ooool2o`00
00?ooooo2?l00003ooooo`?o000000?oooooo`000?l000002_ooool2o`0000Gooooo1?l0000:oooo
o`Go00000_ooool2o`0000Cooooo0ol00009ooooo`Co00000oooool2o`0000Kooooo0_l00005oooo
o`;o00001Oooool2o`0000kooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`13ooooo`;o
00008Oooool3o`000003ooooool0003o000000Wooooo2?l0000=ooooo`Go000000?oooooo`000?l0
00000oooool2o`0000;ooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo1?l0000<ooooo`?o
00000_ooool2o`0000Gooooo0_l00005ooooo`;o00000_ooool2o`0000Cooooo0_l00007ooooo`;o
00001Oooool2o`0000Gooooo0_l0000>ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0
@oooool2o`0000;ooooo0_l00008ooooo`;o00002Oooool2o`0000;ooooo0_l00008ooooo`;o0000
2Oooool2o`0000;ooooo0_l0000:ooooo`;o00002Oooool4o`0000_ooooo0_l00003ooooo`;o0000
9?ooool2o`0000?ooooo0ol000000ooooooo0000o`000003o`000003ooooool0003o0000023ooooo
0_l0001<ooooo`007?ooool00ol0003oooooooooo`16ooooo`?o00002?ooool2o`0000Wooooo0_l0
0002ooooo`;o00000oooool2o`000003ooooool0003o000000[ooooo0_l00004ooooo`;o00002Ooo
ool2o`0000_ooooo0_l0000@ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`000003oooo
ool0003o000000Oooooo0_l0000@ooooo`;o000000Coooooo`000?l0003ooooo1?l000000ooooooo
0000o`000003o`0000kooooo0_l0000Aooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0
??ooool2o`0000Sooooo0_l0000Jooooo`;o000000?oooooo`000?l000000ol00004ooooo`;o0000
1?ooool2o`000004ooooool0003o0000ooooo`;o00007?ooool2o`0000Gooooo0_l000000ooooooo
0000o`000002o`000003ooooool0003o000000;o000000?oooooo`000?l000000ol00007ooooo`Co
00001oooool2o`0000Sooooo0_l00003ooooo`;o00000oooool3o`0000Kooooo0ol00005ooooo`;o
000000?oooooo`000?l000000oooool2o`0005Oooooo000Looooo`03o`000?oooooooooo03_ooooo
0ol0000Tooooo`;o00000_ooool2o`0000Kooooo0_l00004ooooo`Go00004?ooool4o`0000_ooooo
0_l00005ooooo`Oo00000_ooool9o`0000Kooooo0_l000000ooooooo0000o`000007ooooo`;o0000
3oooool2o`000003ooooool0003o000000;o00001Oooool3o`0000Gooooo0_l000000ooooooo0000
o`000003ooooo`;o00001?ooool2o`00057ooooo000Looooo`03o`000?oooooooooo03Wooooo1?l0
0002ooooo`;o00001Oooool2o`0000Cooooo0_l0000Fooooo`;o00001Oooool2o`0000Wooooo0_l0
00000ooooooo0000o`00000;ooooo`;o000000?oooooo`000?l000000_l0000;ooooo`;o00001_oo
ool3o`000005ooooool0003o0000o`000?ooool02ol00004ooooo`;o00000_ooool2o`0001Gooooo
1?l00003ooooo`;o00003Oooool4o`0000[ooooo0_l00005ooooo`;o0000B_ooool001cooooo00?o
0000ooooooooool0>Oooool2o`0000Cooooo0_l00005ooooo`;o00001?ooool2o`0000?ooooo0_l0
000?ooooo`Co00001?ooool3o`0000Wooooo0_l000000ooooooo0000o`00000;ooooo`;o00003Ooo
ool2o`000003ooooool0003o000000?ooooo1Ol00002ooooo`oo000000?oooooo`000?l000001Ooo
ool3o`0001Cooooo0_l0000<ooooo`;o00002?ooool2o`0000cooooo0_l00003ooooo`Go0000Aooo
ool001cooooo00?o0000ooooooooool0>Oooool2o`0000Oooooo0_l00008ooooo`;o00000_ooool3
o`0000?ooooo1?l000000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l000000_ooool3
o`0000Oooooo0_l000000ooooooo0000o`00000?ooooo`;o00003?ooool2o`0000Kooooo6Ol00003
ooooo`;o000000?oooooo`000?l000008_ooool2o`0000Cooooo0_l0000@ooooo`;o00001Oooool3
o`0004Oooooo000Looooo`03o`000?oooooooooo03Sooooo0ol00007ooooo`?o00001oooool2o`00
00;ooooo0_l00004ooooo`Co000000?oooooo`000?l000000_l00006ooooo`Ko000000?oooooo`00
0?l000001Oooool2o`000003ooooool0003o000000oooooo0_l00007ooooo`;o00002Oooool2o`00
0003ooooool0003o000001Ko00000oooool4o`0000Kooooo0_l0000Qooooo`;o00004oooool2o`00
04cooooo000Looooo`03o`000?oooooooooo03Oooooo0ol00007ooooo`Co00006?ooool2o`0000Co
oooo2?l000001?oooooo0000o`000?l00002ooooo`;o00000oooool2o`0001Gooooo0_l000000ooo
oooo0000o`000009oooooaco00001?ooool2o`0000Kooooo0_l0000Hooooo`;o00001oooool2o`00
00?ooooo0_l0000>ooooo`;o00001?ooool2o`0004Kooooo000Looooo`03o`000?oooooooooo03;o
oooo0_l00003ooooo`;o00001oooool3o`0000;ooooo0_l0000?ooooo`;o00001_ooool3o`0000;o
oooo3?l00002ooooo`;o00001_ooool2o`00013ooooo1?l000000ooooooo0000o`000009oooooaco
00003?ooool3o`0001Oooooo0_l00007ooooo`;o00000oooool2o`0000Gooooo0_l00002ooooo`;o
000000?oooooo`000?l000001_ooool2o`0004Kooooo000Looooo`03o`000?oooooooooo03;ooooo
0_l0000<ooooo`;o00000oooool2o`0000oooooo1?l00004ooooo`?o00002Oooool2o`0000Gooooo
0_l00004ooooo`Co00002_ooool2o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`;o0000
2_oooolHo`0000;ooooo0ol00002ooooo`;o00001?ooool2o`0002;ooooo0_l00002ooooo`;o0000
1?ooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0004_ooooo000Looooo`03o`00
0?oooooooooo03Oooooo0_l0000>ooooo`;o00003oooool6o`000003ooooool0003o0000013ooooo
0_l00004ooooo`Co00002Oooool3o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l00000
0_l00008oooooa_o000000Coooooo`000?l0003o00000_ooool4o`0000oooooo1_l0000Aooooo`;o
00000_ooool2o`0000kooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`0dooooo`;o0000
00Coooooo`000?l0003o00001?ooool2o`0000Oooooo0_l0000=ooooo`;o00000_ooool4o`00013o
oooo0_l00009ooooo`;o00002Oooool2o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l0
00001?ooool2o`0000Cooooo7Ol000000ooooooo0000o`000002ooooo`?o00001_ooool2o`0000Oo
oooo1_l0000Hooooo`;o00002_ooool2o`0004cooooo000Looooo`;o0000=Oooool2o`0000;ooooo
0_l00004ooooo`;o00002oooool2o`0000Wooooo0_l00008ooooo`;o00001oooool2o`0000?ooooo
0_l0000Wooooo`;o00001OoooolLo`000005ooooool0003o0000o`000?ooool00_l00003ooooo`;o
00000_ooool6o`0000Oooooo0_l00005ooooo`;o00004Oooool2o`0000Gooooo0_l00003ooooo`;o
0000C?ooool001cooooo00?o0000ooooooooool0@oooool2o`0000Kooooo0_l00002ooooo`;o0000
00Coooooo`000?l0003ooooo1_l00005ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o
00001?ooool4o`0000Cooooo0_l0000=ooooo`;o00003OoooolOo`0000;ooooo1?l00002ooooo`;o
000000?oooooo`000?l000001?ooool4o`0000Oooooo0_l00005ooooo`;o00006?ooool4o`0004oo
oooo000Looooo`03o`000?oooooooooo04?ooooo1?l00008ooooo`Go000000?oooooo`000?l00000
1?l0000:ooooo`;o00001Oooool2o`0000;ooooo0_l00002ooooo`Co00001?ooool2o`0000Gooooo
0_l00006ooooo`;o00002ooooolAo`000003ooooool0003o000000go00000_ooool4o`0000;ooooo
0_l0000:ooooo`;o00005_ooool2o`00017ooooo0ol0001>ooooo`007?ooool00ol0003ooooooooo
o`0cooooo`;o000000?oooooo`000?l000003Oooool2o`0000[ooooo0_l00006ooooo`;o00002Ooo
ool2o`0000Kooooo0_l00002ooooo`;o00002Oooool2o`0000Kooooo0_l0000=ooooo`;o00001?oo
ool2o`000003ooooool0003o000000co000000?oooooo`000?l000003Ol0000Dooooo`Ko00004?oo
ool4o`0000[ooooo0_l00006ooooo`;o00000_ooool2o`0000;ooooo0_l00005ooooo`;o0000?ooo
ool001cooooo00?o0000ooooooooool0:_ooool2o`0000Oooooo0_l000000ooooooo0000o`00000>
ooooo`;o00002?ooool3o`00017ooooo0_l00009ooooo`;o00002_ooool2o`0000;ooooo0_l00006
ooooo`;o00001Oooool2o`0000;ooooo0_l00007oooooa3o000000?oooooo`000?l000002_l0000;
ooooo`;o00002Oooool6o`000003ooooool0003o000000cooooo0_l000000ooooooo0000o`000005
ooooo`;o00000_ooool2o`0000Sooooo1?l00002ooooo`;o00001Oooool2o`0003oooooo000Loooo
o`03o`000?oooooooooo02[ooooo0_l0000@ooooo`Co00001_ooool2o`0000Kooooo1?l00005oooo
o`;o00005Oooool5o`0000cooooo0_l00003ooooo`;o000000?oooooo`000?l000001Oooool2o`00
0003ooooool0003o000000;ooooo0_l00006oooooa_o000000?oooooo`000?l000002?ooool2o`00
00Wooooo0_l00002ooooo`;o000000?oooooo`000?l000002_ooool2o`0000?ooooo0_l00005oooo
o`;o00002_ooool4o`00013ooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`0looooo`Co
00002Oooool2o`0000?ooooo0_l00005ooooo`Oo00001?ooool2o`0000Kooooo0_l00002ooooo`Co
000000Coooooo`000?l0003ooooo0_l0000>ooooo`;o00000oooool2o`0000Kooooo0_l00002oooo
o`;o00001_oooolNo`0000oooooo0_l00009ooooo`;o000000?oooooo`000?l000001_ooool3o`00
00_ooooo0_l00002ooooo`;o00001Oooool4o`000003ooooool0003o000000gooooo0_l0000joooo
o`007?ooool00ol0003oooooooooo`0kooooo`;o00002_ooool4o`0000Sooooo1?l00002ooooo`?o
00001?ooool2o`0000Kooooo0_l00002ooooo`;o00001_ooool2o`000003ooooool0003o0000013o
oooo0_l0000<ooooo`;o00000_ooool6o`000003ooooool0003o000001Go00004Oooool2o`0000_o
oooo0ol00006ooooo`;o00003?ooool6o`0000Oooooo0_l000000ooooooo0000o`000005ooooo`;o
00001_ooool2o`0003[ooooo000Looooo`03o`000?oooooooooo03Wooooo1?l000001?oooooo0000
o`000?l00006ooooo`;o00000_ooool2o`0000Kooooo0_l0000Cooooo`;o00003Oooool4o`0000Oo
oooo0_l00005ooooo`;o00003?ooool2o`0000;ooooo0_l00002oooooaKo00000_ooool2o`0000Go
oooo0ol0000Aooooo`;o00000oooool2o`0000Cooooo0_l00008ooooo`;o00001_ooool5o`00017o
oooo0_l00006ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0>?ooool3o`0000?ooooo
0ol000000ooooooo0000o`000006ooooo`?o00002_ooool2o`0000Sooooo1?l00006ooooo`;o0000
3?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0001Oooooo0_l00002oooooaKo0000
0_ooool2o`0000Gooooo0ol00008ooooo`?o00001_ooool2o`0000Wooooo0ol000000ooooooo0000
o`000004ooooo`;o00001oooool8o`0000;ooooo0_l00006ooooo`;o00001Oooool2o`0003kooooo
000Looooo`03o`000?oooooooooo03Sooooo0_l00004ooooo`Ko00001_ooool2o`0000_ooooo0_l0
0005ooooo`;o000000?oooooo`000?l000000_l00006ooooo`;o000000?oooooo`000?l000003Ooo
ool2o`000003ooooool0003o000000?ooooo0_l00008ooooo`Co00001_ooool2o`0000Cooooo1?l0
0003oooooa?o00002oooool2o`0000?ooooo0ol0000Aooooo`?o000000?oooooo`000?l000004?oo
ool5o`0000;ooooo0_l00006ooooo`;o00001Oooool2o`0003kooooo000Looooo`03o`000?oooooo
oooo03Sooooo0_l00005ooooo`?o00001?ooool3o`0000Oooooo1?l00004ooooo`?o00000oooool2
o`0000gooooo0ol00003ooooo`;o00003?ooool2o`000004ooooool0003o0000o`0000Oooooo1Ol0
0006ooooo`;o00001_ooool4o`000003ooooool0003o000000Oo000000Coooooo`000?l0003ooooo
1?l0000<ooooo`?o00000oooool2o`0000gooooo0_l00007ooooo`;o00004oooool2o`0000;ooooo
1?l0001;ooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00002_ooool2o`0000[ooooo1Ol0
0005ooooo`Co00001?ooool3o`0000Cooooo0_l00004ooooo`;o00000oooool2o`000005ooooool0
003o0000o`000?ooool01?l000001?oooooo0000o`000?l00003ooooo`?o00000_ooool2o`000003
ooooool0003o000000;o00001Oooool3o`00013ooooo2?l000000ooooooo0000o`000007o`0000Co
oooo0_l000000ooooooo0000o`000008ooooo`?o00003?ooool2o`0000Cooooo0ol00006ooooo`;o
00001oooool2o`0000Wooooo0ol00002ooooo`Co0000Boooool001cooooo00?o0000ooooooooool0
;_ooool2o`0000Wooooo0ol0000=ooooo`;o00005?ooool2o`0000Cooooo1?l000000ooooooo0000
o`00000Go`0000?ooooo0_l00005ooooo`Ko00000oooool2o`0000Sooooo0_l000000ooooooo0000
o`000003o`0000?ooooo2Ol00002ooooo`So000000?oooooo`000?l000000oooool2o`0000cooooo
0_l00005ooooo`;o00000_ooool2o`0000;ooooo1?l00005ooooo`;o00001?ooool2o`0000?ooooo
1?l000001?oooooo0000o`000?ooool2o`0000Wooooo0_l0000oooooo`0000Koooooonk^k_lb<S;o
0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000oooo
ooooool0>Oooool2o`0000?ooooo1?l00006ooooo`;o00006_ooool2o`000004ooooool0003o0000
oooooaSo00003Oooool4o`0000?ooooo0_l00005ooooo`;o00002oooool7o`000003ooooool0003o
000000Cooooo1_l000001?oooooo0000o`000?l0000Kooooo`;o00000oooool3o`0000;ooooo0_l0
0007ooooo`;o00001Oooool2o`000003ooooool0003o000000?o00002?ooool3o`0003oooooo0000
1_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0=Oooool2o`0000Oooooo1?l00006ooooo`;o00006_ooool2o`0000Cooooo
6_l0000Hooooo`?o00002oooool3o`0000cooooo1_l000000ooooooo0000o`00000Cooooo`;o0000
2oooool3o`0000;ooooo0_l00006ooooo`;o000000?oooooo`000?l000000ol00005ooooo`;o0000
2Oooool2o`00043ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo1Ol0
0006ooooo`03o`000?oooooooooo03Gooooo1?l0000Aooooo`;o00006_ooool2o`0000;ooooo6_l0
000Hooooo`;o00006oooool2o`0000;ooooo0_l0000@ooooo`;o00001?ooool2o`0000Oooooo0_l0
0002ooooo`;o00001Oooool2o`0000Cooooo0_l000000ooooooo0000o`000003o`0005;ooooo0000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001ooo
ool3o`0003Gooooo1_l0000>ooooo`?o00006_ooool2o`000003ooooool0003o000001Ko00003ooo
ool2o`0000?ooooo0_l0000Uooooo`;o00001_ooool2o`0000Wooooo0_l00005ooooo`;o00000_oo
ool2o`0000;ooooo0_l00002ooooo`?o00000_ooool4o`000004ooooool0003o0000ooooo`;o0000
3?ooool2o`0000Gooooo0_l00013ooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooooooo
o`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0=Oooool2o`0000;ooooo
0_l0000>ooooo`;o000000?oooooo`000?l000000_l0000Eooooo`;o00000_oooolHo`0000;ooooo
0_l00009ooooo`Co00000oooool2o`0001Wooooo0_l00006ooooo`?o000000?oooooo`000?l00000
0_ooool2o`0000;ooooo1?l0000>ooooo`;o00000_ooool4o`0000Gooooo0ol000000ooooooo0000
o`000003ooooo`Co00003Oooool2o`0000Gooooo0_l00013ooooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0@Ooo
ool2o`000003ooooool0003o000000Cooooo1_l0000Doooooago00000_ooool2o`0000Wooooo0_l0
0004ooooo`;o00006_ooool2o`0000Kooooo0ol00005ooooo`;o00001?ooool2o`0000gooooo0_l0
0005ooooo`;o000000?oooooo`000?l000000oooool2o`0000Sooooo0_l0000@ooooo`;o0000Aooo
ool00006oooooomgMgOoV9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`00
0?oooooooooo047ooooo0_l000000ooooooo0000o`000004ooooo`Co00001?ooool2o`0000?ooooo
0_l0000;ooooob3o00004?ooool2o`0001Kooooo1?l00006ooooo`;o00000_ooool2o`0000Cooooo
0_l0000@ooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo0_l0000Oooooo`Co0000
AOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03
o`000?oooooooooo04cooooo0_l00004ooooo`?o00000_ooool2o`0000gooooo8Ol00005ooooo`?o
00003_ooool2o`0000gooooo1?l00006ooooo`;o00000_ooool2o`0000Sooooo0_l00002ooooo`;o
00001?ooool6o`0000Cooooo1Ol0000Rooooo`;o000000Coooooo`000?l0003o0000A?ooool001co
oooo00?o0000ooooooooool0<oooool4o`0000_ooooo0_l0000?ooooo`;o00001oooool2o`0000Oo
oooo1_l000000ooooooo0000o`000003o`000003ooooool0003o000000_o000000?oooooo`000?l0
00001Ol00005ooooo`?o00003_ooool2o`0001Oooooo0_l0000<ooooo`;o00000_ooool4o`0000;o
oooo1Ol00005ooooo`Go00001?ooool2o`0000;ooooo0ol0000Gooooo`;o000000Coooooo`000?l0
003o00002_ooool2o`0003Sooooo000Looooo`03o`000?oooooooooo03?ooooo1?l000000ooooooo
0000o`000007ooooo`?o00005?ooool2o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`co
000000?oooooo`000?l000004Ol0000Qooooo`;o00002Oooool2o`000003ooooool0003o000000Wo
oooo0ol00005oooooa7o000000Coooooo`000?l0003ooooo0ol00002ooooo`;o00000_ooool3o`00
0003ooooool0003o000002Cooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0cooooo`;o
00000oooool2o`0000Kooooo1?l00006ooooo`;o00000oooool2o`0000Oooooo0_l00005ooooo`;o
00001oooool9o`000003ooooool0003o000000;o000000?oooooo`000?l000003?l0000Pooooo`?o
00002?ooool3o`000003ooooool0003o000000;ooooo1Ol00002ooooo`?o00000oooool4o`0000;o
oooo1_l000000ooooooo0000o`000004o`000003ooooool0003o000000Co00002_ooool2o`0000?o
oooo0_l0001Iooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00002oooool4o`0000Kooooo
0_l00003ooooo`;o00001_ooool2o`0000Gooooo0_l00008ooooo`_o000000Coooooo`000?l0003o
oooo4?l0000Aooooo`;o00002oooool2o`0000Cooooo0_l00002ooooo`Go00001?ooool5o`0000;o
oooo0_l00004ooooo`;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000009o`00013o
oooo0ol0001Iooooo`007?ooool00ol0003oooooooooo`16ooooo`;o00003oooool2o`0000Gooooo
0ol00008oooooa_o000000?oooooo`000?l000004Oooool2o`0000Sooooo0_l00002ooooo`;o0000
0oooool2o`0000;ooooo0_l000000ooooooo0000o`00000;ooooo`Go000000?oooooo`000?l00000
1?ooool3o`000003ooooool0003o000000go00002Oooool2o`0000Cooooo0_l00003ooooo`;o0000
EOooool001cooooo00?o0000ooooooooool0;Oooool2o`000004ooooool0003o0000o`0001?ooooo
0_l0000Gooooo`;o00001Oooool2o`000003ooooool0003o000001Wo00005oooool4o`0000?ooooo
0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l0000=ooooo`So00000oooool5o`0000;ooooo
4Ol00004ooooo`Co00001_ooool2o`000003ooooool0003o000000_ooooo0ol00017ooooo`007?oo
ool00ol0003oooooooooo`0]ooooo`;o000000Coooooo`000?l0003o00001Oooool2o`0000Gooooo
0_l00004ooooo`;o00001?ooool2o`0000Kooooo0_l0000Aooooo`;o00000_ooool4o`000004oooo
ool0003o0000o`0000;ooooo4?l00007ooooo`;o00001Oooool2o`0000Kooooo1Ol00007ooooo`;o
00001oooool2o`0000gooooo0_l00004ooooo`;o00000ooooolHo`0000Cooooo0_l00002ooooo`;o
00001?ooool2o`0000kooooo0ol00017ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o0000
0_ooool2o`000003ooooool0003o000000Cooooo0_l00004ooooo`;o00001_ooool2o`0000Oooooo
0_l00009ooooo`;o000000?oooooo`000?l000001ol00002ooooo`oo00001oooool3o`0000;ooooo
1?l00006ooooo`;o00004oooool2o`0000;ooooo0_l0000?ooooo`;o000000?oooooo`000?l00000
5ol000000ooooooo0000o`000006ooooo`;o00000oooool2o`0000;ooooo0_l0000Kooooo`;o0000
>?ooool001cooooo00?o0000ooooooooool0??ooool2o`0000Cooooo0_l00008ooooo`;o00000ooo
ool2o`000003ooooool0003o000000Kooooo0_l00009ooooo`;o00000_oooolIo`0000;ooooo0_l0
0004ooooo`;o00000_ooool2o`0001gooooo0_l00002ooooo`;o00003oooool2o`000003ooooool0
003o000001[o000000?oooooo`000?l000002?ooool2o`0000;ooooo0_l0000Kooooo`;o0000>?oo
ool001cooooo00?o0000ooooooooool0;_ooool2o`0000Wooooo0_l00007ooooo`;o000000?ooooo
o`000?l000000oooool4o`000003ooooool0003o000000;o000000?oooooo`000?l000005OoooolH
o`0000?ooooo0_l00006ooooo`?o00000_ooool2o`0001Sooooo0ol00003ooooo`;o00003_ooool5
o`000003ooooool0003o000001_o0000Hoooool001cooooo00?o0000ooooooooool0;_ooool2o`00
00Cooooo0ol00002ooooo`;o00001Oooool4o`000003ooooool0003o000000?ooooo1?l000000ooo
oooo0000o`000002ooooo`;o00005OoooolIo`0000Sooooo1ol000000ooooooo0000o`00000Doooo
o`;o00000_ooool3o`0000?ooooo0_l0000=ooooobCo00005Oooool2o`00017ooooo0_l00002oooo
o`;o0000=Oooool001cooooo0_l0000Mooooo`;o00004_ooool2o`0000;ooooo1?l00008ooooo`;o
00001?ooool2o`0000?ooooo0ol00005ooooo`;o00005OoooolIo`0000Sooooo1?l000000ooooooo
0000o`00000Eooooo`Wo00004_ooool2o`000003ooooool0003o000001co000000Coooooo`000?l0
003ooooo0_l0000;ooooo`;o00001Oooool2o`0000;ooooo0_l0000:ooooo`;o000000Goooooo`00
0?l0003o0000ooooo`02o`0003Gooooo000Looooo`03o`000?oooooooooo01cooooo0_l0000Boooo
o`;o00000oooool3o`0000Sooooo0_l00004ooooo`;o00000oooool2o`0000?ooooo0_l0000Ioooo
oaSo00002?ooool2o`0000_ooooo0_l0000=ooooo`Wo00001?ooool2o`0000oooooo7Ol00005oooo
o`;o00002oooool2o`0000Sooooo0ol0000:ooooo`Ko0000>?ooool001cooooo00?o0000oooooooo
ool0<_ooool2o`0000Oooooo0_l00003ooooo`;o00003_ooool2o`0000[ooooo0_l0000>oooooaKo
00004_ooool2o`0000;ooooo0_l00007ooooo`;o00000oooool3o`000003ooooool0003o000000;o
00001_ooool2o`0000oooooo7Ol0000=ooooo`;o00003Oooool2o`0000?ooooo0_l00002ooooo`Go
000000?oooooo`000?l00000>_ooool001cooooo00?o0000ooooooooool0<_ooool2o`0000Cooooo
2?l0000;ooooo`;o00002oooool2o`0000;ooooo0_l00008ooooo`;o00001_oooolDo`0000Kooooo
0_l0000:ooooo`;o00002oooool2o`0000?ooooo0_l00003ooooo`;o00006_oooolMo`000003oooo
ool0003o000000;o00001_ooool2o`0001;ooooo0_l00002ooooo`Go00004_ooool2o`0002Wooooo
000Looooo`03o`000?oooooooooo02_ooooo0_l0000;ooooo`?o00000_ooool3o`0000_ooooo0_l0
000;ooooo`;o00003?ooool2o`0000Sooooo3_l0000:ooooo`;o000000?oooooo`000?l000002?oo
ool2o`0000oooooo0_l0000Looooob3o000000?oooooo`000?l000000_l00006ooooo`;o00004Ooo
ool2o`0001[ooooo0_l0000Yooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o00007?ooool3
o`0000oooooo0_l0000:ooooo`;o00001oooool>o`0000gooooo0_l00004ooooo`;o00000_ooool2
o`0000[ooooo0_l000000ooooooo0000o`000002o`0001Sooooo0_l00002oooooaco00000oooool2
o`0000[ooooo0_l00007ooooo`;o00002?ooool2o`0000Oooooo0_l0000looooo`007?ooool00ol0
003oooooooooo`0_ooooo`;o00000_ooool2o`0000Kooooo0ol0000;ooooo`?o00003oooool2o`00
00[ooooo0_l00007ooooo`?o00001?ooool7o`0001?ooooo0_l00009ooooo`;o00000oooool2o`00
0003ooooool0003o000000;o00000oooool2o`0000Gooooo0_l00008ooooo`;o00000_ooool3o`00
00;ooooo8_l0000Aooooo`;o00001?ooool2o`0000_ooooo0_l0000looooo`007?ooool00ol0003o
ooooooooo`0_ooooo`;o00000_ooool2o`0000?ooooo0_l000001?oooooo0000o`000?l00003oooo
o`;o00001oooool2o`0001?ooooo0_l0000=ooooo`oo00000_ooool2o`000004ooooool0003o0000
o`0001Oooooo0_l0000=ooooo`;o00001Oooool2o`0000Sooooo0_l00003ooooo`;o00000_oooolO
o`000004ooooool0003o0000ooooo`;o00001Oooool4o`0000_ooooo1?l00004ooooo`;o000000?o
ooooo`000?l000000_l0000looooo`007?ooool00ol0003oooooooooo`0aooooo`;o00001Oooool2
o`0000Oooooo0_l00007ooooo`;o00004oooool2o`0000;ooooo0_l00005ooooo`;o00000_ooool2
o`000003ooooool0003o000000Wo00000oooool2o`000004ooooool0003o0000o`0001Kooooo0_l0
00000ooooooo0000o`000002ooooo`Co00002?ooool2o`0000Sooooo0_l00005ooooo`Co000000?o
ooooo`000?l000007?l00006ooooo`;o00000oooool6o`0000gooooo0_l00004ooooo`;o000000?o
ooooo`000?l000000_l0000looooo`007?ooool00ol0003oooooooooo`0aooooo`;o00003Oooool2
o`0000Cooooo1?l0000=ooooo`;o00002_ooool2o`000003ooooool0003o000000;ooooo2?l00000
1?oooooo0000o`000?ooool8o`0000Gooooo0_l00003ooooo`Co00001oooool2o`0000Kooooo0_l0
00000ooooooo0000o`000007o`0000Oooooo0_l00002ooooo`?o00000_ooool3o`0000Gooooo9?l0
00000ooooooo0000o`000007ooooo`;o00000_ooool3o`0001;ooooo0_l00002ooooo`?o0000??oo
ool001cooooo00?o0000ooooooooool0>Oooool3o`0000Cooooo0_l00004ooooo`Ko00000oooool2
o`0000Kooooo0_l0000=ooooo`;o00001?ooool6o`000004ooooool0003o0000ooooo`;o00000_oo
ool4o`0000Gooooo0_l00003ooooo`Co00001oooool3o`0000Kooooo0_l00002ooooo`;o000000?o
ooooo`000?l000000_l00002ooooo`;o00001oooool3o`0000;ooooo1Ol00002ooooo`Ko00000_oo
oolMo`000003ooooool0003o000000Gooooo0_l00005ooooo`;o00003?ooool2o`0000?ooooo0ol0
00000ooooooo0000o`000002o`0003cooooo000Looooo`03o`000?oooooooooo02oooooo0_l00007
ooooo`Co00001?ooool2o`0000Sooooo0_l00003ooooo`;o00003_ooool2o`0000gooooo0_l0000:
ooooo`?o00001?ooool2o`000003ooooool0003o000000;ooooo0_l0000:ooooo`;o00001?ooool4
o`0000Cooooo0ol00004ooooo`;o00003oooool2o`000004ooooool0003o0000o`0000Cooooo3_l0
00000ooooooo0000o`000008o`0000;ooooo1?l000000ooooooo0000o`000005ooooo`;o00004ooo
ool2o`0000?ooooo0_l00002ooooo`?o00000_ooool2o`0003Wooooo000Looooo`03o`000?oooooo
oooo02oooooo0_l00007ooooo`;o000000?oooooo`000?l000000oooool2o`0000Oooooo0ol00009
ooooo`;o00002?ooool2o`0000;ooooo1_l0000:ooooo`;o00003?ooool2o`000005ooooool0003o
0000o`000?ooool00_l0000:ooooo`;o00001?ooool2o`0000Kooooo1ol0000Dooooo`;o00001Ooo
ool>o`000003ooooool0003o000000So00001Oooool3o`0001gooooo0_l00007ooooo`;o000000Co
ooooo`000?l0003ooooo0_l0000fooooo`007?ooool00ol0003oooooooooo`0kooooo`;o00003?oo
ool3o`0000Wooooo0_l0000<ooooo`Ko00002_ooool2o`00013ooooo0_l00005ooooo`;o00000ooo
ool5o`0000[ooooo0_l00002ooooo`Go00006Oooool2o`0000?ooooo3?l000000ooooooo0000o`00
0008o`000004ooooool0003o0000ooooo`?o00007Oooool2o`000003ooooool0003o000000Cooooo
0_l00004ooooo`;o0000=_ooool001cooooo00?o0000ooooooooool0>?ooool2o`0001Sooooo0_l0
000@ooooo`;o000000?oooooo`000?l000008oooool2o`0000?ooooo1Ol0000:ooooo`;o00002?oo
ool2o`0000?ooooo0_l00005ooooo`;o00002_ooool2o`0000?ooooo5ol000000ooooooo0000o`00
000Qooooo`;o000000?oooooo`000?l000003Oooool2o`0003?ooooo000Looooo`03o`000?oooooo
oooo03Sooooo0_l0000Hooooo`;o00004oooool4o`0000[ooooo0_l00005ooooo`;o00002_ooool2
o`0001Kooooo0_l00008ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo0_l0000?
oooooaGo000000?oooooo`000?l000007oooool2o`0000Cooooo0_l00004ooooo`;o00002?ooool2
o`0003?ooooo000Looooo`;o0000>Oooool2o`0001?ooooo0_l0000Dooooo`;o00001?ooool2o`00
00Kooooo0_l00002ooooo`;o00001Oooool4o`0000Sooooo0_l0000:ooooo`;o00004_ooool2o`00
00?ooooo1ol0000?ooooo`Co000000?oooooo`000?l000005Ol00004ooooo`;o00001oooool2o`00
00kooooo1?l00003ooooo`Go00000_ooool2o`0000Oooooo0_l0000dooooo`007?ooool00ol0003o
ooooooooo`0`ooooo`;o00006oooool3o`0001?ooooo0_l0000<ooooo`Co00002Oooool2o`0001Co
oooo0_l00007ooooo`;o00001?ooool2o`0000?ooooo0_l00003ooooo`;o00000_ooool2o`0000;o
oooo0_l00007ooooo`;o00000oooool4o`000003ooooool0003o000001Ko00000oooool2o`0000?o
oooo0_l00002ooooo`;o00003_ooool2o`0000Gooooo0_l000000ooooooo0000o`000002o`0000Wo
oooo0_l0000dooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00000_ooool4o`0000oooooo
0_l00005ooooo`;o00006Oooool2o`000003ooooool0003o000000Gooooo0_l00008ooooo`;o0000
2?ooool2o`00013ooooo0_l00002ooooo`?o00000oooool2o`0000Oooooo0_l00005ooooo`Co0000
1oooool2o`0000Wooooo4ol000001?oooooo0000o`000?l00008ooooo`Co00003Oooool2o`0000go
oooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00000_ooool4o`0000Cooooo
0_l00004ooooo`;o00000oooool2o`000003ooooool0003o000001_ooooo1?l000000ooooooo0000
o`00000?ooooo`;o00000oooool2o`000003ooooool0003o000000;o00000_ooool2o`0000cooooo
0_l00003ooooo`;o00001?ooool2o`0000;ooooo0_l00002ooooo`;o00001Oooool2o`0000Kooooo
0_l0000>ooooo`co00000oooool4o`0000;ooooo0_l00006ooooo`Co00003Oooool2o`0004kooooo
000Looooo`03o`000?oooooooooo03cooooo0_l00004ooooo`;o00001?ooool6o`0001Wooooo0_l0
000Aooooo`Go00000oooool2o`000003ooooool0003o000000?ooooo0ol0000Gooooo`;o00000_oo
ool2o`0000Cooooo0_l00009ooooo`Co00000oooool2o`0000?ooooo0_l00003ooooo`?o00000ooo
ool7o`0000Gooooo0_l00002ooooo`;o00006Oooool2o`0004cooooo000Looooo`03o`000?oooooo
oooo04Sooooo0_l00002ooooo`;o00002?ooool2o`0000Sooooo0_l00007ooooo`;o00003oooool5
o`0000Kooooo0_l000000ooooooo0000o`000002o`0000cooooo0_l00005ooooo`;o00003Oooool2
o`0000Wooooo0_l00004ooooo`?o000000?oooooo`000?l000000ol000001?oooooo0000o`000?l0
0005ooooo`;o00000_ooool3o`0000Sooooo1?l00002ooooo`;o00004_ooool3o`0000oooooo1Ol0
000hooooo`007?ooool00ol0003oooooooooo`1Fooooo`;o00002?ooool2o`0000Oooooo0ol00007
ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo0_l00006ooooo`?o00003_ooool2
o`0000Gooooo0_l0000>ooooo`;o00001?ooool2o`0000Gooooo0_l000000ooooooo0000o`000002
ooooo`Go000000Coooooo`000?l0003o00002Oooool3o`0000Oooooo2Ol0000Booooo`;o00001ooo
ool2o`0000Kooooo1_l0000hooooo`007?ooool00ol0003oooooooooo`0dooooo`;o00007oooool3
o`00017ooooo0ol00007ooooo`;o00000oooool2o`0000?ooooo1Ol00005ooooo`;o00003oooool2
o`0001Gooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo1?l00007ooooo`?o00000_oo
ool3o`0000Cooooo0_l00003ooooo`Co00001Oooool2o`0000?ooooo1?l0000Kooooo`;o00001_oo
ool2o`0003cooooo000Looooo`03o`000?oooooooooo03Cooooo0_l0000<ooooo`;o000000?ooooo
o`000?l000003_ooool2o`0000Kooooo0_l0000:ooooo`;o00001oooool2o`0000Wooooo0_l00000
0ooooooo0000o`000002o`0000;ooooo0ol00008ooooo`;o00002oooool2o`0000_ooooo0_l00005
ooooo`;o00000_ooool2o`0000;ooooo0_l0000:ooooo`;o00000_ooool3o`000004ooooool0003o
0000ooooo`;o00001?ooool3o`0002Oooooo0ol00004ooooo`;o0000?oooool001cooooo00?o0000
ooooooooool0=Oooool2o`0000Sooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l0
000Aooooo`;o00004?ooool2o`000003ooooool0003o000000;ooooo0_l0000:ooooo`?o000000Co
ooooo`000?l0003o00001oooool3o`0000[ooooo0ol0000;ooooo`?o00002?ooool2o`0000kooooo
0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000Cooooo0_l0000Tooooo`;o0000
0_ooool3o`0000Cooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0dooooo`?o00002?oo
ool3o`0000Cooooo0_l00002ooooo`;o00001Oooool2o`0000[ooooo0_l000000ooooooo0000o`00
000=ooooo`Go00000_ooool3o`0000Wooooo0ol0000:ooooo`?o00002oooool2o`000003ooooool0
003o000000;o00000oooool4o`000004ooooool0003o0000o`0001Oooooo0_l00009ooooo`;o0000
0_ooool2o`0001kooooo0_l00006ooooo`;o000000?oooooo`000?l00000Aoooool001cooooo00?o
0000ooooooooool0=?ooool2o`0000;ooooo0_l00002ooooo`So00000_ooool2o`0000Gooooo0_l0
0002ooooo`;o00002_ooool2o`000003ooooool0003o000000gooooo0ol00005ooooo`;o00002Ooo
ool2o`0000Wooooo1?l00003ooooo`;o00002_ooool4o`0000?ooooo1?l00002ooooo`;o00002_oo
ool2o`0000_ooooo0_l00003ooooo`;o00002?ooool2o`0000?ooooo0_l0000Iooooo`;o00002Ooo
ool2o`0004Oooooo000Looooo`03o`000?oooooooooo03Sooooo0_l00002ooooo`Co000000?ooooo
o`000?l000000_l00002ooooo`;o00001?ooool2o`0001_ooooo0_l0000<ooooo`;o00002?ooool2
o`0000Gooooo1_l00005ooooo`;o00002oooool2o`0000Wooooo0_l000000ooooooo0000o`000008
ooooo`;o00003?ooool2o`0000;ooooo0_l0000=ooooo`;o00001?ooool2o`0001Sooooo0_l0001=
ooooo`007?ooool00ol0003oooooooooo`0Booooo`;o0000;oooool3o`000004ooooool0003o0000
ooooo`;o000000?oooooo`000?l000006oooool2o`0000cooooo0_l00003ooooo`;o00002?ooool9
o`0000Cooooo0_l0000@ooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`;o00002Ooo
ool2o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l000000_l00007ooooo`;o00002Ooo
ool2o`0001Sooooo0ol0000Jooooo`;o0000<?ooool001cooooo00?o0000ooooooooool04_ooool2
o`0002cooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo1Ol00002ooooo`Co00003_oo
ool2o`0000Wooooo0_l00003ooooo`;o00002?ooool2o`0000Sooooo1Ol00002ooooo`;o00005?oo
ool4o`0000Oooooo0_l000001?oooooo0000o`000?ooool4o`0000Cooooo0ol000000ooooooo0000
o`000002o`0000Gooooo1Ol00003ooooo`;o000000?oooooo`000?l000001?ooool2o`0001Gooooo
0_l00007ooooo`Co00000oooool2o`0001?ooooo0_l0000`ooooo`007?ooool00ol0003ooooooooo
o`0eooooo`;o000000?oooooo`000?l000001_ooool2o`0000[ooooo0_l00003ooooo`Co00000_oo
ool3o`0000Wooooo0_l00009ooooo`;o00000_ooool5o`0000;ooooo0_l00007ooooo`;o00001_oo
ool2o`0000kooooo0_l00008ooooo`;o00002Oooool2o`000004ooooool0003o0000ooooo`Co0000
0_ooool2o`000003ooooool0003o000000?ooooo1Ol00005ooooo`;o00000oooool2o`0000Oooooo
0_l0000Eooooo`;o00000_ooool2o`0000Cooooo0ol00003ooooo`;o00001_ooool3o`0000?ooooo
0_l0000gooooo`007?ooool2o`0003?ooooo0_l000001?oooooo0000o`000?ooool2o`0000gooooo
0_l00008ooooo`;o00001?ooool7o`0000gooooo1Ol00002ooooo`Go00000_ooool2o`0000Gooooo
1?l00006ooooo`?o000000?oooooo`000?l000002Oooool3o`0000cooooo1?l00005ooooo`?o0000
1oooool2o`0000?ooooo0_l00002ooooo`Co00004?ooool2o`0001Wooooo1Ol0000>ooooo`;o0000
0_ooool3o`0000?ooooo0_l0000gooooo`007?ooool00ol0003oooooooooo`0booooo`;o00001Ooo
ool2o`0000Oooooo0_l00003ooooo`;o00001Oooool2o`0000;ooooo0_l00006ooooo`Co00001Ooo
ool2o`0000Kooooo1?l00003ooooo`Co000000?oooooo`000?l000001oooool4o`0000Cooooo1Ol0
00001?oooooo0000o`000?l00008ooooo`?o00003?ooool4o`0000Gooooo0_l00002ooooo`;o0000
00?oooooo`000?l000000_l00004ooooo`;o00005_ooool2o`0001Wooooo0ol00007ooooo`;o0000
0oooool2o`0000;ooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00001ooo
ool2o`0000?ooooo0_l00005ooooo`;o000000?oooooo`000?l000001?l0000<ooooo`;o00000_oo
ool?o`000003ooooool0003o000000;o000000?oooooo`000?l000000oooool3o`0000Cooooo0_l0
00000ooooooo0000o`000002ooooo`;o00002Oooool2o`000003ooooool0003o000000Wooooo0_l0
0005ooooo`;o00001?ooool7o`000003ooooool0003o000000?ooooo0ol0000`ooooo`;o00001_oo
ool2o`0000?ooooo0_l0000=ooooo`;o0000=_ooool001cooooo00?o0000ooooooooool07_ooool2
o`0001kooooo0_l00007ooooo`;o00002?ooool6o`0000kooooo4?l00004ooooo`;o000000?ooooo
o`000?l000002_ooool2o`0000[ooooo0_l00004ooooo`;o000000?oooooo`000?l000002?ooool4
o`0000Cooooo0ol00002ooooo`Oo00000_ooool4o`000004ooooool0003o0000o`0000Cooooo0_l0
0003ooooo`;o00003?ooool2o`0001Oooooo0ol00008ooooo`?o00001?ooool2o`0000;ooooo0_l0
0004ooooo`;o0000=_ooool001cooooo00?o0000ooooooooool07_ooool2o`0001kooooo0_l00007
ooooo`?o00001oooool2o`0000Cooooo0_l0000<oooooa3o00000oooool2o`0000;ooooo0_l00000
0ooooooo0000o`00000Cooooo`;o00001?ooool2o`0000Sooooo1ol000001Ooooooo0000o`000?l0
003ooooo00_o00000oooool7o`0000Cooooo0_l00003ooooo`;o000000?oooooo`000?l000002Ooo
ool2o`0001Sooooo0_l000000ooooooo0000o`000005ooooo`?o00001?ooool2o`0000;ooooo0_l0
000looooo`007?ooool00ol0003oooooooooo`0dooooo`;o00002oooool2o`0000?ooooo1?l0000<
ooooo`?o00002Oooool2o`000003ooooool0003o000000oo00000_ooool2o`0000;ooooo0_l00000
0ooooooo0000o`000005ooooo`Oo00001oooool2o`0000_ooooo1ol00002ooooo`Go000000?ooooo
o`000?l000002Ol00003ooooo`Ko00003Oooool3o`000003ooooool0003o000001cooooo0_l00004
ooooo`;o00001Oooool3o`0000Kooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0_oooo
o`;o00000oooool2o`0000Kooooo0_l00002ooooo`?o00000oooool2o`0000Wooooo0_l00003oooo
o`;o00000_ooool2o`0000Kooooo5?l00004ooooo`;o00002_ooool7o`0000Cooooo0_l0000:oooo
o`;o000000?oooooo`000?l000000ol00002ooooo`So00000_ooool7o`000004ooooool0003o0000
ooooo`So00003_ooool2o`000003ooooool0003o000000Gooooo0_l0000Eooooo`;o00002oooool2
o`0000Oooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o000000?oooooo`00
0?l000000_l00006ooooo`Ko00003oooool2o`0000?ooooo0_l00002ooooo`;o00001?oooolFo`00
0004ooooool0003o0000ooooo`Co00002Oooool3o`0000Gooooo1?l00005ooooo`;o00000oooool2
o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000007o`000003ooooool0003o
000000Ko00000oooool8o`000003ooooool0003o000000;o00002Oooool2o`000003ooooool0003o
000000Gooooo0_l0000hooooo`;o0000<Oooool001cooooo00?o0000ooooooooool0<_ooool4o`00
00;ooooo0_l00002ooooo`Co00005_ooool2o`0000Oooooo3ol000000ooooooo0000o`000009o`00
0003ooooool0003o000000?o00000oooool2o`0000?ooooo1?l00003ooooo`;o00000_ooool2o`00
00?ooooo0_l00003ooooo`;o00001Oooool2o`0000Cooooo2Ol000000ooooooo0000o`000003o`00
00Cooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000;o0000=_ooool2o`00
01Gooooo0_l0000aooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00000_ooool2o`000003
ooooool0003o000000Oooooo0_l0000?ooooo`;o00000_oooolMo`0000Cooooo0_l00003ooooo`;o
000000?oooooo`000?l000000_ooool2o`0000Gooooo1?l00008ooooo`?o00001Oooool2o`000003
ooooool0003o0000013o00001_ooool4o`0001Kooooo0_l0000Sooooo`;o00001?ooool2o`0000?o
oooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00001oooool2o`0000oooooo
0_l00002ooooo`;o000000?oooooo`000?l000005ol00006ooooo`;o00001Oooool2o`0000Wooooo
0_l00005ooooo`;o00001?ooool2o`0000Gooooo5Ol00005ooooo`?o00000_ooool2o`0001Cooooo
0_l0000Booooo`;o00004Oooool2o`0000;ooooo0_l00003ooooo`;o0000?Oooool001cooooo00?o
0000ooooooooool0@oooool2o`0000?ooooo0_l0000Booooo`;o000000?oooooo`000?l000006?l0
0006ooooo`;o00001Oooool2o`0000Oooooo1?l000000ooooooo0000o`000002ooooo`;o00001Ooo
oolMo`000003ooooool0003o000000;o00000_ooool3o`0000;ooooo0_l0000Tooooo`;o00001Ooo
ool2o`0000?ooooo0_l00005ooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0@?ooool2
o`000003ooooool0003o000000?o000000?oooooo`000?l000004OoooolKo`0000[ooooo0_l00003
ooooo`;o00001oooool2o`0000?ooooo0_l00005ooooo`;o00000_oooolMo`000003ooooool0003o
000000Ko000000?oooooo`000?l000000_l00003ooooo`;o00001oooool2o`0000Gooooo0_l0000F
ooooo`;o00000oooool2o`0000Cooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`0eoooo
o`;o00002Oooool8o`000003ooooool0003o000000?ooooo0ol0000;oooooa_o00001Oooool7o`00
00?ooooo0_l0000Cooooo`;o00001_ooool2o`000003ooooool0003o000000go000000?oooooo`00
0?l000002?l000000ooooooo0000o`000002ooooo`Go00000oooool2o`0000Oooooo0_l00005oooo
o`;o00005_ooool2o`0000Wooooo0_l00017ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5
ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0=Ooo
ool2o`0000_ooooo0ol00009ooooo`?o000000?oooooo`000?l000000_l00003ooooo`;o000000?o
ooooo`000?l000006?l00006ooooo`Oo00003?ooool6o`0000_ooooo0_l000000ooooooo0000o`00
000Ko`0000Gooooo1?l00009ooooo`;o00006oooool3o`0000?ooooo0_l0001Booooo`0000Kooooo
ogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Ko
oooo00?o0000ooooooooool0=?ooool2o`0000gooooo0_l000000ooooooo0000o`000002o`0000So
oooo1?l00003ooooo`;o00000ooooolHo`0000?ooooo0_l00003ooooo`Go00001Oooool2o`0000Go
oooo1_l00008ooooo`;o000000Goooooo`000?l0003o0000ooooo`07o`000003ooooool0003o0000
00So000000?oooooo`000?l000001ol000000ooooooo0000o`000002ooooo`?o00001Oooool2o`00
00;ooooo0ol00007ooooo`;o00004_ooool3o`0000?ooooo1?l00002ooooo`;o00004_ooool2o`00
03Sooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo01_ooooo0_l0000Gooooo`;o00004?ooool4o`00
00?ooooo0_l000000ooooooo0000o`000004o`0000[ooooo5_l00003ooooo`So00001oooool2o`00
00Gooooo0_l00002ooooo`;o00001oooool4o`000004ooooool0003o0000oooooa?o000000?ooooo
o`000?l000003_l00005ooooo`;o00000_ooool2o`0000Sooooo0_l0000Booooo`;o00001_ooool2
o`0000;ooooo0_l00006ooooo`;o00002_ooool2o`0003Sooooo00000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o00006oooool2
o`00033ooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l00003ooooo`;o000000?o
ooooo`000?l000004_l00006ooooo`Oo00001_ooool2o`0000Kooooo1_l00002ooooo`Wo000000Co
ooooo`000?l0003ooooo4ol000000ooooooo0000o`00000?o`0001Kooooo0_l0000>ooooo`;o0000
1oooool3o`0000;ooooo0_l00004ooooo`;o0000A?ooool00003ooooool0003ooooo00;ooooo00?o
0000ooooooooool02Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0
;oooool2o`0000_ooooo0_l00004ooooo`?o00004?ooool2o`000003ooooool0003o000000;o0000
00Coooooo`000?l0003ooooo5?l0000Cooooo`;o00002?ooool2o`0000Cooooo1Ol000001?oooooo
0000o`000?l00003oooooako000000?oooooo`000?l000001Ol0000Booooo`;o00000_ooool2o`00
00kooooo0_l00007ooooo`?o00000_ooool2o`0004[ooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`0_ooooo`;o
00002oooool2o`0000Cooooo0ol00007ooooo`;o00001oooool3o`0000;ooooo0_l00004oooooa;o
00000oooool3o`0000Gooooo0_l0000Jooooo`;o00002?ooool2o`0000?ooooo4?l000000ooooooo
0000o`000009o`000003ooooool0003o000000_ooooo0_l00007ooooo`Ko00004?ooool2o`0000;o
oooo0_l000000ooooooo0000o`000007ooooo`Co0000A?ooool00006oooooomgMgOoV9RHoooooonH
V9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo03Cooooo0_l0000Foooo
o`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00001?oo
oolAo`0000;ooooo1Ol00005ooooo`Oo00004oooool6o`0000Gooooo7Ol000000ooooooo0000o`00
0005o`0000Kooooo0_l00003ooooo`;o00002Oooool2o`0001;ooooo0_l00002ooooo`;o00002_oo
ool4o`0004Cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o
410@1_ooool00ol0003oooooooooo`0dooooo`;o00001?ooool2o`0000oooooo0_l000001Ooooooo
0000o`000?l0003ooooo00;o00001Oooool2o`0000Sooooo3Ol00003ooooo`;o00002_ooool5o`00
00Gooooo0_l00006ooooo`;o00000_ooool4o`000004ooooool0003o0000o`0000Gooooo0_l00000
0ooooooo0000o`00000Qo`0000Gooooo0_l0000Booooo`;o00001oooool2o`000004ooooool0003o
0000o`0005Wooooo000Looooo`03o`000?oooooooooo03[ooooo0_l0000?ooooo`;o000000?ooooo
o`000?l000002Oooool2o`0000Kooooo0_l000000ooooooo0000o`000003o`0000;ooooo1Ol0000E
ooooo`;o00000_ooool2o`0000Kooooo0_l00002ooooo`Co00001?oooolUo`000003ooooool0003o
000000?o00002Oooool2o`0000Wooooo0_l00003ooooo`;o00001oooool2o`000004ooooool0003o
0000o`0000Sooooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00005Oooool4
o`0000Kooooo0_l00006ooooo`;o000000?oooooo`000?l000000ol000000ooooooo0000o`00000<
ooooo`;o00001_ooool2o`000003ooooool0003o000000;o00000_ooool2o`000003ooooool0003o
000000Cooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo3Ol000000ooooooo0000o`00
000Io`0000_ooooo0_l00009ooooo`Go00002Oooool2o`0000cooooo0ol00007ooooo`?o0000A?oo
ool001cooooo00?o0000ooooooooool0>?ooool2o`0001Gooooo1?l0000;ooooo`;o00001?ooool2
o`0000?ooooo0ol00008ooooo`;o00000_ooool2o`0000Kooooo0_l000000ooooooo0000o`000005
ooooo`Co00001?ooool2o`0000Cooooo1?l000000ooooooo0000o`00000:o`0000;ooooo6_l0000I
ooooo`?o00002Oooool2o`0000gooooo0_l000000ooooooo0000o`000004ooooo`?o0000A?ooool0
01cooooo00?o0000ooooooooool0Coooool2o`0000Cooooo0_l00004ooooo`;o000000?oooooo`00
0?l000002Oooool2o`0000;ooooo1?l00003ooooo`;o00000_ooool2o`0000Wooooo0_l00002oooo
o`;o000000?oooooo`000?l000000oooool2o`0000Oooooo1?l00002ooooo`;o00000_ooool2o`00
0003ooooool0003o000001ko00000_ooool3o`0001;ooooo0_l0000Nooooo`;o0000Boooool001co
oooo00?o0000ooooooooool0EOooool2o`0000Cooooo0_l00002ooooo`;o00003?ooool6o`0000Go
oooo0_l00007ooooo`;o00001?ooool2o`0000Kooooo1?l00006ooooo`;o000000?oooooo`000?l0
00000_l000000ooooooo0000o`00000Wo`0001;ooooo0_l00004ooooo`;o00004Oooool2o`0005;o
oooo000Looooo`03o`000?oooooooooo04Kooooo0_l00006ooooo`?o00001?ooool2o`0000Sooooo
0ol0000;ooooo`;o00000_ooool2o`0000Gooooo0_l00007ooooo`;o00001?ooool4o`0000?ooooo
1Ol00006ooooo`Go000000?oooooo`000?l00000:?l00007ooooo`;o00000oooool2o`0000_ooooo
0_l0000Aooooo`;o00001oooool2o`0004Wooooo000Looooo`03o`000?oooooooooo04Kooooo0_l0
0006ooooo`?o00000oooool4o`0000?ooooo1?l000000ooooooo0000o`000002o`0000Wooooo0_l0
0008ooooo`Co00003?ooool4o`0000?ooooo0ol000000ooooooo0000o`000004ooooo`Ko000000?o
ooooo`000?l000009?l00002ooooo`;o00001oooool2o`0000?ooooo0_l0000Wooooo`;o0000BOoo
ool001cooooo00?o0000ooooooooool0C_ooool2o`000004ooooool0003o0000ooooo`Co00000ooo
ool9o`0000kooooo0_l00003ooooo`Go00001Oooool4o`000004ooooool0003o0000o`0000Wooooo
0_l00004ooooo`;o000000Coooooo`000?l0003o00000_oooolWo`0001kooooo0_l0000Gooooo`;o
0000BOooool001cooooo00?o0000ooooooooool0@?ooool2o`0000cooooo0_l000001?oooooo0000
o`000?ooool4o`0000?ooooo0_l000000ooooooo0000o`000002o`00013ooooo1Ol00003ooooo`;o
00001Oooool4o`000004ooooool0003o0000o`0001?ooooo0_l00003ooooob3o000000?oooooo`00
0?l000000ol0000:ooooo`;o00003oooool2o`000003ooooool0003o000000Sooooo0ol0000<oooo
o`;o0000BOooool001cooooo00?o0000ooooooooool0@?ooool2o`0000Cooooo0_l0000Fooooo`;o
00005?ooool3o`0000_ooooo0_l00004ooooo`;o00001_ooool2o`0000Sooooo1Ol000000ooooooo
0000o`00000Ro`000003ooooool0003o000000[ooooo0ol0000:ooooo`;o00000_ooool2o`0000_o
oooo1Ol00002ooooo`;o0000DOooool001cooooo00?o0000ooooooooool0A_ooool2o`0000cooooo
0_l0000Fooooo`;o00001oooool3o`0000Gooooo0_l00005ooooo`;o00000_ooool2o`0000?ooooo
0_l000000ooooooo0000o`000008ooooob[o000000?oooooo`000?l000002Oooool4o`0000[ooooo
0_l00003ooooo`;o00003Oooool2o`0000;ooooo0_l00003ooooo`;o0000C?ooool001cooooo0_l0
001Eooooo`;o00005_ooool2o`0000Sooooo0_l00005ooooo`;o00001Oooool2o`0000Oooooo0_l0
000>ooooo`Go000000?oooooo`000?l000003?l000001Ooooooo0000o`000?l0003ooooo017o0000
2Oooool2o`00017ooooo0_l0000:ooooo`;o00001Oooool3o`0000;ooooo0_l00008ooooo`;o0000
@_ooool001cooooo00?o0000ooooooooool0D?ooool3o`0000;ooooo0_l00006ooooo`;o00002_oo
ool2o`0000?ooooo1?l00008ooooo`;o00006_ooool2o`0000?ooooo5_l000000ooooooo0000o`00
000>o`000003ooooool0003o000000;o00008oooool2o`0000?ooooo0_l00005ooooo`?o000000?o
ooooo`000?l000002Oooool4o`00043ooooo000Looooo`03o`000?oooooooooo03kooooo0_l0000@
ooooo`Oo00001?ooool4o`0000[ooooo0_l00002ooooo`Go00002?ooool2o`0000;ooooo0_l0000F
ooooo`;o00000oooool3o`0000?ooooo0ol000000ooooooo0000o`00000Ko`0001Oooooo0_l00006
ooooo`;o00001oooool2o`0000[ooooo1_l00008ooooo`;o000000?oooooo`000?l00000@?ooool0
01cooooo00?o0000ooooooooool0>?ooool2o`0000Cooooo0_l0000Booooo`?o000000Coooooo`00
0?l0003o00000_ooool2o`0000Wooooo0_l00005ooooo`Co00001?ooool2o`0000Oooooo0_l0000@
ooooo`;o00000oooool2o`0000Cooooo1?l000000ooooooo0000o`00000Qo`0000?ooooo0_l0000?
ooooo`Co00001_ooool2o`0000;ooooo0_l000000ooooooo0000o`000007ooooo`;o00000oooool4
o`0000[ooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00002?ooool2o`00
00gooooo0_l00003ooooo`?o00003Oooool2o`0000Kooooo0_l00004ooooo`?o000000Coooooo`00
0?l0003o00001?ooool2o`0000Oooooo0_l00006ooooo`Co000000?oooooo`000?l000001_ooool<
o`000003ooooool0003o000001Oo00000oooool2o`0000[ooooo0_l00003ooooo`;o00003?ooool2
o`000003ooooool0003o000000Oooooo0_l00004ooooo`?o0000Coooool001cooooo00?o0000oooo
ooooool0@_ooool2o`0000gooooo1Ol0000@ooooo`Co00001oooool2o`000003ooooool0003o0000
00;ooooo1Ol00002ooooo`;o00001oooool2o`0000Oooooo0ol0000;ooooo`;o000000?oooooo`00
0?l000006_l000000ooooooo0000o`00000?ooooo`Co00000oooool2o`0000oooooo0_l00007oooo
o`;o00002?ooool2o`0004cooooo000Looooo`03o`000?oooooooooo04_ooooo0_l00004ooooo`Go
00002_ooool2o`0000Cooooo1?l00003ooooo`;o00000_ooool2o`0000Kooooo1?l0000@ooooo`;o
00003Oooool3o`0000?ooooo0_l000001?oooooo0000o`000?oooolMo`0000Kooooo0_l00003oooo
o`;o00001Oooool2o`0000gooooo1Ol00006ooooo`;o00002?ooool2o`0004cooooo000Looooo`03
o`000?oooooooooo04_ooooo0_l00004ooooo`?o000000Coooooo`000?l0003o00002?ooool2o`00
00Oooooo0_l00002ooooo`;o000000?oooooo`000?l000002_ooool2o`0000Sooooo0_l00005oooo
o`;o00000oooool2o`0000Sooooo0ol00006oooooaKo000000?oooooo`000?l000000_l000000ooo
oooo0000o`000002o`0000?ooooo1ol000001?oooooo0000o`000?l0000Cooooo`;o000000?ooooo
o`000?l00000G_ooool001cooooo00?o0000ooooooooool0AOooool2o`0000_ooooo0_l000001?oo
oooo0000o`000?l0000Aooooo`;o00000_ooool7o`0000Sooooo0_l00007ooooo`?o00002_ooool2
o`0000_ooooo1Ol000000ooooooo0000o`00000Do`000003ooooool0003o000000;o00000_ooool4
o`000003ooooool0003o000000?o000000?oooooo`000?l000000_ooool2o`0000kooooo0ol0000D
ooooo`;o0000Coooool001cooooo00?o0000ooooooooool0AOooool2o`0002Oooooo0_l00002oooo
o`;o00001?ooool2o`0000_ooooo0_l0000Dooooo`;o00000_ooool5o`000003ooooool0003o0000
01Co000000?oooooo`000?l000000_l000001?oooooo0000o`000?ooool7o`0001Kooooo0ol0000=
ooooo`?o00001?ooool2o`0004oooooo000Looooo`03o`000?oooooooooo05gooooo0_l0000Ioooo
o`;o00001Oooool2o`0000Cooooo0_l0000?ooooo`;o00000oooool2o`0000Cooooo0_l00002oooo
oa?o000000Coooooo`000?l0003ooooo0ol00002ooooo`;o00000_ooool2o`000003ooooool0003o
000000Kooooo0_l0000:ooooo`;o00003?ooool2o`0000Cooooo1?l000000ooooooo0000o`00001B
ooooo`007?ooool00ol0003oooooooooo`1Looooo`?o00002Oooool2o`0000Cooooo0_l0000:oooo
o`;o00000oooool2o`0000Cooooo0_l00003ooooo`;o000000?oooooo`000?l000001oooool2o`00
00Wooooo0_l00002ooooo`Go00000_ooool7o`000003ooooool0003o000000Go00000_ooool4o`00
00oooooo0_l00006ooooo`;o00000_ooool2o`0000?ooooo0_l00007ooooo`;o00001?ooool2o`00
00?ooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`1Dooooo`Co000000Coooooo`000?l0
003ooooo0_l0000:ooooo`Co00000_ooool2o`0000Cooooo0_l00004ooooo`;o00001_ooool4o`00
00Cooooo1Ol0000<ooooo`;o00000_ooool4o`0000Cooooo0ol000000ooooooo0000o`000005o`00
00;ooooo1_l00004ooooo`?o00003_ooool2o`0000Oooooo0_l00007ooooo`;o00002?ooool3o`00
05_ooooo000Looooo`03o`000?oooooooooo02oooooo0_l0000Sooooo`Co000000?oooooo`000?l0
00000_l00003ooooo`;o00001?ooool2o`0000;ooooo0_l000001?oooooo0000o`000?l00003oooo
o`Co00002oooool4o`000004ooooool0003o0000ooooo`Go00001Oooool2o`0000Gooooo0_l00002
ooooo`;o00001OoooolDo`000003ooooool0003o000000?o00002?ooool2o`0000Gooooo0_l00008
ooooo`;o00000oooool2o`0000Cooooo0_l00002ooooo`Ko0000Foooool001cooooo00?o0000oooo
ooooool0;oooool2o`0001oooooo0_l00002ooooo`Co00000_ooool3o`0000?ooooo0_l00004oooo
o`;o00001Oooool2o`0000Cooooo1_l00008ooooo`;o00001?ooool9o`0000Cooooo0_l0000@oooo
o`;o00000_ooool:o`0000;ooooo1?l000001?oooooo0000o`000?l00007ooooo`;o000000?ooooo
o`000?l000001?ooool2o`0000Wooooo0ol00002ooooo`?o00000oooool2o`0000;ooooo0ol0001N
ooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o000000Coooooo`000?l0003o00004?ooool2
o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000001Oooool5o`0000Kooooo0_l0
0006ooooo`;o00000_ooool3o`0001;ooooo0_l00006ooooo`Wo00000oooool7o`0000Kooooo1?l0
0007ooooo`;o00002_ooool2o`0000;ooooo0ol0000?ooooo`;o0000Eoooool001cooooo0_l0001D
ooooo`?o00004oooool2o`000004ooooool0003o0000ooooo`;o00001?ooool2o`0000;ooooo0_l0
000@ooooo`;o00005?ooool3o`0000Cooooo1?l00002ooooo`Co00001?ooool8o`0000Gooooo0_l0
00000ooooooo0000o`00000>ooooo`;o00006?ooool2o`0000Cooooo0_l0001Aooooo`007?ooool0
0ol0003oooooooooo`1Dooooo`;o00003oooool2o`0000;ooooo0_l0000:ooooo`?o00002?ooool2
o`0000Wooooo0_l00003ooooo`;o00003oooool2o`0000Gooooo0_l00004ooooo`[o00000oooool5
o`0000Kooooo0_l00003ooooo`;o00001_ooool2o`000003ooooool0003o0000017ooooo0_l00004
ooooo`;o00001Oooool2o`00057ooooo000Looooo`03o`000?oooooooooo04Wooooo0_l00002oooo
o`;o00002_ooool2o`0000[ooooo0_l00002ooooo`Co00000oooool2o`0000Cooooo0_l00008oooo
o`;o00000oooool2o`0000;ooooo0ol00004ooooo`;o00005Oooool4o`0000;ooooo2Ol00005oooo
o`Go00002oooool2o`0000Kooooo0_l0000Booooo`Co00001?ooool2o`0000Kooooo0_l0001@oooo
o`007?ooool00ol0003oooooooooo`0oooooo`Co00001_ooool2o`0000;ooooo0_l0000:ooooo`;o
00001?ooool2o`0000Sooooo1?l000000ooooooo0000o`000002o`000003ooooool0003o000000?o
oooo0_l0000;ooooo`;o00000_ooool3o`0000Cooooo0_l0000Eooooo`Co00000_ooool5o`000004
ooooool0003o0000ooooo`;o00001Oooool2o`000003ooooool0003o0000017ooooo0_l0000@oooo
o`Ko00002Oooool2o`000003ooooool0003o0000053ooooo000Looooo`03o`000?oooooooooo03oo
oooo1?l0000Fooooo`;o00001?ooool2o`0000gooooo0_l00003ooooo`?o000000?oooooo`000?l0
00000ol00003ooooo`;o00002oooool2o`0000;ooooo0_l0000Booooo`;o00000oooool2o`0000;o
oooo1?l00004ooooo`?o00000oooool2o`0000?ooooo0_l00005ooooo`;o00002oooool2o`0000?o
oooo0_l0000:ooooo`;o00003Oooool2o`0005?ooooo000Looooo`03o`000?oooooooooo05Wooooo
0_l00004ooooo`;o00000oooool2o`000003ooooool0003o000000_ooooo2?l000000ooooooo0000
o`000002o`0000Wooooo1Ol0000Eooooo`Co00003?ooool6o`000003ooooool0003o000000[ooooo
0_l00002ooooo`;o00001oooool2o`0000?ooooo0_l00008ooooo`;o0000I?ooool001cooooo00?o
0000ooooooooool0D?ooool2o`0000;ooooo0_l00008ooooo`?o00000oooool2o`000003ooooool0
003o000000gooooo1_l000001?oooooo0000o`000?l0000:ooooo`;o000000Coooooo`000?l0003o
00000_ooool2o`0001;ooooo0_l0000<ooooo`;o000000Coooooo`000?l0003o00004?ooool3o`00
00[ooooo0_l0000:ooooo`Co0000H_ooool001cooooo00?o0000ooooooooool0D?ooool2o`0000;o
oooo0_l00008ooooo`;o00001oooool2o`0000Oooooo0_l000000ooooooo0000o`000005ooooo`;o
00000_ooool2o`0000Wooooo0_l00003ooooo`;o00000_ooool2o`0001?ooooo0_l0000Aooooo`;o
00000_ooool2o`0000[ooooo0_l0000;ooooo`;o00003?ooool2o`0006;ooooo000Looooo`03o`00
0?oooooooooo073ooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l00009ooooo`;o0000
0_ooool4o`0001[ooooo0_l0000Aooooo`;o000000Coooooo`000?l0003o0000ROooool001cooooo
00?o0000ooooooooool0@_ooool2o`0000gooooo0_l0000Kooooo`;o00001Oooool3o`0000gooooo
0_l00004ooooo`Co00007Oooool2o`0000Wooooo0ol00003ooooo`;o00002_ooool2o`0007kooooo
000Looooo`03o`000?oooooooooo04;ooooo1?l00008ooooo`;o000000?oooooo`000?l000004ooo
ool3o`0000Gooooo0_l00006ooooo`;o00001_ooool2o`0000;ooooo0_l00008ooooo`?o00003Ooo
ool2o`0000kooooo0_l00009ooooo`?o00003oooool2o`0001[ooooo0_l00003ooooo`;o00000_oo
ool2o`0005Wooooo000Looooo`03o`000?oooooooooo04;ooooo1?l00008ooooo`;o00005_ooool3
o`0000Gooooo0_l0000=ooooo`?o00000_ooool3o`0000Cooooo0_l000000ooooooo0000o`00000>
ooooo`;o00002Oooool2o`0001gooooo0_l0000Eooooo`;o00001_ooool2o`0000?ooooo0_l00002
ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0?_ooool2o`0000;ooooo0_l0000Ioooo
o`;o00001?ooool6o`0000cooooo0_l00006ooooo`;o00000_ooool4o`0000Cooooo0_l00002oooo
o`;o00006?ooool2o`0000Cooooo0ol00002ooooo`Co00002oooool2o`0000?ooooo0_l0000=oooo
o`;o00001_ooool2o`0006[ooooo000Looooo`03o`000?oooooooooo03kooooo0_l0000Mooooo`;o
00000_ooool6o`0000kooooo1?l00004ooooo`Ko000000?oooooo`000?l000001oooool2o`0001ko
oooo0ol00002ooooo`Co00002oooool2o`00013ooooo1?l0000Hooooo`;o0000F?ooool001cooooo
00?o0000ooooooooool0HOooool2o`0000Kooooo1?l00008ooooo`Go00001Oooool2o`0000?ooooo
0_l0000/ooooo`;o00000oooool2o`00017ooooo0_l00007ooooo`;o00006_ooool2o`0005Sooooo
000Looooo`03o`000?oooooooooo04Sooooo0_l0000Oooooo`Go00002_ooool2o`000003ooooool0
003o000000;ooooo0_l0000>ooooo`;o00007Oooool2o`0000Oooooo0_l00004ooooo`;o00002ooo
ool2o`0001[ooooo0_l00006ooooo`;o0000FOooool001cooooo0_l00019ooooo`;o00005oooool2
o`0000Wooooo0_l0000=ooooo`;o00004_ooool2o`0000;ooooo0_l0000Iooooo`;o00000oooool2
o`0000Cooooo0_l00002ooooo`;o00000oooool2o`0000Kooooo0_l0000>ooooo`;o00002_ooool2
o`0000?ooooo0_l000000ooooooo0000o`000002o`0000Oooooo0_l0001>ooooo`007?ooool00ol0
003oooooooooo`1Qooooo`;o00002_ooool2o`0000Sooooo0ol0000Booooo`;o000000?oooooo`00
0?l000000_ooool2o`0001Kooooo0_l00004ooooo`Co00001?ooool3o`0000Kooooo0_l00006oooo
o`;o00001_ooool2o`0000Kooooo0_l0000?ooooo`;o00000oooool2o`0000Oooooo0_l0001>oooo
o`007?ooool00ol0003oooooooooo`1Iooooo`;o000000?oooooo`000?l000000_ooool2o`0000Ko
oooo1?l000001?oooooo0000o`000?l00007ooooo`?o00004Oooool3o`000003ooooool0003o0000
01[ooooo0_l00002ooooo`Co00001Oooool4o`0000;ooooo0_l0000?ooooo`;o000000?oooooo`00
0?l00000MOooool001cooooo00?o0000ooooooooool0FOooool2o`000003ooooool0003o000000;o
oooo0_l00006ooooo`Co00000_ooool2o`0001_ooooo1?l0000Pooooo`;o00001oooool2o`0000Co
oooo0ol00004ooooo`;o00001Oooool2o`000003ooooool0003o000000Kooooo0_l0001`ooooo`00
7?ooool00ol0003oooooooooo`1Looooo`;o00002_ooool2o`0000Cooooo0ol0000;ooooo`;o0000
1?ooool2o`0000;ooooo0ol00002ooooo`Co00000oooool2o`0002_ooooo0_l00004ooooo`;o0000
1Oooool2o`0000Wooooo0_l00002ooooo`;o0000K?ooool001cooooo00?o0000ooooooooool0I?oo
ool2o`000004ooooool0003o0000o`0000Cooooo0ol000000ooooooo0000o`000002ooooo`;o0000
1?ooool2o`0000Cooooo0_l00002ooooo`?o00002Oooool2o`00027ooooo0_l0000;ooooo`;o0000
2_ooool2o`0000Wooooo1?l0001/ooooo`007?ooool00ol0003oooooooooo`1Tooooo`;o000000?o
ooooo`000?l000002Oooool3o`000003ooooool0003o000000oooooo0_l00003ooooo`;o00009ooo
ool2o`0000Kooooo0_l00003ooooo`Ko00001_ooool2o`0000;ooooo0_l00005ooooo`;o0000K_oo
ool001cooooo00?o0000ooooooooool0A_ooool2o`0001Sooooo0_l0000Aooooo`;o00005oooool2
o`0000Gooooo0_l0000Booooo`;o00002_ooool2o`0000Kooooo1?l00005ooooo`Co00002_ooool2
o`0000?ooooo0_l0001`ooooo`007?ooool00ol0003oooooooooo`16ooooo`;o00000_ooool2o`00
01?ooooo1Ol0000?ooooo`;o00003oooool2o`0000gooooo0ol0000Aooooo`;o000000?oooooo`00
0?l000001oooool2o`0000Kooooo1Ol0000Gooooo`;o00002Oooool2o`0006Gooooo000Looooo`03
o`000?oooooooooo04[ooooo0_l0000Cooooo`;o000000?oooooo`000?l000002?ooool4o`0000Go
oooo0_l0000=ooooo`;o00003_ooool2o`000003ooooool0003o0000017ooooo0_l00004ooooo`?o
00001Oooool3o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`;o00006_ooool2o`0006Go
oooo000Looooo`03o`000?oooooooooo05;ooooo0_l0000Hooooo`Ko00000oooool2o`0000Sooooo
0_l000000ooooooo0000o`00000Booooo`?o00005oooool3o`0000Gooooo0ol00006ooooo`;o0000
0oooool2o`0000Kooooo0_l0001iooooo`007?ooool00ol0003oooooooooo`1Booooo`;o00005?oo
ool2o`0000Kooooo0_l00003ooooo`;o00002?ooool2o`000003ooooool0003o000000;ooooo1?l0
0005ooooo`Co00000oooool4o`0000_ooooo0_l0000:ooooo`;o00002_ooool2o`0000?ooooo0_l0
000:ooooo`;o00004_ooool2o`0006Gooooo000Looooo`03o`000?oooooooooo06Sooooo0_l00005
ooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o00001?ooool2o`0000?ooooo1ol0
0002ooooo`Co00001Oooool2o`0000_ooooo0_l00004ooooo`;o00000oooool3o`0000Cooooo1?l0
0002ooooo`;o00000oooool2o`000003ooooool0003o000001_ooooo0_l0001Uooooo`007?ooool0
0ol0003oooooooooo`1_ooooo`;o000000?oooooo`000?l000001oooool2o`0000Cooooo0_l00006
ooooo`Co00007_ooool2o`0000?ooooo1?l00003ooooo`Co00002_ooool2o`000003ooooool0003o
000001[ooooo0_l0001Sooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0JOooool2o`0000Gooooo
1?l00006ooooo`;o00000_ooool2o`0000Oooooo0_l0000=ooooo`;o00002Oooool2o`0000_ooooo
0_l00002ooooo`Co00001Oooool2o`0000_ooooo0_l0000Jooooo`;o0000Hoooool00006oooooomg
MgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06oooo
o`03o`000?oooooooooo06Wooooo0_l00005ooooo`;o00002?ooool2o`0000;ooooo0_l00003oooo
o`;o00000_ooool2o`0000;ooooo0_l00004ooooo`;o00000oooool2o`0000Gooooo1_l0000;oooo
o`;o000000?oooooo`000?l000000ol00004ooooo`?o0000S?ooool00003ooooool@413ooooo00;o
oooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool0Joooool2o`0000Sooooo0_l0000<ooooo`;o00001_ooool2o`0000Cooooo0_l00002oooo
o`;o00001_ooool5o`0000Gooooo0_l00005ooooo`;o000000?oooooo`000?l000000_l000000ooo
oooo0000o`000002ooooo`;o0000SOooool00003ooooool0003ooooo00;ooooo00?o0000oooooooo
ool02Oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0001[ooooo`;o000000?oooooo`00
0?l000001Oooool2o`000003ooooool0003o000000Sooooo1?l0000?ooooo`;o00003?ooool2o`00
00;ooooo0_l00005ooooo`;o00000oooool2o`000003ooooool0003o000000Oooooo0_l00005oooo
o`;o0000POooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Oo<c<co
0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0K_ooool2o`0000Sooooo0_l000000ooo
oooo0000o`000002o`0000?ooooo1?l0000<ooooo`?o00003_ooool2o`0001[ooooo0_l00005oooo
o`;o0000POooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol@413o
^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0M?ooool2o`0000Gooooo1?l0000>oooo
o`;o00000oooool3o`0004Gooooo0_l0001]ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;
ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`1Nooooo`;o00005?oo
ool2o`0001Oooooo0_l0000Xooooo`;o000000?oooooo`000?l000001Oooool2o`0001Oooooo0_l0
001]ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT01_ooool00ol0003oooooooooo`1Nooooo`;o00001?ooool2o`0001Wooooo0_l0000<ooooo`Co
00004_ooool2o`0000Cooooo0_l0000<ooooo`;o000000?oooooo`000?l000001Oooool2o`0008Ko
oooo000Looooo`03o`000?oooooooooo06Cooooo0_l0000Iooooo`;o00001Oooool2o`0000Oooooo
0_l0000Booooo`?o00000oooool3o`0000Gooooo0_l0002Fooooo`007?ooool00ol0003ooooooooo
o`26ooooo`?o00000_ooool2o`0001?ooooo0_l00002ooooo`;o00001?ooool5o`0000;ooooo0_l0
002Fooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o00009Oooool2o`0000;ooooo0_l0000A
ooooo`Co00000oooool2o`000004ooooool0003o0000ooooo`Co00008?ooool2o`00013ooooo0_l0
001Vooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o00009oooool2o`0000Gooooo0_l0000<
ooooo`Co00000oooool5o`000003ooooool0003o000000;o00001_ooool2o`0001Sooooo0_l0000@
ooooo`;o0000I_ooool001cooooo00?o0000ooooooooool0ROooool4o`0000?ooooo0_l00007oooo
o`;o00001Oooool2o`0000Cooooo1?l0000;ooooo`?o0000TOooool001cooooo00?o0000oooooooo
ool0K?ooool2o`0000[ooooo0_l0000Aooooo`;o00003?ooool2o`0000Cooooo0_l000000ooooooo
0000o`000004ooooo`;o00003?ooool2o`00097ooooo000Looooo`03o`000?oooooooooo06cooooo
0_l0000:ooooo`Co00005_ooool2o`0000_ooooo0_l000000ooooooo0000o`00000Aooooo`;o0000
3oooool2o`00087ooooo000Looooo`03o`000?oooooooooo07Wooooo0ol000000ooooooo0000o`00
000Cooooo`?o00002_ooool2o`00013ooooo0_l00002ooooo`;o000000?oooooo`000?l000003?oo
ool2o`00087ooooo000Looooo`03o`000?oooooooooo07Wooooo0_l00002ooooo`;o00002Oooool2
o`0000Wooooo0_l0000:ooooo`;o00003Oooool2o`000003ooooool0003o000000Gooooo0_l0002?
ooooo`007?ooool00ol0003oooooooooo`28ooooo`;o000000?oooooo`000?l000002_ooool2o`00
00;ooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000Cooooo0_l00002
ooooo`;o0000VOooool001cooooo00?o0000ooooooooool0O_ooool2o`0000_ooooo0_l0000:oooo
o`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000001?ooool2
o`0009gooooo000Looooo`;o0000Ooooool4o`0001Gooooo0_l0000>ooooo`;o0000X?ooool001co
oooo00?o0000ooooooooool0MOooool2o`0000Wooooo0_l0000Eooooo`;o00001Oooool2o`0000Oo
oooo0_l0002Pooooo`007?ooool00ol0003oooooooooo`1eooooo`;o00009oooool2o`000:Wooooo
000Looooo`03o`000?oooooooooo08kooooo0_l0000Aooooo`;o0000Y_ooool001cooooo00?o0000
ooooooooool0S_ooool2o`00017ooooo0_l0002Vooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo09kooooo0_l0000=ooooo`;o00003?ooool2o`0008co
oooo000Looooo`03o`000?oooooooooo08cooooo0_l0000@ooooo`;o00003Oooool2o`0000;ooooo
0_l00008ooooo`;o0000S?ooool001cooooo00?o0000ooooooooool0S?ooool2o`0002?ooooo0_l0
002Fooooo`007?ooool00ol0003oooooooooo`2Nooooo`;o0000ZOooool001cooooo00?o0000oooo
ooooool0W_ooool2o`000:Wooooo000Looooo`03o`000?oooooooooo0:;ooooo0_l0002Uooooo`00
7?ooool00ol0003oooooooooo`2Rooooo`;o0000YOooool001cooooo00?o0000ooooooooool0X_oo
ool2o`000:Gooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool2o`000:Sooooo0_l0002Pooooo`007?ooool00ol0003ooooo
ooooo`2Wooooo`;o0000X?ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000
oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Booooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooood[o
oooo000Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`005?oo
ool00ol0003oooooooooo`05ooooo`?o0000oooooom:ooooo`005?ooool00ol0003oooooooooo`3o
oooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000oooooooo
ool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Booooo`03oeEEEOmV
IVKo00000?ooooooE?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:7ooooo
00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0Fooooo`Co000000?o410@oooooooo
ool01Ol00003ooooo`Go00001Oooool2o`000003oa0@4?oooooooooo08[ooooo002Rooooo`05o`00
0?ooooooooooooooool000002Oooool6o`0000cooooo00?o0000ooooooooool00_ooool01OnHV9So
8B4Qonk^k_ooooooA4A400?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooo
oooo08_ooooo002Rooooo`05o`000?ooooooooooooooool000006oooool00ol0003oooooooooo`03
ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?oV9RHob4Q8Oo^k^h01?ooool5o`0008cooooo002Roooo
o`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo00?o0000ooooooooool01?ooool0
0onHV9So8B4Qonk^kP05ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00CoA4A4omgMgOoooooo0000SOoo
ool00:;ooooo00Go0000ohN7QoooooooZJVYo`00000Kooooo`03o`000?oooooooooo00Gooooo00?o
MgMgofIVI_ooool01Oooool00omgMgOoIVIVooooo`02ooooo`04omgMgOmEEEGoooooo`0008gooooo
002Qooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool06Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00omgMgOoc<c<o`00
002=ooooo`00`_ooool00ol0003oooooooooo`02ooooo`05o`000?nj^[[ooooooiRHV?l@41000ooo
ool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?ok^k^odA4A?l00000SOooool00<3ooooo00?o
EEEEofIVI_l000001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c005ooooo`03ogMgMol0003ooooo08cooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1230) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.66458 .45228 Mdot
.64897 .49903 Mdot
.3644 .40609 Mdot
.54847 .60596 Mdot
.42723 .20721 Mdot
.39379 .4072 Mdot
.58768 .35807 Mdot
.53543 .36913 Mdot
.37527 .38732 Mdot
.66686 .29599 Mdot
.57652 .37323 Mdot
.48182 .57597 Mdot
.55104 .36417 Mdot
.55398 .63194 Mdot
.43513 .14981 Mdot
.534 .70004 Mdot
.64469 .47471 Mdot
.29107 .54675 Mdot
.58198 .59424 Mdot
.35999 .37541 Mdot
.65815 .5457 Mdot
.54704 .62823 Mdot
.67783 .51734 Mdot
.55437 .63263 Mdot
.51994 .61041 Mdot
.69214 .48357 Mdot
.7136 .46913 Mdot
.50445 .63798 Mdot
.49092 .63777 Mdot
.54004 .37438 Mdot
.35875 .66389 Mdot
.41115 .1796 Mdot
.55703 .56732 Mdot
.20638 .4108 Mdot
.53381 .3443 Mdot
.68002 .68935 Mdot
.38115 .40921 Mdot
.56022 .34785 Mdot
.5631 .34417 Mdot
.55125 .32375 Mdot
.5692 .36093 Mdot
.68455 .5008 Mdot
.61571 .34294 Mdot
.36165 .47788 Mdot
.5472 .69057 Mdot
.53356 .227 Mdot
.73085 .70637 Mdot
.5325 .67745 Mdot
.65644 .46576 Mdot
.25308 .41453 Mdot
.42541 .27067 Mdot
.56869 .33072 Mdot
.3761 .35887 Mdot
.28713 .80696 Mdot
.54562 .34302 Mdot
.60205 .6152 Mdot
.37207 .41015 Mdot
.54151 .6409 Mdot
.55547 .63776 Mdot
.64904 .60254 Mdot
.54908 .68108 Mdot
.33971 .57013 Mdot
.62456 .48175 Mdot
.56895 .46995 Mdot
.37827 .39313 Mdot
.57516 .35385 Mdot
.65844 .50818 Mdot
.54378 .35864 Mdot
.53156 .71712 Mdot
.35524 .37859 Mdot
.52803 .67877 Mdot
.57744 .36482 Mdot
.64073 .4685 Mdot
.50663 .65949 Mdot
.26517 .5142 Mdot
.69941 .25431 Mdot
.36545 .53501 Mdot
.67515 .65755 Mdot
.63854 .63608 Mdot
.28407 .44141 Mdot
.55447 .59069 Mdot
.42517 .70246 Mdot
.64182 .22598 Mdot
.6833 .51915 Mdot
.47517 .66321 Mdot
.31453 .6055 Mdot
.50989 .65837 Mdot
.56263 .20973 Mdot
.48985 .66107 Mdot
.24315 .55025 Mdot
.38906 .38096 Mdot
.66127 .48505 Mdot
.54934 .60389 Mdot
.4967 .6572 Mdot
.54315 .76403 Mdot
.55804 .57336 Mdot
.52687 .62929 Mdot
.6771 .46166 Mdot
.56241 .32969 Mdot
.58158 .57168 Mdot
.36584 .47384 Mdot
.42002 .38546 Mdot
.57704 .6318 Mdot
.41449 .41578 Mdot
.62616 .49916 Mdot
.50304 .66189 Mdot
.56015 .33902 Mdot
.57347 .64096 Mdot
.73259 .43023 Mdot
.64554 .50138 Mdot
.49923 .64203 Mdot
.34592 .53924 Mdot
.48431 .81508 Mdot
.65409 .48006 Mdot
.31931 .43677 Mdot
.53291 .58965 Mdot
.52636 .63892 Mdot
.65213 .4979 Mdot
.41209 .43446 Mdot
.5832 .2114 Mdot
.70323 .49608 Mdot
.53243 .33171 Mdot
.67155 .44844 Mdot
.49522 .70065 Mdot
.39423 .38767 Mdot
.34562 .30755 Mdot
.64151 .40583 Mdot
.37038 .63866 Mdot
.51517 .6588 Mdot
.66346 .33382 Mdot
.39657 .37367 Mdot
.66803 .49361 Mdot
.5435 .3634 Mdot
.47836 .59 Mdot
.64525 .52067 Mdot
.56736 .38167 Mdot
.35362 .54942 Mdot
.45718 .31055 Mdot
.63241 .51565 Mdot
.40723 .49837 Mdot
.58042 .38908 Mdot
.56586 .32714 Mdot
.18288 .50414 Mdot
.66112 .50553 Mdot
.3378 .55228 Mdot
.53865 .36539 Mdot
.34214 .63832 Mdot
.55537 .68453 Mdot
.40766 .71726 Mdot
.72866 .72529 Mdot
.19782 .42943 Mdot
.47686 .32132 Mdot
.3106 .56196 Mdot
.51962 .35222 Mdot
.52304 .61605 Mdot
.68759 .47365 Mdot
.69078 .49794 Mdot
.55773 .67503 Mdot
.53936 .60002 Mdot
.51789 .67873 Mdot
.49643 .6619 Mdot
.73815 .52246 Mdot
.5573 .57893 Mdot
.6641 .75949 Mdot
.66175 .48053 Mdot
.5371 .61052 Mdot
.38799 .43936 Mdot
.50028 .58973 Mdot
.57343 .36175 Mdot
.54067 .63397 Mdot
.54637 .60563 Mdot
.56032 .67629 Mdot
.56349 .32865 Mdot
.47406 .15944 Mdot
.55548 .78031 Mdot
.41726 .19194 Mdot
.25852 .55543 Mdot
.40459 .42066 Mdot
.51297 .65078 Mdot
.34745 .55041 Mdot
.7229 .6465 Mdot
.56341 .61121 Mdot
.68947 .8073 Mdot
.53449 .62664 Mdot
.43578 .19568 Mdot
.59815 .65209 Mdot
.32491 .23614 Mdot
.40906 .6946 Mdot
.51288 .62327 Mdot
.55917 .49783 Mdot
.5944 .42258 Mdot
.34452 .44486 Mdot
.56594 .3616 Mdot
.38504 .43912 Mdot
.36702 .4113 Mdot
.61355 .3608 Mdot
.61327 .55065 Mdot
.61252 .61356 Mdot
.47967 .6309 Mdot
.3555 .37424 Mdot
.62133 .50302 Mdot
.34399 .57545 Mdot
.69076 .46076 Mdot
.66106 .18314 Mdot
.46926 .2434 Mdot
.58149 .3985 Mdot
.30681 .58061 Mdot
.37433 .37751 Mdot
.42193 .39461 Mdot
.32456 .53556 Mdot
.54235 .66296 Mdot
.66561 .50864 Mdot
.18323 .42306 Mdot
.76316 .43282 Mdot
.16962 .50207 Mdot
.67238 .46171 Mdot
.70409 .34069 Mdot
.56185 .37906 Mdot
.38431 .42426 Mdot
.5259 .6362 Mdot
.53781 .65973 Mdot
.65726 .54334 Mdot
.51872 .67771 Mdot
.48283 .56175 Mdot
.51774 .63377 Mdot
.40381 .29589 Mdot
.35627 .52416 Mdot
.61363 .36289 Mdot
.38376 .61907 Mdot
.69521 .50255 Mdot
.36413 .74713 Mdot
.41843 .4099 Mdot
.71419 .64552 Mdot
.58138 .36224 Mdot
.35186 .56034 Mdot
.41643 .39396 Mdot
.35649 .56488 Mdot
.57344 .58408 Mdot
.36623 .43446 Mdot
.32022 .53349 Mdot
.62206 .64001 Mdot
.51141 .68851 Mdot
.7649 .46935 Mdot
.53856 .33162 Mdot
.70768 .48503 Mdot
.53839 .68397 Mdot
.4052 .42584 Mdot
.49759 .57835 Mdot
.5329 .28054 Mdot
.36011 .30915 Mdot
.42886 .39554 Mdot
.35092 .32975 Mdot
.33657 .57491 Mdot
.52297 .26175 Mdot
.69136 .34568 Mdot
.64991 .46588 Mdot
.55404 .57478 Mdot
.30506 .24168 Mdot
.5385 .36471 Mdot
.56919 .64715 Mdot
.25104 .35743 Mdot
.53829 .35106 Mdot
.54033 .64312 Mdot
.52996 .36727 Mdot
.68983 .50002 Mdot
.49367 .79799 Mdot
.6489 .47037 Mdot
.48556 .65074 Mdot
.55669 .33618 Mdot
.38838 .44647 Mdot
.68663 .47836 Mdot
.5471 .66497 Mdot
.50654 .64182 Mdot
.53173 .45187 Mdot
.53251 .61667 Mdot
.46903 .16908 Mdot
.51433 .62917 Mdot
.37265 .4273 Mdot
.58022 .62109 Mdot
.41286 .8361 Mdot
.61027 .31041 Mdot
.66014 .50827 Mdot
.41297 .43715 Mdot
.371 .39527 Mdot
.34525 .47857 Mdot
.59011 .40616 Mdot
.54907 .58399 Mdot
.40622 .4213 Mdot
.41094 .75662 Mdot
.581 .38346 Mdot
.54751 .57128 Mdot
.42003 .50143 Mdot
.24514 .43567 Mdot
.37574 .35985 Mdot
.55878 .5635 Mdot
.62957 .51292 Mdot
.54837 .60183 Mdot
.42497 .40866 Mdot
.7002 .53181 Mdot
.50804 .60884 Mdot
.61987 .54149 Mdot
.53287 .45041 Mdot
.58866 .37273 Mdot
.6021 .64449 Mdot
.56387 .65793 Mdot
.39001 .43365 Mdot
.69834 .49481 Mdot
.57812 .38623 Mdot
.68767 .49177 Mdot
.28521 .28472 Mdot
.72974 .43685 Mdot
.63064 .59456 Mdot
.2969 .57827 Mdot
.23575 .4188 Mdot
.29756 .25834 Mdot
.31109 .73589 Mdot
.34206 .71708 Mdot
.21914 .35208 Mdot
.40937 .43399 Mdot
.25249 .36861 Mdot
.36915 .40305 Mdot
.52768 .60041 Mdot
.39038 .38897 Mdot
.29248 .25786 Mdot
.51936 .63263 Mdot
.38868 .39486 Mdot
.39778 .77022 Mdot
.54104 .6048 Mdot
.64428 .48515 Mdot
.55649 .17212 Mdot
.35253 .78598 Mdot
.36852 .30648 Mdot
.35644 .4013 Mdot
.308 .67698 Mdot
.52612 .62721 Mdot
.57972 .61132 Mdot
.66764 .46843 Mdot
.53763 .57002 Mdot
.32101 .57647 Mdot
.30437 .57815 Mdot
.54116 .41168 Mdot
.45185 .71619 Mdot
.60051 .63993 Mdot
.68227 .47476 Mdot
.7501 .51789 Mdot
.25016 .51577 Mdot
.25403 .40456 Mdot
.54186 .38442 Mdot
.5496 .17344 Mdot
.46092 .5881 Mdot
.54923 .30162 Mdot
.33033 .41604 Mdot
.65012 .48729 Mdot
.45428 .16459 Mdot
.5623 .35832 Mdot
.80171 .54999 Mdot
.42986 .55856 Mdot
.54457 .65971 Mdot
.58438 .36031 Mdot
.57284 .5493 Mdot
.33036 .77382 Mdot
.8208 .53458 Mdot
.4299 .64736 Mdot
.48457 .65445 Mdot
.27486 .5166 Mdot
.53472 .63558 Mdot
.60649 .2359 Mdot
.51101 .63127 Mdot
.68515 .48681 Mdot
.64248 .27651 Mdot
.55534 .42971 Mdot
.58538 .78432 Mdot
.54823 .25512 Mdot
.31072 .56295 Mdot
.52006 .63781 Mdot
.54689 .65873 Mdot
.31957 .57363 Mdot
.64603 .53197 Mdot
.49692 .66521 Mdot
.34735 .73512 Mdot
.51256 .66744 Mdot
.56738 .35503 Mdot
.43122 .60919 Mdot
.62838 .45031 Mdot
.48697 .62183 Mdot
.63132 .47571 Mdot
.59158 .36965 Mdot
.55156 .33954 Mdot
.59546 .64991 Mdot
.55293 .32185 Mdot
.54133 .62084 Mdot
.82915 .52796 Mdot
.6326 .50849 Mdot
.54556 .53 Mdot
.665 .52016 Mdot
.66684 .66299 Mdot
.54234 .33775 Mdot
.42166 .28269 Mdot
.48199 .57948 Mdot
.55977 .36008 Mdot
.73079 .44434 Mdot
.55298 .6935 Mdot
.49474 .68193 Mdot
.2173 .55979 Mdot
.35895 .40413 Mdot
.5532 .44903 Mdot
.53466 .36988 Mdot
.55469 .66451 Mdot
.51238 .59564 Mdot
.59242 .36613 Mdot
.80177 .48507 Mdot
.38442 .78397 Mdot
.51621 .63115 Mdot
.67702 .48335 Mdot
.67114 .49481 Mdot
.48602 .66644 Mdot
.57333 .60881 Mdot
.40597 .39199 Mdot
.38717 .44917 Mdot
.35627 .4226 Mdot
.5354 .44897 Mdot
.41157 .28686 Mdot
.43015 .22821 Mdot
.55229 .32356 Mdot
.69382 .37084 Mdot
.24692 .55988 Mdot
.48631 .6123 Mdot
.369 .3713 Mdot
.566 .64657 Mdot
.54861 .61335 Mdot
.59465 .37646 Mdot
.30847 .31255 Mdot
.54535 .54783 Mdot
.64353 .53422 Mdot
.56099 .38794 Mdot
.4798 .69437 Mdot
.6006 .28531 Mdot
.34889 .54635 Mdot
.19756 .50197 Mdot
.57902 .36131 Mdot
.64537 .48748 Mdot
.53021 .34382 Mdot
.53072 .66386 Mdot
.59215 .60701 Mdot
.65448 .49297 Mdot
.30027 .55911 Mdot
.50145 .57768 Mdot
.53712 .64363 Mdot
.69436 .76848 Mdot
.24576 .5841 Mdot
.41174 .30144 Mdot
.51406 .62461 Mdot
.49205 .61749 Mdot
.34664 .53155 Mdot
.51797 .6683 Mdot
.51949 .68275 Mdot
.51377 .80127 Mdot
.66206 .4023 Mdot
.29599 .56867 Mdot
.81843 .50371 Mdot
.66784 .46064 Mdot
.35343 .21062 Mdot
.38823 .42843 Mdot
.53625 .38962 Mdot
.41484 .80081 Mdot
.37584 .35794 Mdot
.47907 .32654 Mdot
.38123 .19641 Mdot
.55299 .4469 Mdot
.39413 .34243 Mdot
.46901 .58539 Mdot
.50021 .66637 Mdot
.52945 .64106 Mdot
.3457 .55744 Mdot
.67035 .50798 Mdot
.54507 .4581 Mdot
.78738 .36579 Mdot
.54335 .62794 Mdot
.50285 .54356 Mdot
.76028 .37048 Mdot
.24658 .43956 Mdot
.31894 .5508 Mdot
.29994 .5684 Mdot
.5217 .64021 Mdot
.4984 .81552 Mdot
.69151 .48147 Mdot
.54855 .66419 Mdot
.54652 .5803 Mdot
.35785 .40914 Mdot
.64077 .5048 Mdot
.4172 .42699 Mdot
.4503 .26867 Mdot
.42023 .19527 Mdot
.72231 .75546 Mdot
.54547 .33821 Mdot
.66685 .25905 Mdot
.55097 .38171 Mdot
.42146 .69172 Mdot
.41607 .37982 Mdot
.56027 .59977 Mdot
.69599 .49975 Mdot
.55917 .65927 Mdot
.57055 .6034 Mdot
.54468 .66176 Mdot
.49653 .60539 Mdot
.59349 .84746 Mdot
.30905 .54183 Mdot
.50643 .70194 Mdot
.36764 .42166 Mdot
.59931 .21809 Mdot
.69344 .25533 Mdot
.55025 .65412 Mdot
.51126 .64073 Mdot
.63765 .52063 Mdot
.56276 .66808 Mdot
.56519 .38459 Mdot
.70291 .4795 Mdot
.49645 .65374 Mdot
.56863 .18635 Mdot
.49392 .63965 Mdot
.36027 .21657 Mdot
.52791 .352 Mdot
.74761 .43572 Mdot
.52082 .707 Mdot
.36778 .31145 Mdot
.55315 .44911 Mdot
.41182 .39132 Mdot
.53971 .32157 Mdot
.38119 .40609 Mdot
.80962 .39768 Mdot
.59214 .62433 Mdot
.52276 .61383 Mdot
.51828 .58722 Mdot
.40363 .42282 Mdot
.53586 .20611 Mdot
.51663 .2542 Mdot
.47975 .68984 Mdot
.40411 .41399 Mdot
.62599 .48301 Mdot
.30571 .62561 Mdot
.67409 .51565 Mdot
.31566 .58753 Mdot
.57239 .37386 Mdot
.30379 .56834 Mdot
.24342 .35578 Mdot
.64668 .49904 Mdot
.70983 .49791 Mdot
.3905 .42255 Mdot
.43499 .52988 Mdot
.16897 .63748 Mdot
.43206 .5509 Mdot
.38839 .66835 Mdot
.66994 .47101 Mdot
.48856 .63386 Mdot
.4165 .64709 Mdot
.46056 .51523 Mdot
.38039 .40369 Mdot
.55972 .61474 Mdot
.48 .80057 Mdot
.40628 .39203 Mdot
.55062 .57232 Mdot
.36204 .41403 Mdot
.56969 .36772 Mdot
.37252 .3727 Mdot
.66651 .53476 Mdot
.50392 .6524 Mdot
.1478 .58 Mdot
.36766 .52972 Mdot
.52264 .62478 Mdot
.55694 .38743 Mdot
.50414 .38091 Mdot
.57113 .62118 Mdot
.35554 .54485 Mdot
.39796 .39731 Mdot
.42133 .55721 Mdot
.51404 .63129 Mdot
.40193 .42229 Mdot
.66677 .45127 Mdot
.52526 .33366 Mdot
.60537 .70672 Mdot
.3788 .31343 Mdot
.66792 .46742 Mdot
.39386 .48835 Mdot
.56805 .32066 Mdot
.49218 .61643 Mdot
.54922 .5757 Mdot
.67629 .48754 Mdot
.48653 .76723 Mdot
.57951 .64599 Mdot
.55491 .5913 Mdot
.37113 .42983 Mdot
.3854 .40308 Mdot
.48517 .78127 Mdot
.39971 .44311 Mdot
.59211 .6098 Mdot
.67824 .48857 Mdot
.55232 .60399 Mdot
.63576 .51035 Mdot
.5659 .66268 Mdot
.72243 .4952 Mdot
.64981 .53198 Mdot
.6011 .30078 Mdot
.55575 .61235 Mdot
.6069 .58898 Mdot
.5722 .63942 Mdot
.51094 .67233 Mdot
.40324 .38776 Mdot
.32791 .54202 Mdot
.57904 .57768 Mdot
.36594 .56458 Mdot
.35552 .56529 Mdot
.59134 .41935 Mdot
.35786 .40454 Mdot
.33452 .56095 Mdot
.76849 .37479 Mdot
.35685 .42085 Mdot
.3378 .56903 Mdot
.68808 .25297 Mdot
.53571 .34213 Mdot
.63008 .5082 Mdot
.54057 .60366 Mdot
.24657 .33301 Mdot
.73005 .70953 Mdot
.34992 .44361 Mdot
.51632 .62782 Mdot
.56954 .63877 Mdot
.69736 .50671 Mdot
.83551 .4176 Mdot
.35407 .38315 Mdot
.5004 .6206 Mdot
.65314 .50914 Mdot
.85889 .47508 Mdot
.37247 .42237 Mdot
.3413 .56583 Mdot
.54901 .32667 Mdot
.6224 .5384 Mdot
.64056 .40721 Mdot
.58865 .36428 Mdot
.34129 .38382 Mdot
.42158 .27448 Mdot
.53334 .58909 Mdot
.37476 .36824 Mdot
.19005 .53495 Mdot
.75223 .48464 Mdot
.60593 .41802 Mdot
.29895 .66703 Mdot
.65192 .4854 Mdot
.55904 .38344 Mdot
.30707 .55441 Mdot
.67789 .46366 Mdot
.64258 .48368 Mdot
.59687 .36774 Mdot
.59486 .74336 Mdot
.41942 .50396 Mdot
.56508 .34837 Mdot
.22774 .55088 Mdot
.3498 .27574 Mdot
.36832 .371 Mdot
.32216 .57614 Mdot
.25523 .33926 Mdot
.68587 .49935 Mdot
.54184 .17001 Mdot
.19675 .52793 Mdot
.52705 .62915 Mdot
.33272 .55683 Mdot
.5042 .20944 Mdot
.7944 .35188 Mdot
.53976 .34803 Mdot
.54158 .42643 Mdot
.31719 .57864 Mdot
.54304 .68241 Mdot
.31968 .63416 Mdot
.55162 .59295 Mdot
.56735 .37729 Mdot
.64169 .6058 Mdot
.64341 .48904 Mdot
.59908 .36223 Mdot
.19612 .50193 Mdot
.54301 .62154 Mdot
.55766 .61152 Mdot
.39178 .60431 Mdot
.69828 .47974 Mdot
.41225 .3919 Mdot
.54003 .58484 Mdot
.53844 .63969 Mdot
.5964 .59793 Mdot
.60554 .63414 Mdot
.48045 .81101 Mdot
.51323 .61063 Mdot
.51609 .24332 Mdot
.47971 .64285 Mdot
.55558 .62023 Mdot
.62924 .47989 Mdot
.7107 .77267 Mdot
.46088 .26139 Mdot
.53934 .63582 Mdot
.49159 .62801 Mdot
.59583 .35044 Mdot
.4375 .50447 Mdot
.43111 .52801 Mdot
.4186 .55472 Mdot
.32682 .69933 Mdot
.47666 .65024 Mdot
.66127 .51338 Mdot
.32673 .53195 Mdot
.50828 .60662 Mdot
.65773 .51315 Mdot
.56246 .67744 Mdot
.40735 .39402 Mdot
.35873 .42589 Mdot
.73654 .46445 Mdot
.32955 .5656 Mdot
.45553 .56003 Mdot
.6827 .37099 Mdot
.38022 .43881 Mdot
.52283 .61175 Mdot
.5757 .40215 Mdot
.42469 .40611 Mdot
.33575 .34333 Mdot
.5888 .70981 Mdot
.69433 .48048 Mdot
.66003 .48256 Mdot
.41082 .72263 Mdot
.47434 .30735 Mdot
.61317 .79827 Mdot
.57047 .369 Mdot
.58566 .62637 Mdot
.67629 .33156 Mdot
.65734 .48093 Mdot
.415 .66255 Mdot
.33202 .56067 Mdot
.53718 .35087 Mdot
.4493 .37894 Mdot
.64223 .52208 Mdot
.64081 .48048 Mdot
.49398 .66872 Mdot
.54078 .64952 Mdot
.35141 .72525 Mdot
.27296 .56448 Mdot
.5897 .37344 Mdot
.32476 .57673 Mdot
.40979 .37692 Mdot
.50866 .61282 Mdot
.67605 .51969 Mdot
.34205 .29217 Mdot
.50075 .61628 Mdot
.40187 .38354 Mdot
.6556 .4871 Mdot
.33243 .57744 Mdot
.35984 .54973 Mdot
.51039 .67057 Mdot
.72543 .54447 Mdot
.55669 .3496 Mdot
.64697 .48326 Mdot
.60057 .28824 Mdot
.57837 .6101 Mdot
.53246 .65212 Mdot
.57723 .69769 Mdot
.58828 .38096 Mdot
.73968 .38684 Mdot
.3238 .58523 Mdot
.66827 .50449 Mdot
.50742 .62338 Mdot
.33053 .57194 Mdot
.71754 .36304 Mdot
.42847 .39313 Mdot
.37275 .37418 Mdot
.35627 .54348 Mdot
.32453 .55388 Mdot
.35695 .55058 Mdot
.54272 .16935 Mdot
.68071 .52345 Mdot
.46163 .58849 Mdot
.58275 .63722 Mdot
.40108 .68803 Mdot
.46763 .61062 Mdot
.5785 .3881 Mdot
.35985 .40103 Mdot
.57346 .6203 Mdot
.48542 .64343 Mdot
.57179 .69162 Mdot
.53601 .53589 Mdot
.64508 .43633 Mdot
.64351 .50201 Mdot
.58722 .64658 Mdot
.36046 .42074 Mdot
.67621 .18736 Mdot
.19765 .35079 Mdot
.53291 .70753 Mdot
.40929 .51565 Mdot
.67666 .52021 Mdot
.57709 .32974 Mdot
.38878 .5811 Mdot
.53712 .33766 Mdot
.66697 .50113 Mdot
.51208 .61083 Mdot
.69386 .37719 Mdot
.35379 .53761 Mdot
.54335 .67268 Mdot
.55221 .37728 Mdot
.53367 .67828 Mdot
.58839 .36201 Mdot
.29499 .27134 Mdot
.2393 .6214 Mdot
.53336 .6274 Mdot
.49563 .69184 Mdot
.29577 .67698 Mdot
.55375 .65258 Mdot
.27424 .54902 Mdot
.67506 .52149 Mdot
.52918 .77111 Mdot
.52158 .69488 Mdot
.75513 .5666 Mdot
.57593 .59976 Mdot
.4422 .78637 Mdot
.53376 .65427 Mdot
.24276 .45618 Mdot
.50028 .64561 Mdot
.51132 .67828 Mdot
.55079 .33507 Mdot
.59748 .35649 Mdot
.64174 .46567 Mdot
.40835 .4206 Mdot
.38984 .20036 Mdot
.53502 .64678 Mdot
.35668 .30772 Mdot
.70555 .40016 Mdot
.32222 .55386 Mdot
.67093 .50214 Mdot
.83903 .40309 Mdot
.52512 .35637 Mdot
.25167 .59972 Mdot
.44752 .77741 Mdot
.62566 .37862 Mdot
.32527 .60725 Mdot
.63467 .26655 Mdot
.34091 .57247 Mdot
.56316 .67342 Mdot
.32531 .30373 Mdot
.23677 .48077 Mdot
.59103 .70819 Mdot
.57535 .32346 Mdot
.73033 .62567 Mdot
.31847 .30124 Mdot
.34492 .58025 Mdot
.30797 .57627 Mdot
.57857 .33625 Mdot
.44748 .38787 Mdot
.56451 .54779 Mdot
.32849 .56035 Mdot
.38466 .44298 Mdot
.35401 .39481 Mdot
.3756 .35526 Mdot
.69332 .4887 Mdot
.18442 .46758 Mdot
.60216 .27912 Mdot
.58822 .36825 Mdot
.43786 .38555 Mdot
.66606 .43777 Mdot
.68671 .52304 Mdot
.38561 .41769 Mdot
.39597 .3788 Mdot
.63748 .53212 Mdot
.60001 .62739 Mdot
.57532 .68374 Mdot
.54086 .63118 Mdot
.34334 .545 Mdot
.53856 .65525 Mdot
.40457 .40595 Mdot
.54188 .34997 Mdot
.38509 .37711 Mdot
.53691 .37849 Mdot
.45148 .22632 Mdot
.53635 .67039 Mdot
.50321 .64932 Mdot
.75724 .6859 Mdot
.656 .45509 Mdot
.50028 .23667 Mdot
.39368 .3153 Mdot
.36791 .40627 Mdot
.52349 .68352 Mdot
.70402 .48154 Mdot
.34329 .58422 Mdot
.77546 .66808 Mdot
.57606 .61982 Mdot
.6719 .52089 Mdot
.5054 .62099 Mdot
.72692 .52999 Mdot
.47032 .8425 Mdot
.68353 .49446 Mdot
.72781 .72479 Mdot
.49112 .63411 Mdot
.70287 .29905 Mdot
.52513 .58106 Mdot
.4142 .74811 Mdot
.57955 .64526 Mdot
.67002 .46079 Mdot
.54356 .63355 Mdot
.70077 .47365 Mdot
.38392 .43643 Mdot
.56982 .32668 Mdot
.66224 .47125 Mdot
.5422 .57719 Mdot
.10245 .43438 Mdot
.56307 .375 Mdot
.52323 .63735 Mdot
.55092 .32927 Mdot
.67026 .51146 Mdot
.65548 .46847 Mdot
.77141 .32986 Mdot
.45826 .26785 Mdot
.56852 .36722 Mdot
.50741 .61546 Mdot
.59768 .2587 Mdot
.55126 .5973 Mdot
.37226 .72378 Mdot
.60266 .61059 Mdot
.58118 .62734 Mdot
.70608 .26067 Mdot
.58764 .37906 Mdot
.59426 .80543 Mdot
.76242 .31336 Mdot
.60576 .21764 Mdot
.63485 .54842 Mdot
.34453 .58139 Mdot
.4634 .16209 Mdot
.41806 .285 Mdot
.40362 .41841 Mdot
.57333 .63011 Mdot
.63518 .44828 Mdot
.55576 .3444 Mdot
.32771 .54011 Mdot
.53251 .62831 Mdot
.39111 .37601 Mdot
.34198 .75974 Mdot
.5212 .3598 Mdot
.68253 .50219 Mdot
.65186 .53411 Mdot
.84347 .57151 Mdot
.51121 .62424 Mdot
.50109 .65324 Mdot
.57095 .37561 Mdot
.7485 .36811 Mdot
.34664 .56998 Mdot
.38087 .76534 Mdot
.56723 .36784 Mdot
.50413 .47017 Mdot
.65481 .50527 Mdot
.56882 .6415 Mdot
.50716 .19404 Mdot
.28175 .50718 Mdot
.79133 .58889 Mdot
.34686 .55003 Mdot
.36644 .71679 Mdot
.66753 .46014 Mdot
.54171 .36495 Mdot
.45456 .32828 Mdot
.47487 .62558 Mdot
.56545 .64292 Mdot
.36985 .71466 Mdot
.57095 .42804 Mdot
.42888 .63784 Mdot
.57631 .6136 Mdot
.56987 .44415 Mdot
.5772 .64315 Mdot
.4704 .62865 Mdot
.5966 .61541 Mdot
.52169 .65671 Mdot
.67382 .52075 Mdot
.52457 .72388 Mdot
.41076 .40196 Mdot
.44857 .59447 Mdot
.5107 .47616 Mdot
.52007 .62804 Mdot
.54035 .59212 Mdot
.76381 .63219 Mdot
.48953 .34305 Mdot
.66122 .47458 Mdot
.68772 .52992 Mdot
.54282 .32457 Mdot
.57376 .68716 Mdot
.41248 .41351 Mdot
.47065 .60979 Mdot
.40059 .3853 Mdot
.67995 .51557 Mdot
.36873 .4131 Mdot
.55685 .32539 Mdot
.35895 .38225 Mdot
.41046 .28696 Mdot
.53633 .36519 Mdot
.68732 .47228 Mdot
.50751 .66124 Mdot
.55583 .38687 Mdot
.3685 .62843 Mdot
.3442 .5465 Mdot
.75844 .29723 Mdot
.49522 .6522 Mdot
.6578 .40542 Mdot
.63393 .5561 Mdot
.39011 .37787 Mdot
.49806 .8315 Mdot
.6486 .53371 Mdot
.29614 .56073 Mdot
.6937 .50574 Mdot
.23087 .57282 Mdot
.32985 .54606 Mdot
.67636 .24015 Mdot
.38526 .32813 Mdot
.2692 .5998 Mdot
.5929 .65017 Mdot
.35221 .61423 Mdot
.38114 .36165 Mdot
.55426 .34384 Mdot
.46624 .33204 Mdot
.51961 .68189 Mdot
.27424 .69276 Mdot
.62467 .50859 Mdot
.40882 .41764 Mdot
.54474 .36134 Mdot
.57466 .38736 Mdot
.56688 .58827 Mdot
.27876 .40199 Mdot
.5608 .6631 Mdot
.47141 .29357 Mdot
.33509 .70149 Mdot
.56363 .54128 Mdot
.51823 .63409 Mdot
.38872 .43452 Mdot
.50555 .62069 Mdot
.29006 .56375 Mdot
.17706 .47615 Mdot
.51566 .57461 Mdot
.40018 .31244 Mdot
.37291 .53616 Mdot
.65135 .495 Mdot
.5858 .55848 Mdot
.42294 .29058 Mdot
.51082 .621 Mdot
.48725 .8834 Mdot
.33471 .57054 Mdot
.31969 .3134 Mdot
.50543 .59955 Mdot
.55611 .58296 Mdot
.56903 .48061 Mdot
.62241 .42169 Mdot
.28398 .50934 Mdot
.55774 .64458 Mdot
.33575 .66882 Mdot
.58172 .3449 Mdot
.56801 .65564 Mdot
.52722 .64081 Mdot
.62871 .73241 Mdot
.56252 .38656 Mdot
.36763 .39555 Mdot
.38405 .35988 Mdot
.36916 .45304 Mdot
.29094 .55888 Mdot
.52767 .43058 Mdot
.40714 .66601 Mdot
.33508 .76876 Mdot
.30514 .53682 Mdot
.49298 .65609 Mdot
.32793 .51048 Mdot
.52313 .60138 Mdot
.3124 .54998 Mdot
.55625 .38483 Mdot
.65818 .47382 Mdot
.68838 .32943 Mdot
.35799 .37349 Mdot
.54459 .57119 Mdot
.33542 .57926 Mdot
.6897 .47529 Mdot
.27771 .59519 Mdot
.65614 .50028 Mdot
.56058 .36495 Mdot
.51571 .35722 Mdot
.32111 .54177 Mdot
.66672 .51703 Mdot
.56946 .30794 Mdot
.79679 .36332 Mdot
.59429 .60457 Mdot
.51366 .36982 Mdot
.67185 .45433 Mdot
.66879 .54029 Mdot
.68527 .46224 Mdot
.52242 .67762 Mdot
.40948 .5145 Mdot
.55416 .68839 Mdot
.5888 .37383 Mdot
.36207 .40881 Mdot
.3002 .69578 Mdot
.40906 .25528 Mdot
.36554 .49742 Mdot
.58661 .63122 Mdot
.54534 .62168 Mdot
.52202 .6401 Mdot
.512 .69311 Mdot
.45263 .29959 Mdot
.5616 .65643 Mdot
.55327 .33415 Mdot
.40067 .39721 Mdot
.56225 .67468 Mdot
.40619 .36823 Mdot
.588 .22397 Mdot
.30555 .53792 Mdot
.52471 .4209 Mdot
.21103 .29394 Mdot
.6811 .47028 Mdot
.41731 .43044 Mdot
.40104 .42096 Mdot
.35389 .55065 Mdot
.56141 .34976 Mdot
.65823 .5037 Mdot
.39509 .74785 Mdot
.35779 .55885 Mdot
.54162 .63586 Mdot
.40191 .53789 Mdot
.25359 .66098 Mdot
.56633 .66857 Mdot
.56688 .60857 Mdot
.42702 .38711 Mdot
.30535 .34854 Mdot
.16307 .56691 Mdot
.40687 .62402 Mdot
.32441 .54192 Mdot
.30433 .54727 Mdot
.63185 .52264 Mdot
.54652 .69566 Mdot
.58934 .37238 Mdot
.43314 .63578 Mdot
.48827 .38175 Mdot
.44236 .57254 Mdot
.60956 .47527 Mdot
.57588 .62834 Mdot
.80221 .46605 Mdot
.54324 .61903 Mdot
.68581 .51885 Mdot
.68625 .50613 Mdot
.67746 .47631 Mdot
.55389 .34539 Mdot
.68495 .66294 Mdot
.56032 .336 Mdot
.20017 .30717 Mdot
.65919 .46124 Mdot
.41906 .33238 Mdot
.38389 .42994 Mdot
.52525 .70849 Mdot
.33094 .57675 Mdot
.53102 .31644 Mdot
.53066 .71731 Mdot
.50179 .81926 Mdot
.40934 .41223 Mdot
.68305 .46928 Mdot
.64597 .27107 Mdot
.24676 .28906 Mdot
.42416 .53931 Mdot
.47435 .6899 Mdot
.37892 .59761 Mdot
.31872 .55559 Mdot
.79108 .59366 Mdot
.32202 .57812 Mdot
.54711 .3759 Mdot
.50643 .64792 Mdot
.51084 .65835 Mdot
.57667 .64768 Mdot
.54649 .66373 Mdot
.56853 .32318 Mdot
.56195 .57435 Mdot
.41276 .83604 Mdot
.36375 .43453 Mdot
.62464 .62918 Mdot
.33485 .57316 Mdot
.55424 .3162 Mdot
.40173 .39848 Mdot
.48693 .34463 Mdot
.3868 .62272 Mdot
.51523 .63183 Mdot
.57383 .62481 Mdot
.25024 .6028 Mdot
.5764 .61223 Mdot
.46576 .61244 Mdot
.40265 .42107 Mdot
.37449 .5121 Mdot
.30007 .5521 Mdot
.30325 .55587 Mdot
.53212 .35797 Mdot
.67962 .51508 Mdot
.33988 .56169 Mdot
.37769 .43215 Mdot
.58715 .62891 Mdot
.53487 .58404 Mdot
.67078 .45478 Mdot
.19639 .53834 Mdot
.33355 .58273 Mdot
.62231 .258 Mdot
.69694 .49566 Mdot
.70668 .45744 Mdot
.56568 .64134 Mdot
.60037 .52256 Mdot
.62053 .53604 Mdot
.30112 .53806 Mdot
.55194 .31671 Mdot
.39217 .58175 Mdot
.56914 .38073 Mdot
.68015 .5075 Mdot
.50952 .60686 Mdot
.69239 .49812 Mdot
.51313 .62595 Mdot
.30469 .21752 Mdot
.51862 .65991 Mdot
.33568 .77326 Mdot
.40085 .71993 Mdot
.39435 .41034 Mdot
.49842 .35314 Mdot
.38921 .42684 Mdot
.69899 .49082 Mdot
.52216 .59533 Mdot
.31298 .58194 Mdot
.63609 .23136 Mdot
.66211 .43658 Mdot
.40367 .38214 Mdot
.3525 .42453 Mdot
.54698 .37926 Mdot
.57732 .65713 Mdot
.56454 .64711 Mdot
.38792 .3967 Mdot
.55677 .54082 Mdot
.64823 .52355 Mdot
.50898 .64055 Mdot
.551 .62188 Mdot
.39287 .41297 Mdot
.80272 .37569 Mdot
.71097 .44158 Mdot
.51186 .65107 Mdot
.33387 .32148 Mdot
.58193 .38723 Mdot
.58373 .66485 Mdot
.49023 .68802 Mdot
.32612 .5556 Mdot
.62212 .6879 Mdot
.18786 .44297 Mdot
.54216 .38026 Mdot
.39523 .43175 Mdot
.50908 .62459 Mdot
.38981 .43412 Mdot
.54322 .57956 Mdot
.61255 .43999 Mdot
.40441 .37662 Mdot
.55863 .59053 Mdot
.60346 .62712 Mdot
.69887 .48044 Mdot
.57499 .62597 Mdot
.73785 .67462 Mdot
.42197 .40349 Mdot
.56028 .58585 Mdot
.71667 .55089 Mdot
.57097 .35167 Mdot
.58975 .6611 Mdot
.33201 .53416 Mdot
.39669 .7505 Mdot
.656 .37363 Mdot
.29925 .31819 Mdot
.30763 .53862 Mdot
.53958 .67691 Mdot
.35897 .44093 Mdot
.58589 .34872 Mdot
.36364 .78986 Mdot
.55264 .6774 Mdot
.56567 .37726 Mdot
.54157 .35205 Mdot
.34799 .54583 Mdot
.74738 .72516 Mdot
.49695 .60592 Mdot
.54877 .65407 Mdot
.66763 .72309 Mdot
.66952 .44993 Mdot
.52923 .65994 Mdot
.48809 .64586 Mdot
.55451 .33294 Mdot
.46162 .62438 Mdot
.75049 .61722 Mdot
.40812 .77557 Mdot
.58723 .38685 Mdot
.46974 .52484 Mdot
.36824 .36701 Mdot
.32507 .57147 Mdot
.65847 .49333 Mdot
.33124 .58069 Mdot
.36153 .38196 Mdot
.49171 .65149 Mdot
.53211 .3365 Mdot
.70434 .71871 Mdot
.57878 .3361 Mdot
.283 .32791 Mdot
.67306 .45142 Mdot
.65713 .32066 Mdot
.53319 .87707 Mdot
.57587 .25277 Mdot
.51974 .30887 Mdot
.32267 .55367 Mdot
.40716 .47243 Mdot
.54947 .62091 Mdot
.7858 .61837 Mdot
.50668 .66644 Mdot
.70044 .5623 Mdot
.37625 .44053 Mdot
.35633 .42312 Mdot
.50888 .64897 Mdot
.34393 .70813 Mdot
.58619 .34744 Mdot
.58303 .38255 Mdot
.56507 .59049 Mdot
.56031 .36035 Mdot
.5448 .64799 Mdot
.40479 .39475 Mdot
.59104 .81582 Mdot
.536 .63116 Mdot
.49131 .6815 Mdot
.62182 .41286 Mdot
.72823 .2805 Mdot
.23681 .40009 Mdot
.83536 .48734 Mdot
.22587 .31317 Mdot
.55893 .36006 Mdot
.569 .68056 Mdot
.46946 .52612 Mdot
.39185 .36072 Mdot
.54916 .30375 Mdot
.51788 .66616 Mdot
.51751 .66911 Mdot
.50798 .6767 Mdot
.55747 .60883 Mdot
.79783 .58271 Mdot
.46781 .6961 Mdot
.66366 .61506 Mdot
.57194 .60724 Mdot
.35441 .61807 Mdot
.53089 .36055 Mdot
.64395 .54335 Mdot
.32059 .52556 Mdot
.57577 .629 Mdot
.44849 .6236 Mdot
.60017 .36099 Mdot
.19798 .3091 Mdot
.53849 .37183 Mdot
.37143 .39544 Mdot
.57944 .33293 Mdot
.53073 .61742 Mdot
.67132 .49426 Mdot
.48821 .50109 Mdot
.51722 .26255 Mdot
.40421 .41744 Mdot
.52226 .62502 Mdot
.41386 .32704 Mdot
.40975 .40569 Mdot
.58288 .22047 Mdot
.66532 .49134 Mdot
.34031 .66657 Mdot
.68929 .50333 Mdot
.55687 .58804 Mdot
.55298 .58747 Mdot
.50984 .34976 Mdot
.5689 .32742 Mdot
.6877 .50567 Mdot
.74957 .73043 Mdot
.35546 .5674 Mdot
.68206 .47885 Mdot
.48266 .59885 Mdot
.4612 .4652 Mdot
.67237 .48888 Mdot
.38394 .5622 Mdot
.54377 .3428 Mdot
.63595 .47998 Mdot
.48043 .61217 Mdot
.21182 .52045 Mdot
.33129 .53108 Mdot
.43437 .40167 Mdot
.3957 .55335 Mdot
.42354 .40726 Mdot
.54341 .31966 Mdot
.39089 .42491 Mdot
.57967 .3428 Mdot
.67521 .39046 Mdot
.45547 .57767 Mdot
.55876 .39979 Mdot
.54978 .31906 Mdot
.39047 .42179 Mdot
.50453 .64138 Mdot
.38502 .57848 Mdot
.57547 .67487 Mdot
.49257 .60762 Mdot
.582 .35263 Mdot
.67647 .46365 Mdot
.66076 .53975 Mdot
.32758 .6309 Mdot
.65437 .52972 Mdot
.39949 .38295 Mdot
.43746 .83366 Mdot
.35476 .30314 Mdot
.57999 .36966 Mdot
.58278 .33421 Mdot
.54936 .59405 Mdot
.38084 .40552 Mdot
.39199 .43814 Mdot
.55264 .38037 Mdot
.5376 .52656 Mdot
.51218 .69803 Mdot
.68214 .53065 Mdot
.64798 .46513 Mdot
.68184 .49103 Mdot
.68849 .46315 Mdot
.771 .57143 Mdot
.53681 .34649 Mdot
.68552 .46737 Mdot
.56217 .59321 Mdot
.51866 .66795 Mdot
.43751 .53913 Mdot
.30512 .54935 Mdot
.55508 .68107 Mdot
.59635 .62082 Mdot
.56856 .63752 Mdot
.37562 .37228 Mdot
.58031 .70983 Mdot
.4067 .37831 Mdot
.36595 .44388 Mdot
.37554 .44499 Mdot
.41524 .28606 Mdot
.27244 .62479 Mdot
.23466 .32696 Mdot
.49958 .62163 Mdot
.76254 .39208 Mdot
.37708 .4179 Mdot
.49822 .82503 Mdot
.74036 .38488 Mdot
.53644 .68253 Mdot
.26734 .50636 Mdot
.38873 .39975 Mdot
.65384 .53229 Mdot
.51803 .66419 Mdot
.38199 .45394 Mdot
.33505 .53373 Mdot
.58199 .59894 Mdot
.41541 .38062 Mdot
.66609 .51577 Mdot
.30724 .53035 Mdot
.64453 .46621 Mdot
.37564 .44404 Mdot
.59876 .64391 Mdot
.20355 .70826 Mdot
.35115 .42634 Mdot
.75616 .34313 Mdot
.72518 .50415 Mdot
.50716 .64115 Mdot
.42283 .41911 Mdot
.68205 .44764 Mdot
.53264 .32682 Mdot
.48373 .39626 Mdot
.63472 .49537 Mdot
.3556 .42043 Mdot
.41955 .38845 Mdot
.40354 .41994 Mdot
.64236 .49781 Mdot
.48666 .6698 Mdot
.63692 .50583 Mdot
.58148 .33499 Mdot
.54574 .60125 Mdot
.29947 .25612 Mdot
.7638 .40133 Mdot
.69298 .50096 Mdot
.36754 .39013 Mdot
.34911 .53332 Mdot
.53651 .62261 Mdot
.77532 .41056 Mdot
.50352 .63516 Mdot
.58592 .35984 Mdot
.52291 .79373 Mdot
.73214 .69568 Mdot
.58207 .63762 Mdot
.55021 .59454 Mdot
.58487 .37912 Mdot
.52557 .6288 Mdot
.57921 .64853 Mdot
.42849 .28168 Mdot
.64267 .50808 Mdot
.54557 .63046 Mdot
.36532 .42232 Mdot
.40496 .27551 Mdot
.51244 .69644 Mdot
.32509 .45081 Mdot
.34557 .68287 Mdot
.54029 .78508 Mdot
.50488 .6652 Mdot
.41598 .60249 Mdot
.56115 .61644 Mdot
.54218 .67162 Mdot
.53043 .59972 Mdot
.81032 .57848 Mdot
.39853 .37384 Mdot
.40086 .4143 Mdot
.31823 .53143 Mdot
.34326 .67956 Mdot
.33047 .55648 Mdot
.54299 .34136 Mdot
.29123 .42417 Mdot
.40561 .37784 Mdot
.67237 .51558 Mdot
.54921 .67099 Mdot
.35196 .42978 Mdot
.56759 .64555 Mdot
.529 .61702 Mdot
.41456 .4158 Mdot
.37853 .36441 Mdot
.31355 .31394 Mdot
.31651 .5341 Mdot
.67109 .47433 Mdot
.56695 .6765 Mdot
.34096 .57666 Mdot
.48476 .63383 Mdot
.40352 .68942 Mdot
.67341 .47686 Mdot
.64031 .50782 Mdot
.65603 .53876 Mdot
.49178 .65051 Mdot
.53135 .62071 Mdot
.56303 .33639 Mdot
.6902 .50832 Mdot
.57081 .35392 Mdot
.52851 .4571 Mdot
.33804 .48394 Mdot
.51786 .66627 Mdot
.6361 .27208 Mdot
.31872 .56665 Mdot
.38307 .38103 Mdot
.26232 .66169 Mdot
.32059 .5307 Mdot
.51183 .62848 Mdot
.39794 .43573 Mdot
.31025 .54973 Mdot
.59779 .70577 Mdot
.17244 .40426 Mdot
.34035 .52832 Mdot
.56344 .59361 Mdot
.46011 .66188 Mdot
.83669 .49984 Mdot
.31614 .53053 Mdot
.5448 .32868 Mdot
.49237 .65077 Mdot
.6157 .50061 Mdot
.32668 .58244 Mdot
.52183 .24291 Mdot
.39602 .39769 Mdot
.19771 .47831 Mdot
.54295 .7217 Mdot
.75002 .68564 Mdot
.31033 .56777 Mdot
.66236 .50375 Mdot
.69929 .53224 Mdot
.56527 .63309 Mdot
.31873 .52991 Mdot
.59626 .38042 Mdot
.3945 .38897 Mdot
.45619 .26364 Mdot
.64173 .49637 Mdot
.63372 .29013 Mdot
.36615 .38676 Mdot
.61595 .25658 Mdot
.46849 .79267 Mdot
.57978 .67624 Mdot
.83016 .50296 Mdot
.46111 .36139 Mdot
.49853 .67461 Mdot
.36213 .54594 Mdot
.54667 .38316 Mdot
.53515 .33162 Mdot
.56275 .36807 Mdot
.69564 .39616 Mdot
.41822 .55234 Mdot
.41682 .4324 Mdot
.56598 .28557 Mdot
.32667 .57039 Mdot
.39054 .59672 Mdot
.53096 .58171 Mdot
.54394 .6235 Mdot
.57983 .65398 Mdot
.57595 .64088 Mdot
.56029 .62511 Mdot
.56422 .35545 Mdot
.66166 .39449 Mdot
.42665 .55173 Mdot
.67374 .48254 Mdot
.29453 .37513 Mdot
.38256 .42857 Mdot
.4166 .43397 Mdot
.31312 .54188 Mdot
.60775 .23875 Mdot
.4077 .36963 Mdot
.36761 .41042 Mdot
.51227 .68603 Mdot
.64188 .5206 Mdot
.46648 .65621 Mdot
.55609 .59332 Mdot
.39595 .38363 Mdot
.55531 .47706 Mdot
.75716 .6269 Mdot
.58388 .71082 Mdot
.37589 .56205 Mdot
.42209 .51406 Mdot
.33933 .53049 Mdot
.51739 .59755 Mdot
.50719 .82557 Mdot
.36279 .37927 Mdot
.37599 .39856 Mdot
.31137 .56555 Mdot
.61684 .46584 Mdot
.65259 .48828 Mdot
.52037 .3039 Mdot
.55862 .3292 Mdot
.53331 .59142 Mdot
.33644 .75116 Mdot
.61541 .5635 Mdot
.27496 .41205 Mdot
.56652 .37096 Mdot
.38523 .43531 Mdot
.58492 .6366 Mdot
.56406 .59588 Mdot
.31482 .5647 Mdot
.3815 .23213 Mdot
.59158 .62348 Mdot
.5919 .20154 Mdot
.23849 .6206 Mdot
.20309 .5342 Mdot
.56526 .64322 Mdot
.64239 .50541 Mdot
.41517 .3784 Mdot
.32142 .57567 Mdot
.49471 .58924 Mdot
.19385 .37175 Mdot
.66187 .45677 Mdot
.54269 .37039 Mdot
.50966 .48794 Mdot
.39563 .57466 Mdot
.4962 .66297 Mdot
.50686 .66493 Mdot
.52853 .67488 Mdot
.15751 .45846 Mdot
.38744 .37235 Mdot
.68048 .51753 Mdot
.34015 .54034 Mdot
.66106 .52652 Mdot
.39652 .41615 Mdot
.641 .30412 Mdot
.50148 .64146 Mdot
.66151 .45602 Mdot
.66167 .50209 Mdot
.54183 .37495 Mdot
.52627 .33303 Mdot
.52324 .47365 Mdot
.52093 .65914 Mdot
.34927 .40755 Mdot
.69284 .47224 Mdot
.40414 .54091 Mdot
.32955 .5473 Mdot
.54644 .33715 Mdot
.57332 .61408 Mdot
.37892 .36863 Mdot
.55708 .57073 Mdot
.66004 .48012 Mdot
.36814 .41115 Mdot
.33313 .30857 Mdot
.30302 .54403 Mdot
.53357 .66539 Mdot
.28278 .55528 Mdot
.39587 .43206 Mdot
.55092 .61915 Mdot
.66561 .26529 Mdot
.3761 .54242 Mdot
.50672 .25657 Mdot
.38425 .44543 Mdot
.36424 .30953 Mdot
.6331 .52052 Mdot
.72818 .4113 Mdot
.37473 .39573 Mdot
.63547 .26276 Mdot
.3789 .24875 Mdot
.58529 .64677 Mdot
.6867 .49641 Mdot
.47269 .37342 Mdot
.34797 .20929 Mdot
.79947 .39021 Mdot
.52409 .63825 Mdot
.39927 .44373 Mdot
.31205 .5603 Mdot
.58168 .36813 Mdot
.32908 .45972 Mdot
.37825 .54899 Mdot
.35275 .38886 Mdot
.52886 .60032 Mdot
.66615 .50966 Mdot
.54726 .34524 Mdot
.66071 .37838 Mdot
.37248 .43015 Mdot
.36187 .40109 Mdot
.58441 .63688 Mdot
.33173 .56169 Mdot
.77813 .42987 Mdot
.40597 .39904 Mdot
.24814 .61522 Mdot
.35495 .36609 Mdot
.34872 .573 Mdot
.5646 .6129 Mdot
.31881 .62918 Mdot
.53521 .6957 Mdot
.71709 .29082 Mdot
.38609 .42493 Mdot
.66541 .47826 Mdot
.51564 .67767 Mdot
.42666 .77564 Mdot
.39212 .38267 Mdot
.41196 .51684 Mdot
.23967 .44762 Mdot
.5398 .3442 Mdot
.26298 .66417 Mdot
.53799 .65808 Mdot
.58557 .34667 Mdot
.31867 .56504 Mdot
.51578 .65459 Mdot
.53381 .61819 Mdot
.70095 .49999 Mdot
.5522 .37902 Mdot
.34062 .27116 Mdot
.59868 .35884 Mdot
.5289 .34631 Mdot
.70339 .5035 Mdot
.55182 .63926 Mdot
.37024 .3955 Mdot
.38715 .39956 Mdot
.50342 .59131 Mdot
.54086 .83799 Mdot
.64994 .4875 Mdot
.43313 .42368 Mdot
.1589 .48018 Mdot
.60596 .59324 Mdot
.27785 .68255 Mdot
.39706 .22439 Mdot
.5837 .39035 Mdot
.56801 .59498 Mdot
.66886 .51397 Mdot
.44906 .44222 Mdot
.36336 .39795 Mdot
.48277 .64987 Mdot
.54749 .34922 Mdot
.33268 .5325 Mdot
.41795 .40089 Mdot
.27918 .40545 Mdot
.54096 .66873 Mdot
.26121 .51 Mdot
.41226 .43248 Mdot
.48901 .15222 Mdot
.48265 .35107 Mdot
.68809 .49149 Mdot
.53147 .61417 Mdot
.64336 .5339 Mdot
.33364 .53837 Mdot
.50978 .48615 Mdot
.5443 .34889 Mdot
.4901 .7215 Mdot
.37046 .82829 Mdot
.40241 .4229 Mdot
.67667 .52104 Mdot
.58227 .63391 Mdot
.60123 .46906 Mdot
.54377 .6535 Mdot
.46743 .59401 Mdot
.36175 .51221 Mdot
.57989 .35409 Mdot
.58024 .34043 Mdot
.54993 .61225 Mdot
.35476 .56198 Mdot
.37968 .43139 Mdot
.39107 .38617 Mdot
.62171 .17724 Mdot
.61689 .38405 Mdot
.35891 .73027 Mdot
.52139 .66927 Mdot
.35215 .41276 Mdot
.41021 .25987 Mdot
.57105 .37504 Mdot
.53167 .57767 Mdot
.41205 .41338 Mdot
.22465 .52557 Mdot
.43245 .76375 Mdot
.56322 .6242 Mdot
.47955 .66372 Mdot
.55389 .32844 Mdot
.41606 .58026 Mdot
.36679 .4348 Mdot
.60204 .59946 Mdot
.53699 .38753 Mdot
.49762 .77366 Mdot
.18343 .52256 Mdot
.67146 .47417 Mdot
.2673 .39003 Mdot
.56411 .35459 Mdot
.47703 .66144 Mdot
.34424 .5679 Mdot
.40205 .36934 Mdot
.38756 .37072 Mdot
.51362 .61285 Mdot
.57025 .58369 Mdot
.28113 .66602 Mdot
.65659 .52555 Mdot
.53075 .35841 Mdot
.50243 .65553 Mdot
.68704 .31876 Mdot
.57746 .64462 Mdot
.56646 .33994 Mdot
.19699 .70792 Mdot
.57922 .66545 Mdot
.54749 .65254 Mdot
.78057 .42131 Mdot
.63714 .48998 Mdot
.67525 .52348 Mdot
.2843 .71771 Mdot
.52236 .66917 Mdot
.25327 .64203 Mdot
.66694 .47232 Mdot
.65305 .48495 Mdot
.45301 .27595 Mdot
.53823 .62418 Mdot
.49662 .73451 Mdot
.58778 .36358 Mdot
.53209 .34049 Mdot
.63777 .50028 Mdot
.58735 .65206 Mdot
.53066 .37065 Mdot
.80256 .52282 Mdot
.38086 .40743 Mdot
.52318 .82381 Mdot
.6476 .48109 Mdot
.55488 .4341 Mdot
.57012 .37275 Mdot
.20318 .30439 Mdot
.34902 .36261 Mdot
.50369 .6438 Mdot
.53132 .66851 Mdot
.32061 .56927 Mdot
.5748 .66943 Mdot
.35752 .42652 Mdot
.56093 .36054 Mdot
.65918 .57239 Mdot
.6782 .47625 Mdot
.53153 .65449 Mdot
.59902 .23356 Mdot
.5132 .23035 Mdot
.26488 .37364 Mdot
.65235 .49536 Mdot
.69213 .49006 Mdot
.36314 .42714 Mdot
.40162 .44155 Mdot
.55909 .63681 Mdot
.58038 .38117 Mdot
.69082 .507 Mdot
.57341 .34321 Mdot
.36334 .37901 Mdot
.36793 .39971 Mdot
.39313 .3698 Mdot
.56932 .57212 Mdot
.36636 .41675 Mdot
.30722 .39917 Mdot
.62637 .28613 Mdot
.68938 .5215 Mdot
.21052 .61437 Mdot
.66901 .37913 Mdot
.72033 .43957 Mdot
.32095 .58419 Mdot
.39682 .43214 Mdot
.59104 .34549 Mdot
.55382 .60283 Mdot
.57215 .63587 Mdot
.32979 .35067 Mdot
.59205 .35481 Mdot
.3292 .53933 Mdot
.58402 .34189 Mdot
.34825 .54593 Mdot
.24105 .49358 Mdot
.57295 .66426 Mdot
.53851 .58309 Mdot
.56596 .36009 Mdot
.36748 .41518 Mdot
.40035 .40463 Mdot
.33092 .52645 Mdot
.59958 .43248 Mdot
.4101 .40637 Mdot
.65163 .47896 Mdot
.77534 .55044 Mdot
.41984 .38804 Mdot
.52218 .66319 Mdot
.41036 .67062 Mdot
.77273 .65374 Mdot
.51135 .69287 Mdot
.44386 .27728 Mdot
.69012 .74397 Mdot
.53167 .68095 Mdot
.74376 .70946 Mdot
.38134 .31433 Mdot
.63516 .52162 Mdot
.37375 .43916 Mdot
.42841 .38555 Mdot
.56676 .56379 Mdot
.35025 .52602 Mdot
.49678 .59135 Mdot
.64616 .47759 Mdot
.62359 .49672 Mdot
.21922 .55235 Mdot
.75072 .33001 Mdot
.31131 .55656 Mdot
.30816 .54914 Mdot
.37687 .39256 Mdot
.78541 .31675 Mdot
.51176 .71536 Mdot
.32504 .54084 Mdot
.46401 .56428 Mdot
.52412 .60315 Mdot
.38181 .71449 Mdot
.26128 .55098 Mdot
.64043 .5013 Mdot
.33676 .62045 Mdot
.37657 .38699 Mdot
.64972 .53029 Mdot
.69694 .33667 Mdot
.54121 .68747 Mdot
.67513 .47723 Mdot
.57022 .3397 Mdot
.48682 .31719 Mdot
.65718 .4682 Mdot
.40828 .68004 Mdot
.55905 .38271 Mdot
.40553 .53477 Mdot
.33044 .64419 Mdot
.75916 .77115 Mdot
.56132 .35596 Mdot
.41162 .38339 Mdot
.38763 .39848 Mdot
.38921 .38615 Mdot
.65476 .52773 Mdot
.39233 .43742 Mdot
.66328 .52352 Mdot
.81736 .44421 Mdot
.61022 .47554 Mdot
.32205 .54255 Mdot
.46449 .26317 Mdot
.67525 .50523 Mdot
.47213 .83751 Mdot
.47239 .8689 Mdot
.56875 .59485 Mdot
.5885 .3381 Mdot
.31568 .54767 Mdot
.60747 .19946 Mdot
.32316 .55792 Mdot
.27537 .60903 Mdot
.52607 .80149 Mdot
.53876 .64835 Mdot
.71402 .65344 Mdot
.30317 .57058 Mdot
.65347 .50406 Mdot
.54906 .61896 Mdot
.47 .39854 Mdot
.3252 .5608 Mdot
.34799 .54046 Mdot
.55384 .63152 Mdot
.68361 .46952 Mdot
.37206 .38765 Mdot
.55812 .32366 Mdot
.29742 .57369 Mdot
.71606 .50426 Mdot
.51657 .69196 Mdot
.50253 .62851 Mdot
.43912 .52772 Mdot
.29049 .583 Mdot
.55819 .35942 Mdot
.79393 .63805 Mdot
.38927 .445 Mdot
.46542 .38431 Mdot
.24105 .60424 Mdot
.42304 .28849 Mdot
.38628 .42228 Mdot
.39276 .43048 Mdot
.56139 .62875 Mdot
.30242 .59052 Mdot
.5399 .79484 Mdot
.58965 .32054 Mdot
.41684 .38015 Mdot
.39434 .38722 Mdot
.62407 .52266 Mdot
.22137 .56178 Mdot
.494 .58805 Mdot
.53934 .37886 Mdot
.38485 .36917 Mdot
.62453 .4324 Mdot
.33154 .5651 Mdot
.47551 .82466 Mdot
.57 .66762 Mdot
.5036 .64822 Mdot
.54843 .3615 Mdot
.5581 .33573 Mdot
.44402 .45036 Mdot
.23829 .58339 Mdot
.7047 .73012 Mdot
.64134 .37931 Mdot
.60702 .72502 Mdot
.6234 .51195 Mdot
.69349 .50012 Mdot
.54114 .25381 Mdot
.59922 .35902 Mdot
.52454 .68051 Mdot
.68216 .51273 Mdot
.43702 .35353 Mdot
.75509 .47471 Mdot
.36673 .7212 Mdot
.29202 .69056 Mdot
.51517 .62579 Mdot
.64598 .51631 Mdot
.63815 .48914 Mdot
.70003 .46425 Mdot
.39381 .31818 Mdot
.55749 .6451 Mdot
.51861 .6324 Mdot
.55284 .67261 Mdot
.576 .52375 Mdot
.55468 .66111 Mdot
.71799 .41014 Mdot
.49663 .47649 Mdot
.63114 .66007 Mdot
.60067 .60291 Mdot
.56599 .394 Mdot
.49542 .66055 Mdot
.35545 .55957 Mdot
.53736 .59503 Mdot
.37145 .72648 Mdot
.55676 .3767 Mdot
.71678 .44356 Mdot
.67618 .38697 Mdot
.50704 .67924 Mdot
.29697 .54464 Mdot
.50115 .3863 Mdot
.28766 .27246 Mdot
.29133 .53644 Mdot
.65066 .4796 Mdot
.38196 .41383 Mdot
.59249 .34909 Mdot
.36999 .40243 Mdot
.5723 .57593 Mdot
.54822 .25813 Mdot
.51815 .2128 Mdot
.54211 .45485 Mdot
.57559 .63749 Mdot
.56876 .71051 Mdot
.65479 .48087 Mdot
.39945 .43513 Mdot
.61165 .50058 Mdot
.51793 .67677 Mdot
.34515 .54633 Mdot
.32282 .56495 Mdot
.47547 .38521 Mdot
.45677 .1811 Mdot
.74128 .44131 Mdot
.55078 .36103 Mdot
.40652 .394 Mdot
.32287 .57888 Mdot
.71431 .31434 Mdot
.52653 .33135 Mdot
.5861 .3784 Mdot
.54251 .37268 Mdot
.48952 .63524 Mdot
.40536 .37674 Mdot
.63333 .65153 Mdot
.3529 .41148 Mdot
.52505 .62625 Mdot
.37919 .37294 Mdot
.41019 .41411 Mdot
.33144 .57428 Mdot
.5344 .36549 Mdot
.35721 .39748 Mdot
.55607 .58692 Mdot
.67404 .46918 Mdot
.56019 .42367 Mdot
.41917 .74227 Mdot
.73676 .31666 Mdot
.68313 .55754 Mdot
.64704 .46822 Mdot
.34437 .21679 Mdot
.58372 .38698 Mdot
.55 .52413 Mdot
.30802 .32677 Mdot
.50349 .61155 Mdot
.49725 .85099 Mdot
.41984 .42913 Mdot
.41549 .40887 Mdot
.56312 .61222 Mdot
.44599 .38229 Mdot
.53664 .65294 Mdot
.36377 .38375 Mdot
.32388 .34619 Mdot
.58797 .54775 Mdot
.37189 .4221 Mdot
.60045 .59317 Mdot
.54072 .61606 Mdot
.63974 .50431 Mdot
.42335 .41724 Mdot
.5314 .57671 Mdot
.59571 .17273 Mdot
.55903 .33829 Mdot
.41909 .32408 Mdot
.4213 .68455 Mdot
.56476 .3537 Mdot
.68297 .48148 Mdot
.49987 .60019 Mdot
.31645 .56452 Mdot
.67422 .50747 Mdot
.44082 .77087 Mdot
.30143 .55996 Mdot
.47788 .84425 Mdot
.63942 .49115 Mdot
.42175 .39378 Mdot
.34788 .56571 Mdot
.56342 .68377 Mdot
.40266 .37004 Mdot
.49457 .3474 Mdot
.38464 .42311 Mdot
.56372 .64845 Mdot
.46589 .25336 Mdot
.52941 .35319 Mdot
.52358 .641 Mdot
.41812 .40903 Mdot
.42877 .27948 Mdot
.49121 .63187 Mdot
.55604 .61364 Mdot
.19807 .54404 Mdot
.41219 .81134 Mdot
.32505 .55146 Mdot
.69598 .45548 Mdot
.56188 .59302 Mdot
.34007 .5364 Mdot
.28139 .47877 Mdot
.49404 .64691 Mdot
.66651 .45516 Mdot
.60868 .63372 Mdot
.41823 .42432 Mdot
.56624 .34857 Mdot
.54087 .44964 Mdot
.33475 .53377 Mdot
.86369 .56494 Mdot
.35739 .38371 Mdot
.52153 .59183 Mdot
.57673 .62734 Mdot
.22412 .41522 Mdot
.63635 .52299 Mdot
.62728 .77294 Mdot
.53344 .66563 Mdot
.56805 .52598 Mdot
.51954 .65323 Mdot
.43027 .42325 Mdot
.65218 .48721 Mdot
.55117 .65365 Mdot
.63475 .27878 Mdot
.4993 .68922 Mdot
.31489 .53352 Mdot
.78604 .42235 Mdot
.50816 .68698 Mdot
.29506 .7961 Mdot
.25924 .56586 Mdot
.3714 .4236 Mdot
.50759 .24061 Mdot
.72359 .21944 Mdot
.69589 .39301 Mdot
.66925 .52208 Mdot
.43856 .2117 Mdot
.3697 .39594 Mdot
.46091 .2414 Mdot
.33806 .21771 Mdot
.54183 .61168 Mdot
.49626 .66324 Mdot
.26838 .59035 Mdot
.37007 .44379 Mdot
.35344 .3784 Mdot
.59049 .60436 Mdot
.47196 .64501 Mdot
.3647 .40443 Mdot
.55635 .58332 Mdot
.58136 .58459 Mdot
.56596 .3238 Mdot
.6533 .46496 Mdot
.58328 .36134 Mdot
.55079 .38231 Mdot
.79666 .48791 Mdot
.24445 .55059 Mdot
.56502 .34094 Mdot
.56559 .39012 Mdot
.38462 .71862 Mdot
.29959 .66667 Mdot
.32524 .58261 Mdot
.50343 .16584 Mdot
.3908 .38862 Mdot
.55407 .64424 Mdot
.64162 .47734 Mdot
.71636 .71517 Mdot
.31943 .46497 Mdot
.55124 .80355 Mdot
.52161 .67896 Mdot
.38577 .38276 Mdot
.39416 .31796 Mdot
.46353 .63653 Mdot
.35611 .44805 Mdot
.50084 .65653 Mdot
.35646 .37632 Mdot
.74656 .5852 Mdot
.62859 .26153 Mdot
.35388 .37155 Mdot
.68637 .52757 Mdot
.50597 .65386 Mdot
.64544 .48215 Mdot
.57328 .36984 Mdot
.34184 .57355 Mdot
.32887 .55025 Mdot
.55197 .62331 Mdot
.5921 .66245 Mdot
.24777 .5035 Mdot
.53679 .62144 Mdot
.53073 .6012 Mdot
.38078 .31414 Mdot
.53639 .59844 Mdot
.57234 .64905 Mdot
.56298 .66201 Mdot
.48058 .64127 Mdot
.53052 .34307 Mdot
.6031 .23877 Mdot
.49855 .57498 Mdot
.48483 .58338 Mdot
.52506 .33912 Mdot
.35681 .25137 Mdot
.56616 .38651 Mdot
.29194 .25853 Mdot
.58539 .3548 Mdot
.33103 .54438 Mdot
.25513 .348 Mdot
.56296 .7033 Mdot
.68947 .46718 Mdot
.5362 .31916 Mdot
.34273 .5407 Mdot
.5623 .36486 Mdot
.36881 .38106 Mdot
.1706 .47844 Mdot
.71309 .45935 Mdot
.43039 .62057 Mdot
.54899 .30982 Mdot
.55008 .26676 Mdot
.35546 .40251 Mdot
.64548 .4893 Mdot
.74799 .6388 Mdot
.57548 .64605 Mdot
.3445 .539 Mdot
.55799 .63298 Mdot
.52953 .3616 Mdot
.38022 .38615 Mdot
.79332 .39543 Mdot
.31526 .56498 Mdot
.21152 .60134 Mdot
.3968 .4015 Mdot
.56419 .66472 Mdot
.53677 .37638 Mdot
.23452 .66711 Mdot
.58215 .35676 Mdot
.59805 .76471 Mdot
.63211 .52839 Mdot
.8387 .47862 Mdot
.68093 .50194 Mdot
.49795 .32517 Mdot
.16098 .5845 Mdot
.61971 .23244 Mdot
.68164 .46952 Mdot
.60519 .31396 Mdot
.51052 .62495 Mdot
.50209 .63019 Mdot
.7275 .32259 Mdot
.69473 .45513 Mdot
.57198 .6029 Mdot
.34892 .30813 Mdot
.62247 .29606 Mdot
.3069 .72064 Mdot
.38803 .43113 Mdot
.53519 .65704 Mdot
.52323 .37265 Mdot
.58899 .35346 Mdot
.35382 .39353 Mdot
.58445 .38403 Mdot
.5206 .63259 Mdot
.67634 .5044 Mdot
.40669 .46667 Mdot
.34005 .55258 Mdot
.67844 .23594 Mdot
.36057 .55926 Mdot
.38672 .42182 Mdot
.5725 .67962 Mdot
.3676 .401 Mdot
.73466 .21228 Mdot
.51481 .63621 Mdot
.66557 .47355 Mdot
.55383 .59521 Mdot
.50861 .65202 Mdot
.49683 .66643 Mdot
.36669 .38975 Mdot
.51906 .75352 Mdot
.55642 .58527 Mdot
.54359 .34821 Mdot
.62751 .68274 Mdot
.51069 .68684 Mdot
.43723 .38898 Mdot
.32775 .68507 Mdot
.5577 .29143 Mdot
.63292 .49056 Mdot
.37735 .42541 Mdot
.68055 .4748 Mdot
.61241 .54039 Mdot
.68268 .48154 Mdot
.64367 .70054 Mdot
.75111 .62431 Mdot
.53544 .7653 Mdot
.71241 .55237 Mdot
.53603 .49926 Mdot
.69559 .45544 Mdot
.27044 .55685 Mdot
.69833 .49353 Mdot
.63568 .49529 Mdot
.08858 .58453 Mdot
.69633 .47117 Mdot
.52548 .66476 Mdot
.53439 .68687 Mdot
.582 .25988 Mdot
.38019 .67534 Mdot
.5491 .59991 Mdot
.56139 .59887 Mdot
.33439 .57565 Mdot
.55809 .53462 Mdot
.52436 .24873 Mdot
.40509 .81786 Mdot
.48444 .22756 Mdot
.55587 .63132 Mdot
.55995 .59198 Mdot
.46805 .64861 Mdot
.26168 .73317 Mdot
.81463 .51452 Mdot
.64359 .45631 Mdot
.48247 .68017 Mdot
.67878 .25495 Mdot
.50102 .66877 Mdot
.48856 .64731 Mdot
.51331 .6259 Mdot
.37019 .39505 Mdot
.64628 .46139 Mdot
.48178 .61746 Mdot
.24923 .5729 Mdot
.49739 .65741 Mdot
.42662 .28556 Mdot
.8297 .39885 Mdot
.53849 .65834 Mdot
.63828 .47027 Mdot
.50464 .6216 Mdot
.63569 .51521 Mdot
.65012 .50805 Mdot
.5309 .70635 Mdot
.61209 .71893 Mdot
.62631 .49281 Mdot
.5253 .62555 Mdot
.37634 .38105 Mdot
.47805 .15948 Mdot
.56298 .6502 Mdot
.33653 .57813 Mdot
.52985 .66836 Mdot
.29485 .54919 Mdot
.53369 .60205 Mdot
.35763 .38182 Mdot
.75026 .6789 Mdot
.37718 .39619 Mdot
.8331 .51814 Mdot
.38241 .3659 Mdot
.19968 .55352 Mdot
.6636 .45239 Mdot
.46322 .25904 Mdot
.65833 .78252 Mdot
.41837 .31002 Mdot
.39855 .50722 Mdot
.46919 .48332 Mdot
.58088 .38129 Mdot
.63968 .53112 Mdot
.49348 .53476 Mdot
.31105 .33564 Mdot
.28194 .35118 Mdot
.41222 .4003 Mdot
.74161 .73508 Mdot
.56807 .81535 Mdot
.53905 .5864 Mdot
.6955 .67098 Mdot
.67409 .62377 Mdot
.49441 .66319 Mdot
.4833 .61887 Mdot
.34328 .34261 Mdot
.56841 .58848 Mdot
.68178 .31125 Mdot
.3896 .41933 Mdot
.34423 .54107 Mdot
.65818 .47612 Mdot
.33532 .53272 Mdot
.30728 .33649 Mdot
.46336 .48645 Mdot
.36526 .37958 Mdot
.4839 .66869 Mdot
.55816 .60093 Mdot
.63796 .51194 Mdot
.64167 .44519 Mdot
.69885 .48263 Mdot
.31341 .55438 Mdot
.39073 .41301 Mdot
.79035 .61112 Mdot
.56616 .60398 Mdot
.66258 .50088 Mdot
.39335 .49788 Mdot
.56416 .59403 Mdot
.57067 .3631 Mdot
.50889 .63104 Mdot
.6736 .46666 Mdot
.53657 .59848 Mdot
.68107 .50369 Mdot
.38045 .41161 Mdot
.5342 .68415 Mdot
.56422 .61766 Mdot
.22399 .64014 Mdot
.33248 .54068 Mdot
.67404 .45169 Mdot
.37958 .3319 Mdot
.5791 .62634 Mdot
.47274 .27985 Mdot
.50518 .66024 Mdot
.7561 .46705 Mdot
.50011 .61151 Mdot
.40911 .31049 Mdot
.50287 .57656 Mdot
.56115 .65111 Mdot
.4278 .47476 Mdot
.67065 .64498 Mdot
.66965 .44226 Mdot
.54096 .38144 Mdot
.68954 .46219 Mdot
.31407 .72224 Mdot
.35747 .36027 Mdot
.40326 .43456 Mdot
.38581 .61173 Mdot
.47979 .6413 Mdot
.5412 .64746 Mdot
.51578 .35659 Mdot
.30772 .54421 Mdot
.65273 .49709 Mdot
.34796 .54572 Mdot
.24265 .63971 Mdot
.3047 .55952 Mdot
.4243 .42543 Mdot
.26233 .5078 Mdot
.79664 .57598 Mdot
.33331 .57561 Mdot
.68316 .46875 Mdot
.34058 .489 Mdot
.48367 .65385 Mdot
.26248 .56702 Mdot
.34636 .55157 Mdot
.79518 .6842 Mdot
.57194 .64861 Mdot
.39407 .50831 Mdot
.57056 .34703 Mdot
.34218 .56998 Mdot
.56936 .38161 Mdot
.55185 .60511 Mdot
.50995 .25439 Mdot
.67423 .51821 Mdot
.52377 .35525 Mdot
.59367 .64795 Mdot
.31576 .54622 Mdot
.39392 .37236 Mdot
.51761 .33204 Mdot
.53425 .37568 Mdot
.38052 .23 Mdot
.80201 .41672 Mdot
.39112 .4101 Mdot
.43929 .79074 Mdot
.58736 .35845 Mdot
.49534 .66974 Mdot
.52771 .53733 Mdot
.50313 .64432 Mdot
.72967 .42367 Mdot
.38084 .42881 Mdot
.58619 .25192 Mdot
.55371 .5931 Mdot
.54269 .67494 Mdot
.67114 .44442 Mdot
.38434 .39494 Mdot
.67308 .49282 Mdot
.69465 .46431 Mdot
.38108 .40967 Mdot
.68617 .49414 Mdot
.30048 .56363 Mdot
.63816 .3233 Mdot
.56403 .32944 Mdot
.53966 .35358 Mdot
.39262 .38612 Mdot
.37003 .42551 Mdot
.36774 .40876 Mdot
.50858 .63139 Mdot
.65124 .49213 Mdot
.53139 .61078 Mdot
.49547 .65826 Mdot
.59696 .73096 Mdot
.639 .47641 Mdot
.51896 .61788 Mdot
.4643 .4036 Mdot
.3333 .5948 Mdot
.37796 .37889 Mdot
.5664 .34321 Mdot
.39844 .26806 Mdot
.5001 .36391 Mdot
.53088 .65837 Mdot
.22575 .51984 Mdot
.69211 .47471 Mdot
.31944 .56344 Mdot
.34094 .58359 Mdot
.3233 .55561 Mdot
.60978 .37517 Mdot
.69059 .45411 Mdot
.41227 .82183 Mdot
.53843 .65386 Mdot
.43553 .5284 Mdot
.45363 .57282 Mdot
.23911 .50671 Mdot
.56294 .34123 Mdot
.56256 .59546 Mdot
.55309 .44861 Mdot
.75892 .63443 Mdot
.50566 .64449 Mdot
.49613 .67786 Mdot
.33291 .31234 Mdot
.61029 .63256 Mdot
.63363 .53368 Mdot
.24612 .67407 Mdot
.58104 .65421 Mdot
.62297 .43767 Mdot
.70222 .24338 Mdot
.51904 .66121 Mdot
.53051 .67609 Mdot
.5716 .62474 Mdot
.53427 .59543 Mdot
.62954 .48753 Mdot
.35486 .64295 Mdot
.58663 .38535 Mdot
.43167 .53869 Mdot
.53912 .33023 Mdot
.38882 .36387 Mdot
.60237 .24487 Mdot
.63972 .53216 Mdot
.3202 .56908 Mdot
.59365 .2152 Mdot
.31665 .75657 Mdot
.36796 .43565 Mdot
.79853 .51541 Mdot
.34247 .54551 Mdot
.49657 .67378 Mdot
.29769 .56278 Mdot
.40743 .37901 Mdot
.53957 .34666 Mdot
.4789 .65127 Mdot
.69719 .49273 Mdot
.65469 .46937 Mdot
.57033 .59837 Mdot
.65918 .24381 Mdot
.57178 .35955 Mdot
.51728 .34635 Mdot
.49156 .64046 Mdot
.56375 .68304 Mdot
.67575 .49057 Mdot
.40337 .39548 Mdot
.386 .75946 Mdot
.31465 .53996 Mdot
.55483 .57222 Mdot
.52896 .59976 Mdot
.23738 .59631 Mdot
.54436 .34081 Mdot
.3912 .44913 Mdot
.49812 .6198 Mdot
.63331 .38181 Mdot
.49943 .61865 Mdot
.47779 .67851 Mdot
.37956 .38018 Mdot
.51651 .56649 Mdot
.54506 .58167 Mdot
.46769 .58847 Mdot
.58184 .3754 Mdot
.67003 .47654 Mdot
.7128 .48409 Mdot
.44877 .54019 Mdot
.56971 .36451 Mdot
.51383 .61838 Mdot
.5564 .34294 Mdot
.49497 .64755 Mdot
.56826 .59174 Mdot
.56676 .34032 Mdot
.67387 .49318 Mdot
.4356 .21583 Mdot
.5996 .23699 Mdot
.5367 .59324 Mdot
.58663 .62903 Mdot
.36476 .65417 Mdot
.51285 .75402 Mdot
.51204 .67446 Mdot
.66674 .46638 Mdot
.56478 .6073 Mdot
.56626 .37966 Mdot
.30627 .57343 Mdot
.67448 .46853 Mdot
.40115 .41086 Mdot
.36114 .42683 Mdot
.68254 .38794 Mdot
.40407 .426 Mdot
.48459 .64707 Mdot
.61109 .53193 Mdot
.71102 .46987 Mdot
.70048 .25407 Mdot
.38261 .4054 Mdot
.3133 .58303 Mdot
.55487 .61508 Mdot
.21115 .51881 Mdot
.51768 .3668 Mdot
.3507 .84061 Mdot
.46185 .84049 Mdot
.35437 .5299 Mdot
.55807 .79491 Mdot
.37324 .36339 Mdot
.55182 .57688 Mdot
.34522 .5718 Mdot
.36526 .42963 Mdot
.50811 .60944 Mdot
.50088 .70077 Mdot
.6155 .77565 Mdot
.4858 .5105 Mdot
.55474 .34143 Mdot
.38971 .44073 Mdot
.36767 .5433 Mdot
.40789 .44305 Mdot
.64424 .47646 Mdot
.55799 .65088 Mdot
.56534 .68895 Mdot
.40365 .40398 Mdot
.37649 .44863 Mdot
.52067 .62363 Mdot
.64277 .53375 Mdot
.34583 .34305 Mdot
.55057 .62947 Mdot
.55245 .5005 Mdot
.67787 .5378 Mdot
.39282 .42207 Mdot
.55245 .66865 Mdot
.36659 .50953 Mdot
.399 .39949 Mdot
.37867 .37778 Mdot
.56895 .59441 Mdot
.30024 .56087 Mdot
.58505 .63384 Mdot
.58027 .34216 Mdot
.79414 .64931 Mdot
.56061 .38007 Mdot
.33366 .46299 Mdot
.59256 .65598 Mdot
.61814 .40055 Mdot
.63065 .50144 Mdot
.27392 .60216 Mdot
.35868 .29264 Mdot
.592 .60334 Mdot
.42461 .18864 Mdot
.54389 .43091 Mdot
.64037 .22571 Mdot
.2318 .34871 Mdot
.34198 .56327 Mdot
.56323 .36737 Mdot
.52892 .6762 Mdot
.58052 .33128 Mdot
.3434 .57436 Mdot
.82967 .51109 Mdot
.55821 .66458 Mdot
.65362 .48581 Mdot
.51826 .62789 Mdot
.64846 .48077 Mdot
.56609 .59274 Mdot
.46702 .61918 Mdot
.36157 .30762 Mdot
.43229 .763 Mdot
.4949 .61894 Mdot
.17111 .51697 Mdot
.30185 .51135 Mdot
.33109 .53641 Mdot
.53542 .61333 Mdot
.34555 .43407 Mdot
.59238 .35957 Mdot
.72711 .3421 Mdot
.36947 .39477 Mdot
.55889 .38682 Mdot
.68261 .48847 Mdot
.38139 .42281 Mdot
.3592 .42629 Mdot
.52066 .56571 Mdot
.30644 .53554 Mdot
.53601 .3623 Mdot
.55124 .65567 Mdot
.559 .66249 Mdot
.40808 .7846 Mdot
.30941 .44566 Mdot
.65823 .43555 Mdot
.32244 .78402 Mdot
.70599 .50153 Mdot
.32423 .53945 Mdot
.37048 .38892 Mdot
.5082 .66825 Mdot
.5261 .63887 Mdot
.4503 .26771 Mdot
.68877 .51151 Mdot
.51787 .48172 Mdot
.77747 .50462 Mdot
.36621 .33999 Mdot
.35355 .69555 Mdot
.65983 .47209 Mdot
.35657 .69753 Mdot
.36261 .56726 Mdot
.54267 .1793 Mdot
.4066 .7463 Mdot
.56821 .34659 Mdot
.35365 .69242 Mdot
.65947 .50518 Mdot
.54668 .58605 Mdot
.42257 .39424 Mdot
.40929 .41598 Mdot
.67081 .48329 Mdot
.37277 .45643 Mdot
.33002 .57341 Mdot
.53989 .67117 Mdot
.39928 .81074 Mdot
.69042 .37105 Mdot
.40373 .38653 Mdot
.46527 .62064 Mdot
.54418 .3738 Mdot
.5717 .59925 Mdot
.32544 .57755 Mdot
.5584 .35177 Mdot
.25279 .59571 Mdot
.60882 .27786 Mdot
.55188 .61711 Mdot
.20882 .55962 Mdot
.56526 .36125 Mdot
.49373 .74966 Mdot
.5534 .63678 Mdot
.58734 .36237 Mdot
.57113 .72054 Mdot
.48846 .31992 Mdot
.55393 .4536 Mdot
.34031 .21593 Mdot
.5311 .46424 Mdot
.41832 .39043 Mdot
.50979 .2938 Mdot
.44873 .34868 Mdot
.58575 .33834 Mdot
.38115 .45078 Mdot
.36193 .58908 Mdot
.57118 .38166 Mdot
.50824 .68423 Mdot
.50896 .66064 Mdot
.81821 .51115 Mdot
.52707 .42568 Mdot
.50835 .30997 Mdot
.73527 .38885 Mdot
.5794 .63206 Mdot
.5836 .65449 Mdot
.53081 .63976 Mdot
.62454 .49409 Mdot
.54902 .3426 Mdot
.18579 .5757 Mdot
.57294 .36538 Mdot
.46683 .81933 Mdot
.38894 .3874 Mdot
.38321 .43429 Mdot
.53414 .65926 Mdot
.39417 .53024 Mdot
.30788 .64549 Mdot
.52273 .63105 Mdot
.37569 .58846 Mdot
.78427 .41658 Mdot
.57137 .67498 Mdot
.62932 .51775 Mdot
.5295 .55497 Mdot
.71447 .51599 Mdot
.56495 .3295 Mdot
.33481 .56326 Mdot
.28097 .60731 Mdot
.53671 .34833 Mdot
.54051 .64646 Mdot
.62466 .35461 Mdot
.51282 .64866 Mdot
.52976 .59503 Mdot
.49185 .82551 Mdot
.36249 .55277 Mdot
.37261 .41068 Mdot
.32146 .55408 Mdot
.63366 .51136 Mdot
.22016 .75507 Mdot
.30608 .54267 Mdot
.3021 .63935 Mdot
.82961 .54817 Mdot
.35688 .69282 Mdot
.64744 .47421 Mdot
.30732 .53314 Mdot
.56987 .35318 Mdot
.49444 .15123 Mdot
.65488 .7721 Mdot
.5543 .41041 Mdot
.54667 .63168 Mdot
.65475 .53515 Mdot
.66737 .46232 Mdot
.52355 .34713 Mdot
.65104 .50665 Mdot
.56286 .7223 Mdot
.54068 .58925 Mdot
.58725 .33786 Mdot
.64125 .36542 Mdot
.53848 .38028 Mdot
.64439 .30671 Mdot
.53245 .61772 Mdot
.66534 .47071 Mdot
.58244 .57588 Mdot
.64685 .5482 Mdot
.40171 .44561 Mdot
.51587 .69306 Mdot
.32821 .57356 Mdot
.61792 .41137 Mdot
.3929 .40894 Mdot
.22795 .50611 Mdot
.6368 .50921 Mdot
.57477 .29303 Mdot
.64105 .50629 Mdot
.70157 .46062 Mdot
.55649 .38429 Mdot
.66418 .5178 Mdot
.53395 .675 Mdot
.47202 .38469 Mdot
.64341 .5256 Mdot
.54819 .36808 Mdot
.33538 .55834 Mdot
.68194 .49629 Mdot
.44713 .38574 Mdot
.55858 .61973 Mdot
.36215 .39915 Mdot
.24949 .36253 Mdot
.69238 .51521 Mdot
.3455 .53293 Mdot
.40239 .4339 Mdot
.34962 .5421 Mdot
.76567 .32249 Mdot
.59122 .33877 Mdot
.529 .79828 Mdot
.37789 .56502 Mdot
.69346 .47068 Mdot
.25905 .34543 Mdot
.50995 .66754 Mdot
.55751 .61707 Mdot
.29302 .55329 Mdot
.66789 .46236 Mdot
.5884 .19884 Mdot
.73328 .47946 Mdot
.62685 .31101 Mdot
.55394 .31453 Mdot
.18952 .53932 Mdot
.64896 .29729 Mdot
.8033 .33394 Mdot
.59257 .62645 Mdot
.35627 .37126 Mdot
.52964 .65317 Mdot
.3708 .28613 Mdot
.3167 .54736 Mdot
.42516 .44659 Mdot
.51783 .70116 Mdot
.37684 .41563 Mdot
.5675 .63093 Mdot
.45648 .44449 Mdot
.55119 .55842 Mdot
.31657 .58387 Mdot
.51223 .2439 Mdot
.69327 .46744 Mdot
.34153 .55086 Mdot
.36166 .37811 Mdot
.32298 .66195 Mdot
.51989 .59924 Mdot
.56379 .56864 Mdot
.36582 .34035 Mdot
.64822 .48792 Mdot
.4233 .40981 Mdot
.57219 .33351 Mdot
.32552 .5671 Mdot
.55388 .60118 Mdot
.48597 .62874 Mdot
.4692 .28219 Mdot
.54013 .37196 Mdot
.36384 .44559 Mdot
.58166 .36077 Mdot
.36833 .36332 Mdot
.57712 .59443 Mdot
.38547 .43542 Mdot
.53907 .5771 Mdot
.37399 .3018 Mdot
.48957 .82239 Mdot
.6775 .65715 Mdot
.38289 .42899 Mdot
.34209 .70624 Mdot
.5597 .377 Mdot
.58495 .36152 Mdot
.81092 .58029 Mdot
.5969 .76876 Mdot
.37097 .77883 Mdot
.32746 .25922 Mdot
.54275 .32891 Mdot
.54569 .3727 Mdot
.36121 .40565 Mdot
.66033 .51999 Mdot
.70756 .48487 Mdot
.36386 .36667 Mdot
.41357 .67226 Mdot
.65293 .49717 Mdot
.47512 .16996 Mdot
.32679 .74167 Mdot
.49175 .60405 Mdot
.34168 .44091 Mdot
.32596 .56202 Mdot
.4061 .67247 Mdot
.4548 .44552 Mdot
.53612 .67747 Mdot
.23967 .57285 Mdot
.39972 .3887 Mdot
.41313 .58554 Mdot
.29338 .25877 Mdot
.56481 .65957 Mdot
.55475 .64261 Mdot
.5341 .64529 Mdot
.3385 .52625 Mdot
.63608 .76208 Mdot
.5511 .66688 Mdot
.41571 .67555 Mdot
.57749 .61348 Mdot
.54885 .73719 Mdot
.32663 .55116 Mdot
.58548 .72148 Mdot
.3176 .31371 Mdot
.26053 .68564 Mdot
.57154 .55958 Mdot
.57673 .33634 Mdot
.35256 .60394 Mdot
.58567 .37266 Mdot
.65171 .69058 Mdot
.40741 .74343 Mdot
.69067 .52212 Mdot
.53185 .67786 Mdot
.38729 .4221 Mdot
.66515 .46249 Mdot
.48921 .29721 Mdot
.14393 .67181 Mdot
.58093 .3393 Mdot
.8182 .32745 Mdot
.58392 .3539 Mdot
.35696 .42108 Mdot
.67619 .48933 Mdot
.75256 .61496 Mdot
.44494 .52514 Mdot
.68333 .49731 Mdot
.50219 .21061 Mdot
.64185 .45435 Mdot
.33944 .69302 Mdot
.67521 .52581 Mdot
.55169 .37196 Mdot
.60943 .37352 Mdot
.53704 .72022 Mdot
.52003 .66823 Mdot
.46991 .47861 Mdot
.30395 .65904 Mdot
.51421 .66936 Mdot
.38957 .41659 Mdot
.55255 .78324 Mdot
.33117 .61637 Mdot
.66559 .51356 Mdot
.5907 .3848 Mdot
.55855 .64217 Mdot
.51114 .6109 Mdot
.52576 .595 Mdot
.36179 .8216 Mdot
.54878 .17856 Mdot
.55706 .58592 Mdot
.57997 .62173 Mdot
.37982 .41964 Mdot
.3681 .56809 Mdot
.35835 .28236 Mdot
.56465 .75347 Mdot
.52733 .68338 Mdot
.33652 .54695 Mdot
.36342 .54616 Mdot
.50364 .61238 Mdot
.25588 .557 Mdot
.62232 .35152 Mdot
.55221 .65553 Mdot
.57124 .76752 Mdot
.40608 .33576 Mdot
.37019 .44359 Mdot
.40182 .40579 Mdot
.65508 .4602 Mdot
.39877 .4276 Mdot
.36838 .36706 Mdot
.76723 .59428 Mdot
.51719 .47234 Mdot
.58483 .39727 Mdot
.31289 .55539 Mdot
.52231 .64124 Mdot
.68364 .44121 Mdot
.62899 .37547 Mdot
.57134 .38399 Mdot
.69395 .48104 Mdot
.59098 .36293 Mdot
.28755 .54247 Mdot
.43282 .60401 Mdot
.41189 .39267 Mdot
.54208 .33173 Mdot
.61093 .28071 Mdot
.3346 .54774 Mdot
.53869 .37384 Mdot
.58642 .28177 Mdot
.52479 .69173 Mdot
.69475 .69032 Mdot
.52687 .62756 Mdot
.61335 .20954 Mdot
.53252 .36092 Mdot
.4075 .30191 Mdot
.54678 .64902 Mdot
.39707 .39893 Mdot
.52084 .72185 Mdot
.50101 .66103 Mdot
.40381 .41281 Mdot
.54065 .58583 Mdot
.35944 .55322 Mdot
.68805 .5319 Mdot
.43565 .53972 Mdot
.68285 .80169 Mdot
.30643 .53529 Mdot
.48895 .29145 Mdot
.51535 .67693 Mdot
.79655 .38471 Mdot
.68012 .49797 Mdot
.52797 .5848 Mdot
.34252 .62071 Mdot
.65194 .5258 Mdot
.68707 .47823 Mdot
.51161 .61494 Mdot
.57315 .35026 Mdot
.39376 .4127 Mdot
.33107 .5503 Mdot
.7624 .30296 Mdot
.54407 .62486 Mdot
.56477 .61332 Mdot
.34267 .54787 Mdot
.55272 .37746 Mdot
.49619 .62395 Mdot
.22692 .39287 Mdot
.61132 .18874 Mdot
.58643 .37985 Mdot
.51176 .68474 Mdot
.65406 .72345 Mdot
.72218 .49536 Mdot
.8558 .52639 Mdot
.26088 .56817 Mdot
.37321 .41844 Mdot
.59488 .67503 Mdot
.24411 .76033 Mdot
.33388 .56201 Mdot
.33001 .76265 Mdot
.51767 .60492 Mdot
.56902 .60577 Mdot
.69808 .48162 Mdot
.5264 .61418 Mdot
.67332 .52286 Mdot
.68102 .79527 Mdot
.23424 .596 Mdot
.64427 .48725 Mdot
.70096 .48072 Mdot
.31656 .63131 Mdot
.36223 .28289 Mdot
.67322 .48281 Mdot
.5756 .59624 Mdot
.62714 .5765 Mdot
.46164 .6761 Mdot
.29582 .55719 Mdot
.2934 .33745 Mdot
.72562 .46229 Mdot
.32784 .51814 Mdot
.39712 .22516 Mdot
.72113 .45312 Mdot
.61425 .38542 Mdot
.57053 .33493 Mdot
.56322 .6632 Mdot
.40766 .42049 Mdot
.39586 .43761 Mdot
.58468 .58249 Mdot
.51587 .64235 Mdot
.63456 .51015 Mdot
.30946 .5612 Mdot
.58806 .34427 Mdot
.56153 .59996 Mdot
.31215 .62103 Mdot
.30882 .5406 Mdot
.65245 .51546 Mdot
.55671 .76975 Mdot
.32177 .58606 Mdot
.47229 .5976 Mdot
.54196 .66239 Mdot
.51517 .6257 Mdot
.45453 .64793 Mdot
.55297 .33609 Mdot
.28303 .32542 Mdot
.5635 .67423 Mdot
.24277 .6423 Mdot
.57785 .42433 Mdot
.47341 .61344 Mdot
.64639 .49979 Mdot
.52029 .37159 Mdot
.42843 .39191 Mdot
.44644 .55496 Mdot
.54916 .6179 Mdot
.60914 .23066 Mdot
.81147 .48869 Mdot
.40931 .43849 Mdot
.69975 .45958 Mdot
.32049 .56035 Mdot
.52183 .63291 Mdot
.62494 .69955 Mdot
.51423 .66282 Mdot
.28638 .56533 Mdot
.3875 .3773 Mdot
.5718 .33642 Mdot
.63437 .21924 Mdot
.39439 .43781 Mdot
.68212 .47545 Mdot
.21347 .29235 Mdot
.66122 .52984 Mdot
.70313 .47274 Mdot
.61709 .70352 Mdot
.55796 .33489 Mdot
.27947 .79517 Mdot
.75636 .70214 Mdot
.54085 .69516 Mdot
.56532 .37657 Mdot
.66462 .48347 Mdot
.57455 .61212 Mdot
.64516 .53832 Mdot
.68436 .45061 Mdot
.5806 .60169 Mdot
.5733 .6328 Mdot
.61303 .25782 Mdot
.3289 .22865 Mdot
.31869 .55994 Mdot
.63423 .49629 Mdot
.5377 .50801 Mdot
.57606 .62209 Mdot
.53943 .65372 Mdot
.45634 .35246 Mdot
.30042 .5662 Mdot
.70492 .33398 Mdot
.51387 .60805 Mdot
.22724 .57919 Mdot
.53958 .55448 Mdot
.62647 .49727 Mdot
.58292 .38265 Mdot
.26052 .68147 Mdot
.56609 .31155 Mdot
.6803 .51717 Mdot
.313 .56767 Mdot
.71318 .46812 Mdot
.29838 .63903 Mdot
.52725 .34584 Mdot
.67358 .46664 Mdot
.54286 .44944 Mdot
.55119 .35313 Mdot
.5325 .34689 Mdot
.62609 .68177 Mdot
.36428 .45165 Mdot
.35 .52958 Mdot
.53818 .36651 Mdot
.56106 .52047 Mdot
.55422 .36789 Mdot
.7876 .63659 Mdot
.53346 .6846 Mdot
.40303 .6135 Mdot
.35428 .47331 Mdot
.56567 .70785 Mdot
.52897 .35163 Mdot
.33109 .57764 Mdot
.50293 .6189 Mdot
.65737 .50672 Mdot
.33097 .53446 Mdot
.5076 .3535 Mdot
.36547 .40108 Mdot
.64167 .51043 Mdot
.54192 .31368 Mdot
.65126 .4744 Mdot
.48849 .5363 Mdot
.82454 .58857 Mdot
.19298 .45289 Mdot
.4576 .51998 Mdot
.52551 .59592 Mdot
.33274 .2679 Mdot
.49168 .5968 Mdot
.51147 .64219 Mdot
.39201 .42056 Mdot
.39362 .60536 Mdot
.67352 .49251 Mdot
.61521 .19942 Mdot
.55163 .32933 Mdot
.24435 .66997 Mdot
.62275 .55802 Mdot
.52286 .59217 Mdot
.64401 .52698 Mdot
.66399 .52942 Mdot
.66394 .64186 Mdot
.4306 .39408 Mdot
.4846 .61895 Mdot
.47736 .63418 Mdot
.57532 .58237 Mdot
.54081 .34051 Mdot
.22842 .51525 Mdot
.41602 .38846 Mdot
.84247 .54313 Mdot
.39532 .37917 Mdot
.38211 .58462 Mdot
.66213 .51675 Mdot
.30523 .5448 Mdot
.5412 .65431 Mdot
.6402 .45012 Mdot
.68654 .51413 Mdot
.29265 .56922 Mdot
.34533 .56806 Mdot
.46932 .34112 Mdot
.56554 .33986 Mdot
.48788 .62856 Mdot
.55128 .66902 Mdot
.53313 .60815 Mdot
.50988 .63351 Mdot
.57596 .33374 Mdot
.49813 .63167 Mdot
.52602 .37345 Mdot
.48141 .55514 Mdot
.23887 .5621 Mdot
.52375 .46333 Mdot
.75858 .44444 Mdot
.66267 .51041 Mdot
.57049 .50882 Mdot
.46065 .63594 Mdot
.51193 .82593 Mdot
.77474 .39905 Mdot
.55471 .68477 Mdot
.36838 .43396 Mdot
.51274 .74351 Mdot
.41376 .40143 Mdot
.85173 .3905 Mdot
.45611 .28707 Mdot
.36825 .2071 Mdot
.56037 .65979 Mdot
.44811 .35965 Mdot
.58913 .52893 Mdot
.50307 .59055 Mdot
.46513 .30768 Mdot
.73336 .42762 Mdot
.54286 .23391 Mdot
.31666 .57838 Mdot
.55668 .6261 Mdot
.68066 .44142 Mdot
.53838 .6731 Mdot
.53312 .6545 Mdot
.50502 .61302 Mdot
.55726 .3886 Mdot
.49154 .61134 Mdot
.50053 .64005 Mdot
.25019 .49783 Mdot
.37655 .71905 Mdot
.39435 .4414 Mdot
.81721 .55605 Mdot
.30776 .53949 Mdot
.63768 .51903 Mdot
.50645 .19369 Mdot
.56736 .34586 Mdot
.66696 .63281 Mdot
.51205 .62998 Mdot
.60064 .25256 Mdot
.50915 .33525 Mdot
.32563 .56984 Mdot
.41667 .38265 Mdot
.42121 .18038 Mdot
.38608 .41541 Mdot
.54997 .44693 Mdot
.39416 .39968 Mdot
.46415 .60506 Mdot
.6342 .50762 Mdot
.49145 .62683 Mdot
.53683 .36056 Mdot
.39904 .42146 Mdot
.3739 .66202 Mdot
.53033 .64161 Mdot
.38044 .40911 Mdot
.4912 .62752 Mdot
.42929 .60937 Mdot
.46168 .78953 Mdot
.36254 .37374 Mdot
.54295 .38899 Mdot
.54493 .35474 Mdot
.30068 .56068 Mdot
.64157 .51833 Mdot
.69535 .49267 Mdot
.55811 .35347 Mdot
.61445 .7841 Mdot
.51851 .6823 Mdot
.57574 .62834 Mdot
.24656 .66338 Mdot
.52019 .67491 Mdot
.32606 .67503 Mdot
.55215 .45029 Mdot
.65653 .51244 Mdot
.55662 .57992 Mdot
.51911 .60606 Mdot
.55346 .61675 Mdot
.46332 .55648 Mdot
.40477 .39536 Mdot
.55824 .67179 Mdot
.35018 .56309 Mdot
.44079 .45224 Mdot
.57199 .59929 Mdot
.5551 .56429 Mdot
.69598 .4904 Mdot
.34088 .79217 Mdot
.58133 .34888 Mdot
.35709 .39048 Mdot
.38072 .43071 Mdot
.30024 .33465 Mdot
.62233 .42385 Mdot
.54626 .45188 Mdot
.84345 .5141 Mdot
.36059 .3089 Mdot
.33401 .53892 Mdot
.35743 .45997 Mdot
.5882 .4318 Mdot
.35906 .41197 Mdot
.58203 .33969 Mdot
.5396 .68383 Mdot
.52847 .68375 Mdot
.48937 .8455 Mdot
.50964 .60504 Mdot
.32468 .559 Mdot
.52028 .36176 Mdot
.6601 .50469 Mdot
.32407 .56938 Mdot
.58321 .36468 Mdot
.64632 .4901 Mdot
.55182 .68386 Mdot
.55287 .68213 Mdot
.69403 .4835 Mdot
.67539 .46477 Mdot
.54481 .65859 Mdot
.31274 .37621 Mdot
.68784 .4658 Mdot
.66321 .46884 Mdot
.41144 .38991 Mdot
.4081 .41692 Mdot
.49902 .57762 Mdot
.56657 .3742 Mdot
.49956 .63829 Mdot
.38336 .42214 Mdot
.30528 .56071 Mdot
.67258 .49651 Mdot
.53393 .59468 Mdot
.55786 .59533 Mdot
.33525 .54914 Mdot
.31169 .57228 Mdot
.33652 .57258 Mdot
.53477 .37857 Mdot
.54013 .60896 Mdot
.6792 .48482 Mdot
.56717 .33839 Mdot
.36248 .54296 Mdot
.30001 .57134 Mdot
.40379 .4498 Mdot
.50758 .66933 Mdot
.40017 .47486 Mdot
.19609 .71324 Mdot
.26951 .65797 Mdot
.42519 .41917 Mdot
.4315 .41411 Mdot
.37215 .69548 Mdot
.40623 .5412 Mdot
.56757 .35797 Mdot
.30333 .59005 Mdot
.27721 .60627 Mdot
.50806 .68719 Mdot
.58084 .65309 Mdot
.48143 .67623 Mdot
.34347 .56609 Mdot
.38239 .60349 Mdot
.63778 .53137 Mdot
.75316 .52206 Mdot
.31619 .53551 Mdot
.376 .44853 Mdot
.37306 .45934 Mdot
.39356 .3782 Mdot
.54569 .6831 Mdot
.68257 .64994 Mdot
.59267 .48287 Mdot
.30272 .27528 Mdot
.53153 .36198 Mdot
.69945 .44423 Mdot
.7889 .37854 Mdot
.69135 .48169 Mdot
.39585 .36764 Mdot
.34578 .5433 Mdot
.66762 .46457 Mdot
.59242 .36825 Mdot
.54261 .37014 Mdot
.40227 .38563 Mdot
.38966 .38489 Mdot
.36586 .38353 Mdot
.69879 .46138 Mdot
.66264 .51776 Mdot
.54636 .61718 Mdot
.67061 .50218 Mdot
.44878 .84462 Mdot
.30643 .52949 Mdot
.43159 .37644 Mdot
.56577 .36841 Mdot
.64561 .48339 Mdot
.52971 .63887 Mdot
.41339 .56609 Mdot
.72538 .40171 Mdot
.35311 .54784 Mdot
.42512 .78689 Mdot
.85049 .39476 Mdot
.48685 .6295 Mdot
.54682 .34 Mdot
.39612 .80756 Mdot
.53541 .64259 Mdot
.3748 .38495 Mdot
.34381 .2985 Mdot
.348 .36519 Mdot
.4954 .65604 Mdot
.4904 .67549 Mdot
.58686 .38259 Mdot
.83501 .50805 Mdot
.54288 .6206 Mdot
.70146 .34243 Mdot
.60206 .36612 Mdot
.41447 .38571 Mdot
.57638 .16306 Mdot
.23429 .40365 Mdot
.40835 .66781 Mdot
.41008 .38634 Mdot
.50788 .65298 Mdot
.41155 .39853 Mdot
.35545 .55666 Mdot
.37788 .36891 Mdot
.63453 .53157 Mdot
.41535 .42881 Mdot
.56553 .6141 Mdot
.67139 .4811 Mdot
.56641 .36175 Mdot
.27425 .71415 Mdot
.30511 .48871 Mdot
.39718 .39727 Mdot
.35529 .38952 Mdot
.55019 .58137 Mdot
.67928 .3048 Mdot
.59796 .59092 Mdot
.57092 .64914 Mdot
.53862 .33164 Mdot
.64595 .52489 Mdot
.57576 .38833 Mdot
.52807 .57647 Mdot
.22303 .39117 Mdot
.58051 .35725 Mdot
.59078 .23748 Mdot
.34152 .54409 Mdot
.46859 .43662 Mdot
.52434 .63833 Mdot
.55484 .38092 Mdot
.53947 .61033 Mdot
.6345 .52683 Mdot
.50148 .428 Mdot
.52475 .24635 Mdot
.53706 .35273 Mdot
.61718 .22509 Mdot
.38684 .5653 Mdot
.60295 .57762 Mdot
.58652 .36796 Mdot
.34891 .61726 Mdot
.35885 .42599 Mdot
.3168 .53852 Mdot
.34885 .57429 Mdot
.33536 .53332 Mdot
.59822 .60898 Mdot
.5812 .55806 Mdot
.36132 .54868 Mdot
.5954 .362 Mdot
.31961 .58394 Mdot
.64038 .43024 Mdot
.59434 .2043 Mdot
.31966 .54629 Mdot
.55135 .63403 Mdot
.55119 .54922 Mdot
.38113 .71515 Mdot
.48817 .32956 Mdot
.38991 .19833 Mdot
.74708 .36934 Mdot
.51916 .66708 Mdot
.70202 .51626 Mdot
.64017 .48035 Mdot
.36907 .79114 Mdot
.30728 .67224 Mdot
.24573 .62422 Mdot
.70184 .47723 Mdot
.46528 .2562 Mdot
.64871 .51536 Mdot
.51864 .59865 Mdot
.57504 .62042 Mdot
.70496 .49027 Mdot
.22663 .54302 Mdot
.49384 .26824 Mdot
.68619 .24621 Mdot
.65626 .47024 Mdot
.58235 .37576 Mdot
.52216 .34393 Mdot
.53187 .34581 Mdot
.3384 .75328 Mdot
.6631 .52601 Mdot
.54275 .60195 Mdot
.38419 .4286 Mdot
.54963 .67725 Mdot
.55135 .34758 Mdot
.61296 .1977 Mdot
.68031 .50773 Mdot
.55893 .65242 Mdot
.48037 .72688 Mdot
.37528 .39049 Mdot
.33411 .54392 Mdot
.4391 .65629 Mdot
.2524 .62893 Mdot
.54185 .33542 Mdot
.69586 .51301 Mdot
.41731 .29227 Mdot
.57809 .21986 Mdot
.58981 .64342 Mdot
.47887 .61288 Mdot
.78391 .31869 Mdot
.25276 .59893 Mdot
.48723 .65371 Mdot
.35571 .40685 Mdot
.44439 .27082 Mdot
.5526 .59397 Mdot
.63736 .48657 Mdot
.3352 .5825 Mdot
.34685 .54008 Mdot
.51409 .57183 Mdot
.43178 .52974 Mdot
.48409 .3965 Mdot
.51242 .61949 Mdot
.47058 .60145 Mdot
.41265 .38538 Mdot
.35452 .30842 Mdot
.24075 .63777 Mdot
.31316 .56945 Mdot
.49227 .6273 Mdot
.4467 .22105 Mdot
.69951 .49624 Mdot
.41547 .43133 Mdot
.52694 .35852 Mdot
.44896 .5804 Mdot
.41241 .38028 Mdot
.5506 .59135 Mdot
.49935 .61994 Mdot
.54616 .38072 Mdot
.62611 .49857 Mdot
.346 .56238 Mdot
.38543 .4318 Mdot
.31797 .57513 Mdot
.65497 .5262 Mdot
.67149 .50778 Mdot
.51259 .73895 Mdot
.54508 .70765 Mdot
.40087 .40871 Mdot
.55038 .57236 Mdot
.39467 .33677 Mdot
.84937 .4776 Mdot
.53596 .31939 Mdot
.48382 .63706 Mdot
.6224 .50812 Mdot
.53817 .34764 Mdot
.57254 .61671 Mdot
.76568 .29947 Mdot
.5766 .62011 Mdot
.58601 .41848 Mdot
.18752 .45578 Mdot
.32762 .57595 Mdot
.75087 .51919 Mdot
.70197 .29856 Mdot
.5256 .67382 Mdot
.36938 .42705 Mdot
.46549 .64343 Mdot
.57323 .35347 Mdot
.66479 .51454 Mdot
.85996 .5196 Mdot
.55026 .3661 Mdot
.54669 .66678 Mdot
.32513 .56792 Mdot
.67475 .52492 Mdot
.31742 .60162 Mdot
.25461 .55599 Mdot
.59343 .56648 Mdot
.55776 .57172 Mdot
.50593 .62926 Mdot
.24774 .34302 Mdot
.35825 .388 Mdot
.65816 .47951 Mdot
.54597 .33931 Mdot
.56053 .35314 Mdot
.4019 .38774 Mdot
.60004 .2763 Mdot
.47058 .43414 Mdot
.19287 .68763 Mdot
.40578 .41169 Mdot
.33277 .53018 Mdot
.69422 .32504 Mdot
.37227 .43247 Mdot
.38089 .40413 Mdot
.4142 .39155 Mdot
.59326 .32255 Mdot
.64857 .49108 Mdot
.55544 .59098 Mdot
.63242 .49183 Mdot
.5058 .6514 Mdot
.58006 .42222 Mdot
.53533 .35517 Mdot
.6745 .51422 Mdot
.77388 .31861 Mdot
.68873 .71975 Mdot
.54336 .63984 Mdot
.79309 .3814 Mdot
.5355 .70302 Mdot
.34898 .67435 Mdot
.51162 .70269 Mdot
.39352 .3909 Mdot
.60952 .6114 Mdot
.57924 .58347 Mdot
.32545 .76904 Mdot
.5679 .36926 Mdot
.36939 .44134 Mdot
.51952 .6971 Mdot
.48561 .57769 Mdot
.70641 .47287 Mdot
.66535 .46568 Mdot
.35871 .5611 Mdot
.44223 .76853 Mdot
.56914 .36286 Mdot
.75734 .68954 Mdot
.52494 .66791 Mdot
.21406 .49322 Mdot
.7034 .5591 Mdot
.57272 .62152 Mdot
.71796 .30789 Mdot
.67886 .64266 Mdot
.52247 .63463 Mdot
.5199 .49847 Mdot
.55294 .37674 Mdot
.21438 .40514 Mdot
.57759 .60733 Mdot
.371 .3918 Mdot
.65581 .51922 Mdot
.64125 .53441 Mdot
.36066 .55236 Mdot
.55227 .82045 Mdot
.56833 .38868 Mdot
.66968 .51524 Mdot
.52665 .64654 Mdot
.55199 .33452 Mdot
.3982 .43044 Mdot
.51586 .59568 Mdot
.31426 .68267 Mdot
.66603 .50216 Mdot
.56964 .58553 Mdot
.68504 .34759 Mdot
.40524 .70808 Mdot
.2071 .34447 Mdot
.54562 .33802 Mdot
.3032 .56765 Mdot
.46652 .64249 Mdot
.60535 .7781 Mdot
.58013 .66756 Mdot
.40579 .60666 Mdot
.65076 .42552 Mdot
.30456 .57155 Mdot
.54933 .64511 Mdot
.55141 .60081 Mdot
.37853 .50112 Mdot
.30946 .5656 Mdot
.55588 .66692 Mdot
.50549 .55159 Mdot
.6502 .48708 Mdot
.38197 .35976 Mdot
.65767 .50045 Mdot
.54687 .63239 Mdot
.53011 .71131 Mdot
.69307 .47388 Mdot
.83271 .42086 Mdot
.3558 .52744 Mdot
.57968 .34836 Mdot
.56951 .68227 Mdot
.5698 .6672 Mdot
.16446 .54221 Mdot
.39573 .44827 Mdot
.38952 .26133 Mdot
.24409 .45001 Mdot
.41096 .22674 Mdot
.23323 .40557 Mdot
.28506 .24693 Mdot
.23768 .58686 Mdot
.49932 .60214 Mdot
.72091 .52325 Mdot
.58211 .48049 Mdot
.52889 .35816 Mdot
.78981 .59138 Mdot
.51927 .6683 Mdot
.53067 .6545 Mdot
.41825 .42934 Mdot
.58243 .24683 Mdot
.24385 .62397 Mdot
.41469 .55334 Mdot
.34606 .56066 Mdot
.63502 .49588 Mdot
.56415 .59124 Mdot
.5276 .48473 Mdot
.39462 .44207 Mdot
.21422 .50229 Mdot
.55813 .65007 Mdot
.50513 .82201 Mdot
.70329 .40137 Mdot
.55806 .33726 Mdot
.37742 .43105 Mdot
.25015 .61554 Mdot
.50473 .66659 Mdot
.52568 .35816 Mdot
.53841 .62683 Mdot
.32227 .37747 Mdot
.53777 .57326 Mdot
.31673 .54436 Mdot
.51799 .60362 Mdot
.38287 .58645 Mdot
.18281 .33361 Mdot
.28457 .57767 Mdot
.65274 .53677 Mdot
.41831 .3604 Mdot
.40439 .39881 Mdot
.67297 .46522 Mdot
.40262 .40129 Mdot
.66854 .60595 Mdot
.75251 .59049 Mdot
.34685 .54968 Mdot
.49338 .57406 Mdot
.32034 .54929 Mdot
.40717 .44133 Mdot
.51044 .66571 Mdot
.85474 .44203 Mdot
.39772 .4172 Mdot
.18277 .50345 Mdot
.55643 .36611 Mdot
.38111 .44839 Mdot
.57731 .61123 Mdot
.42049 .29778 Mdot
.39332 .43923 Mdot
.53167 .24972 Mdot
.5526 .61662 Mdot
.66581 .50777 Mdot
.54964 .59543 Mdot
.55078 .69325 Mdot
.34974 .39843 Mdot
.49834 .64814 Mdot
.58306 .36506 Mdot
.68967 .46201 Mdot
.48402 .16028 Mdot
.73051 .43157 Mdot
.5417 .67524 Mdot
.52922 .64574 Mdot
.70738 .4599 Mdot
.5635 .66845 Mdot
.57589 .33383 Mdot
.508 .90336 Mdot
.34081 .54376 Mdot
.35204 .40833 Mdot
.23272 .40377 Mdot
.55037 .68619 Mdot
.50038 .62498 Mdot
.74679 .27814 Mdot
.217 .419 Mdot
.58551 .36686 Mdot
.58482 .59015 Mdot
.39541 .43499 Mdot
.32481 .56562 Mdot
.59569 .35584 Mdot
.51638 .62488 Mdot
.54394 .6516 Mdot
.30246 .56315 Mdot
.61899 .65551 Mdot
.30808 .72322 Mdot
.54073 .37706 Mdot
.60116 .65035 Mdot
.43908 .37398 Mdot
.50779 .67597 Mdot
.36003 .77034 Mdot
.67167 .46768 Mdot
.54251 .3332 Mdot
.33512 .27506 Mdot
.48953 .65338 Mdot
.57992 .38306 Mdot
.56965 .36437 Mdot
.58674 .59551 Mdot
.62124 .50434 Mdot
.68319 .45375 Mdot
.64941 .47582 Mdot
.4824 .86011 Mdot
.3968 .67143 Mdot
.36595 .38354 Mdot
.55223 .37683 Mdot
.36553 .36825 Mdot
.29492 .53951 Mdot
.56886 .44899 Mdot
.35835 .38014 Mdot
.65406 .46407 Mdot
.41886 .36301 Mdot
.55355 .60598 Mdot
.56652 .36028 Mdot
.35903 .40502 Mdot
.53791 .69455 Mdot
.65772 .28733 Mdot
.52431 .29572 Mdot
.307 .57926 Mdot
.34231 .58003 Mdot
.57256 .60459 Mdot
.4267 .38793 Mdot
.54288 .6583 Mdot
.55017 .32227 Mdot
.67794 .30828 Mdot
.57555 .67284 Mdot
.39852 .39594 Mdot
.71451 .49196 Mdot
.25192 .62355 Mdot
.60378 .59713 Mdot
.55111 .63533 Mdot
.50237 .65208 Mdot
.53812 .62643 Mdot
.53934 .22512 Mdot
.5574 .31583 Mdot
.75501 .44187 Mdot
.26983 .33603 Mdot
.6848 .50026 Mdot
.65031 .45597 Mdot
.26822 .66317 Mdot
.61973 .34353 Mdot
.56469 .3753 Mdot
.51095 .63923 Mdot
.63849 .39025 Mdot
.60427 .19009 Mdot
.81918 .35949 Mdot
.35628 .50338 Mdot
.39273 .4469 Mdot
.70221 .50417 Mdot
.38389 .43857 Mdot
.50873 .65727 Mdot
.46857 .64829 Mdot
.27314 .25021 Mdot
.60069 .37913 Mdot
.34816 .54878 Mdot
.50431 .64874 Mdot
.40156 .67548 Mdot
.38024 .42159 Mdot
.35279 .43021 Mdot
.56603 .65945 Mdot
.63 .48231 Mdot
.16001 .44259 Mdot
.55154 .33661 Mdot
.74183 .36129 Mdot
.59325 .52584 Mdot
.74254 .39261 Mdot
.55067 .34415 Mdot
.27542 .52831 Mdot
.42457 .41841 Mdot
.64106 .60448 Mdot
.68684 .50003 Mdot
.33117 .53498 Mdot
.47346 .61671 Mdot
.69824 .48923 Mdot
.41534 .38473 Mdot
.66572 .5117 Mdot
.507 .61047 Mdot
.59529 .34478 Mdot
.37211 .41954 Mdot
.5861 .39571 Mdot
.62448 .49035 Mdot
.31517 .56914 Mdot
.4282 .50548 Mdot
.75759 .64684 Mdot
.67713 .63943 Mdot
.55455 .67595 Mdot
.53829 .48201 Mdot
.53931 .60374 Mdot
.66701 .44905 Mdot
.53244 .63559 Mdot
.65766 .43181 Mdot
.37104 .42744 Mdot
.57969 .61953 Mdot
.51015 .6234 Mdot
.79966 .55642 Mdot
.56274 .64286 Mdot
.51457 .58919 Mdot
.51929 .63449 Mdot
.61732 .47666 Mdot
.50991 .56431 Mdot
.64487 .49806 Mdot
.26965 .51657 Mdot
.38146 .40087 Mdot
.3341 .58174 Mdot
.30521 .53833 Mdot
.39982 .62035 Mdot
.29597 .38222 Mdot
.58271 .25375 Mdot
.65869 .49545 Mdot
.57866 .36531 Mdot
.53334 .63154 Mdot
.28904 .26979 Mdot
.41382 .33812 Mdot
.40747 .42818 Mdot
.73053 .43098 Mdot
.59009 .67871 Mdot
.22221 .36399 Mdot
.56315 .57866 Mdot
.50612 .84616 Mdot
.55249 .70616 Mdot
.53473 .57511 Mdot
.35565 .37928 Mdot
.29928 .53102 Mdot
.57116 .65711 Mdot
.70675 .47577 Mdot
.31199 .54379 Mdot
.68974 .54575 Mdot
.42791 .45937 Mdot
.28597 .50857 Mdot
.78351 .55991 Mdot
.54016 .61436 Mdot
.3713 .41766 Mdot
.64052 .50995 Mdot
.23963 .63301 Mdot
.56852 .33847 Mdot
.58408 .40596 Mdot
.54931 .50583 Mdot
.80705 .38693 Mdot
.30912 .53981 Mdot
.62262 .6747 Mdot
.56496 .6114 Mdot
.33731 .4731 Mdot
.5816 .65706 Mdot
.60944 .19656 Mdot
.32005 .53014 Mdot
.66532 .45537 Mdot
.58078 .37555 Mdot
.63641 .48465 Mdot
.67259 .65506 Mdot
.33753 .43322 Mdot
.49693 .46423 Mdot
.38461 .41319 Mdot
.45194 .44774 Mdot
.66544 .47949 Mdot
.49133 .63202 Mdot
.1895 .68527 Mdot
.66605 .46795 Mdot
.68556 .51742 Mdot
.83257 .54416 Mdot
.85288 .46572 Mdot
.60737 .63872 Mdot
.69648 .47268 Mdot
.38565 .40742 Mdot
.31614 .56106 Mdot
.53825 .59613 Mdot
.54777 .6113 Mdot
.69753 .48702 Mdot
.35007 .40866 Mdot
.63266 .73958 Mdot
.38982 .38622 Mdot
.64724 .48743 Mdot
.37667 .39668 Mdot
.40313 .301 Mdot
.36091 .42305 Mdot
.56922 .66723 Mdot
.53258 .63451 Mdot
.27719 .37865 Mdot
.67091 .50762 Mdot
.51389 .61736 Mdot
.54151 .58446 Mdot
.67668 .48495 Mdot
.26801 .57082 Mdot
.63814 .72846 Mdot
.52275 .67912 Mdot
.55939 .62449 Mdot
.30534 .57159 Mdot
.57554 .4583 Mdot
.51432 .7808 Mdot
.50332 .61866 Mdot
.33276 .52565 Mdot
.70339 .4703 Mdot
.55066 .65713 Mdot
.54541 .18696 Mdot
.44661 .26926 Mdot
.48788 .64681 Mdot
.36035 .42891 Mdot
.57706 .5826 Mdot
.19896 .36353 Mdot
.57131 .64939 Mdot
.66941 .48676 Mdot
.65783 .52312 Mdot
.76334 .68106 Mdot
.67808 .47387 Mdot
.40912 .41619 Mdot
.55128 .3507 Mdot
.61704 .21198 Mdot
.39735 .43095 Mdot
.58912 .6592 Mdot
.76591 .69351 Mdot
.5029 .60452 Mdot
.55654 .68567 Mdot
.174 .44038 Mdot
.3928 .43114 Mdot
.64152 .52809 Mdot
.40677 .52348 Mdot
.50384 .7059 Mdot
.5395 .3361 Mdot
.47547 .60364 Mdot
.51854 .68632 Mdot
.18563 .46427 Mdot
.48705 .23382 Mdot
.53236 .3324 Mdot
.48461 .61456 Mdot
.50264 .61966 Mdot
.34519 .43511 Mdot
.52697 .64203 Mdot
.31344 .55749 Mdot
.65405 .5281 Mdot
.37013 .43331 Mdot
.33748 .55216 Mdot
.52132 .67157 Mdot
.34115 .56826 Mdot
.36233 .39788 Mdot
.52662 .34462 Mdot
.5063 .66068 Mdot
.29569 .5591 Mdot
.34298 .56511 Mdot
.5339 .60516 Mdot
.662 .51515 Mdot
.55797 .70377 Mdot
.56138 .65279 Mdot
.53143 .59521 Mdot
.69423 .49489 Mdot
.74837 .23569 Mdot
.57648 .63361 Mdot
.38809 .54555 Mdot
.68246 .51748 Mdot
.41361 .47828 Mdot
.37479 .43947 Mdot
.52513 .6866 Mdot
.5294 .33857 Mdot
.54636 .37718 Mdot
.41014 .38198 Mdot
.68144 .52304 Mdot
.24587 .43416 Mdot
.71569 .46932 Mdot
.50504 .70376 Mdot
.48097 .64444 Mdot
.68992 .75454 Mdot
.36734 .20422 Mdot
.63211 .51437 Mdot
.40255 .46646 Mdot
.42478 .54341 Mdot
.56346 .38083 Mdot
.37271 .44814 Mdot
.7001 .50825 Mdot
.66882 .52537 Mdot
.65695 .51028 Mdot
.34154 .53793 Mdot
.27989 .37804 Mdot
.62643 .51533 Mdot
.64021 .46721 Mdot
.55347 .61327 Mdot
.50298 .6208 Mdot
.26856 .62855 Mdot
.34931 .72129 Mdot
.33212 .57849 Mdot
.39582 .38104 Mdot
.41991 .86573 Mdot
.55392 .32263 Mdot
.8044 .53184 Mdot
.56868 .67812 Mdot
.18539 .71656 Mdot
.57364 .59886 Mdot
.5243 .64576 Mdot
.69176 .46343 Mdot
.29819 .57011 Mdot
.32566 .54445 Mdot
.6586 .47673 Mdot
.66009 .44914 Mdot
.31348 .55636 Mdot
.7549 .34855 Mdot
.57052 .18421 Mdot
.33159 .42446 Mdot
.67952 .49131 Mdot
.75969 .63252 Mdot
.53129 .37011 Mdot
.71063 .52165 Mdot
.56699 .32287 Mdot
.37896 .41382 Mdot
.42589 .39065 Mdot
.53847 .34137 Mdot
.55124 .61799 Mdot
.36367 .38251 Mdot
.49453 .60832 Mdot
.76892 .40548 Mdot
.6814 .69025 Mdot
.25214 .39217 Mdot
.54421 .5631 Mdot
.27461 .52279 Mdot
.57307 .27962 Mdot
.53806 .66842 Mdot
.45708 .20553 Mdot
.34904 .55479 Mdot
.66689 .54628 Mdot
.5499 .32662 Mdot
.18494 .37021 Mdot
.50074 .65922 Mdot
.66985 .49024 Mdot
.57076 .37054 Mdot
.44188 .57821 Mdot
.69621 .33575 Mdot
.50401 .65169 Mdot
.21241 .72516 Mdot
.61366 .50028 Mdot
.36728 .42902 Mdot
.58671 .79369 Mdot
.62924 .50766 Mdot
.35698 .50739 Mdot
.29484 .32197 Mdot
.78872 .34408 Mdot
.63699 .51726 Mdot
.37979 .45322 Mdot
.64326 .4827 Mdot
.31348 .56737 Mdot
.68583 .52896 Mdot
.378 .42639 Mdot
.55703 .64567 Mdot
.39958 .38969 Mdot
.35474 .56574 Mdot
.31704 .72632 Mdot
.53032 .33479 Mdot
.36832 .4401 Mdot
.54001 .359 Mdot
.41874 .73408 Mdot
.24466 .35435 Mdot
.57392 .33836 Mdot
.55956 .77227 Mdot
.49127 .66273 Mdot
.62714 .50032 Mdot
.40711 .39104 Mdot
.32697 .31031 Mdot
.42365 .51532 Mdot
.68971 .49153 Mdot
.37713 .38007 Mdot
.55858 .49851 Mdot
.57007 .78012 Mdot
.5806 .57263 Mdot
.42618 .75298 Mdot
.68082 .48748 Mdot
.39186 .45264 Mdot
.24773 .66757 Mdot
.64862 .46691 Mdot
.40721 .40831 Mdot
.58065 .37857 Mdot
.55861 .34916 Mdot
.55959 .66672 Mdot
.59555 .39337 Mdot
.38272 .37469 Mdot
.55962 .28075 Mdot
.70306 .48706 Mdot
.45234 .56189 Mdot
.29814 .54117 Mdot
.38547 .39411 Mdot
.50984 .60437 Mdot
.64371 .54537 Mdot
.41404 .2843 Mdot
.64823 .74026 Mdot
.31526 .78157 Mdot
.40148 .38763 Mdot
.66817 .52405 Mdot
.67012 .49369 Mdot
.60406 .60639 Mdot
.45276 .52198 Mdot
.2496 .42639 Mdot
.43289 .66949 Mdot
.41584 .59529 Mdot
.38728 .36164 Mdot
.34998 .36862 Mdot
.5134 .69519 Mdot
.53541 .61883 Mdot
.56954 .38038 Mdot
.55739 .64101 Mdot
.68269 .46063 Mdot
.56218 .66677 Mdot
.5453 .34236 Mdot
.38842 .41632 Mdot
.51142 .66379 Mdot
.3274 .57675 Mdot
.52062 .35529 Mdot
.58972 .38086 Mdot
.39177 .3945 Mdot
.69773 .49191 Mdot
.27749 .58539 Mdot
.38955 .38449 Mdot
.54067 .61479 Mdot
.60722 .41286 Mdot
.52573 .59508 Mdot
.74929 .50158 Mdot
.64908 .46556 Mdot
.37741 .4356 Mdot
.70458 .48228 Mdot
.54408 .36636 Mdot
.2769 .33075 Mdot
.54186 .6338 Mdot
.40505 .41487 Mdot
.33283 .33558 Mdot
.67684 .56036 Mdot
.68852 .44456 Mdot
.5706 .26985 Mdot
.6574 .45168 Mdot
.42031 .39084 Mdot
.8106 .58861 Mdot
.31707 .53679 Mdot
.40597 .43025 Mdot
.44361 .17667 Mdot
.39855 .40793 Mdot
.56718 .63802 Mdot
.57088 .60374 Mdot
.36684 .43052 Mdot
.30027 .56002 Mdot
.23501 .60533 Mdot
.39324 .35722 Mdot
.64052 .52583 Mdot
.79297 .42263 Mdot
.2389 .70452 Mdot
.60727 .38583 Mdot
.57556 .3764 Mdot
.51599 .71453 Mdot
.52977 .57927 Mdot
.57801 .3311 Mdot
.5892 .38575 Mdot
.35367 .54468 Mdot
.41502 .39703 Mdot
.61618 .47478 Mdot
.55362 .3911 Mdot
.47375 .70054 Mdot
.29216 .39026 Mdot
.59705 .58418 Mdot
.59109 .51299 Mdot
.58059 .65521 Mdot
.41188 .61112 Mdot
.54502 .34069 Mdot
.56004 .58479 Mdot
.58847 .58549 Mdot
.53457 .33518 Mdot
.31331 .55991 Mdot
.61139 .30468 Mdot
.37171 .40265 Mdot
.61404 .1735 Mdot
.54365 .57719 Mdot
.56901 .63807 Mdot
.53077 .35957 Mdot
.25011 .47763 Mdot
.68056 .50925 Mdot
.64216 .47187 Mdot
.35728 .39201 Mdot
.44121 .50243 Mdot
.52731 .68449 Mdot
.54963 .66272 Mdot
.36749 .4095 Mdot
.37766 .44745 Mdot
.51157 .29159 Mdot
.55993 .601 Mdot
.56485 .37104 Mdot
.37191 .59459 Mdot
.5436 .34144 Mdot
.51883 .59897 Mdot
.56944 .63064 Mdot
.56856 .66754 Mdot
.50879 .60572 Mdot
.59632 .37217 Mdot
.56156 .58859 Mdot
.54496 .55124 Mdot
.68209 .51094 Mdot
.50191 .64121 Mdot
.41676 .60277 Mdot
.55516 .63198 Mdot
.31555 .55973 Mdot
.55316 .76126 Mdot
.5017 .65969 Mdot
.53359 .6849 Mdot
.38185 .35049 Mdot
.54427 .64529 Mdot
.55284 .3221 Mdot
.67722 .50227 Mdot
.55041 .37604 Mdot
.53771 .37234 Mdot
.40098 .37478 Mdot
.36095 .54894 Mdot
.54617 .68733 Mdot
.35194 .54779 Mdot
.58997 .65047 Mdot
.48789 .65107 Mdot
.28607 .33871 Mdot
.51821 .84534 Mdot
.3236 .74305 Mdot
.54246 .63203 Mdot
.39586 .42533 Mdot
.37604 .43869 Mdot
.65018 .55925 Mdot
.58594 .57633 Mdot
.58621 .34176 Mdot
.55156 .37945 Mdot
.32173 .6862 Mdot
.19657 .44144 Mdot
.31487 .55974 Mdot
.54543 .46818 Mdot
.48334 .62269 Mdot
.54168 .58654 Mdot
.51604 .59419 Mdot
.36536 .36969 Mdot
.40359 .56385 Mdot
.40411 .43085 Mdot
.71893 .40714 Mdot
.53542 .34792 Mdot
.49973 .65503 Mdot
.62315 .43295 Mdot
.66146 .46514 Mdot
.67645 .50266 Mdot
.59011 .37719 Mdot
.38433 .34265 Mdot
.27228 .65277 Mdot
.83948 .38479 Mdot
.61163 .51882 Mdot
.30764 .58158 Mdot
.53673 .67155 Mdot
.39126 .41008 Mdot
.64669 .47645 Mdot
.32024 .5834 Mdot
.48934 .63315 Mdot
.28055 .37677 Mdot
.54414 .62656 Mdot
.5861 .47945 Mdot
.65161 .51668 Mdot
.59987 .1953 Mdot
.65972 .53333 Mdot
.51977 .35247 Mdot
.55261 .32813 Mdot
.57174 .61434 Mdot
.64233 .78059 Mdot
.6326 .48779 Mdot
.58371 .30911 Mdot
.33115 .53018 Mdot
.4311 .28516 Mdot
.3109 .56308 Mdot
.36957 .42926 Mdot
.31054 .54271 Mdot
.37551 .42734 Mdot
.32116 .70687 Mdot
.65385 .43622 Mdot
.34138 .54893 Mdot
.31716 .38431 Mdot
.58659 .57264 Mdot
.32314 .58047 Mdot
.48969 .69231 Mdot
.74685 .51654 Mdot
.36743 .40391 Mdot
.31196 .53562 Mdot
.49246 .62943 Mdot
.2677 .27057 Mdot
.58494 .36157 Mdot
.5822 .33699 Mdot
.50056 .6998 Mdot
.39437 .36783 Mdot
.70746 .48347 Mdot
.55685 .21175 Mdot
.51712 .33851 Mdot
.57489 .62419 Mdot
.56919 .65948 Mdot
.64768 .45831 Mdot
.69809 .42738 Mdot
.57057 .61975 Mdot
.49784 .73386 Mdot
.56336 .60146 Mdot
.5883 .37428 Mdot
.63575 .4877 Mdot
.67305 .49749 Mdot
.37319 .38036 Mdot
.68604 .46693 Mdot
.6255 .56916 Mdot
.64015 .40858 Mdot
.54407 .72273 Mdot
.54793 .36448 Mdot
.68852 .40441 Mdot
.72176 .40997 Mdot
.38891 .20076 Mdot
.63813 .4656 Mdot
.58281 .64568 Mdot
.69976 .49639 Mdot
.32199 .56549 Mdot
.66583 .50566 Mdot
.7032 .50164 Mdot
.54093 .66183 Mdot
.50814 .65279 Mdot
.38758 .42603 Mdot
.44177 .5276 Mdot
.694 .50185 Mdot
.56921 .59568 Mdot
.51931 .58315 Mdot
.50809 .59701 Mdot
.50254 .40725 Mdot
.63142 .50534 Mdot
.82666 .48839 Mdot
.34392 .62859 Mdot
.69494 .50027 Mdot
.1615 .41766 Mdot
.35196 .30724 Mdot
.42078 .43222 Mdot
.55039 .39411 Mdot
.55899 .59907 Mdot
.38419 .4443 Mdot
.50872 .65782 Mdot
.59037 .51273 Mdot
.53925 .65235 Mdot
.31167 .55501 Mdot
.50116 .60042 Mdot
.41997 .38599 Mdot
.39411 .38577 Mdot
.57461 .63961 Mdot
.51602 .66376 Mdot
.30181 .70853 Mdot
.64108 .45625 Mdot
.67336 .51073 Mdot
.23968 .45398 Mdot
.34024 .56115 Mdot
.54115 .33471 Mdot
.52494 .63631 Mdot
.39075 .36983 Mdot
.39699 .38646 Mdot
.62971 .50239 Mdot
.37363 .387 Mdot
.55144 .33742 Mdot
.53855 .63631 Mdot
.57777 .33135 Mdot
.34357 .53826 Mdot
.63391 .49738 Mdot
.50272 .6464 Mdot
.55371 .61352 Mdot
.65731 .52327 Mdot
.52353 .69428 Mdot
.30514 .57036 Mdot
.40022 .40565 Mdot
.63665 .51095 Mdot
.55314 .35026 Mdot
.37274 .43016 Mdot
.54025 .59206 Mdot
.38053 .84062 Mdot
.56564 .63444 Mdot
.55485 .596 Mdot
.43588 .17253 Mdot
.49044 .61079 Mdot
.40497 .38874 Mdot
.65942 .45782 Mdot
.53414 .56556 Mdot
.39132 .62817 Mdot
.79918 .3012 Mdot
.40861 .42555 Mdot
.54085 .67163 Mdot
.30907 .24169 Mdot
.55205 .66484 Mdot
.70247 .73365 Mdot
.32686 .43674 Mdot
.4363 .47526 Mdot
.55285 .69904 Mdot
.56687 .34623 Mdot
.38911 .42726 Mdot
.36903 .42455 Mdot
.80224 .46482 Mdot
.5442 .66231 Mdot
.57057 .48054 Mdot
.49428 .63984 Mdot
.5541 .34525 Mdot
.31029 .66204 Mdot
.39916 .38557 Mdot
.35378 .78719 Mdot
.54269 .60317 Mdot
.63967 .53207 Mdot
.42225 .36584 Mdot
.40931 .31791 Mdot
.53262 .59546 Mdot
.35282 .55702 Mdot
.53812 .38259 Mdot
.51664 .57682 Mdot
.54884 .36007 Mdot
.52808 .59609 Mdot
.5179 .74155 Mdot
.58462 .80291 Mdot
.65935 .51333 Mdot
.57914 .37739 Mdot
.60561 .40912 Mdot
.57889 .59652 Mdot
.63713 .5157 Mdot
.68786 .49843 Mdot
.35532 .55 Mdot
.5148 .45237 Mdot
.67019 .33905 Mdot
.7042 .69541 Mdot
.80484 .44582 Mdot
.41082 .35481 Mdot
.50594 .25444 Mdot
.52676 .6029 Mdot
.21702 .47883 Mdot
.54006 .32698 Mdot
.56554 .64318 Mdot
.66353 .58013 Mdot
.656 .47308 Mdot
.56226 .62087 Mdot
.31875 .55082 Mdot
.22716 .49794 Mdot
.21828 .50564 Mdot
.30096 .30154 Mdot
.38313 .41304 Mdot
.46749 .64455 Mdot
.55467 .7299 Mdot
.35337 .40317 Mdot
.50794 .68475 Mdot
.4061 .4031 Mdot
.77697 .36691 Mdot
.31229 .58079 Mdot
.63421 .51978 Mdot
.37742 .31301 Mdot
.53288 .68814 Mdot
.47998 .64416 Mdot
.34909 .57785 Mdot
.53141 .61794 Mdot
.54325 .82016 Mdot
.37009 .32473 Mdot
.35841 .39971 Mdot
.65758 .51104 Mdot
.54441 .68359 Mdot
.5291 .45475 Mdot
.55918 .65575 Mdot
.73397 .62464 Mdot
.53764 .68417 Mdot
.6818 .33468 Mdot
.65688 .51878 Mdot
.54546 .35958 Mdot
.5825 .59941 Mdot
.53287 .65146 Mdot
.35163 .60925 Mdot
.5471 .70842 Mdot
.56823 .58871 Mdot
.70721 .46532 Mdot
.64713 .47339 Mdot
.64601 .49697 Mdot
.4198 .42023 Mdot
.19054 .45354 Mdot
.55598 .3727 Mdot
.53254 .55913 Mdot
.56627 .39474 Mdot
.62787 .76221 Mdot
.31129 .5823 Mdot
.3189 .2579 Mdot
.51291 .62993 Mdot
.65347 .49248 Mdot
.45693 .22464 Mdot
.6996 .46221 Mdot
.51957 .47991 Mdot
.56879 .36241 Mdot
.66166 .47156 Mdot
.52651 .64941 Mdot
.42334 .53025 Mdot
.26651 .29721 Mdot
.5412 .3691 Mdot
.59189 .65023 Mdot
.39813 .44606 Mdot
.25219 .37793 Mdot
.35819 .82462 Mdot
.58596 .3641 Mdot
.59473 .4113 Mdot
.5437 .66414 Mdot
.6616 .46337 Mdot
.56242 .34221 Mdot
.58229 .34904 Mdot
.37185 .38719 Mdot
.50762 .64962 Mdot
.50759 .64503 Mdot
.42465 .40218 Mdot
.54257 .37318 Mdot
.52987 .70615 Mdot
.54074 .572 Mdot
.25331 .26041 Mdot
.50374 .52096 Mdot
.64397 .17524 Mdot
.62048 .56805 Mdot
.6484 .60756 Mdot
.57822 .20937 Mdot
.67325 .52343 Mdot
.50246 .66348 Mdot
.4903 .5902 Mdot
.38418 .37495 Mdot
.54967 .63903 Mdot
.37612 .46253 Mdot
.57167 .37449 Mdot
.17717 .39504 Mdot
.67053 .38453 Mdot
.77293 .34364 Mdot
.55001 .64144 Mdot
.73335 .44566 Mdot
.33015 .55643 Mdot
.55892 .31393 Mdot
.64045 .49608 Mdot
.5 .61513 Mdot
.30249 .71067 Mdot
.40469 .43103 Mdot
.69053 .4781 Mdot
.24387 .63567 Mdot
.28007 .52041 Mdot
.51683 .60085 Mdot
.40889 .43424 Mdot
.47194 .21343 Mdot
.45021 .66316 Mdot
.53037 .31939 Mdot
.31124 .55765 Mdot
.38733 .43148 Mdot
.54376 .37722 Mdot
.60708 .52245 Mdot
.6697 .4713 Mdot
.70714 .50322 Mdot
.37988 .77305 Mdot
.35356 .41626 Mdot
.33168 .55263 Mdot
.20552 .42933 Mdot
.20731 .50932 Mdot
.31256 .55337 Mdot
.42729 .39398 Mdot
.64674 .47482 Mdot
.65618 .48192 Mdot
.67771 .50154 Mdot
.32335 .7579 Mdot
.66558 .52936 Mdot
.8016 .5067 Mdot
.49872 .60782 Mdot
.52272 .7341 Mdot
.54499 .66922 Mdot
.58485 .33833 Mdot
.64699 .52063 Mdot
.42771 .49978 Mdot
.59481 .60487 Mdot
.26377 .32059 Mdot
.56509 .6539 Mdot
.57933 .32543 Mdot
.56074 .61199 Mdot
.7911 .56283 Mdot
.69691 .50248 Mdot
.54549 .63416 Mdot
.55068 .31838 Mdot
.33463 .56828 Mdot
.71107 .45496 Mdot
.50262 .65191 Mdot
.59419 .25756 Mdot
.49411 .60678 Mdot
.74569 .32028 Mdot
.46825 .54627 Mdot
.30755 .58146 Mdot
.55326 .52892 Mdot
.36462 .4494 Mdot
.53322 .73283 Mdot
.47523 .68661 Mdot
.53823 .36189 Mdot
.38466 .29821 Mdot
.38239 .40203 Mdot
.36473 .50633 Mdot
.47877 .59266 Mdot
.34846 .5727 Mdot
.65298 .44963 Mdot
.58703 .33776 Mdot
.49602 .6754 Mdot
.59902 .59396 Mdot
.7728 .4318 Mdot
.48064 .58381 Mdot
.56363 .66704 Mdot
.33096 .58629 Mdot
.78765 .48501 Mdot
.55399 .62726 Mdot
.52667 .47503 Mdot
.68278 .52858 Mdot
.52995 .70856 Mdot
.80899 .52979 Mdot
.57208 .60405 Mdot
.68179 .47018 Mdot
.6924 .4427 Mdot
.62697 .32761 Mdot
.34918 .53608 Mdot
.52605 .68609 Mdot
.76705 .676 Mdot
.54084 .60735 Mdot
.56175 .36967 Mdot
.53144 .58095 Mdot
.37909 .42388 Mdot
.30586 .73416 Mdot
.37078 .37756 Mdot
.52601 .6816 Mdot
.67965 .49775 Mdot
.53076 .35079 Mdot
.38714 .78997 Mdot
.27242 .40774 Mdot
.79345 .50465 Mdot
.76889 .309 Mdot
.30463 .54724 Mdot
.36292 .54652 Mdot
.58918 .33934 Mdot
.54639 .63262 Mdot
.82273 .57486 Mdot
.54303 .71123 Mdot
.55926 .62229 Mdot
.53801 .6535 Mdot
.23313 .37887 Mdot
.56406 .37932 Mdot
.3733 .39405 Mdot
.57004 .62423 Mdot
.56389 .58849 Mdot
.67533 .52169 Mdot
.33984 .56657 Mdot
.37539 .43949 Mdot
.34468 .54638 Mdot
.3924 .41938 Mdot
.16732 .40575 Mdot
.57727 .58464 Mdot
.33325 .5668 Mdot
.52138 .36956 Mdot
.69657 .48963 Mdot
.63501 .40724 Mdot
.3687 .42693 Mdot
.39304 .37903 Mdot
.57153 .64426 Mdot
.68046 .46853 Mdot
.69994 .47206 Mdot
.32173 .56731 Mdot
.56705 .3347 Mdot
.50364 .66105 Mdot
.48632 .64982 Mdot
.75092 .47161 Mdot
.38743 .36682 Mdot
.57905 .49461 Mdot
.55433 .24185 Mdot
.54437 .63078 Mdot
.70017 .47764 Mdot
.52693 .66239 Mdot
.60184 .22249 Mdot
.66901 .46279 Mdot
.57409 .60452 Mdot
.20509 .57251 Mdot
.38775 .34155 Mdot
.64265 .3421 Mdot
.57303 .6594 Mdot
.68139 .23254 Mdot
.51398 .61329 Mdot
.20585 .29923 Mdot
.31072 .43171 Mdot
.50549 .67475 Mdot
.54439 .59328 Mdot
.6611 .71329 Mdot
.52178 .67454 Mdot
.42074 .39041 Mdot
.25548 .60165 Mdot
.70874 .48163 Mdot
.61916 .26682 Mdot
.58329 .7363 Mdot
.31806 .53098 Mdot
.35688 .39407 Mdot
.34006 .39181 Mdot
.32 .5443 Mdot
.67764 .48951 Mdot
.53785 .62643 Mdot
.46867 .47477 Mdot
.37596 .3612 Mdot
.59775 .56071 Mdot
.56285 .36737 Mdot
.47552 .29241 Mdot
.36563 .33941 Mdot
.54798 .35232 Mdot
.50188 .63666 Mdot
.65069 .72164 Mdot
.42043 .77273 Mdot
.55903 .17356 Mdot
.53754 .37361 Mdot
.53679 .36492 Mdot
.30346 .74073 Mdot
.29674 .53982 Mdot
.77985 .42123 Mdot
.68812 .33311 Mdot
.53642 .33959 Mdot
.44177 .60336 Mdot
.4144 .41117 Mdot
.61032 .27818 Mdot
.66969 .54574 Mdot
.4849 .62974 Mdot
.52863 .64991 Mdot
.56178 .33187 Mdot
.67858 .55822 Mdot
.57338 .79732 Mdot
.53951 .35675 Mdot
.49376 .56662 Mdot
.4877 .42244 Mdot
.34449 .30701 Mdot
.41014 .38462 Mdot
.35236 .53927 Mdot
.37435 .55567 Mdot
.6462 .53171 Mdot
.35719 .54369 Mdot
.22439 .49157 Mdot
.52543 .62343 Mdot
.54076 .34759 Mdot
.41746 .28524 Mdot
.55698 .35285 Mdot
.32323 .54374 Mdot
.31248 .58535 Mdot
.68194 .51088 Mdot
.67031 .51017 Mdot
.65047 .62763 Mdot
.34311 .67863 Mdot
.55998 .65996 Mdot
.34214 .27161 Mdot
.7037 .48387 Mdot
.60515 .56499 Mdot
.36216 .55336 Mdot
.33834 .56529 Mdot
.38471 .59583 Mdot
.51516 .63638 Mdot
.73459 .70682 Mdot
.51916 .63726 Mdot
.31821 .66559 Mdot
.57537 .66754 Mdot
.37268 .38693 Mdot
.5103 .63682 Mdot
.28017 .59743 Mdot
.50112 .68409 Mdot
.54109 .57467 Mdot
.37553 .36499 Mdot
.51727 .57426 Mdot
.37785 .42196 Mdot
.53991 .67854 Mdot
.30806 .5324 Mdot
.37053 .37068 Mdot
.39282 .6564 Mdot
.38904 .5714 Mdot
.42889 .4031 Mdot
.3551 .56323 Mdot
.31014 .53406 Mdot
.41418 .67425 Mdot
.64023 .49547 Mdot
.70303 .52175 Mdot
.54881 .63446 Mdot
.35724 .44111 Mdot
.56962 .37899 Mdot
.56297 .59163 Mdot
.50149 .59118 Mdot
.57944 .643 Mdot
.64164 .53143 Mdot
.2515 .418 Mdot
.32745 .56844 Mdot
.42176 .41349 Mdot
.26817 .57605 Mdot
.40627 .37383 Mdot
.57152 .57073 Mdot
.47729 .60927 Mdot
.63584 .63699 Mdot
.41722 .25616 Mdot
.29443 .74393 Mdot
.67311 .47094 Mdot
.3625 .43197 Mdot
.30166 .53728 Mdot
.60657 .58947 Mdot
.64982 .48843 Mdot
.37798 .42581 Mdot
.54332 .62705 Mdot
.59354 .64618 Mdot
.7056 .41736 Mdot
.57801 .72735 Mdot
.40252 .59871 Mdot
.41217 .38248 Mdot
.37604 .45148 Mdot
.21088 .50044 Mdot
.28341 .53271 Mdot
.42486 .51041 Mdot
.55301 .65344 Mdot
.35265 .55454 Mdot
.64699 .47617 Mdot
.4017 .77537 Mdot
.56604 .33021 Mdot
.44631 .52522 Mdot
.54855 .64065 Mdot
.41657 .48164 Mdot
.68089 .4984 Mdot
.31758 .55394 Mdot
.5591 .33125 Mdot
.35859 .57508 Mdot
.35513 .3887 Mdot
.81854 .38728 Mdot
.53757 .61091 Mdot
.5685 .65348 Mdot
.52266 .3428 Mdot
.65102 .47634 Mdot
.35634 .57301 Mdot
.77097 .40239 Mdot
.36168 .40739 Mdot
.8177 .5947 Mdot
.68703 .46499 Mdot
.77909 .5758 Mdot
.42105 .41062 Mdot
.58949 .37824 Mdot
.40804 .67997 Mdot
.54723 .34213 Mdot
.53431 .68226 Mdot
.66309 .49598 Mdot
.58138 .36858 Mdot
.44535 .53738 Mdot
.29505 .25429 Mdot
.76854 .61384 Mdot
.52645 .62901 Mdot
.22987 .30876 Mdot
.69613 .2841 Mdot
.63267 .46278 Mdot
.52765 .34004 Mdot
.56504 .65038 Mdot
.50037 .67461 Mdot
.54396 .60699 Mdot
.57587 .36187 Mdot
.31107 .32346 Mdot
.36598 .40603 Mdot
.5443 .66687 Mdot
.35307 .5445 Mdot
.37682 .41378 Mdot
.38128 .3135 Mdot
.40104 .38348 Mdot
.63187 .46954 Mdot
.52961 .58129 Mdot
.59589 .33566 Mdot
.16436 .36372 Mdot
.54728 .37421 Mdot
.42852 .3932 Mdot
.54801 .58061 Mdot
.41248 .2774 Mdot
.64708 .49483 Mdot
.36155 .40047 Mdot
.56877 .63919 Mdot
.37069 .3143 Mdot
.32061 .73347 Mdot
.40091 .38415 Mdot
.64784 .484 Mdot
.51795 .18486 Mdot
.5546 .63993 Mdot
.52027 .61106 Mdot
.6615 .47635 Mdot
.59086 .75025 Mdot
.24704 .66065 Mdot
.52035 .66353 Mdot
.54475 .35771 Mdot
.85267 .51427 Mdot
.55253 .56993 Mdot
.32292 .63277 Mdot
.38732 .42836 Mdot
.61196 .29252 Mdot
.5667 .4988 Mdot
.60784 .59239 Mdot
.76683 .40445 Mdot
.56248 .42486 Mdot
.22135 .34687 Mdot
.38119 .46255 Mdot
.31467 .49515 Mdot
.20417 .35766 Mdot
.56882 .32099 Mdot
.70325 .43682 Mdot
.74208 .35526 Mdot
.41154 .82065 Mdot
.52012 .19255 Mdot
.26238 .49652 Mdot
.29823 .70744 Mdot
.47119 .45589 Mdot
.39688 .41603 Mdot
.3395 .5938 Mdot
.50524 .65636 Mdot
.69264 .28001 Mdot
.75311 .68092 Mdot
.65093 .78483 Mdot
.2338 .30235 Mdot
.69689 .73191 Mdot
.29204 .26737 Mdot
.40416 .19195 Mdot
.63746 .59894 Mdot
.43231 .24537 Mdot
.81802 .60645 Mdot
.20615 .55475 Mdot
.81569 .44518 Mdot
.53515 .72586 Mdot
.52797 .4844 Mdot
.75169 .31017 Mdot
.78304 .53632 Mdot
.5785 .78504 Mdot
.36944 .38188 Mdot
.65328 .45933 Mdot
.73027 .3428 Mdot
.67047 .44659 Mdot
.61797 .36479 Mdot
.52611 .17893 Mdot
.31319 .23407 Mdot
.79455 .55823 Mdot
.64075 .20051 Mdot
.67938 .57737 Mdot
.65838 .8237 Mdot
.38624 .35781 Mdot
.62958 .51489 Mdot
.34718 .51198 Mdot
.20691 .49545 Mdot
.72849 .39821 Mdot
.73103 .33048 Mdot
.27486 .3519 Mdot
.38802 .70661 Mdot
.67126 .49082 Mdot
.53783 .52713 Mdot
.58956 .29798 Mdot
.67803 .38828 Mdot
.25461 .60573 Mdot
.44328 .18855 Mdot
.47181 .4844 Mdot
.60462 .26386 Mdot
.49063 .27407 Mdot
.35475 .81876 Mdot
.35954 .62146 Mdot
.6194 .59431 Mdot
.61111 .41542 Mdot
.58898 .2112 Mdot
.45251 .82436 Mdot
.34636 .69604 Mdot
.20709 .5001 Mdot
.17321 .49867 Mdot
.65816 .24289 Mdot
.17263 .59279 Mdot
.69727 .52406 Mdot
.56677 .66379 Mdot
.61751 .71388 Mdot
.77713 .66083 Mdot
.29838 .57975 Mdot
.30976 .30126 Mdot
.32456 .5322 Mdot
.6211 .5264 Mdot
.29145 .71327 Mdot
.80358 .51925 Mdot
.77723 .6677 Mdot
.36623 .54004 Mdot
.54649 .56381 Mdot
.89565 .48142 Mdot
.24225 .32969 Mdot
.64318 .3676 Mdot
.23961 .27074 Mdot
.40864 .49741 Mdot
.44588 .57307 Mdot
.58011 .36834 Mdot
.20189 .34871 Mdot
.65882 .48672 Mdot
.14913 .54105 Mdot
.19823 .31963 Mdot
.5234 .77471 Mdot
.65778 .14292 Mdot
.21227 .45263 Mdot
.42919 .48045 Mdot
.54829 .41443 Mdot
.37437 .64388 Mdot
.53761 .8054 Mdot
.50867 .75652 Mdot
.43571 .2703 Mdot
.75416 .28962 Mdot
.21707 .33889 Mdot
.797 .62813 Mdot
.81982 .40573 Mdot
.43424 .83009 Mdot
.54755 .45472 Mdot
.69573 .53676 Mdot
.34393 .3641 Mdot
.41985 .20807 Mdot
.16493 .44698 Mdot
.34271 .62589 Mdot
.81493 .31692 Mdot
.27432 .56113 Mdot
.29885 .42942 Mdot
.52801 .16704 Mdot
.39944 .70673 Mdot
.51765 .52661 Mdot
.24179 .58529 Mdot
.59933 .56805 Mdot
.24474 .55221 Mdot
.34116 .26011 Mdot
.6206 .39967 Mdot
.21093 .55311 Mdot
.51577 .20774 Mdot
.77029 .4314 Mdot
.68892 .68113 Mdot
.201 .50188 Mdot
.70109 .45978 Mdot
.36935 .70047 Mdot
.51291 .52414 Mdot
.30257 .2374 Mdot
.59129 .41126 Mdot
.35377 .19487 Mdot
.25297 .66281 Mdot
.58774 .62497 Mdot
.4893 .70062 Mdot
.5137 .55317 Mdot
.35459 .6788 Mdot
.53679 .5703 Mdot
.72851 .41761 Mdot
.36551 .20172 Mdot
.69987 .56036 Mdot
.60663 .3052 Mdot
.37607 .30134 Mdot
.54517 .16637 Mdot
.64223 .67196 Mdot
.28968 .52556 Mdot
.28158 .64217 Mdot
.40513 .83358 Mdot
.37929 .3999 Mdot
.80377 .60791 Mdot
.53191 .31776 Mdot
.34665 .74921 Mdot
.70469 .69897 Mdot
.51558 .78972 Mdot
.36707 .20072 Mdot
.26755 .51593 Mdot
.27717 .68936 Mdot
.42976 .7388 Mdot
.83574 .54382 Mdot
.35066 .29713 Mdot
.47532 .60538 Mdot
.6712 .27865 Mdot
.2997 .5587 Mdot
.66662 .65304 Mdot
.83634 .49533 Mdot
.26796 .46074 Mdot
.48345 .67634 Mdot
.4737 .78727 Mdot
.44286 .37358 Mdot
.42566 .52898 Mdot
.2298 .70834 Mdot
.59049 .57665 Mdot
.20263 .43894 Mdot
.67854 .25551 Mdot
.35601 .64706 Mdot
.57843 .1928 Mdot
.56654 .2228 Mdot
.16646 .56064 Mdot
.2238 .29602 Mdot
.26549 .41305 Mdot
.19926 .37452 Mdot
.28141 .24525 Mdot
.17833 .58503 Mdot
.46441 .67303 Mdot
.52115 .34221 Mdot
.32181 .81904 Mdot
.41832 .39116 Mdot
.21955 .39311 Mdot
.80488 .44699 Mdot
.39495 .32313 Mdot
.61784 .46897 Mdot
.5846 .70812 Mdot
.47572 .46062 Mdot
.62711 .47193 Mdot
.52401 .57251 Mdot
.23618 .69534 Mdot
.17548 .54487 Mdot
.20556 .64747 Mdot
.68074 .24429 Mdot
.18578 .3908 Mdot
.46069 .43867 Mdot
.79149 .52991 Mdot
.65197 .55809 Mdot
.49238 .62044 Mdot
.37797 .51721 Mdot
.21342 .44898 Mdot
.4692 .78982 Mdot
.71661 .37812 Mdot
.64623 .45251 Mdot
.32292 .2835 Mdot
.68511 .84016 Mdot
.6686 .59713 Mdot
.81465 .52186 Mdot
.21526 .50534 Mdot
.34183 .6689 Mdot
.40014 .22262 Mdot
.51959 .78163 Mdot
.42553 .17915 Mdot
.62098 .48214 Mdot
.80991 .43849 Mdot
.27734 .48561 Mdot
.42896 .6336 Mdot
.2544 .40897 Mdot
.32662 .2349 Mdot
.48855 .37828 Mdot
.43217 .79602 Mdot
.69615 .32591 Mdot
.5433 .78566 Mdot
.32872 .44881 Mdot
.48397 .29165 Mdot
.83369 .50366 Mdot
.50958 .24121 Mdot
.32102 .65144 Mdot
.49442 .43264 Mdot
.58009 .53283 Mdot
.56121 .42376 Mdot
.32699 .64861 Mdot
.4209 .62495 Mdot
.19348 .406 Mdot
.15222 .34169 Mdot
.30454 .76538 Mdot
.61324 .17695 Mdot
.36496 .24818 Mdot
.4877 .67902 Mdot
.48278 .15531 Mdot
.18621 .63007 Mdot
.18747 .32189 Mdot
.48004 .32912 Mdot
.37737 .46442 Mdot
.58296 .39364 Mdot
.24792 .69451 Mdot
.30353 .3487 Mdot
.4702 .16862 Mdot
.23807 .57632 Mdot
.57549 .39777 Mdot
.52892 .84484 Mdot
.18097 .51699 Mdot
.72767 .67972 Mdot
.58458 .72032 Mdot
.54039 .69906 Mdot
.78896 .59447 Mdot
.65962 .45003 Mdot
.51185 .25621 Mdot
.35067 .68982 Mdot
.38802 .39109 Mdot
.37963 .52406 Mdot
.71752 .31562 Mdot
.49984 .6017 Mdot
.59413 .43136 Mdot
.63707 .47016 Mdot
.42353 .25324 Mdot
.65922 .40281 Mdot
.15907 .44396 Mdot
.23222 .41459 Mdot
.57179 .68192 Mdot
.35322 .64272 Mdot
.24814 .41354 Mdot
.2464 .66659 Mdot
.60001 .36091 Mdot
.25271 .28381 Mdot
.49992 .49754 Mdot
.36649 .69878 Mdot
.77541 .63297 Mdot
.74638 .50841 Mdot
.47942 .6161 Mdot
.51857 .22836 Mdot
.72782 .61486 Mdot
.43529 .53139 Mdot
.66273 .54931 Mdot
.72053 .51257 Mdot
.50289 .14749 Mdot
.22866 .50379 Mdot
.47753 .28082 Mdot
.27538 .26751 Mdot
.56766 .35357 Mdot
.70076 .49017 Mdot
.37408 .57977 Mdot
.77335 .38958 Mdot
.75137 .58384 Mdot
.32121 .73445 Mdot
.38492 .32669 Mdot
.27872 .45269 Mdot
.2809 .26878 Mdot
.24644 .29562 Mdot
.70666 .75592 Mdot
.68367 .44272 Mdot
.64021 .57862 Mdot
.78618 .40825 Mdot
.66586 .4531 Mdot
.76133 .43757 Mdot
.74193 .42956 Mdot
.1724 .42999 Mdot
.61186 .37398 Mdot
.73795 .27217 Mdot
.4047 .61929 Mdot
.3016 .32275 Mdot
.38202 .7892 Mdot
.83163 .50981 Mdot
.30137 .25922 Mdot
.44355 .6315 Mdot
.67144 .72312 Mdot
.54271 .72478 Mdot
.60504 .47978 Mdot
.42304 .85473 Mdot
.37956 .57959 Mdot
.7809 .5764 Mdot
.5198 .20503 Mdot
.53757 .6196 Mdot
.30949 .77509 Mdot
.7582 .3633 Mdot
.30313 .74337 Mdot
.55409 .39254 Mdot
.50101 .6249 Mdot
.49162 .67523 Mdot
.29827 .63081 Mdot
.62918 .3288 Mdot
.19081 .43282 Mdot
.84535 .48258 Mdot
.47509 .20745 Mdot
.75207 .68161 Mdot
.2092 .42938 Mdot
.46724 .17616 Mdot
.68438 .27267 Mdot
.51418 .46227 Mdot
.21789 .4428 Mdot
.40482 .69885 Mdot
.64227 .20455 Mdot
.41037 .57172 Mdot
.50818 .32844 Mdot
.74477 .40839 Mdot
.56191 .23902 Mdot
.39781 .78152 Mdot
.51503 .60589 Mdot
.24382 .63543 Mdot
.42081 .18941 Mdot
.72511 .73027 Mdot
.51145 .82379 Mdot
.28704 .75258 Mdot
.72747 .64464 Mdot
.56147 .23185 Mdot
.68883 .28216 Mdot
.84334 .58235 Mdot
.50504 .4997 Mdot
.28173 .30232 Mdot
.41164 .71389 Mdot
.27913 .26773 Mdot
.52675 .33334 Mdot
.70519 .34533 Mdot
.37074 .30223 Mdot
.19323 .39268 Mdot
.6443 .69393 Mdot
.35277 .2196 Mdot
.42748 .48892 Mdot
.16022 .54469 Mdot
.48712 .23641 Mdot
.47099 .44506 Mdot
.35798 .42026 Mdot
.25763 .52125 Mdot
.33367 .25779 Mdot
.39696 .25227 Mdot
.82732 .51329 Mdot
.39439 .45322 Mdot
.36028 .587 Mdot
.73237 .68768 Mdot
.41064 .74313 Mdot
.53209 .22382 Mdot
.35359 .64294 Mdot
.34119 .21821 Mdot
.26891 .60522 Mdot
.25068 .6425 Mdot
.22259 .41238 Mdot
.8087 .34909 Mdot
.64173 .36192 Mdot
.22831 .52527 Mdot
.74759 .34702 Mdot
.30162 .41738 Mdot
.44579 .59096 Mdot
.06496 .52971 Mdot
.80369 .36915 Mdot
.45692 .24027 Mdot
.16527 .44703 Mdot
.60072 .21529 Mdot
.42341 .25603 Mdot
.52885 .80382 Mdot
.50712 .51878 Mdot
.30145 .69223 Mdot
.53776 .6526 Mdot
.21635 .67957 Mdot
.38737 .72554 Mdot
.16032 .47705 Mdot
.49813 .15538 Mdot
.78314 .60563 Mdot
.50914 .59172 Mdot
.4159 .42429 Mdot
.61617 .38189 Mdot
.39195 .74826 Mdot
.62714 .73429 Mdot
.49197 .54341 Mdot
.35235 .32322 Mdot
.35313 .40611 Mdot
.24156 .43578 Mdot
.61339 .52323 Mdot
.3014 .3434 Mdot
.55253 .23943 Mdot
.40024 .34561 Mdot
.47091 .49369 Mdot
.33431 .65414 Mdot
.56412 .50277 Mdot
.73229 .67279 Mdot
.50291 .78792 Mdot
.55784 .44285 Mdot
.4012 .38201 Mdot
.71123 .68375 Mdot
.76656 .3207 Mdot
.47903 .21406 Mdot
.17059 .49178 Mdot
.25475 .55179 Mdot
.64351 .7452 Mdot
.3187 .6452 Mdot
.54888 .8048 Mdot
.62532 .77513 Mdot
.3719 .27559 Mdot
.60214 .51923 Mdot
.58054 .77647 Mdot
.68275 .29386 Mdot
.17806 .39029 Mdot
.81457 .44397 Mdot
.79425 .41573 Mdot
.32031 .3861 Mdot
.77189 .54275 Mdot
.76299 .64971 Mdot
.39726 .65193 Mdot
.42615 .51622 Mdot
.62348 .83886 Mdot
.68989 .53654 Mdot
.49014 .88765 Mdot
.58786 .37244 Mdot
.44758 .83897 Mdot
.41323 .70295 Mdot
.49633 .42776 Mdot
.40097 .51092 Mdot
.52642 .23325 Mdot
.68535 .33787 Mdot
.69974 .26316 Mdot
.62609 .78695 Mdot
.39329 .36526 Mdot
.8487 .47857 Mdot
.81342 .35048 Mdot
.67906 .7048 Mdot
.56268 .57305 Mdot
.80188 .3569 Mdot
.39081 .46298 Mdot
.47084 .79093 Mdot
.57937 .19025 Mdot
.40777 .23967 Mdot
.46231 .67717 Mdot
.34549 .67472 Mdot
.28408 .29756 Mdot
.24971 .2774 Mdot
.5385 .83252 Mdot
.34278 .25966 Mdot
.52406 .33817 Mdot
.46059 .44862 Mdot
.35943 .2235 Mdot
.44321 .56691 Mdot
.62111 .28043 Mdot
.49277 .53676 Mdot
.56632 .87856 Mdot
.22299 .37776 Mdot
.19219 .43016 Mdot
.46807 .54828 Mdot
.67604 .52645 Mdot
.62167 .32615 Mdot
.52192 .52473 Mdot
.42498 .23443 Mdot
.75392 .32301 Mdot
.5187 .52377 Mdot
.79762 .67656 Mdot
.74497 .51782 Mdot
.45405 .419 Mdot
.75063 .67416 Mdot
.69402 .56037 Mdot
.5524 .39245 Mdot
.25711 .62978 Mdot
.50438 .19998 Mdot
.51816 .3531 Mdot
.52616 .22261 Mdot
.5982 .26448 Mdot
.76598 .49366 Mdot
.75514 .59178 Mdot
.44445 .21359 Mdot
.64469 .71668 Mdot
.68435 .42765 Mdot
.39374 .77095 Mdot
.43203 .39896 Mdot
.50469 .19445 Mdot
.35987 .41462 Mdot
.60763 .57094 Mdot
.44662 .52899 Mdot
.52804 .75146 Mdot
.28169 .73428 Mdot
.30355 .54808 Mdot
.63414 .48798 Mdot
.47091 .851 Mdot
.67391 .45692 Mdot
.22614 .6815 Mdot
.51861 .78688 Mdot
.77732 .63088 Mdot
.26694 .42146 Mdot
.25357 .46527 Mdot
.72233 .76778 Mdot
.59576 .42453 Mdot
.34795 .35363 Mdot
.6425 .42112 Mdot
.63016 .50818 Mdot
.23313 .40512 Mdot
.37849 .36666 Mdot
.50844 .51023 Mdot
.47968 .36986 Mdot
.73273 .46183 Mdot
.63906 .44109 Mdot
.48393 .50677 Mdot
.30816 .68311 Mdot
.17942 .41868 Mdot
.40455 .41212 Mdot
.52084 .87217 Mdot
.49242 .60123 Mdot
.68505 .67535 Mdot
.42495 .17715 Mdot
.54007 .84138 Mdot
.34379 .37277 Mdot
.81821 .35168 Mdot
.5794 .665 Mdot
.41291 .21978 Mdot
.6658 .48631 Mdot
.80001 .42444 Mdot
.3102 .53958 Mdot
.36219 .64603 Mdot
.58152 .39144 Mdot
.42865 .79639 Mdot
.42728 .34891 Mdot
.7084 .49583 Mdot
.36843 .25567 Mdot
.64584 .57676 Mdot
.66691 .30979 Mdot
.24483 .45633 Mdot
.68323 .70581 Mdot
.75772 .58102 Mdot
.64748 .43866 Mdot
.19607 .4147 Mdot
.80421 .42196 Mdot
.15848 .40776 Mdot
.55101 .5478 Mdot
.29404 .51057 Mdot
.75004 .42104 Mdot
.49636 .21925 Mdot
.59884 .48595 Mdot
.39564 .18614 Mdot
.35789 .70192 Mdot
.74335 .46653 Mdot
.32099 .66311 Mdot
.58924 .67353 Mdot
.49413 .46985 Mdot
.51281 .26675 Mdot
.64481 .79034 Mdot
.58739 .47753 Mdot
.4709 .82876 Mdot
.59918 .50743 Mdot
.19503 .45767 Mdot
.61269 .53615 Mdot
.34686 .40385 Mdot
.77668 .54851 Mdot
.60037 .41014 Mdot
.1873 .37435 Mdot
.40531 .18272 Mdot
.60268 .35497 Mdot
.25955 .37351 Mdot
.57827 .20429 Mdot
.60227 .63658 Mdot
.44069 .46127 Mdot
.55935 .67148 Mdot
.64546 .56287 Mdot
.54893 .84604 Mdot
.45367 .22482 Mdot
.46645 .62659 Mdot
.21776 .34873 Mdot
.21061 .33936 Mdot
.16203 .52008 Mdot
.82556 .57572 Mdot
.66546 .5253 Mdot
.19288 .61139 Mdot
.49318 .54488 Mdot
.27096 .25437 Mdot
.37671 .26943 Mdot
.48557 .14605 Mdot
.66789 .72042 Mdot
.54316 .2128 Mdot
.55827 .78519 Mdot
.65594 .3261 Mdot
.64339 .2385 Mdot
.48068 .4034 Mdot
.46308 .28059 Mdot
.61908 .22127 Mdot
.85828 .5952 Mdot
.61209 .62848 Mdot
.59905 .26047 Mdot
.70983 .32531 Mdot
.49517 .19414 Mdot
.32172 .45293 Mdot
.53165 .58112 Mdot
.40695 .29073 Mdot
.34395 .76617 Mdot
.3382 .64269 Mdot
.34667 .59364 Mdot
.31957 .44873 Mdot
.35004 .73465 Mdot
.31694 .673 Mdot
.8161 .44381 Mdot
.67938 .71335 Mdot
.54414 .49468 Mdot
.57973 .59825 Mdot
.61309 .48984 Mdot
.34964 .53212 Mdot
.46987 .37863 Mdot
.54824 .67498 Mdot
.35281 .43468 Mdot
.66722 .31673 Mdot
.26923 .73306 Mdot
.62483 .37358 Mdot
.75006 .33988 Mdot
.64401 .54385 Mdot
.59208 .2698 Mdot
.61892 .43654 Mdot
.36212 .79195 Mdot
.31247 .48071 Mdot
.3431 .62571 Mdot
.24818 .31582 Mdot
.21017 .5501 Mdot
.76194 .48093 Mdot
.2011 .57395 Mdot
.53653 .32957 Mdot
.46352 .60384 Mdot
.7264 .35199 Mdot
.23338 .44697 Mdot
.6464 .55128 Mdot
.5401 .21359 Mdot
.35298 .34959 Mdot
.22106 .53087 Mdot
.67112 .24842 Mdot
.68526 .55917 Mdot
.70739 .71066 Mdot
.23791 .30491 Mdot
.40914 .42413 Mdot
.79975 .39798 Mdot
.61994 .27273 Mdot
.30299 .49447 Mdot
.18575 .46376 Mdot
.16554 .42443 Mdot
.42035 .50362 Mdot
.38856 .68812 Mdot
.53296 .60447 Mdot
.82634 .48866 Mdot
.47629 .22438 Mdot
.5454 .73867 Mdot
.47136 .3262 Mdot
.69608 .47456 Mdot
.50551 .28869 Mdot
.53412 .48647 Mdot
.32202 .71085 Mdot
.66232 .44767 Mdot
.75136 .68735 Mdot
.31306 .52961 Mdot
.39101 .4921 Mdot
.53083 .5689 Mdot
.38119 .66959 Mdot
.79158 .6495 Mdot
.54368 .55395 Mdot
.3668 .23863 Mdot
.69733 .70014 Mdot
.77544 .40607 Mdot
.42884 .2213 Mdot
.37008 .27952 Mdot
.67962 .33653 Mdot
.77375 .57264 Mdot
.46184 .36276 Mdot
.57795 .64741 Mdot
.3453 .3993 Mdot
.69667 .46286 Mdot
.5406 .1818 Mdot
.73124 .63278 Mdot
.393 .66045 Mdot
.51522 .4239 Mdot
.61281 .5747 Mdot
.52689 .4155 Mdot
.46439 .15708 Mdot
.65656 .32803 Mdot
.34913 .69119 Mdot
.61199 .37912 Mdot
.41051 .69767 Mdot
.51304 .79397 Mdot
.19385 .33424 Mdot
.54387 .79516 Mdot
.45911 .48478 Mdot
.48162 .83262 Mdot
.51724 .24045 Mdot
.58636 .19432 Mdot
.3353 .68666 Mdot
.38571 .49799 Mdot
.29174 .58003 Mdot
.70925 .42155 Mdot
.53862 .44785 Mdot
.31335 .60021 Mdot
.52622 .50671 Mdot
.44941 .33383 Mdot
.5644 .28846 Mdot
.58238 .7093 Mdot
.22611 .38727 Mdot
.24366 .31079 Mdot
.80203 .43407 Mdot
.55798 .42709 Mdot
.34087 .49139 Mdot
.34137 .72026 Mdot
.54213 .13409 Mdot
.37466 .83622 Mdot
.53419 .60504 Mdot
.56511 .43233 Mdot
.3758 .68512 Mdot
.41281 .38202 Mdot
.55572 .51369 Mdot
.61782 .43246 Mdot
.58031 .38215 Mdot
.36695 .5872 Mdot
.22537 .54455 Mdot
.53394 .23811 Mdot
.42754 .7507 Mdot
.37914 .30971 Mdot
.26985 .7374 Mdot
.75 .2998 Mdot
.48375 .22069 Mdot
.48863 .13053 Mdot
.56017 .28113 Mdot
.72822 .48352 Mdot
.61952 .70245 Mdot
.18143 .42168 Mdot
.35908 .63411 Mdot
.37166 .76708 Mdot
.36462 .29104 Mdot
.34845 .69674 Mdot
.45729 .57196 Mdot
.21459 .42302 Mdot
.49653 .29776 Mdot
.4872 .45142 Mdot
.25492 .46819 Mdot
.18832 .54203 Mdot
.71292 .71529 Mdot
.26654 .30089 Mdot
.35808 .77835 Mdot
.83313 .61994 Mdot
.19787 .3526 Mdot
.38561 .55268 Mdot
.33161 .47581 Mdot
.62174 .70633 Mdot
.41558 .59697 Mdot
.44061 .61012 Mdot
.46101 .79037 Mdot
.74483 .57957 Mdot
.28038 .37965 Mdot
.42714 .81905 Mdot
.32145 .65093 Mdot
.71297 .55017 Mdot
.38787 .49965 Mdot
.72767 .67256 Mdot
.25781 .38057 Mdot
.45402 .55279 Mdot
.41432 .56308 Mdot
.39027 .6207 Mdot
.70239 .69039 Mdot
.76582 .42366 Mdot
.58385 .22135 Mdot
.80663 .67808 Mdot
.33468 .28599 Mdot
.37562 .80008 Mdot
.50174 .60414 Mdot
.14691 .43904 Mdot
.59183 .23488 Mdot
.35276 .28952 Mdot
.7177 .28988 Mdot
.44578 .43965 Mdot
.73783 .48583 Mdot
.57812 .64647 Mdot
.32414 .27139 Mdot
.77989 .58454 Mdot
.65504 .58686 Mdot
.41682 .79842 Mdot
.35263 .65778 Mdot
.25377 .58949 Mdot
.40167 .6426 Mdot
.50479 .56046 Mdot
.66572 .45893 Mdot
.19905 .63667 Mdot
.44286 .48681 Mdot
.60946 .57644 Mdot
.52783 .73776 Mdot
.54861 .78209 Mdot
.76663 .29429 Mdot
.52065 .55154 Mdot
.20473 .53256 Mdot
.68312 .74007 Mdot
.47571 .70789 Mdot
.58727 .51844 Mdot
.54389 .09359 Mdot
.17922 .31535 Mdot
.70933 .48812 Mdot
.81418 .53143 Mdot
.69005 .73714 Mdot
.19131 .40717 Mdot
.28186 .48358 Mdot
.4742 .35226 Mdot
.50054 .74485 Mdot
.42546 .59962 Mdot
.50273 .57515 Mdot
.68766 .26402 Mdot
.20069 .32226 Mdot
.42234 .80527 Mdot
.21918 .34531 Mdot
.5114 .71664 Mdot
.50145 .57191 Mdot
.57853 .13265 Mdot
.34778 .23109 Mdot
.60465 .60371 Mdot
.5708 .79073 Mdot
.69405 .53753 Mdot
.51238 .65872 Mdot
.28487 .32388 Mdot
.8466 .47449 Mdot
.31752 .64816 Mdot
.19308 .39367 Mdot
.67944 .44484 Mdot
.3615 .35317 Mdot
.58699 .37923 Mdot
.4093 .5134 Mdot
.59382 .63325 Mdot
.57961 .36152 Mdot
.53883 .75861 Mdot
.53922 .20647 Mdot
.61183 .35104 Mdot
.82268 .43189 Mdot
.38934 .173 Mdot
.73676 .64047 Mdot
.68859 .41583 Mdot
.60581 .59072 Mdot
.71321 .54813 Mdot
.38151 .74692 Mdot
.67874 .55358 Mdot
.60635 .20802 Mdot
.10085 .54179 Mdot
.45306 .29051 Mdot
.27991 .66319 Mdot
.61822 .52801 Mdot
.55754 .49334 Mdot
.74758 .65989 Mdot
.38527 .48057 Mdot
.39571 .43075 Mdot
.53431 .71608 Mdot
.53033 .55217 Mdot
.54386 .38531 Mdot
.47503 .87832 Mdot
.53697 .5821 Mdot
.5749 .50666 Mdot
.27253 .25478 Mdot
.39274 .77081 Mdot
.66973 .67895 Mdot
.56087 .68325 Mdot
.68609 .3917 Mdot
.38427 .49694 Mdot
.46517 .18969 Mdot
.24908 .63713 Mdot
.22436 .35136 Mdot
.73188 .62891 Mdot
.70175 .71878 Mdot
.56632 .58934 Mdot
.29098 .55711 Mdot
.61949 .29204 Mdot
.30018 .30941 Mdot
.48774 .69634 Mdot
.23796 .28216 Mdot
.45728 .41726 Mdot
.4286 .34377 Mdot
.47357 .57702 Mdot
.16554 .53657 Mdot
.47279 .81752 Mdot
.77069 .62552 Mdot
.34267 .78248 Mdot
.23312 .47449 Mdot
.40858 .74088 Mdot
.41211 .42831 Mdot
.49462 .70148 Mdot
.69087 .44896 Mdot
.27896 .75343 Mdot
.27675 .3231 Mdot
.44196 .27617 Mdot
.48083 .29415 Mdot
.80794 .49448 Mdot
.66185 .29757 Mdot
.45842 .13744 Mdot
.24155 .47469 Mdot
.28208 .75175 Mdot
.79593 .41033 Mdot
.62858 .55015 Mdot
.54454 .22373 Mdot
.47965 .58174 Mdot
.40419 .39325 Mdot
.21705 .36435 Mdot
.57283 .55702 Mdot
.29535 .71464 Mdot
.51728 .693 Mdot
.28523 .72584 Mdot
.33681 .6053 Mdot
.25188 .37246 Mdot
.48123 .24087 Mdot
.5211 .80078 Mdot
.51408 .1734 Mdot
.71771 .42381 Mdot
.52236 .14362 Mdot
.51765 .18104 Mdot
.24773 .28764 Mdot
.33348 .74809 Mdot
.57557 .82416 Mdot
.39801 .25445 Mdot
.45032 .21411 Mdot
.53212 .25147 Mdot
.59861 .74124 Mdot
.25905 .51794 Mdot
.50222 .5567 Mdot
.63774 .32943 Mdot
.58947 .33158 Mdot
.20928 .75109 Mdot
.28543 .60302 Mdot
.71178 .50127 Mdot
.24441 .50806 Mdot
.21957 .31998 Mdot
.58003 .75506 Mdot
.63386 .22575 Mdot
.52489 .48524 Mdot
.47755 .60231 Mdot
.74688 .59899 Mdot
.80637 .46533 Mdot
.2578 .52978 Mdot
.72822 .77274 Mdot
.75317 .30866 Mdot
.46114 .31537 Mdot
.49132 .47868 Mdot
.66397 .45192 Mdot
.63177 .43849 Mdot
.26157 .44805 Mdot
.62661 .20993 Mdot
.54169 .21057 Mdot
.35733 .22451 Mdot
.72463 .76417 Mdot
.7822 .4092 Mdot
.18032 .42127 Mdot
.49345 .23145 Mdot
.70012 .51492 Mdot
.38288 .53512 Mdot
.42913 .43281 Mdot
.45022 .26763 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0:gooooo0_l0002Jooooo`007?ooool00ol0003oooooooooo`2]oooo
o`;o0000V_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo09_ooooo0_l0002/ooooo`00
7?ooool00ol0003oooooooooo`2Kooooo`;o00003oooool2o`0000[ooooo0_l0002?ooooo`007?oo
ool00ol0003oooooooooo`2Aooooo`;o00006Oooool2o`0000[ooooo0_l0002?ooooo`007?ooool0
0ol0003oooooooooo`2Aooooo`;o0000]_ooool001cooooo00?o0000ooooooooool0Y_ooool2o`00
02[ooooo0_l0001eooooo`007?ooool00ol0003oooooooooo`2Jooooo`;o00001?ooool2o`0000Co
oooo0_l0000Zooooo`;o0000MOooool001cooooo00?o0000ooooooooool0R_ooool2o`0000kooooo
0_l00004ooooo`;o0000Yoooool001cooooo0_l0002;ooooo`;o00003oooool4o`000:[ooooo000L
ooooo`03o`000?oooooooooo09Wooooo1ol0002Yooooo`007?ooool00ol0003oooooooooo`2Coooo
o`;o000000?oooooo`000?l000000ol00003ooooo`;o0000ZOooool001cooooo00?o0000oooooooo
ool0Toooool2o`000003ooooool0003o000000?o00007?ooool2o`00093ooooo000Looooo`03o`00
0?oooooooooo093ooooo0_l000000ooooooo0000o`000004ooooo`;o00001Oooool2o`0001Gooooo
0_l0002@ooooo`007?ooool00ol0003oooooooooo`2@ooooo`;o00000oooool2o`0000Wooooo0_l0
0006ooooo`;o00000oooool2o`0009[ooooo000Looooo`03o`000?oooooooooo09Gooooo1?l0000?
ooooo`;o00000_ooool3o`0000;ooooo0_l0002Fooooo`007?ooool00ol0003oooooooooo`1koooo
o`;o00003Oooool2o`0000_ooooo0_l0000:ooooo`;o00001oooool8o`0000[ooooo0_l00004oooo
o`;o00001oooool2o`0007[ooooo000Looooo`03o`000?oooooooooo07_ooooo0_l00009ooooo`;o
00000_ooool4o`0000Kooooo0_l0000=ooooo`;o00002_ooool2o`000003ooooool0003o000000[o
oooo0_l00003ooooo`Go00001Oooool2o`0007[ooooo000Looooo`03o`000?oooooooooo08;ooooo
0_l000001?oooooo0000o`000?l00004ooooo`;o00000oooool2o`000003ooooool0003o000000ko
oooo0_l000000ooooooo0000o`000004ooooo`?o00004oooool2o`000003ooooool0003o0000087o
oooo000Looooo`03o`000?oooooooooo083ooooo1?l000001?oooooo0000o`000?l00009ooooo`;o
00004Oooool2o`000003ooooool0003o000000?ooooo1?l00006ooooo`;o00006oooool2o`0007Co
oooo000Looooo`03o`000?oooooooooo07gooooo0_l000000ooooooo0000o`00000Rooooo`;o0000
1_ooool3o`0000Kooooo0ol0000Kooooo`;o00000oooool2o`0006oooooo000Looooo`03o`000?oo
oooooooo07gooooo0_l00006ooooo`?o00001?ooool2o`0000Gooooo0_l0000?ooooo`;o00001ooo
ool2o`0000Kooooo0_l000000ooooooo0000o`000007ooooo`Co00004oooool2o`0006oooooo0000
1_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003ooooo
ooooo`20ooooo`;o00000_ooool4o`0000Cooooo0_l00005ooooo`;o00003?ooool2o`0000;ooooo
0_l0000Aooooo`;o00001oooool4o`0008Cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1_oooo
o`;o00001oooool2o`0000Kooooo0_l00002ooooo`?o00000oooool2o`00017ooooo0_l000001?oo
oooo0000o`000?l00002ooooo`;o00004Oooool2o`000003ooooool0003o000000;ooooo0_l00000
0ooooooo0000o`000025ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:oooo
o`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0Koooool2o`0000Oooooo0_l000000ooo
oooo0000o`000008ooooo`;o00000oooool2o`00017ooooo0_l000001?oooooo0000o`000?l0000H
ooooo`;o00000_ooool2o`000003ooooool0003o000000;o0000Poooool00003ooooool0003ooooo
00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06ooooo`?o0000Loooool3o`00
00Gooooo0_l0000Sooooo`;o00006Oooool3o`0000Cooooo1?l00006ooooo`;o0000Noooool00003
ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03
o`000?oooooooooo07?ooooo0ol00005ooooo`;o00005?ooool2o`0001;ooooo0_l00003ooooo`;o
00003?ooool2o`0000;ooooo0ol0000=ooooo`?o0000N_ooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06gooooo
0_l00005ooooo`;o00003oooool4o`0000Sooooo0_l00004ooooo`;o00002oooool3o`0000?ooooo
0ol0000;ooooo`;o00000oooool2o`0000;ooooo0_l0000:ooooo`;o0000N_ooool00006oooooomg
MgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000oooo
ooooool0KOooool4o`0000?ooooo0_l0000?ooooo`Co00000_ooool2o`0000[ooooo0_l00006oooo
o`?o00000_ooool2o`0000Gooooo0ol00003ooooo`Co00000oooool6o`0000?ooooo1_l000000ooo
oooo0000o`00000Qooooo`;o0000G?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0Koooool2o`0001[ooooo1_l0
0005ooooo`Co00001Oooool3o`0000?ooooo0_l00005ooooo`?o00000_ooool4o`0000?ooooo2Ol0
0002ooooo`Co000000?oooooo`000?l000008Oooool2o`0005cooooo000Looooo`03o`000?oooooo
oooo05oooooo0_l00009ooooo`Co00000oooool2o`0001Oooooo0_l000000ooooooo0000o`000002
o`0000Gooooo1?l0000;ooooo`;o00001Oooool3o`0000kooooo1_l00026ooooo`007?ooool00ol0
003oooooooooo`1Oooooo`;o00002Oooool4o`000003ooooool0003o000000;o00003oooool2o`00
00Cooooo1?l000000ooooooo0000o`00000:ooooo`;o00000_ooool2o`0001Wooooo1?l00003oooo
o`Co00000_ooool2o`0000?ooooo0_l0000Kooooo`;o0000H?ooool001cooooo00?o0000oooooooo
ool0Koooool4o`0000[ooooo0ol00002ooooo`;o00001?ooool2o`0000?ooooo0_l00002ooooo`;o
00001?ooool4o`0000;ooooo0_l00008ooooo`Co00000_ooool2o`0000Gooooo0_l00002ooooo`Go
00000oooool2o`0000?ooooo0_l00003ooooo`;o00006oooool2o`00063ooooo000Looooo`03o`00
0?oooooooooo073ooooo0ol0000:ooooo`?o00000_ooool2o`0000_ooooo1?l00004ooooo`;o0000
00?oooooo`000?l000002oooool8o`0000Gooooo0_l00005ooooo`;o00000oooool2o`0000?ooooo
0_l00003ooooo`Go0000N_ooool001cooooo00?o0000ooooooooool0Ioooool2o`0000oooooo0_l0
0003ooooo`;o00000oooool2o`0000Cooooo0_l00005ooooo`?o00002?ooool2o`0000Oooooo1?l0
0003ooooo`?o00005Oooool2o`000003ooooool0003o000000?ooooo1Ol0001jooooo`007?ooool0
0ol0003oooooooooo`1Wooooo`;o00001?ooool2o`0000Wooooo0_l0000>ooooo`;o00004?ooool2
o`000003ooooool0003o000000Cooooo1_l00004ooooo`;o00001?ooool2o`0000[ooooo0_l00000
0ooooooo0000o`000002ooooo`;o00000oooool2o`0000gooooo0_l0001]ooooo`007?ooool00ol0
003oooooooooo`1Rooooo`;o00000_ooool2o`0000Gooooo0_l00009ooooo`;o00003?ooool2o`00
01;ooooo0_l000000ooooooo0000o`000002o`0000Kooooo0_l00004ooooo`;o00001?ooool2o`00
00Oooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l00003ooooo`;o00003?ooool3o`00
01?ooooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`1Oooooo`;o000000?oooooo`000?l0
00000_ooool2o`0000_ooooo0_l0000<ooooo`;o00000oooool2o`0001;ooooo0_l00003ooooo`;o
00002Oooool2o`0000Cooooo0_l000000ooooooo0000o`000007ooooo`;o000000?oooooo`000?l0
00000ol00009ooooo`;o00002_ooool2o`0001Cooooo0_l0001Hooooo`007?ooool00ol0003ooooo
ooooo`1Oooooo`Co00004?ooool2o`0000cooooo0_l0000>ooooo`?o00001Oooool2o`0000Kooooo
1ol00002ooooo`;o00001?ooool2o`000003ooooool0003o000000Oooooo0_l00002ooooo`Co0000
2Oooool2o`0000?ooooo0_l00004ooooo`;o0000Koooool001cooooo00?o0000ooooooooool0F?oo
ool2o`0000Gooooo1?l0000Vooooo`;o00001_ooool3o`000003ooooool0003o000000;ooooo0_l0
0006ooooo`Oo00002?ooool2o`0000kooooo0_l0000@ooooo`;o00001?ooool5o`0000?ooooo0_l0
001Wooooo`007?ooool00ol0003oooooooooo`1Hooooo`?o00006?ooool2o`0000;ooooo0_l0000@
ooooo`;o00002_ooool2o`0000cooooo0ol000000ooooooo0000o`00000@ooooo`;o00001Oooool2
o`00013ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o0000Ioooool0
01cooooo0_l0001Fooooo`;o00000_ooool2o`0001Gooooo0_l000000ooooooo0000o`000002oooo
o`;o00001?ooool2o`0002Sooooo1?l0000>ooooo`Co00006Oooool2o`00077ooooo000Looooo`03
o`000?oooooooooo05Cooooo0ol00005ooooo`;o00004_ooool2o`0000_ooooo0ol000000ooooooo
0000o`000003ooooo`;o00003?ooool2o`0000_ooooo1Ol00003ooooo`;o000000?oooooo`000?l0
00000_l00007ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0001Sooooo0_l000000ooo
oooo0000o`000004o`0006Oooooo000Looooo`03o`000?oooooooooo05Cooooo0ol00004ooooo`Go
00001?ooool2o`0000?ooooo0_l00009ooooo`;o00002?ooool2o`000004ooooool0003o0000oooo
o`Co00002oooool3o`0000_ooooo1Ol00006ooooo`Co00001oooool2o`000004ooooool0003o0000
ooooo`Co00000_ooool5o`00017ooooo0_l000000ooooooo0000o`000004o`0006Oooooo000Loooo
o`03o`000?oooooooooo04oooooo0_l0000:ooooo`Go00001?ooool2o`000003ooooool0003o0000
00Go00001_ooool2o`0000Gooooo0_l00005ooooo`Ko00002_ooool3o`0000cooooo1?l00009oooo
o`;o00002Oooool2o`0000;ooooo1?l00002ooooo`Oo00002oooool2o`0000;ooooo0_l00007oooo
o`;o0000IOooool001cooooo00?o0000ooooooooool0Coooool2o`0000_ooooo1?l00007ooooo`;o
00000_ooool3o`0000gooooo0_l00005ooooo`;o00003?ooool5o`0000oooooo1?l0000Aooooo`;o
00000oooool5o`0000Gooooo0_l000000ooooooo0000o`000008ooooo`;o00001Oooool2o`000004
ooooool0003o0000ooooo`;o0000IOooool001cooooo00?o0000ooooooooool0E_ooool3o`0000;o
oooo0_l0000aooooo`Co000000?oooooo`000?l000003_ooool5o`0000Oooooo0_l0000>ooooo`Co
00000_ooool2o`0000?ooooo0ol00007ooooo`;o00001_ooool2o`000003ooooool0003o000006So
oooo000Looooo`03o`000?oooooooooo04[ooooo0_l00007ooooo`;o000000?oooooo`000?l00000
1Ol0000;ooooo`;o00003Oooool2o`0000Gooooo0_l00006ooooo`;o00000_ooool2o`000003oooo
ool0003o000000Co00002_ooool2o`0000Cooooo0_l0000:ooooo`;o00001Oooool2o`0000Gooooo
0_l00006ooooo`;o00000oooool2o`0000Sooooo0_l0001cooooo`007?ooool00ol0003ooooooooo
o`1:ooooo`;o00001oooool2o`0000?ooooo1_l00008ooooo`Co000000?oooooo`000?l000002_oo
ool2o`0000Gooooo0_l00006ooooo`;o00000_ooool2o`000003ooooool0003o000000Co00002_oo
ool2o`0001Oooooo0_l00005ooooo`;o00001oooool2o`0000?ooooo0_l000000ooooooo0000o`00
000;ooooo`;o00003oooool2o`0005_ooooo000Looooo`03o`000?oooooooooo05[ooooo1?l00000
0ooooooo0000o`000005ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000005
ooooo`;o00002Oooool2o`0000?ooooo0_l00005ooooo`;o000000?oooooo`000?l000002oooool2
o`00027ooooo0_l00005ooooo`;o00000oooool5o`0000_ooooo0_l0000?ooooo`;o0000Foooool0
01cooooo00?o0000ooooooooool0COooool2o`00013ooooo0_l00008ooooo`;o00000oooool2o`00
00Cooooo0ol00009ooooo`Co000000Coooooo`000?l0003ooooo0_l00002ooooo`;o000000?ooooo
o`000?l000001Oooool2o`0000Cooooo0_l0000Hooooo`;o00001oooool5o`0000Kooooo0_l00000
0ooooooo0000o`000007ooooo`;o00001Oooool2o`00013ooooo0_l0001Hooooo`007?ooool00ol0
003oooooooooo`1:ooooo`;o000000?oooooo`000?l000008_ooool5o`0000cooooo0_l000000ooo
oooo0000o`000003o`0000;ooooo0_l00005ooooo`Ko00004?ooool2o`0000Oooooo0_l00002oooo
o`;o00000oooool2o`0000?ooooo1Ol000000ooooooo0000o`000002ooooo`;o00002_ooool2o`00
00Cooooo0ol0000:ooooo`;o00001?ooool2o`0005Sooooo000Looooo`03o`000?oooooooooo04[o
oooo0_l00002ooooo`;o00002Oooool2o`0000[ooooo0_l00002ooooo`;o00001_ooool3o`000003
ooooool0003o000000cooooo1ol00009ooooo`Ko00004?ooool2o`0000Oooooo1?l00005ooooo`;o
00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0001;ooooo1?l00009ooooo`;o
0000G_ooool001cooooo00?o0000ooooooooool0C?ooool4o`0000Wooooo0_l0000:ooooo`;o0000
0_ooool2o`0000[ooooo0_l0000;ooooo`So00001_ooool2o`0000kooooo0_l0000Booooo`;o0000
2Oooool2o`0000Oooooo0_l00008ooooo`;o00002_ooool2o`0006Wooooo000Looooo`03o`000?oo
oooooooo04;ooooo0_l00008ooooo`?o00007?ooool2o`0000;ooooo0_l00002ooooo`;o00002ooo
ool8o`0000Oooooo0ol00005ooooo`Ko00000oooool4o`0000gooooo0_l000000ooooooo0000o`00
0009ooooo`;o00001?ooool2o`0000?ooooo0_l00006ooooo`;o00004Oooool2o`0000[ooooo0_l0
001Fooooo`007?ooool00ol0003oooooooooo`11ooooo`?o00009oooool2o`0000;ooooo1_l0000;
ooooo`;o00000_ooool4o`0000Oooooo0_l00004ooooo`So00001Oooool2o`0000gooooo0_l00004
ooooo`;o00002_ooool4o`0000?ooooo0_l0000>ooooo`;o00002Oooool2o`0000[ooooo0_l00002
ooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0@Oooool2o`0000;ooooo0_l00005oooo
o`;o00001Oooool2o`0000Cooooo0_l0000Aooooo`Co000000?oooooo`000?l000001_ooool2o`00
00Cooooo0_l00004ooooo`;o00003_ooool2o`000004ooooool0003o0000ooooo`;o000000?ooooo
o`000?l000000_ooool2o`0000?ooooo0_l0000>ooooo`;o00000oooool2o`0000Gooooo0_l00000
0ooooooo0000o`000007ooooo`;o00000_ooool4o`0000?ooooo0_l00004ooooo`;o00004Oooool4
o`0005;ooooo000Looooo`;o0000@?ooool2o`0000Cooooo0_l00005ooooo`;o00001Oooool2o`00
00Cooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l00006ooooo`Co00001_ooool2
o`000003ooooool0003o000000Cooooo0_l000001?oooooo0000o`000?ooool2o`0000Sooooo0_l0
000:ooooo`;o000000?oooooo`000?l000001oooool2o`0000Kooooo0_l0000;ooooo`;o000000?o
ooooo`000?l000001Oooool2o`0000Oooooo0_l00002ooooo`Co00002Oooool3o`0000gooooo0_l0
00000ooooooo0000o`000002o`0000Wooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`0n
ooooo`?o00001oooool2o`0000Wooooo0_l00003ooooo`;o00001?ooool2o`000004ooooool0003o
0000ooooo`Co00002?ooool2o`0000?ooooo0ol00007ooooo`Go00002oooool2o`0001Cooooo0_l0
0008ooooo`;o00003_ooool2o`0000;ooooo0_l00007ooooo`;o00004oooool2o`0000gooooo0_l0
0002ooooo`?o00002Oooool2o`0004Oooooo000Looooo`03o`000?oooooooooo03gooooo0ol00008
ooooo`Co00003?ooool2o`0000cooooo0_l00004ooooo`co00002Oooool2o`00013ooooo0_l00000
0ooooooo0000o`00000=ooooo`;o00002?ooool2o`00013ooooo1?l00007ooooo`Co00002Oooool2
o`0001Wooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00002?ooool2o`00
0004ooooool0003o0000o`00017ooooo0_l00006ooooo`Co00000_ooool:o`000003ooooool0003o
000000Sooooo0_l000000ooooooo0000o`00000;ooooo`Co000000?oooooo`000?l000002Oooool2
o`0000;ooooo0_l00008ooooo`;o00001?ooool2o`0000?ooooo0_l00005ooooo`?o00002_ooool2
o`0000Gooooo0_l000001?oooooo0000o`000?l0000:ooooo`;o00002Oooool3o`0000?ooooo0_l0
001Aooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00001oooool3o`0000;ooooo0_l0000A
ooooo`co00001?ooool8o`000004ooooool0003o0000o`0000Cooooo0_l000001?oooooo0000o`00
0?ooool2o`0000_ooooo0_l0000>ooooo`;o00000_ooool2o`0000Gooooo0_l000001?oooooo0000
o`000?ooool5o`0000?ooooo0_l00005ooooo`?o00001?ooool2o`0000_ooooo0_l000000ooooooo
0000o`000002o`0000Wooooo0_l00009ooooo`?o000000?oooooo`000?l000000_l0001Aooooo`00
7?ooool00ol0003oooooooooo`0gooooo`;o00003Oooool2o`0000Gooooo0_l0000Aooooo`Ko0000
0_ooool2o`0000[ooooo1_l00002ooooo`Co00004_ooool2o`0001Gooooo0_l000000ooooooo0000
o`000002ooooo`Ko00002oooool2o`0000Gooooo0_l0000;ooooo`;o00000oooool2o`0000Sooooo
0ol00005ooooo`;o00001_ooool2o`0000Gooooo0_l00008ooooo`;o0000@_ooool001cooooo00?o
0000ooooooooool0=oooool2o`0000Cooooo0_l00005ooooo`;o00001oooool2o`0000kooooo0_l0
000Fooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l0000?ooooo`;o00001_oo
ool3o`0000cooooo0ol000000ooooooo0000o`000004o`0002;ooooo0_l00004ooooo`;o00001ooo
ool3o`0000Gooooo0_l0000:ooooo`;o000000?oooooo`000?l000002?ooool2o`0004;ooooo000L
ooooo`03o`000?oooooooooo03Wooooo0_l00002ooooo`;o00001Oooool2o`0000cooooo0_l00002
ooooo`;o00001?ooool4o`0000Wooooo0_l00004ooooo`;o00002oooool3o`0000;ooooo0_l0000D
ooooo`;o000000Coooooo`000?l0003o00003?ooool9o`0000;ooooo0ol00005ooooo`?o00004ooo
ool2o`0000Oooooo0_l0000<ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo0_l0
00001?oooooo0000o`000?ooool2o`0004cooooo000Looooo`03o`000?oooooooooo03Wooooo0_l0
0002ooooo`;o00004oooool2o`0000;ooooo1Ol000000ooooooo0000o`000002o`000003ooooool0
003o000000Kooooo0_l00004ooooo`;o00000oooool2o`0000Oooooo0_l00005ooooo`;o00003ooo
ool4o`0000Gooooo0_l0000<ooooo`ko00000_ooool3o`0000Oooooo0_l00004ooooo`;o00000ooo
ool3o`0000[ooooo0_l00003ooooo`;o00001?ooool2o`0000?ooooo0_l000000ooooooo0000o`00
0002ooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0BOooool2o`0000gooooo0ol00005
ooooo`?o00004Oooool2o`0000?ooooo0_l00008ooooo`?o00002_ooool2o`0000?ooooo0_l00000
0ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000001_ooool2o`000003ooooool0003o
000000co00003?ooool5o`000003ooooool0003o000000?ooooo0_l0000;ooooo`;o00000oooool2
o`00027ooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`19ooooo`Co00002Oooool4o`00
00Kooooo0_l0000<ooooo`;o00002?ooool3o`0000Sooooo0ol0000:ooooo`;o00000_ooool2o`00
00;ooooo0_l000000ooooooo0000o`000004ooooo`;o000000Coooooo`000?l0003ooooo4?l00000
1Ooooooo0000o`000?l0003ooooo00;o00002_ooool5o`0000Cooooo0_l00005ooooo`;o00000_oo
ool2o`0000cooooo0_l00004ooooo`;o00001Oooool2o`0000gooooo0_l00011ooooo`007?ooool0
0ol0003oooooooooo`0hooooo`;o000000?oooooo`000?l000003_ooool3o`0000Sooooo0_l00006
ooooo`;o00002?ooool2o`0000Cooooo0_l00008ooooo`;o00002_ooool2o`0000Sooooo0_l00004
ooooo`;o00001Oooool2o`0000Gooooo1?l000000ooooooo0000o`000005o`000003ooooool0003o
000000go00003Oooool2o`0000Oooooo0_l00002ooooo`Ko00000oooool2o`0000Oooooo0_l00004
ooooo`;o00001Oooool2o`0000Sooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`0hoooo
o`;o000000?oooooo`000?l000003oooool2o`0000Kooooo0_l00006ooooo`Oo00001Oooool2o`00
01;ooooo0_l00002ooooo`;o000000?oooooo`000?l000002Oooool2o`0001;ooooo6ol000000ooo
oooo0000o`00000Dooooo`;o00000oooool:o`0001kooooo0_l00016ooooo`007?ooool00ol0003o
ooooooooo`0^ooooo`;o00004Oooool4o`0000[ooooo0_l00003ooooo`;o00000oooool2o`000003
ooooool0003o000000;ooooo0ol0000@ooooo`;o00001Oooool4o`0000;ooooo0_l000000ooooooo
0000o`00000@ooooo`;o00003OoooolLo`0001Kooooo0_l000000ooooooo0000o`000002o`000003
ooooool0003o000000?o00003Oooool2o`0005Oooooo000Looooo`03o`000?oooooooooo02kooooo
0_l0000@ooooo`Go00002?ooool4o`0000Sooooo0_l00003ooooo`;o00002Oooool2o`000004oooo
ool0003o0000o`0000Cooooo0_l00004ooooo`Go00002Oooool2o`0000cooooo0_l00003ooooo`?o
00002OoooolBo`000003ooooool0003o000000Go00001?ooool4o`0000Gooooo0_l00007ooooo`;o
00002?ooool3o`0000Gooooo0ol00005ooooo`Co00000oooool2o`0000?ooooo0_l0001;ooooo`00
7?ooool00ol0003oooooooooo`10ooooo`;o000000Coooooo`000?l0003o00001oooool2o`000003
ooooool0003o000000cooooo0_l00005ooooo`;o00000_ooool2o`000004ooooool0003o0000o`00
00[ooooo0_l000000ooooooo0000o`000002o`0000Oooooo0_l0000Aooooo`Go00001OoooolDo`00
0003ooooool0003o000000Go00001?ooool4o`0000Gooooo0_l0000<ooooo`Co000000Coooooo`00
0?l0003o00001Oooool3o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`;o00000oooool2
o`0004_ooooo000Looooo`;o0000?_ooool3o`0000?ooooo0ol00002ooooo`;o00001Oooool3o`00
00gooooo0_l00004ooooo`Co00001_ooool2o`0000Oooooo0_l00004ooooo`;o00001oooool2o`00
00Gooooo0_l0000=ooooo`;o00000ooooolFo`000003ooooool0003o000000Go00006oooool4o`00
00;ooooo0_l0000<ooooo`Co00004?ooool3o`0004?ooooo000Looooo`03o`000?oooooooooo03go
oooo0ol00003ooooo`Co000000?oooooo`000?l000001Oooool2o`0000Gooooo1?l00005ooooo`;o
00001_ooool2o`0000Cooooo1?l000000ooooooo0000o`000004ooooo`;o00003Oooool2o`000003
ooooool0003o000000;ooooo1?l00004ooooo`;o000000?oooooo`000?l000000oooool2o`000005
ooooool0003o0000o`000?ooool00_l000000ooooooo0000o`00000Fo`0000?ooooo0_l000000ooo
oooo0000o`00000Pooooo`;o00001oooool2o`0000_ooooo0_l00003ooooo`Go0000@Oooool001co
oooo00?o0000ooooooooool0?Oooool2o`0000Cooooo1?l00004ooooo`?o00002?ooool4o`0001?o
oooo0_l00003ooooo`;o00000_ooool2o`0000[ooooo0_l00006ooooo`;o00001?ooool2o`0000Co
oooo0_l000000ooooooo0000o`000003ooooo`;o000000Coooooo`000?l0003ooooo7_l000001?oo
oooo0000o`000?ooool3o`0001oooooo0_l00003ooooo`;o00003oooool2o`000003ooooool0003o
000000?ooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00002_ooool5o`00
02Kooooo2?l00004ooooo`;o00002_ooool2o`0001Cooooo3Ol000000ooooooo0000o`000004o`00
0003ooooool0003o000000Oo00001Oooool2o`0002Cooooo0_l0000Booooo`;o00000oooool2o`00
047ooooo000Looooo`03o`000?oooooooooo03oooooo0_l0000<ooooo`?o00007_ooool4o`0000Co
oooo2?l00006ooooo`;o00002?ooool2o`0000;ooooo0_l0000@ooooo`go000000?oooooo`000?l0
00003Ol00003ooooo`;o00001oooool2o`0001Kooooo0_l00006ooooo`;o00000oooool2o`0001;o
oooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0booooo`;o00002Oooool2o`0000Cooooo
0ol00007ooooo`;o00007Oooool6o`0000;ooooo2_l00006ooooo`?o00002oooool2o`0000_ooooo
0_l00004ooooo`;o000000?oooooo`000?l000006?l00002ooooo`?o00001_ooool2o`0001Kooooo
0_l00006ooooo`;o00000oooool2o`0000Sooooo0_l000000ooooooo0000o`000018ooooo`007?oo
ool00ol0003oooooooooo`0booooo`;o00002Oooool2o`0000Cooooo0ol00008ooooo`;o00007?oo
oolFo`0000?ooooo0_l0000Hooooo`;o00000oooool2o`0000;ooooo6_l00003ooooo`;o00001_oo
ool2o`00023ooooo0_l00008ooooo`;o000000Coooooo`000?l0003ooooo1?l00016ooooo`007?oo
ool00ol0003oooooooooo`0hooooo`;o000000?oooooo`000?l000004Oooool2o`0001kooooo5Ol0
000Eooooo`;o00002Oooool?o`000003ooooool0003o000000?o000000?oooooo`000?l000001Ol0
000=ooooo`;o00002oooool6o`0000oooooo0_l00002ooooo`;o00001?ooool2o`0000Kooooo0_l0
0016ooooo`007?ooool00ol0003oooooooooo`0hooooo`Oo00003oooool2o`000004ooooool0003o
0000o`0000Sooooo0_l0000>ooooo`;o000000?oooooo`000?l000004_l00008ooooo`?o00002?oo
ool4o`0000Wooooo7Ol00002ooooo`?o00000_ooool4o`0000Kooooo0_l00007ooooo`Ko00004ooo
ool2o`000003ooooool0003o0000057ooooo000Looooo`03o`000?oooooooooo03Wooooo0_l00002
ooooo`;o00001_ooool2o`0000Oooooo0_l000001?oooooo0000o`000?l00002ooooo`?o00000ooo
ool2o`0000Cooooo0_l000000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l000000ol0
00000ooooooo0000o`00000>o`0000?ooooo0_l000001?oooooo0000o`000?l00007ooooo`?o0000
0oooool2o`0000Wooooo0ol000000ooooooo0000o`00000Co`0000?ooooo0ol00002ooooo`Co0000
1_ooool4o`0000Wooooo0_l00005ooooo`;o00003oooool2o`0000Cooooo0_l00003ooooo`;o0000
A_ooool001cooooo00?o0000ooooooooool0AOooool2o`000003ooooool0003o000000Cooooo1?l0
0004ooooo`?o00002Oooool2o`000003ooooool0003o000000Sooooo4?l000000ooooooo0000o`00
0004o`0000;ooooo0_l00004ooooo`;o00001Oooool2o`0000Cooooo0_l00003ooooo`;o00002?oo
oolGo`0000;ooooo0_l00002ooooo`;o00001?ooool2o`0000Cooooo0_l000000ooooooo0000o`00
0006ooooo`;o00001Oooool2o`0001Gooooo1?l000000ooooooo0000o`000016ooooo`007?ooool0
0ol0003oooooooooo`18ooooo`;o00001_ooool2o`0000Gooooo0_l00003ooooo`;o00001Oooool2
o`0000Kooooo0_l00002oooooaOo00001oooool3o`0000?ooooo0_l000000ooooooo0000o`000003
ooooo`;o00000oooool2o`0000Wooooo3Ol000000ooooooo0000o`000006o`0000;ooooo1?l00003
ooooo`;o000000?oooooo`000?l000001oooool2o`0002Kooooo0ol0000<ooooo`;o0000>_ooool0
01cooooo00?o0000ooooooooool0A_ooool2o`0001Cooooo0_l00005ooooo`?o00001Oooool2o`00
00;ooooo6_l000001?oooooo0000o`000?ooool3o`0000?ooooo0_l000001?oooooo0000o`000?l0
0006ooooo`;o00002_oooolCo`0000?ooooo0_l000001?oooooo0000o`000?l00003ooooo`;o0000
2_ooool6o`00013ooooo0ol0000@ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Gooooo
0_l0000jooooo`007?ooool00ol0003oooooooooo`0fooooo`;o000000?oooooo`000?l000002ooo
ool2o`0000_ooooo0_l00006ooooo`;o00001oooool2o`0000Wooooo2ol000000ooooooo0000o`00
000<o`000004ooooool0003o0000ooooo`?o00001oooool2o`0000Kooooo0_l00009ooooo`Go0000
0_ooool=o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`;o00002_ooool4o`0000oooooo
1?l00008ooooo`;o00001oooool4o`0000;ooooo0_l00009ooooo`;o0000=_ooool00006ooooooo^
k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03
o`000?oooooooooo03Kooooo0_l000000ooooooo0000o`000002o`0000Oooooo1?l00006ooooo`;o
00000oooool2o`0000Kooooo0_l0000>ooooo`;o00000_oooolMo`0001kooooo0_l000000ooooooo
0000o`000004o`000003ooooool0003o000000Ko00000_ooool2o`0000cooooo0_l0000:ooooo`;o
000000Coooooo`000?l0003ooooo0_l0000;ooooo`Co00001Oooool2o`000003ooooool0003o0000
00Oooooo0_l0000?ooooo`;o0000=_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0fooooo`;o00000oooool2
o`0000Oooooo1?l00006ooooo`;o00006oooool2o`0000;ooooo0ol00002oooooaKo00003oooool2
o`0001Cooooo0ol00002ooooo`;o00000oooool4o`000003ooooool0003o000001?ooooo0_l00006
ooooo`;o000000?oooooo`000?l000003Oooool2o`0000Gooooo0_l00008ooooo`;o00004?ooool2
o`0003Oooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006oooo
o`03o`000?oooooooooo03Kooooo0_l0000Aooooo`;o00005Oooool2o`0000[ooooo7ol0000:oooo
o`;o00000_ooool2o`0001Oooooo1?l000000ooooooo0000o`000004o`0000Wooooo0_l0000;oooo
o`;o00002Oooool2o`000003ooooool0003o000000Kooooo0_l0000=ooooo`;o00001?ooool4o`00
0003ooooool0003o000000Gooooo0_l00004ooooo`;o0000=oooool00003ooooool0003ooooo00;o
oooo00?o0000ooooooooool02Oooool01?m4A4CogMgMooooool00007ooooo`?o0000BOooool2o`00
00cooooo0_l00007ooooo`;o00002_oooolOo`0000[ooooo0_l0000Kooooo`;o00000oooool5o`00
00Wooooo0ol0000:ooooo`?o00003?ooool2o`0000Gooooo0ol00009ooooo`;o000000Coooooo`00
0?l0003o00001_ooool2o`000003ooooool0003o000000Gooooo0_l000000ooooooo0000o`00000j
ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGooooo
o`0000Oooooo00?o0000ooooooooool0<oooool3o`0000Gooooo0_l00005ooooo`;o00001?ooool2
o`0000Gooooo0_l00006ooooo`;o00005?ooool:o`000004ooooool0003o0000o`0000;ooooo3_l0
0008ooooo`;o00000oooool2o`0001gooooo0_l000000ooooooo0000o`000002o`0000Oooooo0_l0
0006ooooo`;o00000oooool3o`0000Oooooo0_l00003ooooo`;o00001Oooool2o`0000[ooooo1_l0
000<ooooo`;o00001Oooool2o`0003[ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooo
oooo00[ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0`ooooo`;o000000Cooooo
o`000?l0003o00001?ooool3o`0000Gooooo0_l00004ooooo`;o00001Oooool2o`0000Cooooo1?l0
000Dooooo`Wo00000_ooool@o`0000_ooooo0_l00003ooooo`;o00001Oooool2o`0001Wooooo1?l0
0003ooooo`;o00001oooool5o`0000?ooooo0_l00008ooooo`;o00002?ooool2o`0000Kooooo0_l0
0005ooooo`Wo00002?ooool2o`00047ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo
00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0`ooooo`;o00002?ooool2o`0000?ooooo
0_l00004ooooo`;o00002?ooool2o`0000Cooooo0ol0000Fooooo`Wo000000?oooooo`000?l00000
3_l0000Gooooo`;o00002oooool2o`0000;ooooo0_l0000:ooooo`Oo00000_ooool2o`0000?ooooo
1?l0000Gooooo`Ko00000oooool2o`0000Sooooo1_l000000ooooooo0000o`000018ooooo`0000Ko
ooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000oooooooo
ool0??ooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000003ooooo`?o
00000oooool2o`000003ooooool0003o000001Oooooo6ol0000Mooooo`;o00000oooool6o`0000[o
oooo3?l0000Mooooo`Ko00003Oooool2o`0000Gooooo0_l00018ooooo`007?ooool00ol0003ooooo
ooooo`0aooooo`;o00001?ooool2o`0000?ooooo0_l00007ooooo`;o000000?oooooo`000?l00000
0oooool3o`0000?ooooo0_l00009ooooo`;o00002?ooool2o`0000Gooooo6ol00007ooooo`;o0000
5?ooool2o`0000Gooooo0_l0000;ooooo`;o00001?ooool4o`000003ooooool0003o000001Cooooo
0_l00003ooooo`;o00001_ooool2o`00013ooooo0_l000001?oooooo0000o`000?ooool2o`0000Wo
oooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00001?ooool2o`0000[ooooo
0_l00004ooooo`;o00000oooool2o`0000?ooooo0_l00009ooooo`;o00002?ooool2o`0000Gooooo
6Ol00008ooooo`?o00005?ooool2o`0001;ooooo0ol00003ooooo`;o00000oooool2o`0000Gooooo
0_l0000=ooooo`;o00000oooool4o`0000Cooooo0_l00005ooooo`;o00002?ooool3o`000004oooo
ool0003o0000ooooo`;o00002?ooool3o`0003_ooooo000Looooo`03o`000?oooooooooo03;ooooo
0_l00003ooooo`?o00002?ooool3o`0000Cooooo0_l00008ooooo`;o00001_ooool2o`0000_ooooo
0_l00005oooooaco00001Oooool2o`0000Wooooo0_l00007ooooo`;o000000?oooooo`000?l00000
2Oooool3o`0000?ooooo0ol000000ooooooo0000o`000002o`0000Kooooo0_l00005ooooo`;o0000
5?ooool4o`0000;ooooo0_l00005ooooo`;o00000oooool2o`0000?ooooo2Ol00008ooooo`;o0000
??ooool001cooooo00?o0000ooooooooool0<_ooool2o`0000Cooooo0_l00008ooooo`;o00002Ooo
ool2o`0000cooooo0_l0000;ooooo`;o00001?oooolMo`00013ooooo1_l00003ooooo`;o000000?o
ooooo`000?l000000oooool2o`0000?ooooo1?l00003ooooo`?o00000_ooool3o`0000Kooooo0_l0
0008ooooo`;o00002Oooool2o`0000;ooooo0_l00004ooooo`;o00000_ooool3o`0000Wooooo0_l0
0005ooooo`Oo0000A_ooool001cooooo00?o0000ooooooooool0=?ooool2o`0000Gooooo1ol0000;
ooooo`;o00003_ooool2o`0000oooooo6_l0000Eooooo`Co00001_ooool3o`0000;ooooo0ol00002
ooooo`;o00000oooool2o`0001Cooooo0_l00002ooooo`;o00002Oooool2o`0000;ooooo0_l00008
ooooo`?o000000?oooooo`000?l000002_ooool2o`0004kooooo000Looooo`03o`000?oooooooooo
03Cooooo0_l00004ooooo`So00002_ooool2o`0000oooooo0_l00002ooooo`;o00001oooool2o`00
0003ooooool0003o000001So000000?oooooo`000?l000002oooool2o`0000Kooooo0_l00009oooo
o`;o00000oooool2o`000005ooooool0003o0000o`000?ooool01?l00003ooooo`Ko00001?ooool4
o`0000?ooooo0_l00004ooooo`;o00005Oooool3o`000003ooooool0003o000000Gooooo1ol00006
ooooo`;o00001?ooool2o`00043ooooo000Looooo`03o`000?oooooooooo01kooooo0_l0000Joooo
o`;o00003oooool3o`0001?ooooo0_l000000ooooooo0000o`000002o`0000;ooooo1ol000000ooo
oooo0000o`00000Co`000003ooooool0003o000000[ooooo0ol00006ooooo`;o00004Oooool2o`00
00;ooooo0_l00005ooooo`Ko00001?ooool4o`0000Gooooo0_l000000ooooooo0000o`000002o`00
00cooooo0_l00006ooooo`;o00001?ooool2o`0000?ooooo1Ol00008ooooo`;o00001?ooool2o`00
043ooooo000Looooo`03o`000?oooooooooo01kooooo0_l0000<ooooo`;o00004?ooool2o`0000_o
oooo0ol0000Fooooo`Co00001?ooool2o`000004ooooool0003o0000oooooa;o00002Oooool2o`00
00?ooooo1?l0000]ooooo`So00000oooool9o`0000[ooooo0_l00003ooooo`;o000000?oooooo`00
0?l000001?ooool2o`0000;ooooo0_l0000>ooooo`;o0000A?ooool001cooooo00?o0000oooooooo
ool0;?ooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o000000;o
00000oooool2o`0000Oooooo0_l0000;ooooo`;o00004?ooool2o`0000?ooooo0ol000000ooooooo
0000o`00000=o`0000[ooooo0ol00002ooooo`;o00007Oooool2o`00013ooooo0_l00002ooooo`Co
000000Coooooo`000?l0003ooooo0_l00004ooooo`?o000000Goooooo`000?l0003o0000ooooo`02
o`0000Cooooo0_l000000ooooooo0000o`000005ooooo`;o00000_ooool4o`0000kooooo0_l0000=
ooooo`;o0000=Oooool001cooooo00?o0000ooooooooool0<?ooool2o`0000?ooooo0_l00002oooo
o`;o000000?oooooo`000?l000001Oooool2o`0001Cooooo0_l00006ooooo`;o00002?ooool=o`00
0003ooooool0003o000000So00002oooool5o`0000;ooooo0_l0000Jooooo`;o00000_ooool2o`00
01Gooooo0ol00007ooooo`;o000000?oooooo`000?l000001_l00002ooooo`Co00000oooool2o`00
0003ooooool0003o000000;ooooo1?l0000=ooooo`;o000000Coooooo`000?l0003o00002_ooool2
o`0003Gooooo000Looooo`03o`000?oooooooooo033ooooo1?l0000>ooooo`;o00001?ooool4o`00
00Gooooo0_l0000>ooooo`;o000000Coooooo`000?l0003ooooo0_l00003oooooaGo00001Oooool2
o`0000Oooooo1Ol000000ooooooo0000o`00000Cooooo`So00000oooool2o`0001Cooooo1?l00004
ooooo`Go000000?oooooo`000?l000001_l00004ooooo`;o00000oooool2o`0000Oooooo0_l0000=
ooooo`;o000000Coooooo`000?l0003o0000@Oooool001cooooo0_l0000cooooo`;o00003Oooool3
o`0000Cooooo1_l00003ooooo`;o00004Oooool5o`0000Oooooo0_l000000ooooooo0000o`00000<
o`0000Gooooo0_l00003ooooo`?o000000Coooooo`000?l0003ooooo0_l00007ooooo`;o00001_oo
ool2o`0000Cooooo2Ol00003ooooo`;o00004Oooool2o`000003ooooool0003o000000co000000?o
ooooo`000?l000000ol0000Sooooo`;o0000AOooool001cooooo00?o0000ooooooooool0>_ooool3
o`0000Cooooo0_l00007ooooo`Co00002Oooool2o`0000cooooo0ol0000;ooooo`Oo00000_ooool2
o`000003ooooool0003o000000[ooooo0ol0000=ooooo`;o00001_ooool2o`0000?ooooo0ol00000
0ooooooo0000o`000004o`0001Kooooo0_l00002ooooo`go000000?oooooo`000?l000001?l00003
ooooo`;o000000?oooooo`000?l00000HOooool001cooooo00?o0000ooooooooool0;oooool2o`00
00Sooooo1Ol0000<ooooo`Co00002Oooool2o`0000cooooo0_l0000=ooooo`?o000000?oooooo`00
0?l000000_ooool2o`0001Oooooo0_l0000Aooooo`;o00000_ooool6o`0000Gooooo0_l0000Coooo
o`go000000Coooooo`000?l0003ooooo0ol00002ooooo`?o000000?oooooo`000?l00000HOooool0
01cooooo00?o0000ooooooooool0;oooool2o`0000Sooooo0_l000000ooooooo0000o`00000=oooo
o`?o00001Oooool2o`0001;ooooo0_l00007ooooo`;o00000oooool2o`00013ooooo0_l00002oooo
o`;o00002?ooool4o`0000oooooo0_l00003ooooo`;o00002?ooool2o`0001?ooooo4?l000000ooo
oooo0000o`000007o`0000Cooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`0iooooo`;o
00006?ooool2o`0001;ooooo1?l00005ooooo`;o00000oooool5o`000003ooooool0003o000000[o
oooo0_l00002ooooo`;o00002_ooool2o`0000Gooooo0_l00003ooooo`;o000000Coooooo`000?l0
003ooooo0_l0000Oooooo`;o00000_oooolHo`0000;ooooo1Ol0000Dooooo`;o0000A_ooool001co
oooo00?o0000ooooooooool0>?ooool3o`0001Cooooo0_l0000Cooooo`;o00000oooool2o`0000_o
oooo1?l000000ooooooo0000o`000002ooooo`?o00004?ooool2o`0000[ooooo0_l00003ooooo`;o
000000Coooooo`000?l0003ooooo0_l0000Jooooo`;o00000oooool@o`000003ooooool0003o0000
00Oo00001?ooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000gooooo0ol0000=
ooooo`;o0000=_ooool001cooooo00?o0000ooooooooool0>?ooool2o`0001Gooooo0_l0000Coooo
o`;o00006Oooool3o`00013ooooo0_l00009ooooo`;o000000?oooooo`000?l000002oooool2o`00
00Kooooo0_l00009ooooo`;o00000oooool2o`0000;ooooo5_l00002ooooo`Ko00001oooool2o`00
00;ooooo0_l000000ooooooo0000o`00000:ooooo`?o00003Oooool2o`0003Kooooo000Looooo`03
o`000?oooooooooo04oooooo0_l0000Iooooo`;o00000oooool2o`0000;ooooo0_l0000<ooooo`;o
00006_ooool2o`000003ooooool0003o000000;ooooo1?l00005ooooo`;o00001_ooool2o`0000Wo
oooo0_l00003ooooo`;o000000?oooooo`000?l000007Ol00009ooooo`;o00000oooool2o`0005;o
oooo000Looooo`03o`000?oooooooooo033ooooo0_l00004ooooo`;o00004?ooool2o`000003oooo
ool0003o000001_ooooo1?l00003ooooo`;o00000_ooool2o`0000Wooooo0_l000000ooooooo0000
o`000004ooooo`;o000000?oooooo`000?l000002?ooool2o`0000Sooooo0_l00002ooooo`Oo0000
2?ooool2o`0000oooooo1Ol000001Ooooooo0000o`000?l0003ooooo01So00003?ooool3o`0001co
oooo0_l00002ooooo`;o0000=?ooool001cooooo00?o0000ooooooooool0<?ooool2o`0000;ooooo
1?l00005ooooo`;o00001?ooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0000So
oooo0_l0000>ooooo`;o00000_ooool2o`0000Cooooo0_l0000:ooooo`;o00000oooool2o`0000;o
oooo0_l000000ooooooo0000o`000008ooooo`?o00001Oooool4o`0000;ooooo0_l000000ooooooo
0000o`000002o`0000Sooooo0_l00008ooooo`;o00001?ooool6o`0000;ooooo6ol00006ooooo`;o
00001Oooool2o`0001[ooooo1Ol000000ooooooo0000o`00000dooooo`007?ooool00ol0003ooooo
ooooo`0`ooooo`;o00000_ooool2o`0000Oooooo0_l00004ooooo`;o00001?ooool2o`0000?ooooo
0_l00008ooooo`;o00002?ooool2o`0000Sooooo0_l00004ooooo`;o00001Oooool2o`0000Sooooo
0ol00002ooooo`;o00002oooool2o`0000Gooooo0_l00006ooooo`?o00001?ooool2o`0000Sooooo
0ol000000ooooooo0000o`000004o`0000;ooooo0_l00003oooooako00001_ooool2o`0000Sooooo
0_l0000Gooooo`Go00003Oooool2o`0002Sooooo000Looooo`03o`000?oooooooooo04Wooooo0_l0
000;ooooo`Co00002?ooool2o`0000Kooooo0_l0000=ooooo`;o00002Oooool2o`0000;ooooo0_l0
0007ooooo`Oo00002_ooool4o`000003ooooool0003o000000Co00002?ooool3o`000003ooooool0
003o000000;ooooo1?l00005oooooaKo000000?oooooo`000?l000001ol00003ooooo`;o000000?o
ooooo`000?l000000oooool2o`000003ooooool0003o000000Kooooo0_l00003ooooo`;o00003?oo
ool2o`0000kooooo0_l0000Xooooo`007?ooool00ol0003oooooooooo`1Fooooo`Co00001Oooool2
o`0000Wooooo0ol0000?ooooo`;o00002Oooool2o`0000?ooooo0_l00003ooooo`Co000000?ooooo
o`000?l000002_ooool2o`0000?ooooo1Ol0000Cooooo`;o00002?oooolMo`0000?ooooo0_l00000
0ooooooo0000o`000003ooooo`;o00002Oooool2o`000003ooooool0003o000000;o000000?ooooo
o`000?l000000oooool2o`000003ooooool0003o000003_ooooo000Looooo`03o`000?oooooooooo
03Cooooo0_l0000?ooooo`;o00006?ooool2o`0000[ooooo0_l0000>ooooo`?o00002Oooool2o`00
00?ooooo0_l0000Dooooo`;o00007oooool2o`0000;ooooo7ol0000Iooooo`;o00000oooool2o`00
00?ooooo0_l000000ooooooo0000o`00000kooooo`007?ooool00ol0003oooooooooo`0dooooo`;o
00002_ooool4o`000003ooooool0003o000000Cooooo0_l0000Booooo`;o000000?oooooo`000?l0
00001oooool2o`0000kooooo0_l0000Hooooo`;o00005_ooool2o`0000;ooooo0_l00005ooooo`;o
00002Oooool2o`0000;ooooo7?l000001?oooooo0000o`000?ooool2o`0000cooooo0_l0000<oooo
o`;o00001oooool2o`0003_ooooo000Looooo`03o`000?oooooooooo03Gooooo0_l00009ooooo`Co
00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o00002oooool2o`000003
ooooool0003o000000oooooo0_l00004ooooo`Go00000oooool2o`0001;ooooo0_l00008ooooo`;o
00001?ooool2o`0000Kooooo0_l00002ooooo`Go00000_ooool2o`0000gooooo7_l00002ooooo`;o
00003?ooool2o`0000cooooo0_l00007ooooo`;o0000>oooool001cooooo0_l0000fooooo`;o0000
1Oooool7o`0000?ooooo0_l00006ooooo`;o00000_ooool2o`0001oooooo0_l00002ooooo`Oo0000
0oooool2o`0000;ooooo1?l0000Booooo`;o00000_ooool3o`0000?ooooo0_l00003ooooo`;o0000
1?ooool6o`0000gooooo0ol000000ooooooo0000o`00000Lo`0000_ooooo0_l0000Jooooo`;o0000
>oooool001cooooo00?o0000ooooooooool0<oooool2o`0000?ooooo0_l00002ooooo`So00000ooo
ool2o`0000Cooooo0_l0000Qooooo`;o00001Oooool2o`000003ooooool0003o000000Sooooo1Ol0
00000ooooooo0000o`000002o`0000gooooo0_l00003ooooo`;o00002?ooool2o`0000Cooooo0_l0
00000ooooooo0000o`00000>ooooobCo000000?oooooo`000?l000001_ooool2o`0000Oooooo0_l0
0003ooooo`;o00001_ooool2o`0000;ooooo1?l0000kooooo`007?ooool00ol0003oooooooooo`0c
ooooo`;o00000oooool2o`0000;ooooo0_l00004ooooo`?o000000Goooooo`000?l0003o0000oooo
o`05o`0000?ooooo0ol00003ooooo`;o00005_ooool2o`000003ooooool0003o000000Wooooo0_l0
0004ooooo`Go000000?oooooo`000?l000000_l0000;ooooo`;o00003?ooool2o`0000;ooooo0_l0
0002ooooo`;o00000_ooool2o`0000;ooooo0_l00006ooooo`;o00001Oooool2o`000003ooooool0
003o000001Wo000000Coooooo`000?l0003ooooo0_l0000?ooooo`;o00000oooool2o`000003oooo
ool0003o000000?ooooo0_l00002ooooo`?o0000??ooool001cooooo00?o0000ooooooooool0@?oo
ool5o`000003ooooool0003o000000;ooooo1?l00003ooooo`Co00000oooool3o`000003ooooool0
003o000000Wooooo0_l00007ooooo`;o000000?oooooo`000?l000001oooool5o`0000Gooooo0ol0
000@ooooo`?o00001Oooool2o`0000Cooooo0_l00002ooooo`;o00000_ooool2o`0000Gooooo0ol0
0006ooooo`;o00001OoooolLo`0000gooooo0_l0000@ooooo`;o00000oooool2o`0000;ooooo0ol0
000looooo`007?ooool00ol0003oooooooooo`10ooooo`;o00003oooool3o`0000Gooooo0_l00000
0ooooooo0000o`000002o`0000Oooooo0_l00004ooooo`;o00000oooool3o`000003ooooool0003o
000000Cooooo0_l000000ooooooo0000o`000002o`0000;ooooo0ol0000Booooo`;o00001Oooool2
o`0000kooooo0_l00003ooooo`;o00001?ooool2o`0000Sooooo2Ol000000ooooooo0000o`00000@
o`0000Cooooo0_l00007ooooo`;o00005Oooool2o`000004ooooool0003o0000o`0000;ooooo0_l0
000iooooo`007?ooool00ol0003oooooooooo`0dooooo`;o000000?oooooo`000?l000003Oooool2
o`0000Kooooo0_l00002ooooo`Ko00001_ooool2o`0000gooooo0_l00003ooooo`;o00000_ooool3
o`0000Sooooo0ol000000ooooooo0000o`000002o`0000Wooooo0_l0000Mooooo`;o00002Oooool2
o`0000Wooooo1_l000000ooooooo0000o`00000Bo`0000;ooooo1?l00007ooooo`;o00003oooool2
o`0000?ooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000003Kooooo000Loooo
o`03o`000?oooooooooo037ooooo0_l000001?oooooo0000o`000?ooool2o`0000Sooooo0_l00003
ooooo`;o00001_ooool4o`000003ooooool0003o000000Co00003_ooool2o`0000kooooo0_l00008
ooooo`?o00000_ooool3o`0000Sooooo0ol0000=ooooo`;o00006?ooool2o`0000?ooooo0_l00000
0ooooooo0000o`000003oooooaOo000000?oooooo`000?l000000_ooool2o`0000Sooooo1?l0000>
ooooo`?o00000_ooool2o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l00000<oooool0
01cooooo00?o0000ooooooooool0<Oooool2o`0000Gooooo0_l00007ooooo`;o00000oooool2o`00
00Sooooo0_l00003ooooo`Co00003_ooool2o`0001Oooooo0_l0000=ooooo`Co00003Oooool3o`00
00oooooo0_l00007ooooo`;o00000_ooool6o`0000;ooooo2Ol000000ooooooo0000o`00000<o`00
00;ooooo1?l000000ooooooo0000o`000004ooooo`Oo00003_ooool2o`0000;ooooo0_l00004oooo
o`;o00001oooool2o`0003?ooooo000Looooo`03o`000?oooooooooo03Sooooo0_l00007ooooo`;o
00000_ooool3o`0000Sooooo0_l00003ooooo`;o00000oooool2o`0000Sooooo0_l00002ooooo`Co
00000_ooool4o`0000Kooooo0_l00006ooooo`;o00002oooool4o`0000Cooooo0_l00009ooooo`;o
000000?oooooo`000?l000000ol00003ooooo`;o00000_ooool2o`000004ooooool0003o0000oooo
o`Co00001?ooool8o`000003ooooool0003o000001go000000?oooooo`000?l000001?ooool2o`00
00?ooooo0_l0000>ooooo`;o00000_ooool2o`0000_ooooo0_l0000eooooo`007?ooool00ol0003o
ooooooooo`0looooo`;o00001oooool3o`0000kooooo0_l00002ooooo`;o00001?ooool6o`0000;o
oooo1Ol000000ooooooo0000o`000002o`0000Kooooo0_l0000=ooooo`So00001_ooool2o`0000co
oooo1Ol00003ooooo`;o00000_ooool3o`0000?ooooo1?l00003ooooo`?o00001_ooool3o`0000;o
oooo4ol00002ooooo`;o0000:Oooool2o`0000Kooooo0_l0000eooooo`007?ooool00ol0003ooooo
ooooo`0Aooooo`;o0000:Oooool2o`000003ooooool0003o000000?ooooo0_l0000:ooooo`;o0000
1?ooool4o`0000?ooooo0_l000000ooooooo0000o`00000@o`0000;ooooo0_l00006ooooo`;o0000
2?ooool9o`0001Gooooo0_l00005ooooo`Co000000?oooooo`000?l000002_ooool2o`0000Gooooo
1?l00003ooooo`co00001?ooool4o`000004ooooool0003o0000o`0000Kooooo0_l0000Cooooo`;o
00000_ooool6o`0000?ooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0Aooooo`;o0000
9oooool2o`0000;ooooo0ol00003ooooo`;o00002_ooool2o`0000Kooooo0_l00003ooooo`;o0000
00?oooooo`000?l000002_l000000ooooooo0000o`000002o`0000;ooooo0ol00003ooooo`;o0000
00?oooooo`000?l000000_ooool2o`0000Cooooo0_l000001?oooooo0000o`000?l0000Aooooo`;o
00003_ooool2o`0000?ooooo0_l00005ooooo`;o00002?ooool2o`0000Gooooo3Ol00003ooooo`Co
000000Coooooo`000?l0003o00001_ooool2o`0001?ooooo0_l00002ooooo`So0000@?ooool001co
oooo00?o0000ooooooooool0<_ooool2o`0000Kooooo1_l0000Kooooo`;o000000?oooooo`000?l0
00004Ol00002ooooo`Co00000_ooool2o`0000Cooooo0ol00006ooooo`;o00000oooool2o`0000co
oooo1?l00009ooooo`Co00001_ooool2o`0000Gooooo0_l00008ooooo`;o000000?oooooo`000?l0
00000_ooool2o`000003ooooool0003o000000So000000?oooooo`000?l000000_ooool4o`0001_o
oooo0_l0000:ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool07Oooool2o`0000kooooo
0_l00003ooooo`;o00001_ooool4o`0001gooooo5_l00002ooooo`Co00002?ooool3o`0000Cooooo
1_l000001?oooooo0000o`000?l0000;ooooo`?o00002_ooool4o`0000Gooooo1?l0000>ooooo`;o
000000?oooooo`000?l000001_ooool9o`000003ooooool0003o000000;ooooo1?l0000Kooooo`;o
0000C?ooool001cooooo00?o0000ooooooooool07Oooool2o`0000kooooo0_l000000ooooooo0000
o`000002o`000003ooooool0003o000000;ooooo0ol000000ooooooo0000o`000007ooooo`;o0000
4_oooolNo`0000Sooooo0_l00004ooooo`;o00000_ooool2o`0000;ooooo0_l0000<ooooo`;o0000
0_ooool2o`0000oooooo1?l0000>ooooo`;o000000?oooooo`000?l000001Oooool2o`0000?ooooo
1Ol0000Aooooo`;o00003Oooool2o`0001;ooooo1Ol0000iooooo`007?ooool00ol0003ooooooooo
o`0`ooooo`Co000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00007ooooo`;o00004_oo
oolNo`0000;ooooo0_l0000:ooooo`;o00003?ooool2o`0000Kooooo0_l00002ooooo`;o00002ooo
ool4o`0000?ooooo0_l00005ooooo`;o00004?ooool2o`0000?ooooo0_l000001?oooooo0000o`00
0?l00004ooooo`;o00001_ooool2o`0000;ooooo0_l0000=ooooo`;o00004_ooool5o`0003Wooooo
000Looooo`;o0000@_ooool2o`0000?ooooo0_l00003ooooo`?o00000oooool2o`0000;ooooo0_l0
0004ooooo`?o000000?oooooo`000?l000004ol00003ooooo`;o000000?oooooo`000?l000003Ooo
ool2o`0000Wooooo0_l0000Gooooo`Co00000oooool4o`0000?ooooo0_l00006ooooo`;o00000ooo
ool4o`000004ooooool0003o0000o`0000;ooooo1_l00004ooooo`;o00001_ooool3o`00017ooooo
0_l00007ooooo`;o00001oooool2o`0003gooooo000Looooo`03o`000?oooooooooo03gooooo0_l0
0002ooooo`;o000000?oooooo`000?l000000_l00003ooooo`?o000000?oooooo`000?l000000_l0
0002ooooo`;o00001?oooolIo`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0000Cooooo
0ol000000ooooooo0000o`000002o`0000Gooooo0_l00002ooooo`;o00002_ooool2o`000003oooo
ool0003o000000;o00000_ooool2o`0000;ooooo1?l00005ooooo`;o00002oooool2o`0000?ooooo
1?l00002ooooo`;o00000oooool2o`0000Cooooo0_l00009ooooo`?o00004Oooool2o`0000Oooooo
0_l00007ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0?Oooool6o`000003ooooool0
003o000000Kooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00000_ooool2o`000003oooo
ool0003o000001Oo00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`Ko0000
1?ooool2o`000004ooooool0003o0000ooooo`;o00001?ooool2o`0000Cooooo0ol000000ooooooo
0000o`000002o`000005ooooool0003o0000o`000?ooool00ol00007ooooo`;o00004_ooool2o`00
00;ooooo0_l00009ooooo`;o00002Oooool2o`0001[ooooo0_l00004ooooo`;o0000@Oooool001co
oooo00?o0000ooooooooool0?oooool3o`000003ooooool0003o000000Oooooo0_l000001?oooooo
0000o`000?l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000ko00000_ooool6o`00
00?ooooo0_l0000<ooooo`?o000000?oooooo`000?l000000oooool2o`000004ooooool0003o0000
ooooo`;o00001?ooool2o`0000Cooooo0_l00007ooooo`?o000000Coooooo`000?l0003ooooo0_l0
0005ooooo`;o000000?oooooo`000?l000000_l0000:ooooo`;o000000?oooooo`000?l000000ooo
ool3o`0000Kooooo1Ol000000ooooooo0000o`000003o`0001Sooooo0_l000000ooooooo0000o`00
0002o`0000Cooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0booooo`;o00003?ooool2
o`000004ooooool0003o0000o`0000Cooooo1?l00007ooooo`;o00001?oooolHo`0000?ooooo0_l0
00000ooooooo0000o`000008ooooo`;o00000oooool2o`0000Gooooo0ol00007ooooo`;o00001Ooo
ool2o`0000Oooooo0_l00002ooooo`Co000000?oooooo`000?l000000_ooool2o`000003ooooool0
003o000000;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000Gooooo1?l0
0006ooooo`Go000000?oooooo`000?l000000ol0000Hooooo`Go0000BOooool001cooooo00?o0000
ooooooooool0<_ooool2o`00013ooooo0_l00004ooooo`;o00001?ooool2o`0000?ooooo0_l00002
oooooaco000000?oooooo`000?l000001?l00003ooooo`;o00000_ooool2o`0000[ooooo0_l00002
ooooo`;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000005o`0000?ooooo0_l00000
1Ooooooo0000o`000?l0003ooooo00Go00001oooool3o`000004ooooool0003o0000ooooo`;o0000
2?ooool2o`00013ooooo0_l0000?ooooo`;o00002_ooool2o`0001Kooooo0_l0000booooo`007?oo
ool00ol0003oooooooooo`0aooooo`;o00007Oooool4o`000003ooooool0003o000000;ooooo5_l0
00000ooooooo0000o`000004o`000004ooooool0003o0000ooooo`;o00000oooool2o`0000;ooooo
0_l00007ooooo`;o00001Oooool2o`0000Sooooo0_l00003ooooo`Go00000_ooool3o`0000;ooooo
0_l000000ooooooo0000o`000003o`0000Oooooo1_l00003ooooo`?o0000:?ooool2o`0002;ooooo
0_l0000booooo`007?ooool00ol0003oooooooooo`0aooooo`;o00003?ooool2o`00013ooooo1?l0
0006oooooaCo000000?oooooo`000?l000001?l00005ooooo`;o00001Oooool2o`0000Sooooo0_l0
0003ooooo`;o00003?ooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool?o`000003oooo
ool0003o000000;o00000_ooool2o`000003ooooool0003o000000;ooooo0ol00009ooooo`;o0000
8oooool3o`0001Cooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00000ooo
ool3o`0000Kooooo0_l000001?oooooo0000o`000?ooool2o`0000Cooooo0_l00008oooooaKo0000
2?ooool4o`0000?ooooo0_l00008ooooo`?o000000Coooooo`000?l0003o00002_ooool5o`000003
ooooool0003o000000?o00000_ooool>o`000003ooooool0003o000000;o00001Oooool3o`0000go
oooo0_l0000Sooooo`Co00003?ooool3o`0000Cooooo0_l0000iooooo`007?ooool00ol0003ooooo
ooooo`0iooooo`;o00000oooool2o`0000Oooooo0_l000001?oooooo0000o`000?ooool2o`0000Co
oooo0_l00004ooooo`;o00000_ooool5o`000003ooooool0003o000000ko00001_ooool2o`0000;o
oooo0_l0000=ooooo`?o000000?oooooo`000?l000001?ooool2o`000005ooooool0003o0000o`00
0?ooool01Ol00002ooooo`;o00000_ooool=o`000003ooooool0003o000000Ko00000_ooool5o`00
00?ooooo0_l00002ooooo`Co00002Oooool2o`0001kooooo0ol00003ooooo`;o00000_ooool2o`00
00;ooooo0ol0000oooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00006?ooool2o`0000;o
oooo0_l00007ooooo`;o00001?oooolGo`0000Kooooo2?l00005ooooo`;o00001oooool6o`0000Co
oooo1_l00002ooooo`Co00000_ooool2o`000003ooooool0003o000000co000000?oooooo`000?l0
00001_l00002ooooo`Co00001?ooool2o`0000;ooooo1?l00004ooooo`;o00000oooool2o`0001?o
oooo0_l00002ooooo`;o00001_ooool2o`0000?ooooo0_l00002ooooo`?o0000@oooool001cooooo
00?o0000ooooooooool06Oooool2o`00017ooooo0_l00003ooooo`;o00000oooool2o`0000kooooo
0_l00002ooooo`Co00003Oooool4o`000003ooooool0003o000000co00002?ooool4o`000004oooo
ool0003o0000o`0000Gooooo0_l00009ooooo`;o00002?ooool4o`0000Wooooo3ol000000ooooooo
0000o`000005o`0000;ooooo0_l0000Dooooo`;o00006?ooool6o`0000Kooooo0_l00003ooooo`;o
00000oooool2o`0000Sooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`0Iooooo`;o0000
5_ooool2o`0000?ooooo0_l0000Aooooo`Go00002?ooool2o`0000?ooooo0_l00004ooooo`go0000
0oooool4o`0000?ooooo0ol00007ooooo`;o00003_ooool2o`000004ooooool0003o0000ooooo`Co
000000?oooooo`000?l000001_ooool2o`000003ooooool0003o000000[o000000?oooooo`000?l0
00001_l000000ooooooo0000o`00000Aooooo`;o00007?ooool3o`0000Sooooo0_l00003ooooo`;o
00003Oooool2o`0003Wooooo000Looooo`03o`000?oooooooooo04Wooooo1?l00002ooooo`;o0000
0_ooool2o`000003ooooool0003o000000Oooooo0_l000000ooooooo0000o`000003o`000003oooo
ool0003o000000Oooooo1?l000001?oooooo0000o`000?ooool2o`0000Oooooo0_l00009ooooo`;o
00000oooool5o`000003ooooool0003o000000;ooooo1_l000000ooooooo0000o`000002o`0000;o
oooo3_l00003ooooo`?o000000Coooooo`000?l0003ooooo0_l0000>ooooo`;o00007?ooool4o`00
00[ooooo0_l00004ooooo`;o00000oooool2o`0003oooooo00001_ooooook^k^oc8b<_l0003o<S8b
onk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003ooooooooo
o`0dooooo`;o00006Oooool2o`0000;ooooo0_l0000:ooooo`;o00002_ooool4o`0000?ooooo0_l0
0002ooooo`;o00005Oooool2o`0000?ooooo1?l00002ooooo`;o00000_ooool<o`000003ooooool0
003o000000co00000_ooool3o`0000;ooooo1_l000000ooooooo0000o`00000Zooooo`;o00000_oo
ool2o`0000Kooooo0_l00004ooooo`;o00000oooool2o`0003oooooo00001_ooooooMgMgoiRHV?oo
ooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003o
ooooooooo`0dooooo`;o00004_ooool3o`0000?ooooo0_l00006ooooo`;o00004Oooool6o`0000Ko
oooo0_l00002ooooo`Co00001_ooool2o`0000Wooooo0_l00004ooooo`;o00000_ooool2o`0000;o
oooo8Ol00002ooooo`Go000000?oooooo`000?l000000_ooool2o`0000[ooooo0_l0000Jooooo`;o
00000_ooool2o`0000Gooooo0ol00007ooooo`;o00002oooool2o`0003Cooooo00000ooooooo410@
ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo04Sooooo0ol00003ooooo`;o00001?ooool5o`0000Wooooo0_l00005ooooo`;o
00002_ooool8o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Ko
oooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000co00000_ooool>o`00
0003ooooool0003o000000;o00001oooool4o`0000Sooooo0_l0000Hooooo`;o00002oooool2o`00
00Sooooo0_l0000;ooooo`;o0000=?ooool00003ooooool0003ooooo00;ooooo00?o0000oooooooo
ool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol00011ooooo`;o00002oooool3o`00
00?ooooo1ol00007ooooo`?o00004_ooool3o`0000Gooooo0_l00002ooooo`Go00001?ooool2o`00
00Oooooo1_l000000ooooooo0000o`000004o`0000;ooooo5ol00002ooooo`Go00002Oooool2o`00
00;ooooo0_l0000Nooooo`;o0000F?ooool00003ooooool0003ooooo00;ooooo00?o0000oooooooo
ool02Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0@Oooool2o`00
00Kooooo1?l000001?oooooo0000o`000?l00003ooooo`Co000000?oooooo`000?l000001oooool3
o`0000Gooooo0_l00003ooooo`;o00001oooool2o`0000;ooooo0_l00002ooooo`;o000000Cooooo
o`000?l0003o00000oooool2o`000003ooooool0003o000000Gooooo1_l00003oooooaoo000000?o
ooooo`000?l000001Ol00009ooooo`Go00001?ooool2o`0002Cooooo0_l00009ooooo`;o0000@Ooo
ool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08
ooooo`03o`000?oooooooooo04Wooooo1?l00002ooooo`;o00000oooool6o`0000Sooooo0_l00002
ooooo`;o00000_ooool2o`0000;ooooo0ol0000;ooooo`;o00000_ooool2o`0000Kooooo0ol00008
ooooo`;o00000_ooool2o`0000?ooooo2ol00002ooooo`[o000000?oooooo`000?l000001?l00002
ooooo`Oo00002Oooool5o`0000Cooooo0_l0000Tooooo`;o00001?ooool2o`0000?ooooo0_l00011
ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o
0000ooooooooool0>oooool2o`0001Wooooo1?l0000<ooooo`;o00001_ooool2o`0000[ooooo0_l0
0006ooooo`;o00001?ooool2o`000003ooooool0003o000000Oooooo5?l000000ooooooo0000o`00
000@o`0000;ooooo1ol0000;ooooo`;o0000;?ooool2o`0000;ooooo0_l00016ooooo`0000Kooooo
onk^k_lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000oooooooo
ool0>oooool2o`0000Cooooo0_l0000:ooooo`?o00007oooool2o`0000Wooooo0_l00003ooooo`;o
000000?oooooo`000?l000001oooool2o`0000Oooooo2_l000000ooooooo0000o`00000Jo`0000;o
oooo2?l0000?ooooo`;o00004oooool2o`0000Kooooo0_l00003ooooo`;o00001Oooool2o`0004[o
oooo000Looooo`03o`000?oooooooooo047ooooo0_l0000:ooooo`?o00006?ooool2o`0000Cooooo
0ol0000>ooooo`;o00005OoooolTo`0000Cooooo1?l000000ooooooo0000o`00000?ooooo`;o0000
4oooool2o`0000Gooooo0ol00003ooooo`;o00000oooool2o`0004cooooo000Looooo`03o`000?oo
oooooooo04[ooooo0_l0000Fooooo`;o00001?ooool;o`0000Kooooo1?l000000ooooooo0000o`00
0002o`0000Kooooo0_l00009ooooobSo00000oooool2o`00033ooooo0_l00009ooooo`;o00003_oo
ool2o`0003cooooo000Looooo`03o`000?oooooooooo04[ooooo1_l00005ooooo`;o00002oooool2
o`0000Kooooo1?l00003ooooo`;o00001_ooool4o`000003ooooool0003o000000;o00000oooool2
o`000003ooooool0003o000000Cooooo0_l00002ooooo`Co00000ooooolWo`0001Oooooo0_l0000B
ooooo`;o00000oooool2o`0001Wooooo0_l0000looooo`007?ooool00ol0003oooooooooo`1<oooo
o`Co00001Oooool2o`0000Wooooo0_l0000:ooooo`;o00003?ooool3o`0000?ooooo0_l00003oooo
o`;o00001oooool2o`0000;ooooo1_l000001?oooooo0000o`000?oooolCo`000003ooooool0003o
0000013o00003_ooool2o`0000Gooooo0_l0000@ooooo`Co00000oooool4o`0000?ooooo0_l00006
ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0>Oooool2o`0001?ooooo1?l00002oooo
o`;o00001oooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000003oooo
o`;o00001_ooool2o`0000Gooooo0_l0000Gooooo`[o000000?oooooo`000?l000008Ol000000ooo
oooo0000o`000002ooooo`;o00001oooool2o`0001Oooooo0ol00006ooooo`;o00000oooool4o`00
00Cooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00003oooool2o`0000;o
oooo1?l00002ooooo`;o00001oooool2o`0000Cooooo1_l00003ooooo`;o00000oooool2o`000003
ooooool0003o000001;ooooo0_l00002ooooo`;o00001ooooolZo`0000;ooooo1?l00002ooooo`;o
00003?ooool2o`0001?ooooo0_l00007ooooo`?o00000_ooool3o`0004kooooo000Looooo`03o`00
0?oooooooooo03gooooo0_l0000;ooooo`Go00005?ooool4o`0000[ooooo0_l0000Eooooo`?o0000
00?oooooo`000?l000001?ooool3o`0000;ooooo9Ol000001?oooooo0000o`000?ooool4o`0000Oo
oooo0ol00007ooooo`;o00004oooool2o`0000Oooooo0ol00002ooooo`;o00000_ooool2o`0004_o
oooo000Looooo`03o`000?oooooooooo03?ooooo0_l00008ooooo`;o00001_ooool2o`0000?ooooo
1Ol0000>ooooo`?o00002oooool2o`0000Sooooo0_l0000Aooooo`?o00001oooool3o`0000Cooooo
8ol00003ooooo`Go00000_ooool2o`0000?ooooo0ol0000:ooooo`;o00004_ooool2o`000003oooo
ool0003o000000;ooooo0_l00007ooooo`Co0000BOooool001cooooo00?o0000ooooooooool0<ooo
ool2o`00013ooooo0_l00003ooooo`?o000000Coooooo`000?l0003o00001oooool2o`0000?ooooo
0ol0000:ooooo`?o00000_ooool3o`0000?ooooo0_l00008ooooo`;o00001oooool2o`0000Wooooo
0ol00002ooooob?o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000002ooooo`;o
00003?ooool2o`0000;ooooo0ol0000Aooooo`;o000000?oooooo`000?l000003Oooool2o`0004Wo
oooo000Looooo`03o`000?oooooooooo04_ooooo0_l000001?oooooo0000o`000?l00007ooooo`;o
00001_ooool2o`0000;ooooo0_l00002ooooo`Co00000oooool5o`0000;ooooo0_l00007ooooo`;o
00004_ooool:o`000003ooooool0003o000002;o00004_ooool4o`000003ooooool0003o000000Wo
oooo0_l000001?oooooo0000o`000?l0001Oooooo`007?ooool00ol0003oooooooooo`0oooooo`;o
00007oooool2o`000003ooooool0003o000000Go00001_ooool4o`0000;ooooo0_l0000<ooooo`;o
00000_ooool2o`0000Kooooo0_l00002oooooa7o00000_oooolKo`0001Cooooo0_l0000<ooooo`;o
000000Coooooo`000?l0003o00002?ooool4o`0000Oooooo0ol00019ooooo`007?ooool2o`00043o
oooo0_l0000Dooooo`;o00003?ooool5o`0000Sooooo0_l0000;ooooo`;o00001Oooool2o`0000;o
oooo0_l00006ooooo`;o00000_ooool2o`000003ooooool0003o000000co00000_oooolJo`0000Wo
oooo0_l0000>ooooo`;o00005_ooool4o`0000Oooooo0ol00019ooooo`007?ooool00ol0003ooooo
ooooo`1Eooooo`;o00003_ooool2o`0000;ooooo0_l00008ooooo`;o00002?ooool2o`0001Sooooo
4?l000000ooooooo0000o`00000=o`0000;ooooo2?l00004ooooo`;o00000oooool2o`0000Wooooo
1?l000000ooooooo0000o`000008ooooo`;o00004Oooool2o`00053ooooo000Looooo`03o`000?oo
oooooooo05Cooooo0_l0000Cooooo`;o00001?ooool2o`0000;ooooo0_l00007ooooo`;o00003Ooo
ool2o`0000Oooooo0_l00003ooooob?o000000?oooooo`000?l000001_ooool2o`0000kooooo1Ol0
000:ooooo`;o00004Oooool2o`00053ooooo000Looooo`03o`000?oooooooooo04gooooo1_l00000
0ooooooo0000o`000009ooooo`Co00000_ooool2o`0000Sooooo0_l00005ooooo`;o00001?ooool2
o`0000gooooo0_l00005ooooo`Co000000?oooooo`000?l000000_oooolPo`000004ooooool0003o
0000o`0000[ooooo0_l0000=ooooo`;o00005Oooool2o`0000Sooooo0_l0001>ooooo`007?ooool0
0ol0003oooooooooo`1<ooooo`Wo00000_ooool2o`0000Kooooo1?l00002ooooo`;o00002_ooool2
o`0000?ooooo0_l00004ooooo`;o00001Oooool2o`0000Wooooo0_l00002ooooo`;o00000oooool3
o`000003ooooool0003o000002;o00002_ooool2o`0000[ooooo0_l00004ooooo`;o00004_ooool2
o`0000Sooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`18ooooo`;o00000_ooool4o`00
00;ooooo0ol00002ooooo`?o00000oooool3o`0000Cooooo0ol00004ooooo`;o00001?ooool2o`00
00kooooo1?l00009ooooo`;o00001ooooolUo`000003ooooool0003o000001Kooooo0_l00004oooo
o`;o00006oooool3o`0004kooooo000Looooo`03o`000?oooooooooo04Sooooo0_l00002ooooo`?o
00002Oooool2o`0000?ooooo0ol00004ooooo`;o00000oooool4o`0000_ooooo1?l00005ooooo`?o
00001Oooool2o`0000kooooo0ol000000ooooooo0000o`00000Lo`0002?ooooo0_l0000Hooooo`?o
0000C_ooool001cooooo00?o0000ooooooooool0:oooool2o`0001oooooo0_l0000Booooo`;o0000
00?oooooo`000?l000001?ooool4o`000003ooooool0003o000000Sooooo1?l000001?oooooo0000
o`000?ooool5o`0000Cooooo0_l00008ooooo`;o00001?ooool3o`000003ooooool0003o000001Oo
000000?oooooo`000?l000000oooool2o`0000oooooo0_l0000?ooooo`;o00002Oooool3o`0000Co
oooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o00007oooool2o`0000kooooo
0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`Co00002?ooool2o`0000?o
oooo1Ol000000ooooooo0000o`00000=ooooo`?o00001?ooool2o`000003ooooool0003o000001go
000000Coooooo`000?l0003o00001oooool2o`0000Gooooo0_l0000<ooooo`;o00003?ooool5o`00
00;ooooo0_l00003ooooo`;o00002?ooool2o`0004Sooooo000Looooo`03o`000?oooooooooo04?o
oooo0_l0000Gooooo`;o00000_ooool2o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l0
00001oooool2o`0000Gooooo1_l0000=ooooo`;o00000ooooolTo`000004ooooool0003o0000o`00
00Oooooo0_l0000>ooooo`;o00000oooool2o`0000cooooo0_l000000ooooooo0000o`000002oooo
o`;o00000oooool2o`0000Sooooo0_l000000ooooooo0000o`000015ooooo`007?ooool00ol0003o
ooooooooo`13ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Cooooo0_l00007ooooo`Co
00002?ooool5o`00013ooooo0_l0000Dooooo`So00000_oooolGo`0000Cooooo0_l0000:ooooo`;o
00003?ooool2o`0000Cooooo0_l0000;ooooo`;o00001Oooool3o`000003ooooool0003o000000co
oooo0_l00015ooooo`007?ooool00ol0003oooooooooo`0jooooo`;o00002_ooool2o`0000Wooooo
0_l00004ooooo`;o00001oooool4o`000003ooooool0003o000000Co00000_ooool2o`0000Oooooo
0_l0000=ooooo`;o00004?ooool2o`0000?ooooo7Ol0000?ooooo`;o00004_ooool2o`0000Gooooo
0_l0000;ooooo`Ko00002?ooool2o`0004Wooooo000Looooo`03o`000?oooooooooo03[ooooo0ol0
000Dooooo`;o00000oooool2o`0000gooooo1_l00003ooooo`;o00001_ooool2o`0000;ooooo0_l0
0003ooooo`;o00001?ooool2o`00013ooooo0_l00002ooooo`;o000000?oooooo`000?l000005_l0
00000ooooooo0000o`00000=ooooo`;o00004Oooool2o`0000Sooooo0_l00005ooooo`;o00001?oo
ool4o`0000[ooooo0_l00019ooooo`007?ooool00ol0003oooooooooo`0kooooo`;o00006?ooool3
o`0000?ooooo0_l000000ooooooo0000o`00000>ooooo`Co00002?ooool2o`0000?ooooo0_l00004
ooooo`;o00003oooool4o`000003ooooool0003o000000?o000000?oooooo`000?l000000ol00000
0ooooooo0000o`000009o`0000;ooooo1Ol0000=ooooo`;o00002?ooool2o`0000Oooooo0ol00002
ooooo`Co00002?ooool2o`0000Cooooo1?l0001Eooooo`007?ooool00ol0003oooooooooo`19oooo
o`;o00000_ooool2o`0000Kooooo0_l00004ooooo`;o000000?oooooo`000?l000002oooool2o`00
0003ooooool0003o000000;o00000oooool2o`0000[ooooo0_l00002ooooo`;o00003oooool4o`00
0003ooooool0003o000000;o00000oooool7o`000003ooooool0003o000000Ko00001?ooool2o`00
01Kooooo1?l00008ooooo`;o00000_ooool5o`0000Oooooo0_l00009ooooo`;o0000D_ooool001co
oooo00?o0000ooooooooool0BOooool2o`0000;ooooo0_l0000?ooooo`;o00002oooool7o`000003
ooooool0003o000000;o00002Oooool4o`00013ooooo0_l00002ooooo`;o000000?oooooo`000?l0
00001_ooool5o`0000;ooooo2?l00006ooooo`;o00005?ooool2o`00017ooooo0_l00007ooooo`;o
00002Oooool2o`0005;ooooo000Looooo`;o0000Ioooool2o`000003ooooool0003o000000;ooooo
0_l000000ooooooo0000o`000004o`0000[ooooo1?l0000@ooooo`Co00000oooool<o`0000?ooooo
1?l00002ooooo`;o00001_ooool2o`0000gooooo0_l00004ooooo`;o00004?ooool4o`0000oooooo
0_l0001Eooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o00006_ooool2o`000003ooooool0
003o000000Kooooo0_l000000ooooooo0000o`00000<ooooo`;o00000_ooool2o`0000kooooo0_l0
0003ooooo`_o00001?ooool2o`0000Gooooo1?l0000@ooooo`Co00001?ooool2o`0000[ooooo0_l0
0004ooooo`;o00004Oooool2o`0005Gooooo000Looooo`03o`000?oooooooooo03cooooo1?l0000:
ooooo`;o00004Oooool2o`0000Kooooo0_l00004ooooo`?o00003?ooool2o`0000;ooooo1_l00002
ooooo`;o00003oooool2o`0000Oooooo1?l000001?oooooo0000o`000?ooool4o`000004ooooool0
003o0000ooooo`Ko00001?ooool6o`000003ooooool0003o000000;ooooo0ol0000Aooooo`?o0000
3_ooool3o`0005cooooo000Looooo`03o`000?oooooooooo03cooooo1?l00007ooooo`;o00005?oo
ool4o`0000Cooooo0_l00004ooooo`?o00003?ooool2o`0000;ooooo1?l0000Eooooo`;o00001ooo
ool2o`0000?ooooo1_l00002ooooo`Go00000_ooool3o`0000;ooooo1ol000000ooooooo0000o`00
0003ooooo`;o00004_ooool2o`0000Kooooo0_l00005ooooo`Co000000?oooooo`000?l00000FOoo
ool001cooooo00?o0000ooooooooool0??ooool2o`0000Wooooo0_l0000<ooooo`;o00001?ooool2
o`000004ooooool0003o0000o`0000Cooooo0_l0000Kooooo`;o00008oooool3o`0000?ooooo0ol0
0005ooooo`;o00000_ooool4o`0000Sooooo0_l0000<ooooo`;o00001?ooool2o`0000Oooooo0_l0
0005ooooo`;o00000oooool2o`0005Wooooo000Looooo`03o`000?oooooooooo03Wooooo0_l00000
0ooooooo0000o`00000Gooooo`;o00001?ooool3o`0000gooooo0_l00006ooooo`?o00000_ooool2
o`0000Oooooo0ol0000;ooooo`;o00004Oooool4o`0000?ooooo0ol0000Iooooo`;o00001oooool2
o`0000?ooooo0_l00004ooooo`;o00002Oooool3o`0006;ooooo000Looooo`03o`000?oooooooooo
03Wooooo0_l0000Nooooo`;o000000?oooooo`000?l000000_ooool2o`0000Wooooo0_l00006oooo
o`?o000000?oooooo`000?l000000_l00003ooooo`;o000000?oooooo`000?l000003?ooool2o`00
017ooooo1?l00003ooooo`Co00002Oooool2o`0000;ooooo0_l00007ooooo`;o00002Oooool2o`00
00Gooooo0_l00005ooooo`;o00000_ooool3o`000004ooooool0003o0000o`0006;ooooo000Loooo
o`03o`000?oooooooooo05Wooooo0_l00005ooooo`Co00001oooool2o`000003ooooool0003o0000
00?ooooo0_l00002ooooo`Co00000oooool2o`0000;ooooo0_l0000Gooooo`;o00002?ooool2o`00
00Cooooo1?l00004ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Oooooo0_l0000;oooo
o`?o00000_ooool3o`0000Cooooo0_l00002ooooo`?o0000I_ooool001cooooo00?o0000oooooooo
ool0@Oooool2o`0001Kooooo0_l00005ooooo`Go00002Oooool2o`0000?ooooo1?l00003ooooo`;o
00001_ooool2o`0001Oooooo0_l00008ooooo`Co000000Coooooo`000?l0003ooooo0_l00004oooo
o`;o00001Oooool2o`0000Gooooo0_l0000=ooooo`?o00000_ooool3o`00017ooooo0_l00004oooo
o`;o0000F?ooool001cooooo00?o0000ooooooooool0@Oooool2o`0001Kooooo0_l00008ooooo`;o
00002Oooool2o`0000Gooooo0_l00003ooooo`;o00007?ooool2o`0000gooooo0_l000001?oooooo
0000o`000?ooool2o`0000Wooooo0_l00007ooooo`;o00002Oooool2o`0001_ooooo0_l00004oooo
o`;o0000F?ooool001cooooo00?o0000ooooooooool0LOooool2o`0002Gooooo0_l0000?ooooo`;o
00001Oooool2o`0000Kooooo0_l00004ooooo`;o00002?ooool2o`0000;ooooo0_l0000Aooooo`Co
00001Oooool2o`0000Kooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o0000
00?oooooo`000?l000000_ooool2o`0000Kooooo0ol000001?oooooo0000o`000?l00006ooooo`?o
000000?oooooo`000?l000004Oooool2o`0001Sooooo0_l00006ooooo`;o000000?oooooo`000?l0
00001Oooool2o`0000cooooo0_l00008ooooo`;o00005Oooool4o`0000Gooooo0_l00003ooooo`;o
000000?oooooo`000?l00000Eoooool001cooooo00?o0000ooooooooool0DOooool2o`000003oooo
ool0003o000000;ooooo0_l00006ooooo`?o000000Coooooo`000?l0003o00001_ooool3o`0001Co
oooo0_l00002ooooo`;o00005?ooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`0000?o
oooo1?l00009ooooo`;o00003?ooool2o`0001;ooooo0_l00002ooooo`;o00002oooool2o`0005[o
oooo000Looooo`03o`000?oooooooooo05Cooooo0_l00009ooooo`;o00001Oooool2o`0001Wooooo
0_l00005ooooo`;o00006Oooool3o`0000;ooooo0_l00003ooooo`Co00002Oooool2o`0000?ooooo
0_l00009ooooo`;o00000oooool2o`0000Wooooo1?l0001[ooooo`007?ooool00ol0003ooooooooo
o`1Looooo`;o000000?oooooo`000?l000001?ooool3o`0001Wooooo1Ol0000Iooooo`;o00000_oo
ool3o`0001Oooooo1?l00009ooooo`;o000000?oooooo`000?l000000_l00009ooooo`Co0000Jooo
ool001cooooo00?o0000ooooooooool0G?ooool2o`000003ooooool0003o000000Cooooo0_l00002
ooooo`;o00002?ooool2o`0000?ooooo0_l00002ooooo`?o000000?oooooo`000?l000001?l0000I
ooooo`;o00000_ooool2o`0001Sooooo0_l0000>ooooo`;o00003Oooool2o`0006_ooooo000Loooo
o`;o0000@Oooool2o`0002Oooooo0ol000000ooooooo0000o`000004ooooo`;o00000oooool2o`00
00;ooooo0ol000001?oooooo0000o`000?ooool2o`0000;ooooo0_l0000Dooooo`;o00007Oooool2
o`0008_ooooo000Looooo`03o`000?oooooooooo043ooooo0_l0000Eooooo`Go00003_ooool2o`00
0003ooooool0003o000000kooooo0_l00008ooooo`;o00005?ooool2o`0000Cooooo1?l000000ooo
oooo0000o`00000:ooooo`;o00001_ooool2o`0008_ooooo000Looooo`03o`000?oooooooooo04Co
oooo0_l0000Aooooo`Go00001oooool2o`0000Gooooo0_l0000Fooooo`;o00000oooool2o`0001So
oooo1_l000000ooooooo0000o`00000:ooooo`;o00000oooool2o`00027ooooo0_l00004ooooo`;o
00000oooool2o`00063ooooo000Looooo`03o`000?oooooooooo04Cooooo0_l00006ooooo`;o0000
5Oooool4o`0000Cooooo0_l0000=ooooo`;o00001_ooool2o`0001gooooo0_l00008ooooo`;o0000
3?ooool2o`0001Wooooo0_l00006ooooo`;o00001?ooool2o`0000?ooooo0_l0001Pooooo`007?oo
ool00ol0003oooooooooo`1<ooooo`;o00005oooool4o`0000;ooooo0_l0000=ooooo`;o00003Ooo
ool2o`00023ooooo0_l00003ooooo`;o00005_ooool2o`000003ooooool0003o000000Oooooo0_l0
001cooooo`007?ooool00ol0003oooooooooo`1Oooooo`;o00001_ooool2o`0000?ooooo0_l0000:
ooooo`;o00003oooool2o`0001oooooo0_l000001?oooooo0000o`000?ooool2o`0000cooooo0_l0
0008ooooo`;o000000?oooooo`000?l000006oooool2o`0005oooooo000Looooo`03o`000?oooooo
oooo05oooooo0_l00005ooooo`;o000000Coooooo`000?l0003ooooo0_l00007ooooo`;o000000?o
ooooo`000?l000004_ooool2o`0000cooooo0_l0000>ooooo`;o000000?oooooo`000?l000000_oo
ool2o`0000?ooooo0_l00006ooooo`;o00007_ooool2o`0000Oooooo0ol0001Oooooo`007?ooool0
0ol0003oooooooooo`1Vooooo`;o000000?oooooo`000?l000001_ooool2o`0000;ooooo0_l00005
ooooo`?o00001_ooool2o`0000Cooooo0ol0000<ooooo`;o00003?ooool2o`0000Oooooo0ol00002
ooooo`;o00001_ooool2o`0000Sooooo0_l00007ooooo`;o00002oooool2o`0000?ooooo0_l00002
ooooo`Co00002?ooool2o`0005Cooooo000Looooo`03o`000?oooooooooo067ooooo0_l00005oooo
o`?o00001_ooool2o`0000Gooooo0_l00002ooooo`Oo00000_ooool4o`0000;ooooo0_l0000Aoooo
o`;o00001_ooool4o`0000Sooooo0_l0000@ooooo`;o000000Coooooo`000?l0003o00001oooool2
o`00013ooooo0_l00004ooooo`;o00002?ooool2o`0005Cooooo000Looooo`03o`000?oooooooooo
067ooooo0_l00005ooooo`?o00001_ooool2o`0000;ooooo0_l000000ooooooo0000o`000005oooo
o`Co00001?ooool2o`0000Gooooo0_l0000>ooooo`;o00001_ooool2o`00017ooooo0_l00006oooo
o`;o000000Coooooo`000?l0003ooooo0_l00020ooooo`007?ooool00ol0003oooooooooo`1Soooo
o`;o00003?ooool2o`0000;ooooo0_l00006ooooo`;o00003oooool2o`0000[ooooo0_l00007oooo
o`Co00001oooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o00001_ooool2o`00
00[ooooo0_l0001jooooo`007?ooool00ol0003oooooooooo`1Sooooo`Co00001Oooool2o`0000_o
oooo0_l00002ooooo`;o00000_ooool2o`0001Oooooo0_l00007ooooo`Co00001Oooool8o`000004
ooooool0003o0000ooooo`Co00002?ooool2o`0000Oooooo0_l000000ooooooo0000o`000002o`00
07Gooooo000Looooo`03o`000?oooooooooo06Gooooo0_l00005ooooo`;o000000?oooooo`000?l0
00002?ooool2o`0000Kooooo0_l00003ooooo`;o00001?ooool2o`0000Sooooo0_l00008ooooo`;o
00000oooool2o`0000Gooooo0ol000000ooooooo0000o`000002o`0000Cooooo1?l00008ooooo`;o
00000_ooool2o`0000Kooooo1?l0001eooooo`007?ooool00ol0003oooooooooo`1_ooooo`;o0000
00?oooooo`000?l000000_l00002ooooo`Co00002_ooool2o`0000?ooooo0ol00004ooooo`;o0000
00Coooooo`000?l0003o00002?ooool2o`0000;ooooo0ol00006ooooo`;o00001oooool2o`00013o
oooo0_l00004ooooo`;o0000NOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q
8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo06_ooooo0_l00005
ooooo`Co00000_ooool4o`0000oooooo0_l00005ooooo`Go00003?ooool5o`0000kooooo0_l00003
ooooo`;o00004Oooool2o`0007Wooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ
8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1Gooooo`;o0000
0oooool2o`0000gooooo0_l00005ooooo`;o00004oooool4o`0000Wooooo0_l0000=ooooo`;o0000
00?oooooo`000?l000001?ooool3o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0001cooooo
0_l0001^ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`1Gooooo`;o00000oooool2o`0001Sooooo
0_l0000<ooooo`;o000000?oooooo`000?l000000_l0000=ooooo`;o00000oooool2o`0000Wooooo
0_l00002ooooo`?o00000oooool2o`0000;ooooo0_l0000;ooooo`;o00005?ooool2o`0006kooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RH
oc8b<P06ooooo`?o0000M_ooool2o`0000_ooooo0ol0000Booooo`;o00000oooool2o`0000Cooooo
0_l000000ooooooo0000o`000002o`0000Gooooo0_l00009ooooo`;o00001oooool2o`0001Gooooo
0_l0001]ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05olc<c?l0
003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`23ooooo`Co00007?ooool2o`000003oooo
ool0003o000000;o000000?oooooo`000?l000000_ooool2o`0000Wooooo0_l000000ooooooo0000
o`00000Kooooo`;o0000KOooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Ooo
ool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0F_ooool2o`00027ooooo
0_l00006ooooo`;o00008Oooool2o`000003ooooool0003o000000;ooooo0_l0000<ooooo`;o0000
7Oooool2o`0006_ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oo
oooo^[Zjo`000006ooooo`03o`000?oooooooooo05[ooooo0_l0000Qooooo`?o00000_ooool2o`00
01Cooooo0_l00012ooooo`;o0000Joooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool0
1OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0O_ooool2o`0000;ooooo0_l0
000Dooooo`Co00000_ooool2o`0001Gooooo0_l00005ooooo`;o0000Roooool001cooooo00?o0000
ooooooooool0IOooool2o`0000Wooooo0_l0000>ooooo`;o00001Oooool2o`0000gooooo0_l00002
ooooo`;o00000_ooool2o`0001Gooooo0_l00005ooooo`;o0000Roooool001cooooo00?o0000oooo
ooooool0IOooool2o`0000Wooooo1?l0000<ooooo`Co00000oooool2o`0000_ooooo1?l00007oooo
o`?o00002oooool2o`000003ooooool0003o000009Oooooo000Looooo`03o`000?oooooooooo077o
oooo0ol0000>ooooo`;o00002oooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o
000000?oooooo`000?l000001?l00002ooooo`;o00001Oooool2o`000003ooooool0003o000000Go
oooo0_l0000Iooooo`;o0000MOooool001cooooo00?o0000ooooooooool0LOooool2o`0000;ooooo
0_l0000Hooooo`;o00001_ooool2o`0000;ooooo1Ol000000ooooooo0000o`000002o`000003oooo
ool0003o000000oooooo0_l0000Iooooo`;o0000MOooool001cooooo00?o0000ooooooooool0MOoo
ool2o`0001;ooooo0_l0000:ooooo`;o00001Oooool4o`000003ooooool0003o000000;o0000Y?oo
ool001cooooo00?o0000ooooooooool0P?ooool2o`0000Oooooo0ol00009ooooo`;o00000_ooool2
o`0000?ooooo0_l0000;ooooo`;o0000W?ooool001cooooo00?o0000ooooooooool0M_ooool2o`00
00Sooooo1?l00006ooooo`;o00002_ooool2o`000003ooooool0003o0000013ooooo0_l0002Loooo
o`007?ooool00ol0003oooooooooo`1^ooooo`;o00001_ooool4o`0000Sooooo0_l0000:ooooo`;o
00000_ooool2o`0000;ooooo0_l0000Dooooo`;o00006Oooool2o`0001;ooooo0_l0001/ooooo`00
7?ooool00ol0003oooooooooo`1^ooooo`;o00002?ooool2o`0001Cooooo0_l00002ooooo`;o0000
00?oooooo`000?l000005Oooool2o`0001Wooooo0_l0000Booooo`;o0000K?ooool001cooooo00?o
0000ooooooooool0S_ooool2o`0000Gooooo1?l00002ooooo`;o00001?ooool2o`0000;ooooo0_l0
00000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l00000V?ooool001cooooo00?o0000
ooooooooool0S_ooool2o`0000Oooooo0_l00002ooooo`;o00001?ooool2o`0000;ooooo0_l00000
0ooooooo0000o`000005ooooo`;o00003?ooool2o`0008[ooooo000Looooo`;o0000U_ooool2o`00
00Oooooo0_l0000Mooooo`;o0000R_ooool001cooooo00?o0000ooooooooool0Q_ooool2o`0000go
oooo0_l00007ooooo`;o0000ZOooool001cooooo00?o0000ooooooooool0Q_ooool2o`000<7ooooo
000Looooo`03o`000?oooooooooo09Wooooo0_l0002^ooooo`007?ooool00ol0003oooooooooo`2I
ooooo`;o0000[_ooool001cooooo00?o0000ooooooooool0QOooool2o`000<;ooooo000Looooo`03
o`000?oooooooooo08Gooooo0_l0000?ooooo`;o0000/Oooool001cooooo00?o0000ooooooooool0
U_ooool2o`0000gooooo0_l0002Rooooo`007?ooool00ol0003oooooooooo`2Uooooo`;o00000_oo
ool2o`0009kooooo000Looooo`03o`000?oooooooooo09Oooooo0_l0000@ooooo`;o00002Oooool2
o`0009?ooooo000Looooo`03o`000?oooooooooo09Oooooo0_l00002ooooo`;o00005oooool2o`00
09?ooooo000Looooo`03o`000?oooooooooo09_ooooo0_l0002/ooooo`007?ooool00ol0003ooooo
ooooo`2Kooooo`;o0000[?ooool001cooooo00?o0000ooooooooool0Voooool2o`000:cooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0XOooool2o`000:Kooooo
000Looooo`03o`000?oooooooooo0:7ooooo0_l0002Vooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Booooo`Co
000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003ooooooooo
o`05ooooo`?o0000oooooom:ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Doooo
o`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`00
5?ooool00ol0003oooooooooo`3ooooooe;ooooo000Booooo`03oeEEEOmVIVKo00000?ooooooE?oo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:7ooooo00Co410@o`000?l0003o
oooo0_l000000ol@413oooooooooo`0Fooooo`Co000000?o410@ooooooooool01Ol00003ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^08cooooo002Roooo
o`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo00?o0000ooooooooool00_ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0S?ooool00:;ooooo00Go0000ooooooooooooooooo`00000Kooooo`03
o`000?oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h02?ooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool0R_ooool00:;ooooo00Go0000ooooooooooooooooo`000009oooo
o`Ko00003?ooool00ol0003oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?oZJVYoa0@
4?ooool00_ooool01Ol0003ooooooooooooooooo000008cooooo002Rooooo`05o`000?n7QhOooooo
ojVYZOl000006oooool00ol0003oooooooooo`05ooooo`03ogMgMomVIVKooooo00Cooooo00?o410@
o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000008cooooo002Qooooo`03oa0@4?l0003o
MgMg00;o000000?oV9RHooooooooool06Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Cooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@08cooooo0032
ooooo`03o`000?oooooooooo00;ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05oa0@4?nH
V9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg08cooooo0030ooooo`03oeEE
EOmVIVKo000000Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05ojVYZOl@413o0000oa0@
4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^08cooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1236) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.69269 .48732 Mdot
.65191 .51308 Mdot
.39031 .37052 Mdot
.54167 .62466 Mdot
.45717 .19994 Mdot
.40811 .39578 Mdot
.60569 .38954 Mdot
.55622 .3565 Mdot
.40981 .36643 Mdot
.69435 .32292 Mdot
.58468 .3888 Mdot
.49343 .55988 Mdot
.57192 .36316 Mdot
.52539 .6503 Mdot
.45958 .14386 Mdot
.47566 .69035 Mdot
.66665 .49147 Mdot
.29761 .50215 Mdot
.56825 .63451 Mdot
.40059 .34658 Mdot
.6307 .57047 Mdot
.52431 .64183 Mdot
.65364 .54999 Mdot
.52511 .65112 Mdot
.5238 .60704 Mdot
.68822 .53236 Mdot
.71686 .52399 Mdot
.49308 .61489 Mdot
.48287 .60586 Mdot
.55615 .36294 Mdot
.3331 .63965 Mdot
.43863 .17101 Mdot
.56736 .58714 Mdot
.21886 .3819 Mdot
.57456 .33927 Mdot
.65125 .71647 Mdot
.39962 .38634 Mdot
.59129 .36282 Mdot
.59614 .36329 Mdot
.59873 .33859 Mdot
.58791 .37683 Mdot
.66924 .54117 Mdot
.64257 .38025 Mdot
.36195 .45098 Mdot
.48815 .6897 Mdot
.5672 .2323 Mdot
.70649 .73167 Mdot
.48121 .66503 Mdot
.68026 .4936 Mdot
.26703 .38358 Mdot
.46025 .26262 Mdot
.60885 .35786 Mdot
.42015 .34416 Mdot
.26608 .78882 Mdot
.58459 .34811 Mdot
.5735 .65971 Mdot
.39331 .37925 Mdot
.51186 .64616 Mdot
.52212 .65564 Mdot
.62352 .63945 Mdot
.49142 .6817 Mdot
.31707 .54664 Mdot
.64301 .48605 Mdot
.5768 .47394 Mdot
.40858 .37281 Mdot
.59802 .3784 Mdot
.64969 .52739 Mdot
.57089 .3546 Mdot
.47631 .71004 Mdot
.39425 .34579 Mdot
.47756 .66259 Mdot
.59145 .38555 Mdot
.66609 .48404 Mdot
.47736 .63105 Mdot
.27291 .47636 Mdot
.72472 .27816 Mdot
.36446 .5267 Mdot
.64713 .68877 Mdot
.60786 .67357 Mdot
.29644 .4066 Mdot
.55526 .61525 Mdot
.39283 .67951 Mdot
.6707 .24617 Mdot
.65659 .55538 Mdot
.44942 .62311 Mdot
.28741 .57102 Mdot
.48019 .63279 Mdot
.59458 .2183 Mdot
.46416 .62341 Mdot
.24086 .51119 Mdot
.42368 .37323 Mdot
.66948 .5118 Mdot
.54359 .62352 Mdot
.4726 .62324 Mdot
.50136 .76689 Mdot
.56634 .59641 Mdot
.51305 .6265 Mdot
.69606 .50502 Mdot
.6049 .35279 Mdot
.58013 .60307 Mdot
.36435 .44682 Mdot
.44205 .39457 Mdot
.54063 .66707 Mdot
.41506 .41758 Mdot
.63554 .50044 Mdot
.47322 .63052 Mdot
.59765 .35807 Mdot
.53199 .67172 Mdot
.74683 .47046 Mdot
.64827 .51246 Mdot
.4864 .61397 Mdot
.3467 .52661 Mdot
.45261 .80887 Mdot
.66943 .50251 Mdot
.33226 .39581 Mdot
.54393 .59705 Mdot
.50483 .63263 Mdot
.65445 .5145 Mdot
.40529 .4291 Mdot
.61473 .22261 Mdot
.68716 .54787 Mdot
.57837 .33034 Mdot
.69903 .48734 Mdot
.44794 .67221 Mdot
.42288 .38224 Mdot
.37895 .28583 Mdot
.66448 .4339 Mdot
.34547 .61524 Mdot
.48299 .63716 Mdot
.68871 .36398 Mdot
.43287 .372 Mdot
.66603 .52322 Mdot
.56687 .35713 Mdot
.48798 .56897 Mdot
.63389 .53028 Mdot
.57252 .38655 Mdot
.34474 .53877 Mdot
.49077 .30487 Mdot
.62931 .5194 Mdot
.40629 .48635 Mdot
.58067 .40159 Mdot
.60859 .35263 Mdot
.18506 .47301 Mdot
.65306 .52717 Mdot
.33014 .53316 Mdot
.56165 .35532 Mdot
.31633 .61236 Mdot
.49649 .69027 Mdot
.37643 .69655 Mdot
.70381 .74923 Mdot
.20793 .40053 Mdot
.51088 .31471 Mdot
.30531 .52101 Mdot
.55379 .33779 Mdot
.52135 .61385 Mdot
.69355 .52178 Mdot
.67566 .54294 Mdot
.50044 .68377 Mdot
.54197 .61196 Mdot
.47095 .65494 Mdot
.46862 .62694 Mdot
.7223 .56754 Mdot
.56375 .60373 Mdot
.6341 .77934 Mdot
.67335 .50895 Mdot
.53286 .6197 Mdot
.38267 .41415 Mdot
.516 .57759 Mdot
.59051 .38082 Mdot
.5166 .64067 Mdot
.54097 .62266 Mdot
.50246 .68697 Mdot
.60624 .35268 Mdot
.50039 .15733 Mdot
.51745 .78646 Mdot
.44586 .18382 Mdot
.25577 .51331 Mdot
.40443 .41408 Mdot
.48788 .63005 Mdot
.33859 .53739 Mdot
.69999 .67582 Mdot
.54487 .64119 Mdot
.66592 .82383 Mdot
.51915 .63054 Mdot
.4651 .1896 Mdot
.55318 .69045 Mdot
.35316 .21886 Mdot
.37901 .67131 Mdot
.50962 .61141 Mdot
.56724 .50009 Mdot
.60081 .43675 Mdot
.35176 .40217 Mdot
.58494 .37434 Mdot
.38094 .41121 Mdot
.38901 .37608 Mdot
.63422 .39762 Mdot
.60299 .56868 Mdot
.58502 .65694 Mdot
.47533 .59653 Mdot
.39538 .34299 Mdot
.62877 .50254 Mdot
.31782 .55334 Mdot
.70548 .51108 Mdot
.68531 .19999 Mdot
.50284 .24 Mdot
.58055 .4099 Mdot
.28805 .53655 Mdot
.41415 .35893 Mdot
.43666 .40327 Mdot
.33506 .51143 Mdot
.49659 .66188 Mdot
.65291 .53315 Mdot
.19353 .3949 Mdot
.77255 .47018 Mdot
.17151 .47247 Mdot
.69302 .50205 Mdot
.72635 .37078 Mdot
.56871 .37947 Mdot
.3905 .39917 Mdot
.50682 .63043 Mdot
.49582 .65576 Mdot
.63023 .56686 Mdot
.47205 .65456 Mdot
.4943 .54904 Mdot
.50417 .62235 Mdot
.43967 .28569 Mdot
.36207 .51255 Mdot
.63359 .39928 Mdot
.36064 .59703 Mdot
.67586 .54909 Mdot
.33566 .72688 Mdot
.42248 .41524 Mdot
.69067 .6754 Mdot
.59688 .38743 Mdot
.33429 .54666 Mdot
.43235 .40076 Mdot
.33583 .55183 Mdot
.56943 .6182 Mdot
.37279 .39467 Mdot
.33288 .5067 Mdot
.58782 .67997 Mdot
.46218 .6619 Mdot
.76698 .5109 Mdot
.58467 .33469 Mdot
.70019 .53944 Mdot
.48213 .67583 Mdot
.40203 .41838 Mdot
.51347 .56694 Mdot
.57345 .28524 Mdot
.39552 .29006 Mdot
.44256 .40604 Mdot
.38671 .30623 Mdot
.31193 .54808 Mdot
.55892 .26501 Mdot
.71412 .37606 Mdot
.67527 .48858 Mdot
.5636 .5962 Mdot
.33245 .22303 Mdot
.56206 .35475 Mdot
.52482 .67295 Mdot
.27052 .32947 Mdot
.57295 .34629 Mdot
.50956 .64667 Mdot
.55282 .35295 Mdot
.67339 .54401 Mdot
.45957 .79205 Mdot
.67223 .49124 Mdot
.46834 .61311 Mdot
.59706 .35339 Mdot
.38022 .42172 Mdot
.68905 .52497 Mdot
.49835 .66729 Mdot
.49134 .61901 Mdot
.53903 .45064 Mdot
.52582 .62148 Mdot
.49617 .1664 Mdot
.50593 .61657 Mdot
.38158 .39207 Mdot
.54982 .6603 Mdot
.38606 .82428 Mdot
.6442 .34048 Mdot
.65045 .5287 Mdot
.40517 .43157 Mdot
.40192 .36829 Mdot
.3498 .44841 Mdot
.59277 .4218 Mdot
.55656 .60375 Mdot
.40519 .41575 Mdot
.37965 .73962 Mdot
.58392 .39842 Mdot
.5605 .58709 Mdot
.42014 .49147 Mdot
.25656 .4043 Mdot
.41978 .34494 Mdot
.56896 .58223 Mdot
.62903 .51565 Mdot
.54465 .62087 Mdot
.43054 .41585 Mdot
.67109 .57398 Mdot
.51647 .59735 Mdot
.60874 .55294 Mdot
.54011 .44921 Mdot
.59738 .39821 Mdot
.56095 .68523 Mdot
.51409 .67627 Mdot
.38732 .41133 Mdot
.68376 .5446 Mdot
.57961 .39801 Mdot
.67846 .53608 Mdot
.31063 .26173 Mdot
.74317 .4791 Mdot
.60783 .6331 Mdot
.28213 .53211 Mdot
.24841 .38838 Mdot
.32443 .23823 Mdot
.28577 .71218 Mdot
.31478 .69361 Mdot
.23678 .32543 Mdot
.40266 .4271 Mdot
.27106 .33979 Mdot
.39586 .37204 Mdot
.53531 .60393 Mdot
.41951 .38004 Mdot
.31898 .2374 Mdot
.50606 .62287 Mdot
.41412 .38275 Mdot
.36767 .75334 Mdot
.5392 .61761 Mdot
.6593 .49909 Mdot
.58521 .17956 Mdot
.32541 .76727 Mdot
.4048 .28969 Mdot
.38602 .36172 Mdot
.28378 .649 Mdot
.51435 .62449 Mdot
.55547 .65115 Mdot
.68555 .5046 Mdot
.55326 .57879 Mdot
.30021 .53889 Mdot
.28794 .533 Mdot
.54541 .40691 Mdot
.41474 .69326 Mdot
.56075 .68157 Mdot
.68933 .51945 Mdot
.73827 .56155 Mdot
.25528 .47864 Mdot
.26916 .37393 Mdot
.55077 .37263 Mdot
.57852 .18005 Mdot
.46294 .56491 Mdot
.59714 .31283 Mdot
.34984 .37146 Mdot
.66158 .50481 Mdot
.48097 .16012 Mdot
.58476 .36968 Mdot
.79141 .58239 Mdot
.4259 .54302 Mdot
.50007 .66135 Mdot
.601 .38876 Mdot
.57852 .56465 Mdot
.30405 .75333 Mdot
.81297 .5656 Mdot
.40749 .61808 Mdot
.46458 .61587 Mdot
.28414 .47808 Mdot
.51218 .63699 Mdot
.63818 .25275 Mdot
.50229 .61537 Mdot
.68098 .53061 Mdot
.67255 .30146 Mdot
.5596 .43161 Mdot
.54966 .79582 Mdot
.58443 .26322 Mdot
.30454 .52178 Mdot
.50221 .6269 Mdot
.50218 .66259 Mdot
.30135 .53558 Mdot
.62717 .54507 Mdot
.46645 .63006 Mdot
.31974 .71333 Mdot
.47501 .64145 Mdot
.59115 .37248 Mdot
.41866 .58406 Mdot
.65252 .46509 Mdot
.48892 .5933 Mdot
.65354 .48416 Mdot
.60218 .39867 Mdot
.59125 .35126 Mdot
.55048 .68834 Mdot
.60076 .33811 Mdot
.52706 .63162 Mdot
.82262 .55829 Mdot
.63424 .51222 Mdot
.55633 .53344 Mdot
.64414 .5432 Mdot
.63731 .69388 Mdot
.58564 .34218 Mdot
.45644 .27442 Mdot
.49367 .56259 Mdot
.58152 .36834 Mdot
.7422 .48883 Mdot
.49267 .69688 Mdot
.45426 .64667 Mdot
.21156 .52421 Mdot
.38681 .36529 Mdot
.55924 .45165 Mdot
.55503 .35678 Mdot
.50364 .67331 Mdot
.52583 .58924 Mdot
.60536 .39698 Mdot
.80172 .51893 Mdot
.35544 .76711 Mdot
.50543 .6194 Mdot
.67895 .52284 Mdot
.66665 .52648 Mdot
.45725 .62687 Mdot
.55259 .64537 Mdot
.4267 .39344 Mdot
.37869 .42388 Mdot
.37309 .37839 Mdot
.54248 .44797 Mdot
.44685 .27713 Mdot
.46191 .22085 Mdot
.59965 .33923 Mdot
.71617 .40299 Mdot
.24238 .51991 Mdot
.49239 .58696 Mdot
.41115 .3501 Mdot
.52277 .67017 Mdot
.53625 .63133 Mdot
.60223 .40439 Mdot
.33663 .28735 Mdot
.55865 .55499 Mdot
.62476 .54716 Mdot
.56434 .38644 Mdot
.4389 .66178 Mdot
.63643 .30737 Mdot
.34332 .53451 Mdot
.20077 .46966 Mdot
.59545 .38519 Mdot
.65843 .50155 Mdot
.57103 .33667 Mdot
.48871 .65302 Mdot
.5685 .65036 Mdot
.65956 .51241 Mdot
.30005 .51318 Mdot
.51782 .56796 Mdot
.50732 .64442 Mdot
.66773 .78804 Mdot
.23525 .54586 Mdot
.44699 .29307 Mdot
.50935 .61325 Mdot
.49668 .59333 Mdot
.35245 .51875 Mdot
.47776 .64619 Mdot
.46984 .66001 Mdot
.47898 .79902 Mdot
.68677 .4336 Mdot
.28801 .52183 Mdot
.81578 .5353 Mdot
.69078 .49792 Mdot
.38154 .19649 Mdot
.38966 .40572 Mdot
.54423 .37685 Mdot
.38517 .78719 Mdot
.4199 .34299 Mdot
.51267 .31938 Mdot
.40923 .18506 Mdot
.55896 .44941 Mdot
.43577 .33468 Mdot
.47517 .56411 Mdot
.46793 .63261 Mdot
.50482 .63654 Mdot
.33124 .54157 Mdot
.65585 .53624 Mdot
.55175 .45944 Mdot
.80319 .3943 Mdot
.52265 .63857 Mdot
.51573 .53768 Mdot
.77749 .40065 Mdot
.25774 .40798 Mdot
.32076 .51903 Mdot
.29188 .52187 Mdot
.50116 .62981 Mdot
.46605 .81173 Mdot
.68954 .53038 Mdot
.4998 .66792 Mdot
.5568 .59761 Mdot
.38289 .36839 Mdot
.64311 .51176 Mdot
.41313 .42696 Mdot
.48459 .26353 Mdot
.44911 .18742 Mdot
.69767 .77675 Mdot
.58785 .34527 Mdot
.69459 .28222 Mdot
.55893 .37441 Mdot
.39064 .66758 Mdot
.44338 .38805 Mdot
.55155 .62872 Mdot
.67829 .54729 Mdot
.50987 .67335 Mdot
.55469 .63855 Mdot
.49885 .66293 Mdot
.50741 .58759 Mdot
.56791 .85644 Mdot
.31944 .50639 Mdot
.45529 .67737 Mdot
.38225 .38419 Mdot
.63055 .23248 Mdot
.71918 .27909 Mdot
.50736 .66225 Mdot
.49489 .6219 Mdot
.62945 .52708 Mdot
.50759 .68258 Mdot
.56941 .38709 Mdot
.69987 .53371 Mdot
.47524 .62041 Mdot
.59871 .19524 Mdot
.48403 .609 Mdot
.38895 .20297 Mdot
.56287 .34073 Mdot
.75844 .47568 Mdot
.46534 .69101 Mdot
.40428 .29407 Mdot
.5592 .45172 Mdot
.43113 .39629 Mdot
.58988 .32809 Mdot
.40182 .38426 Mdot
.82095 .42751 Mdot
.5589 .66713 Mdot
.52282 .61184 Mdot
.53407 .58497 Mdot
.40234 .41501 Mdot
.5679 .21145 Mdot
.55161 .25636 Mdot
.44022 .65554 Mdot
.40921 .40867 Mdot
.64397 .48748 Mdot
.28175 .59324 Mdot
.65227 .54573 Mdot
.29053 .54823 Mdot
.58074 .38563 Mdot
.29518 .5226 Mdot
.26245 .3282 Mdot
.65068 .5114 Mdot
.69356 .55085 Mdot
.39494 .4036 Mdot
.43551 .51873 Mdot
.15701 .61318 Mdot
.42955 .53669 Mdot
.36235 .64381 Mdot
.68505 .50841 Mdot
.48335 .60192 Mdot
.39349 .62039 Mdot
.46535 .50772 Mdot
.40301 .38192 Mdot
.54045 .64143 Mdot
.44699 .79286 Mdot
.42687 .39366 Mdot
.56229 .59064 Mdot
.38344 .37463 Mdot
.58299 .38037 Mdot
.41428 .35394 Mdot
.63828 .5605 Mdot
.48133 .62426 Mdot
.14086 .55559 Mdot
.36884 .5202 Mdot
.51444 .62015 Mdot
.56106 .38315 Mdot
.52166 .36992 Mdot
.54303 .65496 Mdot
.34983 .53573 Mdot
.41776 .39185 Mdot
.41591 .54218 Mdot
.50406 .61776 Mdot
.40142 .41337 Mdot
.69461 .48761 Mdot
.56937 .32744 Mdot
.56184 .73041 Mdot
.41643 .29882 Mdot
.68638 .50395 Mdot
.39181 .47312 Mdot
.61276 .34683 Mdot
.49734 .59272 Mdot
.56041 .59416 Mdot
.67514 .52517 Mdot
.44832 .75696 Mdot
.53405 .67918 Mdot
.55505 .61622 Mdot
.37888 .39333 Mdot
.40639 .38581 Mdot
.44932 .77268 Mdot
.39009 .42775 Mdot
.56689 .65319 Mdot
.6753 .5274 Mdot
.54484 .62604 Mdot
.63524 .51522 Mdot
.51287 .68123 Mdot
.71077 .54892 Mdot
.6293 .54706 Mdot
.6375 .32724 Mdot
.54028 .63619 Mdot
.58988 .62932 Mdot
.53197 .66979 Mdot
.47064 .64455 Mdot
.42838 .38844 Mdot
.33325 .5191 Mdot
.57606 .61228 Mdot
.34715 .55394 Mdot
.33456 .55175 Mdot
.59638 .43309 Mdot
.38557 .36491 Mdot
.32054 .53655 Mdot
.78501 .40487 Mdot
.37471 .37709 Mdot
.31648 .54449 Mdot
.71426 .27632 Mdot
.57754 .3395 Mdot
.63252 .51102 Mdot
.53983 .61621 Mdot
.26756 .30678 Mdot
.70555 .73463 Mdot
.35623 .40063 Mdot
.5082 .61723 Mdot
.53038 .66746 Mdot
.67542 .55336 Mdot
.84329 .44575 Mdot
.3914 .34821 Mdot
.50325 .60034 Mdot
.64632 .5243 Mdot
.86044 .50151 Mdot
.38498 .38802 Mdot
.32119 .54461 Mdot
.59578 .3394 Mdot
.61109 .54773 Mdot
.6635 .43492 Mdot
.60243 .39381 Mdot
.37391 .34457 Mdot
.45649 .266 Mdot
.54448 .59678 Mdot
.41766 .35206 Mdot
.18801 .50274 Mdot
.74981 .53036 Mdot
.61666 .4363 Mdot
.27571 .63803 Mdot
.6641 .50473 Mdot
.56437 .38065 Mdot
.30925 .51363 Mdot
.69518 .50738 Mdot
.65914 .49683 Mdot
.60976 .3999 Mdot
.55372 .75938 Mdot
.41955 .49374 Mdot
.59452 .36717 Mdot
.22424 .51409 Mdot
.38274 .25804 Mdot
.41054 .34936 Mdot
.30119 .53936 Mdot
.2765 .31231 Mdot
.67119 .54092 Mdot
.57045 .17557 Mdot
.19604 .49507 Mdot
.51327 .62655 Mdot
.32313 .53256 Mdot
.53616 .21021 Mdot
.81062 .37899 Mdot
.57652 .34582 Mdot
.54707 .42479 Mdot
.2962 .53861 Mdot
.48621 .67807 Mdot
.29473 .60431 Mdot
.55239 .61516 Mdot
.57448 .38332 Mdot
.61602 .64373 Mdot
.65607 .50134 Mdot
.61568 .39706 Mdot
.19926 .46975 Mdot
.52737 .63348 Mdot
.54177 .637 Mdot
.37178 .58428 Mdot
.6954 .53309 Mdot
.43095 .39699 Mdot
.55075 .59739 Mdot
.51101 .64282 Mdot
.57724 .64081 Mdot
.56923 .67697 Mdot
.44852 .80399 Mdot
.51921 .60235 Mdot
.55054 .24552 Mdot
.46758 .60544 Mdot
.53454 .64275 Mdot
.64959 .48631 Mdot
.68585 .7922 Mdot
.49527 .25744 Mdot
.51444 .64088 Mdot
.48987 .59996 Mdot
.61897 .38742 Mdot
.4398 .4966 Mdot
.43127 .51675 Mdot
.41326 .54027 Mdot
.30094 .67368 Mdot
.45922 .61061 Mdot
.64714 .53401 Mdot
.33842 .50955 Mdot
.51783 .59584 Mdot
.64558 .53118 Mdot
.50432 .68964 Mdot
.42592 .39593 Mdot
.37304 .38225 Mdot
.74064 .51307 Mdot
.31363 .53623 Mdot
.45846 .54449 Mdot
.7058 .40303 Mdot
.37832 .40733 Mdot
.52438 .61019 Mdot
.57489 .41005 Mdot
.43193 .41361 Mdot
.36863 .31487 Mdot
.54039 .72955 Mdot
.69219 .53133 Mdot
.67083 .50902 Mdot
.37925 .7025 Mdot
.50896 .30203 Mdot
.58148 .81181 Mdot
.58258 .38162 Mdot
.55136 .66722 Mdot
.70094 .36104 Mdot
.67067 .5057 Mdot
.38944 .63629 Mdot
.31923 .5346 Mdot
.57221 .3454 Mdot
.47185 .38419 Mdot
.63127 .5306 Mdot
.66016 .49319 Mdot
.46181 .63204 Mdot
.50508 .65135 Mdot
.32347 .70287 Mdot
.26767 .51905 Mdot
.59809 .39937 Mdot
.30249 .54156 Mdot
.44083 .38242 Mdot
.51437 .60071 Mdot
.65117 .55084 Mdot
.37461 .27166 Mdot
.50632 .59763 Mdot
.43087 .38432 Mdot
.66484 .50883 Mdot
.30738 .54732 Mdot
.35011 .54112 Mdot
.47149 .64263 Mdot
.70326 .58626 Mdot
.58737 .36068 Mdot
.66249 .49953 Mdot
.63657 .311 Mdot
.55525 .64928 Mdot
.49827 .64641 Mdot
.52218 .71577 Mdot
.59295 .40244 Mdot
.75769 .41939 Mdot
.29695 .54914 Mdot
.65749 .53175 Mdot
.50606 .60733 Mdot
.30959 .54163 Mdot
.73815 .39416 Mdot
.44376 .40368 Mdot
.41399 .35523 Mdot
.35143 .5348 Mdot
.32126 .52488 Mdot
.3469 .54079 Mdot
.57125 .17501 Mdot
.65283 .55759 Mdot
.46391 .56527 Mdot
.54232 .6744 Mdot
.37239 .66427 Mdot
.46739 .58092 Mdot
.57911 .39955 Mdot
.38939 .36372 Mdot
.54525 .65567 Mdot
.47361 .60735 Mdot
.51386 .70784 Mdot
.54861 .53791 Mdot
.67375 .46113 Mdot
.6467 .51149 Mdot
.54176 .6834 Mdot
.37772 .37888 Mdot
.6996 .20481 Mdot
.21405 .32464 Mdot
.47551 .69895 Mdot
.40847 .50365 Mdot
.6513 .55175 Mdot
.6154 .36147 Mdot
.37237 .56612 Mdot
.58077 .33773 Mdot
.65946 .52806 Mdot
.51825 .60167 Mdot
.71628 .40984 Mdot
.35344 .52774 Mdot
.491 .66988 Mdot
.56284 .37155 Mdot
.48144 .66662 Mdot
.60369 .39235 Mdot
.32138 .24998 Mdot
.22371 .58769 Mdot
.51799 .6302 Mdot
.45069 .65991 Mdot
.27243 .64856 Mdot
.51062 .66416 Mdot
.27574 .50392 Mdot
.64964 .55187 Mdot
.48881 .77046 Mdot
.46697 .67575 Mdot
.73851 .60187 Mdot
.56068 .63763 Mdot
.40996 .77403 Mdot
.49744 .64887 Mdot
.25253 .42394 Mdot
.48441 .61704 Mdot
.4671 .65035 Mdot
.59348 .34769 Mdot
.61714 .39255 Mdot
.66789 .48267 Mdot
.40722 .41677 Mdot
.41837 .18964 Mdot
.50375 .64486 Mdot
.3916 .28799 Mdot
.72692 .4349 Mdot
.31999 .52326 Mdot
.66073 .53193 Mdot
.84826 .42983 Mdot
.55652 .34287 Mdot
.23764 .56292 Mdot
.4144 .76481 Mdot
.64494 .41117 Mdot
.29641 .57563 Mdot
.66558 .28998 Mdot
.31665 .54917 Mdot
.50605 .68696 Mdot
.35579 .28031 Mdot
.24472 .44745 Mdot
.54307 .72884 Mdot
.61679 .35351 Mdot
.70871 .65605 Mdot
.34814 .27768 Mdot
.31666 .55749 Mdot
.29182 .53198 Mdot
.61305 .36869 Mdot
.46609 .39535 Mdot
.57298 .56049 Mdot
.31751 .5319 Mdot
.37859 .41465 Mdot
.38671 .35588 Mdot
.41971 .34004 Mdot
.68485 .53698 Mdot
.19017 .43804 Mdot
.63732 .30013 Mdot
.59952 .39558 Mdot
.45782 .39493 Mdot
.69592 .47218 Mdot
.65809 .56084 Mdot
.39598 .39593 Mdot
.42984 .37647 Mdot
.6223 .54184 Mdot
.56562 .671 Mdot
.51782 .70367 Mdot
.51887 .63886 Mdot
.34026 .53122 Mdot
.49953 .65336 Mdot
.41535 .40296 Mdot
.57649 .34853 Mdot
.42264 .36707 Mdot
.55082 .36497 Mdot
.48365 .22133 Mdot
.48802 .66253 Mdot
.48332 .62166 Mdot
.73518 .71233 Mdot
.68502 .48423 Mdot
.5339 .23647 Mdot
.4315 .3045 Mdot
.39293 .37328 Mdot
.47203 .66364 Mdot
.69922 .53584 Mdot
.31395 .55985 Mdot
.75523 .69517 Mdot
.54741 .65686 Mdot
.64785 .54902 Mdot
.50641 .60419 Mdot
.70648 .57487 Mdot
.44175 .83605 Mdot
.67357 .53553 Mdot
.70289 .74877 Mdot
.48542 .60367 Mdot
.72759 .32601 Mdot
.54205 .58318 Mdot
.38252 .73061 Mdot
.53452 .67868 Mdot
.69209 .49957 Mdot
.51847 .64278 Mdot
.70271 .52762 Mdot
.38197 .40794 Mdot
.61158 .35449 Mdot
.68048 .5026 Mdot
.55539 .59063 Mdot
.10835 .41698 Mdot
.57257 .37837 Mdot
.50437 .6291 Mdot
.59642 .34322 Mdot
.65313 .53914 Mdot
.67803 .49495 Mdot
.78982 .35696 Mdot
.49258 .26356 Mdot
.58251 .37913 Mdot
.5116 .60173 Mdot
.63178 .27598 Mdot
.54924 .61908 Mdot
.3432 .70236 Mdot
.57625 .65495 Mdot
.54674 .66599 Mdot
.73085 .28502 Mdot
.59306 .40086 Mdot
.56202 .81681 Mdot
.78249 .33947 Mdot
.6366 .23315 Mdot
.6158 .56713 Mdot
.3159 .55819 Mdot
.48993 .15861 Mdot
.453 .27625 Mdot
.40549 .41165 Mdot
.53882 .66352 Mdot
.66204 .46618 Mdot
.5906 .35728 Mdot
.33462 .51753 Mdot
.51684 .63019 Mdot
.42769 .37062 Mdot
.31502 .73927 Mdot
.54988 .34429 Mdot
.66694 .54085 Mdot
.62957 .55114 Mdot
.83327 .59853 Mdot
.50783 .61079 Mdot
.47891 .62279 Mdot
.57848 .3854 Mdot
.7666 .39857 Mdot
.32309 .55086 Mdot
.35193 .74688 Mdot
.58108 .37836 Mdot
.51173 .46715 Mdot
.65011 .52235 Mdot
.52812 .6688 Mdot
.53782 .19524 Mdot
.29332 .47075 Mdot
.77632 .61989 Mdot
.33844 .53686 Mdot
.33789 .69469 Mdot
.69091 .49724 Mdot
.56434 .35685 Mdot
.48744 .32277 Mdot
.47176 .59205 Mdot
.52474 .66729 Mdot
.34126 .6926 Mdot
.57439 .43453 Mdot
.40867 .60925 Mdot
.55153 .65149 Mdot
.5758 .45019 Mdot
.53375 .67566 Mdot
.46409 .59356 Mdot
.56807 .65943 Mdot
.48845 .64091 Mdot
.64918 .55026 Mdot
.47153 .71484 Mdot
.42204 .40444 Mdot
.44445 .56992 Mdot
.51828 .47338 Mdot
.51027 .62034 Mdot
.54739 .60518 Mdot
.74439 .66162 Mdot
.52095 .33261 Mdot
.67755 .50423 Mdot
.65725 .56741 Mdot
.5914 .33272 Mdot
.51604 .7054 Mdot
.41525 .41442 Mdot
.4721 .58078 Mdot
.42866 .38496 Mdot
.656 .54998 Mdot
.38899 .37864 Mdot
.60279 .34463 Mdot
.39746 .3506 Mdot
.4458 .27706 Mdot
.55991 .35394 Mdot
.69449 .52049 Mdot
.47652 .63296 Mdot
.5604 .38206 Mdot
.34361 .60546 Mdot
.33955 .53286 Mdot
.77977 .3222 Mdot
.47556 .61856 Mdot
.68281 .43607 Mdot
.61456 .57953 Mdot
.42603 .37154 Mdot
.46734 .82864 Mdot
.62786 .54887 Mdot
.29429 .51423 Mdot
.67273 .55073 Mdot
.2229 .53559 Mdot
.3311 .52339 Mdot
.70354 .26205 Mdot
.42495 .31548 Mdot
.2527 .56238 Mdot
.5471 .68785 Mdot
.32514 .59024 Mdot
.42485 .3506 Mdot
.58996 .35573 Mdot
.49845 .32568 Mdot
.47034 .65917 Mdot
.25176 .66529 Mdot
.62805 .50949 Mdot
.40968 .41487 Mdot
.56942 .35677 Mdot
.57629 .39647 Mdot
.56325 .62006 Mdot
.29553 .36919 Mdot
.50871 .67741 Mdot
.50609 .28924 Mdot
.30865 .67652 Mdot
.57197 .55106 Mdot
.5042 .62296 Mdot
.38601 .41083 Mdot
.50672 .60409 Mdot
.28586 .51631 Mdot
.18179 .44678 Mdot
.53304 .57139 Mdot
.43722 .30292 Mdot
.37053 .52771 Mdot
.6563 .51166 Mdot
.58577 .58116 Mdot
.45749 .28295 Mdot
.50997 .60824 Mdot
.46483 .88076 Mdot
.31335 .54345 Mdot
.34926 .28861 Mdot
.51813 .58841 Mdot
.56094 .60808 Mdot
.57724 .48364 Mdot
.64074 .44267 Mdot
.29596 .4728 Mdot
.5186 .66219 Mdot
.31049 .64292 Mdot
.6098 .37714 Mdot
.51865 .67792 Mdot
.50376 .63461 Mdot
.59225 .75366 Mdot
.56625 .3865 Mdot
.39904 .36584 Mdot
.42768 .35072 Mdot
.36617 .4186 Mdot
.29011 .51197 Mdot
.53493 .42773 Mdot
.38123 .64063 Mdot
.30848 .74828 Mdot
.31799 .5004 Mdot
.4706 .62061 Mdot
.34216 .48494 Mdot
.53198 .60163 Mdot
.31675 .51415 Mdot
.56143 .38008 Mdot
.67629 .50119 Mdot
.71252 .35877 Mdot
.39855 .34398 Mdot
.55844 .58487 Mdot
.3086 .5508 Mdot
.69351 .5244 Mdot
.26061 .55578 Mdot
.65465 .51931 Mdot
.57839 .37136 Mdot
.54569 .34125 Mdot
.32924 .51424 Mdot
.6472 .54147 Mdot
.61507 .3304 Mdot
.81213 .39116 Mdot
.57173 .64812 Mdot
.53588 .35378 Mdot
.69691 .4942 Mdot
.63887 .56832 Mdot
.70093 .51032 Mdot
.47454 .65725 Mdot
.40874 .50256 Mdot
.49469 .69293 Mdot
.59692 .39889 Mdot
.38674 .37079 Mdot
.27619 .6687 Mdot
.443 .24523 Mdot
.36897 .47731 Mdot
.54953 .67148 Mdot
.52842 .63547 Mdot
.50143 .63 Mdot
.46099 .66807 Mdot
.48627 .29415 Mdot
.51335 .67339 Mdot
.5958 .34908 Mdot
.4194 .39378 Mdot
.50479 .68722 Mdot
.44237 .37096 Mdot
.62001 .23662 Mdot
.318 .50146 Mdot
.53217 .41712 Mdot
.23122 .27122 Mdot
.69219 .51509 Mdot
.41216 .42936 Mdot
.40174 .41171 Mdot
.34406 .53981 Mdot
.59073 .36479 Mdot
.65304 .52357 Mdot
.36488 .72888 Mdot
.34148 .54752 Mdot
.51568 .64279 Mdot
.3981 .52577 Mdot
.23363 .63128 Mdot
.51069 .68582 Mdot
.54876 .64119 Mdot
.44681 .39719 Mdot
.33089 .31872 Mdot
.15691 .53942 Mdot
.38647 .60022 Mdot
.3313 .51663 Mdot
.312 .5073 Mdot
.62458 .52758 Mdot
.48663 .69439 Mdot
.59829 .39854 Mdot
.41402 .60643 Mdot
.50698 .37596 Mdot
.43955 .55362 Mdot
.62492 .47885 Mdot
.5419 .66367 Mdot
.80478 .49977 Mdot
.52938 .63174 Mdot
.65884 .55669 Mdot
.66651 .54659 Mdot
.68513 .51777 Mdot
.58854 .35619 Mdot
.65797 .69317 Mdot
.59977 .35621 Mdot
.21913 .28394 Mdot
.68484 .49211 Mdot
.45551 .32819 Mdot
.38628 .40287 Mdot
.46902 .69548 Mdot
.30677 .54576 Mdot
.58001 .31796 Mdot
.47552 .70975 Mdot
.46966 .81639 Mdot
.414 .41117 Mdot
.69419 .51536 Mdot
.67573 .29543 Mdot
.26949 .26577 Mdot
.42187 .5263 Mdot
.43612 .65601 Mdot
.3567 .57896 Mdot
.31618 .52208 Mdot
.77559 .62439 Mdot
.29973 .54098 Mdot
.56022 .36796 Mdot
.48639 .62308 Mdot
.48078 .6335 Mdot
.53055 .67861 Mdot
.49876 .66588 Mdot
.61211 .34991 Mdot
.56812 .59954 Mdot
.38596 .82421 Mdot
.37115 .39315 Mdot
.59349 .66996 Mdot
.31175 .54554 Mdot
.6033 .33313 Mdot
.41907 .39544 Mdot
.51769 .3346 Mdot
.36381 .60027 Mdot
.50431 .61908 Mdot
.54264 .65957 Mdot
.23589 .56647 Mdot
.55247 .65027 Mdot
.46403 .58188 Mdot
.40278 .41297 Mdot
.37692 .49748 Mdot
.30502 .50793 Mdot
.30518 .51215 Mdot
.56202 .34679 Mdot
.65605 .54932 Mdot
.32334 .5408 Mdot
.38126 .39953 Mdot
.55136 .66984 Mdot
.54784 .5927 Mdot
.69599 .49402 Mdot
.19396 .5054 Mdot
.30546 .55269 Mdot
.65425 .27931 Mdot
.68207 .54451 Mdot
.71865 .50948 Mdot
.52595 .66638 Mdot
.60124 .52552 Mdot
.61064 .54371 Mdot
.31346 .49912 Mdot
.60135 .3321 Mdot
.37652 .5664 Mdot
.57441 .3873 Mdot
.66155 .54337 Mdot
.51878 .59686 Mdot
.67672 .54402 Mdot
.50774 .61345 Mdot
.3305 .20018 Mdot
.48421 .64061 Mdot
.30908 .75304 Mdot
.37014 .69933 Mdot
.40607 .39854 Mdot
.52761 .34015 Mdot
.39126 .40546 Mdot
.68719 .54185 Mdot
.53371 .59527 Mdot
.29148 .54034 Mdot
.66556 .2516 Mdot
.69242 .46911 Mdot
.43313 .38426 Mdot
.36854 .37906 Mdot
.55775 .37046 Mdot
.52607 .6856 Mdot
.5214 .66938 Mdot
.41234 .38343 Mdot
.56697 .54923 Mdot
.63352 .53549 Mdot
.49375 .62 Mdot
.53106 .64028 Mdot
.40333 .39919 Mdot
.81667 .40422 Mdot
.72796 .4871 Mdot
.48703 .62938 Mdot
.36559 .29662 Mdot
.58321 .40153 Mdot
.53085 .69471 Mdot
.4484 .65371 Mdot
.32057 .52712 Mdot
.58271 .71697 Mdot
.19601 .41408 Mdot
.55355 .36881 Mdot
.39163 .41461 Mdot
.50622 .60941 Mdot
.38692 .41152 Mdot
.55512 .5942 Mdot
.62843 .4538 Mdot
.43705 .3793 Mdot
.55735 .61842 Mdot
.56959 .67088 Mdot
.69528 .53391 Mdot
.54276 .66121 Mdot
.71521 .70156 Mdot
.43079 .41066 Mdot
.56129 .61389 Mdot
.69192 .59145 Mdot
.59646 .37381 Mdot
.5395 .69444 Mdot
.34118 .51535 Mdot
.36641 .73186 Mdot
.67966 .40579 Mdot
.32601 .2921 Mdot
.3198 .50318 Mdot
.48595 .67015 Mdot
.36421 .39748 Mdot
.61067 .38202 Mdot
.3361 .772 Mdot
.49534 .68139 Mdot
.57305 .3818 Mdot
.57459 .34937 Mdot
.34305 .53372 Mdot
.72405 .74906 Mdot
.50764 .58821 Mdot
.50646 .66097 Mdot
.63662 .74659 Mdot
.6971 .48787 Mdot
.49053 .64905 Mdot
.47453 .61015 Mdot
.59737 .34919 Mdot
.454 .59047 Mdot
.73081 .64782 Mdot
.37749 .75986 Mdot
.58989 .40532 Mdot
.4761 .51673 Mdot
.41131 .34611 Mdot
.30639 .53748 Mdot
.66136 .51565 Mdot
.30461 .54931 Mdot
.40038 .35218 Mdot
.47333 .61622 Mdot
.57614 .33328 Mdot
.6774 .74292 Mdot
.6133 .36867 Mdot
.30726 .30072 Mdot
.69893 .49164 Mdot
.68399 .35008 Mdot
.51013 .87955 Mdot
.61113 .26519 Mdot
.56395 .30707 Mdot
.32042 .52345 Mdot
.40156 .46053 Mdot
.53102 .63825 Mdot
.76842 .64809 Mdot
.47209 .63656 Mdot
.6727 .5999 Mdot
.37503 .40683 Mdot
.37281 .37887 Mdot
.48699 .62565 Mdot
.31674 .68419 Mdot
.61182 .38113 Mdot
.58653 .39942 Mdot
.5608 .62178 Mdot
.58171 .36893 Mdot
.50855 .65361 Mdot
.42375 .39484 Mdot
.56 .82627 Mdot
.51639 .63492 Mdot
.45212 .64555 Mdot
.63914 .43603 Mdot
.7516 .30541 Mdot
.25172 .37031 Mdot
.83555 .51712 Mdot
.24639 .28881 Mdot
.58091 .36763 Mdot
.51035 .69709 Mdot
.47582 .51783 Mdot
.43447 .35636 Mdot
.5975 .31522 Mdot
.47922 .6445 Mdot
.47691 .64645 Mdot
.46597 .64682 Mdot
.54364 .63449 Mdot
.78385 .61372 Mdot
.42945 .66512 Mdot
.6373 .65073 Mdot
.55282 .64304 Mdot
.32796 .59428 Mdot
.55878 .34809 Mdot
.62198 .56143 Mdot
.33607 .49929 Mdot
.54139 .66413 Mdot
.43654 .59223 Mdot
.61772 .39657 Mdot
.21669 .28583 Mdot
.55677 .3601 Mdot
.40215 .36875 Mdot
.61559 .36602 Mdot
.52435 .62074 Mdot
.66718 .52621 Mdot
.49522 .49591 Mdot
.55293 .26468 Mdot
.40665 .41135 Mdot
.51402 .62002 Mdot
.45066 .32146 Mdot
.41884 .40657 Mdot
.61487 .23206 Mdot
.66648 .51948 Mdot
.31502 .64109 Mdot
.67058 .54633 Mdot
.55817 .61449 Mdot
.55661 .61069 Mdot
.54307 .33505 Mdot
.6106 .35471 Mdot
.66787 .54717 Mdot
.72655 .75382 Mdot
.33338 .55322 Mdot
.68582 .52257 Mdot
.49231 .57654 Mdot
.465 .46251 Mdot
.67207 .52314 Mdot
.37161 .55182 Mdot
.58349 .34644 Mdot
.65647 .48975 Mdot
.48529 .58404 Mdot
.21288 .48653 Mdot
.34225 .51178 Mdot
.4448 .41196 Mdot
.38812 .54203 Mdot
.42994 .41426 Mdot
.59374 .32911 Mdot
.39347 .4056 Mdot
.6096 .37457 Mdot
.69881 .4229 Mdot
.45683 .55755 Mdot
.55829 .39706 Mdot
.59911 .33313 Mdot
.39548 .40305 Mdot
.49049 .61722 Mdot
.36819 .5643 Mdot
.51878 .69699 Mdot
.50197 .58702 Mdot
.60447 .38277 Mdot
.69427 .50649 Mdot
.63295 .56361 Mdot
.30189 .60213 Mdot
.63293 .54667 Mdot
.42983 .38244 Mdot
.40949 .82358 Mdot
.38931 .2835 Mdot
.59035 .38988 Mdot
.61742 .36848 Mdot
.5506 .6144 Mdot
.40201 .38357 Mdot
.38621 .41682 Mdot
.56094 .37401 Mdot
.54869 .52803 Mdot
.45982 .67467 Mdot
.65162 .56522 Mdot
.67398 .48656 Mdot
.67531 .53177 Mdot
.70229 .51283 Mdot
.756 .6049 Mdot
.57548 .34274 Mdot
.6972 .51513 Mdot
.55734 .62338 Mdot
.47844 .64645 Mdot
.43738 .52689 Mdot
.31122 .50916 Mdot
.49674 .6868 Mdot
.56502 .66458 Mdot
.5305 .66586 Mdot
.41732 .35603 Mdot
.52904 .72695 Mdot
.43782 .38229 Mdot
.36723 .40464 Mdot
.37237 .41151 Mdot
.45032 .27691 Mdot
.25262 .59191 Mdot
.25508 .30149 Mdot
.50179 .60053 Mdot
.77811 .42397 Mdot
.3911 .38856 Mdot
.46685 .82188 Mdot
.7584 .41718 Mdot
.48121 .67277 Mdot
.27644 .46966 Mdot
.41067 .38628 Mdot
.63145 .54976 Mdot
.48072 .64316 Mdot
.37426 .42649 Mdot
.34344 .51673 Mdot
.56523 .63962 Mdot
.44228 .38854 Mdot
.64778 .53981 Mdot
.32256 .49646 Mdot
.67046 .48494 Mdot
.37287 .41045 Mdot
.55691 .68451 Mdot
.18659 .68581 Mdot
.36623 .38056 Mdot
.77489 .37164 Mdot
.71062 .55561 Mdot
.49224 .61902 Mdot
.42181 .42402 Mdot
.70648 .49153 Mdot
.58056 .32715 Mdot
.49859 .3944 Mdot
.64562 .50046 Mdot
.37386 .37627 Mdot
.43935 .39708 Mdot
.40424 .41275 Mdot
.64926 .50722 Mdot
.45557 .63063 Mdot
.63949 .51107 Mdot
.616 .36884 Mdot
.54391 .61821 Mdot
.32652 .2363 Mdot
.77825 .43409 Mdot
.67502 .54667 Mdot
.40199 .36216 Mdot
.35294 .52145 Mdot
.52328 .62917 Mdot
.78739 .44355 Mdot
.49465 .61235 Mdot
.60275 .38958 Mdot
.48663 .79287 Mdot
.70822 .72153 Mdot
.54145 .67434 Mdot
.55067 .61557 Mdot
.59 .39875 Mdot
.51273 .62516 Mdot
.53232 .68085 Mdot
.46293 .27444 Mdot
.6417 .51585 Mdot
.52187 .64224 Mdot
.38017 .38328 Mdot
.44014 .26466 Mdot
.46038 .67268 Mdot
.33444 .41126 Mdot
.31966 .65818 Mdot
.5026 .78785 Mdot
.47184 .63436 Mdot
.4015 .58077 Mdot
.53997 .64402 Mdot
.49093 .66814 Mdot
.53736 .60521 Mdot
.79757 .60882 Mdot
.43419 .37332 Mdot
.40682 .40654 Mdot
.33223 .50359 Mdot
.31757 .65461 Mdot
.32217 .53075 Mdot
.5841 .34506 Mdot
.30582 .38847 Mdot
.43732 .38123 Mdot
.65129 .54437 Mdot
.49587 .67341 Mdot
.36496 .38413 Mdot
.52461 .67067 Mdot
.52375 .61909 Mdot
.41511 .41765 Mdot
.42206 .35151 Mdot
.3423 .2888 Mdot
.3297 .50487 Mdot
.68315 .51186 Mdot
.50897 .69235 Mdot
.31447 .55239 Mdot
.4797 .59991 Mdot
.3745 .66575 Mdot
.68239 .51546 Mdot
.64045 .51427 Mdot
.63038 .55989 Mdot
.4742 .61544 Mdot
.52216 .62383 Mdot
.60149 .35859 Mdot
.66828 .55076 Mdot
.59462 .37484 Mdot
.53598 .45578 Mdot
.34511 .45398 Mdot
.47912 .64457 Mdot
.66687 .29627 Mdot
.30632 .52962 Mdot
.41916 .36845 Mdot
.24173 .63226 Mdot
.33434 .50437 Mdot
.50498 .61414 Mdot
.3917 .4201 Mdot
.3152 .51261 Mdot
.55178 .72851 Mdot
.1843 .37732 Mdot
.34974 .51286 Mdot
.55774 .62452 Mdot
.43483 .62444 Mdot
.83486 .52973 Mdot
.33085 .50152 Mdot
.59147 .33755 Mdot
.47448 .61594 Mdot
.62452 .49903 Mdot
.30037 .54804 Mdot
.55635 .24621 Mdot
.41635 .39066 Mdot
.20339 .4474 Mdot
.48836 .72163 Mdot
.72757 .71203 Mdot
.30023 .52496 Mdot
.65507 .52663 Mdot
.66997 .57402 Mdot
.53126 .6602 Mdot
.33319 .50248 Mdot
.60295 .40752 Mdot
.42204 .38335 Mdot
.4906 .25915 Mdot
.64998 .50562 Mdot
.66446 .31652 Mdot
.40261 .35886 Mdot
.64838 .27695 Mdot
.43525 .78302 Mdot
.52381 .70065 Mdot
.82778 .53345 Mdot
.48832 .35876 Mdot
.46113 .6399 Mdot
.35481 .53884 Mdot
.555 .37372 Mdot
.58124 .33217 Mdot
.57762 .37471 Mdot
.71799 .4302 Mdot
.41323 .53823 Mdot
.41099 .43042 Mdot
.60827 .29999 Mdot
.30817 .53773 Mdot
.37149 .57819 Mdot
.54621 .5876 Mdot
.52634 .63573 Mdot
.52995 .68514 Mdot
.53408 .67321 Mdot
.53365 .65035 Mdot
.58845 .36998 Mdot
.68564 .42586 Mdot
.42299 .53734 Mdot
.67795 .51978 Mdot
.31634 .34259 Mdot
.38651 .40063 Mdot
.41023 .43138 Mdot
.3231 .50897 Mdot
.63956 .25608 Mdot
.44279 .37317 Mdot
.39002 .3759 Mdot
.46369 .65933 Mdot
.63205 .52857 Mdot
.44445 .61711 Mdot
.55423 .61923 Mdot
.42708 .38056 Mdot
.56274 .4795 Mdot
.73752 .65676 Mdot
.534 .72896 Mdot
.36134 .55234 Mdot
.42209 .50329 Mdot
.34808 .51509 Mdot
.52932 .59416 Mdot
.47549 .82397 Mdot
.40259 .35129 Mdot
.4036 .37458 Mdot
.30273 .52402 Mdot
.63551 .47295 Mdot
.66226 .50741 Mdot
.5642 .30339 Mdot
.60238 .34949 Mdot
.54339 .59911 Mdot
.30973 .72985 Mdot
.60264 .59044 Mdot
.29017 .37928 Mdot
.57817 .37927 Mdot
.38346 .40824 Mdot
.54477 .67501 Mdot
.55645 .62732 Mdot
.30559 .52569 Mdot
.41221 .21986 Mdot
.55879 .66627 Mdot
.62284 .21377 Mdot
.22306 .58683 Mdot
.20154 .50062 Mdot
.52442 .66734 Mdot
.64353 .51346 Mdot
.44374 .38635 Mdot
.30106 .5385 Mdot
.50972 .57464 Mdot
.20877 .34489 Mdot
.68894 .48999 Mdot
.56101 .36143 Mdot
.51728 .4849 Mdot
.38245 .56036 Mdot
.46763 .62776 Mdot
.47331 .63543 Mdot
.48023 .6598 Mdot
.1631 .43131 Mdot
.42689 .36505 Mdot
.65532 .55207 Mdot
.34187 .52566 Mdot
.63834 .54722 Mdot
.40282 .40458 Mdot
.67047 .33242 Mdot
.48842 .61512 Mdot
.68905 .48903 Mdot
.65601 .52478 Mdot
.55707 .36443 Mdot
.57082 .32757 Mdot
.53077 .47211 Mdot
.48618 .64193 Mdot
.37494 .36388 Mdot
.69798 .52384 Mdot
.39995 .52863 Mdot
.32989 .52403 Mdot
.58914 .34539 Mdot
.54909 .65023 Mdot
.42156 .35569 Mdot
.5666 .59216 Mdot
.67276 .50729 Mdot
.38991 .37683 Mdot
.36463 .28515 Mdot
.31254 .50434 Mdot
.48944 .65648 Mdot
.28298 .50809 Mdot
.39186 .41543 Mdot
.53303 .63804 Mdot
.69343 .28913 Mdot
.37096 .53484 Mdot
.54153 .25705 Mdot
.37754 .41722 Mdot
.40018 .29142 Mdot
.62665 .52528 Mdot
.74592 .44775 Mdot
.40443 .37163 Mdot
.66627 .28578 Mdot
.4111 .23568 Mdot
.53954 .68268 Mdot
.67403 .53916 Mdot
.4952 .37039 Mdot
.37576 .19466 Mdot
.81233 .42014 Mdot
.50411 .63039 Mdot
.38962 .42798 Mdot
.30768 .5208 Mdot
.59304 .39043 Mdot
.33671 .42219 Mdot
.37034 .54088 Mdot
.38777 .35128 Mdot
.53607 .60467 Mdot
.65239 .53442 Mdot
.58401 .35057 Mdot
.68446 .4103 Mdot
.37949 .39446 Mdot
.39112 .36521 Mdot
.5441 .675 Mdot
.31816 .53508 Mdot
.78643 .46488 Mdot
.42108 .39889 Mdot
.23236 .58067 Mdot
.39608 .33698 Mdot
.32366 .55413 Mdot
.54434 .64353 Mdot
.29365 .59875 Mdot
.47736 .68627 Mdot
.74106 .31684 Mdot
.39096 .40126 Mdot
.67706 .51027 Mdot
.47018 .65252 Mdot
.39492 .76139 Mdot
.42497 .377 Mdot
.41119 .50501 Mdot
.24986 .41591 Mdot
.57964 .34385 Mdot
.24221 .63494 Mdot
.49711 .65478 Mdot
.6118 .38026 Mdot
.30766 .52843 Mdot
.48656 .63481 Mdot
.52532 .62373 Mdot
.68245 .54987 Mdot
.56158 .37278 Mdot
.37218 .25274 Mdot
.61717 .3946 Mdot
.56826 .3373 Mdot
.68305 .55343 Mdot
.51893 .65361 Mdot
.40119 .36784 Mdot
.40987 .38481 Mdot
.51886 .58046 Mdot
.5109 .84176 Mdot
.66131 .50484 Mdot
.43388 .42921 Mdot
.16252 .45242 Mdot
.58733 .63491 Mdot
.25535 .65442 Mdot
.42766 .21368 Mdot
.58444 .40502 Mdot
.55931 .62843 Mdot
.65051 .54027 Mdot
.45147 .44333 Mdot
.39412 .36422 Mdot
.46612 .61162 Mdot
.58106 .35274 Mdot
.34252 .51409 Mdot
.4286 .40723 Mdot
.29551 .37243 Mdot
.49199 .66498 Mdot
.26883 .4729 Mdot
.40623 .42777 Mdot
.51475 .15202 Mdot
.51126 .34219 Mdot
.67898 .5361 Mdot
.52715 .61859 Mdot
.62481 .54662 Mdot
.33937 .52014 Mdot
.51735 .48317 Mdot
.57907 .34995 Mdot
.44388 .7007 Mdot
.3453 .8134 Mdot
.40137 .41418 Mdot
.65092 .55255 Mdot
.54379 .6717 Mdot
.61431 .47412 Mdot
.50388 .65644 Mdot
.47142 .5698 Mdot
.36745 .4962 Mdot
.60161 .38227 Mdot
.6117 .37311 Mdot
.53767 .63144 Mdot
.33589 .54907 Mdot
.38296 .4002 Mdot
.42198 .37865 Mdot
.64893 .19162 Mdot
.63265 .41485 Mdot
.33047 .70866 Mdot
.47924 .64961 Mdot
.37517 .36891 Mdot
.44465 .24987 Mdot
.5789 .38516 Mdot
.54789 .5837 Mdot
.41504 .41401 Mdot
.22555 .49035 Mdot
.39976 .74899 Mdot
.53595 .65188 Mdot
.45339 .6233 Mdot
.59915 .34498 Mdot
.40595 .5624 Mdot
.37293 .39536 Mdot
.58109 .64272 Mdot
.54559 .37433 Mdot
.45931 .76603 Mdot
.18308 .49111 Mdot
.68348 .512 Mdot
.28482 .35898 Mdot
.58903 .36946 Mdot
.45237 .62106 Mdot
.32214 .54795 Mdot
.43892 .37047 Mdot
.4278 .36373 Mdot
.51781 .60433 Mdot
.56791 .61607 Mdot
.25915 .63689 Mdot
.63639 .54299 Mdot
.56038 .34651 Mdot
.47794 .62532 Mdot
.71217 .34736 Mdot
.53309 .67689 Mdot
.6017 .36369 Mdot
.18054 .68593 Mdot
.52533 .69258 Mdot
.50677 .65889 Mdot
.79031 .45513 Mdot
.65093 .49784 Mdot
.6489 .55394 Mdot
.26111 .69176 Mdot
.47992 .65029 Mdot
.23458 .61078 Mdot
.68243 .50721 Mdot
.6651 .50527 Mdot
.48706 .27112 Mdot
.52294 .63168 Mdot
.45079 .71887 Mdot
.60203 .39286 Mdot
.57463 .33583 Mdot
.64456 .50613 Mdot
.5394 .68731 Mdot
.55103 .35606 Mdot
.79597 .55585 Mdot
.4007 .38489 Mdot
.49083 .82476 Mdot
.6645 .49838 Mdot
.55977 .43633 Mdot
.57961 .38314 Mdot
.22248 .28123 Mdot
.38804 .33188 Mdot
.48804 .61825 Mdot
.486 .65699 Mdot
.30527 .53277 Mdot
.51926 .69254 Mdot
.37166 .3823 Mdot
.58202 .36955 Mdot
.63305 .6052 Mdot
.68562 .51818 Mdot
.49595 .64725 Mdot
.63103 .24882 Mdot
.5469 .23216 Mdot
.28396 .34384 Mdot
.65655 .51268 Mdot
.68293 .53735 Mdot
.37543 .38594 Mdot
.39207 .42781 Mdot
.52489 .65798 Mdot
.58417 .39648 Mdot
.66958 .55009 Mdot
.60456 .37101 Mdot
.40323 .35151 Mdot
.39692 .36884 Mdot
.43234 .36643 Mdot
.57298 .59946 Mdot
.38478 .37951 Mdot
.32742 .36182 Mdot
.65815 .31148 Mdot
.66111 .56098 Mdot
.19779 .58243 Mdot
.69271 .41118 Mdot
.73534 .48362 Mdot
.29545 .54647 Mdot
.39242 .41633 Mdot
.61742 .38155 Mdot
.54637 .62622 Mdot
.53423 .66712 Mdot
.36099 .32007 Mdot
.61234 .38939 Mdot
.33606 .51792 Mdot
.61375 .37586 Mdot
.34317 .5339 Mdot
.24814 .45926 Mdot
.51893 .68753 Mdot
.55063 .59438 Mdot
.58612 .37365 Mdot
.38665 .37921 Mdot
.41366 .39894 Mdot
.34371 .50635 Mdot
.6094 .44576 Mdot
.41861 .40733 Mdot
.6687 .4998 Mdot
.763 .58553 Mdot
.43991 .39682 Mdot
.48395 .6457 Mdot
.38361 .64525 Mdot
.75289 .68168 Mdot
.46066 .66742 Mdot
.47794 .27166 Mdot
.66177 .76561 Mdot
.47868 .66737 Mdot
.72012 .73453 Mdot
.4192 .30038 Mdot
.62727 .52747 Mdot
.37441 .40396 Mdot
.44913 .39559 Mdot
.57366 .58553 Mdot
.35735 .51322 Mdot
.51184 .5772 Mdot
.66599 .49471 Mdot
.63419 .49775 Mdot
.21497 .51667 Mdot
.77058 .35765 Mdot
.31037 .51783 Mdot
.31392 .5109 Mdot
.40794 .37127 Mdot
.80382 .34235 Mdot
.45936 .69813 Mdot
.33245 .51624 Mdot
.46961 .54835 Mdot
.53141 .60388 Mdot
.35265 .69283 Mdot
.26006 .50857 Mdot
.64556 .50864 Mdot
.30969 .59302 Mdot
.41099 .36729 Mdot
.63005 .54469 Mdot
.71994 .36655 Mdot
.48371 .68186 Mdot
.68303 .51693 Mdot
.6047 .36647 Mdot
.52234 .31077 Mdot
.67935 .49612 Mdot
.38014 .65539 Mdot
.56467 .38 Mdot
.40243 .52245 Mdot
.30525 .61665 Mdot
.73897 .79049 Mdot
.58588 .36773 Mdot
.43745 .38934 Mdot
.41091 .38445 Mdot
.42069 .37714 Mdot
.63417 .54438 Mdot
.38678 .41652 Mdot
.64123 .54547 Mdot
.82253 .47576 Mdot
.62578 .47907 Mdot
.32934 .51546 Mdot
.49895 .25963 Mdot
.6606 .53775 Mdot
.44303 .83099 Mdot
.44756 .86396 Mdot
.55982 .62868 Mdot
.61978 .3742 Mdot
.32117 .51472 Mdot
.63752 .21414 Mdot
.31677 .52658 Mdot
.25641 .5734 Mdot
.49075 .80173 Mdot
.50477 .64892 Mdot
.69025 .68283 Mdot
.29287 .52466 Mdot
.65036 .52041 Mdot
.53226 .63637 Mdot
.48447 .40063 Mdot
.31526 .52989 Mdot
.34732 .52865 Mdot
.5256 .64988 Mdot
.69436 .51588 Mdot
.40709 .36406 Mdot
.60439 .34388 Mdot
.28565 .52715 Mdot
.69834 .55614 Mdot
.46432 .66899 Mdot
.49908 .60716 Mdot
.44047 .51724 Mdot
.27476 .53787 Mdot
.58085 .36669 Mdot
.77615 .66631 Mdot
.38138 .42091 Mdot
.48487 .38553 Mdot
.22737 .56843 Mdot
.45763 .28074 Mdot
.39296 .39961 Mdot
.39086 .41138 Mdot
.53182 .65398 Mdot
.28041 .54868 Mdot
.50355 .79783 Mdot
.62782 .35365 Mdot
.44368 .38857 Mdot
.4233 .38201 Mdot
.61961 .5248 Mdot
.21535 .52569 Mdot
.50898 .5734 Mdot
.55246 .36621 Mdot
.42661 .36068 Mdot
.64498 .45101 Mdot
.31526 .53728 Mdot
.44515 .81776 Mdot
.51477 .68782 Mdot
.48445 .62119 Mdot
.57203 .35971 Mdot
.59835 .35426 Mdot
.44487 .44979 Mdot
.22819 .54586 Mdot
.67764 .75335 Mdot
.66364 .41138 Mdot
.56567 .74548 Mdot
.62504 .5125 Mdot
.67602 .54628 Mdot
.57698 .2607 Mdot
.61771 .3949 Mdot
.47426 .66142 Mdot
.65924 .54913 Mdot
.46923 .35362 Mdot
.75573 .51919 Mdot
.338 .69936 Mdot
.26862 .66296 Mdot
.50912 .61493 Mdot
.63736 .52562 Mdot
.65229 .49785 Mdot
.70943 .51723 Mdot
.4319 .30756 Mdot
.51809 .66233 Mdot
.50581 .62212 Mdot
.49729 .6776 Mdot
.58142 .52934 Mdot
.50572 .67085 Mdot
.73738 .44645 Mdot
.50387 .47289 Mdot
.59569 .69501 Mdot
.57815 .64669 Mdot
.56629 .39571 Mdot
.46892 .62535 Mdot
.33849 .54739 Mdot
.54415 .60571 Mdot
.34237 .70519 Mdot
.56664 .37411 Mdot
.73162 .4896 Mdot
.69971 .41939 Mdot
.4638 .64883 Mdot
.30606 .50166 Mdot
.51718 .37763 Mdot
.31339 .25056 Mdot
.30248 .49442 Mdot
.66761 .49955 Mdot
.39678 .39014 Mdot
.6165 .38517 Mdot
.39687 .3723 Mdot
.57324 .60657 Mdot
.58491 .26625 Mdot
.55073 .21548 Mdot
.54886 .45544 Mdot
.53591 .67048 Mdot
.51412 .72281 Mdot
.66924 .50364 Mdot
.39307 .42092 Mdot
.62016 .49918 Mdot
.47214 .65318 Mdot
.34043 .53307 Mdot
.3102 .53109 Mdot
.49409 .38368 Mdot
.48492 .1773 Mdot
.75178 .48342 Mdot
.57413 .36133 Mdot
.42541 .39539 Mdot
.2998 .54223 Mdot
.73769 .34211 Mdot
.57176 .32665 Mdot
.5917 .3993 Mdot
.5592 .36305 Mdot
.48332 .60339 Mdot
.43768 .37993 Mdot
.59941 .68777 Mdot
.37665 .36815 Mdot
.51455 .62302 Mdot
.42026 .35936 Mdot
.41323 .4132 Mdot
.30863 .54408 Mdot
.55806 .35325 Mdot
.38871 .35958 Mdot
.5585 .61265 Mdot
.68877 .50976 Mdot
.56315 .42634 Mdot
.38701 .72454 Mdot
.75851 .34361 Mdot
.65312 .59239 Mdot
.67182 .48824 Mdot
.3724 .20159 Mdot
.5855 .40276 Mdot
.55963 .52751 Mdot
.33536 .29999 Mdot
.51118 .59624 Mdot
.46911 .84878 Mdot
.41519 .42995 Mdot
.4206 .41303 Mdot
.544 .64186 Mdot
.46731 .38917 Mdot
.50012 .65029 Mdot
.40186 .35504 Mdot
.35351 .31654 Mdot
.5881 .56345 Mdot
.38479 .3874 Mdot
.5829 .63513 Mdot
.53044 .62732 Mdot
.64282 .51074 Mdot
.42317 .42274 Mdot
.54783 .58246 Mdot
.62403 .18411 Mdot
.59735 .35672 Mdot
.45508 .31862 Mdot
.39153 .65958 Mdot
.59021 .36959 Mdot
.68414 .52516 Mdot
.51268 .58565 Mdot
.30675 .52663 Mdot
.6583 .5388 Mdot
.40784 .75732 Mdot
.30046 .51413 Mdot
.44923 .83894 Mdot
.65198 .50011 Mdot
.4371 .4025 Mdot
.32672 .54852 Mdot
.50425 .69577 Mdot
.43901 .37148 Mdot
.52535 .33549 Mdot
.3915 .39868 Mdot
.51997 .66963 Mdot
.49995 .24981 Mdot
.56339 .34222 Mdot
.50157 .63184 Mdot
.42284 .41437 Mdot
.46325 .27219 Mdot
.48698 .60226 Mdot
.53948 .63754 Mdot
.19471 .51086 Mdot
.38336 .79811 Mdot
.32372 .52367 Mdot
.71219 .5059 Mdot
.55732 .62302 Mdot
.34471 .52162 Mdot
.29274 .44418 Mdot
.47894 .61384 Mdot
.69287 .49161 Mdot
.5732 .67649 Mdot
.41497 .42581 Mdot
.59524 .36824 Mdot
.54761 .44968 Mdot
.34322 .5166 Mdot
.85535 .58926 Mdot
.3952 .35053 Mdot
.53469 .59149 Mdot
.54318 .66338 Mdot
.2367 .38538 Mdot
.62714 .52967 Mdot
.59434 .7896 Mdot
.4892 .65655 Mdot
.57491 .53163 Mdot
.48977 .63689 Mdot
.43025 .42837 Mdot
.66284 .50629 Mdot
.50826 .66271 Mdot
.6656 .30375 Mdot
.45403 .65713 Mdot
.32855 .50338 Mdot
.79525 .45592 Mdot
.46064 .6582 Mdot
.27261 .77691 Mdot
.25305 .52376 Mdot
.38341 .38817 Mdot
.54169 .24142 Mdot
.74552 .23919 Mdot
.71819 .42682 Mdot
.64559 .5483 Mdot
.46921 .20561 Mdot
.4005 .36771 Mdot
.49441 .23715 Mdot
.36586 .2019 Mdot
.53437 .62439 Mdot
.46746 .62803 Mdot
.25405 .55071 Mdot
.36972 .40693 Mdot
.39196 .34472 Mdot
.56856 .64738 Mdot
.45701 .60603 Mdot
.39156 .36959 Mdot
.56085 .60867 Mdot
.57373 .62246 Mdot
.61008 .34916 Mdot
.67844 .49048 Mdot
.59926 .38843 Mdot
.55845 .37488 Mdot
.79598 .52265 Mdot
.24217 .51128 Mdot
.5999 .36307 Mdot
.5675 .39206 Mdot
.35511 .69735 Mdot
.27631 .63766 Mdot
.29922 .54728 Mdot
.53103 .16718 Mdot
.42004 .38014 Mdot
.51666 .65885 Mdot
.66284 .49132 Mdot
.69065 .73984 Mdot
.32851 .42869 Mdot
.51625 .80891 Mdot
.47321 .65778 Mdot
.42022 .3719 Mdot
.43221 .30742 Mdot
.4511 .59981 Mdot
.35897 .40678 Mdot
.4761 .62503 Mdot
.39615 .345 Mdot
.72768 .61873 Mdot
.66007 .28385 Mdot
.39384 .34025 Mdot
.65632 .56467 Mdot
.48142 .62675 Mdot
.66224 .49764 Mdot
.58421 .38439 Mdot
.31679 .55057 Mdot
.32693 .52555 Mdot
.5305 .64219 Mdot
.54242 .69612 Mdot
.25442 .46792 Mdot
.52432 .62852 Mdot
.5365 .60677 Mdot
.41859 .30004 Mdot
.54156 .60824 Mdot
.52611 .67655 Mdot
.51096 .67841 Mdot
.46969 .60441 Mdot
.57174 .33642 Mdot
.63522 .25524 Mdot
.51442 .56443 Mdot
.49736 .56641 Mdot
.56722 .33085 Mdot
.38808 .23603 Mdot
.56946 .38948 Mdot
.31837 .23798 Mdot
.60587 .38614 Mdot
.3332 .52303 Mdot
.27573 .32051 Mdot
.50528 .71329 Mdot
.69985 .51735 Mdot
.58686 .32362 Mdot
.34338 .52693 Mdot
.57974 .37279 Mdot
.40785 .35707 Mdot
.17487 .4496 Mdot
.7223 .51218 Mdot
.41476 .59371 Mdot
.59856 .32209 Mdot
.58858 .27533 Mdot
.38428 .36223 Mdot
.65726 .50296 Mdot
.72712 .66797 Mdot
.53054 .67664 Mdot
.34587 .52585 Mdot
.52693 .65435 Mdot
.5567 .34832 Mdot
.41421 .36971 Mdot
.80611 .42621 Mdot
.30563 .52616 Mdot
.19996 .56826 Mdot
.414 .39398 Mdot
.51039 .68132 Mdot
.55217 .36308 Mdot
.21596 .63799 Mdot
.60153 .38536 Mdot
.56082 .77918 Mdot
.62136 .53513 Mdot
.84022 .50775 Mdot
.66619 .53948 Mdot
.53516 .31714 Mdot
.15309 .55824 Mdot
.65034 .25118 Mdot
.69311 .51475 Mdot
.64016 .34524 Mdot
.50687 .61075 Mdot
.49746 .608 Mdot
.74951 .35047 Mdot
.71152 .50516 Mdot
.55594 .63885 Mdot
.38276 .28686 Mdot
.65466 .32287 Mdot
.28212 .69567 Mdot
.38776 .40755 Mdot
.49622 .65185 Mdot
.54311 .35662 Mdot
.6102 .38707 Mdot
.38711 .35489 Mdot
.58751 .40144 Mdot
.50681 .62381 Mdot
.66184 .53792 Mdot
.39938 .45462 Mdot
.33117 .53495 Mdot
.70541 .25759 Mdot
.344 .54875 Mdot
.39352 .39968 Mdot
.51458 .69864 Mdot
.3959 .36945 Mdot
.75523 .2311 Mdot
.50049 .62168 Mdot
.68077 .50704 Mdot
.55187 .61919 Mdot
.48442 .6275 Mdot
.46548 .63114 Mdot
.40147 .36126 Mdot
.47451 .74828 Mdot
.55973 .61104 Mdot
.57911 .34901 Mdot
.58966 .71298 Mdot
.46235 .65944 Mdot
.4551 .39898 Mdot
.30223 .65879 Mdot
.60253 .3043 Mdot
.64681 .49605 Mdot
.38585 .39385 Mdot
.68823 .51848 Mdot
.60436 .55119 Mdot
.68391 .52502 Mdot
.60922 .72734 Mdot
.73114 .65441 Mdot
.49374 .76604 Mdot
.68661 .59245 Mdot
.54431 .4991 Mdot
.71194 .50577 Mdot
.26832 .51193 Mdot
.68466 .5436 Mdot
.64649 .50088 Mdot
.08275 .57073 Mdot
.70124 .5242 Mdot
.48486 .64947 Mdot
.47836 .67575 Mdot
.61771 .27412 Mdot
.3537 .65125 Mdot
.5464 .61974 Mdot
.55279 .62864 Mdot
.30993 .54719 Mdot
.56742 .54131 Mdot
.55927 .25247 Mdot
.37707 .80434 Mdot
.51725 .22589 Mdot
.52689 .6514 Mdot
.55702 .62081 Mdot
.4504 .60952 Mdot
.24001 .70888 Mdot
.80986 .54647 Mdot
.67224 .47685 Mdot
.44633 .64287 Mdot
.70559 .27804 Mdot
.46673 .63524 Mdot
.47384 .61148 Mdot
.50789 .61355 Mdot
.40139 .3675 Mdot
.67376 .48253 Mdot
.48499 .58787 Mdot
.24115 .5331 Mdot
.47294 .62377 Mdot
.46106 .27819 Mdot
.83986 .42655 Mdot
.49721 .65536 Mdot
.66297 .48384 Mdot
.50548 .60405 Mdot
.63183 .52009 Mdot
.64562 .52121 Mdot
.47346 .69613 Mdot
.57123 .74103 Mdot
.63886 .49546 Mdot
.51527 .62274 Mdot
.41401 .36304 Mdot
.5044 .1579 Mdot
.51831 .67022 Mdot
.31009 .55063 Mdot
.48516 .65569 Mdot
.30096 .50447 Mdot
.53747 .60964 Mdot
.39609 .34945 Mdot
.7282 .70566 Mdot
.40591 .37397 Mdot
.82818 .54826 Mdot
.42549 .3559 Mdot
.1947 .52014 Mdot
.69194 .48678 Mdot
.49753 .25532 Mdot
.62952 .8002 Mdot
.45344 .30329 Mdot
.39791 .49403 Mdot
.47394 .47875 Mdot
.58468 .39695 Mdot
.62406 .54117 Mdot
.50421 .52756 Mdot
.3383 .30771 Mdot
.30437 .32211 Mdot
.42426 .40398 Mdot
.71796 .75816 Mdot
.53539 .8231 Mdot
.54942 .59827 Mdot
.66951 .69992 Mdot
.64801 .65823 Mdot
.46612 .62717 Mdot
.48618 .5895 Mdot
.37854 .3155 Mdot
.56394 .6211 Mdot
.70765 .33933 Mdot
.39685 .4006 Mdot
.34416 .52785 Mdot
.6747 .5029 Mdot
.34422 .51584 Mdot
.33387 .30841 Mdot
.46756 .48144 Mdot
.40502 .35338 Mdot
.45402 .62903 Mdot
.54973 .62807 Mdot
.63566 .51761 Mdot
.67037 .4668 Mdot
.69343 .53565 Mdot
.31371 .51777 Mdot
.40218 .39736 Mdot
.7736 .64098 Mdot
.55166 .63646 Mdot
.65742 .52449 Mdot
.39255 .48338 Mdot
.55783 .62539 Mdot
.58734 .37909 Mdot
.5012 .61357 Mdot
.69037 .50733 Mdot
.54163 .60841 Mdot
.66495 .54098 Mdot
.39753 .38735 Mdot
.47906 .67266 Mdot
.54089 .64732 Mdot
.20808 .60894 Mdot
.33696 .52124 Mdot
.69949 .49256 Mdot
.42001 .31746 Mdot
.54562 .66407 Mdot
.50756 .27659 Mdot
.47585 .63063 Mdot
.7588 .51065 Mdot
.50838 .594 Mdot
.44506 .30251 Mdot
.51935 .56757 Mdot
.51643 .66938 Mdot
.42637 .46798 Mdot
.64298 .67779 Mdot
.69859 .4791 Mdot
.55189 .36922 Mdot
.70366 .51223 Mdot
.28882 .69774 Mdot
.39955 .33394 Mdot
.3964 .42353 Mdot
.36365 .5906 Mdot
.46872 .60427 Mdot
.50685 .6503 Mdot
.5462 .34069 Mdot
.31681 .50727 Mdot
.6554 .5143 Mdot
.34312 .53361 Mdot
.22508 .60799 Mdot
.30339 .51545 Mdot
.42185 .42878 Mdot
.27043 .47098 Mdot
.78331 .60745 Mdot
.30916 .54643 Mdot
.69466 .51496 Mdot
.34799 .46097 Mdot
.46416 .61511 Mdot
.2559 .52433 Mdot
.33666 .53783 Mdot
.77606 .70903 Mdot
.52605 .67595 Mdot
.39385 .49477 Mdot
.59963 .37098 Mdot
.31918 .54815 Mdot
.57426 .38817 Mdot
.54381 .62666 Mdot
.54475 .25538 Mdot
.65079 .54816 Mdot
.55599 .34158 Mdot
.54895 .68648 Mdot
.32238 .51379 Mdot
.43162 .36925 Mdot
.56001 .32355 Mdot
.55059 .36164 Mdot
.411 .21772 Mdot
.81133 .44874 Mdot
.40455 .39565 Mdot
.40752 .77849 Mdot
.60511 .38961 Mdot
.46206 .6336 Mdot
.54081 .53747 Mdot
.48727 .6182 Mdot
.74556 .46251 Mdot
.38542 .39922 Mdot
.62059 .26623 Mdot
.55327 .61703 Mdot
.48915 .67109 Mdot
.6994 .48237 Mdot
.4114 .37915 Mdot
.66924 .52651 Mdot
.70552 .51628 Mdot
.39925 .38659 Mdot
.67552 .53703 Mdot
.29636 .51737 Mdot
.66652 .35445 Mdot
.60624 .3538 Mdot
.57197 .34866 Mdot
.42308 .37987 Mdot
.38116 .38887 Mdot
.39122 .37484 Mdot
.50074 .61356 Mdot
.65848 .50937 Mdot
.52965 .61563 Mdot
.47081 .62348 Mdot
.55419 .7489 Mdot
.66119 .48887 Mdot
.51756 .61219 Mdot
.47738 .40743 Mdot
.30327 .56486 Mdot
.41635 .36278 Mdot
.5993 .36544 Mdot
.43311 .25645 Mdot
.52487 .35053 Mdot
.49268 .64931 Mdot
.22773 .48478 Mdot
.6955 .52541 Mdot
.30955 .52781 Mdot
.31171 .55801 Mdot
.319 .52515 Mdot
.62439 .40831 Mdot
.70927 .50278 Mdot
.38418 .80918 Mdot
.50048 .65233 Mdot
.43629 .5175 Mdot
.45486 .55401 Mdot
.24424 .47148 Mdot
.59813 .36154 Mdot
.55593 .62601 Mdot
.55912 .45119 Mdot
.73901 .66378 Mdot
.48868 .62018 Mdot
.4575 .64238 Mdot
.36439 .28848 Mdot
.57553 .6753 Mdot
.61938 .54273 Mdot
.22606 .64552 Mdot
.53114 .68597 Mdot
.64335 .45442 Mdot
.72732 .26626 Mdot
.4835 .64184 Mdot
.48078 .66236 Mdot
.54107 .65813 Mdot
.54212 .6038 Mdot
.64522 .4923 Mdot
.32934 .61849 Mdot
.58962 .40392 Mdot
.43066 .52618 Mdot
.58579 .33413 Mdot
.43154 .35813 Mdot
.63499 .26175 Mdot
.62355 .54263 Mdot
.30518 .53236 Mdot
.62503 .22839 Mdot
.29097 .73432 Mdot
.37312 .39694 Mdot
.79301 .54921 Mdot
.33915 .53134 Mdot
.46031 .63826 Mdot
.29424 .51632 Mdot
.4379 .38341 Mdot
.57748 .34496 Mdot
.46105 .6118 Mdot
.68443 .54234 Mdot
.67697 .49501 Mdot
.55822 .63329 Mdot
.68754 .26549 Mdot
.59096 .37839 Mdot
.55435 .33296 Mdot
.4816 .60799 Mdot
.50468 .69538 Mdot
.67242 .52692 Mdot
.42231 .39447 Mdot
.35664 .74085 Mdot
.32556 .50854 Mdot
.56487 .59309 Mdot
.53646 .60422 Mdot
.22511 .55992 Mdot
.58546 .34594 Mdot
.38198 .42714 Mdot
.50172 .59837 Mdot
.65408 .41354 Mdot
.50374 .59838 Mdot
.44342 .64091 Mdot
.41697 .365 Mdot
.53383 .56395 Mdot
.55525 .59795 Mdot
.47281 .56606 Mdot
.58868 .39426 Mdot
.68086 .51273 Mdot
.70623 .53899 Mdot
.45097 .52849 Mdot
.58551 .37891 Mdot
.51384 .60862 Mdot
.59214 .35706 Mdot
.47917 .61485 Mdot
.5617 .62491 Mdot
.60165 .36415 Mdot
.66936 .52738 Mdot
.46647 .2093 Mdot
.63181 .25264 Mdot
.54477 .60344 Mdot
.55079 .66972 Mdot
.33929 .63015 Mdot
.46892 .74706 Mdot
.46992 .64722 Mdot
.68637 .5022 Mdot
.54846 .63863 Mdot
.57235 .38398 Mdot
.29288 .52845 Mdot
.68953 .50951 Mdot
.40961 .40416 Mdot
.37422 .38442 Mdot
.70574 .42079 Mdot
.40093 .41772 Mdot
.47008 .60988 Mdot
.60589 .53794 Mdot
.71425 .52455 Mdot
.72571 .27791 Mdot
.40312 .38502 Mdot
.2911 .54178 Mdot
.53789 .63785 Mdot
.21245 .485 Mdot
.54162 .35026 Mdot
.32801 .8257 Mdot
.43345 .83285 Mdot
.35859 .51946 Mdot
.52207 .80157 Mdot
.41701 .34659 Mdot
.56153 .59759 Mdot
.32078 .55134 Mdot
.37523 .38953 Mdot
.51618 .59784 Mdot
.45166 .67367 Mdot
.58159 .79104 Mdot
.49323 .50452 Mdot
.59208 .35491 Mdot
.38327 .41699 Mdot
.36213 .53641 Mdot
.39774 .43335 Mdot
.66533 .49248 Mdot
.51448 .6666 Mdot
.50568 .70157 Mdot
.41617 .40082 Mdot
.37171 .41662 Mdot
.51422 .6178 Mdot
.62454 .54617 Mdot
.38201 .3164 Mdot
.52528 .64568 Mdot
.56068 .50228 Mdot
.64679 .57005 Mdot
.39648 .40536 Mdot
.49955 .67441 Mdot
.37102 .49317 Mdot
.41673 .39419 Mdot
.41744 .36253 Mdot
.56025 .62829 Mdot
.29849 .51476 Mdot
.5465 .67292 Mdot
.61053 .37441 Mdot
.77596 .67679 Mdot
.56714 .37907 Mdot
.3403 .42633 Mdot
.54466 .6918 Mdot
.63327 .42644 Mdot
.63787 .50431 Mdot
.2562 .56505 Mdot
.39348 .27485 Mdot
.57046 .64654 Mdot
.45315 .1814 Mdot
.54948 .43023 Mdot
.66933 .24583 Mdot
.25058 .32196 Mdot
.32357 .54329 Mdot
.57851 .37478 Mdot
.47968 .66118 Mdot
.61722 .36468 Mdot
.31781 .55216 Mdot
.82586 .54159 Mdot
.506 .67631 Mdot
.66476 .50635 Mdot
.50931 .61881 Mdot
.66532 .49877 Mdot
.55981 .62493 Mdot
.4635 .58654 Mdot
.3971 .28903 Mdot
.39958 .74816 Mdot
.49896 .59589 Mdot
.1713 .48703 Mdot
.31712 .47747 Mdot
.33916 .5167 Mdot
.52984 .62087 Mdot
.35717 .38878 Mdot
.60953 .39285 Mdot
.74788 .37154 Mdot
.40097 .36675 Mdot
.56291 .38369 Mdot
.67793 .53035 Mdot
.39001 .39556 Mdot
.37316 .38281 Mdot
.53802 .56507 Mdot
.31979 .50014 Mdot
.56189 .35169 Mdot
.50696 .66413 Mdot
.5078 .67549 Mdot
.37785 .76948 Mdot
.32107 .4074 Mdot
.68875 .46632 Mdot
.29692 .76388 Mdot
.68694 .55277 Mdot
.33279 .51459 Mdot
.40512 .36364 Mdot
.47174 .6391 Mdot
.50472 .6324 Mdot
.48462 .26256 Mdot
.66513 .55245 Mdot
.52538 .47959 Mdot
.77243 .54291 Mdot
.40723 .32035 Mdot
.32666 .67183 Mdot
.67848 .50125 Mdot
.32948 .67411 Mdot
.34176 .55525 Mdot
.57222 .18511 Mdot
.3755 .72804 Mdot
.59819 .36883 Mdot
.32695 .66862 Mdot
.65251 .52567 Mdot
.55413 .60405 Mdot
.43752 .40313 Mdot
.41124 .41396 Mdot
.67584 .51803 Mdot
.36801 .42524 Mdot
.30823 .54241 Mdot
.48976 .66598 Mdot
.37101 .79632 Mdot
.71301 .40319 Mdot
.42967 .38776 Mdot
.46046 .58728 Mdot
.55962 .36482 Mdot
.55841 .63493 Mdot
.30241 .54272 Mdot
.58697 .36322 Mdot
.23934 .5583 Mdot
.64296 .29975 Mdot
.53499 .63716 Mdot
.20289 .5251 Mdot
.58471 .3736 Mdot
.45125 .73725 Mdot
.52161 .65324 Mdot
.60242 .3919 Mdot
.51999 .73282 Mdot
.52409 .31306 Mdot
.56012 .4565 Mdot
.36811 .20036 Mdot
.53842 .46348 Mdot
.43679 .39838 Mdot
.54927 .29263 Mdot
.47989 .34604 Mdot
.6174 .37347 Mdot
.37419 .42193 Mdot
.33535 .57067 Mdot
.57578 .38967 Mdot
.46188 .65491 Mdot
.47785 .63363 Mdot
.81417 .54274 Mdot
.53428 .42245 Mdot
.54898 .30572 Mdot
.75369 .42182 Mdot
.54238 .66871 Mdot
.53394 .6874 Mdot
.50663 .63674 Mdot
.63638 .49596 Mdot
.58726 .35072 Mdot
.17801 .54517 Mdot
.58728 .38208 Mdot
.43632 .811 Mdot
.41967 .37777 Mdot
.38297 .40557 Mdot
.49397 .65248 Mdot
.392 .51883 Mdot
.2843 .61527 Mdot
.50929 .62445 Mdot
.35359 .57177 Mdot
.79463 .44973 Mdot
.51411 .69427 Mdot
.62592 .52048 Mdot
.54582 .55746 Mdot
.69198 .5647 Mdot
.60686 .35447 Mdot
.3188 .5383 Mdot
.26122 .57111 Mdot
.57393 .34363 Mdot
.50719 .64907 Mdot
.64863 .39084 Mdot
.48946 .62851 Mdot
.53928 .6002 Mdot
.46081 .82127 Mdot
.35072 .54417 Mdot
.39331 .38005 Mdot
.31935 .52288 Mdot
.63302 .5155 Mdot
.20206 .73532 Mdot
.31618 .5052 Mdot
.27897 .60813 Mdot
.82073 .5778 Mdot
.33007 .66929 Mdot
.66899 .49308 Mdot
.32163 .49876 Mdot
.59447 .37367 Mdot
.52014 .15169 Mdot
.62488 .79059 Mdot
.55603 .40889 Mdot
.52155 .64404 Mdot
.63085 .55419 Mdot
.68941 .49914 Mdot
.56166 .33551 Mdot
.64714 .52074 Mdot
.51048 .73137 Mdot
.54906 .60254 Mdot
.6189 .37357 Mdot
.66465 .39886 Mdot
.55079 .36703 Mdot
.6734 .33523 Mdot
.525 .62231 Mdot
.68266 .5047 Mdot
.57903 .60989 Mdot
.623 .56997 Mdot
.39136 .43169 Mdot
.46354 .67004 Mdot
.30693 .54129 Mdot
.63351 .43422 Mdot
.40635 .39632 Mdot
.23238 .47171 Mdot
.63683 .51444 Mdot
.61702 .31181 Mdot
.64214 .51321 Mdot
.71307 .51303 Mdot
.56183 .37968 Mdot
.64536 .54032 Mdot
.48363 .6642 Mdot
.491 .38405 Mdot
.62958 .53557 Mdot
.56682 .36325 Mdot
.32331 .53543 Mdot
.67115 .53582 Mdot
.46677 .39293 Mdot
.5364 .64473 Mdot
.39247 .36408 Mdot
.26839 .33427 Mdot
.66655 .55744 Mdot
.35078 .51983 Mdot
.39593 .42239 Mdot
.34732 .53091 Mdot
.78489 .34923 Mdot
.62169 .37571 Mdot
.4932 .79897 Mdot
.3627 .55453 Mdot
.69963 .52273 Mdot
.28015 .31795 Mdot
.47332 .63972 Mdot
.53774 .64165 Mdot
.29605 .50761 Mdot
.68971 .49954 Mdot
.61932 .21038 Mdot
.73129 .53094 Mdot
.65779 .34084 Mdot
.60321 .33092 Mdot
.18677 .50715 Mdot
.67797 .32458 Mdot
.81986 .35932 Mdot
.55823 .66903 Mdot
.39691 .34138 Mdot
.49581 .64486 Mdot
.40636 .27094 Mdot
.32223 .51519 Mdot
.41952 .44443 Mdot
.46327 .68161 Mdot
.39255 .38688 Mdot
.53418 .66024 Mdot
.46071 .44509 Mdot
.56426 .57163 Mdot
.29275 .54411 Mdot
.54662 .24541 Mdot
.7021 .51925 Mdot
.33364 .53479 Mdot
.40175 .34963 Mdot
.29819 .63442 Mdot
.53059 .59741 Mdot
.5709 .59184 Mdot
.40684 .32053 Mdot
.65995 .5039 Mdot
.42791 .41641 Mdot
.6099 .36276 Mdot
.30997 .53448 Mdot
.54762 .6248 Mdot
.48412 .59706 Mdot
.5038 .27855 Mdot
.55795 .36109 Mdot
.36512 .40544 Mdot
.5982 .38695 Mdot
.41196 .34307 Mdot
.56501 .63254 Mdot
.38353 .40856 Mdot
.55341 .58817 Mdot
.41052 .28654 Mdot
.45835 .81755 Mdot
.64984 .68832 Mdot
.3864 .40124 Mdot
.31507 .68205 Mdot
.56859 .37654 Mdot
.60069 .38977 Mdot
.79801 .61049 Mdot
.56014 .78273 Mdot
.34279 .76076 Mdot
.35699 .24078 Mdot
.58962 .33605 Mdot
.56152 .36482 Mdot
.38795 .36792 Mdot
.64189 .53962 Mdot
.70018 .53929 Mdot
.40672 .34277 Mdot
.3864 .64675 Mdot
.65543 .51451 Mdot
.50237 .16802 Mdot
.30061 .71919 Mdot
.5024 .58415 Mdot
.35104 .39703 Mdot
.31459 .53124 Mdot
.37924 .64746 Mdot
.45852 .44595 Mdot
.48346 .66787 Mdot
.23178 .53447 Mdot
.42542 .38697 Mdot
.40144 .56717 Mdot
.31992 .23831 Mdot
.51378 .67816 Mdot
.51824 .65834 Mdot
.50433 .64312 Mdot
.34922 .50962 Mdot
.60316 .78043 Mdot
.49978 .672 Mdot
.38785 .65012 Mdot
.55244 .65204 Mdot
.49965 .74093 Mdot
.32487 .52458 Mdot
.53828 .73827 Mdot
.34688 .28878 Mdot
.23885 .65796 Mdot
.57708 .58055 Mdot
.61162 .36782 Mdot
.32426 .58066 Mdot
.59428 .39584 Mdot
.61887 .71869 Mdot
.37621 .72497 Mdot
.66216 .56218 Mdot
.48055 .66485 Mdot
.39362 .40039 Mdot
.68788 .49767 Mdot
.52567 .29355 Mdot
.13187 .65328 Mdot
.61298 .37252 Mdot
.83396 .35105 Mdot
.60518 .38477 Mdot
.37466 .37734 Mdot
.67364 .52636 Mdot
.73315 .64569 Mdot
.44744 .51549 Mdot
.67118 .5376 Mdot
.5342 .21111 Mdot
.67056 .47422 Mdot
.31315 .66802 Mdot
.64795 .55623 Mdot
.56647 .36793 Mdot
.62439 .40715 Mdot
.48203 .71684 Mdot
.47911 .64773 Mdot
.47474 .47453 Mdot
.28053 .62968 Mdot
.47468 .64417 Mdot
.39888 .39873 Mdot
.51481 .78877 Mdot
.30355 .58736 Mdot
.64916 .53743 Mdot
.59481 .40657 Mdot
.52079 .66124 Mdot
.51753 .60105 Mdot
.53645 .59739 Mdot
.33652 .80577 Mdot
.57821 .18516 Mdot
.55963 .61221 Mdot
.54922 .66071 Mdot
.39146 .39206 Mdot
.34855 .5567 Mdot
.39268 .26535 Mdot
.52178 .76205 Mdot
.47467 .66639 Mdot
.33415 .5287 Mdot
.356 .5392 Mdot
.51086 .59692 Mdot
.25248 .51536 Mdot
.6469 .38818 Mdot
.50768 .66486 Mdot
.53184 .77729 Mdot
.44484 .33023 Mdot
.36988 .40677 Mdot
.41375 .40085 Mdot
.68234 .48804 Mdot
.3961 .4147 Mdot
.41145 .34626 Mdot
.75001 .62605 Mdot
.52493 .47003 Mdot
.58504 .41116 Mdot
.31246 .5181 Mdot
.50066 .63099 Mdot
.70923 .48342 Mdot
.64946 .40859 Mdot
.57496 .39156 Mdot
.69148 .53153 Mdot
.60578 .39432 Mdot
.29513 .49848 Mdot
.42193 .57952 Mdot
.43006 .39746 Mdot
.58791 .33763 Mdot
.64485 .30341 Mdot
.33238 .52789 Mdot
.55548 .36181 Mdot
.62445 .30039 Mdot
.47 .67403 Mdot
.66789 .71722 Mdot
.51447 .62532 Mdot
.64344 .22585 Mdot
.55997 .34903 Mdot
.44315 .29289 Mdot
.50894 .65595 Mdot
.41604 .39234 Mdot
.46784 .71051 Mdot
.47256 .62859 Mdot
.40989 .40755 Mdot
.55065 .59893 Mdot
.34731 .54365 Mdot
.65724 .5693 Mdot
.43516 .5273 Mdot
.65819 .81846 Mdot
.31988 .49995 Mdot
.52522 .28838 Mdot
.47045 .65164 Mdot
.81016 .41433 Mdot
.66881 .53577 Mdot
.54264 .58879 Mdot
.31551 .59459 Mdot
.63385 .54033 Mdot
.68944 .52515 Mdot
.51487 .60442 Mdot
.59919 .37485 Mdot
.40399 .39976 Mdot
.32811 .52712 Mdot
.78318 .32829 Mdot
.52537 .63686 Mdot
.54414 .64403 Mdot
.33713 .53333 Mdot
.56308 .37196 Mdot
.49691 .60006 Mdot
.24205 .36371 Mdot
.64045 .20314 Mdot
.59134 .40037 Mdot
.46394 .65754 Mdot
.62128 .74684 Mdot
.71037 .54908 Mdot
.85065 .55347 Mdot
.25391 .5259 Mdot
.38826 .38579 Mdot
.54481 .70546 Mdot
.22426 .73958 Mdot
.31924 .53681 Mdot
.30364 .74151 Mdot
.52646 .60093 Mdot
.55205 .63991 Mdot
.69373 .53444 Mdot
.52448 .6148 Mdot
.64782 .55199 Mdot
.65559 .81251 Mdot
.2222 .55981 Mdot
.65785 .50063 Mdot
.69692 .53469 Mdot
.29175 .60078 Mdot
.39693 .26648 Mdot
.67746 .51956 Mdot
.56288 .63372 Mdot
.60838 .61012 Mdot
.43045 .64053 Mdot
.29663 .51111 Mdot
.318 .30928 Mdot
.73166 .51335 Mdot
.34296 .49458 Mdot
.42779 .21443 Mdot
.73169 .50235 Mdot
.62881 .41557 Mdot
.60788 .36291 Mdot
.51045 .67946 Mdot
.40676 .41618 Mdot
.38933 .41981 Mdot
.57717 .62008 Mdot
.49614 .62664 Mdot
.63451 .5146 Mdot
.30522 .51972 Mdot
.61557 .37941 Mdot
.55206 .62976 Mdot
.28704 .58879 Mdot
.31996 .50537 Mdot
.64125 .52939 Mdot
.51682 .7762 Mdot
.29522 .54903 Mdot
.47797 .5729 Mdot
.49671 .66114 Mdot
.50918 .61487 Mdot
.43482 .6118 Mdot
.59447 .35025 Mdot
.30748 .29845 Mdot
.50614 .68787 Mdot
.22499 .61083 Mdot
.58043 .43296 Mdot
.47479 .58362 Mdot
.64995 .51178 Mdot
.54119 .35529 Mdot
.44456 .40244 Mdot
.44684 .54021 Mdot
.5331 .63561 Mdot
.64035 .24759 Mdot
.81115 .52123 Mdot
.40067 .43044 Mdot
.71241 .51165 Mdot
.31295 .52639 Mdot
.50724 .625 Mdot
.5863 .72623 Mdot
.4794 .6392 Mdot
.28118 .5174 Mdot
.42436 .36912 Mdot
.60797 .36506 Mdot
.66348 .23858 Mdot
.38814 .41868 Mdot
.68867 .51992 Mdot
.23387 .26965 Mdot
.63679 .55121 Mdot
.70552 .52682 Mdot
.57656 .72901 Mdot
.59875 .35353 Mdot
.25833 .77603 Mdot
.7336 .72758 Mdot
.48195 .68976 Mdot
.57316 .38108 Mdot
.6725 .51332 Mdot
.55125 .64912 Mdot
.62419 .55412 Mdot
.70684 .49618 Mdot
.56242 .64195 Mdot
.53708 .66556 Mdot
.64578 .27788 Mdot
.35693 .21187 Mdot
.31221 .52494 Mdot
.64465 .50091 Mdot
.54674 .50835 Mdot
.54601 .65872 Mdot
.50117 .65304 Mdot
.48585 .34932 Mdot
.2941 .51981 Mdot
.7276 .36365 Mdot
.52163 .60082 Mdot
.21808 .54263 Mdot
.55489 .56101 Mdot
.63675 .49905 Mdot
.58637 .3994 Mdot
.23896 .65348 Mdot
.61267 .33392 Mdot
.65539 .55163 Mdot
.30196 .52666 Mdot
.71715 .52281 Mdot
.27561 .60758 Mdot
.56669 .33618 Mdot
.69038 .5073 Mdot
.54949 .4499 Mdot
.58065 .35774 Mdot
.57151 .33992 Mdot
.58789 .71223 Mdot
.36324 .41385 Mdot
.35579 .51764 Mdot
.56043 .35588 Mdot
.569 .5244 Mdot
.57144 .36758 Mdot
.76946 .66526 Mdot
.47839 .67254 Mdot
.38378 .59141 Mdot
.35575 .44299 Mdot
.50957 .71899 Mdot
.56426 .34091 Mdot
.30629 .54659 Mdot
.50617 .60096 Mdot
.65028 .52539 Mdot
.34027 .51488 Mdot
.53833 .33868 Mdot
.39412 .36791 Mdot
.63933 .51744 Mdot
.59232 .32184 Mdot
.67157 .49612 Mdot
.49862 .52829 Mdot
.81166 .61706 Mdot
.20032 .42345 Mdot
.46212 .51192 Mdot
.53588 .59811 Mdot
.36324 .24902 Mdot
.50456 .57894 Mdot
.49384 .62305 Mdot
.39717 .4036 Mdot
.37386 .58509 Mdot
.66972 .52662 Mdot
.64474 .21527 Mdot
.597 .34388 Mdot
.22465 .641 Mdot
.60769 .58151 Mdot
.53553 .5927 Mdot
.62899 .53759 Mdot
.63871 .55259 Mdot
.6357 .67541 Mdot
.44519 .40483 Mdot
.48764 .59024 Mdot
.47021 .59866 Mdot
.57147 .61693 Mdot
.58306 .34268 Mdot
.23139 .48022 Mdot
.43657 .39574 Mdot
.83469 .57154 Mdot
.42919 .37636 Mdot
.36285 .56901 Mdot
.64509 .53779 Mdot
.31419 .50617 Mdot
.50178 .65488 Mdot
.66874 .46994 Mdot
.66189 .55321 Mdot
.28458 .52199 Mdot
.32298 .54872 Mdot
.50021 .3344 Mdot
.60105 .36288 Mdot
.48605 .59809 Mdot
.49853 .6737 Mdot
.53255 .61464 Mdot
.49985 .61598 Mdot
.61256 .36501 Mdot
.49311 .60648 Mdot
.54504 .35771 Mdot
.49193 .54331 Mdot
.2335 .52351 Mdot
.53144 .46166 Mdot
.76624 .48446 Mdot
.65007 .53242 Mdot
.57758 .51203 Mdot
.44767 .59986 Mdot
.48013 .82511 Mdot
.78861 .43094 Mdot
.49586 .68996 Mdot
.37446 .39554 Mdot
.46623 .7347 Mdot
.42464 .40577 Mdot
.86158 .41457 Mdot
.48997 .28228 Mdot
.39669 .1945 Mdot
.51037 .67471 Mdot
.47747 .35934 Mdot
.59094 .53519 Mdot
.51877 .57965 Mdot
.49913 .30215 Mdot
.74797 .46716 Mdot
.57685 .24091 Mdot
.29603 .53808 Mdot
.531 .64819 Mdot
.70713 .48288 Mdot
.48759 .66625 Mdot
.49688 .64851 Mdot
.51157 .5983 Mdot
.5609 .38452 Mdot
.49907 .58902 Mdot
.48885 .61354 Mdot
.25782 .46264 Mdot
.34744 .69751 Mdot
.38652 .42172 Mdot
.807 .5867 Mdot
.31957 .50392 Mdot
.63052 .52508 Mdot
.53707 .19479 Mdot
.59809 .36772 Mdot
.63978 .66706 Mdot
.50392 .61532 Mdot
.63398 .26982 Mdot
.54741 .3243 Mdot
.30791 .53658 Mdot
.44166 .39081 Mdot
.44905 .17285 Mdot
.3979 .39483 Mdot
.55612 .44879 Mdot
.41384 .39063 Mdot
.46404 .57673 Mdot
.63607 .51191 Mdot
.49052 .5991 Mdot
.56399 .35089 Mdot
.40006 .41058 Mdot
.34828 .63789 Mdot
.50489 .63762 Mdot
.39928 .38567 Mdot
.48982 .5994 Mdot
.41622 .58456 Mdot
.42856 .77901 Mdot
.40374 .34716 Mdot
.54961 .37841 Mdot
.57486 .35345 Mdot
.29908 .51466 Mdot
.63341 .52565 Mdot
.68314 .54126 Mdot
.58544 .36379 Mdot
.58129 .79874 Mdot
.46942 .65886 Mdot
.54179 .66359 Mdot
.22702 .63376 Mdot
.47473 .6532 Mdot
.30088 .6483 Mdot
.5583 .45273 Mdot
.64552 .52965 Mdot
.56294 .60465 Mdot
.52651 .60287 Mdot
.53602 .63815 Mdot
.46879 .5423 Mdot
.42325 .39529 Mdot
.502 .68162 Mdot
.33061 .54786 Mdot
.44085 .45119 Mdot
.55856 .63511 Mdot
.56657 .58182 Mdot
.68537 .53984 Mdot
.31454 .77327 Mdot
.60666 .37987 Mdot
.3921 .35477 Mdot
.38403 .40053 Mdot
.3259 .30677 Mdot
.64083 .44424 Mdot
.55275 .45317 Mdot
.83939 .54324 Mdot
.39605 .28994 Mdot
.33918 .52086 Mdot
.35738 .42434 Mdot
.59473 .44276 Mdot
.38225 .37124 Mdot
.61359 .37333 Mdot
.48307 .67667 Mdot
.47527 .66763 Mdot
.46054 .84195 Mdot
.5198 .59552 Mdot
.31662 .52833 Mdot
.54755 .34571 Mdot
.6532 .52573 Mdot
.3073 .53516 Mdot
.59691 .38994 Mdot
.6572 .50419 Mdot
.49344 .68673 Mdot
.49463 .68595 Mdot
.68952 .53344 Mdot
.69279 .50682 Mdot
.50094 .66076 Mdot
.33753 .34114 Mdot
.6999 .51514 Mdot
.68264 .50153 Mdot
.43203 .39489 Mdot
.40971 .4138 Mdot
.51507 .56689 Mdot
.57576 .38089 Mdot
.48946 .61174 Mdot
.39154 .39687 Mdot
.30283 .51663 Mdot
.66603 .52886 Mdot
.54231 .60282 Mdot
.55364 .62264 Mdot
.3315 .52929 Mdot
.29739 .5296 Mdot
.31329 .54624 Mdot
.54904 .36443 Mdot
.53564 .62062 Mdot
.67892 .5254 Mdot
.60328 .36323 Mdot
.35715 .53626 Mdot
.28967 .52487 Mdot
.39328 .43715 Mdot
.4706 .63961 Mdot
.39457 .46066 Mdot
.17957 .69178 Mdot
.24866 .62833 Mdot
.42477 .42453 Mdot
.43463 .42201 Mdot
.34466 .67259 Mdot
.40214 .5288 Mdot
.58899 .37405 Mdot
.28119 .54817 Mdot
.25827 .56999 Mdot
.4605 .6584 Mdot
.53142 .68508 Mdot
.44762 .63786 Mdot
.32268 .54621 Mdot
.36036 .5837 Mdot
.62286 .5409 Mdot
.74106 .56446 Mdot
.32889 .50589 Mdot
.37143 .41622 Mdot
.36785 .42943 Mdot
.42838 .37427 Mdot
.4883 .68096 Mdot
.65603 .68169 Mdot
.6028 .48535 Mdot
.32993 .25395 Mdot
.55822 .34941 Mdot
.71925 .49072 Mdot
.80368 .40799 Mdot
.68926 .53045 Mdot
.43533 .36573 Mdot
.34351 .53057 Mdot
.68809 .50131 Mdot
.60401 .3983 Mdot
.56113 .36119 Mdot
.42946 .3862 Mdot
.42182 .37661 Mdot
.40397 .35648 Mdot
.71054 .51367 Mdot
.64462 .53914 Mdot
.5323 .63275 Mdot
.66052 .53172 Mdot
.42138 .83593 Mdot
.32201 .49535 Mdot
.45756 .38501 Mdot
.57958 .37741 Mdot
.66146 .49868 Mdot
.50674 .63526 Mdot
.40533 .5508 Mdot
.74429 .43671 Mdot
.34552 .53734 Mdot
.39404 .77326 Mdot
.86001 .41929 Mdot
.4845 .59807 Mdot
.58772 .34758 Mdot
.36776 .79273 Mdot
.50711 .64234 Mdot
.41078 .36446 Mdot
.37674 .27754 Mdot
.38653 .33334 Mdot
.47258 .62166 Mdot
.4549 .6381 Mdot
.59075 .40237 Mdot
.83179 .53809 Mdot
.52801 .63268 Mdot
.72378 .37264 Mdot
.61747 .40041 Mdot
.43761 .39267 Mdot
.60367 .17223 Mdot
.24867 .3738 Mdot
.38213 .64242 Mdot
.434 .39116 Mdot
.48323 .62761 Mdot
.42503 .40213 Mdot
.34087 .54504 Mdot
.42049 .35509 Mdot
.62093 .54009 Mdot
.41068 .42707 Mdot
.54405 .64525 Mdot
.67791 .51697 Mdot
.58518 .37481 Mdot
.25174 .68801 Mdot
.31716 .45499 Mdot
.41734 .39124 Mdot
.39051 .35306 Mdot
.5585 .60173 Mdot
.70554 .33239 Mdot
.58213 .63215 Mdot
.52492 .67558 Mdot
.58472 .33475 Mdot
.63142 .53589 Mdot
.57678 .39792 Mdot
.54494 .58015 Mdot
.2381 .36224 Mdot
.59974 .3844 Mdot
.62353 .25147 Mdot
.33972 .52969 Mdot
.47548 .43751 Mdot
.50418 .63064 Mdot
.56215 .37553 Mdot
.53424 .62134 Mdot
.62366 .53396 Mdot
.51056 .42546 Mdot
.55952 .25019 Mdot
.57059 .34637 Mdot
.64761 .24294 Mdot
.37418 .55399 Mdot
.59141 .61333 Mdot
.59799 .39411 Mdot
.32187 .59252 Mdot
.37307 .38239 Mdot
.32803 .50879 Mdot
.32321 .55514 Mdot
.34389 .51647 Mdot
.57291 .65309 Mdot
.58307 .58024 Mdot
.35223 .54076 Mdot
.61138 .39565 Mdot
.29467 .54551 Mdot
.66675 .45415 Mdot
.6253 .21707 Mdot
.32513 .51648 Mdot
.52241 .64961 Mdot
.5637 .55898 Mdot
.35198 .69351 Mdot
.52236 .32128 Mdot
.41829 .18762 Mdot
.76523 .39993 Mdot
.47937 .64618 Mdot
.67597 .56261 Mdot
.6598 .49266 Mdot
.34123 .77371 Mdot
.28325 .64396 Mdot
.22919 .59083 Mdot
.70075 .53132 Mdot
.49947 .25264 Mdot
.63946 .52647 Mdot
.52989 .59602 Mdot
.5463 .65673 Mdot
.69316 .54373 Mdot
.2246 .50671 Mdot
.52916 .26692 Mdot
.71261 .26894 Mdot
.67746 .49694 Mdot
.58901 .39486 Mdot
.56169 .33278 Mdot
.57162 .3389 Mdot
.31159 .73224 Mdot
.63982 .54809 Mdot
.54206 .61643 Mdot
.38737 .40214 Mdot
.49271 .67858 Mdot
.58508 .35515 Mdot
.64255 .21308 Mdot
.66146 .54368 Mdot
.51408 .66843 Mdot
.43706 .7067 Mdot
.408 .36857 Mdot
.33534 .52487 Mdot
.4148 .62487 Mdot
.2347 .59627 Mdot
.58616 .34009 Mdot
.67087 .55747 Mdot
.45219 .28394 Mdot
.6102 .23065 Mdot
.54639 .68199 Mdot
.4829 .58406 Mdot
.80231 .34452 Mdot
.23873 .56198 Mdot
.46762 .61618 Mdot
.38212 .36564 Mdot
.4787 .26507 Mdot
.55217 .61698 Mdot
.65328 .4955 Mdot
.30687 .55351 Mdot
.34678 .52785 Mdot
.53141 .568 Mdot
.43185 .51833 Mdot
.49886 .39459 Mdot
.51211 .60837 Mdot
.47456 .57523 Mdot
.43658 .39154 Mdot
.38918 .28816 Mdot
.22352 .60583 Mdot
.3006 .52815 Mdot
.49096 .59991 Mdot
.47829 .21563 Mdot
.68366 .54633 Mdot
.40995 .42888 Mdot
.55665 .34506 Mdot
.44752 .55951 Mdot
.44043 .38699 Mdot
.55297 .61275 Mdot
.50279 .59923 Mdot
.55613 .37122 Mdot
.63577 .49996 Mdot
.3274 .54516 Mdot
.38585 .40566 Mdot
.29923 .53586 Mdot
.63515 .54269 Mdot
.6566 .53695 Mdot
.46499 .72902 Mdot
.48702 .7069 Mdot
.41102 .40235 Mdot
.56213 .59054 Mdot
.43535 .32833 Mdot
.85081 .50534 Mdot
.58661 .32369 Mdot
.47638 .60203 Mdot
.62652 .5082 Mdot
.57561 .34439 Mdot
.54688 .65204 Mdot
.78642 .32447 Mdot
.54764 .65741 Mdot
.58937 .43039 Mdot
.1944 .4265 Mdot
.30497 .54284 Mdot
.7389 .5625 Mdot
.72675 .3255 Mdot
.47894 .65656 Mdot
.37966 .38981 Mdot
.4501 .60531 Mdot
.59682 .37661 Mdot
.64802 .5377 Mdot
.85586 .5463 Mdot
.56987 .36362 Mdot
.49692 .66826 Mdot
.30909 .53481 Mdot
.64797 .55504 Mdot
.28954 .56683 Mdot
.25147 .5146 Mdot
.58876 .59505 Mdot
.5667 .59392 Mdot
.50076 .61012 Mdot
.26817 .31614 Mdot
.39445 .35387 Mdot
.67222 .50534 Mdot
.58758 .34643 Mdot
.58749 .3657 Mdot
.42753 .38764 Mdot
.63531 .29641 Mdot
.4781 .43506 Mdot
.17741 .66423 Mdot
.41201 .40816 Mdot
.3437 .51167 Mdot
.71837 .35408 Mdot
.37782 .3965 Mdot
.40301 .38266 Mdot
.43267 .39762 Mdot
.62978 .35685 Mdot
.6578 .50658 Mdot
.55552 .61634 Mdot
.64558 .49676 Mdot
.48327 .62495 Mdot
.58255 .43167 Mdot
.56717 .34659 Mdot
.65342 .54476 Mdot
.79285 .34488 Mdot
.66016 .74366 Mdot
.51369 .64696 Mdot
.80729 .4109 Mdot
.47706 .69509 Mdot
.32333 .64975 Mdot
.45882 .68075 Mdot
.41998 .3839 Mdot
.58277 .65512 Mdot
.57304 .62038 Mdot
.29937 .74797 Mdot
.58048 .37959 Mdot
.3706 .40374 Mdot
.46509 .67724 Mdot
.49843 .56228 Mdot
.70825 .52734 Mdot
.68599 .50059 Mdot
.34066 .54963 Mdot
.40903 .75487 Mdot
.58637 .37767 Mdot
.7351 .71576 Mdot
.48238 .65138 Mdot
.21949 .46041 Mdot
.67591 .5974 Mdot
.54394 .65622 Mdot
.74137 .33505 Mdot
.65234 .6753 Mdot
.50618 .62666 Mdot
.52807 .49635 Mdot
.56379 .37164 Mdot
.22775 .37596 Mdot
.55648 .64618 Mdot
.40391 .36598 Mdot
.64023 .53561 Mdot
.6234 .54653 Mdot
.34911 .54338 Mdot
.51979 .82588 Mdot
.57043 .39293 Mdot
.65001 .54203 Mdot
.49897 .63805 Mdot
.59466 .3483 Mdot
.39421 .41628 Mdot
.52879 .59143 Mdot
.28947 .65534 Mdot
.65816 .52814 Mdot
.56649 .61811 Mdot
.70812 .37808 Mdot
.37454 .68637 Mdot
.22456 .31848 Mdot
.58807 .34527 Mdot
.29528 .52175 Mdot
.45184 .60435 Mdot
.57066 .79233 Mdot
.52583 .6946 Mdot
.38834 .5854 Mdot
.67856 .45358 Mdot
.29313 .52604 Mdot
.51328 .65546 Mdot
.54678 .62244 Mdot
.37952 .48444 Mdot
.30147 .52281 Mdot
.50291 .67603 Mdot
.5199 .54579 Mdot
.66179 .5047 Mdot
.42576 .34916 Mdot
.65529 .52056 Mdot
.52113 .64471 Mdot
.47375 .70189 Mdot
.69678 .52532 Mdot
.84025 .44958 Mdot
.36073 .51697 Mdot
.60568 .37854 Mdot
.51075 .69884 Mdot
.51472 .68738 Mdot
.16134 .51346 Mdot
.38596 .42982 Mdot
.4233 .24892 Mdot
.25435 .41805 Mdot
.44218 .21735 Mdot
.24733 .37568 Mdot
.31116 .22673 Mdot
.22694 .54964 Mdot
.51148 .58681 Mdot
.6993 .57011 Mdot
.59135 .48362 Mdot
.55882 .34558 Mdot
.77445 .6223 Mdot
.47858 .6472 Mdot
.49543 .64656 Mdot
.41347 .42917 Mdot
.61657 .26 Mdot
.22754 .59054 Mdot
.40914 .53943 Mdot
.32883 .544 Mdot
.64558 .50099 Mdot
.55979 .62219 Mdot
.53513 .48383 Mdot
.38646 .42256 Mdot
.2184 .469 Mdot
.51511 .66617 Mdot
.47313 .81993 Mdot
.7249 .43618 Mdot
.59734 .35524 Mdot
.38185 .39835 Mdot
.23409 .58105 Mdot
.47072 .6355 Mdot
.55567 .3444 Mdot
.52099 .63376 Mdot
.3493 .34078 Mdot
.55322 .5827 Mdot
.32444 .51313 Mdot
.52736 .60004 Mdot
.36349 .57037 Mdot
.19915 .30946 Mdot
.27249 .53139 Mdot
.62909 .55538 Mdot
.45425 .36347 Mdot
.42036 .39758 Mdot
.69094 .50561 Mdot
.41747 .39809 Mdot
.64255 .64153 Mdot
.73412 .62319 Mdot
.33875 .53656 Mdot
.50829 .56179 Mdot
.32298 .51896 Mdot
.39729 .43141 Mdot
.47495 .63856 Mdot
.85984 .46803 Mdot
.40265 .40634 Mdot
.18503 .47235 Mdot
.57443 .36846 Mdot
.37465 .41883 Mdot
.55375 .64986 Mdot
.45507 .29033 Mdot
.38667 .41891 Mdot
.56685 .25489 Mdot
.53569 .63734 Mdot
.65369 .53256 Mdot
.5498 .61598 Mdot
.49071 .69499 Mdot
.37992 .35702 Mdot
.48108 .61745 Mdot
.59651 .39 Mdot
.70387 .51209 Mdot
.51052 .15951 Mdot
.74489 .47227 Mdot
.48834 .67054 Mdot
.5011 .63954 Mdot
.71777 .51262 Mdot
.50809 .68345 Mdot
.61246 .36506 Mdot
.48943 .90327 Mdot
.3395 .52913 Mdot
.37751 .36535 Mdot
.247 .37396 Mdot
.4917 .68777 Mdot
.50005 .60334 Mdot
.76904 .30216 Mdot
.2289 .3894 Mdot
.59766 .39278 Mdot
.57284 .63032 Mdot
.39014 .4173 Mdot
.31077 .53292 Mdot
.61551 .39153 Mdot
.51057 .61526 Mdot
.50538 .65532 Mdot
.2986 .51729 Mdot
.58074 .69276 Mdot
.28318 .69849 Mdot
.55476 .3655 Mdot
.55782 .6895 Mdot
.4648 .38068 Mdot
.46632 .64601 Mdot
.3324 .75124 Mdot
.68849 .50689 Mdot
.58769 .33908 Mdot
.36622 .25564 Mdot
.46995 .61679 Mdot
.58288 .39734 Mdot
.58557 .3788 Mdot
.57099 .63701 Mdot
.62786 .50388 Mdot
.70465 .49973 Mdot
.66939 .49577 Mdot
.45591 .85612 Mdot
.37034 .64673 Mdot
.40405 .35655 Mdot
.56319 .37127 Mdot
.40827 .34517 Mdot
.30602 .49741 Mdot
.57523 .45463 Mdot
.39747 .34881 Mdot
.67947 .49038 Mdot
.45358 .36705 Mdot
.54394 .62881 Mdot
.5864 .37422 Mdot
.38639 .36596 Mdot
.4797 .68697 Mdot
.68617 .31352 Mdot
.56759 .29736 Mdot
.28905 .53502 Mdot
.31405 .55582 Mdot
.55508 .64085 Mdot
.44592 .39803 Mdot
.4999 .65894 Mdot
.59835 .33641 Mdot
.70418 .33616 Mdot
.51929 .69555 Mdot
.41911 .39131 Mdot
.70283 .54619 Mdot
.23475 .59021 Mdot
.58373 .63981 Mdot
.52135 .65032 Mdot
.48061 .62294 Mdot
.52115 .63324 Mdot
.57283 .23129 Mdot
.60587 .33478 Mdot
.76357 .48206 Mdot
.29236 .30867 Mdot
.6698 .54091 Mdot
.67938 .48095 Mdot
.24718 .63392 Mdot
.64632 .38024 Mdot
.57353 .37987 Mdot
.49591 .62065 Mdot
.65999 .4205 Mdot
.63397 .20361 Mdot
.83318 .38559 Mdot
.36261 .48317 Mdot
.38368 .42594 Mdot
.68144 .55352 Mdot
.38056 .40966 Mdot
.48038 .63116 Mdot
.45118 .60915 Mdot
.29813 .22923 Mdot
.60982 .40833 Mdot
.34061 .5363 Mdot
.48447 .62206 Mdot
.37444 .65082 Mdot
.39028 .39372 Mdot
.36543 .38469 Mdot
.51479 .67904 Mdot
.6489 .4885 Mdot
.16732 .41553 Mdot
.59314 .34942 Mdot
.76073 .39143 Mdot
.59471 .53067 Mdot
.75991 .42564 Mdot
.58722 .35288 Mdot
.28301 .4872 Mdot
.42424 .42386 Mdot
.61561 .64243 Mdot
.67131 .5421 Mdot
.34008 .51549 Mdot
.47368 .58579 Mdot
.68791 .54021 Mdot
.43902 .39218 Mdot
.65062 .53588 Mdot
.51468 .59784 Mdot
.6218 .3824 Mdot
.38677 .38568 Mdot
.58683 .4108 Mdot
.6382 .49299 Mdot
.30208 .52922 Mdot
.42935 .49631 Mdot
.7371 .6754 Mdot
.65063 .67247 Mdot
.49741 .68179 Mdot
.54562 .48253 Mdot
.5392 .61527 Mdot
.69535 .48532 Mdot
.51093 .63518 Mdot
.68754 .46226 Mdot
.38046 .39118 Mdot
.55036 .65869 Mdot
.50779 .6094 Mdot
.78859 .58875 Mdot
.52297 .6651 Mdot
.53016 .58463 Mdot
.50449 .62406 Mdot
.63526 .48062 Mdot
.52679 .55929 Mdot
.65045 .50927 Mdot
.27791 .47817 Mdot
.40557 .38087 Mdot
.30635 .55212 Mdot
.3175 .50157 Mdot
.37893 .59757 Mdot
.31719 .34869 Mdot
.61759 .26752 Mdot
.65977 .51741 Mdot
.59217 .38675 Mdot
.51469 .63309 Mdot
.31494 .24818 Mdot
.45148 .33435 Mdot
.40318 .42162 Mdot
.74501 .47153 Mdot
.53787 .70669 Mdot
.23909 .33654 Mdot
.56701 .60614 Mdot
.4771 .84506 Mdot
.49432 .7099 Mdot
.55067 .58281 Mdot
.39456 .34651 Mdot
.31362 .49308 Mdot
.52035 .6813 Mdot
.70637 .53036 Mdot
.32095 .50963 Mdot
.659 .58264 Mdot
.42425 .45467 Mdot
.29841 .4723 Mdot
.77103 .59338 Mdot
.53149 .62543 Mdot
.38756 .38377 Mdot
.63894 .51648 Mdot
.2229 .60056 Mdot
.60424 .36432 Mdot
.58484 .41846 Mdot
.55783 .50753 Mdot
.81967 .41608 Mdot
.3207 .50497 Mdot
.58364 .70686 Mdot
.54561 .64245 Mdot
.34339 .43974 Mdot
.53058 .68825 Mdot
.63921 .21134 Mdot
.33416 .50351 Mdot
.69196 .49104 Mdot
.58745 .39351 Mdot
.65371 .49352 Mdot
.6444 .68666 Mdot
.35069 .38802 Mdot
.50446 .46124 Mdot
.39872 .39204 Mdot
.45481 .44777 Mdot
.67612 .51118 Mdot
.487 .60244 Mdot
.17437 .66201 Mdot
.68491 .50301 Mdot
.65938 .55533 Mdot
.82421 .57362 Mdot
.85568 .49266 Mdot
.5698 .68072 Mdot
.70009 .52584 Mdot
.40346 .38905 Mdot
.3096 .52404 Mdot
.54397 .60744 Mdot
.5374 .62886 Mdot
.68911 .53814 Mdot
.37524 .36496 Mdot
.59739 .76012 Mdot
.42108 .37768 Mdot
.65971 .50283 Mdot
.40525 .37387 Mdot
.43917 .29114 Mdot
.37652 .38111 Mdot
.5141 .68698 Mdot
.51189 .63454 Mdot
.29682 .34756 Mdot
.65641 .53638 Mdot
.51462 .60791 Mdot
.5518 .59818 Mdot
.67746 .52368 Mdot
.25996 .52725 Mdot
.60309 .75078 Mdot
.47389 .6588 Mdot
.53358 .64915 Mdot
.2937 .5263 Mdot
.58343 .46427 Mdot
.47645 .7773 Mdot
.5066 .60107 Mdot
.34531 .50634 Mdot
.70761 .52417 Mdot
.50563 .66465 Mdot
.57561 .19323 Mdot
.48093 .26373 Mdot
.47358 .61082 Mdot
.37237 .38579 Mdot
.57232 .61812 Mdot
.21457 .33677 Mdot
.52508 .67603 Mdot
.67229 .51937 Mdot
.63854 .54115 Mdot
.74188 .70776 Mdot
.68752 .51623 Mdot
.41096 .414 Mdot
.58262 .35663 Mdot
.64699 .22898 Mdot
.3934 .4159 Mdot
.53914 .69292 Mdot
.74408 .71936 Mdot
.51395 .59076 Mdot
.49733 .69225 Mdot
.18194 .41223 Mdot
.39047 .41192 Mdot
.62692 .53796 Mdot
.40532 .51122 Mdot
.45319 .68199 Mdot
.58373 .33855 Mdot
.48122 .57737 Mdot
.46764 .66335 Mdot
.19169 .4348 Mdot
.5202 .23225 Mdot
.57802 .33075 Mdot
.48944 .58754 Mdot
.50548 .60128 Mdot
.35636 .38997 Mdot
.50265 .63524 Mdot
.31101 .51985 Mdot
.63358 .54439 Mdot
.37596 .39598 Mdot
.33007 .53285 Mdot
.47764 .65136 Mdot
.31944 .54624 Mdot
.39329 .36338 Mdot
.56668 .33511 Mdot
.47622 .63171 Mdot
.2951 .5127 Mdot
.32293 .54522 Mdot
.53523 .61257 Mdot
.64618 .53617 Mdot
.49965 .71084 Mdot
.51551 .67071 Mdot
.54037 .60156 Mdot
.68059 .54241 Mdot
.76896 .25612 Mdot
.53904 .66814 Mdot
.38218 .53632 Mdot
.65685 .55338 Mdot
.41056 .46812 Mdot
.37482 .40488 Mdot
.47186 .66822 Mdot
.57238 .33294 Mdot
.55877 .36855 Mdot
.43753 .38744 Mdot
.65356 .55768 Mdot
.25747 .40282 Mdot
.71848 .52445 Mdot
.45417 .67941 Mdot
.46798 .60692 Mdot
.66199 .77522 Mdot
.39556 .19159 Mdot
.62992 .518 Mdot
.3947 .4528 Mdot
.42202 .53003 Mdot
.56941 .38242 Mdot
.36946 .41386 Mdot
.67728 .55578 Mdot
.64372 .55144 Mdot
.64735 .52807 Mdot
.34459 .52367 Mdot
.29983 .34676 Mdot
.62532 .51702 Mdot
.66592 .48277 Mdot
.53854 .63517 Mdot
.50492 .6023 Mdot
.24904 .59618 Mdot
.32152 .69851 Mdot
.30647 .54796 Mdot
.42858 .37836 Mdot
.39656 .85615 Mdot
.60131 .33962 Mdot
.79643 .56447 Mdot
.51044 .69492 Mdot
.1696 .69619 Mdot
.55988 .6355 Mdot
.4982 .63566 Mdot
.70422 .51441 Mdot
.28896 .52348 Mdot
.33006 .51934 Mdot
.67451 .50368 Mdot
.68974 .48118 Mdot
.31202 .51913 Mdot
.77347 .37746 Mdot
.60041 .1933 Mdot
.34815 .37955 Mdot
.67376 .53033 Mdot
.73994 .66198 Mdot
.55196 .35576 Mdot
.68544 .56848 Mdot
.61115 .3487 Mdot
.3951 .38752 Mdot
.44317 .40077 Mdot
.58058 .34124 Mdot
.53403 .63736 Mdot
.40229 .35414 Mdot
.50399 .58854 Mdot
.78234 .43833 Mdot
.65278 .71724 Mdot
.26852 .36208 Mdot
.55874 .57427 Mdot
.28298 .48296 Mdot
.61298 .29473 Mdot
.49035 .66243 Mdot
.48774 .20154 Mdot
.33633 .54134 Mdot
.63733 .57476 Mdot
.59655 .34007 Mdot
.19959 .34392 Mdot
.47385 .62698 Mdot
.66969 .52218 Mdot
.58166 .38258 Mdot
.43816 .55798 Mdot
.71932 .36557 Mdot
.48194 .62384 Mdot
.19454 .70358 Mdot
.62244 .49873 Mdot
.37695 .39024 Mdot
.55231 .80487 Mdot
.63224 .51017 Mdot
.36362 .48876 Mdot
.32084 .2954 Mdot
.80563 .37106 Mdot
.63128 .52275 Mdot
.37288 .42438 Mdot
.66031 .49656 Mdot
.30251 .52675 Mdot
.65546 .56563 Mdot
.38554 .39507 Mdot
.51741 .66232 Mdot
.42456 .38762 Mdot
.33346 .55178 Mdot
.29154 .70226 Mdot
.57483 .33105 Mdot
.37062 .40169 Mdot
.5678 .35198 Mdot
.3865 .71538 Mdot
.26392 .32684 Mdot
.60827 .36793 Mdot
.52035 .77938 Mdot
.46406 .62544 Mdot
.6357 .50186 Mdot
.42819 .39339 Mdot
.35761 .28628 Mdot
.42376 .50461 Mdot
.68006 .53709 Mdot
.41515 .36299 Mdot
.56667 .50074 Mdot
.5327 .78929 Mdot
.57921 .60462 Mdot
.39364 .73683 Mdot
.67765 .52843 Mdot
.3822 .43171 Mdot
.22786 .63836 Mdot
.67373 .4884 Mdot
.41538 .40667 Mdot
.5857 .39512 Mdot
.58913 .36211 Mdot
.50563 .67899 Mdot
.59963 .41529 Mdot
.42208 .36336 Mdot
.60131 .29255 Mdot
.69378 .54056 Mdot
.45411 .54579 Mdot
.30914 .49974 Mdot
.41269 .37953 Mdot
.52027 .59512 Mdot
.62142 .56454 Mdot
.44919 .27485 Mdot
.61516 .76158 Mdot
.29021 .76104 Mdot
.42736 .38731 Mdot
.64392 .54958 Mdot
.66702 .52486 Mdot
.57959 .65034 Mdot
.45658 .51335 Mdot
.26209 .39517 Mdot
.4052 .64072 Mdot
.40282 .57484 Mdot
.43041 .35469 Mdot
.38899 .33647 Mdot
.46134 .67152 Mdot
.52563 .62548 Mdot
.57489 .38735 Mdot
.52093 .65947 Mdot
.7004 .50731 Mdot
.50768 .68115 Mdot
.58488 .34751 Mdot
.39848 .39753 Mdot
.47696 .63778 Mdot
.30429 .54336 Mdot
.55266 .34047 Mdot
.59465 .40347 Mdot
.41624 .38505 Mdot
.68545 .542 Mdot
.26314 .5429 Mdot
.422 .37624 Mdot
.5314 .62619 Mdot
.61802 .43287 Mdot
.53639 .59745 Mdot
.74148 .54748 Mdot
.67472 .48771 Mdot
.37881 .4026 Mdot
.69916 .53661 Mdot
.56505 .35937 Mdot
.30037 .30347 Mdot
.51736 .64154 Mdot
.40917 .41002 Mdot
.36465 .30835 Mdot
.64741 .59395 Mdot
.71181 .48931 Mdot
.60893 .28287 Mdot
.68698 .48197 Mdot
.4381 .39948 Mdot
.79682 .61843 Mdot
.32907 .50754 Mdot
.40087 .42215 Mdot
.47137 .17146 Mdot
.41019 .40006 Mdot
.52922 .66518 Mdot
.55465 .63906 Mdot
.37568 .39131 Mdot
.29926 .51398 Mdot
.22164 .56998 Mdot
.43558 .35265 Mdot
.62781 .5347 Mdot
.80171 .45575 Mdot
.21881 .67931 Mdot
.61841 .41448 Mdot
.58191 .38967 Mdot
.46249 .69871 Mdot
.54615 .58424 Mdot
.61545 .36341 Mdot
.59268 .40607 Mdot
.34845 .53487 Mdot
.42883 .4027 Mdot
.63387 .47913 Mdot
.5573 .38574 Mdot
.43292 .67062 Mdot
.31184 .35646 Mdot
.58472 .62292 Mdot
.59569 .51504 Mdot
.53021 .68643 Mdot
.39473 .58856 Mdot
.58599 .34644 Mdot
.56183 .61249 Mdot
.5781 .62453 Mdot
.57921 .33414 Mdot
.30882 .52137 Mdot
.6453 .33307 Mdot
.398 .37382 Mdot
.64144 .18681 Mdot
.55631 .59173 Mdot
.53046 .66658 Mdot
.55946 .34734 Mdot
.25923 .44398 Mdot
.66051 .54512 Mdot
.66604 .48754 Mdot
.39158 .35591 Mdot
.44387 .49505 Mdot
.47416 .66752 Mdot
.50143 .66777 Mdot
.39055 .37516 Mdot
.37277 .41575 Mdot
.55104 .29094 Mdot
.55047 .62957 Mdot
.57689 .37792 Mdot
.348 .57614 Mdot
.58445 .34562 Mdot
.52992 .59644 Mdot
.5357 .66135 Mdot
.5133 .68673 Mdot
.51873 .59549 Mdot
.6066 .4025 Mdot
.56019 .61775 Mdot
.55886 .55919 Mdot
.6604 .5476 Mdot
.48891 .61525 Mdot
.40239 .58091 Mdot
.52602 .6513 Mdot
.31041 .52274 Mdot
.51125 .76679 Mdot
.47409 .62793 Mdot
.47839 .67297 Mdot
.42575 .33863 Mdot
.51023 .65137 Mdot
.60061 .33829 Mdot
.66395 .53688 Mdot
.56247 .36972 Mdot
.55578 .36013 Mdot
.4355 .37566 Mdot
.35169 .54087 Mdot
.48789 .68564 Mdot
.34458 .53687 Mdot
.54331 .68715 Mdot
.47031 .61421 Mdot
.3098 .31053 Mdot
.48913 .84589 Mdot
.29759 .72045 Mdot
.51903 .64079 Mdot
.39581 .41042 Mdot
.37603 .40483 Mdot
.62515 .58701 Mdot
.58102 .61076 Mdot
.61565 .3766 Mdot
.56083 .3728 Mdot
.29642 .65949 Mdot
.20523 .41221 Mdot
.30998 .52229 Mdot
.5524 .46959 Mdot
.48456 .59185 Mdot
.55092 .60051 Mdot
.52951 .59016 Mdot
.40782 .34618 Mdot
.39442 .55012 Mdot
.39881 .42135 Mdot
.73838 .44301 Mdot
.57322 .34247 Mdot
.47659 .6232 Mdot
.64305 .45106 Mdot
.68395 .49714 Mdot
.66323 .5366 Mdot
.59664 .40169 Mdot
.42703 .33117 Mdot
.2515 .62271 Mdot
.8505 .41023 Mdot
.6117 .51972 Mdot
.28806 .53799 Mdot
.48753 .66373 Mdot
.40464 .39576 Mdot
.66712 .49422 Mdot
.29537 .54522 Mdot
.48449 .60194 Mdot
.30068 .34555 Mdot
.52411 .63819 Mdot
.59591 .48253 Mdot
.63994 .52993 Mdot
.6302 .20852 Mdot
.63444 .55462 Mdot
.5538 .33801 Mdot
.59828 .34365 Mdot
.54786 .64949 Mdot
.61167 .79768 Mdot
.64817 .49383 Mdot
.62515 .33655 Mdot
.34253 .5107 Mdot
.46531 .27844 Mdot
.30453 .52199 Mdot
.37827 .39187 Mdot
.32029 .50794 Mdot
.38333 .39396 Mdot
.29556 .68147 Mdot
.68425 .46503 Mdot
.33526 .53339 Mdot
.34183 .34707 Mdot
.58288 .6049 Mdot
.29897 .54386 Mdot
.44653 .65957 Mdot
.73467 .56108 Mdot
.39401 .3713 Mdot
.32514 .50336 Mdot
.48972 .60144 Mdot
.29201 .24806 Mdot
.60065 .38979 Mdot
.61539 .37095 Mdot
.45167 .6722 Mdot
.43419 .36517 Mdot
.70111 .538 Mdot
.5891 .21976 Mdot
.55722 .32769 Mdot
.54382 .65971 Mdot
.51732 .68148 Mdot
.67614 .4811 Mdot
.72069 .46692 Mdot
.54357 .65341 Mdot
.45164 .71829 Mdot
.55195 .63234 Mdot
.59614 .39873 Mdot
.65118 .49538 Mdot
.66549 .52996 Mdot
.41187 .36005 Mdot
.69787 .51505 Mdot
.60821 .59935 Mdot
.66315 .43602 Mdot
.48982 .72333 Mdot
.56937 .36097 Mdot
.71185 .43873 Mdot
.7406 .44627 Mdot
.41745 .18997 Mdot
.66399 .48041 Mdot
.53753 .68066 Mdot
.68375 .54658 Mdot
.30925 .53091 Mdot
.65534 .53082 Mdot
.68378 .55199 Mdot
.49641 .65988 Mdot
.48354 .62767 Mdot
.39095 .40338 Mdot
.44357 .51736 Mdot
.67527 .54793 Mdot
.5595 .62982 Mdot
.53653 .58166 Mdot
.52143 .58786 Mdot
.51375 .40296 Mdot
.63558 .50858 Mdot
.82665 .5191 Mdot
.31764 .6028 Mdot
.67706 .54717 Mdot
.17155 .39113 Mdot
.38623 .2866 Mdot
.41531 .4325 Mdot
.5539 .3879 Mdot
.55147 .62707 Mdot
.37783 .41583 Mdot
.47993 .63153 Mdot
.5951 .51485 Mdot
.50208 .65199 Mdot
.31196 .51705 Mdot
.51382 .58658 Mdot
.4416 .39502 Mdot
.42429 .38083 Mdot
.53379 .67143 Mdot
.4798 .64129 Mdot
.27753 .68242 Mdot
.66951 .47524 Mdot
.65534 .54088 Mdot
.24944 .42194 Mdot
.32402 .54068 Mdot
.58582 .33898 Mdot
.50618 .62975 Mdot
.43057 .36494 Mdot
.42552 .38339 Mdot
.63636 .50494 Mdot
.40871 .36489 Mdot
.59257 .34987 Mdot
.51363 .64058 Mdot
.61514 .36354 Mdot
.34574 .52473 Mdot
.64368 .50165 Mdot
.48534 .61932 Mdot
.53847 .63558 Mdot
.63818 .54094 Mdot
.46853 .6763 Mdot
.29455 .52498 Mdot
.41285 .3996 Mdot
.63546 .51614 Mdot
.58429 .35798 Mdot
.37964 .39464 Mdot
.54737 .60505 Mdot
.35599 .82709 Mdot
.53058 .66148 Mdot
.55179 .62078 Mdot
.46321 .16648 Mdot
.498 .58808 Mdot
.42869 .39024 Mdot
.68673 .48921 Mdot
.5506 .57164 Mdot
.36845 .60508 Mdot
.81715 .3244 Mdot
.40531 .42049 Mdot
.49007 .6671 Mdot
.33666 .22328 Mdot
.5017 .67132 Mdot
.67518 .75653 Mdot
.33934 .39412 Mdot
.43645 .4697 Mdot
.49294 .70244 Mdot
.59745 .36751 Mdot
.39092 .40567 Mdot
.38117 .38745 Mdot
.80495 .49852 Mdot
.49819 .66294 Mdot
.57885 .48364 Mdot
.48418 .60936 Mdot
.58879 .3563 Mdot
.28632 .63335 Mdot
.42754 .38425 Mdot
.32664 .76862 Mdot
.54113 .61748 Mdot
.62356 .54248 Mdot
.45487 .371 Mdot
.44583 .3106 Mdot
.54108 .60266 Mdot
.33799 .54448 Mdot
.54903 .36909 Mdot
.53405 .57401 Mdot
.57344 .35925 Mdot
.53763 .60006 Mdot
.47028 .73403 Mdot
.55128 .81335 Mdot
.64623 .53255 Mdot
.58473 .39323 Mdot
.61527 .42971 Mdot
.56473 .63568 Mdot
.63246 .5211 Mdot
.67322 .54152 Mdot
.34583 .53979 Mdot
.52292 .44968 Mdot
.69463 .36924 Mdot
.67823 .72174 Mdot
.80988 .47872 Mdot
.44923 .3553 Mdot
.54064 .25484 Mdot
.53304 .60549 Mdot
.22412 .44662 Mdot
.58807 .33248 Mdot
.52465 .66753 Mdot
.63728 .61442 Mdot
.67548 .49888 Mdot
.53759 .64852 Mdot
.32061 .51892 Mdot
.23275 .46412 Mdot
.22217 .47195 Mdot
.32846 .27725 Mdot
.398 .39064 Mdot
.45194 .60598 Mdot
.50366 .73564 Mdot
.3817 .36183 Mdot
.46147 .65538 Mdot
.41829 .40197 Mdot
.79337 .39603 Mdot
.29167 .53866 Mdot
.62782 .52473 Mdot
.41492 .29805 Mdot
.4769 .67595 Mdot
.46704 .60647 Mdot
.32218 .55782 Mdot
.52431 .6217 Mdot
.51048 .82424 Mdot
.40838 .3071 Mdot
.38875 .36186 Mdot
.64709 .5292 Mdot
.48713 .68041 Mdot
.53654 .45339 Mdot
.51208 .6709 Mdot
.71268 .65498 Mdot
.48154 .67544 Mdot
.70586 .36431 Mdot
.64107 .53595 Mdot
.57135 .35638 Mdot
.5653 .64031 Mdot
.49899 .64629 Mdot
.32387 .58538 Mdot
.48919 .70902 Mdot
.5637 .62128 Mdot
.71423 .51904 Mdot
.66924 .49223 Mdot
.6519 .50926 Mdot
.41766 .42408 Mdot
.19774 .4242 Mdot
.56909 .37142 Mdot
.54935 .56355 Mdot
.56624 .39654 Mdot
.594 .77993 Mdot
.29016 .54014 Mdot
.34754 .23907 Mdot
.50448 .61596 Mdot
.65941 .51128 Mdot
.48913 .22026 Mdot
.71055 .51479 Mdot
.52706 .47799 Mdot
.58645 .37716 Mdot
.67992 .50236 Mdot
.49674 .63987 Mdot
.42213 .51803 Mdot
.29041 .27314 Mdot
.56085 .35957 Mdot
.54581 .68758 Mdot
.38826 .42937 Mdot
.26993 .34848 Mdot
.33344 .80883 Mdot
.59992 .39178 Mdot
.59948 .42791 Mdot
.49669 .66385 Mdot
.68509 .49575 Mdot
.59703 .36165 Mdot
.60735 .38048 Mdot
.40718 .36359 Mdot
.48574 .62513 Mdot
.48939 .62199 Mdot
.43439 .41032 Mdot
.55888 .36347 Mdot
.47256 .69519 Mdot
.55559 .5832 Mdot
.27672 .23863 Mdot
.51356 .51628 Mdot
.66895 .19083 Mdot
.60512 .59765 Mdot
.62235 .64473 Mdot
.60978 .21974 Mdot
.64751 .55252 Mdot
.47159 .63147 Mdot
.50409 .57351 Mdot
.42306 .36468 Mdot
.51786 .65167 Mdot
.36991 .43525 Mdot
.57975 .38537 Mdot
.18999 .36816 Mdot
.69423 .41661 Mdot
.79059 .37152 Mdot
.51632 .65358 Mdot
.74391 .49019 Mdot
.32203 .53049 Mdot
.60725 .3334 Mdot
.64945 .50447 Mdot
.50636 .59636 Mdot
.27815 .68475 Mdot
.39929 .42189 Mdot
.69169 .52717 Mdot
.22651 .60354 Mdot
.29029 .4814 Mdot
.52768 .59681 Mdot
.40206 .42699 Mdot
.50358 .2107 Mdot
.42407 .62886 Mdot
.57976 .32025 Mdot
.3094 .51851 Mdot
.38714 .40717 Mdot
.55687 .36724 Mdot
.60653 .52498 Mdot
.6847 .50847 Mdot
.68745 .55432 Mdot
.35108 .75511 Mdot
.37457 .37213 Mdot
.32637 .52909 Mdot
.21589 .40006 Mdot
.20999 .47611 Mdot
.31402 .51654 Mdot
.44208 .40429 Mdot
.66813 .49303 Mdot
.66924 .5055 Mdot
.66476 .53668 Mdot
.29732 .73605 Mdot
.63977 .5536 Mdot
.79786 .54017 Mdot
.50872 .59058 Mdot
.4726 .72668 Mdot
.49425 .66864 Mdot
.61669 .37313 Mdot
.63483 .5312 Mdot
.42865 .49096 Mdot
.57202 .64848 Mdot
.28678 .29458 Mdot
.51749 .67444 Mdot
.61889 .35757 Mdot
.54291 .63986 Mdot
.77887 .59549 Mdot
.67739 .54985 Mdot
.51907 .64482 Mdot
.60002 .33306 Mdot
.31485 .54172 Mdot
.72303 .5063 Mdot
.48091 .62299 Mdot
.62848 .27401 Mdot
.50413 .58726 Mdot
.76656 .34723 Mdot
.47501 .53466 Mdot
.28807 .53781 Mdot
.56303 .53374 Mdot
.36416 .41097 Mdot
.48214 .72974 Mdot
.43788 .65157 Mdot
.56403 .3526 Mdot
.42134 .28498 Mdot
.40532 .38248 Mdot
.36942 .48866 Mdot
.48818 .57091 Mdot
.32353 .55379 Mdot
.68308 .47713 Mdot
.61877 .3734 Mdot
.45893 .63972 Mdot
.58141 .63604 Mdot
.78121 .46769 Mdot
.49171 .56536 Mdot
.50884 .68253 Mdot
.30212 .55461 Mdot
.7871 .52161 Mdot
.52872 .64687 Mdot
.53408 .47397 Mdot
.65274 .56364 Mdot
.47304 .6983 Mdot
.8015 .56201 Mdot
.55516 .64005 Mdot
.69271 .5154 Mdot
.71498 .48758 Mdot
.6561 .36077 Mdot
.35116 .52442 Mdot
.47267 .66832 Mdot
.74603 .70291 Mdot
.5372 .61973 Mdot
.57566 .37465 Mdot
.5469 .58713 Mdot
.388 .39422 Mdot
.28087 .71008 Mdot
.41097 .35616 Mdot
.47464 .66358 Mdot
.66874 .53524 Mdot
.56673 .34114 Mdot
.35818 .77366 Mdot
.28802 .37544 Mdot
.7896 .53966 Mdot
.78883 .33469 Mdot
.31228 .50746 Mdot
.35526 .53943 Mdot
.61965 .37559 Mdot
.52069 .64448 Mdot
.81104 .60418 Mdot
.48581 .70975 Mdot
.535 .64735 Mdot
.50051 .65175 Mdot
.2498 .35012 Mdot
.57057 .38175 Mdot
.40438 .36933 Mdot
.54033 .65668 Mdot
.5615 .61879 Mdot
.64972 .55224 Mdot
.31959 .54415 Mdot
.37516 .40525 Mdot
.34002 .53294 Mdot
.39825 .40315 Mdot
.17876 .3792 Mdot
.57123 .62087 Mdot
.31503 .53969 Mdot
.54341 .35322 Mdot
.6864 .53957 Mdot
.65646 .43403 Mdot
.3793 .38927 Mdot
.4276 .37463 Mdot
.52842 .67267 Mdot
.69314 .51323 Mdot
.70331 .52587 Mdot
.30757 .53206 Mdot
.60552 .36043 Mdot
.47425 .63026 Mdot
.46975 .61266 Mdot
.75244 .51708 Mdot
.42964 .36025 Mdot
.58691 .49725 Mdot
.58904 .25066 Mdot
.52099 .64148 Mdot
.69882 .53164 Mdot
.4874 .64892 Mdot
.63312 .23758 Mdot
.69015 .50072 Mdot
.55613 .64155 Mdot
.19708 .53881 Mdot
.42996 .3313 Mdot
.66854 .37502 Mdot
.52086 .68421 Mdot
.70805 .25398 Mdot
.51772 .60492 Mdot
.22552 .27632 Mdot
.32487 .39224 Mdot
.46562 .64354 Mdot
.54872 .60962 Mdot
.62936 .73795 Mdot
.47599 .65413 Mdot
.43881 .39922 Mdot
.24064 .56503 Mdot
.70382 .53638 Mdot
.65174 .28873 Mdot
.53862 .75058 Mdot
.33229 .50309 Mdot
.39016 .35705 Mdot
.37008 .35009 Mdot
.32684 .51532 Mdot
.67424 .52761 Mdot
.52102 .63302 Mdot
.47341 .47107 Mdot
.41988 .34643 Mdot
.59254 .58557 Mdot
.57822 .37446 Mdot
.51054 .28841 Mdot
.40639 .31956 Mdot
.57897 .35469 Mdot
.49236 .61222 Mdot
.61742 .74522 Mdot
.38894 .7578 Mdot
.58789 .18135 Mdot
.55472 .36109 Mdot
.5605 .35397 Mdot
.27851 .71699 Mdot
.30811 .49824 Mdot
.78965 .45509 Mdot
.71195 .36268 Mdot
.57935 .33847 Mdot
.43337 .5775 Mdot
.41822 .41406 Mdot
.64425 .30036 Mdot
.63964 .57527 Mdot
.4825 .59707 Mdot
.49763 .64188 Mdot
.60328 .35418 Mdot
.64876 .59205 Mdot
.53851 .80646 Mdot
.56925 .35036 Mdot
.50838 .55573 Mdot
.49742 .42147 Mdot
.37765 .28518 Mdot
.43542 .38972 Mdot
.35133 .52903 Mdot
.36274 .54698 Mdot
.62739 .54479 Mdot
.35202 .53534 Mdot
.23066 .45827 Mdot
.51707 .62137 Mdot
.57761 .34638 Mdot
.45243 .2764 Mdot
.58509 .36253 Mdot
.32921 .51714 Mdot
.28929 .5443 Mdot
.66034 .54745 Mdot
.65413 .53806 Mdot
.62214 .66396 Mdot
.31746 .65364 Mdot
.50997 .67451 Mdot
.3739 .25333 Mdot
.69694 .53802 Mdot
.59612 .59295 Mdot
.34997 .54455 Mdot
.31953 .54219 Mdot
.36429 .57756 Mdot
.50056 .62208 Mdot
.71044 .73207 Mdot
.50214 .62582 Mdot
.2936 .63777 Mdot
.52044 .6916 Mdot
.40799 .36408 Mdot
.49745 .61853 Mdot
.26213 .5585 Mdot
.45736 .65135 Mdot
.55535 .58674 Mdot
.41902 .34975 Mdot
.53467 .57184 Mdot
.38865 .39189 Mdot
.48514 .6717 Mdot
.32271 .49856 Mdot
.41286 .35079 Mdot
.36797 .63178 Mdot
.37519 .55854 Mdot
.43818 .41233 Mdot
.33538 .55011 Mdot
.32405 .50104 Mdot
.38663 .64884 Mdot
.64975 .50383 Mdot
.67553 .56712 Mdot
.52068 .6478 Mdot
.36283 .39746 Mdot
.57558 .38643 Mdot
.55888 .62203 Mdot
.51697 .57937 Mdot
.53578 .67694 Mdot
.62498 .54235 Mdot
.265 .387 Mdot
.31012 .53681 Mdot
.42349 .41929 Mdot
.25813 .53319 Mdot
.43977 .37723 Mdot
.57464 .59827 Mdot
.482 .58137 Mdot
.60465 .67489 Mdot
.45145 .24709 Mdot
.27009 .72018 Mdot
.68688 .51058 Mdot
.37191 .38996 Mdot
.31429 .49885 Mdot
.58942 .62999 Mdot
.66053 .50546 Mdot
.38595 .39464 Mdot
.52332 .63788 Mdot
.54946 .68521 Mdot
.72664 .45469 Mdot
.53025 .74122 Mdot
.38591 .5791 Mdot
.43854 .3888 Mdot
.37085 .42016 Mdot
.21512 .46743 Mdot
.2926 .49092 Mdot
.42542 .50034 Mdot
.50957 .66411 Mdot
.33987 .54245 Mdot
.6675 .49423 Mdot
.37145 .75915 Mdot
.60725 .35578 Mdot
.44903 .51567 Mdot
.51605 .65182 Mdot
.41465 .47204 Mdot
.66889 .53667 Mdot
.31693 .52023 Mdot
.60165 .3516 Mdot
.33408 .55972 Mdot
.39067 .35243 Mdot
.83038 .41549 Mdot
.5328 .62041 Mdot
.52035 .6768 Mdot
.56283 .33225 Mdot
.67012 .49739 Mdot
.33204 .55748 Mdot
.78467 .4348 Mdot
.38731 .3695 Mdot
.8038 .62353 Mdot
.70002 .51394 Mdot
.76443 .60838 Mdot
.42478 .41659 Mdot
.59548 .40181 Mdot
.37993 .65533 Mdot
.5864 .349 Mdot
.47986 .67079 Mdot
.66159 .52115 Mdot
.59245 .39042 Mdot
.44697 .52589 Mdot
.32183 .23428 Mdot
.75042 .64431 Mdot
.51305 .62598 Mdot
.25083 .2846 Mdot
.72137 .31001 Mdot
.65784 .47571 Mdot
.56995 .33281 Mdot
.51966 .67199 Mdot
.46236 .64066 Mdot
.53889 .62192 Mdot
.59235 .38293 Mdot
.33904 .29718 Mdot
.39159 .37165 Mdot
.49532 .66635 Mdot
.34812 .53448 Mdot
.39384 .38565 Mdot
.41904 .29954 Mdot
.43038 .38379 Mdot
.65551 .48008 Mdot
.54542 .58628 Mdot
.62719 .37344 Mdot
.17809 .33961 Mdot
.56157 .36678 Mdot
.44375 .40375 Mdot
.55755 .59913 Mdot
.44765 .26762 Mdot
.65412 .50838 Mdot
.39121 .36455 Mdot
.52956 .66718 Mdot
.40776 .29748 Mdot
.29482 .71009 Mdot
.42978 .38424 Mdot
.66254 .5007 Mdot
.54799 .18738 Mdot
.52007 .65641 Mdot
.52351 .6078 Mdot
.67646 .50576 Mdot
.55034 .76483 Mdot
.22761 .63078 Mdot
.4826 .64449 Mdot
.57233 .35487 Mdot
.84896 .5421 Mdot
.56407 .58854 Mdot
.29764 .60331 Mdot
.38922 .40483 Mdot
.6459 .31779 Mdot
.57452 .50131 Mdot
.58924 .63365 Mdot
.78059 .43733 Mdot
.56554 .42844 Mdot
.23958 .32048 Mdot
.37352 .43739 Mdot
.32749 .46327 Mdot
.22042 .33102 Mdot
.61317 .34761 Mdot
.72344 .48024 Mdot
.76122 .38498 Mdot
.3834 .80787 Mdot
.55086 .1955 Mdot
.27161 .46101 Mdot
.27421 .68112 Mdot
.47682 .4543 Mdot
.40309 .40479 Mdot
.30917 .56681 Mdot
.47901 .62792 Mdot
.71813 .30559 Mdot
.7311 .7076 Mdot
.62154 .80198 Mdot
.25528 .27852 Mdot
.66904 .75482 Mdot
.31824 .24616 Mdot
.43243 .18247 Mdot
.61316 .63702 Mdot
.46566 .23813 Mdot
.80327 .63453 Mdot
.20104 .52056 Mdot
.82074 .47693 Mdot
.48189 .72249 Mdot
.53548 .48356 Mdot
.77273 .33618 Mdot
.77334 .57156 Mdot
.54236 .79549 Mdot
.40799 .35811 Mdot
.68127 .48592 Mdot
.75081 .37214 Mdot
.6985 .48457 Mdot
.63829 .40056 Mdot
.55567 .18245 Mdot
.34072 .21619 Mdot
.783 .5909 Mdot
.66837 .21864 Mdot
.65184 .61237 Mdot
.63406 .8379 Mdot
.42956 .34955 Mdot
.62781 .51766 Mdot
.35693 .49265 Mdot
.21155 .46294 Mdot
.74723 .43263 Mdot
.75229 .35888 Mdot
.29663 .32321 Mdot
.35887 .68452 Mdot
.66993 .52368 Mdot
.54899 .52869 Mdot
.62879 .32185 Mdot
.70148 .42086 Mdot
.23925 .56976 Mdot
.47212 .18338 Mdot
.47688 .47981 Mdot
.63852 .28303 Mdot
.52623 .27235 Mdot
.32967 .80239 Mdot
.33379 .59824 Mdot
.59818 .63452 Mdot
.62396 .43573 Mdot
.62035 .22337 Mdot
.42311 .81497 Mdot
.31965 .67173 Mdot
.21113 .46733 Mdot
.1756 .46875 Mdot
.68658 .26448 Mdot
.16356 .5652 Mdot
.66845 .56679 Mdot
.51308 .68268 Mdot
.57757 .7374 Mdot
.75728 .68825 Mdot
.28239 .53399 Mdot
.33838 .27732 Mdot
.33667 .50834 Mdot
.61551 .52973 Mdot
.2678 .68715 Mdot
.79764 .55221 Mdot
.75713 .69475 Mdot
.36257 .53282 Mdot
.56046 .57652 Mdot
.89646 .50096 Mdot
.26308 .30382 Mdot
.66649 .40076 Mdot
.26211 .24865 Mdot
.40772 .48565 Mdot
.44427 .55406 Mdot
.59135 .38934 Mdot
.21869 .32257 Mdot
.66686 .51107 Mdot
.14629 .51478 Mdot
.21649 .29565 Mdot
.48393 .77282 Mdot
.67764 .15607 Mdot
.22061 .42212 Mdot
.42881 .47321 Mdot
.55159 .4123 Mdot
.34949 .62028 Mdot
.5027 .80823 Mdot
.46573 .74882 Mdot
.47022 .26356 Mdot
.77594 .31416 Mdot
.23563 .31309 Mdot
.77984 .65675 Mdot
.82968 .43515 Mdot
.40604 .81964 Mdot
.55405 .45639 Mdot
.66565 .57649 Mdot
.38057 .33156 Mdot
.44964 .19995 Mdot
.17192 .41942 Mdot
.31619 .59985 Mdot
.83129 .33999 Mdot
.27071 .51519 Mdot
.31304 .39224 Mdot
.55628 .1709 Mdot
.36932 .68481 Mdot
.5289 .52415 Mdot
.23123 .54754 Mdot
.59192 .59797 Mdot
.24209 .51277 Mdot
.37206 .24269 Mdot
.6367 .42615 Mdot
.20628 .51837 Mdot
.54783 .2101 Mdot
.77908 .46757 Mdot
.66165 .7091 Mdot
.20442 .46935 Mdot
.71325 .51199 Mdot
.34166 .67777 Mdot
.52363 .52084 Mdot
.3297 .2188 Mdot
.59497 .42643 Mdot
.3807 .18134 Mdot
.23295 .63325 Mdot
.55414 .66675 Mdot
.44395 .67123 Mdot
.52917 .54973 Mdot
.32864 .6547 Mdot
.55258 .5786 Mdot
.74547 .4552 Mdot
.39349 .18897 Mdot
.67186 .59808 Mdot
.64166 .33352 Mdot
.41271 .28652 Mdot
.57337 .17228 Mdot
.60829 .7036 Mdot
.30256 .48629 Mdot
.26039 .61103 Mdot
.37843 .82103 Mdot
.40491 .37832 Mdot
.788 .63714 Mdot
.5814 .31961 Mdot
.31929 .72841 Mdot
.67861 .72497 Mdot
.47902 .78709 Mdot
.39503 .18813 Mdot
.27549 .47772 Mdot
.25458 .66163 Mdot
.39647 .72108 Mdot
.82757 .57294 Mdot
.38455 .27739 Mdot
.48046 .5785 Mdot
.69847 .30391 Mdot
.29981 .51275 Mdot
.63777 .68515 Mdot
.83528 .5252 Mdot
.2789 .42732 Mdot
.44915 .6381 Mdot
.43955 .77786 Mdot
.4682 .3791 Mdot
.42493 .5171 Mdot
.21052 .68406 Mdot
.58377 .61145 Mdot
.2118 .40949 Mdot
.70536 .27864 Mdot
.33051 .62266 Mdot
.60911 .20276 Mdot
.59929 .23231 Mdot
.16093 .53231 Mdot
.24485 .27277 Mdot
.28011 .3812 Mdot
.21421 .34732 Mdot
.30716 .22497 Mdot
.1698 .55617 Mdot
.43422 .63611 Mdot
.56121 .33123 Mdot
.29904 .80188 Mdot
.43621 .39903 Mdot
.23425 .36422 Mdot
.80976 .47993 Mdot
.43346 .31307 Mdot
.63665 .47533 Mdot
.53442 .727 Mdot
.48165 .45839 Mdot
.649 .47981 Mdot
.54124 .5737 Mdot
.21646 .66935 Mdot
.17184 .51459 Mdot
.19061 .61905 Mdot
.70759 .26665 Mdot
.19923 .36364 Mdot
.46618 .43994 Mdot
.78321 .56432 Mdot
.62639 .58576 Mdot
.49544 .59544 Mdot
.37908 .50427 Mdot
.2221 .41856 Mdot
.43564 .78007 Mdot
.73721 .41063 Mdot
.67561 .47538 Mdot
.35288 .2622 Mdot
.66489 .85419 Mdot
.64262 .63268 Mdot
.80861 .55371 Mdot
.21902 .47184 Mdot
.31648 .64362 Mdot
.43069 .21223 Mdot
.48169 .77935 Mdot
.45333 .17209 Mdot
.63843 .48547 Mdot
.81589 .47069 Mdot
.28857 .45076 Mdot
.40978 .6054 Mdot
.26904 .37815 Mdot
.3549 .21777 Mdot
.5084 .37164 Mdot
.40121 .78359 Mdot
.72011 .35502 Mdot
.50572 .78915 Mdot
.33793 .40837 Mdot
.51977 .28825 Mdot
.83121 .53383 Mdot
.54377 .24232 Mdot
.29641 .62304 Mdot
.50333 .43082 Mdot
.58385 .54104 Mdot
.56414 .4268 Mdot
.30205 .62083 Mdot
.40244 .59923 Mdot
.206 .3779 Mdot
.16601 .32041 Mdot
.27977 .7433 Mdot
.6411 .19048 Mdot
.39638 .23377 Mdot
.45092 .6417 Mdot
.50877 .15434 Mdot
.17369 .60281 Mdot
.20476 .29824 Mdot
.51325 .32166 Mdot
.37108 .4383 Mdot
.5828 .40688 Mdot
.22709 .66792 Mdot
.32875 .31892 Mdot
.4973 .16608 Mdot
.22941 .53836 Mdot
.57421 .40543 Mdot
.49991 .84688 Mdot
.18132 .48583 Mdot
.70413 .70651 Mdot
.53687 .73704 Mdot
.4809 .69365 Mdot
.77326 .62525 Mdot
.6892 .48181 Mdot
.54678 .25749 Mdot
.32422 .66571 Mdot
.41647 .37955 Mdot
.37967 .51291 Mdot
.74061 .34337 Mdot
.51213 .58678 Mdot
.6019 .44373 Mdot
.66168 .48308 Mdot
.45753 .24495 Mdot
.68398 .43374 Mdot
.16621 .41696 Mdot
.2452 .38443 Mdot
.5135 .70001 Mdot
.32766 .61811 Mdot
.262 .38286 Mdot
.22669 .63728 Mdot
.61757 .39647 Mdot
.27593 .26073 Mdot
.5076 .49332 Mdot
.33902 .67595 Mdot
.75671 .6622 Mdot
.73623 .55424 Mdot
.48247 .58623 Mdot
.55227 .23107 Mdot
.70628 .64621 Mdot
.43569 .52006 Mdot
.63402 .57696 Mdot
.70142 .56222 Mdot
.52827 .14885 Mdot
.23349 .46951 Mdot
.51269 .27791 Mdot
.30028 .2453 Mdot
.59249 .372 Mdot
.68911 .54225 Mdot
.35314 .56542 Mdot
.7884 .42065 Mdot
.73319 .61727 Mdot
.29538 .71118 Mdot
.42435 .31385 Mdot
.29037 .41858 Mdot
.30617 .24673 Mdot
.26895 .27196 Mdot
.68044 .77685 Mdot
.70895 .48547 Mdot
.61788 .61238 Mdot
.79775 .44056 Mdot
.69324 .489 Mdot
.77004 .476 Mdot
.75481 .46881 Mdot
.1815 .40217 Mdot
.62761 .40768 Mdot
.76065 .29614 Mdot
.38474 .59626 Mdot
.32838 .29626 Mdot
.35332 .77251 Mdot
.82807 .54015 Mdot
.32851 .2393 Mdot
.42772 .60006 Mdot
.64087 .74661 Mdot
.48907 .72495 Mdot
.61873 .48221 Mdot
.39803 .84471 Mdot
.36064 .56533 Mdot
.76635 .60882 Mdot
.55167 .20801 Mdot
.52612 .62774 Mdot
.28467 .75387 Mdot
.77587 .39307 Mdot
.27818 .71979 Mdot
.55719 .38753 Mdot
.50064 .60369 Mdot
.45594 .63807 Mdot
.27537 .59852 Mdot
.65789 .36188 Mdot
.20026 .40409 Mdot
.84619 .51099 Mdot
.50631 .20508 Mdot
.72996 .70824 Mdot
.21968 .39993 Mdot
.49496 .17337 Mdot
.71052 .29752 Mdot
.52222 .45965 Mdot
.2273 .41239 Mdot
.37474 .6761 Mdot
.67005 .22312 Mdot
.40075 .55602 Mdot
.54812 .31956 Mdot
.76045 .44343 Mdot
.59612 .24873 Mdot
.368 .76544 Mdot
.52391 .5999 Mdot
.22649 .60327 Mdot
.44932 .18173 Mdot
.69998 .75378 Mdot
.4794 .82283 Mdot
.2633 .72947 Mdot
.70495 .67389 Mdot
.59504 .24122 Mdot
.7146 .30787 Mdot
.83223 .60889 Mdot
.51293 .49594 Mdot
.30696 .27762 Mdot
.38011 .69281 Mdot
.3043 .24564 Mdot
.57127 .32805 Mdot
.72712 .37565 Mdot
.40704 .28624 Mdot
.20681 .36506 Mdot
.61005 .7218 Mdot
.38128 .20516 Mdot
.42771 .48076 Mdot
.15683 .51667 Mdot
.52039 .23478 Mdot
.47736 .44482 Mdot
.37604 .37711 Mdot
.26283 .48266 Mdot
.36373 .23987 Mdot
.43011 .24089 Mdot
.82308 .544 Mdot
.38451 .43424 Mdot
.33343 .56872 Mdot
.70882 .71392 Mdot
.37918 .72489 Mdot
.56558 .22881 Mdot
.32804 .61837 Mdot
.36915 .20266 Mdot
.25154 .56899 Mdot
.23218 .61121 Mdot
.23545 .38267 Mdot
.8241 .37518 Mdot
.6655 .39555 Mdot
.22958 .48966 Mdot
.76676 .37604 Mdot
.31796 .37997 Mdot
.44128 .56745 Mdot
.06323 .51893 Mdot
.81808 .3971 Mdot
.49031 .23562 Mdot
.17226 .41944 Mdot
.63177 .22979 Mdot
.45765 .24769 Mdot
.49378 .8048 Mdot
.51688 .51468 Mdot
.2774 .66496 Mdot
.50103 .65096 Mdot
.19909 .65317 Mdot
.3575 .70483 Mdot
.16428 .44921 Mdot
.52436 .15635 Mdot
.7663 .63608 Mdot
.52429 .58386 Mdot
.4127 .42435 Mdot
.63193 .41335 Mdot
.36197 .72912 Mdot
.59055 .75517 Mdot
.50352 .53521 Mdot
.38762 .30083 Mdot
.37986 .36399 Mdot
.2528 .40453 Mdot
.61114 .52569 Mdot
.32659 .31442 Mdot
.58697 .24796 Mdot
.44119 .34057 Mdot
.47615 .48831 Mdot
.30913 .62759 Mdot
.57193 .50539 Mdot
.70931 .69995 Mdot
.46674 .78271 Mdot
.5634 .44634 Mdot
.43166 .38273 Mdot
.68634 .71088 Mdot
.78584 .3473 Mdot
.51087 .21201 Mdot
.17359 .46243 Mdot
.25283 .51053 Mdot
.61017 .76576 Mdot
.29425 .6161 Mdot
.51401 .80974 Mdot
.59236 .79143 Mdot
.40658 .26091 Mdot
.60371 .52087 Mdot
.5434 .78762 Mdot
.70897 .32052 Mdot
.19126 .36356 Mdot
.81978 .47582 Mdot
.80407 .4483 Mdot
.34544 .34795 Mdot
.76001 .5791 Mdot
.74272 .67802 Mdot
.37297 .62718 Mdot
.42654 .5057 Mdot
.59861 .8504 Mdot
.65892 .57423 Mdot
.4685 .88544 Mdot
.5967 .39744 Mdot
.41969 .82989 Mdot
.38205 .68053 Mdot
.50561 .42565 Mdot
.40008 .49808 Mdot
.56041 .23741 Mdot
.70896 .36771 Mdot
.72491 .28767 Mdot
.59428 .8023 Mdot
.43468 .36214 Mdot
.85003 .50643 Mdot
.82838 .37635 Mdot
.64975 .73019 Mdot
.56899 .59796 Mdot
.8173 .38396 Mdot
.38215 .44301 Mdot
.43728 .78144 Mdot
.60982 .2003 Mdot
.44012 .22975 Mdot
.43064 .64168 Mdot
.31991 .64986 Mdot
.30954 .27335 Mdot
.27286 .25469 Mdot
.50762 .83592 Mdot
.37379 .24243 Mdot
.56629 .32981 Mdot
.46523 .44838 Mdot
.38843 .2096 Mdot
.4414 .54933 Mdot
.65363 .30442 Mdot
.50365 .52928 Mdot
.54481 .8842 Mdot
.23905 .3495 Mdot
.20201 .40146 Mdot
.47484 .53626 Mdot
.64829 .55741 Mdot
.65165 .35973 Mdot
.53291 .52306 Mdot
.45722 .22647 Mdot
.77397 .35 Mdot
.52951 .52147 Mdot
.77888 .7018 Mdot
.73204 .56253 Mdot
.46189 .42434 Mdot
.72882 .70119 Mdot
.66523 .59719 Mdot
.55594 .38676 Mdot
.23883 .59737 Mdot
.53557 .2008 Mdot
.55146 .33817 Mdot
.55959 .22657 Mdot
.63277 .28252 Mdot
.76222 .53534 Mdot
.73697 .62424 Mdot
.4754 .2081 Mdot
.61043 .74088 Mdot
.71036 .4655 Mdot
.36393 .75382 Mdot
.44374 .40952 Mdot
.53535 .19533 Mdot
.38136 .37368 Mdot
.59641 .60269 Mdot
.44914 .51893 Mdot
.48258 .74886 Mdot
.25845 .70961 Mdot
.31079 .50737 Mdot
.64953 .49473 Mdot
.44342 .84507 Mdot
.69687 .49824 Mdot
.20784 .65453 Mdot
.4815 .78469 Mdot
.75884 .66019 Mdot
.28065 .38916 Mdot
.26345 .43226 Mdot
.6983 .78795 Mdot
.60295 .43868 Mdot
.38599 .32491 Mdot
.6678 .4472 Mdot
.6326 .51102 Mdot
.24728 .37525 Mdot
.42164 .35361 Mdot
.51737 .50653 Mdot
.50287 .36412 Mdot
.73819 .51094 Mdot
.66666 .46234 Mdot
.4909 .50094 Mdot
.28377 .65549 Mdot
.19007 .3908 Mdot
.41089 .40759 Mdot
.49661 .87328 Mdot
.50416 .58249 Mdot
.65746 .70408 Mdot
.45256 .17003 Mdot
.51068 .84501 Mdot
.37953 .33752 Mdot
.83276 .37725 Mdot
.52564 .69237 Mdot
.44355 .21071 Mdot
.67081 .51625 Mdot
.80819 .45708 Mdot
.32183 .50545 Mdot
.33681 .62209 Mdot
.58133 .40411 Mdot
.39792 .78371 Mdot
.46203 .34837 Mdot
.69306 .54903 Mdot
.40086 .24132 Mdot
.62236 .60998 Mdot
.69384 .33794 Mdot
.25471 .42402 Mdot
.65439 .73106 Mdot
.74047 .6144 Mdot
.67701 .46422 Mdot
.20778 .38625 Mdot
.81268 .45408 Mdot
.16928 .38193 Mdot
.56336 .55703 Mdot
.3082 .47501 Mdot
.76324 .45779 Mdot
.52893 .21901 Mdot
.60947 .48773 Mdot
.42324 .17592 Mdot
.33049 .67874 Mdot
.74652 .51357 Mdot
.29627 .63543 Mdot
.53675 .70283 Mdot
.50137 .46657 Mdot
.54883 .26797 Mdot
.61526 .80668 Mdot
.59745 .48087 Mdot
.4411 .82151 Mdot
.60465 .50804 Mdot
.20202 .42797 Mdot
.60553 .54413 Mdot
.374 .3604 Mdot
.76472 .58363 Mdot
.60754 .42895 Mdot
.20182 .34775 Mdot
.4329 .17347 Mdot
.62395 .39266 Mdot
.27821 .34399 Mdot
.6096 .21451 Mdot
.56429 .67897 Mdot
.44065 .45816 Mdot
.50311 .68231 Mdot
.62189 .5913 Mdot
.52066 .85076 Mdot
.48578 .22009 Mdot
.45966 .59161 Mdot
.23558 .32231 Mdot
.22869 .31364 Mdot
.16176 .4913 Mdot
.81395 .60472 Mdot
.64162 .54899 Mdot
.18139 .58181 Mdot
.5051 .53674 Mdot
.29575 .23298 Mdot
.41096 .25548 Mdot
.51067 .14536 Mdot
.63692 .74421 Mdot
.57574 .21919 Mdot
.52099 .79194 Mdot
.68241 .3561 Mdot
.67268 .25948 Mdot
.49383 .40306 Mdot
.49733 .27653 Mdot
.64924 .23914 Mdot
.84727 .61884 Mdot
.57908 .67138 Mdot
.63319 .27823 Mdot
.73285 .35418 Mdot
.52558 .19386 Mdot
.33125 .41414 Mdot
.54697 .58745 Mdot
.44251 .28057 Mdot
.31693 .74612 Mdot
.31264 .61624 Mdot
.31679 .5697 Mdot
.33006 .40942 Mdot
.32223 .71296 Mdot
.29222 .6454 Mdot
.82132 .47549 Mdot
.64989 .73785 Mdot
.55218 .49555 Mdot
.56412 .63795 Mdot
.62541 .49031 Mdot
.35407 .52034 Mdot
.49091 .37752 Mdot
.49267 .67552 Mdot
.36287 .38945 Mdot
.69372 .34545 Mdot
.24698 .70849 Mdot
.64466 .40728 Mdot
.7694 .36833 Mdot
.62187 .56225 Mdot
.62781 .28732 Mdot
.63726 .45265 Mdot
.33473 .77413 Mdot
.32324 .44674 Mdot
.31658 .59975 Mdot
.27012 .29074 Mdot
.20605 .51548 Mdot
.7611 .52374 Mdot
.193 .54093 Mdot
.58351 .33173 Mdot
.46345 .57584 Mdot
.74673 .38201 Mdot
.24329 .41553 Mdot
.62254 .57451 Mdot
.5728 .21959 Mdot
.39244 .32348 Mdot
.22074 .49585 Mdot
.69862 .27074 Mdot
.65551 .59447 Mdot
.68105 .73561 Mdot
.25954 .28085 Mdot
.40635 .41984 Mdot
.81174 .4286 Mdot
.65254 .29549 Mdot
.31591 .46081 Mdot
.19185 .4343 Mdot
.17504 .39732 Mdot
.42056 .49356 Mdot
.36069 .66455 Mdot
.53524 .61127 Mdot
.82629 .51941 Mdot
.50883 .22197 Mdot
.4964 .74122 Mdot
.50446 .31952 Mdot
.69816 .52764 Mdot
.54358 .28754 Mdot
.54168 .48638 Mdot
.29633 .68582 Mdot
.6918 .48101 Mdot
.72889 .71366 Mdot
.32845 .49893 Mdot
.38976 .47655 Mdot
.54762 .57357 Mdot
.3551 .64532 Mdot
.77319 .67712 Mdot
.5582 .56211 Mdot
.3974 .22478 Mdot
.6704 .72605 Mdot
.78821 .43861 Mdot
.45996 .21389 Mdot
.40505 .26447 Mdot
.70366 .36626 Mdot
.7589 .60582 Mdot
.4886 .36024 Mdot
.53183 .67924 Mdot
.37416 .35654 Mdot
.708 .51511 Mdot
.5704 .18738 Mdot
.70942 .66262 Mdot
.36779 .63572 Mdot
.52374 .42022 Mdot
.59892 .60835 Mdot
.53403 .41066 Mdot
.49039 .15376 Mdot
.6828 .35816 Mdot
.32263 .66698 Mdot
.62653 .4112 Mdot
.38003 .67469 Mdot
.47723 .7911 Mdot
.21101 .30934 Mdot
.50759 .79902 Mdot
.46277 .47976 Mdot
.45169 .82714 Mdot
.55158 .2429 Mdot
.61707 .2054 Mdot
.30948 .6611 Mdot
.38553 .48208 Mdot
.27713 .53385 Mdot
.72939 .46 Mdot
.54549 .44732 Mdot
.2865 .56407 Mdot
.53513 .50542 Mdot
.48219 .32916 Mdot
.60762 .30296 Mdot
.53167 .72724 Mdot
.24171 .35839 Mdot
.26544 .28621 Mdot
.8087 .46691 Mdot
.56161 .4294 Mdot
.3487 .46407 Mdot
.31411 .69698 Mdot
.56542 .13891 Mdot
.35001 .8221 Mdot
.53547 .61268 Mdot
.56939 .43725 Mdot
.3488 .66163 Mdot
.43935 .38868 Mdot
.56416 .51658 Mdot
.63522 .44948 Mdot
.58368 .39705 Mdot
.34213 .57002 Mdot
.22295 .50835 Mdot
.56821 .24375 Mdot
.39481 .7344 Mdot
.41645 .2953 Mdot
.24752 .71319 Mdot
.77175 .32509 Mdot
.5162 .21909 Mdot
.51147 .13008 Mdot
.60193 .29314 Mdot
.72372 .53674 Mdot
.5796 .7283 Mdot
.19182 .39363 Mdot
.33362 .61029 Mdot
.34334 .74831 Mdot
.39994 .2745 Mdot
.32164 .67263 Mdot
.45993 .55345 Mdot
.22595 .39347 Mdot
.53404 .29458 Mdot
.49459 .44957 Mdot
.26476 .43497 Mdot
.18511 .51001 Mdot
.68691 .73991 Mdot
.2904 .27653 Mdot
.33061 .75956 Mdot
.81884 .64543 Mdot
.21417 .32635 Mdot
.37713 .5433 Mdot
.33898 .44266 Mdot
.58249 .73156 Mdot
.40216 .57626 Mdot
.43023 .58307 Mdot
.42799 .77983 Mdot
.72592 .61386 Mdot
.30021 .34817 Mdot
.39818 .80758 Mdot
.29681 .62256 Mdot
.68728 .5907 Mdot
.38772 .48436 Mdot
.70436 .69985 Mdot
.27569 .35065 Mdot
.45684 .53887 Mdot
.40694 .54808 Mdot
.36792 .59835 Mdot
.67645 .71721 Mdot
.77657 .45917 Mdot
.61586 .23314 Mdot
.78871 .70245 Mdot
.3661 .26529 Mdot
.34781 .78357 Mdot
.51305 .58977 Mdot
.1541 .41375 Mdot
.62432 .24886 Mdot
.38678 .27094 Mdot
.74164 .31582 Mdot
.44742 .44135 Mdot
.7337 .5359 Mdot
.53255 .67866 Mdot
.35381 .25153 Mdot
.76445 .61644 Mdot
.62993 .62194 Mdot
.3869 .78484 Mdot
.32715 .63312 Mdot
.24139 .55111 Mdot
.37848 .61779 Mdot
.52053 .55389 Mdot
.69044 .49484 Mdot
.18524 .60817 Mdot
.44476 .48066 Mdot
.59618 .61119 Mdot
.4784 .73325 Mdot
.51063 .78672 Mdot
.78746 .31886 Mdot
.53616 .55039 Mdot
.20352 .49887 Mdot
.65395 .7619 Mdot
.43341 .68072 Mdot
.59131 .52147 Mdot
.55983 .09742 Mdot
.19606 .29277 Mdot
.69964 .5424 Mdot
.80661 .56314 Mdot
.66155 .75941 Mdot
.20363 .37915 Mdot
.29331 .44885 Mdot
.5025 .34551 Mdot
.45604 .73281 Mdot
.41371 .57712 Mdot
.51915 .56627 Mdot
.71365 .28824 Mdot
.21902 .29802 Mdot
.39256 .79266 Mdot
.23739 .31906 Mdot
.4593 .69971 Mdot
.51761 .56291 Mdot
.60078 .14055 Mdot
.37676 .21577 Mdot
.58135 .64741 Mdot
.53488 .79972 Mdot
.66364 .5766 Mdot
.4814 .63492 Mdot
.30963 .29704 Mdot
.84849 .5025 Mdot
.29317 .61913 Mdot
.20658 .36603 Mdot
.70557 .48692 Mdot
.40396 .33011 Mdot
.59226 .40045 Mdot
.40862 .50147 Mdot
.55608 .67507 Mdot
.59581 .38575 Mdot
.49563 .76001 Mdot
.57127 .21227 Mdot
.63582 .389 Mdot
.82934 .46245 Mdot
.41528 .16279 Mdot
.71504 .66969 Mdot
.71271 .45159 Mdot
.58829 .63168 Mdot
.68757 .58906 Mdot
.35213 .72715 Mdot
.64832 .58717 Mdot
.63681 .22307 Mdot
.09815 .5248 Mdot
.48681 .28543 Mdot
.25814 .63389 Mdot
.61258 .53216 Mdot
.56553 .4956 Mdot
.72611 .68775 Mdot
.38163 .46167 Mdot
.39248 .41428 Mdot
.4786 .71034 Mdot
.54611 .55462 Mdot
.55181 .37458 Mdot
.45179 .87405 Mdot
.55011 .5922 Mdot
.58178 .50986 Mdot
.29745 .23339 Mdot
.363 .7536 Mdot
.63982 .70768 Mdot
.50174 .69342 Mdot
.70908 .42494 Mdot
.38409 .48059 Mdot
.49427 .18666 Mdot
.23111 .60527 Mdot
.24243 .32462 Mdot
.71026 .65901 Mdot
.67456 .74295 Mdot
.56224 .62105 Mdot
.29128 .5105 Mdot
.65217 .31791 Mdot
.32742 .28424 Mdot
.44399 .66496 Mdot
.26031 .25939 Mdot
.46609 .42212 Mdot
.46358 .34177 Mdot
.48238 .55879 Mdot
.16317 .50753 Mdot
.44184 .80985 Mdot
.7521 .65528 Mdot
.31587 .76309 Mdot
.24125 .44164 Mdot
.37726 .72229 Mdot
.40763 .42472 Mdot
.44736 .67329 Mdot
.7118 .496 Mdot
.25588 .73047 Mdot
.30075 .29643 Mdot
.47611 .27033 Mdot
.51634 .29032 Mdot
.8066 .52743 Mdot
.68972 .32469 Mdot
.48174 .13378 Mdot
.25018 .4415 Mdot
.25873 .72859 Mdot
.80648 .44238 Mdot
.61193 .56881 Mdot
.57789 .23061 Mdot
.49048 .56353 Mdot
.42457 .3933 Mdot
.23353 .33706 Mdot
.57812 .57684 Mdot
.27142 .68875 Mdot
.46449 .67073 Mdot
.26186 .70051 Mdot
.30713 .57726 Mdot
.27007 .34339 Mdot
.51465 .23861 Mdot
.48587 .79994 Mdot
.54289 .17555 Mdot
.73591 .46299 Mdot
.54733 .14682 Mdot
.54736 .18347 Mdot
.27055 .26442 Mdot
.30693 .72641 Mdot
.5448 .83255 Mdot
.43142 .24313 Mdot
.48149 .20925 Mdot
.56746 .25671 Mdot
.55777 .75812 Mdot
.26505 .47972 Mdot
.51698 .54956 Mdot
.66547 .3615 Mdot
.62389 .36776 Mdot
.19189 .73171 Mdot
.26532 .56556 Mdot
.69409 .5537 Mdot
.25 .47228 Mdot
.2394 .29536 Mdot
.53905 .76716 Mdot
.66325 .24547 Mdot
.53247 .48398 Mdot
.4846 .57692 Mdot
.72752 .63109 Mdot
.80904 .49848 Mdot
.26145 .49006 Mdot
.70504 .79251 Mdot
.77421 .33453 Mdot
.49467 .30951 Mdot
.49814 .47489 Mdot
.69234 .48653 Mdot
.65617 .45763 Mdot
.27283 .41542 Mdot
.65586 .22786 Mdot
.57408 .21673 Mdot
.3863 .21037 Mdot
.70064 .78469 Mdot
.79394 .44175 Mdot
.19071 .39328 Mdot
.52659 .23057 Mdot
.67427 .56094 Mdot
.37987 .52578 Mdot
.42626 .43489 Mdot
.48455 .26247 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0/_ooool2o`00
09Gooooo000Looooo`;o0000/oooool2o`0009Gooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0:;ooooo0_l0002Uooooo`00
7?ooool00ol0003oooooooooo`2Iooooo`;o00001oooool2o`000:Gooooo000Looooo`03o`000?oo
oooooooo09Wooooo0_l0002^ooooo`007?ooool00ol0003oooooooooo`2dooooo`;o00002Oooool2
o`0008Sooooo000Looooo`03o`000?oooooooooo09;ooooo0_l0000Pooooo`;o00002Oooool2o`00
08Sooooo000Looooo`03o`000?oooooooooo09;ooooo0_l0000>ooooo`;o00002_ooool2o`0009Wo
oooo000Looooo`03o`000?oooooooooo0:;ooooo0_l00004ooooo`;o00001?ooool2o`0009Wooooo
000Looooo`;o0000WOooool2o`0000Gooooo1?l000000ooooooo0000o`00002Oooooo`007?ooool0
0ol0003oooooooooo`2Looooo`;o00001?ooool7o`0002oooooo0_l0001_ooooo`007?ooool00ol0
003oooooooooo`2Kooooo`;o00000_ooool5o`0000?ooooo0_l0000_ooooo`;o0000Koooool001co
oooo00?o0000ooooooooool0Poooool2o`0001?ooooo0_l000000ooooooo0000o`000002ooooo`Go
0000YOooool001cooooo00?o0000ooooooooool0Poooool2o`0001?ooooo0_l00004ooooo`;o0000
ZOooool001cooooo00?o0000ooooooooool0Toooool2o`0000Sooooo1?l00008ooooo`;o0000W_oo
ool001cooooo00?o0000ooooooooool0Roooool2o`0000;ooooo0ol000000ooooooo0000o`000002
o`0000Kooooo1?l00008ooooo`;o00001_ooool2o`0000?ooooo0_l00008ooooo`;o0000Qoooool0
01cooooo00?o0000ooooooooool0ROooool4o`000003ooooool0003o000000;o00000oooool2o`00
00Kooooo0_l0000Booooo`;o00000oooool2o`0000Sooooo0_l00027ooooo`007?ooool00ol0003o
ooooooooo`26ooooo`;o000000?oooooo`000?l000000oooool2o`0000[ooooo0_l000000ooooooo
0000o`00000>ooooo`;o00001oooool2o`00097ooooo000Looooo`03o`000?oooooooooo07Sooooo
0_l0000<ooooo`;o00001oooool2o`0000Wooooo0_l0000Aooooo`;o00001oooool7o`0008cooooo
000Looooo`03o`000?oooooooooo07Sooooo0_l0000?ooooo`;o00000_ooool4o`0000Gooooo0_l0
000Fooooo`;o000000?oooooo`000?l000001Oooool5o`0000[ooooo0_l00020ooooo`007?ooool0
0ol0003oooooooooo`21ooooo`;o000000?oooooo`000?l000000oooool2o`0000;ooooo0ol00006
ooooo`;o00001Oooool2o`0000oooooo0_l000000ooooooo0000o`000003ooooo`Co00003Oooool2
o`0000Cooooo0_l0001jooooo`007?ooool00ol0003oooooooooo`1looooo`?o00000_ooool2o`00
0003ooooool0003o000000Sooooo0_l00003ooooo`;o00002?ooool2o`0000oooooo0_l00006oooo
o`Co00004_ooool3o`0007[ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44
ooooo`Go00001_ooool00ol0003oooooooooo`1looooo`?o00001Oooool2o`0000gooooo0_l0000B
ooooo`;o00003_ooool2o`0000Kooooo0_l0000;ooooo`;o000000?oooooo`000?l000001Oooool2
o`00077ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1fooooo`Co00000oooool2o`0002Sooooo
0_l000001?oooooo0000o`000?l00002ooooo`;o00001_ooool2o`0000Kooooo0_l0000>ooooo`;o
00001Oooool2o`00077ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo
00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`1fooooo`Co00000oooool2o`0000oooooo
0_l000000ooooooo0000o`00000Gooooo`?o00000_ooool2o`0000kooooo0_l0000Jooooo`;o0000
K?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^
kP06ooooo`?o0000J?ooool2o`0000Wooooo1?l00004ooooo`;o00004Oooool2o`000003ooooool0
003o000000Sooooo0_l0000=ooooo`;o00005_ooool2o`0001Oooooo0_l0001/ooooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000
ooooooooool0J?ooool2o`0000Wooooo1?l000001?oooooo0000o`000?ooool2o`0001Sooooo0_l0
0004ooooo`;o00001?ooool2o`0000Oooooo0_l0000Fooooo`;o000000?oooooo`000?l000000ooo
ool4o`00017ooooo0_l0001Xooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0=
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0N?ooool2o`0001_ooooo1_l00006
ooooo`;o00003?ooool2o`0001Cooooo0_l00002ooooo`Go00004Oooool2o`0006Sooooo00001_oo
ooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`00
0?oooooooooo073ooooo0_l00008ooooo`;o00003?ooool2o`0000;ooooo0_l00006ooooo`;o0000
00?oooooo`000?l000000_l00005ooooo`Co00001_ooool2o`0000;ooooo0ol00004ooooo`?o0000
3Oooool2o`0000;ooooo0_l000000ooooooo0000o`00001kooooo`0000Koooooonk^k_lb<S;o0000
oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1`oooo
o`;o00002?ooool2o`0000_ooooo0ol00002ooooo`;o00001?ooool4o`0000[ooooo1?l00006oooo
o`;o00000_ooool2o`0000Gooooo0ol0000:ooooo`;o000000?oooooo`000?l000000_l00002oooo
o`Go0000NOooool001cooooo00?o0000ooooooooool0Joooool2o`0000?ooooo0_l00005ooooo`;o
00002Oooool2o`0000?ooooo0_l00003ooooo`;o00001?ooool2o`0000Cooooo0_l0000Eooooo`;o
00001_ooool2o`0000Cooooo0_l00003ooooo`;o00000oooool2o`0000;ooooo1Ol0001iooooo`00
7?ooool00ol0003oooooooooo`1Wooooo`;o00000_ooool2o`0000;ooooo0ol00005ooooo`;o0000
2Oooool2o`0000Sooooo0_l00004ooooo`;o00001?ooool5o`0000Oooooo0_l00002ooooo`;o0000
1Oooool2o`0000Gooooo0ol00003ooooo`?o00000oooool2o`0000?ooooo0_l0000<ooooo`;o0000
L_ooool001cooooo00?o0000ooooooooool0Ioooool5o`0000?ooooo0_l0000Aooooo`;o00003_oo
ool2o`0000Gooooo1?l00005ooooo`Co00000_ooool2o`0000cooooo0ol00003ooooo`;o00001?oo
ool6o`0000?ooooo0_l00008ooooo`?o0000LOooool001cooooo00?o0000ooooooooool0H?ooool3
o`0000Gooooo1?l0000Aooooo`;o00004_ooool2o`0000oooooo1?l0000<ooooo`;o00004?ooool4
o`0000?ooooo1?l00007ooooo`;o0000LOooool001cooooo00?o0000ooooooooool0GOooool2o`00
0004ooooool0003o0000o`0001[ooooo0_l0000<ooooo`;o00001?ooool2o`00017ooooo0_l00000
0ooooooo0000o`000009ooooo`Co00000_ooool2o`0000Sooooo0_l00003ooooo`Co00000_ooool3
o`000003ooooool0003o000007Kooooo000Looooo`03o`000?oooooooooo05cooooo0ol0000Noooo
o`;o00003?ooool2o`0001Sooooo1?l00005ooooo`Co00000_ooool6o`0000Gooooo0_l000000ooo
oooo0000o`000002o`000003ooooool0003o000000Co000000Coooooo`000?l0003ooooo0_l0000O
ooooo`;o0000EOooool001cooooo00?o0000ooooooooool0G?ooool3o`0000Kooooo0ol0000Boooo
o`;o000000?oooooo`000?l000000oooool2o`0001Sooooo0_l00007ooooo`;o00000oooool2o`00
00;ooooo1?l00002ooooo`Co00001oooool2o`0000?ooooo1?l000000ooooooo0000o`000002o`00
02Gooooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`1Fooooo`;o00003?ooool5o`0000Co
oooo0_l00003ooooo`;o00001_ooool2o`0000Kooooo0_l0000@ooooo`;o00001_ooool3o`000004
ooooool0003o0000ooooo`Co00000oooool2o`0000Kooooo0_l0000Booooo`;o00000_ooool2o`00
00?ooooo0_l00003ooooo`;o00006?ooool2o`0005Wooooo000Looooo`03o`000?oooooooooo05Ko
oooo0_l0000<ooooo`Go00001?ooool2o`000003ooooool0003o000000;o000000Coooooo`000?l0
003o00001_ooool2o`0000Sooooo0_l0000:ooooo`;o00001oooool2o`000004ooooool0003o0000
ooooo`;o00001oooool5o`000003ooooool0003o000000Cooooo0_l00004ooooo`;o00002_ooool2
o`0000?ooooo0_l00003ooooo`;o00006?ooool2o`0005Wooooo000Looooo`03o`000?oooooooooo
05kooooo0ol00003ooooo`;o00002_ooool2o`0000?ooooo0ol00006ooooo`;o00002?ooool2o`00
00;ooooo0_l00003ooooo`;o00006Oooool7o`0000;ooooo0_l000000ooooooo0000o`000004oooo
o`;o00003oooool2o`0000?ooooo1?l0001aooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o
00002?ooool2o`000003ooooool0003o000000;o000000Coooooo`000?l0003o00003?ooool2o`00
01;ooooo0_l00004ooooo`;o000000?oooooo`000?l000000_l0000Kooooo`Go00000_ooool2o`00
00Cooooo0_l000000ooooooo0000o`000007ooooo`Co000000?oooooo`000?l000001_ooool4o`00
077ooooo000Looooo`;o0000D_ooool2o`0000Sooooo0_l00003ooooo`Oo00002?ooool2o`000003
ooooool0003o000001;ooooo0_l00005ooooo`Ko00003?ooool2o`00017ooooo0_l00007ooooo`Go
00001oooool4o`000004ooooool0003o0000ooooo`;o00000oooool2o`0007?ooooo000Looooo`03
o`000?oooooooooo05Gooooo0_l0000;ooooo`;o000000?oooooo`000?l000000_l00006ooooo`;o
00001?ooool3o`0000[ooooo0_l00009ooooo`;o00003oooool3o`0000_ooooo0ol00003ooooo`Co
00001_ooool2o`0000Wooooo1ol000000ooooooo0000o`000003ooooo`;o00003?ooool2o`0006Go
oooo000Looooo`03o`000?oooooooooo05Gooooo0_l0000@ooooo`;o00002_ooool5o`000003oooo
ool0003o000000Oooooo0_l00005ooooo`;o00004_ooool3o`0000cooooo1Ol000000ooooooo0000
o`000003o`0001;ooooo1Ol0000Cooooo`?o00004_ooool2o`00057ooooo000Looooo`03o`000?oo
oooooooo057ooooo0_l00003ooooo`;o00006oooool2o`0000Cooooo0_l00005ooooo`;o00001ooo
ool2o`00017ooooo1?l0000<ooooo`Go00001?ooool2o`000003ooooool0003o000000[ooooo0_l0
0006ooooo`;o00002Oooool2o`0000Sooooo0_l0000Cooooo`;o0000DOooool001cooooo00?o0000
ooooooooool0DOooool2o`000003ooooool0003o000000;o00002Oooool2o`0000cooooo0_l0000?
ooooo`;o00002Oooool2o`0000Gooooo0_l000001?oooooo0000o`000?ooool8o`00013ooooo0_l0
0006ooooo`Co00002?ooool2o`0000Cooooo0_l0000;ooooo`;o00000_ooool2o`0000Cooooo0_l0
001Vooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o00002oooool2o`0000cooooo0_l00002
ooooo`;o00001oooool3o`000003ooooool0003o000000Wooooo0_l000001?oooooo0000o`000?oo
ool3o`000004ooooool0003o0000ooooo`Ko00002_ooool2o`0000Kooooo1?l00006ooooo`;o0000
1oooool5o`0000;ooooo0_l0000?ooooo`?o00000oooool3o`0000Cooooo0_l0001Oooooo`007?oo
ool00ol0003oooooooooo`18ooooo`;o00002_ooool2o`0001gooooo0_l00007ooooo`?o00003ooo
ool2o`000003ooooool0003o000000Cooooo0ol0000>ooooo`;o00001Oooool2o`000003ooooool0
003o000000Kooooo0_l00007ooooo`Go00000_ooool2o`00013ooooo0_l000001?oooooo0000o`00
0?ooool4o`0000;ooooo0_l0001Oooooo`007?ooool00ol0003oooooooooo`17ooooo`?o00000_oo
ool2o`0000Kooooo0_l00005ooooo`;o00001?ooool2o`0001?ooooo0_l00002ooooo`;o00001?oo
ool2o`00017ooooo0_l00002ooooo`;o000000?oooooo`000?l000002oooool2o`0000Kooooo0_l0
000Iooooo`;o00004oooool2o`0000?ooooo0_l0001Sooooo`007?ooool00ol0003oooooooooo`16
ooooo`?o00000oooool2o`0000Kooooo0_l00005ooooo`;o00001?ooool2o`0001?ooooo0_l00002
ooooo`So00002oooool8o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o000000?ooooo
o`000?l000001?ooool2o`0001;ooooo0_l00008ooooo`;o000000Coooooo`000?l0003o00001?oo
ool2o`0001?ooooo0_l0001Sooooo`007?ooool00ol0003oooooooooo`16ooooo`;o00001oooool2
o`0000[ooooo0_l00003ooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`;o00002?oo
ool4o`000003ooooool0003o000000;o00003Oooool8o`0000Wooooo1ol0000Fooooo`;o00002?oo
ool2o`000003ooooool0003o000000;o00000_ooool5o`0000kooooo0_l000000ooooooo0000o`00
0004o`0005oooooo000Looooo`03o`000?oooooooooo04Gooooo0_l00008ooooo`Co00003Oooool2
o`0000Gooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000Gooooo1?l0
000Aooooo`?o00000_ooool4o`0000Kooooo0_l00003ooooo`;o000000?oooooo`000?l000007Ooo
ool2o`0000Kooooo1_l000000ooooooo0000o`00000;ooooo`;o000000?oooooo`000?l000000ooo
ool4o`0005oooooo000Looooo`03o`000?oooooooooo04?ooooo1?l00007ooooo`;o000000?ooooo
o`000?l000000_l0000Booooo`;o00001oooool2o`000003ooooool0003o000000;ooooo0_l00002
ooooo`;o00000oooool2o`0000?ooooo0_l00004ooooo`?o000000?oooooo`000?l000000_l00007
ooooo`?o00006_ooool2o`0000Wooooo0_l00006ooooo`Co00001Oooool4o`0000Oooooo0_l0000:
ooooo`;o0000GOooool001cooooo00?o0000ooooooooool0@oooool2o`0000Oooooo1?l00003oooo
o`;o00004_ooool2o`000003ooooool0003o000000Ko000000?oooooo`000?l000000_ooool8o`00
0003ooooool0003o000000;o000000?oooooo`000?l000001?ooool2o`0000;ooooo0_l00009oooo
o`;o00001Oooool3o`000003ooooool0003o000000;o00001?ooool2o`0000Sooooo0_l0000?oooo
o`;o00001_ooool2o`000003ooooool0003o000000;o00001_ooool2o`0000Gooooo0_l00002oooo
o`Co0000GOooool001cooooo00?o0000ooooooooool0C?ooool2o`0000Kooooo0_l0000@ooooo`;o
00000_ooool6o`0000?ooooo0_l00004ooooo`_o00001oooool2o`0000?ooooo0_l0000?ooooo`So
00001?ooool4o`0001Oooooo0_l00006ooooo`;o00000_ooool2o`0000Oooooo0_l00005ooooo`;o
00000_ooool2o`0005oooooo000Looooo`03o`000?oooooooooo03cooooo0_l0000<ooooo`;o0000
2?ooool2o`0000?ooooo0_l00009ooooo`Co00005Oooool5o`0000;ooooo0_l00005ooooo`Co0000
00?oooooo`000?l000002?ooool2o`0000Sooooo0_l000001?oooooo0000o`000?ooool2o`0000?o
oooo0_l0000?ooooo`;o000000?oooooo`000?l000002oooool2o`0000;ooooo0_l00002ooooo`;o
0000Koooool001cooooo00?o0000ooooooooool0??ooool2o`000003ooooool0003o000000;ooooo
0_l00005ooooo`;o00003Oooool2o`0000?ooooo1Ol000001?oooooo0000o`000?ooool2o`000003
ooooool0003o000000Oooooo0_l0000;ooooo`Ko00001_ooool3o`0000_ooooo0_l0000;ooooo`;o
000000?oooooo`000?l000000oooool2o`0000Cooooo0_l00009ooooo`;o000000?oooooo`000?l0
00001_ooool2o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000002Oooool2o`0000ko
oooo0_l0001Dooooo`007?ooool2o`00043ooooo0_l00002ooooo`;o00002_ooool2o`0000gooooo
1Ol00004ooooo`Go00001oooool2o`0000Gooooo0_l00005ooooo`Go0000;oooool2o`0000_ooooo
0_l00003ooooo`;o00000_ooool4o`0000Kooooo1?l0000:ooooo`;o00003_ooool2o`0005Cooooo
000Looooo`03o`000?oooooooooo04oooooo0_l000000ooooooo0000o`00000:ooooo`Co00001ooo
ool2o`0000oooooo0_l00008ooooo`;o00000_ooool4o`000004ooooool0003o0000ooooo`;o0000
3?ooool2o`0000;ooooo0_l0000?ooooo`;o00002oooool4o`0000?ooooo0_l00002ooooo`Go0000
00Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000006ooooo`;o00005Oooool2o`00057o
oooo000Looooo`03o`000?oooooooooo05;ooooo0ol00009ooooo`;o00001_ooool2o`0000;ooooo
0_l0000>ooooo`;o00001Oooool2o`0000Gooooo1?l000001?oooooo0000o`000?ooool2o`0000[o
oooo1?l00002ooooo`;o00002oooool2o`0000;ooooo0_l0000;ooooo`Co00001oooool2o`000004
ooooool0003o0000ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Cooooo0_l00009oooo
o`;o00001?ooool2o`00057ooooo000Looooo`03o`000?oooooooooo03gooooo0_l00002ooooo`;o
00004?ooool2o`0000Kooooo0_l00004ooooo`;o000000?oooooo`000?l000000_l000001?oooooo
0000o`000?l00007ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00000_ooool2o`00
00gooooo0ol00007ooooo`;o00001oooool2o`0000;ooooo0_l0000Fooooo`;o00005oooool5o`00
00Oooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00000_ooool2o`0000Co
oooo1?l0000;ooooo`;o00000oooool2o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`;o
00002?ooool2o`00017ooooo0_l000000ooooooo0000o`000002ooooo`;o00003_ooool2o`0000Oo
oooo0_l0000Fooooo`;o00001Oooool2o`0000Cooooo0_l00005ooooo`;o00001oooool2o`0000Oo
oooo0_l000000ooooooo0000o`00001Pooooo`007?ooool00ol0003oooooooooo`17ooooo`Co0000
2?ooool2o`000003ooooool0003o000000kooooo0_l00007ooooo`;o00000oooool2o`000004oooo
ool0003o0000o`0000cooooo0_l000000ooooooo0000o`00000Gooooo`;o00000_ooool2o`0001Ko
oooo0_l00005ooooo`;o00001?ooool2o`0000Gooooo1?l00005ooooo`;o00004?ooool2o`0000Wo
oooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00000_ooool2o`0000Sooooo
0_l00002ooooo`;o00003Oooool4o`0000Gooooo0_l000000ooooooo0000o`000002o`000004oooo
ool0003o0000o`0000Kooooo0_l00003ooooo`?o00002?ooool2o`0000kooooo1Ol00005ooooo`;o
00000_ooool2o`0000Wooooo0_l00003ooooo`;o00003_ooool4o`0000;ooooo0_l0000Gooooo`;o
00002Oooool2o`0000;ooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`0booooo`;o0000
3oooool4o`0000;ooooo0ol00002ooooo`;o00001_ooool3o`0000Cooooo1?l00006ooooo`?o0000
2?ooool2o`0000cooooo0ol00002ooooo`;o00002?ooool3o`0000Wooooo0_l00003ooooo`;o0000
00Coooooo`000?l0003ooooo0_l00002ooooo`;o00000_ooool2o`0000Wooooo0_l00002ooooo`Co
00001oooool2o`0000Cooooo1Ol0000;ooooo`;o00000_ooool2o`0001Gooooo0_l000000ooooooo
0000o`00001;ooooo`007?ooool00ol0003oooooooooo`0booooo`;o00003_ooool3o`0000Cooooo
1?l000000ooooooo0000o`000006ooooo`;o00001Oooool4o`0001Wooooo1?l00002ooooo`?o0000
3?ooool2o`0000[ooooo0_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l00000
1_ooool2o`0000;ooooo0_l00005ooooo`So00001oooool2o`0000Oooooo0_l00005ooooo`;o0000
0_ooool4o`0000;ooooo0_l00004ooooo`?o00003?ooool4o`000003ooooool0003o000000Sooooo
0_l00011ooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00001Oooool4o`0000Gooooo0_l0
000Vooooo`Co00003?ooool2o`0000Cooooo0_l00007ooooo`;o00000oooool2o`0000kooooo0_l0
00001Ooooooo0000o`000?l0003ooooo00?o000000?oooooo`000?l000001?l0000<ooooo`;o0000
2oooool2o`0000;ooooo0_l0000:ooooo`?o00003?ooool2o`0000;ooooo0ol00008ooooo`;o0000
@Oooool001cooooo00?o0000ooooooooool0@_ooool4o`0000cooooo1?l0000Rooooo`Co00000ooo
ool2o`0000Kooooo1Ol000001?oooooo0000o`000?ooool2o`0000Oooooo0_l0000Fooooo`ko0000
00?oooooo`000?l000000_ooool2o`0000Gooooo0_l00009ooooo`;o00002Oooool2o`0001Sooooo
0_l0001<ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00003Oooool3o`0002;ooooo1?l0
0002ooooo`?o00001_ooool5o`000003ooooool0003o000000;o00003_ooool2o`0000?ooooo1Ol0
0004ooooo`;o000000Coooooo`000?l0003ooooo2ol000000ooooooo0000o`000005o`0000Oooooo
0ol00006ooooo`?o00002?ooool2o`0000[ooooo0_l00009ooooo`;o00000_ooool2o`0004_ooooo
000Looooo`03o`000?oooooooooo04;ooooo0_l00004ooooo`Co00001oooool2o`0002?ooooo2?l0
0007ooooo`;o000000?oooooo`000?l000000oooool2o`0000kooooo0_l00003ooooo`Go00001?oo
ool5o`000003ooooool0003o000000Wo000000?oooooo`000?l000001?l00002ooooo`;o00001?oo
ool3o`0000Oooooo0_l00005ooooo`;o000000?oooooo`000?l000002_ooool2o`0000Sooooo0ol0
0002ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0=_ooool2o`0000[ooooo0_l00004
ooooo`Co00002?ooool2o`0001Cooooo0_l00002ooooo`;o00002?ooool2o`000003ooooool0003o
000000;o00001_ooool4o`0000?ooooo0_l0000Jooooo`;o000000?oooooo`000?l000005Ol00005
ooooo`;o00001?ooool2o`0000?ooooo0_l0000:ooooo`;o000000Coooooo`000?l0003o00004ooo
ool2o`000003ooooool0003o000000kooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0f
ooooo`;o00001Oooool2o`0001Gooooo0_l000000ooooooo0000o`000002o`0000Sooooo0_l00005
ooooo`;o00000_ooool2o`0000Kooooo0_l00004ooooo`So000000?oooooo`000?l000001Oooool2
o`0000Gooooo0_l0000=ooooo`;o00001?ooool2o`000003ooooool0003o0000013o000000?ooooo
o`000?l000000ol0000:ooooo`;o00000oooool2o`0000kooooo0_l00008ooooo`?o00001?ooool2
o`0000Gooooo0_l00005ooooo`;o00001oooool2o`0003gooooo000Looooo`03o`000?oooooooooo
03gooooo1ol0000@ooooo`;o000000?oooooo`000?l000000_l00002ooooo`?o00000oooool2o`00
00Kooooo0_l00009ooooo`;o00001?ooool;o`0000cooooo0_l00003ooooo`;o00001Oooool2o`00
0003ooooool0003o000000[ooooo5ol00007ooooo`;o00004?ooool2o`0000Cooooo0_l00006oooo
o`?o00001?ooool4o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0004Kooooo000Loooo
o`;o0000?oooool6o`0000Kooooo0_l000000ooooooo0000o`000005ooooo`Co00001Oooool3o`00
00?ooooo0_l00006ooooo`?o00001_ooool2o`0000Gooooo3ol00008ooooo`;o00001?ooool4o`00
00?ooooo0_l00006ooooo`;o00000oooool4o`000003ooooool0003o000001;o00001oooool2o`00
00cooooo0_l00002ooooo`;o00001?ooool2o`0000[ooooo0_l00003ooooo`;o000000Coooooo`00
0?l0003ooooo0_l000000ooooooo0000o`000019ooooo`007?ooool00ol0003oooooooooo`1:oooo
o`;o000000?oooooo`000?l000001Oooool4o`0000Kooooo0_l00003ooooo`;o00001oooool2o`00
00Kooooo0_l00004oooooa;o00001_ooool2o`000003ooooool0003o000000?ooooo0_l0000;oooo
o`;o000000?oooooo`000?l000000ol000000ooooooo0000o`00000Eo`000003ooooool0003o0000
013ooooo0_l0000Dooooo`;o00001_ooool2o`000003ooooool0003o000000kooooo0_l0000loooo
o`007?ooool00ol0003oooooooooo`1Rooooo`;o00004_oooolFo`0000;ooooo0_l00005ooooo`;o
00004ooooolMo`000004ooooool0003o0000o`0000[ooooo0_l00003ooooo`;o00002_ooool2o`00
00;ooooo0_l0000Aooooo`;o00003?ooool2o`0003cooooo000Looooo`03o`000?oooooooooo04_o
oooo0_l0000<ooooo`;o00001oooool2o`0001;ooooo2?l000000ooooooo0000o`00000:o`0000?o
oooo0_l00007ooooo`;o00000_ooool2o`0000oooooo6ol00002ooooo`;o00001Oooool2o`0000?o
oooo0_l00003ooooo`;o00002?ooool4o`0000;ooooo0_l00005ooooo`;o00000oooool2o`0000Go
oooo0_l00007ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0B_ooool3o`0000Oooooo
0_l00003ooooo`;o00003?ooool2o`0000gooooo1ol00002ooooo`co00003?ooool2o`0000;ooooo
0_l0000@oooooa[o00002Oooool6o`0000Cooooo0_l00004ooooo`;o000000Coooooo`000?l0003o
00002oooool2o`0000?ooooo0_l0000>ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0
>_ooool2o`000003ooooool0003o000000;o00001oooool5o`0000Oooooo0_l0000Aooooo`;o0000
3OoooolFo`0000Cooooo0_l00009ooooo`;o00000oooool2o`0000gooooo2_l000000ooooooo0000
o`00000;o`0000[ooooo1Ol00006ooooo`;o00000_ooool5o`000004ooooool0003o0000ooooo`;o
0000G_ooool001cooooo00?o0000ooooooooool0>_ooool2o`000003ooooool0003o000000;o0000
1oooool2o`000003ooooool0003o000000oooooo0_l0000HoooooaKo00001?ooool2o`0000kooooo
0_l0000=oooooa[o00004oooool4o`000004ooooool0003o0000o`0000;ooooo0_l000000ooooooo
0000o`00000;ooooo`;o0000DOooool001cooooo00?o0000ooooooooool0>_ooool2o`0001;ooooo
0_l0000<ooooo`;o00004?ooool2o`0000Kooooo6?l00002ooooo`;o00002oooool2o`0000;ooooo
0_l00003ooooo`;o00001ooooolJo`0001Gooooo0_l00002ooooo`;o00000_ooool4o`0000Gooooo
0ol00004ooooo`Co00000oooool2o`0000?ooooo0_l00015ooooo`007?ooool00ol0003ooooooooo
o`1=ooooo`?o00001?ooool2o`0000Cooooo1?l0000@ooooo`;o00001_oooolHo`0000;ooooo0_l0
000;ooooo`;o00000_ooool2o`0000?ooooo0_l00005oooooago00002oooool2o`00013ooooo0ol0
0005ooooo`?o00001_ooool2o`0000?ooooo0_l00003ooooo`;o00001?ooool2o`0003oooooo000L
ooooo`03o`000?oooooooooo03Sooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l00005
ooooo`;o00001?ooool2o`0001Wooooo3_l00002ooooo`Wo00003_ooool2o`0000?ooooo0_l00000
0ooooooo0000o`000007oooooago00002oooool2o`0000_ooooo1?l000001?oooooo0000o`000?l0
000;ooooo`Co00003oooool5o`0003cooooo000Looooo`03o`000?oooooooooo03Kooooo1?l00004
ooooo`?o00001Oooool2o`0000Gooooo0_l00005ooooo`;o000000?oooooo`000?l000000_ooool2
o`0000Oooooo0_l00007ooooo`;o00001?ooool;o`0000;ooooo3Ol00006ooooo`?o00001_ooool2
o`0000?ooooo0_l000000ooooooo0000o`000007ooooo`Co00000_ooool=o`000003ooooool0003o
000000Go00001Oooool3o`0001;ooooo1?l00002ooooo`;o00002oooool4o`0000[ooooo0_l00004
ooooo`Co0000??ooool001cooooo00?o0000ooooooooool0<oooool2o`000003ooooool0003o0000
00Kooooo0_l00003ooooo`;o00001?ooool2o`000003ooooool0003o000000?ooooo1?l00002oooo
o`;o00000_ooool2o`0000Oooooo0_l00007ooooo`;o00001?ooool;o`000003ooooool0003o0000
00co00001_ooool5o`0000Cooooo0ol0000CoooooaKo00001Oooool3o`0001oooooo0_l0000Boooo
o`;o000000?oooooo`000?l00000@Oooool001cooooo00?o0000ooooooooool0<oooool2o`0000_o
oooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000000oooool4o`0001ko
oooo6ol00003ooooo`;o00000oooool2o`0000;ooooo1Ol0000AoooooaSo00009oooool2o`0000;o
oooo0_l0000Aooooo`;o00000oooool2o`0003cooooo000Looooo`03o`000?oooooooooo03[ooooo
0_l00004ooooo`;o00001Oooool4o`0000;ooooo0_l00003ooooo`;o00000oooool2o`0000Oooooo
0_l0000<ooooo`Ko000000?oooooo`000?l000005ol00003ooooo`;o000000?oooooo`000?l00000
1?ooool2o`0001Cooooo0ol000000ooooooo0000o`00000Ao`0000Cooooo0_l000001?oooooo0000
o`000?l0000Rooooo`;o00005_ooool2o`0003cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^
kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0doooo
o`;o00001?ooool3o`0000Wooooo0ol00004ooooo`;o00002?ooool2o`0000Oooooo1?l00002oooo
o`;o00001_ooool6o`000003ooooool0003o000000[o00000_ooool;o`0000Kooooo0_l0000Ooooo
oaCo00000_ooool2o`000004ooooool0003o0000o`0002;ooooo0_l00003ooooo`;o00002_ooool2
o`0004?ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0=?ooool2o`0000Cooooo0ol00009ooooo`;o00002Ooo
ool2o`0000oooooo0_l00002ooooo`Co000000Coooooo`000?l0003ooooo0_l00005oooooa_o0000
00Coooooo`000?l0003ooooo0_l00008ooooo`;o00004_ooool7o`000003ooooool0003o000000go
00002oooool2o`0001Kooooo0_l00005ooooo`;o00000oooool2o`0000Cooooo0_l000001?oooooo
0000o`000?ooool4o`00047ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wo
oooo1Ol00006ooooo`03o`000?oooooooooo03Gooooo0_l00004ooooo`;o00001Oooool4o`0000_o
oooo0_l0000Eooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooob7o000000?oooooo`00
0?l000002?ooool2o`0001;ooooo1?l000000ooooooo0000o`00000>o`0000?ooooo0_l00008oooo
o`;o00005_ooool2o`0000Oooooo0_l00007ooooo`;o000000?oooooo`000?l000000oooool2o`00
047ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoo
oooo00001oooool3o`0003Gooooo1?l00005ooooo`So00002_ooool2o`0001gooooo8?l000000ooo
oooo0000o`000008ooooo`;o000000?oooooo`000?l000001?ooool2o`0001?ooooo3?l000000ooo
oooo0000o`000003ooooo`Co00001_ooool3o`0000[ooooo0_l000001?oooooo0000o`000?l0000>
ooooo`;o00000_ooool2o`0004kooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`0gooooo`;o00001?ooool5
o`0000cooooo1?l0000Mooooo`?o000000?oooooo`000?l000006_l0000;ooooo`;o000000?ooooo
o`000?l000001?ooool2o`0001;ooooo3?l00002ooooo`;o00001Oooool2o`0000Oooooo0_l00002
ooooo`;o00001_ooool2o`000004ooooool0003o0000o`0001;ooooo1?l00008ooooo`;o0000@_oo
ool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00omgMgOoc<c<o`000007
ooooo`03o`000?oooooooooo03gooooo0_l00002ooooo`;o00002oooool4o`0000_ooooo0_l00006
ooooo`Co000000?oooooo`000?l000001OoooolHo`0000?ooooo0ol00008ooooo`;o00005?ooool2
o`0000;ooooo0_l00004ooooo`So000000?oooooo`000?l000000_l00003ooooo`?o00001?ooool3
o`0000Sooooo0_l0000Pooooo`;o00001?ooool2o`0000;ooooo0_l00012ooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0=ooo
ool2o`0000Kooooo1?l00003ooooo`;o00002?ooool2o`0000_ooooo0_l00006ooooo`Oo00001Ooo
oolEo`000003ooooool0003o000000Ko00002?ooool2o`00017ooooo0_l000000ooooooo0000o`00
0004o`0000Cooooo2?l000000ooooooo0000o`000002o`0000?ooooo0ol00004ooooo`?o00000ooo
ool2o`0000Gooooo1?l00006ooooo`;o00001Oooool2o`0001?ooooo0ol0000<ooooo`;o0000=ooo
ool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`00
0?oooooooooo02kooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l000000ooooooo0000
o`000005ooooo`;o00000oooool2o`0000Sooooo0_l0000Aooooo`?o00001ooooolMo`0001_ooooo
0_l00003ooooo`;o00001_ooool6o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l00000
0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l00005ooooo`Co00001_ooool2o`0000Go
oooo0_l0000Dooooo`?o00001Oooool2o`0000Cooooo0_l00002ooooo`;o0000<oooool001cooooo
00?o0000ooooooooool08?ooool2o`0000cooooo0_l00002ooooo`?o00001oooool2o`0000Kooooo
0_l00005ooooo`Ko00001?ooool2o`0000Cooooo0_l0000;ooooo`;o00002?oooolIo`0001kooooo
0_l0000?ooooo`;o00000oooool2o`0000Cooooo0_l000000ooooooo0000o`000002o`0000Gooooo
0_l0000;ooooo`;o00004oooool2o`0000kooooo0_l000000ooooooo0000o`000002ooooo`;o0000
2?ooool2o`0003?ooooo000Looooo`03o`000?oooooooooo023ooooo0_l0000@ooooo`Co00003_oo
ool2o`0000Oooooo1?l0000:ooooo`;o00005_oooolBo`000003ooooool0003o000000;o00005?oo
ool2o`0000Kooooo0_l000000ooooooo0000o`00000?ooooo`;o000000?oooooo`000?l000005?oo
ool2o`0000Wooooo1Ol0000>ooooo`Co00001oooool2o`0000Kooooo1?l0000<ooooo`;o0000<ooo
ool001cooooo00?o0000ooooooooool0=?ooool2o`0000Oooooo0_l00005ooooo`;o00001oooool4
o`0001Wooooo0_l00004ooooo`;o00000ooooolCo`000003ooooool0003o000000Oooooo1?l00008
ooooo`;o00001_ooool2o`0000;ooooo0_l00002ooooo`;o00003Oooool2o`0001Cooooo0_l0000:
ooooo`Co00003_ooool3o`0000Gooooo0_l000000ooooooo0000o`000006ooooo`;o00003_ooool2
o`0003?ooooo000Looooo`03o`000?oooooooooo03_ooooo1Ol00004ooooo`;o00001oooool4o`00
00Kooooo0_l0000Aooooo`?o00000oooool2o`0000;ooooo5?l000000ooooooo0000o`000007oooo
o`Co00002_ooool4o`0000Kooooo0_l00002ooooo`;o00000oooool2o`0000Sooooo1?l00009oooo
o`?o00003_ooool2o`0000;ooooo0_l00002ooooo`Co00003?ooool2o`0000Cooooo0_l00007oooo
o`;o00000oooool2o`0000Cooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`0kooooo`;o
000000?oooooo`000?l000005oooool2o`0000kooooo0_l00002ooooo`;o00001ooooolCo`000004
ooooool0003o0000o`0001Gooooo1?l00006ooooo`;o00000oooool2o`0000;ooooo0ol00006oooo
o`Go000000?oooooo`000?l000000_l00004ooooo`?o00003_ooool2o`0000Kooooo1?l0000<oooo
o`;o00001oooool2o`0000Cooooo1?l000000ooooooo0000o`000004ooooo`;o000000?oooooo`00
0?l00000=oooool001cooooo00?o0000ooooooooool0<Oooool2o`0001oooooo0_l0000Cooooo`;o
00002oooool2o`0000;ooooo3ol000001?oooooo0000o`000?l0000Eooooo`;o00003Oooool2o`00
0003ooooool0003o000000;o00000oooool2o`000003ooooool0003o000000;o00000_ooool5o`00
00[ooooo0_l000000ooooooo0000o`000004ooooo`?o00002?ooool2o`0000Sooooo0_l00008oooo
o`;o000000?oooooo`000?l000001_ooool2o`0000[ooooo0_l0000gooooo`007?ooool00ol0003o
ooooooooo`0aooooo`;o00002?ooool2o`0001Gooooo0_l0000Pooooo`;o00000_ooool7o`000003
ooooool0003o000000?o00000_ooool2o`0000oooooo0_l0000Hooooo`;o00000oooool4o`0000?o
oooo0ol00004ooooo`Co000000?oooooo`000?l000000_l00003ooooo`;o000000?oooooo`000?l0
00001?ooool3o`0000_ooooo0_l00004ooooo`?o00002?ooool4o`0000gooooo0_l0000mooooo`00
7?ooool00ol0003oooooooooo`0jooooo`?o00005Oooool2o`0001Sooooo0_l00006ooooo`Co0000
00Coooooo`000?l0003ooooo0_l00009ooooo`;o00002oooool2o`000004ooooool0003o0000o`00
01Sooooo0_l000000ooooooo0000o`000002o`0000Kooooo0ol00003ooooo`Co000000?oooooo`00
0?l000000_l00006ooooo`;o00001?ooool2o`0000Oooooo0_l00003ooooo`;o00001?ooool2o`00
00[ooooo1?l0000<ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0>_ooool2o`0000oo
oooo0_l000000ooooooo0000o`00000Jooooo`Co00000_ooool2o`0000?ooooo1Ol0000Dooooo`?o
00000oooool2o`000003ooooool0003o000001cooooo0_l00006ooooo`;o000000?oooooo`000?l0
00002_ooool2o`0001Gooooo0_l00007ooooo`;o00003?ooool7o`000003ooooool0003o000004Go
oooo000Looooo`03o`000?oooooooooo04_ooooo0_l000000ooooooo0000o`000002o`0000Wooooo
0_l0000=ooooo`;o00001?ooool2o`0000Kooooo0_l0000;ooooo`;o00001oooool6o`0000?ooooo
0_l0000Jooooo`;o00002?ooool2o`000003ooooool0003o000000;o00002?ooool2o`0001kooooo
0ol00004ooooo`;o00001oooool5o`000003ooooool0003o000000[ooooo0_l0000iooooo`007?oo
ool00ol0003oooooooooo`0booooo`;o00000oooool2o`0000Gooooo0_l00005ooooo`;o00001Ooo
ool2o`0000;ooooo0_l00009ooooo`?o00001oooool2o`0000Oooooo0_l00003ooooo`;o00004?oo
ool2o`0000Wooooo1Ol00002ooooo`;o00004oooool3o`0000;ooooo1?l0000;ooooo`Co00001ooo
ool3o`0000Oooooo0_l0000Eooooo`Co00000oooool2o`0000Oooooo0_l00003ooooo`;o000000?o
ooooo`000?l000002?ooool2o`0003Wooooo000Looooo`;o0000<_ooool3o`000003ooooool0003o
000000;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00003?ooool4o`0000Oooooo0_l00007
ooooo`;o00000_ooool3o`0001Kooooo1?l000001?oooooo0000o`000?ooool2o`0000Sooooo0_l0
0007ooooo`;o00000oooool9o`0000?ooooo0_l0000Booooo`Go00001Oooool2o`0000gooooo0_l0
0008ooooo`;o00003_ooool2o`000004ooooool0003o0000ooooo`;o00001oooool2o`0003[ooooo
000Looooo`03o`000?oooooooooo037ooooo0_l00002ooooo`;o00008oooool2o`0000Oooooo0_l0
0007ooooo`;o00001?ooool2o`0000Sooooo1?l00006ooooo`;o00000oooool4o`0000Sooooo0_l0
0004ooooo`;o00001oooool2o`0000?ooooo0_l000000ooooooo0000o`000004o`0000?ooooo0_l0
000?ooooo`;o000000?oooooo`000?l000000ol00005ooooo`;o00000_ooool2o`0000Wooooo0_l0
0002ooooo`;o00001?ooool2o`0000gooooo0ol00004ooooo`;o00001oooool2o`0003[ooooo000L
ooooo`03o`000?oooooooooo04Oooooo0_l0000Jooooo`;o00001oooool2o`0000kooooo1?l00006
ooooo`;o00000oooool2o`0000[ooooo1?l0000?ooooo`?o00000_ooool5o`0000?ooooo0_l0000?
ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00000_ooool2o`0000;ooooo0_l0000=
ooooo`;o00001?ooool2o`0000Cooooo0_l00007ooooo`Wo0000@oooool001cooooo00?o0000oooo
ooooool0A?ooool2o`000003ooooool0003o000000Cooooo0_l00006ooooo`;o00003?ooool2o`00
00Sooooo0_l00009ooooo`;o00000_ooool2o`000003ooooool0003o000000[ooooo0_l0000<oooo
o`;o00001Oooool2o`0000Cooooo0_l000001?oooooo0000o`000?l00003ooooo`Go00007Oooool2
o`0000Cooooo0_l0000@ooooo`;o00002Oooool2o`0000;ooooo0_l00005ooooo`Ko0000A?ooool0
01cooooo00?o0000ooooooooool0=Oooool2o`0000[ooooo0_l000000ooooooo0000o`000002oooo
o`;o00000oooool2o`000003ooooool0003o000000?ooooo0_l0000<ooooo`;o00000_ooool2o`00
00Cooooo0ol00008ooooo`;o00000_ooool2o`000003ooooool0003o000001;ooooo0_l0000;oooo
o`;o00001?ooool2o`000003ooooool0003o000000;o00000_ooool2o`0000Wooooo0_l0000Ioooo
o`Go00000_ooool2o`0000_ooooo1?l000000ooooooo0000o`000008ooooo`;o00000_ooool2o`00
00cooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0eooooo`;o00002_ooool3o`0000Co
oooo0_l00005ooooo`?o00005Oooool2o`0000Gooooo0_l0000Gooooo`;o00002_ooool2o`0000[o
oooo0_l000000ooooooo0000o`000007ooooo`;o00003Oooool2o`0001Cooooo0_l000000ooooooo
0000o`000009o`0000Gooooo0_l000000ooooooo0000o`000003ooooo`;o000000Coooooo`000?l0
003o00002?ooool5o`0000Gooooo0_l00005ooooo`;o00001oooool2o`0003Cooooo000Looooo`03
o`000?oooooooooo03Gooooo0_l00006ooooo`So00000oooool2o`0000Gooooo0_l00003ooooo`Co
00001?ooool2o`0002Cooooo0_l00003ooooo`;o000000?oooooo`000?l000002_ooool2o`0000Oo
oooo0_l000000ooooooo0000o`000003ooooo`;o00001oooool2o`0001kooooo0_l000000ooooooo
0000o`000003o`0000;ooooo1Ol00004ooooo`;o000000?oooooo`000?l000001oooool4o`0000Co
oooo1Ol00007ooooo`Co00003?ooool2o`0003Cooooo000Looooo`03o`000?oooooooooo03Cooooo
0ol000000ooooooo0000o`000003ooooo`Co00000_ooool3o`0000;ooooo0_l00002ooooo`?o0000
1Oooool4o`0000Cooooo0ol0000Mooooo`;o00001?ooool3o`0000?ooooo1?l0000:ooooo`;o0000
2?ooool2o`0000?ooooo1ol00004ooooo`;o00001_ooool2o`0000[ooooo0_l00005ooooo`;o0000
2?ooool2o`0000Kooooo0ol0000>ooooo`Go00001?ooool2o`0000cooooo0_l00012ooooo`007?oo
ool00ol0003oooooooooo`0dooooo`;o00000_ooool2o`0000Oooooo1Ol00002ooooo`;o00000_oo
ool3o`0000Gooooo0ol00005ooooo`?o000000?oooooo`000?l000006Oooool3o`0000Gooooo0_l0
0003ooooo`;o00003?ooool2o`0000Kooooo1?l00003ooooo`;o00000_ooool3o`0000cooooo0_l0
000:ooooo`;o00001Oooool2o`0000Gooooo0_l00002ooooo`Ko00000_ooool2o`0000kooooo0_l0
0003ooooo`;o000000?oooooo`000?l000003_ooool3o`00043ooooo000Looooo`03o`000?oooooo
oooo047ooooo0_l00004ooooo`;o00001_ooool2o`000004ooooool0003o0000ooooo`Ko00001Ooo
ool2o`000003ooooool0003o000000oooooo0_l00005ooooo`;o00005_ooool2o`000004ooooool0
003o0000o`0000Gooooo0_l00007ooooo`;o00002_ooool2o`0001;ooooo0_l000001?oooooo0000
o`000?l00002ooooo`Go00000_ooool6o`0000?ooooo0_l00006ooooo`;o00001Oooool2o`0000?o
oooo0_l000000ooooooo0000o`00000;ooooo`;o000000Coooooo`000?l0003o0000@?ooool001co
oooo00?o0000ooooooooool0Aoooool2o`0000Kooooo0_l000000ooooooo0000o`000002ooooo`Oo
00001_ooool2o`0000gooooo1?l00003ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Co
oooo0_l00004ooooo`Ko00002oooool2o`000003ooooool0003o000000Cooooo0_l00004ooooo`;o
00002Oooool2o`0000Gooooo1?l000001?oooooo0000o`000?l00002oooooa;o000000Coooooo`00
0?l0003o00000_ooool2o`0000Gooooo1?l00002ooooo`;o00003Oooool2o`0004Cooooo000Loooo
o`03o`000?oooooooooo03Oooooo0_l00008ooooo`;o00000oooool2o`0000[ooooo0_l00004oooo
o`;o000000?oooooo`000?l000000_ooool2o`0000[ooooo0_l00005ooooo`;o00001?ooool6o`00
00;ooooo0ol00004ooooo`;o00001?ooool2o`0000Gooooo0_l0000>ooooo`;o00000oooool6o`00
00Wooooo0_l00002ooooo`Ko00000oooool2o`0000Cooooo1ol000000ooooooo0000o`00000<o`00
0004ooooool0003o0000o`0000Kooooo0_l00003ooooo`;o00000_ooool3o`0005;ooooo000Loooo
o`03o`000?oooooooooo03Cooooo0_l000000ooooooo0000o`000008ooooo`;o00000oooool2o`00
013ooooo0_l00005ooooo`;o00002_ooool2o`0000Gooooo1?l00002ooooo`Co00001?ooool3o`00
01Cooooo0_l0000;ooooo`;o00000oooool5o`0000[ooooo0_l00002ooooo`;o00000_ooool4o`00
00Sooooo1_l000000ooooooo0000o`00000Ao`0000?ooooo1_l00006ooooo`;o0000D_ooool001co
oooo00?o0000ooooooooool0<Oooool2o`000003ooooool0003o000000;ooooo0_l00007ooooo`;o
00000oooool3o`0000Sooooo0_l00005ooooo`;o000000?oooooo`000?l000004oooool6o`0000oo
oooo1?l0000>ooooo`;o0000:Oooool2o`0000?ooooo0_l00004oooooa_o000000Goooooo`000?l0
003o0000ooooo`03o`0002;ooooo0_l0000eooooo`007?ooool00ol0003oooooooooo`0aooooo`;o
00001Oooool2o`0000;ooooo0_l00008ooooo`?o00002?ooool2o`0000Sooooo0_l00002ooooo`;o
000000Coooooo`000?l0003ooooo0_l00005ooooo`;o00000_ooool2o`0000?ooooo0_l00005oooo
o`Co00001Oooool4o`0000?ooooo0_l0000Cooooo`;o00003Oooool2o`0000;ooooo0_l0000Aoooo
o`;o00000ooooolEo`000003ooooool0003o000000;ooooo0_l00006ooooo`;o00008_ooool2o`00
03Gooooo000Looooo`03o`000?oooooooooo03cooooo0_l00006ooooo`;o00005_ooool2o`000003
ooooool0003o000000?o000000?oooooo`000?l000001Oooool2o`0000Kooooo1Ol00003ooooo`Co
00001Oooool2o`000004ooooool0003o0000ooooo`?o00003oooool2o`0000;ooooo1?l00003oooo
o`;o00001_ooool2o`0000;ooooo0_l00005ooooo`;o00002Oooool2o`0000;ooooo5ol000001?oo
oooo0000o`000?l0000Mooooo`?o0000A?ooool001cooooo0_l0000oooooo`;o00001?ooool2o`00
01Kooooo0_l00002ooooo`_o00002Oooool2o`000003ooooool0003o000000Gooooo0_l000000ooo
oooo0000o`000003ooooo`Co000000?oooooo`000?l000003oooool3o`0000Cooooo0_l00003oooo
o`;o00000oooool2o`0000Gooooo0_l000000ooooooo0000o`000002ooooo`;o00002Oooool3o`00
0003ooooool0003o000001Wo00007Oooool3o`0000oooooo0_l00009ooooo`;o0000:?ooool001co
oooo00?o0000ooooooooool0>Oooool2o`0000?ooooo0_l0000Fooooo`;o00001Oooool>o`0000co
oooo0_l00008ooooo`?o000000Coooooo`000?l0003o00005?ooool2o`0000oooooo0_l00003oooo
o`Co000000?oooooo`000?l000003Oooool4o`000003ooooool0003o000001;o00000_ooool4o`00
00Gooooo0_l0000Fooooo`;o00003?ooool2o`0000;ooooo0_l00009ooooo`;o0000:?ooool001co
oooo00?o0000ooooooooool0<Oooool2o`0000Kooooo1?l00008ooooo`;o00003oooool4o`0000;o
oooo3ol000000ooooooo0000o`000009ooooo`;o00002?ooool3o`000003ooooool0003o000000;o
00002_ooool2o`0000Oooooo0_l00006ooooo`;o00001?ooool2o`0000Gooooo0ol00002ooooo`;o
00002Oooool2o`0000Gooooo0_l000001?oooooo0000o`000?ooool3o`000003ooooool0003o0000
00ko000000Goooooo`000?l0003o0000ooooo`02o`000003ooooool0003o0000027ooooo0_l00000
1?oooooo0000o`000?l0000fooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00001Oooool6
o`0000Oooooo0_l00007ooooo`;o000000?oooooo`000?l000001Oooool2o`000003ooooool0003o
000001?o00005oooool2o`0000[ooooo0_l0000?ooooo`;o00001?ooool2o`0000;ooooo0_l00000
0ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Gooooo8Ol00003
ooooo`;o00001Oooool4o`0001Kooooo1_l0000fooooo`007?ooool00ol0003oooooooooo`0aoooo
o`;o00001Oooool2o`0000;ooooo0_l00007ooooo`;o00001?ooool2o`000003ooooool0003o0000
00Go00001_oooolIo`0000Cooooo0_l00006ooooo`;o00003oooool3o`0001[ooooo0_l00008oooo
o`?o00003?oooolHo`000003ooooool0003o000000Oo000000?oooooo`000?l000001Ol00002oooo
o`Co00006?ooool2o`0003Sooooo000Looooo`03o`000?oooooooooo02cooooo0_l000000ooooooo
0000o`000002o`000003ooooool0003o000000Wooooo0_l000001?oooooo0000o`000?ooool2o`00
00Cooooo0_l000001?oooooo0000o`000?l00002ooooo`?o00000ooooolKo`0000Cooooo0_l00006
ooooo`;o00001?ooool4o`000004ooooool0003o0000ooooo`;o000000Coooooo`000?l0003o0000
0oooool2o`0000[ooooo0ol0000=ooooo`;o00000oooool2o`0000Cooooo0_l00007ooooo`ko0000
00?oooooo`000?l000004Ol000001?oooooo0000o`000?ooool6o`0001Wooooo0_l0000kooooo`00
7?ooool00ol0003oooooooooo`0Aooooo`;o00006Oooool2o`000003ooooool0003o000000?ooooo
0_l00006ooooo`;o000000Coooooo`000?l0003ooooo0_l00007ooooo`;o000000?oooooo`000?l0
00000oooool3o`0000;ooooo0ol000000ooooooo0000o`00000Eo`000003ooooool0003o000000Ko
oooo0_l00007ooooo`_o00001oooool2o`0000[ooooo0ol0000=ooooo`;o00002Oooool2o`0000?o
oooo0_l00002oooooaoo00002oooool3o`0000gooooo0_l00006ooooo`;o000000?oooooo`000?l0
0000>oooool001cooooo00?o0000ooooooooool04Oooool2o`0002Wooooo1Ol0000:ooooo`;o0000
1_ooool2o`0000?ooooo6ol000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l00000
1?ooool2o`0000;ooooo1ol00007ooooo`;o00003Oooool5o`00017ooooo0_l00002ooooo`;o0000
00?oooooo`000?l000000ooooolJo`0000;ooooo0ol0000;ooooo`;o00002?ooool2o`000003oooo
ool0003o000000;o000000?oooooo`000?l000000oooool2o`0003kooooo000Looooo`03o`000?oo
oooooooo01cooooo0_l0000Pooooo`;o000000Coooooo`000?l0003o00001?ooool2o`0000Cooooo
0ol00008oooooaSo00001oooool2o`0000Cooooo0ol00004ooooo`;o000000?oooooo`000?l00000
0oooool2o`0001Oooooo1Ol0000:ooooo`;o00001Oooool2o`0000;ooooo1ol000000ooooooo0000
o`00000No`0000_ooooo0_l00007ooooo`;o000000?oooooo`000?l000000oooool2o`0000Gooooo
0_l0000looooo`007?ooool00ol0003oooooooooo`0Looooo`;o00008?ooool2o`000004ooooool0
003o0000o`0000Cooooo0_l00004ooooo`Go00001_oooolHo`0000;ooooo1?l000000ooooooo0000
o`000004ooooo`?o00001?ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l00000
0_l0000=ooooo`Co00001_ooool2o`0000Cooooo0ol000001?oooooo0000o`000?ooool2o`0000;o
oooo0_l00005oooooaCo000000?oooooo`000?l000004Ol0000;ooooo`;o00003Oooool2o`0000Oo
oooo0_l0000looooo`007?ooool00ol0003oooooooooo`0aooooo`;o00007_ooool2o`0000;ooooo
0_l000000ooooooo0000o`00000Go`0000;ooooo1?l00007ooooo`?o00001?ooool2o`0000?ooooo
0_l00003ooooo`;o00003Oooool4o`0000cooooo0ol000000ooooooo0000o`000003ooooo`Co0000
0_ooool2o`0000Cooooo0ol000000ooooooo0000o`00000Bo`000003ooooool0003o000000Ko0000
1_ooool2o`0000Cooooo0_l0000@ooooo`;o00001oooool2o`0003cooooo000Looooo`03o`000?oo
oooooooo037ooooo0_l0000Booooo`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o0000
0oooool8o`000003ooooool0003o0000017o000000Coooooo`000?l0003ooooo0_l0000>ooooo`;o
00004?ooool2o`0000Oooooo0_l0000?ooooo`Co00000_ooool2o`0000?ooooo0ol00004oooooaSo
000000?oooooo`000?l000001_l00006ooooo`;o00001?ooool2o`0000;ooooo0_l0000?ooooo`;o
00000_ooool4o`0003cooooo000Looooo`03o`000?oooooooooo03cooooo0_l00007ooooo`Go0000
00?oooooo`000?l000000oooool2o`0000Cooooo7_l000001?oooooo0000o`000?ooool2o`0000So
oooo0_l00002ooooo`Co00001oooool2o`0000?ooooo0ol00007ooooo`;o00000_ooool2o`0000Ko
oooo1?l000000ooooooo0000o`000002o`0000Oooooo0_l00003ooooo`;o00000ooooolMo`0000Co
oooo0_l00002ooooo`;o00001oooool2o`0000oooooo0_l00002ooooo`?o0000?Oooool001cooooo
00?o0000ooooooooool0;oooool2o`0000[ooooo0ol00009ooooo`;o00003Oooool2o`0000;ooooo
6_l000001?oooooo0000o`000?ooool2o`0000Oooooo0ol00002ooooo`Co00000oooool2o`0000;o
oooo0_l00003ooooo`;o00002?ooool2o`0000;ooooo0_l00006ooooo`Co00001Oooool2o`0000?o
oooo0_l00005ooooo`;o00000ooooolNo`0000?ooooo0_l00002ooooo`;o00004?ooool4o`0000Oo
oooo1?l0000mooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00002_ooool2o`0000Kooooo
0_l0000=ooooo`;o00001_oooolHo`0000?ooooo1?l000000ooooooo0000o`000005ooooo`Co0000
0_ooool2o`0000Cooooo0_l00002ooooo`;o00000_ooool2o`0000Gooooo0_l0000Gooooo`;o0000
0oooool2o`0000Gooooo8ol0000Cooooo`;o00001?ooool4o`0000Cooooo0_l000001?oooooo0000
o`000?l00002ooooo`;o000000?oooooo`000?l00000=oooool001cooooo00?o0000ooooooooool0
=_ooool2o`0000_ooooo0_l000000ooooooo0000o`000003o`0000Oooooo0_l00006oooooaKo0000
0_ooool2o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l00000
0_ooool2o`0000Oooooo0ol00002ooooo`;o00001Oooool2o`0000Oooooo0_l0000Joooooa7o0000
00?oooooo`000?l000003_l0000:ooooo`;o00002?ooool2o`0000[ooooo1?l000000ooooooo0000
o`000003ooooo`;o000000?oooooo`000?l000000_l0000eooooo`007?ooool2o`0003Oooooo0_l0
000>ooooo`Oo00000_ooool2o`0000Kooooo0ol000000ooooooo0000o`00000Ao`0000Cooooo0_l0
0008ooooo`;o00000_ooool2o`0000[ooooo0_l00002ooooo`;o00000oooool2o`0000Kooooo0_l0
0005ooooo`?o000000?oooooo`000?l000000_l00008ooooo`Co00002Oooool4o`0000;ooooo6?l0
0002ooooo`Co00002?ooool2o`0000oooooo0_l00003ooooo`;o00001?ooool2o`0000Oooooo0_l0
000eooooo`007?ooool00ol0003oooooooooo`16ooooo`;o00000oooool2o`0000;ooooo0_l00006
ooooo`?o000000?oooooo`000?l000002ol000000ooooooo0000o`000004o`0000?ooooo0_l00000
1?oooooo0000o`000?l00004ooooo`;o00000_ooool2o`0000Wooooo1?l000000ooooooo0000o`00
0002o`000003ooooool0003o000000Kooooo0_l00005ooooo`?o000000?oooooo`000?l000000_l0
0008ooooo`Co00002Oooool3o`0000?ooooo6Ol00003ooooo`;o00001_ooool2o`00017ooooo0ol0
0002ooooo`;o00001?ooool2o`0000Gooooo0_l0000gooooo`007?ooool00ol0003oooooooooo`0Z
ooooo`;o00001oooool2o`0001cooooo0_l0000;ooooo`Wo00000_ooool6o`0000?ooooo0_l00000
1?oooooo0000o`000?l00006ooooo`;o00002oooool4o`000003ooooool0003o000000;o00003Ooo
ool2o`0000;ooooo0_l00007ooooo`;o00000_ooool3o`0000gooooo0_l00003ooooo`oo00000_oo
ool9o`0000;ooooo0_l00006ooooo`;o00004_ooool2o`0000;ooooo0_l0000;ooooo`;o0000=ooo
ool001cooooo00?o0000ooooooooool0:_ooool2o`0000;ooooo0_l00003ooooo`;o00003oooool3
o`0000?ooooo0_l00005ooooo`;o00002oooool2o`0000;ooooo1Ol000000ooooooo0000o`000005
o`0000?ooooo0_l00002ooooo`Co00001?ooool2o`0000_ooooo0_l000001?oooooo0000o`000?oo
ool2o`0000Kooooo0_l00002ooooo`;o00000_ooool2o`0000Cooooo0_l00005ooooo`;o00000_oo
ool3o`0001Cooooo0ol00003ooooo`Go000000?oooooo`000?l000000ol00002ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0001[ooooo0_l00006ooooo`;o0000@?ooool001cooooo00?o0000
ooooooooool0;_ooool2o`0001Cooooo0ol00002ooooo`?o00000_ooool2o`000003ooooool0003o
000000oooooo1Ol000001?oooooo0000o`000?l0000;ooooo`Co00001_ooool2o`0000Wooooo0_l0
00001?oooooo0000o`000?ooool2o`0000Kooooo0_l000000ooooooo0000o`000002o`000004oooo
ool0003o0000ooooo`;o000000?oooooo`000?l000001Oooool7o`000003ooooool0003o000000?o
oooo0_l00009ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000009o`00
00Kooooo0_l00008ooooo`Co00004oooool3o`0000?ooooo0_l00010ooooo`007?ooool00ol0003o
ooooooooo`0aooooo`;o00005_ooool3o`0000;ooooo1_l00005ooooo`;o00001?ooool2o`0000ko
oooo1?l000000ooooooo0000o`000003o`0000Oooooo0_l0000Aooooo`;o000000Coooooo`000?l0
003o00000oooool4o`000003ooooool0003o000000Co00000oooool3o`0000;ooooo1Ol00002oooo
o`Co000000?oooooo`000?l000002Oooool2o`0000;ooooo1?l00002ooooo`Go00000_ooool3o`00
00?ooooo0_l000000ooooooo0000o`000008ooooo`Go00003?ooool2o`0000;ooooo1ol00013oooo
o`007?ooool00ol0003oooooooooo`0aooooo`;o00002_ooool2o`0000Oooooo0_l000001?oooooo
0000o`000?l00002ooooo`Ko00001Oooool3o`0000?ooooo1_l00004ooooo`;o00001?ooool:o`00
00Kooooo0_l0000;ooooo`;o00001Oooool2o`000004ooooool0003o0000o`0000;ooooo1Ol00003
ooooo`Co00000_ooool4o`0000;ooooo0_l00007ooooo`;o00001_ooool2o`000003ooooool0003o
000000?o000000?oooooo`000?l000000ol00002ooooo`Co000000Coooooo`000?l0003ooooo0_l0
00000ooooooo0000o`000002o`0000Sooooo0_l00004ooooo`;o00003?ooool2o`0000;ooooo0_l0
0003ooooo`;o0000@oooool001cooooo00?o0000ooooooooool05oooool2o`0002Cooooo0_l00005
ooooo`Co00000_ooool2o`0000;ooooo1Ol00007ooooo`;o00001Oooool4o`0000Cooooo1?l00002
ooooo`;o000000?oooooo`000?l000002oooool2o`0000_ooooo0ol00006ooooo`;o00001?ooool2
o`0000Kooooo1?l00002ooooo`?o00000oooool2o`0000?ooooo0_l0000:ooooo`;o000000Gooooo
o`000?l0003o0000ooooo`04o`000003ooooool0003o000000;o00000_ooool2o`000004ooooool0
003o0000ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Kooooo0_l0000>ooooo`;o0000
4_ooool2o`0003cooooo000Looooo`03o`000?oooooooooo01Oooooo0_l0000[ooooo`;o00001?oo
ool2o`0000Cooooo0ol00007ooooo`;o000000?oooooo`000?l000002_ooool4o`0000;ooooo0_l0
00000ooooooo0000o`00000;ooooo`;o00003?ooool2o`0000Cooooo1ol000000ooooooo0000o`00
0003ooooo`Co00001Oooool8o`000003ooooool0003o000000;o00004?ooool:o`0000;ooooo0_l0
0002ooooo`;o00001oooool2o`000003ooooool0003o000001?ooooo0_l0000?ooooo`Go0000??oo
ool001cooooo00?o0000ooooooooool0D?ooool2o`0000_ooooo0_l000000ooooooo0000o`00000;
ooooo`;o00001?ooool4o`0000Sooooo0_l00002ooooo`;o00001?ooool2o`0000Sooooo0_l00000
0ooooooo0000o`000006o`0000;ooooo1_l00004ooooo`[o00001?ooool2o`0000cooooo0_l00002
ooooo`Co00001?ooool6o`0000[ooooo0_l0000Sooooo`Co0000?_ooool001cooooo00?o0000oooo
ooooool0=oooool2o`0000oooooo0_l0000Fooooo`;o00001?ooool2o`0000Gooooo0_l000001?oo
oooo0000o`000?ooool4o`0000?ooooo0_l00003ooooo`;o00000_ooool4o`0000;ooooo0_l00008
ooooo`_o00000_ooool7o`0000Cooooo1?l000000ooooooo0000o`000004o`0000;ooooo1?l00006
ooooo`Co00001?ooool2o`0000Sooooo0_l0000Mooooo`;o00004_ooool2o`00043ooooo000Loooo
o`03o`000?oooooooooo03Oooooo0_l00004ooooo`;o00002Oooool2o`0001cooooo0_l00008oooo
o`?o00000_ooool3o`0000;ooooo0_l00003ooooo`;o00000_ooool4o`000003ooooool0003o0000
00Wooooo1Ol000001?oooooo0000o`000?l00003ooooo`?o00000_oooolCo`000003ooooool0003o
000000;o00001_ooool4o`0000cooooo0_l0000Oooooo`Co00001_ooool2o`0004[ooooo000Loooo
o`03o`000?oooooooooo03gooooo0_l00006ooooo`;o00006?ooool2o`0000Cooooo0_l0000:oooo
o`;o00000_ooool3o`0000;ooooo0_l00007ooooo`?o00000_ooool2o`0000Sooooo0ol000001?oo
oooo0000o`000?ooool<o`000003ooooool0003o000000co000000?oooooo`000?l000000_l00004
ooooo`;o00002?ooool3o`0000Gooooo0_l000000ooooooo0000o`00000=ooooo`;o00004Oooool3
o`0000Kooooo0_l00003ooooo`;o0000AOooool001cooooo00?o0000ooooooooool0AOooool6o`00
00oooooo0_l00003ooooo`;o00001?ooool3o`0000[ooooo0_l00006ooooo`Co00004_ooool5o`00
0004ooooool0003o0000oooooa7o00000_ooool=o`0000Cooooo0_l000000ooooooo0000o`000005
ooooo`?o00001Oooool2o`0000[ooooo0ol00003ooooo`;o00004Oooool2o`0000Gooooo0ol00004
ooooo`;o00003_ooool2o`0003Gooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ
8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`16ooooo`Go0000
0oooool2o`0000Sooooo1?l00005ooooo`;o00000_ooool4o`0000Wooooo0_l00005ooooo`;o0000
00?oooooo`000?l000001Oooool2o`0000Gooooo0_l00004ooooo`Oo00000oooool3o`000003oooo
ool0003o000001So00001_ooool4o`0000Cooooo0_l00007ooooo`?o00002Oooool4o`0001Sooooo
0_l00002ooooo`?o00005?ooool2o`0003Gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`19oooo
o`?o000000Coooooo`000?l0003o00002?ooool2o`0000Oooooo2?l00008ooooo`;o00001_ooool2
o`0000Sooooo0_l00005ooooo`;o00001_ooool>o`000003ooooool0003o000000Co000000?ooooo
o`000?l000000_l000000ooooooo0000o`000009o`0000?ooooo0_l000000ooooooo0000o`000006
ooooo`;o00001oooool4o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000002
o`0001Sooooo1?l0001>ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`19ooooo`?o000000?ooooo
o`000?l000001oooool2o`0000Cooooo0_l00005ooooo`;o00001?ooool2o`0000Kooooo1Ol00000
0ooooooo0000o`000003o`0000?ooooo0_l00006ooooo`;o00001Oooool3o`0000Cooooo9?l00002
ooooo`?o00000oooool3o`0000gooooo0_l000000ooooooo0000o`000004o`0001oooooo0_l0000@
ooooo`;o0000??ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0
003oV9RHoooooonHV9So8B4Q00Kooooo0ol0000eooooo`;o00003_ooool3o`0000kooooo0_l00003
ooooo`Go00000oooool2o`0000Cooooo0_l00007ooooo`Co000000Coooooo`000?l0003ooooo0_l0
0003ooooo`;o00001_ooool2o`0000Gooooo0ol00004ooooobKo000000?oooooo`000?l000000_l0
00001?oooooo0000o`000?l0000Booooo`?o00004oooool2o`0001gooooo0_l0000looooo`0000?o
ooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
1_ooool00ol0003oooooooooo`0eooooo`;o00003_ooool4o`0001;ooooo1Ol00003ooooo`;o0000
1oooool2o`0000Kooooo0_l0000;ooooo`Co00002Oooool5o`000003ooooool0003o000000So0000
00?oooooo`000?l000006ol00002ooooo`;o00002_ooool2o`00023ooooo0_l00004ooooo`?o0000
3oooool3o`0004;ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00?o
EEEEohN7Qoooool02?ooool00ol0003oooooooooo`0hooooo`;o00001_ooool2o`0000?ooooo1?l0
000=ooooo`?o00000oooool2o`0000kooooo0_l00006ooooo`;o00002oooool4o`0000Wooooo1Ol0
00000ooooooo0000o`000002o`000003ooooool0003o000000go000000?oooooo`000?l000004Ol0
0003ooooo`;o00002Oooool2o`0002Kooooo1Ol00004ooooo`;o00000_ooool2o`0000?ooooo0ol0
0004ooooo`;o0000??ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@
oiRHV008ooooo`03o`000?oooooooooo03Sooooo0_l00006ooooo`;o00000oooool2o`000003oooo
ool0003o000000Oooooo0_l00003ooooo`?o00002_ooool2o`0000Cooooo0_l0000Fooooo`;o0000
1_ooool2o`0000Cooooo2Ol000000ooooooo0000o`00000>o`000003ooooool0003o000000Wo0000
0_ooool5o`0000;ooooo0ol000001?oooooo0000o`000?ooool3o`0000Sooooo0_l0000Rooooo`?o
00001?ooool2o`0000;ooooo0_l0000:ooooo`;o0000??ooool00006ooooooo^k^ko<S8bo`000?lb
<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo02oooooo0_l0000D
ooooo`;o000000?oooooo`000?l000001oooool2o`0000Kooooo0_l00008ooooo`;o00001?ooool2
o`000003ooooool0003o000001_ooooo0_l00006oooooago000000?oooooo`000?l000001?l00002
ooooo`Wo00000_ooool2o`000004ooooool0003o0000o`0000?ooooo0_l00003ooooo`;o00005_oo
ool2o`0000?ooooo0_l0000<ooooo`;o00000_ooool2o`0004Sooooo000Looooo`03o`000?oooooo
oooo02oooooo0_l0000Xooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00
0003ooooo`;o00000oooool2o`0000Wooooo0_l00008ooooo`;o00002_ooool2o`0000Cooooo4_l0
00000ooooooo0000o`00000@o`0000Cooooo0_l0000=ooooo`;o00006oooool4o`000003ooooool0
003o000000Kooooo0_l00004ooooo`;o00000_ooool2o`0000?ooooo0_l00009ooooo`;o0000>?oo
ool001cooooo00?o0000ooooooooool0>_ooool2o`00023ooooo1Ol000000ooooooo0000o`000003
ooooo`;o00001Oooool2o`0000Oooooo0_l00003ooooo`;o00000oooool2o`0000[ooooo1?l00003
ooooobKo00003oooool2o`0001kooooo0ol00009ooooo`;o000000?oooooo`000?l000001Oooool2
o`0000?ooooo0_l00009ooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0>_ooool2o`00
01;ooooo0_l0000<ooooo`Co00002?ooool4o`0000;ooooo0_l0000<ooooo`;o00001Oooool2o`00
00Cooooo0_l00003ooooo`Co000000?oooooo`000?l000008?l000000ooooooo0000o`000004o`00
00gooooo0_l0000Pooooo`?o00002_ooool2o`0000Oooooo0_l00016ooooo`007?ooool00ol0003o
ooooooooo`1>ooooo`;o00003Oooool2o`0000;ooooo0_l00005ooooo`Co00002Oooool2o`0000co
oooo0_l00004ooooo`;o00000oooool>o`000003ooooool0003o000001Ko00000_ooool5o`0002oo
oooo0ol00002ooooo`;o00001Oooool3o`0000Oooooo0_l00016ooooo`007?ooool00ol0003ooooo
ooooo`16ooooo`Co00000oooool2o`0000Sooooo0_l00008ooooo`;o00001oooool2o`0000Wooooo
0_l0000?ooooo`;o00002?oooolTo`0000;ooooo0_l00004ooooo`;o0000:oooool2o`0000Gooooo
0_l00005ooooo`;o0000D?ooool001cooooo00?o0000ooooooooool0A_ooool4o`000003ooooool0
003o000000;o000000?oooooo`000?l000001Oooool4o`0000cooooo0_l000000ooooooo0000o`00
0008ooooo`;o00004?ooool2o`0000Sooooo3Ol00002oooooaWo000000?oooooo`000?l000000ol0
0004ooooo`;o00002Oooool2o`0001[ooooo0_l0001Nooooo`007?ooool00ol0003oooooooooo`16
ooooo`Co000000?oooooo`000?l000000_l000000ooooooo0000o`000007ooooo`;o00000_ooool2
o`0000Sooooo0_l0000;ooooo`;o00001Oooool2o`0000cooooo0_l00007ooooo`_o000000?ooooo
o`000?l000006?l000000ooooooo0000o`000003o`000004ooooool0003o0000ooooo`?o00002?oo
ool2o`0002Kooooo0_l00005ooooo`;o00000oooool2o`0004Kooooo000Looooo`03o`000?oooooo
oooo04;ooooo0_l00002ooooo`;o00000oooool2o`0000?ooooo0_l00004ooooo`;o00001?ooool3
o`0000Wooooo0_l00003ooooo`;o00001Oooool2o`0000Gooooo0_l0000;ooooo`?o00000oooool?
o`000003ooooool0003o000001So000000?oooooo`000?l000000_l00002ooooo`;o00000_ooool2
o`0000;ooooo0_l0000/ooooo`;o00001Oooool2o`0000?ooooo0_l00016ooooo`007?ooool00ol0
003oooooooooo`12ooooo`;o000000Coooooo`000?l0003o00003_ooool2o`0000Cooooo0_l00003
ooooo`Co00000oooool2o`0000?ooooo0_l00009ooooo`;o00001_ooool2o`0000Kooooo0_l00002
oooooa7o000000?oooooo`000?l000005_l00002ooooo`Co00002?ooool2o`000003ooooool0003o
000000Cooooo0_l0000Xooooo`;o0000D?ooool001cooooo00?o0000ooooooooool0AOooool3o`00
013ooooo0_l000000ooooooo0000o`000004ooooo`Co00002oooool4o`0000Cooooo0ol00005oooo
o`;o00001_ooool2o`0000;ooooo:Ol000000ooooooo0000o`000003o`0000Wooooo1?l00005oooo
o`;o00004oooool2o`0000Kooooo0_l00004ooooo`;o00001Oooool2o`0000gooooo0_l00011oooo
o`007?ooool00ol0003oooooooooo`16ooooo`;o00003Oooool2o`000004ooooool0003o0000oooo
o`;o000000?oooooo`000?l000001Oooool2o`0000Wooooo1?l000000ooooooo0000o`000005o`00
01?ooooo0ol000000ooooooo0000o`00000No`0000;ooooo1_l00009ooooo`Co00006_ooool2o`00
00Kooooo0_l00004ooooo`;o00001?ooool2o`0000kooooo0_l00011ooooo`007?ooool2o`0005Ko
oooo0_l000000ooooooo0000o`000004ooooo`;o00001?ooool3o`0000Sooooo0_l00004ooooo`Co
000000?oooooo`000?l000003_ooool2o`0000Gooooo8_l00002ooooo`Ko00004?ooool2o`0001go
oooo0_l0000:ooooo`;o0000DOooool001cooooo00?o0000ooooooooool09oooool2o`0001Cooooo
0_l000000ooooooo0000o`000008ooooo`;o00000oooool2o`0000Oooooo1?l00007ooooo`?o0000
00?oooooo`000?l000001_ooool2o`0000Gooooo1_l0000>ooooo`?o000000Coooooo`000?l0003o
oooo6ol000000ooooooo0000o`000004o`000003ooooool0003o000000Ko00003oooool2o`0001Oo
oooo0_l00004ooooo`;o00001?ooool2o`0005Oooooo000Looooo`03o`000?oooooooooo02Oooooo
0_l0000Dooooo`;o000000?oooooo`000?l000002?ooool2o`0000?ooooo0_l00007ooooo`Co0000
0_ooool2o`0000?ooooo0ol000000ooooooo0000o`00000?ooooo`;o00004?ooool3o`000003oooo
ool0003o000001_o000000?oooooo`000?l000000ol00003ooooo`Go000000?oooooo`000?l00000
4oooool2o`00017ooooo1?l00004ooooo`Co00000_ooool2o`0000Sooooo0_l0001=ooooo`007?oo
ool00ol0003oooooooooo`0eooooo`;o00004oooool2o`0000?ooooo0_l0000<ooooo`?o000000Co
ooooo`000?l0003ooooo0_l00008ooooo`;o00002oooool2o`0000gooooo6Ol000000ooooooo0000
o`00000;o`0000Cooooo1?l000000ooooooo0000o`00000Cooooo`;o00004Oooool3o`0000Oooooo
1?l00003ooooo`;o00001Oooool2o`0004gooooo000Looooo`03o`000?oooooooooo03Gooooo0ol0
000Gooooo`;o00000oooool4o`0000Gooooo0_l00002ooooo`;o00002oooool2o`000003ooooool0
003o000000;ooooo0_l00004ooooo`;o00002oooool2o`000003ooooool0003o000000Co000000?o
ooooo`000?l000007Ol00003ooooo`Go00003Oooool2o`0001_ooooo0_l00007ooooo`Co00000_oo
ool3o`0005Cooooo000Looooo`03o`000?oooooooooo03Kooooo0_l0000>ooooo`;o00001_ooool2
o`0000Cooooo1?l0000:ooooo`;o000000Coooooo`000?l0003o00002Oooool2o`0000;ooooo0ol0
0003ooooo`;o00002oooool2o`0000;ooooo0_l00004ooooobCo00004?ooool2o`0000Cooooo0_l0
000Eooooo`;o00000oooool2o`0000;ooooo0_l00004ooooo`;o00000_ooool4o`0004oooooo000L
ooooo`03o`000?oooooooooo04?ooooo0_l000000ooooooo0000o`000006ooooo`;o00001_ooool2
o`0000[ooooo0_l000000ooooooo0000o`000002o`0000gooooo0ol00002ooooo`;o00003?ooool2
o`000003ooooool0003o000000Cooooo0ol000000ooooooo0000o`00000Oo`0000Kooooo0_l0000=
ooooo`;o00005_ooool2o`0000;ooooo0_l0000<ooooo`Co0000Coooool001cooooo00?o0000oooo
ooooool0@oooool2o`00017ooooo0_l00006ooooo`;o00001?ooool5o`0000?ooooo0_l00009oooo
o`;o00004?ooool2o`000003ooooool0003o000000?o000000?oooooo`000?l000007Ol000000ooo
oooo0000o`000003o`000003ooooool0003o000000?ooooo0_l00003ooooo`;o00003?ooool2o`00
00oooooo0_l000000ooooooo0000o`00001Sooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o
000000Coooooo`000?l0003ooooo1Ol000000ooooooo0000o`000002o`0000Sooooo1?l0000Doooo
obGo00000_ooool5o`0000Oooooo0ol00007ooooo`;o00000oooool2o`0000_ooooo0_l000001?oo
oooo0000o`000?l00009ooooo`;o00002Oooool3o`0004oooooo000Looooo`03o`000?oooooooooo
04?ooooo0_l0000Looooo`;o00001Oooool5o`0000Wooooo1?l00002ooooo`;o00004_ooool6o`00
0003ooooool0003o000001?o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o0000
00?o00000_ooool2o`0000Cooooo0_l00008ooooo`Co000000?oooooo`000?l000002oooool2o`00
0003ooooool0003o000000[ooooo0ol00008ooooo`?o0000Coooool001cooooo00?o0000oooooooo
ool0@oooool2o`00013ooooo0ol00004ooooo`;o00001Oooool2o`0000?ooooo0_l000000ooooooo
0000o`00000;ooooo`;o00000_ooool2o`0000_ooooo0_l00004ooooo`Ko00001?ooool>o`0000;o
oooo1ol00002ooooo`Go00001?ooool2o`00013ooooo0_l00002ooooo`;o00002Oooool2o`0000oo
oooo0_l00002ooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0=oooool4o`0000Kooooo
0_l0000Booooo`Co00000oooool3o`0000Cooooo0_l0000<ooooo`;o000000?oooooo`000?l00000
0_l0000Aooooo`;o00001?ooool6o`0000;ooooo7Ol000000ooooooo0000o`00000Dooooo`;o0000
00Coooooo`000?l0003ooooo0_l00009ooooo`;o00004oooool2o`0005Kooooo000Looooo`03o`00
0?oooooooooo03Oooooo1?l00006ooooo`;o00002oooool2o`0000?ooooo0ol000000ooooooo0000
o`000004ooooo`;o00001?ooool2o`0000cooooo0_l000000ooooooo0000o`000002o`0001oooooo
7Ol0000;ooooo`;o00002_ooool2o`000004ooooool0003o0000o`0001Oooooo0_l00008ooooo`;o
0000EOooool001cooooo00?o0000ooooooooool0=oooool2o`0001Gooooo0_l000000ooooooo0000
o`000003o`0001Gooooo0_l00002ooooo`;o00001oooool2o`0001Wooooo0_l00002oooooaco0000
1_ooool2o`0000Cooooo0_l0000=ooooo`?o00005oooool2o`0000Sooooo0_l0001Eooooo`007?oo
ool00ol0003oooooooooo`0gooooo`;o00006?ooool2o`0000Gooooo0_l00009ooooo`;o00001Ooo
ool3o`0000;ooooo0_l00007ooooo`;o00002Oooool2o`0000kooooo7?l000000ooooooo0000o`00
0007ooooo`;o00000oooool2o`0000_ooooo0_l00005ooooo`;o00007_ooool2o`0005Gooooo000L
ooooo`03o`000?oooooooooo03?ooooo0_l0000Sooooo`Co00001_ooool5o`0000?ooooo0_l00000
0ooooooo0000o`000003o`0000Gooooo0_l0000:ooooo`;o00003?ooool3o`000003ooooool0003o
000001Oo00004?ooool2o`0000_ooooo0_l00005ooooo`;o00007_ooool2o`0005Gooooo000Loooo
o`;o0000=?ooool2o`0001cooooo0_l00005ooooo`Co00001_ooool2o`000003ooooool0003o0000
00?ooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000C
ooooo`;o00000oooool3o`0000;ooooo0ol00003ooooo`;o00000_ooool8o`0000Cooooo0_l0000X
ooooo`;o00002Oooool6o`0000;ooooo0_l0000>ooooo`;o0000C_ooool001cooooo00?o0000oooo
ooooool0>oooool2o`0001Cooooo0_l00008ooooo`;o00002?ooool2o`0000?ooooo1?l00002oooo
o`;o00000_ooool2o`000003ooooool0003o000001?ooooo0_l00003ooooo`;o00000oooool2o`00
00Cooooo0_l00002ooooo`;o000000?oooooo`000?l000000ol00003ooooo`;o00005Oooool2o`00
00kooooo0_l00002ooooo`;o00002Oooool6o`0000;ooooo0_l00004ooooo`;o00002?ooool2o`00
0003ooooool0003o000004_ooooo000Looooo`03o`000?oooooooooo03_ooooo0_l0000Nooooo`;o
00002?ooool2o`0000Cooooo0ol00002ooooo`;o00001Oooool2o`00017ooooo0_l0000>ooooo`Co
00001Oooool3o`0000Gooooo1?l0000;ooooo`;o00001_ooool2o`0000Sooooo0_l00004ooooo`;o
00003Oooool2o`0000Kooooo0ol000000ooooooo0000o`000002o`0000_ooooo0_l0001;ooooo`00
7?ooool00ol0003oooooooooo`1:ooooo`;o000000Coooooo`000?l0003ooooo0_l00006ooooo`;o
00000_ooool2o`0000[ooooo0_l0000Pooooo`;o00002?ooool2o`000003ooooool0003o000000So
00000_ooool3o`0000Gooooo1?l0000;ooooo`;o00004?ooool2o`0000Gooooo0_l00006ooooo`;o
00001?ooool2o`0000Kooooo0ol000000ooooooo0000o`000009ooooo`;o0000Coooool001cooooo
00?o0000ooooooooool0B_ooool2o`000004ooooool0003o0000ooooo`;o00001_ooool3o`000003
ooooool0003o000000Kooooo0ol000000ooooooo0000o`00000Zooooo`;o000000?oooooo`000?l0
00002Ol0000Iooooo`?o00005Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool4o`0000_o
oooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00002?ooool4o`0000Wooooo
0ol0000Cooooo`;o00006Oooool2o`0000;ooooo0_l00005ooooo`;o00001?ooool2o`0001;ooooo
1?l0000Booooo`;o00000oooool2o`000003ooooool0003o000000Sooooo0_l00005ooooo`Co0000
G?ooool001cooooo00?o0000ooooooooool0E?ooool2o`000003ooooool0003o000000Cooooo0ol0
000Jooooo`;o00004oooool2o`0000Cooooo0_l00002ooooo`;o00001oooool2o`0000;ooooo0_l0
000Booooo`;o00002Oooool2o`0000Wooooo0_l00003ooooo`;o000000?oooooo`000?l000004Ooo
ool2o`000003ooooool0003o000005Wooooo000Looooo`03o`000?oooooooooo05Cooooo0_l00000
0ooooooo0000o`000004ooooo`?o00005oooool2o`0000Cooooo0_l0000@ooooo`;o00002?ooool4
o`0000Gooooo0ol0000Mooooo`;o000000?oooooo`000?l000004_ooool2o`0000Oooooo0_l0000:
ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0H?ooool2o`0001Cooooo0ol000001?oo
oooo0000o`000?ooool2o`0001Oooooo0_l000000ooooooo0000o`000002o`0000Kooooo0_l0000F
ooooo`;o00001Oooool2o`0001;ooooo0_l000000ooooooo0000o`000007ooooo`;o0000IOooool0
01cooooo00?o0000ooooooooool0D?ooool4o`0000cooooo0ol000000ooooooo0000o`000003oooo
o`;o00001?ooool2o`000005ooooool0003o0000o`000?ooool00ol000000ooooooo0000o`00000G
ooooo`;o000000Coooooo`000?l0003ooooo1?l0000;ooooo`Wo00001oooool2o`000003ooooool0
003o000000Gooooo0_l0000Booooo`;o000000?oooooo`000?l000003oooool2o`0005gooooo000L
ooooo`03o`000?oooooooooo03_ooooo0_l0000Booooo`Go00003Oooool2o`000003ooooool0003o
000000?ooooo0_l00004ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`000003ooooool0
003o000001Gooooo0_l000000ooooooo0000o`000004ooooo`;o00001oooool2o`000004ooooool0
003o0000ooooo`Wo00000_ooool2o`0000?ooooo0ol00007ooooo`;o00002oooool4o`0000oooooo
0ol00005ooooo`;o0000GOooool001cooooo00?o0000ooooooooool0>oooool2o`000003ooooool0
003o000000oooooo0_l0000:ooooo`;o00001?ooool2o`00013ooooo0_l00004ooooo`;o00000_oo
ool2o`00017ooooo0_l00002ooooo`?o000000?oooooo`000?l000001_ooool4o`000003ooooool0
003o000000cooooo0_l00004ooooo`;o00005?ooool4o`0000Kooooo0_l00006ooooo`Co000000?o
ooooo`000?l00000HOooool001cooooo00?o0000ooooooooool0?_ooool2o`0001_ooooo1?l0000M
ooooo`?o00004?ooool2o`0000?ooooo0ol000000ooooooo0000o`000006ooooo`;o00002Oooool2
o`0000_ooooo0_l0000?ooooo`;o00001?ooool2o`0000Sooooo0_l00006ooooo`;o00000oooool2
o`00067ooooo000Looooo`03o`000?oooooooooo04Gooooo0_l0000Fooooo`Co00000_ooool2o`00
00_ooooo0_l00006ooooo`;o00000_ooool2o`00017ooooo0_l0000<ooooo`Co00001oooool2o`00
0003ooooool0003o000000Wooooo1?l00009ooooo`;o00001?ooool2o`0000Cooooo0_l0000:oooo
o`Co0000J_ooool001cooooo00?o0000ooooooooool0AOooool2o`00013ooooo0_l00006ooooo`;o
00000_ooool2o`0000_ooooo0_l00006ooooo`;o00008oooool4o`0000Oooooo0_l0000<ooooo`;o
00002oooool4o`0000Cooooo0_l00006ooooo`;o00000_ooool3o`000003ooooool0003o000000;o
0000J_ooool001cooooo00?o0000ooooooooool0Eoooool2o`0000Gooooo1?l000000ooooooo0000
o`000007ooooo`;o000000?oooooo`000?l000003Oooool2o`0001Gooooo0ol0000Looooo`;o0000
3oooool3o`0000?ooooo0ol00005ooooo`;o00000_ooool3o`0006oooooo000Looooo`;o0000Gooo
ool4o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000003Ooo
ool2o`0001Cooooo1?l000000ooooooo0000o`00000@ooooo`;o00000oooool2o`0000;ooooo0_l0
000:ooooo`;o00001?ooool2o`0000?ooooo0ol0000Cooooo`;o00001?ooool2o`00063ooooo000L
ooooo`03o`000?oooooooooo05Wooooo0_l00004ooooo`Co00001Oooool2o`0000Sooooo1?l00008
ooooo`;o00005?ooool2o`0000?ooooo0_l0000@ooooo`;o00000oooool2o`0000_ooooo0_l00000
0ooooooo0000o`00000Fooooo`;o00001_ooool3o`0000Cooooo0ol0001Oooooo`007?ooool00ol0
003oooooooooo`1Iooooo`;o00001?ooool4o`0000_ooooo0_l00002ooooo`Co00002oooool2o`00
00_ooooo0_l0000/ooooo`?o00005oooool4o`0000Kooooo0_l00006ooooo`;o0000Goooool001co
oooo00?o0000ooooooooool0J?ooool2o`0000Cooooo0_l00005ooooo`Co00000_ooool2o`0000Co
oooo0_l0000;ooooo`;o00003Oooool2o`00017ooooo0ol00009ooooo`Co00004oooool2o`000003
ooooool0003o000000;o00002oooool2o`0006;ooooo000Looooo`03o`000?oooooooooo05_ooooo
0_l00006ooooo`;o00000oooool2o`0000;ooooo0_l00007ooooo`Co00000_ooool4o`0001kooooo
0_l00007ooooo`;o00002?ooool3o`0000_ooooo0_l00004ooooo`;o00002oooool4o`00013ooooo
0_l0001Rooooo`007?ooool00ol0003oooooooooo`1Kooooo`Co00001?ooool2o`0000Oooooo0_l0
0006ooooo`;o00001oooool2o`0000Cooooo0_l0000<ooooo`;o00002_ooool2o`0000?ooooo0_l0
0002ooooo`;o00001oooool2o`00017ooooo1?l0000;ooooo`Co0000M?ooool001cooooo00?o0000
ooooooooool0GOooool2o`0000Oooooo0_l00008ooooo`;o00000_ooool2o`000003ooooool0003o
000000[ooooo0_l0000<ooooo`;o00002_ooool4o`000003ooooool0003o000000Oooooo0_l00002
ooooo`;o00004Oooool2o`0000oooooo0_l0001dooooo`007?ooool00ol0003oooooooooo`1Voooo
o`;o000000?oooooo`000?l000001?ooool3o`0000Gooooo0_l0000Eooooo`;o00002Oooool4o`00
00;ooooo0_l0000:ooooo`;o0000W?ooool001cooooo00?o0000ooooooooool0D?ooool2o`00013o
oooo0_l00005ooooo`Co00000_ooool4o`0000Wooooo0_l00003ooooo`;o00002oooool2o`0000Wo
oooo1?l0000fooooo`;o0000M?ooool001cooooo00?o0000ooooooooool0D?ooool2o`0000?ooooo
0_l0000;ooooo`;o00001Oooool4o`0000Cooooo0_l00009ooooo`;o00000oooool2o`0000Cooooo
0_l00002ooooo`;o00002_ooool2o`0000_ooooo0_l00003ooooo`;o0000:?ooool2o`0000Cooooo
0_l00004ooooo`;o0000J?ooool001cooooo00?o0000ooooooooool0EOooool2o`0002[ooooo0_l0
0004ooooo`;o000000Coooooo`000?l0003o00002_ooool4o`0000Wooooo0ol00002ooooo`;o0000
1oooool2o`0000Wooooo0_l000000ooooooo0000o`000008ooooo`;o00003Oooool2o`0000Cooooo
0_l0001Xooooo`007?ooool00ol0003oooooooooo`1]ooooo`;o00002oooool2o`0000;ooooo0ol0
0006ooooo`;o000000?oooooo`000?l000002?ooool2o`0000?ooooo0_l0000:ooooo`;o00002ooo
ool2o`0000Wooooo0_l000000ooooooo0000o`000008ooooo`;o00005?ooool2o`0006Oooooo000L
ooooo`03o`000?oooooooooo06gooooo0_l0000:ooooo`?o00000_ooool3o`0000Wooooo0_l00008
ooooo`;o00000_ooool3o`0000Cooooo0_l000000ooooooo0000o`000002o`0000Oooooo0_l00003
ooooo`;o00008Oooool2o`0000Sooooo0ol0001Wooooo`007?ooool00ol0003oooooooooo`1Coooo
o`;o00009?ooool2o`0001cooooo0ol00005ooooo`Oo00000oooool2o`0000;ooooo0_l0000:oooo
o`;o00000_ooool2o`0000Sooooo0_l0000<ooooo`;o00002?ooool2o`0000_ooooo0_l0001Koooo
o`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<00Kooooo00?o0000ooooooooool0Doooool2o`0001oooooo0_l00006ooooo`;o00003ooo
ool2o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000001Oooool6o`0000;ooooo0_l0
000;ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Sooooo0_l0000Booooo`;o00001?oo
ool2o`0000Wooooo0_l0001Kooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0M?ooool3o`0000Go
oooo0_l0000?ooooo`;o00000oooool2o`0000Kooooo0_l00009ooooo`;o00001Oooool2o`000003
ooooool0003o000000Gooooo0_l0000Sooooo`;o00001?ooool2o`0006Kooooo00000ooooooo410@
ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo07Gooooo0_l00002ooooo`;o00007Oooool6o`0000;ooooo0ol00007ooooo`Co
000000?oooooo`000?l000002?ooool2o`0000Sooooo0_l00004ooooo`;o0000O_ooool00003oooo
ool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Olb<S;oV9RHoooooonHV9So<S8b00Ko
oooo0ol0001Mooooo`;o00002?ooool2o`00013ooooo0_l0000Mooooo`Ko00000_ooool3o`0000?o
oooo0_l00002ooooo`;o00003Oooool2o`0000;ooooo0_l00004ooooo`;o000000Coooooo`000?l0
003ooooo0_l0001nooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05
olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`1Mooooo`;o00002?ooool2o`00
0003ooooool0003o000000_ooooo0_l0000Eooooo`;o00003?ooool3o`0000Oooooo0_l00003oooo
o`;o00000oooool2o`0000_ooooo0_l00005ooooo`Co0000POooool00003ooooool@413ooooo00;o
oooo00?o410@ooooooooool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000oooo
ooooool0JOooool3o`0000_ooooo1?l00003ooooo`;o00003?ooool5o`0000cooooo0_l000001?oo
oooo0000o`000?ooool3o`0000Gooooo0_l00003ooooo`;o00004_ooool2o`0008?ooooo00001_oo
ooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`00
0?oooooooooo06Wooooo0_l0000>ooooo`;o00000oooool2o`0000[ooooo1?l000000ooooooo0000
o`000003ooooo`;o00002_ooool2o`000004ooooool0003o0000o`0001?ooooo0_l0000Fooooo`;o
0000M_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413o
ZJVY00Kooooo00?o0000ooooooooool0K?ooool2o`0001Sooooo0_l00002ooooo`;o00002?ooool2
o`0001Wooooo0_l00008ooooo`;o00005_ooool2o`0007Kooooo000Looooo`03o`000?oooooooooo
06cooooo0_l0000Hooooo`;o00001Oooool2o`0000;ooooo0_l00002ooooo`;o00006?ooool2o`00
00;ooooo0_l0000Mooooo`;o0000MOooool001cooooo00?o0000ooooooooool0K_ooool2o`0000Oo
oooo0_l00007ooooo`;o00002_ooool3o`0000;ooooo1ol0000Kooooo`;o00007Oooool2o`0007Go
oooo000Looooo`03o`000?oooooooooo06kooooo0_l00007ooooo`;o000000?oooooo`000?l00000
1?ooool3o`0000Wooooo0_l00004ooooo`So00000_ooool2o`0000Cooooo0_l00006ooooo`;o0000
:Oooool2o`0007;ooooo000Looooo`03o`000?oooooooooo06Oooooo0_l00007ooooo`;o00002?oo
ool2o`0000Gooooo0_l0000<ooooo`;o00001_ooool3o`0000;ooooo0_l00004ooooo`;o000000?o
ooooo`000?l000000oooool2o`0000Kooooo0_l0000Qooooo`;o0000L_ooool001cooooo00?o0000
ooooooooool0Ioooool2o`0000Oooooo0_l0000Cooooo`;o00001Oooool2o`000003ooooool0003o
000000?ooooo0_l0000?ooooo`;o00002oooool2o`0009Gooooo000Looooo`03o`000?oooooooooo
08Gooooo0_l00002ooooo`;o000000?oooooo`000?l000001_ooool2o`0001Oooooo0_l0002Joooo
o`007?ooool00ol0003oooooooooo`25ooooo`;o00000_ooool2o`000003ooooool0003o000001?o
oooo0_l0000:ooooo`;o0000V_ooool001cooooo00?o0000ooooooooool0QOooool2o`0000Gooooo
1?l0000Aooooo`;o00009oooool2o`0007gooooo000Looooo`03o`000?oooooooooo08kooooo0_l0
0002ooooo`;o00003_ooool2o`0002Kooooo0_l0001mooooo`007?ooool00ol0003oooooooooo`1n
ooooo`;o00003?ooool2o`0000Cooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo0_l00000
0ooooooo0000o`00002Uooooo`007?ooool00ol0003oooooooooo`1nooooo`;o00003?ooool2o`00
00Oooooo1?l00002ooooo`;o00000_ooool2o`000003ooooool0003o00000:Gooooo000Looooo`;o
0000U_ooool2o`0000kooooo0_l0000Hooooo`;o0000R?ooool001cooooo00?o0000ooooooooool0
OOooool2o`00017ooooo0_l0000Cooooo`;o00006?ooool2o`0001?ooooo0_l0001cooooo`007?oo
ool00ol0003oooooooooo`1mooooo`;o00004Oooool2o`0002?ooooo0_l0000Mooooo`;o0000Looo
ool001cooooo00?o0000ooooooooool0]Oooool2o`0009;ooooo000Looooo`03o`000?oooooooooo
08kooooo0_l0002iooooo`007?ooool00ol0003oooooooooo`2>ooooo`;o0000^Oooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2?ooooo`;o00003Ooo
ool2o`000:Wooooo000Looooo`03o`000?oooooooooo08oooooo0_l0000=ooooo`;o0000ZOooool0
01cooooo00?o0000ooooooooool0Toooool2o`0000gooooo0_l0002Uooooo`007?ooool00ol0003o
ooooooooo`2Cooooo`;o00003Oooool2o`000:Gooooo000Looooo`03o`000?oooooooooo09Cooooo
0_l0000Gooooo`;o0000V_ooool001cooooo00?o0000ooooooooool0U?ooool2o`0001Oooooo0_l0
002Jooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?oooooo
Boooool001cooooo00?o0000ooooooooool0Voooool2o`000:cooooo000Looooo`03o`000?oooooo
oooo09_ooooo0_l0002/ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Booooo`Co000000?o410@ooooooooool0
0oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`?o0000oooooom:
ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?oo
ooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003ooooooooo
o`3ooooooe;ooooo000Booooo`03oeEEEOmVIVKo00000?ooooooE?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00:7ooooo00Co410@o`000?l0003ooooo0_l000000ol@413ooooo
ooooo`0Fooooo`Co000000?o410@ooooooooool01Ol00003ooooo`05oiRHV?l@413o0000oc8b<_o<
c<`00oooool01Oo^k^ko<S8bo`000?l@413oc<c<08cooooo002Rooooo`05o`000?oooooooooooooo
ool000002Oooool6o`0000cooooo00?o0000ooooooooool00_ooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40
S?ooool00:;ooooo00Go0000ooooooooooooooooo`00000Kooooo`03o`000?oooooooooo00?ooooo
00?oV9RHob4Q8Oo^k^h02?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool0R_ooool00:;ooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00003?ooool00ol0003o
ooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003o
V9RHoooooonHV9So8B4Q08cooooo002Rooooo`05o`000?n7QhOoooooojVYZOl000006oooool00ol0
003oooooooooo`05ooooo`03ogMgMomVIVKooooo00Cooooo00?o410@o`000?nj^[X00oooool01Ol0
003oEEEEo`000?l@413oc<c<08cooooo002Qooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHoooo
ooooool06Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o^[Zjob4Q
8Oooool00_ooool00omEEEGoQhN7ooooo`2>ooooo`00`_ooool00ol0003oooooooooo`02ooooo`05
o`000?nj^[[ooooooiRHV?l@41000oooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00?ogMgM
oa0@4?nHV9P0S_ooool00<3ooooo00?oEEEEofIVI_l000001?ooool01OnHV9So410@o`000?lQ8B7o
c<c<00?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@04ooooo`04olc<c?m4A4Co0000oa0@48cooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1242) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.70393 .53731 Mdot
.66038 .5328 Mdot
.42846 .35043 Mdot
.51643 .64728 Mdot
.48725 .19643 Mdot
.42096 .38287 Mdot
.6094 .41271 Mdot
.59238 .35222 Mdot
.44369 .3638 Mdot
.71813 .35345 Mdot
.5927 .39369 Mdot
.51128 .55604 Mdot
.60142 .36801 Mdot
.48688 .65398 Mdot
.48396 .14051 Mdot
.43128 .65502 Mdot
.68524 .52678 Mdot
.3176 .46654 Mdot
.52793 .66973 Mdot
.44644 .33791 Mdot
.60682 .58667 Mdot
.49274 .64686 Mdot
.63057 .56584 Mdot
.48611 .65436 Mdot
.52076 .62149 Mdot
.6645 .57311 Mdot
.69897 .57663 Mdot
.49624 .605 Mdot
.49446 .59102 Mdot
.58835 .35605 Mdot
.31131 .61191 Mdot
.46612 .16552 Mdot
.56026 .61792 Mdot
.2349 .35376 Mdot
.61841 .35552 Mdot
.61931 .73856 Mdot
.42351 .3698 Mdot
.61459 .38534 Mdot
.61753 .38992 Mdot
.63532 .37297 Mdot
.60267 .3895 Mdot
.64587 .56775 Mdot
.65862 .41934 Mdot
.36797 .42217 Mdot
.43985 .65922 Mdot
.6002 .24211 Mdot
.67998 .75405 Mdot
.44978 .6304 Mdot
.69182 .53751 Mdot
.28545 .35444 Mdot
.49589 .26001 Mdot
.63108 .3953 Mdot
.46114 .34744 Mdot
.24557 .76943 Mdot
.62029 .3704 Mdot
.52412 .69046 Mdot
.42508 .35954 Mdot
.48248 .63977 Mdot
.48106 .6552 Mdot
.59023 .67243 Mdot
.44557 .65176 Mdot
.30056 .51013 Mdot
.66648 .50608 Mdot
.58389 .48042 Mdot
.43846 .36739 Mdot
.6086 .39974 Mdot
.64746 .54299 Mdot
.60663 .36234 Mdot
.42808 .68335 Mdot
.44063 .33225 Mdot
.44906 .62636 Mdot
.59934 .39773 Mdot
.68811 .51916 Mdot
.47304 .6033 Mdot
.28854 .44035 Mdot
.74806 .30421 Mdot
.35881 .51931 Mdot
.61452 .71432 Mdot
.56835 .70263 Mdot
.31456 .37386 Mdot
.53224 .64777 Mdot
.36515 .65091 Mdot
.69843 .26945 Mdot
.62883 .57369 Mdot
.44782 .58586 Mdot
.27017 .53104 Mdot
.47387 .6063 Mdot
.626 .23077 Mdot
.46677 .58989 Mdot
.24499 .47204 Mdot
.44836 .37871 Mdot
.67092 .54454 Mdot
.51846 .64766 Mdot
.47483 .59508 Mdot
.46026 .7625 Mdot
.55384 .63124 Mdot
.4988 .62791 Mdot
.69231 .55624 Mdot
.63114 .38909 Mdot
.55951 .641 Mdot
.3694 .41659 Mdot
.44768 .40373 Mdot
.48631 .67931 Mdot
.41117 .40455 Mdot
.65485 .51284 Mdot
.47022 .60017 Mdot
.62215 .38824 Mdot
.4774 .67562 Mdot
.75311 .51167 Mdot
.65862 .52983 Mdot
.49251 .59915 Mdot
.33946 .51494 Mdot
.42069 .79867 Mdot
.67869 .5378 Mdot
.35465 .35715 Mdot
.54049 .62355 Mdot
.48913 .62537 Mdot
.66072 .53567 Mdot
.39893 .40832 Mdot
.64555 .23749 Mdot
.6542 .58478 Mdot
.62485 .3504 Mdot
.7083 .53865 Mdot
.41857 .62999 Mdot
.44117 .38495 Mdot
.4147 .26938 Mdot
.6833 .46598 Mdot
.32401 .58818 Mdot
.47236 .61111 Mdot
.70845 .39748 Mdot
.45616 .38255 Mdot
.65933 .55079 Mdot
.60175 .36049 Mdot
.50636 .56264 Mdot
.63502 .53669 Mdot
.58504 .3821 Mdot
.32868 .52176 Mdot
.52443 .30521 Mdot
.6396 .52471 Mdot
.4081 .4741 Mdot
.58269 .39938 Mdot
.63421 .39085 Mdot
.19111 .44169 Mdot
.64938 .54508 Mdot
.32026 .50931 Mdot
.59832 .35525 Mdot
.29518 .58248 Mdot
.44498 .66455 Mdot
.34848 .67093 Mdot
.67731 .77035 Mdot
.22173 .37213 Mdot
.54551 .31447 Mdot
.31469 .48505 Mdot
.59903 .33873 Mdot
.51391 .62545 Mdot
.67656 .56797 Mdot
.6486 .57356 Mdot
.45022 .65963 Mdot
.52746 .63725 Mdot
.45011 .61684 Mdot
.46892 .5948 Mdot
.6949 .60861 Mdot
.54676 .63956 Mdot
.60337 .79507 Mdot
.67529 .54529 Mdot
.51577 .63757 Mdot
.39303 .37791 Mdot
.53174 .58648 Mdot
.60175 .39411 Mdot
.48923 .63969 Mdot
.51775 .64527 Mdot
.45006 .66459 Mdot
.63228 .38964 Mdot
.52666 .15829 Mdot
.4798 .78715 Mdot
.47455 .17914 Mdot
.26142 .4715 Mdot
.40522 .39326 Mdot
.48108 .61016 Mdot
.32373 .51733 Mdot
.67293 .7018 Mdot
.50483 .66202 Mdot
.64246 .83805 Mdot
.49889 .63514 Mdot
.49446 .18715 Mdot
.49548 .70555 Mdot
.38206 .20437 Mdot
.35321 .6434 Mdot
.50897 .61492 Mdot
.57507 .50428 Mdot
.60287 .45031 Mdot
.37424 .35901 Mdot
.60239 .3854 Mdot
.39417 .374 Mdot
.42447 .35366 Mdot
.64499 .43222 Mdot
.59047 .58471 Mdot
.54002 .69023 Mdot
.49079 .57891 Mdot
.44189 .33034 Mdot
.64638 .51126 Mdot
.29727 .51674 Mdot
.6952 .56455 Mdot
.70943 .21889 Mdot
.53651 .24165 Mdot
.58098 .40967 Mdot
.28707 .48903 Mdot
.45105 .36072 Mdot
.43709 .40773 Mdot
.34236 .49827 Mdot
.46196 .63877 Mdot
.64418 .54994 Mdot
.20726 .36702 Mdot
.77628 .50766 Mdot
.17689 .44258 Mdot
.69284 .55221 Mdot
.74374 .40297 Mdot
.58669 .37439 Mdot
.40881 .37139 Mdot
.49204 .6256 Mdot
.46605 .63373 Mdot
.60782 .58065 Mdot
.45124 .61708 Mdot
.51037 .54533 Mdot
.49713 .61864 Mdot
.4765 .28164 Mdot
.36337 .5049 Mdot
.64394 .43329 Mdot
.3399 .57182 Mdot
.64491 .57907 Mdot
.30927 .70317 Mdot
.41827 .40802 Mdot
.66287 .70157 Mdot
.6019 .40359 Mdot
.31407 .52091 Mdot
.43428 .40335 Mdot
.31329 .52581 Mdot
.54033 .65624 Mdot
.40071 .35616 Mdot
.3441 .49255 Mdot
.54205 .70736 Mdot
.43779 .61939 Mdot
.7623 .5525 Mdot
.62794 .35974 Mdot
.67059 .58484 Mdot
.44311 .64084 Mdot
.40071 .39489 Mdot
.53018 .5724 Mdot
.61315 .29765 Mdot
.43335 .27704 Mdot
.44277 .41203 Mdot
.42572 .2899 Mdot
.29617 .50828 Mdot
.59417 .27402 Mdot
.73159 .40882 Mdot
.6923 .52961 Mdot
.55217 .63048 Mdot
.36053 .20695 Mdot
.59904 .35521 Mdot
.47179 .67038 Mdot
.29311 .30363 Mdot
.61316 .35895 Mdot
.48082 .63824 Mdot
.59084 .34814 Mdot
.64644 .57299 Mdot
.42536 .78143 Mdot
.68873 .53028 Mdot
.47616 .58614 Mdot
.62492 .38461 Mdot
.38648 .38361 Mdot
.67071 .5679 Mdot
.45919 .64418 Mdot
.49188 .60622 Mdot
.54684 .45011 Mdot
.51023 .63403 Mdot
.52325 .16699 Mdot
.50277 .61597 Mdot
.40923 .35958 Mdot
.49743 .68045 Mdot
.35903 .80955 Mdot
.67023 .37842 Mdot
.64675 .54459 Mdot
.39839 .41106 Mdot
.43754 .35863 Mdot
.35931 .4173 Mdot
.59139 .43161 Mdot
.54236 .63667 Mdot
.40463 .39523 Mdot
.35002 .71804 Mdot
.58629 .39921 Mdot
.55597 .61728 Mdot
.42227 .48098 Mdot
.27276 .37429 Mdot
.4606 .3482 Mdot
.56386 .61034 Mdot
.6414 .52134 Mdot
.52131 .64629 Mdot
.4257 .41321 Mdot
.63462 .60278 Mdot
.52351 .60842 Mdot
.60043 .55842 Mdot
.54785 .44872 Mdot
.59762 .41152 Mdot
.50548 .70526 Mdot
.46304 .66381 Mdot
.39761 .37861 Mdot
.65315 .58013 Mdot
.58351 .39518 Mdot
.65516 .5698 Mdot
.33753 .24135 Mdot
.74765 .52289 Mdot
.57411 .66912 Mdot
.28447 .48387 Mdot
.26537 .35926 Mdot
.35232 .2207 Mdot
.26286 .68621 Mdot
.29049 .66701 Mdot
.25708 .30012 Mdot
.3975 .40434 Mdot
.293 .31307 Mdot
.43131 .35627 Mdot
.53025 .62585 Mdot
.44058 .38118 Mdot
.34651 .21944 Mdot
.49784 .62038 Mdot
.43486 .37889 Mdot
.33889 .73246 Mdot
.52108 .64012 Mdot
.67563 .52757 Mdot
.61382 .19014 Mdot
.29939 .74573 Mdot
.44319 .27911 Mdot
.42934 .33987 Mdot
.26365 .61866 Mdot
.50119 .62758 Mdot
.50699 .67656 Mdot
.686 .54983 Mdot
.5559 .60266 Mdot
.29582 .49443 Mdot
.28965 .48614 Mdot
.55551 .39947 Mdot
.38329 .66283 Mdot
.50507 .70247 Mdot
.67549 .56373 Mdot
.71666 .60323 Mdot
.26733 .44224 Mdot
.28851 .34521 Mdot
.57592 .36121 Mdot
.60734 .18989 Mdot
.47501 .54933 Mdot
.64032 .33821 Mdot
.3827 .33418 Mdot
.67254 .53358 Mdot
.50761 .15872 Mdot
.60558 .38285 Mdot
.77673 .61502 Mdot
.42591 .52739 Mdot
.46448 .64115 Mdot
.60495 .4081 Mdot
.57556 .58231 Mdot
.27921 .73038 Mdot
.80145 .59694 Mdot
.39277 .5876 Mdot
.4708 .58563 Mdot
.30231 .44304 Mdot
.48974 .6338 Mdot
.66864 .27351 Mdot
.50161 .61249 Mdot
.66094 .56717 Mdot
.69964 .33071 Mdot
.56499 .4315 Mdot
.51428 .80239 Mdot
.61954 .27665 Mdot
.31356 .48504 Mdot
.49224 .61982 Mdot
.46482 .64377 Mdot
.2999 .49196 Mdot
.61923 .54843 Mdot
.46504 .59534 Mdot
.29455 .68842 Mdot
.46346 .60872 Mdot
.60783 .39031 Mdot
.41332 .55976 Mdot
.67624 .49231 Mdot
.50479 .58556 Mdot
.67769 .51096 Mdot
.60203 .41586 Mdot
.62252 .37837 Mdot
.49184 .70243 Mdot
.63693 .37349 Mdot
.50245 .6418 Mdot
.8125 .58912 Mdot
.64805 .52084 Mdot
.56392 .53948 Mdot
.63108 .55372 Mdot
.60308 .71858 Mdot
.62474 .3671 Mdot
.49187 .27209 Mdot
.51193 .55888 Mdot
.60438 .37913 Mdot
.74377 .53505 Mdot
.44055 .67109 Mdot
.44073 .60439 Mdot
.21073 .48846 Mdot
.42848 .3434 Mdot
.56479 .45483 Mdot
.59097 .35167 Mdot
.45836 .65293 Mdot
.5341 .60519 Mdot
.6061 .4173 Mdot
.79749 .55281 Mdot
.32748 .74676 Mdot
.50024 .6176 Mdot
.66631 .55962 Mdot
.6568 .55386 Mdot
.45661 .5898 Mdot
.50771 .67024 Mdot
.43484 .39475 Mdot
.38418 .38556 Mdot
.41057 .34412 Mdot
.55 .44776 Mdot
.48294 .27353 Mdot
.49406 .21784 Mdot
.63558 .37418 Mdot
.73258 .43731 Mdot
.24447 .47979 Mdot
.51022 .58232 Mdot
.45263 .34907 Mdot
.4722 .66655 Mdot
.50784 .64836 Mdot
.60063 .42054 Mdot
.36719 .26607 Mdot
.56428 .56773 Mdot
.61599 .55045 Mdot
.57859 .37777 Mdot
.4152 .61965 Mdot
.66845 .33671 Mdot
.33018 .51846 Mdot
.20826 .43721 Mdot
.60224 .40105 Mdot
.67326 .52878 Mdot
.61682 .35051 Mdot
.4637 .6263 Mdot
.52059 .68203 Mdot
.66531 .53771 Mdot
.31582 .47616 Mdot
.53368 .5754 Mdot
.48127 .6348 Mdot
.64044 .80456 Mdot
.23052 .50727 Mdot
.48296 .29112 Mdot
.50736 .61608 Mdot
.51133 .5909 Mdot
.35092 .50994 Mdot
.46184 .61379 Mdot
.4453 .62059 Mdot
.44424 .79229 Mdot
.70521 .46896 Mdot
.29782 .47735 Mdot
.80932 .56719 Mdot
.69483 .54752 Mdot
.40996 .18522 Mdot
.40315 .37552 Mdot
.56645 .36427 Mdot
.35596 .76975 Mdot
.4614 .34594 Mdot
.54735 .31867 Mdot
.43745 .1767 Mdot
.56455 .45224 Mdot
.47405 .33957 Mdot
.49116 .55273 Mdot
.46454 .59801 Mdot
.48601 .62774 Mdot
.31427 .51534 Mdot
.64295 .5545 Mdot
.55796 .46205 Mdot
.81535 .42297 Mdot
.4943 .64313 Mdot
.52927 .53884 Mdot
.7903 .43131 Mdot
.27378 .37776 Mdot
.32652 .49429 Mdot
.30232 .47832 Mdot
.48927 .62073 Mdot
.43354 .80388 Mdot
.66693 .57237 Mdot
.45964 .64579 Mdot
.54711 .62987 Mdot
.4239 .34288 Mdot
.65565 .52581 Mdot
.40614 .41184 Mdot
.51916 .26408 Mdot
.47812 .18309 Mdot
.67204 .7955 Mdot
.62427 .37126 Mdot
.72018 .30848 Mdot
.58247 .36535 Mdot
.36486 .63829 Mdot
.45415 .39919 Mdot
.51886 .65669 Mdot
.64763 .57901 Mdot
.4622 .65807 Mdot
.51348 .6662 Mdot
.46258 .64134 Mdot
.52182 .59269 Mdot
.54303 .86289 Mdot
.33477 .48345 Mdot
.4222 .63594 Mdot
.41515 .35442 Mdot
.66081 .25049 Mdot
.7429 .30523 Mdot
.46808 .64776 Mdot
.49183 .61089 Mdot
.63387 .53198 Mdot
.45535 .66376 Mdot
.58224 .3808 Mdot
.67351 .58039 Mdot
.47913 .59502 Mdot
.62848 .20749 Mdot
.49382 .59406 Mdot
.41802 .1925 Mdot
.60837 .34714 Mdot
.7621 .51615 Mdot
.4239 .65396 Mdot
.44313 .28326 Mdot
.56475 .45491 Mdot
.43567 .39962 Mdot
.63368 .35568 Mdot
.42628 .37011 Mdot
.82876 .45704 Mdot
.50468 .69088 Mdot
.51638 .62491 Mdot
.54171 .60462 Mdot
.40322 .39234 Mdot
.59959 .22073 Mdot
.5858 .2639 Mdot
.41999 .61299 Mdot
.41193 .39273 Mdot
.6673 .50781 Mdot
.26437 .55783 Mdot
.63314 .56073 Mdot
.28094 .50104 Mdot
.59195 .38809 Mdot
.30537 .48004 Mdot
.28446 .30255 Mdot
.66094 .53061 Mdot
.65955 .59033 Mdot
.40763 .37792 Mdot
.43896 .50784 Mdot
.14728 .5893 Mdot
.43081 .52236 Mdot
.34038 .61561 Mdot
.68235 .55248 Mdot
.49662 .5885 Mdot
.37612 .59161 Mdot
.47275 .50158 Mdot
.42867 .36942 Mdot
.50208 .65904 Mdot
.41379 .78058 Mdot
.43478 .39501 Mdot
.55498 .62273 Mdot
.42135 .34818 Mdot
.59691 .38695 Mdot
.45322 .35531 Mdot
.61543 .57213 Mdot
.48143 .60153 Mdot
.13626 .53155 Mdot
.36661 .51232 Mdot
.50481 .62481 Mdot
.57794 .37315 Mdot
.54554 .3625 Mdot
.49484 .67147 Mdot
.33643 .52218 Mdot
.42986 .38748 Mdot
.41408 .52655 Mdot
.50074 .61545 Mdot
.40375 .39026 Mdot
.70502 .53822 Mdot
.61721 .3407 Mdot
.51569 .74263 Mdot
.45571 .2912 Mdot
.68707 .54982 Mdot
.39366 .45706 Mdot
.641 .38724 Mdot
.5121 .5908 Mdot
.55154 .62715 Mdot
.66232 .55881 Mdot
.41082 .74015 Mdot
.47615 .68335 Mdot
.53131 .64852 Mdot
.40659 .3585 Mdot
.42772 .37488 Mdot
.41364 .75863 Mdot
.38926 .39736 Mdot
.51754 .68371 Mdot
.66048 .5607 Mdot
.51704 .65044 Mdot
.64757 .52361 Mdot
.45941 .66683 Mdot
.68082 .59442 Mdot
.61901 .5515 Mdot
.66721 .36278 Mdot
.50607 .65497 Mdot
.55497 .66841 Mdot
.47854 .67413 Mdot
.45797 .60817 Mdot
.44002 .39274 Mdot
.33479 .50267 Mdot
.55022 .65161 Mdot
.32449 .53316 Mdot
.31212 .52504 Mdot
.59705 .44519 Mdot
.42766 .34213 Mdot
.3108 .50505 Mdot
.7972 .43528 Mdot
.4128 .34401 Mdot
.30171 .50797 Mdot
.73849 .30217 Mdot
.62054 .35823 Mdot
.64684 .51918 Mdot
.52263 .63941 Mdot
.29102 .28255 Mdot
.67898 .75682 Mdot
.38006 .35712 Mdot
.50357 .6181 Mdot
.47885 .67101 Mdot
.64211 .58272 Mdot
.84818 .47358 Mdot
.4376 .33241 Mdot
.51349 .60196 Mdot
.64806 .53819 Mdot
.85933 .52786 Mdot
.4142 .35928 Mdot
.30471 .5111 Mdot
.63295 .37203 Mdot
.60494 .55137 Mdot
.68237 .46678 Mdot
.60409 .41259 Mdot
.41747 .319 Mdot
.49219 .2631 Mdot
.54098 .62348 Mdot
.45637 .35529 Mdot
.19 .47017 Mdot
.73786 .57563 Mdot
.62286 .45552 Mdot
.25682 .60689 Mdot
.67399 .53542 Mdot
.58232 .37271 Mdot
.32264 .48251 Mdot
.68978 .55751 Mdot
.67708 .52569 Mdot
.6102 .42284 Mdot
.51235 .76765 Mdot
.42165 .48304 Mdot
.61376 .3906 Mdot
.22617 .47714 Mdot
.41707 .24462 Mdot
.45251 .34784 Mdot
.29615 .49517 Mdot
.30049 .28762 Mdot
.6472 .56886 Mdot
.59902 .18427 Mdot
.1997 .46189 Mdot
.49889 .6281 Mdot
.31588 .50427 Mdot
.56776 .21524 Mdot
.82363 .40619 Mdot
.61613 .36174 Mdot
.55474 .42203 Mdot
.29266 .49309 Mdot
.4444 .64522 Mdot
.27563 .57104 Mdot
.53058 .64617 Mdot
.58864 .38109 Mdot
.58125 .67726 Mdot
.67189 .52686 Mdot
.61795 .42534 Mdot
.20662 .43738 Mdot
.50109 .64329 Mdot
.50629 .65665 Mdot
.35367 .56179 Mdot
.6699 .57766 Mdot
.435 .39994 Mdot
.54397 .62692 Mdot
.48451 .63664 Mdot
.53487 .67708 Mdot
.51651 .70202 Mdot
.41639 .79282 Mdot
.52158 .61465 Mdot
.58434 .25276 Mdot
.47879 .58073 Mdot
.49779 .65552 Mdot
.67332 .51028 Mdot
.6604 .80922 Mdot
.52967 .25909 Mdot
.48787 .63807 Mdot
.50328 .59187 Mdot
.62529 .42088 Mdot
.44393 .48871 Mdot
.43414 .50559 Mdot
.41125 .52499 Mdot
.2785 .64521 Mdot
.46667 .57962 Mdot
.64059 .54676 Mdot
.34606 .49783 Mdot
.52527 .60774 Mdot
.6422 .54335 Mdot
.45025 .669 Mdot
.43229 .39582 Mdot
.40864 .34693 Mdot
.73309 .56213 Mdot
.30692 .50026 Mdot
.46739 .5324 Mdot
.72292 .43752 Mdot
.39548 .36902 Mdot
.51864 .62456 Mdot
.57697 .408 Mdot
.42813 .41229 Mdot
.40575 .29334 Mdot
.48981 .7354 Mdot
.66837 .57459 Mdot
.67395 .54351 Mdot
.35077 .67734 Mdot
.54396 .30304 Mdot
.55002 .82141 Mdot
.59582 .38735 Mdot
.49643 .68672 Mdot
.72057 .39359 Mdot
.67665 .54101 Mdot
.36939 .60689 Mdot
.31171 .50295 Mdot
.61311 .35775 Mdot
.48882 .39316 Mdot
.63277 .53592 Mdot
.67977 .52348 Mdot
.45918 .59444 Mdot
.47486 .63796 Mdot
.29822 .67714 Mdot
.27412 .47438 Mdot
.59786 .41305 Mdot
.29514 .49762 Mdot
.45572 .39413 Mdot
.52 .61018 Mdot
.6286 .56532 Mdot
.40902 .2558 Mdot
.51676 .60166 Mdot
.44524 .39147 Mdot
.67102 .53898 Mdot
.29371 .50521 Mdot
.33312 .52576 Mdot
.46008 .60717 Mdot
.6709 .62232 Mdot
.61354 .38058 Mdot
.67723 .53035 Mdot
.66839 .34136 Mdot
.50775 .67493 Mdot
.47459 .62895 Mdot
.46528 .71256 Mdot
.593 .41178 Mdot
.77028 .45261 Mdot
.28514 .50376 Mdot
.64765 .55188 Mdot
.51008 .60934 Mdot
.29975 .50122 Mdot
.75342 .42683 Mdot
.44541 .41066 Mdot
.45248 .35655 Mdot
.33895 .52207 Mdot
.32167 .49838 Mdot
.32964 .52409 Mdot
.59975 .1838 Mdot
.62542 .57442 Mdot
.47639 .5499 Mdot
.48514 .68618 Mdot
.34781 .63621 Mdot
.48219 .56304 Mdot
.58225 .39607 Mdot
.43113 .34423 Mdot
.49612 .67361 Mdot
.48483 .58552 Mdot
.45543 .69815 Mdot
.55745 .54415 Mdot
.69692 .49707 Mdot
.65827 .52801 Mdot
.48273 .69294 Mdot
.41474 .34727 Mdot
.72274 .22415 Mdot
.23284 .29931 Mdot
.42881 .66701 Mdot
.41002 .49154 Mdot
.62806 .56644 Mdot
.63482 .40126 Mdot
.3563 .54793 Mdot
.62382 .35947 Mdot
.65182 .55016 Mdot
.52153 .61347 Mdot
.73255 .44468 Mdot
.34576 .51776 Mdot
.4528 .64079 Mdot
.58798 .36574 Mdot
.44879 .63192 Mdot
.60603 .41273 Mdot
.34904 .23132 Mdot
.21292 .55357 Mdot
.49851 .63403 Mdot
.42842 .61645 Mdot
.25312 .61808 Mdot
.4686 .65183 Mdot
.2891 .46208 Mdot
.62704 .56563 Mdot
.44908 .76328 Mdot
.43241 .63507 Mdot
.71522 .63555 Mdot
.51882 .66881 Mdot
.37826 .7571 Mdot
.47223 .63005 Mdot
.2674 .39278 Mdot
.48885 .59952 Mdot
.45055 .6113 Mdot
.62634 .37762 Mdot
.62088 .42348 Mdot
.69002 .51891 Mdot
.40559 .39774 Mdot
.44709 .18209 Mdot
.47894 .63223 Mdot
.42891 .27413 Mdot
.74106 .47158 Mdot
.32233 .49653 Mdot
.64907 .55422 Mdot
.85476 .45616 Mdot
.60104 .34403 Mdot
.22917 .52554 Mdot
.38197 .74722 Mdot
.65855 .44339 Mdot
.27671 .53758 Mdot
.69405 .31762 Mdot
.29851 .51204 Mdot
.45237 .66713 Mdot
.38836 .26132 Mdot
.2581 .41477 Mdot
.49271 .73568 Mdot
.64083 .39501 Mdot
.68228 .68343 Mdot
.37981 .25827 Mdot
.2946 .52048 Mdot
.29428 .48638 Mdot
.62778 .40571 Mdot
.47724 .40562 Mdot
.57294 .57577 Mdot
.3131 .50013 Mdot
.39028 .37566 Mdot
.43172 .33558 Mdot
.46222 .3423 Mdot
.65879 .57466 Mdot
.19975 .40843 Mdot
.66942 .32765 Mdot
.60022 .41123 Mdot
.46709 .40697 Mdot
.71319 .51764 Mdot
.62683 .58118 Mdot
.41424 .37347 Mdot
.45071 .38497 Mdot
.61843 .54322 Mdot
.51227 .69663 Mdot
.45812 .69542 Mdot
.49191 .64027 Mdot
.32971 .51476 Mdot
.47011 .63495 Mdot
.41964 .39319 Mdot
.61453 .36352 Mdot
.45175 .37294 Mdot
.58127 .35523 Mdot
.51594 .22086 Mdot
.4561 .63267 Mdot
.48472 .6015 Mdot
.71048 .73664 Mdot
.70104 .53038 Mdot
.56711 .24122 Mdot
.46977 .30119 Mdot
.42866 .35475 Mdot
.44426 .62475 Mdot
.67164 .58168 Mdot
.29169 .52193 Mdot
.73203 .72071 Mdot
.49718 .67609 Mdot
.62814 .5615 Mdot
.51272 .60724 Mdot
.67373 .61325 Mdot
.41276 .82631 Mdot
.65274 .56605 Mdot
.67631 .7699 Mdot
.49778 .59138 Mdot
.74891 .35524 Mdot
.54729 .60522 Mdot
.35283 .70822 Mdot
.4767 .68333 Mdot
.6943 .54971 Mdot
.48871 .64279 Mdot
.68033 .5768 Mdot
.39721 .37199 Mdot
.63561 .39386 Mdot
.68461 .54531 Mdot
.55093 .62038 Mdot
.11576 .39897 Mdot
.59058 .37649 Mdot
.49172 .62287 Mdot
.63108 .37586 Mdot
.63912 .55515 Mdot
.68947 .5374 Mdot
.80504 .38466 Mdot
.527 .26499 Mdot
.59737 .38577 Mdot
.51761 .60901 Mdot
.66413 .29837 Mdot
.52544 .64769 Mdot
.31683 .67718 Mdot
.52873 .68759 Mdot
.49217 .68297 Mdot
.75348 .31144 Mdot
.5934 .41028 Mdot
.53015 .82421 Mdot
.79965 .36638 Mdot
.66653 .25219 Mdot
.59905 .58081 Mdot
.29377 .52089 Mdot
.51638 .15824 Mdot
.48863 .27353 Mdot
.40753 .39214 Mdot
.48697 .67505 Mdot
.68667 .49787 Mdot
.61797 .38159 Mdot
.33702 .50246 Mdot
.49787 .63315 Mdot
.45308 .37872 Mdot
.28983 .71596 Mdot
.5927 .34118 Mdot
.64478 .5659 Mdot
.61605 .55649 Mdot
.81999 .62598 Mdot
.50841 .61317 Mdot
.48063 .59896 Mdot
.59045 .38584 Mdot
.7801 .42974 Mdot
.30257 .51761 Mdot
.32454 .72479 Mdot
.59688 .38397 Mdot
.52009 .46554 Mdot
.65177 .53914 Mdot
.4765 .67012 Mdot
.56832 .20027 Mdot
.31241 .43777 Mdot
.75689 .65049 Mdot
.32398 .51692 Mdot
.31226 .66893 Mdot
.69546 .547 Mdot
.59975 .35828 Mdot
.52026 .32304 Mdot
.4874 .57355 Mdot
.47523 .6661 Mdot
.31564 .66683 Mdot
.57681 .43905 Mdot
.39588 .58022 Mdot
.50347 .67441 Mdot
.57991 .45696 Mdot
.47684 .68021 Mdot
.47699 .57084 Mdot
.51725 .68879 Mdot
.47288 .61758 Mdot
.62791 .56357 Mdot
.42471 .68911 Mdot
.42356 .39915 Mdot
.44936 .54932 Mdot
.5265 .47214 Mdot
.50229 .62185 Mdot
.53619 .63391 Mdot
.72094 .68935 Mdot
.55527 .32933 Mdot
.68149 .5448 Mdot
.62438 .58936 Mdot
.63321 .36223 Mdot
.45683 .69645 Mdot
.41297 .40208 Mdot
.4884 .56505 Mdot
.44304 .39062 Mdot
.63191 .56726 Mdot
.42294 .35558 Mdot
.63463 .38075 Mdot
.44276 .3393 Mdot
.48198 .27328 Mdot
.59759 .35313 Mdot
.67831 .56744 Mdot
.47093 .60401 Mdot
.57812 .37185 Mdot
.32188 .57853 Mdot
.32787 .51527 Mdot
.7985 .34805 Mdot
.48064 .59406 Mdot
.70177 .47114 Mdot
.59451 .60159 Mdot
.45123 .37864 Mdot
.43637 .82231 Mdot
.61672 .55325 Mdot
.3097 .47378 Mdot
.64179 .57862 Mdot
.22038 .49835 Mdot
.32962 .50405 Mdot
.72915 .28656 Mdot
.46532 .31243 Mdot
.24294 .52359 Mdot
.48768 .70007 Mdot
.3021 .56039 Mdot
.46203 .35709 Mdot
.61862 .38008 Mdot
.53103 .32495 Mdot
.44633 .62008 Mdot
.23264 .63631 Mdot
.64272 .51625 Mdot
.40849 .39809 Mdot
.6041 .36237 Mdot
.58202 .39227 Mdot
.5337 .65608 Mdot
.31727 .33909 Mdot
.45901 .66026 Mdot
.54085 .29098 Mdot
.2856 .64857 Mdot
.57405 .56183 Mdot
.49665 .61903 Mdot
.39726 .37725 Mdot
.51297 .60738 Mdot
.29845 .47271 Mdot
.19023 .41717 Mdot
.54493 .58584 Mdot
.47459 .30059 Mdot
.36527 .51917 Mdot
.66411 .53476 Mdot
.57493 .6088 Mdot
.49256 .28139 Mdot
.51164 .61282 Mdot
.44206 .87628 Mdot
.30052 .50511 Mdot
.38129 .26823 Mdot
.52914 .59996 Mdot
.54148 .6434 Mdot
.58498 .48951 Mdot
.65676 .46794 Mdot
.31552 .44015 Mdot
.47453 .65708 Mdot
.28934 .61391 Mdot
.61951 .40919 Mdot
.46484 .66887 Mdot
.48694 .62572 Mdot
.55454 .76823 Mdot
.58007 .37875 Mdot
.43705 .35418 Mdot
.46401 .35839 Mdot
.3785 .37695 Mdot
.30563 .4706 Mdot
.54425 .42494 Mdot
.36019 .61181 Mdot
.28346 .72521 Mdot
.33692 .47681 Mdot
.47465 .59216 Mdot
.35667 .46618 Mdot
.52997 .62165 Mdot
.32764 .48802 Mdot
.58035 .37082 Mdot
.68345 .54166 Mdot
.73195 .3908 Mdot
.44488 .33368 Mdot
.55597 .61352 Mdot
.29217 .50941 Mdot
.67451 .56999 Mdot
.25173 .51445 Mdot
.6568 .53971 Mdot
.60003 .37785 Mdot
.58807 .33729 Mdot
.33613 .49663 Mdot
.63418 .55362 Mdot
.64988 .36806 Mdot
.82411 .41902 Mdot
.52532 .68129 Mdot
.56886 .34445 Mdot
.70185 .5467 Mdot
.61229 .58446 Mdot
.69151 .56273 Mdot
.45097 .62047 Mdot
.41036 .49049 Mdot
.44295 .66694 Mdot
.59705 .4117 Mdot
.42574 .34776 Mdot
.25563 .63948 Mdot
.47763 .24019 Mdot
.37563 .45885 Mdot
.49326 .6889 Mdot
.50007 .64547 Mdot
.48927 .62105 Mdot
.43254 .62545 Mdot
.52008 .29478 Mdot
.46435 .66099 Mdot
.62696 .38039 Mdot
.42941 .38991 Mdot
.45145 .66651 Mdot
.4648 .38448 Mdot
.65095 .25309 Mdot
.33642 .47785 Mdot
.54282 .41336 Mdot
.25287 .24953 Mdot
.68125 .56184 Mdot
.40491 .41363 Mdot
.40515 .38922 Mdot
.32723 .52203 Mdot
.61286 .38588 Mdot
.65237 .54211 Mdot
.33674 .7056 Mdot
.32048 .52575 Mdot
.48712 .64048 Mdot
.39635 .51287 Mdot
.21769 .60053 Mdot
.45595 .6696 Mdot
.50745 .66457 Mdot
.45215 .40701 Mdot
.36023 .2934 Mdot
.15369 .51213 Mdot
.37023 .57491 Mdot
.33551 .49965 Mdot
.32881 .47936 Mdot
.6295 .53055 Mdot
.43734 .66461 Mdot
.59826 .41253 Mdot
.4034 .5772 Mdot
.52814 .37399 Mdot
.44253 .53642 Mdot
.64342 .49244 Mdot
.48919 .67762 Mdot
.80326 .53346 Mdot
.50367 .64359 Mdot
.62941 .57649 Mdot
.6404 .57071 Mdot
.67416 .55984 Mdot
.61738 .37908 Mdot
.62694 .71841 Mdot
.62492 .38864 Mdot
.23976 .26156 Mdot
.69569 .53863 Mdot
.48999 .33199 Mdot
.40359 .3709 Mdot
.42529 .66073 Mdot
.29452 .50341 Mdot
.62783 .33752 Mdot
.42755 .68273 Mdot
.43736 .80958 Mdot
.41372 .39847 Mdot
.6824 .56316 Mdot
.7028 .32386 Mdot
.29375 .24425 Mdot
.42244 .51285 Mdot
.41507 .61437 Mdot
.33481 .55562 Mdot
.32099 .49319 Mdot
.7558 .65466 Mdot
.29354 .49619 Mdot
.58861 .36166 Mdot
.4856 .60479 Mdot
.47373 .60716 Mdot
.47314 .67983 Mdot
.46042 .64345 Mdot
.63876 .38991 Mdot
.55291 .63553 Mdot
.35892 .80947 Mdot
.4003 .35426 Mdot
.55004 .70024 Mdot
.29781 .50577 Mdot
.64094 .36868 Mdot
.42784 .39077 Mdot
.55096 .33121 Mdot
.34353 .57486 Mdot
.49984 .61655 Mdot
.49195 .67492 Mdot
.2269 .52957 Mdot
.5049 .67403 Mdot
.47749 .56242 Mdot
.40488 .39102 Mdot
.38043 .4849 Mdot
.32298 .47539 Mdot
.32052 .47873 Mdot
.6039 .35034 Mdot
.63238 .56658 Mdot
.30902 .50968 Mdot
.40334 .3648 Mdot
.4957 .68871 Mdot
.54544 .61993 Mdot
.70133 .54628 Mdot
.1958 .47212 Mdot
.28886 .51016 Mdot
.68426 .30505 Mdot
.65197 .57902 Mdot
.71007 .5639 Mdot
.47656 .66645 Mdot
.60641 .52702 Mdot
.60694 .54604 Mdot
.33363 .47283 Mdot
.64007 .36671 Mdot
.36177 .54818 Mdot
.58608 .38393 Mdot
.63988 .56446 Mdot
.52525 .60932 Mdot
.64862 .57518 Mdot
.50627 .61504 Mdot
.35674 .18502 Mdot
.47044 .61428 Mdot
.28396 .73025 Mdot
.3425 .67408 Mdot
.41767 .38313 Mdot
.56262 .33455 Mdot
.40421 .37651 Mdot
.6575 .57993 Mdot
.53571 .61646 Mdot
.28724 .49326 Mdot
.69379 .27509 Mdot
.71137 .51278 Mdot
.44712 .39259 Mdot
.40531 .3425 Mdot
.58444 .36186 Mdot
.46777 .68242 Mdot
.47182 .6648 Mdot
.43318 .37796 Mdot
.57077 .55952 Mdot
.63101 .54124 Mdot
.49263 .60878 Mdot
.49774 .65101 Mdot
.41564 .38144 Mdot
.82721 .43257 Mdot
.73173 .53637 Mdot
.48109 .60908 Mdot
.40021 .277 Mdot
.58495 .40194 Mdot
.46985 .69463 Mdot
.43006 .6104 Mdot
.31916 .49925 Mdot
.53872 .73528 Mdot
.20795 .38537 Mdot
.58161 .35893 Mdot
.39756 .3845 Mdot
.50856 .611 Mdot
.39726 .3785 Mdot
.54854 .62496 Mdot
.64301 .47336 Mdot
.45455 .39048 Mdot
.53095 .65166 Mdot
.51752 .69765 Mdot
.66927 .57822 Mdot
.49115 .67633 Mdot
.68946 .7258 Mdot
.42842 .40944 Mdot
.53713 .64948 Mdot
.65817 .6254 Mdot
.61056 .39589 Mdot
.47874 .7007 Mdot
.34368 .50378 Mdot
.33811 .7089 Mdot
.69761 .44038 Mdot
.35521 .26963 Mdot
.33683 .48066 Mdot
.44935 .63771 Mdot
.39043 .3553 Mdot
.61792 .41257 Mdot
.30948 .75114 Mdot
.44818 .6538 Mdot
.58845 .3789 Mdot
.61263 .36238 Mdot
.33045 .51786 Mdot
.69906 .77073 Mdot
.52173 .59346 Mdot
.46848 .64609 Mdot
.60377 .76508 Mdot
.70654 .53907 Mdot
.46788 .62484 Mdot
.48445 .58798 Mdot
.62794 .38163 Mdot
.463 .565 Mdot
.70634 .67632 Mdot
.34798 .74003 Mdot
.58981 .4122 Mdot
.48554 .511 Mdot
.45438 .34485 Mdot
.30149 .49616 Mdot
.66351 .54149 Mdot
.29049 .50617 Mdot
.44426 .34308 Mdot
.47981 .59115 Mdot
.62218 .35162 Mdot
.64858 .76348 Mdot
.62805 .40581 Mdot
.33416 .27665 Mdot
.7053 .54397 Mdot
.70565 .38335 Mdot
.48736 .88014 Mdot
.64487 .28261 Mdot
.60949 .3174 Mdot
.32244 .49693 Mdot
.39938 .44434 Mdot
.49931 .64947 Mdot
.7471 .67689 Mdot
.46493 .60343 Mdot
.63875 .63093 Mdot
.39348 .36692 Mdot
.41009 .34432 Mdot
.48398 .60681 Mdot
.29274 .65705 Mdot
.61947 .41303 Mdot
.58823 .40283 Mdot
.53055 .65636 Mdot
.60409 .3796 Mdot
.47513 .64246 Mdot
.43164 .39361 Mdot
.52952 .83313 Mdot
.49372 .63582 Mdot
.43914 .60301 Mdot
.65344 .462 Mdot
.77248 .3319 Mdot
.27049 .34212 Mdot
.83242 .54704 Mdot
.26887 .26586 Mdot
.60449 .3782 Mdot
.45265 .68215 Mdot
.48537 .51201 Mdot
.46676 .36734 Mdot
.6407 .34178 Mdot
.46411 .61355 Mdot
.46105 .61343 Mdot
.45229 .60789 Mdot
.50936 .65607 Mdot
.76557 .64454 Mdot
.40394 .62584 Mdot
.60449 .6814 Mdot
.50925 .66857 Mdot
.30527 .56522 Mdot
.60009 .34879 Mdot
.60532 .57088 Mdot
.3498 .48496 Mdot
.48855 .67759 Mdot
.43683 .56456 Mdot
.62066 .42633 Mdot
.23709 .26336 Mdot
.59075 .35473 Mdot
.43739 .35917 Mdot
.63212 .40484 Mdot
.51 .63249 Mdot
.6573 .55402 Mdot
.50385 .49293 Mdot
.58799 .27256 Mdot
.40849 .39281 Mdot
.50468 .62442 Mdot
.48644 .32372 Mdot
.41972 .39857 Mdot
.64591 .24747 Mdot
.66282 .54816 Mdot
.2938 .61237 Mdot
.64316 .57318 Mdot
.53464 .64862 Mdot
.5368 .64408 Mdot
.58485 .33231 Mdot
.63461 .39362 Mdot
.64086 .57215 Mdot
.70201 .77512 Mdot
.31053 .52562 Mdot
.67051 .56403 Mdot
.51099 .57223 Mdot
.46913 .45973 Mdot
.66248 .55503 Mdot
.35806 .53766 Mdot
.62065 .3683 Mdot
.67843 .51784 Mdot
.50368 .5753 Mdot
.21875 .45237 Mdot
.3473 .50076 Mdot
.44322 .41685 Mdot
.38161 .5287 Mdot
.42589 .41165 Mdot
.63595 .35913 Mdot
.40527 .37826 Mdot
.62076 .40762 Mdot
.71602 .45835 Mdot
.46613 .54209 Mdot
.56878 .38652 Mdot
.63819 .36706 Mdot
.40835 .37795 Mdot
.49271 .60442 Mdot
.35091 .54624 Mdot
.45917 .6882 Mdot
.51793 .58855 Mdot
.61153 .40771 Mdot
.68991 .55633 Mdot
.61092 .5758 Mdot
.28191 .56944 Mdot
.62152 .55257 Mdot
.446 .38953 Mdot
.38125 .81026 Mdot
.42609 .26943 Mdot
.59585 .39937 Mdot
.63265 .40737 Mdot
.53018 .64451 Mdot
.42691 .36978 Mdot
.39308 .38281 Mdot
.58451 .36605 Mdot
.55737 .5328 Mdot
.42749 .63267 Mdot
.62121 .58408 Mdot
.6926 .52674 Mdot
.65678 .56423 Mdot
.69063 .56524 Mdot
.7354 .6376 Mdot
.61711 .35873 Mdot
.68475 .56463 Mdot
.52692 .6558 Mdot
.4621 .61441 Mdot
.44076 .515 Mdot
.32708 .48038 Mdot
.4465 .66056 Mdot
.51246 .69166 Mdot
.47989 .6699 Mdot
.45452 .35956 Mdot
.47616 .72811 Mdot
.45292 .39305 Mdot
.38849 .36232 Mdot
.388 .37018 Mdot
.48614 .27383 Mdot
.23847 .5576 Mdot
.27777 .27768 Mdot
.51237 .60106 Mdot
.78893 .45611 Mdot
.41726 .36447 Mdot
.43523 .81506 Mdot
.77112 .45018 Mdot
.44445 .6374 Mdot
.29296 .43492 Mdot
.4299 .37858 Mdot
.61821 .55537 Mdot
.46615 .61362 Mdot
.37988 .3882 Mdot
.34446 .5056 Mdot
.52191 .67249 Mdot
.45255 .39927 Mdot
.6359 .55233 Mdot
.34144 .47508 Mdot
.69089 .52283 Mdot
.38914 .36937 Mdot
.50009 .70292 Mdot
.17148 .66332 Mdot
.40192 .34289 Mdot
.7899 .40101 Mdot
.67946 .59913 Mdot
.49244 .60695 Mdot
.41425 .41513 Mdot
.71133 .54428 Mdot
.62745 .34863 Mdot
.51412 .39598 Mdot
.66422 .51895 Mdot
.41226 .34294 Mdot
.44276 .40476 Mdot
.40597 .39202 Mdot
.66298 .5264 Mdot
.4522 .59227 Mdot
.6534 .52288 Mdot
.63085 .40712 Mdot
.52316 .6437 Mdot
.35455 .21908 Mdot
.78785 .46695 Mdot
.64586 .57637 Mdot
.44098 .35369 Mdot
.34954 .51267 Mdot
.50237 .63737 Mdot
.79496 .47659 Mdot
.49934 .6046 Mdot
.60634 .41016 Mdot
.45066 .78716 Mdot
.68186 .74447 Mdot
.48429 .68549 Mdot
.52923 .64557 Mdot
.59136 .40551 Mdot
.49973 .62681 Mdot
.47423 .6833 Mdot
.49791 .273 Mdot
.65199 .52812 Mdot
.49105 .64518 Mdot
.41432 .35218 Mdot
.4764 .25933 Mdot
.4291 .63046 Mdot
.35277 .37192 Mdot
.29741 .63025 Mdot
.46536 .78532 Mdot
.46633 .60181 Mdot
.39159 .55839 Mdot
.49984 .66066 Mdot
.45394 .63929 Mdot
.53045 .62833 Mdot
.78089 .6392 Mdot
.45634 .38434 Mdot
.41198 .38927 Mdot
.34535 .48877 Mdot
.29561 .62645 Mdot
.31689 .50252 Mdot
.62192 .36785 Mdot
.3265 .3554 Mdot
.45329 .39205 Mdot
.63379 .55886 Mdot
.4535 .64706 Mdot
.39868 .3452 Mdot
.47307 .6685 Mdot
.51102 .63093 Mdot
.41117 .40464 Mdot
.45971 .35696 Mdot
.37351 .26783 Mdot
.34292 .48879 Mdot
.67809 .55407 Mdot
.45254 .67547 Mdot
.29519 .51391 Mdot
.49412 .58436 Mdot
.34964 .63769 Mdot
.67449 .55633 Mdot
.65223 .526 Mdot
.61112 .56919 Mdot
.48115 .5912 Mdot
.50618 .633 Mdot
.62458 .39148 Mdot
.63875 .57581 Mdot
.60855 .39476 Mdot
.54389 .45528 Mdot
.35601 .42461 Mdot
.46399 .61353 Mdot
.69492 .32481 Mdot
.3084 .49118 Mdot
.44839 .37209 Mdot
.22525 .60155 Mdot
.34639 .49066 Mdot
.50414 .61355 Mdot
.39387 .38966 Mdot
.32765 .48577 Mdot
.50306 .73821 Mdot
.19909 .35062 Mdot
.35252 .50352 Mdot
.5263 .65693 Mdot
.4271 .58741 Mdot
.82975 .55982 Mdot
.34535 .48558 Mdot
.63116 .36751 Mdot
.48113 .59169 Mdot
.64257 .50713 Mdot
.2884 .50338 Mdot
.59014 .25449 Mdot
.42992 .38568 Mdot
.2133 .41651 Mdot
.43744 .70409 Mdot
.70242 .73607 Mdot
.30817 .48422 Mdot
.65086 .546 Mdot
.63362 .60242 Mdot
.48369 .66622 Mdot
.34653 .48789 Mdot
.60084 .42365 Mdot
.43968 .38507 Mdot
.52513 .26034 Mdot
.66459 .52568 Mdot
.69131 .348 Mdot
.44291 .35122 Mdot
.67897 .30177 Mdot
.402 .7687 Mdot
.46309 .69584 Mdot
.82195 .56419 Mdot
.51458 .36072 Mdot
.45274 .60056 Mdot
.34043 .52583 Mdot
.57933 .36328 Mdot
.62651 .35456 Mdot
.59704 .37886 Mdot
.73324 .46662 Mdot
.41145 .52321 Mdot
.40375 .41393 Mdot
.64691 .32325 Mdot
.30232 .49753 Mdot
.3538 .55695 Mdot
.54747 .61265 Mdot
.49868 .64404 Mdot
.4712 .68516 Mdot
.47799 .67858 Mdot
.49148 .66059 Mdot
.60778 .38648 Mdot
.70382 .46068 Mdot
.42281 .52241 Mdot
.66839 .55654 Mdot
.34292 .31405 Mdot
.4055 .36939 Mdot
.40296 .41443 Mdot
.33573 .48819 Mdot
.67006 .2774 Mdot
.46387 .38676 Mdot
.42523 .35434 Mdot
.4409 .61757 Mdot
.63486 .53437 Mdot
.44306 .58112 Mdot
.5283 .65069 Mdot
.4455 .38656 Mdot
.56962 .48408 Mdot
.71359 .6847 Mdot
.48235 .73228 Mdot
.34363 .53675 Mdot
.42446 .49239 Mdot
.34963 .50525 Mdot
.53361 .61264 Mdot
.44361 .81879 Mdot
.44623 .34403 Mdot
.43418 .36459 Mdot
.3106 .48527 Mdot
.65678 .49174 Mdot
.67085 .53601 Mdot
.60866 .31382 Mdot
.63133 .38501 Mdot
.53877 .62565 Mdot
.28501 .70579 Mdot
.5832 .62028 Mdot
.31039 .34887 Mdot
.59415 .38171 Mdot
.39781 .37327 Mdot
.4874 .68843 Mdot
.52322 .65841 Mdot
.31128 .48825 Mdot
.44361 .21136 Mdot
.50475 .69018 Mdot
.65311 .2294 Mdot
.21242 .55266 Mdot
.20459 .46672 Mdot
.47499 .66586 Mdot
.65482 .52743 Mdot
.45583 .39796 Mdot
.29686 .49437 Mdot
.52705 .57983 Mdot
.22641 .31876 Mdot
.69972 .53887 Mdot
.59402 .35835 Mdot
.52552 .48376 Mdot
.37069 .54356 Mdot
.46751 .59467 Mdot
.46667 .6035 Mdot
.45303 .62545 Mdot
.17191 .40399 Mdot
.45613 .37328 Mdot
.63012 .56913 Mdot
.33555 .51241 Mdot
.62435 .55534 Mdot
.41115 .38475 Mdot
.69517 .36561 Mdot
.49298 .60146 Mdot
.70047 .5379 Mdot
.65292 .54511 Mdot
.5883 .35751 Mdot
.61866 .34185 Mdot
.53848 .47217 Mdot
.47066 .61661 Mdot
.41784 .33414 Mdot
.6786 .57179 Mdot
.39789 .51523 Mdot
.32821 .50364 Mdot
.62504 .37244 Mdot
.50217 .67185 Mdot
.45774 .36168 Mdot
.55681 .6255 Mdot
.67638 .54367 Mdot
.42462 .35495 Mdot
.39848 .26663 Mdot
.33092 .47717 Mdot
.46154 .62933 Mdot
.29782 .46617 Mdot
.39713 .38541 Mdot
.5006 .65086 Mdot
.71886 .31626 Mdot
.36296 .52492 Mdot
.57574 .26287 Mdot
.38772 .37768 Mdot
.43851 .27958 Mdot
.63283 .52925 Mdot
.75656 .48501 Mdot
.43676 .36315 Mdot
.69479 .31284 Mdot
.44429 .22678 Mdot
.48056 .69076 Mdot
.6502 .56931 Mdot
.51787 .37145 Mdot
.40385 .18278 Mdot
.82147 .44982 Mdot
.49052 .62344 Mdot
.38888 .39735 Mdot
.31648 .48652 Mdot
.59736 .40204 Mdot
.35219 .38377 Mdot
.35965 .52986 Mdot
.43353 .33248 Mdot
.53011 .62701 Mdot
.64282 .55065 Mdot
.61829 .37153 Mdot
.70242 .44484 Mdot
.40615 .35973 Mdot
.43174 .34688 Mdot
.48673 .68794 Mdot
.31065 .50255 Mdot
.79023 .49986 Mdot
.42647 .39445 Mdot
.22161 .54558 Mdot
.44232 .32449 Mdot
.3016 .52096 Mdot
.5029 .66341 Mdot
.27469 .56469 Mdot
.43403 .6501 Mdot
.76211 .34471 Mdot
.4074 .37321 Mdot
.67602 .54892 Mdot
.45142 .61443 Mdot
.36415 .74257 Mdot
.4467 .38258 Mdot
.41277 .49303 Mdot
.26496 .38528 Mdot
.6196 .36315 Mdot
.22549 .60441 Mdot
.46759 .63403 Mdot
.61985 .41254 Mdot
.31026 .49135 Mdot
.47652 .61213 Mdot
.50807 .63521 Mdot
.64924 .5838 Mdot
.58599 .36564 Mdot
.40504 .23822 Mdot
.62026 .4248 Mdot
.61428 .34883 Mdot
.64824 .58723 Mdot
.48083 .65109 Mdot
.43734 .35765 Mdot
.43057 .37696 Mdot
.53292 .59131 Mdot
.48126 .84236 Mdot
.67237 .5334 Mdot
.4281 .42574 Mdot
.16942 .42437 Mdot
.54966 .67333 Mdot
.23659 .62468 Mdot
.45873 .20683 Mdot
.58528 .40719 Mdot
.52425 .66096 Mdot
.63686 .55446 Mdot
.45167 .44171 Mdot
.43443 .34857 Mdot
.47442 .58391 Mdot
.61494 .3703 Mdot
.34576 .50296 Mdot
.42801 .40556 Mdot
.31691 .34205 Mdot
.45684 .63752 Mdot
.28387 .43728 Mdot
.39998 .40752 Mdot
.54041 .15479 Mdot
.54234 .33864 Mdot
.65546 .57017 Mdot
.51341 .63291 Mdot
.61644 .54976 Mdot
.33818 .50748 Mdot
.52551 .482 Mdot
.61544 .36675 Mdot
.40599 .66737 Mdot
.32027 .796 Mdot
.40313 .39087 Mdot
.6273 .56715 Mdot
.48735 .68521 Mdot
.62813 .48597 Mdot
.47037 .64069 Mdot
.48697 .55594 Mdot
.37324 .4839 Mdot
.60916 .40496 Mdot
.6237 .40805 Mdot
.50853 .6495 Mdot
.31447 .52369 Mdot
.40382 .3665 Mdot
.44334 .38195 Mdot
.67596 .20844 Mdot
.64223 .44391 Mdot
.30461 .68359 Mdot
.46023 .61716 Mdot
.41662 .33806 Mdot
.4797 .24507 Mdot
.59091 .38608 Mdot
.55047 .60794 Mdot
.41302 .40158 Mdot
.23192 .45496 Mdot
.36838 .72913 Mdot
.49188 .6636 Mdot
.45319 .58666 Mdot
.63185 .37915 Mdot
.39988 .54359 Mdot
.40031 .35676 Mdot
.53892 .67914 Mdot
.56941 .36188 Mdot
.42147 .75238 Mdot
.18661 .45935 Mdot
.67817 .55438 Mdot
.30653 .3304 Mdot
.60852 .38677 Mdot
.45283 .58495 Mdot
.30325 .51445 Mdot
.46207 .38346 Mdot
.45763 .37254 Mdot
.51923 .6155 Mdot
.54059 .6538 Mdot
.24138 .60601 Mdot
.62666 .55011 Mdot
.60265 .34891 Mdot
.4779 .59995 Mdot
.73291 .37876 Mdot
.47587 .68062 Mdot
.62129 .39484 Mdot
.16584 .66401 Mdot
.46559 .68857 Mdot
.4702 .64483 Mdot
.79561 .48886 Mdot
.67017 .52053 Mdot
.62524 .56767 Mdot
.24065 .66409 Mdot
.46017 .61807 Mdot
.22039 .57858 Mdot
.68179 .55 Mdot
.6741 .53656 Mdot
.52129 .27204 Mdot
.50007 .63877 Mdot
.40977 .69182 Mdot
.60405 .41159 Mdot
.62002 .35271 Mdot
.66008 .52248 Mdot
.47955 .69453 Mdot
.58696 .34916 Mdot
.78491 .58939 Mdot
.42519 .36965 Mdot
.45852 .8221 Mdot
.67925 .53098 Mdot
.5652 .43738 Mdot
.59272 .38547 Mdot
.24341 .25897 Mdot
.43326 .31482 Mdot
.49034 .60313 Mdot
.45899 .62713 Mdot
.30505 .49241 Mdot
.4605 .68379 Mdot
.40727 .34619 Mdot
.60386 .3802 Mdot
.60357 .63556 Mdot
.67411 .56047 Mdot
.47256 .62773 Mdot
.66185 .26803 Mdot
.5801 .23872 Mdot
.30675 .31653 Mdot
.66343 .53572 Mdot
.65714 .57375 Mdot
.40891 .35096 Mdot
.39049 .39869 Mdot
.48097 .65922 Mdot
.5876 .39812 Mdot
.64 .576 Mdot
.6187 .40131 Mdot
.44658 .34476 Mdot
.43391 .35472 Mdot
.45932 .37705 Mdot
.55647 .63598 Mdot
.41973 .35295 Mdot
.35489 .32925 Mdot
.68619 .34233 Mdot
.62861 .58283 Mdot
.18895 .55038 Mdot
.71046 .44589 Mdot
.73933 .53019 Mdot
.28584 .50052 Mdot
.39681 .38663 Mdot
.62568 .41649 Mdot
.51776 .65156 Mdot
.48166 .67405 Mdot
.39689 .29656 Mdot
.61647 .41812 Mdot
.33769 .50368 Mdot
.62425 .41101 Mdot
.33044 .51803 Mdot
.26104 .4255 Mdot
.46134 .67825 Mdot
.54592 .62321 Mdot
.60367 .38615 Mdot
.42112 .35418 Mdot
.42166 .38916 Mdot
.352 .49564 Mdot
.61593 .46128 Mdot
.41916 .39899 Mdot
.68055 .53527 Mdot
.74495 .62031 Mdot
.44357 .40476 Mdot
.46631 .61763 Mdot
.36192 .61617 Mdot
.72969 .70806 Mdot
.43269 .62469 Mdot
.5123 .27179 Mdot
.63222 .78354 Mdot
.44636 .63112 Mdot
.69442 .75714 Mdot
.45844 .29354 Mdot
.6318 .53149 Mdot
.39512 .36429 Mdot
.45589 .40658 Mdot
.56512 .61583 Mdot
.35869 .50576 Mdot
.52868 .58394 Mdot
.68277 .52916 Mdot
.6545 .51012 Mdot
.21579 .48078 Mdot
.78692 .38637 Mdot
.32055 .48633 Mdot
.32796 .48359 Mdot
.43915 .36577 Mdot
.81959 .36828 Mdot
.41791 .66333 Mdot
.33662 .50013 Mdot
.48203 .53797 Mdot
.5279 .62337 Mdot
.3265 .66717 Mdot
.26798 .46692 Mdot
.65937 .52502 Mdot
.28829 .56039 Mdot
.44385 .36535 Mdot
.62134 .54921 Mdot
.7381 .39874 Mdot
.4405 .64774 Mdot
.67361 .55786 Mdot
.62177 .39882 Mdot
.55888 .31146 Mdot
.6893 .53922 Mdot
.35667 .62667 Mdot
.58303 .37235 Mdot
.40154 .50929 Mdot
.2849 .58567 Mdot
.71819 .80843 Mdot
.60768 .38291 Mdot
.44669 .39835 Mdot
.4315 .37753 Mdot
.44348 .37993 Mdot
.62413 .55064 Mdot
.3936 .38293 Mdot
.6275 .55468 Mdot
.82409 .50721 Mdot
.6446 .49289 Mdot
.3352 .49758 Mdot
.53337 .26175 Mdot
.64401 .55898 Mdot
.4135 .82104 Mdot
.42213 .85674 Mdot
.52441 .66144 Mdot
.63226 .41233 Mdot
.3302 .49145 Mdot
.66695 .23205 Mdot
.31743 .49639 Mdot
.24406 .53613 Mdot
.45569 .79748 Mdot
.47649 .63595 Mdot
.6625 .70846 Mdot
.30125 .48078 Mdot
.65351 .53772 Mdot
.5015 .64905 Mdot
.49715 .40583 Mdot
.31356 .49738 Mdot
.33851 .51662 Mdot
.48732 .65384 Mdot
.68209 .56367 Mdot
.44355 .35986 Mdot
.63625 .38074 Mdot
.2915 .48089 Mdot
.66373 .59646 Mdot
.43461 .6271 Mdot
.50622 .60434 Mdot
.44479 .50718 Mdot
.27272 .49019 Mdot
.60511 .37768 Mdot
.75504 .69368 Mdot
.38764 .38348 Mdot
.50238 .39059 Mdot
.21881 .53215 Mdot
.49274 .27901 Mdot
.40977 .37359 Mdot
.39946 .38112 Mdot
.48789 .66188 Mdot
.27228 .50135 Mdot
.46756 .79603 Mdot
.65109 .39597 Mdot
.45408 .39969 Mdot
.44164 .38511 Mdot
.62702 .52623 Mdot
.21444 .48947 Mdot
.52642 .57801 Mdot
.58228 .35663 Mdot
.4587 .36916 Mdot
.66406 .47649 Mdot
.30695 .50202 Mdot
.41439 .80713 Mdot
.45809 .67516 Mdot
.4858 .6021 Mdot
.60403 .36629 Mdot
.62522 .38622 Mdot
.44416 .4462 Mdot
.22358 .50807 Mdot
.64899 .77309 Mdot
.68067 .44519 Mdot
.52302 .75706 Mdot
.63828 .51771 Mdot
.64677 .57667 Mdot
.61187 .27296 Mdot
.62095 .42525 Mdot
.44755 .62383 Mdot
.6343 .56837 Mdot
.4974 .35995 Mdot
.74789 .56375 Mdot
.31205 .67386 Mdot
.24876 .63342 Mdot
.50591 .61713 Mdot
.64138 .53375 Mdot
.67127 .52149 Mdot
.69459 .57051 Mdot
.47038 .30487 Mdot
.47414 .65675 Mdot
.4983 .61973 Mdot
.45171 .65161 Mdot
.5857 .53367 Mdot
.46123 .65274 Mdot
.74919 .4842 Mdot
.51191 .47103 Mdot
.55302 .71934 Mdot
.53372 .68176 Mdot
.57535 .38797 Mdot
.47017 .59402 Mdot
.3176 .52395 Mdot
.53397 .63278 Mdot
.31592 .68017 Mdot
.58913 .36979 Mdot
.73391 .53861 Mdot
.7169 .45466 Mdot
.44882 .60875 Mdot
.32632 .47086 Mdot
.5381 .37245 Mdot
.34039 .23119 Mdot
.32384 .46244 Mdot
.68016 .53426 Mdot
.41913 .37014 Mdot
.62298 .41842 Mdot
.43178 .35732 Mdot
.55171 .64481 Mdot
.62043 .27986 Mdot
.5829 .22246 Mdot
.55544 .45711 Mdot
.48083 .67809 Mdot
.45949 .71687 Mdot
.67765 .53848 Mdot
.39416 .39145 Mdot
.63692 .50604 Mdot
.4524 .61597 Mdot
.32843 .51596 Mdot
.30952 .4947 Mdot
.51259 .386 Mdot
.51305 .17695 Mdot
.7542 .52646 Mdot
.60435 .36893 Mdot
.43237 .39512 Mdot
.29254 .49738 Mdot
.75732 .37184 Mdot
.61967 .34161 Mdot
.59264 .40758 Mdot
.59131 .358 Mdot
.496 .58957 Mdot
.45465 .3912 Mdot
.55759 .71389 Mdot
.41838 .3384 Mdot
.50252 .62677 Mdot
.45505 .36506 Mdot
.41207 .39952 Mdot
.2971 .50278 Mdot
.59619 .35145 Mdot
.43235 .34024 Mdot
.53633 .64696 Mdot
.68355 .55569 Mdot
.56754 .42591 Mdot
.35705 .70158 Mdot
.77683 .37195 Mdot
.62038 .62032 Mdot
.69037 .52712 Mdot
.40083 .18922 Mdot
.58667 .40558 Mdot
.56689 .53277 Mdot
.36557 .27734 Mdot
.52077 .60388 Mdot
.44064 .84369 Mdot
.40766 .41636 Mdot
.41778 .40498 Mdot
.50382 .66191 Mdot
.48153 .39949 Mdot
.47278 .63319 Mdot
.44404 .34697 Mdot
.38731 .29281 Mdot
.58219 .57894 Mdot
.41454 .35869 Mdot
.54424 .67338 Mdot
.50796 .64132 Mdot
.65605 .52484 Mdot
.41574 .41481 Mdot
.55103 .60618 Mdot
.65201 .19818 Mdot
.62286 .38717 Mdot
.49037 .32053 Mdot
.36718 .62978 Mdot
.60921 .38794 Mdot
.66725 .56499 Mdot
.52645 .59385 Mdot
.31124 .48962 Mdot
.64198 .55832 Mdot
.37585 .73864 Mdot
.3156 .47711 Mdot
.42013 .83042 Mdot
.66973 .52299 Mdot
.4378 .40748 Mdot
.30662 .51779 Mdot
.44848 .67645 Mdot
.46153 .38443 Mdot
.56042 .33126 Mdot
.40973 .37182 Mdot
.47076 .66377 Mdot
.53404 .25161 Mdot
.60791 .3485 Mdot
.48787 .62228 Mdot
.41906 .40753 Mdot
.49831 .27064 Mdot
.49975 .59149 Mdot
.50456 .65539 Mdot
.19561 .47737 Mdot
.35481 .78139 Mdot
.32439 .49928 Mdot
.70609 .56008 Mdot
.5272 .6555 Mdot
.34166 .5104 Mdot
.31012 .41156 Mdot
.4867 .59337 Mdot
.70102 .54252 Mdot
.5219 .70265 Mdot
.40795 .41202 Mdot
.61352 .39182 Mdot
.55449 .45049 Mdot
.34439 .50543 Mdot
.84452 .61424 Mdot
.4408 .33743 Mdot
.53873 .61289 Mdot
.49034 .6784 Mdot
.25319 .35655 Mdot
.63018 .53342 Mdot
.56119 .80162 Mdot
.46134 .6292 Mdot
.5795 .5369 Mdot
.47685 .61591 Mdot
.42374 .4234 Mdot
.67206 .53562 Mdot
.46827 .64883 Mdot
.69331 .33336 Mdot
.43363 .61375 Mdot
.34291 .48649 Mdot
.80009 .48927 Mdot
.43917 .61555 Mdot
.25098 .75622 Mdot
.25502 .48128 Mdot
.41317 .35818 Mdot
.57529 .24721 Mdot
.76657 .26025 Mdot
.73359 .46296 Mdot
.62753 .55965 Mdot
.50003 .20357 Mdot
.43698 .35695 Mdot
.52809 .23791 Mdot
.39407 .18886 Mdot
.51264 .64202 Mdot
.46719 .59473 Mdot
.2472 .50958 Mdot
.38911 .36501 Mdot
.43844 .32957 Mdot
.52189 .67974 Mdot
.46526 .57598 Mdot
.42983 .35074 Mdot
.54096 .64399 Mdot
.54134 .66118 Mdot
.63753 .3884 Mdot
.69293 .53338 Mdot
.60343 .40636 Mdot
.58168 .36549 Mdot
.79082 .55753 Mdot
.24646 .4719 Mdot
.62035 .39302 Mdot
.57808 .38478 Mdot
.32851 .672 Mdot
.25741 .6065 Mdot
.2881 .50227 Mdot
.55854 .17166 Mdot
.44086 .38164 Mdot
.47568 .65302 Mdot
.68269 .52392 Mdot
.66298 .76118 Mdot
.34378 .39264 Mdot
.48162 .8099 Mdot
.44957 .62029 Mdot
.44677 .37552 Mdot
.47063 .30478 Mdot
.45767 .57082 Mdot
.37946 .36311 Mdot
.47662 .59853 Mdot
.44254 .33292 Mdot
.70264 .65008 Mdot
.68936 .31054 Mdot
.44034 .32647 Mdot
.6244 .58532 Mdot
.47952 .60319 Mdot
.67845 .52868 Mdot
.59518 .39055 Mdot
.29773 .51338 Mdot
.32483 .50258 Mdot
.49595 .65202 Mdot
.4825 .70416 Mdot
.26736 .43302 Mdot
.5035 .6377 Mdot
.52866 .62919 Mdot
.45784 .29302 Mdot
.5304 .63372 Mdot
.47042 .67419 Mdot
.45982 .66291 Mdot
.48169 .58119 Mdot
.6175 .35086 Mdot
.66604 .27578 Mdot
.53097 .56975 Mdot
.51575 .5644 Mdot
.61476 .3423 Mdot
.42038 .22444 Mdot
.58095 .3831 Mdot
.34586 .21993 Mdot
.61117 .41083 Mdot
.33138 .50524 Mdot
.29931 .2953 Mdot
.44925 .70034 Mdot
.68492 .56777 Mdot
.63259 .34826 Mdot
.3359 .51392 Mdot
.59994 .37979 Mdot
.44735 .35386 Mdot
.18269 .42035 Mdot
.71239 .56639 Mdot
.40669 .56737 Mdot
.64086 .35203 Mdot
.62549 .29008 Mdot
.42771 .33892 Mdot
.67146 .52896 Mdot
.70219 .69481 Mdot
.4737 .67818 Mdot
.33923 .51413 Mdot
.48467 .65821 Mdot
.59784 .34756 Mdot
.44424 .36966 Mdot
.815 .45676 Mdot
.31092 .48857 Mdot
.19255 .53503 Mdot
.42578 .38614 Mdot
.4578 .66486 Mdot
.58398 .35433 Mdot
.20092 .60836 Mdot
.60735 .4066 Mdot
.52364 .78793 Mdot
.62221 .53594 Mdot
.8384 .53699 Mdot
.64543 .56423 Mdot
.57505 .31801 Mdot
.1479 .53233 Mdot
.67976 .27349 Mdot
.68218 .56208 Mdot
.66533 .38487 Mdot
.50789 .61244 Mdot
.5046 .60379 Mdot
.76776 .37997 Mdot
.70598 .55932 Mdot
.5142 .66715 Mdot
.41903 .27108 Mdot
.68207 .35589 Mdot
.26011 .66845 Mdot
.4007 .3757 Mdot
.46925 .63123 Mdot
.57689 .34742 Mdot
.61522 .41504 Mdot
.43226 .33506 Mdot
.58866 .40598 Mdot
.49749 .62153 Mdot
.64448 .55995 Mdot
.39603 .43666 Mdot
.31947 .51107 Mdot
.73094 .28174 Mdot
.32258 .52795 Mdot
.41 .37408 Mdot
.4556 .68707 Mdot
.43288 .35431 Mdot
.77512 .25095 Mdot
.49541 .61532 Mdot
.68091 .54891 Mdot
.5269 .6493 Mdot
.48093 .60587 Mdot
.46351 .59541 Mdot
.44103 .35242 Mdot
.43126 .73413 Mdot
.53836 .64596 Mdot
.61607 .36617 Mdot
.54689 .73301 Mdot
.4397 .6172 Mdot
.46208 .41032 Mdot
.28052 .62963 Mdot
.64324 .32779 Mdot
.6675 .51637 Mdot
.41037 .36408 Mdot
.67557 .56231 Mdot
.59807 .55639 Mdot
.66722 .56474 Mdot
.57182 .74687 Mdot
.70665 .68238 Mdot
.45283 .7596 Mdot
.65232 .62559 Mdot
.55229 .50134 Mdot
.70595 .55993 Mdot
.27738 .46856 Mdot
.65442 .57985 Mdot
.66471 .51984 Mdot
.07793 .55766 Mdot
.68116 .57362 Mdot
.46399 .62093 Mdot
.44058 .639 Mdot
.65168 .29373 Mdot
.33101 .62348 Mdot
.52326 .64649 Mdot
.51971 .65738 Mdot
.29547 .50634 Mdot
.57214 .54891 Mdot
.59325 .2614 Mdot
.34924 .78766 Mdot
.54987 .22893 Mdot
.48688 .656 Mdot
.5288 .65351 Mdot
.45426 .57709 Mdot
.22046 .68342 Mdot
.80119 .57871 Mdot
.69527 .51495 Mdot
.43408 .60058 Mdot
.73041 .30388 Mdot
.46174 .59896 Mdot
.48299 .5884 Mdot
.50628 .61523 Mdot
.43768 .35757 Mdot
.69436 .52228 Mdot
.50292 .5784 Mdot
.23959 .49314 Mdot
.4748 .59562 Mdot
.49601 .27675 Mdot
.84702 .45392 Mdot
.46721 .63453 Mdot
.68582 .51695 Mdot
.51229 .60648 Mdot
.64133 .5263 Mdot
.65016 .53518 Mdot
.42817 .66256 Mdot
.52858 .75406 Mdot
.66016 .51095 Mdot
.50316 .62712 Mdot
.44863 .36434 Mdot
.5307 .15942 Mdot
.46936 .66281 Mdot
.29325 .50989 Mdot
.45943 .6256 Mdot
.32053 .47022 Mdot
.52686 .63236 Mdot
.44186 .33714 Mdot
.70323 .7301 Mdot
.436 .36604 Mdot
.81986 .57877 Mdot
.46046 .36368 Mdot
.19391 .4865 Mdot
.70379 .53639 Mdot
.53184 .25712 Mdot
.60054 .81427 Mdot
.48857 .30337 Mdot
.39968 .48103 Mdot
.48001 .47521 Mdot
.58767 .39887 Mdot
.62031 .54271 Mdot
.51659 .52566 Mdot
.36887 .28428 Mdot
.33027 .29626 Mdot
.42572 .40031 Mdot
.6929 .77897 Mdot
.50323 .82703 Mdot
.54261 .62734 Mdot
.64 .72447 Mdot
.61622 .68762 Mdot
.46652 .59336 Mdot
.50371 .58052 Mdot
.41794 .29614 Mdot
.53345 .65726 Mdot
.72941 .37043 Mdot
.41102 .37735 Mdot
.33589 .51487 Mdot
.68112 .54192 Mdot
.34582 .50499 Mdot
.36374 .28463 Mdot
.47314 .47716 Mdot
.44701 .348 Mdot
.45111 .59081 Mdot
.51826 .65508 Mdot
.64646 .5258 Mdot
.69445 .50226 Mdot
.66655 .57858 Mdot
.32286 .48857 Mdot
.41645 .37932 Mdot
.75283 .67011 Mdot
.51272 .66285 Mdot
.65388 .54583 Mdot
.39506 .4691 Mdot
.52568 .65767 Mdot
.60075 .39024 Mdot
.50241 .61044 Mdot
.68666 .55473 Mdot
.5303 .63391 Mdot
.64358 .56465 Mdot
.42163 .36881 Mdot
.44303 .63628 Mdot
.49808 .66385 Mdot
.196 .57743 Mdot
.33555 .5066 Mdot
.70505 .54514 Mdot
.46151 .3133 Mdot
.49193 .68075 Mdot
.54228 .27915 Mdot
.47221 .60201 Mdot
.75368 .55442 Mdot
.51979 .59965 Mdot
.48128 .30144 Mdot
.53488 .57552 Mdot
.46872 .66058 Mdot
.42642 .45903 Mdot
.60998 .7048 Mdot
.71277 .52768 Mdot
.57957 .35871 Mdot
.69244 .56513 Mdot
.2663 .67082 Mdot
.44553 .32337 Mdot
.39474 .39639 Mdot
.34343 .56641 Mdot
.48058 .58056 Mdot
.47664 .63865 Mdot
.58885 .33712 Mdot
.33236 .4825 Mdot
.66142 .53617 Mdot
.33059 .51784 Mdot
.21185 .57563 Mdot
.31701 .47995 Mdot
.41424 .41956 Mdot
.28586 .43571 Mdot
.76558 .6388 Mdot
.2955 .50517 Mdot
.68308 .56311 Mdot
.35859 .43435 Mdot
.47066 .58493 Mdot
.25795 .48123 Mdot
.3217 .51639 Mdot
.75465 .73285 Mdot
.47074 .67369 Mdot
.39596 .48175 Mdot
.61482 .39716 Mdot
.30092 .51274 Mdot
.58543 .38448 Mdot
.51594 .65024 Mdot
.57887 .26172 Mdot
.63038 .56225 Mdot
.60122 .34286 Mdot
.48994 .70014 Mdot
.33175 .49158 Mdot
.45697 .37941 Mdot
.60769 .33121 Mdot
.58311 .35278 Mdot
.44214 .20914 Mdot
.81693 .48059 Mdot
.41908 .38003 Mdot
.37619 .76181 Mdot
.60876 .41225 Mdot
.45837 .59575 Mdot
.55102 .54281 Mdot
.48987 .60249 Mdot
.75374 .50227 Mdot
.40599 .36757 Mdot
.6535 .28536 Mdot
.52955 .64827 Mdot
.45082 .64054 Mdot
.71164 .5322 Mdot
.43575 .37421 Mdot
.6581 .55572 Mdot
.69108 .56896 Mdot
.42313 .36968 Mdot
.6527 .56858 Mdot
.30999 .47697 Mdot
.68835 .39018 Mdot
.63156 .3906 Mdot
.61099 .35963 Mdot
.4432 .38356 Mdot
.41135 .35693 Mdot
.42661 .35452 Mdot
.50215 .6101 Mdot
.66722 .53463 Mdot
.51732 .63235 Mdot
.47305 .59407 Mdot
.51073 .7578 Mdot
.68255 .52049 Mdot
.51301 .62138 Mdot
.4877 .41329 Mdot
.28257 .52469 Mdot
.45032 .36569 Mdot
.61831 .39382 Mdot
.46871 .25014 Mdot
.55601 .34339 Mdot
.469 .62667 Mdot
.23524 .44969 Mdot
.67535 .57184 Mdot
.31197 .49223 Mdot
.29067 .51881 Mdot
.32002 .49703 Mdot
.62989 .43655 Mdot
.70564 .55687 Mdot
.35617 .79334 Mdot
.47146 .63496 Mdot
.43991 .50686 Mdot
.46324 .53905 Mdot
.25553 .43664 Mdot
.62013 .39066 Mdot
.52393 .65707 Mdot
.56469 .45429 Mdot
.71509 .69122 Mdot
.4893 .60483 Mdot
.447 .60173 Mdot
.39838 .2696 Mdot
.52515 .70231 Mdot
.61524 .54433 Mdot
.20957 .61609 Mdot
.47212 .6869 Mdot
.66281 .47891 Mdot
.75078 .29113 Mdot
.46902 .61462 Mdot
.45146 .6279 Mdot
.49159 .67258 Mdot
.5344 .62986 Mdot
.66745 .51242 Mdot
.30783 .59027 Mdot
.58991 .41052 Mdot
.43284 .51369 Mdot
.62891 .35992 Mdot
.46373 .36862 Mdot
.66618 .28296 Mdot
.61874 .54443 Mdot
.30535 .49209 Mdot
.65548 .24522 Mdot
.26719 .70981 Mdot
.3993 .35809 Mdot
.78287 .58348 Mdot
.32873 .51411 Mdot
.45301 .59903 Mdot
.30847 .47523 Mdot
.45211 .39394 Mdot
.61734 .362 Mdot
.46852 .5812 Mdot
.65498 .57869 Mdot
.68882 .53684 Mdot
.51973 .66416 Mdot
.71424 .29019 Mdot
.60366 .39321 Mdot
.60008 .33548 Mdot
.49233 .59154 Mdot
.44886 .67624 Mdot
.65939 .5583 Mdot
.43093 .39236 Mdot
.32898 .71837 Mdot
.33775 .48952 Mdot
.55509 .62658 Mdot
.53071 .62685 Mdot
.21803 .5231 Mdot
.62227 .36968 Mdot
.38451 .3912 Mdot
.51314 .59903 Mdot
.66987 .4464 Mdot
.51459 .60049 Mdot
.43159 .59914 Mdot
.44925 .36789 Mdot
.54599 .57591 Mdot
.54601 .62958 Mdot
.48843 .55346 Mdot
.59204 .40064 Mdot
.67593 .55329 Mdot
.67769 .58656 Mdot
.45734 .51827 Mdot
.59961 .38844 Mdot
.51359 .61592 Mdot
.61913 .38283 Mdot
.48628 .59417 Mdot
.52882 .65933 Mdot
.62094 .39506 Mdot
.6574 .55651 Mdot
.49758 .2069 Mdot
.66277 .27233 Mdot
.53616 .63084 Mdot
.4951 .68829 Mdot
.31762 .60258 Mdot
.42635 .73137 Mdot
.45531 .60997 Mdot
.68856 .54844 Mdot
.50901 .66245 Mdot
.58647 .37997 Mdot
.29826 .48379 Mdot
.68426 .55593 Mdot
.41536 .38968 Mdot
.40866 .34916 Mdot
.7224 .45638 Mdot
.40047 .39349 Mdot
.47972 .58508 Mdot
.60589 .53905 Mdot
.69539 .57705 Mdot
.74898 .30392 Mdot
.42646 .3717 Mdot
.28583 .49453 Mdot
.50345 .65441 Mdot
.21854 .45095 Mdot
.57838 .34253 Mdot
.30521 .80884 Mdot
.40463 .82196 Mdot
.35626 .51244 Mdot
.48649 .80352 Mdot
.45807 .34867 Mdot
.54986 .63176 Mdot
.3005 .51663 Mdot
.4065 .3534 Mdot
.52302 .60871 Mdot
.42109 .63153 Mdot
.54766 .80166 Mdot
.50245 .50112 Mdot
.62057 .38145 Mdot
.39133 .3809 Mdot
.35115 .52614 Mdot
.39286 .40898 Mdot
.6838 .52674 Mdot
.46924 .65686 Mdot
.44856 .6848 Mdot
.42167 .39228 Mdot
.38393 .37531 Mdot
.50661 .62301 Mdot
.61661 .54913 Mdot
.42232 .29796 Mdot
.49033 .65048 Mdot
.56846 .50608 Mdot
.61678 .58919 Mdot
.40704 .38038 Mdot
.45512 .65056 Mdot
.37655 .4798 Mdot
.42731 .38828 Mdot
.4512 .36614 Mdot
.52502 .66137 Mdot
.31359 .47633 Mdot
.48967 .6881 Mdot
.62173 .40818 Mdot
.75468 .70333 Mdot
.58573 .37316 Mdot
.35439 .38812 Mdot
.48477 .70175 Mdot
.6443 .45288 Mdot
.65524 .51698 Mdot
.24543 .52633 Mdot
.43014 .26229 Mdot
.52446 .67969 Mdot
.48175 .1776 Mdot
.55664 .42854 Mdot
.69715 .26904 Mdot
.27206 .29684 Mdot
.30732 .51164 Mdot
.59761 .3797 Mdot
.4516 .62629 Mdot
.63469 .40441 Mdot
.29779 .51557 Mdot
.81859 .57242 Mdot
.45795 .65717 Mdot
.67305 .5371 Mdot
.50296 .62005 Mdot
.67946 .53191 Mdot
.52737 .65841 Mdot
.47668 .5656 Mdot
.43495 .27649 Mdot
.3682 .7282 Mdot
.51209 .59481 Mdot
.17496 .45677 Mdot
.33733 .45023 Mdot
.34091 .50451 Mdot
.51305 .63637 Mdot
.38717 .34697 Mdot
.61215 .41798 Mdot
.76426 .40255 Mdot
.43784 .35661 Mdot
.57909 .37455 Mdot
.6594 .56489 Mdot
.41136 .3685 Mdot
.40848 .34739 Mdot
.54894 .57854 Mdot
.33837 .47764 Mdot
.60079 .35323 Mdot
.46652 .64879 Mdot
.4596 .658 Mdot
.34847 .75039 Mdot
.33996 .37073 Mdot
.70913 .50816 Mdot
.27261 .74157 Mdot
.65206 .58871 Mdot
.33825 .49923 Mdot
.44242 .35775 Mdot
.46283 .6049 Mdot
.48926 .62514 Mdot
.51923 .26309 Mdot
.63565 .57545 Mdot
.53312 .47937 Mdot
.76123 .58139 Mdot
.45075 .31193 Mdot
.30316 .64471 Mdot
.68462 .54307 Mdot
.30571 .6472 Mdot
.31806 .53165 Mdot
.60157 .19431 Mdot
.34649 .70511 Mdot
.61522 .39473 Mdot
.30369 .64142 Mdot
.65037 .54347 Mdot
.54076 .63585 Mdot
.43793 .40816 Mdot
.41016 .39857 Mdot
.6688 .55374 Mdot
.3763 .38566 Mdot
.29825 .50108 Mdot
.45472 .63668 Mdot
.34311 .77863 Mdot
.72964 .43759 Mdot
.44148 .39318 Mdot
.4724 .56485 Mdot
.5905 .35933 Mdot
.51875 .66553 Mdot
.29409 .49872 Mdot
.61152 .38159 Mdot
.23171 .52032 Mdot
.67412 .32766 Mdot
.50238 .6517 Mdot
.20141 .49032 Mdot
.60276 .38479 Mdot
.41094 .716 Mdot
.48258 .65303 Mdot
.60487 .41131 Mdot
.46861 .73063 Mdot
.56098 .31354 Mdot
.56562 .4605 Mdot
.39629 .18759 Mdot
.54589 .4639 Mdot
.43919 .4046 Mdot
.58879 .29937 Mdot
.50934 .34888 Mdot
.62978 .41098 Mdot
.38231 .38215 Mdot
.30989 .54261 Mdot
.5857 .38663 Mdot
.44267 .61316 Mdot
.47145 .60532 Mdot
.80632 .57466 Mdot
.54398 .41924 Mdot
.59123 .31121 Mdot
.76637 .45555 Mdot
.48707 .68191 Mdot
.4744 .69043 Mdot
.48687 .62929 Mdot
.65739 .50994 Mdot
.62029 .37451 Mdot
.17373 .5147 Mdot
.59878 .39195 Mdot
.4055 .79892 Mdot
.4423 .37967 Mdot
.3996 .37072 Mdot
.46738 .62993 Mdot
.39108 .50702 Mdot
.26592 .58242 Mdot
.49838 .62379 Mdot
.33072 .54907 Mdot
.80063 .48273 Mdot
.45614 .68178 Mdot
.63571 .52452 Mdot
.55494 .56943 Mdot
.65558 .60129 Mdot
.63163 .39151 Mdot
.30822 .50504 Mdot
.24866 .53303 Mdot
.61544 .35801 Mdot
.47773 .63804 Mdot
.66427 .4276 Mdot
.48327 .6105 Mdot
.53568 .62488 Mdot
.42948 .81335 Mdot
.33218 .52799 Mdot
.42455 .36013 Mdot
.32228 .49587 Mdot
.64539 .52275 Mdot
.18513 .71525 Mdot
.33317 .48028 Mdot
.2614 .57447 Mdot
.80823 .60784 Mdot
.30668 .64227 Mdot
.6856 .52983 Mdot
.34018 .4772 Mdot
.60925 .39401 Mdot
.54574 .15511 Mdot
.59453 .80511 Mdot
.56364 .40115 Mdot
.48949 .64624 Mdot
.61456 .56057 Mdot
.69299 .54777 Mdot
.60857 .34208 Mdot
.65142 .53583 Mdot
.45884 .72526 Mdot
.53919 .63189 Mdot
.63151 .41158 Mdot
.68186 .43409 Mdot
.57989 .35675 Mdot
.69756 .36842 Mdot
.50907 .63401 Mdot
.68413 .5482 Mdot
.55429 .64935 Mdot
.60238 .58526 Mdot
.38897 .40324 Mdot
.43331 .62804 Mdot
.29839 .49938 Mdot
.64574 .45904 Mdot
.41956 .38187 Mdot
.24229 .43752 Mdot
.64936 .52387 Mdot
.65395 .34115 Mdot
.65405 .5263 Mdot
.70163 .567 Mdot
.58098 .37072 Mdot
.63421 .55143 Mdot
.45201 .63113 Mdot
.50928 .38727 Mdot
.62812 .53966 Mdot
.59752 .36389 Mdot
.31352 .50617 Mdot
.65112 .56462 Mdot
.47908 .40326 Mdot
.4973 .65847 Mdot
.43328 .34707 Mdot
.29048 .30805 Mdot
.63376 .58159 Mdot
.34864 .51053 Mdot
.39494 .39484 Mdot
.33686 .51816 Mdot
.80103 .3767 Mdot
.63397 .41392 Mdot
.4577 .79505 Mdot
.34514 .53856 Mdot
.68076 .57176 Mdot
.3042 .29285 Mdot
.46352 .60639 Mdot
.5004 .65716 Mdot
.31438 .46994 Mdot
.69285 .5483 Mdot
.64966 .2253 Mdot
.71468 .58078 Mdot
.68237 .37655 Mdot
.6417 .36586 Mdot
.18798 .47464 Mdot
.7028 .35629 Mdot
.83377 .38475 Mdot
.50348 .69198 Mdot
.44339 .32978 Mdot
.4743 .62593 Mdot
.44342 .26112 Mdot
.33055 .49252 Mdot
.41314 .43324 Mdot
.42634 .64153 Mdot
.41928 .36444 Mdot
.4856 .66866 Mdot
.46347 .44457 Mdot
.56494 .59309 Mdot
.28546 .49734 Mdot
.5804 .252 Mdot
.68552 .57019 Mdot
.32157 .51259 Mdot
.44637 .34178 Mdot
.27786 .60399 Mdot
.53227 .61678 Mdot
.55987 .62528 Mdot
.45044 .31199 Mdot
.67238 .53168 Mdot
.42285 .41217 Mdot
.62876 .39963 Mdot
.30634 .49669 Mdot
.51969 .65123 Mdot
.49905 .58527 Mdot
.53832 .28075 Mdot
.59132 .35605 Mdot
.386 .36254 Mdot
.6033 .40454 Mdot
.45603 .3419 Mdot
.52596 .66697 Mdot
.39761 .37357 Mdot
.55126 .61622 Mdot
.44884 .27737 Mdot
.42683 .80892 Mdot
.61765 .714 Mdot
.40496 .36975 Mdot
.2913 .65472 Mdot
.58883 .37257 Mdot
.60412 .40845 Mdot
.78121 .64073 Mdot
.52344 .79124 Mdot
.31584 .73937 Mdot
.38755 .22544 Mdot
.63067 .36465 Mdot
.59215 .36066 Mdot
.42809 .34642 Mdot
.6329 .54892 Mdot
.67066 .58472 Mdot
.45198 .33815 Mdot
.36449 .61741 Mdot
.66127 .53636 Mdot
.52953 .16942 Mdot
.2767 .69414 Mdot
.51945 .58605 Mdot
.37588 .35432 Mdot
.31197 .49776 Mdot
.35709 .61869 Mdot
.46083 .44515 Mdot
.44925 .6342 Mdot
.22965 .49595 Mdot
.43915 .38973 Mdot
.39356 .54769 Mdot
.34751 .22038 Mdot
.46171 .66503 Mdot
.47692 .65395 Mdot
.4806 .63148 Mdot
.35419 .50026 Mdot
.56975 .79394 Mdot
.45684 .64886 Mdot
.36533 .62065 Mdot
.50394 .67543 Mdot
.45171 .73259 Mdot
.32433 .50061 Mdot
.49016 .74312 Mdot
.37863 .26818 Mdot
.22068 .62905 Mdot
.56961 .60816 Mdot
.62695 .40431 Mdot
.30003 .54973 Mdot
.59587 .40694 Mdot
.58259 .73983 Mdot
.34721 .70178 Mdot
.62898 .58482 Mdot
.44946 .62986 Mdot
.40949 .37465 Mdot
.69326 .54558 Mdot
.56231 .29664 Mdot
.12114 .63541 Mdot
.6254 .40833 Mdot
.84751 .37445 Mdot
.61121 .40945 Mdot
.41264 .34417 Mdot
.66051 .55871 Mdot
.70891 .67442 Mdot
.45292 .50657 Mdot
.64973 .56608 Mdot
.56585 .21591 Mdot
.69449 .511 Mdot
.29042 .6399 Mdot
.62331 .57013 Mdot
.59369 .36619 Mdot
.62991 .43575 Mdot
.43214 .69492 Mdot
.46158 .61575 Mdot
.48075 .47143 Mdot
.26177 .598 Mdot
.46119 .61039 Mdot
.41357 .37769 Mdot
.47749 .78898 Mdot
.28267 .55285 Mdot
.63863 .551 Mdot
.59355 .4172 Mdot
.47644 .65822 Mdot
.52158 .61249 Mdot
.53599 .62035 Mdot
.31158 .78749 Mdot
.60746 .19508 Mdot
.53737 .64707 Mdot
.49671 .6804 Mdot
.41483 .36721 Mdot
.32547 .53574 Mdot
.42864 .2532 Mdot
.47927 .76267 Mdot
.44419 .6284 Mdot
.32707 .50929 Mdot
.3417 .52642 Mdot
.5202 .60429 Mdot
.25709 .47382 Mdot
.66252 .42549 Mdot
.46644 .64991 Mdot
.49294 .78092 Mdot
.48116 .33445 Mdot
.38935 .36493 Mdot
.42023 .3905 Mdot
.69694 .53308 Mdot
.39986 .38759 Mdot
.45441 .3451 Mdot
.7278 .65666 Mdot
.53296 .46938 Mdot
.58451 .41481 Mdot
.32178 .48795 Mdot
.48802 .62104 Mdot
.71814 .53415 Mdot
.6643 .44191 Mdot
.58392 .38756 Mdot
.66765 .57434 Mdot
.60749 .41583 Mdot
.31546 .46254 Mdot
.41816 .55616 Mdot
.43398 .39964 Mdot
.6288 .36496 Mdot
.67553 .33228 Mdot
.32651 .50763 Mdot
.58839 .35497 Mdot
.65925 .32649 Mdot
.43568 .63399 Mdot
.63816 .73983 Mdot
.50058 .62821 Mdot
.67276 .24538 Mdot
.60072 .35017 Mdot
.47961 .29032 Mdot
.47361 .64449 Mdot
.42837 .38656 Mdot
.42225 .68205 Mdot
.47108 .59847 Mdot
.41313 .39241 Mdot
.5428 .62865 Mdot
.32848 .52613 Mdot
.62407 .59185 Mdot
.4381 .51512 Mdot
.63353 .83264 Mdot
.33852 .4775 Mdot
.56148 .29182 Mdot
.45232 .61384 Mdot
.82008 .44373 Mdot
.64988 .56296 Mdot
.54479 .61287 Mdot
.29361 .56323 Mdot
.6273 .54614 Mdot
.67086 .56826 Mdot
.51744 .61345 Mdot
.61188 .39887 Mdot
.41557 .38234 Mdot
.32419 .50433 Mdot
.80125 .35441 Mdot
.49721 .64408 Mdot
.50243 .66364 Mdot
.32555 .51397 Mdot
.58786 .36615 Mdot
.509 .59712 Mdot
.26075 .33594 Mdot
.66913 .22042 Mdot
.59207 .4083 Mdot
.44245 .61612 Mdot
.58678 .76461 Mdot
.68023 .59447 Mdot
.84268 .58108 Mdot
.25523 .4831 Mdot
.41771 .36024 Mdot
.48775 .71437 Mdot
.20568 .71813 Mdot
.30978 .50436 Mdot
.27902 .71785 Mdot
.52708 .61765 Mdot
.51057 .66571 Mdot
.6676 .5778 Mdot
.51498 .62832 Mdot
.62591 .56476 Mdot
.63005 .82695 Mdot
.21525 .52326 Mdot
.6736 .52765 Mdot
.67024 .57964 Mdot
.27302 .56682 Mdot
.43328 .25505 Mdot
.66833 .55604 Mdot
.52324 .66691 Mdot
.58123 .64515 Mdot
.4152 .60131 Mdot
.31351 .47273 Mdot
.34573 .28465 Mdot
.72274 .56515 Mdot
.35597 .48005 Mdot
.45895 .20758 Mdot
.72825 .55366 Mdot
.63662 .44318 Mdot
.62684 .39862 Mdot
.45887 .6633 Mdot
.40555 .39687 Mdot
.39274 .38777 Mdot
.54618 .65966 Mdot
.48883 .61478 Mdot
.64723 .52276 Mdot
.31562 .48415 Mdot
.62446 .41426 Mdot
.51833 .65782 Mdot
.26903 .55285 Mdot
.33576 .48287 Mdot
.6412 .53899 Mdot
.47752 .77636 Mdot
.28394 .50319 Mdot
.49523 .5613 Mdot
.46257 .63833 Mdot
.506 .61713 Mdot
.43079 .57828 Mdot
.6253 .38033 Mdot
.33447 .27459 Mdot
.45207 .66821 Mdot
.21149 .57869 Mdot
.58162 .4389 Mdot
.49177 .5687 Mdot
.6602 .53043 Mdot
.57514 .34607 Mdot
.447 .41 Mdot
.45222 .5271 Mdot
.50259 .64913 Mdot
.67043 .26822 Mdot
.80691 .55388 Mdot
.39531 .40703 Mdot
.70197 .56566 Mdot
.3153 .49368 Mdot
.49675 .6226 Mdot
.5443 .74363 Mdot
.46829 .61003 Mdot
.292 .47251 Mdot
.45163 .37565 Mdot
.62546 .40016 Mdot
.69159 .26101 Mdot
.39286 .3859 Mdot
.67464 .5637 Mdot
.25573 .24803 Mdot
.62023 .55901 Mdot
.68383 .5771 Mdot
.53294 .74442 Mdot
.62599 .386 Mdot
.23795 .75566 Mdot
.70868 .7509 Mdot
.43572 .65639 Mdot
.58903 .37849 Mdot
.67115 .54784 Mdot
.50453 .67235 Mdot
.61056 .55942 Mdot
.70844 .54973 Mdot
.51795 .67298 Mdot
.48455 .67523 Mdot
.67667 .3025 Mdot
.38555 .19779 Mdot
.31607 .49227 Mdot
.66311 .51867 Mdot
.55503 .51125 Mdot
.49506 .67663 Mdot
.47133 .63602 Mdot
.51439 .35114 Mdot
.3062 .47762 Mdot
.74572 .39545 Mdot
.52421 .6147 Mdot
.21406 .50599 Mdot
.56098 .57629 Mdot
.65681 .51244 Mdot
.5881 .40266 Mdot
.22104 .62427 Mdot
.64702 .37242 Mdot
.63046 .56868 Mdot
.30809 .48642 Mdot
.70001 .57567 Mdot
.25839 .57386 Mdot
.61325 .34659 Mdot
.6867 .55471 Mdot
.55615 .45105 Mdot
.61126 .37286 Mdot
.61573 .35349 Mdot
.54461 .73216 Mdot
.37905 .37104 Mdot
.35472 .50978 Mdot
.59688 .35467 Mdot
.57529 .52904 Mdot
.59779 .36993 Mdot
.74784 .69287 Mdot
.44264 .63585 Mdot
.36797 .56776 Mdot
.36386 .40987 Mdot
.45423 .70995 Mdot
.60941 .34832 Mdot
.29355 .50398 Mdot
.51503 .60459 Mdot
.64939 .54174 Mdot
.3433 .50318 Mdot
.57763 .33383 Mdot
.43255 .35156 Mdot
.64938 .5278 Mdot
.63672 .34891 Mdot
.68498 .53431 Mdot
.51118 .52534 Mdot
.7954 .64573 Mdot
.2116 .39423 Mdot
.46953 .50512 Mdot
.53509 .62073 Mdot
.39496 .23368 Mdot
.52265 .58199 Mdot
.49028 .61074 Mdot
.4088 .37967 Mdot
.35622 .56255 Mdot
.65824 .55615 Mdot
.67365 .23414 Mdot
.63106 .3768 Mdot
.20862 .61121 Mdot
.58951 .60556 Mdot
.53852 .61474 Mdot
.62636 .54121 Mdot
.62029 .56121 Mdot
.60157 .70282 Mdot
.44684 .41185 Mdot
.50477 .5821 Mdot
.48436 .57746 Mdot
.54303 .65553 Mdot
.62271 .36524 Mdot
.23998 .4453 Mdot
.44048 .40273 Mdot
.82375 .60042 Mdot
.45029 .38453 Mdot
.34308 .54887 Mdot
.63627 .54882 Mdot
.33113 .47984 Mdot
.47031 .63784 Mdot
.69329 .50511 Mdot
.63322 .5743 Mdot
.29366 .47667 Mdot
.30349 .51564 Mdot
.53166 .33315 Mdot
.62134 .39386 Mdot
.50049 .58749 Mdot
.45494 .6492 Mdot
.51982 .6334 Mdot
.49969 .61113 Mdot
.62975 .40269 Mdot
.50286 .59946 Mdot
.57872 .34859 Mdot
.50696 .53899 Mdot
.23402 .48477 Mdot
.53941 .46116 Mdot
.76742 .52473 Mdot
.6434 .54742 Mdot
.58459 .51615 Mdot
.45241 .57038 Mdot
.44817 .82075 Mdot
.79808 .46295 Mdot
.44468 .66381 Mdot
.40148 .35766 Mdot
.42228 .71505 Mdot
.42517 .40192 Mdot
.86922 .43807 Mdot
.52388 .28338 Mdot
.42541 .18494 Mdot
.46169 .65953 Mdot
.50367 .36423 Mdot
.59308 .5382 Mdot
.53316 .59032 Mdot
.53331 .30271 Mdot
.75486 .50755 Mdot
.61001 .2525 Mdot
.29299 .49257 Mdot
.49162 .65689 Mdot
.7169 .53328 Mdot
.45314 .63537 Mdot
.47216 .62936 Mdot
.5199 .60609 Mdot
.57696 .3743 Mdot
.51491 .58854 Mdot
.4945 .60079 Mdot
.27167 .42833 Mdot
.32119 .6721 Mdot
.39 .38788 Mdot
.7929 .61759 Mdot
.33628 .48125 Mdot
.63623 .53054 Mdot
.56753 .19972 Mdot
.6159 .39404 Mdot
.60665 .69558 Mdot
.50259 .61363 Mdot
.66572 .29179 Mdot
.59179 .32626 Mdot
.30321 .49662 Mdot
.44999 .40086 Mdot
.47687 .16849 Mdot
.41611 .37426 Mdot
.56206 .45096 Mdot
.42836 .38382 Mdot
.47732 .55857 Mdot
.64994 .52154 Mdot
.50413 .59162 Mdot
.60307 .35442 Mdot
.40496 .387 Mdot
.32643 .61023 Mdot
.4852 .62845 Mdot
.42382 .36905 Mdot
.50343 .59137 Mdot
.41006 .5603 Mdot
.39558 .76371 Mdot
.44881 .34084 Mdot
.57078 .36601 Mdot
.61027 .36516 Mdot
.31415 .47662 Mdot
.63818 .53221 Mdot
.65464 .57701 Mdot
.61013 .38046 Mdot
.54826 .80892 Mdot
.44586 .61942 Mdot
.48914 .67747 Mdot
.21134 .6033 Mdot
.45429 .61731 Mdot
.27977 .61873 Mdot
.56393 .45585 Mdot
.64341 .54203 Mdot
.54548 .64037 Mdot
.52563 .61944 Mdot
.50217 .65321 Mdot
.48023 .53272 Mdot
.43093 .39356 Mdot
.45228 .65853 Mdot
.31023 .51962 Mdot
.43943 .44676 Mdot
.51874 .66575 Mdot
.56259 .60955 Mdot
.65719 .57724 Mdot
.28923 .75188 Mdot
.6151 .408 Mdot
.43688 .33874 Mdot
.40418 .36749 Mdot
.35471 .28277 Mdot
.6572 .46928 Mdot
.55897 .45527 Mdot
.83223 .57275 Mdot
.43391 .27707 Mdot
.33744 .50784 Mdot
.36927 .38338 Mdot
.59764 .45418 Mdot
.42213 .34463 Mdot
.62555 .40922 Mdot
.44322 .64215 Mdot
.44374 .62982 Mdot
.43123 .8353 Mdot
.52671 .60856 Mdot
.31576 .49735 Mdot
.589 .34098 Mdot
.65067 .54399 Mdot
.30414 .49529 Mdot
.60053 .40509 Mdot
.67052 .52982 Mdot
.44441 .65853 Mdot
.4455 .65829 Mdot
.66478 .57471 Mdot
.68867 .55574 Mdot
.46543 .64144 Mdot
.36834 .31203 Mdot
.68672 .56609 Mdot
.68685 .54571 Mdot
.43741 .39934 Mdot
.40908 .39723 Mdot
.53149 .57299 Mdot
.59124 .38052 Mdot
.49635 .60012 Mdot
.41116 .3706 Mdot
.31584 .48042 Mdot
.6544 .55537 Mdot
.53529 .629 Mdot
.52516 .6531 Mdot
.32464 .50788 Mdot
.30191 .48595 Mdot
.2983 .50732 Mdot
.5796 .35435 Mdot
.51655 .6401 Mdot
.66411 .56163 Mdot
.62283 .39575 Mdot
.34498 .5247 Mdot
.29755 .48013 Mdot
.38931 .41154 Mdot
.46161 .60448 Mdot
.39365 .44267 Mdot
.1647 .6704 Mdot
.23212 .59725 Mdot
.41717 .41736 Mdot
.42837 .42022 Mdot
.3206 .64602 Mdot
.40029 .51516 Mdot
.60531 .38908 Mdot
.27327 .50057 Mdot
.24628 .53197 Mdot
.43889 .61568 Mdot
.47257 .68633 Mdot
.43842 .59625 Mdot
.30465 .51334 Mdot
.33943 .56017 Mdot
.61966 .54208 Mdot
.71994 .60516 Mdot
.34179 .48938 Mdot
.384 .37479 Mdot
.37449 .39142 Mdot
.45114 .38234 Mdot
.44401 .64919 Mdot
.62485 .70833 Mdot
.61435 .49316 Mdot
.35856 .23559 Mdot
.59872 .34923 Mdot
.72216 .54336 Mdot
.81463 .4374 Mdot
.66666 .57226 Mdot
.46206 .37757 Mdot
.33316 .51625 Mdot
.69038 .54876 Mdot
.60418 .41714 Mdot
.59427 .35831 Mdot
.44261 .39198 Mdot
.44467 .38027 Mdot
.44488 .35012 Mdot
.69839 .56748 Mdot
.63484 .54985 Mdot
.50449 .64647 Mdot
.64916 .5539 Mdot
.39357 .82417 Mdot
.34123 .47346 Mdot
.47198 .39782 Mdot
.59647 .38202 Mdot
.67723 .5289 Mdot
.48811 .62848 Mdot
.40067 .53419 Mdot
.75646 .47265 Mdot
.33053 .52128 Mdot
.36362 .75535 Mdot
.86723 .44331 Mdot
.49907 .58635 Mdot
.62268 .3728 Mdot
.33983 .77459 Mdot
.48275 .63318 Mdot
.44566 .36311 Mdot
.41173 .26146 Mdot
.43178 .31538 Mdot
.47584 .59408 Mdot
.44681 .5978 Mdot
.5912 .40988 Mdot
.82525 .56841 Mdot
.50212 .64322 Mdot
.74109 .40499 Mdot
.61966 .42867 Mdot
.4439 .40097 Mdot
.63092 .18423 Mdot
.26695 .34543 Mdot
.36086 .61349 Mdot
.44191 .39815 Mdot
.48009 .60503 Mdot
.42729 .39947 Mdot
.32098 .52366 Mdot
.4572 .36048 Mdot
.61875 .54081 Mdot
.40398 .41015 Mdot
.50157 .66451 Mdot
.67076 .55441 Mdot
.60221 .38587 Mdot
.23199 .66036 Mdot
.33397 .42385 Mdot
.43007 .38678 Mdot
.43591 .33605 Mdot
.54501 .63538 Mdot
.72795 .36311 Mdot
.54466 .6709 Mdot
.47025 .67245 Mdot
.62795 .35983 Mdot
.62925 .54071 Mdot
.58154 .39373 Mdot
.55028 .60192 Mdot
.25662 .33459 Mdot
.60621 .40451 Mdot
.65503 .26961 Mdot
.33045 .51352 Mdot
.48154 .43892 Mdot
.49036 .62364 Mdot
.58435 .36784 Mdot
.51516 .63971 Mdot
.62469 .53584 Mdot
.52076 .42463 Mdot
.59342 .25912 Mdot
.61124 .35699 Mdot
.67699 .2642 Mdot
.36101 .53911 Mdot
.56399 .65224 Mdot
.59951 .40886 Mdot
.29925 .56219 Mdot
.4086 .34704 Mdot
.33935 .49146 Mdot
.30081 .52165 Mdot
.34505 .50548 Mdot
.52495 .6854 Mdot
.57352 .60764 Mdot
.3359 .52637 Mdot
.61324 .42123 Mdot
.28594 .49933 Mdot
.68928 .4869 Mdot
.65554 .23329 Mdot
.3315 .49545 Mdot
.48576 .65103 Mdot
.56713 .57352 Mdot
.32581 .66789 Mdot
.5588 .32047 Mdot
.44685 .18007 Mdot
.77872 .43126 Mdot
.46294 .61481 Mdot
.63983 .59237 Mdot
.67979 .52277 Mdot
.3143 .75317 Mdot
.26345 .61332 Mdot
.21755 .55687 Mdot
.67586 .57892 Mdot
.53367 .25452 Mdot
.64229 .53549 Mdot
.53278 .61494 Mdot
.49637 .67521 Mdot
.66171 .58466 Mdot
.22801 .47014 Mdot
.56408 .27136 Mdot
.73729 .29413 Mdot
.68757 .53881 Mdot
.59199 .40135 Mdot
.60882 .33986 Mdot
.61636 .35282 Mdot
.28671 .70839 Mdot
.62451 .55681 Mdot
.52368 .64105 Mdot
.40476 .37114 Mdot
.44825 .64952 Mdot
.61588 .37535 Mdot
.67155 .23152 Mdot
.63959 .56467 Mdot
.46786 .65788 Mdot
.39999 .67602 Mdot
.44107 .36389 Mdot
.33127 .50779 Mdot
.40042 .59178 Mdot
.22191 .56282 Mdot
.62641 .36597 Mdot
.63687 .58413 Mdot
.48772 .28171 Mdot
.64142 .24539 Mdot
.48777 .69497 Mdot
.50104 .57382 Mdot
.81799 .37068 Mdot
.23037 .52443 Mdot
.47395 .58761 Mdot
.42451 .3401 Mdot
.51336 .265 Mdot
.52893 .64761 Mdot
.67327 .52034 Mdot
.28931 .51158 Mdot
.33855 .51588 Mdot
.54403 .58067 Mdot
.43473 .50705 Mdot
.51435 .39611 Mdot
.51278 .61447 Mdot
.49122 .56165 Mdot
.4439 .39966 Mdot
.42627 .27368 Mdot
.21062 .57332 Mdot
.30602 .48644 Mdot
.50424 .59264 Mdot
.51004 .2146 Mdot
.65207 .5815 Mdot
.403 .41153 Mdot
.59981 .34551 Mdot
.45351 .54205 Mdot
.45174 .39756 Mdot
.53296 .64426 Mdot
.51359 .6006 Mdot
.58232 .36174 Mdot
.65535 .5126 Mdot
.30895 .51551 Mdot
.40114 .3728 Mdot
.29781 .49157 Mdot
.62614 .54925 Mdot
.64271 .55561 Mdot
.42074 .70726 Mdot
.43546 .6825 Mdot
.41753 .38947 Mdot
.55494 .62255 Mdot
.47395 .33106 Mdot
.84926 .53309 Mdot
.63241 .3482 Mdot
.49003 .58362 Mdot
.64149 .51481 Mdot
.61626 .35998 Mdot
.49943 .67184 Mdot
.80458 .35019 Mdot
.49708 .67669 Mdot
.5897 .43966 Mdot
.20509 .39732 Mdot
.29578 .49985 Mdot
.71737 .60388 Mdot
.74815 .35473 Mdot
.45466 .62219 Mdot
.4097 .3565 Mdot
.45504 .57429 Mdot
.60891 .3977 Mdot
.63784 .55052 Mdot
.84908 .57334 Mdot
.59956 .36655 Mdot
.45763 .6438 Mdot
.30552 .49629 Mdot
.62404 .5686 Mdot
.27237 .52551 Mdot
.25617 .47332 Mdot
.57084 .62964 Mdot
.55576 .62796 Mdot
.50486 .60766 Mdot
.29132 .2913 Mdot
.43909 .33982 Mdot
.67775 .54189 Mdot
.62334 .37186 Mdot
.61012 .38337 Mdot
.44008 .39164 Mdot
.6678 .32288 Mdot
.48481 .43677 Mdot
.16394 .64096 Mdot
.41408 .39452 Mdot
.34851 .50098 Mdot
.73809 .38567 Mdot
.40339 .36023 Mdot
.42814 .36994 Mdot
.43604 .40147 Mdot
.65168 .39915 Mdot
.66902 .53205 Mdot
.5315 .64887 Mdot
.66609 .51612 Mdot
.48218 .60343 Mdot
.58342 .43822 Mdot
.60839 .35429 Mdot
.63454 .56048 Mdot
.80895 .37171 Mdot
.62969 .76335 Mdot
.48289 .64188 Mdot
.81774 .44026 Mdot
.43083 .6619 Mdot
.3015 .62184 Mdot
.42335 .64008 Mdot
.43778 .38396 Mdot
.53732 .6887 Mdot
.54204 .65919 Mdot
.27488 .72453 Mdot
.59563 .3841 Mdot
.39212 .36258 Mdot
.43008 .63645 Mdot
.51665 .56053 Mdot
.6866 .5782 Mdot
.68969 .54695 Mdot
.31873 .52683 Mdot
.37683 .73595 Mdot
.60104 .38853 Mdot
.71032 .73986 Mdot
.46093 .62057 Mdot
.22977 .42767 Mdot
.64171 .62883 Mdot
.49481 .67314 Mdot
.76133 .364 Mdot
.62076 .70267 Mdot
.49476 .62281 Mdot
.53638 .49676 Mdot
.58869 .36641 Mdot
.24462 .34776 Mdot
.51046 .67323 Mdot
.44028 .35858 Mdot
.6354 .54425 Mdot
.61553 .54943 Mdot
.33067 .52679 Mdot
.48769 .82763 Mdot
.57979 .38681 Mdot
.63513 .55583 Mdot
.48145 .62401 Mdot
.62671 .37895 Mdot
.39779 .38777 Mdot
.53489 .60935 Mdot
.26861 .62549 Mdot
.65111 .54935 Mdot
.53785 .65536 Mdot
.72575 .41111 Mdot
.34745 .65988 Mdot
.24437 .29354 Mdot
.62441 .37144 Mdot
.3061 .4795 Mdot
.45788 .57391 Mdot
.53612 .80168 Mdot
.46557 .69094 Mdot
.3744 .56282 Mdot
.70022 .4898 Mdot
.30045 .48194 Mdot
.47636 .64773 Mdot
.52118 .64886 Mdot
.38379 .46891 Mdot
.31065 .48367 Mdot
.45614 .65449 Mdot
.53401 .54913 Mdot
.67274 .53366 Mdot
.46319 .35574 Mdot
.6561 .54116 Mdot
.48874 .6464 Mdot
.42708 .67085 Mdot
.6765 .57239 Mdot
.84477 .47807 Mdot
.35979 .51013 Mdot
.61498 .40644 Mdot
.45261 .68453 Mdot
.4582 .67465 Mdot
.16136 .48461 Mdot
.38594 .39737 Mdot
.45814 .24137 Mdot
.26963 .38726 Mdot
.47388 .21203 Mdot
.26535 .34721 Mdot
.33808 .20879 Mdot
.22163 .51213 Mdot
.5251 .59438 Mdot
.66437 .60805 Mdot
.60054 .4907 Mdot
.60172 .34724 Mdot
.7547 .65277 Mdot
.46164 .61503 Mdot
.47277 .62684 Mdot
.40614 .41436 Mdot
.64929 .27777 Mdot
.21608 .55657 Mdot
.40663 .52438 Mdot
.31076 .51553 Mdot
.66386 .51932 Mdot
.5295 .65619 Mdot
.54261 .48496 Mdot
.3895 .38878 Mdot
.22746 .43565 Mdot
.4699 .65708 Mdot
.44096 .81405 Mdot
.73914 .47305 Mdot
.62385 .38618 Mdot
.40462 .36432 Mdot
.2231 .54597 Mdot
.46466 .60181 Mdot
.5992 .34446 Mdot
.49724 .63863 Mdot
.38357 .31184 Mdot
.55409 .60841 Mdot
.33369 .4925 Mdot
.52833 .6174 Mdot
.34386 .55001 Mdot
.21744 .28579 Mdot
.27389 .48439 Mdot
.61276 .5618 Mdot
.47973 .37525 Mdot
.427 .39308 Mdot
.68851 .55375 Mdot
.42465 .39141 Mdot
.61054 .67269 Mdot
.71005 .65409 Mdot
.32446 .51694 Mdot
.52574 .5642 Mdot
.32806 .49575 Mdot
.39291 .40631 Mdot
.46556 .6067 Mdot
.86236 .49382 Mdot
.40969 .38589 Mdot
.19116 .44106 Mdot
.59933 .3729 Mdot
.38456 .37848 Mdot
.50617 .67449 Mdot
.49019 .28918 Mdot
.3919 .38511 Mdot
.60099 .26529 Mdot
.50263 .65236 Mdot
.64507 .54998 Mdot
.52839 .64541 Mdot
.43978 .66749 Mdot
.42464 .33171 Mdot
.48624 .59719 Mdot
.60019 .40479 Mdot
.69276 .56508 Mdot
.53692 .1619 Mdot
.75098 .51414 Mdot
.45067 .63951 Mdot
.48152 .62663 Mdot
.70701 .56686 Mdot
.45525 .665 Mdot
.62962 .40268 Mdot
.47082 .90186 Mdot
.33075 .51305 Mdot
.42033 .33674 Mdot
.26516 .34559 Mdot
.44288 .65881 Mdot
.50973 .60219 Mdot
.78908 .32732 Mdot
.24467 .36062 Mdot
.59979 .40763 Mdot
.53534 .66776 Mdot
.3949 .38598 Mdot
.30822 .49624 Mdot
.61923 .42186 Mdot
.5065 .61843 Mdot
.47207 .6411 Mdot
.31214 .47815 Mdot
.53319 .71597 Mdot
.26098 .67151 Mdot
.58523 .35698 Mdot
.50153 .70718 Mdot
.48259 .3918 Mdot
.45321 .60735 Mdot
.30621 .72899 Mdot
.68585 .5533 Mdot
.62793 .36616 Mdot
.39868 .2401 Mdot
.47607 .5894 Mdot
.5862 .39755 Mdot
.59973 .38844 Mdot
.52947 .67262 Mdot
.64475 .51194 Mdot
.70387 .55341 Mdot
.68401 .53249 Mdot
.42899 .84956 Mdot
.34816 .6183 Mdot
.44491 .35025 Mdot
.58849 .3658 Mdot
.45268 .34185 Mdot
.32713 .46699 Mdot
.57996 .46167 Mdot
.44325 .33764 Mdot
.69362 .53389 Mdot
.47737 .37956 Mdot
.5142 .652 Mdot
.60346 .3867 Mdot
.42782 .34362 Mdot
.43527 .65181 Mdot
.71119 .34364 Mdot
.61046 .30884 Mdot
.28918 .48806 Mdot
.2934 .51744 Mdot
.51231 .66821 Mdot
.45059 .40734 Mdot
.46617 .63928 Mdot
.63618 .37043 Mdot
.72639 .36722 Mdot
.45987 .68702 Mdot
.43121 .38809 Mdot
.67122 .59074 Mdot
.2226 .55614 Mdot
.54326 .67718 Mdot
.48463 .65068 Mdot
.48192 .6002 Mdot
.49777 .63842 Mdot
.6056 .24194 Mdot
.64199 .37169 Mdot
.76542 .52255 Mdot
.31769 .28401 Mdot
.64639 .5679 Mdot
.69901 .52363 Mdot
.23028 .60325 Mdot
.66311 .41899 Mdot
.59018 .37803 Mdot
.49345 .61093 Mdot
.67701 .45301 Mdot
.66317 .22018 Mdot
.84441 .41142 Mdot
.371 .46612 Mdot
.38608 .39084 Mdot
.6468 .58643 Mdot
.39511 .37244 Mdot
.47528 .60535 Mdot
.45553 .57697 Mdot
.32394 .21025 Mdot
.60959 .42917 Mdot
.32632 .51795 Mdot
.48516 .60265 Mdot
.35173 .62227 Mdot
.41294 .36743 Mdot
.39897 .34575 Mdot
.4618 .66654 Mdot
.67205 .51167 Mdot
.17777 .38835 Mdot
.62498 .37868 Mdot
.77502 .42255 Mdot
.59787 .53285 Mdot
.77173 .45925 Mdot
.6188 .37585 Mdot
.30093 .45046 Mdot
.41668 .41645 Mdot
.58099 .6762 Mdot
.64645 .56995 Mdot
.34265 .50369 Mdot
.49032 .56982 Mdot
.65899 .57904 Mdot
.44585 .40111 Mdot
.64069 .55067 Mdot
.52211 .60777 Mdot
.63119 .4185 Mdot
.41696 .35897 Mdot
.58607 .41573 Mdot
.66004 .5087 Mdot
.30607 .4881 Mdot
.43241 .48694 Mdot
.71286 .70194 Mdot
.61888 .70018 Mdot
.44929 .65553 Mdot
.55271 .485 Mdot
.52308 .63822 Mdot
.70705 .53547 Mdot
.49051 .63172 Mdot
.70826 .50261 Mdot
.40921 .35808 Mdot
.49872 .67949 Mdot
.50947 .61211 Mdot
.77311 .62121 Mdot
.47544 .66295 Mdot
.53915 .60215 Mdot
.49594 .61992 Mdot
.65725 .4978 Mdot
.54082 .56754 Mdot
.66236 .52879 Mdot
.29457 .44231 Mdot
.43094 .37075 Mdot
.28982 .50987 Mdot
.33601 .47767 Mdot
.36144 .57289 Mdot
.34358 .31923 Mdot
.65093 .28627 Mdot
.66119 .54166 Mdot
.59904 .39907 Mdot
.49428 .63334 Mdot
.34207 .22912 Mdot
.48609 .3397 Mdot
.39983 .39879 Mdot
.75126 .51322 Mdot
.47981 .71178 Mdot
.25893 .31047 Mdot
.54722 .64317 Mdot
.44785 .84093 Mdot
.44045 .69021 Mdot
.55253 .60766 Mdot
.44088 .33318 Mdot
.33464 .46658 Mdot
.46429 .67326 Mdot
.68256 .58004 Mdot
.33378 .4873 Mdot
.62467 .60953 Mdot
.42087 .44538 Mdot
.3181 .44013 Mdot
.75341 .62664 Mdot
.51015 .64074 Mdot
.41875 .35822 Mdot
.64978 .52676 Mdot
.21062 .56761 Mdot
.62285 .39713 Mdot
.58348 .42327 Mdot
.56562 .5113 Mdot
.82884 .44491 Mdot
.33651 .48297 Mdot
.53863 .72719 Mdot
.50445 .66349 Mdot
.35488 .40533 Mdot
.47108 .68851 Mdot
.66842 .22924 Mdot
.34671 .48958 Mdot
.70085 .54148 Mdot
.59165 .3991 Mdot
.67459 .51906 Mdot
.61141 .71245 Mdot
.37922 .34669 Mdot
.51261 .4597 Mdot
.41871 .37302 Mdot
.45629 .4461 Mdot
.67479 .54889 Mdot
.49969 .59164 Mdot
.16119 .63893 Mdot
.68697 .54822 Mdot
.63045 .57516 Mdot
.81234 .60356 Mdot
.85566 .51954 Mdot
.51725 .70489 Mdot
.67894 .57439 Mdot
.42358 .37477 Mdot
.3152 .48992 Mdot
.53244 .63435 Mdot
.51054 .6474 Mdot
.66127 .57811 Mdot
.41795 .33512 Mdot
.56115 .77463 Mdot
.44339 .38061 Mdot
.67308 .5307 Mdot
.43567 .36543 Mdot
.4761 .28769 Mdot
.41253 .34814 Mdot
.45789 .6737 Mdot
.49155 .63207 Mdot
.32062 .31948 Mdot
.64311 .555 Mdot
.5146 .61595 Mdot
.54397 .62829 Mdot
.66481 .55925 Mdot
.26132 .48308 Mdot
.5666 .76678 Mdot
.44927 .62145 Mdot
.49233 .65963 Mdot
.30085 .48229 Mdot
.58979 .47241 Mdot
.43884 .76815 Mdot
.51522 .60499 Mdot
.35318 .49598 Mdot
.68778 .57565 Mdot
.46538 .64808 Mdot
.60557 .20305 Mdot
.51558 .26386 Mdot
.48309 .58781 Mdot
.40615 .34916 Mdot
.54296 .65686 Mdot
.2328 .31085 Mdot
.47008 .67292 Mdot
.66586 .55224 Mdot
.62956 .54904 Mdot
.71767 .73252 Mdot
.67704 .56012 Mdot
.40993 .39839 Mdot
.61329 .374 Mdot
.67612 .24917 Mdot
.39762 .38689 Mdot
.47825 .69907 Mdot
.71988 .7434 Mdot
.52518 .60007 Mdot
.44484 .66753 Mdot
.1934 .3841 Mdot
.39887 .38132 Mdot
.62468 .54064 Mdot
.40603 .49866 Mdot
.41828 .64178 Mdot
.62553 .36266 Mdot
.4991 .5669 Mdot
.44114 .62265 Mdot
.20159 .40529 Mdot
.5531 .2356 Mdot
.62445 .35056 Mdot
.5074 .58095 Mdot
.5144 .60436 Mdot
.3856 .34783 Mdot
.48579 .62522 Mdot
.31948 .48816 Mdot
.62376 .5504 Mdot
.40235 .35879 Mdot
.32047 .50908 Mdot
.4578 .61745 Mdot
.3024 .5113 Mdot
.43422 .34716 Mdot
.61353 .34568 Mdot
.47166 .60298 Mdot
.31118 .4731 Mdot
.30548 .5127 Mdot
.5231 .6334 Mdot
.63825 .54799 Mdot
.44431 .69407 Mdot
.46733 .66079 Mdot
.5352 .62676 Mdot
.65215 .57635 Mdot
.78842 .27753 Mdot
.48448 .67887 Mdot
.37603 .52461 Mdot
.63018 .57152 Mdot
.41019 .45554 Mdot
.39476 .36524 Mdot
.44085 .62894 Mdot
.61916 .34822 Mdot
.58685 .3611 Mdot
.44842 .39691 Mdot
.6258 .5749 Mdot
.27382 .37288 Mdot
.70076 .577 Mdot
.42023 .63845 Mdot
.4786 .58193 Mdot
.63308 .79242 Mdot
.42406 .18191 Mdot
.64109 .52364 Mdot
.39191 .43289 Mdot
.42228 .5161 Mdot
.5851 .37684 Mdot
.38408 .37175 Mdot
.64258 .58616 Mdot
.62401 .56204 Mdot
.64565 .54197 Mdot
.33981 .51207 Mdot
.32401 .31862 Mdot
.63706 .52127 Mdot
.68847 .51777 Mdot
.50594 .6529 Mdot
.51333 .60477 Mdot
.23491 .56253 Mdot
.29655 .67241 Mdot
.29266 .50546 Mdot
.44835 .38582 Mdot
.37264 .8443 Mdot
.6365 .3753 Mdot
.78415 .59752 Mdot
.45315 .67965 Mdot
.15524 .67606 Mdot
.51951 .66676 Mdot
.48286 .6219 Mdot
.69121 .5671 Mdot
.2978 .47886 Mdot
.33242 .50072 Mdot
.68035 .54238 Mdot
.70586 .52861 Mdot
.3207 .48836 Mdot
.78814 .40723 Mdot
.62999 .20568 Mdot
.37857 .34034 Mdot
.65716 .56198 Mdot
.71612 .68958 Mdot
.58818 .34945 Mdot
.64842 .60248 Mdot
.63866 .3884 Mdot
.4202 .36696 Mdot
.44584 .40845 Mdot
.62175 .36205 Mdot
.5017 .65112 Mdot
.44474 .34648 Mdot
.51883 .59133 Mdot
.79108 .47128 Mdot
.62106 .7393 Mdot
.28882 .33401 Mdot
.56081 .59707 Mdot
.30094 .44699 Mdot
.64992 .31744 Mdot
.45764 .63433 Mdot
.51842 .20164 Mdot
.31893 .51839 Mdot
.60989 .59427 Mdot
.63308 .37316 Mdot
.21689 .31817 Mdot
.47331 .59828 Mdot
.6621 .55258 Mdot
.59456 .38707 Mdot
.44073 .53963 Mdot
.73762 .39773 Mdot
.48218 .60172 Mdot
.17831 .68182 Mdot
.63995 .50636 Mdot
.40749 .35493 Mdot
.51829 .81149 Mdot
.64692 .51842 Mdot
.37153 .47394 Mdot
.34933 .2723 Mdot
.81936 .39827 Mdot
.63869 .52864 Mdot
.38002 .38516 Mdot
.67807 .52637 Mdot
.3084 .48684 Mdot
.62361 .58624 Mdot
.40927 .3647 Mdot
.47375 .65617 Mdot
.43802 .38953 Mdot
.31111 .52446 Mdot
.26866 .67574 Mdot
.62177 .34836 Mdot
.39366 .36083 Mdot
.60569 .35813 Mdot
.35687 .69132 Mdot
.28613 .30128 Mdot
.62378 .40236 Mdot
.48173 .78052 Mdot
.4656 .59103 Mdot
.6543 .51398 Mdot
.43592 .39575 Mdot
.39061 .26688 Mdot
.42629 .49384 Mdot
.6554 .57168 Mdot
.4494 .36507 Mdot
.57447 .50489 Mdot
.49561 .79314 Mdot
.55781 .6429 Mdot
.36279 .71541 Mdot
.66086 .56316 Mdot
.38298 .39755 Mdot
.21176 .60825 Mdot
.69151 .5285 Mdot
.41724 .39598 Mdot
.58947 .39859 Mdot
.61366 .38297 Mdot
.45612 .65905 Mdot
.59688 .42844 Mdot
.45379 .36951 Mdot
.64036 .31239 Mdot
.66392 .58253 Mdot
.46183 .53263 Mdot
.32968 .47092 Mdot
.43633 .37551 Mdot
.52725 .60842 Mdot
.6036 .57611 Mdot
.48513 .27146 Mdot
.58106 .77759 Mdot
.26643 .73845 Mdot
.44022 .39131 Mdot
.62558 .56014 Mdot
.6584 .55282 Mdot
.53431 .68479 Mdot
.46344 .50584 Mdot
.27929 .36556 Mdot
.3854 .60833 Mdot
.39414 .55365 Mdot
.46453 .36431 Mdot
.43498 .31967 Mdot
.4306 .62932 Mdot
.50679 .63662 Mdot
.58643 .3843 Mdot
.47763 .65702 Mdot
.69355 .56015 Mdot
.45616 .66247 Mdot
.62088 .37025 Mdot
.4143 .37656 Mdot
.46762 .60751 Mdot
.29487 .50007 Mdot
.59746 .34002 Mdot
.59417 .41413 Mdot
.43437 .38197 Mdot
.656 .57902 Mdot
.25845 .49843 Mdot
.44505 .3801 Mdot
.50945 .64122 Mdot
.62392 .45316 Mdot
.5359 .62038 Mdot
.72327 .59178 Mdot
.69252 .5284 Mdot
.3994 .36554 Mdot
.67116 .58222 Mdot
.59884 .36033 Mdot
.32653 .27911 Mdot
.48901 .64096 Mdot
.41101 .39376 Mdot
.40009 .28718 Mdot
.61574 .62166 Mdot
.71681 .54187 Mdot
.64516 .30228 Mdot
.70363 .52859 Mdot
.43997 .40603 Mdot
.77923 .6482 Mdot
.34092 .4911 Mdot
.39807 .39777 Mdot
.49913 .16944 Mdot
.4188 .38728 Mdot
.47943 .66831 Mdot
.51309 .66658 Mdot
.40569 .35499 Mdot
.31472 .47625 Mdot
.21322 .53426 Mdot
.46913 .36299 Mdot
.62738 .53816 Mdot
.80639 .48861 Mdot
.20137 .65343 Mdot
.62115 .43884 Mdot
.59023 .39173 Mdot
.42001 .66438 Mdot
.54919 .60807 Mdot
.63365 .40279 Mdot
.59193 .41514 Mdot
.33544 .5211 Mdot
.43033 .40242 Mdot
.65542 .49605 Mdot
.57322 .37398 Mdot
.40522 .63111 Mdot
.33687 .32633 Mdot
.55228 .66294 Mdot
.60337 .51766 Mdot
.47115 .68655 Mdot
.38192 .56498 Mdot
.6223 .3705 Mdot
.5386 .64832 Mdot
.54437 .66383 Mdot
.62423 .35489 Mdot
.3168 .48767 Mdot
.6727 .36927 Mdot
.43145 .3594 Mdot
.66869 .20257 Mdot
.55077 .62226 Mdot
.47943 .67042 Mdot
.60126 .34877 Mdot
.27405 .41141 Mdot
.63795 .56532 Mdot
.68662 .52259 Mdot
.43603 .33932 Mdot
.44829 .48769 Mdot
.44303 .6292 Mdot
.46073 .64696 Mdot
.42599 .35421 Mdot
.38533 .37463 Mdot
.59044 .29813 Mdot
.51748 .65672 Mdot
.59415 .37984 Mdot
.3242 .5515 Mdot
.6218 .36855 Mdot
.53251 .61538 Mdot
.48599 .6708 Mdot
.4574 .67276 Mdot
.52605 .60791 Mdot
.60605 .4224 Mdot
.53329 .65264 Mdot
.56391 .57389 Mdot
.63601 .56756 Mdot
.49321 .60192 Mdot
.39269 .55844 Mdot
.48647 .65523 Mdot
.31679 .48965 Mdot
.46989 .76497 Mdot
.4728 .59906 Mdot
.44236 .63628 Mdot
.46658 .34273 Mdot
.47771 .64222 Mdot
.63674 .37361 Mdot
.64642 .56052 Mdot
.58909 .36435 Mdot
.58972 .35414 Mdot
.45582 .38694 Mdot
.33517 .52624 Mdot
.44129 .65409 Mdot
.32985 .52053 Mdot
.48373 .69705 Mdot
.47774 .58801 Mdot
.33661 .28563 Mdot
.45999 .84345 Mdot
.2738 .69538 Mdot
.49053 .6418 Mdot
.40275 .38371 Mdot
.39574 .36573 Mdot
.5999 .61214 Mdot
.55551 .6504 Mdot
.62605 .4124 Mdot
.58536 .36513 Mdot
.27494 .63006 Mdot
.21779 .38336 Mdot
.31686 .48906 Mdot
.55882 .47268 Mdot
.50132 .58137 Mdot
.54177 .63057 Mdot
.53609 .60835 Mdot
.45196 .34261 Mdot
.38756 .53462 Mdot
.39718 .39561 Mdot
.75048 .4802 Mdot
.61558 .35664 Mdot
.47837 .59768 Mdot
.66161 .47587 Mdot
.69128 .54277 Mdot
.6463 .55979 Mdot
.59616 .41399 Mdot
.46762 .33299 Mdot
.23522 .59116 Mdot
.85897 .43517 Mdot
.62142 .52069 Mdot
.28602 .49024 Mdot
.45489 .63327 Mdot
.41905 .38017 Mdot
.68375 .52954 Mdot
.28669 .49923 Mdot
.49765 .58936 Mdot
.32505 .31749 Mdot
.49543 .64404 Mdot
.60573 .49019 Mdot
.63986 .53885 Mdot
.6599 .22494 Mdot
.61639 .56221 Mdot
.59902 .3389 Mdot
.63206 .37741 Mdot
.50166 .67045 Mdot
.58085 .81072 Mdot
.66963 .51553 Mdot
.65539 .37614 Mdot
.3483 .49982 Mdot
.49996 .27755 Mdot
.3134 .48517 Mdot
.40724 .35703 Mdot
.33443 .4854 Mdot
.40881 .36227 Mdot
.27317 .65343 Mdot
.70574 .50532 Mdot
.32399 .5128 Mdot
.37382 .31664 Mdot
.56066 .64324 Mdot
.29055 .4988 Mdot
.42441 .61632 Mdot
.71197 .6032 Mdot
.43057 .35414 Mdot
.3405 .48428 Mdot
.50255 .59295 Mdot
.31753 .22763 Mdot
.60408 .40843 Mdot
.62897 .40835 Mdot
.4219 .62983 Mdot
.46151 .37663 Mdot
.67236 .58416 Mdot
.62076 .23176 Mdot
.60405 .33301 Mdot
.49278 .6759 Mdot
.46216 .67079 Mdot
.69669 .52204 Mdot
.73227 .51054 Mdot
.49616 .6706 Mdot
.41041 .69107 Mdot
.5162 .65977 Mdot
.59646 .41093 Mdot
.67159 .51878 Mdot
.65317 .55589 Mdot
.44896 .36015 Mdot
.6853 .56493 Mdot
.58448 .63179 Mdot
.68217 .46776 Mdot
.43887 .70701 Mdot
.60116 .36473 Mdot
.72738 .4761 Mdot
.75204 .48375 Mdot
.44619 .18234 Mdot
.68791 .5142 Mdot
.47901 .68749 Mdot
.65202 .58176 Mdot
.30911 .49394 Mdot
.64739 .54965 Mdot
.64945 .58638 Mdot
.46332 .63716 Mdot
.48023 .60529 Mdot
.4057 .37473 Mdot
.44841 .5077 Mdot
.6452 .57764 Mdot
.52332 .66215 Mdot
.5445 .6012 Mdot
.53167 .60116 Mdot
.52755 .40122 Mdot
.65099 .51886 Mdot
.82317 .54997 Mdot
.29613 .57256 Mdot
.64689 .57813 Mdot
.18449 .36451 Mdot
.42287 .2716 Mdot
.40789 .41902 Mdot
.56915 .37557 Mdot
.52016 .65535 Mdot
.38891 .37644 Mdot
.47467 .60529 Mdot
.60273 .51753 Mdot
.47265 .63599 Mdot
.32223 .48686 Mdot
.52686 .59551 Mdot
.44683 .40394 Mdot
.44329 .38498 Mdot
.4788 .67697 Mdot
.46697 .61171 Mdot
.25637 .65414 Mdot
.69351 .51164 Mdot
.63874 .55815 Mdot
.2642 .39093 Mdot
.30958 .51005 Mdot
.62676 .36472 Mdot
.49224 .62468 Mdot
.45892 .37488 Mdot
.44209 .38753 Mdot
.65346 .51661 Mdot
.44407 .36181 Mdot
.62432 .37858 Mdot
.48767 .63719 Mdot
.63326 .40275 Mdot
.34003 .51323 Mdot
.66183 .51861 Mdot
.48778 .60166 Mdot
.50557 .65316 Mdot
.62951 .54867 Mdot
.43323 .63609 Mdot
.30283 .48151 Mdot
.42067 .38899 Mdot
.64723 .52447 Mdot
.61343 .37629 Mdot
.40612 .35996 Mdot
.53629 .63377 Mdot
.33128 .81114 Mdot
.48251 .66662 Mdot
.52554 .65055 Mdot
.49055 .16349 Mdot
.51445 .58697 Mdot
.4388 .39409 Mdot
.6989 .53678 Mdot
.55644 .59108 Mdot
.34875 .57933 Mdot
.83307 .3477 Mdot
.40203 .39942 Mdot
.45412 .63782 Mdot
.36495 .2075 Mdot
.45848 .64985 Mdot
.64641 .77589 Mdot
.36323 .35392 Mdot
.43759 .46278 Mdot
.43971 .67892 Mdot
.61558 .39337 Mdot
.40387 .37642 Mdot
.41242 .35589 Mdot
.80359 .53219 Mdot
.46217 .64082 Mdot
.58673 .48966 Mdot
.49374 .59442 Mdot
.61747 .37939 Mdot
.26689 .60212 Mdot
.44283 .38942 Mdot
.30056 .7472 Mdot
.52227 .6413 Mdot
.61887 .54424 Mdot
.47664 .38398 Mdot
.48225 .31078 Mdot
.53471 .6282 Mdot
.31858 .52156 Mdot
.57659 .35785 Mdot
.54519 .58979 Mdot
.60537 .36724 Mdot
.53475 .62375 Mdot
.42534 .71511 Mdot
.51832 .81955 Mdot
.64139 .54493 Mdot
.58997 .39652 Mdot
.6195 .44959 Mdot
.52364 .66929 Mdot
.64104 .52751 Mdot
.64803 .57074 Mdot
.32911 .52294 Mdot
.53163 .4483 Mdot
.71358 .4025 Mdot
.64967 .7442 Mdot
.81095 .51157 Mdot
.47896 .36621 Mdot
.57474 .2605 Mdot
.52762 .62585 Mdot
.236 .41473 Mdot
.63103 .35967 Mdot
.47502 .6662 Mdot
.60651 .64588 Mdot
.68491 .53923 Mdot
.49516 .66227 Mdot
.32652 .49411 Mdot
.24367 .43057 Mdot
.23111 .43821 Mdot
.35788 .25643 Mdot
.41941 .37148 Mdot
.45768 .57499 Mdot
.45379 .72767 Mdot
.42555 .33671 Mdot
.44195 .61342 Mdot
.42216 .39467 Mdot
.80585 .42543 Mdot
.28872 .4918 Mdot
.63422 .52918 Mdot
.45422 .29003 Mdot
.43944 .63859 Mdot
.47769 .58112 Mdot
.29892 .5237 Mdot
.50918 .63311 Mdot
.478 .82459 Mdot
.44892 .29752 Mdot
.43142 .34217 Mdot
.64461 .54272 Mdot
.44356 .64798 Mdot
.54449 .45277 Mdot
.46509 .65804 Mdot
.68659 .68249 Mdot
.44294 .64015 Mdot
.72491 .3968 Mdot
.63563 .54496 Mdot
.60584 .3638 Mdot
.5216 .67304 Mdot
.47511 .62944 Mdot
.3003 .55485 Mdot
.43688 .68654 Mdot
.53311 .65734 Mdot
.69884 .57241 Mdot
.68631 .52923 Mdot
.66332 .5298 Mdot
.41059 .41227 Mdot
.2088 .39502 Mdot
.59312 .37008 Mdot
.55688 .57887 Mdot
.57491 .38881 Mdot
.55974 .79254 Mdot
.28627 .49267 Mdot
.37721 .22318 Mdot
.50241 .61448 Mdot
.66615 .53675 Mdot
.52142 .22037 Mdot
.69755 .56852 Mdot
.53477 .47792 Mdot
.60144 .38832 Mdot
.68448 .5448 Mdot
.47869 .62334 Mdot
.42349 .50558 Mdot
.31603 .25133 Mdot
.59501 .35716 Mdot
.48633 .69903 Mdot
.38757 .39827 Mdot
.29121 .32115 Mdot
.30894 .79071 Mdot
.60233 .40902 Mdot
.5989 .44117 Mdot
.4606 .64031 Mdot
.69307 .54219 Mdot
.61927 .38978 Mdot
.61543 .40893 Mdot
.44388 .35956 Mdot
.4836 .6055 Mdot
.48834 .60651 Mdot
.43199 .41128 Mdot
.59072 .35806 Mdot
.42779 .66102 Mdot
.55523 .61002 Mdot
.30109 .21862 Mdot
.52425 .5155 Mdot
.69391 .20855 Mdot
.58258 .63012 Mdot
.58828 .67726 Mdot
.64073 .23387 Mdot
.62538 .56523 Mdot
.46825 .59971 Mdot
.52212 .57558 Mdot
.45362 .37114 Mdot
.48169 .64878 Mdot
.37428 .40026 Mdot
.5914 .387 Mdot
.2057 .34162 Mdot
.71183 .45153 Mdot
.80481 .39989 Mdot
.47942 .64889 Mdot
.74493 .53625 Mdot
.31702 .50227 Mdot
.64348 .37037 Mdot
.66501 .52444 Mdot
.51732 .60048 Mdot
.25686 .65664 Mdot
.39723 .39648 Mdot
.67102 .57112 Mdot
.21364 .57078 Mdot
.30994 .44698 Mdot
.53085 .61443 Mdot
.39713 .40384 Mdot
.5352 .2123 Mdot
.41114 .59304 Mdot
.62761 .34016 Mdot
.31939 .48613 Mdot
.40066 .37495 Mdot
.58615 .35908 Mdot
.61255 .52621 Mdot
.68209 .55231 Mdot
.65211 .5903 Mdot
.3236 .73364 Mdot
.41479 .34015 Mdot
.32119 .50434 Mdot
.23008 .37146 Mdot
.21729 .44274 Mdot
.32399 .48791 Mdot
.4429 .41064 Mdot
.68513 .52919 Mdot
.67609 .53981 Mdot
.64701 .56091 Mdot
.27317 .71184 Mdot
.62021 .56283 Mdot
.7897 .5741 Mdot
.52151 .59655 Mdot
.42623 .70593 Mdot
.4557 .64204 Mdot
.62913 .41048 Mdot
.63505 .53792 Mdot
.43146 .48181 Mdot
.52553 .68165 Mdot
.31203 .27105 Mdot
.46625 .66527 Mdot
.64055 .39922 Mdot
.5047 .65961 Mdot
.76188 .62809 Mdot
.64553 .58072 Mdot
.48751 .64478 Mdot
.63881 .3674 Mdot
.3029 .50481 Mdot
.71689 .56037 Mdot
.4821 .60044 Mdot
.66111 .29556 Mdot
.51947 .59017 Mdot
.78407 .37537 Mdot
.48671 .52718 Mdot
.28616 .49009 Mdot
.56944 .53968 Mdot
.38159 .36803 Mdot
.43392 .71278 Mdot
.4193 .60967 Mdot
.60207 .35549 Mdot
.45949 .27784 Mdot
.42963 .3717 Mdot
.37588 .47389 Mdot
.50662 .56458 Mdot
.30165 .52057 Mdot
.70289 .52068 Mdot
.63145 .41142 Mdot
.45043 .59988 Mdot
.54206 .67394 Mdot
.78477 .50364 Mdot
.51015 .5608 Mdot
.45617 .66469 Mdot
.28546 .51126 Mdot
.7816 .55824 Mdot
.49136 .6541 Mdot
.54158 .47452 Mdot
.62244 .58239 Mdot
.42734 .66553 Mdot
.78986 .5946 Mdot
.51285 .66763 Mdot
.68133 .56237 Mdot
.7202 .53984 Mdot
.67711 .39861 Mdot
.34564 .5146 Mdot
.44138 .62934 Mdot
.72215 .728 Mdot
.51817 .64046 Mdot
.59567 .37712 Mdot
.54812 .61228 Mdot
.41129 .366 Mdot
.25832 .68386 Mdot
.44994 .35532 Mdot
.44621 .62588 Mdot
.65029 .56247 Mdot
.61123 .35046 Mdot
.33005 .75389 Mdot
.30844 .34549 Mdot
.78094 .57498 Mdot
.80603 .36103 Mdot
.32893 .47968 Mdot
.3406 .52637 Mdot
.63143 .41325 Mdot
.48868 .64587 Mdot
.79577 .63372 Mdot
.43457 .68615 Mdot
.49451 .65936 Mdot
.47191 .63456 Mdot
.26976 .32302 Mdot
.58649 .37707 Mdot
.43834 .36145 Mdot
.49187 .67086 Mdot
.5334 .65418 Mdot
.62683 .56611 Mdot
.30399 .50972 Mdot
.39474 .36569 Mdot
.32818 .51562 Mdot
.40973 .38021 Mdot
.19311 .3527 Mdot
.54003 .65921 Mdot
.30471 .50346 Mdot
.57911 .34503 Mdot
.65817 .57764 Mdot
.67443 .4645 Mdot
.40984 .35586 Mdot
.4503 .38222 Mdot
.47432 .67329 Mdot
.6835 .5609 Mdot
.68206 .57568 Mdot
.30709 .49351 Mdot
.62655 .39533 Mdot
.47122 .60069 Mdot
.47793 .58668 Mdot
.74486 .56266 Mdot
.46114 .37003 Mdot
.59603 .50241 Mdot
.62252 .2642 Mdot
.49113 .6439 Mdot
.67385 .57828 Mdot
.46601 .62241 Mdot
.66337 .25632 Mdot
.69214 .54951 Mdot
.51273 .66937 Mdot
.1933 .50497 Mdot
.46981 .33389 Mdot
.68753 .41119 Mdot
.46369 .67657 Mdot
.73333 .2778 Mdot
.51872 .61592 Mdot
.24673 .25436 Mdot
.34716 .35547 Mdot
.45444 .60506 Mdot
.53323 .63897 Mdot
.59539 .75703 Mdot
.45447 .61872 Mdot
.44093 .40612 Mdot
.23152 .5277 Mdot
.67619 .58392 Mdot
.68195 .31551 Mdot
.49379 .75543 Mdot
.34564 .48822 Mdot
.43445 .3392 Mdot
.41257 .32182 Mdot
.3336 .49577 Mdot
.65974 .56013 Mdot
.49787 .63818 Mdot
.47913 .46816 Mdot
.46011 .35002 Mdot
.5778 .61471 Mdot
.59765 .37927 Mdot
.54562 .29053 Mdot
.44982 .31071 Mdot
.61225 .36959 Mdot
.49792 .6027 Mdot
.58235 .76293 Mdot
.35856 .73837 Mdot
.61659 .19226 Mdot
.58802 .35413 Mdot
.59812 .35358 Mdot
.25584 .6912 Mdot
.32896 .4689 Mdot
.795 .48888 Mdot
.73093 .39492 Mdot
.62242 .35891 Mdot
.43382 .5543 Mdot
.41542 .40404 Mdot
.67518 .32851 Mdot
.61123 .59529 Mdot
.49756 .58414 Mdot
.47767 .62534 Mdot
.62896 .38933 Mdot
.61682 .61942 Mdot
.50405 .81111 Mdot
.60783 .35835 Mdot
.52514 .55731 Mdot
.50735 .42252 Mdot
.41319 .26854 Mdot
.44443 .39777 Mdot
.34259 .51808 Mdot
.34716 .53349 Mdot
.6196 .54817 Mdot
.3393 .52261 Mdot
.24205 .42524 Mdot
.5053 .62757 Mdot
.61662 .36308 Mdot
.4881 .27361 Mdot
.61078 .37947 Mdot
.3337 .49864 Mdot
.28256 .49652 Mdot
.6361 .56737 Mdot
.64054 .5549 Mdot
.58614 .69374 Mdot
.29557 .62545 Mdot
.46156 .65905 Mdot
.40696 .23898 Mdot
.66828 .58218 Mdot
.57744 .62538 Mdot
.33111 .52792 Mdot
.30543 .5082 Mdot
.34456 .55568 Mdot
.49513 .61561 Mdot
.68416 .75453 Mdot
.49309 .61912 Mdot
.27341 .60722 Mdot
.46165 .68371 Mdot
.44416 .36065 Mdot
.4961 .61083 Mdot
.25231 .51759 Mdot
.44085 .60896 Mdot
.55318 .615 Mdot
.45824 .35348 Mdot
.546 .587 Mdot
.41343 .36487 Mdot
.44778 .63865 Mdot
.34103 .4776 Mdot
.45352 .35098 Mdot
.34719 .60395 Mdot
.36141 .5424 Mdot
.43479 .41481 Mdot
.31355 .5242 Mdot
.34086 .48112 Mdot
.36434 .61948 Mdot
.66564 .52417 Mdot
.63907 .59699 Mdot
.48616 .64828 Mdot
.389 .35498 Mdot
.58755 .38413 Mdot
.52903 .65554 Mdot
.53199 .58912 Mdot
.47826 .68298 Mdot
.61998 .54444 Mdot
.28303 .35775 Mdot
.30432 .49827 Mdot
.41707 .41197 Mdot
.25709 .48926 Mdot
.45848 .38976 Mdot
.55845 .63446 Mdot
.5001 .57093 Mdot
.56426 .70381 Mdot
.4863 .24322 Mdot
.2479 .6946 Mdot
.68161 .55524 Mdot
.40308 .35213 Mdot
.33438 .47303 Mdot
.55416 .66907 Mdot
.67146 .53327 Mdot
.40984 .3647 Mdot
.49522 .64319 Mdot
.49076 .69942 Mdot
.73893 .49442 Mdot
.48225 .74337 Mdot
.37221 .55789 Mdot
.44828 .39832 Mdot
.38098 .37941 Mdot
.22413 .43434 Mdot
.31297 .45557 Mdot
.42818 .49015 Mdot
.46804 .65093 Mdot
.3214 .52131 Mdot
.68397 .52982 Mdot
.34236 .73896 Mdot
.63109 .3928 Mdot
.45478 .50694 Mdot
.48058 .64739 Mdot
.41485 .46063 Mdot
.64917 .56376 Mdot
.32305 .49251 Mdot
.62941 .38634 Mdot
.3091 .53155 Mdot
.4362 .33562 Mdot
.83914 .44331 Mdot
.51514 .63804 Mdot
.46659 .66948 Mdot
.61008 .34023 Mdot
.68321 .53437 Mdot
.30783 .52858 Mdot
.79382 .46734 Mdot
.42687 .34717 Mdot
.7864 .65242 Mdot
.68775 .56522 Mdot
.74469 .64039 Mdot
.41971 .41051 Mdot
.59519 .41319 Mdot
.35647 .62663 Mdot
.62089 .3726 Mdot
.44481 .63481 Mdot
.65889 .54593 Mdot
.59694 .40152 Mdot
.45242 .51553 Mdot
.34957 .21678 Mdot
.72784 .6734 Mdot
.49924 .62758 Mdot
.27367 .26191 Mdot
.74372 .33839 Mdot
.6835 .50568 Mdot
.61704 .3462 Mdot
.46911 .66528 Mdot
.45348 .60153 Mdot
.51724 .6433 Mdot
.60163 .39699 Mdot
.36978 .2751 Mdot
.42873 .35238 Mdot
.45797 .6411 Mdot
.33533 .52072 Mdot
.42088 .36461 Mdot
.45824 .29262 Mdot
.44531 .39081 Mdot
.68063 .50855 Mdot
.54773 .6106 Mdot
.64187 .41395 Mdot
.19405 .31564 Mdot
.59065 .36189 Mdot
.44538 .41071 Mdot
.54644 .63202 Mdot
.48373 .26354 Mdot
.66539 .5307 Mdot
.43213 .34641 Mdot
.47846 .67011 Mdot
.44709 .28757 Mdot
.27148 .68422 Mdot
.44448 .39077 Mdot
.67638 .53127 Mdot
.5778 .19355 Mdot
.47935 .65407 Mdot
.51999 .62198 Mdot
.67955 .54526 Mdot
.50976 .77228 Mdot
.21213 .60007 Mdot
.46636 .61584 Mdot
.60753 .36377 Mdot
.84236 .57037 Mdot
.55736 .61986 Mdot
.27819 .57023 Mdot
.40362 .3745 Mdot
.67535 .35002 Mdot
.5823 .50589 Mdot
.55241 .6723 Mdot
.78959 .4703 Mdot
.56941 .42914 Mdot
.26038 .29551 Mdot
.37613 .40406 Mdot
.34334 .43491 Mdot
.23926 .30532 Mdot
.64091 .38819 Mdot
.73075 .52831 Mdot
.77594 .41578 Mdot
.35536 .79188 Mdot
.58133 .20227 Mdot
.28762 .42701 Mdot
.25331 .65271 Mdot
.48275 .45339 Mdot
.41114 .38512 Mdot
.28652 .52882 Mdot
.47675 .60234 Mdot
.74083 .33376 Mdot
.70626 .73204 Mdot
.59206 .81543 Mdot
.27852 .25621 Mdot
.63968 .77399 Mdot
.34563 .22753 Mdot
.46081 .17628 Mdot
.57917 .67178 Mdot
.49959 .2359 Mdot
.78511 .66261 Mdot
.20032 .48608 Mdot
.82211 .5086 Mdot
.43267 .70285 Mdot
.54293 .48473 Mdot
.79079 .36323 Mdot
.75814 .60701 Mdot
.50657 .80097 Mdot
.44701 .35504 Mdot
.69763 .53026 Mdot
.76701 .40297 Mdot
.70974 .53501 Mdot
.65026 .43475 Mdot
.58502 .18944 Mdot
.36883 .20089 Mdot
.76686 .62363 Mdot
.69538 .23945 Mdot
.61977 .643 Mdot
.61015 .84965 Mdot
.46578 .35759 Mdot
.63926 .52261 Mdot
.36595 .4794 Mdot
.22081 .43035 Mdot
.75952 .4679 Mdot
.76962 .38882 Mdot
.32176 .29745 Mdot
.33306 .65828 Mdot
.66092 .55394 Mdot
.55764 .53357 Mdot
.66144 .35589 Mdot
.71849 .45629 Mdot
.22939 .53309 Mdot
.50096 .18176 Mdot
.48325 .4764 Mdot
.67037 .30747 Mdot
.56148 .27658 Mdot
.30498 .78366 Mdot
.31143 .57025 Mdot
.56265 .67195 Mdot
.63284 .45736 Mdot
.65094 .23914 Mdot
.39339 .80195 Mdot
.29637 .64418 Mdot
.21981 .43444 Mdot
.18158 .43851 Mdot
.71336 .28911 Mdot
.15737 .53791 Mdot
.63295 .59337 Mdot
.45886 .66842 Mdot
.53535 .75192 Mdot
.7343 .71423 Mdot
.28348 .48542 Mdot
.36902 .25716 Mdot
.34567 .49601 Mdot
.61968 .53051 Mdot
.24707 .65912 Mdot
.78728 .58571 Mdot
.73407 .72031 Mdot
.35358 .52371 Mdot
.56113 .60076 Mdot
.89573 .52047 Mdot
.28628 .27981 Mdot
.68384 .43579 Mdot
.28575 .22808 Mdot
.40952 .47359 Mdot
.44889 .53747 Mdot
.59685 .3999 Mdot
.23788 .29733 Mdot
.67021 .5421 Mdot
.1461 .48852 Mdot
.23665 .27249 Mdot
.44496 .76475 Mdot
.698 .17054 Mdot
.23331 .39217 Mdot
.42983 .46469 Mdot
.55974 .40602 Mdot
.3282 .59319 Mdot
.46804 .80678 Mdot
.424 .73287 Mdot
.50529 .26236 Mdot
.79529 .33968 Mdot
.25656 .28861 Mdot
.75917 .68471 Mdot
.83622 .46426 Mdot
.37766 .8059 Mdot
.56005 .45913 Mdot
.62988 .60391 Mdot
.42413 .31097 Mdot
.47959 .19554 Mdot
.18221 .39163 Mdot
.29466 .56914 Mdot
.84557 .36292 Mdot
.2794 .47077 Mdot
.33394 .35773 Mdot
.58446 .17779 Mdot
.34276 .65836 Mdot
.5395 .52627 Mdot
.22622 .50949 Mdot
.57194 .63313 Mdot
.24601 .47326 Mdot
.40403 .22885 Mdot
.6489 .45352 Mdot
.20627 .48337 Mdot
.57951 .21665 Mdot
.78277 .5038 Mdot
.63111 .73245 Mdot
.21226 .43671 Mdot
.7026 .56603 Mdot
.31729 .65139 Mdot
.53425 .52178 Mdot
.35743 .20267 Mdot
.59431 .43772 Mdot
.40786 .17035 Mdot
.21689 .60265 Mdot
.49949 .68803 Mdot
.41545 .62925 Mdot
.54218 .55618 Mdot
.30635 .62719 Mdot
.55555 .60215 Mdot
.75501 .49366 Mdot
.42177 .17908 Mdot
.6377 .62896 Mdot
.6695 .37036 Mdot
.45107 .27782 Mdot
.60154 .18124 Mdot
.56918 .72685 Mdot
.32436 .45504 Mdot
.24429 .57814 Mdot
.3516 .80563 Mdot
.43234 .36837 Mdot
.76845 .66602 Mdot
.62894 .3403 Mdot
.29396 .7046 Mdot
.65005 .74715 Mdot
.44279 .77942 Mdot
.42328 .1784 Mdot
.29163 .44169 Mdot
.23548 .63233 Mdot
.3656 .69757 Mdot
.81599 .60258 Mdot
.42046 .26281 Mdot
.49832 .56749 Mdot
.72284 .33251 Mdot
.31584 .47569 Mdot
.60374 .7111 Mdot
.8309 .55523 Mdot
.29554 .39562 Mdot
.44014 .5965 Mdot
.40547 .76338 Mdot
.48697 .38918 Mdot
.4268 .50511 Mdot
.19359 .65931 Mdot
.55763 .65107 Mdot
.22492 .38061 Mdot
.73017 .30453 Mdot
.30902 .59459 Mdot
.63928 .21618 Mdot
.63115 .24592 Mdot
.15848 .50411 Mdot
.2675 .25082 Mdot
.29943 .3515 Mdot
.23196 .32094 Mdot
.33368 .20687 Mdot
.16444 .5275 Mdot
.42181 .59679 Mdot
.60842 .33825 Mdot
.27664 .78295 Mdot
.4384 .40464 Mdot
.25239 .33651 Mdot
.81067 .51281 Mdot
.47212 .31168 Mdot
.65868 .49421 Mdot
.48216 .73047 Mdot
.48805 .45701 Mdot
.67393 .50437 Mdot
.54994 .59154 Mdot
.19956 .64275 Mdot
.17167 .48414 Mdot
.1787 .59061 Mdot
.73274 .29158 Mdot
.21564 .33696 Mdot
.46997 .4405 Mdot
.77 .599 Mdot
.60096 .61027 Mdot
.50953 .59195 Mdot
.38119 .49295 Mdot
.23513 .38873 Mdot
.40211 .76549 Mdot
.75195 .44461 Mdot
.69819 .51497 Mdot
.38439 .24463 Mdot
.64521 .86651 Mdot
.61081 .66425 Mdot
.79862 .5859 Mdot
.2277 .43826 Mdot
.29515 .6151 Mdot
.46165 .20569 Mdot
.4441 .7715 Mdot
.48113 .16819 Mdot
.66122 .50305 Mdot
.81812 .50282 Mdot
.30609 .41801 Mdot
.39802 .57699 Mdot
.28802 .34922 Mdot
.38382 .20342 Mdot
.53099 .36889 Mdot
.3706 .76698 Mdot
.73963 .3866 Mdot
.46858 .78739 Mdot
.35712 .36807 Mdot
.55557 .29116 Mdot
.82537 .56425 Mdot
.57742 .24843 Mdot
.27665 .59167 Mdot
.51278 .43075 Mdot
.58522 .54689 Mdot
.56829 .42673 Mdot
.28189 .58982 Mdot
.38982 .57293 Mdot
.22178 .35038 Mdot
.18144 .29908 Mdot
.25663 .71923 Mdot
.66877 .20657 Mdot
.42884 .22323 Mdot
.44016 .59963 Mdot
.53469 .15639 Mdot
.16395 .57572 Mdot
.22385 .27518 Mdot
.54784 .32067 Mdot
.37441 .40506 Mdot
.5835 .40792 Mdot
.20932 .64042 Mdot
.35775 .2935 Mdot
.52435 .1668 Mdot
.22638 .50023 Mdot
.57724 .40164 Mdot
.47101 .84597 Mdot
.18553 .45439 Mdot
.67757 .73022 Mdot
.48826 .74142 Mdot
.43376 .66107 Mdot
.75321 .65552 Mdot
.70515 .52921 Mdot
.58102 .26419 Mdot
.30127 .63826 Mdot
.43882 .37849 Mdot
.37972 .5025 Mdot
.75996 .37298 Mdot
.52558 .59475 Mdot
.60605 .45722 Mdot
.6851 .51536 Mdot
.49215 .24187 Mdot
.70265 .46879 Mdot
.17647 .38983 Mdot
.26229 .35553 Mdot
.45449 .68788 Mdot
.30617 .58974 Mdot
.28024 .35388 Mdot
.21077 .60712 Mdot
.62046 .42619 Mdot
.30058 .23953 Mdot
.51624 .49144 Mdot
.31488 .64947 Mdot
.73421 .69009 Mdot
.71508 .59788 Mdot
.50041 .5754 Mdot
.58548 .23841 Mdot
.67942 .67449 Mdot
.43911 .50902 Mdot
.60742 .5973 Mdot
.66683 .60223 Mdot
.55357 .15303 Mdot
.24381 .43547 Mdot
.54773 .28089 Mdot
.32634 .22529 Mdot
.60906 .3913 Mdot
.65888 .58133 Mdot
.33015 .54386 Mdot
.7991 .45185 Mdot
.70898 .64885 Mdot
.27197 .6854 Mdot
.46463 .31034 Mdot
.3077 .38637 Mdot
.33266 .22705 Mdot
.29313 .2501 Mdot
.65325 .79483 Mdot
.71684 .53682 Mdot
.58929 .64594 Mdot
.80524 .47277 Mdot
.70314 .53952 Mdot
.7728 .51459 Mdot
.76045 .50864 Mdot
.19394 .37442 Mdot
.63474 .43722 Mdot
.78124 .32147 Mdot
.36859 .57171 Mdot
.35778 .27354 Mdot
.32552 .75243 Mdot
.8211 .57079 Mdot
.35669 .22204 Mdot
.42318 .57072 Mdot
.60845 .76526 Mdot
.43857 .70891 Mdot
.63492 .4932 Mdot
.37249 .83208 Mdot
.3403 .54569 Mdot
.74679 .64072 Mdot
.5832 .21505 Mdot
.50518 .6385 Mdot
.26127 .73063 Mdot
.78929 .42344 Mdot
.25544 .69419 Mdot
.57217 .37573 Mdot
.50981 .60286 Mdot
.44803 .59802 Mdot
.25856 .56382 Mdot
.67869 .39943 Mdot
.21339 .37569 Mdot
.84394 .53948 Mdot
.53749 .20689 Mdot
.70504 .7326 Mdot
.23407 .37118 Mdot
.52261 .17401 Mdot
.73406 .32523 Mdot
.53066 .45843 Mdot
.2411 .38262 Mdot
.34865 .64874 Mdot
.69712 .24443 Mdot
.39437 .53878 Mdot
.59299 .32307 Mdot
.7701 .47882 Mdot
.62915 .26298 Mdot
.33916 .74557 Mdot
.52631 .61521 Mdot
.21364 .57049 Mdot
.47789 .17746 Mdot
.67332 .77442 Mdot
.4472 .81825 Mdot
.24143 .70472 Mdot
.67827 .69999 Mdot
.62763 .2549 Mdot
.7375 .33632 Mdot
.81816 .63583 Mdot
.52173 .49458 Mdot
.33401 .25572 Mdot
.35211 .66672 Mdot
.33066 .2259 Mdot
.61908 .34264 Mdot
.74401 .40802 Mdot
.44522 .2763 Mdot
.22346 .33807 Mdot
.57242 .7422 Mdot
.41025 .19374 Mdot
.42975 .47189 Mdot
.15642 .48866 Mdot
.55341 .23815 Mdot
.48352 .44519 Mdot
.41408 .34483 Mdot
.27593 .44549 Mdot
.39477 .22526 Mdot
.46413 .23415 Mdot
.81532 .57507 Mdot
.38385 .40261 Mdot
.30776 .53995 Mdot
.68255 .73725 Mdot
.34993 .70179 Mdot
.59843 .23824 Mdot
.30655 .59003 Mdot
.39754 .18992 Mdot
.24053 .53142 Mdot
.21811 .57904 Mdot
.25211 .35398 Mdot
.83666 .40113 Mdot
.68289 .43108 Mdot
.23651 .454 Mdot
.78188 .40613 Mdot
.34137 .34588 Mdot
.44489 .54706 Mdot
.0623 .50835 Mdot
.82922 .42491 Mdot
.5239 .23596 Mdot
.18257 .39162 Mdot
.66191 .24784 Mdot
.49247 .24463 Mdot
.45896 .8014 Mdot
.52729 .51433 Mdot
.2569 .6355 Mdot
.47281 .6344 Mdot
.18454 .62649 Mdot
.33037 .67996 Mdot
.17156 .42111 Mdot
.55051 .16036 Mdot
.74516 .66567 Mdot
.53529 .59802 Mdot
.40636 .40889 Mdot
.64118 .44264 Mdot
.33404 .70577 Mdot
.55278 .76939 Mdot
.51719 .53349 Mdot
.42594 .28508 Mdot
.42319 .33711 Mdot
.26875 .37455 Mdot
.61731 .52668 Mdot
.35533 .28953 Mdot
.62031 .26111 Mdot
.47708 .34774 Mdot
.48298 .48429 Mdot
.2884 .59773 Mdot
.57945 .50971 Mdot
.68313 .72416 Mdot
.43076 .77235 Mdot
.56843 .44983 Mdot
.4472 .3907 Mdot
.65853 .73434 Mdot
.8021 .3746 Mdot
.54266 .2143 Mdot
.18015 .43269 Mdot
.25881 .46958 Mdot
.57594 .78103 Mdot
.2749 .58395 Mdot
.47949 .81037 Mdot
.55926 .80314 Mdot
.44272 .25124 Mdot
.61135 .52229 Mdot
.50647 .7934 Mdot
.73183 .35017 Mdot
.20731 .33718 Mdot
.82128 .5076 Mdot
.80997 .4806 Mdot
.37857 .31724 Mdot
.74197 .61509 Mdot
.71885 .70449 Mdot
.35291 .59945 Mdot
.42937 .49524 Mdot
.5744 .85947 Mdot
.62471 .59891 Mdot
.44656 .88151 Mdot
.59729 .41031 Mdot
.39142 .81757 Mdot
.35495 .65314 Mdot
.51557 .42545 Mdot
.40155 .48526 Mdot
.59383 .24624 Mdot
.72749 .40025 Mdot
.74784 .31441 Mdot
.56257 .81355 Mdot
.46372 .3738 Mdot
.84835 .53431 Mdot
.8406 .40202 Mdot
.61786 .75074 Mdot
.55461 .63362 Mdot
.82958 .41098 Mdot
.381 .41428 Mdot
.40372 .76714 Mdot
.63984 .21372 Mdot
.47313 .22422 Mdot
.41497 .60229 Mdot
.29817 .62175 Mdot
.3367 .25194 Mdot
.29732 .23377 Mdot
.47696 .83599 Mdot
.40587 .22882 Mdot
.61388 .34065 Mdot
.46902 .44764 Mdot
.41799 .19891 Mdot
.44503 .53341 Mdot
.68285 .33395 Mdot
.51633 .52734 Mdot
.52394 .88804 Mdot
.25826 .32261 Mdot
.21547 .37313 Mdot
.48673 .52859 Mdot
.62285 .57187 Mdot
.6729 .39842 Mdot
.54306 .52567 Mdot
.48998 .22299 Mdot
.79073 .378 Mdot
.53977 .52339 Mdot
.75771 .72612 Mdot
.70831 .60448 Mdot
.46526 .42842 Mdot
.70398 .72591 Mdot
.63117 .62719 Mdot
.57149 .37469 Mdot
.22554 .56403 Mdot
.56651 .20562 Mdot
.59606 .33774 Mdot
.59246 .23501 Mdot
.66534 .30604 Mdot
.75107 .57689 Mdot
.71327 .65505 Mdot
.50651 .20679 Mdot
.57414 .75866 Mdot
.72469 .50922 Mdot
.33545 .7328 Mdot
.44283 .41483 Mdot
.56586 .20004 Mdot
.42022 .34586 Mdot
.57353 .63843 Mdot
.45498 .50983 Mdot
.4384 .7369 Mdot
.23752 .68334 Mdot
.32786 .47863 Mdot
.6705 .51715 Mdot
.41526 .83616 Mdot
.69849 .55112 Mdot
.19247 .62712 Mdot
.44479 .77732 Mdot
.73655 .68826 Mdot
.2993 .35898 Mdot
.2789 .40052 Mdot
.67355 .80582 Mdot
.60607 .45289 Mdot
.42935 .30732 Mdot
.68906 .48 Mdot
.64692 .51921 Mdot
.26534 .3468 Mdot
.4586 .35925 Mdot
.52691 .50596 Mdot
.52769 .36248 Mdot
.73124 .56072 Mdot
.69055 .49572 Mdot
.4996 .49743 Mdot
.26328 .62551 Mdot
.20403 .36321 Mdot
.41373 .3932 Mdot
.47246 .87231 Mdot
.5215 .58554 Mdot
.6263 .72792 Mdot
.48017 .16602 Mdot
.48159 .84559 Mdot
.42397 .3156 Mdot
.84466 .40259 Mdot
.4659 .6886 Mdot
.47452 .20556 Mdot
.66779 .54881 Mdot
.81258 .48953 Mdot
.337 .48415 Mdot
.31526 .59444 Mdot
.58278 .40317 Mdot
.36758 .76688 Mdot
.49209 .35548 Mdot
.65969 .58867 Mdot
.43446 .23116 Mdot
.59378 .64237 Mdot
.71646 .36968 Mdot
.26973 .39285 Mdot
.62307 .7517 Mdot
.71735 .64631 Mdot
.69996 .50192 Mdot
.22295 .35835 Mdot
.81748 .4861 Mdot
.18281 .35603 Mdot
.5672 .57062 Mdot
.32864 .44513 Mdot
.77029 .49477 Mdot
.56112 .22331 Mdot
.62283 .49556 Mdot
.45086 .1689 Mdot
.30633 .65202 Mdot
.73948 .5609 Mdot
.27602 .60492 Mdot
.47749 .70714 Mdot
.50936 .46487 Mdot
.58417 .27518 Mdot
.58575 .81933 Mdot
.60751 .48896 Mdot
.41087 .81064 Mdot
.61527 .51145 Mdot
.21308 .39844 Mdot
.60236 .54683 Mdot
.41739 .33104 Mdot
.74711 .61853 Mdot
.6094 .44578 Mdot
.21907 .32173 Mdot
.46049 .16739 Mdot
.63069 .42593 Mdot
.30046 .3168 Mdot
.64039 .22837 Mdot
.50976 .70202 Mdot
.44043 .45291 Mdot
.45262 .66004 Mdot
.59685 .61853 Mdot
.4928 .85267 Mdot
.518 .21984 Mdot
.47103 .5675 Mdot
.25599 .2972 Mdot
.24906 .28909 Mdot
.16467 .46225 Mdot
.79883 .63393 Mdot
.6248 .55852 Mdot
.17323 .55236 Mdot
.51899 .53546 Mdot
.32142 .2136 Mdot
.44653 .24644 Mdot
.53571 .14745 Mdot
.60401 .76295 Mdot
.60779 .22972 Mdot
.48407 .79352 Mdot
.70334 .38986 Mdot
.70051 .28368 Mdot
.50691 .40584 Mdot
.53153 .27824 Mdot
.67841 .26035 Mdot
.83387 .64313 Mdot
.53028 .70015 Mdot
.66549 .30116 Mdot
.7517 .38514 Mdot
.55589 .19748 Mdot
.34888 .37575 Mdot
.54799 .61273 Mdot
.479 .27647 Mdot
.29154 .72325 Mdot
.29176 .58611 Mdot
.29228 .53483 Mdot
.34879 .37098 Mdot
.29686 .68807 Mdot
.27171 .61519 Mdot
.8229 .50708 Mdot
.61817 .75766 Mdot
.55984 .49862 Mdot
.52181 .67071 Mdot
.64442 .50102 Mdot
.35139 .51197 Mdot
.5112 .38043 Mdot
.45014 .64677 Mdot
.3936 .34867 Mdot
.7155 .37765 Mdot
.22694 .68258 Mdot
.65826 .44035 Mdot
.78497 .39781 Mdot
.6049 .57225 Mdot
.66137 .31089 Mdot
.65447 .47524 Mdot
.30821 .75336 Mdot
.33851 .41435 Mdot
.29501 .5691 Mdot
.29414 .26764 Mdot
.20659 .4806 Mdot
.75266 .56655 Mdot
.18897 .50781 Mdot
.62824 .35573 Mdot
.47645 .55769 Mdot
.76234 .41355 Mdot
.25796 .38503 Mdot
.60081 .59284 Mdot
.60495 .22976 Mdot
.43647 .30878 Mdot
.22565 .46048 Mdot
.72432 .29586 Mdot
.62245 .62307 Mdot
.65259 .75693 Mdot
.28301 .25841 Mdot
.40318 .39967 Mdot
.81994 .45901 Mdot
.68245 .32338 Mdot
.33342 .4305 Mdot
.2018 .4048 Mdot
.18762 .37012 Mdot
.42274 .48302 Mdot
.3366 .63699 Mdot
.52419 .63232 Mdot
.82277 .55032 Mdot
.54134 .22414 Mdot
.44884 .73189 Mdot
.53826 .31889 Mdot
.676 .57486 Mdot
.58144 .29348 Mdot
.54907 .48834 Mdot
.27372 .65815 Mdot
.7073 .52898 Mdot
.70379 .73766 Mdot
.34482 .48122 Mdot
.3922 .46075 Mdot
.55403 .59312 Mdot
.33288 .61738 Mdot
.75166 .70371 Mdot
.56307 .57827 Mdot
.42879 .21456 Mdot
.64095 .74785 Mdot
.79657 .47123 Mdot
.49144 .21068 Mdot
.44154 .25451 Mdot
.72258 .39892 Mdot
.73865 .6383 Mdot
.51445 .36224 Mdot
.47413 .68149 Mdot
.41787 .32824 Mdot
.69452 .56853 Mdot
.59996 .19643 Mdot
.68308 .68951 Mdot
.34669 .60769 Mdot
.53425 .41782 Mdot
.57329 .645 Mdot
.54557 .40554 Mdot
.51632 .15343 Mdot
.70345 .39199 Mdot
.29963 .63947 Mdot
.63311 .4393 Mdot
.35375 .64697 Mdot
.44162 .78341 Mdot
.23024 .28519 Mdot
.47167 .79812 Mdot
.46779 .47524 Mdot
.42135 .81816 Mdot
.5853 .25029 Mdot
.64722 .21979 Mdot
.28736 .6325 Mdot
.38895 .46674 Mdot
.27773 .48575 Mdot
.74044 .50072 Mdot
.55268 .44754 Mdot
.27078 .52164 Mdot
.54375 .50704 Mdot
.51435 .3303 Mdot
.64677 .32714 Mdot
.47919 .72955 Mdot
.26071 .33093 Mdot
.28921 .26344 Mdot
.8115 .49962 Mdot
.56647 .42929 Mdot
.35943 .4386 Mdot
.28975 .67059 Mdot
.58885 .14596 Mdot
.32531 .80555 Mdot
.52314 .63365 Mdot
.57302 .44107 Mdot
.32544 .63448 Mdot
.44921 .39852 Mdot
.57152 .52058 Mdot
.65106 .47192 Mdot
.58692 .39807 Mdot
.31698 .54433 Mdot
.22589 .47189 Mdot
.60171 .25409 Mdot
.36389 .71271 Mdot
.45547 .28758 Mdot
.22729 .68764 Mdot
.79071 .35148 Mdot
.54851 .222 Mdot
.53432 .13195 Mdot
.64096 .31323 Mdot
.70212 .58634 Mdot
.5365 .74435 Mdot
.2056 .36586 Mdot
.3119 .58239 Mdot
.31655 .72608 Mdot
.43699 .26333 Mdot
.29822 .64524 Mdot
.46992 .5397 Mdot
.24122 .36467 Mdot
.57174 .29857 Mdot
.50251 .44907 Mdot
.28028 .40305 Mdot
.18578 .47766 Mdot
.65893 .76109 Mdot
.31605 .25448 Mdot
.30437 .73772 Mdot
.80177 .67112 Mdot
.23288 .30093 Mdot
.36756 .531 Mdot
.35133 .40922 Mdot
.54038 .74761 Mdot
.3931 .55481 Mdot
.4291 .55844 Mdot
.39511 .76457 Mdot
.7005 .64585 Mdot
.32433 .31986 Mdot
.36924 .79268 Mdot
.27703 .59118 Mdot
.65281 .62404 Mdot
.3909 .46971 Mdot
.67781 .724 Mdot
.29726 .32302 Mdot
.46503 .52756 Mdot
.40295 .53186 Mdot
.34832 .57336 Mdot
.64771 .74004 Mdot
.78204 .49466 Mdot
.64689 .24877 Mdot
.76856 .72612 Mdot
.39916 .24888 Mdot
.32068 .76397 Mdot
.52497 .59848 Mdot
.16405 .38811 Mdot
.65561 .26692 Mdot
.42259 .25731 Mdot
.76271 .34358 Mdot
.44618 .43927 Mdot
.71607 .58426 Mdot
.47493 .68162 Mdot
.3848 .23501 Mdot
.74412 .64766 Mdot
.59902 .65452 Mdot
.35746 .76734 Mdot
.30565 .60499 Mdot
.23531 .51224 Mdot
.35962 .59054 Mdot
.53549 .55893 Mdot
.69706 .54452 Mdot
.17452 .57971 Mdot
.44814 .47429 Mdot
.56958 .64887 Mdot
.43156 .71622 Mdot
.47308 .78594 Mdot
.80592 .34412 Mdot
.54784 .55844 Mdot
.20695 .46486 Mdot
.62349 .77974 Mdot
.4021 .6433 Mdot
.59739 .52395 Mdot
.5762 .10258 Mdot
.21445 .27059 Mdot
.66867 .58681 Mdot
.79509 .59516 Mdot
.63168 .77782 Mdot
.21923 .35164 Mdot
.31089 .41621 Mdot
.53209 .34358 Mdot
.4143 .71075 Mdot
.40779 .55478 Mdot
.53474 .57381 Mdot
.73735 .31509 Mdot
.23931 .27466 Mdot
.36307 .77621 Mdot
.25811 .29418 Mdot
.41753 .66554 Mdot
.53357 .56907 Mdot
.62336 .15039 Mdot
.40642 .20353 Mdot
.53758 .68275 Mdot
.49938 .80391 Mdot
.62824 .6034 Mdot
.47305 .60853 Mdot
.33686 .27336 Mdot
.84731 .53053 Mdot
.27382 .58716 Mdot
.22316 .339 Mdot
.71348 .53845 Mdot
.44932 .32154 Mdot
.59282 .40918 Mdot
.41028 .48942 Mdot
.49986 .6954 Mdot
.60211 .40169 Mdot
.45322 .75336 Mdot
.60295 .22201 Mdot
.64845 .42621 Mdot
.83264 .49288 Mdot
.44132 .15526 Mdot
.68915 .69617 Mdot
.72771 .49119 Mdot
.55213 .67064 Mdot
.65288 .62254 Mdot
.3248 .70349 Mdot
.61645 .61322 Mdot
.66651 .24151 Mdot
.09682 .50804 Mdot
.52067 .2863 Mdot
.24064 .60286 Mdot
.61526 .53306 Mdot
.57332 .49982 Mdot
.70117 .71322 Mdot
.3834 .44045 Mdot
.39824 .38478 Mdot
.42962 .68443 Mdot
.5553 .56555 Mdot
.57557 .36308 Mdot
.42802 .8678 Mdot
.54702 .62023 Mdot
.58921 .51391 Mdot
.32327 .21404 Mdot
.3346 .73251 Mdot
.6061 .73055 Mdot
.44735 .67181 Mdot
.72533 .46092 Mdot
.38765 .46475 Mdot
.52325 .18742 Mdot
.21769 .57264 Mdot
.26319 .29936 Mdot
.68399 .68617 Mdot
.64548 .76338 Mdot
.53217 .65647 Mdot
.30768 .46996 Mdot
.68053 .35002 Mdot
.35685 .26264 Mdot
.41872 .62222 Mdot
.28405 .23815 Mdot
.47072 .42652 Mdot
.49521 .34722 Mdot
.49893 .55078 Mdot
.164 .47828 Mdot
.41062 .79827 Mdot
.72943 .68361 Mdot
.29034 .74105 Mdot
.25465 .40944 Mdot
.34823 .69887 Mdot
.40204 .40537 Mdot
.41751 .63124 Mdot
.71272 .54988 Mdot
.23458 .70606 Mdot
.32714 .27266 Mdot
.51059 .27022 Mdot
.55193 .29278 Mdot
.80116 .56046 Mdot
.7137 .35565 Mdot
.50486 .13257 Mdot
.26422 .40916 Mdot
.23722 .70389 Mdot
.81321 .47415 Mdot
.59606 .5839 Mdot
.61048 .24189 Mdot
.50872 .5585 Mdot
.43346 .39318 Mdot
.25291 .31102 Mdot
.5717 .60216 Mdot
.2504 .66086 Mdot
.43361 .62899 Mdot
.24104 .67348 Mdot
.28489 .5414 Mdot
.29169 .3164 Mdot
.5479 .24143 Mdot
.45082 .79458 Mdot
.57163 .18095 Mdot
.74527 .50389 Mdot
.57228 .15265 Mdot
.57683 .18946 Mdot
.29489 .24298 Mdot
.28246 .70203 Mdot
.51452 .83754 Mdot
.46569 .23653 Mdot
.51275 .20862 Mdot
.60177 .26725 Mdot
.51654 .76725 Mdot
.27889 .44302 Mdot
.53198 .55284 Mdot
.68626 .39775 Mdot
.64045 .40876 Mdot
.17565 .71217 Mdot
.25331 .52592 Mdot
.65936 .59282 Mdot
.26192 .43699 Mdot
.2613 .27202 Mdot
.49818 .77217 Mdot
.69151 .26841 Mdot
.54006 .48476 Mdot
.50289 .56837 Mdot
.70266 .66107 Mdot
.80772 .53161 Mdot
.27339 .45167 Mdot
.68125 .81022 Mdot
.79231 .36141 Mdot
.52827 .30963 Mdot
.50602 .47277 Mdot
.70423 .53621 Mdot
.67885 .48662 Mdot
.28942 .38453 Mdot
.68433 .24897 Mdot
.60603 .22696 Mdot
.41585 .19941 Mdot
.67584 .80292 Mdot
.80143 .47426 Mdot
.20447 .36555 Mdot
.55941 .23457 Mdot
.63867 .58968 Mdot
.3764 .51585 Mdot
.41946 .42725 Mdot
.51917 .26299 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0]oooool2o`00093ooooo
000Looooo`03o`000?oooooooooo0;Oooooo0_l0002@ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0:[ooooo0_l0002Mooooo`00
7?ooool00ol0003oooooooooo`2Pooooo`;o00002?ooool2o`0009gooooo000Looooo`03o`000?oo
oooooooo0:3ooooo0_l0002Wooooo`007?ooool00ol0003oooooooooo`2Iooooo`;o0000[_ooool0
01cooooo00?o0000ooooooooool0VOooool2o`000:kooooo000Looooo`03o`000?oooooooooo0:[o
oooo0_l0000?ooooo`;o0000S?ooool001cooooo00?o0000ooooooooool0Z_ooool2o`0000oooooo
0_l0000:ooooo`;o0000P?ooool001cooooo0_l0002Uooooo`;o00002_ooool2o`0000Cooooo0_l0
000?ooooo`;o0000P?ooool001cooooo00?o0000ooooooooool0S?ooool2o`0001Kooooo0_l00004
ooooo`So00001?ooool2o`00097ooooo000Looooo`03o`000?oooooooooo08cooooo0_l0000Coooo
o`;o000000Coooooo`000?l0003ooooo2Ol0002Iooooo`007?ooool00ol0003oooooooooo`2Qoooo
o`;o000000Coooooo`000?l0003ooooo1_l00002ooooo`;o0000V?ooool001cooooo00?o0000oooo
ooooool0U?ooool2o`0000;ooooo0_l00002ooooo`;o00003Oooool2o`0000;ooooo0_l0002Hoooo
o`007?ooool00ol0003oooooooooo`2?ooooo`;o000000?oooooo`000?l000000_l000000ooooooo
0000o`000002o`000003ooooool0003o000000Sooooo0ol0002Pooooo`007?ooool00ol0003ooooo
ooooo`21ooooo`;o00003?ooool2o`000003ooooool0003o000000?ooooo1?l00003ooooo`;o0000
1_ooool4o`0000Sooooo0_l0000[ooooo`;o0000J?ooool001cooooo00?o0000ooooooooool0POoo
ool2o`0001_ooooo0_l00006ooooo`Co00002?ooool2o`0002_ooooo0_l0001Xooooo`007?ooool0
0ol0003oooooooooo`26ooooo`;o00000_ooool2o`0000Kooooo0_l00003ooooo`Co00002?ooool2
o`000003ooooool0003o000001;ooooo0_l0002=ooooo`007?ooool00ol0003oooooooooo`25oooo
o`?o00000_ooool2o`000003ooooool0003o000000?ooooo0_l00002ooooo`Go00002?ooool2o`00
017ooooo0_l00002ooooo`;o00001?ooool2o`0008Oooooo000Looooo`03o`000?oooooooooo07oo
oooo0_l00004ooooo`?o00001Oooool2o`0000Oooooo1?l00005ooooo`;o00005Oooool2o`0000Oo
oooo0ol00007ooooo`;o0000O_ooool001cooooo00?o0000ooooooooool0L?ooool2o`0000_ooooo
1_l00003ooooo`;o00001Oooool2o`0000Wooooo0_l00003ooooo`Co00001Oooool2o`0001Oooooo
0_l00008ooooo`;o0000O_ooool001cooooo00?o0000ooooooooool0L?ooool2o`0000[ooooo1?l0
00000ooooooo0000o`000003ooooo`;o00005Oooool2o`0000Oooooo0_l0000@ooooo`Co00001_oo
ool4o`0008?ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go0000
1_ooool00ol0003oooooooooo`1looooo`Co00000_ooool4o`0003;ooooo1?l00006ooooo`Go0000
P_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A006ooooo`03o`000?oooooooooo08;ooooo1?l0000Booooo`;o000000?oooooo`00
0?l000006oooool2o`0000Gooooo1Ol000000ooooooo0000o`000022ooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000oooooooo
ool0N_ooool2o`0000Oooooo0ol0000Booooo`;o000000?oooooo`000?l000005?ooool2o`000004
ooooool0003o0000o`0000Sooooo1Ol0000<ooooo`;o0000Moooool00003ooooool0003ooooo00;o
oooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06ooooo`?o0000L?ooool2o`0000;o
oooo0_l00004ooooo`;o00001oooool3o`0001oooooo0_l0000:ooooo`;o000000Coooooo`000?l0
003o00000_ooool2o`0000Kooooo0_l0000=ooooo`;o00000oooool2o`0007;ooooo00000ooooooo
0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003o
ooooooooo`1`ooooo`;o00000_ooool2o`0000;ooooo0ol00005ooooo`;o00004?ooool2o`0000;o
oooo0_l00007ooooo`;o00001?ooool2o`0000gooooo0ol00002ooooo`;o00001_ooool2o`0000Ko
oooo0_l0000:ooooo`;o0000L_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool0
3Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06Wooooo0ol00005ooooo`Co0000
0oooool3o`0000Gooooo0_l0000:ooooo`;o00000oooool3o`0000;ooooo0_l00006ooooo`Oo0000
1_ooool2o`0000Oooooo0_l0000Booooo`?o00002_ooool2o`000003ooooool0003o000000Cooooo
0_l0001Yooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRH
V?l@41001_ooool00ol0003oooooooooo`1Vooooo`;o000000Coooooo`000?l0003o00001Oooool4
o`0001Oooooo0_l00003ooooo`;o00000oooool2o`0000Cooooo1?l000000ooooooo0000o`000002
o`0000Gooooo0ol0000Kooooo`;o00002oooool2o`000003ooooool0003o000000Cooooo0_l0001Y
ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
1_ooool00ol0003oooooooooo`1Uooooo`?o00008?ooool2o`0000;ooooo0_l00008ooooo`;o0000
1?ooool2o`0000Cooooo0_l00006ooooo`;o000000?oooooo`000?l000001_ooool2o`0000?ooooo
0_l0000@ooooo`;o0000Noooool001cooooo00?o0000ooooooooool0IOooool2o`0000Oooooo0_l0
000Hooooo`;o00004oooool2o`0000?ooooo0_l00009ooooo`;o00001Oooool3o`000003ooooool0
003o000000;o00004?ooool2o`0007_ooooo000Looooo`03o`000?oooooooooo05kooooo0_l0000=
ooooo`Co0000;?ooool2o`0000Gooooo1?l0000<ooooo`;o00000_ooool2o`0000Gooooo0_l0000;
ooooo`Co00001?ooool4o`0000_ooooo0_l0001Tooooo`007?ooool00ol0003oooooooooo`1Noooo
o`;o00003Oooool5o`0000Gooooo0_l0000<ooooo`;o000000?oooooo`000?l000003?ooool2o`00
00?ooooo0_l00007ooooo`Co00001?ooool4o`0000;ooooo0_l00006ooooo`;o00000oooool3o`00
00cooooo0_l00004ooooo`Co00002oooool2o`0000;ooooo0_l0001Pooooo`007?ooool00ol0003o
ooooooooo`1Sooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o000000?oooooo`000?l0
00001Oooool2o`000003ooooool0003o000000;o00001oooool2o`000003ooooool0003o000000?o
oooo0_l00007ooooo`;o00000oooool2o`0000oooooo1?l00002ooooo`;o00001_ooool2o`0000Co
oooo0ol0000<ooooo`;o00000_ooool2o`0001;ooooo0_l0001Pooooo`007?ooool00ol0003ooooo
ooooo`1Iooooo`;o00002?ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l00000
0_l0000;ooooo`Co00000_ooool2o`0000_ooooo0_l0000Pooooo`;o00004?ooool3o`0000Cooooo
0_l00002ooooo`;o000000Goooooo`000?l0003o0000ooooo`04o`0007;ooooo000Looooo`03o`00
0?oooooooooo05Wooooo0_l00002ooooo`;o00003?ooool2o`000003ooooool0003o000000gooooo
0_l000000ooooooo0000o`000007ooooo`;o00009?ooool2o`00013ooooo0ol00002ooooo`Co0000
0_ooool2o`0000;ooooo0ol00002ooooo`?o0000LOooool001cooooo00?o0000ooooooooool0GOoo
ool2o`0000cooooo0_l000001?oooooo0000o`000?ooool2o`0000Kooooo0_l00002ooooo`;o0000
2_ooool2o`0000Sooooo0ol00009ooooo`;o00001Oooool2o`0000Sooooo1?l00009ooooo`;o0000
1oooool2o`0000Cooooo0_l00003ooooo`;o00000_ooool4o`00073ooooo000Looooo`03o`000?oo
oooooooo05Wooooo0_l00003ooooo`;o00004Oooool2o`0000Kooooo0_l00005ooooo`;o00004Ooo
ool3o`0000Wooooo0_l00005ooooo`Co00001_ooool4o`0000Gooooo0ol000000ooooooo0000o`00
0002o`0000gooooo1?l00005ooooo`;o00001Oooool2o`0006Wooooo000Looooo`03o`000?oooooo
oooo05Wooooo0_l000000ooooooo0000o`000002o`0000[ooooo0_l0000Booooo`Co00003oooool2
o`0000Cooooo0_l00003ooooo`;o00002_ooool2o`000004ooooool0003o0000ooooo`Co00000_oo
ool2o`0000?ooooo0ol00003ooooo`Ko00002Oooool4o`0000?ooooo0_l00007ooooo`;o0000JOoo
ool001cooooo00?o0000ooooooooool0G?ooool2o`0000cooooo0_l0000=ooooo`;o00000oooool2
o`0000Cooooo0_l0000;ooooo`;o00001?ooool7o`0000gooooo0_l000000ooooooo0000o`000004
ooooo`;o00001oooool8o`0000Cooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo1?l00006
ooooo`;o0000J?ooool001cooooo00?o0000ooooooooool0Coooool2o`0000_ooooo0_l0000Koooo
o`;o00000oooool2o`0000Cooooo0_l00007ooooo`;o00002Oooool6o`0001Wooooo0ol00003oooo
o`;o00002_ooool2o`0000;ooooo0ol000000ooooooo0000o`000002o`0000;ooooo1Ol00003oooo
o`;o0000J?ooool001cooooo0_l0001?ooooo`?o00000_ooool2o`0000Kooooo0_l00006ooooo`;o
00001Oooool2o`0001;ooooo0_l0000<ooooo`?o00001Oooool2o`0001Cooooo0_l0000;ooooo`Go
00004_ooool2o`0000?ooooo1?l000000ooooooo0000o`000002o`0001cooooo0_l0001?ooooo`00
7?ooool00ol0003oooooooooo`1<ooooo`Co00000oooool2o`0000Kooooo0_l00006ooooo`;o0000
1Oooool2o`0001_ooooo1?l000000ooooooo0000o`000006ooooo`;o00005?ooool2o`0000gooooo
1Ol00002ooooo`Co00001?ooool2o`0000Kooooo0_l000000ooooooo0000o`000002o`00027ooooo
0_l0001?ooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00002Oooool3o`0000Wooooo0_l0
0004ooooo`;o00001_ooool2o`000003ooooool0003o000000;ooooo0_l00007ooooo`;o00000ooo
ool5o`000003ooooool0003o000001_ooooo0ol0000>ooooo`Co00000_ooool4o`0000Cooooo0_l0
0006ooooo`;o00000_ooool2o`0007?ooooo000Looooo`03o`000?oooooooooo04[ooooo0ol0000:
ooooo`?o00003oooool2o`0000Kooooo0_l000000ooooooo0000o`000002ooooo`Co00001Oooool3
o`0000;ooooo0_l00004ooooo`;o00002Oooool2o`0000Cooooo0_l00008ooooo`Co00003?ooool2
o`0000Cooooo0_l00007ooooo`;o00003?ooool2o`0000?ooooo0_l00002ooooo`;o00005_ooool2
o`0005;ooooo000Looooo`03o`000?oooooooooo04Wooooo1?l00008ooooo`;o00000oooool2o`00
01Cooooo0_l00008ooooo`;o00001_ooool2o`000004ooooool0003o0000ooooo`Ko00002Oooool4
o`000005ooooool0003o0000o`000?ooool00_l00002ooooo`Oo00003?ooool8o`0000Oooooo0_l0
00000ooooooo0000o`00000=ooooo`?o00000_ooool2o`0001Kooooo0_l0001Booooo`007?ooool0
0ol0003oooooooooo`19ooooo`;o00002Oooool3o`0000?ooooo1?l0000Booooo`;o00000_ooool2
o`0000Gooooo0_l000000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l000000_l0000=
ooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000Ko00003?ooool6
o`0000;ooooo0ol00004ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Gooooo0_l0001_
ooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00004?ooool2o`0000Kooooo0_l0000Boooo
o`;o00000_ooool6o`000004ooooool0003o0000ooooo`;o00000_ooool3o`0000;ooooo0_l0000E
ooooo`;o00000_ooool3o`0000;ooooo0_l0000Fooooo`?o00003oooool4o`000003ooooool0003o
000000Gooooo1?l0001Xooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00001Oooool2o`00
00Kooooo0_l0000?ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo1?l00004oooo
o`Co00001?ooool2o`0000;ooooo1ol0000@ooooo`Oo00000_ooool3o`000003ooooool0003o0000
00_ooooo0_l00006ooooo`;o00001_ooool2o`0000cooooo1ol000000ooooooo0000o`000002oooo
o`Co0000J?ooool001cooooo00?o0000ooooooooool0AOooool2o`0000;ooooo0ol00005ooooo`;o
00003oooool2o`0000?ooooo1Ol00002ooooo`Co00000_ooool2o`0000Sooooo0_l00004ooooo`So
000000?oooooo`000?l000002Oooool8o`0000?ooooo0_l000000ooooooo0000o`00000;ooooo`;o
00001Oooool5o`0000Cooooo1?l0000<ooooo`Co00000_ooool2o`0000?ooooo0_l0001Yooooo`00
7?ooool00ol0003oooooooooo`15ooooo`;o00000oooool2o`0000_ooooo1?l0000;ooooo`;o0000
00?oooooo`000?l000002?ooool3o`0000Sooooo0_l00008ooooo`Wo000000?oooooo`000?l00000
1?ooool2o`0000;ooooo1Ol00008ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Gooooo
0_l000000ooooooo0000o`000006ooooo`?o00001oooool2o`0000Cooooo0ol00006ooooo`;o0000
2_ooool2o`00013ooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`1Gooooo`Ko00002Ooo
ool2o`0000Oooooo0_l00002ooooo`;o00005?ooool8o`000003ooooool0003o000000?ooooo0_l0
0002ooooo`?o000000?oooooo`000?l000002?ooool7o`0001Kooooo0_l00006ooooo`?o00001?oo
ool3o`0001;ooooo0_l0000@ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0@oooool2
o`0000;ooooo0_l0000Booooo`;o00001_ooool2o`0000Gooooo0_l000000ooooooo0000o`000002
o`000003ooooool0003o000000;o00004Oooool2o`0000?ooooo0_l00009ooooo`;o00000_ooool3
o`0000Oooooo0ol00003ooooo`;o000000?oooooo`000?l000007_ooool4o`0000?ooooo0_l00009
ooooo`;o00002?ooool2o`0005gooooo000Looooo`03o`000?oooooooooo04?ooooo0_l00002oooo
o`;o00001?ooool2o`000003ooooool0003o000000cooooo0_l00003ooooo`;o00001Oooool2o`00
0003ooooool0003o000000?ooooo1?l00008ooooo`;o00001oooool2o`0000?ooooo0ol000000ooo
oooo0000o`000005ooooo`;o00000_ooool2o`0000Sooooo0ol0000Xooooo`;o00003_ooool2o`00
00;ooooo0_l00003ooooo`;o0000G_ooool001cooooo00?o0000ooooooooool0COooool2o`000003
ooooool0003o000000Wooooo0_l000000ooooooo0000o`00000@ooooo`;o00003?ooool2o`0000Oo
oooo0_l00004ooooo`;o000000?oooooo`000?l000001Oooool6o`0000oooooo0ol00002ooooo`Co
00004_ooool2o`0000_ooooo0_l0000>ooooo`;o00000oooool3o`0000Cooooo0_l0001Gooooo`00
7?ooool00ol0003oooooooooo`1<ooooo`;o00000_ooool3o`0000Sooooo0_l000001?oooooo0000
o`000?l0000?ooooo`?o00001oooool2o`0000Cooooo0_l00005ooooo`;o00001oooool3o`0000Go
oooo0ol0000:ooooo`;o00001Oooool3o`000003ooooool0003o000000?o00001?ooool2o`0000co
oooo0_l00007ooooo`;o00000_ooool2o`0000kooooo0_l00004ooooo`Co00000_ooool2o`0005Oo
oooo000Looooo`03o`000?oooooooooo04[ooooo1?l000000ooooooo0000o`000002o`0000;ooooo
0_l00007ooooo`?o00001?ooool2o`000003ooooool0003o000000Kooooo0ol00007ooooo`;o0000
00Coooooo`000?l0003ooooo0_l00002ooooo`?o00001oooool2o`000003ooooool0003o000001;o
oooo0_l00009ooooo`;o000000Coooooo`000?l0003ooooo0_l000001?oooooo0000o`000?ooool2
o`0000Gooooo0_l0000;ooooo`;o000000Coooooo`000?l0003o00004Oooool2o`0000?ooooo0_l0
001Kooooo`007?ooool2o`0003Sooooo0_l0000?ooooo`Co00000oooool5o`000003ooooool0003o
000000;ooooo0_l0000:ooooo`;o000000?oooooo`000?l000004oooool2o`0000Gooooo0ol00007
ooooo`;o00001Oooool3o`000003ooooool0003o000001Sooooo0_l000000ooooooo0000o`000003
ooooo`?o00001Oooool2o`0000kooooo0ol0000Aooooo`;o0000H?ooool001cooooo00?o0000oooo
ooooool0=oooool2o`0000oooooo0_l00006ooooo`Co00001Oooool4o`0003Sooooo0ol000000ooo
oooo0000o`000002o`0000cooooo0_l00002ooooo`;o00003?ooool2o`00017ooooo0_l00004oooo
o`;o00000_ooool3o`0000kooooo0_l000001?oooooo0000o`000?ooool2o`0005Sooooo000Loooo
o`03o`000?oooooooooo04[ooooo0_l0000=ooooo`Co0000:oooool2o`0000_ooooo0_l00004oooo
o`;o00002_ooool4o`0000;ooooo0_l0000Oooooo`;o00001?ooool8o`0000gooooo0_l000000ooo
oooo0000o`000003o`0005Sooooo000Looooo`03o`000?oooooooooo04Sooooo1?l00004ooooo`;o
00002Oooool2o`0002_ooooo1?l00002ooooo`;o00000oooool4o`0000;ooooo0_l0000<ooooo`?o
00006Oooool2o`0000kooooo1Ol00002ooooo`Co00002?ooool2o`0000Kooooo0_l0001Iooooo`00
7?ooool00ol0003oooooooooo`18ooooo`;o00001?ooool4o`0000Wooooo0_l0000Gooooo`;o0000
0oooool2o`0000_ooooo0_l00002ooooo`;o00000_ooool3o`000005ooooool0003o0000o`000?oo
ool00_l000000ooooooo0000o`00000=ooooo`;o00002?ooool2o`0000Sooooo0_l00004ooooo`?o
00001oooool2o`0000Gooooo0_l00007ooooo`Co00001_ooool2o`0000Wooooo0_l0001Fooooo`00
7?ooool00ol0003oooooooooo`0kooooo`;o00004Oooool2o`0000_ooooo0_l000000ooooooo0000
o`000002o`0000[ooooo0_l00006ooooo`Co000000?oooooo`000?l000002oooool2o`000003oooo
ool0003o000000Cooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00005Oooool2o`0000?o
oooo0_l00008ooooo`;o00001?ooool2o`0000Sooooo0_l0000<ooooo`;o00000_ooool2o`0000Ko
oooo0_l00004ooooo`;o000000?oooooo`000?l000000_l0001Fooooo`007?ooool00ol0003ooooo
ooooo`0kooooo`;o00001_ooool2o`000003ooooool0003o000001?ooooo0_l000000ooooooo0000
o`000002o`0000;ooooo1?l00004ooooo`;o00002?ooool3o`0000_ooooo1?l000001?oooooo0000
o`000?l0000Oooooo`Go00001oooool2o`0000Wooooo0_l0000;ooooo`;o00002Oooool2o`0000;o
oooo0_l00006ooooo`;o00001?ooool2o`000003ooooool0003o000005Sooooo000Looooo`03o`00
0?oooooooooo04?ooooo0_l000000ooooooo0000o`000002o`0000Kooooo0_l00002ooooo`;o0000
1Oooool4o`0000Gooooo1?l00004ooooo`;o00002Oooool2o`0000Wooooo1?l00004ooooo`;o0000
0_ooool2o`0000cooooo0_l00007ooooo`;o00001?ooool2o`000003ooooool0003o000000;ooooo
0_l00003ooooo`;o00001?ooool2o`0000?ooooo0_l0000:ooooo`?o00001?ooool2o`0000Oooooo
0_l0000Jooooo`;o0000COooool001cooooo00?o0000ooooooooool0@oooool2o`0000?ooooo0_l0
0006ooooo`;o00000_ooool2o`0000Gooooo1?l0000;ooooo`;o00005_ooool2o`0000Sooooo1?l0
000:ooooo`Co00001oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000Sooooo0ol0
000?ooooo`;o00001Oooool2o`0000?ooooo0_l00002ooooo`Co00002Oooool2o`0000gooooo0_l0
001=ooooo`007?ooool00ol0003oooooooooo`1Zooooo`;o00001?ooool2o`0001;ooooo0_l00005
ooooo`Co00002oooool2o`0000gooooo0_l00006ooooo`;o00002Oooool2o`0000oooooo0ol00002
ooooo`;o00000_ooool6o`0000;ooooo1?l00009ooooo`;o00004?ooool2o`0004[ooooo000Loooo
o`03o`000?oooooooooo057ooooo0_l0000=ooooo`;o00003_ooool2o`0001;ooooo1?l000000ooo
oooo0000o`000003o`0000Sooooo0_l00003ooooo`;o00001_ooool2o`0000[ooooo1Ol00006oooo
o`;o00001_ooool2o`0000Wooooo0ol00002ooooo`;o00000_ooool4o`0000Gooooo0_l0000Foooo
o`;o00001?ooool2o`0004[ooooo000Looooo`03o`000?oooooooooo053ooooo0ol00007ooooo`;o
00001?ooool2o`0001Oooooo0_l00009ooooo`_o00001Oooool4o`000003ooooool0003o000000;o
00001_ooool2o`0000Cooooo0_l00004ooooo`;o000000Coooooo`000?l0003o00000oooool4o`00
00?ooooo1Ol0000Dooooo`Co000000?oooooo`000?l000000_l00006ooooo`;o00001?ooool2o`00
00Sooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`10ooooo`Co000000?oooooo`000?l0
00001oooool5o`0000Oooooo0_l0000Mooooo`;o00002Oooool=o`0000?ooooo0ol00002ooooo`;o
00003_ooool2o`000003ooooool0003o000000Gooooo0_l00003ooooo`;o000000Coooooo`000?l0
003ooooo1_l00004ooooo`;o00000_ooool2o`0000Oooooo0_l00003ooooo`;o000000?oooooo`00
0?l000002?ooool2o`0000?ooooo1?l0001Iooooo`007?ooool00ol0003oooooooooo`0oooooo`Go
000000?oooooo`000?l000001oooool2o`000003ooooool0003o0000013ooooo0_l0000Booooo`;o
00002_ooool>o`0000Gooooo0_l00002ooooo`;o00004?ooool2o`0000gooooo1_l000000ooooooo
0000o`000007o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o00005Oooool4o`0000oo
oooo0_l00018ooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00001?ooool2o`0000gooooo
0_l0000=ooooo`;o00004_ooool2o`0000Kooooo6Ol00002ooooo`;o00003Oooool2o`0000Kooooo
0_l00002ooooo`;o000000?oooooo`000?l000000_ooool?o`000003ooooool0003o000000?ooooo
0_l00002ooooo`;o00001?ooool2o`0000Kooooo0_l0000?ooooo`;o00002Oooool2o`000003oooo
ool0003o000004Gooooo000Looooo`03o`000?oooooooooo04cooooo0_l00004ooooo`Co00001?oo
ool2o`0000Cooooo0_l000000ooooooo0000o`000006ooooo`;o00002_ooool2o`000003ooooool0
003o000000;ooooo3Ol000000ooooooo0000o`000008o`000003ooooool0003o000000Cooooo0_l0
000:ooooo`;o00001_ooool2o`0000;ooooo1Ol00004ooooo`Wo00001Oooool2o`0000gooooo0_l0
0006ooooo`;o00003oooool2o`0000cooooo0_l00007ooooo`;o0000??ooool001cooooo0_l0000n
ooooo`;o00001Oooool2o`0000Kooooo0_l00004ooooo`?o00001Oooool2o`0000Cooooo0ol00008
ooooo`;o00002_ooool2o`000003ooooool0003o000000oo000000?oooooo`000?l000001_l00003
ooooo`;o00001?ooool2o`0000?ooooo0_l0000Cooooo`?o000000?oooooo`000?l000004?l0000;
ooooo`?o00000_ooool2o`0000_ooooo0_l0000Dooooo`Co00001oooool2o`0003cooooo000Loooo
o`03o`000?oooooooooo03_ooooo1?l00005ooooo`;o00000oooool2o`0000?ooooo0_l00007oooo
o`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000oooooo0_l00008oooo
o`;o000000?oooooo`000?l000004ol0000>ooooo`?o00004ooooolFo`0000[ooooo0ol00002oooo
o`;o00001_ooool2o`0000?ooooo0_l0000Aooooo`;o000000?oooooo`000?l000000_l00015oooo
o`007?ooool00ol0003oooooooooo`0hooooo`;o000000?oooooo`000?l000001oooool2o`0000?o
oooo0_l00003ooooo`Go00001?ooool4o`0000?ooooo0_l00006ooooo`;o00001Oooool4o`000003
ooooool0003o000000;ooooo1?l000001?oooooo0000o`000?oooolGo`0000Oooooo0_l00005oooo
o`;o00004ooooolFo`0000Gooooo0_l00005ooooo`;o00001?ooool2o`0000;ooooo0ol00008oooo
o`;o00003?ooool2o`000003ooooool0003o000004Oooooo000Looooo`03o`000?oooooooooo03So
oooo0_l0000;ooooo`;o00002?ooool5o`0000Cooooo0ol00003ooooo`;o00001_ooool2o`000003
ooooool0003o000000;ooooo1?l00005ooooo`Co000000Coooooo`000?l0003ooooo6?l00006oooo
o`Co00006?oooolEo`0000Kooooo0_l00005ooooo`;o00001?ooool2o`0000;ooooo0_l00009oooo
o`;o00003oooool2o`0004Oooooo000Looooo`03o`000?oooooooooo03oooooo0_l00004ooooo`;o
00001Oooool2o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`0000Wooooo0_l0000;ooooob7o
00001oooool2o`0000?ooooo0_l00003ooooo`;o00000oooool2o`0000Kooooo6?l00008ooooo`;o
00004_ooool2o`0001;ooooo0ol00002ooooo`;o00002oooool2o`0003Sooooo000Looooo`03o`00
0?oooooooooo03Sooooo0_l00005ooooo`;o00002_ooool3o`0000Wooooo0_l0000Oooooo`oo0000
0_ooool>o`000003ooooool0003o000000Kooooo0_l000000ooooooo0000o`000003ooooo`;o0000
0oooool2o`0000Gooooo6?l000000ooooooo0000o`000006ooooo`;o00001oooool2o`0000Wooooo
0_l00008ooooo`;o00002?ooool7o`0000_ooooo0_l0000hooooo`007?ooool00ol0003ooooooooo
o`0hooooo`;o00001Oooool3o`0000Wooooo0_l0000:ooooo`;o00005oooool2o`0000Kooooo0_l0
00000ooooooo0000o`00000Io`0000;ooooo0_l00006ooooo`;o00001oooool2o`0000Wooooo1?l0
00000ooooooo0000o`00000@o`000003ooooool0003o000000?o00001_ooool2o`0000Gooooo0ol0
0007ooooo`;o00002Oooool2o`0000_ooooo0_l00004ooooo`;o0000@Oooool001cooooo00?o0000
ooooooooool0>Oooool2o`0000Gooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00008Ooo
ool2o`000003ooooool0003o000000;o00001OoooolOo`0000kooooo0_l00003ooooo`Co00002ooo
oolIo`0000Gooooo0ol00006ooooo`;o00001?ooool2o`000004ooooool0003o0000o`0000Oooooo
0_l00005ooooo`;o00002?ooool2o`000003ooooool0003o0000047ooooo000Looooo`03o`000?oo
oooooooo03Wooooo1?l00005ooooo`Co000000Coooooo`000?l0003o00002_ooool3o`0000_ooooo
0_l00007ooooo`;o000000Coooooo`000?l0003o00001_oooolEo`000003ooooool0003o000000Ko
00000oooool2o`0000[ooooo0_l00002ooooo`;o000000?oooooo`000?l000002?ooool<o`0000;o
oooo1_l000000ooooooo0000o`000004o`0000Kooooo0_l0000=ooooo`;o00000_ooool2o`0000Oo
oooo0ol00004ooooo`Co00001?ooool4o`000003ooooool0003o000000Oooooo0_l0000hooooo`00
7?ooool00ol0003oooooooooo`0kooooo`;o00001Oooool2o`00013ooooo0ol0000;ooooo`;o0000
2_ooool2o`0000Oooooo7_l00003ooooo`;o00003_ooool2o`0000_ooooo6?l00004ooooo`;o0000
0oooool2o`0000;ooooo0_l00009ooooo`;o00003?ooool2o`0000Kooooo1?l000001?oooooo0000
o`000?l0000<ooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0@_ooool2o`000003oooo
ool0003o000000kooooo0_l0000Gooooo`;o00001oooool?o`0000;ooooo3?l00003ooooo`;o0000
2Oooool2o`0001;ooooo5ol00004ooooo`;o00000oooool2o`0000;ooooo0_l00009ooooo`;o0000
0oooool2o`0000[ooooo0_l00005ooooo`;o000000?oooooo`000?l00000Aoooool001cooooo00?o
0000ooooooooool0>oooool2o`0000Kooooo1?l00004ooooo`;o00003Oooool2o`0001?ooooo0_l0
0003ooooo`;o00000_oooolMo`0000;ooooo0_l00009ooooo`;o00005?oooolEo`0000Oooooo0_l0
000;ooooo`;o00001oooool2o`0000[ooooo0_l0000:ooooo`;o00001oooool2o`0003cooooo000L
ooooo`03o`000?oooooooooo03_ooooo0_l00003ooooo`;o000000?oooooo`000?l000001_ooool2
o`0000?ooooo1_l00004ooooo`;o00001?ooool2o`0000gooooo0_l00003ooooob7o00000_ooool2
o`0000Wooooo0ol0000@ooooo`;o000000?oooooo`000?l000004Ol000000ooooooo0000o`000006
ooooo`;o00002oooool2o`0000Wooooo0_l00002ooooo`;o00002_ooool2o`0000Cooooo0_l00007
ooooo`;o0000??ooool001cooooo00?o0000ooooooooool0<_ooool2o`0000;ooooo0_l00008oooo
o`;o00001oooool2o`0000Gooooo1_l0000:ooooo`;o00003Oooool2o`0000Gooooo5?l000000ooo
oooo0000o`000008o`0000Gooooo0_l00003ooooo`;o000000Coooooo`000?l0003o00004?oooolI
o`0000kooooo0_l00003ooooo`;o00001oooool4o`0000;ooooo0_l00004ooooo`;o00001?ooool2
o`0004_ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o
410@ooooooooool01?ooool00ol0003oooooooooo`0booooo`;o00000_ooool4o`0000kooooo0ol0
0007ooooo`Co00005_ooool2o`000003ooooool0003o000000Gooooo7Ol00006ooooo`Co00000_oo
ool2o`0001Kooooo1?l000000ooooooo0000o`00000@o`0000kooooo0_l00003ooooo`;o00000ooo
ool2o`0000;ooooo0_l0000:ooooo`;o0000DOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0gooooo`?o0000
1_ooool3o`0000Gooooo0_l00009ooooo`?o00001_ooool2o`0000kooooo0_l00008ooooo`;o0000
00Coooooo`000?l0003ooooo5_l00007ooooo`Co00001_ooool2o`0001Cooooo5Ol00002ooooo`;o
00003oooool2o`0000?ooooo1_l00002ooooo`;o0000FOooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool02Oooool5o`0000Kooooo00?o0000ooooooooool08_ooool2o`0001_ooooo
1Ol0000Hooooo`;o00006?ooool2o`000003ooooool0003o000001Oo00001?ooool2o`000003oooo
ool0003o000000Sooooo0_l0000<ooooo`;o00001_oooolBo`000003ooooool0003o000000;ooooo
0_l00005ooooo`Ko00001Oooool2o`0000?ooooo2Ol0000;ooooo`;o00001Oooool2o`0000;ooooo
0_l00011ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04odA4A?oM
gMgoooooo`0000Oooooo0ol0000Rooooo`;o00006oooool2o`000003ooooool0003o000001?ooooo
0_l0000Mooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`00000Bo`0000Cooooo
1Ol0000=ooooo`;o00001oooool4o`0000?ooooo5_l00002ooooo`;o00001Oooool6o`0000Gooooo
1?l000000ooooooo0000o`000002o`000003ooooool0003o000000;o00001?ooool3o`0000Cooooo
1?l00003ooooo`;o00000_ooool2o`0000Cooooo1Ol0000hooooo`0000?oooooo`000?ooool00_oo
ool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0
=?ooool2o`0000Sooooo0_l0000Gooooo`;o00005oooool2o`0000Cooooo0_l000000ooooooo0000
o`000006o`000003ooooool0003o000000co00001oooool3o`0000Cooooo0_l000000ooooooo0000
o`000005ooooo`;o00000oooool2o`0000?ooooo0ol00003ooooo`co000000?oooooo`000?l00000
1Ol0000Hooooo`;o00001oooool3o`0000Cooooo0ol00003ooooo`;o000000?oooooo`000?l00000
2Oooool2o`0000;ooooo1Ol0000hooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0=?ooool2o`0000Oooooo0ol0
000?ooooo`;o000000?oooooo`000?l000006_ooool4o`0000Cooooo0_l00004ooooo`[o000000Co
ooooo`000?l0003ooooo2?l00002ooooo`;o000000?oooooo`000?l000001Oooool2o`000003oooo
ool0003o000000[ooooo0_l00003ooooo`;o00001?oooolFo`0001cooooo0_l000001?oooooo0000
o`000?l0000:ooooo`Co00002_ooool2o`0003oooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMg
M`cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0mooooo`;o00004?ooool2o`00
0004ooooool0003o0000ooooo`;o00002_ooool2o`0000_ooooo0_l00002ooooo`;o00001ooooolK
o`0002;ooooo5_l0000>ooooo`;o00002_ooool4o`0000;ooooo0_l0000<ooooo`;o00003?ooool2
o`0000;ooooo0_l0000iooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0
003ooooo00Kooooo00?o0000ooooooooool0BOooool2o`0000Gooooo0_l00003ooooo`;o00002_oo
ool2o`0000Oooooo0_l00006ooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`go0000
00Coooooo`000?l0003o00000oooool2o`0000Oooooo0_l0000@ooooo`;o00002_oooolCo`000003
ooooool0003o000000gooooo0_l0000:ooooo`;o00002_ooool2o`0001Cooooo0_l00002ooooo`;o
0000>Oooool001cooooo00?o0000ooooooooool0>_ooool2o`0000Kooooo0_l00005ooooo`;o0000
1Oooool2o`0000kooooo0ol00007ooooo`;o00001Oooool2o`000003ooooool0003o000000;ooooo
0_l00005ooooo`Oo000000?oooooo`000?l000000_l000000ooooooo0000o`00000=ooooo`;o0000
3Oooool2o`000003ooooool0003o000000_ooooo4_l000000ooooooo0000o`00000Uooooo`;o0000
0_ooool2o`0004oooooo000Looooo`03o`000?oooooooooo03Cooooo0_l00002ooooo`Co00001_oo
ool2o`0001cooooo0ol0000>ooooo`;o000000?oooooo`000?l000002oooool5o`000003ooooool0
003o000000?ooooo0_l0000Looooo`;o000000?oooooo`000?l000003?ooool;o`000003ooooool0
003o000000;o00001oooool4o`0002;ooooo0_l0000>ooooo`;o0000?oooool001cooooo00?o0000
ooooooooool0<oooool3o`0000;ooooo0_l0000_ooooo`;o00001Oooool2o`0000;ooooo0_l0000;
ooooo`Co000000Coooooo`000?l0003o00006?ooool2o`0000;ooooo0_l00006ooooo`;o000000?o
ooooo`000?l000002?ooool2o`0000?ooooo2_l00009ooooo`Co00008_ooool2o`0000?ooooo0_l0
0006ooooo`;o000000?oooooo`000?l000000_l0000mooooo`007?ooool00ol0003oooooooooo`0c
ooooo`;o00004_ooool2o`0000;ooooo0_l00004ooooo`;o00001oooool2o`0000gooooo0_l00005
ooooo`;o00000_ooool2o`0000oooooo1?l0000<ooooo`;o00002_ooool2o`000004ooooool0003o
0000o`0000Kooooo0_l000000ooooooo0000o`000003ooooo`;o00000oooool2o`0000?ooooo1Ol0
00001Ooooooo0000o`000?l0003ooooo00;o00001?ooool2o`0000;ooooo0ol0000Kooooo`;o0000
1Oooool2o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000000oooool2o`0003gooooo
000Looooo`03o`000?oooooooooo04Cooooo0_l000000ooooooo0000o`000002ooooo`;o00001?oo
ool2o`0000;ooooo0_l00003ooooo`;o00003Oooool2o`0001[ooooo1?l0000:ooooo`Co00003?oo
ool3o`0000Oooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00001oooool2o`0000;ooooo
0_l000001Ooooooo0000o`000?l0003ooooo00;o00001?ooool2o`0000;ooooo0ol00004ooooo`;o
00005Oooool2o`0000Oooooo0_l00006ooooo`;o0000AOooool001cooooo00?o0000ooooooooool0
=oooool2o`0000_ooooo0_l00005ooooo`;o00001_ooool4o`0001;ooooo0_l0000Aooooo`;o0000
1?ooool2o`0000oooooo0_l0000>ooooo`;o00003?ooool2o`000004ooooool0003o0000o`0000Go
oooo1?l00002ooooo`;o00000_ooool2o`0000Gooooo0ol0000:ooooo`;o00007Oooool3o`000003
ooooool0003o000000[ooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0gooooo`;o0000
1oooool3o`000003ooooool0003o000000;o00000oooool2o`0000;ooooo1_l00004ooooo`Co0000
3oooool2o`0000?ooooo0_l00009ooooo`?o00000oooool2o`0001Kooooo0_l0000Hooooo`;o0000
1_ooool2o`0000_ooooo0ol000000ooooooo0000o`000002o`0000Wooooo0_l0000Mooooo`;o0000
0_ooool4o`0000Sooooo0_l00008ooooo`;o0000=?ooool001cooooo00?o0000ooooooooool0=ooo
ool2o`0000Kooooo1?l000000ooooooo0000o`000003o`0000;ooooo0_l00002ooooo`Co00001Ooo
ool5o`0000Gooooo1?l00006ooooo`;o00000oooool2o`0000[ooooo0_l0000>ooooo`;o00002_oo
ool3o`0001Sooooo0_l00002ooooo`Oo00001oooool2o`000004ooooool0003o0000o`0000?ooooo
0_l00009ooooo`;o00002oooool5o`0001?ooooo0_l00004ooooo`?o00002oooool2o`0000;ooooo
0_l0000`ooooo`007?ooool00ol0003oooooooooo`0fooooo`?o000000?oooooo`000?l000000ooo
ool2o`0000;ooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00001_ooool2o`0000;ooooo
2Ol00002ooooo`Co00002oooool2o`0000Kooooo0_l000000ooooooo0000o`00000?ooooo`Co0000
1?ooool2o`0000;ooooo0_l0000Iooooo`go00001Oooool2o`0000;ooooo1?l00004ooooo`Co0000
2Oooool2o`0000Kooooo1Ol0000Iooooo`?o00001Oooool2o`0000Oooooo0ol0000`ooooo`007?oo
ool00ol0003oooooooooo`0fooooo`;o00000_ooool2o`0000Oooooo0_l00005ooooo`;o00001ooo
ool2o`000005ooooool0003o0000o`000?ooool01_l00007ooooo`;o00004?ooool2o`000003oooo
ool0003o000000;o00001Oooool2o`0000Kooooo2_l00002ooooo`;o00006oooool2o`0000Kooooo
0ol000000ooooooo0000o`000007ooooo`Co00000oooool6o`000003ooooool0003o000000Cooooo
0ol000000ooooooo0000o`000005ooooo`;o00001?ooool2o`0001Gooooo1?l00002ooooo`;o0000
1oooool2o`00037ooooo000Looooo`03o`000?oooooooooo04[ooooo0_l0000:ooooo`;o00001_oo
ool2o`000003ooooool0003o000000Cooooo0_l0000Eooooo`;o00001Oooool2o`0000Cooooo1?l0
00000ooooooo0000o`000005o`0000;ooooo0_l00004ooooo`;o00002?ooool2o`0000?ooooo1?l0
000<ooooo`;o00000_ooool2o`0000Wooooo0_l00007ooooo`;o000000?oooooo`000?l000001Ooo
ool2o`000003ooooool0003o000000Gooooo0_l00004ooooo`;o00005Oooool4o`0003kooooo000L
ooooo`;o0000A?ooool2o`0000Cooooo0_l0000:ooooo`;o00001oooool2o`000003ooooool0003o
000000Oooooo0_l0000Oooooo`;o00002?ooool2o`0000Sooooo0_l00008ooooo`;o00000oooool9
o`0000Wooooo0_l00003ooooo`;o00007?ooool2o`00017ooooo0ol00007ooooo`;o00001Oooool2
o`00043ooooo000Looooo`03o`000?oooooooooo03Wooooo0_l00008ooooo`;o00000oooool3o`00
00[ooooo0_l00007ooooo`;o00000_ooool2o`0000;ooooo0_l00002ooooo`;o00005_ooool2o`00
00Oooooo0_l0000<ooooo`;o00004_ooool:o`0000Oooooo1Ol00002ooooo`Co00001Oooool3o`00
00Oooooo0_l00009ooooo`Co00003_ooool4o`0000Oooooo0_l00005ooooo`;o00001_ooool2o`00
03Sooooo000Looooo`03o`000?oooooooooo03Gooooo0_l00002ooooo`;o00003Oooool3o`0001Oo
oooo0_l00002ooooo`;o00005?ooool2o`0000Cooooo0_l00007ooooo`;o00003?ooool4o`0000co
oooo0_l00002ooooo`;o00000_ooool5o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l0
00001?ooool2o`000003ooooool0003o000000;ooooo0ol00007ooooo`;o00002oooool4o`0000co
oooo0_l00005ooooo`;o00001oooool2o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l0
0000=Oooool001cooooo00?o0000ooooooooool0=Oooool2o`0000;ooooo0_l0000;ooooo`;o0000
;_ooool2o`0000Cooooo0_l00005ooooo`;o00000_ooool2o`0000cooooo0_l00004ooooo`;o0000
1_ooool2o`0000Cooooo1?l00004ooooo`Go00000oooool2o`0000Kooooo0_l000000ooooooo0000
o`000004ooooo`;o00000_ooool2o`00017ooooo0_l00002ooooo`Go00003Oooool2o`0000?ooooo
0_l00007ooooo`Ko00001oooool2o`0003Gooooo000Looooo`03o`000?oooooooooo03;ooooo0_l0
0005ooooo`;o00000_ooool2o`000003ooooool0003o000000Cooooo0_l0000Booooo`;o00001ooo
ool4o`0000oooooo0_l00002ooooo`Co00001Oooool2o`0000;ooooo1Ol00009ooooo`;o00002ooo
ool3o`0000Kooooo0_l000001?oooooo0000o`000?ooool5o`0000?ooooo0_l00009ooooo`;o0000
2?ooool4o`0000Gooooo0_l00008ooooo`;o00001Oooool4o`0000_ooooo0_l00006ooooo`;o0000
1_ooool2o`0000?ooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0booooo`;o00002Ooo
ool5o`00017ooooo0_l00005ooooo`;o000000?oooooo`000?l000001?ooool8o`0000Gooooo0_l0
0003ooooo`;o00000oooool3o`0000_ooooo1?l0000Fooooo`;o000000?oooooo`000?l000001ooo
ool2o`000003ooooool0003o000001gooooo1?l00003ooooo`;o000000?oooooo`000?l000003_oo
ool2o`0000Oooooo0_l00007ooooo`Go00002oooool2o`0003_ooooo000Looooo`03o`000?oooooo
oooo03[ooooo0_l00003ooooo`;o00001Oooool2o`0000Sooooo0_l000001?oooooo0000o`000?oo
ool3o`0000Cooooo0_l000000ooooooo0000o`000009o`0000Gooooo0_l00003ooooo`;o00000_oo
ool6o`0001Wooooo0_l00009ooooo`Co00000_ooool2o`0002Oooooo0_l00006ooooo`;o00001?oo
ool3o`0000Oooooo0_l00007ooooo`;o00001oooool4o`0004Wooooo000Looooo`03o`000?oooooo
oooo03[ooooo1?l00008ooooo`;o00001?ooool2o`0000;ooooo0ol00003ooooo`?o00000_ooool4
o`000003ooooool0003o000000_o00002?ooool3o`000003ooooool0003o000000Co00000_ooool2
o`0000Gooooo0_l0000>ooooo`;o00001oooool4o`0000;ooooo1_l00005ooooo`;o00002?ooool2
o`0000oooooo0_l000000ooooooo0000o`000002o`0000cooooo0ol00009ooooo`?o00000oooool2
o`0000Wooooo1?l000000ooooooo0000o`000002o`0000[ooooo0_l0000gooooo`007?ooool00ol0
003oooooooooo`0iooooo`;o000000?oooooo`000?l000002?ooool2o`0000Cooooo0_l00002oooo
o`?o00000_ooool2o`0000Cooooo1?l000000ooooooo0000o`000005o`000003ooooool0003o0000
00?o00002?ooool3o`0000Wooooo0_l00005ooooo`;o00001?ooool2o`0000Cooooo1ol00006oooo
o`;o00001?ooool2o`0000;ooooo0ol00004ooooo`;o00002?ooool2o`0000oooooo0_l000000ooo
oooo0000o`000004o`0000[ooooo0_l00006ooooo`;o00000_ooool3o`0000?ooooo0_l00009oooo
o`Wo00002_ooool2o`0003Oooooo000Looooo`03o`000?oooooooooo03;ooooo0_l00005ooooo`;o
000000?oooooo`000?l000002?ooool2o`0000Cooooo0_l00007ooooo`;o00001OoooolAo`0000?o
oooo0_l000000ooooooo0000o`000002ooooo`;o00005Oooool2o`0000Cooooo1ol0000>ooooo`Go
00008oooool5o`0000Kooooo0_l0000:ooooo`;o00001_ooool2o`0000Cooooo0_l00006ooooo`;o
000000?oooooo`000?l000003?ooool2o`0003Sooooo000Looooo`03o`000?oooooooooo03;ooooo
0_l00005ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000008ooooo`;o
000000?oooooo`000?l000000_l00008oooooa?o00000_ooool2o`000003ooooool0003o000000;o
oooo0_l00004ooooo`?o00001Oooool5o`0001gooooo1Ol0000>ooooo`;o00006?ooool2o`0000Ko
oooo0_l0000Booooo`;o00001?ooool2o`0000Sooooo0_l000001?oooooo0000o`000?ooool2o`00
00Oooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0aooooo`;o000000?oooooo`000?l0
00001Oooool6o`000003ooooool0003o000000Cooooo0_l00005ooooo`Co00000_oooolKo`0000Ko
oooo1?l00003ooooo`Co00001?ooool5o`0000oooooo0_l0000<ooooo`;o00000oooool3o`000003
ooooool0003o000000?ooooo0_l00003ooooo`;o00003?ooool2o`0002Kooooo1?l0000<ooooo`;o
000000Coooooo`000?l0003ooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o
000000?oooooo`000?l000000_l000000ooooooo0000o`000005ooooo`Co00000_ooool3o`0000Co
oooo0_l00006ooooo`;o00000ooooolKo`0000Kooooo1?l00005ooooo`;o000000?oooooo`000?l0
00001Oooool2o`000003ooooool0003o000000;o00002Oooool2o`0000cooooo0_l00003ooooo`Ko
00000oooool2o`0000?ooooo0_l00006ooooo`;o00001?ooool2o`0000oooooo0_l000000ooooooo
0000o`00000Booooo`Co00002_ooool:o`00047ooooo000Looooo`03o`000?oooooooooo02cooooo
0_l000000ooooooo0000o`00000=ooooo`;o000000Coooooo`000?l0003o00003?ooool2o`0000?o
oooo0_l00002oooooaKo00004_ooool3o`0000;ooooo1Ol000000ooooooo0000o`000002o`0001Co
oooo0_l00009ooooo`;o00002Oooool3o`0000;ooooo1Ol00009ooooo`;o00000oooool2o`0000Co
oooo0ol000000ooooooo0000o`000002ooooo`;o00001oooool2o`0001?ooooo2?l00013ooooo`00
7?ooool00ol0003oooooooooo`0nooooo`;o00002_ooool2o`0000Wooooo0_l00002oooooaSo0000
1oooool2o`0000Oooooo0ol00002ooooo`Co00005_ooool2o`0000;ooooo1?l0000Cooooo`;o0000
0_ooool4o`000004ooooool0003o0000ooooo`;o000000Coooooo`000?l0003ooooo0ol00002oooo
o`;o00001?ooool2o`0000?ooooo0_l000000ooooooo0000o`000007ooooo`;o000000?oooooo`00
0?l000000oooool2o`0000?ooooo0_l00002ooooo`;o00003oooool2o`0000Oooooo0_l0000coooo
o`007?ooool00ol0003oooooooooo`14ooooo`;o000000Coooooo`000?l0003ooooo0_l00004oooo
o`;o00001_oooolIo`0000Oooooo0_l00006ooooo`Co00000oooool3o`0001Gooooo0ol00004oooo
o`;o00000_ooool2o`0000Kooooo0_l0000@ooooo`;o000000Coooooo`000?l0003ooooo0_l00002
ooooo`;o000000Coooooo`000?l0003o00001oooool6o`0000_ooooo0_l00003ooooo`;o00000ooo
ool2o`0000;ooooo0_l0000?ooooo`;o00001oooool2o`0003?ooooo000Looooo`;o0000AOooool5
o`0000Oooooo0_l00003ooooo`;o000000?oooooo`000?l000005ol0000?ooooo`;o00005?ooool2
o`0000Oooooo0_l00009ooooo`;o00001?ooool4o`0000;ooooo0_l0000Fooooo`;o000000Cooooo
o`000?l0003o00001oooool2o`0000;ooooo0ol0000;ooooo`;o00003_ooool2o`0000Gooooo0_l0
0013ooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00002Oooool2o`0000Wooooo0_l0000=
ooooo`;o000000?oooooo`000?l000005ol000000ooooooo0000o`000004ooooo`;o00007?ooool2
o`0000Oooooo0_l0000?ooooo`;o00001?ooool3o`0000Gooooo0_l0000>ooooo`;o00000oooool2
o`0000;ooooo0_l00005ooooo`Ko00002Oooool3o`000003ooooool0003o000000Oooooo1Ol00005
ooooo`Co0000@Oooool001cooooo00?o0000ooooooooool07?ooool2o`0001;ooooo0_l00008oooo
o`?o00001Oooool2o`000003ooooool0003o000000;o00004?oooolKo`0000Cooooo0_l000000ooo
oooo0000o`000009ooooo`co000000?oooooo`000?l000000_l0000@ooooo`;o00001?ooool2o`00
00Kooooo1_l00003ooooo`;o00002oooool4o`0000Cooooo1_l000001?oooooo0000o`000?ooool3
o`000004ooooool0003o0000o`0000[ooooo0_l000000ooooooo0000o`000005ooooo`Go00002Ooo
ool4o`0003oooooo000Looooo`03o`000?oooooooooo017ooooo0_l00009ooooo`;o00007?ooool2
o`0000Kooooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l0000;oooooaWo00002?ooool2
o`0000;ooooo0_l00005ooooo`co000000?oooooo`000?l000000_l00003ooooo`;o00002oooool2
o`0000Cooooo0_l00006ooooo`;o000000Coooooo`000?l0003o00004?ooool4o`0000;ooooo2ol0
00001Ooooooo0000o`000?l0003ooooo00Co00000oooool4o`0000Gooooo1?l00003ooooo`;o0000
3Oooool3o`0003oooooo000Looooo`03o`000?oooooooooo017ooooo0_l0000Kooooo`;o00005?oo
ool4o`000003ooooool0003o000000;ooooo0_l0000:ooooo`[o000000?oooooo`000?l000001ol0
00000ooooooo0000o`000005o`0000Sooooo1?l00004ooooo`;o00000_ooool4o`0000?ooooo0_l0
0008ooooo`;o00005Oooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o00001_oo
ool2o`0000Sooooo0_l000000ooooooo0000o`000008o`000003ooooool0003o000000;o00000ooo
ool2o`0000?ooooo1?l00004ooooo`Go00003oooool2o`000003ooooool0003o0000043ooooo000L
ooooo`03o`000?oooooooooo02kooooo0_l00005ooooo`;o00003Oooool2o`0000?ooooo0_l00003
ooooo`;o00002Oooool;o`000003ooooool0003o000000_o000000?oooooo`000?l000000_ooool2
o`0000Cooooo0ol00005ooooo`;o00000_ooool4o`0000;ooooo0_l00009ooooo`;o00002oooool3
o`0000Oooooo0_l000000ooooooo0000o`000004ooooo`Co00001_ooool2o`0000Oooooo1ol00000
0ooooooo0000o`000002o`0000;ooooo1_l00002ooooo`;o00002oooool3o`000004ooooool0003o
0000ooooo`;o00002oooool2o`0004?ooooo000Looooo`03o`000?oooooooooo03Gooooo0_l0000A
ooooo`;o00001?ooool2o`0000_ooooo5?l00002ooooo`Co00000_ooool2o`0000Gooooo0_l00005
ooooo`;o00001?ooool2o`0000;ooooo1?l0000Dooooo`?o00004?ooool2o`0000Cooooo0_l0000:
oooooaGo00000oooool2o`0000kooooo0_l000000ooooooo0000o`00000Iooooo`;o0000=Oooool0
01cooooo00?o0000ooooooooool0@_ooool3o`0000?ooooo0_l00004ooooo`;o00001?ooool2o`00
00Gooooo5?l00002ooooo`Co00003Oooool2o`0000;ooooo1?l00007ooooo`;o00005oooool4o`00
00Sooooo0_l00008ooooo`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`Oo000000?ooooo
o`000?l000003_l000000ooooooo0000o`000009ooooo`;o00001?ooool2o`0001_ooooo0_l0000;
ooooo`;o0000:?ooool001cooooo00?o0000ooooooooool0@_ooool3o`0000;ooooo0_l00002oooo
o`?o000000?oooooo`000?l000000oooool3o`000004ooooool0003o0000ooooo`Go000000?ooooo
o`000?l000003_l000000ooooooo0000o`000002ooooo`;o00002?ooool5o`000003ooooool0003o
000000;o00006?ooool4o`0000Cooooo1Ol00007ooooo`;o00001_ooool2o`0000?ooooo0_l00000
0ooooooo0000o`000002o`000003ooooool0003o000001Ko00003?ooool4o`0000;ooooo0_l0000X
ooooo`;o0000:?ooool001cooooo00?o0000ooooooooool0<_ooool2o`0001;ooooo0ol00002oooo
o`?o000000?oooooo`000?l000001?ooool2o`000004ooooool0003o0000o`0000;ooooo0_l00000
0ooooooo0000o`00000?o`000003ooooool0003o000000;ooooo1?l00006ooooo`Go00000_ooool2
o`0000Kooooo0_l00002ooooo`;o00001Oooool2o`0000Kooooo1?l00005ooooo`Co00002?ooool2
o`0000Gooooo0_l000000ooooooo0000o`000004o`000003ooooool0003o000001co00001?ooool2
o`0000Gooooo0_l00002ooooo`;o00007?ooool2o`0003Cooooo000Looooo`03o`000?oooooooooo
02Wooooo0_l000000ooooooo0000o`000004ooooo`;o00003oooool2o`000005ooooool0003o0000
o`000?ooool01?l00006ooooo`;o00000oooool2o`0000Gooooo0ol000001Ooooooo0000o`000?l0
003ooooo00;o00001oooool2o`000003ooooool0003o000000;ooooo0_l00005ooooo`;o00001_oo
ool2o`0000Kooooo0_l000000ooooooo0000o`000002o`0000;ooooo1?l00008ooooo`;o00004Ooo
ool2o`0000Sooooo0_l00002ooooo`?o000000?oooooo`000?l000000ol000000ooooooo0000o`00
000Eo`0000Cooooo1?l0000Cooooo`Co00002_ooool2o`0000;ooooo0_l0000dooooo`007?ooool0
0ol0003oooooooooo`0Yooooo`;o000000?oooooo`000?l000003Oooool2o`0000Gooooo0ol00002
ooooo`;o000000?oooooo`000?l000000ol00005ooooo`;o00001Oooool2o`0000Cooooo0_l00000
0ooooooo0000o`000002o`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l000001?ooool2
o`0000;ooooo0ol0000<ooooo`;o00000oooool4o`0000;ooooo0_l0000:ooooo`?o00002_ooool2
o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o00001?ooool4o`000003ooooool0003o
000000Ko000000?oooooo`000?l000004ol00005ooooo`Co00004Oooool4o`0000[ooooo0ol0000g
ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00002_ooool2o`0000Gooooo0_l00003oooo
o`;o00000oooool3o`0000Oooooo0_l00003ooooo`;o00002Oooool2o`0000Cooooo0ol00002oooo
o`;o00001oooool6o`0000cooooo1?l00009ooooo`;o00002Oooool3o`000003ooooool0003o0000
00Oooooo0_l000000ooooooo0000o`000002ooooo`Co000000Coooooo`000?l0003o00001?ooool>
o`000003ooooool0003o000001;o00000oooool3o`000003ooooool0003o0000017ooooo0_l0000:
ooooo`;o000000?oooooo`000?l00000=oooool001cooooo00?o0000ooooooooool0;oooool2o`00
01_ooooo0_l00008ooooo`;o000000?oooooo`000?l000001Oooool2o`0000[ooooo0_l00003oooo
o`?o00002?ooool2o`0000gooooo1Ol00003ooooo`Co00000_ooool2o`0000Kooooo0_l00005oooo
o`;o00002Oooool4o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o00000_oooolSo`00
00;ooooo0ol000000ooooooo0000o`00000Mooooo`?o0000>Oooool001cooooo00?o0000oooooooo
ool0FOooool2o`0000Gooooo1Ol00003ooooo`;o00002?ooool2o`000003ooooool0003o000000Oo
oooo0_l0000;ooooo`;o00000oooool2o`000003ooooool0003o000000;o00002_ooool2o`0000co
oooo2?l0000:ooooo`;o000000?oooooo`000?l000008ol0000Uooooo`;o0000>Oooool001cooooo
00?o0000ooooooooool0A?ooool3o`0001[ooooo1?l00003ooooo`;o000000Coooooo`000?l0003o
oooo1_l000000ooooooo0000o`000005ooooo`Co00003Oooool2o`000003ooooool0003o000000;o
oooo0_l0000<ooooo`;o00002oooool4o`0000Oooooo0_l00004ooooo`?o000000?oooooo`000?l0
00001?l000000ooooooo0000o`000007o`0000;ooooo3ol00002ooooo`;o00008_ooool2o`0003co
oooo000Looooo`;o0000>oooool2o`0000Sooooo0ol0000Gooooo`;o00002?ooool2o`000003oooo
ool0003o000000Oo00002?ooool2o`0000oooooo0ol00007ooooo`;o00001Oooool2o`0000;ooooo
0_l00006ooooo`;o00002_ooool2o`0000;ooooo0_l00004ooooo`?o000000?oooooo`000?l00000
8?l0000Qooooo`?o000000?oooooo`000?l00000??ooool001cooooo00?o0000ooooooooool0=Ooo
ool2o`0000?ooooo0_l00005ooooo`;o00004Oooool2o`0000;ooooo0_l00004ooooo`;o00001_oo
ool4o`0000;ooooo0_l00004ooooo`;o00002?ooool2o`00013ooooo0_l00007ooooo`;o00000_oo
ool5o`0000Wooooo0ol0000:ooooo`;o00002Oooool2o`000003ooooool0003o0000023o00000ooo
ool2o`0000Wooooo0_l00009ooooo`;o000000?oooooo`000?l000000oooool3o`0003oooooo000L
ooooo`03o`000?oooooooooo03Gooooo0_l0000:ooooo`Ko00003Oooool2o`0000;ooooo0_l00004
ooooo`;o00001_ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000002ooo
ool2o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`;o00003oooool4o`0000Cooooo0_l0
0003ooooo`Co000000?oooooo`000?l000004?ooool2o`000004ooooool0003o0000oooooa_o0000
0_ooool2o`0000Kooooo0_l00006ooooo`;o000000?oooooo`000?l000002Oooool2o`000003oooo
ool0003o000000Kooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0Fooooo`;o0000:_oo
ool5o`0000?ooooo0_l00006ooooo`;o00001_ooool2o`0000;ooooo0_l00009ooooo`Go000000?o
ooooo`000?l000001?ooool2o`0000Cooooo0ol00003ooooo`Go00000_ooool3o`0000cooooo0_l0
00000ooooooo0000o`000005ooooo`Co00000_ooool2o`000003ooooool0003o000000Co00001_oo
ool2o`0000Kooooo0ol00002oooooaco00000_ooool3o`000003ooooool0003o000000[ooooo0_l0
0007ooooo`;o000000?oooooo`000?l000002oooool2o`0003gooooo000Looooo`03o`000?oooooo
oooo01Kooooo0_l0000/ooooo`;o00000oooool3o`0000Kooooo0_l00006ooooo`Ko00002oooool2
o`0000;ooooo0ol00003ooooo`?o00000oooool3o`0000?ooooo1?l00003ooooo`;o00003Oooool4
o`000004ooooool0003o0000o`0000;ooooo1Ol00004ooooo`;o00000_ooool2o`0000Kooooo0ol0
0006ooooo`;o00000_ooool>o`000003ooooool0003o000000_o00000oooool2o`000003ooooool0
003o000000?ooooo1_l0000:ooooo`;o000000Coooooo`000?l0003ooooo0_l00008ooooo`;o0000
?Oooool001cooooo00?o0000ooooooooool0A?ooool4o`000003ooooool0003o000000Gooooo0_l0
0004ooooo`;o00001?ooool5o`0000_ooooo0_l000001?oooooo0000o`000?l00004ooooo`Co0000
4?ooool2o`0000Oooooo0_l000000ooooooo0000o`000007o`0000;ooooo1Ol000000ooooooo0000
o`000008ooooo`;o00001?ooool2o`0000[ooooo7ol000001Ooooooo0000o`000?l0003ooooo00;o
000000?oooooo`000?l000001ol0000=ooooo`;o00001Oooool3o`0003oooooo000Looooo`03o`00
0?oooooooooo047ooooo0_l00003ooooo`;o00002?ooool2o`0000?ooooo1Ol00002ooooo`;o0000
00?oooooo`000?l000002oooool2o`0000Kooooo0_l00002ooooo`;o00001_ooool2o`0000Sooooo
0_l00007ooooo`Ko00000_ooool8o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l0
00000_l00002ooooo`?o000000?oooooo`000?l000003Oooool2o`0000;ooooo7ol000000ooooooo
0000o`000006ooooo`Co00004?ooool2o`0000;ooooo0ol0000oooooo`007?ooool00ol0003ooooo
ooooo`11ooooo`Co00004?ooool5o`0000;ooooo0_l00003ooooo`;o00002?ooool2o`0000Oooooo
0_l0000:ooooo`;o00001?ooool2o`0000Oooooo1?l00002ooooo`Co00000oooool8o`0000Cooooo
1_l00002ooooo`;o00000_ooool2o`0000_ooooo1Ol000000ooooooo0000o`00000Ko`0001oooooo
0_l000000ooooooo0000o`000002o`000004ooooool0003o0000ooooo`;o0000>Oooool001cooooo
00?o0000ooooooooool0<_ooool2o`0000gooooo1?l0000;ooooo`?o00000oooool3o`0000?ooooo
0_l00003ooooo`;o00002?ooool4o`0000?ooooo1Ol00004ooooo`;o00002Oooool2o`0000Oooooo
1?l00004ooooo`;o00000_ooool3o`000003ooooool0003o000000?o00000_ooool6o`0000Oooooo
1Ol00009ooooo`Go000000?oooooo`000?l000006Ol0000:ooooo`;o00003?ooool2o`000003oooo
ool0003o000000?ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l000000ooooooo0000
o`000002o`0003Oooooo000Looooo`03o`000?oooooooooo03;ooooo0_l00008ooooo`;o00000ooo
ool2o`000003ooooool0003o000000Kooooo0_l00002ooooo`?o00004_ooool2o`0000Gooooo0ol0
0003ooooo`;o000000?oooooo`000?l000001?ooool2o`000004ooooool0003o0000o`0000Oooooo
0_l00006ooooo`Go00001Oooool4o`000004ooooool0003o0000o`0000Cooooo1_l00002ooooo`[o
000000?oooooo`000?l000001Oooool2o`000003ooooool0003o000000;ooooo6ol0000:ooooo`;o
00000_ooool2o`0000Sooooo0_l000001?oooooo0000o`000?ooool4o`000004ooooool0003o0000
o`0000Sooooo0_l0000gooooo`007?ooool00ol0003oooooooooo`0eooooo`;o00001Oooool2o`00
00?ooooo1Ol00006ooooo`;o00005oooool2o`0000Oooooo0_l0000=ooooo`Co00001oooool2o`00
00;ooooo0_l00002ooooo`;o000000Goooooo`000?l0003o0000ooooo`07o`000003ooooool0003o
000000;o00000oooool3o`0000Cooooo2?l00004ooooo`;o00001?ooool5o`0000Cooooo5Ol00000
0ooooooo0000o`000002o`0000;ooooo0_l0000:ooooo`;o000000?oooooo`000?l000002oooool2
o`0000Cooooo0_l00006ooooo`;o0000>Oooool001cooooo00?o0000ooooooooool0=Oooool2o`00
00cooooo0_l0000>ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Cooooo0_l0000:oooo
o`;o00003Oooool2o`0000gooooo0_l000000ooooooo0000o`000003oooooa3o00000_ooool4o`00
00?ooooo0_l00008ooooo`;o00000oooool5o`000005ooooool0003o0000o`000?ooool05_l00008
ooooo`?o00003?ooool2o`0000Gooooo0_l0000Booooo`;o0000>Oooool001cooooo00?o0000oooo
ooooool0Doooool5o`000003ooooool0003o000000?o00001?ooool2o`0000;ooooo0_l0000Doooo
o`;o00002Oooool2o`0000Gooooo0ol00004oooooaKo00000_ooool3o`0000Oooooo0_l00003oooo
o`Wo000000?oooooo`000?l000004_l00006ooooo`;o00000oooool2o`0001?ooooo1?l00002oooo
o`;o0000Aoooool001cooooo00?o0000ooooooooool0;?ooool2o`0000Sooooo0_l0000Aooooo`;o
00002_ooool8o`0000?ooooo0_l00004ooooo`;o00002Oooool2o`0000Wooooo0_l00009ooooo`;o
00001Oooool>o`000003ooooool0003o000000Wo000000?oooooo`000?l000000_ooool3o`000003
ooooool0003o000000gooooo0ol00002ooooo`Co00000oooool8o`000003ooooool0003o000000?o
00001_ooool2o`0001Wooooo0ol00002ooooo`;o00000_ooool2o`0004?ooooo00001_ooooook^k^
oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool0
0ol0003oooooooooo`0/ooooo`;o00002?ooool2o`00017ooooo0_l0000;ooooo`Co00001_ooool2
o`0000Gooooo0_l00008ooooo`;o00000oooool2o`0000Kooooo0_l00002ooooo`;o00002ooooolL
o`0000;ooooo1_l000000ooooooo0000o`000009ooooo`;o000000Coooooo`000?l0003ooooo1?l0
00000ooooooo0000o`000002o`0000;ooooo1?l00002ooooo`;o00003oooool2o`0001;ooooo0_l0
0007ooooo`;o0000@oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo
00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo04Sooooo0_l0000<ooooo`;o
00002Oooool4o`0000;ooooo0_l0000=ooooo`;o00001_ooool2o`0000;ooooo0_l000000ooooooo
0000o`000004ooooo`;o00000_oooolLo`0000Cooooo1ol00009ooooo`;o000000Coooooo`000?l0
003o00000_ooool2o`000003ooooool0003o000000;o00001?ooool4o`0000?ooooo0_l0000<oooo
o`;o00005?ooool3o`000003ooooool0003o000004Kooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
047ooooo0_l00005ooooo`;o00001oooool2o`0000Oooooo0_l00005ooooo`Co00002_ooool2o`00
01Cooooo0_l000001?oooooo0000o`000?oooolDo`000003ooooool0003o000000[o00001_ooool2
o`0000kooooo0ol00002ooooo`;o00000oooool2o`0000Kooooo0_l00003ooooo`;o00002Oooool2
o`00013ooooo0_l00003ooooo`Go000000?oooooo`000?l000001Oooool2o`0003oooooo00000ooo
oooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@06
ooooo`?o0000@Oooool8o`000003ooooool0003o000000Gooooo1?l00005ooooo`;o00001oooool2
o`0000[ooooo0_l0000Booooo`;o00000oooool]o`000003ooooool0003o000000Gooooo0_l00008
ooooo`Go00000oooool4o`0000;ooooo0_l00002ooooo`;o00002?ooool4o`0000oooooo0_l00003
ooooo`;o00001oooool3o`000003ooooool0003o000003oooooo00000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooo
oooo047ooooo2?l000001?oooooo0000o`000?l00003ooooo`;o000000Coooooo`000?l0003ooooo
0ol00007ooooo`;o000000?oooooo`000?l000002?ooool2o`0001Cooooo0_l00004oooooako0000
0_ooool<o`000003ooooool0003o000000Cooooo0ol00009ooooo`Co00000oooool4o`0000;ooooo
0_l0000;ooooo`Ko00007?ooool3o`0004;ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oo
oooooooo00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`0nooooo`;o000000?o
ooooo`000?l000000oooool2o`0000?ooooo0_l00003ooooo`;o00000oooool4o`0000Oooooo0_l0
000;ooooo`;o00001Oooool2o`0000?ooooo0_l00009ooooo`;o00001Oooool2o`000003ooooool0
003o000002;o000000?oooooo`000?l000001?l00003ooooo`;o00002Oooool4o`0000Wooooo0_l0
0008ooooo`;o00000_ooool2o`000004ooooool0003o0000o`0000[ooooo0_l0000?ooooo`;o0000
A?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03
o`000?oooooooooo03kooooo1Ol0000=ooooo`;o00000oooool2o`0000Gooooo0_l00003ooooo`;o
00000oooool2o`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l000000oooool2o`0000Wo
oooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo3Ol000000ooooooo0000o`00000>o`00
00;ooooo2ol00006ooooo`;o00001_ooool2o`0000_ooooo0_l00008ooooo`;o00004_ooool2o`00
00oooooo0_l00014ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co
0000oa0@40Kooooo00?o0000ooooooooool0@?ooool2o`00013ooooo0_l000000ooooooo0000o`00
0003ooooo`Co00000oooool2o`0000?ooooo0_l00003ooooo`;o00001?ooool2o`00013ooooo1?l0
00000ooooooo0000o`000004o`000003ooooool0003o000002Go00000_ooool2o`0000Gooooo0_l0
0003ooooo`;o00004Oooool2o`0001Cooooo0_l00009ooooo`;o00005?ooool2o`0003Wooooo000L
ooooo`03o`000?oooooooooo043ooooo0_l0000=ooooo`;o000000Coooooo`000?l0003ooooo1?l0
00000ooooooo0000o`000002o`0000[ooooo0_l000000ooooooo0000o`000002o`000003ooooool0
003o000000?o00003_oooolFo`0000;ooooo6ol00002ooooo`;o00001?ooool2o`0000Cooooo0_l0
000Aooooo`;o00005?ooool4o`0000Oooooo0_l00004ooooo`;o00003_ooool2o`0003Wooooo000L
ooooo`03o`000?oooooooooo043ooooo0_l0000=ooooo`;o000000?oooooo`000?l000000oooool2
o`0000Cooooo0ol00008ooooo`;o00000oooool2o`000003ooooool0003o000000?o00003_ooool2
o`000005ooooool0003o0000o`000?ooool08_l000000ooooooo0000o`000005o`0000Kooooo0_l0
0002ooooo`;o00001?ooool4o`0002Kooooo0ol00006ooooo`;o00001Oooool2o`0004Wooooo000L
ooooo`03o`000?oooooooooo04Cooooo0_l00003ooooo`;o00004_ooool3o`0000Sooooo0_l00005
ooooo`;o00000_ooool2o`0000kooooo0ol00003ooooo`go00000_oooolKo`0000Oooooo0_l00008
ooooo`Co00002?ooool2o`0000Cooooo0_l0000Fooooo`;o00001Oooool4o`00053ooooo000Loooo
o`03o`000?oooooooooo03Sooooo0_l000000ooooooo0000o`000007ooooo`;o00000oooool2o`00
00Oooooo1?l00006ooooo`;o00000_ooool2o`0000Kooooo0_l00005ooooo`?o00003Oooool2o`00
00?ooooo0_l00003ooooo`;o000000?oooooo`000?l000006Ol000000ooooooo0000o`00000:o`00
00Cooooo0_l0000<ooooo`;o000000?oooooo`000?l000001Oooool4o`0000;ooooo0_l0000Ioooo
o`;o000000Coooooo`000?l0003o00004?ooool2o`00043ooooo000Looooo`03o`000?oooooooooo
03Sooooo0_l000000ooooooo0000o`000007ooooo`;o00003?ooool7o`0000?ooooo0ol000000ooo
oooo0000o`00000>ooooo`;o00000_ooool2o`0000Wooooo0ol000000ooooooo0000o`000002o`00
0003ooooool0003o000001co00000_ooool<o`0000;ooooo1Ol0000>ooooo`Ko000000?oooooo`00
0?l000000_l0000Mooooo`;o000000?oooooo`000?l000004Oooool2o`00043ooooo000Looooo`03
o`000?oooooooooo04Cooooo0_l00003ooooo`;o00000_ooool2o`0000Oooooo0ol000001?oooooo
0000o`000?ooool2o`0001Gooooo0_l0000:ooooo`;o000000?oooooo`000?l000006ol000000ooo
oooo0000o`00000?o`0000Cooooo0_l000001?oooooo0000o`000?l0000?ooooo`Co0000<?ooool3
o`0004Oooooo000Looooo`03o`000?oooooooooo02Cooooo0_l0000Rooooo`?o00000_ooool2o`00
0003ooooool0003o000000Sooooo0_l0000:ooooo`;o00000_ooool2o`000003ooooool0003o0000
01Kooooo;ol00002ooooo`;o00000_ooool2o`0000Cooooo0_l0000Sooooo`;o00006?ooool3o`00
00Cooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0Tooooo`;o00002oooool2o`0000go
oooo0_l00006ooooo`;o00001Oooool3o`0000Wooooo0_l000000ooooooo0000o`000006ooooo`;o
00000_ooool2o`000004ooooool0003o0000o`0000?ooooo0_l0000@ooooobKo000000?oooooo`00
0?l000001_l00003ooooo`;o00001oooool2o`0002?ooooo0_l00004ooooo`Go00001Oooool2o`00
00?ooooo0_l0000:ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0<Oooool3o`0000Wo
oooo0_l000000ooooooo0000o`00000=ooooo`;o00002_ooool2o`000003ooooool0003o000000;o
00003?ooool3o`0000;ooooo0_l0000:ooooo`;o00000oooool5o`0000;ooooo7Ol000001?oooooo
0000o`000?ooool4o`000004ooooool0003o0000o`0000?ooooo0_l00004ooooo`;o00001oooool2
o`0002?ooooo1_l00004ooooo`;o00000oooool2o`0000oooooo0_l0000looooo`007?ooool00ol0
003oooooooooo`0booooo`;o00002Oooool2o`0001Sooooo0_l00004ooooo`Go00000_ooool2o`00
00Wooooo0_l0000>ooooo`;o00000oooool2o`000003ooooool0003o000000?ooooo:?l00002oooo
o`;o000000Coooooo`000?l0003ooooo0ol00002ooooo`;o00000oooool2o`0001Sooooo0_l00003
ooooo`;o00002?ooool2o`0000Cooooo0_l00003ooooo`;o00000oooool2o`0000[ooooo0_l0000l
ooooo`007?ooool00ol0003oooooooooo`1Gooooo`Co00000_ooool5o`000004ooooool0003o0000
o`0000Sooooo0ol0000Jooooob?o000000Coooooo`000?l0003o00000oooool3o`000004ooooool0
003o0000ooooo`;o00000oooool2o`0001gooooo1?l000000ooooooo0000o`000007ooooo`;o0000
1Oooool2o`0000;ooooo0_l00004ooooo`;o0000B?ooool001cooooo0_l0001@ooooo`;o00002?oo
ool2o`0000Gooooo0_l000000ooooooo0000o`000009ooooo`?o00000_ooool2o`0001Cooooo3Ol0
00000ooooooo0000o`00000Do`0000;ooooo2?l0000Yooooo`Co00002_ooool2o`000004ooooool0
003o0000o`0000Gooooo0_l000000ooooooo0000o`00001;ooooo`007?ooool00ol0003ooooooooo
o`0nooooo`;o00003oooool3o`0000?ooooo0_l00004ooooo`;o00000oooool2o`000003ooooool0
003o000000_ooooo0_l000000ooooooo0000o`00000Aoooooa3o000000?oooooo`000?l000007?l0
000:ooooo`;o00007oooool2o`000004ooooool0003o0000o`0000_ooooo0ol00008ooooo`;o0000
Boooool001cooooo00?o0000ooooooooool0?_ooool2o`00013ooooo0_l00003ooooo`;o00001?oo
ool2o`0000_ooooo0_l00002ooooo`;o00000_ooool2o`0001Cooooo:Ol0000@ooooo`;o00008_oo
ool3o`0000?ooooo0_l00006ooooo`?o0000EOooool001cooooo00?o0000ooooooooool0>oooool2
o`0000_ooooo0_l00003ooooo`Go00000oooool2o`0000Cooooo0_l0000;ooooo`;o00000_ooool3
o`0001Oooooo:_l0000`ooooo`;o00001oooool2o`0005kooooo000Looooo`03o`000?oooooooooo
03;ooooo1?l00005ooooo`;o00002oooool4o`000004ooooool0003o0000o`0001gooooo0_l0000:
ooooo`;o00002OoooolFo`000003ooooool0003o000000go00000_ooool6o`00017ooooo0_l0000K
ooooo`;o00006Oooool2o`0004cooooo000Looooo`03o`000?oooooooooo03;ooooo1?l0000Doooo
o`;o00003oooool2o`0000Kooooo0_l000000ooooooo0000o`000007ooooo`;o00002?ooool2o`00
00Gooooo0_l00002oooooaOo000000?oooooo`000?l000002ol000001?oooooo0000o`000?ooool2
o`000003ooooool0003o0000017ooooo0_l0000Yooooo`;o00001_ooool2o`0000?ooooo0_l0001<
ooooo`007?ooool00ol0003oooooooooo`0booooo`;o00007Oooool4o`0000Gooooo0ol00005oooo
o`?o000000?oooooo`000?l000001Oooool4o`0000oooooo0_l00002ooooo`;o000000Goooooo`00
0?l0003o0000ooooo`0Qo`000004ooooool0003o0000ooooo`?o00001?ooool2o`0003Gooooo0_l0
00000ooooooo0000o`000003ooooo`;o00002Oooool2o`0004Kooooo000Looooo`03o`000?oooooo
oooo03;ooooo0_l0000Gooooo`;o00001?ooool4o`0000Gooooo0_l000000ooooooo0000o`000003
ooooo`;o000000?oooooo`000?l000000_l00003ooooo`?o00006?ooool2o`0000;ooooo0_l00000
0ooooooo0000o`00000Jo`0000;ooooo2Ol00002ooooo`?o00000_ooool2o`0000Gooooo0_l0000M
ooooo`;o00001Oooool2o`0000Kooooo0_l0000>ooooo`;o0000A_ooool001cooooo00?o0000oooo
ooooool0;oooool2o`0001[ooooo0_l00004ooooo`;o000000?oooooo`000?l000001oooool2o`00
00?ooooo1ol00003ooooo`Co00003_ooool2o`0000kooooo9?l000000ooooooo0000o`000003oooo
o`Ko00001Oooool2o`0001Cooooo0_l00007ooooo`;o00001Oooool2o`0000Cooooo0_l0001Hoooo
o`007?ooool00ol0003oooooooooo`0_ooooo`;o00008oooool2o`0000Oooooo0_l00004ooooo`;o
00000oooool2o`0000Cooooo0_l0000>ooooo`;o00002oooool2o`000003ooooool0003o000000Go
000000?oooooo`000?l000002ol00003ooooo`?o000000?oooooo`000?l000000ol0000:ooooo`Co
00007?ooool2o`0000Oooooo0_l0000;ooooo`;o0000F?ooool001cooooo00?o0000ooooooooool0
=_ooool2o`0000cooooo1?l000000ooooooo0000o`00000Dooooo`;o00000_ooool2o`0000?ooooo
0_l0000Kooooo`Co000000Coooooo`000?l0003o00000_oooolAo`0000Gooooo1?l000001?oooooo
0000o`000?l0000Dooooo`;o00005oooool3o`0000Gooooo0_l00005ooooo`;o0000G_ooool001co
oooo00?o0000ooooooooool0=_ooool2o`0000cooooo1?l000000ooooooo0000o`000005ooooo`Oo
00002?ooool2o`0002Cooooo1ol00002oooooa7o00001Oooool5o`000004ooooool0003o0000o`00
01Cooooo0_l0000Gooooo`?o00001Oooool4o`0000?ooooo0_l00008ooooo`;o0000E?ooool001co
oooo00?o0000ooooooooool0A_ooool2o`0000Sooooo1ol00005ooooo`?o00009oooool6o`0000;o
oooo4_l00004ooooo`;o000000?oooooo`000?l000001?l0000Gooooo`;o00005?ooool2o`0000So
oooo1?l00003ooooo`;o00001_ooool2o`0005Cooooo000Looooo`03o`000?oooooooooo04Kooooo
0_l00007ooooo`;o00002oooool3o`00017ooooo0_l0000?ooooo`?o00000_ooool2o`0000?ooooo
0_l00003oooooa;o000000?oooooo`000?l000001Ol000001?oooooo0000o`000?l0000Fooooo`;o
00005?ooool2o`0000Sooooo1?l00003ooooo`;o00000_ooool2o`0005Sooooo000Looooo`03o`00
0?oooooooooo04gooooo1?l00004ooooo`?o00006?ooool2o`0000oooooo0ol00005ooooo`Ko0000
0_ooool<o`0000;ooooo0ol000001?oooooo0000o`000?ooool2o`0000Cooooo0_l0000=ooooo`;o
00001?ooool2o`0001gooooo0_l00002ooooo`;o00001Oooool2o`0000;ooooo1?l0001Fooooo`00
7?ooool00ol0003oooooooooo`1=ooooo`Co00001?ooool3o`0001Gooooo0_l00004ooooo`;o0000
5?ooool2o`0000;ooooo0_l000000ooooooo0000o`000005o`000003ooooool0003o000000?o0000
0_ooool2o`0000;ooooo0ol0000Eooooo`;o00001?ooool2o`0001Wooooo0_l00002ooooo`;o0000
3oooool2o`0005Kooooo000Looooo`;o0000FOooool2o`0001?ooooo1Ol000000ooooooo0000o`00
000Iooooo`Go00001Oooool6o`0000Cooooo1?l00002ooooo`;o00001Oooool2o`0001Cooooo0_l0
000=ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000006ooooo`;o0000Hooo
ool001cooooo00?o0000ooooooooool0BOooool4o`0000_ooooo0_l00002ooooo`;o00000oooool2
o`0000?ooooo0_l00005ooooo`Go00005oooool3o`0000;ooooo0_l00008ooooo`Ko000000?ooooo
o`000?l000002Ol00005ooooo`;o00000oooool3o`0000Wooooo1?l000001?oooooo0000o`000?l0
000<ooooo`;o000000?oooooo`000?l000000_l00009ooooo`Co00002?ooool3o`0005Kooooo000L
ooooo`03o`000?oooooooooo04Sooooo1Ol0000<ooooo`;o000000?oooooo`000?l000000oooool2
o`0000?ooooo0_l000001Ooooooo0000o`000?l0003ooooo00Co00005?ooool8o`0000[ooooo1?l0
00000ooooooo0000o`000004o`0000;ooooo1Ol00003ooooo`;o00001_ooool3o`0000Wooooo1?l0
0002ooooo`;o00007_ooool2o`000003ooooool0003o000000Gooooo0ol0001Fooooo`007?ooool0
0ol0003oooooooooo`18ooooo`;o00002Oooool2o`0000Cooooo0_l0000>ooooo`?o00000oooool2
o`0001;ooooo1_l00002ooooo`;o00000oooool2o`0000Gooooo0_l00004ooooo`Go00002_ooool2
o`0001;ooooo0_l00005ooooo`;o00002_ooool2o`0001Cooooo0_l0001Nooooo`007?ooool00ol0
003oooooooooo`0eooooo`;o00007?ooool4o`0000;ooooo0_l0000?ooooo`;o00001_ooool2o`00
00oooooo0_l00004ooooo`Co00000oooool2o`000003ooooool0003o000000?ooooo0_l000000ooo
oooo0000o`00000Dooooo`;o00003Oooool2o`000003ooooool0003o000000Co00002_ooool2o`00
00_ooooo0_l00009ooooo`;o0000G?ooool001cooooo00?o0000ooooooooool0=Oooool2o`000003
ooooool0003o000001_ooooo0_l00003ooooo`;o00005_ooool2o`0000kooooo0_l000000ooooooo
0000o`000004o`0000Oooooo0ol00003ooooo`;o000000?oooooo`000?l000003?ooool2o`0000Ko
oooo0_l0000@ooooo`Co00006Oooool2o`0000Wooooo0_l0001Looooo`007?ooool00ol0003ooooo
ooooo`0hooooo`;o00001Oooool2o`0000oooooo0_l00005ooooo`;o000000?oooooo`000?l00000
2oooool2o`0000Gooooo0_l00002ooooo`;o00003_ooool2o`000003ooooool0003o000000?o0000
2?ooool2o`0001Gooooo0_l00005ooooo`;o00003_ooool2o`0000Kooooo0_l0000Qooooo`;o0000
G?ooool001cooooo00?o0000ooooooooool0?oooool2o`0000oooooo0_l00005ooooo`;o00000_oo
ool2o`0000[ooooo0_l00005ooooo`;o0000@?ooool2o`0000kooooo0_l00006ooooo`;o00008?oo
ool3o`0005cooooo000Looooo`03o`000?oooooooooo05Kooooo1?l000000ooooooo0000o`000006
ooooo`;o000000?oooooo`000?l00000:Oooool2o`0003Wooooo0_l0000:ooooo`Ko00000oooool2
o`0000Oooooo0_l00006ooooo`;o00000_ooool2o`00057ooooo000Looooo`03o`000?oooooooooo
05Kooooo1?l00006ooooo`;o000000Coooooo`000?l0003ooooo0_l0000<ooooo`;o00006_ooool3
o`0000Cooooo0ol0000Aooooo`;o00002?ooool2o`00017ooooo0_l00002ooooo`;o00002_ooool6
o`0000?ooooo0_l00004ooooo`;o00002Oooool2o`0000;ooooo0_l0001Aooooo`007?ooool00ol0
003oooooooooo`1Aooooo`;o00001?ooool4o`0000Gooooo0_l00007ooooo`?o00002?ooool2o`00
013ooooo0ol00005ooooo`Co00000_ooool2o`000003ooooool0003o000000;o00004?ooool4o`00
00Kooooo0_l0000:ooooo`;o00001Oooool3o`0000gooooo0_l00007ooooo`?o000000?oooooo`00
0?l000000_l00008ooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0DOooool2o`0000Co
oooo1?l0000:ooooo`;o00000_ooool3o`0000_ooooo0_l0000=ooooo`Co00001?ooool3o`0000?o
oooo0_l00003ooooo`Go00003Oooool5o`00017ooooo0_l00006ooooo`;o00001oooool2o`0000Co
oooo0_l00007ooooo`?o000000?oooooo`000?l000002_ooool2o`0005Kooooo000Looooo`03o`00
0?oooooooooo05?ooooo0_l0000:ooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`;o0000
0oooool3o`0000oooooo0_l000000ooooooo0000o`00000>ooooo`?o00000_ooool2o`0000Wooooo
0_l000000ooooooo0000o`00000Eooooo`;o00002oooool2o`0000Kooooo0_l00004ooooo`Go0000
I?ooool001cooooo00?o0000ooooooooool0Doooool4o`0000Cooooo0_l00002ooooo`;o00000_oo
ool2o`0000Kooooo1?l00002ooooo`;o00000oooool2o`0000[ooooo0_l00007ooooo`;o00003_oo
ool2o`0000?ooooo0_l0000Dooooo`;o000000?oooooo`000?l000002_ooool3o`0000Cooooo0_l0
00000ooooooo0000o`000009ooooo`;o00001?ooool5o`0006Cooooo000Looooo`03o`000?oooooo
oooo05Gooooo0_l00004ooooo`;o00001_ooool2o`0000Sooooo0_l00004ooooo`;o00003Oooool2
o`0001Gooooo1?l00007ooooo`;o00000oooool6o`0000Oooooo0_l000000ooooooo0000o`00000;
ooooo`;o00001?ooool2o`000003ooooool0003o000000Wooooo0_l00007ooooo`;o000000?ooooo
o`000?l00000HOooool001cooooo00?o0000ooooooooool0G_ooool2o`0000Oooooo0_l000000ooo
oooo0000o`000007ooooo`;o00000oooool2o`0001oooooo1?l00007ooooo`;o00000oooool6o`00
00Oooooo0_l0000Dooooo`;o000000?oooooo`000?l000002Oooool2o`0000[ooooo0_l0001Qoooo
o`007?ooool2o`0005oooooo0_l000000ooooooo0000o`000004ooooo`;o000000Coooooo`000?l0
003ooooo0_l00009ooooo`;o0000<_ooool2o`0000Sooooo0_l0000=ooooo`;o00001Oooool2o`00
0003ooooool0003o0000017ooooo0_l0001Uooooo`007?ooool00ol0003oooooooooo`1Jooooo`;o
00001?ooool4o`0000;ooooo0ol00004ooooo`;o00005_ooool2o`0000Sooooo0_l0000Gooooo`Co
00006Oooool4o`00013ooooo0_l00007ooooo`;o0000IOooool001cooooo00?o0000ooooooooool0
B_ooool2o`0000;ooooo0_l0000:ooooo`;o00001?ooool4o`0000;ooooo0ol00009ooooo`;o0000
0oooool2o`0000cooooo0_l00008ooooo`;o00003?ooool2o`0000Oooooo1_l0000Booooo`;o0000
1oooool2o`0000Oooooo0_l00007ooooo`?o00000_ooool2o`0006Wooooo000Looooo`03o`000?oo
oooooooo04[ooooo0_l00002ooooo`;o00008_ooool2o`0000?ooooo0_l0000:ooooo`;o00002_oo
ool2o`0000cooooo0_l00003ooooo`;o00000_ooool2o`0000oooooo0_l00005ooooo`;o00001Ooo
ool2o`0000Wooooo0_l00007ooooo`?o00000_ooool2o`0006Wooooo000Looooo`03o`000?oooooo
oooo07Kooooo0_l00005ooooo`;o000000Coooooo`000?l0003ooooo0_l00009ooooo`?o000000?o
ooooo`000?l000001?ooool2o`0000Sooooo0_l0000Cooooo`Co00001Oooool2o`0000?ooooo0_l0
0002ooooo`;o00000oooool3o`000003ooooool0003o000000;o0000Loooool001cooooo00?o0000
ooooooooool0I?ooool2o`00013ooooo0_l00005ooooo`Go00002oooool3o`0000;ooooo0_l00000
1?oooooo0000o`000?ooool2o`0001[ooooo0_l00003ooooo`Co00000oooool4o`0000Gooooo0_l0
0003ooooo`?o000000?oooooo`000?l000000_l0001cooooo`007?ooool00ol0003oooooooooo`1<
ooooo`;o00005_ooool2o`0000[ooooo0_l00002ooooo`?o00001_ooool4o`0000[ooooo1?l00006
ooooo`;o00003?ooool3o`0000[ooooo0_l00002ooooo`;o00001Oooool2o`0000?ooooo1?l0000D
ooooo`;o0000Koooool001cooooo00?o0000ooooooooool0C?ooool2o`0002;ooooo0_l00002oooo
o`?o00002?ooool2o`0000Oooooo0_l000000ooooooo0000o`000002o`0000oooooo0_l00002oooo
o`Co00002_ooool2o`0002Kooooo0_l00005ooooo`;o0000J?ooool001cooooo00?o0000oooooooo
ool0Joooool2o`0001_ooooo0_l00003ooooo`;o00003oooool2o`0000;ooooo0_l0000?ooooo`;o
00005oooool5o`0000Kooooo0ol00005ooooo`?o0000Ioooool001cooooo00?o0000ooooooooool0
Joooool3o`0000Cooooo0_l0000Iooooo`;o00002?ooool2o`0001[ooooo0_l00004ooooo`;o0000
3_ooool2o`000003ooooool0003o000000?o00001_ooool2o`0000Cooooo0_l000000ooooooo0000
o`00001Wooooo`007?ooool00ol0003oooooooooo`1/ooooo`;o00000_ooool4o`0000oooooo0_l0
00000ooooooo0000o`000004ooooo`?o00002?ooool4o`000003ooooool0003o000001Wooooo1?l0
000<ooooo`Co00004_ooool2o`0006[ooooo000Looooo`03o`000?oooooooooo05Kooooo0_l00007
ooooo`;o00003oooool2o`00017ooooo0_l000000ooooooo0000o`000004ooooo`;o00001Oooool2
o`0000Cooooo0_l000000ooooooo0000o`00000Iooooo`;o00003_ooool2o`000003ooooool0003o
000007gooooo000Looooo`03o`000?oooooooooo05Kooooo0_l00007ooooo`Co00002oooool2o`00
01cooooo0_l000000ooooooo0000o`000002ooooo`Oo00003?ooool2o`0002;ooooo0_l0001moooo
o`007?ooool00ol0003oooooooooo`1Qooooo`;o00002oooool2o`0001oooooo0_l00003ooooo`Ko
00003?ooool2o`000:7ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44oooo
o`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Qooooo`;o00003Oooool2
o`0000;ooooo0_l0000>ooooo`;o00001oooool2o`0000Sooooo1?l00002ooooo`;o00000_ooool2
o`0000?ooooo0_l0000:ooooo`;o000000?oooooo`000?l000004oooool2o`0007gooooo00001_oo
ooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40
1_ooool00ol0003oooooooooo`1Tooooo`;o00002_ooool2o`0000;ooooo0_l0000>ooooo`;o0000
1oooool6o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o00000_ooool2o`0000oooooo
0_l000000ooooooo0000o`000009ooooo`;o00002?ooool2o`0000Cooooo0_l00005ooooo`;o0000
L?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool0I?ooool2o`0001[ooooo1?l000000ooooooo0000
o`000008ooooo`Co000000Coooooo`000?l0003o0000:Oooool2o`0000kooooo0_l00005ooooo`;o
0000L?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Olb<S;oV9RH
oooooonHV9So<S8b00Kooooo0ol0001looooo`;o00000_ooool4o`000003ooooool0003o000000[o
oooo0_l00002ooooo`;o00000oooool2o`0000Gooooo1?l00005ooooo`;o00000_ooool2o`0000;o
oooo0ol0000Sooooo`;o0000Koooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
2Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0I_ooool2o`0000Ko
oooo0_l00007ooooo`;o00000oooool2o`0000_ooooo0_l00006ooooo`;o000000?oooooo`000?l0
00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000Gooooo0_l00002ooooo`;o
00000_ooool3o`0000Sooooo0_l0000=ooooo`;o00002Oooool3o`0006oooooo00000ooooooo410@
ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03
o`000?oooooooooo05oooooo0_l00005ooooo`;o00001_ooool2o`000003ooooool0003o000000Co
oooo0_l0000:ooooo`;o00000_ooool5o`0000Sooooo0_l00003ooooo`;o00000oooool2o`0000ko
oooo0_l0000=ooooo`;o00003Oooool2o`0000Gooooo0_l00002ooooo`;o00003?ooool2o`0006;o
oooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zjo`000006
ooooo`03o`000?oooooooooo05oooooo0_l00007ooooo`;o00001oooool2o`0000Gooooo0_l00008
ooooo`?o00000_ooool2o`000003ooooool0003o000000cooooo0ol00005ooooo`;o00000oooool2
o`0000Oooooo0_l00009ooooo`;o00006?ooool2o`0000Cooooo0_l0000:ooooo`;o0000H_ooool0
0006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo
00?o0000ooooooooool0J?ooool2o`0000kooooo0_l00008ooooo`;o00001?ooool5o`0000_ooooo
0_l00006ooooo`;o00000oooool2o`0000cooooo0_l00004ooooo`;o00000_ooool4o`0001Sooooo
0_l0001^ooooo`007?ooool00ol0003oooooooooo`1kooooo`;o00002?ooool2o`000003ooooool0
003o000000Ko00008oooool2o`0000Sooooo1?l00028ooooo`007?ooool00ol0003oooooooooo`1k
ooooo`;o00000oooool2o`000003ooooool0003o000000;o00001Oooool4o`000003ooooool0003o
000001;ooooo0_l00008ooooo`;o00002Oooool2o`0008gooooo000Looooo`03o`000?oooooooooo
07cooooo0_l00002ooooo`;o000000?oooooo`000?l000001Oooool2o`0000;ooooo0_l000000ooo
oooo0000o`000005ooooo`;o00002oooool2o`000003ooooool0003o000000Gooooo0_l00009oooo
o`;o0000SOooool001cooooo00?o0000ooooooooool0O?ooool2o`0000Cooooo0_l00006ooooo`;o
00003?ooool2o`000003ooooool0003o000000?ooooo0_l00006ooooo`;o00007oooool2o`0007ko
oooo000Looooo`03o`000?oooooooooo08;ooooo0_l000000ooooooo0000o`00000Dooooo`;o0000
0oooool2o`0002Oooooo0_l0001nooooo`007?ooool00ol0003oooooooooo`1eooooo`;o00003_oo
ool2o`00027ooooo0_l0000Pooooo`;o0000OOooool001cooooo00?o0000ooooooooool0MOooool2
o`0000cooooo0_l00003ooooo`;o00003Oooool2o`0000[ooooo0_l00003ooooo`;o00008?ooool2
o`0007gooooo000Looooo`03o`000?oooooooooo08?ooooo0_l00003ooooo`;o00003Oooool2o`00
00[ooooo0_l0000Xooooo`;o0000N_ooool001cooooo00?o0000ooooooooool0Roooool2o`000003
ooooool0003o000000;ooooo0_l00005ooooo`;o0000<_ooool2o`0007[ooooo000Looooo`03o`00
0?oooooooooo07Gooooo0_l0000Dooooo`;o000000?oooooo`000?l000000_ooool2o`000003oooo
ool0003o000000;ooooo0_l0002^ooooo`007?ooool00ol0003oooooooooo`1eooooo`;o00004Ooo
ool2o`0000_ooooo0_l00002ooooo`;o00009oooool2o`0008Gooooo000Looooo`;o0000ROooool2
o`0001;ooooo0_l0000Tooooo`;o0000QOooool001cooooo00?o0000ooooooooool0W?ooool2o`00
0:_ooooo000Looooo`03o`000?oooooooooo08Gooooo0_l00032ooooo`007?ooool00ol0003ooooo
ooooo`25ooooo`;o0000<?ooool2o`00093ooooo000Looooo`03o`000?oooooooooo0:gooooo0_l0
0008ooooo`;o0000T?ooool001cooooo00?o0000ooooooooool0Qoooool2o`0002Cooooo0_l0000O
ooooo`;o0000NOooool001cooooo00?o0000ooooooooool0Qoooool2o`0004Gooooo0_l0001ioooo
o`007?ooool00ol0003oooooooooo`2Fooooo`;o0000/Oooool001cooooo00?o0000ooooooooool0
S?ooool2o`0000Sooooo0_l0002aooooo`007?ooool00ol0003oooooooooo`2<ooooo`;o00003Ooo
ool2o`000:cooooo000Looooo`03o`000?oooooooooo08gooooo0_l0000<ooooo`;o0000[?ooool0
01cooooo00?o0000ooooooooool0SOooool2o`000;[ooooo000Looooo`03o`000?oooooooooo0:Ko
oooo0_l0002Qooooo`007?ooool00ol0003oooooooooo`2Vooooo`;o0000XOooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`;o0000U_ooool2o`000;;ooooo000Looooo`03o`000?oooooooooo09Gooooo0_l0002booooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001;ooooo1?l000000ol@
413oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo
0ol0003ooooood[ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000
ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03
o`000?oooooooooo0?ooooooD_ooool001;ooooo00?oEEEEofIVI_l00000oooooomDooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00XOooool01?l@413o0000o`000?ooool2o`00
0003oa0@4?oooooooooo01Kooooo1?l000000ol@413oooooooooo`05o`0000Gooooo0_l000001?l@
413oooooooooooooool5o`0008cooooo002Rooooo`05o`000?ooooooooooooooool000002Oooool6
o`0000cooooo00?o0000ooooooooool00_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o
0000ooooooooool00_ooool01OnHV9So8B4Qonk^k_ooooooA4A408cooooo002Rooooo`05o`000?oo
ooooooooooooool000006oooool00ol0003oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00Cooooo
1Ol00004ooooo`03oiRHV?lQ8B7ok^k^08gooooo002Rooooo`05o`000?ooooooooooooooool00000
2Oooool6o`0000cooooo00?o0000ooooooooool01?ooool00onHV9So8B4Qonk^kP03ooooo`04odA4
A?oMgMgoooooo`0000Kooooo00?oV9RHob4Q8Oo^k^h0S?ooool00:;ooooo00Go0000ohN7Qooooooo
ZJVYo`00000Kooooo`03o`000?oooooooooo00Gooooo00?oMgMgofIVI_ooool00_ooool01?oMgMgo
EEEEooooool00007ooooo`03ogMgMomVIVKooooo08_ooooo002Qooooo`03oa0@4?l0003oMgMg00;o
000000?oV9RHooooooooool06Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;o
oooo00?oMgMgolc<c?l000002?ooool00ol0003oooooooooo`2:ooooo`00`_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00oo^k^koA4A4o`000004ooooo`05
o`000?nj^[[ooooooiRHV?l@4100S?ooool00<3ooooo00?oEEEEofIVI_l000001?ooool01OnHV9So
410@o`000?lQ8B7oc<c<00Gooooo00?oMgMgo`000?ooool00oooool01OnHV9So410@o`000?lQ8B7o
c<c<08cooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1248) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.69171 .59072 Mdot
.66598 .56346 Mdot
.4664 .34977 Mdot
.4744 .65622 Mdot
.51747 .19681 Mdot
.4371 .36727 Mdot
.60898 .42326 Mdot
.63525 .36621 Mdot
.46577 .37139 Mdot
.73737 .38695 Mdot
.61009 .39384 Mdot
.52586 .56453 Mdot
.63296 .385 Mdot
.4516 .63834 Mdot
.5084 .13974 Mdot
.41153 .60809 Mdot
.68655 .57395 Mdot
.34234 .44425 Mdot
.47019 .68053 Mdot
.4852 .34847 Mdot
.58695 .59718 Mdot
.46045 .63791 Mdot
.61858 .57173 Mdot
.45088 .63803 Mdot
.4976 .64163 Mdot
.63277 .59757 Mdot
.66231 .61808 Mdot
.49614 .61331 Mdot
.50466 .60041 Mdot
.63028 .36572 Mdot
.29404 .58142 Mdot
.4937 .16309 Mdot
.53247 .65189 Mdot
.25423 .32676 Mdot
.65152 .39043 Mdot
.58523 .75519 Mdot
.44914 .36097 Mdot
.62865 .4085 Mdot
.6274 .41414 Mdot
.65173 .41509 Mdot
.61901 .39969 Mdot
.62596 .58169 Mdot
.666 .45634 Mdot
.38046 .39168 Mdot
.4169 .61297 Mdot
.63218 .25613 Mdot
.65175 .77305 Mdot
.44646 .59522 Mdot
.68145 .58612 Mdot
.30779 .32773 Mdot
.53163 .26317 Mdot
.63495 .42898 Mdot
.48994 .36358 Mdot
.22586 .74902 Mdot
.64247 .40384 Mdot
.46458 .69614 Mdot
.45784 .35478 Mdot
.4604 .62505 Mdot
.44743 .63478 Mdot
.54949 .69749 Mdot
.42699 .60867 Mdot
.29975 .4659 Mdot
.68449 .54312 Mdot
.5896 .4891 Mdot
.45978 .3706 Mdot
.61579 .41233 Mdot
.64964 .56347 Mdot
.63986 .38629 Mdot
.39392 .64102 Mdot
.48334 .33832 Mdot
.44861 .59219 Mdot
.61158 .40182 Mdot
.6943 .56802 Mdot
.48272 .59357 Mdot
.31181 .40823 Mdot
.76902 .33199 Mdot
.34841 .50599 Mdot
.57873 .73348 Mdot
.52299 .72061 Mdot
.33769 .34424 Mdot
.48599 .66777 Mdot
.34324 .61835 Mdot
.72441 .29544 Mdot
.6105 .57917 Mdot
.46434 .56352 Mdot
.26302 .48866 Mdot
.48136 .59631 Mdot
.65647 .24686 Mdot
.48516 .5786 Mdot
.25578 .43348 Mdot
.45855 .38559 Mdot
.6618 .57923 Mdot
.47543 .65804 Mdot
.48863 .5887 Mdot
.42056 .75124 Mdot
.51692 .66392 Mdot
.47917 .62987 Mdot
.66553 .60047 Mdot
.63797 .42505 Mdot
.51743 .67312 Mdot
.38255 .38354 Mdot
.44452 .4021 Mdot
.43417 .65893 Mdot
.41551 .37707 Mdot
.67311 .54299 Mdot
.48251 .58906 Mdot
.63178 .41695 Mdot
.43079 .64879 Mdot
.75174 .55279 Mdot
.66697 .56 Mdot
.49856 .60657 Mdot
.32628 .49512 Mdot
.38888 .78446 Mdot
.6725 .57946 Mdot
.38564 .32408 Mdot
.51055 .65339 Mdot
.47573 .62033 Mdot
.66399 .56585 Mdot
.40555 .3747 Mdot
.67516 .2558 Mdot
.6184 .60305 Mdot
.65856 .38849 Mdot
.69532 .59231 Mdot
.41068 .58646 Mdot
.44928 .38458 Mdot
.45194 .25889 Mdot
.69612 .50169 Mdot
.30683 .55794 Mdot
.47697 .59831 Mdot
.72181 .43318 Mdot
.46281 .39305 Mdot
.64947 .57673 Mdot
.63794 .38064 Mdot
.5216 .57175 Mdot
.64614 .55108 Mdot
.6125 .38022 Mdot
.31251 .49217 Mdot
.55744 .31156 Mdot
.65568 .54385 Mdot
.41249 .46211 Mdot
.59909 .39305 Mdot
.63977 .42861 Mdot
.20111 .41023 Mdot
.649 .56628 Mdot
.31438 .47816 Mdot
.63856 .37383 Mdot
.27961 .54962 Mdot
.41741 .61977 Mdot
.32476 .64123 Mdot
.64955 .7883 Mdot
.23907 .34442 Mdot
.58 .32077 Mdot
.33137 .45981 Mdot
.6448 .35963 Mdot
.49007 .63973 Mdot
.64483 .60067 Mdot
.62254 .58823 Mdot
.42479 .61753 Mdot
.48988 .65732 Mdot
.45568 .58653 Mdot
.48438 .58399 Mdot
.65678 .64167 Mdot
.50428 .66908 Mdot
.57236 .8066 Mdot
.66353 .58258 Mdot
.48156 .64933 Mdot
.4237 .34401 Mdot
.53125 .61058 Mdot
.61537 .40178 Mdot
.46422 .6303 Mdot
.47685 .65593 Mdot
.42113 .62204 Mdot
.63864 .42633 Mdot
.55301 .16224 Mdot
.44289 .78258 Mdot
.50329 .17782 Mdot
.27609 .43158 Mdot
.41953 .3633 Mdot
.48302 .60441 Mdot
.31122 .48571 Mdot
.64241 .72357 Mdot
.45604 .65751 Mdot
.61919 .84993 Mdot
.47329 .63484 Mdot
.52387 .18833 Mdot
.43728 .69519 Mdot
.41129 .19301 Mdot
.33248 .61197 Mdot
.4957 .62897 Mdot
.58229 .51102 Mdot
.60233 .46157 Mdot
.41182 .32456 Mdot
.62167 .39678 Mdot
.42767 .34181 Mdot
.46183 .34941 Mdot
.64813 .46286 Mdot
.57539 .59873 Mdot
.48375 .70396 Mdot
.50793 .58535 Mdot
.48466 .33642 Mdot
.66543 .53625 Mdot
.29168 .47126 Mdot
.66278 .60797 Mdot
.73304 .23961 Mdot
.56979 .24839 Mdot
.59215 .4031 Mdot
.30358 .44606 Mdot
.47323 .37295 Mdot
.43305 .39783 Mdot
.34031 .48643 Mdot
.44907 .6089 Mdot
.64171 .56703 Mdot
.22423 .33964 Mdot
.77456 .54474 Mdot
.1857 .41237 Mdot
.66921 .59775 Mdot
.75583 .43663 Mdot
.61832 .37638 Mdot
.43954 .35045 Mdot
.4772 .62285 Mdot
.45559 .60847 Mdot
.59116 .58755 Mdot
.45661 .58736 Mdot
.5247 .55093 Mdot
.48576 .62237 Mdot
.51332 .28402 Mdot
.35969 .4967 Mdot
.64679 .46336 Mdot
.32211 .54328 Mdot
.61615 .59168 Mdot
.28559 .67645 Mdot
.41856 .3844 Mdot
.63162 .72307 Mdot
.60948 .40895 Mdot
.30144 .48216 Mdot
.43236 .39176 Mdot
.29804 .48613 Mdot
.48867 .67864 Mdot
.44483 .33357 Mdot
.34664 .48224 Mdot
.49029 .71896 Mdot
.44151 .58187 Mdot
.75089 .59346 Mdot
.65494 .39969 Mdot
.63089 .61184 Mdot
.43292 .59894 Mdot
.41563 .3619 Mdot
.53628 .59014 Mdot
.65043 .31706 Mdot
.4724 .27072 Mdot
.43741 .40563 Mdot
.46634 .28148 Mdot
.29759 .4632 Mdot
.62784 .2883 Mdot
.74324 .44323 Mdot
.68883 .57973 Mdot
.51578 .66293 Mdot
.38909 .19372 Mdot
.63911 .37446 Mdot
.43099 .63998 Mdot
.31831 .28034 Mdot
.64614 .38969 Mdot
.46069 .6227 Mdot
.63502 .3617 Mdot
.62171 .58645 Mdot
.39161 .76606 Mdot
.68586 .57864 Mdot
.49461 .58243 Mdot
.63608 .41691 Mdot
.41343 .34578 Mdot
.64099 .59708 Mdot
.44308 .61057 Mdot
.49258 .61057 Mdot
.55497 .45068 Mdot
.48081 .64286 Mdot
.55033 .17082 Mdot
.49116 .62516 Mdot
.44886 .34238 Mdot
.44089 .66847 Mdot
.33213 .79204 Mdot
.68588 .42061 Mdot
.64788 .56432 Mdot
.40403 .3781 Mdot
.46559 .36343 Mdot
.37481 .38548 Mdot
.59172 .43473 Mdot
.50201 .66503 Mdot
.41769 .36461 Mdot
.32284 .69219 Mdot
.60186 .39446 Mdot
.52905 .6509 Mdot
.42671 .47067 Mdot
.29335 .34627 Mdot
.48903 .36438 Mdot
.54073 .64277 Mdot
.6584 .54219 Mdot
.47845 .65928 Mdot
.42215 .39468 Mdot
.59939 .62116 Mdot
.51028 .63331 Mdot
.59872 .55878 Mdot
.55601 .4492 Mdot
.60187 .41225 Mdot
.44704 .70058 Mdot
.43041 .62823 Mdot
.42675 .34707 Mdot
.62053 .59742 Mdot
.60241 .38971 Mdot
.62964 .589 Mdot
.36552 .22391 Mdot
.74357 .56668 Mdot
.52934 .69515 Mdot
.30303 .44189 Mdot
.28617 .33198 Mdot
.38084 .20611 Mdot
.24279 .65845 Mdot
.26971 .63793 Mdot
.27973 .27652 Mdot
.40682 .36948 Mdot
.31781 .28898 Mdot
.4637 .35689 Mdot
.50083 .65025 Mdot
.45125 .38177 Mdot
.37467 .20427 Mdot
.48479 .62407 Mdot
.44902 .37604 Mdot
.31206 .70793 Mdot
.48312 .655 Mdot
.67991 .57009 Mdot
.64208 .20371 Mdot
.27491 .72169 Mdot
.48241 .27517 Mdot
.47356 .34055 Mdot
.24801 .58662 Mdot
.48079 .63156 Mdot
.44952 .67173 Mdot
.66588 .59235 Mdot
.53915 .63351 Mdot
.30953 .45311 Mdot
.30834 .44511 Mdot
.57367 .39265 Mdot
.35941 .6269 Mdot
.44583 .69718 Mdot
.64742 .59666 Mdot
.68493 .64028 Mdot
.28664 .40782 Mdot
.31153 .31902 Mdot
.61523 .36046 Mdot
.63581 .20278 Mdot
.49282 .54425 Mdot
.67353 .37624 Mdot
.42583 .30906 Mdot
.67288 .57243 Mdot
.53431 .1604 Mdot
.62521 .3982 Mdot
.75763 .64736 Mdot
.4301 .51287 Mdot
.44888 .61226 Mdot
.60858 .41547 Mdot
.56484 .5997 Mdot
.25628 .70533 Mdot
.78618 .62845 Mdot
.3855 .55787 Mdot
.49027 .57806 Mdot
.32724 .41336 Mdot
.46925 .62665 Mdot
.6972 .29765 Mdot
.49325 .62212 Mdot
.63536 .59044 Mdot
.72269 .36377 Mdot
.57267 .42968 Mdot
.4795 .80419 Mdot
.65277 .29495 Mdot
.33062 .45903 Mdot
.482 .61919 Mdot
.44705 .61427 Mdot
.31507 .45413 Mdot
.62402 .55212 Mdot
.48098 .58146 Mdot
.2724 .66091 Mdot
.47241 .58982 Mdot
.62136 .40513 Mdot
.41503 .53754 Mdot
.69299 .53041 Mdot
.51421 .60025 Mdot
.69157 .55426 Mdot
.60195 .4192 Mdot
.63841 .41088 Mdot
.43351 .68903 Mdot
.65287 .41615 Mdot
.46996 .64201 Mdot
.79897 .62006 Mdot
.66453 .54593 Mdot
.56906 .54621 Mdot
.62982 .56216 Mdot
.56573 .7363 Mdot
.64768 .40428 Mdot
.52729 .27572 Mdot
.52616 .56843 Mdot
.62713 .3947 Mdot
.73582 .58118 Mdot
.40981 .62587 Mdot
.45197 .57311 Mdot
.21484 .45292 Mdot
.47137 .34356 Mdot
.57006 .45837 Mdot
.63418 .3646 Mdot
.43576 .61634 Mdot
.52054 .63399 Mdot
.6047 .42447 Mdot
.78907 .58655 Mdot
.30106 .72322 Mdot
.4884 .62424 Mdot
.64518 .58785 Mdot
.64515 .57761 Mdot
.4746 .57125 Mdot
.45352 .66672 Mdot
.43806 .38613 Mdot
.40993 .34667 Mdot
.45789 .3306 Mdot
.55805 .44826 Mdot
.51916 .27604 Mdot
.52642 .21928 Mdot
.6512 .4162 Mdot
.74269 .4728 Mdot
.25337 .44018 Mdot
.51938 .59926 Mdot
.48235 .36301 Mdot
.43389 .63684 Mdot
.46809 .65031 Mdot
.59951 .42338 Mdot
.39949 .24925 Mdot
.56221 .58165 Mdot
.61914 .55316 Mdot
.60901 .37327 Mdot
.41031 .579 Mdot
.69489 .37273 Mdot
.3157 .49079 Mdot
.22004 .40485 Mdot
.61122 .40722 Mdot
.67743 .56941 Mdot
.65337 .3844 Mdot
.45994 .60178 Mdot
.46089 .68626 Mdot
.66494 .57051 Mdot
.33756 .45318 Mdot
.53751 .595 Mdot
.46368 .62065 Mdot
.61278 .81793 Mdot
.23175 .46892 Mdot
.51851 .2958 Mdot
.4938 .62862 Mdot
.51558 .61005 Mdot
.34185 .49766 Mdot
.46796 .59202 Mdot
.44894 .58619 Mdot
.40991 .78106 Mdot
.71588 .50686 Mdot
.32136 .44304 Mdot
.79912 .59902 Mdot
.6748 .59526 Mdot
.4386 .17697 Mdot
.43282 .34894 Mdot
.60139 .35978 Mdot
.32758 .74876 Mdot
.49104 .36188 Mdot
.58203 .32461 Mdot
.46575 .17158 Mdot
.57006 .45522 Mdot
.50477 .35457 Mdot
.50928 .5541 Mdot
.47923 .58306 Mdot
.47203 .61945 Mdot
.30553 .47817 Mdot
.63681 .56984 Mdot
.56386 .46542 Mdot
.82384 .45162 Mdot
.46428 .63664 Mdot
.5398 .54551 Mdot
.79874 .46212 Mdot
.2943 .34955 Mdot
.33155 .47394 Mdot
.32539 .44653 Mdot
.47955 .61738 Mdot
.40116 .79208 Mdot
.63493 .59842 Mdot
.44216 .61196 Mdot
.51132 .66122 Mdot
.46881 .33963 Mdot
.66755 .55487 Mdot
.40896 .38281 Mdot
.55336 .2703 Mdot
.50718 .18223 Mdot
.64574 .81148 Mdot
.64446 .40733 Mdot
.74303 .3374 Mdot
.62004 .36739 Mdot
.34499 .60574 Mdot
.45245 .40321 Mdot
.46938 .66434 Mdot
.61788 .59315 Mdot
.43426 .62288 Mdot
.46012 .6676 Mdot
.44751 .61104 Mdot
.52114 .61662 Mdot
.51878 .86685 Mdot
.34593 .47154 Mdot
.4125 .59083 Mdot
.45604 .34278 Mdot
.68961 .27167 Mdot
.76416 .33325 Mdot
.44588 .61948 Mdot
.48883 .6134 Mdot
.64773 .54653 Mdot
.42543 .62384 Mdot
.61083 .37747 Mdot
.63489 .60922 Mdot
.49172 .59199 Mdot
.65765 .22282 Mdot
.50266 .60306 Mdot
.4474 .18519 Mdot
.64929 .37508 Mdot
.75902 .55622 Mdot
.40461 .60721 Mdot
.48272 .27937 Mdot
.57002 .45845 Mdot
.43539 .38995 Mdot
.66143 .39819 Mdot
.45051 .36335 Mdot
.83305 .4862 Mdot
.44532 .68452 Mdot
.49204 .64109 Mdot
.52657 .63554 Mdot
.41907 .36128 Mdot
.63057 .23386 Mdot
.61889 .27642 Mdot
.41958 .57393 Mdot
.42381 .36701 Mdot
.68498 .54557 Mdot
.25404 .52064 Mdot
.62493 .56888 Mdot
.28855 .45301 Mdot
.61342 .38944 Mdot
.32736 .44985 Mdot
.309 .27922 Mdot
.668 .56221 Mdot
.62006 .61201 Mdot
.43348 .35377 Mdot
.4452 .4979 Mdot
.13988 .56587 Mdot
.43585 .50923 Mdot
.32291 .5848 Mdot
.66102 .59217 Mdot
.50736 .59913 Mdot
.36413 .5622 Mdot
.4822 .49801 Mdot
.45242 .36474 Mdot
.45626 .653 Mdot
.38095 .76382 Mdot
.43784 .38624 Mdot
.5242 .65615 Mdot
.46416 .34246 Mdot
.61744 .39273 Mdot
.47868 .36921 Mdot
.60229 .57553 Mdot
.48966 .5991 Mdot
.13402 .50791 Mdot
.36123 .50189 Mdot
.48515 .63253 Mdot
.61088 .36974 Mdot
.57434 .361 Mdot
.44399 .65822 Mdot
.31966 .4977 Mdot
.43949 .37752 Mdot
.41616 .51106 Mdot
.49038 .62329 Mdot
.421 .35987 Mdot
.69212 .59165 Mdot
.65781 .37338 Mdot
.46943 .74395 Mdot
.49521 .29118 Mdot
.66665 .59294 Mdot
.39942 .44118 Mdot
.64918 .42855 Mdot
.51614 .61038 Mdot
.51764 .65974 Mdot
.64361 .58478 Mdot
.37531 .71704 Mdot
.42568 .65581 Mdot
.48473 .66769 Mdot
.44797 .33955 Mdot
.4477 .36766 Mdot
.37897 .73928 Mdot
.4057 .35945 Mdot
.45787 .68587 Mdot
.64083 .58512 Mdot
.47229 .65873 Mdot
.66267 .54793 Mdot
.42594 .62872 Mdot
.63839 .62564 Mdot
.62165 .55441 Mdot
.68735 .40498 Mdot
.46183 .65324 Mdot
.50367 .69266 Mdot
.43239 .64821 Mdot
.46843 .5853 Mdot
.44313 .38876 Mdot
.33046 .48455 Mdot
.50185 .67935 Mdot
.30502 .50004 Mdot
.29753 .48475 Mdot
.59623 .45348 Mdot
.47167 .34176 Mdot
.31139 .46917 Mdot
.80515 .46569 Mdot
.45984 .33208 Mdot
.30258 .46462 Mdot
.7603 .33003 Mdot
.65111 .39427 Mdot
.66413 .54374 Mdot
.48475 .65562 Mdot
.31656 .26071 Mdot
.65077 .77564 Mdot
.42035 .32436 Mdot
.48993 .62714 Mdot
.43463 .6456 Mdot
.61214 .59494 Mdot
.85006 .50107 Mdot
.48118 .3368 Mdot
.50895 .62204 Mdot
.65387 .56004 Mdot
.85559 .55416 Mdot
.452 .34595 Mdot
.30196 .46871 Mdot
.65034 .41316 Mdot
.60658 .55276 Mdot
.69533 .5024 Mdot
.60529 .41834 Mdot
.46526 .30929 Mdot
.52801 .26603 Mdot
.51101 .65353 Mdot
.48114 .37052 Mdot
.19605 .43744 Mdot
.71594 .61879 Mdot
.62485 .47443 Mdot
.24269 .57443 Mdot
.67206 .5747 Mdot
.61544 .3722 Mdot
.33846 .46317 Mdot
.6624 .60011 Mdot
.68232 .56928 Mdot
.60737 .43418 Mdot
.47165 .76872 Mdot
.42613 .4726 Mdot
.62463 .41106 Mdot
.23353 .44038 Mdot
.45228 .236 Mdot
.48306 .36169 Mdot
.30928 .45371 Mdot
.32671 .26561 Mdot
.62573 .58336 Mdot
.62732 .19602 Mdot
.20773 .42861 Mdot
.47906 .63007 Mdot
.31553 .47222 Mdot
.59887 .22441 Mdot
.83326 .43342 Mdot
.64604 .39411 Mdot
.56593 .41841 Mdot
.30716 .45078 Mdot
.43084 .60287 Mdot
.26286 .53556 Mdot
.48568 .66561 Mdot
.61595 .38206 Mdot
.53811 .70138 Mdot
.67816 .56702 Mdot
.61372 .44237 Mdot
.21825 .40511 Mdot
.46801 .64193 Mdot
.46065 .65451 Mdot
.33736 .53644 Mdot
.63334 .60472 Mdot
.4347 .38966 Mdot
.51078 .65761 Mdot
.46403 .62447 Mdot
.47686 .69063 Mdot
.45787 .70311 Mdot
.38442 .77753 Mdot
.50379 .63712 Mdot
.61702 .26466 Mdot
.49836 .57923 Mdot
.45653 .6475 Mdot
.6888 .55153 Mdot
.63463 .82358 Mdot
.56366 .26619 Mdot
.46477 .62811 Mdot
.50991 .60652 Mdot
.62161 .44331 Mdot
.45014 .48144 Mdot
.43969 .49512 Mdot
.41291 .50961 Mdot
.26003 .61447 Mdot
.48694 .56962 Mdot
.64231 .56236 Mdot
.34444 .48709 Mdot
.51212 .63352 Mdot
.64602 .56063 Mdot
.41825 .62641 Mdot
.43555 .38485 Mdot
.45535 .33174 Mdot
.71317 .60909 Mdot
.31303 .46372 Mdot
.4808 .52579 Mdot
.73359 .47334 Mdot
.43255 .33917 Mdot
.49371 .64243 Mdot
.58998 .39972 Mdot
.42439 .39555 Mdot
.44547 .27959 Mdot
.44073 .72814 Mdot
.63419 .60114 Mdot
.66448 .58044 Mdot
.32639 .64785 Mdot
.57833 .31016 Mdot
.51907 .82704 Mdot
.61648 .39207 Mdot
.43847 .67434 Mdot
.73438 .42828 Mdot
.66837 .58039 Mdot
.3549 .57593 Mdot
.31388 .46859 Mdot
.64688 .38866 Mdot
.49962 .40333 Mdot
.64473 .54919 Mdot
.68577 .56862 Mdot
.47615 .57644 Mdot
.45752 .61786 Mdot
.27633 .64876 Mdot
.29237 .43364 Mdot
.60109 .4139 Mdot
.30619 .45469 Mdot
.45574 .40098 Mdot
.50641 .63277 Mdot
.61783 .57028 Mdot
.44455 .24515 Mdot
.51125 .62391 Mdot
.44827 .3917 Mdot
.6671 .57527 Mdot
.29803 .45994 Mdot
.31498 .49826 Mdot
.47078 .58615 Mdot
.63146 .65 Mdot
.63127 .40447 Mdot
.67846 .57323 Mdot
.69392 .37867 Mdot
.45094 .67082 Mdot
.46442 .61157 Mdot
.41406 .68953 Mdot
.59887 .41061 Mdot
.77746 .48595 Mdot
.29097 .45636 Mdot
.6419 .57062 Mdot
.50093 .62566 Mdot
.30721 .45931 Mdot
.76317 .4604 Mdot
.44059 .40616 Mdot
.47728 .36999 Mdot
.3223 .49932 Mdot
.32467 .47291 Mdot
.31217 .49461 Mdot
.62799 .19561 Mdot
.60773 .57916 Mdot
.49439 .54534 Mdot
.43042 .66538 Mdot
.32816 .60502 Mdot
.50244 .56168 Mdot
.60084 .38996 Mdot
.47223 .34617 Mdot
.44365 .66113 Mdot
.50095 .58823 Mdot
.40779 .66528 Mdot
.56248 .55249 Mdot
.70852 .54109 Mdot
.668 .55836 Mdot
.42695 .67175 Mdot
.46022 .33652 Mdot
.74527 .24509 Mdot
.25375 .27515 Mdot
.40221 .62075 Mdot
.41378 .47961 Mdot
.61645 .5712 Mdot
.63643 .43586 Mdot
.34048 .52574 Mdot
.65239 .39727 Mdot
.64583 .57175 Mdot
.50472 .63621 Mdot
.7423 .48064 Mdot
.33182 .50072 Mdot
.44114 .60397 Mdot
.62465 .37184 Mdot
.44461 .59555 Mdot
.60645 .42021 Mdot
.37759 .21573 Mdot
.20686 .51945 Mdot
.47399 .63379 Mdot
.43018 .57756 Mdot
.23815 .5862 Mdot
.44298 .62281 Mdot
.31386 .42729 Mdot
.61654 .56995 Mdot
.41067 .74968 Mdot
.42526 .59132 Mdot
.68528 .66605 Mdot
.46276 .67362 Mdot
.34766 .73574 Mdot
.46218 .61054 Mdot
.28712 .36336 Mdot
.496 .60382 Mdot
.45945 .58292 Mdot
.64153 .41353 Mdot
.61652 .44256 Mdot
.69574 .5686 Mdot
.4164 .36736 Mdot
.47598 .17791 Mdot
.46439 .61706 Mdot
.46756 .26677 Mdot
.74789 .5089 Mdot
.32676 .47232 Mdot
.64051 .57328 Mdot
.85843 .48213 Mdot
.64524 .36642 Mdot
.22632 .48798 Mdot
.35098 .72484 Mdot
.66738 .47579 Mdot
.26695 .49602 Mdot
.71913 .34898 Mdot
.29644 .46714 Mdot
.421 .62553 Mdot
.42241 .24729 Mdot
.27677 .38342 Mdot
.44365 .7295 Mdot
.64564 .43437 Mdot
.65164 .7068 Mdot
.41292 .24344 Mdot
.28712 .47457 Mdot
.31347 .44741 Mdot
.628 .43343 Mdot
.48219 .41417 Mdot
.56583 .59069 Mdot
.31735 .46795 Mdot
.42287 .34109 Mdot
.47622 .33702 Mdot
.49373 .35772 Mdot
.62795 .59543 Mdot
.2131 .37885 Mdot
.697 .36118 Mdot
.6037 .41362 Mdot
.46793 .41352 Mdot
.71428 .56851 Mdot
.60383 .58839 Mdot
.44091 .35599 Mdot
.45674 .39135 Mdot
.6269 .54795 Mdot
.45221 .69509 Mdot
.41012 .66198 Mdot
.46524 .63281 Mdot
.31772 .48806 Mdot
.45712 .61224 Mdot
.4283 .37286 Mdot
.64384 .39422 Mdot
.46482 .3835 Mdot
.62317 .35972 Mdot
.54826 .22497 Mdot
.44952 .60094 Mdot
.492 .60187 Mdot
.68353 .75842 Mdot
.69464 .58407 Mdot
.59959 .25075 Mdot
.50716 .3057 Mdot
.46334 .35359 Mdot
.44547 .58823 Mdot
.63283 .60937 Mdot
.28411 .47563 Mdot
.70621 .74429 Mdot
.44298 .66419 Mdot
.62111 .56656 Mdot
.50426 .62576 Mdot
.63284 .6416 Mdot
.38344 .81347 Mdot
.63149 .58448 Mdot
.64846 .78782 Mdot
.5067 .60292 Mdot
.76634 .38625 Mdot
.53055 .63687 Mdot
.32599 .68133 Mdot
.42604 .65617 Mdot
.67256 .5966 Mdot
.46145 .63203 Mdot
.64227 .61 Mdot
.43167 .34235 Mdot
.6397 .43161 Mdot
.66901 .5883 Mdot
.52219 .65337 Mdot
.12464 .38026 Mdot
.62024 .38061 Mdot
.47924 .62073 Mdot
.64627 .41533 Mdot
.63387 .56804 Mdot
.67988 .58491 Mdot
.81702 .41267 Mdot
.56093 .27198 Mdot
.61854 .39238 Mdot
.50587 .63031 Mdot
.69386 .32525 Mdot
.48047 .66319 Mdot
.29395 .6488 Mdot
.46957 .69615 Mdot
.43639 .6671 Mdot
.77362 .33951 Mdot
.59999 .40915 Mdot
.49893 .82767 Mdot
.81373 .39378 Mdot
.69496 .27427 Mdot
.58427 .59 Mdot
.28625 .47486 Mdot
.54293 .16086 Mdot
.52428 .27684 Mdot
.42172 .36378 Mdot
.43691 .65542 Mdot
.70082 .54043 Mdot
.63325 .40913 Mdot
.33233 .486 Mdot
.47436 .63268 Mdot
.46225 .38868 Mdot
.26693 .69022 Mdot
.63844 .35731 Mdot
.62707 .57963 Mdot
.61521 .55832 Mdot
.80377 .65367 Mdot
.49678 .62737 Mdot
.49057 .59641 Mdot
.61393 .38675 Mdot
.78889 .46126 Mdot
.29513 .4733 Mdot
.29927 .69942 Mdot
.61949 .39077 Mdot
.52862 .46551 Mdot
.65548 .563 Mdot
.43387 .64305 Mdot
.59852 .20895 Mdot
.33658 .40978 Mdot
.73318 .68007 Mdot
.31169 .48559 Mdot
.29019 .64008 Mdot
.67579 .59516 Mdot
.63797 .37737 Mdot
.55223 .32915 Mdot
.50604 .57689 Mdot
.43597 .63866 Mdot
.29364 .63789 Mdot
.58055 .44082 Mdot
.39032 .55221 Mdot
.44821 .66731 Mdot
.583 .46369 Mdot
.42766 .65288 Mdot
.4973 .56731 Mdot
.45744 .69053 Mdot
.47227 .60286 Mdot
.61903 .56826 Mdot
.38942 .64905 Mdot
.42707 .38014 Mdot
.46181 .53532 Mdot
.53466 .47272 Mdot
.48613 .62862 Mdot
.49898 .65975 Mdot
.6938 .71467 Mdot
.59107 .33375 Mdot
.66747 .58612 Mdot
.59729 .60004 Mdot
.65703 .40457 Mdot
.40908 .66312 Mdot
.41799 .37557 Mdot
.50757 .56724 Mdot
.44704 .38957 Mdot
.61809 .57371 Mdot
.45957 .34981 Mdot
.64609 .42115 Mdot
.48217 .34824 Mdot
.51829 .27564 Mdot
.63903 .37151 Mdot
.64639 .60131 Mdot
.48076 .5924 Mdot
.61182 .36893 Mdot
.3044 .54794 Mdot
.31589 .48711 Mdot
.81444 .37445 Mdot
.49332 .59239 Mdot
.71294 .50922 Mdot
.57091 .62311 Mdot
.46077 .38755 Mdot
.40531 .81254 Mdot
.61801 .55563 Mdot
.33343 .44708 Mdot
.61461 .58971 Mdot
.22321 .46139 Mdot
.32549 .48167 Mdot
.75266 .3132 Mdot
.50364 .31903 Mdot
.23997 .48475 Mdot
.42999 .68353 Mdot
.28575 .52558 Mdot
.48485 .37372 Mdot
.63468 .40873 Mdot
.56335 .33013 Mdot
.45021 .58646 Mdot
.21719 .60628 Mdot
.66109 .53863 Mdot
.41786 .36938 Mdot
.63828 .38397 Mdot
.60316 .38649 Mdot
.48235 .67444 Mdot
.34305 .31243 Mdot
.43051 .6227 Mdot
.57493 .29859 Mdot
.26647 .6182 Mdot
.57223 .57112 Mdot
.48518 .62224 Mdot
.4276 .34592 Mdot
.5043 .62604 Mdot
.32344 .43969 Mdot
.20229 .38745 Mdot
.54056 .61073 Mdot
.51112 .30577 Mdot
.3573 .50701 Mdot
.66681 .56753 Mdot
.55151 .63852 Mdot
.52744 .28597 Mdot
.49906 .62925 Mdot
.419 .86999 Mdot
.30429 .4621 Mdot
.41509 .25283 Mdot
.52104 .62711 Mdot
.49689 .66981 Mdot
.59189 .49816 Mdot
.66955 .49752 Mdot
.33971 .41297 Mdot
.44232 .63114 Mdot
.27291 .58258 Mdot
.61841 .42925 Mdot
.42787 .63388 Mdot
.47419 .61879 Mdot
.51664 .77642 Mdot
.60996 .37471 Mdot
.46853 .35917 Mdot
.48592 .37518 Mdot
.40965 .33818 Mdot
.33088 .44182 Mdot
.5555 .42309 Mdot
.3442 .58088 Mdot
.26049 .6999 Mdot
.35162 .4649 Mdot
.49015 .58624 Mdot
.3702 .45347 Mdot
.504 .6469 Mdot
.33758 .47082 Mdot
.6147 .36956 Mdot
.67169 .58505 Mdot
.74601 .4248 Mdot
.48595 .3425 Mdot
.53177 .64685 Mdot
.29316 .46317 Mdot
.64193 .60107 Mdot
.25099 .47265 Mdot
.6581 .56643 Mdot
.62559 .38971 Mdot
.63447 .35082 Mdot
.3364 .48197 Mdot
.63204 .56392 Mdot
.66827 .41357 Mdot
.83261 .44676 Mdot
.46588 .68852 Mdot
.6092 .3469 Mdot
.68198 .59751 Mdot
.59213 .59296 Mdot
.66018 .60493 Mdot
.45416 .58951 Mdot
.4142 .47866 Mdot
.41426 .62169 Mdot
.6014 .41216 Mdot
.46684 .34548 Mdot
.23896 .60864 Mdot
.51258 .24033 Mdot
.38526 .44249 Mdot
.43558 .67438 Mdot
.46571 .64255 Mdot
.4793 .61758 Mdot
.43106 .58468 Mdot
.55319 .30136 Mdot
.43334 .62667 Mdot
.64016 .4159 Mdot
.43748 .37871 Mdot
.42078 .62449 Mdot
.47188 .39679 Mdot
.68039 .2731 Mdot
.35068 .46596 Mdot
.55652 .41099 Mdot
.27576 .2292 Mdot
.65258 .59865 Mdot
.40746 .38445 Mdot
.42265 .35991 Mdot
.31116 .49144 Mdot
.62726 .40721 Mdot
.65337 .5657 Mdot
.31135 .67849 Mdot
.30379 .49039 Mdot
.46242 .62918 Mdot
.39686 .49906 Mdot
.20606 .56919 Mdot
.42173 .62961 Mdot
.45651 .66169 Mdot
.44901 .40758 Mdot
.39249 .27302 Mdot
.15339 .48503 Mdot
.35783 .54873 Mdot
.33345 .48332 Mdot
.34467 .46432 Mdot
.64415 .54305 Mdot
.41115 .61829 Mdot
.60165 .41356 Mdot
.40066 .54982 Mdot
.55088 .37629 Mdot
.45109 .52295 Mdot
.66084 .51662 Mdot
.43696 .65954 Mdot
.79773 .56679 Mdot
.46929 .64409 Mdot
.6086 .58254 Mdot
.62006 .58101 Mdot
.64971 .59282 Mdot
.6346 .407 Mdot
.59312 .73798 Mdot
.63354 .41954 Mdot
.26181 .24031 Mdot
.68334 .58883 Mdot
.52145 .34304 Mdot
.4368 .3462 Mdot
.40233 .61392 Mdot
.30041 .45866 Mdot
.66561 .37317 Mdot
.39376 .6402 Mdot
.40515 .79892 Mdot
.42077 .37275 Mdot
.65241 .60035 Mdot
.72627 .35576 Mdot
.31921 .22486 Mdot
.42619 .49977 Mdot
.41195 .57528 Mdot
.31488 .52673 Mdot
.32881 .46943 Mdot
.73179 .68383 Mdot
.30583 .45306 Mdot
.62771 .36975 Mdot
.48999 .60469 Mdot
.48068 .59678 Mdot
.42569 .64999 Mdot
.44447 .61093 Mdot
.64526 .42993 Mdot
.51313 .66753 Mdot
.33203 .79196 Mdot
.4453 .33186 Mdot
.49897 .71536 Mdot
.30128 .46151 Mdot
.65943 .41329 Mdot
.43576 .37799 Mdot
.58562 .33508 Mdot
.32628 .5466 Mdot
.48899 .62327 Mdot
.44023 .65914 Mdot
.2234 .49246 Mdot
.44942 .66799 Mdot
.49792 .55862 Mdot
.42106 .36122 Mdot
.38496 .47434 Mdot
.34325 .457 Mdot
.33969 .45861 Mdot
.64489 .37472 Mdot
.619 .57334 Mdot
.30616 .47078 Mdot
.44138 .34179 Mdot
.43752 .67596 Mdot
.51767 .65182 Mdot
.68176 .59703 Mdot
.20185 .43871 Mdot
.28967 .46299 Mdot
.71131 .3345 Mdot
.62057 .5956 Mdot
.68116 .61192 Mdot
.43648 .63996 Mdot
.61748 .53316 Mdot
.61175 .54842 Mdot
.35179 .45916 Mdot
.65976 .41131 Mdot
.34793 .527 Mdot
.61206 .38228 Mdot
.62556 .57572 Mdot
.51079 .63483 Mdot
.6213 .58979 Mdot
.49397 .62714 Mdot
.38322 .17229 Mdot
.47337 .59889 Mdot
.26076 .70522 Mdot
.31884 .64495 Mdot
.43484 .36476 Mdot
.60091 .33861 Mdot
.43265 .35035 Mdot
.62336 .59964 Mdot
.51264 .64532 Mdot
.30084 .44907 Mdot
.7201 .30141 Mdot
.71492 .56216 Mdot
.4491 .39379 Mdot
.45356 .32562 Mdot
.62396 .36663 Mdot
.421 .64939 Mdot
.43493 .63505 Mdot
.44868 .37407 Mdot
.57036 .56879 Mdot
.63937 .55264 Mdot
.49098 .61275 Mdot
.46004 .64443 Mdot
.43506 .3621 Mdot
.83427 .46067 Mdot
.72254 .58642 Mdot
.48388 .60375 Mdot
.43683 .26335 Mdot
.59918 .39637 Mdot
.41788 .66617 Mdot
.43509 .57393 Mdot
.32222 .47167 Mdot
.49308 .74291 Mdot
.22346 .357 Mdot
.62266 .36248 Mdot
.42189 .35139 Mdot
.49864 .62589 Mdot
.42659 .34676 Mdot
.51647 .65715 Mdot
.65477 .49797 Mdot
.45674 .39774 Mdot
.48242 .66962 Mdot
.45777 .69921 Mdot
.63255 .60486 Mdot
.43895 .65984 Mdot
.66111 .74671 Mdot
.42547 .39282 Mdot
.48923 .67198 Mdot
.6191 .65131 Mdot
.6193 .41146 Mdot
.42302 .67905 Mdot
.33714 .49101 Mdot
.31246 .68208 Mdot
.70908 .47664 Mdot
.38628 .25127 Mdot
.34929 .46939 Mdot
.44088 .59963 Mdot
.43427 .32699 Mdot
.61598 .4306 Mdot
.28425 .72759 Mdot
.42761 .61156 Mdot
.61715 .38051 Mdot
.64351 .39177 Mdot
.31632 .49058 Mdot
.67274 .78988 Mdot
.52059 .61756 Mdot
.44743 .6186 Mdot
.56989 .77841 Mdot
.69305 .59257 Mdot
.46362 .60388 Mdot
.49935 .59014 Mdot
.64006 .41753 Mdot
.48233 .55396 Mdot
.67742 .70181 Mdot
.32016 .71637 Mdot
.59663 .40978 Mdot
.49677 .50884 Mdot
.48628 .35914 Mdot
.31278 .45763 Mdot
.66046 .57209 Mdot
.29423 .45988 Mdot
.48068 .3528 Mdot
.4944 .58932 Mdot
.65619 .3886 Mdot
.61848 .7801 Mdot
.62825 .43373 Mdot
.36304 .25609 Mdot
.68776 .59635 Mdot
.72109 .41933 Mdot
.46488 .87882 Mdot
.67634 .30459 Mdot
.65203 .33938 Mdot
.32648 .47262 Mdot
.4028 .42554 Mdot
.46213 .64458 Mdot
.72203 .70415 Mdot
.47664 .58728 Mdot
.60138 .65558 Mdot
.43233 .3365 Mdot
.45741 .33045 Mdot
.48741 .60465 Mdot
.27252 .62737 Mdot
.61716 .43226 Mdot
.60098 .39875 Mdot
.47934 .67255 Mdot
.62663 .39471 Mdot
.45412 .62116 Mdot
.43658 .38289 Mdot
.49961 .83642 Mdot
.46985 .6312 Mdot
.45043 .57151 Mdot
.66444 .49093 Mdot
.79057 .35956 Mdot
.2927 .31596 Mdot
.82595 .57693 Mdot
.29298 .24467 Mdot
.62783 .39422 Mdot
.41175 .64219 Mdot
.49673 .50981 Mdot
.48301 .38383 Mdot
.67274 .38143 Mdot
.46969 .59359 Mdot
.46764 .59118 Mdot
.46318 .58146 Mdot
.46298 .65643 Mdot
.74312 .67462 Mdot
.39287 .5854 Mdot
.56638 .70486 Mdot
.45561 .66643 Mdot
.28861 .53163 Mdot
.64279 .37002 Mdot
.59528 .57398 Mdot
.35686 .47714 Mdot
.43656 .65902 Mdot
.44755 .54399 Mdot
.61621 .44503 Mdot
.25893 .24198 Mdot
.63288 .36676 Mdot
.46511 .36378 Mdot
.63274 .43624 Mdot
.48191 .64166 Mdot
.64529 .57804 Mdot
.51312 .49251 Mdot
.62157 .28576 Mdot
.42175 .36492 Mdot
.4854 .63217 Mdot
.51959 .3337 Mdot
.4246 .37661 Mdot
.67556 .26646 Mdot
.65386 .57677 Mdot
.27728 .58122 Mdot
.61957 .58473 Mdot
.48756 .66984 Mdot
.49228 .66792 Mdot
.63071 .34423 Mdot
.63886 .4307 Mdot
.61905 .58251 Mdot
.67626 .79405 Mdot
.29605 .48458 Mdot
.644 .59389 Mdot
.52358 .58621 Mdot
.47387 .45727 Mdot
.64723 .58194 Mdot
.34349 .51844 Mdot
.64418 .40252 Mdot
.68867 .5624 Mdot
.51777 .58725 Mdot
.22949 .41825 Mdot
.34341 .48986 Mdot
.43693 .41014 Mdot
.37682 .51312 Mdot
.42275 .39314 Mdot
.66103 .40268 Mdot
.43185 .35226 Mdot
.62016 .42904 Mdot
.72595 .4955 Mdot
.48116 .53431 Mdot
.59374 .37793 Mdot
.65794 .41096 Mdot
.43387 .35433 Mdot
.49452 .61013 Mdot
.33322 .52315 Mdot
.41289 .65203 Mdot
.52118 .61046 Mdot
.61296 .42116 Mdot
.66343 .5993 Mdot
.59645 .57983 Mdot
.26848 .53405 Mdot
.62326 .55607 Mdot
.45014 .39098 Mdot
.35306 .79376 Mdot
.46418 .26158 Mdot
.60831 .39999 Mdot
.63264 .43841 Mdot
.48648 .6642 Mdot
.45113 .36361 Mdot
.41986 .34775 Mdot
.62141 .36944 Mdot
.56384 .53938 Mdot
.42082 .58822 Mdot
.59844 .5919 Mdot
.69144 .57736 Mdot
.63549 .58556 Mdot
.65777 .60638 Mdot
.7092 .66846 Mdot
.64868 .39248 Mdot
.65304 .60286 Mdot
.47644 .6697 Mdot
.46771 .59264 Mdot
.44745 .50446 Mdot
.34291 .46432 Mdot
.42135 .61659 Mdot
.45261 .6903 Mdot
.43599 .64543 Mdot
.47677 .37357 Mdot
.426 .71455 Mdot
.45379 .39827 Mdot
.42952 .33077 Mdot
.42454 .33604 Mdot
.52204 .27681 Mdot
.23004 .52244 Mdot
.30233 .2559 Mdot
.50897 .62059 Mdot
.79514 .48811 Mdot
.44981 .35232 Mdot
.40363 .80451 Mdot
.77848 .48332 Mdot
.43682 .59692 Mdot
.31639 .40383 Mdot
.44618 .37186 Mdot
.61812 .5576 Mdot
.47103 .5952 Mdot
.40422 .34801 Mdot
.33668 .49256 Mdot
.46337 .67867 Mdot
.45066 .40216 Mdot
.63431 .56395 Mdot
.35585 .4638 Mdot
.69343 .57294 Mdot
.42638 .33586 Mdot
.44098 .69475 Mdot
.15833 .64098 Mdot
.45026 .32383 Mdot
.80094 .43094 Mdot
.637 .62949 Mdot
.49233 .61147 Mdot
.41335 .39077 Mdot
.69447 .59721 Mdot
.66116 .38764 Mdot
.52922 .40049 Mdot
.67824 .55516 Mdot
.45967 .33069 Mdot
.43885 .39937 Mdot
.42092 .36273 Mdot
.67237 .56039 Mdot
.46889 .57041 Mdot
.66767 .55105 Mdot
.63079 .43686 Mdot
.48179 .65889 Mdot
.38317 .20481 Mdot
.79262 .49958 Mdot
.61868 .58934 Mdot
.47129 .36124 Mdot
.33884 .49912 Mdot
.47342 .63909 Mdot
.79794 .5092 Mdot
.49828 .61545 Mdot
.60821 .41841 Mdot
.41532 .77659 Mdot
.65351 .76396 Mdot
.43011 .664 Mdot
.48499 .66433 Mdot
.60151 .40312 Mdot
.4806 .62988 Mdot
.42446 .65448 Mdot
.53279 .27748 Mdot
.66347 .55437 Mdot
.46083 .63549 Mdot
.4572 .34033 Mdot
.51304 .2599 Mdot
.42399 .58716 Mdot
.38022 .3364 Mdot
.27953 .5998 Mdot
.42891 .77761 Mdot
.47862 .58721 Mdot
.38641 .53583 Mdot
.45374 .65258 Mdot
.44306 .60377 Mdot
.49902 .65227 Mdot
.76036 .66918 Mdot
.46194 .39451 Mdot
.42654 .36449 Mdot
.35053 .47945 Mdot
.27815 .59583 Mdot
.31777 .47192 Mdot
.64531 .40307 Mdot
.35224 .32606 Mdot
.45471 .39788 Mdot
.62709 .56774 Mdot
.4369 .60888 Mdot
.44653 .32385 Mdot
.43302 .63918 Mdot
.4838 .64137 Mdot
.41546 .37716 Mdot
.48281 .37323 Mdot
.40653 .25155 Mdot
.34837 .47888 Mdot
.65705 .59078 Mdot
.41563 .63414 Mdot
.29217 .46809 Mdot
.50774 .59323 Mdot
.32976 .60642 Mdot
.65295 .59031 Mdot
.66492 .55282 Mdot
.60105 .57173 Mdot
.49528 .59039 Mdot
.47921 .63911 Mdot
.63157 .42113 Mdot
.61481 .58512 Mdot
.61883 .40877 Mdot
.55186 .45609 Mdot
.37142 .39565 Mdot
.46962 .59349 Mdot
.71915 .35726 Mdot
.32206 .45949 Mdot
.46286 .3809 Mdot
.21309 .57003 Mdot
.35014 .48126 Mdot
.4939 .62462 Mdot
.41507 .35368 Mdot
.33936 .46923 Mdot
.45495 .73579 Mdot
.2167 .32428 Mdot
.34732 .4935 Mdot
.47529 .67004 Mdot
.43485 .55837 Mdot
.82144 .58996 Mdot
.35273 .47664 Mdot
.65194 .4084 Mdot
.495 .5908 Mdot
.66184 .53016 Mdot
.29451 .45694 Mdot
.62272 .26742 Mdot
.44083 .37643 Mdot
.22735 .38579 Mdot
.39504 .67082 Mdot
.67501 .75734 Mdot
.32726 .45481 Mdot
.64907 .5679 Mdot
.59879 .62053 Mdot
.44071 .64518 Mdot
.35216 .479 Mdot
.59925 .42752 Mdot
.44808 .38362 Mdot
.55926 .26701 Mdot
.67399 .56096 Mdot
.71276 .38391 Mdot
.47428 .36006 Mdot
.70676 .33058 Mdot
.36937 .74976 Mdot
.4132 .66451 Mdot
.81269 .59498 Mdot
.53947 .3672 Mdot
.46733 .57656 Mdot
.32256 .50297 Mdot
.61817 .36387 Mdot
.65728 .39382 Mdot
.62311 .38758 Mdot
.74114 .50405 Mdot
.41324 .50809 Mdot
.40657 .38425 Mdot
.68015 .35486 Mdot
.3122 .45898 Mdot
.33736 .53249 Mdot
.52512 .64512 Mdot
.46604 .64057 Mdot
.42178 .65475 Mdot
.42935 .65208 Mdot
.4491 .64645 Mdot
.62393 .40264 Mdot
.71476 .49768 Mdot
.42643 .50821 Mdot
.6492 .58674 Mdot
.37326 .29004 Mdot
.43917 .34661 Mdot
.40588 .38452 Mdot
.34297 .47623 Mdot
.69856 .30215 Mdot
.4695 .39835 Mdot
.46175 .35058 Mdot
.44635 .58176 Mdot
.64737 .54907 Mdot
.45803 .55816 Mdot
.48078 .66718 Mdot
.45162 .38869 Mdot
.57564 .49062 Mdot
.68567 .70996 Mdot
.43267 .72179 Mdot
.32428 .51307 Mdot
.42906 .48176 Mdot
.34286 .49397 Mdot
.51423 .64115 Mdot
.41183 .8099 Mdot
.4813 .35474 Mdot
.45923 .36552 Mdot
.3284 .45721 Mdot
.67522 .52195 Mdot
.66973 .57303 Mdot
.65043 .33475 Mdot
.64051 .4225 Mdot
.50747 .65434 Mdot
.26281 .6794 Mdot
.55356 .65087 Mdot
.33478 .3216 Mdot
.6193 .38693 Mdot
.4311 .34363 Mdot
.43129 .66954 Mdot
.47188 .66886 Mdot
.3265 .45963 Mdot
.4754 .20677 Mdot
.44542 .68384 Mdot
.68231 .24817 Mdot
.20651 .51851 Mdot
.21216 .43278 Mdot
.436 .63828 Mdot
.66594 .55562 Mdot
.45457 .40352 Mdot
.3106 .45364 Mdot
.53144 .60028 Mdot
.24654 .29364 Mdot
.68634 .59082 Mdot
.63387 .37225 Mdot
.5336 .48481 Mdot
.36027 .52444 Mdot
.48336 .58283 Mdot
.47793 .58868 Mdot
.45253 .59412 Mdot
.18384 .37641 Mdot
.46846 .38575 Mdot
.6153 .57478 Mdot
.32423 .49078 Mdot
.62365 .5595 Mdot
.42974 .36082 Mdot
.71355 .40255 Mdot
.49706 .60852 Mdot
.68779 .59036 Mdot
.65105 .56841 Mdot
.62966 .36673 Mdot
.65831 .37555 Mdot
.54605 .47382 Mdot
.47169 .60057 Mdot
.46606 .32568 Mdot
.64348 .60495 Mdot
.39837 .50095 Mdot
.32478 .48044 Mdot
.64417 .40873 Mdot
.4487 .66407 Mdot
.478 .37658 Mdot
.52402 .65897 Mdot
.66568 .58211 Mdot
.46096 .35061 Mdot
.43389 .25354 Mdot
.34737 .46299 Mdot
.45607 .60236 Mdot
.3242 .43391 Mdot
.42084 .35184 Mdot
.4618 .64646 Mdot
.74127 .3462 Mdot
.35247 .51069 Mdot
.60899 .27375 Mdot
.41893 .34152 Mdot
.47779 .2745 Mdot
.64787 .54371 Mdot
.76038 .52233 Mdot
.46183 .36634 Mdot
.72015 .34348 Mdot
.47805 .22236 Mdot
.42594 .6676 Mdot
.62709 .58554 Mdot
.54007 .37658 Mdot
.4321 .17381 Mdot
.8269 .47924 Mdot
.47809 .62014 Mdot
.40542 .35935 Mdot
.33139 .46201 Mdot
.60763 .40348 Mdot
.37641 .34725 Mdot
.34679 .51334 Mdot
.47826 .33434 Mdot
.4998 .65106 Mdot
.6403 .56678 Mdot
.64046 .40286 Mdot
.71374 .48113 Mdot
.44684 .34019 Mdot
.47071 .34896 Mdot
.43098 .66851 Mdot
.31352 .46763 Mdot
.78935 .53436 Mdot
.4323 .37931 Mdot
.21602 .51031 Mdot
.48631 .32875 Mdot
.29212 .47648 Mdot
.45389 .65722 Mdot
.26251 .52839 Mdot
.41743 .60367 Mdot
.77981 .37395 Mdot
.43724 .35057 Mdot
.66054 .58568 Mdot
.45837 .58563 Mdot
.33499 .71948 Mdot
.455 .38694 Mdot
.41656 .48111 Mdot
.28463 .35635 Mdot
.64714 .39784 Mdot
.21303 .57305 Mdot
.4563 .60977 Mdot
.61761 .43217 Mdot
.32325 .46089 Mdot
.47873 .60213 Mdot
.47853 .64203 Mdot
.61572 .59939 Mdot
.62297 .37029 Mdot
.4386 .228 Mdot
.61587 .44337 Mdot
.65249 .38099 Mdot
.61305 .60305 Mdot
.45048 .63165 Mdot
.46618 .36245 Mdot
.44784 .37133 Mdot
.52933 .61739 Mdot
.45193 .83985 Mdot
.67294 .57217 Mdot
.423 .41099 Mdot
.17952 .39602 Mdot
.49603 .69464 Mdot
.2217 .59382 Mdot
.49002 .20385 Mdot
.59642 .40221 Mdot
.47135 .67145 Mdot
.63307 .56617 Mdot
.45125 .43718 Mdot
.47102 .35235 Mdot
.49398 .57917 Mdot
.63932 .3991 Mdot
.34004 .49115 Mdot
.4267 .38882 Mdot
.34245 .31509 Mdot
.44645 .60459 Mdot
.30624 .40484 Mdot
.40662 .37408 Mdot
.56616 .16046 Mdot
.57482 .3417 Mdot
.6295 .58949 Mdot
.4837 .64448 Mdot
.62011 .55262 Mdot
.32961 .48971 Mdot
.53352 .48296 Mdot
.64213 .39718 Mdot
.38062 .62536 Mdot
.29569 .77628 Mdot
.42016 .35998 Mdot
.61529 .57166 Mdot
.43224 .66586 Mdot
.64046 .50463 Mdot
.4528 .61629 Mdot
.50592 .55608 Mdot
.37853 .47435 Mdot
.6131 .41689 Mdot
.623 .43182 Mdot
.46762 .65157 Mdot
.30008 .48483 Mdot
.44037 .34335 Mdot
.45283 .38416 Mdot
.70244 .22748 Mdot
.6464 .47153 Mdot
.28197 .65567 Mdot
.46453 .59311 Mdot
.4643 .32896 Mdot
.51504 .24564 Mdot
.61409 .38727 Mdot
.53117 .64021 Mdot
.4183 .37512 Mdot
.24366 .41984 Mdot
.33904 .70446 Mdot
.44714 .64912 Mdot
.47104 .56681 Mdot
.64466 .41842 Mdot
.39815 .52438 Mdot
.44423 .33374 Mdot
.48169 .69454 Mdot
.60636 .3583 Mdot
.38505 .73267 Mdot
.19408 .42741 Mdot
.65683 .59107 Mdot
.33173 .30488 Mdot
.62416 .40355 Mdot
.47082 .56533 Mdot
.29807 .4706 Mdot
.46907 .39538 Mdot
.4704 .38569 Mdot
.50158 .63625 Mdot
.49013 .67708 Mdot
.22813 .57402 Mdot
.62905 .55707 Mdot
.6446 .37232 Mdot
.48811 .59497 Mdot
.74873 .41225 Mdot
.42685 .65264 Mdot
.62695 .42057 Mdot
.15298 .64231 Mdot
.41686 .65572 Mdot
.44943 .61902 Mdot
.79633 .52208 Mdot
.68158 .5607 Mdot
.61343 .57156 Mdot
.22339 .63516 Mdot
.46385 .59369 Mdot
.2109 .5459 Mdot
.66292 .59003 Mdot
.67107 .57559 Mdot
.55507 .27881 Mdot
.47097 .63822 Mdot
.37701 .65459 Mdot
.60589 .41748 Mdot
.6542 .3887 Mdot
.67294 .55522 Mdot
.42434 .67161 Mdot
.63084 .3595 Mdot
.76948 .62292 Mdot
.45023 .36217 Mdot
.42644 .81577 Mdot
.67914 .57483 Mdot
.57188 .43725 Mdot
.61575 .38826 Mdot
.26574 .23793 Mdot
.47906 .31206 Mdot
.49415 .60744 Mdot
.45594 .59915 Mdot
.31857 .45792 Mdot
.4158 .64699 Mdot
.45436 .33016 Mdot
.62608 .39487 Mdot
.56863 .66306 Mdot
.64916 .59328 Mdot
.46418 .60925 Mdot
.69088 .29067 Mdot
.6125 .2497 Mdot
.33266 .29228 Mdot
.66558 .56776 Mdot
.62765 .59362 Mdot
.45397 .33532 Mdot
.40566 .36117 Mdot
.44431 .63765 Mdot
.60354 .39408 Mdot
.61543 .58586 Mdot
.62115 .42279 Mdot
.48105 .35565 Mdot
.46631 .35748 Mdot
.46939 .38982 Mdot
.51667 .66849 Mdot
.45975 .34513 Mdot
.3879 .3026 Mdot
.70904 .37796 Mdot
.60394 .59113 Mdot
.18413 .51863 Mdot
.72145 .48229 Mdot
.73301 .57714 Mdot
.29413 .45394 Mdot
.41963 .35264 Mdot
.62276 .43995 Mdot
.47189 .66002 Mdot
.43429 .65045 Mdot
.43606 .2807 Mdot
.61342 .4343 Mdot
.33192 .48717 Mdot
.62256 .4345 Mdot
.31621 .49069 Mdot
.27981 .39321 Mdot
.41953 .64118 Mdot
.51545 .65495 Mdot
.62186 .39848 Mdot
.45961 .34722 Mdot
.43266 .37187 Mdot
.35212 .48686 Mdot
.61856 .47756 Mdot
.42391 .37649 Mdot
.67596 .5788 Mdot
.72101 .65378 Mdot
.43973 .39997 Mdot
.46826 .59795 Mdot
.3455 .58485 Mdot
.70351 .73239 Mdot
.43168 .5842 Mdot
.54637 .27779 Mdot
.60192 .79757 Mdot
.44321 .59349 Mdot
.66705 .77686 Mdot
.4977 .29443 Mdot
.64601 .54501 Mdot
.43555 .33568 Mdot
.4534 .40955 Mdot
.5384 .64925 Mdot
.35353 .49684 Mdot
.53057 .60643 Mdot
.68296 .57489 Mdot
.67324 .54006 Mdot
.22171 .44512 Mdot
.79951 .41581 Mdot
.33423 .46466 Mdot
.34124 .46777 Mdot
.46139 .36993 Mdot
.83262 .39438 Mdot
.3938 .61776 Mdot
.33387 .48439 Mdot
.49785 .53514 Mdot
.50108 .64711 Mdot
.30413 .63815 Mdot
.28559 .42783 Mdot
.67077 .55678 Mdot
.27442 .52401 Mdot
.46475 .37269 Mdot
.62537 .55362 Mdot
.75086 .43263 Mdot
.42536 .60341 Mdot
.6511 .59095 Mdot
.62503 .42366 Mdot
.59526 .31929 Mdot
.67801 .58631 Mdot
.33847 .59503 Mdot
.6163 .37247 Mdot
.40313 .49564 Mdot
.27014 .55221 Mdot
.69705 .82482 Mdot
.62635 .40029 Mdot
.44489 .39724 Mdot
.44797 .37245 Mdot
.45418 .38296 Mdot
.62666 .5561 Mdot
.4202 .34808 Mdot
.6265 .56079 Mdot
.82201 .53842 Mdot
.66237 .5176 Mdot
.33494 .48187 Mdot
.5672 .26926 Mdot
.63315 .57385 Mdot
.38373 .80787 Mdot
.39628 .84719 Mdot
.47125 .67193 Mdot
.63106 .44171 Mdot
.33646 .47484 Mdot
.69522 .25273 Mdot
.32365 .46883 Mdot
.23821 .49845 Mdot
.42107 .78886 Mdot
.46003 .61774 Mdot
.63156 .72952 Mdot
.32336 .44774 Mdot
.6577 .56291 Mdot
.46375 .64596 Mdot
.50749 .41232 Mdot
.32017 .46671 Mdot
.32445 .49549 Mdot
.45195 .63858 Mdot
.65181 .60057 Mdot
.46855 .36816 Mdot
.64764 .4219 Mdot
.3132 .44243 Mdot
.62206 .62088 Mdot
.43275 .58639 Mdot
.5026 .61939 Mdot
.45189 .49848 Mdot
.28442 .44458 Mdot
.62854 .39448 Mdot
.73084 .71968 Mdot
.4146 .34607 Mdot
.51703 .39826 Mdot
.2153 .49589 Mdot
.52774 .28336 Mdot
.43828 .35261 Mdot
.42598 .35001 Mdot
.44615 .64483 Mdot
.27813 .45377 Mdot
.43211 .78955 Mdot
.65873 .43784 Mdot
.45227 .40351 Mdot
.44955 .38501 Mdot
.64251 .53853 Mdot
.21864 .45353 Mdot
.5318 .59756 Mdot
.624 .36138 Mdot
.47366 .38327 Mdot
.67905 .50835 Mdot
.31147 .46475 Mdot
.38367 .79294 Mdot
.41946 .63628 Mdot
.49225 .60319 Mdot
.63566 .38639 Mdot
.6353 .41821 Mdot
.44367 .43947 Mdot
.22451 .47052 Mdot
.61927 .78907 Mdot
.69201 .48057 Mdot
.48054 .76022 Mdot
.65653 .53723 Mdot
.61901 .59017 Mdot
.64507 .29004 Mdot
.61654 .44423 Mdot
.44897 .58963 Mdot
.61852 .57591 Mdot
.52083 .37107 Mdot
.73136 .60708 Mdot
.28961 .64529 Mdot
.23286 .60245 Mdot
.49209 .62825 Mdot
.65257 .55245 Mdot
.68172 .56226 Mdot
.65928 .61198 Mdot
.50761 .31037 Mdot
.44235 .6306 Mdot
.48559 .62402 Mdot
.432 .61152 Mdot
.59152 .53828 Mdot
.43779 .61805 Mdot
.75372 .52209 Mdot
.52033 .47076 Mdot
.50661 .73203 Mdot
.47543 .69384 Mdot
.59997 .38014 Mdot
.48578 .58433 Mdot
.30239 .487 Mdot
.49817 .65767 Mdot
.29285 .65198 Mdot
.6231 .37529 Mdot
.7239 .58812 Mdot
.72703 .49153 Mdot
.45908 .58016 Mdot
.34766 .45371 Mdot
.56263 .37208 Mdot
.3683 .21465 Mdot
.34789 .44218 Mdot
.67668 .57786 Mdot
.44637 .35772 Mdot
.61935 .43948 Mdot
.46319 .35813 Mdot
.50679 .67461 Mdot
.65399 .29852 Mdot
.6143 .23357 Mdot
.5619 .45948 Mdot
.43132 .65363 Mdot
.41037 .6937 Mdot
.67129 .57927 Mdot
.41389 .35535 Mdot
.6556 .52613 Mdot
.45837 .58728 Mdot
.31589 .48794 Mdot
.31974 .46234 Mdot
.53014 .39163 Mdot
.54113 .18002 Mdot
.74887 .56919 Mdot
.63408 .38834 Mdot
.43608 .38445 Mdot
.30378 .45342 Mdot
.77281 .40299 Mdot
.65906 .37573 Mdot
.6011 .40592 Mdot
.63193 .36965 Mdot
.50641 .5999 Mdot
.45641 .39829 Mdot
.51124 .72832 Mdot
.46569 .33059 Mdot
.48222 .63206 Mdot
.47329 .37843 Mdot
.41905 .3727 Mdot
.30342 .45899 Mdot
.63865 .3689 Mdot
.47545 .34316 Mdot
.49007 .66972 Mdot
.65915 .59528 Mdot
.5756 .42239 Mdot
.3303 .67389 Mdot
.7915 .40126 Mdot
.58607 .64384 Mdot
.68962 .57665 Mdot
.42951 .17977 Mdot
.59829 .40104 Mdot
.57267 .53884 Mdot
.39802 .25933 Mdot
.51206 .62817 Mdot
.41197 .8357 Mdot
.4085 .38932 Mdot
.41961 .38099 Mdot
.45543 .65664 Mdot
.48857 .40939 Mdot
.46006 .61305 Mdot
.47794 .35652 Mdot
.42425 .27573 Mdot
.57164 .5927 Mdot
.45261 .34575 Mdot
.48881 .69271 Mdot
.47366 .64592 Mdot
.66845 .55436 Mdot
.41446 .39104 Mdot
.53288 .63813 Mdot
.67949 .21474 Mdot
.63299 .41683 Mdot
.52354 .32965 Mdot
.34895 .59722 Mdot
.62375 .40495 Mdot
.64115 .59265 Mdot
.52345 .61914 Mdot
.32537 .46049 Mdot
.6326 .57214 Mdot
.34555 .71514 Mdot
.337 .45395 Mdot
.39075 .81878 Mdot
.67955 .56246 Mdot
.43373 .39813 Mdot
.29796 .47503 Mdot
.41231 .6339 Mdot
.46786 .39604 Mdot
.59777 .33573 Mdot
.43972 .35144 Mdot
.43505 .6334 Mdot
.56774 .25874 Mdot
.64843 .37613 Mdot
.4775 .61725 Mdot
.41928 .38425 Mdot
.53329 .27498 Mdot
.5079 .60418 Mdot
.4606 .6524 Mdot
.20071 .44376 Mdot
.32686 .76144 Mdot
.32571 .47533 Mdot
.6775 .60867 Mdot
.47686 .66969 Mdot
.33089 .49389 Mdot
.33259 .38179 Mdot
.49799 .59667 Mdot
.68446 .59413 Mdot
.46413 .70652 Mdot
.4101 .38395 Mdot
.62367 .41161 Mdot
.5618 .45171 Mdot
.33672 .49241 Mdot
.83125 .6398 Mdot
.4819 .34509 Mdot
.51788 .64317 Mdot
.4373 .66115 Mdot
.27332 .32925 Mdot
.6437 .54576 Mdot
.52819 .80909 Mdot
.45603 .60213 Mdot
.58416 .54204 Mdot
.47597 .60478 Mdot
.41912 .40547 Mdot
.67078 .57357 Mdot
.44515 .62038 Mdot
.71672 .36718 Mdot
.43878 .57695 Mdot
.35005 .47689 Mdot
.80054 .52209 Mdot
.44534 .57972 Mdot
.23046 .73429 Mdot
.26527 .43986 Mdot
.45217 .34428 Mdot
.60796 .25766 Mdot
.78647 .2823 Mdot
.74183 .50012 Mdot
.62246 .56459 Mdot
.53095 .20563 Mdot
.46647 .36159 Mdot
.56156 .24362 Mdot
.42251 .17868 Mdot
.47606 .64991 Mdot
.48308 .58264 Mdot
.24797 .46845 Mdot
.42891 .33284 Mdot
.48245 .33356 Mdot
.46224 .68495 Mdot
.48543 .56522 Mdot
.46692 .35103 Mdot
.49603 .67003 Mdot
.48761 .68262 Mdot
.64457 .42837 Mdot
.68601 .58327 Mdot
.60871 .41264 Mdot
.61919 .36693 Mdot
.78129 .59214 Mdot
.25754 .4332 Mdot
.62738 .4186 Mdot
.60471 .37811 Mdot
.30563 .64319 Mdot
.24327 .574 Mdot
.29507 .45597 Mdot
.58592 .17925 Mdot
.45117 .38225 Mdot
.44611 .62905 Mdot
.68727 .57025 Mdot
.63394 .77888 Mdot
.36578 .35818 Mdot
.44753 .80662 Mdot
.45302 .58854 Mdot
.45936 .38231 Mdot
.50782 .3103 Mdot
.47657 .5563 Mdot
.41768 .3283 Mdot
.48799 .59282 Mdot
.4845 .34021 Mdot
.67178 .67784 Mdot
.71554 .34086 Mdot
.4845 .33048 Mdot
.59974 .59403 Mdot
.48729 .59872 Mdot
.68064 .57251 Mdot
.61388 .3936 Mdot
.29469 .46819 Mdot
.3232 .47746 Mdot
.45823 .64377 Mdot
.426 .68582 Mdot
.28685 .3999 Mdot
.4738 .64019 Mdot
.49703 .65198 Mdot
.49716 .2937 Mdot
.49477 .65646 Mdot
.42763 .6426 Mdot
.42907 .62543 Mdot
.50077 .58189 Mdot
.65362 .3852 Mdot
.6949 .2998 Mdot
.53761 .58651 Mdot
.5282 .57684 Mdot
.65554 .37391 Mdot
.45321 .21692 Mdot
.60837 .3783 Mdot
.37399 .20467 Mdot
.61116 .4233 Mdot
.32588 .48358 Mdot
.3253 .27275 Mdot
.40336 .66709 Mdot
.65109 .60539 Mdot
.6647 .38914 Mdot
.32361 .49196 Mdot
.6242 .39083 Mdot
.47541 .36496 Mdot
.19401 .39099 Mdot
.68345 .6139 Mdot
.40587 .5428 Mdot
.66865 .39537 Mdot
.66002 .31046 Mdot
.47256 .33816 Mdot
.67619 .56831 Mdot
.67361 .71859 Mdot
.42704 .64871 Mdot
.32653 .49446 Mdot
.44714 .63971 Mdot
.64145 .36703 Mdot
.46186 .37626 Mdot
.81992 .48713 Mdot
.32599 .45959 Mdot
.18941 .50217 Mdot
.43767 .37331 Mdot
.42629 .62606 Mdot
.62647 .36101 Mdot
.18952 .57839 Mdot
.611 .41651 Mdot
.48687 .79119 Mdot
.63477 .54408 Mdot
.83327 .56618 Mdot
.62902 .57872 Mdot
.61568 .32804 Mdot
.14544 .50672 Mdot
.70728 .29892 Mdot
.65305 .59938 Mdot
.67865 .42763 Mdot
.49705 .6265 Mdot
.50206 .61798 Mdot
.78197 .41059 Mdot
.67778 .60811 Mdot
.46014 .66892 Mdot
.45681 .26147 Mdot
.70284 .39402 Mdot
.2414 .6395 Mdot
.43122 .34724 Mdot
.4595 .60911 Mdot
.6195 .35194 Mdot
.61305 .43046 Mdot
.47674 .33675 Mdot
.59941 .4024 Mdot
.48364 .62454 Mdot
.6325 .57487 Mdot
.39943 .4146 Mdot
.31249 .47876 Mdot
.7545 .30794 Mdot
.30459 .49372 Mdot
.43801 .35311 Mdot
.41122 .64943 Mdot
.46602 .35638 Mdot
.79408 .27157 Mdot
.48739 .61896 Mdot
.66338 .5887 Mdot
.48052 .6653 Mdot
.48632 .60164 Mdot
.47969 .58037 Mdot
.47223 .3601 Mdot
.39105 .7112 Mdot
.49246 .67017 Mdot
.64292 .39733 Mdot
.50203 .74279 Mdot
.44515 .581 Mdot
.46052 .41495 Mdot
.26321 .59835 Mdot
.67729 .36111 Mdot
.68214 .55501 Mdot
.44625 .34662 Mdot
.64858 .5956 Mdot
.59717 .55748 Mdot
.64134 .59243 Mdot
.533 .75907 Mdot
.67799 .70739 Mdot
.41333 .74615 Mdot
.61356 .65077 Mdot
.55959 .50605 Mdot
.6774 .60854 Mdot
.29788 .42974 Mdot
.62152 .59785 Mdot
.67807 .55629 Mdot
.07412 .54524 Mdot
.64451 .60786 Mdot
.4643 .5984 Mdot
.43172 .59664 Mdot
.68302 .31828 Mdot
.3128 .59282 Mdot
.47968 .66083 Mdot
.46963 .6655 Mdot
.29866 .46136 Mdot
.57441 .55585 Mdot
.62604 .2751 Mdot
.32196 .76798 Mdot
.58207 .23652 Mdot
.45005 .63978 Mdot
.47946 .66943 Mdot
.47273 .55979 Mdot
.20334 .65713 Mdot
.78868 .61108 Mdot
.70159 .56572 Mdot
.444 .56826 Mdot
.75273 .33202 Mdot
.47652 .58164 Mdot
.4981 .5894 Mdot
.49383 .62727 Mdot
.46644 .3626 Mdot
.69615 .57399 Mdot
.51626 .59084 Mdot
.24454 .45355 Mdot
.4883 .58911 Mdot
.53083 .28131 Mdot
.85111 .48085 Mdot
.45569 .60984 Mdot
.69408 .56452 Mdot
.50461 .6249 Mdot
.65643 .54626 Mdot
.65746 .55889 Mdot
.40407 .61581 Mdot
.48573 .75853 Mdot
.6783 .54456 Mdot
.4823 .63279 Mdot
.46881 .37469 Mdot
.55705 .16396 Mdot
.43497 .63162 Mdot
.29373 .46387 Mdot
.45749 .59841 Mdot
.34364 .45003 Mdot
.49324 .65338 Mdot
.48269 .34529 Mdot
.67581 .75174 Mdot
.45926 .36788 Mdot
.80814 .60939 Mdot
.47906 .37921 Mdot
.19733 .45281 Mdot
.69231 .58993 Mdot
.56575 .26436 Mdot
.57158 .82472 Mdot
.52286 .31024 Mdot
.40399 .46865 Mdot
.48723 .47313 Mdot
.60309 .39476 Mdot
.62903 .5484 Mdot
.52833 .52882 Mdot
.40203 .26591 Mdot
.35886 .27399 Mdot
.42788 .38269 Mdot
.66676 .7972 Mdot
.47166 .82724 Mdot
.50929 .65743 Mdot
.60804 .74401 Mdot
.57999 .71038 Mdot
.4833 .58109 Mdot
.51586 .5938 Mdot
.45959 .28555 Mdot
.48151 .67511 Mdot
.74637 .40382 Mdot
.43588 .35596 Mdot
.32305 .49254 Mdot
.67001 .58387 Mdot
.33862 .49269 Mdot
.39619 .26567 Mdot
.48009 .47428 Mdot
.47918 .3591 Mdot
.46786 .56875 Mdot
.46992 .66275 Mdot
.66072 .54906 Mdot
.70593 .54798 Mdot
.6303 .6036 Mdot
.33394 .46782 Mdot
.4373 .36141 Mdot
.72826 .69796 Mdot
.46139 .66429 Mdot
.65095 .56956 Mdot
.40061 .45574 Mdot
.47436 .67012 Mdot
.61745 .39834 Mdot
.49537 .62138 Mdot
.66221 .59633 Mdot
.49455 .65655 Mdot
.62756 .57797 Mdot
.44883 .35883 Mdot
.43631 .59549 Mdot
.45054 .65395 Mdot
.18797 .54615 Mdot
.32811 .48733 Mdot
.68662 .59716 Mdot
.50081 .31951 Mdot
.43712 .6646 Mdot
.57628 .28738 Mdot
.48288 .59196 Mdot
.74072 .59744 Mdot
.51481 .624 Mdot
.51667 .30756 Mdot
.53825 .59538 Mdot
.43627 .62934 Mdot
.42867 .44874 Mdot
.57321 .7249 Mdot
.70793 .58055 Mdot
.62038 .36095 Mdot
.65965 .60715 Mdot
.24705 .64201 Mdot
.48872 .32851 Mdot
.4105 .36018 Mdot
.32557 .53875 Mdot
.49992 .58038 Mdot
.45799 .61971 Mdot
.63531 .35114 Mdot
.34494 .46942 Mdot
.66398 .56671 Mdot
.31647 .49067 Mdot
.20322 .54302 Mdot
.3366 .45745 Mdot
.41231 .3964 Mdot
.30846 .40366 Mdot
.7435 .66944 Mdot
.29972 .46039 Mdot
.65293 .60071 Mdot
.37294 .40899 Mdot
.49029 .57733 Mdot
.26893 .43944 Mdot
.31031 .48373 Mdot
.73122 .75533 Mdot
.42815 .64232 Mdot
.40037 .46945 Mdot
.62107 .41633 Mdot
.2978 .46833 Mdot
.61119 .38222 Mdot
.47173 .65775 Mdot
.612 .27302 Mdot
.62181 .56853 Mdot
.64578 .36543 Mdot
.43178 .68495 Mdot
.33742 .47601 Mdot
.4655 .39093 Mdot
.65231 .35604 Mdot
.62585 .3593 Mdot
.47364 .20438 Mdot
.81867 .51224 Mdot
.43826 .36396 Mdot
.34586 .74087 Mdot
.60868 .42229 Mdot
.47494 .57681 Mdot
.55738 .55104 Mdot
.49439 .60667 Mdot
.75451 .54196 Mdot
.44087 .34573 Mdot
.68411 .3089 Mdot
.4834 .66639 Mdot
.4399 .60246 Mdot
.70369 .58571 Mdot
.45308 .37347 Mdot
.64412 .57984 Mdot
.65635 .60932 Mdot
.44902 .36058 Mdot
.62921 .58646 Mdot
.33252 .45018 Mdot
.70241 .42856 Mdot
.63756 .42635 Mdot
.6444 .38843 Mdot
.45173 .38511 Mdot
.45196 .34188 Mdot
.46238 .35181 Mdot
.49549 .62098 Mdot
.6688 .56957 Mdot
.48668 .64693 Mdot
.4879 .58655 Mdot
.46798 .75811 Mdot
.68975 .56695 Mdot
.49288 .63627 Mdot
.49448 .41918 Mdot
.2757 .47825 Mdot
.46908 .37671 Mdot
.6254 .41738 Mdot
.50474 .24943 Mdot
.59115 .34466 Mdot
.46288 .60592 Mdot
.24828 .41507 Mdot
.64112 .60306 Mdot
.32364 .46259 Mdot
.28506 .47188 Mdot
.32477 .471 Mdot
.62868 .45985 Mdot
.67888 .60621 Mdot
.32858 .7745 Mdot
.45791 .61325 Mdot
.44628 .49723 Mdot
.47711 .53063 Mdot
.27303 .40298 Mdot
.62869 .41687 Mdot
.47321 .66844 Mdot
.57002 .4577 Mdot
.68746 .71605 Mdot
.49216 .60766 Mdot
.46028 .57432 Mdot
.43404 .25626 Mdot
.4678 .70775 Mdot
.62262 .54789 Mdot
.19682 .58614 Mdot
.42166 .65745 Mdot
.67831 .51049 Mdot
.77224 .31765 Mdot
.47221 .59803 Mdot
.44954 .5947 Mdot
.44127 .65672 Mdot
.50077 .65557 Mdot
.68377 .55083 Mdot
.29121 .55899 Mdot
.59763 .40795 Mdot
.4382 .50198 Mdot
.65548 .4004 Mdot
.47912 .38421 Mdot
.69523 .30788 Mdot
.62634 .54897 Mdot
.31905 .45793 Mdot
.68457 .26531 Mdot
.24575 .68345 Mdot
.44273 .33406 Mdot
.76819 .61773 Mdot
.31736 .48695 Mdot
.46816 .57566 Mdot
.33191 .44767 Mdot
.45254 .39828 Mdot
.64659 .39523 Mdot
.48871 .57236 Mdot
.62268 .59701 Mdot
.67996 .58414 Mdot
.46603 .67063 Mdot
.7387 .31741 Mdot
.61706 .40302 Mdot
.6461 .35682 Mdot
.50295 .59947 Mdot
.41269 .63379 Mdot
.64243 .5826 Mdot
.43691 .38151 Mdot
.30363 .69243 Mdot
.3434 .47815 Mdot
.52154 .65978 Mdot
.50038 .65126 Mdot
.21601 .48638 Mdot
.64425 .40473 Mdot
.40629 .35193 Mdot
.51104 .61935 Mdot
.68059 .48048 Mdot
.51081 .62154 Mdot
.44055 .56679 Mdot
.46661 .37799 Mdot
.5458 .59562 Mdot
.51054 .66059 Mdot
.50688 .55389 Mdot
.60498 .39855 Mdot
.6565 .58887 Mdot
.63675 .61711 Mdot
.46716 .51074 Mdot
.61803 .39614 Mdot
.49773 .63282 Mdot
.63317 .41093 Mdot
.49725 .59703 Mdot
.47618 .67347 Mdot
.62654 .42044 Mdot
.64299 .58003 Mdot
.52884 .20868 Mdot
.69184 .29552 Mdot
.50135 .65724 Mdot
.43712 .67506 Mdot
.30049 .57206 Mdot
.38695 .70702 Mdot
.46493 .58479 Mdot
.669 .59275 Mdot
.45885 .66111 Mdot
.61493 .37976 Mdot
.31894 .44797 Mdot
.65945 .59587 Mdot
.4282 .3672 Mdot
.45452 .33364 Mdot
.73202 .4933 Mdot
.41655 .36054 Mdot
.4977 .5841 Mdot
.61452 .54234 Mdot
.65785 .61706 Mdot
.76989 .33165 Mdot
.4494 .36455 Mdot
.29834 .4496 Mdot
.4607 .65093 Mdot
.22948 .41695 Mdot
.62261 .34929 Mdot
.28258 .79016 Mdot
.37552 .80787 Mdot
.34774 .50071 Mdot
.45149 .80089 Mdot
.48671 .36439 Mdot
.51248 .6637 Mdot
.29427 .47179 Mdot
.45084 .33552 Mdot
.50969 .63331 Mdot
.41327 .5874 Mdot
.51403 .80757 Mdot
.51235 .50076 Mdot
.63504 .41127 Mdot
.41986 .34549 Mdot
.33554 .50853 Mdot
.40118 .3742 Mdot
.68565 .57326 Mdot
.43944 .62698 Mdot
.40777 .6444 Mdot
.43036 .37393 Mdot
.41663 .33846 Mdot
.4877 .6327 Mdot
.62074 .5521 Mdot
.46464 .28877 Mdot
.45624 .63852 Mdot
.57566 .51224 Mdot
.59245 .59989 Mdot
.43109 .35492 Mdot
.43533 .61255 Mdot
.38258 .46889 Mdot
.43715 .37595 Mdot
.4694 .37755 Mdot
.47179 .67231 Mdot
.33572 .4519 Mdot
.433 .67078 Mdot
.62094 .43029 Mdot
.73059 .72849 Mdot
.61823 .3749 Mdot
.37755 .35106 Mdot
.42768 .68395 Mdot
.65103 .47986 Mdot
.67226 .54719 Mdot
.24161 .48734 Mdot
.46782 .25562 Mdot
.46495 .68654 Mdot
.51036 .1771 Mdot
.56653 .42597 Mdot
.72323 .29498 Mdot
.29585 .27372 Mdot
.3033 .47086 Mdot
.62288 .38865 Mdot
.45077 .59376 Mdot
.63556 .43791 Mdot
.29297 .47024 Mdot
.80783 .60333 Mdot
.43217 .61955 Mdot
.66997 .57527 Mdot
.48801 .62795 Mdot
.67844 .5757 Mdot
.47539 .67184 Mdot
.49733 .56151 Mdot
.47397 .27057 Mdot
.3389 .70341 Mdot
.5135 .61468 Mdot
.18199 .42615 Mdot
.35808 .42936 Mdot
.33391 .4899 Mdot
.48074 .64651 Mdot
.43215 .31974 Mdot
.60975 .43061 Mdot
.77598 .43468 Mdot
.46723 .36188 Mdot
.61131 .3713 Mdot
.63644 .58769 Mdot
.44334 .35048 Mdot
.45507 .33203 Mdot
.54679 .59929 Mdot
.35217 .46627 Mdot
.64132 .37441 Mdot
.44414 .61905 Mdot
.43263 .62118 Mdot
.32047 .7276 Mdot
.36565 .33772 Mdot
.71488 .55606 Mdot
.2499 .71736 Mdot
.61502 .60652 Mdot
.33584 .48499 Mdot
.46932 .36573 Mdot
.47422 .58669 Mdot
.47598 .62027 Mdot
.55347 .26927 Mdot
.61321 .58348 Mdot
.5407 .48101 Mdot
.74383 .61932 Mdot
.49266 .31507 Mdot
.28365 .61487 Mdot
.67108 .58672 Mdot
.28591 .61753 Mdot
.29975 .49497 Mdot
.63058 .20677 Mdot
.32038 .67793 Mdot
.62283 .41511 Mdot
.28451 .61152 Mdot
.65098 .56559 Mdot
.50115 .66367 Mdot
.43372 .39885 Mdot
.41854 .37078 Mdot
.65198 .58481 Mdot
.40211 .3454 Mdot
.30604 .45839 Mdot
.44554 .60261 Mdot
.31596 .75785 Mdot
.73991 .47321 Mdot
.44404 .39009 Mdot
.49302 .55852 Mdot
.6306 .36988 Mdot
.46451 .67097 Mdot
.30418 .45496 Mdot
.62943 .40319 Mdot
.22989 .48226 Mdot
.70086 .36113 Mdot
.46219 .64835 Mdot
.20448 .45562 Mdot
.62229 .39674 Mdot
.37497 .68633 Mdot
.44994 .63438 Mdot
.60658 .41799 Mdot
.42029 .71508 Mdot
.59787 .32146 Mdot
.57062 .46505 Mdot
.42471 .17764 Mdot
.55309 .46578 Mdot
.43562 .3966 Mdot
.62701 .31349 Mdot
.53682 .3568 Mdot
.6286 .43884 Mdot
.41046 .34329 Mdot
.29156 .50497 Mdot
.60992 .38398 Mdot
.45041 .57986 Mdot
.4803 .59372 Mdot
.79475 .6066 Mdot
.55622 .41699 Mdot
.63276 .32619 Mdot
.77348 .48942 Mdot
.43337 .66211 Mdot
.42196 .66332 Mdot
.47127 .62122 Mdot
.67593 .5417 Mdot
.63958 .40657 Mdot
.17303 .4844 Mdot
.61515 .39762 Mdot
.3748 .78304 Mdot
.45347 .38198 Mdot
.43443 .34312 Mdot
.45939 .60687 Mdot
.39163 .49456 Mdot
.25326 .54781 Mdot
.4823 .62677 Mdot
.30981 .51897 Mdot
.8023 .51524 Mdot
.41418 .64272 Mdot
.65204 .54144 Mdot
.55459 .58556 Mdot
.61479 .62364 Mdot
.6372 .42699 Mdot
.30964 .46736 Mdot
.24309 .49434 Mdot
.64812 .39062 Mdot
.4591 .62014 Mdot
.67285 .46329 Mdot
.48407 .60636 Mdot
.50568 .65221 Mdot
.39813 .80173 Mdot
.31335 .49953 Mdot
.45711 .35485 Mdot
.3273 .47189 Mdot
.66135 .54586 Mdot
.16952 .69507 Mdot
.34698 .46748 Mdot
.2498 .53921 Mdot
.79232 .63803 Mdot
.28735 .61251 Mdot
.68421 .57679 Mdot
.35373 .46618 Mdot
.61973 .40893 Mdot
.57145 .16142 Mdot
.56412 .81554 Mdot
.58098 .39264 Mdot
.45911 .63499 Mdot
.61092 .56199 Mdot
.67306 .59454 Mdot
.65135 .36983 Mdot
.65781 .56016 Mdot
.4113 .70504 Mdot
.5029 .65968 Mdot
.63038 .4406 Mdot
.69276 .47022 Mdot
.62123 .35981 Mdot
.71544 .40518 Mdot
.48011 .64198 Mdot
.66607 .5901 Mdot
.50764 .67872 Mdot
.58444 .59594 Mdot
.4016 .36622 Mdot
.43058 .58667 Mdot
.30765 .45744 Mdot
.65425 .48572 Mdot
.43703 .36549 Mdot
.25788 .40406 Mdot
.66396 .54927 Mdot
.68244 .38003 Mdot
.66607 .55422 Mdot
.66894 .61227 Mdot
.61535 .36994 Mdot
.63389 .56226 Mdot
.44763 .59717 Mdot
.52602 .39362 Mdot
.63819 .54989 Mdot
.63296 .37888 Mdot
.31226 .47172 Mdot
.63187 .5824 Mdot
.48493 .41239 Mdot
.45395 .64915 Mdot
.47143 .35023 Mdot
.3153 .28436 Mdot
.60787 .5907 Mdot
.33865 .49746 Mdot
.41184 .35885 Mdot
.32201 .49529 Mdot
.81393 .40462 Mdot
.63266 .44411 Mdot
.4227 .78659 Mdot
.32588 .5151 Mdot
.64522 .60616 Mdot
.33063 .27055 Mdot
.47384 .58826 Mdot
.45675 .6505 Mdot
.33877 .44613 Mdot
.67249 .59486 Mdot
.67897 .24338 Mdot
.68306 .624 Mdot
.69884 .41621 Mdot
.66173 .41098 Mdot
.19317 .44198 Mdot
.72236 .39161 Mdot
.84494 .41017 Mdot
.44415 .68488 Mdot
.48582 .33643 Mdot
.46661 .60935 Mdot
.48126 .25723 Mdot
.3358 .47572 Mdot
.4118 .41461 Mdot
.41442 .59538 Mdot
.45096 .35391 Mdot
.44013 .64869 Mdot
.46549 .44272 Mdot
.55153 .61882 Mdot
.29602 .45147 Mdot
.61315 .26323 Mdot
.65027 .60753 Mdot
.3129 .48112 Mdot
.48284 .35258 Mdot
.26262 .57162 Mdot
.50974 .64414 Mdot
.52712 .6592 Mdot
.49243 .31504 Mdot
.67441 .57092 Mdot
.42012 .39131 Mdot
.63098 .42996 Mdot
.31577 .46128 Mdot
.47354 .6613 Mdot
.51054 .59696 Mdot
.57217 .28863 Mdot
.63283 .36824 Mdot
.42638 .32993 Mdot
.60974 .41105 Mdot
.48926 .35628 Mdot
.46971 .67713 Mdot
.43071 .3437 Mdot
.52566 .64928 Mdot
.48782 .2747 Mdot
.39535 .79652 Mdot
.58234 .73345 Mdot
.43856 .34644 Mdot
.27135 .62487 Mdot
.62116 .37683 Mdot
.60786 .41498 Mdot
.76061 .67056 Mdot
.48721 .79443 Mdot
.29055 .71506 Mdot
.4187 .21372 Mdot
.65351 .4056 Mdot
.63108 .37214 Mdot
.46905 .34597 Mdot
.63482 .55963 Mdot
.63099 .61176 Mdot
.48864 .3508 Mdot
.34809 .58585 Mdot
.66371 .56675 Mdot
.55665 .1741 Mdot
.2555 .66695 Mdot
.52354 .60755 Mdot
.41502 .32167 Mdot
.31872 .46582 Mdot
.34003 .58738 Mdot
.46239 .4428 Mdot
.44332 .59734 Mdot
.2334 .45783 Mdot
.44455 .38621 Mdot
.3898 .52762 Mdot
.37574 .20528 Mdot
.42869 .62845 Mdot
.44608 .63068 Mdot
.46593 .61781 Mdot
.3513 .49139 Mdot
.53635 .80271 Mdot
.43788 .61226 Mdot
.34852 .58878 Mdot
.44799 .66856 Mdot
.40705 .71292 Mdot
.32451 .47603 Mdot
.44349 .73702 Mdot
.41216 .25247 Mdot
.20616 .59936 Mdot
.54716 .63889 Mdot
.62757 .43176 Mdot
.28381 .51228 Mdot
.60359 .40687 Mdot
.54438 .75378 Mdot
.32125 .67428 Mdot
.6029 .59408 Mdot
.44659 .59466 Mdot
.43726 .35308 Mdot
.6752 .59308 Mdot
.59809 .3062 Mdot
.11181 .61825 Mdot
.62467 .43342 Mdot
.85877 .39758 Mdot
.61183 .42223 Mdot
.45965 .33211 Mdot
.64267 .5836 Mdot
.68019 .70024 Mdot
.46124 .49956 Mdot
.62972 .58269 Mdot
.59704 .22489 Mdot
.7029 .56016 Mdot
.27181 .60931 Mdot
.60989 .57387 Mdot
.62883 .37687 Mdot
.62855 .45914 Mdot
.39325 .65705 Mdot
.46645 .59315 Mdot
.48772 .46959 Mdot
.24811 .5648 Mdot
.46969 .58922 Mdot
.43703 .35813 Mdot
.44088 .78403 Mdot
.27009 .51464 Mdot
.63733 .56456 Mdot
.59618 .41673 Mdot
.44252 .63344 Mdot
.50557 .6355 Mdot
.50964 .6487 Mdot
.28726 .76695 Mdot
.63633 .2082 Mdot
.49091 .67044 Mdot
.44042 .66787 Mdot
.44634 .35232 Mdot
.30542 .50317 Mdot
.46537 .24633 Mdot
.43812 .75593 Mdot
.44316 .59046 Mdot
.31949 .48284 Mdot
.32382 .50417 Mdot
.51133 .62825 Mdot
.26998 .4337 Mdot
.67075 .46143 Mdot
.44321 .61978 Mdot
.45489 .77878 Mdot
.5128 .34747 Mdot
.42922 .33292 Mdot
.43069 .37155 Mdot
.68911 .58493 Mdot
.42089 .35518 Mdot
.48615 .35943 Mdot
.70072 .68512 Mdot
.54105 .47024 Mdot
.59189 .41057 Mdot
.33375 .46665 Mdot
.47858 .61658 Mdot
.70897 .58729 Mdot
.6738 .47547 Mdot
.60787 .38364 Mdot
.63387 .6005 Mdot
.60629 .42431 Mdot
.34137 .43862 Mdot
.42138 .53507 Mdot
.4342 .38868 Mdot
.65196 .40485 Mdot
.70143 .36677 Mdot
.32031 .48147 Mdot
.63069 .36496 Mdot
.68897 .35974 Mdot
.4297 .59156 Mdot
.60647 .75775 Mdot
.47993 .63149 Mdot
.70073 .26778 Mdot
.64266 .37176 Mdot
.51567 .29448 Mdot
.45166 .62138 Mdot
.43912 .37571 Mdot
.38983 .63986 Mdot
.48405 .58844 Mdot
.42477 .36757 Mdot
.50841 .65862 Mdot
.31045 .49565 Mdot
.59581 .60381 Mdot
.44433 .50403 Mdot
.609 .84418 Mdot
.35237 .46614 Mdot
.59683 .30144 Mdot
.4596 .58574 Mdot
.82625 .47295 Mdot
.63272 .58039 Mdot
.52271 .64486 Mdot
.27878 .52791 Mdot
.63246 .55449 Mdot
.64078 .59746 Mdot
.50215 .63355 Mdot
.61828 .41479 Mdot
.43426 .3626 Mdot
.32127 .47798 Mdot
.81651 .38101 Mdot
.46517 .63949 Mdot
.45342 .65706 Mdot
.31491 .48467 Mdot
.62429 .37202 Mdot
.50992 .61509 Mdot
.28254 .30994 Mdot
.69693 .24025 Mdot
.60031 .40645 Mdot
.44863 .58168 Mdot
.55147 .77671 Mdot
.63775 .62548 Mdot
.83201 .60913 Mdot
.26493 .44134 Mdot
.45326 .34948 Mdot
.4324 .70193 Mdot
.18859 .69624 Mdot
.31131 .46806 Mdot
.25661 .69206 Mdot
.50518 .64238 Mdot
.45821 .66501 Mdot
.63153 .60351 Mdot
.48838 .64247 Mdot
.61659 .56864 Mdot
.60457 .83854 Mdot
.21323 .48686 Mdot
.67862 .56882 Mdot
.6325 .60668 Mdot
.26091 .53073 Mdot
.47037 .24909 Mdot
.64962 .5863 Mdot
.46746 .67523 Mdot
.54249 .67564 Mdot
.41547 .56634 Mdot
.33707 .4484 Mdot
.37588 .26409 Mdot
.69826 .61301 Mdot
.36449 .47245 Mdot
.49032 .20464 Mdot
.71022 .60321 Mdot
.63879 .46893 Mdot
.62962 .42772 Mdot
.42816 .62523 Mdot
.41703 .36659 Mdot
.41566 .3516 Mdot
.49378 .68378 Mdot
.48398 .6134 Mdot
.66283 .54702 Mdot
.33265 .45975 Mdot
.6219 .4372 Mdot
.46833 .66474 Mdot
.25863 .51481 Mdot
.34705 .47137 Mdot
.64886 .55659 Mdot
.43907 .77051 Mdot
.29016 .45558 Mdot
.51341 .56575 Mdot
.44982 .60904 Mdot
.49214 .62832 Mdot
.4404 .55271 Mdot
.63905 .41446 Mdot
.36335 .25422 Mdot
.42005 .62646 Mdot
.20255 .5463 Mdot
.58405 .44167 Mdot
.50996 .57339 Mdot
.66763 .56154 Mdot
.6175 .35021 Mdot
.44255 .40664 Mdot
.46194 .51733 Mdot
.46433 .64683 Mdot
.69872 .29207 Mdot
.79878 .58627 Mdot
.4038 .37211 Mdot
.66991 .61145 Mdot
.32463 .46578 Mdot
.48235 .62466 Mdot
.50098 .75202 Mdot
.47499 .59446 Mdot
.31628 .43655 Mdot
.46293 .38555 Mdot
.62765 .42762 Mdot
.71814 .28613 Mdot
.41724 .3501 Mdot
.6469 .59613 Mdot
.2788 .22781 Mdot
.61767 .56087 Mdot
.6454 .61208 Mdot
.48847 .75019 Mdot
.636 .41871 Mdot
.2186 .73434 Mdot
.68192 .77175 Mdot
.41496 .60973 Mdot
.61784 .38069 Mdot
.65882 .58181 Mdot
.45008 .66623 Mdot
.6081 .56023 Mdot
.68716 .60124 Mdot
.45978 .67637 Mdot
.43529 .65374 Mdot
.70472 .33129 Mdot
.41439 .18679 Mdot
.32637 .46547 Mdot
.67759 .55413 Mdot
.56244 .51653 Mdot
.44132 .66309 Mdot
.457 .61387 Mdot
.54164 .35789 Mdot
.32904 .44835 Mdot
.75874 .42883 Mdot
.50558 .63862 Mdot
.21507 .46954 Mdot
.55628 .59477 Mdot
.67497 .54386 Mdot
.601 .39851 Mdot
.20682 .59426 Mdot
.6633 .41792 Mdot
.61591 .57446 Mdot
.32574 .4563 Mdot
.66388 .61777 Mdot
.24705 .53873 Mdot
.65285 .37797 Mdot
.66225 .59634 Mdot
.56318 .45254 Mdot
.63539 .39736 Mdot
.65109 .38672 Mdot
.49922 .74148 Mdot
.41366 .33376 Mdot
.34681 .49854 Mdot
.63777 .37208 Mdot
.58097 .53474 Mdot
.62942 .38278 Mdot
.72297 .71889 Mdot
.43623 .59503 Mdot
.35526 .54291 Mdot
.37979 .37477 Mdot
.4061 .68244 Mdot
.64951 .37707 Mdot
.29897 .45887 Mdot
.50783 .62517 Mdot
.65188 .56364 Mdot
.3372 .49044 Mdot
.62187 .34218 Mdot
.46783 .3537 Mdot
.66176 .55249 Mdot
.66715 .39083 Mdot
.67975 .58025 Mdot
.52344 .5277 Mdot
.77586 .67422 Mdot
.22674 .36532 Mdot
.47919 .5009 Mdot
.50863 .64862 Mdot
.42736 .22228 Mdot
.52759 .60255 Mdot
.48803 .61208 Mdot
.43269 .35576 Mdot
.34059 .53744 Mdot
.6438 .58026 Mdot
.70142 .25575 Mdot
.64562 .41607 Mdot
.19642 .58092 Mdot
.56533 .63015 Mdot
.5162 .64488 Mdot
.63543 .55024 Mdot
.61566 .56326 Mdot
.56327 .72267 Mdot
.442 .40806 Mdot
.51583 .59618 Mdot
.50323 .57958 Mdot
.49187 .67952 Mdot
.64766 .40147 Mdot
.25436 .41102 Mdot
.43725 .39598 Mdot
.80962 .62965 Mdot
.45667 .39076 Mdot
.32355 .52293 Mdot
.63747 .56148 Mdot
.34589 .46603 Mdot
.45497 .61433 Mdot
.70425 .55176 Mdot
.61265 .58124 Mdot
.31704 .44036 Mdot
.29729 .47175 Mdot
.56325 .33771 Mdot
.62762 .41997 Mdot
.51041 .6002 Mdot
.43626 .6114 Mdot
.48749 .64949 Mdot
.49323 .61983 Mdot
.63091 .43287 Mdot
.50444 .61358 Mdot
.62163 .35364 Mdot
.52139 .54237 Mdot
.24048 .44644 Mdot
.54747 .46189 Mdot
.76234 .56448 Mdot
.64346 .56457 Mdot
.5926 .52274 Mdot
.46977 .55355 Mdot
.41635 .81274 Mdot
.80314 .49467 Mdot
.41769 .61894 Mdot
.44479 .33522 Mdot
.38354 .68516 Mdot
.42648 .38345 Mdot
.87454 .46103 Mdot
.55732 .29034 Mdot
.45433 .17856 Mdot
.4328 .62373 Mdot
.52642 .3734 Mdot
.59896 .54133 Mdot
.53006 .61612 Mdot
.56681 .30922 Mdot
.75435 .54782 Mdot
.64187 .26834 Mdot
.30787 .45061 Mdot
.452 .64391 Mdot
.70826 .58649 Mdot
.44535 .6007 Mdot
.46267 .61004 Mdot
.50967 .62953 Mdot
.60919 .37004 Mdot
.51931 .6094 Mdot
.49851 .60933 Mdot
.29186 .396 Mdot
.29855 .64341 Mdot
.41336 .35059 Mdot
.77497 .64842 Mdot
.34852 .46983 Mdot
.6504 .54668 Mdot
.5977 .2083 Mdot
.62369 .41531 Mdot
.56911 .71686 Mdot
.49291 .62355 Mdot
.69508 .31787 Mdot
.63727 .34183 Mdot
.31361 .45908 Mdot
.44757 .40152 Mdot
.50474 .16727 Mdot
.44131 .35797 Mdot
.56811 .45327 Mdot
.44116 .37397 Mdot
.49706 .55456 Mdot
.66567 .5477 Mdot
.51059 .60673 Mdot
.6423 .37742 Mdot
.42436 .35802 Mdot
.30897 .57977 Mdot
.47099 .61929 Mdot
.4499 .36071 Mdot
.51029 .60606 Mdot
.41065 .53777 Mdot
.36337 .74384 Mdot
.48501 .3527 Mdot
.60639 .36162 Mdot
.64016 .39147 Mdot
.33605 .45253 Mdot
.65116 .5492 Mdot
.62366 .59516 Mdot
.62943 .40112 Mdot
.51557 .8147 Mdot
.45017 .58576 Mdot
.43702 .65937 Mdot
.1998 .57232 Mdot
.45924 .58937 Mdot
.26336 .58708 Mdot
.56926 .45944 Mdot
.64784 .56032 Mdot
.50249 .66927 Mdot
.50265 .64298 Mdot
.46087 .64918 Mdot
.495 .52942 Mdot
.4361 .38229 Mdot
.42713 .61762 Mdot
.29926 .47852 Mdot
.43865 .43875 Mdot
.46438 .67114 Mdot
.54012 .64195 Mdot
.62508 .59687 Mdot
.26529 .72831 Mdot
.61541 .42455 Mdot
.47886 .34436 Mdot
.43982 .34432 Mdot
.3859 .26311 Mdot
.67034 .49895 Mdot
.56512 .45787 Mdot
.82201 .60233 Mdot
.47297 .27089 Mdot
.32876 .4894 Mdot
.39546 .34373 Mdot
.59824 .4643 Mdot
.4669 .33999 Mdot
.62453 .4342 Mdot
.43204 .6 Mdot
.44178 .59114 Mdot
.40188 .82553 Mdot
.51248 .63483 Mdot
.32169 .46822 Mdot
.63484 .35461 Mdot
.65071 .56618 Mdot
.31541 .45896 Mdot
.60771 .40883 Mdot
.67488 .56829 Mdot
.42114 .61395 Mdot
.42219 .61416 Mdot
.63172 .5991 Mdot
.66294 .59818 Mdot
.44924 .61314 Mdot
.40383 .28953 Mdot
.65364 .60507 Mdot
.67022 .58984 Mdot
.43677 .39108 Mdot
.41885 .36901 Mdot
.53694 .59119 Mdot
.61818 .38371 Mdot
.50012 .61027 Mdot
.44154 .35173 Mdot
.33547 .45706 Mdot
.64239 .57735 Mdot
.50214 .65532 Mdot
.47663 .66659 Mdot
.3187 .48029 Mdot
.32099 .45181 Mdot
.30029 .46293 Mdot
.62141 .35803 Mdot
.48009 .65163 Mdot
.64211 .58806 Mdot
.62763 .42247 Mdot
.3281 .50477 Mdot
.32015 .44501 Mdot
.39784 .37727 Mdot
.47352 .58546 Mdot
.39838 .42259 Mdot
.15154 .64927 Mdot
.22009 .5652 Mdot
.41481 .39481 Mdot
.42333 .40448 Mdot
.30063 .61645 Mdot
.40116 .50071 Mdot
.62077 .40192 Mdot
.27975 .45279 Mdot
.24109 .49351 Mdot
.44493 .57971 Mdot
.42218 .65705 Mdot
.45071 .56679 Mdot
.29999 .47021 Mdot
.32052 .53218 Mdot
.62891 .54762 Mdot
.68943 .64199 Mdot
.34694 .47909 Mdot
.41706 .33809 Mdot
.39698 .35114 Mdot
.45861 .38992 Mdot
.42755 .60589 Mdot
.59042 .72898 Mdot
.62558 .50712 Mdot
.38813 .22061 Mdot
.64155 .36925 Mdot
.70789 .59559 Mdot
.82173 .46672 Mdot
.63484 .59816 Mdot
.4722 .39089 Mdot
.31975 .49146 Mdot
.67008 .59395 Mdot
.60312 .42247 Mdot
.63406 .37244 Mdot
.44578 .39013 Mdot
.45485 .38402 Mdot
.47634 .36004 Mdot
.66496 .61139 Mdot
.63558 .56144 Mdot
.46752 .64655 Mdot
.64086 .57309 Mdot
.36544 .8094 Mdot
.35658 .46179 Mdot
.47596 .4081 Mdot
.62059 .38912 Mdot
.67972 .57207 Mdot
.47264 .62165 Mdot
.39986 .51681 Mdot
.76215 .50884 Mdot
.31436 .49303 Mdot
.33444 .73338 Mdot
.87206 .4668 Mdot
.51003 .59817 Mdot
.64234 .40734 Mdot
.31277 .75335 Mdot
.46581 .62067 Mdot
.46763 .37197 Mdot
.44798 .2509 Mdot
.47787 .31207 Mdot
.48993 .58869 Mdot
.46114 .57153 Mdot
.59883 .4078 Mdot
.81539 .59881 Mdot
.46867 .64267 Mdot
.753 .43883 Mdot
.61528 .44661 Mdot
.44105 .39709 Mdot
.65788 .19877 Mdot
.28872 .31899 Mdot
.3447 .58241 Mdot
.4409 .39361 Mdot
.48646 .60045 Mdot
.42957 .38336 Mdot
.30521 .48882 Mdot
.47835 .37539 Mdot
.62895 .54627 Mdot
.40816 .37958 Mdot
.45232 .65714 Mdot
.65249 .58654 Mdot
.62124 .39693 Mdot
.21541 .63163 Mdot
.35429 .39519 Mdot
.44014 .37725 Mdot
.47911 .34039 Mdot
.50528 .66513 Mdot
.74574 .39627 Mdot
.48959 .69111 Mdot
.42867 .64079 Mdot
.65489 .39978 Mdot
.63831 .5513 Mdot
.60181 .38757 Mdot
.53525 .63294 Mdot
.27816 .30861 Mdot
.61155 .41379 Mdot
.6847 .29146 Mdot
.31917 .48781 Mdot
.48666 .44028 Mdot
.47782 .62015 Mdot
.62018 .37047 Mdot
.47949 .65031 Mdot
.63726 .54514 Mdot
.5315 .42572 Mdot
.62607 .27277 Mdot
.64625 .38655 Mdot
.7047 .28854 Mdot
.34751 .52015 Mdot
.51868 .68229 Mdot
.60473 .411 Mdot
.28344 .52736 Mdot
.45529 .33181 Mdot
.34315 .4802 Mdot
.29112 .47704 Mdot
.33741 .49273 Mdot
.46553 .69203 Mdot
.55088 .63731 Mdot
.31758 .5005 Mdot
.61016 .43483 Mdot
.29514 .45303 Mdot
.70309 .52686 Mdot
.68462 .25262 Mdot
.33401 .47808 Mdot
.45326 .63542 Mdot
.56222 .58908 Mdot
.30339 .63892 Mdot
.59558 .32707 Mdot
.47555 .17585 Mdot
.78742 .46293 Mdot
.46802 .59355 Mdot
.60549 .60715 Mdot
.68633 .56798 Mdot
.2887 .72985 Mdot
.24831 .58105 Mdot
.21076 .52276 Mdot
.63753 .60927 Mdot
.56748 .2618 Mdot
.65209 .55442 Mdot
.51169 .64281 Mdot
.44293 .66278 Mdot
.62385 .6069 Mdot
.2368 .4337 Mdot
.59801 .28128 Mdot
.75975 .32131 Mdot
.67718 .58514 Mdot
.6045 .39918 Mdot
.65232 .36756 Mdot
.65187 .38646 Mdot
.2643 .68217 Mdot
.62281 .56059 Mdot
.48421 .65748 Mdot
.43732 .34723 Mdot
.43089 .60805 Mdot
.6363 .40326 Mdot
.69945 .25267 Mdot
.62518 .57573 Mdot
.43784 .62668 Mdot
.37244 .63705 Mdot
.46398 .36983 Mdot
.32388 .48497 Mdot
.39516 .5604 Mdot
.21409 .52897 Mdot
.6496 .40435 Mdot
.60813 .59507 Mdot
.52312 .2857 Mdot
.67131 .26369 Mdot
.43041 .67748 Mdot
.51632 .58422 Mdot
.83086 .39707 Mdot
.2277 .48671 Mdot
.49219 .58205 Mdot
.47004 .3371 Mdot
.54775 .27068 Mdot
.48333 .66554 Mdot
.68382 .56241 Mdot
.28903 .46443 Mdot
.32491 .49505 Mdot
.5424 .60299 Mdot
.44035 .49648 Mdot
.52945 .40055 Mdot
.49842 .63122 Mdot
.51018 .56444 Mdot
.44157 .39607 Mdot
.46476 .2657 Mdot
.20233 .54059 Mdot
.32412 .4549 Mdot
.51003 .60786 Mdot
.54186 .21794 Mdot
.61898 .59829 Mdot
.40696 .38079 Mdot
.64376 .36679 Mdot
.46582 .53037 Mdot
.45022 .40041 Mdot
.48892 .66578 Mdot
.5101 .62099 Mdot
.62212 .36492 Mdot
.67361 .54308 Mdot
.30139 .47465 Mdot
.43377 .34564 Mdot
.31347 .45257 Mdot
.62925 .55617 Mdot
.63562 .57054 Mdot
.38286 .67448 Mdot
.39979 .63979 Mdot
.42969 .36871 Mdot
.52429 .65598 Mdot
.50751 .34414 Mdot
.84478 .56085 Mdot
.6646 .38903 Mdot
.50541 .58996 Mdot
.66021 .53659 Mdot
.64735 .39288 Mdot
.44681 .66203 Mdot
.82003 .37632 Mdot
.44259 .66467 Mdot
.58994 .44484 Mdot
.21957 .36833 Mdot
.30485 .45641 Mdot
.68593 .64083 Mdot
.76566 .38578 Mdot
.4562 .59298 Mdot
.45124 .3403 Mdot
.47358 .55787 Mdot
.6172 .41115 Mdot
.6372 .56371 Mdot
.83973 .6008 Mdot
.63272 .38238 Mdot
.44229 .60925 Mdot
.31553 .46049 Mdot
.61174 .57232 Mdot
.26649 .48135 Mdot
.26895 .43338 Mdot
.53619 .66308 Mdot
.5212 .66117 Mdot
.4991 .62106 Mdot
.31674 .26889 Mdot
.47967 .34693 Mdot
.66814 .58172 Mdot
.64342 .40711 Mdot
.6274 .40297 Mdot
.44395 .3881 Mdot
.69622 .35514 Mdot
.49042 .4386 Mdot
.15263 .61794 Mdot
.42376 .36978 Mdot
.34455 .49038 Mdot
.75274 .4191 Mdot
.44472 .33851 Mdot
.45172 .36469 Mdot
.43453 .39157 Mdot
.6587 .44035 Mdot
.67207 .5689 Mdot
.48466 .66806 Mdot
.68123 .55385 Mdot
.48899 .60112 Mdot
.58535 .44129 Mdot
.64593 .38195 Mdot
.62603 .5695 Mdot
.82205 .39886 Mdot
.59792 .77856 Mdot
.45895 .62683 Mdot
.8244 .46948 Mdot
.40695 .61504 Mdot
.28417 .59138 Mdot
.4117 .59423 Mdot
.44743 .38154 Mdot
.48003 .70151 Mdot
.4891 .68163 Mdot
.25244 .69909 Mdot
.6186 .38978 Mdot
.43342 .33283 Mdot
.42176 .59159 Mdot
.5294 .57174 Mdot
.64768 .6143 Mdot
.67118 .59228 Mdot
.30194 .4904 Mdot
.34645 .71207 Mdot
.61877 .39753 Mdot
.68341 .76145 Mdot
.46259 .59592 Mdot
.24487 .39548 Mdot
.60402 .65343 Mdot
.44305 .6597 Mdot
.77744 .39431 Mdot
.58559 .72377 Mdot
.48103 .62318 Mdot
.54422 .49963 Mdot
.62484 .37281 Mdot
.2648 .32091 Mdot
.45393 .67128 Mdot
.4673 .36521 Mdot
.6405 .5574 Mdot
.61933 .55223 Mdot
.31228 .49758 Mdot
.45612 .82569 Mdot
.60504 .38051 Mdot
.63071 .56619 Mdot
.47238 .61336 Mdot
.64092 .41475 Mdot
.41941 .35408 Mdot
.51786 .63845 Mdot
.25211 .59375 Mdot
.64617 .5707 Mdot
.48664 .67654 Mdot
.73732 .44585 Mdot
.32489 .62958 Mdot
.26625 .27001 Mdot
.64443 .40756 Mdot
.32821 .44987 Mdot
.47709 .559 Mdot
.50201 .80626 Mdot
.4161 .65889 Mdot
.36374 .53913 Mdot
.7116 .53169 Mdot
.322 .44805 Mdot
.45064 .62579 Mdot
.47636 .66089 Mdot
.39106 .45551 Mdot
.32955 .45609 Mdot
.43301 .61633 Mdot
.54328 .55907 Mdot
.67293 .57262 Mdot
.48679 .37251 Mdot
.65642 .56717 Mdot
.45857 .63452 Mdot
.39874 .62521 Mdot
.64151 .6042 Mdot
.84618 .50623 Mdot
.35323 .5001 Mdot
.61604 .42326 Mdot
.41048 .64519 Mdot
.41986 .6358 Mdot
.16451 .4557 Mdot
.40315 .35876 Mdot
.49354 .23892 Mdot
.28961 .3583 Mdot
.50573 .21091 Mdot
.2869 .32062 Mdot
.36551 .19335 Mdot
.2217 .47478 Mdot
.5222 .61948 Mdot
.62283 .63397 Mdot
.60888 .50196 Mdot
.64464 .37002 Mdot
.73066 .68212 Mdot
.46697 .5927 Mdot
.46499 .60882 Mdot
.40808 .38601 Mdot
.67994 .29974 Mdot
.20943 .5225 Mdot
.4076 .50889 Mdot
.30274 .47592 Mdot
.67776 .55524 Mdot
.4785 .67173 Mdot
.54971 .48806 Mdot
.41226 .35121 Mdot
.24141 .40274 Mdot
.43966 .62762 Mdot
.4089 .80434 Mdot
.74593 .51064 Mdot
.63434 .41702 Mdot
.44251 .34243 Mdot
.21735 .51064 Mdot
.47733 .58591 Mdot
.64363 .36532 Mdot
.46952 .63591 Mdot
.42315 .29159 Mdot
.53382 .64088 Mdot
.338 .47792 Mdot
.5063 .6428 Mdot
.32461 .52419 Mdot
.23744 .26291 Mdot
.28861 .44048 Mdot
.60819 .56321 Mdot
.49429 .39023 Mdot
.4336 .37883 Mdot
.66443 .59662 Mdot
.43306 .3758 Mdot
.57331 .6973 Mdot
.68055 .6819 Mdot
.31205 .48592 Mdot
.53522 .57811 Mdot
.33132 .47585 Mdot
.40256 .37068 Mdot
.47517 .59006 Mdot
.86223 .51934 Mdot
.42799 .36051 Mdot
.20123 .40964 Mdot
.62848 .38602 Mdot
.41519 .34105 Mdot
.45007 .66931 Mdot
.52487 .29439 Mdot
.41709 .34903 Mdot
.6338 .28038 Mdot
.46182 .64897 Mdot
.64218 .56759 Mdot
.48442 .66367 Mdot
.41142 .62166 Mdot
.47191 .32755 Mdot
.49553 .59959 Mdot
.60769 .40824 Mdot
.66 .60726 Mdot
.56333 .16732 Mdot
.74914 .55598 Mdot
.44056 .60166 Mdot
.47033 .61517 Mdot
.67589 .61356 Mdot
.42447 .6249 Mdot
.63078 .43275 Mdot
.4522 .89913 Mdot
.31973 .48773 Mdot
.46755 .33022 Mdot
.28679 .31909 Mdot
.4197 .61359 Mdot
.50644 .61986 Mdot
.80669 .35329 Mdot
.26409 .33316 Mdot
.60568 .4102 Mdot
.47891 .68379 Mdot
.41877 .35111 Mdot
.31748 .46233 Mdot
.61523 .43991 Mdot
.49139 .62956 Mdot
.45345 .61786 Mdot
.3338 .45263 Mdot
.48143 .72342 Mdot
.24201 .64276 Mdot
.62705 .36383 Mdot
.44354 .7006 Mdot
.49181 .40325 Mdot
.4644 .58164 Mdot
.282 .70399 Mdot
.66276 .59481 Mdot
.65052 .4054 Mdot
.43196 .22885 Mdot
.49272 .58506 Mdot
.60288 .39296 Mdot
.61811 .39625 Mdot
.47108 .68376 Mdot
.66376 .53592 Mdot
.67904 .60319 Mdot
.68082 .5783 Mdot
.40169 .84036 Mdot
.33073 .58724 Mdot
.47627 .36019 Mdot
.62506 .37225 Mdot
.48694 .35524 Mdot
.34944 .44929 Mdot
.5835 .46882 Mdot
.48335 .34661 Mdot
.68604 .58402 Mdot
.4896 .39423 Mdot
.46923 .65752 Mdot
.62136 .39864 Mdot
.47087 .3433 Mdot
.41756 .6054 Mdot
.73188 .37705 Mdot
.65074 .32934 Mdot
.30672 .44617 Mdot
.28813 .47109 Mdot
.45814 .6684 Mdot
.44717 .40685 Mdot
.45138 .61223 Mdot
.6541 .41323 Mdot
.7438 .40071 Mdot
.41386 .65072 Mdot
.44004 .379 Mdot
.62979 .618 Mdot
.21557 .52174 Mdot
.48732 .69508 Mdot
.45291 .6343 Mdot
.49079 .59849 Mdot
.46998 .63618 Mdot
.63736 .25664 Mdot
.65873 .41622 Mdot
.76081 .56256 Mdot
.3452 .26247 Mdot
.62612 .58212 Mdot
.69848 .57699 Mdot
.21772 .57164 Mdot
.67135 .45624 Mdot
.61902 .38127 Mdot
.48974 .61472 Mdot
.68877 .48769 Mdot
.69147 .2394 Mdot
.85284 .43682 Mdot
.38105 .45231 Mdot
.40788 .352 Mdot
.61253 .60144 Mdot
.42969 .3413 Mdot
.48296 .59679 Mdot
.47429 .56034 Mdot
.35024 .19369 Mdot
.60589 .44069 Mdot
.31281 .48783 Mdot
.49143 .60302 Mdot
.33397 .59098 Mdot
.4451 .35099 Mdot
.4467 .32444 Mdot
.42766 .62987 Mdot
.68739 .55249 Mdot
.1913 .36105 Mdot
.63991 .4131 Mdot
.78453 .45426 Mdot
.60538 .53674 Mdot
.77812 .49278 Mdot
.63772 .40616 Mdot
.32672 .42031 Mdot
.41469 .39349 Mdot
.53782 .70056 Mdot
.62431 .58382 Mdot
.33615 .49043 Mdot
.50871 .57403 Mdot
.62493 .59965 Mdot
.44298 .39868 Mdot
.63902 .56552 Mdot
.50982 .63208 Mdot
.62893 .44559 Mdot
.45377 .34787 Mdot
.59241 .41225 Mdot
.6785 .54208 Mdot
.32291 .456 Mdot
.43769 .47807 Mdot
.68535 .72584 Mdot
.58337 .72147 Mdot
.42718 .61354 Mdot
.55913 .4894 Mdot
.48598 .65512 Mdot
.69644 .58945 Mdot
.47137 .62582 Mdot
.71591 .54853 Mdot
.44986 .34118 Mdot
.44214 .66849 Mdot
.49829 .6273 Mdot
.75317 .65326 Mdot
.43837 .63626 Mdot
.52647 .63224 Mdot
.48406 .62221 Mdot
.67654 .52876 Mdot
.54504 .58393 Mdot
.67025 .56181 Mdot
.31879 .41105 Mdot
.45276 .36739 Mdot
.29073 .46297 Mdot
.3505 .4656 Mdot
.34713 .54666 Mdot
.37415 .2945 Mdot
.68193 .30958 Mdot
.65895 .57065 Mdot
.61052 .40247 Mdot
.47218 .62995 Mdot
.37007 .21289 Mdot
.51582 .35252 Mdot
.41213 .36477 Mdot
.74965 .55488 Mdot
.42489 .69465 Mdot
.28138 .28618 Mdot
.50269 .67203 Mdot
.41859 .83378 Mdot
.40025 .6506 Mdot
.53306 .63994 Mdot
.4833 .33969 Mdot
.3549 .45138 Mdot
.42456 .63778 Mdot
.64301 .61382 Mdot
.34232 .47451 Mdot
.59111 .62986 Mdot
.42048 .4318 Mdot
.34202 .41342 Mdot
.7306 .65896 Mdot
.47546 .6472 Mdot
.4553 .34866 Mdot
.66266 .5519 Mdot
.20298 .5345 Mdot
.62684 .42343 Mdot
.58779 .42048 Mdot
.57287 .51719 Mdot
.83452 .47344 Mdot
.34752 .47176 Mdot
.49104 .7355 Mdot
.45494 .65847 Mdot
.37349 .37037 Mdot
.42045 .65884 Mdot
.69652 .24985 Mdot
.35119 .48044 Mdot
.68516 .59329 Mdot
.60572 .39708 Mdot
.68545 .56184 Mdot
.57507 .7316 Mdot
.42112 .31715 Mdot
.52112 .45955 Mdot
.44383 .35925 Mdot
.45733 .44263 Mdot
.65988 .58488 Mdot
.50777 .6043 Mdot
.15014 .61614 Mdot
.66802 .59173 Mdot
.61027 .58126 Mdot
.79714 .63368 Mdot
.85286 .54636 Mdot
.45951 .70644 Mdot
.64226 .60724 Mdot
.4453 .36426 Mdot
.3278 .46342 Mdot
.4958 .65807 Mdot
.47052 .65177 Mdot
.62704 .6001 Mdot
.46594 .32679 Mdot
.52481 .78322 Mdot
.4537 .38334 Mdot
.67568 .57068 Mdot
.4595 .36721 Mdot
.51277 .29094 Mdot
.45814 .33559 Mdot
.42027 .63467 Mdot
.47168 .62689 Mdot
.34791 .29493 Mdot
.63643 .57032 Mdot
.49833 .63351 Mdot
.50969 .65879 Mdot
.64465 .58664 Mdot
.27261 .44051 Mdot
.52969 .77662 Mdot
.45201 .58913 Mdot
.4503 .64636 Mdot
.32218 .44857 Mdot
.59429 .48209 Mdot
.40224 .75334 Mdot
.50763 .62561 Mdot
.35309 .48746 Mdot
.64989 .61285 Mdot
.44401 .61769 Mdot
.63508 .21624 Mdot
.54994 .26971 Mdot
.49849 .58896 Mdot
.45243 .33186 Mdot
.49118 .68044 Mdot
.2534 .28608 Mdot
.42825 .64112 Mdot
.65174 .58184 Mdot
.63212 .55786 Mdot
.6911 .75496 Mdot
.65124 .59477 Mdot
.41853 .37049 Mdot
.63575 .39998 Mdot
.70387 .27225 Mdot
.42 .35328 Mdot
.42277 .67667 Mdot
.69369 .76526 Mdot
.51824 .6262 Mdot
.41531 .62284 Mdot
.20814 .35609 Mdot
.42542 .34976 Mdot
.63441 .54897 Mdot
.40901 .48606 Mdot
.40459 .59636 Mdot
.65133 .40099 Mdot
.51577 .57449 Mdot
.44373 .58518 Mdot
.21529 .37589 Mdot
.58546 .24367 Mdot
.65822 .38848 Mdot
.51812 .59613 Mdot
.50763 .62459 Mdot
.4299 .31975 Mdot
.47394 .61754 Mdot
.33206 .46521 Mdot
.62653 .55573 Mdot
.44485 .33668 Mdot
.31472 .47817 Mdot
.46227 .59167 Mdot
.30014 .46754 Mdot
.4719 .35091 Mdot
.65339 .37709 Mdot
.48193 .59224 Mdot
.33495 .44734 Mdot
.30112 .47028 Mdot
.48976 .65172 Mdot
.63964 .56197 Mdot
.40168 .65677 Mdot
.43529 .62853 Mdot
.50383 .65348 Mdot
.62257 .59301 Mdot
.80654 .29962 Mdot
.43322 .65712 Mdot
.3701 .51033 Mdot
.61321 .57724 Mdot
.41319 .44168 Mdot
.4347 .33608 Mdot
.43924 .58944 Mdot
.65596 .38334 Mdot
.62662 .36797 Mdot
.44738 .39757 Mdot
.60758 .57978 Mdot
.29454 .34497 Mdot
.66443 .61894 Mdot
.40876 .59312 Mdot
.49805 .58035 Mdot
.60357 .80599 Mdot
.45271 .17539 Mdot
.65735 .5439 Mdot
.39633 .40874 Mdot
.42593 .50261 Mdot
.61554 .37683 Mdot
.41918 .3358 Mdot
.61019 .59949 Mdot
.61786 .56505 Mdot
.64932 .5616 Mdot
.3282 .49362 Mdot
.35173 .29412 Mdot
.65433 .53952 Mdot
.69538 .56662 Mdot
.46337 .6518 Mdot
.50663 .62423 Mdot
.22622 .528 Mdot
.27504 .6437 Mdot
.29684 .45987 Mdot
.45434 .39023 Mdot
.34823 .83024 Mdot
.65133 .41752 Mdot
.76748 .63053 Mdot
.41346 .63921 Mdot
.14237 .65633 Mdot
.46443 .6725 Mdot
.47488 .61307 Mdot
.65744 .608 Mdot
.32088 .44419 Mdot
.33028 .48177 Mdot
.66911 .58372 Mdot
.70072 .58211 Mdot
.33271 .46619 Mdot
.79869 .43753 Mdot
.65898 .22108 Mdot
.42045 .31261 Mdot
.63775 .58408 Mdot
.68855 .7146 Mdot
.63201 .36065 Mdot
.60917 .62318 Mdot
.64588 .42875 Mdot
.44949 .35644 Mdot
.44153 .40462 Mdot
.64929 .39828 Mdot
.46224 .64746 Mdot
.47873 .3564 Mdot
.52007 .61425 Mdot
.7951 .5039 Mdot
.58723 .75599 Mdot
.31244 .30846 Mdot
.54626 .62547 Mdot
.32631 .41693 Mdot
.68256 .34719 Mdot
.44942 .60306 Mdot
.54903 .2058 Mdot
.30682 .48335 Mdot
.58528 .60871 Mdot
.64969 .41419 Mdot
.23659 .29323 Mdot
.48577 .59003 Mdot
.64933 .5798 Mdot
.61587 .39081 Mdot
.44918 .52518 Mdot
.75053 .43163 Mdot
.49008 .59988 Mdot
.16386 .66006 Mdot
.65901 .52798 Mdot
.45076 .33743 Mdot
.48485 .81371 Mdot
.66444 .54313 Mdot
.37979 .46234 Mdot
.37977 .25318 Mdot
.82978 .42556 Mdot
.65327 .54656 Mdot
.40627 .34521 Mdot
.68238 .57038 Mdot
.32562 .45678 Mdot
.59868 .59533 Mdot
.44511 .34621 Mdot
.44257 .62987 Mdot
.44386 .38525 Mdot
.29711 .48366 Mdot
.24895 .64727 Mdot
.65758 .38477 Mdot
.43605 .33246 Mdot
.64195 .38261 Mdot
.33095 .66254 Mdot
.31084 .27807 Mdot
.62522 .42778 Mdot
.44389 .77597 Mdot
.48365 .57863 Mdot
.67234 .54374 Mdot
.43814 .3876 Mdot
.42526 .25271 Mdot
.43103 .48336 Mdot
.6282 .59072 Mdot
.46885 .37571 Mdot
.58168 .51154 Mdot
.45921 .79185 Mdot
.51459 .67441 Mdot
.3346 .68917 Mdot
.63884 .58725 Mdot
.40072 .35855 Mdot
.19968 .5776 Mdot
.68923 .57838 Mdot
.42471 .37299 Mdot
.60455 .39545 Mdot
.62971 .40612 Mdot
.42945 .62008 Mdot
.59589 .43233 Mdot
.46893 .38167 Mdot
.67522 .33967 Mdot
.62636 .60589 Mdot
.47428 .52447 Mdot
.35002 .45534 Mdot
.45246 .37481 Mdot
.51299 .63491 Mdot
.59068 .58141 Mdot
.52118 .27412 Mdot
.54657 .78833 Mdot
.24429 .71409 Mdot
.44429 .38799 Mdot
.62078 .56382 Mdot
.64703 .57776 Mdot
.47625 .69674 Mdot
.47271 .50063 Mdot
.30068 .33817 Mdot
.37335 .57515 Mdot
.39008 .53221 Mdot
.48264 .3807 Mdot
.48151 .3189 Mdot
.42648 .58679 Mdot
.47663 .64198 Mdot
.61206 .38279 Mdot
.44412 .63348 Mdot
.66378 .60398 Mdot
.42692 .6231 Mdot
.64295 .40416 Mdot
.43839 .35799 Mdot
.47618 .59222 Mdot
.30376 .45619 Mdot
.64316 .35979 Mdot
.59825 .41363 Mdot
.44645 .37769 Mdot
.62308 .59792 Mdot
.26332 .45415 Mdot
.45524 .38418 Mdot
.47466 .64698 Mdot
.62544 .47259 Mdot
.50954 .64869 Mdot
.6942 .6322 Mdot
.68999 .57877 Mdot
.43819 .33944 Mdot
.63225 .60961 Mdot
.63609 .37789 Mdot
.35476 .25811 Mdot
.46308 .631 Mdot
.42251 .36724 Mdot
.43794 .27269 Mdot
.58205 .64585 Mdot
.70254 .5948 Mdot
.6782 .3276 Mdot
.69863 .58224 Mdot
.43589 .39843 Mdot
.75793 .67749 Mdot
.34484 .48029 Mdot
.41174 .36292 Mdot
.52691 .17066 Mdot
.43221 .3683 Mdot
.43681 .64372 Mdot
.45963 .66762 Mdot
.44942 .33618 Mdot
.33665 .45255 Mdot
.20963 .49873 Mdot
.48818 .37988 Mdot
.63858 .54831 Mdot
.80696 .52104 Mdot
.18676 .62713 Mdot
.618 .45723 Mdot
.60972 .39078 Mdot
.39539 .6185 Mdot
.53002 .64028 Mdot
.63486 .436 Mdot
.59633 .41387 Mdot
.3191 .49625 Mdot
.42996 .38794 Mdot
.67466 .52593 Mdot
.60512 .36837 Mdot
.39278 .58955 Mdot
.36619 .30058 Mdot
.50082 .68808 Mdot
.61493 .52559 Mdot
.42119 .65641 Mdot
.3733 .54086 Mdot
.64369 .40536 Mdot
.49126 .67205 Mdot
.49052 .686 Mdot
.6556 .39304 Mdot
.33069 .46302 Mdot
.69083 .41076 Mdot
.46146 .35963 Mdot
.69536 .22055 Mdot
.52062 .65509 Mdot
.43537 .64553 Mdot
.64365 .37099 Mdot
.29437 .38081 Mdot
.62358 .57538 Mdot
.69084 .57077 Mdot
.47808 .34448 Mdot
.4548 .48115 Mdot
.44149 .5904 Mdot
.44196 .61354 Mdot
.46226 .35107 Mdot
.41862 .33837 Mdot
.62842 .31259 Mdot
.46833 .66327 Mdot
.62061 .38569 Mdot
.30385 .5196 Mdot
.64474 .40353 Mdot
.51111 .64308 Mdot
.43893 .65084 Mdot
.42056 .63345 Mdot
.51254 .634 Mdot
.60384 .43025 Mdot
.48393 .67179 Mdot
.55954 .59052 Mdot
.62031 .57617 Mdot
.49682 .60899 Mdot
.38784 .53587 Mdot
.45041 .63892 Mdot
.32908 .46434 Mdot
.42987 .75632 Mdot
.48499 .59024 Mdot
.43561 .59525 Mdot
.4971 .3583 Mdot
.45578 .623 Mdot
.65261 .41618 Mdot
.63306 .57647 Mdot
.62645 .37181 Mdot
.63219 .36545 Mdot
.45985 .39628 Mdot
.31687 .49993 Mdot
.42164 .60895 Mdot
.31418 .49201 Mdot
.42711 .67746 Mdot
.4947 .58515 Mdot
.36577 .26442 Mdot
.43093 .83801 Mdot
.2527 .66824 Mdot
.46325 .63278 Mdot
.42582 .35413 Mdot
.43524 .33705 Mdot
.57142 .63638 Mdot
.50867 .67981 Mdot
.62415 .43701 Mdot
.62272 .36949 Mdot
.2578 .5986 Mdot
.23404 .35505 Mdot
.32961 .464 Mdot
.56448 .47728 Mdot
.5139 .59366 Mdot
.50603 .65982 Mdot
.51954 .63782 Mdot
.48599 .35582 Mdot
.38354 .51749 Mdot
.4128 .36054 Mdot
.75553 .51755 Mdot
.64909 .38956 Mdot
.48969 .59354 Mdot
.67642 .50688 Mdot
.67615 .59002 Mdot
.63367 .57584 Mdot
.59952 .41424 Mdot
.50205 .34663 Mdot
.22368 .55857 Mdot
.86482 .45966 Mdot
.63732 .53207 Mdot
.30145 .44666 Mdot
.4482 .60052 Mdot
.43812 .36402 Mdot
.68327 .57568 Mdot
.29603 .45317 Mdot
.50761 .60067 Mdot
.35292 .2931 Mdot
.4642 .6381 Mdot
.6148 .50259 Mdot
.64811 .55567 Mdot
.68861 .24423 Mdot
.61114 .56408 Mdot
.64476 .3598 Mdot
.64602 .41713 Mdot
.44911 .66245 Mdot
.55019 .81973 Mdot
.68409 .55546 Mdot
.67039 .42122 Mdot
.34521 .48937 Mdot
.53442 .28266 Mdot
.33041 .45902 Mdot
.44938 .33888 Mdot
.34425 .47322 Mdot
.44667 .34408 Mdot
.25451 .62329 Mdot
.71328 .55228 Mdot
.31454 .48287 Mdot
.4114 .29392 Mdot
.51784 .67502 Mdot
.30047 .4539 Mdot
.42465 .57655 Mdot
.67857 .63986 Mdot
.46486 .35453 Mdot
.34964 .47428 Mdot
.50878 .60724 Mdot
.34388 .20962 Mdot
.60784 .41492 Mdot
.62841 .43627 Mdot
.41519 .58597 Mdot
.47209 .39004 Mdot
.63257 .6121 Mdot
.65152 .24748 Mdot
.64946 .35634 Mdot
.44024 .66069 Mdot
.4249 .63401 Mdot
.6979 .5748 Mdot
.73325 .55539 Mdot
.44533 .65844 Mdot
.37767 .6535 Mdot
.4656 .66452 Mdot
.6015 .41111 Mdot
.68359 .55987 Mdot
.64121 .57701 Mdot
.47211 .37139 Mdot
.65325 .6034 Mdot
.55023 .66286 Mdot
.69524 .50341 Mdot
.39569 .67525 Mdot
.6349 .38275 Mdot
.73492 .51469 Mdot
.75642 .52134 Mdot
.47508 .17808 Mdot
.69692 .56215 Mdot
.4259 .66258 Mdot
.61877 .59856 Mdot
.32012 .46161 Mdot
.64379 .56872 Mdot
.61426 .60249 Mdot
.45121 .6088 Mdot
.48636 .60074 Mdot
.43499 .35029 Mdot
.45609 .49965 Mdot
.61735 .59027 Mdot
.46998 .67168 Mdot
.53123 .63199 Mdot
.5219 .62908 Mdot
.54304 .40232 Mdot
.66792 .54608 Mdot
.81619 .58083 Mdot
.28074 .53881 Mdot
.61805 .59178 Mdot
.20025 .33801 Mdot
.46097 .26288 Mdot
.40794 .39294 Mdot
.59935 .369 Mdot
.47119 .66442 Mdot
.42096 .34111 Mdot
.48259 .59626 Mdot
.61411 .5254 Mdot
.45779 .61484 Mdot
.3349 .46619 Mdot
.52263 .6213 Mdot
.44353 .40166 Mdot
.4509 .38609 Mdot
.4308 .6511 Mdot
.47293 .59456 Mdot
.23878 .62421 Mdot
.70193 .56087 Mdot
.63081 .57012 Mdot
.2837 .36156 Mdot
.30623 .47139 Mdot
.65072 .40346 Mdot
.47806 .62239 Mdot
.47025 .38799 Mdot
.44833 .38688 Mdot
.67094 .54569 Mdot
.46748 .37001 Mdot
.63953 .41248 Mdot
.46536 .62734 Mdot
.63445 .43567 Mdot
.32775 .49449 Mdot
.67666 .55319 Mdot
.4938 .6045 Mdot
.46295 .65169 Mdot
.63236 .55757 Mdot
.42557 .59229 Mdot
.32437 .44931 Mdot
.43212 .37093 Mdot
.66198 .54843 Mdot
.63422 .40159 Mdot
.44667 .34034 Mdot
.49916 .65968 Mdot
.30667 .79294 Mdot
.43976 .64463 Mdot
.47859 .66516 Mdot
.51792 .16362 Mdot
.51989 .60722 Mdot
.44126 .38873 Mdot
.68741 .58884 Mdot
.54621 .61722 Mdot
.33233 .55119 Mdot
.84687 .37089 Mdot
.41301 .36669 Mdot
.44428 .60294 Mdot
.3937 .19463 Mdot
.43824 .61401 Mdot
.61664 .7915 Mdot
.39745 .32099 Mdot
.44033 .45499 Mdot
.40467 .6352 Mdot
.62392 .41458 Mdot
.43252 .35004 Mdot
.45334 .34186 Mdot
.79821 .56549 Mdot
.44765 .61039 Mdot
.59374 .49858 Mdot
.5024 .60335 Mdot
.63445 .40727 Mdot
.25253 .56925 Mdot
.44766 .38864 Mdot
.27598 .72326 Mdot
.48304 .65663 Mdot
.6266 .54888 Mdot
.48694 .39786 Mdot
.51724 .31859 Mdot
.50232 .65439 Mdot
.3045 .48556 Mdot
.61681 .35869 Mdot
.53872 .61658 Mdot
.63582 .38825 Mdot
.50591 .65086 Mdot
.38579 .68541 Mdot
.48599 .82166 Mdot
.64425 .56139 Mdot
.60629 .39415 Mdot
.61884 .46724 Mdot
.46652 .67733 Mdot
.65566 .54708 Mdot
.62456 .5854 Mdot
.31225 .49335 Mdot
.54091 .44816 Mdot
.72633 .43777 Mdot
.61924 .76239 Mdot
.80809 .54408 Mdot
.49741 .38215 Mdot
.60789 .27114 Mdot
.4989 .64885 Mdot
.25255 .38363 Mdot
.65714 .40113 Mdot
.43577 .63858 Mdot
.57013 .67294 Mdot
.67498 .58409 Mdot
.44992 .65046 Mdot
.3317 .47383 Mdot
.26007 .39781 Mdot
.24518 .40497 Mdot
.38872 .23953 Mdot
.44546 .35881 Mdot
.47685 .55981 Mdot
.40782 .70698 Mdot
.47145 .33396 Mdot
.44955 .57964 Mdot
.429 .37593 Mdot
.81438 .45492 Mdot
.30362 .44843 Mdot
.64917 .54442 Mdot
.49382 .28955 Mdot
.43081 .59596 Mdot
.49735 .57883 Mdot
.28866 .47904 Mdot
.48091 .64146 Mdot
.44598 .82119 Mdot
.48972 .29657 Mdot
.47382 .34448 Mdot
.64805 .56157 Mdot
.42802 .60474 Mdot
.55261 .45341 Mdot
.43605 .62482 Mdot
.65626 .70616 Mdot
.43326 .59835 Mdot
.73819 .43132 Mdot
.64009 .5581 Mdot
.6384 .38649 Mdot
.46289 .67892 Mdot
.46434 .61228 Mdot
.2841 .51864 Mdot
.39911 .64526 Mdot
.48115 .67493 Mdot
.66347 .61504 Mdot
.68519 .5766 Mdot
.6702 .56326 Mdot
.41178 .38555 Mdot
.22368 .3661 Mdot
.62602 .37871 Mdot
.55225 .59904 Mdot
.59898 .38079 Mdot
.52557 .8002 Mdot
.30008 .44843 Mdot
.40747 .21067 Mdot
.49213 .62395 Mdot
.66629 .57038 Mdot
.55366 .22504 Mdot
.66356 .61177 Mdot
.54232 .47964 Mdot
.61914 .39778 Mdot
.66939 .58787 Mdot
.47127 .61088 Mdot
.42762 .49351 Mdot
.34294 .23216 Mdot
.6352 .37229 Mdot
.429 .68147 Mdot
.40377 .36001 Mdot
.31556 .2964 Mdot
.285 .77042 Mdot
.60639 .41376 Mdot
.59705 .4491 Mdot
.447 .60896 Mdot
.67812 .59038 Mdot
.62867 .41556 Mdot
.61527 .42555 Mdot
.46899 .36811 Mdot
.48822 .60354 Mdot
.49025 .60793 Mdot
.42792 .39744 Mdot
.63142 .36918 Mdot
.40456 .61416 Mdot
.53364 .64283 Mdot
.32614 .2007 Mdot
.53425 .51837 Mdot
.71849 .22818 Mdot
.54884 .66154 Mdot
.5469 .7014 Mdot
.67056 .25139 Mdot
.61578 .56896 Mdot
.48128 .58718 Mdot
.52994 .59342 Mdot
.46762 .38296 Mdot
.45278 .63069 Mdot
.39201 .36111 Mdot
.61379 .38828 Mdot
.22419 .3156 Mdot
.72249 .48818 Mdot
.81546 .42852 Mdot
.45143 .629 Mdot
.73663 .58214 Mdot
.31808 .47188 Mdot
.66088 .41545 Mdot
.67516 .56027 Mdot
.51254 .62329 Mdot
.23909 .62688 Mdot
.41216 .36133 Mdot
.63867 .5999 Mdot
.20543 .53779 Mdot
.33535 .41926 Mdot
.51065 .64158 Mdot
.40688 .36878 Mdot
.56672 .21816 Mdot
.41053 .56093 Mdot
.66466 .37679 Mdot
.33361 .46373 Mdot
.43179 .3467 Mdot
.62713 .36607 Mdot
.62555 .53348 Mdot
.66099 .5919 Mdot
.61449 .60849 Mdot
.29801 .70898 Mdot
.46244 .32982 Mdot
.31908 .47588 Mdot
.24796 .34374 Mdot
.22925 .40946 Mdot
.33524 .46817 Mdot
.43782 .40451 Mdot
.68446 .57602 Mdot
.66919 .57918 Mdot
.63302 .57712 Mdot
.25134 .68563 Mdot
.61405 .56509 Mdot
.77727 .60801 Mdot
.51834 .62124 Mdot
.38698 .67273 Mdot
.44226 .60679 Mdot
.628 .43796 Mdot
.6453 .55212 Mdot
.43642 .47303 Mdot
.4661 .68898 Mdot
.33908 .25035 Mdot
.43132 .63153 Mdot
.64377 .43742 Mdot
.45745 .65539 Mdot
.74014 .65999 Mdot
.6154 .59389 Mdot
.45918 .63245 Mdot
.65827 .41148 Mdot
.30621 .46355 Mdot
.69186 .60983 Mdot
.49077 .59883 Mdot
.69117 .32163 Mdot
.52121 .61296 Mdot
.79798 .40437 Mdot
.50054 .52533 Mdot
.30173 .44659 Mdot
.57405 .54587 Mdot
.41831 .33231 Mdot
.39206 .68295 Mdot
.41957 .57174 Mdot
.64105 .37736 Mdot
.49797 .27715 Mdot
.45127 .36703 Mdot
.38339 .46176 Mdot
.52155 .57442 Mdot
.29239 .47607 Mdot
.70402 .57305 Mdot
.63035 .44043 Mdot
.46499 .57478 Mdot
.48597 .69208 Mdot
.78347 .53914 Mdot
.52462 .57052 Mdot
.42531 .62508 Mdot
.28588 .46314 Mdot
.77126 .59444 Mdot
.45399 .64177 Mdot
.54874 .47684 Mdot
.60029 .58951 Mdot
.40168 .61913 Mdot
.77406 .62724 Mdot
.45886 .66831 Mdot
.65225 .59911 Mdot
.70766 .5927 Mdot
.6892 .43812 Mdot
.33313 .49875 Mdot
.43956 .58991 Mdot
.69579 .7509 Mdot
.48089 .65308 Mdot
.62343 .38525 Mdot
.52594 .64482 Mdot
.44528 .3487 Mdot
.23865 .65597 Mdot
.47622 .36768 Mdot
.44652 .59012 Mdot
.6334 .58027 Mdot
.64971 .38056 Mdot
.3033 .73095 Mdot
.33287 .31863 Mdot
.76751 .61021 Mdot
.82039 .38775 Mdot
.34454 .46472 Mdot
.32259 .50347 Mdot
.62992 .44176 Mdot
.45896 .63411 Mdot
.77698 .66313 Mdot
.39761 .64463 Mdot
.4517 .64775 Mdot
.45849 .61331 Mdot
.29267 .29798 Mdot
.61662 .37791 Mdot
.46403 .3662 Mdot
.4424 .65537 Mdot
.48313 .67292 Mdot
.61594 .57039 Mdot
.30264 .46732 Mdot
.43443 .33637 Mdot
.31591 .48755 Mdot
.43276 .35679 Mdot
.21019 .32644 Mdot
.48693 .68055 Mdot
.30865 .46403 Mdot
.62296 .3514 Mdot
.62541 .59784 Mdot
.68747 .49879 Mdot
.45177 .3399 Mdot
.45801 .38925 Mdot
.43051 .64445 Mdot
.65486 .59924 Mdot
.64433 .61002 Mdot
.31906 .45996 Mdot
.63092 .42532 Mdot
.48294 .59023 Mdot
.49557 .58417 Mdot
.72794 .60685 Mdot
.47555 .38471 Mdot
.60503 .5116 Mdot
.65442 .28203 Mdot
.4619 .63469 Mdot
.63613 .60756 Mdot
.46438 .60089 Mdot
.69206 .27824 Mdot
.67087 .5954 Mdot
.45781 .66967 Mdot
.19378 .47121 Mdot
.50346 .34779 Mdot
.69911 .44875 Mdot
.42206 .64073 Mdot
.7568 .30358 Mdot
.50091 .63622 Mdot
.26924 .23367 Mdot
.3766 .32373 Mdot
.46693 .58078 Mdot
.49282 .66212 Mdot
.56017 .77035 Mdot
.45844 .59047 Mdot
.43676 .39922 Mdot
.22812 .49014 Mdot
.63606 .61393 Mdot
.70878 .34656 Mdot
.45027 .75152 Mdot
.35116 .47906 Mdot
.47717 .34332 Mdot
.46083 .30992 Mdot
.33525 .47972 Mdot
.64092 .58423 Mdot
.47024 .6361 Mdot
.48572 .46637 Mdot
.4875 .36635 Mdot
.55102 .64555 Mdot
.62319 .3884 Mdot
.58001 .29856 Mdot
.49182 .31319 Mdot
.63825 .39616 Mdot
.49897 .61318 Mdot
.54648 .77474 Mdot
.32994 .71477 Mdot
.64493 .20619 Mdot
.63064 .36403 Mdot
.63922 .37234 Mdot
.23589 .66381 Mdot
.35023 .4525 Mdot
.79575 .52216 Mdot
.74439 .42908 Mdot
.65185 .39598 Mdot
.4421 .53559 Mdot
.41854 .37882 Mdot
.70163 .36215 Mdot
.58579 .61013 Mdot
.51011 .59492 Mdot
.46908 .61145 Mdot
.63617 .42339 Mdot
.58331 .64308 Mdot
.47019 .81137 Mdot
.64323 .3847 Mdot
.53598 .56863 Mdot
.51685 .42532 Mdot
.45021 .2578 Mdot
.44332 .39522 Mdot
.32802 .4991 Mdot
.32901 .51211 Mdot
.62457 .55205 Mdot
.32242 .49992 Mdot
.25869 .39305 Mdot
.48317 .63475 Mdot
.64539 .39549 Mdot
.5238 .27685 Mdot
.63048 .40113 Mdot
.33295 .48145 Mdot
.29327 .45015 Mdot
.62053 .57606 Mdot
.635 .56868 Mdot
.54432 .71455 Mdot
.2782 .59481 Mdot
.43309 .62325 Mdot
.44076 .22902 Mdot
.62993 .608 Mdot
.5455 .65757 Mdot
.31235 .49882 Mdot
.30496 .46735 Mdot
.32597 .52939 Mdot
.487 .61893 Mdot
.65617 .77373 Mdot
.48303 .61944 Mdot
.25819 .57485 Mdot
.41655 .64751 Mdot
.46839 .36914 Mdot
.49138 .61677 Mdot
.25058 .47609 Mdot
.45049 .57613 Mdot
.52826 .64826 Mdot
.48382 .36944 Mdot
.54074 .61235 Mdot
.44738 .34956 Mdot
.4389 .59939 Mdot
.35413 .46681 Mdot
.48175 .36531 Mdot
.33087 .57371 Mdot
.34775 .52261 Mdot
.42981 .40301 Mdot
.29906 .48471 Mdot
.35201 .47099 Mdot
.34764 .58777 Mdot
.6758 .56051 Mdot
.60363 .61356 Mdot
.45563 .63381 Mdot
.43259 .3261 Mdot
.61302 .38344 Mdot
.47844 .67097 Mdot
.52999 .61425 Mdot
.42719 .65685 Mdot
.62752 .54951 Mdot
.30504 .33085 Mdot
.31298 .46078 Mdot
.41626 .38827 Mdot
.2651 .44623 Mdot
.4609 .39961 Mdot
.5197 .66746 Mdot
.51607 .5801 Mdot
.51803 .72106 Mdot
.52134 .24463 Mdot
.22827 .66758 Mdot
.65823 .5938 Mdot
.44863 .3321 Mdot
.35217 .45962 Mdot
.50248 .69292 Mdot
.6725 .57146 Mdot
.44545 .34664 Mdot
.46475 .63738 Mdot
.43251 .68464 Mdot
.74262 .53476 Mdot
.43593 .73477 Mdot
.36119 .53528 Mdot
.44634 .3984 Mdot
.41094 .34062 Mdot
.23784 .40164 Mdot
.33916 .42963 Mdot
.43314 .48031 Mdot
.44336 .62172 Mdot
.30678 .4871 Mdot
.68317 .57603 Mdot
.31501 .71508 Mdot
.6361 .42737 Mdot
.46338 .50023 Mdot
.45327 .62884 Mdot
.41805 .44832 Mdot
.63158 .58057 Mdot
.33076 .47045 Mdot
.63828 .4218 Mdot
.29271 .49086 Mdot
.47941 .34004 Mdot
.84461 .4708 Mdot
.48078 .64919 Mdot
.42852 .63557 Mdot
.6531 .36883 Mdot
.67854 .57946 Mdot
.29286 .48692 Mdot
.79836 .49956 Mdot
.46786 .34576 Mdot
.76558 .68096 Mdot
.65507 .60494 Mdot
.71989 .67098 Mdot
.41852 .3878 Mdot
.5994 .41301 Mdot
.33827 .595 Mdot
.64129 .40581 Mdot
.43921 .59515 Mdot
.65373 .57262 Mdot
.60768 .4027 Mdot
.46125 .50732 Mdot
.37787 .20208 Mdot
.70108 .70036 Mdot
.47969 .63 Mdot
.29808 .24105 Mdot
.76269 .36876 Mdot
.69726 .54972 Mdot
.65548 .37976 Mdot
.433 .63351 Mdot
.46775 .57768 Mdot
.47806 .65425 Mdot
.61339 .40357 Mdot
.40267 .25776 Mdot
.46513 .35165 Mdot
.44457 .60769 Mdot
.31916 .49591 Mdot
.4517 .35532 Mdot
.49748 .29334 Mdot
.44875 .39132 Mdot
.69441 .55243 Mdot
.52693 .64296 Mdot
.64281 .44839 Mdot
.21208 .29202 Mdot
.62916 .37162 Mdot
.44054 .40618 Mdot
.50907 .66282 Mdot
.52007 .26536 Mdot
.67091 .56539 Mdot
.47126 .34883 Mdot
.43501 .64451 Mdot
.48708 .28513 Mdot
.25108 .65635 Mdot
.4481 .3907 Mdot
.67715 .57334 Mdot
.60738 .20309 Mdot
.44735 .63266 Mdot
.49669 .64149 Mdot
.66592 .58525 Mdot
.46995 .77303 Mdot
.20087 .56887 Mdot
.4696 .59682 Mdot
.63945 .38805 Mdot
.83297 .59894 Mdot
.52849 .65365 Mdot
.26517 .53477 Mdot
.43394 .34861 Mdot
.69799 .3884 Mdot
.59002 .51322 Mdot
.49983 .69472 Mdot
.79381 .50298 Mdot
.57651 .42667 Mdot
.28343 .27229 Mdot
.39177 .36577 Mdot
.36171 .40947 Mdot
.26039 .28088 Mdot
.64865 .42924 Mdot
.72522 .57762 Mdot
.78605 .44726 Mdot
.32777 .77288 Mdot
.6114 .21256 Mdot
.31 .39593 Mdot
.23599 .62273 Mdot
.48874 .45309 Mdot
.42944 .36106 Mdot
.27725 .48354 Mdot
.48589 .59584 Mdot
.76028 .36402 Mdot
.67903 .75379 Mdot
.56271 .82515 Mdot
.30322 .23578 Mdot
.60928 .78921 Mdot
.37385 .21181 Mdot
.48928 .17336 Mdot
.53573 .69716 Mdot
.53363 .23871 Mdot
.76373 .69028 Mdot
.20409 .45163 Mdot
.81979 .54002 Mdot
.39195 .66868 Mdot
.55 .48787 Mdot
.80566 .39098 Mdot
.73733 .64175 Mdot
.4714 .80165 Mdot
.47436 .36586 Mdot
.69197 .58281 Mdot
.77862 .43487 Mdot
.69962 .58881 Mdot
.65563 .46645 Mdot
.6141 .19974 Mdot
.39731 .18849 Mdot
.74604 .6558 Mdot
.72133 .2627 Mdot
.58339 .66885 Mdot
.58672 .85894 Mdot
.48813 .37452 Mdot
.65601 .54192 Mdot
.37345 .47015 Mdot
.23461 .39809 Mdot
.76562 .50336 Mdot
.78275 .41983 Mdot
.34957 .27503 Mdot
.31135 .62869 Mdot
.64738 .58015 Mdot
.56404 .54021 Mdot
.68417 .3982 Mdot
.72839 .49326 Mdot
.22512 .49612 Mdot
.5298 .18363 Mdot
.49075 .47452 Mdot
.69921 .33658 Mdot
.59578 .28638 Mdot
.28097 .76276 Mdot
.29427 .53799 Mdot
.5138 .69663 Mdot
.6377 .47992 Mdot
.68028 .25823 Mdot
.3638 .7855 Mdot
.27711 .61401 Mdot
.23303 .40182 Mdot
.19117 .40809 Mdot
.73793 .31627 Mdot
.1542 .51092 Mdot
.60079 .60733 Mdot
.42446 .62993 Mdot
.49254 .75797 Mdot
.70855 .73828 Mdot
.30094 .44275 Mdot
.40109 .24126 Mdot
.34549 .48548 Mdot
.63335 .53885 Mdot
.22973 .62968 Mdot
.77266 .61922 Mdot
.70839 .74395 Mdot
.33955 .50762 Mdot
.54439 .63054 Mdot
.89341 .54 Mdot
.31146 .25807 Mdot
.69488 .47186 Mdot
.31026 .20935 Mdot
.41385 .46171 Mdot
.45928 .52531 Mdot
.60862 .40123 Mdot
.25917 .27336 Mdot
.66371 .57698 Mdot
.14853 .46226 Mdot
.25842 .25044 Mdot
.40723 .75057 Mdot
.71857 .18619 Mdot
.25027 .36306 Mdot
.43302 .45551 Mdot
.57547 .39862 Mdot
.31105 .56311 Mdot
.43377 .80108 Mdot
.38523 .70873 Mdot
.54029 .26691 Mdot
.81203 .36585 Mdot
.27956 .26577 Mdot
.73523 .71143 Mdot
.83935 .49307 Mdot
.34939 .78895 Mdot
.56573 .46255 Mdot
.59589 .62226 Mdot
.46971 .30337 Mdot
.5097 .19494 Mdot
.19573 .36387 Mdot
.27954 .53485 Mdot
.8577 .38557 Mdot
.30029 .43166 Mdot
.36055 .32724 Mdot
.61256 .18773 Mdot
.32061 .62831 Mdot
.54828 .53187 Mdot
.22688 .47165 Mdot
.53568 .6663 Mdot
.25671 .43439 Mdot
.43654 .21893 Mdot
.65703 .48189 Mdot
.211 .44847 Mdot
.61053 .22724 Mdot
.7815 .53959 Mdot
.5983 .75063 Mdot
.22443 .40415 Mdot
.67053 .61192 Mdot
.29684 .622 Mdot
.54351 .52644 Mdot
.38563 .1893 Mdot
.59319 .44367 Mdot
.435 .16217 Mdot
.20509 .57147 Mdot
.44078 .67797 Mdot
.40681 .58627 Mdot
.54877 .56816 Mdot
.28846 .59705 Mdot
.53921 .63286 Mdot
.75746 .53205 Mdot
.45013 .17231 Mdot
.60041 .65342 Mdot
.68735 .41266 Mdot
.49 .2756 Mdot
.62952 .19313 Mdot
.52727 .74116 Mdot
.34865 .43282 Mdot
.23354 .54418 Mdot
.32498 .78754 Mdot
.45536 .36682 Mdot
.74537 .6941 Mdot
.66547 .37737 Mdot
.27122 .67821 Mdot
.61972 .76512 Mdot
.40717 .76661 Mdot
.45159 .1718 Mdot
.31542 .40995 Mdot
.22015 .60194 Mdot
.33837 .66887 Mdot
.80114 .63242 Mdot
.45757 .25394 Mdot
.51512 .57491 Mdot
.74369 .36391 Mdot
.33777 .45274 Mdot
.56613 .72986 Mdot
.82331 .5853 Mdot
.31734 .36646 Mdot
.45297 .56766 Mdot
.37217 .74405 Mdot
.49849 .40036 Mdot
.43137 .49359 Mdot
.1792 .63433 Mdot
.51095 .68083 Mdot
.24182 .35243 Mdot
.75245 .33273 Mdot
.29228 .56354 Mdot
.66869 .23268 Mdot
.66168 .26326 Mdot
.15907 .47603 Mdot
.29145 .23051 Mdot
.32273 .32463 Mdot
.25229 .29568 Mdot
.36066 .1912 Mdot
.16232 .49907 Mdot
.42599 .56361 Mdot
.65244 .36539 Mdot
.25492 .76246 Mdot
.43498 .39603 Mdot
.27356 .31035 Mdot
.80764 .54536 Mdot
.5089 .31903 Mdot
.67757 .5255 Mdot
.43195 .71959 Mdot
.49477 .45663 Mdot
.69068 .54465 Mdot
.54125 .61862 Mdot
.18565 .61583 Mdot
.17494 .45358 Mdot
.17005 .56226 Mdot
.75572 .31859 Mdot
.23481 .31104 Mdot
.47287 .44016 Mdot
.75169 .63344 Mdot
.5729 .63362 Mdot
.51379 .61015 Mdot
.38378 .48245 Mdot
.25235 .35982 Mdot
.3693 .74619 Mdot
.76069 .47921 Mdot
.70374 .56598 Mdot
.41698 .23128 Mdot
.6261 .87716 Mdot
.57364 .68974 Mdot
.78479 .61824 Mdot
.24136 .40509 Mdot
.27843 .58412 Mdot
.4928 .20303 Mdot
.40739 .75805 Mdot
.50898 .16744 Mdot
.68014 .53667 Mdot
.81653 .53467 Mdot
.3289 .38834 Mdot
.39342 .54975 Mdot
.31079 .32279 Mdot
.41304 .19223 Mdot
.55548 .37077 Mdot
.34089 .74635 Mdot
.75409 .41998 Mdot
.43218 .78051 Mdot
.38647 .33237 Mdot
.59059 .3001 Mdot
.81621 .59473 Mdot
.61012 .25918 Mdot
.26231 .55827 Mdot
.5224 .43237 Mdot
.58739 .55119 Mdot
.57605 .42346 Mdot
.26719 .55652 Mdot
.38292 .54689 Mdot
.24062 .32372 Mdot
.1984 .27787 Mdot
.23554 .69357 Mdot
.69579 .22495 Mdot
.46186 .21686 Mdot
.45251 .56974 Mdot
.5607 .16138 Mdot
.15714 .54894 Mdot
.2445 .25297 Mdot
.58249 .32632 Mdot
.38993 .3671 Mdot
.5948 .40222 Mdot
.19484 .61238 Mdot
.38962 .27289 Mdot
.55138 .17076 Mdot
.22905 .46244 Mdot
.59345 .393 Mdot
.4423 .84212 Mdot
.19356 .42279 Mdot
.64858 .75026 Mdot
.44113 .73448 Mdot
.41013 .61431 Mdot
.7289 .68458 Mdot
.69958 .58284 Mdot
.61423 .27593 Mdot
.28247 .60817 Mdot
.45182 .37875 Mdot
.37979 .49192 Mdot
.77522 .40394 Mdot
.52228 .62005 Mdot
.60723 .4703 Mdot
.69443 .56236 Mdot
.52694 .244 Mdot
.71368 .50657 Mdot
.1898 .36256 Mdot
.2831 .3284 Mdot
.41018 .65021 Mdot
.28964 .55831 Mdot
.30234 .3272 Mdot
.19886 .57641 Mdot
.61602 .44479 Mdot
.32632 .22055 Mdot
.52513 .49193 Mdot
.29468 .62002 Mdot
.7082 .71597 Mdot
.68262 .63617 Mdot
.51553 .58597 Mdot
.6178 .25015 Mdot
.64798 .69844 Mdot
.44539 .49895 Mdot
.58231 .61375 Mdot
.62453 .62837 Mdot
.57893 .16007 Mdot
.25979 .40218 Mdot
.58199 .28946 Mdot
.35322 .20788 Mdot
.62139 .40696 Mdot
.62334 .60185 Mdot
.30889 .51346 Mdot
.80548 .48289 Mdot
.67897 .67721 Mdot
.25148 .65761 Mdot
.50311 .31626 Mdot
.33002 .35689 Mdot
.35999 .21001 Mdot
.31863 .2304 Mdot
.62544 .80966 Mdot
.70589 .59005 Mdot
.55167 .67526 Mdot
.8085 .50464 Mdot
.68907 .59239 Mdot
.76982 .55275 Mdot
.75923 .54818 Mdot
.20952 .34687 Mdot
.63505 .46292 Mdot
.79945 .34782 Mdot
.35591 .54612 Mdot
.38922 .25507 Mdot
.29911 .72929 Mdot
.8107 .60151 Mdot
.38551 .20786 Mdot
.4289 .54634 Mdot
.57495 .77889 Mdot
.3954 .67797 Mdot
.65091 .51366 Mdot
.34667 .81689 Mdot
.31997 .51912 Mdot
.72228 .67129 Mdot
.61407 .22606 Mdot
.47415 .64198 Mdot
.23967 .70572 Mdot
.79839 .45411 Mdot
.23535 .667 Mdot
.60295 .36951 Mdot
.50596 .62045 Mdot
.4626 .57225 Mdot
.24812 .52772 Mdot
.69078 .43866 Mdot
.23 .34781 Mdot
.83859 .56801 Mdot
.56852 .21286 Mdot
.67775 .75424 Mdot
.2522 .3434 Mdot
.55021 .17803 Mdot
.75452 .35524 Mdot
.53934 .45848 Mdot
.25902 .35397 Mdot
.32738 .61782 Mdot
.72303 .2682 Mdot
.39161 .52063 Mdot
.63779 .33911 Mdot
.77397 .51391 Mdot
.66052 .28133 Mdot
.3119 .72219 Mdot
.50665 .64012 Mdot
.20547 .53747 Mdot
.5065 .17651 Mdot
.64552 .79188 Mdot
.41518 .80989 Mdot
.22176 .67871 Mdot
.64805 .72208 Mdot
.65867 .27256 Mdot
.75698 .36698 Mdot
.80122 .66297 Mdot
.53045 .49579 Mdot
.36237 .237 Mdot
.32859 .63644 Mdot
.35784 .20876 Mdot
.65826 .37672 Mdot
.7555 .44173 Mdot
.48421 .27283 Mdot
.24294 .31201 Mdot
.53309 .75499 Mdot
.43953 .18545 Mdot
.43369 .46281 Mdot
.15897 .46065 Mdot
.58587 .24632 Mdot
.48923 .44588 Mdot
.4606 .33379 Mdot
.29696 .41109 Mdot
.42638 .2143 Mdot
.4986 .23232 Mdot
.80401 .60619 Mdot
.39831 .36471 Mdot
.29011 .50105 Mdot
.65408 .7571 Mdot
.32375 .67427 Mdot
.63041 .25184 Mdot
.29 .55864 Mdot
.42617 .18009 Mdot
.23584 .49357 Mdot
.20872 .54647 Mdot
.27234 .32681 Mdot
.84629 .42695 Mdot
.69379 .46744 Mdot
.24904 .41875 Mdot
.79275 .43687 Mdot
.37062 .3166 Mdot
.45556 .53232 Mdot
.06215 .49788 Mdot
.83694 .4525 Mdot
.55736 .24122 Mdot
.19611 .36383 Mdot
.69062 .269 Mdot
.52744 .24688 Mdot
.42453 .79372 Mdot
.53691 .51746 Mdot
.2404 .60441 Mdot
.45913 .61388 Mdot
.17281 .59977 Mdot
.30676 .65154 Mdot
.18208 .39268 Mdot
.57668 .16728 Mdot
.71991 .69376 Mdot
.52669 .62651 Mdot
.41027 .37931 Mdot
.64471 .47012 Mdot
.30883 .67869 Mdot
.51489 .77726 Mdot
.5296 .53783 Mdot
.46559 .27662 Mdot
.46962 .33269 Mdot
.28905 .34642 Mdot
.6313 .53514 Mdot
.38673 .26919 Mdot
.65216 .27855 Mdot
.50403 .3638 Mdot
.4911 .4821 Mdot
.27282 .56546 Mdot
.5869 .51651 Mdot
.65429 .74481 Mdot
.39551 .75678 Mdot
.57343 .45293 Mdot
.45038 .39261 Mdot
.62848 .75358 Mdot
.81518 .40234 Mdot
.57427 .22087 Mdot
.1902 .40275 Mdot
.27314 .43022 Mdot
.54146 .79106 Mdot
.26126 .54977 Mdot
.44547 .80676 Mdot
.52635 .81033 Mdot
.4795 .24692 Mdot
.62473 .53029 Mdot
.47017 .79402 Mdot
.75061 .38223 Mdot
.22603 .31139 Mdot
.81908 .53912 Mdot
.81185 .51258 Mdot
.41769 .29515 Mdot
.71762 .64956 Mdot
.69183 .72857 Mdot
.33723 .56961 Mdot
.43439 .4851 Mdot
.55082 .86603 Mdot
.59369 .61468 Mdot
.42438 .87588 Mdot
.60241 .4109 Mdot
.363 .80215 Mdot
.33289 .62188 Mdot
.52586 .42714 Mdot
.40554 .47311 Mdot
.62613 .2595 Mdot
.74027 .4347 Mdot
.76811 .34295 Mdot
.53107 .82067 Mdot
.47616 .38834 Mdot
.8437 .56219 Mdot
.85001 .42745 Mdot
.58428 .76612 Mdot
.51612 .66616 Mdot
.83858 .4379 Mdot
.39147 .38007 Mdot
.37083 .74814 Mdot
.6691 .23016 Mdot
.50639 .22324 Mdot
.41494 .56701 Mdot
.28098 .59113 Mdot
.36509 .23368 Mdot
.32277 .21496 Mdot
.44666 .83273 Mdot
.43849 .21915 Mdot
.65559 .3715 Mdot
.47248 .44641 Mdot
.44785 .19154 Mdot
.45385 .52102 Mdot
.70741 .36841 Mdot
.52826 .5307 Mdot
.50363 .89004 Mdot
.28031 .29746 Mdot
.23239 .34539 Mdot
.50084 .52678 Mdot
.60809 .57578 Mdot
.68459 .43852 Mdot
.55145 .53132 Mdot
.52292 .22408 Mdot
.804 .40667 Mdot
.5485 .52865 Mdot
.73438 .74916 Mdot
.67371 .64046 Mdot
.46542 .42938 Mdot
.67655 .74783 Mdot
.59466 .65133 Mdot
.60267 .36856 Mdot
.21732 .53014 Mdot
.59706 .2143 Mdot
.64227 .35651 Mdot
.62454 .24764 Mdot
.69496 .33443 Mdot
.73235 .61742 Mdot
.68428 .68297 Mdot
.53768 .20965 Mdot
.537 .76995 Mdot
.72709 .55544 Mdot
.3089 .70824 Mdot
.43693 .40813 Mdot
.59608 .20845 Mdot
.46499 .33957 Mdot
.53534 .67087 Mdot
.46381 .50281 Mdot
.39707 .71582 Mdot
.21927 .65589 Mdot
.3445 .46301 Mdot
.68378 .55759 Mdot
.38684 .82439 Mdot
.67514 .59958 Mdot
.18011 .5996 Mdot
.40874 .76463 Mdot
.71071 .71437 Mdot
.32219 .33161 Mdot
.29953 .37092 Mdot
.64836 .8212 Mdot
.60615 .46571 Mdot
.47379 .30132 Mdot
.70247 .51845 Mdot
.66419 .54382 Mdot
.28691 .32024 Mdot
.48038 .37485 Mdot
.53596 .50844 Mdot
.55349 .36564 Mdot
.71118 .60835 Mdot
.70387 .53846 Mdot
.50929 .49675 Mdot
.24708 .59378 Mdot
.22111 .33607 Mdot
.42453 .36856 Mdot
.44841 .86926 Mdot
.52512 .60725 Mdot
.59271 .74629 Mdot
.50784 .16513 Mdot
.45281 .84318 Mdot
.47075 .3086 Mdot
.85386 .42757 Mdot
.41705 .65593 Mdot
.50561 .20442 Mdot
.65603 .5804 Mdot
.81299 .52163 Mdot
.34705 .47314 Mdot
.2983 .56374 Mdot
.59689 .39663 Mdot
.33815 .74612 Mdot
.51654 .36821 Mdot
.62073 .61019 Mdot
.46873 .22546 Mdot
.55727 .67139 Mdot
.73383 .40417 Mdot
.28962 .36349 Mdot
.59008 .76737 Mdot
.68845 .6755 Mdot
.71001 .54781 Mdot
.24137 .33133 Mdot
.8184 .51786 Mdot
.19892 .33023 Mdot
.56347 .5849 Mdot
.3512 .42129 Mdot
.77144 .53138 Mdot
.59279 .23191 Mdot
.6366 .51168 Mdot
.47859 .16495 Mdot
.28603 .6225 Mdot
.72173 .60664 Mdot
.26083 .57253 Mdot
.42238 .68722 Mdot
.5177 .46462 Mdot
.61804 .28785 Mdot
.5565 .82833 Mdot
.61658 .50182 Mdot
.38062 .79631 Mdot
.62987 .52278 Mdot
.22807 .36925 Mdot
.60599 .54861 Mdot
.46633 .3221 Mdot
.72367 .65221 Mdot
.60782 .45921 Mdot
.23882 .29657 Mdot
.48818 .16436 Mdot
.62849 .45127 Mdot
.32574 .29246 Mdot
.67016 .24557 Mdot
.4505 .69936 Mdot
.44103 .44539 Mdot
.42624 .61908 Mdot
.56671 .64536 Mdot
.46535 .85177 Mdot
.55022 .22415 Mdot
.49176 .5604 Mdot
.27865 .27376 Mdot
.27147 .26603 Mdot
.17075 .43294 Mdot
.78028 .66308 Mdot
.62173 .562 Mdot
.16842 .52314 Mdot
.53129 .5403 Mdot
.34764 .19664 Mdot
.48274 .24257 Mdot
.56084 .15227 Mdot
.56999 .77645 Mdot
.63903 .24406 Mdot
.44782 .79009 Mdot
.71771 .42617 Mdot
.72619 .31073 Mdot
.51891 .41076 Mdot
.56514 .28578 Mdot
.706 .28449 Mdot
.81812 .66786 Mdot
.47334 .70809 Mdot
.69508 .32867 Mdot
.76588 .4176 Mdot
.58605 .20475 Mdot
.37474 .34056 Mdot
.52549 .64529 Mdot
.5156 .27865 Mdot
.26826 .69792 Mdot
.27635 .55323 Mdot
.2797 .49195 Mdot
.37577 .33633 Mdot
.27455 .66052 Mdot
.25593 .5831 Mdot
.8208 .53843 Mdot
.58501 .7725 Mdot
.56691 .50404 Mdot
.4642 .67719 Mdot
.66368 .5254 Mdot
.34157 .49914 Mdot
.53005 .38682 Mdot
.43456 .60676 Mdot
.43988 .32379 Mdot
.73179 .41247 Mdot
.20945 .6557 Mdot
.66666 .47314 Mdot
.79651 .428 Mdot
.59407 .57589 Mdot
.69161 .33991 Mdot
.66875 .50386 Mdot
.28304 .72995 Mdot
.35842 .38358 Mdot
.27984 .53484 Mdot
.31988 .24691 Mdot
.21186 .44579 Mdot
.73646 .60841 Mdot
.18907 .4748 Mdot
.65768 .39586 Mdot
.496 .55326 Mdot
.77292 .44606 Mdot
.27711 .356 Mdot
.57941 .60816 Mdot
.63632 .24378 Mdot
.48064 .30597 Mdot
.23584 .42519 Mdot
.7477 .32333 Mdot
.58746 .64689 Mdot
.62264 .77428 Mdot
.30798 .23797 Mdot
.41353 .3676 Mdot
.82434 .48915 Mdot
.70841 .35586 Mdot
.35401 .40341 Mdot
.21556 .37543 Mdot
.20317 .34308 Mdot
.42727 .47276 Mdot
.31706 .60641 Mdot
.49135 .65168 Mdot
.81573 .58122 Mdot
.57358 .23081 Mdot
.40464 .71137 Mdot
.57173 .32443 Mdot
.6397 .60592 Mdot
.61793 .30612 Mdot
.55591 .49237 Mdot
.25474 .62839 Mdot
.70182 .58242 Mdot
.67647 .75895 Mdot
.35505 .47192 Mdot
.39838 .44569 Mdot
.54338 .62048 Mdot
.3151 .58668 Mdot
.72728 .72885 Mdot
.55701 .59719 Mdot
.4607 .20826 Mdot
.60979 .76522 Mdot
.80041 .50345 Mdot
.5231 .21173 Mdot
.47869 .25009 Mdot
.73562 .43359 Mdot
.71298 .66911 Mdot
.53889 .36868 Mdot
.42533 .65239 Mdot
.46724 .31941 Mdot
.66021 .61052 Mdot
.62917 .20879 Mdot
.65278 .71249 Mdot
.33011 .57722 Mdot
.54678 .41713 Mdot
.5329 .67643 Mdot
.56138 .40194 Mdot
.54234 .15599 Mdot
.71752 .42828 Mdot
.28075 .60933 Mdot
.63334 .4639 Mdot
.33253 .61559 Mdot
.40658 .77082 Mdot
.2513 .26211 Mdot
.43628 .79257 Mdot
.47418 .4718 Mdot
.39088 .80573 Mdot
.6179 .26228 Mdot
.67647 .23727 Mdot
.26957 .60158 Mdot
.39559 .45293 Mdot
.29319 .44179 Mdot
.74273 .54198 Mdot
.56051 .44817 Mdot
.26645 .4768 Mdot
.55168 .51125 Mdot
.54543 .33713 Mdot
.67979 .36031 Mdot
.42901 .71741 Mdot
.28269 .30525 Mdot
.31459 .24286 Mdot
.81031 .53198 Mdot
.5742 .42684 Mdot
.3735 .41484 Mdot
.26882 .64176 Mdot
.61248 .15525 Mdot
.30082 .78675 Mdot
.48959 .65193 Mdot
.57753 .44286 Mdot
.30639 .60438 Mdot
.44719 .39924 Mdot
.57834 .52649 Mdot
.66405 .49947 Mdot
.60308 .39374 Mdot
.29716 .50914 Mdot
.23418 .43555 Mdot
.63391 .26888 Mdot
.33576 .68612 Mdot
.49479 .28707 Mdot
.20949 .66111 Mdot
.80674 .37859 Mdot
.58045 .2293 Mdot
.55744 .1361 Mdot
.67574 .34084 Mdot
.66473 .62591 Mdot
.49235 .75098 Mdot
.22256 .33855 Mdot
.29507 .55106 Mdot
.29182 .70083 Mdot
.475 .25817 Mdot
.2788 .61519 Mdot
.48516 .5333 Mdot
.26021 .33707 Mdot
.60847 .3094 Mdot
.5105 .44978 Mdot
.30107 .37332 Mdot
.19038 .44517 Mdot
.62958 .77855 Mdot
.34307 .23509 Mdot
.27989 .71322 Mdot
.78205 .69671 Mdot
.25375 .27667 Mdot
.35766 .51529 Mdot
.36973 .3758 Mdot
.49729 .75494 Mdot
.38865 .5331 Mdot
.43624 .53816 Mdot
.36299 .74478 Mdot
.66891 .67396 Mdot
.35206 .29521 Mdot
.34068 .77443 Mdot
.26269 .55775 Mdot
.61388 .64919 Mdot
.39702 .45645 Mdot
.6486 .74445 Mdot
.32198 .29814 Mdot
.47712 .52077 Mdot
.40276 .515 Mdot
.33154 .54577 Mdot
.61702 .75848 Mdot
.78247 .52976 Mdot
.6765 .26797 Mdot
.74642 .7488 Mdot
.43324 .23717 Mdot
.29465 .74157 Mdot
.51929 .62436 Mdot
.17667 .36228 Mdot
.68512 .2886 Mdot
.45934 .24912 Mdot
.78046 .37271 Mdot
.44422 .4332 Mdot
.68458 .62648 Mdot
.42572 .65304 Mdot
.41659 .22237 Mdot
.71904 .67743 Mdot
.56115 .6818 Mdot
.32891 .74619 Mdot
.28887 .57413 Mdot
.23541 .47346 Mdot
.3449 .56171 Mdot
.5432 .57205 Mdot
.67936 .59394 Mdot
.16701 .55144 Mdot
.45308 .4682 Mdot
.52699 .6797 Mdot
.3903 .6875 Mdot
.43632 .77991 Mdot
.82175 .36977 Mdot
.55252 .57089 Mdot
.21497 .43082 Mdot
.59223 .79334 Mdot
.38481 .60149 Mdot
.60628 .52972 Mdot
.59313 .10908 Mdot
.23421 .24907 Mdot
.62869 .61279 Mdot
.7796 .6273 Mdot
.60089 .79215 Mdot
.23787 .32496 Mdot
.33352 .38658 Mdot
.56228 .34723 Mdot
.37778 .67935 Mdot
.40773 .53345 Mdot
.53879 .59288 Mdot
.75826 .3441 Mdot
.26127 .25247 Mdot
.33429 .7562 Mdot
.28104 .271 Mdot
.39244 .62037 Mdot
.53953 .58595 Mdot
.64623 .1621 Mdot
.43633 .19469 Mdot
.48011 .69679 Mdot
.46449 .80344 Mdot
.59488 .62139 Mdot
.47928 .59716 Mdot
.36596 .25321 Mdot
.84312 .55857 Mdot
.26005 .55322 Mdot
.2426 .3129 Mdot
.70115 .59186 Mdot
.49165 .3273 Mdot
.60027 .40773 Mdot
.4142 .47765 Mdot
.4406 .68614 Mdot
.61077 .40762 Mdot
.41244 .73884 Mdot
.6339 .23554 Mdot
.65246 .45931 Mdot
.83251 .52308 Mdot
.46721 .15048 Mdot
.6596 .71904 Mdot
.73351 .53226 Mdot
.49957 .69344 Mdot
.61381 .64761 Mdot
.30026 .67634 Mdot
.58422 .63527 Mdot
.69489 .26286 Mdot
.09685 .49139 Mdot
.55401 .29305 Mdot
.22772 .57073 Mdot
.62771 .53924 Mdot
.58053 .50659 Mdot
.67325 .7357 Mdot
.39081 .41841 Mdot
.42212 .35201 Mdot
.39466 .64239 Mdot
.55605 .58017 Mdot
.6141 .36145 Mdot
.4038 .85961 Mdot
.51881 .65247 Mdot
.59777 .52099 Mdot
.34967 .19716 Mdot
.30813 .70792 Mdot
.56989 .74704 Mdot
.41441 .62822 Mdot
.73437 .49811 Mdot
.39462 .45046 Mdot
.55224 .19183 Mdot
.20902 .53965 Mdot
.28632 .27593 Mdot
.65361 .70942 Mdot
.61513 .77979 Mdot
.48074 .67371 Mdot
.33294 .44234 Mdot
.70258 .38756 Mdot
.3879 .24507 Mdot
.41427 .58052 Mdot
.30883 .21879 Mdot
.47242 .4288 Mdot
.52243 .35859 Mdot
.51575 .55444 Mdot
.16801 .44892 Mdot
.37951 .78286 Mdot
.70295 .70981 Mdot
.26644 .71667 Mdot
.2731 .37849 Mdot
.32239 .67111 Mdot
.40914 .37278 Mdot
.40867 .58762 Mdot
.69235 .6017 Mdot
.21537 .68056 Mdot
.35538 .25219 Mdot
.54483 .27595 Mdot
.58681 .30129 Mdot
.79173 .59337 Mdot
.73289 .38973 Mdot
.52801 .13376 Mdot
.28355 .37839 Mdot
.21789 .67805 Mdot
.81598 .50573 Mdot
.58019 .59577 Mdot
.64203 .25719 Mdot
.52381 .56703 Mdot
.43815 .38404 Mdot
.27486 .28658 Mdot
.55224 .63027 Mdot
.23276 .63146 Mdot
.43038 .58742 Mdot
.22317 .64517 Mdot
.27298 .5003 Mdot
.31626 .29203 Mdot
.5807 .24921 Mdot
.41623 .78477 Mdot
.60015 .18965 Mdot
.74643 .54504 Mdot
.59732 .16115 Mdot
.60608 .19881 Mdot
.32039 .22368 Mdot
.26057 .67539 Mdot
.48482 .83915 Mdot
.5004 .23497 Mdot
.54402 .21223 Mdot
.63469 .28254 Mdot
.47585 .76918 Mdot
.30052 .40928 Mdot
.54152 .56365 Mdot
.69909 .43616 Mdot
.64148 .44429 Mdot
.16068 .69267 Mdot
.24914 .48545 Mdot
.61925 .61482 Mdot
.28043 .40327 Mdot
.28493 .25034 Mdot
.45833 .77052 Mdot
.71803 .29413 Mdot
.54733 .48752 Mdot
.51837 .57791 Mdot
.67264 .68764 Mdot
.80251 .56442 Mdot
.29376 .41601 Mdot
.65709 .82572 Mdot
.8073 .38895 Mdot
.56131 .31577 Mdot
.51433 .47233 Mdot
.69291 .58984 Mdot
.69461 .5242 Mdot
.31081 .35607 Mdot
.71143 .27267 Mdot
.63718 .241 Mdot
.44569 .19177 Mdot
.65053 .81863 Mdot
.8046 .50637 Mdot
.22139 .33828 Mdot
.59161 .24323 Mdot
.60582 .60308 Mdot
.37258 .5035 Mdot
.41594 .40874 Mdot
.55341 .26916 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0;gooooo0_l0002:
ooooo`007?ooool00ol0003oooooooooo`2mooooo`;o0000R_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0Z?ooool2o`0009oooooo000Looooo`03o`000?oooooooooo0:Sooooo0_l0
0007ooooo`;o0000U_ooool001cooooo00?o0000ooooooooool0XOooool2o`0000kooooo0_l0002F
ooooo`007?ooool00ol0003oooooooooo`2Qooooo`;o0000Y_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Dooooo`;o0000/oooool001cooooo0_l0
002Eooooo`;o00007?ooool2o`0009Gooooo000Looooo`03o`000?oooooooooo0:cooooo0_l00004
ooooo`;o00003oooool2o`0008Cooooo000Looooo`03o`000?oooooooooo0:cooooo0_l0000Eoooo
o`;o0000Q?ooool001cooooo00?o0000ooooooooool0R_ooool2o`0001kooooo0_l000001?oooooo
0000o`000?ooool:o`0000Cooooo0_l0000>ooooo`;o0000NOooool001cooooo00?o0000oooooooo
ool0R_ooool2o`0000cooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l000000ooooooo
0000o`000004ooooo`;o000000Coooooo`000?l0003ooooo2_l00004ooooo`;o00003_ooool2o`00
07Wooooo000Looooo`03o`000?oooooooooo09Sooooo0_l000000ooooooo0000o`000002o`000003
ooooool0003o000000Co00002oooool4o`0000?ooooo0_l0002?ooooo`007?ooool00ol0003ooooo
ooooo`1iooooo`;o00004oooool3o`0000?ooooo0_l0000:ooooo`Co00000oooool2o`0000Kooooo
0_l00002ooooo`;o00000oooool2o`0008oooooo000Looooo`03o`000?oooooooooo07Wooooo0_l0
000>ooooo`;o00000oooool3o`0000?ooooo0_l00005ooooo`;o00002_ooool2o`0000Kooooo1?l0
002Fooooo`007?ooool00ol0003oooooooooo`26ooooo`;o000000?oooooo`000?l000000_l00002
ooooo`;o00001_ooool2o`0000;ooooo0_l00003ooooo`Co00002oooool4o`0009Kooooo000Loooo
o`03o`000?oooooooooo08Kooooo1?l000000ooooooo0000o`000003ooooo`;o00001Oooool2o`00
00Oooooo1?l00008ooooo`;o000000?oooooo`000?l000002_ooool2o`0008cooooo000Looooo`03
o`000?oooooooooo08Kooooo1?l00006ooooo`;o00003oooool2o`0000Gooooo0_l00002ooooo`;o
00003Oooool2o`0008cooooo000Looooo`03o`000?oooooooooo08?ooooo0_l00006ooooo`;o0000
00?oooooo`000?l000004Oooool2o`0000Gooooo0_l0000looooo`;o0000HOooool001cooooo00?o
0000ooooooooool0N_ooool2o`000003ooooool0003o000000Cooooo0_l00006ooooo`;o000000?o
ooooo`000?l000005_ooool2o`0001Oooooo0_l00002ooooo`;o00008Oooool2o`00067ooooo0000
1_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003ooooo
ooooo`1^ooooo`;o000000?oooooo`000?l000000_l00005ooooo`Go00000oooool2o`0000Wooooo
0ol0000Fooooo`;o00002?ooool2o`0000gooooo0_l00002ooooo`;o00001?ooool2o`0007kooooo
00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@01_ooool00ol0003oooooooooo`1]ooooo`?o000000?oooooo`000?l000000_l00006oooo
o`?o00001?ooool2o`0000Kooooo0_l000001?oooooo0000o`000?l0000Booooo`Co00002_ooool2
o`0001Kooooo0ol0001nooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:oooo
o`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0KOooool3o`0000cooooo0_l0000<oooo
o`;o00005_ooool4o`0001_ooooo0_l000000ooooooo0000o`000002ooooo`;o00002?ooool2o`00
07Gooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^
k^h01_ooool3o`0006Kooooo0_l00006ooooo`;o00001oooool2o`0002?ooooo0_l0000Sooooo`Go
00001Oooool2o`0000Gooooo0_l0001eooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooo
ooooo`0<ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0I_ooool2o`0000kooooo
1Ol0000Kooooo`;o00000oooool3o`0000;ooooo0_l00007ooooo`;o00001?ooool2o`0000[ooooo
0_l00005ooooo`;o00001oooool5o`0007Wooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oo
oooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1_ooooo`Co00000ooo
ool5o`0001Oooooo0_l00002ooooo`?o00000_ooool3o`0000;ooooo0_l00006ooooo`?o00001?oo
ool2o`0000[ooooo0_l000001?oooooo0000o`000?l00008ooooo`Oo0000NOooool00006oooooomg
MgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000oooo
ooooool0HOooool2o`0000Wooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l000000ooo
oooo0000o`000006ooooo`;o00003oooool2o`0000?ooooo0_l00008ooooo`;o00000oooool4o`00
0003ooooool0003o000000;o00003oooool3o`0000Sooooo1?l0001looooo`0000Koooooonk^k_lb
<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooooooo
o`1Qooooo`;o00000_ooool2o`0000Gooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l0
0009ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Hooooo`;o00000oooool2o`0000?ooooo
1?l00006ooooo`;o00001oooool2o`0000?ooooo0_l0000Dooooo`;o0000K_ooool001cooooo00?o
0000ooooooooool0IOooool2o`0000gooooo0_l000000ooooooo0000o`00000;ooooo`;o000000?o
ooooo`000?l000001_ooool2o`000003ooooool0003o000001Sooooo0_l00006ooooo`?o00001ooo
ool2o`0000?ooooo0_l00006ooooo`;o00003?ooool2o`0006kooooo000Looooo`03o`000?oooooo
oooo067ooooo0_l00003ooooo`;o00003oooool2o`000003ooooool0003o000000kooooo0ol00002
ooooo`;o000000?oooooo`000?l000004oooool2o`0000?ooooo0_l00006ooooo`;o000000?ooooo
o`000?l000004_ooool2o`0000Gooooo0_l0000:ooooo`;o0000JOooool001cooooo00?o0000oooo
ooooool0HOooool2o`000003ooooool0003o000000;o00002oooool2o`0000Gooooo0_l00008oooo
o`;o000000Coooooo`000?l0003ooooo0ol0000;ooooo`;o00001oooool2o`0000?ooooo0ol00006
ooooo`;o00001_ooool2o`0000Kooooo0_l0000Aooooo`;o00002_ooool2o`0006Wooooo000Loooo
o`03o`000?oooooooooo06Cooooo0_l0000=ooooo`;o00003oooool2o`000003ooooool0003o0000
00cooooo0_l000000ooooooo0000o`000007ooooo`;o00000oooool2o`0000Kooooo1?l0000<oooo
o`?o00000_ooool3o`0000cooooo0_l0000:ooooo`Co0000Ioooool001cooooo00?o0000oooooooo
ool0E_ooool3o`0000;ooooo0_l00007ooooo`;o00008oooool4o`0000Sooooo0_l0000Gooooo`Co
00001Oooool4o`0000?ooooo0_l00003ooooo`?o00004?ooool2o`0000Kooooo1?l00004ooooo`;o
0000HOooool001cooooo00?o0000ooooooooool0E?ooool5o`0000;ooooo0_l00007ooooo`;o0000
1_ooool2o`0000Gooooo0_l0000?ooooo`;o00000oooool4o`00017ooooo0_l0000Gooooo`Co0000
0_ooool2o`0000Gooooo0_l00003ooooo`;o00002_ooool3o`0000kooooo0_l0001Qooooo`007?oo
ool00ol0003oooooooooo`1Dooooo`;o00002Oooool2o`0000_ooooo0_l00004ooooo`?o00003ooo
ool2o`0000Wooooo0_l0000=ooooo`?o00006?ooool2o`0000;ooooo0_l00005ooooo`;o00000ooo
ool3o`0000Wooooo0_l0001booooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00002_ooool3
o`0000[ooooo0_l00004ooooo`;o00001oooool2o`0000cooooo0_l00004ooooo`;o00003?ooool4
o`0000Wooooo0_l0000=ooooo`;o00003oooool2o`0000cooooo0_l00003ooooo`;o00002oooool2
o`0005gooooo000Looooo`03o`000?oooooooooo053ooooo1Ol00008ooooo`;o000000?oooooo`00
0?l000000_l0000Gooooo`;o00000_ooool2o`0000Sooooo0_l0000>ooooo`;o00000_ooool2o`00
00Cooooo0_l00005ooooo`;o00001Oooool2o`0001Sooooo0_l0000;ooooo`;o00000oooool4o`00
00Wooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1@ooooo`?o00002?ooool4o`0000?o
oooo0_l0000Fooooo`;o00000oooool2o`000003ooooool0003o000000Wooooo0_l0000:ooooo`;o
00002?ooool6o`0000Sooooo1?l00005ooooo`Co00003Oooool3o`0000Sooooo0_l000001?oooooo
0000o`000?ooool2o`000003ooooool0003o000000gooooo0_l0001Iooooo`007?ooool00ol0003o
ooooooooo`18ooooo`;o00004Oooool2o`0000Oooooo0_l0000Dooooo`;o00000_ooool2o`0000;o
oooo0_l000000ooooooo0000o`000006ooooo`;o00000_ooool6o`000003ooooool0003o000000[o
oooo1_l00009ooooo`Co00000_ooool5o`0000Wooooo0_l00002ooooo`?o00000_ooool3o`0000?o
oooo0_l000000ooooooo0000o`000003o`00013ooooo0_l0001Iooooo`007?ooool2o`0004Wooooo
0_l00006ooooo`;o00001oooool2o`0000Wooooo0_l00004ooooo`;o00001?ooool2o`0000Sooooo
0_l00002ooooo`Co00000oooool2o`0000Oooooo0_l000000ooooooo0000o`000004o`000003oooo
ool0003o000000Kooooo0_l00006ooooo`;o00002oooool2o`0000;ooooo1?l00002ooooo`;o0000
0_ooool8o`0000Gooooo0ol00003ooooo`;o00000_ooool2o`0000;ooooo0_l0001Yooooo`007?oo
ool00ol0003oooooooooo`1<ooooo`;o00000_ooool3o`0000Kooooo0_l0000?ooooo`;o00001?oo
ool5o`0000?ooooo1Ol00003ooooo`Go000000Coooooo`000?l0003ooooo0_l00003ooooo`;o0000
00?oooooo`000?l000001Oooool2o`0000Kooooo0_l0000Mooooo`;o00000_ooool4o`0000;ooooo
0_l0000;ooooo`;o00000oooool2o`000004ooooool0003o0000o`0006Sooooo000Looooo`03o`00
0?oooooooooo04cooooo0_l00003ooooo`;o00002oooool2o`000003ooooool0003o000000gooooo
1Ol00003ooooo`;o000000?oooooo`000?l000000_ooool2o`000005ooooool0003o0000o`000?oo
ool00_l000000ooooooo0000o`000003ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooo
oooo0000o`000002o`0002Oooooo0_l00006ooooo`Go00002Oooool5o`000003ooooool0003o0000
00;o0000Ioooool001cooooo00?o0000ooooooooool0G_ooool2o`000003ooooool0003o000000;o
00002oooool4o`0000[ooooo0ol00008ooooo`;o00000oooool8o`000003ooooool0003o000000;o
00002?ooool2o`00013ooooo0_l0000;ooooo`;o00001?ooool7o`0000Wooooo0ol00005ooooo`;o
0000Ioooool001cooooo00?o0000ooooooooool0BOooool2o`0000?ooooo0_l0000Cooooo`;o0000
1oooool2o`0000Gooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool2o`0000[ooooo
0_l00003ooooo`Ko00003_ooool2o`0000Cooooo0_l00009ooooo`?o00002oooool5o`000003oooo
ool0003o000000Wooooo0_l000000ooooooo0000o`000006ooooo`;o00001oooool2o`00063ooooo
000Looooo`03o`000?oooooooooo04Wooooo0_l00003ooooo`;o00001?ooool2o`000003ooooool0
003o000000gooooo0_l00004ooooo`;o00001Oooool2o`000003ooooool0003o000000;ooooo0_l0
00000ooooooo0000o`000002o`0000Wooooo0_l00006ooooo`Co00003oooool2o`000005ooooool0
003o0000o`000?ooool00_l00004ooooo`Go00003?ooool5o`0000_ooooo0_l000000ooooooo0000
o`000002o`000004ooooool0003o0000ooooo`Co00001Oooool2o`00063ooooo000Looooo`03o`00
0?oooooooooo05?ooooo0ol000000ooooooo0000o`00000:ooooo`;o000000?oooooo`000?l00000
0_l0000@ooooo`;o000000?oooooo`000?l000000_l0000Booooo`Go00003Oooool2o`000003oooo
ool0003o000000;ooooo2_l0000@ooooo`;o00000_ooool2o`000003ooooool0003o000000Wooooo
0_l000000ooooooo0000o`000002o`000003ooooool0003o000000Gooooo0_l0001Pooooo`007?oo
ool00ol0003oooooooooo`1@ooooo`;o000000?oooooo`000?l000000_ooool3o`0000;ooooo0_l0
0005ooooo`;o000000?oooooo`000?l000000_l0000@ooooo`Co00003Oooool2o`0000Wooooo0_l0
0002ooooo`;o00004_ooool8o`0000cooooo0ol00003ooooo`Co000000?oooooo`000?l000000ooo
ool2o`0000Cooooo0ol000001?oooooo0000o`000?l00002ooooo`Co00000_ooool2o`0001Gooooo
0_l00019ooooo`007?ooool00ol0003oooooooooo`1?ooooo`?o00001Oooool4o`000003ooooool0
003o000000Sooooo0_l00006ooooo`;o000000?oooooo`000?l000002?ooool3o`0000Sooooo0_l0
0003ooooo`;o00001_ooool2o`0000;ooooo1_l00008ooooo`Ko00000_ooool2o`0000?ooooo0_l0
000>ooooo`Go000000?oooooo`000?l000002?ooool2o`0000Gooooo0_l000000ooooooo0000o`00
0002o`000003ooooool0003o000000;o00006Oooool2o`0004Wooooo000Looooo`03o`000?oooooo
oooo03gooooo0_l0000@ooooo`;o00001_ooool4o`0000Kooooo0_l0000;ooooo`;o000000?ooooo
o`000?l000004oooool2o`0000Gooooo0_l00004ooooo`;o00000_ooool6o`000003ooooool0003o
000000Cooooo1ol00002ooooo`?o000000?oooooo`000?l000004Oooool3o`000003ooooool0003o
000000Kooooo0_l0000;ooooo`?o0000JOooool001cooooo00?o0000ooooooooool0?Oooool2o`00
01;ooooo0_l0000>ooooo`;o000000?oooooo`000?l000009?ooool2o`000003ooooool0003o0000
00Gooooo0_l00003ooooo`;o00000oooool2o`0000Cooooo0_l00003ooooo`?o00000_ooool2o`00
0003ooooool0003o000000_ooooo0_l0000:ooooo`;o00001?ooool5o`0000Sooooo0_l0000Moooo
o`;o0000Boooool001cooooo00?o0000ooooooooool0Coooool4o`0000Gooooo0_l00009ooooo`?o
00009?ooool2o`0000Kooooo1?l00004ooooo`;o00001oooool2o`000003ooooool0003o000000Co
00002?ooool2o`0000Sooooo0_l00006ooooo`;o00000_ooool2o`0000Gooooo1?l0000=ooooo`;o
000000?oooooo`000?l000005Oooool2o`0004_ooooo000Looooo`03o`000?oooooooooo04oooooo
0_l00005ooooo`Co00002Oooool3o`0002cooooo0ol00005ooooo`;o000000?oooooo`000?l00000
1?ooool2o`000003ooooool0003o000000;o00002_ooool5o`0000Gooooo0_l00005ooooo`Go0000
4Oooool2o`0000Cooooo0ol000000ooooooo0000o`00001Rooooo`007?ooool00ol0003ooooooooo
o`11ooooo`;o00004oooool2o`0000_ooooo1ol0000<ooooo`;o00001oooool2o`0000Gooooo0_l0
000;ooooo`;o00002?ooool2o`0000Cooooo0_l0000<ooooo`;o00000oooool5o`0000?ooooo0_l0
0005ooooo`;o000000?oooooo`000?l000001?ooool2o`0000_ooooo2?l0001Vooooo`007?ooool0
0ol0003oooooooooo`11ooooo`;o00001_ooool2o`000003ooooool0003o000001Gooooo0_l00000
0ooooooo0000o`000002o`0000?ooooo1?l00005ooooo`;o00001oooool2o`000003ooooool0003o
000000Co00005Oooool3o`0000?ooooo0ol000000ooooooo0000o`000007ooooo`?o00001_ooool2
o`0001?ooooo1?l00009ooooo`Ko00001?ooool5o`0005oooooo000Looooo`03o`000?oooooooooo
04Wooooo1ol00007ooooo`;o00000_ooool2o`0000Kooooo1?l00006ooooo`Co00001Oooool2o`00
00[ooooo1?l0000Eooooo`;o000000?oooooo`000?l000001?ooool5o`0000Oooooo0_l00005oooo
o`Co00005Oooool3o`0000[ooooo1?l00004ooooo`Go0000Goooool001cooooo0_l0001;ooooo`;o
00000_ooool2o`0000Oooooo0_l00002ooooo`;o00001_ooool4o`0000cooooo0_l0000Qooooo`;o
00000oooool2o`0000Sooooo0_l00009ooooo`;o00001Oooool9o`00017ooooo0_l00006ooooo`;o
00000oooool3o`000003ooooool0003o000000;ooooo0_l0000Jooooo`;o0000AOooool001cooooo
00?o0000ooooooooool0Loooool2o`0000Gooooo0_l0000Iooooo`?o00006?ooool2o`0000Wooooo
1Ol0000Hooooo`?o00000oooool3o`000003ooooool0003o000000;ooooo0_l0000:ooooo`;o0000
3_ooool2o`0004Gooooo000Looooo`03o`000?oooooooooo05Sooooo0_l0000>ooooo`;o00004?oo
ool2o`0001Wooooo0_l000000ooooooo0000o`000007ooooo`Go00006?ooool2o`0000Gooooo0_l0
000Aooooo`;o00001Oooool2o`00017ooooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`1E
ooooo`Go00002?ooool2o`0000Cooooo0_l0000Mooooo`;o00002Oooool5o`000003ooooool0003o
000000Oooooo1ol0000<ooooo`;o00000_ooool2o`0000Cooooo0_l00002ooooo`;o000000?ooooo
o`000?l000003?ooool2o`0000Gooooo0_l00002ooooo`;o00002?ooool2o`0000Oooooo0_l0001F
ooooo`007?ooool00ol0003oooooooooo`16ooooo`;o000000?oooooo`000?l000000_l00008oooo
o`Go00002?ooool2o`0000Sooooo0_l0000Gooooo`Co00002Oooool8o`0000;ooooo0_l00003oooo
o`;o00000oooool2o`0000Wooooo0_l000000ooooooo0000o`000002ooooo`;o00002?ooool2o`00
00Cooooo0_l00009ooooo`;o00001Oooool2o`0000;ooooo0_l00008ooooo`;o00001oooool2o`00
05Kooooo000Looooo`03o`000?oooooooooo04Gooooo0ol000000ooooooo0000o`000002o`0000ko
oooo0_l0000?ooooo`;o00001oooool2o`0000kooooo0_l0000@ooooo`?o00000_ooool2o`0000;o
oooo0_l0000?ooooo`Co00004oooool2o`0000Gooooo0_l0000Kooooo`;o00000oooool2o`0005Ko
oooo000Looooo`03o`000?oooooooooo04Gooooo0_l0000Booooo`Co00001?ooool2o`0000Gooooo
0_l00002ooooo`;o00001oooool2o`0000kooooo0_l000001?oooooo0000o`000?l00009ooooo`;o
00000oooool2o`000004ooooool0003o0000ooooo`Oo00003Oooool2o`0000Wooooo0_l0000?oooo
o`;o00002Oooool2o`0000;ooooo0_l0000<ooooo`;o00001?ooool2o`0000?ooooo0_l0001@oooo
o`007?ooool00ol0003oooooooooo`1Booooo`;o00001Oooool3o`0000Gooooo0_l00005ooooo`?o
00004_ooool2o`0000Cooooo1?l000001?oooooo0000o`000?l00009ooooo`;o00000oooool2o`00
00Cooooo1ol0000Cooooo`;o00000oooool2o`0001[ooooo0_l000001?oooooo0000o`000?l0000<
ooooo`;o00001?ooool3o`0000;ooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`13oooo
o`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001_ooool2o`0000;ooooo0_l00002oooo
o`;o00001?ooool2o`0000Kooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo1Ol00002
ooooo`Wo00000_ooool2o`00023ooooo0_l000000ooooooo0000o`000003ooooo`;o00002_ooool2
o`00017ooooo0ol0000?ooooo`;o00000_ooool2o`0005Cooooo000Looooo`03o`000?oooooooooo
047ooooo1?l00005ooooo`;o00000oooool2o`0000Cooooo0_l000000ooooooo0000o`000004oooo
o`Co00000oooool2o`0000Sooooo1?l00004ooooo`;o000000?oooooo`000?l000001_ooool5o`00
00;ooooo2Ol000000ooooooo0000o`000003o`0000;ooooo1?l0000Booooo`;o00001?ooool2o`00
0003ooooool0003o000000?ooooo0_l00004ooooo`;o00001?ooool2o`0000Cooooo0_l00007oooo
o`;o00000oooool2o`0000oooooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`0mooooo`;o
00000_ooool2o`0000Sooooo0_l00002ooooo`;o00001?ooool2o`000004ooooool0003o0000o`00
00?ooooo1?l00003ooooo`;o00002_ooool2o`0000Oooooo0_l00008ooooo`;o000000?oooooo`00
0?l000000ol000000ooooooo0000o`000009o`0000;ooooo1?l00008ooooo`;o00002?ooool2o`00
0003ooooool0003o000000Wooooo0_l00004ooooo`;o00002_ooool2o`0000Oooooo0_l00003oooo
o`;o000000Coooooo`000?l0003o00003Oooool4o`000003ooooool0003o0000057ooooo000Loooo
o`03o`000?oooooooooo03gooooo0_l0000<ooooo`;o00001Oooool2o`0000Gooooo0_l00004oooo
o`;o00001?ooool2o`0001?ooooo0_l00007ooooo`?o000000?oooooo`000?l000003_l000000ooo
oooo0000o`000002o`0000Wooooo0ol0000;ooooo`;o00001Oooool4o`00017ooooo0_l0000=oooo
o`;o000000?oooooo`000?l000000_l0000<ooooo`Oo0000DOooool001cooooo00?o0000oooooooo
ool0?Oooool2o`0000Gooooo0ol0000:ooooo`?o00002_ooool2o`0001?ooooo0_l000000ooooooo
0000o`000002o`0000Oooooo4ol000000ooooooo0000o`000005o`0000Wooooo0_l00006ooooo`;o
00001?ooool2o`0000Gooooo1ol0000>ooooo`;o00003Oooool3o`0000;ooooo0_l00009ooooo`;o
000000Coooooo`000?l0003ooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`0mooooo`;o
00001Oooool3o`0000[ooooo0_l0000;ooooo`;o00004oooool2o`000003ooooool0003o000000;o
00001ooooolKo`00017ooooo0_l00004ooooo`;o00000_ooool2o`0000Gooooo0ol0000:ooooo`;o
00000oooool2o`0000Kooooo0_l00003ooooo`Co00001?ooool2o`0000Oooooo0_l00007ooooo`;o
0000D?ooool001cooooo00?o0000ooooooooool0?_ooool2o`0000Gooooo0_l00003ooooo`;o0000
00Coooooo`000?l0003o00006_ooool2o`0000[ooooo0_l00005ooooo`;o00000ooooolJo`0000Go
oooo0_l00003ooooo`;o00003oooool2o`0000?ooooo0_l00008ooooo`;o000000?oooooo`000?l0
00000_l00003ooooo`;o00001_ooool2o`0000?ooooo0_l00006ooooo`?o00002_ooool2o`0000;o
oooo0ol0001@ooooo`007?ooool00ol0003oooooooooo`0nooooo`Co00001Oooool5o`000004oooo
ool0003o0000o`0000[ooooo1?l0000<ooooo`;o00002oooool2o`0000Cooooo7ol00003ooooo`Ko
000000?oooooo`000?l000002oooool2o`0000Oooooo0_l00004ooooo`;o00000_ooool2o`000003
ooooool0003o000000;o00003Oooool2o`0000Kooooo0_l00002ooooo`;o00001Oooool2o`0000?o
oooo0_l00002ooooo`;o00002?ooool2o`0004Oooooo000Looooo`;o0000@Oooool2o`0000Gooooo
0ol0000@ooooo`Co00006Oooool2o`0000Kooooo7_l00002ooooo`?o000000?oooooo`000?l00000
3_ooool2o`0000gooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00003_ooool2o`0000Ko
oooo0_l00002ooooo`;o00001Oooool2o`00017ooooo0_l00017ooooo`007?ooool00ol0003ooooo
ooooo`1;ooooo`;o00000oooool2o`0000[ooooo0_l0000Iooooo`;o00001?ooool2o`000003oooo
ool0003o000001_o00001oooool2o`0001oooooo1?l000001?oooooo0000o`000?l0000Iooooo`;o
00006_ooool2o`0004Gooooo000Looooo`03o`000?oooooooooo043ooooo0_l00003ooooo`;o0000
00Coooooo`000?l0003ooooo0_l00003ooooo`;o00001?ooool2o`000003ooooool0003o000000Ko
oooo0_l00004ooooo`;o00003_ooool2o`0000Cooooo0_l000000ooooooo0000o`00000Ko`0000?o
oooo0_l00002ooooo`;o00001Oooool2o`0001Sooooo1?l000000ooooooo0000o`000006o`0000Oo
oooo0_l00003ooooo`;o00000_ooool2o`0000Cooooo0_l00007ooooo`;o00003oooool2o`0004Go
oooo000Looooo`03o`000?oooooooooo043ooooo0_l00003ooooo`;o000000?oooooo`000?l00000
1?ooool2o`0000Kooooo0_l000001?oooooo0000o`000?l00005ooooo`;o00001?ooool2o`0000[o
oooo0_l00009ooooobCo00001?ooool2o`0000?ooooo0ol0000Booooo`?o00000_ooool=o`0000Oo
oooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00002ooooo`Co00001oooool2o`0000[o
oooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00000_ooool2o`0001;ooooo
0_l00008ooooo`Co00005oooool2o`0000Oooooo5?l00002ooooo`ko00001_ooool2o`0000Cooooo
0_l00009ooooo`;o00001oooool3o`000003ooooool0003o000000[o00002?ooool3o`000004oooo
ool0003o0000ooooo`?o00001?ooool2o`0001Gooooo0_l0001:ooooo`007?ooool00ol0003ooooo
ooooo`0fooooo`;o00000_ooool4o`0000Oooooo0ol00006ooooo`;o00002?ooool4o`00023ooooo
8_l00002ooooo`;o00003_ooool2o`0000Gooooo0_l00008ooooo`;o000000?oooooo`000?l00000
3?l00006ooooo`?o00001?ooool3o`0000Gooooo0_l00005ooooo`;o00000oooool2o`0000oooooo
0_l00013ooooo`007?ooool00ol0003oooooooooo`0looooo`;o00001_ooool4o`0001;ooooo0_l0
0007ooooo`;o00005_oooolRo`0000?ooooo0_l00002ooooo`;o00001Oooool2o`0000?ooooo0_l0
000=oooooa?o00003_ooool4o`000003ooooool0003o000000;o00001Oooool2o`0000;ooooo1?l0
000>ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0A?ooool4o`0001Kooooo0_l00003
ooooo`;o00004Oooool2o`0000?ooooo0_l00002ooooo`go000000?oooooo`000?l000003Ol00008
ooooo`?o00001?ooool2o`0000Cooooo1?l0000:oooooaCo00003Oooool4o`000003ooooool0003o
000000_ooooo1?l0000Aooooo`;o00001_ooool2o`0003Sooooo000Looooo`03o`000?oooooooooo
04;ooooo0_l0000Jooooo`;o00005_ooool4o`0000Gooooo1?l000000ooooooo0000o`00000;o`00
0003ooooool0003o000000Wo00002?ooool4o`0000Sooooo1?l0000;oooooaKo00002?ooool2o`00
01Wooooo0ol00009ooooo`Co00001_ooool2o`0003Sooooo000Looooo`03o`000?oooooooooo03So
oooo0_l00008ooooo`;o00004Oooool2o`000003ooooool0003o000000Cooooo0_l0000Dooooo`;o
00000_ooool2o`0000?ooooo5?l000000ooooooo0000o`000009o`0000[ooooo0_l00003ooooo`;o
000000?oooooo`000?l000003?ooool2o`0000;ooooo2Ol000000ooooooo0000o`000009o`000003
ooooool0003o000000Gooooo0_l00003ooooo`;o00001Oooool2o`0000gooooo0ol00006ooooo`;o
000000?oooooo`000?l000000_l00010ooooo`007?ooool00ol0003oooooooooo`0Uooooo`;o0000
4Oooool2o`0000Sooooo0_l0000Aooooo`;o000000?oooooo`000?l000000_ooool2o`0000[ooooo
0_l0000:ooooo`;o00001Oooool4o`000003ooooool0003o000000oo000000?oooooo`000?l00000
2Ol0000?ooooo`;o000000?oooooo`000?l000003?oooolIo`000004ooooool0003o0000ooooo`;o
00000_ooool2o`0000?ooooo0_l00005ooooo`;o00005_ooool2o`000003ooooool0003o000000;o
0000@?ooool001cooooo00?o0000ooooooooool09Oooool2o`0001_ooooo0_l0000:ooooo`;o0000
1_ooool2o`0000Cooooo0_l0000:ooooo`;o00001oooool2o`0000Kooooo1?l00003ooooo`go0000
00?oooooo`000?l000003Ol000000ooooooo0000o`00000Oooooo`Wo000000?oooooo`000?l00000
2Ol00003ooooo`;o000000?oooooo`000?l000002?ooool2o`0000[ooooo0_l0000Cooooo`;o0000
@_ooool001cooooo00?o0000ooooooooool0?_ooool2o`0000Kooooo0_l00006ooooo`;o00001_oo
ool2o`00017ooooo0_l00006ooooo`;o00000oooool2o`000003ooooool0003o000000Gooooo1_l0
00000ooooooo0000o`00000Bo`0000?ooooo0_l00008ooooo`;o00005_oooolEo`0000_ooooo0_l0
0002ooooo`;o00001_ooool2o`0000;ooooo0_l00003ooooo`;o00004?ooool2o`0000[ooooo0_l0
000dooooo`007?ooool00ol0003oooooooooo`0kooooo`;o000000?oooooo`000?l000001_ooool2
o`0001oooooo1?l0000;ooooo`;o00002Oooool5o`000003ooooool0003o0000013o00001?ooool2
o`0000Wooooo0_l0000EoooooaSo00002?ooool3o`0000Sooooo1?l00007ooooo`;o00002oooool2
o`0000?ooooo0_l0000:ooooo`;o0000=?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Ooo
ool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo03Oooooo0_l0
0002ooooo`;o00004oooool2o`0000Gooooo0_l0000>ooooo`;o00003oooool2o`0000Oooooo6?l0
0004ooooo`;o00002?ooool3o`0000gooooo1?l00002ooooo`co000000?oooooo`000?l000002ol0
0008ooooo`Co00001?ooool2o`000003ooooool0003o000001Kooooo0_l000000ooooooo0000o`00
0012ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo03Oooooo0_l0000Cooooo`;o00000_ooool2o`0000Gooooo
0_l00002ooooo`;o00001?ooool2o`0000cooooo0_l00004ooooo`;o000000?oooooo`000?l00000
1oooool7o`000003ooooool0003o000000go00000oooool2o`0000[ooooo0ol0000=ooooo`Co0000
0_ooool=o`0000;ooooo2?l000000ooooooo0000o`00000:ooooo`;o00001?ooool2o`0000Gooooo
0_l00009ooooo`;o00002_ooool2o`0000?ooooo0ol0000looooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`09ooooo`Go00001_ooool00ol0003oooooooooo`0gooooo`;o00004?oo
ool2o`000003ooooool0003o000000?ooooo0_l00006ooooo`Co00001?ooool2o`0000cooooo0_l0
0004ooooo`;o00002ooooolFo`0000;ooooo0ol00007ooooo`;o00004Oooool2o`0000?ooooo3_l0
00000ooooooo0000o`00000:o`0000?ooooo0_l0000Booooo`;o00002Oooool2o`0000cooooo0_l0
00001?oooooo0000o`000?l00006ooooo`;o0000=?ooool00003ooooool0003ooooo00;ooooo00?o
0000ooooooooool02Oooool01?m4A4CogMgMooooool00007ooooo`?o0000>_ooool2o`0000cooooo
1Ol00004ooooo`;o00000_ooool6o`0002cooooo3Ol000000ooooooo0000o`000003ooooo`Oo0000
0oooool2o`0000;ooooo0_l00003ooooo`;o00001?ooool2o`0000;ooooo0_l00003oooooaWo0000
1Oooool2o`0000Sooooo0_l00008ooooo`;o00001oooool2o`0000Cooooo0_l00006ooooo`Co0000
2_ooool2o`0003Cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Co
gMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`0jooooo`;o00001oooool4o`000003oooo
ool0003o000000Co00000_ooool3o`0000;ooooo1?l00007ooooo`;o000000?oooooo`000?l00000
2_ooool2o`0001?ooooo3_l0000:ooooo`Go00001oooool2o`0000?ooooo0_l00004ooooo`;o0000
2?oooolHo`0000Kooooo0_l00007ooooo`?o00001?ooool2o`000004ooooool0003o0000o`0000Ko
oooo0ol00003ooooo`Co00001?ooool2o`0004;ooooo00000ooooooo410@ooooo`02ooooo`03oa0@
4?oooooooooo00[ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0jooooo`;o0000
1oooool6o`0000;ooooo0ol00002ooooo`;o00001oooool2o`0000?ooooo1ol0000:ooooo`;o0000
00Coooooo`000?l0003ooooo0_l00006ooooo`;o00001?ooool5o`0000;ooooo2?l00005ooooo`;o
00000_ooool2o`00027ooooo5_l00007ooooo`;o00002?ooool2o`0000Cooooo0_l00002ooooo`;o
00001oooool2o`0000Gooooo1?l00002ooooo`;o0000@_ooool00006oooooomgMgOoV9RHoooooonH
V9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo03Wooooo0ol00002oooo
o`;o00001oooool2o`0000Kooooo0_l00008ooooo`;o00000_ooool3o`0000;ooooo1?l00004oooo
o`;o00001_ooool2o`000003ooooool0003o000000Kooooo0_l00004ooooo`;o000000?oooooo`00
0?l000000_ooool8o`0000Gooooo0_l000001?oooooo0000o`000?l00004ooooo`;o00000_ooool2
o`0000[ooooo0_l00009oooooaWo00002?ooool2o`0000_ooooo0_l00003ooooo`;o00002Oooool2
o`0000Gooooo0_l0000<ooooo`;o0000>?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Ooo
ool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo03Wooooo0_l00003ooooo`;o00003Ooo
ool4o`0000cooooo0_l00004ooooo`?o000000Coooooo`000?l0003ooooo0ol00009ooooo`;o0000
1_ooool2o`0000;ooooo0_l00002ooooo`;o00000_ooool2o`0000Cooooo1_l00003ooooo`?o0000
1Oooool2o`0000;ooooo0_l0000:ooooo`;o00002OoooolKo`0000Cooooo1?l0000;ooooo`;o0000
0oooool2o`0000Wooooo0_l0000:ooooo`;o00001oooool2o`0003Sooooo000Looooo`03o`000?oo
oooooooo04Oooooo0_l00004ooooo`;o00003Oooool2o`0000Sooooo0ol00002ooooo`;o00002Ooo
ool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o00003_ooool4o`0000?ooooo0_l0
000Cooooo`;o000000Coooooo`000?l0003ooooo0_l00008oooooaWo00001?ooool2o`0000;ooooo
0_l0000Dooooo`;o00002Oooool2o`0000Cooooo0_l00011ooooo`007?ooool00ol0003ooooooooo
o`17ooooo`;o00000_ooool4o`0000gooooo0_l00008ooooo`;o000000?oooooo`000?l000000ooo
ool2o`0000_ooooo0_l0000Pooooo`;o00003oooool2o`000004ooooool0003o0000ooooo`;o0000
1Oooool2o`000003ooooool0003o000000Go000000?oooooo`000?l000004?l00003ooooo`;o0000
0_ooool2o`0000Gooooo0_l00009ooooo`;o00000_ooool2o`0000?ooooo0_l00004ooooo`;o0000
Aoooool001cooooo00?o0000ooooooooool0>oooool2o`0000kooooo0_l0000Iooooo`;o000000?o
ooooo`000?l000000oooool2o`0000kooooo0_l0000Mooooo`;o00004_ooool2o`0000Cooooo0_l0
0002ooooo`;o00000_oooolBo`0000Gooooo0_l00003ooooo`;o00002Oooool2o`0000Oooooo1?l0
0007ooooo`;o0000COooool001cooooo00?o0000ooooooooool0=oooool2o`0000;ooooo0_l0000<
ooooo`;o00003_ooool2o`0000Oooooo0_l0000Jooooo`?o00008oooool2o`000003ooooool0003o
000000;o00001_ooool2o`000004ooooool0003o0000ooooo`;o00001_ooool?o`000003ooooool0
003o000000Sooooo0_l0000:ooooo`;o00002?ooool2o`0000kooooo0_l00009ooooo`;o00000ooo
ool5o`0003Gooooo000Looooo`03o`000?oooooooooo03Oooooo0_l00002ooooo`;o00000oooool4
o`0000Gooooo0_l0000:ooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o00001_ooool2
o`0000Gooooo0_l0000<ooooo`;o00004_ooool2o`000003ooooool0003o000000cooooo0_l00000
0ooooooo0000o`000002o`0000Wooooo1Ol00006oooooa;o00002?ooool2o`0000Gooooo0_l00003
ooooo`;o00001?ooool2o`000003ooooool0003o000000?ooooo0_l0000:ooooo`?o00000oooool2
o`0000?ooooo0_l00003ooooo`Go0000=Oooool001cooooo00?o0000ooooooooool0=?ooool2o`00
00[ooooo1?l00005ooooo`;o00001?ooool3o`0000;ooooo1?l00003ooooo`Go00001_ooool2o`00
00;ooooo0_l00002ooooo`;o000000?oooooo`000?l000004_ooool2o`0000Kooooo0_l00004oooo
o`;o000000?oooooo`000?l000003_ooool2o`0000kooooo0_l00006oooooa?o00003oooool2o`00
00?ooooo1?l00002ooooo`Oo000000?oooooo`000?l000002oooool2o`0000?ooooo0_l00004oooo
o`;o0000??ooool001cooooo00?o0000ooooooooool0=?ooool2o`0000_ooooo0_l00005ooooo`?o
00001?ooool3o`0000;ooooo1?l00003ooooo`;o000000?oooooo`000?l000000oooool2o`000003
ooooool0003o000000Kooooo0_l0000Eooooo`;o00001_ooool4o`0001Gooooo0_l0000Dooooo`Co
00000_ooool>o`0000oooooo0_l00006ooooo`;o00000_ooool4o`000003ooooool0003o000000;o
00001?ooool3o`0000?ooooo0_l0000;ooooo`;o00001?ooool2o`0003Kooooo000Looooo`03o`00
0?oooooooooo03cooooo1?l00008ooooo`;o00001Oooool7o`0000gooooo1?l00004ooooo`;o0000
7_ooool3o`000003ooooool0003o000000Gooooo0_l00002ooooo`Co00006?ooool2o`0000Cooooo
0_l00004ooooo`ko00000_ooool2o`0000Oooooo1_l00007ooooo`;o00000oooool2o`0000;ooooo
0ol00004ooooo`?o00000oooool4o`0000_ooooo0_l00002ooooo`;o0000=_ooool001cooooo00?o
0000ooooooooool0>oooool5o`0000Sooooo0_l00005ooooo`;o000000?oooooo`000?l000000ol0
0003ooooo`Oo000000?oooooo`000?l000000ol000001?oooooo0000o`000?ooool4o`0000[ooooo
0_l00003ooooo`;o00000_ooool2o`0000Oooooo0ol00003ooooo`Co000000?oooooo`000?l00000
0_ooool4o`0001Sooooo1_l00005ooooo`;o000000?oooooo`000?l000002Ol00003ooooo`;o0000
1oooool4o`0000Wooooo0_l00004ooooo`;o000000Coooooo`000?l0003o00003?ooool2o`0000_o
oooo0_l0000jooooo`007?ooool00ol0003oooooooooo`0jooooo`Go00000_ooool2o`000003oooo
ool0003o000000;ooooo1?l00006ooooo`;o000000?oooooo`000?l000000_ooool>o`000003oooo
ool0003o000000Go00002_ooool2o`0000?ooooo0_l00002ooooo`;o00002?ooool2o`0000?ooooo
1?l000000ooooooo0000o`000003ooooo`;o00006oooool7o`0000;ooooo0_l000000ooooooo0000
o`000002o`000005ooooool0003o0000o`000?ooool00_l00003ooooo`;o00006?ooool4o`0000;o
oooo0_l00003ooooo`;o0000D?ooool001cooooo00?o0000ooooooooool0<oooool2o`0000Gooooo
0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Kooooo
0_l00005ooooo`;o00000oooool?o`000003ooooool0003o000000kooooo0_l00004ooooo`;o0000
00?oooooo`000?l000000oooool2o`0000Sooooo0_l00003ooooo`;o00003oooool2o`0000?ooooo
0ol00008ooooo`Co00001?ooool2o`0000?ooooo0ol000000ooooooo0000o`00000@ooooo`;o0000
2oooool2o`0000Wooooo0_l00003ooooo`;o00003Oooool2o`0003cooooo000Looooo`;o0000=?oo
ool2o`0000[ooooo1?l0000IoooooaKo00001_ooool2o`0000;ooooo0_l00006ooooo`;o000000?o
ooooo`000?l000006Oooool2o`0000Sooooo0_l00003ooooo`Co00002Oooool2o`0000Cooooo0_l0
0002ooooo`;o00000oooool2o`00013ooooo0_l0000Kooooo`;o00002_ooool2o`000004ooooool0
003o0000o`0003_ooooo000Looooo`03o`000?oooooooooo03;ooooo0_l000000ooooooo0000o`00
0005ooooo`;o000000Coooooo`000?l0003ooooo0ol00007ooooo`;o00001?ooool2o`0000?ooooo
0_l000000ooooooo0000o`00000Fo`0000?ooooo0_l000001?oooooo0000o`000?ooool4o`0000[o
oooo1?l0000>ooooo`;o00001Oooool2o`0000cooooo2?l00006ooooo`;o00002?ooool2o`00037o
oooo0_l00003ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo0_l0000kooooo`00
7?ooool00ol0003oooooooooo`0booooo`;o000000?oooooo`000?l000001Oooool2o`000004oooo
ool0003o0000ooooo`?o00000oooool2o`0000;ooooo0_l00004ooooo`;o00000oooool2o`000003
ooooool0003o000001Co00001Oooool2o`0000Cooooo1Ol00009ooooo`Co00002Oooool2o`0000?o
oooo1?l0000<ooooo`;o00000_ooool3o`0000;ooooo1?l00006ooooo`;o00001Oooool2o`0000ko
oooo0ol0000Sooooo`;o00000oooool2o`0000?ooooo0_l00012ooooo`007?ooool00ol0003ooooo
ooooo`0`ooooo`;o00004oooool2o`000003ooooool0003o0000017ooooo4ol000001?oooooo0000
o`000?l00007ooooo`;o00000_ooool3o`0000?ooooo0_l0000Aooooo`;o00001Oooool2o`0000Oo
oooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo1?l00009ooooo`Co000000Coooooo`000?l0
003ooooo0_l00006ooooo`;o00000oooool3o`0001cooooo0_l00006ooooo`;o00003Oooool2o`00
00Sooooo0_l000000ooooooo0000o`00000_ooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o
000000?oooooo`000?l000004oooool4o`00013ooooo6Ol00006ooooo`?o00001oooool3o`0000Co
oooo0_l0000Iooooo`Co00001_ooool2o`0000?ooooo1?l00003ooooo`;o00000oooool5o`0000Co
oooo1?l00002ooooo`Co00001?ooool3o`0001_ooooo0_l00006ooooo`;o00000_ooool2o`0000Wo
oooo0_l00008ooooo`;o000000?oooooo`000?l00000;oooool001cooooo00?o0000ooooooooool0
;Oooool2o`0001Sooooo0_l0000@oooooaWo00001_ooool2o`0000Sooooo0_l00005ooooo`;o0000
3oooool2o`0000Sooooo0_l00002ooooo`;o00001?ooool4o`000003ooooool0003o000000?o0000
0_ooool2o`0000?ooooo1?l00002ooooo`;o00000oooool2o`0000;ooooo1Ol00004ooooo`;o0000
1Oooool2o`0001cooooo0_l00002ooooo`Co00000oooool2o`0000kooooo0_l0000`ooooo`007?oo
ool00ol0003oooooooooo`12ooooo`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o0000
2ooooolGo`0000Gooooo0_l000000ooooooo0000o`000003ooooo`?o00001_ooool2o`0000Kooooo
0_l00009ooooo`?o00002?ooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o0000
00Coooooo`000?l0003ooooo0_l00002ooooo`;o00001Oooool2o`0000;ooooo0_l00005ooooo`Co
000000?oooooo`000?l000002_ooool3o`0002;ooooo0_l00003ooooo`?o00001Oooool2o`0000Ko
oooo0_l0000`ooooo`007?ooool00ol0003oooooooooo`0kooooo`;o00001Oooool2o`000003oooo
ool0003o000000Co00000_ooool3o`0000Wooooo6Ol000001?oooooo0000o`000?ooool2o`000003
ooooool0003o000000?ooooo1?l00005ooooo`;o000000?oooooo`000?l000000oooool2o`0000Go
oooo0_l00003ooooo`;o00001_ooool4o`0000?ooooo1_l0000:ooooo`;o00001Oooool2o`0000Co
oooo0_l00003ooooo`Co00001Oooool2o`0000Kooooo0ol0000:ooooo`;o000000?oooooo`000?l0
00006Oooool5o`0000;ooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o0000
2?ooool3o`0000Oooooo1?l000000ooooooo0000o`000003ooooo`;o00000oooool2o`0000Cooooo
6Ol000000ooooooo0000o`000002ooooo`Co00001Oooool2o`0000Gooooo0_l000000ooooooo0000
o`00000:ooooo`Co000000Coooooo`000?l0003o00001Oooool2o`0000Gooooo0_l00002ooooo`;o
00001?ooool2o`00017ooooo0_l00005ooooo`;o00001Oooool4o`0000Gooooo0_l00003ooooo`;o
00001Oooool2o`000003ooooool0003o000001[ooooo1?l0000looooo`007?ooool00ol0003ooooo
ooooo`0`ooooo`;o00002?ooool2o`0000Sooooo0_l00008ooooo`;o00000oooool2o`000004oooo
ool0003o0000oooooaWo00001Oooool4o`0000Sooooo0_l00004ooooo`?o00003?ooool2o`0000;o
oooo0_l0000>ooooo`Co00001?ooool2o`0000oooooo1?l00002ooooo`;o00000oooool2o`0000?o
oooo1?l0000:ooooo`;o00003_ooool2o`0001Cooooo0_l0000nooooo`007?ooool00ol0003ooooo
ooooo`17ooooo`;o00002_ooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000
o`00000Bo`0000Sooooo0_l00008ooooo`?o00000_ooool4o`0000;ooooo1?l0000:ooooo`;o0000
3?ooool4o`0000oooooo0_l00006ooooo`;o00001?ooool2o`0000?ooooo1?l00005ooooo`;o0000
0_ooool2o`0000Gooooo0_l000000ooooooo0000o`000004ooooo`;o00001?ooool2o`0000Cooooo
0_l00007ooooo`;o00001Oooool2o`0000Kooooo1?l0000dooooo`007?ooool00ol0003ooooooooo
o`0^ooooo`;o00001Oooool2o`0000_ooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo
0_l00004ooooo`;o000000?oooooo`000?l000001?oooolDo`0000Wooooo0_l00006ooooo`;o0000
00?oooooo`000?l000000_ooool3o`0000?ooooo1?l0000:ooooo`;o00003?ooool4o`0000oooooo
0_l0000Booooo`?o00001Oooool2o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l00000
1?ooool2o`0000[ooooo0_l00007ooooo`;o00001oooool2o`0000Cooooo1?l0000dooooo`007?oo
ool00ol0003oooooooooo`0^ooooo`;o00001Oooool2o`0000_ooooo0_l00002ooooo`;o00000_oo
ool5o`0000?ooooo0_l00002ooooo`;o00000ooooolCo`000003ooooool0003o0000013ooooo0_l0
0006ooooo`;o00007oooool2o`0000;ooooo0ol000000ooooooo0000o`000008ooooo`;o00004ooo
ool2o`0000Wooooo0_l00009ooooo`;o00003_ooool4o`0000?ooooo0_l00007ooooo`?o000000?o
ooooo`000?l00000??ooool001cooooo00?o0000ooooooooool07?ooool2o`0002Cooooo0_l00000
1?oooooo0000o`000?l00003ooooo`;o00001Oooool2o`0000?ooooo0_l00002ooooo`;o000000?o
ooooo`000?l000004Ol00007ooooo`;o0000:Oooool2o`0000;ooooo0_l00005ooooo`Ko00000ooo
ool2o`0000?ooooo0_l0000Fooooo`;o00001_ooool2o`0000Wooooo0ol0000=ooooo`;o00001Ooo
ool2o`0000Oooooo0ol0000oooooo`007?ooool00ol0003oooooooooo`0Looooo`;o00009oooool3
o`000003ooooool0003o000000;o00002_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000@
o`0000Sooooo0_l000000ooooooo0000o`000002ooooo`;o00001_ooool3o`000003ooooool0003o
000001Kooooo0_l00002ooooo`;o00002?ooool2o`0000Cooooo0_l0000Kooooo`;o00004_ooool4
o`0000gooooo0_l00006ooooo`;o00002_ooool2o`0003[ooooo000Looooo`03o`000?oooooooooo
017ooooo0_l0000]ooooo`Co000000?oooooo`000?l000000_ooool4o`0000Kooooo0_l00009oooo
oaGo00002?ooool2o`0000;ooooo0_l00006ooooo`?o000000?oooooo`000?l000001?l00008oooo
o`;o00001oooool2o`0000Gooooo0_l0000Aooooo`?o00004_ooool2o`0000?ooooo0_l00004oooo
o`;o00001_ooool2o`0000;ooooo1Ol0000<ooooo`;o00001_ooool2o`0000[ooooo0_l0000joooo
o`007?ooool2o`0001;ooooo0_l0000Nooooo`;o00003Oooool4o`000003ooooool0003o000000?o
oooo0_l00007ooooo`Co00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000@o`0000Wo
oooo1?l00006ooooo`;o00000_ooool:o`000003ooooool0003o000000?o00001oooool3o`0000Co
oooo0_l00002ooooo`;o00003Oooool3o`0000Kooooo0_l0000:ooooo`;o000000?oooooo`000?l0
00000_l00004ooooo`Co00001?ooool2o`0000Gooooo1?l0000?ooooo`Co00003_ooool2o`0003Oo
oooo000Looooo`03o`000?oooooooooo037ooooo0_l00007ooooo`;o00006Oooool2o`0000Cooooo
0_l00002ooooo`;o000000?oooooo`000?l000003Ol000001?oooooo0000o`000?ooool2o`0000Ko
oooo1?l00006ooooo`;o00000_ooool:o`000003ooooool0003o000000;o00002Oooool2o`0000So
oooo0_l00005ooooo`;o00003?ooool5o`0000Gooooo0_l00006ooooo`Co00001_ooool2o`0000go
oooo0_l00006ooooo`;o00001oooool4o`000003ooooool0003o000000_ooooo0_l0000gooooo`00
7?ooool00ol0003oooooooooo`0Xooooo`;o00000_ooool2o`0000cooooo0_l0000Oooooo`;o0000
0_ooool2o`0000Cooooo1?l00002ooooo`Co000000?oooooo`000?l000000oooool2o`0000_ooooo
0_l00003ooooo`;o00000_ooool5o`0000;ooooo0ol0000Mooooo`Co00000oooool2o`0000Oooooo
1?l000000ooooooo0000o`000003ooooo`;o00001oooool2o`000003ooooool0003o000000Cooooo
0_l00004ooooo`?o00001_ooool2o`0000Kooooo0_l00007ooooo`Wo00002?ooool2o`0003Sooooo
000Looooo`03o`000?oooooooooo02Sooooo0_l00002ooooo`Co00004_ooool3o`0001Sooooo0_l0
000:ooooo`Wo00000_ooool2o`0000_ooooo1?l00002ooooo`;o000000?oooooo`000?l000001_oo
ool4o`0000Sooooo0_l0000:ooooo`;o00001_ooool2o`0000Gooooo0_l0000<ooooo`;o00003ooo
ool3o`0000Wooooo0ol00007ooooo`?o00000oooool2o`0000Wooooo0_l000001?oooooo0000o`00
0?ooool2o`0000Sooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00004_oo
ool3o`0001?ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo1Ol00002ooooo`Co00000ooo
ool2o`000003ooooool0003o000000Sooooo1?l00002ooooo`Go00002?ooool2o`0000Sooooo0_l0
000:ooooo`;o00000oooool2o`0000Kooooo1?l000000ooooooo0000o`000003ooooo`;o00002?oo
ool2o`0000?ooooo0_l00007ooooo`;o00002Oooool2o`0000Sooooo0ol00003ooooo`;o00000_oo
ool2o`0000Gooooo0_l00003ooooo`Co0000@Oooool001cooooo00?o0000ooooooooool0D?ooool2
o`0000;ooooo0_l00002ooooo`;o00001oooool2o`0000?ooooo0ol00004ooooo`;o000000?ooooo
o`000?l000001Oooool2o`0000Gooooo0ol00007ooooo`;o00002?ooool2o`0001_ooooo0_l00002
ooooo`;o000000?oooooo`000?l000001_l00003ooooo`;o00002?ooool2o`0000?ooooo0_l00000
0ooooooo0000o`00000Fooooo`;o00002oooool2o`0000Oooooo0_l000000ooooooo0000o`000002
o`00047ooooo000Looooo`03o`000?oooooooooo03Sooooo0_l00005ooooo`;o00003oooool2o`00
00;ooooo0_l00003ooooo`;o00001?ooool4o`000003ooooool0003o000000;o00001?ooool3o`00
0003ooooool0003o000000Oooooo0_l00003ooooo`?o00004Oooool2o`0001Kooooo0ol00006oooo
o`;o000000?oooooo`000?l000000oooool2o`0001Kooooo0_l0000;ooooo`;o00002Oooool2o`00
00Gooooo0_l0000=ooooo`;o00000oooool2o`0000cooooo0_l0000cooooo`007?ooool00ol0003o
ooooooooo`0cooooo`;o00000oooool2o`0000Gooooo1Ol00003ooooo`;o00001_ooool2o`0000So
oooo0_l00004ooooo`Co000000Coooooo`000?l0003o00000_ooool2o`000004ooooool0003o0000
o`0000[ooooo1?l0000Booooo`?o00001Oooool2o`00017ooooo0ol0000@ooooo`?o00002Oooool2
o`0000Sooooo0_l00003ooooo`;o00001_ooool2o`0000oooooo1?l0000:ooooo`Wo00000oooool2
o`0000Oooooo0_l0000cooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00002oooool4o`00
00?ooooo0_l00006ooooo`;o00001?ooool2o`0000;ooooo0_l0000:ooooo`?o000000?oooooo`00
0?l000001?l00002ooooo`;o00002?ooool2o`000003ooooool0003o000000kooooo1Ol00003oooo
o`Co00001Oooool2o`0000cooooo0_l00009ooooo`;o00000oooool3o`0000Cooooo0_l00003oooo
o`;o00001_ooool2o`000004ooooool0003o0000ooooo`?o00001?ooool2o`00017ooooo1?l0000:
ooooo`Oo00001Oooool2o`0003cooooo000Looooo`03o`000?oooooooooo04;ooooo0_l00002oooo
o`;o00001Oooool2o`0000?ooooo0_l000000ooooooo0000o`000004o`0000Sooooo0_l000000ooo
oooo0000o`000003ooooo`Co00000_ooool2o`0000Sooooo0_l000000ooooooo0000o`00000>oooo
o`;o000000?oooooo`000?l000000oooool4o`0000?ooooo1?l00005ooooo`Co00000oooool3o`00
00Sooooo0_l0000:ooooo`;o00002oooool5o`000004ooooool0003o0000o`0000Cooooo0_l00000
0ooooooo0000o`00001Vooooo`007?ooool00ol0003oooooooooo`12ooooo`?o000000?oooooo`00
0?l000001Oooool2o`0000;ooooo0ol00003ooooo`Go00001oooool5o`0000;ooooo0_l000000ooo
oooo0000o`00000<ooooo`;o00004oooool2o`0000;ooooo0_l000000ooooooo0000o`000004oooo
o`Co00001Oooool4o`0000Cooooo0ol0000@ooooo`;o00001?ooool2o`0000;ooooo0_l00005oooo
o`?o00000oooool2o`0000?ooooo0_l00002ooooo`Co00001Oooool2o`0000Kooooo0_l00003oooo
o`;o000000?oooooo`000?l000001oooool2o`0004Cooooo000Looooo`03o`000?oooooooooo03ko
oooo0_l00003ooooo`;o00003?ooool4o`0000;ooooo0_l000000ooooooo0000o`000008ooooo`;o
00001?ooool2o`0000Kooooo0_l00007ooooo`;o00001?ooool2o`0000;ooooo0_l00005ooooo`;o
00000_ooool6o`000003ooooool0003o000000?o00000_ooool2o`0000Sooooo0_l00004ooooo`?o
00002?ooool2o`0000Kooooo0_l00002ooooo`So00001_ooool2o`0000Sooooo0_l00004ooooo`;o
00001Oooool2o`000003ooooool0003o000000?ooooo0_l00003ooooo`;o000000Coooooo`000?l0
003ooooo0_l00004ooooo`Co0000@_ooool001cooooo00?o0000ooooooooool0?_ooool3o`0000co
oooo0_l00003ooooo`?o00000_ooool2o`0000?ooooo0_l00008ooooo`;o00000_ooool3o`0000Go
oooo0_l00006ooooo`?o00001?ooool6o`0000?ooooo1?l00004ooooo`;o00001Oooool3o`0000;o
oooo0_l00008ooooo`;o00003?ooool2o`000004ooooool0003o0000ooooo`;o00000oooool2o`00
00;ooooo1ol000000ooooooo0000o`000002ooooo`Go00000oooool2o`0000Kooooo0_l0000:oooo
o`;o00003_ooool2o`0000Kooooo1?l00010ooooo`007?ooool00ol0003oooooooooo`0nooooo`Co
00002oooool2o`0000Sooooo0_l00003ooooo`;o00002?ooool2o`0000;ooooo0ol00005ooooo`;o
00000_ooool2o`0000;ooooo0_l00006ooooo`?o00001Oooool2o`0001cooooo0ol00008ooooo`;o
000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000;o00001Oooool4o`000004
ooooool0003o0000ooooo`Ko000000?oooooo`000?l000000_l00005ooooo`Co00003Oooool2o`00
00Oooooo0ol00009ooooo`?o00005Oooool2o`0002Wooooo000Looooo`03o`000?oooooooooo03ko
oooo1?l00006ooooo`;o00000oooool2o`0001Kooooo0_l00009ooooo`Co00000_ooool2o`0000So
oooo0_l0000<ooooo`;o00003?ooool2o`0000Sooooo0_l000000ooooooo0000o`000008ooooo`;o
00001Oooool2o`0000?ooooo0_l00003ooooo`;o00000_ooool4o`000003ooooool0003o000000Oo
000000?oooooo`000?l000001_l000000ooooooo0000o`000002o`0000Wooooo1_l00005ooooo`Go
00001_ooool2o`000003ooooool0003o000001Kooooo0_l0000Yooooo`007?ooool00ol0003ooooo
ooooo`0Dooooo`;o00008oooool2o`0000?ooooo1Ol00005ooooo`;o00001Oooool2o`0000kooooo
0_l00004ooooo`Go00000oooool2o`000003ooooool0003o000000Oooooo0_l00005ooooo`;o0000
1_ooool2o`0000Cooooo0_l0000<ooooo`?o00001oooool2o`0000Cooooo0_l00007ooooo`Co0000
00?oooooo`000?l000002?oooolKo`0000?ooooo0ol00008ooooo`Ko00001Oooool2o`0000Wooooo
0_l0000<ooooo`;o0000=_ooool001cooooo0_l0000Eooooo`;o00006Oooool2o`0000Sooooo0_l0
0003ooooo`Go00003?ooool4o`0000Cooooo0_l00003ooooo`;o000000?oooooo`000?l000001Ooo
ool4o`0000?ooooo0_l000001?oooooo0000o`000?l00006ooooo`;o000000?oooooo`000?l00000
0_l00008ooooo`;o00004oooool2o`0000Sooooo0_l00003ooooo`;o00000oooool2o`0000;ooooo
1?l00002ooooo`;o00001?ooool4o`000003ooooool0003o0000017o000000Coooooo`000?l0003o
00000_ooool2o`000003ooooool0003o000000?o00002_ooool4o`0000kooooo0_l0000<ooooo`;o
0000=_ooool001cooooo00?o0000ooooooooool0;oooool2o`0000;ooooo0_l0000Looooo`;o0000
00?oooooo`000?l000000ol00003ooooo`;o00002_ooool2o`0000Oooooo0_l00008ooooo`Go0000
2oooool2o`0000Sooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo0ol00003ooooo`;o0000
2?ooool4o`0000Kooooo0_l00004oooooa7o000000?oooooo`000?l000000_l000000ooooooo0000
o`000009o`000004ooooool0003o0000o`0000Wooooo0_l000001?oooooo0000o`000?ooool2o`00
01[ooooo0_l0000eooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00007?ooool7o`0002?o
oooo0_l0000>ooooo`;o00002?ooool6o`0000;ooooo0ol000000ooooooo0000o`000003o`0000go
oooo0_l00002ooooo`;o00002?ooool2o`0000;ooooo3Ol000000ooooooo0000o`00000;o`000004
ooooool0003o0000ooooo`;o00000_ooool4o`0000Cooooo0_l000001?oooooo0000o`000?ooool2
o`0001[ooooo0_l0000eooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00002_ooool4o`00
00Gooooo0ol00003ooooo`;o00005oooool2o`0000;ooooo0_l0000;ooooo`;o00001Oooool2o`00
00?ooooo0ol00003ooooo`Co000000Coooooo`000?l0003ooooo0_l00007ooooo`;o00002?ooool2
o`0000Gooooo0ol000000ooooooo0000o`00000:o`000003ooooool0003o000000_o00001Oooool2
o`000003ooooool0003o000000;ooooo1?l00004ooooo`;o000000?oooooo`000?l000006Oooool2
o`0003Wooooo000Looooo`03o`000?oooooooooo03Cooooo0_l0000?ooooo`;o00002_ooool3o`00
00Kooooo0ol00003ooooo`?o00002Oooool2o`0000Gooooo0_l00004ooooo`;o00000_ooool2o`00
00?ooooo0_l00006ooooo`;o00001Oooool4o`000004ooooool0003o0000o`0000?ooooo1Ol0000<
ooooo`;o00003oooool3o`000003ooooool0003o0000013o000000?oooooo`000?l000003?l00000
0ooooooo0000o`00000=ooooo`;o00006Oooool3o`0003Sooooo000Looooo`03o`000?oooooooooo
02[ooooo0_l00008ooooo`;o00003_ooool2o`0000Oooooo0_l00006ooooo`;o00001?ooool4o`00
00;ooooo0_l00009ooooo`;o00001Oooool2o`0000gooooo0ol00002ooooo`;o00002_ooool4o`00
00?ooooo0_l00002ooooo`?o000000Coooooo`000?l0003o00000_ooool2o`0000?ooooo0_l0000D
ooooob7o000000?oooooo`000?l000003Oooool3o`0000Wooooo1?l00008ooooo`;o000000Cooooo
o`000?l0003o0000>?ooool001cooooo00?o0000ooooooooool0:_ooool2o`0001;ooooo0ol00003
ooooo`;o00001oooool3o`0000Gooooo0_l00004ooooo`Co00002oooool2o`0001Oooooo0_l00002
ooooo`;o00000_ooool3o`000003ooooool0003o000000?ooooo0ol00003ooooo`;o00000_ooool2
o`000003ooooool0003o000000;o000000Goooooo`000?l0003o0000ooooo`06o`0000Gooooo0_l0
000<ooooob3o000000?oooooo`000?l000002?ooool3o`0000?ooooo0_l00009ooooo`Co00002?oo
ool4o`0003[ooooo000Looooo`03o`000?oooooooooo03gooooo1?l000001Ooooooo0000o`000?l0
003ooooo00;o00001_ooool2o`000004ooooool0003o0000o`0000[ooooo0_l0000:ooooo`;o0000
5oooool4o`0000Cooooo0ol000001?oooooo0000o`000?ooool6o`0000;ooooo0ol000001?oooooo
0000o`000?ooool2o`0000?ooooo1_l000000ooooooo0000o`000003o`0000?ooooo0ol00007oooo
o`;o00000_oooolMo`0000Cooooo0_l00008ooooo`?o00003_ooool2o`0000cooooo0_l0000joooo
o`007?ooool00ol0003oooooooooo`0mooooo`So000000?oooooo`000?l000000oooool2o`0000?o
oooo1?l00006ooooo`;o00000_ooool2o`0000Sooooo0_l0000<ooooo`;o00002_ooool2o`000003
ooooool0003o000000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000001?l00003ooooo`;o
00001?ooool9o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`;o00001_oooolBo`000003
ooooool0003o0000013o0000I_ooool001cooooo00?o0000ooooooooool0>_ooool2o`000003oooo
ool0003o000000;ooooo0_l00003ooooo`;o00000oooool2o`0000?ooooo0_l00008ooooo`;o0000
3?ooool2o`0000Kooooo0_l00004ooooo`;o00002_ooool2o`000003ooooool0003o000000Ko0000
0_ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000001ol000000ooooooo0000
o`000009o`00017ooooo5_l000000ooooooo0000o`00000=o`0000Gooooo1?l0000Looooo`;o0000
?oooool001cooooo00?o0000ooooooooool0>_ooool5o`0000kooooo0_l00007ooooo`;o00001?oo
ool2o`0000?ooooo0_l00005ooooo`;o00000_ooool2o`0000;ooooo0_l0000@ooooo`?o000000?o
ooooo`000?l000000_l000000ooooooo0000o`000009o`000003ooooool0003o000000[o000000Go
ooooo`000?l0003o0000ooooo`04o`0000Gooooo1?l00007ooooo`Co00000_oooolOo`000003oooo
ool0003o000000Cooooo1Ol0000Hooooo`;o000000?oooooo`000?l00000?oooool001cooooo00?o
0000ooooooooool0??ooool2o`0000oooooo1?l00004ooooo`Co00000oooool2o`0000?ooooo0_l0
0002ooooo`;o00001Oooool3o`0001?ooooo0ol00003ooooo`;o00000_ooool:o`000003ooooool0
003o000000Wo00000_ooool2o`0000Oooooo0_l00002ooooo`Co00001oooool4o`0000;ooooo8_l0
0007ooooo`;o00006?ooool2o`0004;ooooo000Looooo`03o`000?oooooooooo03cooooo0_l0000<
ooooo`;o000000?oooooo`000?l000000_l000001?oooooo0000o`000?ooool4o`0000[ooooo1?l0
00001?oooooo0000o`000?ooool4o`0000gooooo0_l00002ooooo`Go000000?oooooo`000?l00000
0ol000000ooooooo0000o`00000Bo`000004ooooool0003o0000ooooo`Co00000oooool4o`000004
ooooool0003o0000ooooo`;o00001oooool2o`0000Cooooo4?l000000ooooooo0000o`00000?o`00
00?ooooo0_l00002ooooo`;o00003oooool2o`0000;ooooo0_l00006ooooo`;o0000?oooool001co
oooo00?o0000ooooooooool0??ooool2o`0000cooooo0_l000000ooooooo0000o`000003ooooo`;o
00001?ooool2o`0000Wooooo0_l00003ooooo`Oo00003Oooool2o`0000;ooooo8ol000000ooooooo
0000o`000002o`0000;ooooo0ol00003ooooo`Ko00001?ooool4o`000003ooooool0003o000002?o
00000oooool2o`0001?ooooo0_l00002ooooo`;o00001Oooool3o`0003oooooo00001_ooooook^k^
oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool0
0ol0003oooooooooo`0oooooo`;o00000oooool2o`0000Oooooo0ol00008ooooo`?o00001oooool2
o`0000Gooooo0_l00002ooooo`;o00003Oooool2o`0000?ooooo0ol000000ooooooo0000o`000003
o`000003ooooool0003o000001Wo00000_ooool5o`0000Gooooo1_l00002ooooo`;o000000?ooooo
o`000?l000009Ol0000<ooooo`;o00002?ooool2o`000003ooooool0003o000000Sooooo0_l00010
ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooo
oonHV9So8B4Q00Kooooo00?o0000ooooooooool0?oooool2o`0000?ooooo0_l00007ooooo`?o0000
1oooool5o`0000Kooooo0_l00006ooooo`;o00000_ooool2o`00013ooooo8?l000000ooooooo0000
o`000004o`000004ooooool0003o0000ooooo`;o000000Coooooo`000?l0003ooooo0_l00003oooo
o`;o000000?oooooo`000?l000003ol00002oooooaSo00003?ooool2o`0000Gooooo0_l000001?oo
oooo0000o`000?ooool2o`0000Gooooo0ol00012ooooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0d
ooooo`;o000000?oooooo`000?l000001_ooool2o`0000oooooo1?l00003ooooo`;o000000?ooooo
o`000?l000003_ooool2o`0000;ooooo0_l0000@ooooo`;o000000?oooooo`000?l000000ooooolO
o`0000;ooooo1?l000000ooooooo0000o`000003o`000004ooooool0003o0000ooooo`[o000000?o
ooooo`000?l000008?l00009ooooo`;o00002?ooool2o`0000Oooooo0_l00002ooooo`?o00001?oo
ool2o`0003cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000
oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000=?ooool2o`000003ooooool0003o000000Kooooo0_l0
0003ooooo`;o00000_ooool2o`0000Kooooo1_l000000ooooooo0000o`00000Pooooo`;o00002ooo
oolQo`000005ooooool0003o0000o`000?ooool01_l00002ooooo`;o000000?oooooo`000?l00000
1?ooool3o`000003ooooool0003o000001co00001?ooool2o`0000Sooooo0_l0000Aooooo`;o0000
00?oooooo`000?l000001?l00002ooooo`Co0000>_ooool00003ooooool0003ooooo00;ooooo00?o
0000ooooooooool02Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0
@oooool3o`0000;ooooo1?l00008ooooo`;o00002_ooool2o`000003ooooool0003o000000;ooooo
0_l00003ooooo`;o00002oooool2o`0000Wooooo1_l000000ooooooo0000o`00000Go`0000Cooooo
0ol000000ooooooo0000o`00000@ooooo`;o000000?oooooo`000?l000004ol00003ooooo`Ko0000
1?ooool2o`0000;ooooo0_l0000Eooooo`;o000000?oooooo`000?l000000ol000000ooooooo0000
o`000004ooooo`;o0000>_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Ooo
ool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo04?ooooo0_l00005ooooo`;o00002Ooo
ool5o`0000Kooooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool2o`0001;ooooo5_l0
00000ooooooo0000o`000007o`000005ooooool0003o0000o`000?ooool01_l0000=ooooo`Co0000
0_ooool5o`000004ooooool0003o0000ooooo`oo00000_ooool3o`0000Sooooo0ol000000ooooooo
0000o`000004o`0000cooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l00005ooooo`;o
0000?Oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008oooo
o`03o`000?oooooooooo03cooooo0_l0000<ooooo`;o00002Oooool7o`0000cooooo0_l0000Foooo
oaOo00001?ooool6o`000003ooooool0003o000000Oo000000?oooooo`000?l000002_ooool5o`00
00;ooooo1?l000000ooooooo0000o`00000Eo`0000;ooooo0_l00004ooooo`?o00000oooool4o`00
00Sooooo0_l00002ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Gooooo0_l0000moooo
o`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o
0000ooooooooool0>Oooool2o`000003ooooool0003o000001?ooooo0_l00003ooooo`Ko00003?oo
ool2o`0001Gooooo1?l000000ooooooo0000o`00000Uo`000003ooooool0003o000000_ooooo1_l0
00000ooooooo0000o`000003ooooo`co000000?oooooo`000?l000002?l000000ooooooo0000o`00
0002o`0001Cooooo0_l00005ooooo`;o0000Boooool001cooooo00?o0000ooooooooool08Oooool2
o`0000[ooooo0ol00009ooooo`;o00005_ooool4o`000003ooooool0003o000000?o00000oooool2
o`0000Oooooo0ol00002ooooo`;o00003_ooool^o`000003ooooool0003o000000Co00002?ooool2
o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o00000_ooool8o`000003ooooool0003o
000000;o00000_ooool4o`0000?ooooo0_l00004ooooo`;o00000oooool2o`0000[ooooo0_l00003
ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool08Oooool2o`0000[ooooo0ol0000Soooo
o`;o00001?ooool2o`000003ooooool0003o000000;o00001oooool3o`0000;ooooo0_l0000>oooo
o`Go000000?oooooo`000?l000008?l000000ooooooo0000o`000003o`000003ooooool0003o0000
00Co00003?ooool4o`0000Gooooo0_l000000ooooooo0000o`000002o`0000Gooooo1?l0000?oooo
o`;o00000oooool2o`0000;ooooo0_l00006ooooo`?o00000_ooool2o`0000?ooooo0_l00017oooo
o`007?ooool00ol0003oooooooooo`19ooooo`?o00000oooool2o`0000?ooooo0_l00003ooooo`;o
000000Coooooo`000?l0003o00002Oooool2o`0001;ooooo0_l000001?oooooo0000o`000?oooolV
o`0000Gooooo0_l00007ooooo`;o00001Oooool4o`000003ooooool0003o000000Co00004_ooool2
o`0001;ooooo0_l00006ooooo`?o00001oooool2o`0004Oooooo000Looooo`03o`000?oooooooooo
03Wooooo0_l0000>ooooo`?o00000oooool2o`0000?ooooo0ol00002ooooo`;o00005_ooool2o`00
00Gooooo0_l00004ooooo`;o000000?oooooo`000?l000002ol000000ooooooo0000o`00000Ho`00
00Gooooo0_l00006ooooo`;o00001_ooool2o`0000;ooooo1?l00005ooooo`?o00001_ooool2o`00
00Cooooo0ol0000Iooooo`Go0000C_ooool001cooooo00?o0000ooooooooool0>Oooool2o`0000co
oooo0_l000000ooooooo0000o`000003ooooo`;o00001?ooool2o`0000[ooooo0_l000000ooooooo
0000o`000002o`0000Wooooo0_l00005ooooo`;o00001?ooool2o`000003ooooool0003o000002Ko
00001?ooool5o`0000;ooooo0_l00006ooooo`;o00002Oooool2o`0000;ooooo0ol00006ooooo`;o
00001Oooool2o`0001Sooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00001Oooool2o`00
04Cooooo000Looooo`03o`000?oooooooooo03Oooooo0_l00009ooooo`;o00000oooool3o`0000Go
oooo0_l0000@ooooo`;o000000?oooooo`000?l000000_l0000Jooooobgo000000?oooooo`000?l0
00000_ooool4o`0000Cooooo0_l00009ooooo`;o00000_ooool2o`00017ooooo0_l0000@ooooo`;o
00000oooool2o`0000Gooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o0000A?ooool001co
oooo00?o0000ooooooooool0=oooool2o`0000Wooooo0_l000001?oooooo0000o`000?ooool2o`00
01gooooo0_l0000<ooooo`;o00002Oooool]o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`00
00_ooooo0_l0000Aooooo`;o00000_ooool2o`00013ooooo0_l0000=ooooo`?o0000Aoooool001co
oooo00?o0000ooooooooool0AOooool2o`0000Cooooo0_l00007ooooo`;o00001Oooool3o`000003
ooooool0003o000000Kooooo0_l0000<ooooo`;o00001?ooool7o`000003ooooool0003o000001Wo
000000?oooooo`000?l000002_l00003ooooo`?o00001Oooool2o`0000;ooooo0_l0000Kooooo`Ko
00008Oooool2o`0000[ooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0^ooooo`Co0000
6Oooool4o`0000Gooooo0_l00005ooooo`Oo00001?ooool2o`0001?ooooo1Ol00002ooooo`[o0000
00?oooooo`000?l000008_l00009ooooo`;o00003_ooool2o`0000Kooooo0_l00003ooooo`Oo0000
3_ooool2o`00013ooooo0_l0000:ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0;_oo
ool4o`0001?ooooo0_l00004ooooo`Co00001Oooool4o`0000;ooooo0_l000001?oooooo0000o`00
0?ooool2o`0000;ooooo1?l0000Dooooo`Co000000?oooooo`000?l000009_l000000ooooooo0000
o`000002o`000003ooooool0003o000000?ooooo0_l00003ooooo`Co00003Oooool2o`0000Kooooo
0_l00007ooooo`?o00003_ooool2o`0005_ooooo000Looooo`03o`000?oooooooooo02kooooo0_l0
000Eooooo`;o00001_ooool2o`0000Oooooo0_l00002ooooo`Co00001_ooool4o`0001?ooooo1Ol0
00000ooooooo0000o`00000Jo`000003ooooool0003o000000go00000_ooool2o`0000?ooooo0_l0
0003ooooo`Co00001oooool2o`0001oooooo0_l0000;ooooo`;o00001?ooool2o`0004oooooo000L
ooooo`;o0000;oooool2o`0001gooooo0_l00007ooooo`;o00000oooool3o`0000;ooooo0_l00004
ooooo`;o00004oooool2o`000004ooooool0003o0000ooooobco00000oooool2o`0000Wooooo1?l0
0005ooooo`?o00000_ooool2o`0001[ooooo1?l00009ooooo`;o00001?ooool2o`0004oooooo000L
ooooo`03o`000?oooooooooo043ooooo0_l00002ooooo`;o00004_ooool2o`000003ooooool0003o
000000?ooooo0_l0000Eooooo`;o00001Oooool2o`000003ooooool0003o000002So00001Oooool2
o`0000_ooooo1Ol00002ooooo`?o00000_ooool2o`0001_ooooo0ol00006ooooo`Co00003_ooool2
o`0004Kooooo000Looooo`03o`000?oooooooooo02_ooooo0_l0000Aooooo`Co00000_ooool2o`00
00Cooooo0ol000000ooooooo0000o`000008ooooo`;o00007Oooool2o`0000?ooooo0_l000000ooo
oooo0000o`000002ooooobOo00000oooool2o`00013ooooo0ol0000Tooooo`;o00000_ooool2o`00
00?ooooo1?l0000>ooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0:oooool2o`0000Go
oooo0_l0000:ooooo`Co00002?ooool3o`000003ooooool0003o000000Gooooo0_l0000Uooooo`;o
000000?oooooo`000?l00000:?l00004ooooo`Co0000>Oooool2o`000003ooooool0003o000005[o
oooo000Looooo`03o`000?oooooooooo03;ooooo0_l0000<ooooo`;o00001oooool2o`0000[ooooo
0_l0000Aooooo`;o00005oooool3o`000003ooooool0003o000000Wo000000?oooooo`000?l00000
5_l000000ooooooo0000o`000003ooooo`;o00001?ooool2o`0003Kooooo0_l0000:ooooo`?o0000
1?ooool2o`0004Oooooo000Looooo`03o`000?oooooooooo04Kooooo0_l000000ooooooo0000o`00
0003ooooo`?o00005oooool2o`0001Gooooo7ol000000ooooooo0000o`000006o`0000?ooooo0_l0
0003ooooo`;o00001?ooool2o`0002Cooooo0_l0000Looooo`?o00001?ooool2o`0000Cooooo0_l0
0011ooooo`007?ooool00ol0003oooooooooo`16ooooo`;o000000?oooooo`000?l000000oooool3
o`0001Cooooo0_l00003ooooo`;o00004?ooool7o`000004ooooool0003o0000oooooa_o000000?o
ooooo`000?l000000_l00003ooooo`;o00003_ooool2o`0001oooooo0_l00006ooooo`Ko00001Ooo
ool2o`0000?ooooo0_l0000Aooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0IOooool2
o`000003ooooool0003o000000;o00003_ooool5o`0000Oooooo7?l000001?oooooo0000o`000?l0
0004ooooo`;o00001Oooool2o`0000;ooooo0_l00003ooooo`;o00006Oooool2o`0000cooooo1_l0
0005ooooo`;o00000oooool2o`0000?ooooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`1A
ooooo`;o00001_ooool2o`0000?ooooo0_l00005ooooo`;o000000?oooooo`000?l000003oooool3
o`000003ooooool0003o000000Oooooo1ol000000ooooooo0000o`000002ooooo`co00000_ooool6
o`0000?ooooo0_l000001?oooooo0000o`000?ooool4o`0000;ooooo0_l0000Nooooo`;o00000_oo
ool2o`000003ooooool0003o000000Sooooo0_l00006ooooo`;o00000_ooool2o`0000Cooooo0_l0
001?ooooo`007?ooool00ol0003oooooooooo`12ooooo`Co00002oooool5o`0000?ooooo0_l00003
ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Aooooo`Co00000_ooool2o`0000Oooooo1ol0
0005ooooo`Go00000_ooool5o`000003ooooool0003o000000;o000000Coooooo`000?l0003ooooo
1?l000001?oooooo0000o`000?ooool2o`0002Gooooo0_l000001?oooooo0000o`000?ooool2o`00
00Sooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo0_l0001Eooooo`007?ooool00ol0003o
ooooooooo`12ooooo`Co00001_ooool2o`0000Cooooo1?l0000;ooooo`Oo00003oooool2o`0000?o
oooo0ol000000ooooooo0000o`000004ooooo`Co000000?oooooo`000?l000001_ooool4o`0000?o
oooo1?l000000ooooooo0000o`000003o`000003ooooool0003o000000;o00002_ooool2o`00027o
oooo0_l000001?oooooo0000o`000?l0000>ooooo`;o00002Oooool2o`0005;ooooo000Looooo`03
o`000?oooooooooo04cooooo1?l00002ooooo`;o00003_ooool2o`0000;ooooo0_l000000ooooooo
0000o`00000;ooooo`;o000000?oooooo`000?l000000ol00002ooooo`;o00001Oooool8o`0000;o
oooo1_l000001?oooooo0000o`000?ooool4o`0000?ooooo0_l000000ooooooo0000o`00000<oooo
o`;o00009?ooool3o`0000Cooooo0_l00007ooooo`?o00002Oooool2o`0005;ooooo000Looooo`03
o`000?oooooooooo04kooooo0_l0000Iooooo`;o00002oooool2o`000003ooooool0003o000000;o
00001_ooool<o`0000;ooooo1_l000000ooooooo0000o`000002ooooo`Go00005_ooool2o`0001ko
oooo0_l00007ooooo`;o00001oooool3o`0005gooooo000Looooo`03o`000?oooooooooo037ooooo
0_l0000Mooooo`;o000000?oooooo`000?l000002_ooool2o`0000Cooooo0_l00002ooooo`;o0000
4?ooool2o`0000Kooooo1?l00002ooooo`;o00001?ooool7o`000004ooooool0003o0000ooooo`?o
00000_ooool3o`0001Gooooo0_l0000Nooooo`;o00006oooool2o`0005?ooooo000Looooo`03o`00
0?oooooooooo037ooooo1?l0000Dooooo`;o00001Oooool2o`000003ooooool0003o000000[ooooo
0_l00004ooooo`;o00006oooool2o`0000;ooooo0_l00002ooooo`?o00000_ooool6o`0000;ooooo
2ol00006ooooo`;o0000??ooool2o`0000Kooooo0_l00004ooooo`;o0000Doooool001cooooo00?o
0000ooooooooool0<oooool2o`0000Gooooo0_l0000=ooooo`;o00002?ooool2o`0002gooooo0_l0
0002ooooo`;o00000_ooool7o`0000;ooooo3_l00002ooooo`;o00000oooool4o`0000?ooooo0_l0
0005ooooo`;o00005oooool2o`0001Gooooo0_l000000ooooooo0000o`000003ooooo`;o00002_oo
ool2o`0004gooooo000Looooo`;o0000>oooool2o`0001;ooooo0_l000000ooooooo0000o`000002
o`0000Kooooo1?l0000Zooooo`;o000000?oooooo`000?l000003?l00009ooooo`;o00001Oooool3
o`000004ooooool0003o0000o`0000Gooooo0_l0000Gooooo`;o00001oooool3o`0000Gooooo0_l0
0007ooooo`;o00003oooool2o`0004gooooo000Looooo`03o`000?oooooooooo04kooooo0_l00000
0ooooooo0000o`000005ooooo`;o000000?oooooo`000?l000000_l0000;ooooo`;o00005_ooool2
o`0000Gooooo0_l000000ooooooo0000o`000005o`0000Gooooo0ol0000@ooooo`;o000000?ooooo
o`000?l000001?ooool2o`0002;ooooo0ol00005ooooo`;o00001Oooool2o`00063ooooo000Loooo
o`03o`000?oooooooooo04[ooooo0_l00004ooooo`?o00001Oooool2o`0000Kooooo1?l00006oooo
o`;o00003_ooool2o`0000Gooooo0ol0000=ooooo`Oo000000?oooooo`000?l000006Oooool2o`00
01[ooooo0ol00005ooooo`;o00003Oooool2o`00063ooooo000Looooo`03o`000?oooooooooo04[o
oooo0_l00004ooooo`;o00002oooool2o`000003ooooool0003o000000;o00005Oooool4o`0000?o
oooo0ol0000?ooooo`Ko00008Oooool2o`0001Gooooo0ol00005ooooo`;o000000?oooooo`000?l0
00001?ooool2o`0006Kooooo000Looooo`03o`000?oooooooooo04cooooo0_l00009ooooo`;o0000
1?ooool2o`0000kooooo0_l0000:ooooo`Co00000oooool2o`0003Oooooo0_l0000Eooooo`?o0000
2?ooool2o`0000Cooooo1?l00006ooooo`;o0000G?ooool001cooooo00?o0000ooooooooool0C?oo
ool3o`0000Cooooo0_l00002ooooo`;o00000_ooool2o`0000Kooooo0ol000000ooooooo0000o`00
0004ooooo`;o00001oooool2o`0000Gooooo0_l000000ooooooo0000o`000003ooooo`Go00005?oo
ool2o`0000gooooo0_l00006ooooo`;o00006Oooool2o`0000[ooooo1?l00002ooooo`?o00001_oo
ool2o`0005cooooo000Looooo`03o`000?oooooooooo04gooooo0_l00004ooooo`;o00001_ooool2
o`0000Kooooo0ol000000ooooooo0000o`000002o`0000;ooooo0_l00007ooooo`;o00001Oooool2
o`0000Kooooo1_l0000Aooooo`Co00001_ooool2o`0000Gooooo0_l00006ooooo`;o00006oooool2
o`0000?ooooo0_l00003ooooo`Co00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`00001M
ooooo`007?ooool00ol0003oooooooooo`1Fooooo`;o00001_ooool2o`0000;ooooo0_l00005oooo
o`;o00007_ooool2o`0000kooooo0_l000000ooooooo0000o`000007ooooo`?o00002oooool2o`00
00Gooooo0_l0000=ooooo`;o00000_ooool4o`000003ooooool0003o000000?ooooo0_l0000>oooo
o`;o000000?oooooo`000?l00000GOooool001cooooo00?o0000ooooooooool0E_ooool2o`0000Ko
oooo0_l00002ooooo`;o00002_ooool2o`0001Wooooo0_l0000>ooooo`;o00002_ooool2o`0000co
oooo0_l000000ooooooo0000o`000002ooooo`;o00003Oooool2o`0000;ooooo1?l0000:ooooo`;o
0000K?ooool001cooooo00?o0000ooooooooool0D_ooool2o`0000Gooooo0ol000000ooooooo0000
o`000005ooooo`;o00002?ooool2o`0001_ooooo0ol0000Dooooo`;o00004?ooool4o`0000;ooooo
1?l0000;ooooo`;o00004?ooool4o`0000Wooooo1?l0001Mooooo`007?ooool00ol0003ooooooooo
o`1Booooo`;o00001?ooool4o`000003ooooool0003o000000;o00000oooool2o`0001?ooooo0_l0
000@ooooo`?o00004oooool3o`00013ooooo0_l000000ooooooo0000o`000003ooooo`;o00002ooo
ool2o`0001;ooooo0_l00002ooooo`;o00001Oooool4o`0005gooooo000Looooo`03o`000?oooooo
oooo04?ooooo0_l00002ooooo`;o00003oooool2o`0000Gooooo0_l00008ooooo`;o00000_ooool2
o`0000[ooooo0_l0000?ooooo`Co00000_ooool2o`0000[ooooo0_l00003ooooo`;o00005?ooool4
o`0001cooooo0_l00008ooooo`;o0000I_ooool001cooooo00?o0000ooooooooool0@oooool2o`00
00;ooooo0_l0000Pooooo`;o00000_ooool2o`0001?ooooo0_l00006ooooo`Co00000_ooool2o`00
00[ooooo0_l0000Fooooo`;o00000_ooool3o`0000;ooooo0_l0000Hooooo`;o00002Oooool2o`00
06Gooooo000Looooo`03o`000?oooooooooo05cooooo0_l0000?ooooo`;o00002?ooool2o`0000Wo
oooo0_l00008ooooo`;o00004?ooool2o`0000Sooooo0_l0000:ooooo`;o00001oooool2o`0002?o
oooo0_l0001Uooooo`007?ooool00ol0003oooooooooo`1Looooo`;o00003oooool2o`0000?ooooo
0_l000000ooooooo0000o`000002o`0001cooooo0_l00005ooooo`Go00001oooool2o`0001Sooooo
0_l0000;ooooo`Co00003oooool2o`0006Gooooo000Looooo`03o`000?oooooooooo06Oooooo0_l0
00001?oooooo0000o`000?l00005ooooo`Go00003?ooool2o`00013ooooo0_l00005ooooo`;o0000
00?oooooo`000?l000005?ooool2o`0000Kooooo0_l00003ooooo`;o00002oooool6o`0000?ooooo
0_l00008ooooo`;o0000IOooool001cooooo0_l00017ooooo`;o00007oooool2o`000004ooooool0
003o0000o`0000Oooooo0ol0000:ooooo`Ko00005?ooool3o`0001Oooooo0_l00006ooooo`Co0000
3_ooool2o`0000;ooooo0_l00003ooooo`;o00001?ooool2o`0000_ooooo0_l00002ooooo`;o0000
F?ooool001cooooo00?o0000ooooooooool0A_ooool2o`0001[ooooo0_l00003ooooo`;o00002ooo
ool2o`0000Wooooo1Ol000000ooooooo0000o`000008ooooo`;o00002_ooool3o`000003ooooool0
003o000000cooooo0_l0000@ooooo`;o00001oooool2o`0000Gooooo0_l00007ooooo`?o00000ooo
ool2o`0000_ooooo0_l00002ooooo`;o0000F?ooool001cooooo00?o0000ooooooooool0H_ooool2
o`0000Gooooo0_l0000Booooo`Co00001oooool2o`000003ooooool0003o000000;ooooo0_l0000=
ooooo`?o00002?ooool2o`0000;ooooo0_l0000;ooooo`?o00002oooool2o`0000Oooooo0_l00004
ooooo`Co00000_ooool2o`0000_ooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1Soooo
o`;o00001?ooool2o`0001;ooooo0_l00002ooooo`;o00001Oooool2o`000003ooooool0003o0000
00Oooooo0_l00002ooooo`So00002Oooool2o`0000oooooo0ol00004ooooo`;o00000_ooool2o`00
00[ooooo0_l00004ooooo`Go000000?oooooo`000?l000002oooool2o`0005gooooo000Looooo`03
o`000?oooooooooo04oooooo0_l00007ooooo`;o00002Oooool2o`000003ooooool0003o000001Wo
oooo0_l0000Aooooo`;o00000_ooool6o`0000_ooooo0_l0000Fooooo`;o00000_ooool2o`00017o
oooo1?l0001]ooooo`007?ooool00ol0003oooooooooo`1?ooooo`;o00001oooool2o`0000cooooo
0_l0000@ooooo`;o000000?oooooo`000?l000001?ooool2o`0003Oooooo0_l00006ooooo`;o0000
00Coooooo`000?l0003o00002?ooool2o`0000Sooooo0_l00002ooooo`;o0000JOooool001cooooo
00?o0000ooooooooool0F_ooool2o`0000Wooooo0_l0000Aooooo`;o000000?oooooo`000?l00000
1?ooool2o`0001;ooooo1?l0000Qooooo`Co00001?ooool2o`0000;ooooo0_l00008ooooo`;o0000
3?ooool2o`0006Wooooo000Looooo`03o`000?oooooooooo05Wooooo0ol00009ooooo`Co00005ooo
ool2o`0000Wooooo0_l00004ooooo`;o00000_ooool4o`0001;ooooo0_l00005ooooo`;o00001_oo
ool4o`0001cooooo0_l0001]ooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o00003?ooool2
o`0000;ooooo0_l0000Cooooo`;o00002Oooool3o`0000?ooooo0_l00002ooooo`;o00005?ooool2
o`000003ooooool0003o000000;ooooo0_l00006ooooo`;o00002_ooool2o`0000Sooooo0ol00007
ooooo`;o0000KOooool001cooooo00?o0000ooooooooool0G?ooool2o`0000Wooooo0_l00002oooo
o`;o00003?ooool2o`0000Sooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo0_l00003oooo
o`;o00003?ooool3o`0000;ooooo0_l00004ooooo`?o00001?ooool4o`0000Gooooo0_l00006oooo
o`;o000000Coooooo`000?l0003o00001?ooool3o`0000;ooooo0_l0001booooo`007?ooool00ol0
003oooooooooo`1Looooo`;o00006oooool2o`0000Kooooo1?l00003ooooo`Co00001?ooool2o`00
017ooooo0ol00002ooooo`;o00001Oooool2o`0000Cooooo1?l00005ooooo`;o00001?ooool3o`00
00;ooooo0ol00009ooooo`;o0000L_ooool001cooooo00?o0000ooooooooool0M_ooool4o`000003
ooooool0003o000000Cooooo1?l00004ooooo`Go00006Oooool2o`0001_ooooo0ol00022ooooo`00
7?ooool00ol0003oooooooooo`1Nooooo`;o00001_ooool2o`0000[ooooo0_l00002ooooo`Co0000
00?oooooo`000?l000001_ooool2o`000003ooooool0003o000000?ooooo0ol0000Iooooo`;o0000
1Oooool2o`0001oooooo0_l0001hooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o00001?oo
ool2o`0000Kooooo0_l00006ooooo`;o00000_ooool2o`00017ooooo0ol000000ooooooo0000o`00
0003ooooo`;o00002_ooool2o`00013ooooo1?l0000Booooo`;o000000?oooooo`000?l000002?oo
ool2o`0000Kooooo0_l0001`ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q
1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0F?ooool2o`0000Ko
oooo0_l00006ooooo`;o00001?ooool3o`0000Sooooo0_l00004ooooo`;o00001?ooool3o`000004
ooooool0003o0000o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool3o`00
00oooooo0_l0000?ooooo`Co000000Coooooo`000?l0003ooooo0_l00007ooooo`;o00001oooool3
o`0006oooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1Pooooo`;o00001_ooool2o`0000Gooooo
0_l00007ooooo`?o00000_ooool4o`0000Gooooo0_l00002ooooo`;o00001Oooool2o`0000;ooooo
0_l00004ooooo`;o00008?ooool5o`0000?ooooo0_l00007ooooo`;o00001Oooool2o`000003oooo
ool0003o000006oooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo07Sooooo0_l00003ooooo`;o0000
00?oooooo`000?l000009Oooool2o`0001Oooooo0_l0000Cooooo`;o0000L_ooool00003ooooool0
003ooooo00;ooooo00?o0000ooooooooool02Oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo
0ol0001booooo`;o00002_ooool4o`0000Oooooo0_l00004ooooo`;o00000_ooool4o`00013ooooo
0_l000000ooooooo0000o`00002Mooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooooooo
o`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`1booooo`;o0000
1oooool2o`000003ooooool0003o000000?o00001_ooool2o`0000;ooooo1?l00002ooooo`Co0000
00?oooooo`000?l000001Oooool2o`0000Wooooo0_l0000:ooooo`;o00002?ooool2o`0008Oooooo
00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go410@okZj^_oooooo^[Zj
oa0@4006ooooo`03o`000?oooooooooo07?ooooo0_l000001?oooooo0000o`000?ooool4o`0000;o
oooo1_l00008ooooo`?o00002?ooool2o`0000Gooooo0_l00002ooooo`;o00000oooool2o`0000co
oooo0_l00008ooooo`;o00001Oooool2o`00083ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMg
M`_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo07?ooooo0_l00000
1?oooooo0000o`000?ooool2o`0000Gooooo1_l0000?ooooo`;o00003?ooool2o`0000;ooooo0ol0
000Mooooo`;o00001Oooool2o`0007Wooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo
00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo07Wooooo0_l00005ooooo`;o
00000_ooool2o`000003ooooool0003o000000cooooo0_l00003ooooo`;o00002?ooool2o`000003
ooooool0003o000000[ooooo0_l0000Iooooo`;o0000NOooool001cooooo00?o0000ooooooooool0
KOooool2o`0000[ooooo1?l0000:ooooo`;o00004Oooool2o`0000Sooooo0_l0000=ooooo`;o0000
3_ooool2o`0000_ooooo0_l0001gooooo`007?ooool00ol0003oooooooooo`1]ooooo`;o00003?oo
ool2o`00013ooooo0_l0000;ooooo`;o00003Oooool2o`0000Cooooo0_l0000Booooo`;o00002_oo
ool3o`0007Oooooo000Looooo`03o`000?oooooooooo07[ooooo0_l0000Aooooo`;o00002oooool2
o`0000gooooo0_l00004ooooo`;o00000_ooool2o`000003ooooool0003o000001;ooooo0_l00003
ooooo`;o00003_ooool2o`0006Sooooo000Looooo`03o`000?oooooooooo07[ooooo0_l00003oooo
o`;o00003oooool2o`0000?ooooo0_l00007ooooo`;o00001Oooool2o`0000[ooooo1?l000000ooo
oooo0000o`00000Booooo`;o00001_ooool2o`0000_ooooo0_l0001Xooooo`007?ooool00ol0003o
ooooooooo`1]ooooo`;o00004?ooool2o`0000oooooo0_l00003ooooo`;o00001oooool2o`0000Go
oooo0_l0000:ooooo`;o00007oooool2o`0007Gooooo000Looooo`03o`000?oooooooooo06gooooo
0_l0000Eooooo`;o00001oooool2o`000;[ooooo000Looooo`03o`000?oooooooooo08;ooooo1?l0
0007ooooo`;o00004?ooool2o`000:Sooooo000Looooo`03o`000?oooooooooo07oooooo0_l00000
0ooooooo0000o`000004ooooo`;o00001Oooool2o`0000Wooooo0_l00003ooooo`;o00008?ooool2
o`0008Kooooo000Looooo`03o`000?oooooooooo07oooooo0_l00007ooooo`;o00000_ooool2o`00
0003ooooool0003o000000Wooooo0_l0000Uooooo`;o0000Q_ooool001cooooo00?o0000oooooooo
ool0S?ooool2o`000003ooooool0003o0000037ooooo0_l00025ooooo`007?ooool00ol0003ooooo
ooooo`1mooooo`;o0000@oooool2o`000003ooooool0003o000008;ooooo000Looooo`;o0000O_oo
ool2o`0001Cooooo0_l0000`ooooo`;o0000P_ooool001cooooo00?o0000ooooooooool0Toooool2
o`000;Cooooo000Looooo`03o`000?oooooooooo0;_ooooo0_l0002<ooooo`007?ooool00ol0003o
ooooooooo`1oooooo`;o0000>_ooool2o`0008cooooo000Looooo`03o`000?oooooooooo07oooooo
0_l00038ooooo`007?ooool00ol0003oooooooooo`2Uooooo`;o00002?ooool2o`0009Sooooo000L
ooooo`03o`000?oooooooooo08Cooooo0_l00008ooooo`;o00005Oooool2o`0000Sooooo0_l0002H
ooooo`007?ooool00ol0003oooooooooo`24ooooo`;o00002?ooool2o`000;Wooooo000Looooo`03
o`000?oooooooooo08Kooooo0_l00010ooooo`;o0000Ooooool001cooooo00?o0000ooooooooool0
Q_ooool2o`0000_ooooo0_l0000cooooo`;o0000Ooooool001cooooo00?o0000ooooooooool0Tooo
ool2o`000;Cooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0X?ooool2o`000:Oooooo000Looooo`03o`000?oooooooooo0:3ooooo0_l0002Wooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo08oooooo0_l0
002hooooo`007?ooool2o`00093ooooo0_l0002hooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`004_ooool4
o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000oooooooo
ool01Oooool3o`000?ooooooB_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?oo
ool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool0
01Cooooo00?o0000ooooooooool0oooooomBooooo`004_ooool00omEEEGoIVIVo`00003ooooooeCo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Qooooo`04oa0@4?l0003o0000
ooooo`;o000000?o410@ooooooooool05_ooool4o`000003oa0@4?oooooooooo00Go00001Oooool2
o`000009oa0@4?ooooooooooooooooo<c<co8B4Qo`000?lQ8B7oc<c<08cooooo002Rooooo`05o`00
0?ooooooooooooooool000002Oooool6o`0000cooooo00?o0000ooooooooool00_ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool00_ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q08cooooo002Rooooo`05o`000?ooooooooooooooool000006oooool00ol0003oooooooooo`03
ooooo`03oiRHV?lQ8B7ok^k^00Cooooo1Ol00003ooooo`05o`000?ooooooooooooooool00000S?oo
ool00:;ooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00003?ooool00ol0003ooooooooo
o`04ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00CoA4A4omgMgOoooooo00001?ooool01Olb<S;oV9RH
oooooonHV9So<S8b08cooooo002Rooooo`05o`000?n7QhOoooooojVYZOl000006oooool00ol0003o
ooooooooo`05ooooo`03ogMgMomVIVKooooo00;ooooo00CogMgMoeEEEOoooooo00001?ooool01Oo<
c<co0000o`000?l0003oc<c<08cooooo002Qooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHoooo
ooooool06Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?oMgMgolc<
c?l000001?ooool01Ol@413o^[Zjoooooonj^[[o410@08cooooo0032ooooo`03o`000?oooooooooo
00;ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03onk^k_m4A4Co000000Cooooo00Go0000
okZj^_oooooo^[Zjo`00002<ooooo`00`?ooool00omEEEGoIVIVo`000004ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01Oooool00omgMgOo0000ooooo`03ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0
S?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1254) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.6576 .6343 Mdot
.65951 .60291 Mdot
.49269 .36135 Mdot
.43134 .64092 Mdot
.5477 .20103 Mdot
.46078 .35198 Mdot
.61696 .42458 Mdot
.67048 .39994 Mdot
.47535 .37665 Mdot
.75132 .42269 Mdot
.63885 .40135 Mdot
.53122 .58033 Mdot
.65723 .41469 Mdot
.43136 .61137 Mdot
.53291 .14151 Mdot
.41733 .56764 Mdot
.66511 .62129 Mdot
.36377 .43368 Mdot
.41486 .65848 Mdot
.50846 .36856 Mdot
.57006 .6037 Mdot
.43712 .61765 Mdot
.61945 .57902 Mdot
.43117 .61062 Mdot
.45662 .64869 Mdot
.60588 .60739 Mdot
.61583 .64136 Mdot
.47746 .62828 Mdot
.49331 .62313 Mdot
.66772 .39559 Mdot
.28196 .5489 Mdot
.52132 .1638 Mdot
.48466 .6746 Mdot
.27658 .30131 Mdot
.66435 .43281 Mdot
.54999 .76615 Mdot
.47267 .35688 Mdot
.63829 .42746 Mdot
.63381 .43033 Mdot
.64993 .45123 Mdot
.63982 .41277 Mdot
.61655 .59045 Mdot
.66611 .49005 Mdot
.40076 .36066 Mdot
.42226 .57245 Mdot
.66264 .27398 Mdot
.62219 .78844 Mdot
.46078 .57883 Mdot
.64996 .6267 Mdot
.33348 .30409 Mdot
.5667 .27219 Mdot
.63029 .44957 Mdot
.50303 .38254 Mdot
.20721 .72784 Mdot
.64938 .43606 Mdot
.40852 .67479 Mdot
.48297 .35929 Mdot
.44762 .60916 Mdot
.43167 .60594 Mdot
.50335 .71164 Mdot
.43541 .57485 Mdot
.3169 .4255 Mdot
.68691 .59084 Mdot
.5935 .49921 Mdot
.47184 .37185 Mdot
.62885 .4188 Mdot
.64825 .59307 Mdot
.65994 .42144 Mdot
.37933 .59225 Mdot
.51397 .35831 Mdot
.46436 .57828 Mdot
.63421 .40829 Mdot
.67774 .61911 Mdot
.48602 .60349 Mdot
.34075 .38166 Mdot
.78722 .36107 Mdot
.33496 .4852 Mdot
.54114 .74579 Mdot
.47512 .72667 Mdot
.36494 .31865 Mdot
.43196 .6589 Mdot
.32771 .58327 Mdot
.74805 .32359 Mdot
.60711 .58204 Mdot
.48671 .56199 Mdot
.26564 .44583 Mdot
.48322 .60494 Mdot
.68555 .26619 Mdot
.49768 .59088 Mdot
.27294 .39652 Mdot
.46109 .38252 Mdot
.64202 .61056 Mdot
.43063 .64296 Mdot
.49301 .60297 Mdot
.38271 .73339 Mdot
.46173 .67705 Mdot
.45423 .62675 Mdot
.62626 .62757 Mdot
.63395 .44877 Mdot
.46 .68419 Mdot
.40495 .35018 Mdot
.44305 .38562 Mdot
.40358 .61605 Mdot
.43851 .34484 Mdot
.67891 .58805 Mdot
.48904 .59937 Mdot
.63436 .43651 Mdot
.40916 .60564 Mdot
.74333 .59292 Mdot
.66318 .60094 Mdot
.4843 .62483 Mdot
.31583 .46263 Mdot
.35774 .7664 Mdot
.6491 .6172 Mdot
.42362 .2994 Mdot
.45931 .66572 Mdot
.45999 .61776 Mdot
.65602 .60344 Mdot
.43138 .33974 Mdot
.7031 .27703 Mdot
.59196 .60829 Mdot
.67156 .4339 Mdot
.66114 .63659 Mdot
.42148 .55304 Mdot
.45545 .37403 Mdot
.48995 .25476 Mdot
.70124 .53995 Mdot
.29492 .52509 Mdot
.47923 .60358 Mdot
.72814 .47014 Mdot
.46113 .39145 Mdot
.63598 .60154 Mdot
.66298 .41562 Mdot
.52508 .59059 Mdot
.65489 .5813 Mdot
.64913 .39279 Mdot
.30702 .45178 Mdot
.58911 .32362 Mdot
.66571 .58011 Mdot
.4194 .45097 Mdot
.63037 .39366 Mdot
.63403 .45344 Mdot
.21486 .37898 Mdot
.64533 .59457 Mdot
.31876 .44223 Mdot
.66798 .41004 Mdot
.27017 .51484 Mdot
.419 .57749 Mdot
.30608 .60842 Mdot
.62087 .80286 Mdot
.2597 .31788 Mdot
.61326 .33318 Mdot
.3457 .44427 Mdot
.6796 .39772 Mdot
.45293 .64167 Mdot
.61105 .61618 Mdot
.60791 .59455 Mdot
.42803 .57941 Mdot
.44025 .65375 Mdot
.47327 .57919 Mdot
.49363 .5958 Mdot
.61189 .66338 Mdot
.44697 .6735 Mdot
.54128 .81393 Mdot
.63998 .61374 Mdot
.44076 .6418 Mdot
.46879 .32705 Mdot
.50764 .63885 Mdot
.63639 .4112 Mdot
.44551 .6155 Mdot
.43305 .64262 Mdot
.42188 .58029 Mdot
.63393 .45046 Mdot
.57946 .16919 Mdot
.40712 .77306 Mdot
.5321 .17983 Mdot
.29975 .39508 Mdot
.45238 .33627 Mdot
.47751 .61247 Mdot
.3104 .44557 Mdot
.60912 .74035 Mdot
.41886 .62803 Mdot
.59616 .85945 Mdot
.447 .62552 Mdot
.55327 .19303 Mdot
.38944 .66227 Mdot
.44067 .18479 Mdot
.31748 .57813 Mdot
.46478 .63867 Mdot
.58865 .52067 Mdot
.60145 .46951 Mdot
.46007 .30581 Mdot
.64328 .41307 Mdot
.47325 .3285 Mdot
.49003 .35834 Mdot
.64573 .49008 Mdot
.55773 .61047 Mdot
.42605 .69506 Mdot
.5075 .60728 Mdot
.51624 .35635 Mdot
.67573 .57621 Mdot
.30459 .42547 Mdot
.62009 .63234 Mdot
.75569 .26183 Mdot
.60232 .25993 Mdot
.61782 .3989 Mdot
.33239 .41549 Mdot
.47958 .38287 Mdot
.43754 .37403 Mdot
.33195 .46689 Mdot
.45325 .5901 Mdot
.63964 .59058 Mdot
.24424 .31306 Mdot
.76761 .58087 Mdot
.19797 .38219 Mdot
.6311 .62757 Mdot
.76224 .4713 Mdot
.65516 .39465 Mdot
.47603 .34333 Mdot
.45874 .62059 Mdot
.45801 .59464 Mdot
.5807 .59102 Mdot
.47364 .58055 Mdot
.53364 .56255 Mdot
.46397 .62685 Mdot
.54911 .29292 Mdot
.3522 .48256 Mdot
.64422 .49004 Mdot
.30868 .51126 Mdot
.60006 .59553 Mdot
.26523 .64729 Mdot
.43573 .35255 Mdot
.59774 .73922 Mdot
.62753 .41199 Mdot
.30567 .43677 Mdot
.44054 .36736 Mdot
.29977 .43956 Mdot
.42933 .67027 Mdot
.49059 .33439 Mdot
.34081 .46774 Mdot
.43787 .71462 Mdot
.46161 .56542 Mdot
.73312 .63286 Mdot
.6605 .44263 Mdot
.59335 .62158 Mdot
.44658 .57191 Mdot
.4501 .33297 Mdot
.52619 .6132 Mdot
.68401 .34225 Mdot
.5116 .27162 Mdot
.43705 .38554 Mdot
.50679 .28131 Mdot
.31668 .42264 Mdot
.65926 .30723 Mdot
.7488 .47851 Mdot
.6622 .62621 Mdot
.46083 .6757 Mdot
.41782 .18352 Mdot
.66789 .41102 Mdot
.41647 .59856 Mdot
.34557 .26004 Mdot
.66125 .42877 Mdot
.44973 .60784 Mdot
.67254 .39484 Mdot
.60903 .59265 Mdot
.35893 .74621 Mdot
.66026 .62415 Mdot
.50094 .60026 Mdot
.63672 .44042 Mdot
.45791 .32146 Mdot
.61147 .61102 Mdot
.44784 .58679 Mdot
.47759 .6238 Mdot
.56363 .45208 Mdot
.44498 .63674 Mdot
.57741 .17782 Mdot
.46499 .63278 Mdot
.48835 .3452 Mdot
.40132 .62859 Mdot
.30577 .77197 Mdot
.69016 .46261 Mdot
.64627 .59255 Mdot
.42766 .34269 Mdot
.48121 .37075 Mdot
.39744 .35404 Mdot
.59845 .43238 Mdot
.4465 .66885 Mdot
.44988 .33603 Mdot
.29893 .6627 Mdot
.6321 .39627 Mdot
.48081 .67294 Mdot
.43329 .46112 Mdot
.31783 .3209 Mdot
.50148 .383 Mdot
.49873 .66884 Mdot
.66845 .57971 Mdot
.43158 .64615 Mdot
.43216 .36486 Mdot
.56664 .63339 Mdot
.47213 .65168 Mdot
.60574 .56271 Mdot
.56484 .45046 Mdot
.61964 .41069 Mdot
.39592 .67317 Mdot
.42523 .59001 Mdot
.46954 .33129 Mdot
.5981 .60214 Mdot
.63518 .39312 Mdot
.61179 .59848 Mdot
.3942 .20973 Mdot
.73141 .60913 Mdot
.4772 .70596 Mdot
.33307 .41187 Mdot
.31042 .30709 Mdot
.40978 .19472 Mdot
.22602 .62935 Mdot
.253 .60687 Mdot
.30437 .25501 Mdot
.43625 .33532 Mdot
.34489 .26799 Mdot
.48497 .3647 Mdot
.4527 .65716 Mdot
.45838 .37346 Mdot
.40324 .19218 Mdot
.46205 .62721 Mdot
.46122 .36749 Mdot
.28788 .68026 Mdot
.43762 .6469 Mdot
.66307 .61539 Mdot
.66976 .21999 Mdot
.25236 .69553 Mdot
.52141 .27834 Mdot
.50507 .358 Mdot
.23728 .55348 Mdot
.4538 .62911 Mdot
.40511 .63652 Mdot
.63264 .62173 Mdot
.50146 .66094 Mdot
.3341 .42428 Mdot
.33732 .41766 Mdot
.59917 .39112 Mdot
.34421 .58807 Mdot
.39517 .66785 Mdot
.61601 .6142 Mdot
.6439 .66927 Mdot
.31296 .37698 Mdot
.33761 .29598 Mdot
.65821 .37851 Mdot
.66374 .2185 Mdot
.5089 .55004 Mdot
.69238 .42273 Mdot
.47453 .29853 Mdot
.656 .61299 Mdot
.56111 .16513 Mdot
.64394 .41726 Mdot
.73433 .67876 Mdot
.43833 .50056 Mdot
.45059 .59221 Mdot
.62191 .41673 Mdot
.54678 .61613 Mdot
.23568 .67855 Mdot
.76747 .65954 Mdot
.38492 .53005 Mdot
.50117 .59312 Mdot
.35546 .38992 Mdot
.45133 .61693 Mdot
.72315 .32462 Mdot
.46869 .63232 Mdot
.61391 .6027 Mdot
.74079 .39986 Mdot
.58454 .4273 Mdot
.44546 .80149 Mdot
.68331 .31736 Mdot
.34581 .44318 Mdot
.46433 .62186 Mdot
.44783 .59219 Mdot
.33827 .42897 Mdot
.63624 .56822 Mdot
.49329 .59147 Mdot
.25374 .63138 Mdot
.48236 .59365 Mdot
.63703 .41859 Mdot
.42358 .5188 Mdot
.69705 .57548 Mdot
.50049 .62579 Mdot
.68576 .605 Mdot
.61461 .41685 Mdot
.64192 .438 Mdot
.38762 .65245 Mdot
.65061 .4528 Mdot
.43941 .62781 Mdot
.78217 .65076 Mdot
.67117 .58674 Mdot
.57342 .55392 Mdot
.63511 .57942 Mdot
.52669 .74671 Mdot
.65261 .44049 Mdot
.56214 .28517 Mdot
.53011 .58555 Mdot
.64739 .41654 Mdot
.71872 .62545 Mdot
.40637 .57955 Mdot
.47362 .56439 Mdot
.2238 .41789 Mdot
.50119 .35941 Mdot
.57529 .46182 Mdot
.67063 .39749 Mdot
.43799 .58565 Mdot
.48089 .65746 Mdot
.61334 .4237 Mdot
.77663 .61963 Mdot
.27669 .69699 Mdot
.46405 .63007 Mdot
.62257 .60641 Mdot
.63227 .59954 Mdot
.49303 .5764 Mdot
.41067 .63383 Mdot
.44782 .366 Mdot
.45343 .32024 Mdot
.50121 .33971 Mdot
.56684 .44941 Mdot
.55484 .28455 Mdot
.55868 .22519 Mdot
.64902 .45167 Mdot
.74643 .50859 Mdot
.26879 .40216 Mdot
.50519 .62606 Mdot
.49552 .37945 Mdot
.42101 .59808 Mdot
.43188 .63202 Mdot
.61029 .41978 Mdot
.43306 .23706 Mdot
.5548 .59419 Mdot
.63139 .56597 Mdot
.6494 .38446 Mdot
.4213 .548 Mdot
.71326 .41424 Mdot
.31022 .45248 Mdot
.23594 .37295 Mdot
.62993 .41191 Mdot
.66194 .61352 Mdot
.67012 .42824 Mdot
.46589 .59335 Mdot
.40679 .65952 Mdot
.65241 .60704 Mdot
.35505 .44162 Mdot
.52407 .61928 Mdot
.45315 .60874 Mdot
.58488 .828 Mdot
.23876 .43143 Mdot
.55258 .30707 Mdot
.46386 .63703 Mdot
.49389 .63603 Mdot
.32883 .47567 Mdot
.47792 .59214 Mdot
.46744 .57398 Mdot
.37656 .76543 Mdot
.71822 .54595 Mdot
.34907 .42356 Mdot
.78538 .63049 Mdot
.63755 .62894 Mdot
.46725 .17192 Mdot
.47297 .33717 Mdot
.64279 .36982 Mdot
.30069 .72452 Mdot
.50536 .38132 Mdot
.61564 .33685 Mdot
.49416 .16963 Mdot
.57585 .45801 Mdot
.52568 .37461 Mdot
.52154 .56589 Mdot
.49116 .59197 Mdot
.45872 .61432 Mdot
.31204 .43663 Mdot
.63401 .58924 Mdot
.56945 .46935 Mdot
.82854 .48027 Mdot
.44042 .61977 Mdot
.54627 .55563 Mdot
.80265 .49303 Mdot
.31884 .32404 Mdot
.33403 .45277 Mdot
.35053 .42931 Mdot
.4645 .61877 Mdot
.36937 .77633 Mdot
.60654 .60922 Mdot
.44617 .58704 Mdot
.45683 .67183 Mdot
.50264 .35496 Mdot
.66756 .59696 Mdot
.42897 .34818 Mdot
.58673 .28223 Mdot
.53632 .1848 Mdot
.61897 .82457 Mdot
.64844 .44015 Mdot
.76258 .36832 Mdot
.66048 .38839 Mdot
.33136 .57134 Mdot
.4487 .39313 Mdot
.42248 .6429 Mdot
.60003 .59738 Mdot
.43204 .58903 Mdot
.41444 .63881 Mdot
.45057 .59038 Mdot
.49354 .64407 Mdot
.49507 .86834 Mdot
.34793 .45991 Mdot
.42353 .55638 Mdot
.49213 .35017 Mdot
.71639 .29563 Mdot
.78254 .36267 Mdot
.44308 .59475 Mdot
.47307 .62318 Mdot
.65844 .57817 Mdot
.42448 .58392 Mdot
.64942 .38926 Mdot
.5979 .62005 Mdot
.49236 .60809 Mdot
.68584 .241 Mdot
.4897 .62453 Mdot
.47689 .18125 Mdot
.67386 .41734 Mdot
.74979 .59527 Mdot
.408 .56531 Mdot
.52196 .2828 Mdot
.57524 .46191 Mdot
.44361 .36732 Mdot
.66808 .4433 Mdot
.47156 .3595 Mdot
.83367 .51503 Mdot
.39654 .64978 Mdot
.45326 .64412 Mdot
.48605 .66089 Mdot
.45349 .33465 Mdot
.66053 .25044 Mdot
.65003 .2934 Mdot
.4346 .5477 Mdot
.45252 .34196 Mdot
.68597 .59388 Mdot
.25044 .48276 Mdot
.6266 .58067 Mdot
.31183 .41236 Mdot
.64387 .4006 Mdot
.35028 .43371 Mdot
.33557 .25861 Mdot
.66197 .60314 Mdot
.58603 .61971 Mdot
.46952 .34063 Mdot
.45412 .4902 Mdot
.13483 .54284 Mdot
.44445 .49839 Mdot
.31053 .55193 Mdot
.62933 .61874 Mdot
.49634 .62284 Mdot
.357 .53304 Mdot
.49291 .49748 Mdot
.47167 .362 Mdot
.42249 .62501 Mdot
.34922 .74267 Mdot
.4476 .36593 Mdot
.47272 .67502 Mdot
.49734 .35468 Mdot
.64411 .40642 Mdot
.48716 .38282 Mdot
.60148 .57645 Mdot
.48557 .61287 Mdot
.13415 .48451 Mdot
.35325 .48651 Mdot
.45551 .63309 Mdot
.65208 .383 Mdot
.60616 .36701 Mdot
.41061 .62064 Mdot
.30944 .46102 Mdot
.45468 .36089 Mdot
.42227 .49657 Mdot
.466 .63096 Mdot
.45605 .33508 Mdot
.65751 .63505 Mdot
.68101 .41888 Mdot
.42488 .73547 Mdot
.53338 .29872 Mdot
.63266 .6226 Mdot
.40885 .42649 Mdot
.64326 .46002 Mdot
.49408 .63655 Mdot
.46389 .67438 Mdot
.62449 .60339 Mdot
.34323 .68795 Mdot
.40003 .6094 Mdot
.43101 .65782 Mdot
.48989 .34242 Mdot
.46663 .3604 Mdot
.34638 .71484 Mdot
.44155 .32718 Mdot
.40476 .65733 Mdot
.62239 .60199 Mdot
.4282 .641 Mdot
.66886 .58789 Mdot
.42156 .5874 Mdot
.59418 .64115 Mdot
.63323 .56851 Mdot
.69538 .44924 Mdot
.42579 .62928 Mdot
.44522 .69407 Mdot
.41075 .60599 Mdot
.48296 .58736 Mdot
.44918 .37226 Mdot
.32523 .45799 Mdot
.44187 .68046 Mdot
.29723 .45587 Mdot
.30029 .43812 Mdot
.59692 .45785 Mdot
.50282 .35813 Mdot
.3243 .43495 Mdot
.80867 .49615 Mdot
.50193 .34265 Mdot
.3204 .42657 Mdot
.77926 .35937 Mdot
.6613 .43589 Mdot
.67191 .58419 Mdot
.43819 .64859 Mdot
.34371 .24166 Mdot
.62132 .79086 Mdot
.47092 .31011 Mdot
.46267 .63315 Mdot
.4144 .60507 Mdot
.59419 .59785 Mdot
.84885 .52823 Mdot
.51328 .35637 Mdot
.47935 .64279 Mdot
.65422 .59338 Mdot
.84923 .5804 Mdot
.48711 .34966 Mdot
.31679 .42858 Mdot
.64955 .44883 Mdot
.61672 .56044 Mdot
.70055 .54069 Mdot
.61754 .41767 Mdot
.51054 .31503 Mdot
.56324 .27483 Mdot
.45968 .6661 Mdot
.48905 .38469 Mdot
.20596 .40477 Mdot
.68381 .6574 Mdot
.62341 .49226 Mdot
.23361 .54095 Mdot
.6533 .61395 Mdot
.65516 .38862 Mdot
.34791 .45072 Mdot
.62393 .62552 Mdot
.66567 .6161 Mdot
.60979 .43575 Mdot
.43214 .76316 Mdot
.43275 .46289 Mdot
.63443 .42558 Mdot
.24615 .40453 Mdot
.48783 .23247 Mdot
.49716 .37874 Mdot
.33352 .42451 Mdot
.35464 .24668 Mdot
.61476 .59174 Mdot
.65522 .21061 Mdot
.21997 .39567 Mdot
.45401 .62679 Mdot
.32481 .43955 Mdot
.62918 .23742 Mdot
.83961 .46064 Mdot
.65814 .43195 Mdot
.58125 .41625 Mdot
.33335 .4211 Mdot
.44249 .57325 Mdot
.25677 .49866 Mdot
.43268 .65684 Mdot
.65023 .39709 Mdot
.48956 .71313 Mdot
.66463 .61229 Mdot
.61131 .44887 Mdot
.23395 .37326 Mdot
.43834 .62623 Mdot
.42407 .62925 Mdot
.32383 .50761 Mdot
.60052 .61481 Mdot
.44336 .36665 Mdot
.45765 .66887 Mdot
.45021 .61151 Mdot
.41814 .67522 Mdot
.40399 .68098 Mdot
.35325 .75825 Mdot
.46428 .65003 Mdot
.64817 .28081 Mdot
.50535 .59759 Mdot
.427 .62134 Mdot
.68535 .60144 Mdot
.60868 .83521 Mdot
.59667 .27858 Mdot
.44763 .61447 Mdot
.49218 .63065 Mdot
.61654 .45375 Mdot
.45837 .47579 Mdot
.44791 .48641 Mdot
.41844 .49494 Mdot
.24605 .58222 Mdot
.5025 .58083 Mdot
.64412 .58776 Mdot
.33558 .47001 Mdot
.47358 .65281 Mdot
.64822 .58887 Mdot
.41557 .58265 Mdot
.44711 .36318 Mdot
.4989 .33943 Mdot
.68098 .65054 Mdot
.33002 .43329 Mdot
.49539 .52595 Mdot
.73761 .50966 Mdot
.47859 .33022 Mdot
.45344 .64633 Mdot
.61702 .39592 Mdot
.43321 .36704 Mdot
.48645 .2742 Mdot
.3954 .70911 Mdot
.60389 .61153 Mdot
.64268 .61296 Mdot
.3069 .61507 Mdot
.61126 .32316 Mdot
.48866 .82889 Mdot
.64406 .40509 Mdot
.39629 .63408 Mdot
.74187 .46425 Mdot
.64537 .61528 Mdot
.34586 .54445 Mdot
.32672 .43645 Mdot
.66244 .42845 Mdot
.50478 .41237 Mdot
.65477 .57872 Mdot
.66919 .61716 Mdot
.49289 .58345 Mdot
.45172 .6023 Mdot
.2583 .61823 Mdot
.32157 .40015 Mdot
.61783 .41177 Mdot
.33017 .42301 Mdot
.45186 .39334 Mdot
.46943 .64882 Mdot
.61975 .57764 Mdot
.48074 .24009 Mdot
.47979 .64538 Mdot
.45089 .37914 Mdot
.64937 .61131 Mdot
.31936 .42095 Mdot
.30563 .45903 Mdot
.48386 .58959 Mdot
.58912 .66869 Mdot
.64245 .42706 Mdot
.65918 .61667 Mdot
.71055 .42129 Mdot
.40656 .63635 Mdot
.46098 .60327 Mdot
.37473 .65052 Mdot
.61862 .40778 Mdot
.77931 .51899 Mdot
.31335 .41533 Mdot
.63657 .59305 Mdot
.47072 .64031 Mdot
.32834 .42658 Mdot
.76716 .49433 Mdot
.43888 .38764 Mdot
.48517 .38283 Mdot
.31066 .464 Mdot
.33039 .44685 Mdot
.30543 .4539 Mdot
.65584 .21024 Mdot
.60478 .58101 Mdot
.51027 .55182 Mdot
.39639 .62074 Mdot
.31396 .57154 Mdot
.51513 .57478 Mdot
.63371 .39233 Mdot
.49967 .36194 Mdot
.40819 .62295 Mdot
.50077 .60914 Mdot
.37948 .61715 Mdot
.56584 .56107 Mdot
.70658 .58843 Mdot
.66518 .60015 Mdot
.3901 .62724 Mdot
.49951 .34764 Mdot
.76682 .26732 Mdot
.27645 .25252 Mdot
.3998 .57405 Mdot
.41997 .46806 Mdot
.61776 .57787 Mdot
.62952 .45736 Mdot
.32601 .49866 Mdot
.66015 .43915 Mdot
.63816 .59619 Mdot
.46563 .65006 Mdot
.74556 .51678 Mdot
.31794 .47107 Mdot
.45109 .58092 Mdot
.6613 .3965 Mdot
.45905 .57771 Mdot
.61702 .41993 Mdot
.40671 .20338 Mdot
.20574 .48549 Mdot
.44823 .62535 Mdot
.44936 .55541 Mdot
.22784 .55342 Mdot
.43853 .59483 Mdot
.34483 .40258 Mdot
.61871 .57693 Mdot
.37414 .72987 Mdot
.44043 .56242 Mdot
.64915 .69161 Mdot
.4128 .64626 Mdot
.31902 .71036 Mdot
.46053 .6009 Mdot
.31128 .33647 Mdot
.48511 .62093 Mdot
.47794 .57892 Mdot
.64228 .44245 Mdot
.61319 .45039 Mdot
.67867 .61986 Mdot
.44672 .3372 Mdot
.50496 .17707 Mdot
.45646 .6069 Mdot
.50657 .26644 Mdot
.74782 .54598 Mdot
.33225 .44817 Mdot
.6333 .59389 Mdot
.85926 .50787 Mdot
.67655 .406 Mdot
.22901 .45082 Mdot
.32234 .69813 Mdot
.67099 .50813 Mdot
.26714 .45313 Mdot
.73982 .38346 Mdot
.31272 .42439 Mdot
.41921 .58287 Mdot
.4574 .23854 Mdot
.30055 .35435 Mdot
.39807 .71162 Mdot
.63802 .46284 Mdot
.61749 .7251 Mdot
.44699 .23345 Mdot
.29728 .42771 Mdot
.34073 .4228 Mdot
.62357 .44745 Mdot
.48211 .41772 Mdot
.55321 .60405 Mdot
.32978 .43874 Mdot
.46954 .32449 Mdot
.50954 .3554 Mdot
.51104 .37802 Mdot
.60471 .60321 Mdot
.23004 .34963 Mdot
.71821 .39986 Mdot
.61991 .41277 Mdot
.46489 .41209 Mdot
.69909 .61904 Mdot
.59302 .5899 Mdot
.47212 .34772 Mdot
.45706 .38577 Mdot
.64035 .56664 Mdot
.39973 .66747 Mdot
.38329 .61318 Mdot
.44406 .61796 Mdot
.31351 .45143 Mdot
.45605 .59826 Mdot
.45108 .34927 Mdot
.65673 .43028 Mdot
.46749 .38503 Mdot
.66546 .38392 Mdot
.5803 .23356 Mdot
.45928 .58507 Mdot
.48452 .61664 Mdot
.65473 .77723 Mdot
.66546 .63117 Mdot
.63091 .26461 Mdot
.54228 .31799 Mdot
.48744 .36215 Mdot
.46345 .57309 Mdot
.59645 .61941 Mdot
.2934 .42835 Mdot
.67813 .76549 Mdot
.40552 .62533 Mdot
.62528 .57666 Mdot
.47295 .6427 Mdot
.58963 .65943 Mdot
.35419 .79751 Mdot
.61722 .59587 Mdot
.6197 .80232 Mdot
.49268 .62617 Mdot
.77954 .41852 Mdot
.48963 .66299 Mdot
.30286 .65061 Mdot
.40003 .60986 Mdot
.63471 .62861 Mdot
.44248 .61452 Mdot
.60252 .62387 Mdot
.47628 .33191 Mdot
.63313 .45607 Mdot
.63853 .62082 Mdot
.4715 .6722 Mdot
.13498 .36088 Mdot
.65376 .39976 Mdot
.46156 .62075 Mdot
.64504 .44744 Mdot
.6336 .5861 Mdot
.64953 .62506 Mdot
.82551 .44096 Mdot
.5939 .28461 Mdot
.64494 .40711 Mdot
.47079 .64681 Mdot
.71996 .35609 Mdot
.43032 .65068 Mdot
.27509 .61785 Mdot
.41244 .67745 Mdot
.39923 .62505 Mdot
.79088 .36879 Mdot
.62067 .40694 Mdot
.46832 .82736 Mdot
.82457 .42153 Mdot
.72136 .29901 Mdot
.57215 .59576 Mdot
.29616 .42788 Mdot
.56956 .16655 Mdot
.55937 .28604 Mdot
.4536 .33818 Mdot
.40815 .61437 Mdot
.70023 .58907 Mdot
.64025 .43211 Mdot
.32578 .46044 Mdot
.44932 .62489 Mdot
.46277 .38751 Mdot
.24678 .66249 Mdot
.67652 .39177 Mdot
.61924 .58943 Mdot
.6255 .56767 Mdot
.78476 .68126 Mdot
.46673 .63842 Mdot
.48826 .61124 Mdot
.64594 .39894 Mdot
.79291 .49296 Mdot
.3067 .42794 Mdot
.27678 .67128 Mdot
.64657 .40678 Mdot
.53693 .46715 Mdot
.65273 .59638 Mdot
.41596 .60264 Mdot
.62818 .2212 Mdot
.36311 .38694 Mdot
.70543 .70781 Mdot
.31084 .44577 Mdot
.27229 .60884 Mdot
.63847 .62943 Mdot
.66529 .41281 Mdot
.5829 .3408 Mdot
.51168 .5961 Mdot
.42098 .60071 Mdot
.27591 .60653 Mdot
.58756 .43998 Mdot
.39142 .52622 Mdot
.40685 .63122 Mdot
.58584 .46936 Mdot
.4037 .6077 Mdot
.51024 .58146 Mdot
.40374 .66341 Mdot
.47276 .60329 Mdot
.62236 .57658 Mdot
.37062 .60132 Mdot
.44479 .35375 Mdot
.47827 .53034 Mdot
.54252 .47497 Mdot
.45922 .63124 Mdot
.4459 .66262 Mdot
.66342 .73678 Mdot
.62679 .34616 Mdot
.63943 .61845 Mdot
.57752 .60452 Mdot
.65931 .44762 Mdot
.38174 .6145 Mdot
.44167 .34472 Mdot
.51712 .58333 Mdot
.45114 .37625 Mdot
.61763 .58038 Mdot
.48828 .35722 Mdot
.64228 .45184 Mdot
.50586 .36778 Mdot
.55409 .284 Mdot
.66975 .40807 Mdot
.61158 .61756 Mdot
.48569 .60121 Mdot
.65317 .38302 Mdot
.29258 .51429 Mdot
.31285 .44956 Mdot
.82758 .4012 Mdot
.49297 .60954 Mdot
.7155 .54869 Mdot
.54051 .64352 Mdot
.462 .38564 Mdot
.37445 .79935 Mdot
.62943 .56716 Mdot
.35612 .43395 Mdot
.60068 .5932 Mdot
.23124 .42506 Mdot
.32367 .45222 Mdot
.77368 .34146 Mdot
.53761 .33453 Mdot
.24339 .44632 Mdot
.38681 .6439 Mdot
.27759 .48741 Mdot
.49171 .38825 Mdot
.64129 .43313 Mdot
.59481 .34116 Mdot
.4685 .57512 Mdot
.20566 .57558 Mdot
.67178 .57703 Mdot
.44631 .33961 Mdot
.66076 .41841 Mdot
.63774 .39112 Mdot
.42625 .66184 Mdot
.37203 .2899 Mdot
.42928 .58645 Mdot
.60755 .31179 Mdot
.25181 .58609 Mdot
.57016 .57839 Mdot
.46374 .62631 Mdot
.47091 .3312 Mdot
.47277 .64291 Mdot
.35176 .42083 Mdot
.21783 .35791 Mdot
.51656 .63817 Mdot
.54548 .31838 Mdot
.3472 .48889 Mdot
.65647 .60623 Mdot
.51347 .66459 Mdot
.56129 .29659 Mdot
.46667 .64138 Mdot
.39573 .86187 Mdot
.32379 .42617 Mdot
.45016 .24265 Mdot
.48607 .65247 Mdot
.44001 .669 Mdot
.59702 .50927 Mdot
.67691 .53074 Mdot
.3657 .39108 Mdot
.43135 .59991 Mdot
.26162 .54966 Mdot
.61945 .43557 Mdot
.41911 .59218 Mdot
.46043 .61555 Mdot
.47917 .77843 Mdot
.64981 .38634 Mdot
.48652 .36958 Mdot
.49233 .38964 Mdot
.4562 .31457 Mdot
.35646 .42666 Mdot
.56903 .42304 Mdot
.3334 .54884 Mdot
.24 .67275 Mdot
.35783 .45761 Mdot
.49563 .60158 Mdot
.38176 .44482 Mdot
.45753 .65699 Mdot
.34066 .45571 Mdot
.65554 .38578 Mdot
.64343 .62029 Mdot
.75424 .46006 Mdot
.51327 .36294 Mdot
.48597 .67073 Mdot
.31189 .42044 Mdot
.60887 .61507 Mdot
.25814 .43185 Mdot
.65146 .60025 Mdot
.65025 .41159 Mdot
.67527 .38104 Mdot
.33151 .46107 Mdot
.6355 .5821 Mdot
.66937 .45681 Mdot
.83763 .47445 Mdot
.40997 .66543 Mdot
.65148 .36247 Mdot
.64291 .63441 Mdot
.57781 .59696 Mdot
.61935 .62827 Mdot
.47043 .58038 Mdot
.42045 .46716 Mdot
.41403 .57791 Mdot
.61937 .41038 Mdot
.49658 .35844 Mdot
.2265 .57672 Mdot
.54735 .24581 Mdot
.39731 .42906 Mdot
.39432 .63299 Mdot
.43652 .62487 Mdot
.46419 .61871 Mdot
.4494 .56105 Mdot
.58488 .3136 Mdot
.42856 .59092 Mdot
.63968 .44323 Mdot
.45263 .36012 Mdot
.41972 .58201 Mdot
.46848 .39963 Mdot
.70776 .29613 Mdot
.35625 .45799 Mdot
.57302 .41152 Mdot
.29963 .21052 Mdot
.61788 .61874 Mdot
.42669 .34966 Mdot
.45726 .33629 Mdot
.30651 .45036 Mdot
.63848 .42532 Mdot
.64886 .59687 Mdot
.28951 .64816 Mdot
.30168 .44495 Mdot
.44539 .61339 Mdot
.40024 .48464 Mdot
.19863 .53746 Mdot
.41701 .5862 Mdot
.41601 .63141 Mdot
.44516 .39542 Mdot
.42685 .25788 Mdot
.156 .45807 Mdot
.3491 .52159 Mdot
.32832 .45958 Mdot
.35214 .45417 Mdot
.65698 .57263 Mdot
.41219 .57452 Mdot
.61849 .41174 Mdot
.40542 .52555 Mdot
.5746 .38307 Mdot
.46359 .51477 Mdot
.67253 .54999 Mdot
.40497 .61795 Mdot
.78823 .59963 Mdot
.43739 .62869 Mdot
.60247 .58445 Mdot
.61315 .58715 Mdot
.62096 .61259 Mdot
.64243 .43183 Mdot
.55761 .75139 Mdot
.63374 .44016 Mdot
.28503 .2205 Mdot
.64974 .62938 Mdot
.5483 .35937 Mdot
.47783 .33861 Mdot
.40258 .56916 Mdot
.32252 .42161 Mdot
.68728 .41946 Mdot
.37957 .5915 Mdot
.3734 .78446 Mdot
.44595 .344 Mdot
.61636 .62 Mdot
.7453 .39051 Mdot
.34556 .2079 Mdot
.43312 .48814 Mdot
.42367 .54592 Mdot
.30091 .49206 Mdot
.33603 .44826 Mdot
.70389 .71113 Mdot
.33078 .42172 Mdot
.66419 .39741 Mdot
.48107 .61747 Mdot
.48249 .60488 Mdot
.40449 .60428 Mdot
.44855 .58806 Mdot
.63868 .45868 Mdot
.45645 .67758 Mdot
.30567 .77187 Mdot
.49173 .33304 Mdot
.4462 .71432 Mdot
.32146 .4239 Mdot
.65791 .45505 Mdot
.4521 .35829 Mdot
.62033 .34662 Mdot
.31305 .51524 Mdot
.46518 .62989 Mdot
.40746 .61923 Mdot
.22531 .45568 Mdot
.40718 .63256 Mdot
.51277 .56973 Mdot
.4551 .33599 Mdot
.39 .4644 Mdot
.35649 .44714 Mdot
.35248 .44741 Mdot
.67126 .41469 Mdot
.61874 .5804 Mdot
.3187 .43247 Mdot
.48406 .33922 Mdot
.39485 .63565 Mdot
.46723 .66879 Mdot
.64296 .63396 Mdot
.21205 .40553 Mdot
.30795 .41902 Mdot
.7346 .36711 Mdot
.59977 .60042 Mdot
.63683 .64471 Mdot
.42027 .60194 Mdot
.63174 .54913 Mdot
.62391 .55876 Mdot
.36189 .4525 Mdot
.65905 .4537 Mdot
.33491 .50202 Mdot
.64748 .39403 Mdot
.62189 .58567 Mdot
.47149 .65303 Mdot
.60556 .59548 Mdot
.46515 .63618 Mdot
.40965 .16218 Mdot
.47656 .60126 Mdot
.23992 .67836 Mdot
.29988 .61277 Mdot
.46138 .34863 Mdot
.63965 .35239 Mdot
.47178 .3379 Mdot
.59808 .60546 Mdot
.46581 .66145 Mdot
.32829 .41588 Mdot
.74384 .33009 Mdot
.70313 .61227 Mdot
.45045 .38168 Mdot
.50038 .33138 Mdot
.66341 .39116 Mdot
.40127 .60188 Mdot
.42315 .59757 Mdot
.46245 .3658 Mdot
.56904 .57649 Mdot
.64888 .57839 Mdot
.47487 .62427 Mdot
.43162 .62182 Mdot
.46361 .34707 Mdot
.8378 .48862 Mdot
.70088 .63333 Mdot
.47854 .61257 Mdot
.47473 .25604 Mdot
.6287 .39614 Mdot
.38696 .61871 Mdot
.45559 .55522 Mdot
.32985 .44434 Mdot
.44806 .74071 Mdot
.24235 .32936 Mdot
.66417 .38612 Mdot
.46273 .33041 Mdot
.46906 .63882 Mdot
.4696 .33098 Mdot
.46362 .67188 Mdot
.66237 .52712 Mdot
.45401 .39117 Mdot
.42839 .65763 Mdot
.40356 .67556 Mdot
.5999 .61462 Mdot
.40608 .61918 Mdot
.63061 .76381 Mdot
.43541 .36472 Mdot
.43268 .66499 Mdot
.57796 .66945 Mdot
.63141 .42104 Mdot
.38382 .63635 Mdot
.32703 .46759 Mdot
.29026 .65197 Mdot
.71363 .51356 Mdot
.41867 .23727 Mdot
.3527 .45982 Mdot
.45375 .5778 Mdot
.4858 .32147 Mdot
.61715 .43586 Mdot
.26087 .70175 Mdot
.43426 .57717 Mdot
.652 .39694 Mdot
.65821 .42826 Mdot
.3108 .45266 Mdot
.64542 .80621 Mdot
.49237 .64468 Mdot
.44477 .59532 Mdot
.53554 .78656 Mdot
.65815 .63598 Mdot
.46671 .59751 Mdot
.49824 .61099 Mdot
.63866 .44443 Mdot
.50111 .55879 Mdot
.64462 .72316 Mdot
.29478 .68938 Mdot
.61732 .40619 Mdot
.5083 .51083 Mdot
.50208 .37806 Mdot
.33416 .4296 Mdot
.64791 .60529 Mdot
.31523 .41891 Mdot
.50118 .37115 Mdot
.49594 .60741 Mdot
.66938 .43326 Mdot
.58753 .79249 Mdot
.62366 .44798 Mdot
.39334 .23946 Mdot
.64976 .63636 Mdot
.72947 .45697 Mdot
.44264 .87557 Mdot
.70485 .33038 Mdot
.68783 .37133 Mdot
.33181 .44811 Mdot
.41181 .40598 Mdot
.43277 .62352 Mdot
.69356 .72919 Mdot
.48671 .59422 Mdot
.56148 .67407 Mdot
.47957 .32794 Mdot
.50094 .33925 Mdot
.4797 .61567 Mdot
.25664 .59573 Mdot
.6169 .43817 Mdot
.62908 .39886 Mdot
.42475 .65776 Mdot
.64715 .41611 Mdot
.44695 .60193 Mdot
.4491 .36241 Mdot
.47025 .83625 Mdot
.44799 .62043 Mdot
.47256 .56197 Mdot
.67062 .52245 Mdot
.80566 .38802 Mdot
.31789 .29242 Mdot
.8163 .6066 Mdot
.31838 .22556 Mdot
.64808 .41683 Mdot
.39827 .5928 Mdot
.50838 .51187 Mdot
.48564 .39491 Mdot
.68895 .42886 Mdot
.47794 .59458 Mdot
.47831 .59128 Mdot
.48153 .58042 Mdot
.42406 .63235 Mdot
.71668 .70325 Mdot
.39504 .54976 Mdot
.52469 .71947 Mdot
.41222 .63484 Mdot
.27937 .49484 Mdot
.67295 .40882 Mdot
.5943 .57592 Mdot
.35576 .46828 Mdot
.4051 .61729 Mdot
.46499 .53399 Mdot
.61252 .45351 Mdot
.28195 .22199 Mdot
.66879 .39876 Mdot
.48063 .37065 Mdot
.6265 .45462 Mdot
.44651 .63675 Mdot
.63196 .59989 Mdot
.52219 .4947 Mdot
.65303 .30366 Mdot
.45273 .33897 Mdot
.45595 .63304 Mdot
.5487 .35012 Mdot
.44574 .34948 Mdot
.70329 .28848 Mdot
.63894 .60421 Mdot
.26593 .54839 Mdot
.60912 .59031 Mdot
.43228 .66189 Mdot
.43701 .66397 Mdot
.67252 .37058 Mdot
.63269 .45453 Mdot
.61087 .58815 Mdot
.64958 .81035 Mdot
.29907 .43785 Mdot
.61616 .61008 Mdot
.51806 .61054 Mdot
.47934 .45541 Mdot
.62956 .60361 Mdot
.3289 .49333 Mdot
.65137 .43648 Mdot
.67729 .61299 Mdot
.5128 .61185 Mdot
.24488 .3847 Mdot
.33329 .47127 Mdot
.43568 .39127 Mdot
.37397 .49555 Mdot
.43341 .36357 Mdot
.66488 .44708 Mdot
.46971 .33842 Mdot
.62063 .43618 Mdot
.72861 .53311 Mdot
.49737 .53522 Mdot
.63133 .38019 Mdot
.65719 .45264 Mdot
.46929 .34127 Mdot
.47907 .6248 Mdot
.31765 .49348 Mdot
.39235 .60266 Mdot
.49825 .63802 Mdot
.62089 .42436 Mdot
.62532 .62547 Mdot
.59279 .58108 Mdot
.26191 .49703 Mdot
.63389 .5708 Mdot
.45256 .3801 Mdot
.32529 .77426 Mdot
.50269 .26027 Mdot
.63363 .40459 Mdot
.62601 .45683 Mdot
.43394 .65635 Mdot
.47173 .36017 Mdot
.46328 .3267 Mdot
.66051 .39142 Mdot
.5692 .5475 Mdot
.43551 .55805 Mdot
.58478 .59464 Mdot
.66694 .62565 Mdot
.61863 .59908 Mdot
.61657 .62821 Mdot
.67765 .69626 Mdot
.6609 .43282 Mdot
.61496 .62245 Mdot
.42402 .65289 Mdot
.47732 .59242 Mdot
.45711 .4968 Mdot
.35063 .45342 Mdot
.42558 .57667 Mdot
.40045 .66094 Mdot
.41548 .60569 Mdot
.4824 .38527 Mdot
.38193 .68762 Mdot
.45162 .38939 Mdot
.47989 .32146 Mdot
.47315 .32204 Mdot
.55736 .28574 Mdot
.22728 .48699 Mdot
.32839 .23651 Mdot
.48046 .64174 Mdot
.79672 .51992 Mdot
.4804 .35207 Mdot
.37231 .79038 Mdot
.78059 .51622 Mdot
.45145 .57309 Mdot
.3448 .37791 Mdot
.46263 .3622 Mdot
.62872 .5687 Mdot
.47767 .59676 Mdot
.44581 .31877 Mdot
.32594 .46836 Mdot
.41081 .6519 Mdot
.44761 .39063 Mdot
.63718 .58365 Mdot
.36244 .45808 Mdot
.67275 .62308 Mdot
.47479 .32321 Mdot
.39198 .66267 Mdot
.14724 .61891 Mdot
.49888 .32756 Mdot
.80804 .46128 Mdot
.59264 .64559 Mdot
.47671 .62431 Mdot
.42782 .35744 Mdot
.65754 .63947 Mdot
.67454 .4338 Mdot
.5428 .4076 Mdot
.67472 .60316 Mdot
.50242 .34087 Mdot
.44044 .37867 Mdot
.45386 .33686 Mdot
.66651 .60425 Mdot
.48878 .57221 Mdot
.67029 .5935 Mdot
.62482 .45357 Mdot
.43395 .6485 Mdot
.41217 .19374 Mdot
.79274 .53186 Mdot
.60408 .59418 Mdot
.48695 .37285 Mdot
.32526 .4747 Mdot
.44369 .62848 Mdot
.79644 .54136 Mdot
.47706 .63132 Mdot
.61945 .41912 Mdot
.38108 .76137 Mdot
.62357 .77976 Mdot
.39715 .6192 Mdot
.43281 .65523 Mdot
.62662 .4025 Mdot
.45502 .62785 Mdot
.40013 .60773 Mdot
.56696 .28775 Mdot
.66521 .59438 Mdot
.4393 .61632 Mdot
.49484 .34915 Mdot
.54942 .26658 Mdot
.43989 .55895 Mdot
.41547 .30835 Mdot
.26647 .56755 Mdot
.39359 .76489 Mdot
.48797 .59536 Mdot
.38596 .51351 Mdot
.42124 .62288 Mdot
.45264 .58221 Mdot
.44996 .65727 Mdot
.73625 .6982 Mdot
.45954 .39215 Mdot
.45636 .34219 Mdot
.34715 .46735 Mdot
.26551 .56344 Mdot
.32669 .44106 Mdot
.65176 .43776 Mdot
.38196 .30145 Mdot
.45247 .38975 Mdot
.62902 .58134 Mdot
.44432 .58125 Mdot
.49632 .3256 Mdot
.41854 .59915 Mdot
.44783 .638 Mdot
.4384 .3449 Mdot
.48951 .38719 Mdot
.4408 .2402 Mdot
.34518 .46605 Mdot
.62782 .61541 Mdot
.40744 .58766 Mdot
.30741 .42329 Mdot
.50149 .61647 Mdot
.31542 .57284 Mdot
.62545 .61266 Mdot
.66725 .59372 Mdot
.60204 .5732 Mdot
.49561 .609 Mdot
.44691 .63296 Mdot
.63174 .43967 Mdot
.60502 .58907 Mdot
.63312 .41883 Mdot
.55989 .45789 Mdot
.39233 .36744 Mdot
.47797 .59445 Mdot
.7386 .39293 Mdot
.33989 .43764 Mdot
.46696 .3817 Mdot
.20536 .538 Mdot
.34546 .46849 Mdot
.46711 .63445 Mdot
.45505 .32737 Mdot
.34345 .45554 Mdot
.40921 .72235 Mdot
.23694 .29862 Mdot
.33633 .47588 Mdot
.42307 .65229 Mdot
.45346 .54209 Mdot
.80994 .61986 Mdot
.35153 .46625 Mdot
.65327 .44668 Mdot
.49514 .60919 Mdot
.67422 .56708 Mdot
.31721 .41728 Mdot
.65359 .28452 Mdot
.45624 .36119 Mdot
.24544 .35575 Mdot
.36638 .62586 Mdot
.64574 .77534 Mdot
.34694 .43787 Mdot
.64392 .59567 Mdot
.56636 .63268 Mdot
.41885 .60839 Mdot
.3493 .46769 Mdot
.6079 .42439 Mdot
.45535 .37227 Mdot
.59246 .27914 Mdot
.66713 .6056 Mdot
.72745 .4231 Mdot
.49022 .37364 Mdot
.73087 .36262 Mdot
.33825 .72648 Mdot
.38429 .6164 Mdot
.80015 .62544 Mdot
.56287 .37757 Mdot
.48608 .57815 Mdot
.30935 .46776 Mdot
.66016 .38371 Mdot
.66673 .43837 Mdot
.65058 .40774 Mdot
.74191 .54148 Mdot
.41877 .49364 Mdot
.42606 .34933 Mdot
.70584 .39392 Mdot
.3328 .43001 Mdot
.32336 .50391 Mdot
.4789 .66745 Mdot
.43827 .62378 Mdot
.3979 .60693 Mdot
.40553 .60779 Mdot
.42317 .61516 Mdot
.64011 .4192 Mdot
.718 .53573 Mdot
.4337 .49576 Mdot
.62629 .60798 Mdot
.40634 .27106 Mdot
.47912 .34075 Mdot
.42531 .34951 Mdot
.34143 .46192 Mdot
.72433 .3298 Mdot
.46552 .39962 Mdot
.48898 .35909 Mdot
.46642 .56855 Mdot
.65688 .58027 Mdot
.47978 .55281 Mdot
.42833 .65421 Mdot
.45472 .3794 Mdot
.58052 .49871 Mdot
.65424 .73161 Mdot
.38789 .69886 Mdot
.30891 .47944 Mdot
.43605 .47219 Mdot
.33116 .47373 Mdot
.47006 .65945 Mdot
.3803 .79746 Mdot
.50034 .37288 Mdot
.47537 .36771 Mdot
.3458 .44039 Mdot
.68487 .56146 Mdot
.65329 .6115 Mdot
.68645 .36459 Mdot
.63672 .44881 Mdot
.45587 .66451 Mdot
.24357 .65116 Mdot
.51163 .67511 Mdot
.36253 .29828 Mdot
.64912 .40374 Mdot
.47513 .33238 Mdot
.39429 .62586 Mdot
.42143 .64862 Mdot
.34272 .44097 Mdot
.5074 .20618 Mdot
.39682 .6489 Mdot
.70994 .26961 Mdot
.20553 .48453 Mdot
.22417 .39927 Mdot
.4213 .60047 Mdot
.66591 .59674 Mdot
.45037 .39507 Mdot
.33471 .4254 Mdot
.51508 .62723 Mdot
.26887 .2699 Mdot
.65131 .63212 Mdot
.66633 .405 Mdot
.54121 .48789 Mdot
.35119 .50263 Mdot
.49379 .59409 Mdot
.48654 .59623 Mdot
.46606 .58249 Mdot
.19868 .34883 Mdot
.46978 .38908 Mdot
.61432 .58024 Mdot
.31657 .45764 Mdot
.63224 .57356 Mdot
.46136 .34218 Mdot
.72453 .44182 Mdot
.48185 .62531 Mdot
.65317 .63252 Mdot
.64481 .59721 Mdot
.66688 .39612 Mdot
.68001 .42131 Mdot
.55285 .47717 Mdot
.47429 .60123 Mdot
.50885 .33762 Mdot
.6069 .61946 Mdot
.40193 .48624 Mdot
.32414 .45091 Mdot
.64731 .44095 Mdot
.40932 .62841 Mdot
.48211 .38802 Mdot
.47147 .67695 Mdot
.6419 .61475 Mdot
.48846 .35863 Mdot
.47042 .24623 Mdot
.35546 .45427 Mdot
.4629 .59089 Mdot
.35349 .41417 Mdot
.46157 .32994 Mdot
.43108 .62456 Mdot
.76009 .3783 Mdot
.34024 .49021 Mdot
.64052 .2893 Mdot
.46568 .32208 Mdot
.51703 .2767 Mdot
.65971 .57554 Mdot
.75781 .55895 Mdot
.47649 .37017 Mdot
.74144 .37706 Mdot
.51207 .22256 Mdot
.3919 .62187 Mdot
.6135 .59428 Mdot
.56137 .38552 Mdot
.46034 .16799 Mdot
.8285 .50833 Mdot
.4614 .61947 Mdot
.4413 .32702 Mdot
.34393 .4459 Mdot
.63051 .4067 Mdot
.40889 .31684 Mdot
.33272 .49036 Mdot
.51274 .35292 Mdot
.45136 .65702 Mdot
.63891 .58954 Mdot
.6487 .43384 Mdot
.71808 .51819 Mdot
.48881 .34218 Mdot
.4963 .36328 Mdot
.39471 .62453 Mdot
.32727 .43568 Mdot
.7839 .56812 Mdot
.44892 .35667 Mdot
.21552 .47526 Mdot
.52145 .3472 Mdot
.30117 .42981 Mdot
.41773 .6263 Mdot
.25741 .49065 Mdot
.42702 .56646 Mdot
.79396 .40418 Mdot
.47455 .34162 Mdot
.63498 .61395 Mdot
.47595 .58048 Mdot
.30821 .69256 Mdot
.45793 .38076 Mdot
.42285 .46963 Mdot
.30852 .32978 Mdot
.65637 .43548 Mdot
.20494 .54116 Mdot
.45747 .59603 Mdot
.61723 .43828 Mdot
.33955 .43935 Mdot
.47709 .60773 Mdot
.44427 .63442 Mdot
.593 .60341 Mdot
.6611 .39359 Mdot
.47263 .22241 Mdot
.6126 .45117 Mdot
.67196 .42464 Mdot
.58809 .60777 Mdot
.43617 .60609 Mdot
.48235 .37045 Mdot
.46399 .36315 Mdot
.50096 .64583 Mdot
.42302 .83425 Mdot
.65628 .61286 Mdot
.42659 .38643 Mdot
.19266 .36749 Mdot
.43705 .69179 Mdot
.21113 .56228 Mdot
.52144 .2049 Mdot
.62298 .39926 Mdot
.41968 .65052 Mdot
.63457 .5843 Mdot
.45217 .43014 Mdot
.49377 .36601 Mdot
.50272 .5961 Mdot
.65056 .43028 Mdot
.32949 .46986 Mdot
.43863 .36136 Mdot
.37127 .29227 Mdot
.45454 .58527 Mdot
.33462 .37727 Mdot
.43281 .33945 Mdot
.59206 .1689 Mdot
.60746 .35129 Mdot
.61124 .59883 Mdot
.44556 .64009 Mdot
.63249 .56615 Mdot
.32141 .46086 Mdot
.54113 .48588 Mdot
.65362 .4311 Mdot
.36988 .58115 Mdot
.27191 .75449 Mdot
.45533 .33456 Mdot
.61633 .57784 Mdot
.39728 .622 Mdot
.64952 .52944 Mdot
.45005 .59774 Mdot
.51884 .56786 Mdot
.38301 .46529 Mdot
.62379 .42031 Mdot
.62063 .44111 Mdot
.43065 .63252 Mdot
.30253 .43841 Mdot
.48238 .33958 Mdot
.45786 .37669 Mdot
.72793 .24843 Mdot
.64613 .49774 Mdot
.26306 .62546 Mdot
.4749 .59044 Mdot
.5064 .34131 Mdot
.55021 .25172 Mdot
.64571 .39946 Mdot
.48846 .66568 Mdot
.44226 .34452 Mdot
.2607 .38564 Mdot
.31273 .67558 Mdot
.41978 .61566 Mdot
.49131 .56926 Mdot
.64208 .44861 Mdot
.40107 .50557 Mdot
.49008 .33416 Mdot
.4227 .68291 Mdot
.64906 .37108 Mdot
.35129 .70711 Mdot
.20531 .39551 Mdot
.62741 .61548 Mdot
.35972 .28305 Mdot
.63956 .42002 Mdot
.49149 .56741 Mdot
.3118 .42737 Mdot
.46617 .39698 Mdot
.4716 .39022 Mdot
.46327 .64787 Mdot
.43115 .66997 Mdot
.21952 .54138 Mdot
.63811 .57532 Mdot
.67263 .41208 Mdot
.48803 .60833 Mdot
.75903 .44723 Mdot
.4033 .60713 Mdot
.62953 .43497 Mdot
.14205 .62096 Mdot
.39318 .60686 Mdot
.44575 .59706 Mdot
.79267 .55472 Mdot
.6728 .60948 Mdot
.61457 .57714 Mdot
.20957 .60532 Mdot
.47405 .59038 Mdot
.20611 .51301 Mdot
.63259 .61835 Mdot
.65178 .61391 Mdot
.58787 .29124 Mdot
.44299 .62601 Mdot
.35584 .61068 Mdot
.61857 .4172 Mdot
.66768 .43252 Mdot
.67097 .60022 Mdot
.3884 .62657 Mdot
.67084 .3895 Mdot
.74982 .65591 Mdot
.47231 .35847 Mdot
.39473 .80578 Mdot
.65817 .61811 Mdot
.58143 .43618 Mdot
.64616 .4016 Mdot
.28918 .2184 Mdot
.52082 .32258 Mdot
.48106 .62249 Mdot
.46505 .58857 Mdot
.33855 .43408 Mdot
.39858 .59812 Mdot
.49892 .33702 Mdot
.64677 .41572 Mdot
.527 .68397 Mdot
.62017 .61262 Mdot
.46274 .60153 Mdot
.71749 .31628 Mdot
.6437 .26477 Mdot
.36098 .27161 Mdot
.65541 .60566 Mdot
.60621 .60147 Mdot
.49626 .34249 Mdot
.44046 .32842 Mdot
.42734 .60566 Mdot
.63366 .3971 Mdot
.60481 .58997 Mdot
.62504 .43152 Mdot
.49945 .37346 Mdot
.48629 .36687 Mdot
.46892 .39278 Mdot
.45988 .68028 Mdot
.49237 .35411 Mdot
.42504 .28286 Mdot
.72515 .41739 Mdot
.59072 .59305 Mdot
.18333 .48706 Mdot
.72544 .51932 Mdot
.71681 .62241 Mdot
.31845 .41528 Mdot
.45997 .32962 Mdot
.61791 .45013 Mdot
.42701 .64157 Mdot
.41026 .60885 Mdot
.47714 .27308 Mdot
.61348 .43866 Mdot
.32472 .4609 Mdot
.61921 .44349 Mdot
.31064 .45268 Mdot
.30425 .36336 Mdot
.40622 .59438 Mdot
.46346 .66975 Mdot
.64212 .41444 Mdot
.49051 .35547 Mdot
.45464 .35174 Mdot
.34488 .47319 Mdot
.61796 .49336 Mdot
.44535 .34893 Mdot
.65216 .61884 Mdot
.69125 .68455 Mdot
.44069 .37975 Mdot
.47391 .59674 Mdot
.33454 .55242 Mdot
.67471 .75413 Mdot
.45026 .56106 Mdot
.57961 .28949 Mdot
.57115 .80751 Mdot
.45891 .57526 Mdot
.63838 .79337 Mdot
.53541 .3029 Mdot
.65769 .57564 Mdot
.48255 .32963 Mdot
.44928 .40068 Mdot
.49317 .67382 Mdot
.34373 .48054 Mdot
.5099 .63435 Mdot
.66108 .62022 Mdot
.68032 .58471 Mdot
.23259 .41003 Mdot
.80832 .44576 Mdot
.34359 .44955 Mdot
.34634 .45529 Mdot
.47346 .37248 Mdot
.84286 .42058 Mdot
.38965 .57265 Mdot
.32799 .4606 Mdot
.51245 .54003 Mdot
.45514 .65512 Mdot
.28623 .60654 Mdot
.31293 .39377 Mdot
.66829 .60035 Mdot
.26824 .48551 Mdot
.47367 .37688 Mdot
.63687 .57027 Mdot
.75784 .4676 Mdot
.43635 .57045 Mdot
.6236 .61204 Mdot
.62668 .43587 Mdot
.63024 .33379 Mdot
.64694 .62487 Mdot
.32586 .5617 Mdot
.65566 .38959 Mdot
.40759 .48197 Mdot
.26141 .51719 Mdot
.6757 .83959 Mdot
.64299 .41973 Mdot
.44573 .38126 Mdot
.46324 .36407 Mdot
.45937 .37686 Mdot
.63676 .57302 Mdot
.4634 .32715 Mdot
.63356 .57631 Mdot
.81623 .56928 Mdot
.67397 .55168 Mdot
.33047 .45987 Mdot
.60002 .28215 Mdot
.62821 .58949 Mdot
.35411 .79141 Mdot
.37019 .83543 Mdot
.41937 .65088 Mdot
.62422 .45917 Mdot
.33671 .45713 Mdot
.72184 .27591 Mdot
.3332 .44398 Mdot
.2386 .46081 Mdot
.38738 .77588 Mdot
.45337 .6041 Mdot
.59824 .7454 Mdot
.34848 .42942 Mdot
.65436 .5977 Mdot
.43265 .62571 Mdot
.51451 .41911 Mdot
.33271 .44025 Mdot
.31422 .46178 Mdot
.43139 .61178 Mdot
.61577 .61984 Mdot
.47966 .37626 Mdot
.6435 .45354 Mdot
.34278 .41834 Mdot
.5835 .63198 Mdot
.45094 .56324 Mdot
.47674 .63711 Mdot
.46162 .49227 Mdot
.30928 .40561 Mdot
.64823 .41767 Mdot
.70386 .74382 Mdot
.45897 .32235 Mdot
.52811 .40751 Mdot
.21684 .46005 Mdot
.56182 .2937 Mdot
.47343 .34366 Mdot
.46697 .33257 Mdot
.42263 .61189 Mdot
.29737 .41063 Mdot
.39766 .77861 Mdot
.65408 .47284 Mdot
.4485 .39332 Mdot
.45535 .3746 Mdot
.65717 .56719 Mdot
.22779 .41814 Mdot
.51729 .62381 Mdot
.66557 .38621 Mdot
.47553 .39039 Mdot
.68714 .54526 Mdot
.32797 .43268 Mdot
.35341 .77514 Mdot
.40981 .59048 Mdot
.48357 .61785 Mdot
.65761 .41806 Mdot
.6355 .44072 Mdot
.44543 .43049 Mdot
.23079 .43361 Mdot
.58886 .80109 Mdot
.69689 .51683 Mdot
.43913 .75587 Mdot
.66886 .57329 Mdot
.60357 .59503 Mdot
.67579 .31123 Mdot
.61289 .4526 Mdot
.46601 .57667 Mdot
.61647 .58225 Mdot
.53919 .38509 Mdot
.70649 .64785 Mdot
.27119 .61427 Mdot
.22117 .57059 Mdot
.4631 .63551 Mdot
.65908 .58663 Mdot
.67154 .61076 Mdot
.61516 .63412 Mdot
.54219 .32378 Mdot
.43181 .59957 Mdot
.46256 .62779 Mdot
.43823 .57991 Mdot
.59951 .54654 Mdot
.43834 .58815 Mdot
.75147 .5594 Mdot
.52859 .47238 Mdot
.45956 .73347 Mdot
.41717 .67821 Mdot
.63857 .38424 Mdot
.49426 .59698 Mdot
.30285 .44112 Mdot
.44614 .66046 Mdot
.27375 .6212 Mdot
.65856 .39807 Mdot
.702 .6344 Mdot
.73002 .52886 Mdot
.47843 .57603 Mdot
.36222 .44558 Mdot
.58989 .37724 Mdot
.39681 .20123 Mdot
.36843 .43173 Mdot
.65356 .61867 Mdot
.47381 .35284 Mdot
.61564 .44767 Mdot
.48363 .36523 Mdot
.44741 .67943 Mdot
.68474 .32139 Mdot
.64477 .24848 Mdot
.56826 .46232 Mdot
.40572 .61003 Mdot
.37146 .65641 Mdot
.64845 .61634 Mdot
.45282 .32779 Mdot
.66901 .55958 Mdot
.47494 .58175 Mdot
.31228 .45024 Mdot
.33605 .4376 Mdot
.54572 .40005 Mdot
.56925 .18635 Mdot
.73629 .61044 Mdot
.6554 .41813 Mdot
.44772 .36323 Mdot
.32869 .42061 Mdot
.78383 .43519 Mdot
.68047 .42173 Mdot
.62408 .40461 Mdot
.66669 .40087 Mdot
.49501 .62329 Mdot
.4535 .3914 Mdot
.46367 .73108 Mdot
.50664 .34405 Mdot
.4542 .63054 Mdot
.47694 .38666 Mdot
.44469 .34293 Mdot
.32517 .4238 Mdot
.67108 .40513 Mdot
.50438 .36103 Mdot
.43439 .66374 Mdot
.62527 .61993 Mdot
.58992 .41821 Mdot
.30768 .64219 Mdot
.80233 .43127 Mdot
.54858 .66308 Mdot
.66567 .62447 Mdot
.45821 .17358 Mdot
.62551 .39901 Mdot
.57812 .54662 Mdot
.43205 .2462 Mdot
.47737 .64891 Mdot
.38347 .82493 Mdot
.42478 .35512 Mdot
.43888 .35004 Mdot
.41915 .62699 Mdot
.49013 .41529 Mdot
.45722 .601 Mdot
.49603 .37276 Mdot
.46356 .26563 Mdot
.55778 .60417 Mdot
.48764 .34994 Mdot
.42932 .68533 Mdot
.43854 .63332 Mdot
.66856 .59701 Mdot
.42853 .35796 Mdot
.4916 .66446 Mdot
.70609 .2335 Mdot
.63509 .43753 Mdot
.55346 .34509 Mdot
.33693 .56334 Mdot
.63834 .42062 Mdot
.61545 .60755 Mdot
.49389 .64686 Mdot
.34128 .44068 Mdot
.62935 .58798 Mdot
.31796 .68732 Mdot
.35407 .4421 Mdot
.36141 .80416 Mdot
.6697 .6099 Mdot
.43779 .37469 Mdot
.30819 .43012 Mdot
.40421 .58633 Mdot
.46464 .39684 Mdot
.63523 .34917 Mdot
.4753 .34406 Mdot
.42456 .59654 Mdot
.60062 .27085 Mdot
.67258 .4179 Mdot
.46351 .61709 Mdot
.43638 .35278 Mdot
.56763 .28509 Mdot
.49252 .62777 Mdot
.42567 .62776 Mdot
.21 .41036 Mdot
.30008 .73851 Mdot
.32903 .44893 Mdot
.63385 .64045 Mdot
.42431 .65322 Mdot
.32025 .46496 Mdot
.35921 .35546 Mdot
.49213 .61652 Mdot
.64731 .63337 Mdot
.40937 .68841 Mdot
.42921 .34957 Mdot
.63355 .42508 Mdot
.56948 .45342 Mdot
.32604 .46828 Mdot
.81569 .66566 Mdot
.50794 .36481 Mdot
.47213 .66293 Mdot
.40402 .61961 Mdot
.29672 .30397 Mdot
.65553 .57492 Mdot
.49559 .81212 Mdot
.46303 .5907 Mdot
.59036 .54945 Mdot
.47323 .60744 Mdot
.42532 .37658 Mdot
.65349 .61247 Mdot
.44191 .59481 Mdot
.73463 .40442 Mdot
.45976 .55972 Mdot
.34845 .46534 Mdot
.79677 .55435 Mdot
.46597 .56618 Mdot
.21133 .71142 Mdot
.28388 .40085 Mdot
.48863 .34869 Mdot
.63937 .27248 Mdot
.80493 .30499 Mdot
.74308 .53727 Mdot
.62769 .57623 Mdot
.56182 .21172 Mdot
.48321 .37001 Mdot
.59437 .25418 Mdot
.45095 .17168 Mdot
.43699 .63791 Mdot
.49375 .59375 Mdot
.25609 .42834 Mdot
.47837 .32268 Mdot
.51623 .35278 Mdot
.40801 .65866 Mdot
.5024 .57442 Mdot
.49197 .36258 Mdot
.4392 .66853 Mdot
.4277 .67358 Mdot
.63839 .45686 Mdot
.65644 .62723 Mdot
.62416 .4144 Mdot
.66 .38726 Mdot
.76749 .62598 Mdot
.27518 .39621 Mdot
.63095 .43375 Mdot
.64386 .38549 Mdot
.28712 .61168 Mdot
.23423 .54048 Mdot
.31838 .41699 Mdot
.61316 .1899 Mdot
.45802 .37377 Mdot
.43553 .60119 Mdot
.66911 .61894 Mdot
.60383 .79264 Mdot
.39443 .3277 Mdot
.41402 .7992 Mdot
.47004 .57882 Mdot
.46335 .38046 Mdot
.54237 .32371 Mdot
.4967 .55933 Mdot
.46769 .31179 Mdot
.48961 .60634 Mdot
.51365 .36046 Mdot
.63571 .70017 Mdot
.73768 .37432 Mdot
.51936 .34921 Mdot
.58441 .5968 Mdot
.4846 .61095 Mdot
.66141 .61742 Mdot
.64147 .40411 Mdot
.3101 .42427 Mdot
.32557 .44806 Mdot
.43104 .62001 Mdot
.38351 .64641 Mdot
.31263 .37001 Mdot
.44302 .62952 Mdot
.44882 .65555 Mdot
.53499 .30195 Mdot
.44409 .65697 Mdot
.41183 .59895 Mdot
.42625 .5873 Mdot
.50514 .60147 Mdot
.66975 .42908 Mdot
.72108 .3268 Mdot
.52957 .60817 Mdot
.52766 .59673 Mdot
.679 .41874 Mdot
.48641 .2137 Mdot
.64715 .38802 Mdot
.40253 .19246 Mdot
.6184 .42573 Mdot
.32244 .45367 Mdot
.35317 .2533 Mdot
.37492 .61962 Mdot
.61189 .62366 Mdot
.67701 .43592 Mdot
.31546 .45822 Mdot
.64879 .41115 Mdot
.48738 .378 Mdot
.20869 .36163 Mdot
.63934 .64719 Mdot
.41201 .52128 Mdot
.67757 .4424 Mdot
.69126 .33564 Mdot
.50622 .35534 Mdot
.66209 .61205 Mdot
.64187 .7384 Mdot
.40647 .6038 Mdot
.31635 .46223 Mdot
.42744 .60906 Mdot
.67381 .40486 Mdot
.46896 .3775 Mdot
.82084 .51722 Mdot
.34242 .44058 Mdot
.19054 .46968 Mdot
.45663 .35652 Mdot
.42365 .58591 Mdot
.6674 .38782 Mdot
.18186 .54835 Mdot
.62273 .4188 Mdot
.45086 .78929 Mdot
.64882 .56799 Mdot
.82489 .59513 Mdot
.62127 .59008 Mdot
.65456 .34671 Mdot
.14572 .48132 Mdot
.73223 .32687 Mdot
.61759 .61959 Mdot
.68072 .46866 Mdot
.46759 .63804 Mdot
.47748 .63573 Mdot
.79184 .44211 Mdot
.63432 .64015 Mdot
.41367 .64 Mdot
.49521 .25839 Mdot
.7152 .43552 Mdot
.22633 .60921 Mdot
.47294 .33484 Mdot
.46009 .59795 Mdot
.66318 .37308 Mdot
.61541 .43434 Mdot
.51009 .35524 Mdot
.62568 .40059 Mdot
.46101 .62665 Mdot
.62691 .58974 Mdot
.41027 .38995 Mdot
.31685 .44141 Mdot
.77567 .33569 Mdot
.30023 .44855 Mdot
.47285 .34375 Mdot
.3926 .59983 Mdot
.48697 .36588 Mdot
.81189 .29265 Mdot
.46765 .62585 Mdot
.6341 .61769 Mdot
.42914 .65242 Mdot
.48163 .6126 Mdot
.49325 .58973 Mdot
.48855 .37254 Mdot
.35578 .68013 Mdot
.43618 .66594 Mdot
.65402 .4318 Mdot
.45729 .74299 Mdot
.46546 .56712 Mdot
.45656 .4102 Mdot
.2507 .56554 Mdot
.70188 .40283 Mdot
.67781 .60429 Mdot
.48324 .34602 Mdot
.61771 .61403 Mdot
.6041 .56155 Mdot
.61576 .60748 Mdot
.49402 .76417 Mdot
.64569 .72841 Mdot
.37597 .72606 Mdot
.57301 .66878 Mdot
.56583 .51309 Mdot
.63379 .6403 Mdot
.32841 .39879 Mdot
.59837 .60293 Mdot
.67376 .60409 Mdot
.0713 .5333 Mdot
.60543 .62271 Mdot
.47104 .59415 Mdot
.44628 .56963 Mdot
.71092 .34706 Mdot
.29964 .56011 Mdot
.43127 .64822 Mdot
.42193 .64404 Mdot
.31907 .42217 Mdot
.57732 .56246 Mdot
.65682 .29306 Mdot
.2957 .74559 Mdot
.61353 .24846 Mdot
.42921 .6112 Mdot
.42623 .65507 Mdot
.49394 .56184 Mdot
.1889 .63032 Mdot
.7725 .64309 Mdot
.68665 .61811 Mdot
.46611 .55543 Mdot
.77202 .36183 Mdot
.49048 .58914 Mdot
.49803 .60974 Mdot
.46495 .63616 Mdot
.48241 .37075 Mdot
.6747 .62471 Mdot
.50923 .61577 Mdot
.25595 .41507 Mdot
.49253 .60314 Mdot
.56479 .29175 Mdot
.85212 .50747 Mdot
.45702 .59561 Mdot
.68037 .61591 Mdot
.47387 .64232 Mdot
.66512 .58294 Mdot
.65766 .59478 Mdot
.40424 .57083 Mdot
.44387 .75527 Mdot
.68171 .59174 Mdot
.45366 .63108 Mdot
.47505 .38115 Mdot
.58348 .17147 Mdot
.42593 .59528 Mdot
.31204 .42114 Mdot
.46661 .58917 Mdot
.36169 .44068 Mdot
.44529 .65362 Mdot
.50848 .36515 Mdot
.64634 .77007 Mdot
.47358 .36946 Mdot
.79328 .63975 Mdot
.48218 .39036 Mdot
.20488 .41926 Mdot
.65883 .63402 Mdot
.59869 .27675 Mdot
.54283 .83148 Mdot
.55528 .3238 Mdot
.41059 .45747 Mdot
.49524 .47272 Mdot
.63292 .39729 Mdot
.64226 .56836 Mdot
.5376 .53588 Mdot
.43697 .25285 Mdot
.38939 .25573 Mdot
.44353 .35636 Mdot
.6398 .81267 Mdot
.44072 .82379 Mdot
.45624 .66784 Mdot
.57442 .75802 Mdot
.54094 .72542 Mdot
.49493 .59238 Mdot
.50677 .61909 Mdot
.50138 .28423 Mdot
.42531 .66178 Mdot
.75788 .43891 Mdot
.46916 .34384 Mdot
.31473 .45837 Mdot
.64331 .61851 Mdot
.32759 .46988 Mdot
.43041 .25177 Mdot
.48809 .47307 Mdot
.4952 .37528 Mdot
.48834 .56973 Mdot
.42387 .64208 Mdot
.66684 .588 Mdot
.70134 .59771 Mdot
.59945 .61241 Mdot
.34071 .45138 Mdot
.46549 .34833 Mdot
.70019 .7238 Mdot
.41738 .63695 Mdot
.64369 .59789 Mdot
.40868 .44367 Mdot
.4224 .65164 Mdot
.64002 .4105 Mdot
.47058 .63339 Mdot
.62658 .62249 Mdot
.44387 .65686 Mdot
.62109 .58858 Mdot
.47429 .35533 Mdot
.45158 .57178 Mdot
.41813 .62158 Mdot
.18391 .51486 Mdot
.32163 .45797 Mdot
.64802 .6364 Mdot
.53519 .33522 Mdot
.40142 .62285 Mdot
.60888 .30093 Mdot
.48727 .6022 Mdot
.72028 .63845 Mdot
.48271 .64721 Mdot
.55002 .32075 Mdot
.52446 .61962 Mdot
.42864 .59463 Mdot
.43373 .43815 Mdot
.53421 .73751 Mdot
.68442 .63086 Mdot
.66282 .38283 Mdot
.61774 .62992 Mdot
.23145 .61173 Mdot
.52329 .34716 Mdot
.44633 .32924 Mdot
.31157 .50715 Mdot
.5056 .59944 Mdot
.45052 .60386 Mdot
.67585 .38192 Mdot
.34844 .45804 Mdot
.65525 .60401 Mdot
.31084 .45281 Mdot
.19913 .51032 Mdot
.35108 .44502 Mdot
.42419 .36393 Mdot
.33678 .37647 Mdot
.71729 .69867 Mdot
.32081 .42223 Mdot
.61645 .62059 Mdot
.39141 .38477 Mdot
.50161 .59225 Mdot
.2888 .40044 Mdot
.31125 .44356 Mdot
.70606 .77616 Mdot
.41245 .59897 Mdot
.40687 .45816 Mdot
.62896 .42605 Mdot
.31324 .42582 Mdot
.6469 .39329 Mdot
.42857 .6399 Mdot
.64338 .28889 Mdot
.62447 .5784 Mdot
.67739 .4051 Mdot
.38752 .64629 Mdot
.33659 .45849 Mdot
.46472 .39134 Mdot
.6858 .39571 Mdot
.66765 .38559 Mdot
.50532 .20351 Mdot
.81654 .54352 Mdot
.46402 .35068 Mdot
.31727 .71603 Mdot
.61733 .42337 Mdot
.49191 .58316 Mdot
.56102 .56025 Mdot
.48184 .62205 Mdot
.74851 .5808 Mdot
.4809 .34152 Mdot
.71171 .33614 Mdot
.43058 .65564 Mdot
.45118 .57899 Mdot
.67584 .63452 Mdot
.46546 .36889 Mdot
.62951 .60037 Mdot
.61386 .63009 Mdot
.47291 .35655 Mdot
.61393 .59615 Mdot
.35373 .43675 Mdot
.70812 .46771 Mdot
.63313 .44953 Mdot
.66106 .42651 Mdot
.45664 .37652 Mdot
.49052 .34697 Mdot
.48833 .36033 Mdot
.47097 .6332 Mdot
.65591 .60872 Mdot
.44566 .6441 Mdot
.49404 .60044 Mdot
.42666 .75074 Mdot
.67431 .61723 Mdot
.45729 .64141 Mdot
.49806 .42393 Mdot
.28287 .4309 Mdot
.47412 .38274 Mdot
.63063 .43092 Mdot
.54072 .25452 Mdot
.6279 .35507 Mdot
.46469 .59832 Mdot
.26669 .38149 Mdot
.60683 .61656 Mdot
.33841 .44063 Mdot
.29681 .42519 Mdot
.33208 .44596 Mdot
.62329 .47782 Mdot
.63607 .63923 Mdot
.30188 .75287 Mdot
.45573 .59952 Mdot
.45528 .48982 Mdot
.49283 .53019 Mdot
.29671 .37164 Mdot
.63274 .4336 Mdot
.42254 .64928 Mdot
.57534 .46101 Mdot
.65661 .73744 Mdot
.47978 .62128 Mdot
.48077 .57097 Mdot
.4709 .24882 Mdot
.41261 .69166 Mdot
.63621 .56399 Mdot
.18791 .55597 Mdot
.39581 .60955 Mdot
.68672 .54769 Mdot
.7914 .34535 Mdot
.47641 .59974 Mdot
.46348 .58073 Mdot
.41001 .61783 Mdot
.44931 .66087 Mdot
.68194 .59985 Mdot
.28032 .52549 Mdot
.61963 .40486 Mdot
.44651 .49234 Mdot
.6605 .44349 Mdot
.48051 .39409 Mdot
.72135 .33602 Mdot
.6395 .56714 Mdot
.33888 .43444 Mdot
.71172 .28824 Mdot
.22705 .65565 Mdot
.48886 .33342 Mdot
.74907 .65139 Mdot
.31401 .45032 Mdot
.48695 .57768 Mdot
.35474 .43392 Mdot
.45071 .38842 Mdot
.65774 .43318 Mdot
.50293 .58521 Mdot
.59989 .60254 Mdot
.65027 .62461 Mdot
.41659 .64576 Mdot
.76037 .34653 Mdot
.63638 .41342 Mdot
.68155 .39465 Mdot
.49294 .62157 Mdot
.40468 .58637 Mdot
.6258 .60121 Mdot
.45028 .36166 Mdot
.2813 .66353 Mdot
.34037 .46345 Mdot
.46826 .6764 Mdot
.45164 .65757 Mdot
.21903 .45008 Mdot
.64999 .43811 Mdot
.44644 .32212 Mdot
.48303 .64192 Mdot
.6856 .51546 Mdot
.48119 .64344 Mdot
.46199 .55226 Mdot
.47144 .38203 Mdot
.53115 .61789 Mdot
.45624 .6709 Mdot
.51984 .56517 Mdot
.63238 .40123 Mdot
.6292 .61373 Mdot
.59521 .62991 Mdot
.47923 .50742 Mdot
.64194 .40943 Mdot
.46309 .64275 Mdot
.639 .43332 Mdot
.49144 .61633 Mdot
.42202 .6561 Mdot
.62939 .43448 Mdot
.6286 .59981 Mdot
.56004 .21458 Mdot
.71836 .32171 Mdot
.44902 .66248 Mdot
.39502 .6344 Mdot
.28857 .53941 Mdot
.35272 .67477 Mdot
.48105 .58456 Mdot
.63456 .62383 Mdot
.41792 .63263 Mdot
.65111 .39443 Mdot
.34504 .42696 Mdot
.62499 .62056 Mdot
.45533 .34525 Mdot
.49743 .34102 Mdot
.73455 .53058 Mdot
.45189 .33262 Mdot
.50172 .60343 Mdot
.62804 .55536 Mdot
.61208 .63832 Mdot
.78806 .36066 Mdot
.46998 .3595 Mdot
.32544 .41473 Mdot
.42688 .62682 Mdot
.24503 .38353 Mdot
.66597 .37216 Mdot
.26042 .76988 Mdot
.34657 .7907 Mdot
.33491 .48105 Mdot
.41723 .79385 Mdot
.49903 .38219 Mdot
.45718 .67435 Mdot
.30699 .42659 Mdot
.49394 .34057 Mdot
.47166 .6513 Mdot
.42521 .55437 Mdot
.48091 .80896 Mdot
.52191 .50348 Mdot
.63976 .43527 Mdot
.4646 .32528 Mdot
.32015 .48052 Mdot
.42756 .33843 Mdot
.66493 .62041 Mdot
.43277 .59516 Mdot
.3927 .59452 Mdot
.45164 .35149 Mdot
.4646 .31858 Mdot
.45688 .63513 Mdot
.63323 .56615 Mdot
.5067 .2893 Mdot
.43408 .6149 Mdot
.58195 .52094 Mdot
.57325 .60561 Mdot
.46703 .33946 Mdot
.44038 .58277 Mdot
.38878 .45982 Mdot
.45441 .35794 Mdot
.47399 .38354 Mdot
.41955 .65165 Mdot
.35473 .43973 Mdot
.39464 .62784 Mdot
.62034 .43791 Mdot
.70397 .75183 Mdot
.65586 .39332 Mdot
.40949 .31976 Mdot
.38516 .64403 Mdot
.65373 .50746 Mdot
.6759 .5921 Mdot
.24441 .4487 Mdot
.50579 .25506 Mdot
.40963 .66233 Mdot
.53903 .1799 Mdot
.57962 .42408 Mdot
.74697 .32311 Mdot
.32153 .25298 Mdot
.31622 .43071 Mdot
.64972 .40832 Mdot
.46503 .58096 Mdot
.62847 .45873 Mdot
.30676 .42504 Mdot
.79384 .63391 Mdot
.43284 .58544 Mdot
.65133 .61305 Mdot
.46085 .63223 Mdot
.65685 .61828 Mdot
.42221 .65398 Mdot
.51167 .57354 Mdot
.5131 .27183 Mdot
.31268 .6744 Mdot
.4886 .63933 Mdot
.19252 .3955 Mdot
.37837 .41373 Mdot
.32484 .46436 Mdot
.44228 .63922 Mdot
.4836 .31283 Mdot
.61324 .43295 Mdot
.78285 .4676 Mdot
.48351 .37075 Mdot
.65207 .38458 Mdot
.61717 .60122 Mdot
.47823 .34621 Mdot
.49856 .33957 Mdot
.52973 .62236 Mdot
.35745 .45885 Mdot
.66924 .41236 Mdot
.44227 .59319 Mdot
.43203 .58683 Mdot
.29454 .70158 Mdot
.39707 .31025 Mdot
.70604 .60541 Mdot
.22918 .69162 Mdot
.58678 .61237 Mdot
.32916 .46253 Mdot
.48201 .37502 Mdot
.48563 .59221 Mdot
.46017 .61792 Mdot
.58688 .28112 Mdot
.60529 .58699 Mdot
.54772 .48445 Mdot
.72039 .65589 Mdot
.52995 .32883 Mdot
.26879 .58302 Mdot
.64147 .62102 Mdot
.2707 .58577 Mdot
.29576 .44907 Mdot
.65894 .22221 Mdot
.298 .64721 Mdot
.63071 .42679 Mdot
.27002 .57963 Mdot
.64731 .59533 Mdot
.44627 .66721 Mdot
.4374 .37546 Mdot
.44577 .34108 Mdot
.62998 .6083 Mdot
.44427 .31631 Mdot
.32791 .42522 Mdot
.45524 .58326 Mdot
.29008 .73435 Mdot
.74372 .50921 Mdot
.44893 .37413 Mdot
.5093 .56831 Mdot
.6658 .4 Mdot
.41539 .645 Mdot
.32818 .42183 Mdot
.64243 .42452 Mdot
.23379 .44472 Mdot
.72156 .39929 Mdot
.42982 .62618 Mdot
.21212 .42131 Mdot
.64361 .4136 Mdot
.34561 .64945 Mdot
.43359 .6075 Mdot
.61866 .41798 Mdot
.37778 .68733 Mdot
.63338 .33622 Mdot
.57532 .46961 Mdot
.45311 .17091 Mdot
.55995 .46876 Mdot
.43982 .37403 Mdot
.66239 .33407 Mdot
.5622 .36908 Mdot
.62268 .45382 Mdot
.45565 .3183 Mdot
.2855 .46118 Mdot
.64485 .3937 Mdot
.47077 .56965 Mdot
.4845 .60205 Mdot
.77963 .63823 Mdot
.57117 .41704 Mdot
.67092 .34955 Mdot
.77506 .52296 Mdot
.40071 .61869 Mdot
.39187 .61596 Mdot
.45686 .6149 Mdot
.68154 .58768 Mdot
.64563 .43579 Mdot
.17591 .4543 Mdot
.63933 .40809 Mdot
.34481 .76362 Mdot
.45952 .37548 Mdot
.47804 .33462 Mdot
.46177 .59639 Mdot
.39429 .48109 Mdot
.24636 .51239 Mdot
.45847 .62709 Mdot
.29663 .48141 Mdot
.7997 .54726 Mdot
.40018 .59387 Mdot
.66398 .57568 Mdot
.54551 .60165 Mdot
.57755 .63549 Mdot
.63264 .44977 Mdot
.32438 .43276 Mdot
.24426 .45583 Mdot
.66185 .43091 Mdot
.45085 .60498 Mdot
.67524 .49773 Mdot
.47642 .61464 Mdot
.45536 .66186 Mdot
.36709 .78655 Mdot
.30379 .45941 Mdot
.48248 .35882 Mdot
.33297 .44837 Mdot
.66888 .58504 Mdot
.15531 .67499 Mdot
.35178 .45752 Mdot
.24412 .50326 Mdot
.77317 .66791 Mdot
.27269 .58069 Mdot
.66042 .62212 Mdot
.359 .45942 Mdot
.63346 .41971 Mdot
.59724 .17046 Mdot
.53387 .82199 Mdot
.60865 .39014 Mdot
.43869 .61469 Mdot
.61832 .56884 Mdot
.63657 .62745 Mdot
.67859 .41263 Mdot
.65684 .59591 Mdot
.37099 .67255 Mdot
.44934 .66536 Mdot
.62381 .45733 Mdot
.69716 .50668 Mdot
.66383 .38245 Mdot
.72601 .44408 Mdot
.4452 .6356 Mdot
.63478 .62027 Mdot
.44829 .6835 Mdot
.5685 .60299 Mdot
.43303 .33126 Mdot
.44829 .56217 Mdot
.32992 .42578 Mdot
.65879 .5144 Mdot
.46211 .35076 Mdot
.27904 .37216 Mdot
.66889 .58984 Mdot
.69908 .42558 Mdot
.66707 .59562 Mdot
.62401 .63921 Mdot
.65593 .38664 Mdot
.63812 .58223 Mdot
.46041 .58105 Mdot
.54014 .40239 Mdot
.6494 .57528 Mdot
.66158 .41002 Mdot
.32278 .43695 Mdot
.61946 .59456 Mdot
.48553 .41687 Mdot
.42408 .62061 Mdot
.49579 .36463 Mdot
.34226 .26362 Mdot
.59452 .59266 Mdot
.32578 .47335 Mdot
.44853 .32899 Mdot
.31249 .46015 Mdot
.82344 .43285 Mdot
.62533 .46309 Mdot
.38871 .77365 Mdot
.31021 .48229 Mdot
.60708 .62138 Mdot
.35888 .25148 Mdot
.48432 .59331 Mdot
.42475 .62361 Mdot
.36041 .435 Mdot
.63586 .62734 Mdot
.70686 .26415 Mdot
.63906 .65515 Mdot
.70614 .45712 Mdot
.66175 .45371 Mdot
.20219 .40932 Mdot
.73559 .42957 Mdot
.85329 .43546 Mdot
.39566 .6498 Mdot
.51715 .35648 Mdot
.46405 .60344 Mdot
.51913 .25953 Mdot
.33558 .45709 Mdot
.41862 .39007 Mdot
.42534 .55995 Mdot
.47969 .35387 Mdot
.41563 .61066 Mdot
.46816 .4396 Mdot
.52292 .64462 Mdot
.32187 .4147 Mdot
.64444 .27882 Mdot
.60996 .62525 Mdot
.31521 .44328 Mdot
.50333 .37168 Mdot
.25272 .53786 Mdot
.46411 .65884 Mdot
.47523 .67826 Mdot
.52979 .32876 Mdot
.65846 .61284 Mdot
.43264 .36017 Mdot
.62701 .44686 Mdot
.33401 .43402 Mdot
.42712 .64377 Mdot
.50046 .62131 Mdot
.60467 .30191 Mdot
.66797 .4002 Mdot
.47731 .31871 Mdot
.62607 .41378 Mdot
.50707 .37633 Mdot
.41582 .65463 Mdot
.47477 .33213 Mdot
.47745 .67064 Mdot
.52644 .27886 Mdot
.36428 .78045 Mdot
.54522 .74621 Mdot
.47889 .34017 Mdot
.25578 .59311 Mdot
.6566 .39757 Mdot
.62179 .41596 Mdot
.73646 .69943 Mdot
.45174 .79264 Mdot
.26752 .68827 Mdot
.45027 .20568 Mdot
.6559 .44592 Mdot
.66484 .4026 Mdot
.49763 .36009 Mdot
.64087 .58106 Mdot
.59346 .62151 Mdot
.51011 .37132 Mdot
.33735 .5533 Mdot
.65504 .60388 Mdot
.58372 .18199 Mdot
.23747 .63814 Mdot
.50254 .63541 Mdot
.464 .30498 Mdot
.33251 .43871 Mdot
.3284 .55464 Mdot
.46482 .43898 Mdot
.45701 .57801 Mdot
.24286 .42077 Mdot
.45161 .37136 Mdot
.39038 .50746 Mdot
.40439 .19327 Mdot
.4238 .58902 Mdot
.43417 .60224 Mdot
.45672 .60857 Mdot
.34217 .476 Mdot
.50323 .80681 Mdot
.4427 .58425 Mdot
.33752 .55588 Mdot
.40588 .63233 Mdot
.36792 .68293 Mdot
.32765 .44835 Mdot
.3996 .72093 Mdot
.44697 .24188 Mdot
.19545 .56917 Mdot
.50817 .66541 Mdot
.62386 .44539 Mdot
.278 .47043 Mdot
.62512 .40679 Mdot
.5056 .76063 Mdot
.29917 .64324 Mdot
.5873 .59649 Mdot
.46121 .57854 Mdot
.47242 .34315 Mdot
.6394 .62765 Mdot
.632 .32161 Mdot
.10383 .60175 Mdot
.62112 .44428 Mdot
.86778 .42045 Mdot
.61949 .42493 Mdot
.50178 .34256 Mdot
.62501 .60204 Mdot
.64752 .72202 Mdot
.47171 .49531 Mdot
.61788 .59343 Mdot
.62744 .23774 Mdot
.69178 .61266 Mdot
.25789 .57696 Mdot
.60973 .57772 Mdot
.66078 .40471 Mdot
.62301 .47696 Mdot
.37071 .60915 Mdot
.47613 .59187 Mdot
.49539 .46926 Mdot
.23985 .53068 Mdot
.48105 .59131 Mdot
.46804 .34607 Mdot
.40538 .77426 Mdot
.2659 .47455 Mdot
.63879 .58609 Mdot
.61188 .41239 Mdot
.4296 .60159 Mdot
.4668 .65014 Mdot
.46096 .66194 Mdot
.26395 .74441 Mdot
.66454 .22425 Mdot
.43478 .66497 Mdot
.4014 .62772 Mdot
.47839 .34953 Mdot
.29635 .45994 Mdot
.50246 .24507 Mdot
.39882 .74221 Mdot
.46028 .57307 Mdot
.31859 .44851 Mdot
.30996 .46965 Mdot
.4767 .64857 Mdot
.29116 .39627 Mdot
.67253 .49557 Mdot
.44109 .593 Mdot
.41792 .77111 Mdot
.53759 .36604 Mdot
.4786 .32294 Mdot
.45363 .35007 Mdot
.65852 .62962 Mdot
.45931 .33207 Mdot
.50175 .37826 Mdot
.66916 .71032 Mdot
.5486 .47276 Mdot
.61217 .40576 Mdot
.34157 .45053 Mdot
.46465 .61748 Mdot
.68229 .63568 Mdot
.67794 .50934 Mdot
.64344 .39199 Mdot
.60419 .61074 Mdot
.61452 .42434 Mdot
.36479 .4258 Mdot
.4311 .51814 Mdot
.44367 .36549 Mdot
.65524 .44421 Mdot
.72078 .40599 Mdot
.32026 .44805 Mdot
.66833 .39513 Mdot
.71178 .39916 Mdot
.44579 .56502 Mdot
.57357 .77057 Mdot
.45336 .62841 Mdot
.72678 .29263 Mdot
.67177 .41051 Mdot
.5503 .30529 Mdot
.44524 .60025 Mdot
.45576 .35933 Mdot
.37528 .5919 Mdot
.4904 .59978 Mdot
.45274 .34303 Mdot
.45487 .66818 Mdot
.30355 .45387 Mdot
.5735 .61013 Mdot
.45355 .49565 Mdot
.58465 .85309 Mdot
.35771 .45883 Mdot
.63033 .31671 Mdot
.47686 .58149 Mdot
.82859 .50189 Mdot
.62191 .59367 Mdot
.47633 .66632 Mdot
.27148 .49012 Mdot
.64242 .57557 Mdot
.61102 .61124 Mdot
.46562 .64647 Mdot
.62847 .42242 Mdot
.46273 .34678 Mdot
.32385 .44681 Mdot
.82886 .40791 Mdot
.43864 .62237 Mdot
.41756 .62586 Mdot
.31387 .44705 Mdot
.661 .39632 Mdot
.48548 .63797 Mdot
.30709 .28625 Mdot
.72341 .26238 Mdot
.62306 .40467 Mdot
.46861 .57003 Mdot
.51596 .78315 Mdot
.59374 .64078 Mdot
.8187 .63714 Mdot
.28309 .40198 Mdot
.48483 .35281 Mdot
.38577 .67102 Mdot
.17316 .67417 Mdot
.32518 .43429 Mdot
.23683 .66455 Mdot
.46163 .65462 Mdot
.41482 .63526 Mdot
.60033 .61279 Mdot
.44993 .64229 Mdot
.61968 .57593 Mdot
.57919 .84726 Mdot
.21617 .45088 Mdot
.66331 .61379 Mdot
.59839 .61648 Mdot
.25561 .49335 Mdot
.50773 .24887 Mdot
.62698 .60793 Mdot
.41516 .65113 Mdot
.49327 .69381 Mdot
.4284 .54084 Mdot
.358 .43692 Mdot
.40773 .24786 Mdot
.65876 .6513 Mdot
.36735 .46503 Mdot
.52184 .20576 Mdot
.67768 .64649 Mdot
.63647 .49228 Mdot
.627 .44355 Mdot
.42568 .58657 Mdot
.4478 .33704 Mdot
.4569 .32646 Mdot
.43369 .67928 Mdot
.47031 .61953 Mdot
.66943 .58702 Mdot
.34658 .44499 Mdot
.61792 .44618 Mdot
.42155 .64243 Mdot
.25569 .47579 Mdot
.34917 .46026 Mdot
.65344 .58764 Mdot
.4021 .7589 Mdot
.31279 .41452 Mdot
.52149 .58233 Mdot
.45366 .59075 Mdot
.46307 .6356 Mdot
.45889 .53935 Mdot
.63987 .44122 Mdot
.39362 .23775 Mdot
.41755 .58323 Mdot
.19806 .5138 Mdot
.59 .44112 Mdot
.51606 .59219 Mdot
.6623 .60245 Mdot
.66114 .37001 Mdot
.44003 .38933 Mdot
.47456 .51243 Mdot
.43231 .62675 Mdot
.72459 .31865 Mdot
.78691 .61826 Mdot
.43149 .33691 Mdot
.62527 .63899 Mdot
.33641 .44313 Mdot
.46018 .62573 Mdot
.45803 .75207 Mdot
.48076 .59912 Mdot
.34683 .41395 Mdot
.46489 .38542 Mdot
.62577 .44165 Mdot
.74252 .31351 Mdot
.45937 .32651 Mdot
.6161 .61348 Mdot
.30282 .2093 Mdot
.62631 .57075 Mdot
.6038 .6275 Mdot
.44487 .74712 Mdot
.63558 .44174 Mdot
.2005 .71232 Mdot
.65366 .78976 Mdot
.42127 .56966 Mdot
.65229 .39769 Mdot
.63749 .61039 Mdot
.40876 .63126 Mdot
.61632 .56657 Mdot
.64686 .63943 Mdot
.40949 .64719 Mdot
.40836 .61211 Mdot
.72906 .36343 Mdot
.44337 .17885 Mdot
.33781 .44428 Mdot
.67503 .60186 Mdot
.56897 .52419 Mdot
.40525 .6234 Mdot
.45465 .59926 Mdot
.56752 .36909 Mdot
.3523 .43315 Mdot
.76637 .46325 Mdot
.46456 .6523 Mdot
.22103 .43353 Mdot
.54159 .61298 Mdot
.67974 .58994 Mdot
.62921 .3987 Mdot
.19656 .56375 Mdot
.66142 .45929 Mdot
.61509 .5802 Mdot
.3448 .43801 Mdot
.61742 .64178 Mdot
.24161 .50285 Mdot
.67436 .42182 Mdot
.6266 .62252 Mdot
.57051 .45443 Mdot
.64958 .42578 Mdot
.66674 .42925 Mdot
.45408 .74093 Mdot
.46198 .31358 Mdot
.33433 .47909 Mdot
.66867 .40779 Mdot
.58734 .54299 Mdot
.65704 .4099 Mdot
.69517 .74281 Mdot
.4517 .57141 Mdot
.34562 .5165 Mdot
.40523 .34105 Mdot
.37095 .64043 Mdot
.67264 .41941 Mdot
.32094 .42086 Mdot
.47611 .64445 Mdot
.64965 .59456 Mdot
.32734 .46724 Mdot
.66456 .36379 Mdot
.4904 .36508 Mdot
.6653 .59173 Mdot
.67849 .43804 Mdot
.65358 .62201 Mdot
.53344 .53434 Mdot
.75326 .70208 Mdot
.24546 .33716 Mdot
.49028 .50004 Mdot
.46009 .66126 Mdot
.46029 .21509 Mdot
.50991 .63015 Mdot
.47373 .62167 Mdot
.46735 .34123 Mdot
.3275 .50933 Mdot
.62891 .60045 Mdot
.72751 .27969 Mdot
.64411 .44752 Mdot
.18811 .55048 Mdot
.53219 .65307 Mdot
.46946 .6632 Mdot
.64703 .57388 Mdot
.62258 .57147 Mdot
.52259 .73442 Mdot
.43934 .3908 Mdot
.50492 .62179 Mdot
.50827 .59902 Mdot
.43176 .67344 Mdot
.65433 .43848 Mdot
.27433 .37808 Mdot
.44117 .3742 Mdot
.79266 .65876 Mdot
.45729 .38523 Mdot
.30814 .48998 Mdot
.64145 .58411 Mdot
.35187 .45599 Mdot
.453 .59806 Mdot
.69795 .60285 Mdot
.60695 .58473 Mdot
.34678 .41852 Mdot
.31012 .42773 Mdot
.5944 .34809 Mdot
.63025 .43507 Mdot
.49767 .62477 Mdot
.44201 .58257 Mdot
.44434 .6465 Mdot
.47048 .63078 Mdot
.62594 .44958 Mdot
.48257 .63393 Mdot
.66503 .37634 Mdot
.53164 .55175 Mdot
.25283 .40922 Mdot
.55515 .46401 Mdot
.75142 .60306 Mdot
.64303 .59 Mdot
.60031 .53314 Mdot
.49025 .55322 Mdot
.38482 .80115 Mdot
.80381 .52619 Mdot
.41985 .57697 Mdot
.48977 .33595 Mdot
.35288 .64659 Mdot
.44202 .35623 Mdot
.87751 .48364 Mdot
.58939 .30282 Mdot
.48331 .17547 Mdot
.43032 .58862 Mdot
.54553 .38575 Mdot
.60827 .54984 Mdot
.50255 .64465 Mdot
.59899 .32157 Mdot
.74706 .58718 Mdot
.67182 .28792 Mdot
.33409 .42146 Mdot
.42705 .61548 Mdot
.68168 .63515 Mdot
.45641 .58181 Mdot
.46123 .60093 Mdot
.47438 .64861 Mdot
.65031 .38204 Mdot
.49746 .63646 Mdot
.48206 .62691 Mdot
.31806 .36701 Mdot
.28012 .61212 Mdot
.45522 .32446 Mdot
.75344 .67863 Mdot
.35166 .4598 Mdot
.66046 .57998 Mdot
.62735 .22044 Mdot
.63104 .42775 Mdot
.52885 .73002 Mdot
.46735 .63302 Mdot
.72114 .3475 Mdot
.67749 .37037 Mdot
.33392 .43113 Mdot
.44555 .38751 Mdot
.53265 .16923 Mdot
.47069 .34923 Mdot
.57458 .45555 Mdot
.4582 .35972 Mdot
.51267 .56419 Mdot
.67105 .58919 Mdot
.49255 .63111 Mdot
.66777 .41575 Mdot
.45993 .33634 Mdot
.29654 .54718 Mdot
.45829 .61342 Mdot
.47331 .35728 Mdot
.49284 .63038 Mdot
.41784 .51821 Mdot
.33289 .71968 Mdot
.50531 .37233 Mdot
.64869 .37373 Mdot
.65639 .42552 Mdot
.35448 .44044 Mdot
.65979 .58282 Mdot
.60223 .60116 Mdot
.64388 .4231 Mdot
.48339 .81622 Mdot
.46873 .57452 Mdot
.40514 .61782 Mdot
.19228 .54116 Mdot
.47407 .5839 Mdot
.25197 .55403 Mdot
.5745 .463 Mdot
.64977 .5898 Mdot
.44523 .67247 Mdot
.4593 .65329 Mdot
.42835 .62575 Mdot
.50923 .53312 Mdot
.44922 .36162 Mdot
.42997 .58093 Mdot
.30666 .43301 Mdot
.44048 .42823 Mdot
.41521 .64506 Mdot
.49833 .66818 Mdot
.6016 .60329 Mdot
.24314 .70289 Mdot
.62041 .42918 Mdot
.50598 .36335 Mdot
.48135 .33982 Mdot
.4188 .24809 Mdot
.67791 .53252 Mdot
.57118 .46076 Mdot
.80882 .63179 Mdot
.51217 .27193 Mdot
.3209 .45994 Mdot
.43538 .31383 Mdot
.59838 .47188 Mdot
.50109 .35431 Mdot
.62073 .44494 Mdot
.4452 .57208 Mdot
.45869 .57258 Mdot
.37245 .81284 Mdot
.47296 .65396 Mdot
.33243 .44218 Mdot
.67508 .38618 Mdot
.6466 .59556 Mdot
.33544 .43241 Mdot
.62644 .41083 Mdot
.6612 .61131 Mdot
.42693 .5748 Mdot
.42778 .57558 Mdot
.60394 .60837 Mdot
.62573 .62433 Mdot
.45015 .59305 Mdot
.44254 .27416 Mdot
.61402 .62472 Mdot
.63806 .62259 Mdot
.44379 .36921 Mdot
.44737 .33996 Mdot
.52607 .61443 Mdot
.65053 .4003 Mdot
.48226 .62874 Mdot
.47611 .34562 Mdot
.35059 .44413 Mdot
.63073 .59769 Mdot
.4506 .66168 Mdot
.42582 .65038 Mdot
.32009 .44628 Mdot
.34447 .43153 Mdot
.31953 .42409 Mdot
.66435 .38083 Mdot
.43818 .64223 Mdot
.62038 .60478 Mdot
.62881 .43723 Mdot
.31331 .47255 Mdot
.34737 .42491 Mdot
.42244 .34124 Mdot
.48604 .59073 Mdot
.40884 .40162 Mdot
.14021 .62849 Mdot
.21271 .53267 Mdot
.42684 .36232 Mdot
.42842 .37714 Mdot
.2854 .58455 Mdot
.40513 .4862 Mdot
.63907 .41586 Mdot
.29995 .41013 Mdot
.24244 .45529 Mdot
.46557 .5659 Mdot
.3965 .6093 Mdot
.47343 .55773 Mdot
.31391 .42822 Mdot
.30618 .49929 Mdot
.64238 .56761 Mdot
.64989 .67175 Mdot
.34345 .46561 Mdot
.46521 .31857 Mdot
.43498 .31918 Mdot
.45906 .38606 Mdot
.43748 .57335 Mdot
.55401 .74306 Mdot
.63439 .52709 Mdot
.41836 .20913 Mdot
.67268 .40736 Mdot
.67687 .64139 Mdot
.82489 .4959 Mdot
.60669 .60893 Mdot
.47121 .39523 Mdot
.31282 .45542 Mdot
.6345 .6253 Mdot
.61337 .42066 Mdot
.66633 .40534 Mdot
.45002 .37565 Mdot
.45922 .37827 Mdot
.49194 .3747 Mdot
.62056 .63648 Mdot
.64005 .58282 Mdot
.43444 .62901 Mdot
.63369 .59398 Mdot
.33744 .79169 Mdot
.36444 .45617 Mdot
.47396 .4109 Mdot
.64827 .40655 Mdot
.66113 .61662 Mdot
.45724 .61624 Mdot
.40321 .49955 Mdot
.76165 .54453 Mdot
.30792 .45368 Mdot
.30717 .70777 Mdot
.87445 .48995 Mdot
.49909 .62249 Mdot
.64698 .43848 Mdot
.28708 .72937 Mdot
.45433 .61035 Mdot
.47618 .37837 Mdot
.485 .24622 Mdot
.51999 .32232 Mdot
.4938 .60381 Mdot
.48217 .56868 Mdot
.62077 .40523 Mdot
.80239 .62894 Mdot
.43814 .62724 Mdot
.75909 .47364 Mdot
.61159 .45517 Mdot
.44307 .37779 Mdot
.68433 .21576 Mdot
.31354 .29504 Mdot
.33386 .55023 Mdot
.44487 .37449 Mdot
.48271 .61176 Mdot
.4442 .35797 Mdot
.30376 .44443 Mdot
.48308 .38728 Mdot
.64284 .56648 Mdot
.43038 .34485 Mdot
.4168 .62516 Mdot
.62868 .60976 Mdot
.64297 .41279 Mdot
.20219 .60224 Mdot
.37817 .36911 Mdot
.45526 .36122 Mdot
.50919 .35966 Mdot
.44945 .67113 Mdot
.75828 .43128 Mdot
.42992 .6841 Mdot
.4141 .59798 Mdot
.66039 .44268 Mdot
.64877 .57658 Mdot
.63591 .39112 Mdot
.49737 .66024 Mdot
.30241 .28481 Mdot
.62515 .41699 Mdot
.7119 .31647 Mdot
.31471 .45207 Mdot
.49116 .4413 Mdot
.46126 .61927 Mdot
.65927 .39124 Mdot
.43878 .64086 Mdot
.65066 .57044 Mdot
.5421 .42902 Mdot
.65682 .29063 Mdot
.66354 .42627 Mdot
.73011 .31531 Mdot
.33378 .49617 Mdot
.46189 .69214 Mdot
.62268 .41094 Mdot
.2755 .4895 Mdot
.49882 .33947 Mdot
.33844 .46477 Mdot
.29975 .43022 Mdot
.32651 .46901 Mdot
.40936 .66983 Mdot
.51325 .66359 Mdot
.30659 .46271 Mdot
.61119 .43775 Mdot
.32005 .41524 Mdot
.70551 .57077 Mdot
.71202 .27464 Mdot
.33249 .45698 Mdot
.4348 .61062 Mdot
.55063 .60345 Mdot
.28541 .60736 Mdot
.63141 .34097 Mdot
.50435 .17494 Mdot
.79131 .49477 Mdot
.47687 .59331 Mdot
.57922 .61302 Mdot
.67027 .61689 Mdot
.26493 .70416 Mdot
.23821 .5477 Mdot
.20899 .48872 Mdot
.5996 .62111 Mdot
.60035 .27413 Mdot
.65735 .58796 Mdot
.46669 .65911 Mdot
.40652 .62402 Mdot
.59255 .61402 Mdot
.25079 .39815 Mdot
.63031 .2961 Mdot
.77962 .34997 Mdot
.64735 .62362 Mdot
.63166 .40137 Mdot
.68057 .4105 Mdot
.66749 .42942 Mdot
.2448 .65406 Mdot
.63079 .57378 Mdot
.43649 .64944 Mdot
.47743 .33968 Mdot
.43956 .57679 Mdot
.64596 .4307 Mdot
.72573 .27621 Mdot
.62163 .58542 Mdot
.43183 .59391 Mdot
.3565 .59399 Mdot
.47531 .37423 Mdot
.31997 .45291 Mdot
.39839 .53254 Mdot
.21131 .49508 Mdot
.65389 .44202 Mdot
.59093 .59758 Mdot
.5575 .2959 Mdot
.69938 .28513 Mdot
.38945 .63564 Mdot
.51385 .6078 Mdot
.84085 .42356 Mdot
.23063 .44941 Mdot
.49974 .59865 Mdot
.50535 .35323 Mdot
.58141 .28208 Mdot
.43098 .65488 Mdot
.67313 .61166 Mdot
.30621 .41984 Mdot
.31479 .46169 Mdot
.5232 .6284 Mdot
.44868 .4878 Mdot
.54307 .40761 Mdot
.46475 .6422 Mdot
.51964 .58 Mdot
.44396 .37729 Mdot
.50369 .26465 Mdot
.1986 .50783 Mdot
.34469 .43593 Mdot
.4912 .63193 Mdot
.57355 .2256 Mdot
.59626 .60266 Mdot
.42854 .34582 Mdot
.67541 .40572 Mdot
.48128 .5266 Mdot
.44798 .38853 Mdot
.43518 .65961 Mdot
.48103 .64266 Mdot
.66285 .38794 Mdot
.67923 .58842 Mdot
.3116 .43175 Mdot
.476 .33583 Mdot
.33786 .42671 Mdot
.63882 .57477 Mdot
.63265 .58891 Mdot
.35499 .63293 Mdot
.3868 .59038 Mdot
.45513 .34738 Mdot
.47289 .67493 Mdot
.53322 .36387 Mdot
.83735 .58854 Mdot
.67699 .43579 Mdot
.50245 .61217 Mdot
.6718 .57425 Mdot
.6598 .43208 Mdot
.40955 .62551 Mdot
.83274 .40268 Mdot
.40493 .62556 Mdot
.5938 .44552 Mdot
.23758 .3399 Mdot
.32797 .42318 Mdot
.64525 .67 Mdot
.77893 .4181 Mdot
.46946 .58433 Mdot
.49141 .34543 Mdot
.49437 .55993 Mdot
.63051 .41909 Mdot
.63941 .58544 Mdot
.82783 .62829 Mdot
.659 .41251 Mdot
.44824 .58533 Mdot
.33443 .4334 Mdot
.61245 .57715 Mdot
.27169 .43683 Mdot
.28985 .39602 Mdot
.48607 .68355 Mdot
.46744 .67723 Mdot
.47315 .63589 Mdot
.34396 .24932 Mdot
.50468 .36593 Mdot
.64396 .61599 Mdot
.64787 .43917 Mdot
.64157 .42254 Mdot
.45008 .3724 Mdot
.71885 .3925 Mdot
.49523 .44028 Mdot
.14345 .59526 Mdot
.45034 .34388 Mdot
.33425 .4723 Mdot
.76198 .45385 Mdot
.48814 .33903 Mdot
.47128 .36141 Mdot
.44204 .36833 Mdot
.65429 .47483 Mdot
.65873 .61014 Mdot
.4308 .65807 Mdot
.67795 .60287 Mdot
.48351 .61399 Mdot
.59106 .44062 Mdot
.66679 .42201 Mdot
.627 .58179 Mdot
.83203 .42617 Mdot
.56546 .78914 Mdot
.44528 .60923 Mdot
.82719 .4985 Mdot
.40829 .57111 Mdot
.27179 .55908 Mdot
.42168 .55841 Mdot
.45636 .37014 Mdot
.42185 .69008 Mdot
.42905 .67359 Mdot
.23244 .67201 Mdot
.64677 .40525 Mdot
.48222 .32577 Mdot
.43594 .56076 Mdot
.5312 .58965 Mdot
.60464 .6309 Mdot
.63669 .6248 Mdot
.30023 .4443 Mdot
.31891 .68376 Mdot
.64129 .41105 Mdot
.65473 .7801 Mdot
.47165 .59108 Mdot
.26463 .36442 Mdot
.56411 .67174 Mdot
.40886 .62134 Mdot
.78941 .42562 Mdot
.54822 .7379 Mdot
.46062 .62375 Mdot
.55121 .50491 Mdot
.6609 .39753 Mdot
.28794 .29587 Mdot
.40828 .63852 Mdot
.48102 .37325 Mdot
.64677 .58301 Mdot
.63183 .56538 Mdot
.30394 .45686 Mdot
.42506 .82015 Mdot
.64303 .38766 Mdot
.63285 .58272 Mdot
.46396 .61053 Mdot
.64101 .4429 Mdot
.45883 .33037 Mdot
.47525 .65949 Mdot
.24047 .56082 Mdot
.63937 .59572 Mdot
.42866 .66696 Mdot
.74263 .48147 Mdot
.30767 .59644 Mdot
.28988 .24824 Mdot
.64826 .44029 Mdot
.35088 .43424 Mdot
.49741 .56282 Mdot
.46852 .8063 Mdot
.39031 .61006 Mdot
.35616 .5145 Mdot
.71159 .57594 Mdot
.34732 .42892 Mdot
.44106 .60237 Mdot
.42916 .64566 Mdot
.40008 .44403 Mdot
.3474 .44018 Mdot
.43574 .58384 Mdot
.54686 .57144 Mdot
.65585 .61315 Mdot
.4946 .38804 Mdot
.64963 .59969 Mdot
.43875 .61397 Mdot
.39313 .57794 Mdot
.60622 .61783 Mdot
.84441 .53404 Mdot
.34243 .48268 Mdot
.62162 .42813 Mdot
.39488 .5955 Mdot
.41056 .59023 Mdot
.17072 .42685 Mdot
.43908 .32594 Mdot
.52902 .24188 Mdot
.31387 .33193 Mdot
.53765 .21407 Mdot
.31153 .29647 Mdot
.39312 .18068 Mdot
.22698 .43802 Mdot
.49247 .64684 Mdot
.58135 .64948 Mdot
.61495 .51692 Mdot
.67411 .40969 Mdot
.7026 .70953 Mdot
.47679 .59192 Mdot
.46357 .60185 Mdot
.42627 .35141 Mdot
.70783 .32516 Mdot
.20777 .48853 Mdot
.41228 .49377 Mdot
.31172 .43337 Mdot
.67432 .60296 Mdot
.42446 .65633 Mdot
.55601 .49305 Mdot
.45364 .3243 Mdot
.26017 .3708 Mdot
.43241 .59573 Mdot
.37717 .79099 Mdot
.74569 .54799 Mdot
.63571 .43892 Mdot
.4845 .34062 Mdot
.21674 .47551 Mdot
.48807 .59344 Mdot
.67607 .40397 Mdot
.44403 .62334 Mdot
.4662 .28053 Mdot
.49124 .66674 Mdot
.33565 .45998 Mdot
.46221 .65569 Mdot
.30917 .49167 Mdot
.25892 .2411 Mdot
.31603 .40416 Mdot
.61446 .56894 Mdot
.49863 .40239 Mdot
.45011 .35725 Mdot
.62804 .624 Mdot
.45199 .35475 Mdot
.53225 .71353 Mdot
.6461 .70517 Mdot
.31085 .44622 Mdot
.53256 .59737 Mdot
.33235 .45363 Mdot
.43122 .33534 Mdot
.48391 .59566 Mdot
.8594 .54469 Mdot
.46046 .34066 Mdot
.21505 .37842 Mdot
.65429 .41147 Mdot
.46197 .31946 Mdot
.40681 .63426 Mdot
.55823 .30585 Mdot
.45982 .32575 Mdot
.66446 .29971 Mdot
.4291 .62632 Mdot
.63946 .59125 Mdot
.43275 .65424 Mdot
.41066 .57701 Mdot
.51207 .34256 Mdot
.48838 .61728 Mdot
.62688 .41035 Mdot
.61799 .63021 Mdot
.58978 .1757 Mdot
.73994 .59674 Mdot
.4522 .57893 Mdot
.46132 .61018 Mdot
.63053 .6436 Mdot
.423 .58399 Mdot
.62588 .44934 Mdot
.43358 .89503 Mdot
.31516 .45233 Mdot
.50802 .34431 Mdot
.31145 .29503 Mdot
.42549 .57387 Mdot
.47912 .6398 Mdot
.82176 .37978 Mdot
.2868 .30748 Mdot
.62399 .41069 Mdot
.42034 .66851 Mdot
.46017 .32811 Mdot
.33451 .4359 Mdot
.61274 .44629 Mdot
.46162 .63585 Mdot
.44919 .59927 Mdot
.35288 .43953 Mdot
.4301 .71621 Mdot
.22662 .61266 Mdot
.66663 .39114 Mdot
.39348 .672 Mdot
.49425 .41131 Mdot
.48252 .58157 Mdot
.2603 .67665 Mdot
.62823 .62168 Mdot
.65389 .44348 Mdot
.46577 .22218 Mdot
.49802 .60209 Mdot
.63374 .39585 Mdot
.6419 .40957 Mdot
.41457 .66283 Mdot
.6746 .57505 Mdot
.63733 .63703 Mdot
.65619 .62134 Mdot
.37429 .82867 Mdot
.31853 .55429 Mdot
.49177 .37477 Mdot
.66131 .39724 Mdot
.5054 .37497 Mdot
.36637 .44108 Mdot
.58619 .47545 Mdot
.50811 .36651 Mdot
.65587 .62772 Mdot
.49144 .40413 Mdot
.42718 .63781 Mdot
.64176 .41411 Mdot
.50106 .35894 Mdot
.42656 .56764 Mdot
.74743 .41309 Mdot
.68602 .35759 Mdot
.33535 .41749 Mdot
.30077 .4248 Mdot
.41269 .63824 Mdot
.4437 .39317 Mdot
.45229 .59402 Mdot
.65279 .45156 Mdot
.75576 .43603 Mdot
.39415 .60144 Mdot
.45394 .36235 Mdot
.58988 .62926 Mdot
.21363 .48738 Mdot
.4281 .687 Mdot
.43551 .60962 Mdot
.4867 .61314 Mdot
.44407 .62387 Mdot
.66754 .27512 Mdot
.65624 .45675 Mdot
.75023 .60142 Mdot
.37435 .24445 Mdot
.61623 .59089 Mdot
.67493 .62756 Mdot
.20967 .53946 Mdot
.67252 .49104 Mdot
.6526 .39918 Mdot
.47251 .62477 Mdot
.69414 .52373 Mdot
.71841 .26101 Mdot
.85844 .46205 Mdot
.39179 .44178 Mdot
.44832 .32268 Mdot
.58901 .60563 Mdot
.4752 .32966 Mdot
.48377 .60642 Mdot
.49522 .56321 Mdot
.37675 .17969 Mdot
.60622 .44287 Mdot
.31011 .44828 Mdot
.48326 .61715 Mdot
.32159 .55788 Mdot
.47881 .34781 Mdot
.49617 .32633 Mdot
.42198 .58928 Mdot
.68365 .60233 Mdot
.2077 .33387 Mdot
.64138 .44089 Mdot
.78919 .48629 Mdot
.61697 .54802 Mdot
.77921 .52586 Mdot
.64476 .43397 Mdot
.35555 .39805 Mdot
.42743 .3608 Mdot
.48905 .71239 Mdot
.61339 .59144 Mdot
.32643 .46644 Mdot
.51494 .59281 Mdot
.59911 .60603 Mdot
.44363 .38096 Mdot
.63915 .58787 Mdot
.47263 .65054 Mdot
.62191 .46195 Mdot
.48649 .35211 Mdot
.61151 .40743 Mdot
.6832 .58878 Mdot
.34308 .43593 Mdot
.44492 .47008 Mdot
.65499 .74637 Mdot
.54555 .73561 Mdot
.43265 .57825 Mdot
.56473 .4955 Mdot
.43934 .64922 Mdot
.66429 .63511 Mdot
.45315 .61802 Mdot
.71019 .59615 Mdot
.48992 .3451 Mdot
.40213 .62921 Mdot
.46772 .63951 Mdot
.72895 .6842 Mdot
.42454 .60068 Mdot
.48813 .65826 Mdot
.46311 .62544 Mdot
.68549 .57082 Mdot
.53758 .60282 Mdot
.66384 .60411 Mdot
.34782 .38593 Mdot
.46986 .36419 Mdot
.30921 .41939 Mdot
.35633 .45765 Mdot
.33591 .51868 Mdot
.40768 .275 Mdot
.70984 .33673 Mdot
.6482 .60348 Mdot
.63311 .40797 Mdot
.45029 .62139 Mdot
.39863 .19977 Mdot
.53919 .37017 Mdot
.44476 .3333 Mdot
.74073 .59548 Mdot
.3812 .65899 Mdot
.30605 .26406 Mdot
.44428 .67476 Mdot
.38957 .82372 Mdot
.38103 .60097 Mdot
.49082 .66588 Mdot
.51301 .35978 Mdot
.36934 .44395 Mdot
.4133 .59361 Mdot
.60119 .62837 Mdot
.3421 .46045 Mdot
.55672 .64642 Mdot
.42479 .41593 Mdot
.36747 .39175 Mdot
.70274 .68926 Mdot
.43863 .63559 Mdot
.48672 .35364 Mdot
.6663 .59165 Mdot
.20007 .5014 Mdot
.62782 .43734 Mdot
.60192 .4152 Mdot
.5793 .52563 Mdot
.83659 .50172 Mdot
.34937 .46072 Mdot
.44393 .73238 Mdot
.41741 .62791 Mdot
.40011 .33778 Mdot
.39388 .61062 Mdot
.72306 .27289 Mdot
.34719 .46833 Mdot
.64851 .63315 Mdot
.63374 .40066 Mdot
.67499 .61169 Mdot
.53684 .74365 Mdot
.47077 .30396 Mdot
.52948 .461 Mdot
.47106 .35189 Mdot
.45948 .4376 Mdot
.63526 .61301 Mdot
.49233 .62783 Mdot
.1412 .59371 Mdot
.63475 .62256 Mdot
.60501 .58387 Mdot
.77879 .66356 Mdot
.84728 .57313 Mdot
.4057 .68625 Mdot
.60428 .62107 Mdot
.46782 .35616 Mdot
.34046 .44425 Mdot
.44402 .65896 Mdot
.43226 .63489 Mdot
.60012 .60736 Mdot
.50834 .33909 Mdot
.48873 .78619 Mdot
.45886 .37675 Mdot
.65955 .6134 Mdot
.47426 .36914 Mdot
.54815 .30087 Mdot
.4988 .34549 Mdot
.41178 .58952 Mdot
.45245 .61897 Mdot
.37775 .27437 Mdot
.63336 .58931 Mdot
.46297 .64366 Mdot
.45608 .66907 Mdot
.62337 .60527 Mdot
.29361 .40125 Mdot
.49297 .78039 Mdot
.46889 .57852 Mdot
.424 .61596 Mdot
.34717 .42948 Mdot
.59678 .49219 Mdot
.36726 .733 Mdot
.47562 .64464 Mdot
.34585 .47397 Mdot
.607 .63037 Mdot
.4432 .59222 Mdot
.6638 .23253 Mdot
.58352 .28125 Mdot
.49862 .60939 Mdot
.49678 .33773 Mdot
.43098 .67385 Mdot
.27604 .26282 Mdot
.41352 .59802 Mdot
.63265 .60617 Mdot
.64005 .57796 Mdot
.66258 .77458 Mdot
.62025 .61494 Mdot
.44599 .34084 Mdot
.64792 .42793 Mdot
.72965 .29766 Mdot
.4599 .33026 Mdot
.38471 .633 Mdot
.66586 .78447 Mdot
.48414 .6505 Mdot
.41458 .57908 Mdot
.22602 .32851 Mdot
.46668 .332 Mdot
.6467 .57213 Mdot
.41452 .47386 Mdot
.41077 .55818 Mdot
.65711 .44101 Mdot
.51926 .59485 Mdot
.46289 .56953 Mdot
.23257 .34687 Mdot
.61699 .25621 Mdot
.67126 .43379 Mdot
.50663 .62231 Mdot
.47639 .64391 Mdot
.48115 .31149 Mdot
.46134 .61453 Mdot
.34171 .44846 Mdot
.63683 .57266 Mdot
.4891 .33739 Mdot
.319 .44244 Mdot
.47443 .58775 Mdot
.31611 .4267 Mdot
.49558 .3654 Mdot
.67534 .42117 Mdot
.4865 .60182 Mdot
.35708 .43492 Mdot
.31482 .42899 Mdot
.4442 .64979 Mdot
.64259 .58583 Mdot
.37888 .60735 Mdot
.42855 .59345 Mdot
.45302 .66154 Mdot
.60347 .59883 Mdot
.82317 .32207 Mdot
.40434 .61399 Mdot
.36484 .49329 Mdot
.61084 .58143 Mdot
.41999 .42771 Mdot
.48166 .32933 Mdot
.45701 .56959 Mdot
.67288 .42833 Mdot
.66445 .39481 Mdot
.44735 .38364 Mdot
.60418 .58149 Mdot
.31911 .31975 Mdot
.61768 .64313 Mdot
.41756 .55701 Mdot
.50444 .59892 Mdot
.57379 .81578 Mdot
.4814 .17207 Mdot
.66691 .58099 Mdot
.40902 .38153 Mdot
.43289 .49065 Mdot
.65317 .39258 Mdot
.4682 .31828 Mdot
.5888 .6029 Mdot
.62352 .57375 Mdot
.6497 .59162 Mdot
.3181 .4627 Mdot
.38198 .27373 Mdot
.66649 .57482 Mdot
.67991 .61803 Mdot
.42786 .62945 Mdot
.4759 .64306 Mdot
.22293 .49326 Mdot
.25749 .61286 Mdot
.31813 .42024 Mdot
.45589 .38293 Mdot
.32359 .81405 Mdot
.64866 .45273 Mdot
.74667 .66293 Mdot
.40191 .59076 Mdot
.13104 .63707 Mdot
.41451 .64636 Mdot
.46559 .61225 Mdot
.61545 .62948 Mdot
.34828 .42452 Mdot
.32699 .45613 Mdot
.64281 .61788 Mdot
.67405 .63176 Mdot
.3413 .44953 Mdot
.80514 .46825 Mdot
.68702 .23926 Mdot
.4692 .29948 Mdot
.62147 .5994 Mdot
.6577 .7362 Mdot
.67116 .39168 Mdot
.57359 .63496 Mdot
.63964 .45806 Mdot
.47669 .35435 Mdot
.43992 .38618 Mdot
.65746 .43748 Mdot
.43055 .62559 Mdot
.49681 .37303 Mdot
.49439 .64152 Mdot
.79452 .53613 Mdot
.55226 .76709 Mdot
.33883 .28603 Mdot
.51388 .6529 Mdot
.35497 .39391 Mdot
.70917 .38342 Mdot
.45773 .58643 Mdot
.57943 .2139 Mdot
.30893 .44109 Mdot
.56082 .62007 Mdot
.64852 .44911 Mdot
.25841 .26945 Mdot
.49035 .60233 Mdot
.63299 .60343 Mdot
.64458 .40361 Mdot
.46184 .51633 Mdot
.75766 .46662 Mdot
.48515 .61378 Mdot
.15129 .63847 Mdot
.67194 .56323 Mdot
.49292 .34247 Mdot
.4521 .81174 Mdot
.67243 .5837 Mdot
.38776 .45374 Mdot
.41153 .23827 Mdot
.8369 .45293 Mdot
.66267 .58154 Mdot
.44977 .31759 Mdot
.66472 .61688 Mdot
.34436 .43829 Mdot
.58237 .59848 Mdot
.48293 .34494 Mdot
.43254 .59923 Mdot
.45183 .37004 Mdot
.30068 .43699 Mdot
.2328 .61729 Mdot
.67326 .43018 Mdot
.48455 .32732 Mdot
.66384 .4201 Mdot
.30962 .62985 Mdot
.33756 .25762 Mdot
.62428 .43959 Mdot
.40722 .76589 Mdot
.49672 .59007 Mdot
.67797 .58848 Mdot
.44689 .36724 Mdot
.46108 .24408 Mdot
.43818 .47404 Mdot
.60927 .59922 Mdot
.47447 .38188 Mdot
.58806 .5211 Mdot
.4237 .78573 Mdot
.45655 .68369 Mdot
.31 .65871 Mdot
.61908 .60231 Mdot
.43638 .32513 Mdot
.19156 .54673 Mdot
.66377 .62548 Mdot
.44854 .34687 Mdot
.63372 .39875 Mdot
.6405 .42679 Mdot
.43031 .58403 Mdot
.60289 .42939 Mdot
.47188 .38627 Mdot
.70436 .37351 Mdot
.59502 .6134 Mdot
.48868 .52294 Mdot
.36298 .44789 Mdot
.46409 .36938 Mdot
.47334 .65429 Mdot
.58486 .58412 Mdot
.55675 .28269 Mdot
.51213 .79394 Mdot
.22415 .68833 Mdot
.45036 .3726 Mdot
.62692 .57463 Mdot
.63337 .60075 Mdot
.41811 .68223 Mdot
.48375 .49872 Mdot
.32574 .31367 Mdot
.36855 .54311 Mdot
.39073 .51106 Mdot
.48614 .39254 Mdot
.52145 .33261 Mdot
.44322 .55999 Mdot
.44323 .63292 Mdot
.64716 .39442 Mdot
.43061 .60272 Mdot
.62291 .62948 Mdot
.42617 .5844 Mdot
.6495 .43667 Mdot
.46896 .34703 Mdot
.48304 .59811 Mdot
.32709 .42232 Mdot
.6785 .39722 Mdot
.61586 .41022 Mdot
.45856 .36659 Mdot
.59935 .60357 Mdot
.27776 .41218 Mdot
.45942 .37873 Mdot
.43832 .63482 Mdot
.62346 .49049 Mdot
.46088 .66188 Mdot
.65441 .66482 Mdot
.6642 .62608 Mdot
.48288 .33479 Mdot
.59586 .61947 Mdot
.66391 .41185 Mdot
.38447 .24078 Mdot
.44428 .61509 Mdot
.45145 .34117 Mdot
.47758 .2655 Mdot
.54421 .66582 Mdot
.66957 .64023 Mdot
.70701 .35809 Mdot
.67142 .63125 Mdot
.43902 .37613 Mdot
.73317 .70571 Mdot
.34021 .46559 Mdot
.4457 .33175 Mdot
.55471 .17505 Mdot
.45705 .34899 Mdot
.41743 .60487 Mdot
.4141 .63848 Mdot
.4926 .3402 Mdot
.35488 .44071 Mdot
.21094 .46358 Mdot
.49341 .39365 Mdot
.65042 .57411 Mdot
.80342 .55294 Mdot
.17508 .60061 Mdot
.61303 .4697 Mdot
.64042 .3988 Mdot
.39155 .57303 Mdot
.4871 .66543 Mdot
.62823 .45619 Mdot
.61402 .40982 Mdot
.30978 .45938 Mdot
.44137 .36233 Mdot
.68441 .56656 Mdot
.6462 .37819 Mdot
.39453 .55265 Mdot
.3987 .27982 Mdot
.44161 .68821 Mdot
.62739 .54124 Mdot
.39622 .60838 Mdot
.36871 .51645 Mdot
.64921 .43812 Mdot
.43436 .66658 Mdot
.43042 .67926 Mdot
.66576 .43706 Mdot
.34266 .44613 Mdot
.69808 .45364 Mdot
.48131 .36508 Mdot
.72115 .24048 Mdot
.46895 .67266 Mdot
.41497 .60542 Mdot
.67287 .41023 Mdot
.31982 .35326 Mdot
.6209 .58408 Mdot
.67202 .6206 Mdot
.5053 .36319 Mdot
.46327 .47638 Mdot
.45873 .57184 Mdot
.44488 .58795 Mdot
.48889 .35975 Mdot
.46672 .31973 Mdot
.66357 .33336 Mdot
.4225 .64127 Mdot
.65066 .40399 Mdot
.29192 .48111 Mdot
.65109 .43764 Mdot
.46601 .65893 Mdot
.4131 .61166 Mdot
.41295 .58872 Mdot
.4736 .65339 Mdot
.60959 .4297 Mdot
.42861 .66073 Mdot
.54722 .6063 Mdot
.61783 .58307 Mdot
.48133 .6255 Mdot
.38782 .51368 Mdot
.43015 .61089 Mdot
.34052 .44574 Mdot
.39159 .74109 Mdot
.48973 .60202 Mdot
.45096 .57115 Mdot
.51462 .37856 Mdot
.44647 .60437 Mdot
.65036 .45264 Mdot
.6258 .59118 Mdot
.66235 .39813 Mdot
.66901 .39685 Mdot
.45695 .39225 Mdot
.30629 .46174 Mdot
.42983 .57192 Mdot
.30832 .45261 Mdot
.38726 .63485 Mdot
.49919 .60348 Mdot
.39664 .24734 Mdot
.40216 .82966 Mdot
.23471 .63953 Mdot
.44292 .6164 Mdot
.4639 .335 Mdot
.48164 .33053 Mdot
.53613 .65821 Mdot
.44948 .68507 Mdot
.61959 .44764 Mdot
.66131 .39264 Mdot
.24545 .5658 Mdot
.25381 .32771 Mdot
.34115 .44596 Mdot
.56916 .48303 Mdot
.50547 .61845 Mdot
.45211 .66759 Mdot
.47728 .65986 Mdot
.50406 .37526 Mdot
.38268 .49915 Mdot
.44838 .33057 Mdot
.75394 .55439 Mdot
.66326 .43063 Mdot
.49003 .60812 Mdot
.68472 .54308 Mdot
.64256 .62618 Mdot
.62676 .59116 Mdot
.61643 .4113 Mdot
.52631 .36756 Mdot
.21694 .5256 Mdot
.86799 .48378 Mdot
.65276 .55756 Mdot
.33 .41461 Mdot
.45862 .5838 Mdot
.46389 .35062 Mdot
.66061 .62091 Mdot
.321 .41577 Mdot
.49521 .62445 Mdot
.38329 .27285 Mdot
.43919 .62069 Mdot
.62138 .51907 Mdot
.65363 .58647 Mdot
.7158 .26601 Mdot
.61713 .57056 Mdot
.67951 .39793 Mdot
.64392 .44863 Mdot
.41074 .62726 Mdot
.51984 .82478 Mdot
.67901 .60511 Mdot
.67032 .46285 Mdot
.33543 .47198 Mdot
.56791 .29357 Mdot
.34569 .44304 Mdot
.49117 .34282 Mdot
.34504 .46037 Mdot
.48568 .34481 Mdot
.24004 .59163 Mdot
.70623 .60129 Mdot
.31503 .44553 Mdot
.45287 .27958 Mdot
.46041 .68588 Mdot
.32536 .41873 Mdot
.44185 .55189 Mdot
.63596 .66723 Mdot
.48768 .36378 Mdot
.34982 .46334 Mdot
.49075 .63088 Mdot
.3708 .19432 Mdot
.62182 .4159 Mdot
.62308 .45081 Mdot
.42815 .55408 Mdot
.47144 .39452 Mdot
.59437 .62235 Mdot
.68088 .26652 Mdot
.68386 .39525 Mdot
.40631 .6206 Mdot
.41654 .59087 Mdot
.67599 .62566 Mdot
.7244 .59974 Mdot
.4113 .6216 Mdot
.35687 .60931 Mdot
.41994 .64019 Mdot
.62024 .40949 Mdot
.67514 .60946 Mdot
.6303 .59674 Mdot
.47969 .38108 Mdot
.61477 .62304 Mdot
.50462 .68473 Mdot
.70048 .54186 Mdot
.36528 .63158 Mdot
.65983 .41469 Mdot
.73471 .55332 Mdot
.75419 .55832 Mdot
.50408 .17715 Mdot
.68478 .61412 Mdot
.39523 .61615 Mdot
.59589 .60292 Mdot
.3369 .43747 Mdot
.63956 .59299 Mdot
.58944 .60715 Mdot
.45479 .59161 Mdot
.48241 .61192 Mdot
.47342 .33969 Mdot
.4663 .49433 Mdot
.60223 .59461 Mdot
.41863 .64965 Mdot
.49344 .65911 Mdot
.48555 .65433 Mdot
.55912 .40668 Mdot
.67352 .58867 Mdot
.80579 .61134 Mdot
.27207 .50284 Mdot
.60138 .59619 Mdot
.21864 .31183 Mdot
.4996 .26082 Mdot
.42255 .35948 Mdot
.63921 .37577 Mdot
.42361 .64437 Mdot
.46783 .32316 Mdot
.48395 .60572 Mdot
.62638 .54078 Mdot
.45434 .6005 Mdot
.34273 .451 Mdot
.49159 .64846 Mdot
.44251 .38433 Mdot
.45556 .37662 Mdot
.40734 .60761 Mdot
.47937 .59769 Mdot
.2251 .59308 Mdot
.69034 .61343 Mdot
.62987 .58542 Mdot
.30758 .33457 Mdot
.31826 .43287 Mdot
.65521 .44227 Mdot
.45959 .62094 Mdot
.47052 .39188 Mdot
.45349 .37509 Mdot
.67586 .58983 Mdot
.47755 .37684 Mdot
.64155 .44011 Mdot
.4486 .61441 Mdot
.62797 .4555 Mdot
.31731 .46309 Mdot
.67508 .60048 Mdot
.48332 .61994 Mdot
.42769 .62905 Mdot
.64044 .5779 Mdot
.44054 .56323 Mdot
.34836 .43144 Mdot
.45499 .3507 Mdot
.66809 .58803 Mdot
.64598 .42771 Mdot
.4886 .34218 Mdot
.44608 .66271 Mdot
.28251 .7727 Mdot
.41868 .60736 Mdot
.42793 .65077 Mdot
.54534 .16686 Mdot
.49958 .63444 Mdot
.44806 .37066 Mdot
.65387 .63137 Mdot
.51827 .6443 Mdot
.31983 .5206 Mdot
.85857 .39382 Mdot
.44422 .33513 Mdot
.45409 .58255 Mdot
.42262 .18488 Mdot
.4417 .58569 Mdot
.58622 .80315 Mdot
.4398 .29852 Mdot
.4451 .44691 Mdot
.39513 .58598 Mdot
.63166 .42742 Mdot
.47192 .33761 Mdot
.49132 .34789 Mdot
.78887 .5983 Mdot
.45115 .59005 Mdot
.5989 .50999 Mdot
.48929 .62463 Mdot
.64216 .43188 Mdot
.24351 .53537 Mdot
.45207 .37599 Mdot
.2533 .6972 Mdot
.43637 .64794 Mdot
.63978 .56723 Mdot
.48742 .40623 Mdot
.54923 .33351 Mdot
.45123 .66115 Mdot
.30551 .44132 Mdot
.66009 .37806 Mdot
.51099 .64486 Mdot
.65636 .41957 Mdot
.45633 .66107 Mdot
.35464 .64659 Mdot
.45431 .81984 Mdot
.64632 .5883 Mdot
.63585 .39889 Mdot
.61547 .48183 Mdot
.41352 .65255 Mdot
.66417 .58336 Mdot
.612 .59293 Mdot
.30612 .45271 Mdot
.55027 .44959 Mdot
.73226 .47425 Mdot
.58755 .77588 Mdot
.80126 .576 Mdot
.50496 .39705 Mdot
.63942 .28646 Mdot
.45234 .65477 Mdot
.27373 .35391 Mdot
.66159 .44477 Mdot
.42091 .60052 Mdot
.52795 .6925 Mdot
.64669 .62163 Mdot
.42049 .61862 Mdot
.33422 .45283 Mdot
.28184 .36668 Mdot
.26429 .3728 Mdot
.42058 .2267 Mdot
.47237 .35284 Mdot
.49725 .56371 Mdot
.36844 .67495 Mdot
.50838 .3504 Mdot
.47 .56887 Mdot
.44926 .35196 Mdot
.81891 .48449 Mdot
.33125 .41718 Mdot
.66048 .57704 Mdot
.5322 .29661 Mdot
.44552 .56862 Mdot
.50498 .59682 Mdot
.2959 .43181 Mdot
.44606 .63586 Mdot
.41444 .81412 Mdot
.52881 .30407 Mdot
.50214 .36145 Mdot
.64885 .59081 Mdot
.43855 .57286 Mdot
.561 .45503 Mdot
.43194 .59151 Mdot
.62232 .72493 Mdot
.44719 .57174 Mdot
.74528 .46698 Mdot
.64597 .58329 Mdot
.65901 .42039 Mdot
.41038 .65186 Mdot
.46034 .60369 Mdot
.27714 .47866 Mdot
.38289 .59571 Mdot
.42511 .66134 Mdot
.6178 .63904 Mdot
.66145 .62248 Mdot
.66254 .60513 Mdot
.42959 .35155 Mdot
.24213 .33785 Mdot
.65809 .40363 Mdot
.53512 .62009 Mdot
.6372 .3843 Mdot
.49179 .80303 Mdot
.32783 .41497 Mdot
.43817 .20172 Mdot
.46654 .6327 Mdot
.65345 .60776 Mdot
.58557 .23414 Mdot
.61912 .63611 Mdot
.54916 .48316 Mdot
.64129 .41155 Mdot
.63919 .62076 Mdot
.46541 .60801 Mdot
.43464 .48274 Mdot
.37076 .21596 Mdot
.66708 .40606 Mdot
.3869 .64079 Mdot
.43907 .32702 Mdot
.34235 .27479 Mdot
.26197 .74824 Mdot
.62171 .41418 Mdot
.59838 .45176 Mdot
.45177 .58861 Mdot
.64389 .62754 Mdot
.63356 .43258 Mdot
.61971 .43018 Mdot
.47999 .37653 Mdot
.48107 .61536 Mdot
.47849 .62016 Mdot
.43448 .37095 Mdot
.66665 .39999 Mdot
.40547 .56989 Mdot
.4901 .66816 Mdot
.35159 .18512 Mdot
.54271 .52439 Mdot
.74224 .24947 Mdot
.50303 .68373 Mdot
.50057 .71451 Mdot
.69886 .27196 Mdot
.61864 .57591 Mdot
.48959 .59692 Mdot
.51856 .61881 Mdot
.47019 .38641 Mdot
.4384 .60714 Mdot
.42441 .32624 Mdot
.64487 .4 Mdot
.24517 .29048 Mdot
.72603 .52544 Mdot
.82243 .4574 Mdot
.43895 .60504 Mdot
.71936 .62611 Mdot
.32694 .44128 Mdot
.65901 .45704 Mdot
.66853 .60576 Mdot
.4813 .64562 Mdot
.22517 .59589 Mdot
.44724 .33076 Mdot
.6077 .61237 Mdot
.20194 .50474 Mdot
.36245 .39844 Mdot
.46667 .6576 Mdot
.4368 .33474 Mdot
.59792 .2281 Mdot
.42078 .53569 Mdot
.6844 .4237 Mdot
.34397 .44853 Mdot
.47376 .33496 Mdot
.66566 .39345 Mdot
.64082 .55323 Mdot
.62956 .61853 Mdot
.58484 .61493 Mdot
.27491 .68163 Mdot
.50473 .34135 Mdot
.32417 .44403 Mdot
.26921 .31739 Mdot
.24569 .37679 Mdot
.34126 .4525 Mdot
.43768 .3843 Mdot
.66132 .62174 Mdot
.64708 .61502 Mdot
.62519 .5916 Mdot
.23224 .65784 Mdot
.61956 .5723 Mdot
.76061 .64144 Mdot
.48772 .64677 Mdot
.35899 .62989 Mdot
.44996 .58365 Mdot
.62239 .45231 Mdot
.65369 .58168 Mdot
.44323 .46491 Mdot
.41008 .66615 Mdot
.36743 .23285 Mdot
.42341 .59277 Mdot
.63575 .46441 Mdot
.42138 .62756 Mdot
.71381 .69036 Mdot
.59757 .59739 Mdot
.44081 .61307 Mdot
.6573 .45321 Mdot
.32445 .42829 Mdot
.65046 .64729 Mdot
.48641 .61341 Mdot
.71776 .35164 Mdot
.4964 .6405 Mdot
.80822 .43391 Mdot
.51358 .52935 Mdot
.33031 .41472 Mdot
.57848 .55313 Mdot
.46799 .31522 Mdot
.36014 .64255 Mdot
.43451 .54616 Mdot
.66704 .41497 Mdot
.53589 .28298 Mdot
.46923 .36277 Mdot
.39147 .45249 Mdot
.52369 .59434 Mdot
.30176 .42947 Mdot
.68422 .62487 Mdot
.6238 .45712 Mdot
.48459 .57466 Mdot
.42656 .68286 Mdot
.77735 .57378 Mdot
.52801 .58855 Mdot
.42355 .58465 Mdot
.30321 .41817 Mdot
.75614 .62974 Mdot
.43003 .61546 Mdot
.55502 .48081 Mdot
.58862 .59152 Mdot
.39983 .57283 Mdot
.75436 .65939 Mdot
.4132 .63862 Mdot
.61726 .61892 Mdot
.67782 .63944 Mdot
.69246 .47694 Mdot
.31998 .47039 Mdot
.45712 .57014 Mdot
.66735 .7711 Mdot
.43763 .64385 Mdot
.65236 .40627 Mdot
.48 .66756 Mdot
.48088 .34656 Mdot
.2223 .62681 Mdot
.48592 .38055 Mdot
.46357 .57524 Mdot
.62245 .59402 Mdot
.67032 .4229 Mdot
.27842 .70527 Mdot
.36054 .29561 Mdot
.74944 .64471 Mdot
.83177 .41466 Mdot
.35172 .45442 Mdot
.30921 .46829 Mdot
.62328 .45829 Mdot
.43932 .61399 Mdot
.75491 .69194 Mdot
.38157 .59527 Mdot
.42377 .61797 Mdot
.45603 .6 Mdot
.31812 .27547 Mdot
.65326 .39441 Mdot
.47809 .37162 Mdot
.41181 .61738 Mdot
.42751 .6611 Mdot
.61781 .57708 Mdot
.3185 .42818 Mdot
.4813 .32937 Mdot
.31256 .44993 Mdot
.46654 .34193 Mdot
.22983 .30076 Mdot
.4274 .67086 Mdot
.3262 .43027 Mdot
.6663 .37478 Mdot
.60095 .60437 Mdot
.69357 .5355 Mdot
.49202 .34548 Mdot
.45895 .38505 Mdot
.41244 .60192 Mdot
.61897 .62051 Mdot
.60403 .62483 Mdot
.33745 .43574 Mdot
.62905 .44265 Mdot
.4885 .60069 Mdot
.50036 .60273 Mdot
.70206 .64812 Mdot
.47677 .39256 Mdot
.61293 .52561 Mdot
.68402 .30357 Mdot
.44057 .61661 Mdot
.60004 .61883 Mdot
.46937 .596 Mdot
.71863 .30295 Mdot
.63411 .6268 Mdot
.41174 .63924 Mdot
.19853 .4377 Mdot
.5273 .36844 Mdot
.70335 .48654 Mdot
.40878 .59497 Mdot
.77797 .33081 Mdot
.4628 .64738 Mdot
.29282 .21452 Mdot
.41171 .29886 Mdot
.48475 .58248 Mdot
.43993 .65974 Mdot
.52444 .77797 Mdot
.47276 .58413 Mdot
.43919 .37745 Mdot
.23037 .4529 Mdot
.59595 .62579 Mdot
.73102 .38129 Mdot
.40886 .73961 Mdot
.34814 .46733 Mdot
.50551 .36179 Mdot
.50724 .31443 Mdot
.33221 .45886 Mdot
.6233 .60142 Mdot
.44428 .62402 Mdot
.49299 .46583 Mdot
.49869 .38392 Mdot
.51027 .67079 Mdot
.65004 .40843 Mdot
.61287 .31217 Mdot
.52964 .32619 Mdot
.652 .42733 Mdot
.47927 .63013 Mdot
.51047 .78072 Mdot
.30384 .68745 Mdot
.67262 .22282 Mdot
.66873 .39413 Mdot
.66933 .40902 Mdot
.21904 .63522 Mdot
.36497 .4448 Mdot
.7921 .55485 Mdot
.75189 .46442 Mdot
.66065 .43776 Mdot
.45633 .52406 Mdot
.43964 .34765 Mdot
.72201 .40042 Mdot
.56038 .62183 Mdot
.5018 .61893 Mdot
.46371 .60672 Mdot
.63333 .44573 Mdot
.54608 .66273 Mdot
.43707 .80745 Mdot
.66307 .42267 Mdot
.53763 .58489 Mdot
.52544 .42988 Mdot
.48805 .25332 Mdot
.44564 .37804 Mdot
.31528 .46717 Mdot
.31327 .48052 Mdot
.63677 .56852 Mdot
.31046 .46463 Mdot
.28039 .36241 Mdot
.4526 .63305 Mdot
.65681 .43242 Mdot
.55894 .28599 Mdot
.6444 .42406 Mdot
.32924 .45806 Mdot
.31908 .4125 Mdot
.61811 .58306 Mdot
.63383 .58728 Mdot
.49916 .72512 Mdot
.26565 .5624 Mdot
.43088 .58851 Mdot
.47499 .22375 Mdot
.59564 .61694 Mdot
.49956 .68063 Mdot
.30335 .45811 Mdot
.32047 .42969 Mdot
.31092 .49756 Mdot
.46744 .62552 Mdot
.62684 .78944 Mdot
.46472 .62282 Mdot
.24824 .54125 Mdot
.39887 .59876 Mdot
.47882 .37685 Mdot
.4718 .62737 Mdot
.25672 .43537 Mdot
.47155 .56627 Mdot
.48105 .6708 Mdot
.49278 .3848 Mdot
.51572 .64 Mdot
.48135 .34862 Mdot
.45222 .57621 Mdot
.35903 .46 Mdot
.49323 .38099 Mdot
.3192 .54168 Mdot
.33428 .49829 Mdot
.43314 .3785 Mdot
.3017 .43817 Mdot
.35441 .46203 Mdot
.33664 .55502 Mdot
.66877 .60631 Mdot
.57323 .62198 Mdot
.43758 .6113 Mdot
.48446 .31957 Mdot
.64741 .3957 Mdot
.42475 .65559 Mdot
.5038 .64276 Mdot
.40034 .61096 Mdot
.64046 .56833 Mdot
.33053 .30694 Mdot
.33223 .43166 Mdot
.43153 .35547 Mdot
.28217 .40567 Mdot
.4562 .39582 Mdot
.46375 .68104 Mdot
.51633 .6025 Mdot
.46951 .72589 Mdot
.55615 .25138 Mdot
.21157 .63951 Mdot
.62592 .61829 Mdot
.49397 .33551 Mdot
.36191 .45311 Mdot
.44392 .6937 Mdot
.65664 .61212 Mdot
.48275 .34545 Mdot
.44009 .62063 Mdot
.38809 .64602 Mdot
.73861 .57455 Mdot
.3928 .71635 Mdot
.35279 .5112 Mdot
.44619 .38354 Mdot
.45726 .3168 Mdot
.25622 .36979 Mdot
.36506 .41288 Mdot
.44032 .47149 Mdot
.43966 .59438 Mdot
.30611 .44393 Mdot
.6602 .62109 Mdot
.29012 .68804 Mdot
.63169 .44913 Mdot
.474 .4964 Mdot
.44019 .6063 Mdot
.4244 .43605 Mdot
.62105 .59306 Mdot
.33643 .4503 Mdot
.63541 .44627 Mdot
.29231 .44426 Mdot
.50969 .3594 Mdot
.84682 .49793 Mdot
.44038 .64109 Mdot
.41828 .59379 Mdot
.68036 .41223 Mdot
.65342 .62078 Mdot
.2947 .44004 Mdot
.79846 .53148 Mdot
.49701 .35925 Mdot
.7416 .70859 Mdot
.61524 .62542 Mdot
.69027 .69913 Mdot
.43354 .35582 Mdot
.61724 .41015 Mdot
.32566 .56167 Mdot
.6473 .43657 Mdot
.45453 .57354 Mdot
.64277 .60153 Mdot
.63114 .40616 Mdot
.4726 .50273 Mdot
.40653 .19047 Mdot
.67057 .72424 Mdot
.45442 .62723 Mdot
.3237 .22231 Mdot
.77784 .40062 Mdot
.69289 .60064 Mdot
.67506 .42472 Mdot
.42307 .59522 Mdot
.48614 .57967 Mdot
.43503 .64243 Mdot
.63396 .41089 Mdot
.43706 .24542 Mdot
.49024 .36193 Mdot
.45097 .58597 Mdot
.31001 .45911 Mdot
.47892 .35527 Mdot
.53527 .30158 Mdot
.45142 .37922 Mdot
.68916 .60338 Mdot
.48208 .66657 Mdot
.63571 .47403 Mdot
.23199 .26902 Mdot
.66403 .40042 Mdot
.43884 .38764 Mdot
.45398 .67172 Mdot
.55594 .2732 Mdot
.66115 .60708 Mdot
.4968 .36347 Mdot
.41555 .60443 Mdot
.52623 .2903 Mdot
.23407 .62693 Mdot
.45126 .37813 Mdot
.65813 .61601 Mdot
.63641 .21597 Mdot
.43336 .60448 Mdot
.45611 .64791 Mdot
.63915 .61694 Mdot
.43126 .76754 Mdot
.1937 .53745 Mdot
.47558 .5969 Mdot
.65845 .42242 Mdot
.82085 .62738 Mdot
.479 .67474 Mdot
.25895 .49776 Mdot
.47403 .33785 Mdot
.71168 .43082 Mdot
.5969 .52405 Mdot
.44112 .69405 Mdot
.79339 .53527 Mdot
.58921 .42314 Mdot
.30835 .25121 Mdot
.42207 .33022 Mdot
.38274 .3865 Mdot
.28347 .25809 Mdot
.64253 .46027 Mdot
.70754 .62506 Mdot
.79145 .4792 Mdot
.3011 .75109 Mdot
.64077 .22631 Mdot
.33767 .36905 Mdot
.22255 .59163 Mdot
.49481 .45347 Mdot
.46097 .34211 Mdot
.28202 .4361 Mdot
.48613 .60758 Mdot
.77597 .39587 Mdot
.64981 .77236 Mdot
.53365 .83117 Mdot
.32902 .21753 Mdot
.5783 .80026 Mdot
.40259 .19923 Mdot
.51781 .17377 Mdot
.48583 .70913 Mdot
.5673 .24649 Mdot
.73939 .71698 Mdot
.21237 .41756 Mdot
.81373 .57102 Mdot
.36458 .6237 Mdot
.55628 .49287 Mdot
.81718 .41924 Mdot
.71095 .67482 Mdot
.437 .79775 Mdot
.48575 .37817 Mdot
.6632 .62946 Mdot
.78547 .46753 Mdot
.66869 .63573 Mdot
.65582 .49636 Mdot
.64273 .21316 Mdot
.42597 .17909 Mdot
.72072 .68665 Mdot
.74563 .28794 Mdot
.54263 .68816 Mdot
.5637 .86577 Mdot
.49529 .3899 Mdot
.66678 .57823 Mdot
.37867 .4622 Mdot
.25282 .36663 Mdot
.76574 .53834 Mdot
.79144 .45166 Mdot
.37932 .25633 Mdot
.29454 .59653 Mdot
.63136 .60251 Mdot
.56928 .54832 Mdot
.69381 .44378 Mdot
.73114 .53065 Mdot
.22636 .4594 Mdot
.55863 .18883 Mdot
.49896 .47449 Mdot
.72393 .36969 Mdot
.62836 .30124 Mdot
.25806 .73998 Mdot
.28377 .50257 Mdot
.45773 .70213 Mdot
.63869 .50292 Mdot
.70784 .28016 Mdot
.33484 .76567 Mdot
.26253 .58197 Mdot
.25074 .36994 Mdot
.2043 .3777 Mdot
.75974 .34533 Mdot
.15404 .48415 Mdot
.57533 .61375 Mdot
.41935 .58756 Mdot
.45056 .75626 Mdot
.68036 .75995 Mdot
.33071 .41136 Mdot
.43423 .22978 Mdot
.33757 .46951 Mdot
.64879 .56236 Mdot
.21603 .5992 Mdot
.75385 .65224 Mdot
.68046 .76526 Mdot
.32451 .48208 Mdot
.50909 .65805 Mdot
.88943 .55963 Mdot
.33819 .23896 Mdot
.6994 .50851 Mdot
.33537 .19272 Mdot
.42072 .45057 Mdot
.47299 .51938 Mdot
.63288 .40572 Mdot
.28224 .25103 Mdot
.64546 .61032 Mdot
.15359 .43601 Mdot
.28153 .22983 Mdot
.3713 .73042 Mdot
.73904 .2029 Mdot
.27118 .3353 Mdot
.43832 .44623 Mdot
.59964 .39535 Mdot
.29902 .53066 Mdot
.40011 .79131 Mdot
.35132 .67703 Mdot
.57458 .2772 Mdot
.82602 .39241 Mdot
.30428 .24497 Mdot
.70834 .7364 Mdot
.83898 .52152 Mdot
.32168 .76899 Mdot
.57128 .46624 Mdot
.56338 .63561 Mdot
.5133 .30833 Mdot
.53987 .19815 Mdot
.21225 .33624 Mdot
.27141 .49822 Mdot
.86773 .40792 Mdot
.33111 .40143 Mdot
.39166 .30203 Mdot
.64033 .20053 Mdot
.30365 .5955 Mdot
.55514 .53983 Mdot
.23304 .43448 Mdot
.48487 .68575 Mdot
.27393 .3972 Mdot
.46947 .21321 Mdot
.66094 .51149 Mdot
.22042 .41403 Mdot
.64071 .24156 Mdot
.77534 .57451 Mdot
.56415 .76329 Mdot
.24088 .37216 Mdot
.62572 .63968 Mdot
.28101 .59024 Mdot
.55096 .53381 Mdot
.41405 .17884 Mdot
.59648 .444 Mdot
.46224 .15679 Mdot
.19743 .5399 Mdot
.39607 .63946 Mdot
.41563 .55203 Mdot
.54886 .58157 Mdot
.27542 .56496 Mdot
.50189 .66036 Mdot
.75331 .56966 Mdot
.47854 .16867 Mdot
.56073 .67185 Mdot
.69346 .45588 Mdot
.52852 .28014 Mdot
.65712 .20776 Mdot
.48446 .74663 Mdot
.3712 .41847 Mdot
.22807 .50972 Mdot
.29897 .76696 Mdot
.4719 .36578 Mdot
.719 .72077 Mdot
.68474 .42439 Mdot
.25159 .64974 Mdot
.58818 .77848 Mdot
.3728 .74891 Mdot
.47997 .16832 Mdot
.34454 .38415 Mdot
.20889 .57083 Mdot
.31584 .6358 Mdot
.78325 .66207 Mdot
.49525 .2511 Mdot
.51861 .5953 Mdot
.76037 .39751 Mdot
.35552 .4413 Mdot
.52653 .741 Mdot
.81253 .61512 Mdot
.3436 .34075 Mdot
.47578 .55982 Mdot
.34061 .72014 Mdot
.5033 .41016 Mdot
.43875 .48345 Mdot
.16743 .6092 Mdot
.45233 .68716 Mdot
.26228 .32542 Mdot
.7717 .36262 Mdot
.28115 .53037 Mdot
.69692 .25199 Mdot
.69046 .28394 Mdot
.16275 .44808 Mdot
.31642 .21212 Mdot
.34935 .30126 Mdot
.27489 .27193 Mdot
.38784 .17818 Mdot
.16345 .47084 Mdot
.44285 .54279 Mdot
.68185 .40803 Mdot
.23417 .74066 Mdot
.43973 .37311 Mdot
.29745 .28624 Mdot
.80067 .5773 Mdot
.54193 .33441 Mdot
.68664 .56672 Mdot
.38697 .69576 Mdot
.50163 .45745 Mdot
.69064 .5936 Mdot
.51234 .64676 Mdot
.17487 .58871 Mdot
.18163 .42305 Mdot
.16463 .53411 Mdot
.77613 .34717 Mdot
.25648 .28626 Mdot
.47573 .43878 Mdot
.72842 .6669 Mdot
.53853 .65491 Mdot
.49237 .63543 Mdot
.38672 .4718 Mdot
.27349 .33231 Mdot
.33813 .72247 Mdot
.76346 .51384 Mdot
.6888 .61834 Mdot
.45025 .22228 Mdot
.60753 .88613 Mdot
.53217 .70699 Mdot
.76725 .6502 Mdot
.25991 .37287 Mdot
.26682 .55144 Mdot
.52407 .20439 Mdot
.37217 .73916 Mdot
.53685 .16985 Mdot
.68634 .58209 Mdot
.81108 .56603 Mdot
.35578 .36243 Mdot
.39554 .52467 Mdot
.33675 .29951 Mdot
.44241 .18416 Mdot
.58126 .37751 Mdot
.31275 .72207 Mdot
.76318 .45463 Mdot
.39691 .76872 Mdot
.42431 .30538 Mdot
.62389 .31469 Mdot
.80383 .62493 Mdot
.64149 .27427 Mdot
.25368 .52352 Mdot
.53146 .43569 Mdot
.59298 .55704 Mdot
.58996 .41933 Mdot
.25833 .52172 Mdot
.38134 .52161 Mdot
.26229 .29833 Mdot
.21676 .25697 Mdot
.21684 .66671 Mdot
.72182 .24535 Mdot
.49518 .21483 Mdot
.47493 .56153 Mdot
.58684 .16922 Mdot
.15327 .52242 Mdot
.26646 .23192 Mdot
.61623 .33845 Mdot
.41929 .33165 Mdot
.62123 .39882 Mdot
.1838 .58403 Mdot
.4236 .2574 Mdot
.57842 .17788 Mdot
.23727 .42551 Mdot
.62432 .39147 Mdot
.41386 .83535 Mdot
.20534 .39123 Mdot
.61763 .76622 Mdot
.39705 .71724 Mdot
.41275 .5715 Mdot
.70067 .71167 Mdot
.67218 .63193 Mdot
.64556 .29223 Mdot
.26841 .57617 Mdot
.46082 .37171 Mdot
.38038 .47964 Mdot
.78607 .43591 Mdot
.49213 .64734 Mdot
.60624 .48179 Mdot
.6824 .61392 Mdot
.56143 .25135 Mdot
.71636 .54564 Mdot
.206 .33538 Mdot
.30722 .30356 Mdot
.3911 .60052 Mdot
.27888 .5247 Mdot
.3278 .30344 Mdot
.19092 .54554 Mdot
.61243 .4531 Mdot
.35285 .20409 Mdot
.53339 .49496 Mdot
.27909 .58829 Mdot
.67909 .73921 Mdot
.64023 .66518 Mdot
.51215 .60977 Mdot
.64889 .26585 Mdot
.61279 .71688 Mdot
.4544 .49122 Mdot
.5554 .62787 Mdot
.58325 .64241 Mdot
.6044 .16979 Mdot
.28136 .37054 Mdot
.61471 .30337 Mdot
.3806 .19319 Mdot
.63572 .41987 Mdot
.5963 .6079 Mdot
.29632 .47416 Mdot
.80736 .51379 Mdot
.64367 .70067 Mdot
.23435 .62827 Mdot
.53772 .331 Mdot
.35664 .33107 Mdot
.38785 .1958 Mdot
.34512 .21318 Mdot
.59727 .82115 Mdot
.67661 .63756 Mdot
.5053 .6943 Mdot
.80758 .53617 Mdot
.65336 .63438 Mdot
.76139 .58995 Mdot
.75174 .58681 Mdot
.2281 .3198 Mdot
.63071 .48448 Mdot
.81509 .37485 Mdot
.34661 .51923 Mdot
.4221 .24111 Mdot
.2746 .70351 Mdot
.7971 .63192 Mdot
.41475 .19694 Mdot
.44314 .52963 Mdot
.54093 .78746 Mdot
.36414 .63535 Mdot
.6628 .54312 Mdot
.32087 .79926 Mdot
.30496 .48463 Mdot
.69304 .69953 Mdot
.64411 .24069 Mdot
.44182 .63101 Mdot
.22019 .67948 Mdot
.80304 .485 Mdot
.21829 .63862 Mdot
.6435 .37788 Mdot
.47831 .63994 Mdot
.48324 .57041 Mdot
.24391 .49098 Mdot
.69427 .47741 Mdot
.24987 .32084 Mdot
.83016 .59635 Mdot
.59929 .22276 Mdot
.64849 .77266 Mdot
.27377 .31711 Mdot
.57782 .18533 Mdot
.77136 .38706 Mdot
.5479 .45989 Mdot
.28084 .3269 Mdot
.31162 .58433 Mdot
.7472 .29395 Mdot
.39278 .50209 Mdot
.67771 .36697 Mdot
.77228 .54837 Mdot
.68961 .3033 Mdot
.2868 .69581 Mdot
.46436 .65403 Mdot
.20202 .50441 Mdot
.53516 .17886 Mdot
.61691 .80595 Mdot
.38343 .79795 Mdot
.20465 .65179 Mdot
.61495 .73935 Mdot
.68771 .29371 Mdot
.77254 .39933 Mdot
.78158 .68994 Mdot
.53838 .49952 Mdot
.39163 .22171 Mdot
.31041 .60309 Mdot
.38553 .19439 Mdot
.67923 .42251 Mdot
.76122 .47637 Mdot
.52296 .27625 Mdot
.265 .28727 Mdot
.49348 .76034 Mdot
.46893 .1805 Mdot
.43978 .45429 Mdot
.16449 .43266 Mdot
.61746 .25901 Mdot
.49463 .44685 Mdot
.50149 .345 Mdot
.32549 .38149 Mdot
.45834 .20723 Mdot
.53311 .23559 Mdot
.78942 .637 Mdot
.43028 .32944 Mdot
.2856 .45607 Mdot
.62383 .77316 Mdot
.30152 .64308 Mdot
.66096 .26922 Mdot
.2792 .52508 Mdot
.45483 .17349 Mdot
.23727 .45587 Mdot
.20395 .51369 Mdot
.29575 .30164 Mdot
.85301 .45258 Mdot
.69809 .50411 Mdot
.26712 .38461 Mdot
.79932 .46815 Mdot
.4043 .29318 Mdot
.47081 .52523 Mdot
.06278 .48744 Mdot
.84128 .47995 Mdot
.59024 .25128 Mdot
.21266 .33619 Mdot
.71736 .29289 Mdot
.56217 .25444 Mdot
.3909 .78181 Mdot
.5451 .52355 Mdot
.22822 .57224 Mdot
.45597 .60086 Mdot
.16399 .57317 Mdot
.28738 .62024 Mdot
.19567 .36416 Mdot
.60281 .17703 Mdot
.69087 .71951 Mdot
.49212 .65377 Mdot
.43241 .34511 Mdot
.64369 .49575 Mdot
.28713 .64846 Mdot
.47745 .779 Mdot
.53854 .54633 Mdot
.50557 .27606 Mdot
.50797 .34817 Mdot
.31323 .32079 Mdot
.64696 .55769 Mdot
.42008 .25372 Mdot
.68178 .29964 Mdot
.52051 .38257 Mdot
.50001 .48213 Mdot
.26282 .53162 Mdot
.59388 .52673 Mdot
.62328 .76146 Mdot
.36168 .73616 Mdot
.57918 .45543 Mdot
.45194 .38171 Mdot
.59683 .76816 Mdot
.82491 .43037 Mdot
.60543 .23147 Mdot
.20372 .37281 Mdot
.2959 .39386 Mdot
.50711 .79602 Mdot
.25355 .51431 Mdot
.41203 .79904 Mdot
.49384 .81313 Mdot
.51645 .24828 Mdot
.63955 .54978 Mdot
.43468 .78972 Mdot
.76479 .41611 Mdot
.2472 .28652 Mdot
.81311 .5702 Mdot
.8097 .54415 Mdot
.46088 .28235 Mdot
.68685 .68099 Mdot
.66208 .74954 Mdot
.32617 .53828 Mdot
.44184 .47625 Mdot
.52776 .87013 Mdot
.56462 .62586 Mdot
.40199 .86853 Mdot
.62106 .40975 Mdot
.33483 .78365 Mdot
.31659 .58786 Mdot
.5356 .43077 Mdot
.41179 .4617 Mdot
.65689 .2767 Mdot
.74687 .47021 Mdot
.78534 .37281 Mdot
.50004 .82382 Mdot
.47607 .39556 Mdot
.83609 .59001 Mdot
.85659 .45268 Mdot
.54978 .77626 Mdot
.46008 .67826 Mdot
.84441 .4647 Mdot
.41474 .34473 Mdot
.33951 .72472 Mdot
.69722 .24934 Mdot
.53965 .22695 Mdot
.42768 .54114 Mdot
.26871 .55873 Mdot
.39431 .21888 Mdot
.34891 .19855 Mdot
.41677 .82618 Mdot
.47151 .21373 Mdot
.68052 .41616 Mdot
.47628 .44473 Mdot
.47795 .1876 Mdot
.46634 .51372 Mdot
.72581 .40702 Mdot
.53756 .53802 Mdot
.48377 .8902 Mdot
.30485 .27451 Mdot
.25256 .31863 Mdot
.514 .53103 Mdot
.60695 .57856 Mdot
.68713 .4773 Mdot
.55802 .53926 Mdot
.55574 .22983 Mdot
.81369 .43582 Mdot
.55543 .53634 Mdot
.70919 .77059 Mdot
.63028 .66642 Mdot
.46481 .42629 Mdot
.64694 .76641 Mdot
.5555 .67005 Mdot
.64329 .37703 Mdot
.2142 .49616 Mdot
.62704 .22666 Mdot
.67924 .39261 Mdot
.65531 .26409 Mdot
.72054 .36705 Mdot
.70619 .65566 Mdot
.65041 .70664 Mdot
.56874 .21663 Mdot
.49981 .77502 Mdot
.71829 .60141 Mdot
.28497 .68065 Mdot
.43607 .38859 Mdot
.62579 .22044 Mdot
.50022 .35294 Mdot
.48386 .68898 Mdot
.47472 .499 Mdot
.36038 .68626 Mdot
.20404 .6276 Mdot
.35302 .45306 Mdot
.67712 .60735 Mdot
.35826 .80983 Mdot
.63522 .63221 Mdot
.17093 .572 Mdot
.37401 .74692 Mdot
.68173 .7379 Mdot
.34861 .30778 Mdot
.32492 .3444 Mdot
.62289 .83401 Mdot
.60483 .47587 Mdot
.51632 .30666 Mdot
.70602 .56004 Mdot
.67192 .58431 Mdot
.31155 .29612 Mdot
.4857 .38761 Mdot
.54391 .51369 Mdot
.57982 .37356 Mdot
.6782 .65 Mdot
.70348 .58587 Mdot
.5188 .49891 Mdot
.23563 .56091 Mdot
.24112 .30967 Mdot
.45181 .34355 Mdot
.42444 .86413 Mdot
.50422 .63521 Mdot
.55768 .75883 Mdot
.53554 .16737 Mdot
.4244 .83779 Mdot
.51459 .31576 Mdot
.86034 .45238 Mdot
.39319 .6071 Mdot
.53681 .20738 Mdot
.63693 .60779 Mdot
.80944 .55325 Mdot
.34793 .46148 Mdot
.2868 .5308 Mdot
.62635 .3952 Mdot
.31028 .72177 Mdot
.53467 .38372 Mdot
.58788 .61751 Mdot
.50325 .22448 Mdot
.51266 .69147 Mdot
.74525 .44061 Mdot
.31397 .33676 Mdot
.55618 .77799 Mdot
.65422 .70043 Mdot
.70514 .59659 Mdot
.26277 .30555 Mdot
.81548 .54921 Mdot
.21748 .30474 Mdot
.55421 .59774 Mdot
.37408 .40245 Mdot
.76695 .56715 Mdot
.6236 .24466 Mdot
.64783 .53562 Mdot
.50642 .16415 Mdot
.27024 .59083 Mdot
.69376 .64866 Mdot
.25095 .53881 Mdot
.3808 .64786 Mdot
.52598 .46613 Mdot
.64979 .30538 Mdot
.52761 .8337 Mdot
.62306 .51879 Mdot
.35074 .77853 Mdot
.64388 .54457 Mdot
.24679 .34079 Mdot
.6165 .55717 Mdot
.51038 .33286 Mdot
.69446 .68339 Mdot
.60544 .46855 Mdot
.26078 .27262 Mdot
.51593 .16452 Mdot
.62163 .46804 Mdot
.35342 .27151 Mdot
.69852 .26575 Mdot
.39838 .67278 Mdot
.4443 .43654 Mdot
.4283 .58133 Mdot
.52845 .66809 Mdot
.43831 .84812 Mdot
.58215 .2329 Mdot
.50803 .57045 Mdot
.30323 .25239 Mdot
.29556 .24482 Mdot
.17986 .40343 Mdot
.75854 .69167 Mdot
.62893 .57403 Mdot
.16704 .4941 Mdot
.5397 .54939 Mdot
.37412 .18229 Mdot
.51914 .24419 Mdot
.58619 .15974 Mdot
.53545 .78469 Mdot
.66898 .26196 Mdot
.41254 .78198 Mdot
.72486 .46381 Mdot
.74912 .33992 Mdot
.5289 .41739 Mdot
.59755 .29871 Mdot
.7314 .31103 Mdot
.8002 .69273 Mdot
.41752 .6948 Mdot
.72089 .36019 Mdot
.77517 .45108 Mdot
.61578 .21573 Mdot
.4079 .31175 Mdot
.47924 .66772 Mdot
.55151 .28702 Mdot
.24755 .67057 Mdot
.26697 .5186 Mdot
.28078 .44509 Mdot
.40968 .30847 Mdot
.25576 .6309 Mdot
.24525 .54986 Mdot
.81497 .56939 Mdot
.55105 .78231 Mdot
.57293 .51175 Mdot
.41203 .65085 Mdot
.67559 .56185 Mdot
.32809 .47653 Mdot
.54674 .39611 Mdot
.44379 .57822 Mdot
.49163 .32186 Mdot
.74184 .44905 Mdot
.1948 .62817 Mdot
.66976 .50544 Mdot
.80403 .45867 Mdot
.59205 .57785 Mdot
.71732 .37373 Mdot
.67728 .53757 Mdot
.25966 .70431 Mdot
.38308 .35498 Mdot
.27167 .49822 Mdot
.34694 .22887 Mdot
.22181 .41147 Mdot
.71276 .64815 Mdot
.1933 .44205 Mdot
.6657 .44033 Mdot
.51193 .56225 Mdot
.7784 .47917 Mdot
.30041 .32907 Mdot
.55577 .62142 Mdot
.6664 .26141 Mdot
.52179 .31465 Mdot
.25099 .39062 Mdot
.76823 .35259 Mdot
.54929 .66613 Mdot
.59168 .78735 Mdot
.3341 .21985 Mdot
.44398 .3361 Mdot
.82489 .51892 Mdot
.72924 .39227 Mdot
.37722 .37919 Mdot
.23288 .34645 Mdot
.22153 .31642 Mdot
.43391 .46322 Mdot
.30269 .57355 Mdot
.44527 .65099 Mdot
.80527 .61176 Mdot
.60523 .24173 Mdot
.36609 .68071 Mdot
.60413 .33593 Mdot
.60365 .61864 Mdot
.65201 .32461 Mdot
.56183 .49833 Mdot
.23982 .59705 Mdot
.67526 .63211 Mdot
.64734 .77703 Mdot
.35696 .4639 Mdot
.40774 .43208 Mdot
.51349 .64844 Mdot
.30244 .55391 Mdot
.70032 .75207 Mdot
.5408 .61588 Mdot
.49285 .20592 Mdot
.57755 .77778 Mdot
.79985 .53534 Mdot
.55473 .217 Mdot
.51596 .25149 Mdot
.74233 .46939 Mdot
.68213 .69707 Mdot
.56183 .37898 Mdot
.40237 .60624 Mdot
.51192 .3295 Mdot
.61656 .63324 Mdot
.6577 .22419 Mdot
.61918 .73061 Mdot
.31833 .54489 Mdot
.5605 .41894 Mdot
.48025 .69241 Mdot
.58128 .40184 Mdot
.56857 .16143 Mdot
.72433 .46582 Mdot
.26659 .5773 Mdot
.6292 .48469 Mdot
.31706 .58168 Mdot
.37265 .75357 Mdot
.27389 .24041 Mdot
.40181 .78259 Mdot
.48171 .46985 Mdot
.3606 .78994 Mdot
.64902 .27846 Mdot
.70447 .2574 Mdot
.25655 .56899 Mdot
.40456 .44061 Mdot
.32174 .4068 Mdot
.73716 .58258 Mdot
.56901 .44932 Mdot
.27341 .43203 Mdot
.55853 .51787 Mdot
.57507 .3492 Mdot
.7041 .40139 Mdot
.38447 .69212 Mdot
.30733 .28188 Mdot
.34121 .22482 Mdot
.8051 .56377 Mdot
.58696 .4237 Mdot
.39114 .39263 Mdot
.25184 .61094 Mdot
.63621 .16674 Mdot
.27692 .76591 Mdot
.44394 .64981 Mdot
.58477 .44268 Mdot
.29229 .57211 Mdot
.44638 .385 Mdot
.58461 .53502 Mdot
.67193 .53134 Mdot
.63347 .39654 Mdot
.2885 .46685 Mdot
.2476 .40005 Mdot
.66425 .28765 Mdot
.31136 .65522 Mdot
.53303 .29389 Mdot
.19442 .63392 Mdot
.8197 .40619 Mdot
.61173 .24077 Mdot
.5809 .1425 Mdot
.70464 .37508 Mdot
.61797 .64995 Mdot
.44895 .74894 Mdot
.24253 .31202 Mdot
.28411 .51717 Mdot
.26975 .67302 Mdot
.51313 .25927 Mdot
.26403 .58323 Mdot
.50088 .5352 Mdot
.28254 .31116 Mdot
.64302 .32642 Mdot
.51822 .45183 Mdot
.32669 .34673 Mdot
.19878 .41269 Mdot
.59921 .79197 Mdot
.37103 .21874 Mdot
.25764 .68646 Mdot
.75991 .72183 Mdot
.27645 .25394 Mdot
.34748 .4951 Mdot
.39502 .3443 Mdot
.45478 .75421 Mdot
.38888 .51162 Mdot
.45012 .52459 Mdot
.33255 .72072 Mdot
.63188 .69619 Mdot
.38235 .27471 Mdot
.31301 .75312 Mdot
.25408 .52297 Mdot
.57333 .66706 Mdot
.40534 .44448 Mdot
.61723 .76069 Mdot
.34922 .2766 Mdot
.49077 .51976 Mdot
.40666 .49839 Mdot
.31847 .51525 Mdot
.58498 .77206 Mdot
.77793 .56406 Mdot
.70416 .29019 Mdot
.72257 .7702 Mdot
.46791 .23048 Mdot
.27018 .71671 Mdot
.48634 .64963 Mdot
.19183 .33626 Mdot
.71225 .31339 Mdot
.49661 .24669 Mdot
.7947 .40282 Mdot
.44422 .42338 Mdot
.64129 .65771 Mdot
.40217 .60697 Mdot
.44901 .21366 Mdot
.68942 .70471 Mdot
.51718 .6999 Mdot
.30191 .72171 Mdot
.2774 .54132 Mdot
.24154 .43551 Mdot
.33446 .53169 Mdot
.54232 .58785 Mdot
.64238 .63059 Mdot
.16274 .52339 Mdot
.4596 .46302 Mdot
.47234 .69323 Mdot
.35774 .64882 Mdot
.40068 .76884 Mdot
.83496 .3956 Mdot
.55121 .58395 Mdot
.2275 .39723 Mdot
.5605 .80257 Mdot
.38131 .56149 Mdot
.61747 .54235 Mdot
.61068 .11694 Mdot
.25509 .22849 Mdot
.5913 .62221 Mdot
.76044 .65899 Mdot
.5696 .80222 Mdot
.25935 .29945 Mdot
.36012 .36053 Mdot
.59258 .35655 Mdot
.34941 .64015 Mdot
.41353 .51428 Mdot
.52656 .61626 Mdot
.77595 .37468 Mdot
.28461 .23179 Mdot
.30678 .7329 Mdot
.30582 .24992 Mdot
.38686 .5748 Mdot
.53151 .60707 Mdot
.66921 .17562 Mdot
.46653 .18926 Mdot
.42139 .68453 Mdot
.43037 .79853 Mdot
.56284 .63471 Mdot
.48141 .60426 Mdot
.39641 .23703 Mdot
.83591 .58652 Mdot
.25209 .51806 Mdot
.26463 .28811 Mdot
.66905 .63806 Mdot
.5259 .34575 Mdot
.622 .4058 Mdot
.42048 .46621 Mdot
.39294 .65017 Mdot
.62935 .41189 Mdot
.37434 .71698 Mdot
.6638 .25252 Mdot
.65013 .48847 Mdot
.82897 .55296 Mdot
.49308 .14848 Mdot
.62695 .73745 Mdot
.73072 .57323 Mdot
.44072 .69267 Mdot
.57331 .66531 Mdot
.27918 .64635 Mdot
.54899 .65411 Mdot
.72141 .2868 Mdot
.09824 .47474 Mdot
.58592 .30539 Mdot
.2195 .53799 Mdot
.64306 .5597 Mdot
.58651 .51593 Mdot
.64277 .75453 Mdot
.40369 .39602 Mdot
.46251 .33096 Mdot
.37945 .59347 Mdot
.54992 .59431 Mdot
.65689 .37853 Mdot
.3793 .84942 Mdot
.46814 .66988 Mdot
.606 .53249 Mdot
.37632 .1829 Mdot
.28429 .68031 Mdot
.53243 .75705 Mdot
.4101 .58278 Mdot
.73623 .5356 Mdot
.40407 .4379 Mdot
.58117 .19986 Mdot
.2051 .50654 Mdot
.3114 .25471 Mdot
.61981 .72777 Mdot
.58396 .79189 Mdot
.42532 .65992 Mdot
.35776 .42813 Mdot
.71651 .42898 Mdot
.4201 .23174 Mdot
.42717 .55016 Mdot
.33437 .20162 Mdot
.4728 .42786 Mdot
.54501 .37397 Mdot
.52628 .56706 Mdot
.17514 .41951 Mdot
.3491 .76374 Mdot
.67312 .73312 Mdot
.24463 .69037 Mdot
.29643 .34964 Mdot
.30057 .63975 Mdot
.43609 .3389 Mdot
.41829 .55335 Mdot
.65301 .64179 Mdot
.19855 .65429 Mdot
.38493 .2353 Mdot
.57831 .28741 Mdot
.62001 .31546 Mdot
.77847 .62579 Mdot
.74649 .42616 Mdot
.55135 .13728 Mdot
.30785 .35016 Mdot
.20107 .65138 Mdot
.81476 .53694 Mdot
.56442 .60448 Mdot
.67196 .27612 Mdot
.52884 .58387 Mdot
.44929 .36448 Mdot
.29902 .26416 Mdot
.51804 .65643 Mdot
.21878 .60096 Mdot
.44784 .56257 Mdot
.20859 .61593 Mdot
.27143 .45689 Mdot
.34317 .27075 Mdot
.61262 .26166 Mdot
.38264 .77054 Mdot
.62844 .20139 Mdot
.74001 .58538 Mdot
.62238 .1721 Mdot
.63494 .21136 Mdot
.34675 .20683 Mdot
.24171 .64697 Mdot
.45566 .83744 Mdot
.53512 .2386 Mdot
.57516 .21997 Mdot
.66543 .30209 Mdot
.43625 .7645 Mdot
.32916 .38049 Mdot
.54387 .57758 Mdot
.70383 .47492 Mdot
.63371 .46938 Mdot
.14705 .67339 Mdot
.25256 .44533 Mdot
.58372 .62337 Mdot
.30537 .37234 Mdot
.30997 .23066 Mdot
.41988 .76255 Mdot
.74218 .32219 Mdot
.55383 .49221 Mdot
.5192 .59978 Mdot
.63799 .70938 Mdot
.79343 .59668 Mdot
.32237 .38538 Mdot
.63274 .8389 Mdot
.81901 .41698 Mdot
.59309 .32768 Mdot
.52265 .47376 Mdot
.65962 .63419 Mdot
.69923 .56747 Mdot
.33644 .33084 Mdot
.73662 .29862 Mdot
.66714 .25856 Mdot
.47578 .18756 Mdot
.62488 .83173 Mdot
.80348 .53811 Mdot
.2413 .31175 Mdot
.62285 .25626 Mdot
.58255 .60757 Mdot
.36878 .4884 Mdot
.42237 .38107 Mdot
.58683 .28099 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0<?ooooo0_l00024ooooo`007?ooool00ol0003ooooooooo
o`33ooooo`;o0000Q?ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2_ooooo`;o0000V?oo
ool001cooooo00?o0000ooooooooool0ZOooool2o`0000Cooooo0_l0002Hooooo`007?ooool00ol0
003oooooooooo`2Yooooo`;o00003_ooool2o`0008kooooo000Looooo`03o`000?oooooooooo0;Wo
oooo0_l0002>ooooo`007?ooool00ol0003oooooooooo`2Looooo`;o0000Zoooool001cooooo0_l0
002Mooooo`;o0000Zoooool001cooooo00?o0000ooooooooool0T_ooool2o`000;Gooooo000Loooo
o`03o`000?oooooooooo09;ooooo0_l0000Wooooo`;o0000S?ooool001cooooo00?o0000oooooooo
ool0POooool2o`0003;ooooo0_l00004ooooo`;o0000S?ooool001cooooo00?o0000ooooooooool0
POooool2o`0001kooooo0_l000000ooooooo0000o`000002o`0000[ooooo0_l000000ooooooo0000
o`00002Booooo`007?ooool00ol0003oooooooooo`2Booooo`;o00001?ooool2o`0000Oooooo0_l0
00000ooooooo0000o`000002o`000005ooooool0003o0000o`000?ooool00_l00003ooooo`;o0000
00Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000002o`0000cooooo0_l0001looooo`00
7?ooool00ol0003oooooooooo`2?ooooo`;o000000?oooooo`000?l000000_l00002ooooo`?o0000
0_ooool2o`0000[ooooo1_l00006ooooo`;o000000?oooooo`000?l000001_l000000ooooooo0000
o`000003ooooo`;o00000oooool2o`0007cooooo000Looooo`03o`000?oooooooooo08oooooo1?l0
00000ooooooo0000o`000003ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo0_l0
0005ooooo`;o00000oooool2o`0000Sooooo0_l00002ooooo`;o000000?oooooo`000?l000000ooo
ool2o`00087ooooo000Looooo`03o`000?oooooooooo07[ooooo0_l0000Dooooo`?o00001_ooool2
o`0000Gooooo0_l00002ooooo`;o00002_ooool2o`0000Kooooo0_l00002ooooo`;o00000_ooool2
o`0001Cooooo0_l0001aooooo`007?ooool00ol0003oooooooooo`1gooooo`;o000000?oooooo`00
0?l000000_l00005ooooo`;o00000_ooool2o`0000?ooooo0_l00007ooooo`Ko00001Oooool2o`00
00Oooooo1?l0000;ooooo`;o00000_ooool2o`0000;ooooo0_l0000Dooooo`;o0000LOooool001co
oooo00?o0000ooooooooool0M_ooool3o`0000?ooooo0_l00005ooooo`?o000000?oooooo`000?l0
00000oooool2o`0000Oooooo1?l0000@ooooo`Co00003Oooool2o`0008gooooo000Looooo`03o`00
0?oooooooooo06kooooo0_l00006ooooo`?o00002oooool4o`0000?ooooo0ol00009ooooo`;o0000
4Oooool2o`0000Wooooo0_l000000ooooooo0000o`000002o`0008gooooo000Looooo`03o`000?oo
oooooooo06kooooo0_l0000@ooooo`;o00001?ooool2o`0000?ooooo0_l00007ooooo`;o000000?o
ooooo`000?l000004Oooool2o`0000Kooooo0_l000001?oooooo0000o`000?ooool2o`0000Wooooo
0_l00024ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Ko
oooo00?o0000ooooooooool0JOooool2o`0000gooooo0_l00005ooooo`Go00004?ooool2o`0001[o
oooo1?l0000?ooooo`;o0000Q?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q
8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo06Wooooo0_l0000:
ooooo`;o000000?oooooo`000?l000000_l00003ooooo`Ko0000:oooool2o`0009Oooooo00000ooo
oooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0
003oooooooooo`1^ooooo`;o00001Oooool2o`0000;ooooo0ol00002ooooo`Oo00009oooool2o`00
00_ooooo0_l0002>ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03
oiRHV?lQ8B7ok^k^00Kooooo0ol0001Yooooo`;o00000oooool2o`0000gooooo1?l0000:ooooo`;o
00007oooool4o`0000Wooooo0_l0000=ooooo`;o00000_ooool2o`0001kooooo0_l0001Kooooo`00
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00Gooooo
00?o0000ooooooooool0JOooool2o`0000Cooooo0_l0000<ooooo`;o000000?oooooo`000?l00000
2Oooool2o`0000;ooooo0_l0000;ooooo`;o00000_ooool3o`0000?ooooo0_l00006ooooo`;o0000
6?ooool2o`0000;ooooo0_l0000Nooooo`;o0000Foooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06gooooo1?l0
000?ooooo`;o00000_ooool2o`0000Wooooo1?l00009ooooo`;o00000_ooool3o`0000?ooooo0_l0
0003ooooo`;o00009Oooool2o`0007Gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo
00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo05kooooo0ol00002ooooo`;o
00002?ooool2o`0000gooooo0_l00006ooooo`;o00002oooool2o`0001Sooooo0_l00006ooooo`;o
00005Oooool2o`0000Gooooo0ol0001eooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Kooooo`;o000000Cooooo
o`000?l0003o00000_ooool2o`0000Oooooo0_l0000>ooooo`;o00004?ooool2o`0000;ooooo0_l0
00000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000003?ooool2o`0000Gooooo0ol0
0003ooooo`;o00004?ooool2o`000003ooooool0003o000000;ooooo0_l0001fooooo`007?ooool0
0ol0003oooooooooo`1Jooooo`?o00002_ooool2o`0000?ooooo0_l00007ooooo`;o00005oooool2
o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000003?ooool2
o`0000?ooooo1?l000001?oooooo0000o`000?ooool2o`0000[ooooo0_l00005ooooo`Co00001Ooo
ool2o`0000Cooooo0_l0001]ooooo`007?ooool00ol0003oooooooooo`1Iooooo`?o00002oooool4
o`0000[ooooo0_l00005ooooo`;o0000<_ooool2o`0000?ooooo1?l0000;ooooo`;o000000Gooooo
o`000?l0003o0000ooooo`02o`0000Oooooo1?l00002ooooo`;o0000KOooool001cooooo00?o0000
ooooooooool0F?ooool3o`0000[ooooo0_l00002ooooo`;o00002_ooool2o`0000Cooooo0ol0000A
ooooo`;o00000oooool5o`0000Oooooo0_l000000ooooooo0000o`00000Booooo`;o00001_ooool2
o`0000Kooooo0ol00008ooooo`Oo0000L?ooool001cooooo00?o0000ooooooooool0F?ooool2o`00
00[ooooo0ol00004ooooo`;o00003_ooool2o`0000Sooooo0_l00008ooooo`;o00000oooool5o`00
00Oooooo0_l000000ooooooo0000o`000007ooooo`;o00001?ooool2o`0000?ooooo0_l00006oooo
o`;o00001oooool2o`0000;ooooo0_l00004ooooo`Co000000?oooooo`000?l00000L?ooool001co
oooo00?o0000ooooooooool0Coooool2o`0000Oooooo0_l00007ooooo`;o000000?oooooo`000?l0
00001Oooool4o`0001Kooooo0_l00002ooooo`;o00002Oooool2o`0001Kooooo0_l00003ooooo`?o
00000oooool2o`0000Gooooo0_l00008ooooo`;o00000_ooool2o`0007_ooooo000Looooo`03o`00
0?oooooooooo04oooooo0_l00002ooooo`;o00000oooool3o`0000Kooooo0_l0000:ooooo`;o0000
1Oooool2o`0000oooooo0_l00002ooooo`;o00000_ooool2o`0000Gooooo0_l00005ooooo`;o0000
5?ooool2o`0000Kooooo0_l00003ooooo`;o000000?oooooo`000?l000004Oooool2o`0000cooooo
0_l0001Uooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00001?ooool2o`0000cooooo0_l0
000;ooooo`;o00000oooool2o`0000[ooooo0_l00006ooooo`;o00003?ooool2o`0000cooooo0_l0
000>ooooo`?o00001Oooool2o`00017ooooo0_l0000<ooooo`;o0000IOooool001cooooo00?o0000
ooooooooool0Ioooool2o`000003ooooool0003o000000gooooo0_l000001?oooooo0000o`000?l0
0003ooooo`Co00000oooool2o`0000Kooooo0_l00005ooooo`;o00003oooool3o`0000kooooo0_l0
000<ooooo`?o00004?ooool2o`0006cooooo000Looooo`03o`000?oooooooooo053ooooo0_l00003
ooooo`;o00004oooool4o`0000_ooooo0_l000001?oooooo0000o`000?l00003ooooo`Go00000_oo
ool7o`000003ooooool0003o000000Gooooo0_l0000>ooooo`Co00005Oooool4o`0000?ooooo0ol0
00001?oooooo0000o`000?l0000<ooooo`;o00002Oooool2o`00067ooooo000Looooo`03o`000?oo
oooooooo053ooooo0_l00003ooooo`;o00001Oooool2o`000003ooooool0003o000000_ooooo0_l0
0008ooooo`;o000000?oooooo`000?l000002_ooool2o`0000;ooooo1ol00002ooooo`;o000000?o
ooooo`000?l000000oooool2o`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l000001?oo
ool2o`00017ooooo1?l00002ooooo`;o00000oooool3o`0000cooooo0_l00009ooooo`?o0000H?oo
ool001cooooo00?o0000ooooooooool0F_ooool4o`000003ooooool0003o000000_ooooo0_l00000
0ooooooo0000o`000005ooooo`;o00001Oooool2o`0000;ooooo0_l000000ooooooo0000o`000003
ooooo`?o00001_ooool2o`000003ooooool0003o000000?ooooo0_l00002ooooo`Go000000Cooooo
o`000?l0003o00001oooool2o`0000Gooooo0_l0000=ooooo`;o000000?oooooo`000?l000001Ooo
ool2o`0001Oooooo1?l0001Nooooo`007?ooool2o`0005Wooooo1?l00003ooooo`?o00002_ooool2
o`000003ooooool0003o000000;o00002_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002
ooooo`;o00002oooool2o`0000Kooooo0ol000001?oooooo0000o`000?ooool2o`0000Wooooo2?l0
0005ooooo`;o00001_ooool2o`0000Sooooo0_l00003ooooo`;o00002_ooool2o`0000Sooooo0_l0
0002ooooo`;o0000F_ooool001cooooo00?o0000ooooooooool0E_ooool4o`0000Gooooo1?l00002
ooooo`;o00002?ooool4o`0001;ooooo0_l000000ooooooo0000o`000002o`0000oooooo1?l00002
ooooo`;o000000?oooooo`000?l000001_ooool2o`000003ooooool0003o000000Co00001oooool3
o`0001Cooooo0ol00009ooooo`;o00003?ooool2o`0005[ooooo000Looooo`03o`000?oooooooooo
04?ooooo0_l0000Aooooo`Co00001Oooool4o`0000;ooooo0_l00003ooooo`;o00000oooool2o`00
00Kooooo0_l00002ooooo`;o00002?ooool4o`000003ooooool0003o000000[ooooo0_l00003oooo
o`Co00000_ooool2o`0000Wooooo0_l00005ooooo`;o00002?ooool2o`0000Kooooo1?l0000;oooo
o`?o00002_ooool2o`0006Kooooo000Looooo`03o`000?oooooooooo04?ooooo0_l0000Cooooo`;o
00003oooool3o`000003ooooool0003o000000Sooooo0_l00002ooooo`;o00002Oooool3o`0000go
oooo0_l00005ooooo`Go000000?oooooo`000?l000000_l0000Iooooo`;o00000oooool4o`0000co
oooo0_l0000:ooooo`;o00000oooool2o`00067ooooo000Looooo`03o`000?oooooooooo05Kooooo
0_l00005ooooo`;o000000?oooooo`000?l000001oooool6o`00033ooooo0ol000000ooooooo0000
o`000002o`0001Wooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00006ooooo`;o0000
0_ooool3o`0000[ooooo0_l00002ooooo`?o00002Oooool2o`0005Gooooo000Looooo`03o`000?oo
oooooooo05Kooooo0_l00005ooooo`;o000000?oooooo`000?l000002Oooool2o`0002Kooooo0_l0
0002ooooo`;o00001oooool3o`0000cooooo0_l0000Booooo`;o00001?ooool2o`0000;ooooo1_l0
0003ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o000000Coooooo`000?l0003ooooo
1?l00009ooooo`;o000000?oooooo`000?l00000D_ooool001cooooo00?o0000ooooooooool0B?oo
ool2o`0000Kooooo0_l00002ooooo`;o00005_ooool2o`0002Gooooo0_l00002ooooo`;o00002?oo
ool2o`0000cooooo0_l0000>ooooo`;o00003?ooool4o`0000;ooooo0_l00004ooooo`Co00000_oo
ool2o`0000;ooooo1?l0000>ooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0B?ooool2
o`0000Kooooo0ol000000ooooooo0000o`000002o`0001Cooooo0_l000001?oooooo0000o`000?oo
ool2o`0000Cooooo0ol00005ooooo`;o00005Oooool2o`0000Wooooo0ol0000<ooooo`;o000000?o
ooooo`000?l000002Oooool2o`0000_ooooo0_l00005ooooo`;o00002_ooool2o`0000;ooooo0_l0
0002ooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0DOooool2o`0000?ooooo0_l00007
ooooo`;o00000oooool2o`0000Gooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00000ooo
ool4o`0000Gooooo0ol00009ooooo`;o00002Oooool2o`000003ooooool0003o000000Cooooo2?l0
0009ooooo`Go00002Oooool2o`0000_ooooo0ol00003ooooo`Ko00001oooool6o`0000;ooooo0ol0
001Oooooo`007?ooool00ol0003oooooooooo`1Oooooo`;o00000oooool2o`0000Gooooo0_l00000
0ooooooo0000o`000007ooooo`?o00001?ooool2o`000003ooooool0003o000000Wooooo0_l00000
0ooooooo0000o`000009ooooo`;o00001?ooool2o`0000;ooooo1_l00009ooooo`;o00000_ooool2
o`0000Cooooo1?l0000<ooooo`Co000000Coooooo`000?l0003ooooo0ol00009ooooo`Co00000_oo
ool4o`0005kooooo000Looooo`03o`000?oooooooooo063ooooo0_l0000?ooooo`;o00002oooool2
o`0000Kooooo0_l00007ooooo`;o000000?oooooo`000?l000000_l0000;ooooo`;o00000oooool6
o`0000Gooooo0_l00004ooooo`[o00003Oooool3o`00017ooooo0_l00005ooooo`;o0000G_ooool0
01cooooo00?o0000ooooooooool0D?ooool2o`0000_ooooo1Ol00008ooooo`;o00001Oooool2o`00
01?ooooo0_l0000:ooooo`Co00002Oooool4o`0000?ooooo0_l00002ooooo`;o00001?ooool7o`00
00;ooooo2?l0000>ooooo`Co00002Oooool2o`000004ooooool0003o0000ooooo`;o0000IOooool0
01cooooo00?o0000ooooooooool0COooool2o`000003ooooool0003o000000;o00002Oooool5o`00
00Sooooo0_l0000cooooo`Co00003?ooool8o`000003ooooool0003o000000?ooooo0_l0000=oooo
o`?o00000_ooool2o`000003ooooool0003o000000;o00001?ooool2o`000003ooooool0003o0000
00Co00000_ooool2o`0000Gooooo0_l0001Iooooo`007?ooool00ol0003oooooooooo`1<ooooo`?o
00000oooool2o`00013ooooo0_l0000?ooooo`;o0000:_ooool2o`0000Cooooo0_l00006ooooo`;o
00000oooool2o`0000;ooooo0_l000000ooooooo0000o`00000?ooooo`Co00000_ooool6o`0000Wo
oooo1?l00002ooooo`;o00001Oooool2o`0005Wooooo000Looooo`03o`000?oooooooooo04cooooo
0_l0000Cooooo`Go00003oooool2o`0000Wooooo0_l0000Uooooo`Co00001?ooool2o`0000;ooooo
1?l000001?oooooo0000o`000?ooool2o`00017ooooo0ol000000ooooooo0000o`000008ooooo`;o
00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`;o00004oooool2o`0004?o
oooo000Looooo`03o`000?oooooooooo04Wooooo0_l00006ooooo`;o00001oooool2o`0000Gooooo
0ol00006ooooo`;o00001Oooool3o`0000cooooo0_l00009ooooo`;o00002Oooool2o`00017ooooo
0_l00004ooooo`So00004_ooool2o`0000Cooooo0_l000000ooooooo0000o`000008ooooo`;o0000
1?ooool2o`000004ooooool0003o0000ooooo`Go00000_ooool2o`0001?ooooo0_l00013ooooo`00
7?ooool2o`0004Sooooo1?l00006ooooo`;o00000oooool2o`0000;ooooo1?l00003ooooo`;o0000
1oooool2o`0000;ooooo0_l000001?oooooo0000o`000?l00004ooooo`;o00002?ooool2o`0000;o
oooo0_l00003ooooo`;o00002?ooool3o`00017ooooo0ol00002ooooo`;o000000?oooooo`000?l0
00000_l00009ooooo`;o00000_ooool2o`0000Cooooo0ol00009ooooo`;o00001?ooool2o`0000Ko
oooo0_l000000ooooooo0000o`000006o`0005cooooo000Looooo`03o`000?oooooooooo04?ooooo
0_l00002ooooo`;o00002?ooool2o`0000?ooooo0_l00004ooooo`?o000000?oooooo`000?l00000
1Oooool5o`0000;ooooo0_l00008ooooo`;o000000?oooooo`000?l000001Oooool2o`0000;ooooo
0_l0000=ooooo`;o00004Oooool4o`0000;ooooo0_l0000<ooooo`Co000000?oooooo`000?l00000
0ol00002ooooo`;o00001_ooool2o`0000;ooooo0_l00004ooooo`Co00002?ooool3o`00063ooooo
000Looooo`03o`000?oooooooooo04?ooooo0_l0000=ooooo`;o00001Oooool2o`0000;ooooo0_l0
00001?oooooo0000o`000?l00004ooooo`Co00000oooool2o`0000_ooooo0_l00009ooooo`;o0000
2_ooool5o`0000gooooo0_l00002ooooo`Co00000oooool5o`0000Oooooo0ol00003ooooo`;o0000
00?oooooo`000?l000002Oooool7o`0000Cooooo1?l00008ooooo`;o00006_ooool2o`0004Gooooo
000Looooo`03o`000?oooooooooo04_ooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l0
0005ooooo`;o00001?ooool2o`0000gooooo0_l00002ooooo`Co000000?oooooo`000?l000002_oo
ool5o`0000cooooo0ol00009ooooo`Go00001oooool2o`0001;ooooo0_l000000ooooooo0000o`00
000^ooooo`;o0000AOooool001cooooo00?o0000ooooooooool0@oooool2o`0000Kooooo0ol0000:
ooooo`;o00003?ooool2o`0001Gooooo0_l00002ooooo`Co00001Oooool2o`0000Kooooo1Ol00002
ooooo`;o00002?ooool2o`0001Gooooo0_l00006ooooo`?o00004oooool2o`0000[ooooo0_l00004
ooooo`;o000000?oooooo`000?l00000F_ooool001cooooo00?o0000ooooooooool0@oooool3o`00
00Gooooo0ol0000:ooooo`;o00003?ooool2o`0001Wooooo0_l00007ooooo`;o000000Coooooo`00
0?l0003ooooo1_l00003ooooo`;o00001_ooool4o`000003ooooool0003o000001;ooooo0_l00006
ooooo`?o000000?oooooo`000?l000000ol0000=ooooo`;o00002Oooool4o`0000;ooooo0ol00000
0ooooooo0000o`00001Jooooo`007?ooool00ol0003oooooooooo`14ooooo`Co00001_ooool2o`00
0004ooooool0003o0000ooooo`?o00003Oooool2o`0000gooooo0_l0000<ooooo`;o00001oooool2
o`000003ooooool0003o000000Oo000000Coooooo`000?l0003ooooo0_l00005ooooo`Co000000?o
ooooo`000?l000001?ooool3o`0001Oooooo1Ol0000?ooooo`;o00001oooool4o`000004ooooool0
003o0000o`0005kooooo000Looooo`03o`000?oooooooooo04Kooooo0_l00005ooooo`?o000000Co
ooooo`000?l0003ooooo0ol0000;ooooo`Co00003Oooool2o`0000cooooo0_l00007ooooo`;o0000
00?oooooo`000?l000003ol00007ooooo`;o00001Oooool5o`0000kooooo0_l00002ooooo`;o0000
1Oooool2o`0000kooooo0ol00009ooooo`Co00000oooool4o`0001Oooooo0_l0000oooooo`007?oo
ool00ol0003oooooooooo`1=ooooo`;o00000_ooool2o`0000oooooo1?l0000Pooooo`;o00000_oo
oolEo`0000Kooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000_l0
0009ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Gooooo0_l00004ooooo`;o00002Ooo
ool2o`0000Gooooo0_l00002ooooo`?o00001?ooool4o`0001Oooooo0_l0000oooooo`007?ooool0
0ol0003oooooooooo`16ooooo`;o00000oooool2o`0000;ooooo1?l00005ooooo`;o00001?ooool2
o`0000Cooooo0_l0000Fooooo`;o00002?ooool2o`0000;ooooo4_l000001?oooooo0000o`000?l0
0008ooooo`;o00000_ooool2o`0000?ooooo0_l00009ooooo`?o00003_ooool2o`000003ooooool0
003o0000013ooooo0_l00002ooooo`?o000000?oooooo`000?l000000oooool2o`0005Sooooo000L
ooooo`03o`000?oooooooooo04Kooooo0_l00003ooooo`;o00000_ooool2o`0000Cooooo0_l00000
0ooooooo0000o`000004ooooo`Ko00001_ooool2o`0000Cooooo0_l0000:ooooo`;o00001_ooool3
o`000003ooooool0003o000001;o00000_ooool3o`0000;ooooo0_l00003ooooo`;o000000?ooooo
o`000?l000004?ooool2o`0000kooooo0_l0000Booooo`;o00000oooool3o`000003ooooool0003o
000000;ooooo0_l00009ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0?oooool3o`00
01;ooooo0ol00009ooooo`Co00001_ooool2o`0000Cooooo0_l0000Booooo`?o000000?oooooo`00
0?l000000_l000000ooooooo0000o`00000Bo`000005ooooool0003o0000o`000?ooool00_l00002
ooooo`Co000000?oooooo`000?l000004_ooool2o`0000Cooooo0_l00008ooooo`?o00002oooool2
o`0000Cooooo0_l00005ooooo`;o00002Oooool2o`0004kooooo000Looooo`03o`000?oooooooooo
03_ooooo0_l00002ooooo`Co00002?ooool3o`0000Kooooo0_l0000:ooooo`Co00006_ooool2o`00
00Oooooo6Ol00002ooooo`;o00000_ooool2o`0000;ooooo1?l000000ooooooo0000o`00000?oooo
o`;o000000Coooooo`000?l0003o00000oooool3o`0000Oooooo0ol00007ooooo`;o00001?ooool2
o`0000;ooooo0_l0000?ooooo`;o0000Coooool001cooooo00?o0000ooooooooool0>oooool2o`00
00Cooooo0_l00006ooooo`Go00004oooool3o`0000Sooooo0_l0000@ooooo`Co00000ooooolOo`00
01Kooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00003ooooo`?o00004Oooool2
o`0000Cooooo0_l00002ooooo`;o00001oooool2o`0000Kooooo0_l0001?ooooo`007?ooool00ol0
003oooooooooo`19ooooo`;o000000?oooooo`000?l000006?ooool2o`0000Cooooo0_l0000?oooo
o`;o000000Coooooo`000?l0003ooooo8_l0000Eooooo`;o000000?oooooo`000?l000002_ooool2
o`0000oooooo0_l0000Dooooo`;o00001_ooool2o`0004oooooo000Looooo`03o`000?oooooooooo
04Sooooo0_l0000Looooo`;o00005Oooool2o`0000Cooooo0_l00002oooooako000000Coooooo`00
0?l0003o00001oooool2o`0001Cooooo1?l00007ooooo`;o00001oooool2o`0000Oooooo0_l00000
0ooooooo0000o`00000;ooooo`;o00000oooool2o`0000?ooooo0_l0001:ooooo`007?ooool2o`00
03kooooo0_l00008ooooo`?o00004oooool2o`000003ooooool0003o000000Cooooo0_l0000Hoooo
o`;o00001?oooolMo`0000;ooooo1?l00005ooooo`Co00001Oooool2o`0000Cooooo0_l00007oooo
o`Co000000?oooooo`000?l000001?ooool2o`0000?ooooo0_l0000;ooooo`;o000000?oooooo`00
0?l000002oooool2o`0000?ooooo0ol00002ooooo`;o0000B_ooool001cooooo00?o0000oooooooo
ool0?Oooool2o`0000Sooooo0_l0000<ooooo`;o00001_ooool2o`000003ooooool0003o000000;o
oooo0_l0000Gooooo`;o000000?oooooo`000?l000001?oooolQo`0000Oooooo0_l00007ooooo`;o
00001?ooool2o`0000?ooooo0_l00007ooooo`?o00002?ooool2o`0000gooooo0_l0000?ooooo`;o
000000?oooooo`000?l00000C_ooool001cooooo00?o0000ooooooooool0C?ooool2o`0000Oooooo
0_l00007ooooo`;o00001?ooool2o`0000_ooooo0_l00006ooooo`;o00000_ooool2o`0000Oooooo
8?l0000Gooooo`;o00000oooool2o`0000Cooooo0_l00002ooooo`;o00005oooool3o`0000kooooo
0_l0001Aooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00001oooool2o`00013ooooo0_l0
000Aooooo`;o00001_ooool2o`0000_ooooo1Ol000000ooooooo0000o`000005o`000003ooooool0
003o0000013o00002?ooool2o`0000gooooo0_l00009ooooo`;o00004Oooool2o`0000Gooooo0_l0
0002ooooo`;o00004Oooool2o`0004kooooo000Looooo`03o`000?oooooooooo02Sooooo0_l0000F
ooooo`;o000000?oooooo`000?l000004_ooool2o`0001Oooooo0ol0000;ooooo`;o00001_oooolB
o`000003ooooool0003o000000[o00002Oooool2o`00023ooooo0_l00009ooooo`;o00001Oooool2
o`0000;ooooo0_l00002ooooo`;o00002oooool7o`0004_ooooo000Looooo`03o`000?oooooooooo
02Sooooo0_l0000Booooo`;o00000_ooool2o`00013ooooo0_l00003ooooo`;o00001_ooool2o`00
00oooooo0ol0000;ooooo`;o00001_oooolBo`000003ooooool0003o000000[o00001?ooool4o`00
02?ooooo0_l00002ooooo`;o00001Oooool2o`0000cooooo0ol0000;ooooo`;o000000?oooooo`00
0?l000000_l0001;ooooo`007?ooool00ol0003oooooooooo`0kooooo`?o00004?ooool2o`0000;o
oooo0_l00004ooooo`;o00001Oooool2o`0000?ooooo0_l00004ooooo`;o00002oooool2o`0000?o
oooo0_l00008ooooo`;o000000?oooooo`000?l000001Ol000000ooooooo0000o`00000@o`0000Co
oooo1_l00006ooooo`Co00002_ooool2o`00017ooooo0_l00002ooooo`;o000000?oooooo`000?l0
00002Oooool2o`000003ooooool0003o000000;o00001oooool2o`0000Oooooo0_l0001:ooooo`00
7?ooool00ol0003oooooooooo`0kooooo`;o00003_ooool2o`000003ooooool0003o000000?o0000
1?ooool3o`0000?ooooo1?l000000ooooooo0000o`000002o`0000Cooooo0_l0000;ooooo`;o0000
0oooool2o`0000_ooooo3?l000000ooooooo0000o`000005o`0000;ooooo1Ol00003ooooo`?o0000
00?oooooo`000?l000001_ooool4o`0000[ooooo0_l0000:ooooo`Co00000_ooool7o`0000;ooooo
0_l00008ooooo`?o00000_ooool2o`0000Oooooo0_l00007ooooo`;o0000B_ooool001cooooo00?o
0000ooooooooool0?_ooool2o`0000Sooooo1Ol000000ooooooo0000o`000004o`0000?ooooo0ol0
0003ooooo`Co000000?oooooo`000?l000009Oooool;o`0000;ooooo3_l00003ooooo`;o00000_oo
ool4o`0000[ooooo0_l0000Booooo`Co00000_ooool7o`0000;ooooo0_l00003ooooo`;o00000_oo
ool4o`0000?ooooo0_l0000:ooooo`;o000000?oooooo`000?l000002?ooool2o`0004;ooooo000L
ooooo`03o`000?oooooooooo03kooooo0ol000000ooooooo0000o`000004ooooo`?o000000?ooooo
o`000?l000000oooool3o`000003ooooool0003o000000_ooooo0_l00005ooooo`Go00006?ooool>
o`000003ooooool0003o000000ko00000_ooool2o`0000Cooooo0_l00004ooooo`;o00001?ooool2
o`000003ooooool0003o000000kooooo1Ol000000ooooooo0000o`000003o`0000[ooooo0_l00002
ooooo`;o00001Oooool3o`0000Cooooo0_l00003ooooo`;o000000?oooooo`000?l000002?ooool2
o`0004;ooooo000Looooo`03o`000?oooooooooo03oooooo0_l000000ooooooo0000o`000008oooo
o`;o00001Oooool4o`0000_ooooo0_l00002ooooo`So00002Oooool2o`0000Sooooo0_l00002oooo
ob3o00003_ooool2o`0000Cooooo0_l000000ooooooo0000o`00000;ooooo`;o000000?oooooo`00
0?l000000_l00002ooooo`Co00000_ooool2o`00013ooooo0_l000000ooooooo0000o`000004oooo
o`;o00004_ooool2o`00043ooooo000Looooo`03o`000?oooooooooo03gooooo0_l00003ooooo`;o
00002?ooool2o`0000Gooooo0_l0000Aooooo`?o00000_ooool3o`0000Wooooo0_l00002ooooo`;o
00001?ooool2o`0000;ooooo0_l00003oooooaSo00000oooool2o`0000?ooooo0_l00007ooooo`;o
00000_ooool2o`00013ooooo1Ol000001Ooooooo0000o`000?l0003ooooo00?o00000_ooool2o`00
00Wooooo0_l00005ooooo`;o000000?oooooo`000?l000006?ooool2o`00043ooooo000Looooo`03
o`000?oooooooooo03gooooo0_l0000=ooooo`;o00000oooool4o`00013ooooo0_l00005ooooo`?o
00000oooool2o`0000Gooooo1?l0000:ooooo`;o000000?oooooo`000?l000005_l00003ooooo`;o
00000oooool5o`0000Cooooo0_l00002ooooo`;o00004_ooool?o`0000Wooooo0_l00008ooooo`;o
00002?ooool2o`00053ooooo000Looooo`03o`000?oooooooooo04kooooo0_l000000ooooooo0000
o`00000Booooo`;o00001_ooool2o`000003ooooool0003o000000;o00001Oooool2o`0000Oooooo
1?l000001?oooooo0000o`000?oooolEo`0000cooooo1?l00004ooooo`;o00003Oooool2o`0000Wo
oooo3?l0000Eooooo`;o00001oooool2o`0000Wooooo0_l00015ooooo`0000Koooooonk^k_lb<S;o
0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000oooo
ooooool0?oooool2o`0000gooooo0_l0000<ooooo`;o00001?ooool2o`0000cooooo0_l000001?oo
oooo0000o`000?l00005ooooo`;o00001Oooool4o`0000Cooooo5Ol0000Pooooo`;o000000?ooooo
o`000?l000000ooooolDo`0000Kooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo1?l0
000Booooo`;o00001?ooool2o`0000Wooooo0_l0000dooooo`0000KoooooogMgMonHV9SooooooiRH
V?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03_ooooo
0_l00002ooooo`;o00000oooool2o`0000oooooo0ol00002ooooo`Ko00000_ooool2o`0000cooooo
0_l000001?oooooo0000o`000?l00005ooooo`;o00000_ooool2o`0000Wooooo4_l000001?oooooo
0000o`000?ooool2o`0000cooooo0_l0000?ooooo`;o00001?oooolHo`0000Cooooo0_l00003oooo
o`;o000000Coooooo`000?l0003ooooo0_l0000:ooooo`;o00003_ooool2o`000003ooooool0003o
000000Kooooo0_l0000dooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09oooo
o`Go00001_ooool00ol0003oooooooooo`0kooooo`;o00000_ooool2o`0000?ooooo1?l00005oooo
o`?o00001Oooool3o`0000;ooooo0ol000000ooooooo0000o`000005ooooo`Co00001oooool4o`00
00_ooooo0_l0000<ooooo`Go000000?oooooo`000?l000001?l000000ooooooo0000o`000004oooo
o`;o00002oooool3o`0000oooooo0_l00004oooooaSo00001_ooool6o`0000Cooooo0_l00004oooo
o`;o00000_ooool3o`00017ooooo0_l0000looooo`0000?oooooo`000?ooool00_ooool00ol0003o
ooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol00015ooooo`?o00001Oooool3o`00
00Cooooo0ol000000ooooooo0000o`000004o`0000Oooooo1Ol00002ooooo`;o00000_ooool4o`00
00;ooooo0_l00009ooooo`;o00002oooool2o`0000?ooooo0ol00008ooooo`;o00003?ooool3o`00
00[ooooo0_l0000:oooooa?o000000?oooooo`000?l000001Oooool9o`0000Cooooo0_l00004oooo
o`;o00000_ooool4o`0000?ooooo0_l00009ooooo`Co0000??ooool00003ooooool0003ooooo00;o
oooo00?o0000ooooooooool02Oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo
03Oooooo0_l00006ooooo`Co00002Oooool2o`0000Kooooo0_l00002ooooo`Ko00000oooool4o`00
00?ooooo0_l00002ooooo`;o00002?ooool2o`0000Wooooo0ol0000:ooooo`;o00002oooool5o`00
00cooooo0_l0000;ooooo`;o00002?oooolGo`0000Kooooo0ol00003ooooo`?o00000_ooool2o`00
00cooooo0_l00003ooooo`;o00001_ooool2o`000003ooooool0003o000000;o0000??ooool00003
ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00omgMgOoc<c<o`000007ooooo`03
o`000?oooooooooo03Oooooo0_l00005ooooo`Go00002Oooool4o`0000Sooooo0_l00007ooooo`Ko
00006oooool2o`0001Oooooo0ol0000:ooooo`;o00000oooool2o`0000?ooooo0_l0000?oooooaWo
00002_ooool4o`000003ooooool0003o0000017ooooo0_l00006ooooo`;o000000?oooooo`000?l0
00002oooool2o`00037ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4
A?l000001oooool00ol0003oooooooooo`0nooooo`;o000000Coooooo`000?l0003ooooo0_l00002
ooooo`;o00001?ooool2o`0000Oooooo0_l00004ooooo`?o00000_ooool5o`000003ooooool0003o
000002Oooooo1?l000000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l000001_ooool2
o`0000?ooooo0_l00003ooooo`;o00000_ooool2o`0000_ooooo6Ol0000<ooooo`;o00007oooool2
o`0000_ooooo0_l0000aooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0
003ooooo00Kooooo00?o0000ooooooooool0?Oooool2o`0000;ooooo0_l000000ooooooo0000o`00
0002ooooo`;o00001Oooool2o`0000Kooooo0_l00004ooooo`?o00000_ooool8o`0000?ooooo1?l0
0002ooooo`;o00000_ooool2o`0001Sooooo1?l000000ooooooo0000o`000003ooooo`Co000000?o
ooooo`000?l000005?ooool2o`0000Sooooo0_l000000ooooooo0000o`00000Fo`0000Wooooo0_l0
0009ooooo`;o00006Oooool2o`0003gooooo000Looooo`03o`000?oooooooooo03gooooo0_l00002
ooooo`;o000000?oooooo`000?l000000_l00007ooooo`;o00003_ooool2o`000003ooooool0003o
000000go00000_ooool6o`0000gooooo0_l0000Aooooo`Co00002oooool2o`0000cooooo0_l00000
1?oooooo0000o`000?ooool2o`0000;ooooo0_l00002ooooo`Ko000000?oooooo`000?l000003_l0
0009ooooo`;o00000_ooool2o`0000Gooooo0_l00004ooooo`;o00000_ooool2o`0000_ooooo0_l0
0002ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0=Oooool2o`0000Sooooo1?l00002
ooooo`?o00000oooool2o`0001;ooooo4_l00004ooooo`;o00003oooool2o`00017ooooo0ol00007
ooooo`;o00000oooool2o`0000Sooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l0
0004oooooa_o00001_ooool2o`0000?ooooo0_l0000;ooooo`;o00000_ooool2o`0000_ooooo1?l0
0004ooooo`;o00001_ooool2o`00037ooooo000Looooo`03o`000?oooooooooo03Gooooo1?l00006
ooooo`Co00002?ooool2o`00017ooooo4ol0000Looooo`;o00003oooool2o`0000?ooooo0_l0000=
ooooo`;o000000?oooooo`000?l000000_ooool5o`0000Cooooo3_l000000ooooooo0000o`00000<
o`0000Cooooo0_l00003ooooo`;o00001_ooool2o`0001Cooooo1?l00003ooooo`?o00001_ooool2
o`00037ooooo000Looooo`03o`000?oooooooooo03Cooooo0_l000000ooooooo0000o`00000>oooo
o`Co00004OoooolFo`000003ooooool0003o000000cooooo0_l00002ooooo`;o00001_ooool2o`00
00Cooooo0_l000000ooooooo0000o`000006ooooo`;o00005Oooool2o`0000;ooooo1Ol00004oooo
oaoo00001oooool2o`0000Gooooo0ol0000;ooooo`;o00002oooool2o`000003ooooool0003o0000
03[ooooo000Looooo`03o`000?oooooooooo03Cooooo0_l0000Aooooo`Co00001?ooool2o`0000Oo
oooo0_l00002oooooaKo000000?oooooo`000?l000002?ooool2o`0000;ooooo0_l00002ooooo`;o
00001?ooool6o`0000;ooooo0_l000000ooooooo0000o`00000?ooooo`;o000000?oooooo`000?l0
00000_l0000<ooooo`;o00001?ooool4o`000005ooooool0003o0000o`000?ooool04?l00003oooo
o`;o000000?oooooo`000?l000000_ooool4o`0000Cooooo0_l00002ooooo`;o00003?ooool2o`00
00Wooooo1?l0000mooooo`007?ooool00ol0003oooooooooo`0booooo`;o00004?ooool2o`000004
ooooool0003o0000ooooo`;o00000oooool3o`0000?ooooo0_l000000ooooooo0000o`000002oooo
oa[o00001oooool2o`0000;ooooo0_l00008ooooo`Ko00005_ooool2o`000003ooooool0003o0000
00;o00004Oooool6o`000003ooooool0003o0000017o00000oooool2o`0000Gooooo1?l00004oooo
o`;o00001_ooool2o`0000cooooo1?l00003ooooo`;o0000?oooool001cooooo00?o0000oooooooo
ool0;_ooool2o`0000;ooooo0_l0000@ooooo`;o000000?oooooo`000?l000001?l00003ooooo`;o
00000oooool2o`000003ooooool0003o000000;ooooo6_l0000;ooooo`;o00000oooool2o`0000Go
oooo0_l0000Jooooo`;o00003_ooool2o`0000Cooooo0_l000000ooooooo0000o`00000Fo`0000_o
oooo0_l0000;ooooo`?o00001_ooool3o`0000?ooooo1Ol00002ooooo`;o00001oooool2o`0003Ko
oooo000Looooo`03o`000?oooooooooo02kooooo0_l0000=ooooo`;o00001oooool4o`000003oooo
ool0003o000000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool8o`000003oooo
ool0003o000000co00003Oooool2o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o0000
0oooool4o`000003ooooool0003o000000Cooooo0_l0000:ooooo`;o00003_ooool4o`0000Gooooo
5Ol000001?oooooo0000o`000?l0000:ooooo`;o00002oooool2o`0000Oooooo0ol00006ooooo`;o
00002oooool2o`0003Kooooo000Looooo`03o`000?oooooooooo03_ooooo1?l00007ooooo`;o0000
5?oooolIo`0000Oooooo0_l00002ooooo`;o00001oooool2o`0000Oooooo1?l000000ooooooo0000
o`000003ooooo`?o00006oooool4o`0000?ooooo5_l000001?oooooo0000o`000?l0000=ooooo`;o
00001?ooool2o`0000;ooooo0_l00009ooooo`;o00002Oooool2o`0003oooooo000Looooo`03o`00
0?oooooooooo03_ooooo0_l0000;ooooo`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o
00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000Fo`0000;ooooo0_l00002ooooo`Oo
00002?ooool2o`0000[ooooo0_l00003ooooo`;o00007?ooool6o`000003ooooool0003o000001Co
000000?oooooo`000?l000001?ooool2o`0000Sooooo0_l00004ooooo`;o00003Oooool2o`0000Co
oooo0_l00003ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0<Oooool2o`0001Cooooo
0ol000000ooooooo0000o`000003o`0000?ooooo0_l00002ooooo`;o00000_oooolKo`0000;ooooo
0_l00004ooooo`Go00002?ooool4o`0000Sooooo0_l00004ooooo`;o00005Oooool3o`0000Kooooo
0ol00003oooooa?o00002?ooool2o`0000Sooooo0_l00003ooooo`;o00001?ooool2o`0000kooooo
0_l00014ooooo`007?ooool2o`0003;ooooo0_l0000@ooooo`;o00000_ooool2o`0000?ooooo0_l0
000>oooooaSo00001oooool2o`0000Oooooo0ol00006ooooo`;o00003_ooool2o`0000Kooooo0_l0
0008ooooo`;o00000_ooool4o`0000Sooooo0_l00002oooooa?o00002?ooool2o`0000gooooo0_l0
0004ooooo`;o00000oooool2o`0000?ooooo0_l0000Booooo`;o000000?oooooo`000?l00000<ooo
ool001cooooo00?o0000ooooooooool0=Oooool2o`0000cooooo1_l00002ooooo`;o00001_ooool2
o`0000[ooooo5Ol00006ooooo`?o00001oooool3o`0000Cooooo0_l0000;ooooo`;o00000oooool2
o`0000Kooooo0_l00008ooooo`;o000000?oooooo`000?l000001_l00005ooooo`;o00000_ooool9
o`000003ooooool0003o000000Ko00002_ooool2o`0001?ooooo0_l00002ooooo`;o00000oooool2
o`0000gooooo0_l00003ooooo`Go0000<oooool001cooooo00?o0000ooooooooool0;oooool2o`00
00Cooooo0_l0000>ooooo`Wo00001Oooool3o`0000?ooooo0_l00002oooooaSo00001Oooool2o`00
00Cooooo1?l00007ooooo`;o00002oooool2o`0000?ooooo1?l0000Aooooo`;o000000?oooooo`00
0?l000000ol00004ooooo`;o00000ooooolBo`000003ooooool0003o000000Gooooo1?l000000ooo
oooo0000o`000005ooooo`;o00002Oooool2o`0000_ooooo0_l00004ooooo`;o00000oooool2o`00
00Cooooo0_l0000eooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00004_ooool2o`000004
ooooool0003o0000ooooo`Go00001_ooool2o`0000?ooooo0_l00002oooooaSo00001_ooool2o`00
00?ooooo1?l00005ooooo`;o00005?ooool2o`0000Oooooo0_l00004ooooo`;o00000_ooool2o`00
00;ooooo0ol00005ooooo`;o00001oooool8o`0000;ooooo1?l000000ooooooo0000o`000005oooo
o`;o00000oooool2o`0000Gooooo0_l00006ooooo`;o00003_ooool4o`0000;ooooo0_l00004oooo
o`;o0000>_ooool001cooooo00?o0000ooooooooool0@Oooool4o`000003ooooool0003o000000;o
oooo0_l0000=ooooo`;o00000_oooolFo`0000Cooooo0_l00002ooooo`;o00001Oooool2o`0000Go
oooo0_l000000ooooooo0000o`000004ooooo`;o00005?ooool2o`0000Cooooo0_l000000ooooooo
0000o`000002ooooo`Co00003Oooool3o`0000;ooooo1?l00004ooooo`;o000000?oooooo`000?l0
00001?ooool2o`0000[ooooo0_l00003ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`00
00cooooo0_l00008ooooo`?o00000oooool2o`0003Cooooo000Looooo`03o`000?oooooooooo047o
oooo0_l0000Gooooo`;o00001?oooolBo`0000;ooooo0_l000000ooooooo0000o`000004o`0000So
oooo0_l00002ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Sooooo0_l00009ooooo`;o
00000_ooool2o`0000Cooooo0_l00002ooooo`Co00003Oooool3o`0000;ooooo0_l00009ooooo`;o
00001?ooool2o`0000Cooooo0_l00003ooooo`?o00000oooool7o`000003ooooool0003o000000?o
oooo0ol0000Aooooo`;o00000oooool2o`0003Cooooo000Looooo`03o`000?oooooooooo037ooooo
0_l00007ooooo`;o00006oooool2o`000003ooooool0003o000000Gooooo4Ol00002ooooo`;o0000
0oooool2o`0000[ooooo0ol00005ooooo`;o00002_ooool2o`000004ooooool0003o0000o`0000So
oooo0_l00002ooooo`;o00001Oooool2o`000003ooooool0003o000000;o00000_ooool2o`0000?o
oooo1Ol000000ooooooo0000o`000002ooooo`;o00003Oooool2o`0000Oooooo0_l00003ooooo`Co
00000_ooool4o`000003ooooool0003o000000Kooooo0ol00003ooooo`Co0000AOooool001cooooo
00?o0000ooooooooool0<Oooool2o`0000Oooooo0_l0000Kooooo`;o00001?ooool2o`0000;ooooo
3_l000000ooooooo0000o`000008ooooo`;o00001oooool5o`0000;ooooo1Ol0000:ooooo`Ko0000
1oooool4o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o0000
0_ooool6o`0000Gooooo0ol00004ooooo`;o00001_ooool2o`0000kooooo0_l00002ooooo`Co0000
0_ooool3o`0000[ooooo1?l00015ooooo`007?ooool00ol0003oooooooooo`0Looooo`;o00009?oo
ool3o`0000[ooooo0_l00002ooooo`;o00002?ooool2o`0000?ooooo0_l00002ooooo`Wo00002ooo
ool2o`0000Oooooo0_l00005ooooo`Co00000oooool4o`0000Kooooo1Ol00006ooooo`Co00000_oo
ool6o`0000Wooooo0_l00002ooooo`Co00001?ooool2o`0000;ooooo0_l00004ooooo`;o00002_oo
ool2o`0000;ooooo0_l00007ooooo`;o00001oooool3o`0001Kooooo0_l0000kooooo`007?ooool0
0ol0003oooooooooo`0Looooo`;o00009?ooool3o`0000[ooooo0_l00002ooooo`;o000000?ooooo
o`000?l000002Oooool2o`0000?ooooo1ol0000;ooooo`;o00004_ooool2o`0000?ooooo1?l00009
ooooo`;o00003?ooool2o`0000;ooooo0_l00009ooooo`;o00001?ooool2o`0000Cooooo0_l00008
ooooo`;o00002?ooool5o`000003ooooool0003o000000Oooooo0_l00003ooooo`;o00000_ooool2
o`0000Cooooo0_l00002ooooo`;o00002_ooool2o`000004ooooool0003o0000o`0003[ooooo000L
ooooo`03o`000?oooooooooo02cooooo0_l0000Pooooo`;o00001_ooool2o`0000?ooooo1?l00002
ooooo`Oo000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000007ooooo`;o00000_oo
ool2o`0000?ooooo0_l00006ooooo`;o00005?ooool2o`0000kooooo1?l00002ooooo`;o00002_oo
ool2o`000004ooooool0003o0000ooooo`;o00004_ooool2o`000003ooooool0003o000000gooooo
1?l00008ooooo`;o00000_ooool2o`0000[ooooo0_l00002ooooo`;o0000>_ooool001cooooo00?o
0000ooooooooool0:?ooool2o`0000;ooooo1?l0000?ooooo`;o00003Oooool2o`0000?ooooo0_l0
0006ooooo`go000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00000;ooooo`Oo0000
1_ooool4o`000003ooooool0003o000000oooooo0_l0000;ooooo`Oo00000_ooool2o`0000[ooooo
0_l000000ooooooo0000o`000003ooooo`;o00008_ooool2o`0000kooooo0_l00002ooooo`;o0000
0oooool2o`0000kooooo0_l000000ooooooo0000o`00000^ooooo`007?ooool00ol0003ooooooooo
o`0Aooooo`;o00005Oooool2o`0000Cooooo0_l00008ooooo`;o00001Oooool5o`0000;ooooo0_l0
000;ooooo`;o000000?oooooo`000?l000001oooool2o`0000Sooooo0_l00002ooooo`Co00000ooo
ool2o`0000Sooooo1?l00007ooooo`Co000000?oooooo`000?l000007?ooool4o`0001Wooooo0_l0
0004ooooo`;o00004?ooool2o`0001[ooooo0_l00002ooooo`;o00000oooool2o`0000Cooooo0_l0
0008ooooo`;o000000?oooooo`000?l00000;_ooool001cooooo00?o0000ooooooooool04Oooool2
o`0002Gooooo0_l00006ooooo`Co00000_ooool2o`0000Cooooo0_l00002ooooo`;o00000_ooool4
o`0000Kooooo1Ol00005ooooo`;o000000?oooooo`000?l000000_l00005ooooo`;o00004oooool2
o`0000;ooooo1ol0000Hooooo`;o00000_ooool2o`0000cooooo0_l00007ooooo`;o00000_ooool6
o`0000Cooooo1?l00008ooooo`;o0000:Oooool2o`0000[ooooo0_l0000_ooooo`007?ooool00ol0
003oooooooooo`0cooooo`;o00003?ooool2o`0000;ooooo0_l00005ooooo`;o000000Coooooo`00
0?l0003o00000_ooool2o`000003ooooool0003o000000Gooooo1ol00002ooooo`?o000000?ooooo
o`000?l000000_l00004ooooo`;o000000?oooooo`000?l000002_ooool4o`0000?ooooo0_l00002
ooooo`;o000000?oooooo`000?l000001Ol0000?ooooo`;o000000?oooooo`000?l000001Oooool3
o`000003ooooool0003o000000Sooooo0_l00005ooooo`Co00000_ooool5o`0000Gooooo1?l0000L
ooooo`;o00001_ooool3o`000003ooooool0003o000001Gooooo0_l0000_ooooo`007?ooool00ol0
003oooooooooo`0cooooo`;o00003?ooool3o`000003ooooool0003o000000Sooooo1?l000000ooo
oooo0000o`000003o`0000Sooooo1?l000000ooooooo0000o`000003o`0000;ooooo0_l00004oooo
o`;o000000?oooooo`000?l000002?ooool7o`0000;ooooo0_l00002ooooo`;o000000Goooooo`00
0?l0003o0000ooooo`04o`000004ooooool0003o0000ooooo`;o00002?ooool2o`000003ooooool0
003o000000Kooooo1Ol00003ooooo`;o00002_ooool2o`0000Kooooo0ol000000ooooooo0000o`00
0004ooooo`?o00006oooool2o`0000Kooooo0ol000000ooooooo0000o`000002o`0000?ooooo0ol0
0004ooooo`;o0000>?ooool001cooooo0_l0000nooooo`;o00000oooool2o`0000cooooo0ol00000
1?oooooo0000o`000?l00009ooooo`?o00000oooool2o`000003ooooool0003o000000kooooo0_l0
0004ooooo`?o00000oooool2o`0000Cooooo1?l00002ooooo`;o00000oooool2o`000004ooooool0
003o0000ooooo`;o00001oooool2o`0000Cooooo0_l00006ooooo`;o00001?ooool2o`0000;ooooo
0_l0000?ooooo`;o000000?oooooo`000?l000001Oooool2o`0002Wooooo0_l00003ooooo`?o0000
00Coooooo`000?l0003ooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0mooooo`?o0000
2oooool3o`0000Oooooo0_l000000ooooooo0000o`000006ooooo`;o00000oooool2o`0000;ooooo
0_l00003ooooo`;o00002Oooool2o`000004ooooool0003o0000ooooo`;o00002_ooool2o`0000Wo
oooo0_l00004ooooo`;o00001oooool3o`0000?ooooo0_l00002ooooo`;o00003?ooool2o`0000go
oooo0_l0000Aooooo`;o0000:?ooool2o`000003ooooool0003o000003_ooooo000Looooo`03o`00
0?oooooooooo03gooooo1?l0000:ooooo`?o00001oooool2o`000003ooooool0003o000000Oooooo
0_l00002ooooo`;o00000_ooool2o`0000?ooooo0_l0000;ooooo`?o000000?oooooo`000?l00000
5Oooool4o`0000cooooo0_l00007ooooo`;o00006oooool2o`0000?ooooo0_l00003ooooo`;o0000
1oooool2o`00033ooooo1?l0000dooooo`007?ooool00ol0003oooooooooo`0mooooo`Co00001Ooo
ool2o`0001Wooooo0_l00002ooooo`Co00004_ooool2o`0000;ooooo0_l0000Gooooo`;o00001ooo
ool2o`0001_ooooo0ol0000@ooooo`;o00000oooool4o`0000Gooooo0_l0000;ooooo`Go00006?oo
ool2o`0000Kooooo1?l0000dooooo`007?ooool00ol0003oooooooooo`0mooooo`Co00001Oooool2
o`0000Cooooo0_l0000Cooooo`;o00001?ooool2o`0000Kooooo0_l00009ooooo`?o00005oooool4
o`0000Wooooo0_l0000:ooooo`;o00001Oooool4o`0000Kooooo0ol0000Booooo`;o000000?ooooo
o`000?l000000_l00005ooooo`;o00000oooool2o`0000Kooooo1Ol00003ooooo`;o00003?ooool2
o`0000Gooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00000oooool4o`00
00_ooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000?ooooo1?l00004oooo
o`Go00001oooool5o`0000;ooooo0_l00004ooooo`?o00001_ooool2o`0000gooooo1_l00009oooo
o`;o00002_ooool2o`0000Gooooo1?l00003ooooo`;o00001oooool2o`0000cooooo0ol00006oooo
o`;o00000_ooool2o`0000?ooooo0_l00008ooooo`;o00001?ooool2o`0000Cooooo0_l00006oooo
o`;o00000oooool2o`0000;ooooo0_l0000looooo`007?ooool00ol0003oooooooooo`0hooooo`;o
00005?ooool8o`0000?ooooo1?l00005ooooo`Co00000oooool2o`0000;ooooo0_l000000ooooooo
0000o`000002ooooo`;o00003Oooool7o`0000Sooooo0ol000000ooooooo0000o`000004ooooo`;o
00005?ooool2o`0000Oooooo0_l00007ooooo`Go00002Oooool2o`0000Oooooo0_l00002ooooo`;o
00001?ooool2o`000003ooooool0003o000000Cooooo0_l00009ooooo`?o00000oooool2o`0000Ko
oooo0ol000000ooooooo0000o`00000looooo`007?ooool00ol0003oooooooooo`0^ooooo`;o0000
00?oooooo`000?l000006oooool4o`000003ooooool0003o000000oooooo0_l00003ooooo`;o0000
0_ooool3o`0000Sooooo0_l00008ooooo`So00003?ooool2o`0000?ooooo0ol0000Dooooo`;o0000
1Oooool4o`0000Wooooo0ol0000=ooooo`;o00003Oooool2o`000003ooooool0003o000000kooooo
0ol00004ooooo`;o00001oooool2o`0000?ooooo0_l0000jooooo`007?ooool00ol0003ooooooooo
o`0^ooooo`;o000000?oooooo`000?l000004?ooool2o`0000[ooooo0ol00005ooooo`;o00000ooo
ool2o`0000Kooooo0_l00008ooooo`;o00002?ooool2o`000003ooooool0003o000000;o000000?o
ooooo`000?l000000_l0000:ooooo`Co00000oooool2o`0000Cooooo1?l0000>ooooo`;o00001_oo
ool2o`000003ooooool0003o000000?o000000?oooooo`000?l000000oooool2o`00017ooooo0_l0
0006ooooo`;o00002?ooool2o`0000kooooo0ol00006ooooo`;o00002_ooool2o`0003[ooooo000L
ooooo`03o`000?oooooooooo04?ooooo0_l0000:ooooo`;o00001_ooool2o`0000?ooooo0_l0000M
ooooo`Co000000?oooooo`000?l000002_ooool6o`0000?ooooo0_l00002ooooo`;o00000_ooool2
o`0000Cooooo0_l00008ooooo`;o00001_ooool2o`000003ooooool0003o000000?ooooo0ol00003
ooooo`;o00001Oooool2o`0000?ooooo0_l00002ooooo`;o00002Oooool2o`0000Sooooo0ol0000>
ooooo`;o00001_ooool2o`0000gooooo0_l0000gooooo`007?ooool00ol0003oooooooooo`11oooo
o`;o00001oooool2o`0000Kooooo0_l00004ooooo`?o00000_ooool2o`0000[ooooo0_l0000>oooo
o`;o00000oooool2o`0000cooooo0_l0000:ooooo`?o000000?oooooo`000?l000001Oooool2o`00
01Sooooo0_l00002ooooo`;o00001oooool2o`0000?ooooo0_l00002ooooo`;o000000?oooooo`00
0?l000000_l0000?ooooo`Co00004Oooool4o`0000kooooo0_l0000gooooo`007?ooool00ol0003o
ooooooooo`0Cooooo`;o00007Oooool2o`0000gooooo0_l00007ooooo`?o00001Oooool2o`0000Co
oooo0ol00002ooooo`;o00002_ooool2o`0000Gooooo0_l00007ooooo`;o00000oooool2o`0000Go
oooo0_l0000<ooooo`;o00000oooool2o`0000;ooooo1Ol000001?oooooo0000o`000?l00005oooo
o`;o00000oooool2o`0000Wooooo0_l00003ooooo`Co00003?ooool2o`0000Gooooo1?l00003oooo
o`;o00001_ooool2o`0000;ooooo1?l0000Aooooo`Co00003?ooool2o`0003Wooooo000Looooo`03
o`000?oooooooooo01?ooooo0_l0000Mooooo`;o00001oooool6o`0000?ooooo0_l00005ooooo`;o
000000?oooooo`000?l000005_ooool2o`0000Sooooo0_l0000Cooooo`;o00003?ooool2o`0000Wo
oooo0ol000000ooooooo0000o`000006ooooo`?o00000_ooool4o`0000Oooooo0_l00003ooooo`;o
00003_ooool2o`0000Oooooo0_l00003ooooo`;o00001_ooool2o`0000;ooooo1?l000000ooooooo
0000o`000005ooooo`;o00001oooool9o`0000Oooooo0_l0000iooooo`007?ooool00ol0003ooooo
ooooo`0kooooo`Oo00000_ooool2o`0000;ooooo0_l00003ooooo`?o00001_ooool2o`0000;ooooo
0_l00008ooooo`Co00007oooool2o`0000Sooooo0_l0000@ooooo`;o00001_ooool2o`0000Cooooo
0_l0000Eooooo`;o00003_ooool2o`0000Kooooo0_l0000;ooooo`?o00001Oooool2o`0000Oooooo
2Ol00012ooooo`007?ooool00ol0003oooooooooo`0Xooooo`;o00004Oooool3o`000004ooooool0
003o0000o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0000Oooooo0_l00002ooooo`;o0000
2?ooool2o`0000Oooooo0_l00005ooooo`;o00004Oooool2o`0000?ooooo0_l00002ooooo`?o0000
4?ooool2o`0000cooooo0_l00008ooooo`;o00002?ooool2o`000003ooooool0003o000000?ooooo
0_l00005ooooo`;o00001Oooool2o`0000?ooooo0_l0000;ooooo`;o00001Oooool2o`0000Wooooo
0_l00002ooooo`Co00003?ooool2o`0003Cooooo000Looooo`03o`000?oooooooooo02Sooooo0_l0
000@ooooo`?o00003Oooool2o`00017ooooo0_l00005ooooo`;o00001oooool2o`0000Gooooo0_l0
000?ooooo`?o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00006Oooool2o`0000Sooooo
0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00004ooooo`;o00001_ooool2o`0000Go
oooo0_l00005ooooo`;o00002?ooool2o`0000Oooooo0ol00003ooooo`;o00002_ooool2o`000003
ooooool0003o000000;o00003?ooool2o`0003Cooooo000Looooo`;o0000>?ooool6o`0000gooooo
1?l00003ooooo`Co00000oooool2o`0000?ooooo0_l0000:ooooo`;o00004_ooool2o`0000Kooooo
1_l0000Gooooo`;o00001oooool3o`0000Oooooo0_l000000ooooooo0000o`000002ooooo`;o0000
00Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l0
00002Oooool2o`0000;ooooo0_l00008ooooo`;o00001oooool3o`0000Kooooo0_l00007ooooo`;o
00000oooool2o`0004;ooooo000Looooo`03o`000?oooooooooo03Oooooo1?l0000;ooooo`;o0000
00Coooooo`000?l0003ooooo1?l000000ooooooo0000o`000002o`0000?ooooo0_l00005ooooo`Co
000000?oooooo`000?l000000oooool3o`00013ooooo0ol00004ooooo`Ko00000oooool2o`0000Co
oooo0_l00004ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Gooooo0_l000000ooooooo
0000o`000007ooooo`Go00000_ooool2o`0000Cooooo0_l00005ooooo`;o000000?oooooo`000?l0
00002Oooool2o`0000cooooo0_l00004ooooo`;o00002_ooool2o`0000Sooooo1_l00002ooooo`;o
0000?_ooool001cooooo00?o0000ooooooooool0>Oooool2o`0000_ooooo0_l000000ooooooo0000
o`000003ooooo`;o00000oooool2o`0000[ooooo1?l000001?oooooo0000o`000?ooool5o`00013o
oooo0_l00005ooooo`Ko00000oooool:o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`;o
00001Oooool2o`0000?ooooo0_l00006ooooo`Co00000oooool2o`0000Gooooo0_l00002ooooo`;o
00000_ooool2o`0000Wooooo0_l0000Booooo`;o00001?ooool2o`0000[ooooo2?l00004ooooo`;o
0000?_ooool001cooooo00?o0000ooooooooool0>Oooool2o`0001Wooooo0ol00007ooooo`;o0000
1Oooool4o`000003ooooool0003o000001Kooooo1_l00002ooooo`oo00001?ooool4o`0000gooooo
0_l00002ooooo`;o00002Oooool2o`0000Gooooo1_l00003ooooo`Go00001?ooool2o`0000[ooooo
0_l0000<ooooo`Co00002Oooool4o`0001cooooo0_l0000Zooooo`007?ooool00ol0003ooooooooo
o`11ooooo`;o00001_ooool3o`0000Oooooo1?l00007ooooo`;o00001Oooool3o`0000;ooooo0_l0
000<ooooo`;o00002?ooool2o`000004ooooool0003o0000o`0000;ooooo1ol000000ooooooo0000
o`000002ooooo`?o000000Coooooo`000?l0003ooooo1?l00002ooooo`;o00001Oooool2o`0000Ko
oooo1?l00002ooooo`;o00001_ooool3o`0000;ooooo1?l00004ooooo`Go00001?ooool4o`000003
ooooool0003o000000Gooooo0_l0000<ooooo`Co0000:Oooool2o`0002[ooooo000Looooo`03o`00
0?oooooooooo03cooooo0_l00003ooooo`;o00001_ooool7o`0000?ooooo0_l000000ooooooo0000
o`00000>ooooo`;o00000_ooool2o`0000cooooo0_l00007ooooo`;o00001?ooool2o`000003oooo
ool0003o000000Go000000?oooooo`000?l000001Ol000001?oooooo0000o`000?ooool3o`0000?o
oooo1Ol00002ooooo`;o00002?ooool2o`0000;ooooo0_l00006ooooo`?o000000?oooooo`000?l0
00000oooool8o`0000Gooooo1?l000000ooooooo0000o`00000Looooo`;o00001oooool4o`0004?o
oooo000Looooo`03o`000?oooooooooo03cooooo0_l0000>ooooo`Ko000000Coooooo`000?l0003o
oooo0_l0000Wooooo`Co000000?oooooo`000?l000000ol00004ooooo`;o00000_ooool7o`000004
ooooool0003o0000ooooo`Co00000_ooool7o`0001_ooooo3Ol000000ooooooo0000o`000003oooo
o`;o00000_ooool2o`0000;ooooo0_l0000@ooooo`;o00000_ooool2o`0000;ooooo1?l00005oooo
o`Go0000@_ooool001cooooo00?o0000ooooooooool0=?ooool2o`0000Kooooo0_l00002ooooo`;o
00000_ooool4o`0000Sooooo0_l000000ooooooo0000o`000006ooooo`;o00001Oooool2o`0000Co
oooo0_l0000Aooooo`;o00000_ooool=o`000003ooooool0003o000000So000000?oooooo`000?l0
00001?l00003ooooo`So00001Oooool2o`0001Cooooo4?l00003ooooo`;o00000_ooool2o`0000;o
oooo1?l0000>ooooo`;o00000_ooool2o`0000Cooooo0_l00007ooooo`?o0000@_ooool001cooooo
00?o0000ooooooooool0<_ooool4o`0000Wooooo0ol00002ooooo`Co00004oooool2o`0000;ooooo
0_l000001?oooooo0000o`000?l00003ooooo`;o00004?ooool3o`000003ooooool0003o000000Co
000000?oooooo`000?l000004?l000000ooooooo0000o`000003o`0000;ooooo1ol00008ooooo`;o
00004?ooool2o`0000?ooooo5?l00002ooooo`;o00000_ooool4o`0000Oooooo1?l0000:ooooo`?o
00002Oooool3o`0000Sooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0booooo`;o0000
2oooool2o`0000Gooooo0_l00008ooooo`;o000000?oooooo`000?l000002_ooool2o`0000;ooooo
0_l0000Eooooo`Ko00000_ooool<o`000003ooooool0003o000000go000000Coooooo`000?l0003o
oooo1?l00007ooooo`;o00001_ooool2o`0000Kooooo0_l000000ooooooo0000o`00000Ho`0000Go
oooo0_l00002ooooo`;o00001Oooool4o`0000[ooooo0ol00005ooooo`;o00003Oooool2o`0003So
oooo000Looooo`03o`000?oooooooooo04Kooooo0_l00008ooooo`Oo00003?ooool2o`0000oooooo
0_l00006ooooo`;o00000_oooolNo`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l0
00000_ooool2o`0000;ooooo1?l00004ooooo`;o00001_ooool2o`000003ooooool0003o000000co
000000?oooooo`000?l000002Ol00009ooooo`;o00002_ooool2o`0000Gooooo0_l00008ooooo`;o
00003_ooool2o`0003Oooooo000Looooo`03o`000?oooooooooo03Sooooo0_l0000Booooo`;o0000
1?ooool5o`0000;ooooo0_l00007ooooo`?o00000_ooool2o`0000_ooooo0_l0000:oooooako0000
00Coooooo`000?l0003ooooo2ol00002ooooo`;o00002Oooool2o`000004ooooool0003o0000oooo
oa3o000000?oooooo`000?l000002_l0000?ooooo`;o000000?oooooo`000?l000001Oooool2o`00
01Sooooo0_l0000gooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00004_ooool4o`0000;o
oooo1?l00003ooooo`;o00001oooool3o`0000;ooooo0_l00003ooooo`;o00003oooool2o`000003
ooooool0003o0000017o000000?oooooo`000?l000000_l000000ooooooo0000o`000003o`0000;o
oooo0_l00002ooooo`Ko000000Goooooo`000?l0003o0000ooooo`02o`0000Wooooo0_l00004oooo
o`So000000?oooooo`000?l000004_l00004ooooo`;o00002Oooool6o`0001[ooooo0_l0000koooo
o`007?ooool00ol0003oooooooooo`0eooooo`;o00005oooool2o`0000Cooooo0_l000001?oooooo
0000o`000?l00009ooooo`;o00001oooool2o`0000cooooo0_l000000ooooooo0000o`00000So`00
00Gooooo1?l000000ooooooo0000o`00000;ooooo`;o00000_ooool2o`0000;ooooo4ol000000ooo
oooo0000o`000006o`0000?ooooo1?l00009ooooo`Go00000_ooool2o`0001Kooooo0_l0000koooo
o`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0:_ooool2o`0000Wooooo0_l0000>ooooo`;o00000ooo
ool2o`0000?ooooo0_l00003ooooo`;o000000Coooooo`000?l0003o00005_ooool2o`0000Cooooo
1_l00002ooooo`go000000?oooooo`000?l000001?l000000ooooooo0000o`00000<o`0000?ooooo
1ol00004ooooo`?o00001ooooolJo`000003ooooool0003o000000Wo000000?oooooo`000?l00000
0_l0000:ooooo`;o00001?ooool2o`0001Kooooo0_l0000kooooo`0000KoooooogMgMonHV9Sooooo
oiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000oooo
ooooool0:_ooool3o`0001Sooooo0_l00003ooooo`;o00000oooool3o`0000[ooooo0_l000001?oo
oooo0000o`000?l0000>ooooo`;o00001?ooool5o`000003ooooool0003o000002go00001?ooool3
o`0000Cooooo:Ol00002ooooo`Co00002?ooool5o`0000cooooo0_l00008ooooo`Co0000?Oooool0
0003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool0:oooool2o`0001Gooooo0_l000000ooooooo0000o`000003
ooooo`;o00001?ooool2o`0000[ooooo0_l000001?oooooo0000o`000?l0000Fooooo`?o000000?o
ooooo`000?l000009_l000001?oooooo0000o`000?ooool3o`0000Gooooo0_l00004ooooob?o0000
00?oooooo`000?l000001?ooool5o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l00000
2_ooool4o`0000Sooooo1?l0000mooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooooooo
o`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0001kooooo0_l0000Eooooo`;o0000
1oooool2o`0000;ooooo0ol0000Looooo`;o00004_ooool2o`000004ooooool0003o0000ooooo`Ko
000000?oooooo`000?l000007ol000001?oooooo0000o`000?l00004ooooo`Oo00000oooool2o`00
00;ooooo:ol00002ooooo`Co00001_ooool2o`0000[ooooo0_l0001;ooooo`0000?oooooo`000?oo
ool00_ooool00ol0003oooooooooo`09ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0
003oooooooooo`0Nooooo`;o00005Oooool2o`0000Oooooo1?l000000ooooooo0000o`00000Aoooo
o`;o000000?oooooo`000?l000001_ooool2o`0001;ooooo0_l000001?oooooo0000o`000?ooool3
o`000003ooooool0003o000001Co000000?oooooo`000?l000002_l00002ooooo`;o00001Oooool8
o`000003ooooool0003o000000Co000000?oooooo`000?l000001_l000000ooooooo0000o`00000K
o`000003ooooool0003o000000;ooooo0_l00008ooooo`;o00004oooool2o`0004;ooooo00000ooo
oooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0
003oooooooooo`0cooooo`;o00002oooool2o`0000Cooooo0_l00006ooooo`;o00001Oooool3o`00
0003ooooool0003o000000Gooooo0_l0000>ooooo`;o00000oooool4o`0000?ooooo2_l000000ooo
oooo0000o`00000<o`000003ooooool0003o000000go00000oooool3o`0000?ooooo1Ol000000ooo
oooo0000o`00000=o`000003ooooool0003o000000So000000?oooooo`000?l000003?l00005oooo
o`;o00001_ooool2o`0001Wooooo0_l00012ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;
ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0<oooool2o`00017ooooo0ol00005
ooooo`;o00001Oooool7o`0000;ooooo1?l0000>ooooo`;o00000oooool4o`0000;ooooo6_l00000
0ooooooo0000o`00000?o`000004ooooool0003o0000o`0000Kooooo0_l00004ooooob?o00000ooo
ool2o`0000;ooooo0_l00007ooooo`?o00005Oooool2o`0004Gooooo00001_ooooook^k^oc8b<_l0
003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`16ooooo`?o
00001Oooool4o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo1?l0000>oooo
o`;o00001_oooolMo`0000;ooooo1_l000001Ooooooo0000o`000?l0003ooooo00Oo00000oooool2
o`0000?ooooo0_l00004ooooobSo00000_ooool2o`0000Sooooo0_l0000Eooooo`Co0000@oooool0
01cooooo00?o0000ooooooooool0;?ooool2o`0001;ooooo0_l00006ooooo`;o00001_ooool2o`00
00;ooooo1?l00008ooooo`;o00005_ooool<o`000003ooooool0003o000000ko00000_ooool7o`00
0003ooooool0003o000000?o000000?oooooo`000?l000001?l000000ooooooo0000o`000002o`00
00Oooooo9ol0000Nooooo`;o00001_ooool2o`0004?ooooo000Looooo`03o`000?oooooooooo02[o
oooo1?l0000Booooo`;o00001_ooool2o`0000Kooooo0_l00003ooooo`?o00000_ooool2o`0001[o
oooo:?l000000ooooooo0000o`000002o`0000;ooooo1ol00002ooooo`;o000000Coooooo`000?l0
003o00000_ooool2o`0000?ooooo8ol000000ooooooo0000o`00000Gooooo`;o00000_ooool2o`00
00Gooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0Zooooo`;o0000:Oooool2o`0000?o
oooo0_l0000Gooooo`;o000000?oooooo`000?l000001?oooolWo`000003ooooool0003o000000Ko
00001Oooool3o`0000;ooooo0_l00002ooooob;o00000oooool2o`000004ooooool0003o0000oooo
o`;o00004Oooool2o`0000Oooooo1?l00014ooooo`007?ooool00ol0003oooooooooo`0looooo`;o
000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000Sooooo0_l0000Oooooo`;o
00001OoooolYo`000003ooooool0003o000000;ooooo0_l00007ooooo`;o000000?oooooo`000?l0
00001?ooool<o`000003ooooool0003o000001?o00001_ooool2o`000004ooooool0003o0000o`00
00gooooo0_l00002ooooo`;o00001Oooool3o`0000Cooooo0_l00010ooooo`007?ooool00ol0003o
ooooooooo`0Zooooo`;o00003_ooool4o`000003ooooool0003o000000Cooooo1Ol00005ooooo`;o
000000?oooooo`000?l000003Oooool2o`0000kooooo1?l00005ooooo`Co000000?oooooo`000?l0
00006_l000001?oooooo0000o`000?ooool9o`0000Wooooo0_l000000ooooooo0000o`000006oooo
oako000000?oooooo`000?l000002Oooool2o`0000[ooooo0_l000000ooooooo0000o`000002oooo
o`Co00000oooool3o`0000Cooooo1?l0000nooooo`007?ooool00ol0003oooooooooo`0Zooooo`;o
00003_ooool3o`0000Wooooo1?l00005ooooo`;o00004?ooool2o`0000gooooo1Ol00004ooooo`;o
000000?oooooo`000?l000007Ol000000ooooooo0000o`000004ooooo`;o00000_ooool2o`0000co
oooo0_l00004ooooo`Wo000000?oooooo`000?l000000ol000000ooooooo0000o`00000>o`000003
ooooool0003o000000?ooooo0_l00008ooooo`;o00001_ooool2o`0000Oooooo0_l000000ooooooo
0000o`000005o`0000Cooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0Wooooo`;o0000
4_ooool2o`0000Kooooo0_l0000:ooooo`;o00004_ooool2o`0000_ooooo0_l000000ooooooo0000
o`000004ooooo`Ko000000?oooooo`000?l000006Ol000000ooooooo0000o`000006o`0000oooooo
0ol000000ooooooo0000o`000003o`0000Sooooo1?l00003oooooa7o00001?ooool2o`0000Sooooo
0_l0000Aooooo`Co00000_ooool2o`000003ooooool0003o0000047ooooo000Looooo`03o`000?oo
oooooooo02Oooooo0_l00004ooooo`;o00004_ooool4o`0000Cooooo0_l0000Cooooo`;o00000ooo
ool2o`0000Wooooo0_l00003ooooo`Co00000_ooool6o`000003ooooool0003o000000ko000000?o
ooooo`000?l000004?l000000ooooooo0000o`00000=ooooo`;o00000_ooool3o`0000Wooooo1_l0
00000ooooooo0000o`000005o`000003ooooool0003o000000So00001?ooool2o`0000Cooooo0_l0
000Aooooo`;o00000_ooool3o`0000Kooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0]
ooooo`;o00004_ooool4o`0000Cooooo0_l0000Booooo`Go00003?ooool2o`000003ooooool0003o
000000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_oooolRo`000003ooooool0003o
000000Kooooo0_l0000<ooooo`;o000000?oooooo`000?l000001?ooool:o`000003ooooool0003o
000000Co00000_ooool4o`0000cooooo0_l0000;ooooo`;o00000_ooool4o`0000?ooooo0_l00019
ooooo`007?ooool00ol0003oooooooooo`1Gooooo`;o00001?ooool5o`0000gooooo1?l00006oooo
o`?o00001_oooolIo`000003ooooool0003o000000Ko000000Coooooo`000?l0003o00001?ooool2
o`0000?ooooo0_l00007ooooo`;o000000?oooooo`000?l000001Oooool3o`0000;ooooo1?l00003
ooooo`;o00001_ooool2o`0001Kooooo0_l000000ooooooo0000o`000002ooooo`;o0000D?ooool0
01cooooo00?o0000ooooooooool0Boooool2o`000003ooooool0003o000000;ooooo0_l00003oooo
o`;o000000Coooooo`000?l0003ooooo0_l0000>ooooo`Go00001_ooool4o`000003ooooool0003o
000000;ooooo8?l000000ooooooo0000o`000004o`0000Wooooo0_l00006ooooo`;o00000_ooool2
o`0000cooooo0ol000000ooooooo0000o`000007ooooo`;o00001?ooool8o`0000[ooooo0_l0001G
ooooo`007?ooool2o`0003oooooo0ol0000:ooooo`;o000000?oooooo`000?l000000_ooool2o`00
00Kooooo1ol0000<ooooo`;o000000?oooooo`000?l000001?ooool9o`0000;ooooo3_l000000ooo
oooo0000o`00000=o`0000Cooooo0_l0000Dooooo`;o00002_ooool2o`0000Gooooo0_l000001?oo
oooo0000o`000?ooool2o`0000Gooooo0_l00003ooooo`So00002_ooool3o`0000;ooooo0_l00003
ooooo`;o0000COooool001cooooo00?o0000ooooooooool0?Oooool4o`0000Gooooo0_l00003oooo
o`?o00003Oooool2o`0000;ooooo1?l0000Cooooo`;o00000_ooool5o`0000?ooooo5_l00002oooo
o`Co00001Oooool2o`0000Cooooo1?l00002ooooo`;o00005?ooool2o`0000Gooooo0_l00004oooo
o`;o00001Oooool2o`0000Oooooo0_l00002ooooo`;o00002?ooool3o`0000;ooooo0_l00003oooo
o`;o0000COooool001cooooo00?o0000ooooooooool0?Oooool2o`0000Oooooo1?l00002ooooo`;o
00004oooool2o`0001;ooooo0_l000000ooooooo0000o`000006oooooako00001?ooool5o`0000;o
oooo1?l00002ooooo`;o00006oooool3o`0000_ooooo0_l00006ooooo`;o00000_ooool2o`0000So
oooo0_l000000ooooooo0000o`000009ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0
B?ooool2o`0001Oooooo0_l0000Booooo`;o000000?oooooo`000?l000001?oooolSo`000004oooo
ool0003o0000ooooo`;o00000oooool2o`00013ooooo0_l0000?ooooo`;o00002oooool2o`0001Go
oooo1_l00004ooooo`;o000000?oooooo`000?l00000BOooool001cooooo00?o0000ooooooooool0
BOooool2o`000003ooooool0003o000000[ooooo0_l00003ooooo`;o00007?ooool:o`000003oooo
ool0003o0000017o000000?oooooo`000?l000001Ol00002ooooo`;o00002Oooool2o`0000cooooo
0_l00005ooooo`;o00001oooool2o`0000?ooooo0_l0000Looooo`Co00000_ooool2o`0000;ooooo
1?l0001<ooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00001?ooool2o`000003ooooool0
003o000000[ooooo0_l00003ooooo`;o00007?ooool:o`0000;ooooo1Ol000000ooooooo0000o`00
0005o`000003ooooool0003o000000Wo000000?oooooo`000?l000000_l00003ooooo`;o00000ooo
ool4o`0000Gooooo0_l0000;ooooo`;o00001?ooool5o`0000?ooooo0_l0000Fooooo`;o00001?oo
ool2o`0000Kooooo1?l0000:ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0@oooool2
o`0000Sooooo0_l00007ooooo`;o00008_ooool2o`000005ooooool0003o0000o`000?ooool00_l0
0002oooooa7o000000?oooooo`000?l000001ol000001?oooooo0000o`000?l00004ooooo`;o0000
0oooool6o`0000?ooooo1?l00002ooooo`;o00002oooool7o`0001Wooooo0_l0000<ooooo`;o0000
3?ooool2o`0004;ooooo000Looooo`03o`000?oooooooooo02cooooo0_l00007ooooo`;o00004Ooo
ool4o`000003ooooool0003o000000Gooooo1?l0000:ooooo`;o00004Oooool2o`0000?ooooo1_l0
00000ooooooo0000o`000002oooooa_o00000_ooool2o`0000gooooo1?l000000ooooooo0000o`00
0002o`0000;ooooo0_l0000?ooooo`Co0000N?ooool001cooooo00?o0000ooooooooool0;?ooool2
o`000003ooooool0003o000000Cooooo0_l0000Aooooo`Co00001Oooool2o`000003ooooool0003o
000000cooooo0_l0000:ooooo`?o00000oooool3o`0000Gooooo2_l000000ooooooo0000o`000002
o`0000;ooooo0_l000000ooooooo0000o`00000<o`0000Cooooo0_l0000>ooooo`?o00006_ooool2
o`0001;ooooo0_l0001Tooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00004oooool2o`00
00?ooooo0ol00005ooooo`;o00001_ooool3o`0000Kooooo0_l0000:ooooo`Co00000_ooool2o`00
00Wooooo1ol00002ooooo`?o000000?oooooo`000?l000000_l000000ooooooo0000o`000009o`00
00Kooooo0_l0000oooooo`;o00001_ooool2o`0000Cooooo0_l0001Fooooo`007?ooool00ol0003o
ooooooooo`14ooooo`;o00000oooool3o`0000[ooooo0_l000001?oooooo0000o`000?l0000Doooo
o`;o000000Coooooo`000?l0003o00002Oooool2o`0000?ooooo1ol000000ooooooo0000o`000002
o`000003ooooool0003o000000;o00000_ooool2o`000003ooooool0003o000000?ooooo0_l0000j
ooooo`;o000000?oooooo`000?l000002oooool2o`0000Cooooo0_l00008ooooo`;o0000C?ooool0
01cooooo00?o0000ooooooooool0D?ooool2o`0000Cooooo0_l000000ooooooo0000o`000009oooo
o`;o00002oooool5o`0000Wooooo0ol00002ooooo`Ko00001?ooool2o`000003ooooool0003o0000
00;o00001Oooool2o`0000?ooooo0ol00005ooooo`;o0000<_ooool5o`0000Kooooo0_l000000ooo
oooo0000o`00000@ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0AOooool2o`0000Wo
oooo0_l000000ooooooo0000o`000006ooooo`?o000000?oooooo`000?l000000oooool2o`0000Ko
oooo0_l00003ooooo`;o00001?ooool3o`0000Kooooo0ol00002ooooo`Go00000_ooool8o`0000Go
oooo0ol00004ooooo`;o00001Oooool2o`0000?ooooo0_l0000_ooooo`;o000000?oooooo`000?l0
00001?ooool2o`000003ooooool0003o000005kooooo000Looooo`03o`000?oooooooooo04Gooooo
1?l00003ooooo`;o00001Oooool2o`0000Kooooo0ol000001?oooooo0000o`000?l00002ooooo`;o
00001_ooool2o`0000Wooooo1?l00006ooooo`?o000000?oooooo`000?l000000_l000000ooooooo
0000o`000002o`000004ooooool0003o0000ooooo`;o00001?ooool3o`0000Sooooo0_l00003oooo
o`;o00000_ooool2o`00027ooooo0_l0000?ooooo`;o00000_ooool2o`0000_ooooo1?l00005oooo
o`;o00001?ooool2o`0004Oooooo000Looooo`03o`000?oooooooooo04Oooooo0_l00003ooooo`Co
00002Oooool2o`0000Gooooo0_l0000Gooooo`?o00001_ooool7o`000003ooooool0003o000000?o
00000oooool2o`0000;ooooo1?l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000?o
oooo0_l0000Uooooo`;o00004oooool2o`0000_ooooo1?l00005ooooo`;o00001?ooool2o`0004Oo
oooo000Looooo`03o`000?oooooooooo04kooooo0ol00005ooooo`;o000000?oooooo`000?l00000
2_ooool2o`0001?ooooo0_l00008ooooo`;o000000?oooooo`000?l000000oooool3o`0000Oooooo
0_l00004ooooo`;o00000_ooool2o`0002Oooooo0_l0000=ooooo`Co00002Oooool2o`0000Cooooo
0_l0001Looooo`007?ooool2o`00053ooooo1?l00003ooooo`;o00001?ooool2o`0000Oooooo0_l0
000Cooooo`;o00005Oooool2o`00017ooooo0_l0000Sooooo`Ko00000_ooool2o`0000Gooooo1ol0
0006ooooo`;o00001?ooool2o`0000Cooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`1;
ooooo`;o00001?ooool3o`000003ooooool0003o000000Gooooo0_l0000cooooo`;o00004Oooool2
o`0002Gooooo1Ol000000ooooooo0000o`000009ooooo`?o00001_ooool2o`0000Cooooo0_l00004
ooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0Boooool2o`0000Cooooo0ol000000ooo
oooo0000o`000002o`0000Oooooo0_l0000<ooooo`;o00009oooool2o`00013ooooo0_l0000Soooo
o`?o00002oooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0005gooooo000Looooo`03
o`000?oooooooooo05Oooooo0_l00007ooooo`;o00000_ooool2o`0000Sooooo0_l0000=ooooo`;o
00006?ooool2o`000003ooooool0003o000000gooooo0_l0000Pooooo`;o00000_ooool2o`0000Go
oooo0_l00008ooooo`?o00001oooool2o`000003ooooool0003o000005[ooooo000Looooo`03o`00
0?oooooooooo03gooooo0_l00002ooooo`;o00008Oooool2o`0001Oooooo0ol0000=ooooo`;o0000
2oooool3o`0000?ooooo0_l00007ooooo`;o00008?ooool2o`0000Wooooo0_l00008ooooo`?o0000
2_ooool2o`0005[ooooo000Looooo`03o`000?oooooooooo03gooooo0_l00002ooooo`;o00004Ooo
ool2o`0000gooooo0_l00008ooooo`;o00001oooool2o`0000Cooooo1?l00008ooooo`Co000000?o
ooooo`000?l000003?ooool2o`0000;ooooo0ol00007ooooo`;o00006?ooool2o`0001_ooooo0_l0
000:ooooo`;o0000Foooool001cooooo00?o0000ooooooooool0E?ooool2o`0000gooooo0_l00003
ooooo`;o000000?oooooo`000?l000000_l00007ooooo`;o00001?ooool3o`0000Wooooo1?l0000C
ooooo`;o00001_ooool2o`0001[ooooo0_l0000Hooooo`;o00003Oooool2o`0005_ooooo000Loooo
o`03o`000?oooooooooo05kooooo0_l000001?oooooo0000o`000?l00004ooooo`Go00004Oooool2
o`000003ooooool0003o000002Cooooo0_l0000Uooooo`?o00003?ooool2o`0000Oooooo0_l0000;
ooooo`;o0000E?ooool001cooooo00?o0000ooooooooool0G_ooool2o`000004ooooool0003o0000
o`0000Cooooo1Ol00009ooooo`;o00001_ooool2o`000003ooooool0003o000001;ooooo1?l00005
ooooo`;o00003?ooool2o`0001Oooooo0ol00006ooooo`?o00001Oooool2o`0000Sooooo0_l00004
ooooo`;o00002oooool2o`0005Cooooo000Looooo`03o`000?oooooooooo043ooooo0_l0000Hoooo
o`;o00000_ooool2o`0000[ooooo0ol00009ooooo`;o00007Oooool4o`0000Gooooo0_l0000<oooo
o`;o00005oooool3o`0000Kooooo0_l00006ooooo`;o00001Oooool2o`000003ooooool0003o0000
06Oooooo000Looooo`03o`000?oooooooooo043ooooo0_l0000Hooooo`;o00001?ooool2o`0001?o
oooo0ol0000Dooooo`;o00001Oooool2o`0001?ooooo0_l0000Kooooo`?o00001_ooool2o`000003
ooooool0003o000000[ooooo0_l0001Zooooo`007?ooool00ol0003oooooooooo`1Kooooo`;o0000
0oooool2o`0001;ooooo0ol00002ooooo`;o00002oooool2o`0000Cooooo0_l00004ooooo`?o0000
4Oooool4o`0000?ooooo0_l0000Fooooo`;o00002_ooool2o`0000Cooooo0_l0001`ooooo`007?oo
ool00ol0003oooooooooo`1Kooooo`;o000000?oooooo`000?l000004_ooool4o`0000?ooooo0_l0
000;ooooo`;o00002_ooool2o`0001;ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o0000
6?ooool2o`0000?ooooo0_l00002ooooo`Go000000Coooooo`000?l0003ooooo0_l00006ooooo`;o
0000IOooool001cooooo00?o0000ooooooooool0B?ooool2o`0000Kooooo0_l0000<ooooo`;o0000
4_ooool2o`000003ooooool0003o000000Cooooo0_l00004ooooo`;o00002oooool4o`0001Gooooo
0_l000000ooooooo0000o`000002ooooo`;o00003_ooool2o`0000;ooooo1?l00002ooooo`;o0000
0oooool2o`0000;ooooo1Ol00003ooooo`?o00001_ooool2o`0006Gooooo000Looooo`03o`000?oo
oooooooo04Sooooo0_l00006ooooo`Co00006_ooool2o`0000Gooooo0_l00004ooooo`;o000000Co
ooooo`000?l0003ooooo0_l0000;ooooo`Go00005?ooool2o`0000;ooooo0_l00003ooooo`;o0000
3?ooool2o`0000;ooooo1?l0000Cooooo`;o00000oooool2o`000003ooooool0003o000006Kooooo
000Looooo`03o`000?oooooooooo057ooooo0ol00008ooooo`;o00004?ooool2o`000003ooooool0
003o000000?ooooo0_l00006ooooo`;o00003Oooool2o`0000;ooooo0_l00007ooooo`;o00002ooo
ool2o`0000;ooooo1?l000000ooooooo0000o`00000=ooooo`;o00004?ooool2o`0000_ooooo0_l0
00000ooooooo0000o`00001Vooooo`007?ooool2o`0005;ooooo0_l00009ooooo`Co00004Oooool2
o`0000;ooooo0ol0000?ooooo`;o00001?ooool3o`0000[ooooo0_l0000;ooooo`;o00000oooool3
o`0000;ooooo0_l0000<ooooo`;o00004?ooool4o`0007Cooooo000Looooo`03o`000?oooooooooo
05Gooooo0_l00007ooooo`;o00000_ooool2o`00017ooooo0_l0000@ooooo`;o00001Oooool5o`00
01kooooo0_l0000Pooooo`;o00000_ooool2o`0000Oooooo0ol0001Vooooo`007?ooool00ol0003o
ooooooooo`1Eooooo`;o00001oooool2o`0000;ooooo0_l0000Aooooo`;o00005?ooool3o`000003
ooooool0003o000000;o00005_ooool2o`0002;ooooo0_l00008ooooo`;o00001oooool3o`0006Ko
oooo000Looooo`03o`000?oooooooooo06oooooo0_l0000>ooooo`;o00002_ooool3o`000003oooo
ool0003o000000cooooo0_l000000ooooooo0000o`000007ooooo`;o00001_ooool2o`0000Cooooo
0_l0000Dooooo`;o00002_ooool2o`0006kooooo000Looooo`03o`000?oooooooooo06cooooo1Ol0
0007ooooo`;o00001Oooool2o`0000Cooooo0_l00002ooooo`;o00004_ooool2o`000003ooooool0
003o000000oooooo1?l00002ooooo`;o00003?ooool4o`00013ooooo0_l0001^ooooo`007?ooool0
0ol0003oooooooooo`1Fooooo`;o00004Oooool2o`000003ooooool0003o000000Co00001Oooool3
o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo0ol0000Aooooo`;o00004?ooool2
o`0000;ooooo0_l0000@ooooo`Ko00000oooool2o`0000Sooooo0ol0001^ooooo`007?ooool00ol0
003oooooooooo`1Aooooo`;o00000oooool2o`0000Gooooo0_l00006ooooo`;o00000_ooool2o`00
00Gooooo0_l00005ooooo`;o00000oooool4o`000003ooooool0003o000000Gooooo1?l0000Aoooo
o`;o00004?ooool3o`0000cooooo0_l00005ooooo`;o00000_ooool2o`0000?ooooo0_l00008oooo
o`?o0000K_ooool001cooooo00?o0000ooooooooool0DOooool2o`0000Gooooo0_l00003ooooo`;o
000000?oooooo`000?l000000oooool2o`0001;ooooo0_l00002ooooo`?o00001?ooool2o`0000;o
oooo0_l0000Vooooo`;o00001Oooool2o`000003ooooool0003o000000;ooooo0_l0000>ooooo`?o
00001?ooool2o`0000cooooo0_l00002ooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0
F?ooool2o`0000Kooooo0_l00004ooooo`;o00001oooool2o`0000Sooooo1?l00003ooooo`?o0000
00?oooooo`000?l000006Oooool2o`0001Kooooo0_l000001?oooooo0000o`000?l0000:ooooo`;o
00001Oooool3o`0000;ooooo1?l0000<ooooo`;o00000_ooool2o`00063ooooo000Looooo`03o`00
0?oooooooooo06Kooooo0_l00006ooooo`?o00000oooool2o`0000Cooooo1Ol000001?oooooo0000
o`000?l0000Dooooo`?o00001Oooool2o`0000Kooooo0_l00006ooooo`Co00001Oooool2o`000003
ooooool0003o000000[ooooo0_l00005ooooo`;o000000?oooooo`000?l000000_l0000=ooooo`;o
0000IOooool001cooooo00?o0000ooooooooool0K_ooool2o`0000?ooooo0ol00005ooooo`Co0000
0oooool2o`0001?ooooo0ol00002ooooo`;o00001?ooool2o`0000?ooooo0_l00006ooooo`Co0000
1Oooool2o`000003ooooool0003o000000[ooooo0_l00005ooooo`;o000000?oooooo`000?l00000
3oooool2o`0006Gooooo000Looooo`03o`000?oooooooooo06Wooooo0_l00008ooooo`;o000000?o
ooooo`000?l000000oooool2o`0000;ooooo0_l000000ooooooo0000o`00000Hooooo`;o00001?oo
ool4o`0000Cooooo0_l00003ooooo`;o00005_ooool2o`0000Sooooo0_l000000ooooooo0000o`00
001cooooo`007?ooool00ol0003oooooooooo`1Yooooo`;o00002Oooool4o`0000Oooooo0_l00005
ooooo`;o00004oooool2o`0000Oooooo0_l00004ooooo`Co000000?oooooo`000?l000002oooool2
o`0001Kooooo0_l0001cooooo`007?ooool00ol0003oooooooooo`1]ooooo`Ko000000?oooooo`00
0?l000000ol00005ooooo`;o00001_ooool2o`000003ooooool0003o000000Cooooo0_l0000:oooo
o`;o00003Oooool4o`0000Kooooo0_l00006ooooo`;o00002?ooool4o`0000Oooooo0_l0001foooo
o`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<00Kooooo00?o0000ooooooooool0J_ooool2o`000003ooooool0003o000000Co00000_oo
ool4o`0000Gooooo0_l00004ooooo`;o00000oooool2o`0000Cooooo0_l0000Booooo`;o00003ooo
ool2o`0000Cooooo0ol00002ooooo`?o00001?ooool4o`0000;ooooo0_l00003ooooo`;o0000M_oo
ool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?oooooo
V9RHob4Q8@06ooooo`03o`000?oooooooooo06[ooooo0_l00003ooooo`;o00001oooool2o`0000[o
oooo0_l00009ooooo`;o00004?ooool4o`0001Gooooo0ol00002ooooo`?o00002_ooool2o`0007_o
oooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo06Gooooo0_l00008ooooo`;o00001Oooool5o`0000Oo
oooo0ol00003ooooo`Co00005Oooool2o`0001Gooooo0_l0002?ooooo`0000?oooooo`000?ooool0
0_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`0006Go
oooo0_l0000?ooooo`;o000000?oooooo`000?l000001oooool3o`0000?ooooo1?l000000ooooooo
0000o`00000=ooooo`;o00005?ooool2o`000004ooooool0003o0000ooooo`;o000000Coooooo`00
0?l0003o00002?ooool2o`00087ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00Wooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo07;ooooo0_l00005
ooooo`;o000000?oooooo`000?l000003oooool2o`0000Gooooo0_l00006ooooo`;o00000_ooool2
o`00013ooooo0_l000000ooooooo0000o`000004ooooo`?o00001oooool3o`0000Kooooo0_l0001i
ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooo
okZj^_l@41001_ooool00ol0003oooooooooo`1aooooo`?o00002?ooool2o`0000cooooo0_l00008
ooooo`;o00000_ooool2o`0000Kooooo0_l0000Dooooo`;o00003Oooool2o`0000Oooooo0_l0001i
ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`1aooooo`;o00000_ooool2o`0001?ooooo0_l00003ooooo`;o0000
1oooool2o`0000?ooooo0_l0000Gooooo`;o00005?ooool2o`000003ooooool0003o000007Sooooo
00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06oooo
o`03o`000?oooooooooo06Gooooo0_l0000>ooooo`;o00003?ooool2o`0000[ooooo0_l0000<oooo
o`;o00003Oooool2o`0000Wooooo0_l0000Cooooo`;o000000?oooooo`000?l00000N?ooool001co
oooo00?o0000ooooooooool0IOooool2o`0001cooooo0_l0000Dooooo`;o00000_ooool2o`0000go
oooo0_l00009ooooo`;o0000T?ooool001cooooo00?o0000ooooooooool0Q_ooool2o`0000Sooooo
0_l00007ooooo`;o00003oooool2o`0001;ooooo0_l00029ooooo`007?ooool00ol0003ooooooooo
o`1iooooo`Co00002Oooool2o`0000?ooooo0_l00003ooooo`;o00003Oooool2o`0000Cooooo0_l0
0003ooooo`;o00004_ooool2o`0000Gooooo0_l00022ooooo`007?ooool00ol0003oooooooooo`1i
ooooo`Co00001oooool2o`0000Gooooo0_l00007ooooo`;o00002Oooool2o`0000Cooooo0_l0000C
ooooo`;o00002Oooool2o`0008;ooooo000Looooo`03o`000?oooooooooo07Kooooo0_l00007oooo
o`;o00000oooool2o`0000kooooo0_l00005ooooo`;o00003Oooool2o`000003ooooool0003o0000
00_ooooo0_l0002=ooooo`007?ooool00ol0003oooooooooo`1fooooo`;o00001oooool2o`0000Go
oooo0_l0000Cooooo`;o00002oooool4o`000003ooooool0003o000001Sooooo0_l00020ooooo`00
7?ooool00ol0003oooooooooo`1eooooo`;o00003?ooool2o`000003ooooool0003o000000Sooooo
0_l00003ooooo`;o00004Oooool2o`0001Sooooo0_l00003ooooo`;o0000P?ooool001cooooo00?o
0000ooooooooool0MOooool2o`0000cooooo0_l000000ooooooo0000o`000008ooooo`;o00000ooo
ool2o`0002_ooooo0_l00006ooooo`;o00003?ooool2o`0006oooooo000Looooo`03o`000?oooooo
oooo08Kooooo0_l00012ooooo`;o00003?ooool2o`0006oooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0Moooool2o`0001;ooooo0_l0000[ooooo`;o
0000Soooool001cooooo0_l0001hooooo`;o00004_ooool2o`0002_ooooo1?l0002=ooooo`007?oo
ool00ol0003oooooooooo`2jooooo`;o0000SOooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`1mooooo`;o0000?oooool2o`0008Wooooo000Looooo`03
o`000?oooooooooo07gooooo0_l00007ooooo`;o0000=_ooool2o`0008Wooooo000Looooo`03o`00
0?oooooooooo08Kooooo0_l0000Eooooo`;o00005?ooool2o`0009Cooooo000Looooo`03o`000?oo
oooooooo07oooooo0_l0000Looooo`;o00002Oooool2o`0000Wooooo0_l0002Dooooo`007?ooool0
0ol0003oooooooooo`1oooooo`;o00009oooool2o`0009oooooo000Looooo`03o`000?oooooooooo
08cooooo0_l0002kooooo`007?ooool00ol0003oooooooooo`2<ooooo`;o0000^oooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`32ooooo`;o0000QOoo
ool001cooooo00?o0000ooooooooool0`_ooool2o`0008Gooooo000Looooo`03o`000?oooooooooo
09Wooooo0_l0002^ooooo`007?ooool00ol0003oooooooooo`29ooooo`;o00003_ooool2o`000:ko
oooo000Looooo`03o`000?oooooooooo08Wooooo0_l0002nooooo`007?ooool2o`000?ooooooBooo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001;ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oo
oooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
oooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo0ol0003ooooood[ooooo000Dooooo`03
o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?oo
ool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool0
01;ooooo00?oEEEEofIVI_l00000oooooomDooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00XOooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo01Kooooo1?l0
00000ol@413oooooooooo`05o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`;o0000
00?o410@ooooooooool0R_ooool00:;ooooo00Go0000ooooooooooooooooo`000009ooooo`Ko0000
3?ooool00ol0003oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo08_ooooo002Rooooo`05o`000?ooooooooooooooool0
00006oooool00ol0003oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000oooooooo
ool01Ol0002<ooooo`00X_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l0000<ooooo`03
o`000?oooooooooo00Cooooo00?oV9RHob4Q8Oo^k^h01oooool02?mgMgOo<S8booooooooooooA4A4
omgMgOoooooo0000SOooool00:;ooooo00Go0000ohN7QoooooooZJVYo`00000Kooooo`03o`000?oo
oooooooo00Gooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo
00CogMgMoeEEEOoooooo0000SOooool00:7ooooo00?o410@o`000?mgMgL00_l000000onHV9Sooooo
ooooo`0Iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`05ooooo`03ogMgMoo<c<co000008gooooo0032ooooo`03o`000?oooooooooo00;ooooo00Go
0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Gooooo00?ok^k^odA4A?l00000
SOooool00<3ooooo00?oEEEEofIVI_l000001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo
1?l00005ooooo`03ogMgMol0003ooooo08cooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1260) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.61059 .65871 Mdot
.63516 .64121 Mdot
.50512 .37299 Mdot
.40375 .60651 Mdot
.57787 .209 Mdot
.49196 .34318 Mdot
.6387 .42692 Mdot
.68732 .44524 Mdot
.48134 .37124 Mdot
.75943 .46 Mdot
.67017 .42419 Mdot
.52663 .5971 Mdot
.66793 .44906 Mdot
.42745 .58735 Mdot
.55752 .14577 Mdot
.43914 .54671 Mdot
.62523 .65529 Mdot
.37717 .42832 Mdot
.38051 .61248 Mdot
.51553 .38639 Mdot
.5568 .60778 Mdot
.42609 .59546 Mdot
.62565 .59862 Mdot
.42792 .58675 Mdot
.41332 .63133 Mdot
.59194 .61206 Mdot
.5719 .64691 Mdot
.44096 .63269 Mdot
.45594 .6388 Mdot
.68912 .43941 Mdot
.27527 .51521 Mdot
.54902 .16758 Mdot
.42669 .67375 Mdot
.30158 .27794 Mdot
.65941 .4687 Mdot
.51434 .77138 Mdot
.495 .35558 Mdot
.64912 .44351 Mdot
.64462 .44222 Mdot
.63992 .47339 Mdot
.66184 .43382 Mdot
.61527 .60539 Mdot
.6607 .52089 Mdot
.42976 .33209 Mdot
.44378 .55398 Mdot
.69102 .29516 Mdot
.59152 .79984 Mdot
.47234 .58599 Mdot
.60821 .64862 Mdot
.36197 .28418 Mdot
.60063 .28675 Mdot
.62857 .45798 Mdot
.50363 .39353 Mdot
.18983 .70615 Mdot
.64781 .45957 Mdot
.36813 .63164 Mdot
.4997 .36465 Mdot
.43977 .59781 Mdot
.43199 .58414 Mdot
.45519 .71387 Mdot
.45497 .56501 Mdot
.34619 .39726 Mdot
.66983 .64058 Mdot
.59507 .51019 Mdot
.48283 .36528 Mdot
.65133 .42978 Mdot
.63527 .62793 Mdot
.66411 .45642 Mdot
.38453 .54825 Mdot
.52816 .38132 Mdot
.47509 .58779 Mdot
.66246 .42594 Mdot
.6404 .66066 Mdot
.46716 .61991 Mdot
.37264 .36125 Mdot
.80241 .39095 Mdot
.32397 .45477 Mdot
.50287 .75112 Mdot
.42795 .72141 Mdot
.39557 .29794 Mdot
.39109 .62193 Mdot
.31884 .54696 Mdot
.76877 .35321 Mdot
.61282 .5939 Mdot
.49851 .57755 Mdot
.27724 .40415 Mdot
.46398 .61942 Mdot
.71268 .28832 Mdot
.4875 .61365 Mdot
.29658 .36234 Mdot
.46819 .36583 Mdot
.61494 .63393 Mdot
.40173 .60751 Mdot
.47259 .62281 Mdot
.34766 .70952 Mdot
.40426 .66095 Mdot
.42876 .61418 Mdot
.58842 .63636 Mdot
.63097 .45954 Mdot
.40187 .66757 Mdot
.43732 .32144 Mdot
.45533 .35945 Mdot
.40297 .57135 Mdot
.47993 .32286 Mdot
.66395 .63711 Mdot
.47327 .61823 Mdot
.63999 .4478 Mdot
.41494 .56852 Mdot
.72861 .63114 Mdot
.63987 .64208 Mdot
.44793 .63497 Mdot
.31795 .42117 Mdot
.32779 .74481 Mdot
.61444 .64221 Mdot
.4663 .28432 Mdot
.40551 .64784 Mdot
.43964 .6125 Mdot
.632 .63924 Mdot
.4745 .31578 Mdot
.72883 .30076 Mdot
.57804 .6092 Mdot
.66546 .47351 Mdot
.61297 .66252 Mdot
.44368 .5365 Mdot
.47141 .35515 Mdot
.52825 .25714 Mdot
.69814 .57892 Mdot
.28906 .49063 Mdot
.46286 .61597 Mdot
.72712 .50729 Mdot
.46293 .37465 Mdot
.61885 .62505 Mdot
.67057 .45363 Mdot
.51349 .61104 Mdot
.64965 .62332 Mdot
.68135 .42472 Mdot
.31886 .40841 Mdot
.61875 .34092 Mdot
.65894 .62678 Mdot
.42866 .44083 Mdot
.66841 .41157 Mdot
.6283 .46448 Mdot
.23224 .3484 Mdot
.63182 .62705 Mdot
.33593 .40865 Mdot
.67776 .45261 Mdot
.26715 .47893 Mdot
.43921 .55556 Mdot
.29313 .57349 Mdot
.5914 .81377 Mdot
.28326 .29295 Mdot
.64451 .35141 Mdot
.35301 .43026 Mdot
.69578 .44588 Mdot
.41607 .62327 Mdot
.58688 .62096 Mdot
.60568 .6035 Mdot
.44673 .56339 Mdot
.39969 .62306 Mdot
.48026 .59425 Mdot
.48007 .61688 Mdot
.5662 .67323 Mdot
.39377 .64689 Mdot
.51034 .81703 Mdot
.61057 .63443 Mdot
.40866 .61409 Mdot
.5144 .33325 Mdot
.46161 .65639 Mdot
.66147 .42985 Mdot
.43311 .60037 Mdot
.40345 .60902 Mdot
.44097 .5597 Mdot
.62981 .4612 Mdot
.60599 .17902 Mdot
.37267 .75877 Mdot
.561 .18516 Mdot
.33201 .36452 Mdot
.49675 .32668 Mdot
.45384 .62114 Mdot
.32659 .40511 Mdot
.57366 .75141 Mdot
.40576 .58895 Mdot
.57325 .86663 Mdot
.42551 .60784 Mdot
.58259 .20128 Mdot
.35956 .61378 Mdot
.47013 .17991 Mdot
.30857 .5429 Mdot
.42528 .63033 Mdot
.59289 .53314 Mdot
.60169 .47401 Mdot
.51153 .30527 Mdot
.66309 .43685 Mdot
.51676 .33761 Mdot
.50542 .36919 Mdot
.6394 .51396 Mdot
.53732 .62 Mdot
.37641 .66563 Mdot
.48156 .63068 Mdot
.53217 .38014 Mdot
.66906 .62432 Mdot
.33364 .38898 Mdot
.57977 .63811 Mdot
.77695 .28519 Mdot
.63365 .276 Mdot
.65466 .40838 Mdot
.36296 .39974 Mdot
.4805 .37915 Mdot
.45977 .34513 Mdot
.32672 .43494 Mdot
.45857 .58915 Mdot
.631 .62084 Mdot
.26697 .28772 Mdot
.75571 .61573 Mdot
.21349 .35224 Mdot
.59204 .63852 Mdot
.76275 .50643 Mdot
.68324 .43116 Mdot
.50836 .35028 Mdot
.43655 .61349 Mdot
.45786 .59544 Mdot
.57835 .59387 Mdot
.47941 .59567 Mdot
.53615 .57638 Mdot
.43438 .62165 Mdot
.58289 .30797 Mdot
.34259 .4608 Mdot
.63786 .51335 Mdot
.30159 .4763 Mdot
.59834 .60045 Mdot
.24866 .61618 Mdot
.47278 .32676 Mdot
.56193 .74929 Mdot
.65558 .42368 Mdot
.3285 .39679 Mdot
.46702 .3405 Mdot
.32049 .39617 Mdot
.38311 .63275 Mdot
.52561 .35392 Mdot
.33339 .44213 Mdot
.38916 .69612 Mdot
.47972 .57295 Mdot
.70947 .66969 Mdot
.6514 .47405 Mdot
.56706 .6223 Mdot
.46535 .5703 Mdot
.49683 .32284 Mdot
.49815 .63497 Mdot
.71268 .37191 Mdot
.54992 .27985 Mdot
.45149 .35671 Mdot
.54617 .28989 Mdot
.34743 .39507 Mdot
.68763 .33016 Mdot
.74793 .51408 Mdot
.61953 .65633 Mdot
.40376 .65894 Mdot
.44669 .17648 Mdot
.67696 .45331 Mdot
.42608 .56853 Mdot
.37439 .24316 Mdot
.65955 .46346 Mdot
.44212 .59842 Mdot
.6927 .44069 Mdot
.60788 .60274 Mdot
.328 .72215 Mdot
.61887 .65382 Mdot
.48141 .62345 Mdot
.63829 .45306 Mdot
.5093 .32074 Mdot
.59244 .6172 Mdot
.45784 .58314 Mdot
.44463 .6295 Mdot
.57241 .45462 Mdot
.41513 .61375 Mdot
.60457 .18784 Mdot
.43013 .62649 Mdot
.51518 .36011 Mdot
.39088 .57983 Mdot
.28039 .74958 Mdot
.6841 .50095 Mdot
.63423 .62637 Mdot
.46875 .31634 Mdot
.48979 .37119 Mdot
.42789 .32641 Mdot
.61493 .43053 Mdot
.39517 .6415 Mdot
.49484 .32466 Mdot
.27908 .63022 Mdot
.66868 .41499 Mdot
.42277 .6701 Mdot
.4421 .45278 Mdot
.3457 .29887 Mdot
.50159 .39323 Mdot
.44404 .67614 Mdot
.66134 .62686 Mdot
.39984 .61066 Mdot
.46163 .33497 Mdot
.53317 .64252 Mdot
.42189 .64596 Mdot
.61638 .57757 Mdot
.57392 .45293 Mdot
.64996 .41768 Mdot
.36008 .62845 Mdot
.43865 .56893 Mdot
.51244 .33703 Mdot
.59044 .60553 Mdot
.6724 .41436 Mdot
.6051 .60852 Mdot
.42331 .19885 Mdot
.71215 .64921 Mdot
.42394 .70028 Mdot
.365 .39636 Mdot
.33766 .28519 Mdot
.43893 .18645 Mdot
.2128 .59928 Mdot
.24074 .57446 Mdot
.33061 .23593 Mdot
.48191 .31517 Mdot
.37374 .25056 Mdot
.49703 .36974 Mdot
.40545 .63512 Mdot
.47359 .35672 Mdot
.43203 .18314 Mdot
.43296 .62045 Mdot
.47993 .35432 Mdot
.26707 .64999 Mdot
.40294 .61563 Mdot
.62751 .65065 Mdot
.69649 .23884 Mdot
.23229 .66775 Mdot
.55906 .28888 Mdot
.51894 .37795 Mdot
.2316 .51977 Mdot
.42655 .61542 Mdot
.38836 .58763 Mdot
.59813 .63519 Mdot
.44817 .67119 Mdot
.35962 .40927 Mdot
.36545 .40477 Mdot
.63036 .39822 Mdot
.33761 .54912 Mdot
.3616 .62102 Mdot
.59253 .62167 Mdot
.59682 .68648 Mdot
.34523 .35134 Mdot
.36623 .2767 Mdot
.69381 .41398 Mdot
.69075 .23689 Mdot
.51835 .56321 Mdot
.69408 .47019 Mdot
.52325 .30342 Mdot
.62341 .6446 Mdot
.58798 .17287 Mdot
.65987 .44057 Mdot
.70718 .70836 Mdot
.44983 .4919 Mdot
.45521 .58864 Mdot
.64847 .42327 Mdot
.52076 .63093 Mdot
.2178 .65046 Mdot
.74552 .68962 Mdot
.39066 .50512 Mdot
.48824 .61686 Mdot
.3844 .37247 Mdot
.43537 .60561 Mdot
.74586 .35374 Mdot
.43263 .62899 Mdot
.60246 .61254 Mdot
.75304 .43829 Mdot
.60118 .42761 Mdot
.41237 .7945 Mdot
.71033 .34311 Mdot
.35398 .42968 Mdot
.43864 .61845 Mdot
.45348 .58667 Mdot
.35954 .41568 Mdot
.64359 .60108 Mdot
.48379 .61273 Mdot
.23909 .60025 Mdot
.47407 .61071 Mdot
.65575 .43598 Mdot
.43754 .50551 Mdot
.68767 .62238 Mdot
.46023 .64419 Mdot
.65893 .65305 Mdot
.64174 .41963 Mdot
.64265 .45473 Mdot
.36294 .60193 Mdot
.63995 .47545 Mdot
.41912 .60356 Mdot
.7624 .68061 Mdot
.65839 .63425 Mdot
.57838 .56383 Mdot
.63665 .61041 Mdot
.48725 .74993 Mdot
.64679 .46595 Mdot
.59533 .30048 Mdot
.52231 .6035 Mdot
.66194 .44282 Mdot
.69322 .66595 Mdot
.42457 .54908 Mdot
.48867 .5773 Mdot
.23739 .3837 Mdot
.5141 .37682 Mdot
.5812 .46502 Mdot
.68939 .44279 Mdot
.45164 .5752 Mdot
.42542 .65721 Mdot
.63613 .42466 Mdot
.76036 .65167 Mdot
.25502 .66854 Mdot
.43179 .62393 Mdot
.60485 .61981 Mdot
.61808 .62142 Mdot
.49558 .59712 Mdot
.39507 .5879 Mdot
.47302 .34386 Mdot
.50484 .3159 Mdot
.52965 .36301 Mdot
.57613 .45174 Mdot
.5888 .29918 Mdot
.59058 .23564 Mdot
.63904 .4731 Mdot
.74382 .544 Mdot
.29077 .36683 Mdot
.46493 .64596 Mdot
.49615 .38724 Mdot
.43014 .57132 Mdot
.4112 .60075 Mdot
.63571 .42036 Mdot
.46733 .22959 Mdot
.54486 .60392 Mdot
.64069 .59567 Mdot
.68574 .41602 Mdot
.44253 .5318 Mdot
.72155 .45868 Mdot
.32108 .41016 Mdot
.25565 .34214 Mdot
.65723 .42539 Mdot
.62795 .64888 Mdot
.66702 .46832 Mdot
.46391 .59984 Mdot
.3743 .61088 Mdot
.62597 .63889 Mdot
.3627 .43459 Mdot
.49152 .64112 Mdot
.44336 .60145 Mdot
.5569 .83471 Mdot
.25128 .39516 Mdot
.58408 .32455 Mdot
.42606 .62851 Mdot
.44817 .64896 Mdot
.32069 .44092 Mdot
.47252 .60712 Mdot
.47999 .58564 Mdot
.34466 .7457 Mdot
.71275 .58467 Mdot
.37115 .41595 Mdot
.7683 .66108 Mdot
.59602 .64273 Mdot
.49599 .17005 Mdot
.51126 .34417 Mdot
.68246 .39504 Mdot
.27592 .69745 Mdot
.5068 .39361 Mdot
.64729 .35521 Mdot
.52268 .17091 Mdot
.58252 .46057 Mdot
.53603 .39374 Mdot
.52432 .58246 Mdot
.4818 .61249 Mdot
.44184 .60924 Mdot
.33458 .40058 Mdot
.62823 .61615 Mdot
.57457 .47364 Mdot
.82955 .50897 Mdot
.4264 .5992 Mdot
.54984 .56696 Mdot
.8021 .524 Mdot
.34684 .30193 Mdot
.33761 .42685 Mdot
.36841 .42194 Mdot
.44131 .61645 Mdot
.33867 .75693 Mdot
.59055 .61376 Mdot
.45657 .58211 Mdot
.40156 .6521 Mdot
.51889 .37475 Mdot
.64696 .64151 Mdot
.46774 .32075 Mdot
.61848 .29925 Mdot
.56549 .19078 Mdot
.59188 .8346 Mdot
.64444 .46215 Mdot
.77844 .40069 Mdot
.69033 .42784 Mdot
.32436 .53608 Mdot
.45448 .37117 Mdot
.39667 .60178 Mdot
.59711 .60193 Mdot
.44482 .5732 Mdot
.39415 .59379 Mdot
.45667 .58743 Mdot
.44409 .65474 Mdot
.47176 .86733 Mdot
.34413 .44118 Mdot
.44623 .54078 Mdot
.51378 .36564 Mdot
.74056 .32179 Mdot
.7978 .39295 Mdot
.44843 .585 Mdot
.44254 .62578 Mdot
.65458 .62274 Mdot
.44144 .56415 Mdot
.68347 .42132 Mdot
.57242 .62057 Mdot
.46742 .62646 Mdot
.71268 .26162 Mdot
.45199 .6381 Mdot
.50647 .18068 Mdot
.67637 .46206 Mdot
.73487 .63246 Mdot
.42799 .53935 Mdot
.55958 .29399 Mdot
.58114 .46513 Mdot
.46918 .34232 Mdot
.65838 .47917 Mdot
.49221 .3564 Mdot
.83067 .54364 Mdot
.37214 .59857 Mdot
.41446 .62529 Mdot
.43009 .66345 Mdot
.49861 .3265 Mdot
.68898 .27018 Mdot
.67864 .31439 Mdot
.45739 .53871 Mdot
.49355 .33039 Mdot
.66676 .64349 Mdot
.25335 .4449 Mdot
.62992 .60511 Mdot
.34591 .38379 Mdot
.67333 .42757 Mdot
.36491 .4257 Mdot
.36373 .24114 Mdot
.63691 .64282 Mdot
.5617 .62042 Mdot
.50655 .34364 Mdot
.4652 .48572 Mdot
.13208 .5201 Mdot
.45601 .49134 Mdot
.30368 .51786 Mdot
.59813 .6314 Mdot
.4586 .64002 Mdot
.3547 .50433 Mdot
.50342 .50059 Mdot
.49025 .35816 Mdot
.41073 .5895 Mdot
.31928 .71757 Mdot
.47293 .34366 Mdot
.41444 .66652 Mdot
.5143 .37167 Mdot
.66886 .43238 Mdot
.48753 .38441 Mdot
.61025 .58676 Mdot
.4584 .62657 Mdot
.13663 .46118 Mdot
.34407 .46452 Mdot
.42435 .61942 Mdot
.68806 .41607 Mdot
.63963 .38106 Mdot
.4052 .57873 Mdot
.31419 .41726 Mdot
.48129 .34469 Mdot
.43209 .48451 Mdot
.43219 .62602 Mdot
.50031 .32879 Mdot
.61019 .65922 Mdot
.68207 .46597 Mdot
.38328 .71842 Mdot
.5688 .3135 Mdot
.59743 .6358 Mdot
.42119 .41396 Mdot
.63224 .47806 Mdot
.44809 .64944 Mdot
.40664 .65978 Mdot
.60907 .61894 Mdot
.3161 .65356 Mdot
.40412 .56538 Mdot
.39123 .62033 Mdot
.51866 .35939 Mdot
.48862 .35328 Mdot
.31702 .68575 Mdot
.49072 .31268 Mdot
.37413 .608 Mdot
.60897 .61679 Mdot
.40177 .60431 Mdot
.65557 .63476 Mdot
.43704 .56448 Mdot
.55484 .64604 Mdot
.64121 .59952 Mdot
.69124 .49075 Mdot
.4096 .59452 Mdot
.39052 .67188 Mdot
.41613 .56976 Mdot
.48007 .60547 Mdot
.469 .3497 Mdot
.32793 .42309 Mdot
.38811 .65205 Mdot
.30716 .40855 Mdot
.32198 .39529 Mdot
.60097 .45833 Mdot
.51667 .37684 Mdot
.3452 .40906 Mdot
.80787 .52661 Mdot
.52794 .36564 Mdot
.3482 .40065 Mdot
.79509 .38963 Mdot
.65508 .46929 Mdot
.66095 .632 Mdot
.40204 .61739 Mdot
.37203 .22573 Mdot
.59079 .80214 Mdot
.52084 .31671 Mdot
.42849 .62497 Mdot
.4199 .57152 Mdot
.59039 .60109 Mdot
.84454 .5552 Mdot
.52872 .3797 Mdot
.43219 .64474 Mdot
.63952 .63175 Mdot
.84025 .60659 Mdot
.51047 .36192 Mdot
.34411 .39915 Mdot
.64064 .47083 Mdot
.62879 .58073 Mdot
.69747 .5798 Mdot
.64432 .42134 Mdot
.5489 .33406 Mdot
.59732 .28929 Mdot
.40564 .6485 Mdot
.48877 .38721 Mdot
.21976 .3726 Mdot
.64206 .68824 Mdot
.61934 .50833 Mdot
.22961 .50718 Mdot
.62045 .64328 Mdot
.68718 .42474 Mdot
.35007 .43563 Mdot
.58841 .6338 Mdot
.62945 .65266 Mdot
.62437 .43447 Mdot
.39434 .75185 Mdot
.4416 .4545 Mdot
.64877 .4391 Mdot
.2639 .37016 Mdot
.52357 .23416 Mdot
.49789 .38778 Mdot
.35905 .40903 Mdot
.38382 .23121 Mdot
.61293 .60533 Mdot
.6824 .2279 Mdot
.23626 .3635 Mdot
.4286 .61404 Mdot
.34211 .41211 Mdot
.65841 .25404 Mdot
.84265 .48786 Mdot
.65528 .46377 Mdot
.60086 .41864 Mdot
.36088 .40593 Mdot
.46148 .56868 Mdot
.25702 .46151 Mdot
.3929 .6205 Mdot
.67901 .42958 Mdot
.43975 .71168 Mdot
.63133 .64988 Mdot
.61696 .44913 Mdot
.25341 .34246 Mdot
.41977 .60175 Mdot
.40849 .59329 Mdot
.31485 .47478 Mdot
.57973 .61632 Mdot
.46952 .34162 Mdot
.40313 .64965 Mdot
.43931 .60123 Mdot
.37418 .63446 Mdot
.36325 .64018 Mdot
.32345 .73542 Mdot
.41739 .63846 Mdot
.67716 .30085 Mdot
.48805 .62175 Mdot
.41666 .59036 Mdot
.66081 .65017 Mdot
.5826 .84392 Mdot
.62808 .29599 Mdot
.43527 .60129 Mdot
.44958 .64412 Mdot
.6177 .45567 Mdot
.46797 .47219 Mdot
.45829 .48057 Mdot
.42776 .48219 Mdot
.23676 .54878 Mdot
.49978 .60324 Mdot
.63654 .62191 Mdot
.32832 .44037 Mdot
.42225 .648 Mdot
.63874 .62509 Mdot
.43398 .55695 Mdot
.47474 .34121 Mdot
.52799 .36205 Mdot
.63743 .68249 Mdot
.35039 .41258 Mdot
.50788 .53288 Mdot
.73508 .54561 Mdot
.51979 .34298 Mdot
.41299 .62709 Mdot
.65458 .40578 Mdot
.4611 .33723 Mdot
.52768 .27733 Mdot
.35574 .67982 Mdot
.58598 .61467 Mdot
.61329 .63568 Mdot
.29311 .57998 Mdot
.642 .34155 Mdot
.45877 .82704 Mdot
.6699 .4313 Mdot
.38212 .58291 Mdot
.74264 .50077 Mdot
.61325 .63868 Mdot
.34198 .51323 Mdot
.34572 .41188 Mdot
.66067 .46393 Mdot
.50538 .41799 Mdot
.6514 .62111 Mdot
.63218 .65537 Mdot
.49024 .60469 Mdot
.44789 .59609 Mdot
.24464 .58615 Mdot
.35728 .37725 Mdot
.64763 .41745 Mdot
.35749 .40542 Mdot
.4563 .37273 Mdot
.42163 .64161 Mdot
.6267 .59776 Mdot
.51727 .24062 Mdot
.43109 .64706 Mdot
.46461 .35655 Mdot
.61981 .63918 Mdot
.35057 .39584 Mdot
.31252 .41397 Mdot
.47877 .60785 Mdot
.54619 .679 Mdot
.6513 .44666 Mdot
.62305 .64878 Mdot
.71607 .46618 Mdot
.38972 .58809 Mdot
.45257 .60326 Mdot
.3522 .60157 Mdot
.65058 .41511 Mdot
.77606 .55162 Mdot
.34678 .38712 Mdot
.6268 .62031 Mdot
.42754 .63608 Mdot
.35394 .4068 Mdot
.76543 .52828 Mdot
.45148 .35986 Mdot
.48567 .38306 Mdot
.3132 .42068 Mdot
.33991 .42062 Mdot
.31593 .40952 Mdot
.68297 .22755 Mdot
.61132 .59192 Mdot
.51912 .56547 Mdot
.39174 .57223 Mdot
.30567 .53675 Mdot
.51454 .59413 Mdot
.67166 .4126 Mdot
.51072 .37767 Mdot
.40158 .57854 Mdot
.47324 .63096 Mdot
.37459 .56648 Mdot
.56922 .57042 Mdot
.69163 .63508 Mdot
.64221 .64264 Mdot
.38064 .57532 Mdot
.52185 .36852 Mdot
.78701 .29049 Mdot
.30066 .23175 Mdot
.41672 .5418 Mdot
.42853 .45758 Mdot
.62501 .59658 Mdot
.62394 .46603 Mdot
.31614 .46553 Mdot
.6526 .47099 Mdot
.62521 .62332 Mdot
.41829 .63956 Mdot
.7425 .5524 Mdot
.3144 .4306 Mdot
.46437 .58131 Mdot
.68484 .43695 Mdot
.47186 .58383 Mdot
.64248 .42286 Mdot
.43608 .19442 Mdot
.20931 .45182 Mdot
.42637 .60867 Mdot
.47192 .55523 Mdot
.22237 .52017 Mdot
.44543 .58181 Mdot
.37537 .38808 Mdot
.62625 .59645 Mdot
.34039 .70441 Mdot
.46391 .55771 Mdot
.60801 .70996 Mdot
.38731 .59959 Mdot
.2932 .6815 Mdot
.45435 .60128 Mdot
.33931 .3129 Mdot
.45154 .63251 Mdot
.48343 .59585 Mdot
.6396 .45894 Mdot
.61743 .4512 Mdot
.64107 .66153 Mdot
.49154 .32311 Mdot
.53403 .17953 Mdot
.44684 .60256 Mdot
.54506 .27326 Mdot
.74133 .58215 Mdot
.34003 .42282 Mdot
.62383 .61863 Mdot
.85721 .53351 Mdot
.68698 .45325 Mdot
.23697 .41453 Mdot
.29707 .66766 Mdot
.66937 .54054 Mdot
.27666 .41089 Mdot
.75537 .42026 Mdot
.34283 .39342 Mdot
.43735 .55961 Mdot
.49295 .23504 Mdot
.32897 .32856 Mdot
.3579 .68355 Mdot
.62819 .47835 Mdot
.58055 .73733 Mdot
.48164 .22828 Mdot
.32386 .38699 Mdot
.36537 .412 Mdot
.62655 .4515 Mdot
.48085 .41548 Mdot
.53636 .61505 Mdot
.346 .41566 Mdot
.51638 .3317 Mdot
.52534 .37804 Mdot
.5147 .39368 Mdot
.59545 .60826 Mdot
.25025 .32123 Mdot
.73131 .44247 Mdot
.64909 .41925 Mdot
.46372 .40217 Mdot
.66916 .66377 Mdot
.59351 .59471 Mdot
.50223 .34972 Mdot
.46347 .36626 Mdot
.64724 .60153 Mdot
.36518 .62037 Mdot
.38138 .56296 Mdot
.43013 .60081 Mdot
.32466 .41078 Mdot
.45375 .59644 Mdot
.48771 .33397 Mdot
.65572 .46124 Mdot
.4707 .37269 Mdot
.69561 .4246 Mdot
.61173 .24647 Mdot
.46648 .58972 Mdot
.45456 .62886 Mdot
.62441 .79274 Mdot
.62006 .66148 Mdot
.66066 .28257 Mdot
.57358 .33726 Mdot
.50064 .36983 Mdot
.47757 .58211 Mdot
.57166 .61982 Mdot
.31834 .38657 Mdot
.6482 .78385 Mdot
.39737 .5789 Mdot
.63134 .60101 Mdot
.42764 .63967 Mdot
.54708 .66875 Mdot
.32549 .77874 Mdot
.6112 .60975 Mdot
.59014 .81313 Mdot
.45305 .64099 Mdot
.78816 .4518 Mdot
.43389 .66716 Mdot
.28431 .61691 Mdot
.4038 .56568 Mdot
.59389 .64094 Mdot
.43209 .59748 Mdot
.57316 .62534 Mdot
.51707 .34268 Mdot
.62669 .46691 Mdot
.60336 .63783 Mdot
.41381 .66308 Mdot
.14672 .34093 Mdot
.6786 .43462 Mdot
.438 .61567 Mdot
.63803 .46584 Mdot
.63048 .61381 Mdot
.60895 .64727 Mdot
.83069 .46945 Mdot
.6251 .30226 Mdot
.66867 .43358 Mdot
.42374 .64112 Mdot
.74168 .38989 Mdot
.39569 .61342 Mdot
.2609 .58498 Mdot
.36976 .63635 Mdot
.39153 .57636 Mdot
.80505 .39879 Mdot
.65299 .41569 Mdot
.43832 .82339 Mdot
.83227 .44951 Mdot
.7451 .3258 Mdot
.56524 .59965 Mdot
.32229 .38683 Mdot
.59627 .1752 Mdot
.59272 .3012 Mdot
.49663 .32883 Mdot
.40799 .57327 Mdot
.68467 .63718 Mdot
.64631 .44861 Mdot
.32646 .42513 Mdot
.4274 .60921 Mdot
.4661 .37171 Mdot
.22981 .63325 Mdot
.69758 .43856 Mdot
.61811 .60618 Mdot
.63528 .59312 Mdot
.76328 .70822 Mdot
.42659 .63165 Mdot
.46166 .6268 Mdot
.67555 .42783 Mdot
.79218 .52475 Mdot
.3348 .39178 Mdot
.25765 .64091 Mdot
.66966 .43462 Mdot
.5445 .47046 Mdot
.6358 .63284 Mdot
.42294 .57093 Mdot
.65706 .23673 Mdot
.39071 .36857 Mdot
.67417 .73296 Mdot
.32684 .40547 Mdot
.25908 .57581 Mdot
.59647 .6436 Mdot
.67407 .45297 Mdot
.61186 .35741 Mdot
.49575 .62019 Mdot
.4284 .57304 Mdot
.26298 .57334 Mdot
.59975 .43869 Mdot
.39876 .50331 Mdot
.39391 .58406 Mdot
.58876 .47375 Mdot
.40876 .56641 Mdot
.50607 .60295 Mdot
.37001 .61535 Mdot
.45942 .61145 Mdot
.62918 .5988 Mdot
.36973 .55515 Mdot
.47994 .33286 Mdot
.49381 .53501 Mdot
.54939 .47886 Mdot
.42803 .62103 Mdot
.39763 .63477 Mdot
.6303 .75501 Mdot
.66047 .366 Mdot
.60605 .63688 Mdot
.56533 .60678 Mdot
.64878 .47727 Mdot
.37878 .56407 Mdot
.483 .32464 Mdot
.51079 .60426 Mdot
.46707 .3542 Mdot
.62334 .59842 Mdot
.50501 .36723 Mdot
.63411 .46827 Mdot
.51301 .38463 Mdot
.58817 .29851 Mdot
.68026 .45228 Mdot
.58592 .62224 Mdot
.46916 .61806 Mdot
.68876 .41682 Mdot
.28736 .4787 Mdot
.32559 .40913 Mdot
.83778 .42813 Mdot
.46661 .62785 Mdot
.70995 .58795 Mdot
.50117 .65936 Mdot
.46667 .36933 Mdot
.34419 .78292 Mdot
.6387 .59545 Mdot
.36964 .42779 Mdot
.60041 .59873 Mdot
.24438 .38986 Mdot
.33139 .41831 Mdot
.7918 .37078 Mdot
.56542 .35678 Mdot
.25291 .40874 Mdot
.36693 .59222 Mdot
.27771 .44752 Mdot
.49032 .3918 Mdot
.64601 .45027 Mdot
.62479 .35747 Mdot
.48002 .58748 Mdot
.19815 .54438 Mdot
.66555 .62454 Mdot
.48992 .32437 Mdot
.66702 .45446 Mdot
.67511 .41433 Mdot
.38574 .62154 Mdot
.40326 .27209 Mdot
.44412 .5694 Mdot
.63797 .33012 Mdot
.2419 .55278 Mdot
.57108 .5852 Mdot
.43469 .62111 Mdot
.51349 .33807 Mdot
.42739 .63969 Mdot
.37451 .4135 Mdot
.23662 .32898 Mdot
.47285 .65723 Mdot
.57635 .33759 Mdot
.33658 .46419 Mdot
.62979 .64115 Mdot
.46318 .67696 Mdot
.59317 .31302 Mdot
.42435 .63371 Mdot
.3724 .8519 Mdot
.3509 .40303 Mdot
.48583 .23786 Mdot
.43255 .65689 Mdot
.39062 .63729 Mdot
.59952 .52215 Mdot
.67744 .56663 Mdot
.39227 .37365 Mdot
.43652 .57997 Mdot
.25588 .51586 Mdot
.63252 .43749 Mdot
.43223 .56599 Mdot
.44176 .61133 Mdot
.44259 .77478 Mdot
.68523 .41847 Mdot
.49445 .37416 Mdot
.49055 .39331 Mdot
.50771 .3122 Mdot
.37494 .42085 Mdot
.58424 .42648 Mdot
.32799 .51616 Mdot
.22241 .64422 Mdot
.35583 .446 Mdot
.47592 .62275 Mdot
.39079 .43857 Mdot
.40878 .63874 Mdot
.33999 .43363 Mdot
.68889 .42166 Mdot
.60751 .64037 Mdot
.75625 .49608 Mdot
.52429 .38459 Mdot
.42867 .67133 Mdot
.34373 .39012 Mdot
.58636 .61922 Mdot
.27251 .39306 Mdot
.63142 .63442 Mdot
.66728 .44131 Mdot
.70299 .42456 Mdot
.32988 .43008 Mdot
.6349 .61252 Mdot
.65751 .49074 Mdot
.83923 .50215 Mdot
.37328 .6192 Mdot
.68928 .39028 Mdot
.59748 .65017 Mdot
.5718 .59944 Mdot
.58263 .63431 Mdot
.47746 .59345 Mdot
.42904 .45682 Mdot
.43375 .55252 Mdot
.64987 .41732 Mdot
.51062 .37361 Mdot
.21857 .54407 Mdot
.58156 .25661 Mdot
.4108 .41841 Mdot
.38098 .58147 Mdot
.41977 .59952 Mdot
.44119 .61619 Mdot
.47233 .56178 Mdot
.61456 .33116 Mdot
.44079 .57195 Mdot
.63778 .45781 Mdot
.48064 .34265 Mdot
.43823 .55937 Mdot
.46651 .38866 Mdot
.73248 .32159 Mdot
.35397 .44527 Mdot
.59156 .41637 Mdot
.32422 .19375 Mdot
.58963 .62582 Mdot
.46418 .32144 Mdot
.5005 .33053 Mdot
.31947 .40706 Mdot
.65093 .44209 Mdot
.63246 .6307 Mdot
.27187 .61526 Mdot
.31878 .40102 Mdot
.43484 .59894 Mdot
.40664 .47048 Mdot
.19554 .50569 Mdot
.43371 .56042 Mdot
.40105 .58924 Mdot
.45134 .3727 Mdot
.46261 .24824 Mdot
.16152 .43117 Mdot
.34399 .49361 Mdot
.32877 .42656 Mdot
.352 .44045 Mdot
.65692 .61663 Mdot
.43224 .54881 Mdot
.64828 .41778 Mdot
.41683 .50618 Mdot
.59863 .39409 Mdot
.47805 .51329 Mdot
.67428 .58988 Mdot
.40281 .57333 Mdot
.77498 .63148 Mdot
.41718 .60263 Mdot
.6071 .59329 Mdot
.61486 .601 Mdot
.59767 .62296 Mdot
.64755 .45025 Mdot
.5213 .75834 Mdot
.63698 .45082 Mdot
.30913 .20242 Mdot
.60632 .65033 Mdot
.5703 .37879 Mdot
.51347 .34885 Mdot
.42065 .5396 Mdot
.35266 .39865 Mdot
.68929 .46706 Mdot
.38506 .54778 Mdot
.34256 .76645 Mdot
.48708 .32697 Mdot
.58738 .62616 Mdot
.75919 .42737 Mdot
.37249 .19361 Mdot
.44287 .47879 Mdot
.4449 .53112 Mdot
.29594 .4526 Mdot
.34238 .42582 Mdot
.67256 .73577 Mdot
.35865 .40473 Mdot
.68567 .43945 Mdot
.45169 .62726 Mdot
.46358 .61894 Mdot
.41158 .56475 Mdot
.45726 .58448 Mdot
.6295 .47366 Mdot
.39984 .65794 Mdot
.2803 .74948 Mdot
.52736 .35318 Mdot
.39633 .69836 Mdot
.3506 .39961 Mdot
.64543 .48285 Mdot
.48172 .34095 Mdot
.65341 .36514 Mdot
.30569 .48126 Mdot
.43259 .62466 Mdot
.40381 .57576 Mdot
.23244 .41965 Mdot
.39316 .58528 Mdot
.51522 .58823 Mdot
.49904 .32862 Mdot
.39545 .45386 Mdot
.3603 .43919 Mdot
.35636 .43679 Mdot
.67647 .45835 Mdot
.62423 .59916 Mdot
.34298 .40305 Mdot
.51721 .35358 Mdot
.37967 .58386 Mdot
.41056 .65676 Mdot
.59775 .64982 Mdot
.22631 .37294 Mdot
.33985 .38657 Mdot
.75325 .40213 Mdot
.59407 .60442 Mdot
.58858 .65744 Mdot
.42699 .57334 Mdot
.64248 .5768 Mdot
.63581 .58333 Mdot
.36361 .44401 Mdot
.64673 .48239 Mdot
.32526 .47223 Mdot
.67966 .42462 Mdot
.62292 .60519 Mdot
.42064 .64651 Mdot
.60326 .60284 Mdot
.42748 .62893 Mdot
.43615 .15474 Mdot
.4635 .61256 Mdot
.22185 .6501 Mdot
.28633 .57838 Mdot
.49504 .34154 Mdot
.6756 .37526 Mdot
.50996 .34368 Mdot
.58692 .60826 Mdot
.41191 .64888 Mdot
.35973 .39755 Mdot
.76444 .36026 Mdot
.6773 .65812 Mdot
.46244 .35874 Mdot
.53478 .3544 Mdot
.68998 .43245 Mdot
.41002 .56131 Mdot
.43214 .57252 Mdot
.48195 .35399 Mdot
.57032 .58379 Mdot
.6472 .61752 Mdot
.44269 .62787 Mdot
.41923 .59398 Mdot
.49764 .34242 Mdot
.83782 .51656 Mdot
.66775 .67379 Mdot
.45432 .62192 Mdot
.5134 .25528 Mdot
.66606 .41257 Mdot
.3826 .5678 Mdot
.47746 .55825 Mdot
.34158 .41881 Mdot
.40521 .72972 Mdot
.26438 .30282 Mdot
.69369 .42689 Mdot
.50815 .33108 Mdot
.42762 .63371 Mdot
.51267 .33685 Mdot
.4069 .65713 Mdot
.66434 .55974 Mdot
.4586 .37097 Mdot
.38973 .61845 Mdot
.36454 .63215 Mdot
.57938 .616 Mdot
.40276 .57481 Mdot
.59832 .77665 Mdot
.46484 .33584 Mdot
.38784 .62849 Mdot
.5356 .68026 Mdot
.65091 .4334 Mdot
.36845 .58435 Mdot
.32268 .43176 Mdot
.27217 .61927 Mdot
.71132 .55024 Mdot
.45179 .22773 Mdot
.34914 .44418 Mdot
.46791 .58036 Mdot
.52949 .33815 Mdot
.63069 .43662 Mdot
.23982 .67409 Mdot
.45296 .56604 Mdot
.67997 .43081 Mdot
.6579 .4609 Mdot
.32143 .41053 Mdot
.61729 .81962 Mdot
.44265 .65458 Mdot
.44905 .58658 Mdot
.50119 .78952 Mdot
.61038 .66031 Mdot
.46097 .60326 Mdot
.46956 .63134 Mdot
.63642 .45833 Mdot
.51024 .57462 Mdot
.60849 .73939 Mdot
.27259 .65961 Mdot
.65013 .41334 Mdot
.51834 .51673 Mdot
.50359 .38984 Mdot
.3561 .41329 Mdot
.62416 .63492 Mdot
.34763 .39124 Mdot
.5057 .38457 Mdot
.4708 .62753 Mdot
.66364 .47186 Mdot
.55591 .8004 Mdot
.62623 .4521 Mdot
.42443 .2269 Mdot
.60268 .65576 Mdot
.73019 .49507 Mdot
.42058 .87036 Mdot
.72968 .35908 Mdot
.71472 .41104 Mdot
.33981 .42244 Mdot
.42592 .38662 Mdot
.41857 .59588 Mdot
.66216 .75126 Mdot
.47658 .61304 Mdot
.51873 .68542 Mdot
.52178 .34158 Mdot
.52978 .36251 Mdot
.45234 .625 Mdot
.24544 .56276 Mdot
.62895 .43848 Mdot
.66499 .41507 Mdot
.38739 .61653 Mdot
.6622 .4423 Mdot
.44524 .59252 Mdot
.47664 .34193 Mdot
.44145 .83269 Mdot
.43039 .60534 Mdot
.48891 .57391 Mdot
.67107 .556 Mdot
.8176 .41701 Mdot
.34564 .27202 Mdot
.80346 .63577 Mdot
.34478 .20884 Mdot
.66199 .4436 Mdot
.41099 .55382 Mdot
.51846 .5179 Mdot
.48253 .3938 Mdot
.68723 .47483 Mdot
.47039 .60884 Mdot
.4735 .60678 Mdot
.48468 .59836 Mdot
.40604 .59532 Mdot
.68676 .7296 Mdot
.40782 .52227 Mdot
.48137 .7246 Mdot
.39553 .58945 Mdot
.27803 .45623 Mdot
.68179 .4546 Mdot
.60229 .58376 Mdot
.34903 .45174 Mdot
.40339 .57303 Mdot
.48305 .53594 Mdot
.61491 .45485 Mdot
.30589 .20366 Mdot
.68721 .44328 Mdot
.48944 .37071 Mdot
.62321 .46065 Mdot
.41602 .61493 Mdot
.61754 .62143 Mdot
.53023 .49948 Mdot
.68162 .32567 Mdot
.4955 .32867 Mdot
.42465 .61972 Mdot
.57292 .37052 Mdot
.48346 .33054 Mdot
.72855 .31302 Mdot
.6185 .62847 Mdot
.26015 .5146 Mdot
.60942 .60109 Mdot
.38936 .62502 Mdot
.39106 .62997 Mdot
.70468 .40841 Mdot
.627 .4648 Mdot
.61225 .60048 Mdot
.6222 .82394 Mdot
.32079 .39468 Mdot
.59676 .61878 Mdot
.49059 .63378 Mdot
.48555 .45427 Mdot
.61239 .62219 Mdot
.31848 .4606 Mdot
.64856 .46162 Mdot
.64379 .65652 Mdot
.48358 .63506 Mdot
.26473 .35247 Mdot
.32599 .43987 Mdot
.4473 .36385 Mdot
.37305 .47646 Mdot
.46368 .33425 Mdot
.65394 .4805 Mdot
.50819 .34232 Mdot
.63284 .43871 Mdot
.72426 .57019 Mdot
.51008 .54391 Mdot
.67184 .40003 Mdot
.64547 .48016 Mdot
.50588 .34383 Mdot
.44468 .63132 Mdot
.30899 .4575 Mdot
.39873 .55829 Mdot
.45147 .65269 Mdot
.64181 .42889 Mdot
.5895 .63433 Mdot
.59839 .58764 Mdot
.26211 .45943 Mdot
.64081 .60229 Mdot
.46488 .35835 Mdot
.29848 .75206 Mdot
.54106 .26574 Mdot
.66468 .42268 Mdot
.62189 .46291 Mdot
.394 .62085 Mdot
.49177 .35695 Mdot
.51074 .32885 Mdot
.68822 .43123 Mdot
.57401 .55773 Mdot
.45882 .54984 Mdot
.58148 .59679 Mdot
.62458 .65898 Mdot
.60917 .61276 Mdot
.58057 .63338 Mdot
.64114 .71939 Mdot
.65653 .46658 Mdot
.58425 .62777 Mdot
.39025 .61144 Mdot
.47191 .60691 Mdot
.46896 .49288 Mdot
.35095 .43904 Mdot
.44577 .55959 Mdot
.36887 .61171 Mdot
.42036 .57262 Mdot
.48235 .38326 Mdot
.34661 .64944 Mdot
.45812 .36781 Mdot
.52538 .3356 Mdot
.52028 .33205 Mdot
.59094 .30071 Mdot
.22998 .45166 Mdot
.35561 .21986 Mdot
.43362 .64476 Mdot
.79374 .55142 Mdot
.50378 .35848 Mdot
.34176 .77285 Mdot
.77765 .54877 Mdot
.46849 .5745 Mdot
.376 .35736 Mdot
.48489 .35149 Mdot
.63759 .59644 Mdot
.46829 .61018 Mdot
.49657 .30896 Mdot
.32145 .43159 Mdot
.38197 .60421 Mdot
.45507 .36756 Mdot
.63481 .61469 Mdot
.36106 .44811 Mdot
.63238 .6608 Mdot
.52083 .33415 Mdot
.36141 .61414 Mdot
.13817 .59709 Mdot
.53588 .34961 Mdot
.81102 .49193 Mdot
.5524 .6518 Mdot
.44371 .62923 Mdot
.46143 .32785 Mdot
.60843 .66267 Mdot
.6684 .47496 Mdot
.55407 .41689 Mdot
.6483 .64893 Mdot
.52978 .36434 Mdot
.45847 .35074 Mdot
.49758 .3282 Mdot
.6397 .64604 Mdot
.4953 .59108 Mdot
.65226 .63992 Mdot
.62302 .45851 Mdot
.39951 .61421 Mdot
.44138 .1858 Mdot
.78822 .56361 Mdot
.60289 .60109 Mdot
.49229 .37669 Mdot
.31819 .43757 Mdot
.4211 .60723 Mdot
.79059 .57298 Mdot
.43828 .63458 Mdot
.64508 .42344 Mdot
.34847 .74173 Mdot
.59236 .79141 Mdot
.39367 .57133 Mdot
.39405 .61911 Mdot
.66063 .41628 Mdot
.42832 .61552 Mdot
.40535 .56436 Mdot
.59946 .30372 Mdot
.64722 .63856 Mdot
.42858 .59624 Mdot
.51675 .36676 Mdot
.58463 .27925 Mdot
.4633 .55369 Mdot
.45637 .28979 Mdot
.25865 .53416 Mdot
.35993 .74747 Mdot
.47638 .6145 Mdot
.39017 .4922 Mdot
.4115 .58731 Mdot
.46458 .58341 Mdot
.40359 .63315 Mdot
.70894 .72548 Mdot
.46148 .3744 Mdot
.49629 .33353 Mdot
.33959 .44596 Mdot
.25822 .53 Mdot
.34216 .41448 Mdot
.64788 .46301 Mdot
.4146 .28233 Mdot
.45843 .36862 Mdot
.63105 .60734 Mdot
.459 .5766 Mdot
.53506 .34656 Mdot
.42746 .57031 Mdot
.41584 .61681 Mdot
.47979 .32284 Mdot
.48851 .38958 Mdot
.47577 .23388 Mdot
.33802 .4437 Mdot
.59996 .62845 Mdot
.42336 .55533 Mdot
.33769 .38917 Mdot
.46792 .63708 Mdot
.30702 .53795 Mdot
.6008 .62544 Mdot
.64948 .63894 Mdot
.61151 .58446 Mdot
.46911 .62866 Mdot
.41933 .61267 Mdot
.63631 .44901 Mdot
.60664 .59797 Mdot
.65363 .43305 Mdot
.56783 .46048 Mdot
.41953 .34122 Mdot
.47052 .60877 Mdot
.75236 .43108 Mdot
.35388 .4223 Mdot
.47242 .36934 Mdot
.20206 .50578 Mdot
.33739 .44579 Mdot
.43001 .62925 Mdot
.50426 .32301 Mdot
.34263 .43547 Mdot
.36778 .69949 Mdot
.25951 .27405 Mdot
.32705 .44628 Mdot
.39006 .61032 Mdot
.47476 .54161 Mdot
.79547 .6492 Mdot
.34485 .44783 Mdot
.64441 .47184 Mdot
.46856 .62861 Mdot
.67205 .61289 Mdot
.34997 .39129 Mdot
.68217 .30539 Mdot
.48199 .34601 Mdot
.26712 .32691 Mdot
.35491 .57665 Mdot
.61491 .78979 Mdot
.35907 .42696 Mdot
.62981 .62679 Mdot
.53327 .64178 Mdot
.42112 .5766 Mdot
.34185 .44755 Mdot
.63007 .42376 Mdot
.47275 .35369 Mdot
.62409 .29634 Mdot
.63914 .6472 Mdot
.73416 .46435 Mdot
.49405 .3795 Mdot
.75049 .39716 Mdot
.30954 .69924 Mdot
.38086 .56547 Mdot
.78448 .65522 Mdot
.58466 .39131 Mdot
.48955 .5972 Mdot
.30997 .4241 Mdot
.69266 .42184 Mdot
.65881 .47452 Mdot
.67061 .43854 Mdot
.73609 .57807 Mdot
.428 .48106 Mdot
.46357 .32106 Mdot
.72164 .43872 Mdot
.35483 .4126 Mdot
.3141 .47066 Mdot
.42168 .6642 Mdot
.42175 .60013 Mdot
.4032 .56296 Mdot
.41034 .5676 Mdot
.41895 .58385 Mdot
.65663 .43892 Mdot
.71382 .57349 Mdot
.44439 .4862 Mdot
.60593 .62299 Mdot
.44114 .25749 Mdot
.51255 .35111 Mdot
.46257 .32106 Mdot
.33659 .43815 Mdot
.74672 .35959 Mdot
.46405 .38686 Mdot
.50405 .36892 Mdot
.48188 .57909 Mdot
.65194 .62367 Mdot
.49628 .56402 Mdot
.39204 .61527 Mdot
.46673 .35901 Mdot
.58348 .50815 Mdot
.61988 .74885 Mdot
.35009 .66508 Mdot
.30455 .43781 Mdot
.44518 .4641 Mdot
.32334 .44067 Mdot
.41585 .65047 Mdot
.34949 .78162 Mdot
.50373 .38537 Mdot
.48817 .36488 Mdot
.3562 .42791 Mdot
.68199 .60584 Mdot
.62263 .64194 Mdot
.71474 .40134 Mdot
.63234 .46136 Mdot
.40365 .64407 Mdot
.2277 .62152 Mdot
.46019 .68472 Mdot
.39284 .2795 Mdot
.67324 .43423 Mdot
.51592 .34218 Mdot
.38586 .57554 Mdot
.39168 .60603 Mdot
.35337 .4262 Mdot
.53947 .20967 Mdot
.3729 .5976 Mdot
.73551 .29337 Mdot
.20923 .45085 Mdot
.24047 .36662 Mdot
.42881 .57312 Mdot
.64577 .64058 Mdot
.45468 .37435 Mdot
.35939 .41061 Mdot
.47588 .64829 Mdot
.29304 .24793 Mdot
.60616 .65332 Mdot
.68063 .44764 Mdot
.54771 .4929 Mdot
.3436 .47764 Mdot
.48178 .61536 Mdot
.47455 .61462 Mdot
.47291 .59219 Mdot
.21632 .32149 Mdot
.47061 .3783 Mdot
.6206 .59635 Mdot
.32216 .41688 Mdot
.63822 .60358 Mdot
.4999 .33761 Mdot
.72711 .48205 Mdot
.44597 .63368 Mdot
.60761 .65476 Mdot
.62911 .62828 Mdot
.68819 .43958 Mdot
.67926 .4681 Mdot
.55875 .4818 Mdot
.4622 .61102 Mdot
.53763 .3625 Mdot
.58049 .62205 Mdot
.40855 .47202 Mdot
.3327 .41791 Mdot
.64331 .46189 Mdot
.39822 .58302 Mdot
.48124 .38548 Mdot
.41287 .66744 Mdot
.61111 .63619 Mdot
.50403 .36825 Mdot
.50753 .24483 Mdot
.35529 .44262 Mdot
.46403 .59613 Mdot
.3784 .40514 Mdot
.50762 .32985 Mdot
.4167 .59529 Mdot
.77489 .412 Mdot
.32925 .46247 Mdot
.66977 .30898 Mdot
.51508 .32712 Mdot
.55505 .28637 Mdot
.65722 .62072 Mdot
.74936 .59443 Mdot
.487 .36742 Mdot
.75797 .41282 Mdot
.5461 .22743 Mdot
.3861 .57164 Mdot
.60997 .60649 Mdot
.58139 .39776 Mdot
.48866 .16522 Mdot
.82632 .5373 Mdot
.43899 .61469 Mdot
.49046 .3124 Mdot
.35031 .43002 Mdot
.6611 .42198 Mdot
.44764 .2953 Mdot
.32198 .45913 Mdot
.53059 .37682 Mdot
.40465 .63398 Mdot
.63134 .61968 Mdot
.64908 .4572 Mdot
.71547 .555 Mdot
.51806 .35855 Mdot
.50661 .37661 Mdot
.38723 .57462 Mdot
.34666 .41187 Mdot
.77411 .60083 Mdot
.48091 .33757 Mdot
.22005 .44057 Mdot
.54384 .37265 Mdot
.32762 .38997 Mdot
.40627 .58707 Mdot
.25892 .45271 Mdot
.44979 .55225 Mdot
.80431 .43514 Mdot
.50886 .34818 Mdot
.60661 .63162 Mdot
.48092 .59666 Mdot
.2847 .66239 Mdot
.46759 .36215 Mdot
.4315 .45951 Mdot
.33606 .30634 Mdot
.65202 .46505 Mdot
.20126 .50906 Mdot
.45641 .59597 Mdot
.62913 .43869 Mdot
.35227 .42315 Mdot
.45786 .61749 Mdot
.41658 .61162 Mdot
.58391 .60541 Mdot
.68698 .43394 Mdot
.50694 .22152 Mdot
.61646 .45206 Mdot
.67041 .46664 Mdot
.57464 .60845 Mdot
.43493 .58752 Mdot
.49084 .37179 Mdot
.48491 .3532 Mdot
.451 .65975 Mdot
.39459 .82566 Mdot
.62375 .64472 Mdot
.44313 .35677 Mdot
.20872 .33912 Mdot
.38411 .66507 Mdot
.20476 .53031 Mdot
.55291 .20996 Mdot
.65958 .41152 Mdot
.38916 .60678 Mdot
.63253 .61329 Mdot
.45629 .4212 Mdot
.50234 .37684 Mdot
.48694 .62 Mdot
.6526 .45598 Mdot
.3234 .43569 Mdot
.46994 .33466 Mdot
.40243 .27419 Mdot
.4633 .58679 Mdot
.36698 .35558 Mdot
.47639 .31616 Mdot
.61801 .18012 Mdot
.63942 .36762 Mdot
.60441 .60845 Mdot
.41285 .6165 Mdot
.64152 .5966 Mdot
.32327 .42194 Mdot
.54768 .49067 Mdot
.65355 .45923 Mdot
.37311 .54092 Mdot
.24935 .73096 Mdot
.50008 .32789 Mdot
.62383 .59564 Mdot
.39176 .57345 Mdot
.65353 .55917 Mdot
.45046 .59191 Mdot
.52105 .58539 Mdot
.38662 .45502 Mdot
.647 .42739 Mdot
.62944 .44307 Mdot
.41005 .60019 Mdot
.32418 .39638 Mdot
.51574 .35271 Mdot
.47076 .35886 Mdot
.75195 .27093 Mdot
.64212 .52252 Mdot
.24845 .5935 Mdot
.4721 .60387 Mdot
.53291 .36555 Mdot
.58471 .2633 Mdot
.67506 .4281 Mdot
.43217 .6687 Mdot
.48362 .3249 Mdot
.28277 .35331 Mdot
.29046 .64312 Mdot
.41609 .58183 Mdot
.49863 .58809 Mdot
.63551 .46476 Mdot
.40852 .48834 Mdot
.52542 .35345 Mdot
.37481 .64688 Mdot
.68818 .39967 Mdot
.32137 .67635 Mdot
.22018 .36409 Mdot
.59959 .62827 Mdot
.38974 .26543 Mdot
.65571 .43909 Mdot
.49964 .58579 Mdot
.34043 .39471 Mdot
.46535 .38431 Mdot
.47178 .38072 Mdot
.41799 .63596 Mdot
.38442 .63336 Mdot
.2157 .50837 Mdot
.6415 .60919 Mdot
.67913 .45723 Mdot
.46405 .62451 Mdot
.76347 .48319 Mdot
.40875 .56581 Mdot
.6387 .44325 Mdot
.13301 .59995 Mdot
.39731 .56145 Mdot
.4483 .58843 Mdot
.78473 .58662 Mdot
.64148 .65237 Mdot
.62267 .59401 Mdot
.19948 .57485 Mdot
.47161 .60325 Mdot
.20593 .4801 Mdot
.60094 .63295 Mdot
.61932 .64222 Mdot
.61883 .30884 Mdot
.42273 .6051 Mdot
.3478 .56541 Mdot
.64554 .42148 Mdot
.6625 .47034 Mdot
.64718 .64534 Mdot
.37933 .57443 Mdot
.6954 .43395 Mdot
.72623 .68745 Mdot
.49349 .35631 Mdot
.36368 .79242 Mdot
.62111 .64889 Mdot
.59471 .43627 Mdot
.67362 .4302 Mdot
.31348 .20066 Mdot
.55457 .34425 Mdot
.44772 .63102 Mdot
.46731 .59592 Mdot
.35577 .41921 Mdot
.40909 .55746 Mdot
.52984 .35983 Mdot
.66235 .4417 Mdot
.48007 .69403 Mdot
.5971 .62255 Mdot
.45509 .60329 Mdot
.74104 .3441 Mdot
.67311 .28365 Mdot
.39104 .25494 Mdot
.6295 .64012 Mdot
.59842 .60751 Mdot
.52343 .36331 Mdot
.48916 .31282 Mdot
.42925 .58082 Mdot
.66942 .41677 Mdot
.60593 .5985 Mdot
.6388 .43754 Mdot
.50239 .38534 Mdot
.49632 .37215 Mdot
.46882 .38158 Mdot
.40203 .66302 Mdot
.51066 .36819 Mdot
.46485 .27066 Mdot
.73315 .45926 Mdot
.58909 .59673 Mdot
.18652 .45576 Mdot
.72257 .55596 Mdot
.69155 .66384 Mdot
.35172 .39044 Mdot
.50666 .32836 Mdot
.62125 .45148 Mdot
.4006 .60387 Mdot
.41368 .57126 Mdot
.51904 .27389 Mdot
.62585 .43783 Mdot
.32544 .42463 Mdot
.62692 .44468 Mdot
.32129 .41049 Mdot
.33378 .33738 Mdot
.41881 .55928 Mdot
.40725 .65491 Mdot
.66145 .43696 Mdot
.5081 .36774 Mdot
.4884 .33818 Mdot
.33536 .44928 Mdot
.61491 .50816 Mdot
.4835 .32992 Mdot
.61554 .64518 Mdot
.65588 .71125 Mdot
.45784 .35191 Mdot
.46606 .60763 Mdot
.32915 .51943 Mdot
.64376 .77271 Mdot
.47305 .56228 Mdot
.61105 .30656 Mdot
.54019 .81331 Mdot
.4731 .58139 Mdot
.60858 .80652 Mdot
.57003 .31884 Mdot
.65562 .61993 Mdot
.52304 .34502 Mdot
.45238 .3815 Mdot
.43667 .67747 Mdot
.33256 .45496 Mdot
.46622 .65339 Mdot
.62212 .65204 Mdot
.66752 .6342 Mdot
.2483 .37608 Mdot
.81313 .47613 Mdot
.34718 .43195 Mdot
.34555 .43729 Mdot
.48334 .36689 Mdot
.85027 .44671 Mdot
.4026 .53733 Mdot
.32781 .42699 Mdot
.52212 .55072 Mdot
.40829 .63533 Mdot
.27335 .57302 Mdot
.34791 .36745 Mdot
.64469 .64427 Mdot
.2697 .44611 Mdot
.48014 .37025 Mdot
.64327 .60363 Mdot
.75875 .50316 Mdot
.45791 .56212 Mdot
.60009 .62404 Mdot
.6365 .44218 Mdot
.66242 .35449 Mdot
.60689 .64545 Mdot
.319 .52741 Mdot
.68696 .42621 Mdot
.41492 .46895 Mdot
.25883 .48137 Mdot
.6543 .85273 Mdot
.65743 .44165 Mdot
.45991 .35597 Mdot
.48376 .35329 Mdot
.47153 .36006 Mdot
.64191 .6063 Mdot
.51056 .32926 Mdot
.63772 .60694 Mdot
.80687 .59955 Mdot
.67523 .59233 Mdot
.32996 .42841 Mdot
.63108 .29993 Mdot
.62415 .61231 Mdot
.32516 .77201 Mdot
.34415 .82152 Mdot
.38869 .60696 Mdot
.61997 .46469 Mdot
.33621 .43154 Mdot
.74632 .30106 Mdot
.34402 .42125 Mdot
.24484 .42378 Mdot
.35493 .75882 Mdot
.44741 .59845 Mdot
.5631 .75544 Mdot
.36677 .4213 Mdot
.63587 .6347 Mdot
.41673 .59718 Mdot
.51827 .42551 Mdot
.34675 .41881 Mdot
.31733 .41976 Mdot
.42713 .58763 Mdot
.58708 .62579 Mdot
.48442 .37399 Mdot
.63428 .47094 Mdot
.36898 .40777 Mdot
.55045 .63614 Mdot
.47287 .56489 Mdot
.43347 .63847 Mdot
.47299 .48939 Mdot
.34439 .37691 Mdot
.66136 .44435 Mdot
.67449 .7656 Mdot
.5101 .32242 Mdot
.53506 .41721 Mdot
.22338 .4247 Mdot
.59403 .30985 Mdot
.50643 .34846 Mdot
.50982 .33592 Mdot
.42117 .58141 Mdot
.32854 .37566 Mdot
.36436 .76345 Mdot
.64322 .49859 Mdot
.45427 .37133 Mdot
.4709 .35553 Mdot
.65975 .61061 Mdot
.24177 .38374 Mdot
.48045 .64545 Mdot
.69446 .42764 Mdot
.47496 .38349 Mdot
.68603 .58487 Mdot
.34943 .41061 Mdot
.32413 .7541 Mdot
.42444 .5587 Mdot
.45293 .62921 Mdot
.66542 .45204 Mdot
.63747 .45256 Mdot
.45086 .42043 Mdot
.24223 .39784 Mdot
.55794 .80889 Mdot
.69504 .55327 Mdot
.39963 .74487 Mdot
.66537 .61974 Mdot
.60199 .6014 Mdot
.70324 .33598 Mdot
.61577 .45381 Mdot
.47731 .58737 Mdot
.62104 .59911 Mdot
.55254 .40027 Mdot
.67382 .68403 Mdot
.25742 .58145 Mdot
.21392 .53811 Mdot
.42684 .6269 Mdot
.64872 .62979 Mdot
.63922 .65259 Mdot
.57452 .63839 Mdot
.57238 .34409 Mdot
.43711 .58008 Mdot
.43279 .62123 Mdot
.45495 .57106 Mdot
.6076 .56087 Mdot
.45033 .5772 Mdot
.74298 .59553 Mdot
.53614 .47581 Mdot
.41431 .7246 Mdot
.37253 .63843 Mdot
.67805 .40812 Mdot
.47941 .61817 Mdot
.32268 .39852 Mdot
.39902 .63299 Mdot
.25921 .5885 Mdot
.68221 .43669 Mdot
.66916 .67451 Mdot
.72614 .56568 Mdot
.48587 .59292 Mdot
.36781 .43905 Mdot
.61885 .38845 Mdot
.42562 .191 Mdot
.38274 .42663 Mdot
.61683 .64604 Mdot
.49903 .35401 Mdot
.62125 .44822 Mdot
.49569 .36913 Mdot
.39232 .65398 Mdot
.71182 .34767 Mdot
.67376 .26691 Mdot
.57473 .4655 Mdot
.40897 .56909 Mdot
.34682 .60925 Mdot
.61468 .6413 Mdot
.50222 .32155 Mdot
.6706 .60234 Mdot
.47928 .59739 Mdot
.32457 .40932 Mdot
.35116 .41968 Mdot
.55864 .41084 Mdot
.59739 .19598 Mdot
.71725 .64943 Mdot
.66421 .45046 Mdot
.47511 .34164 Mdot
.35773 .40228 Mdot
.79019 .46824 Mdot
.67961 .46847 Mdot
.65728 .41617 Mdot
.68424 .44421 Mdot
.45718 .63975 Mdot
.45819 .37102 Mdot
.41771 .72307 Mdot
.53105 .36799 Mdot
.42562 .61668 Mdot
.47721 .38084 Mdot
.48662 .32543 Mdot
.35336 .40235 Mdot
.68345 .45041 Mdot
.51607 .37951 Mdot
.38958 .62819 Mdot
.59408 .63008 Mdot
.6113 .41864 Mdot
.29012 .60747 Mdot
.80915 .4619 Mdot
.50622 .67588 Mdot
.62395 .65751 Mdot
.48696 .17054 Mdot
.66186 .41293 Mdot
.5835 .55718 Mdot
.46701 .23814 Mdot
.42729 .64791 Mdot
.35522 .81147 Mdot
.45917 .3254 Mdot
.4773 .32666 Mdot
.40679 .58847 Mdot
.4891 .41602 Mdot
.4523 .59905 Mdot
.49933 .38286 Mdot
.50391 .26269 Mdot
.54173 .61318 Mdot
.51061 .36244 Mdot
.37871 .65276 Mdot
.41411 .60653 Mdot
.64778 .64196 Mdot
.46194 .32843 Mdot
.43601 .66931 Mdot
.73139 .25417 Mdot
.63958 .44922 Mdot
.57927 .36492 Mdot
.33136 .52908 Mdot
.65468 .43855 Mdot
.59878 .61665 Mdot
.4431 .65707 Mdot
.3525 .42509 Mdot
.62613 .6121 Mdot
.29404 .65578 Mdot
.36143 .43455 Mdot
.33244 .78666 Mdot
.63809 .65116 Mdot
.45949 .34583 Mdot
.33523 .39404 Mdot
.42017 .55265 Mdot
.46411 .38316 Mdot
.67022 .37082 Mdot
.50727 .35012 Mdot
.43392 .57285 Mdot
.63203 .28782 Mdot
.67513 .46169 Mdot
.44219 .6146 Mdot
.47329 .32724 Mdot
.60036 .30086 Mdot
.45176 .64218 Mdot
.41072 .59346 Mdot
.22337 .37751 Mdot
.27503 .71302 Mdot
.33739 .42069 Mdot
.58719 .65162 Mdot
.3902 .6119 Mdot
.31955 .42491 Mdot
.38939 .33338 Mdot
.46011 .63292 Mdot
.60192 .65189 Mdot
.36534 .65185 Mdot
.46732 .32187 Mdot
.64873 .43805 Mdot
.57776 .45581 Mdot
.32157 .4316 Mdot
.79798 .69136 Mdot
.51712 .38377 Mdot
.41628 .65519 Mdot
.40062 .57397 Mdot
.32294 .28122 Mdot
.65444 .61806 Mdot
.46353 .81086 Mdot
.46427 .59609 Mdot
.59756 .56165 Mdot
.45595 .61473 Mdot
.4476 .34522 Mdot
.62192 .64261 Mdot
.44764 .5842 Mdot
.746 .44418 Mdot
.48083 .56586 Mdot
.3418 .44526 Mdot
.78887 .58602 Mdot
.48257 .57615 Mdot
.19385 .68792 Mdot
.31068 .36622 Mdot
.5124 .36239 Mdot
.66891 .29123 Mdot
.82172 .32798 Mdot
.73782 .57366 Mdot
.63339 .60245 Mdot
.59247 .22181 Mdot
.49177 .37211 Mdot
.62618 .26928 Mdot
.47942 .16784 Mdot
.4095 .60852 Mdot
.48207 .61503 Mdot
.27097 .39027 Mdot
.52367 .33586 Mdot
.53456 .37722 Mdot
.37568 .61019 Mdot
.50416 .59508 Mdot
.50361 .37332 Mdot
.39026 .63624 Mdot
.38085 .63618 Mdot
.6298 .4713 Mdot
.61357 .65317 Mdot
.65158 .42311 Mdot
.69068 .42619 Mdot
.74965 .6586 Mdot
.29946 .36214 Mdot
.64039 .44312 Mdot
.6816 .41312 Mdot
.27361 .57816 Mdot
.23027 .50666 Mdot
.35116 .39187 Mdot
.64014 .20342 Mdot
.47313 .35671 Mdot
.4384 .58387 Mdot
.63081 .65633 Mdot
.57286 .8022 Mdot
.42867 .3038 Mdot
.38144 .78791 Mdot
.47846 .59196 Mdot
.4711 .36574 Mdot
.57256 .34399 Mdot
.50666 .57538 Mdot
.51812 .31681 Mdot
.46698 .62381 Mdot
.52626 .38291 Mdot
.59547 .71549 Mdot
.75501 .41013 Mdot
.54036 .37443 Mdot
.58004 .5983 Mdot
.4594 .62457 Mdot
.62449 .6507 Mdot
.66948 .42844 Mdot
.34022 .39155 Mdot
.33587 .41743 Mdot
.42031 .59244 Mdot
.36242 .59535 Mdot
.34382 .34473 Mdot
.41986 .6074 Mdot
.40395 .63088 Mdot
.56979 .31764 Mdot
.39997 .62852 Mdot
.42171 .56579 Mdot
.44109 .5678 Mdot
.48428 .62529 Mdot
.66625 .46876 Mdot
.74394 .35605 Mdot
.50563 .62897 Mdot
.51186 .61724 Mdot
.6798 .46564 Mdot
.51974 .21481 Mdot
.68271 .41831 Mdot
.4313 .18333 Mdot
.63894 .42865 Mdot
.32947 .41821 Mdot
.38242 .23737 Mdot
.36772 .5693 Mdot
.58084 .62768 Mdot
.67013 .47778 Mdot
.32086 .41696 Mdot
.66703 .4398 Mdot
.48916 .38063 Mdot
.22653 .33277 Mdot
.58995 .66103 Mdot
.42436 .50437 Mdot
.66899 .48283 Mdot
.71823 .36439 Mdot
.52201 .3768 Mdot
.62929 .64815 Mdot
.60744 .75357 Mdot
.41369 .56567 Mdot
.3186 .42097 Mdot
.42665 .58307 Mdot
.68564 .45132 Mdot
.47681 .36744 Mdot
.81771 .54705 Mdot
.35346 .42576 Mdot
.19586 .43752 Mdot
.48586 .34298 Mdot
.43968 .56495 Mdot
.6945 .43044 Mdot
.17794 .51823 Mdot
.64753 .42545 Mdot
.41598 .78253 Mdot
.65324 .60738 Mdot
.81337 .62376 Mdot
.61906 .60785 Mdot
.68881 .37294 Mdot
.14869 .45602 Mdot
.75395 .35671 Mdot
.58867 .62636 Mdot
.67319 .50461 Mdot
.42739 .63205 Mdot
.43494 .63805 Mdot
.7973 .47427 Mdot
.58767 .65148 Mdot
.39264 .59439 Mdot
.53374 .26202 Mdot
.71776 .4779 Mdot
.21518 .57805 Mdot
.5128 .34246 Mdot
.45646 .59904 Mdot
.69835 .40872 Mdot
.63031 .43469 Mdot
.52604 .37807 Mdot
.66104 .41426 Mdot
.43282 .61927 Mdot
.62307 .61156 Mdot
.42884 .36393 Mdot
.33512 .40674 Mdot
.79414 .36445 Mdot
.31492 .40326 Mdot
.506 .34806 Mdot
.40061 .55641 Mdot
.49754 .37198 Mdot
.82835 .3139 Mdot
.4373 .62369 Mdot
.60265 .63338 Mdot
.39377 .61418 Mdot
.45609 .62399 Mdot
.48529 .61107 Mdot
.49367 .37759 Mdot
.3275 .64218 Mdot
.38948 .63158 Mdot
.65325 .46013 Mdot
.41434 .73464 Mdot
.48181 .57696 Mdot
.4566 .39677 Mdot
.24328 .5318 Mdot
.71392 .45004 Mdot
.65055 .65079 Mdot
.51087 .35706 Mdot
.59393 .62232 Mdot
.61451 .57594 Mdot
.59906 .61678 Mdot
.45562 .76257 Mdot
.6103 .74458 Mdot
.34172 .69995 Mdot
.53086 .6798 Mdot
.57053 .52229 Mdot
.58718 .65143 Mdot
.36315 .37847 Mdot
.58987 .60624 Mdot
.64664 .64917 Mdot
.06946 .5217 Mdot
.57652 .62463 Mdot
.46653 .60388 Mdot
.46624 .56809 Mdot
.73459 .37907 Mdot
.29209 .52593 Mdot
.39809 .61208 Mdot
.39544 .60236 Mdot
.34975 .39652 Mdot
.58216 .57108 Mdot
.68501 .31479 Mdot
.27099 .72086 Mdot
.64387 .2645 Mdot
.42614 .58569 Mdot
.39015 .61478 Mdot
.50366 .57864 Mdot
.17727 .60319 Mdot
.75293 .67406 Mdot
.65232 .66285 Mdot
.48607 .5633 Mdot
.78799 .39274 Mdot
.48382 .60957 Mdot
.47046 .63025 Mdot
.42739 .62876 Mdot
.49065 .37204 Mdot
.63381 .66269 Mdot
.47646 .63828 Mdot
.27338 .37862 Mdot
.47207 .62273 Mdot
.59699 .30791 Mdot
.85005 .53399 Mdot
.45646 .59538 Mdot
.64541 .6597 Mdot
.4285 .64011 Mdot
.65642 .62936 Mdot
.64093 .63474 Mdot
.42279 .54161 Mdot
.40388 .74518 Mdot
.66388 .64116 Mdot
.42485 .61663 Mdot
.47794 .3745 Mdot
.60998 .18187 Mdot
.43582 .57299 Mdot
.3436 .39071 Mdot
.46782 .59737 Mdot
.37031 .43505 Mdot
.40297 .62667 Mdot
.5175 .38425 Mdot
.61517 .78474 Mdot
.48572 .36482 Mdot
.77546 .66938 Mdot
.48057 .38762 Mdot
.21659 .38625 Mdot
.61184 .65923 Mdot
.63005 .29413 Mdot
.51425 .83461 Mdot
.58444 .34314 Mdot
.41938 .44694 Mdot
.50343 .47448 Mdot
.66877 .41642 Mdot
.64805 .60438 Mdot
.54407 .54585 Mdot
.47312 .24524 Mdot
.42117 .24181 Mdot
.47722 .33391 Mdot
.61217 .82526 Mdot
.41045 .81689 Mdot
.40252 .6476 Mdot
.53983 .76614 Mdot
.50047 .73224 Mdot
.48416 .61416 Mdot
.4712 .64077 Mdot
.54194 .29241 Mdot
.38519 .62098 Mdot
.76363 .47515 Mdot
.50366 .34514 Mdot
.32017 .41682 Mdot
.60893 .63924 Mdot
.32188 .43423 Mdot
.46585 .24309 Mdot
.49656 .47392 Mdot
.49735 .38402 Mdot
.49636 .58794 Mdot
.3982 .60205 Mdot
.65381 .63421 Mdot
.68167 .64573 Mdot
.58116 .61415 Mdot
.34335 .43103 Mdot
.49774 .34474 Mdot
.6691 .74693 Mdot
.39778 .59394 Mdot
.62768 .62796 Mdot
.41894 .43354 Mdot
.3901 .60934 Mdot
.66382 .43223 Mdot
.43286 .63116 Mdot
.59294 .63264 Mdot
.3999 .62827 Mdot
.62016 .60665 Mdot
.49726 .35585 Mdot
.46923 .57337 Mdot
.4102 .58441 Mdot
.18391 .4837 Mdot
.32558 .42016 Mdot
.60109 .65481 Mdot
.56288 .35794 Mdot
.39543 .5754 Mdot
.63934 .3194 Mdot
.46927 .61957 Mdot
.69289 .67605 Mdot
.43249 .65055 Mdot
.58002 .3401 Mdot
.49178 .64137 Mdot
.43837 .57451 Mdot
.44179 .42786 Mdot
.49438 .74235 Mdot
.64441 .67035 Mdot
.69467 .42203 Mdot
.58001 .63527 Mdot
.21981 .58048 Mdot
.54587 .37243 Mdot
.49531 .31758 Mdot
.30405 .47217 Mdot
.48657 .62354 Mdot
.44588 .59629 Mdot
.70293 .42595 Mdot
.34591 .44037 Mdot
.63089 .63907 Mdot
.32135 .41067 Mdot
.19945 .47775 Mdot
.35679 .43443 Mdot
.45388 .33277 Mdot
.36888 .355 Mdot
.68738 .72558 Mdot
.35107 .39787 Mdot
.58696 .6267 Mdot
.41445 .36185 Mdot
.48941 .61608 Mdot
.31749 .36653 Mdot
.32887 .40431 Mdot
.67951 .79507 Mdot
.42228 .56619 Mdot
.4154 .44766 Mdot
.64543 .43549 Mdot
.34267 .39476 Mdot
.67975 .42345 Mdot
.40287 .60377 Mdot
.67246 .30886 Mdot
.62974 .6018 Mdot
.68844 .4526 Mdot
.3662 .59486 Mdot
.33515 .43228 Mdot
.46573 .3771 Mdot
.70236 .44444 Mdot
.69601 .42781 Mdot
.5371 .20664 Mdot
.81046 .57425 Mdot
.49493 .34498 Mdot
.29127 .68782 Mdot
.63998 .42603 Mdot
.48978 .6041 Mdot
.56387 .56992 Mdot
.44855 .63121 Mdot
.73643 .618 Mdot
.51308 .35283 Mdot
.73553 .36615 Mdot
.39243 .61806 Mdot
.4654 .57968 Mdot
.63129 .66937 Mdot
.48127 .35852 Mdot
.61539 .62012 Mdot
.5769 .63425 Mdot
.49542 .35556 Mdot
.60867 .60809 Mdot
.36539 .42972 Mdot
.70534 .50602 Mdot
.63003 .45977 Mdot
.6611 .46139 Mdot
.47016 .3579 Mdot
.51526 .36266 Mdot
.50263 .36925 Mdot
.43323 .63133 Mdot
.62712 .64218 Mdot
.40989 .61948 Mdot
.47586 .62119 Mdot
.38769 .7365 Mdot
.63764 .65793 Mdot
.41883 .62646 Mdot
.49934 .42692 Mdot
.30303 .38788 Mdot
.47647 .37525 Mdot
.64247 .4405 Mdot
.576 .26541 Mdot
.66352 .37481 Mdot
.45902 .60245 Mdot
.29029 .35001 Mdot
.58323 .61965 Mdot
.35039 .42316 Mdot
.32415 .38515 Mdot
.34169 .42147 Mdot
.61644 .4901 Mdot
.58946 .65125 Mdot
.2766 .72882 Mdot
.45256 .59704 Mdot
.46635 .48561 Mdot
.506 .53748 Mdot
.32615 .34388 Mdot
.64144 .44415 Mdot
.39191 .60727 Mdot
.5814 .46407 Mdot
.62307 .7547 Mdot
.44787 .62924 Mdot
.49057 .58767 Mdot
.50843 .24746 Mdot
.36728 .65726 Mdot
.64504 .59648 Mdot
.18285 .52567 Mdot
.39887 .56412 Mdot
.68553 .58789 Mdot
.8079 .37373 Mdot
.46483 .61141 Mdot
.47268 .58925 Mdot
.40687 .57661 Mdot
.40097 .63574 Mdot
.65807 .64849 Mdot
.27551 .49071 Mdot
.65324 .41362 Mdot
.45749 .48598 Mdot
.65112 .47474 Mdot
.47795 .39004 Mdot
.74386 .36648 Mdot
.64643 .60166 Mdot
.35573 .41966 Mdot
.73644 .31349 Mdot
.21144 .62679 Mdot
.52508 .35217 Mdot
.72587 .68353 Mdot
.32596 .41026 Mdot
.4905 .59693 Mdot
.36844 .42744 Mdot
.45816 .36629 Mdot
.6542 .4644 Mdot
.49662 .60856 Mdot
.59188 .60621 Mdot
.60988 .64746 Mdot
.39045 .60087 Mdot
.77875 .377 Mdot
.6597 .43154 Mdot
.69948 .44284 Mdot
.45683 .63735 Mdot
.4207 .55293 Mdot
.61204 .61832 Mdot
.47797 .34218 Mdot
.2626 .63228 Mdot
.33491 .43847 Mdot
.41 .66473 Mdot
.4045 .63465 Mdot
.22697 .41443 Mdot
.6467 .46179 Mdot
.4971 .31226 Mdot
.43561 .64671 Mdot
.68432 .55072 Mdot
.43329 .64658 Mdot
.48264 .5576 Mdot
.47506 .37275 Mdot
.5011 .63807 Mdot
.40141 .65071 Mdot
.52301 .5819 Mdot
.66596 .41921 Mdot
.60251 .62818 Mdot
.56212 .63216 Mdot
.49179 .50916 Mdot
.66551 .43297 Mdot
.42126 .63192 Mdot
.64478 .44848 Mdot
.45975 .63241 Mdot
.38679 .61339 Mdot
.639 .44273 Mdot
.61528 .61919 Mdot
.59101 .2246 Mdot
.74167 .35017 Mdot
.39989 .63699 Mdot
.38069 .58284 Mdot
.28235 .5054 Mdot
.32592 .63593 Mdot
.48106 .60226 Mdot
.59787 .63767 Mdot
.40153 .59128 Mdot
.68139 .42784 Mdot
.36601 .41782 Mdot
.59336 .63042 Mdot
.49356 .33459 Mdot
.52557 .36272 Mdot
.73034 .56726 Mdot
.49854 .32397 Mdot
.47918 .62636 Mdot
.6397 .58211 Mdot
.56972 .64268 Mdot
.80326 .39046 Mdot
.49128 .35521 Mdot
.35785 .39457 Mdot
.41226 .59371 Mdot
.26501 .35143 Mdot
.70026 .40846 Mdot
.23907 .74826 Mdot
.31826 .77065 Mdot
.32445 .4504 Mdot
.38393 .78273 Mdot
.49884 .39152 Mdot
.40105 .65497 Mdot
.33585 .39108 Mdot
.52323 .36079 Mdot
.42177 .6453 Mdot
.44797 .53989 Mdot
.44846 .80597 Mdot
.53021 .5092 Mdot
.64364 .45063 Mdot
.51249 .32878 Mdot
.31243 .44231 Mdot
.47011 .31344 Mdot
.62556 .65466 Mdot
.44113 .57783 Mdot
.40312 .55281 Mdot
.48654 .33581 Mdot
.51543 .32287 Mdot
.42353 .62186 Mdot
.6421 .59708 Mdot
.54678 .29949 Mdot
.42638 .59154 Mdot
.58638 .53233 Mdot
.55913 .60885 Mdot
.50565 .34078 Mdot
.45515 .57484 Mdot
.39487 .45022 Mdot
.48341 .34237 Mdot
.47597 .37587 Mdot
.38826 .60776 Mdot
.36392 .43281 Mdot
.38482 .57726 Mdot
.6315 .43993 Mdot
.6752 .77292 Mdot
.68454 .43029 Mdot
.44839 .2975 Mdot
.36531 .59248 Mdot
.65225 .53554 Mdot
.65833 .64027 Mdot
.25345 .41095 Mdot
.54362 .26083 Mdot
.3747 .61513 Mdot
.56778 .186 Mdot
.59657 .42561 Mdot
.76778 .35273 Mdot
.34877 .23503 Mdot
.34223 .40005 Mdot
.66976 .43832 Mdot
.47349 .59041 Mdot
.62284 .46706 Mdot
.33631 .38992 Mdot
.77676 .66375 Mdot
.44764 .57127 Mdot
.61975 .64145 Mdot
.42818 .62295 Mdot
.61983 .64808 Mdot
.38835 .61144 Mdot
.51237 .59299 Mdot
.5513 .28037 Mdot
.29055 .64182 Mdot
.44169 .64841 Mdot
.20627 .36498 Mdot
.39774 .40288 Mdot
.32309 .4273 Mdot
.41158 .6134 Mdot
.53064 .32666 Mdot
.62939 .43276 Mdot
.78474 .50104 Mdot
.49143 .37283 Mdot
.68738 .41795 Mdot
.60613 .61338 Mdot
.50734 .35355 Mdot
.52761 .36206 Mdot
.49664 .64266 Mdot
.35473 .4465 Mdot
.6768 .45525 Mdot
.44914 .58338 Mdot
.44616 .57166 Mdot
.27132 .67287 Mdot
.43268 .28971 Mdot
.6838 .65176 Mdot
.21078 .66474 Mdot
.5689 .61304 Mdot
.3273 .42932 Mdot
.48709 .37475 Mdot
.47766 .61085 Mdot
.4396 .61274 Mdot
.61871 .29807 Mdot
.60812 .59661 Mdot
.55374 .48955 Mdot
.69131 .68972 Mdot
.56018 .35123 Mdot
.25887 .54973 Mdot
.60544 .63967 Mdot
.26043 .5525 Mdot
.3099 .40259 Mdot
.68633 .24048 Mdot
.28011 .61367 Mdot
.64582 .43728 Mdot
.26056 .54633 Mdot
.63264 .62877 Mdot
.39571 .63963 Mdot
.45863 .34643 Mdot
.48861 .32494 Mdot
.60822 .62536 Mdot
.4948 .30582 Mdot
.3545 .40548 Mdot
.46537 .58584 Mdot
.26598 .70847 Mdot
.74112 .54482 Mdot
.46737 .35111 Mdot
.5131 .58675 Mdot
.68446 .44292 Mdot
.39014 .59964 Mdot
.35668 .40295 Mdot
.65333 .44474 Mdot
.24308 .40821 Mdot
.7347 .44115 Mdot
.41463 .5954 Mdot
.22404 .38751 Mdot
.66278 .43753 Mdot
.32529 .60736 Mdot
.43204 .58653 Mdot
.64515 .42212 Mdot
.34357 .64928 Mdot
.66599 .35747 Mdot
.5797 .47414 Mdot
.48155 .1673 Mdot
.56625 .47267 Mdot
.46147 .3461 Mdot
.69338 .35997 Mdot
.58526 .3845 Mdot
.62174 .45741 Mdot
.50711 .31567 Mdot
.29264 .41523 Mdot
.67833 .42221 Mdot
.48454 .5826 Mdot
.46755 .61805 Mdot
.76119 .66891 Mdot
.58817 .42097 Mdot
.70305 .37947 Mdot
.77135 .55598 Mdot
.39797 .57204 Mdot
.38994 .56738 Mdot
.44028 .60828 Mdot
.66657 .63724 Mdot
.6461 .45611 Mdot
.18229 .42447 Mdot
.66538 .42983 Mdot
.31605 .74087 Mdot
.47269 .3591 Mdot
.51653 .34614 Mdot
.45878 .59917 Mdot
.39957 .46711 Mdot
.24529 .47666 Mdot
.43097 .61764 Mdot
.29459 .43897 Mdot
.79294 .57874 Mdot
.41286 .55549 Mdot
.66036 .62166 Mdot
.52886 .61576 Mdot
.54266 .64198 Mdot
.62962 .45968 Mdot
.34685 .40781 Mdot
.25174 .41803 Mdot
.65849 .46567 Mdot
.44516 .59727 Mdot
.67197 .53078 Mdot
.45136 .62194 Mdot
.40457 .6412 Mdot
.33687 .76795 Mdot
.31077 .41361 Mdot
.49972 .36399 Mdot
.34032 .4235 Mdot
.65786 .63219 Mdot
.14256 .65517 Mdot
.34963 .44221 Mdot
.24433 .46713 Mdot
.75113 .69689 Mdot
.2631 .5474 Mdot
.62025 .6527 Mdot
.35602 .44774 Mdot
.65308 .43398 Mdot
.62308 .18232 Mdot
.50384 .8244 Mdot
.64401 .39881 Mdot
.42954 .59478 Mdot
.62902 .58927 Mdot
.59633 .64114 Mdot
.68383 .45991 Mdot
.63932 .63501 Mdot
.34137 .63001 Mdot
.3987 .63999 Mdot
.62031 .46198 Mdot
.69493 .54288 Mdot
.69546 .42196 Mdot
.72837 .48386 Mdot
.41618 .61314 Mdot
.60096 .63539 Mdot
.39251 .65955 Mdot
.55545 .60757 Mdot
.47918 .3108 Mdot
.47121 .56235 Mdot
.35561 .40741 Mdot
.65862 .54451 Mdot
.49374 .34348 Mdot
.30541 .34271 Mdot
.65405 .63643 Mdot
.7014 .47246 Mdot
.64769 .6403 Mdot
.57921 .6465 Mdot
.68866 .42292 Mdot
.63658 .61444 Mdot
.47046 .58756 Mdot
.55117 .41307 Mdot
.64968 .61508 Mdot
.67406 .44834 Mdot
.34268 .40899 Mdot
.61392 .61006 Mdot
.4844 .41589 Mdot
.41528 .58785 Mdot
.5051 .37721 Mdot
.37091 .24629 Mdot
.59367 .59714 Mdot
.31906 .43637 Mdot
.49766 .31906 Mdot
.31713 .41756 Mdot
.82965 .46134 Mdot
.6197 .47085 Mdot
.35604 .75654 Mdot
.30479 .44182 Mdot
.579 .62392 Mdot
.38845 .23602 Mdot
.47574 .61129 Mdot
.41338 .59019 Mdot
.37294 .42946 Mdot
.59585 .64069 Mdot
.73278 .28726 Mdot
.58954 .66956 Mdot
.70375 .49705 Mdot
.64911 .4842 Mdot
.21507 .37711 Mdot
.74161 .46903 Mdot
.85898 .46078 Mdot
.37138 .59857 Mdot
.53319 .38032 Mdot
.4542 .60555 Mdot
.5564 .26816 Mdot
.33546 .43064 Mdot
.43548 .3624 Mdot
.44837 .54527 Mdot
.50183 .359 Mdot
.4168 .5759 Mdot
.47222 .43553 Mdot
.47887 .66235 Mdot
.35487 .39215 Mdot
.67367 .29835 Mdot
.57796 .62853 Mdot
.33241 .40665 Mdot
.5079 .38596 Mdot
.24848 .5035 Mdot
.41208 .64533 Mdot
.41627 .67114 Mdot
.56006 .35116 Mdot
.62555 .6462 Mdot
.46511 .33118 Mdot
.62876 .45314 Mdot
.35259 .41605 Mdot
.39895 .60558 Mdot
.46325 .64062 Mdot
.63506 .32018 Mdot
.68553 .4443 Mdot
.52482 .33128 Mdot
.65335 .42397 Mdot
.51032 .39085 Mdot
.38367 .609 Mdot
.5158 .34171 Mdot
.41975 .66592 Mdot
.56363 .29011 Mdot
.33416 .76089 Mdot
.50738 .75207 Mdot
.51288 .3506 Mdot
.24492 .56005 Mdot
.68168 .43485 Mdot
.64886 .42262 Mdot
.70916 .72657 Mdot
.41733 .78611 Mdot
.24732 .65946 Mdot
.48196 .20155 Mdot
.64674 .47325 Mdot
.68179 .44465 Mdot
.51025 .37529 Mdot
.63943 .61536 Mdot
.56722 .62221 Mdot
.51606 .38891 Mdot
.33222 .52037 Mdot
.63085 .63885 Mdot
.61088 .19295 Mdot
.22299 .6081 Mdot
.45723 .6523 Mdot
.51497 .30648 Mdot
.34786 .41776 Mdot
.32225 .52106 Mdot
.46896 .43409 Mdot
.47024 .58275 Mdot
.2578 .38503 Mdot
.47122 .35052 Mdot
.39535 .48806 Mdot
.43327 .18435 Mdot
.43803 .56721 Mdot
.43663 .58357 Mdot
.44557 .60388 Mdot
.33201 .45007 Mdot
.47059 .8064 Mdot
.45607 .57766 Mdot
.33235 .52264 Mdot
.39222 .58455 Mdot
.33676 .64424 Mdot
.33697 .41927 Mdot
.36002 .69616 Mdot
.48239 .23656 Mdot
.18873 .53873 Mdot
.45629 .67655 Mdot
.62814 .44959 Mdot
.28237 .42705 Mdot
.65681 .41841 Mdot
.46714 .76066 Mdot
.28174 .60939 Mdot
.58344 .59864 Mdot
.47281 .586 Mdot
.50623 .34738 Mdot
.59851 .64281 Mdot
.663 .34238 Mdot
.09719 .58585 Mdot
.62746 .44665 Mdot
.87461 .44307 Mdot
.64039 .42854 Mdot
.52789 .36553 Mdot
.61072 .61837 Mdot
.61146 .73876 Mdot
.48334 .4947 Mdot
.61381 .60836 Mdot
.65677 .25423 Mdot
.66209 .65919 Mdot
.24893 .54349 Mdot
.61787 .5919 Mdot
.67789 .44364 Mdot
.61611 .48889 Mdot
.36697 .56122 Mdot
.47165 .60572 Mdot
.50325 .47093 Mdot
.237 .4961 Mdot
.47528 .60829 Mdot
.50113 .34549 Mdot
.37116 .75982 Mdot
.26978 .43397 Mdot
.63402 .6174 Mdot
.64088 .41555 Mdot
.43399 .57981 Mdot
.41904 .64056 Mdot
.4083 .64559 Mdot
.24205 .72023 Mdot
.69171 .243 Mdot
.38914 .62973 Mdot
.39161 .57917 Mdot
.50464 .35555 Mdot
.30381 .41232 Mdot
.5395 .24963 Mdot
.36217 .72225 Mdot
.47519 .58009 Mdot
.33092 .41207 Mdot
.30943 .42641 Mdot
.42698 .64713 Mdot
.32073 .36368 Mdot
.66878 .52798 Mdot
.44854 .58241 Mdot
.38235 .75835 Mdot
.55513 .3864 Mdot
.52369 .33625 Mdot
.48896 .33635 Mdot
.61398 .65608 Mdot
.50464 .32944 Mdot
.50311 .38983 Mdot
.63357 .731 Mdot
.55525 .47675 Mdot
.64456 .41088 Mdot
.34474 .43113 Mdot
.44249 .61568 Mdot
.6402 .6727 Mdot
.67636 .54329 Mdot
.67842 .41945 Mdot
.58704 .61415 Mdot
.63676 .42566 Mdot
.38255 .42049 Mdot
.44597 .50714 Mdot
.47065 .34085 Mdot
.64688 .47125 Mdot
.73192 .44856 Mdot
.33243 .41311 Mdot
.68983 .43922 Mdot
.72536 .44322 Mdot
.46809 .56363 Mdot
.53991 .77802 Mdot
.42688 .61462 Mdot
.75035 .31936 Mdot
.67967 .45547 Mdot
.58234 .32241 Mdot
.4455 .59021 Mdot
.48315 .34432 Mdot
.37884 .54808 Mdot
.47384 .61916 Mdot
.49307 .33124 Mdot
.40142 .64694 Mdot
.31432 .4088 Mdot
.55585 .61337 Mdot
.4652 .49092 Mdot
.56037 .85934 Mdot
.35501 .44664 Mdot
.661 .33714 Mdot
.4807 .59795 Mdot
.82716 .53078 Mdot
.6164 .61084 Mdot
.41941 .66138 Mdot
.27177 .45115 Mdot
.64439 .61165 Mdot
.59189 .61716 Mdot
.42039 .63675 Mdot
.64812 .43231 Mdot
.49735 .34151 Mdot
.33576 .41533 Mdot
.83819 .43498 Mdot
.42313 .59952 Mdot
.40648 .58669 Mdot
.32844 .40805 Mdot
.68482 .4366 Mdot
.43968 .64541 Mdot
.33401 .26534 Mdot
.74802 .28631 Mdot
.65637 .41557 Mdot
.48284 .58197 Mdot
.48073 .78414 Mdot
.55457 .64562 Mdot
.80288 .66486 Mdot
.3095 .36697 Mdot
.50617 .36209 Mdot
.35337 .62592 Mdot
.15946 .6521 Mdot
.34628 .40938 Mdot
.22008 .63574 Mdot
.41291 .64 Mdot
.3972 .59119 Mdot
.58159 .61466 Mdot
.4138 .62141 Mdot
.62751 .59632 Mdot
.55388 .8531 Mdot
.22396 .41547 Mdot
.62894 .64991 Mdot
.57618 .61728 Mdot
.25674 .4558 Mdot
.54492 .25463 Mdot
.60646 .62335 Mdot
.38559 .60527 Mdot
.43943 .69467 Mdot
.44911 .52855 Mdot
.3692 .43101 Mdot
.44066 .23622 Mdot
.60916 .67396 Mdot
.36481 .45367 Mdot
.55339 .2109 Mdot
.63271 .67849 Mdot
.63121 .51309 Mdot
.6311 .4498 Mdot
.44102 .56688 Mdot
.49255 .3238 Mdot
.50626 .32385 Mdot
.38287 .64638 Mdot
.44389 .62114 Mdot
.65674 .63415 Mdot
.35315 .4313 Mdot
.62409 .44706 Mdot
.39643 .60081 Mdot
.25979 .43688 Mdot
.3452 .44222 Mdot
.64366 .62724 Mdot
.36701 .74198 Mdot
.34638 .38611 Mdot
.51548 .60226 Mdot
.45831 .58985 Mdot
.42676 .62694 Mdot
.47898 .54035 Mdot
.63928 .45594 Mdot
.4246 .22533 Mdot
.43566 .5587 Mdot
.19795 .48142 Mdot
.60179 .4394 Mdot
.50327 .61492 Mdot
.6378 .64257 Mdot
.6974 .40373 Mdot
.45125 .36245 Mdot
.48802 .51363 Mdot
.41569 .59761 Mdot
.74739 .34722 Mdot
.77153 .64929 Mdot
.47559 .31391 Mdot
.58035 .6467 Mdot
.34688 .42321 Mdot
.43308 .61801 Mdot
.41669 .74463 Mdot
.46795 .61385 Mdot
.37372 .40355 Mdot
.4687 .37119 Mdot
.63181 .44705 Mdot
.76413 .34248 Mdot
.50813 .3258 Mdot
.59334 .62119 Mdot
.32753 .19273 Mdot
.63485 .59661 Mdot
.57119 .62948 Mdot
.40352 .73622 Mdot
.63679 .45363 Mdot
.18388 .68989 Mdot
.62421 .8047 Mdot
.44328 .55103 Mdot
.67953 .4317 Mdot
.61173 .63104 Mdot
.39551 .58495 Mdot
.62768 .58598 Mdot
.59884 .65685 Mdot
.38416 .59902 Mdot
.40975 .57205 Mdot
.74881 .39823 Mdot
.47235 .17426 Mdot
.3469 .42488 Mdot
.64961 .64812 Mdot
.57388 .53431 Mdot
.39868 .57732 Mdot
.45211 .59612 Mdot
.59177 .38379 Mdot
.36697 .42598 Mdot
.76834 .49825 Mdot
.41624 .64047 Mdot
.23174 .39835 Mdot
.51659 .62969 Mdot
.66333 .63909 Mdot
.6652 .41503 Mdot
.19031 .53301 Mdot
.64859 .48897 Mdot
.62131 .59675 Mdot
.35731 .42564 Mdot
.57308 .6477 Mdot
.24201 .46683 Mdot
.67395 .46586 Mdot
.59294 .63267 Mdot
.5785 .45684 Mdot
.65555 .45167 Mdot
.66358 .46718 Mdot
.41089 .73153 Mdot
.51317 .31515 Mdot
.32434 .44806 Mdot
.67985 .45134 Mdot
.59357 .55517 Mdot
.67173 .44514 Mdot
.66492 .764 Mdot
.4695 .57311 Mdot
.33897 .48858 Mdot
.43998 .31362 Mdot
.35315 .5908 Mdot
.67421 .46291 Mdot
.35192 .39692 Mdot
.42889 .6435 Mdot
.63506 .62977 Mdot
.32311 .4317 Mdot
.6996 .39641 Mdot
.50054 .37389 Mdot
.64952 .63664 Mdot
.67098 .48004 Mdot
.61441 .64799 Mdot
.5405 .54412 Mdot
.72801 .72866 Mdot
.26754 .31018 Mdot
.50121 .50299 Mdot
.40805 .64432 Mdot
.49341 .21221 Mdot
.46817 .65015 Mdot
.44412 .62515 Mdot
.5047 .34218 Mdot
.31862 .47741 Mdot
.61489 .61979 Mdot
.7514 .30548 Mdot
.63738 .46519 Mdot
.18373 .51993 Mdot
.48851 .66871 Mdot
.41396 .65332 Mdot
.64878 .61249 Mdot
.63164 .59458 Mdot
.48113 .73776 Mdot
.45001 .36405 Mdot
.46727 .64251 Mdot
.48965 .62329 Mdot
.38353 .63801 Mdot
.64903 .46574 Mdot
.29967 .34749 Mdot
.46226 .34696 Mdot
.773 .68728 Mdot
.46395 .36582 Mdot
.30187 .45104 Mdot
.63748 .61786 Mdot
.35065 .44136 Mdot
.45204 .59418 Mdot
.67519 .651 Mdot
.61098 .59583 Mdot
.37176 .40926 Mdot
.33851 .39381 Mdot
.62439 .36384 Mdot
.63899 .4438 Mdot
.45831 .64221 Mdot
.45651 .5759 Mdot
.40732 .62032 Mdot
.43492 .62927 Mdot
.62632 .45519 Mdot
.43973 .64049 Mdot
.69868 .41405 Mdot
.53699 .56412 Mdot
.27076 .37382 Mdot
.56249 .46723 Mdot
.73515 .63974 Mdot
.63392 .62271 Mdot
.60623 .54821 Mdot
.50359 .56652 Mdot
.35393 .7862 Mdot
.80013 .55736 Mdot
.44021 .55575 Mdot
.52387 .35485 Mdot
.333 .60221 Mdot
.47614 .33288 Mdot
.87813 .50614 Mdot
.61956 .32053 Mdot
.5124 .17562 Mdot
.44369 .57167 Mdot
.56084 .40007 Mdot
.61846 .56697 Mdot
.45333 .65938 Mdot
.6291 .33909 Mdot
.73369 .62474 Mdot
.69927 .31072 Mdot
.36124 .40679 Mdot
.42132 .5868 Mdot
.63941 .67216 Mdot
.46729 .58558 Mdot
.45473 .6018 Mdot
.42527 .64535 Mdot
.68736 .41378 Mdot
.45139 .65115 Mdot
.44484 .63501 Mdot
.34927 .3427 Mdot
.26654 .57891 Mdot
.50606 .32116 Mdot
.72866 .70757 Mdot
.34806 .44352 Mdot
.6549 .62531 Mdot
.65625 .23586 Mdot
.64523 .43827 Mdot
.48751 .73472 Mdot
.4313 .62845 Mdot
.7432 .37977 Mdot
.70791 .40913 Mdot
.35478 .41413 Mdot
.45564 .36284 Mdot
.56066 .17434 Mdot
.50011 .34945 Mdot
.58205 .45794 Mdot
.48429 .34639 Mdot
.51742 .58129 Mdot
.65638 .63652 Mdot
.44964 .64464 Mdot
.67348 .45692 Mdot
.50248 .33271 Mdot
.28979 .51318 Mdot
.44235 .60832 Mdot
.49507 .35631 Mdot
.45034 .64427 Mdot
.43075 .50329 Mdot
.30502 .69163 Mdot
.50992 .38734 Mdot
.68796 .40271 Mdot
.65902 .4572 Mdot
.36312 .43336 Mdot
.65228 .62737 Mdot
.5956 .6057 Mdot
.6551 .44489 Mdot
.45181 .81362 Mdot
.48056 .58703 Mdot
.40305 .57336 Mdot
.18894 .50997 Mdot
.47696 .5985 Mdot
.24594 .52017 Mdot
.58025 .46639 Mdot
.63915 .62663 Mdot
.39288 .64457 Mdot
.41214 .63708 Mdot
.41405 .59407 Mdot
.5198 .54225 Mdot
.47732 .34143 Mdot
.44764 .56591 Mdot
.33198 .39495 Mdot
.44666 .41682 Mdot
.38996 .59962 Mdot
.44361 .67546 Mdot
.59268 .6073 Mdot
.22314 .67605 Mdot
.63773 .43274 Mdot
.51602 .38185 Mdot
.51483 .35218 Mdot
.45278 .23783 Mdot
.67837 .5689 Mdot
.57767 .46373 Mdot
.79282 .66071 Mdot
.55045 .28029 Mdot
.32359 .42084 Mdot
.48406 .29939 Mdot
.59883 .47689 Mdot
.51793 .37356 Mdot
.62678 .44708 Mdot
.4642 .56953 Mdot
.47422 .5786 Mdot
.34343 .79732 Mdot
.42115 .6484 Mdot
.345 .41966 Mdot
.70012 .43142 Mdot
.63191 .62846 Mdot
.35488 .41607 Mdot
.65551 .42209 Mdot
.62915 .64717 Mdot
.44771 .55909 Mdot
.44815 .56028 Mdot
.58931 .61217 Mdot
.59078 .63364 Mdot
.45426 .58889 Mdot
.48335 .26635 Mdot
.58158 .62942 Mdot
.60156 .63871 Mdot
.46784 .34398 Mdot
.49062 .32536 Mdot
.49719 .63618 Mdot
.6767 .4326 Mdot
.44351 .6365 Mdot
.50648 .35162 Mdot
.35705 .43356 Mdot
.61869 .61926 Mdot
.40142 .63744 Mdot
.39317 .61022 Mdot
.33371 .41195 Mdot
.36219 .42117 Mdot
.34905 .39827 Mdot
.69653 .42001 Mdot
.40681 .61249 Mdot
.6049 .61749 Mdot
.63659 .44476 Mdot
.31037 .43078 Mdot
.36908 .41682 Mdot
.46236 .31417 Mdot
.47928 .60962 Mdot
.42448 .38089 Mdot
.13064 .60811 Mdot
.21002 .49985 Mdot
.45764 .33168 Mdot
.44998 .34603 Mdot
.27542 .5512 Mdot
.41217 .47237 Mdot
.65894 .43558 Mdot
.33209 .37619 Mdot
.24995 .41773 Mdot
.4824 .57563 Mdot
.39989 .56415 Mdot
.49098 .56881 Mdot
.34187 .39677 Mdot
.29965 .46202 Mdot
.64841 .6036 Mdot
.60376 .69081 Mdot
.33658 .44224 Mdot
.51592 .32331 Mdot
.48351 .30321 Mdot
.46451 .36767 Mdot
.45742 .56524 Mdot
.51662 .75019 Mdot
.63922 .55199 Mdot
.44889 .20138 Mdot
.68279 .45314 Mdot
.63153 .67447 Mdot
.82418 .52505 Mdot
.59098 .61358 Mdot
.47002 .38563 Mdot
.32096 .41356 Mdot
.59655 .63861 Mdot
.63854 .42194 Mdot
.68037 .4479 Mdot
.46685 .35304 Mdot
.47033 .36104 Mdot
.49477 .38141 Mdot
.57732 .64231 Mdot
.63745 .61614 Mdot
.41516 .60064 Mdot
.62401 .61895 Mdot
.31002 .7713 Mdot
.36487 .44697 Mdot
.47184 .40479 Mdot
.6706 .4358 Mdot
.62483 .65007 Mdot
.43936 .60946 Mdot
.41061 .48361 Mdot
.75533 .57938 Mdot
.31822 .41028 Mdot
.28261 .67908 Mdot
.87438 .51299 Mdot
.46117 .64099 Mdot
.64486 .45951 Mdot
.26329 .70301 Mdot
.44267 .60339 Mdot
.48055 .37309 Mdot
.52237 .24753 Mdot
.55397 .34396 Mdot
.4724 .6238 Mdot
.49271 .58515 Mdot
.65406 .41455 Mdot
.78637 .65844 Mdot
.41882 .60225 Mdot
.75911 .50893 Mdot
.61322 .45671 Mdot
.46081 .35126 Mdot
.70993 .2349 Mdot
.341 .27413 Mdot
.32846 .51743 Mdot
.46449 .34908 Mdot
.45747 .62406 Mdot
.4766 .33548 Mdot
.32121 .40138 Mdot
.48238 .38549 Mdot
.64915 .60256 Mdot
.47103 .31894 Mdot
.40644 .58574 Mdot
.60589 .62548 Mdot
.66319 .43639 Mdot
.19262 .57225 Mdot
.40599 .34596 Mdot
.48138 .34534 Mdot
.5218 .38108 Mdot
.39641 .64603 Mdot
.76521 .46756 Mdot
.37931 .65129 Mdot
.42437 .56658 Mdot
.6513 .47401 Mdot
.64834 .61588 Mdot
.67375 .41303 Mdot
.44323 .66896 Mdot
.32896 .26364 Mdot
.6505 .42571 Mdot
.73598 .34388 Mdot
.32514 .41183 Mdot
.49546 .44213 Mdot
.43908 .61445 Mdot
.68771 .43034 Mdot
.40822 .61194 Mdot
.65332 .61089 Mdot
.55171 .43452 Mdot
.68505 .31222 Mdot
.66306 .46277 Mdot
.75258 .34397 Mdot
.32348 .46579 Mdot
.40455 .6781 Mdot
.6524 .41974 Mdot
.27547 .45015 Mdot
.52789 .36206 Mdot
.33281 .43807 Mdot
.32576 .38952 Mdot
.32147 .4326 Mdot
.37077 .62492 Mdot
.46299 .67616 Mdot
.3109 .41787 Mdot
.62439 .43654 Mdot
.35316 .39144 Mdot
.69671 .61524 Mdot
.73726 .29895 Mdot
.33349 .42819 Mdot
.43033 .58939 Mdot
.5337 .61553 Mdot
.27242 .57388 Mdot
.66463 .36183 Mdot
.53324 .1773 Mdot
.79037 .52666 Mdot
.47086 .60724 Mdot
.56011 .6148 Mdot
.63347 .65581 Mdot
.24346 .67656 Mdot
.23326 .51387 Mdot
.21201 .45491 Mdot
.57306 .62185 Mdot
.63169 .29137 Mdot
.64634 .62974 Mdot
.41367 .64756 Mdot
.39932 .57836 Mdot
.57308 .61458 Mdot
.2699 .36419 Mdot
.66019 .31545 Mdot
.7965 .37954 Mdot
.60807 .6449 Mdot
.66535 .4188 Mdot
.68746 .45824 Mdot
.66412 .46775 Mdot
.22863 .6245 Mdot
.63699 .60267 Mdot
.40039 .61684 Mdot
.51234 .34924 Mdot
.45743 .56951 Mdot
.65008 .45239 Mdot
.74986 .30159 Mdot
.62294 .60484 Mdot
.44135 .57633 Mdot
.35257 .55161 Mdot
.48315 .36947 Mdot
.32846 .41573 Mdot
.40901 .50986 Mdot
.21335 .46134 Mdot
.6469 .4683 Mdot
.58694 .60019 Mdot
.58986 .31201 Mdot
.72503 .30913 Mdot
.37452 .58336 Mdot
.48801 .63146 Mdot
.84795 .45003 Mdot
.23889 .41302 Mdot
.48197 .62161 Mdot
.52278 .37492 Mdot
.61347 .29872 Mdot
.3932 .61763 Mdot
.64019 .65392 Mdot
.33764 .38611 Mdot
.31782 .41989 Mdot
.48535 .64917 Mdot
.45927 .4821 Mdot
.55441 .41688 Mdot
.42264 .63281 Mdot
.51525 .59986 Mdot
.46176 .35123 Mdot
.5423 .2707 Mdot
.19925 .47522 Mdot
.35889 .4242 Mdot
.44798 .6445 Mdot
.60475 .23761 Mdot
.58798 .60556 Mdot
.4684 .31888 Mdot
.68625 .45263 Mdot
.49583 .53118 Mdot
.4565 .36519 Mdot
.39256 .62458 Mdot
.43359 .64587 Mdot
.69189 .42854 Mdot
.66397 .63752 Mdot
.33752 .39733 Mdot
.51428 .34551 Mdot
.36084 .41375 Mdot
.64232 .60907 Mdot
.62758 .615 Mdot
.33966 .58683 Mdot
.39592 .54865 Mdot
.49194 .33576 Mdot
.41463 .66656 Mdot
.55022 .38546 Mdot
.82702 .61601 Mdot
.67015 .47767 Mdot
.47224 .63397 Mdot
.66707 .62133 Mdot
.65614 .46525 Mdot
.40068 .58107 Mdot
.84262 .42915 Mdot
.39664 .57882 Mdot
.60363 .444 Mdot
.25883 .31247 Mdot
.35576 .40393 Mdot
.59841 .68765 Mdot
.78761 .45146 Mdot
.47362 .59576 Mdot
.51725 .36228 Mdot
.50471 .57605 Mdot
.65204 .43124 Mdot
.63496 .61741 Mdot
.81352 .65556 Mdot
.67063 .44856 Mdot
.45928 .58247 Mdot
.35338 .41597 Mdot
.62072 .59285 Mdot
.28705 .3945 Mdot
.31894 .3633 Mdot
.42883 .6825 Mdot
.40914 .66499 Mdot
.4323 .63485 Mdot
.37253 .23297 Mdot
.5129 .38285 Mdot
.61158 .63819 Mdot
.64483 .46085 Mdot
.65454 .44258 Mdot
.46945 .35038 Mdot
.73412 .43396 Mdot
.49952 .44194 Mdot
.13652 .57282 Mdot
.49068 .33001 Mdot
.3264 .44151 Mdot
.76537 .48941 Mdot
.52025 .35613 Mdot
.49049 .35746 Mdot
.46732 .34222 Mdot
.64388 .5008 Mdot
.62804 .64491 Mdot
.39093 .62042 Mdot
.65174 .64982 Mdot
.45608 .62622 Mdot
.60307 .43874 Mdot
.6684 .4613 Mdot
.62931 .60618 Mdot
.83894 .45364 Mdot
.53263 .79484 Mdot
.4383 .59619 Mdot
.82616 .52747 Mdot
.428 .54396 Mdot
.26476 .52559 Mdot
.44436 .54155 Mdot
.47502 .35277 Mdot
.37344 .65701 Mdot
.38172 .63681 Mdot
.21526 .64371 Mdot
.67098 .43359 Mdot
.52492 .34114 Mdot
.4594 .55292 Mdot
.52079 .60788 Mdot
.56909 .63334 Mdot
.59868 .63945 Mdot
.31781 .39995 Mdot
.29526 .65166 Mdot
.66391 .43369 Mdot
.62461 .79552 Mdot
.4695 .60213 Mdot
.28882 .33524 Mdot
.5216 .6831 Mdot
.40331 .578 Mdot
.79708 .4577 Mdot
.50986 .74474 Mdot
.43498 .617 Mdot
.55672 .51231 Mdot
.6838 .43769 Mdot
.3136 .27319 Mdot
.38952 .59061 Mdot
.48773 .37281 Mdot
.64226 .62002 Mdot
.64122 .59535 Mdot
.3126 .41142 Mdot
.39468 .81121 Mdot
.68018 .41478 Mdot
.63262 .61105 Mdot
.44804 .61041 Mdot
.63865 .4584 Mdot
.50533 .32795 Mdot
.41982 .65462 Mdot
.23378 .52705 Mdot
.62647 .62383 Mdot
.38434 .62848 Mdot
.74135 .51724 Mdot
.29631 .56147 Mdot
.31495 .22858 Mdot
.64425 .46212 Mdot
.36499 .4264 Mdot
.5059 .5802 Mdot
.43583 .80197 Mdot
.39175 .56282 Mdot
.35167 .48875 Mdot
.70105 .61987 Mdot
.36627 .42042 Mdot
.4412 .58869 Mdot
.39874 .60852 Mdot
.4105 .43451 Mdot
.35761 .42886 Mdot
.45091 .57224 Mdot
.54662 .5836 Mdot
.62315 .64459 Mdot
.49316 .39337 Mdot
.63054 .6329 Mdot
.43018 .59438 Mdot
.40742 .54189 Mdot
.58148 .62042 Mdot
.83942 .56165 Mdot
.33114 .45624 Mdot
.63927 .43262 Mdot
.40578 .55418 Mdot
.42532 .559 Mdot
.17991 .39813 Mdot
.48805 .3102 Mdot
.56416 .2503 Mdot
.34185 .30889 Mdot
.56948 .22144 Mdot
.33885 .27531 Mdot
.42079 .17091 Mdot
.23729 .40222 Mdot
.4417 .65629 Mdot
.54157 .65792 Mdot
.61765 .53488 Mdot
.68201 .45587 Mdot
.67104 .73423 Mdot
.47201 .6062 Mdot
.4553 .6041 Mdot
.46281 .32274 Mdot
.73228 .35331 Mdot
.21086 .45479 Mdot
.42073 .48002 Mdot
.33653 .39842 Mdot
.64807 .64863 Mdot
.38818 .615 Mdot
.56103 .49973 Mdot
.5045 .3197 Mdot
.28334 .34056 Mdot
.44045 .57795 Mdot
.34623 .77416 Mdot
.73891 .5844 Mdot
.63887 .45095 Mdot
.51634 .35474 Mdot
.2212 .44072 Mdot
.47826 .6128 Mdot
.68817 .45122 Mdot
.42557 .60417 Mdot
.51036 .27909 Mdot
.43529 .67093 Mdot
.33344 .4325 Mdot
.41266 .6413 Mdot
.30243 .45343 Mdot
.2816 .22064 Mdot
.35175 .37884 Mdot
.62543 .58701 Mdot
.49618 .40752 Mdot
.48125 .33881 Mdot
.59277 .63446 Mdot
.48438 .33831 Mdot
.48926 .72032 Mdot
.60744 .72238 Mdot
.3265 .40578 Mdot
.51693 .61617 Mdot
.33588 .42605 Mdot
.47569 .31277 Mdot
.47326 .613 Mdot
.85387 .56995 Mdot
.50024 .3359 Mdot
.23248 .34788 Mdot
.66914 .44434 Mdot
.5132 .32189 Mdot
.39152 .58649 Mdot
.58922 .32327 Mdot
.5089 .3256 Mdot
.69223 .3226 Mdot
.41406 .59497 Mdot
.63033 .62112 Mdot
.3947 .61818 Mdot
.43009 .54974 Mdot
.53718 .3677 Mdot
.45669 .63158 Mdot
.65612 .42207 Mdot
.57996 .6356 Mdot
.61627 .18703 Mdot
.72423 .63554 Mdot
.4662 .58035 Mdot
.44684 .60829 Mdot
.58361 .65384 Mdot
.44011 .56313 Mdot
.62645 .45492 Mdot
.41492 .8895 Mdot
.3253 .41224 Mdot
.53213 .36852 Mdot
.33876 .27395 Mdot
.44665 .55736 Mdot
.43363 .64229 Mdot
.83416 .40654 Mdot
.3124 .2841 Mdot
.65359 .42043 Mdot
.3784 .62644 Mdot
.50775 .32752 Mdot
.35145 .41757 Mdot
.61988 .44621 Mdot
.42572 .62599 Mdot
.44873 .59232 Mdot
.36246 .43186 Mdot
.38317 .69602 Mdot
.2151 .58166 Mdot
.6918 .43398 Mdot
.35876 .62684 Mdot
.49288 .41381 Mdot
.48445 .59972 Mdot
.24158 .64747 Mdot
.59483 .63281 Mdot
.64624 .46955 Mdot
.4999 .22015 Mdot
.47733 .62401 Mdot
.67015 .41576 Mdot
.66538 .43304 Mdot
.37774 .61731 Mdot
.66878 .62275 Mdot
.59135 .6496 Mdot
.6171 .64938 Mdot
.34706 .81458 Mdot
.31176 .52034 Mdot
.49458 .38134 Mdot
.68425 .43766 Mdot
.50882 .38918 Mdot
.37525 .43587 Mdot
.58783 .48129 Mdot
.51627 .38492 Mdot
.61274 .6531 Mdot
.48849 .4057 Mdot
.40368 .60129 Mdot
.66157 .43641 Mdot
.51433 .37645 Mdot
.44918 .55297 Mdot
.75709 .45099 Mdot
.71487 .39155 Mdot
.36415 .40363 Mdot
.32936 .38648 Mdot
.39325 .59241 Mdot
.45147 .3691 Mdot
.45482 .59103 Mdot
.64214 .47593 Mdot
.76191 .47257 Mdot
.4018 .55795 Mdot
.47971 .34522 Mdot
.55804 .63174 Mdot
.21664 .45323 Mdot
.37777 .65467 Mdot
.43161 .58928 Mdot
.45892 .62743 Mdot
.42515 .60454 Mdot
.69558 .29678 Mdot
.64361 .48334 Mdot
.73416 .63837 Mdot
.40456 .23019 Mdot
.61469 .60555 Mdot
.63269 .66457 Mdot
.20616 .50702 Mdot
.66789 .52344 Mdot
.67854 .43325 Mdot
.44094 .6265 Mdot
.69256 .56041 Mdot
.74353 .2846 Mdot
.86117 .48726 Mdot
.40265 .43341 Mdot
.4991 .31415 Mdot
.5777 .60644 Mdot
.51755 .33999 Mdot
.46294 .62079 Mdot
.5041 .58064 Mdot
.40325 .16839 Mdot
.61659 .44136 Mdot
.32426 .40683 Mdot
.4533 .62848 Mdot
.31472 .52378 Mdot
.50636 .35489 Mdot
.53458 .3474 Mdot
.43634 .56607 Mdot
.65823 .65073 Mdot
.22675 .30714 Mdot
.64025 .45674 Mdot
.78904 .51859 Mdot
.62775 .56846 Mdot
.77519 .55843 Mdot
.64704 .45392 Mdot
.38361 .38327 Mdot
.45915 .3305 Mdot
.43897 .71081 Mdot
.6121 .60433 Mdot
.32292 .43029 Mdot
.50169 .61582 Mdot
.58736 .60894 Mdot
.45883 .35461 Mdot
.63285 .61877 Mdot
.4229 .64547 Mdot
.6177 .46752 Mdot
.50794 .36289 Mdot
.64289 .41189 Mdot
.6674 .63846 Mdot
.35766 .42317 Mdot
.45398 .46377 Mdot
.62227 .76297 Mdot
.50672 .74228 Mdot
.45114 .56575 Mdot
.56892 .50318 Mdot
.4023 .61872 Mdot
.61691 .66336 Mdot
.4355 .60766 Mdot
.69246 .64208 Mdot
.51641 .36111 Mdot
.39117 .58062 Mdot
.42629 .63315 Mdot
.70086 .7132 Mdot
.43107 .57557 Mdot
.43279 .66261 Mdot
.43503 .62003 Mdot
.67946 .61808 Mdot
.51879 .62026 Mdot
.63758 .64449 Mdot
.37852 .36693 Mdot
.48747 .35838 Mdot
.34117 .38761 Mdot
.35425 .44512 Mdot
.32868 .48864 Mdot
.44315 .2611 Mdot
.73392 .36674 Mdot
.62603 .63411 Mdot
.66202 .42485 Mdot
.43094 .6077 Mdot
.42747 .18984 Mdot
.55602 .38933 Mdot
.49201 .31913 Mdot
.72534 .63415 Mdot
.35423 .61048 Mdot
.33256 .24449 Mdot
.39144 .6466 Mdot
.36087 .81084 Mdot
.38427 .55411 Mdot
.43491 .67005 Mdot
.52599 .38225 Mdot
.37703 .43863 Mdot
.42613 .56307 Mdot
.56837 .63022 Mdot
.33798 .43761 Mdot
.51845 .65895 Mdot
.43429 .39968 Mdot
.39356 .37441 Mdot
.67022 .71654 Mdot
.41233 .60815 Mdot
.50682 .36394 Mdot
.65042 .63697 Mdot
.20161 .46848 Mdot
.63599 .4442 Mdot
.62756 .41562 Mdot
.58405 .53675 Mdot
.83512 .52993 Mdot
.34514 .44265 Mdot
.3995 .71912 Mdot
.40478 .5879 Mdot
.4343 .31154 Mdot
.39579 .56429 Mdot
.74752 .29783 Mdot
.33926 .44675 Mdot
.6031 .65242 Mdot
.66733 .41975 Mdot
.64215 .65474 Mdot
.49795 .7485 Mdot
.52057 .30876 Mdot
.53715 .46411 Mdot
.49814 .35131 Mdot
.46371 .43128 Mdot
.60766 .63124 Mdot
.45155 .64213 Mdot
.13445 .57154 Mdot
.59906 .63691 Mdot
.60975 .59418 Mdot
.75761 .69264 Mdot
.83892 .5998 Mdot
.36327 .64814 Mdot
.57698 .62271 Mdot
.49272 .35143 Mdot
.34891 .4267 Mdot
.39863 .63016 Mdot
.40913 .60294 Mdot
.58697 .61024 Mdot
.5362 .36393 Mdot
.45338 .78381 Mdot
.47131 .3596 Mdot
.62597 .64725 Mdot
.48637 .36509 Mdot
.58108 .31712 Mdot
.52302 .3667 Mdot
.42691 .55927 Mdot
.43429 .60777 Mdot
.40931 .25832 Mdot
.62773 .61575 Mdot
.42057 .6325 Mdot
.40194 .64872 Mdot
.60651 .61952 Mdot
.32415 .36794 Mdot
.45694 .77851 Mdot
.47792 .59094 Mdot
.4189 .58493 Mdot
.36574 .42084 Mdot
.59725 .50227 Mdot
.3348 .70753 Mdot
.42843 .64327 Mdot
.33613 .4505 Mdot
.57137 .63304 Mdot
.45052 .5834 Mdot
.69132 .25165 Mdot
.61553 .29798 Mdot
.47124 .63024 Mdot
.52767 .35972 Mdot
.38288 .63814 Mdot
.30039 .24145 Mdot
.42381 .56623 Mdot
.61215 .62568 Mdot
.6411 .6125 Mdot
.63244 .79113 Mdot
.59488 .62415 Mdot
.48894 .32494 Mdot
.65312 .45193 Mdot
.75286 .32493 Mdot
.50621 .32872 Mdot
.37141 .58086 Mdot
.6367 .80086 Mdot
.4319 .65408 Mdot
.43413 .55375 Mdot
.24674 .3017 Mdot
.50996 .33528 Mdot
.64951 .61057 Mdot
.42276 .46228 Mdot
.43115 .53508 Mdot
.6496 .47006 Mdot
.50428 .61743 Mdot
.47879 .57802 Mdot
.25313 .31874 Mdot
.64718 .27298 Mdot
.66522 .47327 Mdot
.46882 .64332 Mdot
.4294 .64331 Mdot
.52904 .32396 Mdot
.44315 .61128 Mdot
.34647 .43 Mdot
.64214 .60599 Mdot
.52227 .35555 Mdot
.33594 .40896 Mdot
.47404 .6016 Mdot
.3448 .39744 Mdot
.5043 .3776 Mdot
.67508 .46595 Mdot
.46911 .61891 Mdot
.3698 .42894 Mdot
.34216 .39792 Mdot
.4049 .62279 Mdot
.63694 .61969 Mdot
.37855 .5588 Mdot
.43912 .57365 Mdot
.40314 .63914 Mdot
.59912 .6042 Mdot
.83813 .34455 Mdot
.40504 .5706 Mdot
.36003 .47352 Mdot
.6166 .59541 Mdot
.43029 .41485 Mdot
.52259 .3442 Mdot
.47439 .5746 Mdot
.66936 .46994 Mdot
.68787 .43696 Mdot
.45921 .35929 Mdot
.61046 .59198 Mdot
.34703 .2979 Mdot
.57298 .64942 Mdot
.43951 .53778 Mdot
.48594 .6229 Mdot
.54373 .82172 Mdot
.51022 .17196 Mdot
.65928 .6279 Mdot
.43075 .35304 Mdot
.44291 .48114 Mdot
.68374 .42767 Mdot
.51828 .32507 Mdot
.58015 .60401 Mdot
.63144 .59727 Mdot
.63758 .62785 Mdot
.31957 .42205 Mdot
.41394 .25797 Mdot
.66274 .62111 Mdot
.64362 .66089 Mdot
.4108 .59611 Mdot
.42952 .64228 Mdot
.22486 .45862 Mdot
.24441 .58056 Mdot
.34981 .3944 Mdot
.46474 .36283 Mdot
.29903 .79589 Mdot
.63838 .47386 Mdot
.72208 .69389 Mdot
.4159 .55439 Mdot
.12125 .61832 Mdot
.38849 .60046 Mdot
.44747 .61275 Mdot
.57863 .63418 Mdot
.37 .41675 Mdot
.33051 .42333 Mdot
.6091 .63856 Mdot
.62988 .66672 Mdot
.34529 .43035 Mdot
.80734 .49925 Mdot
.71372 .25983 Mdot
.51901 .30233 Mdot
.61079 .61455 Mdot
.62411 .75368 Mdot
.69412 .43666 Mdot
.53914 .64245 Mdot
.63027 .47351 Mdot
.49955 .35706 Mdot
.45306 .35853 Mdot
.65159 .46751 Mdot
.41555 .59556 Mdot
.49984 .38356 Mdot
.44605 .65332 Mdot
.78945 .56781 Mdot
.51684 .77253 Mdot
.36746 .26727 Mdot
.46515 .66814 Mdot
.38369 .37761 Mdot
.72812 .42496 Mdot
.46438 .58968 Mdot
.60959 .22599 Mdot
.32868 .40138 Mdot
.53469 .62939 Mdot
.63972 .47025 Mdot
.28206 .24715 Mdot
.47128 .62114 Mdot
.61498 .62424 Mdot
.67132 .43055 Mdot
.47666 .51447 Mdot
.75874 .50222 Mdot
.45735 .62702 Mdot
.14056 .61714 Mdot
.67182 .60762 Mdot
.52087 .36135 Mdot
.42021 .80578 Mdot
.66173 .63162 Mdot
.39522 .44513 Mdot
.44407 .22776 Mdot
.84074 .48034 Mdot
.65553 .62741 Mdot
.50087 .31062 Mdot
.62795 .65254 Mdot
.35676 .42554 Mdot
.57677 .59978 Mdot
.51158 .35623 Mdot
.43787 .5804 Mdot
.4724 .3496 Mdot
.32316 .39461 Mdot
.22051 .58628 Mdot
.66876 .47156 Mdot
.52591 .34412 Mdot
.66772 .45782 Mdot
.29382 .59438 Mdot
.36583 .24034 Mdot
.63248 .44394 Mdot
.37223 .75074 Mdot
.4875 .61255 Mdot
.66283 .63731 Mdot
.47146 .34424 Mdot
.49746 .24111 Mdot
.44741 .46629 Mdot
.60271 .60761 Mdot
.47714 .37473 Mdot
.59235 .53348 Mdot
.3892 .77515 Mdot
.39909 .6649 Mdot
.28997 .6249 Mdot
.60639 .61514 Mdot
.48481 .30818 Mdot
.18754 .51577 Mdot
.6215 .6569 Mdot
.48741 .33059 Mdot
.66853 .41819 Mdot
.65065 .44483 Mdot
.44636 .56843 Mdot
.62136 .42786 Mdot
.47323 .37697 Mdot
.72665 .41281 Mdot
.576 .6142 Mdot
.50179 .52832 Mdot
.36751 .44081 Mdot
.4801 .35788 Mdot
.42123 .64897 Mdot
.58683 .58896 Mdot
.5907 .2973 Mdot
.47809 .79451 Mdot
.20632 .66154 Mdot
.46946 .35072 Mdot
.6336 .60051 Mdot
.61773 .62289 Mdot
.37202 .64449 Mdot
.49506 .50046 Mdot
.35394 .29271 Mdot
.37042 .51336 Mdot
.39609 .49103 Mdot
.48373 .39202 Mdot
.5513 .35692 Mdot
.46656 .55691 Mdot
.41719 .60982 Mdot
.67924 .42475 Mdot
.43381 .58129 Mdot
.58429 .63665 Mdot
.44266 .56571 Mdot
.64745 .46017 Mdot
.50088 .34679 Mdot
.47037 .61442 Mdot
.3556 .40257 Mdot
.69526 .44508 Mdot
.6465 .41537 Mdot
.47911 .35168 Mdot
.59021 .60697 Mdot
.30087 .37429 Mdot
.47008 .36153 Mdot
.41277 .60739 Mdot
.61895 .50619 Mdot
.40828 .64548 Mdot
.60674 .68544 Mdot
.62157 .65752 Mdot
.51982 .34961 Mdot
.57107 .61987 Mdot
.67401 .45128 Mdot
.41509 .22742 Mdot
.4327 .59918 Mdot
.49319 .32911 Mdot
.51788 .26571 Mdot
.5009 .67857 Mdot
.62196 .67003 Mdot
.73084 .39254 Mdot
.62677 .66499 Mdot
.45933 .34772 Mdot
.70541 .73215 Mdot
.3338 .44 Mdot
.49365 .3188 Mdot
.58263 .18255 Mdot
.49206 .33824 Mdot
.4226 .57337 Mdot
.39415 .59334 Mdot
.52254 .35972 Mdot
.36326 .43375 Mdot
.21703 .42895 Mdot
.49051 .39719 Mdot
.65119 .61457 Mdot
.79576 .58425 Mdot
.16644 .57398 Mdot
.60961 .47662 Mdot
.6728 .42332 Mdot
.40535 .53807 Mdot
.43066 .66774 Mdot
.62354 .46368 Mdot
.64464 .4144 Mdot
.31558 .41587 Mdot
.47145 .33691 Mdot
.68007 .61265 Mdot
.68574 .40664 Mdot
.4076 .52428 Mdot
.43325 .26448 Mdot
.38737 .66224 Mdot
.63653 .5656 Mdot
.40018 .56342 Mdot
.36793 .49214 Mdot
.64628 .46113 Mdot
.38803 .63121 Mdot
.38075 .64488 Mdot
.65849 .47294 Mdot
.34911 .42928 Mdot
.69436 .49436 Mdot
.49417 .36735 Mdot
.74561 .26206 Mdot
.41132 .66166 Mdot
.42013 .57212 Mdot
.68063 .45585 Mdot
.34964 .32977 Mdot
.62337 .60336 Mdot
.63292 .65894 Mdot
.51545 .38139 Mdot
.47286 .47363 Mdot
.4746 .57789 Mdot
.455 .58178 Mdot
.50348 .36927 Mdot
.51688 .32572 Mdot
.69432 .35932 Mdot
.39795 .60047 Mdot
.67372 .43564 Mdot
.29087 .43887 Mdot
.64761 .46234 Mdot
.41331 .6469 Mdot
.41404 .57485 Mdot
.42848 .55946 Mdot
.42193 .64846 Mdot
.62817 .42893 Mdot
.38786 .62163 Mdot
.52768 .62011 Mdot
.62164 .60053 Mdot
.44549 .63346 Mdot
.39258 .49265 Mdot
.42702 .58617 Mdot
.34772 .42761 Mdot
.35584 .71993 Mdot
.47115 .62062 Mdot
.46907 .57241 Mdot
.51904 .39549 Mdot
.44299 .5938 Mdot
.6398 .47511 Mdot
.62114 .61175 Mdot
.68408 .43912 Mdot
.68889 .44136 Mdot
.45985 .37346 Mdot
.31126 .41679 Mdot
.45151 .55883 Mdot
.31936 .40957 Mdot
.37287 .58257 Mdot
.47697 .62559 Mdot
.4285 .23456 Mdot
.37376 .81851 Mdot
.2202 .60966 Mdot
.43077 .59899 Mdot
.50616 .33515 Mdot
.52181 .34525 Mdot
.49247 .67272 Mdot
.39335 .66223 Mdot
.62423 .44922 Mdot
.68778 .43301 Mdot
.23805 .53197 Mdot
.27676 .30179 Mdot
.34805 .42815 Mdot
.57295 .48935 Mdot
.47033 .63992 Mdot
.39968 .64429 Mdot
.42138 .65653 Mdot
.50707 .38876 Mdot
.385 .48035 Mdot
.49679 .32001 Mdot
.74621 .59015 Mdot
.65984 .46628 Mdot
.46566 .62536 Mdot
.68413 .5821 Mdot
.60225 .64366 Mdot
.62178 .61239 Mdot
.64651 .41639 Mdot
.53961 .38884 Mdot
.21508 .49235 Mdot
.86849 .50777 Mdot
.65908 .59642 Mdot
.36158 .39741 Mdot
.46709 .58839 Mdot
.4949 .34484 Mdot
.62123 .65212 Mdot
.35382 .39256 Mdot
.45645 .64079 Mdot
.41536 .25724 Mdot
.42487 .59887 Mdot
.62438 .53902 Mdot
.64473 .62648 Mdot
.74104 .2899 Mdot
.62746 .59002 Mdot
.69556 .44607 Mdot
.63667 .46614 Mdot
.40026 .58297 Mdot
.48989 .82591 Mdot
.65117 .65181 Mdot
.6593 .49627 Mdot
.32748 .44204 Mdot
.59963 .31012 Mdot
.35399 .4295 Mdot
.51927 .36046 Mdot
.3409 .43956 Mdot
.51361 .35803 Mdot
.23002 .5589 Mdot
.68574 .64807 Mdot
.33055 .40784 Mdot
.49638 .27425 Mdot
.4023 .66983 Mdot
.35627 .39829 Mdot
.46475 .5472 Mdot
.58844 .68198 Mdot
.4996 .37108 Mdot
.34422 .4447 Mdot
.44822 .64347 Mdot
.39795 .18193 Mdot
.64893 .42259 Mdot
.62398 .4546 Mdot
.45106 .54134 Mdot
.47041 .38503 Mdot
.56735 .62319 Mdot
.70827 .28847 Mdot
.70102 .44378 Mdot
.40188 .57582 Mdot
.43071 .56332 Mdot
.63484 .66389 Mdot
.70693 .64185 Mdot
.405 .57979 Mdot
.34943 .56397 Mdot
.39709 .59796 Mdot
.65121 .41718 Mdot
.64391 .65332 Mdot
.61926 .61839 Mdot
.48123 .37766 Mdot
.5836 .62821 Mdot
.45216 .69091 Mdot
.6973 .58117 Mdot
.35125 .58273 Mdot
.66933 .45087 Mdot
.72741 .591 Mdot
.74585 .59415 Mdot
.53317 .17954 Mdot
.65201 .65977 Mdot
.39366 .56857 Mdot
.58734 .60568 Mdot
.35185 .4202 Mdot
.62893 .62227 Mdot
.57664 .60791 Mdot
.45831 .59122 Mdot
.45715 .62398 Mdot
.50972 .3462 Mdot
.47787 .49248 Mdot
.60108 .60039 Mdot
.38906 .60543 Mdot
.43876 .6661 Mdot
.43104 .65802 Mdot
.5749 .41458 Mdot
.65888 .63656 Mdot
.79212 .64126 Mdot
.27034 .46568 Mdot
.59933 .6013 Mdot
.23936 .28634 Mdot
.53818 .26564 Mdot
.45442 .32867 Mdot
.67967 .39973 Mdot
.39626 .60368 Mdot
.51594 .32945 Mdot
.4637 .6204 Mdot
.63542 .56466 Mdot
.45094 .59673 Mdot
.34535 .43221 Mdot
.44004 .65702 Mdot
.45582 .35766 Mdot
.46944 .35727 Mdot
.41207 .56862 Mdot
.46844 .61196 Mdot
.21563 .56115 Mdot
.65976 .65974 Mdot
.6285 .61074 Mdot
.33527 .31074 Mdot
.34235 .40294 Mdot
.64772 .46958 Mdot
.43673 .61435 Mdot
.47041 .3817 Mdot
.46941 .3547 Mdot
.66001 .63814 Mdot
.48257 .37292 Mdot
.6409 .45619 Mdot
.4359 .60197 Mdot
.62367 .46269 Mdot
.31873 .42214 Mdot
.65074 .64713 Mdot
.45112 .63061 Mdot
.41101 .59573 Mdot
.64142 .61265 Mdot
.46396 .5586 Mdot
.36517 .42297 Mdot
.48943 .33777 Mdot
.65482 .63464 Mdot
.65238 .45012 Mdot
.51791 .35843 Mdot
.39772 .63499 Mdot
.25922 .75067 Mdot
.42181 .57582 Mdot
.39418 .61189 Mdot
.57285 .17317 Mdot
.4545 .65054 Mdot
.46955 .3477 Mdot
.60884 .65435 Mdot
.47298 .66209 Mdot
.31236 .4877 Mdot
.86816 .41649 Mdot
.49048 .31995 Mdot
.46523 .5846 Mdot
.45171 .17831 Mdot
.45442 .57795 Mdot
.55538 .81062 Mdot
.48719 .28825 Mdot
.4523 .43946 Mdot
.40902 .54801 Mdot
.64583 .43844 Mdot
.51025 .34359 Mdot
.5151 .36374 Mdot
.77578 .63015 Mdot
.4573 .58762 Mdot
.60136 .52329 Mdot
.45162 .63793 Mdot
.64738 .45006 Mdot
.23996 .50089 Mdot
.46783 .35456 Mdot
.23304 .66949 Mdot
.4014 .61555 Mdot
.6466 .6019 Mdot
.48442 .40583 Mdot
.57711 .35404 Mdot
.40214 .63744 Mdot
.32525 .39973 Mdot
.69513 .41439 Mdot
.46353 .6616 Mdot
.66356 .45236 Mdot
.40562 .64124 Mdot
.33469 .60175 Mdot
.4234 .81428 Mdot
.63777 .62359 Mdot
.66988 .41989 Mdot
.61107 .49321 Mdot
.38347 .60593 Mdot
.65533 .62945 Mdot
.60995 .60464 Mdot
.3174 .40884 Mdot
.55929 .45272 Mdot
.73113 .51088 Mdot
.55503 .78443 Mdot
.79058 .60722 Mdot
.50342 .4052 Mdot
.66877 .30586 Mdot
.40673 .63289 Mdot
.29913 .32634 Mdot
.65162 .47657 Mdot
.42847 .57287 Mdot
.48168 .70131 Mdot
.60898 .64324 Mdot
.41429 .58415 Mdot
.33769 .42704 Mdot
.30865 .33817 Mdot
.28801 .34248 Mdot
.45306 .21812 Mdot
.49815 .35289 Mdot
.50545 .58142 Mdot
.33877 .63356 Mdot
.52793 .37377 Mdot
.48431 .5813 Mdot
.48452 .3345 Mdot
.81949 .51414 Mdot
.36132 .40073 Mdot
.65687 .62247 Mdot
.568 .31083 Mdot
.46615 .56672 Mdot
.4884 .62097 Mdot
.32002 .38956 Mdot
.41648 .61397 Mdot
.38362 .80359 Mdot
.56445 .31998 Mdot
.51353 .37862 Mdot
.63762 .62679 Mdot
.45854 .56559 Mdot
.56934 .45765 Mdot
.44312 .57481 Mdot
.58547 .73776 Mdot
.4659 .57054 Mdot
.74578 .50318 Mdot
.64145 .61979 Mdot
.66438 .45492 Mdot
.38169 .604 Mdot
.45184 .6031 Mdot
.27926 .43704 Mdot
.38872 .55118 Mdot
.38533 .6204 Mdot
.57408 .64446 Mdot
.62101 .6536 Mdot
.63558 .64442 Mdot
.46671 .32351 Mdot
.26387 .3107 Mdot
.67745 .44091 Mdot
.50459 .63898 Mdot
.67687 .40728 Mdot
.45862 .80121 Mdot
.3597 .39635 Mdot
.46902 .19635 Mdot
.4311 .62762 Mdot
.6261 .63998 Mdot
.61684 .24747 Mdot
.57629 .64147 Mdot
.5551 .48822 Mdot
.6635 .43407 Mdot
.60392 .63817 Mdot
.45102 .60968 Mdot
.44407 .47395 Mdot
.39915 .20282 Mdot
.68024 .44896 Mdot
.36882 .58883 Mdot
.48784 .31098 Mdot
.3711 .25678 Mdot
.24024 .7245 Mdot
.64984 .42131 Mdot
.605 .45107 Mdot
.45886 .58713 Mdot
.60243 .64542 Mdot
.64268 .44385 Mdot
.63653 .43316 Mdot
.48444 .37441 Mdot
.45342 .6257 Mdot
.44801 .62749 Mdot
.45945 .34121 Mdot
.68495 .44337 Mdot
.42447 .54151 Mdot
.43376 .6715 Mdot
.37726 .17197 Mdot
.5491 .53321 Mdot
.76472 .27201 Mdot
.45002 .68962 Mdot
.45257 .71587 Mdot
.72506 .29505 Mdot
.62672 .59557 Mdot
.47604 .61649 Mdot
.48512 .64117 Mdot
.47192 .37593 Mdot
.43557 .58982 Mdot
.46856 .30425 Mdot
.67426 .42789 Mdot
.26836 .26662 Mdot
.72259 .56229 Mdot
.82577 .48645 Mdot
.43765 .58888 Mdot
.69388 .66638 Mdot
.34215 .41481 Mdot
.64626 .48542 Mdot
.64032 .64796 Mdot
.43218 .64833 Mdot
.21543 .5641 Mdot
.49558 .31929 Mdot
.58819 .61668 Mdot
.20295 .47182 Mdot
.38869 .3837 Mdot
.41454 .64634 Mdot
.48276 .31506 Mdot
.62845 .242 Mdot
.43872 .5201 Mdot
.68356 .47037 Mdot
.34828 .4316 Mdot
.5133 .34316 Mdot
.68958 .43617 Mdot
.65052 .58572 Mdot
.59849 .63138 Mdot
.56459 .61576 Mdot
.25491 .65207 Mdot
.5314 .3653 Mdot
.33816 .41405 Mdot
.29351 .29288 Mdot
.26632 .34545 Mdot
.34293 .43208 Mdot
.45271 .3554 Mdot
.62133 .65307 Mdot
.61476 .63964 Mdot
.62038 .61159 Mdot
.21624 .62888 Mdot
.62897 .59316 Mdot
.74012 .67356 Mdot
.43716 .65348 Mdot
.34509 .58262 Mdot
.46174 .58259 Mdot
.6226 .45568 Mdot
.64845 .62293 Mdot
.45199 .45834 Mdot
.37298 .62016 Mdot
.39668 .2188 Mdot
.43542 .56948 Mdot
.62634 .47901 Mdot
.40795 .59035 Mdot
.68325 .71821 Mdot
.59438 .60146 Mdot
.43225 .59533 Mdot
.6454 .48075 Mdot
.35001 .40501 Mdot
.60054 .66618 Mdot
.4585 .62746 Mdot
.74014 .38461 Mdot
.44849 .65359 Mdot
.81457 .46399 Mdot
.5234 .5382 Mdot
.36178 .39771 Mdot
.58396 .56327 Mdot
.51842 .32124 Mdot
.34149 .59573 Mdot
.45703 .53708 Mdot
.67358 .45583 Mdot
.57201 .29573 Mdot
.48822 .35688 Mdot
.39982 .44347 Mdot
.50924 .61581 Mdot
.32846 .39005 Mdot
.64597 .66661 Mdot
.62039 .4617 Mdot
.49094 .59291 Mdot
.37733 .64818 Mdot
.7667 .60733 Mdot
.51807 .60769 Mdot
.44026 .564 Mdot
.3345 .38334 Mdot
.73657 .66349 Mdot
.42329 .58895 Mdot
.56054 .48599 Mdot
.58747 .59518 Mdot
.41683 .54095 Mdot
.731 .69023 Mdot
.39335 .59299 Mdot
.58901 .62569 Mdot
.63308 .67352 Mdot
.68777 .51352 Mdot
.31618 .43046 Mdot
.47421 .57522 Mdot
.63721 .78829 Mdot
.40522 .61327 Mdot
.6726 .43876 Mdot
.42278 .66503 Mdot
.50879 .3557 Mdot
.20949 .59677 Mdot
.48698 .38165 Mdot
.47649 .58437 Mdot
.61645 .61142 Mdot
.67031 .46424 Mdot
.25598 .67738 Mdot
.39064 .27704 Mdot
.7271 .67764 Mdot
.84016 .44175 Mdot
.35143 .44033 Mdot
.30957 .42462 Mdot
.61962 .46294 Mdot
.43053 .59481 Mdot
.72996 .7195 Mdot
.38695 .55058 Mdot
.41715 .58601 Mdot
.45237 .59757 Mdot
.34567 .25597 Mdot
.68247 .42948 Mdot
.48693 .36959 Mdot
.40861 .57754 Mdot
.38696 .62143 Mdot
.62545 .59597 Mdot
.34572 .40023 Mdot
.5223 .34402 Mdot
.32505 .40925 Mdot
.50366 .3419 Mdot
.25178 .276 Mdot
.38164 .63252 Mdot
.34992 .40768 Mdot
.6999 .41233 Mdot
.59091 .60801 Mdot
.69187 .57348 Mdot
.51767 .3627 Mdot
.46509 .36662 Mdot
.42032 .56817 Mdot
.58892 .62768 Mdot
.57358 .62662 Mdot
.35363 .41952 Mdot
.63281 .45024 Mdot
.47158 .61904 Mdot
.47863 .62537 Mdot
.66774 .68412 Mdot
.47535 .38638 Mdot
.61774 .54381 Mdot
.71059 .32818 Mdot
.42914 .59737 Mdot
.57541 .61952 Mdot
.46391 .60403 Mdot
.74244 .32981 Mdot
.59497 .6394 Mdot
.39174 .59278 Mdot
.20745 .40467 Mdot
.54064 .3895 Mdot
.70027 .5235 Mdot
.42102 .5612 Mdot
.79652 .359 Mdot
.41801 .63521 Mdot
.31718 .19719 Mdot
.45067 .28178 Mdot
.48528 .60126 Mdot
.39543 .62785 Mdot
.48878 .77989 Mdot
.47592 .59779 Mdot
.4585 .34902 Mdot
.23799 .41651 Mdot
.56599 .62718 Mdot
.74775 .41889 Mdot
.37035 .72062 Mdot
.3407 .44657 Mdot
.51665 .3806 Mdot
.54664 .33314 Mdot
.33188 .42912 Mdot
.61013 .61695 Mdot
.42515 .6048 Mdot
.50055 .46708 Mdot
.49812 .39261 Mdot
.4585 .68105 Mdot
.66981 .43866 Mdot
.64346 .33087 Mdot
.56073 .34807 Mdot
.65553 .45491 Mdot
.44053 .63538 Mdot
.47486 .78111 Mdot
.28113 .65702 Mdot
.69931 .24199 Mdot
.69084 .43835 Mdot
.67931 .45272 Mdot
.20557 .6058 Mdot
.37148 .43879 Mdot
.78413 .58679 Mdot
.75307 .5004 Mdot
.65364 .47028 Mdot
.47299 .52132 Mdot
.47942 .32543 Mdot
.7348 .4423 Mdot
.53318 .63156 Mdot
.4663 .63919 Mdot
.45117 .60759 Mdot
.63281 .45613 Mdot
.50347 .67576 Mdot
.40488 .79955 Mdot
.66536 .45944 Mdot
.53054 .60041 Mdot
.53217 .43549 Mdot
.52623 .25529 Mdot
.46225 .35277 Mdot
.3146 .42548 Mdot
.30744 .44044 Mdot
.64387 .60171 Mdot
.31266 .42124 Mdot
.30691 .33431 Mdot
.42263 .61714 Mdot
.65425 .46301 Mdot
.59234 .30112 Mdot
.65457 .44603 Mdot
.33053 .42632 Mdot
.35304 .38834 Mdot
.62187 .6007 Mdot
.62971 .61476 Mdot
.45328 .7255 Mdot
.25849 .52895 Mdot
.44422 .572 Mdot
.5095 .22325 Mdot
.57322 .61748 Mdot
.44516 .68587 Mdot
.31127 .41226 Mdot
.34623 .40274 Mdot
.30355 .46093 Mdot
.43745 .62331 Mdot
.59637 .80131 Mdot
.43809 .6194 Mdot
.24381 .50705 Mdot
.40913 .55802 Mdot
.48339 .37382 Mdot
.43845 .62784 Mdot
.27001 .39655 Mdot
.48648 .57883 Mdot
.42337 .66843 Mdot
.49227 .38968 Mdot
.47109 .65862 Mdot
.50735 .35722 Mdot
.46754 .57787 Mdot
.3557 .44811 Mdot
.49364 .38694 Mdot
.31283 .50841 Mdot
.32419 .4682 Mdot
.45308 .34815 Mdot
.32345 .39589 Mdot
.34974 .44664 Mdot
.33138 .52184 Mdot
.6401 .64843 Mdot
.54697 .62675 Mdot
.4316 .59185 Mdot
.52945 .33553 Mdot
.67864 .42616 Mdot
.38887 .61445 Mdot
.45558 .65829 Mdot
.40339 .56654 Mdot
.6467 .60345 Mdot
.35891 .28669 Mdot
.35317 .41325 Mdot
.46673 .32712 Mdot
.30787 .36962 Mdot
.45812 .37759 Mdot
.4053 .66642 Mdot
.49509 .62636 Mdot
.42218 .71899 Mdot
.59025 .26349 Mdot
.19804 .61071 Mdot
.59597 .62924 Mdot
.52722 .35655 Mdot
.36328 .44446 Mdot
.38946 .6708 Mdot
.62467 .64457 Mdot
.51102 .35639 Mdot
.42548 .5995 Mdot
.36688 .59451 Mdot
.72776 .61297 Mdot
.35436 .68922 Mdot
.347 .48533 Mdot
.45859 .35861 Mdot
.50873 .31532 Mdot
.27885 .33954 Mdot
.38744 .40356 Mdot
.44945 .46424 Mdot
.44652 .58232 Mdot
.32387 .40186 Mdot
.62073 .65196 Mdot
.26839 .65834 Mdot
.62958 .45844 Mdot
.48569 .49631 Mdot
.43747 .59061 Mdot
.43369 .42488 Mdot
.61637 .60988 Mdot
.34102 .42728 Mdot
.63347 .45802 Mdot
.30885 .39829 Mdot
.52253 .38106 Mdot
.84578 .525 Mdot
.40899 .6133 Mdot
.43053 .5665 Mdot
.68597 .45984 Mdot
.61511 .64714 Mdot
.31424 .39523 Mdot
.79411 .56298 Mdot
.51036 .37439 Mdot
.71492 .73469 Mdot
.58192 .63047 Mdot
.6562 .72359 Mdot
.46863 .32817 Mdot
.64791 .41604 Mdot
.31878 .52738 Mdot
.64639 .45819 Mdot
.47061 .5769 Mdot
.62374 .62945 Mdot
.66188 .42205 Mdot
.48503 .50268 Mdot
.43539 .18192 Mdot
.63675 .74414 Mdot
.42848 .61464 Mdot
.35023 .20605 Mdot
.78887 .43356 Mdot
.67029 .64954 Mdot
.67292 .46845 Mdot
.43362 .57089 Mdot
.48846 .59883 Mdot
.40478 .61033 Mdot
.66039 .42771 Mdot
.4723 .23826 Mdot
.5028 .37169 Mdot
.4605 .58483 Mdot
.31596 .41571 Mdot
.50019 .35925 Mdot
.57006 .31719 Mdot
.46487 .35692 Mdot
.6641 .6519 Mdot
.42515 .66554 Mdot
.62617 .49097 Mdot
.25353 .24692 Mdot
.68315 .44228 Mdot
.45146 .35985 Mdot
.39948 .64994 Mdot
.59069 .28691 Mdot
.6327 .64474 Mdot
.5069 .37705 Mdot
.42134 .57184 Mdot
.56329 .30288 Mdot
.22076 .59642 Mdot
.46564 .35587 Mdot
.62272 .64771 Mdot
.66474 .23187 Mdot
.43431 .58443 Mdot
.41354 .63034 Mdot
.60712 .6358 Mdot
.39411 .75661 Mdot
.19076 .50606 Mdot
.46693 .60887 Mdot
.66245 .45624 Mdot
.80615 .65545 Mdot
.42056 .67051 Mdot
.25925 .46039 Mdot
.51149 .34548 Mdot
.71469 .47443 Mdot
.6014 .53801 Mdot
.38731 .66999 Mdot
.78842 .56699 Mdot
.60857 .42293 Mdot
.3348 .23261 Mdot
.46458 .30644 Mdot
.40677 .36585 Mdot
.30818 .23738 Mdot
.63168 .47791 Mdot
.67879 .66734 Mdot
.79212 .51151 Mdot
.27589 .72687 Mdot
.66914 .24321 Mdot
.36919 .34726 Mdot
.21332 .55978 Mdot
.50091 .45486 Mdot
.49968 .33723 Mdot
.30013 .39209 Mdot
.46342 .62294 Mdot
.78763 .42885 Mdot
.61894 .78741 Mdot
.50484 .83347 Mdot
.35562 .2018 Mdot
.54688 .80694 Mdot
.43159 .18985 Mdot
.54643 .17737 Mdot
.4344 .70661 Mdot
.6003 .25921 Mdot
.71248 .74215 Mdot
.22488 .38401 Mdot
.80404 .60142 Mdot
.35378 .57497 Mdot
.56128 .49955 Mdot
.82537 .4478 Mdot
.67942 .70494 Mdot
.40357 .78951 Mdot
.48762 .37961 Mdot
.61865 .65898 Mdot
.78743 .50068 Mdot
.62186 .66638 Mdot
.65162 .52429 Mdot
.67065 .22948 Mdot
.45465 .1729 Mdot
.69128 .71528 Mdot
.76777 .31464 Mdot
.49834 .69848 Mdot
.54095 .87011 Mdot
.49334 .39525 Mdot
.66097 .62497 Mdot
.38181 .45305 Mdot
.27514 .33667 Mdot
.76024 .57258 Mdot
.7956 .48407 Mdot
.41038 .24171 Mdot
.28307 .56256 Mdot
.61469 .62265 Mdot
.57406 .55853 Mdot
.68972 .48648 Mdot
.72702 .56749 Mdot
.23289 .42332 Mdot
.58745 .19746 Mdot
.50722 .47664 Mdot
.74355 .40597 Mdot
.65844 .32076 Mdot
.23663 .71566 Mdot
.28078 .46524 Mdot
.40298 .68785 Mdot
.63626 .52586 Mdot
.73313 .30451 Mdot
.30704 .74285 Mdot
.25281 .5486 Mdot
.27255 .3395 Mdot
.22077 .34775 Mdot
.77827 .37575 Mdot
.15684 .4575 Mdot
.55511 .61658 Mdot
.43506 .56298 Mdot
.41028 .74765 Mdot
.65016 .77877 Mdot
.36325 .39439 Mdot
.46801 .22278 Mdot
.33012 .44133 Mdot
.65507 .6007 Mdot
.20627 .5681 Mdot
.73118 .68389 Mdot
.65066 .78382 Mdot
.31535 .44569 Mdot
.45815 .67116 Mdot
.88371 .57947 Mdot
.36606 .22281 Mdot
.69721 .54494 Mdot
.36084 .1784 Mdot
.42992 .44056 Mdot
.48737 .5208 Mdot
.66341 .42298 Mdot
.30678 .23066 Mdot
.61774 .63603 Mdot
.16126 .40976 Mdot
.30573 .21095 Mdot
.33808 .70482 Mdot
.75908 .2205 Mdot
.29579 .30946 Mdot
.44622 .43768 Mdot
.63076 .40118 Mdot
.29275 .49654 Mdot
.36738 .77769 Mdot
.32435 .63898 Mdot
.60756 .29287 Mdot
.83718 .41914 Mdot
.33036 .2265 Mdot
.67893 .75908 Mdot
.83522 .54973 Mdot
.29506 .74632 Mdot
.57675 .47009 Mdot
.52886 .64595 Mdot
.55192 .32506 Mdot
.56995 .20507 Mdot
.23156 .30914 Mdot
.27041 .46047 Mdot
.87573 .42993 Mdot
.36522 .38278 Mdot
.42602 .28286 Mdot
.66761 .21604 Mdot
.29236 .56092 Mdot
.56006 .54989 Mdot
.24446 .39851 Mdot
.42786 .68393 Mdot
.29778 .3629 Mdot
.50255 .21178 Mdot
.66009 .54191 Mdot
.23426 .38034 Mdot
.66954 .25934 Mdot
.76455 .60832 Mdot
.52932 .77022 Mdot
.2612 .34137 Mdot
.5805 .64765 Mdot
.27028 .55693 Mdot
.55655 .54364 Mdot
.44243 .17147 Mdot
.60704 .44197 Mdot
.48931 .15428 Mdot
.19408 .50829 Mdot
.37824 .58761 Mdot
.43632 .53238 Mdot
.5445 .59327 Mdot
.2677 .53158 Mdot
.44875 .67092 Mdot
.74317 .60593 Mdot
.50709 .16819 Mdot
.51812 .6833 Mdot
.68823 .49582 Mdot
.56548 .29179 Mdot
.68406 .22501 Mdot
.44226 .74389 Mdot
.39059 .4105 Mdot
.22781 .47524 Mdot
.27405 .74418 Mdot
.48749 .36099 Mdot
.68981 .74539 Mdot
.68367 .47096 Mdot
.23548 .61966 Mdot
.55584 .78699 Mdot
.34027 .72663 Mdot
.50849 .16801 Mdot
.37585 .36452 Mdot
.20173 .53925 Mdot
.29905 .59954 Mdot
.76257 .691 Mdot
.53306 .25451 Mdot
.50329 .61805 Mdot
.77242 .43271 Mdot
.36339 .4345 Mdot
.48635 .74446 Mdot
.79872 .64441 Mdot
.37353 .31924 Mdot
.49195 .57219 Mdot
.31183 .69203 Mdot
.50317 .41581 Mdot
.44841 .47552 Mdot
.15833 .58411 Mdot
.39566 .66664 Mdot
.28595 .30007 Mdot
.78758 .39362 Mdot
.2759 .49591 Mdot
.7235 .27367 Mdot
.71678 .3074 Mdot
.16945 .42026 Mdot
.34213 .19595 Mdot
.37865 .28208 Mdot
.29938 .25009 Mdot
.41492 .16797 Mdot
.16783 .44272 Mdot
.46489 .53781 Mdot
.69055 .45608 Mdot
.21469 .71785 Mdot
.46208 .34521 Mdot
.32365 .26464 Mdot
.78985 .60855 Mdot
.56968 .35599 Mdot
.68186 .61263 Mdot
.34956 .66068 Mdot
.50844 .45949 Mdot
.67206 .64316 Mdot
.46467 .66325 Mdot
.16724 .56155 Mdot
.19166 .39278 Mdot
.16249 .50604 Mdot
.79351 .37675 Mdot
.28034 .26301 Mdot
.47917 .43627 Mdot
.70068 .69839 Mdot
.49591 .66969 Mdot
.44708 .64771 Mdot
.39057 .45974 Mdot
.29826 .30681 Mdot
.30954 .69473 Mdot
.76043 .54802 Mdot
.65514 .66325 Mdot
.48398 .21777 Mdot
.58941 .8935 Mdot
.48832 .7145 Mdot
.74631 .68107 Mdot
.28289 .34234 Mdot
.26072 .51775 Mdot
.55537 .20973 Mdot
.33916 .71526 Mdot
.56484 .17542 Mdot
.6748 .63166 Mdot
.80186 .59674 Mdot
.38597 .34081 Mdot
.40395 .50289 Mdot
.36535 .28002 Mdot
.47185 .17946 Mdot
.60781 .38913 Mdot
.28689 .69458 Mdot
.76647 .49008 Mdot
.36316 .75229 Mdot
.46822 .28929 Mdot
.65457 .33438 Mdot
.78841 .6545 Mdot
.67094 .29328 Mdot
.25089 .48827 Mdot
.53925 .44054 Mdot
.60137 .56869 Mdot
.61105 .41949 Mdot
.25545 .48627 Mdot
.38493 .49782 Mdot
.28644 .27464 Mdot
.23631 .23663 Mdot
.20084 .63902 Mdot
.7464 .26744 Mdot
.52864 .2172 Mdot
.49069 .57411 Mdot
.61305 .17989 Mdot
.15234 .49605 Mdot
.28947 .21231 Mdot
.64806 .3568 Mdot
.46038 .30693 Mdot
.6582 .41013 Mdot
.1762 .55548 Mdot
.45896 .24726 Mdot
.60554 .18802 Mdot
.25086 .38984 Mdot
.66332 .40607 Mdot
.38586 .82578 Mdot
.2207 .36014 Mdot
.58509 .77762 Mdot
.35766 .69095 Mdot
.43335 .54688 Mdot
.66895 .73596 Mdot
.62745 .66583 Mdot
.67447 .31264 Mdot
.25941 .54285 Mdot
.47639 .35719 Mdot
.38193 .4655 Mdot
.79234 .46868 Mdot
.44113 .65648 Mdot
.60415 .49108 Mdot
.64914 .65899 Mdot
.59519 .26393 Mdot
.71112 .58447 Mdot
.22484 .30863 Mdot
.33421 .28161 Mdot
.3982 .55647 Mdot
.27425 .48982 Mdot
.35605 .28318 Mdot
.18708 .51459 Mdot
.61511 .45435 Mdot
.37985 .19039 Mdot
.5404 .50017 Mdot
.26859 .555 Mdot
.6473 .75912 Mdot
.59218 .68098 Mdot
.48454 .63319 Mdot
.67812 .28525 Mdot
.57477 .72868 Mdot
.4656 .48678 Mdot
.52406 .64005 Mdot
.54531 .64916 Mdot
.62988 .18217 Mdot
.30815 .3415 Mdot
.64525 .32214 Mdot
.4082 .18155 Mdot
.65407 .43589 Mdot
.58262 .60987 Mdot
.29675 .42945 Mdot
.80491 .54448 Mdot
.60397 .71755 Mdot
.2209 .59782 Mdot
.56653 .3528 Mdot
.38681 .30982 Mdot
.41598 .18477 Mdot
.37229 .19868 Mdot
.56884 .8292 Mdot
.63172 .67176 Mdot
.45418 .69888 Mdot
.80256 .56728 Mdot
.6068 .65625 Mdot
.74791 .62565 Mdot
.73854 .62372 Mdot
.24937 .29361 Mdot
.62398 .50168 Mdot
.82807 .40227 Mdot
.34061 .49115 Mdot
.45582 .23179 Mdot
.25252 .67561 Mdot
.78044 .66164 Mdot
.44422 .18924 Mdot
.46161 .52307 Mdot
.50683 .79091 Mdot
.34844 .58692 Mdot
.66676 .57942 Mdot
.29544 .77938 Mdot
.30041 .44337 Mdot
.65948 .72428 Mdot
.67279 .25871 Mdot
.41792 .60747 Mdot
.20316 .65232 Mdot
.80334 .51608 Mdot
.20453 .60941 Mdot
.68353 .40455 Mdot
.43295 .64178 Mdot
.49254 .58753 Mdot
.24577 .45421 Mdot
.68986 .51416 Mdot
.2727 .29523 Mdot
.81875 .62439 Mdot
.62946 .23653 Mdot
.61759 .78753 Mdot
.29842 .29277 Mdot
.60546 .19583 Mdot
.78429 .42011 Mdot
.55582 .46271 Mdot
.30615 .30206 Mdot
.30187 .54922 Mdot
.76911 .32115 Mdot
.39808 .48405 Mdot
.70854 .40419 Mdot
.76535 .58203 Mdot
.7157 .32816 Mdot
.26457 .66691 Mdot
.41508 .64169 Mdot
.20307 .47147 Mdot
.56393 .1845 Mdot
.5876 .81636 Mdot
.35241 .78256 Mdot
.19037 .62423 Mdot
.57954 .75107 Mdot
.71399 .31775 Mdot
.78387 .43291 Mdot
.75958 .71625 Mdot
.54493 .50549 Mdot
.42142 .21006 Mdot
.29823 .56771 Mdot
.41348 .18318 Mdot
.67771 .46895 Mdot
.76097 .5114 Mdot
.56045 .28679 Mdot
.28929 .26428 Mdot
.45448 .75869 Mdot
.49838 .17887 Mdot
.448 .44652 Mdot
.17285 .40479 Mdot
.64765 .27597 Mdot
.49981 .4483 Mdot
.5257 .36741 Mdot
.35875 .35835 Mdot
.49045 .20414 Mdot
.5674 .24394 Mdot
.77172 .66702 Mdot
.47603 .30841 Mdot
.2951 .40979 Mdot
.59214 .78495 Mdot
.28403 .60903 Mdot
.68955 .28997 Mdot
.27452 .49023 Mdot
.48352 .17006 Mdot
.24442 .41897 Mdot
.20374 .48091 Mdot
.3219 .27898 Mdot
.85682 .47824 Mdot
.69571 .5404 Mdot
.29053 .35262 Mdot
.80151 .49976 Mdot
.44099 .27639 Mdot
.48643 .52713 Mdot
.0642 .47693 Mdot
.84225 .50736 Mdot
.6222 .26593 Mdot
.232 .30908 Mdot
.74155 .31894 Mdot
.59609 .26732 Mdot
.35836 .76597 Mdot
.5513 .53235 Mdot
.22065 .53937 Mdot
.45164 .59809 Mdot
.15814 .54666 Mdot
.27288 .5868 Mdot
.21221 .33583 Mdot
.62892 .18964 Mdot
.65847 .74201 Mdot
.43835 .66132 Mdot
.47329 .31995 Mdot
.63904 .51948 Mdot
.26956 .61574 Mdot
.44095 .77513 Mdot
.54373 .5575 Mdot
.54471 .2835 Mdot
.52921 .37183 Mdot
.34079 .29833 Mdot
.65472 .59398 Mdot
.45471 .24326 Mdot
.70848 .32385 Mdot
.52646 .39899 Mdot
.50884 .48471 Mdot
.25869 .49683 Mdot
.59871 .54028 Mdot
.59047 .77354 Mdot
.3301 .71081 Mdot
.58626 .45746 Mdot
.46329 .35952 Mdot
.56391 .77772 Mdot
.83143 .45864 Mdot
.63581 .24599 Mdot
.22046 .3433 Mdot
.32694 .36259 Mdot
.47323 .79604 Mdot
.25181 .47848 Mdot
.37949 .78748 Mdot
.4619 .81168 Mdot
.5531 .25552 Mdot
.64922 .5809 Mdot
.40025 .78086 Mdot
.77394 .4514 Mdot
.2705 .26297 Mdot
.80349 .60066 Mdot
.8035 .57519 Mdot
.50562 .27946 Mdot
.64997 .70763 Mdot
.63005 .76693 Mdot
.31996 .50568 Mdot
.45122 .4692 Mdot
.50505 .87177 Mdot
.53547 .63454 Mdot
.37949 .85945 Mdot
.65175 .41788 Mdot
.30739 .76243 Mdot
.30656 .55221 Mdot
.54405 .43635 Mdot
.42025 .451 Mdot
.68553 .29749 Mdot
.74695 .50617 Mdot
.79929 .40349 Mdot
.4695 .8231 Mdot
.4739 .38889 Mdot
.82555 .61757 Mdot
.86037 .47795 Mdot
.51496 .78097 Mdot
.4026 .66104 Mdot
.84697 .49147 Mdot
.45102 .31595 Mdot
.3107 .69724 Mdot
.72374 .27086 Mdot
.57268 .2354 Mdot
.44837 .52849 Mdot
.26183 .52523 Mdot
.42405 .20763 Mdot
.37543 .18477 Mdot
.3874 .81651 Mdot
.5047 .21262 Mdot
.68333 .46346 Mdot
.48077 .44266 Mdot
.50818 .18721 Mdot
.48048 .51293 Mdot
.73665 .44862 Mdot
.54385 .54822 Mdot
.46418 .88849 Mdot
.33143 .25418 Mdot
.27563 .29329 Mdot
.52378 .54014 Mdot
.61481 .59115 Mdot
.68175 .51324 Mdot
.56287 .54933 Mdot
.58818 .24025 Mdot
.81967 .46538 Mdot
.56057 .5463 Mdot
.68249 .79012 Mdot
.58293 .6796 Mdot
.46647 .41962 Mdot
.61552 .78127 Mdot
.51278 .68182 Mdot
.68341 .40349 Mdot
.21598 .46229 Mdot
.65614 .24244 Mdot
.69899 .4402 Mdot
.68429 .28403 Mdot
.74099 .40307 Mdot
.67305 .68978 Mdot
.61237 .72458 Mdot
.59952 .22774 Mdot
.46318 .77411 Mdot
.69964 .64507 Mdot
.26434 .65055 Mdot
.44899 .36031 Mdot
.65477 .23573 Mdot
.5182 .37225 Mdot
.42731 .68644 Mdot
.48666 .49916 Mdot
.33028 .64937 Mdot
.19203 .59868 Mdot
.35353 .44038 Mdot
.64756 .6527 Mdot
.32999 .79263 Mdot
.5919 .64408 Mdot
.16489 .54452 Mdot
.34119 .72449 Mdot
.65002 .75818 Mdot
.37792 .28817 Mdot
.35428 .32179 Mdot
.59718 .84414 Mdot
.60288 .48326 Mdot
.55438 .32291 Mdot
.69966 .60227 Mdot
.66087 .63211 Mdot
.33887 .27498 Mdot
.48476 .38749 Mdot
.55024 .52148 Mdot
.60637 .38614 Mdot
.63346 .68121 Mdot
.68949 .63311 Mdot
.52726 .50396 Mdot
.22905 .52739 Mdot
.26376 .28443 Mdot
.49203 .33088 Mdot
.40061 .85696 Mdot
.4592 .65267 Mdot
.52203 .76532 Mdot
.56334 .17273 Mdot
.39643 .82951 Mdot
.55168 .33513 Mdot
.86413 .47713 Mdot
.39719 .56162 Mdot
.56796 .21435 Mdot
.61371 .62924 Mdot
.80187 .58427 Mdot
.34321 .44222 Mdot
.28119 .49647 Mdot
.66432 .41036 Mdot
.28468 .69429 Mdot
.5467 .39976 Mdot
.56538 .61803 Mdot
.53781 .22827 Mdot
.46297 .69819 Mdot
.75003 .47824 Mdot
.34218 .31346 Mdot
.52191 .78328 Mdot
.61541 .71938 Mdot
.68655 .64381 Mdot
.28684 .28148 Mdot
.80863 .57998 Mdot
.23823 .27989 Mdot
.5419 .60783 Mdot
.39687 .38813 Mdot
.75716 .60183 Mdot
.65328 .26124 Mdot
.65351 .56602 Mdot
.53433 .1665 Mdot
.2593 .55759 Mdot
.6559 .68383 Mdot
.24668 .5045 Mdot
.35913 .5973 Mdot
.53358 .46938 Mdot
.67866 .32717 Mdot
.49903 .83543 Mdot
.6259 .5392 Mdot
.32178 .75761 Mdot
.65189 .57588 Mdot
.26892 .31357 Mdot
.62862 .57755 Mdot
.54183 .35742 Mdot
.6597 .71066 Mdot
.60466 .4735 Mdot
.28465 .25023 Mdot
.54376 .16777 Mdot
.61589 .47614 Mdot
.38288 .2544 Mdot
.72493 .28843 Mdot
.36199 .62786 Mdot
.45057 .42739 Mdot
.44603 .56501 Mdot
.48187 .6809 Mdot
.41167 .84174 Mdot
.61347 .24592 Mdot
.51103 .58952 Mdot
.32936 .23341 Mdot
.32102 .22579 Mdot
.19203 .37401 Mdot
.73399 .71913 Mdot
.63544 .60149 Mdot
.16907 .46525 Mdot
.54444 .56085 Mdot
.40069 .17065 Mdot
.55524 .25149 Mdot
.61179 .16984 Mdot
.50088 .78767 Mdot
.69715 .28291 Mdot
.37831 .76946 Mdot
.72425 .50174 Mdot
.76872 .37059 Mdot
.53598 .42491 Mdot
.62792 .31672 Mdot
.75395 .33942 Mdot
.78035 .71735 Mdot
.37052 .66285 Mdot
.74208 .39477 Mdot
.77925 .48542 Mdot
.64498 .23005 Mdot
.44638 .29139 Mdot
.42198 .66465 Mdot
.58561 .30159 Mdot
.22985 .64166 Mdot
.2638 .48296 Mdot
.29487 .40005 Mdot
.44868 .28908 Mdot
.24105 .59963 Mdot
.23986 .51585 Mdot
.80554 .59975 Mdot
.51687 .78691 Mdot
.57722 .52151 Mdot
.38356 .60364 Mdot
.67479 .60622 Mdot
.31975 .44126 Mdot
.56052 .40774 Mdot
.46008 .57374 Mdot
.5334 .34073 Mdot
.74502 .48651 Mdot
.18312 .60027 Mdot
.66769 .53748 Mdot
.80732 .48973 Mdot
.599 .58497 Mdot
.73727 .4115 Mdot
.678 .57481 Mdot
.23853 .67687 Mdot
.41284 .33008 Mdot
.27064 .46046 Mdot
.37493 .21384 Mdot
.2362 .37793 Mdot
.68205 .68403 Mdot
.20153 .40964 Mdot
.6569 .47554 Mdot
.51748 .57882 Mdot
.77868 .51274 Mdot
.32735 .30494 Mdot
.52812 .63298 Mdot
.69473 .28214 Mdot
.5574 .33358 Mdot
.27099 .35758 Mdot
.78553 .383 Mdot
.50655 .67855 Mdot
.55993 .79587 Mdot
.36104 .20436 Mdot
.48975 .32042 Mdot
.82152 .54844 Mdot
.74373 .43179 Mdot
.40351 .35775 Mdot
.25348 .31836 Mdot
.24236 .2905 Mdot
.44277 .45501 Mdot
.29396 .53915 Mdot
.40474 .62454 Mdot
.79153 .6417 Mdot
.63594 .25679 Mdot
.33574 .6415 Mdot
.6348 .35317 Mdot
.5786 .62024 Mdot
.68247 .34817 Mdot
.56631 .50603 Mdot
.22926 .56466 Mdot
.63129 .66756 Mdot
.61669 .79164 Mdot
.35171 .44939 Mdot
.41955 .42062 Mdot
.46568 .6647 Mdot
.29529 .51969 Mdot
.6712 .77291 Mdot
.51388 .63298 Mdot
.52514 .20768 Mdot
.54466 .78529 Mdot
.79499 .56679 Mdot
.58613 .2265 Mdot
.55293 .25892 Mdot
.74236 .50559 Mdot
.64647 .72073 Mdot
.58311 .39256 Mdot
.40844 .56469 Mdot
.5448 .35352 Mdot
.57632 .63795 Mdot
.68521 .24247 Mdot
.58293 .74296 Mdot
.31194 .51143 Mdot
.57468 .4241 Mdot
.42386 .68801 Mdot
.60432 .40749 Mdot
.59493 .16977 Mdot
.72345 .50361 Mdot
.25745 .54396 Mdot
.62271 .50131 Mdot
.30775 .5463 Mdot
.34044 .73192 Mdot
.29775 .22039 Mdot
.36837 .76849 Mdot
.49 .46968 Mdot
.33104 .77096 Mdot
.67804 .29846 Mdot
.73063 .27985 Mdot
.24865 .53542 Mdot
.41541 .43055 Mdot
.35665 .38439 Mdot
.72464 .62162 Mdot
.57831 .45153 Mdot
.29058 .39012 Mdot
.56369 .52674 Mdot
.60284 .36568 Mdot
.71686 .44786 Mdot
.34795 .65561 Mdot
.33422 .26125 Mdot
.36871 .2096 Mdot
.79592 .5949 Mdot
.60552 .42386 Mdot
.41237 .37216 Mdot
.23923 .57879 Mdot
.65996 .18037 Mdot
.254 .74334 Mdot
.40473 .62262 Mdot
.59591 .44214 Mdot
.28367 .53837 Mdot
.45773 .36035 Mdot
.59006 .54718 Mdot
.67325 .56642 Mdot
.66958 .41617 Mdot
.29299 .42135 Mdot
.26608 .36605 Mdot
.69213 .3098 Mdot
.29175 .62096 Mdot
.56894 .30766 Mdot
.18223 .60637 Mdot
.8295 .43407 Mdot
.64204 .25622 Mdot
.60452 .15114 Mdot
.72653 .41487 Mdot
.57148 .65792 Mdot
.40758 .73921 Mdot
.26518 .28667 Mdot
.27968 .48171 Mdot
.25088 .64317 Mdot
.55083 .26685 Mdot
.25411 .54989 Mdot
.51295 .54415 Mdot
.30786 .28745 Mdot
.67419 .34887 Mdot
.52518 .45539 Mdot
.35633 .32418 Mdot
.21094 .38057 Mdot
.56802 .80109 Mdot
.39961 .2055 Mdot
.23814 .65791 Mdot
.73571 .746 Mdot
.30067 .23308 Mdot
.33769 .46995 Mdot
.42725 .31777 Mdot
.41393 .74628 Mdot
.39376 .49117 Mdot
.46718 .51989 Mdot
.30467 .69282 Mdot
.59072 .71083 Mdot
.41439 .25886 Mdot
.28681 .72907 Mdot
.25132 .48767 Mdot
.53136 .678 Mdot
.41556 .43463 Mdot
.58412 .7722 Mdot
.37842 .25889 Mdot
.50333 .52498 Mdot
.41456 .4832 Mdot
.31064 .48197 Mdot
.55209 .78052 Mdot
.76868 .59738 Mdot
.7293 .31493 Mdot
.69737 .79005 Mdot
.50298 .22879 Mdot
.24783 .68982 Mdot
.43438 .65483 Mdot
.20937 .31042 Mdot
.73634 .34056 Mdot
.53395 .25023 Mdot
.8052 .43364 Mdot
.44913 .41139 Mdot
.59196 .67311 Mdot
.40782 .56502 Mdot
.48165 .20917 Mdot
.65569 .72844 Mdot
.46956 .7062 Mdot
.27713 .69435 Mdot
.27153 .50732 Mdot
.25339 .39867 Mdot
.32849 .50056 Mdot
.53389 .60216 Mdot
.59912 .64674 Mdot
.16175 .49547 Mdot
.46775 .45927 Mdot
.41541 .68484 Mdot
.33695 .60348 Mdot
.36656 .75302 Mdot
.84554 .42148 Mdot
.54596 .59491 Mdot
.24435 .36459 Mdot
.52865 .80738 Mdot
.38985 .52796 Mdot
.6269 .56276 Mdot
.62886 .12619 Mdot
.27687 .20911 Mdot
.56471 .62308 Mdot
.73782 .68949 Mdot
.53805 .80793 Mdot
.28333 .27559 Mdot
.3901 .33856 Mdot
.62245 .37137 Mdot
.33158 .59596 Mdot
.42476 .49865 Mdot
.49655 .6378 Mdot
.79012 .40634 Mdot
.30908 .21295 Mdot
.2812 .70674 Mdot
.33208 .23124 Mdot
.39837 .53823 Mdot
.50868 .62716 Mdot
.69208 .1909 Mdot
.49682 .18735 Mdot
.37364 .64874 Mdot
.39721 .7894 Mdot
.52867 .64511 Mdot
.4635 .61786 Mdot
.42754 .22493 Mdot
.82571 .61422 Mdot
.25 .4825 Mdot
.2889 .26506 Mdot
.62169 .66819 Mdot
.54939 .3707 Mdot
.65478 .41572 Mdot
.42909 .45592 Mdot
.36881 .59907 Mdot
.65685 .42495 Mdot
.34004 .68853 Mdot
.69214 .27258 Mdot
.6435 .51386 Mdot
.82197 .58257 Mdot
.51904 .14922 Mdot
.59172 .75064 Mdot
.7202 .61287 Mdot
.38689 .66791 Mdot
.53153 .6762 Mdot
.26213 .61408 Mdot
.50812 .66772 Mdot
.74554 .31276 Mdot
.10103 .45796 Mdot
.61593 .32303 Mdot
.2161 .5049 Mdot
.65143 .59477 Mdot
.59038 .52781 Mdot
.61017 .76922 Mdot
.42173 .37398 Mdot
.50767 .33129 Mdot
.38438 .54905 Mdot
.53893 .60604 Mdot
.693 .4133 Mdot
.35472 .83733 Mdot
.41115 .65846 Mdot
.61212 .54914 Mdot
.40307 .17138 Mdot
.26375 .65022 Mdot
.49462 .76047 Mdot
.42806 .55353 Mdot
.73135 .57238 Mdot
.41537 .42754 Mdot
.60985 .21147 Mdot
.20577 .47351 Mdot
.3381 .23607 Mdot
.58323 .74024 Mdot
.55216 .79945 Mdot
.38634 .619 Mdot
.3751 .42243 Mdot
.72082 .47181 Mdot
.45293 .22276 Mdot
.44972 .53704 Mdot
.36043 .18685 Mdot
.47413 .42367 Mdot
.56265 .39129 Mdot
.52822 .583 Mdot
.18532 .39026 Mdot
.31993 .74126 Mdot
.64036 .75276 Mdot
.22536 .66259 Mdot
.32418 .32377 Mdot
.28356 .60563 Mdot
.48041 .31747 Mdot
.43985 .53496 Mdot
.6036 .66222 Mdot
.1844 .62753 Mdot
.41524 .2223 Mdot
.61003 .30425 Mdot
.65077 .33478 Mdot
.76155 .65726 Mdot
.75376 .46415 Mdot
.57494 .1431 Mdot
.33655 .32545 Mdot
.187 .62417 Mdot
.80953 .56773 Mdot
.54945 .61069 Mdot
.6997 .29818 Mdot
.52202 .60193 Mdot
.47517 .34362 Mdot
.325 .24414 Mdot
.46994 .67141 Mdot
.20876 .56977 Mdot
.47074 .56251 Mdot
.19752 .58603 Mdot
.28004 .41356 Mdot
.37194 .25304 Mdot
.64314 .27852 Mdot
.35042 .75218 Mdot
.65619 .21608 Mdot
.72689 .62401 Mdot
.64737 .18556 Mdot
.66315 .2269 Mdot
.37367 .19265 Mdot
.22628 .61719 Mdot
.42716 .83248 Mdot
.56954 .24745 Mdot
.60592 .2319 Mdot
.69322 .32523 Mdot
.39827 .75411 Mdot
.36217 .35806 Mdot
.54093 .5907 Mdot
.70048 .51261 Mdot
.62416 .48417 Mdot
.13478 .65447 Mdot
.26294 .40663 Mdot
.55673 .62524 Mdot
.33604 .34575 Mdot
.3361 .21327 Mdot
.38324 .74901 Mdot
.76335 .35184 Mdot
.55907 .49862 Mdot
.50026 .62299 Mdot
.59954 .72495 Mdot
.78068 .62815 Mdot
.35633 .36171 Mdot
.60824 .84975 Mdot
.82746 .44529 Mdot
.6229 .34482 Mdot
.53034 .47715 Mdot
.6125 .65984 Mdot
.69202 .61234 Mdot
.36562 .30971 Mdot
.75929 .32629 Mdot
.6954 .27917 Mdot
.50599 .18689 Mdot
.59897 .84213 Mdot
.79822 .56943 Mdot
.26388 .28637 Mdot
.65276 .27341 Mdot
.56872 .60872 Mdot
.36517 .47038 Mdot
.44258 .35018 Mdot
.61867 .29793 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0<Sooooo0_l0001oooooo`007?ooool00ol0003oooooooooo`38ooooo`;o0000Ooooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0]oooool2o`00
093ooooo000Looooo`03o`000?oooooooooo0;7ooooo0_l00004ooooo`;o0000T?ooool001cooooo
00?o0000ooooooooool0YOooool2o`0000[ooooo0_l0002Fooooo`007?ooool2o`000:Kooooo0_l0
000Jooooo`;o0000Q_ooool001cooooo00?o0000ooooooooool0R_ooool2o`0000oooooo0_l0000T
ooooo`;o0000Q_ooool001cooooo00?o0000ooooooooool0R_ooool2o`0000oooooo0_l0002/oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo09_ooooo
0_l0002/ooooo`007?ooool00ol0003oooooooooo`1oooooo`;o00000_ooool2o`0001?ooooo1Ol0
0004ooooo`;o00001oooool2o`000003ooooool0003o000000;o0000V?ooool001cooooo00?o0000
ooooooooool0Moooool2o`0000Gooooo0ol00002ooooo`Co00001Oooool2o`0000[ooooo1?l00000
0ooooooo0000o`000002ooooo`?o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002
o`0000cooooo0_l00004ooooo`;o0000Q?ooool001cooooo00?o0000ooooooooool0Moooool2o`00
00Gooooo0ol00004ooooo`;o00001Oooool2o`0000;ooooo0_l00004ooooo`;o000000Goooooo`00
0?l0003o0000ooooo`02o`0000?ooooo0_l00002ooooo`;o00002_ooool3o`000003ooooool0003o
000000?ooooo1Ol00003ooooo`;o0000Q?ooool001cooooo00?o0000ooooooooool0LOooool2o`00
01[ooooo1Ol00004ooooo`;o00002oooool2o`0000Cooooo0_l00003ooooo`;o00000_ooool6o`00
00?ooooo0_l000000ooooooo0000o`000029ooooo`007?ooool00ol0003oooooooooo`1aooooo`;o
00003_ooool2o`0000[ooooo1?l00004ooooo`?o00001_ooool2o`000003ooooool0003o000000;o
00001?ooool3o`0000;ooooo0_l00004ooooo`;o00002oooool6o`0000cooooo0_l0001dooooo`00
7?ooool00ol0003oooooooooo`1nooooo`;o000000?oooooo`000?l000000_l00003ooooo`Co0000
2Oooool3o`0000Kooooo0_l000000ooooooo0000o`000006ooooo`?o00001oooool2o`0000Cooooo
0_l00006ooooo`[o00002?ooool2o`0007Cooooo000Looooo`03o`000?oooooooooo077ooooo0_l0
0003ooooo`;o00001_ooool2o`0000?ooooo0_l00003ooooo`Ko00004?ooool2o`000003ooooool0
003o000000oooooo1Ol00002ooooo`;o00001oooool4o`000003ooooool0003o000000;o00000ooo
ool2o`0007Wooooo000Looooo`03o`000?oooooooooo077ooooo0_l00003ooooo`Co00002Oooool2
o`0000;ooooo0ol000000ooooooo0000o`000002o`0000oooooo0_l000000ooooooo0000o`00000?
ooooo`Go00002_ooool2o`000003ooooool0003o000000?ooooo0_l00003ooooo`;o0000NOooool0
0006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oo
oooooooo06Kooooo0ol0000<ooooo`Go00003Oooool3o`0000?ooooo0_l0000Uooooo`;o00002ooo
ool4o`0000Cooooo0_l0000Booooo`;o0000J_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo06Ko
oooo0ol00002ooooo`;o00002?ooool3o`0000oooooo0_l000000ooooooo0000o`000009ooooo`;o
00009oooool2o`000003ooooool0003o000000;o00006?ooool2o`0006[ooooo00000ooooooo410@
ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003ooooo
ooooo`1Sooooo`;o00001_ooool2o`0000Sooooo0_l0000?ooooo`;o00000_ooool2o`0000Wooooo
0_l0000Tooooo`;o000000Coooooo`000?l0003ooooo0_l00026ooooo`0000?oooooo`000?ooool0
0_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0001Qooooo`Co0000
2oooool2o`0000?ooooo0_l00007ooooo`;o00001_ooool2o`0000Kooooo0_l00009ooooo`;o0000
7_ooool4o`0008cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?o
MgMgofIVI_ooool01Oooool00ol0003oooooooooo`1Pooooo`Co00002_ooool6o`0000[ooooo0_l0
000>ooooo`;o00002Oooool2o`000003ooooool0003o000001Oooooo0_l00002ooooo`;o00004Ooo
ool2o`0007_ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`1Fooooo`;o00002?ooool2o`0000[ooooo1?l00002
ooooo`;o00002_ooool2o`0000Kooooo0_l0000Aooooo`;o000000?oooooo`000?l000002Oooool2
o`0000;ooooo0_l00008ooooo`;o000000?oooooo`000?l000004_ooool2o`0007_ooooo00001_oo
ooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`00
0?oooooooooo05Kooooo0_l00002ooooo`;o00001?ooool2o`0000[ooooo0_l00006ooooo`;o0000
3oooool3o`00017ooooo0_l00002ooooo`Co00001_ooool2o`0000;ooooo0_l00003ooooo`?o0000
1Oooool2o`0000Sooooo0_l00025ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Jooooo`;o00001?ooool3o`00
00Kooooo0_l00009ooooo`Co00003Oooool2o`0001Kooooo1Ol00003ooooo`;o00001?ooool2o`00
00?ooooo0ol00002ooooo`;o00002oooool2o`0008Gooooo000Looooo`03o`000?oooooooooo067o
oooo0_l00006ooooo`;o00002oooool2o`0001Oooooo0_l00008ooooo`;o00001Oooool2o`0000?o
oooo0_l000000ooooooo0000o`00000;ooooo`;o00006_ooool2o`0000;ooooo0_l0001booooo`00
7?ooool00ol0003oooooooooo`1Hooooo`;o00000oooool2o`00017ooooo0_l0000;ooooo`;o0000
4?ooool2o`0000Sooooo0_l00004ooooo`Co00001Oooool2o`0000_ooooo0_l0000Jooooo`;o0000
0_ooool2o`0001cooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o00000ooo
ool2o`00017ooooo0_l000000ooooooo0000o`000008ooooo`;o00001?ooool2o`0000[ooooo0_l0
0003ooooo`;o00002Oooool5o`00017ooooo0_l00005ooooo`?o0000=?ooool2o`0005Cooooo000L
ooooo`03o`000?oooooooooo06Gooooo0_l000000ooooooo0000o`000009ooooo`Co00003?ooool2
o`000004ooooool0003o0000o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`;o00003?oo
ool2o`0000[ooooo0_l0000;ooooo`Ko000000?oooooo`000?l000004?ooool2o`0000Cooooo0_l0
001]ooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o000000?oooooo`000?l000000_l00000
0ooooooo0000o`00000;ooooo`;o00002Oooool2o`000004ooooool0003o0000ooooo`?o00000ooo
ool2o`000003ooooool0003o000000?ooooo0_l00003ooooo`;o00001Oooool2o`0000Wooooo0_l0
00000ooooooo0000o`00000;ooooo`;o00000_ooool2o`000003ooooool0003o000000[ooooo0_l0
0004ooooo`Co00000_ooool2o`0006gooooo000Looooo`03o`000?oooooooooo05kooooo1?l00000
0ooooooo0000o`000002ooooo`Co00002_ooool2o`0000;ooooo0_l00005ooooo`;o00003_ooool2
o`0000;ooooo0_l000000ooooooo0000o`000002o`0000Gooooo0_l00009ooooo`;o00005?ooool2
o`0000_ooooo0_l00004ooooo`Co00000_ooool2o`0006gooooo000Looooo`03o`000?oooooooooo
04Wooooo0_l0000Cooooo`;o00001oooool5o`0000;ooooo0_l00005ooooo`;o00000_ooool3o`00
00_ooooo0_l00002ooooo`;o00000oooool2o`0000Gooooo1?l000000ooooooo0000o`000008oooo
o`;o00003_ooool2o`0000Cooooo0_l00003ooooo`;o00001_ooool2o`0000Kooooo1Ol00007oooo
o`;o00001?ooool2o`0006Cooooo000Looooo`03o`000?oooooooooo04Wooooo0_l0000Eooooo`;o
00001_ooool4o`0000;ooooo0_l00008ooooo`Co00002oooool2o`0000;ooooo0_l00002ooooo`;o
00000oooool4o`000003ooooool0003o000000?o00002?ooool2o`0000kooooo0_l00004ooooo`;o
00000oooool2o`0000Kooooo0_l00006ooooo`?o00002Oooool3o`0000?ooooo0_l0001Tooooo`00
7?ooool00ol0003oooooooooo`1Nooooo`Co00004?ooool3o`000003ooooool0003o000000;o0000
2?ooool2o`000003ooooool0003o000000Sooooo0_l00003ooooo`Co00000_ooool2o`0000;ooooo
0_l00004ooooo`;o00005Oooool2o`0000Cooooo0_l00005ooooo`;o00001oooool2o`0000Sooooo
1_l0001Xooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o00001_ooool4o`0000Sooooo0ol0
00000ooooooo0000o`00000:ooooo`;o000000?oooooo`000?l000002Oooool2o`0000;ooooo1?l0
0006ooooo`;o000000Coooooo`000?l0003ooooo0_l0000?ooooo`;o00001?ooool2o`0000Kooooo
0_l00003ooooo`;o000000?oooooo`000?l000001?ooool2o`0000?ooooo0_l00003ooooo`Ko0000
J?ooool001cooooo00?o0000ooooooooool0Coooool2o`0000Oooooo0_l000000ooooooo0000o`00
0009ooooo`Co00002oooool2o`0001Wooooo1Ol000000ooooooo0000o`000009ooooo`;o00000ooo
ool2o`0000gooooo0_l0000<ooooo`Co00001?ooool2o`0000Wooooo0_l0001aooooo`007?ooool2
o`00053ooooo0_l00007ooooo`Go000000?oooooo`000?l000005Oooool3o`0001Wooooo1?l0000<
ooooo`;o00000oooool2o`0000;ooooo0ol00004ooooo`Ko00003?ooool4o`0001Kooooo0_l0001Z
ooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o00000oooool2o`0000Sooooo0_l0000;oooo
o`?o000000?oooooo`000?l000000_l0000Vooooo`;o00000_ooool8o`0000;ooooo1?l0000Moooo
o`;o00002Oooool2o`0000_ooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1Xooooo`;o
00000oooool2o`0000Kooooo0_l00002ooooo`Co00001?ooool4o`0000Oooooo0_l0000Eooooo`;o
00000_ooool4o`0000;ooooo0_l000000ooooooo0000o`000007ooooo`;o00004?ooool4o`0000?o
oooo0_l0000Fooooo`;o0000GOooool001cooooo00?o0000ooooooooool0JOooool2o`0000;ooooo
0_l00006ooooo`Co00002?ooool4o`0000Oooooo0_l0000Jooooo`;o00000oooool2o`000003oooo
ool0003o000000Oooooo0_l00004ooooo`;o00002_ooool4o`000003ooooool0003o000000Cooooo
0ol0000;ooooo`;o0000Hoooool001cooooo00?o0000ooooooooool0E?ooool2o`000004ooooool0
003o0000ooooo`;o00002Oooool6o`0000cooooo0_l0000:ooooo`;o00001?ooool2o`000003oooo
ool0003o000001;ooooo0_l00008ooooo`;o000000Coooooo`000?l0003ooooo0_l00008ooooo`Oo
00003?ooool2o`000003ooooool0003o000000Cooooo0ol0000;ooooo`;o00002?ooool2o`0005Wo
oooo000Looooo`03o`000?oooooooooo05?ooooo0ol000001?oooooo0000o`000?ooool2o`0000Wo
oooo1_l00009ooooo`;o00001Oooool2o`0000cooooo0_l0000>ooooo`;o00001Oooool2o`0000;o
oooo0_l00004ooooo`Co000000?oooooo`000?l000001_ooool2o`000003ooooool0003o000000Co
00001_ooool2o`0000Gooooo0_l00008ooooo`;o00005Oooool3o`0005Sooooo000Looooo`03o`00
0?oooooooooo05?ooooo0_l00005ooooo`;o00003Oooool2o`0000Wooooo0_l00005ooooo`;o0000
5_ooool2o`0000Cooooo0_l00009ooooo`;o00001Oooool3o`000003ooooool0003o000000;o0000
1?ooool2o`0000Gooooo0_l00006ooooo`Co00003Oooool2o`0000?ooooo0_l00009ooooo`;o0000
1_ooool2o`0005Sooooo000Looooo`03o`000?oooooooooo06;ooooo0_l00006ooooo`;o000000?o
ooooo`000?l000004?ooool2o`0001;ooooo0_l0000@ooooo`;o00001Oooool3o`0000;ooooo0_l0
000Eooooo`;o00001?ooool4o`0000[ooooo0ol00008ooooo`;o00001oooool2o`0000?ooooo0_l0
001Booooo`007?ooool00ol0003oooooooooo`1>ooooo`;o000000?oooooo`000?l000001Oooool3
o`0000Oooooo0_l00006ooooo`Go00001?ooool2o`0000Kooooo0_l00002ooooo`;o00002_ooool2
o`00013ooooo0_l00006ooooo`;o00001_ooool2o`0001_ooooo0_l00002ooooo`Co00002oooool2
o`0000Sooooo0_l00007ooooo`;o00000oooool2o`0005;ooooo000Looooo`03o`000?oooooooooo
04[ooooo0_l00002ooooo`;o000000?oooooo`000?l000001Oooool3o`0000?ooooo0_l00005oooo
o`;o00000oooool3o`0000Kooooo0_l00006ooooo`?o000000?oooooo`000?l000002_ooool2o`00
013ooooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l00005ooooo`;o00002Oooool2o`00
00kooooo0_l000000ooooooo0000o`000002o`0000gooooo0_l0000:ooooo`;o0000GOooool001co
oooo00?o0000ooooooooool0B_ooool2o`0000gooooo0_l00003ooooo`;o00001Oooool2o`0000;o
oooo0_l00005ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l00005ooooo`;o
00000_ooool2o`0000Kooooo0_l0000?ooooo`Co00001?ooool2o`0000Gooooo0_l00009ooooo`;o
00004Oooool2o`0000Cooooo0_l00009ooooo`?o00002Oooool2o`0005gooooo000Looooo`03o`00
0?oooooooooo05;ooooo0_l00005ooooo`;o00001oooool2o`000003ooooool0003o000000;ooooo
0ol00004ooooo`Co00000oooool2o`0000[ooooo0_l00002ooooo`;o00001_ooool2o`0000?ooooo
0_l0000Gooooo`Co00008_ooool2o`0000;ooooo1Ol00002ooooo`?o00003Oooool2o`0000Wooooo
0_l0001>ooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o00001_ooool3o`0000_ooooo1?l0
0006ooooo`;o00001Oooool3o`0000?ooooo0_l0000Eooooo`;o00001?ooool2o`0000Cooooo0_l0
000Aooooo`;o00000_ooool3o`0000Sooooo1Ol00009ooooo`;o00002oooool5o`0000Kooooo1?l0
0002ooooo`Co00000_ooool3o`0000Sooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`1:
ooooo`?o00001Oooool3o`0000_ooooo0_l0000?ooooo`;o00001?ooool2o`00013ooooo0_l00002
ooooo`Go00000_ooool2o`0000Cooooo0_l0000@ooooo`Co000000?oooooo`000?l000000ol00006
ooooo`Go00002?ooool3o`0000Wooooo0_l00005ooooo`;o00001?ooool4o`0000;ooooo1?l00000
0ooooooo0000o`000002o`0000_ooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`1;oooo
o`Co00001_ooool5o`0000;ooooo0ol0000@ooooo`;o00006?ooool2o`0000;ooooo1Ol0000Joooo
o`Co00000_ooool4o`0000cooooo0_l00005ooooo`;o00002_ooool3o`0000Cooooo0ol00009oooo
o`;o000000?oooooo`000?l000000_l0000=ooooo`;o0000Boooool001cooooo00?o0000oooooooo
ool0COooool2o`0000Kooooo1Ol00002ooooo`?o00003?ooool6o`0000cooooo0_l0000?ooooo`;o
00008_ooool2o`0000;ooooo0_l00003ooooo`?o00001?ooool9o`0000_ooooo1?l000000ooooooo
0000o`000004o`0000Oooooo0_l000000ooooooo0000o`000002ooooo`;o0000F?ooool001cooooo
0_l0001=ooooo`;o00002oooool2o`00013ooooo1?l0000>ooooo`;o00003oooool2o`0000Wooooo
0_l0000Cooooo`;o00001_ooool2o`0000;ooooo1ol00002ooooo`So00003?ooool3o`000004oooo
ool0003o0000ooooo`?o00002?ooool2o`000004ooooool0003o0000ooooo`?o0000Eoooool001co
oooo00?o0000ooooooooool0C?ooool2o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l0
00001Oooool2o`0000_ooooo0_l0000Hooooo`;o00002oooool2o`0000?ooooo0_l0000:ooooo`?o
00001_ooool2o`0000?ooooo0_l00005ooooo`Oo000000?oooooo`000?l000001ol0000=ooooo`;o
00003oooool5o`000004ooooool0003o0000o`0005Oooooo000Looooo`03o`000?oooooooooo04Ko
oooo0_l0000:ooooo`;o00000_ooool2o`0000Gooooo0_l000000ooooooo0000o`000005ooooo`Co
00000_ooool2o`0001Sooooo0_l00009ooooo`Co00000oooool2o`0000;ooooo0_l00003ooooo`Ko
00002oooool4o`0000Sooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00003?ooool2o`00
00?ooooo0_l00009ooooo`;o00000oooool2o`0000Cooooo0_l0001Gooooo`007?ooool00ol0003o
ooooooooo`10ooooo`;o00000oooool5o`0000Sooooo0ol00007ooooo`?o00002?ooool6o`0000Ko
oooo0_l00005ooooo`;o00005_ooool3o`0000;ooooo2_l000000ooooooo0000o`000003o`0000ko
oooo0_l00003ooooo`;o000000?oooooo`000?l000000_l00002ooooo`Co00003_ooool4o`000004
ooooool0003o0000ooooo`Co00001?ooool2o`000003ooooool0003o000000Kooooo0_l0001Goooo
o`007?ooool00ol0003oooooooooo`10ooooo`;o00000oooool2o`000003ooooool0003o000000Ko
oooo1_l00006ooooo`;o00002oooool4o`0000Kooooo0_l00005ooooo`;o00003Oooool4o`0000So
oooo3_l00002ooooo`;o00003_ooool2o`0000?ooooo1ol00004ooooo`;o00003oooool3o`0000;o
oooo1_l00007ooooo`Go000000?oooooo`000?l000006Oooool2o`0003kooooo000Looooo`03o`00
0?oooooooooo053ooooo0_l00002ooooo`;o00005?ooool3o`0001cooooo1?l00002ooooo`;o0000
00Coooooo`000?l0003ooooo4_l0000>ooooo`;o00001Oooool3o`0000Wooooo0_l00009ooooo`;o
00000_ooool6o`0000cooooo1?l000000ooooooo0000o`000006ooooo`;o00004Oooool2o`0003ko
oooo000Looooo`03o`000?oooooooooo04oooooo0_l0000Uooooo`;o00003oooool2o`0000Kooooo
0_l000000ooooooo0000o`000007o`000003ooooool0003o000000Wo00003Oooool3o`0000;ooooo
0_l0000=ooooo`;o000000Coooooo`000?l0003o00001Oooool2o`0000Cooooo1?l00007ooooo`;o
00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`;o0000DOooool001cooooo
00?o0000ooooooooool0@oooool2o`0000Wooooo0ol0000Nooooo`;o00001Oooool2o`0000oooooo
0_l000000ooooooo0000o`000007ooooo`Oo000000?oooooo`000?l000002_l00009ooooo`;o0000
0_ooool3o`0000;ooooo0_l00009ooooo`?o00001?ooool5o`0000;ooooo0_l00009ooooo`;o0000
1Oooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0000Cooooo0_l0001Aooooo`00
7?ooool00ol0003oooooooooo`13ooooo`;o00002Oooool2o`0000gooooo0_l00007ooooo`;o0000
0_ooool2o`0000?ooooo0ol0000Hooooo`;o00001Oooool5o`0000;ooooo3ol000000ooooooo0000
o`000006ooooo`;o00001oooool5o`0000Kooooo0ol00007ooooo`;o00000_ooool2o`0000Kooooo
0_l000000ooooooo0000o`000003ooooo`;o00001_ooool2o`000005ooooool0003o0000o`000?oo
ool01?l000000ooooooo0000o`00001Aooooo`007?ooool00ol0003oooooooooo`19ooooo`;o0000
2?ooool2o`0000Sooooo0_l00007ooooo`?o000000?oooooo`000?l000001?ooool2o`0001Gooooo
0_l00007oooooaOo000000Coooooo`000?l0003o00001Oooool2o`0000Sooooo1?l0000Kooooo`?o
000000?oooooo`000?l000000oooool5o`0000Oooooo0_l000000ooooooo0000o`000002o`0001;o
oooo0_l00010ooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00002?ooool2o`0001;ooooo
0_l00005ooooo`;o00004_ooool2o`0000?ooooo0ol00006oooooa_o00006Oooool2o`0000Gooooo
1?l0000:ooooo`;o000000?oooooo`000?l000001Oooool4o`0000Kooooo0_l0000Hooooo`;o0000
@?ooool001cooooo00?o0000ooooooooool0A_ooool2o`0001;ooooo0_l00004ooooo`;o00003?oo
ool2o`0000_ooooo0_l00005ooooo`;o00001?ooool2o`0000Kooooo6_l00004ooooo`Go00004Ooo
ool2o`0000Gooooo1?l000001?oooooo0000o`000?l00009ooooo`;o00003oooool2o`0005[ooooo
000Looooo`03o`000?oooooooooo047ooooo0_l00003ooooo`;o00003_ooool2o`0000;ooooo0_l0
0004ooooo`?o00001_ooool2o`00013ooooo0_l0000Coooooa[o00001?ooool5o`0000Cooooo0_l0
000Gooooo`Go00003?ooool2o`0006Kooooo000Looooo`03o`000?oooooooooo02cooooo0_l0000B
ooooo`?o00003_ooool2o`0000;ooooo1Ol00006ooooo`?o00001_ooool2o`0000oooooo0ol00008
ooooo`;o00002_oooolJo`0000cooooo1?l0000:ooooo`;o00000_ooool2o`0000;ooooo0_l00004
ooooo`;o00003?ooool2o`0000Sooooo0_l00004ooooo`;o0000E_ooool001cooooo00?o0000oooo
ooooool0;?ooool2o`0001;ooooo0_l00002ooooo`;o00002Oooool4o`0000;ooooo1ol00003oooo
o`?o00001?ooool2o`0000Cooooo1?l0000:ooooo`;o00002Oooool2o`0000[ooooo0_l000000ooo
oooo0000o`00000Eo`0000Gooooo0_l00004ooooo`;o000000Coooooo`000?l0003o00002Oooool6
o`0000;ooooo0_l00005ooooo`;o00003Oooool2o`0000Kooooo1?l00002ooooo`;o000000?ooooo
o`000?l000005_ooool2o`0003_ooooo000Looooo`03o`000?oooooooooo04Cooooo0_l00002oooo
o`;o00001Oooool2o`0000;ooooo0_l00003ooooo`Co00000_ooool3o`0000Gooooo0_l000001?oo
oooo0000o`000?ooool4o`0000Cooooo0_l0000:ooooo`;o00003?ooool2o`000003ooooool0003o
000001Ko000000?oooooo`000?l000001?ooool2o`0000Cooooo0_l00002ooooo`;o00002oooool2
o`0000_ooooo0_l0000=ooooo`;o00001_ooool8o`000003ooooool0003o000001Kooooo0_l0000k
ooooo`007?ooool2o`0004Gooooo0_l00002ooooo`;o00002Oooool2o`0000Kooooo0_l000000ooo
oooo0000o`000009ooooo`;o00002Oooool2o`0000[ooooo0_l0000:oooooa3o000000?oooooo`00
0?l000002Ol00002ooooo`;o00001_ooool2o`0002?ooooo0_l000000ooooooo0000o`000007oooo
o`;o00002?ooool4o`0005Sooooo000Looooo`03o`000?oooooooooo04;ooooo0_l00004ooooo`;o
00002?ooool2o`0000Cooooo0_l000000ooooooo0000o`00000?ooooo`;o00006_ooool2o`0000;o
oooo0_l000000ooooooo0000o`00000Ko`000003ooooool0003o000000?ooooo1?l00002ooooo`;o
00004?ooool2o`0000;ooooo0_l00007ooooo`;o000000?oooooo`000?l000003_ooool2o`000004
ooooool0003o0000o`0000Cooooo1?l0001Aooooo`007?ooool00ol0003oooooooooo`12ooooo`;o
00003_ooool2o`0000Cooooo0_l000000ooooooo0000o`00000?ooooo`;o00001Oooool3o`0001;o
oooo0_l00002ooooo`;o000000?oooooo`000?l000006ol000000ooooooo0000o`000002o`000003
ooooool0003o000000?o000000?oooooo`000?l000004?ooool2o`0000;ooooo0ol00002ooooo`;o
00005Oooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool4o`00057ooooo000Looooo`03
o`000?oooooooooo04Cooooo0_l0000>ooooo`;o00006oooool7o`0000Oooooo0_l0000;ooooo`;o
000000?oooooo`000?l000007Ol000000ooooooo0000o`000002ooooo`Co00003?ooool2o`0000;o
oooo0_l00005ooooo`?o00000_ooool4o`0000Kooooo0ol00009ooooo`;o00000oooool5o`0000co
oooo0_l00018ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00003_ooool2o`0000Oooooo
0ol00004ooooo`Co00002?ooool4o`000004ooooool0003o0000o`0000Oooooo0_l00002ooooo`;o
00001Oooool2o`0000;ooooo4?l000000ooooooo0000o`000009o`000004ooooool0003o0000o`00
00Gooooo0_l0000>ooooo`;o00000_ooool2o`0000_ooooo0ol00006ooooo`?o00002Oooool2o`00
00Cooooo0_l00004ooooo`;o00002?ooool2o`0004Sooooo000Looooo`03o`000?oooooooooo03oo
oooo0_l00003ooooo`;o00000oooool2o`000003ooooool0003o000000Gooooo0ol00007ooooo`?o
000000Coooooo`000?l0003ooooo1_l00006ooooo`;o00000oooool3o`0000Sooooo0_l000000ooo
oooo0000o`000003ooooo`Co00000_ooool9o`0000;ooooo1?l00002ooooo`ko00002oooool2o`00
00Kooooo0_l00005ooooo`;o00001oooool2o`000004ooooool0003o0000o`00013ooooo0_l00003
ooooo`;o00002?ooool2o`0000Oooooo0_l00019ooooo`007?ooool00ol0003oooooooooo`0ooooo
o`;o00000oooool2o`0000?ooooo1Ol00005ooooo`?o00001Oooool2o`0000Cooooo2Ol00003oooo
o`;o00001oooool3o`0000;ooooo0_l00003ooooo`;o00001_ooool2o`0000Cooooo7ol0000;oooo
o`;o00001_ooool2o`0000Gooooo0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o0000
017ooooo0_l00003ooooo`;o000000?oooooo`000?l000003_ooool2o`0004Wooooo000Looooo`03
o`000?oooooooooo04[ooooo0_l00006ooooo`;o00001oooool2o`0000?ooooo1Ol000000ooooooo
0000o`000005ooooo`;o00002?ooool6o`0000Gooooo0_l0000;oooooako000000Coooooo`000?l0
003o00001Oooool2o`0000kooooo0_l00004ooooo`;o00002?ooool2o`0000cooooo0_l00005oooo
o`;o000000?oooooo`000?l000001_ooool2o`0000Gooooo0_l0001:ooooo`007?ooool00ol0003o
ooooooooo`0kooooo`;o00001oooool4o`0000[ooooo1?l00008ooooo`Co00005oooool2o`000003
ooooool0003o000000Cooooo0_l000000ooooooo0000o`000008oooooa_o00000_ooool5o`0000Go
oooo0_l0000>ooooo`;o00003?ooool6o`0000;ooooo0_l00006ooooo`;o00004?ooool2o`0000Go
oooo0_l00004ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0>oooool2o`0000Gooooo
1_l000000ooooooo0000o`000002ooooo`;o00001Oooool3o`0000Oooooo0_l00007ooooo`?o0000
0_ooool2o`0000;ooooo1?l00005ooooo`;o000000?oooooo`000?l000001oooool2o`0000Sooooo
8?l0000Uooooo`;o00000_ooool2o`0000;ooooo0_l0000Kooooo`;o00000oooool2o`0000?ooooo
0_l00014ooooo`007?ooool00ol0003oooooooooo`11ooooo`?o000000Coooooo`000?l0003ooooo
0ol00002ooooo`;o00001_ooool2o`00013ooooo0ol00002ooooo`;o000000?oooooo`000?l00000
0ol00005ooooo`;o00002oooool2o`0000Oooooo1?l000000ooooooo0000o`00000Fo`0000Wooooo
0_l0000Eooooo`;o00004oooool2o`0000Sooooo0_l000000ooooooo0000o`000009ooooo`;o0000
0oooool3o`0004Sooooo000Looooo`03o`000?oooooooooo047ooooo0_l00002ooooo`;o000000?o
ooooo`000?l000000ol0000Looooo`;o00000_ooool5o`000003ooooool0003o000000Cooooo1?l0
0009ooooo`;o00001oooool2o`0000;ooooo6?l0000:ooooo`;o00000oooool4o`0000kooooo0_l0
000Cooooo`;o00002?ooool5o`0000_ooooo0_l00002ooooo`;o0000B?ooool001cooooo00?o0000
ooooooooool0@oooool4o`0000;ooooo1?l00003ooooo`;o00003Oooool2o`0000?ooooo2ol00000
1?oooooo0000o`000?ooool2o`0000Cooooo1?l0000:ooooo`;o00002_oooolCo`000003ooooool0
003o000000Kooooo1?l00007ooooo`Co00000oooool2o`0002[ooooo0_l0000<ooooo`;o0000C?oo
ool001cooooo00?o0000ooooooooool0>Oooool2o`0000Sooooo1?l00005ooooo`Ko00000_ooool2
o`0000Gooooo0_l00002ooooo`;o00000oooool=o`0000Gooooo0_l00005ooooo`;o00002?ooool2
o`0000[ooooo4ol00006ooooo`;o000000?oooooo`000?l000000_l0000>ooooo`?o000000?ooooo
o`000?l000005Oooool2o`0000oooooo0_l0000?ooooo`;o000000?oooooo`000?l00000A_ooool0
0006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413ooooooooo
o`04ooooo`03o`000?oooooooooo03Wooooo1?l0000?ooooo`Co00001?ooool3o`0000Cooooo0_l0
00000ooooooo0000o`000004ooooo`ko00001?ooool2o`0000Gooooo0_l0000Eoooooa;o00001?oo
ool4o`0000?ooooo1?l00005ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`;o0000
5Oooool2o`0000Kooooo0_l00004ooooo`;o000000?oooooo`000?l000003Oooool7o`0004Kooooo
00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0>oooool2o`00017ooooo0_l00004ooooo`?o00000oooool2o`0000;o
oooo0_l00002oooooa?o00007?ooool2o`0000Kooooo0_l000000ooooooo0000o`000009o`0000?o
oooo0_l00007ooooo`;o00001Oooool2o`0000?ooooo0_l0000Iooooo`;o00000oooool2o`0000?o
oooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l0000:ooooo`;o000000?oooooo`00
0?l00000B?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool5o`0000Ko
oooo00?o0000ooooooooool0=oooool2o`0000oooooo0_l000000ooooooo0000o`000004o`0000?o
oooo0_l00004ooooo`Co00000ooooolDo`0001Cooooo0_l00006ooooo`;o00002Oooool2o`0000Oo
oooo1?l00005ooooo`Ko00001Oooool2o`0000kooooo0_l00002ooooo`;o00001oooool2o`000003
ooooool0003o000000?o000000?oooooo`000?l000003?ooool5o`00013ooooo0_l00015ooooo`00
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oo
oooo0ol0000gooooo`;o00003oooool6o`000003ooooool0003o000000_ooooo0_l00003oooooa?o
00002Oooool2o`0000[ooooo0_l00008ooooo`;o00004_ooool2o`0000Gooooo1_l00005ooooo`;o
00003_ooool2o`0000;ooooo0_l00007ooooo`;o000000Coooooo`000?l0003ooooo0_l00006oooo
o`;o00001oooool6o`0000Kooooo0_l00007ooooo`;o00001Oooool2o`0003kooooo00000ooooooo
0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0
003oooooooooo`0dooooo`;o00002_ooool2o`0000Oooooo0_l0000;ooooo`;o00002OoooolDo`00
0005ooooool0003o0000o`000?ooool00_l000000ooooooo0000o`00000Dooooo`;o000000?ooooo
o`000?l000000_ooool3o`0000?ooooo0_l0000Wooooo`;o00001_ooool2o`000003ooooool0003o
000000Cooooo1?l000001?oooooo0000o`000?ooool4o`0000Oooooo0ol000000ooooooo0000o`00
0006ooooo`;o00000_ooool2o`000003ooooool0003o000000Oooooo0_l0000nooooo`0000?ooooo
oa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000
ooooooooool0=?ooool2o`0000[ooooo0_l00009ooooo`;o000000?oooooo`000?l000000_ooool2
o`0000;ooooo0_l00008ooooo`_o000000?oooooo`000?l000002ol000000ooooooo0000o`00000J
ooooo`;o00000_ooool5o`000003ooooool0003o0000013ooooo0_l0000=ooooo`;o00003_ooool2
o`000003ooooool0003o000000;ooooo1Ol00002ooooo`Go00002_ooool2o`0000gooooo0_l00000
0ooooooo0000o`000009ooooo`;o0000??ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg3?oo
ool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo037ooooo0_l0000;ooooo`;o00002ooo
ool2o`000005ooooool0003o0000o`000?ooool00_l00002ooooo`;o00001?ooool2o`000003oooo
ool0003o000001Ko00001?ooool2o`00017ooooo0_l0000=ooooo`;o00004oooool2o`0000gooooo
0_l0000:ooooo`?o000000?oooooo`000?l000001?l000001?oooooo0000o`000?ooool2o`0000;o
oooo1ol00006ooooo`;o00000oooool2o`0000Gooooo0_l0000Aooooo`;o0000??ooool00006oooo
ooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo
037ooooo0_l0000;ooooo`;o00001Oooool3o`000004ooooool0003o0000o`0000?ooooo0_l00005
ooooo`?o00000_ooool3o`000003ooooool0003o000001Co000000?oooooo`000?l000000oooool2
o`0000Sooooo0_l000000ooooooo0000o`000004ooooo`;o00002?ooool2o`0000;ooooo0_l0000A
ooooo`;o000000?oooooo`000?l000000oooool2o`0000oooooo0_l00002oooooaKo00000_ooool2
o`0000;ooooo0_l00002ooooo`;o00000oooool3o`0000Cooooo0_l0001?ooooo`007?ooool00ol0
003oooooooooo`15ooooo`?o000000Goooooo`000?l0003o0000ooooo`03o`0000Oooooo0_l00002
ooooo`;o00001?oooolGo`0000[ooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l0
0009ooooo`Ko00000_ooool2o`0000Sooooo0_l00003ooooo`?o00001Oooool2o`0000?ooooo0_l0
00000ooooooo0000o`000002ooooo`;o00000oooool2o`0000;ooooo5Ol00007ooooo`;o00002?oo
ool2o`0001;ooooo0_l0000>ooooo`;o0000<Oooool001cooooo00?o0000ooooooooool0<oooool2
o`0001?ooooo2?l0000;ooooo`;o00001?oooolGo`000003ooooool0003o000000Oooooo0_l00000
0ooooooo0000o`000006ooooo`Go00000_ooool2o`0000Cooooo0ol00003ooooo`;o00002?ooool2
o`0000Cooooo0_l00009ooooo`?o000000?oooooo`000?l000000_ooool2o`0000Kooooo3Ol00000
0ooooooo0000o`000005o`0000oooooo0_l000000ooooooo0000o`000007ooooo`;o00002Oooool2
o`0000Cooooo0_l000000ooooooo0000o`000005ooooo`;o0000<Oooool001cooooo00?o0000oooo
ooooool0<oooool2o`0000?ooooo0_l0000;ooooo`;o000000?oooooo`000?l000000_ooool2o`00
00gooooo0_l00004oooooaOo000000?oooooo`000?l000002_ooool2o`0000;ooooo0_l00004oooo
o`?o00000_ooool4o`0001;ooooo0_l0000;ooooo`;o00000_ooool2o`0000Cooooo1?l00004oooo
oaOo000000?oooooo`000?l000003?ooool2o`000003ooooool0003o000000Oooooo0_l0000?oooo
o`;o000000?oooooo`000?l00000>?ooool001cooooo00?o0000ooooooooool0>?ooool2o`0000_o
oooo0_l000000ooooooo0000o`000002ooooo`;o00002_ooool2o`0000Oooooo5ol000000ooooooo
0000o`000008ooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`;o00001Oooool2o`00
00Kooooo0_l00005ooooo`;o00000oooool2o`0000_ooooo0_l000000ooooooo0000o`000002oooo
o`Ko00000_ooool2o`000003ooooool0003o000001Go000000?oooooo`000?l000001_ooool2o`00
00Sooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00004oooool2o`0000?o
oooo0_l00002oooooa[o00002?ooool2o`0000Oooooo0_l000000ooooooo0000o`00000=ooooo`;o
00001Oooool2o`0001?ooooo0_l00002ooooo`Co00000_ooool6o`000003ooooool0003o000001?o
000000?oooooo`000?l000001_ooool2o`0000Kooooo1?l00007ooooo`;o00003_ooool4o`0000Wo
oooo0_l0000^ooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00004?ooool2o`0000oooooo
0_l00007ooooo`;o00000_oooolHo`0000Kooooo0_l00002ooooo`?o00003Oooool4o`0002gooooo
0_l00002oooooa[o00002Oooool2o`000004ooooool0003o0000ooooo`;o00001?ooool2o`0000;o
oooo0ol00004ooooo`;o00001_ooool6o`0000Wooooo0_l0000^ooooo`007?ooool00ol0003ooooo
ooooo`0aooooo`;o00007_ooool2o`000004ooooool0003o0000ooooo`;o00002oooool4o`000003
ooooool0003o000000Wo000000Coooooo`000?l0003o00001oooool2o`000003ooooool0003o0000
00;o00003Oooool7o`0000oooooo0_l00002ooooo`Co00003?ooool2o`0000Sooooo6ol00009oooo
o`;o000000?oooooo`000?l000001oooool2o`0000;ooooo0ol00003ooooo`?o00001_ooool4o`00
03_ooooo000Looooo`03o`000?oooooooooo03cooooo0_l0000Cooooo`;o00001?ooool2o`0000;o
oooo0ol000000ooooooo0000o`000003oooooaGo00000_ooool2o`0000Gooooo0ol00008ooooo`Co
00001Oooool4o`0000oooooo0_l00002ooooo`Co00003?ooool5o`0000Gooooo6_l00006ooooo`;o
00002?ooool2o`0000kooooo0_l00009ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0
<oooool2o`0000Oooooo0_l00006ooooo`;o00005OoooolHo`000003ooooool0003o000000?o0000
0_ooool2o`0000[ooooo0ol00003ooooo`Co00001oooool2o`0000?ooooo1?l0000:ooooo`;o0000
4Oooool5o`0000;ooooo0_l000000ooooooo0000o`00000Go`0000Kooooo1_l00004ooooo`;o0000
6_ooool2o`0000Wooooo0_l0000_ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00003ooo
ool2o`0000Wooooo0_l00003ooooo`;o00002?oooolHo`0000Oooooo0ol00007ooooo`?o00003_oo
ool2o`0000?ooooo1?l0000:ooooo`;o00004Oooool5o`0000;ooooo7Ol00006ooooo`Go00000_oo
ool2o`0001Sooooo0_l00002ooooo`;o00002Oooool2o`0002oooooo000Looooo`03o`000?oooooo
oooo04oooooo0_l00003ooooo`Co00002oooool2o`000003ooooool0003o000000go00002?ooool3
o`0000?ooooo0ol00008ooooo`;o00003oooool2o`0001oooooo0_l00003oooooaSo000000?ooooo
o`000?l000000_l00003ooooo`;o00000oooool3o`0000;ooooo0_l0000Gooooo`Go00000oooool2
o`0003Oooooo000Looooo`;o0000@Oooool2o`0000Gooooo0_l0000<ooooo`?o00001?ooool4o`00
00Kooooo3ol00008ooooo`;o00001?ooool4o`0000Oooooo0_l0000?ooooo`;o00005_ooool3o`00
00Oooooo0_l000000ooooooo0000o`00000=o`000003ooooool0003o000000So00001_ooool3o`00
00?ooooo0ol00005ooooo`;o00001?ooool2o`0000;ooooo0_l0000:ooooo`;o000000?oooooo`00
0?l000000oooool2o`0003Oooooo000Looooo`03o`000?oooooooooo043ooooo1Ol00002ooooo`;o
00000oooool2o`0000;ooooo0_l00003ooooo`?o00001?ooool5o`0000Gooooo1Ol00003ooooo`;o
00000oooool2o`0000?ooooo1?l000000ooooooo0000o`000006ooooo`;o00001Oooool2o`0000co
oooo0_l00003ooooo`;o00001_ooool2o`0000Wooooo0_l00002ooooo`Co00001oooool2o`000003
ooooool0003o000000go000000?oooooo`000?l000002?l00006ooooo`;o00003?ooool2o`0000Co
oooo0_l00002ooooo`;o00003oooool2o`000003ooooool0003o000003Oooooo000Looooo`03o`00
0?oooooooooo01gooooo0_l0000>ooooo`Co00002?ooool2o`0000Kooooo1_l00005ooooo`;o0000
0_ooool2o`0000Gooooo0_l00006ooooo`Co00000oooool4o`0000Wooooo0_l00003ooooo`Co0000
00?oooooo`000?l000002?ooool3o`0000;ooooo0_l000000ooooooo0000o`000009ooooo`;o0000
0oooool2o`0000Kooooo0_l00009ooooo`;o000000?oooooo`000?l000001_l00002ooooo`;o0000
0_oooolLo`0000Sooooo0_l0000Fooooo`;o00002Oooool2o`000003ooooool0003o000003[ooooo
000Looooo`03o`000?oooooooooo01gooooo0_l0000:ooooo`;o00000_ooool4o`0000Sooooo0_l0
0007ooooo`;o000000?oooooo`000?l000002Oooool3o`000004ooooool0003o0000ooooo`;o0000
1_ooool4o`000005ooooool0003o0000o`000?ooool00_l00002ooooo`;o00003Oooool2o`0000[o
oooo0ol00005ooooo`;o00000oooool2o`0000_ooooo0_l0000Booooo`;o000000?oooooo`000?l0
00000ol00002ooooo`;o00000_ooool2o`000003ooooool0003o000001Oo00002?ooool2o`000003
ooooool0003o000000Oooooo0_l0000:ooooo`;o00002Oooool2o`0000Oooooo0_l0000dooooo`00
7?ooool00ol0003oooooooooo`0Yooooo`;o00005oooool2o`0000cooooo0ol000000ooooooo0000
o`000008ooooo`?o00000oooool5o`000003ooooool0003o000000;o00003Oooool2o`0000Wooooo
1?l00003ooooo`Go00000_ooool2o`0000_ooooo0_l00008ooooo`;o00001?ooool2o`0000;ooooo
0_l000001?oooooo0000o`000?l0000:oooooaSo00003Oooool3o`0000Cooooo1?l0000>ooooo`Co
00000oooool2o`0000Oooooo0_l0000dooooo`007?ooool00ol0003oooooooooo`0cooooo`;o0000
3Oooool2o`0000Oooooo0ol00006ooooo`;o000000?oooooo`000?l000001Oooool2o`0000?ooooo
1_l000000ooooooo0000o`000002o`0000[ooooo0_l00004ooooo`;o00001_ooool2o`0000Gooooo
1Ol0000=ooooo`;o00002_ooool2o`0000Cooooo1?l00002ooooo`Co00002_ooool5o`000003oooo
ool0003o0000017o00001oooool2o`0000Cooooo0_l00004ooooo`;o00000_ooool2o`0000cooooo
1Ol00011ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00002Oooool2o`0000_ooooo0ol0
0006ooooo`;o000000?oooooo`000?l000002Oooool6o`0000;ooooo0_l00007ooooo`;o00000ooo
ool2o`0000Cooooo1?l000000ooooooo0000o`000009ooooo`?o00002_ooool2o`0000;ooooo0ol0
0008ooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo1?l0000:oooooa_o00001Ooo
ool2o`0000Kooooo0_l00006ooooo`;o00001_ooool3o`0000Kooooo0_l00002ooooo`;o0000?Ooo
ool001cooooo00?o0000ooooooooool0?_ooool3o`0001kooooo0_l000000ooooooo0000o`000002
ooooo`;o00000_ooool2o`0000Gooooo1?l0000;ooooo`Go00001oooool2o`000003ooooool0003o
000000?ooooo1?l00003ooooo`;o000000?oooooo`000?l000000_l00008ooooo`;o000000?ooooo
o`000?l000001Oooool2o`000003ooooool0003o000000Co00000oooool3o`0000?ooooo0_l00000
0ooooooo0000o`00000Ao`0000;ooooo1?l00004ooooo`;o00001Oooool2o`0000Gooooo0_l00007
ooooo`?o00002_ooool2o`0003gooooo000Looooo`03o`000?oooooooooo017ooooo0_l0000Zoooo
o`Co00001Oooool2o`0000Cooooo0_l0000@ooooo`?o00000_ooool2o`000003ooooool0003o0000
00Wooooo0_l00002ooooo`;o00002_ooool3o`0000Sooooo1?l00004ooooo`Co00001_ooool5o`00
00Kooooo0ol00005ooooo`;o000000Coooooo`000?l0003ooooo1_l00002ooooo`Oo00000oooool2
o`000003ooooool0003o000000Wo00001?ooool2o`0000?ooooo0_l00002ooooo`Co00003?ooool2
o`0000Wooooo0_l00003ooooo`;o00003oooool2o`0003;ooooo000Looooo`03o`000?oooooooooo
017ooooo0_l0000Zooooo`Co00001Oooool2o`0000Cooooo1?l00003ooooo`;o00001Oooool2o`00
00;ooooo0_l00003ooooo`?o00001_ooool2o`0000Oooooo0_l00002ooooo`;o00002_ooool2o`00
00Gooooo1?l0000@ooooo`?o00001_ooool3o`0000?ooooo1?l0000<ooooo`;o000000?oooooo`00
0?l000000_l00002ooooo`co000000Coooooo`000?l0003o00000oooool2o`0000Oooooo0ol00009
ooooo`;o00000_ooool2o`0000Wooooo0_l00003ooooo`;o00001oooool2o`0000?ooooo1Ol0000b
ooooo`007?ooool00ol0003oooooooooo`0mooooo`Co00003?ooool8o`0000;ooooo0_l000000ooo
oooo0000o`000004ooooo`?o000000?oooooo`000?l000001_ooool2o`0000_ooooo0_l00008oooo
o`Ko00000oooool2o`0000?ooooo0_l0000Looooo`;o000000?oooooo`000?l000001oooool2o`00
00?ooooo0_l00006ooooo`Co000000Goooooo`000?l0003o0000ooooo`03o`0000;ooooo0_l0000=
ooooo`;o000000?oooooo`000?l000001_ooool2o`0000;ooooo0_l0000Gooooo`;o00000oooool4
o`0003?ooooo000Looooo`03o`000?oooooooooo03Sooooo0_l00003ooooo`?o00003Oooool7o`00
00?ooooo0_l00007ooooo`?o00002_ooool2o`0000oooooo0_l00002ooooo`?o00000_ooool4o`00
0004ooooool0003o0000o`0000;ooooo1Ol0000<ooooo`;o00003_ooool2o`0000Oooooo0_l00003
ooooo`;o00001Oooool2o`0000Cooooo1_l00003ooooo`;o00001?ooool2o`0000[ooooo0ol00003
ooooo`;o00001?ooool2o`0000?ooooo0_l00004ooooo`;o00001oooool2o`0003oooooo000Loooo
o`03o`000?oooooooooo03Sooooo0_l0000Dooooo`?o00004Oooool2o`0000?ooooo0_l000001?oo
oooo0000o`000?ooool4o`0000cooooo0ol000001?oooooo0000o`000?l00005ooooo`;o00000_oo
ool2o`0000;ooooo1ol0000:ooooo`;o00003?ooool4o`0000;ooooo0_l0000<ooooo`;o000000?o
ooooo`000?l000001Oooool3o`0000_ooooo0_l0000;ooooo`;o00000oooool2o`0000Gooooo0_l0
0002ooooo`;o00001?ooool2o`0000Oooooo0_l00004ooooo`;o00001?ooool2o`0003?ooooo000L
ooooo`03o`000?oooooooooo04;ooooo0_l0000:ooooo`;o00001Oooool3o`0000;ooooo0_l00006
ooooo`;o00000oooool2o`000004ooooool0003o0000o`0000;ooooo0_l00003ooooo`;o00001Ooo
ool4o`0000;ooooo0_l0000;ooooo`Co000000Coooooo`000?l0003ooooo0ol0000Eooooo`Go0000
0oooool2o`0000Sooooo0_l00002ooooo`;o00000_ooool2o`0000Gooooo0_l000000ooooooo0000
o`000009ooooo`;o00005_ooool2o`0000_ooooo1?l00008ooooo`?o00000oooool2o`0003?ooooo
000Looooo`03o`000?oooooooooo037ooooo0_l0000?ooooo`;o00004Oooool3o`0000;ooooo0_l0
000?ooooo`?o00001_ooool2o`0000Gooooo1?l0000?ooooo`Co000000?oooooo`000?l000001_l0
000Cooooo`;o00004?ooool2o`000004ooooool0003o0000o`0000;ooooo0_l00008ooooo`;o0000
2Oooool3o`0000Wooooo0_l0000:ooooo`;o00002oooool4o`0000Wooooo0_l0000hooooo`007?oo
ool00ol0003oooooooooo`0^ooooo`;o000000?oooooo`000?l000005_ooool2o`0000Gooooo0_l0
0004ooooo`Co000000?oooooo`000?l000003oooool2o`0000_ooooo0_l0000;ooooo`;o00003Ooo
ool2o`0000;ooooo0ol0000Booooo`;o00000_ooool2o`0000oooooo0_l00008ooooo`;o00000ooo
ool2o`0000Sooooo1?l000000ooooooo0000o`000006ooooo`;o00001oooool2o`0000;ooooo0_l0
001Aooooo`007?ooool2o`0002oooooo0_l0000Aooooo`;o00001_ooool3o`0000Cooooo0_l00004
ooooo`Co000000?oooooo`000?l000002_ooool2o`00013ooooo0_l0000;ooooo`;o00004_ooool2
o`000004ooooool0003o0000ooooo`;o00001_ooool2o`0000;ooooo0_l00004ooooo`?o00004Ooo
ool3o`0000Cooooo0_l00003ooooo`;o00001_ooool4o`0000?ooooo0_l00004ooooo`;o00001?oo
ool2o`0000;ooooo0ol00002ooooo`;o00000oooool3o`0000?ooooo0ol00015ooooo`007?ooool0
0ol0003oooooooooo`11ooooo`?o00001_ooool5o`0001Sooooo0_l00006ooooo`;o00003Oooool3
o`0000Gooooo1?l0000@ooooo`;o000000?oooooo`000?l000000ol00006ooooo`;o00000_ooool2
o`0000Cooooo1Ol00007ooooo`;o00001_ooool3o`0000Cooooo0_l00008ooooo`;o000000?ooooo
o`000?l000002oooool2o`0000Cooooo0ol000000ooooooo0000o`000002o`0000Kooooo0ol00003
ooooo`?o00002Oooool2o`0003[ooooo000Looooo`03o`000?oooooooooo037ooooo0_l00007oooo
o`Oo000000?oooooo`000?l000000oooool2o`0000;ooooo1?l00005ooooo`;o00000_ooool2o`00
00[ooooo0_l00009ooooo`;o00002_ooool2o`000004ooooool0003o0000o`0000?ooooo2?l00000
0ooooooo0000o`00000;ooooo`;o00000oooool2o`0000Oooooo0_l00003ooooo`;o00001Oooool3
o`0000Oooooo0_l00005ooooo`;o00004?ooool2o`0000Sooooo0_l00004ooooo`?o00000oooool4
o`0000;ooooo0ol0000Gooooo`?o00001_ooool2o`000003ooooool0003o000002kooooo000Loooo
o`03o`000?oooooooooo037ooooo0_l00007ooooo`Oo000000?oooooo`000?l000000oooool2o`00
00;ooooo0_l00007ooooo`;o00000_ooool2o`0000Sooooo1?l0000Eooooo`;o00001?ooool2o`00
0003ooooool0003o000000Cooooo0_l000000ooooooo0000o`00000=ooooo`;o00002_ooool2o`00
00?ooooo0_l00005ooooo`;o00001?ooool2o`0000;ooooo0_l00004ooooo`?o00006_ooool2o`00
00Gooooo1?l000000ooooooo0000o`000002o`0000;ooooo0ol0000Dooooo`;o00000_ooool2o`00
00Kooooo0_l000000ooooooo0000o`00000^ooooo`007?ooool00ol0003oooooooooo`0jooooo`?o
000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l0000@ooooo`;o00001_ooool2o`0000Oo
oooo0_l00008ooooo`;o00002_ooool2o`0001Gooooo0_l000001?oooooo0000o`000?l0000:oooo
o`;o00001oooool2o`0000Oooooo0_l00002ooooo`;o00001?ooool3o`0000;ooooo1_l0000;oooo
o`Co00000_ooool2o`0000Sooooo0_l00003ooooo`;o00000_ooool2o`0000Cooooo0_l00002oooo
o`;o00001oooool2o`0000;ooooo0_l0000<ooooo`;o0000;oooool001cooooo00?o0000oooooooo
ool0>Oooool2o`0000gooooo1?l00003ooooo`Co00000oooool2o`0000;ooooo0_l00006ooooo`;o
00000oooool2o`0000;ooooo0_l00008ooooo`;o00008?ooool3o`000003ooooool0003o000000So
oooo0_l0000:ooooo`;o00005_ooool6o`0000_ooooo1?l00002ooooo`;o00002oooool4o`0000;o
oooo0_l00004ooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o00001?ooool2o`0000[o
oooo0_l0000_ooooo`007?ooool00ol0003oooooooooo`0Wooooo`;o00003Oooool5o`0000[ooooo
0_l000000ooooooo0000o`000004o`000003ooooool0003o000000;o00000oooool2o`0000Cooooo
0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0ol0000Qooooo`;o00001oooool2o`000003
ooooool0003o000000cooooo0_l0000Uooooo`;o00007oooool2o`0000gooooo0_l00003ooooo`;o
00002Oooool2o`0003_ooooo000Looooo`03o`000?oooooooooo01?ooooo0_l0000Booooo`;o0000
3Oooool4o`0000_ooooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool2o`0000Wooooo
0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000?o00005oooool2o`0000So
oooo0_l00005ooooo`Ko00000oooool2o`0000Sooooo0_l00008ooooo`;o00001Oooool4o`0000Go
oooo0ol0000:ooooo`?o00001?ooool4o`0002Gooooo0_l0001;ooooo`007?ooool00ol0003ooooo
ooooo`0Cooooo`;o00008oooool2o`0001Oooooo0ol00007ooooo`;o00001_ooool4o`000003oooo
ool0003o000001Oooooo0_l0000?ooooo`;o00000_ooool2o`0000?ooooo0_l00003ooooo`;o0000
3Oooool2o`0000Gooooo1?l00005ooooo`?o00002Oooool4o`000004ooooool0003o0000ooooo`Co
00002Oooool2o`0001cooooo0_l000000ooooooo0000o`000005ooooo`;o00001Oooool2o`0003So
oooo000Looooo`03o`000?oooooooooo03Sooooo0_l0000=ooooo`?o00001_ooool4o`0000Oooooo
0_l00006ooooo`?o00000_ooool2o`00017ooooo0_l00004ooooo`;o00002oooool2o`0000[ooooo
0_l00003ooooo`?o00004Oooool2o`0000Oooooo0_l0000=ooooo`;o00000oooool2o`0000?ooooo
0_l00009ooooo`;o00004oooool2o`0000Kooooo0ol000000ooooooo0000o`000002o`0000?ooooo
0ol00004ooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0?oooool2o`0000Kooooo1_l0
0003ooooo`;o000000?oooooo`000?l000003oooool2o`0000;ooooo0_l0000Aooooo`;o00003Ooo
ool6o`0000[ooooo0_l000000ooooooo0000o`000002o`0000kooooo0_l00002ooooo`;o00001_oo
ool3o`0001Oooooo0ol0000Mooooo`;o00001_ooool2o`0000Cooooo0_l00004ooooo`Co0000??oo
ool001cooooo00?o0000ooooooooool0>_ooool2o`0000?ooooo0_l00009ooooo`Go000000Cooooo
o`000?l0003ooooo0_l0000cooooo`Oo00003_ooool2o`0000;ooooo0_l0000<ooooo`;o00001_oo
ool2o`0000;ooooo1?l00006ooooo`;o00002Oooool2o`0000Cooooo0_l0000aooooo`Co00000ooo
ool2o`000003ooooool0003o000003Cooooo000Looooo`03o`000?oooooooooo03[ooooo0_l00006
ooooo`;o00002Oooool2o`000003ooooool0003o000000Kooooo0_l00006ooooo`;o00001?ooool2
o`0001Kooooo1?l00006ooooo`;o000000?oooooo`000?l000000ol000000ooooooo0000o`000002
o`0000Cooooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo0_l00007ooooo`;o00001_ooool2
o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000000oooool2o`0000Wooooo0_l0
0003ooooo`;o0000<_ooool2o`0000Gooooo0_l000000ooooooo0000o`00000dooooo`007?ooool0
0ol0003oooooooooo`0jooooo`;o00000_ooool2o`0000;ooooo1?l0000Booooo`;o00000_ooool2
o`0000;ooooo0_l00004ooooo`;o00003Oooool2o`0000Oooooo1Ol000000ooooooo0000o`000003
o`0000;ooooo2_l000000ooooooo0000o`000003o`0000Kooooo0_l00003ooooo`;o00004_ooool2
o`0000?ooooo0ol00005ooooo`?o00002Oooool5o`0000Kooooo0_l0000Yooooo`;o0000?_ooool0
01cooooo00?o0000ooooooooool0<_ooool2o`0000Wooooo0ol00003ooooo`?o00001oooool2o`00
0004ooooool0003o0000o`0000Wooooo0_l00003ooooo`;o00004_ooool2o`0000[ooooo0_l00000
0ooooooo0000o`000003o`0000Cooooo1?l00005ooooo`Co00002?ooool6o`0000Cooooo0_l00003
ooooo`;o00003?ooool2o`0000Cooooo1Ol00008ooooo`?o000000?oooooo`000?l000000_l00004
ooooo`?o00003?ooool3o`0001;ooooo0_l00006ooooo`;o0000?Oooool001cooooo00?o0000oooo
ooooool0<?ooool4o`0000Wooooo0_l00004ooooo`;o00002?ooool2o`000003ooooool0003o0000
00;o00003?ooool3o`000003ooooool0003o0000017ooooo1?l00006ooooo`;o00001?ooool6o`00
0003ooooool0003o000000?ooooo0_l0000=ooooo`Go00001Oooool3o`0000;ooooo0ol00008oooo
o`;o00001oooool2o`0000_ooooo0_l00004ooooo`;o00001?ooool3o`0000[ooooo1Ol00003oooo
o`;o00003Oooool2o`0000;ooooo0_l00002ooooo`;o0000?Oooool001cooooo0_l0000aooooo`;o
00005oooool2o`0000?ooooo1_l00002ooooo`;o00001_ooool4o`0000;ooooo0_l00004ooooo`;o
00002oooool8o`0000;ooooo0_l00003ooooo`[o000000?oooooo`000?l000000_l0000Aooooo`;o
00001Oooool2o`0000?ooooo0ol00007ooooo`;o00000oooool4o`0001Gooooo0_l00007ooooo`;o
00001_ooool2o`0000Kooooo0_l00004ooooo`;o00002oooool3o`0000;ooooo0_l0000looooo`00
7?ooool00ol0003oooooooooo`19ooooo`Co000000?oooooo`000?l000000ol00003ooooo`;o0000
1_ooool4o`0000Sooooo0_l00003ooooo`;o00002?ooool;o`000003ooooool0003o000000Co0000
00?oooooo`000?l000000_l000000ooooooo0000o`000002o`00017ooooo0_l00005ooooo`;o0000
0oooool3o`0000cooooo1?l00007ooooo`;o00003?ooool2o`0000;ooooo0_l00003ooooo`;o0000
2?ooool2o`0000Wooooo0ol00003ooooo`;o00001oooool2o`0000;ooooo0_l0000looooo`007?oo
ool00ol0003oooooooooo`0fooooo`;o00004oooool2o`0000Cooooo0_l000000ooooooo0000o`00
000:ooooo`;o00003Oooool2o`0000?ooooo0_l00003ooooo`;o00000ooooolBo`000003ooooool0
003o000000Go00008_ooool2o`000003ooooool0003o000000gooooo0_l00008ooooo`;o00001_oo
ool2o`0000Gooooo1?l00004ooooo`;o00002?ooool3o`0000Cooooo1?l0000=ooooo`;o0000>?oo
ool001cooooo00?o0000ooooooooool0=_ooool2o`0000[ooooo0_l00003ooooo`;o00000oooool2
o`0000?ooooo0_l000000ooooooo0000o`00000Nooooo`;o000000?oooooo`000?l000001OoooolC
o`0000;ooooo2?l0000Booooo`;o00002?ooool2o`000004ooooool0003o0000ooooo`;o00004Ooo
ool2o`0000;ooooo1?l00005ooooo`;o00001_ooool4o`0000kooooo0ol00006ooooo`;o00003Ooo
ool2o`0003Sooooo000Looooo`03o`000?oooooooooo03?ooooo0_l0000=ooooo`;o00000oooool2
o`0000?ooooo0_l00003ooooo`;o00001Oooool2o`000003ooooool0003o000000;o00005?ooool2
o`0000;ooooo0ol00002ooooo`Oo000000?oooooo`000?l000005_l00009ooooo`;o00001_ooool2
o`0000Sooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool2o`0000Cooooo0_l00006
ooooo`;o00000_ooool2o`0000Oooooo0_l00008ooooo`;o00003oooool2o`0000Cooooo0_l0000=
ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0<oooool2o`0000gooooo0_l00003oooo
o`;o00000oooool2o`0000[ooooo0_l000000ooooooo0000o`000002o`0000kooooo0ol00003oooo
o`;o000000?oooooo`000?l000000_l00002oooooaOo000000?oooooo`000?l000001_l000001?oo
oooo0000o`000?ooool2o`0000?ooooo0_l00004ooooo`Co00002Oooool4o`0000;ooooo0_l00002
ooooo`;o00001?ooool2o`000003ooooool0003o000000?ooooo0_l00005ooooo`;o00003_ooool3
o`0001;ooooo1?l0000=ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0?oooool2o`00
0003ooooool0003o000000?ooooo0_l0000Dooooo`;o00003_ooool3o`0000Cooooo9_l00002oooo
o`?o000000?oooooo`000?l000000oooool2o`0000Cooooo0_l00002ooooo`;o00001oooool2o`00
00Kooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00001Oooool4
o`0000gooooo0ol0000Aooooo`Wo0000A?ooool001cooooo00?o0000ooooooooool0:?ooool2o`00
017ooooo0_l00002ooooo`?o00006oooool2o`0001Gooooo0_l00003oooooako00001Oooool2o`00
017ooooo0_l00002ooooo`Co00000_ooool2o`0000Gooooo0_l00003ooooo`;o000000?oooooo`00
0?l000003_ooool3o`0000cooooo1Ol00007ooooo`;o00001oooool9o`0000gooooo0_l0000eoooo
o`007?ooool00ol0003oooooooooo`0Xooooo`?o00001oooool2o`0000Oooooo1?l000000ooooooo
0000o`000008ooooo`;o00001?ooool4o`000003ooooool0003o000000Cooooo0_l0000Booooo`;o
00001_oooolWo`0000?ooooo0ol0000?ooooo`Co00000_ooool2o`0001gooooo0_l00003ooooo`;o
00001Oooool2o`000004ooooool0003o0000ooooo`Co00001Oooool2o`0000Sooooo0_l00002oooo
o`Co00003Oooool2o`0003Gooooo000Looooo`03o`000?oooooooooo02Wooooo0_l00007ooooo`;o
00002Oooool2o`0000?ooooo0_l00006ooooo`;o00001?ooool7o`0000;ooooo1?l0000Booooo`?o
00001Oooool_o`0000Cooooo0_l0000Hooooo`;o00000_ooool2o`0000?ooooo0_l000000ooooooo
0000o`000006ooooo`;o00000oooool4o`0000?ooooo0_l00005ooooo`?o00003oooool3o`000003
ooooool0003o000000;o0000A?ooool001cooooo00?o0000ooooooooool0@_ooool4o`0000Cooooo
1?l00002ooooo`;o000000?oooooo`000?l000000_l00002ooooo`Co00004oooool2o`0000?ooooo
0_l000000ooooooo0000o`00000=o`000003ooooool0003o000001?o000000?oooooo`000?l00000
0ol000000ooooooo0000o`000002o`0000;ooooo0_l0000Hooooo`;o00000_ooool2o`0000?ooooo
1Ol00003ooooo`;o00002?ooool2o`0000[ooooo0_l00005ooooo`;o00002_ooool2o`0000?ooooo
0_l0000Fooooo`;o0000;?ooool001cooooo00?o0000ooooooooool0<?ooool2o`00013ooooo1?l0
0006ooooo`;o00000_ooool3o`0000Sooooo0_l0000?ooooo`Co00001?ooool6o`000003ooooool0
003o000001oo00001?ooool3o`000003ooooool0003o000000Co00001?ooool2o`0000Gooooo0_l0
0008ooooo`?o000000?oooooo`000?l000000oooool2o`000005ooooool0003o0000o`000?ooool0
0_l00004ooooo`;o00000oooool3o`0000;ooooo0_l00002ooooo`?o00001_ooool3o`0000?ooooo
0_l000000ooooooo0000o`000008ooooo`Ko00000_ooool2o`0001;ooooo0_l0000/ooooo`007?oo
ool00ol0003oooooooooo`0Looooo`;o00004_ooool2o`0000[ooooo0_l00006ooooo`;o00001_oo
ool2o`0000?ooooo0_l00002ooooo`;o00005?ooool5o`0000Cooooo;Ol00002ooooo`Oo00001?oo
ool2o`0000Gooooo0ol00007ooooo`Ko00000_ooool3o`000004ooooool0003o0000o`0000;ooooo
0_l00008ooooo`?o00001_ooool3o`0000Kooooo0ol00006ooooo`;o00001?ooool3o`000003oooo
ool0003o000000;o00001?ooool2o`00043ooooo000Looooo`03o`000?oooooooooo01cooooo0_l0
000Nooooo`;o00001_ooool2o`0000Kooooo0_l00002ooooo`;o00000oooool2o`0001Cooooo1_l0
0003ooooo`;o000000Coooooo`000?l0003ooooo8?l00002ooooo`Go000000?oooooo`000?l00000
0ol00005ooooo`;o00002?ooool2o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l00000
0_l000000ooooooo0000o`000002o`0000Gooooo0_l00005ooooo`;o00000_ooool2o`0000Kooooo
0_l00003ooooo`;o00001Oooool2o`0000[ooooo0ol0001;ooooo`0000Koooooonk^k_lb<S;o0000
oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000oooo
ooooool0COooool2o`000003ooooool0003o000001gooooo0_l00002ooooo`?o00001OoooolTo`00
00?ooooo1?l00006ooooo`?o00002Oooool2o`000003ooooool0003o000000Cooooo3?l00004oooo
o`;o00001?ooool3o`0000kooooo0_l00004ooooo`?o0000F?ooool00006oooooomgMgOoV9RHoooo
oonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oo
oooooooo02Wooooo0_l0000Eooooo`;o00000_ooool2o`0000Oooooo0_l0000=ooooo`;o00002_oo
ool2o`000003ooooool0003o000000Cooooo1?l00007ooooob?o000000Coooooo`000?l0003ooooo
0_l00002ooooo`;o00001?ooool3o`0000Sooooo1ol00002oooooa?o00001?ooool2o`0001Cooooo
1?l00004ooooo`;o00001oooool4o`0004Kooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oo
oooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo02Sooooo
0ol0000=ooooo`;o000000?oooooo`000?l000000oooool3o`000003ooooool0003o000000Cooooo
0ol0000?ooooo`?o00002Oooool2o`000003ooooool0003o000000Cooooo1_l00002ooooobKo0000
00?oooooo`000?l000000_ooool2o`000003ooooool0003o000000;o00000oooool2o`0000Cooooo
8?l0000Jooooo`Co00001?ooool2o`0000Oooooo1Ol00009ooooo`;o0000>_ooool00003ooooool0
003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo
0ol0000Xooooo`;o00003?ooool4o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000
o`000004ooooo`?o00004?ooool2o`0000Wooooo1?l00003ooooo`;o000000?oooooo`000?l00000
0ol00002ooooobCo00000_ooool4o`000003ooooool0003o000000;o000000Coooooo`000?l0003o
00002?oooolOo`0000?ooooo0_l00007ooooo`;o00004Oooool2o`0000Cooooo0_l00007ooooo`?o
00002Oooool2o`0003[ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo
00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo03Kooooo0ol00006ooooo`;o
00005oooool2o`0000kooooo1?l00003ooooo`;o000000?oooooo`000?l000001?oooolUo`0000;o
oooo2Ol00002ooooo`Go00002OoooolKo`0000?ooooo0ol000000ooooooo0000o`000003ooooo`;o
00003Oooool2o`0000;ooooo0_l00004ooooo`;o00001oooool2o`0000[ooooo0_l0000jooooo`00
00?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo
00?o0000ooooooooool09oooool2o`0000kooooo0_l00006ooooo`;o00000oooool3o`00017ooooo
1Ol00009ooooo`;o00001Oooool2o`0000Oooooo7?l000000ooooooo0000o`000008o`000003oooo
ool0003o000000;ooooo0_l000000ooooooo0000o`000004ooooo`Co00000_oooolQo`0000Cooooo
0ol000000ooooooo0000o`00000Booooo`;o00001Oooool2o`0000Kooooo0_l0000>ooooo`;o0000
>_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03
o`000?oooooooooo02Oooooo0_l0000Dooooo`Co00000oooool3o`00017ooooo1Ol00009ooooo`;o
00001Oooool4o`0000?ooooo:Ol000000ooooooo0000o`000003ooooo`Co00001Oooool2o`000003
ooooool0003o0000027o000000Coooooo`000?l0003ooooo0_l000001Ooooooo0000o`000?l0003o
oooo00;o00005_ooool2o`0000Kooooo0_l0001:ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^
k^h<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0?Oooool2o`0001;ooooo
0_l000000ooooooo0000o`000003o`0001Kooooo5ol000000ooooooo0000o`00000Do`0000;ooooo
1_l00003ooooo`Ko000000?oooooo`000?l000003_l000000ooooooo0000o`00000@o`000003oooo
ool0003o000000;ooooo1Ol000000ooooooo0000o`000002o`0000Gooooo0_l000000ooooooo0000
o`000007ooooo`;o00005?ooool2o`0003oooooo000Looooo`03o`000?oooooooooo02Cooooo0_l0
0004ooooo`;o00006_ooool2o`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l000001Ol0
000Fooooo`So000000?oooooo`000?l000004_l00002ooooo`go00000_ooool7o`0000;ooooo1_l0
0003ooooob?o00000oooool4o`0000Cooooo0_l00005ooooo`;o000000?oooooo`000?l000000_l0
0005ooooo`;o00005?ooool3o`0003kooooo000Looooo`03o`000?oooooooooo02Cooooo0_l00004
ooooo`;o00006_ooool2o`000003ooooool0003o000000;ooooo0_l00006ooooo`;o00000_ooool4
o`0001Gooooo4ol000000ooooooo0000o`000006o`000003ooooool0003o000000ko000000Cooooo
o`000?l0003ooooo1?l000001?oooooo0000o`000?ooool2o`0000Cooooo9_l00002ooooo`;o0000
1Oooool2o`0000Kooooo0_l000000ooooooo0000o`00000Kooooo`?o0000?_ooool001cooooo00?o
0000ooooooooool0>Oooool3o`0000[ooooo1Ol0000:ooooo`;o00000oooool3o`0001Gooooo1_l0
00000ooooooo0000o`00000:o`000003ooooool0003o000000Ko000000?oooooo`000?l000004?l0
0004ooooo`;o000000Coooooo`000?l0003ooooo0_l00006ooooobGo00001?ooool2o`0000;ooooo
0_l00006ooooo`;o000000Coooooo`000?l0003o00005_ooool4o`00047ooooo000Looooo`03o`00
0?oooooooooo03Sooooo1?l00005ooooo`;o00001?ooool2o`00017ooooo0_l0000Cooooo`Go0000
00?oooooo`000?l000000_l00002ooooo`_o000000?oooooo`000?l000006_l0000;ooooo`;o0000
00Coooooo`000?l0003ooooo9?l00004ooooo`;o00002_ooool2o`000005ooooool0003o0000o`00
0?ooool00_l00009ooooo`;o00002?ooool4o`00047ooooo000Looooo`03o`000?oooooooooo03So
oooo0_l00007ooooo`Co00004_ooool2o`0001;ooooo0_l00002ooooo`Go00000oooool:o`000003
ooooool0003o000001So000000Coooooo`000?l0003ooooo0ol000001?oooooo0000o`000?l00003
ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooob7o00005?ooool2o`0000Cooooo0_l0
0007ooooo`Co0000COooool001cooooo00?o0000ooooooooool0@oooool2o`0000;ooooo0_l00009
ooooo`;o00000oooool2o`00017ooooo0ol00004ooooo`Go00000_ooool5o`000003ooooool0003o
000000;o000000?oooooo`000?l000004ol000000ooooooo0000o`000003o`0000;ooooo0_l00000
0ooooooo0000o`000002o`000003ooooool0003o000000;o00001OoooolXo`0000?ooooo0_l0000:
ooooo`Go00002oooool2o`0004oooooo000Looooo`03o`000?oooooooooo04Cooooo0_l000000ooo
oooo0000o`000009ooooo`;o00004_ooool2o`0000;ooooo0_l00007ooooobGo000000?oooooo`00
0?l000001Ol00003ooooo`;o00000oooool4o`0000?ooooo7ol000000ooooooo0000o`000008o`00
00;ooooo1?l00008ooooo`?o000000?oooooo`000?l000002oooool2o`0000Oooooo0_l00016oooo
o`007?ooool00ol0003oooooooooo`0nooooo`;o00001?ooool2o`00023ooooo0_l0000:ooooob7o
000000?oooooo`000?l000001Ol00003ooooo`Co00001?ooool2o`0000;ooooo0_l00003ooooo`;o
00001_oooolPo`0000Cooooo1?l00008ooooo`;o00000_ooool2o`0001Cooooo0_l00016ooooo`00
7?ooool00ol0003oooooooooo`0nooooo`;o00001oooool2o`0000Gooooo1?l00009ooooo`;o0000
2Oooool5o`0000Oooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool@o`000003oooo
ool0003o000000Wo000000?oooooo`000?l000001_l00004ooooo`;o000000?oooooo`000?l00000
1?l00006ooooo`Ko00000_oooolLo`0000Cooooo0_l00003ooooo`;o00001oooool2o`00013ooooo
0_l0001:ooooo`007?ooool00ol0003oooooooooo`12ooooo`;o000000?oooooo`000?l000000_l0
0005ooooo`Co00002Oooool2o`0000[ooooo1Ol00009ooooo`;o000000?oooooo`000?l000004ol0
00000ooooooo0000o`000007o`000003ooooool0003o000000Ko00002?ooool7o`000003ooooool0
003o000000?ooooo1_l000000ooooooo0000o`00000Co`0000?ooooo1Ol000000ooooooo0000o`00
0005o`000003ooooool0003o000001Wooooo0_l000000ooooooo0000o`000017ooooo`007?ooool0
0ol0003oooooooooo`12ooooo`;o000000?oooooo`000?l000001?ooool2o`0001_ooooo1ol00003
ooooo`;o000000?oooooo`000?l000006_l000001?oooooo0000o`000?l00002ooooo`Go00003?oo
ool2o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`Go000000Coooooo`000?l0003ooooo
5Ol00002ooooo`;o00000_ooool3o`0000;ooooo0_l00003ooooo`?o00004?ooool2o`0000Kooooo
0ol00017ooooo`007?ooool2o`00037ooooo0_l0000<ooooo`;o00000oooool3o`0000Gooooo0_l0
0002ooooo`;o000000Coooooo`000?l0003o00001oooool2o`0000[ooooo0_l00002ooooo`?o0000
0oooool3o`000005ooooool0003o0000o`000?ooool04Ol000000ooooooo0000o`000005o`000004
ooooool0003o0000ooooo`;o000000?oooooo`000?l000004Oooool2o`000003ooooool0003o0000
00Cooooo0_l000000ooooooo0000o`00000Ro`0000Oooooo0ol0000<ooooo`;o00000_ooool2o`00
00Kooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`0Xooooo`;o000000?oooooo`000?l0
00000oooool2o`0000cooooo0_l00003ooooo`?o00002Oooool2o`000004ooooool0003o0000o`00
00Oooooo0_l00005ooooo`;o00002?ooool2o`0000Cooooo0_l00002ooooo`;o000000?oooooo`00
0?l000002ol00002ooooo`[o000000?oooooo`000?l000006_ooool2o`0000Sooooo7?l00002oooo
o`Co00005oooool2o`0000Kooooo0ol00004ooooo`Co0000@oooool001cooooo00?o0000oooooooo
ool0:?ooool2o`000003ooooool0003o000001gooooo0_l00007ooooo`;o00000oooool2o`0000;o
oooo0_l00005ooooo`;o00002?ooool2o`0000Gooooo1Ol00003oooooaco00003Oooool2o`0000Go
oooo0_l00008ooooo`;o00000_ooool3o`0000;ooooo4_l000000ooooooo0000o`000004ooooo`;o
00005_ooool2o`0000;ooooo0_l00005ooooo`?o00001?ooool4o`0004?ooooo000Looooo`03o`00
0?oooooooooo03oooooo0_l00009ooooo`;o000000?oooooo`000?l000001?ooool4o`000003oooo
ool0003o000001Cooooo0_l00004ooooo`Co00001?oooolBo`000003ooooool0003o000000Oo0000
1oooool2o`0000Cooooo0_l00005ooooo`;o00002?ooool2o`0000?ooooo0ol000000ooooooo0000
o`00000Ao`000003ooooool0003o000000?ooooo0_l0000Fooooo`;o00000_ooool4o`0000;ooooo
1_l00019ooooo`007?ooool00ol0003oooooooooo`0oooooo`Co00000_ooool2o`0000Kooooo0_l0
0006ooooo`;o00000_ooool2o`0001?ooooo0_l00005ooooo`;o00000_oooolDo`0000;ooooo0ol0
00000ooooooo0000o`000005o`0000Gooooo0_l0000Kooooo`;o00000_oooolEo`000003ooooool0
003o000000Gooooo0_l0000<ooooo`;o00002Oooool2o`000004ooooool0003o0000o`0000;ooooo
0_l000000ooooooo0000o`000016ooooo`007?ooool00ol0003oooooooooo`11ooooo`;o00000_oo
ool2o`000003ooooool0003o000000Sooooo0_l00005ooooo`;o00000_ooool2o`0000oooooo0_l0
0005oooooaSo00001_ooool3o`0000;ooooo0_l00007ooooo`;o00007?ooool=o`0000;ooooo1Ol0
0003ooooo`;o000000?oooooo`000?l000000_ooool3o`0000_ooooo0_l0000:ooooo`Co00001_oo
ool2o`0004Kooooo000Looooo`03o`000?oooooooooo04Sooooo0_l00005ooooo`;o000000?ooooo
o`000?l000002Oooool2o`0001Sooooo0_l000000ooooooo0000o`00000Do`000003ooooool0003o
000000;o00001_ooool4o`0000;ooooo0_l0000;ooooo`;o00003?ooool2o`000003ooooool0003o
000000Gooooo1Ol00003ooooo`;o00002Oooool2o`0000;ooooo0ol00003ooooo`;o00003_ooool2
o`0000;ooooo0ol0001?ooooo`007?ooool00ol0003oooooooooo`18ooooo`Co00000oooool2o`00
00?ooooo0_l0000Tooooo`?o00000_ooool2o`0000;ooooo3Ol000000ooooooo0000o`000002oooo
o`;o00001?ooool4o`0000oooooo0_l00004ooooo`;o00001_ooool3o`0000?ooooo0_l00002oooo
o`;o000000?oooooo`000?l000001Ol00005ooooo`;o00003?ooool2o`0000Sooooo0_l00002oooo
o`Co00000oooool2o`0004oooooo000Looooo`03o`000?oooooooooo04Gooooo0_l00003ooooo`?o
000000Coooooo`000?l0003o00000oooool2o`0000oooooo0_l0000Dooooo`;o00002_ooool7o`00
00;ooooo0_l000000ooooooo0000o`000002o`0000Gooooo0_l00002ooooo`?o00001_ooool2o`00
00Wooooo0_l00007ooooo`;o00000oooool2o`0000Gooooo1Ol00007ooooo`?o00001Oooool2o`00
00kooooo0_l00002ooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0AOooool2o`0000?o
oooo0ol000001?oooooo0000o`000?l00007ooooo`;o00002oooool2o`0000Wooooo0_l0000>oooo
o`;o00002?ooool4o`0000;ooooo0_l000000ooooooo0000o`00000:ooooo`Co00001_ooool3o`00
00;ooooo0_l0000:ooooo`;o00003Oooool3o`0000[ooooo0_l00005ooooo`;o00002Oooool2o`00
05oooooo000Looooo`03o`000?oooooooooo05Sooooo0_l00002ooooo`;o00004_ooool3o`0000go
oooo0_l00006ooooo`;o00001oooool2o`0000Kooooo0_l00004ooooo`Wo000000Coooooo`000?l0
003o00000_ooool2o`0000[ooooo1Ol0000;ooooo`?o00006oooool2o`0000Gooooo0_l00003oooo
o`;o0000Doooool001cooooo00?o0000ooooooooool0G?ooool2o`0000Gooooo0_l0000<ooooo`;o
00004?ooool2o`0000;ooooo0ol00003ooooo`;o00000_ooool3o`0000Gooooo0_l00008ooooo`Go
00004oooool5o`000003ooooool0003o000000Oooooo0ol00004ooooo`;o00000_ooool4o`000003
ooooool0003o000000cooooo1?l00003ooooo`;o00000oooool2o`0005?ooooo000Looooo`03o`00
0?oooooooooo03_ooooo0_l0000@ooooo`;o00003?ooool2o`0000Kooooo0_l00006ooooo`;o0000
0_ooool2o`0000kooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00001?ooool3o`0000;o
oooo0_l0000Aooooo`;o00005oooool5o`0000[ooooo0_l00002ooooo`;o00000_ooool4o`000004
ooooool0003o0000ooooo`;o00002Oooool8o`0000Oooooo0_l0001@ooooo`007?ooool00ol0003o
ooooooooo`0hooooo`;o000000?oooooo`000?l000004?ooool2o`0000cooooo0_l00002ooooo`;o
000000?oooooo`000?l000001oooool2o`0000;ooooo0ol0000=ooooo`;o00001Oooool2o`0000Ko
oooo0ol0000^ooooo`?o00002oooool2o`0000Sooooo0_l00004ooooo`;o00002Oooool8o`0000;o
oooo1?l000000ooooooo0000o`000006ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0
>?ooool2o`0001cooooo0_l000000ooooooo0000o`000004ooooo`Go00003?ooool2o`0001Wooooo
0_l00002ooooo`;o00001oooool2o`0002Kooooo0_l0000Uooooo`;o000000?oooooo`000?l00000
1_ooool4o`0000Wooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`1Fooooo`;o000000?o
ooooo`000?l000001_ooool2o`0000kooooo0_l00006ooooo`Ko00003?ooool2o`0000?ooooo0_l0
00000ooooooo0000o`000003ooooo`;o00001?ooool2o`00043ooooo0_l00005ooooo`;o00001ooo
ool2o`0005Oooooo000Looooo`;o0000Eoooool2o`0000Wooooo0_l00008ooooo`;o00001?ooool2
o`000003ooooool0003o000000?ooooo1_l00007ooooo`;o00002?ooool2o`000003ooooool0003o
000000Cooooo0_l00003ooooo`;o0000@?ooool2o`0000kooooo0_l0001Gooooo`007?ooool00ol0
003oooooooooo`1Booooo`;o00003Oooool2o`0000Oooooo0ol00007ooooo`;o00004?ooool2o`00
017ooooo0_l0000nooooo`;o0000K_ooool001cooooo00?o0000ooooooooool0>_ooool2o`0001Ko
oooo0_l00004ooooo`;o00003oooool4o`0001cooooo0_l0000:ooooo`;o0000>?ooool2o`0000So
oooo0_l0000>ooooo`;o00002Oooool2o`0005?ooooo000Looooo`03o`000?oooooooooo03[ooooo
0_l0000Gooooo`;o00000oooool2o`0000kooooo0ol00002ooooo`;o00006_ooool4o`0000Sooooo
0_l0000Uooooo`;o00001?ooool2o`0000_ooooo1Ol0000>ooooo`;o00001Oooool2o`0000Wooooo
0_l0001Cooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o000000?oooooo`000?l000004?oo
ool2o`0000?ooooo0_l0000Looooo`;o00000oooool2o`0002[ooooo0_l00004ooooo`;o00003Ooo
ool3o`0000cooooo1?l0001Uooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00002oooool2
o`0001;ooooo0_l0000Oooooo`;o00000_ooool3o`0000Wooooo0_l0000Qooooo`Co00005?ooool2
o`0000Gooooo0_l000000ooooooo0000o`00000Aooooo`;o00001Oooool2o`0004gooooo000Loooo
o`03o`000?oooooooooo04;ooooo0_l00005ooooo`Co00005oooool2o`0000Cooooo0_l00004oooo
o`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00001Oooool2o`0000Sooooo0_l0000:oooo
o`;o00008Oooool4o`0000;ooooo0_l00006ooooo`;o00002?ooool2o`0000;ooooo0_l000000ooo
oooo0000o`00000:ooooo`Co00001_ooool2o`0000Gooooo0_l0001=ooooo`007?ooool00ol0003o
ooooooooo`12ooooo`;o00001oooool2o`0000Oooooo0_l0000>ooooo`;o000000?oooooo`000?l0
00001oooool4o`000003ooooool0003o000000;ooooo0_l00003ooooo`;o00001?ooool5o`0001;o
oooo0_l0000Uooooo`Co00001_ooool4o`000003ooooool0003o000000Oooooo0_l0000=ooooo`Co
0000G?ooool001cooooo00?o0000ooooooooool0B_ooool2o`0000Sooooo0_l0000Aooooo`;o0000
0_ooool2o`0000Gooooo0_l0000?ooooo`?o000000?oooooo`000?l000001_ooool2o`0000Sooooo
0_l0000Tooooo`;o000000Coooooo`000?l0003o00002Oooool2o`000004ooooool0003o0000o`00
00Oooooo0_l00005ooooo`?o0000I?ooool001cooooo00?o0000ooooooooool0B_ooool2o`0000[o
oooo0_l000000ooooooo0000o`00000@ooooo`;o00004oooool2o`000003ooooool0003o000000[o
oooo0_l00008ooooo`;o00007?ooool2o`0000Kooooo0_l00002ooooo`;o00003?ooool3o`0000Oo
oooo0_l00005ooooo`?o00001?ooool2o`0005kooooo000Looooo`03o`000?oooooooooo04gooooo
0_l00007ooooo`;o000000?oooooo`000?l000004?ooool2o`0001?ooooo1?l0000Kooooo`;o0000
5_ooool2o`00017ooooo0_l00005ooooo`;o00001?ooool2o`0000;ooooo0_l00004ooooo`;o0000
1_ooool2o`0005kooooo000Looooo`03o`000?oooooooooo04gooooo0_l0000Fooooo`;o00001?oo
ool2o`0001Gooooo0ol0000Fooooo`;o00000_ooool2o`0002Wooooo0_l0000:ooooo`?o00002?oo
ool2o`000003ooooool0003o000006?ooooo000Looooo`03o`000?oooooooooo06Gooooo0_l0000C
ooooo`;o00000oooool2o`0000;ooooo0_l0000Dooooo`Co00007?ooool3o`0000Oooooo0_l0000A
ooooo`?o00002oooool2o`0006?ooooo000Looooo`03o`000?oooooooooo06?ooooo0ol00007oooo
o`;o00001?ooool2o`0000Gooooo0_l00003ooooo`Co00005_ooool2o`0001kooooo0ol00006oooo
o`?o00003Oooool2o`00013ooooo0_l0001Sooooo`007?ooool00ol0003oooooooooo`1?ooooo`;o
00001?ooool2o`0000Wooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00001?ooool2o`00
00Cooooo0_l00009ooooo`Go000000?oooooo`000?l000001_ooool2o`0000cooooo0_l000000ooo
oooo0000o`000002ooooo`?o00005_ooool2o`0000Kooooo0_l00007ooooo`;o00001Oooool2o`00
013ooooo0_l0001Sooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o00000oooool2o`0000Co
oooo0_l00005ooooo`;o00000_ooool2o`0000Gooooo0_l00003ooooo`;o00000oooool2o`0000_o
oooo0ol000000ooooooo0000o`000002o`0000Kooooo0_l0000<ooooo`;o000000?oooooo`000?l0
00000_ooool3o`0001Kooooo0_l00006ooooo`;o00001oooool2o`0000Wooooo0_l00004ooooo`;o
00003Oooool2o`0005cooooo000Looooo`;o0000Boooool2o`0000Cooooo0_l00005ooooo`;o0000
0oooool2o`0000kooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo0_l00007ooooo`?o0000
5_ooool2o`000003ooooool0003o000000;o00000_ooool2o`0000gooooo0_l00002ooooo`?o0000
0_ooool2o`0000Sooooo0_l0000;ooooo`;o000000?oooooo`000?l000001?ooool2o`0000gooooo
0_l0001Looooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00001Oooool2o`0000Cooooo0_l0
0007ooooo`;o00001_ooool2o`0000;ooooo1Ol00002ooooo`;o000000?oooooo`000?l000000_l0
000Kooooo`;o000000?oooooo`000?l000000ol000000ooooooo0000o`00000=ooooo`;o00000_oo
ool3o`0000;ooooo0_l00004ooooo`;o00000_ooool3o`0000?ooooo0_l00005ooooo`;o0000M?oo
ool001cooooo00?o0000ooooooooool0GOooool2o`0000Oooooo0_l00002ooooo`;o00000_ooool7
o`0000Oooooo1?l0000Qooooo`;o00004?ooool2o`0000gooooo0_l00003ooooo`Co000000?ooooo
o`000?l00000Noooool001cooooo00?o0000ooooooooool0IOooool2o`0000?ooooo0_l00004oooo
o`;o00000oooool2o`000003ooooool0003o000000;ooooo0_l0000Booooo`;o00000_ooool2o`00
00Oooooo0_l00007ooooo`;o00002oooool2o`0001;ooooo1?l00003ooooo`?o00002?ooool2o`00
06kooooo000Looooo`03o`000?oooooooooo063ooooo0_l00003ooooo`;o00000_ooool2o`0000Go
oooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000001Kooooo0_l00002ooooo`;o
00001oooool2o`0000Oooooo0_l0000Nooooo`;o00001_ooool3o`0000Sooooo0_l0001^ooooo`00
7?ooool00ol0003oooooooooo`1Pooooo`;o00001oooool2o`000003ooooool0003o000000?ooooo
1?l0000Kooooo`;o00005?ooool2o`0000Cooooo0_l0000Hooooo`;o00003?ooool2o`000003oooo
ool0003o0000073ooooo000Looooo`03o`000?oooooooooo06[ooooo1?l00003ooooo`;o000000Co
ooooo`000?l0003ooooo0_l0000]ooooo`;o00001?ooool2o`0001Cooooo0_l00005ooooo`;o0000
2Oooool2o`000003ooooool0003o0000073ooooo000Looooo`03o`000?oooooooooo067ooooo0_l0
00000ooooooo0000o`000007o`0000Oooooo0_l000000ooooooo0000o`00000Zooooo`?o00000_oo
ool2o`00013ooooo0_l00006ooooo`;o00001Oooool2o`0000;ooooo0_l00007ooooo`Co0000Kooo
ool001cooooo00?o0000ooooooooool0HOooool2o`000003ooooool0003o000000Co000000?ooooo
o`000?l000000_l0000<ooooo`;o00003_ooool3o`0000Gooooo0_l0000>ooooo`?o00000_ooool2
o`00013ooooo1?l0000?ooooo`;o00001oooool4o`0006oooooo000Looooo`03o`000?oooooooooo
06Kooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l0000>ooooo`?o00000oooool4o`00
01Oooooo0_l00005ooooo`;o00001Oooool4o`000003ooooool0003o000000kooooo0_l0001hoooo
o`007?ooool00ol0003oooooooooo`1Looooo`;o00002?ooool2o`0000Kooooo0_l00004ooooo`;o
00002?ooool2o`00017ooooo0_l00003ooooo`;o00000oooool2o`0000Oooooo0_l00006ooooo`;o
00000_ooool2o`000003ooooool0003o000000Gooooo0_l00003ooooo`;o00000oooool2o`0000Wo
oooo0_l0001hooooo`007?ooool00ol0003oooooooooo`1Looooo`;o00003_ooool5o`0000Sooooo
0_l00003ooooo`;o00000oooool2o`0000_ooooo0_l00004ooooo`Co000000?oooooo`000?l00000
1oooool4o`0000Gooooo0_l000001?oooooo0000o`000?l0000:ooooo`;o00001Oooool2o`0000Wo
oooo0ol0001gooooo`007?ooool00ol0003oooooooooo`1Xooooo`;o00000_ooool2o`000003oooo
ool0003o000000Oooooo0ol00008ooooo`?o00002_ooool2o`0000Kooooo0_l00005ooooo`;o0000
0oooool4o`0000Gooooo0_l00002ooooo`;o00002_ooool2o`0000Gooooo0ol00004ooooo`;o0000
0_ooool3o`0007Oooooo000Looooo`03o`000?oooooooooo06Sooooo0_l00005ooooo`;o00001ooo
ool2o`0000?ooooo1?l00003ooooo`;o00006Oooool4o`000003ooooool0003o000000_ooooo0_l0
000:ooooo`;o00001Oooool3o`0000?ooooo0ol0000=ooooo`;o00000oooool2o`0006Sooooo0000
1_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<
c<`01_ooool00ol0003oooooooooo`1Wooooo`;o00002Oooool2o`0000Wooooo1?l000000ooooooo
0000o`00000Dooooo`;o00001Oooool4o`0001[ooooo0_l00005ooooo`Go000000?oooooo`000?l0
00003_ooool2o`0000?ooooo0_l0001Xooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5oooo
o`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0GOooool2
o`0000Sooooo0_l00003ooooo`;o00001?ooool2o`0000kooooo0_l0000Booooo`Co00003oooool2
o`0000Oooooo0_l0000Aooooo`Co00004?ooool2o`0006kooooo00000ooooooo410@ooooo`02oooo
o`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo05gooooo0_l0000=ooooo`;o00004_ooool2o`0001Cooooo0_l0000Aooooo`;o00001Oooool4
o`0000Sooooo0_l00009ooooo`;o00004?ooool2o`0006kooooo00000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000NOooool2
o`0000Gooooo0_l00008ooooo`;o00001Oooool2o`0001gooooo0ol00002ooooo`?o00001?ooool4
o`0000_ooooo0_l0001looooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09oooo
o`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`1iooooo`;o00002_ooool2
o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0001kooooo0ol00004
ooooo`Co00000_ooool2o`0000?ooooo0_l00002ooooo`;o0000O?ooool00003ooooool@413ooooo
00;ooooo00?o410@ooooooooool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000
ooooooooool0QOooool2o`0000Oooooo0_l00005ooooo`;o00004Oooool2o`000004ooooool0003o
0000ooooo`;o000000?oooooo`000?l000003oooool2o`0000?ooooo0_l00020ooooo`0000Kooooo
ogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003o
ooooooooo`1`ooooo`?o00002Oooool2o`0001Cooooo0ol0000Cooooo`;o000000Coooooo`000?l0
003ooooo0_l000000ooooooo0000o`00002Fooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;
ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`1]ooooo`;o000000Co
ooooo`000?l0003o00002Oooool2o`0000Sooooo0_l00007ooooo`;o000000Coooooo`000?l0003o
00005oooool2o`0000?ooooo0_l00009ooooo`;o0000Roooool001cooooo00?o0000ooooooooool0
KOooool2o`0000Oooooo0_l00002ooooo`;o00001_ooool2o`0000;ooooo0_l00007ooooo`;o0000
4Oooool2o`0000Sooooo0_l0000=ooooo`?o0000Roooool001cooooo00?o0000ooooooooool0K?oo
ool2o`0000Sooooo0_l00002ooooo`;o00001_ooool2o`0001kooooo0_l00009ooooo`;o00003?oo
ool2o`0000Sooooo0_l00022ooooo`007?ooool00ol0003oooooooooo`1/ooooo`;o00007Oooool2
o`0000Sooooo0_l00009ooooo`;o00002oooool2o`0001Cooooo1Ol00021ooooo`007?ooool00ol0
003oooooooooo`1jooooo`Co00003Oooool2o`0000Cooooo0_l00002ooooo`;o00001?ooool2o`00
00?ooooo0_l0000Qooooo`;o000000?oooooo`000?l00000POooool001cooooo00?o0000oooooooo
ool0N_ooool5o`0001;ooooo0_l00008ooooo`;o00006?ooool2o`0009;ooooo000Looooo`03o`00
0?oooooooooo07gooooo0_l00008ooooo`;o00000oooool2o`0001;ooooo0_l000000ooooooo0000
o`00000@ooooo`;o00001Oooool2o`0008_ooooo000Looooo`03o`000?oooooooooo06oooooo0_l0
000Fooooo`;o00000oooool2o`00013ooooo1?l000000ooooooo0000o`00000<ooooo`;o00002Ooo
ool2o`0008_ooooo000Looooo`03o`000?oooooooooo06oooooo0_l0000]ooooo`;o00004Oooool2
o`0009Kooooo000Looooo`03o`000?oooooooooo08;ooooo0_l0000kooooo`;o0000R?ooool001co
oooo00?o0000ooooooooool0P_ooool2o`0003Gooooo0_l00003ooooo`?o0000R?ooool001cooooo
00?o0000ooooooooool0^Oooool2o`0000?ooooo0_l00002ooooo`;o0000QOooool001cooooo0_l0
001fooooo`;o0000Boooool2o`0000gooooo0_l0001fooooo`007?ooool00ol0003oooooooooo`1e
ooooo`;o0000>Oooool2o`0001oooooo0_l0001fooooo`007?ooool00ol0003oooooooooo`1noooo
o`;o0000<?ooool2o`0009Oooooo000Looooo`03o`000?oooooooooo07Sooooo0_l00004ooooo`;o
0000<_ooool2o`0009Gooooo000Looooo`03o`000?oooooooooo07Sooooo0_l0000hooooo`;o0000
UOooool001cooooo00?o0000ooooooooool0UOooool2o`0001oooooo0_l0002Aooooo`007?ooool0
0ol0003oooooooooo`25ooooo`;o00003_ooool2o`0001Gooooo0_l00008ooooo`;o0000TOooool0
01cooooo00?o0000ooooooooool0QOooool2o`0001Wooooo0_l0000:ooooo`;o0000Voooool001co
oooo00?o0000ooooooooool0X?ooool2o`000:Oooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo08?ooooo0_l0000>ooooo`;o0000]?ooool001co
oooo00?o0000ooooooooool0Poooool2o`0000kooooo0_l0002dooooo`007?ooool00ol0003ooooo
ooooo`2looooo`;o0000Roooool001cooooo00?o0000ooooooooool0_?ooool2o`0008_ooooo000L
ooooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`004_ooool4o`000003oa0@4?oooooo
oooo00?ooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool3o`000?oo
ooooB_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003ooooooooo
o`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000oooo
ooooool0oooooomBooooo`004_ooool00omEEEGoIVIVo`00003ooooooeCooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo002Qooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@
ooooooooool05_ooool4o`000003oa0@4?oooooooooo00Go00000oooool01Oo^k^ko<S8bo`000?l@
413oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP2<ooooo`00X_ooool01Ol0003ooooooooo
oooooooo000000Wooooo1_l0000<ooooo`03o`000?oooooooooo00;ooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A003ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonHV9So
MgMg08cooooo002Rooooo`05o`000?ooooooooooooooool000006oooool00ol0003oooooooooo`03
ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go0000ooooooooooooooooo`000003ooooo`05oa0@4?oo
ooooooooooooool@4100S?ooool00:;ooooo00Go0000ooooooooooooooooo`000009ooooo`Ko0000
3?ooool00ol0003oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@03ooooo`05o`000?ooooooooooooooool00000S?ooool00:;ooooo00Go0000ohN7Qooo
ooooZJVYo`00000Kooooo`03o`000?oooooooooo00Gooooo00?oMgMgofIVI_ooool00_ooool01Ol0
003oEEEEo`000?l@413oc<c<00?ooooo00Go0000ooooooooooooooooo`00002<ooooo`00XOooool0
0ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo01Wooooo00?o0000ooooooooool01_ooool0
1_l0003oooooooooooooooooEEEEohN7Q`Kooooo00Go410@oooooooooooooooooa0@402<ooooo`00
`_ooool00ol0003oooooooooo`02ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool00ooMgMgo
410@oiRHV005ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0S?ooool00<3ooooo00?oEEEEofIVI_l0
00001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo00Coc<c<odA4A?l0003o410@0oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^08cooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1266) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.5641 .66143 Mdot
.59645 .66672 Mdot
.51131 .37473 Mdot
.39953 .56946 Mdot
.60783 .22076 Mdot
.52571 .34682 Mdot
.66906 .44231 Mdot
.68309 .48845 Mdot
.4961 .3568 Mdot
.76117 .49842 Mdot
.69074 .46211 Mdot
.51366 .61063 Mdot
.66711 .47958 Mdot
.43039 .57528 Mdot
.58233 .15252 Mdot
.46163 .54942 Mdot
.57858 .66821 Mdot
.38302 .42304 Mdot
.37647 .56131 Mdot
.51369 .39271 Mdot
.54844 .61116 Mdot
.42301 .57933 Mdot
.62438 .63266 Mdot
.43117 .57525 Mdot
.38612 .59383 Mdot
.58842 .62263 Mdot
.53756 .64311 Mdot
.40066 .61473 Mdot
.40612 .62999 Mdot
.68911 .4848 Mdot
.27447 .48091 Mdot
.57677 .17442 Mdot
.37341 .64705 Mdot
.32879 .25713 Mdot
.64772 .49 Mdot
.47878 .77069 Mdot
.5178 .35627 Mdot
.6631 .46214 Mdot
.66185 .45821 Mdot
.6323 .48181 Mdot
.67806 .46357 Mdot
.61223 .6318 Mdot
.65123 .54887 Mdot
.46703 .31034 Mdot
.4631 .56071 Mdot
.71673 .31923 Mdot
.55987 .80707 Mdot
.46239 .6028 Mdot
.56948 .65294 Mdot
.39274 .26849 Mdot
.63255 .30658 Mdot
.63766 .46193 Mdot
.50109 .39113 Mdot
.17389 .68424 Mdot
.64788 .47412 Mdot
.35121 .5776 Mdot
.51391 .36533 Mdot
.42945 .59069 Mdot
.43586 .57661 Mdot
.40835 .70456 Mdot
.46557 .57767 Mdot
.37601 .38337 Mdot
.63499 .68282 Mdot
.5943 .52141 Mdot
.50168 .35347 Mdot
.67605 .4529 Mdot
.60719 .65908 Mdot
.65871 .48281 Mdot
.4046 .51797 Mdot
.52912 .39635 Mdot
.46291 .60541 Mdot
.68526 .45815 Mdot
.59001 .68267 Mdot
.42814 .62314 Mdot
.40535 .34681 Mdot
.81437 .42109 Mdot
.32283 .41525 Mdot
.4648 .74946 Mdot
.3841 .70636 Mdot
.42864 .28275 Mdot
.37859 .57294 Mdot
.31676 .51065 Mdot
.78617 .38373 Mdot
.61744 .62074 Mdot
.49341 .59877 Mdot
.29684 .36554 Mdot
.42609 .62078 Mdot
.73738 .3128 Mdot
.45138 .62952 Mdot
.32632 .33226 Mdot
.49097 .34499 Mdot
.58734 .64902 Mdot
.39734 .56884 Mdot
.43047 .62842 Mdot
.31636 .68054 Mdot
.36109 .61916 Mdot
.40911 .59289 Mdot
.56229 .63544 Mdot
.63805 .46443 Mdot
.3571 .62721 Mdot
.47799 .30216 Mdot
.486 .3338 Mdot
.4224 .54626 Mdot
.53004 .32269 Mdot
.62914 .6792 Mdot
.43428 .6257 Mdot
.65444 .45974 Mdot
.43444 .55336 Mdot
.70852 .66664 Mdot
.59986 .67039 Mdot
.4035 .62151 Mdot
.33793 .38004 Mdot
.29977 .72012 Mdot
.57974 .65309 Mdot
.51134 .27965 Mdot
.36931 .60405 Mdot
.41679 .59967 Mdot
.59539 .66349 Mdot
.52522 .31238 Mdot
.7519 .32655 Mdot
.57564 .61446 Mdot
.64994 .4987 Mdot
.56491 .66681 Mdot
.46622 .53914 Mdot
.50225 .33922 Mdot
.5662 .266 Mdot
.6874 .61698 Mdot
.28955 .45539 Mdot
.42806 .6178 Mdot
.71861 .54353 Mdot
.48042 .35084 Mdot
.59816 .64669 Mdot
.66464 .485 Mdot
.48686 .62687 Mdot
.62313 .66454 Mdot
.69663 .46919 Mdot
.34776 .37201 Mdot
.6456 .36282 Mdot
.63014 .67059 Mdot
.43967 .43231 Mdot
.69897 .44887 Mdot
.63194 .4682 Mdot
.25294 .319 Mdot
.60543 .65632 Mdot
.36163 .38448 Mdot
.66995 .48902 Mdot
.27038 .44285 Mdot
.45908 .55951 Mdot
.28649 .53719 Mdot
.56116 .82092 Mdot
.30944 .27011 Mdot
.6726 .37488 Mdot
.35607 .41096 Mdot
.69056 .49262 Mdot
.39418 .58969 Mdot
.57664 .62545 Mdot
.60634 .62441 Mdot
.4607 .57188 Mdot
.38384 .57874 Mdot
.46119 .6127 Mdot
.44119 .62852 Mdot
.52284 .67353 Mdot
.36221 .59816 Mdot
.47954 .81586 Mdot
.58352 .64635 Mdot
.39687 .57815 Mdot
.54759 .35683 Mdot
.40563 .64933 Mdot
.68138 .46037 Mdot
.42326 .58747 Mdot
.39737 .57103 Mdot
.45894 .56522 Mdot
.63576 .46558 Mdot
.63257 .19172 Mdot
.34008 .74034 Mdot
.58985 .1938 Mdot
.37003 .34278 Mdot
.53998 .33878 Mdot
.41789 .61509 Mdot
.35696 .3751 Mdot
.5366 .75622 Mdot
.41415 .55975 Mdot
.55035 .87144 Mdot
.41248 .58659 Mdot
.61166 .21293 Mdot
.35217 .5606 Mdot
.4995 .1784 Mdot
.30609 .50717 Mdot
.39378 .60151 Mdot
.59409 .54797 Mdot
.60404 .47643 Mdot
.55778 .32268 Mdot
.67592 .46673 Mdot
.54612 .36187 Mdot
.51431 .37265 Mdot
.63044 .5347 Mdot
.51365 .62695 Mdot
.34099 .62053 Mdot
.43309 .63853 Mdot
.53447 .39772 Mdot
.64352 .67054 Mdot
.37048 .36759 Mdot
.5521 .63425 Mdot
.79645 .30935 Mdot
.66313 .29624 Mdot
.69022 .4368 Mdot
.38612 .39484 Mdot
.49006 .36247 Mdot
.49994 .32532 Mdot
.33474 .39556 Mdot
.44952 .59811 Mdot
.61018 .65209 Mdot
.29206 .26408 Mdot
.73928 .64881 Mdot
.23202 .32295 Mdot
.56353 .63821 Mdot
.75726 .54163 Mdot
.69208 .4753 Mdot
.53057 .36399 Mdot
.41414 .59805 Mdot
.44361 .60166 Mdot
.58417 .60339 Mdot
.45921 .61347 Mdot
.53477 .5893 Mdot
.40597 .6018 Mdot
.6136 .32885 Mdot
.33586 .43041 Mdot
.62905 .53354 Mdot
.30188 .43931 Mdot
.60201 .6177 Mdot
.23632 .5837 Mdot
.52185 .32028 Mdot
.52482 .75281 Mdot
.68332 .4514 Mdot
.36283 .37061 Mdot
.50911 .3263 Mdot
.35514 .3648 Mdot
.36383 .58019 Mdot
.5414 .37824 Mdot
.33475 .4056 Mdot
.34758 .66599 Mdot
.47933 .59421 Mdot
.68077 .70297 Mdot
.63948 .48939 Mdot
.5528 .62076 Mdot
.47007 .58673 Mdot
.54225 .3356 Mdot
.45251 .64632 Mdot
.73553 .40466 Mdot
.58655 .29547 Mdot
.48407 .33069 Mdot
.58332 .30681 Mdot
.37819 .38211 Mdot
.71224 .35639 Mdot
.74058 .5493 Mdot
.57289 .66476 Mdot
.36169 .61632 Mdot
.47546 .17268 Mdot
.66893 .48903 Mdot
.44314 .5619 Mdot
.40437 .23005 Mdot
.65091 .48545 Mdot
.43041 .59275 Mdot
.69095 .48753 Mdot
.60856 .6252 Mdot
.29967 .69447 Mdot
.57377 .66246 Mdot
.43807 .63347 Mdot
.64899 .46269 Mdot
.55172 .34159 Mdot
.58489 .62622 Mdot
.45421 .59379 Mdot
.40538 .61489 Mdot
.58126 .45903 Mdot
.40125 .58268 Mdot
.63159 .20088 Mdot
.39956 .60214 Mdot
.5277 .37488 Mdot
.40648 .54333 Mdot
.25648 .72528 Mdot
.6701 .53382 Mdot
.60775 .65748 Mdot
.51888 .30922 Mdot
.50216 .36229 Mdot
.46542 .30595 Mdot
.64074 .43675 Mdot
.36674 .59283 Mdot
.53979 .3356 Mdot
.26407 .5954 Mdot
.69716 .45278 Mdot
.37066 .64029 Mdot
.45257 .44589 Mdot
.37634 .28085 Mdot
.49942 .38947 Mdot
.38865 .65952 Mdot
.63277 .67146 Mdot
.39358 .5699 Mdot
.5072 .31893 Mdot
.4963 .64869 Mdot
.38018 .6123 Mdot
.62393 .60473 Mdot
.58321 .45744 Mdot
.68324 .44252 Mdot
.34499 .5751 Mdot
.45131 .57078 Mdot
.54355 .35886 Mdot
.59104 .61737 Mdot
.69976 .45437 Mdot
.60239 .6277 Mdot
.45258 .19149 Mdot
.6868 .68566 Mdot
.37547 .67965 Mdot
.38964 .39126 Mdot
.36734 .26682 Mdot
.46813 .18153 Mdot
.20347 .56854 Mdot
.23327 .541 Mdot
.35815 .21959 Mdot
.53276 .317 Mdot
.40389 .23706 Mdot
.50831 .36642 Mdot
.37831 .59169 Mdot
.50242 .34168 Mdot
.46084 .17735 Mdot
.4062 .59998 Mdot
.50877 .3444 Mdot
.2502 .61771 Mdot
.3919 .57536 Mdot
.58343 .66685 Mdot
.72194 .25997 Mdot
.21499 .63877 Mdot
.59444 .30664 Mdot
.51901 .38848 Mdot
.23104 .48586 Mdot
.40679 .59208 Mdot
.3998 .54723 Mdot
.57243 .63914 Mdot
.392 .65644 Mdot
.37698 .40163 Mdot
.38484 .40067 Mdot
.6642 .41637 Mdot
.33938 .51188 Mdot
.35064 .56706 Mdot
.58084 .62878 Mdot
.54885 .68976 Mdot
.38102 .33242 Mdot
.39688 .26161 Mdot
.7132 .4613 Mdot
.71651 .25764 Mdot
.51991 .5788 Mdot
.67976 .51029 Mdot
.56582 .3231 Mdot
.58458 .66049 Mdot
.615 .18356 Mdot
.67101 .46719 Mdot
.67684 .73531 Mdot
.46329 .4881 Mdot
.44766 .59553 Mdot
.67884 .44593 Mdot
.48518 .6415 Mdot
.20292 .62144 Mdot
.7208 .71794 Mdot
.40212 .48409 Mdot
.44996 .63185 Mdot
.4132 .36021 Mdot
.42024 .59231 Mdot
.76478 .38422 Mdot
.39889 .60582 Mdot
.59733 .62883 Mdot
.75885 .47829 Mdot
.62246 .43391 Mdot
.38051 .78348 Mdot
.73317 .37146 Mdot
.35711 .41139 Mdot
.4111 .60275 Mdot
.44818 .59311 Mdot
.37197 .40607 Mdot
.63521 .64482 Mdot
.448 .62757 Mdot
.22868 .56796 Mdot
.44088 .62139 Mdot
.67318 .46071 Mdot
.45411 .49935 Mdot
.66577 .66679 Mdot
.40716 .63754 Mdot
.61473 .68763 Mdot
.67526 .43865 Mdot
.64969 .4668 Mdot
.36232 .55001 Mdot
.63119 .48417 Mdot
.41203 .5792 Mdot
.73997 .70902 Mdot
.62429 .67535 Mdot
.58334 .57734 Mdot
.62297 .64864 Mdot
.44839 .74603 Mdot
.64203 .47868 Mdot
.62606 .32109 Mdot
.50386 .6176 Mdot
.66989 .47046 Mdot
.66058 .70125 Mdot
.44962 .54313 Mdot
.4842 .59866 Mdot
.25531 .35089 Mdot
.51539 .38411 Mdot
.58758 .46881 Mdot
.68665 .48755 Mdot
.45643 .58422 Mdot
.37612 .62645 Mdot
.66762 .43922 Mdot
.74064 .68208 Mdot
.2365 .63837 Mdot
.40262 .60152 Mdot
.59278 .63482 Mdot
.60081 .64408 Mdot
.47456 .61757 Mdot
.40619 .55125 Mdot
.51192 .33276 Mdot
.55102 .33372 Mdot
.53933 .38622 Mdot
.58587 .45618 Mdot
.62031 .31935 Mdot
.62186 .25044 Mdot
.63194 .48117 Mdot
.735 .57848 Mdot
.31882 .33536 Mdot
.4112 .6419 Mdot
.49704 .37996 Mdot
.44387 .56672 Mdot
.40907 .5714 Mdot
.6691 .43577 Mdot
.50193 .22689 Mdot
.53379 .61063 Mdot
.63638 .63824 Mdot
.70645 .46211 Mdot
.46467 .53252 Mdot
.71826 .50313 Mdot
.34883 .37448 Mdot
.27887 .31301 Mdot
.6829 .4539 Mdot
.58498 .66609 Mdot
.65343 .49489 Mdot
.44368 .60843 Mdot
.37066 .5589 Mdot
.5912 .65918 Mdot
.36247 .4205 Mdot
.442 .64938 Mdot
.42866 .59551 Mdot
.52869 .83791 Mdot
.2688 .36072 Mdot
.61193 .34744 Mdot
.39567 .60068 Mdot
.39552 .63387 Mdot
.32646 .39765 Mdot
.44305 .61817 Mdot
.46856 .60578 Mdot
.31487 .72234 Mdot
.70023 .62189 Mdot
.38245 .41208 Mdot
.74818 .6903 Mdot
.56374 .643 Mdot
.52476 .17134 Mdot
.53726 .36261 Mdot
.71296 .43227 Mdot
.25382 .66817 Mdot
.50386 .39333 Mdot
.67569 .37905 Mdot
.55125 .17529 Mdot
.59031 .46376 Mdot
.53706 .40829 Mdot
.51876 .59769 Mdot
.44619 .62656 Mdot
.42096 .59919 Mdot
.36631 .37803 Mdot
.61232 .64739 Mdot
.57885 .47856 Mdot
.82689 .53788 Mdot
.42012 .58188 Mdot
.55177 .57873 Mdot
.79708 .55504 Mdot
.37769 .28395 Mdot
.34848 .39615 Mdot
.37555 .41523 Mdot
.41435 .60338 Mdot
.30966 .73427 Mdot
.58594 .623 Mdot
.45424 .59228 Mdot
.36414 .60699 Mdot
.52031 .38628 Mdot
.60695 .6744 Mdot
.51764 .31221 Mdot
.64791 .32125 Mdot
.59454 .20006 Mdot
.56435 .84157 Mdot
.64409 .47397 Mdot
.79028 .43386 Mdot
.69965 .47626 Mdot
.32362 .50104 Mdot
.47636 .34497 Mdot
.39785 .56177 Mdot
.59987 .61817 Mdot
.45278 .57802 Mdot
.40155 .55466 Mdot
.4497 .59574 Mdot
.39033 .63671 Mdot
.44865 .86379 Mdot
.34277 .41104 Mdot
.46826 .54585 Mdot
.52238 .37702 Mdot
.76154 .34961 Mdot
.80963 .42362 Mdot
.44616 .58863 Mdot
.40711 .61059 Mdot
.6285 .66628 Mdot
.45649 .56905 Mdot
.70092 .46729 Mdot
.56105 .6202 Mdot
.42365 .62792 Mdot
.73771 .28436 Mdot
.40396 .62675 Mdot
.53609 .18337 Mdot
.66361 .49556 Mdot
.71504 .66715 Mdot
.45313 .53455 Mdot
.59457 .31248 Mdot
.58749 .46894 Mdot
.50981 .32902 Mdot
.6426 .49986 Mdot
.51531 .35461 Mdot
.82408 .57219 Mdot
.37572 .54887 Mdot
.39158 .59 Mdot
.37712 .63657 Mdot
.5414 .34007 Mdot
.71545 .29268 Mdot
.70407 .33875 Mdot
.47647 .54743 Mdot
.53549 .3392 Mdot
.62938 .68411 Mdot
.26238 .40767 Mdot
.62246 .6405 Mdot
.38211 .36953 Mdot
.68944 .46699 Mdot
.36961 .41585 Mdot
.3931 .22719 Mdot
.59683 .66885 Mdot
.54731 .61959 Mdot
.53459 .35861 Mdot
.47705 .48502 Mdot
.13164 .49751 Mdot
.46908 .48901 Mdot
.30275 .48304 Mdot
.57622 .63708 Mdot
.40727 .63276 Mdot
.35685 .47642 Mdot
.51257 .50722 Mdot
.51257 .35417 Mdot
.41733 .56397 Mdot
.29205 .68905 Mdot
.51198 .33256 Mdot
.36542 .63126 Mdot
.51828 .38094 Mdot
.68271 .46764 Mdot
.49182 .37166 Mdot
.6173 .61196 Mdot
.41685 .62223 Mdot
.14146 .43774 Mdot
.33713 .43517 Mdot
.40218 .59305 Mdot
.70789 .46289 Mdot
.67179 .40322 Mdot
.42051 .55286 Mdot
.337 .37567 Mdot
.51757 .33953 Mdot
.44462 .47582 Mdot
.40109 .60329 Mdot
.54128 .34334 Mdot
.56356 .66174 Mdot
.66684 .50225 Mdot
.34588 .69417 Mdot
.60015 .33525 Mdot
.5712 .63914 Mdot
.43562 .40375 Mdot
.62507 .48421 Mdot
.39526 .63427 Mdot
.36311 .61875 Mdot
.59667 .63691 Mdot
.29514 .61496 Mdot
.42615 .54294 Mdot
.37998 .57165 Mdot
.5311 .37695 Mdot
.51543 .35012 Mdot
.29187 .65277 Mdot
.54114 .32081 Mdot
.37242 .55652 Mdot
.59849 .63555 Mdot
.39982 .56661 Mdot
.62074 .67449 Mdot
.45325 .56648 Mdot
.52 .64617 Mdot
.63442 .64253 Mdot
.67664 .52622 Mdot
.41272 .56625 Mdot
.34871 .6307 Mdot
.43478 .55517 Mdot
.45052 .62115 Mdot
.50472 .33402 Mdot
.34453 .38705 Mdot
.35525 .60266 Mdot
.33393 .36745 Mdot
.35694 .36509 Mdot
.61033 .45884 Mdot
.51752 .38606 Mdot
.36738 .39211 Mdot
.80276 .55713 Mdot
.53594 .38661 Mdot
.37526 .38784 Mdot
.80748 .42035 Mdot
.64448 .48742 Mdot
.62873 .67486 Mdot
.3899 .57604 Mdot
.40122 .21319 Mdot
.55937 .80927 Mdot
.56121 .34137 Mdot
.39992 .59986 Mdot
.43677 .5593 Mdot
.59376 .6142 Mdot
.8371 .5822 Mdot
.53025 .39557 Mdot
.38701 .61849 Mdot
.60718 .66413 Mdot
.82865 .63269 Mdot
.52299 .3723 Mdot
.37353 .38373 Mdot
.63464 .47955 Mdot
.63318 .61391 Mdot
.68667 .61803 Mdot
.67657 .44165 Mdot
.57691 .36215 Mdot
.6293 .30914 Mdot
.36897 .60485 Mdot
.49145 .3754 Mdot
.23709 .34125 Mdot
.5928 .70735 Mdot
.61348 .52231 Mdot
.23072 .47336 Mdot
.58346 .65773 Mdot
.70031 .47211 Mdot
.35067 .41203 Mdot
.56486 .63387 Mdot
.58386 .66953 Mdot
.65141 .44179 Mdot
.35879 .73543 Mdot
.45216 .4476 Mdot
.66688 .45835 Mdot
.28634 .33798 Mdot
.55912 .24101 Mdot
.49822 .38157 Mdot
.37672 .40117 Mdot
.41381 .21941 Mdot
.61056 .63029 Mdot
.70853 .24762 Mdot
.25638 .33267 Mdot
.40913 .59268 Mdot
.36311 .39158 Mdot
.68611 .27395 Mdot
.84239 .51527 Mdot
.64823 .48272 Mdot
.62413 .42754 Mdot
.38038 .39988 Mdot
.46823 .58374 Mdot
.26345 .42464 Mdot
.38105 .57277 Mdot
.69078 .47191 Mdot
.39257 .69815 Mdot
.58729 .66916 Mdot
.63354 .45101 Mdot
.27639 .31329 Mdot
.41392 .57857 Mdot
.41287 .56461 Mdot
.31303 .43886 Mdot
.57296 .6197 Mdot
.5105 .32877 Mdot
.36666 .60493 Mdot
.42633 .59248 Mdot
.35498 .58057 Mdot
.34175 .58808 Mdot
.29581 .70938 Mdot
.38303 .60247 Mdot
.70345 .32416 Mdot
.44655 .63497 Mdot
.42088 .56911 Mdot
.61841 .6865 Mdot
.55623 .84977 Mdot
.65721 .31806 Mdot
.42381 .5896 Mdot
.39869 .63029 Mdot
.62986 .45613 Mdot
.47838 .47107 Mdot
.46988 .478 Mdot
.43988 .47255 Mdot
.23253 .51474 Mdot
.47421 .62285 Mdot
.61324 .65629 Mdot
.33226 .40124 Mdot
.3791 .61456 Mdot
.61218 .65961 Mdot
.45451 .5574 Mdot
.51496 .33215 Mdot
.53815 .38464 Mdot
.58606 .69994 Mdot
.36785 .39826 Mdot
.51586 .54483 Mdot
.72622 .58045 Mdot
.54433 .36764 Mdot
.38927 .59035 Mdot
.69063 .43404 Mdot
.50553 .3203 Mdot
.56757 .28892 Mdot
.32366 .64214 Mdot
.58105 .62111 Mdot
.58449 .64882 Mdot
.28563 .54335 Mdot
.66959 .36475 Mdot
.42932 .82157 Mdot
.68423 .46756 Mdot
.39536 .54074 Mdot
.73634 .53711 Mdot
.5818 .65036 Mdot
.34307 .48249 Mdot
.36552 .3943 Mdot
.65131 .48666 Mdot
.50432 .41917 Mdot
.62666 .66382 Mdot
.58476 .67328 Mdot
.46169 .62345 Mdot
.43624 .59537 Mdot
.23562 .55288 Mdot
.39186 .36563 Mdot
.68137 .44074 Mdot
.37822 .39774 Mdot
.47676 .34694 Mdot
.38309 .60811 Mdot
.6256 .63244 Mdot
.55376 .24669 Mdot
.38499 .61992 Mdot
.49604 .33618 Mdot
.58639 .65509 Mdot
.3798 .38477 Mdot
.33738 .37279 Mdot
.44727 .62209 Mdot
.50261 .68169 Mdot
.66128 .46613 Mdot
.58092 .66247 Mdot
.70915 .50932 Mdot
.40093 .54827 Mdot
.43304 .60304 Mdot
.34887 .5512 Mdot
.68481 .4407 Mdot
.76789 .58368 Mdot
.38182 .37378 Mdot
.60775 .64907 Mdot
.39052 .6077 Mdot
.37472 .39668 Mdot
.75804 .562 Mdot
.48191 .33335 Mdot
.49124 .36917 Mdot
.33357 .3778 Mdot
.35488 .39451 Mdot
.34396 .37118 Mdot
.70905 .24728 Mdot
.61686 .61788 Mdot
.52003 .58125 Mdot
.41066 .53881 Mdot
.30355 .50133 Mdot
.50026 .61157 Mdot
.70034 .45191 Mdot
.51223 .38209 Mdot
.41751 .54996 Mdot
.42524 .63447 Mdot
.38996 .5267 Mdot
.57357 .58247 Mdot
.66577 .67743 Mdot
.60164 .67219 Mdot
.3964 .53487 Mdot
.52745 .38435 Mdot
.80549 .31428 Mdot
.32607 .21312 Mdot
.44249 .5306 Mdot
.4393 .44876 Mdot
.62517 .63034 Mdot
.62763 .46791 Mdot
.31459 .42784 Mdot
.64186 .48721 Mdot
.60405 .64982 Mdot
.38271 .60401 Mdot
.73335 .58694 Mdot
.32786 .38621 Mdot
.46055 .5957 Mdot
.68804 .48069 Mdot
.46393 .60087 Mdot
.67425 .4416 Mdot
.46556 .18888 Mdot
.21729 .41867 Mdot
.41231 .58773 Mdot
.48346 .57298 Mdot
.22173 .48668 Mdot
.44685 .58456 Mdot
.40162 .38227 Mdot
.62607 .63092 Mdot
.31047 .67411 Mdot
.47636 .57367 Mdot
.56355 .71906 Mdot
.39179 .55479 Mdot
.27092 .64979 Mdot
.43603 .60306 Mdot
.37055 .29348 Mdot
.40774 .62206 Mdot
.46261 .615 Mdot
.64442 .46809 Mdot
.6326 .4527 Mdot
.59053 .68375 Mdot
.53836 .33181 Mdot
.56315 .18525 Mdot
.42996 .59863 Mdot
.58226 .28721 Mdot
.72906 .61683 Mdot
.35321 .39583 Mdot
.6072 .64611 Mdot
.8523 .5592 Mdot
.67734 .49466 Mdot
.24983 .37939 Mdot
.27598 .6342 Mdot
.66243 .57256 Mdot
.29451 .37142 Mdot
.76518 .45868 Mdot
.37615 .37778 Mdot
.45635 .56267 Mdot
.52865 .23678 Mdot
.36125 .30718 Mdot
.32495 .64714 Mdot
.62227 .48286 Mdot
.54163 .74262 Mdot
.51649 .22797 Mdot
.36133 .35982 Mdot
.37987 .40635 Mdot
.64112 .45598 Mdot
.48252 .40784 Mdot
.51543 .62285 Mdot
.36271 .39678 Mdot
.55001 .35635 Mdot
.52662 .39253 Mdot
.5108 .39826 Mdot
.59424 .62193 Mdot
.27341 .29421 Mdot
.73462 .48718 Mdot
.68173 .44321 Mdot
.47009 .38648 Mdot
.62703 .69786 Mdot
.59996 .61065 Mdot
.52709 .3587 Mdot
.48718 .34303 Mdot
.63781 .64621 Mdot
.35493 .56591 Mdot
.39988 .52698 Mdot
.42107 .58559 Mdot
.35144 .37728 Mdot
.43997 .59955 Mdot
.52908 .33718 Mdot
.65041 .48092 Mdot
.48737 .35182 Mdot
.70647 .47435 Mdot
.64217 .26359 Mdot
.45467 .60307 Mdot
.41246 .62132 Mdot
.59286 .80464 Mdot
.57114 .66972 Mdot
.68824 .30416 Mdot
.59979 .36199 Mdot
.51068 .36928 Mdot
.46977 .60194 Mdot
.56071 .6195 Mdot
.3554 .35653 Mdot
.61681 .79907 Mdot
.41355 .54702 Mdot
.62648 .63806 Mdot
.38783 .6107 Mdot
.50492 .67123 Mdot
.29778 .75736 Mdot
.60589 .63234 Mdot
.5598 .82013 Mdot
.40278 .62984 Mdot
.79216 .48582 Mdot
.37957 .64339 Mdot
.27109 .58102 Mdot
.42573 .54292 Mdot
.56316 .64074 Mdot
.42502 .58494 Mdot
.55716 .6237 Mdot
.54248 .36585 Mdot
.6289 .47 Mdot
.57447 .6435 Mdot
.36615 .62649 Mdot
.15983 .32057 Mdot
.68586 .47567 Mdot
.41311 .6005 Mdot
.63729 .47368 Mdot
.61586 .6473 Mdot
.57116 .65253 Mdot
.83248 .49815 Mdot
.6539 .32465 Mdot
.68151 .4684 Mdot
.38462 .60918 Mdot
.75846 .42557 Mdot
.38843 .56942 Mdot
.25174 .55082 Mdot
.34985 .58279 Mdot
.40869 .54142 Mdot
.81596 .42903 Mdot
.68655 .44285 Mdot
.40888 .81583 Mdot
.83671 .47773 Mdot
.76563 .35412 Mdot
.56539 .60521 Mdot
.35974 .35878 Mdot
.62312 .18674 Mdot
.62356 .32174 Mdot
.53862 .34044 Mdot
.42591 .55137 Mdot
.65635 .6805 Mdot
.65704 .46442 Mdot
.34179 .3876 Mdot
.41248 .5888 Mdot
.4848 .34896 Mdot
.21633 .60285 Mdot
.69654 .48821 Mdot
.6137 .63417 Mdot
.63403 .63264 Mdot
.73975 .73399 Mdot
.39344 .60347 Mdot
.41903 .62456 Mdot
.6904 .46856 Mdot
.78669 .55659 Mdot
.37052 .37088 Mdot
.2424 .6088 Mdot
.68102 .46988 Mdot
.55076 .47541 Mdot
.60347 .66232 Mdot
.43929 .56117 Mdot
.68483 .25533 Mdot
.41937 .3544 Mdot
.63992 .75449 Mdot
.35697 .37551 Mdot
.25105 .54167 Mdot
.56347 .64384 Mdot
.66733 .48684 Mdot
.63845 .37848 Mdot
.45716 .63557 Mdot
.44148 .56664 Mdot
.25522 .53906 Mdot
.61782 .44195 Mdot
.41154 .48481 Mdot
.40731 .54801 Mdot
.59216 .47747 Mdot
.42996 .5471 Mdot
.48265 .62159 Mdot
.3631 .56158 Mdot
.42995 .61273 Mdot
.62655 .63482 Mdot
.38368 .51789 Mdot
.52401 .3301 Mdot
.50372 .54744 Mdot
.55502 .48421 Mdot
.40294 .59679 Mdot
.37334 .5873 Mdot
.59494 .76858 Mdot
.69016 .39231 Mdot
.57761 .64463 Mdot
.56102 .60979 Mdot
.63632 .49118 Mdot
.39612 .52656 Mdot
.53129 .32642 Mdot
.48799 .62164 Mdot
.49979 .33595 Mdot
.62296 .63114 Mdot
.5155 .37115 Mdot
.63275 .47445 Mdot
.51203 .38954 Mdot
.61984 .3186 Mdot
.67183 .4904 Mdot
.57438 .6258 Mdot
.43103 .62316 Mdot
.70781 .46403 Mdot
.28902 .44227 Mdot
.35339 .37692 Mdot
.84509 .45512 Mdot
.42199 .62843 Mdot
.697 .62574 Mdot
.45259 .66471 Mdot
.48707 .34712 Mdot
.31494 .76358 Mdot
.63508 .63716 Mdot
.37399 .41966 Mdot
.60475 .61754 Mdot
.26211 .35626 Mdot
.35092 .38653 Mdot
.80674 .40065 Mdot
.5863 .38197 Mdot
.26803 .37297 Mdot
.37188 .54349 Mdot
.28597 .40759 Mdot
.49128 .38169 Mdot
.65538 .46553 Mdot
.6524 .37889 Mdot
.46699 .60724 Mdot
.19483 .513 Mdot
.63927 .67045 Mdot
.53645 .33159 Mdot
.66193 .48322 Mdot
.70138 .45594 Mdot
.37451 .57045 Mdot
.43605 .2594 Mdot
.45486 .57472 Mdot
.66541 .35301 Mdot
.23708 .51859 Mdot
.57556 .59511 Mdot
.4066 .60166 Mdot
.54347 .36037 Mdot
.38768 .61054 Mdot
.38753 .41057 Mdot
.25834 .30118 Mdot
.41714 .65551 Mdot
.60242 .36204 Mdot
.33089 .43206 Mdot
.5922 .66306 Mdot
.40847 .66962 Mdot
.62201 .33473 Mdot
.39061 .60348 Mdot
.34912 .84012 Mdot
.37544 .39176 Mdot
.52171 .23836 Mdot
.38107 .63099 Mdot
.3664 .58698 Mdot
.59907 .53612 Mdot
.67054 .60351 Mdot
.41947 .36061 Mdot
.44201 .57722 Mdot
.25569 .4817 Mdot
.65803 .44737 Mdot
.44898 .56441 Mdot
.41909 .60045 Mdot
.40737 .76582 Mdot
.70432 .46495 Mdot
.50326 .36747 Mdot
.49106 .3836 Mdot
.55404 .33053 Mdot
.38311 .41747 Mdot
.60027 .43405 Mdot
.32798 .48338 Mdot
.208 .61464 Mdot
.3509 .42408 Mdot
.43341 .63022 Mdot
.39807 .43052 Mdot
.37767 .59685 Mdot
.34498 .40226 Mdot
.70405 .46971 Mdot
.57575 .64746 Mdot
.75174 .53226 Mdot
.52334 .39656 Mdot
.37508 .64517 Mdot
.37838 .37515 Mdot
.57793 .62416 Mdot
.29339 .35702 Mdot
.59891 .66035 Mdot
.67381 .47312 Mdot
.71329 .47434 Mdot
.34048 .39325 Mdot
.62002 .64909 Mdot
.64126 .51272 Mdot
.83739 .53004 Mdot
.36408 .56545 Mdot
.71795 .42685 Mdot
.55931 .64919 Mdot
.57415 .60626 Mdot
.55866 .6321 Mdot
.45968 .61091 Mdot
.43982 .44809 Mdot
.45574 .55252 Mdot
.68334 .44215 Mdot
.51445 .37931 Mdot
.21516 .511 Mdot
.6146 .2727 Mdot
.42509 .41019 Mdot
.39462 .53919 Mdot
.41575 .57719 Mdot
.41451 .60312 Mdot
.48064 .58084 Mdot
.64135 .35335 Mdot
.45072 .57439 Mdot
.64435 .46612 Mdot
.51852 .33766 Mdot
.45709 .56302 Mdot
.47517 .36808 Mdot
.75399 .34895 Mdot
.34943 .42218 Mdot
.6116 .42613 Mdot
.3493 .17906 Mdot
.57419 .6296 Mdot
.51359 .31052 Mdot
.5403 .3449 Mdot
.34923 .37152 Mdot
.6653 .4622 Mdot
.6028 .65888 Mdot
.25908 .58047 Mdot
.35157 .36716 Mdot
.4255 .58784 Mdot
.41603 .45741 Mdot
.19673 .47392 Mdot
.45325 .5609 Mdot
.41048 .55625 Mdot
.47262 .34628 Mdot
.49902 .24412 Mdot
.16989 .40434 Mdot
.34266 .4646 Mdot
.3424 .38994 Mdot
.34947 .41689 Mdot
.6356 .66237 Mdot
.45574 .5476 Mdot
.68178 .44145 Mdot
.43301 .49334 Mdot
.62298 .40956 Mdot
.49128 .51893 Mdot
.66454 .63279 Mdot
.42123 .54747 Mdot
.75825 .662 Mdot
.41155 .57715 Mdot
.61273 .61669 Mdot
.61522 .62827 Mdot
.58394 .63238 Mdot
.65614 .46653 Mdot
.48491 .75875 Mdot
.65005 .46024 Mdot
.33387 .18628 Mdot
.56659 .65307 Mdot
.58756 .3993 Mdot
.53516 .36709 Mdot
.44615 .53058 Mdot
.37947 .38879 Mdot
.67428 .50644 Mdot
.40532 .51787 Mdot
.31319 .74523 Mdot
.53284 .33141 Mdot
.57171 .6288 Mdot
.76737 .4657 Mdot
.39979 .18214 Mdot
.45477 .47259 Mdot
.46651 .53265 Mdot
.30137 .41084 Mdot
.35236 .3995 Mdot
.63835 .75683 Mdot
.37957 .39784 Mdot
.68645 .48311 Mdot
.41168 .61813 Mdot
.42614 .62019 Mdot
.43324 .54796 Mdot
.45266 .59425 Mdot
.62575 .47804 Mdot
.35974 .61345 Mdot
.2564 .72516 Mdot
.54363 .3786 Mdot
.35315 .67014 Mdot
.37751 .38849 Mdot
.63244 .49634 Mdot
.52041 .33735 Mdot
.68313 .39011 Mdot
.30508 .44547 Mdot
.40245 .60262 Mdot
.42094 .54984 Mdot
.24432 .38461 Mdot
.40589 .54834 Mdot
.50499 .60585 Mdot
.54047 .3422 Mdot
.40278 .44237 Mdot
.35735 .42218 Mdot
.35503 .41779 Mdot
.66557 .49263 Mdot
.6231 .63234 Mdot
.37029 .38612 Mdot
.53434 .37258 Mdot
.3922 .54017 Mdot
.36708 .61699 Mdot
.55981 .64902 Mdot
.24431 .34138 Mdot
.37656 .36918 Mdot
.76685 .43866 Mdot
.5953 .61845 Mdot
.54668 .65374 Mdot
.44031 .56579 Mdot
.64367 .61335 Mdot
.63793 .62072 Mdot
.35919 .42744 Mdot
.63343 .49642 Mdot
.32172 .4376 Mdot
.69566 .46828 Mdot
.61783 .63647 Mdot
.3791 .61198 Mdot
.6047 .62241 Mdot
.39611 .60203 Mdot
.46248 .15003 Mdot
.43158 .61612 Mdot
.20683 .62082 Mdot
.27877 .54268 Mdot
.52893 .34828 Mdot
.7055 .40552 Mdot
.53677 .36132 Mdot
.58589 .61744 Mdot
.37249 .60877 Mdot
.38502 .39132 Mdot
.78147 .39134 Mdot
.63967 .6954 Mdot
.49265 .33649 Mdot
.55083 .3819 Mdot
.69556 .4798 Mdot
.43314 .54409 Mdot
.44435 .56896 Mdot
.51041 .34564 Mdot
.57471 .59389 Mdot
.62561 .65946 Mdot
.4055 .61226 Mdot
.41981 .57335 Mdot
.52989 .35085 Mdot
.8344 .54466 Mdot
.62457 .70438 Mdot
.41755 .61599 Mdot
.55202 .26103 Mdot
.69697 .44846 Mdot
.4008 .53079 Mdot
.48648 .57722 Mdot
.35739 .39489 Mdot
.36589 .71124 Mdot
.28908 .27795 Mdot
.70292 .47644 Mdot
.54496 .35104 Mdot
.3924 .60585 Mdot
.54384 .35889 Mdot
.36462 .61557 Mdot
.65953 .59434 Mdot
.47987 .34564 Mdot
.3803 .56941 Mdot
.34744 .57856 Mdot
.57274 .61939 Mdot
.42046 .54841 Mdot
.56455 .78491 Mdot
.50967 .32153 Mdot
.37078 .57757 Mdot
.4917 .68349 Mdot
.67288 .45535 Mdot
.37713 .53793 Mdot
.33399 .39067 Mdot
.25887 .58458 Mdot
.70246 .58573 Mdot
.48534 .22275 Mdot
.34544 .41762 Mdot
.46405 .59645 Mdot
.55628 .36684 Mdot
.6569 .44585 Mdot
.22157 .6451 Mdot
.46347 .57763 Mdot
.69022 .47342 Mdot
.65176 .48214 Mdot
.34891 .37493 Mdot
.58845 .82998 Mdot
.3892 .63558 Mdot
.44522 .59007 Mdot
.46714 .78731 Mdot
.56335 .663 Mdot
.4385 .60868 Mdot
.42187 .6327 Mdot
.643 .46582 Mdot
.5076 .59321 Mdot
.5698 .74947 Mdot
.25414 .62767 Mdot
.68509 .4388 Mdot
.52582 .52627 Mdot
.50224 .38747 Mdot
.37118 .40246 Mdot
.59324 .65578 Mdot
.38069 .37862 Mdot
.50574 .38407 Mdot
.42565 .63066 Mdot
.64923 .49594 Mdot
.52375 .80366 Mdot
.64035 .45634 Mdot
.45592 .21867 Mdot
.55949 .65532 Mdot
.72289 .53244 Mdot
.39864 .86314 Mdot
.75016 .38972 Mdot
.73084 .45644 Mdot
.35337 .39543 Mdot
.44503 .36884 Mdot
.41786 .57403 Mdot
.62833 .76977 Mdot
.44106 .62419 Mdot
.47363 .68813 Mdot
.54705 .36746 Mdot
.53975 .38603 Mdot
.41379 .61688 Mdot
.2393 .52876 Mdot
.65418 .44655 Mdot
.69491 .45042 Mdot
.37993 .56678 Mdot
.6705 .47023 Mdot
.43749 .59131 Mdot
.51596 .33408 Mdot
.41316 .82579 Mdot
.41747 .58857 Mdot
.487 .59507 Mdot
.66521 .59045 Mdot
.82633 .44614 Mdot
.37541 .25526 Mdot
.78769 .66423 Mdot
.37193 .19476 Mdot
.66919 .4711 Mdot
.43627 .53846 Mdot
.52589 .52761 Mdot
.48471 .3795 Mdot
.67078 .51174 Mdot
.43987 .61804 Mdot
.44412 .61849 Mdot
.46152 .61734 Mdot
.40961 .56398 Mdot
.65394 .75289 Mdot
.42801 .50598 Mdot
.43831 .72035 Mdot
.40559 .55257 Mdot
.28432 .41733 Mdot
.67169 .49311 Mdot
.6104 .60471 Mdot
.34322 .42458 Mdot
.42191 .5477 Mdot
.49542 .54813 Mdot
.62739 .45501 Mdot
.33048 .18723 Mdot
.68441 .4869 Mdot
.50226 .36171 Mdot
.63131 .46203 Mdot
.40087 .58409 Mdot
.60043 .64374 Mdot
.53645 .50655 Mdot
.70664 .35114 Mdot
.53791 .33939 Mdot
.40211 .59346 Mdot
.59223 .39251 Mdot
.52806 .33122 Mdot
.75079 .33959 Mdot
.59488 .64842 Mdot
.26003 .48044 Mdot
.61094 .62493 Mdot
.37474 .57492 Mdot
.37217 .58019 Mdot
.72406 .45394 Mdot
.63077 .46797 Mdot
.6136 .62623 Mdot
.59421 .83473 Mdot
.35589 .36389 Mdot
.58711 .62957 Mdot
.44264 .64385 Mdot
.49259 .45434 Mdot
.59616 .64086 Mdot
.31721 .42168 Mdot
.64656 .47632 Mdot
.59528 .68193 Mdot
.43317 .64246 Mdot
.28858 .32234 Mdot
.33089 .39948 Mdot
.47492 .33661 Mdot
.37421 .45612 Mdot
.50951 .31962 Mdot
.63893 .49843 Mdot
.53667 .35911 Mdot
.65742 .44851 Mdot
.71345 .60581 Mdot
.51651 .55765 Mdot
.70492 .43612 Mdot
.63313 .4928 Mdot
.53402 .3582 Mdot
.40403 .61633 Mdot
.31055 .41702 Mdot
.42273 .53378 Mdot
.39724 .63962 Mdot
.67053 .44572 Mdot
.56536 .63462 Mdot
.60631 .60653 Mdot
.26865 .42207 Mdot
.63216 .64483 Mdot
.49482 .33758 Mdot
.27315 .72753 Mdot
.57844 .27808 Mdot
.6891 .45712 Mdot
.62851 .46377 Mdot
.38155 .57372 Mdot
.51457 .3546 Mdot
.54806 .35059 Mdot
.69539 .47792 Mdot
.57803 .57098 Mdot
.47546 .56266 Mdot
.58696 .60692 Mdot
.57613 .67056 Mdot
.60201 .6331 Mdot
.55746 .63085 Mdot
.6005 .73628 Mdot
.64709 .48602 Mdot
.56696 .62854 Mdot
.38587 .56475 Mdot
.44278 .6177 Mdot
.48131 .49359 Mdot
.34927 .41505 Mdot
.46238 .56815 Mdot
.36403 .55852 Mdot
.43632 .56039 Mdot
.48879 .36728 Mdot
.32313 .60311 Mdot
.48186 .34234 Mdot
.55439 .36333 Mdot
.55259 .35843 Mdot
.62203 .32112 Mdot
.23788 .41682 Mdot
.38362 .20621 Mdot
.38784 .61954 Mdot
.78623 .58254 Mdot
.52125 .36495 Mdot
.31248 .75225 Mdot
.76977 .58082 Mdot
.46934 .59177 Mdot
.40852 .34234 Mdot
.51441 .34631 Mdot
.63371 .63749 Mdot
.43707 .61765 Mdot
.54647 .32042 Mdot
.33319 .38986 Mdot
.3842 .55503 Mdot
.47949 .34137 Mdot
.61813 .65057 Mdot
.35544 .42917 Mdot
.58238 .67743 Mdot
.55162 .36063 Mdot
.35415 .56061 Mdot
.13113 .57554 Mdot
.55521 .37816 Mdot
.80993 .52293 Mdot
.51487 .65289 Mdot
.40504 .61403 Mdot
.50945 .31369 Mdot
.56104 .66466 Mdot
.65173 .5019 Mdot
.56216 .42784 Mdot
.60405 .67974 Mdot
.53868 .38703 Mdot
.49509 .32868 Mdot
.53968 .3407 Mdot
.59717 .67267 Mdot
.47941 .61201 Mdot
.6135 .67628 Mdot
.63278 .46006 Mdot
.39064 .57221 Mdot
.47063 .18122 Mdot
.77928 .59467 Mdot
.60546 .62086 Mdot
.49997 .36796 Mdot
.32654 .3935 Mdot
.41028 .58298 Mdot
.78049 .60378 Mdot
.39764 .61428 Mdot
.67612 .44375 Mdot
.31813 .71826 Mdot
.55991 .79879 Mdot
.41315 .53948 Mdot
.38294 .57245 Mdot
.69162 .4487 Mdot
.40772 .59342 Mdot
.42769 .54307 Mdot
.62936 .32483 Mdot
.6092 .67276 Mdot
.42389 .58163 Mdot
.52371 .37989 Mdot
.61807 .29767 Mdot
.47759 .56882 Mdot
.50046 .28141 Mdot
.25623 .50017 Mdot
.32848 .7259 Mdot
.43972 .62502 Mdot
.39888 .47279 Mdot
.41952 .56319 Mdot
.45885 .59745 Mdot
.3786 .58894 Mdot
.67906 .75034 Mdot
.47956 .35012 Mdot
.53551 .34387 Mdot
.33696 .41251 Mdot
.25638 .49601 Mdot
.36124 .39296 Mdot
.64508 .47702 Mdot
.44911 .26913 Mdot
.48149 .34323 Mdot
.62152 .64293 Mdot
.46062 .5897 Mdot
.55625 .37542 Mdot
.4428 .56411 Mdot
.39923 .58517 Mdot
.52992 .32257 Mdot
.49044 .37795 Mdot
.51106 .23255 Mdot
.33703 .40946 Mdot
.58066 .63657 Mdot
.44657 .54841 Mdot
.37391 .37038 Mdot
.41636 .63605 Mdot
.30487 .5025 Mdot
.58423 .63549 Mdot
.61122 .67425 Mdot
.61892 .6102 Mdot
.42343 .6305 Mdot
.40473 .58508 Mdot
.65111 .4585 Mdot
.61036 .62063 Mdot
.67464 .45699 Mdot
.57532 .46469 Mdot
.4532 .31951 Mdot
.44003 .61807 Mdot
.75982 .4709 Mdot
.36222 .4069 Mdot
.49116 .34993 Mdot
.20319 .47353 Mdot
.33555 .41128 Mdot
.39724 .60411 Mdot
.54727 .34103 Mdot
.34549 .40572 Mdot
.33206 .66885 Mdot
.28405 .25096 Mdot
.32814 .40665 Mdot
.38652 .56386 Mdot
.48857 .55524 Mdot
.77816 .67761 Mdot
.34034 .4176 Mdot
.63603 .48237 Mdot
.42302 .63014 Mdot
.65344 .66 Mdot
.38225 .37999 Mdot
.70786 .32941 Mdot
.51701 .34088 Mdot
.2921 .29999 Mdot
.36042 .53158 Mdot
.5828 .8003 Mdot
.36268 .41352 Mdot
.60423 .65485 Mdot
.49666 .648 Mdot
.434 .5636 Mdot
.33796 .41534 Mdot
.66153 .4359 Mdot
.5044 .33913 Mdot
.65345 .31833 Mdot
.59593 .67299 Mdot
.73187 .5059 Mdot
.49919 .37115 Mdot
.76518 .43327 Mdot
.28404 .66867 Mdot
.39883 .52843 Mdot
.76591 .68391 Mdot
.60482 .40777 Mdot
.46771 .61724 Mdot
.32785 .37961 Mdot
.70651 .47087 Mdot
.64456 .49523 Mdot
.6779 .47343 Mdot
.7243 .61311 Mdot
.44002 .47149 Mdot
.51291 .30987 Mdot
.72508 .48628 Mdot
.37081 .40122 Mdot
.31248 .43395 Mdot
.37081 .63222 Mdot
.41651 .57905 Mdot
.42617 .54047 Mdot
.43085 .54916 Mdot
.42741 .56677 Mdot
.67099 .4636 Mdot
.70287 .60988 Mdot
.45707 .4806 Mdot
.59067 .63724 Mdot
.47694 .2494 Mdot
.53275 .36773 Mdot
.51172 .3093 Mdot
.33942 .40357 Mdot
.76516 .3907 Mdot
.47421 .36515 Mdot
.51361 .37141 Mdot
.47617 .6005 Mdot
.62508 .6658 Mdot
.49929 .58389 Mdot
.38437 .56851 Mdot
.49562 .33909 Mdot
.58428 .51829 Mdot
.58315 .76079 Mdot
.32157 .62266 Mdot
.31449 .39289 Mdot
.45603 .45819 Mdot
.32852 .39884 Mdot
.37379 .61276 Mdot
.31974 .76274 Mdot
.50379 .38327 Mdot
.50572 .3568 Mdot
.35974 .41212 Mdot
.66616 .65075 Mdot
.5862 .65852 Mdot
.73425 .44298 Mdot
.63743 .46685 Mdot
.37068 .59913 Mdot
.21553 .59082 Mdot
.40664 .67609 Mdot
.42502 .26575 Mdot
.68317 .47207 Mdot
.54202 .36477 Mdot
.40263 .53758 Mdot
.39084 .56181 Mdot
.35903 .40879 Mdot
.57145 .21722 Mdot
.37723 .54825 Mdot
.75859 .31896 Mdot
.21733 .4177 Mdot
.26076 .33542 Mdot
.44171 .567 Mdot
.60634 .67315 Mdot
.47436 .34844 Mdot
.37579 .40245 Mdot
.42201 .64944 Mdot
.31872 .22806 Mdot
.56411 .65507 Mdot
.67547 .48712 Mdot
.55249 .49966 Mdot
.33897 .44878 Mdot
.44401 .62837 Mdot
.43808 .62408 Mdot
.45729 .60797 Mdot
.23649 .29482 Mdot
.48335 .35696 Mdot
.62243 .62772 Mdot
.3448 .37941 Mdot
.62933 .64436 Mdot
.53501 .34972 Mdot
.72072 .52149 Mdot
.40315 .61912 Mdot
.56414 .6567 Mdot
.60246 .65528 Mdot
.68826 .48447 Mdot
.66366 .50234 Mdot
.56356 .4876 Mdot
.43214 .61432 Mdot
.54945 .38844 Mdot
.56893 .62365 Mdot
.41835 .45911 Mdot
.35219 .38729 Mdot
.64375 .47298 Mdot
.41202 .55026 Mdot
.4868 .36883 Mdot
.36415 .63173 Mdot
.58233 .64762 Mdot
.5141 .37098 Mdot
.54475 .24928 Mdot
.35147 .421 Mdot
.44719 .60611 Mdot
.39628 .40268 Mdot
.54543 .3496 Mdot
.41704 .57222 Mdot
.78534 .44675 Mdot
.32523 .42724 Mdot
.69611 .33234 Mdot
.55201 .35118 Mdot
.59097 .30348 Mdot
.63282 .66573 Mdot
.73555 .62831 Mdot
.50293 .35772 Mdot
.76922 .45009 Mdot
.57982 .23696 Mdot
.40432 .53501 Mdot
.6075 .62928 Mdot
.5999 .41284 Mdot
.51698 .16559 Mdot
.82035 .56626 Mdot
.41452 .60059 Mdot
.54092 .32031 Mdot
.35439 .40859 Mdot
.68778 .45407 Mdot
.49027 .28369 Mdot
.32022 .42007 Mdot
.53358 .39479 Mdot
.37866 .59027 Mdot
.61141 .65161 Mdot
.65054 .47308 Mdot
.70636 .59052 Mdot
.53123 .37606 Mdot
.50965 .37811 Mdot
.40462 .53766 Mdot
.36611 .39505 Mdot
.76013 .6324 Mdot
.52185 .33428 Mdot
.2294 .40648 Mdot
.55339 .39604 Mdot
.36443 .36457 Mdot
.4159 .55897 Mdot
.26673 .41516 Mdot
.46813 .56196 Mdot
.8109 .46653 Mdot
.53253 .36316 Mdot
.58305 .64231 Mdot
.45957 .61486 Mdot
.26515 .62968 Mdot
.4936 .34186 Mdot
.44235 .45106 Mdot
.36666 .28674 Mdot
.64546 .48153 Mdot
.20195 .47692 Mdot
.44217 .60103 Mdot
.65419 .4468 Mdot
.36057 .40612 Mdot
.42354 .61541 Mdot
.40387 .58239 Mdot
.5847 .61405 Mdot
.69221 .47943 Mdot
.5412 .2253 Mdot
.63096 .45313 Mdot
.65691 .49561 Mdot
.57181 .61308 Mdot
.43503 .58086 Mdot
.50246 .3634 Mdot
.51303 .34734 Mdot
.39496 .64611 Mdot
.36677 .81426 Mdot
.58475 .66079 Mdot
.47486 .32993 Mdot
.22749 .31126 Mdot
.34645 .61993 Mdot
.2028 .4982 Mdot
.58423 .21904 Mdot
.69313 .44319 Mdot
.38834 .56085 Mdot
.61771 .6482 Mdot
.46425 .41133 Mdot
.50666 .37498 Mdot
.44632 .63346 Mdot
.65332 .4745 Mdot
.3318 .39434 Mdot
.51478 .32406 Mdot
.43523 .26128 Mdot
.45491 .59937 Mdot
.40094 .33995 Mdot
.52718 .31403 Mdot
.64398 .19409 Mdot
.66907 .39013 Mdot
.60191 .62721 Mdot
.39762 .58278 Mdot
.63644 .63948 Mdot
.3418 .38354 Mdot
.55262 .4972 Mdot
.65098 .47777 Mdot
.38746 .50857 Mdot
.2284 .70608 Mdot
.54164 .3424 Mdot
.62496 .62879 Mdot
.41022 .53964 Mdot
.65095 .59197 Mdot
.4416 .59443 Mdot
.51347 .60149 Mdot
.39067 .44234 Mdot
.67509 .44808 Mdot
.65075 .45048 Mdot
.40872 .57015 Mdot
.35885 .36734 Mdot
.53384 .37104 Mdot
.49863 .34136 Mdot
.77413 .29465 Mdot
.63462 .54575 Mdot
.23847 .56026 Mdot
.4458 .6158 Mdot
.54165 .38942 Mdot
.6178 .28025 Mdot
.68989 .46846 Mdot
.37805 .64413 Mdot
.53159 .32709 Mdot
.3095 .32377 Mdot
.27306 .60784 Mdot
.42686 .56329 Mdot
.48547 .60908 Mdot
.63659 .47157 Mdot
.41999 .47395 Mdot
.54156 .37781 Mdot
.34808 .59524 Mdot
.71603 .44004 Mdot
.29657 .64122 Mdot
.23848 .3335 Mdot
.58051 .63626 Mdot
.42126 .2524 Mdot
.67038 .46308 Mdot
.48834 .6069 Mdot
.37374 .37734 Mdot
.47628 .3623 Mdot
.48268 .35983 Mdot
.38531 .60081 Mdot
.36446 .58113 Mdot
.2166 .47529 Mdot
.62745 .65063 Mdot
.66816 .49348 Mdot
.42248 .62442 Mdot
.76163 .51973 Mdot
.43022 .54665 Mdot
.65759 .45539 Mdot
.12586 .57928 Mdot
.42057 .53517 Mdot
.44311 .59075 Mdot
.77261 .61744 Mdot
.59506 .67776 Mdot
.62504 .62653 Mdot
.19323 .54404 Mdot
.44602 .61512 Mdot
.21033 .44741 Mdot
.57713 .63945 Mdot
.58348 .65638 Mdot
.64718 .33124 Mdot
.41304 .58287 Mdot
.35231 .52379 Mdot
.6775 .44259 Mdot
.64902 .49371 Mdot
.60493 .67688 Mdot
.39491 .53367 Mdot
.69824 .48367 Mdot
.69933 .71673 Mdot
.51623 .35553 Mdot
.33363 .77594 Mdot
.57924 .66113 Mdot
.61179 .4405 Mdot
.68716 .46923 Mdot
.33839 .18491 Mdot
.57847 .37185 Mdot
.40622 .61827 Mdot
.44972 .60787 Mdot
.36603 .40627 Mdot
.43353 .54027 Mdot
.54144 .38448 Mdot
.67112 .46988 Mdot
.43098 .69093 Mdot
.58384 .63183 Mdot
.43466 .60479 Mdot
.76097 .37354 Mdot
.70032 .30585 Mdot
.42232 .24265 Mdot
.59278 .6623 Mdot
.59761 .62301 Mdot
.53266 .38236 Mdot
.53968 .31984 Mdot
.43652 .57245 Mdot
.69635 .45502 Mdot
.60948 .62064 Mdot
.66265 .45074 Mdot
.50264 .38218 Mdot
.50604 .36744 Mdot
.48014 .35999 Mdot
.35882 .62103 Mdot
.51845 .37611 Mdot
.50596 .26617 Mdot
.73182 .50174 Mdot
.59476 .61028 Mdot
.19357 .42478 Mdot
.71332 .59134 Mdot
.65864 .69978 Mdot
.38394 .38006 Mdot
.54577 .34765 Mdot
.63622 .45411 Mdot
.3993 .56556 Mdot
.43192 .55435 Mdot
.55994 .2831 Mdot
.65152 .44482 Mdot
.34141 .38667 Mdot
.6471 .4507 Mdot
.34881 .37481 Mdot
.36742 .31645 Mdot
.44161 .54882 Mdot
.36606 .61304 Mdot
.67507 .4656 Mdot
.51713 .37386 Mdot
.52702 .34083 Mdot
.33269 .41409 Mdot
.61004 .5214 Mdot
.52847 .33079 Mdot
.57808 .65543 Mdot
.6158 .73205 Mdot
.49374 .3292 Mdot
.4379 .61465 Mdot
.32934 .48656 Mdot
.61105 .78776 Mdot
.48094 .58156 Mdot
.63994 .32854 Mdot
.50897 .81481 Mdot
.46703 .59946 Mdot
.57796 .81594 Mdot
.60028 .34154 Mdot
.63181 .66459 Mdot
.54556 .37061 Mdot
.46818 .35674 Mdot
.38192 .65706 Mdot
.32919 .41946 Mdot
.41085 .64912 Mdot
.5778 .66368 Mdot
.63554 .67798 Mdot
.26838 .34377 Mdot
.814 .50691 Mdot
.35099 .40721 Mdot
.34627 .40939 Mdot
.50077 .35494 Mdot
.85501 .47288 Mdot
.42638 .51806 Mdot
.34135 .38974 Mdot
.52637 .5644 Mdot
.37996 .59371 Mdot
.26596 .53827 Mdot
.38543 .35081 Mdot
.60304 .67474 Mdot
.27846 .40708 Mdot
.49598 .35526 Mdot
.63315 .64705 Mdot
.75341 .53876 Mdot
.46945 .57618 Mdot
.58498 .63432 Mdot
.6571 .45327 Mdot
.69048 .38044 Mdot
.57102 .65022 Mdot
.31809 .49296 Mdot
.69889 .4732 Mdot
.4253 .4574 Mdot
.26224 .44555 Mdot
.63298 .86426 Mdot
.66886 .46629 Mdot
.49276 .33311 Mdot
.51219 .34655 Mdot
.49815 .34265 Mdot
.63002 .64869 Mdot
.54768 .35086 Mdot
.62648 .64675 Mdot
.79385 .62921 Mdot
.66468 .63577 Mdot
.34182 .39201 Mdot
.65976 .32236 Mdot
.61286 .64227 Mdot
.2974 .74988 Mdot
.31846 .8056 Mdot
.38786 .5607 Mdot
.62572 .46477 Mdot
.34391 .39809 Mdot
.76816 .32773 Mdot
.35696 .39826 Mdot
.25668 .38777 Mdot
.32426 .73815 Mdot
.43389 .59652 Mdot
.52672 .75924 Mdot
.37435 .41387 Mdot
.60196 .66346 Mdot
.41559 .57343 Mdot
.51916 .43038 Mdot
.36062 .39915 Mdot
.33835 .37875 Mdot
.42996 .57523 Mdot
.5718 .62845 Mdot
.49639 .36095 Mdot
.63072 .47717 Mdot
.38591 .40425 Mdot
.52018 .63742 Mdot
.47937 .58441 Mdot
.39198 .61392 Mdot
.48471 .49066 Mdot
.3821 .36061 Mdot
.6682 .47124 Mdot
.64329 .7845 Mdot
.55139 .34382 Mdot
.53768 .42593 Mdot
.23455 .39027 Mdot
.62331 .33127 Mdot
.53074 .36139 Mdot
.54263 .35608 Mdot
.43066 .56685 Mdot
.36745 .35221 Mdot
.33275 .74453 Mdot
.6303 .51633 Mdot
.47607 .34511 Mdot
.50156 .33917 Mdot
.64245 .6575 Mdot
.26016 .35083 Mdot
.42755 .64915 Mdot
.70287 .47736 Mdot
.48335 .36385 Mdot
.6755 .6251 Mdot
.36881 .3963 Mdot
.2965 .73012 Mdot
.4464 .55244 Mdot
.4111 .62048 Mdot
.66321 .48019 Mdot
.64895 .46181 Mdot
.45994 .41011 Mdot
.25838 .36351 Mdot
.52657 .81235 Mdot
.68673 .58881 Mdot
.36274 .72815 Mdot
.64223 .66656 Mdot
.6045 .62055 Mdot
.72666 .36346 Mdot
.629 .45436 Mdot
.46498 .60602 Mdot
.62103 .63049 Mdot
.56085 .41556 Mdot
.6339 .71325 Mdot
.24873 .54742 Mdot
.21115 .50534 Mdot
.39741 .60004 Mdot
.61707 .66821 Mdot
.59274 .67642 Mdot
.54625 .63449 Mdot
.5971 .36906 Mdot
.44233 .5777 Mdot
.40544 .60037 Mdot
.46177 .58308 Mdot
.61234 .58211 Mdot
.454 .58476 Mdot
.72885 .62996 Mdot
.54247 .48086 Mdot
.37287 .70699 Mdot
.35102 .5851 Mdot
.70671 .44959 Mdot
.43968 .62902 Mdot
.35655 .36791 Mdot
.37568 .58632 Mdot
.24967 .55446 Mdot
.68641 .47914 Mdot
.6266 .70521 Mdot
.71584 .60111 Mdot
.46766 .61316 Mdot
.36676 .42592 Mdot
.64831 .40614 Mdot
.45458 .18411 Mdot
.39079 .42177 Mdot
.57834 .65674 Mdot
.52167 .35853 Mdot
.63869 .45156 Mdot
.50785 .36504 Mdot
.35701 .60614 Mdot
.73455 .37653 Mdot
.7009 .28848 Mdot
.58105 .46993 Mdot
.42893 .54921 Mdot
.33905 .55893 Mdot
.58068 .65274 Mdot
.54671 .33833 Mdot
.65711 .64891 Mdot
.45751 .61477 Mdot
.35241 .37632 Mdot
.36263 .4032 Mdot
.5685 .42335 Mdot
.62525 .20877 Mdot
.69271 .68505 Mdot
.66398 .47809 Mdot
.51497 .33272 Mdot
.38065 .39526 Mdot
.79179 .50191 Mdot
.66383 .50286 Mdot
.68963 .4463 Mdot
.68119 .48621 Mdot
.40636 .6316 Mdot
.47951 .34558 Mdot
.3755 .70592 Mdot
.53812 .38987 Mdot
.40519 .59221 Mdot
.48654 .36206 Mdot
.53343 .32986 Mdot
.37757 .39274 Mdot
.67582 .49076 Mdot
.51607 .38755 Mdot
.3724 .57791 Mdot
.57391 .63425 Mdot
.63881 .42806 Mdot
.27844 .57064 Mdot
.81196 .49303 Mdot
.45901 .67857 Mdot
.57627 .66892 Mdot
.51571 .17072 Mdot
.69419 .44617 Mdot
.58773 .57203 Mdot
.50234 .23516 Mdot
.38219 .61805 Mdot
.32763 .79557 Mdot
.50723 .31071 Mdot
.5257 .32356 Mdot
.41525 .56025 Mdot
.48944 .41146 Mdot
.43672 .60026 Mdot
.50092 .37728 Mdot
.54432 .26711 Mdot
.52395 .61921 Mdot
.52268 .37272 Mdot
.34806 .60262 Mdot
.4064 .57729 Mdot
.60754 .67513 Mdot
.50988 .31441 Mdot
.38114 .64721 Mdot
.75506 .27647 Mdot
.653 .46057 Mdot
.60087 .38723 Mdot
.33194 .49539 Mdot
.67036 .46192 Mdot
.59077 .62942 Mdot
.38889 .63839 Mdot
.35926 .40743 Mdot
.61436 .64339 Mdot
.27467 .62134 Mdot
.36093 .41983 Mdot
.30437 .76666 Mdot
.59252 .67473 Mdot
.49922 .32569 Mdot
.36995 .37315 Mdot
.44491 .54371 Mdot
.47598 .36055 Mdot
.69998 .39943 Mdot
.52998 .36304 Mdot
.44531 .57042 Mdot
.66131 .30922 Mdot
.66278 .49446 Mdot
.41647 .60282 Mdot
.52207 .32101 Mdot
.63066 .32181 Mdot
.40124 .63 Mdot
.41431 .56645 Mdot
.24052 .34561 Mdot
.25228 .68544 Mdot
.35321 .3925 Mdot
.54924 .64779 Mdot
.38551 .56505 Mdot
.33652 .38359 Mdot
.42252 .31611 Mdot
.41335 .62815 Mdot
.56179 .65216 Mdot
.33801 .60244 Mdot
.51708 .31282 Mdot
.66778 .4575 Mdot
.5867 .45971 Mdot
.33327 .38993 Mdot
.77835 .71647 Mdot
.51582 .39167 Mdot
.37142 .61838 Mdot
.41893 .54622 Mdot
.35151 .26159 Mdot
.63208 .66275 Mdot
.43212 .80543 Mdot
.44739 .60623 Mdot
.60285 .5799 Mdot
.42484 .6124 Mdot
.48649 .32082 Mdot
.58511 .65838 Mdot
.4463 .58759 Mdot
.75009 .48556 Mdot
.48523 .58631 Mdot
.33879 .4129 Mdot
.77691 .61667 Mdot
.47938 .59753 Mdot
.17817 .66412 Mdot
.34502 .33782 Mdot
.52393 .37409 Mdot
.69606 .31353 Mdot
.83665 .35098 Mdot
.72665 .60859 Mdot
.62684 .64049 Mdot
.62264 .23591 Mdot
.5029 .36425 Mdot
.65631 .28865 Mdot
.50788 .16714 Mdot
.40182 .57507 Mdot
.44453 .6283 Mdot
.29207 .35486 Mdot
.55276 .36317 Mdot
.53842 .39721 Mdot
.37269 .55861 Mdot
.48639 .61496 Mdot
.51007 .37377 Mdot
.36687 .58582 Mdot
.35961 .58295 Mdot
.62764 .47575 Mdot
.56992 .65874 Mdot
.68112 .44802 Mdot
.70133 .47491 Mdot
.72819 .68937 Mdot
.33001 .33247 Mdot
.65873 .4563 Mdot
.70598 .45736 Mdot
.26557 .54332 Mdot
.23145 .47281 Mdot
.38268 .3812 Mdot
.66669 .21978 Mdot
.50212 .34138 Mdot
.44023 .58113 Mdot
.58303 .673 Mdot
.54113 .80737 Mdot
.467 .28791 Mdot
.35004 .77306 Mdot
.46182 .61013 Mdot
.49311 .34646 Mdot
.59731 .36894 Mdot
.50342 .59487 Mdot
.55933 .34076 Mdot
.42521 .62577 Mdot
.52633 .39643 Mdot
.5527 .72224 Mdot
.76698 .44754 Mdot
.54764 .39691 Mdot
.58499 .60743 Mdot
.41902 .62143 Mdot
.58076 .66463 Mdot
.68664 .46509 Mdot
.37509 .37432 Mdot
.35478 .38948 Mdot
.42176 .57323 Mdot
.36459 .54515 Mdot
.3787 .32542 Mdot
.40935 .58216 Mdot
.3806 .58736 Mdot
.60028 .34013 Mdot
.37977 .58305 Mdot
.44142 .55657 Mdot
.45379 .57154 Mdot
.4399 .63593 Mdot
.65262 .49478 Mdot
.7629 .3867 Mdot
.46555 .64226 Mdot
.48071 .63246 Mdot
.66495 .50064 Mdot
.55305 .22025 Mdot
.70289 .46385 Mdot
.4601 .17742 Mdot
.6685 .44372 Mdot
.34958 .3851 Mdot
.41259 .22521 Mdot
.37981 .5273 Mdot
.56348 .62733 Mdot
.65265 .5056 Mdot
.34364 .37869 Mdot
.67506 .47179 Mdot
.49513 .36912 Mdot
.24728 .30484 Mdot
.54588 .65762 Mdot
.44048 .49398 Mdot
.6513 .50999 Mdot
.74016 .39575 Mdot
.523 .38964 Mdot
.58665 .66663 Mdot
.57087 .76327 Mdot
.43469 .55025 Mdot
.33867 .38023 Mdot
.43314 .57198 Mdot
.67716 .49254 Mdot
.49577 .35108 Mdot
.81064 .57668 Mdot
.35939 .40861 Mdot
.20518 .40574 Mdot
.52195 .34203 Mdot
.45473 .56853 Mdot
.70049 .48017 Mdot
.17771 .48824 Mdot
.67672 .44696 Mdot
.38266 .77136 Mdot
.63875 .65311 Mdot
.79878 .65181 Mdot
.61307 .63597 Mdot
.71622 .40465 Mdot
.15435 .43071 Mdot
.77194 .38768 Mdot
.57273 .62949 Mdot
.65938 .53436 Mdot
.39357 .60437 Mdot
.39309 .61463 Mdot
.79825 .50692 Mdot
.54975 .64775 Mdot
.39983 .55422 Mdot
.57163 .27255 Mdot
.70971 .51846 Mdot
.20819 .5462 Mdot
.53962 .3627 Mdot
.43946 .60306 Mdot
.71933 .45454 Mdot
.65757 .44417 Mdot
.52748 .39297 Mdot
.69304 .44697 Mdot
.40711 .59909 Mdot
.61277 .64108 Mdot
.45607 .3392 Mdot
.36245 .38264 Mdot
.80953 .39374 Mdot
.3462 .36652 Mdot
.53078 .36081 Mdot
.42504 .53358 Mdot
.50701 .36823 Mdot
.84327 .33505 Mdot
.40587 .60532 Mdot
.57813 .64072 Mdot
.38645 .56879 Mdot
.41714 .61873 Mdot
.45091 .62705 Mdot
.50027 .36947 Mdot
.30811 .5991 Mdot
.36975 .58109 Mdot
.65007 .4783 Mdot
.3744 .71888 Mdot
.47797 .5984 Mdot
.46607 .37765 Mdot
.24116 .49745 Mdot
.71107 .49697 Mdot
.60555 .68214 Mdot
.52695 .36984 Mdot
.58139 .62992 Mdot
.62211 .60205 Mdot
.59089 .62966 Mdot
.41854 .75471 Mdot
.57246 .7549 Mdot
.31172 .66869 Mdot
.48665 .68313 Mdot
.57301 .53335 Mdot
.54936 .64761 Mdot
.39579 .36834 Mdot
.59004 .61757 Mdot
.60213 .67894 Mdot
.06859 .51028 Mdot
.56169 .62414 Mdot
.44174 .61257 Mdot
.47224 .58499 Mdot
.75333 .41311 Mdot
.29048 .49117 Mdot
.3912 .56988 Mdot
.39645 .56145 Mdot
.37882 .38497 Mdot
.58829 .58529 Mdot
.70999 .33967 Mdot
.24836 .69424 Mdot
.67257 .28428 Mdot
.43082 .57327 Mdot
.38335 .56704 Mdot
.49812 .59916 Mdot
.16862 .5759 Mdot
.73025 .70342 Mdot
.60393 .69109 Mdot
.49107 .5832 Mdot
.8003 .42424 Mdot
.45052 .62553 Mdot
.4234 .63242 Mdot
.39619 .60183 Mdot
.50215 .36346 Mdot
.58295 .67989 Mdot
.42427 .64162 Mdot
.29652 .34488 Mdot
.43008 .62807 Mdot
.62637 .32926 Mdot
.84492 .5606 Mdot
.44272 .60068 Mdot
.59594 .68507 Mdot
.38798 .61167 Mdot
.6255 .67133 Mdot
.60606 .66675 Mdot
.44854 .53414 Mdot
.36648 .72924 Mdot
.62674 .68183 Mdot
.40479 .59162 Mdot
.4913 .35712 Mdot
.63647 .19514 Mdot
.44651 .57182 Mdot
.37803 .37567 Mdot
.44874 .60914 Mdot
.3718 .42451 Mdot
.38322 .58346 Mdot
.51601 .3923 Mdot
.58258 .79537 Mdot
.50404 .35506 Mdot
.75492 .69778 Mdot
.48529 .37074 Mdot
.23204 .35394 Mdot
.56498 .66266 Mdot
.65916 .3161 Mdot
.48574 .83404 Mdot
.60969 .36688 Mdot
.43003 .4377 Mdot
.51138 .47836 Mdot
.69626 .45428 Mdot
.63653 .64925 Mdot
.5477 .55778 Mdot
.50969 .24326 Mdot
.45355 .2325 Mdot
.52122 .32879 Mdot
.58399 .83485 Mdot
.38106 .80662 Mdot
.36758 .60232 Mdot
.50465 .76813 Mdot
.4599 .73081 Mdot
.44732 .62865 Mdot
.41844 .64084 Mdot
.57984 .30957 Mdot
.37447 .56978 Mdot
.76308 .51214 Mdot
.53157 .35722 Mdot
.34316 .3782 Mdot
.57786 .64777 Mdot
.33165 .39222 Mdot
.50163 .23975 Mdot
.50494 .47722 Mdot
.499 .37723 Mdot
.48316 .60903 Mdot
.39885 .56286 Mdot
.61916 .67338 Mdot
.64926 .68711 Mdot
.57617 .6187 Mdot
.3491 .40345 Mdot
.52813 .35225 Mdot
.63552 .76664 Mdot
.4045 .55698 Mdot
.60173 .65416 Mdot
.43085 .42465 Mdot
.38726 .5632 Mdot
.68042 .46386 Mdot
.39727 .60765 Mdot
.57029 .63515 Mdot
.37991 .58281 Mdot
.61483 .63583 Mdot
.51906 .35818 Mdot
.47077 .59107 Mdot
.42072 .56035 Mdot
.18785 .45278 Mdot
.34504 .38364 Mdot
.55892 .65402 Mdot
.58299 .3834 Mdot
.41323 .54337 Mdot
.66689 .3423 Mdot
.43004 .62422 Mdot
.65926 .70883 Mdot
.38394 .62436 Mdot
.60559 .36431 Mdot
.44231 .64963 Mdot
.4472 .57461 Mdot
.45222 .41877 Mdot
.45485 .73962 Mdot
.5933 .69262 Mdot
.70787 .4714 Mdot
.55506 .63211 Mdot
.21241 .54844 Mdot
.55641 .39611 Mdot
.54388 .32959 Mdot
.30421 .43471 Mdot
.44361 .63569 Mdot
.43469 .59411 Mdot
.71222 .4758 Mdot
.3446 .41188 Mdot
.59467 .66266 Mdot
.34874 .37497 Mdot
.20422 .44539 Mdot
.35646 .41662 Mdot
.49902 .31377 Mdot
.40259 .33944 Mdot
.65442 .74939 Mdot
.37888 .38706 Mdot
.57076 .62894 Mdot
.44249 .34136 Mdot
.45184 .63174 Mdot
.35369 .3399 Mdot
.35942 .37624 Mdot
.65199 .81181 Mdot
.44169 .55732 Mdot
.42586 .43812 Mdot
.66815 .45328 Mdot
.37527 .37887 Mdot
.69675 .46734 Mdot
.40102 .56696 Mdot
.69862 .33238 Mdot
.62484 .63776 Mdot
.67922 .49474 Mdot
.36979 .5453 Mdot
.3426 .39797 Mdot
.48074 .35424 Mdot
.69846 .49333 Mdot
.70405 .47774 Mdot
.56883 .21375 Mdot
.80064 .60454 Mdot
.52617 .35015 Mdot
.26855 .65685 Mdot
.67065 .44237 Mdot
.46168 .62292 Mdot
.5673 .58142 Mdot
.40665 .61899 Mdot
.71901 .65302 Mdot
.5318 .36913 Mdot
.7549 .398 Mdot
.38257 .57072 Mdot
.46277 .59485 Mdot
.57864 .6839 Mdot
.50615 .34797 Mdot
.60006 .6416 Mdot
.55269 .63105 Mdot
.51809 .35658 Mdot
.60533 .6296 Mdot
.36809 .41872 Mdot
.69466 .54215 Mdot
.63716 .46423 Mdot
.6532 .4848 Mdot
.49902 .34034 Mdot
.52578 .37641 Mdot
.51243 .3705 Mdot
.39735 .60805 Mdot
.58935 .66178 Mdot
.39338 .58272 Mdot
.43442 .62911 Mdot
.35175 .71635 Mdot
.58852 .67893 Mdot
.39325 .59393 Mdot
.50026 .42713 Mdot
.3345 .35241 Mdot
.4897 .35688 Mdot
.66222 .45546 Mdot
.60989 .282 Mdot
.69464 .40248 Mdot
.43798 .60689 Mdot
.31866 .32163 Mdot
.57441 .62311 Mdot
.35941 .40459 Mdot
.3621 .3585 Mdot
.35533 .39646 Mdot
.61122 .49735 Mdot
.55148 .64787 Mdot
.2533 .70279 Mdot
.43864 .59914 Mdot
.47813 .48516 Mdot
.51381 .55025 Mdot
.36024 .32141 Mdot
.65838 .45779 Mdot
.39013 .56281 Mdot
.58808 .46775 Mdot
.58733 .76705 Mdot
.40764 .61699 Mdot
.47723 .60895 Mdot
.54605 .25211 Mdot
.33724 .60937 Mdot
.63913 .64008 Mdot
.18162 .49531 Mdot
.42154 .53818 Mdot
.67446 .62882 Mdot
.82158 .40238 Mdot
.43353 .61628 Mdot
.45976 .60553 Mdot
.42313 .55275 Mdot
.37492 .58971 Mdot
.6156 .68435 Mdot
.2769 .45544 Mdot
.68755 .44109 Mdot
.46977 .4836 Mdot
.63897 .48993 Mdot
.48238 .37242 Mdot
.76216 .39839 Mdot
.63709 .6462 Mdot
.36563 .40653 Mdot
.75813 .34053 Mdot
.19919 .59719 Mdot
.54218 .37675 Mdot
.69917 .71333 Mdot
.35287 .37788 Mdot
.46899 .61713 Mdot
.3727 .41884 Mdot
.48309 .34088 Mdot
.64717 .4825 Mdot
.46623 .62706 Mdot
.59203 .61859 Mdot
.57174 .65318 Mdot
.39351 .55748 Mdot
.79352 .40811 Mdot
.67906 .46031 Mdot
.69577 .49193 Mdot
.4078 .62944 Mdot
.44524 .54433 Mdot
.5993 .6384 Mdot
.51682 .33527 Mdot
.24814 .59919 Mdot
.33806 .40298 Mdot
.36314 .62676 Mdot
.37805 .59072 Mdot
.23946 .37992 Mdot
.64551 .4752 Mdot
.54668 .32476 Mdot
.38791 .62282 Mdot
.67673 .58572 Mdot
.38659 .62103 Mdot
.49087 .57632 Mdot
.49047 .35409 Mdot
.45575 .64884 Mdot
.36491 .60531 Mdot
.51753 .59749 Mdot
.69261 .45505 Mdot
.58302 .63796 Mdot
.53747 .63005 Mdot
.50259 .51614 Mdot
.68057 .46565 Mdot
.39029 .59987 Mdot
.6564 .46331 Mdot
.41347 .62753 Mdot
.38187 .56406 Mdot
.65824 .45515 Mdot
.60079 .64097 Mdot
.62149 .23871 Mdot
.76122 .38016 Mdot
.37327 .5903 Mdot
.39376 .53998 Mdot
.28205 .47084 Mdot
.30836 .59237 Mdot
.45443 .61928 Mdot
.56971 .6404 Mdot
.40936 .55792 Mdot
.69386 .47173 Mdot
.37622 .41092 Mdot
.57291 .63408 Mdot
.53298 .34245 Mdot
.53522 .38345 Mdot
.71987 .60253 Mdot
.5428 .33783 Mdot
.43377 .63443 Mdot
.64103 .62041 Mdot
.53775 .63876 Mdot
.81526 .4205 Mdot
.51565 .35323 Mdot
.38553 .38721 Mdot
.41521 .5678 Mdot
.28896 .32142 Mdot
.72078 .45426 Mdot
.21885 .72563 Mdot
.29114 .74803 Mdot
.32459 .41012 Mdot
.35193 .76788 Mdot
.49784 .38615 Mdot
.36214 .61024 Mdot
.37169 .37099 Mdot
.53429 .38078 Mdot
.38056 .61159 Mdot
.46964 .54549 Mdot
.41685 .79875 Mdot
.53637 .51759 Mdot
.6539 .46426 Mdot
.54924 .35161 Mdot
.31894 .39817 Mdot
.52055 .3076 Mdot
.57923 .66802 Mdot
.44682 .57886 Mdot
.42804 .53231 Mdot
.52711 .33759 Mdot
.55467 .34682 Mdot
.3997 .59407 Mdot
.6366 .64017 Mdot
.58331 .31881 Mdot
.42638 .57712 Mdot
.58808 .54609 Mdot
.55113 .61154 Mdot
.53624 .35618 Mdot
.4592 .58636 Mdot
.40212 .4395 Mdot
.52072 .3397 Mdot
.48891 .35714 Mdot
.38696 .56101 Mdot
.36485 .41996 Mdot
.40071 .53824 Mdot
.65527 .44889 Mdot
.64483 .7913 Mdot
.69371 .47526 Mdot
.49159 .28566 Mdot
.3696 .54347 Mdot
.64641 .56349 Mdot
.6203 .67921 Mdot
.2682 .37498 Mdot
.58055 .27302 Mdot
.36827 .56238 Mdot
.59644 .19533 Mdot
.61658 .43265 Mdot
.78526 .38326 Mdot
.37718 .2202 Mdot
.37178 .38319 Mdot
.6777 .47267 Mdot
.45935 .6068 Mdot
.62609 .4685 Mdot
.37249 .37022 Mdot
.75687 .69238 Mdot
.45617 .5785 Mdot
.58444 .65627 Mdot
.40143 .59821 Mdot
.57892 .65982 Mdot
.38442 .56364 Mdot
.49833 .61115 Mdot
.58776 .29624 Mdot
.27333 .60641 Mdot
.39097 .62879 Mdot
.22313 .33501 Mdot
.41593 .39666 Mdot
.33756 .38734 Mdot
.39928 .5798 Mdot
.56386 .355 Mdot
.65751 .44232 Mdot
.78156 .53474 Mdot
.50213 .36454 Mdot
.70608 .46503 Mdot
.59935 .63162 Mdot
.52735 .36504 Mdot
.53776 .38441 Mdot
.44875 .65162 Mdot
.34976 .42373 Mdot
.66759 .49042 Mdot
.44804 .58808 Mdot
.45482 .57779 Mdot
.25144 .642 Mdot
.47095 .27669 Mdot
.65044 .69135 Mdot
.19493 .63705 Mdot
.5616 .61456 Mdot
.3392 .39126 Mdot
.49775 .36325 Mdot
.44378 .6234 Mdot
.41655 .5998 Mdot
.64825 .32 Mdot
.61227 .62036 Mdot
.55829 .49618 Mdot
.65726 .71946 Mdot
.58205 .37769 Mdot
.25429 .51566 Mdot
.57463 .64578 Mdot
.25546 .51842 Mdot
.34013 .36421 Mdot
.71239 .26123 Mdot
.26743 .57811 Mdot
.66689 .45496 Mdot
.25643 .51232 Mdot
.60455 .65788 Mdot
.36842 .5911 Mdot
.49799 .32569 Mdot
.53518 .33105 Mdot
.59022 .63998 Mdot
.54507 .31559 Mdot
.3761 .39603 Mdot
.45728 .5997 Mdot
.24418 .6807 Mdot
.73226 .57942 Mdot
.50236 .33401 Mdot
.50343 .605 Mdot
.68251 .48527 Mdot
.39412 .55645 Mdot
.37944 .39527 Mdot
.66404 .46594 Mdot
.25745 .37305 Mdot
.7389 .48496 Mdot
.41554 .57069 Mdot
.24002 .35472 Mdot
.67517 .46701 Mdot
.31546 .56272 Mdot
.43402 .57815 Mdot
.67685 .44281 Mdot
.32054 .60362 Mdot
.69412 .38412 Mdot
.58346 .47888 Mdot
.50998 .16684 Mdot
.57143 .4776 Mdot
.50088 .32694 Mdot
.7189 .38987 Mdot
.60618 .40248 Mdot
.63245 .45876 Mdot
.55256 .33461 Mdot
.31259 .3718 Mdot
.69701 .46545 Mdot
.47553 .60402 Mdot
.42979 .62214 Mdot
.73975 .69813 Mdot
.60624 .42963 Mdot
.72794 .41382 Mdot
.76258 .58823 Mdot
.41735 .54296 Mdot
.41034 .53443 Mdot
.42087 .59748 Mdot
.63245 .67999 Mdot
.65008 .4702 Mdot
.19207 .39493 Mdot
.68333 .46323 Mdot
.28921 .71535 Mdot
.49978 .34269 Mdot
.53947 .36766 Mdot
.44086 .60468 Mdot
.40774 .45342 Mdot
.24987 .44119 Mdot
.40745 .5967 Mdot
.3048 .39479 Mdot
.78211 .60942 Mdot
.43755 .54118 Mdot
.63536 .66744 Mdot
.50477 .62624 Mdot
.50791 .64566 Mdot
.63693 .46396 Mdot
.36935 .3925 Mdot
.265 .38178 Mdot
.64891 .48662 Mdot
.43337 .59421 Mdot
.66357 .56222 Mdot
.41565 .61397 Mdot
.37326 .59667 Mdot
.30803 .74636 Mdot
.33554 .37196 Mdot
.51442 .36495 Mdot
.35286 .39645 Mdot
.62504 .6738 Mdot
.13128 .63574 Mdot
.34666 .41638 Mdot
.25018 .43144 Mdot
.72655 .72431 Mdot
.25883 .5134 Mdot
.57571 .66272 Mdot
.35071 .42568 Mdot
.67356 .45729 Mdot
.64887 .1968 Mdot
.474 .82276 Mdot
.68062 .42182 Mdot
.42569 .58142 Mdot
.63135 .62468 Mdot
.5653 .64196 Mdot
.67072 .49836 Mdot
.6045 .66589 Mdot
.32533 .58153 Mdot
.37025 .5926 Mdot
.62802 .46209 Mdot
.68642 .57788 Mdot
.70854 .47144 Mdot
.72198 .52292 Mdot
.40239 .58306 Mdot
.57473 .64077 Mdot
.35417 .6134 Mdot
.54663 .61123 Mdot
.53037 .31096 Mdot
.47947 .5811 Mdot
.37538 .39816 Mdot
.65337 .5753 Mdot
.52659 .34837 Mdot
.33663 .31715 Mdot
.61793 .67488 Mdot
.68893 .51377 Mdot
.60847 .67407 Mdot
.54509 .64211 Mdot
.70282 .47095 Mdot
.61961 .65147 Mdot
.45957 .60323 Mdot
.55844 .42464 Mdot
.62986 .65874 Mdot
.67097 .48328 Mdot
.36584 .39009 Mdot
.60759 .63425 Mdot
.48551 .40965 Mdot
.42183 .56647 Mdot
.50821 .37733 Mdot
.40081 .23272 Mdot
.59923 .61276 Mdot
.32804 .39263 Mdot
.54492 .3328 Mdot
.33977 .37714 Mdot
.8325 .49008 Mdot
.62112 .47142 Mdot
.32523 .73572 Mdot
.31277 .3975 Mdot
.56528 .62438 Mdot
.41884 .22441 Mdot
.44179 .62264 Mdot
.4187 .56646 Mdot
.37733 .4223 Mdot
.56521 .64142 Mdot
.75634 .31226 Mdot
.54368 .66823 Mdot
.69234 .53393 Mdot
.63458 .50008 Mdot
.23144 .34558 Mdot
.73973 .50901 Mdot
.86206 .48622 Mdot
.37474 .54875 Mdot
.53572 .39836 Mdot
.43201 .60557 Mdot
.5923 .28316 Mdot
.34404 .39695 Mdot
.46369 .33558 Mdot
.46873 .55247 Mdot
.51958 .36366 Mdot
.43151 .5599 Mdot
.47803 .43098 Mdot
.42451 .66237 Mdot
.38498 .38343 Mdot
.70031 .32127 Mdot
.55943 .62703 Mdot
.36053 .38044 Mdot
.50721 .38701 Mdot
.2498 .46902 Mdot
.37493 .60512 Mdot
.36589 .63829 Mdot
.58194 .37764 Mdot
.58497 .66286 Mdot
.51238 .31832 Mdot
.64177 .45811 Mdot
.36649 .40202 Mdot
.39676 .56579 Mdot
.41083 .63623 Mdot
.66257 .34297 Mdot
.68219 .4869 Mdot
.55667 .35882 Mdot
.6817 .44998 Mdot
.50781 .39308 Mdot
.38242 .5593 Mdot
.5423 .3644 Mdot
.36903 .63326 Mdot
.59846 .30828 Mdot
.30558 .7383 Mdot
.46964 .751 Mdot
.53339 .36769 Mdot
.23913 .52598 Mdot
.68772 .47744 Mdot
.67957 .4457 Mdot
.67933 .75131 Mdot
.38441 .77525 Mdot
.2303 .62914 Mdot
.51369 .20124 Mdot
.6367 .48528 Mdot
.67881 .48536 Mdot
.51303 .38006 Mdot
.62092 .65382 Mdot
.55309 .62069 Mdot
.51341 .39511 Mdot
.33275 .48778 Mdot
.59482 .66251 Mdot
.6378 .20694 Mdot
.2124 .57717 Mdot
.40246 .64302 Mdot
.56 .32555 Mdot
.36215 .39946 Mdot
.32178 .48726 Mdot
.47514 .42878 Mdot
.46365 .59932 Mdot
.27776 .35136 Mdot
.50582 .336 Mdot
.40467 .47041 Mdot
.46218 .1787 Mdot
.45207 .56913 Mdot
.43935 .57968 Mdot
.42797 .59853 Mdot
.33 .41337 Mdot
.4386 .8016 Mdot
.45768 .58903 Mdot
.33296 .48983 Mdot
.40535 .54728 Mdot
.31603 .5992 Mdot
.35407 .39138 Mdot
.32613 .66409 Mdot
.51809 .23642 Mdot
.186 .50815 Mdot
.40105 .66618 Mdot
.64414 .45504 Mdot
.29639 .38492 Mdot
.68787 .44796 Mdot
.42971 .75422 Mdot
.2697 .57358 Mdot
.58827 .60919 Mdot
.46274 .60301 Mdot
.53146 .3606 Mdot
.56596 .64415 Mdot
.69012 .36768 Mdot
.09179 .57044 Mdot
.64595 .45248 Mdot
.8793 .46548 Mdot
.66972 .44452 Mdot
.53594 .38652 Mdot
.59834 .6376 Mdot
.57277 .74939 Mdot
.4945 .49818 Mdot
.60887 .63301 Mdot
.68457 .27405 Mdot
.61744 .69279 Mdot
.24525 .50923 Mdot
.62239 .62171 Mdot
.67699 .48238 Mdot
.61123 .49563 Mdot
.37965 .52166 Mdot
.44372 .61677 Mdot
.51093 .47456 Mdot
.23952 .4616 Mdot
.44406 .62048 Mdot
.52969 .35538 Mdot
.33876 .74134 Mdot
.28125 .39449 Mdot
.61527 .65188 Mdot
.67594 .43483 Mdot
.44042 .57531 Mdot
.38239 .60537 Mdot
.37252 .6031 Mdot
.22194 .6948 Mdot
.71749 .26418 Mdot
.37089 .5792 Mdot
.40755 .54333 Mdot
.52406 .36397 Mdot
.3277 .36943 Mdot
.57602 .25999 Mdot
.32887 .6969 Mdot
.46976 .59932 Mdot
.35541 .3826 Mdot
.32576 .38153 Mdot
.38244 .61705 Mdot
.35722 .33841 Mdot
.6601 .55855 Mdot
.44847 .58705 Mdot
.3487 .74116 Mdot
.56627 .40596 Mdot
.55252 .36355 Mdot
.52854 .33995 Mdot
.56824 .661 Mdot
.54376 .34714 Mdot
.50182 .38712 Mdot
.59472 .74587 Mdot
.5608 .48197 Mdot
.68052 .43306 Mdot
.34993 .40467 Mdot
.41571 .60372 Mdot
.58825 .69227 Mdot
.66906 .57669 Mdot
.69942 .46301 Mdot
.5824 .62135 Mdot
.66779 .4403 Mdot
.39272 .41707 Mdot
.46252 .50379 Mdot
.51189 .32901 Mdot
.63793 .48329 Mdot
.73339 .49258 Mdot
.35573 .38435 Mdot
.68983 .48501 Mdot
.7276 .48941 Mdot
.47635 .58127 Mdot
.50581 .77991 Mdot
.40765 .5918 Mdot
.77085 .3475 Mdot
.66953 .49246 Mdot
.61066 .34515 Mdot
.43965 .59001 Mdot
.51913 .34075 Mdot
.39647 .51558 Mdot
.4341 .62663 Mdot
.53465 .33947 Mdot
.36731 .60107 Mdot
.34255 .37003 Mdot
.54351 .61541 Mdot
.47762 .49063 Mdot
.53602 .86292 Mdot
.34999 .42406 Mdot
.68801 .36194 Mdot
.45818 .61579 Mdot
.82198 .55973 Mdot
.60871 .63635 Mdot
.37035 .62743 Mdot
.27943 .41229 Mdot
.62788 .65394 Mdot
.58445 .62589 Mdot
.38607 .60315 Mdot
.6722 .45259 Mdot
.53041 .3501 Mdot
.35637 .38823 Mdot
.8446 .46216 Mdot
.41787 .57969 Mdot
.41633 .55889 Mdot
.35647 .37829 Mdot
.68834 .48041 Mdot
.39116 .62452 Mdot
.36284 .24767 Mdot
.77036 .31166 Mdot
.6892 .44508 Mdot
.47445 .60329 Mdot
.44616 .77976 Mdot
.5199 .6458 Mdot
.78475 .69187 Mdot
.34352 .33814 Mdot
.52008 .369 Mdot
.33918 .57378 Mdot
.14758 .63019 Mdot
.36781 .39314 Mdot
.20664 .60598 Mdot
.37924 .6007 Mdot
.40595 .55477 Mdot
.57633 .61918 Mdot
.39429 .58679 Mdot
.62699 .6315 Mdot
.52846 .85602 Mdot
.23623 .38115 Mdot
.58518 .66744 Mdot
.56789 .61931 Mdot
.2641 .41862 Mdot
.58144 .26636 Mdot
.59074 .63777 Mdot
.38658 .55774 Mdot
.38793 .67848 Mdot
.46961 .53095 Mdot
.37212 .42144 Mdot
.47405 .2293 Mdot
.55828 .67784 Mdot
.35961 .43535 Mdot
.58479 .22011 Mdot
.58027 .69355 Mdot
.62362 .5314 Mdot
.64651 .45648 Mdot
.45437 .57083 Mdot
.53867 .33313 Mdot
.54813 .34302 Mdot
.35472 .59476 Mdot
.41183 .60823 Mdot
.62248 .67458 Mdot
.35551 .41173 Mdot
.64241 .45155 Mdot
.39838 .56094 Mdot
.27031 .3989 Mdot
.343 .41278 Mdot
.61431 .66397 Mdot
.33447 .72038 Mdot
.38185 .37243 Mdot
.49579 .61863 Mdot
.44873 .59838 Mdot
.39734 .60001 Mdot
.4919 .55383 Mdot
.64695 .46553 Mdot
.45598 .21719 Mdot
.45532 .56048 Mdot
.20226 .4492 Mdot
.62034 .44237 Mdot
.47039 .63205 Mdot
.59774 .66931 Mdot
.72093 .44734 Mdot
.47984 .33567 Mdot
.49959 .52079 Mdot
.41455 .57288 Mdot
.76659 .3772 Mdot
.75288 .679 Mdot
.52649 .31146 Mdot
.54607 .64234 Mdot
.35719 .40172 Mdot
.40832 .59847 Mdot
.37784 .73083 Mdot
.43341 .61978 Mdot
.39273 .40108 Mdot
.48707 .34964 Mdot
.64936 .4547 Mdot
.78253 .37239 Mdot
.54824 .34604 Mdot
.58197 .62897 Mdot
.35273 .17829 Mdot
.63174 .63603 Mdot
.55081 .62691 Mdot
.36523 .71865 Mdot
.64756 .46226 Mdot
.16887 .66733 Mdot
.59385 .81631 Mdot
.46352 .5569 Mdot
.68913 .4739 Mdot
.58759 .64535 Mdot
.40838 .54962 Mdot
.63121 .61994 Mdot
.55559 .65487 Mdot
.3894 .55265 Mdot
.42809 .55187 Mdot
.7635 .43469 Mdot
.50127 .1729 Mdot
.35593 .4027 Mdot
.60595 .67995 Mdot
.57661 .54675 Mdot
.41555 .54696 Mdot
.43911 .59824 Mdot
.61456 .40162 Mdot
.37172 .41714 Mdot
.76445 .53352 Mdot
.38085 .60338 Mdot
.24686 .36435 Mdot
.48021 .64135 Mdot
.62718 .68031 Mdot
.69506 .45051 Mdot
.18817 .50217 Mdot
.63356 .50594 Mdot
.62264 .62847 Mdot
.36205 .41154 Mdot
.53828 .64387 Mdot
.24795 .43128 Mdot
.6601 .4972 Mdot
.57026 .63517 Mdot
.58724 .46056 Mdot
.65863 .47305 Mdot
.65145 .49157 Mdot
.37101 .71454 Mdot
.55667 .33677 Mdot
.32546 .40732 Mdot
.67221 .48944 Mdot
.59754 .57215 Mdot
.67257 .4792 Mdot
.6326 .78203 Mdot
.47117 .59094 Mdot
.33644 .45863 Mdot
.48159 .29659 Mdot
.35404 .54243 Mdot
.66155 .49488 Mdot
.38002 .38662 Mdot
.38583 .61496 Mdot
.60549 .66004 Mdot
.33436 .39085 Mdot
.72435 .43668 Mdot
.50761 .37173 Mdot
.61283 .6729 Mdot
.65315 .50822 Mdot
.57482 .65617 Mdot
.54437 .556 Mdot
.7006 .75337 Mdot
.29252 .28493 Mdot
.51066 .50987 Mdot
.37325 .6017 Mdot
.52654 .21367 Mdot
.41354 .6473 Mdot
.40855 .61125 Mdot
.53454 .35628 Mdot
.31621 .44233 Mdot
.6 .64108 Mdot
.77259 .33265 Mdot
.63744 .47277 Mdot
.18323 .48937 Mdot
.4371 .67023 Mdot
.37105 .6149 Mdot
.63108 .65644 Mdot
.63078 .63213 Mdot
.44026 .73303 Mdot
.47744 .33706 Mdot
.41422 .64023 Mdot
.44753 .63647 Mdot
.3605 .58552 Mdot
.64336 .48003 Mdot
.32999 .32049 Mdot
.50102 .32801 Mdot
.75106 .71459 Mdot
.48789 .34289 Mdot
.30687 .40859 Mdot
.61739 .65429 Mdot
.34791 .41652 Mdot
.44073 .59695 Mdot
.63837 .69036 Mdot
.61504 .62141 Mdot
.38751 .40619 Mdot
.37273 .37525 Mdot
.65236 .38484 Mdot
.65729 .456 Mdot
.40617 .63452 Mdot
.45938 .58796 Mdot
.39108 .58155 Mdot
.39994 .60771 Mdot
.63801 .45881 Mdot
.39422 .62013 Mdot
.71665 .46183 Mdot
.53841 .57694 Mdot
.29388 .34092 Mdot
.5688 .47188 Mdot
.71423 .67387 Mdot
.61064 .6551 Mdot
.60834 .56757 Mdot
.50495 .58562 Mdot
.32407 .76822 Mdot
.7922 .5882 Mdot
.45981 .56041 Mdot
.53916 .37769 Mdot
.32555 .55582 Mdot
.52098 .32723 Mdot
.87644 .52873 Mdot
.64685 .34292 Mdot
.54151 .17896 Mdot
.45301 .57613 Mdot
.5723 .41549 Mdot
.624 .59272 Mdot
.39717 .64721 Mdot
.65635 .36142 Mdot
.71506 .65987 Mdot
.72355 .33627 Mdot
.38006 .40064 Mdot
.42678 .57041 Mdot
.58733 .69133 Mdot
.45895 .6003 Mdot
.4358 .60363 Mdot
.38254 .6141 Mdot
.70906 .45979 Mdot
.39757 .6381 Mdot
.40145 .61936 Mdot
.38384 .32427 Mdot
.25813 .54446 Mdot
.54938 .34016 Mdot
.70123 .73448 Mdot
.34472 .41618 Mdot
.62688 .6681 Mdot
.68406 .25435 Mdot
.66572 .45538 Mdot
.44648 .73112 Mdot
.3986 .60445 Mdot
.7607 .4136 Mdot
.72619 .45472 Mdot
.36954 .40222 Mdot
.48368 .3369 Mdot
.58874 .18257 Mdot
.52595 .35682 Mdot
.59062 .46109 Mdot
.51818 .34284 Mdot
.51162 .59836 Mdot
.62047 .67596 Mdot
.39849 .63081 Mdot
.66427 .48954 Mdot
.54015 .34813 Mdot
.28893 .47859 Mdot
.42208 .59898 Mdot
.51727 .35674 Mdot
.39919 .63094 Mdot
.44682 .49489 Mdot
.28066 .66033 Mdot
.50853 .3897 Mdot
.71502 .44447 Mdot
.65539 .4799 Mdot
.36361 .41991 Mdot
.62255 .66835 Mdot
.59599 .62017 Mdot
.66474 .46727 Mdot
.42094 .80702 Mdot
.46785 .60704 Mdot
.42143 .54766 Mdot
.18968 .47881 Mdot
.4546 .61468 Mdot
.24533 .48593 Mdot
.58624 .47043 Mdot
.61118 .6608 Mdot
.36309 .59531 Mdot
.38098 .59771 Mdot
.41617 .56941 Mdot
.52528 .55513 Mdot
.5168 .33426 Mdot
.45973 .57441 Mdot
.36676 .37164 Mdot
.45672 .40544 Mdot
.39398 .55633 Mdot
.38815 .65855 Mdot
.59213 .61977 Mdot
.20567 .64826 Mdot
.66522 .44618 Mdot
.5154 .38938 Mdot
.53358 .37006 Mdot
.48725 .23242 Mdot
.67121 .60622 Mdot
.58445 .46786 Mdot
.77422 .6887 Mdot
.58701 .29605 Mdot
.34292 .38293 Mdot
.53545 .30244 Mdot
.60054 .47993 Mdot
.52004 .38483 Mdot
.64498 .45254 Mdot
.46972 .58556 Mdot
.47031 .59767 Mdot
.31518 .77922 Mdot
.37819 .61419 Mdot
.35884 .39818 Mdot
.70498 .48168 Mdot
.60429 .65721 Mdot
.36802 .40358 Mdot
.68447 .4501 Mdot
.58725 .66597 Mdot
.46398 .56872 Mdot
.46363 .5701 Mdot
.58582 .62128 Mdot
.56726 .63477 Mdot
.4468 .59505 Mdot
.52487 .26637 Mdot
.56249 .62868 Mdot
.5721 .64296 Mdot
.50771 .32927 Mdot
.53638 .33292 Mdot
.45079 .64705 Mdot
.6866 .47301 Mdot
.3995 .61959 Mdot
.5283 .36324 Mdot
.35709 .41628 Mdot
.60312 .64319 Mdot
.37394 .59146 Mdot
.38896 .56564 Mdot
.35755 .38468 Mdot
.36998 .41126 Mdot
.37729 .38619 Mdot
.71093 .46937 Mdot
.39693 .57574 Mdot
.59494 .63349 Mdot
.65491 .45537 Mdot
.32391 .38565 Mdot
.37985 .41183 Mdot
.51161 .30383 Mdot
.44615 .62352 Mdot
.44551 .36174 Mdot
.12285 .58811 Mdot
.21196 .46705 Mdot
.50397 .31457 Mdot
.4889 .32198 Mdot
.27098 .51686 Mdot
.42252 .46009 Mdot
.67511 .46272 Mdot
.37116 .35429 Mdot
.26312 .38164 Mdot
.47964 .59698 Mdot
.42256 .53894 Mdot
.49222 .58946 Mdot
.37351 .38009 Mdot
.30225 .42215 Mdot
.63737 .64857 Mdot
.55539 .69648 Mdot
.33682 .4073 Mdot
.55475 .3475 Mdot
.53504 .3062 Mdot
.4868 .3447 Mdot
.46723 .57895 Mdot
.47911 .7503 Mdot
.63834 .58037 Mdot
.47949 .19723 Mdot
.67337 .49254 Mdot
.57866 .68886 Mdot
.81964 .55434 Mdot
.58644 .62312 Mdot
.47886 .36507 Mdot
.34633 .37652 Mdot
.5676 .64029 Mdot
.67118 .43849 Mdot
.67507 .48717 Mdot
.50051 .33502 Mdot
.49648 .34262 Mdot
.49845 .37316 Mdot
.54593 .63783 Mdot
.61882 .65313 Mdot
.41182 .57437 Mdot
.60705 .64643 Mdot
.28371 .74855 Mdot
.36023 .43021 Mdot
.47534 .39159 Mdot
.68037 .47142 Mdot
.58149 .66451 Mdot
.41929 .59755 Mdot
.42176 .4701 Mdot
.7437 .61286 Mdot
.34596 .37277 Mdot
.2614 .64788 Mdot
.87189 .53614 Mdot
.40896 .63527 Mdot
.64651 .47207 Mdot
.24189 .67478 Mdot
.42658 .59619 Mdot
.49422 .35769 Mdot
.55959 .25473 Mdot
.57797 .37167 Mdot
.4296 .62899 Mdot
.48162 .60647 Mdot
.68785 .44251 Mdot
.76758 .68688 Mdot
.4129 .57816 Mdot
.75302 .54412 Mdot
.62433 .45634 Mdot
.49686 .33027 Mdot
.73434 .25599 Mdot
.37056 .25676 Mdot
.32853 .48463 Mdot
.50146 .33087 Mdot
.41805 .61973 Mdot
.51977 .32946 Mdot
.35389 .36892 Mdot
.48762 .36956 Mdot
.63867 .64765 Mdot
.52137 .31282 Mdot
.417 .55826 Mdot
.58831 .63858 Mdot
.6764 .46646 Mdot
.18675 .54207 Mdot
.43791 .32651 Mdot
.51715 .34001 Mdot
.52122 .39257 Mdot
.36457 .59815 Mdot
.76595 .50475 Mdot
.34929 .60071 Mdot
.44316 .55925 Mdot
.63942 .48927 Mdot
.62798 .65879 Mdot
.70135 .45367 Mdot
.38733 .65117 Mdot
.35738 .24556 Mdot
.67861 .44923 Mdot
.75637 .37307 Mdot
.35108 .37826 Mdot
.49992 .44289 Mdot
.41478 .6005 Mdot
.6958 .47694 Mdot
.39829 .57637 Mdot
.6364 .65648 Mdot
.55935 .44196 Mdot
.71014 .33693 Mdot
.65356 .48733 Mdot
.7716 .37388 Mdot
.32039 .42918 Mdot
.35723 .64319 Mdot
.68415 .44597 Mdot
.28322 .41082 Mdot
.53804 .38458 Mdot
.33687 .40152 Mdot
.36261 .36305 Mdot
.3325 .39069 Mdot
.35796 .57018 Mdot
.40815 .66878 Mdot
.33302 .37497 Mdot
.65064 .44331 Mdot
.38428 .38185 Mdot
.67803 .65728 Mdot
.75991 .32505 Mdot
.34453 .39399 Mdot
.43063 .57868 Mdot
.5115 .62428 Mdot
.26488 .53916 Mdot
.69341 .38858 Mdot
.56218 .18289 Mdot
.78465 .55856 Mdot
.4417 .61729 Mdot
.5487 .61571 Mdot
.58571 .67452 Mdot
.22478 .64753 Mdot
.23349 .47989 Mdot
.21956 .4216 Mdot
.56052 .62124 Mdot
.66083 .31312 Mdot
.61479 .66696 Mdot
.37438 .60841 Mdot
.41564 .54812 Mdot
.56583 .61667 Mdot
.29371 .33266 Mdot
.68707 .33874 Mdot
.8102 .40957 Mdot
.57242 .65056 Mdot
.69259 .45428 Mdot
.67516 .49881 Mdot
.65155 .49245 Mdot
.21612 .59386 Mdot
.62915 .64287 Mdot
.38921 .57461 Mdot
.53407 .36648 Mdot
.46463 .5829 Mdot
.65537 .46993 Mdot
.77139 .32841 Mdot
.61811 .63621 Mdot
.44805 .57794 Mdot
.35939 .51373 Mdot
.49869 .35668 Mdot
.35073 .38292 Mdot
.42536 .49427 Mdot
.22002 .428 Mdot
.64007 .48066 Mdot
.59094 .61192 Mdot
.61916 .33355 Mdot
.74776 .33528 Mdot
.38582 .5381 Mdot
.4403 .64147 Mdot
.85226 .47655 Mdot
.25211 .37784 Mdot
.43988 .63249 Mdot
.52484 .38889 Mdot
.64326 .3204 Mdot
.38345 .57088 Mdot
.5929 .67791 Mdot
.37478 .36734 Mdot
.33874 .37905 Mdot
.43285 .6538 Mdot
.47096 .47983 Mdot
.56261 .42785 Mdot
.39036 .60154 Mdot
.49719 .61656 Mdot
.49769 .33079 Mdot
.57975 .28385 Mdot
.20433 .44285 Mdot
.36448 .41157 Mdot
.39732 .62954 Mdot
.63526 .25373 Mdot
.58861 .61615 Mdot
.51846 .31111 Mdot
.67695 .49385 Mdot
.50566 .54283 Mdot
.48256 .33935 Mdot
.37756 .57595 Mdot
.38717 .62056 Mdot
.70014 .47757 Mdot
.6289 .67948 Mdot
.37026 .3776 Mdot
.53831 .36569 Mdot
.37461 .40537 Mdot
.62819 .65098 Mdot
.61287 .64626 Mdot
.33764 .54098 Mdot
.41965 .52427 Mdot
.53108 .34198 Mdot
.36552 .6314 Mdot
.55937 .40516 Mdot
.81385 .64324 Mdot
.65268 .50551 Mdot
.42222 .63611 Mdot
.64309 .66799 Mdot
.6477 .48457 Mdot
.41532 .55089 Mdot
.84969 .4556 Mdot
.41288 .54645 Mdot
.62032 .44613 Mdot
.28297 .28652 Mdot
.3781 .39559 Mdot
.55034 .69143 Mdot
.79165 .48556 Mdot
.45454 .61107 Mdot
.52767 .37765 Mdot
.50096 .59608 Mdot
.67527 .45449 Mdot
.61593 .65247 Mdot
.79687 .68229 Mdot
.66896 .48107 Mdot
.45579 .59428 Mdot
.36709 .4025 Mdot
.6241 .62423 Mdot
.31129 .35655 Mdot
.35503 .33755 Mdot
.37561 .65905 Mdot
.3625 .62666 Mdot
.39408 .61014 Mdot
.40205 .22016 Mdot
.51247 .38797 Mdot
.58091 .64897 Mdot
.64536 .47315 Mdot
.66663 .46503 Mdot
.50455 .33477 Mdot
.74069 .47786 Mdot
.50376 .44342 Mdot
.13172 .5506 Mdot
.53366 .33662 Mdot
.33026 .40137 Mdot
.76264 .52541 Mdot
.53493 .37616 Mdot
.5133 .35394 Mdot
.50834 .32771 Mdot
.63119 .51947 Mdot
.58799 .66392 Mdot
.37968 .57157 Mdot
.60742 .68216 Mdot
.41548 .62038 Mdot
.62232 .44179 Mdot
.65809 .48972 Mdot
.62124 .64098 Mdot
.84274 .48125 Mdot
.49959 .79557 Mdot
.4299 .58862 Mdot
.82136 .55655 Mdot
.45364 .53989 Mdot
.26339 .4916 Mdot
.46675 .54595 Mdot
.50675 .34001 Mdot
.34198 .6086 Mdot
.35987 .58382 Mdot
.20119 .61452 Mdot
.68263 .47003 Mdot
.5501 .36824 Mdot
.47499 .56676 Mdot
.49886 .62198 Mdot
.54478 .6303 Mdot
.56886 .6419 Mdot
.35099 .3659 Mdot
.27635 .61656 Mdot
.67916 .465 Mdot
.59333 .8074 Mdot
.4455 .61321 Mdot
.31692 .30886 Mdot
.47672 .6861 Mdot
.4193 .55093 Mdot
.8004 .49034 Mdot
.47144 .74424 Mdot
.41025 .59918 Mdot
.56012 .52159 Mdot
.68662 .48075 Mdot
.34137 .25327 Mdot
.3992 .54991 Mdot
.49956 .36219 Mdot
.61922 .6586 Mdot
.63697 .63801 Mdot
.33897 .37111 Mdot
.36517 .79906 Mdot
.70395 .45883 Mdot
.61964 .64667 Mdot
.42373 .6043 Mdot
.64435 .46709 Mdot
.54516 .34639 Mdot
.37386 .61986 Mdot
.23227 .49302 Mdot
.60447 .65094 Mdot
.36794 .57637 Mdot
.73339 .55248 Mdot
.29127 .52548 Mdot
.34111 .21127 Mdot
.64402 .47382 Mdot
.3693 .41635 Mdot
.49956 .60025 Mdot
.40411 .7934 Mdot
.41366 .53245 Mdot
.35044 .46181 Mdot
.68131 .66091 Mdot
.3745 .41297 Mdot
.438 .5861 Mdot
.3944 .56774 Mdot
.42205 .426 Mdot
.36011 .41383 Mdot
.45797 .58149 Mdot
.54495 .59389 Mdot
.5844 .66031 Mdot
.49304 .38514 Mdot
.59956 .6589 Mdot
.42641 .58164 Mdot
.43252 .5251 Mdot
.57173 .62295 Mdot
.83124 .58913 Mdot
.3278 .42037 Mdot
.66642 .44703 Mdot
.43077 .53523 Mdot
.44702 .55336 Mdot
.19205 .3697 Mdot
.5388 .31626 Mdot
.59856 .26419 Mdot
.3729 .28997 Mdot
.60101 .23313 Mdot
.36831 .25763 Mdot
.44836 .1641 Mdot
.25224 .36771 Mdot
.38796 .63665 Mdot
.50081 .66113 Mdot
.61623 .55485 Mdot
.67118 .49422 Mdot
.6365 .75524 Mdot
.44353 .61729 Mdot
.43405 .60543 Mdot
.51187 .31072 Mdot
.75268 .38327 Mdot
.21844 .42155 Mdot
.43235 .46895 Mdot
.36896 .37777 Mdot
.60395 .67943 Mdot
.38174 .56601 Mdot
.56423 .50781 Mdot
.54916 .33784 Mdot
.3106 .31303 Mdot
.44623 .57847 Mdot
.31655 .75419 Mdot
.72629 .61925 Mdot
.65115 .46144 Mdot
.53275 .37265 Mdot
.23052 .40654 Mdot
.4427 .62495 Mdot
.67977 .49353 Mdot
.41555 .58436 Mdot
.5535 .28737 Mdot
.38049 .64867 Mdot
.34124 .39716 Mdot
.37814 .60172 Mdot
.30654 .41154 Mdot
.3052 .20178 Mdot
.38759 .36606 Mdot
.6293 .62004 Mdot
.49399 .40349 Mdot
.52137 .33545 Mdot
.56828 .63616 Mdot
.52397 .33764 Mdot
.4461 .71755 Mdot
.56566 .73198 Mdot
.3565 .37546 Mdot
.48833 .63034 Mdot
.34791 .39432 Mdot
.52667 .3105 Mdot
.43831 .62235 Mdot
.84562 .59521 Mdot
.53647 .3488 Mdot
.25322 .31852 Mdot
.67197 .47677 Mdot
.55374 .34485 Mdot
.40362 .54816 Mdot
.61685 .34591 Mdot
.54885 .3463 Mdot
.71652 .34852 Mdot
.41548 .56999 Mdot
.60946 .65183 Mdot
.38411 .57218 Mdot
.45377 .54723 Mdot
.54613 .39197 Mdot
.41194 .62485 Mdot
.68486 .45053 Mdot
.55468 .63236 Mdot
.64263 .20122 Mdot
.70295 .67139 Mdot
.46278 .59572 Mdot
.42486 .60215 Mdot
.54458 .6499 Mdot
.45625 .56746 Mdot
.63833 .45864 Mdot
.39616 .88243 Mdot
.35091 .37862 Mdot
.53911 .39082 Mdot
.36817 .25634 Mdot
.46403 .56631 Mdot
.3894 .61729 Mdot
.84395 .43333 Mdot
.34042 .26355 Mdot
.68447 .44739 Mdot
.36421 .5729 Mdot
.54697 .34748 Mdot
.36452 .40213 Mdot
.63891 .44949 Mdot
.39754 .59857 Mdot
.44006 .59354 Mdot
.36355 .41859 Mdot
.34322 .66517 Mdot
.2077 .54996 Mdot
.69559 .4819 Mdot
.34446 .57362 Mdot
.49226 .41 Mdot
.46005 .61836 Mdot
.22624 .61689 Mdot
.57183 .63619 Mdot
.63871 .48127 Mdot
.534 .22277 Mdot
.43376 .63185 Mdot
.69751 .45447 Mdot
.68044 .46561 Mdot
.37 .56475 Mdot
.64418 .66924 Mdot
.55428 .64669 Mdot
.57571 .65869 Mdot
.32034 .79827 Mdot
.31093 .48591 Mdot
.49836 .37298 Mdot
.68697 .48096 Mdot
.50702 .39058 Mdot
.37782 .42728 Mdot
.5895 .48633 Mdot
.51476 .39201 Mdot
.56936 .65826 Mdot
.48745 .398 Mdot
.40348 .56592 Mdot
.67563 .46529 Mdot
.51575 .38403 Mdot
.46749 .56257 Mdot
.76037 .49017 Mdot
.73631 .42956 Mdot
.38455 .39927 Mdot
.36713 .36267 Mdot
.40159 .55322 Mdot
.47516 .34241 Mdot
.44534 .59679 Mdot
.6324 .48574 Mdot
.76168 .50992 Mdot
.42616 .53565 Mdot
.51605 .33865 Mdot
.53271 .63068 Mdot
.22439 .41956 Mdot
.34635 .60519 Mdot
.43152 .57954 Mdot
.41657 .62322 Mdot
.41498 .58428 Mdot
.72089 .32127 Mdot
.63113 .49611 Mdot
.71334 .67273 Mdot
.43533 .21998 Mdot
.61168 .63154 Mdot
.58123 .68068 Mdot
.20715 .47453 Mdot
.65846 .55339 Mdot
.6871 .47457 Mdot
.40559 .60999 Mdot
.68421 .59652 Mdot
.76635 .30969 Mdot
.8611 .51253 Mdot
.41353 .42571 Mdot
.54777 .32837 Mdot
.5771 .61245 Mdot
.54491 .36424 Mdot
.42435 .62104 Mdot
.49723 .60117 Mdot
.42973 .15997 Mdot
.63893 .4448 Mdot
.35382 .37458 Mdot
.41188 .62018 Mdot
.31384 .48934 Mdot
.52567 .365 Mdot
.55522 .37604 Mdot
.45169 .56719 Mdot
.61481 .68585 Mdot
.24814 .28129 Mdot
.64672 .46678 Mdot
.78395 .55099 Mdot
.63191 .59763 Mdot
.76637 .59034 Mdot
.65252 .4691 Mdot
.40985 .37485 Mdot
.50617 .31441 Mdot
.39165 .69693 Mdot
.61068 .62903 Mdot
.33523 .38962 Mdot
.46769 .63281 Mdot
.58591 .61812 Mdot
.49275 .33164 Mdot
.61326 .652 Mdot
.38108 .61253 Mdot
.62162 .46753 Mdot
.52063 .37088 Mdot
.67873 .43294 Mdot
.63285 .681 Mdot
.3642 .41013 Mdot
.46461 .45962 Mdot
.58755 .77503 Mdot
.46788 .74146 Mdot
.46233 .57641 Mdot
.57127 .51198 Mdot
.38902 .57716 Mdot
.5679 .6698 Mdot
.41856 .59366 Mdot
.66456 .68312 Mdot
.5279 .37636 Mdot
.40642 .54402 Mdot
.3921 .60444 Mdot
.66954 .73936 Mdot
.44147 .57031 Mdot
.37936 .6374 Mdot
.40771 .60118 Mdot
.65858 .66426 Mdot
.48846 .63328 Mdot
.59626 .67029 Mdot
.40951 .35361 Mdot
.5105 .35227 Mdot
.37734 .37107 Mdot
.34973 .42226 Mdot
.32638 .45653 Mdot
.47965 .25312 Mdot
.75349 .39867 Mdot
.59529 .6566 Mdot
.68592 .45698 Mdot
.41582 .5904 Mdot
.45644 .18323 Mdot
.56703 .40797 Mdot
.54085 .32873 Mdot
.70441 .66993 Mdot
.3474 .55866 Mdot
.36055 .22783 Mdot
.36077 .59714 Mdot
.33286 .79538 Mdot
.40437 .52208 Mdot
.38021 .64741 Mdot
.52615 .39581 Mdot
.37914 .42975 Mdot
.44622 .55775 Mdot
.54679 .6276 Mdot
.34073 .40382 Mdot
.47437 .66474 Mdot
.44903 .38417 Mdot
.42038 .36137 Mdot
.63369 .73942 Mdot
.40395 .57697 Mdot
.51911 .37061 Mdot
.61354 .67356 Mdot
.20752 .4359 Mdot
.65497 .45461 Mdot
.66093 .42901 Mdot
.58629 .55059 Mdot
.83015 .5582 Mdot
.34271 .41308 Mdot
.35938 .69734 Mdot
.4142 .55832 Mdot
.47416 .29446 Mdot
.41811 .53613 Mdot
.76944 .32427 Mdot
.33638 .41317 Mdot
.56235 .65308 Mdot
.69294 .45647 Mdot
.59443 .67972 Mdot
.45934 .74621 Mdot
.56331 .33038 Mdot
.54354 .46899 Mdot
.52323 .3563 Mdot
.47055 .42466 Mdot
.58425 .64278 Mdot
.40112 .62982 Mdot
.12979 .54961 Mdot
.57156 .64056 Mdot
.61469 .61912 Mdot
.73395 .72023 Mdot
.82781 .62636 Mdot
.33792 .59795 Mdot
.56416 .62303 Mdot
.51962 .35214 Mdot
.35582 .40542 Mdot
.37756 .58368 Mdot
.40594 .5712 Mdot
.58474 .61878 Mdot
.54681 .38918 Mdot
.41916 .77636 Mdot
.49838 .3422 Mdot
.58451 .66374 Mdot
.50429 .35569 Mdot
.61041 .33919 Mdot
.52994 .38404 Mdot
.44821 .55477 Mdot
.41774 .59285 Mdot
.44193 .24707 Mdot
.61233 .64682 Mdot
.38944 .59984 Mdot
.36649 .60329 Mdot
.59429 .63566 Mdot
.36177 .34335 Mdot
.422 .7713 Mdot
.46231 .6091 Mdot
.42657 .56742 Mdot
.37367 .41298 Mdot
.59593 .51183 Mdot
.30569 .67772 Mdot
.3857 .61441 Mdot
.33287 .41584 Mdot
.54766 .62997 Mdot
.44897 .58902 Mdot
.71727 .27328 Mdot
.64528 .31974 Mdot
.42406 .63284 Mdot
.53927 .38313 Mdot
.3599 .58548 Mdot
.32614 .22232 Mdot
.4429 .55856 Mdot
.59286 .64268 Mdot
.62451 .65286 Mdot
.60104 .80421 Mdot
.58043 .63143 Mdot
.53541 .3313 Mdot
.65724 .47161 Mdot
.77295 .35352 Mdot
.54526 .34769 Mdot
.38247 .53573 Mdot
.60652 .81414 Mdot
.38182 .62757 Mdot
.45565 .55408 Mdot
.26993 .27616 Mdot
.54319 .3557 Mdot
.6332 .65512 Mdot
.43332 .45243 Mdot
.45529 .5311 Mdot
.64042 .48411 Mdot
.4702 .6339 Mdot
.47427 .59909 Mdot
.27662 .29203 Mdot
.67559 .29353 Mdot
.64985 .49831 Mdot
.4156 .64176 Mdot
.38626 .61514 Mdot
.5639 .35163 Mdot
.41996 .60141 Mdot
.35188 .4054 Mdot
.63045 .64854 Mdot
.53719 .3771 Mdot
.36141 .38469 Mdot
.44939 .61537 Mdot
.375 .38266 Mdot
.5074 .37697 Mdot
.66098 .49797 Mdot
.43038 .62369 Mdot
.3737 .42045 Mdot
.37301 .3813 Mdot
.38756 .58176 Mdot
.61543 .65518 Mdot
.39627 .52292 Mdot
.44834 .5745 Mdot
.37382 .59393 Mdot
.6004 .62094 Mdot
.85131 .3668 Mdot
.42467 .54731 Mdot
.35639 .45029 Mdot
.62006 .6246 Mdot
.44358 .40367 Mdot
.54577 .3698 Mdot
.47372 .5943 Mdot
.65452 .49786 Mdot
.69021 .48226 Mdot
.4896 .33526 Mdot
.61609 .61742 Mdot
.3777 .28009 Mdot
.53721 .64573 Mdot
.46305 .53886 Mdot
.44328 .63505 Mdot
.51345 .82363 Mdot
.53906 .17499 Mdot
.62969 .67147 Mdot
.46246 .32768 Mdot
.45498 .47497 Mdot
.69554 .47271 Mdot
.55539 .35041 Mdot
.58185 .61135 Mdot
.62904 .63469 Mdot
.60896 .66054 Mdot
.3387 .38151 Mdot
.4469 .24706 Mdot
.63836 .66741 Mdot
.59354 .68485 Mdot
.41235 .56818 Mdot
.387 .61429 Mdot
.23187 .42434 Mdot
.23606 .54709 Mdot
.38021 .38295 Mdot
.49096 .34081 Mdot
.27497 .77599 Mdot
.63104 .48173 Mdot
.69422 .7225 Mdot
.44063 .54233 Mdot
.11294 .60011 Mdot
.39218 .55607 Mdot
.42131 .60537 Mdot
.55463 .63114 Mdot
.38078 .41226 Mdot
.34628 .38887 Mdot
.57859 .64752 Mdot
.57779 .68068 Mdot
.35086 .40464 Mdot
.8053 .53057 Mdot
.73867 .28247 Mdot
.56299 .32067 Mdot
.60167 .63528 Mdot
.58828 .76624 Mdot
.69517 .48512 Mdot
.50355 .64709 Mdot
.62633 .47819 Mdot
.51958 .36068 Mdot
.48444 .33252 Mdot
.64337 .48329 Mdot
.41604 .5715 Mdot
.50103 .37832 Mdot
.39233 .63662 Mdot
.78 .59874 Mdot
.48146 .7721 Mdot
.39786 .25261 Mdot
.4094 .66217 Mdot
.41135 .36719 Mdot
.73774 .47002 Mdot
.45316 .60195 Mdot
.63915 .2418 Mdot
.36091 .37413 Mdot
.50445 .63643 Mdot
.63459 .47861 Mdot
.3072 .22667 Mdot
.43053 .62652 Mdot
.59618 .6437 Mdot
.68564 .46796 Mdot
.49022 .52009 Mdot
.75352 .53788 Mdot
.41578 .62184 Mdot
.13172 .59614 Mdot
.65578 .65454 Mdot
.53162 .37957 Mdot
.38931 .79596 Mdot
.62993 .67484 Mdot
.40287 .4356 Mdot
.477 .2218 Mdot
.84128 .50793 Mdot
.62598 .66969 Mdot
.54979 .32504 Mdot
.58259 .66834 Mdot
.36171 .41109 Mdot
.58048 .60745 Mdot
.5281 .36992 Mdot
.44263 .57844 Mdot
.5074 .33619 Mdot
.35836 .36532 Mdot
.21244 .55444 Mdot
.65338 .49895 Mdot
.54881 .37094 Mdot
.65987 .48641 Mdot
.28433 .55706 Mdot
.39527 .22661 Mdot
.65255 .45259 Mdot
.3394 .73109 Mdot
.45219 .62881 Mdot
.6276 .67899 Mdot
.51043 .33193 Mdot
.53401 .24373 Mdot
.45837 .46088 Mdot
.60121 .62557 Mdot
.49055 .35683 Mdot
.59363 .54828 Mdot
.35621 .76049 Mdot
.3562 .62248 Mdot
.27539 .58852 Mdot
.59808 .63293 Mdot
.53595 .31203 Mdot
.18754 .48483 Mdot
.57435 .66665 Mdot
.5309 .33442 Mdot
.69479 .45581 Mdot
.66268 .46421 Mdot
.45713 .57549 Mdot
.64986 .43616 Mdot
.48615 .35676 Mdot
.74068 .45594 Mdot
.56971 .61726 Mdot
.51087 .53948 Mdot
.36554 .42696 Mdot
.5059 .34674 Mdot
.37791 .61484 Mdot
.59399 .60276 Mdot
.62231 .31741 Mdot
.44468 .79017 Mdot
.19102 .63402 Mdot
.50431 .33501 Mdot
.62837 .63901 Mdot
.59929 .64471 Mdot
.34709 .59238 Mdot
.50516 .50646 Mdot
.38472 .27595 Mdot
.37825 .48647 Mdot
.406 .47317 Mdot
.48605 .37797 Mdot
.56959 .38438 Mdot
.47872 .57364 Mdot
.40571 .58169 Mdot
.69531 .46815 Mdot
.43922 .57613 Mdot
.558 .6341 Mdot
.4563 .57101 Mdot
.6472 .47436 Mdot
.52852 .35594 Mdot
.43479 .62158 Mdot
.37895 .39434 Mdot
.69053 .49182 Mdot
.68113 .43823 Mdot
.51043 .34219 Mdot
.58992 .61825 Mdot
.33202 .34204 Mdot
.49589 .34282 Mdot
.40484 .57682 Mdot
.61302 .51941 Mdot
.37259 .60297 Mdot
.55711 .6908 Mdot
.57412 .66721 Mdot
.53943 .37202 Mdot
.55996 .61935 Mdot
.66854 .48552 Mdot
.44616 .21819 Mdot
.42399 .58644 Mdot
.536 .3379 Mdot
.55778 .27352 Mdot
.45281 .68029 Mdot
.56953 .67907 Mdot
.74886 .42964 Mdot
.5757 .67727 Mdot
.49788 .32696 Mdot
.67522 .75616 Mdot
.33629 .40376 Mdot
.5422 .32964 Mdot
.61049 .19317 Mdot
.5295 .34386 Mdot
.43729 .56254 Mdot
.40184 .55436 Mdot
.5344 .37971 Mdot
.36359 .42023 Mdot
.22773 .39504 Mdot
.49005 .38822 Mdot
.63167 .65892 Mdot
.78425 .61477 Mdot
.16081 .54727 Mdot
.60927 .47899 Mdot
.69291 .46311 Mdot
.42964 .52023 Mdot
.37695 .64203 Mdot
.62914 .4653 Mdot
.67976 .4362 Mdot
.33944 .3753 Mdot
.51477 .32673 Mdot
.66162 .65853 Mdot
.71213 .44971 Mdot
.42842 .50786 Mdot
.46895 .25491 Mdot
.34968 .61613 Mdot
.63859 .59692 Mdot
.42312 .53862 Mdot
.37073 .46818 Mdot
.64584 .47436 Mdot
.36889 .58023 Mdot
.35402 .59263 Mdot
.64502 .49342 Mdot
.35411 .40714 Mdot
.6809 .52997 Mdot
.50812 .36276 Mdot
.76833 .28494 Mdot
.36518 .62345 Mdot
.43652 .55988 Mdot
.67005 .49337 Mdot
.38279 .31136 Mdot
.61949 .63529 Mdot
.58368 .67638 Mdot
.51503 .3886 Mdot
.48311 .47357 Mdot
.4712 .59724 Mdot
.45345 .59101 Mdot
.51297 .37118 Mdot
.55407 .3505 Mdot
.71966 .38919 Mdot
.39984 .5616 Mdot
.68209 .47347 Mdot
.30115 .39542 Mdot
.6455 .47627 Mdot
.37461 .60749 Mdot
.4301 .55707 Mdot
.44941 .55612 Mdot
.37863 .61481 Mdot
.65748 .43908 Mdot
.37626 .57128 Mdot
.50058 .6305 Mdot
.6205 .63208 Mdot
.403 .6186 Mdot
.40198 .47372 Mdot
.43102 .57422 Mdot
.3544 .40497 Mdot
.32339 .69362 Mdot
.43078 .62609 Mdot
.47138 .59014 Mdot
.51455 .40221 Mdot
.43486 .59053 Mdot
.63127 .4837 Mdot
.6113 .63997 Mdot
.68555 .48204 Mdot
.68735 .48621 Mdot
.47904 .34855 Mdot
.33416 .37431 Mdot
.46676 .57035 Mdot
.34755 .37302 Mdot
.38388 .53718 Mdot
.43231 .63275 Mdot
.46083 .22636 Mdot
.346 .80471 Mdot
.20953 .57896 Mdot
.42297 .58492 Mdot
.54081 .3528 Mdot
.54433 .37024 Mdot
.44232 .67422 Mdot
.3536 .61731 Mdot
.64079 .45335 Mdot
.69357 .47911 Mdot
.23591 .49775 Mdot
.30248 .27785 Mdot
.35423 .40558 Mdot
.57543 .49636 Mdot
.41768 .63967 Mdot
.36796 .59744 Mdot
.37389 .62303 Mdot
.50562 .38896 Mdot
.3905 .46175 Mdot
.54383 .33309 Mdot
.73292 .62436 Mdot
.64937 .48812 Mdot
.42307 .62605 Mdot
.67434 .62193 Mdot
.56859 .6466 Mdot
.61119 .6408 Mdot
.68076 .43911 Mdot
.54275 .40606 Mdot
.21796 .4592 Mdot
.86637 .53187 Mdot
.64975 .64236 Mdot
.38646 .39173 Mdot
.45628 .60242 Mdot
.52626 .35005 Mdot
.57695 .66308 Mdot
.38403 .38334 Mdot
.40532 .63202 Mdot
.44839 .24649 Mdot
.41947 .58056 Mdot
.62288 .56131 Mdot
.6159 .66405 Mdot
.76388 .31542 Mdot
.62998 .62473 Mdot
.69024 .49266 Mdot
.63616 .4734 Mdot
.41387 .55175 Mdot
.46024 .82309 Mdot
.60571 .68311 Mdot
.64366 .52012 Mdot
.33072 .40248 Mdot
.62848 .33176 Mdot
.35723 .4113 Mdot
.53081 .37799 Mdot
.34135 .40702 Mdot
.52812 .37252 Mdot
.22477 .5255 Mdot
.65417 .68865 Mdot
.35826 .37975 Mdot
.54002 .27816 Mdot
.35672 .63054 Mdot
.38215 .39051 Mdot
.48034 .56091 Mdot
.54136 .68334 Mdot
.50905 .36924 Mdot
.34087 .41407 Mdot
.39799 .62876 Mdot
.42521 .17252 Mdot
.67963 .44573 Mdot
.63641 .45748 Mdot
.47155 .54861 Mdot
.47942 .36444 Mdot
.55229 .62153 Mdot
.73322 .31286 Mdot
.69712 .4928 Mdot
.41917 .54841 Mdot
.44972 .5614 Mdot
.58347 .68152 Mdot
.68218 .68016 Mdot
.41976 .5534 Mdot
.35468 .52267 Mdot
.40098 .55932 Mdot
.68452 .44297 Mdot
.597 .6799 Mdot
.60428 .64303 Mdot
.49161 .36177 Mdot
.56584 .62858 Mdot
.39966 .67932 Mdot
.6863 .61961 Mdot
.35401 .53639 Mdot
.66629 .48198 Mdot
.7137 .62685 Mdot
.73198 .62834 Mdot
.56231 .18518 Mdot
.60397 .68877 Mdot
.41429 .53762 Mdot
.5879 .61591 Mdot
.36263 .40406 Mdot
.60751 .65161 Mdot
.57473 .61321 Mdot
.44756 .59925 Mdot
.41788 .61946 Mdot
.53464 .36269 Mdot
.48943 .4949 Mdot
.60439 .61925 Mdot
.38922 .55986 Mdot
.38356 .64522 Mdot
.37957 .63116 Mdot
.58969 .42576 Mdot
.62332 .67705 Mdot
.77545 .67019 Mdot
.27533 .42837 Mdot
.60235 .61889 Mdot
.26212 .26193 Mdot
.57585 .27745 Mdot
.50062 .31107 Mdot
.71039 .43832 Mdot
.39611 .56288 Mdot
.55117 .35395 Mdot
.42518 .62127 Mdot
.63753 .59533 Mdot
.4378 .59785 Mdot
.34955 .40584 Mdot
.3864 .63628 Mdot
.4878 .33257 Mdot
.49904 .33947 Mdot
.43191 .55123 Mdot
.43551 .61888 Mdot
.21045 .5287 Mdot
.61406 .69235 Mdot
.61709 .64395 Mdot
.36616 .29085 Mdot
.36995 .38558 Mdot
.63955 .48231 Mdot
.41351 .59874 Mdot
.48117 .36055 Mdot
.50117 .3377 Mdot
.62357 .67855 Mdot
.4958 .35891 Mdot
.64753 .46677 Mdot
.42363 .59047 Mdot
.63002 .46433 Mdot
.3379 .38114 Mdot
.60772 .67994 Mdot
.40885 .62031 Mdot
.41279 .5681 Mdot
.62464 .65317 Mdot
.47596 .57467 Mdot
.3716 .41415 Mdot
.52802 .34138 Mdot
.61998 .6741 Mdot
.65856 .46966 Mdot
.5312 .37588 Mdot
.37324 .58754 Mdot
.23718 .72722 Mdot
.43501 .56358 Mdot
.38846 .56744 Mdot
.60045 .18251 Mdot
.40046 .63961 Mdot
.50658 .33297 Mdot
.5654 .657 Mdot
.4175 .65987 Mdot
.31101 .45323 Mdot
.87575 .43872 Mdot
.53941 .3284 Mdot
.45827 .59865 Mdot
.4807 .17508 Mdot
.4563 .58811 Mdot
.52412 .81379 Mdot
.53523 .29116 Mdot
.46144 .4328 Mdot
.43473 .53192 Mdot
.66589 .4559 Mdot
.53703 .36148 Mdot
.52482 .37691 Mdot
.7592 .66067 Mdot
.44996 .59628 Mdot
.60071 .53779 Mdot
.40383 .62636 Mdot
.65623 .46627 Mdot
.24189 .46641 Mdot
.50009 .33665 Mdot
.21554 .64058 Mdot
.39092 .57432 Mdot
.63707 .64649 Mdot
.48429 .39636 Mdot
.60016 .37797 Mdot
.37441 .59184 Mdot
.35857 .37055 Mdot
.71384 .46203 Mdot
.4069 .65518 Mdot
.66196 .47914 Mdot
.3739 .59729 Mdot
.32764 .55498 Mdot
.39337 .80509 Mdot
.61273 .65809 Mdot
.69423 .45831 Mdot
.60668 .50128 Mdot
.38443 .55698 Mdot
.62425 .67095 Mdot
.60881 .6279 Mdot
.34601 .37141 Mdot
.56731 .45762 Mdot
.72279 .54673 Mdot
.52166 .78774 Mdot
.77631 .6374 Mdot
.49985 .40375 Mdot
.69532 .32896 Mdot
.38084 .59067 Mdot
.32837 .30181 Mdot
.63855 .49228 Mdot
.44166 .56658 Mdot
.43414 .69804 Mdot
.57455 .65008 Mdot
.4239 .56338 Mdot
.34839 .39632 Mdot
.34005 .3135 Mdot
.31606 .31509 Mdot
.48578 .21378 Mdot
.52199 .35721 Mdot
.4982 .60166 Mdot
.3215 .58624 Mdot
.53159 .39136 Mdot
.47651 .60281 Mdot
.52643 .335 Mdot
.81614 .54399 Mdot
.38428 .39543 Mdot
.63109 .6669 Mdot
.5999 .33213 Mdot
.47307 .58365 Mdot
.44746 .63457 Mdot
.35658 .35963 Mdot
.40191 .58382 Mdot
.35372 .78986 Mdot
.59514 .34332 Mdot
.51423 .38499 Mdot
.60989 .65992 Mdot
.46786 .57971 Mdot
.57746 .46181 Mdot
.45042 .57804 Mdot
.54649 .74379 Mdot
.47032 .58716 Mdot
.73947 .53922 Mdot
.61878 .65797 Mdot
.66012 .48177 Mdot
.38406 .55476 Mdot
.43271 .60245 Mdot
.2902 .3959 Mdot
.41042 .52219 Mdot
.37504 .56932 Mdot
.54119 .6403 Mdot
.5758 .66389 Mdot
.59461 .66888 Mdot
.5162 .31371 Mdot
.2885 .28518 Mdot
.67913 .48 Mdot
.46035 .64959 Mdot
.70642 .44804 Mdot
.42628 .79495 Mdot
.38573 .38995 Mdot
.49998 .19451 Mdot
.39917 .60368 Mdot
.59037 .65986 Mdot
.64702 .2649 Mdot
.54547 .63709 Mdot
.55965 .49473 Mdot
.67863 .46498 Mdot
.57464 .64402 Mdot
.42624 .60592 Mdot
.45562 .46796 Mdot
.42783 .19307 Mdot
.67419 .48791 Mdot
.37589 .54124 Mdot
.53856 .31695 Mdot
.40131 .24279 Mdot
.22019 .69956 Mdot
.6812 .44537 Mdot
.61821 .45208 Mdot
.45146 .59701 Mdot
.56731 .64788 Mdot
.65932 .45833 Mdot
.66403 .44585 Mdot
.49611 .3613 Mdot
.41401 .61815 Mdot
.40907 .61574 Mdot
.50187 .32233 Mdot
.6825 .48588 Mdot
.45012 .53502 Mdot
.37921 .64843 Mdot
.40296 .16144 Mdot
.55314 .54436 Mdot
.78556 .29548 Mdot
.39713 .67707 Mdot
.40618 .70604 Mdot
.7487 .32031 Mdot
.6269 .63033 Mdot
.43793 .6261 Mdot
.4337 .64757 Mdot
.48592 .35526 Mdot
.43352 .58274 Mdot
.51908 .29903 Mdot
.68966 .46781 Mdot
.29343 .24441 Mdot
.71273 .5978 Mdot
.82552 .51578 Mdot
.43558 .58367 Mdot
.6614 .70153 Mdot
.36098 .39314 Mdot
.6323 .50015 Mdot
.59651 .67424 Mdot
.38493 .62194 Mdot
.20994 .53176 Mdot
.54336 .33156 Mdot
.58168 .62357 Mdot
.20841 .4392 Mdot
.41388 .37447 Mdot
.37571 .60768 Mdot
.53358 .31752 Mdot
.6579 .25958 Mdot
.45936 .51634 Mdot
.66721 .50656 Mdot
.35197 .40791 Mdot
.53942 .36352 Mdot
.69214 .4825 Mdot
.64764 .62712 Mdot
.57655 .63726 Mdot
.55429 .61591 Mdot
.23844 .62084 Mdot
.53997 .38857 Mdot
.359 .38945 Mdot
.32048 .27077 Mdot
.29078 .3162 Mdot
.34806 .40376 Mdot
.48622 .32988 Mdot
.57643 .66378 Mdot
.58213 .6519 Mdot
.61091 .63938 Mdot
.20363 .59909 Mdot
.62967 .62905 Mdot
.71614 .7037 Mdot
.38559 .63064 Mdot
.34576 .53688 Mdot
.45747 .59559 Mdot
.63441 .45779 Mdot
.62233 .66369 Mdot
.46233 .45344 Mdot
.36314 .5662 Mdot
.42639 .20837 Mdot
.4487 .56904 Mdot
.62083 .48295 Mdot
.4147 .56234 Mdot
.64917 .74252 Mdot
.59747 .61643 Mdot
.4269 .58372 Mdot
.63294 .49354 Mdot
.37346 .39273 Mdot
.55345 .66563 Mdot
.41626 .62296 Mdot
.75761 .41945 Mdot
.39435 .63854 Mdot
.81712 .49447 Mdot
.52909 .5504 Mdot
.38643 .39214 Mdot
.58907 .57814 Mdot
.55755 .34628 Mdot
.33744 .54808 Mdot
.47633 .54512 Mdot
.66505 .48874 Mdot
.60557 .31484 Mdot
.51224 .35193 Mdot
.40864 .43429 Mdot
.47798 .63189 Mdot
.36528 .36518 Mdot
.59561 .69057 Mdot
.6283 .46183 Mdot
.47304 .61371 Mdot
.34941 .59673 Mdot
.75178 .63949 Mdot
.49537 .62268 Mdot
.45578 .5682 Mdot
.37273 .36276 Mdot
.71306 .69499 Mdot
.42643 .57322 Mdot
.56477 .49234 Mdot
.59362 .60829 Mdot
.4425 .52977 Mdot
.70454 .71898 Mdot
.40132 .55367 Mdot
.57375 .62923 Mdot
.5803 .68884 Mdot
.67634 .54699 Mdot
.3296 .38656 Mdot
.47309 .59476 Mdot
.60572 .80209 Mdot
.39528 .57519 Mdot
.67865 .47502 Mdot
.37137 .63389 Mdot
.52663 .36742 Mdot
.20055 .56609 Mdot
.49298 .36867 Mdot
.46697 .60329 Mdot
.60827 .63677 Mdot
.65792 .49348 Mdot
.23652 .64771 Mdot
.42258 .26334 Mdot
.70101 .70815 Mdot
.84562 .46891 Mdot
.34902 .41635 Mdot
.32708 .38 Mdot
.62673 .46279 Mdot
.42627 .58216 Mdot
.7026 .74516 Mdot
.40803 .52083 Mdot
.42455 .56677 Mdot
.43806 .59935 Mdot
.37488 .23986 Mdot
.69308 .47357 Mdot
.50129 .35926 Mdot
.42407 .55471 Mdot
.37567 .57076 Mdot
.62582 .63001 Mdot
.37391 .3858 Mdot
.54565 .36956 Mdot
.35286 .37661 Mdot
.53409 .35531 Mdot
.27565 .25256 Mdot
.36278 .57958 Mdot
.37141 .39464 Mdot
.71856 .45961 Mdot
.58995 .61934 Mdot
.6825 .6112 Mdot
.5277 .37818 Mdot
.48808 .34409 Mdot
.43908 .55728 Mdot
.57161 .6304 Mdot
.55638 .62474 Mdot
.36432 .40497 Mdot
.6475 .45764 Mdot
.43224 .6253 Mdot
.43398 .63346 Mdot
.62569 .71213 Mdot
.48214 .36723 Mdot
.61808 .56539 Mdot
.73352 .35524 Mdot
.4233 .58273 Mdot
.56547 .62049 Mdot
.43977 .61104 Mdot
.76296 .35826 Mdot
.56541 .64008 Mdot
.39998 .55262 Mdot
.22026 .37234 Mdot
.5442 .40662 Mdot
.6905 .55853 Mdot
.44279 .5522 Mdot
.81219 .38768 Mdot
.38589 .60019 Mdot
.34207 .18189 Mdot
.49185 .27307 Mdot
.45943 .6198 Mdot
.37708 .58014 Mdot
.45363 .77627 Mdot
.45444 .61368 Mdot
.49627 .32747 Mdot
.25057 .38124 Mdot
.5467 .6251 Mdot
.75833 .45856 Mdot
.33555 .69563 Mdot
.33742 .41367 Mdot
.51625 .38882 Mdot
.57513 .36149 Mdot
.34263 .39359 Mdot
.59916 .63638 Mdot
.41478 .58445 Mdot
.50805 .4702 Mdot
.49699 .38696 Mdot
.40402 .67167 Mdot
.67741 .47295 Mdot
.67089 .35409 Mdot
.58374 .37454 Mdot
.65568 .47565 Mdot
.39841 .61655 Mdot
.44004 .77601 Mdot
.26248 .62416 Mdot
.72465 .26342 Mdot
.69132 .48482 Mdot
.67087 .49012 Mdot
.19573 .57576 Mdot
.37171 .42742 Mdot
.77198 .61764 Mdot
.74766 .5364 Mdot
.64296 .4873 Mdot
.4876 .52798 Mdot
.52816 .32428 Mdot
.73864 .48606 Mdot
.5012 .63882 Mdot
.414 .63684 Mdot
.42821 .60473 Mdot
.64258 .46216 Mdot
.45575 .67821 Mdot
.37376 .78795 Mdot
.65719 .48611 Mdot
.51674 .61226 Mdot
.53681 .44156 Mdot
.56415 .26359 Mdot
.49699 .33217 Mdot
.33157 .38198 Mdot
.31565 .39592 Mdot
.635 .6455 Mdot
.33262 .37803 Mdot
.33773 .30978 Mdot
.40307 .59033 Mdot
.64826 .48137 Mdot
.62323 .32163 Mdot
.66342 .46782 Mdot
.34387 .39082 Mdot
.38596 .37844 Mdot
.62052 .63234 Mdot
.61452 .64745 Mdot
.40912 .71628 Mdot
.25679 .49496 Mdot
.45317 .57673 Mdot
.54395 .22749 Mdot
.56412 .61854 Mdot
.39129 .6708 Mdot
.33688 .37124 Mdot
.37259 .38828 Mdot
.30553 .42103 Mdot
.40628 .60516 Mdot
.56497 .80911 Mdot
.40998 .60297 Mdot
.24486 .4727 Mdot
.4334 .54076 Mdot
.49576 .36015 Mdot
.40306 .6092 Mdot
.28977 .36024 Mdot
.48083 .60028 Mdot
.37129 .63851 Mdot
.49335 .38038 Mdot
.415 .65596 Mdot
.52452 .36712 Mdot
.46592 .59427 Mdot
.35032 .42578 Mdot
.49517 .37809 Mdot
.3122 .47448 Mdot
.3208 .43243 Mdot
.49121 .32456 Mdot
.35827 .36648 Mdot
.34516 .42026 Mdot
.33187 .48901 Mdot
.596 .67438 Mdot
.52212 .62967 Mdot
.42939 .58111 Mdot
.55792 .36431 Mdot
.69368 .46897 Mdot
.38265 .56603 Mdot
.39948 .64756 Mdot
.42496 .54323 Mdot
.63609 .64802 Mdot
.38967 .27066 Mdot
.36915 .40059 Mdot
.51543 .31644 Mdot
.34151 .33988 Mdot
.47493 .35251 Mdot
.35962 .62691 Mdot
.45253 .63979 Mdot
.3785 .70207 Mdot
.62293 .28079 Mdot
.18793 .58149 Mdot
.57643 .63476 Mdot
.54104 .38092 Mdot
.35866 .4276 Mdot
.34831 .62891 Mdot
.58556 .66136 Mdot
.52758 .36958 Mdot
.41932 .58139 Mdot
.37084 .54514 Mdot
.71088 .64904 Mdot
.32199 .65493 Mdot
.34446 .45742 Mdot
.48956 .33448 Mdot
.55373 .33501 Mdot
.30537 .31177 Mdot
.40585 .40009 Mdot
.46024 .45921 Mdot
.44716 .58563 Mdot
.35624 .37107 Mdot
.57663 .66261 Mdot
.25035 .6266 Mdot
.63801 .46278 Mdot
.49669 .50032 Mdot
.43404 .58459 Mdot
.44549 .41523 Mdot
.60947 .63567 Mdot
.35038 .39921 Mdot
.64126 .46413 Mdot
.34033 .36097 Mdot
.52213 .39299 Mdot
.84152 .55221 Mdot
.39771 .57784 Mdot
.4475 .56362 Mdot
.67289 .49937 Mdot
.57608 .65618 Mdot
.34827 .3608 Mdot
.78539 .59393 Mdot
.51371 .37959 Mdot
.68603 .75862 Mdot
.56178 .62945 Mdot
.61839 .74317 Mdot
.51711 .31845 Mdot
.68216 .43971 Mdot
.31786 .49292 Mdot
.64838 .47204 Mdot
.46902 .59472 Mdot
.59769 .65243 Mdot
.68815 .45466 Mdot
.4965 .50752 Mdot
.46426 .17664 Mdot
.6002 .75912 Mdot
.40855 .59297 Mdot
.37742 .19245 Mdot
.79567 .46726 Mdot
.63184 .68882 Mdot
.65807 .49877 Mdot
.4465 .56884 Mdot
.46503 .61848 Mdot
.39727 .57284 Mdot
.6827 .458 Mdot
.50789 .23625 Mdot
.51074 .37213 Mdot
.45459 .59655 Mdot
.33995 .37536 Mdot
.5183 .36246 Mdot
.60061 .33958 Mdot
.49595 .33658 Mdot
.6222 .68871 Mdot
.37302 .63593 Mdot
.61797 .50005 Mdot
.27643 .22602 Mdot
.68206 .48409 Mdot
.4819 .33334 Mdot
.36415 .60363 Mdot
.62339 .30624 Mdot
.59196 .66711 Mdot
.50952 .3786 Mdot
.43754 .56059 Mdot
.59692 .32288 Mdot
.21153 .56508 Mdot
.49738 .33627 Mdot
.58148 .66165 Mdot
.692 .25067 Mdot
.43716 .57851 Mdot
.38702 .59318 Mdot
.57948 .64479 Mdot
.35901 .7408 Mdot
.19199 .47469 Mdot
.43735 .61597 Mdot
.65796 .4815 Mdot
.78896 .68286 Mdot
.36899 .63962 Mdot
.26578 .42329 Mdot
.5364 .3636 Mdot
.70609 .51579 Mdot
.6024 .55493 Mdot
.34712 .62741 Mdot
.77905 .59796 Mdot
.63394 .43085 Mdot
.36249 .21682 Mdot
.51443 .29884 Mdot
.43416 .348 Mdot
.33421 .21902 Mdot
.62476 .48378 Mdot
.64067 .70183 Mdot
.78795 .54398 Mdot
.25268 .70068 Mdot
.69619 .26306 Mdot
.40296 .33089 Mdot
.20832 .52746 Mdot
.50708 .45721 Mdot
.53514 .34928 Mdot
.32963 .35479 Mdot
.42316 .62289 Mdot
.79512 .4626 Mdot
.58671 .79857 Mdot
.47619 .83205 Mdot
.38277 .18874 Mdot
.51516 .80913 Mdot
.4607 .18382 Mdot
.57509 .18425 Mdot
.38643 .69068 Mdot
.632 .27669 Mdot
.68359 .7652 Mdot
.24139 .35147 Mdot
.7907 .63112 Mdot
.35919 .53044 Mdot
.56445 .50762 Mdot
.83016 .47671 Mdot
.64343 .7308 Mdot
.37148 .77734 Mdot
.49476 .36735 Mdot
.5709 .66649 Mdot
.78443 .53411 Mdot
.57084 .67551 Mdot
.6436 .55035 Mdot
.69752 .24855 Mdot
.48327 .16993 Mdot
.65838 .74066 Mdot
.78725 .34239 Mdot
.45197 .69813 Mdot
.5182 .87198 Mdot
.49268 .38741 Mdot
.6337 .67005 Mdot
.38401 .4404 Mdot
.30111 .30902 Mdot
.7495 .60557 Mdot
.79515 .5169 Mdot
.44212 .23152 Mdot
.27745 .52764 Mdot
.59739 .6426 Mdot
.57816 .57175 Mdot
.67434 .52221 Mdot
.71651 .60292 Mdot
.24427 .38819 Mdot
.61596 .20932 Mdot
.51506 .48092 Mdot
.75742 .44446 Mdot
.68537 .34432 Mdot
.21704 .69019 Mdot
.28505 .42729 Mdot
.35639 .65683 Mdot
.63035 .54831 Mdot
.75566 .33076 Mdot
.28106 .71745 Mdot
.24842 .51443 Mdot
.2981 .31132 Mdot
.24035 .31864 Mdot
.7932 .40681 Mdot
.16258 .43088 Mdot
.54042 .61788 Mdot
.45293 .5641 Mdot
.37242 .73315 Mdot
.61837 .79437 Mdot
.38947 .38856 Mdot
.50203 .22037 Mdot
.33297 .40315 Mdot
.64452 .6467 Mdot
.20056 .53649 Mdot
.70519 .71338 Mdot
.61941 .79928 Mdot
.31969 .40231 Mdot
.40225 .6618 Mdot
.87616 .59966 Mdot
.39476 .2099 Mdot
.68866 .58015 Mdot
.38645 .1665 Mdot
.44095 .43208 Mdot
.4991 .52937 Mdot
.68818 .45647 Mdot
.33249 .21255 Mdot
.58755 .652 Mdot
.17146 .38355 Mdot
.33072 .19405 Mdot
.30851 .67457 Mdot
.77843 .23884 Mdot
.32362 .28627 Mdot
.45599 .43017 Mdot
.66494 .41883 Mdot
.2927 .46163 Mdot
.33599 .76056 Mdot
.30601 .59623 Mdot
.63841 .31366 Mdot
.84562 .44591 Mdot
.35755 .21065 Mdot
.64756 .77893 Mdot
.82808 .57781 Mdot
.27005 .72136 Mdot
.58178 .47475 Mdot
.48998 .65261 Mdot
.58281 .35103 Mdot
.59996 .21568 Mdot
.25332 .28303 Mdot
.2763 .42265 Mdot
.88176 .45161 Mdot
.39631 .37439 Mdot
.46245 .27029 Mdot
.69414 .2341 Mdot
.28726 .52528 Mdot
.5632 .5619 Mdot
.2607 .36404 Mdot
.37502 .66041 Mdot
.32786 .33285 Mdot
.53563 .21463 Mdot
.65428 .57256 Mdot
.25228 .34792 Mdot
.69671 .28027 Mdot
.74942 .64066 Mdot
.49418 .77118 Mdot
.28511 .31241 Mdot
.54561 .64333 Mdot
.26492 .5226 Mdot
.5599 .5553 Mdot
.47079 .16721 Mdot
.62598 .44429 Mdot
.51632 .15464 Mdot
.19496 .47668 Mdot
.38889 .54217 Mdot
.45951 .53039 Mdot
.53904 .60235 Mdot
.26557 .49757 Mdot
.39254 .65648 Mdot
.7276 .6403 Mdot
.53565 .17081 Mdot
.47288 .68616 Mdot
.6738 .53001 Mdot
.60004 .31024 Mdot
.70999 .2446 Mdot
.40201 .73384 Mdot
.40647 .40641 Mdot
.23272 .44099 Mdot
.2507 .71959 Mdot
.50836 .35385 Mdot
.65843 .76727 Mdot
.66723 .50709 Mdot
.22324 .58836 Mdot
.52266 .79036 Mdot
.31037 .7003 Mdot
.53702 .17079 Mdot
.40767 .35071 Mdot
.19887 .50746 Mdot
.2889 .56126 Mdot
.73949 .71853 Mdot
.57046 .26408 Mdot
.46848 .63441 Mdot
.77942 .46901 Mdot
.36337 .42079 Mdot
.44671 .74043 Mdot
.78204 .67283 Mdot
.4063 .30278 Mdot
.49096 .59318 Mdot
.28671 .66037 Mdot
.50164 .41594 Mdot
.45998 .47054 Mdot
.15192 .55895 Mdot
.35341 .62398 Mdot
.31242 .27695 Mdot
.7998 .42523 Mdot
.27675 .46094 Mdot
.74798 .2974 Mdot
.74018 .33315 Mdot
.17906 .3926 Mdot
.36836 .18221 Mdot
.40993 .26754 Mdot
.32542 .23054 Mdot
.44199 .16067 Mdot
.17537 .4147 Mdot
.48184 .54826 Mdot
.67966 .4983 Mdot
.19675 .69436 Mdot
.50199 .32666 Mdot
.35174 .24599 Mdot
.77545 .63874 Mdot
.59138 .38068 Mdot
.66344 .65816 Mdot
.32215 .6169 Mdot
.51499 .46287 Mdot
.63684 .68478 Mdot
.4082 .65734 Mdot
.16278 .53429 Mdot
.20489 .36293 Mdot
.16358 .478 Mdot
.80771 .40683 Mdot
.30604 .24167 Mdot
.48404 .43301 Mdot
.66904 .7267 Mdot
.44636 .67235 Mdot
.39517 .63191 Mdot
.396 .44633 Mdot
.32616 .284 Mdot
.28443 .66357 Mdot
.75177 .58132 Mdot
.60753 .69276 Mdot
.51773 .21781 Mdot
.5716 .89935 Mdot
.44398 .71183 Mdot
.72234 .71018 Mdot
.31004 .31452 Mdot
.26028 .48367 Mdot
.58655 .21908 Mdot
.30927 .68695 Mdot
.59288 .18409 Mdot
.6463 .67654 Mdot
.7889 .62674 Mdot
.41881 .32378 Mdot
.41755 .48605 Mdot
.39608 .26474 Mdot
.5012 .1781 Mdot
.63465 .40593 Mdot
.26401 .66452 Mdot
.76371 .52593 Mdot
.33148 .73175 Mdot
.51489 .28483 Mdot
.68183 .35849 Mdot
.77015 .68304 Mdot
.69794 .31577 Mdot
.25383 .45302 Mdot
.54507 .44673 Mdot
.60804 .5886 Mdot
.63831 .42863 Mdot
.25841 .45081 Mdot
.39332 .47638 Mdot
.31268 .25311 Mdot
.25682 .21705 Mdot
.18778 .61071 Mdot
.76912 .29085 Mdot
.56198 .22391 Mdot
.4885 .59526 Mdot
.63929 .19336 Mdot
.15431 .46969 Mdot
.31326 .19437 Mdot
.6766 .38076 Mdot
.50916 .29723 Mdot
.69247 .4408 Mdot
.17211 .52681 Mdot
.49494 .24248 Mdot
.63252 .20117 Mdot
.26928 .35599 Mdot
.69736 .43937 Mdot
.35841 .81352 Mdot
.23942 .3299 Mdot
.5512 .78419 Mdot
.32442 .65716 Mdot
.45719 .54618 Mdot
.63431 .75653 Mdot
.57596 .67842 Mdot
.7003 .33657 Mdot
.25577 .50884 Mdot
.50396 .34379 Mdot
.38454 .44944 Mdot
.79394 .50204 Mdot
.38744 .63646 Mdot
.60198 .49798 Mdot
.60059 .68673 Mdot
.62751 .28155 Mdot
.69868 .62185 Mdot
.24605 .28272 Mdot
.36354 .26306 Mdot
.42227 .53199 Mdot
.27579 .45449 Mdot
.38662 .26702 Mdot
.18724 .48366 Mdot
.62792 .45465 Mdot
.4072 .17955 Mdot
.54557 .50742 Mdot
.26344 .52075 Mdot
.61331 .77517 Mdot
.54439 .68257 Mdot
.43513 .64146 Mdot
.7051 .30781 Mdot
.53481 .73289 Mdot
.47754 .48625 Mdot
.48577 .64846 Mdot
.50817 .65197 Mdot
.6553 .19709 Mdot
.33974 .31643 Mdot
.67267 .34527 Mdot
.43586 .17294 Mdot
.67241 .45944 Mdot
.58071 .61632 Mdot
.31117 .38429 Mdot
.79816 .57498 Mdot
.56133 .72623 Mdot
.21151 .56655 Mdot
.58869 .37817 Mdot
.41972 .29376 Mdot
.44421 .17675 Mdot
.3999 .18709 Mdot
.54011 .83366 Mdot
.57889 .68636 Mdot
.40368 .68849 Mdot
.7935 .598 Mdot
.56236 .6574 Mdot
.72993 .65924 Mdot
.72033 .65836 Mdot
.27295 .26873 Mdot
.61648 .51434 Mdot
.83834 .42978 Mdot
.3385 .46149 Mdot
.48999 .22717 Mdot
.23343 .64603 Mdot
.76097 .69019 Mdot
.47376 .18491 Mdot
.47885 .52757 Mdot
.47297 .78925 Mdot
.34905 .53991 Mdot
.6607 .61955 Mdot
.27081 .75756 Mdot
.30845 .3993 Mdot
.62223 .74441 Mdot
.6998 .2798 Mdot
.40808 .58076 Mdot
.18882 .62451 Mdot
.79918 .54731 Mdot
.19434 .57959 Mdot
.71156 .44626 Mdot
.38935 .61635 Mdot
.47944 .60875 Mdot
.25336 .41798 Mdot
.67863 .54794 Mdot
.29811 .27146 Mdot
.80442 .65196 Mdot
.65871 .25383 Mdot
.58533 .79848 Mdot
.32577 .27099 Mdot
.63284 .20945 Mdot
.79311 .45403 Mdot
.56278 .4672 Mdot
.33445 .28008 Mdot
.29835 .51338 Mdot
.78824 .34936 Mdot
.40741 .46757 Mdot
.7287 .4477 Mdot
.75357 .6145 Mdot
.73823 .35534 Mdot
.24568 .63606 Mdot
.37929 .60367 Mdot
.20857 .43885 Mdot
.59263 .19341 Mdot
.55756 .82303 Mdot
.32246 .7641 Mdot
.17902 .59632 Mdot
.54235 .7566 Mdot
.73699 .34411 Mdot
.79079 .46737 Mdot
.73558 .74134 Mdot
.54959 .5136 Mdot
.4514 .20216 Mdot
.29252 .5312 Mdot
.44149 .17498 Mdot
.66203 .5021 Mdot
.75469 .54636 Mdot
.59576 .30438 Mdot
.31543 .24346 Mdot
.41676 .75058 Mdot
.52787 .18052 Mdot
.45781 .44018 Mdot
.18405 .3771 Mdot
.676 .29676 Mdot
.50501 .45018 Mdot
.53242 .3862 Mdot
.39402 .34237 Mdot
.52257 .20507 Mdot
.60102 .25741 Mdot
.7512 .69574 Mdot
.52731 .30679 Mdot
.31773 .36723 Mdot
.55908 .79235 Mdot
.27205 .57299 Mdot
.71563 .31361 Mdot
.276 .45493 Mdot
.51219 .16983 Mdot
.25701 .38318 Mdot
.20806 .44835 Mdot
.35034 .25936 Mdot
.85776 .50404 Mdot
.68707 .57534 Mdot
.3189 .32381 Mdot
.79924 .53169 Mdot
.47934 .26642 Mdot
.49828 .5372 Mdot
.06648 .46623 Mdot
.83987 .53494 Mdot
.65255 .2849 Mdot
.2538 .28296 Mdot
.76261 .34664 Mdot
.62849 .28529 Mdot
.32739 .74659 Mdot
.55521 .54344 Mdot
.21773 .50608 Mdot
.43711 .5992 Mdot
.15528 .52022 Mdot
.26374 .55188 Mdot
.23148 .30809 Mdot
.65483 .20494 Mdot
.6233 .76056 Mdot
.38389 .63961 Mdot
.52379 .31523 Mdot
.63135 .54133 Mdot
.25676 .58117 Mdot
.40581 .76603 Mdot
.54637 .56978 Mdot
.58212 .29908 Mdot
.53405 .39098 Mdot
.37116 .27969 Mdot
.64754 .6386 Mdot
.4898 .23788 Mdot
.73167 .35053 Mdot
.524 .40855 Mdot
.51689 .48987 Mdot
.26037 .46189 Mdot
.60031 .5569 Mdot
.55619 .78077 Mdot
.30162 .68144 Mdot
.59513 .46005 Mdot
.49267 .33754 Mdot
.53002 .78197 Mdot
.83462 .48715 Mdot
.66499 .26409 Mdot
.24025 .3146 Mdot
.36422 .33932 Mdot
.44007 .79122 Mdot
.2559 .44279 Mdot
.34815 .77238 Mdot
.43061 .8061 Mdot
.58894 .26865 Mdot
.64781 .62013 Mdot
.3673 .76787 Mdot
.77768 .4877 Mdot
.29562 .24109 Mdot
.79019 .63043 Mdot
.79345 .60578 Mdot
.54956 .28663 Mdot
.60795 .72745 Mdot
.59614 .78015 Mdot
.31928 .47227 Mdot
.4623 .46467 Mdot
.48247 .87091 Mdot
.50242 .64077 Mdot
.357 .84861 Mdot
.68461 .44394 Mdot
.28126 .73877 Mdot
.3031 .51594 Mdot
.55044 .44316 Mdot
.43084 .44155 Mdot
.71148 .32127 Mdot
.74037 .54196 Mdot
.80971 .43454 Mdot
.4394 .81853 Mdot
.48009 .37002 Mdot
.81215 .64486 Mdot
.86138 .50332 Mdot
.48025 .78017 Mdot
.36 .61861 Mdot
.84633 .51841 Mdot
.49679 .30067 Mdot
.28526 .66635 Mdot
.74822 .29437 Mdot
.60522 .24844 Mdot
.46901 .53059 Mdot
.26058 .49127 Mdot
.45391 .20013 Mdot
.40225 .17372 Mdot
.35879 .8039 Mdot
.53788 .21582 Mdot
.66895 .50093 Mdot
.48648 .44072 Mdot
.53844 .19028 Mdot
.49329 .51888 Mdot
.73882 .49153 Mdot
.54731 .56028 Mdot
.44464 .88483 Mdot
.3597 .23686 Mdot
.30125 .26987 Mdot
.52923 .55253 Mdot
.62019 .61922 Mdot
.67013 .54556 Mdot
.56607 .56158 Mdot
.61988 .25523 Mdot
.82205 .49527 Mdot
.56378 .55824 Mdot
.65472 .80746 Mdot
.53658 .68023 Mdot
.47195 .41072 Mdot
.58262 .79201 Mdot
.46679 .68442 Mdot
.71183 .44467 Mdot
.22249 .4288 Mdot
.68399 .26138 Mdot
.69687 .48987 Mdot
.71094 .30695 Mdot
.75571 .44137 Mdot
.63355 .71758 Mdot
.57109 .7353 Mdot
.62974 .24285 Mdot
.42759 .76751 Mdot
.67271 .68428 Mdot
.24755 .61853 Mdot
.47903 .33343 Mdot
.68266 .25413 Mdot
.52104 .38419 Mdot
.37501 .66337 Mdot
.49772 .50368 Mdot
.3087 .60688 Mdot
.18347 .5695 Mdot
.35084 .41803 Mdot
.60119 .68171 Mdot
.30249 .77309 Mdot
.55885 .64228 Mdot
.16211 .51702 Mdot
.3111 .69788 Mdot
.61608 .77465 Mdot
.4094 .27331 Mdot
.38682 .30411 Mdot
.57125 .8516 Mdot
.60239 .48779 Mdot
.58557 .34804 Mdot
.68432 .64295 Mdot
.62856 .67491 Mdot
.36832 .25732 Mdot
.4884 .37324 Mdot
.55424 .53154 Mdot
.63278 .40345 Mdot
.58149 .69672 Mdot
.66383 .67618 Mdot
.53378 .51166 Mdot
.22749 .49358 Mdot
.28865 .26083 Mdot
.53411 .33836 Mdot
.37699 .84765 Mdot
.40419 .64458 Mdot
.48625 .76564 Mdot
.5912 .18116 Mdot
.36904 .81849 Mdot
.57917 .36286 Mdot
.86529 .50192 Mdot
.42039 .5352 Mdot
.5989 .22542 Mdot
.59073 .64569 Mdot
.79053 .61467 Mdot
.34146 .41112 Mdot
.2817 .46154 Mdot
.69685 .44494 Mdot
.26203 .6643 Mdot
.55241 .41446 Mdot
.55388 .61751 Mdot
.57213 .23684 Mdot
.41275 .69054 Mdot
.74765 .51637 Mdot
.37359 .29442 Mdot
.48759 .78319 Mdot
.57313 .73067 Mdot
.65645 .68539 Mdot
.3132 .25959 Mdot
.79808 .61027 Mdot
.26088 .25605 Mdot
.52742 .61473 Mdot
.41951 .37846 Mdot
.74257 .63494 Mdot
.68131 .28134 Mdot
.65143 .60074 Mdot
.56232 .17191 Mdot
.25366 .52346 Mdot
.60957 .70862 Mdot
.24795 .47007 Mdot
.3595 .54672 Mdot
.53997 .4743 Mdot
.70393 .35256 Mdot
.47065 .8335 Mdot
.62422 .56186 Mdot
.29434 .73385 Mdot
.65026 .61356 Mdot
.29407 .28813 Mdot
.63338 .60969 Mdot
.55767 .38517 Mdot
.62028 .73237 Mdot
.60672 .47565 Mdot
.31006 .22975 Mdot
.57165 .1741 Mdot
.61453 .47809 Mdot
.41362 .24149 Mdot
.74892 .31324 Mdot
.3473 .57412 Mdot
.45959 .41865 Mdot
.45915 .57266 Mdot
.43062 .67909 Mdot
.38546 .83268 Mdot
.64379 .26309 Mdot
.4991 .60825 Mdot
.35672 .2171 Mdot
.34753 .20918 Mdot
.20701 .34495 Mdot
.7071 .74475 Mdot
.62894 .64097 Mdot
.17447 .43653 Mdot
.54669 .57307 Mdot
.42721 .16191 Mdot
.59064 .26447 Mdot
.63749 .18256 Mdot
.46663 .78542 Mdot
.72303 .30656 Mdot
.34565 .75303 Mdot
.71569 .53855 Mdot
.78458 .40204 Mdot
.53976 .43278 Mdot
.65553 .33936 Mdot
.77319 .36903 Mdot
.75885 .74124 Mdot
.33765 .61685 Mdot
.75815 .43132 Mdot
.77803 .52024 Mdot
.67325 .2476 Mdot
.48808 .28021 Mdot
.37087 .63295 Mdot
.61707 .32186 Mdot
.21547 .61156 Mdot
.26672 .44719 Mdot
.32055 .36001 Mdot
.49064 .27887 Mdot
.23062 .56717 Mdot
.23985 .48157 Mdot
.79243 .62946 Mdot
.48276 .78625 Mdot
.57922 .53294 Mdot
.38597 .55546 Mdot
.65926 .6525 Mdot
.32555 .39763 Mdot
.57124 .42107 Mdot
.4636 .58774 Mdot
.55831 .37001 Mdot
.74087 .52415 Mdot
.17468 .57205 Mdot
.66053 .56886 Mdot
.80642 .52116 Mdot
.60722 .60427 Mdot
.7505 .45205 Mdot
.67035 .61333 Mdot
.22009 .64814 Mdot
.4474 .31059 Mdot
.27652 .42263 Mdot
.40356 .20201 Mdot
.25473 .34571 Mdot
.64505 .71437 Mdot
.21357 .37793 Mdot
.64277 .49493 Mdot
.51301 .59585 Mdot
.77361 .54636 Mdot
.35734 .28441 Mdot
.49384 .64153 Mdot
.72079 .30561 Mdot
.58522 .36006 Mdot
.29544 .32693 Mdot
.79928 .41404 Mdot
.45945 .68088 Mdot
.52746 .79963 Mdot
.38853 .19167 Mdot
.53864 .32826 Mdot
.81429 .57781 Mdot
.7511 .47345 Mdot
.43312 .33949 Mdot
.27702 .2917 Mdot
.26537 .26576 Mdot
.45329 .44832 Mdot
.29125 .50412 Mdot
.38607 .58295 Mdot
.77478 .67065 Mdot
.66522 .27561 Mdot
.31595 .59621 Mdot
.66275 .37553 Mdot
.56863 .62192 Mdot
.70838 .37584 Mdot
.56891 .51506 Mdot
.22336 .5315 Mdot
.57897 .68228 Mdot
.58479 .80238 Mdot
.34629 .42421 Mdot
.4331 .41136 Mdot
.4095 .65919 Mdot
.29415 .48487 Mdot
.64041 .79095 Mdot
.47498 .64446 Mdot
.5574 .21348 Mdot
.51123 .7875 Mdot
.78581 .59765 Mdot
.61706 .24023 Mdot
.58892 .27241 Mdot
.7355 .54156 Mdot
.60676 .73864 Mdot
.60266 .4088 Mdot
.43042 .54558 Mdot
.56346 .38205 Mdot
.54859 .63406 Mdot
.71135 .26328 Mdot
.54467 .74875 Mdot
.31129 .47735 Mdot
.58855 .43307 Mdot
.37241 .66394 Mdot
.62995 .41968 Mdot
.62139 .18091 Mdot
.71473 .54026 Mdot
.25367 .5099 Mdot
.61549 .51356 Mdot
.30492 .51037 Mdot
.31068 .70641 Mdot
.32259 .2023 Mdot
.33649 .75068 Mdot
.49849 .47178 Mdot
.30274 .74919 Mdot
.70442 .32169 Mdot
.75459 .3042 Mdot
.24605 .50118 Mdot
.4277 .42186 Mdot
.38994 .37492 Mdot
.70608 .65801 Mdot
.58828 .45576 Mdot
.31678 .35312 Mdot
.56672 .53775 Mdot
.62847 .38613 Mdot
.71585 .495 Mdot
.32226 .6106 Mdot
.36294 .24382 Mdot
.39682 .19741 Mdot
.78298 .62518 Mdot
.62944 .43133 Mdot
.43748 .35416 Mdot
.23129 .54555 Mdot
.68355 .19611 Mdot
.23244 .71939 Mdot
.38759 .58152 Mdot
.61134 .44514 Mdot
.2808 .50398 Mdot
.48751 .3354 Mdot
.5929 .56289 Mdot
.66707 .60308 Mdot
.69689 .45453 Mdot
.31051 .37705 Mdot
.28919 .33433 Mdot
.7169 .33488 Mdot
.27781 .58418 Mdot
.60123 .32838 Mdot
.17313 .57852 Mdot
.83612 .4622 Mdot
.67088 .27532 Mdot
.62848 .16197 Mdot
.73988 .4585 Mdot
.53114 .65533 Mdot
.36907 .72293 Mdot
.29015 .263 Mdot
.28179 .44572 Mdot
.23571 .61175 Mdot
.58726 .28092 Mdot
.24955 .51575 Mdot
.51895 .55771 Mdot
.33571 .26648 Mdot
.70094 .37585 Mdot
.53122 .45996 Mdot
.38912 .30664 Mdot
.2266 .34906 Mdot
.53611 .80573 Mdot
.42849 .19572 Mdot
.22167 .62804 Mdot
.70994 .76867 Mdot
.32612 .21437 Mdot
.33217 .43892 Mdot
.46521 .29913 Mdot
.37555 .73222 Mdot
.4032 .47272 Mdot
.48294 .52477 Mdot
.28024 .66169 Mdot
.5473 .71632 Mdot
.44744 .24793 Mdot
.26264 .70276 Mdot
.25431 .45239 Mdot
.48721 .68142 Mdot
.42735 .4258 Mdot
.54957 .77862 Mdot
.40901 .24539 Mdot
.51236 .53552 Mdot
.42611 .47063 Mdot
.30939 .44674 Mdot
.51843 .78358 Mdot
.75501 .62947 Mdot
.75137 .34167 Mdot
.67124 .80806 Mdot
.53806 .2321 Mdot
.22802 .66142 Mdot
.38315 .63008 Mdot
.22903 .28509 Mdot
.75684 .36947 Mdot
.57089 .25967 Mdot
.81198 .46488 Mdot
.45889 .39846 Mdot
.54496 .6729 Mdot
.42973 .54538 Mdot
.51432 .20883 Mdot
.61852 .74749 Mdot
.42179 .70015 Mdot
.25512 .66472 Mdot
.27155 .47287 Mdot
.27051 .36373 Mdot
.32763 .46852 Mdot
.52011 .61266 Mdot
.5634 .64721 Mdot
.16397 .46759 Mdot
.47697 .45711 Mdot
.36512 .65648 Mdot
.32971 .55601 Mdot
.3345 .733 Mdot
.85344 .44728 Mdot
.54039 .6034 Mdot
.26522 .33349 Mdot
.49674 .80769 Mdot
.40747 .50371 Mdot
.63015 .59022 Mdot
.64764 .13687 Mdot
.29928 .19112 Mdot
.54896 .62157 Mdot
.71225 .71808 Mdot
.50631 .80917 Mdot
.30941 .2538 Mdot
.42292 .32124 Mdot
.65084 .39163 Mdot
.32562 .55049 Mdot
.43965 .48829 Mdot
.44947 .64807 Mdot
.80051 .4386 Mdot
.33438 .19616 Mdot
.25813 .67824 Mdot
.35955 .21529 Mdot
.42148 .51665 Mdot
.47075 .64068 Mdot
.7146 .20782 Mdot
.52716 .18893 Mdot
.34614 .59772 Mdot
.36533 .77647 Mdot
.49002 .65192 Mdot
.42689 .61941 Mdot
.45904 .21714 Mdot
.81262 .64167 Mdot
.25366 .44704 Mdot
.31504 .24418 Mdot
.57001 .67716 Mdot
.56209 .39524 Mdot
.68794 .44411 Mdot
.43987 .44722 Mdot
.37119 .54875 Mdot
.68304 .45329 Mdot
.31098 .6545 Mdot
.71846 .29535 Mdot
.63384 .53573 Mdot
.81157 .61189 Mdot
.54517 .15269 Mdot
.55444 .75787 Mdot
.70306 .65007 Mdot
.34739 .62429 Mdot
.48752 .67972 Mdot
.24967 .58015 Mdot
.46139 .67202 Mdot
.76671 .34025 Mdot
.10525 .44092 Mdot
.64305 .34534 Mdot
.21745 .47177 Mdot
.64474 .63905 Mdot
.59136 .54156 Mdot
.57578 .77929 Mdot
.44538 .35363 Mdot
.5445 .35088 Mdot
.40443 .51848 Mdot
.52449 .61425 Mdot
.7131 .46028 Mdot
.33037 .82337 Mdot
.36658 .61937 Mdot
.614 .57014 Mdot
.42976 .16281 Mdot
.24704 .61821 Mdot
.45731 .75747 Mdot
.45094 .54983 Mdot
.72026 .60767 Mdot
.42804 .41893 Mdot
.6382 .22649 Mdot
.21097 .44076 Mdot
.36611 .22035 Mdot
.54463 .74601 Mdot
.51986 .80227 Mdot
.37705 .56845 Mdot
.38251 .41871 Mdot
.71451 .51352 Mdot
.48614 .21821 Mdot
.47099 .54243 Mdot
.38685 .17459 Mdot
.47819 .41725 Mdot
.57567 .40908 Mdot
.52312 .59724 Mdot
.19846 .36136 Mdot
.29271 .71583 Mdot
.60522 .76803 Mdot
.20887 .63371 Mdot
.35566 .30193 Mdot
.2721 .5696 Mdot
.53116 .3181 Mdot
.46294 .53541 Mdot
.55705 .662 Mdot
.17297 .60047 Mdot
.44596 .21329 Mdot
.63929 .32605 Mdot
.67814 .35861 Mdot
.74135 .68715 Mdot
.75419 .50311 Mdot
.59877 .15119 Mdot
.36884 .30525 Mdot
.17578 .59661 Mdot
.80046 .5981 Mdot
.53608 .61463 Mdot
.72466 .32298 Mdot
.50454 .61631 Mdot
.51375 .33412 Mdot
.35243 .22683 Mdot
.41526 .6671 Mdot
.20282 .53806 Mdot
.47902 .5811 Mdot
.19016 .55582 Mdot
.29782 .37299 Mdot
.40208 .23927 Mdot
.67178 .29933 Mdot
.32015 .73017 Mdot
.68328 .23352 Mdot
.708 .66001 Mdot
.67213 .2014 Mdot
.6904 .24529 Mdot
.40097 .1813 Mdot
.21461 .58642 Mdot
.39925 .82436 Mdot
.6032 .26155 Mdot
.63607 .24776 Mdot
.71742 .35141 Mdot
.36245 .73858 Mdot
.39687 .34241 Mdot
.53534 .60105 Mdot
.68985 .54785 Mdot
.61816 .48957 Mdot
.12386 .63603 Mdot
.27967 .3699 Mdot
.53611 .62491 Mdot
.37103 .32505 Mdot
.36313 .19844 Mdot
.34891 .7305 Mdot
.78113 .38241 Mdot
.56251 .50651 Mdot
.46151 .63795 Mdot
.55827 .73299 Mdot
.76452 .65838 Mdot
.39215 .34589 Mdot
.58362 .85824 Mdot
.83257 .47391 Mdot
.64998 .36669 Mdot
.5369 .48219 Mdot
.5653 .66363 Mdot
.67402 .65544 Mdot
.39761 .29327 Mdot
.7789 .35509 Mdot
.7215 .3025 Mdot
.53624 .18967 Mdot
.57279 .84983 Mdot
.78878 .60019 Mdot
.28876 .26264 Mdot
.68078 .29424 Mdot
.56411 .61181 Mdot
.3622 .44906 Mdot
.47777 .3243 Mdot
.64823 .31985 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0<oooooo0_l0001hooooo`007?ooool0
0ol0003oooooooooo`3?ooooo`;o0000N?ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo09;ooooo
0_l0002eooooo`007?ooool2o`0009?ooooo0_l0000Iooooo`;o00002_ooool2o`0000Cooooo0_l0
0028ooooo`007?ooool00ol0003oooooooooo`2Tooooo`;o00001oooool2o`0000[ooooo0_l00004
ooooo`;o0000R?ooool001cooooo00?o0000ooooooooool0R?ooool2o`0001[ooooo0_l0002Soooo
o`007?ooool00ol0003oooooooooo`1oooooo`;o00001_ooool3o`0000;ooooo0_l0000jooooo`;o
0000Ooooool001cooooo00?o0000ooooooooool0Ooooool2o`0000Kooooo0ol00002ooooo`Co0000
5?ooool2o`0002;ooooo0_l0001oooooo`007?ooool00ol0003oooooooooo`1jooooo`;o00004_oo
ool2o`0000Gooooo0_l0000:ooooo`Go0000Xoooool001cooooo00?o0000ooooooooool0N_ooool2
o`0001Wooooo0_l00002ooooo`;o00001_ooool5o`000004ooooool0003o0000ooooo`?o00001_oo
ool2o`0009Cooooo000Looooo`03o`000?oooooooooo07[ooooo0_l00003ooooo`;o00001Oooool2
o`0000;ooooo1?l00009ooooo`Co00001?ooool2o`0000;ooooo0ol000001?oooooo0000o`000?oo
ool3o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l0002?ooooo`007?ooool0
0ol0003oooooooooo`1_ooooo`;o00002Oooool2o`0000?ooooo0_l00005ooooo`;o00000_ooool5
o`0000?ooooo0ol00002ooooo`?o00001?ooool3o`0000[ooooo0_l00002ooooo`;o00001Oooool4
o`0008oooooo000Looooo`03o`000?oooooooooo06kooooo0ol0000>ooooo`Co00002_ooool2o`00
00?ooooo1Ol00007ooooo`?o00001oooool2o`0000;ooooo0_l0000>ooooo`;o00002?ooool2o`00
087ooooo000Looooo`03o`000?oooooooooo06_ooooo0_l000000ooooooo0000o`000004ooooo`;o
00002?ooool5o`0000gooooo1ol0000Aooooo`Ko00001Oooool2o`0000;ooooo0_l00002ooooo`Ko
00000oooool4o`0000?ooooo0_l0001looooo`007?ooool00ol0003oooooooooo`1Xooooo`Go0000
1oooool2o`0000Sooooo0_l0000@ooooo`Co00000_ooool2o`0001;ooooo0_l00007ooooo`;o0000
0_ooool2o`0000;ooooo1_l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`0007cooooo
000Looooo`03o`000?oooooooooo06Sooooo1?l0000=ooooo`;o00000oooool2o`0001?ooooo0_l0
00000ooooooo0000o`00000?ooooo`;o000000Coooooo`000?l0003o00001_ooool2o`0001;ooooo
0_l00020ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Ko
oooo00?o0000ooooooooool0GOooool2o`0001Sooooo1Ol0000;ooooo`;o00001_ooool2o`0000;o
oooo0_l0000Booooo`;o000000Coooooo`000?l0003o00003oooool3o`0000Cooooo0_l00005oooo
o`Co0000Noooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo05gooooo0_l00003ooooo`;o00001?oo
ool3o`0000[ooooo1?l000000ooooooo0000o`00000;ooooo`;o00001_ooool2o`0000kooooo0_l0
000Kooooo`Co00000oooool2o`0000Gooooo1ol00009ooooo`;o0000KOooool00003ooooool@413o
oooo00;ooooo00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooo
oooo06;ooooo0_l00004ooooo`?o00001oooool2o`000003ooooool0003o000000Kooooo0_l00008
ooooo`;o00003oooool2o`0000Gooooo0_l0000Mooooo`;o00002oooool8o`0000Oooooo0_l0001]
ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^
00Kooooo0ol0001Oooooo`;o00001?ooool2o`0000_ooooo0_l00009ooooo`Co00003_ooool3o`00
00Kooooo0_l00009ooooo`;o00006?ooool2o`0000[ooooo0ol000000ooooooo0000o`000002oooo
o`;o00001?ooool2o`00073ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00co
oooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`1Oooooo`;o00001?ooool2o`0001;o
oooo0_l00004ooooo`;o00003_ooool3o`00017ooooo0_l000000ooooooo0000o`00000Eooooo`;o
00002_ooool3o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o0000L?ooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo06gooooo0_l0000:ooooo`;o00003?ooool2o`0001[ooooo0_l000000ooooooo0000
o`00000Oooooo`;o00000_ooool2o`0000Cooooo0_l0000Aooooo`;o0000Hoooool00006oooooomg
MgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000oooo
ooooool0Joooool4o`000003ooooool0003o000000[ooooo0_l00009ooooo`;o00006_ooool2o`00
01oooooo0_l000001?oooooo0000o`000?ooool3o`0001Oooooo0_l0001Sooooo`0000Koooooonk^
k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`1Vooooo`Co000000?oooooo`000?l000000oooool3o`0000Wooooo0_l000000ooooooo0000
o`00000<ooooo`;o00002oooool2o`0000_ooooo0_l000000ooooooo0000o`000005ooooo`;o0000
0_ooool2o`0000cooooo0ol00004ooooo`;o0000OOooool001cooooo00?o0000ooooooooool0D?oo
ool2o`0001Cooooo1?l00006ooooo`Co00002oooool2o`0000cooooo0_l000001?oooooo0000o`00
0?l00007ooooo`;o00002?ooool2o`000004ooooool0003o0000ooooo`?o00001?ooool2o`0000;o
oooo0ol00007ooooo`;o00000_ooool2o`0008Cooooo000Looooo`03o`000?oooooooooo053ooooo
0_l0000Gooooo`;o00001Oooool5o`0000;ooooo0_l00006ooooo`;o00000_ooool2o`0000Gooooo
0_l000001?oooooo0000o`000?ooool3o`0000Oooooo0_l00003ooooo`;o00000oooool2o`0000Go
oooo0_l00003ooooo`;o00001?ooool2o`0000;ooooo0ol00002ooooo`;o000000?oooooo`000?l0
00004Oooool2o`0007;ooooo000Looooo`03o`000?oooooooooo06Kooooo0_l000000ooooooo0000
o`000006ooooo`Co00000_ooool2o`0000Kooooo0_l00002ooooo`?o00001?ooool2o`0000Cooooo
0_l00005ooooo`;o000000?oooooo`000?l000000oooool2o`0000Wooooo0_l00004ooooo`;o0000
00?oooooo`000?l000001Oooool3o`0000Gooooo0_l0000Aooooo`;o0000L_ooool001cooooo00?o
0000ooooooooool0E_ooool2o`0000Sooooo0_l00004ooooo`;o00001oooool2o`0000_ooooo0ol0
0003ooooo`Co00003?ooool2o`0000?ooooo0_l000001?oooooo0000o`000?l00002ooooo`;o0000
2Oooool5o`0000Cooooo0_l0000:ooooo`;o00002oooool2o`0007_ooooo000Looooo`03o`000?oo
oooooooo05Kooooo0_l00008ooooo`?o000000?oooooo`000?l000000_l00007ooooo`Co00002Ooo
ool3o`000003ooooool0003o000000;o00003_ooool2o`0000;ooooo0_l00003ooooo`;o00000_oo
ool2o`0000?ooooo0_l00006ooooo`?o00004?ooool2o`0000_ooooo0_l0001kooooo`007?ooool0
0ol0003oooooooooo`1Qooooo`;o000000?oooooo`000?l000000_l00009ooooo`;o00002oooool4
o`0000[ooooo0_l00002ooooo`;o00001?ooool2o`0000?ooooo0_l00005ooooo`Co00001Oooool2
o`0001;ooooo0_l0000Iooooo`;o0000KOooool001cooooo00?o0000ooooooooool0LOooool2o`00
00_ooooo0_l0000<ooooo`;o00000_ooool2o`0000Wooooo0_l00002ooooo`Go000000Coooooo`00
0?l0003ooooo0_l000000ooooooo0000o`000009ooooo`;o000000?oooooo`000?l000001?ooool2
o`0000Gooooo0_l0000Booooo`;o00000_ooool2o`0006Wooooo000Looooo`03o`000?oooooooooo
077ooooo0_l00003ooooo`;o00001oooool2o`0001[ooooo0_l00002ooooo`Co00000_ooool5o`00
00cooooo0_l000000ooooooo0000o`00000;ooooo`;o00005_ooool2o`0001Wooooo0_l0001>oooo
o`007?ooool00ol0003oooooooooo`1Looooo`;o00000_ooool2o`0001Cooooo0_l00007ooooo`;o
00000_ooool4o`0001Cooooo1_l00005ooooo`;o00002_ooool2o`00017ooooo0ol000001?oooooo
0000o`000?ooool2o`0002_ooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`1Looooo`;o
00000_ooool2o`000003ooooool0003o000000[ooooo1Ol0000;ooooo`So00005_ooool3o`0000;o
oooo0_l00006ooooo`;o00001_ooool2o`00017ooooo0_l00002ooooo`;o000000?oooooo`000?l0
00003_ooool2o`0000Gooooo0_l0001Tooooo`007?ooool00ol0003oooooooooo`1Looooo`;o0000
1Oooool2o`0000[ooooo1Ol0000=ooooo`;o00002Oooool4o`0000kooooo0_l00002ooooo`;o0000
1_ooool2o`000004ooooool0003o0000ooooo`;o00003oooool2o`0000Sooooo0_l0000:ooooo`;o
00000oooool2o`000004ooooool0003o0000ooooo`?o0000I?ooool001cooooo0_l0001Jooooo`;o
00005oooool2o`00017ooooo0_l00005ooooo`Co00001oooool2o`0001Cooooo1Ol0000?ooooo`;o
00000oooool2o`0000?ooooo0_l0000:ooooo`;o00001?ooool4o`000004ooooool0003o0000o`00
06Cooooo000Looooo`03o`000?oooooooooo05Kooooo0_l000000ooooooo0000o`000006ooooo`?o
00001oooool2o`0000Wooooo0_l00005ooooo`;o00001_ooool2o`0000kooooo1Ol0000Dooooo`;o
00000_ooool2o`0001;ooooo0_l00003ooooo`;o00001Oooool2o`0000Kooooo1Ol0001Zooooo`00
7?ooool00ol0003oooooooooo`1Aooooo`;o00000oooool2o`0000Wooooo0ol00003ooooo`;o0000
0_ooool2o`0000Oooooo1?l00005ooooo`;o00005_ooool2o`000003ooooool0003o000001Sooooo
0_l0000;ooooo`;o00001Oooool2o`0000?ooooo0_l00005ooooo`;o00001_ooool3o`0000Sooooo
0_l00004ooooo`;o0000G?ooool001cooooo00?o0000ooooooooool0DOooool2o`0000Oooooo0_l0
0006ooooo`;o00000oooool2o`0000Gooooo0_l00004ooooo`?o00001_ooool2o`0000_ooooo0_l0
000Tooooo`;o00001?ooool3o`0000Kooooo0ol0000@ooooo`;o00001_ooool2o`0000Sooooo1Ol0
0002ooooo`;o0000G?ooool001cooooo00?o0000ooooooooool0DOooool2o`0000Oooooo0ol00005
ooooo`;o00001oooool2o`000003ooooool0003o000000;ooooo0_l00009ooooo`;o00001oooool2
o`0000;ooooo0_l0000Tooooo`;o000000Coooooo`000?l0003ooooo0ol00003ooooo`;o000000Co
ooooo`000?l0003o00002oooool2o`0000?ooooo1?l00004ooooo`;o00000_ooool2o`0000?ooooo
1ol0001Oooooo`007?ooool00ol0003oooooooooo`1Aooooo`?o00001_ooool3o`0000cooooo1?l0
0005ooooo`Co00001?ooool2o`000003ooooool0003o000000;ooooo0_l00003ooooo`;o00004?oo
ool2o`0000Oooooo0_l00004ooooo`;o00001?ooool2o`0000Cooooo1Ol000001?oooooo0000o`00
0?ooool2o`000003ooooool0003o000000cooooo0ol00004ooooo`;o00002?ooool2o`0000?ooooo
1?l000000ooooooo0000o`00001Oooooo`007?ooool00ol0003oooooooooo`1Booooo`;o000000?o
ooooo`000?l000001oooool2o`000004ooooool0003o0000ooooo`;o00000oooool2o`0000Wooooo
0_l00004ooooo`Go00000_ooool2o`0000?ooooo0_l00006ooooo`;o00000_ooool2o`0000Cooooo
0_l00007ooooo`;o00001?ooool2o`0000Cooooo0_l00005ooooo`;o00000oooool2o`000003oooo
ool0003o0000013ooooo0_l0001iooooo`007?ooool00ol0003oooooooooo`1Eooooo`;o00001_oo
ool3o`000004ooooool0003o0000ooooo`Co00004oooool3o`0000?ooooo0_l0000;ooooo`;o0000
0_ooool2o`0000Sooooo0_l0000Cooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`;o
00001_ooool2o`0001Gooooo0_l00008ooooo`;o0000H_ooool001cooooo00?o0000ooooooooool0
E?ooool2o`0000Oooooo0_l00003ooooo`;o00000_ooool2o`00017ooooo0_l00006ooooo`;o0000
4_ooool2o`0000Gooooo0_l0000Cooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`;o
00001_ooool2o`0000Cooooo0_l00008ooooo`Co00000oooool2o`0000Sooooo0_l0000:ooooo`;o
0000E_ooool001cooooo00?o0000ooooooooool0E?ooool2o`0000Cooooo0_l00003ooooo`;o0000
00?oooooo`000?l000001Oooool2o`0000[ooooo1_l0000Jooooo`;o00001Oooool2o`0000Cooooo
0_l00008ooooo`;o00002Oooool3o`00013ooooo0_l00008ooooo`Co00000oooool2o`0000?ooooo
0_l0000?ooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0C?ooool5o`0000Wooooo0_l0
0003ooooo`;o00002?ooool2o`0000[ooooo1?l0000>ooooo`;o00004_ooool3o`000004ooooool0
003o0000ooooo`;o00002?ooool2o`0000Cooooo0_l00003ooooo`?o000000?oooooo`000?l00000
0_l00003ooooo`;o000000?oooooo`000?l000000ol0000@ooooo`;o00000oooool3o`0000[ooooo
0_l0001Kooooo`007?ooool00ol0003oooooooooo`17ooooo`;o00000oooool5o`0000Wooooo0ol0
0008ooooo`?o00002?ooool2o`0000Gooooo0_l0000>ooooo`;o00004_ooool3o`000003ooooool0
003o000000;ooooo0_l0000=ooooo`;o00001Oooool6o`0000?ooooo0_l000000ooooooo0000o`00
0003o`0000Kooooo0_l00005ooooo`;o000000?oooooo`000?l000000oooool2o`0000_ooooo0_l0
0008ooooo`;o0000DOooool001cooooo00?o0000ooooooooool0Aoooool2o`0000oooooo1_l00007
ooooo`?o00002?ooool2o`000003ooooool0003o000000;ooooo0_l0000Kooooo`;o00001Oooool3
o`0000Gooooo0_l0000:ooooo`?o00000oooool2o`0000;ooooo0_l0000=ooooo`;o00001_ooool3
o`0000Cooooo0_l00007ooooo`;o00002_ooool2o`0000Sooooo0_l0001Aooooo`007?ooool00ol0
003oooooooooo`1Fooooo`Co00000_ooool2o`0001Gooooo1?l0000Mooooo`;o00005?ooool2o`00
00?ooooo0ol00003ooooo`;o00000_ooool2o`0001Kooooo0_l0000=ooooo`;o00005?ooool2o`00
057ooooo000Looooo`03o`000?oooooooooo04Wooooo0_l0000:ooooo`?o00006oooool5o`0000Go
oooo0_l00006ooooo`;o00003oooool2o`0001;ooooo0_l0000?ooooo`;o00006oooool3o`0000[o
oooo0ol00007ooooo`;o00001Oooool4o`000003ooooool0003o000004cooooo000Looooo`03o`00
0?oooooooooo04Wooooo0_l0000:ooooo`;o00007_ooool3o`0000Gooooo0_l00006ooooo`;o0000
3oooool2o`000003ooooool0003o000000Oooooo0_l0000Gooooo`;o00002?ooool2o`0000gooooo
0_l00002ooooo`?o00002_ooool3o`0000Oooooo0_l00007ooooo`;o000000?oooooo`000?l00000
C?ooool001cooooo0_l0001Aooooo`;o00002Oooool2o`0003Kooooo0_l00004ooooo`;o00000ooo
ool2o`0000;ooooo1Ol0000Booooo`Co00002?ooool2o`0000gooooo1_l0000Eooooo`;o0000F?oo
ool001cooooo00?o0000ooooooooool0D?ooool2o`0000Wooooo0_l0000:ooooo`;o00001oooool2
o`0000Sooooo0_l00004ooooo`;o00004Oooool2o`0000?ooooo0_l00004ooooo`;o00000_ooool5
o`0000?ooooo0_l0000=ooooo`;o000000?oooooo`000?l000000_l0000Fooooo`;o00001?ooool2
o`0000Wooooo0_l00008ooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0COooool2o`00
01Sooooo0_l00007ooooo`Ko00001?ooool3o`0000?ooooo0_l0000Aooooo`;o00000oooool2o`00
00Sooooo0_l000001?oooooo0000o`000?ooool4o`0000kooooo1_l00007ooooo`;o000000?ooooo
o`000?l000004?ooool2o`0000;ooooo1Ol000001?oooooo0000o`000?l00008ooooo`;o0000E_oo
ool001cooooo00?o0000ooooooooool0Aoooool2o`0000Cooooo0_l0000?ooooo`;o00000oooool2
o`0000Gooooo0_l00006ooooo`Co00001Oooool2o`00017ooooo0_l00003ooooo`?o00002oooool;
o`0000gooooo0ol000000ooooooo0000o`000002o`0000Kooooo1Ol00007ooooo`;o00002oooool5
o`000004ooooool0003o0000o`0000cooooo0_l00008ooooo`;o0000B?ooool001cooooo00?o0000
ooooooooool0A_ooool3o`0000gooooo1Ol00002ooooo`So00001Oooool3o`0000cooooo0_l0000C
ooooo`;o00001?ooool2o`0000Sooooo3_l0000=ooooo`;o00000_ooool4o`0000Sooooo0_l00000
0ooooooo0000o`000005ooooo`;o00002Oooool2o`0000Gooooo0_l00003ooooo`Co000000Cooooo
o`000?l0003ooooo0_l000001?oooooo0000o`000?l00007ooooo`;o0000B?ooool001cooooo00?o
0000ooooooooool0A_ooool2o`0000;ooooo0_l0000:ooooo`oo00001_ooool2o`0000Oooooo0_l0
0003ooooo`;o00002oooool2o`0001Kooooo4Ol0000>ooooo`;o00000_ooool2o`0000Wooooo0_l0
0004ooooo`?o00002Oooool3o`0000Cooooo0_l00003ooooo`Co000000Coooooo`000?l0003ooooo
1_l0000:ooooo`;o0000AOooool001cooooo00?o0000ooooooooool0B_ooool2o`0000;ooooo0ol0
000:ooooo`;o00001?ooool4o`0000Gooooo0ol00007ooooo`;o00004?ooool2o`0000Oooooo0_l0
000?ooooo`oo00002oooool2o`0000Gooooo0_l00003ooooo`;o00001_ooool6o`0000_ooooo0_l0
0004ooooo`;o00003?ooool3o`0000cooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`0`
ooooo`;o00005_ooool4o`0000;ooooo0ol00009ooooo`;o00002?ooool2o`000004ooooool0003o
0000ooooo`;o00001Oooool2o`0001?ooooo0_l00007ooooo`;o00002Oooool3o`0000;ooooo4Ol0
00000ooooooo0000o`000003o`0000Cooooo0_l00002ooooo`;o00001Oooool6o`0000;ooooo2?l0
000;ooooo`[o00001Oooool2o`0000;ooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`0`
ooooo`;o00005_ooool2o`00013ooooo0_l00005ooooo`;o000000Coooooo`000?l0003ooooo0_l0
0008ooooo`;o00000_ooool6o`0000Wooooo1?l0000?ooooo`;o000000?oooooo`000?l000002Ol0
00000ooooooo0000o`000002o`0000;ooooo2_l00008ooooo`;o00001Oooool6o`000003ooooool0
003o000000Oo00002oooool5o`000003ooooool0003o000000;o00001Oooool2o`0000;ooooo0_l0
00000ooooooo0000o`00001Aooooo`007?ooool00ol0003oooooooooo`1Looooo`;o00000oooool2
o`000003ooooool0003o000000oooooo1_l00009ooooo`;o00001?ooool2o`0000Kooooo0_l00003
ooooo`;o00000ooooolEo`000003ooooool0003o000000cooooo0_l00002ooooo`;o00000_ooool3
o`000003ooooool0003o000000?ooooo0_l0000;ooooo`;o000000Coooooo`000?l0003o00003?oo
ool2o`000004ooooool0003o0000ooooo`?o0000D?ooool001cooooo00?o0000ooooooooool0B_oo
ool2o`00013ooooo0_l00008ooooo`?o00003oooool2o`0000Gooooo0_l00009ooooo`;o00001_oo
ool2o`0000;ooooo0_l000000ooooooo0000o`00000Go`000003ooooool0003o000000[ooooo0ol0
0002ooooo`;o000000Coooooo`000?l0003o00000_ooool4o`0000kooooo0ol000000ooooooo0000
o`00000<ooooo`Co00000_ooool3o`00053ooooo000Looooo`03o`000?oooooooooo04Gooooo0_l0
0003ooooo`;o00001?ooool4o`0000Kooooo1?l00006ooooo`Go00003oooool2o`0000Gooooo0_l0
000Booooo`;o000000?oooooo`000?l000006_l000000ooooooo0000o`00000:ooooo`;o00001?oo
ool5o`0000Cooooo0_l0000>ooooo`?o00001?ooool2o`0000Kooooo1?l000000ooooooo0000o`00
0003ooooo`;o00005Oooool2o`0003Wooooo000Looooo`03o`000?oooooooooo04Gooooo0_l00003
ooooo`;o00001?ooool4o`0000Gooooo1Ol00006ooooo`;o000000?oooooo`000?l000000oooool2
o`0000;ooooo0_l0000Qooooo`;o00000_oooolLo`0000cooooo0_l00004ooooo`?o00006?ooool2
o`000003ooooool0003o000000Co00001?ooool4o`0000Kooooo0_l0000Eooooo`;o0000>Oooool0
01cooooo00?o0000ooooooooool0BOooool2o`000003ooooool0003o000000_ooooo0_l000000ooo
oooo0000o`00000=ooooo`?o000000Goooooo`000?l0003o0000ooooo`02o`0000Wooooo0ol00008
ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Gooooo1?l000000ooooooo0000o`000005
o`000003ooooool0003o000000oo00002_ooool2o`000003ooooool0003o000000gooooo0_l00008
ooooo`;o00000oooool5o`0000;ooooo0_l00007ooooo`Co000000?oooooo`000?l00000D_ooool0
01cooooo00?o0000ooooooooool0BOooool2o`000003ooooool0003o000000Gooooo0_l00007oooo
o`;o00002_ooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000002o`00
00Kooooo1ol00006ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Gooooo6_l000001?oo
oooo0000o`000?l00009ooooo`?o000000?oooooo`000?l000002_ooool2o`000003ooooool0003o
000000Co00001?ooool2o`0000Cooooo1?l00007ooooo`;o00000_ooool4o`000003ooooool0003o
000000Gooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00001Oooool2o`00
0003ooooool0003o000000?ooooo0_l00002ooooo`;o00002?ooool2o`0000Wooooo0_l00008oooo
o`Co00001_ooool3o`000004ooooool0003o0000o`0001?ooooo7Ol0000;ooooo`;o00000oooool4
o`0000Kooooo0ol00003ooooo`Ko00000_ooool2o`0000oooooo0_l00006ooooo`;o000000?ooooo
o`000?l000000oooool2o`0004_ooooo000Looooo`;o0000@Oooool2o`0000Cooooo0ol000000ooo
oooo0000o`000002ooooo`Go00002_ooool2o`0001[ooooo0_l000000ooooooo0000o`000002oooo
o`?o00001_ooool2o`0000_ooooo2?l00003ooooo`Go000000?oooooo`000?l000002_l00007oooo
o`;o00001oooool4o`0000Kooooo0_l00008ooooo`;o00003?ooool2o`0000?ooooo0_l00005oooo
o`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00003_ooool2o`0003_ooooo000Loooo
o`03o`000?oooooooooo04Kooooo1?l000001?oooooo0000o`000?ooool5o`0000Cooooo0_l0000:
ooooo`;o00001?ooool2o`0000Wooooo0_l00003ooooo`;o00001_ooool2o`0000Kooooo0_l00002
ooooo`;o00001ooooolOo`0000Gooooo0_l0000Aooooo`;o00001Oooool2o`0000_ooooo0ol00000
0ooooooo0000o`000003ooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`;o00000ooo
ool2o`0000kooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`18ooooo`Go00001?ooool2
o`000004ooooool0003o0000ooooo`;o00000_ooool3o`0000?ooooo1?l00002ooooo`Co00001Ooo
ool2o`0000;ooooo0ol0000:ooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0
003o000000Gooooo0_l000000ooooooo0000o`00000Io`000003ooooool0003o000000Gooooo0_l0
000Aooooo`;o00001Oooool4o`0000Wooooo1_l00003ooooo`Co00001oooool6o`0004kooooo000L
ooooo`03o`000?oooooooooo04[ooooo0_l00005ooooo`;o000000?oooooo`000?l000001Oooool3
o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0000Oooooo1?l000000ooooooo0000o`00
000;ooooo`Co00001?ooool2o`0000Sooooo0_l00002oooooago00001Oooool2o`0001[ooooo1_l0
0008ooooo`;o00001?ooool4o`0000Kooooo0ol00002ooooo`;o0000C_ooool001cooooo00?o0000
ooooooooool0?Oooool4o`0001?ooooo0_l00004ooooo`;o00002?ooool2o`0000Gooooo1?l00000
0ooooooo0000o`000005o`000003ooooool0003o000000Sooooo0_l000000ooooooo0000o`000006
ooooo`;o00002?ooool<o`0000;ooooo3_l00004ooooo`Go00000oooool3o`0000cooooo0_l00000
0ooooooo0000o`000005ooooo`Ko00005_ooool2o`0005?ooooo000Looooo`03o`000?oooooooooo
03gooooo1?l0000;ooooo`;o00000_ooool3o`000003ooooool0003o000000Cooooo0_l000000ooo
oooo0000o`00000<ooooo`co000000?oooooo`000?l000001?l00007ooooo`;o00001_ooool2o`00
00Oooooo7Ol00004ooooo`?o00001Oooool4o`0000_ooooo0_l000000ooooooo0000o`000003oooo
o`;o00001?ooool2o`0000[ooooo0_l0001Oooooo`007?ooool00ol0003oooooooooo`1<ooooo`Oo
000000?oooooo`000?l000001oooool2o`0000Cooooo0_l00002oooooa;o000000?oooooo`000?l0
00000ol00003ooooo`;o00002Oooool2o`0000Oooooo7Ol0000;ooooo`;o000000Coooooo`000?l0
003o00002oooool2o`0000Gooooo0_l00004ooooo`;o00002_ooool2o`0000Sooooo0_l00003oooo
o`;o00006?ooool2o`0003Kooooo000Looooo`03o`000?oooooooooo03_ooooo0_l00007ooooo`;o
00002?ooool2o`0000Oooooo0_l00003ooooo`;o00001?ooool3o`0000;ooooo4ol00003ooooo`;o
00000oooool2o`0000Wooooo0_l00008oooooago00001?ooool2o`0000Cooooo0_l00002ooooo`;o
00002oooool2o`0000_ooooo0_l0000<ooooo`;o00001_ooool2o`0000?ooooo0_l000000ooooooo
0000o`00000Eooooo`;o0000=_ooool001cooooo00?o0000ooooooooool0>oooool2o`0000Oooooo
0_l0000:ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo0ol00003ooooo`;o0000
1?oooolBo`000003ooooool0003o000000;o00000_ooool4o`0001?ooooo2?l000000ooooooo0000
o`00000Ao`0000Cooooo1?l0000Gooooo`;o00000_ooool2o`00017ooooo0_l00006ooooo`?o0000
0_ooool2o`000003ooooool0003o000004gooooo000Looooo`03o`000?oooooooooo03Sooooo0_l0
0008ooooo`;o00002_ooool4o`000003ooooool0003o000000Sooooo0_l00002ooooo`;o00001Ooo
oolGo`0000;ooooo1_l0000=ooooo`;o00001?oooolEo`0000;ooooo0_l00006ooooo`Co00000_oo
ool2o`0000_ooooo0_l00005ooooo`;o00000_ooool2o`0000Oooooo1?l00007ooooo`;o00001Ooo
ool7o`00053ooooo000Looooo`03o`000?oooooooooo03Sooooo0_l00008ooooo`;o00001Oooool3
o`000004ooooool0003o0000o`0000;ooooo0_l0000=ooooo`;o00000ooooolFo`0000Wooooo0_l0
000=ooooo`;o00001?oooolEo`0000;ooooo0_l00006ooooo`Go000000?oooooo`000?l000002ooo
ool2o`0000;ooooo0_l00006ooooo`;o00000_ooool2o`0000;ooooo1?l00007ooooo`;o00001_oo
ool4o`0005;ooooo000Looooo`03o`000?oooooooooo03Cooooo0_l0000Cooooo`_o00003Oooool2
o`0000?ooooo3_l000000ooooooo0000o`000004o`0000Cooooo0_l0000=ooooo`;o00002_oooolD
o`000003ooooool0003o000000;ooooo1?l00003ooooo`Co00004_ooool2o`0000Kooooo0_l00002
ooooo`Co00004Oooool6o`0000?ooooo1?l0001;ooooo`007?ooool00ol0003oooooooooo`0doooo
o`;o00005_ooool2o`0000;ooooo0_l0000;ooooo`;o00000_ooool2o`0000;ooooo5_l00004oooo
o`;o00003Oooool2o`0000Gooooo0_l00005ooooo`_o000000?oooooo`000?l000001?l000000ooo
oooo0000o`000006o`0000?ooooo0ol00002ooooo`;o00001oooool2o`0000Kooooo0_l0000<oooo
o`;o00004Oooool2o`000003ooooool0003o000000?o000000?oooooo`000?l000000_l00006oooo
o`;o0000@oooool001cooooo00?o0000ooooooooool0B?ooool2o`0000;ooooo0_l00002ooooo`;o
00002oooool2o`0000Kooooo6?l0000Hooooo`;o00001?oooolHo`0000cooooo0_l00007ooooo`;o
00003?ooool2o`0000;ooooo0_l000000ooooooo0000o`000007ooooo`;o00002?ooool2o`0000;o
oooo1Ol0000;ooooo`;o0000@oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q
8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo03Kooooo0_l0000@oooo
o`;o00000_ooool2o`0001Cooooo0_l00002oooooaOo00006_ooool2o`0000;ooooo0_l000000ooo
oooo0000o`00000Ao`0000cooooo0_l0000Aooooo`;o00001?ooool2o`0000;ooooo1Ol00007oooo
o`;o00002?ooool2o`0000?ooooo0_l00003ooooo`;o00001oooool2o`0004Cooooo00001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0=_ooool2o`0000?ooooo0_l00009ooooo`;o00004?ooool2o`000004ooooool0003o
0000ooooo`?o000000Goooooo`000?l0003o0000ooooo`0Go`0000Kooooo0_l0000Booooo`;o0000
00?oooooo`000?l000000oooool=o`0000;ooooo1ol00008ooooo`;o00004Oooool2o`0000[ooooo
0_l0000?ooooo`;o00002oooool2o`0000Oooooo0_l00014ooooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`09ooooo`Go00001_ooool00ol0003oooooooooo`0kooooo`;o00002Ooo
ool2o`0000cooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo7_l00004ooooo`;o0000
00?oooooo`000?l000003?ooool2o`0000Oooooo0ol00005ooooo`?o000000?oooooo`000?l00000
1Ol000000ooooooo0000o`000005o`0000Kooooo0_l0000Sooooo`;o00002oooool2o`0000;ooooo
0_l000000ooooooo0000o`00001Cooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooooooo
o`09ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0001Dooooo`;o00002_oooolKo`000005oooo
ool0003o0000o`000?ooool00_l0000?ooooo`;o00002?ooool2o`0000Gooooo0ol00005ooooo`?o
00003_ooool2o`0000Cooooo0_l000000ooooooo0000o`00000@ooooo`;o00001_ooool4o`0000oo
oooo0_l000000ooooooo0000o`000005ooooo`;o00001Oooool2o`0000?ooooo0_l00010ooooo`00
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oo
oooo00?o0000ooooooooool0<oooool2o`0000[ooooo0_l0000Sooooo`;o00000_oooolGo`000003
ooooool0003o000000Sooooo1?l00003ooooo`;o00002_ooool4o`0000;ooooo0_l00008ooooo`;o
00000oooool4o`0000_ooooo0_l000000ooooooo0000o`000004ooooo`;o00000oooool2o`0000Go
oooo0_l00006ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l0000>ooooo`;o
00001Oooool2o`0000?ooooo0_l00010ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooo
ooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0<oooool2o`0000[ooooo
0_l00006ooooo`;o00002Oooool2o`0000?ooooo1?l00005ooooo`;o00001?oooolFo`0000Cooooo
0_l00008ooooo`Co00000oooool2o`0000Kooooo0_l00002ooooo`Co00001Oooool2o`0000?ooooo
1?l00003ooooo`Co000000?oooooo`000?l000001oooool3o`0000Oooooo0_l00003ooooo`;o0000
4?ooool2o`0000;ooooo0_l00004ooooo`;o00004Oooool2o`0000?ooooo0_l00014ooooo`0000Ko
ooooogMgMonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000oooooooo
ool0Aoooool2o`0000Wooooo0_l00003ooooo`Co00000oooool4o`0000Cooooo5_l0000:ooooo`;o
000000?oooooo`000?l000001oooool3o`000004ooooool0003o0000ooooo`Go00002?ooool2o`00
00?ooooo1?l00005ooooo`;o000000?oooooo`000?l000001oooool3o`0000Cooooo0_l0000eoooo
o`;o00000oooool2o`0004Cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPgooooo00?oMgMg
o`000?ooool01_ooool00ol0003oooooooooo`0eooooo`;o00007?ooool2o`0000;ooooo0ol00004
ooooo`Co00000ooooolGo`0000[ooooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool3
o`000003ooooool0003o000000;ooooo1?l0000Booooo`Co00000_ooool2o`0000Oooooo0_l00006
ooooo`;o00008?ooool2o`0000Kooooo1?l0000;ooooo`;o000000?oooooo`000?l00000A?ooool0
01cooooo00?o0000ooooooooool0=Oooool2o`0000cooooo0_l00005ooooo`;o00000oooool2o`00
0004ooooool0003o0000o`0000Cooooo0_l00006ooooo`;o00000_oooolCo`000004ooooool0003o
0000ooooo`;o00003oooool2o`0000?ooooo0_l00004ooooo`;o00001Oooool2o`0000oooooo1?l0
0002ooooo`;o00001oooool2o`0001?ooooo0_l0000Cooooo`;o00001_ooool4o`0000_ooooo0_l0
0017ooooo`007?ooool00ol0003oooooooooo`13ooooo`Co00000oooool2o`0000?ooooo0_l00000
0ooooooo0000o`000005ooooo`;o00001Oooool6o`000005ooooool0003o0000o`000?ooool03Ol0
00000ooooooo0000o`000003o`0000Wooooo0_l00006ooooo`;o000000?oooooo`000?l000001?oo
ool2o`0000Gooooo0ol0000Dooooo`;o00004Oooool2o`0000Wooooo0_l00003ooooo`;o00005ooo
ool2o`0000kooooo0_l000000ooooooo0000o`000012ooooo`007?ooool00ol0003oooooooooo`0k
ooooo`;o00001_ooool4o`000003ooooool0003o000000Sooooo1_l00006ooooo`Co000000Gooooo
o`000?l0003o0000ooooo`02o`0000?ooooo4Ol0000:ooooo`?o00001Oooool2o`0000Cooooo0_l0
0009ooooo`;o00004?ooool2o`000004ooooool0003o0000o`00017ooooo0_l00009ooooo`;o0000
0oooool2o`0001Oooooo0_l0000<ooooo`Oo0000@_ooool001cooooo00?o0000ooooooooool0>ooo
ool2o`0000Oooooo0_l00002ooooo`;o00002?ooool6o`000003ooooool0003o000000?ooooo0_l0
0002ooooo`;o00000_ooool2o`0000Cooooo3ol00008ooooo`Oo00002oooool2o`0000Sooooo0_l0
000:ooooo`;o00001Oooool5o`0000Gooooo0_l00005ooooo`;o00000_ooool2o`0001cooooo0_l0
000<ooooo`;o00002oooool2o`000003ooooool0003o000004Cooooo000Looooo`03o`000?oooooo
oooo02kooooo0_l000000ooooooo0000o`00000Aooooo`?o00003oooool2o`000003ooooool0003o
000000Oooooo1_l000000ooooooo0000o`000003ooooo`_o00001Oooool2o`0000?ooooo1_l00007
ooooo`;o00001Oooool3o`0000Gooooo0_l00004ooooo`;o00001?ooool2o`0000Kooooo0_l00007
ooooo`;o00000oooool4o`0000;ooooo0_l000000ooooooo0000o`000002o`0000Gooooo0_l0000@
ooooo`;o00001?ooool2o`0000;ooooo0_l00002ooooo`;o00002oooool2o`0000?ooooo0_l00005
ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0;_ooool2o`000003ooooool0003o0000
01;ooooo0_l00006ooooo`?o00001_ooool2o`0000[ooooo1?l00002ooooo`?o00001Oooool3o`00
00Cooooo0_l00005ooooo`;o00002oooool2o`0000?ooooo1?l00003ooooo`Co00002_ooool2o`00
00Gooooo0_l0000=ooooo`;o00000_ooool4o`0000;ooooo0ol000000ooooooo0000o`000003o`00
00Gooooo0_l00004ooooo`;o00000_ooool2o`0000Gooooo0_l00005ooooo`;o00000_ooool2o`00
0004ooooool0003o0000ooooo`;o00001_ooool2o`0000Kooooo0_l00005ooooo`Co0000>Oooool0
01cooooo00?o0000ooooooooool0=Oooool2o`0000Wooooo0_l0000;ooooo`?o00003oooool2o`00
0003ooooool0003o000000;o00000_ooool4o`0000Gooooo0_l0000<ooooo`Co00002?ooool2o`00
00Gooooo0_l00005ooooo`;o00004Oooool2o`0000gooooo0_l00002ooooo`;o00001?ooool3o`00
0004ooooool0003o0000ooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o
000000?o000000Coooooo`000?l0003o00000_ooool2o`000004ooooool0003o0000ooooo`;o0000
2Oooool5o`0000Kooooo0_l00004ooooo`;o00002Oooool2o`0003Wooooo000Looooo`03o`000?oo
oooooooo02[ooooo0_l00009ooooo`;o00002Oooool2o`0001cooooo0ol000001?oooooo0000o`00
0?ooool2o`000003ooooool0003o000000;o00001Oooool2o`0000cooooo1?l00004ooooo`?o0000
1oooool2o`0003Wooooo0_l000001?oooooo0000o`000?ooool<o`000003ooooool0003o000000So
00002oooool3o`0000Wooooo0_l000000ooooooo0000o`00000Dooooo`;o0000;_ooool001cooooo
00?o0000ooooooooool07oooool2o`0000Wooooo0_l0000Cooooo`Co00001Oooool2o`0000?ooooo
1?l00003ooooo`;o00001?ooool2o`0000;ooooo0_l00002ooooo`Go000000?oooooo`000?l00000
3oooool4o`0000;ooooo0_l00006ooooo`?o00001oooool2o`0000Oooooo0_l00003ooooo`;o0000
2_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000?ooooo`Go00002?ooool4o`000003oooo
ool0003o000000[o00000_ooool4o`0000Cooooo0_l00005ooooo`;o000000?oooooo`000?l00000
2Oooool2o`0001Oooooo0_l0000^ooooo`007?ooool00ol0003oooooooooo`0Oooooo`;o00007_oo
ool4o`0000Gooooo0_l00003ooooo`Ko000000?oooooo`000?l000000_ooool4o`0000?ooooo0_l0
0002ooooo`;o00005?ooool8o`0000Oooooo0_l00005ooooo`;o00002Oooool2o`0000?ooooo0ol0
0009ooooo`;o00000_ooool2o`000003ooooool0003o000000oooooo1ol00002ooooo`;o00000_oo
oolAo`0000;ooooo0ol00005ooooo`;o00001Oooool2o`0001Gooooo0_l00004ooooo`;o0000>?oo
ool001cooooo00?o0000ooooooooool0?_ooool5o`0000cooooo1_l00003ooooo`;o00001Oooool4
o`0000Oooooo0_l00006ooooo`;o00001Oooool2o`0000;ooooo0_l0000<ooooo`;o00000_ooool2
o`0000oooooo0_l0000;ooooo`;o00005?ooool2o`000003ooooool0003o000000;o00000_ooool2
o`0000;ooooo4Ol000000ooooooo0000o`000004o`000003ooooool0003o000000Oooooo0_l00000
0ooooooo0000o`000004ooooo`;o00003?ooool2o`0000Cooooo1?l0000fooooo`007?ooool2o`00
03oooooo1Ol0000<ooooo`?o000000?oooooo`000?l000003?ooool2o`0000Oooooo0_l00004oooo
o`Co00001Oooool2o`0000kooooo1Ol000000ooooooo0000o`00000?ooooo`;o00002oooool2o`00
01Kooooo0_l00003oooooako000000?oooooo`000?l000001Oooool2o`0000?ooooo0ol00003oooo
o`;o00005?ooool2o`0000Sooooo0_l0000/ooooo`007?ooool00ol0003oooooooooo`0iooooo`;o
00005?ooool3o`0000Cooooo0_l00002ooooo`;o00001Oooool2o`0000gooooo0_l0000?ooooo`;o
00001_ooool2o`000003ooooool0003o000000Cooooo0_l00008ooooo`;o00000_ooool2o`0002?o
oooo0_l000000ooooooo0000o`00000Po`0000Kooooo0_l00004ooooo`;o00001_ooool2o`0000oo
oooo0ol00009ooooo`;o0000;?ooool001cooooo00?o0000ooooooooool0>Oooool2o`0001Cooooo
0_l00005ooooo`;o00000_ooool2o`0000Gooooo0_l00003ooooo`;o00000_ooool4o`0000Sooooo
0_l00009ooooo`Co000000?oooooo`000?l000002?ooool4o`0000?ooooo0_l00003ooooo`;o0000
0oooool2o`0001;ooooo0_l00003ooooo`?o00002_oooolMo`0000;ooooo1_l000000ooooooo0000
o`000004ooooo`Co00001oooool2o`0000oooooo0ol0000gooooo`007?ooool00ol0003ooooooooo
o`13ooooo`;o00001Oooool2o`0000[ooooo1?l000000ooooooo0000o`000009ooooo`;o00000_oo
ool6o`0000Kooooo0_l00003ooooo`;o00001_ooool5o`0000Sooooo1Ol00002ooooo`;o00002?oo
ool2o`0000Kooooo0_l0000:ooooo`;o000000?oooooo`000?l000001_l00002ooooo`;o00000ooo
oolQo`0000;ooooo0_l000000ooooooo0000o`000004ooooo`Co0000D_ooool001cooooo00?o0000
ooooooooool0@oooool2o`0000Gooooo0_l00005ooooo`;o00000oooool4o`000003ooooool0003o
000000gooooo1_l0000;ooooo`;o00001oooool4o`0000Wooooo1?l0000?ooooo`;o00000oooool2
o`0000cooooo2Ol00002ooooo`;o00000ooooolEo`000003ooooool0003o000000Wo00005_ooool2
o`0000Cooooo0_l00006ooooo`;o000000?oooooo`000?l00000>?ooool001cooooo00?o0000oooo
ooooool04_ooool2o`0001kooooo0_l0000=ooooo`;o00002?ooool2o`0000Cooooo0_l0000Ioooo
o`;o00004oooool2o`0000gooooo1?l0000@ooooo`;o00003Oooool2o`0000;ooooo0_l000000ooo
oooo0000o`000002o`0000Sooooo8?l0000?ooooo`;o00001_ooool4o`0000?ooooo0_l00006oooo
o`;o000000?oooooo`000?l000002Oooool2o`0002gooooo000Looooo`03o`000?oooooooooo01;o
oooo0_l0000Jooooo`;o00000_ooool2o`0000gooooo0_l00008ooooo`Co00002Oooool2o`0000go
oooo0_l0000<ooooo`;o00002Oooool3o`0000;ooooo1_l00005ooooo`Co00001?ooool2o`0000Oo
oooo0_l0000:ooooo`;o00001?ooool2o`0000Cooooo1?l00009oooooaoo00001oooool2o`0000Go
oooo1?l00002ooooo`;o00000_ooool4o`0000?ooooo0_l00009ooooo`;o00002Oooool2o`0002go
oooo000Looooo`03o`000?oooooooooo02kooooo0_l0000<ooooo`Co00000oooool2o`0000;ooooo
0_l00003ooooo`?o00001Oooool2o`0000;ooooo0_l0000:ooooo`;o000000?oooooo`000?l00000
3?ooool2o`0000Oooooo1?l00003ooooo`So00000oooool4o`0000Cooooo0ol00003ooooo`;o0000
00?oooooo`000?l000002_ooool2o`0000Kooooo0_l00002ooooo`Co00002Oooool>o`000003oooo
ool0003o000000ko00001oooool2o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`;o0000
4?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000eooooo`007?ooool00ol0003ooooooooo
o`0kooooo`Oo000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l00006ooooo`;o00003?oo
ool4o`0000[ooooo0_l0000:ooooo`Ko00000oooool2o`0000Cooooo1?l000000ooooooo0000o`00
0007ooooo`;o00000oooool6o`0000Sooooo0_l000000ooooooo0000o`000004ooooo`;o00000_oo
ool2o`0000Gooooo0ol00003ooooo`ko000000?oooooo`000?l000003ol0000:ooooo`;o00006?oo
ool3o`0000Cooooo0ol0000eooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00001oooool8
o`000003ooooool0003o000000?ooooo0_l0000@ooooo`;o00001Oooool3o`0000cooooo0_l0000:
ooooo`;o00003oooool2o`000003ooooool0003o000000?ooooo0_l00009ooooo`Co00002?ooool2
o`000003ooooool0003o000000Gooooo1_l000000ooooooo0000o`000007o`000003ooooool0003o
000000?o000000?oooooo`000?l000005ol00007ooooo`;o00001?ooool2o`0001Gooooo1?l00003
ooooo`;o0000=_ooool001cooooo00?o0000ooooooooool0<Oooool2o`0000Oooooo0_l0000<oooo
o`Co00000oooool4o`0000;ooooo0_l00003ooooo`;o00000oooool4o`0000Cooooo0_l00003oooo
o`;o00008oooool2o`0000;ooooo0_l0000;ooooo`Co00001Oooool3o`0000Cooooo0_l00002oooo
o`Ko000000?oooooo`000?l000000_l000000ooooooo0000o`00000Oo`0000[ooooo0_l00004oooo
o`;o00005oooool4o`0003Wooooo000Looooo`03o`000?oooooooooo03Wooooo0_l0000<ooooo`;o
000000?oooooo`000?l000000_l000000ooooooo0000o`000002o`0000;ooooo0_l00005ooooo`;o
000000?oooooo`000?l000000_l00004ooooo`;o00000oooool2o`0000Wooooo0_l00006ooooo`;o
000000?oooooo`000?l000000_l0000;ooooo`;o00000_ooool5o`0000[ooooo0_l00005ooooo`?o
00000oooool3o`0000Sooooo0_l00008oooooago00001Oooool2o`0000;ooooo0_l00002ooooo`;o
00002oooool3o`0000kooooo0_l00004ooooo`;o0000<oooool001cooooo00?o0000ooooooooool0
=_ooool5o`0000Wooooo0_l000000ooooooo0000o`000003ooooo`;o00000oooool2o`0000Wooooo
0_l00003ooooo`?o000000?oooooo`000?l000000ol0000=ooooo`;o00001_ooool2o`000003oooo
ool0003o000000;o00001Oooool2o`0000Kooooo1ol0000Gooooo`Co00001oooool2o`0000;ooooo
0_l00003oooooaco00001oooool6o`0000;ooooo0_l00007ooooo`;o00000_ooool3o`0000_ooooo
0_l00007ooooo`;o0000<oooool001cooooo00?o0000ooooooooool0=_ooool4o`0000[ooooo0_l0
000;ooooo`?o00001oooool2o`0000Gooooo0_l000000ooooooo0000o`000003o`00027ooooo0_l0
0006ooooo`Ko000000?oooooo`000?l000002?ooool2o`0000gooooo0ol0000:ooooo`;o00000ooo
ool2o`0000Cooooo5_l00008ooooo`Go00001Oooool2o`0000Cooooo0_l00005ooooo`;o00002Ooo
ool2o`0003cooooo000Looooo`03o`000?oooooooooo03Oooooo0_l0000=ooooo`Co00001_ooool4
o`0000Oooooo0_l00007ooooo`;o00000_ooool2o`0001cooooo0_l000000ooooooo0000o`000004
o`0000Sooooo1_l00007ooooo`;o00003?ooool4o`0000gooooo0_l00005oooooa7o000000?ooooo
o`000?l000000ol00004ooooo`;o00000oooool4o`0000Gooooo0_l0000;ooooo`;o00000_ooool5
o`0000;ooooo0_l0000looooo`007?ooool00ol0003oooooooooo`0Wooooo`;o00003_ooool2o`00
00Gooooo0_l00006ooooo`Oo00000oooool2o`000003ooooool0003o000000oooooo0_l00002oooo
o`;o00007?ooool2o`000003ooooool0003o000000Co00002_ooool6o`00017ooooo1?l00003oooo
o`;o00001oooool2o`000003ooooool0003o000000Cooooo4_l00004ooooo`;o00000_ooool4o`00
00cooooo0_l0000?ooooo`Go00000_ooool2o`0003cooooo000Looooo`;o0000:?ooool2o`0001Go
oooo0_l00009ooooo`Go00000_ooool2o`000003ooooool0003o000000[ooooo0_l00004ooooo`;o
0000:Oooool2o`0000_ooooo0ol0000@ooooo`Co00000oooool2o`0000Oooooo1ol00002oooooa;o
00002?ooool2o`0000Gooooo0_l00007ooooo`;o00002?ooool2o`0000cooooo0_l00008ooooo`;o
0000<_ooool001cooooo00?o0000ooooooooool0>Oooool2o`00017ooooo0_l00002ooooo`;o0000
1Oooool2o`0000;ooooo0_l00002ooooo`;o00001?ooool2o`0001[ooooo0_l0000=ooooo`Co0000
2_ooool2o`00013ooooo0_l0000?ooooo`;o00000_ooool2o`0000?ooooo0_l000001?oooooo0000
o`000?ooool2o`000003ooooool0003o000000Co00003Oooool2o`0000;ooooo0_l00005ooooo`;o
00000_ooool2o`0000Kooooo0ol0000Cooooo`Co0000<_ooool001cooooo00?o0000ooooooooool0
>Oooool2o`0000;ooooo0_l00002ooooo`Co00004_ooool2o`0000;ooooo0_l00002ooooo`?o0000
7oooool2o`0000Cooooo0_l00009ooooo`;o00002_ooool4o`000003ooooool0003o000000Gooooo
0_l000000ooooooo0000o`000004ooooo`?o00005?ooool2o`0000Cooooo0_l000000ooooooo0000
o`000004o`0000gooooo0_l00002ooooo`;o00001Oooool2o`0000;ooooo0_l00007ooooo`?o0000
1?ooool2o`0000Kooooo0_l00004ooooo`?o0000<oooool001cooooo00?o0000ooooooooool04ooo
ool2o`0002Cooooo0_l00002ooooo`;o00000_ooool4o`0000Oooooo0_l000000ooooooo0000o`00
000>ooooo`?o000000?oooooo`000?l000005Oooool2o`0000_ooooo0_l0000Eooooo`Oo00001Ooo
ool2o`000003ooooool0003o000000Cooooo0ol0000Dooooo`;o00001?ooool2o`0000?ooooo1_l0
0008ooooo`;o00001Oooool4o`0000Kooooo0_l00009ooooo`;o00001?ooool2o`0000Kooooo0_l0
000jooooo`007?ooool00ol0003oooooooooo`0Cooooo`;o00009?ooool2o`000003ooooool0003o
000000Cooooo0_l00008ooooo`;o000000Coooooo`000?l0003o00002oooool4o`0000;ooooo0_l0
0006ooooo`;o00001?ooool2o`0000Oooooo0_l0000Vooooo`;o00001_ooool2o`0000?ooooo0_l0
0005ooooo`;o00001_ooool2o`0000Cooooo0_l00007ooooo`;o000000?oooooo`000?l000001?oo
ool2o`000004ooooool0003o0000ooooo`;o00001Oooool3o`0000Kooooo0_l00006ooooo`;o0000
7_ooool2o`0003?ooooo000Looooo`03o`000?oooooooooo037ooooo0_l00009ooooo`;o00002_oo
ool2o`0000?ooooo1Ol00002ooooo`;o00001oooool4o`0000[ooooo0_l00004ooooo`;o00002_oo
ool2o`0000Kooooo0_l0000:ooooo`;o00003?ooool2o`0000Wooooo0_l00003ooooo`;o00001?oo
ool3o`0000Kooooo0_l00004ooooo`;o00000oooool2o`0000;ooooo0_l00007ooooo`;o00001?oo
ool2o`0000Cooooo1?l00009ooooo`;o00000oooool2o`0000Sooooo0_l00008ooooo`;o00001?oo
ool2o`0000Cooooo0_l0000cooooo`007?ooool00ol0003oooooooooo`0_ooooo`Co00005Oooool3
o`0000;ooooo1?l00003ooooo`;o00002Oooool2o`0001Sooooo0_l00002ooooo`;o000000?ooooo
o`000?l000000oooool5o`0000Oooooo0_l00008ooooo`?o000000?oooooo`000?l000002Oooool2
o`0000Wooooo0_l00003ooooo`;o00001oooool3o`0000?ooooo0_l00002ooooo`;o00004oooool3
o`0000[ooooo0_l00003ooooo`;o00000oooool2o`0000?ooooo0_l00008ooooo`;o00001?ooool3
o`0003Sooooo000Looooo`03o`000?oooooooooo02oooooo0_l0000Hooooo`;o00001?ooool2o`00
0003ooooool0003o000001_ooooo0_l00007ooooo`?o00000_ooool2o`000003ooooool0003o0000
00;o00000oooool3o`00017ooooo0ol000000ooooooo0000o`000009ooooo`;o00001_ooool2o`00
00Kooooo0_l000000ooooooo0000o`000003ooooo`?o00001?ooool2o`0000;ooooo0_l00008oooo
o`;o00002_ooool2o`000004ooooool0003o0000o`0000_ooooo0_l00003ooooo`;o00001oooool3
o`0000[ooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00000oooool2o`00
00?ooooo0_l000000ooooooo0000o`000006ooooo`?o00004_ooool2o`0000Oooooo0_l00003oooo
o`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000002ooooo`;o00003_ooool2o`00
00Cooooo0_l00006ooooo`;o00002Oooool2o`0000Wooooo0_l00003ooooo`?o00004_ooool3o`00
00cooooo0ol00004ooooo`;o00001Oooool2o`0000cooooo0ol00014ooooo`007?ooool00ol0003o
ooooooooo`0dooooo`;o00002_ooool3o`0000;ooooo0_l00003ooooo`;o00002_ooool2o`0000;o
oooo0ol0000Booooo`;o00001oooool2o`000003ooooool0003o000000?o00001Oooool2o`0000;o
oooo0_l0000=ooooo`Go000000?oooooo`000?l000001oooool2o`0002oooooo0_l0000Cooooo`;o
00001Oooool2o`0002?ooooo0_l0000^ooooo`007?ooool00ol0003oooooooooo`0dooooo`;o0000
2_ooool3o`0000;ooooo0_l00003ooooo`;o00002_ooool2o`0000?ooooo0_l0000Dooooo`;o0000
1Oooool2o`000004ooooool0003o0000ooooo`;o00000oooool8o`000005ooooool0003o0000o`00
0?ooool01ol000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000Oooooo0_l00007
ooooo`;o00005Oooool2o`0000kooooo1?l0000<ooooo`;o00001oooool2o`0000kooooo1?l00008
ooooo`;o00002?ooool2o`000003ooooool0003o000002kooooo000Looooo`03o`000?oooooooooo
037ooooo0_l0000=ooooo`;o00000oooool2o`0001Cooooo0_l0000Dooooo`;o00001_ooool2o`00
00;ooooo3_l000000ooooooo0000o`000009o`0000cooooo0_l0000;ooooo`;o00001?ooool4o`00
00gooooo1Ol00006ooooo`;o00000_ooool5o`0000;ooooo0_l00008ooooo`;o00001oooool2o`00
00?ooooo0_l00003ooooo`?o00000oooool4o`0000Sooooo0ol00007ooooo`;o0000<Oooool001co
oooo00?o0000ooooooooool0<Oooool2o`0000[ooooo0ol0000Cooooo`;o00001?ooool2o`0001;o
oooo1?l00006ooooo`Go000000?oooooo`000?l000003Ol00002ooooo`?o00000_ooool2o`0000Wo
oooo0_l00003ooooo`;o00003oooool6o`0000Gooooo0_l00008ooooo`?o00001_ooool2o`0000;o
oooo0_l00005ooooo`;o00001_ooool2o`0000Cooooo0_l00002ooooo`Co00000_ooool2o`0000?o
oooo0ol0000<ooooo`;o00000_ooool2o`0000Sooooo0_l0000`ooooo`007?ooool00ol0003ooooo
ooooo`0mooooo`?o00002?ooool2o`0000Cooooo0ol000001?oooooo0000o`000?l00004ooooo`;o
00003oooool2o`000003ooooool0003o000000;o00001OoooolFo`0000Cooooo0_l000001?oooooo
0000o`000?l00008ooooo`;o00000_ooool2o`00013ooooo0_l00006ooooo`;o000000?oooooo`00
0?l000002?ooool2o`0001Wooooo0ol00004ooooo`Wo00005Oooool2o`0000cooooo0_l0000`oooo
o`007?ooool00ol0003oooooooooo`0iooooo`Co00002oooool2o`0000Cooooo1ol00002ooooo`Co
00003oooool2o`0000;ooooo0ol00003ooooo`Co00000oooool4o`000003ooooool0003o0000013o
00000_ooool3o`0000Wooooo1_l0000:ooooo`?o00002Oooool2o`0000_ooooo0_l0000Cooooo`;o
00001?ooool4o`0000?ooooo1?l00002ooooo`?o00002?ooool2o`0000Oooooo0_l00004ooooo`;o
0000??ooool001cooooo00?o0000ooooooooool0<Oooool2o`0000Kooooo1?l00003ooooo`;o0000
1Oooool4o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo1?l0000?ooooo`;o
00000oooool8o`0000Cooooo0_l000000ooooooo0000o`00000Co`000003ooooool0003o000000?o
00001?ooool2o`000003ooooool0003o000000;ooooo0_l0000:ooooo`?o00001Oooool2o`000003
ooooool0003o000000;o00002oooool2o`0000[ooooo1Ol000000ooooooo0000o`000002o`0000Ko
oooo0ol00008ooooo`;o00001?ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000Co
oooo0_l0000looooo`007?ooool2o`0002Oooooo0ol00008ooooo`;o00003Oooool3o`0000Cooooo
1?l00002ooooo`?o00005_ooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l00000
1_l00005ooooo`go000000?oooooo`000?l000003Ol00002ooooo`;o000000Coooooo`000?l0003o
oooo0_l00003ooooo`;o00003_ooool2o`000003ooooool0003o000000;o00002_ooool3o`000004
ooooool0003o0000ooooo`;o00001?ooool5o`000003ooooool0003o000000Wooooo0_l00004oooo
o`;o00000_ooool2o`0000Cooooo0_l00002ooooo`;o00000oooool2o`0004Oooooo000Looooo`03
o`000?oooooooooo02Kooooo0ol0000Gooooo`?o00001_ooool2o`0000?ooooo0_l00002ooooo`;o
00004_ooool2o`0000Kooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o
000000?oooooo`000?l000002ol000000ooooooo0000o`000006o`000003ooooool0003o000000;o
oooo0_l000000ooooooo0000o`000005ooooo`;o00000oooool2o`00017ooooo1?l0000:ooooo`;o
00000_ooool2o`000003ooooool0003o000000;o00005_ooool2o`000003ooooool0003o000000co
oooo0_l0000Aooooo`;o0000>Oooool001cooooo00?o0000ooooooooool0>_ooool2o`0000Gooooo
0_l00006ooooo`;o00000_ooool2o`0000?ooooo0_l00005ooooo`;o00002oooool3o`0000cooooo
0_l00002oooooaWo000000?oooooo`000?l000000_l00004ooooo`?o00002Oooool3o`0000?ooooo
0_l00003ooooo`;o00002oooool3o`0000;ooooo0_l0000<ooooo`;o00005_ooool2o`00013ooooo
0_l000000ooooooo0000o`000002o`0000?ooooo0ol00005ooooo`;o0000>Oooool001cooooo00?o
0000ooooooooool0;_ooool2o`0000[ooooo0_l00005ooooo`;o00001oooool2o`000003ooooool0
003o000000[ooooo0_l0000;ooooo`?o000000Coooooo`000?l0003ooooo0_l00004ooooo`Co0000
00?oooooo`000?l000001?l000000ooooooo0000o`00000Do`0000Kooooo0_l00007ooooo`Go0000
1?ooool3o`0000;ooooo0ol0000:ooooo`?o00000_ooool2o`0000gooooo0_l00007ooooo`;o0000
7Oooool3o`000003ooooool0003o000000;o00000oooool3o`000003ooooool0003o000000Gooooo
0_l0000fooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00006_ooool2o`0000kooooo0_l0
0007ooooo`;o00001Oooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000008_l0
00001?oooooo0000o`000?l0000:ooooo`?o00001oooool2o`0000?ooooo0ol00007ooooo`;o0000
2?ooool2o`0000Gooooo0_l00003ooooo`?o00001_ooool2o`0001Cooooo0_l00007ooooo`;o0000
2_ooool2o`000003ooooool0003o000000?ooooo1?l0000fooooo`007?ooool00ol0003ooooooooo
o`0mooooo`;o00000_ooool2o`0001Oooooo0_l00007ooooo`;o00002_ooool7o`000003ooooool0
003o000001go000000Coooooo`000?l0003o00003Oooool2o`0000[ooooo0ol00007ooooo`;o0000
1_ooool4o`0000Gooooo0_l00004ooooo`;o00007?ooool2o`0001?ooooo0_l00006ooooo`;o0000
>?ooool001cooooo00?o0000ooooooooool0>?ooool2o`0000?ooooo0ol000000ooooooo0000o`00
0004ooooo`;o00003?ooool2o`0001Oooooo9ol00002ooooo`;o00003_ooool2o`0001Wooooo0_l0
00000ooooooo0000o`00000<ooooo`;o0000<_ooool2o`00043ooooo000Looooo`03o`000?oooooo
oooo01[ooooo0_l0000Iooooo`;o000000?oooooo`000?l000001?ooool2o`0000Oooooo0_l0000<
ooooo`Co00005Oooool2o`000003ooooool0003o000000?ooooo8?l000000ooooooo0000o`00000E
ooooo`;o00002?ooool2o`000004ooooool0003o0000ooooo`;o00000_ooool4o`0000_ooooo1?l0
000cooooo`;o0000?oooool001cooooo00?o0000ooooooooool06_ooool2o`0000_ooooo0_l0000<
ooooo`;o00001Oooool2o`0001Kooooo1Ol0000Aooooo`Go00000_ooool4o`000003ooooool0003o
000001ko000000?oooooo`000?l000000_l0000Cooooo`;o00002?ooool2o`000004ooooool0003o
0000ooooo`;o00001?ooool2o`0000[ooooo1Ol00006ooooo`;o00008_ooool2o`0000Oooooo0_l0
000oooooo`007?ooool00ol0003oooooooooo`0Wooooo`;o00002_ooool4o`0000Gooooo0_l00003
ooooo`;o00004?ooool4o`0001?ooooo1_l00003ooooob_o00001oooool2o`0000Cooooo0_l00000
1?oooooo0000o`000?l00009ooooo`Co00004_ooool2o`0000Cooooo0_l00003ooooo`;o00003_oo
ool2o`0001;ooooo0_l00002ooooo`Co00000_ooool2o`0003kooooo000Looooo`03o`000?oooooo
oooo02Gooooo0_l0000<ooooo`Co00000_ooool4o`0000?ooooo0ol0000:ooooo`;o000000Cooooo
o`000?l0003ooooo0ol0000@ooooo`;o00001Ooooolao`0000Oooooo0_l00004ooooo`;o00000_oo
ool2o`0000Cooooo0_l00003ooooo`Co00000_ooool2o`0000[ooooo0_l00008ooooo`;o00000ooo
ool3o`0000[ooooo1Ol00003ooooo`;o00001?ooool2o`0000_ooooo1?l00002ooooo`;o0000?_oo
ool001cooooo00?o0000ooooooooool09Oooool2o`0001;ooooo1?l00003ooooo`;o00001oooool2
o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000003Oooool2
o`0000Kooooo8Ol000000ooooooo0000o`000008o`0000;ooooo1?l00005ooooo`;o00003_ooool4
o`0000Oooooo0_l000000ooooooo0000o`000007ooooo`;o00003_ooool2o`0000[ooooo1?l00004
ooooo`;o00001?ooool2o`0000Cooooo0_l0000>ooooo`;o0000>oooool001cooooo00?o0000oooo
ooooool09?ooool2o`0001cooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l0000<oooo
o`;o00001?ooool2o`000004ooooool0003o0000ooooo`Co000000?oooooo`000?l00000:_l0000E
ooooo`;o00000_ooool2o`0000Kooooo0_l0000Cooooo`;o00001_ooool2o`0000Sooooo0_l0000:
ooooo`;o00001?ooool2o`0000kooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0Toooo
o`;o00007?ooool2o`000003ooooool0003o000000oooooo0_l0000=ooooo`;o00001?ooool2o`00
00Cooooo2Ol000000ooooooo0000o`000004o`000003ooooool0003o000001?o00000oooool4o`00
00;ooooo0_l00008ooooo`;o00003oooool2o`0000Gooooo0_l00005ooooo`;o00002Oooool2o`00
00;ooooo0_l000000ooooooo0000o`000003ooooo`Co00001_ooool2o`0000Sooooo0ol00007oooo
o`;o00002_ooool2o`0003gooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`12ooooo`;o000000?o
ooooo`000?l000003oooool2o`0000Sooooo0_l0000;ooooo`Co00000_oooolWo`0000;ooooo0_l0
0003ooooo`;o00001oooool2o`000003ooooool0003o000000Sooooo0_l00009ooooo`;o00000ooo
ool4o`0000Gooooo1_l00005ooooo`;o00001Oooool4o`0000kooooo0ol00004ooooo`;o000000?o
ooooo`000?l000002_ooool2o`0003gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo
0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0Wooooo`;o
00003?ooool3o`0000Gooooo0_l00003ooooo`;o00003_ooool2o`0000cooooo0_l000000ooooooo
0000o`000008oooooaKo000000?oooooo`000?l000006?l000000ooooooo0000o`000004o`000003
ooooool0003o000000Gooooo0_l00008ooooo`;o00003_ooool2o`0000;ooooo0ol00002ooooo`Co
00001_ooool2o`0000Sooooo0_l0000Cooooo`Co00004_ooool2o`0003Sooooo00000ooooooo410@
ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo027ooooo0_l00004ooooo`;o00002oooool4o`0000Gooooo0ol0000=ooooo`;o
00000oooool2o`0000cooooo0_l000000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l0
0000>Ol0000?ooooo`;o00004?ooool5o`0000cooooo0_l00008ooooo`;o00004oooool9o`0000go
oooo0_l00008ooooo`;o0000;_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
2Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0000Qooooo`;o00004Oooool2o`0000So
oooo0_l00003ooooo`;o00002?ooool2o`00017ooooo0_l000000ooooooo0000o`000002o`0000?o
oooo0_l000000ooooooo0000o`00000]o`000003ooooool0003o000000;o000000?oooooo`000?l0
00000ol00003ooooo`Co00003?ooool2o`000003ooooool0003o000000Oooooo0_l000000ooooooo
0000o`000005ooooo`;o00000oooool3o`0000cooooo1?l0000Aooooo`Wo00005oooool2o`0002ko
oooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oeEEEOl0003o
410@olc<c006ooooo`03o`000?oooooooooo03oooooo0_l00002ooooo`;o00004?ooool2o`0000go
oooo0ol00003ooooo`;o000000?oooooo`000?l000000ol000000ooooooo0000o`00000Vo`0000?o
oooo1?l000000ooooooo0000o`000005ooooo`Co00001_ooool2o`000004ooooool0003o0000oooo
o`;o000000?oooooo`000?l000000_ooool3o`0000;ooooo0ol00007ooooo`;o00000oooool3o`00
00cooooo1?l00008ooooo`;o00002?ooool2o`0000;ooooo1?l00017ooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000oooooooo
ool0?oooool2o`0000[ooooo0_l00008ooooo`;o00002_ooool2o`000003ooooool0003o000000Co
oooo1Ol000001?oooooo0000o`000?oooolMo`000003ooooool0003o000000?o000000?oooooo`00
0?l000001?l000000ooooooo0000o`000002o`0001;ooooo0_l000000ooooooo0000o`000006o`00
00;ooooo0ol00003ooooo`;o000000?oooooo`000?l000002_ooool2o`0000cooooo1_l00006oooo
o`;o00002?ooool2o`0000;ooooo1?l00017ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;
ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0>Oooool2o`0000Oooooo0_l00005
ooooo`Co00002?ooool2o`0000[ooooo0_l00002ooooo`;o00000oooool3o`0000Gooooo4_l00002
ooooo`Co000000?oooooo`000?l000002Ol000000ooooooo0000o`000004o`000004ooooool0003o
0000o`0000;ooooo1?l00003ooooo`;o00000_ooool3o`000004ooooool0003o0000o`0000?ooooo
2Ol00004ooooo`;o00000oooool2o`0000kooooo0_l00005ooooo`;o00000oooool4o`00013ooooo
0_l00003ooooo`;o00000oooool2o`0004?ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPco
oooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`0iooooo`;o00000oooool6o`00
00Gooooo0_l0000Aooooo`;o00001oooool2o`0000Sooooo;Ol00002ooooo`?o00000_ooool9o`00
0003ooooool0003o000000;o000000Goooooo`000?l0003o0000ooooo`0;o`0000Cooooo0_l00003
ooooo`;o000000?oooooo`000?l000000_l00005ooooo`;o00000_ooool2o`0000Gooooo0_l00004
ooooo`;o00001Oooool2o`000003ooooool0003o000000Sooooo1_l00003ooooo`;o0000@oooool0
01cooooo00?o0000ooooooooool0?_ooool4o`0000Cooooo0_l00005ooooo`?o00001_ooool2o`00
00Cooooo0_l00007ooooo`;o00000oooool2o`0000;ooooo:_l00002ooooo`;o000000?oooooo`00
0?l000000ol00005ooooo`_o000000?oooooo`000?l000004_l00003ooooo`;o000000?oooooo`00
0?l000000_l00005ooooo`;o00000oooool2o`0000[ooooo1?l00003ooooo`;o000000?oooooo`00
0?l000001?ooool8o`0004[ooooo000Looooo`03o`000?oooooooooo03kooooo0ol00005ooooo`;o
00000_ooool2o`000004ooooool0003o0000o`0000Kooooo0_l0000=ooooo`;o00000oooool^o`00
0003ooooool0003o000000Oo00001?ooool2o`0000Cooooo7?l000000ooooooo0000o`000003o`00
0003ooooool0003o000000;ooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo0ol00006oooo
o`?o00003?ooool4o`0004kooooo000Looooo`03o`000?oooooooooo03[ooooo0_l00002ooooo`?o
00002Oooool2o`0000Kooooo0_l00002ooooo`;o00003Oooool2o`0000Cooooo2_l000001?oooooo
0000o`000?oooolKo`0000;ooooo0_l000000ooooooo0000o`000005o`0000;ooooo1_l00002oooo
o`;o00000_oooolPo`000003ooooool0003o000000;ooooo0_l00002ooooo`?o000000?oooooo`00
0?l000000_ooool3o`0000Kooooo1?l0001Mooooo`007?ooool00ol0003oooooooooo`0jooooo`;o
00002?ooool2o`0000Sooooo0ol000000ooooooo0000o`00000Aooooo`;o00001_ooool@o`0000;o
oooo0_l000000ooooooo0000o`00000=o`000003ooooool0003o000000Co00000_ooool2o`000004
ooooool0003o0000ooooo`Ko00001?ooool2o`0000;ooooo3ol000000ooooooo0000o`00000;o`00
00Cooooo0_l00007ooooo`;o00001Oooool2o`0000?ooooo0_l00004ooooo`;o00003oooool3o`00
00_ooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00005_ooool2o`000003
ooooool0003o000000Gooooo0ol000000ooooooo0000o`00000IooooobCo00000oooool2o`0000Co
oooo0ol00002ooooo`?o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00000Po`00
00Cooooo0_l00006ooooo`;o00001_ooool2o`0000?ooooo0_l00003ooooo`Co00001?ooool2o`00
00Sooooo1Ol00009ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0;?ooool2o`0000co
oooo0_l00004ooooo`;o00001Oooool2o`0000Wooooo0_l00002ooooo`;o00005Oooool5o`000003
ooooool0003o000000;o000000?oooooo`000?l000002Ol00002ooooo`co00000oooool3o`000004
ooooool0003o0000ooooo`;o00000_ooool2o`0000Gooooo0_l000000ooooooo0000o`00000Qo`00
00Sooooo0_l000000ooooooo0000o`00000@ooooo`Co00001?ooool4o`0000Sooooo0ol00009oooo
o`;o0000?_ooool001cooooo00?o0000ooooooooool09Oooool4o`00017ooooo1?l00002ooooo`;o
00002_ooool2o`0000Sooooo0_l0000Kooooo`Ko000000?oooooo`000?l000000ol000000ooooooo
0000o`000006o`000003ooooool0003o000000So000000Goooooo`000?l0003o0000ooooo`02o`00
0003ooooool0003o000000?ooooo0_l00003ooooo`;o00001_oooolPo`0000Oooooo0_l0000Goooo
o`;o00001?ooool2o`0000?ooooo0_l0000?ooooo`;o0000?_ooool001cooooo00?o0000oooooooo
ool09Oooool4o`0001?ooooo0_l00004ooooo`;o00001Oooool2o`000003ooooool0003o000002Go
oooo5Ol000000ooooooo0000o`00000;o`0000Wooooo0ol00003ooooo`;o00001?ooool5o`0000?o
oooo7_l00003ooooo`;o00004oooool2o`0000;ooooo0_l000000ooooooo0000o`000006ooooo`;o
0000Coooool001cooooo00?o0000ooooooooool0@_ooool2o`0000Gooooo0_l00003ooooo`;o0000
3Oooool2o`0000Kooooo0_l00009ooooo`;o000000?oooooo`000?l000004ol000000ooooooo0000
o`000002o`0000;ooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000;o0000
00?oooooo`000?l000000_l0000:ooooo`Go00000_oooolOo`0000Wooooo0_l0000=ooooo`;o0000
1Oooool2o`0000Kooooo0_l0000:ooooo`?o0000@_ooool001cooooo00?o0000ooooooooool0@_oo
ool4o`0000;ooooo0_l00004ooooo`;o00003Oooool2o`0000Kooooo0_l00009ooooo`;o00001?oo
ool5o`0000;ooooo2ol000000ooooooo0000o`000003o`000003ooooool0003o000000;ooooo2Ol0
00000ooooooo0000o`000004o`0000;ooooo0_l00004oooooago000000?oooooo`000?l000000_l0
00001?oooooo0000o`000?l00009ooooo`;o00005?ooool2o`0001;ooooo0ol00012ooooo`007?oo
ool00ol0003oooooooooo`0oooooo`;o00000oooool3o`000004ooooool0003o0000o`0000Kooooo
0_l000000ooooooo0000o`00000@ooooo`;o00003_ooool5o`0000;ooooo3_l000000ooooooo0000
o`000006o`0000?ooooo0_l000001?oooooo0000o`000?ooool6o`0000;ooooo0_l00004ooooo`;o
00000_oooolQo`0000;ooooo0_l0000?ooooo`;o00001oooool2o`0001Kooooo0_l00013ooooo`00
7?ooool2o`00043ooooo0_l00003ooooo`?o00000_ooool2o`0000Kooooo0_l000000ooooooo0000
o`000005ooooo`;o00002Oooool2o`0000kooooo1_l000000ooooooo0000o`00000<o`000003oooo
ool0003o000000Ko00001_ooool9o`0000[ooooo1?l000000ooooooo0000o`00000Jo`0000Cooooo
0_l000000ooooooo0000o`00000:ooooo`Co00001oooool2o`0001;ooooo0ol00016ooooo`007?oo
ool00ol0003oooooooooo`1Kooooo`;o00001?ooool2o`0000;ooooo0_l0000Cooooo`;o00001?oo
ool2o`0000;ooooo0_l00003ooooo`;o00000oooool2o`0000_ooooo0_l00004ooooo`Co00001?oo
ool2o`0000;ooooo0ol000000ooooooo0000o`00000Ko`0000?ooooo0ol000000ooooooo0000o`00
0002o`0000Sooooo0_l00003ooooo`;o00006?ooool3o`0004Kooooo000Looooo`03o`000?oooooo
oooo05Cooooo0_l0000;ooooo`;o00000_ooool3o`0000Sooooo0_l000000ooooooo0000o`000003
ooooo`Ko00000_ooool6o`0000?ooooo0_l0000Hooooo`;o00001?ooool2o`0000?ooooo0_l00000
0ooooooo0000o`00000Lo`0000;ooooo1Ol000001?oooooo0000o`000?l00008ooooo`;o00000_oo
ool2o`0000gooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`16ooooo`;o00003?ooool2
o`000003ooooool0003o000000;o00002oooool2o`0000Sooooo0_l000001?oooooo0000o`000?oo
ool8o`000003ooooool0003o000000Go00006Oooool2o`0000gooooo0_l000000ooooooo0000o`00
000Lo`000004ooooool0003o0000ooooo`?o00000_ooool4o`0000Kooooo1_l000000ooooooo0000
o`000007ooooo`Go0000D_ooool001cooooo00?o0000ooooooooool0=_ooool2o`0000kooooo0_l0
0007ooooo`Go00000oooool4o`0000_ooooo0_l00004ooooo`;o00001oooool3o`0000?ooooo0_l0
0002ooooo`Co000000?oooooo`000?l000000_l00007ooooo`;o00001Oooool2o`0000Oooooo0_l0
000@oooooaco00000oooool4o`0000Kooooo0_l00006ooooo`Co00000oooool2o`0000Oooooo0ol0
0007ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0<oooool2o`000003ooooool0003o
000001Oooooo1Ol00005ooooo`;o00002oooool2o`0000Cooooo0ol00006ooooo`?o00001oooool6
o`000003ooooool0003o000000Oooooo0_l00005ooooo`;o00005Oooool2o`000003ooooool0003o
0000017o000000?oooooo`000?l000002Ol00003ooooo`Co00003?ooool4o`0001Kooooo0_l0001;
ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00006_ooool2o`0000Sooooo0_l00007oooo
o`;o00001?ooool2o`0000?ooooo1?l0000:ooooo`;o00000_ooool6o`0000Gooooo0_l0000Doooo
o`;o00002oooool2o`000003ooooool0003o000000;ooooo3ol000000ooooooo0000o`000009o`00
00Gooooo0_l0000;ooooo`Go00004_ooool2o`0004oooooo000Looooo`03o`000?oooooooooo05Wo
oooo0_l00006ooooo`?o00001?ooool2o`0000Gooooo0_l0000:ooooo`;o00000_ooool4o`0000Oo
oooo1Ol00003ooooo`;o00003?ooool2o`0000Cooooo0_l00005ooooo`;o00001_oooolJo`0001;o
oooo0_l000000ooooooo0000o`00000Booooo`Co0000COooool001cooooo00?o0000ooooooooool0
Boooool2o`0001?ooooo0ol0000Jooooo`Go00002_ooool3o`0000?ooooo0_l0000Booooo`;o0000
1Oooool2o`0000Kooooo1ol000000ooooooo0000o`00000=o`0000;ooooo0_l00004ooooo`;o0000
2oooool2o`000003ooooool0003o000001Cooooo0_l0001=ooooo`007?ooool00ol0003ooooooooo
o`1;ooooo`;o00000oooool2o`0000kooooo0_l000000ooooooo0000o`00000Aooooo`;o00000_oo
ool2o`000003ooooool0003o000000?o00001_ooool2o`0000Gooooo1?l00008ooooo`;o00003_oo
ool2o`0000Gooooo0_l000000ooooooo0000o`00000Fo`000004ooooool0003o0000ooooo`;o0000
00?oooooo`000?l000001?ooool2o`0001Gooooo0_l00006ooooo`;o0000C_ooool001cooooo00?o
0000ooooooooool0C?ooool2o`0000;ooooo0_l0000<ooooo`Co000000?oooooo`000?l000004Ooo
ool2o`0000;ooooo0_l00002ooooo`;o00002?ooool2o`0000Gooooo1?l00007ooooo`Co00000_oo
ool2o`0000Wooooo1?l00003ooooo`;o000000?oooooo`000?l000003Ol00002ooooo`Oo00001?oo
ool2o`000003ooooool0003o000000Cooooo0_l0000Aooooo`;o00000_ooool2o`0000?ooooo0_l0
00001?oooooo0000o`000?ooool2o`000003ooooool0003o000004Sooooo000Looooo`03o`000?oo
oooooooo03Gooooo0_l0000Eooooo`Co00003_ooool2o`00037ooooo0_l000000ooooooo0000o`00
0003o`000003ooooool0003o000000;o00000_ooool2o`0000[ooooo0ol00009ooooo`oo000000?o
ooooo`000?l000000ol00004ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`Co0000
3_ooool2o`0000Kooooo0ol00004ooooo`;o000000?oooooo`000?l00000B?ooool001cooooo00?o
0000ooooooooool0=Oooool2o`0001Oooooo0_l0000;ooooo`;o00001?ooool2o`0001cooooo0_l0
000Cooooo`Go00005_ooool2o`0000Oooooo0ol000000ooooooo0000o`000004o`0000;ooooo1?l0
00000ooooooo0000o`000002o`0000;ooooo1?l00004ooooo`;o00000_ooool4o`0000[ooooo0_l0
0002ooooo`;o00001_ooool5o`0004oooooo000Looooo`03o`000?oooooooooo04?ooooo0_l0000F
ooooo`;o00001?ooool2o`0001Oooooo0_l00003ooooo`;o000000?oooooo`000?l000001?ooool2
o`0000cooooo0_l0000Gooooo`Co00001Oooool@o`000004ooooool0003o0000ooooo`;o000000?o
ooooo`000?l000000_l0000Fooooo`;o00000_ooool4o`000005ooooool0003o0000o`000?ooool0
1?l000000ooooooo0000o`00001<ooooo`007?ooool00ol0003oooooooooo`0looooo`;o00001Ooo
ool3o`0000Oooooo0_l0000?ooooo`;o00001Oooool2o`0000;ooooo0_l00002ooooo`;o00002ooo
ool2o`0000Kooooo0_l00004ooooo`;o00009Oooool4o`0000Kooooo3_l00005ooooo`;o000000?o
ooooo`000?l000004oooool2o`0000Wooooo1_l00006ooooo`;o0000C?ooool001cooooo00?o0000
ooooooooool0??ooool2o`0000Kooooo0_l00007ooooo`;o00003oooool2o`000003ooooool0003o
000000;ooooo1_l00002ooooo`;o00000_ooool2o`0000Sooooo0ol0000;ooooo`;o00001?ooool2
o`00023ooooo0_l00006ooooo`;o00003Oooool2o`0000;ooooo0_l0000Fooooo`;o00001_ooool2
o`0000;ooooo0ol0001Fooooo`007?ooool2o`0004Gooooo0_l00008ooooo`;o00004Oooool2o`00
00Cooooo0_l00008ooooo`;o00001?ooool2o`0000;ooooo0ol00007ooooo`;o00000_ooool2o`00
00Cooooo0_l0000Pooooo`;o00001_ooool4o`0000_ooooo0_l00002ooooo`;o00001?ooool3o`00
01Oooooo0_l00003ooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0A?ooool2o`0000So
oooo0ol000000ooooooo0000o`00000=ooooo`;o00005?ooool2o`0000Sooooo0_l00002ooooo`;o
0000=?ooool2o`0000[ooooo0ol00002ooooo`;o00001?ooool3o`0000Cooooo0_l0000:ooooo`;o
00000_ooool2o`0005kooooo000Looooo`03o`000?oooooooooo04Kooooo0_l00007ooooo`;o0000
00?oooooo`000?l000003Oooool2o`0001;ooooo0ol000000ooooooo0000o`000005ooooo`?o0000
>_ooool2o`0000Sooooo0ol0000?ooooo`;o00001Oooool2o`0000?ooooo0_l00002ooooo`;o0000
G_ooool001cooooo00?o0000ooooooooool0A_ooool2o`0001Cooooo0_l00003ooooo`;o00004?oo
ool5o`000003ooooool0003o000000Gooooo0_l0000kooooo`;o00000oooool2o`0000kooooo0_l0
000<ooooo`;o00001Oooool2o`0000Cooooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`1L
ooooo`;o00005Oooool2o`0001Oooooo0_l0000dooooo`;o00000oooool2o`000003ooooool0003o
000000;ooooo0_l00002ooooo`;o00002oooool4o`0000Cooooo0_l00004ooooo`;o0000F_ooool0
01cooooo00?o0000ooooooooool0F?ooool5o`0001;ooooo0_l00004ooooo`;o00002_ooool2o`00
00Wooooo0ol0000Oooooo`;o00005oooool2o`000003ooooool0003o000000;ooooo0_l0000?oooo
o`Co00003Oooool2o`0000Oooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`18ooooo`;o
00001?ooool2o`0000Sooooo1Ol000000ooooooo0000o`000004ooooo`;o00000oooool2o`0000Co
oooo0_l00002ooooo`Go00002Oooool2o`0000Sooooo1?l0000Oooooo`;o00000oooool2o`0001Go
oooo0_l00006ooooo`;o00002oooool4o`000003ooooool0003o000000;o00000oooool3o`0000;o
oooo0_l00007ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0B?ooool2o`0000Cooooo
0_l00004ooooo`;o00002?ooool2o`0000?ooooo0ol00003ooooo`;o00002?ooool5o`0001?ooooo
0_l0000Sooooo`;o000000?oooooo`000?l000005Oooool2o`0000Kooooo0_l0000:ooooo`;o0000
00Coooooo`000?l0003ooooo1?l00003ooooo`?o0000Foooool001cooooo00?o0000ooooooooool0
@oooool2o`0000_ooooo0_l00002ooooo`;o00003Oooool2o`0000;ooooo0_l0000;ooooo`;o0000
>_ooool2o`000003ooooool0003o0000027ooooo0_l00006ooooo`;o00002?ooool2o`0005oooooo
000Looooo`03o`000?oooooooooo04?ooooo0_l00004ooooo`;o00001Oooool2o`0000?ooooo0_l0
000@ooooo`;o00002Oooool3o`0003kooooo0_l0000=ooooo`;o00004_ooool2o`00013ooooo0_l0
001Oooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00002_ooool2o`0000Kooooo0_l00005
ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o00000_ooool3o`000004ooooool0
003o0000o`0001Cooooo0_l00003ooooo`;o00005_ooool2o`0000Sooooo1?l0000:ooooo`Ko0000
1Oooool2o`0007[ooooo000Looooo`03o`000?oooooooooo05cooooo0ol00002ooooo`;o000000?o
ooooo`000?l000001ol000001?oooooo0000o`000?ooool2o`0000;ooooo1?l00006ooooo`;o0000
2_ooool4o`0000?ooooo0_l0000Fooooo`;o00001_ooool6o`0000cooooo1?l00005ooooo`;o0000
2Oooool2o`0000Kooooo0_l0000:ooooo`;o0000Foooool001cooooo00?o0000ooooooooool0F?oo
ool2o`0000;ooooo0_l00002ooooo`?o00000oooool2o`000003ooooool0003o000000Kooooo0ol0
00000ooooooo0000o`000008ooooo`;o00002_ooool2o`0002Gooooo0_l00002ooooo`;o00001ooo
ool4o`0001Gooooo0_l00006ooooo`;o00002_ooool2o`0005_ooooo000Looooo`03o`000?oooooo
oooo05Sooooo0_l00006ooooo`;o00001?ooool2o`0000;ooooo0ol000001?oooooo0000o`000?oo
ool3o`0001Wooooo0_l000000ooooooo0000o`000002ooooo`;o0000:Oooool4o`0000Oooooo0_l0
0006ooooo`;o00000_ooool2o`0001?ooooo0_l00006ooooo`;o0000E?ooool001cooooo00?o0000
ooooooooool0H_ooool2o`0000Cooooo1Ol000001?oooooo0000o`000?ooool2o`0001[ooooo0_l0
00000ooooooo0000o`000002ooooo`?o00005Oooool4o`0001Gooooo0ol00002ooooo`;o00000ooo
ool2o`000003ooooool0003o000000;ooooo0_l00008ooooo`Co00001oooool2o`0000Kooooo0_l0
001Dooooo`007?ooool00ol0003oooooooooo`1Kooooo`;o00000oooool4o`0000?ooooo0ol0000T
ooooo`;o000000?oooooo`000?l000000_ooool2o`0001Gooooo1?l0000=ooooo`;o00001_ooool3
o`0000Oooooo0_l0000?ooooo`Co0000IOooool001cooooo0_l0001Iooooo`;o000000?oooooo`00
0?l000001Ol00005ooooo`;o000000?oooooo`000?l000006?ooool2o`0000Sooooo0_l000000ooo
oooo0000o`000004o`000003ooooool0003o000001?ooooo0_l00006ooooo`?o00001Oooool2o`00
00Kooooo0_l0000:ooooo`;o00001_ooool2o`0006kooooo000Looooo`03o`000?oooooooooo05So
oooo0_l00003ooooo`Co000000Coooooo`000?l0003o00001Oooool2o`000003ooooool0003o0000
01Gooooo0_l00002ooooo`;o00002Oooool4o`000003ooooool0003o000000gooooo0_l00004oooo
o`;o00001_ooool3o`0001Cooooo0_l00003ooooo`;o00001_ooool2o`0000Gooooo0_l0001Woooo
o`007?ooool00ol0003oooooooooo`1Dooooo`;o00001oooool2o`0000?ooooo0ol00008ooooo`;o
00005Oooool2o`0000;ooooo0_l00007ooooo`;o00005?ooool2o`0000;ooooo0ol00008ooooo`;o
00004_ooool4o`0000?ooooo0_l00005ooooo`;o00001_ooool2o`0006Oooooo000Looooo`03o`00
0?oooooooooo05Cooooo0_l00007ooooo`;o00002_ooool2o`0000Gooooo0_l0000Booooo`;o0000
2oooool2o`0000Oooooo0_l0000;ooooo`;o00000_ooool3o`0000;ooooo0_l00004ooooo`;o0000
1oooool2o`0000Kooooo0_l000000ooooooo0000o`000002o`0000[ooooo0_l000000ooooooo0000
o`00001/ooooo`007?ooool00ol0003oooooooooo`1Sooooo`?o00000oooool2o`0000Gooooo0_l0
000Xooooo`;o00002oooool2o`0000Oooooo0_l00004ooooo`;o00000_ooool2o`0000?ooooo0_l0
0006ooooo`;o00004_ooool2o`0006cooooo000Looooo`03o`000?oooooooooo05oooooo0_l00002
ooooo`Co00006Oooool3o`0001Oooooo0_l0000Jooooo`;o00000_ooool3o`0000kooooo0_l0000=
ooooo`;o0000KOooool001cooooo00?o0000ooooooooool0Goooool2o`0000Cooooo0ol00007oooo
o`;o00000oooool2o`0000[ooooo0ol00004ooooo`;o00004Oooool2o`0000Cooooo0_l0000Ioooo
o`Co00000_ooool2o`0000Gooooo0_l000000ooooooo0000o`000005ooooo`;o00001_ooool2o`00
00Oooooo0_l0001Tooooo`007?ooool00ol0003oooooooooo`1Vooooo`;o00001Oooool4o`0000?o
oooo0_l00003ooooo`;o00002_ooool4o`0000oooooo0ol00002ooooo`;o000000?oooooo`000?l0
00006Oooool4o`0000;ooooo0_l00005ooooo`;o00002?ooool2o`0000oooooo0_l0001Tooooo`00
7?ooool00ol0003oooooooooo`1Fooooo`;o00001oooool2o`0000Sooooo0_l00002ooooo`?o0000
2Oooool2o`0000[ooooo0_l00004ooooo`;o00002oooool3o`0000;ooooo0_l0000Looooo`;o0000
1_ooool3o`0008?ooooo000Looooo`03o`000?oooooooooo05Kooooo0_l00007ooooo`;o00002?oo
ool2o`0000?ooooo0_l00003ooooo`Co00000_ooool2o`0000Wooooo0_l00005ooooo`;o00000ooo
ool2o`0001gooooo0_l0000:ooooo`;o00001_ooool3o`0000Wooooo0_l0001hooooo`007?ooool0
0ol0003oooooooooo`1Sooooo`;o00003_ooool4o`0000gooooo0_l00007ooooo`;o000000?ooooo
o`000?l000001_ooool2o`0000Oooooo0_l00005ooooo`;o00001Oooool4o`0000Cooooo0_l00005
ooooo`;o00002_ooool2o`0000?ooooo0_l0001hooooo`007?ooool00ol0003oooooooooo`1Soooo
o`;o00004oooool2o`0001?ooooo0_l00009ooooo`;o000000?oooooo`000?l000001?ooool2o`00
00;ooooo0_l000000ooooooo0000o`000005ooooo`Co000000Coooooo`000?l0003ooooo0_l00005
ooooo`;o00002_ooool2o`000003ooooool0003o000007[ooooo000Looooo`03o`000?oooooooooo
07Kooooo1?l0000Jooooo`;o00000oooool4o`0000Gooooo0_l000001?oooooo0000o`000?l00007
ooooo`;o00000oooool2o`0000gooooo0_l00008ooooo`;o0000N_ooool001cooooo00?o0000oooo
ooooool0Koooool2o`0000Gooooo0_l0000Cooooo`Co00001Oooool4o`000003ooooool0003o0000
00Oooooo0_l00002ooooo`;o00006oooool2o`0000Oooooo1?l0001iooooo`0000Koooooonk^k_lb
<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o
0000ooooooooool0Koooool2o`0000oooooo0_l00009ooooo`Co00001oooool2o`0000kooooo0_l0
000:ooooo`;o00001Oooool2o`0000[ooooo0_l00005ooooo`Co0000NOooool00006oooooomgMgOo
V9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03
o`000?oooooooooo06Oooooo0ol0000Aooooo`;o00000oooool2o`0000Gooooo0_l0000Fooooo`;o
00004Oooool2o`0000Gooooo0_l0000:ooooo`;o0000P_ooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool0I?ooool2o`000004ooooool0003o0000o`0000Wooooo0_l00006ooooo`;o00001oooool2o`00
0003ooooool0003o000001Kooooo0_l00007ooooo`;o00002?ooool2o`0000Gooooo1?l00008oooo
o`;o0000P_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Olb<S;o
V9RHoooooonHV9So<S8b00Kooooo0ol0001Tooooo`;o00003Oooool2o`0000oooooo0_l00005oooo
o`;o00006?ooool5o`0000Sooooo0_l00006ooooo`?o00001?ooool2o`0000;ooooo0_l00022oooo
o`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05olc<c?l0003o0000o`00
0?o<c<`01_ooool00ol0003oooooooooo`1Tooooo`;o00001oooool2o`0000;ooooo0_l00005oooo
o`;o00000_ooool2o`0000[ooooo1Ol0000Hooooo`?o00000_ooool2o`0000kooooo0_l000000ooo
oooo0000o`000004o`0008Kooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wo
oooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo06Cooooo0_l00007oooo
o`;o00000_ooool2o`0000Gooooo0_l00002ooooo`;o00001oooool2o`000004ooooool0003o0000
o`0001?ooooo0_l000001?oooooo0000o`000?ooool2o`0000Cooooo1?l00004ooooo`Co00001ooo
ool4o`00013ooooo0_l00003ooooo`;o0000LOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0QOooool2o`0001Oo
oooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000?ooooo0_l00004oooo
o`Co00001oooool2o`00017ooooo0ol00003ooooo`;o0000LOooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0LOoo
ool4o`0000cooooo0_l0000Eooooo`;o00002?ooool2o`0000;ooooo0ol0000?ooooo`;o00001ooo
ool2o`0000gooooo0_l0001gooooo`007?ooool00ol0003oooooooooo`1aooooo`Go00002oooool2
o`0000Sooooo0_l0000;ooooo`;o00002?ooool2o`0000;ooooo0_l0000@ooooo`;o00000oooool2
o`0000;ooooo0_l00026ooooo`007?ooool00ol0003oooooooooo`1dooooo`;o00004_ooool2o`00
0003ooooool0003o000002Gooooo0ol00008ooooo`;o0000R_ooool001cooooo00?o0000oooooooo
ool0J?ooool2o`0001Cooooo0_l00008ooooo`;o00002?ooool2o`0000;ooooo0_l0000;ooooo`;o
00003?ooool4o`0009Cooooo000Looooo`03o`000?oooooooooo06Sooooo0_l0000Dooooo`;o0000
0_ooool2o`0000kooooo0_l00002ooooo`;o00002oooool2o`0000cooooo0_l0002Fooooo`007?oo
ool00ol0003oooooooooo`22ooooo`;o0000=oooool2o`0008cooooo000Looooo`03o`000?oooooo
oooo07Wooooo0_l0000Jooooo`Co000000?oooooo`000?l000004?ooool2o`0000gooooo0_l0002<
ooooo`007?ooool00ol0003oooooooooo`1iooooo`;o00006_ooool4o`000003ooooool0003o0000
013ooooo0_l0000<ooooo`;o000000?oooooo`000?l00000R_ooool001cooooo00?o0000oooooooo
ool0K_ooool2o`0003Sooooo0_l0000@ooooo`;o000000?oooooo`000?l00000R_ooool001cooooo
00?o0000ooooooooool0K_ooool2o`0003Sooooo0_l0000:ooooo`;o0000Toooool001cooooo00?o
0000ooooooooool0]?ooool2o`0009?ooooo000Looooo`03o`000?oooooooooo073ooooo0_l00005
ooooo`;o0000>?ooool2o`0000?ooooo0_l0002Aooooo`007?ooool2o`00077ooooo0_l00005oooo
o`;o0000>?ooool2o`0000?ooooo0_l0002Aooooo`007?ooool00ol0003oooooooooo`2Xooooo`;o
00003?ooool2o`00097ooooo000Looooo`03o`000?oooooooooo0:Sooooo0_l0000@ooooo`;o0000
SOooool001cooooo00?o0000ooooooooool0^_ooool2o`0008gooooo000Looooo`03o`000?oooooo
oooo07kooooo0_l0000>ooooo`;o00006_ooool2o`0001kooooo0_l0001mooooo`007?ooool00ol0
003oooooooooo`1nooooo`;o00003_ooool2o`0001[ooooo0_l0000Nooooo`;o0000OOooool001co
oooo00?o0000ooooooooool0VOooool2o`0001Cooooo0_l0002Hooooo`007?ooool00ol0003ooooo
ooooo`2Iooooo`;o00002_ooool2o`0000Sooooo0_l0002Hooooo`007?ooool00ol0003ooooooooo
o`2Uooooo`;o0000X_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`1mooooo`;o0000b_ooool001cooooo00?o0000ooooooooool0OOooool2o`0000ko
oooo0_l0002jooooo`007?ooool00ol0003oooooooooo`2=ooooo`;o0000^_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0002gooooo`;o0000TOooool001cooooo
00?o0000ooooooooool0]_ooool2o`00097ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooooooo
ool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
B_ooool001Cooooo00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o0000
ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03
o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`004_oo
ool00omEEEGoIVIVo`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo002Qooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05_ooool4o`000003
oa0@4?oooooooooo00Go00000oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b
<_l0003o410@olc<c02<ooooo`00X_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l0000<
ooooo`03o`000?oooooooooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B400oooool01OmEEEGoMgMgoooooonHV9So8B4Q08cooooo002Rooooo`05o`00
0?ooooooooooooooool000006oooool00ol0003oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00Co
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000S?ooool0
0:;ooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00003?ooool00ol0003oooooooooo`04
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`000?nH
V9SooooooiRHV?lQ8B40S?ooool00:;ooooo00Go0000ohN7QoooooooZJVYo`00000Kooooo`03o`00
0?oooooooooo00Gooooo00?oMgMgofIVI_ooool00_ooool01Ol0003oEEEEo`000?l@413oc<c<00?o
oooo00Go0000oeEEEOl0003o410@olc<c02<ooooo`00XOooool00ol@413o0000ogMgM`02o`000003
oiRHV?oooooooooo01Wooooo00?o0000ooooooooool01_ooool01_l0003oooooooooooooooooEEEE
ohN7Q`Kooooo00?oEEEEohN7Qoooool0S_ooool00<;ooooo00?o0000ooooooooool00_ooool01Ol0
003o^[ZjoooooonHV9So410@00?ooooo00?ogMgMoa0@4?nHV9P01Oooool00ooMgMgo410@oiRHV02>
ooooo`00`?ooool00omEEEGoIVIVo`000004ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool0
1?o<c<coA4A4o`000?l@4104ooooo`04olc<c?m4A4Co0000oa0@48cooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1272) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.53083 .65152 Mdot
.55426 .67416 Mdot
.52348 .36663 Mdot
.4119 .54685 Mdot
.63722 .23613 Mdot
.55396 .36112 Mdot
.69585 .47635 Mdot
.66549 .51906 Mdot
.52595 .34377 Mdot
.75618 .53726 Mdot
.69252 .50552 Mdot
.49425 .61902 Mdot
.66171 .50186 Mdot
.42752 .57361 Mdot
.60741 .16169 Mdot
.46958 .56841 Mdot
.53875 .66363 Mdot
.38341 .41024 Mdot
.39714 .52495 Mdot
.51482 .38523 Mdot
.54642 .61655 Mdot
.41912 .5707 Mdot
.60541 .67272 Mdot
.42809 .57416 Mdot
.38406 .55305 Mdot
.5846 .64528 Mdot
.51172 .63649 Mdot
.37506 .57703 Mdot
.36624 .59282 Mdot
.67264 .51999 Mdot
.27948 .44678 Mdot
.60451 .18432 Mdot
.33643 .60061 Mdot
.3578 .23932 Mdot
.64047 .49826 Mdot
.44373 .76408 Mdot
.54188 .36029 Mdot
.67662 .48838 Mdot
.67963 .485 Mdot
.63595 .48509 Mdot
.68394 .49869 Mdot
.59675 .66558 Mdot
.63824 .5741 Mdot
.51037 .29905 Mdot
.46393 .58087 Mdot
.73936 .34568 Mdot
.52733 .80987 Mdot
.42824 .61024 Mdot
.54315 .64895 Mdot
.4251 .25748 Mdot
.66159 .33123 Mdot
.6572 .47313 Mdot
.50666 .37622 Mdot
.15951 .66239 Mdot
.65485 .48648 Mdot
.35946 .52694 Mdot
.53236 .3625 Mdot
.41383 .58212 Mdot
.43032 .57844 Mdot
.36573 .68541 Mdot
.45298 .59609 Mdot
.39808 .37896 Mdot
.58696 .71011 Mdot
.59115 .53225 Mdot
.53263 .34587 Mdot
.69291 .48984 Mdot
.56916 .67742 Mdot
.65381 .4991 Mdot
.43108 .50525 Mdot
.52447 .39839 Mdot
.42664 .61214 Mdot
.69319 .49936 Mdot
.53959 .68189 Mdot
.38584 .60136 Mdot
.43828 .33783 Mdot
.82296 .45121 Mdot
.33564 .37244 Mdot
.42768 .74109 Mdot
.34532 .68333 Mdot
.46329 .27344 Mdot
.39327 .5339 Mdot
.32146 .47517 Mdot
.79986 .41455 Mdot
.60869 .65926 Mdot
.47156 .61423 Mdot
.32331 .33128 Mdot
.38623 .59826 Mdot
.75926 .33917 Mdot
.401 .62203 Mdot
.36158 .30787 Mdot
.53019 .33304 Mdot
.56162 .65868 Mdot
.41081 .54475 Mdot
.38397 .60704 Mdot
.2897 .6476 Mdot
.34367 .56403 Mdot
.3991 .56871 Mdot
.55087 .6359 Mdot
.65543 .47486 Mdot
.33477 .5728 Mdot
.52424 .29514 Mdot
.53146 .32249 Mdot
.44273 .54726 Mdot
.57267 .3452 Mdot
.57993 .70429 Mdot
.38835 .60761 Mdot
.67288 .48151 Mdot
.44675 .5612 Mdot
.68398 .69864 Mdot
.5542 .67853 Mdot
.37096 .58383 Mdot
.37301 .34964 Mdot
.27439 .69292 Mdot
.5519 .65532 Mdot
.55653 .28527 Mdot
.36277 .55166 Mdot
.39803 .57859 Mdot
.55592 .67164 Mdot
.57288 .33084 Mdot
.77187 .3539 Mdot
.5779 .63169 Mdot
.6363 .50834 Mdot
.52776 .6563 Mdot
.47746 .55633 Mdot
.54305 .33777 Mdot
.60294 .28138 Mdot
.66969 .65292 Mdot
.29646 .42027 Mdot
.38997 .59771 Mdot
.70285 .57756 Mdot
.51617 .33147 Mdot
.57237 .66494 Mdot
.65555 .5042 Mdot
.44608 .63267 Mdot
.57993 .6914 Mdot
.69022 .51364 Mdot
.38561 .35105 Mdot
.66895 .38882 Mdot
.58446 .69947 Mdot
.4522 .42518 Mdot
.71053 .49723 Mdot
.64625 .47428 Mdot
.27661 .2913 Mdot
.56992 .67476 Mdot
.38748 .37051 Mdot
.65597 .51081 Mdot
.2796 .40753 Mdot
.46137 .57906 Mdot
.28656 .50053 Mdot
.53015 .8241 Mdot
.33772 .2499 Mdot
.69626 .40282 Mdot
.36322 .38265 Mdot
.66969 .52685 Mdot
.39259 .55592 Mdot
.57225 .63956 Mdot
.5979 .65701 Mdot
.45321 .59025 Mdot
.39373 .54144 Mdot
.41896 .616 Mdot
.39191 .61462 Mdot
.48157 .66721 Mdot
.36084 .54441 Mdot
.44883 .81035 Mdot
.56108 .65483 Mdot
.40361 .55028 Mdot
.561 .38391 Mdot
.35725 .61495 Mdot
.6889 .49858 Mdot
.41249 .57582 Mdot
.40928 .54618 Mdot
.45697 .58444 Mdot
.6523 .47435 Mdot
.65901 .20714 Mdot
.30988 .71836 Mdot
.61859 .2055 Mdot
.40958 .33087 Mdot
.56921 .36585 Mdot
.38546 .58889 Mdot
.39104 .36012 Mdot
.49857 .75423 Mdot
.42841 .55161 Mdot
.5272 .87395 Mdot
.40656 .56726 Mdot
.64028 .22798 Mdot
.36623 .51504 Mdot
.52874 .18024 Mdot
.31011 .47182 Mdot
.38243 .56342 Mdot
.59152 .5642 Mdot
.61002 .47904 Mdot
.59222 .35387 Mdot
.6796 .49939 Mdot
.5566 .38604 Mdot
.52705 .36737 Mdot
.61968 .55266 Mdot
.48552 .63074 Mdot
.32413 .56675 Mdot
.38081 .61757 Mdot
.52936 .40342 Mdot
.6017 .70578 Mdot
.40517 .3615 Mdot
.53855 .63087 Mdot
.81389 .33398 Mdot
.6902 .32017 Mdot
.71311 .48053 Mdot
.39896 .39178 Mdot
.51665 .3445 Mdot
.54913 .32598 Mdot
.3598 .35801 Mdot
.42127 .59976 Mdot
.57748 .67575 Mdot
.31907 .24259 Mdot
.71889 .6796 Mdot
.25332 .29476 Mdot
.55025 .63792 Mdot
.74561 .57622 Mdot
.68195 .51497 Mdot
.54384 .37577 Mdot
.39778 .57569 Mdot
.41392 .5981 Mdot
.58855 .62547 Mdot
.4164 .61551 Mdot
.53253 .60002 Mdot
.38954 .57218 Mdot
.64017 .35485 Mdot
.339 .39227 Mdot
.61851 .5509 Mdot
.3096 .40202 Mdot
.59913 .64948 Mdot
.22858 .55006 Mdot
.56792 .33775 Mdot
.48709 .7493 Mdot
.69833 .49294 Mdot
.39796 .36016 Mdot
.55544 .33361 Mdot
.39462 .34979 Mdot
.37384 .5317 Mdot
.54264 .39337 Mdot
.35226 .36543 Mdot
.31525 .62731 Mdot
.45473 .61089 Mdot
.64809 .73181 Mdot
.6355 .49439 Mdot
.54936 .62414 Mdot
.44961 .60363 Mdot
.57314 .36423 Mdot
.39766 .63626 Mdot
.75209 .43934 Mdot
.62036 .31806 Mdot
.53106 .31923 Mdot
.61644 .33151 Mdot
.40073 .37904 Mdot
.73251 .38519 Mdot
.72674 .58341 Mdot
.5363 .65774 Mdot
.34633 .56122 Mdot
.50413 .17214 Mdot
.65527 .51016 Mdot
.44724 .57304 Mdot
.43521 .22097 Mdot
.6465 .49655 Mdot
.41271 .58399 Mdot
.67252 .52315 Mdot
.59896 .65868 Mdot
.27476 .66394 Mdot
.53875 .6566 Mdot
.387 .61646 Mdot
.66596 .48013 Mdot
.57609 .37334 Mdot
.57917 .64557 Mdot
.42853 .60021 Mdot
.37775 .58023 Mdot
.58961 .46576 Mdot
.40296 .55633 Mdot
.65838 .21681 Mdot
.38538 .56788 Mdot
.53374 .37991 Mdot
.43202 .53261 Mdot
.2345 .69952 Mdot
.65182 .56041 Mdot
.57094 .67695 Mdot
.56856 .32336 Mdot
.52628 .35157 Mdot
.50808 .29535 Mdot
.67153 .45715 Mdot
.36869 .54227 Mdot
.5714 .36303 Mdot
.25431 .55897 Mdot
.70568 .50088 Mdot
.33722 .59059 Mdot
.46424 .44107 Mdot
.40917 .26749 Mdot
.50627 .37327 Mdot
.34412 .62236 Mdot
.58717 .70155 Mdot
.40734 .54258 Mdot
.55754 .32601 Mdot
.45351 .64863 Mdot
.36415 .56341 Mdot
.61975 .64144 Mdot
.59221 .46432 Mdot
.70529 .48448 Mdot
.35198 .52479 Mdot
.44664 .58431 Mdot
.55654 .38236 Mdot
.59008 .64288 Mdot
.70625 .50306 Mdot
.59236 .65716 Mdot
.48188 .18761 Mdot
.6567 .71744 Mdot
.33538 .6474 Mdot
.40496 .39009 Mdot
.39895 .25252 Mdot
.49722 .17996 Mdot
.19812 .53728 Mdot
.23079 .50693 Mdot
.38672 .20624 Mdot
.57699 .34033 Mdot
.43502 .22775 Mdot
.52767 .35884 Mdot
.37983 .54697 Mdot
.54178 .33957 Mdot
.48958 .1748 Mdot
.39125 .57117 Mdot
.54436 .34626 Mdot
.23771 .58399 Mdot
.40214 .5449 Mdot
.5437 .66564 Mdot
.74573 .28308 Mdot
.20078 .609 Mdot
.62623 .33097 Mdot
.52023 .38338 Mdot
.23563 .45204 Mdot
.39838 .56646 Mdot
.42505 .5308 Mdot
.55856 .64381 Mdot
.34677 .61916 Mdot
.38438 .39279 Mdot
.39331 .39563 Mdot
.69472 .44606 Mdot
.34868 .47774 Mdot
.36234 .5193 Mdot
.57389 .6444 Mdot
.5046 .68078 Mdot
.41824 .32104 Mdot
.42893 .25113 Mdot
.71316 .51175 Mdot
.74068 .28048 Mdot
.51593 .59241 Mdot
.65681 .53757 Mdot
.59849 .35392 Mdot
.54936 .66232 Mdot
.64191 .19702 Mdot
.67627 .49656 Mdot
.64403 .75874 Mdot
.47647 .48965 Mdot
.42214 .59709 Mdot
.7001 .48551 Mdot
.43939 .64235 Mdot
.19124 .59181 Mdot
.69381 .74389 Mdot
.41785 .46824 Mdot
.39866 .62289 Mdot
.44169 .35286 Mdot
.40649 .57653 Mdot
.77949 .41551 Mdot
.38179 .5698 Mdot
.58734 .65475 Mdot
.75773 .51907 Mdot
.64821 .44841 Mdot
.35017 .76876 Mdot
.75138 .40164 Mdot
.36361 .3837 Mdot
.39184 .57644 Mdot
.42465 .59606 Mdot
.37777 .3921 Mdot
.60565 .68586 Mdot
.39845 .61852 Mdot
.22289 .53481 Mdot
.39583 .60916 Mdot
.68414 .4938 Mdot
.47002 .50125 Mdot
.6337 .70457 Mdot
.36271 .6013 Mdot
.56171 .7014 Mdot
.70242 .4762 Mdot
.6629 .48305 Mdot
.38211 .51071 Mdot
.63314 .48722 Mdot
.41238 .5624 Mdot
.71536 .73538 Mdot
.57565 .6987 Mdot
.5853 .59592 Mdot
.591 .6824 Mdot
.41092 .73534 Mdot
.64666 .48585 Mdot
.65348 .34659 Mdot
.47554 .62607 Mdot
.67227 .49786 Mdot
.62223 .72994 Mdot
.4638 .55836 Mdot
.45812 .61433 Mdot
.27703 .32002 Mdot
.51977 .37673 Mdot
.59422 .47428 Mdot
.66886 .52058 Mdot
.43898 .59586 Mdot
.34973 .57527 Mdot
.69656 .47256 Mdot
.71796 .7104 Mdot
.22152 .60703 Mdot
.38775 .56963 Mdot
.57876 .65542 Mdot
.57691 .66537 Mdot
.43194 .62436 Mdot
.42857 .53919 Mdot
.55407 .34087 Mdot
.58096 .36585 Mdot
.53703 .39767 Mdot
.59554 .4632 Mdot
.64841 .3446 Mdot
.65205 .26945 Mdot
.63617 .48434 Mdot
.72046 .61127 Mdot
.35237 .30902 Mdot
.3633 .6083 Mdot
.51009 .36228 Mdot
.44407 .57701 Mdot
.41671 .5554 Mdot
.6991 .46976 Mdot
.53644 .22889 Mdot
.52475 .61516 Mdot
.61175 .68134 Mdot
.70562 .51137 Mdot
.47842 .54753 Mdot
.70237 .5435 Mdot
.38534 .35373 Mdot
.30507 .28626 Mdot
.69589 .49478 Mdot
.54552 .66614 Mdot
.64068 .50604 Mdot
.40836 .60254 Mdot
.3912 .52018 Mdot
.55577 .66627 Mdot
.36203 .39472 Mdot
.38655 .63388 Mdot
.4092 .5844 Mdot
.50003 .83754 Mdot
.29085 .32869 Mdot
.63519 .37462 Mdot
.38428 .5642 Mdot
.35708 .59118 Mdot
.35 .35639 Mdot
.39984 .60848 Mdot
.43242 .61491 Mdot
.2879 .696 Mdot
.68162 .65656 Mdot
.38611 .40244 Mdot
.72544 .71766 Mdot
.54661 .64046 Mdot
.55341 .17575 Mdot
.5491 .38032 Mdot
.73071 .47719 Mdot
.23485 .63722 Mdot
.50779 .38066 Mdot
.69946 .40752 Mdot
.57982 .18286 Mdot
.59872 .4696 Mdot
.53297 .41521 Mdot
.50827 .60849 Mdot
.39717 .61657 Mdot
.40105 .58124 Mdot
.39514 .36856 Mdot
.5833 .67467 Mdot
.58257 .48425 Mdot
.82071 .56704 Mdot
.41516 .57008 Mdot
.55328 .59156 Mdot
.7876 .58613 Mdot
.41073 .27076 Mdot
.36982 .36736 Mdot
.37711 .40085 Mdot
.39332 .57916 Mdot
.28297 .70891 Mdot
.58227 .64406 Mdot
.4299 .59937 Mdot
.35598 .55256 Mdot
.5222 .3821 Mdot
.55839 .68605 Mdot
.56723 .32616 Mdot
.67416 .34745 Mdot
.62345 .21257 Mdot
.5363 .84539 Mdot
.65235 .48405 Mdot
.79798 .46719 Mdot
.68733 .52001 Mdot
.32925 .46707 Mdot
.51507 .32572 Mdot
.41605 .5404 Mdot
.59722 .64891 Mdot
.4417 .59006 Mdot
.42312 .53817 Mdot
.42343 .59851 Mdot
.35216 .59209 Mdot
.42553 .85767 Mdot
.35437 .37417 Mdot
.47627 .56499 Mdot
.52891 .37659 Mdot
.77903 .37862 Mdot
.81799 .45422 Mdot
.42716 .59226 Mdot
.38258 .57862 Mdot
.58475 .69589 Mdot
.45203 .58607 Mdot
.69526 .51462 Mdot
.56116 .62713 Mdot
.37944 .6019 Mdot
.76056 .30885 Mdot
.3672 .58861 Mdot
.5657 .18944 Mdot
.64748 .51294 Mdot
.69109 .69859 Mdot
.46974 .5488 Mdot
.62555 .3375 Mdot
.59409 .4744 Mdot
.5545 .33629 Mdot
.63084 .50677 Mdot
.54139 .35732 Mdot
.81389 .60075 Mdot
.40025 .5159 Mdot
.39067 .55433 Mdot
.34372 .58738 Mdot
.56924 .36762 Mdot
.73952 .31752 Mdot
.72582 .36589 Mdot
.48195 .5677 Mdot
.56592 .36347 Mdot
.57949 .70785 Mdot
.27688 .37191 Mdot
.59739 .67724 Mdot
.41214 .36688 Mdot
.68722 .5079 Mdot
.37102 .3969 Mdot
.4234 .21699 Mdot
.5529 .67561 Mdot
.54233 .62145 Mdot
.55047 .37566 Mdot
.48823 .48862 Mdot
.13352 .4749 Mdot
.48148 .49186 Mdot
.30796 .44843 Mdot
.56342 .64548 Mdot
.36539 .59627 Mdot
.36309 .44955 Mdot
.51913 .51709 Mdot
.5398 .35486 Mdot
.42766 .55703 Mdot
.26816 .65799 Mdot
.55422 .34077 Mdot
.33883 .57832 Mdot
.52353 .37567 Mdot
.68247 .50418 Mdot
.5116 .35283 Mdot
.61311 .64955 Mdot
.37881 .59292 Mdot
.14865 .41416 Mdot
.33914 .39866 Mdot
.39477 .56375 Mdot
.70645 .51227 Mdot
.699 .43314 Mdot
.43723 .5511 Mdot
.37383 .34609 Mdot
.55387 .3503 Mdot
.45861 .47149 Mdot
.3853 .5697 Mdot
.56659 .37011 Mdot
.53006 .65163 Mdot
.64666 .52194 Mdot
.31369 .66411 Mdot
.62615 .36257 Mdot
.55753 .64296 Mdot
.45147 .39594 Mdot
.62792 .48577 Mdot
.35668 .59148 Mdot
.34567 .56392 Mdot
.58006 .65898 Mdot
.28138 .57343 Mdot
.44722 .54679 Mdot
.3953 .53399 Mdot
.53488 .38428 Mdot
.54477 .35485 Mdot
.27183 .61689 Mdot
.58127 .34835 Mdot
.39409 .51947 Mdot
.5827 .65939 Mdot
.41411 .54522 Mdot
.57217 .69575 Mdot
.45151 .58229 Mdot
.48575 .64372 Mdot
.60663 .68395 Mdot
.65618 .5537 Mdot
.42295 .55502 Mdot
.32574 .57793 Mdot
.44588 .56303 Mdot
.40353 .6155 Mdot
.54791 .33605 Mdot
.37423 .35891 Mdot
.34999 .54775 Mdot
.37316 .33852 Mdot
.39599 .35122 Mdot
.62545 .46334 Mdot
.52029 .37999 Mdot
.38504 .37972 Mdot
.79337 .58771 Mdot
.53422 .39547 Mdot
.39412 .38178 Mdot
.81637 .451 Mdot
.64061 .49427 Mdot
.58087 .70124 Mdot
.40016 .54394 Mdot
.43096 .20425 Mdot
.52705 .81205 Mdot
.58509 .37541 Mdot
.38755 .56664 Mdot
.44449 .56766 Mdot
.59392 .64162 Mdot
.82655 .60921 Mdot
.52573 .39852 Mdot
.36337 .57197 Mdot
.56529 .68015 Mdot
.81448 .6586 Mdot
.53284 .37431 Mdot
.39598 .37783 Mdot
.6399 .48338 Mdot
.62384 .65459 Mdot
.6688 .65413 Mdot
.70156 .48006 Mdot
.59362 .39245 Mdot
.65829 .33393 Mdot
.36187 .5521 Mdot
.50881 .35607 Mdot
.25764 .31118 Mdot
.54128 .711 Mdot
.60632 .53409 Mdot
.23691 .43973 Mdot
.5506 .65998 Mdot
.69086 .51764 Mdot
.35899 .38008 Mdot
.55511 .63641 Mdot
.54211 .66771 Mdot
.68154 .46625 Mdot
.32605 .71479 Mdot
.46391 .44283 Mdot
.68274 .48824 Mdot
.31294 .30873 Mdot
.594 .25292 Mdot
.50992 .36426 Mdot
.38449 .3923 Mdot
.44441 .21161 Mdot
.59669 .66359 Mdot
.7333 .26947 Mdot
.27982 .30373 Mdot
.39929 .56859 Mdot
.3827 .37616 Mdot
.71192 .29675 Mdot
.8389 .54293 Mdot
.64722 .49284 Mdot
.65044 .44418 Mdot
.38901 .39316 Mdot
.45023 .60107 Mdot
.27558 .38887 Mdot
.39557 .53546 Mdot
.68371 .51191 Mdot
.35111 .67471 Mdot
.54511 .66957 Mdot
.65929 .46399 Mdot
.30231 .28643 Mdot
.41404 .56343 Mdot
.42422 .55406 Mdot
.31941 .40112 Mdot
.57263 .63381 Mdot
.55516 .33663 Mdot
.35989 .55128 Mdot
.41024 .58098 Mdot
.36314 .52939 Mdot
.3426 .53455 Mdot
.271 .68092 Mdot
.37467 .55727 Mdot
.72653 .35026 Mdot
.39401 .62319 Mdot
.42602 .56286 Mdot
.56593 .70285 Mdot
.52945 .85268 Mdot
.68329 .34425 Mdot
.41106 .57749 Mdot
.3614 .5891 Mdot
.65285 .4656 Mdot
.48878 .47305 Mdot
.48152 .47929 Mdot
.4539 .4669 Mdot
.23341 .48049 Mdot
.42965 .62764 Mdot
.57652 .68006 Mdot
.35326 .36104 Mdot
.36142 .56472 Mdot
.57296 .68109 Mdot
.45928 .57571 Mdot
.55671 .34283 Mdot
.53679 .39566 Mdot
.53339 .6994 Mdot
.38051 .38389 Mdot
.5184 .55962 Mdot
.71153 .6135 Mdot
.55149 .3884 Mdot
.38887 .55294 Mdot
.71471 .47704 Mdot
.55593 .32614 Mdot
.60473 .30891 Mdot
.30103 .59834 Mdot
.57929 .63991 Mdot
.55958 .65662 Mdot
.28487 .50627 Mdot
.69309 .39206 Mdot
.40031 .81251 Mdot
.68344 .50507 Mdot
.42287 .52191 Mdot
.72274 .57223 Mdot
.55601 .65545 Mdot
.34925 .45276 Mdot
.38209 .37968 Mdot
.64568 .49772 Mdot
.50528 .41601 Mdot
.58401 .69331 Mdot
.54014 .67083 Mdot
.41388 .6235 Mdot
.41437 .58949 Mdot
.2316 .51881 Mdot
.42171 .36297 Mdot
.70532 .48166 Mdot
.3887 .39055 Mdot
.51444 .32727 Mdot
.3698 .56158 Mdot
.60659 .67305 Mdot
.58963 .25819 Mdot
.36082 .57212 Mdot
.53963 .33084 Mdot
.55526 .66078 Mdot
.40011 .38178 Mdot
.37526 .34433 Mdot
.40028 .61406 Mdot
.45841 .67659 Mdot
.67152 .48978 Mdot
.54485 .66108 Mdot
.68992 .54697 Mdot
.42565 .53257 Mdot
.4057 .59186 Mdot
.36299 .50815 Mdot
.70754 .48317 Mdot
.75482 .61472 Mdot
.40926 .37166 Mdot
.5781 .67252 Mdot
.37508 .56552 Mdot
.38661 .38782 Mdot
.74509 .59484 Mdot
.52732 .31986 Mdot
.51282 .35043 Mdot
.3693 .34549 Mdot
.37527 .37137 Mdot
.38242 .3476 Mdot
.73379 .26912 Mdot
.60994 .65607 Mdot
.51541 .59453 Mdot
.43664 .53142 Mdot
.30777 .46621 Mdot
.4735 .62233 Mdot
.70901 .50069 Mdot
.51889 .37296 Mdot
.43708 .54663 Mdot
.37665 .60861 Mdot
.41682 .50565 Mdot
.57694 .59906 Mdot
.63126 .71266 Mdot
.55442 .68078 Mdot
.4247 .51733 Mdot
.52866 .38683 Mdot
.822 .33839 Mdot
.35237 .19687 Mdot
.46286 .54054 Mdot
.45162 .4419 Mdot
.60785 .67115 Mdot
.64174 .47273 Mdot
.32335 .38726 Mdot
.63905 .49285 Mdot
.5744 .67045 Mdot
.3731 .55826 Mdot
.71857 .6197 Mdot
.35861 .34859 Mdot
.43219 .60502 Mdot
.67444 .51627 Mdot
.43126 .60986 Mdot
.69999 .47867 Mdot
.49503 .18685 Mdot
.2296 .38616 Mdot
.40549 .56784 Mdot
.47571 .59486 Mdot
.22595 .45328 Mdot
.43129 .59042 Mdot
.4223 .38235 Mdot
.60815 .67199 Mdot
.28532 .64009 Mdot
.4674 .59498 Mdot
.51824 .71751 Mdot
.41477 .5307 Mdot
.25288 .61604 Mdot
.40765 .59387 Mdot
.40425 .2791 Mdot
.37312 .58685 Mdot
.41848 .61824 Mdot
.65763 .48072 Mdot
.65755 .46464 Mdot
.53984 .68337 Mdot
.57302 .35873 Mdot
.59222 .19428 Mdot
.40741 .58714 Mdot
.61703 .30815 Mdot
.71167 .64937 Mdot
.37314 .3708 Mdot
.58027 .6706 Mdot
.84454 .58517 Mdot
.65765 .52054 Mdot
.26715 .34591 Mdot
.25985 .59855 Mdot
.65025 .60353 Mdot
.31948 .33611 Mdot
.76903 .49809 Mdot
.40225 .37402 Mdot
.45679 .58114 Mdot
.56397 .24376 Mdot
.39644 .29128 Mdot
.30104 .60458 Mdot
.62638 .48365 Mdot
.50169 .74023 Mdot
.55112 .2325 Mdot
.40096 .3481 Mdot
.38481 .39756 Mdot
.66488 .47129 Mdot
.4895 .39698 Mdot
.49032 .62738 Mdot
.37833 .3789 Mdot
.56342 .38488 Mdot
.52422 .39314 Mdot
.51067 .39036 Mdot
.58994 .64829 Mdot
.29902 .26909 Mdot
.72702 .53116 Mdot
.70387 .48446 Mdot
.48611 .36786 Mdot
.57619 .71716 Mdot
.60056 .64134 Mdot
.54584 .36955 Mdot
.52786 .32932 Mdot
.60741 .68776 Mdot
.36858 .51914 Mdot
.42799 .51203 Mdot
.41267 .57305 Mdot
.38595 .35781 Mdot
.4133 .5944 Mdot
.56319 .35752 Mdot
.65023 .49275 Mdot
.52229 .33546 Mdot
.69595 .52139 Mdot
.67107 .28458 Mdot
.42126 .60605 Mdot
.37671 .58934 Mdot
.5603 .81269 Mdot
.53148 .66121 Mdot
.71323 .3289 Mdot
.6204 .38975 Mdot
.52715 .3625 Mdot
.43692 .61292 Mdot
.56127 .62656 Mdot
.39664 .34116 Mdot
.58431 .81077 Mdot
.43634 .54145 Mdot
.60282 .67757 Mdot
.37072 .56622 Mdot
.46151 .66708 Mdot
.27167 .73384 Mdot
.59139 .66219 Mdot
.52868 .82312 Mdot
.36424 .59082 Mdot
.79144 .52032 Mdot
.34193 .59689 Mdot
.26376 .54344 Mdot
.44694 .54652 Mdot
.54789 .63899 Mdot
.41578 .5756 Mdot
.55318 .62747 Mdot
.55093 .38602 Mdot
.64158 .47458 Mdot
.55628 .64729 Mdot
.34247 .57282 Mdot
.17424 .30001 Mdot
.67696 .51141 Mdot
.39504 .57647 Mdot
.64721 .47999 Mdot
.58625 .67698 Mdot
.54506 .64971 Mdot
.83091 .52714 Mdot
.67943 .35109 Mdot
.68102 .50392 Mdot
.36993 .56323 Mdot
.76968 .46211 Mdot
.40374 .53846 Mdot
.24808 .51569 Mdot
.35536 .53082 Mdot
.43438 .53251 Mdot
.82342 .45921 Mdot
.70716 .48636 Mdot
.38021 .8048 Mdot
.83804 .50606 Mdot
.7826 .3835 Mdot
.56942 .61832 Mdot
.39988 .34609 Mdot
.64983 .20104 Mdot
.651 .34723 Mdot
.56704 .3664 Mdot
.44191 .55392 Mdot
.61774 .71474 Mdot
.67044 .48606 Mdot
.37185 .35714 Mdot
.40468 .56864 Mdot
.52177 .33219 Mdot
.20662 .57166 Mdot
.67764 .52669 Mdot
.59593 .66805 Mdot
.6137 .67594 Mdot
.71456 .75801 Mdot
.38055 .56447 Mdot
.37855 .59612 Mdot
.68648 .50949 Mdot
.77652 .58832 Mdot
.40298 .36461 Mdot
.23148 .57542 Mdot
.67925 .50458 Mdot
.55558 .48171 Mdot
.56354 .67662 Mdot
.44492 .57045 Mdot
.7111 .27669 Mdot
.44893 .34476 Mdot
.60339 .77171 Mdot
.39076 .36044 Mdot
.24852 .50669 Mdot
.54552 .64077 Mdot
.65581 .50732 Mdot
.66217 .40362 Mdot
.40461 .62974 Mdot
.44232 .57561 Mdot
.25309 .50399 Mdot
.64016 .45274 Mdot
.42823 .47201 Mdot
.43101 .5374 Mdot
.59671 .48169 Mdot
.44732 .55284 Mdot
.44191 .62869 Mdot
.38072 .51876 Mdot
.39538 .5958 Mdot
.60551 .67524 Mdot
.40737 .49425 Mdot
.56443 .34823 Mdot
.50622 .56411 Mdot
.55909 .49099 Mdot
.39202 .56677 Mdot
.37865 .54128 Mdot
.55778 .77682 Mdot
.71371 .42367 Mdot
.55786 .64996 Mdot
.56416 .61986 Mdot
.63179 .49553 Mdot
.42384 .5092 Mdot
.57156 .34968 Mdot
.44975 .62941 Mdot
.54295 .33351 Mdot
.60544 .67086 Mdot
.52898 .36735 Mdot
.64225 .47877 Mdot
.515 .38071 Mdot
.6481 .3438 Mdot
.65628 .5132 Mdot
.56987 .63824 Mdot
.38782 .60341 Mdot
.70544 .51322 Mdot
.2974 .40603 Mdot
.38749 .35895 Mdot
.84955 .48204 Mdot
.37796 .60121 Mdot
.67778 .66087 Mdot
.40019 .65349 Mdot
.52518 .33207 Mdot
.28722 .74181 Mdot
.61131 .68008 Mdot
.37394 .40273 Mdot
.60121 .65044 Mdot
.28394 .32482 Mdot
.37909 .36352 Mdot
.81823 .43056 Mdot
.60066 .407 Mdot
.28812 .33958 Mdot
.39586 .51007 Mdot
.3016 .36915 Mdot
.50467 .3623 Mdot
.66824 .48573 Mdot
.6766 .40493 Mdot
.42951 .61515 Mdot
.19567 .48147 Mdot
.59578 .70424 Mdot
.57187 .35748 Mdot
.65541 .50125 Mdot
.7062 .50487 Mdot
.39056 .52983 Mdot
.46967 .25209 Mdot
.44616 .58908 Mdot
.68895 .37983 Mdot
.23748 .48409 Mdot
.5809 .61324 Mdot
.39005 .57254 Mdot
.55538 .38329 Mdot
.37076 .56601 Mdot
.39309 .40344 Mdot
.28259 .27507 Mdot
.36523 .62834 Mdot
.62326 .38959 Mdot
.3348 .39379 Mdot
.55361 .66916 Mdot
.35946 .64291 Mdot
.64694 .36107 Mdot
.37881 .56255 Mdot
.3261 .8265 Mdot
.3912 .3847 Mdot
.55734 .24415 Mdot
.34988 .58188 Mdot
.37233 .53781 Mdot
.59519 .55047 Mdot
.65619 .63959 Mdot
.4473 .35192 Mdot
.43425 .58316 Mdot
.26108 .44774 Mdot
.68467 .47444 Mdot
.44978 .57821 Mdot
.39879 .58069 Mdot
.37391 .75196 Mdot
.70097 .51346 Mdot
.52328 .35596 Mdot
.50339 .36435 Mdot
.58527 .36329 Mdot
.38516 .40636 Mdot
.61657 .44578 Mdot
.33348 .45114 Mdot
.19702 .58438 Mdot
.35211 .39146 Mdot
.38503 .61053 Mdot
.4047 .42068 Mdot
.3752 .55045 Mdot
.36251 .36877 Mdot
.69666 .5173 Mdot
.55371 .65004 Mdot
.74051 .56789 Mdot
.5197 .3943 Mdot
.33824 .59828 Mdot
.40572 .37225 Mdot
.57433 .63968 Mdot
.31996 .32469 Mdot
.56122 .67239 Mdot
.67185 .50201 Mdot
.70441 .52231 Mdot
.36653 .35973 Mdot
.58809 .68078 Mdot
.62607 .52443 Mdot
.83222 .55817 Mdot
.38062 .52172 Mdot
.73592 .46894 Mdot
.53612 .64185 Mdot
.57878 .62364 Mdot
.54878 .63255 Mdot
.419 .61403 Mdot
.45209 .44129 Mdot
.46339 .5709 Mdot
.70561 .48413 Mdot
.52216 .3719 Mdot
.21638 .47779 Mdot
.64588 .29381 Mdot
.4396 .40394 Mdot
.42248 .52004 Mdot
.41626 .56396 Mdot
.39364 .57911 Mdot
.46684 .60142 Mdot
.66457 .37955 Mdot
.44323 .58649 Mdot
.65924 .4795 Mdot
.55581 .34979 Mdot
.45712 .58184 Mdot
.49954 .34561 Mdot
.77195 .37771 Mdot
.35195 .38864 Mdot
.63256 .4408 Mdot
.37468 .16664 Mdot
.56713 .64021 Mdot
.56394 .32141 Mdot
.56471 .37073 Mdot
.3871 .35173 Mdot
.67798 .48981 Mdot
.56564 .6743 Mdot
.2516 .54435 Mdot
.39081 .34965 Mdot
.41365 .57767 Mdot
.42842 .4463 Mdot
.20222 .44223 Mdot
.45572 .57794 Mdot
.42822 .54619 Mdot
.50984 .32583 Mdot
.53539 .24551 Mdot
.181 .37756 Mdot
.34618 .43465 Mdot
.37051 .35906 Mdot
.35502 .38359 Mdot
.59496 .69739 Mdot
.46612 .56531 Mdot
.70514 .48264 Mdot
.45132 .4885 Mdot
.64739 .42983 Mdot
.50039 .5305 Mdot
.64351 .67437 Mdot
.44118 .5474 Mdot
.73827 .69076 Mdot
.41371 .56078 Mdot
.60756 .653 Mdot
.60171 .66454 Mdot
.57369 .64846 Mdot
.6678 .48683 Mdot
.44889 .75263 Mdot
.66902 .47923 Mdot
.35903 .17221 Mdot
.54031 .64742 Mdot
.60039 .41989 Mdot
.54422 .38156 Mdot
.46556 .54171 Mdot
.39691 .38454 Mdot
.65207 .53065 Mdot
.4318 .50555 Mdot
.28583 .72135 Mdot
.56957 .35532 Mdot
.56533 .63811 Mdot
.76958 .50491 Mdot
.42733 .17372 Mdot
.46759 .47025 Mdot
.47969 .5479 Mdot
.31667 .36975 Mdot
.3696 .37226 Mdot
.60194 .7736 Mdot
.3899 .39127 Mdot
.6716 .51706 Mdot
.37889 .58664 Mdot
.38673 .59789 Mdot
.44912 .55556 Mdot
.42694 .59952 Mdot
.63284 .47993 Mdot
.34677 .55815 Mdot
.23442 .69941 Mdot
.54485 .39507 Mdot
.31891 .63293 Mdot
.39546 .38339 Mdot
.62548 .50002 Mdot
.55732 .35107 Mdot
.70729 .42036 Mdot
.31159 .4091 Mdot
.3867 .57022 Mdot
.43947 .54906 Mdot
.2607 .35103 Mdot
.42971 .53656 Mdot
.48413 .61741 Mdot
.56691 .36883 Mdot
.41134 .43048 Mdot
.35741 .39307 Mdot
.35815 .3877 Mdot
.65058 .51127 Mdot
.60461 .67188 Mdot
.39178 .37763 Mdot
.53978 .38428 Mdot
.41997 .51926 Mdot
.35034 .56287 Mdot
.53686 .64187 Mdot
.26567 .31134 Mdot
.40831 .36529 Mdot
.77516 .4759 Mdot
.59321 .64638 Mdot
.51707 .64395 Mdot
.4421 .57436 Mdot
.63172 .65436 Mdot
.62432 .66364 Mdot
.35734 .39937 Mdot
.6261 .5003 Mdot
.32685 .39976 Mdot
.69032 .51247 Mdot
.59712 .67192 Mdot
.36364 .56264 Mdot
.5981 .65467 Mdot
.3834 .5654 Mdot
.48859 .14805 Mdot
.39373 .59911 Mdot
.19512 .59085 Mdot
.27747 .50634 Mdot
.55494 .36459 Mdot
.72749 .44077 Mdot
.54976 .3791 Mdot
.58559 .63993 Mdot
.3614 .5569 Mdot
.40035 .38867 Mdot
.79453 .42272 Mdot
.59279 .72101 Mdot
.5365 .3286 Mdot
.55173 .40177 Mdot
.68137 .52009 Mdot
.4513 .55188 Mdot
.4427 .57892 Mdot
.54458 .34827 Mdot
.5799 .61161 Mdot
.58546 .69015 Mdot
.38013 .57857 Mdot
.42188 .56467 Mdot
.5536 .36697 Mdot
.82761 .57294 Mdot
.57417 .72177 Mdot
.38448 .58924 Mdot
.58979 .27349 Mdot
.70939 .49634 Mdot
.42924 .51645 Mdot
.47671 .59824 Mdot
.37651 .37358 Mdot
.33104 .68665 Mdot
.31601 .25526 Mdot
.69044 .52171 Mdot
.56334 .37798 Mdot
.37788 .56537 Mdot
.55674 .38258 Mdot
.34947 .56092 Mdot
.6478 .62913 Mdot
.51873 .32749 Mdot
.39689 .53275 Mdot
.35403 .52746 Mdot
.57262 .63348 Mdot
.44006 .54759 Mdot
.52947 .78801 Mdot
.55836 .33015 Mdot
.38273 .53274 Mdot
.44657 .67802 Mdot
.689 .48983 Mdot
.40274 .50835 Mdot
.36272 .35422 Mdot
.25081 .54851 Mdot
.6876 .61925 Mdot
.51889 .22236 Mdot
.35181 .38175 Mdot
.43493 .60724 Mdot
.56413 .39472 Mdot
.68459 .47255 Mdot
.20636 .61521 Mdot
.45094 .59533 Mdot
.68201 .51257 Mdot
.65003 .49452 Mdot
.38518 .35413 Mdot
.55913 .8372 Mdot
.35211 .59026 Mdot
.42522 .59246 Mdot
.43361 .77995 Mdot
.5289 .6526 Mdot
.40454 .59916 Mdot
.37525 .60484 Mdot
.6584 .47854 Mdot
.49504 .60751 Mdot
.52934 .75229 Mdot
.23998 .59415 Mdot
.70876 .48102 Mdot
.52982 .53848 Mdot
.50922 .37257 Mdot
.37952 .38914 Mdot
.56027 .66598 Mdot
.40516 .37671 Mdot
.51347 .37106 Mdot
.37915 .60556 Mdot
.63712 .50465 Mdot
.49106 .80215 Mdot
.664 .4711 Mdot
.48745 .21474 Mdot
.53111 .64609 Mdot
.70758 .56771 Mdot
.37676 .85381 Mdot
.76581 .42159 Mdot
.73512 .50426 Mdot
.37357 .3707 Mdot
.46948 .35376 Mdot
.42009 .56365 Mdot
.59269 .78409 Mdot
.3942 .6113 Mdot
.4275 .68056 Mdot
.55412 .39012 Mdot
.53744 .39784 Mdot
.38132 .58727 Mdot
.23837 .49419 Mdot
.68185 .47162 Mdot
.70623 .49774 Mdot
.39809 .53076 Mdot
.67286 .4981 Mdot
.41876 .58801 Mdot
.5563 .34513 Mdot
.3853 .81565 Mdot
.40794 .57221 Mdot
.46476 .61197 Mdot
.65277 .62454 Mdot
.83178 .47533 Mdot
.40684 .24247 Mdot
.76912 .6916 Mdot
.39955 .1835 Mdot
.67122 .49782 Mdot
.45642 .54784 Mdot
.52979 .54 Mdot
.50097 .35891 Mdot
.64876 .53488 Mdot
.39771 .60621 Mdot
.40034 .60942 Mdot
.41587 .6193 Mdot
.42252 .55112 Mdot
.61895 .77229 Mdot
.44998 .50214 Mdot
.39713 .70739 Mdot
.42737 .53975 Mdot
.29761 .37939 Mdot
.65456 .51555 Mdot
.60974 .63769 Mdot
.34651 .38758 Mdot
.44149 .54807 Mdot
.49823 .56604 Mdot
.65019 .46388 Mdot
.35551 .17282 Mdot
.66751 .51869 Mdot
.52679 .35128 Mdot
.65057 .47003 Mdot
.40156 .55692 Mdot
.57691 .66495 Mdot
.54041 .51564 Mdot
.72755 .37934 Mdot
.56737 .36516 Mdot
.39437 .56397 Mdot
.60709 .41489 Mdot
.56651 .35202 Mdot
.76964 .3677 Mdot
.56813 .66357 Mdot
.26549 .44646 Mdot
.60089 .65961 Mdot
.38835 .53292 Mdot
.38251 .53532 Mdot
.72937 .50323 Mdot
.64518 .4737 Mdot
.60193 .662 Mdot
.5658 .84266 Mdot
.39551 .34936 Mdot
.57848 .64897 Mdot
.38743 .62855 Mdot
.5 .45591 Mdot
.57611 .66073 Mdot
.32787 .37957 Mdot
.65189 .48708 Mdot
.54452 .68435 Mdot
.3795 .62145 Mdot
.316 .29506 Mdot
.35323 .35918 Mdot
.51725 .31942 Mdot
.37751 .43471 Mdot
.55913 .3284 Mdot
.62891 .50395 Mdot
.55139 .37761 Mdot
.68354 .47504 Mdot
.69697 .63922 Mdot
.51676 .57285 Mdot
.72337 .48279 Mdot
.62832 .49651 Mdot
.55043 .37495 Mdot
.37568 .58034 Mdot
.32356 .37481 Mdot
.44737 .53448 Mdot
.35505 .59862 Mdot
.69479 .48037 Mdot
.5551 .63707 Mdot
.60629 .63862 Mdot
.28112 .38591 Mdot
.60259 .6847 Mdot
.53781 .3309 Mdot
.24987 .70122 Mdot
.61391 .29707 Mdot
.69631 .50096 Mdot
.64596 .47006 Mdot
.39537 .53646 Mdot
.54088 .35671 Mdot
.56611 .37934 Mdot
.68252 .5187 Mdot
.57952 .5877 Mdot
.47357 .58486 Mdot
.59031 .63052 Mdot
.5351 .66404 Mdot
.58766 .66023 Mdot
.54813 .63142 Mdot
.55697 .74514 Mdot
.64353 .49472 Mdot
.56107 .63491 Mdot
.40456 .5335 Mdot
.40004 .60799 Mdot
.49227 .49902 Mdot
.35607 .38183 Mdot
.4578 .58778 Mdot
.38288 .51704 Mdot
.44336 .56822 Mdot
.5121 .34788 Mdot
.31393 .55281 Mdot
.52273 .32607 Mdot
.56366 .39169 Mdot
.56459 .3875 Mdot
.64967 .34652 Mdot
.2506 .38298 Mdot
.41226 .1958 Mdot
.36299 .57331 Mdot
.7744 .61318 Mdot
.53741 .3684 Mdot
.28502 .7291 Mdot
.75703 .61197 Mdot
.44449 .60656 Mdot
.44184 .33245 Mdot
.54684 .35183 Mdot
.60977 .67998 Mdot
.39616 .60397 Mdot
.58516 .34952 Mdot
.3624 .35329 Mdot
.40744 .52555 Mdot
.52062 .32433 Mdot
.58532 .68031 Mdot
.35415 .39938 Mdot
.53543 .67257 Mdot
.56215 .38873 Mdot
.36899 .5154 Mdot
.12609 .55419 Mdot
.5581 .40193 Mdot
.8047 .55422 Mdot
.47666 .65038 Mdot
.37831 .57943 Mdot
.56013 .32209 Mdot
.52548 .65347 Mdot
.63629 .51335 Mdot
.56688 .43943 Mdot
.55332 .68802 Mdot
.53618 .3978 Mdot
.54305 .32493 Mdot
.56754 .36724 Mdot
.55029 .67807 Mdot
.44177 .622 Mdot
.56409 .69196 Mdot
.65384 .46948 Mdot
.40349 .54192 Mdot
.49974 .18003 Mdot
.7661 .62493 Mdot
.59971 .65376 Mdot
.52054 .35412 Mdot
.35285 .3533 Mdot
.40823 .56338 Mdot
.76632 .6337 Mdot
.37365 .57481 Mdot
.69986 .48185 Mdot
.29081 .69157 Mdot
.5265 .80147 Mdot
.43858 .534 Mdot
.3973 .53659 Mdot
.70557 .49475 Mdot
.3978 .56802 Mdot
.44816 .54785 Mdot
.65589 .35064 Mdot
.56144 .68656 Mdot
.41782 .57276 Mdot
.52784 .37967 Mdot
.64886 .32149 Mdot
.47186 .59099 Mdot
.54556 .28353 Mdot
.25934 .46611 Mdot
.2999 .70082 Mdot
.39268 .61095 Mdot
.41147 .45633 Mdot
.42971 .55816 Mdot
.4293 .60506 Mdot
.38223 .54504 Mdot
.64732 .77208 Mdot
.5157 .3306 Mdot
.56238 .3668 Mdot
.34918 .37213 Mdot
.26005 .46201 Mdot
.38044 .37551 Mdot
.65025 .48662 Mdot
.48461 .26203 Mdot
.52187 .32648 Mdot
.59459 .67822 Mdot
.43737 .60152 Mdot
.56024 .40071 Mdot
.44528 .57449 Mdot
.39962 .55646 Mdot
.57266 .34501 Mdot
.50637 .35824 Mdot
.54615 .2362 Mdot
.35138 .36954 Mdot
.56759 .64835 Mdot
.4589 .56281 Mdot
.40566 .36574 Mdot
.36962 .60471 Mdot
.30908 .46737 Mdot
.57137 .65026 Mdot
.56274 .68899 Mdot
.615 .64803 Mdot
.37766 .60391 Mdot
.4031 .56047 Mdot
.67133 .47871 Mdot
.60344 .65574 Mdot
.68848 .4921 Mdot
.58165 .47118 Mdot
.49204 .30512 Mdot
.39779 .60634 Mdot
.76056 .51166 Mdot
.37028 .38472 Mdot
.52711 .33619 Mdot
.20878 .4414 Mdot
.3489 .37053 Mdot
.3823 .56754 Mdot
.57287 .37109 Mdot
.36012 .37165 Mdot
.30324 .63217 Mdot
.31017 .22976 Mdot
.34555 .36433 Mdot
.40563 .53337 Mdot
.48982 .57522 Mdot
.75832 .70474 Mdot
.34836 .37852 Mdot
.63865 .48658 Mdot
.37758 .60332 Mdot
.61952 .70013 Mdot
.40552 .37862 Mdot
.73015 .35608 Mdot
.55252 .35068 Mdot
.31981 .27564 Mdot
.37933 .49687 Mdot
.54957 .80664 Mdot
.36629 .38966 Mdot
.57016 .67318 Mdot
.45409 .64809 Mdot
.43923 .56902 Mdot
.34808 .3752 Mdot
.6929 .46594 Mdot
.54477 .33947 Mdot
.67974 .34449 Mdot
.54908 .67746 Mdot
.71994 .54603 Mdot
.5177 .35609 Mdot
.77462 .47006 Mdot
.26254 .63562 Mdot
.42703 .5128 Mdot
.74482 .71106 Mdot
.62323 .42672 Mdot
.42321 .62187 Mdot
.36171 .34412 Mdot
.69856 .51869 Mdot
.63437 .50169 Mdot
.67385 .50482 Mdot
.70719 .64599 Mdot
.4539 .4658 Mdot
.56332 .32019 Mdot
.71498 .53173 Mdot
.38017 .38807 Mdot
.31989 .39501 Mdot
.3421 .5806 Mdot
.41524 .56567 Mdot
.44854 .54449 Mdot
.4467 .55523 Mdot
.43226 .56619 Mdot
.67998 .49428 Mdot
.6859 .64397 Mdot
.47021 .47946 Mdot
.57499 .65538 Mdot
.51295 .24681 Mdot
.54225 .37996 Mdot
.56226 .31874 Mdot
.35759 .36618 Mdot
.77922 .42252 Mdot
.50034 .34261 Mdot
.52752 .36606 Mdot
.44595 .61401 Mdot
.58129 .69343 Mdot
.48878 .60155 Mdot
.40102 .53497 Mdot
.53771 .33252 Mdot
.58278 .52859 Mdot
.5446 .76663 Mdot
.30459 .57452 Mdot
.33893 .35107 Mdot
.46786 .45489 Mdot
.3513 .35794 Mdot
.35905 .56085 Mdot
.29158 .74128 Mdot
.51266 .3691 Mdot
.533 .35097 Mdot
.36492 .38623 Mdot
.63909 .69142 Mdot
.55221 .66233 Mdot
.74432 .48757 Mdot
.65284 .47599 Mdot
.3676 .5487 Mdot
.20727 .55936 Mdot
.35896 .65057 Mdot
.45834 .25736 Mdot
.67847 .50734 Mdot
.55125 .38504 Mdot
.43001 .52426 Mdot
.41055 .5351 Mdot
.36674 .38338 Mdot
.60307 .22877 Mdot
.40227 .51627 Mdot
.7788 .34596 Mdot
.22975 .38522 Mdot
.28452 .30626 Mdot
.44221 .57599 Mdot
.55842 .68478 Mdot
.5108 .32778 Mdot
.38282 .39265 Mdot
.36932 .62307 Mdot
.3456 .21059 Mdot
.53615 .64729 Mdot
.6611 .51295 Mdot
.55541 .50781 Mdot
.34031 .41601 Mdot
.3944 .61646 Mdot
.39206 .6091 Mdot
.41938 .61074 Mdot
.25881 .26923 Mdot
.51487 .33734 Mdot
.60765 .66789 Mdot
.37948 .35424 Mdot
.60029 .6831 Mdot
.5576 .37028 Mdot
.70506 .55826 Mdot
.37275 .58176 Mdot
.53479 .64837 Mdot
.56832 .67219 Mdot
.67216 .51922 Mdot
.64439 .52031 Mdot
.56677 .49449 Mdot
.39558 .59836 Mdot
.54832 .40537 Mdot
.56618 .63356 Mdot
.43099 .44837 Mdot
.37934 .36499 Mdot
.65297 .48323 Mdot
.43321 .5428 Mdot
.50937 .34848 Mdot
.33758 .5787 Mdot
.55896 .65458 Mdot
.52817 .36615 Mdot
.58143 .25946 Mdot
.35391 .38861 Mdot
.41284 .60335 Mdot
.40617 .40065 Mdot
.56481 .37714 Mdot
.42105 .56195 Mdot
.79127 .4818 Mdot
.33204 .38699 Mdot
.71897 .35871 Mdot
.56913 .38159 Mdot
.62352 .32744 Mdot
.58994 .69811 Mdot
.71705 .6601 Mdot
.53031 .34934 Mdot
.77501 .48814 Mdot
.61278 .25107 Mdot
.43191 .523 Mdot
.59514 .66116 Mdot
.61654 .4303 Mdot
.54516 .16901 Mdot
.8107 .59526 Mdot
.39584 .57754 Mdot
.58138 .34771 Mdot
.36379 .37971 Mdot
.69845 .49784 Mdot
.53462 .28241 Mdot
.33108 .3777 Mdot
.52881 .40021 Mdot
.38126 .54607 Mdot
.5789 .67631 Mdot
.65765 .48745 Mdot
.69131 .62404 Mdot
.53546 .3838 Mdot
.51996 .36818 Mdot
.4317 .5258 Mdot
.38189 .3806 Mdot
.74235 .66239 Mdot
.56032 .3499 Mdot
.24314 .37336 Mdot
.55285 .41276 Mdot
.40215 .35517 Mdot
.43009 .55234 Mdot
.28028 .37902 Mdot
.46746 .58295 Mdot
.81364 .49815 Mdot
.54566 .3769 Mdot
.56441 .65267 Mdot
.41553 .61665 Mdot
.25022 .59517 Mdot
.53447 .33284 Mdot
.45464 .44481 Mdot
.39964 .27178 Mdot
.64645 .49021 Mdot
.20711 .44487 Mdot
.4135 .59674 Mdot
.68172 .47182 Mdot
.36972 .38288 Mdot
.3889 .59302 Mdot
.4048 .55815 Mdot
.58614 .63634 Mdot
.67874 .5179 Mdot
.57505 .23372 Mdot
.65537 .46418 Mdot
.64277 .50897 Mdot
.57465 .62829 Mdot
.42624 .58044 Mdot
.52567 .35252 Mdot
.54515 .35133 Mdot
.3509 .60604 Mdot
.33978 .80013 Mdot
.54927 .66262 Mdot
.51962 .31481 Mdot
.24862 .28434 Mdot
.32976 .5651 Mdot
.20528 .46603 Mdot
.61512 .23202 Mdot
.71114 .48938 Mdot
.4089 .53262 Mdot
.58696 .67873 Mdot
.47548 .40167 Mdot
.52021 .36393 Mdot
.39443 .62189 Mdot
.65813 .49005 Mdot
.35788 .35582 Mdot
.56083 .33604 Mdot
.46891 .25382 Mdot
.4245 .60388 Mdot
.43534 .33033 Mdot
.57391 .33392 Mdot
.66978 .21062 Mdot
.69424 .41842 Mdot
.59236 .65656 Mdot
.40048 .55379 Mdot
.61089 .68237 Mdot
.37455 .35463 Mdot
.55571 .50509 Mdot
.65347 .49079 Mdot
.40904 .4871 Mdot
.20944 .68031 Mdot
.56759 .36957 Mdot
.60885 .66978 Mdot
.43611 .53194 Mdot
.641 .62606 Mdot
.41885 .59254 Mdot
.49893 .61243 Mdot
.39544 .4277 Mdot
.69623 .48523 Mdot
.67665 .47278 Mdot
.41744 .55438 Mdot
.39674 .3547 Mdot
.54048 .38292 Mdot
.53895 .33632 Mdot
.79418 .31925 Mdot
.62422 .5674 Mdot
.23347 .52606 Mdot
.40375 .6088 Mdot
.53792 .40153 Mdot
.64882 .30228 Mdot
.68622 .50912 Mdot
.34062 .59755 Mdot
.57136 .35051 Mdot
.34041 .29813 Mdot
.26118 .57049 Mdot
.43462 .56366 Mdot
.45252 .62118 Mdot
.64823 .47839 Mdot
.43472 .46343 Mdot
.54302 .39318 Mdot
.34656 .5408 Mdot
.72994 .48797 Mdot
.27781 .60288 Mdot
.25979 .30421 Mdot
.56773 .6481 Mdot
.45371 .24429 Mdot
.68016 .49357 Mdot
.45841 .61983 Mdot
.40079 .37235 Mdot
.50423 .33975 Mdot
.5121 .33925 Mdot
.37771 .55732 Mdot
.37401 .53261 Mdot
.2221 .44233 Mdot
.59355 .6862 Mdot
.65188 .51369 Mdot
.38103 .59834 Mdot
.75327 .55628 Mdot
.44777 .55258 Mdot
.67885 .4804 Mdot
.12057 .55889 Mdot
.44543 .5347 Mdot
.42313 .59146 Mdot
.75655 .64705 Mdot
.54539 .68018 Mdot
.61061 .66785 Mdot
.19096 .51297 Mdot
.40447 .60851 Mdot
.21904 .41514 Mdot
.56214 .64726 Mdot
.55183 .65938 Mdot
.67209 .35775 Mdot
.41001 .56539 Mdot
.3674 .48898 Mdot
.70161 .48155 Mdot
.63831 .50217 Mdot
.55522 .68634 Mdot
.4231 .51522 Mdot
.68149 .52429 Mdot
.66978 .74288 Mdot
.54135 .35859 Mdot
.30507 .75674 Mdot
.54443 .65905 Mdot
.63171 .45089 Mdot
.68372 .50796 Mdot
.36373 .1713 Mdot
.59262 .39975 Mdot
.37535 .58309 Mdot
.41328 .60614 Mdot
.37338 .38743 Mdot
.45372 .54845 Mdot
.53989 .39782 Mdot
.67358 .49829 Mdot
.384 .67462 Mdot
.57404 .6481 Mdot
.40526 .59402 Mdot
.77688 .40396 Mdot
.72481 .33085 Mdot
.45437 .23498 Mdot
.55468 .66913 Mdot
.59198 .65113 Mdot
.53356 .38963 Mdot
.58077 .34676 Mdot
.4341 .57633 Mdot
.70289 .50285 Mdot
.60279 .65535 Mdot
.686 .47993 Mdot
.51257 .36736 Mdot
.52529 .35788 Mdot
.50963 .33844 Mdot
.34036 .56575 Mdot
.52715 .37271 Mdot
.54714 .26947 Mdot
.72041 .54281 Mdot
.59622 .63822 Mdot
.20438 .39408 Mdot
.69824 .6247 Mdot
.61956 .72862 Mdot
.40687 .3791 Mdot
.56659 .37577 Mdot
.66108 .46737 Mdot
.41449 .54413 Mdot
.44428 .56053 Mdot
.59854 .30077 Mdot
.68027 .46878 Mdot
.37227 .35627 Mdot
.67325 .47093 Mdot
.38515 .35396 Mdot
.40384 .30182 Mdot
.45483 .56075 Mdot
.35269 .5588 Mdot
.68028 .49814 Mdot
.52799 .37029 Mdot
.55917 .35843 Mdot
.34462 .37233 Mdot
.60371 .53271 Mdot
.56704 .3519 Mdot
.54839 .65538 Mdot
.57194 .74511 Mdot
.54154 .32434 Mdot
.39919 .60262 Mdot
.33504 .45443 Mdot
.57694 .79888 Mdot
.46665 .602 Mdot
.66542 .3548 Mdot
.47747 .81188 Mdot
.4357 .61035 Mdot
.5464 .82162 Mdot
.62492 .36935 Mdot
.58936 .69686 Mdot
.55095 .39111 Mdot
.49899 .33469 Mdot
.33969 .61695 Mdot
.33853 .3779 Mdot
.36109 .61715 Mdot
.54131 .65991 Mdot
.58846 .70719 Mdot
.29235 .31378 Mdot
.81092 .53805 Mdot
.36261 .37635 Mdot
.35791 .37506 Mdot
.53087 .34603 Mdot
.85706 .49911 Mdot
.45145 .51722 Mdot
.36988 .35816 Mdot
.52596 .5784 Mdot
.37963 .54923 Mdot
.26433 .50283 Mdot
.42101 .34333 Mdot
.55433 .68344 Mdot
.29388 .36971 Mdot
.52704 .34273 Mdot
.60191 .68657 Mdot
.74165 .57371 Mdot
.45827 .5959 Mdot
.57294 .65017 Mdot
.68011 .47856 Mdot
.71322 .41055 Mdot
.54703 .64844 Mdot
.32322 .45891 Mdot
.6889 .51756 Mdot
.43801 .4481 Mdot
.27139 .41047 Mdot
.61188 .87424 Mdot
.67594 .49464 Mdot
.53847 .32637 Mdot
.54514 .35021 Mdot
.53779 .33678 Mdot
.59756 .68622 Mdot
.5656 .37936 Mdot
.59567 .68326 Mdot
.77747 .65796 Mdot
.64263 .67746 Mdot
.3685 .35995 Mdot
.68526 .34876 Mdot
.58824 .67226 Mdot
.27143 .72553 Mdot
.29353 .78786 Mdot
.40854 .53216 Mdot
.64187 .46995 Mdot
.36514 .36521 Mdot
.78697 .35554 Mdot
.37348 .37519 Mdot
.27338 .35354 Mdot
.29594 .71434 Mdot
.41181 .58857 Mdot
.48962 .75636 Mdot
.37638 .39909 Mdot
.56141 .67621 Mdot
.41918 .56158 Mdot
.5195 .43256 Mdot
.3751 .37864 Mdot
.37398 .34908 Mdot
.42727 .57326 Mdot
.56566 .63798 Mdot
.52295 .34677 Mdot
.63826 .48037 Mdot
.39283 .3986 Mdot
.48974 .63673 Mdot
.46248 .6039 Mdot
.37052 .57111 Mdot
.49514 .49609 Mdot
.41653 .35617 Mdot
.6705 .49727 Mdot
.61076 .8002 Mdot
.57414 .37512 Mdot
.53677 .43245 Mdot
.24999 .357 Mdot
.64886 .35739 Mdot
.54595 .37429 Mdot
.55789 .37992 Mdot
.43441 .5686 Mdot
.40715 .34159 Mdot
.30334 .72238 Mdot
.61866 .52751 Mdot
.51465 .32572 Mdot
.54254 .33717 Mdot
.60597 .69698 Mdot
.28245 .32003 Mdot
.37376 .62564 Mdot
.68981 .52231 Mdot
.50979 .34294 Mdot
.6565 .66348 Mdot
.38269 .38345 Mdot
.27117 .70383 Mdot
.45639 .56673 Mdot
.37651 .58782 Mdot
.65888 .4998 Mdot
.6667 .47956 Mdot
.47221 .40032 Mdot
.27879 .33125 Mdot
.49463 .81133 Mdot
.67228 .62266 Mdot
.32918 .70674 Mdot
.60142 .70277 Mdot
.59924 .65309 Mdot
.74565 .39304 Mdot
.6525 .4641 Mdot
.42826 .61351 Mdot
.60441 .66941 Mdot
.56403 .42943 Mdot
.58806 .7333 Mdot
.24543 .51247 Mdot
.21293 .47246 Mdot
.38588 .565 Mdot
.57175 .68935 Mdot
.54408 .67762 Mdot
.53016 .63013 Mdot
.61625 .39616 Mdot
.43407 .58365 Mdot
.39045 .57089 Mdot
.44441 .59803 Mdot
.61062 .60869 Mdot
.43655 .59484 Mdot
.70985 .66209 Mdot
.54718 .48753 Mdot
.33638 .68235 Mdot
.35574 .53272 Mdot
.71619 .49924 Mdot
.39044 .61397 Mdot
.39466 .35372 Mdot
.38154 .54165 Mdot
.2455 .5194 Mdot
.67446 .51414 Mdot
.57688 .7234 Mdot
.69996 .63442 Mdot
.42545 .61923 Mdot
.36484 .40275 Mdot
.67621 .43133 Mdot
.48353 .1805 Mdot
.39443 .41217 Mdot
.54743 .65618 Mdot
.54266 .36485 Mdot
.66491 .46698 Mdot
.52837 .35758 Mdot
.34953 .55095 Mdot
.75247 .40716 Mdot
.72572 .31274 Mdot
.58677 .47579 Mdot
.44533 .55408 Mdot
.34812 .51284 Mdot
.55296 .65579 Mdot
.57445 .3685 Mdot
.62902 .69122 Mdot
.41386 .61542 Mdot
.3872 .35779 Mdot
.37326 .38269 Mdot
.57488 .43663 Mdot
.65273 .22471 Mdot
.6638 .71638 Mdot
.6613 .49891 Mdot
.5564 .3433 Mdot
.39307 .38981 Mdot
.78856 .53606 Mdot
.6443 .52101 Mdot
.70639 .49145 Mdot
.66562 .51605 Mdot
.36547 .59459 Mdot
.51835 .32731 Mdot
.33837 .68142 Mdot
.53452 .39951 Mdot
.39731 .56537 Mdot
.5139 .34265 Mdot
.57097 .35424 Mdot
.3922 .38654 Mdot
.65888 .51617 Mdot
.51863 .38077 Mdot
.38425 .53371 Mdot
.56366 .64244 Mdot
.66936 .44907 Mdot
.27314 .53249 Mdot
.81079 .52457 Mdot
.41009 .66865 Mdot
.53633 .66286 Mdot
.54432 .17404 Mdot
.70943 .493 Mdot
.58831 .59094 Mdot
.5376 .23718 Mdot
.36055 .56915 Mdot
.30107 .77745 Mdot
.5581 .31732 Mdot
.56915 .34337 Mdot
.42882 .55282 Mdot
.49413 .40265 Mdot
.41052 .59265 Mdot
.51471 .36218 Mdot
.58378 .27899 Mdot
.50547 .62262 Mdot
.53234 .37429 Mdot
.34232 .54703 Mdot
.41045 .55695 Mdot
.55864 .68698 Mdot
.5605 .32319 Mdot
.34147 .60261 Mdot
.77681 .30007 Mdot
.67104 .48118 Mdot
.61864 .4109 Mdot
.33833 .46289 Mdot
.68134 .49282 Mdot
.58154 .65107 Mdot
.35032 .59349 Mdot
.36785 .38264 Mdot
.58844 .67385 Mdot
.26053 .5848 Mdot
.36103 .39291 Mdot
.2777 .74446 Mdot
.54513 .6764 Mdot
.54834 .32574 Mdot
.40102 .3664 Mdot
.46005 .55713 Mdot
.50509 .33803 Mdot
.72263 .43299 Mdot
.54422 .37468 Mdot
.4423 .58054 Mdot
.68784 .3345 Mdot
.64755 .51134 Mdot
.39512 .58031 Mdot
.56772 .33859 Mdot
.65769 .34748 Mdot
.36317 .59014 Mdot
.42383 .55636 Mdot
.26106 .3151 Mdot
.23227 .65637 Mdot
.37587 .36888 Mdot
.52471 .63926 Mdot
.40407 .53344 Mdot
.3697 .35102 Mdot
.45782 .30451 Mdot
.37219 .59538 Mdot
.53626 .6446 Mdot
.33107 .54836 Mdot
.56669 .32649 Mdot
.68408 .4882 Mdot
.59576 .46616 Mdot
.36244 .35338 Mdot
.75705 .74056 Mdot
.5167 .38515 Mdot
.35259 .5654 Mdot
.44044 .54476 Mdot
.3819 .24559 Mdot
.59059 .69592 Mdot
.40144 .79592 Mdot
.41289 .60356 Mdot
.60268 .60392 Mdot
.39228 .59202 Mdot
.53615 .3135 Mdot
.55143 .66149 Mdot
.42819 .59177 Mdot
.74607 .5274 Mdot
.46865 .60569 Mdot
.35031 .37327 Mdot
.76105 .64623 Mdot
.45228 .61301 Mdot
.16444 .64032 Mdot
.38495 .31785 Mdot
.53206 .37618 Mdot
.72033 .33878 Mdot
.84956 .37376 Mdot
.71013 .64143 Mdot
.60115 .67944 Mdot
.65203 .25376 Mdot
.52536 .3534 Mdot
.68414 .31184 Mdot
.5362 .16962 Mdot
.40926 .5521 Mdot
.39491 .61676 Mdot
.31851 .32296 Mdot
.56193 .39098 Mdot
.53332 .40554 Mdot
.39376 .52101 Mdot
.45032 .62498 Mdot
.52336 .36512 Mdot
.37356 .53716 Mdot
.3678 .53198 Mdot
.63618 .47863 Mdot
.53845 .65227 Mdot
.7 .48881 Mdot
.68985 .51998 Mdot
.70371 .71772 Mdot
.36624 .3088 Mdot
.67899 .48175 Mdot
.70917 .50699 Mdot
.26327 .5077 Mdot
.23773 .43915 Mdot
.40503 .37995 Mdot
.69249 .23878 Mdot
.54172 .33912 Mdot
.42955 .58421 Mdot
.53897 .66962 Mdot
.50866 .80795 Mdot
.50771 .28043 Mdot
.32029 .75507 Mdot
.42173 .6146 Mdot
.53115 .3354 Mdot
.6165 .39605 Mdot
.48835 .6097 Mdot
.58358 .37474 Mdot
.38197 .60128 Mdot
.52217 .39642 Mdot
.50922 .71933 Mdot
.77342 .48577 Mdot
.54479 .41052 Mdot
.58849 .63007 Mdot
.38088 .59381 Mdot
.54313 .6624 Mdot
.68726 .50495 Mdot
.40386 .37021 Mdot
.37928 .36836 Mdot
.42329 .56602 Mdot
.38579 .50816 Mdot
.41565 .31303 Mdot
.40834 .56218 Mdot
.38514 .54498 Mdot
.62522 .36785 Mdot
.38763 .5415 Mdot
.44989 .56791 Mdot
.44794 .58629 Mdot
.38752 .61975 Mdot
.64015 .50542 Mdot
.77755 .41819 Mdot
.41315 .6385 Mdot
.43523 .63542 Mdot
.64597 .51912 Mdot
.58598 .22999 Mdot
.70039 .51231 Mdot
.48883 .17477 Mdot
.69456 .47735 Mdot
.37926 .3616 Mdot
.44349 .21716 Mdot
.40475 .50078 Mdot
.55854 .63222 Mdot
.63551 .51856 Mdot
.3789 .35285 Mdot
.67389 .50199 Mdot
.51599 .35218 Mdot
.27055 .27834 Mdot
.51357 .64721 Mdot
.45791 .4914 Mdot
.6333 .52377 Mdot
.7566 .42871 Mdot
.5227 .38757 Mdot
.54646 .66755 Mdot
.53268 .76687 Mdot
.44882 .55849 Mdot
.37364 .35027 Mdot
.43209 .57357 Mdot
.65877 .51859 Mdot
.53008 .34003 Mdot
.79969 .60612 Mdot
.36712 .38355 Mdot
.21826 .37467 Mdot
.55499 .35525 Mdot
.45107 .58468 Mdot
.68557 .52308 Mdot
.1812 .45823 Mdot
.69804 .4852 Mdot
.35117 .75608 Mdot
.60394 .69276 Mdot
.78132 .67909 Mdot
.5939 .66877 Mdot
.73611 .43999 Mdot
.16268 .40525 Mdot
.78574 .41921 Mdot
.56583 .63915 Mdot
.64257 .55832 Mdot
.37986 .56514 Mdot
.37059 .57231 Mdot
.79463 .54001 Mdot
.52542 .63924 Mdot
.422 .53645 Mdot
.60797 .28969 Mdot
.6912 .55456 Mdot
.20548 .51394 Mdot
.55069 .38212 Mdot
.40992 .59619 Mdot
.72394 .50521 Mdot
.68606 .4715 Mdot
.5247 .3942 Mdot
.70796 .4935 Mdot
.39257 .57125 Mdot
.58922 .67155 Mdot
.4919 .3206 Mdot
.38939 .36977 Mdot
.82166 .4231 Mdot
.38624 .34546 Mdot
.54643 .37396 Mdot
.44916 .53561 Mdot
.52538 .35912 Mdot
.85655 .35589 Mdot
.38642 .57437 Mdot
.56184 .64854 Mdot
.40261 .53662 Mdot
.38191 .59073 Mdot
.40149 .61995 Mdot
.51968 .35547 Mdot
.29896 .55317 Mdot
.37946 .53491 Mdot
.65239 .49061 Mdot
.33852 .69718 Mdot
.44982 .61319 Mdot
.48626 .35762 Mdot
.24441 .46309 Mdot
.69304 .53814 Mdot
.55417 .69112 Mdot
.53713 .37624 Mdot
.57352 .6454 Mdot
.6189 .63751 Mdot
.58146 .65129 Mdot
.38327 .7411 Mdot
.5329 .75849 Mdot
.2869 .63352 Mdot
.44107 .67734 Mdot
.57262 .54567 Mdot
.52502 .63911 Mdot
.42351 .36632 Mdot
.5891 .64245 Mdot
.55168 .68602 Mdot
.06868 .49889 Mdot
.55895 .62958 Mdot
.40356 .60392 Mdot
.45358 .6031 Mdot
.76671 .44819 Mdot
.29494 .45646 Mdot
.40556 .54079 Mdot
.41526 .5391 Mdot
.39916 .38146 Mdot
.59109 .60634 Mdot
.73125 .36713 Mdot
.22829 .66624 Mdot
.69912 .30742 Mdot
.42944 .57268 Mdot
.40101 .53329 Mdot
.4782 .61388 Mdot
.16295 .54848 Mdot
.70505 .73046 Mdot
.55004 .69803 Mdot
.47862 .60262 Mdot
.80886 .45568 Mdot
.40169 .61862 Mdot
.3765 .60559 Mdot
.38361 .56532 Mdot
.5254 .35233 Mdot
.53426 .6748 Mdot
.37252 .61499 Mdot
.32461 .31481 Mdot
.3839 .60649 Mdot
.65219 .35527 Mdot
.83673 .58756 Mdot
.41416 .59689 Mdot
.54436 .6879 Mdot
.36995 .56706 Mdot
.57885 .697 Mdot
.56229 .68079 Mdot
.46659 .54716 Mdot
.33239 .70848 Mdot
.57642 .70462 Mdot
.39757 .56469 Mdot
.5218 .34123 Mdot
.66279 .21113 Mdot
.44212 .58224 Mdot
.40511 .37268 Mdot
.4115 .60633 Mdot
.37041 .40499 Mdot
.38991 .54415 Mdot
.51656 .38595 Mdot
.5488 .80163 Mdot
.5331 .34865 Mdot
.73207 .72448 Mdot
.50682 .34983 Mdot
.25091 .32286 Mdot
.53073 .6527 Mdot
.6853 .34212 Mdot
.45716 .82971 Mdot
.63063 .39353 Mdot
.44236 .42972 Mdot
.51832 .48437 Mdot
.70356 .50208 Mdot
.60401 .68927 Mdot
.54878 .57121 Mdot
.54616 .24682 Mdot
.48613 .22789 Mdot
.5632 .34499 Mdot
.55527 .84142 Mdot
.35265 .79318 Mdot
.36264 .54955 Mdot
.46927 .76384 Mdot
.42048 .7215 Mdot
.39737 .61888 Mdot
.36862 .61086 Mdot
.61308 .33508 Mdot
.3909 .52935 Mdot
.75605 .54935 Mdot
.5497 .37234 Mdot
.37871 .35214 Mdot
.55519 .6516 Mdot
.35926 .35423 Mdot
.53732 .24162 Mdot
.5126 .48275 Mdot
.51339 .36093 Mdot
.44915 .62083 Mdot
.41601 .54193 Mdot
.57108 .69397 Mdot
.60696 .71817 Mdot
.5763 .63519 Mdot
.3643 .37236 Mdot
.55147 .36642 Mdot
.60009 .78232 Mdot
.42375 .54218 Mdot
.56868 .67111 Mdot
.44378 .41728 Mdot
.40665 .53344 Mdot
.68494 .50031 Mdot
.37924 .56987 Mdot
.5597 .64037 Mdot
.38793 .54142 Mdot
.59538 .66977 Mdot
.54129 .36244 Mdot
.44673 .60659 Mdot
.43249 .55704 Mdot
.19558 .42212 Mdot
.37711 .35716 Mdot
.53154 .64507 Mdot
.59606 .40811 Mdot
.43763 .53794 Mdot
.69072 .369 Mdot
.38637 .60347 Mdot
.62086 .73565 Mdot
.35654 .57584 Mdot
.62642 .39142 Mdot
.38687 .6343 Mdot
.44036 .5846 Mdot
.46475 .41098 Mdot
.41656 .7297 Mdot
.54031 .69425 Mdot
.69976 .51932 Mdot
.54399 .63105 Mdot
.20935 .51596 Mdot
.55704 .41425 Mdot
.57829 .35888 Mdot
.31248 .39648 Mdot
.39096 .62192 Mdot
.41442 .58771 Mdot
.70214 .52333 Mdot
.35504 .37607 Mdot
.55597 .67067 Mdot
.38502 .35403 Mdot
.21311 .41347 Mdot
.35984 .38751 Mdot
.55018 .31493 Mdot
.43685 .32968 Mdot
.61913 .76919 Mdot
.39769 .383 Mdot
.56435 .63755 Mdot
.47565 .32548 Mdot
.40059 .62392 Mdot
.39454 .3229 Mdot
.39185 .36267 Mdot
.62392 .82616 Mdot
.44957 .56869 Mdot
.43792 .42972 Mdot
.68794 .48531 Mdot
.40083 .37464 Mdot
.69188 .51252 Mdot
.41466 .54638 Mdot
.72129 .35883 Mdot
.60166 .6766 Mdot
.65895 .52184 Mdot
.39298 .51043 Mdot
.36432 .36423 Mdot
.51426 .33413 Mdot
.67773 .53135 Mdot
.69087 .52305 Mdot
.60027 .22477 Mdot
.7871 .63431 Mdot
.55182 .36353 Mdot
.24972 .62386 Mdot
.69696 .47732 Mdot
.41404 .62313 Mdot
.5703 .5965 Mdot
.37499 .58387 Mdot
.69706 .68517 Mdot
.5406 .37999 Mdot
.76936 .43083 Mdot
.39811 .53518 Mdot
.43494 .60569 Mdot
.5295 .67736 Mdot
.53989 .34622 Mdot
.57857 .66362 Mdot
.5416 .6295 Mdot
.54184 .3607 Mdot
.59319 .66012 Mdot
.36837 .39778 Mdot
.6773 .57436 Mdot
.65478 .47426 Mdot
.64855 .49739 Mdot
.53986 .33595 Mdot
.53143 .37916 Mdot
.52742 .3646 Mdot
.37893 .57018 Mdot
.55229 .66645 Mdot
.39768 .55079 Mdot
.38639 .61035 Mdot
.31964 .69138 Mdot
.53917 .67696 Mdot
.38848 .55808 Mdot
.50305 .42499 Mdot
.37464 .327 Mdot
.52061 .34025 Mdot
.68221 .48329 Mdot
.64167 .30396 Mdot
.71855 .4361 Mdot
.40567 .59763 Mdot
.35126 .29751 Mdot
.5717 .63672 Mdot
.37009 .38096 Mdot
.40178 .3469 Mdot
.37395 .37284 Mdot
.60828 .50067 Mdot
.52756 .63952 Mdot
.23247 .67532 Mdot
.41276 .59328 Mdot
.48918 .48894 Mdot
.51547 .5657 Mdot
.39761 .30551 Mdot
.67749 .48258 Mdot
.40936 .53526 Mdot
.59506 .47329 Mdot
.54983 .77381 Mdot
.37734 .58316 Mdot
.44094 .61953 Mdot
.58305 .26266 Mdot
.32645 .55555 Mdot
.6131 .68367 Mdot
.18424 .46494 Mdot
.44559 .5388 Mdot
.65456 .66778 Mdot
.83229 .43088 Mdot
.39491 .60059 Mdot
.42354 .61057 Mdot
.43909 .55295 Mdot
.37832 .54385 Mdot
.56353 .69941 Mdot
.28432 .42063 Mdot
.709 .48482 Mdot
.48174 .4857 Mdot
.6347 .49483 Mdot
.50334 .35088 Mdot
.77582 .43102 Mdot
.60666 .68747 Mdot
.37292 .38728 Mdot
.77647 .36892 Mdot
.19049 .56712 Mdot
.54419 .39286 Mdot
.66971 .73995 Mdot
.38653 .3593 Mdot
.42488 .62226 Mdot
.37296 .40126 Mdot
.52482 .3257 Mdot
.64672 .49203 Mdot
.41804 .62782 Mdot
.5903 .6445 Mdot
.54499 .65039 Mdot
.4151 .534 Mdot
.80444 .43932 Mdot
.68768 .49713 Mdot
.67526 .52906 Mdot
.36768 .59322 Mdot
.45999 .55793 Mdot
.58085 .66145 Mdot
.55618 .34672 Mdot
.23834 .56477 Mdot
.357 .36496 Mdot
.33995 .57263 Mdot
.38036 .54613 Mdot
.25614 .34675 Mdot
.65222 .4857 Mdot
.58302 .35462 Mdot
.36033 .57631 Mdot
.66316 .61928 Mdot
.36094 .57394 Mdot
.48257 .59656 Mdot
.52344 .33862 Mdot
.40171 .64015 Mdot
.35802 .5512 Mdot
.50665 .60861 Mdot
.70027 .50144 Mdot
.5683 .65064 Mdot
.51994 .62756 Mdot
.51013 .52733 Mdot
.68324 .50157 Mdot
.38172 .55989 Mdot
.67107 .48496 Mdot
.37268 .59491 Mdot
.40125 .53028 Mdot
.67953 .48062 Mdot
.57973 .66377 Mdot
.65113 .25669 Mdot
.77659 .41107 Mdot
.37639 .54351 Mdot
.42152 .52015 Mdot
.28781 .43645 Mdot
.3013 .54658 Mdot
.40788 .61665 Mdot
.55508 .64262 Mdot
.4264 .54659 Mdot
.68609 .51365 Mdot
.3792 .39856 Mdot
.56288 .64165 Mdot
.56185 .36398 Mdot
.53505 .39253 Mdot
.70388 .6357 Mdot
.5719 .36644 Mdot
.38305 .61431 Mdot
.62687 .66356 Mdot
.51473 .63332 Mdot
.82391 .45052 Mdot
.54264 .3568 Mdot
.40362 .38564 Mdot
.42341 .55789 Mdot
.31644 .29428 Mdot
.72566 .50452 Mdot
.20006 .70235 Mdot
.26579 .72333 Mdot
.34012 .36728 Mdot
.32167 .74977 Mdot
.50689 .36883 Mdot
.35149 .55534 Mdot
.40372 .3653 Mdot
.53544 .38976 Mdot
.36503 .56303 Mdot
.47746 .56473 Mdot
.38621 .78746 Mdot
.5398 .5281 Mdot
.6684 .48403 Mdot
.56632 .38074 Mdot
.34159 .3555 Mdot
.56995 .3223 Mdot
.53943 .66386 Mdot
.43638 .58717 Mdot
.45169 .53584 Mdot
.56161 .35636 Mdot
.57494 .37879 Mdot
.39236 .56268 Mdot
.61054 .68296 Mdot
.61442 .34611 Mdot
.42325 .57181 Mdot
.58626 .56131 Mdot
.55019 .61763 Mdot
.55338 .37539 Mdot
.43926 .59869 Mdot
.41035 .4281 Mdot
.55587 .35288 Mdot
.51972 .34003 Mdot
.40756 .53173 Mdot
.36458 .39617 Mdot
.42824 .52347 Mdot
.6815 .4741 Mdot
.6133 .8067 Mdot
.68325 .51591 Mdot
.53673 .28466 Mdot
.39278 .50901 Mdot
.63594 .59091 Mdot
.56982 .69862 Mdot
.28799 .34137 Mdot
.61578 .29147 Mdot
.38706 .52134 Mdot
.62499 .20774 Mdot
.63966 .44621 Mdot
.79902 .4141 Mdot
.40653 .20871 Mdot
.39517 .37639 Mdot
.6745 .50421 Mdot
.42214 .61114 Mdot
.63955 .47284 Mdot
.4048 .36499 Mdot
.73453 .71934 Mdot
.44393 .59226 Mdot
.55268 .65998 Mdot
.38988 .56663 Mdot
.54517 .65802 Mdot
.40388 .53173 Mdot
.47082 .62222 Mdot
.62136 .319 Mdot
.26168 .56892 Mdot
.35767 .58362 Mdot
.24273 .30599 Mdot
.43249 .39299 Mdot
.36845 .35402 Mdot
.40401 .55309 Mdot
.58001 .38732 Mdot
.68688 .46986 Mdot
.77333 .56848 Mdot
.52459 .35304 Mdot
.70278 .5138 Mdot
.58674 .6577 Mdot
.54107 .37367 Mdot
.53659 .39519 Mdot
.39386 .63946 Mdot
.35148 .39046 Mdot
.6534 .51051 Mdot
.42903 .59315 Mdot
.44349 .59106 Mdot
.23533 .60965 Mdot
.51062 .27124 Mdot
.60834 .72129 Mdot
.18186 .60896 Mdot
.56396 .62372 Mdot
.36705 .35757 Mdot
.52227 .34923 Mdot
.39677 .61262 Mdot
.39778 .5785 Mdot
.67464 .34615 Mdot
.60504 .65639 Mdot
.56102 .50395 Mdot
.61914 .74378 Mdot
.59582 .40393 Mdot
.25527 .48119 Mdot
.55432 .64849 Mdot
.25609 .48389 Mdot
.381 .33956 Mdot
.73678 .28418 Mdot
.26044 .54107 Mdot
.68583 .48582 Mdot
.25789 .47798 Mdot
.56792 .67498 Mdot
.3714 .5418 Mdot
.54729 .32485 Mdot
.57136 .35628 Mdot
.57217 .65643 Mdot
.58605 .34308 Mdot
.38827 .38817 Mdot
.42619 .60548 Mdot
.22509 .65162 Mdot
.71765 .6123 Mdot
.54609 .33417 Mdot
.48234 .6171 Mdot
.6672 .51619 Mdot
.41611 .53368 Mdot
.39187 .38929 Mdot
.67339 .49138 Mdot
.27633 .33992 Mdot
.73306 .52872 Mdot
.42135 .5599 Mdot
.25958 .32333 Mdot
.67887 .49908 Mdot
.3168 .51838 Mdot
.42776 .57805 Mdot
.70102 .48138 Mdot
.31089 .55408 Mdot
.71669 .41494 Mdot
.58726 .48407 Mdot
.53827 .16952 Mdot
.57555 .48351 Mdot
.54894 .32788 Mdot
.73838 .42251 Mdot
.62503 .42279 Mdot
.65444 .46849 Mdot
.5816 .36728 Mdot
.34327 .33554 Mdot
.69363 .51148 Mdot
.44251 .61598 Mdot
.38771 .6018 Mdot
.71581 .72524 Mdot
.62492 .44281 Mdot
.74523 .45078 Mdot
.74886 .61922 Mdot
.44114 .54083 Mdot
.43722 .52668 Mdot
.40246 .58012 Mdot
.5839 .70674 Mdot
.66005 .48537 Mdot
.20512 .36584 Mdot
.68721 .50168 Mdot
.26496 .68758 Mdot
.53909 .33807 Mdot
.54704 .38515 Mdot
.40948 .59818 Mdot
.41856 .44089 Mdot
.2598 .4065 Mdot
.39483 .56995 Mdot
.32629 .35359 Mdot
.76729 .63914 Mdot
.45602 .55129 Mdot
.59214 .7005 Mdot
.47273 .63198 Mdot
.46955 .64569 Mdot
.65479 .47398 Mdot
.38608 .38137 Mdot
.28337 .34765 Mdot
.64418 .49628 Mdot
.41344 .58687 Mdot
.65042 .59181 Mdot
.385 .58666 Mdot
.37164 .54817 Mdot
.28115 .72221 Mdot
.37363 .34261 Mdot
.533 .36267 Mdot
.37241 .37089 Mdot
.57716 .6982 Mdot
.12142 .61681 Mdot
.35344 .38138 Mdot
.26143 .39664 Mdot
.70001 .74957 Mdot
.26019 .47907 Mdot
.54021 .65795 Mdot
.35133 .39307 Mdot
.68761 .49165 Mdot
.67444 .21387 Mdot
.44425 .81704 Mdot
.70979 .45775 Mdot
.41923 .57396 Mdot
.61697 .6676 Mdot
.54925 .64078 Mdot
.65109 .52003 Mdot
.56166 .67926 Mdot
.32453 .5322 Mdot
.37202 .54376 Mdot
.64672 .46874 Mdot
.67215 .61107 Mdot
.70053 .51943 Mdot
.70662 .55956 Mdot
.40334 .55744 Mdot
.55898 .64618 Mdot
.34147 .55767 Mdot
.5438 .61604 Mdot
.57689 .33166 Mdot
.46526 .60146 Mdot
.3859 .3893 Mdot
.6428 .60581 Mdot
.55341 .36277 Mdot
.37189 .29661 Mdot
.56911 .69407 Mdot
.66613 .54494 Mdot
.56007 .68692 Mdot
.52318 .63501 Mdot
.69432 .51786 Mdot
.58577 .68181 Mdot
.42524 .60901 Mdot
.56167 .43638 Mdot
.59042 .69228 Mdot
.66093 .50697 Mdot
.38562 .37729 Mdot
.59113 .66439 Mdot
.49142 .39975 Mdot
.42876 .56195 Mdot
.51958 .36671 Mdot
.43164 .22319 Mdot
.59934 .6434 Mdot
.35504 .35315 Mdot
.57699 .36258 Mdot
.37607 .34894 Mdot
.83205 .51905 Mdot
.63206 .47396 Mdot
.29686 .71168 Mdot
.33473 .35501 Mdot
.5623 .63174 Mdot
.44987 .21698 Mdot
.39569 .61069 Mdot
.42671 .55966 Mdot
.37663 .40685 Mdot
.54968 .64044 Mdot
.77716 .33872 Mdot
.50557 .65742 Mdot
.6737 .56575 Mdot
.62536 .50528 Mdot
.25103 .31522 Mdot
.72936 .54819 Mdot
.86248 .5117 Mdot
.39903 .5153 Mdot
.53061 .40484 Mdot
.40284 .59271 Mdot
.62595 .30428 Mdot
.36615 .36459 Mdot
.50282 .31721 Mdot
.47353 .57287 Mdot
.53737 .3662 Mdot
.44034 .5649 Mdot
.48572 .42669 Mdot
.37172 .64006 Mdot
.40559 .38238 Mdot
.72384 .34703 Mdot
.55371 .63019 Mdot
.38975 .36682 Mdot
.51281 .375 Mdot
.25658 .43489 Mdot
.36628 .55527 Mdot
.33502 .58723 Mdot
.59568 .4039 Mdot
.54791 .66407 Mdot
.56173 .32919 Mdot
.664 .47306 Mdot
.3767 .38509 Mdot
.41255 .54231 Mdot
.36586 .60183 Mdot
.6864 .36964 Mdot
.66586 .51725 Mdot
.56886 .38907 Mdot
.69864 .49079 Mdot
.51064 .38256 Mdot
.40412 .52739 Mdot
.55174 .38499 Mdot
.34017 .58145 Mdot
.62971 .33275 Mdot
.27917 .71311 Mdot
.43271 .74323 Mdot
.54266 .38047 Mdot
.23857 .49141 Mdot
.67685 .51379 Mdot
.70073 .48573 Mdot
.64768 .77296 Mdot
.35317 .76034 Mdot
.2169 .59775 Mdot
.54531 .20471 Mdot
.63674 .48966 Mdot
.66458 .5138 Mdot
.52074 .37166 Mdot
.58494 .68397 Mdot
.54982 .62421 Mdot
.51365 .38786 Mdot
.33869 .45606 Mdot
.5562 .67069 Mdot
.66434 .22386 Mdot
.20582 .54557 Mdot
.35695 .60533 Mdot
.59263 .35764 Mdot
.37585 .38004 Mdot
.32716 .45398 Mdot
.4833 .42376 Mdot
.4322 .60879 Mdot
.30208 .32036 Mdot
.54764 .33839 Mdot
.4175 .45569 Mdot
.49102 .17631 Mdot
.44854 .58356 Mdot
.43023 .58281 Mdot
.40617 .58572 Mdot
.34282 .37111 Mdot
.40731 .79252 Mdot
.43557 .5995 Mdot
.33906 .45798 Mdot
.42972 .53524 Mdot
.30763 .55096 Mdot
.37731 .36891 Mdot
.29917 .62649 Mdot
.5535 .24147 Mdot
.1872 .47745 Mdot
.35318 .63569 Mdot
.66808 .47237 Mdot
.31903 .34663 Mdot
.7039 .49236 Mdot
.39387 .74173 Mdot
.26351 .53635 Mdot
.59089 .63355 Mdot
.42842 .61055 Mdot
.547 .3744 Mdot
.54785 .64232 Mdot
.71251 .39665 Mdot
.08758 .55542 Mdot
.67124 .47159 Mdot
.88195 .48777 Mdot
.69499 .47881 Mdot
.53426 .39539 Mdot
.58079 .66041 Mdot
.53222 .75275 Mdot
.50378 .50588 Mdot
.59317 .66441 Mdot
.71049 .2968 Mdot
.56432 .70747 Mdot
.24696 .47474 Mdot
.61185 .66238 Mdot
.66555 .51031 Mdot
.60901 .49871 Mdot
.40337 .49583 Mdot
.40148 .60801 Mdot
.51779 .48015 Mdot
.24726 .42761 Mdot
.39876 .61072 Mdot
.55 .36965 Mdot
.30871 .71937 Mdot
.29942 .35745 Mdot
.58186 .67907 Mdot
.70464 .47223 Mdot
.43466 .58092 Mdot
.37168 .55913 Mdot
.36606 .55254 Mdot
.20396 .66856 Mdot
.74152 .28747 Mdot
.38186 .53398 Mdot
.43292 .53345 Mdot
.5399 .3702 Mdot
.36472 .33717 Mdot
.61139 .2761 Mdot
.2998 .66714 Mdot
.43896 .61129 Mdot
.38496 .36459 Mdot
.3582 .34466 Mdot
.36158 .56844 Mdot
.39766 .32244 Mdot
.64708 .58708 Mdot
.43026 .59284 Mdot
.31746 .72023 Mdot
.57116 .42316 Mdot
.56146 .39114 Mdot
.56083 .35904 Mdot
.53504 .65268 Mdot
.56544 .37437 Mdot
.50913 .37192 Mdot
.55327 .75364 Mdot
.56484 .48847 Mdot
.70839 .4721 Mdot
.36386 .37376 Mdot
.39388 .58032 Mdot
.53608 .69143 Mdot
.65623 .6088 Mdot
.6976 .51103 Mdot
.58028 .64084 Mdot
.69616 .47373 Mdot
.3982 .40972 Mdot
.47736 .50859 Mdot
.55608 .33788 Mdot
.63942 .48797 Mdot
.72406 .53558 Mdot
.38389 .36599 Mdot
.6731 .52058 Mdot
.71743 .53383 Mdot
.46154 .60108 Mdot
.47145 .77608 Mdot
.39914 .56692 Mdot
.78799 .37662 Mdot
.65344 .51359 Mdot
.63431 .37233 Mdot
.42138 .58875 Mdot
.55404 .35226 Mdot
.42177 .49811 Mdot
.38766 .6082 Mdot
.56517 .36314 Mdot
.36335 .5485 Mdot
.38159 .34573 Mdot
.53801 .61784 Mdot
.48895 .49515 Mdot
.51137 .8638 Mdot
.35149 .39093 Mdot
.71049 .39031 Mdot
.41356 .6165 Mdot
.81315 .58879 Mdot
.59019 .66631 Mdot
.34492 .57487 Mdot
.29379 .3748 Mdot
.59153 .68836 Mdot
.57905 .64511 Mdot
.37618 .55949 Mdot
.69101 .48725 Mdot
.55449 .36692 Mdot
.38129 .36889 Mdot
.84813 .48929 Mdot
.41556 .56708 Mdot
.43043 .5526 Mdot
.3886 .36222 Mdot
.67487 .51625 Mdot
.36102 .57959 Mdot
.39309 .2336 Mdot
.79009 .33808 Mdot
.70713 .48997 Mdot
.44166 .61524 Mdot
.41255 .77019 Mdot
.48575 .64344 Mdot
.76451 .71778 Mdot
.38331 .31766 Mdot
.53357 .36984 Mdot
.34454 .52363 Mdot
.13749 .60861 Mdot
.38452 .3807 Mdot
.19674 .57558 Mdot
.37337 .55399 Mdot
.42614 .54165 Mdot
.57616 .6356 Mdot
.39505 .55409 Mdot
.60847 .67283 Mdot
.5027 .85599 Mdot
.25264 .34808 Mdot
.54468 .66715 Mdot
.5681 .63051 Mdot
.27709 .3827 Mdot
.61649 .28398 Mdot
.57457 .65569 Mdot
.40874 .52914 Mdot
.34456 .64827 Mdot
.48229 .54589 Mdot
.37146 .40274 Mdot
.50756 .22716 Mdot
.51581 .66668 Mdot
.35699 .40802 Mdot
.61573 .23324 Mdot
.52937 .68971 Mdot
.61422 .54721 Mdot
.66915 .47469 Mdot
.44897 .58611 Mdot
.57235 .36015 Mdot
.57203 .37312 Mdot
.35456 .54095 Mdot
.38754 .58042 Mdot
.57399 .69698 Mdot
.36232 .38285 Mdot
.66848 .46899 Mdot
.41698 .54024 Mdot
.28665 .36286 Mdot
.35336 .37584 Mdot
.57177 .68496 Mdot
.30511 .69487 Mdot
.41015 .37014 Mdot
.46276 .62747 Mdot
.42044 .59941 Mdot
.38586 .56493 Mdot
.49342 .57304 Mdot
.66185 .48066 Mdot
.48737 .21332 Mdot
.45764 .57882 Mdot
.21071 .41734 Mdot
.64377 .45347 Mdot
.42155 .63258 Mdot
.55329 .67649 Mdot
.73007 .49629 Mdot
.52379 .32048 Mdot
.50705 .53302 Mdot
.41898 .56047 Mdot
.78179 .40799 Mdot
.73135 .70688 Mdot
.57399 .33039 Mdot
.52439 .63519 Mdot
.37086 .37741 Mdot
.39384 .57172 Mdot
.34234 .71168 Mdot
.39198 .60276 Mdot
.40197 .39914 Mdot
.52353 .3338 Mdot
.6728 .47509 Mdot
.79731 .40278 Mdot
.56979 .37567 Mdot
.57471 .64528 Mdot
.37821 .16617 Mdot
.60911 .67811 Mdot
.54205 .62661 Mdot
.33091 .69565 Mdot
.6652 .47903 Mdot
.15558 .64491 Mdot
.56268 .82445 Mdot
.46681 .577 Mdot
.68082 .51223 Mdot
.56519 .65717 Mdot
.43111 .53959 Mdot
.61966 .66207 Mdot
.52699 .64523 Mdot
.4134 .52736 Mdot
.4431 .55585 Mdot
.77282 .47191 Mdot
.53007 .17481 Mdot
.36928 .37699 Mdot
.55514 .68948 Mdot
.57622 .56094 Mdot
.43772 .54287 Mdot
.41385 .59308 Mdot
.63598 .42261 Mdot
.37263 .39938 Mdot
.75446 .56863 Mdot
.3723 .55681 Mdot
.26597 .33199 Mdot
.43254 .64156 Mdot
.57721 .70382 Mdot
.70625 .49789 Mdot
.19003 .47124 Mdot
.62289 .51332 Mdot
.60724 .66859 Mdot
.36704 .38773 Mdot
.5123 .63691 Mdot
.25917 .39665 Mdot
.64417 .51257 Mdot
.55966 .64036 Mdot
.59614 .46691 Mdot
.663 .49238 Mdot
.64153 .50168 Mdot
.33543 .6914 Mdot
.58366 .37047 Mdot
.34263 .36452 Mdot
.6572 .51263 Mdot
.59696 .59334 Mdot
.66533 .50513 Mdot
.59885 .79646 Mdot
.44731 .60664 Mdot
.33942 .42678 Mdot
.52758 .29131 Mdot
.37088 .50299 Mdot
.64644 .51102 Mdot
.39898 .38322 Mdot
.36568 .56846 Mdot
.56696 .67676 Mdot
.36298 .35451 Mdot
.73818 .48149 Mdot
.52319 .36202 Mdot
.565 .68923 Mdot
.63494 .52217 Mdot
.54498 .65377 Mdot
.54553 .56939 Mdot
.6716 .77563 Mdot
.31988 .26202 Mdot
.51741 .52009 Mdot
.36777 .55185 Mdot
.55951 .21937 Mdot
.36328 .61608 Mdot
.38288 .58005 Mdot
.55225 .37413 Mdot
.32171 .40528 Mdot
.57899 .66332 Mdot
.79072 .36086 Mdot
.64806 .47951 Mdot
.18663 .45885 Mdot
.38501 .65389 Mdot
.35519 .56186 Mdot
.5932 .69161 Mdot
.61122 .67465 Mdot
.40114 .72082 Mdot
.52019 .3206 Mdot
.36603 .6079 Mdot
.39433 .62496 Mdot
.36736 .53413 Mdot
.64635 .48769 Mdot
.36468 .29843 Mdot
.54846 .32878 Mdot
.72714 .74021 Mdot
.52863 .32967 Mdot
.32323 .3663 Mdot
.58158 .68182 Mdot
.35419 .38228 Mdot
.41605 .59341 Mdot
.59102 .71694 Mdot
.60643 .65868 Mdot
.39427 .40054 Mdot
.40153 .36984 Mdot
.67715 .41084 Mdot
.67815 .48066 Mdot
.36366 .59749 Mdot
.43792 .59977 Mdot
.39695 .54841 Mdot
.38078 .57174 Mdot
.66016 .4714 Mdot
.36647 .57731 Mdot
.71635 .51274 Mdot
.53821 .58921 Mdot
.32163 .31143 Mdot
.57375 .47801 Mdot
.68938 .70477 Mdot
.57529 .67765 Mdot
.60533 .58993 Mdot
.49524 .60182 Mdot
.29573 .74761 Mdot
.78005 .61853 Mdot
.46132 .58011 Mdot
.54057 .39152 Mdot
.3307 .51143 Mdot
.56388 .34347 Mdot
.87246 .55162 Mdot
.67059 .3694 Mdot
.57063 .18554 Mdot
.44352 .58896 Mdot
.57961 .43108 Mdot
.6207 .62482 Mdot
.352 .6084 Mdot
.67988 .38783 Mdot
.69201 .69192 Mdot
.74424 .36394 Mdot
.38808 .3936 Mdot
.42894 .56797 Mdot
.53548 .68995 Mdot
.42706 .60685 Mdot
.40701 .59407 Mdot
.3642 .56608 Mdot
.71012 .50977 Mdot
.35605 .597 Mdot
.37152 .5809 Mdot
.4203 .3124 Mdot
.25537 .50916 Mdot
.57517 .37131 Mdot
.67172 .75867 Mdot
.35227 .38 Mdot
.58193 .69595 Mdot
.7104 .27561 Mdot
.68472 .48541 Mdot
.40703 .71979 Mdot
.38281 .56871 Mdot
.77318 .44816 Mdot
.73114 .50356 Mdot
.37857 .38767 Mdot
.52744 .32324 Mdot
.61674 .19379 Mdot
.54662 .36742 Mdot
.59989 .46723 Mdot
.55189 .35277 Mdot
.49796 .61057 Mdot
.57126 .69653 Mdot
.36091 .58951 Mdot
.65175 .50765 Mdot
.56211 .37301 Mdot
.29418 .44407 Mdot
.40194 .5819 Mdot
.54117 .36012 Mdot
.36125 .58999 Mdot
.46336 .49417 Mdot
.26048 .62663 Mdot
.51248 .37887 Mdot
.7265 .49387 Mdot
.65433 .49498 Mdot
.36336 .39514 Mdot
.57718 .69323 Mdot
.59267 .64814 Mdot
.67248 .49265 Mdot
.39088 .79653 Mdot
.43063 .61539 Mdot
.44119 .5477 Mdot
.1945 .44775 Mdot
.41151 .61364 Mdot
.25017 .45187 Mdot
.59231 .47584 Mdot
.5712 .68106 Mdot
.36373 .54237 Mdot
.37722 .55268 Mdot
.42276 .5596 Mdot
.52619 .56945 Mdot
.5568 .34594 Mdot
.45024 .59162 Mdot
.39987 .36325 Mdot
.47025 .39488 Mdot
.41606 .53349 Mdot
.34386 .62085 Mdot
.58973 .64552 Mdot
.19093 .61984 Mdot
.69079 .47766 Mdot
.51739 .3824 Mdot
.541 .38209 Mdot
.52178 .23194 Mdot
.65638 .64268 Mdot
.59102 .47364 Mdot
.75332 .71531 Mdot
.62072 .31875 Mdot
.37585 .35509 Mdot
.58141 .32233 Mdot
.60483 .483 Mdot
.52269 .38052 Mdot
.67032 .47109 Mdot
.45023 .60277 Mdot
.44089 .61048 Mdot
.28819 .75897 Mdot
.36107 .564 Mdot
.37472 .37665 Mdot
.68963 .52607 Mdot
.56824 .67445 Mdot
.3766 .38731 Mdot
.7001 .49252 Mdot
.54742 .66751 Mdot
.45884 .58857 Mdot
.45742 .58974 Mdot
.58326 .64279 Mdot
.55701 .63825 Mdot
.42195 .59627 Mdot
.56602 .27427 Mdot
.55634 .63244 Mdot
.55477 .64545 Mdot
.55277 .33484 Mdot
.57096 .3587 Mdot
.39572 .63608 Mdot
.67983 .51008 Mdot
.37013 .57991 Mdot
.54304 .37338 Mdot
.36047 .38758 Mdot
.57959 .66642 Mdot
.37615 .5447 Mdot
.40673 .53632 Mdot
.38478 .36761 Mdot
.37344 .39398 Mdot
.39701 .38162 Mdot
.7049 .51804 Mdot
.4055 .54881 Mdot
.58162 .65602 Mdot
.67679 .47879 Mdot
.35401 .34695 Mdot
.38284 .40126 Mdot
.56221 .31246 Mdot
.39863 .61433 Mdot
.4724 .34562 Mdot
.11676 .5685 Mdot
.21841 .43443 Mdot
.55506 .3191 Mdot
.53898 .31587 Mdot
.27242 .48219 Mdot
.43533 .45014 Mdot
.6832 .49632 Mdot
.40959 .34543 Mdot
.28131 .3476 Mdot
.45302 .61274 Mdot
.44627 .54039 Mdot
.47609 .60756 Mdot
.39872 .3748 Mdot
.31383 .38207 Mdot
.60538 .68914 Mdot
.50964 .6889 Mdot
.35278 .36762 Mdot
.57452 .3794 Mdot
.58093 .32736 Mdot
.52645 .33026 Mdot
.45356 .59749 Mdot
.4422 .74359 Mdot
.63085 .61052 Mdot
.51 .19686 Mdot
.65607 .51611 Mdot
.52877 .68344 Mdot
.81135 .58373 Mdot
.58264 .64445 Mdot
.5049 .34272 Mdot
.3822 .35335 Mdot
.55321 .64125 Mdot
.6996 .47377 Mdot
.66078 .51273 Mdot
.54406 .33342 Mdot
.53644 .33548 Mdot
.51575 .35723 Mdot
.52735 .63226 Mdot
.58374 .68218 Mdot
.41611 .55929 Mdot
.57986 .67066 Mdot
.25905 .72383 Mdot
.35778 .40279 Mdot
.48847 .3738 Mdot
.6773 .50515 Mdot
.54382 .66281 Mdot
.4014 .57905 Mdot
.43579 .45993 Mdot
.72732 .64462 Mdot
.3836 .3503 Mdot
.24411 .61492 Mdot
.86697 .5596 Mdot
.36509 .59979 Mdot
.65578 .48435 Mdot
.22331 .64528 Mdot
.40725 .58336 Mdot
.52374 .34328 Mdot
.59602 .26778 Mdot
.59201 .39964 Mdot
.383 .6069 Mdot
.44882 .61897 Mdot
.70822 .48658 Mdot
.74635 .71382 Mdot
.41375 .56241 Mdot
.74072 .57859 Mdot
.64569 .46364 Mdot
.54371 .32732 Mdot
.75725 .27876 Mdot
.40181 .24329 Mdot
.3341 .45244 Mdot
.54718 .33121 Mdot
.38165 .59198 Mdot
.56178 .34446 Mdot
.39212 .35287 Mdot
.50956 .3494 Mdot
.60738 .68905 Mdot
.56997 .32918 Mdot
.43129 .55263 Mdot
.57191 .6545 Mdot
.68014 .49952 Mdot
.18472 .5116 Mdot
.47357 .31267 Mdot
.55325 .35028 Mdot
.51992 .38887 Mdot
.36316 .54507 Mdot
.76038 .54235 Mdot
.3448 .54548 Mdot
.44928 .57105 Mdot
.63556 .49426 Mdot
.58841 .69119 Mdot
.70829 .5026 Mdot
.34436 .61016 Mdot
.38719 .2309 Mdot
.69754 .48836 Mdot
.77266 .40337 Mdot
.38507 .35823 Mdot
.50508 .44374 Mdot
.39607 .57767 Mdot
.68363 .51827 Mdot
.40596 .55021 Mdot
.59921 .69403 Mdot
.56429 .45088 Mdot
.7316 .36421 Mdot
.6465 .49954 Mdot
.78676 .40453 Mdot
.32778 .38888 Mdot
.3266 .59383 Mdot
.70338 .48854 Mdot
.29799 .37278 Mdot
.53674 .39554 Mdot
.35713 .36328 Mdot
.4012 .35246 Mdot
.36115 .35352 Mdot
.37117 .52275 Mdot
.35908 .64172 Mdot
.3696 .3433 Mdot
.68011 .46709 Mdot
.40598 .3809 Mdot
.65111 .69473 Mdot
.77952 .35251 Mdot
.36886 .36313 Mdot
.42493 .57589 Mdot
.48367 .6293 Mdot
.26306 .50374 Mdot
.71631 .41985 Mdot
.59109 .19177 Mdot
.7742 .59029 Mdot
.39962 .60698 Mdot
.54559 .61955 Mdot
.54001 .67225 Mdot
.20919 .61755 Mdot
.23894 .44606 Mdot
.23155 .3889 Mdot
.5598 .62744 Mdot
.68709 .33882 Mdot
.57029 .68701 Mdot
.36312 .55756 Mdot
.43702 .54384 Mdot
.56744 .62757 Mdot
.32168 .30433 Mdot
.7102 .36536 Mdot
.82047 .43959 Mdot
.54797 .64947 Mdot
.70101 .50072 Mdot
.65411 .52309 Mdot
.64094 .50252 Mdot
.20749 .56244 Mdot
.60133 .68203 Mdot
.40067 .5425 Mdot
.54402 .38028 Mdot
.4473 .59919 Mdot
.66396 .48844 Mdot
.78992 .3563 Mdot
.59755 .67191 Mdot
.43813 .5873 Mdot
.37496 .48262 Mdot
.52799 .34555 Mdot
.38162 .36111 Mdot
.44457 .48711 Mdot
.23122 .39524 Mdot
.64355 .48617 Mdot
.59232 .63776 Mdot
.64444 .35983 Mdot
.76717 .36308 Mdot
.41316 .51343 Mdot
.38571 .62483 Mdot
.85383 .50315 Mdot
.2698 .34442 Mdot
.38896 .61688 Mdot
.5245 .38847 Mdot
.66987 .34643 Mdot
.39876 .53589 Mdot
.54334 .67885 Mdot
.40823 .36281 Mdot
.37423 .34954 Mdot
.37826 .63393 Mdot
.48258 .48156 Mdot
.56746 .43949 Mdot
.38034 .56104 Mdot
.46595 .62599 Mdot
.54413 .3283 Mdot
.61497 .30399 Mdot
.21351 .41096 Mdot
.36888 .38975 Mdot
.3611 .58765 Mdot
.66451 .27378 Mdot
.58855 .64039 Mdot
.56804 .3254 Mdot
.65783 .51957 Mdot
.50906 .55865 Mdot
.52505 .32437 Mdot
.39053 .53524 Mdot
.3617 .57384 Mdot
.68689 .52115 Mdot
.57955 .70433 Mdot
.39813 .37063 Mdot
.54751 .38307 Mdot
.38018 .39376 Mdot
.59402 .68679 Mdot
.58475 .67442 Mdot
.34809 .49973 Mdot
.44692 .52175 Mdot
.56097 .36224 Mdot
.33882 .57851 Mdot
.56148 .42158 Mdot
.79796 .67001 Mdot
.63557 .51846 Mdot
.37358 .60821 Mdot
.60203 .70399 Mdot
.64522 .49396 Mdot
.435 .54573 Mdot
.85403 .48197 Mdot
.43618 .54048 Mdot
.64278 .45592 Mdot
.30945 .26264 Mdot
.39037 .3889 Mdot
.50576 .68275 Mdot
.79095 .52015 Mdot
.41452 .61117 Mdot
.53197 .38168 Mdot
.48415 .61111 Mdot
.6911 .49064 Mdot
.58191 .67984 Mdot
.77807 .70813 Mdot
.66149 .50407 Mdot
.42937 .60143 Mdot
.37673 .38587 Mdot
.61148 .66537 Mdot
.34316 .32454 Mdot
.39541 .32085 Mdot
.33516 .61848 Mdot
.33953 .57241 Mdot
.37513 .56955 Mdot
.43228 .2111 Mdot
.51596 .37917 Mdot
.55659 .65421 Mdot
.65399 .48432 Mdot
.67589 .49243 Mdot
.54737 .33648 Mdot
.7375 .52237 Mdot
.50855 .4449 Mdot
.12907 .52845 Mdot
.56659 .36028 Mdot
.35125 .36046 Mdot
.75357 .56136 Mdot
.53812 .38706 Mdot
.54048 .35532 Mdot
.5541 .33413 Mdot
.61926 .53212 Mdot
.54957 .66678 Mdot
.39507 .53374 Mdot
.556 .69238 Mdot
.37944 .59069 Mdot
.64675 .45367 Mdot
.64744 .50408 Mdot
.59599 .67686 Mdot
.84359 .50894 Mdot
.46647 .79119 Mdot
.41591 .58124 Mdot
.81288 .58574 Mdot
.46817 .55564 Mdot
.26761 .45762 Mdot
.4751 .56492 Mdot
.54608 .34206 Mdot
.33218 .55358 Mdot
.36764 .53267 Mdot
.19039 .58479 Mdot
.68006 .50569 Mdot
.55668 .39259 Mdot
.47064 .58866 Mdot
.4659 .62958 Mdot
.53099 .62741 Mdot
.55286 .64285 Mdot
.39071 .3481 Mdot
.26293 .57929 Mdot
.6831 .50028 Mdot
.56109 .81551 Mdot
.40568 .60691 Mdot
.34843 .28612 Mdot
.43059 .67907 Mdot
.43765 .5487 Mdot
.79934 .52343 Mdot
.43385 .73667 Mdot
.39441 .57357 Mdot
.56109 .53224 Mdot
.67332 .51541 Mdot
.37084 .23664 Mdot
.4235 .53256 Mdot
.52444 .34962 Mdot
.57988 .68542 Mdot
.61248 .68132 Mdot
.37761 .34414 Mdot
.33682 .78391 Mdot
.70592 .50806 Mdot
.58984 .67916 Mdot
.39847 .58628 Mdot
.65842 .48008 Mdot
.56709 .37447 Mdot
.35319 .5676 Mdot
.23593 .45902 Mdot
.57376 .67131 Mdot
.38028 .53072 Mdot
.71886 .58628 Mdot
.29293 .48937 Mdot
.36808 .19654 Mdot
.65243 .48391 Mdot
.37053 .39701 Mdot
.47959 .61443 Mdot
.37352 .78088 Mdot
.44044 .52696 Mdot
.35324 .43364 Mdot
.65413 .69728 Mdot
.37684 .39862 Mdot
.42367 .58542 Mdot
.40947 .54178 Mdot
.43413 .41841 Mdot
.36411 .38777 Mdot
.44268 .59507 Mdot
.54545 .60403 Mdot
.54934 .66208 Mdot
.50397 .36649 Mdot
.56292 .67207 Mdot
.41954 .57462 Mdot
.45621 .52904 Mdot
.56928 .63492 Mdot
.81986 .61651 Mdot
.33695 .37881 Mdot
.69111 .4791 Mdot
.4533 .54104 Mdot
.45627 .56794 Mdot
.20693 .34175 Mdot
.5815 .34202 Mdot
.63153 .28333 Mdot
.40631 .27598 Mdot
.63185 .24891 Mdot
.39947 .24384 Mdot
.47593 .16046 Mdot
.2714 .33505 Mdot
.35066 .59097 Mdot
.45724 .65822 Mdot
.61037 .57576 Mdot
.65355 .51626 Mdot
.59967 .77178 Mdot
.40091 .60823 Mdot
.4043 .594 Mdot
.56239 .32046 Mdot
.76856 .4144 Mdot
.23043 .38893 Mdot
.44622 .46133 Mdot
.39711 .36999 Mdot
.55334 .6877 Mdot
.40013 .53149 Mdot
.56546 .51685 Mdot
.57668 .3691 Mdot
.34131 .289 Mdot
.43628 .58657 Mdot
.28866 .7316 Mdot
.70849 .65187 Mdot
.6688 .48063 Mdot
.53866 .38295 Mdot
.24426 .37334 Mdot
.39504 .613 Mdot
.66 .52115 Mdot
.4103 .56818 Mdot
.59382 .30533 Mdot
.34058 .60451 Mdot
.36398 .36279 Mdot
.37162 .55424 Mdot
.32173 .36949 Mdot
.32943 .18474 Mdot
.41824 .3633 Mdot
.61818 .662 Mdot
.49785 .39189 Mdot
.55922 .35041 Mdot
.55705 .63957 Mdot
.55948 .35398 Mdot
.40435 .70578 Mdot
.52233 .73256 Mdot
.39049 .36007 Mdot
.44688 .63503 Mdot
.37093 .36586 Mdot
.5743 .32928 Mdot
.39336 .60801 Mdot
.8346 .62062 Mdot
.55923 .37076 Mdot
.27693 .29087 Mdot
.66721 .50314 Mdot
.57548 .37681 Mdot
.42792 .53463 Mdot
.64024 .37281 Mdot
.5701 .37617 Mdot
.73682 .37682 Mdot
.42188 .55944 Mdot
.5771 .67512 Mdot
.39842 .53724 Mdot
.46487 .5644 Mdot
.54315 .406 Mdot
.37358 .59171 Mdot
.69995 .49313 Mdot
.54331 .63101 Mdot
.66872 .21813 Mdot
.67713 .70345 Mdot
.43424 .60622 Mdot
.40104 .58576 Mdot
.51702 .6409 Mdot
.45309 .58476 Mdot
.66057 .47147 Mdot
.3772 .87371 Mdot
.38472 .35836 Mdot
.53494 .4009 Mdot
.39925 .24258 Mdot
.46073 .58639 Mdot
.36594 .57229 Mdot
.85094 .45995 Mdot
.37043 .24641 Mdot
.70244 .49011 Mdot
.37771 .52683 Mdot
.56765 .37628 Mdot
.37532 .38357 Mdot
.66596 .46566 Mdot
.38721 .56413 Mdot
.41857 .59102 Mdot
.36409 .39411 Mdot
.31213 .62643 Mdot
.20455 .51783 Mdot
.68011 .52161 Mdot
.35173 .52369 Mdot
.4961 .40091 Mdot
.41379 .61927 Mdot
.21462 .58531 Mdot
.56039 .64195 Mdot
.64188 .48619 Mdot
.56778 .23 Mdot
.38442 .61213 Mdot
.70432 .50265 Mdot
.6832 .50146 Mdot
.38818 .52371 Mdot
.60304 .70516 Mdot
.53213 .63901 Mdot
.5435 .65555 Mdot
.29455 .77996 Mdot
.31611 .45169 Mdot
.51581 .35703 Mdot
.67343 .51578 Mdot
.51107 .37904 Mdot
.3766 .41101 Mdot
.59163 .49141 Mdot
.51583 .38499 Mdot
.53837 .6517 Mdot
.49501 .38341 Mdot
.41705 .54761 Mdot
.6809 .49829 Mdot
.52005 .37685 Mdot
.46649 .58345 Mdot
.75685 .52987 Mdot
.74988 .4699 Mdot
.39404 .39443 Mdot
.40487 .35452 Mdot
.42395 .53711 Mdot
.51495 .3235 Mdot
.41939 .59632 Mdot
.63292 .48911 Mdot
.75482 .54748 Mdot
.44965 .53879 Mdot
.55346 .34853 Mdot
.51221 .62871 Mdot
.23665 .3866 Mdot
.33901 .54938 Mdot
.42486 .57709 Mdot
.37782 .59344 Mdot
.41002 .56771 Mdot
.74306 .348 Mdot
.62473 .49951 Mdot
.68853 .7038 Mdot
.46643 .21394 Mdot
.59655 .6651 Mdot
.53257 .67473 Mdot
.21266 .44216 Mdot
.64504 .58078 Mdot
.67878 .51144 Mdot
.38217 .57717 Mdot
.66946 .63103 Mdot
.78654 .33596 Mdot
.85832 .53804 Mdot
.4245 .41801 Mdot
.58179 .35897 Mdot
.58015 .63091 Mdot
.55408 .38668 Mdot
.38483 .59722 Mdot
.47563 .61547 Mdot
.45605 .15443 Mdot
.66754 .46236 Mdot
.38924 .35747 Mdot
.37726 .58813 Mdot
.31895 .45518 Mdot
.54008 .37221 Mdot
.5588 .4006 Mdot
.44975 .58191 Mdot
.56227 .70006 Mdot
.27153 .25674 Mdot
.66058 .48128 Mdot
.77409 .5833 Mdot
.62633 .6323 Mdot
.75275 .62102 Mdot
.66281 .48618 Mdot
.43352 .37165 Mdot
.55713 .32053 Mdot
.35017 .673 Mdot
.59775 .66273 Mdot
.36469 .3541 Mdot
.41787 .63225 Mdot
.58523 .64048 Mdot
.53928 .32535 Mdot
.5801 .67777 Mdot
.36458 .56406 Mdot
.63506 .47115 Mdot
.53248 .37142 Mdot
.70719 .4712 Mdot
.58432 .70766 Mdot
.36954 .38852 Mdot
.47576 .45797 Mdot
.55135 .78196 Mdot
.42992 .7334 Mdot
.45091 .59408 Mdot
.57152 .52146 Mdot
.39872 .54406 Mdot
.52863 .65995 Mdot
.4043 .57615 Mdot
.62877 .71687 Mdot
.53288 .38102 Mdot
.43176 .5332 Mdot
.37891 .5642 Mdot
.63572 .76186 Mdot
.43943 .57822 Mdot
.34471 .58895 Mdot
.39113 .57302 Mdot
.62493 .70315 Mdot
.44595 .63695 Mdot
.55136 .67607 Mdot
.44016 .34561 Mdot
.53976 .35212 Mdot
.40764 .36756 Mdot
.35213 .3889 Mdot
.33017 .42287 Mdot
.51643 .25084 Mdot
.76806 .43163 Mdot
.56127 .66785 Mdot
.69467 .49889 Mdot
.40537 .57213 Mdot
.48539 .1799 Mdot
.57224 .42473 Mdot
.57669 .35687 Mdot
.67897 .702 Mdot
.35995 .51323 Mdot
.38967 .21434 Mdot
.36002 .54336 Mdot
.30595 .77759 Mdot
.43185 .50976 Mdot
.3408 .60263 Mdot
.52231 .39573 Mdot
.37808 .41374 Mdot
.45269 .57146 Mdot
.53591 .62583 Mdot
.35835 .3672 Mdot
.42565 .65919 Mdot
.46848 .37058 Mdot
.44793 .35258 Mdot
.59387 .7567 Mdot
.40916 .55489 Mdot
.53174 .36998 Mdot
.56539 .69017 Mdot
.21755 .40389 Mdot
.67742 .47828 Mdot
.69273 .45849 Mdot
.58496 .56631 Mdot
.82176 .58661 Mdot
.35296 .37592 Mdot
.32471 .66873 Mdot
.42936 .55056 Mdot
.51762 .28745 Mdot
.44329 .53411 Mdot
.78843 .35183 Mdot
.34826 .37247 Mdot
.53605 .6454 Mdot
.6991 .50285 Mdot
.54419 .68154 Mdot
.42186 .73705 Mdot
.59319 .36342 Mdot
.54837 .47534 Mdot
.54535 .36481 Mdot
.47943 .41851 Mdot
.56492 .65371 Mdot
.36323 .5899 Mdot
.12725 .52777 Mdot
.55654 .6439 Mdot
.6076 .65633 Mdot
.70826 .7458 Mdot
.81399 .6527 Mdot
.33327 .54409 Mdot
.56216 .63038 Mdot
.54612 .35939 Mdot
.36711 .37862 Mdot
.38522 .54067 Mdot
.41485 .55288 Mdot
.58386 .64032 Mdot
.54465 .40439 Mdot
.38625 .76411 Mdot
.53825 .33668 Mdot
.54687 .66432 Mdot
.53281 .34922 Mdot
.63506 .36615 Mdot
.53072 .38869 Mdot
.45626 .5699 Mdot
.40448 .57506 Mdot
.47508 .24086 Mdot
.58382 .67437 Mdot
.38123 .55927 Mdot
.361 .54982 Mdot
.57925 .65682 Mdot
.40256 .32925 Mdot
.38844 .75906 Mdot
.42306 .61418 Mdot
.43118 .56598 Mdot
.37602 .39801 Mdot
.59302 .52044 Mdot
.28093 .64456 Mdot
.36608 .56795 Mdot
.34366 .37421 Mdot
.53545 .6274 Mdot
.42888 .59426 Mdot
.74123 .29711 Mdot
.67187 .34579 Mdot
.37673 .6064 Mdot
.53829 .39541 Mdot
.36671 .53393 Mdot
.35297 .2057 Mdot
.44959 .57035 Mdot
.57178 .65947 Mdot
.58901 .68576 Mdot
.56864 .8136 Mdot
.57156 .64557 Mdot
.57136 .35664 Mdot
.66354 .49063 Mdot
.78957 .38299 Mdot
.56617 .37554 Mdot
.40912 .50945 Mdot
.57551 .82416 Mdot
.35277 .57833 Mdot
.46235 .57259 Mdot
.29517 .25235 Mdot
.55858 .38006 Mdot
.59642 .69173 Mdot
.44589 .44464 Mdot
.4721 .54458 Mdot
.64071 .48936 Mdot
.42069 .63377 Mdot
.44461 .61261 Mdot
.30253 .26725 Mdot
.70162 .31743 Mdot
.6364 .50782 Mdot
.36631 .61039 Mdot
.36579 .56885 Mdot
.58191 .38468 Mdot
.39851 .58188 Mdot
.36455 .37566 Mdot
.59811 .68632 Mdot
.53929 .38957 Mdot
.38718 .37049 Mdot
.40682 .61086 Mdot
.39788 .37786 Mdot
.5193 .36594 Mdot
.64442 .51394 Mdot
.38698 .60333 Mdot
.37338 .4031 Mdot
.3975 .37556 Mdot
.39429 .54608 Mdot
.57924 .68096 Mdot
.42338 .50565 Mdot
.44131 .58519 Mdot
.37418 .54645 Mdot
.59586 .65144 Mdot
.86259 .38861 Mdot
.44358 .54965 Mdot
.35611 .42303 Mdot
.60802 .66405 Mdot
.45893 .39465 Mdot
.5516 .39073 Mdot
.44763 .60952 Mdot
.6399 .50997 Mdot
.6752 .51877 Mdot
.53425 .32574 Mdot
.60963 .65523 Mdot
.41051 .26695 Mdot
.50964 .63868 Mdot
.4753 .55564 Mdot
.39093 .62119 Mdot
.48281 .82144 Mdot
.5679 .1812 Mdot
.58351 .69974 Mdot
.50313 .31123 Mdot
.46795 .47289 Mdot
.6866 .51529 Mdot
.57306 .38206 Mdot
.58472 .63236 Mdot
.60775 .67611 Mdot
.56952 .6794 Mdot
.37303 .35111 Mdot
.4803 .24128 Mdot
.59594 .70187 Mdot
.54227 .68628 Mdot
.42129 .55596 Mdot
.36702 .56858 Mdot
.2436 .39088 Mdot
.23276 .5129 Mdot
.40173 .38063 Mdot
.53263 .33037 Mdot
.25183 .7547 Mdot
.63493 .48468 Mdot
.66381 .74793 Mdot
.45762 .55385 Mdot
.10603 .58244 Mdot
.41458 .53196 Mdot
.39599 .58524 Mdot
.54414 .63036 Mdot
.38389 .4019 Mdot
.3741 .36134 Mdot
.55603 .65197 Mdot
.53 .67345 Mdot
.36448 .3744 Mdot
.79899 .56214 Mdot
.76147 .30684 Mdot
.59718 .3511 Mdot
.58552 .66126 Mdot
.55065 .77316 Mdot
.67773 .52372 Mdot
.46339 .64717 Mdot
.63331 .48017 Mdot
.53968 .36439 Mdot
.53051 .32068 Mdot
.64348 .49031 Mdot
.42101 .56077 Mdot
.51408 .36308 Mdot
.3535 .59286 Mdot
.76641 .62884 Mdot
.44652 .76579 Mdot
.42953 .24238 Mdot
.3593 .63362 Mdot
.43778 .36186 Mdot
.73683 .51595 Mdot
.42097 .60443 Mdot
.66776 .26124 Mdot
.39429 .36193 Mdot
.46753 .63902 Mdot
.64068 .48249 Mdot
.33349 .20832 Mdot
.38519 .60557 Mdot
.5735 .66215 Mdot
.68389 .50621 Mdot
.49943 .53194 Mdot
.74186 .57291 Mdot
.37843 .59192 Mdot
.1247 .57544 Mdot
.62492 .69587 Mdot
.53394 .3866 Mdot
.35961 .78257 Mdot
.58227 .70197 Mdot
.41115 .42515 Mdot
.50998 .22036 Mdot
.83862 .53578 Mdot
.58015 .69632 Mdot
.58511 .3558 Mdot
.54193 .6661 Mdot
.36706 .38713 Mdot
.58461 .62792 Mdot
.53777 .37727 Mdot
.43364 .5843 Mdot
.54872 .3398 Mdot
.39709 .35238 Mdot
.20863 .52214 Mdot
.63858 .51055 Mdot
.55402 .39344 Mdot
.65129 .50245 Mdot
.28157 .51903 Mdot
.42561 .21664 Mdot
.67686 .47538 Mdot
.30937 .70764 Mdot
.40208 .622 Mdot
.57806 .70321 Mdot
.55339 .33903 Mdot
.57029 .25187 Mdot
.47013 .45825 Mdot
.59304 .65506 Mdot
.52138 .34064 Mdot
.59114 .5645 Mdot
.32513 .7423 Mdot
.33707 .56728 Mdot
.2669 .55021 Mdot
.58461 .65767 Mdot
.58064 .33552 Mdot
.19157 .45395 Mdot
.53627 .66 Mdot
.56631 .35665 Mdot
.70095 .5031 Mdot
.6743 .48944 Mdot
.44729 .59086 Mdot
.68143 .46063 Mdot
.5176 .33838 Mdot
.74544 .50108 Mdot
.57092 .63023 Mdot
.51463 .55433 Mdot
.36336 .40284 Mdot
.54063 .34532 Mdot
.36032 .5644 Mdot
.59726 .62942 Mdot
.65061 .34259 Mdot
.41214 .78097 Mdot
.17845 .60614 Mdot
.54704 .33646 Mdot
.6037 .67909 Mdot
.57511 .6647 Mdot
.34693 .53839 Mdot
.51276 .51604 Mdot
.41741 .26385 Mdot
.39088 .46345 Mdot
.4196 .45873 Mdot
.50293 .35736 Mdot
.57742 .40853 Mdot
.46988 .59535 Mdot
.40649 .55913 Mdot
.69019 .51218 Mdot
.43312 .58059 Mdot
.54641 .63331 Mdot
.45033 .58735 Mdot
.65416 .4862 Mdot
.54887 .36903 Mdot
.3915 .60497 Mdot
.39217 .38837 Mdot
.66999 .52622 Mdot
.70653 .47865 Mdot
.54712 .3463 Mdot
.58863 .64293 Mdot
.37018 .3175 Mdot
.53583 .33515 Mdot
.40984 .55548 Mdot
.60597 .53026 Mdot
.36622 .55247 Mdot
.51155 .68186 Mdot
.53568 .66031 Mdot
.54412 .38792 Mdot
.56049 .62611 Mdot
.65763 .50705 Mdot
.47737 .21323 Mdot
.41383 .57574 Mdot
.5672 .36277 Mdot
.59614 .28867 Mdot
.4037 .66873 Mdot
.52458 .66963 Mdot
.7606 .46811 Mdot
.53043 .66964 Mdot
.54647 .3257 Mdot
.64329 .77703 Mdot
.35495 .36466 Mdot
.57707 .3583 Mdot
.63823 .2067 Mdot
.55857 .36226 Mdot
.44239 .57033 Mdot
.42352 .53818 Mdot
.53597 .38906 Mdot
.36321 .39539 Mdot
.24255 .36221 Mdot
.50028 .36998 Mdot
.59226 .69343 Mdot
.76884 .64432 Mdot
.15823 .52038 Mdot
.6148 .48035 Mdot
.69289 .50753 Mdot
.45461 .52154 Mdot
.34072 .59437 Mdot
.64547 .47133 Mdot
.70668 .47564 Mdot
.37649 .34743 Mdot
.55944 .33825 Mdot
.63089 .69861 Mdot
.72056 .50029 Mdot
.45078 .50476 Mdot
.50505 .25099 Mdot
.33533 .56046 Mdot
.63117 .632 Mdot
.44675 .5404 Mdot
.37688 .44494 Mdot
.65322 .48537 Mdot
.37916 .53388 Mdot
.35504 .53913 Mdot
.63596 .50003 Mdot
.3647 .37849 Mdot
.66125 .5591 Mdot
.53026 .35635 Mdot
.78904 .30882 Mdot
.34389 .56925 Mdot
.4439 .56797 Mdot
.65326 .51476 Mdot
.41822 .29888 Mdot
.59937 .67209 Mdot
.53714 .67245 Mdot
.51747 .38133 Mdot
.49307 .47644 Mdot
.44226 .61054 Mdot
.43044 .59816 Mdot
.52727 .36544 Mdot
.57167 .3817 Mdot
.73904 .42173 Mdot
.41755 .54183 Mdot
.67641 .50755 Mdot
.32174 .3548 Mdot
.65122 .48639 Mdot
.36405 .55696 Mdot
.44124 .56165 Mdot
.45627 .57179 Mdot
.36086 .56471 Mdot
.68837 .46695 Mdot
.3919 .53139 Mdot
.46463 .63525 Mdot
.60275 .67034 Mdot
.3731 .58129 Mdot
.41518 .45811 Mdot
.42882 .57342 Mdot
.36653 .37724 Mdot
.2952 .66317 Mdot
.38565 .60541 Mdot
.44822 .60621 Mdot
.51196 .39686 Mdot
.41763 .58577 Mdot
.63356 .48675 Mdot
.58904 .67 Mdot
.67161 .51568 Mdot
.67028 .51998 Mdot
.51609 .32927 Mdot
.37117 .34346 Mdot
.46024 .5905 Mdot
.38496 .35167 Mdot
.41087 .5115 Mdot
.38286 .6119 Mdot
.49327 .22276 Mdot
.31916 .78845 Mdot
.2028 .54761 Mdot
.41444 .57406 Mdot
.55903 .37653 Mdot
.54996 .39005 Mdot
.39119 .65975 Mdot
.33824 .56153 Mdot
.66607 .46933 Mdot
.68012 .51846 Mdot
.23901 .46348 Mdot
.33051 .25644 Mdot
.36596 .37752 Mdot
.57647 .50373 Mdot
.36864 .60917 Mdot
.36657 .54617 Mdot
.35072 .57091 Mdot
.51077 .37628 Mdot
.3991 .44418 Mdot
.576 .36243 Mdot
.71477 .65644 Mdot
.64316 .49773 Mdot
.38028 .6 Mdot
.65615 .66016 Mdot
.54815 .6451 Mdot
.58821 .67038 Mdot
.70583 .4795 Mdot
.53883 .41579 Mdot
.22542 .42635 Mdot
.86164 .55629 Mdot
.62336 .68632 Mdot
.40146 .3896 Mdot
.42316 .60658 Mdot
.55196 .36355 Mdot
.54102 .65896 Mdot
.40481 .38206 Mdot
.36454 .59444 Mdot
.48182 .24087 Mdot
.41583 .56879 Mdot
.61647 .58483 Mdot
.5732 .68613 Mdot
.78395 .34221 Mdot
.61586 .66742 Mdot
.66936 .52672 Mdot
.64637 .47931 Mdot
.43346 .54532 Mdot
.43081 .81631 Mdot
.55407 .69208 Mdot
.62782 .5355 Mdot
.35089 .36151 Mdot
.65374 .35794 Mdot
.36376 .38372 Mdot
.5341 .38475 Mdot
.35634 .37003 Mdot
.5358 .37886 Mdot
.22433 .49172 Mdot
.61381 .72012 Mdot
.38878 .36467 Mdot
.58199 .29116 Mdot
.33247 .57702 Mdot
.39815 .38689 Mdot
.47917 .58341 Mdot
.4986 .67414 Mdot
.52605 .36129 Mdot
.35106 .37563 Mdot
.36206 .58723 Mdot
.45245 .16629 Mdot
.70075 .48579 Mdot
.65949 .46967 Mdot
.47757 .56876 Mdot
.50584 .34217 Mdot
.54805 .62436 Mdot
.75533 .33921 Mdot
.67635 .53033 Mdot
.43919 .54665 Mdot
.45262 .57631 Mdot
.53406 .6768 Mdot
.65167 .71339 Mdot
.43636 .55096 Mdot
.37042 .48862 Mdot
.41985 .54114 Mdot
.70578 .48555 Mdot
.54653 .68342 Mdot
.58067 .66708 Mdot
.51846 .34474 Mdot
.56 .63423 Mdot
.35378 .65254 Mdot
.66815 .65587 Mdot
.37071 .49867 Mdot
.65906 .50297 Mdot
.69464 .66017 Mdot
.71331 .66033 Mdot
.5914 .19414 Mdot
.55072 .69595 Mdot
.43986 .53289 Mdot
.58804 .63976 Mdot
.37263 .38324 Mdot
.57567 .67369 Mdot
.57752 .63012 Mdot
.41884 .59918 Mdot
.38177 .5917 Mdot
.54733 .37832 Mdot
.49938 .50152 Mdot
.6 .65191 Mdot
.41019 .53256 Mdot
.3438 .60062 Mdot
.3488 .58156 Mdot
.60278 .43955 Mdot
.57391 .69916 Mdot
.75596 .69779 Mdot
.28664 .39199 Mdot
.59871 .65072 Mdot
.28655 .23902 Mdot
.61167 .296 Mdot
.55177 .31332 Mdot
.72636 .48607 Mdot
.41405 .53982 Mdot
.56627 .3835 Mdot
.38523 .59796 Mdot
.63051 .62976 Mdot
.4133 .59197 Mdot
.36269 .37434 Mdot
.34992 .58996 Mdot
.53392 .32278 Mdot
.54036 .33538 Mdot
.4462 .55774 Mdot
.39411 .60366 Mdot
.20973 .49595 Mdot
.56056 .70506 Mdot
.59013 .67595 Mdot
.39951 .27576 Mdot
.392 .37702 Mdot
.64164 .48741 Mdot
.39681 .57566 Mdot
.51018 .3393 Mdot
.54305 .33582 Mdot
.5736 .70032 Mdot
.52405 .34503 Mdot
.66122 .48175 Mdot
.4102 .57788 Mdot
.64724 .471 Mdot
.37241 .35033 Mdot
.5569 .69069 Mdot
.37522 .58621 Mdot
.42163 .55624 Mdot
.5889 .686 Mdot
.46627 .59575 Mdot
.37358 .39723 Mdot
.55942 .35955 Mdot
.57154 .69498 Mdot
.66633 .49026 Mdot
.53554 .38365 Mdot
.37838 .54141 Mdot
.21677 .70276 Mdot
.43994 .56969 Mdot
.40516 .53716 Mdot
.628 .19474 Mdot
.35717 .60022 Mdot
.5499 .33676 Mdot
.53578 .64898 Mdot
.36552 .63405 Mdot
.31641 .41787 Mdot
.88138 .46054 Mdot
.57591 .35594 Mdot
.42783 .60546 Mdot
.50957 .17513 Mdot
.43531 .59817 Mdot
.49232 .81252 Mdot
.58057 .30663 Mdot
.47198 .42743 Mdot
.45685 .5389 Mdot
.68442 .48591 Mdot
.5498 .37941 Mdot
.53047 .37863 Mdot
.73937 .68947 Mdot
.42313 .59898 Mdot
.59665 .55264 Mdot
.3674 .58817 Mdot
.66812 .48672 Mdot
.24907 .4324 Mdot
.54279 .33423 Mdot
.20109 .61087 Mdot
.40216 .54352 Mdot
.60644 .68765 Mdot
.49333 .38077 Mdot
.61857 .40357 Mdot
.37629 .54521 Mdot
.39504 .35747 Mdot
.71329 .51247 Mdot
.35759 .62332 Mdot
.65912 .49834 Mdot
.3717 .54894 Mdot
.33356 .51058 Mdot
.36433 .79241 Mdot
.57464 .68066 Mdot
.69812 .50503 Mdot
.60356 .50633 Mdot
.40695 .52711 Mdot
.57767 .69594 Mdot
.59719 .6609 Mdot
.38421 .34928 Mdot
.57393 .46452 Mdot
.70748 .58071 Mdot
.48769 .78564 Mdot
.75857 .66637 Mdot
.50168 .39284 Mdot
.7185 .35509 Mdot
.38281 .54747 Mdot
.36084 .28122 Mdot
.63256 .49711 Mdot
.4425 .57567 Mdot
.38857 .68306 Mdot
.55027 .65056 Mdot
.43258 .56157 Mdot
.36962 .36739 Mdot
.37519 .29382 Mdot
.34778 .29147 Mdot
.51835 .21368 Mdot
.54388 .36432 Mdot
.47673 .61565 Mdot
.31828 .53726 Mdot
.5287 .39595 Mdot
.44469 .61549 Mdot
.56295 .35394 Mdot
.80886 .57403 Mdot
.39666 .39142 Mdot
.58737 .69779 Mdot
.6266 .35913 Mdot
.45567 .60238 Mdot
.39506 .62345 Mdot
.39711 .34524 Mdot
.40243 .55754 Mdot
.32514 .77321 Mdot
.61948 .37193 Mdot
.51854 .37695 Mdot
.57077 .6797 Mdot
.45354 .59822 Mdot
.58462 .46846 Mdot
.43985 .58873 Mdot
.50636 .74218 Mdot
.44951 .60399 Mdot
.72613 .57419 Mdot
.57995 .68477 Mdot
.65561 .49914 Mdot
.4074 .52525 Mdot
.40599 .59128 Mdot
.30905 .35732 Mdot
.43806 .51369 Mdot
.39177 .52938 Mdot
.51879 .63392 Mdot
.53944 .65882 Mdot
.55112 .67417 Mdot
.56585 .32692 Mdot
.31549 .26189 Mdot
.66874 .50997 Mdot
.40734 .64276 Mdot
.71711 .49755 Mdot
.3949 .78428 Mdot
.40196 .38796 Mdot
.5308 .19628 Mdot
.38381 .56861 Mdot
.55454 .66603 Mdot
.67562 .28609 Mdot
.5272 .63178 Mdot
.5624 .50233 Mdot
.68284 .49995 Mdot
.55594 .64765 Mdot
.39873 .58899 Mdot
.46804 .4654 Mdot
.45668 .18669 Mdot
.65966 .51272 Mdot
.40123 .51033 Mdot
.58113 .3428 Mdot
.43261 .23307 Mdot
.20214 .67387 Mdot
.702 .48636 Mdot
.63824 .45944 Mdot
.42364 .60035 Mdot
.5457 .64505 Mdot
.67773 .48352 Mdot
.6901 .47666 Mdot
.52247 .34686 Mdot
.38036 .58822 Mdot
.37932 .58331 Mdot
.55223 .32511 Mdot
.66679 .51666 Mdot
.46747 .54873 Mdot
.33981 .60384 Mdot
.42873 .15354 Mdot
.55433 .5572 Mdot
.80446 .31958 Mdot
.35146 .64888 Mdot
.36405 .68675 Mdot
.76943 .34722 Mdot
.60929 .67177 Mdot
.39073 .6105 Mdot
.3791 .62733 Mdot
.51852 .33715 Mdot
.42355 .58042 Mdot
.56876 .31081 Mdot
.68664 .50856 Mdot
.32 .22419 Mdot
.69715 .6312 Mdot
.82162 .54544 Mdot
.42415 .58239 Mdot
.62332 .73023 Mdot
.38013 .37541 Mdot
.62378 .50487 Mdot
.5486 .67859 Mdot
.35911 .57394 Mdot
.20887 .4991 Mdot
.5767 .36073 Mdot
.57822 .64187 Mdot
.21805 .40712 Mdot
.43754 .37004 Mdot
.36473 .55764 Mdot
.57741 .34134 Mdot
.68588 .28058 Mdot
.47628 .52454 Mdot
.64608 .5271 Mdot
.36273 .37754 Mdot
.54993 .3825 Mdot
.67666 .5201 Mdot
.62932 .67117 Mdot
.56355 .64581 Mdot
.55381 .6217 Mdot
.22591 .58836 Mdot
.53654 .39984 Mdot
.38192 .37169 Mdot
.34962 .25159 Mdot
.31851 .2898 Mdot
.36337 .37183 Mdot
.53379 .31995 Mdot
.54006 .65913 Mdot
.55487 .65639 Mdot
.58924 .66941 Mdot
.19461 .56873 Mdot
.61254 .6715 Mdot
.68934 .73114 Mdot
.35303 .58317 Mdot
.35932 .49763 Mdot
.42967 .60316 Mdot
.65719 .46883 Mdot
.57959 .69037 Mdot
.47336 .45074 Mdot
.37915 .52188 Mdot
.45645 .20177 Mdot
.446 .58153 Mdot
.62503 .48338 Mdot
.42703 .5539 Mdot
.61232 .76238 Mdot
.59629 .64605 Mdot
.41809 .57625 Mdot
.62767 .49723 Mdot
.38886 .38426 Mdot
.51706 .65376 Mdot
.37782 .59304 Mdot
.76977 .45513 Mdot
.35372 .59601 Mdot
.81586 .52534 Mdot
.53064 .5644 Mdot
.40114 .38989 Mdot
.5905 .59829 Mdot
.5782 .3791 Mdot
.34732 .50493 Mdot
.48275 .56479 Mdot
.65285 .50745 Mdot
.63538 .33981 Mdot
.54122 .35332 Mdot
.4184 .42478 Mdot
.43163 .63452 Mdot
.40259 .35631 Mdot
.54272 .69321 Mdot
.64726 .46866 Mdot
.43188 .62149 Mdot
.3473 .54212 Mdot
.73298 .66984 Mdot
.46036 .6302 Mdot
.45215 .58503 Mdot
.4091 .35692 Mdot
.68639 .72353 Mdot
.42645 .56945 Mdot
.56731 .4996 Mdot
.59583 .63548 Mdot
.46295 .5394 Mdot
.67565 .74483 Mdot
.4235 .53724 Mdot
.56696 .63971 Mdot
.53008 .68398 Mdot
.66011 .57663 Mdot
.36048 .3495 Mdot
.44651 .60961 Mdot
.57321 .81223 Mdot
.40472 .54724 Mdot
.67282 .50632 Mdot
.34142 .58274 Mdot
.53879 .37449 Mdot
.19555 .53498 Mdot
.51458 .3508 Mdot
.43261 .61272 Mdot
.58948 .66628 Mdot
.64471 .50741 Mdot
.22039 .61688 Mdot
.45563 .25491 Mdot
.67204 .73545 Mdot
.84821 .49609 Mdot
.35505 .38282 Mdot
.36058 .3441 Mdot
.64462 .46878 Mdot
.419 .57484 Mdot
.67347 .7683 Mdot
.43534 .5106 Mdot
.43034 .56411 Mdot
.41219 .59301 Mdot
.4054 .22749 Mdot
.68406 .5144 Mdot
.52794 .34902 Mdot
.43848 .55519 Mdot
.39159 .5307 Mdot
.60864 .67114 Mdot
.39464 .37958 Mdot
.55162 .3905 Mdot
.38734 .35833 Mdot
.55273 .37315 Mdot
.30109 .23081 Mdot
.37301 .53084 Mdot
.38581 .38424 Mdot
.71979 .5108 Mdot
.58807 .64384 Mdot
.66599 .64722 Mdot
.5317 .38209 Mdot
.5281 .33054 Mdot
.44765 .56728 Mdot
.56416 .63888 Mdot
.5513 .62772 Mdot
.3731 .3852 Mdot
.66912 .47604 Mdot
.3872 .60585 Mdot
.38371 .61363 Mdot
.5775 .72927 Mdot
.50642 .34562 Mdot
.61303 .58905 Mdot
.75236 .38418 Mdot
.4165 .57299 Mdot
.56506 .62977 Mdot
.40345 .60158 Mdot
.7798 .3878 Mdot
.551 .63987 Mdot
.42295 .53534 Mdot
.23666 .34105 Mdot
.54084 .4169 Mdot
.675 .59087 Mdot
.45378 .56462 Mdot
.82469 .41641 Mdot
.37864 .55722 Mdot
.36735 .16874 Mdot
.53375 .27264 Mdot
.41255 .61991 Mdot
.38726 .53788 Mdot
.4194 .76727 Mdot
.41221 .61288 Mdot
.5448 .3249 Mdot
.26769 .34763 Mdot
.53759 .6243 Mdot
.76219 .49936 Mdot
.30531 .66571 Mdot
.34876 .37335 Mdot
.51821 .38225 Mdot
.59157 .39213 Mdot
.36781 .36154 Mdot
.58253 .66028 Mdot
.40976 .56766 Mdot
.51499 .47517 Mdot
.50584 .36949 Mdot
.35617 .644 Mdot
.67406 .50421 Mdot
.69435 .38116 Mdot
.59877 .40148 Mdot
.65855 .49223 Mdot
.37211 .57696 Mdot
.40628 .76573 Mdot
.24848 .58957 Mdot
.74824 .28675 Mdot
.67448 .52132 Mdot
.65582 .51234 Mdot
.18968 .54535 Mdot
.36994 .40742 Mdot
.75588 .64727 Mdot
.73553 .57169 Mdot
.63971 .49335 Mdot
.49648 .54213 Mdot
.57054 .34559 Mdot
.73244 .52965 Mdot
.46202 .64092 Mdot
.36763 .60419 Mdot
.40105 .58962 Mdot
.6612 .47609 Mdot
.40647 .6675 Mdot
.34409 .7729 Mdot
.64987 .50069 Mdot
.49803 .61946 Mdot
.53919 .44768 Mdot
.60093 .27835 Mdot
.54273 .32876 Mdot
.36513 .34721 Mdot
.339 .35349 Mdot
.60493 .68625 Mdot
.36813 .34512 Mdot
.37216 .28993 Mdot
.39765 .56258 Mdot
.64844 .4918 Mdot
.65071 .3471 Mdot
.67113 .49217 Mdot
.37091 .36072 Mdot
.40963 .37767 Mdot
.60256 .67056 Mdot
.58503 .67617 Mdot
.36844 .69882 Mdot
.2606 .46098 Mdot
.44313 .58944 Mdot
.57794 .23642 Mdot
.56497 .62785 Mdot
.34627 .63879 Mdot
.37534 .34293 Mdot
.39172 .38061 Mdot
.31724 .38028 Mdot
.38681 .57456 Mdot
.53264 .81264 Mdot
.39097 .57578 Mdot
.25128 .43868 Mdot
.45336 .54885 Mdot
.52306 .34585 Mdot
.38134 .57489 Mdot
.31525 .32746 Mdot
.45218 .61502 Mdot
.33864 .58846 Mdot
.50704 .3614 Mdot
.3636 .62794 Mdot
.53774 .3725 Mdot
.43867 .60673 Mdot
.35103 .39297 Mdot
.50994 .35988 Mdot
.31752 .44037 Mdot
.32712 .39301 Mdot
.5413 .31933 Mdot
.39662 .35349 Mdot
.35005 .38412 Mdot
.33785 .45707 Mdot
.54811 .67835 Mdot
.49674 .63063 Mdot
.42206 .57649 Mdot
.56747 .39328 Mdot
.68835 .51174 Mdot
.40094 .53213 Mdot
.3534 .60982 Mdot
.44626 .54633 Mdot
.60437 .68828 Mdot
.42212 .25925 Mdot
.37954 .38634 Mdot
.56463 .32943 Mdot
.38136 .31862 Mdot
.50909 .33107 Mdot
.33708 .57238 Mdot
.39812 .63035 Mdot
.34035 .67707 Mdot
.65349 .30298 Mdot
.18135 .55187 Mdot
.56547 .64449 Mdot
.54098 .395 Mdot
.3569 .39928 Mdot
.32631 .57567 Mdot
.54953 .66355 Mdot
.53772 .37662 Mdot
.41506 .56919 Mdot
.39442 .5108 Mdot
.68896 .68205 Mdot
.29727 .61517 Mdot
.34661 .42733 Mdot
.53465 .32519 Mdot
.58228 .36809 Mdot
.33521 .28731 Mdot
.41925 .39807 Mdot
.47176 .45675 Mdot
.43057 .59122 Mdot
.39299 .35637 Mdot
.54108 .65843 Mdot
.2365 .59338 Mdot
.6568 .47385 Mdot
.50563 .50857 Mdot
.42228 .58183 Mdot
.45905 .40722 Mdot
.59138 .6664 Mdot
.36856 .37058 Mdot
.65843 .47651 Mdot
.38194 .33702 Mdot
.52041 .38993 Mdot
.83407 .57971 Mdot
.40443 .5507 Mdot
.44924 .57676 Mdot
.65215 .5223 Mdot
.54605 .65451 Mdot
.38967 .34159 Mdot
.77257 .62421 Mdot
.52151 .37168 Mdot
.65562 .77979 Mdot
.55487 .63251 Mdot
.57738 .75659 Mdot
.56524 .33271 Mdot
.70642 .48086 Mdot
.32298 .45885 Mdot
.65714 .48548 Mdot
.44175 .60822 Mdot
.56684 .66746 Mdot
.6981 .49851 Mdot
.50528 .51702 Mdot
.49301 .17458 Mdot
.56151 .76832 Mdot
.39869 .56835 Mdot
.40504 .18168 Mdot
.79812 .50128 Mdot
.58227 .7126 Mdot
.642 .51313 Mdot
.44445 .58008 Mdot
.41946 .62159 Mdot
.40788 .54724 Mdot
.69192 .49768 Mdot
.54331 .23934 Mdot
.52504 .36446 Mdot
.42653 .602 Mdot
.377 .34782 Mdot
.53748 .36439 Mdot
.62565 .36723 Mdot
.53934 .33105 Mdot
.57005 .70694 Mdot
.34132 .58559 Mdot
.61316 .5034 Mdot
.30033 .20656 Mdot
.66765 .51497 Mdot
.52731 .31984 Mdot
.35858 .54956 Mdot
.65312 .33076 Mdot
.55036 .67137 Mdot
.51954 .36849 Mdot
.44408 .56907 Mdot
.62582 .34905 Mdot
.20643 .53316 Mdot
.54073 .3319 Mdot
.54594 .66094 Mdot
.71785 .272 Mdot
.42971 .58057 Mdot
.38516 .55326 Mdot
.55927 .65133 Mdot
.32647 .72097 Mdot
.19734 .44343 Mdot
.39773 .60309 Mdot
.65451 .49769 Mdot
.76952 .7092 Mdot
.33645 .58938 Mdot
.27809 .38734 Mdot
.54777 .38028 Mdot
.68648 .55165 Mdot
.59914 .57362 Mdot
.32607 .57391 Mdot
.7655 .6281 Mdot
.66361 .44972 Mdot
.39111 .20403 Mdot
.56472 .30821 Mdot
.46511 .33431 Mdot
.3612 .20326 Mdot
.62795 .48523 Mdot
.59479 .72619 Mdot
.77912 .5765 Mdot
.23199 .67305 Mdot
.72155 .28544 Mdot
.43799 .32032 Mdot
.20775 .49484 Mdot
.5133 .46074 Mdot
.55802 .3701 Mdot
.36846 .32708 Mdot
.38261 .59768 Mdot
.7983 .49667 Mdot
.55334 .80557 Mdot
.44757 .82684 Mdot
.4103 .17854 Mdot
.48305 .80673 Mdot
.48978 .18112 Mdot
.60368 .19427 Mdot
.34508 .66396 Mdot
.66171 .29864 Mdot
.65333 .78557 Mdot
.26143 .32038 Mdot
.77395 .65986 Mdot
.3775 .49566 Mdot
.56568 .51663 Mdot
.83162 .50582 Mdot
.6038 .75108 Mdot
.34106 .76148 Mdot
.51695 .3506 Mdot
.53337 .65818 Mdot
.77653 .56763 Mdot
.52768 .66649 Mdot
.63205 .57453 Mdot
.72303 .27 Mdot
.51179 .17017 Mdot
.62279 .76194 Mdot
.80375 .37079 Mdot
.40641 .68673 Mdot
.49518 .87136 Mdot
.50253 .36915 Mdot
.58892 .70122 Mdot
.38597 .42405 Mdot
.33022 .28444 Mdot
.73393 .63699 Mdot
.79 .55011 Mdot
.47422 .22584 Mdot
.27797 .4923 Mdot
.57549 .66239 Mdot
.57976 .58857 Mdot
.65303 .54841 Mdot
.70043 .63621 Mdot
.26024 .35445 Mdot
.64411 .22445 Mdot
.52159 .48743 Mdot
.76497 .48404 Mdot
.7084 .37129 Mdot
.19959 .664 Mdot
.2962 .3899 Mdot
.32253 .61388 Mdot
.6211 .5699 Mdot
.77501 .35847 Mdot
.25751 .69002 Mdot
.24948 .47991 Mdot
.32683 .28614 Mdot
.26274 .29083 Mdot
.80428 .438 Mdot
.17124 .40419 Mdot
.53238 .61946 Mdot
.45306 .58026 Mdot
.33777 .71372 Mdot
.58534 .8064 Mdot
.40653 .38773 Mdot
.53596 .22244 Mdot
.35249 .36282 Mdot
.61473 .68981 Mdot
.19907 .50458 Mdot
.67659 .73992 Mdot
.58706 .8113 Mdot
.34008 .35922 Mdot
.35388 .63026 Mdot
.86672 .62031 Mdot
.42404 .20043 Mdot
.67428 .6135 Mdot
.41222 .15713 Mdot
.45342 .42504 Mdot
.50558 .54361 Mdot
.69641 .4999 Mdot
.35905 .19692 Mdot
.55903 .66019 Mdot
.18418 .35747 Mdot
.35622 .17927 Mdot
.28364 .64073 Mdot
.79687 .25778 Mdot
.3541 .26635 Mdot
.46738 .42403 Mdot
.6958 .44904 Mdot
.29899 .42682 Mdot
.3064 .74045 Mdot
.29757 .55093 Mdot
.66623 .33902 Mdot
.85119 .47255 Mdot
.38562 .19766 Mdot
.61476 .79551 Mdot
.81746 .60587 Mdot
.2472 .69465 Mdot
.58646 .48019 Mdot
.44484 .65131 Mdot
.60458 .38194 Mdot
.62948 .2299 Mdot
.27714 .25834 Mdot
.2886 .3859 Mdot
.88591 .47295 Mdot
.42098 .37373 Mdot
.49985 .26434 Mdot
.71958 .25443 Mdot
.28869 .48948 Mdot
.56422 .57602 Mdot
.28129 .33173 Mdot
.33464 .62033 Mdot
.36359 .30868 Mdot
.56852 .22173 Mdot
.64338 .60267 Mdot
.27398 .31733 Mdot
.72176 .30394 Mdot
.73039 .67111 Mdot
.45914 .76606 Mdot
.31209 .28609 Mdot
.52306 .63587 Mdot
.26532 .48784 Mdot
.56083 .5689 Mdot
.4991 .16612 Mdot
.65123 .45648 Mdot
.54332 .15784 Mdot
.2001 .44515 Mdot
.41619 .51875 Mdot
.47524 .5442 Mdot
.53554 .6094 Mdot
.26911 .46351 Mdot
.34715 .61941 Mdot
.7074 .67221 Mdot
.56419 .17654 Mdot
.42643 .67852 Mdot
.65438 .55708 Mdot
.6309 .33488 Mdot
.73464 .26626 Mdot
.36466 .71739 Mdot
.41859 .40297 Mdot
.24251 .40738 Mdot
.22935 .69366 Mdot
.53707 .35132 Mdot
.62544 .78583 Mdot
.64601 .52773 Mdot
.21513 .55627 Mdot
.48888 .78843 Mdot
.28395 .67075 Mdot
.56554 .17668 Mdot
.43933 .34232 Mdot
.20029 .47555 Mdot
.2861 .5221 Mdot
.71439 .74416 Mdot
.6066 .27989 Mdot
.41834 .63359 Mdot
.78121 .50585 Mdot
.3628 .39569 Mdot
.40854 .72933 Mdot
.76274 .70007 Mdot
.44108 .2919 Mdot
.47179 .61049 Mdot
.26604 .62611 Mdot
.50303 .41073 Mdot
.47219 .46909 Mdot
.14825 .53371 Mdot
.33363 .56912 Mdot
.34125 .25662 Mdot
.80824 .45677 Mdot
.28356 .42637 Mdot
.77006 .3227 Mdot
.76023 .36073 Mdot
.19155 .36517 Mdot
.39495 .17103 Mdot
.44259 .25805 Mdot
.3527 .21358 Mdot
.46892 .15639 Mdot
.18594 .38678 Mdot
.48629 .56811 Mdot
.65791 .52538 Mdot
.18054 .67056 Mdot
.54993 .32849 Mdot
.38128 .23068 Mdot
.75761 .6677 Mdot
.6074 .40589 Mdot
.63335 .69812 Mdot
.30725 .56774 Mdot
.52083 .46769 Mdot
.5893 .71239 Mdot
.35844 .62676 Mdot
.16152 .50687 Mdot
.22107 .33382 Mdot
.16788 .44998 Mdot
.8184 .43693 Mdot
.33316 .2226 Mdot
.49069 .4299 Mdot
.63428 .75098 Mdot
.39499 .65908 Mdot
.35812 .5889 Mdot
.40324 .43245 Mdot
.35667 .26449 Mdot
.26352 .62989 Mdot
.73775 .61331 Mdot
.55328 .70153 Mdot
.55136 .22226 Mdot
.55398 .90379 Mdot
.40111 .69951 Mdot
.6959 .73685 Mdot
.34072 .29023 Mdot
.26541 .44973 Mdot
.61727 .23229 Mdot
.28334 .65524 Mdot
.62085 .19574 Mdot
.604 .71055 Mdot
.77245 .65574 Mdot
.45379 .31212 Mdot
.43468 .47519 Mdot
.42827 .25413 Mdot
.53042 .18007 Mdot
.66106 .42855 Mdot
.2446 .6325 Mdot
.75468 .56178 Mdot
.30245 .70771 Mdot
.56163 .29217 Mdot
.70478 .3863 Mdot
.74939 .71011 Mdot
.722 .34117 Mdot
.26232 .41832 Mdot
.54873 .4537 Mdot
.60811 .61599 Mdot
.66879 .44938 Mdot
.26705 .41592 Mdot
.40591 .45815 Mdot
.34059 .23415 Mdot
.27801 .19844 Mdot
.17777 .58199 Mdot
.78972 .31525 Mdot
.59484 .23494 Mdot
.46678 .61209 Mdot
.66538 .20948 Mdot
.15915 .44325 Mdot
.33756 .17824 Mdot
.70045 .40944 Mdot
.55951 .30363 Mdot
.71238 .48637 Mdot
.17156 .49801 Mdot
.53088 .24305 Mdot
.65925 .21721 Mdot
.29199 .32453 Mdot
.71654 .48603 Mdot
.33176 .79872 Mdot
.26111 .30097 Mdot
.51612 .78548 Mdot
.29885 .61771 Mdot
.4679 .56397 Mdot
.59741 .77258 Mdot
.52991 .67076 Mdot
.7225 .36337 Mdot
.2577 .47458 Mdot
.54148 .3421 Mdot
.38863 .4318 Mdot
.7908 .53587 Mdot
.35046 .59053 Mdot
.60026 .50266 Mdot
.54818 .69222 Mdot
.65766 .30389 Mdot
.68007 .65669 Mdot
.26926 .25806 Mdot
.3947 .24843 Mdot
.44737 .53213 Mdot
.28336 .41965 Mdot
.41886 .25527 Mdot
.19142 .45281 Mdot
.65101 .46386 Mdot
.43466 .17181 Mdot
.54861 .51653 Mdot
.26399 .48611 Mdot
.57765 .7868 Mdot
.50156 .67293 Mdot
.38135 .62163 Mdot
.72925 .33308 Mdot
.49422 .72887 Mdot
.48871 .49011 Mdot
.43973 .64775 Mdot
.46828 .65062 Mdot
.68047 .21459 Mdot
.37526 .29651 Mdot
.69631 .37209 Mdot
.46342 .16754 Mdot
.68496 .49247 Mdot
.58174 .63614 Mdot
.33802 .34445 Mdot
.78712 .60521 Mdot
.51744 .72522 Mdot
.20622 .53468 Mdot
.60439 .40404 Mdot
.45444 .28352 Mdot
.47233 .17207 Mdot
.4278 .17862 Mdot
.51088 .83445 Mdot
.5293 .68046 Mdot
.35869 .6652 Mdot
.78046 .62808 Mdot
.53241 .64825 Mdot
.70802 .69024 Mdot
.69785 .69011 Mdot
.29844 .24561 Mdot
.60882 .52346 Mdot
.8458 .4572 Mdot
.34171 .43028 Mdot
.52418 .22726 Mdot
.21762 .61534 Mdot
.73907 .71714 Mdot
.50318 .18409 Mdot
.48973 .5417 Mdot
.43953 .78247 Mdot
.36399 .50023 Mdot
.64416 .65991 Mdot
.24747 .73417 Mdot
.32882 .35707 Mdot
.58189 .7587 Mdot
.72468 .30356 Mdot
.4087 .56036 Mdot
.1773 .59629 Mdot
.79063 .57868 Mdot
.18785 .54941 Mdot
.72246 .49627 Mdot
.36673 .5715 Mdot
.44405 .61997 Mdot
.26633 .38285 Mdot
.6624 .57808 Mdot
.32565 .25004 Mdot
.78732 .67889 Mdot
.68661 .27448 Mdot
.55193 .80524 Mdot
.35532 .25226 Mdot
.65982 .22612 Mdot
.79766 .48822 Mdot
.56806 .4736 Mdot
.36529 .26159 Mdot
.3014 .47759 Mdot
.80426 .37815 Mdot
.42007 .45374 Mdot
.73727 .4947 Mdot
.73733 .64541 Mdot
.75676 .38429 Mdot
.23063 .60386 Mdot
.37088 .55625 Mdot
.21827 .40676 Mdot
.62123 .20536 Mdot
.52684 .82578 Mdot
.2941 .743 Mdot
.1708 .56816 Mdot
.50404 .75538 Mdot
.75635 .37233 Mdot
.79314 .50223 Mdot
.71006 .76467 Mdot
.55186 .52344 Mdot
.48131 .19811 Mdot
.29372 .49452 Mdot
.46939 .17005 Mdot
.64335 .51917 Mdot
.74237 .58059 Mdot
.62772 .32846 Mdot
.34304 .22519 Mdot
.38108 .73652 Mdot
.55731 .18546 Mdot
.46889 .43551 Mdot
.19794 .34978 Mdot
.70188 .32091 Mdot
.51052 .45266 Mdot
.53167 .39243 Mdot
.42913 .33319 Mdot
.55458 .2099 Mdot
.6335 .2758 Mdot
.72824 .72266 Mdot
.57525 .32483 Mdot
.35127 .33291 Mdot
.52491 .79482 Mdot
.26607 .53549 Mdot
.73877 .33966 Mdot
.28352 .42011 Mdot
.54073 .17277 Mdot
.27435 .34927 Mdot
.21666 .41619 Mdot
.38054 .24334 Mdot
.85592 .53005 Mdot
.67272 .6084 Mdot
.35169 .2994 Mdot
.79248 .56385 Mdot
.51832 .26348 Mdot
.50339 .55297 Mdot
.06966 .45518 Mdot
.83421 .56277 Mdot
.6807 .30775 Mdot
.27766 .25828 Mdot
.78025 .37551 Mdot
.65859 .30799 Mdot
.29852 .72415 Mdot
.5563 .55618 Mdot
.21952 .47268 Mdot
.41169 .59229 Mdot
.15542 .49374 Mdot
.26027 .51604 Mdot
.25312 .28137 Mdot
.68033 .22289 Mdot
.58594 .77433 Mdot
.34642 .59321 Mdot
.57115 .33345 Mdot
.62111 .5613 Mdot
.24918 .54529 Mdot
.37245 .75205 Mdot
.5471 .58288 Mdot
.61625 .3222 Mdot
.53083 .39746 Mdot
.40377 .26555 Mdot
.623 .68301 Mdot
.52495 .2376 Mdot
.75092 .37915 Mdot
.51992 .40868 Mdot
.52323 .4975 Mdot
.26769 .42736 Mdot
.59757 .57565 Mdot
.52068 .78263 Mdot
.2771 .64899 Mdot
.60556 .46602 Mdot
.53596 .32932 Mdot
.49531 .78066 Mdot
.83459 .51583 Mdot
.69249 .28553 Mdot
.26271 .28717 Mdot
.4042 .3255 Mdot
.40781 .78167 Mdot
.2656 .4078 Mdot
.31844 .7542 Mdot
.40005 .79648 Mdot
.62314 .28748 Mdot
.63268 .66277 Mdot
.33624 .75114 Mdot
.7759 .52455 Mdot
.32218 .2212 Mdot
.77347 .65922 Mdot
.77953 .63561 Mdot
.59077 .30372 Mdot
.56216 .73812 Mdot
.56073 .78871 Mdot
.32443 .4386 Mdot
.47395 .46311 Mdot
.45973 .8675 Mdot
.46327 .64235 Mdot
.33463 .83598 Mdot
.70516 .48665 Mdot
.25698 .71313 Mdot
.30639 .47991 Mdot
.55428 .45098 Mdot
.44305 .43348 Mdot
.73428 .3476 Mdot
.72695 .57669 Mdot
.81658 .46556 Mdot
.4098 .81015 Mdot
.50289 .34793 Mdot
.79603 .67167 Mdot
.85971 .52888 Mdot
.4459 .77386 Mdot
.34315 .56328 Mdot
.84257 .54558 Mdot
.54746 .30125 Mdot
.26391 .63293 Mdot
.77036 .31944 Mdot
.63684 .26602 Mdot
.48193 .54535 Mdot
.26487 .45734 Mdot
.48373 .19641 Mdot
.42916 .16559 Mdot
.33118 .78852 Mdot
.57085 .22329 Mdot
.64867 .52167 Mdot
.49337 .43954 Mdot
.56861 .19683 Mdot
.50199 .53053 Mdot
.73125 .53409 Mdot
.54833 .57366 Mdot
.42488 .87916 Mdot
.38922 .22286 Mdot
.32898 .24885 Mdot
.53054 .56656 Mdot
.61172 .65909 Mdot
.6541 .57385 Mdot
.56697 .57603 Mdot
.65038 .27461 Mdot
.82076 .52553 Mdot
.56461 .57233 Mdot
.62634 .82238 Mdot
.49462 .67159 Mdot
.48167 .40058 Mdot
.54845 .79825 Mdot
.41959 .6758 Mdot
.72375 .49435 Mdot
.23361 .39588 Mdot
.71023 .28315 Mdot
.67731 .52806 Mdot
.73481 .33242 Mdot
.76415 .48081 Mdot
.58871 .73699 Mdot
.52804 .7374 Mdot
.65901 .26178 Mdot
.3934 .75564 Mdot
.63925 .71744 Mdot
.23505 .58511 Mdot
.52391 .3186 Mdot
.7091 .27532 Mdot
.52378 .38089 Mdot
.33442 .62461 Mdot
.50643 .51258 Mdot
.29708 .56103 Mdot
.17845 .53992 Mdot
.35523 .38545 Mdot
.55005 .68791 Mdot
.27624 .75152 Mdot
.54146 .63771 Mdot
.16256 .48947 Mdot
.28462 .66796 Mdot
.58046 .78675 Mdot
.44239 .26359 Mdot
.42155 .29199 Mdot
.54497 .85639 Mdot
.60389 .49131 Mdot
.6085 .37848 Mdot
.66135 .68015 Mdot
.58064 .70117 Mdot
.39946 .24354 Mdot
.50777 .35307 Mdot
.55555 .54329 Mdot
.6585 .42606 Mdot
.52986 .69398 Mdot
.62889 .7118 Mdot
.53778 .52153 Mdot
.23096 .4598 Mdot
.31537 .23927 Mdot
.56562 .36194 Mdot
.35359 .83624 Mdot
.35753 .60813 Mdot
.45084 .75971 Mdot
.61902 .19256 Mdot
.34238 .80478 Mdot
.59627 .39274 Mdot
.86389 .52689 Mdot
.44529 .53462 Mdot
.62925 .24036 Mdot
.56734 .65947 Mdot
.77541 .6442 Mdot
.35343 .3734 Mdot
.28831 .42692 Mdot
.71227 .49248 Mdot
.24279 .6324 Mdot
.55268 .42631 Mdot
.55267 .6226 Mdot
.60568 .25009 Mdot
.367 .66991 Mdot
.73786 .55406 Mdot
.40742 .28054 Mdot
.45345 .77765 Mdot
.52893 .73261 Mdot
.61738 .71811 Mdot
.34136 .24035 Mdot
.78385 .63986 Mdot
.28501 .23365 Mdot
.51316 .61865 Mdot
.44166 .3731 Mdot
.72368 .66606 Mdot
.70729 .30451 Mdot
.64059 .63718 Mdot
.59027 .18044 Mdot
.25359 .48878 Mdot
.55831 .7192 Mdot
.25463 .43599 Mdot
.37845 .50749 Mdot
.54487 .48073 Mdot
.72503 .3808 Mdot
.44235 .82788 Mdot
.61762 .58573 Mdot
.26909 .70786 Mdot
.63699 .65396 Mdot
.32167 .2651 Mdot
.62535 .649 Mdot
.55984 .40761 Mdot
.57699 .74672 Mdot
.61336 .4779 Mdot
.33668 .21149 Mdot
.59952 .18354 Mdot
.62106 .47867 Mdot
.44525 .23307 Mdot
.77014 .3397 Mdot
.35544 .5242 Mdot
.471 .41077 Mdot
.45122 .59011 Mdot
.38091 .66148 Mdot
.35973 .82096 Mdot
.67259 .28408 Mdot
.47384 .62015 Mdot
.38508 .20373 Mdot
.37484 .19523 Mdot
.22463 .3166 Mdot
.67847 .76798 Mdot
.60266 .68069 Mdot
.18314 .40791 Mdot
.54744 .58601 Mdot
.45367 .15608 Mdot
.62456 .28292 Mdot
.66315 .19778 Mdot
.43293 .77793 Mdot
.74615 .33238 Mdot
.31498 .73321 Mdot
.69943 .57278 Mdot
.79645 .43371 Mdot
.54057 .43958 Mdot
.67951 .36598 Mdot
.78866 .3994 Mdot
.73605 .76393 Mdot
.32278 .56338 Mdot
.7685 .4688 Mdot
.77133 .55527 Mdot
.70024 .26809 Mdot
.53119 .27851 Mdot
.34166 .58148 Mdot
.64487 .34725 Mdot
.20473 .58066 Mdot
.2755 .41211 Mdot
.35593 .32845 Mdot
.5338 .27795 Mdot
.2249 .53381 Mdot
.24521 .44752 Mdot
.77593 .65824 Mdot
.44891 .78028 Mdot
.57826 .54544 Mdot
.40902 .52706 Mdot
.63015 .69403 Mdot
.34904 .35614 Mdot
.5784 .43519 Mdot
.44189 .60179 Mdot
.56527 .39741 Mdot
.72907 .56094 Mdot
.16941 .5437 Mdot
.64836 .59906 Mdot
.80125 .55289 Mdot
.60739 .63607 Mdot
.75639 .49424 Mdot
.65437 .65098 Mdot
.20464 .61854 Mdot
.48556 .29812 Mdot
.28883 .38585 Mdot
.43264 .1936 Mdot
.27698 .31542 Mdot
.60285 .73749 Mdot
.22915 .34706 Mdot
.63339 .50076 Mdot
.50117 .60838 Mdot
.76322 .57972 Mdot
.38979 .2681 Mdot
.45128 .6431 Mdot
.74412 .33134 Mdot
.60455 .38972 Mdot
.32381 .29946 Mdot
.80928 .44502 Mdot
.41098 .67092 Mdot
.49437 .79849 Mdot
.41642 .182 Mdot
.57547 .3554 Mdot
.80331 .60697 Mdot
.75046 .51616 Mdot
.46603 .32586 Mdot
.30296 .26697 Mdot
.29015 .24261 Mdot
.46499 .44378 Mdot
.29476 .46909 Mdot
.39234 .54582 Mdot
.75523 .69824 Mdot
.69252 .2979 Mdot
.30858 .54809 Mdot
.68673 .40251 Mdot
.56705 .63242 Mdot
.72905 .40653 Mdot
.56922 .52496 Mdot
.22219 .49791 Mdot
.53023 .67562 Mdot
.55181 .80908 Mdot
.34884 .38898 Mdot
.44786 .40408 Mdot
.35936 .62973 Mdot
.29913 .45011 Mdot
.60841 .80589 Mdot
.42553 .64288 Mdot
.58943 .22331 Mdot
.47741 .78427 Mdot
.77261 .6278 Mdot
.64712 .25797 Mdot
.62314 .29175 Mdot
.72155 .57624 Mdot
.56397 .74916 Mdot
.62032 .42741 Mdot
.44854 .55173 Mdot
.56878 .40626 Mdot
.53383 .63004 Mdot
.73576 .28632 Mdot
.50527 .74726 Mdot
.31662 .44323 Mdot
.60121 .44499 Mdot
.33261 .62516 Mdot
.65742 .43944 Mdot
.64782 .19476 Mdot
.69843 .57432 Mdot
.25541 .47557 Mdot
.60816 .52236 Mdot
.30869 .47479 Mdot
.28418 .67779 Mdot
.34812 .18633 Mdot
.30665 .72967 Mdot
.50655 .47625 Mdot
.27629 .72499 Mdot
.72765 .34768 Mdot
.77598 .33001 Mdot
.24886 .46685 Mdot
.44068 .41466 Mdot
.41515 .37413 Mdot
.68252 .69098 Mdot
.59846 .46279 Mdot
.35056 .32261 Mdot
.56694 .55033 Mdot
.65182 .41029 Mdot
.70007 .53741 Mdot
.30989 .56087 Mdot
.39299 .22991 Mdot
.42534 .18846 Mdot
.76642 .65436 Mdot
.65774 .44861 Mdot
.46668 .34003 Mdot
.22826 .51168 Mdot
.70679 .2139 Mdot
.21261 .69449 Mdot
.3945 .54594 Mdot
.63002 .45396 Mdot
.28395 .4695 Mdot
.53212 .32451 Mdot
.59171 .58145 Mdot
.65317 .63934 Mdot
.70379 .50253 Mdot
.33922 .3392 Mdot
.31638 .30561 Mdot
.7381 .36231 Mdot
.27016 .54559 Mdot
.62868 .35484 Mdot
.16712 .55057 Mdot
.83968 .49034 Mdot
.69777 .29773 Mdot
.65251 .175 Mdot
.74364 .50409 Mdot
.49661 .64865 Mdot
.33429 .70132 Mdot
.31701 .24142 Mdot
.29011 .41018 Mdot
.22452 .57915 Mdot
.62158 .30128 Mdot
.25045 .48121 Mdot
.51921 .57249 Mdot
.36565 .24881 Mdot
.72245 .40626 Mdot
.53602 .46569 Mdot
.42406 .29478 Mdot
.24545 .31865 Mdot
.50351 .80572 Mdot
.45757 .18937 Mdot
.20869 .59726 Mdot
.68309 .7894 Mdot
.3525 .19807 Mdot
.33478 .40289 Mdot
.50707 .28966 Mdot
.34045 .71301 Mdot
.41632 .45749 Mdot
.49322 .53791 Mdot
.25991 .62818 Mdot
.50375 .71181 Mdot
.48095 .24215 Mdot
.24108 .67478 Mdot
.26286 .41765 Mdot
.44155 .6758 Mdot
.43993 .41833 Mdot
.51388 .77954 Mdot
.44064 .23639 Mdot
.51666 .54981 Mdot
.44028 .46158 Mdot
.31527 .41056 Mdot
.48419 .78106 Mdot
.73731 .65993 Mdot
.77001 .36992 Mdot
.64463 .82398 Mdot
.57268 .24042 Mdot
.21102 .63196 Mdot
.35185 .5816 Mdot
.25052 .26063 Mdot
.77333 .39954 Mdot
.60673 .275 Mdot
.81496 .49631 Mdot
.47353 .38582 Mdot
.50522 .66229 Mdot
.44818 .55114 Mdot
.54689 .21255 Mdot
.57846 .76076 Mdot
.37722 .68291 Mdot
.23635 .63336 Mdot
.27736 .43864 Mdot
.29234 .3313 Mdot
.33225 .43603 Mdot
.50291 .61892 Mdot
.54233 .64258 Mdot
.16938 .43974 Mdot
.48673 .45719 Mdot
.3285 .61344 Mdot
.33614 .51118 Mdot
.30507 .7094 Mdot
.85874 .47292 Mdot
.53718 .61001 Mdot
.28955 .30452 Mdot
.46476 .8033 Mdot
.42992 .4908 Mdot
.62513 .62221 Mdot
.66697 .14899 Mdot
.32205 .17469 Mdot
.54333 .62312 Mdot
.68429 .74403 Mdot
.47433 .80575 Mdot
.33718 .2345 Mdot
.4581 .30933 Mdot
.67638 .41743 Mdot
.33145 .5073 Mdot
.45607 .48435 Mdot
.39424 .6364 Mdot
.80709 .4709 Mdot
.3602 .1816 Mdot
.23805 .64806 Mdot
.38797 .20229 Mdot
.44699 .51311 Mdot
.41981 .63876 Mdot
.73656 .22627 Mdot
.55739 .19398 Mdot
.34304 .54265 Mdot
.33512 .76003 Mdot
.44496 .65078 Mdot
.38786 .59791 Mdot
.49054 .21363 Mdot
.79673 .66866 Mdot
.26285 .41221 Mdot
.34267 .22584 Mdot
.52604 .66784 Mdot
.56522 .41508 Mdot
.70714 .48841 Mdot
.45211 .4404 Mdot
.39442 .51352 Mdot
.69652 .49437 Mdot
.28825 .61626 Mdot
.74233 .3204 Mdot
.62238 .55458 Mdot
.79785 .64074 Mdot
.57154 .15886 Mdot
.51577 .75853 Mdot
.68042 .68387 Mdot
.32805 .57005 Mdot
.4418 .67429 Mdot
.24223 .54499 Mdot
.41156 .66311 Mdot
.78459 .36889 Mdot
.11096 .42346 Mdot
.66662 .37173 Mdot
.2234 .4388 Mdot
.61967 .68343 Mdot
.58887 .55633 Mdot
.54005 .78417 Mdot
.47516 .3369 Mdot
.56313 .37759 Mdot
.43105 .50575 Mdot
.50883 .61899 Mdot
.71378 .51085 Mdot
.30645 .80764 Mdot
.34804 .5652 Mdot
.61029 .59415 Mdot
.4564 .1572 Mdot
.2346 .58483 Mdot
.42103 .74829 Mdot
.46142 .56639 Mdot
.70368 .64079 Mdot
.44148 .4119 Mdot
.66587 .24482 Mdot
.22047 .40852 Mdot
.39508 .20777 Mdot
.50489 .7443 Mdot
.48709 .80025 Mdot
.39434 .52999 Mdot
.38391 .40698 Mdot
.69699 .55113 Mdot
.51925 .21805 Mdot
.47965 .56106 Mdot
.41336 .16508 Mdot
.48587 .40933 Mdot
.58419 .4267 Mdot
.5145 .60723 Mdot
.21434 .33308 Mdot
.2681 .6881 Mdot
.56815 .77824 Mdot
.19549 .60414 Mdot
.39009 .2851 Mdot
.26665 .53221 Mdot
.57547 .34085 Mdot
.47641 .55119 Mdot
.52317 .65078 Mdot
.16442 .5733 Mdot
.47674 .2084 Mdot
.66518 .3522 Mdot
.7013 .38622 Mdot
.71834 .71503 Mdot
.7473 .54215 Mdot
.6229 .16155 Mdot
.40375 .29062 Mdot
.1676 .56891 Mdot
.78755 .62808 Mdot
.52675 .61765 Mdot
.74646 .34988 Mdot
.47725 .62501 Mdot
.55469 .34341 Mdot
.38101 .21253 Mdot
.36464 .64224 Mdot
.20114 .506 Mdot
.46474 .60138 Mdot
.1866 .5253 Mdot
.32333 .337 Mdot
.43326 .22971 Mdot
.69793 .32363 Mdot
.29248 .70504 Mdot
.7093 .25348 Mdot
.68433 .69264 Mdot
.69649 .21954 Mdot
.71636 .26621 Mdot
.42846 .173 Mdot
.20689 .55492 Mdot
.37188 .81309 Mdot
.63556 .28066 Mdot
.66511 .26744 Mdot
.73751 .37994 Mdot
.32936 .71881 Mdot
.43155 .33323 Mdot
.53061 .60878 Mdot
.67318 .57964 Mdot
.61845 .49076 Mdot
.11427 .61815 Mdot
.3019 .3362 Mdot
.52123 .62433 Mdot
.40846 .31142 Mdot
.39072 .18638 Mdot
.31753 .70791 Mdot
.79508 .41339 Mdot
.564 .51542 Mdot
.40863 .63349 Mdot
.51575 .73227 Mdot
.74517 .68705 Mdot
.42721 .33736 Mdot
.55879 .86448 Mdot
.83444 .50269 Mdot
.67355 .39275 Mdot
.54177 .48901 Mdot
.53033 .65358 Mdot
.6469 .69392 Mdot
.43157 .28232 Mdot
.79511 .38459 Mdot
.74495 .32803 Mdot
.5664 .19594 Mdot
.54625 .85482 Mdot
.77539 .63026 Mdot
.31552 .24098 Mdot
.70643 .31829 Mdot
.56722 .62301 Mdot
.36146 .4236 Mdot
.52475 .3118 Mdot
.67464 .34599 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0Voooool2o`0003Sooooo
0_l0001booooo`007?ooool2o`0008Wooooo0_l0000Aooooo`;o0000>?ooool2o`0007;ooooo000L
ooooo`03o`000?oooooooooo08Sooooo0_l00006ooooo`;o00000oooool2o`000;;ooooo000Loooo
o`03o`000?oooooooooo08;ooooo0_l0000<ooooo`?o00000_ooool2o`0001Kooooo0_l00007oooo
o`;o0000TOooool001cooooo00?o0000ooooooooool0P_ooool2o`0000gooooo0_l00004ooooo`;o
00005?ooool2o`0000Oooooo0_l0000:ooooo`;o00000oooool2o`00083ooooo000Looooo`03o`00
0?oooooooooo08?ooooo0_l00003ooooo`;o00003Oooool2o`0000Gooooo0_l0000Rooooo`;o0000
0oooool2o`00083ooooo000Looooo`03o`000?oooooooooo07Cooooo1Ol0000:ooooo`;o00000ooo
ool2o`0000Gooooo0_l00002ooooo`;o00002Oooool2o`0000gooooo0_l0002Jooooo`007?ooool0
0ol0003oooooooooo`1aooooo`So00001?ooool2o`0000[ooooo0_l00004ooooo`;o00000_ooool5
o`0000Sooooo1?l00006ooooo`Go0000V_ooool001cooooo00?o0000ooooooooool0IOooool2o`00
00Wooooo1?l00009ooooo`;o00002?ooool4o`0000[ooooo0ol00003ooooo`?o00000_ooool4o`00
00Cooooo1ol0000Qooooo`;o0000Moooool001cooooo00?o0000ooooooooool0IOooool2o`0000?o
oooo0_l00004ooooo`;o00005Oooool2o`0001;ooooo0ol00004ooooo`;o00001?ooool2o`0000;o
oooo0ol000001?oooooo0000o`000?ooool3o`0001[ooooo0_l0001gooooo`007?ooool00ol0003o
ooooooooo`1Zooooo`;o00001?ooool2o`00013ooooo0_l00003ooooo`;o00004?ooool8o`0000Oo
oooo0ol00005ooooo`;o000000?oooooo`000?l000000_l00005ooooo`;o0000Roooool001cooooo
00?o0000ooooooooool0L?ooool3o`0000_ooooo2?l000000ooooooo0000o`00000@ooooo`Co0000
00?oooooo`000?l000000_l00006ooooo`?o00002_ooool2o`0000;ooooo0_l000001?oooooo0000
o`000?ooool4o`0008Kooooo000Looooo`03o`000?oooooooooo06Oooooo0_l00004ooooo`;o0000
0_ooool2o`0000Sooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l0000;ooooo`;o0000
1_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000?ooooo`;o00000oooool2o`000003oooo
ool0003o000000Cooooo1?l00026ooooo`007?ooool00ol0003oooooooooo`1Wooooo`;o00001?oo
ool2o`0000cooooo0_l00009ooooo`;o00002Oooool2o`0000Kooooo0_l00002ooooo`;o00004_oo
ool2o`000003ooooool0003o000000;o0000TOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^
1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo08Kooooo0_l000000ooooooo0000
o`000006ooooo`;o00008Oooool2o`0000Kooooo0_l00007ooooo`;o0000P_ooool00006oooooomg
MgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006oooo
o`03o`000?oooooooooo06oooooo1?l000000ooooooo0000o`000002o`0000[ooooo0_l00005oooo
o`;o00003_ooool2o`0000Oooooo0_l00005ooooo`;o00001_ooool2o`000004ooooool0003o0000
o`0000Gooooo0ol000000ooooooo0000o`000003ooooo`Go00001Oooool2o`0007Sooooo00000ooo
oooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0
003oooooooooo`1Gooooo`;o00005_ooool4o`000003ooooool0003o000000;o00000_ooool2o`00
00Kooooo0_l0000Eooooo`;o00001oooool2o`0000Gooooo0_l00006ooooo`;o000000Coooooo`00
0?l0003o00001Oooool3o`000003ooooool0003o000000Cooooo1?l00003ooooo`Co00000oooool2
o`0007?ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q
8Oo^k^h01_ooool3o`0005Oooooo0_l0000Fooooo`;o00002Oooool2o`0000[ooooo0_l00009oooo
o`;o00001_ooool2o`0003;ooooo1?l00003ooooo`;o0000Loooool00003ooooool0003ooooo00;o
oooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo06oo
oooo0_l000000ooooooo0000o`000005ooooo`Co00002Oooool4o`0000Oooooo0_l0000Jooooo`;o
00005_ooool3o`0000Oooooo0_l0001hooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0G_ooool2o`0000Wooooo
0_l00004ooooo`;o000000?oooooo`000?l000001Oooool6o`000003ooooool0003o000000Kooooo
0_l0000=ooooo`;o00005?ooool2o`0001Kooooo1?l00003ooooo`;o00001?ooool2o`0007Gooooo
00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4006oooo
o`03o`000?oooooooooo05kooooo0_l00009ooooo`?o000000?oooooo`000?l000002oooool2o`00
0004ooooool0003o0000ooooo`;o00001oooool2o`0000;ooooo0_l00008ooooo`;o00005oooool2
o`0001Gooooo0_l00003ooooo`;o00001?ooool6o`00077ooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo06[ooooo
0_l000000ooooooo0000o`000002o`0000Oooooo0_l000000ooooooo0000o`00000<ooooo`;o0000
0_ooool2o`0000Gooooo0_l000000ooooooo0000o`000002ooooo`?o00001oooool2o`0000Oooooo
1?l0000Eooooo`;o00002oooool7o`0000Oooooo0_l0001Uooooo`007?ooool00ol0003ooooooooo
o`1_ooooo`;o00001oooool2o`000003ooooool0003o000000Wooooo0ol00003ooooo`Co00001?oo
ool2o`000003ooooool0003o000000;ooooo0ol00007ooooo`;o00001oooool2o`0001Oooooo0_l0
0009ooooo`;o000000?oooooo`000?l000001?l00007ooooo`;o0000IOooool001cooooo00?o0000
ooooooooool0IOooool2o`0001oooooo0ol000000ooooooo0000o`000004o`0001;ooooo0_l00000
0ooooooo0000o`00000;ooooo`;o00007_ooool2o`000003ooooool0003o000000Oooooo0_l0001Y
ooooo`007?ooool00ol0003oooooooooo`1Tooooo`?o000000?oooooo`000?l000004Oooool2o`00
00_ooooo1?l0000@ooooo`;o00001?ooool2o`000003ooooool0003o000000?ooooo0_l00003oooo
o`;o000000Coooooo`000?l0003ooooo0ol00004ooooo`;o00003oooool2o`0000Gooooo0_l00003
ooooo`;o00000oooool2o`0006Wooooo000Looooo`03o`000?oooooooooo06Cooooo0_l00002oooo
o`;o00000_ooool2o`0000gooooo0_l00003ooooo`;o00001_ooool4o`0000[ooooo0_l00004oooo
o`;o00000oooool2o`0000;ooooo1?l000000ooooooo0000o`000003ooooo`;o00001?ooool3o`00
00Cooooo0_l000000ooooooo0000o`00000<ooooo`;o000000Coooooo`000?l0003ooooo0ol00003
ooooo`;o00004?ooool2o`0005cooooo000Looooo`03o`000?oooooooooo05kooooo0_l000000ooo
oooo0000o`000009ooooo`;o00002_ooool2o`0000;ooooo0_l00002ooooo`;o00001oooool3o`00
00[ooooo0_l00002ooooo`;o00001Oooool2o`0000Cooooo0_l000000ooooooo0000o`000009oooo
o`;o00001?ooool2o`0000;ooooo0ol00007ooooo`;o000000?oooooo`000?l000000_ooool2o`00
0003ooooool0003o000001Kooooo0_l0001Looooo`007?ooool00ol0003oooooooooo`1Iooooo`;o
00000oooool2o`000003ooooool0003o000001Gooooo1_l0000;ooooo`;o00000_ooool2o`0000_o
oooo0_l0000:ooooo`;o00000_ooool2o`0000?ooooo0_l00004ooooo`Co00000_ooool2o`0000?o
oooo0_l00002ooooo`?o00000_ooool2o`000003ooooool0003o000007_ooooo000Looooo`03o`00
0?oooooooooo05Wooooo0_l0000?ooooo`?o00002?ooool2o`0000?ooooo1?l0000;ooooo`Ko0000
00?oooooo`000?l000005?ooool2o`0000Kooooo0ol00006ooooo`?o00000oooool2o`0000Gooooo
0ol00004ooooo`;o0000O?ooool001cooooo00?o0000ooooooooool0FOooool2o`0000Sooooo0_l0
0005ooooo`?o00000oooool2o`0000?ooooo0_l0000Dooooo`;o00000oooool2o`0001Gooooo0_l0
0002ooooo`Go00002?ooool2o`0000?ooooo0_l0000<ooooo`;o00004?ooool2o`0006[ooooo000L
ooooo`03o`000?oooooooooo05Wooooo1?l00006ooooo`?o00001Oooool2o`0000?ooooo0_l0000<
ooooo`Co00001_ooool2o`0000gooooo1?l0000<ooooo`So000000?oooooo`000?l000001?ooool2
o`00017ooooo0_l0000Booooo`;o0000J_ooool001cooooo00?o0000ooooooooool0Foooool4o`00
00Cooooo0ol00005ooooo`;o00002oooool2o`0000Cooooo1?l00006ooooo`;o00001_ooool2o`00
00Gooooo1?l0000>ooooo`Co00000oooool5o`000003ooooool0003o0000017ooooo0_l0000:oooo
o`;o0000L_ooool001cooooo00?o0000ooooooooool0GOooool2o`0000Sooooo0_l0000:ooooo`Co
000000?oooooo`000?l000000_ooool5o`0000oooooo0_l0000Aooooo`;o00001Oooool2o`0000;o
oooo0_l000000ooooooo0000o`000002o`0001Cooooo0_l0000:ooooo`;o0000L_ooool001cooooo
0_l0001Mooooo`;o00002?ooool3o`000003ooooool0003o000000;ooooo1?l000000ooooooo0000
o`000002o`0000Gooooo0_l0000:ooooo`;o00002oooool2o`0000Wooooo0_l000001?oooooo0000
o`000?l00008ooooo`;o00001Oooool2o`0000[ooooo1?l00004ooooo`;o0000O_ooool001cooooo
00?o0000ooooooooool0G?ooool2o`0000Gooooo0_l000000ooooooo0000o`000002ooooo`;o0000
0_ooool4o`0000cooooo0_l00004ooooo`;o000000Coooooo`000?l0003o00001_ooool2o`0000?o
oooo0_l00009ooooo`;o00000_ooool2o`0000oooooo0_l00006ooooo`;o00000_ooool4o`0000_o
oooo0_l0000Aooooo`;o000000?oooooo`000?l00000HOooool001cooooo00?o0000ooooooooool0
E?ooool4o`0000_ooooo0_l00003ooooo`;o000000?oooooo`000?l000004Oooool2o`0000Cooooo
1Ol00003ooooo`;o00000_ooool3o`0000;ooooo0_l0000Uooooo`?o00003oooool4o`00017ooooo
0_l000000ooooooo0000o`00000Gooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0C_oo
ool2o`0000Cooooo1?l0000@ooooo`;o000000?oooooo`000?l000001_ooool2o`00013ooooo0ol0
0004ooooo`;o00000oooool2o`0002Kooooo0_l000000ooooooo0000o`00000@ooooo`Co00000ooo
ool2o`0002Sooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o00004Oooool5
o`0000[ooooo0_l000000ooooooo0000o`00000?ooooo`?o00001Oooool2o`0000cooooo0_l00003
ooooo`;o00001?ooool2o`0001;ooooo0ol0000Fooooo`;o000000?oooooo`000?l00000L_ooool0
01cooooo00?o0000ooooooooool0Goooool8o`0000Sooooo0ol0000=ooooo`Oo00001_ooool2o`00
00cooooo0_l00003ooooo`;o00001?ooool2o`0001?ooooo0_l00002ooooo`;o00002oooool2o`00
00Gooooo1?l0000?ooooo`;o00001?ooool2o`0005cooooo000Looooo`03o`000?oooooooooo053o
oooo0_l0000;ooooo`Co00001?ooool2o`0000Sooooo0_l0000:ooooo`;o00000_ooool5o`0002[o
oooo0_l0000>ooooo`;o00002oooool2o`0000?ooooo0_l00002ooooo`;o00002_ooool2o`0000?o
oooo1?l000001?oooooo0000o`000?l0001Looooo`007?ooool00ol0003oooooooooo`1@ooooo`;o
00002oooool2o`0001cooooo0_l000000ooooooo0000o`000002ooooo`;o00003oooool2o`0000go
oooo0_l00006ooooo`;o00000_ooool2o`0000cooooo0_l0000Booooo`;o00000_ooool2o`0000[o
oooo0_l00003ooooo`Co000000Coooooo`000?l0003o0000G?ooool001cooooo00?o0000oooooooo
ool0F?ooool2o`0000[ooooo0_l0000Hooooo`Co00004Oooool2o`0000gooooo0_l00006ooooo`;o
00002?ooool2o`0000Kooooo0_l00003ooooo`Co00001Oooool2o`0000?ooooo0_l00003ooooo`;o
00001Oooool2o`0000Kooooo1?l0001Rooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o0000
0_ooool2o`0000[ooooo0_l0000Hooooo`Co00009oooool3o`0000Sooooo0_l00004ooooo`;o0000
0oooool6o`0000Gooooo0_l00003ooooo`;o00002_ooool2o`0000Kooooo0_l0000=ooooo`;o0000
EOooool001cooooo00?o0000ooooooooool0Coooool2o`0000?ooooo0_l0000Kooooo`;o00003Ooo
ool3o`0000Gooooo0_l0000Gooooo`;o00001_ooool3o`0000kooooo0_l00003ooooo`Co00001?oo
ool2o`0000;ooooo0_l0000>ooooo`;o00001_ooool2o`0000Sooooo0ol00002ooooo`;o0000EOoo
ool001cooooo00?o0000ooooooooool0COooool4o`0000kooooo0_l000000ooooooo0000o`000002
ooooo`Co00000oooool2o`0000;ooooo0_l00008ooooo`;o00001?ooool2o`0000Gooooo0_l00006
ooooo`;o00003oooool2o`0000Oooooo1Ol00002ooooo`;o00003Oooool2o`0000;ooooo0_l00000
0ooooooo0000o`000004o`0000Wooooo1?l000000ooooooo0000o`000002o`0000Cooooo0_l00002
ooooo`;o00000oooool4o`0005Wooooo000Looooo`03o`000?oooooooooo04gooooo0_l00003oooo
o`;o00002_ooool3o`000003ooooool0003o000000;ooooo2Ol0000<ooooo`;o00004oooool2o`00
01;ooooo0_l00005ooooo`Co00000_ooool2o`0000_ooooo0_l00004ooooo`;o000000?oooooo`00
0?l000000_l0000;ooooo`Co00000oooool2o`0000Sooooo0_l00002ooooo`Ko0000F?ooool001co
oooo00?o0000ooooooooool0D_ooool2o`0000;ooooo0_l00006ooooo`;o00001?ooool2o`0000?o
oooo1_l00006ooooo`;o00001_ooool4o`0000Cooooo0_l00005ooooo`;o00004oooool2o`000003
ooooool0003o000000;ooooo0_l00009ooooo`;o00001?ooool2o`0000?ooooo0_l00002ooooo`Co
000000?oooooo`000?l000008_ooool6o`0005Sooooo000Looooo`03o`000?oooooooooo04oooooo
0_l000000ooooooo0000o`000002ooooo`;o00002oooool3o`0000Gooooo1?l00006ooooo`?o0000
1Oooool4o`0000Cooooo0ol00004ooooo`;o00004oooool2o`0000Cooooo0ol00009ooooo`;o0000
1?ooool2o`0000Oooooo1?l000000ooooooo0000o`000005ooooo`;o0000NOooool001cooooo00?o
0000ooooooooool0Coooool2o`0001;ooooo0_l00006ooooo`;o000000?oooooo`000?l000000ooo
ool5o`0000kooooo0_l0000Booooo`;o00001Oooool2o`0000Cooooo0_l0000Jooooo`?o00002?oo
ool2o`0000gooooo1?l00002ooooo`;o00002?ooool2o`0005[ooooo000Looooo`;o0000=_ooool2
o`0001[ooooo0_l0000Booooo`;o00001?ooool2o`000004ooooool0003o0000o`0000;ooooo1Ol0
000<ooooo`;o00005?ooool2o`0000Kooooo0_l0000:ooooo`;o00003oooool2o`0000;ooooo1Ol0
000;ooooo`;o00002?ooool4o`0000;ooooo0_l00008ooooo`;o00002_ooool2o`0004kooooo000L
ooooo`03o`000?oooooooooo03Gooooo0_l0000Jooooo`;o00001?ooool2o`000003ooooool0003o
000000Wooooo0_l00008ooooo`;o00003_ooool2o`0000?ooooo0_l0000;ooooo`;o00003oooool2
o`0000[ooooo0_l00002ooooo`;o00002?ooool2o`000003ooooool0003o000000?ooooo1_l00003
ooooo`So00003Oooool2o`0000?ooooo0ol0000?ooooo`;o0000C_ooool001cooooo00?o0000oooo
ooooool0Boooool2o`0000Cooooo0_l00004ooooo`Go00001oooool4o`0001Kooooo1?l0000@oooo
o`;o00002Oooool2o`0001Cooooo0_l00005ooooo`;o000000Coooooo`000?l0003o00001Oooool2
o`0000;ooooo0_l00003ooooo`Oo00001Oooool2o`0000Cooooo0_l000000ooooooo0000o`000003
ooooo`?o00002_ooool2o`0005?ooooo000Looooo`03o`000?oooooooooo04_ooooo0_l0000<oooo
o`;o00001oooool3o`0000[ooooo0_l000001?oooooo0000o`000?l00008ooooo`;o00004_ooool2
o`0000Wooooo0_l0000Fooooo`?o00000_ooool2o`0000;ooooo0_l00002ooooo`;o00000_ooool2
o`0000_ooooo0_l00005ooooo`;o00001?ooool2o`0001;ooooo0ol00006ooooo`;o0000Boooool0
01cooooo00?o0000ooooooooool0D?ooool2o`000003ooooool0003o000000Kooooo0_l00005oooo
o`;o000000?oooooo`000?l000002?ooool2o`000004ooooool0003o0000o`0000cooooo1_l00009
ooooo`?o00000oooool2o`0000Sooooo0_l00005ooooo`;o000000?oooooo`000?l000000oooool2
o`0000;ooooo1?l0000:ooooo`;o00000_ooool2o`0000_ooooo0_l00006ooooo`;o00003?ooool2
o`0000Wooooo0_l00007ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0AOooool2o`00
00Oooooo1ol000000ooooooo0000o`000003ooooo`;o00002?ooool3o`0001Wooooo1_l00009oooo
o`;o00001?ooool2o`0000Sooooo0_l00003ooooo`Co000000Coooooo`000?l0003o00000_ooool2
o`0000;ooooo0_l0000Uooooo`;o00003?ooool2o`0001?ooooo0_l0001:ooooo`007?ooool00ol0
003oooooooooo`15ooooo`;o00001Oooool4o`000003ooooool0003o000000;ooooo1Ol0000<oooo
o`;o00003Oooool2o`000004ooooool0003o0000o`0002Gooooo0_l00002ooooo`[o000000?ooooo
o`000?l000001?l0000Aooooo`;o00005?ooool2o`0000;ooooo1?l00008ooooo`;o00002?ooool2
o`0000Gooooo0ol000000ooooooo0000o`000016ooooo`007?ooool00ol0003oooooooooo`1<oooo
o`Co000000?oooooo`000?l000000_ooool5o`0000Cooooo0_l00004ooooo`;o00002?ooool2o`00
00Gooooo0_l000001Ooooooo0000o`000?l0003ooooo00?o00001Oooool2o`0000Gooooo0_l0000?
ooooo`;o00000_ooool2o`0000;ooooo2_l00003ooooo`Ko00000_ooool2o`0000Wooooo1?l00007
ooooo`;o00002oooool2o`0000;ooooo1?l00008ooooo`?o00001oooool2o`0000Kooooo0_l00000
0ooooooo0000o`000016ooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o000000?oooooo`00
0?l000001_ooool4o`000003ooooool0003o000000Cooooo0_l00006ooooo`Co00003?ooool3o`00
0003ooooool0003o000000;ooooo0_l00005ooooo`;o00001oooool2o`000003ooooool0003o0000
00?ooooo0_l00004oooooaWo00002Oooool2o`0000Wooooo0_l0000>ooooo`?o00002oooool2o`00
00Oooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o00001_ooool4o`0000Ko
oooo0ol00006ooooo`;o00000_ooool2o`0000;ooooo1?l00007ooooo`?o00004_ooool2o`000003
ooooool0003o000000Wooooo6Ol0000<ooooo`?o00005Oooool2o`0000?ooooo0_l00008ooooo`;o
0000FOooool001cooooo00?o0000ooooooooool0Doooool2o`0000;ooooo0ol000000ooooooo0000
o`000006ooooo`Co00002Oooool2o`0000;ooooo1?l00007ooooo`Co00001oooool4o`0001Cooooo
3ol000000ooooooo0000o`000007o`0000Wooooo0_l000001?oooooo0000o`000?l00006ooooo`;o
000000?oooooo`000?l000003oooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool3o`00
00Oooooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`12ooooo`Co00003Oooool3o`000005
ooooool0003o0000o`000?ooool00_l00008ooooo`;o00001Oooool4o`00017ooooo0_l00005oooo
o`Ko00001Oooool2o`0000Wooooo0_l00002oooooaWo00002?ooool3o`0000;ooooo0ol00005oooo
o`Go00001oooool2o`0000[ooooo1Ol000001?oooooo0000o`000?l00007ooooo`;o00002oooool2
o`0004;ooooo000Looooo`03o`000?oooooooooo04;ooooo1?l0000>ooooo`;o00002?ooool2o`00
00Cooooo0ol00005ooooo`Co00000oooool4o`000003ooooool0003o000000gooooo0ol000000ooo
oooo0000o`000006ooooo`;o00000_ooool2o`0000Gooooo7Ol00008ooooo`;o00000_ooool4o`00
00Oooooo0_l00008ooooo`;o00002oooool2o`00017ooooo0ol00006ooooo`Co0000@?ooool001co
oooo00?o0000ooooooooool0BOooool2o`0000_ooooo0_l00002ooooo`;o00000_ooool2o`0000Co
oooo0ol00003ooooo`;o00001oooool4o`000004ooooool0003o0000ooooo`Co00000_ooool2o`00
00Cooooo0_l00002ooooo`;o00001oooool2o`000003ooooool0003o000000Oooooo2_l000000ooo
oooo0000o`000007o`000003ooooool0003o000000?o00003Oooool2o`0000;ooooo0_l00008oooo
o`;o00001?ooool2o`0000Wooooo0ol00003ooooo`;o00001?ooool3o`000004ooooool0003o0000
ooooo`;o000000Coooooo`000?l0003o00002?ooool2o`00043ooooo000Looooo`03o`000?oooooo
oooo043ooooo0_l00007ooooo`;o00002Oooool4o`0000;ooooo0_l0000>ooooo`;o00001Oooool9
o`000003ooooool0003o000000;o00000_ooool2o`0000;ooooo0_l00004ooooo`;o000000?ooooo
o`000?l000001?ooool2o`0000Wooooo2ol00002oooooa7o00003_ooool2o`0000;ooooo0ol00003
ooooo`;o00000_ooool4o`0000Wooooo0ol00003ooooo`;o00001?ooool3o`000004ooooool0003o
0000ooooo`Co0000C?ooool001cooooo00?o0000ooooooooool0@?ooool2o`0000Gooooo0_l00006
ooooo`;o00000_ooool3o`0000;ooooo0_l0000:ooooo`;o00001?ooool2o`0000?ooooo3Ol00000
0ooooooo0000o`000004o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l000001_ooool2
o`0000Oooooo3?l000000ooooooo0000o`00000:o`000003ooooool0003o000000;o00001oooool2
o`0000Sooooo1_l00002ooooo`Oo00002_ooool7o`0000Sooooo0_l000000ooooooo0000o`000002
o`0004cooooo000Looooo`;o0000?_ooool2o`0000Sooooo0_l00005ooooo`?o00000_ooool4o`00
0003ooooool0003o000000[ooooo0_l00009oooooaCo00002?ooool2o`0000Wooooo0_l00007oooo
o`co000000?oooooo`000?l000002_l000001?oooooo0000o`000?l00008ooooo`;o00000_ooool2
o`0000Cooooo1_l00002ooooo`?o00000_ooool2o`0000[ooooo2_l00005ooooo`;o000000?ooooo
o`000?l00000C_ooool001cooooo00?o0000ooooooooool0?Oooool2o`0000oooooo0_l000000ooo
oooo0000o`000002ooooo`;o00003oooool2o`0000;ooooo0_l00003oooooa;o00002oooool4o`00
00Gooooo0_l00009oooooaSo000000Goooooo`000?l0003o0000ooooo`04o`0000Oooooo0_l00007
ooooo`;o000000?oooooo`000?l000000oooool4o`0000_ooooo0_l00004ooooo`?o00001_ooool4
o`000003ooooool0003o000004_ooooo000Looooo`03o`000?oooooooooo04gooooo0_l00002oooo
o`;o00000_ooool2o`0000kooooo2?l000000ooooooo0000o`00000Co`000003ooooool0003o0000
00Kooooo1?l00005ooooo`;o00002_ooool9o`000003ooooool0003o000000oo000000?oooooo`00
0?l000000_l00007ooooo`;o00000_ooool2o`0000;ooooo0_l00002ooooo`;o00000oooool2o`00
00_ooooo0_l000000ooooooo0000o`00000<ooooo`Co000000Coooooo`000?l0003o00004oooool2
o`0003Gooooo000Looooo`03o`000?oooooooooo03Sooooo0_l0000Cooooo`;o00000_ooool2o`00
00_ooooo0_l000000ooooooo0000o`000002ooooo`So000000?oooooo`000?l000004ol000000ooo
oooo0000o`00000Dooooo`;o00000oooool;o`0000;ooooo1?l000000ooooooo0000o`000009o`00
0003ooooool0003o000000Wooooo0_l00002ooooo`Oo000000Coooooo`000?l0003ooooo0_l0000=
ooooo`;o000000?oooooo`000?l000003Oooool2o`0000;ooooo0ol0000Cooooo`;o0000=Oooool0
01cooooo00?o0000ooooooooool0>?ooool2o`00017ooooo0_l0000<ooooo`;o00000oooool2o`00
0003ooooool0003o000000Sooooo0_l000000ooooooo0000o`00000Co`000004ooooool0003o0000
o`0000?ooooo0_l0000>ooooo`;o00000oooool<o`000003ooooool0003o000000ko000000?ooooo
o`000?l000002Oooool2o`0000Cooooo1Ol00004ooooo`;o00003Oooool2o`0000Cooooo0_l00005
ooooo`Co000000?oooooo`000?l000000oooool2o`0004[ooooo000Looooo`03o`000?oooooooooo
03_ooooo0_l00002ooooo`;o00002_ooool2o`0000cooooo0_l0000:ooooo`;o00001OoooolGo`00
0003ooooool0003o000000;o00000_ooool2o`0001Cooooo7?l000000ooooooo0000o`000009oooo
o`;o000000Coooooo`000?l0003ooooo0_l00009ooooo`;o00002?ooool2o`0000;ooooo2Ol00003
ooooo`Co00001_ooool2o`0004[ooooo000Looooo`03o`000?oooooooooo03_ooooo0_l00002oooo
o`;o00007Oooool2o`0000Gooooo0_l00004oooooaWo00000_ooool2o`0001;ooooo0_l00003oooo
o`_o000000?oooooo`000?l000001Ol000000ooooooo0000o`000006o`0000;ooooo0_l00008oooo
o`;o00000_ooool2o`0000Wooooo0_l000000ooooooo0000o`000002ooooo`;o00001?ooool2o`00
00;ooooo1Ol00002ooooo`;o00001_ooool4o`000003ooooool0003o000004cooooo000Looooo`03
o`000?oooooooooo05Kooooo0_l00004ooooo`Co00000oooool4o`0000;ooooo6ol00005ooooo`?o
00002?ooool2o`0000Cooooo0_l00003oooooago00002Oooool4o`000003ooooool0003o000000Wo
oooo0ol00003ooooo`Go00000_ooool2o`0000Kooooo0_l00006ooooo`;o00000_ooool4o`000003
ooooool0003o000000Cooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`13ooooo`;o0000
1_ooool3o`0000Sooooo0_l00004ooooo`?o00001?ooool4o`0000;ooooo0_l000000ooooooo0000
o`00000Io`0000;ooooo1Ol00006ooooo`;o00001Oooool2o`0000;ooooo6_l000000ooooooo0000
o`000009ooooo`;o00000oooool4o`0000Oooooo0_l00004ooooo`;o000000?oooooo`000?l00000
0_ooool2o`0000kooooo0_l00002ooooo`;o00000_ooool2o`0000Gooooo0_l0000=ooooo`;o0000
=oooool001cooooo00?o0000ooooooooool0=oooool2o`0000[ooooo0_l00006ooooo`?o00003_oo
ool3o`0000Kooooo0_l000000ooooooo0000o`00000Mo`0000Gooooo0_l0000=ooooo`;o00001?oo
oolHo`000003ooooool0003o000000Kooooo0_l00007ooooo`?o00007_ooool2o`0000Wooooo1ol0
0003ooooo`;o00003Oooool2o`0003Oooooo000Looooo`03o`000?oooooooooo03Oooooo0_l0000N
ooooo`;o00001?ooool2o`0000Cooooo0_l00002ooooo`Go000000?oooooo`000?l000005?l0000I
ooooo`;o00000ooooolIo`0000Sooooo0_l0000@ooooo`;o00001_ooool4o`0000Sooooo0ol00000
0ooooooo0000o`000002ooooo`;o00001Oooool4o`000003ooooool0003o000000?ooooo0_l00016
ooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o00000oooool2o`000004ooooool0003o0000
o`0000Cooooo0_l00003ooooo`?o00000_ooool2o`000003ooooool0003o000000;ooooo5?l00003
ooooo`;o00005Oooool3o`0000;ooooo6_l00006ooooo`;o00004Oooool2o`0000Kooooo1?l00008
ooooo`?o000000?oooooo`000?l000000_ooool4o`0000Kooooo0_l000001?oooooo0000o`000?l0
0019ooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00003?ooool4o`0000?ooooo0_l00003
ooooo`;o000000?oooooo`000?l000001?l00006ooooo`;o000000Coooooo`000?l0003ooooo0_l0
0003oooooaGo00000oooool2o`0000oooooo0_l00005ooooo`;o00000ooooolFo`000003ooooool0
003o000000Kooooo0_l0000Fooooo`;o00001Oooool3o`0000Oooooo0_l00005ooooo`?o00001Ooo
ool3o`000004ooooool0003o0000o`0004Wooooo000Looooo`03o`000?oooooooooo03Wooooo0_l0
000<ooooo`Ko00002Oooool8o`0000Oooooo1Ol00003oooooaGo00005?ooool2o`0000[ooooo5Ol0
0002ooooo`;o00001_ooool2o`0000?ooooo0ol0000=ooooo`;o000000?oooooo`000?l000001Ooo
ool5o`0000Gooooo0_l0000=ooooo`;o00006Oooool2o`0003?ooooo00001_ooooook^k^oc8b<_l0
003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003ooooo
ooooo`0oooooo`;o00001_ooool3o`000003ooooool0003o000000Wooooo0_l000001?oooooo0000
o`000?ooool2o`0000Wooooo1Ol00002oooooaCo00001oooool2o`0001?ooooo0ol000001?oooooo
0000o`000?oooolBo`0000Gooooo1?l000000ooooooo0000o`000003ooooo`Go00002oooool3o`00
00Cooooo0_l00004ooooo`;o00002Oooool2o`0002Cooooo0_l0000cooooo`0000KoooooogMgMonH
V9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo03oooooo0_l00006ooooo`?o00001_ooool3o`0000Kooooo0_l00007ooooo`Co000000?ooooo
o`000?l000000ol00002oooooa;o00002Oooool2o`0000Cooooo1?l00002ooooo`;o00001?ooool2
o`000004ooooool0003o0000o`0000;ooooo5?l00005ooooo`Co00001?ooool2o`0000;ooooo0ol0
000<ooooo`;o00001?ooool2o`0000Gooooo0_l00008ooooo`;o0000FOooool00003ooooool@413o
oooo00;ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo00?o0000ooooooooool0Aoooool3
o`0000Kooooo0ol0000?ooooo`Ko00000_ooool2o`0000?ooooo3?l000001?oooooo0000o`000?oo
ool2o`0000?ooooo0_l00009ooooo`Co00000_ooool2o`0000Cooooo0ol00005ooooo`co00001?oo
ool3o`0000Oooooo0_l00005ooooo`;o00007_ooool2o`00017ooooo0_l00003ooooo`;o0000Booo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?m4A4CogMgMooooool0
0007ooooo`?o0000HOooool2o`000003ooooool0003o000000;o000000Coooooo`000?l0003o0000
0oooool?o`000004ooooool0003o0000o`0000;ooooo0_l0000@ooooo`Go000000Coooooo`000?l0
003o00002?ooool7o`000004ooooool0003o0000ooooo`Co00001oooool4o`0001[ooooo0_l00000
0ooooooo0000o`00000@ooooo`;o00001Oooool2o`0000?ooooo0_l000000ooooooo0000o`000018
ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGooooo
o`0000Oooooo00?o0000ooooooooool0<Oooool2o`000003ooooool0003o000000gooooo0_l0000H
ooooo`;o00000_ooool2o`000004ooooool0003o0000o`0000;ooooo0_l00005ooooo`ko00000_oo
ool2o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l000001_ooool5o`0000;ooooo0_l0
0009ooooo`Wo000000Coooooo`000?l0003ooooo0_l00007ooooo`Ko000000?oooooo`000?l00000
3?ooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0000Oooooo0_l00007ooooo`;o
00001Oooool4o`000004ooooool0003o0000ooooo`;o0000B?ooool00003ooooool@413ooooo00;o
oooo00?o410@ooooooooool02_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo037o
oooo0_l000000ooooooo0000o`000002ooooo`;o00002Oooool3o`0000Gooooo0_l00004ooooo`Co
00000_ooool2o`0000Cooooo0_l00002ooooo`;o00000_ooool2o`0000Wooooo0_l00002ooooo`Oo
000000?oooooo`000?l000003Oooool2o`000004ooooool0003o0000ooooo`;o00001oooool2o`00
00Wooooo0_l000001?oooooo0000o`000?l00002ooooo`?o00000_ooool2o`000004ooooool0003o
0000ooooo`;o00001?ooool6o`000003ooooool0003o000000cooooo0_l00003ooooo`;o00001Ooo
ool3o`0000Gooooo1?l00006ooooo`;o00001?ooool7o`0004_ooooo00001_ooooooMgMgoiRHV?oo
ooooV9RHogMgM`cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0hooooo`;o0000
2?ooool4o`0000Gooooo0_l00004ooooo`So00000_ooool2o`0000Cooooo1?l0000;ooooo`;o0000
0_ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000000_l0000<ooooo`;o0000
0oooool6o`0000?ooooo0_l00004ooooo`;o00000oooool2o`0000Kooooo0_l00003ooooo`;o0000
1?ooool2o`0000Cooooo0ol00004ooooo`;o00002Oooool2o`0000Kooooo0_l00005ooooo`?o0000
0_ooool2o`0000?ooooo0_l00006ooooo`;o00001Oooool4o`0004gooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`0]ooooo`;o
00004oooool3o`0000gooooo1_l00003ooooo`;o00001_ooool2o`0001;ooooo1?l000000ooooooo
0000o`000002o`0000_ooooo0ol00005ooooo`Co00002Oooool2o`0000Oooooo0_l00002ooooo`;o
000000Goooooo`000?l0003o0000ooooo`02o`0000_ooooo0_l00002ooooo`;o00002Oooool2o`00
00Kooooo0_l0000:ooooo`?o00003oooool5o`0000?ooooo1?l00017ooooo`007?ooool00ol0003o
ooooooooo`0]ooooo`;o00004_ooool4o`0000cooooo1?l0000>ooooo`;o00001_ooool2o`0000[o
oooo0_l0000=ooooo`;o000000?oooooo`000?l000000ol0000:ooooo`;o00001_ooool2o`0000Oo
oooo1Ol00002ooooo`?o000000?oooooo`000?l000002oooool2o`0001Gooooo0_l00004ooooo`;o
00001Oooool2o`0000oooooo0_l000000ooooooo0000o`000003ooooo`Co00001_ooool2o`0003oo
oooo000Looooo`03o`000?oooooooooo047ooooo1?l0000<ooooo`Co00000oooool3o`0000;ooooo
0_l00004ooooo`;o00001_ooool2o`0001?ooooo0_l00004ooooo`;o000000?oooooo`000?l00000
0ol0000:ooooo`;o00001_ooool2o`0000Wooooo0ol00005ooooo`;o00002_ooool2o`0001Oooooo
0_l00004ooooo`;o00000_ooool2o`000003ooooool0003o000000Gooooo0_l00007ooooo`;o0000
0_ooool4o`0000_ooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0Pooooo`;o00006_oo
ool2o`0001[ooooo0ol00002ooooo`;o00002Oooool2o`0000Kooooo1?l00006ooooo`;o00001?oo
ool2o`0000;ooooo0_l0000>ooooo`;o00000oooool2o`0001Sooooo0_l000000ooooooo0000o`00
0007ooooo`;o00001_ooool2o`0000;ooooo0_l0000Eooooo`Go00001Oooool2o`0000Oooooo0_l0
0002ooooo`Co000000?oooooo`000?l000001oooool2o`00043ooooo000Looooo`03o`000?oooooo
oooo023ooooo0_l0000Jooooo`;o00002?ooool2o`0000Gooooo0_l00004ooooo`;o00000oooool4
o`000003ooooool0003o000000Wooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o
000000;o00001_ooool2o`000003ooooool0003o000000?ooooo1?l00009ooooo`?o00000_ooool4
o`000004ooooool0003o0000o`0000Cooooo0_l0000>ooooo`;o00001?ooool2o`0000;ooooo0_l0
000:ooooo`?o00000_ooool2o`0000Gooooo0_l0000@ooooo`;o00001_ooool2o`0000_ooooo0_l0
0003ooooo`;o00001oooool2o`00043ooooo000Looooo`03o`000?oooooooooo04Kooooo0_l00005
ooooo`;o00001?ooool2o`0000?ooooo1?l000000ooooooo0000o`00000<ooooo`Co00003_ooool2
o`0000?ooooo0_l00007ooooo`?o000000Coooooo`000?l0003o00001?ooool2o`0000;ooooo1?l0
0002ooooo`;o00003_ooool2o`000003ooooool0003o000000?ooooo1?l00008ooooo`Go00001_oo
ool2o`000004ooooool0003o0000o`0001gooooo0_l00002ooooo`Co00003?ooool2o`0000?ooooo
0_l0000looooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00007?ooool2o`0000;ooooo0_l0
000:ooooo`;o00000_ooool2o`000003ooooool0003o000000Oooooo0ol0000>ooooo`;o00001ooo
ool2o`0000Cooooo0_l00006ooooo`;o00000oooool2o`0000[ooooo0_l00009ooooo`;o00000_oo
ool2o`0000?ooooo0_l00005ooooo`;o00001_ooool2o`0000Wooooo0_l00002ooooo`Co00001Ooo
ool2o`0000Gooooo0_l00003ooooo`;o0000??ooool001cooooo00?o0000ooooooooool0@oooool2
o`0000Sooooo1Ol00008ooooo`;o00003?ooool2o`0000?ooooo1?l00006ooooo`;o00000_ooool2
o`0000;ooooo0_l0000;ooooo`;o00001oooool2o`0000kooooo0_l00004ooooo`;o00001_ooool2
o`0000;ooooo0ol0000Nooooo`;o00001Oooool2o`0000Gooooo0ol0000=ooooo`;o00001oooool2
o`0000Gooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00003_ooool4o`00
00;ooooo0ol00002ooooo`Co00001?ooool2o`0000;ooooo0_l0000:ooooo`Co00000oooool2o`00
00Sooooo0_l0000Looooo`;o00001_ooool2o`0000gooooo0_l00005ooooo`Oo00001_ooool2o`00
013ooooo0_l0000Booooo`;o00000oooool2o`0000?ooooo0_l0000?ooooo`;o00000oooool3o`00
043ooooo000Looooo`03o`000?oooooooooo033ooooo0_l000000ooooooo0000o`000009ooooo`Go
000000Coooooo`000?l0003o00000_ooool3o`0000;ooooo0_l00006ooooo`;o00002oooool2o`00
0003ooooool0003o000001cooooo0_l00009ooooo`;o00000_ooool2o`0000Sooooo0_l0000=oooo
o`;o00001_ooool3o`0000Wooooo0_l00005ooooo`;o000000?oooooo`000?l000001_ooool2o`00
01Gooooo1?l00003ooooo`;o00003oooool2o`0000Cooooo0_l00010ooooo`007?ooool00ol0003o
ooooooooo`0`ooooo`;o00002_ooool7o`000003ooooool0003o000000Cooooo0_l00007ooooo`;o
00001oooool2o`0000Gooooo0_l0000Booooo`;o00001Oooool2o`0000Cooooo0_l000000ooooooo
0000o`000004ooooo`Go000000?oooooo`000?l000002oooool3o`0001gooooo0_l00002ooooo`;o
000000Coooooo`000?l0003ooooo1?l000000ooooooo0000o`00000=ooooo`;o00002Oooool2o`00
01Sooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0kooooo`Co000000?oooooo`000?l0
00002?ooool4o`0000?ooooo1?l00002ooooo`;o00000oooool2o`0000;ooooo0_l0000@ooooo`;o
00000oooool2o`0000Gooooo0_l00007ooooo`?o000000?oooooo`000?l000000_l000001?oooooo
0000o`000?ooool2o`0000_ooooo0ol00008ooooo`;o00004oooool2o`0000;ooooo0_l00006oooo
o`;o000000Coooooo`000?l0003ooooo0_l000001?oooooo0000o`000?l00006ooooo`;o00005Ooo
ool4o`0000[ooooo0_l00014ooooo`007?ooool2o`0003Cooooo0_l00006ooooo`;o00003?ooool2
o`000003ooooool0003o000000;o000000?oooooo`000?l000000_l00002ooooo`;o00001?ooool2
o`000004ooooool0003o0000ooooo`;o00001?ooool2o`0000Oooooo0_l0000Dooooo`Go00002Ooo
ool2o`0001?ooooo0_l00003ooooo`;o00000_ooool2o`0001?ooooo0_l00004ooooo`;o000000?o
ooooo`000?l000001?l00006ooooo`;o00003_ooool2o`0000Gooooo1?l0000<ooooo`Go0000?ooo
ool001cooooo00?o0000ooooooooool04oooool2o`0001kooooo0_l00005ooooo`?o00002Oooool2
o`000003ooooool0003o000000?ooooo0_l00003ooooo`;o00002?ooool2o`0000Cooooo0ol00000
0ooooooo0000o`000002o`0000?ooooo0_l0000Dooooo`?o00000oooool2o`0000Sooooo1?l0000:
ooooo`;o00002_ooool4o`0000;ooooo0_l0000Cooooo`;o000000?oooooo`000?l000000_l00004
ooooo`;o00006?ooool2o`0000Kooooo0_l0000;ooooo`Oo0000?oooool001cooooo00?o0000oooo
ooooool04oooool2o`0002;ooooo0_l000001?oooooo0000o`000?l00009ooooo`;o00002_ooool3
o`0000Oooooo0_l00006ooooo`;o000000?oooooo`000?l000000ol00002ooooo`;o00004?ooool7
o`0000gooooo1Ol000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000002_ooool2
o`0001Wooooo0_l000000ooooooo0000o`000004o`0000Cooooo0_l00005ooooo`;o00001?ooool2
o`00017ooooo0_l0000;ooooo`;o000000?oooooo`000?l000001oooool2o`0003Sooooo000Loooo
o`03o`000?oooooooooo03Oooooo1?l0000<ooooo`Co00001_ooool4o`0000Oooooo0_l00007oooo
o`;o00000oooool2o`0001Cooooo1ol00003ooooo`Go00001_ooool4o`000003ooooool0003o0000
00?ooooo0_l00002ooooo`;o00009oooool3o`000003ooooool0003o000000Cooooo0_l00002oooo
o`;o000000?oooooo`000?l000001?ooool2o`0001kooooo0_l00003ooooo`;o00001Oooool4o`00
00Oooooo0_l0000]ooooo`007?ooool00ol0003oooooooooo`0hooooo`?o00003?ooool7o`0000?o
oooo0_l000000ooooooo0000o`00000?ooooo`;o00000oooool2o`0000oooooo0_l0000<ooooo`Ko
00001oooool2o`0000_ooooo0_l0000Booooo`;o00001?ooool4o`0000Kooooo0_l00003ooooo`So
000000?oooooo`000?l000000oooool2o`0001[ooooo0_l0000@ooooo`;o00001oooool2o`0000Oo
oooo0_l0000]ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00001Oooool2o`0000Wooooo
1Ol00002ooooo`;o000000?oooooo`000?l000002_ooool3o`0000Cooooo0_l000000ooooooo0000
o`00000?ooooo`;o00003?ooool2o`0000Gooooo0_l00002ooooo`Co00003Oooool2o`0000?ooooo
0_l0000;ooooo`;o00000oooool7o`0000Cooooo0_l00005ooooo`Wo00000_ooool6o`0001Oooooo
0_l00007ooooo`;o00001?ooool2o`0004;ooooo000Looooo`03o`000?oooooooooo03oooooo0_l0
000<ooooo`;o00000_ooool2o`0000Kooooo0_l000000ooooooo0000o`000002ooooo`?o00001?oo
ool2o`0001_ooooo0_l0000:ooooo`;o00000_ooool4o`0000gooooo0_l00003ooooo`;o00003_oo
ool9o`0000[ooooo5?l0000:ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`Co0000
1Oooool2o`000004ooooool0003o0000ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0
>_ooool2o`0000Gooooo0_l000000ooooooo0000o`00000Cooooo`;o000000?oooooo`000?l00000
0oooool2o`00027ooooo0_l000000ooooooo0000o`000008ooooo`;o000000?oooooo`000?l00000
0_l00003ooooo`;o00006?ooool2o`0000;ooooo2?l00009oooooa?o000000?oooooo`000?l00000
1?l00007ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`Co00002?ooool2o`0000go
oooo1?l00007ooooo`;o0000:oooool001cooooo00?o0000ooooooooool0:?ooool2o`00013ooooo
0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000001oooool5o`0000oooooo
0_l00002ooooo`;o00008?ooool4o`0000Kooooo0_l000000ooooooo0000o`000005ooooo`?o0000
0oooool2o`000003ooooool0003o000000Sooooo0_l00005ooooo`;o00000_ooool7o`0000[ooooo
7?l00004ooooo`;o00002oooool3o`00013ooooo0_l00005ooooo`Co00001oooool2o`0002_ooooo
000Looooo`03o`000?oooooooooo02Sooooo0_l0000?ooooo`;o00000_ooool2o`0000Cooooo0_l0
0008ooooo`Ko00002oooool5o`0000;ooooo0_l00007ooooo`;o00006Oooool2o`0000[ooooo0_l0
0002ooooo`;o000000?oooooo`000?l000000oooool2o`000003ooooool0003o000000Sooooo0_l0
0007ooooo`;o00000_ooool4o`0000?ooooo1_l00002oooooaco00001?ooool2o`0000cooooo0_l0
000@ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0>Oooool2o`000003ooooool0003o
000000Gooooo0_l00003ooooo`;o00000oooool6o`0000;ooooo0_l00007ooooo`Co00003?ooool2
o`0000Kooooo0_l0000Mooooo`;o00000_ooool2o`0000Sooooo0ol00007ooooo`;o00000_ooool2
o`0000Cooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo2?l000000ooooooo0000o`00
000Jo`000003ooooool0003o000000?ooooo0_l00006ooooo`;o00001oooool2o`00017ooooo1?l0
000eooooo`007?ooool00ol0003oooooooooo`0looooo`;o00002_ooool3o`0000?ooooo0ol00000
1?oooooo0000o`000?ooool2o`0001oooooo0_l0000Hooooo`;o00001oooool2o`0000Sooooo1?l0
0006ooooo`;o00000_ooool2o`0000Cooooo1_l000001?oooooo0000o`000?ooool2o`0000Cooooo
8ol00002ooooo`;o00001_ooool5o`0000Cooooo0_l0000Aooooo`Co0000=Oooool001cooooo00?o
0000ooooooooool0<Oooool2o`0001Kooooo0_l00004ooooo`;o000000?oooooo`000?l000001_oo
ool3o`0001Oooooo0ol0000:ooooo`;o00002_ooool5o`0000Oooooo1?l00008ooooo`?o00001?oo
ool4o`0000Cooooo0_l000000ooooooo0000o`000004o`0000_ooooo7ol000001?oooooo0000o`00
0?l00003ooooo`;o00001Oooool5o`0000Gooooo0_l0000?ooooo`;o00002Oooool2o`0002cooooo
000Looooo`03o`000?oooooooooo037ooooo0_l0000Booooo`;o00000oooool2o`0000?ooooo0_l0
00000ooooooo0000o`000003ooooo`;o000000Coooooo`000?l0003o00005oooool3o`0000[ooooo
0_l00005ooooo`;o00000oooool6o`0000Cooooo1_l00009ooooo`;o00001?ooool4o`0000;ooooo
1?l00006ooooo`;o00000_ooool2o`0000?ooooo0_l00003oooooaco00000oooool2o`0000?ooooo
0_l00008ooooo`;o00001Oooool2o`0000cooooo0_l000000ooooooo0000o`000009ooooo`;o0000
;?ooool001cooooo00?o0000ooooooooool0;oooool2o`0000oooooo0_l00003ooooo`;o00000ooo
ool2o`0000_ooooo0_l00003ooooo`;o00006Oooool2o`0000Sooooo0_l00005ooooo`;o00001ooo
ool4o`0000;ooooo1_l0000Eooooo`Co00001_ooool2o`0000;ooooo0_l00003ooooo`;o00000_oo
oolMo`000004ooooool0003o0000o`0000;ooooo0_l00004ooooo`;o00006Oooool2o`0003[ooooo
000Looooo`03o`000?oooooooooo02oooooo0_l00003ooooo`;o00002_ooool2o`0000;ooooo0_l0
0004ooooo`;o00004?ooool2o`0001?ooooo0_l00002ooooo`Co00001_ooool4o`0000;ooooo0_l0
000<ooooo`;o00001_ooool4o`0000Oooooo0_l0000<ooooo`;o00003?ooool2o`0000Cooooo3?l0
0002oooooaGo000000?oooooo`000?l000001?ooool2o`0000;ooooo0_l00007ooooo`;o00000ooo
ool3o`0000Wooooo0_l0000gooooo`007?ooool2o`0001Cooooo0_l0000Oooooo`;o00002_ooool2
o`0000;ooooo0_l0000Cooooo`;o00004_ooool2o`0000;ooooo2?l00006ooooo`?o00000oooool2
o`0000kooooo0_l00005ooooo`Co00001_ooool2o`0000gooooo0_l0000;ooooo`;o00000oooool>
o`000003ooooool0003o000001?o00000oooool2o`0000Cooooo1?l00007ooooo`;o00000oooool3
o`0000Wooooo0_l000000ooooooo0000o`00000dooooo`007?ooool00ol0003oooooooooo`0Coooo
o`;o0000:?ooool2o`000003ooooool0003o000000gooooo0_l000000ooooooo0000o`000005oooo
o`;o00004_ooool2o`0000Cooooo1?l00009ooooo`;o00003?ooool3o`0000Cooooo0_l00005oooo
o`Co00004_ooool7o`0000Kooooo0_l000001?oooooo0000o`000?l00002ooooobKo000000?ooooo
o`000?l000001?ooool4o`0000Kooooo0ol0000:ooooo`;o00001Oooool3o`0003Cooooo000Loooo
o`03o`000?oooooooooo037ooooo0_l0000:ooooo`?o00001oooool2o`0000Cooooo1?l000000ooo
oooo0000o`000002ooooo`;o000000?oooooo`000?l000003Oooool2o`0000?ooooo0_l00006oooo
o`Co00002oooool7o`0000?ooooo0ol0000?ooooo`;o00003oooool4o`0000;ooooo0_l00006oooo
o`?o000000?oooooo`000?l000000_oooolNo`0000;ooooo1_l000000ooooooo0000o`000006oooo
o`;o00000_ooool2o`0000;ooooo0_l0000:ooooo`Co00001?ooool2o`0003Gooooo000Looooo`03
o`000?oooooooooo037ooooo0_l0000;ooooo`;o00001oooool2o`0000Cooooo1?l000000ooooooo
0000o`000002ooooo`;o000000?oooooo`000?l000003Oooool3o`0000Oooooo0_l00003ooooo`co
000000?oooooo`000?l000001_l0000;ooooo`;o00001oooool2o`0000oooooo0_l0000=ooooo`;o
00001OoooolJo`000003ooooool0003o000000Go00004Oooool2o`0000kooooo1_l0000iooooo`00
7?ooool00ol0003oooooooooo`0hooooo`Co00000oooool2o`0000Gooooo1?l00002ooooo`;o0000
00?oooooo`000?l000005oooool3o`0000;ooooo0_l00002ooooo`?o00001?ooool<o`0000;ooooo
2Ol00008ooooo`;o00001oooool3o`0002Cooooo0_l00002oooooago00002oooool2o`0001Wooooo
0_l00004ooooo`;o0000<oooool001cooooo00?o0000ooooooooool0>?ooool4o`0000?ooooo0ol0
0004ooooo`Co00000_ooool3o`0000;ooooo0_l0000Eooooo`?o00000_ooool2o`0000;ooooo1Ol0
0003ooooo`;o000000?oooooo`000?l000000ol000000ooooooo0000o`000002ooooo`Co000000?o
ooooo`000?l000001?l0000?ooooo`Oo00001Oooool4o`0000?ooooo0ol0000Aooooo`;o00000_oo
oolLo`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l000005_ooool2o`0000Oooooo0_l0
000cooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00003Oooool3o`0000Kooooo0_l00002
ooooo`?o00000_ooool2o`0000Gooooo0_l00009ooooo`;o00003Oooool4o`0000;ooooo2Ol00002
ooooo`Oo00001Oooool2o`0000oooooo0_l000000ooooooo0000o`000002o`0000Gooooo1?l00003
ooooo`?o00005OoooolHo`0000Wooooo0_l00002ooooo`Co00002Oooool2o`0000_ooooo0ol0000l
ooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00003Oooool3o`0000Kooooo0_l00002oooo
o`;o00002_ooool3o`0000Sooooo0_l0000=ooooo`co00001Oooool8o`0000;ooooo0_l000000ooo
oooo0000o`00000Booooo`;o00001Oooool2o`0000;ooooo0_l00005ooooo`;o00001Oooool2o`00
00?ooooo0_l00006oooooaWo00002Oooool2o`0000Cooooo0_l00009ooooo`;o000000?oooooo`00
0?l000002?ooool2o`0003gooooo000Looooo`03o`000?oooooooooo03Wooooo0_l00005ooooo`;o
00001_ooool2o`0000oooooo0_l0000Aooooo`;o000000Coooooo`000?l0003o00000oooool:o`00
00;ooooo0_l00003ooooo`Go00000_ooool2o`000003ooooool0003o000000Gooooo0_l0000Boooo
o`;o00000_ooool2o`0000Cooooo0ol00005ooooo`;o00000oooool2o`0000Cooooo1?l00002oooo
oaGo00002Oooool2o`0000[ooooo0_l00006ooooo`;o00000_ooool5o`00043ooooo000Looooo`03
o`000?oooooooooo02Kooooo0_l0000Aooooo`;o00003Oooool2o`0002;ooooo0_l000000ooooooo
0000o`000003o`0000?ooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000?o
00000oooool5o`0000?ooooo0_l00005ooooo`;o00002Oooool2o`0000Sooooo0_l00007ooooo`;o
00000oooool2o`0000Wooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00002ooooo`;o
00000_ooool8o`0000cooooo0_l00003ooooo`;o00001oooool2o`0000[ooooo1Ol000000ooooooo
0000o`000007ooooo`Co0000<_ooool001cooooo00?o0000ooooooooool09_ooool2o`0002_ooooo
1?l0000?ooooo`;o00001oooool;o`000003ooooool0003o000000So000000?oooooo`000?l00000
1Ol000000ooooooo0000o`000002o`0000cooooo0ol000000ooooooo0000o`000008ooooo`;o0000
1?ooool2o`0000Kooooo1?l00002ooooo`?o00000_ooool2o`0000Oooooo1?l00004ooooo`Co0000
2_ooool2o`0000;ooooo1?l00003ooooo`;o000000?oooooo`000?l000005_ooool2o`0000Kooooo
1Ol0000booooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00003_ooool2o`000003ooooool0
003o000000Cooooo0_l0000<ooooo`Co00003oooool2o`0000Cooooo0_l00002ooooo`;o000000?o
ooooo`000?l000004?l000000ooooooo0000o`000008o`0000kooooo1Ol0000?ooooo`;o00002?oo
ool2o`0000;ooooo0ol00002ooooo`;o000000?oooooo`000?l000001Oooool3o`0000Kooooo0_l0
000:ooooo`So00001_ooool2o`0001Wooooo0_l00003ooooo`;o0000=Oooool001cooooo00?o0000
ooooooooool0;?ooool2o`0000kooooo1Ol00004ooooo`;o00002oooool3o`0000oooooo0_l00006
ooooo`?o00001?oooolNo`0000_ooooo0_l00003ooooo`;o00001Oooool2o`0001Oooooo0_l00005
ooooo`;o00001Oooool2o`000003ooooool0003o000000Wooooo0_l000000ooooooo0000o`000003
ooooo`Co000000?oooooo`000?l000001_ooool2o`0000Sooooo0ol00005ooooo`;o00001oooool2
o`0000Cooooo0_l0000dooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00001Oooool2o`00
01;ooooo0ol0000@ooooo`;o00001oooool5o`0000?ooooo8?l00006ooooo`?o00002_ooool2o`00
02Sooooo0_l00009ooooo`;o000000?oooooo`000?l000004?ooool2o`0000Sooooo1?l00004oooo
o`;o00003Oooool2o`0003Cooooo000Looooo`03o`000?oooooooooo03?ooooo0_l000000ooooooo
0000o`00000Cooooo`;o000000Coooooo`000?l0003ooooo0ol0000Eooooo`;o000000?oooooo`00
0?l000009ol000001?oooooo0000o`000?l00002ooooo`;o000000?oooooo`000?l000000_l00006
ooooo`;o00001oooool2o`0002;ooooo0_l00009ooooo`;o00001?ooool2o`0000Oooooo0_l00002
ooooo`;o00002Oooool2o`0000gooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`0coooo
o`;o00001Oooool2o`0000;ooooo0ol0000:ooooo`Go00000_ooool4o`0000Sooooo0_l000000ooo
oooo0000o`000006ooooo`Oo000000?oooooo`000?l000007Ol000001?oooooo0000o`000?ooool7
o`0000?ooooo1?l0000?ooooo`;o00000oooool4o`0000[ooooo0_l0000?ooooo`;o00001Oooool2
o`0000;ooooo0_l00004ooooo`;o00001oooool6o`0001;ooooo0_l00004ooooo`?o0000>Oooool0
01cooooo0_l0000booooo`Co00001?ooool3o`0000;ooooo0ol00006ooooo`;o00001?ooool3o`00
00?ooooo0ol00007ooooo`Ko00001Oooool8o`000003ooooool0003o000000So000000?oooooo`00
0?l000005Ol000000ooooooo0000o`000005o`0000Wooooo0_l0000>ooooo`Ko00001?ooool2o`00
00Cooooo0ol00009ooooo`;o00002_ooool2o`000003ooooool0003o000000Gooooo0_l000000ooo
oooo0000o`000006ooooo`?o00002Oooool2o`0000Sooooo0_l00005ooooo`;o0000>Oooool001co
oooo00?o0000ooooooooool09Oooool2o`0000[ooooo1?l00002ooooo`Co00003?ooool2o`0000Go
oooo0_l00003ooooo`;o00002?ooool2o`000003ooooool0003o000000;o00001?ooool4o`0000;o
oooo5ol000000ooooooo0000o`00000;o`000003ooooool0003o000000?o00001oooool2o`0000;o
oooo0_l0000>ooooo`;o00002?ooool2o`0000Gooooo0ol00008ooooo`?o00002?ooool2o`0000;o
oooo0_l00008ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Wooooo0_l000000ooooooo
0000o`000002o`0001Cooooo0_l0000_ooooo`007?ooool00ol0003oooooooooo`0Iooooo`;o0000
2_ooool2o`00013ooooo0_l00007ooooo`Co00006Oooool2o`0000;ooooo0ol00002ooooo`Co0000
1?oooolXo`000003ooooool0003o000000Oooooo0_l000000ooooooo0000o`00000;ooooo`?o0000
2Oooool4o`0000Kooooo0_l00009ooooo`;o00002?ooool4o`0000gooooo0_l00003ooooo`;o0000
1?ooool2o`0000Oooooo1?l0000@ooooo`;o00000_ooool2o`0002oooooo000Looooo`03o`000?oo
oooooooo01Wooooo0_l00008ooooo`;o00006oooool4o`0000_ooooo0_l0000Eooooo`;o00000ooo
ool6o`000003ooooool0003o000001co00000_ooool4o`000003ooooool0003o000000Wooooo1Ol0
0009ooooo`?o00002Oooool2o`0000Sooooo0_l00005ooooo`;o000000?oooooo`000?l000000ol0
0008ooooo`;o00000_ooool3o`0000gooooo0_l00004ooooo`;o00004_ooool2o`0000Oooooo1?l0
000aooooo`007?ooool00ol0003oooooooooo`0Sooooo`;o00006oooool2o`0000gooooo0_l0000<
ooooo`;o00000_ooool2o`0000;ooooo0_l00002ooooob;o000000?oooooo`000?l000001ol00003
ooooo`;o00002?ooool2o`000003ooooool0003o0000013ooooo0_l00002ooooo`;o00002Oooool2
o`0000Gooooo0_l000001?oooooo0000o`000?ooool2o`0000cooooo0ol00005ooooo`;o00001_oo
ool2o`0000gooooo0_l00009ooooo`;o00002Oooool2o`00037ooooo000Looooo`03o`000?oooooo
oooo043ooooo0_l00008ooooo`;o00004Oooool2o`0000;ooooo0_l00002ooooob[o000000?ooooo
o`000?l000001?l000000ooooooo0000o`000002o`0000?ooooo0_l000001?oooooo0000o`000?oo
ool2o`0000?ooooo0_l0000<ooooo`;o000000?oooooo`000?l000000_l00008ooooo`;o00003ooo
ool2o`00013ooooo0_l00006ooooo`;o00002oooool4o`0000Wooooo0_l0000looooo`007?ooool0
0ol0003oooooooooo`0Rooooo`;o00003oooool3o`0000Cooooo1?l0000<ooooo`;o00001Oooool2
o`0000gooooo0_l00004ooooocKo00000_ooool2o`000004ooooool0003o0000ooooo`;o000000?o
ooooo`000?l000000_l00002ooooo`;o00000oooool2o`0000Kooooo1?l00009ooooo`;o00003_oo
ool2o`0000Wooooo0_l00009ooooo`;o00000_ooool2o`0000Cooooo0ol00004ooooo`;o00001ooo
ool2o`00043ooooo000Looooo`03o`000?oooooooooo02;ooooo0_l0000?ooooo`?o00001?ooool4
o`000003ooooool0003o0000013ooooo0_l0000=ooooo`;o00001?oooolfo`0000Wooooo1?l00004
ooooo`?o00000_ooool4o`00013ooooo0ol0000Fooooo`;o000000?oooooo`000?l000000oooool2
o`0000;ooooo1?l00002ooooo`;o00001?ooool3o`0000gooooo0_l00010ooooo`007?ooool00ol0
003oooooooooo`0Uooooo`;o00002oooool2o`0000Sooooo0_l000000ooooooo0000o`000006oooo
o`;o00002?ooool2o`0000Gooooo0_l00005ooooo`;o00001OoooolIo`000003ooooool0003o0000
00Wo000000?oooooo`000?l000001ol000000ooooooo0000o`000003ooooo`Co00001Oooool3o`00
00Oooooo0_l00004ooooo`;o00002?ooool3o`000003ooooool0003o000000;ooooo0_l00002oooo
o`Co00000oooool2o`0000Gooooo0_l00005ooooo`;o00001_ooool3o`000003ooooool0003o0000
00;o00005?ooool2o`0000Cooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0Uooooo`;o
00002oooool2o`0000Sooooo0_l00009ooooo`;o00003oooool2o`0000Gooooo0_l00005ooooobgo
000000?oooooo`000?l000000_l00003ooooo`Co00001Oooool2o`000003ooooool0003o000000Go
oooo0_l00004ooooo`;o00002?ooool3o`000003ooooool0003o000000Kooooo1?l00003ooooo`Co
00000oooool2o`0000Gooooo1?l00004ooooo`?o00000oooool3o`0000Wooooo0_l00002ooooo`;o
00001?ooool2o`0000Cooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0fooooo`;o0000
1oooool2o`0000Cooooo0_l0000;ooooo`;o00004_ooool7o`000003ooooool0003o000002Ko0000
4Oooool2o`0000_ooooo0_l00006ooooo`;o00004?ooool2o`0000?ooooo0_l00002ooooo`;o0000
2?ooool3o`0000?ooooo0ol00003ooooo`?o00001?ooool2o`0000?ooooo0_l00002ooooo`;o0000
3?ooool2o`0003cooooo000Looooo`03o`000?oooooooooo01oooooo0_l0000Eooooo`;o00000_oo
ool4o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000002o`0000Gooooo0ol0
000Gooooo`;o000000?oooooo`000?l00000:_l0000Dooooo`;o00003?ooool2o`0000Kooooo0_l0
0008ooooo`;o00001oooool2o`0000Wooooo0_l00004ooooo`;o00000oooool2o`0000Gooooo0_l0
0002ooooo`;o00002_ooool2o`0000Gooooo0_l0000looooo`007?ooool00ol0003oooooooooo`0O
ooooo`;o00006Oooool4o`0000Cooooo0_l00004ooooo`Co00001Oooool2o`0001Kooooo1Ol00000
0ooooooo0000o`00000:o`0000;ooooo7Ol0000Dooooo`;o00002?ooool2o`0000[ooooo0ol00007
ooooo`;o00005_ooool4o`0000kooooo0_l00002ooooo`Co00001?ooool2o`000003ooooool0003o
000000?ooooo0_l000000ooooooo0000o`00000hooooo`007?ooool00ol0003oooooooooo`0loooo
o`;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00006_oooolBo`00
00;ooooo5ol000001?oooooo0000o`000?l0000Cooooo`;o000000?oooooo`000?l000002?ooool5
o`0000Cooooo1_l00004ooooo`;o000000?oooooo`000?l000001oooool2o`0000gooooo0_l0000@
ooooo`;o00000_ooool4o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`;o000000?ooooo
o`000?l00000>?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Go
k^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo03[ooooo1?l00008ooooo`;o0000
00Goooooo`000?l0003o0000ooooo`02o`0001Oooooo0_l00002ooooob3o000000?oooooo`000?l0
00001ol000001?oooooo0000o`000?l0000<ooooo`;o00001Oooool2o`0000?ooooo0_l00007oooo
o`Co000000Coooooo`000?l0003ooooo1?l00006ooooo`;o00000_ooool2o`0000Kooooo0_l0000O
ooooo`;o00002_ooool2o`0004?ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ
8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0fooooo`;o0000
0_ooool2o`0000Cooooo0_l00007ooooo`?o00000_ooool2o`0001Kooooo0_l00003ooooo`Oo0000
00?oooooo`000?l000006Ol000000ooooooo0000o`000002o`000003ooooool0003o000000Go0000
2Oooool2o`0000[ooooo0_l00003ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`;o0000
2oooool2o`0001gooooo0_l0000Dooooo`;o0000@oooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
=_ooool2o`0000Sooooo0_l000000ooooooo0000o`000009ooooo`;o000000?oooooo`000?l00000
2oooool2o`0000[ooooo0ol00002oooooa3o000000?oooooo`000?l000004Ol000000ooooooo0000
o`000005o`0000Wooooo0_l00003ooooo`;o00002_ooool2o`000003ooooool0003o000000Co0000
4Oooool2o`0001gooooo0_l0000Dooooo`;o0000@oooool00003ooooool0003ooooo00;ooooo00?o
0000ooooooooool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol00013ooooo`;o0000
3?ooool2o`0000Cooooo0_l00005ooooo`;o00002_ooool4o`0000;ooooo1Ol00002oooooaoo0000
00Goooooo`000?l0003o0000ooooo`04o`0000[ooooo0_l0000=ooooo`;o00000_ooool2o`0000oo
oooo1?l0000dooooo`;o0000@_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
2Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0=_ooool2o`0000Co
oooo0_l00009ooooo`;o00003_ooool2o`0000Gooooo0_l0000:ooooobco00000_ooool2o`000003
ooooool0003o000000;o00003_ooool2o`0000gooooo0_l00002ooooo`;o00002oooool4o`0002_o
oooo0_l00002ooooo`;o00000oooool3o`00047ooooo00000ooooooo410@ooooo`02ooooo`03oa0@
4?oooooooooo00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`0Yooooo`;o0000
2oooool3o`0000?ooooo1?l00004ooooo`;o000000?oooooo`000?l000000_l0000Cooooo`;o0000
2oooool2o`000003ooooool0003o0000023o00000_ooool4o`000003ooooool0003o000000;ooooo
2_l00004ooooo`?o000000?oooooo`000?l000003Oooool2o`0000;ooooo0_l000000ooooooo0000
o`000008ooooo`;o00000_ooool2o`0000Cooooo0_l0000Sooooo`;o00000_ooool3o`0000?ooooo
0_l000000ooooooo0000o`00000nooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03
omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0:Oooool2o`0000cooooo0_l00005ooooo`;o
00001?ooool2o`0000?ooooo0_l0000Qooooo`;o000000?oooooo`000?l000004Ol000000ooooooo
0000o`00000=o`000003ooooool0003o000000Co000000?oooooo`000?l000002Ol00004ooooo`Co
00003?ooool2o`0000Sooooo0_l00004ooooo`;o00001_ooool2o`0000Cooooo0_l0000<ooooo`?o
00002_ooool2o`0000gooooo0_l00006ooooo`;o0000?_ooool00006ooooooo^k^ko<S8bo`000?lb
<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo03kooooo0ol00002
ooooo`;o00001oooool2o`0000oooooo0_l00006ooooo`Co00000oooool2o`000005ooooool0003o
0000o`000?ooool01?l00002ooooob?o00000_ooool2o`0000Oooooo0_l00002ooooo`;o00003?oo
ool2o`0000kooooo0_l0000<ooooo`;o00002_ooool5o`0000Cooooo0_l00003ooooo`?o00001?oo
ool2o`0004oooooo000Looooo`03o`000?oooooooooo027ooooo0_l000000ooooooo0000o`00000I
ooooo`?o000000Coooooo`000?l0003o00001_ooool4o`0000Gooooo0_l00003ooooo`;o000000?o
ooooo`000?l000001_ooool8o`0000?ooooo1?l000001?oooooo0000o`000?oooolKo`0000;ooooo
1ol00004ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo1_l00004ooooo`;o0000
0_ooool2o`0000Oooooo0_l0000Cooooo`;o00002_ooool2o`0000Oooooo0_l00003ooooo`;o0000
1Oooool4o`0000[ooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0Qooooo`;o000000?o
ooooo`000?l000005?ooool2o`0000?ooooo0ol00002ooooo`;o00002?ooool2o`0000Gooooo0_l0
0003ooooo`;o000000?oooooo`000?l000002_ooool6o`0000?ooooo0_l00004oooooa3o000000?o
ooooo`000?l000002?l00003ooooo`;o000000Goooooo`000?l0003o0000ooooo`08o`0000;ooooo
2ol000000ooooooo0000o`000002o`0000_ooooo0_l0000@ooooo`;o00001_ooool2o`0000Sooooo
0_l00007ooooo`Co00001oooool2o`0000[ooooo0_l00003ooooo`;o00002Oooool2o`00037ooooo
000Looooo`03o`000?oooooooooo03[ooooo0_l0000Aooooo`;o00006_ooool2o`000005ooooool0
003o0000o`000?ooool00_l00002ooooo`;o00000_ooool9o`000003ooooool0003o000000Co0000
00?oooooo`000?l000002?l00002ooooo`Co00001?ooool7o`0000;ooooo0_l000000ooooooo0000
o`000007o`000004ooooool0003o0000o`0000;ooooo0_l0000<ooooo`?o00001oooool2o`0000;o
oooo0_l000000ooooooo0000o`000003ooooo`Go00001Oooool2o`0000Oooooo1?l00002ooooo`Co
00004_ooool2o`0000Wooooo0_l0000aooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o0000
0_ooool4o`0000Sooooo0_l00003ooooo`?o00000oooool3o`000003ooooool0003o000000;ooooo
2Ol000000ooooooo0000o`000004o`0000?ooooo2?l00004ooooo`;o00000_ooool6o`0000?ooooo
0_l00002ooooo`;o00000oooool3o`000003ooooool0003o000000co000000?oooooo`000?l00000
0ol00009ooooo`?o00000oooool2o`0000;ooooo0_l00005ooooo`;o00001?ooool4o`0001Cooooo
1?l000000ooooooo0000o`000002o`0004_ooooo000Looooo`03o`000?oooooooooo057ooooo1?l0
0008ooooo`;o00000oooool3o`0000?ooooo0_l00005ooooo`Ko000000Goooooo`000?l0003o0000
ooooo`02o`0000;ooooo1?l00002ooooo`;o00000_ooool2o`0000;ooooo1?l00002ooooo`Co0000
00?oooooo`000?l000001ol00003ooooo`Co000000?oooooo`000?l000005_l00009ooooo`;o0000
00Coooooo`000?l0003ooooo0_l00005ooooo`;o00001oooool2o`0001Cooooo2Ol0001;ooooo`00
7?ooool00ol0003oooooooooo`11ooooo`;o00001_ooool5o`0000Cooooo0_l00005ooooo`;o0000
1?ooool2o`0000?ooooo0_l00009ooooo`Ko00000_ooool2o`000003ooooool0003o000000;ooooo
1Ol000001?oooooo0000o`000?l00005ooooo`Co00000_ooool6o`000004ooooool0003o0000o`00
00;ooooo0_l00003oooooago00002?ooool3o`0000Cooooo0_l00005ooooo`;o00001oooool2o`00
01Cooooo0_l000000ooooooo0000o`000002ooooo`;o0000Boooool001cooooo00?o0000oooooooo
ool0@Oooool2o`0000Kooooo1Ol00004ooooo`;o00001Oooool2o`0000Cooooo0_l00003ooooo`;o
00002Oooool6o`0000;ooooo0_l000000ooooooo0000o`000003o`0000;ooooo0_l000001Ooooooo
0000o`000?l0003ooooo00Co000000?oooooo`000?l000001?ooool2o`000003ooooool0003o0000
00?ooooo0_l00005ooooo`So00001?oooolBo`0000;ooooo0_l00004ooooo`?o000000?oooooo`00
0?l000004_ooool3o`0000Sooooo0_l00008ooooo`;o00000_ooool2o`000003ooooool0003o0000
04_ooooo000Looooo`03o`000?oooooooooo03;ooooo0_l0000Eooooo`;o00001oooool2o`0000Go
oooo0_l0000Booooo`Co00001?ooool2o`0000Gooooo1Ol000001?oooooo0000o`000?ooool2o`00
0003ooooool0003o000000;o000000?oooooo`000?l000001?ooool3o`0000Gooooo0_l00005oooo
o`?o000000?oooooo`000?l000000ol000000ooooooo0000o`00000Bo`000005ooooool0003o0000
o`000?ooool00_l00005ooooo`;o00000_ooool3o`0000cooooo1?l00008ooooo`;o00002?ooool2
o`0000;ooooo1?l0001<ooooo`007?ooool00ol0003oooooooooo`0booooo`;o00009?ooool3o`00
01;ooooo0_l00002ooooo`Ko00001Oooool2o`000003ooooool0003o000000?o000000Goooooo`00
0?l0003o0000ooooo`04o`0000;ooooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l00006
ooooo`Co000000?oooooo`000?l000006ol000001?oooooo0000o`000?l00008ooooo`?o00003?oo
ool6o`00013ooooo0_l00004ooooo`;o00000_ooool2o`0004Sooooo000Looooo`03o`000?oooooo
oooo02oooooo0_l0000Dooooo`;o00004Oooool2o`0001Kooooo1Ol0000<ooooo`;o00000oooool2
o`000003ooooool0003o000000;o00000_ooool2o`000003ooooool0003o000000?o00000oooool2
o`0000Sooooo0_l000000ooooooo0000o`00000Ho`0000Gooooo0_l00009ooooo`;o00002?ooool2
o`0000Cooooo1?l00003ooooo`;o00000_ooool2o`0000Gooooo0_l000000ooooooo0000o`000002
o`0000Gooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00005?ooool2o`00
00?ooooo0_l0000:ooooo`Ko00003Oooool2o`000003ooooool0003o000000Co00006Oooool2o`00
00?ooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l00002ooooo`;o00000oooool3o`00
0003ooooool0003o000001So00000_ooool3o`000003ooooool0003o000000cooooo0_l00004oooo
o`;o00001Oooool3o`0000?ooooo0_l00002ooooo`;o00001?ooool3o`000003ooooool0003o0000
00;o0000Coooool001cooooo0_l00016ooooo`;o00000oooool2o`0000[ooooo0_l00002ooooo`;o
00003Oooool2o`000003ooooool0003o000000Go00006?ooool4o`000004ooooool0003o0000oooo
o`?o000000?oooooo`000?l000001Oooool2o`0000?ooooo0_l000000ooooooo0000o`00000Co`00
0003ooooool0003o000000Co000000Goooooo`000?l0003o0000ooooo`02o`0000Sooooo0_l00002
ooooo`;o00002oooool3o`0000gooooo0_l0000Aooooo`;o0000@_ooool001cooooo00?o0000oooo
ooooool0AOooool2o`00017ooooo0_l0000Eooooo`Co00001_ooool2o`0000?ooooo0_l0000=oooo
o`;o00001Oooool2o`000003ooooool0003o000000_ooooo8?l00003ooooo`Ko00001?ooool2o`00
00;ooooo0ol0000:ooooo`;o00004Oooool4o`0000cooooo0_l00012ooooo`007?ooool00ol0003o
ooooooooo`18ooooo`;o00002Oooool2o`0000?ooooo0_l0000Oooooo`;o00000oooool2o`00017o
oooo0_l0000=ooooo`;o00000_ooool2o`000003ooooool0003o000001_o00000oooool6o`0000So
oooo0ol000001?oooooo0000o`000?l00008ooooo`;o00003oooool6o`0000[ooooo0_l00012oooo
o`007?ooool00ol0003oooooooooo`18ooooo`;o00002Oooool2o`0002?ooooo0_l000000ooooooo
0000o`000002o`0000Sooooo0_l00008ooooo`;o00003Oooool2o`0000Kooooo8?l00005ooooo`;o
00000_ooool2o`0000Gooooo1?l00002ooooo`;o00000oooool4o`0000Gooooo0_l00009ooooo`Co
00002_ooool2o`0004;ooooo000Looooo`03o`000?oooooooooo033ooooo0_l0000;ooooo`;o0000
5oooool2o`0000Cooooo0_l00004ooooo`;o00002?ooool2o`0000[ooooo0_l000000ooooooo0000
o`000002o`0000?ooooo0_l00003ooooo`;o00005oooool2o`0000Kooooo3?l000000ooooooo0000
o`00000Eo`000003ooooool0003o000000;ooooo0_l00005ooooo`;o00001?ooool2o`0000?ooooo
1?l00005ooooo`?o00002?ooool3o`0004oooooo000Looooo`03o`000?oooooooooo033ooooo0_l0
000;ooooo`;o00001oooool2o`0000kooooo0_l000001?oooooo0000o`000?ooool5o`000003oooo
ool0003o000000Sooooo0_l00003ooooo`;o00003Oooool4o`0000kooooo0_l00005ooooo`;o0000
1Oooool2o`0000;ooooo0_l000000ooooooo0000o`00000Bo`000003ooooool0003o000000ko0000
1Oooool2o`0001Cooooo0_l00004ooooo`;o00000oooool3o`0005Cooooo000Looooo`03o`000?oo
oooooooo03Oooooo0_l00006ooooo`;o00001Oooool2o`00017ooooo0_l00003ooooo`?o00001Ooo
ool2o`0000Wooooo1?l0000:ooooo`Go00003_ooool2o`0000Gooooo0_l00009ooooo`;o000000?o
ooooo`000?l000007_l00002ooooo`;o00001_ooool2o`0001Cooooo1Ol00006ooooo`?o00002_oo
ool2o`0004Sooooo000Looooo`03o`000?oooooooooo03Oooooo0_l00005ooooo`?o00001oooool2
o`0000oooooo0_l0000;ooooo`;o00001_ooool2o`0000?ooooo0_l0000:ooooo`Go00002?ooool2
o`0000oooooo1?l00006oooooako00001?ooool2o`0000;ooooo0_l0000Cooooo`;o00001Oooool3
o`0001?ooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00002?ooool2o`00
0003ooooool0003o000001kooooo0_l000000ooooooo0000o`000009ooooo`;o00002_ooool2o`00
00Gooooo0_l00003ooooo`;o00002_ooool4o`0000Oooooo7_l00007ooooo`;o00004oooool2o`00
01_ooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00001_ooool2o`000003
ooooool0003o000000cooooo0_l0000@ooooo`;o000000?oooooo`000?l000002Oooool2o`0000[o
oooo1Ol00002ooooo`?o00000_ooool2o`0001Gooooo2_l000000ooooooo0000o`00000Ao`0000Oo
oooo0_l00004ooooo`;o00004Oooool2o`0001;ooooo1?l0001;ooooo`007?ooool00ol0003ooooo
ooooo`10ooooo`;o00004_ooool2o`0000?ooooo0_l0000?ooooo`Co00002Oooool2o`000003oooo
ool0003o000000_ooooo0ol00003ooooo`;o00004Oooool4o`0000Cooooo0_l00002ooooo`Ko0000
00?oooooo`000?l000004?l000001?oooooo0000o`000?l0000:ooooo`;o00001oooool2o`0000So
oooo0_l0000Booooo`Co0000Boooool001cooooo00?o0000ooooooooool0E?ooool2o`0001;ooooo
1_l00005ooooo`;o00000_ooool2o`000003ooooool0003o000000Cooooo0_l0000Nooooo`Co0000
1?ooool2o`0000;ooooo2Ol000000ooooooo0000o`00000=o`000004ooooool0003o0000o`00013o
oooo0_l000001?oooooo0000o`000?ooool2o`0006Sooooo000Looooo`03o`000?oooooooooo05;o
oooo0ol0000Cooooo`;o00002Oooool2o`0000_ooooo0_l0000Pooooo`;o00001?ooool2o`0000;o
oooo3?l000000ooooooo0000o`00000;o`000003ooooool0003o0000013ooooo0_l00004ooooo`;o
00002oooool4o`0005Wooooo000Looooo`03o`000?oooooooooo053ooooo1Ol00006ooooo`;o0000
1oooool2o`0000?ooooo0_l0000gooooo`;o00001?ooool4o`000003ooooool0003o000001Oo0000
0oooool2o`000003ooooool0003o000000cooooo0_l000000ooooooo0000o`000002o`000003oooo
ool0003o000000Sooooo1?l00006ooooo`;o0000DOooool001cooooo00?o0000ooooooooool0@Ooo
ool2o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l000000oooool2o`0000Cooooo0_l0
0002ooooo`;o00000oooool2o`0000;ooooo0ol0000moooooa[o00001Oooool4o`000003ooooool0
003o000000Co00002?ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000002?oo
ool2o`0000Sooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`11ooooo`;o00001?ooool2
o`0000Cooooo0_l00006ooooo`;o00000oooool2o`0000?ooooo0_l00007ooooo`Co00002?ooool2
o`0003;ooooo0_l00002ooooo`Go00001?ooool>o`0000Cooooo1Ol00002ooooo`Go00001oooool2
o`000003ooooool0003o000001?ooooo0_l0001Eooooo`007?ooool2o`0004Wooooo0_l00003oooo
o`;o00002oooool2o`0000;ooooo0_l00009ooooo`?o00002?ooool2o`0000Wooooo0_l0000Xoooo
o`;o00001?ooool3o`000003ooooool0003o000000_o000000?oooooo`000?l000000_ooool2o`00
00;ooooo0ol00005ooooo`;o00001_ooool3o`000003ooooool0003o000001?ooooo1?l0001Coooo
o`007?ooool00ol0003oooooooooo`0mooooo`;o00001?ooool2o`0000?ooooo0_l00003ooooo`;o
00001Oooool2o`0000Gooooo0_l000000ooooooo0000o`000009ooooo`;o00005?ooool2o`0002So
oooo0_l00005ooooo`Ko000000?oooooo`000?l000002Ol00003ooooo`Co000000?oooooo`000?l0
00003?ooool3o`000003ooooool0003o000001Gooooo0ol0001Cooooo`007?ooool00ol0003ooooo
ooooo`0mooooo`;o00001?ooool2o`0000oooooo0_l00005ooooo`;o00000_ooool6o`0000;ooooo
0_l0000Dooooo`;o000000?oooooo`000?l00000<?ooool;o`000003ooooool0003o000000;o0000
1Oooool2o`000003ooooool0003o000000cooooo0_l00002ooooo`;o00003?ooool2o`0000Oooooo
0_l00004ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0E?ooool2o`0000;ooooo0_l0
0005ooooo`Ko00000_ooool3o`0001?ooooo0_l000000ooooooo0000o`00000Zooooo`;o00001_oo
ool3o`000003ooooool0003o000000?o00000oooool2o`0002?ooooo0_l00003ooooo`;o00000_oo
ool4o`0000Cooooo0_l000000ooooooo0000o`00001>ooooo`007?ooool00ol0003oooooooooo`1@
ooooo`;o00001Oooool3o`0000;ooooo1Ol00007ooooo`Go0000<oooool2o`0000[ooooo0_l0000;
ooooo`Go00000_ooool2o`0000Kooooo0ol00005ooooo`;o00004oooool2o`0000Oooooo1?l00004
ooooo`;o0000DOooool001cooooo00?o0000ooooooooool0D?ooool2o`0000Gooooo0_l00003oooo
o`?o00001oooool2o`0000;ooooo0ol00006ooooo`;o0000:oooool2o`0000?ooooo0_l0000@oooo
o`Co000000?oooooo`000?l000001oooool2o`000005ooooool0003o0000o`000?ooool00_l00002
ooooo`Ko00004?ooool2o`0000Cooooo0_l000000ooooooo0000o`000002o`0005Kooooo000Loooo
o`03o`000?oooooooooo067ooooo1?l000001?oooooo0000o`000?l0000:ooooo`;o00002oooool2
o`00023ooooo0_l000000ooooooo0000o`00000;ooooo`;o00000oooool2o`0000?ooooo0_l00003
ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000;ooooo0_l00004ooooo`Co00002ooo
ool2o`0000?ooooo1?l000001?oooooo0000o`000?l00003ooooo`;o00000_ooool2o`0005;ooooo
000Looooo`03o`000?oooooooooo05?ooooo0_l00003ooooo`?o00001?ooool6o`000004ooooool0
003o0000o`0001Kooooo0ol00003ooooo`;o00006oooool2o`0000kooooo0_l00003ooooo`?o0000
0oooool2o`0000;ooooo1_l0000Dooooo`;o00001?ooool2o`0000Gooooo1Ol00008ooooo`;o0000
D_ooool001cooooo00?o0000ooooooooool0D?ooool2o`000003ooooool0003o000000Ko00000_oo
ool4o`0000Gooooo0_l0000Gooooo`;o00001?ooool2o`0001gooooo0_l0000Aooooo`?o00000ooo
ool2o`0000?ooooo0_l0000Gooooo`;o00002?ooool2o`0000;ooooo0ol0001Mooooo`007?ooool0
0ol0003oooooooooo`1@ooooo`;o00000_ooool4o`000003ooooool0003o000000;ooooo0_l00000
0ooooooo0000o`00000Oooooo`;o000000?oooooo`000?l000005oooool2o`0000Gooooo0_l0000B
ooooo`;o00000oooool2o`0000Kooooo0_l0000Nooooo`;o00000oooool2o`0005gooooo000Loooo
o`03o`000?oooooooooo05Wooooo0ol00004ooooo`;o00007oooool2o`000003ooooool0003o0000
01Oooooo0_l00005ooooo`Ko00003_ooool2o`0000_ooooo1?l00006ooooo`;o00002oooool2o`00
00?ooooo0_l0001Vooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00001_ooool2o`0000?o
oooo0_l00007ooooo`;o00007Oooool2o`0000Cooooo0_l0000Jooooo`Ko00004Oooool2o`0000Wo
oooo0ol00006ooooo`;o00001_ooool2o`0000?ooooo0_l00003ooooo`;o00000_ooool2o`0006;o
oooo000Looooo`03o`000?oooooooooo04gooooo0_l00006ooooo`;o00003?ooool2o`0001?ooooo
0_l00008ooooo`;o000000Coooooo`000?l0003ooooo0ol0000Mooooo`;o00002Oooool2o`0000Ko
oooo0_l00003ooooo`;o00001?ooool2o`0000oooooo0_l00005ooooo`;o00001Oooool2o`0006;o
oooo000Looooo`03o`000?oooooooooo05[ooooo0ol00003ooooo`;o00005_ooool3o`000003oooo
ool0003o000000Oooooo1_l0000Dooooo`Co00001Oooool2o`0000Wooooo0_l00006ooooo`;o0000
0oooool2o`0001Cooooo1?l00004ooooo`;o00002?ooool2o`0000Sooooo0_l0001Eooooo`007?oo
ool00ol0003oooooooooo`1Fooooo`;o00000_ooool4o`0000;ooooo0_l00004ooooo`;o00004Ooo
ool2o`000003ooooool0003o000000Wooooo1?l000000ooooooo0000o`00000Aooooo`Co00003_oo
ool2o`0000?ooooo0_l0000=ooooo`;o00003oooool6o`0000;ooooo0_l00004ooooo`;o00000_oo
ool2o`0000Sooooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`1Fooooo`;o00001?ooool2
o`0000Sooooo0_l0000Mooooo`;o00000_ooool2o`000003ooooool0003o000001;ooooo0_l0000?
ooooo`;o00000oooool4o`0000_ooooo0_l0000=ooooo`So00000_ooool2o`0000;ooooo1?l0001S
ooooo`007?ooool2o`0005gooooo0_l00007ooooo`;o00000_ooool2o`0001[ooooo0_l0000Coooo
o`;o00001?ooool2o`00017ooooo0_l00003ooooo`;o00001_ooool2o`0000Sooooo0_l00008oooo
o`;o00002_ooool4o`0006Gooooo000Looooo`03o`000?oooooooooo05Kooooo0_l0000<ooooo`?o
00000_ooool2o`0000[ooooo0ol0000Fooooo`;o00002_ooool2o`0000;ooooo0_l00008ooooo`?o
00001Oooool2o`000003ooooool0003o000000_ooooo0_l00008ooooo`;o00005?ooool2o`0006Oo
oooo000Looooo`03o`000?oooooooooo04kooooo0_l00006ooooo`;o00001oooool2o`0000?ooooo
0_l00008ooooo`;o00001Oooool3o`0000Cooooo0_l0000@ooooo`;o00002oooool2o`000003oooo
ool0003o000000;o00001_ooool3o`0000Gooooo0_l00006ooooo`;o00000oooool2o`0008[ooooo
000Looooo`03o`000?oooooooooo04kooooo0_l0000:ooooo`;o00000oooool2o`0000?ooooo0_l0
0003ooooo`;o00000oooool3o`0000Wooooo1?l0000Aooooo`;o00002_ooool2o`0000?ooooo0_l0
0002ooooo`;o00000oooool2o`0000gooooo0ol00002ooooo`;o00003_ooool2o`0000Oooooo0_l0
000<ooooo`;o0000Hoooool001cooooo00?o0000ooooooooool0F_ooool2o`0000gooooo1?l00002
ooooo`;o00002Oooool2o`0001?ooooo0_l0000Cooooo`;o00000oooool2o`0000gooooo0ol00008
ooooo`;o00000_ooool2o`0000;ooooo1?l00007ooooo`;o00003?ooool2o`0006?ooooo000Loooo
o`03o`000?oooooooooo06_ooooo0_l0000=ooooo`;o00001?ooool2o`0000[ooooo0ol00002oooo
o`;o00000_ooool2o`0001Kooooo0_l00009ooooo`;o00002Oooool2o`0000;ooooo0_l00002oooo
o`;o00005_ooool2o`0000Kooooo0_l0001Looooo`007?ooool00ol0003oooooooooo`1^ooooo`;o
00002_ooool2o`0000Cooooo0_l00002ooooo`;o00001_ooool3o`0000;ooooo0_l00002ooooo`;o
00004_ooool2o`0000;ooooo0_l00004ooooo`;o00004?ooool2o`00013ooooo1?l00008ooooo`;o
00001_ooool2o`0005cooooo000Looooo`03o`000?oooooooooo06cooooo1?l0000Booooo`Co0000
8oooool2o`0000Sooooo0_l00009ooooo`Co00000oooool2o`0000Oooooo0ol00006ooooo`Co0000
K_ooool001cooooo00?o0000ooooooooool0I_ooool2o`0000Cooooo0_l0000Dooooo`;o00002Ooo
ool2o`0000Kooooo0_l0000Hooooo`;o00002_ooool2o`000003ooooool0003o000000;o00000ooo
ool2o`0000Oooooo0ol00005ooooo`;o0000LOooool001cooooo00?o0000ooooooooool0G_ooool4
o`0000Cooooo0_l0000Qooooo`;o00000_ooool2o`000003ooooool0003o000000?ooooo0_l0000H
ooooo`Co00000_ooool2o`0000Cooooo0_l00003ooooo`;o00002oooool2o`0000Oooooo0_l0001a
ooooo`007?ooool00ol0003oooooooooo`1Looooo`Ko00005?ooool2o`0000Wooooo0ol00005oooo
o`;o00000oooool4o`0000Sooooo0_l000000ooooooo0000o`000004ooooo`;o00002_ooool4o`00
00;ooooo0_l0000Fooooo`;o00000_ooool2o`0007Kooooo000Looooo`03o`000?oooooooooo05co
oooo0_l0000<ooooo`;o00001Oooool2o`0000?ooooo0_l00005ooooo`;o00000_ooool3o`0000Go
oooo1?l000000ooooooo0000o`000007ooooo`;o000000Coooooo`000?l0003ooooo0_l00004oooo
o`Co00001Oooool2o`000003ooooool0003o000000cooooo1?l0000@ooooo`;o0000M_ooool001co
oooo00?o0000ooooooooool0G?ooool2o`0000cooooo0_l00005ooooo`;o00001oooool2o`000003
ooooool0003o000000cooooo0_l0000:ooooo`;o00000_ooool2o`0000Oooooo0ol000000ooooooo
0000o`000002ooooo`;o00002_ooool3o`0000;ooooo1?l00006ooooo`;o00001oooool2o`0007Oo
oooo000Looooo`03o`000?oooooooooo05cooooo0_l00006ooooo`;o00000_ooool2o`00013ooooo
0_l0000Hooooo`;o00001Oooool2o`0000Oooooo0_l00002ooooo`;o00002?ooool2o`0000Cooooo
0ol0000<ooooo`;o00001oooool2o`0000Sooooo0_l0001]ooooo`0000Koooooonk^k_lb<S;o0000
oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000oooo
ooooool0I?ooool2o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`0000cooooo0_l0000Aoooo
o`;o00001Oooool2o`0001Gooooo0_l0000Vooooo`;o0000KOooool00006oooooomgMgOoV9RHoooo
oonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oo
oooooooo06oooooo0_l00002ooooo`;o00001_ooool2o`000003ooooool0003o000000?o00009?oo
ool2o`0001Kooooo0_l00003ooooo`;o0000Poooool00003ooooool@413ooooo00;ooooo00?o410@
ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0J?oo
ool2o`000003ooooool0003o000000kooooo0_l000001?oooooo0000o`000?l0000Iooooo`;o0000
00?oooooo`000?l000002?ooool2o`0000Gooooo0_l00008ooooo`;o00001Oooool2o`0000;ooooo
0ol00023ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nH
V9SooooooiRHV?lb<S801_ooool3o`0006Sooooo0_l000000ooooooo0000o`00000Vooooo`;o0000
1Oooool5o`0000Sooooo0_l00005ooooo`;o00002?ooool2o`0000Wooooo0_l00024ooooo`0000?o
ooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<c<`0
1_ooool00ol0003oooooooooo`1[ooooo`;o00002oooool2o`0001Wooooo0_l000001?oooooo0000
o`000?ooool2o`000003ooooool0003o000000;ooooo0_l00005ooooo`;o00001Oooool4o`0000So
oooo0_l00006ooooo`?o0000Q?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool0
2Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0H?ooool2o`0000Wo
oooo0_l0000;ooooo`;o00007?ooool2o`000003ooooool0003o000000Gooooo0ol00005ooooo`;o
00001Oooool3o`0000Sooooo0_l00006ooooo`?o0000Q?ooool00006oooooomgMgOoV9RHoooooonH
V9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0H?ooool2
o`0001cooooo0_l000000ooooooo0000o`00000;ooooo`;o00001oooool2o`0000?ooooo0ol00002
ooooo`;o00001?ooool4o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool3
o`0008cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@06ooooo`03o`000?oooooooooo07Gooooo0_l00002ooooo`;o00000oooool2o`000003oooo
ool0003o000000_ooooo0_l00007ooooo`;o00000oooool3o`0000Sooooo1?l00007ooooo`;o0000
00Coooooo`000?l0003o00000_ooool3o`0008cooooo000Looooo`03o`000?oooooooooo07Gooooo
0_l00002ooooo`;o00003Oooool2o`0000?ooooo0_l0000Sooooo`;o000000?oooooo`000?l00000
T_ooool001cooooo00?o0000ooooooooool0LOooool2o`0001Gooooo0_l00003ooooo`;o00002_oo
ool2o`0001?ooooo0_l0002Iooooo`007?ooool00ol0003oooooooooo`1aooooo`;o00009_ooool2
o`0000gooooo0_l00004ooooo`;o00000oooool2o`0000;ooooo0_l0000?ooooo`;o00001?ooool2
o`0007Wooooo000Looooo`03o`000?oooooooooo06Kooooo0_l0000Tooooo`Co00005oooool3o`00
00Wooooo0_l00002ooooo`;o00003_ooool3o`0000Cooooo0_l0001iooooo`007?ooool00ol0003o
ooooooooo`1Vooooo`;o00009?ooool4o`000003ooooool0003o000001Cooooo0_l0000Nooooo`;o
0000P?ooool001cooooo00?o0000ooooooooool0TOooool2o`0000oooooo0_l0002Uooooo`007?oo
ool00ol0003oooooooooo`1Yooooo`;o00001?ooool2o`0002kooooo0_l000000ooooooo0000o`00
000>ooooo`;o0000UOooool001cooooo00?o0000ooooooooool0JOooool2o`0000Cooooo0_l0000^
ooooo`;o00004Oooool2o`0009Gooooo000Looooo`03o`000?oooooooooo0;7ooooo0_l000000ooo
oooo0000o`00002Cooooo`007?ooool00ol0003oooooooooo`2Zooooo`;o00001Oooool2o`000003
ooooool0003o000009?ooooo000Looooo`03o`000?oooooooooo0:[ooooo0_l0002Mooooo`007?oo
ool2o`000:Wooooo0_l0002Oooooo`007?ooool00ol0003oooooooooo`1gooooo`;o00009oooool2
o`0000Kooooo0_l00004ooooo`;o0000VOooool001cooooo00?o0000ooooooooool0Moooool2o`00
00gooooo0_l0000Hooooo`;o00002oooool3o`0009Wooooo000Looooo`03o`000?oooooooooo08Ko
oooo0_l0000Uooooo`;o0000V_ooool001cooooo00?o0000ooooooooool0X_ooool2o`0000kooooo
0_l0002Eooooo`007?ooool00ol0003oooooooooo`2Booooo`;o00003_ooool2o`0000kooooo0_l0
002Eooooo`007?ooool00ol0003oooooooooo`2Booooo`;o00002Oooool2o`000:[ooooo000Loooo
o`03o`000?oooooooooo07Oooooo0_l0000Tooooo`;o00002?ooool2o`0001[ooooo0_l00024oooo
o`007?ooool00ol0003oooooooooo`1gooooo`;o0000;_ooool2o`0001[ooooo0_l00024ooooo`00
7?ooool00ol0003oooooooooo`26ooooo`;o0000`Oooool001cooooo00?o0000ooooooooool0Q_oo
ool2o`000<7ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2
o`000?ooooooBoooool001cooooo00?o0000ooooooooool0/?ooool2o`0009Oooooo000Looooo`03
o`000?oooooooooo0;3ooooo0_l0002Gooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Booooo`Co000000?o410@
ooooooooool00oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`?o
0000oooooom:ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oo
oooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0
003oooooooooo`3ooooooe;ooooo000Booooo`03oeEEEOmVIVKo00000?ooooooE?ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00:7ooooo00Co410@o`000?l0003ooooo0_l00000
0ol@413oooooooooo`0Fooooo`Co000000?o410@ooooooooool01Ol00005ooooo`03o`000?o^k^ko
oooo00?ooooo1Ol0002<ooooo`00X_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l0000<
ooooo`03o`000?oooooooooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03oeEEEOnY
ZJWooooo00?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A02<ooooo`00X_ooool01Ol0003ooooooooo
oooooooo000001_ooooo00?o0000ooooooooool00oooool00onHV9So8B4Qonk^kP06ooooo`03ojVY
ZOmEEEGooooo00Cooooo00?oV9RHob4Q8Oo^k^h0SOooool00:;ooooo00Go0000oooooooooooooooo
o`000009ooooo`Ko00003?ooool00ol0003oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00Kooooo
00?o8B4Qooooooooool01?ooool00onHV9So8B4Qonk^kP2<ooooo`00X_ooool01Ol0003oQhN7oooo
oonYZJWo000001_ooooo00?o0000ooooooooool01Oooool00omgMgOoIVIVooooo`05ooooo`03oeEE
EOo<c<cooooo00Gooooo00?oMgMgofIVI_ooool0Roooool00:7ooooo00?o410@o`000?mgMgL00_l0
00000onHV9Soooooooooo`0Iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?oo
ool00onYZJWoMgMgooooo`06ooooo`03o`000?oooooooooo08[ooooo0032ooooo`03o`000?oooooo
oooo00;ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05oa0@4?oooooooooooooooolb<S80
0oooool01Ol0003o^[ZjoooooonHV9So410@08cooooo0030ooooo`03oeEEEOmVIVKo000000Cooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`Go00000oooool01OnHV9So410@o`000?lQ8B7oc<c<
08cooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1278) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.51377 .64238 Mdot
.51934 .66784 Mdot
.5496 .35895 Mdot
.42412 .54356 Mdot
.66573 .25497 Mdot
.57194 .37969 Mdot
.70671 .52373 Mdot
.64732 .53325 Mdot
.56672 .34479 Mdot
.744 .57565 Mdot
.67709 .54176 Mdot
.46982 .62151 Mdot
.65856 .51876 Mdot
.4124 .57098 Mdot
.63252 .1733 Mdot
.45603 .58833 Mdot
.51362 .65242 Mdot
.38468 .38837 Mdot
.42574 .5156 Mdot
.52938 .36908 Mdot
.54839 .6298 Mdot
.40904 .56323 Mdot
.56688 .70486 Mdot
.41235 .57171 Mdot
.39987 .52757 Mdot
.56905 .67612 Mdot
.49199 .63039 Mdot
.37383 .53596 Mdot
.35396 .54168 Mdot
.6516 .53827 Mdot
.29022 .41343 Mdot
.63212 .19706 Mdot
.32192 .5443 Mdot
.38821 .22494 Mdot
.6459 .50387 Mdot
.40965 .75167 Mdot
.56536 .36941 Mdot
.68211 .52211 Mdot
.68732 .522 Mdot
.65049 .49375 Mdot
.67724 .53221 Mdot
.56412 .69535 Mdot
.62225 .59688 Mdot
.55681 .29951 Mdot
.44107 .59628 Mdot
.75848 .37393 Mdot
.49386 .80806 Mdot
.38422 .59271 Mdot
.53008 .64826 Mdot
.45861 .25157 Mdot
.6869 .35996 Mdot
.67845 .49994 Mdot
.5291 .35871 Mdot
.14676 .64083 Mdot
.66695 .50605 Mdot
.38661 .49251 Mdot
.55823 .36308 Mdot
.39578 .56587 Mdot
.4104 .57575 Mdot
.32919 .65855 Mdot
.41706 .60038 Mdot
.40993 .37387 Mdot
.53281 .7173 Mdot
.58598 .54201 Mdot
.56977 .35185 Mdot
.69216 .53268 Mdot
.53025 .67978 Mdot
.65525 .5125 Mdot
.45415 .51018 Mdot
.52797 .38835 Mdot
.38174 .59301 Mdot
.68311 .53842 Mdot
.50047 .66563 Mdot
.36069 .55862 Mdot
.47072 .33442 Mdot
.82808 .48093 Mdot
.36279 .33315 Mdot
.39232 .72636 Mdot
.31268 .6542 Mdot
.49869 .2703 Mdot
.41883 .52047 Mdot
.33281 .44151 Mdot
.80967 .44551 Mdot
.58058 .69747 Mdot
.43473 .6176 Mdot
.35547 .3025 Mdot
.36355 .55675 Mdot
.77801 .36697 Mdot
.35615 .58562 Mdot
.40098 .29065 Mdot
.57543 .34042 Mdot
.53823 .66614 Mdot
.42516 .54143 Mdot
.35483 .56185 Mdot
.26854 .6119 Mdot
.35459 .51215 Mdot
.39751 .54775 Mdot
.54671 .64699 Mdot
.67585 .49982 Mdot
.33809 .51764 Mdot
.57198 .30092 Mdot
.58089 .33298 Mdot
.44513 .56337 Mdot
.59746 .37954 Mdot
.52708 .70697 Mdot
.35722 .56485 Mdot
.68545 .51602 Mdot
.43755 .57598 Mdot
.65602 .72653 Mdot
.51571 .67002 Mdot
.36525 .53767 Mdot
.41347 .33641 Mdot
.25224 .66386 Mdot
.53274 .65734 Mdot
.59965 .30085 Mdot
.38277 .5121 Mdot
.38815 .55265 Mdot
.52288 .66773 Mdot
.60642 .36568 Mdot
.78851 .38241 Mdot
.57178 .66184 Mdot
.63325 .5115 Mdot
.50602 .64408 Mdot
.47242 .57747 Mdot
.58197 .35487 Mdot
.63755 .30292 Mdot
.64617 .68535 Mdot
.30945 .38626 Mdot
.36642 .55884 Mdot
.68063 .60806 Mdot
.56334 .32881 Mdot
.54294 .67692 Mdot
.65198 .51675 Mdot
.39603 .62041 Mdot
.53133 .6961 Mdot
.66873 .54532 Mdot
.4215 .34559 Mdot
.68804 .41825 Mdot
.53212 .70558 Mdot
.4656 .41997 Mdot
.70089 .54511 Mdot
.66766 .49311 Mdot
.30265 .26586 Mdot
.533 .67914 Mdot
.40856 .3618 Mdot
.64641 .52127 Mdot
.29434 .37358 Mdot
.43906 .59435 Mdot
.29352 .46426 Mdot
.49834 .82318 Mdot
.36762 .23284 Mdot
.71457 .43441 Mdot
.38232 .35112 Mdot
.64587 .54328 Mdot
.40383 .53558 Mdot
.56253 .66445 Mdot
.57204 .69133 Mdot
.42155 .59723 Mdot
.41488 .52653 Mdot
.37309 .59098 Mdot
.35438 .57314 Mdot
.44017 .65532 Mdot
.38427 .50602 Mdot
.41823 .80038 Mdot
.54095 .66412 Mdot
.41582 .53985 Mdot
.56107 .39992 Mdot
.33059 .56144 Mdot
.68082 .53529 Mdot
.40032 .56131 Mdot
.42296 .54127 Mdot
.43018 .59578 Mdot
.67333 .49727 Mdot
.68506 .22513 Mdot
.28259 .69363 Mdot
.64693 .22034 Mdot
.44662 .32869 Mdot
.57972 .39373 Mdot
.37097 .55018 Mdot
.41925 .35696 Mdot
.46043 .74492 Mdot
.43114 .55834 Mdot
.50361 .87422 Mdot
.40367 .55226 Mdot
.66815 .24621 Mdot
.39432 .48639 Mdot
.55778 .18539 Mdot
.3205 .4376 Mdot
.39059 .53281 Mdot
.58495 .58081 Mdot
.61968 .48548 Mdot
.61153 .39091 Mdot
.67362 .52969 Mdot
.55635 .39831 Mdot
.55127 .36208 Mdot
.60724 .56776 Mdot
.45169 .62928 Mdot
.32793 .51319 Mdot
.34518 .57054 Mdot
.52874 .39696 Mdot
.54929 .72342 Mdot
.42985 .36377 Mdot
.53529 .63556 Mdot
.82909 .35884 Mdot
.71413 .34725 Mdot
.71748 .53155 Mdot
.40486 .38313 Mdot
.55892 .33825 Mdot
.59273 .34894 Mdot
.39814 .33316 Mdot
.38597 .58129 Mdot
.53935 .6855 Mdot
.34754 .22364 Mdot
.69508 .70759 Mdot
.27681 .26812 Mdot
.54504 .6478 Mdot
.72782 .60965 Mdot
.66144 .54057 Mdot
.55461 .38062 Mdot
.39053 .55079 Mdot
.38201 .57545 Mdot
.58242 .65863 Mdot
.3714 .58903 Mdot
.53141 .6106 Mdot
.38798 .54289 Mdot
.66174 .3847 Mdot
.35553 .35165 Mdot
.60636 .5654 Mdot
.32454 .36578 Mdot
.57868 .68637 Mdot
.22557 .5158 Mdot
.59868 .3709 Mdot
.44957 .73846 Mdot
.69301 .53784 Mdot
.42455 .3608 Mdot
.59254 .36044 Mdot
.42865 .34892 Mdot
.40201 .50474 Mdot
.54205 .39304 Mdot
.38658 .33323 Mdot
.29341 .583 Mdot
.41223 .60951 Mdot
.61257 .75546 Mdot
.64374 .4993 Mdot
.54949 .63748 Mdot
.40933 .60263 Mdot
.58435 .39492 Mdot
.35004 .6013 Mdot
.76229 .47492 Mdot
.64973 .34706 Mdot
.58178 .32988 Mdot
.64368 .36251 Mdot
.41247 .37529 Mdot
.74809 .41592 Mdot
.7066 .61539 Mdot
.51553 .64821 Mdot
.35928 .51094 Mdot
.53265 .17485 Mdot
.64648 .52047 Mdot
.42845 .58402 Mdot
.46662 .21612 Mdot
.652 .50654 Mdot
.39337 .56616 Mdot
.64972 .54112 Mdot
.57169 .69302 Mdot
.25387 .6314 Mdot
.51915 .64898 Mdot
.34993 .57227 Mdot
.68127 .51076 Mdot
.58125 .40269 Mdot
.56405 .67272 Mdot
.39113 .58643 Mdot
.37308 .53968 Mdot
.59626 .47512 Mdot
.41035 .54315 Mdot
.68457 .23541 Mdot
.38887 .53746 Mdot
.54555 .37512 Mdot
.44757 .54544 Mdot
.21488 .67283 Mdot
.63196 .58144 Mdot
.53232 .68091 Mdot
.60696 .35538 Mdot
.56168 .35063 Mdot
.55298 .29528 Mdot
.69704 .49387 Mdot
.39345 .50942 Mdot
.5836 .39319 Mdot
.25026 .52143 Mdot
.69231 .54637 Mdot
.329 .53354 Mdot
.47631 .43846 Mdot
.44346 .25931 Mdot
.53078 .35593 Mdot
.31742 .57176 Mdot
.53449 .70963 Mdot
.4242 .53737 Mdot
.59821 .35403 Mdot
.40531 .63658 Mdot
.37631 .52057 Mdot
.60105 .68078 Mdot
.59955 .47413 Mdot
.70745 .53344 Mdot
.37677 .48752 Mdot
.4193 .59006 Mdot
.55849 .39561 Mdot
.57547 .67729 Mdot
.69124 .54798 Mdot
.56696 .68802 Mdot
.5111 .18735 Mdot
.62307 .74384 Mdot
.3054 .60721 Mdot
.41285 .38473 Mdot
.43198 .24281 Mdot
.52617 .18185 Mdot
.19686 .50568 Mdot
.23337 .47249 Mdot
.41596 .19614 Mdot
.60427 .37669 Mdot
.46679 .22286 Mdot
.55782 .35686 Mdot
.40105 .52046 Mdot
.57994 .35516 Mdot
.5182 .17565 Mdot
.39003 .54354 Mdot
.57693 .36196 Mdot
.22993 .54933 Mdot
.41883 .53519 Mdot
.51688 .65624 Mdot
.76756 .30779 Mdot
.18988 .57885 Mdot
.65313 .36089 Mdot
.53461 .3696 Mdot
.24525 .41858 Mdot
.39895 .54595 Mdot
.44362 .53966 Mdot
.54765 .657 Mdot
.3207 .5672 Mdot
.39039 .37335 Mdot
.39766 .38222 Mdot
.71564 .48537 Mdot
.36449 .44779 Mdot
.39007 .48801 Mdot
.56038 .66844 Mdot
.4656 .66455 Mdot
.45536 .317 Mdot
.46201 .24564 Mdot
.69414 .55593 Mdot
.76293 .30506 Mdot
.50989 .60286 Mdot
.63391 .55148 Mdot
.61857 .39027 Mdot
.52478 .65857 Mdot
.66859 .21322 Mdot
.67405 .52596 Mdot
.60964 .7781 Mdot
.48737 .49672 Mdot
.38883 .58032 Mdot
.70188 .53322 Mdot
.38841 .62587 Mdot
.18294 .56182 Mdot
.66519 .76684 Mdot
.43594 .45845 Mdot
.35399 .58519 Mdot
.46957 .35003 Mdot
.39571 .55742 Mdot
.78984 .44702 Mdot
.38477 .53597 Mdot
.56439 .6834 Mdot
.74919 .5598 Mdot
.67481 .47353 Mdot
.3216 .75063 Mdot
.7647 .43302 Mdot
.38175 .35211 Mdot
.38584 .54699 Mdot
.39158 .58142 Mdot
.38548 .36762 Mdot
.55965 .71232 Mdot
.35639 .58066 Mdot
.22177 .50109 Mdot
.3609 .57084 Mdot
.68221 .5296 Mdot
.4819 .51098 Mdot
.59427 .73372 Mdot
.34395 .54737 Mdot
.51069 .69233 Mdot
.71192 .52493 Mdot
.67631 .51003 Mdot
.41224 .49124 Mdot
.64581 .49392 Mdot
.41145 .55367 Mdot
.68899 .75922 Mdot
.52376 .69809 Mdot
.58139 .61879 Mdot
.5466 .69955 Mdot
.37569 .71856 Mdot
.66032 .50038 Mdot
.67655 .37606 Mdot
.43742 .62558 Mdot
.66992 .52386 Mdot
.57964 .75081 Mdot
.45621 .57958 Mdot
.41507 .61308 Mdot
.30198 .29165 Mdot
.5393 .36394 Mdot
.60053 .48221 Mdot
.6487 .5366 Mdot
.40317 .59131 Mdot
.35331 .52218 Mdot
.70994 .51992 Mdot
.69283 .73607 Mdot
.21033 .57499 Mdot
.38898 .54015 Mdot
.5562 .67766 Mdot
.54668 .68055 Mdot
.38147 .60577 Mdot
.44111 .5499 Mdot
.58686 .36574 Mdot
.59198 .39892 Mdot
.53594 .39396 Mdot
.60379 .47346 Mdot
.67204 .37403 Mdot
.6806 .29237 Mdot
.65125 .4934 Mdot
.70061 .64179 Mdot
.39047 .28928 Mdot
.33919 .55433 Mdot
.54165 .34793 Mdot
.4225 .58445 Mdot
.42008 .55252 Mdot
.71352 .51716 Mdot
.57041 .23549 Mdot
.52091 .61983 Mdot
.56923 .71312 Mdot
.68506 .55292 Mdot
.47797 .5688 Mdot
.67567 .57602 Mdot
.41951 .34775 Mdot
.33372 .2625 Mdot
.6895 .53742 Mdot
.51817 .65769 Mdot
.63914 .51002 Mdot
.37442 .57446 Mdot
.42126 .50653 Mdot
.52713 .66509 Mdot
.37297 .36034 Mdot
.34242 .59406 Mdot
.39059 .56394 Mdot
.47084 .83345 Mdot
.31667 .29972 Mdot
.65339 .40467 Mdot
.39123 .53457 Mdot
.34746 .53699 Mdot
.38822 .32621 Mdot
.36405 .57289 Mdot
.38571 .59872 Mdot
.26431 .66729 Mdot
.65801 .6877 Mdot
.38828 .38245 Mdot
.70056 .74261 Mdot
.54029 .6466 Mdot
.58199 .18344 Mdot
.55482 .38817 Mdot
.73583 .52495 Mdot
.21944 .60534 Mdot
.52691 .36314 Mdot
.71755 .43972 Mdot
.6083 .19349 Mdot
.60682 .47862 Mdot
.5304 .41401 Mdot
.49605 .61379 Mdot
.35671 .57806 Mdot
.38783 .55633 Mdot
.41591 .3653 Mdot
.54533 .6896 Mdot
.58549 .49109 Mdot
.81093 .59647 Mdot
.40693 .56003 Mdot
.55326 .6071 Mdot
.77384 .61705 Mdot
.44528 .26294 Mdot
.39932 .34668 Mdot
.38021 .37456 Mdot
.38446 .54963 Mdot
.25923 .68143 Mdot
.56786 .67393 Mdot
.39289 .58688 Mdot
.37506 .5088 Mdot
.53679 .36968 Mdot
.51446 .67773 Mdot
.60473 .35849 Mdot
.69641 .37719 Mdot
.65185 .22819 Mdot
.50769 .84606 Mdot
.66676 .50303 Mdot
.80142 .50025 Mdot
.66258 .54793 Mdot
.3408 .43495 Mdot
.56435 .32399 Mdot
.43196 .54216 Mdot
.57744 .6851 Mdot
.4102 .59004 Mdot
.43819 .54531 Mdot
.38862 .582 Mdot
.34227 .5361 Mdot
.40213 .84887 Mdot
.3822 .34023 Mdot
.4661 .58528 Mdot
.54521 .36956 Mdot
.79271 .40844 Mdot
.82264 .48448 Mdot
.39664 .58103 Mdot
.37776 .54175 Mdot
.53338 .70279 Mdot
.42346 .59417 Mdot
.67263 .54926 Mdot
.56037 .64793 Mdot
.35601 .55517 Mdot
.78096 .33468 Mdot
.3584 .53877 Mdot
.59508 .19871 Mdot
.63844 .51831 Mdot
.66391 .72629 Mdot
.46867 .57037 Mdot
.6512 .36789 Mdot
.60036 .4823 Mdot
.59023 .36233 Mdot
.62946 .50913 Mdot
.5673 .3671 Mdot
.80027 .62927 Mdot
.42967 .50798 Mdot
.40371 .53318 Mdot
.33807 .53012 Mdot
.57858 .39484 Mdot
.76084 .3442 Mdot
.74349 .39521 Mdot
.47157 .58734 Mdot
.57879 .38995 Mdot
.52615 .71025 Mdot
.29615 .33841 Mdot
.55568 .70176 Mdot
.43308 .36965 Mdot
.67103 .5397 Mdot
.37796 .36756 Mdot
.45433 .2108 Mdot
.51695 .66766 Mdot
.54296 .63145 Mdot
.55875 .38611 Mdot
.49731 .49635 Mdot
.1377 .45205 Mdot
.49151 .49979 Mdot
.31911 .41476 Mdot
.55055 .66158 Mdot
.35026 .54406 Mdot
.37348 .42391 Mdot
.52225 .52913 Mdot
.56814 .36415 Mdot
.42616 .56142 Mdot
.24833 .62513 Mdot
.58703 .36577 Mdot
.33942 .52202 Mdot
.54255 .36544 Mdot
.67104 .53431 Mdot
.54928 .34117 Mdot
.59116 .68976 Mdot
.36318 .54857 Mdot
.15818 .39032 Mdot
.35268 .35901 Mdot
.3988 .54181 Mdot
.68552 .55386 Mdot
.71815 .46916 Mdot
.43769 .56425 Mdot
.41562 .33382 Mdot
.58003 .37239 Mdot
.47244 .47205 Mdot
.38725 .53843 Mdot
.57469 .39457 Mdot
.51266 .64215 Mdot
.63216 .52772 Mdot
.28746 .62989 Mdot
.64613 .39352 Mdot
.54742 .6558 Mdot
.46817 .39065 Mdot
.64025 .49171 Mdot
.34684 .53711 Mdot
.35694 .51266 Mdot
.55456 .68025 Mdot
.27564 .53071 Mdot
.44916 .56471 Mdot
.42032 .52199 Mdot
.54306 .37947 Mdot
.57107 .36821 Mdot
.2575 .57911 Mdot
.60303 .3853 Mdot
.42403 .50782 Mdot
.55659 .68238 Mdot
.42693 .54407 Mdot
.52223 .69371 Mdot
.42577 .59172 Mdot
.44839 .63761 Mdot
.56163 .71183 Mdot
.63449 .57356 Mdot
.4246 .55672 Mdot
.32398 .52228 Mdot
.43526 .57685 Mdot
.36195 .58105 Mdot
.58617 .35738 Mdot
.40848 .34445 Mdot
.37001 .50295 Mdot
.41673 .3258 Mdot
.42878 .35088 Mdot
.64466 .47592 Mdot
.53716 .36676 Mdot
.39943 .36531 Mdot
.77984 .61818 Mdot
.53561 .39026 Mdot
.40429 .37333 Mdot
.82151 .48135 Mdot
.64901 .50156 Mdot
.52838 .70457 Mdot
.41804 .53305 Mdot
.4612 .19909 Mdot
.49383 .81026 Mdot
.59224 .40671 Mdot
.39141 .53831 Mdot
.43023 .57915 Mdot
.57939 .67759 Mdot
.813 .63629 Mdot
.52869 .38917 Mdot
.36916 .52538 Mdot
.52463 .6784 Mdot
.79786 .68415 Mdot
.5494 .37086 Mdot
.40904 .37193 Mdot
.65583 .49484 Mdot
.59872 .69504 Mdot
.64504 .68666 Mdot
.70824 .52874 Mdot
.60048 .41977 Mdot
.68347 .36288 Mdot
.38161 .51184 Mdot
.54442 .34247 Mdot
.28091 .28291 Mdot
.49322 .69819 Mdot
.59834 .54333 Mdot
.24809 .40671 Mdot
.52777 .65843 Mdot
.66694 .54853 Mdot
.38136 .34666 Mdot
.55017 .65044 Mdot
.51368 .65652 Mdot
.70249 .50844 Mdot
.29679 .69077 Mdot
.47603 .44038 Mdot
.68659 .52563 Mdot
.34296 .2831 Mdot
.62767 .26971 Mdot
.54018 .34947 Mdot
.39072 .37306 Mdot
.47531 .20784 Mdot
.56566 .6943 Mdot
.75638 .29314 Mdot
.30609 .27728 Mdot
.39774 .54782 Mdot
.40073 .36157 Mdot
.73535 .32204 Mdot
.83227 .57087 Mdot
.65562 .50478 Mdot
.67677 .47043 Mdot
.39431 .37725 Mdot
.41118 .60157 Mdot
.29284 .35489 Mdot
.41965 .52331 Mdot
.66515 .5398 Mdot
.31697 .64376 Mdot
.51494 .65933 Mdot
.68441 .49427 Mdot
.33066 .26244 Mdot
.41168 .55549 Mdot
.42627 .55699 Mdot
.33403 .36362 Mdot
.56627 .66028 Mdot
.59045 .36304 Mdot
.38003 .5101 Mdot
.39434 .56267 Mdot
.39083 .49641 Mdot
.36354 .49139 Mdot
.2497 .65067 Mdot
.38963 .52362 Mdot
.74591 .37858 Mdot
.35075 .58326 Mdot
.4202 .56379 Mdot
.51407 .69603 Mdot
.50213 .85264 Mdot
.70557 .37369 Mdot
.39794 .56122 Mdot
.35308 .53672 Mdot
.67773 .49126 Mdot
.49818 .47805 Mdot
.49191 .48457 Mdot
.46804 .46579 Mdot
.23938 .44613 Mdot
.37858 .60748 Mdot
.53553 .68696 Mdot
.39009 .33102 Mdot
.37303 .51966 Mdot
.53158 .68483 Mdot
.43894 .59135 Mdot
.58722 .36902 Mdot
.53702 .39177 Mdot
.4883 .6831 Mdot
.39307 .36423 Mdot
.5164 .57459 Mdot
.69165 .64401 Mdot
.55139 .39614 Mdot
.40348 .53099 Mdot
.72126 .528 Mdot
.5971 .35323 Mdot
.63749 .33687 Mdot
.28932 .5511 Mdot
.56824 .66947 Mdot
.53819 .66374 Mdot
.29113 .46948 Mdot
.71159 .42276 Mdot
.37189 .79995 Mdot
.67092 .53549 Mdot
.44628 .5292 Mdot
.70209 .60489 Mdot
.53617 .66053 Mdot
.36021 .42427 Mdot
.39744 .36301 Mdot
.65037 .50675 Mdot
.51056 .40972 Mdot
.53367 .70026 Mdot
.50929 .6575 Mdot
.36538 .5945 Mdot
.38968 .57058 Mdot
.23266 .48423 Mdot
.4453 .36606 Mdot
.70997 .53092 Mdot
.39516 .37511 Mdot
.56307 .32475 Mdot
.38241 .52305 Mdot
.56798 .70568 Mdot
.62421 .27501 Mdot
.36696 .52389 Mdot
.58384 .3465 Mdot
.53114 .66227 Mdot
.40993 .37686 Mdot
.41735 .33307 Mdot
.36054 .57775 Mdot
.41394 .66308 Mdot
.67703 .51941 Mdot
.5217 .65485 Mdot
.66245 .57518 Mdot
.44319 .54186 Mdot
.38161 .56598 Mdot
.38933 .47893 Mdot
.71058 .53278 Mdot
.73721 .64448 Mdot
.42686 .37338 Mdot
.54227 .6845 Mdot
.38342 .52894 Mdot
.3949 .37156 Mdot
.72666 .62633 Mdot
.57833 .3278 Mdot
.55201 .34006 Mdot
.41175 .33018 Mdot
.39968 .35323 Mdot
.42164 .34076 Mdot
.75684 .29277 Mdot
.58407 .69521 Mdot
.50899 .60449 Mdot
.45144 .54624 Mdot
.31818 .43217 Mdot
.43513 .62287 Mdot
.69609 .54743 Mdot
.54159 .36049 Mdot
.44115 .56058 Mdot
.34872 .55974 Mdot
.44369 .50495 Mdot
.57515 .62113 Mdot
.59047 .73926 Mdot
.5141 .67141 Mdot
.44894 .5245 Mdot
.53747 .37802 Mdot
.83639 .36259 Mdot
.3793 .18324 Mdot
.46687 .56203 Mdot
.46478 .43759 Mdot
.57073 .70529 Mdot
.66385 .48918 Mdot
.34215 .34771 Mdot
.64849 .49987 Mdot
.54044 .68073 Mdot
.38761 .52316 Mdot
.69877 .65007 Mdot
.40049 .32559 Mdot
.39078 .59189 Mdot
.65533 .53637 Mdot
.38712 .59444 Mdot
.70808 .52708 Mdot
.5243 .18844 Mdot
.24582 .35474 Mdot
.4025 .55182 Mdot
.4499 .60726 Mdot
.23495 .4202 Mdot
.40138 .58294 Mdot
.4369 .38322 Mdot
.57049 .70592 Mdot
.26572 .60361 Mdot
.43716 .60599 Mdot
.47516 .70465 Mdot
.43627 .53279 Mdot
.2395 .58092 Mdot
.38122 .56857 Mdot
.43959 .27043 Mdot
.36425 .54104 Mdot
.37146 .59249 Mdot
.67397 .505 Mdot
.68257 .49368 Mdot
.49976 .667 Mdot
.58822 .39086 Mdot
.62102 .20639 Mdot
.38692 .56431 Mdot
.64798 .33565 Mdot
.68985 .67915 Mdot
.39876 .35126 Mdot
.54567 .68537 Mdot
.83402 .61144 Mdot
.6408 .53058 Mdot
.28827 .31458 Mdot
.2492 .56144 Mdot
.63299 .63289 Mdot
.35025 .30595 Mdot
.76677 .53763 Mdot
.41805 .37254 Mdot
.43234 .59377 Mdot
.59872 .25566 Mdot
.43348 .28183 Mdot
.28752 .55831 Mdot
.63959 .48997 Mdot
.46207 .7296 Mdot
.58509 .24169 Mdot
.43441 .34887 Mdot
.38866 .3774 Mdot
.68623 .50402 Mdot
.50331 .38449 Mdot
.46046 .62693 Mdot
.3955 .35968 Mdot
.56285 .4022 Mdot
.5308 .38218 Mdot
.52287 .37414 Mdot
.57157 .68114 Mdot
.32656 .24639 Mdot
.7079 .57164 Mdot
.70622 .5331 Mdot
.5128 .35149 Mdot
.52206 .71799 Mdot
.585 .67961 Mdot
.56055 .37846 Mdot
.57497 .33572 Mdot
.56089 .71453 Mdot
.39765 .49119 Mdot
.45171 .51862 Mdot
.40279 .55988 Mdot
.41713 .35162 Mdot
.3847 .57279 Mdot
.58106 .38426 Mdot
.65809 .50658 Mdot
.5677 .33589 Mdot
.67017 .55451 Mdot
.69786 .30907 Mdot
.38117 .58529 Mdot
.36471 .54493 Mdot
.5269 .8166 Mdot
.50718 .6481 Mdot
.73511 .35615 Mdot
.63579 .41868 Mdot
.55504 .35896 Mdot
.39105 .60025 Mdot
.56067 .64746 Mdot
.43504 .3402 Mdot
.55101 .81879 Mdot
.4446 .55585 Mdot
.56089 .70579 Mdot
.37947 .52652 Mdot
.41631 .65456 Mdot
.24765 .70869 Mdot
.56206 .68997 Mdot
.49675 .82194 Mdot
.35403 .53922 Mdot
.78598 .55506 Mdot
.32936 .53973 Mdot
.26261 .50509 Mdot
.44914 .56437 Mdot
.54239 .64673 Mdot
.4027 .56357 Mdot
.55253 .64265 Mdot
.5525 .3939 Mdot
.66291 .49035 Mdot
.54295 .65695 Mdot
.34748 .51812 Mdot
.18985 .27945 Mdot
.66082 .53475 Mdot
.38798 .54929 Mdot
.66519 .49733 Mdot
.54623 .69303 Mdot
.5313 .64989 Mdot
.82606 .55632 Mdot
.70095 .38097 Mdot
.67028 .53317 Mdot
.3812 .52416 Mdot
.77533 .49862 Mdot
.42398 .53157 Mdot
.25 .48006 Mdot
.38096 .49342 Mdot
.44926 .54644 Mdot
.82743 .489 Mdot
.70737 .53547 Mdot
.35227 .79041 Mdot
.83625 .53443 Mdot
.79573 .41355 Mdot
.56957 .64305 Mdot
.43473 .34647 Mdot
.67624 .218 Mdot
.67401 .37671 Mdot
.57758 .39256 Mdot
.43921 .56851 Mdot
.57156 .73767 Mdot
.6796 .51687 Mdot
.40802 .34137 Mdot
.40131 .55169 Mdot
.56852 .33314 Mdot
.20082 .5399 Mdot
.65205 .54764 Mdot
.56141 .69604 Mdot
.57465 .71068 Mdot
.68822 .77981 Mdot
.38842 .53207 Mdot
.36031 .55052 Mdot
.66916 .54018 Mdot
.76173 .61965 Mdot
.4257 .36589 Mdot
.22509 .54126 Mdot
.66846 .53232 Mdot
.55852 .48916 Mdot
.52569 .67537 Mdot
.42831 .58114 Mdot
.73549 .30039 Mdot
.47971 .33962 Mdot
.56523 .78397 Mdot
.41882 .35707 Mdot
.25155 .47138 Mdot
.53916 .64599 Mdot
.64938 .5189 Mdot
.68219 .43257 Mdot
.35623 .5963 Mdot
.42201 .58256 Mdot
.2566 .46866 Mdot
.66564 .47356 Mdot
.44641 .46595 Mdot
.44394 .54972 Mdot
.60161 .48836 Mdot
.44472 .56977 Mdot
.39113 .61503 Mdot
.41139 .4981 Mdot
.37146 .56128 Mdot
.56527 .70632 Mdot
.43364 .48592 Mdot
.58888 .37797 Mdot
.50198 .5802 Mdot
.56131 .49874 Mdot
.39435 .54158 Mdot
.4034 .51554 Mdot
.51915 .77909 Mdot
.7301 .45863 Mdot
.54216 .65943 Mdot
.56507 .6424 Mdot
.63877 .49933 Mdot
.44876 .51292 Mdot
.59346 .38292 Mdot
.4007 .61949 Mdot
.58461 .35142 Mdot
.5683 .70383 Mdot
.55248 .3635 Mdot
.66135 .4935 Mdot
.53276 .36493 Mdot
.67191 .37321 Mdot
.64466 .52313 Mdot
.56139 .66194 Mdot
.36028 .56136 Mdot
.68389 .55405 Mdot
.31204 .37113 Mdot
.41746 .35366 Mdot
.85108 .5088 Mdot
.35555 .55387 Mdot
.65345 .69227 Mdot
.35314 .6244 Mdot
.57158 .33566 Mdot
.26154 .71806 Mdot
.5693 .71217 Mdot
.37725 .37483 Mdot
.57983 .68799 Mdot
.30929 .29618 Mdot
.40842 .35141 Mdot
.82622 .46036 Mdot
.60927 .43078 Mdot
.31237 .3092 Mdot
.42651 .49883 Mdot
.32364 .33393 Mdot
.53624 .3462 Mdot
.67818 .51516 Mdot
.69633 .43511 Mdot
.38279 .59704 Mdot
.20064 .44979 Mdot
.54287 .71835 Mdot
.58808 .38936 Mdot
.65452 .51479 Mdot
.68991 .54909 Mdot
.41832 .5151 Mdot
.50354 .25023 Mdot
.4151 .59242 Mdot
.70785 .40989 Mdot
.24311 .44945 Mdot
.57912 .64135 Mdot
.38802 .54346 Mdot
.55719 .39538 Mdot
.37966 .52642 Mdot
.39514 .38806 Mdot
.30891 .25115 Mdot
.33009 .58075 Mdot
.63911 .41855 Mdot
.3509 .35326 Mdot
.52288 .66494 Mdot
.32308 .60155 Mdot
.66725 .39091 Mdot
.38873 .52973 Mdot
.30346 .81109 Mdot
.40021 .37306 Mdot
.59246 .25498 Mdot
.34831 .52716 Mdot
.39882 .50852 Mdot
.58807 .56423 Mdot
.63514 .67314 Mdot
.47572 .3475 Mdot
.40955 .58114 Mdot
.27187 .41452 Mdot
.69991 .51761 Mdot
.42703 .58847 Mdot
.3868 .55441 Mdot
.34264 .73368 Mdot
.6788 .55192 Mdot
.5567 .35135 Mdot
.53367 .34759 Mdot
.59873 .39825 Mdot
.38669 .38554 Mdot
.63222 .462 Mdot
.3444 .41985 Mdot
.18964 .55366 Mdot
.36725 .35272 Mdot
.35285 .56552 Mdot
.41112 .40818 Mdot
.39497 .51953 Mdot
.39315 .34201 Mdot
.67266 .55198 Mdot
.5386 .65631 Mdot
.72252 .60215 Mdot
.52722 .38084 Mdot
.32498 .54145 Mdot
.42282 .37282 Mdot
.56418 .66591 Mdot
.35128 .2971 Mdot
.52699 .67178 Mdot
.66568 .52575 Mdot
.67917 .55975 Mdot
.40263 .33931 Mdot
.54517 .69641 Mdot
.61622 .52854 Mdot
.82376 .58662 Mdot
.41092 .50075 Mdot
.74334 .51323 Mdot
.5279 .64052 Mdot
.57564 .65389 Mdot
.54627 .64324 Mdot
.37426 .58949 Mdot
.46523 .43701 Mdot
.44695 .58934 Mdot
.70805 .53321 Mdot
.54463 .3617 Mdot
.22224 .44459 Mdot
.67456 .31947 Mdot
.45387 .39914 Mdot
.44682 .52698 Mdot
.41269 .55741 Mdot
.38472 .54983 Mdot
.43318 .60946 Mdot
.68341 .40908 Mdot
.41436 .58915 Mdot
.67629 .50552 Mdot
.58166 .37353 Mdot
.43221 .59433 Mdot
.53946 .33155 Mdot
.78604 .40744 Mdot
.36901 .35013 Mdot
.65417 .46129 Mdot
.40022 .15661 Mdot
.55784 .6615 Mdot
.60477 .35169 Mdot
.5727 .39364 Mdot
.42207 .3471 Mdot
.68178 .5237 Mdot
.52946 .67581 Mdot
.24974 .50734 Mdot
.42606 .34718 Mdot
.39951 .56319 Mdot
.4426 .43772 Mdot
.21186 .41076 Mdot
.43343 .59135 Mdot
.43539 .55454 Mdot
.55833 .32119 Mdot
.5713 .25231 Mdot
.19477 .35095 Mdot
.35491 .40409 Mdot
.40588 .34183 Mdot
.37536 .34713 Mdot
.5433 .71223 Mdot
.45388 .58557 Mdot
.70897 .53177 Mdot
.46781 .492 Mdot
.67078 .45582 Mdot
.50367 .54589 Mdot
.61314 .71027 Mdot
.44376 .56292 Mdot
.71557 .7173 Mdot
.41366 .55368 Mdot
.58389 .69208 Mdot
.56956 .69806 Mdot
.55715 .67057 Mdot
.6769 .5154 Mdot
.41393 .74016 Mdot
.68441 .51229 Mdot
.3844 .16035 Mdot
.52835 .64574 Mdot
.60895 .44039 Mdot
.55093 .38501 Mdot
.46871 .56318 Mdot
.40524 .37699 Mdot
.63171 .54045 Mdot
.45465 .51087 Mdot
.26102 .69533 Mdot
.58769 .38653 Mdot
.55781 .65896 Mdot
.76568 .54427 Mdot
.455 .16836 Mdot
.47998 .47213 Mdot
.47907 .56904 Mdot
.34083 .3324 Mdot
.39525 .34936 Mdot
.56397 .78547 Mdot
.39586 .37655 Mdot
.65284 .53518 Mdot
.36847 .5445 Mdot
.36418 .55684 Mdot
.44421 .57264 Mdot
.39046 .58495 Mdot
.65045 .4892 Mdot
.36147 .50891 Mdot
.21482 .67271 Mdot
.54247 .39622 Mdot
.29508 .58962 Mdot
.40443 .37529 Mdot
.62896 .50161 Mdot
.58174 .37555 Mdot
.72457 .45455 Mdot
.32521 .3734 Mdot
.38776 .53973 Mdot
.44107 .56366 Mdot
.28089 .31938 Mdot
.44364 .54821 Mdot
.45374 .62098 Mdot
.57584 .39398 Mdot
.42154 .4189 Mdot
.37056 .35618 Mdot
.37481 .35186 Mdot
.64211 .5187 Mdot
.56664 .70393 Mdot
.40587 .36912 Mdot
.54626 .38328 Mdot
.44528 .52475 Mdot
.36292 .51328 Mdot
.52882 .64099 Mdot
.28987 .28334 Mdot
.43027 .36767 Mdot
.77798 .51298 Mdot
.57574 .68136 Mdot
.49769 .63464 Mdot
.42277 .5817 Mdot
.60696 .69352 Mdot
.59462 .70378 Mdot
.36673 .36246 Mdot
.62942 .50201 Mdot
.34121 .36115 Mdot
.66964 .54463 Mdot
.55943 .69888 Mdot
.37642 .51976 Mdot
.57406 .68994 Mdot
.38963 .53463 Mdot
.51456 .14889 Mdot
.36762 .56227 Mdot
.18688 .56049 Mdot
.28272 .47005 Mdot
.56982 .38272 Mdot
.74097 .4787 Mdot
.55602 .38785 Mdot
.57366 .6731 Mdot
.37848 .51468 Mdot
.40761 .38166 Mdot
.80342 .45416 Mdot
.54045 .73156 Mdot
.58252 .34205 Mdot
.54693 .40809 Mdot
.65761 .54391 Mdot
.44891 .57054 Mdot
.41981 .58465 Mdot
.57566 .36354 Mdot
.57841 .63889 Mdot
.53679 .69951 Mdot
.37614 .54014 Mdot
.41582 .56187 Mdot
.56712 .38318 Mdot
.8175 .60152 Mdot
.52123 .72241 Mdot
.37005 .54976 Mdot
.6258 .2923 Mdot
.70044 .54416 Mdot
.45227 .5253 Mdot
.4499 .60935 Mdot
.39865 .35542 Mdot
.30133 .65739 Mdot
.34468 .23517 Mdot
.6648 .55138 Mdot
.56674 .3974 Mdot
.38569 .53073 Mdot
.55849 .39592 Mdot
.36314 .51163 Mdot
.62903 .66247 Mdot
.5675 .32758 Mdot
.42225 .52219 Mdot
.37954 .49037 Mdot
.56643 .65999 Mdot
.4427 .56268 Mdot
.49337 .78555 Mdot
.59651 .35885 Mdot
.41021 .51181 Mdot
.40163 .66291 Mdot
.68944 .53029 Mdot
.43245 .5008 Mdot
.40242 .33253 Mdot
.24831 .51151 Mdot
.66766 .64991 Mdot
.55204 .22641 Mdot
.37391 .3444 Mdot
.39192 .59517 Mdot
.56012 .40999 Mdot
.70122 .51597 Mdot
.19448 .58484 Mdot
.41507 .59885 Mdot
.66339 .53905 Mdot
.65645 .50748 Mdot
.41912 .348 Mdot
.52922 .84121 Mdot
.34371 .53455 Mdot
.39498 .57977 Mdot
.40089 .76757 Mdot
.51033 .6423 Mdot
.37459 .56969 Mdot
.35066 .55567 Mdot
.6762 .50431 Mdot
.47525 .61427 Mdot
.48821 .7468 Mdot
.23049 .55964 Mdot
.71342 .53107 Mdot
.53004 .55215 Mdot
.53395 .35609 Mdot
.38866 .36685 Mdot
.53128 .66822 Mdot
.41893 .3758 Mdot
.53876 .3563 Mdot
.35281 .55809 Mdot
.63704 .50816 Mdot
.45784 .79566 Mdot
.68555 .50327 Mdot
.51881 .21525 Mdot
.5185 .63955 Mdot
.68488 .59924 Mdot
.35483 .84231 Mdot
.77644 .45404 Mdot
.72662 .5514 Mdot
.39913 .35153 Mdot
.49922 .343 Mdot
.41545 .56001 Mdot
.55572 .79378 Mdot
.35819 .57149 Mdot
.38305 .66213 Mdot
.55214 .39945 Mdot
.53608 .39433 Mdot
.36961 .54644 Mdot
.24273 .45937 Mdot
.69964 .51369 Mdot
.69576 .54443 Mdot
.42431 .52151 Mdot
.67011 .52438 Mdot
.39402 .57275 Mdot
.58533 .37049 Mdot
.35806 .80233 Mdot
.40041 .556 Mdot
.42541 .61445 Mdot
.63409 .65681 Mdot
.83395 .50426 Mdot
.43942 .23412 Mdot
.74807 .7176 Mdot
.42762 .17517 Mdot
.66921 .52312 Mdot
.4562 .56916 Mdot
.52988 .55378 Mdot
.5344 .34241 Mdot
.62843 .54563 Mdot
.36442 .56983 Mdot
.36373 .57395 Mdot
.36884 .59182 Mdot
.42756 .55385 Mdot
.58251 .78734 Mdot
.46741 .51042 Mdot
.35929 .68694 Mdot
.43992 .54955 Mdot
.31713 .34395 Mdot
.64159 .52403 Mdot
.59436 .67677 Mdot
.36487 .34769 Mdot
.44349 .5636 Mdot
.49214 .58318 Mdot
.67563 .48815 Mdot
.38073 .16057 Mdot
.64896 .53407 Mdot
.56223 .35083 Mdot
.67377 .49305 Mdot
.40896 .54252 Mdot
.54701 .68037 Mdot
.54176 .52613 Mdot
.74386 .40963 Mdot
.57872 .39201 Mdot
.39834 .54165 Mdot
.61782 .43745 Mdot
.58769 .3822 Mdot
.78485 .39692 Mdot
.54018 .67313 Mdot
.27635 .41325 Mdot
.57275 .69474 Mdot
.41518 .51607 Mdot
.40914 .51374 Mdot
.71978 .55153 Mdot
.66691 .49203 Mdot
.57182 .69675 Mdot
.53699 .84769 Mdot
.42958 .34879 Mdot
.56094 .67415 Mdot
.34431 .58708 Mdot
.50745 .45926 Mdot
.54962 .67799 Mdot
.35015 .33956 Mdot
.66403 .50438 Mdot
.50324 .66955 Mdot
.34215 .57465 Mdot
.34627 .27131 Mdot
.39089 .32979 Mdot
.56804 .32035 Mdot
.38357 .41194 Mdot
.59801 .35748 Mdot
.62966 .50607 Mdot
.55801 .38816 Mdot
.6986 .51748 Mdot
.67568 .66964 Mdot
.51269 .58685 Mdot
.72565 .53321 Mdot
.63421 .49946 Mdot
.55923 .38562 Mdot
.37152 .53844 Mdot
.34718 .33587 Mdot
.45754 .55327 Mdot
.33957 .54252 Mdot
.70264 .52732 Mdot
.54975 .65085 Mdot
.59114 .67771 Mdot
.29885 .35164 Mdot
.5566 .70963 Mdot
.58248 .34505 Mdot
.22916 .67366 Mdot
.64631 .32242 Mdot
.68401 .54132 Mdot
.66919 .49002 Mdot
.41895 .52393 Mdot
.56744 .36628 Mdot
.5684 .40017 Mdot
.65933 .54364 Mdot
.5761 .60762 Mdot
.45186 .60059 Mdot
.58217 .66517 Mdot
.5093 .65111 Mdot
.56032 .68639 Mdot
.546 .64198 Mdot
.51171 .74412 Mdot
.65115 .50362 Mdot
.55636 .65397 Mdot
.42737 .52816 Mdot
.36455 .57265 Mdot
.50016 .50891 Mdot
.37761 .34635 Mdot
.42869 .59819 Mdot
.41356 .49785 Mdot
.42879 .57883 Mdot
.55282 .33783 Mdot
.31988 .50365 Mdot
.57183 .32934 Mdot
.56032 .40734 Mdot
.56289 .4048 Mdot
.67287 .376 Mdot
.26773 .35056 Mdot
.44134 .18875 Mdot
.36783 .52595 Mdot
.75837 .64309 Mdot
.55662 .37081 Mdot
.25991 .70389 Mdot
.73969 .64195 Mdot
.40213 .60119 Mdot
.47539 .3281 Mdot
.57451 .36784 Mdot
.56745 .7113 Mdot
.36518 .56719 Mdot
.60624 .38673 Mdot
.40257 .33164 Mdot
.4338 .52347 Mdot
.57059 .32653 Mdot
.54313 .69401 Mdot
.36426 .36162 Mdot
.5032 .65699 Mdot
.55967 .40416 Mdot
.39771 .48816 Mdot
.123 .53295 Mdot
.55308 .41254 Mdot
.79545 .58572 Mdot
.43481 .64236 Mdot
.37414 .53953 Mdot
.60188 .35092 Mdot
.50489 .64179 Mdot
.62947 .51626 Mdot
.5682 .45011 Mdot
.50888 .67666 Mdot
.53537 .39368 Mdot
.58914 .3438 Mdot
.57743 .39343 Mdot
.51269 .66754 Mdot
.39205 .60947 Mdot
.517 .68586 Mdot
.67715 .49491 Mdot
.42177 .53406 Mdot
.5287 .18226 Mdot
.74884 .6541 Mdot
.57619 .69011 Mdot
.55598 .34788 Mdot
.39255 .32561 Mdot
.40795 .55123 Mdot
.74831 .66236 Mdot
.3747 .53366 Mdot
.7052 .53002 Mdot
.26706 .66238 Mdot
.49212 .79929 Mdot
.45134 .54974 Mdot
.42031 .52544 Mdot
.69793 .54202 Mdot
.39721 .54643 Mdot
.44918 .56598 Mdot
.67806 .38025 Mdot
.51723 .68014 Mdot
.40646 .56345 Mdot
.54215 .37109 Mdot
.67592 .34987 Mdot
.44601 .60442 Mdot
.5895 .29582 Mdot
.26805 .43247 Mdot
.27484 .67301 Mdot
.35744 .57025 Mdot
.42697 .44387 Mdot
.42667 .56359 Mdot
.3883 .58997 Mdot
.40409 .52085 Mdot
.61445 .79024 Mdot
.56317 .32789 Mdot
.57359 .38954 Mdot
.3786 .33647 Mdot
.26929 .4285 Mdot
.39969 .3595 Mdot
.66299 .50305 Mdot
.52022 .26107 Mdot
.57088 .32902 Mdot
.55248 .70013 Mdot
.39752 .59335 Mdot
.55515 .41279 Mdot
.42552 .58374 Mdot
.40807 .54086 Mdot
.59758 .37936 Mdot
.54051 .3434 Mdot
.58061 .24464 Mdot
.38288 .33556 Mdot
.55191 .66615 Mdot
.44769 .58205 Mdot
.42744 .36746 Mdot
.34664 .55309 Mdot
.31951 .43333 Mdot
.5537 .66983 Mdot
.51725 .6828 Mdot
.59373 .68836 Mdot
.35311 .55597 Mdot
.40703 .5458 Mdot
.68659 .5134 Mdot
.57809 .69309 Mdot
.68687 .53129 Mdot
.58637 .47916 Mdot
.53433 .3003 Mdot
.36437 .56998 Mdot
.75426 .55256 Mdot
.38547 .35713 Mdot
.57153 .34027 Mdot
.21859 .40956 Mdot
.37947 .33522 Mdot
.38706 .53506 Mdot
.57944 .39944 Mdot
.38917 .34201 Mdot
.28236 .59148 Mdot
.33746 .21074 Mdot
.37927 .32975 Mdot
.42822 .52879 Mdot
.4786 .59242 Mdot
.73625 .73023 Mdot
.37299 .3407 Mdot
.65234 .49602 Mdot
.35353 .55544 Mdot
.57403 .72794 Mdot
.41783 .37733 Mdot
.74861 .38483 Mdot
.57888 .37159 Mdot
.34974 .25442 Mdot
.40613 .47598 Mdot
.51534 .80847 Mdot
.37915 .3584 Mdot
.53448 .67863 Mdot
.40596 .63629 Mdot
.42482 .57661 Mdot
.37516 .3382 Mdot
.71099 .51144 Mdot
.5819 .35753 Mdot
.70219 .37404 Mdot
.51212 .6665 Mdot
.69806 .58221 Mdot
.55247 .34727 Mdot
.77858 .5067 Mdot
.24557 .60093 Mdot
.45099 .51932 Mdot
.72153 .73626 Mdot
.63982 .4485 Mdot
.3739 .59843 Mdot
.40491 .32401 Mdot
.67384 .5541 Mdot
.63689 .5049 Mdot
.6645 .5287 Mdot
.6855 .67599 Mdot
.46794 .4645 Mdot
.6049 .34995 Mdot
.69124 .5701 Mdot
.38986 .36664 Mdot
.33617 .35664 Mdot
.34152 .52391 Mdot
.41063 .55763 Mdot
.4519 .56323 Mdot
.44233 .57144 Mdot
.42196 .57008 Mdot
.67889 .52733 Mdot
.6639 .67484 Mdot
.48235 .48332 Mdot
.55284 .67484 Mdot
.54858 .24965 Mdot
.55069 .38208 Mdot
.60478 .3477 Mdot
.39133 .33692 Mdot
.78875 .45447 Mdot
.54152 .32944 Mdot
.55258 .36158 Mdot
.40022 .60657 Mdot
.53119 .69827 Mdot
.4675 .61112 Mdot
.42398 .52686 Mdot
.58157 .34631 Mdot
.57924 .53843 Mdot
.50468 .76536 Mdot
.30046 .52477 Mdot
.37511 .31879 Mdot
.4798 .45452 Mdot
.38918 .32793 Mdot
.37361 .51577 Mdot
.2655 .71775 Mdot
.53943 .35441 Mdot
.56656 .35572 Mdot
.38067 .3548 Mdot
.60341 .72425 Mdot
.52726 .66069 Mdot
.74459 .53324 Mdot
.67286 .4987 Mdot
.3893 .51319 Mdot
.20311 .52739 Mdot
.32219 .61238 Mdot
.49224 .25448 Mdot
.66542 .53336 Mdot
.55333 .39342 Mdot
.45006 .53509 Mdot
.43082 .53366 Mdot
.38413 .35382 Mdot
.63396 .24415 Mdot
.43127 .50969 Mdot
.79585 .37397 Mdot
.24606 .35381 Mdot
.31117 .27969 Mdot
.42162 .5827 Mdot
.51519 .67679 Mdot
.55878 .32307 Mdot
.38911 .37197 Mdot
.33476 .57385 Mdot
.37331 .19577 Mdot
.52354 .64316 Mdot
.64844 .52555 Mdot
.55621 .51694 Mdot
.34963 .38072 Mdot
.35483 .57625 Mdot
.35848 .5684 Mdot
.3766 .58733 Mdot
.28293 .24511 Mdot
.55986 .33217 Mdot
.57294 .70326 Mdot
.41515 .34448 Mdot
.55488 .70712 Mdot
.56729 .38834 Mdot
.6811 .5901 Mdot
.36825 .53747 Mdot
.52109 .64282 Mdot
.53358 .67685 Mdot
.65179 .53734 Mdot
.63124 .52495 Mdot
.56835 .50204 Mdot
.36943 .56303 Mdot
.54348 .40952 Mdot
.56123 .65612 Mdot
.44543 .44049 Mdot
.40746 .35258 Mdot
.66791 .50301 Mdot
.4414 .55548 Mdot
.5497 .33683 Mdot
.33763 .52242 Mdot
.53937 .6624 Mdot
.55291 .36212 Mdot
.61687 .27529 Mdot
.37071 .35075 Mdot
.37697 .57799 Mdot
.41107 .39245 Mdot
.56858 .39785 Mdot
.41748 .55976 Mdot
.79267 .51669 Mdot
.35126 .34624 Mdot
.73788 .38752 Mdot
.57017 .40363 Mdot
.65115 .35728 Mdot
.53798 .70883 Mdot
.69453 .68922 Mdot
.5659 .35233 Mdot
.7752 .52609 Mdot
.6445 .26956 Mdot
.4519 .53447 Mdot
.56624 .692 Mdot
.6311 .4503 Mdot
.57317 .17557 Mdot
.79742 .62426 Mdot
.38758 .55048 Mdot
.60354 .38469 Mdot
.38512 .34944 Mdot
.68842 .54079 Mdot
.57868 .29109 Mdot
.35468 .33764 Mdot
.52961 .39268 Mdot
.40273 .52088 Mdot
.54026 .68691 Mdot
.66843 .50851 Mdot
.67112 .65467 Mdot
.54377 .37945 Mdot
.54608 .35745 Mdot
.45056 .53765 Mdot
.39657 .36336 Mdot
.72115 .6904 Mdot
.58463 .37683 Mdot
.26087 .34164 Mdot
.54758 .42002 Mdot
.43117 .35682 Mdot
.4317 .56004 Mdot
.29889 .34498 Mdot
.44445 .59845 Mdot
.81262 .5298 Mdot
.55491 .38289 Mdot
.54559 .66572 Mdot
.37009 .58943 Mdot
.24037 .55938 Mdot
.57901 .3438 Mdot
.46767 .44125 Mdot
.43432 .26207 Mdot
.65702 .50277 Mdot
.21651 .41305 Mdot
.38285 .57434 Mdot
.69942 .51382 Mdot
.38654 .35553 Mdot
.36972 .5551 Mdot
.41004 .5456 Mdot
.57628 .67025 Mdot
.65712 .54045 Mdot
.60823 .2466 Mdot
.68071 .49183 Mdot
.63832 .5132 Mdot
.57056 .65644 Mdot
.40579 .57387 Mdot
.56064 .35081 Mdot
.57383 .36613 Mdot
.33098 .55001 Mdot
.31376 .78343 Mdot
.52445 .65865 Mdot
.57019 .31757 Mdot
.27172 .25877 Mdot
.33628 .51161 Mdot
.21206 .43394 Mdot
.64522 .24874 Mdot
.70843 .5389 Mdot
.431 .53043 Mdot
.54561 .69446 Mdot
.48988 .39296 Mdot
.54925 .35464 Mdot
.35171 .58198 Mdot
.66656 .51015 Mdot
.39713 .33036 Mdot
.59465 .366 Mdot
.50288 .25185 Mdot
.38523 .586 Mdot
.46949 .32669 Mdot
.60553 .36938 Mdot
.69511 .22958 Mdot
.71324 .45143 Mdot
.56743 .68769 Mdot
.41085 .53981 Mdot
.56765 .71326 Mdot
.41155 .34142 Mdot
.55677 .51395 Mdot
.66227 .50745 Mdot
.43319 .47776 Mdot
.19277 .65407 Mdot
.5759 .39492 Mdot
.57281 .70501 Mdot
.45078 .54659 Mdot
.62343 .6595 Mdot
.3902 .57546 Mdot
.47984 .61702 Mdot
.40127 .41134 Mdot
.69907 .53186 Mdot
.69486 .51205 Mdot
.42144 .55238 Mdot
.42714 .35474 Mdot
.54762 .38282 Mdot
.58025 .35038 Mdot
.81189 .34443 Mdot
.61094 .58709 Mdot
.23361 .49124 Mdot
.36656 .57576 Mdot
.53483 .39868 Mdot
.67689 .32883 Mdot
.66927 .53977 Mdot
.3277 .54046 Mdot
.59269 .38354 Mdot
.37474 .2774 Mdot
.25524 .53207 Mdot
.42574 .57025 Mdot
.40511 .61459 Mdot
.6672 .49705 Mdot
.45062 .4576 Mdot
.54245 .39319 Mdot
.36787 .49694 Mdot
.72926 .53725 Mdot
.26583 .56247 Mdot
.28371 .27671 Mdot
.55223 .66612 Mdot
.48667 .24119 Mdot
.6797 .52705 Mdot
.41308 .61644 Mdot
.4179 .37073 Mdot
.54725 .3285 Mdot
.55639 .33183 Mdot
.392 .52577 Mdot
.40192 .50558 Mdot
.23222 .40978 Mdot
.54654 .70365 Mdot
.64098 .52107 Mdot
.36009 .5535 Mdot
.73829 .59211 Mdot
.44532 .56973 Mdot
.69089 .51884 Mdot
.11705 .53873 Mdot
.45596 .55281 Mdot
.39424 .57777 Mdot
.73684 .67505 Mdot
.50677 .66651 Mdot
.57623 .7043 Mdot
.19265 .48165 Mdot
.36727 .57601 Mdot
.232 .38348 Mdot
.54802 .66147 Mdot
.52934 .65908 Mdot
.6928 .38774 Mdot
.40746 .55369 Mdot
.38988 .46333 Mdot
.70695 .53007 Mdot
.6404 .50606 Mdot
.51139 .67615 Mdot
.44801 .52091 Mdot
.65596 .54772 Mdot
.63839 .76533 Mdot
.56634 .3679 Mdot
.27843 .73524 Mdot
.52296 .65369 Mdot
.65413 .4689 Mdot
.6685 .53737 Mdot
.38924 .15997 Mdot
.59811 .42436 Mdot
.36897 .54 Mdot
.37519 .58013 Mdot
.38555 .36112 Mdot
.45346 .56863 Mdot
.5375 .39547 Mdot
.67045 .52497 Mdot
.34309 .64734 Mdot
.55773 .67061 Mdot
.37945 .56701 Mdot
.78855 .43491 Mdot
.74614 .35813 Mdot
.48679 .23208 Mdot
.52384 .66566 Mdot
.57129 .68419 Mdot
.53879 .38388 Mdot
.60354 .38368 Mdot
.41495 .5773 Mdot
.68776 .54636 Mdot
.57777 .69258 Mdot
.6966 .52254 Mdot
.54057 .35296 Mdot
.55684 .35428 Mdot
.55389 .33 Mdot
.34981 .51241 Mdot
.54716 .36568 Mdot
.58732 .28036 Mdot
.69853 .57969 Mdot
.58316 .67505 Mdot
.21868 .36401 Mdot
.67807 .65524 Mdot
.57595 .74909 Mdot
.41888 .37836 Mdot
.57098 .39816 Mdot
.68472 .49829 Mdot
.42808 .54363 Mdot
.43588 .57441 Mdot
.63332 .32637 Mdot
.70014 .51034 Mdot
.40886 .34101 Mdot
.69335 .50868 Mdot
.41922 .34783 Mdot
.44172 .29424 Mdot
.44541 .57889 Mdot
.36809 .51137 Mdot
.6753 .52952 Mdot
.54958 .36467 Mdot
.57751 .38193 Mdot
.37345 .33498 Mdot
.59648 .54171 Mdot
.58818 .38243 Mdot
.52962 .6548 Mdot
.52556 .74853 Mdot
.58826 .34217 Mdot
.36823 .56829 Mdot
.3461 .4234 Mdot
.54184 .80564 Mdot
.43265 .6097 Mdot
.68663 .38468 Mdot
.44565 .8044 Mdot
.39107 .59774 Mdot
.51409 .82323 Mdot
.64354 .40023 Mdot
.53769 .70735 Mdot
.54931 .3978 Mdot
.54192 .32347 Mdot
.31634 .56471 Mdot
.36308 .33781 Mdot
.33215 .56459 Mdot
.5192 .65202 Mdot
.53484 .71571 Mdot
.3195 .28663 Mdot
.80396 .56948 Mdot
.38709 .34663 Mdot
.38462 .34269 Mdot
.56851 .35048 Mdot
.85639 .52531 Mdot
.46719 .53222 Mdot
.40603 .3407 Mdot
.52305 .59135 Mdot
.39932 .52184 Mdot
.26869 .46726 Mdot
.45325 .34361 Mdot
.51224 .67334 Mdot
.31491 .33524 Mdot
.56819 .34494 Mdot
.55492 .71029 Mdot
.72347 .60732 Mdot
.42383 .60301 Mdot
.55516 .67092 Mdot
.6933 .51829 Mdot
.72986 .44372 Mdot
.53418 .65066 Mdot
.33425 .42627 Mdot
.66529 .54717 Mdot
.45222 .44172 Mdot
.28586 .3768 Mdot
.59117 .88272 Mdot
.67568 .52477 Mdot
.58503 .34169 Mdot
.57463 .36535 Mdot
.5792 .34974 Mdot
.55045 .70686 Mdot
.56793 .39984 Mdot
.5502 .70367 Mdot
.75787 .6856 Mdot
.61127 .71303 Mdot
.40391 .34093 Mdot
.70687 .37839 Mdot
.55138 .69233 Mdot
.24775 .69946 Mdot
.2697 .76848 Mdot
.431 .5298 Mdot
.66502 .48737 Mdot
.39774 .3418 Mdot
.80255 .38417 Mdot
.39537 .35395 Mdot
.2943 .32161 Mdot
.27051 .6881 Mdot
.3887 .56824 Mdot
.45251 .74648 Mdot
.38053 .3725 Mdot
.52409 .67368 Mdot
.41653 .55819 Mdot
.52153 .43254 Mdot
.39355 .35705 Mdot
.41452 .33659 Mdot
.41251 .5706 Mdot
.55817 .6591 Mdot
.56262 .34449 Mdot
.65632 .49211 Mdot
.3962 .38405 Mdot
.45642 .63285 Mdot
.42577 .6092 Mdot
.37536 .52941 Mdot
.50278 .50557 Mdot
.44337 .35959 Mdot
.6692 .52235 Mdot
.57739 .81232 Mdot
.5782 .40276 Mdot
.53568 .4358 Mdot
.26919 .32544 Mdot
.66981 .38715 Mdot
.55697 .38147 Mdot
.56077 .39493 Mdot
.42157 .573 Mdot
.44263 .34213 Mdot
.27661 .69767 Mdot
.60945 .53344 Mdot
.56388 .32374 Mdot
.58203 .35399 Mdot
.55583 .71952 Mdot
.30806 .29189 Mdot
.3366 .57852 Mdot
.66401 .55147 Mdot
.55257 .33321 Mdot
.63032 .69762 Mdot
.39494 .36566 Mdot
.24876 .67577 Mdot
.4423 .58394 Mdot
.36583 .54381 Mdot
.65835 .51585 Mdot
.68231 .51095 Mdot
.4873 .39194 Mdot
.30278 .30169 Mdot
.46214 .80565 Mdot
.65247 .65379 Mdot
.29958 .68164 Mdot
.54919 .72095 Mdot
.57625 .68935 Mdot
.7599 .42404 Mdot
.67792 .48985 Mdot
.38237 .59502 Mdot
.56837 .70242 Mdot
.563 .44037 Mdot
.53848 .74185 Mdot
.24764 .47708 Mdot
.21925 .43965 Mdot
.39168 .53619 Mdot
.52548 .68913 Mdot
.5076 .66414 Mdot
.52405 .6308 Mdot
.63029 .42392 Mdot
.40902 .58128 Mdot
.38973 .54281 Mdot
.40627 .59623 Mdot
.6008 .63863 Mdot
.402 .58904 Mdot
.68673 .69135 Mdot
.55009 .49543 Mdot
.30558 .65238 Mdot
.3813 .49498 Mdot
.70557 .54795 Mdot
.3538 .57166 Mdot
.4262 .35295 Mdot
.40564 .5179 Mdot
.24684 .48378 Mdot
.6569 .5348 Mdot
.52418 .72563 Mdot
.67918 .66486 Mdot
.37708 .59759 Mdot
.37068 .36998 Mdot
.69911 .46412 Mdot
.51236 .18036 Mdot
.3966 .39673 Mdot
.5281 .65447 Mdot
.56232 .37291 Mdot
.68814 .5003 Mdot
.55912 .35655 Mdot
.36809 .50492 Mdot
.76535 .43891 Mdot
.74785 .3392 Mdot
.59178 .48324 Mdot
.44204 .56998 Mdot
.37068 .47701 Mdot
.53326 .65834 Mdot
.58266 .39856 Mdot
.58978 .72402 Mdot
.36953 .58737 Mdot
.41802 .35244 Mdot
.38907 .35796 Mdot
.5774 .44938 Mdot
.67948 .24356 Mdot
.63174 .74275 Mdot
.66094 .51682 Mdot
.58669 .36917 Mdot
.39937 .37795 Mdot
.78049 .57039 Mdot
.63087 .52586 Mdot
.70194 .53955 Mdot
.6494 .53064 Mdot
.35178 .54274 Mdot
.56718 .3272 Mdot
.30715 .65133 Mdot
.5334 .39469 Mdot
.39915 .54456 Mdot
.55707 .33522 Mdot
.58965 .38642 Mdot
.4 .37504 Mdot
.64444 .52694 Mdot
.53545 .36646 Mdot
.41124 .51373 Mdot
.55312 .6602 Mdot
.69557 .48343 Mdot
.27465 .49376 Mdot
.80569 .55637 Mdot
.36459 .64525 Mdot
.51157 .65094 Mdot
.57277 .18064 Mdot
.70351 .54152 Mdot
.58335 .61296 Mdot
.57232 .24409 Mdot
.36901 .52186 Mdot
.27592 .75737 Mdot
.60247 .3441 Mdot
.59588 .37642 Mdot
.43044 .55945 Mdot
.50503 .39135 Mdot
.38425 .56981 Mdot
.54599 .34984 Mdot
.62117 .29795 Mdot
.48711 .6228 Mdot
.54911 .37048 Mdot
.3604 .50005 Mdot
.41471 .54893 Mdot
.51424 .67861 Mdot
.60159 .35232 Mdot
.32527 .54617 Mdot
.79643 .32462 Mdot
.68432 .5147 Mdot
.63296 .43566 Mdot
.35015 .43234 Mdot
.68122 .52735 Mdot
.56206 .67746 Mdot
.3395 .53674 Mdot
.38548 .35411 Mdot
.55038 .69324 Mdot
.25218 .54696 Mdot
.37337 .35807 Mdot
.25292 .72059 Mdot
.50948 .66373 Mdot
.59231 .34816 Mdot
.42261 .36672 Mdot
.45308 .57809 Mdot
.54876 .3276 Mdot
.7374 .46951 Mdot
.55567 .38027 Mdot
.41821 .58528 Mdot
.71087 .36302 Mdot
.63983 .5171 Mdot
.38467 .5516 Mdot
.59799 .3716 Mdot
.68046 .377 Mdot
.35371 .53824 Mdot
.42408 .55823 Mdot
.28447 .28648 Mdot
.21547 .62638 Mdot
.4021 .35229 Mdot
.51258 .63355 Mdot
.42705 .52779 Mdot
.41002 .33514 Mdot
.49471 .29932 Mdot
.35637 .54647 Mdot
.52585 .64194 Mdot
.34484 .49916 Mdot
.60419 .35867 Mdot
.68757 .5264 Mdot
.60361 .47581 Mdot
.40257 .33173 Mdot
.73435 .76323 Mdot
.53085 .36959 Mdot
.3637 .51582 Mdot
.44517 .56038 Mdot
.4137 .23361 Mdot
.53924 .70762 Mdot
.3716 .78243 Mdot
.37685 .57816 Mdot
.59478 .63198 Mdot
.37268 .55675 Mdot
.58703 .32729 Mdot
.52727 .65972 Mdot
.39784 .58148 Mdot
.73356 .5685 Mdot
.43404 .61224 Mdot
.37893 .33775 Mdot
.7416 .67426 Mdot
.40821 .60946 Mdot
.1528 .61678 Mdot
.42704 .3081 Mdot
.54746 .37149 Mdot
.74127 .36641 Mdot
.86037 .39622 Mdot
.68902 .67154 Mdot
.55786 .70565 Mdot
.68021 .27518 Mdot
.55983 .35119 Mdot
.70899 .33834 Mdot
.56433 .17526 Mdot
.41799 .54503 Mdot
.35497 .57682 Mdot
.34952 .29561 Mdot
.55856 .40574 Mdot
.53128 .40162 Mdot
.42349 .50918 Mdot
.4017 .61632 Mdot
.55063 .35783 Mdot
.40023 .50885 Mdot
.39551 .50112 Mdot
.65517 .48993 Mdot
.52225 .64685 Mdot
.69843 .53595 Mdot
.66489 .5496 Mdot
.67688 .74306 Mdot
.40642 .29288 Mdot
.68983 .51976 Mdot
.69201 .55157 Mdot
.26697 .47184 Mdot
.24901 .40613 Mdot
.41629 .37802 Mdot
.71725 .26015 Mdot
.58021 .35479 Mdot
.40506 .57837 Mdot
.50908 .65621 Mdot
.47545 .80375 Mdot
.54894 .28132 Mdot
.29261 .73436 Mdot
.37616 .59168 Mdot
.57523 .34302 Mdot
.63061 .42384 Mdot
.4637 .61615 Mdot
.59038 .40587 Mdot
.35822 .55612 Mdot
.52764 .38477 Mdot
.46749 .70639 Mdot
.77416 .52389 Mdot
.53978 .41292 Mdot
.58097 .66424 Mdot
.36383 .55043 Mdot
.51897 .65432 Mdot
.67373 .53799 Mdot
.4225 .37057 Mdot
.40473 .35465 Mdot
.41568 .56365 Mdot
.4159 .49087 Mdot
.45299 .30808 Mdot
.40901 .5506 Mdot
.40631 .5229 Mdot
.64414 .39876 Mdot
.41031 .52217 Mdot
.43496 .58214 Mdot
.41906 .59194 Mdot
.34826 .57605 Mdot
.63923 .50934 Mdot
.78768 .4499 Mdot
.36262 .61072 Mdot
.38372 .61767 Mdot
.63297 .52385 Mdot
.6182 .24384 Mdot
.67876 .55084 Mdot
.51743 .17551 Mdot
.705 .52438 Mdot
.40995 .35019 Mdot
.47474 .21329 Mdot
.43306 .49282 Mdot
.55563 .65021 Mdot
.62544 .52136 Mdot
.41572 .34296 Mdot
.66715 .52714 Mdot
.55368 .34325 Mdot
.29591 .25376 Mdot
.49029 .63669 Mdot
.47302 .4969 Mdot
.62174 .52818 Mdot
.76736 .46249 Mdot
.53323 .37513 Mdot
.51784 .65907 Mdot
.49349 .7634 Mdot
.44164 .57478 Mdot
.41368 .33737 Mdot
.41575 .57427 Mdot
.64279 .52913 Mdot
.57204 .34561 Mdot
.78498 .63535 Mdot
.38425 .35419 Mdot
.23485 .34449 Mdot
.5771 .37661 Mdot
.4235 .59285 Mdot
.65991 .54937 Mdot
.18826 .42828 Mdot
.70048 .53245 Mdot
.32184 .73712 Mdot
.55466 .71549 Mdot
.76114 .70529 Mdot
.55903 .69493 Mdot
.74826 .47719 Mdot
.1736 .37969 Mdot
.79539 .4508 Mdot
.55749 .65995 Mdot
.62461 .57734 Mdot
.38737 .53197 Mdot
.37444 .53019 Mdot
.78646 .57335 Mdot
.51375 .63372 Mdot
.43848 .54303 Mdot
.6417 .31323 Mdot
.66535 .58339 Mdot
.20709 .48137 Mdot
.55478 .39081 Mdot
.38079 .57156 Mdot
.71175 .55335 Mdot
.70293 .51555 Mdot
.5305 .38366 Mdot
.70157 .54157 Mdot
.39085 .54453 Mdot
.55275 .69276 Mdot
.53458 .31213 Mdot
.41053 .36262 Mdot
.83035 .45231 Mdot
.42561 .34104 Mdot
.55751 .38166 Mdot
.45824 .5551 Mdot
.55609 .35524 Mdot
.86813 .37632 Mdot
.38396 .54191 Mdot
.54674 .66185 Mdot
.42418 .52928 Mdot
.36709 .54907 Mdot
.35764 .5838 Mdot
.55444 .3482 Mdot
.3006 .507 Mdot
.40659 .5112 Mdot
.66158 .50666 Mdot
.30738 .67082 Mdot
.40514 .60826 Mdot
.51753 .34193 Mdot
.25296 .42923 Mdot
.66438 .5674 Mdot
.50833 .67984 Mdot
.55042 .3754 Mdot
.55932 .66876 Mdot
.60192 .67606 Mdot
.56182 .67752 Mdot
.35045 .72238 Mdot
.49244 .75428 Mdot
.26817 .59574 Mdot
.39587 .66133 Mdot
.56914 .55835 Mdot
.51314 .63354 Mdot
.4457 .36892 Mdot
.57492 .67652 Mdot
.50847 .67414 Mdot
.06972 .48733 Mdot
.55736 .64856 Mdot
.37005 .57211 Mdot
.41439 .60452 Mdot
.77448 .48347 Mdot
.30541 .4225 Mdot
.42399 .53473 Mdot
.43211 .54047 Mdot
.4091 .37614 Mdot
.58637 .63349 Mdot
.7484 .39659 Mdot
.21113 .63744 Mdot
.72298 .33339 Mdot
.41455 .57185 Mdot
.42495 .52552 Mdot
.44552 .6184 Mdot
.16038 .52085 Mdot
.6779 .75469 Mdot
.50221 .68487 Mdot
.45104 .61201 Mdot
.81348 .48685 Mdot
.35865 .5827 Mdot
.35095 .55687 Mdot
.38983 .53474 Mdot
.56057 .35046 Mdot
.50041 .65836 Mdot
.34139 .56472 Mdot
.35696 .2894 Mdot
.35522 .56135 Mdot
.67347 .38498 Mdot
.82561 .61463 Mdot
.38319 .57488 Mdot
.50121 .67274 Mdot
.3782 .52655 Mdot
.52726 .699 Mdot
.52134 .67663 Mdot
.4665 .56881 Mdot
.30227 .68391 Mdot
.52376 .70486 Mdot
.39991 .54435 Mdot
.56505 .33964 Mdot
.68862 .22965 Mdot
.41673 .58608 Mdot
.42189 .37292 Mdot
.37378 .57909 Mdot
.37402 .37546 Mdot
.41038 .52574 Mdot
.53019 .37036 Mdot
.51397 .80322 Mdot
.56819 .35419 Mdot
.70734 .74896 Mdot
.54624 .33677 Mdot
.27274 .29345 Mdot
.51271 .64301 Mdot
.70771 .37137 Mdot
.42832 .82158 Mdot
.64736 .42203 Mdot
.45578 .42366 Mdot
.52349 .49258 Mdot
.6891 .5462 Mdot
.5561 .71331 Mdot
.54712 .58563 Mdot
.58204 .25576 Mdot
.51863 .2281 Mdot
.59025 .37468 Mdot
.52605 .84486 Mdot
.32541 .77671 Mdot
.38385 .51062 Mdot
.43421 .75333 Mdot
.38335 .70504 Mdot
.35538 .58034 Mdot
.34144 .55892 Mdot
.63975 .36713 Mdot
.41879 .51494 Mdot
.74228 .58598 Mdot
.56066 .38338 Mdot
.41607 .34226 Mdot
.5386 .65815 Mdot
.39919 .33015 Mdot
.57264 .24864 Mdot
.51854 .49061 Mdot
.54563 .34824 Mdot
.40098 .61264 Mdot
.43086 .54326 Mdot
.52227 .6918 Mdot
.55727 .73611 Mdot
.56863 .66389 Mdot
.39154 .34547 Mdot
.56623 .38113 Mdot
.56331 .7935 Mdot
.43564 .54874 Mdot
.53476 .67666 Mdot
.4575 .41162 Mdot
.42892 .52956 Mdot
.67636 .53376 Mdot
.38288 .53426 Mdot
.55135 .65617 Mdot
.41058 .52233 Mdot
.55954 .6965 Mdot
.56338 .37028 Mdot
.40459 .60261 Mdot
.42955 .56484 Mdot
.20716 .39162 Mdot
.41154 .34519 Mdot
.51979 .63929 Mdot
.60292 .431 Mdot
.44812 .55329 Mdot
.71019 .39888 Mdot
.35929 .56047 Mdot
.57875 .75522 Mdot
.35979 .52483 Mdot
.64265 .42014 Mdot
.34258 .59476 Mdot
.41335 .58619 Mdot
.47859 .40487 Mdot
.38054 .71323 Mdot
.4953 .67802 Mdot
.67472 .55525 Mdot
.5418 .63891 Mdot
.21069 .48313 Mdot
.55197 .42353 Mdot
.59338 .39302 Mdot
.32858 .35938 Mdot
.34941 .58029 Mdot
.39127 .56955 Mdot
.67627 .55944 Mdot
.38128 .34184 Mdot
.52371 .66729 Mdot
.41908 .34781 Mdot
.22608 .38211 Mdot
.3762 .35267 Mdot
.59752 .33707 Mdot
.47108 .32582 Mdot
.58226 .78453 Mdot
.40676 .3764 Mdot
.55739 .65795 Mdot
.5135 .31667 Mdot
.35492 .58741 Mdot
.43587 .31631 Mdot
.41795 .3595 Mdot
.59573 .83802 Mdot
.43404 .5825 Mdot
.45133 .42315 Mdot
.69303 .52699 Mdot
.41614 .37233 Mdot
.67094 .5457 Mdot
.42632 .54522 Mdot
.74003 .38765 Mdot
.5603 .7045 Mdot
.64106 .53264 Mdot
.42371 .4975 Mdot
.39789 .34057 Mdot
.56037 .32953 Mdot
.65079 .55263 Mdot
.66473 .55274 Mdot
.63106 .23956 Mdot
.77006 .66335 Mdot
.5687 .37955 Mdot
.23522 .58956 Mdot
.70681 .52503 Mdot
.36562 .59422 Mdot
.56935 .61639 Mdot
.36806 .54027 Mdot
.67148 .71378 Mdot
.54962 .38066 Mdot
.77868 .464 Mdot
.42172 .52493 Mdot
.39282 .59419 Mdot
.49392 .65935 Mdot
.57416 .35824 Mdot
.54956 .68109 Mdot
.53979 .63639 Mdot
.56502 .36965 Mdot
.56533 .69019 Mdot
.3756 .36689 Mdot
.65523 .60195 Mdot
.67561 .49895 Mdot
.65284 .5083 Mdot
.58108 .35085 Mdot
.54474 .37303 Mdot
.55366 .36055 Mdot
.38238 .53425 Mdot
.52394 .66268 Mdot
.41135 .5359 Mdot
.35386 .56609 Mdot
.29195 .66263 Mdot
.50363 .66159 Mdot
.39921 .53396 Mdot
.50836 .42174 Mdot
.41892 .31433 Mdot
.56442 .33804 Mdot
.69073 .52246 Mdot
.6703 .33081 Mdot
.73389 .47339 Mdot
.37663 .56953 Mdot
.38741 .27877 Mdot
.56387 .66204 Mdot
.38834 .35463 Mdot
.43572 .3477 Mdot
.39761 .35302 Mdot
.6091 .50331 Mdot
.51701 .63455 Mdot
.21448 .64691 Mdot
.38528 .57174 Mdot
.4981 .49681 Mdot
.5122 .58057 Mdot
.4365 .29719 Mdot
.688 .5194 Mdot
.42987 .53296 Mdot
.60168 .48145 Mdot
.5109 .77417 Mdot
.37031 .5413 Mdot
.39197 .60715 Mdot
.61875 .27911 Mdot
.33598 .50454 Mdot
.56995 .71514 Mdot
.1906 .4346 Mdot
.45351 .55695 Mdot
.62725 .70211 Mdot
.83983 .45914 Mdot
.36714 .56404 Mdot
.38002 .58987 Mdot
.43763 .56662 Mdot
.40179 .51718 Mdot
.51287 .69129 Mdot
.29746 .3869 Mdot
.71042 .53457 Mdot
.49191 .49235 Mdot
.64256 .49933 Mdot
.54172 .33651 Mdot
.78454 .46379 Mdot
.56009 .71391 Mdot
.38536 .36069 Mdot
.79121 .39824 Mdot
.18543 .53667 Mdot
.54347 .39387 Mdot
.63827 .76274 Mdot
.41655 .35332 Mdot
.37531 .59978 Mdot
.37712 .37281 Mdot
.57383 .3306 Mdot
.65584 .504 Mdot
.36783 .60134 Mdot
.57454 .67859 Mdot
.53064 .65016 Mdot
.43475 .53593 Mdot
.81129 .47037 Mdot
.68139 .53368 Mdot
.64945 .54878 Mdot
.35478 .54261 Mdot
.45243 .57871 Mdot
.5533 .68191 Mdot
.58413 .37161 Mdot
.23344 .52946 Mdot
.39165 .33576 Mdot
.34478 .5174 Mdot
.40203 .52027 Mdot
.27641 .31543 Mdot
.66543 .50384 Mdot
.60108 .39109 Mdot
.36317 .52644 Mdot
.64411 .65051 Mdot
.36567 .52513 Mdot
.45976 .60846 Mdot
.56748 .33906 Mdot
.35289 .60782 Mdot
.37805 .50898 Mdot
.49345 .61394 Mdot
.68661 .54405 Mdot
.55066 .66775 Mdot
.5095 .62626 Mdot
.51301 .5414 Mdot
.67401 .53335 Mdot
.39296 .53023 Mdot
.68105 .51676 Mdot
.35716 .54638 Mdot
.42684 .52329 Mdot
.6912 .51937 Mdot
.55047 .68204 Mdot
.67951 .27831 Mdot
.78757 .44237 Mdot
.40028 .51555 Mdot
.44614 .52665 Mdot
.29946 .40288 Mdot
.30532 .50104 Mdot
.36439 .58473 Mdot
.54562 .65379 Mdot
.43385 .55354 Mdot
.66544 .54253 Mdot
.38295 .3738 Mdot
.55306 .65922 Mdot
.57523 .38741 Mdot
.5379 .38766 Mdot
.68309 .66607 Mdot
.58163 .39582 Mdot
.34887 .56822 Mdot
.59758 .70342 Mdot
.49835 .62867 Mdot
.82914 .48014 Mdot
.5684 .36777 Mdot
.4126 .38113 Mdot
.4225 .55892 Mdot
.34674 .27066 Mdot
.71437 .55289 Mdot
.18297 .67881 Mdot
.2427 .69699 Mdot
.37101 .33 Mdot
.29364 .72884 Mdot
.53431 .35226 Mdot
.36846 .5086 Mdot
.4259 .36665 Mdot
.53986 .38508 Mdot
.37733 .52089 Mdot
.46765 .58502 Mdot
.35669 .77228 Mdot
.54015 .53999 Mdot
.67978 .51442 Mdot
.56781 .40125 Mdot
.37753 .3225 Mdot
.6084 .35442 Mdot
.51415 .65288 Mdot
.40807 .58478 Mdot
.46004 .55624 Mdot
.58079 .38233 Mdot
.57731 .40548 Mdot
.39807 .53947 Mdot
.56695 .71342 Mdot
.63805 .37877 Mdot
.41091 .56685 Mdot
.58064 .57704 Mdot
.5522 .63278 Mdot
.56076 .38833 Mdot
.40107 .59304 Mdot
.41984 .41644 Mdot
.57945 .37569 Mdot
.56372 .33723 Mdot
.43054 .52878 Mdot
.37385 .36318 Mdot
.44919 .53341 Mdot
.69781 .51573 Mdot
.58114 .81877 Mdot
.66169 .54212 Mdot
.58148 .29429 Mdot
.42338 .49587 Mdot
.62093 .61731 Mdot
.51869 .69426 Mdot
.31202 .31076 Mdot
.64827 .31591 Mdot
.41714 .50478 Mdot
.65309 .22318 Mdot
.66444 .4679 Mdot
.80888 .4451 Mdot
.4365 .20085 Mdot
.40955 .3705 Mdot
.66552 .52881 Mdot
.3785 .58937 Mdot
.66143 .48797 Mdot
.42714 .36662 Mdot
.71015 .74413 Mdot
.41044 .59274 Mdot
.52959 .65997 Mdot
.39301 .53997 Mdot
.52448 .65374 Mdot
.42789 .52626 Mdot
.43099 .62229 Mdot
.65051 .34808 Mdot
.25601 .5304 Mdot
.3544 .53109 Mdot
.26469 .27834 Mdot
.44749 .39073 Mdot
.4075 .3366 Mdot
.41374 .54189 Mdot
.58102 .41318 Mdot
.70448 .51417 Mdot
.75983 .60187 Mdot
.55955 .35031 Mdot
.68059 .55313 Mdot
.56152 .6845 Mdot
.55466 .37705 Mdot
.53718 .39119 Mdot
.34703 .60417 Mdot
.36738 .35162 Mdot
.64482 .5197 Mdot
.39735 .58283 Mdot
.411 .5918 Mdot
.22343 .5763 Mdot
.55033 .27314 Mdot
.55972 .7393 Mdot
.17165 .58068 Mdot
.56378 .64613 Mdot
.40439 .33817 Mdot
.5605 .34569 Mdot
.35908 .57432 Mdot
.38805 .55242 Mdot
.69708 .37583 Mdot
.57912 .69411 Mdot
.56184 .51249 Mdot
.57808 .76179 Mdot
.6027 .42794 Mdot
.2618 .44687 Mdot
.54034 .65604 Mdot
.26229 .44946 Mdot
.42325 .33155 Mdot
.75913 .30896 Mdot
.2594 .5033 Mdot
.691 .52604 Mdot
.26497 .44384 Mdot
.531 .67777 Mdot
.39638 .51089 Mdot
.59205 .34656 Mdot
.58852 .38819 Mdot
.54945 .6732 Mdot
.61086 .38017 Mdot
.39601 .37309 Mdot
.38544 .58814 Mdot
.20912 .62178 Mdot
.69778 .6428 Mdot
.58621 .35446 Mdot
.45093 .62067 Mdot
.6504 .53169 Mdot
.43566 .53637 Mdot
.39847 .37668 Mdot
.67693 .52147 Mdot
.29901 .30934 Mdot
.71639 .57016 Mdot
.41938 .55875 Mdot
.28223 .29383 Mdot
.67341 .52903 Mdot
.32907 .47719 Mdot
.40888 .57365 Mdot
.7066 .52982 Mdot
.31557 .50525 Mdot
.73285 .44871 Mdot
.59062 .49073 Mdot
.56638 .17537 Mdot
.57825 .49058 Mdot
.59162 .35068 Mdot
.7516 .45683 Mdot
.64184 .44567 Mdot
.67812 .49458 Mdot
.59191 .40012 Mdot
.38259 .30895 Mdot
.67321 .54617 Mdot
.39542 .60577 Mdot
.36153 .56015 Mdot
.68984 .74979 Mdot
.64383 .46108 Mdot
.75505 .48899 Mdot
.73055 .64871 Mdot
.44863 .55721 Mdot
.45406 .54093 Mdot
.38977 .55667 Mdot
.53046 .7121 Mdot
.6721 .50916 Mdot
.22122 .3374 Mdot
.67662 .53602 Mdot
.24392 .65823 Mdot
.57924 .35185 Mdot
.55045 .39011 Mdot
.37881 .57249 Mdot
.43159 .43024 Mdot
.27473 .37315 Mdot
.39352 .5454 Mdot
.35708 .31911 Mdot
.74881 .66756 Mdot
.45348 .5719 Mdot
.5397 .7125 Mdot
.43179 .62905 Mdot
.42545 .63795 Mdot
.67579 .49877 Mdot
.39885 .36706 Mdot
.30603 .3163 Mdot
.65043 .50495 Mdot
.39132 .56837 Mdot
.63302 .6193 Mdot
.37255 .54844 Mdot
.39345 .51553 Mdot
.25676 .69604 Mdot
.41642 .33033 Mdot
.55847 .3637 Mdot
.39822 .35074 Mdot
.52528 .69874 Mdot
.11297 .59848 Mdot
.37566 .3448 Mdot
.27749 .36337 Mdot
.67204 .77208 Mdot
.26723 .44492 Mdot
.51966 .65047 Mdot
.36559 .35412 Mdot
.68669 .5305 Mdot
.69947 .23336 Mdot
.41456 .80716 Mdot
.72579 .502 Mdot
.4064 .56513 Mdot
.5837 .7059 Mdot
.54221 .64863 Mdot
.63623 .5268 Mdot
.52184 .67528 Mdot
.33873 .48757 Mdot
.39614 .51273 Mdot
.67047 .48957 Mdot
.65278 .64159 Mdot
.67546 .55575 Mdot
.68302 .59157 Mdot
.40969 .54411 Mdot
.54614 .65849 Mdot
.35528 .50712 Mdot
.54567 .62804 Mdot
.60906 .36737 Mdot
.43082 .60894 Mdot
.39351 .37202 Mdot
.62659 .63539 Mdot
.57027 .38033 Mdot
.41016 .28238 Mdot
.52048 .69059 Mdot
.64092 .56463 Mdot
.51569 .67948 Mdot
.5118 .63089 Mdot
.67011 .55093 Mdot
.54254 .69519 Mdot
.3824 .5899 Mdot
.56149 .44613 Mdot
.54045 .70488 Mdot
.65339 .52144 Mdot
.40181 .36443 Mdot
.56005 .69082 Mdot
.50386 .38787 Mdot
.4229 .56518 Mdot
.54684 .35617 Mdot
.46313 .21789 Mdot
.58272 .68107 Mdot
.39512 .32671 Mdot
.58946 .39534 Mdot
.41625 .33789 Mdot
.82833 .54817 Mdot
.652 .48504 Mdot
.2715 .68515 Mdot
.36824 .32056 Mdot
.55917 .65245 Mdot
.48114 .2138 Mdot
.35962 .57194 Mdot
.42331 .56242 Mdot
.37864 .38075 Mdot
.54283 .64877 Mdot
.79501 .36625 Mdot
.4738 .64479 Mdot
.65078 .59176 Mdot
.62525 .50675 Mdot
.27335 .28652 Mdot
.71009 .58492 Mdot
.86032 .53726 Mdot
.42869 .50651 Mdot
.52939 .39944 Mdot
.37894 .56452 Mdot
.65622 .33116 Mdot
.39892 .34219 Mdot
.54913 .31151 Mdot
.45835 .59189 Mdot
.55829 .36942 Mdot
.42898 .57494 Mdot
.49482 .42317 Mdot
.3317 .59916 Mdot
.41593 .37993 Mdot
.74374 .37514 Mdot
.55203 .64511 Mdot
.41315 .36097 Mdot
.53527 .35934 Mdot
.26868 .40165 Mdot
.38404 .51668 Mdot
.32889 .5303 Mdot
.60251 .4279 Mdot
.52203 .65837 Mdot
.59933 .35951 Mdot
.68451 .50478 Mdot
.38955 .36202 Mdot
.42822 .54103 Mdot
.34605 .54895 Mdot
.70587 .39955 Mdot
.64874 .53181 Mdot
.56716 .40851 Mdot
.69529 .53675 Mdot
.52796 .36544 Mdot
.43047 .52286 Mdot
.5537 .39378 Mdot
.3387 .5247 Mdot
.65617 .36253 Mdot
.25551 .68594 Mdot
.39741 .72907 Mdot
.55063 .38283 Mdot
.2433 .45662 Mdot
.65884 .53624 Mdot
.70222 .53353 Mdot
.61492 .79105 Mdot
.32395 .74178 Mdot
.20723 .56574 Mdot
.57658 .21196 Mdot
.64823 .49688 Mdot
.65029 .5282 Mdot
.54389 .36058 Mdot
.54045 .69574 Mdot
.54996 .63783 Mdot
.52671 .37159 Mdot
.34989 .42566 Mdot
.5239 .66747 Mdot
.6902 .24346 Mdot
.20344 .5135 Mdot
.33627 .54967 Mdot
.61023 .39432 Mdot
.3929 .35838 Mdot
.33819 .42186 Mdot
.49288 .41957 Mdot
.38858 .59436 Mdot
.33016 .29272 Mdot
.58446 .35904 Mdot
.43304 .44485 Mdot
.51973 .17734 Mdot
.42177 .59075 Mdot
.4067 .5781 Mdot
.38734 .5626 Mdot
.37211 .33354 Mdot
.37691 .77922 Mdot
.39737 .59089 Mdot
.35045 .42766 Mdot
.44447 .54693 Mdot
.3123 .5034 Mdot
.40302 .35345 Mdot
.28011 .58519 Mdot
.58843 .2515 Mdot
.19236 .44667 Mdot
.31986 .59071 Mdot
.68841 .50692 Mdot
.34875 .31396 Mdot
.69863 .53971 Mdot
.36032 .72384 Mdot
.26348 .49844 Mdot
.58134 .66871 Mdot
.38419 .59304 Mdot
.55753 .38241 Mdot
.53985 .64837 Mdot
.7295 .42841 Mdot
.0845 .54073 Mdot
.69138 .50812 Mdot
.88262 .50989 Mdot
.70411 .52592 Mdot
.53568 .39021 Mdot
.55407 .68142 Mdot
.49091 .74777 Mdot
.50958 .51694 Mdot
.56184 .6923 Mdot
.73402 .32207 Mdot
.5123 .70058 Mdot
.25407 .4405 Mdot
.5816 .70071 Mdot
.65376 .52631 Mdot
.61071 .50116 Mdot
.43047 .48609 Mdot
.36553 .57364 Mdot
.52316 .48781 Mdot
.25998 .39454 Mdot
.36175 .57399 Mdot
.56287 .38197 Mdot
.28151 .69468 Mdot
.32318 .32399 Mdot
.54099 .69065 Mdot
.71626 .52081 Mdot
.41165 .58024 Mdot
.38581 .52275 Mdot
.38557 .51472 Mdot
.18838 .64195 Mdot
.76346 .31248 Mdot
.40904 .51219 Mdot
.44771 .54677 Mdot
.55666 .37395 Mdot
.40902 .31959 Mdot
.64483 .29766 Mdot
.27565 .63415 Mdot
.39389 .60052 Mdot
.41155 .35636 Mdot
.40108 .32231 Mdot
.37041 .52207 Mdot
.43836 .31642 Mdot
.63004 .61346 Mdot
.39858 .58352 Mdot
.28918 .69636 Mdot
.57067 .43691 Mdot
.55801 .40556 Mdot
.57821 .38358 Mdot
.51804 .64499 Mdot
.57089 .39647 Mdot
.53432 .3555 Mdot
.51029 .75288 Mdot
.56708 .49592 Mdot
.71922 .52127 Mdot
.39011 .34597 Mdot
.38381 .55072 Mdot
.49271 .67409 Mdot
.63821 .63899 Mdot
.6771 .54834 Mdot
.56845 .67075 Mdot
.70883 .52108 Mdot
.40046 .39654 Mdot
.48719 .52082 Mdot
.59023 .36469 Mdot
.65214 .49726 Mdot
.7035 .5746 Mdot
.4097 .35653 Mdot
.65157 .53908 Mdot
.69439 .5722 Mdot
.42567 .6073 Mdot
.43718 .76634 Mdot
.39908 .54676 Mdot
.80144 .4064 Mdot
.64221 .52185 Mdot
.65282 .40248 Mdot
.39524 .575 Mdot
.5787 .37385 Mdot
.44676 .49698 Mdot
.35631 .56491 Mdot
.57844 .38921 Mdot
.38519 .51035 Mdot
.42208 .33857 Mdot
.53891 .62686 Mdot
.49763 .50418 Mdot
.48618 .86199 Mdot
.36708 .35205 Mdot
.72786 .42148 Mdot
.36869 .58808 Mdot
.80067 .61792 Mdot
.55769 .69105 Mdot
.34861 .52035 Mdot
.31389 .34002 Mdot
.54341 .70328 Mdot
.56428 .67236 Mdot
.38916 .52608 Mdot
.69334 .52999 Mdot
.56772 .38385 Mdot
.40562 .35646 Mdot
.84872 .51634 Mdot
.40968 .55865 Mdot
.43173 .56046 Mdot
.41594 .35712 Mdot
.65563 .53663 Mdot
.36102 .5291 Mdot
.42451 .22349 Mdot
.807 .36524 Mdot
.70404 .53848 Mdot
.39485 .60478 Mdot
.38029 .75571 Mdot
.44843 .63741 Mdot
.74242 .74228 Mdot
.42552 .30736 Mdot
.55329 .36863 Mdot
.36665 .48409 Mdot
.12919 .58742 Mdot
.3983 .36546 Mdot
.19051 .54473 Mdot
.39098 .52061 Mdot
.43763 .55002 Mdot
.56828 .66415 Mdot
.40697 .53616 Mdot
.57028 .70656 Mdot
.47639 .85294 Mdot
.27261 .3168 Mdot
.51656 .65765 Mdot
.56428 .65466 Mdot
.29513 .34872 Mdot
.64922 .30721 Mdot
.55222 .67467 Mdot
.43279 .52738 Mdot
.3121 .60823 Mdot
.48258 .56642 Mdot
.37544 .37355 Mdot
.54076 .22973 Mdot
.48385 .65014 Mdot
.3632 .37262 Mdot
.64585 .25012 Mdot
.48764 .67162 Mdot
.60324 .5604 Mdot
.68777 .5093 Mdot
.42025 .59244 Mdot
.58658 .39159 Mdot
.57748 .40013 Mdot
.37809 .50029 Mdot
.37946 .54623 Mdot
.52307 .69567 Mdot
.38154 .35071 Mdot
.69036 .50425 Mdot
.43271 .54272 Mdot
.30792 .32956 Mdot
.37994 .34084 Mdot
.5281 .68636 Mdot
.27955 .66633 Mdot
.42886 .37223 Mdot
.41826 .62344 Mdot
.38564 .58054 Mdot
.39173 .53613 Mdot
.48403 .59004 Mdot
.67747 .50803 Mdot
.51859 .21383 Mdot
.43491 .59278 Mdot
.2232 .38599 Mdot
.67003 .47597 Mdot
.37029 .60815 Mdot
.51658 .66838 Mdot
.72443 .54543 Mdot
.57501 .3258 Mdot
.5094 .54818 Mdot
.41732 .55737 Mdot
.79283 .43911 Mdot
.70742 .73246 Mdot
.60748 .36541 Mdot
.51371 .63125 Mdot
.39182 .35317 Mdot
.39131 .54571 Mdot
.3108 .68827 Mdot
.36349 .56357 Mdot
.40607 .38965 Mdot
.56944 .33564 Mdot
.69039 .51178 Mdot
.80828 .43345 Mdot
.57392 .40025 Mdot
.56042 .66949 Mdot
.40386 .1565 Mdot
.56771 .70988 Mdot
.54112 .63477 Mdot
.30116 .66844 Mdot
.6815 .50957 Mdot
.14407 .62287 Mdot
.53096 .82892 Mdot
.44726 .59438 Mdot
.66284 .538 Mdot
.54256 .66824 Mdot
.44246 .55173 Mdot
.59023 .7021 Mdot
.51312 .63746 Mdot
.43705 .5289 Mdot
.43868 .5705 Mdot
.77654 .50902 Mdot
.55867 .18001 Mdot
.39112 .35177 Mdot
.50986 .67882 Mdot
.57206 .57603 Mdot
.44452 .55767 Mdot
.38621 .57236 Mdot
.65584 .44712 Mdot
.37772 .37075 Mdot
.73844 .60292 Mdot
.38802 .52169 Mdot
.28846 .30184 Mdot
.38114 .62228 Mdot
.5246 .70457 Mdot
.69565 .54454 Mdot
.19586 .44028 Mdot
.61831 .51458 Mdot
.57198 .70347 Mdot
.38104 .3573 Mdot
.49278 .63061 Mdot
.27519 .36348 Mdot
.63635 .51684 Mdot
.55133 .65612 Mdot
.60397 .47642 Mdot
.66823 .51474 Mdot
.64376 .50686 Mdot
.30486 .66352 Mdot
.59275 .40292 Mdot
.37549 .32891 Mdot
.64581 .52321 Mdot
.59019 .61731 Mdot
.65816 .52298 Mdot
.56405 .80697 Mdot
.40523 .60299 Mdot
.34865 .39382 Mdot
.5743 .29821 Mdot
.39791 .47797 Mdot
.6393 .51632 Mdot
.40801 .37725 Mdot
.37372 .52468 Mdot
.52871 .67785 Mdot
.40251 .33294 Mdot
.74096 .52836 Mdot
.55265 .35558 Mdot
.51928 .68448 Mdot
.62355 .52616 Mdot
.52781 .65171 Mdot
.54398 .58358 Mdot
.6417 .79492 Mdot
.34914 .24194 Mdot
.52039 .53261 Mdot
.38761 .51538 Mdot
.592 .22929 Mdot
.33428 .56348 Mdot
.37676 .54284 Mdot
.56093 .38659 Mdot
.33515 .36819 Mdot
.55017 .68129 Mdot
.80554 .38978 Mdot
.66629 .4976 Mdot
.19377 .42841 Mdot
.34129 .62114 Mdot
.36895 .51448 Mdot
.5435 .7067 Mdot
.57229 .70904 Mdot
.36484 .70195 Mdot
.57142 .32334 Mdot
.34158 .55478 Mdot
.35016 .58548 Mdot
.39455 .50251 Mdot
.65871 .50126 Mdot
.4027 .28252 Mdot
.59082 .35121 Mdot
.70167 .76365 Mdot
.5755 .33659 Mdot
.34981 .3287 Mdot
.53894 .69193 Mdot
.37564 .3458 Mdot
.38749 .57407 Mdot
.53742 .7264 Mdot
.57876 .69635 Mdot
.39694 .38644 Mdot
.42053 .36932 Mdot
.6973 .44139 Mdot
.69014 .51861 Mdot
.34782 .54439 Mdot
.3991 .59271 Mdot
.41261 .5338 Mdot
.38239 .53637 Mdot
.68202 .50085 Mdot
.36734 .53061 Mdot
.6979 .55735 Mdot
.53768 .60201 Mdot
.35324 .28621 Mdot
.5772 .48511 Mdot
.66159 .73183 Mdot
.53599 .68469 Mdot
.59655 .61401 Mdot
.47753 .61066 Mdot
.2694 .7249 Mdot
.76394 .64819 Mdot
.43828 .59502 Mdot
.54188 .38981 Mdot
.34715 .47236 Mdot
.59181 .37384 Mdot
.86622 .57491 Mdot
.69004 .39919 Mdot
.59959 .19529 Mdot
.41269 .59068 Mdot
.58257 .44579 Mdot
.60681 .65977 Mdot
.33039 .55293 Mdot
.69886 .41773 Mdot
.66548 .72021 Mdot
.76105 .39322 Mdot
.39325 .37686 Mdot
.41809 .5688 Mdot
.49276 .67241 Mdot
.38527 .58963 Mdot
.3806 .56825 Mdot
.37433 .52227 Mdot
.69139 .55369 Mdot
.34173 .54141 Mdot
.36809 .53612 Mdot
.45722 .30766 Mdot
.25836 .47352 Mdot
.58157 .40086 Mdot
.64088 .77955 Mdot
.37567 .34326 Mdot
.53058 .70054 Mdot
.73487 .29923 Mdot
.69058 .52513 Mdot
.37025 .70153 Mdot
.38641 .53609 Mdot
.78035 .48274 Mdot
.72187 .55151 Mdot
.38898 .36512 Mdot
.5771 .33065 Mdot
.64454 .20796 Mdot
.56262 .37778 Mdot
.60871 .47679 Mdot
.57696 .37251 Mdot
.47889 .61593 Mdot
.52103 .69369 Mdot
.3523 .53687 Mdot
.64613 .51689 Mdot
.56895 .39328 Mdot
.30534 .41036 Mdot
.38785 .55736 Mdot
.56509 .36873 Mdot
.35218 .5374 Mdot
.47722 .50108 Mdot
.24504 .59135 Mdot
.53214 .3625 Mdot
.72167 .54387 Mdot
.65933 .51035 Mdot
.37365 .36152 Mdot
.52792 .69534 Mdot
.57406 .68244 Mdot
.67505 .52145 Mdot
.3617 .7823 Mdot
.38375 .59792 Mdot
.44354 .56317 Mdot
.20331 .41674 Mdot
.36893 .58451 Mdot
.26038 .4185 Mdot
.59807 .48342 Mdot
.52992 .68347 Mdot
.38822 .50637 Mdot
.39505 .52245 Mdot
.42061 .55958 Mdot
.52369 .58336 Mdot
.58509 .37145 Mdot
.41727 .59631 Mdot
.42389 .36394 Mdot
.48694 .38607 Mdot
.43572 .53616 Mdot
.31781 .56968 Mdot
.57333 .67905 Mdot
.17913 .59117 Mdot
.70198 .5233 Mdot
.53334 .36728 Mdot
.54851 .38264 Mdot
.55587 .2362 Mdot
.63472 .67639 Mdot
.59696 .48158 Mdot
.73041 .74021 Mdot
.64996 .34783 Mdot
.41211 .34269 Mdot
.61657 .35593 Mdot
.6114 .48889 Mdot
.53829 .36868 Mdot
.69097 .50721 Mdot
.41044 .60251 Mdot
.39631 .60127 Mdot
.26288 .73688 Mdot
.37324 .51899 Mdot
.39496 .35569 Mdot
.66278 .55459 Mdot
.53172 .67778 Mdot
.38783 .36335 Mdot
.69478 .53859 Mdot
.51874 .65973 Mdot
.42934 .59918 Mdot
.42679 .59916 Mdot
.56965 .67377 Mdot
.55063 .65298 Mdot
.38937 .5797 Mdot
.6054 .28974 Mdot
.55347 .6487 Mdot
.54314 .65493 Mdot
.59003 .35989 Mdot
.58637 .38982 Mdot
.34863 .60034 Mdot
.66391 .53593 Mdot
.36792 .53459 Mdot
.556 .3785 Mdot
.37659 .35312 Mdot
.54826 .68306 Mdot
.39945 .51624 Mdot
.42734 .53196 Mdot
.40899 .35818 Mdot
.38128 .36629 Mdot
.40689 .37506 Mdot
.68106 .55697 Mdot
.41828 .54026 Mdot
.55829 .68001 Mdot
.69065 .51662 Mdot
.3958 .32168 Mdot
.38535 .37898 Mdot
.60633 .33907 Mdot
.35922 .57697 Mdot
.50516 .33452 Mdot
.1123 .5492 Mdot
.22922 .40225 Mdot
.59983 .3449 Mdot
.58912 .33179 Mdot
.27983 .44795 Mdot
.44985 .44336 Mdot
.67906 .53042 Mdot
.44266 .34675 Mdot
.3037 .31628 Mdot
.40923 .6097 Mdot
.45295 .55868 Mdot
.4449 .61453 Mdot
.414 .3714 Mdot
.33392 .3442 Mdot
.55779 .7141 Mdot
.46921 .67189 Mdot
.38574 .33493 Mdot
.57661 .40559 Mdot
.61421 .36241 Mdot
.57338 .33532 Mdot
.41699 .60145 Mdot
.40673 .73029 Mdot
.61659 .64104 Mdot
.54021 .2002 Mdot
.64235 .52536 Mdot
.48973 .66504 Mdot
.7993 .61324 Mdot
.56791 .67439 Mdot
.54711 .33088 Mdot
.4176 .34553 Mdot
.54512 .65173 Mdot
.71139 .52182 Mdot
.64838 .5252 Mdot
.58538 .35225 Mdot
.57903 .34757 Mdot
.55012 .34683 Mdot
.51946 .63058 Mdot
.54057 .69381 Mdot
.41644 .55452 Mdot
.54526 .68508 Mdot
.23653 .69762 Mdot
.36547 .36644 Mdot
.5126 .35695 Mdot
.66659 .53128 Mdot
.5193 .65496 Mdot
.39001 .55529 Mdot
.45119 .454 Mdot
.70665 .67409 Mdot
.42063 .34376 Mdot
.2312 .58081 Mdot
.85963 .58348 Mdot
.34708 .54685 Mdot
.66945 .50558 Mdot
.20787 .61504 Mdot
.39018 .56196 Mdot
.56554 .34262 Mdot
.63086 .28657 Mdot
.59721 .42415 Mdot
.35431 .5612 Mdot
.40123 .61122 Mdot
.70814 .5359 Mdot
.72302 .73886 Mdot
.41232 .55468 Mdot
.72219 .61163 Mdot
.67101 .48515 Mdot
.58848 .34655 Mdot
.77837 .3029 Mdot
.43429 .23421 Mdot
.34507 .42125 Mdot
.58866 .35259 Mdot
.36587 .54973 Mdot
.58959 .37345 Mdot
.4249 .35098 Mdot
.54944 .33756 Mdot
.56026 .71528 Mdot
.60515 .3629 Mdot
.4323 .56109 Mdot
.55076 .67217 Mdot
.67387 .53014 Mdot
.18652 .48089 Mdot
.51185 .30596 Mdot
.57965 .37189 Mdot
.53061 .37475 Mdot
.3865 .50789 Mdot
.74824 .57965 Mdot
.36419 .49958 Mdot
.43192 .58389 Mdot
.64389 .49923 Mdot
.53893 .7025 Mdot
.69389 .54843 Mdot
.32337 .55528 Mdot
.41814 .22005 Mdot
.69685 .53461 Mdot
.7846 .43432 Mdot
.41624 .35144 Mdot
.51095 .44518 Mdot
.38763 .55072 Mdot
.66046 .54409 Mdot
.41741 .54147 Mdot
.54879 .71305 Mdot
.56671 .46009 Mdot
.74905 .39348 Mdot
.6494 .50841 Mdot
.79793 .43549 Mdot
.34606 .34873 Mdot
.31638 .53803 Mdot
.70185 .53643 Mdot
.31888 .33768 Mdot
.53706 .39162 Mdot
.39277 .33479 Mdot
.43204 .35369 Mdot
.40135 .33091 Mdot
.40077 .49571 Mdot
.32295 .5998 Mdot
.41264 .3284 Mdot
.70095 .50866 Mdot
.41685 .37915 Mdot
.6181 .7259 Mdot
.79586 .38094 Mdot
.40187 .34331 Mdot
.40869 .57036 Mdot
.44923 .62834 Mdot
.26719 .46815 Mdot
.73241 .45427 Mdot
.61975 .20369 Mdot
.75911 .62157 Mdot
.36506 .57164 Mdot
.54694 .63186 Mdot
.50804 .65843 Mdot
.19693 .58703 Mdot
.24947 .41281 Mdot
.24753 .35732 Mdot
.55918 .64749 Mdot
.70976 .36776 Mdot
.5255 .68658 Mdot
.37958 .51618 Mdot
.44328 .5582 Mdot
.56505 .65159 Mdot
.35314 .28011 Mdot
.72911 .3947 Mdot
.82727 .46936 Mdot
.53416 .65181 Mdot
.68785 .54405 Mdot
.63689 .53182 Mdot
.64257 .50709 Mdot
.20293 .53049 Mdot
.55659 .70724 Mdot
.41934 .53238 Mdot
.55161 .38386 Mdot
.40868 .59874 Mdot
.67251 .51349 Mdot
.80525 .38495 Mdot
.55983 .69918 Mdot
.40937 .58609 Mdot
.39662 .45988 Mdot
.56692 .34772 Mdot
.41189 .35148 Mdot
.4625 .48873 Mdot
.24649 .36354 Mdot
.65724 .49869 Mdot
.58034 .67344 Mdot
.66498 .3897 Mdot
.78301 .39207 Mdot
.44038 .51305 Mdot
.34458 .58149 Mdot
.85262 .52974 Mdot
.29131 .31325 Mdot
.35096 .57374 Mdot
.53379 .37717 Mdot
.69245 .3761 Mdot
.42178 .52595 Mdot
.50601 .66471 Mdot
.43183 .36547 Mdot
.4145 .33716 Mdot
.33688 .59158 Mdot
.49275 .48741 Mdot
.56891 .45028 Mdot
.39105 .52993 Mdot
.42305 .62347 Mdot
.58828 .34777 Mdot
.64661 .33071 Mdot
.22675 .37964 Mdot
.38086 .36004 Mdot
.35407 .53544 Mdot
.69201 .29737 Mdot
.57584 .6747 Mdot
.60567 .3578 Mdot
.64149 .52964 Mdot
.50636 .57485 Mdot
.57458 .32975 Mdot
.41599 .51954 Mdot
.3664 .52546 Mdot
.66178 .54859 Mdot
.52673 .70674 Mdot
.41681 .36825 Mdot
.5521 .38892 Mdot
.38633 .37071 Mdot
.54667 .70438 Mdot
.54677 .69061 Mdot
.36861 .46648 Mdot
.46272 .53764 Mdot
.57589 .3857 Mdot
.33927 .52218 Mdot
.55808 .43231 Mdot
.77948 .69612 Mdot
.62553 .52125 Mdot
.34688 .5581 Mdot
.54979 .72226 Mdot
.65312 .5042 Mdot
.44036 .55881 Mdot
.85557 .50818 Mdot
.44523 .55496 Mdot
.66885 .47751 Mdot
.33778 .24137 Mdot
.39736 .37524 Mdot
.46643 .66624 Mdot
.78549 .55498 Mdot
.37266 .58452 Mdot
.54311 .37522 Mdot
.45636 .6172 Mdot
.69012 .53205 Mdot
.5405 .69109 Mdot
.75732 .7328 Mdot
.65641 .51997 Mdot
.39085 .58774 Mdot
.38899 .36252 Mdot
.57903 .70279 Mdot
.38144 .30037 Mdot
.43639 .31411 Mdot
.31213 .56753 Mdot
.34439 .51721 Mdot
.3801 .5314 Mdot
.46301 .206 Mdot
.53467 .36395 Mdot
.53767 .66042 Mdot
.66801 .50431 Mdot
.67774 .52367 Mdot
.58556 .35734 Mdot
.72348 .56518 Mdot
.5139 .44679 Mdot
.12856 .50622 Mdot
.58159 .38843 Mdot
.38811 .32954 Mdot
.73812 .59654 Mdot
.54329 .38422 Mdot
.56821 .36502 Mdot
.59135 .36011 Mdot
.60868 .53975 Mdot
.52126 .66089 Mdot
.42029 .52163 Mdot
.50943 .68177 Mdot
.36546 .54749 Mdot
.67351 .47768 Mdot
.64609 .51204 Mdot
.55472 .7005 Mdot
.84147 .53668 Mdot
.43345 .7816 Mdot
.39797 .56685 Mdot
.8007 .61504 Mdot
.46283 .57704 Mdot
.2774 .42426 Mdot
.46475 .58525 Mdot
.58092 .36041 Mdot
.3446 .50292 Mdot
.39521 .50156 Mdot
.18306 .55466 Mdot
.66802 .53352 Mdot
.55305 .4033 Mdot
.44548 .60278 Mdot
.42242 .62587 Mdot
.52614 .62969 Mdot
.54358 .65225 Mdot
.42697 .34559 Mdot
.25549 .54082 Mdot
.67514 .53254 Mdot
.52807 .81961 Mdot
.36925 .57563 Mdot
.38273 .26799 Mdot
.38577 .66114 Mdot
.43994 .56259 Mdot
.79389 .55684 Mdot
.39791 .72236 Mdot
.3901 .54717 Mdot
.55926 .54356 Mdot
.65516 .53496 Mdot
.40157 .22361 Mdot
.44166 .54047 Mdot
.56173 .34775 Mdot
.53512 .69264 Mdot
.57015 .71348 Mdot
.4194 .33445 Mdot
.30985 .766 Mdot
.68757 .55095 Mdot
.54776 .69693 Mdot
.38164 .55753 Mdot
.67517 .50524 Mdot
.57226 .39766 Mdot
.36276 .51763 Mdot
.24465 .42524 Mdot
.53918 .68059 Mdot
.40865 .50835 Mdot
.69815 .61765 Mdot
.30132 .45394 Mdot
.39568 .18467 Mdot
.66694 .50301 Mdot
.37755 .36739 Mdot
.44754 .61889 Mdot
.34428 .76461 Mdot
.45626 .54244 Mdot
.3609 .40417 Mdot
.62146 .72764 Mdot
.38109 .3723 Mdot
.39972 .57478 Mdot
.42628 .53834 Mdot
.44719 .41217 Mdot
.379 .35554 Mdot
.40704 .59344 Mdot
.54691 .61756 Mdot
.52496 .65845 Mdot
.53295 .34953 Mdot
.52878 .67285 Mdot
.40605 .56573 Mdot
.46697 .54862 Mdot
.56292 .65906 Mdot
.80537 .6438 Mdot
.36081 .33847 Mdot
.70106 .52474 Mdot
.4581 .56196 Mdot
.44128 .58477 Mdot
.22437 .31453 Mdot
.60718 .37906 Mdot
.66225 .30737 Mdot
.44134 .26756 Mdot
.66155 .26858 Mdot
.43189 .23442 Mdot
.50341 .16001 Mdot
.29412 .30478 Mdot
.34182 .53466 Mdot
.41059 .64605 Mdot
.60025 .59656 Mdot
.64031 .52407 Mdot
.56118 .78324 Mdot
.36498 .57342 Mdot
.37881 .56633 Mdot
.60415 .34989 Mdot
.77972 .44609 Mdot
.24637 .3574 Mdot
.46068 .45774 Mdot
.41642 .36731 Mdot
.50906 .6764 Mdot
.42536 .52349 Mdot
.5645 .52632 Mdot
.58469 .39994 Mdot
.37492 .26946 Mdot
.40847 .5844 Mdot
.26309 .70689 Mdot
.68626 .68163 Mdot
.6831 .51297 Mdot
.54642 .38128 Mdot
.26203 .34155 Mdot
.3576 .57352 Mdot
.6422 .53238 Mdot
.40534 .55547 Mdot
.6292 .33235 Mdot
.32339 .54844 Mdot
.39867 .33938 Mdot
.38935 .51958 Mdot
.34691 .33152 Mdot
.35402 .16963 Mdot
.4415 .36668 Mdot
.58866 .70181 Mdot
.5123 .37615 Mdot
.5835 .37647 Mdot
.54969 .65373 Mdot
.58106 .37917 Mdot
.36572 .68606 Mdot
.47959 .72309 Mdot
.41888 .35659 Mdot
.39695 .6227 Mdot
.40123 .34662 Mdot
.60827 .36414 Mdot
.36019 .56836 Mdot
.8209 .64613 Mdot
.56817 .38984 Mdot
.303 .26548 Mdot
.66132 .52316 Mdot
.57869 .40463 Mdot
.44364 .54531 Mdot
.65883 .40276 Mdot
.57392 .40077 Mdot
.75269 .40689 Mdot
.42014 .55883 Mdot
.53945 .6849 Mdot
.42077 .52675 Mdot
.45305 .5847 Mdot
.53851 .40666 Mdot
.36058 .54458 Mdot
.69404 .5389 Mdot
.54111 .63844 Mdot
.6942 .23759 Mdot
.64793 .73108 Mdot
.39188 .59405 Mdot
.38383 .55903 Mdot
.49905 .63299 Mdot
.42561 .59398 Mdot
.68236 .50121 Mdot
.35799 .86322 Mdot
.4159 .35133 Mdot
.53305 .3965 Mdot
.43158 .23315 Mdot
.43321 .59879 Mdot
.37092 .5272 Mdot
.85517 .48627 Mdot
.40193 .23303 Mdot
.69945 .53751 Mdot
.4071 .50329 Mdot
.57163 .3992 Mdot
.38976 .36002 Mdot
.68959 .49976 Mdot
.39333 .53663 Mdot
.39131 .57437 Mdot
.37479 .36101 Mdot
.29107 .58248 Mdot
.20569 .48536 Mdot
.65589 .54434 Mdot
.37641 .48659 Mdot
.50717 .38875 Mdot
.36728 .59053 Mdot
.2069 .55306 Mdot
.55068 .65747 Mdot
.65568 .4977 Mdot
.60093 .24165 Mdot
.35127 .56669 Mdot
.68943 .54691 Mdot
.67409 .53327 Mdot
.41778 .50781 Mdot
.55095 .72375 Mdot
.52362 .63664 Mdot
.52491 .65152 Mdot
.27007 .7599 Mdot
.32721 .4183 Mdot
.55029 .34672 Mdot
.65496 .53532 Mdot
.53083 .3623 Mdot
.37832 .38543 Mdot
.5936 .49719 Mdot
.53031 .36914 Mdot
.5226 .64654 Mdot
.51411 .36612 Mdot
.42685 .54771 Mdot
.67557 .53001 Mdot
.5394 .36419 Mdot
.44281 .59857 Mdot
.74598 .56926 Mdot
.75566 .51103 Mdot
.39878 .38189 Mdot
.43386 .35658 Mdot
.43944 .54498 Mdot
.56508 .3223 Mdot
.38744 .57802 Mdot
.64428 .49507 Mdot
.74108 .58446 Mdot
.45666 .55846 Mdot
.58104 .37084 Mdot
.49601 .62601 Mdot
.25301 .35484 Mdot
.35529 .50084 Mdot
.40764 .57098 Mdot
.36207 .54831 Mdot
.40555 .555 Mdot
.7617 .37641 Mdot
.62849 .50102 Mdot
.66071 .73099 Mdot
.49756 .21228 Mdot
.56432 .69497 Mdot
.49875 .65778 Mdot
.22243 .41006 Mdot
.62809 .60573 Mdot
.66207 .53606 Mdot
.37871 .54059 Mdot
.64907 .66276 Mdot
.80391 .36306 Mdot
.85291 .56377 Mdot
.43585 .4107 Mdot
.59716 .39413 Mdot
.57408 .6626 Mdot
.55424 .39685 Mdot
.36353 .55518 Mdot
.44067 .61896 Mdot
.4822 .15185 Mdot
.69215 .49749 Mdot
.41969 .35348 Mdot
.3661 .54447 Mdot
.32996 .42202 Mdot
.55522 .37534 Mdot
.55376 .41174 Mdot
.42423 .59054 Mdot
.51152 .69121 Mdot
.29649 .2339 Mdot
.67592 .50742 Mdot
.75941 .61522 Mdot
.60975 .6688 Mdot
.73468 .65034 Mdot
.67357 .51154 Mdot
.4545 .37188 Mdot
.60063 .34765 Mdot
.31618 .6415 Mdot
.56731 .69459 Mdot
.4042 .3339 Mdot
.36706 .60598 Mdot
.57298 .67331 Mdot
.58611 .34142 Mdot
.54032 .68859 Mdot
.37618 .52125 Mdot
.65658 .48449 Mdot
.55142 .36877 Mdot
.71878 .51996 Mdot
.53069 .71325 Mdot
.38215 .35942 Mdot
.48681 .45921 Mdot
.51373 .78317 Mdot
.3938 .7186 Mdot
.41603 .59812 Mdot
.56967 .53109 Mdot
.4169 .53207 Mdot
.50454 .64642 Mdot
.39455 .55565 Mdot
.58706 .74194 Mdot
.54418 .37533 Mdot
.44707 .54594 Mdot
.38746 .53076 Mdot
.60029 .7801 Mdot
.41758 .5821 Mdot
.33786 .53164 Mdot
.38834 .54451 Mdot
.58196 .73137 Mdot
.39578 .62386 Mdot
.5152 .66692 Mdot
.47045 .34251 Mdot
.57003 .36223 Mdot
.42809 .36949 Mdot
.36899 .35042 Mdot
.34074 .38856 Mdot
.55279 .25423 Mdot
.77741 .46497 Mdot
.53068 .66978 Mdot
.68463 .53907 Mdot
.39881 .55412 Mdot
.51422 .18004 Mdot
.57233 .43859 Mdot
.59306 .39093 Mdot
.65013 .72971 Mdot
.38628 .48176 Mdot
.4196 .20432 Mdot
.3838 .50481 Mdot
.28046 .7577 Mdot
.45457 .5169 Mdot
.32467 .54622 Mdot
.52811 .38403 Mdot
.37956 .38916 Mdot
.43498 .58583 Mdot
.53344 .6311 Mdot
.39119 .33806 Mdot
.37725 .6387 Mdot
.49253 .36 Mdot
.47617 .34803 Mdot
.55176 .76732 Mdot
.4156 .54671 Mdot
.5521 .36728 Mdot
.51916 .68541 Mdot
.23162 .37257 Mdot
.69152 .51661 Mdot
.71339 .50186 Mdot
.57959 .58291 Mdot
.80998 .6152 Mdot
.3795 .34071 Mdot
.29636 .63517 Mdot
.43264 .55832 Mdot
.56216 .29063 Mdot
.45471 .55144 Mdot
.80428 .38017 Mdot
.37738 .33633 Mdot
.52496 .6422 Mdot
.68451 .54418 Mdot
.50474 .66705 Mdot
.38634 .72156 Mdot
.60833 .39923 Mdot
.55168 .48269 Mdot
.56389 .3751 Mdot
.49034 .41311 Mdot
.54517 .66657 Mdot
.35397 .53807 Mdot
.12681 .50584 Mdot
.54585 .65552 Mdot
.58161 .69482 Mdot
.68113 .76874 Mdot
.79758 .6787 Mdot
.34905 .49632 Mdot
.55971 .65124 Mdot
.5685 .37229 Mdot
.38832 .35111 Mdot
.409 .51984 Mdot
.42099 .54956 Mdot
.57192 .67252 Mdot
.53996 .40577 Mdot
.35502 .74741 Mdot
.57957 .35007 Mdot
.52089 .65776 Mdot
.56762 .35434 Mdot
.65456 .39636 Mdot
.53761 .38124 Mdot
.43983 .58616 Mdot
.39564 .55516 Mdot
.50825 .23981 Mdot
.546 .68986 Mdot
.39308 .5295 Mdot
.382 .50981 Mdot
.55555 .67868 Mdot
.44147 .32588 Mdot
.35669 .74215 Mdot
.37751 .5922 Mdot
.42135 .56921 Mdot
.38083 .3713 Mdot
.58919 .52782 Mdot
.2612 .60915 Mdot
.37444 .52461 Mdot
.37109 .33602 Mdot
.53224 .63183 Mdot
.39632 .58333 Mdot
.76286 .3227 Mdot
.69448 .37545 Mdot
.35047 .55768 Mdot
.53804 .39227 Mdot
.3939 .50197 Mdot
.38051 .19181 Mdot
.43276 .58359 Mdot
.54669 .6742 Mdot
.54269 .69983 Mdot
.53546 .81901 Mdot
.55754 .66755 Mdot
.58825 .38846 Mdot
.67022 .51426 Mdot
.80244 .41304 Mdot
.57074 .39772 Mdot
.43744 .50568 Mdot
.544 .83071 Mdot
.35401 .52542 Mdot
.44458 .59028 Mdot
.32196 .23066 Mdot
.5612 .39554 Mdot
.54668 .70937 Mdot
.45944 .4395 Mdot
.4733 .56594 Mdot
.6524 .49884 Mdot
.3694 .60899 Mdot
.39939 .60491 Mdot
.33035 .24498 Mdot
.72477 .34413 Mdot
.63376 .51102 Mdot
.34009 .55756 Mdot
.3735 .52499 Mdot
.58452 .4119 Mdot
.38555 .55492 Mdot
.38903 .34758 Mdot
.55094 .70734 Mdot
.54236 .38719 Mdot
.40837 .36159 Mdot
.3673 .57934 Mdot
.41068 .37303 Mdot
.54717 .35543 Mdot
.63542 .51814 Mdot
.3598 .56076 Mdot
.37672 .37493 Mdot
.41225 .37128 Mdot
.41231 .53027 Mdot
.53743 .68962 Mdot
.44854 .50781 Mdot
.41371 .58715 Mdot
.39678 .51611 Mdot
.5745 .68649 Mdot
.87192 .40991 Mdot
.444 .56571 Mdot
.3619 .39198 Mdot
.57631 .70076 Mdot
.47601 .38806 Mdot
.55 .39801 Mdot
.40426 .60486 Mdot
.63511 .51352 Mdot
.65415 .53884 Mdot
.58186 .33783 Mdot
.58433 .69444 Mdot
.44475 .25898 Mdot
.48765 .63178 Mdot
.47048 .57687 Mdot
.34977 .57943 Mdot
.45164 .81501 Mdot
.59664 .19057 Mdot
.53112 .70507 Mdot
.54905 .30702 Mdot
.48035 .47525 Mdot
.66467 .54399 Mdot
.57409 .40636 Mdot
.57722 .66591 Mdot
.5673 .70802 Mdot
.52929 .68115 Mdot
.41275 .33762 Mdot
.51365 .24073 Mdot
.54338 .71651 Mdot
.50022 .67045 Mdot
.42269 .55615 Mdot
.3747 .52561 Mdot
.25973 .35868 Mdot
.2346 .47827 Mdot
.41233 .37684 Mdot
.57859 .34031 Mdot
.23002 .73237 Mdot
.64962 .49305 Mdot
.6317 .76959 Mdot
.45312 .5746 Mdot
.1005 .56524 Mdot
.43547 .53378 Mdot
.38089 .55514 Mdot
.54216 .63855 Mdot
.38621 .38035 Mdot
.40672 .34613 Mdot
.53901 .65897 Mdot
.49691 .65602 Mdot
.39003 .34679 Mdot
.78846 .59378 Mdot
.78187 .33251 Mdot
.61829 .38769 Mdot
.55759 .6853 Mdot
.51157 .77365 Mdot
.65321 .54477 Mdot
.41746 .63797 Mdot
.65086 .48955 Mdot
.56098 .37019 Mdot
.5808 .33078 Mdot
.65428 .50103 Mdot
.41842 .55905 Mdot
.54481 .35027 Mdot
.34284 .53719 Mdot
.74884 .65778 Mdot
.41246 .75368 Mdot
.46207 .2369 Mdot
.32457 .58793 Mdot
.46241 .36109 Mdot
.7244 .56038 Mdot
.3821 .58403 Mdot
.69501 .28391 Mdot
.42034 .36039 Mdot
.42322 .63267 Mdot
.6572 .49479 Mdot
.3606 .19229 Mdot
.3568 .5613 Mdot
.54615 .67662 Mdot
.67022 .53647 Mdot
.50253 .54765 Mdot
.72376 .60662 Mdot
.36374 .54768 Mdot
.11943 .5551 Mdot
.58281 .72649 Mdot
.54095 .38106 Mdot
.33128 .76579 Mdot
.52965 .70634 Mdot
.42023 .41406 Mdot
.54265 .22339 Mdot
.83282 .5639 Mdot
.52873 .69944 Mdot
.60265 .39246 Mdot
.51482 .65549 Mdot
.38149 .35683 Mdot
.57878 .66084 Mdot
.54999 .37654 Mdot
.40817 .58132 Mdot
.58418 .36095 Mdot
.42887 .35247 Mdot
.20921 .48941 Mdot
.6335 .51391 Mdot
.55039 .40197 Mdot
.65041 .5132 Mdot
.28598 .48096 Mdot
.45656 .21071 Mdot
.69335 .51428 Mdot
.28271 .6813 Mdot
.35697 .58622 Mdot
.52547 .70453 Mdot
.58768 .36384 Mdot
.6056 .2653 Mdot
.48187 .45869 Mdot
.56923 .68727 Mdot
.56493 .33891 Mdot
.58464 .58116 Mdot
.29651 .72114 Mdot
.34472 .51311 Mdot
.26485 .51102 Mdot
.55966 .68295 Mdot
.6101 .37209 Mdot
.19949 .42313 Mdot
.51373 .64933 Mdot
.58407 .38568 Mdot
.68576 .54546 Mdot
.67941 .52116 Mdot
.4148 .59413 Mdot
.70437 .50196 Mdot
.56224 .33464 Mdot
.74043 .54659 Mdot
.56666 .65606 Mdot
.51316 .57003 Mdot
.36955 .36925 Mdot
.57524 .35823 Mdot
.3723 .51876 Mdot
.58782 .66545 Mdot
.6746 .37195 Mdot
.38065 .76719 Mdot
.1687 .57819 Mdot
.58537 .35707 Mdot
.56083 .70719 Mdot
.5456 .67889 Mdot
.36892 .49538 Mdot
.51669 .52824 Mdot
.45141 .25695 Mdot
.40733 .44525 Mdot
.43565 .44859 Mdot
.53742 .34169 Mdot
.57654 .42704 Mdot
.44074 .6067 Mdot
.41034 .54742 Mdot
.66973 .54435 Mdot
.4107 .57898 Mdot
.54363 .64207 Mdot
.4207 .59393 Mdot
.66661 .50543 Mdot
.56268 .38065 Mdot
.36136 .56482 Mdot
.39914 .37627 Mdot
.64638 .54277 Mdot
.71343 .52831 Mdot
.57863 .36423 Mdot
.5742 .67667 Mdot
.41262 .30277 Mdot
.5788 .3468 Mdot
.41555 .54756 Mdot
.59872 .53846 Mdot
.38576 .51478 Mdot
.47284 .66454 Mdot
.51281 .64925 Mdot
.5467 .38985 Mdot
.56024 .64668 Mdot
.65094 .51972 Mdot
.5085 .21262 Mdot
.40128 .56224 Mdot
.58029 .39042 Mdot
.6318 .31098 Mdot
.35889 .64389 Mdot
.49323 .65209 Mdot
.76583 .50674 Mdot
.49994 .65327 Mdot
.5911 .34685 Mdot
.61035 .79439 Mdot
.38984 .33428 Mdot
.59249 .39216 Mdot
.66553 .22309 Mdot
.57413 .38398 Mdot
.42625 .57952 Mdot
.43846 .5456 Mdot
.54062 .38469 Mdot
.37338 .36166 Mdot
.26112 .33088 Mdot
.52718 .35179 Mdot
.54182 .70716 Mdot
.74992 .67255 Mdot
.15877 .49328 Mdot
.62559 .48636 Mdot
.67564 .54324 Mdot
.46828 .53848 Mdot
.32995 .53716 Mdot
.66821 .49059 Mdot
.71569 .5251 Mdot
.41729 .33684 Mdot
.59222 .36711 Mdot
.59095 .72926 Mdot
.71008 .54961 Mdot
.46788 .51436 Mdot
.54086 .25273 Mdot
.34611 .50794 Mdot
.61394 .66775 Mdot
.45332 .55887 Mdot
.38625 .4225 Mdot
.66651 .50434 Mdot
.4066 .51014 Mdot
.37917 .49925 Mdot
.63998 .50362 Mdot
.38676 .34936 Mdot
.63924 .58149 Mdot
.56119 .35721 Mdot
.80754 .33337 Mdot
.35153 .51596 Mdot
.42946 .579 Mdot
.64117 .52265 Mdot
.45489 .293 Mdot
.56135 .70058 Mdot
.50504 .65746 Mdot
.53418 .36641 Mdot
.50191 .4824 Mdot
.39777 .60218 Mdot
.3943 .58657 Mdot
.55291 .36098 Mdot
.57277 .40529 Mdot
.75224 .4559 Mdot
.43193 .54427 Mdot
.66379 .53203 Mdot
.35078 .32002 Mdot
.66402 .50356 Mdot
.38084 .51637 Mdot
.43233 .57353 Mdot
.43847 .5875 Mdot
.37256 .5193 Mdot
.70718 .51149 Mdot
.41893 .51745 Mdot
.41983 .62937 Mdot
.56597 .70195 Mdot
.36889 .53739 Mdot
.43116 .44674 Mdot
.41349 .57182 Mdot
.38907 .3499 Mdot
.27189 .62969 Mdot
.35722 .56143 Mdot
.4065 .60327 Mdot
.52035 .38302 Mdot
.39518 .57066 Mdot
.64661 .49379 Mdot
.55379 .69192 Mdot
.65379 .53406 Mdot
.65001 .53685 Mdot
.56409 .32717 Mdot
.41406 .3296 Mdot
.42967 .60101 Mdot
.42063 .34575 Mdot
.43868 .50925 Mdot
.35044 .56572 Mdot
.52551 .22381 Mdot
.29354 .76993 Mdot
.20017 .51584 Mdot
.40311 .56173 Mdot
.56389 .39346 Mdot
.54929 .39621 Mdot
.34691 .63012 Mdot
.34939 .50905 Mdot
.68813 .50308 Mdot
.65766 .5418 Mdot
.24729 .42948 Mdot
.36032 .23808 Mdot
.38845 .34965 Mdot
.57633 .5114 Mdot
.34262 .55715 Mdot
.38965 .5108 Mdot
.35761 .51931 Mdot
.53262 .35978 Mdot
.41041 .42824 Mdot
.58852 .39486 Mdot
.69245 .68582 Mdot
.64843 .5052 Mdot
.35818 .55415 Mdot
.63069 .69445 Mdot
.5379 .64991 Mdot
.55278 .69146 Mdot
.71221 .52903 Mdot
.53464 .41666 Mdot
.23747 .39412 Mdot
.85435 .58106 Mdot
.58321 .72 Mdot
.40868 .38278 Mdot
.38229 .58689 Mdot
.56877 .37967 Mdot
.51967 .65142 Mdot
.41509 .37934 Mdot
.35116 .54223 Mdot
.51518 .24049 Mdot
.40844 .5598 Mdot
.6052 .60843 Mdot
.52872 .68814 Mdot
.801 .36989 Mdot
.5825 .70551 Mdot
.64568 .54296 Mdot
.66487 .49639 Mdot
.43962 .55762 Mdot
.40162 .80556 Mdot
.50786 .68066 Mdot
.61426 .54445 Mdot
.38721 .33001 Mdot
.67452 .38771 Mdot
.38183 .35221 Mdot
.54225 .37934 Mdot
.38731 .33849 Mdot
.5476 .37597 Mdot
.22877 .4578 Mdot
.56679 .74038 Mdot
.41414 .35898 Mdot
.62072 .31272 Mdot
.33257 .52124 Mdot
.40564 .37933 Mdot
.46054 .5996 Mdot
.46019 .65942 Mdot
.55512 .35728 Mdot
.37785 .33971 Mdot
.35528 .53547 Mdot
.47974 .16326 Mdot
.70217 .53359 Mdot
.68225 .49905 Mdot
.46562 .58843 Mdot
.54842 .33082 Mdot
.54806 .63682 Mdot
.77426 .36706 Mdot
.64996 .55078 Mdot
.44275 .56152 Mdot
.43132 .58885 Mdot
.49884 .65991 Mdot
.61705 .74075 Mdot
.43718 .56357 Mdot
.39332 .4641 Mdot
.43396 .5454 Mdot
.70689 .53446 Mdot
.50552 .66954 Mdot
.54872 .68417 Mdot
.56049 .33961 Mdot
.55582 .65271 Mdot
.31848 .61467 Mdot
.64408 .68846 Mdot
.39663 .47385 Mdot
.65565 .51794 Mdot
.67104 .69024 Mdot
.69054 .68956 Mdot
.62022 .20617 Mdot
.50351 .68304 Mdot
.45291 .54904 Mdot
.57582 .67399 Mdot
.38822 .35785 Mdot
.53915 .68311 Mdot
.57216 .66006 Mdot
.38465 .57935 Mdot
.36619 .54962 Mdot
.55498 .38527 Mdot
.50605 .51198 Mdot
.57774 .68875 Mdot
.43197 .53127 Mdot
.32855 .54374 Mdot
.34751 .52656 Mdot
.61352 .45575 Mdot
.52206 .69735 Mdot
.73406 .72369 Mdot
.30355 .35739 Mdot
.57746 .6872 Mdot
.3122 .21798 Mdot
.64448 .32103 Mdot
.59894 .33583 Mdot
.72661 .53607 Mdot
.43084 .54019 Mdot
.56643 .40309 Mdot
.36316 .55591 Mdot
.61387 .66508 Mdot
.38677 .57131 Mdot
.38881 .34549 Mdot
.34195 .53354 Mdot
.58282 .33507 Mdot
.58176 .35082 Mdot
.43989 .57318 Mdot
.3641 .56561 Mdot
.21345 .46304 Mdot
.50906 .69588 Mdot
.55028 .69555 Mdot
.43461 .26616 Mdot
.40653 .36889 Mdot
.65459 .49827 Mdot
.38989 .55008 Mdot
.55425 .33088 Mdot
.58323 .35336 Mdot
.52152 .69829 Mdot
.56456 .34414 Mdot
.67604 .50814 Mdot
.39703 .56083 Mdot
.67011 .49152 Mdot
.41263 .33654 Mdot
.51093 .68071 Mdot
.36626 .54195 Mdot
.42268 .55657 Mdot
.54244 .69988 Mdot
.43505 .60616 Mdot
.37951 .36925 Mdot
.57683 .38287 Mdot
.52211 .69279 Mdot
.67267 .51604 Mdot
.54392 .37937 Mdot
.4031 .51545 Mdot
.19832 .67771 Mdot
.4248 .57751 Mdot
.42573 .53154 Mdot
.65531 .20981 Mdot
.34016 .54458 Mdot
.58697 .35942 Mdot
.52176 .64372 Mdot
.32862 .58921 Mdot
.3287 .38288 Mdot
.88504 .48191 Mdot
.59293 .38993 Mdot
.38681 .58922 Mdot
.53827 .17848 Mdot
.39826 .58998 Mdot
.46001 .80663 Mdot
.61955 .33382 Mdot
.48347 .42363 Mdot
.46241 .56041 Mdot
.6899 .52525 Mdot
.55584 .38811 Mdot
.54457 .37202 Mdot
.7168 .71607 Mdot
.38801 .58208 Mdot
.5892 .56694 Mdot
.35895 .53853 Mdot
.67724 .51557 Mdot
.26136 .39927 Mdot
.58405 .35187 Mdot
.18994 .58077 Mdot
.41978 .53424 Mdot
.55976 .71388 Mdot
.51391 .36348 Mdot
.63289 .4299 Mdot
.39932 .51671 Mdot
.42402 .35689 Mdot
.69397 .55645 Mdot
.3267 .57286 Mdot
.65986 .51512 Mdot
.39305 .51609 Mdot
.35085 .47206 Mdot
.33641 .77645 Mdot
.53342 .68582 Mdot
.68186 .54491 Mdot
.6021 .51039 Mdot
.43262 .52449 Mdot
.52672 .69736 Mdot
.56829 .69325 Mdot
.42173 .34324 Mdot
.57799 .47306 Mdot
.68575 .61153 Mdot
.45348 .77792 Mdot
.73774 .69368 Mdot
.51478 .37733 Mdot
.73782 .38368 Mdot
.40291 .52295 Mdot
.39586 .26542 Mdot
.63866 .50058 Mdot
.42212 .5827 Mdot
.34805 .65817 Mdot
.53525 .65398 Mdot
.42595 .56761 Mdot
.39916 .34655 Mdot
.4131 .2803 Mdot
.38261 .27273 Mdot
.55061 .21777 Mdot
.56342 .37358 Mdot
.44237 .61921 Mdot
.32956 .49143 Mdot
.53198 .38786 Mdot
.3981 .60675 Mdot
.58357 .38152 Mdot
.7977 .60419 Mdot
.40241 .38159 Mdot
.53543 .70649 Mdot
.64728 .39009 Mdot
.41737 .60519 Mdot
.3513 .58404 Mdot
.43321 .34484 Mdot
.40901 .54353 Mdot
.29817 .75394 Mdot
.63716 .40317 Mdot
.53826 .36343 Mdot
.53033 .6823 Mdot
.41658 .60183 Mdot
.59006 .47703 Mdot
.40964 .58806 Mdot
.46638 .73232 Mdot
.40905 .60277 Mdot
.7059 .60691 Mdot
.5356 .69233 Mdot
.65655 .51357 Mdot
.43393 .52319 Mdot
.38232 .56583 Mdot
.33459 .32295 Mdot
.45874 .52455 Mdot
.41957 .51562 Mdot
.50493 .62956 Mdot
.51816 .65037 Mdot
.51655 .66574 Mdot
.60337 .35886 Mdot
.34435 .24129 Mdot
.65628 .52812 Mdot
.35763 .61335 Mdot
.70792 .54686 Mdot
.36467 .7695 Mdot
.40984 .38189 Mdot
.56117 .20163 Mdot
.38718 .53675 Mdot
.52625 .6641 Mdot
.70204 .31065 Mdot
.51943 .63026 Mdot
.56332 .51065 Mdot
.67528 .53218 Mdot
.54238 .65688 Mdot
.37943 .55936 Mdot
.48022 .46658 Mdot
.48557 .18385 Mdot
.64756 .52458 Mdot
.43105 .50223 Mdot
.60634 .37985 Mdot
.46464 .22791 Mdot
.18635 .64785 Mdot
.70273 .53431 Mdot
.66298 .47793 Mdot
.38726 .58322 Mdot
.53581 .64814 Mdot
.68732 .52007 Mdot
.70223 .52209 Mdot
.56223 .34415 Mdot
.36816 .54645 Mdot
.37157 .54263 Mdot
.59522 .35004 Mdot
.64978 .53183 Mdot
.46644 .57037 Mdot
.32311 .54771 Mdot
.45433 .1484 Mdot
.55239 .57106 Mdot
.82125 .34402 Mdot
.317 .60942 Mdot
.32791 .66004 Mdot
.78689 .37536 Mdot
.57193 .7064 Mdot
.35651 .5687 Mdot
.33934 .5824 Mdot
.56359 .33436 Mdot
.40392 .5719 Mdot
.61096 .33821 Mdot
.67005 .53971 Mdot
.34767 .20629 Mdot
.67656 .66171 Mdot
.81422 .57542 Mdot
.40266 .57343 Mdot
.58109 .75129 Mdot
.39955 .35921 Mdot
.62396 .50607 Mdot
.51082 .66695 Mdot
.36392 .52432 Mdot
.21223 .46624 Mdot
.59044 .39387 Mdot
.56594 .66993 Mdot
.23181 .3757 Mdot
.45949 .36922 Mdot
.38096 .51724 Mdot
.60399 .37777 Mdot
.71184 .30456 Mdot
.48422 .54157 Mdot
.62935 .53437 Mdot
.38618 .34742 Mdot
.55405 .39047 Mdot
.65423 .54082 Mdot
.59702 .70978 Mdot
.5504 .66184 Mdot
.55493 .63839 Mdot
.2176 .55517 Mdot
.53439 .396 Mdot
.40377 .35857 Mdot
.38051 .23581 Mdot
.34893 .26692 Mdot
.39132 .34449 Mdot
.58389 .33254 Mdot
.51858 .65088 Mdot
.53442 .66007 Mdot
.55442 .6918 Mdot
.1893 .53795 Mdot
.57597 .70739 Mdot
.66041 .7553 Mdot
.35032 .52921 Mdot
.38245 .46823 Mdot
.38987 .58901 Mdot
.68055 .49678 Mdot
.53169 .69525 Mdot
.48459 .45063 Mdot
.40943 .49992 Mdot
.48661 .19911 Mdot
.42083 .58813 Mdot
.63795 .48959 Mdot
.42832 .55889 Mdot
.57346 .7771 Mdot
.5785 .68225 Mdot
.40371 .5656 Mdot
.63306 .49986 Mdot
.39877 .37097 Mdot
.49219 .64084 Mdot
.3624 .54805 Mdot
.77643 .49084 Mdot
.34049 .53985 Mdot
.81085 .55645 Mdot
.52884 .57853 Mdot
.40819 .38284 Mdot
.58554 .62265 Mdot
.58088 .40733 Mdot
.36855 .47052 Mdot
.47398 .58477 Mdot
.64711 .51736 Mdot
.66037 .3695 Mdot
.57007 .36427 Mdot
.42916 .41544 Mdot
.37993 .61508 Mdot
.43085 .35815 Mdot
.49764 .67756 Mdot
.67105 .48986 Mdot
.38222 .60328 Mdot
.36846 .4981 Mdot
.71081 .6979 Mdot
.41455 .62456 Mdot
.42438 .59363 Mdot
.43613 .35994 Mdot
.6573 .7485 Mdot
.41508 .56786 Mdot
.56826 .50741 Mdot
.58426 .67211 Mdot
.4676 .56075 Mdot
.64501 .76724 Mdot
.43905 .54479 Mdot
.55805 .66107 Mdot
.49067 .66572 Mdot
.64038 .60243 Mdot
.40221 .32748 Mdot
.40292 .60426 Mdot
.5399 .81842 Mdot
.419 .53869 Mdot
.66238 .52881 Mdot
.33912 .52587 Mdot
.55273 .37568 Mdot
.1946 .50355 Mdot
.5534 .34133 Mdot
.38694 .5973 Mdot
.55709 .69052 Mdot
.64115 .51275 Mdot
.2079 .58532 Mdot
.4893 .25185 Mdot
.64092 .7589 Mdot
.84789 .52323 Mdot
.37599 .34657 Mdot
.40376 .32327 Mdot
.66834 .48827 Mdot
.40551 .56546 Mdot
.64327 .78835 Mdot
.45703 .5193 Mdot
.42227 .56753 Mdot
.3851 .57118 Mdot
.43684 .21907 Mdot
.66337 .54163 Mdot
.56454 .35015 Mdot
.43534 .56785 Mdot
.41894 .51663 Mdot
.57163 .70569 Mdot
.40642 .37224 Mdot
.55016 .39784 Mdot
.41776 .35301 Mdot
.56193 .38636 Mdot
.32764 .21109 Mdot
.40135 .50349 Mdot
.39656 .36858 Mdot
.70346 .55668 Mdot
.57311 .6771 Mdot
.64335 .67994 Mdot
.54264 .37538 Mdot
.57467 .33684 Mdot
.43337 .5806 Mdot
.55629 .65864 Mdot
.55046 .64151 Mdot
.38703 .35943 Mdot
.68682 .51024 Mdot
.35787 .56271 Mdot
.34976 .56783 Mdot
.52641 .73276 Mdot
.5478 .33347 Mdot
.60257 .61348 Mdot
.76688 .41444 Mdot
.40538 .56262 Mdot
.56225 .6523 Mdot
.37187 .57049 Mdot
.79271 .41803 Mdot
.54438 .64944 Mdot
.43981 .54271 Mdot
.25621 .31113 Mdot
.53605 .41864 Mdot
.65478 .61995 Mdot
.44135 .58135 Mdot
.8339 .445 Mdot
.3928 .52637 Mdot
.39279 .15789 Mdot
.57506 .28033 Mdot
.36597 .59032 Mdot
.41209 .51922 Mdot
.38649 .7531 Mdot
.36992 .58436 Mdot
.5904 .34497 Mdot
.2887 .31618 Mdot
.53626 .63096 Mdot
.7593 .54041 Mdot
.28039 .63224 Mdot
.37726 .33716 Mdot
.53404 .36751 Mdot
.59745 .41908 Mdot
.40227 .34147 Mdot
.55573 .68266 Mdot
.40542 .55479 Mdot
.52078 .48211 Mdot
.53286 .35255 Mdot
.32068 .60288 Mdot
.66521 .52849 Mdot
.71307 .41139 Mdot
.60692 .42656 Mdot
.66495 .51154 Mdot
.37179 .53401 Mdot
.37406 .75054 Mdot
.2396 .5538 Mdot
.7698 .31166 Mdot
.65207 .54057 Mdot
.64501 .52225 Mdot
.18748 .5146 Mdot
.37331 .37807 Mdot
.73614 .67526 Mdot
.71659 .60528 Mdot
.6488 .50052 Mdot
.49743 .55967 Mdot
.59546 .37893 Mdot
.71541 .57083 Mdot
.41563 .63268 Mdot
.34554 .55181 Mdot
.38044 .56137 Mdot
.68032 .50489 Mdot
.36113 .64309 Mdot
.3161 .7547 Mdot
.65091 .5112 Mdot
.47589 .62149 Mdot
.54034 .45316 Mdot
.63574 .2992 Mdot
.58711 .34718 Mdot
.40744 .32886 Mdot
.37455 .32043 Mdot
.55863 .71209 Mdot
.41079 .32907 Mdot
.40929 .27583 Mdot
.40175 .54317 Mdot
.65743 .50492 Mdot
.67375 .37658 Mdot
.67451 .52029 Mdot
.40501 .34329 Mdot
.42288 .37854 Mdot
.56561 .70195 Mdot
.54575 .69167 Mdot
.33257 .67479 Mdot
.26996 .42751 Mdot
.41196 .59067 Mdot
.61122 .24985 Mdot
.563 .65053 Mdot
.31445 .59495 Mdot
.41782 .33174 Mdot
.40337 .37089 Mdot
.33818 .34185 Mdot
.38406 .54229 Mdot
.49936 .81174 Mdot
.38582 .54598 Mdot
.26298 .40552 Mdot
.45286 .56883 Mdot
.56332 .34392 Mdot
.38008 .53865 Mdot
.34533 .29901 Mdot
.40716 .61059 Mdot
.33197 .53125 Mdot
.53922 .34615 Mdot
.32913 .58 Mdot
.55366 .3736 Mdot
.39582 .59745 Mdot
.36539 .35394 Mdot
.54308 .34593 Mdot
.32887 .40696 Mdot
.34378 .35322 Mdot
.59002 .33707 Mdot
.42782 .35345 Mdot
.3705 .34566 Mdot
.34911 .42653 Mdot
.51057 .66652 Mdot
.46965 .62834 Mdot
.4062 .5686 Mdot
.56443 .41077 Mdot
.66868 .54285 Mdot
.42557 .52456 Mdot
.33066 .55482 Mdot
.44872 .56394 Mdot
.557 .71294 Mdot
.45578 .25298 Mdot
.39057 .36499 Mdot
.6012 .36108 Mdot
.42394 .3078 Mdot
.55566 .32454 Mdot
.3413 .51718 Mdot
.351 .59385 Mdot
.30866 .64597 Mdot
.68113 .3295 Mdot
.17837 .52194 Mdot
.55313 .66264 Mdot
.53987 .39322 Mdot
.36645 .36221 Mdot
.32588 .52039 Mdot
.52392 .65927 Mdot
.55046 .3761 Mdot
.40761 .55946 Mdot
.42519 .49878 Mdot
.66304 .71126 Mdot
.28116 .57182 Mdot
.35454 .39566 Mdot
.58242 .33767 Mdot
.59227 .40088 Mdot
.36781 .267 Mdot
.42927 .39444 Mdot
.48329 .45724 Mdot
.40016 .58286 Mdot
.42321 .35471 Mdot
.52015 .65124 Mdot
.2272 .55922 Mdot
.67767 .50013 Mdot
.51102 .51999 Mdot
.40183 .57175 Mdot
.47378 .40111 Mdot
.55867 .69195 Mdot
.3959 .34761 Mdot
.67758 .5031 Mdot
.42432 .32904 Mdot
.53024 .37621 Mdot
.82354 .60737 Mdot
.416 .5407 Mdot
.42757 .58733 Mdot
.6359 .53006 Mdot
.5282 .65277 Mdot
.42965 .33829 Mdot
.75573 .65356 Mdot
.54437 .3611 Mdot
.62434 .79776 Mdot
.55208 .64766 Mdot
.53423 .7626 Mdot
.59981 .36481 Mdot
.71158 .53042 Mdot
.33401 .42618 Mdot
.66963 .50712 Mdot
.39833 .60042 Mdot
.53597 .67375 Mdot
.68755 .54097 Mdot
.50995 .52969 Mdot
.52165 .17591 Mdot
.52109 .77085 Mdot
.39754 .54725 Mdot
.43303 .17395 Mdot
.79626 .53537 Mdot
.52802 .71676 Mdot
.63426 .51682 Mdot
.42051 .58639 Mdot
.37068 .59596 Mdot
.42115 .54096 Mdot
.68385 .53664 Mdot
.57821 .24739 Mdot
.55224 .35866 Mdot
.38817 .58615 Mdot
.41752 .33753 Mdot
.55973 .36839 Mdot
.64471 .39812 Mdot
.58351 .34643 Mdot
.51764 .70333 Mdot
.33689 .52847 Mdot
.61337 .50533 Mdot
.32489 .18877 Mdot
.65159 .53101 Mdot
.57833 .32778 Mdot
.37952 .50821 Mdot
.67896 .35962 Mdot
.51816 .66377 Mdot
.54555 .35738 Mdot
.42871 .57979 Mdot
.64878 .37989 Mdot
.20562 .50079 Mdot
.58404 .34829 Mdot
.52281 .65554 Mdot
.74192 .2955 Mdot
.40817 .5765 Mdot
.40052 .5285 Mdot
.54228 .66116 Mdot
.29711 .69788 Mdot
.20676 .41225 Mdot
.36691 .56761 Mdot
.65704 .51205 Mdot
.74807 .73417 Mdot
.32899 .53233 Mdot
.29557 .35323 Mdot
.55399 .38704 Mdot
.65989 .57902 Mdot
.5913 .59291 Mdot
.32654 .51896 Mdot
.74793 .65706 Mdot
.69053 .48195 Mdot
.42038 .19451 Mdot
.60857 .33361 Mdot
.49947 .32598 Mdot
.38887 .19035 Mdot
.64063 .49133 Mdot
.54415 .73777 Mdot
.76546 .60873 Mdot
.21417 .64451 Mdot
.74481 .30999 Mdot
.47377 .31577 Mdot
.21158 .46208 Mdot
.51905 .46563 Mdot
.56774 .38853 Mdot
.41263 .31177 Mdot
.36169 .55407 Mdot
.79722 .53074 Mdot
.51898 .80808 Mdot
.4188 .81779 Mdot
.43808 .1714 Mdot
.45051 .79953 Mdot
.51873 .18192 Mdot
.63202 .20735 Mdot
.31212 .62945 Mdot
.68879 .32457 Mdot
.62234 .80286 Mdot
.28452 .29122 Mdot
.75401 .68739 Mdot
.40368 .47392 Mdot
.56473 .52607 Mdot
.82979 .535 Mdot
.56158 .76461 Mdot
.31265 .7424 Mdot
.5555 .34276 Mdot
.51175 .64713 Mdot
.76348 .60085 Mdot
.49888 .65029 Mdot
.61732 .59681 Mdot
.7468 .29349 Mdot
.54014 .17366 Mdot
.58534 .77853 Mdot
.81699 .3995 Mdot
.36442 .66511 Mdot
.47161 .86823 Mdot
.52987 .35151 Mdot
.53629 .71068 Mdot
.38959 .40397 Mdot
.36194 .26371 Mdot
.71401 .66632 Mdot
.78021 .58339 Mdot
.50636 .22485 Mdot
.28477 .45726 Mdot
.54775 .67822 Mdot
.57638 .60871 Mdot
.63148 .56589 Mdot
.67951 .66661 Mdot
.28011 .32262 Mdot
.67154 .24262 Mdot
.52636 .49596 Mdot
.76629 .52375 Mdot
.72694 .40102 Mdot
.18457 .63752 Mdot
.31361 .35445 Mdot
.3037 .56378 Mdot
.60855 .59001 Mdot
.79097 .38724 Mdot
.23694 .66118 Mdot
.256 .44553 Mdot
.3582 .26476 Mdot
.28735 .26481 Mdot
.8113 .46904 Mdot
.18269 .37751 Mdot
.53084 .62566 Mdot
.42889 .59142 Mdot
.3069 .69034 Mdot
.55144 .8146 Mdot
.4155 .38388 Mdot
.56938 .22891 Mdot
.3883 .33172 Mdot
.56966 .71953 Mdot
.20178 .47242 Mdot
.64604 .7629 Mdot
.55391 .81974 Mdot
.37443 .3245 Mdot
.32176 .58287 Mdot
.85539 .64151 Mdot
.45375 .19459 Mdot
.65479 .64415 Mdot
.43792 .15044 Mdot
.46678 .41992 Mdot
.50593 .56007 Mdot
.68501 .54075 Mdot
.38622 .18403 Mdot
.5348 .66482 Mdot
.19924 .33167 Mdot
.38205 .16683 Mdot
.26415 .60452 Mdot
.81427 .2771 Mdot
.38673 .25036 Mdot
.47946 .4195 Mdot
.71649 .48946 Mdot
.31134 .39297 Mdot
.27906 .71788 Mdot
.29956 .50541 Mdot
.69024 .36827 Mdot
.85391 .49898 Mdot
.41424 .18767 Mdot
.58108 .8084 Mdot
.80362 .63388 Mdot
.22706 .66673 Mdot
.59061 .48714 Mdot
.39561 .6364 Mdot
.61734 .4128 Mdot
.65829 .24752 Mdot
.30262 .2355 Mdot
.30651 .35115 Mdot
.88821 .49394 Mdot
.43897 .37608 Mdot
.53724 .26484 Mdot
.74365 .27673 Mdot
.2967 .45423 Mdot
.56188 .59208 Mdot
.30553 .3022 Mdot
.31097 .57013 Mdot
.4034 .29199 Mdot
.60087 .23302 Mdot
.62713 .63171 Mdot
.29876 .2891 Mdot
.7443 .32986 Mdot
.70796 .6992 Mdot
.42467 .75496 Mdot
.34155 .26294 Mdot
.51124 .63132 Mdot
.27159 .45324 Mdot
.55855 .58389 Mdot
.52732 .16826 Mdot
.67845 .48269 Mdot
.57036 .16395 Mdot
.20936 .41376 Mdot
.44256 .52192 Mdot
.4765 .56541 Mdot
.53572 .61904 Mdot
.27833 .43003 Mdot
.32086 .56753 Mdot
.68333 .70107 Mdot
.59269 .18544 Mdot
.38167 .65975 Mdot
.63355 .57759 Mdot
.65695 .36469 Mdot
.75769 .28968 Mdot
.33099 .69568 Mdot
.42761 .39789 Mdot
.25686 .37487 Mdot
.21043 .66687 Mdot
.5689 .35941 Mdot
.5915 .80072 Mdot
.62902 .53519 Mdot
.21137 .52356 Mdot
.4548 .78098 Mdot
.26166 .63877 Mdot
.59401 .18572 Mdot
.47071 .3391 Mdot
.20595 .4436 Mdot
.29097 .48307 Mdot
.68782 .76729 Mdot
.64071 .30155 Mdot
.36733 .60766 Mdot
.77778 .54274 Mdot
.3729 .36168 Mdot
.37281 .71189 Mdot
.74114 .72578 Mdot
.47687 .28724 Mdot
.43679 .61553 Mdot
.25039 .59013 Mdot
.50964 .40216 Mdot
.48386 .47153 Mdot
.14727 .50831 Mdot
.33907 .51463 Mdot
.37191 .23959 Mdot
.81273 .48804 Mdot
.29611 .39277 Mdot
.78945 .34916 Mdot
.77665 .38966 Mdot
.20671 .33811 Mdot
.42176 .16258 Mdot
.47614 .25395 Mdot
.38083 .19948 Mdot
.49563 .15514 Mdot
.19945 .35908 Mdot
.47686 .58713 Mdot
.63834 .53608 Mdot
.16624 .64677 Mdot
.59194 .35197 Mdot
.41195 .21904 Mdot
.73671 .69498 Mdot
.6184 .43074 Mdot
.59446 .72912 Mdot
.30615 .51766 Mdot
.52579 .47389 Mdot
.53492 .72094 Mdot
.32604 .57786 Mdot
.16345 .47923 Mdot
.23991 .30575 Mdot
.17535 .4219 Mdot
.82559 .46684 Mdot
.36133 .20616 Mdot
.49886 .42726 Mdot
.59737 .77041 Mdot
.34985 .63014 Mdot
.3503 .53542 Mdot
.41215 .41831 Mdot
.38928 .24892 Mdot
.24738 .59456 Mdot
.71871 .64348 Mdot
.50369 .68939 Mdot
.58441 .23111 Mdot
.53644 .90696 Mdot
.36172 .6787 Mdot
.66759 .76049 Mdot
.37436 .27046 Mdot
.27596 .41649 Mdot
.6472 .24921 Mdot
.26219 .62111 Mdot
.64857 .21031 Mdot
.55229 .72847 Mdot
.75268 .68349 Mdot
.48998 .30665 Mdot
.45272 .47143 Mdot
.46153 .24859 Mdot
.55943 .18537 Mdot
.68489 .45789 Mdot
.22914 .59932 Mdot
.73936 .59687 Mdot
.2767 .68096 Mdot
.60526 .31067 Mdot
.72275 .41704 Mdot
.72646 .73534 Mdot
.74263 .36892 Mdot
.27597 .38484 Mdot
.55078 .4609 Mdot
.59854 .64836 Mdot
.69511 .48358 Mdot
.28092 .38236 Mdot
.42159 .44416 Mdot
.36973 .21819 Mdot
.29956 .18099 Mdot
.17096 .55316 Mdot
.80798 .34032 Mdot
.62689 .25012 Mdot
.42837 .61516 Mdot
.69101 .22807 Mdot
.16684 .41665 Mdot
.36209 .16406 Mdot
.71845 .44186 Mdot
.60513 .32562 Mdot
.71215 .53669 Mdot
.17453 .46898 Mdot
.56641 .2489 Mdot
.68538 .23591 Mdot
.31838 .29612 Mdot
.71629 .53734 Mdot
.30613 .78151 Mdot
.28533 .27387 Mdot
.48031 .78106 Mdot
.28192 .5745 Mdot
.45686 .5846 Mdot
.55889 .78351 Mdot
.49861 .65393 Mdot
.74068 .39251 Mdot
.26523 .44059 Mdot
.57799 .35669 Mdot
.39488 .41288 Mdot
.78292 .56992 Mdot
.34198 .53421 Mdot
.59964 .50705 Mdot
.50263 .67835 Mdot
.68491 .3304 Mdot
.65639 .68797 Mdot
.29407 .23507 Mdot
.42725 .23818 Mdot
.45884 .55072 Mdot
.29662 .38591 Mdot
.45234 .24856 Mdot
.19948 .42202 Mdot
.67648 .48868 Mdot
.46227 .16716 Mdot
.54914 .52677 Mdot
.27038 .45161 Mdot
.54061 .79353 Mdot
.464 .65779 Mdot
.34328 .5756 Mdot
.75022 .36049 Mdot
.45456 .71635 Mdot
.49766 .49816 Mdot
.38946 .63125 Mdot
.42379 .64166 Mdot
.7051 .23441 Mdot
.41363 .28302 Mdot
.71544 .40199 Mdot
.491 .16552 Mdot
.68407 .52935 Mdot
.57273 .66818 Mdot
.3751 .31406 Mdot
.77201 .63511 Mdot
.47486 .7139 Mdot
.20523 .50236 Mdot
.61441 .42902 Mdot
.49019 .27956 Mdot
.50044 .17081 Mdot
.45587 .17333 Mdot
.48099 .83145 Mdot
.49181 .66219 Mdot
.32233 .63216 Mdot
.76362 .65737 Mdot
.51841 .64134 Mdot
.68293 .71808 Mdot
.67196 .71837 Mdot
.32536 .2246 Mdot
.60236 .52936 Mdot
.85033 .48426 Mdot
.35072 .39829 Mdot
.5579 .23195 Mdot
.2054 .58397 Mdot
.71508 .74204 Mdot
.5324 .18673 Mdot
.49128 .56038 Mdot
.40672 .77063 Mdot
.38896 .47243 Mdot
.61808 .69657 Mdot
.22585 .70964 Mdot
.35969 .3216 Mdot
.53938 .76602 Mdot
.74707 .32948 Mdot
.41076 .54977 Mdot
.16873 .56803 Mdot
.77775 .60996 Mdot
.18514 .51888 Mdot
.71514 .54664 Mdot
.37216 .52723 Mdot
.39521 .60924 Mdot
.28402 .34946 Mdot
.64247 .60441 Mdot
.35478 .23145 Mdot
.76761 .70488 Mdot
.71267 .29803 Mdot
.51753 .80749 Mdot
.38666 .23709 Mdot
.68605 .24563 Mdot
.79797 .5223 Mdot
.5716 .48099 Mdot
.39806 .24718 Mdot
.31108 .44289 Mdot
.81691 .40721 Mdot
.43528 .44349 Mdot
.73383 .54245 Mdot
.71702 .67426 Mdot
.77105 .41448 Mdot
.2197 .57079 Mdot
.38727 .52036 Mdot
.23206 .37534 Mdot
.64943 .2204 Mdot
.49532 .82443 Mdot
.26782 .71979 Mdot
.16573 .53992 Mdot
.4655 .74679 Mdot
.77172 .40188 Mdot
.79092 .53715 Mdot
.68354 .7858 Mdot
.55152 .53428 Mdot
.51113 .19797 Mdot
.30188 .45851 Mdot
.49728 .16855 Mdot
.63102 .52322 Mdot
.72397 .61347 Mdot
.65497 .35809 Mdot
.37173 .2098 Mdot
.34802 .71724 Mdot
.58661 .19372 Mdot
.48059 .43271 Mdot
.21436 .32298 Mdot
.72481 .34785 Mdot
.51616 .45607 Mdot
.5359 .3857 Mdot
.46307 .33057 Mdot
.58627 .21866 Mdot
.66408 .29885 Mdot
.70332 .74728 Mdot
.61103 .35874 Mdot
.39307 .30954 Mdot
.48979 .79208 Mdot
.26641 .49732 Mdot
.75859 .36754 Mdot
.29672 .38637 Mdot
.56909 .17894 Mdot
.2958 .31774 Mdot
.22944 .3846 Mdot
.41211 .23123 Mdot
.85138 .55621 Mdot
.65331 .63876 Mdot
.38816 .28055 Mdot
.7813 .59599 Mdot
.55699 .2672 Mdot
.50153 .57011 Mdot
.07376 .44363 Mdot
.82535 .59087 Mdot
.70597 .334 Mdot
.30318 .23546 Mdot
.79414 .40519 Mdot
.68563 .33486 Mdot
.27224 .6993 Mdot
.55425 .56995 Mdot
.226 .43939 Mdot
.38537 .5704 Mdot
.15853 .4671 Mdot
.26272 .47979 Mdot
.27676 .25609 Mdot
.70513 .24328 Mdot
.54699 .78268 Mdot
.33621 .536 Mdot
.60371 .36806 Mdot
.60842 .57905 Mdot
.2471 .50852 Mdot
.3413 .7337 Mdot
.54626 .59719 Mdot
.64532 .35206 Mdot
.53239 .39064 Mdot
.43786 .2564 Mdot
.58386 .71784 Mdot
.55961 .24229 Mdot
.76591 .40915 Mdot
.52148 .39985 Mdot
.52744 .50709 Mdot
.28032 .39391 Mdot
.59006 .59524 Mdot
.48433 .77862 Mdot
.25722 .61446 Mdot
.61633 .47597 Mdot
.58177 .34219 Mdot
.46021 .77346 Mdot
.83136 .54466 Mdot
.71785 .30984 Mdot
.28736 .26151 Mdot
.44335 .32125 Mdot
.37664 .76764 Mdot
.2804 .37427 Mdot
.29083 .73332 Mdot
.37033 .78292 Mdot
.65482 .3117 Mdot
.60456 .70175 Mdot
.3075 .73114 Mdot
.76849 .56157 Mdot
.34976 .20365 Mdot
.75354 .68678 Mdot
.76201 .66453 Mdot
.62709 .3301 Mdot
.51468 .73749 Mdot
.52394 .79211 Mdot
.33544 .40569 Mdot
.4853 .46488 Mdot
.43657 .86148 Mdot
.41724 .63408 Mdot
.31253 .82155 Mdot
.70529 .53526 Mdot
.23511 .68611 Mdot
.3164 .44514 Mdot
.5559 .45886 Mdot
.45651 .42755 Mdot
.7535 .37589 Mdot
.70682 .60923 Mdot
.81966 .49622 Mdot
.3807 .79803 Mdot
.54261 .33412 Mdot
.77732 .69778 Mdot
.85544 .55462 Mdot
.41233 .76206 Mdot
.3544 .51148 Mdot
.83574 .57303 Mdot
.59541 .31804 Mdot
.24728 .59785 Mdot
.7899 .34564 Mdot
.66691 .28786 Mdot
.48244 .5659 Mdot
.27467 .42397 Mdot
.51345 .19655 Mdot
.45621 .16039 Mdot
.30483 .7706 Mdot
.60325 .23497 Mdot
.63372 .52798 Mdot
.50112 .43932 Mdot
.59847 .20665 Mdot
.50514 .54578 Mdot
.71323 .57409 Mdot
.54677 .58811 Mdot
.40471 .87137 Mdot
.41971 .21251 Mdot
.35826 .23075 Mdot
.52859 .58061 Mdot
.58376 .69816 Mdot
.63511 .59834 Mdot
.56429 .5924 Mdot
.67909 .29804 Mdot
.81591 .55598 Mdot
.56201 .58804 Mdot
.59778 .83472 Mdot
.45578 .65776 Mdot
.49542 .39064 Mdot
.51319 .79968 Mdot
.37466 .65541 Mdot
.71804 .5449 Mdot
.24886 .36406 Mdot
.73441 .30734 Mdot
.65134 .54886 Mdot
.75551 .35986 Mdot
.76631 .52039 Mdot
.54035 .7459 Mdot
.48503 .72961 Mdot
.68689 .28425 Mdot
.36108 .73884 Mdot
.60101 .74363 Mdot
.22712 .5508 Mdot
.57526 .3241 Mdot
.73367 .2989 Mdot
.5387 .36963 Mdot
.30935 .57606 Mdot
.51141 .52454 Mdot
.29623 .51429 Mdot
.177 .51013 Mdot
.37411 .34863 Mdot
.50607 .67501 Mdot
.25172 .7284 Mdot
.53682 .64146 Mdot
.16622 .46179 Mdot
.26238 .63556 Mdot
.54346 .79404 Mdot
.47629 .25946 Mdot
.45755 .28621 Mdot
.51825 .85854 Mdot
.60728 .49579 Mdot
.62314 .40992 Mdot
.63246 .71222 Mdot
.52817 .70433 Mdot
.43187 .23412 Mdot
.54532 .33965 Mdot
.55379 .55592 Mdot
.68187 .4547 Mdot
.48669 .67641 Mdot
.58724 .73825 Mdot
.53887 .53282 Mdot
.23937 .4262 Mdot
.34349 .22012 Mdot
.57964 .3888 Mdot
.33045 .82266 Mdot
.33488 .55295 Mdot
.41627 .74767 Mdot
.64664 .20686 Mdot
.31659 .78851 Mdot
.60431 .42027 Mdot
.85998 .55209 Mdot
.4559 .55267 Mdot
.65866 .25901 Mdot
.54265 .67083 Mdot
.75686 .67258 Mdot
.38194 .33923 Mdot
.30078 .39327 Mdot
.70686 .54176 Mdot
.22745 .59939 Mdot
.54984 .43381 Mdot
.55345 .63839 Mdot
.63801 .2678 Mdot
.32904 .63917 Mdot
.72028 .59014 Mdot
.44282 .27245 Mdot
.41987 .76658 Mdot
.48521 .72399 Mdot
.5714 .74009 Mdot
.3709 .22419 Mdot
.76618 .66862 Mdot
.31022 .21302 Mdot
.50165 .6206 Mdot
.46302 .37108 Mdot
.70113 .69465 Mdot
.73072 .33031 Mdot
.621 .67259 Mdot
.6182 .19191 Mdot
.25905 .45411 Mdot
.50721 .71278 Mdot
.26663 .40278 Mdot
.40764 .48604 Mdot
.54815 .48831 Mdot
.74146 .41121 Mdot
.41396 .81849 Mdot
.60611 .60965 Mdot
.24659 .68016 Mdot
.61253 .692 Mdot
.35124 .24502 Mdot
.60279 .68887 Mdot
.55463 .41883 Mdot
.53094 .75193 Mdot
.62455 .48461 Mdot
.3642 .19568 Mdot
.62728 .19586 Mdot
.63518 .48571 Mdot
.4774 .22929 Mdot
.78832 .3674 Mdot
.38139 .48852 Mdot
.48431 .40423 Mdot
.41951 .59601 Mdot
.33903 .63027 Mdot
.33453 .80664 Mdot
.69929 .3085 Mdot
.43617 .62151 Mdot
.41408 .1935 Mdot
.40275 .18416 Mdot
.24453 .28937 Mdot
.6488 .78826 Mdot
.55878 .70737 Mdot
.19502 .37949 Mdot
.54686 .60034 Mdot
.47997 .15326 Mdot
.65622 .30652 Mdot
.6886 .21539 Mdot
.40011 .7654 Mdot
.76617 .35988 Mdot
.28688 .71062 Mdot
.67658 .60304 Mdot
.80396 .46525 Mdot
.54039 .44453 Mdot
.6993 .39591 Mdot
.80024 .43014 Mdot
.71233 .78498 Mdot
.32771 .51063 Mdot
.77309 .50628 Mdot
.75908 .59012 Mdot
.72555 .29109 Mdot
.57401 .28582 Mdot
.34035 .52472 Mdot
.66803 .37679 Mdot
.19773 .54919 Mdot
.28973 .37836 Mdot
.3984 .30763 Mdot
.57648 .28599 Mdot
.22392 .49986 Mdot
.25578 .41424 Mdot
.75621 .68587 Mdot
.41561 .76899 Mdot
.57417 .55808 Mdot
.43411 .52579 Mdot
.59069 .72604 Mdot
.38717 .32556 Mdot
.58151 .44893 Mdot
.40163 .59666 Mdot
.56107 .41278 Mdot
.70945 .59552 Mdot
.16745 .51516 Mdot
.63139 .62766 Mdot
.79193 .5848 Mdot
.59315 .67484 Mdot
.75472 .53674 Mdot
.63093 .68546 Mdot
.1924 .58847 Mdot
.5258 .29376 Mdot
.30675 .35108 Mdot
.46205 .18871 Mdot
.30225 .28757 Mdot
.55682 .75162 Mdot
.24788 .31744 Mdot
.6367 .50383 Mdot
.48477 .61423 Mdot
.74753 .61252 Mdot
.42399 .2567 Mdot
.40218 .63099 Mdot
.76434 .35877 Mdot
.61597 .41853 Mdot
.35545 .27613 Mdot
.81536 .47584 Mdot
.36581 .64806 Mdot
.46075 .79221 Mdot
.44456 .1755 Mdot
.5929 .38933 Mdot
.78867 .63596 Mdot
.74144 .55864 Mdot
.50227 .31819 Mdot
.33082 .24476 Mdot
.31625 .22141 Mdot
.47701 .44159 Mdot
.30449 .43476 Mdot
.41106 .52868 Mdot
.73327 .72412 Mdot
.71733 .32319 Mdot
.31436 .50093 Mdot
.70571 .43342 Mdot
.5625 .65569 Mdot
.74405 .43934 Mdot
.56725 .53511 Mdot
.22582 .46411 Mdot
.49575 .65788 Mdot
.51789 .81138 Mdot
.36606 .34958 Mdot
.4629 .3988 Mdot
.3257 .58221 Mdot
.31005 .41628 Mdot
.57568 .81742 Mdot
.37418 .62075 Mdot
.62083 .237 Mdot
.44354 .77543 Mdot
.75546 .65695 Mdot
.67591 .27947 Mdot
.65461 .31664 Mdot
.70082 .60842 Mdot
.5191 .75059 Mdot
.63597 .44862 Mdot
.44662 .56935 Mdot
.56522 .42177 Mdot
.52911 .63258 Mdot
.75808 .31123 Mdot
.4658 .7379 Mdot
.32794 .40985 Mdot
.61179 .45977 Mdot
.30779 .57707 Mdot
.68345 .46839 Mdot
.67405 .21123 Mdot
.67571 .60442 Mdot
.26272 .44149 Mdot
.60205 .52803 Mdot
.31896 .44036 Mdot
.26159 .64683 Mdot
.37411 .17269 Mdot
.27934 .70607 Mdot
.51351 .48295 Mdot
.2522 .69897 Mdot
.74726 .37586 Mdot
.79454 .35688 Mdot
.2571 .43296 Mdot
.45443 .40907 Mdot
.43172 .37642 Mdot
.65512 .71971 Mdot
.60756 .4733 Mdot
.39073 .30072 Mdot
.56396 .56357 Mdot
.67228 .43815 Mdot
.67222 .56972 Mdot
.31206 .51097 Mdot
.42415 .21988 Mdot
.45414 .18287 Mdot
.74648 .68212 Mdot
.68499 .47824 Mdot
.50002 .33086 Mdot
.2302 .47741 Mdot
.72949 .23356 Mdot
.19488 .66908 Mdot
.41255 .53031 Mdot
.65194 .47068 Mdot
.29314 .43556 Mdot
.58061 .33515 Mdot
.58553 .6017 Mdot
.6323 .67324 Mdot
.68895 .54659 Mdot
.37711 .31061 Mdot
.34694 .28065 Mdot
.75539 .39152 Mdot
.26923 .50611 Mdot
.65029 .38551 Mdot
.16429 .52243 Mdot
.84012 .51835 Mdot
.72223 .32297 Mdot
.67661 .19013 Mdot
.73729 .54971 Mdot
.46352 .63996 Mdot
.3039 .67557 Mdot
.34532 .22231 Mdot
.30436 .37593 Mdot
.21764 .54589 Mdot
.65261 .32764 Mdot
.25683 .4468 Mdot
.51563 .58628 Mdot
.39718 .23486 Mdot
.73818 .43907 Mdot
.53931 .47238 Mdot
.46021 .28927 Mdot
.26705 .28976 Mdot
.47021 .80085 Mdot
.48669 .18663 Mdot
.19927 .56594 Mdot
.65568 .80778 Mdot
.37951 .18441 Mdot
.34749 .36417 Mdot
.55036 .28969 Mdot
.3092 .68968 Mdot
.43219 .44641 Mdot
.49564 .55543 Mdot
.24424 .59308 Mdot
.46226 .69763 Mdot
.51439 .24164 Mdot
.22254 .64567 Mdot
.27658 .38416 Mdot
.39611 .65987 Mdot
.45345 .41244 Mdot
.47751 .77444 Mdot
.47288 .23211 Mdot
.51598 .56525 Mdot
.4554 .45678 Mdot
.32843 .37472 Mdot
.44978 .77272 Mdot
.71602 .68828 Mdot
.78497 .39925 Mdot
.61796 .83767 Mdot
.60662 .25343 Mdot
.1972 .60197 Mdot
.35045 .5276 Mdot
.27348 .23741 Mdot
.78558 .43029 Mdot
.64072 .29594 Mdot
.81421 .52775 Mdot
.49265 .37471 Mdot
.47163 .64835 Mdot
.44676 .56872 Mdot
.57908 .22036 Mdot
.53629 .7672 Mdot
.33846 .65664 Mdot
.22127 .60106 Mdot
.28876 .40529 Mdot
.3181 .30201 Mdot
.34276 .40357 Mdot
.48426 .62082 Mdot
.5347 .64469 Mdot
.17794 .41175 Mdot
.49619 .45954 Mdot
.30889 .56188 Mdot
.35433 .47291 Mdot
.27889 .68305 Mdot
.86143 .49833 Mdot
.53799 .62009 Mdot
.31679 .27827 Mdot
.43275 .79404 Mdot
.45172 .48995 Mdot
.61079 .65601 Mdot
.68674 .16253 Mdot
.34492 .15995 Mdot
.5435 .63315 Mdot
.65466 .76678 Mdot
.44209 .79757 Mdot
.36618 .21813 Mdot
.49474 .3038 Mdot
.69726 .44841 Mdot
.34784 .46927 Mdot
.4712 .48733 Mdot
.34754 .60023 Mdot
.80977 .50298 Mdot
.38641 .16949 Mdot
.22139 .61681 Mdot
.41699 .19244 Mdot
.46484 .52578 Mdot
.3684 .61395 Mdot
.75773 .24607 Mdot
.58731 .20234 Mdot
.36266 .49718 Mdot
.30695 .7405 Mdot
.39567 .63593 Mdot
.36489 .55759 Mdot
.52183 .2145 Mdot
.7782 .69496 Mdot
.27715 .37874 Mdot
.37139 .21039 Mdot
.49608 .65076 Mdot
.56149 .42773 Mdot
.70547 .53718 Mdot
.46525 .43607 Mdot
.42495 .50167 Mdot
.69034 .53757 Mdot
.27281 .57522 Mdot
.76336 .34722 Mdot
.60931 .57042 Mdot
.78096 .66895 Mdot
.59794 .16771 Mdot
.47658 .75176 Mdot
.65352 .71345 Mdot
.33124 .51568 Mdot
.39611 .65838 Mdot
.23997 .50896 Mdot
.36488 .63922 Mdot
.79893 .39827 Mdot
.11817 .40546 Mdot
.68583 .40145 Mdot
.23399 .40629 Mdot
.57901 .71738 Mdot
.58279 .57119 Mdot
.50308 .78331 Mdot
.51054 .32631 Mdot
.5668 .39699 Mdot
.45411 .51088 Mdot
.49427 .62057 Mdot
.69544 .55553 Mdot
.28326 .79021 Mdot
.35877 .5143 Mdot
.6005 .61976 Mdot
.48289 .15464 Mdot
.22672 .55056 Mdot
.38651 .73324 Mdot
.44774 .58556 Mdot
.6824 .67104 Mdot
.45542 .4065 Mdot
.69253 .26616 Mdot
.23413 .37697 Mdot
.42475 .19862 Mdot
.46522 .73455 Mdot
.45388 .79318 Mdot
.42164 .51811 Mdot
.38535 .38532 Mdot
.67086 .58153 Mdot
.55201 .22224 Mdot
.47222 .58175 Mdot
.44009 .15835 Mdot
.49686 .40114 Mdot
.58802 .44304 Mdot
.50592 .6132 Mdot
.23271 .3057 Mdot
.24675 .6587 Mdot
.52959 .78279 Mdot
.18539 .57424 Mdot
.42648 .2742 Mdot
.26756 .49422 Mdot
.60266 .37683 Mdot
.47409 .57255 Mdot
.50337 .63964 Mdot
.15876 .54601 Mdot
.50742 .20774 Mdot
.68688 .382 Mdot
.7195 .41688 Mdot
.69304 .7403 Mdot
.73284 .58041 Mdot
.64715 .17412 Mdot
.44034 .28239 Mdot
.16244 .5411 Mdot
.77099 .65735 Mdot
.5235 .6223 Mdot
.76471 .37841 Mdot
.44036 .62514 Mdot
.58548 .36807 Mdot
.41043 .2015 Mdot
.3267 .6012 Mdot
.20369 .47368 Mdot
.4301 .60872 Mdot
.18691 .49449 Mdot
.3553 .30684 Mdot
.46511 .22462 Mdot
.72096 .35084 Mdot
.26803 .6775 Mdot
.73395 .27564 Mdot
.65696 .72112 Mdot
.72018 .23983 Mdot
.74067 .28928 Mdot
.45609 .16775 Mdot
.20331 .52291 Mdot
.34518 .79883 Mdot
.66584 .30451 Mdot
.6926 .29053 Mdot
.7531 .41021 Mdot
.29964 .69563 Mdot
.46528 .33034 Mdot
.52902 .61698 Mdot
.65213 .60736 Mdot
.62543 .49394 Mdot
.10593 .60095 Mdot
.32876 .30612 Mdot
.51298 .62466 Mdot
.44657 .30558 Mdot
.4188 .17717 Mdot
.2897 .68217 Mdot
.80506 .44457 Mdot
.5633 .52482 Mdot
.35906 .60278 Mdot
.47394 .72199 Mdot
.72306 .7137 Mdot
.4605 .33558 Mdot
.53381 .86849 Mdot
.83308 .5315 Mdot
.69272 .42237 Mdot
.54484 .49711 Mdot
.51149 .64337 Mdot
.61301 .72569 Mdot
.46672 .27724 Mdot
.80764 .41457 Mdot
.76536 .35528 Mdot
.59625 .20545 Mdot
.51927 .85712 Mdot
.75816 .65935 Mdot
.34371 .22174 Mdot
.72925 .34503 Mdot
.56656 .64702 Mdot
.36627 .39426 Mdot
.57547 .31792 Mdot
.69711 .37566 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0Roooool2o`0000?ooooo
0_l0000Aooooo`;o0000Y?ooool001cooooo0_l0002<ooooo`;o00000oooool2o`0000Kooooo0ol0
0008ooooo`;o0000Y?ooool001cooooo00?o0000ooooooooool0O_ooool3o`0001Oooooo0ol00002
ooooo`;o0000Z_ooool001cooooo00?o0000ooooooooool0K?ooool2o`0000gooooo1_l0000:oooo
o`;o00003?ooool2o`0000;ooooo0_l0002Zooooo`007?ooool00ol0003oooooooooo`1/ooooo`;o
00002_ooool6o`0000Oooooo0_l00004ooooo`;o00000oooool2o`0000kooooo0_l0000iooooo`;o
0000K?ooool001cooooo00?o0000ooooooooool0L_ooool2o`0000Cooooo0ol0000:ooooo`;o0000
2Oooool2o`0000Kooooo0_l00002ooooo`;o00000_ooool2o`0001?ooooo0_l0000Tooooo`;o0000
K?ooool001cooooo00?o0000ooooooooool0L_ooool2o`0000Cooooo0_l0000Fooooo`Co00001?oo
ool2o`0000;ooooo1?l00008ooooo`;o00002oooool2o`0000Oooooo0_l00029ooooo`007?ooool0
0ol0003oooooooooo`1_ooooo`;o00001oooool4o`0000oooooo0_l00003ooooo`Co00002_ooool3
o`0000Oooooo0_l0000Dooooo`;o0000ROooool001cooooo00?o0000ooooooooool0Koooool2o`00
00Gooooo0_l00002ooooo`;o00002oooool6o`0000?ooooo0_l0000=ooooo`;o00002?ooool2o`00
0003ooooool0003o000000Kooooo0_l0000Dooooo`;o00000_ooool2o`0007Wooooo000Looooo`03
o`000?oooooooooo07Kooooo0_l0000<ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o
000000?oooooo`000?l000004_ooool4o`000003ooooool0003o000000?o00001_ooool4o`0001;o
oooo0_l00002ooooo`;o0000NOooool001cooooo00?o0000ooooooooool0G_ooool2o`0002Cooooo
0_l00007ooooo`;o00005?ooool5o`0000?ooooo0_l00005ooooo`;o000000Coooooo`000?l0003o
0000TOooool001cooooo00?o0000ooooooooool0G_ooool2o`0001Oooooo1Ol00003ooooo`;o0000
3oooool2o`0000Sooooo0_l00007ooooo`Oo00002?ooool2o`000005ooooool0003o0000o`000?oo
ool00_l0002>ooooo`007?ooool00ol0003oooooooooo`1gooooo`Go000000?oooooo`000?l00000
0_l00002ooooo`;o00002oooool2o`0000Sooooo0_l00006ooooo`;o000000?oooooo`000?l00000
1?l00006ooooo`?o00001Oooool2o`0000;ooooo0_l0002:ooooo`007?ooool00ol0003ooooooooo
o`1Vooooo`;o00004oooool4o`0000Cooooo0_l00007ooooo`;o00001?ooool2o`0000Kooooo0_l0
0006ooooo`;o00000oooool4o`0000Kooooo0ol00009ooooo`?o00006?ooool2o`0006oooooo0000
1_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003ooooo
ooooo`1Vooooo`;o00002Oooool2o`0000Gooooo0_l000000ooooooo0000o`000006ooooo`?o0000
1_ooool2o`0000Cooooo0_l0000Cooooo`;o00004_ooool2o`000003ooooool0003o000000;ooooo
0_l000000ooooooo0000o`00000Aooooo`;o0000Koooool00006oooooomgMgOoV9RHoooooonHV9So
MgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo
077ooooo1?l000000ooooooo0000o`000002o`0000Wooooo1?l00009ooooo`;o00004Oooool2o`00
01Kooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00001o
ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^
00Oooooo00?o0000ooooooooool0Loooool2o`000003ooooool0003o000000;o00002Oooool5o`00
00Sooooo1?l00006ooooo`;o00001_ooool3o`0001Wooooo0ol00007ooooo`Co0000OOooool00003
ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06ooooo`?o
0000N?ooool2o`0000Sooooo0_l00002ooooo`;o00000_ooool2o`0000Kooooo0_l00006ooooo`;o
00001_ooool2o`0000Sooooo0_l00005ooooo`;o00001_ooool2o`000003ooooool0003o000000[o
oooo0_l0001mooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMg
MomVIVKooooo00Gooooo00?o0000ooooooooool0K_ooool2o`0000;ooooo0_l0000>ooooo`;o0000
00?oooooo`000?l000000oooool2o`0000Oooooo0_l0000Gooooo`;o00001Oooool2o`0000Kooooo
0_l000000ooooooo0000o`000006ooooo`;o0000POooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06gooooo0ol0
0002ooooo`;o00004Oooool2o`0000cooooo0_l00002ooooo`;o00002?ooool2o`0001_ooooo0ol0
0005ooooo`;o00000_ooool2o`0000;ooooo0_l0001iooooo`0000KoooooogMgMonHV9SooooooiRH
V?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`1Wooooo`;o
000000Coooooo`000?l0003ooooo0_l00006ooooo`;o00006Oooool3o`0000Cooooo0_l00005oooo
o`;o000000?oooooo`000?l000005Oooool2o`0000Gooooo0_l00005ooooo`;o00000_ooool2o`00
00;ooooo1Ol00004ooooo`;o0000L?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0HOooool2o`0000Cooooo0_l0
00000ooooooo0000o`000009ooooo`;o00003_ooool2o`0000Wooooo0ol00003ooooo`;o000000?o
ooooo`000?l000000oooool2o`000003ooooool0003o000000;ooooo0ol0000@ooooo`;o00005Ooo
ool4o`0000;ooooo1?l00003ooooo`;o0000Joooool001cooooo00?o0000ooooooooool0HOooool3
o`0000oooooo0ol0000?ooooo`;o00003?ooool5o`000003ooooool0003o000000Kooooo0_l00002
ooooo`?o00001oooool2o`0002Cooooo0_l000000ooooooo0000o`000002ooooo`;o0000Joooool0
01cooooo00?o0000ooooooooool0H_ooool3o`0000Oooooo0_l00005ooooo`?o00003?ooool6o`00
00;ooooo0_l00007ooooo`?o00006Oooool2o`0000Oooooo0_l000000ooooooo0000o`00000Aoooo
o`?o00001oooool2o`0006oooooo000Looooo`03o`000?oooooooooo06?ooooo0_l000000ooooooo
0000o`000004ooooo`?o00001_ooool2o`0000Sooooo0_l000000ooooooo0000o`000004o`0000;o
oooo0_l00007ooooo`?o00004Oooool2o`0000Cooooo0_l000000ooooooo0000o`000006ooooo`;o
000000?oooooo`000?l000004Oooool4o`0000;ooooo0_l0001cooooo`007?ooool00ol0003ooooo
ooooo`1Vooooo`;o00001?ooool3o`0000Kooooo0_l00003ooooo`;o00000oooool2o`0000Gooooo
0_l0000;ooooo`?o00002oooool2o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l00000
7_ooool2o`0000;ooooo0_l00005ooooo`;o0000K?ooool001cooooo00?o0000ooooooooool0IOoo
ool2o`0000[ooooo0_l00007ooooo`;o00005oooool2o`0000;ooooo0_l00008ooooo`;o00000_oo
ool2o`0000Gooooo0_l00002ooooo`;o00000oooool2o`0000Kooooo0_l0000Aooooo`;o00002Ooo
ool5o`0006Wooooo000Looooo`03o`000?oooooooooo05gooooo0_l00006ooooo`;o00002Oooool3
o`000003ooooool0003o000000Wooooo0_l000001?oooooo0000o`000?l00003ooooo`;o00002Ooo
ool2o`000005ooooool0003o0000o`000?ooool00_l00009ooooo`;o00001Oooool2o`0000?ooooo
0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000000;o00003oooool2o`0000[ooooo
1Ol00008ooooo`;o0000G_ooool001cooooo00?o0000ooooooooool0G?ooool5o`0000_ooooo0_l0
0002ooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`Co000000Coooooo`000?l0003o0000
0oooool5o`0000Gooooo0_l00002ooooo`;o00000_ooool2o`0001Gooooo0_l00003ooooo`;o0000
0_ooool2o`0000?ooooo0ol00004ooooo`;o00004oooool2o`0000;ooooo1?l00006ooooo`;o0000
G_ooool001cooooo00?o0000ooooooooool0EOooool2o`0000Gooooo0_l000000ooooooo0000o`00
000;ooooo`;o00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`000003ooooool0
003o000000Sooooo1_l00005ooooo`;o00003Oooool2o`0000kooooo0_l00003ooooo`;o00002?oo
ool2o`0000Cooooo0_l000000ooooooo0000o`00000@ooooo`;o000000Coooooo`000?l0003ooooo
0_l00003ooooo`;o0000HOooool001cooooo00?o0000ooooooooool0EOooool2o`0001?ooooo1_l0
00000ooooooo0000o`000002ooooo`;o00000oooool2o`0000_ooooo1?l0000?ooooo`;o00001Ooo
ool5o`0000cooooo0_l00006ooooo`;o00000oooool2o`0000Sooooo0_l0000;ooooo`;o00001_oo
ool2o`0000Kooooo0_l0001Qooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o00003_ooool8
o`0001Wooooo0_l00007ooooo`;o00001_ooool2o`0000Oooooo0ol0000<ooooo`;o00000_ooool2
o`000004ooooool0003o0000o`0000?ooooo0_l00004ooooo`;o00000oooool2o`0000Wooooo0ol0
00000ooooooo0000o`000003o`0000?ooooo0_l0000?ooooo`;o0000EOooool001cooooo00?o0000
ooooooooool0F?ooool2o`0000cooooo1?l00004ooooo`;o00002oooool2o`000003ooooool0003o
000000oooooo0_l000000ooooooo0000o`00000Pooooo`Oo00001oooool2o`000003ooooool0003o
000000?ooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo1Ol00003
ooooo`;o00003oooool2o`0005Gooooo000Looooo`;o0000H_ooool2o`0000?ooooo0_l0000Boooo
o`?o000000?oooooo`000?l000003oooool5o`0000Oooooo0_l00003ooooo`;o00003?ooool2o`00
00Cooooo1_l000000ooooooo0000o`000005ooooo`?o00000oooool2o`0000Cooooo0_l00002oooo
o`;o0000MOooool001cooooo00?o0000ooooooooool0G?ooool2o`0000?ooooo0_l0000;ooooo`;o
00002_ooool2o`0001Cooooo0ol00004ooooo`;o00000_ooool3o`0000;ooooo0_l0000:ooooo`Ko
00001?ooool2o`0000?ooooo1?l00002ooooo`Co00000oooool2o`0000Cooooo0_l00004ooooo`;o
0000Loooool001cooooo00?o0000ooooooooool0E_ooool2o`0000Cooooo0_l0000@ooooo`;o0000
5_ooool2o`0000;ooooo0_l00003ooooo`?o00001Oooool2o`0000?ooooo0_l0000>ooooo`;o0000
0_ooool2o`0000Oooooo0_l00002ooooo`Ko00004Oooool2o`0007?ooooo000Looooo`03o`000?oo
oooooooo05Gooooo0ol00002ooooo`;o0000:_ooool2o`0000;ooooo1ol00006ooooo`;o00003?oo
ool2o`0001;ooooo0_l00004ooooo`;o00004Oooool2o`00017ooooo0_l0001Rooooo`007?ooool0
0ol0003oooooooooo`1Eooooo`;o00000oooool2o`0000cooooo1Ol00005ooooo`;o00005Oooool2
o`000004ooooool0003o0000o`0000Sooooo0_l0000<ooooo`;o0000:oooool2o`00017ooooo0_l0
001Rooooo`007?ooool00ol0003oooooooooo`1Jooooo`;o00000oooool2o`0000Oooooo1Ol00000
1?oooooo0000o`000?ooool5o`0000Oooooo0_l0000:ooooo`;o000000Coooooo`000?l0003o0000
7?ooool2o`0000Cooooo0_l0000>ooooo`;o00002?ooool2o`00013ooooo0_l0001Zooooo`007?oo
ool00ol0003oooooooooo`1Fooooo`;o00000_ooool2o`0000?ooooo0_l0000<ooooo`?o000000Co
ooooo`000?l0003ooooo1?l000000ooooooo0000o`000002ooooo`;o00002_ooool5o`00013ooooo
0_l0000;ooooo`;o00001?ooool2o`0000kooooo0_l00005ooooo`;o000000Coooooo`000?l0003o
oooo0_l00003ooooo`;o00002?ooool2o`0006[ooooo000Looooo`03o`000?oooooooooo05Kooooo
0_l000000ooooooo0000o`00000Booooo`;o00001oooool2o`000003ooooool0003o0000013ooooo
0ol0000@ooooo`;o00003oooool2o`0001Oooooo0_l00004ooooo`;o00000oooool2o`0007Cooooo
000Looooo`03o`000?oooooooooo05Sooooo0ol0000Booooo`;o000000?oooooo`000?l000001ooo
ool2o`0000Kooooo0_l00004ooooo`;o00000oooool2o`00027ooooo0_l0000Dooooo`Co00004?oo
ool2o`00013ooooo0_l000000ooooooo0000o`00001Iooooo`007?ooool00ol0003oooooooooo`0j
ooooo`;o00005_ooool2o`0000Cooooo0_l00006ooooo`Go00002_ooool3o`0000Cooooo0_l00002
ooooo`;o00001Oooool2o`0000Cooooo0_l0000;ooooo`;o00001Oooool2o`0002Sooooo1?l0000?
ooooo`?o00004?ooool2o`000003ooooool0003o000001Gooooo0_l00012ooooo`007?ooool00ol0
003oooooooooo`0jooooo`;o00005_ooool2o`0000Cooooo0_l00006ooooo`Go00001oooool5o`00
00Gooooo0_l00002ooooo`;o00000oooool6o`0000Cooooo1?l00007ooooo`;o00001Oooool2o`00
01;ooooo0_l00006ooooo`;o00000_ooool2o`0000Sooooo0_l0000Aooooo`?o0000:_ooool2o`00
04;ooooo000Looooo`03o`000?oooooooooo05Sooooo1?l0000@ooooo`Go00002Oooool2o`0000?o
oooo1_l00004ooooo`Co00001?ooool2o`0001cooooo0_l00006ooooo`;o00000_ooool2o`0001ko
oooo0_l000000ooooooo0000o`00001Yooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o0000
1oooool2o`0000;ooooo0ol000001?oooooo0000o`000?l00004ooooo`;o00002Oooool2o`0000[o
oooo0_l0000Dooooo`?o00000oooool2o`0001kooooo0_l0000@ooooo`;o00002_ooool2o`0000Co
oooo0_l000000ooooooo0000o`00000=ooooo`;o0000F_ooool001cooooo00?o0000ooooooooool0
C?ooool2o`0000Gooooo1?l00002ooooo`;o00000_ooool5o`0000;ooooo0_l0000:ooooo`;o0000
2Oooool2o`0000;ooooo0_l0000Aooooo`;o00000oooool2o`0001Kooooo0_l00002ooooo`;o0000
0oooool2o`0000Oooooo0_l00004ooooo`Co00002_ooool2o`0000;ooooo0_l00002ooooo`;o0000
2Oooool2o`0000?ooooo0_l00003ooooo`;o0000EOooool001cooooo00?o0000ooooooooool0Dooo
ool4o`000004ooooool0003o0000o`0000?ooooo1?l00006ooooo`;o00001_ooool2o`0000gooooo
0ol0000:ooooo`;o00000_ooool2o`0001Gooooo0_l00006ooooo`?o000000?oooooo`000?l00000
0oooool3o`0000Kooooo0_l00004ooooo`;o00004?ooool2o`0000;ooooo0_l00009ooooo`;o0000
0oooool4o`000003ooooool0003o000005Gooooo000Looooo`03o`000?oooooooooo05Gooooo0_l0
00000ooooooo0000o`000007ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l0
000@ooooo`;o00002?ooool4o`0000;ooooo0_l0000Eooooo`;o00001oooool2o`0000Gooooo1?l0
00000ooooooo0000o`000008ooooo`;o00001?ooool4o`0000Wooooo0_l00002ooooo`;o00001Ooo
ool2o`0000Oooooo1?l000000ooooooo0000o`00001Eooooo`007?ooool2o`00063ooooo1ol00006
ooooo`Co00002?ooool2o`000003ooooool0003o000000gooooo0_l0000Aooooo`;o00002oooool2
o`0000Gooooo0_l00003ooooo`?o00000oooool2o`000003ooooool0003o000000Gooooo0_l00003
ooooo`Go00001?ooool2o`0000?ooooo0_l00002ooooo`;o00001Oooool2o`0000Gooooo0_l0001L
ooooo`007?ooool00ol0003oooooooooo`1Jooooo`Co000000Goooooo`000?l0003o0000ooooo`03
o`0000Kooooo0_l00002ooooo`;o00001_ooool2o`000003ooooool0003o000000Gooooo0_l0000I
ooooo`;o00002oooool2o`0000Gooooo0_l00003ooooo`;o00001oooool2o`0000[ooooo0ol00006
ooooo`;o00003Oooool2o`0000Kooooo0_l0000<ooooo`;o0000C_ooool001cooooo00?o0000oooo
ooooool0B?ooool4o`0000kooooo1?l00002ooooo`;o00000_ooool2o`000003ooooool0003o0000
00Gooooo1?l0000<ooooo`;o00000_ooool2o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`00
00Sooooo1?l00004ooooo`;o00002_ooool2o`0001[ooooo0_l00002ooooo`Oo00003Oooool2o`00
00Kooooo0_l00007ooooo`Co000000?oooooo`000?l00000C_ooool001cooooo00?o0000oooooooo
ool0B?ooool4o`00017ooooo0_l00003ooooo`;o00000oooool2o`0000Gooooo1?l00005ooooo`Co
000000?oooooo`000?l000000_l00006ooooo`?o00001?ooool6o`0000Sooooo0_l00006ooooo`;o
00002_ooool2o`00013ooooo0_l0000<ooooo`Ko00002_ooool3o`0000?ooooo0_l00004ooooo`;o
000000?oooooo`000?l000000oooool5o`00057ooooo000Looooo`03o`000?oooooooooo053ooooo
0_l00009ooooo`Co00000oooool2o`0000[ooooo0_l00007ooooo`Co000000?oooooo`000?l00000
1?ooool2o`0000?ooooo0_l00006ooooo`;o00006Oooool2o`0000?ooooo0_l0000@ooooo`;o0000
0oooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o00003?ooool3o`0000?ooooo
0_l00007ooooo`;o00000_ooool6o`00057ooooo000Looooo`03o`000?oooooooooo04Gooooo0_l0
0009ooooo`;o00000oooool3o`0000;ooooo0ol00002ooooo`?o00003?ooool2o`0000Kooooo0_l0
000:ooooo`Co00001?ooool3o`0000?ooooo0_l00004ooooo`;o00002oooool2o`0000Gooooo0_l0
0003ooooo`;o00005Oooool2o`000003ooooool0003o000000;ooooo1_l0000Oooooo`Ko0000DOoo
ool001cooooo00?o0000ooooooooool0AOooool2o`0000Kooooo0_l00006ooooo`Wo000000Cooooo
o`000?l0003o00003?ooool4o`0000Cooooo0_l00009ooooo`;o000000?oooooo`000?l000001?oo
ool3o`0000?ooooo0_l00004ooooo`;o00001oooool2o`0000;ooooo0_l0000@ooooo`Co00001Ooo
ool2o`0000oooooo1?l00004ooooo`;o0000L?ooool001cooooo00?o0000ooooooooool0@_ooool2
o`0000Wooooo0_l00008ooooo`?o00000_ooool2o`0000_ooooo0_l00003ooooo`Go000000?ooooo
o`000?l000000ol00004ooooo`Ko00002Oooool2o`00017ooooo0_l0000Aooooo`Oo00001Oooool2
o`0000kooooo0_l00007ooooo`;o00003?ooool4o`0000;ooooo0_l00007ooooo`;o0000Doooool0
01cooooo00?o0000ooooooooool0@_ooool2o`00013ooooo0_l000000ooooooo0000o`000003oooo
o`;o00001oooool2o`0000;ooooo0_l00006ooooo`;o000000?oooooo`000?l000000ol000000ooo
oooo0000o`000006o`0000;ooooo0_l00006ooooo`;o00001oooool2o`0000Oooooo0_l00002oooo
o`;o00002?ooool2o`0000?ooooo2?l00008ooooo`;o00002oooool2o`0000cooooo0_l00007oooo
o`Co00000_ooool2o`0000Oooooo0_l00009ooooo`;o0000B?ooool001cooooo00?o0000oooooooo
ool0E?ooool2o`0000oooooo0_l00007ooooo`;o00001_ooool2o`0000;ooooo3_l00004ooooo`?o
00001_ooool4o`0000Gooooo0_l00002ooooo`;o00002?ooool4o`000003ooooool0003o000000Oo
000000?oooooo`000?l000001?ooool2o`0000Oooooo0_l00004ooooo`;o00001_ooool2o`0000;o
oooo0_l0000Qooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0?Oooool2o`0001;ooooo
0_l0000=ooooo`;o00002Oooool5o`0000Gooooo1?l000000ooooooo0000o`00000<o`0000Gooooo
0_l00004ooooo`Ko00001_ooool2o`0000[ooooo4ol0000:ooooo`Co00000_ooool5o`0000?ooooo
1ol0000=ooooo`;o00000_ooool3o`0005Sooooo000Looooo`03o`000?oooooooooo03gooooo0_l0
000Booooo`;o00003Oooool2o`000003ooooool0003o000000;o00001?ooool4o`0000?ooooo0_l0
00000ooooooo0000o`00000Ao`0000[ooooo1Ol00008ooooo`?o00002OoooolCo`0000Cooooo0_l0
00001?oooooo0000o`000?ooool3o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`;o0000
00?oooooo`000?l000000_l00005ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo
0ol00009ooooo`;o00001_ooool2o`0004Gooooo000Looooo`03o`000?oooooooooo03oooooo0_l0
0003ooooo`;o00005_ooool2o`0000Gooooo1?l00006ooooo`Oo000000?oooooo`000?l000004?l0
00000ooooooo0000o`000008ooooo`;o000000?oooooo`000?l000002Oooool2o`0000[ooooo5Ol0
00000ooooooo0000o`000003o`0000Cooooo0_l00002ooooo`;o00002_ooool2o`0000Gooooo0ol0
0002ooooo`;o00004Oooool2o`0000Kooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`0o
ooooo`;o00000oooool2o`0000_ooooo0_l00009ooooo`;o00001?ooool4o`0000Oooooo1ol00000
0ooooooo0000o`000006o`000003ooooool0003o000000co00002Oooool2o`000003ooooool0003o
0000017ooooo6_l00006ooooo`;o00000_ooool2o`0001;ooooo0_l0000:ooooo`;o00004_ooool2
o`0004Cooooo000Looooo`03o`000?oooooooooo04Wooooo0_l00006ooooo`;o00003oooool3o`00
00Cooooo0ol00002ooooo`;o00001OoooolDo`000003ooooool0003o000000;o000000?oooooo`00
0?l000001?ooool2o`000003ooooool0003o000000Cooooo0_l00004ooooo`;o00001?oooolDo`00
00;ooooo0ol0000Uooooo`;o00001Oooool2o`0000;ooooo0_l0000>ooooo`?o000000?oooooo`00
0?l00000@?ooool001cooooo00?o0000ooooooooool0BOooool2o`0001;ooooo0_l00004ooooo`;o
00001?ooool4o`000003ooooool0003o000000?ooooo6ol000000ooooooo0000o`000004ooooo`Co
00001Oooool2o`0000Cooooo0_l00004oooooaWo00003?ooool2o`0001?ooooo0_l00002ooooo`?o
00002?ooool3o`0000Oooooo0_l00005ooooo`;o000000?oooooo`000?l00000@?ooool001cooooo
0_l0000mooooo`;o00005Oooool2o`0000Cooooo0_l000001?oooooo0000o`000?l0000<ooooo`Go
00000ooooolKo`0000Oooooo1?l0000@oooooa[o00003?ooool3o`0000Kooooo0_l0000:ooooo`Oo
00002Oooool2o`0000Oooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`0looooo`;o0000
3_ooool2o`0000Gooooo0_l00004ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000[o
oooo1_l000000ooooooo0000o`00000Fo`0000[ooooo1?l0000:ooooo`;o00000_ooool@o`000003
ooooool0003o000000Wo00002oooool4o`0000Kooooo0_l0000<ooooo`;o00005Oooool2o`0004[o
oooo000Looooo`03o`000?oooooooooo04cooooo1?l0000;ooooo`Co000000?oooooo`000?l00000
0_l00005ooooo`;o000000?oooooo`000?l000001?l000000ooooooo0000o`00000Fo`0001Sooooo
0_l00002oooooa3o000000?oooooo`000?l000003?l00008ooooo`;o00006oooool2o`0000Sooooo
0_l00007ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0?Oooool2o`0000gooooo1?l0
00000ooooooo0000o`000008ooooo`;o00000_ooool2o`000003ooooool0003o000000?ooooo1?l0
0004ooooo`;o00000_oooolKo`0000kooooo0_l00005ooooo`;o00000ooooolNo`0000[ooooo0ol0
0006ooooo`Co00003_ooool2o`0000;ooooo0_l000000ooooooo0000o`000003o`0000Oooooo0_l0
0009ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0?Oooool2o`0000gooooo0ol00002
ooooo`;o00003?ooool2o`0000Kooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo6ol00004
ooooo`;o00002?ooool2o`0000Wooooo7ol00007ooooo`;o000000Coooooo`000?l0003o00001_oo
ool4o`0000Kooooo0_l0000:ooooo`So00002_ooool2o`0000Kooooo0_l000000ooooooo0000o`00
000kooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00001oooool3o`0000Oooooo0_l0000>
ooooo`;o000000?oooooo`000?l000001?l00004oooooaSo00000_ooool2o`0000?ooooo0_l0000?
ooooo`;o00000_ooool=o`000003ooooool0003o000000oo00001oooool2o`000003ooooool0003o
000000;o00001_ooool2o`0000Oooooo0_l0000;ooooo`;o00003?ooool2o`000004ooooool0003o
0000o`0000Sooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00001oooool3
o`0000Oooooo0_l0000>ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Cooooo3ol00000
0ooooooo0000o`000006o`000004ooooool0003o0000o`0000?ooooo0_l0000?ooooo`;o00000ooo
oolLo`0000Sooooo0_l00002ooooo`Co00002?ooool2o`0000Gooooo0_l00008ooooo`;o00001?oo
ool2o`0000?ooooo0ol000000ooooooo0000o`000002o`0000;ooooo0_l00015ooooo`007?ooool0
0ol0003oooooooooo`1Rooooo`;o00001Oooool2o`0000Sooooo6?l000001Ooooooo0000o`000?l0
003ooooo00Go00004_oooolMo`0000Sooooo0_l00002ooooo`;o000000?oooooo`000?l000000_oo
ool2o`0000?ooooo0_l00004ooooo`?o00002?ooool2o`0000Cooooo0_l00003ooooo`?o000000?o
ooooo`000?l000000_ooool2o`0004Oooooo000Looooo`03o`000?oooooooooo04Sooooo0_l00006
ooooo`;o00001?ooool3o`0000?ooooo0_l00004ooooo`;o00000_ooool3o`0000Wooooo0_l00000
0ooooooo0000o`00000Do`0000Gooooo0_l000000ooooooo0000o`000007ooooo`;o00002?oooolA
o`000003ooooool0003o000000Oo000000?oooooo`000?l000003oooool2o`000004ooooool0003o
0000o`0000Gooooo1_l0000:ooooo`;o00000oooool2o`0000Oooooo0_l000001?oooooo0000o`00
0?l00017ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00003_ooool2o`0000Kooooo0_l0
0004ooooo`So000000?oooooo`000?l000001Oooool3o`0000Wooooo0_l00002oooooaCo000000?o
ooooo`000?l000003oooool2o`0000Gooooo0_l000000ooooooo0000o`00000=o`0000?ooooo2ol0
000Booooo`Ko00000_ooool7o`0000[ooooo2Ol00005ooooo`;o000000?oooooo`000?l000005Ooo
ool2o`00037ooooo000Looooo`03o`000?oooooooooo03Gooooo0_l000000ooooooo0000o`000002
ooooo`;o00002?ooool4o`0000cooooo0_l000001?oooooo0000o`000?l00003ooooo`;o00003Ooo
ool2o`0000Kooooo5?l000000ooooooo0000o`00000Fooooo`;o00000_oooolNo`0000Kooooo0_l0
0002ooooo`;o00001?ooool6o`0000;ooooo1ol0000:ooooo`Go000000Coooooo`000?l0003o0000
2?ooool4o`0001?ooooo0_l0000aooooo`007?ooool00ol0003oooooooooo`0eooooo`;o00001Ooo
ool2o`0000Sooooo1?l0000<ooooo`Co00003Oooool2o`0000Gooooo0_l00007ooooo`Go000000?o
ooooo`000?l000001ol00004ooooo`;o00005?ooool2o`0000?ooooo8?l00006ooooo`;o00000_oo
ool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000000oooool2o`0000[ooooo0_l0
00000ooooooo0000o`00000;ooooo`;o000000?oooooo`000?l000000_l00016ooooo`007?ooool0
0ol0003oooooooooo`15ooooo`Go00003?ooool4o`0000?ooooo0_l00002ooooo`;o00001?ooool2
o`0000kooooo1Ol000000ooooooo0000o`000006o`0000Gooooo0_l0000>ooooo`;o00001?ooool2
o`0000?ooooo0_l000000ooooooo0000o`00000Eo`000004ooooool0003o0000o`0000;ooooo0_l0
0008ooooo`;o00000_ooool2o`000004ooooool0003o0000o`0000;ooooo1?l0000=ooooo`Go0000
2oooool3o`0000;ooooo0ol00015ooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00004ooo
ool2o`0001Kooooo0_l00002ooooo`;o00002?ooool2o`0000[ooooo1Ol000001?oooooo0000o`00
0?ooool2o`0000cooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l000001?oooooo
0000o`000?ooool3o`0000Gooooo5ol000000ooooooo0000o`000005o`0000Oooooo0ol00003oooo
o`Go00001?ooool2o`0000gooooo0ol00009ooooo`;o00000oooool2o`0000?ooooo0_l00015oooo
o`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooo
oooo00Cooooo00?o0000ooooooooool0<?ooool2o`0000kooooo0_l0000Eooooo`;o00000oooool4
o`000003ooooool0003o000000Sooooo0_l000000ooooooo0000o`000002ooooo`;o00001?ooool3
o`0000;ooooo0_l000000ooooooo0000o`000002o`0000[ooooo0_l00004ooooo`;o000000?ooooo
o`000?l000000_ooool4o`000004ooooool0003o0000o`0000Gooooo6_l000000ooooooo0000o`00
0002o`0000Oooooo0_l00004ooooo`?o00005_ooool2o`000003ooooool0003o000000?o00000ooo
ool2o`000003ooooool0003o000000Gooooo0_l00015ooooo`0000KoooooogMgMonHV9SooooooiRH
V?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo043ooooo
0_l00007ooooo`;o00001_ooool2o`0000Cooooo0_l00003ooooo`Co000000?oooooo`000?l00000
2oooool3o`000004ooooool0003o0000o`0000Sooooo0ol00002ooooo`;o00001?ooool2o`00017o
oooo0_l00003ooooo`;o00001_oooolLo`0000[ooooo0_l000000ooooooo0000o`00000<ooooo`;o
00002?ooool2o`0000;ooooo2?l00006ooooo`;o00005oooool2o`0003?ooooo00000ooooooo410@
ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006ooooo`03o`000?oooooooooo04Wooooo
0_l00006ooooo`;o00006oooool3o`0000;ooooo0_l00008ooooo`?o00001oooool3o`0000Kooooo
0_l000000ooooooo0000o`00000Aooooo`So000000?oooooo`000?l000004?l000000ooooooo0000
o`000009ooooo`?o000000?oooooo`000?l000002Oooool2o`000003ooooool0003o000000Co0000
1?ooool2o`0000?ooooo0ol0000:ooooo`Co000000?oooooo`000?l000001?ooool2o`0000cooooo
0_l0000cooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04odA4A?oM
gMgoooooo`0000Oooooo0ol00017ooooo`;o00002?ooool5o`0000Sooooo0_l0000>ooooo`;o0000
5oooool2o`0000Oooooo0_l000001?oooooo0000o`000?ooool2o`0000Kooooo0_l00002ooooo`;o
00000_ooool6o`0000?ooooo4_l000000ooooooo0000o`000007ooooo`Wo00001oooool3o`0000?o
oooo1_l000000ooooooo0000o`00000=ooooo`;o00000_ooool4o`000003ooooool0003o000000Co
oooo0_l00011ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgM
gOmEEEGoooooo`0000Oooooo00?o0000ooooooooool08oooool2o`0002;ooooo0ol00003ooooo`;o
00000oooool4o`0000Cooooo0_l00002ooooo`;o00002Oooool2o`000003ooooool0003o000000;o
oooo0ol00008ooooo`;o00006Oooool6o`0000;ooooo0_l00002ooooo`;o00001Oooool2o`000004
ooooool0003o0000ooooo`co000000Coooooo`000?l0003o00003?ooool2o`0000?ooooo1?l00007
ooooo`;o00002?ooool2o`000003ooooool0003o000000gooooo0_l00005ooooo`;o000000?ooooo
o`000?l00000A_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00omg
MgOoc<c<o`000007ooooo`03o`000?oooooooooo02?ooooo0_l0000Sooooo`;o00000oooool2o`00
00?ooooo0_l00006ooooo`;o00002oooool4o`000003ooooool0003o000000;ooooo0ol00008oooo
o`;o00001Oooool2o`0000cooooo0_l00006ooooo`Co00003oooool5o`000003ooooool0003o0000
00So000000Coooooo`000?l0003o00004Oooool2o`0000Sooooo0_l0000Eooooo`;o00000_ooool2
o`0000Gooooo1?l000000ooooooo0000o`000003ooooo`;o0000@Oooool00006oooooomgMgOoV9RH
oooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo03Kooooo0_l0
0007ooooo`So000000?oooooo`000?l000000oooool2o`00013ooooo0_l00006ooooo`;o00004?oo
ool2o`0000Cooooo0_l000000ooooooo0000o`000006ooooo`;o00000_ooool5o`0000oooooo0_l0
0007ooooo`_o00000oooool3o`000003ooooool0003o000000Sooooo0_l0000Aooooo`;o00001_oo
ool4o`0000Oooooo0ol000000ooooooo0000o`000002ooooo`;o00001Oooool4o`0000Kooooo0_l0
000?ooooo`;o0000<?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000
ooooo`06ooooo`03o`000?oooooooooo03Kooooo0_l00007ooooo`So000000?oooooo`000?l00000
0oooool4o`0000Cooooo0ol00003ooooo`;o00000_ooool2o`0000?ooooo0_l000000ooooooo0000
o`00000@ooooo`;o00000_ooool4o`0000Cooooo0_l000000ooooooo0000o`000002o`0000;ooooo
1Ol00009ooooo`;o00001?ooool2o`0000Gooooo0_l000001Ooooooo0000o`000?l0003ooooo00Ko
00000oooool3o`0000Wooooo1?l0000Iooooo`Co00001oooool3o`000003ooooool0003o000000;o
oooo1?l00006ooooo`Ko00004_ooool2o`00033ooooo000Looooo`03o`000?oooooooooo03?ooooo
0_l00009ooooo`Co000000?oooooo`000?l000001oooool7o`0000;ooooo0ol00003ooooo`;o0000
1?ooool2o`000004ooooool0003o0000ooooo`;o00005?ooool2o`0000?ooooo0_l000001?oooooo
0000o`000?ooool2o`0001;ooooo0_l0000;ooooo`Go00000oooool3o`0000Gooooo0_l00009oooo
o`?o00001?ooool3o`0000kooooo0_l000000ooooooo0000o`000005ooooo`?o00001_ooool2o`00
00Cooooo1?l00005ooooo`Oo0000A?ooool001cooooo00?o0000ooooooooool0<oooool2o`0000Wo
oooo0_l00009ooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo0_l00009ooooo`;o
00001?ooool2o`0000?ooooo0_l0000Dooooo`;o000000?oooooo`000?l000003?ooool3o`0000;o
oooo0_l00002ooooo`;o00000oooool2o`0000Oooooo0_l00002ooooo`Co00000_ooool2o`0000So
oooo1Ol000000ooooooo0000o`000005ooooo`Co00003Oooool2o`000003ooooool0003o000000Go
oooo1Ol00004ooooo`;o00003Oooool2o`0004Wooooo000Looooo`03o`000?oooooooooo03Gooooo
0_l00006ooooo`;o00002_ooool2o`0000_ooooo0_l00007ooooo`;o00001_ooool2o`000003oooo
ool0003o000000?o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00002Oooool2o`0000Sooooo
0ol000001?oooooo0000o`000?l00002ooooo`?o000000Coooooo`000?l0003o00000_ooool2o`00
00_ooooo1?l00002ooooo`;o00002?ooool5o`0000Kooooo0_l00002ooooo`?o00003Oooool2o`00
00Cooooo0_l00004ooooo`;o00002?ooool2o`0005Cooooo000Looooo`03o`000?oooooooooo03Go
oooo0_l00006ooooo`;o00002oooool4o`0000Kooooo1?l00007ooooo`;o00001_ooool5o`000005
ooooool0003o0000o`000?ooool00_l00003ooooo`;o00000_ooool2o`0001?ooooo1?l00006oooo
o`;o00000_ooool3o`00013ooooo0_l000000ooooooo0000o`000003ooooo`;o00001?ooool5o`00
00Kooooo0_l00003ooooo`;o00003Oooool2o`0000Cooooo0_l0000>ooooo`;o0000E?ooool001co
oooo00?o0000ooooooooool0>Oooool4o`0000gooooo1_l00004ooooo`;o000000?oooooo`000?l0
00004?ooool2o`0000?ooooo0_l0000Booooo`;o00001?ooool2o`0000Oooooo0_l0000;ooooo`;o
00004oooool2o`0000?ooooo0_l00006ooooo`Oo00000oooool2o`0001gooooo0_l0000@ooooo`;o
00000oooool2o`0004Oooooo000Looooo`03o`000?oooooooooo03Wooooo1?l00004ooooo`;o0000
2_ooool5o`000005ooooool0003o0000o`000?ooool00_l0000;ooooo`;o00002?ooool2o`0001;o
oooo0_l00004ooooo`;o00003_ooool2o`0000cooooo0_l00007ooooo`;o000000?oooooo`000?l0
00003?ooool7o`0000?ooooo0_l0000>ooooo`;o00001Oooool2o`0000Kooooo0_l0000:ooooo`;o
00001?ooool2o`0000?ooooo0_l000000ooooooo0000o`000014ooooo`007?ooool00ol0003ooooo
ooooo`0jooooo`;o00001Oooool2o`0000gooooo0_l000000ooooooo0000o`000007ooooo`;o0000
00?oooooo`000?l000000oooool2o`0000Gooooo0_l000000ooooooo0000o`00000Sooooo`;o0000
0oooool2o`0000cooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo
0_l0000Booooo`;o00003_ooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000oo
oooo0_l00004ooooo`?o000000?oooooo`000?l000000_ooool2o`0004Cooooo000Looooo`03o`00
0?oooooooooo03[ooooo1?l00006ooooo`Co00005?ooool2o`000003ooooool0003o000000?ooooo
0_l00005ooooo`;o00007oooool2o`0000?ooooo1?l00002ooooo`;o00001_ooool2o`0000Wooooo
0_l0000:ooooo`;o00003Oooool2o`0000?ooooo0_l0000;ooooo`;o00001Oooool2o`0000Cooooo
0ol00005ooooo`Co00001Oooool2o`0000Cooooo1_l00018ooooo`007?ooool00ol0003ooooooooo
o`0looooo`;o00001_ooool4o`0000Oooooo0_l000000ooooooo0000o`00000=ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0002;ooooo2_l000000ooooooo0000o`000006ooooo`;o00004_oo
ool2o`000003ooooool0003o000000?ooooo0_l00005ooooo`;o000000?oooooo`000?l000004?oo
ool2o`0000Kooooo0_l00004ooooo`?o00001?ooool4o`0000Gooooo0_l00005ooooo`Co0000BOoo
ool001cooooo00?o0000ooooooooool05?ooool2o`0002Wooooo0_l00003ooooo`;o00001?ooool2
o`0000?ooooo0_l000001?oooooo0000o`000?l0000<ooooo`Go00000_ooool2o`0001Oooooo0_l0
0002ooooo`Oo000000?oooooo`000?l000000_l00003ooooo`;o000000?oooooo`000?l000002Ooo
ool2o`0000Sooooo0_l00005ooooo`;o00001?ooool4o`0000Gooooo0_l00009ooooo`;o00004?oo
ool2o`0000Gooooo0_l000000ooooooo0000o`00000>ooooo`;o000000?oooooo`000?l000001?oo
ool3o`0000Kooooo0_l0000looooo`007?ooool00ol0003oooooooooo`0Dooooo`;o00009Oooool2
o`0000;ooooo0_l00003ooooo`;o00001?ooool3o`0000;ooooo1_l00002ooooo`;o00002_ooool2
o`0000kooooo0_l0000<ooooo`;o00000_ooool7o`0001Kooooo0ol00007ooooo`;o00001Oooool2
o`0000?ooooo0ol0000@ooooo`Co00000_ooool2o`0000cooooo0_l00008ooooo`?o00003Oooool2
o`0000;ooooo0_l00003ooooo`?o00001_ooool2o`0003cooooo000Looooo`;o0000:_ooool2o`00
013ooooo1?l0000<ooooo`;o00000oooool3o`000004ooooool0003o0000ooooo`;o00006_ooool2
o`0001?ooooo1?l0000>ooooo`;o00001oooool2o`00013ooooo0_l000001?oooooo0000o`000?l0
000>ooooo`Go00000oooool2o`0000cooooo0_l00003ooooo`;o00001?ooool2o`00013ooooo1Ol0
0009ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0:Oooool2o`0001;ooooo0_l0000A
ooooo`;o00000_ooool3o`0000Kooooo0ol0000_ooooo`;o00001oooool4o`00013ooooo0_l00007
ooooo`;o00004_ooool2o`0000oooooo0_l00008ooooo`;o00000_ooool4o`0000cooooo0_l00002
ooooo`;o000000?oooooo`000?l000000_l00007ooooo`;o0000?Oooool001cooooo00?o0000oooo
ooooool0Aoooool2o`0000;ooooo0_l00003ooooo`;o00000oooool2o`0000;ooooo0_l00002oooo
o`?o0000:_ooool2o`0000?ooooo1Ol00004ooooo`?o00002Oooool2o`0000Kooooo0_l0000Foooo
o`;o00004?ooool2o`0000;ooooo0ol0000;ooooo`Co00001?ooool3o`0000Gooooo0_l00002oooo
o`;o00000oooool2o`0004Kooooo000Looooo`03o`000?oooooooooo03;ooooo0_l0000Cooooo`;o
00000_ooool2o`0000cooooo0_l00003ooooo`;o00007Oooool2o`0000_ooooo0_l00003ooooo`Go
00001Oooool3o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000009ooooo`Co
000000?oooooo`000?l000003Oooool3o`0000Oooooo0_l00002ooooo`;o00000oooool2o`0000?o
oooo0_l0000<ooooo`;o00001Oooool3o`0001Kooooo0_l00002ooooo`;o0000>_ooool001cooooo
00?o0000ooooooooool0<_ooool2o`0000gooooo0ol00002ooooo`;o00000oooool2o`0000oooooo
0_l0000Mooooo`Co00005Oooool2o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o0000
3?ooool4o`000003ooooool0003o000000gooooo0_l00005ooooo`;o000000?oooooo`000?l00000
0_ooool2o`0000cooooo0_l0000Dooooo`;o00000_ooool4o`0000cooooo0_l00002ooooo`;o0000
>_ooool001cooooo00?o0000ooooooooool0<?ooool2o`0000oooooo0ol00002ooooo`;o00003?oo
ool2o`0000Kooooo0_l0000Fooooo`;o00001Oooool3o`0000oooooo0_l00005ooooo`;o00000_oo
ool4o`0000Wooooo0_l0000Sooooo`;o00002?ooool2o`0000Wooooo0_l0000Dooooo`;o00000_oo
ool4o`0000Cooooo0_l00005ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0<?ooool2
o`0000?ooooo0_l0000:ooooo`;o00003Oooool2o`000004ooooool0003o0000o`0000;ooooo0_l0
00000ooooooo0000o`00000@ooooo`;o00001Oooool2o`0000;ooooo0_l0000Cooooo`;o00001Ooo
ool2o`0000;ooooo0_l0000;ooooo`;o0000:Oooool3o`000003ooooool0003o000000;ooooo1?l0
0009ooooo`;o00001Oooool2o`0000_ooooo0_l00006ooooo`;o000000?oooooo`000?l000000_oo
ool3o`0003kooooo000Looooo`03o`000?oooooooooo03Gooooo0_l00007ooooo`;o00002?ooool2
o`0000Cooooo1?l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000004?ooool4
o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000001?l0000>ooooo`;o00001Oooool5
o`0000cooooo0_l00002ooooo`;o00002oooool2o`0000Gooooo1Ol0000<ooooo`?o000000Cooooo
o`000?l0003ooooo1Ol00009ooooo`;o00001?ooool3o`0001Kooooo0_l00003ooooo`;o0000?_oo
ool001cooooo00?o0000ooooooooool0?_ooool2o`0000Sooooo0_l00003ooooo`Go000000?ooooo
o`000?l000004_ooool2o`0000Cooooo1?l00004ooooo`;o00001?ooool7o`0000gooooo0_l00005
ooooo`Go00003?ooool2o`0000;ooooo0_l0000;ooooo`;o00000_ooool:o`0000Sooooo0_l00004
ooooo`Go00004_ooool2o`0000;ooooo0_l00003ooooo`;o00003oooool2o`0004;ooooo000Loooo
o`03o`000?oooooooooo037ooooo0_l0000Dooooo`?o00000oooool2o`0000?ooooo0_l0000Coooo
o`;o00003?ooool2o`0000Cooooo0_l000000ooooooo0000o`000002o`0000Oooooo0_l0000=oooo
o`;o00001?ooool2o`0001_ooooo2ol00008ooooo`;o00001?ooool5o`0000;ooooo0_l0000@oooo
o`Co00000oooool2o`0000oooooo0_l00003ooooo`;o0000?Oooool001cooooo00?o0000oooooooo
ool0<Oooool2o`0000Kooooo1?l00003ooooo`?o00001?ooool3o`0000?ooooo0_l00003ooooo`;o
00001Oooool4o`0001gooooo0ol000000ooooooo0000o`000009ooooo`;o00003_ooool2o`0000?o
oooo0ol00002ooooo`Co00002?ooool2o`0000Gooooo0_l00003ooooo`So00004Oooool<o`0000go
oooo0_l0000;ooooo`;o00002oooool5o`00013ooooo0_l0000[ooooo`007?ooool00ol0003ooooo
ooooo`0iooooo`Co00000_ooool4o`0000Gooooo0_l00002ooooo`;o00002oooool4o`0001Kooooo
0_l00005ooooo`Co00000oooool2o`0000Gooooo0ol0000>ooooo`;o000000Coooooo`000?l0003o
oooo0_l00002ooooo`Co00002?ooool2o`0000Gooooo1?l00002ooooo`Ko00001?ooool3o`0000;o
oooo0_l00003ooooo`?o00000oooool2o`000003ooooool0003o000000;ooooo0ol00005ooooo`;o
00004Oooool4o`0000_ooooo1?l00005ooooo`Co00002?ooool2o`0002_ooooo000Looooo`03o`00
0?oooooooooo01?ooooo0_l0000Zooooo`?o00001_ooool2o`0000;ooooo0_l0000Looooo`;o0000
1oooool2o`0000;ooooo0ol000000ooooooo0000o`000002o`0000;ooooo0_l00005ooooo`?o0000
1oooool2o`000003ooooool0003o000000Gooooo0_l00008ooooo`;o00001_ooool2o`0000;ooooo
0_l00004ooooo`;o00000_ooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool3o`0000;o
oooo0_l00002ooooo`_o00001?ooool2o`0000Gooooo0_l0000:ooooo`;o00001Oooool2o`0000[o
oooo0_l000000ooooooo0000o`000002o`0000Gooooo1?l0000eooooo`007?ooool00ol0003ooooo
ooooo`0Cooooo`;o0000:oooool2o`0000Kooooo0_l0000Mooooo`;o000000?oooooo`000?l00000
1_ooool2o`0000?ooooo2?l00003ooooo`?o00002_ooool2o`000003ooooool0003o000000?o0000
1Oooool2o`0000Oooooo0ol00006ooooo`;o00000_ooool2o`0000Cooooo1_l00002ooooo`;o0000
00?oooooo`000?l000001_ooool3o`000003ooooool0003o000000[o00002_ooool2o`0000[ooooo
0_l00005ooooo`;o00002_ooool2o`0000?ooooo0_l0000nooooo`007?ooool00ol0003ooooooooo
o`0`ooooo`;o00001oooool2o`0000gooooo0_l00009ooooo`;o000000?oooooo`000?l000003ooo
ool2o`0000Wooooo1?l00002ooooo`Co000000Coooooo`000?l0003o00000_ooool3o`0000Cooooo
0_l00004ooooo`;o00000oooool2o`0000Kooooo0_l00007ooooo`?o00001oooool2o`0000Oooooo
1_l00009ooooo`;o00000ooooolAo`0000;ooooo0_l0000Gooooo`;o00008oooool2o`0002[ooooo
000Looooo`03o`000?oooooooooo033ooooo0_l00007ooooo`;o00005oooool3o`000003ooooool0
003o000001Kooooo0_l00002ooooo`Co00000_ooool2o`000004ooooool0003o0000ooooo`;o0000
0_ooool3o`000003ooooool0003o000000?o00000_ooool2o`0000Oooooo0_l00003ooooo`;o0000
00?oooooo`000?l000001oooool2o`0000Cooooo1?l00002ooooo`?o00001oooool2o`0000;ooooo
0_l00004ooooo`;o00001?oooolDo`0001Oooooo0_l0000<ooooo`;o00003?ooool2o`0000Oooooo
0_l0000Zooooo`007?ooool2o`00043ooooo0_l00003ooooo`?o00002oooool3o`0000[ooooo0_l0
00000ooooooo0000o`000008ooooo`[o000000?oooooo`000?l000000_ooool4o`0000;ooooo1?l0
00000ooooooo0000o`000003o`0000;ooooo0_l00007ooooo`?o00000_ooool5o`0000Oooooo0_l0
0004ooooo`;o00001?ooool3o`0000Oooooo0_l00002ooooo`Co00000ooooolGo`0000Gooooo0_l0
000Booooo`;o00001oooool2o`0000?ooooo0_l0000:ooooo`Co0000<oooool001cooooo00?o0000
ooooooooool0??ooool2o`000003ooooool0003o000000?ooooo0ol0000:ooooo`;o00003?ooool2
o`000003ooooool0003o000000;o00000oooool2o`000003ooooool0003o000000;ooooo1_l00000
0ooooooo0000o`000002o`000003ooooool0003o000000go000000?oooooo`000?l000002Oooool2
o`0000?ooooo1?l0000Eooooo`;o00002oooool3o`0000?ooooo5_l00003ooooo`;o000000?ooooo
o`000?l000000_ooool2o`0001Oooooo1?l00006ooooo`;o00001Oooool2o`0003Gooooo000Loooo
o`03o`000?oooooooooo02Kooooo0_l0000Dooooo`;o000000?oooooo`000?l000003?ooool2o`00
00;ooooo1Ol00008ooooo`;o00000_ooool4o`0000?ooooo0_l000001Ooooooo0000o`000?l0003o
oooo00;o00000_ooool2o`0000?ooooo1Ol000001?oooooo0000o`000?l00002ooooo`co00003_oo
ool4o`0000Kooooo0_l0000;ooooo`;o00002?ooool2o`000004ooooool0003o0000o`0000;ooooo
6?l00002ooooo`;o00001Oooool2o`0000_ooooo1_l00008ooooo`;o00001_ooool2o`0003cooooo
000Looooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`;o00002?ooool2o`0000Cooooo0_l0
000<ooooo`;o000000?oooooo`000?l000000oooool4o`0000Sooooo0_l00002ooooo`?o00000_oo
ool2o`0000Cooooo5_l000000ooooooo0000o`000007o`000003ooooool0003o000000;o00000_oo
ool2o`0000?ooooo0_l00004ooooo`?o00001_ooool2o`0000Wooooo1?l00008ooooo`?o000000?o
ooooo`000?l000000_oooolHo`000003ooooool0003o0000013ooooo0_l000000ooooooo0000o`00
0004o`0001Kooooo0ol00007ooooo`;o0000;?ooool001cooooo00?o0000ooooooooool0;?ooool2
o`0000Sooooo0_l00006ooooo`;o00002_ooool2o`000003ooooool0003o000000?ooooo0_l0000>
ooooo`;o00000oooool2o`000003ooooool0003o000001So00000_ooool4o`000004ooooool0003o
0000ooooo`Co00000_ooool2o`0000?ooooo0_l00004ooooo`Co00003_ooool4o`0000;ooooo0_l0
0007ooooo`;o00001ooooolLo`0000Wooooo0_l00002ooooo`;o00001?ooool3o`0001Kooooo0ol0
0007ooooo`;o0000;?ooool001cooooo00?o0000ooooooooool0<oooool2o`0000Cooooo0_l00002
ooooo`?o00001_ooool2o`0000Gooooo0_l0000>ooooo`;o00002?oooolRo`0000;ooooo0_l00000
0ooooooo0000o`000002o`0000;ooooo0_l0000;ooooo`?o00003Oooool4o`0000;ooooo0_l0000<
ooooo`;o00000_oooolMo`0000Sooooo0_l00009ooooo`;o00000oooool2o`00013ooooo0_l0000g
ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00000oooool3o`0000;ooooo0_l00007oooo
o`;o00005Oooool2o`000003ooooool0003o000000Cooooo8ol00006ooooo`Co000000?oooooo`00
0?l000003?ooool2o`0000gooooo0_l0000Booooo`;o00000_oooolOo`0000gooooo0_l00007oooo
o`;o00003Oooool2o`000003ooooool0003o000003Oooooo000Looooo`03o`000?oooooooooo033o
oooo1?l00002ooooo`Co00001?ooool2o`0000kooooo0_l0000@ooooo`;o00001?oooolUo`000003
ooooool0003o000000Go00001oooool2o`0000Kooooo0_l0000Sooooo`ko000000?oooooo`000?l0
00004?l0000=ooooo`;o00002?ooool2o`0000cooooo0_l000000ooooooo0000o`00000gooooo`00
7?ooool00ol0003oooooooooo`0`ooooo`Co00000_ooool2o`0000Kooooo0_l000000ooooooo0000
o`00000;ooooo`;o00003_ooool2o`0000Kooooo9Ol000000ooooooo0000o`000007o`0000Gooooo
0_l00006ooooo`;o00002?ooool2o`0000Gooooo0ol0000Aooooob7o00000oooool2o`0000Sooooo
0_l000000ooooooo0000o`000005ooooo`;o00003oooool4o`0003Gooooo000Looooo`03o`000?oo
oooooooo03kooooo0_l000000ooooooo0000o`000005ooooo`;o00005?ooool2o`0000[ooooo5_l0
0002ooooo`[o000000?oooooo`000?l000001_l0000=ooooo`Ko00001?ooool2o`000003ooooool0
003o000000;ooooo0ol00006ooooo`;o00000_ooool2o`0000;ooooo6ol000000ooooooo0000o`00
0006o`0000?ooooo1?l00006ooooo`;o000000?oooooo`000?l000002oooool2o`0000_ooooo0_l0
000eooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00002?ooool2o`0000Gooooo0_l00005
ooooo`;o00003oooool5o`000003ooooool0003o000000;o000000?oooooo`000?l000003Ol00000
0ooooooo0000o`000008o`000003ooooool0003o000000Gooooo0_l0000<ooooo`Ko00001oooool2
o`0000Cooooo0_l00005ooooo`;o00000_ooool2o`0000;ooooo1?l00002oooooako00001Oooool2
o`00013ooooo0_l00003ooooo`?o00001?ooool2o`0000Cooooo0_l0000fooooo`007?ooool00ol0
003oooooooooo`0Tooooo`;o00006?ooool2o`0000oooooo0_l00005ooooo`;o00003oooool;o`00
00;ooooo3Ol000000ooooooo0000o`000008o`0000;ooooo0ol00003ooooo`;o00003?ooool2o`00
0003ooooool0003o000000Cooooo0_l00002ooooo`;o00000oooool3o`0000_ooooo0_l00005oooo
oako000000?oooooo`000?l000001?ooool2o`0000oooooo0_l00003ooooo`;o00001?ooool4o`00
00?ooooo0_l0000fooooo`007?ooool00ol0003oooooooooo`0Rooooo`Co00004oooool3o`0002Oo
oooo0_l00002ooooobGo00000_ooool3o`0000;ooooo0ol0000Eooooo`;o00000_ooool2o`0000?o
oooo0_l00002ooooo`;o00001Oooool2o`000003ooooool0003o000000Gooooo0_l000000ooooooo
0000o`00000Io`000004ooooool0003o0000o`0000?ooooo0_l000000ooooooo0000o`000002oooo
o`;o00001_ooool4o`0000Wooooo1_l00004ooooo`;o0000<oooool001cooooo00?o0000oooooooo
ool06?ooool2o`0000Sooooo0_l0000=ooooo`?o00001Oooool3o`0000;ooooo0_l00005ooooo`;o
00002?ooool2o`0001;ooooo0_l000000ooooooo0000o`00000Vo`000005ooooool0003o0000o`00
0?ooool00ol00004ooooo`;o00001oooool2o`0000Oooooo0_l0000:ooooo`;o00001?ooool3o`00
0003ooooool0003o000000Gooooo0_l000001?oooooo0000o`000?oooolHo`000004ooooool0003o
0000o`0000Kooooo1_l00006ooooo`;o00003oooool2o`0000Cooooo0_l0000cooooo`007?ooool0
0ol0003oooooooooo`0Hooooo`;o00005oooool3o`0000Kooooo0_l00002ooooo`;o00001Oooool2
o`0000Sooooo0_l0000Dooooo`Co00000_oooolSo`0000;ooooo0_l00008ooooo`;o00001oooool2
o`0000Oooooo0_l00004ooooo`;o00001oooool2o`000005ooooool0003o0000o`000?ooool01?l0
0003ooooo`;o00000ooooolFo`000003ooooool0003o000000;o00000_ooool2o`0000Kooooo1?l0
0002ooooo`;o00003oooool2o`0003gooooo000Looooo`03o`000?oooooooooo033ooooo0_l00008
ooooo`;o00001oooool2o`0000Wooooo0_l0000Eooooo`Co00000_oooolWo`0000gooooo0ol0000@
ooooo`;o00001oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000Cooooo7?l00000
0ooooooo0000o`000002o`0000Kooooo0_l00002ooooo`;o00003oooool2o`0003gooooo000Loooo
o`;o00008_ooool2o`0000gooooo0_l0000;ooooo`;o00001?ooool2o`000004ooooool0003o0000
o`0000Gooooo0_l0000:ooooo`;o00002Oooool:o`000003ooooool0003o000000Go000000?ooooo
o`000?l000006Ol000000ooooooo0000o`000009ooooo`Go00009?ooool2o`0000Gooooo5ol00002
ooooo`;o00000_ooool3o`0001[ooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0Qoooo
o`;o00004Oooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0000Cooooo0ol00000
0ooooooo0000o`00000>ooooo`;o00002Oooool2o`000003ooooool0003o000000;o000000Cooooo
o`000?l0003ooooo1ol00002ooooo`Co000000?oooooo`000?l000004ol000000ooooooo0000o`00
000<ooooo`;o00001?ooool2o`00023ooooo0_l00003ooooo`?o000000?oooooo`000?l000002ol0
0003ooooo`Oo00000_ooool2o`0000?ooooo0_l0000Fooooo`;o00002Oooool2o`0003?ooooo000L
ooooo`03o`000?oooooooooo02?ooooo0_l0000?ooooo`;o00000_ooool4o`0000Cooooo0_l00000
0ooooooo0000o`000005ooooo`;o00006Oooool2o`000003ooooool0003o000000go000000?ooooo
o`000?l000006_l00009ooooo`;o00002Oooool2o`0000Kooooo0_l0000Hooooo`;o00001?ooool2
o`000003ooooool0003o000001Go00001oooool2o`0000Sooooo0_l000000ooooooo0000o`000002
ooooo`Go00000_ooool2o`0000Kooooo1Ol0000cooooo`007?ooool00ol0003oooooooooo`0Soooo
o`;o00004oooool2o`0000Wooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00003_ooool2
o`0000Wooooo0_l000000ooooooo0000o`00000=o`000003ooooool0003o000001[o00002?ooool4
o`000003ooooool0003o000000gooooo0_l00003ooooo`Co00001oooool2o`00017ooooo0_l00000
0ooooooo0000o`000003o`0000?ooooo1Ol00005ooooo`;o00000oooool2o`000003ooooool0003o
000000Wooooo0_l000000ooooooo0000o`000002ooooo`Go00000_ooool2o`0000Kooooo0ol0000e
ooooo`007?ooool00ol0003oooooooooo`0hooooo`?o00002oooool3o`000004ooooool0003o0000
ooooo`;o00001?ooool2o`0000Gooooo0_l00005ooooo`;o00001Oooool?o`000003ooooool0003o
000001co00001_ooool4o`000003ooooool0003o000001;ooooo1?l00007ooooo`;o00005_ooool3
o`0000gooooo0_l00003ooooo`;o000000?oooooo`000?l000001?ooool2o`00057ooooo000Loooo
o`03o`000?oooooooooo01gooooo0_l0000Iooooo`?o00000_ooool2o`000003ooooool0003o0000
00_ooooo0_l00004ooooo`;o00002_ooool6o`0000?ooooo1Ol000000ooooooo0000o`00000So`00
0003ooooool0003o000000Go00002Oooool2o`0000gooooo0_l00006ooooo`;o00001?ooool2o`00
00Kooooo0_l000000ooooooo0000o`00000Iooooo`;o00003Oooool2o`0001?ooooo0_l00004oooo
o`;o0000=_ooool001cooooo00?o0000ooooooooool07Oooool2o`0001Cooooo0_l00008ooooo`;o
000000?oooooo`000?l000007Oooool2o`000003ooooool0003o000000?o000000Coooooo`000?l0
003ooooo0_l000000ooooooo0000o`00000Ro`0000;ooooo1ol00009ooooo`;o00003Oooool2o`00
00Kooooo0ol00003ooooo`;o00001_ooool2o`000003ooooool0003o000000Kooooo0_l0000Aoooo
o`;o000000?oooooo`000?l000000oooool2o`00013ooooo0_l00008ooooo`;o00001?ooool2o`00
03Kooooo000Looooo`03o`000?oooooooooo03?ooooo0_l0000?ooooo`;o00004_ooool2o`0000Oo
oooo1_l00005oooooago000000?oooooo`000?l000001_l00002ooooo`Ko00001Oooool2o`0000;o
oooo0_l0000;ooooo`;o00002?ooool4o`0000?ooooo0ol0000@ooooo`;o000000?oooooo`000?l0
00001?ooool3o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o00000oooool2o`0000Wo
oooo0ol00004ooooo`;o00002?ooool2o`0003cooooo000Looooo`03o`000?oooooooooo03Wooooo
0_l00006ooooo`;o000000?oooooo`000?l000003oooool2o`000003ooooool0003o000000Oooooo
1?l000001?oooooo0000o`000?oooolYo`0000;ooooo1?l00007ooooo`Oo00002_ooool2o`0000So
oooo0_l00006ooooo`;o00001_ooool2o`0000Oooooo0_l00002ooooo`;o00001?ooool3o`000003
ooooool0003o000000Co00001oooool2o`0000[ooooo1?l00007ooooo`;o00001?ooool3o`0000So
oooo0_l0000aooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00001?ooool3o`0000Gooooo
0_l00002ooooo`;o00003_ooool2o`000003ooooool0003o000000Kooooo0ol00003ooooo`;o0000
00?oooooo`000?l000009_l00002ooooo`Go00002Oooool2o`000003ooooool0003o000000;ooooo
0_l0000<ooooo`;o000000?oooooo`000?l000003?ooool2o`000003ooooool0003o000000Oooooo
0_l00003ooooo`;o00001oooool2o`000003ooooool0003o000000Sooooo0_l0000<ooooo`;o0000
1oooool2o`0000Gooooo0_l00008ooooo`;o0000<Oooool001cooooo00?o0000ooooooooool0<ooo
ool3o`0000Cooooo0_l00009ooooo`Co000000?oooooo`000?l000001?ooool2o`0000kooooo0ol0
0003ooooo`?o000000?oooooo`000?l000004ol000000ooooooo0000o`000003o`000003ooooool0
003o000000[o000000?oooooo`000?l000000ol00007ooooo`;o00000_ooool2o`0000?ooooo0_l0
000<ooooo`;o000000Coooooo`000?l0003o00001_ooool2o`0000?ooooo1ol00005ooooo`;o0000
00?oooooo`000?l000000_l00005ooooo`;o00002Oooool2o`0000?ooooo0_l0000Qooooo`;o0000
=Oooool001cooooo00?o0000ooooooooool0=?ooool2o`0000Cooooo0ol00002ooooo`;o00001_oo
ool2o`000003ooooool0003o000000Cooooo0_l00009ooooo`?o00001oooool4o`0000;ooooo:?l0
00000ooooooo0000o`000002o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o000000?o
ooooo`000?l000000_l00003ooooo`;o00000oooool2o`0000Cooooo1?l00006ooooo`;o00001Ooo
ool2o`000003ooooool0003o000000Gooooo1Ol00007ooooo`;o00000_ooool2o`0000Gooooo0_l0
00000ooooooo0000o`000002o`0000Wooooo0_l000000ooooooo0000o`00000Cooooo`?o0000=?oo
ool001cooooo00?o0000ooooooooool09_ooool2o`0001?ooooo0ol000001?oooooo0000o`000?l0
000Eooooo`;o00000_ooool3o`0000Oooooo0ol00003ooooobko00000oooool2o`0000Gooooo1Ol0
0005ooooo`?o00000_ooool3o`0000?ooooo0_l00009ooooo`;o00003oooool2o`0000Wooooo0_l0
0002ooooo`;o00002?ooool2o`0000_ooooo0_l000000ooooooo0000o`000002o`0000Oooooo0_l0
0009ooooo`;o0000=?ooool001cooooo00?o0000ooooooooool09_ooool2o`0000kooooo0_l00003
ooooo`?o00000_ooool2o`0000Oooooo0_l00003ooooo`;o00001oooool2o`0000?ooooo0_l00006
ooooo`Go00000oooool6o`000003ooooool0003o000001go000000?oooooo`000?l000001_l00008
ooooo`?o00002?ooool2o`0000?ooooo0_l0000=ooooo`?o00005?ooool2o`0000_ooooo0_l00005
ooooo`;o00001?ooool2o`0000[ooooo0_l00007ooooo`;o0000?oooool00006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`00
0?oooooooooo03Kooooo0_l00003ooooo`;o00003?ooool2o`000003ooooool0003o000000;o0000
2?ooool2o`0000;ooooo0_l00006ooooo`;o000000Coooooo`000?l0003ooooo1_l00003oooooaco
000000?oooooo`000?l000000ol00003ooooo`?o00002oooool2o`0000_ooooo0ol00006ooooo`;o
00001?ooool2o`0000cooooo0_l00007ooooo`?o00002_ooool2o`0000Cooooo0_l00005ooooo`;o
00001oooool2o`0000[ooooo0_l0000oooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5oooo
o`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0C?ooool3
o`0000Cooooo0_l00003ooooo`;o00002?ooool2o`0000Kooooo2?l000000ooooooo0000o`00000K
o`000003ooooool0003o000000Gooooo0_l0000<ooooo`;o00001_ooool2o`0000?ooooo0ol00006
ooooo`;o000000?oooooo`000?l000001?ooool3o`0000Sooooo0_l00008ooooo`;o00001oooool2
o`0000Oooooo0_l0000<ooooo`Co00001_ooool2o`0004?ooooo00000ooooooo410@ooooo`02oooo
o`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo027ooooo0_l0000Sooooo`?o00001?ooool2o`0000Cooooo0_l0000=ooooo`;o000000Cooooo
o`000?l0003ooooo0_l00002ooooo`Ko000000?oooooo`000?l000006ol00002ooooo`;o00006_oo
ool2o`0000cooooo0_l000000ooooooo0000o`000004ooooo`?o00000oooool2o`0000kooooo0_l0
0006ooooo`;o00001oooool2o`0000cooooo0_l00008ooooo`;o0000@oooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0
000Oooooo`Co00006Oooool2o`0000Kooooo1Ol00003ooooo`?o00005Oooool6o`0000?ooooo0ol0
00001?oooooo0000o`000?oooolGo`000003ooooool0003o000000?o000000?oooooo`000?l00000
3_ooool2o`0000Oooooo0_l000000ooooooo0000o`00000:ooooo`;o00003oooool3o`0000?ooooo
0_l00005ooooo`;o000000?oooooo`000?l000002_ooool2o`0000?ooooo0_l00005ooooo`?o0000
4?ooool2o`00047ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go
0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo01oooooo0_l0000Kooooo`;o0000
1_ooool2o`0000Kooooo0_l00004ooooo`?o00003oooool4o`0000Gooooo0ol000000ooooooo0000
o`000003o`0000;ooooo0_l00002oooooa3o000000?oooooo`000?l000000_l0000Aooooo`;o0000
1oooool2o`0000gooooo0_l0000<ooooo`;o00000_ooool3o`0000;ooooo0_l00005ooooo`;o0000
1_ooool2o`0000?ooooo1?l00003ooooo`;o00001Oooool3o`0000Wooooo0_l00005ooooo`;o0000
@Oooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7oooo
o`08ooooo`03o`000?oooooooooo04Cooooo0_l0000;ooooo`Co00002_ooool2o`000004ooooool0
003o0000o`0000Sooooo1?l00002ooooo`Oo00000_ooool:o`000003ooooool0003o000000Oo0000
0_ooool2o`0000kooooo0_l0000<ooooo`;o00001Oooool2o`0000Sooooo0_l00005ooooo`;o0000
0oooool2o`000003ooooool0003o000000Kooooo0ol00005ooooo`Co000000?oooooo`000?l00000
1?l0000:ooooo`;o00002?ooool2o`0000Oooooo0_l0000oooooo`0000KoooooogMgMonHV9Sooooo
oiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0DOooool2o`000003
ooooool0003o000000Wooooo0_l000000ooooooo0000o`000003o`0000Sooooo0_l000000ooooooo
0000o`000005o`0000?ooooo2?l00003ooooo`Ko000000Goooooo`000?l0003o0000ooooo`04o`00
0003ooooool0003o0000013ooooo0_l00005ooooo`;o00001Oooool2o`0000Sooooo0_l0000=oooo
o`;o00001oooool4o`0000?ooooo1?l00003ooooo`Co00001?ooool2o`0000Cooooo0_l00002oooo
o`;o00003Oooool2o`000003ooooool0003o000003cooooo00001_ooooook^k^oc8b<_l0003o<S8b
onk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`10ooooo`;o00003_oo
ool2o`0000;ooooo0_l0000>ooooo`?o00002Oooool6o`0000;ooooo0_l000000ooooooo0000o`00
0002ooooo`Ko000000?oooooo`000?l000001?l000000ooooooo0000o`000002o`0000?ooooo0_l0
00001?oooooo0000o`000?ooool2o`000003ooooool0003o000000;ooooo0_l00006ooooo`;o0000
3oooool2o`0000;ooooo1?l00007ooooo`;o00004?ooool2o`0000Gooooo0_l00003ooooo`;o0000
1_ooool2o`0000;ooooo0_l00004ooooo`;o00001Oooool2o`000003ooooool0003o000000?ooooo
0_l000000ooooooo0000o`00000looooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00004?oo
ool2o`0000;ooooo0_l0000:ooooo`;o00004_ooool2o`0000[ooooo0_l00002ooooo`;o00000_oo
ool5o`0000;ooooo1_l000000ooooooo0000o`00000:o`000003ooooool0003o000000;ooooo1Ol0
00000ooooooo0000o`000002ooooo`;o00001Oooool2o`0000Cooooo0_l00005ooooo`;o00000_oo
ool9o`0000Cooooo0_l000000ooooooo0000o`00000Dooooo`;o000000?oooooo`000?l000000ooo
ool2o`0000[ooooo0_l00003ooooo`Co00001?ooool2o`000003ooooool0003o000000?ooooo0_l0
000oooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00004?ooool2o`0000;ooooo0_l0000;
ooooo`;o00006?ooool2o`0000Wooooo0_l000000ooooooo0000o`000002ooooo`Co000000?ooooo
o`000?l000001Oooool9o`000003ooooool0003o000000Oo000000?oooooo`000?l000000_l00004
ooooo`;o000000?oooooo`000?l000000ol000000ooooooo0000o`000005ooooo`Ko000000Cooooo
o`000?l0003ooooo0_l00005ooooo`;o00000_ooool2o`0000Gooooo0_l0000<ooooo`;o00004_oo
ool3o`0000;ooooo1?l00004ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0:oooool2
o`0001?ooooo0_l0000;ooooo`;o00000_ooool2o`0001Sooooo0_l00002ooooo`;o00001Oooool4
o`0000?ooooo0ol00003ooooo`_o000000Coooooo`000?l0003o00000oooool4o`000004ooooool0
003o0000ooooo`Co00000_ooool5o`0000;ooooo0ol0000:ooooo`;o000000?oooooo`000?l00000
0oooool2o`0000Wooooo0_l00005ooooo`;o00008?ooool3o`0000Wooooo0_l00018ooooo`007?oo
ool00ol0003oooooooooo`0[ooooo`;o00005Oooool2o`0000Wooooo0_l0000Pooooo`;o00001ooo
ool4o`000003ooooool0003o000000Cooooo2_l00005ooooo`;o00001_ooool2o`000003ooooool0
003o000000?ooooo0ol000001?oooooo0000o`000?ooool6o`0000_ooooo0_l0000=ooooo`;o0000
7Oooool2o`0001Gooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00004Ooo
ool2o`0000?ooooo0_l00006ooooo`;o00001_ooool2o`000004ooooool0003o0000o`0000[ooooo
0ol00002ooooo`;o00001?ooool2o`0000;ooooo0ol00002ooooo`?o000000Coooooo`000?l0003o
oooo0_l00005oooooaCo00006Oooool2o`0001gooooo0_l0000Fooooo`;o0000Aoooool001cooooo
00?o0000ooooooooool0Coooool2o`0000Cooooo1?l000000ooooooo0000o`000006ooooo`;o0000
00?oooooo`000?l000000oooool2o`000004ooooool0003o0000o`0000_ooooo0_l00002ooooo`;o
00000_ooool5o`000003ooooool0003o000000?ooooo1Ol00002ooooo`;o00001?oooolAo`000003
ooooool0003o000000?o00002Oooool4o`0000Wooooo1?l0000dooooo`?o0000A_ooool001cooooo
00?o0000ooooooooool0@Oooool2o`0000cooooo0_l000000ooooooo0000o`000002ooooo`?o0000
1?ooool2o`0000Kooooo0_l0000Fooooo`;o000000Coooooo`000?l0003ooooo1Ol00006ooooo`;o
000000?oooooo`000?l000002?ooool5o`0000;ooooo4?l00009ooooo`Co00002Oooool4o`0002_o
oooo0_l00002ooooo`?o00000oooool2o`000003ooooool0003o000004?ooooo000Looooo`03o`00
0?oooooooooo03Sooooo0_l00007ooooo`;o00003_ooool3o`0000Wooooo0_l00008ooooo`;o0000
2_ooool2o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l000000_ooool4o`0000Kooooo
0_l00003ooooo`;o00001oooool6o`000003ooooool0003o000000go00001_ooool2o`0000Gooooo
0_l00007ooooo`;o00000_ooool2o`0000;ooooo0_l0000Uooooo`;o00000_ooool3o`0000Kooooo
0_l00013ooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00002_ooool3o`0001Kooooo0_l0
000@ooooo`;o00000_ooool2o`0000Wooooo0ol00002ooooo`;o00002oooool4o`000003ooooool0
003o000000?ooooo0_l00003ooooo`;o00001oooool2o`0000;ooooo2_l000000ooooooo0000o`00
0005o`0000;ooooo0ol000000ooooooo0000o`000005ooooo`;o00001?ooool2o`0000Gooooo0_l0
0002ooooo`;o00003Oooool3o`0000Cooooo0_l00004ooooo`;o00001Oooool2o`0001gooooo0_l0
000eooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00002oooool2o`0000Oooooo0_l00000
0ooooooo0000o`00000Jooooo`Co00003?ooool4o`0000gooooo0_l00002ooooo`;o000000?ooooo
o`000?l000002oooool2o`0000Cooooo0_l00002oooooaOo000000?oooooo`000?l000002oooool2
o`0000Wooooo0ol0000:ooooo`Go00001?ooool2o`0000Cooooo0_l00005ooooo`;o00003Oooool2
o`0000?ooooo0_l00009ooooo`;o0000=Oooool001cooooo00?o0000ooooooooool0<_ooool2o`00
00Gooooo0_l00007ooooo`;o000000?oooooo`000?l000002_ooool2o`0000kooooo1?l00007oooo
o`;o00000oooool4o`0000gooooo0_l0000Aooooo`?o00002?oooolFo`0000Wooooo0_l0000@oooo
o`;o00002_ooool2o`0000[ooooo0_l000000ooooooo0000o`000006ooooo`;o00003?ooool2o`00
00?ooooo0_l00010ooooo`007?ooool2o`0003?ooooo0_l00005ooooo`;o00001oooool2o`0000Wo
oooo0_l00002ooooo`;o00003Oooool2o`0000[ooooo0_l00005ooooo`;o00008?ooool2o`0000;o
oooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000001?o00002Oooool2o`0000co
oooo0_l00006ooooo`;o00002?ooool2o`0000Sooooo1?l00007ooooo`;o0000Doooool001cooooo
00?o0000ooooooooool0>oooool2o`00013ooooo0_l0000Aooooo`Co00004_ooool2o`0000_ooooo
0_l00006ooooo`;o00003?ooool2o`000003ooooool0003o000000?o000000?oooooo`000?l00000
4_l000000ooooooo0000o`00000Dooooo`;o000000?oooooo`000?l000000oooool5o`0000Gooooo
0_l0000:ooooo`;o00000_ooool2o`000003ooooool0003o000005Gooooo000Looooo`03o`000?oo
oooooooo03_ooooo0_l0000?ooooo`;o00004?ooool2o`0000;ooooo0_l00003ooooo`;o000000Co
ooooo`000?l0003ooooo0_l00007ooooo`;o00001Oooool2o`0000Cooooo0_l00006ooooo`;o0000
0oooool2o`000003ooooool0003o000000Sooooo7_l00008ooooo`;o00001Oooool2o`0000Cooooo
0_l00004ooooo`Co00005Oooool2o`000003ooooool0003o000000;o000000?oooooo`000?l00000
D?ooool001cooooo00?o0000ooooooooool0BOooool2o`000003ooooool0003o0000013ooooo0_l0
0007ooooo`;o000000Coooooo`000?l0003ooooo0_l00009ooooo`Co000000?oooooo`000?l00000
4Oooool5o`0000Sooooo7_l00006ooooo`Co00000_ooool2o`000003ooooool0003o000000cooooo
0_l0000Eooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`00001@ooooo`007?oo
ool00ol0003oooooooooo`19ooooo`;o00000oooool2o`0000?ooooo0_l00006ooooo`;o00000_oo
ool2o`0000Kooooo0_l0000:ooooo`;o00000oooool4o`000003ooooool0003o000000;o00000_oo
ool2o`0000gooooo0ol000000ooooooo0000o`000003ooooob3o00001_ooool2o`000004ooooool0
003o0000ooooo`Co00001?ooool2o`0000Oooooo0ol0000Dooooo`;o000000?oooooo`000?l00000
1?l0001Aooooo`007?ooool00ol0003oooooooooo`11ooooo`;o00000oooool2o`0000Kooooo0_l0
0002ooooo`?o00000_ooool2o`0000;ooooo0_l00002ooooo`;o00004_ooool2o`0000Cooooo0_l0
0004ooooo`;o00000_ooool2o`0000kooooo1Ol00003ooooo`?o000000?oooooo`000?l000007?l0
0007ooooo`;o00000oooool2o`0000Cooooo0_l00008ooooo`?o00002?ooool2o`0000Wooooo0_l0
0003ooooo`Co0000DOooool001cooooo00?o0000ooooooooool0??ooool2o`0000?ooooo0_l00003
ooooo`;o00002_ooool2o`0000?ooooo0_l00005ooooo`Co0000<_ooool2o`0000Kooooo0_l00000
0ooooooo0000o`000007o`000003ooooool0003o000001;o00001Oooool4o`0001;ooooo1?l00008
ooooo`;o00002Oooool2o`0000Cooooo0_l00003ooooo`;o0000COooool001cooooo00?o0000oooo
ooooool0??ooool2o`0000Cooooo0_l00003ooooo`;o00003Oooool2o`0000Kooooo1?l0000coooo
o`;o00001?ooool3o`000003ooooool0003o000001_o00001_ooool2o`0000;ooooo0_l00002oooo
o`?o00002oooool6o`0000Cooooo0_l000000ooooooo0000o`000006ooooo`;o000000?oooooo`00
0?l000000_l000000ooooooo0000o`000003ooooo`;o0000COooool001cooooo00?o0000oooooooo
ool0@_ooool2o`0000?ooooo0_l00004ooooo`;o00001?ooool2o`000003ooooool0003o000000Oo
oooo0_l00007ooooo`;o0000:oooool2o`0000?ooooo1?l000000ooooooo0000o`00000Ko`000004
ooooool0003o0000ooooo`;o00001?ooool2o`0000;ooooo0ol00007ooooo`;o00001Oooool3o`00
00Cooooo0_l000000ooooooo0000o`000004ooooo`Co000000?oooooo`000?l000000_l0001Eoooo
o`007?ooool00ol0003oooooooooo`0hooooo`;o00000oooool2o`0000gooooo0ol00004ooooo`;o
00002_ooool2o`0000Oooooo0_l00008ooooo`;o00009_ooool2o`000003ooooool0003o0000023o
000000?oooooo`000?l000002?ooool2o`000003ooooool0003o000000Gooooo0_l00005ooooo`?o
00003Oooool3o`00017ooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o0000
0oooool2o`0000gooooo0_l00002ooooo`;o00001?ooool6o`0000;ooooo0_l0000Booooo`;o0000
9oooool;o`000003ooooool0003o000001Go000000?oooooo`000?l000003?ooool2o`0000cooooo
0ol0000Aooooo`Co00003?ooool2o`0004Sooooo000Looooo`03o`000?oooooooooo04Wooooo0_l0
0004ooooo`?o00000_ooool8o`0000;ooooo0_l0000Cooooo`;o00009_ooool2o`0000;ooooo7Ol0
0003ooooo`;o00002?ooool2o`0000?ooooo0_l0000;ooooo`Co00004?ooool5o`0000_ooooo0_l0
0018ooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00001?ooool2o`0000?ooooo0_l00008
ooooo`;o000000?oooooo`000?l000003_ooool4o`0002[ooooo0ol00002ooooo`co000000?ooooo
o`000?l000002?l000001Ooooooo0000o`000?l0003ooooo00;o00001oooool2o`0000;ooooo0ol0
00001?oooooo0000o`000?l00009ooooo`?o00001Oooool2o`0000[ooooo0ol0000;ooooo`;o0000
B?ooool001cooooo00?o0000ooooooooool0E?ooool2o`0000Oooooo0_l000001?oooooo0000o`00
0?l0000>ooooo`;o0000;OoooolOo`000004ooooool0003o0000ooooo`;o00002?ooool2o`000003
ooooool0003o000000;o00000_ooool2o`0000?ooooo1Ol00005ooooo`?o00002Oooool2o`0005Ko
oooo000Looooo`03o`000?oooooooooo057ooooo0_l00005ooooo`;o00000oooool5o`0000Kooooo
0_l0000hoooooa[o00000oooool6o`0000Cooooo0_l00005ooooo`;o00001?ooool2o`0000?ooooo
0_l00003ooooo`;o00001?ooool2o`0000?ooooo0ol0000;ooooo`;o0000C_ooool001cooooo00?o
0000ooooooooool0BOooool4o`000003ooooool0003o000000?o00000oooool6o`000004ooooool0
003o0000o`0000Sooooo0_l0000Xooooo`;o00002?ooool2o`0000Cooooo2Ol000000ooooooo0000
o`000003o`000003ooooool0003o000000So00000oooool4o`0000;ooooo0_l00002ooooo`;o0000
5Oooool2o`000003ooooool0003o000000Kooooo0ol0000;ooooo`;o0000C_ooool001cooooo0_l0
001:ooooo`Wo00000oooool3o`0000;ooooo0_l000000ooooooo0000o`00000Dooooo`Co00006ooo
ool2o`0000Sooooo0_l00005ooooo`;o000000?oooooo`000?l000005_l00003ooooo`;o00000_oo
ool2o`000004ooooool0003o0000o`0000oooooo0_l00006ooooo`?o00005?ooool2o`0004kooooo
000Looooo`03o`000?oooooooooo04gooooo0_l00002ooooo`;o00000_ooool2o`0001cooooo1?l0
0002ooooo`;o00007?ooool2o`0000[ooooo7Ol000000ooooooo0000o`000005ooooo`;o00004?oo
ool2o`0000Kooooo0_l0000Booooo`;o0000DOooool001cooooo00?o0000ooooooooool0DOooool3
o`0000?ooooo0_l0000Pooooo`;o00006Oooool2o`000003ooooool0003o000000_ooooo6?l00000
1?oooooo0000o`000?l0000Nooooo`;o00004oooool2o`000003ooooool0003o0000057ooooo000L
ooooo`03o`000?oooooooooo04Kooooo0_l00005ooooo`;o00000oooool2o`0000?ooooo1?l0000i
ooooo`;o00004OoooolEo`0000;ooooo0_l00003ooooo`;o00003oooool2o`0000Sooooo0_l0000C
ooooo`;o0000E?ooool001cooooo00?o0000ooooooooool0A_ooool2o`0000Gooooo0_l0000:oooo
o`;o00006_ooool2o`000003ooooool0003o000001cooooo0_l00009ooooo`;o00001?oooolBo`00
00Gooooo0_l00003ooooo`;o00001Oooool2o`0000Cooooo0_l00002ooooo`Co00003oooool2o`00
063ooooo000Looooo`03o`000?oooooooooo06gooooo0_l00006ooooo`;o000000?oooooo`000?l0
00005_ooool2o`0000Cooooo0_l00009ooooo`;o00001Oooool?o`000003ooooool0003o000000Wo
oooo0_l00005ooooo`;o00001?ooool2o`0000Cooooo0_l0000=ooooo`Co0000H?ooool001cooooo
00?o0000ooooooooool0C_ooool2o`000003ooooool0003o000000;o00000_ooool2o`0001Cooooo
0_l00007ooooo`;o00001?ooool2o`0001;ooooo0_l0000Dooooo`Ko000000Coooooo`000?l0003o
oooo1?l000001?oooooo0000o`000?ooool4o`0001Gooooo0_l000000ooooooo0000o`000002o`00
00;ooooo0_l00009ooooo`;o00002?ooool2o`0005Sooooo000Looooo`03o`000?oooooooooo04ko
oooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00004ooooo`;o00003oooool2o`0000Ko
oooo0_l00002ooooo`Ko00005_ooool4o`0000cooooo0_l00002ooooo`;o000000?oooooo`000?l0
00001?l00002ooooo`;o00000oooool2o`0001Gooooo1ol00002ooooo`;o00003oooool2o`0000;o
oooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o00001oooool2o`0000oooooo
0_l000000ooooooo0000o`000007ooooo`Ko00005_ooool6o`0000[ooooo0ol000001?oooooo0000
o`000?l00002ooooo`;o00002Oooool4o`0000;ooooo0_l000000ooooooo0000o`000002o`0000[o
oooo1Ol0000Dooooo`Go0000F_ooool001cooooo00?o0000ooooooooool0C_ooool2o`0000Cooooo
0_l00006ooooo`;o00004oooool2o`0000Wooooo0ol0000Cooooo`;o00001_ooool2o`0000_ooooo
0_l00002ooooo`;o00000_ooool3o`0000Gooooo0_l000000ooooooo0000o`000003o`000004oooo
ool0003o0000ooooo`Go00001oooool4o`000003ooooool0003o000001Cooooo0_l000000ooooooo
0000o`00001Jooooo`007?ooool00ol0003oooooooooo`17ooooo`;o00001Oooool2o`0000cooooo
0_l00002ooooo`;o00006oooool2o`000003ooooool0003o0000013ooooo1?l00004ooooo`;o0000
2oooool2o`0000?ooooo0_l00002ooooo`;o00001Oooool4o`000004ooooool0003o0000o`0000Oo
oooo0_l00007ooooo`;o00000_ooool2o`0000gooooo0_l00007ooooo`;o00001Oooool2o`0005Go
oooo000Looooo`03o`000?oooooooooo04Oooooo0_l0000>ooooo`;o00000_ooool2o`0000?ooooo
0_l00009ooooo`?o00003?ooool2o`0000Cooooo0_l0000Aooooo`?o00004Oooool2o`0000?ooooo
0_l0000;ooooo`;o00000_ooool2o`00013ooooo0_l00002ooooo`;o00003Oooool2o`0000Cooooo
0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l00000EOooool001cooooo00?o
0000ooooooooool0D_ooool2o`0000?ooooo0_l00002ooooo`;o00002?ooool2o`0000Cooooo0ol0
0004ooooo`;o00001_ooool2o`0001;ooooo0_l00003ooooo`?o00003Oooool2o`0000Sooooo0_l0
0002ooooo`;o00000oooool2o`0000?ooooo1?l0000Nooooo`;o00002?ooool3o`0000Gooooo0_l0
001Hooooo`007?ooool00ol0003oooooooooo`1Booooo`;o00003?ooool2o`0000?ooooo0ol00008
ooooo`Co00003oooool2o`0000Wooooo0_l00004ooooo`;o00003Oooool2o`0000Kooooo1?l00002
ooooo`Oo00000oooool3o`0000Oooooo0_l0000Fooooo`;o00001Oooool2o`000003ooooool0003o
000000;o0000G_ooool001cooooo00?o0000ooooooooool0H?ooool4o`0000;ooooo0_l00008oooo
o`;o00004Oooool2o`0000gooooo0_l0000>ooooo`;o00001oooool2o`0000Gooooo1_l00003oooo
o`?o000000?oooooo`000?l000001?ooool6o`0000gooooo0_l00003ooooo`;o000000Coooooo`00
0?l0003ooooo0ol00003ooooo`;o00000_ooool2o`0005[ooooo000Looooo`03o`000?oooooooooo
06;ooooo0_l0000<ooooo`;o00004Oooool2o`0000[ooooo0_l000001?oooooo0000o`000?l00006
ooooo`?o00001?ooool2o`0000Sooooo0_l0000Aooooo`;o00001_ooool4o`0000gooooo0_l00006
ooooo`Go00002?ooool2o`0005[ooooo000Looooo`;o0000I_ooool2o`0000Wooooo0_l00004oooo
o`;o00002oooool2o`0000[ooooo0_l00002ooooo`;o00001_ooool3o`0000Oooooo1?l00003oooo
o`;o00002Oooool4o`0001Oooooo0_l00008ooooo`;o00000oooool3o`0006Gooooo000Looooo`03
o`000?oooooooooo05gooooo0_l00006ooooo`;o00003oooool2o`0000;ooooo0_l00005ooooo`?o
00001Oooool2o`0000cooooo0_l00003ooooo`;o00001?ooool2o`000003ooooool0003o000000Co
00001_ooool2o`0000Cooooo1?l0000Gooooo`;o00002?ooool2o`0000Cooooo0_l0001Uooooo`00
7?ooool00ol0003oooooooooo`1Fooooo`;o00001Oooool2o`0000Cooooo0_l0000Cooooo`Co0000
1Oooool3o`0000;ooooo0_l000000ooooooo0000o`00000<ooooo`;o00000oooool2o`0000Cooooo
0_l00005ooooo`;o00001_ooool2o`0000Gooooo0_l00009ooooo`;o00003_ooool2o`0000?ooooo
0_l0001_ooooo`007?ooool00ol0003oooooooooo`1Dooooo`Go00002_ooool2o`0001?ooooo0_l0
000<ooooo`;o0000<?ooool2o`0000Wooooo0_l00007ooooo`;o00001Oooool4o`000003ooooool0
003o000000;ooooo0_l0001[ooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o000000?ooooo
o`000?l00000:Oooool2o`0001Wooooo0_l0000;ooooo`;o00003?ooool2o`0001;ooooo1?l00005
ooooo`;o00001Oooool2o`0000;ooooo0_l00009ooooo`;o0000G?ooool001cooooo00?o0000oooo
ooooool0HOooool2o`0000Gooooo0_l00002ooooo`;o00004?ooool2o`0000;ooooo0_l000000ooo
oooo0000o`000003ooooo`;o00004Oooool2o`000003ooooool0003o000000Sooooo0ol00006oooo
o`;o00000oooool2o`0001;ooooo1?l000001?oooooo0000o`000?ooool2o`0000[ooooo0_l00009
ooooo`;o0000G?ooool001cooooo00?o0000ooooooooool0E?ooool2o`0000_ooooo0_l00005oooo
o`;o00000_ooool2o`0000Gooooo0_l00002ooooo`?o00001?ooool2o`0000?ooooo1?l00003oooo
o`;o00005?ooool2o`0000Sooooo0ol00002ooooo`;o00000_ooool2o`0001Cooooo0_l000000ooo
oooo0000o`000002o`000004ooooool0003o0000ooooo`;o00000oooool2o`000003ooooool0003o
000006_ooooo000Looooo`03o`000?oooooooooo05Cooooo0_l00006ooooo`;o000000?oooooo`00
0?l000003oooool2o`000003ooooool0003o000000;ooooo0ol00004ooooo`Co000000?oooooo`00
0?l000002Oooool2o`0001Kooooo0_l00002ooooo`;o00000oooool2o`0000gooooo0_l00009oooo
o`;o00000oooool2o`0000Oooooo1?l000000ooooooo0000o`00001[ooooo`007?ooool00ol0003o
ooooooooo`1Looooo`;o000000?oooooo`000?l000003oooool2o`0000kooooo0_l0000:ooooo`Co
00000_ooool2o`0000?ooooo0_l00009ooooo`;o00000_ooool2o`0001Kooooo0_l0000Gooooo`;o
0000L?ooool001cooooo00?o0000ooooooooool0I_ooool2o`0000;ooooo0_l0000Pooooo`;o0000
0_ooool4o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l00000
4?ooool2o`000003ooooool0003o000000Kooooo0_l00025ooooo`007?ooool00ol0003ooooooooo
o`1Pooooo`;o00001?ooool2o`0000;ooooo0_l0000;ooooo`;o00004?ooool2o`0000Gooooo0_l0
0006ooooo`Co00002Oooool2o`00013ooooo0_l000000ooooooo0000o`000003ooooo`;o000000?o
ooooo`000?l000002?ooool2o`0000kooooo0_l0001[ooooo`007?ooool00ol0003oooooooooo`1P
ooooo`Co00003_ooool2o`000003ooooool0003o000000;o00004?ooool2o`0000Gooooo0_l00006
ooooo`;o00001_ooool2o`000003ooooool0003o000000?ooooo0_l00004ooooo`;o00000_ooool4
o`0000?ooooo0_l00004ooooo`;o00002oooool2o`0000kooooo0_l00006ooooo`;o0000Hoooool0
01cooooo00?o0000ooooooooool0H_ooool2o`0000kooooo0_l000000ooooooo0000o`00000Voooo
o`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00001?ooool2o`0000;ooooo1?l00003
ooooo`;o00004_ooool4o`0000Wooooo0_l00008ooooo`;o0000Hoooool001cooooo00?o0000oooo
ooooool0F?ooool2o`0000Wooooo0_l0000:ooooo`;o0000;?ooool2o`0001Cooooo0_l00004oooo
o`;o00002Oooool2o`0000Oooooo1?l00009ooooo`;o0000KOooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oo
oooooooo05Sooooo0_l00009ooooo`;o00002_ooool2o`0001Sooooo0_l00005ooooo`Co00001ooo
ool2o`0000Wooooo0_l00004ooooo`?o00000_ooool4o`0000gooooo1?l00023ooooo`0000Kooooo
ogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Ko
oooo00?o0000ooooooooool0ROooool2o`000003ooooool0003o000000;ooooo1?l00007ooooo`;o
00002Oooool2o`0000Cooooo0ol00002ooooo`Co00003Oooool2o`0000Wooooo0_l0001jooooo`00
00?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`1/ooooo`;o00001oooool2o`000003ooooool0003o000000[o
oooo0_l00006ooooo`;o000000?oooooo`000?l000000_l00009ooooo`;o00001Oooool2o`0001Oo
oooo0_l00009ooooo`;o00001?ooool2o`0007[ooooo00000ooooooo0000ooooo`02ooooo`03o`00
0?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000K?ooool2o`0000?o
oooo0_l00002ooooo`;o000000?oooooo`000?l000002_ooool2o`0000Wooooo0_l00004ooooo`Co
00000oooool2o`0000Gooooo0_l0000Gooooo`;o00002?ooool3o`00083ooooo00000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03
o`000?oooooooooo06Wooooo0_l00006ooooo`;o00003?ooool2o`0000cooooo0_l00003ooooo`;o
000000?oooooo`000?l000000_l0000:ooooo`;o00001oooool2o`0001Sooooo0_l00021ooooo`00
00?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@
41001_ooool00ol0003oooooooooo`1Yooooo`;o00005?ooool2o`0000;ooooo0_l00008ooooo`;o
00000oooool2o`0000Wooooo0_l00005ooooo`?o00001Oooool2o`0000Gooooo0_l00004ooooo`;o
00005_ooool2o`0007Kooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj
^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo05oooooo0_l0000Rooooo`;o00006?ooool3
o`0000Cooooo0ol0000<ooooo`;o00000oooool3o`0001Kooooo0_l0001fooooo`0000Koooooonk^
k_lb<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003ooooo
ooooo`1Oooooo`;o0000;_ooool2o`0000cooooo0ol00004ooooo`;o00002Oooool2o`0000Oooooo
0_l0002?ooooo`007?ooool00ol0003oooooooooo`23ooooo`?o00002Oooool2o`0001Kooooo0_l0
00000ooooooo0000o`000002o`000003ooooool0003o000000Kooooo1?l0002>ooooo`007?ooool0
0ol0003oooooooooo`1Rooooo`;o00007oooool3o`000003ooooool0003o000001Gooooo0_l00007
ooooo`Oo000000Coooooo`000?l0003o00001Oooool4o`0008kooooo000Looooo`03o`000?oooooo
oooo06;ooooo0_l00004ooooo`;o00007Oooool2o`0001Cooooo0ol00003ooooo`;o00000oooool2
o`0000Kooooo0_l0002Gooooo`007?ooool00ol0003oooooooooo`1Xooooo`;o0000<oooool3o`00
00?ooooo0_l0002Tooooo`007?ooool00ol0003oooooooooo`2Hooooo`;o00003oooool2o`0000;o
oooo0_l0002Jooooo`007?ooool00ol0003oooooooooo`2Eooooo`;o000000?oooooo`000?l00000
3oooool2o`0000;ooooo0_l0002Jooooo`007?ooool00ol0003oooooooooo`2Eooooo`;o00009ooo
ool2o`0000Gooooo0_l00022ooooo`007?ooool00ol0003oooooooooo`2nooooo`;o00001Oooool2
o`0008;ooooo000Looooo`03o`000?oooooooooo073ooooo0_l0000fooooo`;o00005?ooool2o`00
08Wooooo000Looooo`03o`000?oooooooooo073ooooo0_l0000_ooooo`;o00001?ooool3o`0009oo
oooo000Looooo`03o`000?oooooooooo07oooooo0_l0000Pooooo`;o00001?ooool2o`0000;ooooo
0_l0002Looooo`007?ooool2o`00083ooooo0_l0000Fooooo`;o00001_ooool2o`0000[ooooo0_l0
002Looooo`007?ooool00ol0003oooooooooo`2Gooooo`;o00001_ooool2o`000:Sooooo000Loooo
o`03o`000?oooooooooo0:Gooooo0_l0002Rooooo`007?ooool00ol0003oooooooooo`2:ooooo`;o
00003_ooool2o`0000Wooooo0_l0002Rooooo`007?ooool00ol0003oooooooooo`1aooooo`;o0000
5oooool2o`0000kooooo0_l0002]ooooo`007?ooool00ol0003oooooooooo`1aooooo`;o00008_oo
ool2o`0001?ooooo0_l0002Mooooo`007?ooool00ol0003oooooooooo`20ooooo`;o00004oooool2
o`0001?ooooo0_l0002Mooooo`007?ooool00ol0003oooooooooo`20ooooo`;o00007_ooool2o`00
0:Oooooo000Looooo`03o`000?oooooooooo0:3ooooo0_l0002Wooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0;cooooo0_l0002;ooooo`007?ooool0
0ol0003oooooooooo`2looooo`;o0000Roooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Zooooo`;o
0000WOooool001cooooo00?o0000ooooooooool0Z_ooool2o`0009gooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Booooo`Co000000?o410@ooooooooool00oooool0
0ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`?o0000oooooom:ooooo`00
5?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_oo
ool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooo
oe;ooooo000Booooo`03oeEEEOmVIVKo00000?ooooooE?ooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00:7ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0F
ooooo`Co000000?o410@ooooooooool01Ol00005ooooo`03o`000?o^k^kooooo00?ooooo00Goc<c<
ob4Q8Ol0003o8B4Qolc<c02<ooooo`00X_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l0
000<ooooo`03o`000?oooooooooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03oeEE
EOnYZJWooooo00?ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@2<ooooo`00X_ooool01Ol0003ooooo
oooooooooooo000001_ooooo00?o0000ooooooooool00oooool00onHV9So8B4Qonk^kP06ooooo`03
ojVYZOmEEEGooooo00?ooooo00Go0000ooooooooooooooooo`00002<ooooo`00X_ooool01Ol0003o
oooooooooooooooo000000Wooooo1_l0000<ooooo`03o`000?oooooooooo00Cooooo00?oV9RHob4Q
8Oo^k^h01_ooool00olQ8B7oooooooooo`02ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80S?ooool0
0:;ooooo00Go0000ohN7QoooooooZJVYo`00000Kooooo`03o`000?oooooooooo00Gooooo00?oMgMg
ofIVI_ooool01Oooool00omEEEGoc<c<ooooo`02ooooo`05olc<c?l0003o0000o`000?o<c<`0S?oo
ool00:7ooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Iooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01?ooool00onYZJWoMgMgooooo`02ooooo`05oa0@4?nj^[[o
oooookZj^_l@4100S?ooool00<;ooooo00?o0000ooooooooool00_ooool01Ol0003o^[ZjoooooonH
V9So410@00?ooooo00Go410@oooooooooooooooooc8b<P03ooooo`05o`000?nj^[[ooooookZj^_l0
0000S?ooool00<3ooooo00?oEEEEofIVI_l000001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00?o
oooo1Ol00003ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0S?ooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1284) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.5077 .64234 Mdot
.49749 .65798 Mdot
.58608 .36306 Mdot
.42135 .5499 Mdot
.69286 .27695 Mdot
.58244 .39501 Mdot
.69602 .57234 Mdot
.63868 .53797 Mdot
.60555 .36564 Mdot
.72478 .61275 Mdot
.65407 .56319 Mdot
.44015 .61679 Mdot
.65999 .53766 Mdot
.39007 .55649 Mdot
.65765 .18722 Mdot
.4242 .5939 Mdot
.50125 .64691 Mdot
.39346 .3587 Mdot
.44278 .52909 Mdot
.56288 .35811 Mdot
.5446 .65358 Mdot
.39381 .54975 Mdot
.51708 .71746 Mdot
.38946 .55686 Mdot
.41606 .52331 Mdot
.536 .70341 Mdot
.47688 .62466 Mdot
.39095 .50826 Mdot
.37065 .49782 Mdot
.63803 .54393 Mdot
.30634 .38158 Mdot
.65938 .21263 Mdot
.33111 .48929 Mdot
.41969 .21427 Mdot
.65977 .52044 Mdot
.37721 .73367 Mdot
.58658 .38293 Mdot
.67384 .55721 Mdot
.6784 .5607 Mdot
.66961 .51688 Mdot
.66164 .55807 Mdot
.51908 .70952 Mdot
.60348 .61705 Mdot
.60221 .31137 Mdot
.40095 .59181 Mdot
.77386 .40351 Mdot
.45959 .80139 Mdot
.35268 .54955 Mdot
.52094 .65761 Mdot
.49278 .25121 Mdot
.70768 .39203 Mdot
.6889 .54163 Mdot
.56833 .35037 Mdot
.13571 .61976 Mdot
.67606 .5376 Mdot
.41934 .48124 Mdot
.58769 .37267 Mdot
.38227 .54123 Mdot
.38482 .5576 Mdot
.2997 .62606 Mdot
.37401 .57781 Mdot
.41916 .3605 Mdot
.4828 .70313 Mdot
.57946 .55054 Mdot
.60243 .37344 Mdot
.67337 .56902 Mdot
.49907 .67195 Mdot
.66255 .532 Mdot
.46537 .52844 Mdot
.54646 .37421 Mdot
.35066 .54842 Mdot
.66107 .56554 Mdot
.47652 .64634 Mdot
.36317 .51193 Mdot
.50263 .33589 Mdot
.82963 .51026 Mdot
.4011 .30442 Mdot
.35961 .70593 Mdot
.28669 .62072 Mdot
.53413 .27342 Mdot
.43471 .53028 Mdot
.34989 .41058 Mdot
.8155 .47627 Mdot
.53539 .72329 Mdot
.38875 .60296 Mdot
.39212 .28007 Mdot
.36693 .51278 Mdot
.79337 .39579 Mdot
.33684 .53032 Mdot
.44279 .28207 Mdot
.61382 .36834 Mdot
.5162 .67303 Mdot
.4239 .54932 Mdot
.35532 .51096 Mdot
.25335 .57464 Mdot
.38535 .479 Mdot
.39829 .53288 Mdot
.53655 .67009 Mdot
.687 .54003 Mdot
.36403 .47442 Mdot
.61686 .31878 Mdot
.62162 .36419 Mdot
.42381 .57442 Mdot
.60265 .41226 Mdot
.48113 .68911 Mdot
.35479 .51427 Mdot
.68214 .55626 Mdot
.40682 .57719 Mdot
.62564 .74976 Mdot
.49207 .65667 Mdot
.38312 .50306 Mdot
.44846 .33845 Mdot
.23378 .63357 Mdot
.51779 .66465 Mdot
.63855 .32563 Mdot
.41281 .49875 Mdot
.38771 .52842 Mdot
.50105 .66075 Mdot
.6206 .40481 Mdot
.80163 .41177 Mdot
.54824 .69525 Mdot
.64135 .5177 Mdot
.49698 .63777 Mdot
.45326 .59109 Mdot
.60753 .38449 Mdot
.66884 .33015 Mdot
.61805 .713 Mdot
.32798 .35437 Mdot
.36717 .51601 Mdot
.65353 .63397 Mdot
.61091 .34776 Mdot
.51244 .68143 Mdot
.65639 .53203 Mdot
.35067 .58472 Mdot
.48995 .68265 Mdot
.6456 .56026 Mdot
.44824 .3496 Mdot
.70192 .45035 Mdot
.48582 .69048 Mdot
.47942 .41687 Mdot
.67399 .58159 Mdot
.68495 .52908 Mdot
.33051 .2431 Mdot
.50203 .67392 Mdot
.42483 .35127 Mdot
.648 .53063 Mdot
.31408 .342 Mdot
.39948 .58937 Mdot
.30732 .42931 Mdot
.46566 .81794 Mdot
.39875 .21926 Mdot
.72675 .46855 Mdot
.41443 .32577 Mdot
.63041 .54682 Mdot
.41262 .53082 Mdot
.53814 .69217 Mdot
.52918 .71388 Mdot
.37977 .57903 Mdot
.42747 .53268 Mdot
.34566 .54227 Mdot
.34548 .51891 Mdot
.39784 .63645 Mdot
.41595 .49436 Mdot
.3879 .78595 Mdot
.51999 .67456 Mdot
.41806 .54232 Mdot
.56037 .39924 Mdot
.33159 .50387 Mdot
.66165 .56221 Mdot
.38918 .54215 Mdot
.42231 .54782 Mdot
.38912 .58434 Mdot
.68675 .53638 Mdot
.71037 .24542 Mdot
.25868 .66681 Mdot
.67461 .23802 Mdot
.47983 .33406 Mdot
.57853 .41014 Mdot
.3777 .5144 Mdot
.43701 .35591 Mdot
.42342 .728 Mdot
.41488 .56303 Mdot
.47946 .87227 Mdot
.39891 .53988 Mdot
.69484 .26735 Mdot
.42591 .47859 Mdot
.5865 .19388 Mdot
.33686 .40548 Mdot
.40554 .51946 Mdot
.57462 .59668 Mdot
.63072 .49749 Mdot
.6165 .42454 Mdot
.66119 .55418 Mdot
.55854 .39548 Mdot
.58468 .36661 Mdot
.59372 .57987 Mdot
.41124 .61848 Mdot
.35054 .46827 Mdot
.34004 .51278 Mdot
.54103 .38412 Mdot
.49525 .71889 Mdot
.44409 .3661 Mdot
.53232 .65303 Mdot
.84198 .38366 Mdot
.73435 .37682 Mdot
.7028 .57983 Mdot
.41097 .36414 Mdot
.60437 .35376 Mdot
.61964 .38585 Mdot
.43878 .32579 Mdot
.36248 .54277 Mdot
.50353 .68251 Mdot
.37695 .20761 Mdot
.66858 .73232 Mdot
.30202 .24347 Mdot
.53469 .66959 Mdot
.70409 .64082 Mdot
.64386 .55207 Mdot
.57133 .38181 Mdot
.3909 .52921 Mdot
.36435 .53658 Mdot
.55979 .69506 Mdot
.34578 .5397 Mdot
.53023 .62479 Mdot
.39559 .52302 Mdot
.67761 .41724 Mdot
.38456 .31556 Mdot
.5933 .57688 Mdot
.3458 .33232 Mdot
.53935 .71524 Mdot
.22746 .48122 Mdot
.60901 .4062 Mdot
.41357 .72025 Mdot
.67038 .57223 Mdot
.43941 .36141 Mdot
.611 .39515 Mdot
.45226 .3545 Mdot
.43033 .50503 Mdot
.55388 .38353 Mdot
.42948 .31796 Mdot
.28275 .53576 Mdot
.36657 .58214 Mdot
.5754 .77346 Mdot
.66026 .5163 Mdot
.54338 .66286 Mdot
.36625 .5739 Mdot
.58249 .41423 Mdot
.32284 .54882 Mdot
.76627 .51086 Mdot
.67333 .38111 Mdot
.62347 .36095 Mdot
.66368 .39774 Mdot
.4208 .36343 Mdot
.75877 .44799 Mdot
.68075 .64403 Mdot
.50603 .6464 Mdot
.39077 .48091 Mdot
.56105 .181 Mdot
.64874 .53023 Mdot
.39335 .57575 Mdot
.49838 .21577 Mdot
.66408 .52626 Mdot
.38033 .53958 Mdot
.63469 .54581 Mdot
.52787 .71452 Mdot
.23752 .59761 Mdot
.50967 .64948 Mdot
.34261 .51604 Mdot
.68305 .55059 Mdot
.57638 .41798 Mdot
.53378 .69813 Mdot
.36236 .54961 Mdot
.38759 .50988 Mdot
.60081 .48628 Mdot
.41136 .54003 Mdot
.70984 .25644 Mdot
.4006 .52072 Mdot
.57054 .37144 Mdot
.43987 .56418 Mdot
.19795 .6456 Mdot
.61152 .59751 Mdot
.50013 .67414 Mdot
.62765 .39594 Mdot
.59872 .36609 Mdot
.59697 .30549 Mdot
.70675 .54289 Mdot
.42195 .50414 Mdot
.58258 .41251 Mdot
.25218 .48357 Mdot
.66478 .57699 Mdot
.34537 .48186 Mdot
.48846 .4385 Mdot
.4787 .2569 Mdot
.57136 .34912 Mdot
.31143 .516 Mdot
.48624 .69579 Mdot
.42642 .5462 Mdot
.62043 .3927 Mdot
.35921 .60808 Mdot
.40352 .50041 Mdot
.56914 .71517 Mdot
.6049 .48602 Mdot
.68909 .57839 Mdot
.40975 .46973 Mdot
.38159 .57265 Mdot
.56184 .39432 Mdot
.54163 .70774 Mdot
.66287 .57737 Mdot
.52613 .70818 Mdot
.54023 .19087 Mdot
.58738 .76441 Mdot
.28639 .56235 Mdot
.41787 .37125 Mdot
.46606 .23802 Mdot
.55498 .18726 Mdot
.19974 .4738 Mdot
.24105 .43804 Mdot
.44578 .1894 Mdot
.61221 .41231 Mdot
.49898 .22265 Mdot
.59224 .36782 Mdot
.42182 .51938 Mdot
.60598 .3834 Mdot
.54679 .17992 Mdot
.3965 .52495 Mdot
.59898 .38629 Mdot
.22711 .51415 Mdot
.42396 .5413 Mdot
.50248 .65109 Mdot
.78712 .33371 Mdot
.18241 .54852 Mdot
.67386 .39481 Mdot
.56759 .3605 Mdot
.25967 .386 Mdot
.40079 .53301 Mdot
.44056 .55847 Mdot
.53078 .67709 Mdot
.31753 .51005 Mdot
.40382 .34559 Mdot
.40479 .35788 Mdot
.72367 .53075 Mdot
.38495 .42291 Mdot
.42234 .47814 Mdot
.53351 .69298 Mdot
.42961 .64509 Mdot
.49102 .32002 Mdot
.49569 .24545 Mdot
.66244 .58514 Mdot
.78295 .33093 Mdot
.50483 .61136 Mdot
.61724 .55544 Mdot
.62627 .42497 Mdot
.50941 .65834 Mdot
.69471 .23185 Mdot
.6647 .55283 Mdot
.57446 .79296 Mdot
.49456 .50836 Mdot
.36541 .54421 Mdot
.68281 .57549 Mdot
.34458 .58894 Mdot
.17815 .53167 Mdot
.63553 .78641 Mdot
.45413 .45548 Mdot
.33555 .52946 Mdot
.49686 .35111 Mdot
.38908 .53664 Mdot
.79565 .47869 Mdot
.39892 .51672 Mdot
.52671 .7038 Mdot
.73349 .59954 Mdot
.69537 .5106 Mdot
.2951 .72952 Mdot
.77314 .46518 Mdot
.4132 .32589 Mdot
.39074 .52361 Mdot
.36656 .54683 Mdot
.40407 .33798 Mdot
.50679 .71635 Mdot
.34084 .52569 Mdot
.22537 .46706 Mdot
.35259 .5203 Mdot
.66741 .56056 Mdot
.48717 .52664 Mdot
.55011 .7532 Mdot
.35613 .49586 Mdot
.47275 .66934 Mdot
.70092 .57406 Mdot
.67979 .54719 Mdot
.43987 .49325 Mdot
.66473 .51393 Mdot
.40349 .5464 Mdot
.66146 .7801 Mdot
.48223 .67957 Mdot
.56993 .6444 Mdot
.50089 .69623 Mdot
.34356 .69643 Mdot
.67512 .52894 Mdot
.69447 .40855 Mdot
.39159 .61055 Mdot
.66365 .54875 Mdot
.5342 .76297 Mdot
.42762 .58877 Mdot
.36829 .58735 Mdot
.32936 .26629 Mdot
.57579 .35932 Mdot
.60534 .49256 Mdot
.63704 .541 Mdot
.36803 .56134 Mdot
.38092 .4854 Mdot
.70254 .56989 Mdot
.66584 .75864 Mdot
.20319 .54254 Mdot
.39851 .52229 Mdot
.52349 .69387 Mdot
.51329 .68653 Mdot
.34342 .56081 Mdot
.42994 .56458 Mdot
.60266 .39591 Mdot
.58915 .42215 Mdot
.54894 .38159 Mdot
.61034 .48624 Mdot
.69037 .40657 Mdot
.70687 .31865 Mdot
.67046 .51713 Mdot
.67602 .66933 Mdot
.4317 .27747 Mdot
.34612 .49831 Mdot
.58608 .34882 Mdot
.38776 .57161 Mdot
.41088 .55213 Mdot
.7082 .5679 Mdot
.60351 .24651 Mdot
.52057 .63006 Mdot
.51648 .7247 Mdot
.65465 .5771 Mdot
.46466 .58521 Mdot
.64447 .59765 Mdot
.44483 .35033 Mdot
.36409 .24211 Mdot
.66733 .56957 Mdot
.50299 .65269 Mdot
.64924 .51948 Mdot
.35949 .53064 Mdot
.44347 .51658 Mdot
.50706 .66311 Mdot
.39892 .32618 Mdot
.32093 .53921 Mdot
.38018 .5363 Mdot
.44091 .82552 Mdot
.34539 .2745 Mdot
.66644 .43639 Mdot
.40456 .52092 Mdot
.36689 .49121 Mdot
.43351 .31362 Mdot
.35323 .52336 Mdot
.35001 .55551 Mdot
.24459 .637 Mdot
.6305 .7144 Mdot
.3976 .35332 Mdot
.67405 .76474 Mdot
.5313 .66517 Mdot
.61024 .19414 Mdot
.56549 .38688 Mdot
.72857 .5721 Mdot
.20777 .57297 Mdot
.56369 .35298 Mdot
.72924 .47447 Mdot
.63646 .20705 Mdot
.61401 .49069 Mdot
.5346 .40686 Mdot
.48564 .61613 Mdot
.34321 .5237 Mdot
.38446 .53016 Mdot
.42844 .35898 Mdot
.50615 .68986 Mdot
.58694 .49913 Mdot
.79778 .62595 Mdot
.3949 .54644 Mdot
.54879 .62616 Mdot
.75593 .64746 Mdot
.48071 .26103 Mdot
.43098 .33629 Mdot
.3958 .34137 Mdot
.38762 .524 Mdot
.23881 .65247 Mdot
.53643 .70131 Mdot
.36334 .55115 Mdot
.40723 .49011 Mdot
.56929 .36179 Mdot
.48522 .66034 Mdot
.62349 .39841 Mdot
.71391 .40977 Mdot
.67947 .24672 Mdot
.47839 .84348 Mdot
.67809 .53567 Mdot
.80052 .53283 Mdot
.63935 .55875 Mdot
.35768 .40525 Mdot
.61258 .34316 Mdot
.42864 .55412 Mdot
.53873 .71377 Mdot
.37423 .56568 Mdot
.43107 .5601 Mdot
.3639 .54507 Mdot
.36125 .48803 Mdot
.3783 .83735 Mdot
.42191 .31947 Mdot
.44075 .5949 Mdot
.57498 .36738 Mdot
.80253 .43881 Mdot
.82359 .51429 Mdot
.3706 .55025 Mdot
.38935 .51453 Mdot
.4881 .68879 Mdot
.38319 .57845 Mdot
.64602 .56586 Mdot
.54673 .67863 Mdot
.36197 .50718 Mdot
.79865 .36139 Mdot
.37688 .499 Mdot
.62408 .2111 Mdot
.64347 .52376 Mdot
.63441 .74966 Mdot
.45047 .5863 Mdot
.67025 .40174 Mdot
.6051 .49261 Mdot
.60773 .39533 Mdot
.6376 .51526 Mdot
.58947 .38279 Mdot
.78337 .65758 Mdot
.44885 .52138 Mdot
.41441 .52934 Mdot
.35904 .48241 Mdot
.57709 .41004 Mdot
.77901 .37226 Mdot
.75672 .42617 Mdot
.44893 .59694 Mdot
.57983 .40689 Mdot
.47925 .69207 Mdot
.31933 .30794 Mdot
.50813 .70591 Mdot
.4456 .37126 Mdot
.65127 .55769 Mdot
.39835 .33382 Mdot
.48573 .20888 Mdot
.4951 .65626 Mdot
.54021 .65362 Mdot
.56952 .38841 Mdot
.50297 .50764 Mdot
.14417 .42882 Mdot
.49751 .51192 Mdot
.33597 .38275 Mdot
.52995 .6816 Mdot
.36518 .49706 Mdot
.38769 .39965 Mdot
.52138 .54219 Mdot
.59224 .38127 Mdot
.40841 .56128 Mdot
.23295 .59122 Mdot
.60277 .39604 Mdot
.36431 .47784 Mdot
.57682 .36261 Mdot
.65552 .5545 Mdot
.59588 .3488 Mdot
.5529 .72225 Mdot
.37336 .50795 Mdot
.16996 .36617 Mdot
.37787 .32187 Mdot
.4041 .53069 Mdot
.65465 .57817 Mdot
.72807 .50927 Mdot
.41602 .57059 Mdot
.45157 .33678 Mdot
.59309 .39608 Mdot
.48436 .4775 Mdot
.39869 .52001 Mdot
.57408 .40672 Mdot
.50654 .64143 Mdot
.62892 .52974 Mdot
.26775 .59293 Mdot
.65961 .42622 Mdot
.53142 .67625 Mdot
.48502 .38815 Mdot
.65913 .50897 Mdot
.36612 .49094 Mdot
.38783 .48079 Mdot
.52032 .6936 Mdot
.27832 .48796 Mdot
.42729 .57716 Mdot
.43472 .5323 Mdot
.56533 .37275 Mdot
.59075 .38652 Mdot
.24923 .5402 Mdot
.60708 .41816 Mdot
.44494 .5192 Mdot
.52061 .69646 Mdot
.42313 .55201 Mdot
.48304 .67527 Mdot
.38666 .57859 Mdot
.40671 .62364 Mdot
.50877 .71755 Mdot
.61362 .587 Mdot
.4109 .55761 Mdot
.34277 .47357 Mdot
.40412 .57616 Mdot
.34478 .52839 Mdot
.60851 .38905 Mdot
.43922 .34167 Mdot
.40355 .48127 Mdot
.4566 .32837 Mdot
.45088 .35614 Mdot
.66593 .49911 Mdot
.57207 .35991 Mdot
.41584 .34631 Mdot
.76233 .64824 Mdot
.55148 .3778 Mdot
.41447 .35568 Mdot
.82289 .51124 Mdot
.66431 .52117 Mdot
.48317 .68744 Mdot
.42497 .5393 Mdot
.49174 .19787 Mdot
.45981 .8037 Mdot
.5882 .42789 Mdot
.40168 .52314 Mdot
.39791 .57404 Mdot
.54556 .70997 Mdot
.79652 .66331 Mdot
.5465 .37512 Mdot
.3947 .49827 Mdot
.49489 .66698 Mdot
.77896 .70914 Mdot
.5764 .37132 Mdot
.41918 .35837 Mdot
.67421 .52149 Mdot
.56071 .72665 Mdot
.61667 .71431 Mdot
.69366 .57593 Mdot
.5989 .44165 Mdot
.70387 .3952 Mdot
.41196 .49765 Mdot
.5914 .34633 Mdot
.30627 .25695 Mdot
.45418 .67357 Mdot
.59026 .55019 Mdot
.26392 .37471 Mdot
.5125 .66085 Mdot
.64205 .5617 Mdot
.4169 .3226 Mdot
.53722 .67477 Mdot
.4988 .64879 Mdot
.70329 .55873 Mdot
.27134 .66425 Mdot
.48813 .44068 Mdot
.67441 .56195 Mdot
.37561 .26176 Mdot
.6595 .29105 Mdot
.58403 .34908 Mdot
.40423 .34554 Mdot
.50646 .20837 Mdot
.52114 .71031 Mdot
.77748 .31824 Mdot
.33442 .25376 Mdot
.39839 .53309 Mdot
.41963 .34514 Mdot
.756 .34931 Mdot
.82262 .59902 Mdot
.66838 .52792 Mdot
.69693 .50733 Mdot
.40444 .35124 Mdot
.36833 .57441 Mdot
.31445 .32363 Mdot
.4333 .53298 Mdot
.64708 .55384 Mdot
.29081 .60763 Mdot
.49847 .65097 Mdot
.69677 .53932 Mdot
.36075 .24178 Mdot
.40216 .54755 Mdot
.41198 .55893 Mdot
.35616 .32891 Mdot
.54429 .69168 Mdot
.60735 .39601 Mdot
.41126 .49496 Mdot
.38385 .53842 Mdot
.42258 .48841 Mdot
.39602 .46617 Mdot
.23236 .61926 Mdot
.41142 .51293 Mdot
.76131 .40858 Mdot
.33451 .52679 Mdot
.40178 .55831 Mdot
.47426 .67348 Mdot
.47411 .84959 Mdot
.72336 .40585 Mdot
.38757 .54033 Mdot
.37322 .49431 Mdot
.69318 .53312 Mdot
.50575 .48609 Mdot
.49977 .49366 Mdot
.48081 .46942 Mdot
.25039 .41221 Mdot
.34068 .56178 Mdot
.49912 .68009 Mdot
.4337 .31879 Mdot
.40134 .4973 Mdot
.49684 .67559 Mdot
.40076 .58742 Mdot
.60053 .3986 Mdot
.55142 .37976 Mdot
.45322 .65873 Mdot
.41215 .34079 Mdot
.51126 .58817 Mdot
.66714 .67132 Mdot
.55725 .39125 Mdot
.41595 .52789 Mdot
.70979 .57771 Mdot
.62006 .39153 Mdot
.66402 .37136 Mdot
.28921 .5032 Mdot
.53988 .69875 Mdot
.51791 .67202 Mdot
.30432 .43386 Mdot
.72445 .45593 Mdot
.34418 .78394 Mdot
.65447 .55505 Mdot
.45007 .54968 Mdot
.67507 .63358 Mdot
.51849 .66897 Mdot
.37547 .39751 Mdot
.4162 .34338 Mdot
.66246 .52521 Mdot
.52079 .40195 Mdot
.48963 .687 Mdot
.493 .64639 Mdot
.3376 .54231 Mdot
.3741 .53931 Mdot
.23882 .4495 Mdot
.46289 .37042 Mdot
.69402 .57784 Mdot
.40627 .35001 Mdot
.61147 .34314 Mdot
.4065 .50685 Mdot
.51777 .71886 Mdot
.65682 .29681 Mdot
.39363 .49569 Mdot
.61504 .3788 Mdot
.51281 .66537 Mdot
.41791 .36273 Mdot
.4533 .33666 Mdot
.34642 .52512 Mdot
.37143 .63996 Mdot
.6725 .55221 Mdot
.50865 .65416 Mdot
.6335 .59276 Mdot
.43839 .56009 Mdot
.37199 .53096 Mdot
.41985 .46668 Mdot
.69337 .57919 Mdot
.71527 .67246 Mdot
.43683 .37091 Mdot
.50679 .68456 Mdot
.4033 .51153 Mdot
.40823 .34707 Mdot
.7031 .65571 Mdot
.62186 .35663 Mdot
.59859 .34991 Mdot
.45066 .33117 Mdot
.42585 .33995 Mdot
.45205 .34595 Mdot
.77792 .31783 Mdot
.54093 .72353 Mdot
.50389 .61245 Mdot
.44329 .56594 Mdot
.33449 .39995 Mdot
.38879 .60724 Mdot
.66796 .58008 Mdot
.57955 .35843 Mdot
.42188 .57064 Mdot
.35162 .5063 Mdot
.45955 .5203 Mdot
.5652 .64728 Mdot
.54565 .7565 Mdot
.48934 .65643 Mdot
.45489 .54548 Mdot
.56272 .36836 Mdot
.84856 .38669 Mdot
.40661 .17232 Mdot
.45226 .58065 Mdot
.47821 .43622 Mdot
.5208 .72084 Mdot
.68345 .5227 Mdot
.36972 .31323 Mdot
.66484 .51979 Mdot
.50762 .68098 Mdot
.41022 .51101 Mdot
.67446 .67748 Mdot
.44507 .32099 Mdot
.35818 .5531 Mdot
.64237 .54504 Mdot
.35373 .5527 Mdot
.69481 .57485 Mdot
.55338 .19371 Mdot
.26552 .32482 Mdot
.39843 .53877 Mdot
.41038 .60338 Mdot
.24848 .3877 Mdot
.37255 .55482 Mdot
.44665 .38198 Mdot
.52026 .72102 Mdot
.25217 .56581 Mdot
.39318 .59589 Mdot
.43676 .68242 Mdot
.43941 .55042 Mdot
.23115 .54515 Mdot
.36952 .53212 Mdot
.47587 .26813 Mdot
.37994 .50438 Mdot
.34345 .5429 Mdot
.68189 .54241 Mdot
.69567 .5379 Mdot
.4748 .647 Mdot
.58828 .4141 Mdot
.64936 .22158 Mdot
.37727 .53381 Mdot
.67382 .36874 Mdot
.66438 .70556 Mdot
.42688 .33824 Mdot
.50921 .68801 Mdot
.82085 .63792 Mdot
.63531 .5337 Mdot
.31254 .28599 Mdot
.24444 .52346 Mdot
.61099 .65993 Mdot
.38562 .2819 Mdot
.75849 .57633 Mdot
.42734 .36538 Mdot
.39235 .58457 Mdot
.63215 .27227 Mdot
.4712 .27956 Mdot
.2851 .51074 Mdot
.65871 .50736 Mdot
.42453 .71061 Mdot
.61814 .25526 Mdot
.45811 .35584 Mdot
.40028 .34839 Mdot
.69234 .54888 Mdot
.52399 .37317 Mdot
.42463 .61882 Mdot
.41754 .34004 Mdot
.56114 .40325 Mdot
.55366 .36908 Mdot
.5519 .36074 Mdot
.5351 .7079 Mdot
.35551 .22659 Mdot
.67779 .60472 Mdot
.68788 .57766 Mdot
.54976 .34286 Mdot
.47421 .69956 Mdot
.55071 .71349 Mdot
.57655 .38511 Mdot
.61627 .36349 Mdot
.50692 .71881 Mdot
.42847 .48619 Mdot
.46005 .53941 Mdot
.39207 .54325 Mdot
.43973 .35142 Mdot
.36859 .53697 Mdot
.58541 .40476 Mdot
.66915 .53086 Mdot
.61131 .35846 Mdot
.64169 .56943 Mdot
.72189 .33653 Mdot
.35571 .54205 Mdot
.3773 .50696 Mdot
.49273 .81611 Mdot
.49633 .64049 Mdot
.75348 .3853 Mdot
.64646 .44781 Mdot
.58921 .36725 Mdot
.35317 .55995 Mdot
.54723 .67837 Mdot
.46421 .34847 Mdot
.51717 .82292 Mdot
.42883 .56986 Mdot
.5109 .713 Mdot
.40205 .50684 Mdot
.37219 .63144 Mdot
.22613 .68238 Mdot
.52034 .70496 Mdot
.46396 .81639 Mdot
.37249 .49641 Mdot
.77601 .58955 Mdot
.343 .48615 Mdot
.26789 .46677 Mdot
.42751 .57695 Mdot
.53309 .66696 Mdot
.38901 .54515 Mdot
.54335 .6694 Mdot
.5596 .38992 Mdot
.6823 .52314 Mdot
.52684 .67323 Mdot
.37556 .47933 Mdot
.20652 .25912 Mdot
.64788 .54764 Mdot
.39036 .52648 Mdot
.68077 .53073 Mdot
.5047 .69241 Mdot
.52109 .65951 Mdot
.81797 .58557 Mdot
.71773 .41348 Mdot
.65592 .55334 Mdot
.40494 .50666 Mdot
.77529 .5347 Mdot
.43068 .54189 Mdot
.25752 .44452 Mdot
.41449 .47874 Mdot
.44087 .56544 Mdot
.82788 .51837 Mdot
.68749 .5795 Mdot
.32532 .77286 Mdot
.83134 .56276 Mdot
.80493 .44404 Mdot
.55639 .67644 Mdot
.46003 .35386 Mdot
.70205 .23737 Mdot
.69177 .40921 Mdot
.57743 .40766 Mdot
.41408 .57401 Mdot
.52045 .74729 Mdot
.67646 .55303 Mdot
.44131 .33948 Mdot
.39769 .53781 Mdot
.61309 .35627 Mdot
.199 .50778 Mdot
.63223 .55379 Mdot
.51613 .70749 Mdot
.52366 .72735 Mdot
.6612 .799 Mdot
.40458 .51737 Mdot
.36968 .50702 Mdot
.64961 .55675 Mdot
.74254 .65015 Mdot
.4386 .36536 Mdot
.22353 .50667 Mdot
.65535 .55156 Mdot
.55957 .4973 Mdot
.49811 .66636 Mdot
.39492 .57388 Mdot
.7576 .32601 Mdot
.51139 .33917 Mdot
.52589 .7908 Mdot
.43656 .35571 Mdot
.26013 .43625 Mdot
.53064 .6638 Mdot
.65245 .53138 Mdot
.69711 .46473 Mdot
.3299 .54264 Mdot
.38857 .5701 Mdot
.26572 .43357 Mdot
.68788 .50686 Mdot
.46332 .4668 Mdot
.43284 .56586 Mdot
.60587 .49747 Mdot
.41856 .57792 Mdot
.34781 .57606 Mdot
.43911 .50214 Mdot
.36865 .52103 Mdot
.51478 .717 Mdot
.45538 .49203 Mdot
.59571 .406 Mdot
.49434 .59254 Mdot
.5618 .50703 Mdot
.40111 .52719 Mdot
.42606 .51646 Mdot
.47945 .7747 Mdot
.73908 .49571 Mdot
.52441 .67369 Mdot
.55323 .67486 Mdot
.65495 .51321 Mdot
.46038 .53175 Mdot
.59707 .41236 Mdot
.35449 .58575 Mdot
.61193 .38338 Mdot
.51898 .71801 Mdot
.5842 .36853 Mdot
.6797 .52467 Mdot
.5692 .35634 Mdot
.69041 .40576 Mdot
.64499 .53046 Mdot
.53888 .68992 Mdot
.36042 .51345 Mdot
.65316 .57736 Mdot
.33223 .33883 Mdot
.4383 .35283 Mdot
.84965 .53539 Mdot
.36265 .50609 Mdot
.62516 .71899 Mdot
.31954 .58132 Mdot
.614 .36111 Mdot
.23836 .69286 Mdot
.51681 .72409 Mdot
.39334 .34029 Mdot
.53968 .71691 Mdot
.33726 .27087 Mdot
.43341 .3455 Mdot
.83048 .48981 Mdot
.61259 .45268 Mdot
.33984 .28248 Mdot
.44965 .50863 Mdot
.35058 .30334 Mdot
.5819 .34436 Mdot
.67691 .55117 Mdot
.71032 .46847 Mdot
.34887 .55251 Mdot
.2096 .41817 Mdot
.49039 .70932 Mdot
.58889 .41299 Mdot
.66011 .53273 Mdot
.66102 .57729 Mdot
.4376 .52491 Mdot
.53724 .25392 Mdot
.37668 .57093 Mdot
.72146 .44238 Mdot
.25391 .41538 Mdot
.56414 .67492 Mdot
.39516 .52336 Mdot
.56123 .39345 Mdot
.40226 .50692 Mdot
.40142 .36285 Mdot
.33673 .22984 Mdot
.31852 .52344 Mdot
.6503 .44802 Mdot
.37825 .3171 Mdot
.50313 .65953 Mdot
.3023 .55168 Mdot
.68208 .42331 Mdot
.40657 .51623 Mdot
.2814 .79392 Mdot
.41132 .35221 Mdot
.62628 .27061 Mdot
.37304 .48572 Mdot
.42625 .50685 Mdot
.57851 .57653 Mdot
.60825 .70237 Mdot
.50458 .34719 Mdot
.37996 .55992 Mdot
.28777 .38257 Mdot
.69388 .56626 Mdot
.3896 .57747 Mdot
.38531 .52835 Mdot
.31399 .71156 Mdot
.64974 .57225 Mdot
.59523 .36265 Mdot
.57853 .34415 Mdot
.59729 .42586 Mdot
.39549 .35612 Mdot
.64735 .48303 Mdot
.36036 .39021 Mdot
.18595 .52273 Mdot
.39809 .31889 Mdot
.3506 .51246 Mdot
.41871 .39372 Mdot
.41774 .51391 Mdot
.42969 .32868 Mdot
.64472 .56839 Mdot
.52355 .66918 Mdot
.69788 .63372 Mdot
.5513 .36717 Mdot
.3364 .48722 Mdot
.4325 .3683 Mdot
.53861 .69409 Mdot
.38642 .27492 Mdot
.50195 .66585 Mdot
.65906 .54631 Mdot
.64733 .58021 Mdot
.43851 .33385 Mdot
.50164 .69332 Mdot
.61183 .52994 Mdot
.81217 .61527 Mdot
.43836 .5053 Mdot
.74081 .55734 Mdot
.52343 .65146 Mdot
.55631 .68941 Mdot
.53831 .66685 Mdot
.34756 .54156 Mdot
.47863 .43564 Mdot
.41129 .59079 Mdot
.68999 .5785 Mdot
.58111 .36149 Mdot
.23265 .41172 Mdot
.69982 .34913 Mdot
.46803 .39619 Mdot
.45182 .54759 Mdot
.40132 .54932 Mdot
.38763 .5243 Mdot
.38781 .59592 Mdot
.69721 .44113 Mdot
.37812 .56829 Mdot
.6832 .54426 Mdot
.59341 .39798 Mdot
.39194 .58483 Mdot
.58785 .33419 Mdot
.7962 .43787 Mdot
.40183 .31773 Mdot
.67442 .48913 Mdot
.4258 .14907 Mdot
.53616 .6872 Mdot
.62789 .39208 Mdot
.573 .40443 Mdot
.44755 .35094 Mdot
.67217 .55767 Mdot
.50127 .6696 Mdot
.25367 .47018 Mdot
.4511 .35234 Mdot
.38707 .54256 Mdot
.4579 .43271 Mdot
.22539 .3797 Mdot
.39475 .58378 Mdot
.42142 .56365 Mdot
.60767 .33622 Mdot
.60591 .26412 Mdot
.21102 .3247 Mdot
.36957 .37341 Mdot
.43937 .33817 Mdot
.41089 .31888 Mdot
.4928 .70392 Mdot
.42215 .59147 Mdot
.69215 .57804 Mdot
.47959 .50282 Mdot
.68994 .48825 Mdot
.50098 .56155 Mdot
.57632 .7377 Mdot
.42272 .57343 Mdot
.69055 .74125 Mdot
.40513 .54803 Mdot
.54234 .72144 Mdot
.52296 .71563 Mdot
.52922 .69136 Mdot
.67581 .5503 Mdot
.38083 .72155 Mdot
.68444 .55343 Mdot
.4099 .15086 Mdot
.52086 .65486 Mdot
.61354 .46031 Mdot
.56564 .38208 Mdot
.45421 .58153 Mdot
.4137 .35928 Mdot
.62037 .54118 Mdot
.4655 .52937 Mdot
.23923 .66781 Mdot
.58994 .41084 Mdot
.53787 .68561 Mdot
.75581 .58283 Mdot
.48286 .16626 Mdot
.49062 .47816 Mdot
.46614 .58533 Mdot
.37167 .30131 Mdot
.42594 .33454 Mdot
.52487 .792 Mdot
.40601 .35167 Mdot
.64139 .54259 Mdot
.38045 .50935 Mdot
.36731 .51328 Mdot
.41579 .57936 Mdot
.36296 .54818 Mdot
.67097 .51326 Mdot
.39356 .48073 Mdot
.19791 .64548 Mdot
.55175 .38668 Mdot
.28216 .54312 Mdot
.41368 .3573 Mdot
.64104 .51022 Mdot
.59197 .39944 Mdot
.73466 .49119 Mdot
.34526 .34007 Mdot
.398 .52112 Mdot
.41952 .57233 Mdot
.30424 .29022 Mdot
.43371 .56478 Mdot
.41451 .61338 Mdot
.57529 .40724 Mdot
.43338 .40826 Mdot
.39938 .32242 Mdot
.407 .32133 Mdot
.64658 .52621 Mdot
.51729 .7167 Mdot
.41801 .35386 Mdot
.56416 .37765 Mdot
.45185 .54489 Mdot
.39389 .48516 Mdot
.52397 .65239 Mdot
.31626 .25795 Mdot
.443 .36892 Mdot
.77534 .54942 Mdot
.53928 .71047 Mdot
.48566 .62885 Mdot
.3898 .57016 Mdot
.57189 .7252 Mdot
.55268 .73237 Mdot
.39122 .32599 Mdot
.64147 .51059 Mdot
.36442 .32539 Mdot
.64675 .56033 Mdot
.51281 .70733 Mdot
.40411 .49993 Mdot
.53209 .71461 Mdot
.4034 .51973 Mdot
.54054 .15265 Mdot
.36506 .51882 Mdot
.18224 .52993 Mdot
.29453 .43451 Mdot
.57889 .3952 Mdot
.74614 .51807 Mdot
.56647 .38747 Mdot
.54256 .7041 Mdot
.40823 .4976 Mdot
.4139 .36482 Mdot
.8081 .48538 Mdot
.48824 .72399 Mdot
.6173 .37419 Mdot
.54794 .40209 Mdot
.63864 .55261 Mdot
.42266 .58048 Mdot
.38538 .5697 Mdot
.597 .38654 Mdot
.56439 .67174 Mdot
.49263 .68847 Mdot
.38947 .51242 Mdot
.39998 .55403 Mdot
.57688 .39331 Mdot
.8042 .63016 Mdot
.47293 .70486 Mdot
.37738 .5135 Mdot
.65906 .31705 Mdot
.67402 .58075 Mdot
.45716 .54713 Mdot
.41014 .6047 Mdot
.42331 .34028 Mdot
.2773 .62478 Mdot
.37453 .21814 Mdot
.63877 .563 Mdot
.5662 .40211 Mdot
.40364 .51443 Mdot
.56159 .39455 Mdot
.3946 .48403 Mdot
.60391 .6923 Mdot
.61429 .34943 Mdot
.43602 .53346 Mdot
.41293 .47452 Mdot
.54463 .69157 Mdot
.42183 .57271 Mdot
.45658 .77708 Mdot
.61552 .39583 Mdot
.43299 .51687 Mdot
.35993 .63765 Mdot
.67282 .56606 Mdot
.45307 .51273 Mdot
.44239 .32808 Mdot
.25156 .4743 Mdot
.64325 .67703 Mdot
.58444 .23479 Mdot
.41119 .31642 Mdot
.35694 .55632 Mdot
.55659 .41042 Mdot
.69661 .56549 Mdot
.18606 .55428 Mdot
.373 .57521 Mdot
.6464 .55216 Mdot
.66722 .53012 Mdot
.44432 .35032 Mdot
.49884 .84193 Mdot
.36385 .48777 Mdot
.37039 .54832 Mdot
.36944 .75031 Mdot
.50356 .63981 Mdot
.3637 .52804 Mdot
.35663 .50466 Mdot
.68404 .54341 Mdot
.45017 .61316 Mdot
.44781 .73212 Mdot
.2259 .5245 Mdot
.69812 .57878 Mdot
.52648 .56591 Mdot
.57479 .35059 Mdot
.40698 .33944 Mdot
.50852 .66792 Mdot
.42679 .36821 Mdot
.57921 .35349 Mdot
.35666 .50738 Mdot
.6479 .51728 Mdot
.4245 .7839 Mdot
.69233 .54795 Mdot
.54986 .22023 Mdot
.51492 .64434 Mdot
.65669 .62537 Mdot
.33285 .82861 Mdot
.78205 .48665 Mdot
.7058 .59451 Mdot
.4269 .33866 Mdot
.53409 .33835 Mdot
.40124 .55275 Mdot
.51801 .79851 Mdot
.34991 .51948 Mdot
.3437 .63362 Mdot
.55522 .39448 Mdot
.54877 .38201 Mdot
.37976 .51129 Mdot
.25237 .42497 Mdot
.69687 .56341 Mdot
.66917 .57795 Mdot
.43803 .534 Mdot
.66333 .54912 Mdot
.37545 .54368 Mdot
.59816 .39834 Mdot
.33145 .78595 Mdot
.39355 .53941 Mdot
.37827 .59504 Mdot
.60978 .68586 Mdot
.83273 .53287 Mdot
.47283 .23044 Mdot
.72486 .74187 Mdot
.4559 .17005 Mdot
.6638 .54786 Mdot
.43288 .58272 Mdot
.52622 .56761 Mdot
.58157 .34052 Mdot
.61547 .5478 Mdot
.35613 .52145 Mdot
.35207 .52393 Mdot
.34196 .54111 Mdot
.41559 .55808 Mdot
.54524 .79769 Mdot
.47554 .52759 Mdot
.32605 .66045 Mdot
.42912 .56372 Mdot
.34167 .31241 Mdot
.64169 .52886 Mdot
.5631 .71198 Mdot
.39834 .31462 Mdot
.42195 .57367 Mdot
.48117 .59491 Mdot
.69305 .52882 Mdot
.40609 .15062 Mdot
.63928 .53939 Mdot
.5989 .36668 Mdot
.68944 .53286 Mdot
.41086 .53866 Mdot
.5137 .68674 Mdot
.54019 .5372 Mdot
.75544 .44144 Mdot
.57863 .4082 Mdot
.40389 .53025 Mdot
.62481 .45999 Mdot
.59225 .40799 Mdot
.79623 .42698 Mdot
.51279 .6775 Mdot
.29238 .38138 Mdot
.52799 .71628 Mdot
.43474 .52421 Mdot
.43128 .51825 Mdot
.69587 .59363 Mdot
.68494 .52761 Mdot
.52596 .71667 Mdot
.50789 .84981 Mdot
.45326 .35466 Mdot
.53002 .69634 Mdot
.32663 .53041 Mdot
.5143 .46428 Mdot
.51758 .68803 Mdot
.3821 .30644 Mdot
.67509 .53428 Mdot
.47774 .64975 Mdot
.33391 .51668 Mdot
.37871 .25168 Mdot
.43502 .31843 Mdot
.6159 .34135 Mdot
.39383 .38813 Mdot
.61783 .39538 Mdot
.63953 .51331 Mdot
.56745 .38912 Mdot
.69273 .56544 Mdot
.6503 .69639 Mdot
.50709 .59854 Mdot
.71233 .58182 Mdot
.64938 .51085 Mdot
.57019 .38848 Mdot
.38737 .50801 Mdot
.3791 .30384 Mdot
.44536 .57289 Mdot
.35434 .49066 Mdot
.68842 .57285 Mdot
.53664 .67482 Mdot
.55892 .71276 Mdot
.32099 .32032 Mdot
.50537 .71209 Mdot
.61515 .3768 Mdot
.21139 .6453 Mdot
.67433 .35338 Mdot
.65986 .56788 Mdot
.68757 .52718 Mdot
.43234 .53307 Mdot
.5902 .3823 Mdot
.56647 .40602 Mdot
.64011 .55336 Mdot
.56651 .62939 Mdot
.41401 .59999 Mdot
.55599 .70117 Mdot
.4971 .64326 Mdot
.52107 .70171 Mdot
.53878 .66565 Mdot
.46696 .73181 Mdot
.66521 .52391 Mdot
.53992 .68116 Mdot
.43577 .54132 Mdot
.35382 .52347 Mdot
.50343 .52212 Mdot
.41369 .31984 Mdot
.38633 .58485 Mdot
.44078 .50283 Mdot
.39692 .57285 Mdot
.60012 .34854 Mdot
.3402 .46054 Mdot
.6168 .3544 Mdot
.55755 .40741 Mdot
.56027 .40605 Mdot
.69077 .4085 Mdot
.28869 .32017 Mdot
.47081 .18526 Mdot
.39325 .49768 Mdot
.73838 .67185 Mdot
.58057 .37685 Mdot
.23757 .67725 Mdot
.71804 .67022 Mdot
.36119 .56776 Mdot
.50914 .32897 Mdot
.59305 .38884 Mdot
.51483 .72193 Mdot
.359 .52008 Mdot
.61073 .42011 Mdot
.44305 .32742 Mdot
.44381 .54052 Mdot
.61679 .35031 Mdot
.50142 .69031 Mdot
.38917 .32476 Mdot
.48525 .64296 Mdot
.55809 .4034 Mdot
.42869 .48247 Mdot
.1218 .51174 Mdot
.55096 .4106 Mdot
.78224 .61716 Mdot
.38979 .62394 Mdot
.38848 .51057 Mdot
.62575 .39099 Mdot
.49612 .63591 Mdot
.63393 .51994 Mdot
.56698 .45909 Mdot
.47988 .65671 Mdot
.54871 .38114 Mdot
.62066 .37932 Mdot
.57684 .40813 Mdot
.49048 .65348 Mdot
.34982 .56989 Mdot
.48241 .66684 Mdot
.69094 .53651 Mdot
.42709 .54235 Mdot
.5575 .18801 Mdot
.7278 .68174 Mdot
.53433 .71603 Mdot
.59677 .35932 Mdot
.43791 .31595 Mdot
.40293 .54252 Mdot
.72676 .68943 Mdot
.39327 .50753 Mdot
.68908 .5755 Mdot
.2474 .63147 Mdot
.45695 .79181 Mdot
.4407 .56851 Mdot
.43227 .535 Mdot
.67262 .57786 Mdot
.39916 .53196 Mdot
.42636 .57792 Mdot
.6951 .41273 Mdot
.48635 .66319 Mdot
.39177 .54792 Mdot
.57184 .36625 Mdot
.69838 .38205 Mdot
.40516 .59983 Mdot
.63006 .31741 Mdot
.28202 .39981 Mdot
.25362 .64327 Mdot
.35035 .51822 Mdot
.44416 .43595 Mdot
.40713 .56283 Mdot
.3576 .55002 Mdot
.4239 .52194 Mdot
.58113 .80437 Mdot
.61099 .34665 Mdot
.5762 .40247 Mdot
.42018 .31458 Mdot
.28375 .39607 Mdot
.42059 .3432 Mdot
.67528 .53268 Mdot
.55535 .26605 Mdot
.61623 .35337 Mdot
.50596 .70191 Mdot
.36241 .55878 Mdot
.55231 .41176 Mdot
.39082 .57343 Mdot
.41154 .53708 Mdot
.60288 .41217 Mdot
.58763 .34445 Mdot
.61413 .25767 Mdot
.42489 .31693 Mdot
.52784 .6848 Mdot
.41521 .58669 Mdot
.43988 .36736 Mdot
.35467 .50092 Mdot
.33585 .40118 Mdot
.52677 .68801 Mdot
.48456 .66488 Mdot
.55685 .7213 Mdot
.35865 .50616 Mdot
.40675 .53897 Mdot
.6854 .55545 Mdot
.53476 .71907 Mdot
.66969 .56471 Mdot
.58909 .48851 Mdot
.57748 .30535 Mdot
.35597 .52153 Mdot
.74097 .59264 Mdot
.41223 .33126 Mdot
.61149 .36555 Mdot
.23247 .37817 Mdot
.4216 .31432 Mdot
.40127 .51799 Mdot
.57587 .41412 Mdot
.42658 .32568 Mdot
.26993 .54858 Mdot
.36547 .19421 Mdot
.42327 .31039 Mdot
.436 .54237 Mdot
.45899 .60068 Mdot
.71228 .75372 Mdot
.41207 .31373 Mdot
.67045 .51984 Mdot
.35948 .50603 Mdot
.52193 .74015 Mdot
.42494 .36863 Mdot
.76299 .41512 Mdot
.59294 .39471 Mdot
.38133 .23687 Mdot
.43363 .47045 Mdot
.48028 .80546 Mdot
.4061 .32771 Mdot
.50372 .67493 Mdot
.35976 .60797 Mdot
.39535 .56878 Mdot
.4157 .31346 Mdot
.70938 .56216 Mdot
.60546 .38649 Mdot
.72006 .40636 Mdot
.49053 .65259 Mdot
.66768 .61127 Mdot
.59473 .35608 Mdot
.77706 .54275 Mdot
.23348 .56545 Mdot
.45917 .5401 Mdot
.69644 .75913 Mdot
.65444 .47361 Mdot
.34143 .54972 Mdot
.44915 .3218 Mdot
.64484 .57125 Mdot
.64958 .51536 Mdot
.65567 .54686 Mdot
.66002 .70251 Mdot
.48072 .46782 Mdot
.62911 .39037 Mdot
.65873 .59699 Mdot
.40802 .34009 Mdot
.36026 .32194 Mdot
.36629 .48006 Mdot
.3996 .54791 Mdot
.43158 .57749 Mdot
.41477 .57761 Mdot
.39821 .56306 Mdot
.66693 .55709 Mdot
.63772 .7017 Mdot
.49188 .49189 Mdot
.52253 .68953 Mdot
.58322 .25772 Mdot
.56784 .37988 Mdot
.63039 .38813 Mdot
.43126 .32384 Mdot
.79366 .48648 Mdot
.59016 .33355 Mdot
.58582 .36724 Mdot
.35711 .57138 Mdot
.48864 .68406 Mdot
.43753 .6104 Mdot
.43405 .5382 Mdot
.61364 .37737 Mdot
.57378 .54726 Mdot
.46409 .75614 Mdot
.30947 .47715 Mdot
.41976 .29947 Mdot
.49096 .45725 Mdot
.43401 .31572 Mdot
.40353 .49478 Mdot
.242 .69267 Mdot
.58079 .35245 Mdot
.59782 .37381 Mdot
.41025 .32662 Mdot
.5623 .74778 Mdot
.51047 .6614 Mdot
.73538 .57766 Mdot
.68552 .53726 Mdot
.41695 .50436 Mdot
.20312 .49509 Mdot
.29872 .56638 Mdot
.5262 .25726 Mdot
.65236 .54996 Mdot
.56047 .38994 Mdot
.44969 .55628 Mdot
.43447 .54782 Mdot
.41382 .32854 Mdot
.66371 .26313 Mdot
.44937 .52409 Mdot
.80963 .4027 Mdot
.26584 .32393 Mdot
.34004 .2563 Mdot
.38816 .56989 Mdot
.48667 .66017 Mdot
.60792 .33848 Mdot
.40377 .3437 Mdot
.3274 .51595 Mdot
.40155 .1839 Mdot
.51813 .64998 Mdot
.646 .53436 Mdot
.5548 .52634 Mdot
.36748 .34508 Mdot
.34324 .52148 Mdot
.35277 .51736 Mdot
.35083 .54093 Mdot
.30833 .22288 Mdot
.60744 .34868 Mdot
.52404 .72135 Mdot
.44406 .34597 Mdot
.50501 .70895 Mdot
.57302 .39664 Mdot
.65163 .61502 Mdot
.3856 .50507 Mdot
.51593 .64799 Mdot
.50422 .67344 Mdot
.63886 .54327 Mdot
.62998 .52719 Mdot
.56829 .51014 Mdot
.3657 .52056 Mdot
.54509 .4023 Mdot
.54262 .68597 Mdot
.46068 .43625 Mdot
.43176 .34547 Mdot
.67896 .53659 Mdot
.42593 .56793 Mdot
.59786 .3453 Mdot
.36178 .47735 Mdot
.51988 .6725 Mdot
.58557 .36788 Mdot
.65038 .29646 Mdot
.4034 .31874 Mdot
.35841 .53451 Mdot
.4159 .37764 Mdot
.56751 .40409 Mdot
.40298 .5541 Mdot
.78948 .55104 Mdot
.38144 .31137 Mdot
.75248 .41819 Mdot
.56686 .4108 Mdot
.67262 .39152 Mdot
.4894 .69712 Mdot
.66871 .71508 Mdot
.59992 .37076 Mdot
.76991 .56331 Mdot
.67439 .29207 Mdot
.45174 .5562 Mdot
.52299 .70962 Mdot
.64379 .47315 Mdot
.60099 .18533 Mdot
.78075 .65303 Mdot
.38911 .52682 Mdot
.60795 .41787 Mdot
.41801 .32688 Mdot
.66411 .57071 Mdot
.62029 .30896 Mdot
.38865 .30539 Mdot
.54474 .37902 Mdot
.42287 .52101 Mdot
.50344 .68405 Mdot
.67527 .54011 Mdot
.64661 .68176 Mdot
.56579 .37322 Mdot
.58443 .35934 Mdot
.44848 .55871 Mdot
.41531 .34292 Mdot
.69698 .71594 Mdot
.59315 .40232 Mdot
.2821 .31181 Mdot
.54505 .41815 Mdot
.44884 .36165 Mdot
.41405 .56434 Mdot
.32168 .31398 Mdot
.40414 .59512 Mdot
.80786 .56117 Mdot
.56972 .38348 Mdot
.52278 .67922 Mdot
.34454 .53946 Mdot
.23592 .52295 Mdot
.61373 .37363 Mdot
.48072 .44072 Mdot
.47012 .25816 Mdot
.67085 .52778 Mdot
.22996 .38166 Mdot
.36591 .53653 Mdot
.69655 .56345 Mdot
.41437 .33116 Mdot
.37269 .51629 Mdot
.40913 .54109 Mdot
.54703 .70331 Mdot
.64071 .54932 Mdot
.64023 .26361 Mdot
.69515 .53516 Mdot
.64655 .52075 Mdot
.55049 .6905 Mdot
.38292 .5531 Mdot
.59799 .36538 Mdot
.59395 .38708 Mdot
.33932 .49417 Mdot
.28896 .76436 Mdot
.50903 .6581 Mdot
.61776 .33915 Mdot
.2963 .23495 Mdot
.36258 .46965 Mdot
.22311 .40219 Mdot
.67411 .26887 Mdot
.68642 .58191 Mdot
.437 .54545 Mdot
.50325 .69265 Mdot
.5071 .3865 Mdot
.58827 .35946 Mdot
.33623 .52558 Mdot
.67267 .53953 Mdot
.43968 .3229 Mdot
.60863 .40056 Mdot
.53669 .25548 Mdot
.3582 .54518 Mdot
.5032 .32844 Mdot
.61749 .4073 Mdot
.71966 .25072 Mdot
.72501 .48776 Mdot
.52679 .70838 Mdot
.41441 .53856 Mdot
.51456 .7235 Mdot
.44391 .3419 Mdot
.5557 .52315 Mdot
.67163 .53467 Mdot
.45486 .4804 Mdot
.17861 .62773 Mdot
.57489 .40797 Mdot
.52324 .72232 Mdot
.44235 .56601 Mdot
.59896 .68993 Mdot
.37046 .54242 Mdot
.45773 .61526 Mdot
.40961 .39317 Mdot
.68087 .57306 Mdot
.69377 .55969 Mdot
.41202 .55304 Mdot
.44616 .35861 Mdot
.56537 .37826 Mdot
.60978 .37986 Mdot
.82707 .36988 Mdot
.59503 .60455 Mdot
.23887 .45622 Mdot
.35261 .52671 Mdot
.54462 .38641 Mdot
.70115 .35929 Mdot
.65 .55655 Mdot
.34044 .48661 Mdot
.59608 .41226 Mdot
.41193 .26241 Mdot
.25573 .49312 Mdot
.40116 .56588 Mdot
.35916 .5828 Mdot
.68248 .53209 Mdot
.46612 .45701 Mdot
.55401 .38389 Mdot
.40155 .47417 Mdot
.71499 .58468 Mdot
.26106 .52103 Mdot
.30956 .25157 Mdot
.52813 .68506 Mdot
.51974 .24335 Mdot
.66773 .55757 Mdot
.36588 .58937 Mdot
.428 .36404 Mdot
.59624 .33614 Mdot
.6047 .34562 Mdot
.41176 .5163 Mdot
.42986 .50582 Mdot
.24662 .37787 Mdot
.49902 .69931 Mdot
.64367 .52676 Mdot
.36703 .50856 Mdot
.71661 .62627 Mdot
.41922 .57822 Mdot
.68447 .56129 Mdot
.11526 .51866 Mdot
.44381 .5721 Mdot
.3715 .54666 Mdot
.71381 .70105 Mdot
.48411 .64967 Mdot
.52747 .7245 Mdot
.19835 .45016 Mdot
.35292 .52728 Mdot
.24891 .35281 Mdot
.5279 .67948 Mdot
.51355 .66251 Mdot
.70852 .42033 Mdot
.40052 .54346 Mdot
.41592 .44812 Mdot
.69109 .57625 Mdot
.65282 .5181 Mdot
.48304 .65765 Mdot
.45607 .54129 Mdot
.63487 .5554 Mdot
.60603 .78359 Mdot
.58832 .38261 Mdot
.2541 .71191 Mdot
.51074 .65463 Mdot
.67588 .49664 Mdot
.65131 .55448 Mdot
.41488 .15108 Mdot
.59647 .44441 Mdot
.3843 .50709 Mdot
.35532 .53477 Mdot
.40907 .33354 Mdot
.4296 .58137 Mdot
.54899 .3836 Mdot
.66305 .54965 Mdot
.31098 .6119 Mdot
.52969 .69188 Mdot
.36954 .52998 Mdot
.79587 .46619 Mdot
.764 .38709 Mdot
.51929 .23415 Mdot
.50352 .66062 Mdot
.5328 .70954 Mdot
.55886 .3736 Mdot
.60832 .41715 Mdot
.38704 .56185 Mdot
.66046 .57394 Mdot
.5347 .71855 Mdot
.68641 .56693 Mdot
.58254 .35204 Mdot
.59345 .36506 Mdot
.60273 .34196 Mdot
.37976 .47654 Mdot
.57936 .36611 Mdot
.62548 .29825 Mdot
.66776 .60898 Mdot
.55127 .70959 Mdot
.23626 .33477 Mdot
.65367 .68234 Mdot
.5293 .76009 Mdot
.42556 .37001 Mdot
.5694 .40643 Mdot
.69485 .5434 Mdot
.42439 .55249 Mdot
.40658 .57518 Mdot
.66254 .35904 Mdot
.69984 .56055 Mdot
.4422 .3398 Mdot
.69499 .55642 Mdot
.44453 .35026 Mdot
.47961 .29442 Mdot
.41364 .58366 Mdot
.39968 .48723 Mdot
.66253 .55536 Mdot
.58161 .36718 Mdot
.58432 .40075 Mdot
.4148 .31036 Mdot
.58891 .54853 Mdot
.59257 .40847 Mdot
.51659 .66073 Mdot
.47885 .74052 Mdot
.62117 .37737 Mdot
.36027 .52271 Mdot
.36209 .39424 Mdot
.506 .80778 Mdot
.38717 .59577 Mdot
.70288 .41725 Mdot
.41364 .79213 Mdot
.35466 .55779 Mdot
.48101 .82063 Mdot
.65597 .43231 Mdot
.4897 .69553 Mdot
.55477 .39166 Mdot
.59079 .32877 Mdot
.31405 .50873 Mdot
.40023 .30754 Mdot
.33117 .50681 Mdot
.50777 .65093 Mdot
.4848 .70233 Mdot
.3491 .26305 Mdot
.7932 .601 Mdot
.42168 .32681 Mdot
.42234 .32271 Mdot
.60269 .37143 Mdot
.85299 .55138 Mdot
.46761 .55403 Mdot
.44023 .33743 Mdot
.51931 .60374 Mdot
.41972 .51918 Mdot
.27897 .43218 Mdot
.48111 .34904 Mdot
.48591 .65647 Mdot
.34031 .30485 Mdot
.60633 .36689 Mdot
.50364 .71121 Mdot
.69907 .63842 Mdot
.37932 .58476 Mdot
.52726 .68978 Mdot
.68715 .56251 Mdot
.74008 .47887 Mdot
.52331 .66237 Mdot
.35068 .39554 Mdot
.64182 .55965 Mdot
.46688 .4389 Mdot
.30516 .34522 Mdot
.571 .88976 Mdot
.66688 .55354 Mdot
.61926 .37524 Mdot
.59502 .3871 Mdot
.60958 .37865 Mdot
.50125 .70513 Mdot
.56618 .40529 Mdot
.50238 .70252 Mdot
.73539 .71177 Mdot
.57357 .7399 Mdot
.43847 .33605 Mdot
.72392 .41065 Mdot
.50955 .69656 Mdot
.22677 .67221 Mdot
.24727 .74769 Mdot
.43745 .54493 Mdot
.68497 .52168 Mdot
.4333 .33205 Mdot
.81475 .41324 Mdot
.42226 .33698 Mdot
.31864 .29265 Mdot
.24841 .66008 Mdot
.37531 .53729 Mdot
.41649 .72941 Mdot
.39723 .33958 Mdot
.49783 .66434 Mdot
.40357 .55256 Mdot
.52608 .43157 Mdot
.41837 .33715 Mdot
.44917 .33916 Mdot
.39045 .55637 Mdot
.53807 .68595 Mdot
.60317 .36199 Mdot
.67576 .51967 Mdot
.40306 .35888 Mdot
.41824 .62197 Mdot
.3796 .59095 Mdot
.39687 .50546 Mdot
.50638 .5181 Mdot
.46259 .36568 Mdot
.66447 .54751 Mdot
.54371 .82078 Mdot
.5738 .41595 Mdot
.53672 .43653 Mdot
.29159 .29604 Mdot
.68538 .41957 Mdot
.57208 .38416 Mdot
.5638 .39545 Mdot
.39557 .56441 Mdot
.47066 .34974 Mdot
.25304 .67108 Mdot
.60301 .53654 Mdot
.61223 .34257 Mdot
.60825 .38384 Mdot
.50123 .71925 Mdot
.33613 .26699 Mdot
.32588 .52072 Mdot
.63811 .56264 Mdot
.60115 .34404 Mdot
.5987 .72576 Mdot
.41241 .34307 Mdot
.22962 .64651 Mdot
.40792 .58493 Mdot
.379 .50709 Mdot
.6623 .53604 Mdot
.68376 .55131 Mdot
.50479 .386 Mdot
.32959 .27525 Mdot
.42921 .7951 Mdot
.62799 .68137 Mdot
.27429 .65389 Mdot
.49504 .71586 Mdot
.53485 .71561 Mdot
.76926 .45604 Mdot
.69395 .5317 Mdot
.34983 .55051 Mdot
.51968 .71721 Mdot
.55987 .44731 Mdot
.48808 .73653 Mdot
.25539 .4418 Mdot
.23002 .40719 Mdot
.40358 .52216 Mdot
.48861 .67387 Mdot
.48668 .64881 Mdot
.52281 .64121 Mdot
.63987 .45143 Mdot
.37945 .5596 Mdot
.39688 .52431 Mdot
.36733 .56692 Mdot
.58225 .66944 Mdot
.36867 .55903 Mdot
.66026 .71707 Mdot
.55123 .50407 Mdot
.28109 .61858 Mdot
.41469 .48063 Mdot
.67817 .5859 Mdot
.34625 .51753 Mdot
.44671 .35686 Mdot
.42656 .5202 Mdot
.25375 .44819 Mdot
.64484 .54512 Mdot
.47494 .70991 Mdot
.65428 .69175 Mdot
.34428 .55026 Mdot
.39047 .33348 Mdot
.71357 .5031 Mdot
.54117 .18385 Mdot
.40213 .37382 Mdot
.51535 .65926 Mdot
.58207 .3829 Mdot
.69646 .54708 Mdot
.59318 .36859 Mdot
.40127 .48177 Mdot
.77323 .47138 Mdot
.76693 .36738 Mdot
.59483 .49257 Mdot
.41562 .57657 Mdot
.40086 .4551 Mdot
.51756 .66556 Mdot
.57916 .41572 Mdot
.5433 .74456 Mdot
.34557 .53733 Mdot
.43978 .35245 Mdot
.41432 .33425 Mdot
.57642 .46048 Mdot
.70513 .26505 Mdot
.5977 .76371 Mdot
.66339 .53851 Mdot
.60006 .39833 Mdot
.408 .35534 Mdot
.76773 .60448 Mdot
.62892 .52789 Mdot
.6783 .5789 Mdot
.64248 .53778 Mdot
.36771 .49713 Mdot
.61413 .34877 Mdot
.28242 .61726 Mdot
.5464 .38177 Mdot
.4021 .53243 Mdot
.60429 .34946 Mdot
.59185 .4121 Mdot
.41009 .35357 Mdot
.6416 .53242 Mdot
.57085 .35872 Mdot
.43288 .51949 Mdot
.5331 .68298 Mdot
.70909 .5292 Mdot
.28288 .45551 Mdot
.79674 .58818 Mdot
.32755 .61036 Mdot
.49985 .64474 Mdot
.60095 .19042 Mdot
.67895 .58094 Mdot
.57178 .63671 Mdot
.60613 .25573 Mdot
.39658 .49583 Mdot
.2525 .73565 Mdot
.63063 .38397 Mdot
.60267 .40927 Mdot
.41344 .56316 Mdot
.52273 .38034 Mdot
.37073 .53498 Mdot
.5885 .35333 Mdot
.65529 .32353 Mdot
.46984 .61962 Mdot
.57654 .37084 Mdot
.39347 .47256 Mdot
.40983 .54629 Mdot
.48435 .66074 Mdot
.62455 .39227 Mdot
.33446 .49089 Mdot
.8137 .3498 Mdot
.68233 .55482 Mdot
.64407 .4615 Mdot
.3669 .40416 Mdot
.66858 .55883 Mdot
.52871 .69892 Mdot
.35755 .48709 Mdot
.41467 .32965 Mdot
.5081 .69612 Mdot
.25012 .50828 Mdot
.40096 .32474 Mdot
.23045 .69552 Mdot
.48927 .64961 Mdot
.61989 .38492 Mdot
.43487 .36408 Mdot
.42389 .58668 Mdot
.59781 .33629 Mdot
.74418 .50782 Mdot
.57223 .38239 Mdot
.38367 .56886 Mdot
.72979 .39404 Mdot
.64579 .52376 Mdot
.38614 .52521 Mdot
.60785 .40648 Mdot
.69818 .40952 Mdot
.37283 .49562 Mdot
.40926 .55806 Mdot
.3101 .26037 Mdot
.20212 .59591 Mdot
.42831 .34133 Mdot
.50808 .63573 Mdot
.43579 .54082 Mdot
.44659 .33522 Mdot
.53231 .30094 Mdot
.36939 .50215 Mdot
.52086 .65089 Mdot
.3746 .46399 Mdot
.62282 .39846 Mdot
.67456 .56298 Mdot
.61006 .48805 Mdot
.44299 .3275 Mdot
.7106 .78414 Mdot
.56409 .35892 Mdot
.39391 .48766 Mdot
.42606 .57274 Mdot
.44653 .2261 Mdot
.49087 .6968 Mdot
.34288 .76513 Mdot
.35817 .53454 Mdot
.57844 .6616 Mdot
.37339 .51935 Mdot
.6279 .35981 Mdot
.51116 .66099 Mdot
.37111 .55139 Mdot
.71214 .60713 Mdot
.38853 .59854 Mdot
.42 .31562 Mdot
.71883 .70041 Mdot
.36304 .57947 Mdot
.14327 .59368 Mdot
.46733 .30889 Mdot
.57473 .37032 Mdot
.75839 .39588 Mdot
.86908 .41834 Mdot
.66401 .69828 Mdot
.50829 .71042 Mdot
.70668 .29971 Mdot
.59727 .36503 Mdot
.73025 .36756 Mdot
.59228 .18421 Mdot
.41544 .54664 Mdot
.34287 .52197 Mdot
.38414 .27342 Mdot
.55683 .40473 Mdot
.53987 .38981 Mdot
.44406 .52065 Mdot
.35594 .58276 Mdot
.58741 .36298 Mdot
.42709 .50805 Mdot
.42625 .49713 Mdot
.67539 .51702 Mdot
.51448 .65084 Mdot
.67714 .5748 Mdot
.63984 .5614 Mdot
.64833 .76493 Mdot
.44844 .28612 Mdot
.68272 .56113 Mdot
.66192 .58048 Mdot
.27666 .43638 Mdot
.26495 .37415 Mdot
.42311 .3681 Mdot
.7406 .28358 Mdot
.60643 .38331 Mdot
.3788 .55501 Mdot
.49356 .64563 Mdot
.44162 .79454 Mdot
.58914 .29004 Mdot
.26741 .7114 Mdot
.34746 .54441 Mdot
.6119 .37046 Mdot
.64027 .45141 Mdot
.43071 .61276 Mdot
.58597 .42617 Mdot
.36317 .50901 Mdot
.54878 .37067 Mdot
.42956 .68476 Mdot
.76931 .56128 Mdot
.54153 .40545 Mdot
.55535 .70018 Mdot
.37232 .50945 Mdot
.50603 .6518 Mdot
.65447 .55851 Mdot
.43311 .36659 Mdot
.42815 .34453 Mdot
.39842 .5549 Mdot
.44268 .4943 Mdot
.48954 .31035 Mdot
.40423 .54297 Mdot
.42408 .52492 Mdot
.65677 .431 Mdot
.42739 .52683 Mdot
.40082 .57912 Mdot
.38027 .57366 Mdot
.33814 .51882 Mdot
.64971 .51917 Mdot
.79323 .48176 Mdot
.32842 .56237 Mdot
.34178 .57652 Mdot
.63271 .52665 Mdot
.64929 .26162 Mdot
.65016 .57124 Mdot
.54601 .17968 Mdot
.69357 .57224 Mdot
.43551 .3459 Mdot
.50625 .21386 Mdot
.45493 .50184 Mdot
.54163 .67775 Mdot
.62608 .52274 Mdot
.4457 .34518 Mdot
.65886 .54807 Mdot
.59791 .35379 Mdot
.3228 .23153 Mdot
.47266 .62768 Mdot
.48277 .50906 Mdot
.61785 .5285 Mdot
.77253 .49667 Mdot
.56158 .36427 Mdot
.50178 .65305 Mdot
.45404 .75209 Mdot
.41153 .57912 Mdot
.44807 .33954 Mdot
.39004 .56079 Mdot
.63835 .53307 Mdot
.60818 .37034 Mdot
.76669 .66405 Mdot
.41363 .32882 Mdot
.25458 .31556 Mdot
.588 .39694 Mdot
.3839 .57762 Mdot
.63643 .55855 Mdot
.19891 .39847 Mdot
.68187 .57425 Mdot
.29501 .715 Mdot
.50121 .71487 Mdot
.7386 .73014 Mdot
.51457 .70474 Mdot
.75303 .51524 Mdot
.18705 .35407 Mdot
.80045 .48239 Mdot
.53693 .68605 Mdot
.60619 .59194 Mdot
.40391 .51648 Mdot
.39561 .50524 Mdot
.7739 .60652 Mdot
.50963 .63663 Mdot
.43314 .55891 Mdot
.67152 .34251 Mdot
.63671 .60393 Mdot
.21301 .44866 Mdot
.56337 .38869 Mdot
.36668 .53349 Mdot
.68414 .59215 Mdot
.69868 .56543 Mdot
.55223 .37031 Mdot
.67671 .57986 Mdot
.39627 .52611 Mdot
.51042 .69798 Mdot
.58033 .31601 Mdot
.42561 .35325 Mdot
.83549 .48124 Mdot
.45522 .34722 Mdot
.57224 .38469 Mdot
.445 .57437 Mdot
.59238 .36522 Mdot
.87801 .3963 Mdot
.39358 .51938 Mdot
.52654 .67858 Mdot
.43248 .54025 Mdot
.37579 .511 Mdot
.33934 .52893 Mdot
.59555 .35836 Mdot
.31318 .46336 Mdot
.43057 .51415 Mdot
.67168 .53366 Mdot
.28148 .64109 Mdot
.3607 .57626 Mdot
.55913 .33592 Mdot
.26666 .39609 Mdot
.63458 .5829 Mdot
.47709 .65848 Mdot
.57322 .37516 Mdot
.53236 .69227 Mdot
.57199 .71085 Mdot
.52845 .69876 Mdot
.32067 .69931 Mdot
.45214 .7413 Mdot
.25595 .5566 Mdot
.35457 .63481 Mdot
.5625 .57048 Mdot
.50883 .6361 Mdot
.46245 .37253 Mdot
.54157 .70697 Mdot
.48107 .65496 Mdot
.07168 .47543 Mdot
.54395 .67737 Mdot
.3583 .52632 Mdot
.36998 .57918 Mdot
.77661 .51863 Mdot
.32159 .39022 Mdot
.42831 .54422 Mdot
.43014 .55322 Mdot
.41748 .36158 Mdot
.57158 .6644 Mdot
.76115 .42751 Mdot
.19721 .60824 Mdot
.74368 .36172 Mdot
.39103 .55857 Mdot
.43574 .5377 Mdot
.40281 .60877 Mdot
.16095 .49301 Mdot
.6494 .77563 Mdot
.46765 .66089 Mdot
.41148 .60684 Mdot
.81406 .51757 Mdot
.34097 .52836 Mdot
.35595 .50559 Mdot
.40346 .51995 Mdot
.59819 .36505 Mdot
.48055 .6424 Mdot
.34091 .5069 Mdot
.39269 .26941 Mdot
.35609 .51083 Mdot
.68952 .41741 Mdot
.81162 .64191 Mdot
.36572 .53709 Mdot
.47329 .65121 Mdot
.40106 .50587 Mdot
.48487 .68218 Mdot
.49303 .66378 Mdot
.44801 .58506 Mdot
.27645 .65661 Mdot
.47914 .68539 Mdot
.40281 .53289 Mdot
.60765 .35998 Mdot
.71365 .25047 Mdot
.38196 .56821 Mdot
.43141 .36785 Mdot
.35513 .5332 Mdot
.39037 .33984 Mdot
.42482 .5294 Mdot
.56274 .35936 Mdot
.47827 .79971 Mdot
.59984 .37394 Mdot
.68115 .77085 Mdot
.59475 .34274 Mdot
.29685 .26625 Mdot
.50607 .64188 Mdot
.72574 .40326 Mdot
.39921 .80951 Mdot
.65985 .45186 Mdot
.46993 .41981 Mdot
.52658 .5025 Mdot
.6618 .57474 Mdot
.50333 .71429 Mdot
.54236 .60071 Mdot
.61661 .26969 Mdot
.55067 .23316 Mdot
.59876 .40475 Mdot
.49633 .84515 Mdot
.29954 .75748 Mdot
.41425 .49831 Mdot
.40022 .73642 Mdot
.34966 .68241 Mdot
.34032 .525 Mdot
.34541 .50208 Mdot
.65823 .4029 Mdot
.43804 .52499 Mdot
.72181 .62126 Mdot
.57281 .38824 Mdot
.44652 .34486 Mdot
.52226 .67004 Mdot
.4414 .32408 Mdot
.60684 .26051 Mdot
.52223 .50058 Mdot
.58911 .3518 Mdot
.35604 .57824 Mdot
.42689 .55407 Mdot
.48411 .67387 Mdot
.50388 .73838 Mdot
.54402 .69529 Mdot
.42609 .32955 Mdot
.57789 .39133 Mdot
.52575 .79985 Mdot
.42625 .56047 Mdot
.50542 .67433 Mdot
.47174 .40806 Mdot
.43599 .54343 Mdot
.65972 .55816 Mdot
.39889 .51426 Mdot
.53444 .67939 Mdot
.42747 .5271 Mdot
.51415 .70606 Mdot
.58478 .38194 Mdot
.36242 .57066 Mdot
.40855 .56554 Mdot
.22216 .36166 Mdot
.44081 .3441 Mdot
.5166 .64514 Mdot
.60395 .45119 Mdot
.4345 .5699 Mdot
.72454 .43115 Mdot
.36037 .51235 Mdot
.53419 .76671 Mdot
.38654 .49129 Mdot
.65433 .44973 Mdot
.32065 .54011 Mdot
.37924 .56571 Mdot
.4933 .40089 Mdot
.34772 .69104 Mdot
.46325 .65444 Mdot
.64511 .57293 Mdot
.53685 .66074 Mdot
.21643 .45014 Mdot
.54856 .42413 Mdot
.59274 .41901 Mdot
.35134 .32557 Mdot
.3357 .52334 Mdot
.37609 .53988 Mdot
.64511 .57833 Mdot
.42008 .31976 Mdot
.50219 .66123 Mdot
.44443 .35018 Mdot
.24283 .35164 Mdot
.40777 .3226 Mdot
.63097 .37518 Mdot
.50507 .32736 Mdot
.54446 .795 Mdot
.4153 .35999 Mdot
.53819 .68467 Mdot
.55454 .31659 Mdot
.33465 .53203 Mdot
.47401 .31994 Mdot
.43375 .3566 Mdot
.56773 .84722 Mdot
.3997 .57871 Mdot
.46555 .41868 Mdot
.67904 .56686 Mdot
.42552 .36398 Mdot
.64689 .56191 Mdot
.42172 .55229 Mdot
.75449 .41828 Mdot
.51098 .71168 Mdot
.63389 .53542 Mdot
.44802 .50606 Mdot
.4342 .3313 Mdot
.60849 .34633 Mdot
.62841 .55894 Mdot
.63805 .56434 Mdot
.66082 .2579 Mdot
.74974 .69131 Mdot
.58057 .39233 Mdot
.22537 .55466 Mdot
.69506 .57318 Mdot
.33797 .54211 Mdot
.56124 .64047 Mdot
.38342 .5066 Mdot
.64317 .73835 Mdot
.56834 .37812 Mdot
.78292 .49719 Mdot
.43369 .53538 Mdot
.35827 .55619 Mdot
.47048 .64121 Mdot
.60018 .38152 Mdot
.51544 .68942 Mdot
.53616 .65724 Mdot
.58621 .38282 Mdot
.52325 .70792 Mdot
.39679 .33227 Mdot
.63023 .62487 Mdot
.68736 .53915 Mdot
.66364 .5279 Mdot
.60998 .38076 Mdot
.57178 .36944 Mdot
.58723 .36734 Mdot
.39854 .51386 Mdot
.50583 .65943 Mdot
.41783 .53659 Mdot
.35097 .51339 Mdot
.26915 .63121 Mdot
.48316 .6455 Mdot
.41062 .52652 Mdot
.51635 .41813 Mdot
.46096 .31523 Mdot
.60812 .35802 Mdot
.68106 .56311 Mdot
.6949 .36184 Mdot
.74062 .51276 Mdot
.36534 .5294 Mdot
.42626 .26646 Mdot
.54098 .69151 Mdot
.4165 .33199 Mdot
.46027 .35507 Mdot
.42461 .33825 Mdot
.61263 .50901 Mdot
.51397 .63953 Mdot
.19967 .61805 Mdot
.3699 .5368 Mdot
.50359 .50815 Mdot
.50642 .59323 Mdot
.47522 .2971 Mdot
.6814 .55978 Mdot
.43424 .54667 Mdot
.60697 .49211 Mdot
.47101 .76736 Mdot
.3843 .5088 Mdot
.35064 .56733 Mdot
.65234 .30107 Mdot
.36296 .46459 Mdot
.51704 .7268 Mdot
.20068 .40433 Mdot
.43802 .57419 Mdot
.59458 .72993 Mdot
.84416 .4871 Mdot
.36319 .51948 Mdot
.35155 .54487 Mdot
.41415 .5719 Mdot
.42403 .5169 Mdot
.47535 .66908 Mdot
.31583 .35524 Mdot
.69188 .58023 Mdot
.49897 .50298 Mdot
.65898 .51558 Mdot
.59018 .33955 Mdot
.78852 .49651 Mdot
.50646 .71777 Mdot
.40926 .33314 Mdot
.80219 .42826 Mdot
.18413 .50597 Mdot
.55413 .38508 Mdot
.6058 .78128 Mdot
.43783 .35208 Mdot
.34168 .55167 Mdot
.39437 .33824 Mdot
.61773 .35712 Mdot
.66908 .52761 Mdot
.33537 .55073 Mdot
.53981 .70809 Mdot
.52034 .65913 Mdot
.43583 .55198 Mdot
.81407 .5011 Mdot
.66338 .56184 Mdot
.62974 .5542 Mdot
.37079 .49888 Mdot
.42274 .58678 Mdot
.51812 .69324 Mdot
.59653 .39829 Mdot
.23371 .49376 Mdot
.43218 .32324 Mdot
.37252 .47744 Mdot
.42267 .51997 Mdot
.29969 .28652 Mdot
.6765 .53507 Mdot
.60236 .42177 Mdot
.38881 .49469 Mdot
.62008 .67843 Mdot
.39179 .49559 Mdot
.42531 .60728 Mdot
.60953 .36132 Mdot
.3225 .55787 Mdot
.40988 .49251 Mdot
.48143 .61561 Mdot
.66056 .57151 Mdot
.52563 .68446 Mdot
.50495 .62903 Mdot
.51094 .55605 Mdot
.65839 .5562 Mdot
.40922 .51979 Mdot
.67773 .55395 Mdot
.37018 .5026 Mdot
.43874 .53694 Mdot
.6843 .56179 Mdot
.5156 .69073 Mdot
.7061 .30311 Mdot
.79407 .47393 Mdot
.42374 .51437 Mdot
.45145 .54708 Mdot
.31645 .37109 Mdot
.32033 .4585 Mdot
.34371 .53257 Mdot
.53129 .67378 Mdot
.42091 .56209 Mdot
.64533 .55613 Mdot
.39825 .34212 Mdot
.53374 .68239 Mdot
.57882 .40246 Mdot
.55524 .37634 Mdot
.65822 .69295 Mdot
.57928 .41298 Mdot
.34508 .51232 Mdot
.5569 .73248 Mdot
.48788 .62577 Mdot
.83081 .50937 Mdot
.58957 .38414 Mdot
.41849 .3679 Mdot
.40748 .55731 Mdot
.37921 .25117 Mdot
.68783 .59279 Mdot
.16777 .65535 Mdot
.22231 .6696 Mdot
.41319 .30579 Mdot
.26824 .70562 Mdot
.57693 .34798 Mdot
.4008 .48518 Mdot
.43852 .36596 Mdot
.55866 .37518 Mdot
.4041 .50142 Mdot
.44333 .59501 Mdot
.32863 .75352 Mdot
.53725 .55226 Mdot
.67875 .55195 Mdot
.56564 .40658 Mdot
.42251 .30375 Mdot
.62964 .39514 Mdot
.50155 .64752 Mdot
.37617 .56088 Mdot
.44647 .5757 Mdot
.58643 .40334 Mdot
.57217 .41763 Mdot
.40545 .52884 Mdot
.51371 .72302 Mdot
.65343 .4139 Mdot
.39226 .55312 Mdot
.57127 .59205 Mdot
.54683 .65861 Mdot
.569 .39137 Mdot
.3653 .561 Mdot
.43077 .40533 Mdot
.59024 .39798 Mdot
.60807 .3567 Mdot
.43782 .54382 Mdot
.39777 .32863 Mdot
.44998 .55451 Mdot
.69347 .56391 Mdot
.54876 .82746 Mdot
.64293 .5535 Mdot
.62333 .3136 Mdot
.44801 .50374 Mdot
.60148 .64221 Mdot
.47946 .67395 Mdot
.33932 .28381 Mdot
.6769 .34567 Mdot
.44118 .51274 Mdot
.68048 .24143 Mdot
.68614 .49992 Mdot
.81475 .4759 Mdot
.46703 .19678 Mdot
.42024 .35773 Mdot
.65629 .54765 Mdot
.35077 .54363 Mdot
.68176 .51977 Mdot
.43989 .36665 Mdot
.68421 .76634 Mdot
.37272 .56761 Mdot
.51313 .6631 Mdot
.40147 .52529 Mdot
.51227 .65589 Mdot
.4375 .54006 Mdot
.38394 .60466 Mdot
.67389 .38211 Mdot
.25679 .49139 Mdot
.37777 .49175 Mdot
.28845 .25253 Mdot
.46074 .38909 Mdot
.44379 .33499 Mdot
.41487 .54186 Mdot
.57386 .42654 Mdot
.70124 .56431 Mdot
.74142 .63446 Mdot
.59768 .36412 Mdot
.65072 .57449 Mdot
.52339 .70186 Mdot
.57429 .37952 Mdot
.55199 .37925 Mdot
.3195 .55271 Mdot
.39897 .31816 Mdot
.64802 .52865 Mdot
.36971 .55182 Mdot
.37375 .56741 Mdot
.21592 .54244 Mdot
.58875 .28201 Mdot
.50716 .74301 Mdot
.16439 .55252 Mdot
.55044 .67845 Mdot
.44048 .33413 Mdot
.60109 .36121 Mdot
.3482 .52192 Mdot
.38783 .52822 Mdot
.71481 .40836 Mdot
.53534 .72034 Mdot
.5607 .52129 Mdot
.53498 .77267 Mdot
.60317 .44868 Mdot
.2738 .41314 Mdot
.52524 .67057 Mdot
.27401 .41559 Mdot
.45868 .33684 Mdot
.77911 .33513 Mdot
.26454 .46549 Mdot
.67797 .5651 Mdot
.27748 .41043 Mdot
.50123 .67168 Mdot
.42331 .50747 Mdot
.62082 .38332 Mdot
.58991 .41251 Mdot
.52073 .68574 Mdot
.6188 .41687 Mdot
.40812 .34905 Mdot
.35677 .5468 Mdot
.1965 .59159 Mdot
.67322 .67026 Mdot
.61077 .38679 Mdot
.41032 .61231 Mdot
.64238 .53901 Mdot
.43621 .55288 Mdot
.40799 .35367 Mdot
.67064 .55304 Mdot
.32476 .2818 Mdot
.68871 .60592 Mdot
.40525 .55495 Mdot
.30725 .26681 Mdot
.66162 .55372 Mdot
.35117 .44174 Mdot
.38533 .5553 Mdot
.69089 .57596 Mdot
.33387 .46136 Mdot
.74238 .48436 Mdot
.59266 .49893 Mdot
.5943 .1845 Mdot
.57908 .49853 Mdot
.61755 .38676 Mdot
.7586 .49199 Mdot
.6564 .47163 Mdot
.69184 .53669 Mdot
.58868 .42294 Mdot
.4278 .29423 Mdot
.6483 .56373 Mdot
.35371 .56764 Mdot
.36251 .51336 Mdot
.66242 .77132 Mdot
.66222 .48564 Mdot
.75752 .5274 Mdot
.70792 .67619 Mdot
.43214 .57255 Mdot
.44965 .56255 Mdot
.38554 .53179 Mdot
.48219 .69621 Mdot
.67744 .54342 Mdot
.24007 .3099 Mdot
.65806 .55949 Mdot
.2265 .62784 Mdot
.60805 .38037 Mdot
.5613 .38568 Mdot
.36443 .53261 Mdot
.44647 .42243 Mdot
.29419 .34175 Mdot
.39743 .52861 Mdot
.39513 .29316 Mdot
.72691 .69437 Mdot
.42759 .58324 Mdot
.48968 .70179 Mdot
.38505 .61101 Mdot
.37891 .61691 Mdot
.6876 .53911 Mdot
.41417 .34697 Mdot
.33209 .28836 Mdot
.66373 .5242 Mdot
.37709 .53927 Mdot
.61166 .64448 Mdot
.38027 .51452 Mdot
.41868 .50934 Mdot
.23529 .6685 Mdot
.45405 .33328 Mdot
.58733 .37331 Mdot
.42693 .33755 Mdot
.48327 .68091 Mdot
.10591 .5808 Mdot
.4128 .31771 Mdot
.29794 .33225 Mdot
.6432 .79144 Mdot
.27974 .41154 Mdot
.50929 .65056 Mdot
.39525 .31939 Mdot
.67022 .56423 Mdot
.72365 .255 Mdot
.38504 .79307 Mdot
.72779 .54952 Mdot
.39036 .54879 Mdot
.53681 .73001 Mdot
.53176 .66804 Mdot
.63382 .52978 Mdot
.49449 .66346 Mdot
.3655 .45237 Mdot
.42217 .50891 Mdot
.68871 .52749 Mdot
.62895 .66883 Mdot
.64551 .57387 Mdot
.65371 .61699 Mdot
.41009 .54004 Mdot
.52845 .6766 Mdot
.38724 .47555 Mdot
.54287 .65055 Mdot
.62245 .40682 Mdot
.38521 .59403 Mdot
.40691 .34645 Mdot
.6051 .66304 Mdot
.58094 .39408 Mdot
.44996 .27551 Mdot
.48309 .67193 Mdot
.61893 .57424 Mdot
.48524 .66201 Mdot
.50738 .63342 Mdot
.64316 .56577 Mdot
.50016 .69045 Mdot
.35328 .54626 Mdot
.55933 .45315 Mdot
.49299 .69521 Mdot
.65351 .53552 Mdot
.41818 .34763 Mdot
.51796 .70361 Mdot
.52309 .37659 Mdot
.40284 .56103 Mdot
.5857 .35888 Mdot
.49504 .21713 Mdot
.54719 .71376 Mdot
.44001 .31864 Mdot
.58763 .418 Mdot
.44977 .34138 Mdot
.82142 .57728 Mdot
.67353 .51074 Mdot
.24957 .65682 Mdot
.41099 .29781 Mdot
.54316 .68178 Mdot
.51258 .21505 Mdot
.35067 .52046 Mdot
.40533 .55981 Mdot
.39129 .34683 Mdot
.5322 .66861 Mdot
.80965 .3945 Mdot
.44369 .63103 Mdot
.626 .61218 Mdot
.63304 .51273 Mdot
.29779 .25996 Mdot
.68204 .61675 Mdot
.85561 .56286 Mdot
.44866 .51918 Mdot
.53985 .38715 Mdot
.37127 .52823 Mdot
.68194 .363 Mdot
.43393 .33323 Mdot
.59728 .32086 Mdot
.42626 .59686 Mdot
.58264 .37721 Mdot
.40017 .57079 Mdot
.50523 .4208 Mdot
.31001 .54715 Mdot
.4219 .36922 Mdot
.75972 .40501 Mdot
.54167 .67135 Mdot
.42876 .35421 Mdot
.57461 .35367 Mdot
.28565 .36985 Mdot
.4113 .50331 Mdot
.34664 .4797 Mdot
.60291 .4486 Mdot
.50671 .656 Mdot
.61757 .39758 Mdot
.69037 .54845 Mdot
.41136 .33688 Mdot
.42662 .55104 Mdot
.35717 .49795 Mdot
.72017 .43189 Mdot
.64098 .53799 Mdot
.56263 .41328 Mdot
.67339 .57319 Mdot
.56366 .35497 Mdot
.44174 .53852 Mdot
.56041 .39042 Mdot
.36232 .47926 Mdot
.67662 .39609 Mdot
.23501 .65739 Mdot
.36458 .70912 Mdot
.5672 .38034 Mdot
.25328 .4223 Mdot
.64519 .54729 Mdot
.68296 .57584 Mdot
.58174 .80516 Mdot
.29709 .72006 Mdot
.20158 .53336 Mdot
.60734 .22288 Mdot
.66608 .51761 Mdot
.64524 .53704 Mdot
.58123 .36014 Mdot
.49803 .68905 Mdot
.54362 .66344 Mdot
.5581 .35934 Mdot
.3659 .39722 Mdot
.50224 .66146 Mdot
.715 .2655 Mdot
.20533 .48112 Mdot
.34595 .49435 Mdot
.61394 .42655 Mdot
.41679 .33733 Mdot
.35449 .39148 Mdot
.50402 .4166 Mdot
.35489 .55353 Mdot
.36104 .269 Mdot
.60605 .38925 Mdot
.44989 .43851 Mdot
.54841 .18181 Mdot
.38336 .57497 Mdot
.38023 .55609 Mdot
.37899 .53316 Mdot
.41356 .3087 Mdot
.34766 .7619 Mdot
.36392 .55697 Mdot
.36664 .39939 Mdot
.43555 .56427 Mdot
.32953 .45999 Mdot
.42797 .34261 Mdot
.26948 .54189 Mdot
.62213 .2662 Mdot
.20128 .41583 Mdot
.30411 .53806 Mdot
.692 .55218 Mdot
.38378 .28787 Mdot
.67458 .57694 Mdot
.32971 .70126 Mdot
.26979 .46062 Mdot
.55308 .7041 Mdot
.35244 .54981 Mdot
.57167 .38517 Mdot
.52983 .66591 Mdot
.74077 .46207 Mdot
.08248 .52627 Mdot
.69366 .5548 Mdot
.88126 .53188 Mdot
.69126 .57278 Mdot
.55158 .37777 Mdot
.51911 .69371 Mdot
.4502 .73351 Mdot
.511 .53034 Mdot
.51871 .70593 Mdot
.75476 .34937 Mdot
.47079 .67738 Mdot
.26644 .40681 Mdot
.5354 .72579 Mdot
.6496 .53835 Mdot
.6154 .50731 Mdot
.45314 .49163 Mdot
.35368 .52469 Mdot
.52662 .49716 Mdot
.27731 .36288 Mdot
.35054 .52297 Mdot
.57523 .38915 Mdot
.25765 .66795 Mdot
.3513 .29508 Mdot
.50169 .68668 Mdot
.70868 .5714 Mdot
.38222 .56099 Mdot
.40915 .5093 Mdot
.41343 .50289 Mdot
.17546 .61531 Mdot
.78297 .3388 Mdot
.43193 .51658 Mdot
.43899 .56524 Mdot
.57801 .37902 Mdot
.45317 .31855 Mdot
.6754 .3242 Mdot
.25693 .59898 Mdot
.35514 .5618 Mdot
.43148 .35047 Mdot
.44643 .31802 Mdot
.39772 .49699 Mdot
.47603 .32012 Mdot
.60931 .63755 Mdot
.37005 .55311 Mdot
.26433 .67022 Mdot
.56697 .44609 Mdot
.5565 .40426 Mdot
.58358 .40234 Mdot
.51097 .64676 Mdot
.57007 .40499 Mdot
.57543 .35035 Mdot
.46704 .74229 Mdot
.56772 .50397 Mdot
.71162 .57217 Mdot
.42461 .32872 Mdot
.38627 .52409 Mdot
.46195 .65123 Mdot
.61537 .66647 Mdot
.65011 .56805 Mdot
.53919 .69969 Mdot
.70048 .57068 Mdot
.40559 .37565 Mdot
.4897 .53755 Mdot
.60593 .39717 Mdot
.66974 .52061 Mdot
.67268 .60587 Mdot
.43001 .34925 Mdot
.63744 .54464 Mdot
.66231 .60037 Mdot
.37996 .58938 Mdot
.40352 .75073 Mdot
.4002 .53354 Mdot
.81118 .43648 Mdot
.64404 .52805 Mdot
.66597 .43434 Mdot
.37449 .54584 Mdot
.59113 .39617 Mdot
.46377 .50955 Mdot
.35399 .51385 Mdot
.58 .40614 Mdot
.41545 .49908 Mdot
.45395 .34426 Mdot
.53777 .64669 Mdot
.50196 .51677 Mdot
.46026 .85746 Mdot
.39835 .31835 Mdot
.73968 .45458 Mdot
.34446 .53757 Mdot
.7848 .64691 Mdot
.51574 .70157 Mdot
.37624 .48148 Mdot
.3386 .30904 Mdot
.49632 .69633 Mdot
.53423 .69807 Mdot
.40947 .51426 Mdot
.67676 .56854 Mdot
.57674 .39421 Mdot
.42724 .34616 Mdot
.84634 .54322 Mdot
.39804 .54776 Mdot
.41374 .56459 Mdot
.43413 .35391 Mdot
.6424 .54543 Mdot
.38536 .49486 Mdot
.45665 .21765 Mdot
.82087 .3928 Mdot
.68143 .57949 Mdot
.3537 .56632 Mdot
.34984 .73659 Mdot
.40676 .62351 Mdot
.71882 .76499 Mdot
.46614 .30773 Mdot
.58048 .37273 Mdot
.39822 .46056 Mdot
.12265 .56673 Mdot
.41493 .34553 Mdot
.18807 .5136 Mdot
.4142 .51172 Mdot
.42684 .56252 Mdot
.54352 .69528 Mdot
.41442 .53348 Mdot
.51978 .72124 Mdot
.44933 .84684 Mdot
.29559 .28783 Mdot
.50125 .65147 Mdot
.54616 .68654 Mdot
.31738 .31761 Mdot
.67856 .33548 Mdot
.52211 .68888 Mdot
.44054 .54395 Mdot
.29167 .56248 Mdot
.47191 .58313 Mdot
.39259 .33834 Mdot
.57328 .23697 Mdot
.45833 .63449 Mdot
.38237 .33515 Mdot
.67474 .27044 Mdot
.45652 .64906 Mdot
.59136 .57071 Mdot
.68966 .55346 Mdot
.381 .57488 Mdot
.58631 .41348 Mdot
.57401 .41322 Mdot
.41156 .4842 Mdot
.38691 .5183 Mdot
.48281 .67726 Mdot
.4141 .32497 Mdot
.69564 .55143 Mdot
.42879 .55495 Mdot
.33305 .29999 Mdot
.41952 .31823 Mdot
.4927 .67386 Mdot
.2583 .63566 Mdot
.43955 .37123 Mdot
.37015 .59907 Mdot
.36284 .54208 Mdot
.40366 .52217 Mdot
.46831 .59944 Mdot
.68226 .54671 Mdot
.54951 .21877 Mdot
.39566 .58565 Mdot
.2395 .35545 Mdot
.69146 .51171 Mdot
.33455 .56016 Mdot
.4942 .65635 Mdot
.70483 .59035 Mdot
.6201 .35219 Mdot
.50638 .5634 Mdot
.40483 .5527 Mdot
.7995 .47044 Mdot
.68155 .75532 Mdot
.62191 .40486 Mdot
.50991 .63486 Mdot
.42032 .33384 Mdot
.39563 .52709 Mdot
.28366 .66173 Mdot
.36095 .51672 Mdot
.41102 .37159 Mdot
.61259 .35955 Mdot
.69 .55673 Mdot
.81535 .46409 Mdot
.57104 .41059 Mdot
.53281 .69355 Mdot
.42954 .14932 Mdot
.51558 .72121 Mdot
.53791 .65649 Mdot
.2765 .63819 Mdot
.6842 .54997 Mdot
.13442 .60134 Mdot
.49863 .8296 Mdot
.40957 .59404 Mdot
.64679 .55107 Mdot
.51839 .67761 Mdot
.42982 .56636 Mdot
.54693 .73015 Mdot
.50829 .6388 Mdot
.44275 .54709 Mdot
.41209 .57479 Mdot
.77466 .54552 Mdot
.58704 .18855 Mdot
.42093 .33259 Mdot
.47948 .65858 Mdot
.56405 .59074 Mdot
.42739 .57087 Mdot
.37007 .53781 Mdot
.6731 .47593 Mdot
.39607 .3365 Mdot
.71642 .63552 Mdot
.4114 .51025 Mdot
.31365 .27436 Mdot
.33942 .58193 Mdot
.47997 .68552 Mdot
.669 .57794 Mdot
.20556 .40933 Mdot
.62038 .51665 Mdot
.52292 .72074 Mdot
.40856 .3283 Mdot
.4782 .62498 Mdot
.29554 .33242 Mdot
.64216 .52198 Mdot
.53444 .67935 Mdot
.61049 .48858 Mdot
.67023 .5432 Mdot
.65581 .52076 Mdot
.27982 .63222 Mdot
.58929 .42545 Mdot
.41903 .30749 Mdot
.64585 .53129 Mdot
.57667 .64252 Mdot
.65596 .53958 Mdot
.52871 .81338 Mdot
.36274 .57141 Mdot
.36481 .36069 Mdot
.61819 .31625 Mdot
.42725 .46968 Mdot
.64578 .52302 Mdot
.41606 .3616 Mdot
.39883 .50121 Mdot
.49908 .66988 Mdot
.44222 .32848 Mdot
.73301 .57394 Mdot
.59008 .36279 Mdot
.48553 .66701 Mdot
.62086 .52658 Mdot
.51681 .65765 Mdot
.53956 .59833 Mdot
.61142 .81093 Mdot
.37976 .22517 Mdot
.5192 .54606 Mdot
.41453 .50491 Mdot
.6237 .24317 Mdot
.3342 .50579 Mdot
.38777 .5144 Mdot
.57047 .39043 Mdot
.35628 .33334 Mdot
.51584 .69008 Mdot
.81693 .41904 Mdot
.68147 .53183 Mdot
.20471 .39808 Mdot
.31138 .57679 Mdot
.39953 .49031 Mdot
.49501 .69925 Mdot
.52123 .72441 Mdot
.33238 .67755 Mdot
.61811 .347 Mdot
.34841 .49938 Mdot
.33239 .52912 Mdot
.42532 .49816 Mdot
.67325 .5282 Mdot
.44277 .27388 Mdot
.61656 .38678 Mdot
.67513 .78452 Mdot
.61621 .36478 Mdot
.384 .29877 Mdot
.49908 .6857 Mdot
.41213 .31828 Mdot
.36961 .53969 Mdot
.4851 .71579 Mdot
.53378 .7215 Mdot
.4031 .36189 Mdot
.43144 .36466 Mdot
.71141 .47553 Mdot
.68401 .56069 Mdot
.36235 .49596 Mdot
.36403 .55939 Mdot
.42038 .53625 Mdot
.3969 .51509 Mdot
.69108 .54418 Mdot
.38968 .50025 Mdot
.66617 .58841 Mdot
.5352 .61736 Mdot
.38795 .26597 Mdot
.57837 .49331 Mdot
.63163 .75459 Mdot
.50096 .67921 Mdot
.58193 .63828 Mdot
.45451 .61132 Mdot
.24551 .70057 Mdot
.74408 .67683 Mdot
.39828 .5893 Mdot
.55624 .38053 Mdot
.37242 .44171 Mdot
.60053 .40521 Mdot
.85774 .59861 Mdot
.70429 .43155 Mdot
.62821 .20803 Mdot
.37578 .56796 Mdot
.58142 .4583 Mdot
.5827 .69324 Mdot
.33673 .49658 Mdot
.71245 .45019 Mdot
.63638 .7442 Mdot
.77368 .42369 Mdot
.40385 .35025 Mdot
.39615 .55952 Mdot
.46277 .64994 Mdot
.35559 .5478 Mdot
.36934 .5315 Mdot
.40085 .50006 Mdot
.66032 .58169 Mdot
.35754 .49101 Mdot
.38643 .50415 Mdot
.49358 .30984 Mdot
.2671 .43809 Mdot
.57723 .41673 Mdot
.60941 .7967 Mdot
.41379 .3168 Mdot
.48689 .68524 Mdot
.7571 .32477 Mdot
.67843 .56438 Mdot
.33727 .67749 Mdot
.4 .51806 Mdot
.78225 .5171 Mdot
.69894 .59398 Mdot
.4085 .33843 Mdot
.61997 .35931 Mdot
.67181 .2248 Mdot
.57832 .38635 Mdot
.61657 .48962 Mdot
.59099 .39401 Mdot
.4562 .61451 Mdot
.48194 .67458 Mdot
.37231 .49393 Mdot
.65141 .52802 Mdot
.57032 .40105 Mdot
.32207 .37836 Mdot
.38364 .53072 Mdot
.58697 .38222 Mdot
.37186 .49417 Mdot
.48525 .51434 Mdot
.23469 .55535 Mdot
.56988 .35438 Mdot
.70147 .58898 Mdot
.66735 .53394 Mdot
.39874 .32731 Mdot
.48737 .6798 Mdot
.53683 .71013 Mdot
.66934 .55161 Mdot
.33369 .76451 Mdot
.34904 .5538 Mdot
.42231 .57345 Mdot
.2159 .38612 Mdot
.34727 .53461 Mdot
.27564 .38612 Mdot
.60203 .49323 Mdot
.49621 .67352 Mdot
.41923 .49764 Mdot
.41614 .51631 Mdot
.40549 .55629 Mdot
.51956 .59644 Mdot
.59732 .39885 Mdot
.37627 .57516 Mdot
.43743 .36302 Mdot
.50609 .37977 Mdot
.43642 .55277 Mdot
.313 .51356 Mdot
.53827 .70767 Mdot
.17039 .5626 Mdot
.69117 .57044 Mdot
.56829 .35822 Mdot
.56607 .37874 Mdot
.58915 .24506 Mdot
.60724 .70562 Mdot
.60096 .49162 Mdot
.70586 .76301 Mdot
.67341 .3819 Mdot
.44327 .343 Mdot
.63707 .39662 Mdot
.6187 .49859 Mdot
.57128 .36198 Mdot
.69397 .55389 Mdot
.36727 .57461 Mdot
.35658 .56399 Mdot
.23966 .7134 Mdot
.40183 .49696 Mdot
.42051 .33755 Mdot
.63579 .56535 Mdot
.50187 .67228 Mdot
.40902 .33647 Mdot
.67156 .57382 Mdot
.50234 .65402 Mdot
.38651 .58594 Mdot
.38389 .58415 Mdot
.53823 .70229 Mdot
.53598 .67688 Mdot
.36631 .54423 Mdot
.642 .31233 Mdot
.5408 .67523 Mdot
.52841 .67239 Mdot
.60944 .39333 Mdot
.587 .41214 Mdot
.32227 .54752 Mdot
.64919 .55044 Mdot
.38739 .5031 Mdot
.57385 .38154 Mdot
.40781 .32311 Mdot
.51301 .6892 Mdot
.42277 .51442 Mdot
.43301 .54431 Mdot
.42813 .34961 Mdot
.40185 .33451 Mdot
.41597 .35906 Mdot
.64971 .57841 Mdot
.41954 .54427 Mdot
.52367 .69687 Mdot
.68619 .55984 Mdot
.44154 .31415 Mdot
.39705 .34826 Mdot
.63669 .37825 Mdot
.34606 .52392 Mdot
.54301 .33069 Mdot
.10946 .53016 Mdot
.24421 .37077 Mdot
.62792 .38453 Mdot
.62781 .36641 Mdot
.29297 .41469 Mdot
.46482 .44034 Mdot
.66442 .55859 Mdot
.46831 .35421 Mdot
.32947 .28824 Mdot
.36388 .58037 Mdot
.43609 .57516 Mdot
.40242 .60591 Mdot
.42389 .3618 Mdot
.36089 .31113 Mdot
.50439 .71613 Mdot
.4334 .65081 Mdot
.4279 .31856 Mdot
.57155 .41726 Mdot
.63111 .40277 Mdot
.61538 .362 Mdot
.37345 .57854 Mdot
.37351 .7109 Mdot
.59561 .67028 Mdot
.56999 .20736 Mdot
.64121 .53013 Mdot
.46192 .64439 Mdot
.78376 .64259 Mdot
.53614 .70163 Mdot
.59596 .33816 Mdot
.44511 .34787 Mdot
.53225 .6722 Mdot
.70267 .57159 Mdot
.64625 .53413 Mdot
.61185 .3845 Mdot
.61108 .37679 Mdot
.59325 .35397 Mdot
.51778 .63818 Mdot
.49933 .68806 Mdot
.40652 .55053 Mdot
.50904 .68749 Mdot
.21657 .67051 Mdot
.3876 .32916 Mdot
.54763 .34681 Mdot
.65493 .54968 Mdot
.50598 .65234 Mdot
.38683 .53123 Mdot
.46646 .45293 Mdot
.68231 .70072 Mdot
.44892 .34793 Mdot
.2229 .54609 Mdot
.84999 .60774 Mdot
.35981 .49714 Mdot
.67822 .53931 Mdot
.19584 .58451 Mdot
.38151 .53492 Mdot
.60616 .36292 Mdot
.66325 .3107 Mdot
.59527 .44389 Mdot
.35541 .51024 Mdot
.35659 .57686 Mdot
.68811 .58008 Mdot
.69797 .76162 Mdot
.40331 .54759 Mdot
.6977 .64216 Mdot
.69039 .52292 Mdot
.61822 .38145 Mdot
.79747 .32799 Mdot
.46766 .22978 Mdot
.36103 .3918 Mdot
.61393 .38674 Mdot
.37437 .5105 Mdot
.5991 .40342 Mdot
.44706 .35484 Mdot
.59743 .34577 Mdot
.50606 .71887 Mdot
.62105 .40222 Mdot
.41375 .56532 Mdot
.52259 .68647 Mdot
.66099 .55457 Mdot
.19215 .45004 Mdot
.55189 .30734 Mdot
.59321 .39545 Mdot
.55941 .36309 Mdot
.41735 .49781 Mdot
.72956 .61592 Mdot
.39772 .47447 Mdot
.39684 .57812 Mdot
.66044 .51635 Mdot
.4928 .69211 Mdot
.66524 .57938 Mdot
.32712 .49841 Mdot
.44981 .21328 Mdot
.6765 .5731 Mdot
.79215 .46563 Mdot
.43916 .35077 Mdot
.51737 .44739 Mdot
.38894 .52699 Mdot
.64062 .55438 Mdot
.4179 .54434 Mdot
.49724 .70864 Mdot
.56687 .46883 Mdot
.76217 .42423 Mdot
.66043 .52551 Mdot
.80486 .4666 Mdot
.37412 .31371 Mdot
.32653 .48454 Mdot
.6804 .57715 Mdot
.34451 .30681 Mdot
.55157 .37962 Mdot
.43367 .32336 Mdot
.45207 .35942 Mdot
.44256 .32604 Mdot
.43074 .49353 Mdot
.30282 .54938 Mdot
.45229 .32978 Mdot
.70173 .55895 Mdot
.42314 .3693 Mdot
.58126 .74978 Mdot
.80882 .41007 Mdot
.43535 .33622 Mdot
.38782 .55337 Mdot
.40768 .6171 Mdot
.27725 .43301 Mdot
.74149 .49061 Mdot
.648 .21868 Mdot
.73959 .65194 Mdot
.35505 .52305 Mdot
.54307 .65549 Mdot
.49085 .64614 Mdot
.18818 .55631 Mdot
.26478 .3805 Mdot
.2671 .32724 Mdot
.546 .67751 Mdot
.72815 .39924 Mdot
.49017 .67218 Mdot
.40842 .49961 Mdot
.42572 .57052 Mdot
.54861 .68423 Mdot
.38732 .26058 Mdot
.74327 .42605 Mdot
.83036 .49874 Mdot
.52259 .663 Mdot
.66171 .57239 Mdot
.63059 .53408 Mdot
.65446 .52011 Mdot
.20249 .4982 Mdot
.50644 .71043 Mdot
.42646 .53963 Mdot
.56697 .38174 Mdot
.36781 .57047 Mdot
.67431 .54596 Mdot
.8172 .41396 Mdot
.51302 .70787 Mdot
.37624 .56264 Mdot
.42112 .44654 Mdot
.6037 .36809 Mdot
.43584 .34797 Mdot
.47592 .49853 Mdot
.26554 .33324 Mdot
.67371 .5254 Mdot
.54918 .70745 Mdot
.67997 .42212 Mdot
.79506 .42196 Mdot
.45429 .53056 Mdot
.33084 .52406 Mdot
.84863 .55623 Mdot
.31596 .28491 Mdot
.34224 .51769 Mdot
.56037 .3661 Mdot
.71024 .40868 Mdot
.43302 .53622 Mdot
.48431 .6483 Mdot
.44576 .36798 Mdot
.44883 .33973 Mdot
.31795 .53625 Mdot
.50019 .49706 Mdot
.56775 .45944 Mdot
.4081 .51817 Mdot
.37509 .60159 Mdot
.6172 .38242 Mdot
.67338 .36315 Mdot
.24374 .34926 Mdot
.40625 .32976 Mdot
.375 .49417 Mdot
.71715 .32401 Mdot
.5437 .70621 Mdot
.62486 .39795 Mdot
.63674 .53309 Mdot
.49987 .58823 Mdot
.61857 .35665 Mdot
.43329 .528 Mdot
.39229 .49633 Mdot
.63831 .55887 Mdot
.48092 .68871 Mdot
.42802 .36162 Mdot
.56324 .38567 Mdot
.40259 .34109 Mdot
.49884 .7 Mdot
.50672 .69161 Mdot
.39526 .44329 Mdot
.46053 .56056 Mdot
.58045 .40193 Mdot
.36405 .47788 Mdot
.55431 .43683 Mdot
.75866 .72132 Mdot
.62626 .52266 Mdot
.35121 .50425 Mdot
.49562 .71786 Mdot
.66663 .5257 Mdot
.42247 .56918 Mdot
.85426 .53425 Mdot
.43016 .56964 Mdot
.69038 .51303 Mdot
.36742 .22303 Mdot
.40787 .35167 Mdot
.43052 .64637 Mdot
.7755 .58954 Mdot
.35003 .5366 Mdot
.56892 .36984 Mdot
.41897 .61171 Mdot
.672 .56734 Mdot
.50099 .6865 Mdot
.73487 .75601 Mdot
.65721 .53681 Mdot
.36118 .55028 Mdot
.41053 .33679 Mdot
.53136 .72562 Mdot
.42455 .28558 Mdot
.47457 .31728 Mdot
.30807 .51283 Mdot
.37211 .47711 Mdot
.39902 .51037 Mdot
.49409 .20507 Mdot
.57168 .3566 Mdot
.51985 .67022 Mdot
.67808 .53743 Mdot
.66928 .55462 Mdot
.60812 .38863 Mdot
.69866 .60372 Mdot
.51979 .44935 Mdot
.13015 .48375 Mdot
.58326 .40786 Mdot
.43244 .31628 Mdot
.71622 .63002 Mdot
.56154 .37659 Mdot
.5916 .38197 Mdot
.61028 .39426 Mdot
.60027 .5438 Mdot
.50428 .65648 Mdot
.43495 .532 Mdot
.47707 .66035 Mdot
.37591 .50895 Mdot
.69401 .51531 Mdot
.65492 .52528 Mdot
.50783 .70419 Mdot
.83635 .5644 Mdot
.40085 .76671 Mdot
.38301 .54339 Mdot
.7851 .6442 Mdot
.43842 .58939 Mdot
.29252 .39217 Mdot
.43859 .59463 Mdot
.60263 .38801 Mdot
.37431 .46683 Mdot
.42596 .49747 Mdot
.17929 .52438 Mdot
.65405 .55189 Mdot
.55371 .39909 Mdot
.40463 .5985 Mdot
.3745 .6036 Mdot
.52499 .64147 Mdot
.53059 .67129 Mdot
.45315 .3513 Mdot
.25457 .5016 Mdot
.65987 .55666 Mdot
.49432 .81945 Mdot
.3547 .52815 Mdot
.4192 .25526 Mdot
.34587 .63285 Mdot
.41927 .57104 Mdot
.78418 .59017 Mdot
.36466 .70204 Mdot
.39358 .52696 Mdot
.55467 .55475 Mdot
.64337 .54403 Mdot
.43332 .21454 Mdot
.43809 .55857 Mdot
.60065 .36388 Mdot
.49525 .68303 Mdot
.51752 .7257 Mdot
.45415 .33903 Mdot
.28453 .74562 Mdot
.65791 .57717 Mdot
.50349 .69575 Mdot
.37911 .52621 Mdot
.68257 .54336 Mdot
.57065 .40708 Mdot
.39244 .48838 Mdot
.25829 .39231 Mdot
.50655 .67978 Mdot
.43342 .51236 Mdot
.67204 .64537 Mdot
.31639 .42011 Mdot
.42363 .17582 Mdot
.67823 .5358 Mdot
.39813 .33348 Mdot
.40558 .60993 Mdot
.3167 .74496 Mdot
.45088 .56438 Mdot
.3744 .37415 Mdot
.58537 .75116 Mdot
.39777 .33973 Mdot
.37787 .54902 Mdot
.42728 .54816 Mdot
.46068 .40752 Mdot
.40821 .32597 Mdot
.36965 .56557 Mdot
.54441 .63794 Mdot
.50968 .65844 Mdot
.57681 .34528 Mdot
.50282 .66777 Mdot
.38963 .54886 Mdot
.45958 .57032 Mdot
.54214 .68904 Mdot
.78792 .67087 Mdot
.39687 .30727 Mdot
.68894 .57073 Mdot
.4403 .57883 Mdot
.40638 .58483 Mdot
.24405 .28839 Mdot
.6147 .41495 Mdot
.68986 .33576 Mdot
.47729 .26532 Mdot
.68955 .2918 Mdot
.46523 .22963 Mdot
.5308 .16281 Mdot
.31969 .27737 Mdot
.3615 .48693 Mdot
.3654 .62062 Mdot
.58601 .61631 Mdot
.64041 .5284 Mdot
.52153 .78911 Mdot
.35346 .52424 Mdot
.36964 .52915 Mdot
.62847 .39023 Mdot
.78613 .47803 Mdot
.2659 .32734 Mdot
.4746 .45867 Mdot
.42805 .3607 Mdot
.48026 .65663 Mdot
.43746 .53625 Mdot
.56145 .5357 Mdot
.58074 .4181 Mdot
.41086 .25513 Mdot
.37674 .56096 Mdot
.24027 .68067 Mdot
.66041 .70789 Mdot
.68277 .55306 Mdot
.5659 .37631 Mdot
.28331 .31169 Mdot
.34771 .52068 Mdot
.63512 .53545 Mdot
.39748 .54283 Mdot
.6579 .36718 Mdot
.33096 .49262 Mdot
.4355 .33101 Mdot
.41359 .50965 Mdot
.37969 .30069 Mdot
.37869 .15655 Mdot
.45768 .37056 Mdot
.5448 .72952 Mdot
.53836 .36289 Mdot
.59259 .40128 Mdot
.53471 .67671 Mdot
.58884 .40144 Mdot
.33162 .65986 Mdot
.43996 .70349 Mdot
.43701 .35546 Mdot
.3512 .58793 Mdot
.4324 .33769 Mdot
.62355 .40394 Mdot
.35417 .51815 Mdot
.80463 .67172 Mdot
.57242 .39828 Mdot
.33089 .24278 Mdot
.65825 .54183 Mdot
.57361 .41785 Mdot
.436 .56284 Mdot
.67223 .43468 Mdot
.57088 .41106 Mdot
.76399 .43826 Mdot
.40575 .55555 Mdot
.504 .68228 Mdot
.43168 .53627 Mdot
.42135 .59061 Mdot
.54248 .39648 Mdot
.37445 .50388 Mdot
.67063 .57349 Mdot
.53647 .65993 Mdot
.71873 .25933 Mdot
.61645 .75371 Mdot
.35764 .55546 Mdot
.37943 .52862 Mdot
.48826 .62841 Mdot
.38537 .57992 Mdot
.69111 .54462 Mdot
.33839 .85088 Mdot
.43898 .3505 Mdot
.5448 .38375 Mdot
.4648 .22832 Mdot
.39079 .58834 Mdot
.39491 .50074 Mdot
.85654 .51228 Mdot
.43462 .22391 Mdot
.67701 .57628 Mdot
.43458 .5062 Mdot
.56953 .40786 Mdot
.41312 .33583 Mdot
.69801 .54743 Mdot
.40437 .52365 Mdot
.37217 .54261 Mdot
.40017 .32741 Mdot
.28069 .53584 Mdot
.21114 .45272 Mdot
.63707 .55207 Mdot
.4092 .4685 Mdot
.5261 .37663 Mdot
.3417 .5392 Mdot
.20321 .52045 Mdot
.53298 .67966 Mdot
.67279 .52351 Mdot
.63309 .25746 Mdot
.34832 .51246 Mdot
.66174 .57545 Mdot
.65851 .55622 Mdot
.44041 .5165 Mdot
.49694 .72055 Mdot
.52136 .64586 Mdot
.51413 .65519 Mdot
.2472 .73837 Mdot
.34391 .38672 Mdot
.59345 .35401 Mdot
.64293 .54412 Mdot
.56862 .35363 Mdot
.38928 .35216 Mdot
.59508 .50448 Mdot
.56386 .35841 Mdot
.51505 .65096 Mdot
.54621 .35352 Mdot
.42009 .5541 Mdot
.6623 .55579 Mdot
.57571 .35955 Mdot
.40204 .59426 Mdot
.72801 .60749 Mdot
.75368 .55155 Mdot
.40585 .35832 Mdot
.4521 .36218 Mdot
.43234 .56072 Mdot
.61332 .34172 Mdot
.36627 .5419 Mdot
.66272 .5138 Mdot
.72044 .61999 Mdot
.44083 .57614 Mdot
.59494 .39566 Mdot
.48446 .62354 Mdot
.27299 .32472 Mdot
.38754 .47034 Mdot
.38656 .55291 Mdot
.37273 .50703 Mdot
.39801 .54274 Mdot
.7766 .40607 Mdot
.64068 .50972 Mdot
.63069 .75382 Mdot
.52859 .215 Mdot
.51949 .70949 Mdot
.47844 .64144 Mdot
.2364 .37851 Mdot
.60792 .62815 Mdot
.64775 .54928 Mdot
.39094 .5146 Mdot
.62382 .69067 Mdot
.81822 .3906 Mdot
.84488 .58964 Mdot
.44772 .40423 Mdot
.59642 .42219 Mdot
.54987 .69675 Mdot
.5584 .39325 Mdot
.36823 .5119 Mdot
.39609 .60698 Mdot
.50832 .15236 Mdot
.70133 .54637 Mdot
.44028 .3541 Mdot
.3787 .50767 Mdot
.34651 .39073 Mdot
.57604 .37882 Mdot
.55166 .40988 Mdot
.38578 .5767 Mdot
.47407 .66859 Mdot
.32256 .21314 Mdot
.68153 .5453 Mdot
.74012 .64622 Mdot
.58291 .70218 Mdot
.71246 .67774 Mdot
.67663 .54582 Mdot
.47271 .37401 Mdot
.62678 .38762 Mdot
.29038 .60481 Mdot
.52257 .71188 Mdot
.44292 .3304 Mdot
.33301 .55654 Mdot
.54174 .70389 Mdot
.62019 .37559 Mdot
.50242 .685 Mdot
.40298 .50077 Mdot
.67819 .51314 Mdot
.57931 .37139 Mdot
.71197 .571 Mdot
.48211 .69762 Mdot
.40777 .33027 Mdot
.49682 .46325 Mdot
.47512 .7781 Mdot
.36052 .69776 Mdot
.37423 .57543 Mdot
.56572 .54027 Mdot
.42485 .53789 Mdot
.49361 .63817 Mdot
.38972 .53483 Mdot
.54166 .75771 Mdot
.56951 .37062 Mdot
.43897 .56442 Mdot
.40488 .51584 Mdot
.56406 .79373 Mdot
.38536 .5665 Mdot
.35802 .48327 Mdot
.39452 .52417 Mdot
.53279 .74702 Mdot
.35023 .58893 Mdot
.49371 .65475 Mdot
.50019 .34382 Mdot
.59477 .38132 Mdot
.43979 .36903 Mdot
.40162 .31791 Mdot
.35814 .35487 Mdot
.58795 .26294 Mdot
.78161 .49835 Mdot
.50682 .66806 Mdot
.66186 .56698 Mdot
.39395 .53722 Mdot
.54302 .18377 Mdot
.56899 .44835 Mdot
.59321 .4174 Mdot
.61895 .75252 Mdot
.41769 .4685 Mdot
.45014 .19792 Mdot
.41581 .49282 Mdot
.25673 .73606 Mdot
.46305 .53736 Mdot
.33369 .4909 Mdot
.54976 .37011 Mdot
.38942 .35738 Mdot
.3991 .58138 Mdot
.53182 .64747 Mdot
.43051 .32454 Mdot
.33687 .6034 Mdot
.521 .35373 Mdot
.50493 .34757 Mdot
.50797 .77016 Mdot
.4123 .54576 Mdot
.58091 .37089 Mdot
.48482 .66756 Mdot
.24942 .34232 Mdot
.68697 .5604 Mdot
.71669 .55193 Mdot
.57006 .59912 Mdot
.79501 .64375 Mdot
.41918 .31785 Mdot
.27487 .59829 Mdot
.41616 .56402 Mdot
.60503 .30341 Mdot
.44329 .57074 Mdot
.81683 .40896 Mdot
.41885 .31369 Mdot
.51994 .65043 Mdot
.65862 .57011 Mdot
.48123 .64896 Mdot
.35368 .70041 Mdot
.61047 .42938 Mdot
.5532 .49076 Mdot
.5812 .38564 Mdot
.50291 .40918 Mdot
.52181 .67921 Mdot
.3732 .49568 Mdot
.12842 .48368 Mdot
.5303 .67488 Mdot
.53801 .72212 Mdot
.65306 .78867 Mdot
.77877 .70413 Mdot
.37954 .46341 Mdot
.54433 .68117 Mdot
.5861 .38744 Mdot
.41929 .33014 Mdot
.42807 .52426 Mdot
.41398 .55121 Mdot
.54126 .70277 Mdot
.54389 .39553 Mdot
.32595 .72676 Mdot
.60958 .37916 Mdot
.5059 .65482 Mdot
.59941 .37361 Mdot
.66831 .4286 Mdot
.56015 .37087 Mdot
.40413 .58478 Mdot
.39088 .53538 Mdot
.54114 .24393 Mdot
.50655 .69057 Mdot
.40987 .51947 Mdot
.413 .49619 Mdot
.52223 .69376 Mdot
.47603 .33142 Mdot
.32725 .72115 Mdot
.34809 .5455 Mdot
.39842 .56214 Mdot
.39817 .33863 Mdot
.58492 .53439 Mdot
.24699 .57249 Mdot
.39944 .50171 Mdot
.41147 .30978 Mdot
.53054 .64737 Mdot
.36856 .55137 Mdot
.78186 .3496 Mdot
.71235 .40802 Mdot
.35486 .50587 Mdot
.5518 .38066 Mdot
.42483 .49709 Mdot
.40857 .18091 Mdot
.39786 .57851 Mdot
.51764 .68367 Mdot
.49741 .69315 Mdot
.50161 .82028 Mdot
.53167 .69017 Mdot
.58951 .41251 Mdot
.67204 .54454 Mdot
.8115 .44331 Mdot
.56937 .40585 Mdot
.45498 .52036 Mdot
.51197 .83375 Mdot
.38025 .48795 Mdot
.4079 .59012 Mdot
.34981 .21156 Mdot
.56358 .39617 Mdot
.49684 .70402 Mdot
.47336 .43761 Mdot
.45929 .5834 Mdot
.66917 .52186 Mdot
.33366 .56107 Mdot
.35718 .56927 Mdot
.35954 .22561 Mdot
.74454 .37305 Mdot
.64229 .51752 Mdot
.34491 .50077 Mdot
.39846 .50125 Mdot
.57782 .42742 Mdot
.38402 .52768 Mdot
.4226 .3288 Mdot
.50148 .70589 Mdot
.55859 .37851 Mdot
.42486 .351 Mdot
.35015 .52969 Mdot
.42017 .36045 Mdot
.58635 .35854 Mdot
.64015 .52264 Mdot
.36056 .5128 Mdot
.39286 .34018 Mdot
.42232 .36038 Mdot
.42283 .53372 Mdot
.49919 .68318 Mdot
.46211 .52492 Mdot
.37886 .56656 Mdot
.42083 .51231 Mdot
.53472 .71279 Mdot
.87926 .43076 Mdot
.42089 .57517 Mdot
.37575 .35861 Mdot
.5288 .72246 Mdot
.49398 .38437 Mdot
.55502 .39218 Mdot
.36108 .5724 Mdot
.64258 .51951 Mdot
.63959 .54605 Mdot
.61967 .36987 Mdot
.54163 .72316 Mdot
.47992 .25678 Mdot
.46901 .62457 Mdot
.45044 .59054 Mdot
.33666 .5225 Mdot
.42024 .80414 Mdot
.62506 .20287 Mdot
.48523 .68947 Mdot
.59599 .31622 Mdot
.49085 .48192 Mdot
.64373 .5568 Mdot
.56919 .4162 Mdot
.5507 .70035 Mdot
.51594 .71971 Mdot
.49721 .67182 Mdot
.44721 .33923 Mdot
.54661 .24537 Mdot
.49139 .70787 Mdot
.47339 .64936 Mdot
.40989 .55595 Mdot
.39901 .50257 Mdot
.2797 .32823 Mdot
.24159 .44356 Mdot
.42003 .36447 Mdot
.61592 .37039 Mdot
.20991 .70937 Mdot
.66895 .51575 Mdot
.5987 .78698 Mdot
.4256 .58466 Mdot
.0963 .54852 Mdot
.43804 .55088 Mdot
.38056 .52432 Mdot
.53731 .66064 Mdot
.39698 .35006 Mdot
.43662 .34137 Mdot
.52204 .67076 Mdot
.47659 .63991 Mdot
.42396 .32912 Mdot
.77384 .62524 Mdot
.79961 .35907 Mdot
.62647 .42307 Mdot
.51949 .69876 Mdot
.47153 .7669 Mdot
.63488 .55122 Mdot
.37069 .61402 Mdot
.6713 .51382 Mdot
.58353 .37993 Mdot
.62247 .36157 Mdot
.66971 .52466 Mdot
.40427 .5544 Mdot
.58736 .35281 Mdot
.36135 .48897 Mdot
.72762 .68516 Mdot
.37992 .73595 Mdot
.49521 .23643 Mdot
.30953 .53334 Mdot
.48509 .36357 Mdot
.70044 .6004 Mdot
.35737 .54178 Mdot
.72032 .30942 Mdot
.43519 .35865 Mdot
.37589 .61079 Mdot
.67549 .52249 Mdot
.38816 .1788 Mdot
.35749 .51162 Mdot
.51549 .6842 Mdot
.6532 .55511 Mdot
.49954 .56343 Mdot
.6994 .63782 Mdot
.37448 .50785 Mdot
.1159 .53506 Mdot
.53349 .74364 Mdot
.56265 .37261 Mdot
.30459 .74596 Mdot
.48349 .68984 Mdot
.4305 .40307 Mdot
.57464 .23085 Mdot
.824 .59218 Mdot
.4859 .68333 Mdot
.60401 .42317 Mdot
.50068 .64919 Mdot
.4093 .32834 Mdot
.55528 .69672 Mdot
.57201 .3756 Mdot
.3788 .55898 Mdot
.6044 .39054 Mdot
.44973 .35747 Mdot
.21417 .45649 Mdot
.64032 .51934 Mdot
.55256 .3962 Mdot
.65791 .52897 Mdot
.29758 .44376 Mdot
.48796 .20906 Mdot
.69059 .56015 Mdot
.25984 .65283 Mdot
.33702 .53112 Mdot
.48073 .68593 Mdot
.60467 .39496 Mdot
.63941 .28378 Mdot
.4926 .46223 Mdot
.52883 .70957 Mdot
.60798 .35922 Mdot
.57435 .59709 Mdot
.27076 .69758 Mdot
.37344 .47443 Mdot
.26952 .4719 Mdot
.52283 .69949 Mdot
.62128 .41076 Mdot
.21127 .39257 Mdot
.50328 .64558 Mdot
.58714 .40778 Mdot
.65907 .5719 Mdot
.67265 .55479 Mdot
.37542 .57181 Mdot
.70894 .55214 Mdot
.60825 .35301 Mdot
.7259 .59013 Mdot
.54733 .6887 Mdot
.50785 .58403 Mdot
.38987 .33256 Mdot
.6008 .38232 Mdot
.40111 .49609 Mdot
.56152 .70173 Mdot
.69338 .40449 Mdot
.35064 .749 Mdot
.16184 .55029 Mdot
.60819 .38831 Mdot
.5102 .71387 Mdot
.51345 .68474 Mdot
.40255 .47325 Mdot
.51619 .54179 Mdot
.48619 .25579 Mdot
.42637 .43238 Mdot
.45273 .44359 Mdot
.58527 .34135 Mdot
.57101 .43802 Mdot
.39769 .59853 Mdot
.40784 .54226 Mdot
.64703 .56018 Mdot
.3825 .55959 Mdot
.53686 .66447 Mdot
.38064 .5762 Mdot
.67626 .53696 Mdot
.57612 .38818 Mdot
.3582 .51636 Mdot
.40874 .35385 Mdot
.63112 .54638 Mdot
.70016 .57677 Mdot
.5983 .38918 Mdot
.54073 .7067 Mdot
.45573 .29896 Mdot
.61149 .37601 Mdot
.41156 .54618 Mdot
.59162 .54424 Mdot
.41354 .50308 Mdot
.43901 .64461 Mdot
.5023 .64488 Mdot
.55922 .38336 Mdot
.5473 .67739 Mdot
.65302 .5329 Mdot
.5394 .21646 Mdot
.38909 .54336 Mdot
.58088 .40829 Mdot
.66344 .3398 Mdot
.32314 .6081 Mdot
.4728 .63679 Mdot
.7646 .54483 Mdot
.48271 .63957 Mdot
.61991 .38309 Mdot
.57705 .80781 Mdot
.43161 .32093 Mdot
.59214 .41785 Mdot
.69212 .24209 Mdot
.58063 .39944 Mdot
.39422 .57143 Mdot
.43106 .56045 Mdot
.55947 .37533 Mdot
.39838 .32731 Mdot
.2829 .30149 Mdot
.56904 .34475 Mdot
.49331 .69829 Mdot
.72771 .69915 Mdot
.16237 .46589 Mdot
.63962 .49941 Mdot
.65203 .5632 Mdot
.46599 .56045 Mdot
.34503 .48444 Mdot
.68658 .5271 Mdot
.7051 .57473 Mdot
.45119 .34075 Mdot
.60572 .40018 Mdot
.54518 .74878 Mdot
.68332 .58905 Mdot
.47478 .53263 Mdot
.57573 .25986 Mdot
.37598 .47137 Mdot
.58755 .7002 Mdot
.43641 .5754 Mdot
.39896 .40116 Mdot
.67695 .53624 Mdot
.43108 .51307 Mdot
.4126 .48384 Mdot
.65379 .51644 Mdot
.4194 .32805 Mdot
.6169 .59789 Mdot
.59383 .37072 Mdot
.82369 .35828 Mdot
.38091 .48004 Mdot
.39736 .57342 Mdot
.6425 .52778 Mdot
.49166 .29416 Mdot
.51376 .71007 Mdot
.4875 .64408 Mdot
.56968 .35805 Mdot
.50852 .49122 Mdot
.35724 .56574 Mdot
.36462 .55196 Mdot
.58647 .36707 Mdot
.56846 .41429 Mdot
.75928 .49091 Mdot
.42692 .55537 Mdot
.65231 .54811 Mdot
.3864 .29264 Mdot
.67567 .53379 Mdot
.40922 .5007 Mdot
.40414 .57232 Mdot
.40204 .58472 Mdot
.40109 .49668 Mdot
.70572 .56198 Mdot
.43673 .52762 Mdot
.37201 .60589 Mdot
.51753 .71491 Mdot
.38614 .50548 Mdot
.44847 .44032 Mdot
.39024 .55776 Mdot
.42082 .33006 Mdot
.25399 .59424 Mdot
.35775 .51193 Mdot
.3636 .5725 Mdot
.54304 .36835 Mdot
.37797 .54338 Mdot
.66563 .51435 Mdot
.51185 .69847 Mdot
.64305 .54256 Mdot
.63786 .54185 Mdot
.61185 .34652 Mdot
.45269 .33161 Mdot
.38603 .5874 Mdot
.44736 .34942 Mdot
.45467 .52537 Mdot
.34842 .51133 Mdot
.55729 .22955 Mdot
.26943 .74943 Mdot
.20172 .48377 Mdot
.39079 .54447 Mdot
.5669 .39706 Mdot
.55594 .39025 Mdot
.31462 .58911 Mdot
.37985 .47383 Mdot
.69459 .54926 Mdot
.64018 .55083 Mdot
.26061 .39629 Mdot
.39148 .22319 Mdot
.42052 .32947 Mdot
.57491 .51921 Mdot
.34782 .50142 Mdot
.4185 .50264 Mdot
.38668 .48612 Mdot
.57169 .35269 Mdot
.42435 .41462 Mdot
.58684 .41704 Mdot
.6667 .71187 Mdot
.66157 .52294 Mdot
.36478 .50778 Mdot
.59962 .7229 Mdot
.52711 .66512 Mdot
.51131 .69736 Mdot
.69817 .5771 Mdot
.53691 .41073 Mdot
.25368 .36286 Mdot
.84463 .60613 Mdot
.53384 .73909 Mdot
.41452 .3666 Mdot
.35534 .5439 Mdot
.58053 .39247 Mdot
.50868 .65101 Mdot
.42141 .36823 Mdot
.36743 .49646 Mdot
.54813 .24527 Mdot
.39619 .54745 Mdot
.58918 .63131 Mdot
.49217 .67543 Mdot
.81486 .39812 Mdot
.53525 .72922 Mdot
.63047 .5464 Mdot
.68111 .52979 Mdot
.4227 .56805 Mdot
.37274 .79083 Mdot
.47605 .65882 Mdot
.60386 .54859 Mdot
.4314 .31601 Mdot
.69006 .42013 Mdot
.41319 .32601 Mdot
.56493 .37211 Mdot
.42722 .32207 Mdot
.57106 .37348 Mdot
.23805 .42405 Mdot
.51545 .74759 Mdot
.43116 .35377 Mdot
.65441 .34224 Mdot
.35531 .47479 Mdot
.41303 .36141 Mdot
.42751 .60218 Mdot
.42293 .64124 Mdot
.59044 .36603 Mdot
.41798 .31615 Mdot
.37624 .49495 Mdot
.5071 .16361 Mdot
.68287 .57585 Mdot
.69243 .54282 Mdot
.4389 .59668 Mdot
.59728 .33898 Mdot
.54252 .66154 Mdot
.78976 .39599 Mdot
.62892 .55662 Mdot
.42274 .57208 Mdot
.39374 .58079 Mdot
.47747 .64255 Mdot
.57991 .76163 Mdot
.41608 .56989 Mdot
.4194 .45039 Mdot
.42762 .55737 Mdot
.68767 .57872 Mdot
.4806 .65075 Mdot
.51266 .69015 Mdot
.60473 .35624 Mdot
.54027 .67986 Mdot
.29534 .56993 Mdot
.61538 .71607 Mdot
.42514 .46385 Mdot
.65837 .53522 Mdot
.64396 .71626 Mdot
.66443 .71539 Mdot
.64859 .22129 Mdot
.46996 .65951 Mdot
.44292 .56847 Mdot
.54414 .70572 Mdot
.41377 .33357 Mdot
.50489 .68108 Mdot
.54971 .69407 Mdot
.36307 .54067 Mdot
.37469 .51067 Mdot
.56789 .38506 Mdot
.50841 .52517 Mdot
.53685 .71619 Mdot
.43714 .54672 Mdot
.33983 .48916 Mdot
.37237 .48489 Mdot
.62156 .47378 Mdot
.48106 .67803 Mdot
.71008 .74751 Mdot
.32525 .32569 Mdot
.53749 .71506 Mdot
.33858 .19914 Mdot
.67294 .35179 Mdot
.63267 .37395 Mdot
.71206 .58396 Mdot
.42935 .55224 Mdot
.56389 .40725 Mdot
.36735 .51204 Mdot
.5882 .69742 Mdot
.37136 .53763 Mdot
.42392 .32746 Mdot
.36227 .4863 Mdot
.62196 .36755 Mdot
.61047 .38116 Mdot
.41108 .57712 Mdot
.3596 .51842 Mdot
.22156 .43013 Mdot
.46968 .67217 Mdot
.5065 .69719 Mdot
.47078 .26264 Mdot
.41864 .35421 Mdot
.67151 .52309 Mdot
.39105 .52835 Mdot
.60301 .34307 Mdot
.60953 .38409 Mdot
.48012 .67854 Mdot
.60462 .36333 Mdot
.68109 .54586 Mdot
.38724 .53944 Mdot
.68751 .52917 Mdot
.44774 .33808 Mdot
.47936 .66034 Mdot
.38076 .50632 Mdot
.40954 .55617 Mdot
.49716 .69297 Mdot
.39063 .59469 Mdot
.39847 .33606 Mdot
.58318 .40085 Mdot
.48342 .67452 Mdot
.6723 .54731 Mdot
.56595 .37327 Mdot
.42589 .51616 Mdot
.18211 .65247 Mdot
.39462 .56927 Mdot
.43206 .54297 Mdot
.6821 .22744 Mdot
.35381 .49219 Mdot
.60751 .39114 Mdot
.51603 .64894 Mdot
.31236 .53423 Mdot
.34739 .34969 Mdot
.88672 .50287 Mdot
.59346 .41664 Mdot
.35702 .54848 Mdot
.56681 .18532 Mdot
.36521 .55695 Mdot
.42728 .79594 Mdot
.6494 .37066 Mdot
.49543 .42151 Mdot
.44699 .57901 Mdot
.67769 .564 Mdot
.56617 .38752 Mdot
.57253 .36863 Mdot
.69189 .74011 Mdot
.36338 .54469 Mdot
.57917 .57973 Mdot
.3775 .49923 Mdot
.6759 .55063 Mdot
.27837 .3675 Mdot
.6112 .38343 Mdot
.18218 .5505 Mdot
.42541 .54123 Mdot
.50618 .71749 Mdot
.54709 .3515 Mdot
.64353 .45676 Mdot
.42242 .51473 Mdot
.44142 .35866 Mdot
.66213 .58547 Mdot
.32027 .515 Mdot
.66401 .53683 Mdot
.41809 .50951 Mdot
.37672 .44253 Mdot
.30986 .75744 Mdot
.49788 .67766 Mdot
.65591 .56872 Mdot
.60199 .5153 Mdot
.4423 .54107 Mdot
.48524 .68064 Mdot
.52429 .71198 Mdot
.45026 .34788 Mdot
.57953 .48209 Mdot
.6589 .63807 Mdot
.41933 .76429 Mdot
.71412 .71897 Mdot
.54058 .36356 Mdot
.75294 .41416 Mdot
.4217 .52273 Mdot
.43279 .25524 Mdot
.65411 .5139 Mdot
.38857 .57027 Mdot
.31485 .6257 Mdot
.52219 .6651 Mdot
.40341 .56456 Mdot
.43097 .33609 Mdot
.45243 .27395 Mdot
.41987 .25971 Mdot
.58222 .22602 Mdot
.58216 .38426 Mdot
.39837 .60794 Mdot
.35374 .4532 Mdot
.55032 .37449 Mdot
.35537 .57024 Mdot
.58922 .40471 Mdot
.78289 .63422 Mdot
.40924 .36086 Mdot
.48817 .69332 Mdot
.66146 .423 Mdot
.3724 .58183 Mdot
.33435 .52772 Mdot
.45959 .35216 Mdot
.41008 .53923 Mdot
.27317 .73241 Mdot
.64864 .43483 Mdot
.57522 .35832 Mdot
.49737 .67322 Mdot
.37291 .57853 Mdot
.5935 .4871 Mdot
.37509 .56403 Mdot
.42837 .71388 Mdot
.36594 .57382 Mdot
.67939 .636 Mdot
.49587 .68324 Mdot
.66274 .53353 Mdot
.44407 .54029 Mdot
.37264 .53137 Mdot
.36527 .294 Mdot
.46298 .54674 Mdot
.43825 .52611 Mdot
.49834 .62876 Mdot
.50764 .64939 Mdot
.49601 .65506 Mdot
.62189 .39846 Mdot
.37454 .22386 Mdot
.65002 .54099 Mdot
.32433 .56573 Mdot
.68156 .58635 Mdot
.33595 .75081 Mdot
.4158 .36661 Mdot
.59109 .21058 Mdot
.4 .51902 Mdot
.50697 .66196 Mdot
.72568 .33805 Mdot
.51777 .6379 Mdot
.56236 .51928 Mdot
.66027 .55659 Mdot
.52641 .67271 Mdot
.37598 .52566 Mdot
.49097 .47153 Mdot
.51458 .18469 Mdot
.64612 .53324 Mdot
.45167 .51429 Mdot
.61331 .41527 Mdot
.49716 .22755 Mdot
.17305 .62181 Mdot
.68296 .57653 Mdot
.68536 .51052 Mdot
.3619 .54485 Mdot
.52629 .66226 Mdot
.68018 .55972 Mdot
.6925 .56987 Mdot
.60312 .3614 Mdot
.3787 .51026 Mdot
.3842 .51048 Mdot
.62077 .38801 Mdot
.64179 .53868 Mdot
.4471 .58603 Mdot
.33099 .49202 Mdot
.48001 .14609 Mdot
.54695 .58498 Mdot
.83577 .36854 Mdot
.29532 .56322 Mdot
.29862 .62794 Mdot
.80096 .40442 Mdot
.52169 .72247 Mdot
.35092 .51663 Mdot
.32568 .52497 Mdot
.60927 .35378 Mdot
.38316 .55061 Mdot
.64079 .37715 Mdot
.65058 .55701 Mdot
.37598 .19102 Mdot
.65182 .68869 Mdot
.80329 .60553 Mdot
.38103 .55049 Mdot
.53609 .76388 Mdot
.42075 .34295 Mdot
.63158 .51199 Mdot
.4887 .65208 Mdot
.39063 .49383 Mdot
.21995 .43334 Mdot
.58929 .41765 Mdot
.53744 .69766 Mdot
.24937 .34533 Mdot
.47949 .37101 Mdot
.40883 .50146 Mdot
.61137 .41301 Mdot
.73528 .33108 Mdot
.48168 .56066 Mdot
.62173 .53502 Mdot
.42037 .32657 Mdot
.56319 .38801 Mdot
.63825 .54782 Mdot
.55482 .73673 Mdot
.52964 .6816 Mdot
.54721 .66636 Mdot
.21366 .52151 Mdot
.54623 .38339 Mdot
.42421 .34583 Mdot
.41273 .22388 Mdot
.38142 .24811 Mdot
.42662 .32881 Mdot
.6239 .36524 Mdot
.50779 .64994 Mdot
.51733 .66729 Mdot
.51246 .69897 Mdot
.1878 .5069 Mdot
.52619 .72623 Mdot
.63007 .77568 Mdot
.37439 .48814 Mdot
.41031 .45074 Mdot
.3595 .55045 Mdot
.6924 .53991 Mdot
.49073 .68231 Mdot
.49516 .45307 Mdot
.43746 .5036 Mdot
.51689 .20047 Mdot
.38406 .5726 Mdot
.65671 .50622 Mdot
.41212 .5614 Mdot
.53332 .78603 Mdot
.54169 .71254 Mdot
.38807 .54702 Mdot
.6477 .51056 Mdot
.4115 .34956 Mdot
.47517 .63029 Mdot
.37318 .50712 Mdot
.77751 .52626 Mdot
.35703 .48944 Mdot
.80212 .5876 Mdot
.52451 .59225 Mdot
.41406 .3663 Mdot
.57256 .64969 Mdot
.57453 .4215 Mdot
.39648 .44742 Mdot
.4536 .59564 Mdot
.65185 .52896 Mdot
.67943 .40251 Mdot
.59322 .38287 Mdot
.44097 .40707 Mdot
.33947 .57185 Mdot
.44768 .36255 Mdot
.46627 .6542 Mdot
.68899 .52811 Mdot
.34512 .55842 Mdot
.40231 .47569 Mdot
.68576 .7232 Mdot
.36661 .59836 Mdot
.38435 .57879 Mdot
.45326 .36515 Mdot
.62661 .76942 Mdot
.39458 .55678 Mdot
.56755 .51565 Mdot
.55419 .70761 Mdot
.454 .57983 Mdot
.61347 .78571 Mdot
.43219 .56035 Mdot
.53663 .6871 Mdot
.46293 .64493 Mdot
.61797 .62453 Mdot
.44524 .32362 Mdot
.36028 .57094 Mdot
.50595 .82053 Mdot
.42136 .54376 Mdot
.65407 .54542 Mdot
.36237 .48018 Mdot
.57432 .3771 Mdot
.19774 .47184 Mdot
.59884 .35201 Mdot
.3518 .55495 Mdot
.51556 .70076 Mdot
.6498 .52226 Mdot
.1992 .55344 Mdot
.52308 .25438 Mdot
.60866 .77801 Mdot
.84464 .55022 Mdot
.41193 .31894 Mdot
.4486 .32051 Mdot
.68742 .52477 Mdot
.38945 .5483 Mdot
.61257 .805 Mdot
.46396 .54038 Mdot
.40048 .56188 Mdot
.37022 .53636 Mdot
.46894 .21501 Mdot
.6445 .55412 Mdot
.60069 .36803 Mdot
.41118 .57111 Mdot
.43722 .52681 Mdot
.52163 .7218 Mdot
.41675 .35655 Mdot
.55524 .39212 Mdot
.43909 .35263 Mdot
.57126 .3911 Mdot
.35487 .19374 Mdot
.43045 .50342 Mdot
.41147 .34622 Mdot
.67271 .59085 Mdot
.53936 .70634 Mdot
.61577 .70813 Mdot
.56849 .36963 Mdot
.61552 .36447 Mdot
.39995 .57709 Mdot
.53683 .6844 Mdot
.54237 .66732 Mdot
.41155 .3336 Mdot
.68812 .55354 Mdot
.35719 .51313 Mdot
.34613 .5125 Mdot
.47706 .72011 Mdot
.59652 .34093 Mdot
.58671 .63766 Mdot
.77692 .44563 Mdot
.39167 .54666 Mdot
.54583 .68354 Mdot
.36103 .52656 Mdot
.80156 .44873 Mdot
.5331 .67021 Mdot
.43452 .55945 Mdot
.27842 .2831 Mdot
.53738 .41361 Mdot
.63074 .64548 Mdot
.40792 .58278 Mdot
.83972 .47336 Mdot
.41194 .51732 Mdot
.41828 .14947 Mdot
.6146 .2955 Mdot
.34087 .5384 Mdot
.43067 .52552 Mdot
.35547 .73406 Mdot
.34812 .53499 Mdot
.62072 .38101 Mdot
.3129 .28747 Mdot
.53451 .64928 Mdot
.74963 .58066 Mdot
.26131 .59637 Mdot
.41842 .31416 Mdot
.56878 .35873 Mdot
.59491 .4399 Mdot
.4369 .33527 Mdot
.51969 .69581 Mdot
.3981 .54253 Mdot
.52489 .49082 Mdot
.57528 .34749 Mdot
.3 .55388 Mdot
.65635 .54727 Mdot
.72644 .44396 Mdot
.60883 .44874 Mdot
.67046 .53901 Mdot
.3908 .50557 Mdot
.34381 .7308 Mdot
.23611 .51741 Mdot
.78902 .33775 Mdot
.63681 .54636 Mdot
.64602 .53021 Mdot
.18915 .4836 Mdot
.3884 .3424 Mdot
.71306 .70125 Mdot
.69117 .63584 Mdot
.66475 .5204 Mdot
.49175 .57563 Mdot
.60086 .41093 Mdot
.68745 .6062 Mdot
.36828 .60762 Mdot
.35452 .49954 Mdot
.37501 .52752 Mdot
.68683 .54622 Mdot
.32483 .60722 Mdot
.29004 .73373 Mdot
.65983 .52818 Mdot
.45034 .6174 Mdot
.54163 .45797 Mdot
.66749 .32566 Mdot
.61681 .38121 Mdot
.44825 .32771 Mdot
.41906 .30054 Mdot
.50602 .71539 Mdot
.45057 .32955 Mdot
.4481 .26841 Mdot
.40509 .53362 Mdot
.66978 .52939 Mdot
.69154 .40908 Mdot
.66998 .55069 Mdot
.43769 .33854 Mdot
.43007 .37229 Mdot
.51719 .71461 Mdot
.50517 .6913 Mdot
.30238 .64584 Mdot
.28456 .39515 Mdot
.37521 .5674 Mdot
.64323 .26747 Mdot
.5475 .68241 Mdot
.29764 .54484 Mdot
.45437 .33539 Mdot
.41505 .35313 Mdot
.36648 .30877 Mdot
.39334 .51967 Mdot
.46527 .80606 Mdot
.39156 .52304 Mdot
.27953 .37363 Mdot
.42872 .58123 Mdot
.60396 .36212 Mdot
.39346 .51456 Mdot
.37922 .27575 Mdot
.36183 .57991 Mdot
.35041 .48104 Mdot
.58492 .34589 Mdot
.31811 .52266 Mdot
.57659 .37642 Mdot
.35853 .56066 Mdot
.39514 .31921 Mdot
.58838 .34817 Mdot
.34596 .37513 Mdot
.36986 .31781 Mdot
.62571 .37304 Mdot
.44789 .35788 Mdot
.40658 .31532 Mdot
.36524 .398 Mdot
.4887 .65171 Mdot
.43911 .62089 Mdot
.38743 .55053 Mdot
.55955 .41361 Mdot
.64737 .5584 Mdot
.43688 .53726 Mdot
.33587 .49816 Mdot
.42734 .5765 Mdot
.50424 .71471 Mdot
.49014 .25229 Mdot
.40977 .33948 Mdot
.61827 .3995 Mdot
.4649 .30798 Mdot
.60487 .33786 Mdot
.3683 .47556 Mdot
.32759 .53921 Mdot
.28403 .61063 Mdot
.705 .35977 Mdot
.17907 .49182 Mdot
.53137 .68419 Mdot
.55235 .38243 Mdot
.39108 .32572 Mdot
.34615 .47255 Mdot
.50809 .65793 Mdot
.57265 .37566 Mdot
.39586 .54664 Mdot
.44876 .50817 Mdot
.63422 .73604 Mdot
.27434 .52677 Mdot
.36966 .36294 Mdot
.62013 .37001 Mdot
.58901 .42371 Mdot
.40262 .25148 Mdot
.43743 .38818 Mdot
.49386 .46066 Mdot
.37171 .55387 Mdot
.44244 .35685 Mdot
.50934 .6513 Mdot
.22264 .5245 Mdot
.68818 .54135 Mdot
.51193 .5335 Mdot
.38179 .54895 Mdot
.48911 .39741 Mdot
.51604 .7029 Mdot
.42779 .33412 Mdot
.68599 .54342 Mdot
.46071 .33415 Mdot
.55787 .36415 Mdot
.81003 .63522 Mdot
.4175 .5429 Mdot
.39072 .57716 Mdot
.63096 .53243 Mdot
.51652 .65851 Mdot
.46051 .3458 Mdot
.73518 .68161 Mdot
.5813 .36087 Mdot
.59282 .81218 Mdot
.54033 .6736 Mdot
.48981 .7599 Mdot
.61433 .40189 Mdot
.69637 .57801 Mdot
.35043 .39542 Mdot
.67718 .54031 Mdot
.35862 .56459 Mdot
.50863 .67416 Mdot
.66321 .5702 Mdot
.50955 .54404 Mdot
.55025 .18065 Mdot
.47962 .76581 Mdot
.39871 .53263 Mdot
.46122 .16942 Mdot
.79009 .5691 Mdot
.47914 .70033 Mdot
.63962 .52143 Mdot
.38485 .57128 Mdot
.34062 .54596 Mdot
.42116 .54649 Mdot
.66299 .56513 Mdot
.61207 .26015 Mdot
.58783 .36486 Mdot
.36032 .54736 Mdot
.45097 .34157 Mdot
.58429 .37764 Mdot
.65748 .43042 Mdot
.61486 .37856 Mdot
.47446 .68139 Mdot
.35829 .48091 Mdot
.61747 .5103 Mdot
.34972 .17289 Mdot
.64389 .53943 Mdot
.62187 .3566 Mdot
.4114 .49291 Mdot
.70005 .39203 Mdot
.49909 .65532 Mdot
.58406 .35891 Mdot
.39612 .57335 Mdot
.66505 .41337 Mdot
.20915 .46813 Mdot
.61387 .38043 Mdot
.50938 .65535 Mdot
.76387 .32075 Mdot
.38257 .55633 Mdot
.4158 .52431 Mdot
.52326 .67451 Mdot
.27128 .67228 Mdot
.21994 .38151 Mdot
.3599 .52141 Mdot
.66432 .53308 Mdot
.72491 .75745 Mdot
.34589 .48107 Mdot
.31743 .32195 Mdot
.56589 .38555 Mdot
.63192 .59724 Mdot
.57906 .61161 Mdot
.34744 .47175 Mdot
.7267 .68443 Mdot
.70576 .52655 Mdot
.45018 .18836 Mdot
.64087 .37135 Mdot
.53687 .32436 Mdot
.41706 .18051 Mdot
.65966 .50892 Mdot
.49223 .73372 Mdot
.74731 .64028 Mdot
.19956 .61553 Mdot
.7656 .33628 Mdot
.5095 .31726 Mdot
.21973 .42933 Mdot
.52395 .47191 Mdot
.57316 .39712 Mdot
.45597 .31016 Mdot
.36778 .50997 Mdot
.79185 .56439 Mdot
.48377 .80574 Mdot
.38999 .80478 Mdot
.46607 .1674 Mdot
.41787 .78734 Mdot
.5476 .18633 Mdot
.65986 .22333 Mdot
.28825 .58983 Mdot
.71244 .35391 Mdot
.59125 .81674 Mdot
.30992 .26461 Mdot
.73122 .71332 Mdot
.43111 .4668 Mdot
.56169 .53541 Mdot
.82471 .56407 Mdot
.51741 .77034 Mdot
.28654 .72046 Mdot
.59945 .35483 Mdot
.5024 .64313 Mdot
.74566 .63339 Mdot
.48269 .6376 Mdot
.59956 .61688 Mdot
.76854 .31861 Mdot
.56834 .18058 Mdot
.54682 .78996 Mdot
.82688 .42857 Mdot
.32848 .63504 Mdot
.44729 .86256 Mdot
.57233 .34554 Mdot
.48741 .6979 Mdot
.39725 .38022 Mdot
.39572 .24737 Mdot
.69021 .69302 Mdot
.76587 .6164 Mdot
.53823 .22865 Mdot
.29776 .42312 Mdot
.5158 .6864 Mdot
.56669 .6308 Mdot
.61224 .57596 Mdot
.65448 .69345 Mdot
.30322 .29325 Mdot
.69787 .26356 Mdot
.52892 .50603 Mdot
.76129 .56257 Mdot
.74051 .4328 Mdot
.17218 .61104 Mdot
.33621 .32237 Mdot
.30073 .51128 Mdot
.59297 .60823 Mdot
.80336 .41678 Mdot
.21975 .63145 Mdot
.26785 .41165 Mdot
.39167 .24767 Mdot
.31369 .24108 Mdot
.81426 .49977 Mdot
.19686 .35094 Mdot
.5299 .64035 Mdot
.38998 .58066 Mdot
.2802 .66403 Mdot
.51696 .81876 Mdot
.42042 .37222 Mdot
.60192 .23957 Mdot
.43175 .31806 Mdot
.51635 .73012 Mdot
.2086 .44021 Mdot
.61449 .78186 Mdot
.52029 .82435 Mdot
.41859 .30366 Mdot
.30966 .52767 Mdot
.8422 .6632 Mdot
.4838 .19253 Mdot
.63077 .67142 Mdot
.46362 .14644 Mdot
.48056 .41691 Mdot
.50116 .57513 Mdot
.66109 .56824 Mdot
.41378 .17399 Mdot
.51417 .66954 Mdot
.21649 .30635 Mdot
.40816 .15681 Mdot
.25054 .56703 Mdot
.83051 .29658 Mdot
.42098 .23886 Mdot
.49231 .41687 Mdot
.72338 .53602 Mdot
.32935 .36103 Mdot
.25446 .69343 Mdot
.312 .46225 Mdot
.70949 .40061 Mdot
.85372 .52521 Mdot
.44335 .18091 Mdot
.54708 .81755 Mdot
.78659 .66171 Mdot
.20997 .63805 Mdot
.59306 .49583 Mdot
.35091 .60469 Mdot
.62262 .44109 Mdot
.68589 .26826 Mdot
.32925 .21492 Mdot
.32911 .31958 Mdot
.88862 .51463 Mdot
.45078 .37701 Mdot
.57378 .27147 Mdot
.76603 .3006 Mdot
.31127 .42034 Mdot
.55513 .60928 Mdot
.33265 .27591 Mdot
.30554 .51602 Mdot
.44541 .28425 Mdot
.63241 .24821 Mdot
.60585 .65882 Mdot
.32591 .26378 Mdot
.76399 .35756 Mdot
.68266 .72444 Mdot
.39143 .73785 Mdot
.3728 .24344 Mdot
.50658 .63338 Mdot
.28349 .41939 Mdot
.5523 .59949 Mdot
.55536 .17367 Mdot
.69676 .5236 Mdot
.59712 .17296 Mdot
.22249 .38278 Mdot
.45132 .54123 Mdot
.46393 .58279 Mdot
.53498 .63599 Mdot
.29296 .39776 Mdot
.31752 .51035 Mdot
.65617 .72629 Mdot
.62086 .19724 Mdot
.34227 .63055 Mdot
.61282 .59246 Mdot
.67695 .39811 Mdot
.77882 .31446 Mdot
.30163 .66991 Mdot
.43568 .39036 Mdot
.27544 .3439 Mdot
.19422 .63964 Mdot
.59633 .37838 Mdot
.55723 .81161 Mdot
.62093 .5357 Mdot
.21205 .4905 Mdot
.42077 .76773 Mdot
.24401 .60525 Mdot
.62217 .19765 Mdot
.50147 .34055 Mdot
.21574 .41185 Mdot
.30337 .44524 Mdot
.66029 .78753 Mdot
.67164 .32861 Mdot
.33263 .55883 Mdot
.76927 .57922 Mdot
.39789 .32717 Mdot
.34045 .689 Mdot
.71754 .74959 Mdot
.51295 .28903 Mdot
.3915 .60254 Mdot
.24012 .55329 Mdot
.52231 .39233 Mdot
.49394 .47768 Mdot
.14899 .48266 Mdot
.36597 .47277 Mdot
.40397 .22632 Mdot
.81315 .51887 Mdot
.31391 .36108 Mdot
.80591 .3764 Mdot
.78923 .41957 Mdot
.22436 .31168 Mdot
.44882 .15695 Mdot
.51005 .25549 Mdot
.40957 .18854 Mdot
.52228 .15705 Mdot
.21571 .33181 Mdot
.45757 .59728 Mdot
.62883 .53783 Mdot
.15398 .62322 Mdot
.61685 .38799 Mdot
.44342 .2114 Mdot
.71303 .72022 Mdot
.62492 .45485 Mdot
.55008 .74975 Mdot
.31877 .47069 Mdot
.52974 .48144 Mdot
.48352 .70803 Mdot
.31657 .52066 Mdot
.16855 .45134 Mdot
.261 .27912 Mdot
.18585 .3937 Mdot
.82901 .49637 Mdot
.39021 .19255 Mdot
.5083 .4256 Mdot
.5593 .78462 Mdot
.31676 .58921 Mdot
.37095 .49189 Mdot
.42297 .40476 Mdot
.42348 .23784 Mdot
.23638 .55846 Mdot
.69495 .67127 Mdot
.46714 .66518 Mdot
.61664 .24404 Mdot
.51903 .90895 Mdot
.3274 .65109 Mdot
.63805 .78068 Mdot
.41038 .25595 Mdot
.29173 .38457 Mdot
.67591 .26951 Mdot
.2462 .58555 Mdot
.67575 .22753 Mdot
.49867 .72701 Mdot
.72997 .70962 Mdot
.52703 .30764 Mdot
.46871 .47482 Mdot
.49542 .24846 Mdot
.58812 .19399 Mdot
.70215 .49357 Mdot
.21789 .56556 Mdot
.71767 .63034 Mdot
.25459 .65227 Mdot
.64294 .33937 Mdot
.7352 .44984 Mdot
.70172 .75836 Mdot
.75941 .39849 Mdot
.29438 .35307 Mdot
.55159 .4678 Mdot
.57817 .68178 Mdot
.7087 .52937 Mdot
.29961 .35065 Mdot
.43928 .43492 Mdot
.39973 .20545 Mdot
.32114 .16487 Mdot
.16735 .52428 Mdot
.82373 .36574 Mdot
.65759 .26916 Mdot
.38154 .59743 Mdot
.71588 .24889 Mdot
.17729 .38991 Mdot
.38666 .15194 Mdot
.72995 .47688 Mdot
.6408 .3605 Mdot
.69256 .5821 Mdot
.18097 .43975 Mdot
.6008 .25971 Mdot
.71059 .25703 Mdot
.34751 .27142 Mdot
.69754 .58364 Mdot
.28173 .76211 Mdot
.3114 .24912 Mdot
.44414 .77042 Mdot
.2743 .52946 Mdot
.42679 .59197 Mdot
.5192 .78882 Mdot
.48029 .63939 Mdot
.75444 .42338 Mdot
.27813 .40738 Mdot
.60362 .3832 Mdot
.40391 .39252 Mdot
.77048 .60375 Mdot
.36194 .48673 Mdot
.59975 .5127 Mdot
.47166 .65555 Mdot
.70843 .36049 Mdot
.62874 .71477 Mdot
.32 .21412 Mdot
.46081 .23268 Mdot
.44851 .57146 Mdot
.31508 .35426 Mdot
.48657 .2472 Mdot
.21138 .3915 Mdot
.69343 .52979 Mdot
.49003 .1658 Mdot
.54699 .53736 Mdot
.28236 .41787 Mdot
.50276 .79497 Mdot
.42801 .64007 Mdot
.3342 .51771 Mdot
.76768 .38949 Mdot
.4175 .69582 Mdot
.50299 .50974 Mdot
.34555 .59635 Mdot
.37763 .62 Mdot
.72885 .25624 Mdot
.45336 .27701 Mdot
.72943 .4342 Mdot
.51858 .1669 Mdot
.66906 .56181 Mdot
.54496 .70022 Mdot
.41948 .29549 Mdot
.75305 .66426 Mdot
.4361 .6928 Mdot
.20856 .46974 Mdot
.6194 .45265 Mdot
.5262 .28204 Mdot
.52849 .17297 Mdot
.48413 .17138 Mdot
.4503 .82443 Mdot
.46611 .6427 Mdot
.29596 .59253 Mdot
.7433 .68555 Mdot
.51379 .64525 Mdot
.65532 .74235 Mdot
.64349 .74258 Mdot
.35321 .20617 Mdot
.59734 .5337 Mdot
.85185 .51097 Mdot
.36629 .36612 Mdot
.5908 .24105 Mdot
.19694 .55232 Mdot
.68947 .76447 Mdot
.56136 .19299 Mdot
.48443 .57713 Mdot
.37501 .75384 Mdot
.41783 .45851 Mdot
.58469 .7263 Mdot
.20632 .68441 Mdot
.39876 .2956 Mdot
.49543 .76514 Mdot
.76663 .35711 Mdot
.40621 .54382 Mdot
.16315 .53976 Mdot
.76071 .64081 Mdot
.18626 .4881 Mdot
.69128 .58914 Mdot
.39588 .50168 Mdot
.35217 .57115 Mdot
.30573 .31859 Mdot
.61971 .62701 Mdot
.38509 .21606 Mdot
.7456 .72968 Mdot
.73644 .32402 Mdot
.48227 .80484 Mdot
.41934 .22591 Mdot
.71118 .26766 Mdot
.79397 .5559 Mdot
.57295 .48924 Mdot
.43228 .23742 Mdot
.32697 .41004 Mdot
.82609 .43659 Mdot
.45175 .43745 Mdot
.71871 .58804 Mdot
.69316 .70055 Mdot
.78097 .44548 Mdot
.21314 .53721 Mdot
.41164 .50867 Mdot
.24966 .34498 Mdot
.67696 .23824 Mdot
.46294 .81883 Mdot
.24406 .69498 Mdot
.16382 .51151 Mdot
.42796 .73042 Mdot
.78298 .43237 Mdot
.78419 .57167 Mdot
.65647 .80434 Mdot
.54835 .54525 Mdot
.54075 .2018 Mdot
.31697 .42426 Mdot
.52514 .17045 Mdot
.63105 .52567 Mdot
.69976 .64395 Mdot
.67635 .39189 Mdot
.40113 .19756 Mdot
.3182 .69359 Mdot
.61547 .205 Mdot
.49245 .43208 Mdot
.23307 .29703 Mdot
.74428 .37697 Mdot
.52164 .46067 Mdot
.55524 .37377 Mdot
.4955 .33339 Mdot
.61726 .23112 Mdot
.69204 .32599 Mdot
.67691 .76919 Mdot
.62971 .39941 Mdot
.43878 .29945 Mdot
.45397 .78364 Mdot
.27322 .45934 Mdot
.77479 .39678 Mdot
.31513 .35472 Mdot
.59722 .18837 Mdot
.32057 .2892 Mdot
.24614 .35393 Mdot
.44469 .2235 Mdot
.84413 .58249 Mdot
.62954 .66588 Mdot
.42741 .26835 Mdot
.76581 .62783 Mdot
.59436 .27715 Mdot
.49467 .58433 Mdot
.07879 .43143 Mdot
.81344 .61921 Mdot
.72773 .36308 Mdot
.32984 .21491 Mdot
.80425 .43542 Mdot
.70876 .36528 Mdot
.249 .67269 Mdot
.54867 .58375 Mdot
.2371 .40647 Mdot
.37108 .53611 Mdot
.16463 .44018 Mdot
.27123 .44375 Mdot
.30186 .23263 Mdot
.72888 .26576 Mdot
.50695 .78508 Mdot
.35379 .48534 Mdot
.61623 .40569 Mdot
.59361 .59436 Mdot
.25071 .47156 Mdot
.31276 .71156 Mdot
.54224 .61345 Mdot
.66792 .38705 Mdot
.54859 .37729 Mdot
.47308 .25293 Mdot
.53492 .73792 Mdot
.59348 .25179 Mdot
.77652 .44015 Mdot
.53346 .38775 Mdot
.52881 .51804 Mdot
.29794 .36214 Mdot
.57796 .61448 Mdot
.44753 .76815 Mdot
.24246 .57874 Mdot
.6267 .49033 Mdot
.61669 .37391 Mdot
.42516 .76 Mdot
.825 .57346 Mdot
.74057 .33655 Mdot
.31368 .23809 Mdot
.47928 .32565 Mdot
.34695 .74931 Mdot
.29988 .34277 Mdot
.2657 .71026 Mdot
.34172 .76561 Mdot
.68299 .34077 Mdot
.56675 .73162 Mdot
.28141 .70838 Mdot
.75561 .59812 Mdot
.37795 .18869 Mdot
.73074 .71274 Mdot
.74112 .69222 Mdot
.65668 .36461 Mdot
.46857 .72365 Mdot
.48617 .78985 Mdot
.35226 .37401 Mdot
.49535 .46986 Mdot
.41276 .85278 Mdot
.36998 .60978 Mdot
.2908 .80535 Mdot
.68519 .57839 Mdot
.21604 .65818 Mdot
.33264 .41247 Mdot
.55608 .4661 Mdot
.47066 .42414 Mdot
.76888 .40563 Mdot
.68056 .63828 Mdot
.81891 .52641 Mdot
.35233 .78223 Mdot
.59118 .3381 Mdot
.75626 .72292 Mdot
.84856 .58044 Mdot
.38 .74493 Mdot
.38529 .47839 Mdot
.82598 .6007 Mdot
.63567 .34901 Mdot
.23567 .56197 Mdot
.80657 .37259 Mdot
.69478 .31346 Mdot
.4719 .58273 Mdot
.28975 .39185 Mdot
.54295 .20063 Mdot
.48339 .15832 Mdot
.28001 .75039 Mdot
.63479 .25056 Mdot
.63033 .53027 Mdot
.50938 .44038 Mdot
.62789 .2198 Mdot
.50247 .56131 Mdot
.68476 .60825 Mdot
.54212 .60337 Mdot
.3839 .86138 Mdot
.45086 .20604 Mdot
.38871 .21592 Mdot
.52433 .59422 Mdot
.53931 .7252 Mdot
.61374 .61929 Mdot
.55712 .60984 Mdot
.70528 .32499 Mdot
.80748 .5865 Mdot
.55524 .60451 Mdot
.56938 .84431 Mdot
.41726 .63984 Mdot
.51344 .3824 Mdot
.47704 .7958 Mdot
.33611 .62426 Mdot
.69593 .58894 Mdot
.26795 .33369 Mdot
.75612 .3335 Mdot
.631 .55484 Mdot
.77278 .38876 Mdot
.76212 .55911 Mdot
.49075 .74211 Mdot
.44449 .71136 Mdot
.71282 .30974 Mdot
.33114 .7177 Mdot
.56001 .76243 Mdot
.22403 .51598 Mdot
.62074 .35025 Mdot
.756 .32443 Mdot
.57076 .36291 Mdot
.30107 .52307 Mdot
.51166 .53836 Mdot
.30614 .46957 Mdot
.17917 .48011 Mdot
.40853 .31904 Mdot
.47774 .6543 Mdot
.22935 .70413 Mdot
.53092 .65877 Mdot
.17305 .43391 Mdot
.24492 .6016 Mdot
.50569 .79612 Mdot
.51056 .26116 Mdot
.49389 .28716 Mdot
.49104 .85808 Mdot
.61225 .50337 Mdot
.63037 .43952 Mdot
.59947 .73803 Mdot
.48309 .6871 Mdot
.46518 .22934 Mdot
.59341 .34463 Mdot
.54872 .56852 Mdot
.69936 .48916 Mdot
.45367 .65292 Mdot
.54118 .75466 Mdot
.53673 .54466 Mdot
.25254 .39327 Mdot
.37247 .20375 Mdot
.58126 .40675 Mdot
.30764 .80698 Mdot
.34204 .49671 Mdot
.38334 .72966 Mdot
.67375 .22378 Mdot
.2919 .76989 Mdot
.60436 .4431 Mdot
.85358 .57743 Mdot
.44382 .57199 Mdot
.68657 .28107 Mdot
.51659 .67872 Mdot
.73505 .69956 Mdot
.42226 .31866 Mdot
.3186 .36154 Mdot
.6828 .58282 Mdot
.21625 .56582 Mdot
.5478 .4366 Mdot
.54609 .66567 Mdot
.66855 .2897 Mdot
.30056 .6014 Mdot
.69482 .62303 Mdot
.47907 .27082 Mdot
.38725 .75011 Mdot
.44471 .70456 Mdot
.52098 .74955 Mdot
.40143 .21144 Mdot
.74527 .69618 Mdot
.3361 .19447 Mdot
.49484 .62221 Mdot
.4832 .37185 Mdot
.67549 .7202 Mdot
.75116 .35825 Mdot
.59364 .70375 Mdot
.64583 .20629 Mdot
.27003 .41985 Mdot
.46344 .69044 Mdot
.28349 .37096 Mdot
.43644 .48432 Mdot
.54966 .49669 Mdot
.75305 .44319 Mdot
.38554 .80527 Mdot
.58983 .63284 Mdot
.22725 .65127 Mdot
.57913 .7232 Mdot
.38226 .22838 Mdot
.56818 .72175 Mdot
.55019 .41908 Mdot
.4842 .74625 Mdot
.63817 .498 Mdot
.3922 .1826 Mdot
.65471 .21106 Mdot
.65344 .50216 Mdot
.50981 .23044 Mdot
.80322 .39596 Mdot
.41442 .47357 Mdot
.49877 .39953 Mdot
.37846 .57667 Mdot
.30878 .58937 Mdot
.30997 .78982 Mdot
.72326 .33585 Mdot
.39011 .60666 Mdot
.44364 .18659 Mdot
.43101 .17617 Mdot
.2663 .26363 Mdot
.61863 .80525 Mdot
.50831 .71233 Mdot
.20993 .35139 Mdot
.54305 .61715 Mdot
.50625 .15355 Mdot
.68467 .33478 Mdot
.71349 .23514 Mdot
.36863 .74793 Mdot
.78287 .38861 Mdot
.26176 .68591 Mdot
.64921 .62823 Mdot
.80724 .49652 Mdot
.54093 .44766 Mdot
.71392 .42834 Mdot
.80771 .46102 Mdot
.68803 .80407 Mdot
.35068 .46653 Mdot
.77178 .54317 Mdot
.74146 .62423 Mdot
.74877 .31622 Mdot
.61494 .3015 Mdot
.36449 .47999 Mdot
.68569 .40934 Mdot
.1946 .51742 Mdot
.30891 .34676 Mdot
.44372 .29973 Mdot
.61719 .30234 Mdot
.22774 .46561 Mdot
.2713 .38192 Mdot
.73361 .71196 Mdot
.38332 .75248 Mdot
.56698 .56992 Mdot
.44258 .54298 Mdot
.54467 .74633 Mdot
.43254 .31234 Mdot
.58085 .46102 Mdot
.36351 .564 Mdot
.55639 .41411 Mdot
.68246 .62602 Mdot
.16883 .48642 Mdot
.60985 .65407 Mdot
.77853 .61662 Mdot
.56264 .71035 Mdot
.74555 .57833 Mdot
.60151 .71462 Mdot
.18356 .55825 Mdot
.56647 .2978 Mdot
.32937 .31951 Mdot
.49165 .18753 Mdot
.32988 .26269 Mdot
.50843 .75511 Mdot
.26931 .28947 Mdot
.64996 .51465 Mdot
.46668 .61425 Mdot
.7267 .64397 Mdot
.45957 .25091 Mdot
.35581 .60022 Mdot
.78125 .38747 Mdot
.62074 .44502 Mdot
.38963 .25744 Mdot
.81746 .50625 Mdot
.3286 .61408 Mdot
.42701 .78048 Mdot
.47292 .1723 Mdot
.59369 .41622 Mdot
.77054 .66446 Mdot
.72407 .59944 Mdot
.54089 .31774 Mdot
.36003 .22545 Mdot
.34318 .20255 Mdot
.48895 .44214 Mdot
.32018 .40212 Mdot
.42313 .53184 Mdot
.70924 .7479 Mdot
.73913 .35096 Mdot
.33266 .45829 Mdot
.71874 .46711 Mdot
.54398 .68641 Mdot
.75331 .47338 Mdot
.56291 .54482 Mdot
.23425 .43037 Mdot
.47391 .64068 Mdot
.48313 .80897 Mdot
.39869 .31631 Mdot
.47803 .39583 Mdot
.31368 .52597 Mdot
.32667 .38411 Mdot
.5427 .82543 Mdot
.33459 .57809 Mdot
.65128 .25439 Mdot
.40997 .76083 Mdot
.73473 .68478 Mdot
.70286 .30429 Mdot
.68229 .34646 Mdot
.67403 .63677 Mdot
.47393 .74132 Mdot
.64966 .47284 Mdot
.42093 .57866 Mdot
.55899 .42658 Mdot
.52745 .64599 Mdot
.77797 .33755 Mdot
.42796 .72025 Mdot
.34493 .37809 Mdot
.61978 .47672 Mdot
.29908 .52466 Mdot
.70187 .50653 Mdot
.69975 .23003 Mdot
.64855 .62961 Mdot
.27539 .40811 Mdot
.59739 .53235 Mdot
.33526 .40806 Mdot
.24337 .6143 Mdot
.40036 .16147 Mdot
.25501 .68057 Mdot
.51846 .49187 Mdot
.23089 .67167 Mdot
.76298 .40568 Mdot
.81012 .38447 Mdot
.27055 .39976 Mdot
.46851 .40538 Mdot
.44115 .37544 Mdot
.6249 .74369 Mdot
.61518 .48677 Mdot
.43482 .28936 Mdot
.55768 .57654 Mdot
.68837 .46963 Mdot
.64094 .58882 Mdot
.3281 .46533 Mdot
.45599 .214 Mdot
.48317 .18083 Mdot
.72351 .70808 Mdot
.70237 .52013 Mdot
.53689 .32827 Mdot
.23715 .44304 Mdot
.75137 .25485 Mdot
.17945 .64353 Mdot
.42297 .53392 Mdot
.67379 .49747 Mdot
.30819 .40297 Mdot
.62043 .36649 Mdot
.57408 .62239 Mdot
.60528 .7028 Mdot
.66146 .57491 Mdot
.42154 .29338 Mdot
.38013 .26014 Mdot
.76847 .42205 Mdot
.27517 .4669 Mdot
.66556 .4185 Mdot
.16472 .4941 Mdot
.8374 .54619 Mdot
.74373 .35056 Mdot
.70051 .20721 Mdot
.72089 .59301 Mdot
.42852 .6276 Mdot
.27833 .64678 Mdot
.37453 .20606 Mdot
.32392 .34411 Mdot
.21524 .51214 Mdot
.67916 .35919 Mdot
.26856 .41288 Mdot
.51054 .59833 Mdot
.43001 .2251 Mdot
.74796 .47347 Mdot
.54161 .47969 Mdot
.49659 .29052 Mdot
.29078 .2629 Mdot
.43643 .79084 Mdot
.51592 .18763 Mdot
.19366 .53435 Mdot
.6282 .82351 Mdot
.40691 .17349 Mdot
.37016 .32735 Mdot
.59273 .29892 Mdot
.28223 .66332 Mdot
.44935 .44017 Mdot
.49059 .57206 Mdot
.23359 .55729 Mdot
.42462 .67574 Mdot
.54744 .24634 Mdot
.20739 .61599 Mdot
.29506 .35241 Mdot
.35456 .63315 Mdot
.46749 .40856 Mdot
.44092 .76272 Mdot
.50549 .23283 Mdot
.51137 .57952 Mdot
.47012 .45682 Mdot
.34829 .34112 Mdot
.41558 .75837 Mdot
.69164 .71402 Mdot
.79606 .42939 Mdot
.59161 .84896 Mdot
.63924 .27083 Mdot
.18668 .57183 Mdot
.37532 .48722 Mdot
.29745 .21574 Mdot
.7935 .46147 Mdot
.67186 .32206 Mdot
.80977 .55889 Mdot
.51607 .36714 Mdot
.43985 .63334 Mdot
.42156 .57836 Mdot
.61058 .23201 Mdot
.49279 .76557 Mdot
.30717 .62364 Mdot
.21007 .56825 Mdot
.30539 .37357 Mdot
.3469 .27655 Mdot
.35901 .37203 Mdot
.4651 .61807 Mdot
.52718 .65917 Mdot
.18951 .38378 Mdot
.50481 .46432 Mdot
.3072 .50792 Mdot
.38106 .44443 Mdot
.25634 .65468 Mdot
.86141 .52354 Mdot
.53722 .63837 Mdot
.34621 .25535 Mdot
.40098 .77996 Mdot
.46801 .49999 Mdot
.58754 .68829 Mdot
.70678 .17743 Mdot
.36763 .14694 Mdot
.5402 .65571 Mdot
.62401 .78584 Mdot
.4099 .78446 Mdot
.39607 .20489 Mdot
.53232 .305 Mdot
.71168 .48358 Mdot
.3724 .4391 Mdot
.48248 .49671 Mdot
.32153 .54735 Mdot
.8084 .53454 Mdot
.4129 .15995 Mdot
.20848 .58505 Mdot
.44655 .18591 Mdot
.46801 .5472 Mdot
.33166 .56762 Mdot
.77786 .26698 Mdot
.61684 .21404 Mdot
.39576 .47123 Mdot
.28112 .71829 Mdot
.3509 .60411 Mdot
.36717 .51421 Mdot
.55281 .2198 Mdot
.75729 .72031 Mdot
.29614 .34711 Mdot
.40084 .19809 Mdot
.47799 .63674 Mdot
.55649 .4322 Mdot
.68397 .57954 Mdot
.47867 .43459 Mdot
.44772 .51182 Mdot
.66803 .57024 Mdot
.26507 .53256 Mdot
.78123 .37536 Mdot
.59505 .58322 Mdot
.76115 .69629 Mdot
.6243 .17925 Mdot
.438 .7369 Mdot
.6235 .73814 Mdot
.35486 .47077 Mdot
.35434 .63141 Mdot
.2431 .47271 Mdot
.3276 .60242 Mdot
.80961 .42814 Mdot
.12691 .38686 Mdot
.69989 .43373 Mdot
.24884 .3745 Mdot
.5283 .73501 Mdot
.57349 .58503 Mdot
.46526 .7762 Mdot
.55073 .32419 Mdot
.56644 .40183 Mdot
.46509 .52939 Mdot
.48259 .62004 Mdot
.66393 .58555 Mdot
.26102 .77122 Mdot
.38936 .48317 Mdot
.58454 .64564 Mdot
.50935 .15524 Mdot
.22366 .5158 Mdot
.35448 .7129 Mdot
.41385 .58888 Mdot
.65716 .69773 Mdot
.46958 .40296 Mdot
.7177 .29017 Mdot
.25168 .34651 Mdot
.45495 .193 Mdot
.42738 .71638 Mdot
.42066 .78083 Mdot
.43833 .52965 Mdot
.39451 .35521 Mdot
.64108 .60297 Mdot
.58404 .23062 Mdot
.45165 .59367 Mdot
.46685 .15452 Mdot
.51124 .394 Mdot
.58747 .45724 Mdot
.50088 .61837 Mdot
.25322 .27957 Mdot
.22909 .6282 Mdot
.48997 .78112 Mdot
.17868 .54418 Mdot
.464 .26996 Mdot
.27491 .45648 Mdot
.6102 .41191 Mdot
.45764 .58799 Mdot
.49421 .63392 Mdot
.15601 .51866 Mdot
.53792 .21136 Mdot
.70362 .41459 Mdot
.73219 .44971 Mdot
.666 .76253 Mdot
.71038 .61636 Mdot
.67139 .1888 Mdot
.47751 .28119 Mdot
.16034 .5131 Mdot
.75105 .68568 Mdot
.52287 .63333 Mdot
.7792 .40811 Mdot
.39536 .61149 Mdot
.60003 .39669 Mdot
.44048 .19394 Mdot
.30527 .55062 Mdot
.21041 .44131 Mdot
.38442 .5934 Mdot
.19105 .46349 Mdot
.39221 .28345 Mdot
.49743 .22424 Mdot
.7404 .3803 Mdot
.24714 .64824 Mdot
.75692 .29959 Mdot
.62691 .74496 Mdot
.74291 .262 Mdot
.76301 .31408 Mdot
.4839 .16575 Mdot
.20394 .4906 Mdot
.31928 .78168 Mdot
.69322 .33246 Mdot
.71793 .31658 Mdot
.76401 .44175 Mdot
.27362 .66984 Mdot
.49789 .33276 Mdot
.52842 .63068 Mdot
.62789 .63099 Mdot
.63858 .50443 Mdot
.09885 .58444 Mdot
.35918 .28035 Mdot
.50978 .62975 Mdot
.48391 .30746 Mdot
.44716 .1711 Mdot
.2658 .65412 Mdot
.81095 .47556 Mdot
.5605 .53422 Mdot
.32854 .55111 Mdot
.43506 .7022 Mdot
.69861 .73794 Mdot
.49144 .33918 Mdot
.5087 .8703 Mdot
.82851 .5602 Mdot
.70659 .45478 Mdot
.54604 .50606 Mdot
.50442 .64117 Mdot
.57483 .74956 Mdot
.50234 .27847 Mdot
.81641 .44471 Mdot
.78255 .38378 Mdot
.62568 .2183 Mdot
.4918 .85676 Mdot
.73743 .68717 Mdot
.37279 .20531 Mdot
.74872 .37386 Mdot
.55222 .68021 Mdot
.37893 .36194 Mdot
.62185 .34246 Mdot
.71486 .40819 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo07Cooooo0_l0000Mooooo`;o00000oooool2o`000:oooooo000Looooo`03o`00
0?oooooooooo07Cooooo0_l0000:ooooo`;o00000_ooool2o`000004ooooool0003o0000o`0000Wo
oooo0_l00003ooooo`;o0000[oooool001cooooo0_l0001kooooo`;o00001?ooool6o`000004oooo
ool0003o0000o`0001Oooooo0_l00009ooooo`;o0000Voooool001cooooo00?o0000ooooooooool0
Moooool2o`000003ooooool0003o000000Gooooo1?l0000?ooooo`;o00002oooool3o`0000Sooooo
0_l0002Kooooo`007?ooool00ol0003oooooooooo`1gooooo`;o00002?ooool3o`0000[ooooo0_l0
0004ooooo`;o00000oooool2o`0000Oooooo0_l00002ooooo`;o0000XOooool001cooooo00?o0000
ooooooooool0O_ooool2o`0000;ooooo0_l0000:ooooo`;o00002Oooool2o`0000_ooooo0_l00000
0ooooooo0000o`00002Nooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o00005oooool2o`00
01Wooooo1?l00004ooooo`;o00001_ooool2o`0009kooooo000Looooo`03o`000?oooooooooo06Go
oooo0_l0000]ooooo`;o00000oooool4o`0000Cooooo0_l00002ooooo`;o0000X_ooool001cooooo
00?o0000ooooooooool0P?ooool2o`0000cooooo2_l000001?oooooo0000o`000?l00009ooooo`Co
0000X?ooool001cooooo00?o0000ooooooooool0K_ooool2o`00013ooooo0_l000000ooooooo0000
o`000009ooooo`Ko00000_ooool2o`0000;ooooo0_l0000;ooooo`?o00001oooool2o`0000_ooooo
0_l00029ooooo`007?ooool00ol0003oooooooooo`1^ooooo`;o00004?ooool2o`000004ooooool0
003o0000ooooo`Co00007_ooool2o`0000Oooooo0_l0000;ooooo`;o00008_ooool2o`0006Gooooo
000Looooo`03o`000?oooooooooo07[ooooo0_l00005ooooo`;o000000?oooooo`000?l000001?l0
0002ooooo`;o00002oooool2o`0001?ooooo0ol000001?oooooo0000o`000?ooool2o`00013ooooo
0_l0000Iooooo`;o0000IOooool001cooooo00?o0000ooooooooool0N_ooool4o`000003ooooool0
003o000000;o000000?oooooo`000?l000001_ooool2o`0000_ooooo0_l0000Aooooo`Go000000Co
ooooo`000?l0003ooooo0_l00006ooooo`;o00002?ooool2o`00083ooooo000Looooo`03o`000?oo
oooooooo07cooooo0_l000000ooooooo0000o`00000;ooooo`?o00001_ooool2o`0000Gooooo0_l0
0005ooooo`?o00001_ooool4o`000004ooooool0003o0000ooooo`;o00001oooool4o`00017ooooo
0_l0001eooooo`007?ooool00ol0003oooooooooo`1gooooo`;o00002?ooool2o`0000Wooooo1?l0
0005ooooo`;o00001Oooool2o`0000Gooooo0ol00008ooooo`;o000000Coooooo`000?l0003ooooo
0_l00005ooooo`;o000000Coooooo`000?l0003o00004Oooool2o`0000;ooooo0_l0001aooooo`00
00Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000oooo
ooooool0L?ooool2o`0000Cooooo0ol00002ooooo`;o00001?ooool2o`0000[ooooo1Ol00007oooo
o`;o00004Oooool2o`0000;ooooo1Ol00006ooooo`;o000000Coooooo`000?l0003o00005Oooool2
o`00077ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1Yooooo`;o00001Oooool2o`000004oooo
ool0003o0000ooooo`;o00000oooool2o`0000kooooo0_l00003ooooo`;o00000_ooool2o`0000?o
oooo0_l0000Aooooo`;o00000_ooool2o`000003ooooool0003o000000Kooooo0_l00005ooooo`;o
0000QOooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00onHV9So8B4Q
onk^kP07ooooo`03o`000?oooooooooo06Wooooo0ol00007ooooo`;o00002Oooool3o`0000[ooooo
0_l000000ooooooo0000o`000004ooooo`;o00001_ooool2o`0001gooooo0_l00005ooooo`;o0000
0_ooool2o`00087ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o
V9RHob4Q8Oo^k^h01_ooool3o`0006[ooooo1?l0000@ooooo`?o00003Oooool2o`0000cooooo0_l0
0006ooooo`;o00001_ooool3o`0001Oooooo0ol00020ooooo`0000?oooooo`000?ooool00_ooool0
0ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0K?ooool2
o`000003ooooool0003o000000Cooooo0ol00005ooooo`?o00003oooool2o`0000cooooo0_l00005
ooooo`;o00001_ooool3o`0001Gooooo0_l000000ooooooo0000o`000020ooooo`0000?ooooooa0@
4?ooool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0Koooool2o`0000Cooooo1?l00004ooooo`?o00003oooool2o`0000Wooooo1Ol00002oooo
o`;o00004_ooool2o`0000gooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l0000@
ooooo`;o0000Ioooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooo
oonHV9So410@00Kooooo00?o0000ooooooooool0K_ooool2o`0000Oooooo0_l00006ooooo`;o0000
2oooool2o`0000cooooo0ol00004ooooo`;o00002?ooool2o`0000Sooooo0_l00005ooooo`;o0000
2Oooool3o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000003Oooool2o`0006Oo
oooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006
ooooo`03o`000?oooooooooo06Cooooo1Ol00005ooooo`;o00003oooool2o`0000Cooooo0_l00002
ooooo`;o000000?oooooo`000?l000001?l00003ooooo`;o00002_ooool4o`0000?ooooo0_l00000
0ooooooo0000o`00000?ooooo`;o00001oooool4o`0000Sooooo0ol0001eooooo`007?ooool00ol0
003oooooooooo`1Mooooo`;o00001Oooool5o`0000gooooo0_l000000ooooooo0000o`000002o`00
00Sooooo0_l00002ooooo`;o00000oooool5o`0000;ooooo0_l00006ooooo`?o000000?oooooo`00
0?l000000_l00003ooooo`;o000000?oooooo`000?l000006?ooool4o`0000Wooooo0_l0001eoooo
o`007?ooool00ol0003oooooooooo`1Mooooo`;o00005oooool2o`000003ooooool0003o000000;o
000000?oooooo`000?l000004Oooool2o`0000[ooooo0ol0000;ooooo`;o00000_ooool3o`0001Go
oooo0ol00005ooooo`;o0000N?ooool001cooooo00?o0000ooooooooool0H?ooool2o`0001;ooooo
1?l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Gooooo0_l00002ooooo`;o0000
3oooool2o`0000oooooo0ol0000@ooooo`;o00001?ooool2o`0000Gooooo0_l00002ooooo`;o0000
0_ooool2o`00073ooooo000Looooo`03o`000?oooooooooo063ooooo0_l0000>ooooo`?o000000?o
ooooo`000?l000001?l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000_l0
0002ooooo`?o00000_ooool2o`0000oooooo0_l0000Iooooo`;o00001oooool2o`0000oooooo0_l0
00000ooooooo0000o`000004o`0006gooooo000Looooo`03o`000?oooooooooo06[ooooo0_l00004
ooooo`?o00001Oooool2o`0000Gooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00004
ooooo`Go00001_ooool2o`0000;ooooo0_l00007ooooo`;o00001?ooool2o`0000Cooooo1Ol0000J
ooooo`Ko00001?ooool2o`0006Oooooo000Looooo`03o`000?oooooooooo05kooooo0_l00005oooo
o`;o00000oooool2o`0000cooooo0_l0000Hooooo`Ko00002?ooool4o`0000Oooooo0_l00002oooo
o`Co00001?ooool2o`000003ooooool0003o000000Oooooo1?l0000Gooooo`Co0000Ioooool001co
oooo00?o0000ooooooooool0GOooool3o`0000Gooooo0_l0000Aooooo`;o00006?ooool2o`0000Wo
oooo0_l000000ooooooo0000o`000003ooooo`;o00002?ooool2o`0000Gooooo0_l00002ooooo`;o
00001oooool4o`0001Oooooo0_l00004ooooo`;o0000Hoooool001cooooo00?o0000ooooooooool0
GOooool2o`0000?ooooo0_l0000Dooooo`;o00002oooool3o`000003ooooool0003o000000Wooooo
0_l00007ooooo`;o00001_ooool2o`0000oooooo0_l00002ooooo`;o00001?ooool2o`0001Gooooo
0ol00006ooooo`;o00000_ooool2o`0006?ooooo000Looooo`03o`000?oooooooooo06;ooooo0_l0
0004ooooo`;o00001oooool4o`00013ooooo0ol000000ooooooo0000o`000009ooooo`;o00009_oo
ool2o`0000;ooooo0_l00005ooooo`;o00003_ooool4o`0000;ooooo0_l000000ooooooo0000o`00
001Wooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o00000_ooool2o`0000Cooooo0_l00007
ooooo`Ko00009_ooool2o`0000Kooooo0_l00005ooooo`Co00003?ooool2o`0000Oooooo1?l0000@
ooooo`;o00000_ooool2o`0000Cooooo0_l0001Tooooo`007?ooool00ol0003oooooooooo`1Noooo
o`;o000000?oooooo`000?l000004_ooool2o`000004ooooool0003o0000ooooo`Co00006oooool2
o`000003ooooool0003o000000Kooooo0_l00005ooooo`Co00003?ooool2o`0000;ooooo0_l00003
ooooo`;o00000oooool2o`0000gooooo0_l00008ooooo`Co0000H_ooool001cooooo0_l0001Roooo
o`;o00005?ooool3o`000003ooooool0003o000000Co00004Oooool2o`0000Kooooo1Ol0000?oooo
o`;o00003Oooool2o`000003ooooool0003o000000Sooooo0_l0000=ooooo`;o00002Oooool4o`00
067ooooo000Looooo`03o`000?oooooooooo05[ooooo0_l00005ooooo`;o00001_ooool2o`0000;o
oooo0_l00008ooooo`;o00001_ooool2o`000003ooooool0003o000000;o00000oooool2o`0000Oo
oooo0_l00002ooooo`;o00000oooool3o`0000Cooooo0_l00002ooooo`;o00000oooool2o`00013o
oooo0_l00006ooooo`;o00000oooool2o`0000Cooooo0_l0000Booooo`Go00001oooool2o`0005Oo
oooo000Looooo`03o`000?oooooooooo05[ooooo0_l00004ooooo`;o000000?oooooo`000?l00000
1?ooool6o`0000cooooo0_l00005ooooo`Co00000oooool2o`0000[ooooo1ol00006ooooo`;o0000
0_ooool3o`0000;ooooo0_l0000=ooooo`;o00001Oooool2o`000004ooooool0003o0000o`0000?o
oooo0_l00004ooooo`;o000000?oooooo`000?l000003_ooool2o`0000;ooooo1?l00005ooooo`;o
0000Eoooool001cooooo00?o0000ooooooooool0?oooool2o`0001cooooo0_l000000ooooooo0000
o`000003o`0000Kooooo0_l0000;ooooo`Go00001Oooool2o`000003ooooool0003o000000kooooo
0_l000000ooooooo0000o`000002o`0000Kooooo0_l00003ooooo`;o00003_ooool2o`000003oooo
ool0003o000000?ooooo1ol00004ooooo`;o00000oooool2o`0000;ooooo0_l0000>ooooo`;o0000
00Coooooo`000?l0003ooooo0_l0001Nooooo`007?ooool00ol0003oooooooooo`0oooooo`;o0000
4_ooool2o`0000Kooooo1?l00002ooooo`;o00000oooool3o`0000Gooooo0_l00006ooooo`Ko0000
1_ooool2o`000003ooooool0003o000000kooooo0_l000000ooooooo0000o`000008ooooo`;o0000
4oooool2o`0000;ooooo0_l00002ooooo`Ko00001oooool2o`000003ooooool0003o000000?ooooo
0_l00009ooooo`;o00001Oooool2o`0000Kooooo0_l0001Iooooo`007?ooool00ol0003ooooooooo
o`1Cooooo`;o00001_ooool4o`000004ooooool0003o0000o`0000?ooooo1Ol00003ooooo`;o0000
1_ooool2o`0000;ooooo0_l00006ooooo`;o00000oooool2o`0000cooooo1?l0000Hooooo`;o0000
2?ooool2o`0000Cooooo0_l00003ooooo`;o00001?ooool3o`0000Gooooo0_l00008ooooo`So0000
0oooool2o`0000?ooooo0_l00009ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0GOoo
ool2o`000003ooooool0003o000000Gooooo1Ol00006ooooo`;o00001_ooool4o`0000Wooooo0_l0
0005ooooo`;o00000oooool2o`0000;ooooo0ol0000Gooooo`;o00004_ooool5o`0000;ooooo0ol0
0003ooooo`;o00000oooool3o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l00000
0ol00003ooooo`;o00003_ooool2o`0004kooooo000Looooo`03o`000?oooooooooo06[ooooo0_l0
00000ooooooo0000o`000003ooooo`;o00001Oooool2o`000003ooooool0003o000000Wooooo0_l0
0003ooooo`Go00000_ooool2o`0000;ooooo0ol0000@ooooo`;o00002oooool2o`0000cooooo0_l0
00000ooooooo0000o`000004o`0000Cooooo0_l00003ooooo`?o000000?oooooo`000?l00000K?oo
ool001cooooo00?o0000ooooooooool0H_ooool2o`0000?ooooo0ol00002ooooo`?o00002?ooool5
o`00013ooooo1_l0000Hooooo`;o00002oooool2o`00017ooooo0_l0000Aooooo`;o0000J_ooool0
01cooooo00?o0000ooooooooool0Coooool4o`0000oooooo1?l000001?oooooo0000o`000?l00002
ooooo`?o00002?ooool2o`000003ooooool0003o000000;o00002_ooool2o`0000Cooooo1?l00003
ooooo`;o00002?ooool2o`0001cooooo0_l0000Nooooo`;o0000J_ooool001cooooo00?o0000oooo
ooooool0Coooool4o`0000Cooooo0_l0000;ooooo`Co00000oooool2o`0000Cooooo0_l00007oooo
o`Co00002_ooool2o`0000;ooooo0_l00007ooooo`Co00001_ooool2o`0000Kooooo0_l0000Boooo
o`Co00007?ooool2o`0006cooooo000Looooo`03o`000?oooooooooo05Oooooo0_l00009ooooo`?o
000000?oooooo`000?l000000_ooool3o`0000Cooooo0_l00007ooooo`Co00002?ooool2o`0000Co
oooo1?l00007ooooo`;o00003_ooool2o`0001;ooooo0_l0000?ooooo`;o00003Oooool2o`00013o
oooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00003_ooool4o`0000;ooooo
1?l000000ooooooo0000o`000003o`0000gooooo0_l000000ooooooo0000o`000008ooooo`;o0000
00?oooooo`000?l000000_ooool3o`0000gooooo0_l00004ooooo`;o00009oooool2o`0001oooooo
0_l0001Jooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00001_ooool2o`0000Kooooo1Ol0
00000ooooooo0000o`000002o`000004ooooool0003o0000o`0000oooooo0_l0000>ooooo`;o0000
4_ooool3o`0000?ooooo0_l0000Gooooo`;o00005?ooool2o`000003ooooool0003o000000;o0000
0oooool2o`0000Oooooo0_l0001Rooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o00002Ooo
ool2o`0000?ooooo0_l00008ooooo`;o00000oooool2o`0000Gooooo0_l000000ooooooo0000o`00
0006ooooo`Co00003oooool2o`0000;ooooo1?l0000Looooo`;o00001_ooool2o`0000cooooo0_l0
00000ooooooo0000o`000002o`0000?ooooo0_l00007ooooo`;o0000H_ooool001cooooo00?o0000
ooooooooool0B?ooool2o`00017ooooo0_l00002ooooo`;o00000oooool2o`0000Sooooo0_l00003
ooooo`;o00001Oooool2o`000004ooooool0003o0000o`0000;ooooo0_l000000ooooooo0000o`00
0002o`0000kooooo0ol00002ooooo`;o00005_ooool2o`0000kooooo0_l000000ooooooo0000o`00
0006ooooo`;o000000?oooooo`000?l00000=_ooool2o`0003gooooo000Looooo`;o0000BOooool2
o`0000kooooo0_l000000ooooooo0000o`00000;ooooo`;o00002oooool2o`000004ooooool0003o
0000o`0000?ooooo0_l00002ooooo`Go00001?ooool3o`0000;ooooo0_l00005ooooo`;o00004?oo
ool2o`0000Wooooo0_l00007ooooo`;o00001Oooool2o`000003ooooool0003o000000Kooooo1Ol0
000>ooooo`;o00003_ooool2o`000003ooooool0003o000001?ooooo0_l0000mooooo`007?ooool0
0ol0003oooooooooo`1Hooooo`;o00003_ooool2o`0000Cooooo0_l00005ooooo`Ko00001?ooool2
o`0000?ooooo1?l00003ooooo`?o00000_ooool2o`0001Oooooo0_l0000Booooo`;o00000_ooool2
o`000004ooooool0003o0000o`0000Wooooo0_l0000?ooooo`?o00003_ooool2o`000003ooooool0
003o000005;ooooo000Looooo`03o`000?oooooooooo04?ooooo0_l0000Vooooo`Go00001oooool3
o`000003ooooool0003o000000Co000000?oooooo`000?l000001?l0000<ooooo`;o00000oooool2
o`0000cooooo1?l00005ooooo`;o00001_ooool2o`0000Cooooo0_l000000ooooooo0000o`000002
ooooo`;o00006_ooool3o`0006Gooooo000Looooo`03o`000?oooooooooo04?ooooo0_l00005oooo
o`;o00006?ooool2o`0000Cooooo1?l00005ooooo`;o00000oooool2o`000003ooooool0003o0000
00?o00000_ooool6o`0000Sooooo0_l000001?oooooo0000o`000?l00003ooooo`Ko00002?ooool4
o`0000Gooooo0_l00006ooooo`;o00001?ooool2o`0000Kooooo0_l0000<ooooo`;o00003_ooool4
o`00067ooooo000Looooo`03o`000?oooooooooo04Gooooo0_l00003ooooo`;o00003?ooool2o`00
00[ooooo0ol00003ooooo`?o00001?ooool9o`0000Sooooo1_l000000ooooooo0000o`000005oooo
o`;o000000Coooooo`000?l0003o00001Oooool4o`00027ooooo0_l00004ooooo`?o00001?ooool2
o`0000Gooooo0_l00008ooooo`;o00001?ooool4o`00067ooooo000Looooo`03o`000?oooooooooo
04Gooooo0_l00008ooooo`;o00001oooool2o`0000_ooooo0_l00004ooooo`;o00001?ooool2o`00
0003ooooool0003o000000Go00000oooool@o`0000Cooooo0_l0000Looooo`;o00001oooool2o`00
00?ooooo1?l00003ooooo`Co00001?ooool2o`0000?ooooo0_l0000:ooooo`;o00001Oooool2o`00
00Sooooo0_l00003ooooo`;o00000oooool2o`0004kooooo000Looooo`03o`000?oooooooooo04oo
oooo0_l00009ooooo`;o00001?ooool2o`000003ooooool0003o000000;ooooo0_l0000;ooooo`;o
000000?oooooo`000?l000000_l00002oooooaCo000000?oooooo`000?l000000_ooool3o`0000?o
oooo0_l00004ooooo`;o00002?ooool2o`0000;ooooo0_l00007ooooo`;o00000oooool2o`0000Go
oooo0_l00002ooooo`;o00001oooool2o`0000kooooo0_l000000ooooooo0000o`000008ooooo`;o
00000oooool4o`000003ooooool0003o000004kooooo000Looooo`03o`000?oooooooooo05[ooooo
0_l00004ooooo`;o000000?oooooo`000?l000001_l00006ooooo`;o000000Coooooo`000?l0003o
oooo0_l00004oooooaCo00001Oooool3o`0000?ooooo0_l00004ooooo`;o00002?ooool2o`00013o
oooo0_l00005ooooo`;o00000_ooool2o`0000_ooooo0_l0000:ooooo`;o00004?ooool4o`000003
ooooool0003o000004kooooo000Looooo`03o`000?oooooooooo047ooooo0_l0000@ooooo`Co0000
2oooool6o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000002o`0000;ooooo
0_l00002ooooo`;o000000?oooooo`000?l000004?l00008ooooo`;o00004Oooool2o`0000;ooooo
0_l0000=ooooo`;o00003?ooool2o`0000?ooooo0_l00002ooooo`Go00000oooool2o`0000;ooooo
0_l00002ooooo`;o00001?ooool2o`0000Gooooo1?l0001Cooooo`007?ooool00ol0003ooooooooo
o`11ooooo`;o00004?ooool6o`0000Wooooo0_l00002ooooo`;o00001_ooool4o`000003ooooool0
003o000000;o00000ooooolFo`000003ooooool0003o000000Gooooo0_l00006ooooo`Co00001ooo
ool2o`0000;ooooo0_l0000;ooooo`;o00003_ooool2o`0000?ooooo0_l00002ooooo`Go00000ooo
ool2o`0000;ooooo0_l00002ooooo`;o00001?ooool2o`0000Gooooo0_l0000;ooooo`;o0000B?oo
ool001cooooo00?o0000ooooooooool0@_ooool2o`0000oooooo0_l00002ooooo`;o00000oooool3
o`0000kooooo0_l000000ooooooo0000o`000003ooooo`;o00000oooool2o`000003ooooool0003o
000001Co00001?ooool2o`0000Oooooo1?l00007ooooo`Co00003Oooool2o`0001Oooooo0ol00005
ooooo`;o00003?ooool2o`0000kooooo0_l00002ooooo`;o0000B?ooool001cooooo00?o0000oooo
ooooool0@_ooool2o`0000Gooooo0_l00008ooooo`;o00001oooool3o`0000kooooo0_l000000ooo
oooo0000o`000006ooooo`;o000000?oooooo`000?l000005ol00003ooooo`?o00000oooool3o`00
00gooooo0_l0000<ooooo`?o00005oooool2o`0000;ooooo1_l0000<ooooo`;o00001Oooool2o`00
00Gooooo1Ol0001;ooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00002?ooool2o`0001_o
oooo0_l00006ooooo`;o000000?oooooo`000?l000005ol00004ooooo`;o00000oooool5o`0000So
oooo0_l00006ooooo`;o00001oooool5o`000004ooooool0003o0000o`0001Gooooo1Ol00009oooo
o`?o00000oooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`00
0?l00000Boooool001cooooo00?o0000ooooooooool0J?ooool2o`0000;ooooo0ol0000<oooooaSo
00002Oooool2o`000003ooooool0003o000000?o00001_ooool2o`0000Kooooo0_l00005ooooo`Oo
000000?oooooo`000?l000001?l00006ooooo`;o00001Oooool2o`0000Cooooo1?l00009ooooo`?o
00000oooool2o`0000Kooooo0_l00002ooooo`Go0000Boooool001cooooo00?o0000ooooooooool0
COooool2o`0000Oooooo0_l00004ooooo`Co00000_ooool2o`000004ooooool0003o0000ooooo`;o
00000_ooool3o`0000_ooooo3ol000000ooooooo0000o`000006o`0000[ooooo0_l000001?oooooo
0000o`000?ooool2o`0000_ooooo0_l00004ooooo`;o000000?oooooo`000?l000002?l000000ooo
oooo0000o`000003o`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l00002oooo
o`;o00007oooool2o`0004cooooo000Looooo`03o`000?oooooooooo04gooooo0ol00006ooooo`;o
00001?ooool8o`000003ooooool0003o000000gooooo0_l00004ooooo`?o000000?oooooo`000?l0
00005?l0000;ooooo`?o00003?ooool3o`0000Cooooo4ol00009ooooo`;o00000oooool6o`0006go
oooo000Looooo`;o0000?Oooool2o`0000gooooo1Ol0000<ooooo`Oo00002_ooool2o`0000Gooooo
0_l00005oooooaco00000_ooool2o`0000Gooooo0_l0000<ooooo`;o00001OoooolCo`0000?ooooo
0_l0000;ooooo`Co00001?ooool2o`0000[ooooo1?l000001?oooooo0000o`000?l00006ooooo`;o
00002?ooool2o`0004?ooooo000Looooo`03o`000?oooooooooo03Wooooo0_l000000ooooooo0000
o`000002ooooo`;o00002Oooool4o`0000gooooo1?l0000=ooooo`;o00003?oooolFo`000003oooo
ool0003o000000?o00000_ooool2o`0000?ooooo0_l00005ooooo`;o00001oooool2o`0000?ooooo
5Ol00003ooooo`;o00002_ooool2o`0000Oooooo0_l00002ooooo`;o00001_ooool4o`000004oooo
ool0003o0000o`0000Kooooo0_l00008ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0
>Oooool2o`0000Gooooo0_l00008ooooo`Go00003Oooool2o`0000Gooooo0_l00002ooooo`;o0000
2?ooool2o`0000Sooooo1?l000000ooooooo0000o`00000Do`0000Sooooo0_l00005ooooo`;o0000
1oooool2o`0000?ooooo5Ol0000?ooooo`;o00002oooool2o`0000oooooo0_l0001Booooo`007?oo
ool00ol0003oooooooooo`1:ooooo`;o00005oooool2o`0000;ooooo0_l00008ooooo`;o00000ooo
ool2o`0000?ooooo6ol0000LoooooaSo00002Oooool2o`0000Cooooo0_l00005ooooo`?o00003Ooo
ool2o`0000;ooooo0ol00009ooooo`;o00001_ooool2o`0003oooooo000Looooo`03o`000?oooooo
oooo04Cooooo0_l00009ooooo`;o00001Oooool2o`0000Gooooo0_l00003ooooo`Co000000?ooooo
o`000?l000002_ooool6o`0000;ooooo0ol000000ooooooo0000o`000008o`000003ooooool0003o
000000Go00006_ooool2o`0000?ooooo6_l00002ooooo`;o00001Oooool2o`0000;ooooo1Ol00002
ooooo`Ko00001Oooool2o`0000?ooooo1?l00002ooooo`;o00002_ooool2o`0000Kooooo0_l0000o
ooooo`007?ooool00ol0003oooooooooo`0dooooo`;o00003_ooool2o`0000Wooooo0_l00005oooo
o`;o00001Oooool2o`0000?ooooo1?l000000ooooooo0000o`00000:ooooo`?o000000?oooooo`00
0?l000001_oooolBo`0000;ooooo0_l00005ooooo`;o00003oooool3o`0000;ooooo6Ol00003oooo
o`;o00001?ooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool2o`00
00Gooooo0_l00003ooooo`;o00004?ooool2o`0000Kooooo0_l0000oooooo`007?ooool00ol0003o
ooooooooo`0dooooo`;o00008Oooool2o`0001[ooooo0_l0000=ooooo`oo00000_ooool2o`0000Go
oooo0_l00008ooooo`;o00001_ooool9o`000003ooooool0003o000001;o00002?ooool2o`0000?o
oooo0_l00009ooooo`;o00001Oooool2o`0000[ooooo0_l0000Aooooo`;o00000_ooool2o`0003_o
oooo000Looooo`03o`000?oooooooooo04cooooo0_l00009ooooo`Co00002?ooool2o`0000cooooo
0_l0000?ooooo`go00000_ooool4o`0000?ooooo0ol00009ooooo`;o00001ooooolMo`0000;ooooo
0_l000001?oooooo0000o`000?ooool4o`000003ooooool0003o0000013ooooo0_l0000:ooooo`;o
00000_ooool2o`0000kooooo0_l000000ooooooo0000o`00000kooooo`007?ooool00ol0003ooooo
ooooo`1<ooooo`?o00000oooool2o`0000?ooooo1?l00004ooooo`;o00000_ooool2o`0000Sooooo
1_l000000ooooooo0000o`000002o`0000Oooooo0_l000000ooooooo0000o`00000;o`0000;ooooo
1?l000000ooooooo0000o`000003o`0000_ooooo0_l00006ooooob3o000000?oooooo`000?l00000
0oooool2o`0001Sooooo0ol00008ooooo`?o00001_ooool2o`0000Gooooo0_l0000nooooo`007?oo
ool00ol0003oooooooooo`18ooooo`?o000000Coooooo`000?l0003o00000oooool2o`0000?ooooo
0_l00006ooooo`;o00001?ooool2o`0000Gooooo1Ol00003ooooo`Co00001oooool3o`000003oooo
ool0003o000000Oooooo0_l000000ooooooo0000o`000005ooooo`;o00003_ooool3o`0000Gooooo
3ol000000ooooooo0000o`00000>o`0001gooooo0_l000001?oooooo0000o`000?l00009ooooo`;o
00001_ooool2o`0004Gooooo000Looooo`03o`000?oooooooooo04Cooooo1ol000000ooooooo0000
o`000004ooooo`;o00001oooool2o`0000?ooooo0_l00003ooooo`;o00001Oooool2o`0000oooooo
0_l000001?oooooo0000o`000?ooool2o`0000[ooooo0_l0000@ooooo`;o00000oooool3o`0000Co
oooo3ol000000ooooooo0000o`000002o`000003ooooool0003o000000Co00000oooool3o`0000Wo
oooo0_l0000Booooo`Go00004_ooool2o`0004Gooooo000Looooo`03o`000?oooooooooo03[ooooo
0_l00008ooooo`Go00002Oooool4o`0000Cooooo0ol00003ooooo`;o00001?ooool2o`000003oooo
ool0003o000001;ooooo0_l0000>ooooo`;o00003_ooool2o`0000;ooooo1?l000000ooooooo0000
o`000004oooooaoo00003?ooool2o`0000Kooooo0_l0000<ooooo`;o00002oooool2o`0000Oooooo
0_l00009ooooo`;o0000>Oooool001cooooo00?o0000ooooooooool09_ooool2o`0001;ooooo0_l0
0006ooooo`;o000000?oooooo`000?l000001_ooool2o`0000;ooooo0_l000000ooooooo0000o`00
0002o`0000;ooooo0ol00009ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Oooooo`;o0000
3_ooool2o`000003ooooool0003o000000?o00001OoooolQo`0000[ooooo1?l00006ooooo`;o0000
4?ooool2o`000003ooooool0003o000000Cooooo0_l00007ooooo`;o00002Oooool4o`0003Oooooo
000Looooo`03o`000?oooooooooo02Kooooo0_l0000>ooooo`;o00002_ooool2o`0000Wooooo0_l0
0002ooooo`;o00000oooool2o`0000gooooo0_l00005ooooo`?o00000_ooool2o`0000Wooooo0_l0
000<ooooo`;o00001_ooool2o`0000Kooooo0_l00004ooooo`?o00001ooooolQo`0000[ooooo0_l0
000Jooooo`;o000000?oooooo`000?l000000ol000000ooooooo0000o`00000:ooooo`;o00002?oo
ool2o`0003Oooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o0000
00?o410@ooooooooool01?ooool00ol0003oooooooooo`0fooooo`;o000000?oooooo`000?l00000
1_ooool2o`0000_ooooo1?l00008ooooo`?o00002?ooool2o`0000Kooooo1ol00008ooooo`;o0000
00?oooooo`000?l000000_l000000ooooooo0000o`000004ooooo`;o00001_ooool2o`0000Kooooo
0_l00006ooooo`;o00000_ooool2o`0000Cooooo0_l00002ooooo`_o000000?oooooo`000?l00000
1_l000000ooooooo0000o`000004o`0000cooooo0ol00006ooooo`Co00001Oooool2o`0000_ooooo
0ol000000ooooooo0000o`00000:ooooo`?o0000@?ooool00006oooooomgMgOoV9RHoooooonHV9So
MgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0iooooo`;o
00001_ooool2o`0000_ooooo1ol00003ooooo`Go00004Oooool3o`000003ooooool0003o000000_o
oooo1?l000000ooooooo0000o`00000>ooooo`;o00000_ooool2o`0000Sooooo0_l00002ooooo`;o
00001?ooool3o`000003ooooool0003o000001_o00002_ooool3o`0000Kooooo1?l00005ooooo`;o
00002?ooool2o`0000?ooooo0_l00003ooooo`?o000000?oooooo`000?l000000_l00002ooooo`;o
00004?ooool2o`0002kooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo
1Ol00006ooooo`03o`000?oooooooooo03gooooo1?l0000@ooooo`Go00000_ooool5o`0000cooooo
0_l00003ooooo`;o00000_ooool3o`000003ooooool0003o000000;ooooo0_l0000Hooooo`;o0000
0_ooool2o`000004ooooool0003o0000ooooo`;o00003?ooool3o`000003ooooool0003o000001_o
00001oooool2o`000004ooooool0003o0000o`0000Oooooo0_l00006ooooo`;o00002?ooool2o`00
00?ooooo0_l00003ooooo`?o000000?oooooo`000?l000001?l0000Booooo`;o0000;_ooool00003
ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?m4A4CogMgMooooool00007oooo
o`?o0000?Oooool4o`0000Cooooo0_l0000=ooooo`;o00000_ooool2o`000003ooooool0003o0000
00?ooooo0_l00002ooooo`;o00000oooool2o`0000Sooooo0_l000000ooooooo0000o`000002oooo
o`;o00000_ooool2o`0000Sooooo0_l0000;ooooo`;o00001?ooool5o`0000Gooooo0_l00006oooo
oako00001oooool9o`0000Sooooo0_l00003ooooo`?o00002?ooool2o`0000kooooo1?l00012oooo
o`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`00
00Oooooo00?o0000ooooooooool0?Oooool2o`0000Kooooo0_l0000Iooooo`;o00000_ooool2o`00
00?ooooo0ol00004ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Kooooo1?l00004oooo
o`;o00001?ooool3o`0000Gooooo0_l00007ooooo`;o00001Oooool4o`000003ooooool0003o0000
00ko000000?oooooo`000?l000001ol00007ooooo`;o00000_ooool2o`000004ooooool0003o0000
ooooo`?o00001?ooool2o`000003ooooool0003o000000;o00002Oooool7o`0000Kooooo0_l00000
0ooooooo0000o`000014ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:oooo
o`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0?Oooool4o`0000Kooooo1?l00008oooo
o`;o000000Coooooo`000?l0003o00004?ooool3o`0000Cooooo0_l000000ooooooo0000o`00000A
ooooo`Oo000000?oooooo`000?l000000_ooool5o`0000Wooooo0_l00008ooooo`Co00000ooooolH
o`0001;ooooo1Ol00003ooooo`Ko00002_ooool8o`0000Gooooo0_l00004ooooo`;o0000@Oooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oo
oooooooo03oooooo0_l000000ooooooo0000o`000003ooooo`Co00000oooool2o`0000?ooooo0_l0
00001?oooooo0000o`000?l0000=ooooo`Go00000oooool2o`0001Wooooo1?l00005ooooo`Go0000
2Oooool2o`0000Sooooo0ol00002oooooaWo00004oooool6o`0000;ooooo0ol000000ooooooo0000
o`00000:ooooo`;o00001?ooool2o`0000Kooooo1?l000000ooooooo0000o`000011ooooo`0000Ko
ooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000oooooooo
ool0@_ooool2o`0000Cooooo0_l00004ooooo`?o00000_ooool6o`0000;ooooo0_l00009ooooo`Co
00001?ooool2o`0001Kooooo0_l0000Sooooo`;o00000_oooolIo`0000Sooooo0_l00002ooooo`;o
00002?ooool5o`000003ooooool0003o000000?o00002?ooool2o`000003ooooool0003o000000_o
oooo1ol00011ooooo`007?ooool00ol0003oooooooooo`0nooooo`Co00003Oooool2o`0000?ooooo
0ol000001?oooooo0000o`000?ooool2o`0002Wooooo0_l0000;ooooo`;o00000oooool2o`0000;o
oooo0_l00002ooooo`;o00000_ooool2o`0000Gooooo1?l00002ooooo`ko00000_ooool6o`0000Wo
oooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo1?l000000ooooooo0000o`000002ooooo`;o
00002_ooool2o`000003ooooool0003o000000_ooooo0_l00002ooooo`?o00003_ooool2o`00037o
oooo000Looooo`03o`000?oooooooooo03kooooo1?l0000Booooo`;o00000_ooool2o`0000Oooooo
1?l0000^ooooo`Co000000?oooooo`000?l000000_ooool3o`000003ooooool0003o000000;ooooo
0_l00007ooooo`Co00001?ooool:o`000003ooooool0003o000000Go00003Oooool2o`0000;ooooo
0_l000001?oooooo0000o`000?l00003ooooo`?o00003Oooool2o`0000[ooooo0_l00002ooooo`;o
00000oooool2o`0000kooooo0_l0000aooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o0000
0oooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo1?l0000Dooooo`;o0000
4_ooool2o`0000Kooooo0_l00006ooooo`;o000000?oooooo`000?l000003?ooool3o`0000Kooooo
0_l00002ooooo`Oo000000Coooooo`000?l0003o00000_ooool2o`0000Wooooo0_l00004ooooo`Go
00001?ooool2o`0000gooooo0_l000000ooooooo0000o`000004o`0000?ooooo0ol00006ooooo`;o
0000@Oooool001cooooo00?o0000ooooooooool0B_ooool2o`0000;ooooo0ol0000<ooooo`;o0000
1?ooool2o`0001Cooooo0_l0000Booooo`;o00001_ooool2o`0000[ooooo0_l0000;ooooo`;o0000
0_ooool2o`0000?ooooo0ol000000ooooooo0000o`000005o`0000;ooooo0_l00002ooooo`;o0000
2?ooool3o`0000Cooooo0ol0000Booooo`;o000000?oooooo`000?l000001ol00004ooooo`?o0000
B?ooool001cooooo00?o0000ooooooooool0:oooool2o`0001Oooooo0_l00002ooooo`;o00001?oo
ool2o`00013ooooo0_l0000oooooo`;o00003oooool2o`0000?ooooo0ol000000ooooooo0000o`00
0003o`0000?ooooo0ol00002ooooo`;o00002?ooool2o`000003ooooool0003o000000gooooo0_l0
0008ooooo`;o00000_ooool3o`0000[ooooo1_l00004ooooo`;o00003oooool2o`0002gooooo000L
ooooo`03o`000?oooooooooo01Kooooo0_l0000Cooooo`;o00002?ooool2o`0000gooooo0_l00002
ooooo`;o00002Oooool2o`000004ooooool0003o0000o`0000Kooooo0ol0000Uooooo`;o00002?oo
ool2o`0000Wooooo0_l00009ooooo`;o00002?ooool2o`00013ooooo0_l0000<ooooo`?o000000?o
ooooo`000?l000002Oooool3o`000003ooooool0003o000000Co00000oooool2o`0000cooooo0_l0
0002ooooo`Ko00001?ooool2o`0000oooooo0_l0000]ooooo`007?ooool00ol0003oooooooooo`0F
ooooo`;o00007Oooool2o`0000gooooo0_l0000;ooooo`Co000000Coooooo`000?l0003o00000ooo
ool2o`000003ooooool0003o000002Kooooo0_l00002ooooo`Co00000_ooool3o`0000Cooooo0_l0
0002ooooo`;o00002Oooool2o`0000;ooooo0_l000000ooooooo0000o`000003o`0001cooooo1?l0
0002ooooo`Co00001oooool3o`0000?ooooo1Ol00002ooooo`;o00003?ooool2o`0000Cooooo0_l0
00000ooooooo0000o`000003ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0<_ooool2
o`0000?ooooo0_l00007ooooo`;o00002Oooool2o`0000Cooooo1?l000000ooooooo0000o`000004
ooooo`;o00005oooool2o`0001Cooooo1_l000000ooooooo0000o`000006o`000003ooooool0003o
000000kooooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l00005ooooo`;o00002_ooool2
o`0000Cooooo0_l00004ooooo`Co00004?ooool2o`0000Wooooo0_l00002ooooo`;o00001Oooool4
o`000003ooooool0003o000000?ooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0boooo
o`;o00000oooool2o`0000Oooooo0ol00006ooooo`Co00000_ooool2o`0000;ooooo0_l0000Ioooo
o`;o00001Oooool4o`0000Cooooo0_l0000?ooooo`?o00000_ooool7o`000003ooooool0003o0000
00Gooooo0_l0000Booooo`;o00001Oooool6o`0000?ooooo0_l000000ooooooo0000o`00000Doooo
o`;o00001_ooool2o`0000Sooooo1Ol00002ooooo`;o00001Oooool4o`000003ooooool0003o0000
04?ooooo000Looooo`03o`000?oooooooooo047ooooo0_l00006ooooo`Co00000_ooool3o`0000;o
oooo0_l00007ooooo`Co00003Oooool2o`0000Gooooo1Ol00003ooooo`;o00004?ooool2o`0000;o
oooo0_l00003ooooo`;o000000?oooooo`000?l000001Oooool2o`00013ooooo0_l00008ooooo`Go
00000oooool2o`0001Oooooo0_l00006ooooo`?o00001oooool5o`0000?ooooo0ol00006ooooo`Go
0000@_ooool001cooooo00?o0000ooooooooool0@Oooool2o`0000Oooooo0ol00002ooooo`?o0000
0_ooool2o`0000Oooooo1?l0000Gooooo`;o00000oooool2o`0000Cooooo1?l00008ooooo`;o0000
4oooool3o`0000Gooooo0_l00004ooooo`Go00001oooool6o`0000;ooooo0_l00006ooooo`?o0000
5oooool2o`0000Wooooo0_l00004ooooo`?o00001Oooool3o`000003ooooool0003o000004;ooooo
000Looooo`;o0000=?ooool2o`0000Kooooo1?l00002ooooo`Co00001Oooool2o`0000?ooooo0_l0
000Rooooo`;o00002?ooool2o`0000?ooooo1Ol0000Mooooo`?o00001Oooool2o`0000Cooooo0_l0
00000ooooooo0000o`000009ooooo`Co00002?ooool9o`0000_ooooo0_l00002ooooo`;o00001?oo
ool3o`0000Kooooo0_l0000<ooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0<oooool2
o`0000Kooooo1?l00002ooooo`Co00004oooool2o`0001Gooooo0_l00002ooooo`;o00002Oooool2
o`0000;ooooo1?l0000:ooooo`;o00000_ooool2o`0000Oooooo0_l0000Cooooo`;o00003?ooool2
o`000003ooooool0003o000000Co00000oooool2o`0000?ooooo1?l0000;ooooo`Ko00001?ooool4
o`0005_ooooo000Looooo`03o`000?oooooooooo047ooooo0ol00006ooooo`;o00002_ooool4o`00
00[ooooo0_l00002ooooo`;o00001Oooool2o`0000gooooo0_l00004ooooo`;o00002_ooool2o`00
00;ooooo1?l00004ooooo`?o00003Oooool2o`0000Cooooo0_l00005ooooo`Co00001_ooool6o`00
00Cooooo0_l0000Cooooo`;o00001?ooool2o`0000;ooooo0_l00008ooooo`;o0000DOooool001co
oooo00?o0000ooooooooool0@_ooool2o`0000Kooooo0_l00008ooooo`Co00003?ooool2o`000003
ooooool0003o000000Co00004Oooool2o`0000Cooooo0_l0000>ooooo`Co00001?ooool3o`0000Oo
oooo0_l00004ooooo`;o00001_ooool9o`0000Oooooo0_l000000ooooooo0000o`000004ooooo`;o
00006Oooool2o`0000cooooo0_l00006ooooo`;o00000oooool2o`0004Cooooo000Looooo`03o`00
0?oooooooooo03[ooooo0_l0000Hooooo`?o00002oooool2o`0000?ooooo1_l00005ooooo`;o0000
0_ooool4o`0000Cooooo0_l00006ooooo`;o00005?ooool6o`000004ooooool0003o0000ooooo`;o
00003?ooool7o`0000Wooooo0_l000000ooooooo0000o`000004ooooo`;o00004?ooool2o`0000co
oooo0_l0000?ooooo`;o00000oooool4o`0004;ooooo000Looooo`03o`000?oooooooooo037ooooo
0_l00007ooooo`;o00002_ooool2o`0000[ooooo0ol000000ooooooo0000o`00000:ooooo`;o0000
0oooool2o`0000Gooooo0_l00002ooooo`;o00000_ooool4o`0000?ooooo0_l00006ooooo`Go0000
2Oooool2o`0000?ooooo0_l00002ooooo`Ko000000?oooooo`000?l000002_ooool4o`0002cooooo
0_l00005ooooo`;o00001Oooool2o`0000Sooooo0_l00004ooooo`Co000000Coooooo`000?l0003o
oooo0_l00012ooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00003Oooool2o`0000Cooooo
0_l00007ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000Sooooo0_l00002ooooo`;o
000000?oooooo`000?l000001Oooool6o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l0
00000_ooool2o`000003ooooool0003o000000Go00002?ooool2o`0000?ooooo0_l00003ooooo`;o
00004?ooool4o`000003ooooool0003o000002Kooooo0_l00005ooooo`;o000000?oooooo`000?l0
00000_l0000=ooooo`;o00001?ooool7o`0004Gooooo000Looooo`03o`000?oooooooooo03gooooo
0_l000000ooooooo0000o`000009ooooo`;o000000Coooooo`000?l0003o00000oooool2o`0000[o
oooo0_l00002ooooo`;o00001_ooool9o`000003ooooool0003o000000ko000000?oooooo`000?l0
00000_l0000=ooooo`;o00000_ooool3o`0000Oooooo0_l0000<ooooo`;o00004?ooool2o`0000Go
oooo1_l00009ooooo`;o00001Oooool2o`0000?ooooo0_l00005ooooo`Co00001?ooool2o`0000Go
oooo1?l0000;ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool05?ooool2o`0002Oooooo
0_l0000<ooooo`;o000000?oooooo`000?l000001?ooool2o`0000_ooooo0_l00009ooooo`?o0000
00Coooooo`000?l0003ooooo3_l000001?oooooo0000o`000?l0000?ooooo`;o00001_ooool2o`00
00Sooooo0_l0000Nooooo`;o00001Oooool6o`0000Cooooo0_l0000:ooooo`;o00001?ooool2o`00
00Cooooo1?l00004ooooo`;o00001Oooool2o`0000Cooooo0ol00006ooooo`;o0000>_ooool001co
oooo00?o0000ooooooooool05?ooool2o`00027ooooo0_l0000Eooooo`;o00004Oooool2o`0000[o
oooo0_l000000ooooooo0000o`00000:o`000003ooooool0003o000000;o000000?oooooo`000?l0
00001Ol0000;ooooo`;o00001?ooool5o`0000gooooo0_l0000Hooooo`;o00003oooool2o`0000[o
oooo0_l00004ooooo`;o00000_ooool2o`0000gooooo0_l000000ooooooo0000o`000003ooooo`?o
0000@_ooool001cooooo00?o0000ooooooooool0;Oooool2o`0000Sooooo0_l00006ooooo`;o0000
1Oooool2o`0002Cooooo1?l000000ooooooo0000o`00000;o`000003ooooool0003o000000;ooooo
1ol00006ooooo`;o00002?ooool5o`0000Wooooo0_l00002ooooo`;o00002_ooool2o`0001Cooooo
0_l0000Mooooo`;o00003Oooool6o`0000[ooooo0_l0000kooooo`007?ooool00ol0003ooooooooo
o`0Vooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`;o00000_ooool3o`0000Gooooo0_l0
0006ooooo`;o00005_ooool2o`0000Cooooo2?l000000ooooooo0000o`00000:o`000003ooooool0
003o000000;o000000?oooooo`000?l000000ol00004ooooo`;o00002_ooool2o`0000?ooooo0_l0
0005ooooo`;o00003_ooool2o`0000Gooooo1Ol0000:ooooo`;o00000oooool2o`0000kooooo0_l0
0008ooooo`;o00003oooool4o`000003ooooool0003o000000Oooooo0_l0000kooooo`007?ooool0
0ol0003oooooooooo`0Vooooo`?o00002_ooool2o`0000Cooooo0ol00002ooooo`;o00003_ooool2
o`0000Oooooo0_l0000=ooooo`So000000?oooooo`000?l000000ol000000ooooooo0000o`000009
o`0000;ooooo0_l00002ooooo`?o000000?oooooo`000?l000005Oooool2o`0001?ooooo0_l00004
ooooo`[o00003Oooool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2
o`0000?ooooo0_l00003ooooo`;o00002oooool2o`0000;ooooo0_l00003ooooo`;o00002Oooool2
o`0003Wooooo000Looooo`03o`000?oooooooooo03Kooooo0_l000000ooooooo0000o`000004oooo
o`Co00003Oooool2o`0000Gooooo0_l0000?ooooo`Go00000_oooolAo`000003ooooool0003o0000
00?ooooo0_l00007ooooo`?o00002_ooool2o`0000?ooooo0_l00002ooooo`Co00001oooool2o`00
00Cooooo0_l00004ooooo`[o00000_ooool2o`0000gooooo0_l00003ooooo`;o000000?oooooo`00
0?l000001oooool2o`000003ooooool0003o000000;o00001?ooool2o`0000Gooooo0_l0000>oooo
o`;o00000_ooool2o`0003Wooooo000Looooo`03o`000?oooooooooo037ooooo0ol00002ooooo`;o
00001_ooool5o`0000Gooooo0_l00005ooooo`?o00005_ooool4o`000003ooooool0003o000000?o
000000?oooooo`000?l000004?l00003ooooo`;o000000Goooooo`000?l0003o0000ooooo`03o`00
00[ooooo0_l000000ooooooo0000o`000002o`0000;ooooo1?l00007ooooo`;o00001_ooool2o`00
00?ooooo1_l000000ooooooo0000o`000002ooooo`;o00005_ooool2o`0000Wooooo1?l00004oooo
o`;o00005Oooool2o`0003gooooo000Looooo`03o`000?oooooooooo037ooooo0ol0000:ooooo`;o
00002?ooool2o`0000Gooooo0_l0000Fooooo`So000000?oooooo`000?l000001_l000000ooooooo
0000o`00000?o`000004ooooool0003o0000o`0000Wooooo1?l00004ooooo`;o00001_ooool2o`00
00Kooooo0_l000000ooooooo0000o`000004ooooo`;o00000oooool2o`000004ooooool0003o0000
o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000002Oooool3o`0000Kooooo0_l0000:
ooooo`;o00002Oooool2o`000003ooooool0003o000000;o00001?ooool2o`0000Gooooo0ol0000m
ooooo`007?ooool2o`0003oooooo0_l0000?ooooo`;o00005_oooolBo`0000;ooooo3_l00007oooo
o`;o00000_ooool2o`000003ooooool0003o000000;o00001?ooool2o`0000Gooooo0ol00006oooo
o`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000;o00000_ooool2o`00
00;ooooo0_l00002ooooo`;o000000?oooooo`000?l000001oooool5o`000003ooooool0003o0000
01[ooooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l000000ooooooo0000o`000002oooo
o`?o0000?Oooool001cooooo00?o0000ooooooooool0Coooool2o`0000Wooooo0_l0000<ooooo`;o
00000_ooool6o`0000;ooooo4ol000000ooooooo0000o`000003o`000003ooooool0003o000000;o
00000_ooool2o`0000;ooooo0_l00004ooooo`;o00001_ooool3o`0000Kooooo0_l00004ooooo`;o
00001?ooool5o`0000?ooooo0_l00007ooooo`;o00000_ooool2o`0000?ooooo0_l00004ooooo`;o
00001oooool2o`0001oooooo0_l0000Eooooo`;o0000:oooool001cooooo00?o0000ooooooooool0
>?ooool3o`0000;ooooo0_l00006ooooo`;o00004oooool2o`0000Cooooo0_l00006ooooobGo0000
00?oooooo`000?l000002?ooool2o`0000Cooooo1?l00005ooooo`?o00001?ooool3o`0000;ooooo
1?l00007ooooo`;o00000oooool3o`0000Kooooo0_l00002ooooo`Co00002?ooool2o`000004oooo
ool0003o0000o`0000;ooooo0_l00008ooooo`;o00005_ooool2o`0001Cooooo0_l0000[ooooo`00
7?ooool00ol0003oooooooooo`0hooooo`?o00000_ooool2o`0000Kooooo0_l00007ooooo`;o0000
2Oooool2o`0000Gooooo1Ol00003ooooo`Go000000?oooooo`000?l000007Ol000000ooooooo0000
o`000003ooooo`;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000006ooooo`;o0000
1?ooool2o`0000?ooooo1?l0000<ooooo`Co00001Oooool5o`000003ooooool0003o000000?ooooo
0_l00002ooooo`Oo00001oooool2o`0000?ooooo0_l00005ooooo`;o00003oooool2o`0000;ooooo
0_l00005ooooo`;o0000=_ooool001cooooo00?o0000ooooooooool09?ooool2o`0000[ooooo1?l0
0005ooooo`;o00001oooool2o`0000;ooooo0_l00006ooooo`;o00002Oooool2o`0000?ooooo1ol0
0006oooooa;o000000?oooooo`000?l000001ol000001Ooooooo0000o`000?l0003ooooo00Go0000
0_ooool2o`0000Cooooo0_l00002ooooo`Go00004oooool2o`0000Sooooo0_l00002ooooo`Co0000
0_oooolGo`0000Wooooo0_l00002ooooo`;o00001_ooool2o`00013ooooo0_l000000ooooooo0000
o`000005ooooo`?o0000=Oooool001cooooo00?o0000ooooooooool09?ooool2o`0000[ooooo1?l0
0005ooooo`;o00001oooool2o`000004ooooool0003o0000o`0001Kooooo2?l000000ooooooo0000
o`00000Xo`0000Wooooo0_l00002ooooo`?o00005?ooool2o`0000Sooooo0ol00004ooooo`;o0000
00?oooooo`000?l000000ol000000ooooooo0000o`00000:o`000003ooooool0003o000000;o0000
3Oooool2o`0000;ooooo0_l00007ooooo`;o00002oooool3o`0000Sooooo0_l00009ooooo`;o0000
:_ooool001cooooo00?o0000ooooooooool08_ooool2o`0000_ooooo0_l0000;ooooo`;o00001ooo
ool2o`0000;ooooo0_l0000Eooooo`?o000000Coooooo`000?l0003ooooo;Ol00006ooooo`;o0000
0oooool4o`0000Gooooo0_l00009ooooo`Ko00001oooool2o`0000Cooooo0_l00002oooooa;o0000
0_ooool4o`0000gooooo1?l00005ooooo`Co00002?ooool3o`000004ooooool0003o0000o`0001;o
oooo0_l0000Zooooo`007?ooool00ol0003oooooooooo`0Rooooo`;o00002oooool2o`0000Sooooo
0_l000000ooooooo0000o`000002o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l00000
0oooool2o`0000_ooooo0_l00003ooooo`Go000000?oooooo`000?l000003Ol00002oooooa7o0000
00?oooooo`000?l000001_l0000<ooooo`?o00001Oooool2o`0000Oooooo1?l00002ooooo`;o0000
3ooooolFo`0000;ooooo0_l0000=ooooo`;o00001oooool2o`0000[ooooo0ol00002ooooo`;o0000
?_ooool001cooooo00?o0000ooooooooool05oooool2o`0001[ooooo0_l00002ooooo`Co00000ooo
ool2o`0000;ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`000?l00000
0oooool2o`0000[ooooo0ol00002oooooc;o00003?ooool3o`0000gooooo1?l0000Dooooo`?o0000
00?oooooo`000?l000004?l000000ooooooo0000o`000002o`0001Kooooo0_l0000;ooooo`;o0000
2Oooool2o`000003ooooool0003o000003?ooooo000Looooo`03o`000?oooooooooo01Oooooo0_l0
000Jooooo`;o00000_ooool2o`0000cooooo0ol0000=ooooo`;o00001_ooool2o`0000;ooooo0ol0
0002oooooaoo000000?oooooo`000?l000003Ol00002ooooo`;o000000?oooooo`000?l000001Ooo
ool2o`0000gooooo0_l0000Cooooo`?o000000?oooooo`000?l000006_l0000=ooooo`;o00001Ooo
ool2o`0000_ooooo0_l00009ooooo`;o000000?oooooo`000?l00000<oooool001cooooo00?o0000
ooooooooool08?ooool2o`0001Cooooo1?l0000Hooooo`;o000000?oooooo`000?l000002_ooool2
o`0000?ooooo7ol000000ooooooo0000o`000006o`0000;ooooo1Ol000001Ooooooo0000o`000?l0
003ooooo00;o00001_ooool2o`0001[ooooo0_l00003ooooo`Go000000?oooooo`000?l000005Ol0
0002ooooo`?o00000_ooool2o`0000Wooooo0_l0000Vooooo`;o0000;Oooool001cooooo00?o0000
ooooooooool08?ooool4o`0001;ooooo1?l000001?oooooo0000o`000?ooool2o`0001;ooooo0_l0
0004ooooo`;o00001oooool3o`0000;ooooo0_l000000ooooooo0000o`00000Bo`000003ooooool0
003o000000Go000000?oooooo`000?l000001Ol00003ooooo`Co00000_ooool2o`0000[ooooo0ol0
000=ooooo`?o00001Oooool2o`0000;ooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo
5ol00007ooooo`;o00003oooool2o`0000Kooooo0_l000000ooooooo0000o`000006ooooo`;o0000
0oooool4o`0000Kooooo0_l0000]ooooo`007?ooool00ol0003oooooooooo`0Rooooo`;o00005ooo
ool2o`000003ooooool0003o000000;ooooo0_l0000Cooooo`?o00001Oooool7o`0000Gooooo8ol0
0005ooooo`;o00001_ooool2o`0000Gooooo0ol00007ooooo`Co00000_ooool3o`0000Gooooo0_l0
0002ooooo`Co00001?oooolJo`0000Oooooo0_l0000?ooooo`;o00001_ooool2o`000003ooooool0
003o000000Kooooo0_l00003ooooo`Co0000=Oooool001cooooo00?o0000ooooooooool0<Oooool2
o`0000oooooo0_l00009ooooo`;o00001Oooool2o`000003ooooool0003o000000Kooooo0_l00003
ooooo`Go00000_oooolSo`000003ooooool0003o000000Co00001_ooool2o`0000Gooooo1?l00006
ooooo`Co00001?ooool2o`0000[ooooo0_l00004ooooo`Co000000?oooooo`000?l000005?l00006
ooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0<Oooool2o`0000?ooooo0_l00006oooo
o`;o00000_ooool2o`0000Wooooo0_l00005ooooo`;o00000_ooool2o`0000?ooooo0_l00005oooo
o`Go000000?oooooo`000?l000008_l000000ooooooo0000o`000004o`0000gooooo1_l00003oooo
o`;o00001_ooool3o`0000Kooooo0_l000000ooooooo0000o`000005ooooo`;o00000oooool9o`00
00;ooooo2ol000000ooooooo0000o`00000Aooooo`Ko00005?ooool2o`0003Sooooo000Looooo`03
o`000?oooooooooo03Kooooo0_l00006ooooo`;o00000_ooool2o`000003ooooool0003o000000;o
00003oooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool4o`000003ooooool0003o000002;o
000000?oooooo`000?l000001Ol0000<ooooo`;o000000Coooooo`000?l0003o00000oooool2o`00
0003ooooool0003o000000?ooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o0000
00?ooooo0_l00003oooooa_o00004Oooool6o`00017ooooo0_l000000ooooooo0000o`00000hoooo
o`007?ooool2o`0001gooooo0_l0000Cooooo`;o00001?ooool3o`0000_ooooo1?l0000;ooooo`;o
00002Oooool4o`0000;ooooo<Ol0000?ooooo`;o00001oooool2o`0000Oooooo0ol00002ooooo`;o
00000_ooool2o`0000;ooooo0_l00003oooooaWo00001oooool2o`0000gooooo0_l00003ooooo`;o
00003Oooool2o`000003ooooool0003o000003Sooooo000Looooo`03o`000?oooooooooo01cooooo
0_l0000Cooooo`?o00000oooool4o`000004ooooool0003o0000o`0000_ooooo0_l00008ooooo`;o
00002?ooool3o`0000?ooooo:Ol000000ooooooo0000o`000004ooooo`;o00005Oooool2o`0000_o
oooo0_l00002ooooo`;o00000_ooool2o`0000Oooooo5ol00002ooooo`;o000000?oooooo`000?l0
00000_ooool2o`0000Kooooo0_l00005ooooo`;o00000oooool2o`00013ooooo1?l0000fooooo`00
7?ooool00ol0003oooooooooo`0booooo`;o00001Oooool2o`000004ooooool0003o0000o`0000Oo
oooo1_l00003ooooo`;o00003Oooool2o`0000Cooooo0_l00002ooooo`;o000000Coooooo`000?l0
003ooooo5_l000000ooooooo0000o`000005o`0000;ooooo0ol00003ooooo`;o00003?ooool2o`00
00Oooooo0_l00003ooooo`;o00004oooool2o`0000;ooooo5ol00002ooooo`;o000000?oooooo`00
0?l000001_ooool2o`0000;ooooo0_l0000;ooooo`;o00004?ooool3o`0003Kooooo000Looooo`03
o`000?oooooooooo03Sooooo0ol0000;ooooo`Go00001?ooool2o`0001Cooooo0_l000001Ooooooo
0000o`000?l0003ooooo01Wo00000_ooool6o`000004ooooool0003o0000o`0000?ooooo0_l0000<
ooooo`;o00003?ooool2o`0001?ooooo0_l000000ooooooo0000o`00000Io`0000[ooooo0_l00005
ooooo`;o00002?ooool2o`0000?ooooo0_l00004ooooo`;o00001Oooool2o`0003Oooooo000Loooo
o`03o`000?oooooooooo03Cooooo0_l00002ooooo`;o00003oooool2o`0000kooooo1Ol00007oooo
o`Wo000000?oooooo`000?l000007?l000000ooooooo0000o`000002ooooo`Co00000oooool2o`00
00Cooooo1?l0000Uooooo`;o000000?oooooo`000?l000006?l0000>ooooo`Go00002oooool2o`00
00Cooooo0ol00006ooooo`;o0000=Oooool001cooooo00?o0000ooooooooool0=?ooool2o`0000go
oooo0_l00003ooooo`?o00000oooool2o`0000Wooooo1_l00007ooooo`So000000?oooooo`000?l0
00008?l000000ooooooo0000o`000005ooooo`;o00001?ooool4o`0000Cooooo0_l0000Roooooa[o
00003_ooool2o`000003ooooool0003o000000Gooooo0_l00004ooooo`;o00000oooool6o`0000Co
oooo0_l0000eooooo`007?ooool00ol0003oooooooooo`0Tooooo`;o00006oooool4o`0000?ooooo
0_l00004ooooo`;o00003Oooool2o`0000Oooooo1?l00004ooooo`go000000?oooooo`000?l00000
4?l000000ooooooo0000o`00000Fooooo`;o00001Oooool2o`0001_ooooo6Ol0000Iooooo`;o0000
2Oooool2o`0000;ooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0Tooooo`;o00004ooo
ool2o`0000Kooooo0_l0000:ooooo`?o00003?ooool2o`0000[ooooo0_l000001?oooooo0000o`00
0?oooolRo`0000;ooooo0_l00008ooooo`;o00002Oooool2o`0000Gooooo0_l00003ooooo`?o0000
1_ooool2o`0000oooooo6?l00004ooooo`;o00004?ooool4o`0004[ooooo000Looooo`03o`000?oo
oooooooo03Wooooo0_l00005ooooo`;o00002oooool4o`0000_ooooo0_l0000=ooooo`;o000000?o
ooooo`000?l000008?l00002ooooo`;o00002?ooool2o`000003ooooool0003o000001;ooooo0ol0
0006ooooo`;o00001oooool2o`0000Oooooo5ol00004ooooo`?o00003oooool2o`0000_ooooo0_l0
000oooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00002Oooool2o`0000;ooooo0_l0000@
ooooo`;o00001_ooool6o`000003ooooool0003o000001go00002oooool4o`000003ooooool0003o
0000013ooooo0_l00005ooooo`;o00000oooool2o`0000Cooooo1?l00007oooooaOo00001Oooool3
o`000003ooooool0003o000000?ooooo0_l0000Booooo`?o00001oooool2o`0003Kooooo000Loooo
o`03o`000?oooooooooo01oooooo0_l0000Zooooo`;o00005?ooool2o`000003ooooool0003o0000
00?ooooo1_l000000ooooooo0000o`00000Ho`000003ooooool0003o000000Go00002?ooool2o`00
00Kooooo0_l0000=ooooo`;o00001Oooool2o`0000?ooooo0_l00004ooooo`;o00002OoooolDo`00
0004ooooool0003o0000o`0000Gooooo0_l000000ooooooo0000o`000002o`000004ooooool0003o
0000ooooo`;o00003oooool2o`0000Oooooo0ol0000fooooo`007?ooool00ol0003oooooooooo`0L
ooooo`;o000000?oooooo`000?l000006oooool2o`0000;ooooo0_l0000Rooooo`;o00001Oooool2
o`000003ooooool0003o000001Go000000?oooooo`000?l000000ol00002ooooo`So000000?ooooo
o`000?l000001Oooool2o`0000;ooooo0ol0000:ooooo`;o00001oooool3o`0000?ooooo0ol0000:
ooooo`;o00000_ooool2o`0000?ooooo3ol000001?oooooo0000o`000?l0000:ooooo`Co00000_oo
ool2o`0001Kooooo1?l0000gooooo`007?ooool00ol0003oooooooooo`0Looooo`;o00007_ooool2
o`0000;ooooo0_l0000:ooooo`;o00008?ooool8o`000003ooooool0003o000000co000000?ooooo
o`000?l000000ol00002ooooo`_o00001Oooool2o`0000;ooooo0ol0000:ooooo`;o00001oooool2
o`0000Gooooo0_l00004ooooo`;o00001?ooool2o`0000Oooooo0ol00002ooooo`Co000000?ooooo
o`000?l000000_l00002ooooo`Go00002_ooool2o`0000_ooooo1Ol00002ooooo`;o00001_ooool2
o`0003Wooooo000Looooo`03o`000?oooooooooo04Sooooo0_l00002ooooo`;o00003?ooool2o`00
00Gooooo1?l00007ooooo`Go00000_ooool3o`0000;ooooo2?l000000ooooooo0000o`000006o`00
00;ooooo2ol00009ooooo`;o000000?oooooo`000?l000003oooool2o`0000oooooo0_l00006oooo
o`;o00001Oooool9o`000003ooooool0003o000000Co00000oooool4o`0000kooooo0_l000000ooo
oooo0000o`000002ooooo`Go00000_ooool2o`0000Oooooo0_l0000hooooo`0000Koooooonk^k_lb
<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o
0000ooooooooool0:oooool2o`0000oooooo0_l0000:ooooo`;o00001Oooool2o`0000;ooooo0_l0
0005ooooo`Co00000oooool4o`0000Oooooo1?l00003ooooo`;o00000oooool5o`000003ooooool0
003o000000Wo00000_ooool2o`0000;ooooo0_l0000<ooooo`Ko00001?ooool2o`0000[ooooo0_l0
00000ooooooo0000o`000009ooooo`Co00001Oooool4o`0000Oooooo1?l000000ooooooo0000o`00
0007o`0000?ooooo1?l00003ooooo`;o00002Oooool2o`000003ooooool0003o000000_ooooo0_l0
0005ooooo`;o0000>?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo
00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo02_ooooo0_l0000?ooooo`Co
00003oooool6o`0000Oooooo0_l0000?ooooo`;o00002?ooool7o`000003ooooool0003o000000;o
00000_ooool4o`0000;ooooo2?l00006ooooo`;o00000_ooool2o`0000;ooooo0_l00002ooooo`Co
00003Oooool3o`0000Cooooo0_l00002ooooo`Co00001?ooool3o`0000Kooooo0_l00006ooooo`Wo
00000oooool2o`0000Gooooo0_l0000Iooooo`;o0000?oooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool0?_ooool2o`0000Wooooo0_l00005ooooo`?o00000oooool2o`0001Gooooo0_l000001?oooooo
0000o`000?ooool<o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000;ooooo2?l00000
0ooooooo0000o`000003ooooo`;o00001_ooool3o`000003ooooool0003o000000Cooooo0_l00003
ooooo`;o00000oooool4o`0000Cooooo0_l00004ooooo`Co00000_ooool2o`0000?ooooo0_l00002
ooooo`?o00002oooool3o`0000Cooooo0_l000000ooooooo0000o`000006ooooo`;o00004oooool2
o`0000[ooooo0_l0000dooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09oooo
o`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0002Sooooo0_l0000Oooooo`;o000000?ooooo
o`000?l000000_ooool2o`0000Cooooo0_l00006ooooo`;o00001oooool2o`000003ooooool0003o
000000Cooooo0_l000000ooooooo0000o`00000:o`000003ooooool0003o000000?o00000_ooool2
o`0000Sooooo0_l000000ooooooo0000o`00000;ooooo`?o00001oooool3o`0000;ooooo0_l00003
ooooo`;o00003?ooool4o`0000Gooooo1?l00003ooooo`;o00002oooool2o`0000Gooooo0_l00000
0ooooooo0000o`000006ooooo`;o00002_ooool2o`0000Oooooo0ol00009ooooo`;o0000=?ooool0
0003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oEEEEo`000?l@413o
c<c<00Kooooo00?o0000ooooooooool0:?ooool2o`0002;ooooo0_l0000=ooooo`;o000000?ooooo
o`000?l000001oooool2o`000003ooooool0003o000000;ooooo0_l00005ooooo`?o000000?ooooo
o`000?l000000_l00002ooooo`Go00000oooool2o`0000Sooooo0_l0000Booooo`;o00001Oooool2
o`0000?ooooo0_l0000;ooooo`;o00002oooool3o`0000Wooooo0ol00002ooooo`;o000000?ooooo
o`000?l000005Oooool4o`0000Cooooo0_l000000ooooooo0000o`000005ooooo`;o00001Oooool2
o`0003Sooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEEohN7
Qoooool02?ooool00ol0003oooooooooo`0looooo`;o00003_ooool2o`0000gooooo0_l00008oooo
o`?o00001_ooool2o`000004ooooool0003o0000ooooo`Co000000?oooooo`000?l000002Ol00002
ooooo`;o00007Oooool2o`0000[ooooo0_l0000:ooooo`?o00002oooool2o`0000Sooooo1Ol00000
1Ooooooo0000o`000?l0003ooooo00;o00000oooool2o`0000?ooooo0_l0000;ooooo`Co00001ooo
ool2o`0000cooooo0ol0000gooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgM
gOl@413oV9RH00Sooooo00?o0000ooooooooool0=?ooool2o`0000Kooooo0_l0000Kooooo`Co0000
1?ooool2o`0000;ooooo1?l00008ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000
o`00000Ao`0000Cooooo0_l0000>ooooo`;o00003oooool2o`0000Gooooo0_l00003ooooo`;o0000
2Oooool2o`0000_ooooo0_l00004ooooo`;o00001oooool2o`0000;ooooo0ol0000Uooooo`;o0000
=oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106oooo
o`03o`000?oooooooooo03Cooooo0ol00006ooooo`;o00003?ooool2o`0000cooooo0_l00006oooo
o`;o00001?ooool2o`0000_ooooo1?l000000ooooooo0000o`000004o`000003ooooool0003o0000
00Co00000_ooool4o`0000;ooooo1Ol000000ooooooo0000o`000003ooooo`;o00001Oooool2o`00
00[ooooo0_l00003ooooo`;o00001Oooool2o`0000kooooo0_l00006ooooo`;o00000oooool2o`00
017ooooo0_l0000Jooooo`;o0000@oooool001cooooo00?o0000ooooooooool0=Oooool2o`0000Ko
oooo0_l000000ooooooo0000o`000009ooooo`;o00002oooool2o`0000gooooo0_l0000<ooooo`Co
00002?ooool4o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000006o`0000?o
oooo0ol00003ooooo`;o00002Oooool5o`0000Wooooo0_l000000ooooooo0000o`000002ooooo`?o
00003_ooool3o`0000Oooooo0_l00007ooooo`;o00001?ooool2o`0000[ooooo0_l00002ooooo`?o
00002?ooool2o`0004?ooooo000Looooo`03o`000?oooooooooo02Sooooo0_l0000;ooooo`;o0000
1_ooool2o`000003ooooool0003o000000Kooooo0_l0000>ooooo`?o00006?ooool2o`0000;ooooo
0_l00008ooooo`Oo00000oooool2o`0000;ooooo0_l00002ooooo`Co00000_ooool3o`0000?ooooo
0_l00009ooooo`;o000000?oooooo`000?l000003?ooool2o`0000;ooooo0ol00002ooooo`;o0000
2oooool2o`0000Oooooo0_l00007ooooo`;o000000?oooooo`000?l000000ol0000:ooooo`;o0000
0_ooool3o`0000Sooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`0Xooooo`;o00001?oo
ool2o`0000Gooooo0_l0000Aooooo`;o00003?ooool2o`000003ooooool0003o000000Gooooo0_l0
0007ooooo`;o00002?ooool2o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l0
0005ooooo`;o00002?ooool7o`000003ooooool0003o000000Wooooo0_l0000=ooooo`;o00002ooo
ool3o`0000;ooooo0_l0000Cooooo`;o00001_ooool3o`0000Cooooo0_l0000Eooooo`;o0000@ooo
ool001cooooo00?o0000ooooooooool0;_ooool2o`0000Kooooo0_l0000>ooooo`?o00003Oooool2
o`0000Gooooo1Ol000000ooooooo0000o`000004ooooo`;o00004?ooool2o`0000?ooooo0_l00005
ooooo`;o00003?ooool:o`0000Wooooo0_l00004ooooo`;o00001oooool2o`0000Wooooo0_l00000
1Ooooooo0000o`000?l0003ooooo00;o00001oooool2o`0000Kooooo0_l00002ooooo`;o00001Ooo
ool2o`0000Kooooo0_l00006ooooo`;o000000?oooooo`000?l000001Oooool2o`0004Sooooo000L
ooooo`03o`000?oooooooooo03Kooooo0_l0000>ooooo`?o00002oooool2o`0000Oooooo0ol00003
ooooo`;o00001_ooool2o`0001[ooooo0_l00003ooooo`;o00002?ooool3o`000005ooooool0003o
0000o`000?ooool01_l000001?oooooo0000o`000?ooool2o`0000Cooooo0_l00004ooooo`;o0000
3?ooool2o`0000;ooooo1?l00005ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Wooooo
0_l0000>ooooo`;o000000?oooooo`000?l000001Oooool4o`0004Kooooo000Looooo`03o`000?oo
oooooooo04Cooooo0_l00002ooooo`;o00000oooool2o`0000Gooooo0_l000000ooooooo0000o`00
000Booooo`Ko00001?ooool2o`0001Cooooo0ol00009ooooo`;o000000?oooooo`000?l000002?l0
00000ooooooo0000o`000003o`0000[ooooo0_l00006ooooo`;o00002_ooool2o`0000Gooooo0ol0
0005ooooo`;o00001_ooool2o`0000Cooooo0_l00007ooooo`;o00002_ooool2o`0000Gooooo0_l0
0016ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00000_ooool2o`0000;ooooo0ol00000
0ooooooo0000o`000005ooooo`;o00003_ooool2o`0000?ooooo1Ol00004ooooo`;o00001_ooool2
o`0000cooooo0_l00004ooooo`;o00000oooool4o`0000?ooooo0_l00002ooooo`?o00000_ooool2
o`0000;ooooo0_l0000:ooooo`;o00001?ooool2o`0001;ooooo0_l00005ooooo`Co00000_ooool4
o`0000Cooooo0_l00006ooooo`?o00002_ooool2o`0000Oooooo0_l00014ooooo`007?ooool00ol0
003oooooooooo`0kooooo`;o00001?ooool2o`0000Wooooo0_l00002ooooo`;o00001?ooool2o`00
00oooooo0_l00006ooooo`Co00000_ooool2o`0000Kooooo0_l00005ooooo`;o000000?oooooo`00
0?l000002?ooool2o`0000?ooooo1Ol00002ooooo`Wo00000_ooool7o`0000Cooooo0_l000001?oo
oooo0000o`000?ooool4o`0000Gooooo0_l0000>ooooo`;o00000oooool4o`0000;ooooo1?l00004
ooooo`;o00001_ooool4o`0001;ooooo0_l00002ooooo`;o0000@?ooool001cooooo00?o0000oooo
ooooool0=oooool2o`0000;ooooo0_l00004ooooo`;o00003?ooool2o`0000Gooooo1?l0000Goooo
o`;o00000_ooool2o`0000gooooo1Ol0000;ooooo`So000000?oooooo`000?l000002ol000000ooo
oooo0000o`000002o`0000Cooooo0_l00003ooooo`Go00000oooool4o`0000kooooo0_l00005oooo
o`;o00001?ooool4o`0000cooooo0_l00002ooooo`;o00001_ooool2o`0000Oooooo0_l000000ooo
oooo0000o`000010ooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00001?ooool2o`0000;o
oooo0_l00004ooooo`;o00001_ooool2o`0000Oooooo0_l00005ooooo`;o00009Oooool4o`000003
ooooool0003o000000Gooooo6?l000000ooooooo0000o`000008ooooo`;o000000?oooooo`000?l0
00000_l00004ooooo`;o000000?oooooo`000?l000001?ooool2o`0000cooooo1?l00004ooooo`Co
00001Oooool2o`0000?ooooo0_l00004ooooo`;o00001_ooool2o`000003ooooool0003o000000Co
oooo0_l00013ooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00000_ooool2o`0000Cooooo
0_l00004ooooo`;o00002?ooool2o`0000Kooooo0_l0000Wooooo`;o000000?oooooo`000?l00000
1?ooool4o`000003ooooool0003o000001Go00001oooool4o`0000;ooooo0_l00007ooooo`;o0000
1?ooool2o`0000cooooo1?l00005ooooo`;o00001_ooool2o`0000?ooooo0_l00003ooooo`Co0000
1Oooool2o`000003ooooool0003o000004Wooooo000Looooo`;o0000>?ooool2o`0000gooooo0_l0
0002ooooo`;o000000?oooooo`000?l000001?l00004ooooo`;o00003_ooool2o`00023ooooo0_l0
0006ooooo`Co000000?oooooo`000?l000004?l000001Ooooooo0000o`000?l0003ooooo00;o0000
1Oooool4o`0003Cooooo0ol00003ooooo`Co00001Oooool2o`0004cooooo000Looooo`03o`000?oo
oooooooo03?ooooo0_l00002ooooo`;o00003Oooool2o`0000;ooooo0_l00003ooooo`So00004?oo
ool2o`00023ooooo0_l00005oooooaSo000000Coooooo`000?l0003ooooo0ol0000Cooooo`;o0000
7Oooool2o`0000Wooooo0ol0000;ooooo`;o0000COooool001cooooo00?o0000ooooooooool0<ooo
ool2o`0000gooooo0_l00005ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`Go0000
=oooool3o`000003ooooool0003o000001;o00000_ooool7o`00017ooooo0ol0000Mooooo`;o0000
5oooool3o`0004cooooo000Looooo`03o`000?oooooooooo04;ooooo0_l00005ooooo`;o00000_oo
ool2o`0000Oooooo1?l0000<ooooo`Co00009Oooool2o`0000?ooooo7?l00008ooooo`;o00001ooo
ool4o`0003Kooooo0ol0001;ooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00001Oooool2
o`000004ooooool0003o0000o`0000cooooo1?l0000Zoooooa_o00001oooool4o`0000Oooooo1?l0
000/ooooo`;o00000_ooool3o`0000Cooooo0_l000000ooooooo0000o`00000=ooooo`;o0000>Ooo
ool001cooooo00?o0000ooooooooool0B_ooool2o`0000Cooooo0_l00002ooooo`;o000000Cooooo
o`000?l0003o0000>_ooool2o`0000?ooooo5ol00006ooooo`;o00002Oooool2o`000003ooooool0
003o000000?ooooo0_l0000Vooooo`;o00000_ooool3o`0000Oooooo0_l0000=ooooo`;o0000>Ooo
ool001cooooo00?o0000ooooooooool0@oooool4o`0000;ooooo0ol00002ooooo`Ko000000?ooooo
o`000?l000001oooool2o`0003Kooooo1_l000000ooooooo0000o`00000Ao`0000Wooooo0_l00003
ooooo`;o00001?ooool2o`0000?ooooo0_l0000:ooooo`Go00001?ooool2o`0000Gooooo0_l0000E
ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0@oooool8o`0000;ooooo0ol00002oooo
o`Go00001oooool2o`00033ooooo0_l00003oooooa[o00001Oooool2o`0000?ooooo0_l00003oooo
o`;o00002Oooool2o`0000[ooooo1Ol00004ooooo`;o00001Oooool2o`0000Gooooo0_l0000>oooo
o`;o00001?ooool2o`0004Gooooo000Looooo`03o`000?oooooooooo04Kooooo1Ol00002ooooo`;o
00001Oooool2o`0001Cooooo0_l0000Jooooo`;o00002?ooool2o`0000?ooooo8Ol0000Cooooo`;o
00000_ooool2o`0000Sooooo0_l00009ooooo`;o000000?oooooo`000?l000001Oooool4o`0001;o
oooo0_l00015ooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00001?ooool2o`0001Oooooo
1?l0000Jooooo`;o00003Oooool2o`000003ooooool0003o000001_o00004Oooool2o`0000Gooooo
0_l00008ooooo`;o00002Oooool4o`0000Sooooo0_l0001Iooooo`007?ooool00ol0003ooooooooo
o`16ooooo`;o00000_ooool2o`0000?ooooo0_l0000Gooooo`;o00001?ooool2o`0001[ooooo0_l0
000:oooooaco00001_ooool2o`0000cooooo1?l00004ooooo`;o000000?oooooo`000?l000004Ooo
ool2o`0000?ooooo1?l0001Looooo`007?ooool00ol0003oooooooooo`0oooooo`;o00001Oooool2
o`0000;ooooo0_l00005ooooo`;o00006oooool2o`0001Sooooo1?l0000:oooooa[o00002?ooool2
o`0000Sooooo0_l00004ooooo`;o00001?ooool2o`000003ooooool0003o000001Gooooo1Ol00000
0ooooooo0000o`000002o`0005Oooooo000Looooo`03o`000?oooooooooo03oooooo0_l0000@oooo
o`;o00006?ooool2o`0001_ooooo0_l0000>oooooaSo000000?oooooo`000?l000002?ooool2o`00
00Gooooo0_l0000<ooooo`;o00005_ooool:o`0005Oooooo000Looooo`03o`000?oooooooooo04[o
oooo0ol0000Nooooo`Co00006oooool2o`0000Oooooo0_l00003oooooa_o00002?ooool2o`0000;o
oooo0ol00005ooooo`;o00001oooool3o`0001Gooooo0_l00002ooooo`?o000000?oooooo`000?l0
0000Eoooool001cooooo00?o0000ooooooooool0Aoooool2o`000003ooooool0003o000000;o0000
00?oooooo`000?l000004oooool2o`0000Oooooo0_l0000Eooooo`;o00001?ooool2o`0000Oooooo
0_l00003oooooaWo000000?oooooo`000?l000001_ooool2o`0000?ooooo0ol00005ooooo`;o0000
2?ooool3o`0000Sooooo0_l0000:ooooo`;o00000oooool2o`000003ooooool0003o000005Oooooo
000Looooo`03o`000?oooooooooo04Oooooo0_l00003ooooo`;o000000?oooooo`000?l000000ooo
ool2o`0000kooooo0_l00006ooooo`;o00000oooool2o`00017ooooo0_l0000Coooooa_o00001_oo
ool3o`0001;ooooo1ol00006ooooo`;o00002_ooool2o`0000Cooooo0_l00003ooooo`;o0000E?oo
ool001cooooo0_l0001=ooooo`;o00001_ooool2o`0000kooooo0_l000000ooooooo0000o`000003
ooooo`;o000000?oooooo`000?l000001?l0000Qoooooaoo00001_ooool2o`0000kooooo0_l00002
ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o000000?oooooo`000?l000001Oooool4
o`000003ooooool0003o000000;o000000?oooooo`000?l000000oooool2o`0005Cooooo000Loooo
o`03o`000?oooooooooo04Oooooo0_l00003ooooo`;o00005_ooool2o`000003ooooool0003o0000
00Kooooo0_l00002ooooo`;o00005Oooool5o`0000Oooooo4ol000000ooooooo0000o`000009o`00
00Gooooo1Ol00002ooooo`?o00001oooool2o`0000Kooooo0_l00005ooooo`;o000000?oooooo`00
0?l000001Oooool4o`000003ooooool0003o000000;o00003?ooool2o`0004kooooo000Looooo`03
o`000?oooooooooo04Oooooo0_l0000:ooooo`;o00007?ooool2o`0001Oooooo1Ol00007ooooo`;o
000000?oooooo`000?l000003_l000000ooooooo0000o`000006o`0000Sooooo0_l000000ooooooo
0000o`000002ooooo`Go00003Oooool3o`00017ooooo0_l0000@ooooo`;o0000C_ooool001cooooo
00?o0000ooooooooool0@?ooool2o`00017ooooo0_l00003ooooo`;o00005oooool4o`000003oooo
ool0003o000000kooooo0_l00005ooooo`;o00002?ooool4o`000003ooooool0003o000001Co0000
00Coooooo`000?l0003ooooo0_l00009ooooo`;o000000?oooooo`000?l000003Oooool3o`00017o
oooo1?l0000>ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0@?ooool2o`0000Sooooo
0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00008ooooo`;o00002oooool2o`0000;ooooo
0_l000000ooooooo0000o`00000>ooooo`?o00001?ooool2o`0000Sooooo0_l00003oooooaGo0000
00Goooooo`000?l0003o0000ooooo`02o`0000gooooo0_l00002ooooo`;o00002_ooool2o`0000Ko
oooo0_l0000:ooooo`Co00003?ooool2o`0004kooooo000Looooo`03o`000?oooooooooo04[ooooo
0_l00003ooooo`;o00000_ooool2o`0000Oooooo0_l00004ooooo`;o00002oooool2o`0001Kooooo
0_l0000Aooooo`;o000000?oooooo`000?l000004_l000000ooooooo0000o`000003o`0000Wooooo
0_l00002ooooo`?o000000Coooooo`000?l0003o00000_ooool2o`0000Cooooo1?l00006ooooo`Co
00002Oooool3o`0005cooooo000Looooo`03o`000?oooooooooo05Sooooo0ol000001?oooooo0000
o`000?l00009ooooo`;o00006Oooool2o`0000;ooooo0_l0000>ooooo`;o000000Coooooo`000?l0
003ooooo4Ol00007ooooo`;o00002Oooool2o`0000;ooooo0_l000001?oooooo0000o`000?l00003
ooooo`;o00001?ooool4o`000003ooooool0003o000000Gooooo0_l00003ooooo`;o00003?ooool2
o`0005Gooooo000Looooo`03o`000?oooooooooo05Sooooo0ol00002ooooo`;o00002?ooool3o`00
00kooooo0_l00009ooooo`;o00000_ooool2o`0000_ooooo0_l000000ooooooo0000o`000004oooo
oa7o00000_ooool3o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`;o00001_ooool2o`00
00oooooo0_l000000ooooooo0000o`000007ooooo`;o00003?ooool3o`0005Cooooo000Looooo`03
o`000?oooooooooo06Kooooo0ol0000?ooooo`;o00006_ooool2o`0000Gooooo0_l00006ooooo`_o
00000_ooool4o`000003ooooool0003o000000Go00000oooool2o`00013ooooo0_l00007ooooo`?o
00005Oooool3o`0005Cooooo000Looooo`03o`000?oooooooooo05cooooo0_l00008ooooo`;o0000
4Oooool2o`0000Wooooo1?l0000Cooooo`;o000000?oooooo`000?l000001?ooool;o`0000?ooooo
0_l00002ooooo`;o00000_ooool2o`0000?ooooo0_l0000@ooooo`;o00001oooool2o`0001;ooooo
0_l0001Iooooo`007?ooool00ol0003oooooooooo`1Eooooo`;o00001Oooool2o`0000kooooo0_l0
000;ooooo`;o00002Oooool5o`0000Gooooo0_l00004ooooo`;o00002?ooool2o`0000Cooooo1?l0
0002ooooo`Wo000000?oooooo`000?l000001oooool2o`0001Kooooo0_l0000Eooooo`Co0000FOoo
ool001cooooo00?o0000ooooooooool0C_ooool2o`0000Gooooo0_l00003ooooo`;o00004?ooool2
o`0000;ooooo0_l00005ooooo`?o00003Oooool2o`0000Gooooo0_l00004ooooo`;o00001_ooool2
o`0000Kooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo1Ol000000ooooooo0000o`00
0007ooooo`;o00002oooool2o`0000Wooooo0_l0000Eooooo`;o0000Foooool001cooooo00?o0000
ooooooooool0COooool5o`0000Sooooo0_l0000Booooo`Co00001Oooool3o`000004ooooool0003o
0000ooooo`;o00002oooool2o`000003ooooool0003o000000_ooooo0ol00002ooooo`;o00001_oo
ool4o`0000Cooooo0_l00005ooooo`;o00001_ooool2o`0000Kooooo0_l000001?oooooo0000o`00
0?ooool2o`00013ooooo0_l0001Xooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o000000?o
ooooo`000?l000007?ooool2o`0000_ooooo0_l000000ooooooo0000o`00000;ooooo`;o00000_oo
ool2o`0000Gooooo1?l000001?oooooo0000o`000?l00002ooooo`;o00001?ooool2o`0000;ooooo
0_l00004ooooo`;o00001Oooool2o`0000Kooooo0_l00006ooooo`;o00001?ooool2o`0000kooooo
1?l00007ooooo`;o0000Goooool001cooooo00?o0000ooooooooool0Hoooool2o`0001?ooooo0_l0
000Eooooo`;o00000oooool6o`0000;ooooo0_l00003ooooo`;o00000oooool2o`0000;ooooo0_l0
00000ooooooo0000o`000008ooooo`;o00003_ooool3o`000003ooooool0003o000000;o00000_oo
ool2o`0000[ooooo0_l00009ooooo`;o0000Goooool001cooooo00?o0000ooooooooool0COooool2
o`0000[ooooo0_l00004ooooo`;o00000_ooool2o`0000oooooo0_l00002ooooo`;o00006_ooool2
o`0000Cooooo0_l00005ooooo`;o000000Coooooo`000?l0003o00000_ooool3o`000003ooooool0
003o000000Cooooo0_l0000Booooo`?o000000?oooooo`000?l000000_l00002ooooo`;o00004?oo
ool2o`0006Cooooo000Looooo`;o0000C_ooool2o`0000Gooooo0_l000000ooooooo0000o`000002
o`0000Cooooo0_l00008ooooo`;o00000_ooool3o`0000Cooooo0_l00004ooooo`;o00000oooool2
o`0001Wooooo0_l00008ooooo`?o00000_ooool2o`0000;ooooo1?l00002ooooo`;o00000_ooool5
o`0000_ooooo0_l000000ooooooo0000o`00000Gooooo`Co0000H_ooool001cooooo00?o0000oooo
ooooool0E?ooool2o`000003ooooool0003o000000kooooo1?l00002ooooo`?o00001?ooool4o`00
0004ooooool0003o0000o`0000?ooooo0_l0000?ooooo`;o00004oooool2o`0000Kooooo1?l00006
ooooo`Go00002?ooool8o`0001Sooooo0ol0001Rooooo`007?ooool00ol0003oooooooooo`1Noooo
o`;o000000?oooooo`000?l000001?ooool2o`0000gooooo0_l000000ooooooo0000o`00000Eoooo
o`;o000000?oooooo`000?l000003?ooool2o`0000Wooooo1Ol0000Cooooo`?o00000_ooool2o`00
00oooooo0_l00008ooooo`;o00000_ooool2o`000003ooooool0003o000005cooooo000Looooo`03
o`000?oooooooooo05kooooo0_l000000ooooooo0000o`00000Pooooo`;o000000?oooooo`000?l0
00002oooool2o`0000Kooooo0_l00004ooooo`;o00001Oooool2o`0000;ooooo0ol0000Jooooo`;o
00002Oooool2o`0000Cooooo0_l00002ooooo`Co00001_ooool2o`000003ooooool0003o000005co
oooo000Looooo`03o`000?oooooooooo05Sooooo0_l0000Cooooo`;o00004_ooool4o`000003oooo
ool0003o000000?ooooo0_l0000>ooooo`;o00002oooool6o`0000Cooooo0_l00005ooooo`;o0000
0oooool2o`0001Cooooo0ol00007ooooo`Go0000I_ooool001cooooo00?o0000ooooooooool0F?oo
ool4o`0000gooooo1_l0000?ooooo`;o000000Coooooo`000?l0003ooooo0_l00005ooooo`;o0000
2oooool2o`0000;ooooo0ol0000;ooooo`;o00001_ooool2o`0000Gooooo1?l000000ooooooo0000
o`00000?ooooo`;o00001?ooool4o`000003ooooool0003o000000;o000000?oooooo`000?l00000
0_l00003ooooo`;o0000HOooool001cooooo00?o0000ooooooooool0F_ooool3o`0000cooooo1Ol0
000@ooooo`;o00001?ooool3o`0000Oooooo0_l00005ooooo`;o000000?oooooo`000?l000000_oo
ool3o`0000_ooooo0_l0000?ooooo`;o00002oooool2o`0000Gooooo0_l00006ooooo`Oo00002?oo
ool2o`00067ooooo000Looooo`03o`000?oooooooooo057ooooo0_l00008ooooo`;o00002Oooool2
o`0001gooooo0_l00006ooooo`?o00001Oooool2o`0000[ooooo0_l000000ooooooo0000o`000004
ooooo`;o00007?ooool2o`0000Wooooo0_l00003ooooo`?o0000K_ooool001cooooo00?o0000oooo
ooooool0DOooool2o`0001?ooooo0_l0000Uooooo`;o00002Oooool2o`0000Oooooo0_l000000ooo
oooo0000o`000004ooooo`;o00002oooool2o`00013ooooo0_l00004ooooo`;o00000_ooool2o`00
00Cooooo0_l0001^ooooo`007?ooool00ol0003oooooooooo`2Aooooo`Co00000_ooool3o`0001go
oooo0_l00009ooooo`;o00001Oooool2o`0000Cooooo0_l0001hooooo`007?ooool00ol0003ooooo
ooooo`1Tooooo`;o00002Oooool2o`0000kooooo0_l00004ooooo`Co00002?ooool4o`0000;ooooo
0_l00002ooooo`;o00009?ooool5o`0000Gooooo0_l00006ooooo`;o0000M?ooool001cooooo00?o
0000ooooooooool0I?ooool2o`0000Kooooo0_l000000ooooooo0000o`00000>ooooo`Co00000_oo
ool4o`0000Oooooo0_l00009ooooo`;o00001?ooool2o`0000oooooo0_l0000=ooooo`;o000000?o
ooooo`000?l000001Oooool2o`0000Kooooo0_l00003ooooo`;o00002Oooool2o`0006Cooooo000L
ooooo`03o`000?oooooooooo06Sooooo0_l00002ooooo`;o00003?ooool2o`0000Gooooo0_l00000
0ooooooo0000o`000002o`0000Sooooo0_l0000?ooooo`;o00001_ooool2o`0000Oooooo0_l0000;
ooooo`Ko00000_ooool2o`0000;ooooo0_l00006ooooo`;o00000oooool2o`0000Wooooo0_l0001T
ooooo`007?ooool00ol0003oooooooooo`1Qooooo`;o00001Oooool2o`0000_ooooo0_l00003oooo
o`;o00002?ooool2o`0000Cooooo0_l0000>ooooo`;o00002Oooool6o`0000?ooooo0_l0000?oooo
o`;o00000_ooool2o`0000;ooooo0_l00002ooooo`Co000000Coooooo`000?l0003ooooo0_l0001d
ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`00
0?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0F?ooool2o`0000Oooooo0_l0000Booooo`;o0000
0_ooool2o`0000Sooooo0_l00005ooooo`Co00000oooool2o`0000Oooooo0_l00009ooooo`Co0000
1Oooool2o`0000?ooooo0_l00002ooooo`;o00005?ooool2o`000003ooooool0003o000007Oooooo
00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRH
V?lQ8B401_ooool00ol0003oooooooooo`1Hooooo`;o00007oooool2o`0000Sooooo0_l00002oooo
o`?o00000_ooool2o`0000?ooooo0_l00004ooooo`;o00001oooool3o`0000Cooooo0_l00004oooo
o`;o00001?ooool2o`0000;ooooo0_l00009ooooo`;o0000QOooool00003ooooool@413ooooo00;o
oooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool0Qoooool3o`0000gooooo0ol00006ooooo`?o00000_ooool4o`0000Cooooo0_l0000Coooo
o`;o00003oooool2o`0007Cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wo
oooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000T_ooool2o`0000Cooooo0_l0000;oooo
o`Co00001?ooool2o`0002Cooooo0_l0001dooooo`0000?oooooo`000?ooool00_ooool00ol0003o
ooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`1Koooo
o`;o00007?ooool4o`0000Sooooo0_l0000;ooooo`?o00000oooool3o`0001kooooo0_l00008oooo
o`Co00002_ooool2o`0000Wooooo0_l0001[ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413o
ooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`1Koooo
o`;o00000oooool2o`0001Oooooo1?l000000ooooooo0000o`000005ooooo`;o00003?ooool2o`00
00?ooooo0ol00006ooooo`;o00005Oooool3o`0000Sooooo1?l0000:ooooo`;o00002Oooool2o`00
06_ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zjo`00
0006ooooo`03o`000?oooooooooo063ooooo0_l0000Looooo`;o00006Oooool2o`0000Kooooo0_l0
000>ooooo`;o00001Oooool2o`0000?ooooo0_l00004ooooo`;o0000Q?ooool00006ooooooo^k^ko
<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000oooooooo
ool0W?ooool2o`0000[ooooo0_l00007ooooo`;o00002_ooool2o`0000Cooooo0_l00024ooooo`00
7?ooool00ol0003oooooooooo`2Cooooo`?o00001_ooool2o`0000Kooooo0_l00002ooooo`;o0000
1?ooool2o`0000cooooo0_l0002;ooooo`007?ooool00ol0003oooooooooo`2Cooooo`?o00000_oo
ool2o`0000?ooooo1_l000000ooooooo0000o`000007ooooo`?o00003?ooool2o`0008_ooooo000L
ooooo`03o`000?oooooooooo08oooooo0_l00007ooooo`;o00000oooool6o`000004ooooool0003o
0000o`0000Kooooo0_l0000Iooooo`;o0000Ooooool001cooooo00?o0000ooooooooool0Roooool2
o`0000;ooooo0_l0000Cooooo`?o00001_ooool3o`0001Sooooo0_l0001oooooo`007?ooool00ol0
003oooooooooo`1Xooooo`;o00008Oooool2o`00017ooooo0_l0000=ooooo`?o0000VOooool001co
oooo00?o0000ooooooooool0J?ooool2o`0003Cooooo0_l00003ooooo`;o0000Y?ooool001cooooo
00?o0000ooooooooool0Moooool2o`0002[ooooo0_l0002Tooooo`007?ooool00ol0003ooooooooo
o`1gooooo`;o0000d?ooool001cooooo00?o0000ooooooooool0V?ooool2o`0000Cooooo0_l0002Y
ooooo`007?ooool00ol0003oooooooooo`2>ooooo`;o00002?ooool2o`0000?ooooo0ol0000Eoooo
o`;o0000T_ooool001cooooo00?o0000ooooooooool0S_ooool2o`0000Kooooo0_l00005ooooo`;o
00000_ooool2o`0001;ooooo0_l00005ooooo`;o0000Roooool001cooooo0_l0001[ooooo`;o0000
5_ooool2o`0001;ooooo0_l00009ooooo`;o00004_ooool2o`0000Gooooo0_l0002;ooooo`007?oo
ool00ol0003oooooooooo`1Zooooo`;o00005_ooool2o`000<Gooooo000Looooo`03o`000?oooooo
oooo09;ooooo0_l00008ooooo`;o0000Zoooool001cooooo00?o0000ooooooooool0NOooool2o`00
01Oooooo0_l00008ooooo`;o0000Zoooool001cooooo00?o0000ooooooooool0NOooool2o`0001?o
oooo0_l0002iooooo`007?ooool00ol0003oooooooooo`2>ooooo`;o0000^Oooool001cooooo00?o
0000ooooooooool0XOooool2o`000:Kooooo000Looooo`03o`000?oooooooooo09Sooooo0_l00007
ooooo`;o0000Y_ooool001cooooo00?o0000ooooooooool0V?ooool2o`000:oooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0;Kooooo0_l0002A
ooooo`007?ooool00ol0003oooooooooo`2fooooo`;o0000TOooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooo
oom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0YOooool2o`000:;ooooo000Looooo`03o`00
0?oooooooooo0:Gooooo0_l0002Rooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001;ooooo1?l000000ol@413ooooooooo
o`03ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo0ol0003ooooo
od[ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0
oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooo
oooo0?ooooooD_ooool001;ooooo00?oEEEEofIVI_l00000oooooomDooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00XOooool01?l@413o0000o`000?ooool2o`000003oa0@4?oo
oooooooo01Kooooo1?l000000ol@413oooooooooo`05o`0000?ooooo00Goc<c<ob4Q8Ol0003o8B4Q
olc<c005ooooo`;o000000?o410@ooooooooool0R_ooool00:;ooooo00Go0000oooooooooooooooo
o`000009ooooo`Ko00003?ooool00ol0003oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@00oooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0Roooool00:;o
oooo00Go0000ooooooooooooooooo`00000Kooooo`03o`000?oooooooooo00?ooooo00?oV9RHob4Q
8Oo^k^h01?ooool01Ol0003ooooooooooooooooo000000?ooooo1Ol0002<ooooo`00X_ooool01Ol0
003ooooooooooooooooo000000Wooooo1_l0000<ooooo`03o`000?oooooooooo00Cooooo00?oV9RH
ob4Q8Oo^k^h00oooool01Olb<S;oV9RHoooooonHV9So<S8b00?ooooo00CoA4A4omgMgOoooooo0000
SOooool00:;ooooo00Go0000ohN7QoooooooZJVYo`00000Kooooo`03o`000?oooooooooo00Gooooo
00?oMgMgofIVI_ooool00_ooool01Oo<c<co0000o`000?l0003oc<c<00?ooooo00CogMgMoeEEEOoo
oooo0000SOooool00:7ooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Iooooo`03
o`000?oooooooooo00Kooooo00Wo0000oooooooooooooooooa0@4?nj^[[ooooookZj^_l@41001?oo
ool00omgMgOoc<c<o`00002=ooooo`00`_ooool00ol0003oooooooooo`02ooooo`05o`000?nj^[[o
oooooiRHV?l@41000oooool01Ol0003o^[Zjoooooonj^[[o000000Cooooo00?ok^k^odA4A?l00000
SOooool00<3ooooo00?oEEEEofIVI_l000001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00GoZJVYoa0@4?l0003o410@ojVYZ@05ooooo`03ogMgMol0003ooooo08cooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1290) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.50186 .65401 Mdot
.48472 .65513 Mdot
.62103 .3846 Mdot
.40168 .5481 Mdot
.7181 .30165 Mdot
.59242 .40307 Mdot
.66629 .61045 Mdot
.64382 .54681 Mdot
.63074 .39991 Mdot
.69883 .64703 Mdot
.6362 .5723 Mdot
.40469 .60254 Mdot
.66092 .56396 Mdot
.37234 .52699 Mdot
.68254 .20332 Mdot
.3825 .57746 Mdot
.49412 .65245 Mdot
.4143 .32566 Mdot
.43649 .54846 Mdot
.60836 .36442 Mdot
.52665 .68364 Mdot
.38008 .52614 Mdot
.46739 .70696 Mdot
.37164 .52673 Mdot
.41667 .53006 Mdot
.49001 .71512 Mdot
.46654 .6203 Mdot
.41065 .50125 Mdot
.40081 .47829 Mdot
.63815 .55017 Mdot
.32732 .35205 Mdot
.68596 .2307 Mdot
.36025 .44605 Mdot
.45203 .20764 Mdot
.67187 .55249 Mdot
.34723 .71042 Mdot
.60485 .39863 Mdot
.65558 .58497 Mdot
.65643 .59055 Mdot
.68147 .5564 Mdot
.64586 .57523 Mdot
.47287 .70288 Mdot
.58212 .63425 Mdot
.64349 .33346 Mdot
.35996 .56087 Mdot
.78525 .43403 Mdot
.42471 .78936 Mdot
.34999 .49661 Mdot
.50554 .67621 Mdot
.52706 .25663 Mdot
.72309 .42653 Mdot
.6791 .58759 Mdot
.61512 .36136 Mdot
.12641 .59927 Mdot
.67232 .57681 Mdot
.44373 .49186 Mdot
.6141 .39279 Mdot
.37897 .51226 Mdot
.36787 .52355 Mdot
.27755 .58982 Mdot
.34598 .53075 Mdot
.43339 .33847 Mdot
.44528 .67396 Mdot
.57193 .55777 Mdot
.62255 .40382 Mdot
.64687 .59067 Mdot
.47823 .66336 Mdot
.6668 .56255 Mdot
.46082 .54979 Mdot
.58066 .36824 Mdot
.34919 .49465 Mdot
.63962 .57884 Mdot
.46348 .63311 Mdot
.38634 .48123 Mdot
.53416 .34194 Mdot
.82754 .53931 Mdot
.4473 .28947 Mdot
.33041 .68057 Mdot
.2674 .5843 Mdot
.56886 .28269 Mdot
.42793 .54552 Mdot
.37189 .38291 Mdot
.81743 .50697 Mdot
.48268 .72831 Mdot
.34727 .5661 Mdot
.43218 .26502 Mdot
.38863 .48473 Mdot
.80527 .42528 Mdot
.35002 .47554 Mdot
.48467 .28311 Mdot
.63418 .40692 Mdot
.49185 .68027 Mdot
.4044 .54978 Mdot
.38071 .47438 Mdot
.24431 .53662 Mdot
.41959 .4721 Mdot
.39639 .52073 Mdot
.51089 .69544 Mdot
.67874 .58549 Mdot
.40117 .45278 Mdot
.65595 .34678 Mdot
.64318 .40685 Mdot
.38845 .5632 Mdot
.59718 .43111 Mdot
.45015 .66116 Mdot
.37826 .47599 Mdot
.66247 .59162 Mdot
.37102 .55253 Mdot
.59374 .76802 Mdot
.47969 .6496 Mdot
.40795 .49169 Mdot
.4725 .34635 Mdot
.21927 .60257 Mdot
.49853 .67746 Mdot
.67138 .35841 Mdot
.43163 .50961 Mdot
.39267 .50982 Mdot
.48702 .65994 Mdot
.61795 .43687 Mdot
.81106 .44163 Mdot
.50654 .71928 Mdot
.65575 .53688 Mdot
.49348 .64286 Mdot
.42472 .59117 Mdot
.61743 .41471 Mdot
.69573 .3623 Mdot
.58663 .73505 Mdot
.35132 .3255 Mdot
.38661 .48681 Mdot
.62331 .65465 Mdot
.64633 .38541 Mdot
.48357 .68064 Mdot
.66214 .55788 Mdot
.32566 .53093 Mdot
.46277 .66174 Mdot
.63203 .56464 Mdot
.46479 .35348 Mdot
.70983 .4844 Mdot
.45417 .6643 Mdot
.4934 .41642 Mdot
.64062 .60025 Mdot
.68503 .5751 Mdot
.35959 .22345 Mdot
.47958 .66709 Mdot
.4432 .33642 Mdot
.65616 .55018 Mdot
.33795 .31354 Mdot
.35945 .55754 Mdot
.32748 .39678 Mdot
.43229 .80823 Mdot
.43073 .20951 Mdot
.73254 .5041 Mdot
.45406 .31456 Mdot
.62762 .54899 Mdot
.40855 .53127 Mdot
.49812 .71032 Mdot
.4787 .71518 Mdot
.34938 .53516 Mdot
.41967 .54297 Mdot
.34959 .48763 Mdot
.36676 .4723 Mdot
.35776 .6075 Mdot
.43626 .5067 Mdot
.35818 .76704 Mdot
.49408 .68471 Mdot
.40434 .54168 Mdot
.57474 .39201 Mdot
.35778 .45618 Mdot
.64266 .57744 Mdot
.38292 .51829 Mdot
.40407 .5478 Mdot
.35329 .54588 Mdot
.68127 .58234 Mdot
.73458 .2677 Mdot
.23845 .63865 Mdot
.70121 .25821 Mdot
.50829 .3445 Mdot
.57935 .412 Mdot
.39601 .49418 Mdot
.45016 .3492 Mdot
.38924 .70363 Mdot
.38657 .54973 Mdot
.45469 .86815 Mdot
.39121 .52487 Mdot
.7199 .291 Mdot
.44888 .48966 Mdot
.61478 .2057 Mdot
.35837 .37615 Mdot
.41185 .51954 Mdot
.56076 .61077 Mdot
.64335 .51603 Mdot
.61091 .44941 Mdot
.64863 .57292 Mdot
.57661 .38817 Mdot
.61739 .38626 Mdot
.57952 .58859 Mdot
.36851 .59313 Mdot
.38592 .43874 Mdot
.36451 .46528 Mdot
.56836 .37408 Mdot
.4498 .69434 Mdot
.45287 .36163 Mdot
.51735 .67924 Mdot
.85247 .40829 Mdot
.75033 .40826 Mdot
.67198 .61904 Mdot
.42532 .337 Mdot
.63868 .38869 Mdot
.62639 .42298 Mdot
.47279 .33229 Mdot
.36313 .49765 Mdot
.47554 .67265 Mdot
.40694 .19469 Mdot
.63993 .75334 Mdot
.32837 .22124 Mdot
.50966 .6939 Mdot
.67491 .66863 Mdot
.63701 .55808 Mdot
.59705 .38693 Mdot
.39427 .51285 Mdot
.36928 .49577 Mdot
.52085 .72344 Mdot
.35164 .48596 Mdot
.52349 .64472 Mdot
.40242 .5134 Mdot
.68714 .45132 Mdot
.423 .28998 Mdot
.57973 .58498 Mdot
.37224 .30346 Mdot
.48806 .72551 Mdot
.23429 .44656 Mdot
.60575 .43062 Mdot
.38059 .6951 Mdot
.64234 .59016 Mdot
.44888 .35441 Mdot
.61268 .42419 Mdot
.46554 .35883 Mdot
.44108 .52351 Mdot
.58294 .37695 Mdot
.47056 .32087 Mdot
.28352 .48823 Mdot
.33818 .53111 Mdot
.53765 .78553 Mdot
.67421 .54934 Mdot
.52096 .69282 Mdot
.34292 .52292 Mdot
.57919 .4178 Mdot
.32132 .49037 Mdot
.7643 .54675 Mdot
.68998 .41834 Mdot
.64702 .40401 Mdot
.67551 .43472 Mdot
.4332 .34222 Mdot
.76435 .4809 Mdot
.65004 .66824 Mdot
.49877 .65597 Mdot
.42402 .478 Mdot
.58937 .19059 Mdot
.65702 .55056 Mdot
.36135 .54187 Mdot
.53046 .21999 Mdot
.67167 .55983 Mdot
.37887 .50987 Mdot
.63301 .55005 Mdot
.47728 .71436 Mdot
.22593 .56317 Mdot
.50045 .66092 Mdot
.36553 .46877 Mdot
.66737 .58953 Mdot
.5731 .41838 Mdot
.49094 .70995 Mdot
.35776 .50198 Mdot
.40707 .49952 Mdot
.60237 .49837 Mdot
.4004 .53511 Mdot
.73378 .27955 Mdot
.40757 .51622 Mdot
.60483 .37946 Mdot
.41172 .56902 Mdot
.18391 .6182 Mdot
.59087 .60893 Mdot
.47782 .6654 Mdot
.63023 .43325 Mdot
.62611 .3959 Mdot
.63763 .32496 Mdot
.69565 .5942 Mdot
.43482 .51882 Mdot
.58039 .41639 Mdot
.26022 .44593 Mdot
.63505 .58938 Mdot
.38004 .44708 Mdot
.50001 .44121 Mdot
.51429 .26067 Mdot
.61826 .36208 Mdot
.32556 .46325 Mdot
.45184 .66868 Mdot
.40899 .55006 Mdot
.6229 .42821 Mdot
.32535 .56394 Mdot
.42457 .50563 Mdot
.52812 .73875 Mdot
.60742 .49923 Mdot
.6558 .60907 Mdot
.43869 .47231 Mdot
.35462 .53106 Mdot
.57997 .38912 Mdot
.49303 .72255 Mdot
.63342 .58858 Mdot
.47927 .70877 Mdot
.56934 .19821 Mdot
.55076 .77895 Mdot
.27854 .51565 Mdot
.42802 .34822 Mdot
.50081 .23859 Mdot
.58363 .19632 Mdot
.20673 .44179 Mdot
.25368 .40414 Mdot
.47603 .18631 Mdot
.60707 .43728 Mdot
.53144 .22723 Mdot
.62083 .39263 Mdot
.42425 .53104 Mdot
.61715 .4129 Mdot
.57536 .18783 Mdot
.4015 .51518 Mdot
.60999 .40976 Mdot
.22933 .47872 Mdot
.4103 .54571 Mdot
.49323 .65599 Mdot
.8042 .36047 Mdot
.17846 .51825 Mdot
.68755 .43098 Mdot
.61093 .36946 Mdot
.27857 .35477 Mdot
.39799 .52282 Mdot
.41527 .56639 Mdot
.50154 .6956 Mdot
.3361 .45854 Mdot
.43121 .31767 Mdot
.42396 .32818 Mdot
.7187 .57805 Mdot
.40839 .40346 Mdot
.4466 .48837 Mdot
.4937 .7068 Mdot
.39408 .6215 Mdot
.52457 .32873 Mdot
.52952 .25084 Mdot
.63021 .59683 Mdot
.80047 .35768 Mdot
.50117 .62177 Mdot
.60856 .55484 Mdot
.62371 .45365 Mdot
.49571 .66669 Mdot
.7199 .25263 Mdot
.65232 .5752 Mdot
.53924 .80307 Mdot
.4961 .52286 Mdot
.36421 .50072 Mdot
.65082 .60228 Mdot
.31969 .5365 Mdot
.17686 .50154 Mdot
.6054 .80221 Mdot
.47029 .45959 Mdot
.34919 .47455 Mdot
.52336 .35564 Mdot
.3872 .51527 Mdot
.79705 .51022 Mdot
.40951 .51253 Mdot
.48211 .70665 Mdot
.71085 .63671 Mdot
.70187 .55762 Mdot
.271 .70591 Mdot
.77664 .49764 Mdot
.45292 .31359 Mdot
.39859 .50974 Mdot
.36307 .50307 Mdot
.43673 .31314 Mdot
.45989 .69831 Mdot
.35755 .47413 Mdot
.23376 .43302 Mdot
.37231 .47798 Mdot
.64821 .58118 Mdot
.48436 .54392 Mdot
.50356 .76261 Mdot
.38895 .46495 Mdot
.4495 .64434 Mdot
.67166 .61459 Mdot
.66741 .58517 Mdot
.45443 .51126 Mdot
.67881 .55015 Mdot
.38933 .53202 Mdot
.63321 .7977 Mdot
.45636 .65466 Mdot
.55007 .67076 Mdot
.4651 .67851 Mdot
.31535 .66985 Mdot
.6782 .57042 Mdot
.70652 .44321 Mdot
.34912 .57651 Mdot
.65485 .5724 Mdot
.4874 .76579 Mdot
.38713 .57561 Mdot
.33705 .53797 Mdot
.35846 .2445 Mdot
.61746 .37413 Mdot
.60836 .5049 Mdot
.63959 .54778 Mdot
.35302 .51351 Mdot
.41472 .47601 Mdot
.6756 .61291 Mdot
.63753 .77775 Mdot
.20011 .51002 Mdot
.40495 .5154 Mdot
.4851 .69785 Mdot
.48126 .68413 Mdot
.33376 .5026 Mdot
.40026 .56225 Mdot
.60568 .41881 Mdot
.58246 .43078 Mdot
.57902 .37394 Mdot
.61421 .50085 Mdot
.70269 .44132 Mdot
.73029 .34767 Mdot
.68197 .55718 Mdot
.64755 .69317 Mdot
.4744 .27487 Mdot
.37778 .45952 Mdot
.62984 .3717 Mdot
.35978 .53478 Mdot
.39098 .54091 Mdot
.6843 .61327 Mdot
.63516 .26168 Mdot
.51586 .64957 Mdot
.46431 .71315 Mdot
.62736 .58396 Mdot
.44435 .59125 Mdot
.61498 .60849 Mdot
.46107 .35169 Mdot
.39552 .22554 Mdot
.64155 .58603 Mdot
.49293 .65739 Mdot
.66319 .54412 Mdot
.37023 .48887 Mdot
.4455 .53729 Mdot
.49071 .66683 Mdot
.43853 .30291 Mdot
.32514 .48134 Mdot
.38129 .50796 Mdot
.41029 .81352 Mdot
.37612 .25342 Mdot
.67388 .46901 Mdot
.41008 .51961 Mdot
.40037 .47013 Mdot
.47527 .31867 Mdot
.37066 .48026 Mdot
.34337 .49945 Mdot
.22899 .60573 Mdot
.6001 .73608 Mdot
.42081 .32123 Mdot
.64634 .78374 Mdot
.50964 .68856 Mdot
.63806 .20791 Mdot
.58909 .38601 Mdot
.71012 .61583 Mdot
.20017 .54065 Mdot
.61014 .36075 Mdot
.73435 .51055 Mdot
.66402 .2234 Mdot
.61918 .50548 Mdot
.5475 .39741 Mdot
.47943 .61836 Mdot
.36126 .47411 Mdot
.38904 .50812 Mdot
.44137 .34442 Mdot
.4734 .6791 Mdot
.58684 .50793 Mdot
.78138 .65511 Mdot
.38339 .5252 Mdot
.53699 .64838 Mdot
.73426 .67679 Mdot
.51633 .2655 Mdot
.45895 .33354 Mdot
.42628 .31037 Mdot
.39607 .5074 Mdot
.22202 .62272 Mdot
.49146 .71424 Mdot
.35734 .5036 Mdot
.43211 .49718 Mdot
.61119 .37156 Mdot
.47013 .64608 Mdot
.62391 .43338 Mdot
.72595 .44442 Mdot
.70584 .2678 Mdot
.44843 .83761 Mdot
.67523 .57734 Mdot
.79531 .56485 Mdot
.62798 .56055 Mdot
.379 .37852 Mdot
.64961 .38023 Mdot
.40527 .55582 Mdot
.48774 .72396 Mdot
.35425 .5208 Mdot
.40382 .56073 Mdot
.36243 .50001 Mdot
.39641 .463 Mdot
.35403 .82306 Mdot
.46364 .31657 Mdot
.40429 .58765 Mdot
.61085 .37972 Mdot
.80837 .46951 Mdot
.82074 .54377 Mdot
.36342 .50819 Mdot
.40471 .50357 Mdot
.45734 .66444 Mdot
.35218 .53681 Mdot
.62836 .56983 Mdot
.51461 .70752 Mdot
.38853 .47738 Mdot
.81338 .38871 Mdot
.40521 .48401 Mdot
.65239 .2265 Mdot
.65546 .54235 Mdot
.60336 .76845 Mdot
.42045 .58725 Mdot
.68209 .43746 Mdot
.60806 .50489 Mdot
.60998 .42202 Mdot
.65223 .53255 Mdot
.60668 .40065 Mdot
.76343 .68529 Mdot
.44755 .54249 Mdot
.41104 .53194 Mdot
.39581 .45661 Mdot
.5785 .41118 Mdot
.79387 .4013 Mdot
.76529 .45823 Mdot
.41687 .59277 Mdot
.58237 .40987 Mdot
.44681 .663 Mdot
.34556 .28118 Mdot
.46586 .69072 Mdot
.45398 .36685 Mdot
.63829 .56648 Mdot
.43361 .30703 Mdot
.51757 .21133 Mdot
.48305 .65205 Mdot
.52315 .68265 Mdot
.59027 .38973 Mdot
.50406 .52105 Mdot
.15291 .4052 Mdot
.49803 .52639 Mdot
.35796 .35333 Mdot
.49793 .69746 Mdot
.39647 .47321 Mdot
.40544 .37682 Mdot
.51661 .55505 Mdot
.60961 .4017 Mdot
.38228 .54378 Mdot
.22227 .55682 Mdot
.60567 .41898 Mdot
.40146 .45634 Mdot
.61565 .37743 Mdot
.64406 .56839 Mdot
.63618 .37822 Mdot
.50427 .73916 Mdot
.39692 .48697 Mdot
.18393 .34187 Mdot
.41233 .29295 Mdot
.40225 .52431 Mdot
.62692 .58516 Mdot
.72876 .55133 Mdot
.38293 .55503 Mdot
.47662 .34652 Mdot
.59866 .41187 Mdot
.49292 .48734 Mdot
.40684 .51427 Mdot
.57869 .40652 Mdot
.50132 .65257 Mdot
.63543 .53706 Mdot
.25484 .55439 Mdot
.66704 .45928 Mdot
.50262 .69565 Mdot
.5014 .38856 Mdot
.67525 .54145 Mdot
.39979 .46929 Mdot
.42154 .47591 Mdot
.48276 .69463 Mdot
.28935 .44662 Mdot
.39056 .56733 Mdot
.42655 .54688 Mdot
.60012 .37674 Mdot
.60436 .40392 Mdot
.24723 .501 Mdot
.60029 .43877 Mdot
.44521 .53997 Mdot
.48129 .69638 Mdot
.40173 .55054 Mdot
.45968 .65265 Mdot
.35462 .53924 Mdot
.36437 .59657 Mdot
.46098 .70079 Mdot
.59452 .59471 Mdot
.38701 .54376 Mdot
.37647 .43925 Mdot
.36936 .54986 Mdot
.35934 .4781 Mdot
.61487 .41837 Mdot
.4617 .34295 Mdot
.43342 .48545 Mdot
.48659 .34079 Mdot
.46295 .35913 Mdot
.68237 .53429 Mdot
.61458 .37201 Mdot
.44023 .32636 Mdot
.74121 .67736 Mdot
.5843 .37213 Mdot
.43277 .33165 Mdot
.82043 .54083 Mdot
.67496 .55627 Mdot
.45309 .66073 Mdot
.41267 .54536 Mdot
.52268 .20075 Mdot
.42516 .79189 Mdot
.58066 .43636 Mdot
.40642 .51845 Mdot
.36578 .54393 Mdot
.4969 .72679 Mdot
.77743 .68997 Mdot
.58015 .36888 Mdot
.4195 .4971 Mdot
.47745 .6571 Mdot
.75804 .73332 Mdot
.60874 .38364 Mdot
.43462 .33689 Mdot
.6824 .56362 Mdot
.51503 .74528 Mdot
.58499 .73627 Mdot
.662 .61095 Mdot
.5924 .45625 Mdot
.71878 .42997 Mdot
.43171 .50809 Mdot
.63445 .37265 Mdot
.33311 .23377 Mdot
.42412 .64512 Mdot
.58265 .55542 Mdot
.284 .34427 Mdot
.49665 .6708 Mdot
.62817 .56426 Mdot
.45791 .31471 Mdot
.50841 .69919 Mdot
.49056 .65134 Mdot
.68243 .606 Mdot
.24999 .63603 Mdot
.49953 .44373 Mdot
.65253 .58777 Mdot
.40999 .2451 Mdot
.68881 .31647 Mdot
.6284 .37056 Mdot
.43159 .31791 Mdot
.53778 .2132 Mdot
.47411 .70535 Mdot
.79638 .34431 Mdot
.36416 .23368 Mdot
.39629 .52093 Mdot
.44383 .32857 Mdot
.77355 .3781 Mdot
.80997 .6271 Mdot
.67391 .56433 Mdot
.70402 .5531 Mdot
.42786 .32237 Mdot
.34409 .52451 Mdot
.33968 .29576 Mdot
.42477 .54651 Mdot
.63821 .56114 Mdot
.27282 .56813 Mdot
.48914 .65227 Mdot
.68759 .58919 Mdot
.39188 .22483 Mdot
.38749 .53155 Mdot
.38694 .54527 Mdot
.38434 .29958 Mdot
.50429 .71466 Mdot
.60925 .42222 Mdot
.43272 .50493 Mdot
.38224 .51201 Mdot
.44355 .5023 Mdot
.429 .46194 Mdot
.21922 .58723 Mdot
.42074 .52022 Mdot
.77245 .43973 Mdot
.34981 .47237 Mdot
.37923 .53709 Mdot
.44975 .64761 Mdot
.44539 .8435 Mdot
.73597 .43976 Mdot
.38329 .516 Mdot
.40467 .47784 Mdot
.68863 .58221 Mdot
.51024 .49655 Mdot
.50381 .50549 Mdot
.49075 .47761 Mdot
.26615 .37922 Mdot
.3306 .50349 Mdot
.47317 .6675 Mdot
.47356 .32439 Mdot
.42481 .50117 Mdot
.47392 .66324 Mdot
.36117 .55651 Mdot
.6022 .4192 Mdot
.58299 .37342 Mdot
.42497 .63369 Mdot
.44158 .32045 Mdot
.50443 .59993 Mdot
.63892 .69477 Mdot
.5793 .38428 Mdot
.4133 .53241 Mdot
.68263 .62001 Mdot
.62316 .42725 Mdot
.68266 .41021 Mdot
.30054 .45704 Mdot
.49589 .71564 Mdot
.49391 .68143 Mdot
.32405 .40058 Mdot
.73119 .49051 Mdot
.31742 .76468 Mdot
.64283 .56778 Mdot
.4319 .56561 Mdot
.64326 .65689 Mdot
.49635 .68044 Mdot
.39479 .37244 Mdot
.44267 .32492 Mdot
.6711 .5579 Mdot
.53586 .39538 Mdot
.45988 .6643 Mdot
.48544 .64499 Mdot
.34172 .48485 Mdot
.37444 .50485 Mdot
.24999 .41515 Mdot
.47546 .37342 Mdot
.66168 .61237 Mdot
.43018 .32239 Mdot
.64889 .37972 Mdot
.4219 .5123 Mdot
.46724 .70856 Mdot
.6867 .32306 Mdot
.41995 .494 Mdot
.62727 .41559 Mdot
.49399 .67333 Mdot
.43128 .33948 Mdot
.47841 .3471 Mdot
.3633 .47685 Mdot
.33487 .6074 Mdot
.65843 .58144 Mdot
.4974 .66343 Mdot
.6079 .60114 Mdot
.41193 .56583 Mdot
.37924 .49873 Mdot
.44581 .47123 Mdot
.66041 .61275 Mdot
.68952 .69806 Mdot
.44434 .36074 Mdot
.47706 .67677 Mdot
.41633 .51285 Mdot
.43382 .32151 Mdot
.67482 .68204 Mdot
.64857 .39907 Mdot
.63731 .3812 Mdot
.47934 .3417 Mdot
.45227 .33112 Mdot
.47119 .35303 Mdot
.79682 .34386 Mdot
.48881 .73296 Mdot
.50047 .62263 Mdot
.41524 .57209 Mdot
.35593 .37042 Mdot
.34685 .57131 Mdot
.63626 .5945 Mdot
.62051 .37607 Mdot
.38856 .55952 Mdot
.37994 .46868 Mdot
.45863 .54256 Mdot
.54538 .67513 Mdot
.4988 .76392 Mdot
.47683 .64719 Mdot
.44021 .56372 Mdot
.60137 .37194 Mdot
.8585 .41051 Mdot
.43426 .16437 Mdot
.42389 .58477 Mdot
.49117 .43812 Mdot
.46873 .71268 Mdot
.68809 .5685 Mdot
.40331 .2862 Mdot
.6762 .55558 Mdot
.47987 .67571 Mdot
.42133 .51796 Mdot
.64653 .70123 Mdot
.48103 .33088 Mdot
.35179 .50209 Mdot
.6415 .55307 Mdot
.3485 .49946 Mdot
.66378 .61109 Mdot
.58227 .20271 Mdot
.28833 .29684 Mdot
.39178 .52391 Mdot
.36668 .57786 Mdot
.26631 .3563 Mdot
.36132 .51233 Mdot
.4541 .37634 Mdot
.46825 .7124 Mdot
.24483 .5274 Mdot
.35236 .56035 Mdot
.40394 .65435 Mdot
.41862 .56112 Mdot
.22792 .50915 Mdot
.37652 .49743 Mdot
.51218 .27272 Mdot
.4046 .49005 Mdot
.34723 .48681 Mdot
.67274 .58425 Mdot
.68753 .58752 Mdot
.46064 .63241 Mdot
.58367 .42203 Mdot
.67687 .23952 Mdot
.38102 .50435 Mdot
.69307 .40588 Mdot
.63598 .72802 Mdot
.45434 .33113 Mdot
.47704 .68093 Mdot
.80514 .66437 Mdot
.64252 .54224 Mdot
.33908 .26063 Mdot
.24566 .48522 Mdot
.58451 .68371 Mdot
.42434 .26483 Mdot
.7443 .61353 Mdot
.43742 .34884 Mdot
.35559 .54818 Mdot
.6636 .29299 Mdot
.50849 .285 Mdot
.2937 .46429 Mdot
.6751 .53952 Mdot
.39085 .68417 Mdot
.64959 .27288 Mdot
.4719 .36212 Mdot
.42621 .31773 Mdot
.67693 .59445 Mdot
.55154 .36764 Mdot
.38407 .59856 Mdot
.44617 .32423 Mdot
.57208 .39577 Mdot
.59254 .36721 Mdot
.59573 .36063 Mdot
.48681 .71701 Mdot
.38525 .20994 Mdot
.6414 .62679 Mdot
.65477 .60765 Mdot
.59453 .34722 Mdot
.4388 .66886 Mdot
.50259 .73224 Mdot
.59726 .3927 Mdot
.63959 .40407 Mdot
.45901 .70063 Mdot
.44844 .5007 Mdot
.44951 .55986 Mdot
.38399 .52121 Mdot
.45556 .34867 Mdot
.37212 .49929 Mdot
.58766 .4125 Mdot
.6725 .56697 Mdot
.63986 .39708 Mdot
.6227 .57155 Mdot
.74261 .36636 Mdot
.35822 .49321 Mdot
.40079 .48953 Mdot
.45792 .81108 Mdot
.492 .6444 Mdot
.76792 .41583 Mdot
.65248 .47674 Mdot
.61951 .39004 Mdot
.34265 .50451 Mdot
.51527 .70749 Mdot
.48401 .3584 Mdot
.48304 .82303 Mdot
.39617 .56428 Mdot
.46466 .69856 Mdot
.41901 .50895 Mdot
.33457 .59714 Mdot
.20739 .65541 Mdot
.47632 .70113 Mdot
.43052 .8063 Mdot
.40304 .47877 Mdot
.76153 .62325 Mdot
.37672 .44895 Mdot
.27966 .42943 Mdot
.39091 .56736 Mdot
.51001 .69099 Mdot
.38045 .51977 Mdot
.51712 .69871 Mdot
.58234 .38445 Mdot
.68701 .56853 Mdot
.50075 .69013 Mdot
.41133 .46593 Mdot
.22409 .23927 Mdot
.64372 .55878 Mdot
.39604 .51096 Mdot
.68087 .57502 Mdot
.47066 .67932 Mdot
.50451 .67751 Mdot
.80666 .61461 Mdot
.72905 .44798 Mdot
.64531 .56816 Mdot
.42102 .51103 Mdot
.76976 .57019 Mdot
.41607 .55061 Mdot
.2706 .40962 Mdot
.44129 .48687 Mdot
.41235 .57035 Mdot
.82467 .54743 Mdot
.65364 .60857 Mdot
.29965 .75235 Mdot
.82332 .59089 Mdot
.81015 .47479 Mdot
.52577 .70798 Mdot
.47547 .36136 Mdot
.72686 .25881 Mdot
.70357 .44382 Mdot
.58027 .40917 Mdot
.37924 .55573 Mdot
.46829 .742 Mdot
.6606 .58521 Mdot
.46508 .34315 Mdot
.39206 .52282 Mdot
.64254 .39595 Mdot
.20131 .47544 Mdot
.62473 .55461 Mdot
.47155 .69879 Mdot
.47029 .72178 Mdot
.63387 .81531 Mdot
.41279 .51747 Mdot
.39458 .48346 Mdot
.63779 .56464 Mdot
.71941 .67923 Mdot
.44686 .35702 Mdot
.22685 .47186 Mdot
.64632 .56683 Mdot
.55912 .50561 Mdot
.48086 .65978 Mdot
.36364 .54166 Mdot
.77711 .35307 Mdot
.54413 .34359 Mdot
.48596 .79196 Mdot
.44991 .34872 Mdot
.2742 .40192 Mdot
.50994 .68719 Mdot
.65941 .55431 Mdot
.7058 .49954 Mdot
.33294 .48481 Mdot
.36135 .53433 Mdot
.28043 .39948 Mdot
.69774 .55095 Mdot
.47687 .47459 Mdot
.40277 .56507 Mdot
.60902 .50898 Mdot
.38139 .56156 Mdot
.32784 .51993 Mdot
.44979 .52186 Mdot
.38418 .49082 Mdot
.46587 .70483 Mdot
.46683 .50897 Mdot
.594 .42118 Mdot
.48617 .60126 Mdot
.56047 .51549 Mdot
.40286 .52009 Mdot
.43002 .53111 Mdot
.4393 .7627 Mdot
.74069 .53376 Mdot
.4984 .68828 Mdot
.52333 .70617 Mdot
.67057 .54291 Mdot
.45365 .55345 Mdot
.59206 .42727 Mdot
.32799 .53271 Mdot
.62142 .41708 Mdot
.46856 .70891 Mdot
.61555 .38734 Mdot
.68425 .56913 Mdot
.61431 .36707 Mdot
.70291 .44056 Mdot
.65369 .54761 Mdot
.50015 .70961 Mdot
.38326 .47992 Mdot
.62615 .5836 Mdot
.35695 .31026 Mdot
.45334 .3484 Mdot
.84522 .56194 Mdot
.38972 .47726 Mdot
.59413 .74037 Mdot
.30262 .52985 Mdot
.63974 .40097 Mdot
.21802 .66675 Mdot
.46471 .71274 Mdot
.42417 .3089 Mdot
.48806 .72697 Mdot
.36708 .24947 Mdot
.45402 .34037 Mdot
.83105 .5191 Mdot
.61121 .47201 Mdot
.36954 .25998 Mdot
.45549 .52956 Mdot
.38106 .27814 Mdot
.62855 .36426 Mdot
.66233 .58469 Mdot
.71764 .50399 Mdot
.34467 .49664 Mdot
.2225 .38686 Mdot
.44935 .6827 Mdot
.58471 .42156 Mdot
.6645 .56116 Mdot
.632 .58733 Mdot
.43427 .54345 Mdot
.57031 .26321 Mdot
.35233 .52649 Mdot
.72913 .47648 Mdot
.2696 .38218 Mdot
.53464 .70713 Mdot
.40185 .51323 Mdot
.58032 .38812 Mdot
.41909 .50917 Mdot
.41884 .33207 Mdot
.3655 .2115 Mdot
.33149 .46838 Mdot
.65698 .47767 Mdot
.41387 .2897 Mdot
.48963 .66134 Mdot
.29825 .49915 Mdot
.69099 .45726 Mdot
.41499 .51841 Mdot
.26008 .77512 Mdot
.43267 .32707 Mdot
.65814 .29043 Mdot
.40774 .47039 Mdot
.4366 .52329 Mdot
.56687 .58649 Mdot
.57695 .72579 Mdot
.53388 .35095 Mdot
.36263 .52114 Mdot
.30833 .35263 Mdot
.66699 .60567 Mdot
.35748 .54043 Mdot
.39104 .50785 Mdot
.28848 .6863 Mdot
.62668 .57718 Mdot
.62674 .39086 Mdot
.62572 .36187 Mdot
.58949 .4399 Mdot
.41738 .32341 Mdot
.66073 .50963 Mdot
.38114 .36255 Mdot
.18603 .4917 Mdot
.44088 .29795 Mdot
.37552 .47179 Mdot
.42917 .37705 Mdot
.42471 .52495 Mdot
.46375 .32852 Mdot
.62566 .57159 Mdot
.50053 .68506 Mdot
.66729 .66117 Mdot
.59119 .3649 Mdot
.3679 .44633 Mdot
.44063 .35513 Mdot
.49741 .71183 Mdot
.42432 .25897 Mdot
.48461 .66321 Mdot
.65339 .56743 Mdot
.62091 .58488 Mdot
.46677 .33777 Mdot
.46745 .6773 Mdot
.61212 .53364 Mdot
.79757 .6438 Mdot
.44753 .52532 Mdot
.72894 .59959 Mdot
.51102 .67355 Mdot
.51915 .71836 Mdot
.51439 .69415 Mdot
.35176 .48822 Mdot
.49157 .43748 Mdot
.3697 .56661 Mdot
.65675 .60984 Mdot
.6192 .37967 Mdot
.24737 .37954 Mdot
.72073 .38199 Mdot
.48167 .39522 Mdot
.43523 .56473 Mdot
.38557 .53185 Mdot
.39585 .50757 Mdot
.34807 .55736 Mdot
.70515 .47503 Mdot
.35514 .52536 Mdot
.6723 .58625 Mdot
.59758 .41346 Mdot
.35515 .54814 Mdot
.6347 .35639 Mdot
.80231 .46871 Mdot
.44562 .29956 Mdot
.6889 .5249 Mdot
.4514 .14407 Mdot
.49948 .70581 Mdot
.63219 .4307 Mdot
.57947 .40378 Mdot
.46322 .35388 Mdot
.65398 .58376 Mdot
.48164 .66432 Mdot
.26352 .43338 Mdot
.46582 .35681 Mdot
.3812 .5168 Mdot
.4735 .43184 Mdot
.24261 .34941 Mdot
.35783 .54912 Mdot
.39205 .55517 Mdot
.64896 .36886 Mdot
.63872 .28055 Mdot
.22951 .29908 Mdot
.39032 .34342 Mdot
.46426 .34111 Mdot
.45415 .30705 Mdot
.45368 .67864 Mdot
.38049 .57424 Mdot
.65943 .61115 Mdot
.48382 .51849 Mdot
.70098 .52649 Mdot
.49381 .57492 Mdot
.53593 .75605 Mdot
.38788 .5618 Mdot
.6637 .76224 Mdot
.38933 .53421 Mdot
.49058 .7324 Mdot
.47277 .71055 Mdot
.49117 .70202 Mdot
.66223 .58331 Mdot
.35065 .69738 Mdot
.66641 .59208 Mdot
.43531 .14378 Mdot
.50706 .67426 Mdot
.61415 .4791 Mdot
.5934 .38305 Mdot
.4271 .58604 Mdot
.4299 .33389 Mdot
.61959 .54113 Mdot
.46056 .55068 Mdot
.22073 .63937 Mdot
.58671 .42061 Mdot
.50195 .70628 Mdot
.74009 .61985 Mdot
.51093 .16752 Mdot
.49814 .48795 Mdot
.44675 .59164 Mdot
.40722 .27744 Mdot
.45648 .32853 Mdot
.4852 .79293 Mdot
.42886 .32353 Mdot
.64266 .55112 Mdot
.40181 .49351 Mdot
.38857 .48532 Mdot
.37805 .56051 Mdot
.35932 .50139 Mdot
.68402 .55341 Mdot
.42633 .47953 Mdot
.18387 .61808 Mdot
.57836 .37845 Mdot
.28045 .4959 Mdot
.43114 .33237 Mdot
.65676 .53099 Mdot
.59562 .41343 Mdot
.73741 .52906 Mdot
.37062 .31068 Mdot
.40552 .51433 Mdot
.38532 .55877 Mdot
.32999 .26412 Mdot
.40432 .56511 Mdot
.37144 .58958 Mdot
.57915 .40765 Mdot
.44695 .39917 Mdot
.44092 .30092 Mdot
.44947 .30571 Mdot
.65733 .54635 Mdot
.46791 .70654 Mdot
.43656 .33282 Mdot
.59578 .3792 Mdot
.43673 .56282 Mdot
.42531 .48458 Mdot
.51099 .67467 Mdot
.34416 .23557 Mdot
.45133 .36323 Mdot
.76735 .58498 Mdot
.48941 .7223 Mdot
.47942 .62769 Mdot
.36221 .53529 Mdot
.53065 .74614 Mdot
.50358 .74623 Mdot
.42912 .29878 Mdot
.65722 .53158 Mdot
.3947 .29581 Mdot
.63288 .56535 Mdot
.46895 .69578 Mdot
.42524 .50561 Mdot
.48074 .7183 Mdot
.41021 .51794 Mdot
.56668 .15948 Mdot
.38308 .48678 Mdot
.18125 .49933 Mdot
.31252 .40091 Mdot
.59005 .40054 Mdot
.74361 .55776 Mdot
.58919 .38705 Mdot
.49575 .72099 Mdot
.42925 .5059 Mdot
.42727 .33915 Mdot
.8087 .51634 Mdot
.44331 .69841 Mdot
.63255 .41327 Mdot
.56206 .39147 Mdot
.63181 .55619 Mdot
.38409 .56613 Mdot
.35929 .53163 Mdot
.60844 .40849 Mdot
.53617 .70386 Mdot
.46197 .66743 Mdot
.40643 .50247 Mdot
.38107 .53336 Mdot
.59048 .39793 Mdot
.78789 .6586 Mdot
.43589 .67415 Mdot
.3964 .49342 Mdot
.68847 .34704 Mdot
.64098 .59952 Mdot
.44228 .56529 Mdot
.36641 .57905 Mdot
.45017 .32914 Mdot
.25899 .58987 Mdot
.40509 .20439 Mdot
.62456 .56429 Mdot
.57635 .39763 Mdot
.41438 .51491 Mdot
.5796 .38916 Mdot
.42631 .48387 Mdot
.57364 .71677 Mdot
.64764 .38882 Mdot
.42696 .5484 Mdot
.44074 .48033 Mdot
.50469 .71483 Mdot
.38739 .56071 Mdot
.41964 .76194 Mdot
.61625 .4277 Mdot
.43582 .53508 Mdot
.3253 .60338 Mdot
.64842 .58857 Mdot
.45646 .53426 Mdot
.47415 .33575 Mdot
.26073 .43738 Mdot
.61526 .69993 Mdot
.61579 .2475 Mdot
.45533 .30543 Mdot
.34835 .50373 Mdot
.56418 .40145 Mdot
.6705 .60706 Mdot
.18123 .52377 Mdot
.34693 .52788 Mdot
.63901 .55973 Mdot
.67159 .56496 Mdot
.4606 .35132 Mdot
.46807 .8394 Mdot
.39882 .46486 Mdot
.36476 .50692 Mdot
.33989 .7284 Mdot
.49967 .64957 Mdot
.37532 .49075 Mdot
.3855 .47142 Mdot
.67366 .58628 Mdot
.4199 .60352 Mdot
.41055 .70791 Mdot
.2263 .48912 Mdot
.66628 .61571 Mdot
.51969 .57868 Mdot
.62092 .36563 Mdot
.43834 .31592 Mdot
.48884 .67047 Mdot
.43605 .35118 Mdot
.62311 .37141 Mdot
.38406 .47319 Mdot
.66267 .54147 Mdot
.39137 .76669 Mdot
.67759 .59375 Mdot
.58042 .22973 Mdot
.50705 .6608 Mdot
.62545 .64532 Mdot
.31086 .81271 Mdot
.78275 .51926 Mdot
.67329 .63 Mdot
.45403 .33136 Mdot
.57344 .34156 Mdot
.38294 .53365 Mdot
.47979 .79804 Mdot
.37055 .47559 Mdot
.31247 .5972 Mdot
.57473 .386 Mdot
.57856 .37417 Mdot
.39991 .49407 Mdot
.26706 .39129 Mdot
.67195 .60607 Mdot
.63826 .59354 Mdot
.42849 .54994 Mdot
.6543 .5723 Mdot
.37208 .50831 Mdot
.60059 .41729 Mdot
.30579 .76666 Mdot
.388 .52035 Mdot
.34124 .55169 Mdot
.58061 .71008 Mdot
.82805 .56123 Mdot
.50677 .23179 Mdot
.69983 .76409 Mdot
.4845 .16815 Mdot
.65567 .57211 Mdot
.39466 .57477 Mdot
.51936 .58041 Mdot
.62903 .36002 Mdot
.61018 .548 Mdot
.37443 .48126 Mdot
.36926 .47977 Mdot
.34726 .48476 Mdot
.39063 .54764 Mdot
.50795 .80325 Mdot
.47206 .54705 Mdot
.29843 .62968 Mdot
.39984 .56118 Mdot
.36984 .28584 Mdot
.65152 .54401 Mdot
.52033 .7358 Mdot
.44232 .29529 Mdot
.38699 .56138 Mdot
.46972 .6007 Mdot
.69124 .57808 Mdot
.43133 .14303 Mdot
.64338 .54799 Mdot
.62575 .39648 Mdot
.68587 .5804 Mdot
.40109 .53397 Mdot
.48147 .68464 Mdot
.5357 .548 Mdot
.76188 .47422 Mdot
.58068 .41027 Mdot
.40244 .52392 Mdot
.62806 .48209 Mdot
.59025 .42013 Mdot
.80375 .45751 Mdot
.48624 .67904 Mdot
.31309 .35161 Mdot
.47643 .71558 Mdot
.43219 .54134 Mdot
.43335 .5352 Mdot
.66021 .62476 Mdot
.68599 .57371 Mdot
.4746 .71395 Mdot
.47857 .84904 Mdot
.46655 .35941 Mdot
.48886 .70543 Mdot
.33769 .4742 Mdot
.51993 .47114 Mdot
.48387 .6891 Mdot
.42081 .28307 Mdot
.67422 .57402 Mdot
.46435 .63571 Mdot
.35511 .4654 Mdot
.41251 .23653 Mdot
.47475 .32468 Mdot
.65255 .3787 Mdot
.40914 .36314 Mdot
.6185 .42893 Mdot
.65473 .53239 Mdot
.58837 .38877 Mdot
.66623 .60441 Mdot
.6217 .71882 Mdot
.50114 .60935 Mdot
.68513 .62323 Mdot
.66565 .53708 Mdot
.59063 .39024 Mdot
.40825 .49827 Mdot
.41688 .28053 Mdot
.41481 .57713 Mdot
.389 .45972 Mdot
.65755 .60517 Mdot
.5079 .69877 Mdot
.51418 .73544 Mdot
.34669 .29272 Mdot
.46056 .69354 Mdot
.62886 .41416 Mdot
.19681 .61659 Mdot
.69659 .38898 Mdot
.63685 .57924 Mdot
.68817 .57433 Mdot
.42382 .54602 Mdot
.60752 .40086 Mdot
.57398 .40157 Mdot
.63265 .5572 Mdot
.55029 .65183 Mdot
.37056 .57661 Mdot
.5134 .7268 Mdot
.49146 .64667 Mdot
.47868 .6998 Mdot
.5155 .69342 Mdot
.42637 .7071 Mdot
.67401 .559 Mdot
.50655 .70533 Mdot
.42134 .55328 Mdot
.37107 .48074 Mdot
.50162 .53649 Mdot
.45633 .31001 Mdot
.35099 .54458 Mdot
.45083 .52273 Mdot
.36575 .54238 Mdot
.639 .38062 Mdot
.37166 .42772 Mdot
.64632 .3954 Mdot
.56667 .39825 Mdot
.56959 .39795 Mdot
.70269 .44314 Mdot
.3129 .29237 Mdot
.50061 .18553 Mdot
.41867 .49544 Mdot
.71492 .69904 Mdot
.60651 .39049 Mdot
.21831 .64972 Mdot
.69254 .6962 Mdot
.3433 .51484 Mdot
.54302 .33497 Mdot
.604 .40705 Mdot
.4638 .70905 Mdot
.37766 .4827 Mdot
.60392 .44256 Mdot
.47515 .33551 Mdot
.43005 .55716 Mdot
.64878 .39064 Mdot
.46904 .6753 Mdot
.42697 .29715 Mdot
.47763 .63696 Mdot
.56975 .3944 Mdot
.44968 .49556 Mdot
.12246 .49045 Mdot
.55955 .40142 Mdot
.76534 .64804 Mdot
.3483 .59169 Mdot
.40717 .50062 Mdot
.6302 .42909 Mdot
.4925 .64051 Mdot
.64658 .53339 Mdot
.56485 .46585 Mdot
.46469 .64067 Mdot
.57904 .37356 Mdot
.63188 .41866 Mdot
.57958 .40928 Mdot
.47943 .64663 Mdot
.33314 .51314 Mdot
.4634 .64759 Mdot
.68453 .58426 Mdot
.41239 .54847 Mdot
.58612 .19737 Mdot
.70344 .70742 Mdot
.48246 .72146 Mdot
.6302 .3892 Mdot
.4781 .32354 Mdot
.39189 .52949 Mdot
.70206 .71447 Mdot
.41277 .50266 Mdot
.65701 .60726 Mdot
.23205 .59951 Mdot
.4213 .77862 Mdot
.41064 .57191 Mdot
.42242 .54724 Mdot
.64118 .59608 Mdot
.39771 .52097 Mdot
.38916 .56712 Mdot
.70627 .44723 Mdot
.47016 .64833 Mdot
.38012 .52351 Mdot
.6096 .37664 Mdot
.71528 .417 Mdot
.3619 .57147 Mdot
.66542 .34689 Mdot
.30094 .36885 Mdot
.23661 .61239 Mdot
.37179 .47513 Mdot
.46196 .43354 Mdot
.38017 .54368 Mdot
.35366 .49965 Mdot
.42424 .53382 Mdot
.54803 .8144 Mdot
.64693 .38402 Mdot
.58295 .40388 Mdot
.46402 .31083 Mdot
.30309 .36541 Mdot
.44598 .32832 Mdot
.67555 .57312 Mdot
.58957 .27681 Mdot
.64657 .39405 Mdot
.46621 .68619 Mdot
.35077 .50836 Mdot
.56003 .40288 Mdot
.36088 .53834 Mdot
.40289 .5337 Mdot
.59742 .43118 Mdot
.63262 .36812 Mdot
.64596 .27488 Mdot
.46711 .31665 Mdot
.49417 .69736 Mdot
.37452 .56566 Mdot
.44795 .35974 Mdot
.38558 .46742 Mdot
.3573 .37175 Mdot
.49129 .69801 Mdot
.46709 .64796 Mdot
.50987 .74034 Mdot
.38642 .47402 Mdot
.39761 .53076 Mdot
.66583 .59382 Mdot
.48235 .7242 Mdot
.64689 .58524 Mdot
.58927 .49853 Mdot
.61901 .3199 Mdot
.37425 .48118 Mdot
.72103 .63046 Mdot
.44863 .31563 Mdot
.63468 .40331 Mdot
.25016 .34769 Mdot
.46531 .31166 Mdot
.4101 .51516 Mdot
.57514 .41443 Mdot
.46367 .32456 Mdot
.26616 .50493 Mdot
.39375 .1804 Mdot
.46813 .30914 Mdot
.42083 .55406 Mdot
.43404 .59885 Mdot
.6868 .77489 Mdot
.45725 .30403 Mdot
.68062 .55981 Mdot
.38718 .47461 Mdot
.46793 .7343 Mdot
.43445 .35031 Mdot
.77305 .44651 Mdot
.59953 .41081 Mdot
.41396 .22326 Mdot
.45508 .47916 Mdot
.44449 .79736 Mdot
.44528 .3089 Mdot
.48039 .66915 Mdot
.32574 .56384 Mdot
.36719 .53849 Mdot
.46056 .30648 Mdot
.68854 .60963 Mdot
.61449 .41452 Mdot
.73266 .44056 Mdot
.47989 .64623 Mdot
.63328 .63084 Mdot
.63128 .38495 Mdot
.77025 .57807 Mdot
.22649 .52969 Mdot
.44812 .56028 Mdot
.67 .77934 Mdot
.66626 .50262 Mdot
.34013 .49161 Mdot
.48387 .33285 Mdot
.62387 .57434 Mdot
.66488 .54111 Mdot
.65036 .56487 Mdot
.63154 .72498 Mdot
.49082 .47565 Mdot
.63449 .43 Mdot
.62519 .61034 Mdot
.43878 .31702 Mdot
.39032 .29328 Mdot
.40308 .45996 Mdot
.38542 .52972 Mdot
.39505 .57055 Mdot
.37801 .5586 Mdot
.37313 .53705 Mdot
.65056 .57908 Mdot
.60832 .72387 Mdot
.49718 .50411 Mdot
.48696 .69472 Mdot
.61627 .27072 Mdot
.59666 .38322 Mdot
.63703 .42897 Mdot
.46844 .32668 Mdot
.79402 .51828 Mdot
.63656 .3568 Mdot
.61753 .38756 Mdot
.33785 .51648 Mdot
.4606 .66171 Mdot
.39998 .59688 Mdot
.42186 .55033 Mdot
.62723 .41378 Mdot
.5669 .55511 Mdot
.42432 .73787 Mdot
.33065 .43494 Mdot
.46741 .29593 Mdot
.50057 .46311 Mdot
.47506 .32132 Mdot
.42749 .50005 Mdot
.22139 .66658 Mdot
.62469 .37156 Mdot
.61928 .40082 Mdot
.44982 .31153 Mdot
.5183 .7618 Mdot
.49463 .66922 Mdot
.71716 .61908 Mdot
.67964 .58255 Mdot
.43082 .51665 Mdot
.2074 .46259 Mdot
.28904 .51687 Mdot
.55971 .26578 Mdot
.64535 .56356 Mdot
.58295 .38496 Mdot
.4282 .56955 Mdot
.41548 .55652 Mdot
.45183 .31557 Mdot
.69178 .28527 Mdot
.44637 .54504 Mdot
.81993 .43189 Mdot
.28871 .296 Mdot
.37032 .23653 Mdot
.36117 .53387 Mdot
.47199 .64703 Mdot
.64847 .37206 Mdot
.43251 .31636 Mdot
.34705 .46338 Mdot
.43022 .17508 Mdot
.5073 .66818 Mdot
.65223 .55067 Mdot
.55128 .53558 Mdot
.39361 .31267 Mdot
.36287 .47264 Mdot
.37448 .47634 Mdot
.355 .48966 Mdot
.33447 .20288 Mdot
.64362 .38487 Mdot
.47122 .71591 Mdot
.46326 .34865 Mdot
.46174 .69068 Mdot
.58528 .39735 Mdot
.62053 .63237 Mdot
.40874 .49501 Mdot
.50639 .66473 Mdot
.48175 .66893 Mdot
.63963 .55007 Mdot
.63799 .53591 Mdot
.56664 .51845 Mdot
.38231 .48825 Mdot
.55939 .39171 Mdot
.50603 .71007 Mdot
.47597 .43629 Mdot
.45262 .33895 Mdot
.67513 .57864 Mdot
.39414 .56102 Mdot
.63913 .37557 Mdot
.39898 .45406 Mdot
.49528 .68359 Mdot
.61687 .38785 Mdot
.68118 .32231 Mdot
.44694 .30132 Mdot
.36636 .49021 Mdot
.42526 .35497 Mdot
.57593 .40029 Mdot
.38321 .53575 Mdot
.78167 .58464 Mdot
.41926 .28634 Mdot
.76248 .45016 Mdot
.57131 .40658 Mdot
.68692 .4281 Mdot
.45409 .67134 Mdot
.64022 .73716 Mdot
.6231 .40022 Mdot
.75919 .59932 Mdot
.70182 .31816 Mdot
.43105 .57026 Mdot
.47597 .70666 Mdot
.65395 .49916 Mdot
.62844 .19801 Mdot
.76088 .68119 Mdot
.3949 .51011 Mdot
.60128 .43907 Mdot
.45639 .31828 Mdot
.63814 .58414 Mdot
.65755 .33469 Mdot
.43017 .2843 Mdot
.5757 .37115 Mdot
.42401 .53265 Mdot
.47453 .67342 Mdot
.66981 .57761 Mdot
.61855 .70462 Mdot
.60012 .37737 Mdot
.62282 .38042 Mdot
.4255 .57049 Mdot
.44236 .32401 Mdot
.67029 .73855 Mdot
.5946 .41648 Mdot
.30623 .28443 Mdot
.5513 .41103 Mdot
.45875 .36145 Mdot
.38498 .54982 Mdot
.34777 .28683 Mdot
.362 .56619 Mdot
.79932 .59206 Mdot
.59468 .3868 Mdot
.49351 .68971 Mdot
.35075 .4851 Mdot
.23691 .48619 Mdot
.63014 .41101 Mdot
.49306 .44346 Mdot
.50643 .26061 Mdot
.6759 .5662 Mdot
.24724 .35109 Mdot
.37047 .49696 Mdot
.67157 .60589 Mdot
.4505 .31735 Mdot
.39067 .4913 Mdot
.39776 .53382 Mdot
.50115 .72363 Mdot
.63642 .55479 Mdot
.67051 .28433 Mdot
.68889 .5849 Mdot
.65993 .54287 Mdot
.5117 .71746 Mdot
.37009 .51948 Mdot
.62623 .39485 Mdot
.60597 .4066 Mdot
.37081 .45256 Mdot
.26562 .74318 Mdot
.49554 .66621 Mdot
.65459 .37614 Mdot
.32178 .21323 Mdot
.39946 .44709 Mdot
.23813 .37101 Mdot
.70121 .29201 Mdot
.65183 .60958 Mdot
.41968 .55657 Mdot
.46927 .67823 Mdot
.52648 .38342 Mdot
.62508 .38337 Mdot
.35265 .47203 Mdot
.66845 .57512 Mdot
.47546 .33059 Mdot
.60774 .42625 Mdot
.56989 .26476 Mdot
.35783 .49668 Mdot
.53624 .33513 Mdot
.61391 .43684 Mdot
.74302 .27371 Mdot
.72937 .52583 Mdot
.4797 .70952 Mdot
.40404 .53683 Mdot
.46314 .71049 Mdot
.46586 .34614 Mdot
.55261 .53226 Mdot
.67147 .57142 Mdot
.46897 .49324 Mdot
.16717 .60154 Mdot
.57842 .40812 Mdot
.47037 .7162 Mdot
.41397 .5716 Mdot
.56868 .71504 Mdot
.36934 .5037 Mdot
.43302 .60729 Mdot
.42168 .3734 Mdot
.6505 .59922 Mdot
.67095 .60203 Mdot
.39128 .54226 Mdot
.45689 .3574 Mdot
.59626 .38041 Mdot
.62246 .41326 Mdot
.83967 .39533 Mdot
.5767 .61918 Mdot
.24923 .42152 Mdot
.36762 .48177 Mdot
.57092 .37645 Mdot
.72067 .39286 Mdot
.63824 .56482 Mdot
.37337 .44781 Mdot
.59123 .42645 Mdot
.45109 .25401 Mdot
.26274 .45433 Mdot
.37339 .54096 Mdot
.33263 .52954 Mdot
.68116 .57686 Mdot
.4797 .46197 Mdot
.5828 .37725 Mdot
.43268 .47502 Mdot
.68828 .6255 Mdot
.26366 .47948 Mdot
.33676 .22918 Mdot
.49424 .69776 Mdot
.5526 .25093 Mdot
.65078 .57998 Mdot
.33457 .53966 Mdot
.43844 .34808 Mdot
.64113 .36344 Mdot
.6434 .37981 Mdot
.4185 .52272 Mdot
.44024 .52412 Mdot
.26511 .34713 Mdot
.46166 .6791 Mdot
.65439 .54434 Mdot
.39151 .48227 Mdot
.6887 .6574 Mdot
.38186 .56222 Mdot
.66095 .59598 Mdot
.11516 .49862 Mdot
.41298 .57583 Mdot
.36686 .50686 Mdot
.68792 .72457 Mdot
.4736 .63979 Mdot
.47425 .72227 Mdot
.20801 .41861 Mdot
.36745 .48232 Mdot
.26935 .32352 Mdot
.49761 .69451 Mdot
.49644 .67258 Mdot
.71856 .45486 Mdot
.38947 .52805 Mdot
.44156 .44381 Mdot
.6589 .60924 Mdot
.66715 .54568 Mdot
.46854 .64319 Mdot
.44384 .5607 Mdot
.62619 .55673 Mdot
.57334 .79742 Mdot
.60614 .3997 Mdot
.23235 .68721 Mdot
.49887 .6655 Mdot
.69051 .53465 Mdot
.64089 .56483 Mdot
.44047 .14468 Mdot
.59046 .4581 Mdot
.40644 .49526 Mdot
.36362 .48832 Mdot
.44434 .31429 Mdot
.3911 .57158 Mdot
.57773 .37535 Mdot
.65368 .57232 Mdot
.28866 .57108 Mdot
.49124 .70273 Mdot
.37816 .49631 Mdot
.79886 .49754 Mdot
.77794 .41727 Mdot
.55166 .24134 Mdot
.48935 .66228 Mdot
.48404 .71585 Mdot
.59444 .37304 Mdot
.60181 .4387 Mdot
.36613 .52781 Mdot
.63326 .58397 Mdot
.48235 .72373 Mdot
.65911 .60037 Mdot
.62607 .37244 Mdot
.62379 .39149 Mdot
.6438 .3743 Mdot
.41517 .46559 Mdot
.61462 .38196 Mdot
.66048 .32215 Mdot
.63302 .62815 Mdot
.50437 .73002 Mdot
.25674 .30677 Mdot
.62575 .70533 Mdot
.48133 .76068 Mdot
.43458 .35217 Mdot
.57574 .40366 Mdot
.68316 .59153 Mdot
.40253 .55176 Mdot
.37195 .55097 Mdot
.68449 .39719 Mdot
.6771 .60597 Mdot
.46569 .34388 Mdot
.67438 .60083 Mdot
.46084 .35143 Mdot
.5164 .30225 Mdot
.37407 .56211 Mdot
.42833 .48997 Mdot
.64868 .5746 Mdot
.61517 .38444 Mdot
.58958 .40856 Mdot
.46102 .30329 Mdot
.58168 .55402 Mdot
.59015 .42074 Mdot
.50002 .67425 Mdot
.43519 .71941 Mdot
.63377 .41738 Mdot
.37672 .48517 Mdot
.38271 .36717 Mdot
.46958 .80506 Mdot
.34763 .55686 Mdot
.71334 .45176 Mdot
.38184 .77502 Mdot
.34542 .50364 Mdot
.44719 .81366 Mdot
.66275 .4644 Mdot
.4552 .67024 Mdot
.57681 .38353 Mdot
.63689 .35107 Mdot
.33181 .45766 Mdot
.44606 .29141 Mdot
.35614 .45804 Mdot
.4982 .66051 Mdot
.44739 .67379 Mdot
.38028 .24347 Mdot
.77876 .63211 Mdot
.45926 .32128 Mdot
.46258 .31954 Mdot
.62433 .40256 Mdot
.84683 .5774 Mdot
.45379 .57114 Mdot
.46554 .34121 Mdot
.51369 .61729 Mdot
.42257 .52985 Mdot
.29492 .39849 Mdot
.50485 .3574 Mdot
.47273 .64459 Mdot
.3689 .27925 Mdot
.63026 .40138 Mdot
.45951 .69149 Mdot
.66909 .6657 Mdot
.34606 .54047 Mdot
.49059 .69937 Mdot
.66261 .59874 Mdot
.74379 .51497 Mdot
.5046 .68098 Mdot
.37197 .36736 Mdot
.62941 .56225 Mdot
.48124 .44011 Mdot
.32855 .31647 Mdot
.55152 .89537 Mdot
.65334 .57735 Mdot
.63349 .41497 Mdot
.60666 .4074 Mdot
.62325 .41228 Mdot
.46044 .68484 Mdot
.57424 .40069 Mdot
.46281 .68378 Mdot
.71042 .73606 Mdot
.53241 .75751 Mdot
.4651 .33915 Mdot
.73569 .44466 Mdot
.47229 .686 Mdot
.20882 .64429 Mdot
.22648 .72576 Mdot
.42048 .55652 Mdot
.68976 .56802 Mdot
.46398 .33314 Mdot
.8234 .44275 Mdot
.45193 .32667 Mdot
.34548 .26716 Mdot
.22993 .63096 Mdot
.37689 .5047 Mdot
.38307 .70534 Mdot
.42887 .30992 Mdot
.48183 .65858 Mdot
.38479 .53538 Mdot
.53293 .43051 Mdot
.44897 .32353 Mdot
.47272 .34718 Mdot
.3727 .52722 Mdot
.50192 .70664 Mdot
.63205 .39552 Mdot
.68452 .56266 Mdot
.42205 .32851 Mdot
.37687 .59895 Mdot
.34359 .54742 Mdot
.4167 .50419 Mdot
.50527 .53204 Mdot
.47583 .37008 Mdot
.65643 .5725 Mdot
.51006 .82538 Mdot
.57272 .41521 Mdot
.54082 .43581 Mdot
.3165 .26936 Mdot
.6949 .4537 Mdot
.59548 .3889 Mdot
.58032 .39107 Mdot
.3703 .53589 Mdot
.49148 .35947 Mdot
.23296 .64325 Mdot
.59949 .53957 Mdot
.64963 .3793 Mdot
.61842 .4148 Mdot
.45432 .69739 Mdot
.36594 .24587 Mdot
.34262 .46658 Mdot
.62424 .56374 Mdot
.64182 .37596 Mdot
.5636 .74669 Mdot
.44006 .32192 Mdot
.21409 .61661 Mdot
.36837 .55922 Mdot
.40211 .491 Mdot
.6638 .56483 Mdot
.66741 .59045 Mdot
.52402 .38348 Mdot
.35837 .25256 Mdot
.39618 .77944 Mdot
.5996 .70451 Mdot
.25362 .62427 Mdot
.45068 .69111 Mdot
.4831 .72165 Mdot
.77378 .48856 Mdot
.69015 .58122 Mdot
.34695 .49572 Mdot
.46947 .70888 Mdot
.55799 .45036 Mdot
.44186 .71526 Mdot
.26857 .40712 Mdot
.24497 .3754 Mdot
.40846 .51948 Mdot
.46676 .65562 Mdot
.47727 .64123 Mdot
.51501 .66362 Mdot
.64526 .47864 Mdot
.36252 .52055 Mdot
.40226 .51516 Mdot
.34841 .51745 Mdot
.5552 .69758 Mdot
.35525 .51226 Mdot
.63116 .73876 Mdot
.55043 .51301 Mdot
.26294 .58221 Mdot
.44088 .48944 Mdot
.64287 .60705 Mdot
.36838 .47195 Mdot
.45853 .35676 Mdot
.42782 .53409 Mdot
.26615 .4131 Mdot
.64335 .55511 Mdot
.43623 .67994 Mdot
.62605 .71449 Mdot
.34248 .49257 Mdot
.42446 .30339 Mdot
.71772 .54583 Mdot
.56996 .19114 Mdot
.41604 .34567 Mdot
.49993 .67234 Mdot
.60227 .39536 Mdot
.68219 .59494 Mdot
.62076 .39388 Mdot
.43175 .48494 Mdot
.77609 .50402 Mdot
.78259 .39676 Mdot
.59579 .50288 Mdot
.37935 .55855 Mdot
.43115 .44882 Mdot
.49775 .67775 Mdot
.5762 .41748 Mdot
.49306 .75204 Mdot
.35327 .48431 Mdot
.45492 .34929 Mdot
.44818 .3188 Mdot
.57349 .46901 Mdot
.72926 .28879 Mdot
.56273 .77903 Mdot
.66271 .56707 Mdot
.60201 .41867 Mdot
.42808 .32756 Mdot
.75055 .63766 Mdot
.63618 .53591 Mdot
.6453 .60115 Mdot
.64716 .54964 Mdot
.39863 .47536 Mdot
.64794 .38799 Mdot
.26426 .58053 Mdot
.57603 .37337 Mdot
.3994 .52358 Mdot
.64118 .38403 Mdot
.58763 .42311 Mdot
.43082 .32735 Mdot
.64967 .546 Mdot
.61448 .37021 Mdot
.4339 .53698 Mdot
.49964 .70087 Mdot
.70529 .57939 Mdot
.29797 .41896 Mdot
.78403 .61957 Mdot
.30198 .56737 Mdot
.49375 .64995 Mdot
.6287 .20326 Mdot
.64496 .60322 Mdot
.55327 .66073 Mdot
.63824 .27168 Mdot
.42211 .49634 Mdot
.23108 .71263 Mdot
.6393 .42623 Mdot
.59832 .42872 Mdot
.38523 .54869 Mdot
.54719 .37352 Mdot
.37524 .4999 Mdot
.62911 .37791 Mdot
.6848 .35496 Mdot
.45487 .61401 Mdot
.60921 .38341 Mdot
.4267 .46899 Mdot
.39436 .5371 Mdot
.46885 .64568 Mdot
.62809 .4295 Mdot
.36478 .44816 Mdot
.82852 .37531 Mdot
.66365 .59109 Mdot
.65173 .48852 Mdot
.38767 .37875 Mdot
.65041 .58129 Mdot
.48635 .70564 Mdot
.39329 .45939 Mdot
.4518 .31686 Mdot
.47135 .68446 Mdot
.25441 .46942 Mdot
.44164 .30337 Mdot
.21065 .66969 Mdot
.47987 .64367 Mdot
.62729 .42242 Mdot
.44377 .35301 Mdot
.38337 .57157 Mdot
.64229 .36447 Mdot
.74355 .54675 Mdot
.59709 .38793 Mdot
.35867 .52978 Mdot
.74399 .42687 Mdot
.65782 .54419 Mdot
.39407 .50685 Mdot
.60449 .43005 Mdot
.71011 .44417 Mdot
.40371 .47848 Mdot
.38532 .54272 Mdot
.33731 .23718 Mdot
.19243 .56534 Mdot
.45303 .33385 Mdot
.5045 .64852 Mdot
.42171 .55298 Mdot
.47289 .34312 Mdot
.56978 .30928 Mdot
.39737 .48016 Mdot
.50916 .67126 Mdot
.41064 .44821 Mdot
.62304 .43317 Mdot
.65194 .58843 Mdot
.61403 .50234 Mdot
.47505 .33554 Mdot
.6861 .80304 Mdot
.60911 .36586 Mdot
.42416 .48699 Mdot
.39167 .56386 Mdot
.48021 .22346 Mdot
.45562 .67191 Mdot
.31565 .7443 Mdot
.36615 .49007 Mdot
.55336 .68986 Mdot
.38903 .49357 Mdot
.65152 .40336 Mdot
.49546 .66965 Mdot
.36293 .50924 Mdot
.68232 .64106 Mdot
.34798 .56076 Mdot
.46345 .3116 Mdot
.69321 .7242 Mdot
.33714 .52682 Mdot
.13594 .57107 Mdot
.50375 .31903 Mdot
.60849 .3817 Mdot
.7715 .42653 Mdot
.87569 .44017 Mdot
.63589 .72111 Mdot
.46373 .69434 Mdot
.73086 .32683 Mdot
.62608 .39409 Mdot
.74738 .39887 Mdot
.6199 .19622 Mdot
.3989 .54175 Mdot
.36216 .47277 Mdot
.42134 .25714 Mdot
.56782 .39528 Mdot
.56329 .37889 Mdot
.44341 .54122 Mdot
.33037 .52898 Mdot
.62188 .38552 Mdot
.43653 .52475 Mdot
.44235 .51396 Mdot
.68551 .55962 Mdot
.50385 .66582 Mdot
.64645 .59732 Mdot
.62655 .56307 Mdot
.6187 .78302 Mdot
.48962 .2895 Mdot
.65952 .59445 Mdot
.63144 .59123 Mdot
.29207 .40223 Mdot
.28514 .34377 Mdot
.43316 .34847 Mdot
.76219 .30867 Mdot
.61754 .41316 Mdot
.36567 .51736 Mdot
.48641 .64503 Mdot
.40753 .77992 Mdot
.62684 .30595 Mdot
.24496 .68671 Mdot
.34954 .49009 Mdot
.63121 .40756 Mdot
.64572 .4787 Mdot
.39088 .59593 Mdot
.57887 .43299 Mdot
.38824 .47945 Mdot
.58589 .3663 Mdot
.39641 .65701 Mdot
.75894 .59744 Mdot
.55442 .39519 Mdot
.51291 .72593 Mdot
.39509 .48705 Mdot
.49622 .6596 Mdot
.64007 .56961 Mdot
.44153 .35391 Mdot
.45046 .33534 Mdot
.37931 .53263 Mdot
.45622 .51251 Mdot
.52452 .31917 Mdot
.3925 .53079 Mdot
.42227 .53592 Mdot
.6637 .46331 Mdot
.42381 .53903 Mdot
.36504 .54962 Mdot
.35304 .53096 Mdot
.3591 .46834 Mdot
.66378 .54424 Mdot
.79427 .51348 Mdot
.31881 .50439 Mdot
.32284 .5202 Mdot
.64211 .5367 Mdot
.67869 .28282 Mdot
.62766 .57649 Mdot
.57459 .18748 Mdot
.6635 .60871 Mdot
.45556 .34234 Mdot
.53793 .21891 Mdot
.46302 .52164 Mdot
.5103 .70423 Mdot
.63413 .53154 Mdot
.46534 .34922 Mdot
.65182 .56809 Mdot
.63466 .3848 Mdot
.35066 .21198 Mdot
.45956 .62007 Mdot
.48506 .52543 Mdot
.62024 .53235 Mdot
.77227 .53087 Mdot
.60353 .3683 Mdot
.49156 .65647 Mdot
.4158 .73211 Mdot
.37416 .55725 Mdot
.4714 .34691 Mdot
.36902 .52947 Mdot
.64627 .5438 Mdot
.62874 .40528 Mdot
.74522 .69188 Mdot
.45147 .31555 Mdot
.27701 .28833 Mdot
.59465 .4086 Mdot
.35319 .5366 Mdot
.62552 .55948 Mdot
.21288 .36891 Mdot
.65065 .60072 Mdot
.27102 .69033 Mdot
.45596 .69317 Mdot
.71402 .75328 Mdot
.47174 .69546 Mdot
.75082 .55345 Mdot
.20287 .3286 Mdot
.80126 .51372 Mdot
.50086 .70579 Mdot
.58755 .60214 Mdot
.41301 .51639 Mdot
.41605 .5031 Mdot
.75719 .63896 Mdot
.50555 .65032 Mdot
.4067 .56161 Mdot
.69614 .37671 Mdot
.60913 .6166 Mdot
.22314 .41607 Mdot
.58605 .38585 Mdot
.37337 .49595 Mdot
.64739 .61674 Mdot
.67297 .60832 Mdot
.59008 .36741 Mdot
.64352 .60066 Mdot
.40041 .5156 Mdot
.47218 .68758 Mdot
.62477 .33214 Mdot
.44257 .33835 Mdot
.83714 .51009 Mdot
.47384 .35516 Mdot
.59512 .38935 Mdot
.41355 .57779 Mdot
.62303 .39083 Mdot
.88624 .4158 Mdot
.40389 .50975 Mdot
.49706 .69281 Mdot
.41894 .55068 Mdot
.39685 .49073 Mdot
.3538 .47551 Mdot
.63019 .38756 Mdot
.33572 .42477 Mdot
.43553 .53165 Mdot
.67225 .57082 Mdot
.26098 .60913 Mdot
.33736 .52254 Mdot
.60636 .34462 Mdot
.2851 .36441 Mdot
.61123 .58694 Mdot
.46008 .63992 Mdot
.60374 .38401 Mdot
.49315 .70542 Mdot
.53283 .73578 Mdot
.48623 .7053 Mdot
.29457 .67272 Mdot
.41404 .7189 Mdot
.25039 .51685 Mdot
.32096 .59938 Mdot
.55326 .58121 Mdot
.50502 .64931 Mdot
.47452 .37479 Mdot
.4933 .72202 Mdot
.46708 .64052 Mdot
.07452 .46313 Mdot
.51269 .70541 Mdot
.37256 .48563 Mdot
.34228 .52982 Mdot
.7733 .55347 Mdot
.34289 .36042 Mdot
.41217 .55033 Mdot
.40734 .55646 Mdot
.43153 .3382 Mdot
.54599 .69449 Mdot
.76936 .45942 Mdot
.18672 .5789 Mdot
.76079 .39182 Mdot
.37138 .52892 Mdot
.42381 .551 Mdot
.35916 .57958 Mdot
.16461 .465 Mdot
.62008 .79293 Mdot
.44537 .63726 Mdot
.36782 .58185 Mdot
.8106 .54788 Mdot
.35582 .47595 Mdot
.3844 .4715 Mdot
.41007 .51812 Mdot
.6266 .39473 Mdot
.47074 .63335 Mdot
.36837 .46201 Mdot
.43095 .25566 Mdot
.38147 .47489 Mdot
.69957 .45167 Mdot
.79496 .66902 Mdot
.3699 .4971 Mdot
.4571 .63382 Mdot
.4191 .5076 Mdot
.45779 .65789 Mdot
.47734 .65393 Mdot
.41646 .58544 Mdot
.25522 .62736 Mdot
.44989 .6575 Mdot
.39955 .5244 Mdot
.6364 .39648 Mdot
.73749 .27323 Mdot
.3579 .52804 Mdot
.43983 .35396 Mdot
.36471 .48728 Mdot
.42104 .3079 Mdot
.41969 .53931 Mdot
.60782 .36534 Mdot
.44184 .79071 Mdot
.62044 .40234 Mdot
.65393 .78983 Mdot
.63817 .37069 Mdot
.32263 .24164 Mdot
.50075 .65262 Mdot
.73872 .4369 Mdot
.36996 .79344 Mdot
.66797 .48287 Mdot
.48436 .41871 Mdot
.52702 .51335 Mdot
.63385 .58551 Mdot
.45791 .69401 Mdot
.53347 .6161 Mdot
.6492 .28813 Mdot
.58212 .24296 Mdot
.59705 .42248 Mdot
.4662 .84232 Mdot
.27535 .73581 Mdot
.43289 .50995 Mdot
.36845 .71346 Mdot
.32053 .65478 Mdot
.35753 .47339 Mdot
.37553 .46164 Mdot
.66832 .4396 Mdot
.43461 .54375 Mdot
.69496 .65377 Mdot
.59241 .39193 Mdot
.46635 .34949 Mdot
.49888 .68441 Mdot
.47605 .33223 Mdot
.63928 .27684 Mdot
.5232 .51172 Mdot
.63032 .37684 Mdot
.33283 .52362 Mdot
.40366 .55447 Mdot
.4617 .65253 Mdot
.4535 .72266 Mdot
.50195 .71661 Mdot
.4604 .32614 Mdot
.59276 .39746 Mdot
.48781 .80122 Mdot
.3986 .55725 Mdot
.48219 .67049 Mdot
.48599 .40696 Mdot
.42009 .55471 Mdot
.64434 .57371 Mdot
.41137 .51105 Mdot
.50307 .69994 Mdot
.42368 .53926 Mdot
.47069 .69602 Mdot
.60463 .39672 Mdot
.34227 .51808 Mdot
.37952 .54633 Mdot
.24046 .33253 Mdot
.46149 .34542 Mdot
.50819 .66284 Mdot
.60019 .46751 Mdot
.40252 .56843 Mdot
.73321 .46504 Mdot
.38394 .47922 Mdot
.48845 .76966 Mdot
.41677 .48514 Mdot
.6618 .48002 Mdot
.32424 .48219 Mdot
.35773 .52425 Mdot
.5085 .39965 Mdot
.31906 .66414 Mdot
.44029 .63211 Mdot
.62298 .57606 Mdot
.51688 .68833 Mdot
.22648 .41727 Mdot
.55163 .41869 Mdot
.58625 .43011 Mdot
.3794 .29698 Mdot
.35341 .47038 Mdot
.37547 .50672 Mdot
.61992 .58166 Mdot
.46197 .31531 Mdot
.4878 .66128 Mdot
.46081 .35132 Mdot
.26299 .32242 Mdot
.44961 .30712 Mdot
.64479 .41895 Mdot
.5386 .33396 Mdot
.50659 .80049 Mdot
.43065 .33541 Mdot
.50282 .70599 Mdot
.59692 .32625 Mdot
.34619 .47623 Mdot
.50711 .33095 Mdot
.44699 .34702 Mdot
.54026 .85375 Mdot
.36438 .54852 Mdot
.48018 .41701 Mdot
.65283 .59424 Mdot
.4366 .34626 Mdot
.63185 .5668 Mdot
.40025 .54958 Mdot
.76441 .45013 Mdot
.46531 .69753 Mdot
.63978 .54268 Mdot
.45535 .52662 Mdot
.46523 .33337 Mdot
.64547 .38254 Mdot
.61795 .5571 Mdot
.62309 .5654 Mdot
.68904 .27938 Mdot
.72655 .7178 Mdot
.59347 .40003 Mdot
.2203 .5196 Mdot
.66475 .61027 Mdot
.34229 .48467 Mdot
.54399 .66676 Mdot
.40604 .49425 Mdot
.61294 .75847 Mdot
.59838 .38244 Mdot
.78219 .53025 Mdot
.42348 .54831 Mdot
.34951 .5043 Mdot
.45481 .62689 Mdot
.61453 .40755 Mdot
.4813 .68773 Mdot
.51827 .6848 Mdot
.60472 .39829 Mdot
.47708 .70581 Mdot
.43275 .30523 Mdot
.60337 .64316 Mdot
.6797 .58492 Mdot
.6703 .56065 Mdot
.62194 .41401 Mdot
.60718 .37893 Mdot
.61828 .38867 Mdot
.41144 .51054 Mdot
.49206 .66391 Mdot
.40837 .53856 Mdot
.37533 .47263 Mdot
.25141 .59798 Mdot
.4739 .63688 Mdot
.41025 .52741 Mdot
.52716 .41536 Mdot
.49685 .32693 Mdot
.63811 .39497 Mdot
.65687 .59402 Mdot
.7144 .39618 Mdot
.73923 .55285 Mdot
.3755 .49275 Mdot
.46684 .2616 Mdot
.50113 .71215 Mdot
.45154 .31952 Mdot
.47516 .36225 Mdot
.45266 .32924 Mdot
.61701 .51864 Mdot
.50816 .65588 Mdot
.18824 .589 Mdot
.37323 .50021 Mdot
.50454 .52158 Mdot
.49985 .60407 Mdot
.51235 .30511 Mdot
.65938 .59267 Mdot
.41608 .55567 Mdot
.61039 .50493 Mdot
.4311 .75253 Mdot
.4053 .49628 Mdot
.33541 .51048 Mdot
.68298 .3279 Mdot
.3993 .44218 Mdot
.46438 .71587 Mdot
.21423 .37433 Mdot
.40445 .57323 Mdot
.55852 .75031 Mdot
.84524 .51482 Mdot
.38122 .48568 Mdot
.3526 .49272 Mdot
.38048 .55443 Mdot
.42794 .53039 Mdot
.45313 .64514 Mdot
.33871 .32643 Mdot
.6583 .61235 Mdot
.50127 .51612 Mdot
.67349 .54784 Mdot
.63603 .36421 Mdot
.78769 .52901 Mdot
.45906 .69937 Mdot
.44478 .31422 Mdot
.80934 .45869 Mdot
.1866 .47508 Mdot
.58202 .37814 Mdot
.57295 .79528 Mdot
.45343 .34762 Mdot
.33887 .49353 Mdot
.42651 .30775 Mdot
.64515 .3986 Mdot
.67464 .56466 Mdot
.33312 .49251 Mdot
.4909 .72132 Mdot
.50411 .67664 Mdot
.41382 .55981 Mdot
.81275 .53154 Mdot
.64424 .5786 Mdot
.62202 .55396 Mdot
.40039 .47915 Mdot
.38213 .57089 Mdot
.48121 .69231 Mdot
.59949 .41603 Mdot
.23925 .45793 Mdot
.46954 .32689 Mdot
.40897 .46176 Mdot
.42459 .53187 Mdot
.32519 .26045 Mdot
.67459 .57565 Mdot
.59481 .43912 Mdot
.41678 .48957 Mdot
.59182 .70197 Mdot
.41861 .49252 Mdot
.38332 .58905 Mdot
.6366 .39871 Mdot
.31565 .50038 Mdot
.43293 .50141 Mdot
.47328 .61612 Mdot
.63479 .58213 Mdot
.49259 .69513 Mdot
.50245 .64004 Mdot
.50453 .56945 Mdot
.64489 .57162 Mdot
.41415 .52275 Mdot
.66082 .58675 Mdot
.39773 .48108 Mdot
.42719 .55227 Mdot
.66049 .59608 Mdot
.48066 .68856 Mdot
.73027 .33057 Mdot
.79615 .50545 Mdot
.42946 .52831 Mdot
.43503 .56428 Mdot
.33828 .34185 Mdot
.34502 .42167 Mdot
.35518 .48022 Mdot
.50413 .69409 Mdot
.39253 .55392 Mdot
.635 .56144 Mdot
.42834 .31211 Mdot
.50054 .70108 Mdot
.58473 .40566 Mdot
.58921 .37279 Mdot
.63008 .71577 Mdot
.578 .41498 Mdot
.37015 .46798 Mdot
.50951 .74818 Mdot
.48234 .62674 Mdot
.82888 .53835 Mdot
.6056 .40156 Mdot
.42956 .34493 Mdot
.38441 .54093 Mdot
.41303 .23615 Mdot
.6511 .61955 Mdot
.1546 .63222 Mdot
.20488 .64161 Mdot
.46105 .29839 Mdot
.24577 .68066 Mdot
.62355 .36458 Mdot
.42997 .48839 Mdot
.44663 .35748 Mdot
.59318 .37393 Mdot
.42424 .50676 Mdot
.40812 .58904 Mdot
.3024 .73145 Mdot
.53103 .56394 Mdot
.66307 .58664 Mdot
.57306 .40165 Mdot
.46983 .30213 Mdot
.63304 .43346 Mdot
.49411 .65308 Mdot
.35918 .51879 Mdot
.4152 .57931 Mdot
.58932 .41219 Mdot
.57069 .41611 Mdot
.40468 .52445 Mdot
.46265 .70941 Mdot
.66083 .44881 Mdot
.37642 .52679 Mdot
.55849 .6054 Mdot
.52612 .68945 Mdot
.58737 .39127 Mdot
.35127 .51161 Mdot
.44365 .39503 Mdot
.59543 .41106 Mdot
.63902 .39371 Mdot
.42162 .55604 Mdot
.43589 .30366 Mdot
.42942 .56859 Mdot
.66797 .60412 Mdot
.51656 .83254 Mdot
.63507 .55852 Mdot
.6603 .34104 Mdot
.45645 .52399 Mdot
.5777 .66475 Mdot
.45611 .64982 Mdot
.3689 .26109 Mdot
.70032 .37989 Mdot
.44576 .53332 Mdot
.70672 .26214 Mdot
.6978 .54114 Mdot
.81671 .50663 Mdot
.49796 .19668 Mdot
.43584 .33726 Mdot
.6502 .56576 Mdot
.3529 .49143 Mdot
.68856 .56497 Mdot
.44803 .35912 Mdot
.65711 .78567 Mdot
.3518 .5213 Mdot
.49571 .6725 Mdot
.4046 .51941 Mdot
.49943 .66762 Mdot
.42388 .55353 Mdot
.34336 .56606 Mdot
.69036 .41922 Mdot
.26414 .45259 Mdot
.40973 .47937 Mdot
.3135 .22897 Mdot
.47232 .3878 Mdot
.47049 .34156 Mdot
.40191 .53891 Mdot
.56965 .42782 Mdot
.67673 .60893 Mdot
.7184 .66548 Mdot
.62704 .39366 Mdot
.62587 .57959 Mdot
.48048 .70221 Mdot
.6007 .38766 Mdot
.58391 .3733 Mdot
.31553 .49545 Mdot
.44222 .29799 Mdot
.65733 .54902 Mdot
.36156 .50838 Mdot
.35267 .52178 Mdot
.21294 .50841 Mdot
.62496 .29717 Mdot
.45619 .73035 Mdot
.16014 .52444 Mdot
.51848 .7085 Mdot
.4682 .33922 Mdot
.63137 .39358 Mdot
.36726 .47592 Mdot
.39292 .50982 Mdot
.72712 .44296 Mdot
.48281 .72577 Mdot
.55777 .53002 Mdot
.49096 .77605 Mdot
.59861 .46484 Mdot
.29095 .38077 Mdot
.5011 .68727 Mdot
.29092 .38306 Mdot
.48387 .34892 Mdot
.79646 .36227 Mdot
.27608 .42846 Mdot
.65314 .59241 Mdot
.29513 .37849 Mdot
.4803 .66527 Mdot
.43377 .5224 Mdot
.62936 .42164 Mdot
.5858 .42195 Mdot
.48781 .69105 Mdot
.61339 .44464 Mdot
.43233 .32281 Mdot
.35542 .497 Mdot
.18737 .56139 Mdot
.64484 .69397 Mdot
.61816 .41849 Mdot
.36692 .5867 Mdot
.64621 .5502 Mdot
.4136 .56057 Mdot
.42912 .32619 Mdot
.65647 .58028 Mdot
.3527 .2579 Mdot
.65257 .6325 Mdot
.38436 .53797 Mdot
.334 .24276 Mdot
.64932 .57305 Mdot
.38018 .4141 Mdot
.37002 .52262 Mdot
.65878 .6089 Mdot
.36346 .42645 Mdot
.7453 .52079 Mdot
.59319 .50821 Mdot
.62188 .19665 Mdot
.57832 .5068 Mdot
.62366 .42269 Mdot
.75954 .5275 Mdot
.66787 .50118 Mdot
.68515 .5848 Mdot
.58193 .43131 Mdot
.47356 .29339 Mdot
.63158 .56913 Mdot
.33766 .51161 Mdot
.3849 .48156 Mdot
.63407 .78947 Mdot
.67705 .51726 Mdot
.75317 .56552 Mdot
.6815 .70106 Mdot
.39841 .56819 Mdot
.42561 .57319 Mdot
.38853 .50986 Mdot
.4478 .66753 Mdot
.66872 .5812 Mdot
.26135 .2837 Mdot
.64203 .57309 Mdot
.213 .5969 Mdot
.62087 .41242 Mdot
.58739 .38242 Mdot
.37238 .49374 Mdot
.4626 .41795 Mdot
.31747 .31293 Mdot
.3992 .51785 Mdot
.43825 .27728 Mdot
.70202 .7191 Mdot
.38831 .57151 Mdot
.45197 .67526 Mdot
.34377 .57449 Mdot
.33904 .57998 Mdot
.67993 .58499 Mdot
.4385 .32554 Mdot
.36054 .26446 Mdot
.67267 .55809 Mdot
.37669 .50717 Mdot
.58647 .66671 Mdot
.39797 .49628 Mdot
.42873 .52178 Mdot
.21705 .64011 Mdot
.48122 .34473 Mdot
.61336 .39297 Mdot
.45491 .33083 Mdot
.45677 .65606 Mdot
.10024 .56374 Mdot
.45633 .30764 Mdot
.32202 .3039 Mdot
.61396 .80733 Mdot
.29744 .37966 Mdot
.49965 .66143 Mdot
.43706 .29664 Mdot
.64766 .58542 Mdot
.74657 .27839 Mdot
.35594 .77476 Mdot
.71652 .59612 Mdot
.3785 .52286 Mdot
.48351 .735 Mdot
.50822 .6908 Mdot
.64226 .53914 Mdot
.47901 .65508 Mdot
.39904 .43032 Mdot
.43187 .52311 Mdot
.68881 .57506 Mdot
.60123 .69199 Mdot
.62267 .57712 Mdot
.62235 .63506 Mdot
.39937 .53406 Mdot
.49993 .6934 Mdot
.42143 .46912 Mdot
.52654 .67987 Mdot
.6198 .43902 Mdot
.34663 .55387 Mdot
.43318 .32026 Mdot
.57856 .68742 Mdot
.59222 .40137 Mdot
.49 .277 Mdot
.46156 .65081 Mdot
.60221 .57665 Mdot
.46935 .64695 Mdot
.50436 .6458 Mdot
.62624 .5685 Mdot
.46783 .67433 Mdot
.35296 .49464 Mdot
.55781 .45754 Mdot
.45848 .67217 Mdot
.65745 .5575 Mdot
.44098 .32893 Mdot
.47509 .69791 Mdot
.54904 .3705 Mdot
.37804 .53939 Mdot
.62391 .38098 Mdot
.52731 .22099 Mdot
.49791 .73033 Mdot
.47848 .32725 Mdot
.58176 .4252 Mdot
.47187 .34892 Mdot
.81128 .60614 Mdot
.68671 .55169 Mdot
.23137 .62739 Mdot
.45808 .28904 Mdot
.50917 .7078 Mdot
.54409 .22083 Mdot
.37052 .47671 Mdot
.38088 .54061 Mdot
.41832 .31373 Mdot
.50823 .69149 Mdot
.82099 .42322 Mdot
.41143 .61357 Mdot
.60053 .62739 Mdot
.64691 .52812 Mdot
.32375 .23593 Mdot
.64758 .6412 Mdot
.84828 .58842 Mdot
.44875 .54037 Mdot
.56511 .37634 Mdot
.38078 .49672 Mdot
.70193 .39868 Mdot
.46358 .33428 Mdot
.64132 .34376 Mdot
.38461 .58099 Mdot
.60737 .39221 Mdot
.36945 .54335 Mdot
.51662 .41985 Mdot
.30841 .49205 Mdot
.43182 .34875 Mdot
.77148 .43603 Mdot
.51444 .69965 Mdot
.44449 .34152 Mdot
.61966 .36835 Mdot
.307 .3401 Mdot
.42756 .51267 Mdot
.38177 .44616 Mdot
.59827 .46467 Mdot
.49474 .66282 Mdot
.61725 .43019 Mdot
.67539 .59315 Mdot
.4439 .31777 Mdot
.40564 .55271 Mdot
.38913 .46731 Mdot
.72873 .46596 Mdot
.64584 .54855 Mdot
.567 .40687 Mdot
.64431 .59328 Mdot
.60986 .36233 Mdot
.42915 .55491 Mdot
.58248 .38529 Mdot
.39947 .45626 Mdot
.69028 .43195 Mdot
.21795 .62807 Mdot
.33512 .68409 Mdot
.59589 .38305 Mdot
.26829 .38875 Mdot
.64191 .55641 Mdot
.65076 .60262 Mdot
.54878 .8152 Mdot
.27291 .69575 Mdot
.19997 .50089 Mdot
.63712 .23731 Mdot
.67833 .5546 Mdot
.64984 .5515 Mdot
.62032 .3787 Mdot
.46672 .67181 Mdot
.52083 .69342 Mdot
.6033 .36259 Mdot
.38624 .37092 Mdot
.4877 .66144 Mdot
.73828 .28961 Mdot
.21151 .44863 Mdot
.37889 .45663 Mdot
.60797 .4497 Mdot
.44767 .32232 Mdot
.37566 .36342 Mdot
.51629 .41533 Mdot
.3488 .50068 Mdot
.39381 .2498 Mdot
.61291 .41675 Mdot
.46691 .43745 Mdot
.57703 .18996 Mdot
.35447 .53413 Mdot
.36583 .5191 Mdot
.38281 .50533 Mdot
.4606 .3011 Mdot
.32 .74085 Mdot
.35332 .50791 Mdot
.38701 .37345 Mdot
.40668 .56612 Mdot
.35748 .42442 Mdot
.45178 .3342 Mdot
.26753 .49799 Mdot
.65401 .28509 Mdot
.2139 .38523 Mdot
.30631 .48437 Mdot
.67429 .59648 Mdot
.42268 .26935 Mdot
.64326 .59687 Mdot
.30279 .67487 Mdot
.28241 .4239 Mdot
.50853 .72748 Mdot
.34961 .49666 Mdot
.59437 .38923 Mdot
.50795 .68807 Mdot
.74608 .49676 Mdot
.0815 .51195 Mdot
.67413 .59905 Mdot
.87782 .55389 Mdot
.66067 .60731 Mdot
.58442 .37215 Mdot
.48173 .69351 Mdot
.41253 .70951 Mdot
.50767 .54416 Mdot
.47446 .70016 Mdot
.77238 .37822 Mdot
.44369 .64928 Mdot
.28375 .37443 Mdot
.48242 .7304 Mdot
.65231 .55575 Mdot
.62075 .5178 Mdot
.4652 .50868 Mdot
.37003 .48135 Mdot
.52777 .50761 Mdot
.29883 .3332 Mdot
.36862 .47811 Mdot
.59306 .39421 Mdot
.23741 .63989 Mdot
.38239 .27132 Mdot
.47144 .67337 Mdot
.68344 .61568 Mdot
.36341 .52356 Mdot
.42187 .51594 Mdot
.42931 .51353 Mdot
.16529 .5889 Mdot
.79983 .366 Mdot
.43508 .53429 Mdot
.41016 .56901 Mdot
.60321 .39004 Mdot
.489 .33039 Mdot
.70205 .35507 Mdot
.24387 .56248 Mdot
.34287 .50703 Mdot
.44908 .34154 Mdot
.48385 .3286 Mdot
.42238 .49827 Mdot
.50905 .33085 Mdot
.58502 .65882 Mdot
.36082 .50939 Mdot
.24322 .64256 Mdot
.56361 .45036 Mdot
.56787 .39474 Mdot
.58805 .40923 Mdot
.50271 .65979 Mdot
.57712 .40265 Mdot
.62153 .36584 Mdot
.42616 .72069 Mdot
.56662 .51228 Mdot
.68727 .61675 Mdot
.45994 .32455 Mdot
.39504 .50635 Mdot
.43889 .62981 Mdot
.58814 .6902 Mdot
.62981 .57372 Mdot
.49476 .71562 Mdot
.67252 .61237 Mdot
.41819 .34909 Mdot
.4845 .55429 Mdot
.60739 .42202 Mdot
.67961 .55992 Mdot
.63694 .62611 Mdot
.44866 .33958 Mdot
.63691 .5504 Mdot
.62792 .61573 Mdot
.34447 .54581 Mdot
.37147 .72924 Mdot
.39716 .52261 Mdot
.81702 .46694 Mdot
.65407 .54541 Mdot
.67337 .46705 Mdot
.3697 .50876 Mdot
.59728 .41045 Mdot
.46765 .52954 Mdot
.37785 .47513 Mdot
.583 .4094 Mdot
.43323 .51132 Mdot
.47434 .35264 Mdot
.52413 .67401 Mdot
.50124 .53107 Mdot
.43349 .85016 Mdot
.44138 .29775 Mdot
.74575 .48883 Mdot
.35212 .48383 Mdot
.76573 .67536 Mdot
.47442 .69445 Mdot
.41153 .46865 Mdot
.36662 .28287 Mdot
.46092 .67525 Mdot
.49136 .71034 Mdot
.41843 .51954 Mdot
.64993 .59323 Mdot
.58963 .39838 Mdot
.44858 .33544 Mdot
.84096 .57005 Mdot
.38449 .52841 Mdot
.38456 .54974 Mdot
.44904 .34574 Mdot
.64122 .55328 Mdot
.41402 .4872 Mdot
.48944 .21642 Mdot
.83173 .42056 Mdot
.64771 .60391 Mdot
.33854 .51026 Mdot
.32184 .71328 Mdot
.3644 .59645 Mdot
.69404 .78563 Mdot
.50293 .31764 Mdot
.60994 .38764 Mdot
.43012 .45531 Mdot
.11788 .54659 Mdot
.44013 .32524 Mdot
.18947 .48232 Mdot
.42359 .52118 Mdot
.39808 .55879 Mdot
.50146 .71624 Mdot
.40795 .53414 Mdot
.4678 .71221 Mdot
.42139 .8376 Mdot
.32082 .26162 Mdot
.49182 .65509 Mdot
.50927 .71255 Mdot
.34302 .29012 Mdot
.70351 .36805 Mdot
.48702 .69398 Mdot
.42425 .55774 Mdot
.28355 .51431 Mdot
.45577 .59117 Mdot
.42442 .30731 Mdot
.60486 .24874 Mdot
.4345 .61896 Mdot
.41369 .30325 Mdot
.70179 .29377 Mdot
.43078 .62749 Mdot
.57928 .57802 Mdot
.67112 .59581 Mdot
.35281 .53245 Mdot
.58236 .41996 Mdot
.57452 .41265 Mdot
.43746 .49248 Mdot
.40001 .50371 Mdot
.45829 .65365 Mdot
.45421 .3138 Mdot
.67847 .59774 Mdot
.4048 .55636 Mdot
.36102 .27471 Mdot
.46203 .31349 Mdot
.47104 .6588 Mdot
.24149 .60366 Mdot
.44718 .36295 Mdot
.33443 .55369 Mdot
.36393 .49752 Mdot
.40851 .51955 Mdot
.45009 .60092 Mdot
.66964 .58691 Mdot
.57997 .2282 Mdot
.35765 .55143 Mdot
.25921 .32605 Mdot
.69872 .55835 Mdot
.32584 .50184 Mdot
.48206 .6513 Mdot
.67247 .62677 Mdot
.64999 .39377 Mdot
.49949 .57651 Mdot
.38566 .53646 Mdot
.80193 .50171 Mdot
.65422 .77512 Mdot
.61964 .43742 Mdot
.50618 .64871 Mdot
.45292 .32356 Mdot
.39919 .51559 Mdot
.26112 .63308 Mdot
.38144 .48229 Mdot
.42286 .34552 Mdot
.63993 .39879 Mdot
.66918 .59784 Mdot
.81849 .49476 Mdot
.57422 .4086 Mdot
.49275 .70653 Mdot
.45524 .14476 Mdot
.46462 .7089 Mdot
.52001 .68475 Mdot
.25704 .60589 Mdot
.66879 .59007 Mdot
.12663 .58038 Mdot
.46583 .82643 Mdot
.36724 .56848 Mdot
.64018 .55948 Mdot
.49081 .68462 Mdot
.39917 .56312 Mdot
.49562 .74163 Mdot
.5038 .65153 Mdot
.4245 .56096 Mdot
.37692 .55472 Mdot
.76733 .58118 Mdot
.61503 .2003 Mdot
.45432 .32346 Mdot
.46337 .64139 Mdot
.5525 .60422 Mdot
.39406 .56375 Mdot
.37258 .50089 Mdot
.68548 .50946 Mdot
.42948 .30744 Mdot
.68881 .6653 Mdot
.42269 .51821 Mdot
.34076 .2501 Mdot
.31849 .5271 Mdot
.45073 .65786 Mdot
.63812 .59341 Mdot
.21897 .37875 Mdot
.62731 .52544 Mdot
.47044 .71436 Mdot
.4473 .31108 Mdot
.46862 .62114 Mdot
.3195 .30405 Mdot
.65487 .54026 Mdot
.5031 .69991 Mdot
.61461 .50289 Mdot
.66387 .57506 Mdot
.66841 .54986 Mdot
.26038 .59858 Mdot
.58208 .43444 Mdot
.46577 .30369 Mdot
.65395 .5488 Mdot
.55618 .66748 Mdot
.65635 .56164 Mdot
.4931 .81553 Mdot
.34201 .51891 Mdot
.38767 .32922 Mdot
.65674 .34366 Mdot
.45073 .47709 Mdot
.65812 .54371 Mdot
.43041 .33729 Mdot
.42106 .50293 Mdot
.47953 .66238 Mdot
.47373 .33597 Mdot
.71518 .61646 Mdot
.62359 .38731 Mdot
.46716 .64975 Mdot
.62504 .53183 Mdot
.50209 .67262 Mdot
.53113 .61317 Mdot
.58129 .82341 Mdot
.41118 .21195 Mdot
.51393 .5591 Mdot
.42869 .51581 Mdot
.65411 .26067 Mdot
.36057 .45826 Mdot
.40369 .50222 Mdot
.5891 .39167 Mdot
.38371 .30352 Mdot
.48124 .68846 Mdot
.82474 .4487 Mdot
.68061 .57623 Mdot
.21909 .36814 Mdot
.29714 .52612 Mdot
.42682 .49303 Mdot
.45807 .67629 Mdot
.46826 .71663 Mdot
.30467 .64892 Mdot
.6515 .3869 Mdot
.37986 .46181 Mdot
.34568 .47359 Mdot
.44112 .51478 Mdot
.6774 .56842 Mdot
.48358 .27363 Mdot
.62274 .42219 Mdot
.64793 .80249 Mdot
.63859 .40514 Mdot
.42376 .27803 Mdot
.46968 .67064 Mdot
.45551 .30756 Mdot
.3708 .50153 Mdot
.44292 .68807 Mdot
.48111 .72534 Mdot
.42055 .33162 Mdot
.44083 .35103 Mdot
.71841 .51195 Mdot
.66093 .5953 Mdot
.39451 .47005 Mdot
.35154 .50968 Mdot
.41076 .54044 Mdot
.40943 .50997 Mdot
.67917 .59047 Mdot
.4147 .49483 Mdot
.63184 .60223 Mdot
.52738 .63564 Mdot
.42489 .25139 Mdot
.57776 .5018 Mdot
.60031 .77276 Mdot
.47537 .66866 Mdot
.56141 .66171 Mdot
.42711 .60382 Mdot
.22436 .67511 Mdot
.72095 .70399 Mdot
.35847 .55668 Mdot
.5874 .37597 Mdot
.4026 .42123 Mdot
.59823 .42409 Mdot
.84709 .62265 Mdot
.7127 .46568 Mdot
.65619 .2237 Mdot
.35371 .52356 Mdot
.57776 .46762 Mdot
.54991 .72033 Mdot
.36705 .45293 Mdot
.71997 .48448 Mdot
.60555 .76358 Mdot
.78204 .45499 Mdot
.42801 .32124 Mdot
.37422 .53344 Mdot
.44043 .62925 Mdot
.35369 .49701 Mdot
.37686 .49696 Mdot
.42311 .50352 Mdot
.62984 .59181 Mdot
.39199 .46244 Mdot
.40997 .49506 Mdot
.52865 .31838 Mdot
.28151 .40368 Mdot
.57438 .41756 Mdot
.57787 .80986 Mdot
.45752 .30768 Mdot
.45813 .66123 Mdot
.77675 .35175 Mdot
.65396 .59242 Mdot
.30906 .64894 Mdot
.4092 .51418 Mdot
.77902 .55112 Mdot
.6641 .62664 Mdot
.44037 .31648 Mdot
.6453 .40168 Mdot
.69824 .2441 Mdot
.59722 .39474 Mdot
.62236 .50527 Mdot
.59873 .40887 Mdot
.43031 .60635 Mdot
.45876 .65158 Mdot
.40404 .47677 Mdot
.66061 .55144 Mdot
.57989 .39906 Mdot
.34378 .34891 Mdot
.38802 .50776 Mdot
.60567 .39847 Mdot
.40353 .47658 Mdot
.48593 .53102 Mdot
.22958 .51912 Mdot
.61563 .36581 Mdot
.66809 .62435 Mdot
.66896 .56752 Mdot
.43771 .30347 Mdot
.46183 .65814 Mdot
.48711 .71992 Mdot
.65666 .5785 Mdot
.3072 .74344 Mdot
.34386 .49768 Mdot
.38746 .56151 Mdot
.2321 .35603 Mdot
.35683 .48354 Mdot
.29559 .35549 Mdot
.60421 .50465 Mdot
.47463 .66161 Mdot
.43681 .5117 Mdot
.4217 .52584 Mdot
.38358 .53887 Mdot
.51315 .60943 Mdot
.59966 .41702 Mdot
.34928 .52972 Mdot
.44639 .35414 Mdot
.52726 .37735 Mdot
.41389 .56065 Mdot
.32854 .46128 Mdot
.4897 .71972 Mdot
.16473 .53421 Mdot
.6618 .60596 Mdot
.61277 .36807 Mdot
.59644 .3812 Mdot
.62113 .25841 Mdot
.57545 .72876 Mdot
.60283 .50303 Mdot
.68005 .78339 Mdot
.68989 .41909 Mdot
.46452 .34641 Mdot
.64213 .43664 Mdot
.62575 .51267 Mdot
.61245 .37305 Mdot
.67506 .59869 Mdot
.34319 .52411 Mdot
.34243 .50949 Mdot
.21885 .68894 Mdot
.42532 .50117 Mdot
.45022 .32548 Mdot
.62058 .56578 Mdot
.48047 .66616 Mdot
.44221 .31582 Mdot
.64243 .59223 Mdot
.49163 .65754 Mdot
.35063 .5458 Mdot
.3496 .54249 Mdot
.49253 .71641 Mdot
.50601 .69957 Mdot
.36487 .50144 Mdot
.6746 .34115 Mdot
.51119 .702 Mdot
.50261 .69094 Mdot
.61265 .42187 Mdot
.58376 .41943 Mdot
.32148 .48916 Mdot
.64253 .56116 Mdot
.41136 .49513 Mdot
.59873 .38857 Mdot
.44941 .30747 Mdot
.47945 .68524 Mdot
.42859 .52787 Mdot
.41657 .55348 Mdot
.44686 .33818 Mdot
.43685 .30968 Mdot
.43174 .33511 Mdot
.62321 .58336 Mdot
.4042 .54384 Mdot
.48345 .69955 Mdot
.66341 .59665 Mdot
.48161 .32291 Mdot
.4233 .31633 Mdot
.64942 .42196 Mdot
.36383 .47584 Mdot
.58488 .33617 Mdot
.10817 .5113 Mdot
.2631 .34047 Mdot
.63607 .42548 Mdot
.64712 .41019 Mdot
.31156 .38322 Mdot
.47947 .44153 Mdot
.64752 .57775 Mdot
.48644 .36315 Mdot
.35763 .26412 Mdot
.33722 .52808 Mdot
.40161 .57243 Mdot
.35876 .57633 Mdot
.43638 .34317 Mdot
.39266 .28455 Mdot
.45802 .69638 Mdot
.39933 .62665 Mdot
.46901 .32036 Mdot
.57052 .41545 Mdot
.63251 .43916 Mdot
.64006 .40237 Mdot
.34514 .5311 Mdot
.34357 .68604 Mdot
.56838 .69614 Mdot
.59942 .21835 Mdot
.65045 .54436 Mdot
.43991 .62571 Mdot
.76494 .6714 Mdot
.49106 .71418 Mdot
.64066 .36588 Mdot
.46297 .35047 Mdot
.50596 .69385 Mdot
.67496 .61403 Mdot
.65258 .55075 Mdot
.62057 .41778 Mdot
.62573 .41188 Mdot
.63167 .38189 Mdot
.51181 .65724 Mdot
.4685 .67224 Mdot
.38856 .53666 Mdot
.4772 .6805 Mdot
.19944 .64294 Mdot
.42291 .29978 Mdot
.59134 .34945 Mdot
.64752 .56558 Mdot
.49592 .6599 Mdot
.38987 .51061 Mdot
.48018 .45702 Mdot
.65495 .72405 Mdot
.46662 .35279 Mdot
.21933 .51124 Mdot
.83807 .63232 Mdot
.39184 .46884 Mdot
.67248 .57964 Mdot
.18731 .55401 Mdot
.3833 .50828 Mdot
.63324 .39805 Mdot
.69228 .33951 Mdot
.5891 .45707 Mdot
.38121 .47401 Mdot
.33401 .52214 Mdot
.65409 .60943 Mdot
.67163 .78176 Mdot
.3883 .5325 Mdot
.6679 .66895 Mdot
.69284 .57121 Mdot
.6281 .41914 Mdot
.81436 .35371 Mdot
.50161 .23038 Mdot
.38174 .36437 Mdot
.62055 .42066 Mdot
.39604 .48931 Mdot
.59803 .42173 Mdot
.46017 .35585 Mdot
.63863 .37584 Mdot
.45831 .7001 Mdot
.61925 .4352 Mdot
.38411 .55016 Mdot
.48887 .69322 Mdot
.64816 .57295 Mdot
.2016 .41907 Mdot
.59228 .31708 Mdot
.59918 .41153 Mdot
.60262 .3661 Mdot
.43536 .51099 Mdot
.70471 .64979 Mdot
.42984 .47364 Mdot
.36253 .54607 Mdot
.67434 .5495 Mdot
.46004 .66994 Mdot
.63437 .59199 Mdot
.35326 .45137 Mdot
.48221 .21093 Mdot
.64692 .59573 Mdot
.79526 .49712 Mdot
.45549 .34788 Mdot
.52393 .45088 Mdot
.39466 .51007 Mdot
.63233 .55808 Mdot
.40273 .54256 Mdot
.45531 .68514 Mdot
.56557 .47651 Mdot
.77086 .45598 Mdot
.66936 .55661 Mdot
.80776 .49765 Mdot
.4089 .28681 Mdot
.35412 .44166 Mdot
.64789 .6015 Mdot
.37364 .28099 Mdot
.58323 .37338 Mdot
.47056 .32789 Mdot
.46274 .36197 Mdot
.47569 .33422 Mdot
.44739 .51077 Mdot
.29977 .49647 Mdot
.48174 .34108 Mdot
.68038 .60565 Mdot
.43281 .34973 Mdot
.54241 .76615 Mdot
.81817 .43964 Mdot
.46242 .33701 Mdot
.37323 .52344 Mdot
.36459 .59038 Mdot
.29296 .39918 Mdot
.74369 .52779 Mdot
.67546 .2364 Mdot
.71613 .68078 Mdot
.3724 .48139 Mdot
.52459 .68549 Mdot
.48319 .6431 Mdot
.18303 .52563 Mdot
.28454 .34975 Mdot
.28986 .29915 Mdot
.51458 .70638 Mdot
.74167 .43251 Mdot
.46946 .65589 Mdot
.42818 .50796 Mdot
.39251 .56233 Mdot
.51319 .71235 Mdot
.42343 .24637 Mdot
.75239 .4589 Mdot
.8298 .52794 Mdot
.5036 .68076 Mdot
.6351 .58354 Mdot
.63599 .54044 Mdot
.66763 .54841 Mdot
.20631 .4657 Mdot
.4622 .69294 Mdot
.41378 .54657 Mdot
.59453 .38377 Mdot
.34632 .52075 Mdot
.66454 .57985 Mdot
.82566 .44335 Mdot
.46884 .69635 Mdot
.35791 .52002 Mdot
.44525 .44285 Mdot
.62764 .40068 Mdot
.45444 .34374 Mdot
.48179 .51383 Mdot
.28789 .30488 Mdot
.67963 .5667 Mdot
.50226 .7275 Mdot
.68895 .45606 Mdot
.80331 .45238 Mdot
.44768 .55154 Mdot
.347 .46964 Mdot
.84182 .5827 Mdot
.34285 .25988 Mdot
.36421 .46965 Mdot
.60122 .36882 Mdot
.72249 .44342 Mdot
.42227 .54846 Mdot
.47451 .63922 Mdot
.45453 .36429 Mdot
.47201 .34741 Mdot
.32334 .47918 Mdot
.50358 .50934 Mdot
.56557 .46638 Mdot
.41457 .52088 Mdot
.33744 .55866 Mdot
.62647 .41937 Mdot
.69379 .39992 Mdot
.2641 .32017 Mdot
.44415 .31016 Mdot
.40623 .47912 Mdot
.73931 .35309 Mdot
.49605 .72311 Mdot
.62587 .43359 Mdot
.64451 .54273 Mdot
.49245 .59849 Mdot
.64607 .39838 Mdot
.42822 .54316 Mdot
.41861 .49353 Mdot
.62697 .56029 Mdot
.45013 .66076 Mdot
.43957 .34605 Mdot
.58868 .38373 Mdot
.43322 .31396 Mdot
.4611 .67943 Mdot
.47285 .68063 Mdot
.42387 .43129 Mdot
.442 .57507 Mdot
.58621 .40648 Mdot
.4012 .45619 Mdot
.55386 .43669 Mdot
.73581 .74529 Mdot
.63443 .53157 Mdot
.38055 .46703 Mdot
.45045 .69339 Mdot
.67397 .56135 Mdot
.38995 .55912 Mdot
.85005 .56027 Mdot
.39775 .56515 Mdot
.6975 .55973 Mdot
.39779 .20804 Mdot
.43035 .32461 Mdot
.39535 .62269 Mdot
.76097 .6233 Mdot
.35768 .48639 Mdot
.60492 .37718 Mdot
.37625 .59003 Mdot
.64687 .58857 Mdot
.47093 .67267 Mdot
.71105 .77748 Mdot
.65944 .56128 Mdot
.35633 .50176 Mdot
.4433 .31709 Mdot
.47825 .72682 Mdot
.46949 .2817 Mdot
.5085 .32806 Mdot
.32223 .46132 Mdot
.40866 .46114 Mdot
.41441 .50882 Mdot
.52555 .20842 Mdot
.61619 .36896 Mdot
.4967 .68236 Mdot
.67386 .5784 Mdot
.65423 .57988 Mdot
.61489 .41782 Mdot
.66412 .63449 Mdot
.52577 .4531 Mdot
.13383 .46094 Mdot
.58406 .41326 Mdot
.47361 .32112 Mdot
.68836 .66055 Mdot
.59456 .37671 Mdot
.60864 .40168 Mdot
.61266 .42309 Mdot
.59452 .54688 Mdot
.49228 .66078 Mdot
.42698 .54682 Mdot
.4593 .64087 Mdot
.39835 .48963 Mdot
.69912 .56376 Mdot
.66511 .55237 Mdot
.46652 .68923 Mdot
.82826 .59203 Mdot
.36932 .74643 Mdot
.37781 .51404 Mdot
.76628 .67283 Mdot
.40143 .58284 Mdot
.31252 .36206 Mdot
.40117 .58631 Mdot
.61132 .41348 Mdot
.41074 .45134 Mdot
.44196 .51423 Mdot
.17913 .49404 Mdot
.64507 .56589 Mdot
.5695 .38938 Mdot
.3617 .56984 Mdot
.33669 .56109 Mdot
.51663 .66479 Mdot
.50516 .69204 Mdot
.46877 .3571 Mdot
.26022 .46237 Mdot
.64564 .57306 Mdot
.45996 .81491 Mdot
.36828 .48406 Mdot
.45737 .24853 Mdot
.31417 .5963 Mdot
.38577 .55779 Mdot
.77033 .6229 Mdot
.33506 .67654 Mdot
.3979 .51384 Mdot
.54743 .56504 Mdot
.64306 .5534 Mdot
.46589 .2097 Mdot
.41237 .56483 Mdot
.62901 .39543 Mdot
.46774 .66602 Mdot
.46495 .71502 Mdot
.47781 .34916 Mdot
.26115 .72313 Mdot
.62974 .5856 Mdot
.46765 .68033 Mdot
.38823 .50172 Mdot
.67252 .58529 Mdot
.57618 .40498 Mdot
.4227 .48665 Mdot
.27647 .36061 Mdot
.47974 .67412 Mdot
.43919 .53164 Mdot
.64158 .66855 Mdot
.3374 .38894 Mdot
.45199 .17015 Mdot
.67523 .57754 Mdot
.43356 .3067 Mdot
.36195 .58215 Mdot
.29119 .72227 Mdot
.42667 .57476 Mdot
.39441 .34409 Mdot
.54747 .76762 Mdot
.42936 .31028 Mdot
.36971 .51318 Mdot
.40835 .55171 Mdot
.47448 .40494 Mdot
.4483 .30949 Mdot
.35107 .51775 Mdot
.53183 .66429 Mdot
.49587 .66699 Mdot
.62397 .3619 Mdot
.48414 .66493 Mdot
.37796 .52232 Mdot
.4378 .58115 Mdot
.50375 .71154 Mdot
.76779 .69738 Mdot
.44154 .28934 Mdot
.65922 .60442 Mdot
.40515 .57738 Mdot
.36703 .55808 Mdot
.26564 .26363 Mdot
.60907 .44079 Mdot
.71349 .36781 Mdot
.51337 .26977 Mdot
.71527 .3181 Mdot
.49919 .22988 Mdot
.55814 .16886 Mdot
.34729 .25337 Mdot
.397 .46231 Mdot
.32898 .58202 Mdot
.56791 .63422 Mdot
.65049 .54273 Mdot
.4812 .78904 Mdot
.3702 .48093 Mdot
.37887 .49596 Mdot
.6338 .42965 Mdot
.78786 .51003 Mdot
.28859 .29925 Mdot
.48645 .46428 Mdot
.44008 .34537 Mdot
.46524 .64086 Mdot
.42643 .55108 Mdot
.55639 .54459 Mdot
.57599 .42059 Mdot
.44862 .24659 Mdot
.35954 .51929 Mdot
.2205 .65351 Mdot
.63169 .73008 Mdot
.66529 .59058 Mdot
.59801 .3795 Mdot
.3075 .2843 Mdot
.36771 .47483 Mdot
.64136 .54324 Mdot
.38793 .52531 Mdot
.67754 .40721 Mdot
.3596 .44833 Mdot
.46646 .33401 Mdot
.42466 .51915 Mdot
.41782 .27836 Mdot
.40318 .14568 Mdot
.46838 .37232 Mdot
.49284 .73997 Mdot
.57635 .35881 Mdot
.59486 .41527 Mdot
.50505 .6985 Mdot
.5922 .41256 Mdot
.30321 .62899 Mdot
.40569 .67556 Mdot
.45046 .34893 Mdot
.3248 .53533 Mdot
.45897 .3354 Mdot
.62209 .43734 Mdot
.37511 .47786 Mdot
.78603 .6971 Mdot
.58347 .39807 Mdot
.35997 .22318 Mdot
.65637 .56464 Mdot
.57146 .41699 Mdot
.40791 .56568 Mdot
.67996 .4679 Mdot
.57383 .40898 Mdot
.77059 .47045 Mdot
.38432 .53867 Mdot
.47609 .67295 Mdot
.42098 .54771 Mdot
.37977 .57302 Mdot
.56106 .38577 Mdot
.40039 .48532 Mdot
.64183 .59124 Mdot
.51705 .68746 Mdot
.74187 .28299 Mdot
.58356 .77107 Mdot
.34956 .50346 Mdot
.38662 .50326 Mdot
.48267 .6289 Mdot
.35291 .53949 Mdot
.67887 .59081 Mdot
.31838 .83663 Mdot
.45552 .3476 Mdot
.57292 .37448 Mdot
.49863 .22848 Mdot
.35274 .55085 Mdot
.41846 .4994 Mdot
.855 .53818 Mdot
.46817 .21933 Mdot
.64557 .59827 Mdot
.44388 .52579 Mdot
.57493 .40512 Mdot
.44606 .3186 Mdot
.68349 .59586 Mdot
.40788 .5209 Mdot
.37047 .50514 Mdot
.43931 .30441 Mdot
.28125 .48891 Mdot
.22075 .42018 Mdot
.63068 .55528 Mdot
.43836 .47037 Mdot
.55295 .36987 Mdot
.34847 .48332 Mdot
.20371 .48766 Mdot
.50169 .69891 Mdot
.68016 .56453 Mdot
.66369 .27701 Mdot
.37331 .47022 Mdot
.63346 .5861 Mdot
.64496 .57173 Mdot
.44274 .53698 Mdot
.45057 .69671 Mdot
.51194 .6673 Mdot
.50131 .6687 Mdot
.22622 .71567 Mdot
.36569 .35768 Mdot
.63177 .38205 Mdot
.64265 .55309 Mdot
.61475 .36435 Mdot
.41359 .31848 Mdot
.59536 .51312 Mdot
.60911 .3653 Mdot
.50426 .66638 Mdot
.58885 .35371 Mdot
.39746 .54919 Mdot
.64817 .57461 Mdot
.61725 .37426 Mdot
.3603 .56401 Mdot
.70324 .64302 Mdot
.74434 .59091 Mdot
.4245 .32904 Mdot
.46241 .36398 Mdot
.40488 .56198 Mdot
.6507 .37856 Mdot
.36662 .50012 Mdot
.6772 .54865 Mdot
.69325 .65257 Mdot
.40694 .5762 Mdot
.60019 .41297 Mdot
.47825 .62336 Mdot
.29617 .29675 Mdot
.42215 .463 Mdot
.37274 .5222 Mdot
.39701 .48591 Mdot
.38836 .52568 Mdot
.78751 .43662 Mdot
.65641 .53036 Mdot
.59928 .772 Mdot
.55946 .22227 Mdot
.47321 .70325 Mdot
.46757 .63148 Mdot
.25426 .3479 Mdot
.5847 .64765 Mdot
.64233 .55944 Mdot
.40577 .50489 Mdot
.59466 .71377 Mdot
.82949 .41844 Mdot
.83427 .61571 Mdot
.46036 .39878 Mdot
.58919 .4358 Mdot
.50765 .72115 Mdot
.57844 .38639 Mdot
.39024 .48524 Mdot
.3529 .57433 Mdot
.53467 .15597 Mdot
.68757 .59642 Mdot
.45429 .3506 Mdot
.40149 .4911 Mdot
.36807 .36199 Mdot
.60228 .38849 Mdot
.5605 .40052 Mdot
.35512 .53711 Mdot
.45163 .64434 Mdot
.34925 .19474 Mdot
.67016 .58562 Mdot
.71673 .67573 Mdot
.54819 .72797 Mdot
.68659 .70269 Mdot
.66627 .58174 Mdot
.4881 .37734 Mdot
.63312 .42718 Mdot
.27293 .56479 Mdot
.47443 .70772 Mdot
.47298 .33775 Mdot
.32671 .49817 Mdot
.495 .72027 Mdot
.63407 .41565 Mdot
.47308 .67305 Mdot
.42401 .50556 Mdot
.68917 .55635 Mdot
.61039 .38584 Mdot
.68823 .616 Mdot
.44705 .66871 Mdot
.44532 .31156 Mdot
.50502 .47027 Mdot
.43603 .76588 Mdot
.33109 .67184 Mdot
.34766 .52879 Mdot
.55997 .54884 Mdot
.41356 .54451 Mdot
.48913 .64031 Mdot
.38905 .51483 Mdot
.49432 .76351 Mdot
.60474 .37815 Mdot
.41055 .56855 Mdot
.41415 .51678 Mdot
.52784 .80254 Mdot
.36154 .52948 Mdot
.39464 .45659 Mdot
.40076 .51314 Mdot
.48129 .74865 Mdot
.32376 .53667 Mdot
.48229 .65004 Mdot
.52929 .34892 Mdot
.61113 .40357 Mdot
.44767 .36116 Mdot
.44532 .29953 Mdot
.38215 .32391 Mdot
.62148 .27674 Mdot
.78077 .5316 Mdot
.48735 .66891 Mdot
.63908 .58024 Mdot
.39002 .51951 Mdot
.57179 .19128 Mdot
.56548 .45361 Mdot
.58702 .42889 Mdot
.58633 .77014 Mdot
.44426 .4733 Mdot
.48118 .19544 Mdot
.43692 .50491 Mdot
.23502 .713 Mdot
.45415 .55826 Mdot
.3637 .44792 Mdot
.58746 .36621 Mdot
.41132 .32385 Mdot
.36244 .55015 Mdot
.51939 .67324 Mdot
.46741 .32666 Mdot
.3102 .55718 Mdot
.55355 .35337 Mdot
.53422 .3512 Mdot
.46344 .76428 Mdot
.39682 .53881 Mdot
.61173 .38665 Mdot
.46602 .64955 Mdot
.27052 .31358 Mdot
.66379 .59753 Mdot
.70253 .60091 Mdot
.55666 .61399 Mdot
.77703 .67192 Mdot
.46187 .31289 Mdot
.26043 .55936 Mdot
.38706 .55128 Mdot
.64424 .32455 Mdot
.41295 .57477 Mdot
.82596 .43811 Mdot
.46322 .30905 Mdot
.50862 .67013 Mdot
.63433 .57996 Mdot
.46987 .63747 Mdot
.3248 .67448 Mdot
.604 .45028 Mdot
.55323 .49911 Mdot
.59947 .39641 Mdot
.51661 .40729 Mdot
.49272 .68877 Mdot
.404 .47883 Mdot
.13205 .46117 Mdot
.50258 .69393 Mdot
.4856 .72957 Mdot
.62446 .80529 Mdot
.75782 .72874 Mdot
.41499 .45016 Mdot
.51067 .70814 Mdot
.60079 .40109 Mdot
.455 .32094 Mdot
.42625 .53766 Mdot
.39428 .54288 Mdot
.4951 .7192 Mdot
.56313 .38479 Mdot
.29955 .70268 Mdot
.62285 .41264 Mdot
.49463 .66136 Mdot
.62045 .40181 Mdot
.67611 .46186 Mdot
.5975 .37201 Mdot
.36509 .5565 Mdot
.38941 .51606 Mdot
.5735 .25323 Mdot
.47332 .67987 Mdot
.41485 .52309 Mdot
.43326 .50715 Mdot
.48418 .69657 Mdot
.50503 .34267 Mdot
.30068 .69664 Mdot
.34926 .49118 Mdot
.37394 .53667 Mdot
.43046 .30981 Mdot
.5804 .54067 Mdot
.23857 .53535 Mdot
.42114 .50378 Mdot
.4583 .30056 Mdot
.51848 .67278 Mdot
.36107 .50722 Mdot
.79798 .37742 Mdot
.72473 .44269 Mdot
.38325 .47084 Mdot
.5828 .37417 Mdot
.44132 .51345 Mdot
.43704 .17314 Mdot
.36306 .54707 Mdot
.48653 .68694 Mdot
.46374 .67392 Mdot
.46723 .81722 Mdot
.49387 .70366 Mdot
.58547 .42164 Mdot
.66408 .57724 Mdot
.81664 .47386 Mdot
.57609 .40308 Mdot
.45411 .54229 Mdot
.47971 .83321 Mdot
.41337 .47793 Mdot
.36666 .56378 Mdot
.37827 .19529 Mdot
.57954 .39149 Mdot
.45718 .68107 Mdot
.48685 .43933 Mdot
.43555 .58893 Mdot
.67841 .56048 Mdot
.32443 .50282 Mdot
.33925 .51435 Mdot
.38949 .20945 Mdot
.7605 .40365 Mdot
.65676 .53744 Mdot
.37551 .46045 Mdot
.42078 .50268 Mdot
.57238 .43056 Mdot
.39064 .50645 Mdot
.45841 .32299 Mdot
.46026 .68562 Mdot
.59083 .37607 Mdot
.44341 .33627 Mdot
.3632 .48201 Mdot
.43421 .33919 Mdot
.62455 .38118 Mdot
.65258 .53913 Mdot
.38379 .47965 Mdot
.4237 .3087 Mdot
.43592 .34084 Mdot
.41477 .54079 Mdot
.47131 .66925 Mdot
.45895 .54686 Mdot
.35687 .5246 Mdot
.4284 .52529 Mdot
.48389 .71962 Mdot
.88465 .45125 Mdot
.38513 .56153 Mdot
.39846 .32559 Mdot
.47581 .72157 Mdot
.51222 .38405 Mdot
.57657 .38406 Mdot
.34014 .519 Mdot
.65637 .53902 Mdot
.63803 .55218 Mdot
.63762 .41094 Mdot
.48965 .73319 Mdot
.51541 .26074 Mdot
.45359 .6167 Mdot
.42001 .58969 Mdot
.35507 .47015 Mdot
.38859 .78872 Mdot
.65293 .2181 Mdot
.45411 .66324 Mdot
.63928 .33754 Mdot
.49779 .49238 Mdot
.63318 .56104 Mdot
.56964 .41325 Mdot
.50689 .72389 Mdot
.46549 .70785 Mdot
.47663 .6616 Mdot
.47078 .3463 Mdot
.57896 .25516 Mdot
.45076 .6817 Mdot
.45783 .63285 Mdot
.38739 .5421 Mdot
.42023 .504 Mdot
.30304 .30008 Mdot
.25364 .40937 Mdot
.43213 .34259 Mdot
.63424 .40962 Mdot
.19174 .68604 Mdot
.68154 .5549 Mdot
.56551 .79991 Mdot
.38571 .57118 Mdot
.09335 .53223 Mdot
.41687 .56057 Mdot
.39075 .50188 Mdot
.51731 .68843 Mdot
.42214 .31794 Mdot
.4596 .34076 Mdot
.49823 .6846 Mdot
.46482 .62947 Mdot
.45916 .32423 Mdot
.7554 .65596 Mdot
.81445 .38619 Mdot
.62382 .45227 Mdot
.47904 .69648 Mdot
.4315 .75206 Mdot
.62913 .55384 Mdot
.33301 .5741 Mdot
.68408 .55422 Mdot
.60558 .39457 Mdot
.64575 .40448 Mdot
.67701 .56297 Mdot
.38399 .53693 Mdot
.62868 .37661 Mdot
.39619 .46383 Mdot
.70314 .71057 Mdot
.34973 .71292 Mdot
.52862 .24117 Mdot
.31494 .47849 Mdot
.50578 .36849 Mdot
.66601 .63238 Mdot
.3598 .49399 Mdot
.74317 .33713 Mdot
.44685 .3494 Mdot
.3369 .57111 Mdot
.6827 .56521 Mdot
.416 .16812 Mdot
.38216 .47648 Mdot
.48443 .68508 Mdot
.64181 .56674 Mdot
.49205 .57666 Mdot
.66939 .66521 Mdot
.39789 .48781 Mdot
.11409 .51523 Mdot
.48109 .74551 Mdot
.59822 .37481 Mdot
.27992 .72346 Mdot
.45218 .66272 Mdot
.44272 .39237 Mdot
.60578 .24266 Mdot
.81213 .62035 Mdot
.45821 .65928 Mdot
.59633 .4413 Mdot
.49237 .65327 Mdot
.44794 .3117 Mdot
.51428 .72348 Mdot
.60265 .38342 Mdot
.36253 .51967 Mdot
.61075 .41641 Mdot
.46093 .35921 Mdot
.22341 .42365 Mdot
.65414 .53722 Mdot
.57089 .38661 Mdot
.66529 .55709 Mdot
.31592 .40889 Mdot
.51978 .21179 Mdot
.66742 .60011 Mdot
.24107 .62305 Mdot
.3496 .47616 Mdot
.45133 .65848 Mdot
.60786 .41959 Mdot
.67089 .30672 Mdot
.5015 .46905 Mdot
.48072 .71219 Mdot
.63715 .396 Mdot
.56048 .61129 Mdot
.24819 .6722 Mdot
.41018 .45919 Mdot
.28093 .43386 Mdot
.4813 .7002 Mdot
.61723 .44143 Mdot
.2266 .36246 Mdot
.49675 .65335 Mdot
.58682 .41614 Mdot
.63341 .58148 Mdot
.65654 .58281 Mdot
.35085 .52639 Mdot
.69314 .602 Mdot
.64159 .39006 Mdot
.7025 .62983 Mdot
.50925 .71458 Mdot
.50085 .59572 Mdot
.4242 .30259 Mdot
.61433 .40851 Mdot
.42523 .49982 Mdot
.52082 .72847 Mdot
.70629 .43933 Mdot
.32265 .72674 Mdot
.15792 .52246 Mdot
.61517 .41765 Mdot
.4637 .69873 Mdot
.48244 .68335 Mdot
.43343 .47422 Mdot
.51139 .55509 Mdot
.52115 .26061 Mdot
.44664 .4258 Mdot
.46935 .44415 Mdot
.6318 .3632 Mdot
.56604 .44166 Mdot
.35542 .56578 Mdot
.39582 .53338 Mdot
.63319 .5654 Mdot
.36469 .52292 Mdot
.51465 .69142 Mdot
.35174 .53331 Mdot
.67295 .57659 Mdot
.59441 .39427 Mdot
.37959 .47988 Mdot
.42959 .32679 Mdot
.62871 .54897 Mdot
.6696 .61579 Mdot
.6073 .41114 Mdot
.49252 .72121 Mdot
.49584 .30645 Mdot
.62663 .41154 Mdot
.39589 .53843 Mdot
.58541 .54909 Mdot
.42925 .51374 Mdot
.40599 .62244 Mdot
.49618 .65211 Mdot
.58798 .37949 Mdot
.51593 .70675 Mdot
.65888 .55565 Mdot
.56997 .2248 Mdot
.38191 .51888 Mdot
.58212 .41176 Mdot
.68958 .37426 Mdot
.29895 .5648 Mdot
.45899 .62545 Mdot
.75716 .58192 Mdot
.47443 .633 Mdot
.62859 .4211 Mdot
.544 .81721 Mdot
.47074 .32501 Mdot
.58595 .42853 Mdot
.7176 .26339 Mdot
.58798 .40469 Mdot
.36466 .53945 Mdot
.40363 .5609 Mdot
.59378 .37453 Mdot
.43729 .30326 Mdot
.30733 .27458 Mdot
.61667 .35685 Mdot
.45705 .6745 Mdot
.70265 .72366 Mdot
.16903 .43822 Mdot
.65515 .52149 Mdot
.63471 .57093 Mdot
.44991 .57559 Mdot
.37946 .44884 Mdot
.6875 .57387 Mdot
.67707 .61682 Mdot
.47369 .34919 Mdot
.60537 .42398 Mdot
.49646 .75676 Mdot
.64708 .61338 Mdot
.46952 .55218 Mdot
.60916 .27216 Mdot
.41255 .4575 Mdot
.55406 .7257 Mdot
.40187 .57279 Mdot
.41492 .38078 Mdot
.674 .57673 Mdot
.43668 .53103 Mdot
.4383 .49251 Mdot
.66865 .54502 Mdot
.45667 .32004 Mdot
.595 .60902 Mdot
.61939 .39584 Mdot
.8374 .38328 Mdot
.41579 .4704 Mdot
.36573 .5431 Mdot
.6528 .54402 Mdot
.52774 .3022 Mdot
.46835 .69864 Mdot
.48028 .63937 Mdot
.61394 .36885 Mdot
.51205 .50225 Mdot
.34169 .51123 Mdot
.3577 .50493 Mdot
.61805 .38792 Mdot
.57029 .41095 Mdot
.76032 .52627 Mdot
.40273 .55516 Mdot
.6468 .56265 Mdot
.42661 .27389 Mdot
.67501 .57419 Mdot
.42798 .50934 Mdot
.37164 .54728 Mdot
.36329 .55498 Mdot
.42493 .50039 Mdot
.68378 .60886 Mdot
.43162 .54486 Mdot
.3346 .56342 Mdot
.46896 .70542 Mdot
.40893 .49572 Mdot
.46586 .43938 Mdot
.37146 .52785 Mdot
.45617 .32217 Mdot
.24177 .55763 Mdot
.38216 .47687 Mdot
.34192 .52032 Mdot
.57999 .36333 Mdot
.37417 .51012 Mdot
.67941 .5512 Mdot
.47307 .68913 Mdot
.64396 .55245 Mdot
.63977 .5487 Mdot
.64754 .38423 Mdot
.48095 .34283 Mdot
.34966 .54702 Mdot
.46407 .35283 Mdot
.45095 .54695 Mdot
.37405 .46958 Mdot
.5884 .23988 Mdot
.24709 .72723 Mdot
.20749 .45155 Mdot
.38217 .52084 Mdot
.58099 .39402 Mdot
.57907 .38293 Mdot
.29632 .54113 Mdot
.41558 .46259 Mdot
.67888 .5957 Mdot
.63469 .55555 Mdot
.27858 .36438 Mdot
.42349 .2121 Mdot
.45641 .32163 Mdot
.57229 .52709 Mdot
.37843 .46278 Mdot
.43312 .51592 Mdot
.41946 .48087 Mdot
.6177 .36549 Mdot
.44043 .40394 Mdot
.58132 .42362 Mdot
.63818 .73407 Mdot
.67174 .55558 Mdot
.39029 .48 Mdot
.56486 .74423 Mdot
.50614 .68558 Mdot
.47327 .68801 Mdot
.66699 .61473 Mdot
.54799 .40189 Mdot
.27379 .33302 Mdot
.83249 .63147 Mdot
.48013 .74091 Mdot
.42703 .34132 Mdot
.35647 .49423 Mdot
.59333 .40008 Mdot
.49894 .66127 Mdot
.43178 .34737 Mdot
.39868 .47462 Mdot
.58045 .25518 Mdot
.38347 .52677 Mdot
.56859 .65254 Mdot
.4695 .65927 Mdot
.82548 .42677 Mdot
.48192 .73315 Mdot
.62798 .54872 Mdot
.68177 .57429 Mdot
.3908 .55865 Mdot
.34445 .77216 Mdot
.4585 .63948 Mdot
.59685 .55086 Mdot
.47282 .32017 Mdot
.69967 .45433 Mdot
.45284 .31365 Mdot
.60028 .37604 Mdot
.46681 .32302 Mdot
.60367 .38127 Mdot
.25198 .39095 Mdot
.46384 .73996 Mdot
.4467 .34322 Mdot
.68134 .37854 Mdot
.39195 .44726 Mdot
.42816 .33535 Mdot
.38572 .58584 Mdot
.38559 .61713 Mdot
.62123 .39003 Mdot
.46149 .31048 Mdot
.40682 .48061 Mdot
.53465 .16733 Mdot
.65068 .60256 Mdot
.68136 .59003 Mdot
.40142 .58781 Mdot
.64131 .36766 Mdot
.521 .69136 Mdot
.80176 .42562 Mdot
.61975 .55539 Mdot
.38864 .56102 Mdot
.35861 .54589 Mdot
.46585 .63156 Mdot
.54166 .77593 Mdot
.38341 .55465 Mdot
.44446 .44789 Mdot
.40191 .55672 Mdot
.65411 .60817 Mdot
.46826 .638 Mdot
.47861 .6854 Mdot
.63724 .39134 Mdot
.50771 .70478 Mdot
.28479 .52197 Mdot
.58341 .73788 Mdot
.4495 .46815 Mdot
.66147 .56132 Mdot
.6142 .73769 Mdot
.63562 .73729 Mdot
.67613 .23917 Mdot
.4493 .63718 Mdot
.41353 .57329 Mdot
.49677 .72312 Mdot
.44828 .31803 Mdot
.47756 .67317 Mdot
.50889 .71933 Mdot
.36518 .49693 Mdot
.39618 .48967 Mdot
.59219 .3865 Mdot
.50597 .53913 Mdot
.48509 .72397 Mdot
.41892 .55744 Mdot
.37232 .44931 Mdot
.4074 .46913 Mdot
.62668 .49327 Mdot
.45586 .65312 Mdot
.68441 .76893 Mdot
.35082 .29782 Mdot
.48606 .72374 Mdot
.36531 .18275 Mdot
.69564 .38735 Mdot
.64734 .41797 Mdot
.68421 .62455 Mdot
.40732 .55537 Mdot
.57142 .40132 Mdot
.38946 .48463 Mdot
.55534 .7232 Mdot
.37368 .5018 Mdot
.4604 .32336 Mdot
.3979 .46241 Mdot
.64115 .40995 Mdot
.62198 .4146 Mdot
.37476 .55553 Mdot
.37926 .4822 Mdot
.23397 .39758 Mdot
.44426 .64532 Mdot
.46939 .68367 Mdot
.5073 .26575 Mdot
.4368 .33355 Mdot
.67946 .56322 Mdot
.39505 .51251 Mdot
.64346 .3758 Mdot
.61916 .41588 Mdot
.45451 .65299 Mdot
.63194 .39749 Mdot
.66939 .58557 Mdot
.38376 .51526 Mdot
.68686 .57621 Mdot
.47205 .34575 Mdot
.46247 .64223 Mdot
.40406 .49193 Mdot
.38693 .54195 Mdot
.46362 .67364 Mdot
.35063 .55757 Mdot
.43239 .3084 Mdot
.58874 .40775 Mdot
.46054 .65247 Mdot
.66209 .57886 Mdot
.6002 .37751 Mdot
.43008 .5308 Mdot
.16828 .6273 Mdot
.36634 .53828 Mdot
.41662 .55209 Mdot
.70801 .24738 Mdot
.38798 .46048 Mdot
.61268 .41904 Mdot
.50604 .66559 Mdot
.31784 .47863 Mdot
.37176 .31981 Mdot
.88639 .52359 Mdot
.58744 .42836 Mdot
.35434 .49827 Mdot
.59512 .1955 Mdot
.35429 .50868 Mdot
.39447 .7802 Mdot
.66748 .41279 Mdot
.5078 .42157 Mdot
.41533 .58145 Mdot
.65364 .5916 Mdot
.58896 .38687 Mdot
.60829 .37887 Mdot
.66512 .76123 Mdot
.36233 .49942 Mdot
.56698 .5902 Mdot
.40559 .48464 Mdot
.66203 .58356 Mdot
.29969 .33768 Mdot
.62085 .41663 Mdot
.17793 .52031 Mdot
.41166 .5467 Mdot
.45895 .69891 Mdot
.5902 .35255 Mdot
.65024 .4841 Mdot
.42807 .52794 Mdot
.45238 .35405 Mdot
.62986 .59705 Mdot
.33787 .46214 Mdot
.66443 .56661 Mdot
.42814 .52161 Mdot
.40704 .42376 Mdot
.28499 .73571 Mdot
.47358 .66521 Mdot
.63344 .57737 Mdot
.60238 .52232 Mdot
.42804 .55685 Mdot
.45908 .65716 Mdot
.47575 .70938 Mdot
.46802 .35347 Mdot
.5786 .49121 Mdot
.62842 .65952 Mdot
.38616 .74454 Mdot
.68811 .74182 Mdot
.57936 .3595 Mdot
.76356 .44594 Mdot
.42175 .53319 Mdot
.47106 .2513 Mdot
.66962 .54298 Mdot
.36124 .53445 Mdot
.28996 .58817 Mdot
.50194 .68162 Mdot
.37599 .54184 Mdot
.45909 .33343 Mdot
.49196 .27569 Mdot
.45889 .25317 Mdot
.6129 .23834 Mdot
.60118 .39625 Mdot
.35494 .57652 Mdot
.38654 .42611 Mdot
.58517 .36944 Mdot
.33726 .51479 Mdot
.59032 .41535 Mdot
.76465 .66369 Mdot
.42564 .33295 Mdot
.45493 .66771 Mdot
.66921 .45648 Mdot
.34257 .53376 Mdot
.34899 .47299 Mdot
.47594 .36004 Mdot
.40001 .53363 Mdot
.25039 .709 Mdot
.65393 .46568 Mdot
.61774 .37289 Mdot
.47589 .66247 Mdot
.34475 .53077 Mdot
.5941 .49787 Mdot
.35608 .52018 Mdot
.39421 .68766 Mdot
.34275 .52267 Mdot
.64779 .66003 Mdot
.46821 .66662 Mdot
.66588 .56365 Mdot
.4305 .55712 Mdot
.37941 .49944 Mdot
.39939 .27117 Mdot
.45 .56571 Mdot
.43404 .54466 Mdot
.49542 .6359 Mdot
.49878 .6593 Mdot
.48456 .65225 Mdot
.62185 .43281 Mdot
.40547 .20984 Mdot
.65061 .55739 Mdot
.31325 .50909 Mdot
.64593 .6098 Mdot
.30915 .72858 Mdot
.42797 .34197 Mdot
.62032 .22307 Mdot
.40847 .51475 Mdot
.49139 .66621 Mdot
.74604 .36773 Mdot
.51189 .65695 Mdot
.55971 .52787 Mdot
.646 .57335 Mdot
.50072 .68947 Mdot
.38628 .49898 Mdot
.49919 .48009 Mdot
.54376 .18938 Mdot
.65305 .55014 Mdot
.45437 .53577 Mdot
.60752 .44021 Mdot
.52997 .23213 Mdot
.16239 .59604 Mdot
.65041 .60307 Mdot
.69493 .55508 Mdot
.36107 .49856 Mdot
.50722 .68322 Mdot
.65845 .59161 Mdot
.66355 .60666 Mdot
.63248 .39501 Mdot
.39975 .49263 Mdot
.40404 .49716 Mdot
.62613 .42503 Mdot
.64599 .54955 Mdot
.41486 .58559 Mdot
.35972 .44792 Mdot
.50588 .14669 Mdot
.53814 .5982 Mdot
.84793 .39297 Mdot
.28681 .51414 Mdot
.27645 .5922 Mdot
.81143 .434 Mdot
.46903 .71504 Mdot
.37339 .47456 Mdot
.3399 .46983 Mdot
.64174 .39141 Mdot
.37222 .51824 Mdot
.65487 .42052 Mdot
.6383 .56554 Mdot
.40464 .17847 Mdot
.62363 .71146 Mdot
.7891 .63538 Mdot
.37083 .5165 Mdot
.4897 .76748 Mdot
.44628 .32832 Mdot
.645 .52686 Mdot
.47811 .64448 Mdot
.41861 .49017 Mdot
.23196 .40075 Mdot
.58336 .42615 Mdot
.49435 .71292 Mdot
.27029 .31644 Mdot
.49733 .37486 Mdot
.42721 .50973 Mdot
.606 .43729 Mdot
.75577 .35958 Mdot
.4712 .57516 Mdot
.62348 .53738 Mdot
.4585 .32013 Mdot
.58654 .38527 Mdot
.63517 .55286 Mdot
.50686 .75058 Mdot
.49768 .6972 Mdot
.5223 .69708 Mdot
.21425 .48762 Mdot
.57478 .37451 Mdot
.44659 .33272 Mdot
.44596 .21607 Mdot
.4152 .23376 Mdot
.46135 .32619 Mdot
.64438 .40839 Mdot
.49866 .65981 Mdot
.49646 .67849 Mdot
.47327 .68994 Mdot
.19016 .47566 Mdot
.47281 .72279 Mdot
.59896 .79194 Mdot
.40822 .47366 Mdot
.43768 .44587 Mdot
.35486 .50094 Mdot
.68335 .58779 Mdot
.46378 .66209 Mdot
.50456 .45834 Mdot
.4477 .5234 Mdot
.54729 .20594 Mdot
.35641 .53274 Mdot
.67346 .53719 Mdot
.38529 .5467 Mdot
.49252 .78906 Mdot
.4914 .72565 Mdot
.37836 .52005 Mdot
.664 .53573 Mdot
.43463 .32537 Mdot
.46331 .62287 Mdot
.39732 .48632 Mdot
.77317 .56123 Mdot
.39202 .46083 Mdot
.78984 .61837 Mdot
.51763 .60564 Mdot
.42681 .34078 Mdot
.55103 .67694 Mdot
.57092 .42168 Mdot
.42608 .43692 Mdot
.42491 .59391 Mdot
.66043 .55238 Mdot
.69192 .43767 Mdot
.60889 .40342 Mdot
.45413 .4 Mdot
.32347 .51465 Mdot
.45733 .36132 Mdot
.44511 .63284 Mdot
.68863 .57578 Mdot
.33701 .50038 Mdot
.43316 .47743 Mdot
.65842 .7453 Mdot
.33211 .55171 Mdot
.35283 .53787 Mdot
.46342 .36674 Mdot
.595 .78597 Mdot
.3752 .53067 Mdot
.56537 .52398 Mdot
.5089 .73024 Mdot
.42685 .58498 Mdot
.58153 .79999 Mdot
.40489 .56167 Mdot
.49994 .70616 Mdot
.44152 .62632 Mdot
.59334 .64287 Mdot
.4795 .33317 Mdot
.34051 .51726 Mdot
.47153 .81837 Mdot
.40618 .54503 Mdot
.65028 .56285 Mdot
.39945 .45716 Mdot
.60278 .38613 Mdot
.20494 .44 Mdot
.63631 .38362 Mdot
.34525 .50002 Mdot
.47474 .69381 Mdot
.66234 .54645 Mdot
.19444 .52153 Mdot
.55646 .26259 Mdot
.57588 .79251 Mdot
.83842 .57719 Mdot
.45508 .30791 Mdot
.4842 .33152 Mdot
.68962 .57198 Mdot
.37828 .52187 Mdot
.58199 .81793 Mdot
.45389 .56075 Mdot
.37564 .53807 Mdot
.37381 .50024 Mdot
.5015 .21546 Mdot
.63591 .55971 Mdot
.62577 .3987 Mdot
.37828 .55171 Mdot
.43262 .54457 Mdot
.46913 .71432 Mdot
.43395 .33385 Mdot
.57681 .3841 Mdot
.45418 .34888 Mdot
.589 .39263 Mdot
.38236 .17893 Mdot
.44209 .52187 Mdot
.437 .32315 Mdot
.63695 .60852 Mdot
.49136 .71988 Mdot
.58454 .73069 Mdot
.60477 .37674 Mdot
.63831 .40455 Mdot
.3655 .54753 Mdot
.50183 .70474 Mdot
.5175 .69649 Mdot
.44644 .31624 Mdot
.66964 .5948 Mdot
.38094 .47715 Mdot
.37113 .46876 Mdot
.43555 .69207 Mdot
.64011 .36963 Mdot
.56556 .66051 Mdot
.7824 .47736 Mdot
.38104 .52274 Mdot
.51074 .71045 Mdot
.37445 .48787 Mdot
.80639 .47966 Mdot
.50794 .69317 Mdot
.40791 .56287 Mdot
.30271 .25734 Mdot
.54722 .40552 Mdot
.60344 .66711 Mdot
.36921 .55744 Mdot
.8422 .50165 Mdot
.41789 .52348 Mdot
.44378 .14355 Mdot
.651 .31719 Mdot
.34829 .4824 Mdot
.42764 .53997 Mdot
.32699 .7106 Mdot
.3573 .48426 Mdot
.6308 .41993 Mdot
.33942 .26203 Mdot
.52065 .67597 Mdot
.73345 .61893 Mdot
.24833 .55908 Mdot
.46267 .30913 Mdot
.6129 .36882 Mdot
.58785 .45269 Mdot
.46441 .33761 Mdot
.48095 .69515 Mdot
.38858 .52563 Mdot
.52688 .5008 Mdot
.62218 .36304 Mdot
.29496 .50223 Mdot
.65054 .56562 Mdot
.73392 .478 Mdot
.60562 .46709 Mdot
.66731 .57301 Mdot
.41251 .49954 Mdot
.3162 .70703 Mdot
.23808 .48071 Mdot
.80568 .36464 Mdot
.63484 .5513 Mdot
.65471 .54831 Mdot
.19471 .45246 Mdot
.4175 .30957 Mdot
.68713 .72473 Mdot
.66012 .66194 Mdot
.67578 .556 Mdot
.48234 .58709 Mdot
.59596 .42884 Mdot
.65125 .63227 Mdot
.33178 .56482 Mdot
.38607 .46636 Mdot
.38412 .49922 Mdot
.67386 .58971 Mdot
.30042 .56345 Mdot
.26626 .71044 Mdot
.66726 .558 Mdot
.42063 .60631 Mdot
.54334 .4626 Mdot
.69504 .35705 Mdot
.62696 .4183 Mdot
.47942 .3378 Mdot
.46688 .29676 Mdot
.45965 .69688 Mdot
.4803 .34024 Mdot
.48754 .26852 Mdot
.40065 .52663 Mdot
.67401 .56649 Mdot
.70336 .44369 Mdot
.65784 .5786 Mdot
.46257 .34008 Mdot
.43793 .35756 Mdot
.46884 .7049 Mdot
.47172 .67907 Mdot
.27824 .61364 Mdot
.30401 .36457 Mdot
.3537 .52275 Mdot
.67339 .28878 Mdot
.51311 .71062 Mdot
.29623 .49311 Mdot
.48025 .34652 Mdot
.43487 .33022 Mdot
.39991 .28277 Mdot
.40349 .50972 Mdot
.4305 .79527 Mdot
.39961 .51011 Mdot
.30052 .34365 Mdot
.39017 .57088 Mdot
.63245 .3961 Mdot
.40753 .5069 Mdot
.41564 .25807 Mdot
.33604 .52688 Mdot
.38643 .44946 Mdot
.63023 .36786 Mdot
.33137 .46778 Mdot
.60465 .38734 Mdot
.34637 .50774 Mdot
.43696 .29646 Mdot
.63162 .37261 Mdot
.36828 .34575 Mdot
.40276 .28962 Mdot
.64086 .41588 Mdot
.45896 .35818 Mdot
.45138 .30123 Mdot
.38565 .37171 Mdot
.47828 .64428 Mdot
.40378 .60513 Mdot
.37519 .52152 Mdot
.56467 .4057 Mdot
.63479 .56421 Mdot
.4252 .55139 Mdot
.36556 .45366 Mdot
.39097 .56698 Mdot
.45846 .69497 Mdot
.52465 .25744 Mdot
.44067 .31796 Mdot
.6171 .43191 Mdot
.50185 .31799 Mdot
.64671 .37009 Mdot
.40544 .45696 Mdot
.33275 .48162 Mdot
.26657 .57249 Mdot
.72426 .39299 Mdot
.18339 .46151 Mdot
.49744 .7001 Mdot
.58218 .37559 Mdot
.42907 .29855 Mdot
.38073 .44011 Mdot
.49484 .66524 Mdot
.603 .38393 Mdot
.38387 .52608 Mdot
.45494 .529 Mdot
.60332 .75601 Mdot
.27698 .48168 Mdot
.39183 .33114 Mdot
.63791 .41126 Mdot
.58211 .43237 Mdot
.43912 .24125 Mdot
.44505 .37854 Mdot
.50273 .46719 Mdot
.36145 .51112 Mdot
.45456 .3537 Mdot
.49937 .66201 Mdot
.22295 .48958 Mdot
.67871 .58705 Mdot
.50813 .54724 Mdot
.37257 .51622 Mdot
.50469 .39676 Mdot
.47391 .69557 Mdot
.45818 .32983 Mdot
.67526 .58746 Mdot
.48745 .34681 Mdot
.60029 .36603 Mdot
.79371 .66289 Mdot
.40343 .54153 Mdot
.35852 .541 Mdot
.63717 .53957 Mdot
.50134 .6729 Mdot
.4809 .35584 Mdot
.71136 .70791 Mdot
.61979 .37933 Mdot
.56151 .82287 Mdot
.51183 .70053 Mdot
.44563 .74699 Mdot
.61248 .431 Mdot
.66444 .61405 Mdot
.37174 .36721 Mdot
.67098 .57934 Mdot
.34358 .51092 Mdot
.48496 .67348 Mdot
.63774 .58313 Mdot
.50435 .55785 Mdot
.5788 .18901 Mdot
.43812 .75217 Mdot
.39687 .52095 Mdot
.48974 .16815 Mdot
.77957 .60216 Mdot
.4431 .67032 Mdot
.65253 .53802 Mdot
.35783 .53233 Mdot
.34219 .48816 Mdot
.40401 .54624 Mdot
.64139 .58008 Mdot
.64419 .27723 Mdot
.62063 .38725 Mdot
.35789 .49929 Mdot
.47294 .34961 Mdot
.60793 .39366 Mdot
.66449 .46285 Mdot
.62731 .41532 Mdot
.44645 .65316 Mdot
.39524 .4548 Mdot
.62345 .52029 Mdot
.37446 .15906 Mdot
.64706 .55163 Mdot
.64859 .39904 Mdot
.43383 .50273 Mdot
.71553 .42698 Mdot
.48767 .6552 Mdot
.62291 .37979 Mdot
.36485 .54215 Mdot
.67414 .44797 Mdot
.21695 .43546 Mdot
.62508 .41616 Mdot
.49738 .66485 Mdot
.78342 .34728 Mdot
.36729 .52106 Mdot
.41575 .53038 Mdot
.4969 .68771 Mdot
.24934 .64492 Mdot
.23674 .3514 Mdot
.37739 .48416 Mdot
.66736 .5646 Mdot
.70037 .77877 Mdot
.38074 .44678 Mdot
.34286 .29421 Mdot
.59051 .38542 Mdot
.60618 .60752 Mdot
.56275 .62879 Mdot
.38232 .4401 Mdot
.70216 .70982 Mdot
.7035 .57696 Mdot
.48039 .18587 Mdot
.65779 .41506 Mdot
.57659 .33031 Mdot
.44562 .17393 Mdot
.67573 .54173 Mdot
.44499 .7123 Mdot
.72496 .6705 Mdot
.18835 .58635 Mdot
.78364 .36384 Mdot
.54501 .32454 Mdot
.23213 .3969 Mdot
.52774 .47962 Mdot
.58494 .39775 Mdot
.49404 .32069 Mdot
.39117 .48373 Mdot
.78213 .59737 Mdot
.44784 .79834 Mdot
.36119 .78779 Mdot
.49438 .1667 Mdot
.38547 .77001 Mdot
.57639 .19447 Mdot
.68685 .24192 Mdot
.27382 .5472 Mdot
.73193 .38601 Mdot
.5604 .82701 Mdot
.33702 .24098 Mdot
.70595 .73725 Mdot
.45348 .47352 Mdot
.55667 .54426 Mdot
.81637 .59283 Mdot
.47231 .76742 Mdot
.26304 .69623 Mdot
.63497 .38688 Mdot
.49715 .6511 Mdot
.72334 .6645 Mdot
.47452 .6317 Mdot
.57894 .63423 Mdot
.78797 .34491 Mdot
.59643 .19081 Mdot
.50807 .79613 Mdot
.83335 .4576 Mdot
.30036 .59902 Mdot
.42205 .85432 Mdot
.61979 .3594 Mdot
.45185 .6709 Mdot
.41156 .35297 Mdot
.43101 .23591 Mdot
.66314 .71663 Mdot
.74727 .64847 Mdot
.56967 .23724 Mdot
.31657 .39101 Mdot
.48338 .68652 Mdot
.5502 .65363 Mdot
.59608 .5802 Mdot
.62619 .71612 Mdot
.32883 .26692 Mdot
.72267 .28687 Mdot
.52877 .51689 Mdot
.75014 .6 Mdot
.74881 .46598 Mdot
.16252 .58486 Mdot
.36282 .29475 Mdot
.31311 .46138 Mdot
.57455 .62389 Mdot
.81203 .4468 Mdot
.20623 .60126 Mdot
.28476 .37904 Mdot
.42662 .23536 Mdot
.34116 .22001 Mdot
.81313 .53021 Mdot
.21355 .32467 Mdot
.52064 .66475 Mdot
.35584 .54316 Mdot
.25787 .63577 Mdot
.48213 .81872 Mdot
.42983 .35099 Mdot
.63321 .25428 Mdot
.47237 .32258 Mdot
.46356 .71923 Mdot
.21949 .40815 Mdot
.58242 .79652 Mdot
.48641 .82507 Mdot
.46657 .29985 Mdot
.31808 .47319 Mdot
.82728 .68522 Mdot
.51422 .19442 Mdot
.60292 .69456 Mdot
.4895 .14527 Mdot
.49447 .41649 Mdot
.49339 .58714 Mdot
.63749 .58036 Mdot
.44171 .16707 Mdot
.49242 .67664 Mdot
.23569 .28178 Mdot
.43423 .14936 Mdot
.24301 .52899 Mdot
.84553 .31598 Mdot
.45642 .23236 Mdot
.5055 .41664 Mdot
.71652 .58397 Mdot
.35228 .33196 Mdot
.23291 .66764 Mdot
.33415 .42387 Mdot
.72336 .43526 Mdot
.85057 .55138 Mdot
.4728 .17755 Mdot
.51309 .82274 Mdot
.76671 .68899 Mdot
.19616 .60906 Mdot
.59379 .50554 Mdot
.32007 .55872 Mdot
.62114 .46547 Mdot
.71181 .29172 Mdot
.35653 .19688 Mdot
.35539 .29216 Mdot
.88711 .5352 Mdot
.45901 .37423 Mdot
.60867 .28393 Mdot
.78642 .32562 Mdot
.33179 .38891 Mdot
.54347 .62654 Mdot
.36174 .25349 Mdot
.31783 .46425 Mdot
.487 .28655 Mdot
.6626 .267 Mdot
.57975 .6829 Mdot
.35473 .24185 Mdot
.78046 .3866 Mdot
.6551 .74638 Mdot
.36036 .71506 Mdot
.40514 .22795 Mdot
.50371 .64533 Mdot
.30083 .38708 Mdot
.54181 .61476 Mdot
.58349 .18249 Mdot
.69711 .57435 Mdot
.62384 .1849 Mdot
.23931 .3525 Mdot
.43823 .5599 Mdot
.44326 .58963 Mdot
.52537 .66025 Mdot
.31259 .36743 Mdot
.33597 .45876 Mdot
.62671 .74738 Mdot
.64862 .21198 Mdot
.31137 .59328 Mdot
.59268 .60212 Mdot
.6902 .43377 Mdot
.79783 .34018 Mdot
.27694 .64134 Mdot
.44391 .38016 Mdot
.2977 .31497 Mdot
.18091 .61229 Mdot
.61455 .40279 Mdot
.52306 .81846 Mdot
.62216 .53747 Mdot
.21723 .45731 Mdot
.38757 .74843 Mdot
.23119 .57077 Mdot
.6499 .21251 Mdot
.53168 .34603 Mdot
.22951 .38052 Mdot
.32297 .41019 Mdot
.6322 .80461 Mdot
.69833 .36037 Mdot
.32484 .50043 Mdot
.7557 .61454 Mdot
.4368 .30288 Mdot
.31235 .66167 Mdot
.69231 .7712 Mdot
.5486 .29724 Mdot
.34957 .56699 Mdot
.23548 .5163 Mdot
.54144 .38509 Mdot
.50102 .48727 Mdot
.15343 .45668 Mdot
.40307 .45247 Mdot
.43704 .21712 Mdot
.80953 .54926 Mdot
.33629 .33208 Mdot
.81929 .40408 Mdot
.79792 .45014 Mdot
.24419 .28619 Mdot
.47597 .15426 Mdot
.54379 .26283 Mdot
.43878 .18087 Mdot
.54913 .16221 Mdot
.23443 .30527 Mdot
.43162 .59635 Mdot
.63205 .54206 Mdot
.14382 .60014 Mdot
.62213 .42323 Mdot
.47566 .20803 Mdot
.687 .74298 Mdot
.62712 .4777 Mdot
.50285 .75961 Mdot
.34338 .43061 Mdot
.53214 .49007 Mdot
.44406 .67917 Mdot
.33037 .4663 Mdot
.17678 .42322 Mdot
.28392 .25429 Mdot
.1993 .36568 Mdot
.82873 .52572 Mdot
.41946 .18199 Mdot
.51873 .42528 Mdot
.52097 .79342 Mdot
.29805 .54083 Mdot
.40374 .47405 Mdot
.43636 .39188 Mdot
.45881 .23176 Mdot
.23069 .52211 Mdot
.6672 .69596 Mdot
.44321 .6399 Mdot
.64751 .2608 Mdot
.50179 .90982 Mdot
.29935 .61865 Mdot
.60787 .79703 Mdot
.44825 .24729 Mdot
.31222 .3547 Mdot
.70283 .29278 Mdot
.23561 .54924 Mdot
.70205 .24717 Mdot
.45037 .7052 Mdot
.7047 .73371 Mdot
.56431 .31522 Mdot
.48041 .48467 Mdot
.52941 .25402 Mdot
.61636 .20593 Mdot
.71026 .53394 Mdot
.21103 .53168 Mdot
.6901 .66099 Mdot
.23644 .62239 Mdot
.67258 .37677 Mdot
.74194 .48399 Mdot
.6756 .77884 Mdot
.77214 .42922 Mdot
.31689 .32383 Mdot
.55182 .47427 Mdot
.54774 .71085 Mdot
.70483 .57966 Mdot
.32243 .32158 Mdot
.45781 .43149 Mdot
.43034 .19631 Mdot
.34242 .15021 Mdot
.16703 .49531 Mdot
.83689 .39122 Mdot
.68644 .29163 Mdot
.34295 .55601 Mdot
.73959 .27161 Mdot
.19038 .36313 Mdot
.41102 .14204 Mdot
.73479 .5132 Mdot
.66301 .40394 Mdot
.65856 .61414 Mdot
.19082 .41042 Mdot
.6335 .2751 Mdot
.73445 .28022 Mdot
.37855 .25086 Mdot
.66427 .61854 Mdot
.25881 .74075 Mdot
.33878 .22713 Mdot
.4083 .75305 Mdot
.2762 .48429 Mdot
.38572 .57751 Mdot
.47882 .78812 Mdot
.47072 .63133 Mdot
.76354 .45544 Mdot
.29611 .3757 Mdot
.61565 .41107 Mdot
.41718 .37114 Mdot
.75371 .63675 Mdot
.39746 .4625 Mdot
.59974 .52005 Mdot
.45317 .63555 Mdot
.72742 .39342 Mdot
.59821 .73645 Mdot
.34657 .19549 Mdot
.4951 .23236 Mdot
.4202 .57786 Mdot
.33801 .32547 Mdot
.52106 .25146 Mdot
.22681 .36143 Mdot
.69093 .57917 Mdot
.518 .16783 Mdot
.54225 .54753 Mdot
.29972 .38563 Mdot
.46417 .79067 Mdot
.39154 .6171 Mdot
.35494 .46616 Mdot
.78123 .41962 Mdot
.38448 .66863 Mdot
.50366 .5234 Mdot
.31809 .54687 Mdot
.33812 .58365 Mdot
.75134 .27979 Mdot
.49306 .27939 Mdot
.73778 .46792 Mdot
.54627 .17172 Mdot
.64851 .58319 Mdot
.50028 .72029 Mdot
.46641 .2911 Mdot
.73065 .69227 Mdot
.40275 .66469 Mdot
.21616 .4371 Mdot
.61959 .47432 Mdot
.56162 .29079 Mdot
.55663 .17872 Mdot
.51262 .17291 Mdot
.41885 .81331 Mdot
.44718 .62604 Mdot
.2799 .54902 Mdot
.71986 .71216 Mdot
.50572 .66071 Mdot
.6259 .7625 Mdot
.61326 .76243 Mdot
.38156 .19051 Mdot
.59379 .53803 Mdot
.85034 .53753 Mdot
.38822 .33508 Mdot
.62251 .25451 Mdot
.19236 .52063 Mdot
.66266 .7841 Mdot
.59005 .20283 Mdot
.47339 .58787 Mdot
.34503 .73228 Mdot
.44437 .45895 Mdot
.54696 .74742 Mdot
.18911 .65886 Mdot
.44331 .28076 Mdot
.45128 .75493 Mdot
.783 .38603 Mdot
.39334 .53286 Mdot
.16061 .51145 Mdot
.73984 .67068 Mdot
.19118 .45718 Mdot
.65548 .61859 Mdot
.4187 .50096 Mdot
.33423 .51502 Mdot
.33083 .29084 Mdot
.59462 .64582 Mdot
.4161 .20415 Mdot
.72161 .75296 Mdot
.75745 .35194 Mdot
.4463 .79708 Mdot
.45307 .21906 Mdot
.73473 .29187 Mdot
.7856 .58881 Mdot
.57235 .49776 Mdot
.46756 .23279 Mdot
.34839 .37992 Mdot
.8317 .46593 Mdot
.4684 .43648 Mdot
.69305 .62826 Mdot
.6663 .72382 Mdot
.78642 .47705 Mdot
.21104 .50346 Mdot
.424 .51716 Mdot
.27062 .3161 Mdot
.7034 .25855 Mdot
.42986 .8088 Mdot
.22321 .66909 Mdot
.16514 .48296 Mdot
.3932 .70631 Mdot
.78996 .46354 Mdot
.77292 .60543 Mdot
.62924 .82001 Mdot
.54257 .55567 Mdot
.57039 .20961 Mdot
.33822 .39279 Mdot
.55308 .17588 Mdot
.64016 .53541 Mdot
.6703 .6709 Mdot
.69088 .42813 Mdot
.43105 .18867 Mdot
.29225 .66649 Mdot
.64381 .21945 Mdot
.50409 .43392 Mdot
.25375 .27221 Mdot
.75985 .40774 Mdot
.52644 .46661 Mdot
.59095 .37111 Mdot
.52631 .34068 Mdot
.64721 .24712 Mdot
.71646 .35657 Mdot
.64942 .78807 Mdot
.63154 .43638 Mdot
.48291 .30406 Mdot
.41787 .7692 Mdot
.2864 .42265 Mdot
.78714 .42697 Mdot
.33803 .32592 Mdot
.62493 .20085 Mdot
.34774 .26418 Mdot
.26635 .32458 Mdot
.47808 .2205 Mdot
.83423 .60891 Mdot
.60193 .68897 Mdot
.4684 .26388 Mdot
.74631 .65876 Mdot
.62945 .29282 Mdot
.48613 .59448 Mdot
.08476 .41849 Mdot
.79857 .64743 Mdot
.74543 .39435 Mdot
.35716 .19692 Mdot
.81041 .46601 Mdot
.72722 .39844 Mdot
.22915 .64492 Mdot
.53972 .59677 Mdot
.25255 .37434 Mdot
.37463 .50077 Mdot
.17362 .413 Mdot
.28554 .40886 Mdot
.32787 .21139 Mdot
.75116 .29004 Mdot
.46616 .78088 Mdot
.38986 .4552 Mdot
.61312 .43492 Mdot
.57692 .60654 Mdot
.26015 .43492 Mdot
.28736 .68631 Mdot
.53295 .63146 Mdot
.68278 .4246 Mdot
.58129 .37092 Mdot
.5088 .25551 Mdot
.4811 .74046 Mdot
.62582 .2658 Mdot
.78263 .47176 Mdot
.55711 .37758 Mdot
.52708 .52959 Mdot
.31988 .33276 Mdot
.56153 .63237 Mdot
.41112 .7507 Mdot
.23309 .54252 Mdot
.63637 .50897 Mdot
.63223 .41277 Mdot
.39124 .74001 Mdot
.81548 .60202 Mdot
.76026 .36516 Mdot
.34106 .21726 Mdot
.51049 .33605 Mdot
.31928 .72704 Mdot
.32331 .31398 Mdot
.24333 .6855 Mdot
.31459 .74479 Mdot
.70662 .37385 Mdot
.5233 .75018 Mdot
.2583 .68349 Mdot
.73749 .63331 Mdot
.40648 .17645 Mdot
.70545 .73668 Mdot
.71726 .71827 Mdot
.67714 .40468 Mdot
.42835 .69659 Mdot
.44771 .7814 Mdot
.37446 .34452 Mdot
.5031 .47807 Mdot
.38817 .84133 Mdot
.33279 .56819 Mdot
.26958 .78745 Mdot
.65173 .60606 Mdot
.2 .62979 Mdot
.35443 .38272 Mdot
.55565 .47244 Mdot
.48496 .42362 Mdot
.78014 .4364 Mdot
.64923 .66248 Mdot
.81446 .5562 Mdot
.32492 .7629 Mdot
.63703 .36303 Mdot
.7332 .74676 Mdot
.83909 .60642 Mdot
.34968 .72268 Mdot
.41959 .47132 Mdot
.8133 .62836 Mdot
.66359 .39082 Mdot
.22931 .52583 Mdot
.82022 .39998 Mdot
.71975 .34223 Mdot
.45576 .59091 Mdot
.30967 .36166 Mdot
.57246 .20864 Mdot
.51075 .15945 Mdot
.25697 .72822 Mdot
.66495 .26977 Mdot
.63719 .53797 Mdot
.51779 .4429 Mdot
.6565 .23602 Mdot
.49547 .57465 Mdot
.64876 .6333 Mdot
.53321 .61922 Mdot
.36234 .84916 Mdot
.48262 .20374 Mdot
.41988 .20463 Mdot
.51753 .60772 Mdot
.48679 .73305 Mdot
.59027 .63659 Mdot
.54503 .62725 Mdot
.72835 .3548 Mdot
.79562 .61669 Mdot
.54391 .62076 Mdot
.54148 .85113 Mdot
.3788 .61475 Mdot
.53518 .37775 Mdot
.44016 .78618 Mdot
.30694 .58521 Mdot
.6611 .62129 Mdot
.29038 .3053 Mdot
.77506 .36115 Mdot
.62284 .55489 Mdot
.78624 .4187 Mdot
.75174 .59651 Mdot
.44398 .72378 Mdot
.40913 .68397 Mdot
.73621 .33771 Mdot
.30423 .69288 Mdot
.5177 .77367 Mdot
.22584 .48095 Mdot
.65156 .39151 Mdot
.77575 .35142 Mdot
.61138 .3734 Mdot
.30944 .47104 Mdot
.5072 .55211 Mdot
.32643 .42931 Mdot
.18496 .4499 Mdot
.45185 .30534 Mdot
.46269 .63811 Mdot
.2094 .67913 Mdot
.51324 .68376 Mdot
.18298 .40582 Mdot
.23241 .56668 Mdot
.46722 .7926 Mdot
.5446 .26873 Mdot
.52967 .29488 Mdot
.46336 .85497 Mdot
.61686 .51456 Mdot
.63125 .46618 Mdot
.56401 .75707 Mdot
.45319 .66044 Mdot
.49911 .22957 Mdot
.63652 .37203 Mdot
.54072 .5801 Mdot
.70831 .52837 Mdot
.42618 .62975 Mdot
.49296 .7604 Mdot
.53141 .55612 Mdot
.27018 .36146 Mdot
.40195 .19036 Mdot
.58345 .41086 Mdot
.2853 .7893 Mdot
.37367 .45588 Mdot
.35298 .70611 Mdot
.70005 .24312 Mdot
.26853 .74911 Mdot
.59876 .45997 Mdot
.84467 .60287 Mdot
.41305 .57578 Mdot
.71247 .30606 Mdot
.48863 .68338 Mdot
.71043 .72467 Mdot
.46422 .31611 Mdot
.34111 .33258 Mdot
.64797 .6076 Mdot
.20939 .53216 Mdot
.5491 .43608 Mdot
.52168 .69619 Mdot
.69666 .31526 Mdot
.28203 .55919 Mdot
.6625 .65067 Mdot
.51522 .27613 Mdot
.35637 .72837 Mdot
.41004 .6763 Mdot
.4695 .74494 Mdot
.43271 .20236 Mdot
.72156 .72218 Mdot
.36224 .17822 Mdot
.49103 .62783 Mdot
.50178 .37513 Mdot
.64739 .74221 Mdot
.76823 .3878 Mdot
.56041 .72813 Mdot
.67285 .22324 Mdot
.28626 .38682 Mdot
.43096 .65937 Mdot
.30473 .34115 Mdot
.45466 .4991 Mdot
.54959 .50548 Mdot
.75943 .47618 Mdot
.35718 .78816 Mdot
.56891 .65437 Mdot
.21135 .62178 Mdot
.54029 .74496 Mdot
.41415 .21544 Mdot
.52589 .74328 Mdot
.55471 .41213 Mdot
.43942 .72805 Mdot
.65318 .51963 Mdot
.42057 .17241 Mdot
.68147 .2288 Mdot
.67068 .53129 Mdot
.54227 .2366 Mdot
.81468 .42505 Mdot
.44181 .47955 Mdot
.51433 .39765 Mdot
.34987 .53234 Mdot
.29141 .54261 Mdot
.28627 .77064 Mdot
.74397 .36553 Mdot
.34797 .57121 Mdot
.47361 .18323 Mdot
.45967 .17139 Mdot
.28954 .23974 Mdot
.58854 .81867 Mdot
.46283 .6959 Mdot
.22766 .32388 Mdot
.53339 .63627 Mdot
.53276 .15699 Mdot
.70902 .36695 Mdot
.73748 .25672 Mdot
.33915 .72579 Mdot
.79597 .41817 Mdot
.23992 .65974 Mdot
.6192 .64785 Mdot
.80628 .52749 Mdot
.54318 .44986 Mdot
.72287 .46265 Mdot
.81119 .49192 Mdot
.66344 .82097 Mdot
.38594 .43731 Mdot
.7648 .57923 Mdot
.71886 .65676 Mdot
.7696 .34292 Mdot
.65227 .32442 Mdot
.40148 .45855 Mdot
.69712 .44393 Mdot
.19547 .48549 Mdot
.33227 .31806 Mdot
.48653 .30573 Mdot
.65423 .32586 Mdot
.2364 .4314 Mdot
.29138 .35131 Mdot
.70852 .73613 Mdot
.35272 .73087 Mdot
.55741 .58022 Mdot
.42707 .55821 Mdot
.49523 .75432 Mdot
.47487 .31674 Mdot
.57761 .47031 Mdot
.34772 .51294 Mdot
.56196 .4058 Mdot
.64953 .65071 Mdot
.17354 .45746 Mdot
.58399 .67746 Mdot
.7613 .6478 Mdot
.52001 .73461 Mdot
.7292 .61761 Mdot
.56788 .73701 Mdot
.17815 .52812 Mdot
.60603 .31003 Mdot
.35568 .29209 Mdot
.52157 .1902 Mdot
.35913 .24132 Mdot
.4599 .74639 Mdot
.29294 .26358 Mdot
.66543 .54078 Mdot
.44876 .60956 Mdot
.7012 .67334 Mdot
.49591 .2512 Mdot
.32422 .55275 Mdot
.79454 .41706 Mdot
.61955 .46828 Mdot
.42567 .24397 Mdot
.81554 .53636 Mdot
.30221 .57221 Mdot
.39353 .76307 Mdot
.50157 .17257 Mdot
.58777 .42814 Mdot
.74933 .69214 Mdot
.69874 .63676 Mdot
.58106 .3252 Mdot
.39001 .20935 Mdot
.37053 .18629 Mdot
.50012 .44547 Mdot
.34121 .37192 Mdot
.41642 .53986 Mdot
.68353 .76927 Mdot
.75751 .38066 Mdot
.36138 .42372 Mdot
.72524 .50263 Mdot
.50711 .7112 Mdot
.75676 .50802 Mdot
.55656 .55389 Mdot
.2473 .39715 Mdot
.46048 .62835 Mdot
.44767 .80165 Mdot
.44234 .2966 Mdot
.49295 .39555 Mdot
.32393 .47086 Mdot
.34834 .35452 Mdot
.50979 .82976 Mdot
.31627 .5227 Mdot
.68026 .27503 Mdot
.37756 .74036 Mdot
.71076 .71083 Mdot
.72727 .3319 Mdot
.70504 .38035 Mdot
.64262 .65998 Mdot
.4315 .71999 Mdot
.66073 .50057 Mdot
.3833 .56375 Mdot
.55881 .42212 Mdot
.51673 .67043 Mdot
.79518 .36487 Mdot
.39352 .69479 Mdot
.36711 .34882 Mdot
.62491 .49531 Mdot
.30632 .47292 Mdot
.70804 .55157 Mdot
.72456 .25089 Mdot
.6187 .64939 Mdot
.29314 .37619 Mdot
.59407 .53685 Mdot
.35688 .37858 Mdot
.22978 .58082 Mdot
.42675 .15279 Mdot
.23397 .6538 Mdot
.52088 .50247 Mdot
.21268 .64361 Mdot
.77448 .43664 Mdot
.82253 .41244 Mdot
.28887 .36805 Mdot
.48256 .4039 Mdot
.44856 .36771 Mdot
.59296 .76251 Mdot
.62032 .50258 Mdot
.47886 .29 Mdot
.54829 .58822 Mdot
.69827 .50429 Mdot
.61405 .59559 Mdot
.35606 .42821 Mdot
.48846 .21262 Mdot
.51246 .18249 Mdot
.69793 .73182 Mdot
.70371 .56978 Mdot
.57679 .33353 Mdot
.24897 .40911 Mdot
.77213 .27747 Mdot
.16647 .61807 Mdot
.41476 .541 Mdot
.68888 .53516 Mdot
.32856 .37261 Mdot
.64057 .40853 Mdot
.55741 .64244 Mdot
.57365 .72634 Mdot
.6335 .58544 Mdot
.46801 .28966 Mdot
.41504 .24446 Mdot
.77725 .45349 Mdot
.28793 .42913 Mdot
.67404 .45252 Mdot
.16835 .46559 Mdot
.83142 .57391 Mdot
.76189 .37999 Mdot
.72392 .22603 Mdot
.69523 .63196 Mdot
.39041 .60708 Mdot
.2578 .61597 Mdot
.40429 .19284 Mdot
.34787 .31559 Mdot
.2174 .4782 Mdot
.69997 .39486 Mdot
.28539 .38024 Mdot
.50449 .60977 Mdot
.46373 .21984 Mdot
.75175 .5085 Mdot
.54288 .48756 Mdot
.5324 .29848 Mdot
.3161 .23846 Mdot
.4025 .7754 Mdot
.54532 .19253 Mdot
.19192 .50269 Mdot
.60103 .8364 Mdot
.43468 .16557 Mdot
.40113 .29697 Mdot
.6322 .31646 Mdot
.25973 .63492 Mdot
.46657 .43932 Mdot
.48106 .5841 Mdot
.22811 .52126 Mdot
.39101 .6485 Mdot
.57984 .25622 Mdot
.1958 .58601 Mdot
.31764 .32319 Mdot
.32089 .59728 Mdot
.48162 .40698 Mdot
.40512 .74393 Mdot
.53824 .23861 Mdot
.50425 .59181 Mdot
.4829 .46187 Mdot
.37375 .31142 Mdot
.38258 .73784 Mdot
.66467 .7367 Mdot
.80326 .46001 Mdot
.56587 .85774 Mdot
.66993 .29215 Mdot
.17957 .54179 Mdot
.40932 .47353 Mdot
.32193 .19592 Mdot
.79706 .49286 Mdot
.69918 .35268 Mdot
.80158 .5896 Mdot
.54331 .3646 Mdot
.40621 .61435 Mdot
.38409 .564 Mdot
.64094 .24736 Mdot
.44914 .75482 Mdot
.28395 .58622 Mdot
.20301 .53545 Mdot
.32675 .34417 Mdot
.3778 .25535 Mdot
.38095 .34222 Mdot
.44631 .61136 Mdot
.50989 .68184 Mdot
.20401 .35595 Mdot
.51178 .47139 Mdot
.32276 .45769 Mdot
.41168 .42761 Mdot
.23772 .62509 Mdot
.85862 .54873 Mdot
.52647 .66382 Mdot
.37696 .23618 Mdot
.36986 .76085 Mdot
.47476 .51702 Mdot
.55653 .71508 Mdot
.72686 .19355 Mdot
.38996 .13576 Mdot
.5222 .68491 Mdot
.59291 .80096 Mdot
.37813 .76627 Mdot
.42653 .1952 Mdot
.57005 .31299 Mdot
.7183 .52142 Mdot
.4017 .41826 Mdot
.48798 .51082 Mdot
.3208 .48915 Mdot
.80303 .56559 Mdot
.43948 .15312 Mdot
.19948 .55317 Mdot
.4765 .18293 Mdot
.45638 .56596 Mdot
.31886 .50998 Mdot
.79675 .2887 Mdot
.64562 .22888 Mdot
.42853 .46841 Mdot
.25795 .69394 Mdot
.32015 .55792 Mdot
.38783 .48575 Mdot
.58328 .22958 Mdot
.73429 .74437 Mdot
.31912 .31809 Mdot
.4308 .18917 Mdot
.46723 .62834 Mdot
.55615 .43018 Mdot
.65009 .6059 Mdot
.49167 .43628 Mdot
.45213 .53285 Mdot
.64167 .58699 Mdot
.26532 .48972 Mdot
.79578 .40441 Mdot
.58004 .59255 Mdot
.73879 .72241 Mdot
.65042 .19336 Mdot
.40194 .71363 Mdot
.59148 .75751 Mdot
.3912 .44336 Mdot
.32067 .59508 Mdot
.25181 .43672 Mdot
.30342 .55674 Mdot
.81651 .45839 Mdot
.13717 .36765 Mdot
.70808 .46775 Mdot
.26775 .34395 Mdot
.47416 .7331 Mdot
.56129 .59694 Mdot
.42716 .76202 Mdot
.59377 .33212 Mdot
.57672 .39752 Mdot
.4601 .55077 Mdot
.47585 .62005 Mdot
.63115 .59802 Mdot
.23998 .75087 Mdot
.4225 .47967 Mdot
.56231 .67031 Mdot
.53605 .15904 Mdot
.22549 .48081 Mdot
.32574 .68792 Mdot
.3726 .56659 Mdot
.62877 .72032 Mdot
.48364 .40156 Mdot
.74088 .31639 Mdot
.27265 .31756 Mdot
.48559 .1912 Mdot
.39319 .69046 Mdot
.3878 .76299 Mdot
.43171 .54717 Mdot
.41701 .32231 Mdot
.61235 .61545 Mdot
.61507 .2432 Mdot
.42176 .59199 Mdot
.49379 .15373 Mdot
.52872 .38984 Mdot
.58382 .46826 Mdot
.49835 .62769 Mdot
.2755 .25504 Mdot
.2154 .59711 Mdot
.44973 .77242 Mdot
.17542 .51422 Mdot
.50168 .27303 Mdot
.28858 .42008 Mdot
.60506 .43571 Mdot
.43242 .59101 Mdot
.49003 .63728 Mdot
.15625 .49125 Mdot
.56822 .21933 Mdot
.71459 .44918 Mdot
.73906 .4839 Mdot
.63776 .78137 Mdot
.68047 .64812 Mdot
.69541 .20544 Mdot
.51418 .28747 Mdot
.16138 .48496 Mdot
.72811 .71256 Mdot
.51712 .65447 Mdot
.78973 .43866 Mdot
.35233 .57915 Mdot
.6031 .41748 Mdot
.47108 .1901 Mdot
.30176 .49715 Mdot
.22126 .40908 Mdot
.3462 .55272 Mdot
.19906 .43235 Mdot
.43292 .26804 Mdot
.53004 .2287 Mdot
.75576 .41147 Mdot
.23017 .61798 Mdot
.77788 .32491 Mdot
.59517 .76375 Mdot
.76432 .28568 Mdot
.78307 .34016 Mdot
.51193 .16712 Mdot
.20887 .4581 Mdot
.29441 .76184 Mdot
.71686 .3639 Mdot
.74062 .34497 Mdot
.77018 .47408 Mdot
.2516 .64223 Mdot
.52923 .33974 Mdot
.52157 .65215 Mdot
.60126 .65046 Mdot
.65413 .52491 Mdot
.09301 .56861 Mdot
.39201 .2595 Mdot
.50677 .64321 Mdot
.51927 .31646 Mdot
.47579 .1682 Mdot
.24618 .62454 Mdot
.81289 .50643 Mdot
.55568 .54315 Mdot
.32582 .49267 Mdot
.40115 .6745 Mdot
.67225 .75942 Mdot
.52012 .34665 Mdot
.48348 .86995 Mdot
.82073 .58864 Mdot
.71431 .4891 Mdot
.54518 .51536 Mdot
.49976 .65109 Mdot
.53442 .76533 Mdot
.53757 .2862 Mdot
.8213 .47514 Mdot
.79621 .41314 Mdot
.65431 .23422 Mdot
.46387 .8537 Mdot
.71354 .71328 Mdot
.4024 .1919 Mdot
.76445 .40425 Mdot
.51938 .71035 Mdot
.40044 .32901 Mdot
.65609 .3815 Mdot
.7272 .44278 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo07_ooooo0_l0003<ooooo`007?ooool0
0ol0003oooooooooo`1kooooo`;o0000c?ooool001cooooo00?o0000ooooooooool0P_ooool2o`00
00Cooooo1_l000000ooooooo0000o`00002hooooo`007?ooool00ol0003oooooooooo`1oooooo`;o
000000?oooooo`000?l000001?ooool6o`000004ooooool0003o0000o`0000Wooooo0_l00004oooo
o`;o0000Y_ooool001cooooo00?o0000ooooooooool0K?ooool2o`00017ooooo0_l00008ooooo`Co
00000oooool2o`0000Wooooo0_l00004ooooo`;o0000Y_ooool001cooooo0_l0001]ooooo`;o0000
6Oooool6o`00013ooooo0_l0002Zooooo`007?ooool00ol0003oooooooooo`27ooooo`;o00000_oo
ool2o`0000[ooooo0_l00004ooooo`;o00002oooool2o`0009gooooo000Looooo`03o`000?oooooo
oooo07Kooooo0_l0000Oooooo`;o00002Oooool2o`0000Gooooo0ol00008ooooo`;o0000Toooool0
01cooooo00?o0000ooooooooool0M_ooool2o`0002[ooooo0_l00005ooooo`?o00000oooool2o`00
00?ooooo0_l0002Cooooo`007?ooool00ol0003oooooooooo`29ooooo`;o00009?ooool2o`0009So
oooo000Looooo`03o`000?oooooooooo08?ooooo0_l00004ooooo`;o000000?oooooo`000?l00000
2Oooool2o`000003ooooool0003o000000?o00000oooool4o`0000Cooooo0_l00006ooooo`;o0000
UOooool001cooooo00?o0000ooooooooool0Poooool2o`0000Oooooo0_l000001?oooooo0000o`00
0?ooool2o`0000?ooooo0_l000000ooooooo0000o`000003o`0000?ooooo1?l00004ooooo`;o0000
0_ooool2o`0000;ooooo0_l0002Eooooo`007?ooool00ol0003oooooooooo`25ooooo`;o000000?o
ooooo`000?l000000_l000000ooooooo0000o`000002o`000003ooooool0003o000000_ooooo0_l0
0002ooooo`;o00002Oooool2o`0009Wooooo000Looooo`03o`000?oooooooooo07;ooooo0_l0000<
ooooo`;o00000oooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000001oooool2
o`0000Oooooo0_l00002ooooo`;o00002oooool2o`0009Oooooo000Looooo`03o`000?oooooooooo
07;ooooo0_l00004ooooo`;o00000_ooool2o`0000;ooooo0_l00009ooooo`;o00002Oooool2o`00
01Sooooo0ol0002Fooooo`007?ooool00ol0003oooooooooo`1cooooo`;o00000oooool2o`0000;o
oooo0_l00007ooooo`;o00001?ooool2o`0000Wooooo0ol0000:ooooo`;o00003?ooool2o`0000Oo
oooo0_l0002=ooooo`007?ooool00ol0003oooooooooo`1cooooo`Co00003_ooool2o`0000oooooo
1?l00005ooooo`;o00000_ooool2o`0001;ooooo0_l000000ooooooo0000o`00000;ooooo`;o0000
P?ooool001cooooo00?o0000ooooooooool0MOooool2o`000003ooooool0003o000000Gooooo0_l0
0007ooooo`;o00002oooool5o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Sooooo0ol0
0002ooooo`;o00002Oooool2o`00083ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo
0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`1hooooo`;o00001Oooool3o`0000Kooooo
0_l0000;ooooo`;o00000oooool2o`0000[ooooo0_l00005ooooo`;o00001_ooool5o`0000;ooooo
1?l0000?ooooo`;o00005oooool2o`0005oooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1Uoooo
o`;o00001_ooool5o`0000Gooooo0_l00006ooooo`?o00001Oooool3o`0000oooooo0ol00002oooo
o`;o00000oooool2o`0000Sooooo0_l00006ooooo`Co000000?oooooo`000?l000000_ooool2o`00
00Kooooo0_l00007ooooo`;o00005oooool2o`0005oooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`1Uooooo`;o
00001_ooool5o`0000Gooooo0_l00007ooooo`;o00001Oooool3o`0000oooooo0_l00003ooooo`;o
00000oooool2o`00013ooooo1?l000001Ooooooo0000o`000?l0003ooooo00;o00001_ooool4o`00
07oooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^
k^h01_ooool3o`0006Wooooo0_l0000Nooooo`;o00006oooool2o`0000gooooo0_l00002ooooo`Go
00001_ooool2o`000004ooooool0003o0000o`0007oooooo00000ooooooo0000ooooo`02ooooo`03
o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`1Yooooo`;o
00005Oooool2o`000003ooooool0003o000000;o00000_ooool2o`0000kooooo0_l0000;ooooo`;o
00001_ooool2o`0000Wooooo0_l000000ooooooo0000o`000006ooooo`;o000000Coooooo`000?l0
003o00004?ooool2o`0000;ooooo0_l0001Yooooo`0000?ooooooa0@4?ooool00_ooool00ol@413o
ooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0OOooool2o`000004
ooooool0003o0000ooooo`Co00002?ooool2o`0000Kooooo1?l0000<ooooo`;o00001Oooool2o`00
00Kooooo0_l0000<ooooo`;o00000_ooool2o`000003ooooool0003o000000gooooo0_l00002oooo
o`;o0000JOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonH
V9So410@00Kooooo00?o0000ooooooooool0Ioooool2o`0000Gooooo0_l00003ooooo`;o00001?oo
ool6o`000003ooooool0003o000000;o00000_ooool4o`0000Gooooo0_l00003ooooo`;o000000?o
ooooo`000?l000000_l00009ooooo`Go00003Oooool2o`0001?ooooo0_l00002ooooo`;o0000N?oo
ool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Ko
oooo00?o0000ooooooooool0IOooool4o`0000Gooooo0_l00003ooooo`;o00001?ooool4o`0000?o
oooo1Ol000000ooooooo0000o`000002o`0000[ooooo0_l00003ooooo`Co00001oooool3o`0000Co
oooo0_l00009ooooo`;o00005oooool2o`0007Sooooo000Looooo`03o`000?oooooooooo06Gooooo
0_l00004ooooo`;o00005_ooool2o`0000Gooooo0_l000000ooooooo0000o`00000<ooooo`;o0000
0_ooool2o`0000[ooooo0_l0000Booooo`;o00003_ooool3o`0007Oooooo000Looooo`03o`000?oo
oooooooo06Oooooo0_l00002ooooo`;o00007Oooool2o`000003ooooool0003o000000;o00000_oo
ool3o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00001oooool7o`0000Kooooo0_l0
0008ooooo`;o00003?ooool2o`000003ooooool0003o000007Oooooo000Looooo`03o`000?oooooo
oooo06Oooooo0_l00002ooooo`;o00001?ooool2o`00013ooooo0_l0000:ooooo`;o00000_ooool3
o`0000;ooooo0_l0000>ooooo`Oo00000oooool2o`000003ooooool0003o000000oooooo0_l00005
ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o0000L?ooool001cooooo00?o0000
ooooooooool0J_ooool2o`0000Gooooo0_l00009ooooo`?o00001?ooool2o`0001?ooooo0_l0000?
ooooo`;o00001oooool2o`000003ooooool0003o000000oooooo0_l00008ooooo`?o000000Cooooo
o`000?l0003ooooo0_l0000>ooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0H_ooool2
o`0000Kooooo0_l0000@ooooo`?o000000?oooooo`000?l000007?ooool3o`0000Oooooo0ol0000:
ooooo`;o00000_ooool3o`0001;ooooo1?l00008ooooo`?o00002_ooool2o`00063ooooo000Loooo
o`03o`000?oooooooooo06;ooooo0_l00004ooooo`Co00001oooool2o`0000_ooooo0_l000000ooo
oooo0000o`00000<ooooo`;o000000?oooooo`000?l000001oooool6o`0000Gooooo0_l0000?oooo
o`?o00004_ooool2o`0000[ooooo0ol0001/ooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o
000000?oooooo`000?l000000_ooool2o`0000Gooooo1_l00009ooooo`?o00000_ooool3o`0000Oo
oooo0_l000000ooooooo0000o`000007ooooo`;o00000_ooool2o`0000Gooooo0_l00002ooooo`;o
00008oooool2o`0000Gooooo0_l0001_ooooo`007?ooool00ol0003oooooooooo`15ooooo`;o0000
4oooool2o`0000Oooooo1?l00003ooooo`Co00001oooool4o`0000Wooooo0_l00003ooooo`?o0000
5Oooool2o`0000[ooooo0ol00007ooooo`;o00001?ooool2o`0000Kooooo0_l00006ooooo`;o0000
1?ooool2o`0000Gooooo0_l0001_ooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00004ooo
ool2o`0000Oooooo1?l00002ooooo`?o00000oooool4o`0001Sooooo0_l0000Booooo`;o00001ooo
ool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o00000_ooool4o`0000Cooooo1?l0
0006ooooo`;o00002oooool2o`000003ooooool0003o000000?ooooo0_l0001Wooooo`007?ooool0
0ol0003oooooooooo`1Uooooo`;o00000_ooool3o`0000?ooooo1_l00003ooooo`;o00001oooool4
o`0000;ooooo0_l00002ooooo`;o00006oooool2o`0000Gooooo0_l00008ooooo`;o00001_ooool2
o`000003ooooool0003o000001Gooooo0_l00002ooooo`?o0000Ioooool001cooooo00?o0000oooo
ooooool0LOooool4o`0000?ooooo0_l00007ooooo`Co000000Coooooo`000?l0003o00001Oooool2
o`000003ooooool0003o000002kooooo0_l000000ooooooo0000o`000006ooooo`Co00003oooool5
o`0006Gooooo000Looooo`;o0000K?ooool2o`0000Oooooo0_l000000ooooooo0000o`000003oooo
o`;o00002?ooool2o`0000Kooooo0_l000000ooooooo0000o`000002ooooo`;o00001_ooool2o`00
00Kooooo0_l000000ooooooo0000o`000006ooooo`;o00003oooool2o`000003ooooool0003o0000
00Kooooo1?l0000@ooooo`Co00001?ooool2o`0005oooooo000Looooo`03o`000?oooooooooo05Ko
oooo0_l000000ooooooo0000o`00000@ooooo`Co00000_ooool8o`0000?ooooo0_l00008ooooo`;o
00001oooool4o`0000;ooooo0_l00006ooooo`;o00001_ooool2o`000003ooooool0003o000000Ko
oooo0_l00005ooooo`Co00002oooool2o`0000;ooooo0_l0000Jooooo`Co0000Goooool001cooooo
00?o0000ooooooooool0E_ooool2o`000003ooooool0003o000000Cooooo0_l0000<ooooo`Oo0000
0_ooool3o`0000[ooooo1?l000000ooooooo0000o`000005ooooo`Co00003oooool2o`0000?ooooo
0ol0000=ooooo`Co00002oooool2o`0000;ooooo0_l0000Dooooo`?o00000oooool2o`0000Cooooo
0_l0001Kooooo`007?ooool00ol0003oooooooooo`1Oooooo`;o00000oooool4o`0000;ooooo1?l0
00000ooooooo0000o`000003ooooo`;o00001_ooool2o`0000Gooooo1ol0000:ooooo`;o00002ooo
ool8o`00013ooooo0_l0000;ooooo`;o00001oooool4o`0000gooooo0ol00005ooooo`;o00000_oo
ool2o`0005_ooooo000Looooo`03o`000?oooooooooo05?ooooo0_l00006ooooo`;o00001oooool5
o`000003ooooool0003o000000?o000000Goooooo`000?l0003o0000ooooo`02o`0000Kooooo0_l0
0008ooooo`;o00003?ooool2o`0000_ooooo1ol00005ooooo`;o00000_ooool2o`0000;ooooo0_l0
000Dooooo`;o00000_ooool4o`0000oooooo0_l000001?oooooo0000o`000?ooool2o`0005oooooo
000Looooo`03o`000?oooooooooo05?ooooo0_l00006ooooo`;o00002_ooool2o`0000;ooooo1?l0
00001?oooooo0000o`000?l0000Cooooo`;o000000?oooooo`000?l000002Oooool2o`0000_ooooo
0_l000000ooooooo0000o`000007ooooo`;o00000_ooool3o`000003ooooool0003o0000017ooooo
0_l000000ooooooo0000o`000006ooooo`;o00003?ooool3o`000003ooooool0003o000000Cooooo
0_l0001Looooo`007?ooool00ol0003oooooooooo`1Sooooo`;o00000_ooool2o`0000?ooooo0_l0
000Hooooo`;o000000?oooooo`000?l000004?ooool2o`0000Cooooo1Ol00007ooooo`;o00000ooo
ool2o`000003ooooool0003o000000gooooo0_l00002ooooo`;o00002Oooool3o`0000_ooooo0_l0
0008ooooo`;o0000G?ooool001cooooo00?o0000ooooooooool0Coooool2o`0001;ooooo0_l0000C
ooooo`;o00001?ooool2o`0000Kooooo1Ol0000>ooooo`Co00000_ooool2o`0000;ooooo0_l00008
ooooo`;o00004oooool4o`0000Kooooo0_l000000ooooooo0000o`000003ooooo`;o00005_ooool4
o`0005Wooooo000Looooo`03o`000?oooooooooo04oooooo0_l0000?ooooo`;o00004?ooool2o`00
00Cooooo0_l00004ooooo`;o00001oooool2o`0000gooooo0_l000000ooooooo0000o`000003o`00
0003ooooool0003o000000;ooooo0ol0000Fooooo`;o00001?ooool2o`0000;ooooo0_l00002oooo
o`Oo00000oooool2o`0000?ooooo0_l0000Aooooo`Co0000FOooool001cooooo00?o0000oooooooo
ool0H?ooool2o`00013ooooo1?l00002ooooo`;o00001oooool2o`000003ooooool0003o000000;o
00000oooool2o`0000Wooooo0_l00003ooooo`?o00001_ooool2o`0001Kooooo0_l00008ooooo`;o
00000_ooool6o`0000Cooooo0_l00003ooooo`;o000000?oooooo`000?l000003Oooool2o`0000;o
oooo0ol00005ooooo`;o0000D?ooool001cooooo00?o0000ooooooooool0BOooool2o`0002;ooooo
0_l00004ooooo`Oo00001?ooool2o`000004ooooool0003o0000ooooo`Co00000oooool3o`0000Oo
oooo0_l00003ooooo`Co00005oooool2o`0001Gooooo0ol0000:ooooo`;o000000?oooooo`000?l0
00003Oooool7o`0000Gooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`19ooooo`;o0000
00?oooooo`000?l000000oooool2o`0000gooooo0_l0000;ooooo`;o00001?ooool5o`0000Cooooo
1Ol00003ooooo`?o000000?oooooo`000?l000000_ooool2o`0000Oooooo0_l00003ooooo`;o0000
1Oooool2o`0000Sooooo0_l00008ooooo`;o00002oooool2o`0000Sooooo0_l00003ooooo`;o0000
0oooool2o`000003ooooool0003o000000;ooooo0_l0000<ooooo`Co00001Oooool2o`0005?ooooo
000Looooo`03o`000?oooooooooo04cooooo0_l00003ooooo`;o00000oooool2o`0000Sooooo0_l0
000;ooooo`;o00001Oooool2o`0000Kooooo0_l000000ooooooo0000o`000002o`000003ooooool0
003o000000;ooooo0_l00002ooooo`;o00000oooool2o`0000Oooooo0_l00005ooooo`Co00001_oo
ool2o`0001Gooooo0_l0000;ooooo`Co00000oooool3o`0000Cooooo0_l00008ooooo`Co00002Ooo
ool2o`0000Wooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`1Fooooo`;o00002_ooool2
o`0000Cooooo0_l00002ooooo`?o000000?oooooo`000?l000003Oooool9o`0000Cooooo1?l00000
1?oooooo0000o`000?ooool2o`0000;ooooo1Ol00006ooooo`;o00003_ooool2o`0001[ooooo0_l0
00000ooooooo0000o`000002ooooo`?o00000_ooool2o`0000?ooooo0_l000001?oooooo0000o`00
0?ooool8o`0000;ooooo0_l0000=ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0H_oo
ool2o`0000Cooooo0_l00002ooooo`?o000000?oooooo`000?l000000_l00007ooooo`;o00000_oo
ool2o`000005ooooool0003o0000o`000?ooool00_l00004ooooo`Co00001?ooool6o`000003oooo
ool0003o000000_ooooo0_l00009ooooo`;o00005?ooool2o`0000Oooooo1_l00003ooooo`;o0000
0oooool5o`000003ooooool0003o000000?ooooo0ol00002ooooo`;o0000Eoooool001cooooo00?o
0000ooooooooool0F_ooool4o`0000gooooo1Ol00002ooooo`;o00001?ooool2o`000005ooooool0
003o0000o`000?ooool00_l000000ooooooo0000o`000003ooooo`Oo00001?ooool6o`00013ooooo
0ol00003ooooo`;o00005oooool4o`0000Wooooo0_l0000:ooooo`?o0000I_ooool001cooooo0_l0
0018ooooo`;o00004Oooool4o`000003ooooool0003o000000[ooooo0_l000000ooooooo0000o`00
0008ooooo`?o000000Coooooo`000?l0003ooooo0_l00005oooooa3o00004oooool2o`0000?ooooo
0_l0000Gooooo`;o00007?ooool2o`0006;ooooo000Looooo`03o`000?oooooooooo04Oooooo0_l0
000Aooooo`;o00000oooool2o`0000?ooooo0ol0000>ooooo`;o00000_ooool2o`0000Sooooo0_l0
00000ooooooo0000o`00000?o`0000;ooooo0_l00009ooooo`;o00000_ooool2o`0003_ooooo0_l0
001Rooooo`007?ooool00ol0003oooooooooo`18ooooo`;o00001_ooool2o`0000Sooooo0ol00007
ooooo`?o00003_ooool2o`0000;ooooo0_l00008ooooo`;o000000?oooooo`000?l000003ol00002
ooooo`?o000000?oooooo`000?l000001?ooool3o`0000;ooooo0_l0000Nooooo`;o00003?ooool2
o`0000cooooo0_l0001Sooooo`007?ooool00ol0003oooooooooo`18ooooo`;o00001_ooool2o`00
00Sooooo0ol0000Cooooo`;o00000oooool2o`0000gooooo2?l000000ooooooo0000o`000007o`00
00Cooooo0_l000000ooooooo0000o`000004ooooo`;o00004?ooool2o`0000[ooooo0_l00005oooo
o`;o00003?ooool2o`0000cooooo0_l0000>ooooo`;o0000Doooool001cooooo00?o0000oooooooo
ool0E?ooool2o`0000gooooo1?l00003ooooo`;o00001?ooool2o`0000?ooooo0ol00004ooooo`;o
00001_ooool8o`000003ooooool0003o000000Oo00007oooool2o`0000[ooooo0_l0000aooooo`;o
0000Doooool001cooooo00?o0000ooooooooool0E?ooool2o`0000Oooooo0_l00004ooooo`Ko0000
00Coooooo`000?l0003ooooo0_l00007ooooo`;o00001?ooool2o`0000Kooooo5?l0000=ooooo`;o
00003Oooool3o`0000Kooooo0_l0000;ooooo`;o00004?ooool4o`0000gooooo0_l0000Pooooo`;o
0000>?ooool001cooooo00?o0000ooooooooool0D_ooool5o`0000Kooooo0_l00005ooooo`;o0000
00Coooooo`000?l0003o00000oooool2o`0000Kooooo0_l0000<oooooaKo00001_ooool3o`0000?o
oooo1Ol0000:ooooo`;o00001oooool2o`0000Kooooo0_l00003ooooo`;o00001?ooool2o`0000[o
oooo1_l00003ooooo`;o00001_ooool2o`00023ooooo0_l0000hooooo`007?ooool00ol0003ooooo
ooooo`1Booooo`;o000000?oooooo`000?l000003?ooool4o`000003ooooool0003o000000_ooooo
0_l0000<oooooaSo00000_ooool5o`0000Gooooo0ol0000Kooooo`;o00002Oooool2o`000003oooo
ool0003o000000Cooooo1?l00003ooooo`;o00000oooool2o`0006;ooooo000Looooo`03o`000?oo
oooooooo04;ooooo0_l00002ooooo`;o00002?ooool6o`0000gooooo1?l00003ooooo`;o00000_oo
ool2o`0000Sooooo0_l00004ooooo`;o00000_oooolIo`0000;ooooo0_l0000>ooooo`;o00002_oo
ool2o`0000?ooooo0_l0000;ooooo`Co000000?oooooo`000?l000000ol00004ooooo`Co00007?oo
ool2o`000003ooooool0003o000004_ooooo000Looooo`03o`000?oooooooooo03kooooo0_l00002
ooooo`;o00000_ooool2o`0000Sooooo0_l000001?oooooo0000o`000?l0000=ooooo`;o00001Ooo
ool2o`0000;ooooo0_l00008ooooo`Co00000_ooool2o`0000;ooooo6Ol00003ooooo`;o000000?o
ooooo`000?l000001?ooool2o`0000Cooooo0_l0000:ooooo`;o00000oooool2o`0000_ooooo1?l0
00001?oooooo0000o`000?l00007ooooo`;o00003_ooool2o`0000gooooo0_l000000ooooooo0000
o`00001;ooooo`007?ooool00ol0003oooooooooo`0nooooo`;o0000:_ooool2o`0000?ooooo0_l0
0009ooooo`Ko00001?oooolIo`000004ooooool0003o0000ooooo`?o00000oooool2o`0000oooooo
0_l00003ooooo`;o00002?ooool2o`00017ooooo0_l0000<ooooo`Co0000GOooool001cooooo00?o
0000ooooooooool0B_ooool2o`0000Wooooo0_l00006ooooo`;o00001Oooool2o`0000Cooooo0ol0
0002ooooo`;o00002Oooool4o`0000Kooooo2?l000000ooooooo0000o`00000>o`0000Cooooo0ol0
0006ooooo`Go00002Oooool2o`0000?ooooo0_l00008ooooo`;o00001?ooool2o`0000?ooooo0_l0
000Dooooo`?o0000G_ooool001cooooo00?o0000ooooooooool0B_ooool2o`0000Wooooo0_l00006
ooooo`?o00001?ooool2o`0000Gooooo0_l0000=ooooo`;o00002_oooolEo`0000Oooooo0_l00006
ooooo`Go00002Oooool4o`00013ooooo0ol00003ooooo`;o00005oooool2o`000003ooooool0003o
000005Wooooo000Looooo`03o`000?oooooooooo05;ooooo0_l0000:ooooo`Co00009?oooolFo`00
00Kooooo0_l00003ooooo`?o00003?ooool2o`0000;ooooo0_l0000@ooooo`;o00001Oooool2o`00
00;ooooo0_l00004ooooo`;o00003?ooool2o`000003ooooool0003o000000_ooooo0_l00002oooo
o`;o0000B?ooool001cooooo00?o0000ooooooooool0>?ooool2o`0001Sooooo0ol00004ooooo`;o
00000oooool4o`0000Cooooo0_l00002ooooo`;o00002_ooool4o`000004ooooool0003o0000o`00
00Wooooo5Ol00004ooooo`?o00001?ooool5o`000003ooooool0003o000000Oooooo0_l00009oooo
o`;o00002_ooool2o`0000?ooooo0ol00002ooooo`;o00001?ooool2o`0000Oooooo0_l0000>oooo
o`;o00000oooool2o`0000;ooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o
00005?ooool3o`000004ooooool0003o0000o`0000Cooooo0_l00003ooooo`;o00001_ooool2o`00
00;ooooo0_l00008ooooo`Ko000000Coooooo`000?l0003o00001Oooool2o`000003ooooool0003o
000001Go00000oooool3o`0000;ooooo0_l00002ooooo`?o000000?oooooo`000?l000003_ooool2
o`0000;ooooo0_l0000:ooooo`;o00000_ooool5o`0000Kooooo0_l00008ooooo`;o000000?ooooo
o`000?l000000_ooool2o`0000Oooooo0_l00003ooooo`?o000000?oooooo`000?l00000B?ooool0
01cooooo0_l0001<ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000Gooooo0_l0000A
ooooo`;o00001_ooool2o`0000gooooo6_l00008ooooo`;o000000?oooooo`000?l000000_l0000@
ooooo`?o00004_ooool2o`000003ooooool0003o000000Kooooo0_l0000;ooooo`;o00000_ooool2
o`0000cooooo0ol0001;ooooo`007?ooool00ol0003oooooooooo`19ooooo`Ko00002_ooool4o`00
00?ooooo1?l00003ooooo`;o00000oooool2o`0000?ooooo0_l000000ooooooo0000o`00000<oooo
o`Co000000?oooooo`000?l000004_l0000=ooooo`Co00001?ooool2o`0000Wooooo0ol0000=oooo
o`;o00004_ooool2o`0000_ooooo0_l00004ooooo`;o00001?ooool3o`0000[ooooo0_l00012oooo
o`007?ooool00ol0003oooooooooo`0oooooo`;o00001oooool4o`000003ooooool0003o000000Co
oooo0_l00002ooooo`;o00000_ooool3o`0000;ooooo1?l00003ooooo`;o00001?ooool2o`0000;o
oooo0_l0000?ooooo`;o00000_ooool2o`000003ooooool0003o000000oo00003?ooool2o`0000;o
oooo0_l00004ooooo`;o00002Oooool3o`0000Oooooo0_l00003ooooo`?o00003_ooool2o`000003
ooooool0003o000000;o00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`;o
00001?ooool3o`0000[ooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`0oooooo`;o0000
1oooool2o`0000Wooooo0_l00002ooooo`;o00000oooool2o`0000Cooooo0_l00009ooooo`;o0000
1?ooool2o`00017ooooo0_l00003ooooo`Go000000?oooooo`000?l000002?l000000ooooooo0000
o`000002ooooo`;o00001?ooool2o`0000oooooo0ol0000;ooooo`?o000000?oooooo`000?l00000
0_l00009ooooo`;o00000oooool2o`000003ooooool0003o000000;o00000oooool2o`0000;ooooo
0_l00007ooooo`;o00003?ooool2o`0004Oooooo000Looooo`03o`000?oooooooooo03[ooooo0_l0
000:ooooo`;o00003?ooool4o`0000Wooooo0ol00008ooooo`;o00001Oooool3o`0000;ooooo0_l0
0007ooooo`;o00002?oooolCo`0000;ooooo0_l0000Eooooo`?o00001?ooool?o`0000Wooooo0_l0
0006ooooo`?o00004Oooool2o`0000Cooooo0_l00005ooooo`Co0000A_ooool001cooooo00?o0000
ooooooooool0>_ooool2o`000003ooooool0003o000000Oooooo0_l0000<ooooo`Oo00001?ooool5
o`0000Sooooo0_l00006ooooo`Ko00001oooool2o`0000[ooooo2?l000001Ooooooo0000o`000?l0
003ooooo00;o00004Oooool2o`0000[ooooo5_l0000?ooooo`?o00001?ooool2o`0000Kooooo0ol0
0003ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`Ko0000AOooool001cooooo00?o
0000ooooooooool0:Oooool2o`0001;ooooo0_l00002ooooo`Co00004_ooool5o`0000;ooooo0ol0
00000ooooooo0000o`00000Aooooo`Ko00004oooool7o`0000cooooo0_l0000:ooooo`Co00002?oo
oolHo`00013ooooo1_l00006ooooo`Co00000_ooool2o`0000Kooooo0_l000000ooooooo0000o`00
0004o`0004Gooooo000Looooo`03o`000?oooooooooo02Wooooo0_l0000Fooooo`Co00001Oooool2
o`0000kooooo0_l00002ooooo`;o00000_ooool2o`0000Oooooo0_l00003ooooo`;o00000oooool2
o`0000;ooooo0ol000000ooooooo0000o`000005ooooo`;o00002?ooool4o`000005ooooool0003o
0000o`000?ooool00_l00008ooooo`;o00003?ooool3o`0000Gooooo2ol000000ooooooo0000o`00
000<o`00013ooooo1Ol00009ooooo`;o0000F?ooool001cooooo00?o0000ooooooooool0@_ooool2
o`0000Kooooo1_l00008ooooo`;o00003Oooool2o`0000;ooooo0_l00003ooooo`;o00002?ooool2
o`000003ooooool0003o000000Gooooo0ol0000:ooooo`;o000000?oooooo`000?l000000ol00005
ooooo`?o00003Oooool4o`0000?ooooo3Ol000000ooooooo0000o`00000<o`0000_ooooo0_l00004
ooooo`;o00009Oooool2o`0003kooooo000Looooo`03o`000?oooooooooo04;ooooo0_l00008oooo
o`Co00002?ooool2o`0000;ooooo0_l00009ooooo`;o00001oooool3o`0000Cooooo0_l000000ooo
oooo0000o`000004ooooo`;o00000oooool2o`000003ooooool0003o000000?ooooo0_l000001?oo
oooo0000o`000?l00003ooooo`?o00000_ooool2o`000004ooooool0003o0000o`0000Oooooo1?l0
0002ooooo`;o000000Coooooo`000?l0003ooooo6ol000001?oooooo0000o`000?l00004ooooo`;o
000000?oooooo`000?l000001?l00002ooooo`;o00004oooool2o`0000Kooooo0_l00008ooooo`;o
0000?_ooool001cooooo00?o0000ooooooooool0@oooool2o`0000;ooooo0_l00004ooooo`;o0000
1?ooool2o`0000Cooooo1_l0000>ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`000003
ooooool0003o000000Cooooo0_l000000ooooooo0000o`000003ooooo`;o00000_ooool3o`000003
ooooool0003o000000Wooooo0_l0000;ooooo`Co00001OoooolRo`0000Cooooo0_l000000ooooooo
0000o`000002ooooo`Go00003oooool4o`000003ooooool0003o000000Kooooo0_l00018ooooo`00
7?ooool00ol0003oooooooooo`13ooooo`;o00000_ooool2o`0000Cooooo0_l00004ooooo`?o0000
0oooool6o`0000;ooooo0_l0000:ooooo`Co00001?ooool2o`0000?ooooo0_l00007ooooo`;o0000
1oooool2o`0001Gooooo0_l000001?oooooo0000o`000?l0000:ooooo`;o00000ooooolKo`0000go
oooo0ol00003ooooo`;o00002_ooool4o`0001Kooooo0_l0000kooooo`007?ooool00ol0003ooooo
ooooo`12ooooo`;o000000?oooooo`000?l000003Oooool2o`0000?ooooo1?l000001?oooooo0000
o`000?ooool2o`0000cooooo0_l00004ooooo`;o00007oooool2o`0000_ooooo0_l000001?oooooo
0000o`000?l00003ooooo`;o00001?ooool3o`000003ooooool0003o000001[o00003?ooool2o`00
00Kooooo0_l00002ooooo`;o00002_ooool2o`0000;ooooo0ol00008ooooo`;o00001Oooool2o`00
03_ooooo000Looooo`03o`000?oooooooooo04;ooooo0_l000000ooooooo0000o`000007ooooo`;o
00000oooool2o`0000Cooooo0_l00003ooooo`;o00000oooool2o`0000?ooooo1?l0000Zooooo`;o
00001oooool2o`0000Oooooo0_l00002ooooo`;o00001?ooool2o`000003ooooool0003o000001_o
00000_ooool2o`0000Sooooo0_l0000:ooooo`;o00002_ooool2o`0000;ooooo0ol00007ooooo`?o
0000@_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@
413oooooooooo`04ooooo`03o`000?oooooooooo04kooooo0_l00003ooooo`;o00003_ooool2o`00
00?ooooo1?l0000Nooooo`Co00004Oooool2o`0000Oooooo0_l00008ooooob3o00000_ooool2o`00
00Sooooo0_l00006ooooo`Co00002Oooool2o`0000oooooo0_l00006ooooo`;o00000_ooool2o`00
03Oooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0B?ooool2o`0000?ooooo0_l00004ooooo`;o00004_ooool2
o`000003ooooool0003o000001kooooo1?l0000;ooooo`;o000000?oooooo`000?l000000_ooool2
o`0000Sooooo0_l00004ooooob;o00002Oooool2o`0000?ooooo0_l00002ooooo`Ko00001?ooool2
o`0000?ooooo0_l00005ooooo`;o00004?ooool3o`000003ooooool0003o000003Oooooo00000ooo
oooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006ooooo`03o`000?oooooooooo
04Sooooo0_l00003ooooo`;o00002?ooool2o`0000;ooooo0ol00009ooooo`;o00008oooool3o`00
0003ooooool0003o000000;o00001Oooool2o`000003ooooool0003o000000;ooooo1Ol00005oooo
o`;o00000_ooool4o`0000;ooooo3ol00002ooooo`co00002_ooool2o`000003ooooool0003o0000
00;o00000_ooool2o`0000;ooooo0_l00004ooooo`?o00002Oooool2o`0000_ooooo0_l00004oooo
o`;o0000>_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?m4A4Co
gMgMooooool00007ooooo`?o0000B?ooool2o`0000_ooooo1?l00002ooooo`?o00001?ooool2o`00
00;ooooo0_l0000Uooooo`;o000000?oooooo`000?l000000_l00005ooooo`;o00001_ooool4o`00
00Wooooo0_l00002oooooaoo00003Oooool4o`0000Kooooo0_l00005ooooo`;o00003Oooool2o`00
00Oooooo0_l00010ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04
omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0;_ooool2o`0000Sooooo0_l0000>oooo
o`;o00001Oooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0000Gooooo0_l00002
ooooo`;o00006Oooool2o`0000Sooooo0_l00009ooooo`;o000000?oooooo`000?l000004oooool2
o`0000;ooooo8?l00002ooooo`;o00000_ooool2o`0000?ooooo0_l0000Dooooo`Co00001oooool3
o`0000Gooooo0_l00011ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:oooo
o`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0;_ooool2o`0000Sooooo0_l0000:oooo
o`;o00001oooool4o`0000?ooooo0_l00002ooooo`?o00002?ooool2o`0001cooooo0_l00008oooo
o`;o00002Oooool2o`000004ooooool0003o0000o`0000Sooooo0_l00008ooooo`;o00000ooooolO
o`0000;ooooo0_l00002ooooo`;o00000oooool2o`00017ooooo0_l000000ooooooo0000o`000002
o`0000Sooooo0_l00005ooooo`;o00002Oooool2o`0003Kooooo00001_ooooooMgMgoiRHV?oooooo
V9RHogMgM`cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0jooooo`;o00002?oo
ool2o`0000Oooooo1?l00003ooooo`;o00000oooool2o`0000Sooooo1?l0000booooo`?o00002?oo
ool2o`0000Wooooo0ol00002oooooaco00002?ooool4o`0001Cooooo1Ol0000Booooo`;o00002?oo
ool4o`0003Cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool0
1_ooool00ol0003oooooooooo`0eooooo`;o00000oooool2o`00017ooooo0_l00004ooooo`?o0000
3oooool2o`00017ooooo0_l0000Zooooo`;o000000?oooooo`000?l000001_ooool3o`0000?ooooo
6ol00002ooooo`;o000000?oooooo`000?l000000oooool2o`0001Kooooo0_l0000;ooooo`;o0000
1_ooool2o`0000[ooooo0_l0000dooooo`007?ooool00ol0003oooooooooo`0Hooooo`;o00006ooo
ool2o`0000Wooooo0_l00003ooooo`?o00001Oooool2o`0000Cooooo0_l0000Sooooo`;o00001Ooo
ool2o`0001;ooooo0_l00003ooooo`Co000000Coooooo`000?l0003ooooo0_l00002ooooo`;o0000
00?oooooo`000?l000001_ooool2o`0000Cooooo3Ol000000ooooooo0000o`00000;o`0000;ooooo
0_l000000ooooooo0000o`000005ooooo`;o00001oooool2o`0000oooooo0_l000001?oooooo0000
o`000?ooool5o`0000Wooooo0_l0000@ooooo`;o0000:oooool001cooooo00?o0000ooooooooool0
6?ooool2o`0002Cooooo1?l00002ooooo`Co00001Oooool2o`0000_ooooo0_l000000ooooooo0000
o`00000=ooooo`;o00004Oooool2o`0001;ooooo0_l00003ooooo`Co000000Coooooo`000?l0003o
oooo0ol000000ooooooo0000o`000009ooooo`;o00001OoooolJo`000003ooooool0003o000000Wo
oooo0_l00007ooooo`;o00003oooool2o`000003ooooool0003o000000Ko00002Oooool2o`00013o
oooo0_l0000[ooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00001_ooool2o`0000Cooooo
0ol00006ooooo`;o00002Oooool4o`000003ooooool0003o000000[ooooo0_l000000ooooooo0000
o`000002ooooo`Co00002oooool3o`0001Sooooo0_l00005ooooo`;o000000?oooooo`000?l00000
3?ooool2o`0000;ooooo3ol000000ooooooo0000o`000003o`0000?ooooo1Ol00007ooooo`Co0000
7?ooool2o`0000_ooooo0_l000000ooooooo0000o`00000mooooo`007?ooool00ol0003ooooooooo
o`0fooooo`;o00003Oooool2o`00017ooooo0ol0000>ooooo`;o00001Oooool4o`000003ooooool0
003o000000?ooooo0_l00004ooooo`Co00002Oooool2o`0000_ooooo0_l00009ooooo`;o00002ooo
ool2o`000003ooooool0003o000000;ooooo5Ol000000ooooooo0000o`000009ooooo`;o00002Ooo
ool4o`0000Gooooo0_l00007ooooo`;o00000oooool2o`0000?ooooo0ol000000ooooooo0000o`00
0003o`0003oooooo000Looooo`03o`000?oooooooooo05Kooooo0ol000000ooooooo0000o`00000:
ooooo`;o00001?ooool2o`0000;ooooo1?l000000ooooooo0000o`000003ooooo`;o00000_ooool2
o`0000;ooooo0_l00009ooooo`;o00005_ooool2o`0000;ooooo0_l00006ooooo`;o00000_ooool3
o`000003ooooool0003o000001?o00003Oooool4o`0000Kooooo1?l00005ooooo`;o00001oooool2
o`0000?ooooo0_l00003ooooo`?o000000Coooooo`000?l0003ooooo0_l0000oooooo`007?ooool0
0ol0003oooooooooo`0mooooo`;o00002Oooool3o`0000Oooooo0_l00002ooooo`Ko00002_ooool2
o`0000Cooooo0_l00002ooooo`;o00003?ooool2o`0000Kooooo0_l00009ooooo`?o00000_ooool2
o`0000Sooooo0_l00007ooooo`;o00001_ooool2o`0000?ooooo1ol000000ooooooo0000o`00000=
o`0000kooooo1?l00007ooooo`;o00001Oooool2o`0000Sooooo0_l00002ooooo`;o00001oooool2
o`000003ooooool0003o0000043ooooo000Looooo`03o`000?oooooooooo03gooooo0_l00004oooo
o`;o00000oooool3o`0000?ooooo0_l000001?oooooo0000o`000?l00004ooooo`;o00003_ooool2
o`0001cooooo0ol00008ooooo`So00000oooool2o`0000;ooooo0_l0000:ooooo`;o000000Cooooo
o`000?l0003o00001_ooool3o`000003ooooool0003o000000;o000000?oooooo`000?l000002Ol0
00000ooooooo0000o`000009ooooo`;o00000_ooool2o`0000Wooooo0_l00003ooooo`?o00002?oo
ool7o`0000Kooooo0_l000000ooooooo0000o`000010ooooo`007?ooool00ol0003oooooooooo`0c
ooooo`;o00002_ooool2o`0000;ooooo0_l00009ooooo`;o000000?oooooo`000?l000005Oooool2
o`0000gooooo1Ol0000;ooooo`;o00002oooool2o`000003ooooool0003o000000Go00003_ooool2
o`000004ooooool0003o0000o`0000Oooooo0_l000000ooooooo0000o`00000:o`000005ooooool0
003o0000o`000?ooool00_l00006ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000
o`000003ooooo`;o00000oooool2o`0000;ooooo0ol00009ooooo`So00001oooool4o`0000oooooo
0_l0000^ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00002_ooool2o`00013ooooo0_l0
000Looooo`;o00001_ooool6o`000003ooooool0003o000000gooooo0_l00005ooooo`;o00000_oo
ool6o`000003ooooool0003o000000?ooooo0_l0000>ooooo`;o00001_ooool8o`000004ooooool0
003o0000o`0000;ooooo0_l00009ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`Co
00001?ooool5o`0000[ooooo0_l00004ooooo`;o00001Oooool6o`0000oooooo0_l0000^ooooo`00
7?ooool00ol0003oooooooooo`0oooooo`;o00004?ooool2o`0001cooooo1?l000000ooooooo0000
o`000002ooooo`;o000000Coooooo`000?l0003ooooo0_l0000:ooooo`Go00001_ooool2o`000003
ooooool0003o000000;ooooo0_l000000ooooooo0000o`000003ooooo`;o00003_ooool2o`0000So
oooo2Ol0000Hooooo`Ko00000_ooool6o`0000Oooooo0_l0000>ooooo`;o00000_ooool2o`0003oo
oooo000Looooo`03o`000?oooooooooo047ooooo0_l00005ooooo`;o00001oooool2o`0000Oooooo
0_l0000Eooooo`oo00000_ooool2o`0000Cooooo1ol00006ooooo`;o00001Oooool2o`000003oooo
ool0003o000002;ooooo0_l0000>ooooo`;o00000_ooool2o`0000Kooooo1ol000000ooooooo0000
o`000004o`0000Oooooo0_l000000ooooooo0000o`00000;ooooo`;o00000_ooool2o`0003oooooo
000Looooo`;o0000>Oooool2o`0000;ooooo0_l00002ooooo`?o00001Oooool2o`0000Sooooo0_l0
0006ooooo`;o00004ooooolBo`000004ooooool0003o0000o`0000?ooooo0_l00003ooooo`;o0000
5oooool2o`0000Gooooo0_l00002ooooo`Co00002oooool5o`0000;ooooo0_l0000:ooooo`;o0000
0_ooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o0000
2Oooool2o`000003ooooool0003o000000Kooooo1?l000000ooooooo0000o`000002ooooo`;o0000
4_ooool2o`0002_ooooo000Looooo`03o`000?oooooooooo03Sooooo0_l00002ooooo`;o00000_oo
ool2o`00013ooooo0_l0000Kooooo`;o00000_ooool4o`0000Cooooo1_l000001?oooooo0000o`00
0?l00003ooooo`;o00007?ooool3o`0000Cooooo0_l00002ooooo`Go00001Oooool2o`0000?ooooo
1?l00003ooooo`;o00003_ooool2o`0000;ooooo0_l000001?oooooo0000o`000?l00003ooooo`Co
00003?ooool2o`0000?ooooo0ol00003ooooo`Co00006Oooool2o`0002_ooooo000Looooo`03o`00
0?oooooooooo02kooooo0_l00005ooooo`;o00000oooool2o`0000Cooooo0_l000000ooooooo0000
o`000005ooooo`;o00001_ooool2o`0000[ooooo0_l00005ooooo`;o000000Coooooo`000?l0003o
00001Oooool5o`000004ooooool0003o0000o`0000;ooooo2Ol00004ooooo`;o00003_ooool2o`00
00Kooooo0_l00005ooooo`;o00002?ooool2o`000003ooooool0003o000000Gooooo1?l00008oooo
o`;o00003Oooool2o`0000Cooooo1Ol00005ooooo`;o00003?ooool8o`0000Gooooo1_l00004oooo
o`;o0000??ooool001cooooo00?o0000ooooooooool09oooool3o`0000Cooooo0_l00005ooooo`;o
000000?oooooo`000?l000000_l00004ooooo`;o000000?oooooo`000?l000001Oooool2o`0001;o
oooo0_l00002ooooo`;o000000?oooooo`000?l000001?l00005ooooo`?o00000oooool>o`0000Wo
oooo0_l00006ooooo`;o000000Coooooo`000?l0003o00001Oooool2o`0000oooooo0_l00009oooo
o`Go00005?ooool5o`0000;ooooo0ol0000Booooo`;o00000_ooool4o`0000Sooooo1_l00004oooo
o`;o0000??ooool001cooooo00?o0000ooooooooool05Oooool2o`00013ooooo0ol0000>ooooo`;o
00001_ooool2o`0000oooooo0_l00009ooooo`;o00001?ooool7o`000004ooooool0003o0000oooo
o`;o00001OoooolCo`000003ooooool0003o000000?ooooo0_l00006ooooo`;o000000?oooooo`00
0?l000000_l00003ooooo`;o00003?ooool2o`00013ooooo0_l0000Booooo`Co000000?oooooo`00
0?l000003Oooool2o`0000Sooooo0_l00003ooooo`;o00001Oooool2o`0000;ooooo0_l00016oooo
o`007?ooool00ol0003oooooooooo`0Eooooo`;o00006oooool3o`0000[ooooo0ol0000?ooooo`;o
00002Oooool2o`0000Kooooo2ol000001?oooooo0000o`000?ooool=o`0000;ooooo1Ol000000ooo
oooo0000o`00000>ooooo`Co00000oooool3o`0000Gooooo0_l00004ooooo`;o00001Oooool2o`00
00;ooooo0_l00005ooooo`Co00000oooool2o`000003ooooool0003o000000Kooooo1Ol000000ooo
oooo0000o`000002o`0000Oooooo1?l000000ooooooo0000o`000005o`000003ooooool0003o0000
00cooooo0_l00004ooooo`;o000000?oooooo`000?l000000_ooool2o`0003gooooo000Looooo`03
o`000?oooooooooo03;ooooo0ol0000:ooooo`;o00003_ooool2o`00013ooooo0_l00002ooooo`;o
000000Coooooo`000?l0003ooooo5Ol000000ooooooo0000o`000006o`0000;ooooo0_l000000ooo
oooo0000o`00000?ooooo`?o00001Oooool2o`0000_ooooo0_l000000ooooooo0000o`000003o`00
00?ooooo1?l00002ooooo`?o000000?oooooo`000?l000001_ooool2o`0000Cooooo1?l00007oooo
o`Co00000oooool5o`000003ooooool0003o000000Gooooo0_l00009ooooo`Co000000?oooooo`00
0?l000000_ooool2o`0003gooooo000Looooo`03o`000?oooooooooo04Kooooo0_l00007ooooo`;o
00003oooool3o`000005ooooool0003o0000o`000?ooool08_l000000ooooooo0000o`000005o`00
00gooooo1Ol000000ooooooo0000o`00000:ooooo`;o00001?ooool5o`0000Oooooo1?l0000@oooo
o`;o00007Oooool2o`0000;ooooo0_l00005ooooo`Ko0000@_ooool001cooooo00?o0000oooooooo
ool0>Oooool3o`0000;ooooo0_l00006ooooo`;o00006?ooool2o`0000;ooooo0_l00004ooooo`;o
000000?oooooo`000?l000006?l000000ooooooo0000o`000008o`0000Gooooo0_l00003ooooo`;o
00001?ooool2o`000003ooooool0003o000000Sooooo1?l000000ooooooo0000o`00000=ooooo`Co
00002Oooool2o`0000oooooo0_l00006ooooo`;o00002?ooool5o`0000;ooooo1?l00005ooooo`Ko
0000@?ooool001cooooo00?o0000ooooooooool0>Oooool3o`0000;ooooo0_l00003ooooo`;o0000
0_ooool2o`0000Wooooo0_l0000?ooooo`Co00001_oooolQo`000004ooooool0003o0000o`0000Go
oooo0_l00003ooooo`Ko00001_ooool2o`0000Gooooo0_l00003ooooo`;o00003_ooool3o`000003
ooooool0003o000000Cooooo1ol0000<ooooo`;o00001_ooool4o`0000Kooooo0ol00004ooooo`Co
00001?ooool3o`0000;ooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0booooo`;o0000
1_ooool2o`0000Oooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00001_ooool2o`0000;o
oooo0_l0000;ooooo`Oo00000oooool2o`000003ooooool0003o000001co00000_ooool2o`0000[o
oooo1_l00006ooooo`;o00006_ooool2o`0000;ooooo0_l00004ooooo`;o00000_ooool5o`0001Co
oooo0_l00007ooooo`;o00001?ooool2o`0000Kooooo0_l00015ooooo`007?ooool00ol0003ooooo
ooooo`0aooooo`?o00001_ooool4o`0000Sooooo0_l000000ooooooo0000o`000003o`0000Sooooo
0_l00008ooooo`;o00001?ooool4o`000003ooooool0003o000001Go00000_ooool7o`0000gooooo
0_l0000^ooooo`;o00001Oooool2o`0000Cooooo0_l0000<ooooo`;o000000?oooooo`000?l00000
1?ooool3o`0000Gooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00002Ooo
ool4o`0000;ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`000?l00000
2?ooool4o`0000Kooooo0_l00002ooooo`?o000000Coooooo`000?l0003ooooo5ol000000ooooooo
0000o`00000:o`0000Wooooo0_l00002ooooo`Go00003?ooool2o`00023ooooo0ol0000Aooooo`Go
00001?ooool4o`0000Sooooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`0Tooooo`;o0000
2Oooool2o`0000Sooooo0_l00003ooooo`;o00000_ooool2o`000004ooooool0003o0000o`0000[o
oooo0_l00004ooooo`;o00001_ooool2o`0000;ooooo1_l000000ooooooo0000o`00000So`0000co
oooo1Ol00008ooooo`;o00000_ooool2o`0000Wooooo0_l0000Fooooo`;o00004_ooool2o`0000Co
oooo0_l00002ooooo`;o00002?ooool2o`0000[ooooo0_l00013ooooo`007?ooool00ol0003ooooo
ooooo`0Tooooo`;o00002Oooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0001Oo
oooo0_l00009ooooo`;o000000Coooooo`000?l0003ooooo5Ol000000ooooooo0000o`00000>o`00
0003ooooool0003o000000Co00001Oooool2o`0000Oooooo0_l00009ooooo`;o00003Oooool2o`00
00gooooo0ol0000Pooooo`;o00004oooool2o`0000?ooooo1?l00011ooooo`007?ooool00ol0003o
ooooooooo`0Rooooo`;o00003oooool2o`000003ooooool0003o000001_ooooo0_l00002ooooo`;o
00001?ooool3o`0000?ooooo0_l000000ooooooo0000o`000002oooooa3o000000?oooooo`000?l0
00003_l00003ooooo`;o00001Oooool2o`0000_ooooo0_l0000Booooo`;o00001?ooool3o`000003
ooooool0003o000000Gooooo0ol0000Uooooo`;o00001oooool2o`0000Gooooo0ol000001?oooooo
0000o`000?ooool2o`00047ooooo000Looooo`;o00008oooool2o`0001;ooooo0ol00004ooooo`;o
00003_ooool2o`0000Cooooo0_l00002ooooo`;o00001?ooool3o`0000?ooooo0_l000000ooooooo
0000o`000002oooooa?o000000?oooooo`000?l000002ol00003ooooo`Co00004?ooool2o`0000?o
oooo0_l00007ooooo`;o00001?ooool4o`0000;ooooo0ol000000ooooooo0000o`000004o`0000_o
oooo1_l0000:ooooo`;o00003?ooool2o`0000Oooooo0_l00005ooooo`Ko00002Oooool2o`0003Wo
oooo000Looooo`03o`000?oooooooooo03Kooooo0ol00002ooooo`Co00000_ooool2o`0000[ooooo
0_l00004ooooo`;o00001oooool3o`0000Cooooo6_l000000ooooooo0000o`00000Bo`0000cooooo
0_l00003ooooo`Ko00001oooool2o`0000Kooooo0_l00004ooooo`[o00002Oooool6o`0000Sooooo
1?l00002ooooo`;o000000?oooooo`000?l000000_l0000<ooooo`;o00001oooool2o`0000_ooooo
0_l0000iooooo`007?ooool00ol0003oooooooooo`0kooooo`;o00001?ooool2o`00013ooooo0_l0
0007ooooo`;o00001_ooool7o`000003ooooool0003o0000023o00004?ooool4o`000003ooooool0
003o000000;o000000?oooooo`000?l000001Oooool2o`000003ooooool0003o000000Cooooo0_l0
00000ooooooo0000o`00000;o`0000gooooo0_l00008ooooo`;o00001?ooool2o`000003ooooool0
003o000000;o00001_ooool2o`0000Cooooo0_l00005ooooo`;o00000oooool4o`00047ooooo000L
ooooo`03o`000?oooooooooo03gooooo0_l00002ooooo`;o00000oooool2o`0001[ooooo1?l00003
ooooob?o00000_ooool2o`0000?ooooo0ol00005ooooo`;o00000oooool2o`0000Kooooo0_l00005
ooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000;o00000oooool2
o`000004ooooool0003o0000o`0000?ooooo0_l00006ooooo`;o00001_ooool2o`0000kooooo0_l0
0003ooooo`Co00002?ooool2o`000003ooooool0003o000000?ooooo1?l00004ooooo`;o0000>ooo
ool001cooooo00?o0000ooooooooool05oooool2o`0000Kooooo0_l0000?ooooo`;o00000oooool2
o`0000Kooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l0000Aooooo`;o00001oooool4
o`0000;ooooo:_l000001?oooooo0000o`000?l00003ooooo`Co00000oooool2o`0000Cooooo0ol0
0006ooooo`;o00000oooool2o`0000Oooooo0ol00002ooooo`;o00000oooool2o`0000;ooooo0_l0
0006ooooo`;o00001_ooool2o`0000Wooooo0_l00003ooooo`;o00000oooool2o`0000[ooooo1_l0
000:ooooo`;o0000>oooool001cooooo00?o0000ooooooooool05oooool2o`0000Kooooo1?l0000=
ooooo`;o00000oooool2o`0000gooooo0_l00003ooooo`;o00000oooool2o`0000Oooooo1Ol00009
ooooo`;o000000?oooooo`000?l000009?l00002ooooo`;o00001?ooool2o`000003ooooool0003o
000000Cooooo0_l00005ooooo`Co00000oooool4o`000003ooooool0003o000000;o00002?ooool2
o`0000Gooooo1?l00004ooooo`;o00002Oooool2o`0000cooooo0_l00003ooooo`;o000000?ooooo
o`000?l000003_ooool4o`000003ooooool0003o000000[ooooo0_l0000hooooo`007?ooool00ol0
003oooooooooo`0Qooooo`;o00004oooool2o`0000cooooo0_l000000ooooooo0000o`000002o`00
00?ooooo0_l00007ooooo`Go00002OoooolHo`000003ooooool0003o000000_o000000?oooooo`00
0?l000002?ooool2o`000003ooooool0003o000000Cooooo0_l00007ooooo`;o00000oooool2o`00
00?ooooo1?l00009ooooo`;o00001?ooool4o`0000Cooooo0_l000000ooooooo0000o`000006oooo
o`;o00005?ooool2o`0000[ooooo0_l00002ooooo`;o00000oooool2o`0000Gooooo0_l00003oooo
o`;o0000>?ooool001cooooo00?o0000ooooooooool0<?ooool2o`0000Cooooo0_l00003ooooo`;o
00001oooool5o`00013ooooo0_l00008ooooobko00000_ooool2o`0000Cooooo0_l00002ooooo`;o
000000?oooooo`000?l000004_ooool2o`0000Wooooo0ol00003ooooo`Co00001oooool3o`0001?o
oooo0_l00006ooooo`;o00002_ooool2o`0000;ooooo0_l0000:ooooo`;o0000?Oooool001cooooo
00?o0000ooooooooool0<?ooool2o`0000Gooooo0ol000000ooooooo0000o`000009ooooo`?o0000
4?ooool2o`0000;ooooo0_l00004ooooo`;o00000oooool]o`0000Gooooo0_l000000ooooooo0000
o`000003o`0001;ooooo0_l0000:ooooo`;o00001_ooool2o`0000Oooooo0_l00009ooooo`;o0000
0_ooool2o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`;o00000oooool2o`0001Cooooo
0_l0000Aooooo`;o0000:oooool001cooooo00?o0000ooooooooool0<?ooool2o`0000Cooooo1?l0
000=ooooo`;o00000_ooool3o`0000oooooo0_l00005ooooo`;o00000_oooolLo`000003ooooool0
003o000000co000000?oooooo`000?l000001?ooool2o`0000;ooooo0_l00007ooooo`;o00002Ooo
ool6o`00013ooooo0_l00004ooooo`;o000000?oooooo`000?l000002Oooool2o`0000;ooooo1?l0
0005ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o00001oooool2o`0000Cooooo0_l0
0005ooooo`?o00004?ooool2o`0002_ooooo000Looooo`03o`000?oooooooooo01_ooooo0_l0000I
ooooo`;o00002?ooool3o`0000?ooooo0_l00003ooooo`?o00004Oooool2o`0000?ooooo7?l00000
0ooooooo0000o`00000:o`0000?ooooo0_l00002ooooo`;o00001?ooool2o`0000?ooooo0ol00005
ooooo`;o00001oooool4o`0000;ooooo0_l0000>ooooo`?o000000?oooooo`000?l000000_ooool6
o`0000;ooooo0_l0000:ooooo`;o00002?ooool4o`0000?ooooo0_l00002ooooo`;o000000?ooooo
o`000?l000000_l00004ooooo`Co00001?ooool2o`0003gooooo000Looooo`03o`000?oooooooooo
01_ooooo0_l0000Eooooo`;o00002_ooool5o`0000?ooooo0_l00002ooooo`;o00004oooool2o`00
00Gooooo0ol000000ooooooo0000o`000008o`0000;ooooo7Ol00007ooooo`;o00000oooool3o`00
00gooooo1?l0000@ooooo`;o000000Goooooo`000?l0003o0000ooooo`0>o`0000;ooooo1Ol00004
ooooo`;o00002?ooool2o`0000Sooooo0_l000000ooooooo0000o`000008ooooo`;o00005_ooool2
o`0002_ooooo000Looooo`03o`000?oooooooooo03;ooooo0_l0000:ooooo`;o00002_ooool4o`00
01Kooooo1?l00002oooooaWo00000_ooool>o`0000cooooo0_l0000>ooooo`;o00003?ooool2o`00
00Cooooo0_l000001?oooooo0000o`000?l00002ooooo`_o000000Coooooo`000?l0003ooooo1Ol0
0004ooooo`;o00002?ooool2o`0001Kooooo0_l00002ooooo`;o00001Oooool4o`0000Sooooo0_l0
000[ooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00001?ooool2o`0000gooooo0_l0000?
ooooo`;o00001Oooool3o`0000;ooooo0ol000000ooooooo0000o`00000Lo`000003ooooool0003o
000000;o00003oooool4o`0001Kooooo0_l00002ooooo`Co00001?ooool4o`0000;ooooo1?l00000
0ooooooo0000o`000004o`000004ooooool0003o0000o`0000Gooooo0_l0000Tooooo`Ko00001Ooo
ool4o`0003Gooooo000Looooo`03o`000?oooooooooo03Oooooo0_l00004ooooo`;o00002Oooool2
o`00017ooooo1?l0000:ooooo`;o00000_oooolNo`000003ooooool0003o000000Go00001oooool2
o`0000Gooooo0_l0000>ooooo`;o00001_ooool2o`0000Cooooo0_l00004ooooo`;o00000oooool@
o`0000Gooooo0_l0000Vooooo`Co0000?_ooool001cooooo00?o0000ooooooooool08oooool2o`00
02?ooooo0_l0000;ooooo`;o00001?ooool2o`0000Oooooo0_l00006ooooo`_o000000?oooooo`00
0?l000001?l000000ooooooo0000o`00000:o`0000;ooooo1_l00003ooooo`;o00000_ooool2o`00
00Gooooo0_l00007ooooo`Co00000oooool2o`0000[ooooo0_l00003ooooo`;o00001_ooool?o`00
00cooooo0_l00007ooooo`;o00001?ooool2o`0000gooooo0_l00002ooooo`?o0000?oooool001co
oooo0_l0000Tooooo`;o00009?ooool2o`0000[ooooo1?l0000;ooooo`;o00001_ooool;o`000003
ooooool0003o000001;o00000oooool5o`0000;ooooo0_l00009ooooo`;o00001oooool4o`0000Co
oooo0_l00006ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0000Cooooo4ol00004oooo
o`;o00001?ooool2o`0000Oooooo0_l00004ooooo`;o00000oooool2o`0000Sooooo0_l00003oooo
o`;o00002Oooool2o`0003Cooooo000Looooo`03o`000?oooooooooo03Wooooo0_l00002ooooo`;o
00002_ooool2o`0000cooooo0_l0000=ooooob?o000000?oooooo`000?l000000_ooool6o`000003
ooooool0003o000000?ooooo0_l00005ooooo`;o00003_ooool3o`0000Gooooo0ol00002ooooo`;o
00001_oooolGo`0000;ooooo1Ol00005ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Go
oooo1?l00008ooooo`;o00002oooool2o`000003ooooool0003o000000Cooooo0_l0000^ooooo`00
7?ooool00ol0003oooooooooo`0iooooo`;o00000_ooool2o`0000Gooooo0_l00009ooooo`;o0000
3_ooool4o`0000?ooooo2Ol000000ooooooo0000o`00000Ho`0000Cooooo1?l00003ooooo`;o0000
0oooool2o`0000Gooooo1Ol00003ooooo`;o000000?oooooo`000?l000000oooool2o`000003oooo
ool0003o000000?ooooo0_l00007ooooo`;o000000?oooooo`000?l000006Ol000001?oooooo0000
o`000?l00005ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Gooooo0_l0000<ooooo`;o
00002Oooool2o`0000Oooooo0_l0000^ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o0000
1Oooool8o`0000Gooooo0_l00005ooooo`Co000000?oooooo`000?l000001?oooolPo`000004oooo
ool0003o0000ooooo`Co00003_ooool6o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`Co
000000?oooooo`000?l000001oooool2o`000003ooooool0003o000000So000000?oooooo`000?l0
00004?l0000<ooooo`;o00005Oooool2o`0000Wooooo0_l0000gooooo`007?ooool00ol0003ooooo
ooooo`0iooooo`;o00002oooool2o`0000?ooooo1?l00002ooooo`;o00001Oooool2o`0000Cooooo
0_l00004ooooo`;o00000oooool3o`000003ooooool0003o000001[o000000?oooooo`000?l00000
1_l0000>ooooo`;o000000?oooooo`000?l000004Oooool2o`0000oooooo5_l00002ooooo`?o0000
3?ooool2o`0000Oooooo0_l0000@ooooo`;o00001?ooool3o`0003Oooooo000Looooo`03o`000?oo
oooooooo01gooooo0_l0000Jooooo`Co00002Oooool2o`0000Cooooo0_l00007ooooo`;o00001_oo
ool3o`0000Kooooo2Ol000000ooooooo0000o`00000Fo`000003ooooool0003o000000Oo00005ooo
ool2o`0000?ooooo0_l0000FoooooaSo000000?oooooo`000?l000004?ooool2o`0000Cooooo0_l0
0006ooooo`Co00001_ooool2o`0000Cooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0K
ooooo`Co00007?ooool2o`0000_ooooo0_l0000;ooooo`;o00001_ooool3o`0000Kooooo1?l00002
ooooo`co000000?oooooo`000?l000002_l00002ooooo`_o00003_ooool2o`0000Oooooo0_l00003
ooooo`;o00005_oooolHo`000003ooooool0003o0000013ooooo0_l0000<ooooo`Co0000A_ooool0
01cooooo00?o0000ooooooooool06oooool2o`0000_ooooo0_l0000Mooooo`?o00002Oooool4o`00
00?ooooo0_l00002ooooo`;o00002?ooool4o`000004ooooool0003o0000o`0000;ooooo1?l00002
ooooo`go000000?oooooo`000?l000000_l00006ooooo`;o00003_ooool2o`0002Cooooo3ol00000
0ooooooo0000o`000007o`0000;ooooo0_l0000Cooooo`;o00005Oooool2o`0003[ooooo000Loooo
o`03o`000?oooooooooo02Sooooo0_l0000Mooooo`;o00002_ooool2o`0000Gooooo0_l00002oooo
o`;o00002?ooool9o`000003ooooool0003o000000Cooooo3Ol000000ooooooo0000o`000002o`00
00;ooooo1_l00003ooooo`;o00001_ooool2o`0002Oooooo3Ol000000ooooooo0000o`00000=o`00
01?ooooo0_l0000Booooo`;o000000?oooooo`000?l00000>_ooool001cooooo00?o0000oooooooo
ool0>Oooool2o`0002gooooo0_l00002ooooo`_o000000?oooooo`000?l000001?l000000ooooooo
0000o`000008o`0000?ooooo1?l00005ooooo`;o00001Oooool4o`0000Gooooo0_l0000Aooooo`;o
00001_ooool2o`0000Cooooo7Ol00003ooooo`;o00003_ooool2o`0001;ooooo0_l000000ooooooo
0000o`000002o`0003Sooooo000Looooo`03o`000?oooooooooo02Gooooo0_l0000Booooo`;o0000
3?ooool2o`0000Wooooo0_l0000Cooooo`;o000000?oooooo`000?l000000_ooool9o`0000;ooooo
0ol00004ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o00004?ooool4o`0000Gooooo
0_l00005ooooo`;o00000_ooool3o`0000Gooooo0_l00004ooooo`Co00001?oooolIo`0000;ooooo
0_l00003ooooo`;o00002_ooool2o`000004ooooool0003o0000o`0001Gooooo1?l0000hooooo`00
7?ooool00ol0003oooooooooo`0Uooooo`;o00002_ooool2o`0001Cooooo0_l00009ooooo`?o0000
4_ooool2o`000003ooooool0003o000000?ooooo1ol00003ooooo`;o00001?ooool2o`0000;ooooo
0_l000001Ooooooo0000o`000?l0003ooooo00;o00003Oooool2o`0000[ooooo0_l00005ooooo`;o
00000_ooool3o`0000Kooooo0_l00003ooooo`;o00001_oooolIo`0000;ooooo0_l00002ooooo`;o
00002oooool2o`000003ooooool0003o000000?ooooo0_l0000Booooo`;o0000>Oooool001cooooo
00?o0000ooooooooool0<Oooool2o`0000Kooooo0_l000000ooooooo0000o`000006ooooo`;o0000
3?ooool3o`0000Cooooo0ol00004ooooo`;o00002?ooool2o`0000Kooooo0ol00005ooooo`;o0000
0oooool3o`000003ooooool0003o000000Co00003Oooool2o`000003ooooool0003o000000;ooooo
0_l0000Eooooo`;o00000oooool2o`0000Sooooo0_l000000ooooooo0000o`00000Fo`0000Oooooo
0_l0000>ooooo`;o00000oooool2o`0001;ooooo0_l0000iooooo`007?ooool00ol0003ooooooooo
o`0booooo`;o00001Oooool2o`000003ooooool0003o000000Kooooo0_l0000:ooooo`;o00001?oo
ool2o`000004ooooool0003o0000o`0000Cooooo0_l0000Aooooo`Go000000Coooooo`000?l0003o
00000oooool@o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000002ooooo`;o
00003oooool2o`0000Cooooo0_l00002ooooo`;o00002Oooool2o`0000?ooooo1?l000000ooooooo
0000o`00000?o`00013ooooo0_l0000;ooooo`;o00001?ooool2o`0000Cooooo0ol00006ooooo`;o
0000=oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^oc8b
<_l0003o410@olc<c006ooooo`03o`000?oooooooooo03;ooooo0_l00005ooooo`;o00005Oooool2
o`0000Cooooo0_l00009ooooo`;o00002_ooool2o`0000Cooooo1Ol000000ooooooo0000o`000006
ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000004o`000003ooooool0003o
000000kooooo0_l0000<ooooo`;o00001?ooool2o`0000;ooooo0ol0000>oooooaOo00003_ooool2
o`0000_ooooo0_l00003ooooo`?o00000_ooool6o`0000Gooooo0_l0000gooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo
00?o0000ooooooooool0<Oooool2o`0000kooooo0ol0000Booooo`;o00002Oooool6o`0000;ooooo
0_l00002ooooo`;o00001?ooool3o`0000Gooooo0_l000000ooooooo0000o`000004ooooo`Ko0000
0oooool2o`0000_ooooo0_l00003ooooo`?o00002_ooool2o`0000Gooooo0_l00004ooooo`;o0000
0_ooool2o`0000Gooooo0_l00003oooooaOo00001Oooool2o`0000Wooooo0_l00008ooooo`;o0000
1?ooool2o`0000?ooooo0_l00002ooooo`;o0000?_ooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
9Oooool2o`0000Cooooo0_l00004ooooo`;o00003_ooool3o`0000Cooooo0_l00004ooooo`;o0000
00?oooooo`000?l000002oooool2o`0000;ooooo1Ol00002ooooo`;o00002?ooool2o`0000;ooooo
1_l000000ooooooo0000o`000008ooooo`?o00003oooool4o`000004ooooool0003o0000o`0000Wo
oooo0ol00005ooooo`;o00002?ooool2o`0000Gooooo0_l00003oooooaGo00001oooool2o`0000;o
oooo0_l00005ooooo`;o000000?oooooo`000?l000001Oooool2o`0004gooooo00000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o
00009Oooool2o`0000Cooooo0_l00006ooooo`;o00002_ooool2o`0000?ooooo0_l00002ooooo`;o
00001?ooool2o`000003ooooool0003o000000_ooooo0_l00005ooooo`?o00003oooool4o`0000Go
oooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00005ooooo`;o00000oooool4o`0000;o
oooo0_l00009ooooo`;o00003_ooool4o`0000?ooooo0_l00005ooooo`;o000000?oooooo`000?l0
00003Ol00002ooooo`;o000000?oooooo`000?l000001oooool2o`0000Gooooo0_l000000ooooooo
0000o`000004ooooo`;o00002_ooool2o`0000Sooooo0_l0000hooooo`0000?oooooo`000?ooool0
0_ooool00ol0003oooooooooo`09ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003o
ooooooooo`0cooooo`;o00002_ooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o
00000oooool2o`0001Cooooo0_l0000Gooooo`?o00000oooool5o`0000Cooooo0_l00005ooooo`;o
00000oooool2o`0000?ooooo0_l00003ooooo`;o00002_ooool4o`0000Cooooo0_l000000ooooooo
0000o`000002o`0000?ooooo0_l00005ooooo`;o00000_ooool?o`000004ooooool0003o0000oooo
o`;o00005Oooool4o`0000Wooooo0ol00006ooooo`Co0000>?ooool00003ooooool@413ooooo00;o
oooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo03co
oooo0_l00009ooooo`;o00000_ooool2o`0000?ooooo0ol0000Fooooo`;o00001Oooool2o`0000Wo
oooo0_l00002ooooo`;o00001?ooool6o`0000?ooooo0_l0000?ooooo`;o00000_ooool3o`0000[o
oooo1?l00004ooooo`;o00000_ooool3o`0000;ooooo0_l000000ooooooo0000o`000005oooooa?o
00006Oooool2o`0000_ooooo0_l00005ooooo`Co0000>_ooool00006oooooomgMgOoV9RHoooooonH
V9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo03Oooooo0_l00003oooo
o`;o00002oooool2o`0000Kooooo0_l0000Fooooo`;o00001Oooool2o`0000Wooooo0_l0000<oooo
o`;o00000_ooool3o`0000oooooo0ol000001?oooooo0000o`000?l0000<ooooo`;o00002?ooool3
o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo4ol0000]ooooo`;o0000??oo
ool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03
o`000?oooooooooo03Oooooo0_l0000@ooooo`;o00003?ooool2o`0001kooooo0_l00007ooooo`Co
00002Oooool2o`000003ooooool0003o000000kooooo0_l00007ooooo`;o000000?oooooo`000?l0
00000oooool3o`0000oooooo0_l00002ooooo`?o00001?ooool2o`0000;ooooo2_l00007ooooo`;o
00002Oooool2o`0000;ooooo0_l0000>ooooo`;o00001oooool2o`0003cooooo000Looooo`03o`00
0?oooooooooo03;ooooo0_l00004ooooo`;o00000_ooool2o`0000Cooooo0_l00003ooooo`;o0000
1oooool2o`0000Gooooo0_l00005ooooo`;o00005oooool2o`000004ooooool0003o0000o`0000?o
oooo1?l00005ooooo`;o00001Oooool2o`0000Cooooo1?l00009ooooo`;o00001?ooool5o`0000?o
oooo0_l0000?ooooo`?o00000oooool2o`0000Cooooo4?l00005ooooo`Co00000_ooool3o`0000;o
oooo0_l00002ooooo`;o00002Oooool4o`000003ooooool0003o000000Oooooo0_l0000looooo`00
7?ooool00ol0003oooooooooo`0booooo`;o00001?ooool2o`0000;ooooo0_l00003ooooo`?o0000
0oooool2o`0000Oooooo0_l0000<ooooo`;o00006_ooool4o`0000_ooooo0_l00005ooooo`[o0000
1Oooool2o`0000;ooooo0_l00004ooooo`?o000000?oooooo`000?l000002Oooool2o`0000Sooooo
0_l0000;ooooo`oo00001oooool2o`0000;ooooo0ol000000ooooooo0000o`00000<ooooo`Ko0000
0oooool2o`0004?ooooo000Looooo`03o`000?oooooooooo047ooooo0_l000000ooooooo0000o`00
0003ooooo`Go000000?oooooo`000?l00000:oooool3o`000003ooooool0003o0000013ooooo1?l0
00001?oooooo0000o`000?l00005ooooo`;o00002?ooool2o`0000;ooooo0_l00008ooooo`?o0000
5_ooool2o`000003ooooool0003o000000?o00000_ooool3o`0000Sooooo0_l00006ooooo`;o0000
1?ooool5o`0000?ooooo0_l00007ooooo`;o00002Oooool2o`0003Sooooo000Looooo`03o`000?oo
oooooooo03?ooooo0_l0000>ooooo`?o000000?oooooo`000?l000001Ol000000ooooooo0000o`00
000/ooooo`Go00001_ooool2o`000003ooooool0003o000000So00000oooool3o`000003ooooool0
003o000000?o00003?ooool2o`0000Sooooo0_l00006ooooo`;o00002Oooool5o`0000Cooooo1_l0
00000ooooooo0000o`000002o`0001Gooooo1Ol0000;ooooo`;o00002_ooool2o`0003Sooooo000L
ooooo`03o`000?oooooooooo03?ooooo0_l00008ooooo`;o00001?ooool2o`0000;ooooo0_l00006
ooooo`;o00003?ooool4o`0001gooooo0_l00007ooooo`?o000000?oooooo`000?l000002Ol00002
ooooo`?o000000?oooooo`000?l000000_l0000=ooooo`;o00001?ooool2o`0000[ooooo0_l00009
ooooo`Go00001Oooool2o`000003ooooool0003o000000?ooooo0ol000000ooooooo0000o`000004
ooooo`;o00006oooool3o`0004?ooooo000Looooo`03o`000?oooooooooo02oooooo0_l0000<oooo
o`;o00002?ooool2o`0000Sooooo0_l0000:ooooo`Co00009Oooool3o`0000;ooooo1?l00002oooo
o`Oo000000?oooooo`000?l000003_ooool2o`0000Sooooo1?l000001?oooooo0000o`000?l0000;
ooooo`;o00000_ooool2o`0000?ooooo0ol00003ooooo`Co00001?ooool5o`0000Cooooo0_l00004
ooooo`;o00002oooool2o`0000Wooooo0_l00005ooooo`?o0000>oooool001cooooo00?o0000oooo
ooooool0;oooool2o`0001cooooo0_l000001?oooooo0000o`000?l0000cooooo`;o00000oooool>
o`0000;ooooo1?l00009ooooo`?o00002?ooool4o`000005ooooool0003o0000o`000?ooool00_l0
0008ooooo`;o00001oooool3o`0000;ooooo0ol00007ooooo`?o00000_ooool2o`0000Oooooo0_l0
0003ooooo`;o00001_ooool2o`0000;ooooo0_l0000<ooooo`?o0000>oooool001cooooo00?o0000
ooooooooool0@oooool3o`0000?ooooo0ol000001?oooooo0000o`000?ooool3o`0003Wooooo3_l0
00000ooooooo0000o`000004o`0000Oooooo0ol0000Aooooo`;o00002?ooool2o`0000cooooo0_l0
0009ooooo`;o00000_ooool2o`0000_ooooo1?l00009ooooo`;o0000B_ooool001cooooo00?o0000
ooooooooool0?Oooool9o`0000;ooooo1Ol000000ooooooo0000o`000006ooooo`;o0000=?ooool2
o`0000?ooooo4_l0000>ooooo`;o00002_ooool2o`000003ooooool0003o000000gooooo0_l00009
ooooo`;o00001Oooool2o`0000gooooo1?l0001Eooooo`007?ooool00ol0003oooooooooo`0moooo
o`Ko00001?ooool3o`000003ooooool0003o000000?o00001_ooool2o`0002kooooo0_l00005oooo
oa;o000000Coooooo`000?l0003o00000oooool2o`0000Wooooo0_l0000:ooooo`;o000000?ooooo
o`000?l000001Oooool2o`0000Kooooo0_l00009ooooo`;o00001Oooool2o`0001cooooo0_l00018
ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o000000?oooooo`000?l000000_ooool2o`00
00Cooooo0_l0000@ooooo`Co00006?ooool2o`0000Wooooo0_l00004ooooo`Go00000_ooool;o`00
0003ooooool0003o000000;o000000?oooooo`000?l000000_l00003ooooo`;o00003Oooool2o`00
0003ooooool0003o000000Kooooo1?l0000@ooooo`;o00001?ooool4o`0000cooooo0_l00002oooo
o`Co00002?ooool3o`0004Oooooo000Looooo`;o0000A?ooool2o`0001[ooooo1?l0000Hooooo`;o
00003ooooolGo`000003ooooool0003o000000;o00000oooool2o`0000;ooooo0_l00004ooooo`;o
00000oooool2o`0000Cooooo0_l00003ooooo`;o00002?ooool2o`0000;ooooo0_l00004ooooo`;o
00000_ooool6o`0000cooooo0_l00002ooooo`Co00002Oooool2o`0004Oooooo000Looooo`03o`00
0?oooooooooo043ooooo0_l00002ooooo`;o00000_ooool2o`0001[ooooo0_l0000Iooooo`;o0000
3?ooool2o`000003ooooool0003o0000017o000000?oooooo`000?l000000_l00007ooooo`;o0000
1?ooool2o`0000Wooooo0_l00005ooooo`;o00001_ooool2o`0000;ooooo0_l00008ooooo`?o0000
6_ooool2o`0004gooooo000Looooo`03o`000?oooooooooo03[ooooo0_l00004ooooo`;o00000_oo
ool2o`0000;ooooo0_l0000Jooooo`;o00005oooool4o`0000cooooo6Ol00009ooooo`;o00001?oo
ool2o`0000?ooooo0_l0000;ooooo`;o00001?ooool2o`0000gooooo1?l00006ooooo`;o00001ooo
ool2o`000003ooooool0003o000000Kooooo1?l0001;ooooo`007?ooool00ol0003oooooooooo`0j
ooooo`;o00003_ooool2o`0001Kooooo0_l0000Iooooo`;o00002Oooool2o`0000Cooooo5ol00002
ooooo`;o00001oooool2o`000004ooooool0003o0000o`0000Cooooo0_l0000<ooooo`;o00000ooo
ool4o`0000;ooooo1?l00005ooooo`;o00002?ooool2o`0000Oooooo0_l000000ooooooo0000o`00
0008ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0B_ooool2o`0001Kooooo1?l0000I
ooooo`;o00001oooool2o`0000?ooooo5_l000000ooooooo0000o`000005o`0000Gooooo0_l00000
1?oooooo0000o`000?l00002ooooo`;o00003_ooool2o`0000?ooooo1?l00002ooooo`Co00001Ooo
ool2o`0000Wooooo0_l0000<ooooo`;o00001oooool2o`0000;ooooo0_l00015ooooo`007?ooool0
0ol0003oooooooooo`13ooooo`?o00000_ooool2o`00017ooooo0_l00007ooooo`;o00006Oooool2
o`0000cooooo7_l00002ooooo`;o00000_ooool2o`0000Gooooo0_l000000ooooooo0000o`000003
ooooo`;o00003Oooool2o`0000Gooooo0_l00004ooooo`;o00002?ooool3o`0000cooooo0_l00007
ooooo`;o00000_ooool2o`0004Gooooo000Looooo`03o`000?oooooooooo047ooooo1_l000000ooo
oooo0000o`00000Aooooo`;o00001_ooool2o`0001Cooooo0_l0000@oooooa_o00001oooool8o`00
00Kooooo0_l00003ooooo`;o00002oooool4o`0000Cooooo1?l00003ooooo`;o00002?ooool4o`00
00?ooooo0_l0000?ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0@Oooool2o`0000;o
oooo0_l00006ooooo`;o00003Oooool2o`0000Gooooo0_l00003ooooo`;o00003oooool2o`0000oo
oooo7_l00007ooooo`;o00000_ooool2o`0001Sooooo0_l00006ooooo`Co00001oooool2o`0000Ko
oooo0_l00003ooooo`;o00001_ooool2o`0000;ooooo0_l00003ooooo`;o0000BOooool001cooooo
00?o0000ooooooooool0AOooool2o`0000Kooooo0_l0000=ooooo`;o000000?oooooo`000?l00000
1Oooool5o`0001Cooooo1?l00007ooooo`;o000000?oooooo`000?l000005Ol000001?oooooo0000
o`000?l00005ooooo`Co00002Oooool2o`0002Cooooo0_l00003ooooo`;o00001?ooool4o`0000Ko
oooo0_l00002ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0@?ooool2o`0000?ooooo
0_l0000Hooooo`;o00001Oooool5o`0001Cooooo1?l00007ooooo`Co000000?oooooo`000?l00000
6?l00004ooooo`Co00002Oooool2o`0002Wooooo0ol00003ooooo`Co00001_ooool2o`0005;ooooo
000Looooo`03o`000?oooooooooo043ooooo0_l0000:ooooo`;o00000_ooool2o`0001Kooooo0_l0
000Poooooaoo00004?ooool2o`0001cooooo0_l0000<ooooo`?o00002oooool2o`0005Cooooo000L
ooooo`03o`000?oooooooooo03_ooooo0_l0000>ooooo`?o00000_ooool2o`0000Sooooo0_l0000=
ooooo`;o000000?oooooo`000?l000003Oooool2o`0000Cooooo0_l0000;oooooa_o00004?ooool3
o`0001_ooooo0_l0000<ooooo`;o00003?ooool3o`0001?ooooo0_l0000nooooo`007?ooool00ol0
003oooooooooo`0kooooo`;o00001_ooool2o`0000?ooooo0_l000001?oooooo0000o`000?l0000<
ooooo`;o00002_ooool2o`000004ooooool0003o0000ooooo`;o00003Oooool3o`0000?ooooo0_l0
0009ooooo`;o00000_oooolIo`0000oooooo1?l00004ooooo`;o0000<_ooool3o`0001;ooooo0_l0
000nooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00000oooool2o`0000[ooooo0_l00009
ooooo`;o00001Oooool2o`0001Cooooo0_l0000<ooooo`Co000000Coooooo`000?l0003ooooo5ol0
0007ooooo`;o00001_ooool2o`000003ooooool0003o000000?ooooo0_l0000Xooooo`;o00000_oo
ool4o`0000?ooooo0_l00002ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0D?ooool2
o`0000;ooooo0ol00008ooooo`;o00005oooool2o`0000;ooooo0_l0000<ooooo`;o00000_oooolI
o`0000Oooooo1?l00009ooooo`;o00000oooool2o`0000[ooooo1Ol00004ooooo`;o00004oooool2
o`0000;ooooo1?l00007ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0D?ooool4o`00
0003ooooool0003o000000Oooooo0_l0000>ooooo`;o00002?ooool2o`0000;ooooo0_l00009oooo
o`;o00000ooooolLo`0000Kooooo0_l000000ooooooo0000o`000002ooooo`;o00002Oooool2o`00
00[ooooo1Ol00004ooooo`;o00001Oooool3o`0000Gooooo0_l0000@ooooo`;o00001?ooool2o`00
04_ooooo000Looooo`;o0000Doooool2o`0000[ooooo0_l0000>ooooo`;o00005oooool2o`0000?o
oooo0_l000000ooooooo0000o`00000Go`0000Wooooo0_l00002ooooo`;o00001Oooool2o`0000Ko
oooo0_l00008ooooo`;o00002_ooool5o`0000Gooooo0_l0000@ooooo`;o00001?ooool2o`0004_o
oooo000Looooo`03o`000?oooooooooo05kooooo0_l0000Kooooo`;o00004_ooool<o`000003oooo
ool0003o000000Oo00001Oooool2o`00013ooooo0_l000000ooooooo0000o`000003ooooo`?o0000
1oooool2o`0000[ooooo0ol00009ooooo`;o0000HOooool001cooooo00?o0000ooooooooool0E?oo
ool2o`0000Sooooo0_l00003ooooo`;o00002_ooool2o`0000Sooooo1Ol00004ooooo`;o00000ooo
ool2o`0000Kooooo0_l00002oooooaKo000000?oooooo`000?l000004oooool2o`0000Cooooo1?l0
000Booooo`;o00001?ooool4o`000003ooooool0003o0000067ooooo000Looooo`03o`000?oooooo
oooo04kooooo0_l00003ooooo`?o00003Oooool2o`000003ooooool0003o000000Gooooo1?l00008
ooooo`;o000000?oooooo`000?l000001?ooool2o`0000?ooooo0_l0000:oooooaKo000000?ooooo
o`000?l000000_ooool2o`0000Wooooo0_l0000<ooooo`;o00005oooool5o`0006Cooooo000Loooo
o`03o`000?oooooooooo04Oooooo1?l00003ooooo`;o00000oooool2o`00013ooooo0ol00005oooo
o`?o00001?ooool2o`0000Wooooo0_l000000ooooooo0000o`000009ooooo`;o00001?ooool7o`00
00;ooooo2ol00007ooooo`;o00002Oooool2o`0000;ooooo0_l00008ooooo`;o00005oooool8o`00
0003ooooool0003o000005kooooo000Looooo`03o`000?oooooooooo04Kooooo1Ol0000Jooooo`;o
00001oooool2o`000004ooooool0003o0000ooooo`;o00002Oooool2o`0000_ooooo0ol00004oooo
oa;o00003?ooool2o`0000;ooooo1?l00004ooooo`;o00002?ooool4o`0000Wooooo0_l0000:oooo
o`;o00000_ooool4o`000003ooooool0003o000005kooooo000Looooo`03o`000?oooooooooo04Ko
oooo0_l0000Yooooo`;o00004?ooool2o`0000?ooooo1_l00005oooooa7o000000?oooooo`000?l0
00002?ooool4o`0000;ooooo1?l0000=ooooo`Go00002Oooool2o`0000[ooooo0_l00003ooooo`;o
000000?oooooo`000?l00000Goooool001cooooo00?o0000ooooooooool0DOooool2o`0000Cooooo
0_l00002ooooo`;o00004Oooool2o`0001?ooooo0_l00002ooooo`Go00001?ooool2o`000003oooo
ool0003o000001;o00002?ooool4o`0001?ooooo1?l000000ooooooo0000o`00000Cooooo`;o0000
0oooool5o`0000;ooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`16ooooo`;o00002Ooo
ool2o`0000Cooooo0_l00002ooooo`;o00002?ooool2o`0000?ooooo0_l00002ooooo`;o00005ooo
ool2o`0000?ooooo0_l00002ooooo`;o00000ooooolBo`0000Wooooo0ol00004ooooo`?o00002?oo
ool2o`0000Gooooo1?l00004ooooo`;o00000_ooool2o`0000Cooooo1?l000001?oooooo0000o`00
0?ooool2o`0000;ooooo0_l00003ooooo`;o0000Foooool001cooooo00?o0000ooooooooool0A_oo
ool2o`0000Gooooo0_l000000ooooooo0000o`00000?ooooo`;o000000Coooooo`000?l0003o0000
0oooool3o`0000?ooooo0_l00003ooooo`;o00005?ooool3o`0000[ooooo3ol00007ooooo`Ko0000
0oooool3o`0000Sooooo0_l00005ooooo`Co00001?ooool2o`0000;ooooo0_l00004ooooo`Co0000
1?ooool2o`0000gooooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o000000?o
ooooo`000?l000003Oooool4o`000003ooooool0003o000000Gooooo0ol000001?oooooo0000o`00
0?l00003ooooo`;o00003?ooool2o`0000Kooooo0_l00003ooooo`;o00001_ooool<o`000003oooo
ool0003o000000Oooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000000gooooo
1?l0000Booooo`;o00004Oooool2o`0005Gooooo000Looooo`03o`000?oooooooooo05Kooooo0_l0
00000ooooooo0000o`000004ooooo`;o00002oooool2o`000003ooooool0003o000001;ooooo0_l0
000;ooooo`;o00000_ooool4o`000003ooooool0003o000000co00000_ooool2o`0000oooooo0ol0
000<ooooo`;o000000?oooooo`000?l000004Oooool4o`0000oooooo0_l0001Eooooo`007?ooool0
0ol0003oooooooooo`1Fooooo`;o000000?oooooo`000?l000007_ooool2o`0000_ooooo0_l0000<
ooooo`Co000000?oooooo`000?l000000_l00006ooooo`Co000000Coooooo`000?l0003o00002_oo
ool2o`0000?ooooo0ol00002ooooo`;o00000oooool2o`0000?ooooo1Ol00006ooooo`Co00002Ooo
ool4o`0000gooooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00004_ooool2
o`00017ooooo1_l00009ooooo`;o00002oooool3o`0000;ooooo0ol000001Ooooooo0000o`000?l0
003ooooo00Co00001?ooool2o`0000_ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l0
0003ooooo`;o00000oooool5o`0000Kooooo1?l00004ooooo`;o00000oooool4o`0006Cooooo000L
ooooo`03o`000?oooooooooo053ooooo0_l000000ooooooo0000o`00000;ooooo`Ko00004Oooool2
o`000004ooooool0003o0000o`0000?ooooo0_l0000Aooooo`Co000000Goooooo`000?l0003o0000
ooooo`03o`000003ooooool0003o000000Co000000?oooooo`000?l000000oooool2o`0000Kooooo
0_l00007ooooo`;o00004?ooool2o`0000[ooooo0ol0000=ooooo`;o0000G?ooool001cooooo00?o
0000ooooooooool0Doooool2o`0000_ooooo1Ol0000?ooooo`;o00001?ooool2o`0000Cooooo0_l0
000;ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo0_l00005ooooo`Ko000000?o
ooooo`000?l000000_l000000ooooooo0000o`000002o`0000?ooooo0ol0000Booooo`;o00001Ooo
ool5o`0000Oooooo0_l0000=ooooo`?o0000G?ooool001cooooo0_l0001;ooooo`;o00002?ooool2
o`0001kooooo0_l00004ooooo`;o00001_ooool2o`0000Wooooo0_l00003ooooo`;o00001Oooool2
o`0000Gooooo1?l00002ooooo`;o000000?oooooo`000?l000000oooool2o`0000;ooooo0ol0000C
ooooo`;o00001oooool3o`0001Kooooo0ol0001Looooo`007?ooool00ol0003oooooooooo`1:oooo
o`;o00002?ooool2o`0000Sooooo0_l0000Jooooo`;o00001Oooool3o`0000Cooooo0_l000000ooo
oooo0000o`00000<ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0000?ooooo0_l0000:
ooooo`;o00006?ooool2o`0001Kooooo0_l000000ooooooo0000o`00001Pooooo`007?ooool00ol0
003oooooooooo`1Nooooo`;o00008Oooool2o`0000Gooooo0_l000001?oooooo0000o`000?ooool3
o`0000_ooooo1?l00009ooooo`?o00001oooool2o`0000Oooooo0_l00002ooooo`;o00002_ooool2
o`0001Kooooo0_l000000ooooooo0000o`00001Pooooo`007?ooool00ol0003oooooooooo`2>oooo
o`?o00002?ooool2o`000003ooooool0003o000000Co00001oooool3o`0000Oooooo0_l00007oooo
o`;o00000_ooool2o`000003ooooool0003o000001;ooooo0_l0001`ooooo`007?ooool00ol0003o
ooooooooo`1Looooo`;o00002?ooool2o`0000cooooo0_l00004ooooo`Co00001oooool4o`0000;o
oooo0_l0000<ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000?ooooo0_l0000Foooo
o`?o000000?oooooo`000?l000000_l00003ooooo`;o00002_ooool2o`000003ooooool0003o0000
073ooooo000Looooo`03o`000?oooooooooo05cooooo0_l00002ooooo`;o000000Coooooo`000?l0
003ooooo0_l0000<ooooo`;o000000Coooooo`000?l0003ooooo1?l00007ooooo`Co000000Cooooo
o`000?l0003o00001_ooool2o`0000Kooooo1ol00003ooooo`;o00000oooool4o`0000oooooo0ol0
00000ooooooo0000o`000002o`0000?ooooo0_l0000:ooooo`;o00002_ooool2o`0006Oooooo000L
ooooo`03o`000?oooooooooo063ooooo0_l000000ooooooo0000o`00000<ooooo`;o00001?ooool2
o`0000;ooooo0_l00007ooooo`;o00001?ooool2o`0000Oooooo0_l000000ooooooo0000o`000003
ooooo`;o000000?oooooo`000?l000002_ooool6o`0000gooooo0_l000000ooooooo0000o`00000H
ooooo`?o00000oooool2o`0006Oooooo000Looooo`03o`000?oooooooooo05Wooooo0_l0000Aoooo
o`;o00000oooool2o`0000Kooooo0_l00009ooooo`;o00002?ooool2o`0000Kooooo0_l00003oooo
o`;o00004Oooool2o`0000[ooooo2?l0000Hooooo`Go0000J_ooool001cooooo00?o0000oooooooo
ool0DOooool2o`0000Kooooo0_l0000Aooooo`;o00000_ooool2o`0000Kooooo0ol00004ooooo`;o
00003Oooool2o`0000cooooo0_l00006ooooo`;o00001_ooool2o`0000cooooo0ol00002ooooo`;o
00004?ooool2o`0000Sooooo1?l0001Zooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o0000
7Oooool2o`0000Kooooo0_l00005ooooo`;o00001?ooool2o`0001Gooooo0_l00006ooooo`;o0000
1_ooool2o`000003ooooool0003o000000;ooooo0_l0000Fooooo`;o00001?ooool2o`0000Gooooo
0_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l00000I?ooool001cooooo00?o
0000ooooooooool0O?ooool3o`0000;ooooo0_l00002ooooo`;o00001oooool2o`0000Cooooo0_l0
000Iooooo`;o00000_ooool2o`0001Kooooo0_l00009ooooo`Co00001_ooool2o`000003ooooool0
003o000006Cooooo000Looooo`03o`000?oooooooooo07cooooo0ol00002ooooo`;o00002oooool2
o`0000Cooooo0_l0000_ooooo`;o00001?ooool2o`000003ooooool0003o000000?ooooo0_l00000
1?oooooo0000o`000?ooool2o`0006kooooo000Looooo`03o`000?oooooooooo05Cooooo0_l0000J
ooooo`Co00005oooool2o`0000_ooooo0_l0000Aooooo`;o00004?ooool2o`0000Kooooo0_l00007
ooooo`?o000000Coooooo`000?l0003o00001?ooool2o`0000?ooooo0_l0001Yooooo`007?ooool0
0ol0003oooooooooo`1Dooooo`;o00000oooool2o`0001Gooooo1?l00006ooooo`;o00002_ooool2
o`0000?ooooo0ol00005ooooo`;o00000oooool3o`000003ooooool0003o000000gooooo0_l0000@
ooooo`;o00002oooool2o`0000?ooooo1Ol0000:ooooo`;o0000JOooool00006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`00
0?oooooooooo05Wooooo0_l0000Iooooo`;o00001?ooool2o`0000[ooooo0_l00004ooooo`;o0000
1Oooool3o`0000?ooooo1Ol00007ooooo`;o00004?ooool2o`0000Kooooo0_l00005ooooo`;o0000
0_ooool2o`0000Gooooo0_l0001fooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o
8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0M?ooool2o`00
013ooooo1?l00003ooooo`;o00001Oooool2o`0000Cooooo0_l00005ooooo`;o00000_ooool2o`00
00oooooo1Ol00004ooooo`;o000000?oooooo`000?l000000_ooool2o`00087ooooo00000ooooooo
410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo08Sooooo0_l00003ooooo`?o00002?ooool2o`0000Oooooo0_l0000Aoooo
o`Co000000?oooooo`000?l000001oooool2o`0000Kooooo0_l0001mooooo`0000?oooooo`000?oo
ool00_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`00
08kooooo0_l00008ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Gooooo0_l000000ooo
oooo0000o`000007ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`;o00001oooool2o`00
00?ooooo0_l0000:ooooo`;o0000K?ooool00003ooooool0003ooooo00;ooooo00?o0000oooooooo
ool02Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0R?ooool2o`00
00Cooooo0_l00005ooooo`;o00001?ooool2o`0000Cooooo0_l00005ooooo`;o000000?oooooo`00
0?l000004?ooool2o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l000000oooool2o`00
00[ooooo0_l0001/ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05
oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`28ooooo`?o00002_ooool2o`00
027ooooo0_l0000:ooooo`;o000000Coooooo`000?l0003ooooo0_l0001mooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003ooooo
ooooo`1Qooooo`;o00009Oooool3o`0000Kooooo0_l0000Uooooo`;o00002_ooool2o`0008?ooooo
00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06oooo
o`03o`000?oooooooooo067ooooo0_l0000Oooooo`Co00002?ooool2o`000004ooooool0003o0000
o`0000Sooooo0_l0000@ooooo`;o00006_ooool2o`0007gooooo000Looooo`03o`000?oooooooooo
08;ooooo1?l00008ooooo`;o00000_ooool5o`0000;ooooo0_l000000ooooooo0000o`000008oooo
o`;o00001Oooool3o`0000Wooooo1?l0000=ooooo`;o0000OOooool001cooooo00?o0000oooooooo
ool0U?ooool3o`0000;ooooo0_l0000;ooooo`;o00001Oooool2o`0000[ooooo1?l0000<ooooo`;o
00002Oooool2o`0007?ooooo000Looooo`03o`000?oooooooooo06oooooo0_l0000Xooooo`?o0000
1oooool2o`0000kooooo0_l00004ooooo`;o00003_ooool2o`0000Wooooo0_l0001cooooo`007?oo
ool00ol0003oooooooooo`1_ooooo`;o00008oooool2o`0000?ooooo0ol00006ooooo`?o00003Ooo
ool3o`0000Cooooo0_l0002>ooooo`007?ooool00ol0003oooooooooo`2Dooooo`;o00003?ooool2
o`0000kooooo0_l0002Eooooo`007?ooool00ol0003oooooooooo`2Hooooo`;o00002?ooool4o`00
0:?ooooo000Looooo`03o`000?oooooooooo06Cooooo0_l0000Oooooo`;o00001oooool2o`0000So
oooo0_l0000:ooooo`;o00006Oooool2o`0008Sooooo000Looooo`03o`000?oooooooooo06Cooooo
0_l0000Oooooo`;o00001oooool2o`0000Cooooo0_l0000Yooooo`;o0000R?ooool001cooooo00?o
0000ooooooooool0N_ooool2o`00017ooooo0_l00005ooooo`;o0000/oooool001cooooo00?o0000
ooooooooool0N_ooool2o`00017ooooo0_l00005ooooo`;o0000/oooool001cooooo00?o0000oooo
ooooool0L_ooool2o`0002Cooooo0_l0002_ooooo`007?ooool2o`0007?ooooo0_l0000Eooooo`;o
00003Oooool2o`0001;ooooo0_l0002Kooooo`007?ooool00ol0003oooooooooo`25ooooo`;o0000
0_ooool2o`0000Sooooo0_l0000Gooooo`;o0000Voooool001cooooo00?o0000ooooooooool0QOoo
ool2o`0000cooooo0_l0000Gooooo`;o00001_ooool2o`0009?ooooo000Looooo`03o`000?oooooo
oooo0;Cooooo0_l0002Cooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo093ooooo0_l0002gooooo`007?ooool00ol0003oooooooooo`2@ooooo`;o0000
1oooool2o`000:kooooo000Looooo`03o`000?oooooooooo09Wooooo0_l0002^ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`2_ooooo`;o0000V?ooool001cooooo00?o0000oooooooo
ool0[oooool2o`0009Sooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0Woooool2o`000:Sooooo000Looooo`03o`000?oooooooooo09oooooo0_l0002Xooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0
003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001;ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo
B_ooool001Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood[ooooo000D
ooooo`03o`000?oooooooooo00Gooooo0ol0003ooooood[ooooo000Dooooo`03o`000?oooooooooo
0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003ooooo
ooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001;ooooo00?oEEEE
ofIVI_l00000oooooomDooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00XOoo
ool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo01Kooooo1?l000000ol@413ooooo
ooooo`05o`0000?ooooo00Co410@o`000?m4A4Coc<c<1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
08cooooo002Rooooo`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo00?o0000oooo
ooooool00_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo00?oV9RHoa0@4?oMgMd00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg08cooooo002Rooooo`05o`000?ooooooooooooooool000006ooo
ool00ol0003oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oQhN7oeEEEOooool00_oo
ool01Ol@413ooooooooooooooooo410@08cooooo002Rooooo`05o`000?ooooooooooooooool00000
2Oooool6o`0000cooooo00?o0000ooooooooool01?ooool00onHV9So8B4Qonk^kP03ooooo`05olc<
c?lQ8B7o0000oeEEEOl000000oooool01Ol0003ooooooooooooooooo000008cooooo002Rooooo`05
o`000?n7QhOoooooojVYZOl000006oooool00ol0003oooooooooo`05ooooo`03ogMgMomVIVKooooo
00;ooooo00Go8B4QohN7QoooooooV9RHo`000003ooooo`05o`000?ooooooooooooooool00000S?oo
ool00:7ooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Iooooo`03o`000?oooooo
oooo00Kooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`2:ooooo`00`_ooool00ol0003oooooooooo`02ooooo`05o`000?nj
^[[ooooooiRHV?l@41000oooool01OlQ8B7oV9RHoooooomgMgOoEEEE00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`2<ooooo`00`?ooool00omEEEGoIVIVo`000004ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`00oooool01Oo<c<co410@o`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP2<ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1296) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.4859 .67418 Mdot
.47255 .66219 Mdot
.64388 .41866 Mdot
.37682 .526 Mdot
.74092 .32851 Mdot
.60969 .4097 Mdot
.62805 .63116 Mdot
.65163 .57023 Mdot
.63773 .43542 Mdot
.66702 .67685 Mdot
.62943 .57961 Mdot
.367 .57456 Mdot
.65291 .59639 Mdot
.37056 .48939 Mdot
.70688 .22143 Mdot
.34704 .53652 Mdot
.48107 .66726 Mdot
.44793 .29787 Mdot
.41055 .5539 Mdot
.64969 .39361 Mdot
.49158 .70958 Mdot
.37659 .49514 Mdot
.42958 .67924 Mdot
.37027 .48868 Mdot
.40052 .52851 Mdot
.44246 .7048 Mdot
.46105 .61932 Mdot
.41617 .50745 Mdot
.42338 .48313 Mdot
.6457 .56752 Mdot
.35245 .32566 Mdot
.7115 .25104 Mdot
.40032 .42144 Mdot
.48508 .20518 Mdot
.66899 .59554 Mdot
.32062 .68255 Mdot
.62156 .41596 Mdot
.6345 .60286 Mdot
.63132 .60711 Mdot
.6737 .60425 Mdot
.63479 .58853 Mdot
.43598 .68016 Mdot
.55843 .64796 Mdot
.67828 .36365 Mdot
.33786 .50859 Mdot
.7926 .46513 Mdot
.38968 .77175 Mdot
.37615 .45374 Mdot
.47549 .69402 Mdot
.56097 .26798 Mdot
.73239 .46262 Mdot
.64943 .62497 Mdot
.65592 .39387 Mdot
.11881 .57941 Mdot
.65162 .61286 Mdot
.44919 .51319 Mdot
.63254 .41917 Mdot
.38594 .48658 Mdot
.37001 .48379 Mdot
.26271 .55134 Mdot
.34811 .47494 Mdot
.46006 .31533 Mdot
.42316 .642 Mdot
.56404 .56378 Mdot
.62922 .4321 Mdot
.62474 .59926 Mdot
.46265 .66104 Mdot
.65815 .59997 Mdot
.44391 .56303 Mdot
.62409 .37915 Mdot
.37651 .45199 Mdot
.62765 .58593 Mdot
.45692 .62766 Mdot
.41188 .47381 Mdot
.56528 .35194 Mdot
.82188 .56819 Mdot
.49452 .29017 Mdot
.30562 .65117 Mdot
.25476 .54626 Mdot
.60235 .29775 Mdot
.40192 .54641 Mdot
.39756 .35897 Mdot
.81536 .53751 Mdot
.43198 .71044 Mdot
.32605 .51251 Mdot
.47431 .25817 Mdot
.41117 .47837 Mdot
.81343 .45525 Mdot
.3867 .43992 Mdot
.52425 .29449 Mdot
.63527 .44259 Mdot
.46303 .68446 Mdot
.37799 .52939 Mdot
.41242 .46361 Mdot
.24151 .49855 Mdot
.44008 .48678 Mdot
.39183 .50615 Mdot
.46905 .71096 Mdot
.65047 .6233 Mdot
.43455 .45485 Mdot
.68685 .38289 Mdot
.64405 .44707 Mdot
.35744 .52575 Mdot
.59334 .43504 Mdot
.4337 .63535 Mdot
.4099 .46286 Mdot
.63468 .61332 Mdot
.35121 .50609 Mdot
.56108 .78115 Mdot
.47012 .65375 Mdot
.42049 .49883 Mdot
.48705 .3521 Mdot
.20883 .5713 Mdot
.46944 .68913 Mdot
.69673 .39719 Mdot
.42734 .52628 Mdot
.39711 .49723 Mdot
.47186 .66756 Mdot
.60808 .454 Mdot
.81671 .47195 Mdot
.45464 .72337 Mdot
.66526 .57198 Mdot
.48434 .65781 Mdot
.38947 .57547 Mdot
.61769 .43556 Mdot
.71713 .39826 Mdot
.55309 .75096 Mdot
.37854 .30074 Mdot
.40851 .47806 Mdot
.59113 .66977 Mdot
.66183 .43139 Mdot
.45681 .67642 Mdot
.65813 .59383 Mdot
.32801 .47195 Mdot
.44838 .64559 Mdot
.63089 .57207 Mdot
.47659 .35093 Mdot
.7113 .51962 Mdot
.43765 .64002 Mdot
.50715 .41887 Mdot
.61432 .60305 Mdot
.66306 .61998 Mdot
.38928 .20728 Mdot
.46157 .66458 Mdot
.46924 .321 Mdot
.6589 .58402 Mdot
.36516 .28899 Mdot
.33951 .50495 Mdot
.35321 .36791 Mdot
.39837 .79391 Mdot
.46327 .2038 Mdot
.73167 .54028 Mdot
.49176 .3184 Mdot
.63385 .55913 Mdot
.39339 .52229 Mdot
.45076 .70928 Mdot
.43391 .69451 Mdot
.34749 .4801 Mdot
.39481 .5385 Mdot
.38089 .4478 Mdot
.40328 .45032 Mdot
.3257 .5682 Mdot
.43344 .52665 Mdot
.3296 .74373 Mdot
.462 .68931 Mdot
.38307 .52452 Mdot
.60522 .39163 Mdot
.39844 .42965 Mdot
.63092 .58725 Mdot
.38428 .49324 Mdot
.37892 .5279 Mdot
.34267 .49098 Mdot
.6546 .62306 Mdot
.75726 .29154 Mdot
.22205 .60978 Mdot
.72624 .28055 Mdot
.53251 .35692 Mdot
.59329 .40837 Mdot
.41011 .49068 Mdot
.46619 .33516 Mdot
.35963 .6728 Mdot
.36429 .51479 Mdot
.42932 .86191 Mdot
.38523 .5039 Mdot
.74281 .31666 Mdot
.45488 .51068 Mdot
.64251 .22083 Mdot
.38424 .3504 Mdot
.40379 .51869 Mdot
.54411 .62235 Mdot
.65427 .54192 Mdot
.60086 .46305 Mdot
.63833 .58969 Mdot
.6099 .39013 Mdot
.64018 .41736 Mdot
.56552 .59408 Mdot
.33387 .55145 Mdot
.42373 .42807 Mdot
.40396 .44271 Mdot
.6078 .37694 Mdot
.42032 .65996 Mdot
.46314 .34822 Mdot
.48397 .70298 Mdot
.86057 .43265 Mdot
.76172 .44104 Mdot
.63121 .64323 Mdot
.45376 .31056 Mdot
.65275 .43125 Mdot
.6201 .44812 Mdot
.495 .34322 Mdot
.38572 .46449 Mdot
.45499 .66383 Mdot
.43707 .18511 Mdot
.60978 .77033 Mdot
.35532 .20178 Mdot
.46872 .70902 Mdot
.64133 .69173 Mdot
.64035 .57164 Mdot
.62647 .40319 Mdot
.39605 .50019 Mdot
.39118 .4686 Mdot
.47208 .73641 Mdot
.38383 .44803 Mdot
.50634 .66861 Mdot
.4014 .50737 Mdot
.69001 .48602 Mdot
.46747 .27645 Mdot
.56657 .59007 Mdot
.40233 .28024 Mdot
.43684 .71193 Mdot
.24603 .4123 Mdot
.59968 .4389 Mdot
.35217 .66416 Mdot
.62188 .59571 Mdot
.46289 .33877 Mdot
.6085 .43898 Mdot
.47485 .35533 Mdot
.42803 .54067 Mdot
.62356 .3869 Mdot
.50072 .33425 Mdot
.29534 .44261 Mdot
.34078 .47271 Mdot
.50013 .7919 Mdot
.67272 .5942 Mdot
.48081 .71505 Mdot
.35128 .46759 Mdot
.58835 .41281 Mdot
.34399 .43927 Mdot
.75678 .58211 Mdot
.69887 .45711 Mdot
.65002 .44622 Mdot
.67908 .47113 Mdot
.45751 .31814 Mdot
.76484 .51424 Mdot
.61592 .68711 Mdot
.48258 .6737 Mdot
.44046 .49484 Mdot
.61754 .20359 Mdot
.65929 .58509 Mdot
.35163 .49157 Mdot
.56264 .22893 Mdot
.66376 .60115 Mdot
.38759 .48517 Mdot
.64039 .56342 Mdot
.43325 .6927 Mdot
.21914 .52841 Mdot
.48091 .67901 Mdot
.40362 .44646 Mdot
.63946 .61647 Mdot
.58293 .41163 Mdot
.44573 .70199 Mdot
.37887 .46281 Mdot
.41479 .50348 Mdot
.60115 .51058 Mdot
.38459 .51742 Mdot
.75593 .30427 Mdot
.40308 .51323 Mdot
.63795 .40422 Mdot
.37534 .54835 Mdot
.17286 .59092 Mdot
.57078 .61567 Mdot
.46109 .66183 Mdot
.62071 .459 Mdot
.6377 .42949 Mdot
.67295 .35215 Mdot
.66546 .6371 Mdot
.42439 .53434 Mdot
.59037 .41232 Mdot
.27437 .40931 Mdot
.61696 .59087 Mdot
.41993 .43505 Mdot
.51025 .44695 Mdot
.54947 .27098 Mdot
.65772 .39626 Mdot
.35646 .42138 Mdot
.43316 .64139 Mdot
.38166 .53358 Mdot
.61483 .44977 Mdot
.31021 .51026 Mdot
.42389 .5195 Mdot
.48235 .75004 Mdot
.60705 .51292 Mdot
.6204 .6218 Mdot
.45414 .49009 Mdot
.35463 .47989 Mdot
.61218 .39268 Mdot
.44151 .71358 Mdot
.61623 .58936 Mdot
.43765 .69003 Mdot
.59842 .20928 Mdot
.51403 .78753 Mdot
.2817 .46915 Mdot
.44995 .32159 Mdot
.5358 .24485 Mdot
.61216 .20892 Mdot
.21779 .4099 Mdot
.27104 .37132 Mdot
.50675 .18692 Mdot
.59841 .44633 Mdot
.56394 .23674 Mdot
.63693 .42375 Mdot
.40606 .5352 Mdot
.61875 .43412 Mdot
.60395 .19927 Mdot
.39944 .50756 Mdot
.6159 .42669 Mdot
.23663 .44344 Mdot
.38527 .53208 Mdot
.47866 .66968 Mdot
.81863 .38768 Mdot
.17806 .48812 Mdot
.69361 .468 Mdot
.64887 .40017 Mdot
.30142 .32551 Mdot
.39145 .50863 Mdot
.37977 .54946 Mdot
.461 .70312 Mdot
.37132 .4208 Mdot
.4708 .30057 Mdot
.45746 .30328 Mdot
.70149 .62327 Mdot
.43334 .38917 Mdot
.45346 .50924 Mdot
.44936 .70259 Mdot
.36009 .59029 Mdot
.55579 .3417 Mdot
.56306 .26194 Mdot
.6084 .59631 Mdot
.81533 .38497 Mdot
.49363 .63655 Mdot
.60697 .55677 Mdot
.61422 .47429 Mdot
.47403 .67948 Mdot
.74375 .27518 Mdot
.63918 .59432 Mdot
.50444 .80845 Mdot
.49174 .53719 Mdot
.3843 .46733 Mdot
.62056 .61179 Mdot
.31866 .47825 Mdot
.17913 .4714 Mdot
.57516 .8142 Mdot
.48207 .47022 Mdot
.38613 .43873 Mdot
.54904 .36357 Mdot
.38938 .49536 Mdot
.79409 .54155 Mdot
.40719 .51284 Mdot
.44091 .69107 Mdot
.68191 .66967 Mdot
.69126 .60766 Mdot
.24966 .68027 Mdot
.7752 .53008 Mdot
.49142 .3167 Mdot
.40131 .50223 Mdot
.38182 .46785 Mdot
.47861 .30226 Mdot
.42792 .66752 Mdot
.39467 .44426 Mdot
.24684 .39949 Mdot
.40487 .45941 Mdot
.63221 .59411 Mdot
.47503 .55786 Mdot
.45638 .7621 Mdot
.42314 .46227 Mdot
.43649 .6245 Mdot
.63174 .63896 Mdot
.64241 .61383 Mdot
.45021 .53254 Mdot
.67572 .59769 Mdot
.37874 .50614 Mdot
.6046 .81183 Mdot
.44353 .63612 Mdot
.5217 .69452 Mdot
.44292 .65747 Mdot
.29187 .63984 Mdot
.66066 .61272 Mdot
.71198 .47918 Mdot
.32305 .52635 Mdot
.64286 .59521 Mdot
.44077 .75878 Mdot
.35125 .53676 Mdot
.3347 .47935 Mdot
.3886 .22663 Mdot
.65017 .40847 Mdot
.60866 .51826 Mdot
.64791 .56716 Mdot
.36672 .46672 Mdot
.43461 .48898 Mdot
.63615 .64041 Mdot
.60834 .79316 Mdot
.20116 .4775 Mdot
.40178 .51057 Mdot
.44804 .68824 Mdot
.45309 .67618 Mdot
.35522 .44973 Mdot
.36744 .534 Mdot
.60641 .42957 Mdot
.58279 .42766 Mdot
.62085 .3822 Mdot
.61518 .51647 Mdot
.7083 .47733 Mdot
.75017 .37873 Mdot
.67356 .6051 Mdot
.61596 .71266 Mdot
.51644 .28209 Mdot
.41641 .44743 Mdot
.6598 .41246 Mdot
.35578 .4853 Mdot
.37353 .51271 Mdot
.64603 .64626 Mdot
.665 .28072 Mdot
.49863 .67401 Mdot
.42418 .68339 Mdot
.61432 .58259 Mdot
.42046 .58613 Mdot
.59128 .61046 Mdot
.47408 .34653 Mdot
.42735 .21302 Mdot
.62413 .59226 Mdot
.47769 .67062 Mdot
.66737 .58309 Mdot
.39652 .46505 Mdot
.42668 .55126 Mdot
.47033 .67519 Mdot
.48515 .29714 Mdot
.35263 .43358 Mdot
.39057 .48622 Mdot
.37916 .79738 Mdot
.408 .23696 Mdot
.67575 .50198 Mdot
.40244 .5172 Mdot
.42755 .47491 Mdot
.50622 .33487 Mdot
.40241 .45964 Mdot
.36797 .45162 Mdot
.21766 .57404 Mdot
.56779 .75223 Mdot
.4577 .2968 Mdot
.61787 .79934 Mdot
.47149 .70558 Mdot
.66519 .22457 Mdot
.62157 .39691 Mdot
.6818 .65364 Mdot
.19652 .50847 Mdot
.65265 .39072 Mdot
.73273 .54714 Mdot
.69063 .24228 Mdot
.62181 .52213 Mdot
.56896 .392 Mdot
.47466 .62476 Mdot
.39797 .44714 Mdot
.39578 .49311 Mdot
.46249 .32489 Mdot
.44968 .66555 Mdot
.58472 .517 Mdot
.76196 .68352 Mdot
.37958 .49731 Mdot
.51641 .67156 Mdot
.70929 .70428 Mdot
.55132 .27673 Mdot
.48252 .3335 Mdot
.46866 .29268 Mdot
.40123 .49888 Mdot
.20905 .5926 Mdot
.44396 .70553 Mdot
.37737 .4635 Mdot
.43586 .51688 Mdot
.64782 .40234 Mdot
.46226 .64292 Mdot
.61419 .45492 Mdot
.73196 .48014 Mdot
.73051 .29103 Mdot
.41794 .8284 Mdot
.65338 .61538 Mdot
.78591 .59628 Mdot
.62978 .56668 Mdot
.40393 .35498 Mdot
.66847 .42688 Mdot
.3752 .53386 Mdot
.43699 .71002 Mdot
.3622 .47229 Mdot
.3713 .53583 Mdot
.38358 .4654 Mdot
.42879 .46537 Mdot
.32943 .80602 Mdot
.4979 .32703 Mdot
.36476 .55921 Mdot
.64166 .40865 Mdot
.81022 .50047 Mdot
.8142 .57301 Mdot
.37835 .47127 Mdot
.41018 .50385 Mdot
.44124 .64265 Mdot
.34843 .48284 Mdot
.62403 .57266 Mdot
.46708 .7217 Mdot
.41559 .47249 Mdot
.82508 .41635 Mdot
.42316 .49086 Mdot
.67969 .24474 Mdot
.66259 .57707 Mdot
.57149 .78246 Mdot
.38321 .56947 Mdot
.68639 .47348 Mdot
.6083 .51816 Mdot
.60775 .4353 Mdot
.66374 .56511 Mdot
.62108 .41855 Mdot
.74083 .7119 Mdot
.42756 .55532 Mdot
.39486 .5248 Mdot
.43015 .45711 Mdot
.59335 .4073 Mdot
.80521 .43096 Mdot
.76905 .49109 Mdot
.37945 .57194 Mdot
.59717 .40844 Mdot
.42869 .63482 Mdot
.37392 .25864 Mdot
.43711 .6659 Mdot
.46287 .35466 Mdot
.6353 .57764 Mdot
.47848 .29593 Mdot
.54966 .21833 Mdot
.47231 .65853 Mdot
.48812 .70802 Mdot
.6194 .39999 Mdot
.50033 .53448 Mdot
.16389 .38114 Mdot
.49299 .54042 Mdot
.38437 .32742 Mdot
.45729 .70079 Mdot
.42331 .47526 Mdot
.42681 .35504 Mdot
.50826 .56639 Mdot
.62217 .42136 Mdot
.36523 .50753 Mdot
.21636 .52224 Mdot
.6063 .42968 Mdot
.43413 .45994 Mdot
.64651 .41013 Mdot
.63854 .58314 Mdot
.65921 .42157 Mdot
.45086 .73859 Mdot
.41535 .48663 Mdot
.19995 .31763 Mdot
.45267 .27445 Mdot
.39341 .51306 Mdot
.61313 .58366 Mdot
.72035 .59335 Mdot
.3582 .51567 Mdot
.49148 .35471 Mdot
.60629 .41962 Mdot
.49633 .50041 Mdot
.40398 .51154 Mdot
.59748 .40379 Mdot
.48625 .67249 Mdot
.6471 .55628 Mdot
.24856 .51502 Mdot
.66811 .49155 Mdot
.46183 .70415 Mdot
.51689 .39202 Mdot
.67802 .58734 Mdot
.42761 .47373 Mdot
.43968 .49172 Mdot
.44817 .68399 Mdot
.30846 .40796 Mdot
.35703 .53076 Mdot
.3998 .54625 Mdot
.63681 .39895 Mdot
.61682 .41888 Mdot
.25162 .46211 Mdot
.59262 .44438 Mdot
.42523 .55288 Mdot
.44609 .68363 Mdot
.37538 .52756 Mdot
.44838 .63771 Mdot
.3485 .48605 Mdot
.33062 .5551 Mdot
.42759 .67015 Mdot
.57798 .59761 Mdot
.36865 .51125 Mdot
.41558 .42341 Mdot
.35179 .50282 Mdot
.39479 .44854 Mdot
.61345 .43621 Mdot
.47863 .34106 Mdot
.44367 .50556 Mdot
.5062 .35487 Mdot
.47245 .35354 Mdot
.68593 .57937 Mdot
.6498 .40488 Mdot
.47387 .3128 Mdot
.71689 .70485 Mdot
.62686 .38436 Mdot
.46396 .31022 Mdot
.81425 .57017 Mdot
.66872 .60048 Mdot
.43764 .63699 Mdot
.38744 .53392 Mdot
.5538 .20785 Mdot
.39031 .77463 Mdot
.57874 .43383 Mdot
.40061 .51346 Mdot
.35336 .49575 Mdot
.4443 .72141 Mdot
.75601 .71582 Mdot
.62337 .37929 Mdot
.42572 .51052 Mdot
.46482 .65646 Mdot
.73546 .75628 Mdot
.63696 .40969 Mdot
.46215 .31493 Mdot
.66917 .61042 Mdot
.46583 .7507 Mdot
.55123 .75201 Mdot
.6244 .62828 Mdot
.5853 .46353 Mdot
.72749 .46636 Mdot
.42841 .52523 Mdot
.66222 .41558 Mdot
.36083 .21371 Mdot
.39867 .61676 Mdot
.57584 .56016 Mdot
.30788 .31605 Mdot
.47218 .68305 Mdot
.62746 .56912 Mdot
.49462 .32158 Mdot
.46489 .71146 Mdot
.47899 .66387 Mdot
.64523 .63985 Mdot
.23292 .60684 Mdot
.50948 .44986 Mdot
.63056 .60189 Mdot
.44534 .23352 Mdot
.71483 .34517 Mdot
.65966 .41063 Mdot
.47105 .30099 Mdot
.56921 .2225 Mdot
.43557 .68297 Mdot
.81276 .37093 Mdot
.39465 .21737 Mdot
.39162 .50617 Mdot
.4752 .31728 Mdot
.78768 .408 Mdot
.79449 .65492 Mdot
.66204 .60573 Mdot
.69565 .60221 Mdot
.46482 .30122 Mdot
.35112 .46935 Mdot
.36757 .27198 Mdot
.39811 .54469 Mdot
.6392 .5744 Mdot
.2628 .52689 Mdot
.47753 .66372 Mdot
.65725 .63105 Mdot
.42345 .21189 Mdot
.37779 .50432 Mdot
.36756 .51217 Mdot
.41664 .2769 Mdot
.45338 .71793 Mdot
.6071 .43491 Mdot
.43138 .5234 Mdot
.38833 .48928 Mdot
.44332 .52411 Mdot
.45081 .47585 Mdot
.21029 .55495 Mdot
.4102 .52655 Mdot
.77914 .47166 Mdot
.38747 .43753 Mdot
.36791 .50092 Mdot
.43638 .62668 Mdot
.41605 .83434 Mdot
.74305 .47502 Mdot
.38617 .49234 Mdot
.42638 .48521 Mdot
.66204 .62664 Mdot
.51093 .50854 Mdot
.50309 .51852 Mdot
.49637 .48971 Mdot
.28638 .34784 Mdot
.35067 .44959 Mdot
.45591 .65844 Mdot
.50103 .33838 Mdot
.4272 .51626 Mdot
.4588 .65675 Mdot
.34143 .50468 Mdot
.60355 .42718 Mdot
.6251 .38441 Mdot
.39852 .60842 Mdot
.47863 .31079 Mdot
.49563 .61149 Mdot
.60768 .71372 Mdot
.61539 .38926 Mdot
.3963 .52699 Mdot
.64367 .65047 Mdot
.61541 .44916 Mdot
.69219 .45085 Mdot
.32237 .41532 Mdot
.44642 .71074 Mdot
.46382 .68718 Mdot
.34954 .37106 Mdot
.73155 .52586 Mdot
.29201 .74234 Mdot
.6381 .58175 Mdot
.39987 .56191 Mdot
.60849 .67398 Mdot
.46613 .68891 Mdot
.41799 .34917 Mdot
.47674 .31429 Mdot
.6647 .59932 Mdot
.55532 .39293 Mdot
.44417 .64461 Mdot
.47727 .65518 Mdot
.37356 .44138 Mdot
.3882 .47855 Mdot
.26605 .3817 Mdot
.48469 .37463 Mdot
.62367 .62938 Mdot
.46719 .30259 Mdot
.66819 .42628 Mdot
.41675 .5228 Mdot
.42864 .68057 Mdot
.71295 .35291 Mdot
.42808 .5082 Mdot
.62445 .44341 Mdot
.46872 .68227 Mdot
.45758 .31502 Mdot
.49331 .35599 Mdot
.39859 .4509 Mdot
.30773 .56759 Mdot
.63885 .60346 Mdot
.47721 .67853 Mdot
.58793 .60204 Mdot
.37659 .5462 Mdot
.39564 .47909 Mdot
.46002 .4885 Mdot
.62252 .62875 Mdot
.66052 .72062 Mdot
.45724 .34249 Mdot
.45393 .66775 Mdot
.41196 .51882 Mdot
.47123 .30476 Mdot
.64276 .70438 Mdot
.65472 .44302 Mdot
.65766 .42466 Mdot
.49702 .35291 Mdot
.47947 .32633 Mdot
.48239 .35561 Mdot
.81322 .37042 Mdot
.43653 .72086 Mdot
.49307 .63744 Mdot
.37822 .55361 Mdot
.3818 .34436 Mdot
.32349 .51924 Mdot
.61451 .59584 Mdot
.65059 .4119 Mdot
.35965 .52303 Mdot
.41515 .45834 Mdot
.44283 .55758 Mdot
.51557 .70003 Mdot
.45159 .76151 Mdot
.4683 .64948 Mdot
.41196 .56577 Mdot
.64078 .39609 Mdot
.86619 .43407 Mdot
.46203 .15944 Mdot
.38746 .56975 Mdot
.50292 .44359 Mdot
.42775 .68535 Mdot
.67079 .61623 Mdot
.4408 .26745 Mdot
.67013 .60071 Mdot
.4568 .6699 Mdot
.41222 .52577 Mdot
.61558 .72075 Mdot
.50447 .34639 Mdot
.37399 .45851 Mdot
.64683 .57236 Mdot
.37292 .45464 Mdot
.62578 .62979 Mdot
.61096 .21543 Mdot
.31364 .27133 Mdot
.38633 .50388 Mdot
.33509 .53092 Mdot
.28797 .3266 Mdot
.37386 .47199 Mdot
.46349 .36634 Mdot
.42752 .68479 Mdot
.24388 .4891 Mdot
.33274 .50618 Mdot
.37549 .62307 Mdot
.38482 .54869 Mdot
.22992 .47333 Mdot
.39476 .47594 Mdot
.54761 .28455 Mdot
.419 .49487 Mdot
.37881 .44578 Mdot
.64682 .61777 Mdot
.65803 .62988 Mdot
.45319 .62489 Mdot
.58826 .41877 Mdot
.70311 .25997 Mdot
.39292 .48393 Mdot
.70483 .44536 Mdot
.60532 .74615 Mdot
.48092 .32821 Mdot
.4516 .67017 Mdot
.78711 .69045 Mdot
.65251 .56578 Mdot
.36714 .23895 Mdot
.25293 .44727 Mdot
.55408 .70283 Mdot
.46514 .25523 Mdot
.72459 .64852 Mdot
.45704 .32619 Mdot
.34283 .49424 Mdot
.69229 .31725 Mdot
.54404 .29828 Mdot
.31261 .42136 Mdot
.67879 .58521 Mdot
.36247 .65206 Mdot
.67887 .29412 Mdot
.48046 .36292 Mdot
.46553 .2973 Mdot
.64386 .62772 Mdot
.58512 .37013 Mdot
.34678 .56218 Mdot
.47992 .31725 Mdot
.59979 .39315 Mdot
.63619 .38605 Mdot
.64106 .38229 Mdot
.43918 .70323 Mdot
.41534 .19683 Mdot
.60593 .63644 Mdot
.6204 .61976 Mdot
.64015 .36747 Mdot
.41646 .63603 Mdot
.44949 .73123 Mdot
.62168 .4068 Mdot
.64184 .44375 Mdot
.42597 .66894 Mdot
.44911 .5225 Mdot
.42602 .56723 Mdot
.38289 .4957 Mdot
.47068 .33943 Mdot
.3906 .47326 Mdot
.59852 .41341 Mdot
.659 .60662 Mdot
.64726 .43835 Mdot
.61743 .57075 Mdot
.75958 .39799 Mdot
.38532 .45752 Mdot
.41651 .49146 Mdot
.42265 .80144 Mdot
.48265 .65843 Mdot
.77822 .44733 Mdot
.65409 .50527 Mdot
.63829 .42121 Mdot
.36403 .4546 Mdot
.46785 .72214 Mdot
.49614 .36602 Mdot
.44896 .81917 Mdot
.36304 .53238 Mdot
.43186 .67066 Mdot
.4168 .51883 Mdot
.30814 .55436 Mdot
.19166 .6282 Mdot
.43963 .68202 Mdot
.39654 .79147 Mdot
.4247 .48509 Mdot
.74281 .65557 Mdot
.41705 .435 Mdot
.29768 .39396 Mdot
.35729 .53103 Mdot
.47053 .70742 Mdot
.38154 .49188 Mdot
.47376 .71739 Mdot
.61773 .39135 Mdot
.66971 .6159 Mdot
.46346 .69905 Mdot
.43699 .47606 Mdot
.24236 .2201 Mdot
.64494 .57779 Mdot
.39864 .50072 Mdot
.6594 .61765 Mdot
.44731 .66307 Mdot
.47386 .69431 Mdot
.79222 .6433 Mdot
.73443 .48349 Mdot
.63954 .58414 Mdot
.41692 .52144 Mdot
.75908 .60482 Mdot
.3877 .54001 Mdot
.28893 .37622 Mdot
.44951 .50768 Mdot
.37557 .54986 Mdot
.81786 .57626 Mdot
.61916 .61979 Mdot
.27562 .72917 Mdot
.81218 .61871 Mdot
.81137 .50573 Mdot
.48116 .72754 Mdot
.48459 .36458 Mdot
.75028 .28191 Mdot
.70874 .47969 Mdot
.59634 .40669 Mdot
.35507 .51367 Mdot
.42025 .72056 Mdot
.63771 .60766 Mdot
.48153 .34423 Mdot
.38731 .50353 Mdot
.65078 .43839 Mdot
.20785 .44304 Mdot
.62868 .56071 Mdot
.43728 .67621 Mdot
.42493 .69535 Mdot
.60648 .82857 Mdot
.40598 .51836 Mdot
.41595 .48239 Mdot
.6362 .57619 Mdot
.69289 .70601 Mdot
.46044 .34015 Mdot
.23508 .43715 Mdot
.64116 .5844 Mdot
.557 .51389 Mdot
.46699 .66153 Mdot
.35346 .49264 Mdot
.79375 .38109 Mdot
.57783 .35298 Mdot
.4459 .78733 Mdot
.46624 .33457 Mdot
.2934 .36922 Mdot
.47247 .70493 Mdot
.65858 .58959 Mdot
.70748 .5359 Mdot
.36234 .43763 Mdot
.35729 .48583 Mdot
.3003 .3672 Mdot
.69088 .60016 Mdot
.48454 .48802 Mdot
.36841 .53812 Mdot
.60987 .52211 Mdot
.35313 .51975 Mdot
.33715 .46212 Mdot
.43955 .54143 Mdot
.40428 .47855 Mdot
.4295 .67644 Mdot
.46463 .52886 Mdot
.59642 .42395 Mdot
.47862 .60916 Mdot
.55763 .52387 Mdot
.39684 .51133 Mdot
.41133 .53934 Mdot
.39996 .74233 Mdot
.73536 .57177 Mdot
.4629 .69568 Mdot
.47839 .72547 Mdot
.67364 .5861 Mdot
.43288 .56426 Mdot
.59169 .42886 Mdot
.32929 .47382 Mdot
.61903 .44014 Mdot
.42948 .68181 Mdot
.6381 .4168 Mdot
.66666 .61526 Mdot
.65252 .39976 Mdot
.70869 .47663 Mdot
.65855 .57984 Mdot
.45263 .71076 Mdot
.41072 .47017 Mdot
.6135 .58185 Mdot
.38515 .28637 Mdot
.469 .33722 Mdot
.83784 .58861 Mdot
.41644 .47339 Mdot
.56124 .756 Mdot
.30334 .47637 Mdot
.64422 .44137 Mdot
.2007 .64018 Mdot
.42467 .6832 Mdot
.46648 .29043 Mdot
.4365 .71348 Mdot
.39801 .23228 Mdot
.47418 .3325 Mdot
.82805 .54827 Mdot
.60587 .48769 Mdot
.40066 .24205 Mdot
.44305 .54778 Mdot
.41367 .25884 Mdot
.66348 .40349 Mdot
.63925 .60896 Mdot
.71782 .54068 Mdot
.3709 .45054 Mdot
.23904 .35623 Mdot
.42473 .65021 Mdot
.5893 .41892 Mdot
.6575 .59757 Mdot
.61594 .5876 Mdot
.40998 .54943 Mdot
.60232 .27778 Mdot
.3563 .47528 Mdot
.73058 .51141 Mdot
.28988 .35063 Mdot
.49345 .72849 Mdot
.40112 .5068 Mdot
.61323 .39229 Mdot
.4167 .51902 Mdot
.45004 .3042 Mdot
.39469 .19645 Mdot
.36431 .42629 Mdot
.65925 .50739 Mdot
.45485 .27254 Mdot
.47293 .67076 Mdot
.31006 .44877 Mdot
.6934 .49191 Mdot
.40696 .52076 Mdot
.23972 .75486 Mdot
.46677 .30715 Mdot
.68729 .31399 Mdot
.43242 .47928 Mdot
.42335 .53818 Mdot
.55396 .59395 Mdot
.54271 .7425 Mdot
.56349 .35896 Mdot
.36821 .47814 Mdot
.33293 .32544 Mdot
.63041 .6277 Mdot
.3498 .48845 Mdot
.39737 .49472 Mdot
.26661 .65857 Mdot
.61801 .57638 Mdot
.64219 .42658 Mdot
.66283 .39936 Mdot
.5839 .44127 Mdot
.45261 .29698 Mdot
.66994 .54215 Mdot
.40631 .33756 Mdot
.18985 .46063 Mdot
.48811 .29458 Mdot
.41043 .45727 Mdot
.44464 .35807 Mdot
.41051 .5321 Mdot
.48979 .3346 Mdot
.62044 .57189 Mdot
.46631 .69574 Mdot
.63213 .68306 Mdot
.63569 .38321 Mdot
.40843 .42638 Mdot
.45648 .33428 Mdot
.44946 .7096 Mdot
.46404 .24976 Mdot
.46796 .66727 Mdot
.64543 .59127 Mdot
.60768 .58241 Mdot
.48577 .3423 Mdot
.44564 .65886 Mdot
.61524 .54242 Mdot
.78009 .67184 Mdot
.43493 .54384 Mdot
.70871 .6389 Mdot
.48166 .69525 Mdot
.47011 .73199 Mdot
.4731 .71252 Mdot
.3828 .44958 Mdot
.50335 .44286 Mdot
.34196 .51884 Mdot
.62077 .62322 Mdot
.64689 .41408 Mdot
.26621 .34856 Mdot
.7366 .4173 Mdot
.49481 .39631 Mdot
.40465 .56344 Mdot
.37624 .50289 Mdot
.40094 .49879 Mdot
.33132 .50185 Mdot
.70678 .50997 Mdot
.35936 .47603 Mdot
.64517 .61867 Mdot
.60423 .41988 Mdot
.34252 .494 Mdot
.67085 .39479 Mdot
.80437 .49984 Mdot
.49265 .29986 Mdot
.69268 .56695 Mdot
.47717 .14181 Mdot
.45411 .70764 Mdot
.62342 .45819 Mdot
.60045 .40209 Mdot
.47503 .34991 Mdot
.63429 .60071 Mdot
.46492 .665 Mdot
.27919 .39782 Mdot
.47599 .3541 Mdot
.38418 .49095 Mdot
.4883 .4355 Mdot
.26314 .32035 Mdot
.34388 .49617 Mdot
.36501 .52272 Mdot
.67511 .41358 Mdot
.66905 .30112 Mdot
.24998 .27443 Mdot
.41717 .316 Mdot
.48175 .34217 Mdot
.49589 .31245 Mdot
.43125 .64936 Mdot
.34651 .53192 Mdot
.62228 .62644 Mdot
.47996 .5346 Mdot
.70156 .56887 Mdot
.48384 .58499 Mdot
.49418 .76559 Mdot
.35778 .52423 Mdot
.63547 .77995 Mdot
.37716 .50739 Mdot
.43818 .72174 Mdot
.43182 .68626 Mdot
.45001 .69687 Mdot
.64012 .60806 Mdot
.32432 .66838 Mdot
.63714 .61724 Mdot
.46086 .13916 Mdot
.47791 .69354 Mdot
.61087 .4958 Mdot
.62712 .39818 Mdot
.39205 .5729 Mdot
.45991 .31026 Mdot
.62511 .54943 Mdot
.44337 .56362 Mdot
.2057 .61056 Mdot
.59132 .41916 Mdot
.45581 .71029 Mdot
.71887 .65446 Mdot
.53938 .17223 Mdot
.50106 .5003 Mdot
.42444 .58746 Mdot
.44548 .26108 Mdot
.4843 .32885 Mdot
.44539 .78817 Mdot
.46521 .30252 Mdot
.64869 .57215 Mdot
.41474 .495 Mdot
.41076 .47873 Mdot
.35128 .5169 Mdot
.38044 .46369 Mdot
.67792 .60195 Mdot
.44138 .49725 Mdot
.17284 .59079 Mdot
.61859 .38493 Mdot
.28962 .45004 Mdot
.46203 .30975 Mdot
.6677 .56606 Mdot
.60297 .41862 Mdot
.73306 .56711 Mdot
.40003 .28668 Mdot
.40297 .51047 Mdot
.35764 .52006 Mdot
.35739 .24149 Mdot
.36976 .53937 Mdot
.33642 .54756 Mdot
.59684 .40491 Mdot
.46236 .39233 Mdot
.48804 .29749 Mdot
.49315 .30794 Mdot
.66184 .58182 Mdot
.4302 .67928 Mdot
.46651 .31341 Mdot
.63197 .39751 Mdot
.40692 .56311 Mdot
.43779 .50191 Mdot
.48097 .69611 Mdot
.37293 .21663 Mdot
.46156 .34906 Mdot
.7543 .61936 Mdot
.43878 .70994 Mdot
.47475 .63456 Mdot
.3572 .487 Mdot
.48657 .75654 Mdot
.45199 .74548 Mdot
.47464 .28659 Mdot
.66796 .56698 Mdot
.42936 .27403 Mdot
.63119 .5731 Mdot
.4369 .67195 Mdot
.42447 .51985 Mdot
.43403 .69886 Mdot
.40375 .5164 Mdot
.59303 .16929 Mdot
.40625 .47497 Mdot
.18391 .46871 Mdot
.33618 .37047 Mdot
.61031 .40645 Mdot
.73388 .5966 Mdot
.62079 .39762 Mdot
.444 .71466 Mdot
.42769 .52226 Mdot
.45426 .31299 Mdot
.8052 .54707 Mdot
.4124 .66193 Mdot
.6301 .44567 Mdot
.59119 .38724 Mdot
.63628 .56663 Mdot
.35267 .52549 Mdot
.3578 .48276 Mdot
.61579 .42473 Mdot
.4962 .72609 Mdot
.44511 .6482 Mdot
.41222 .50466 Mdot
.37198 .50014 Mdot
.6128 .40509 Mdot
.76876 .68639 Mdot
.41158 .64001 Mdot
.41087 .4905 Mdot
.71305 .38115 Mdot
.61496 .60244 Mdot
.415 .56787 Mdot
.33455 .5324 Mdot
.47939 .32343 Mdot
.24643 .55366 Mdot
.43583 .19421 Mdot
.62388 .56661 Mdot
.60261 .3962 Mdot
.40902 .51831 Mdot
.61184 .39247 Mdot
.43897 .50166 Mdot
.53968 .73456 Mdot
.66056 .4347 Mdot
.39951 .54749 Mdot
.45225 .49999 Mdot
.45363 .71841 Mdot
.35804 .52303 Mdot
.3837 .73955 Mdot
.60938 .4444 Mdot
.41542 .54528 Mdot
.30045 .5628 Mdot
.62724 .59903 Mdot
.44253 .55139 Mdot
.49429 .34627 Mdot
.27574 .40157 Mdot
.58443 .71799 Mdot
.64573 .26417 Mdot
.4976 .3119 Mdot
.36987 .45734 Mdot
.58744 .39486 Mdot
.6329 .63172 Mdot
.17996 .49343 Mdot
.35099 .47329 Mdot
.64101 .57416 Mdot
.65985 .60466 Mdot
.47383 .34586 Mdot
.4371 .83361 Mdot
.42932 .46865 Mdot
.3802 .47163 Mdot
.31298 .70228 Mdot
.48651 .66849 Mdot
.39858 .47072 Mdot
.41721 .4651 Mdot
.64615 .61979 Mdot
.38539 .58287 Mdot
.37904 .67553 Mdot
.23175 .45384 Mdot
.62656 .63599 Mdot
.50988 .5898 Mdot
.65771 .40165 Mdot
.47845 .30526 Mdot
.46672 .67566 Mdot
.4548 .32771 Mdot
.65569 .40894 Mdot
.41525 .4654 Mdot
.66838 .58035 Mdot
.35924 .74383 Mdot
.64478 .62778 Mdot
.61043 .24356 Mdot
.48596 .68291 Mdot
.5931 .65867 Mdot
.28896 .79463 Mdot
.77861 .55154 Mdot
.63314 .65427 Mdot
.48055 .32804 Mdot
.61552 .35429 Mdot
.37308 .50181 Mdot
.44125 .79227 Mdot
.40485 .45609 Mdot
.29099 .55587 Mdot
.60979 .38768 Mdot
.62026 .3821 Mdot
.41299 .49384 Mdot
.28651 .35915 Mdot
.63457 .6321 Mdot
.61663 .59582 Mdot
.40046 .54954 Mdot
.64256 .59465 Mdot
.38414 .47853 Mdot
.60352 .42454 Mdot
.28138 .74466 Mdot
.38629 .49873 Mdot
.32955 .49439 Mdot
.54786 .72824 Mdot
.81988 .58935 Mdot
.54092 .23846 Mdot
.67336 .78396 Mdot
.51347 .16961 Mdot
.64361 .59582 Mdot
.35781 .5405 Mdot
.50952 .59158 Mdot
.66586 .39822 Mdot
.61055 .55211 Mdot
.40427 .4636 Mdot
.40175 .45809 Mdot
.37983 .44447 Mdot
.36869 .51663 Mdot
.47098 .80394 Mdot
.45948 .56149 Mdot
.27709 .5962 Mdot
.36764 .53291 Mdot
.40048 .26473 Mdot
.65881 .57513 Mdot
.47113 .74514 Mdot
.48963 .293 Mdot
.35734 .52325 Mdot
.46036 .60311 Mdot
.66754 .62456 Mdot
.45663 .13782 Mdot
.65074 .57066 Mdot
.637 .42961 Mdot
.66025 .62418 Mdot
.38589 .51738 Mdot
.45296 .67669 Mdot
.52856 .55796 Mdot
.76324 .5076 Mdot
.59568 .40779 Mdot
.39382 .51301 Mdot
.62752 .50331 Mdot
.59419 .42078 Mdot
.80721 .48849 Mdot
.4597 .67816 Mdot
.33785 .32471 Mdot
.43206 .69316 Mdot
.40849 .54677 Mdot
.41256 .54383 Mdot
.62004 .64187 Mdot
.66501 .61938 Mdot
.43149 .69048 Mdot
.44919 .84544 Mdot
.47547 .35652 Mdot
.44652 .69679 Mdot
.37189 .4324 Mdot
.52375 .4798 Mdot
.45217 .68175 Mdot
.46401 .27 Mdot
.65501 .61254 Mdot
.45778 .63038 Mdot
.395 .43582 Mdot
.4471 .22605 Mdot
.50192 .33926 Mdot
.67213 .42537 Mdot
.43042 .33761 Mdot
.61074 .44712 Mdot
.66586 .56651 Mdot
.61879 .39809 Mdot
.63029 .62603 Mdot
.59066 .73645 Mdot
.49327 .62149 Mdot
.64709 .65425 Mdot
.67247 .5773 Mdot
.61925 .40054 Mdot
.4165 .50367 Mdot
.45837 .26639 Mdot
.37683 .55708 Mdot
.42475 .45645 Mdot
.62359 .61956 Mdot
.46463 .71078 Mdot
.46282 .74153 Mdot
.37495 .26949 Mdot
.43097 .6642 Mdot
.62655 .44359 Mdot
.18561 .58789 Mdot
.71197 .42789 Mdot
.62523 .58438 Mdot
.66674 .62074 Mdot
.39737 .54367 Mdot
.62146 .4193 Mdot
.59762 .39784 Mdot
.6366 .56789 Mdot
.52718 .67318 Mdot
.33838 .5307 Mdot
.46225 .73446 Mdot
.48144 .66024 Mdot
.44219 .68326 Mdot
.47461 .71264 Mdot
.39397 .6724 Mdot
.6661 .60201 Mdot
.4602 .71384 Mdot
.39131 .54611 Mdot
.40237 .46032 Mdot
.4949 .54976 Mdot
.49594 .31647 Mdot
.34186 .48868 Mdot
.44035 .54217 Mdot
.35445 .49447 Mdot
.65939 .42489 Mdot
.40821 .4078 Mdot
.65488 .43936 Mdot
.59226 .39318 Mdot
.59566 .3938 Mdot
.70793 .47904 Mdot
.3396 .26774 Mdot
.53087 .18964 Mdot
.42618 .50874 Mdot
.68854 .72395 Mdot
.62964 .41229 Mdot
.20233 .62181 Mdot
.66377 .71921 Mdot
.35738 .46218 Mdot
.57714 .34627 Mdot
.61393 .42056 Mdot
.42572 .67912 Mdot
.40542 .4674 Mdot
.59528 .45078 Mdot
.49548 .34672 Mdot
.39878 .55515 Mdot
.66037 .43659 Mdot
.44809 .65909 Mdot
.47205 .28397 Mdot
.47262 .64255 Mdot
.59824 .39141 Mdot
.45288 .51713 Mdot
.12498 .46902 Mdot
.5822 .39417 Mdot
.74498 .67779 Mdot
.31897 .54705 Mdot
.41409 .50422 Mdot
.62172 .45559 Mdot
.48441 .655 Mdot
.65845 .56158 Mdot
.56331 .47055 Mdot
.45785 .63457 Mdot
.62097 .38195 Mdot
.62687 .44888 Mdot
.59576 .4064 Mdot
.47108 .6515 Mdot
.34787 .45714 Mdot
.4547 .63802 Mdot
.65639 .62625 Mdot
.38547 .53558 Mdot
.61458 .21026 Mdot
.67629 .73057 Mdot
.43389 .70305 Mdot
.64589 .42749 Mdot
.50583 .33971 Mdot
.38239 .50698 Mdot
.67479 .73694 Mdot
.41671 .51002 Mdot
.62209 .62099 Mdot
.22113 .56707 Mdot
.38581 .75927 Mdot
.37339 .54964 Mdot
.39536 .54332 Mdot
.61708 .59926 Mdot
.39258 .5074 Mdot
.35602 .52959 Mdot
.71091 .48298 Mdot
.46137 .64435 Mdot
.37856 .49369 Mdot
.64335 .40561 Mdot
.72598 .45388 Mdot
.33413 .52167 Mdot
.69402 .38269 Mdot
.32432 .34041 Mdot
.22385 .58097 Mdot
.40602 .4568 Mdot
.47884 .43695 Mdot
.36378 .50581 Mdot
.37724 .45825 Mdot
.4042 .53677 Mdot
.51537 .82016 Mdot
.66336 .43025 Mdot
.60275 .40422 Mdot
.50143 .32239 Mdot
.3268 .33733 Mdot
.47698 .31913 Mdot
.65665 .61286 Mdot
.62217 .29291 Mdot
.65603 .43841 Mdot
.43985 .66331 Mdot
.36866 .46193 Mdot
.58191 .39535 Mdot
.35391 .48855 Mdot
.38742 .51877 Mdot
.59348 .43522 Mdot
.66408 .40992 Mdot
.67554 .29587 Mdot
.50058 .32922 Mdot
.45471 .69695 Mdot
.34595 .52006 Mdot
.46022 .34349 Mdot
.4196 .46183 Mdot
.38316 .34581 Mdot
.45234 .69449 Mdot
.45856 .64155 Mdot
.45807 .74328 Mdot
.41625 .46797 Mdot
.38557 .51259 Mdot
.6356 .61784 Mdot
.43282 .70565 Mdot
.62849 .59565 Mdot
.5872 .50844 Mdot
.6565 .34298 Mdot
.40419 .46338 Mdot
.69491 .66473 Mdot
.48701 .31439 Mdot
.6381 .44054 Mdot
.27123 .31859 Mdot
.502 .32392 Mdot
.4057 .51479 Mdot
.58788 .40862 Mdot
.49253 .33223 Mdot
.27107 .46181 Mdot
.42203 .16954 Mdot
.50549 .32315 Mdot
.39041 .54617 Mdot
.40534 .58647 Mdot
.6602 .79349 Mdot
.49971 .312 Mdot
.67051 .60678 Mdot
.41638 .46908 Mdot
.4204 .70967 Mdot
.45401 .3261 Mdot
.77857 .4786 Mdot
.60777 .41958 Mdot
.44709 .2139 Mdot
.46455 .49783 Mdot
.40823 .78378 Mdot
.48828 .30697 Mdot
.46102 .66659 Mdot
.31058 .51008 Mdot
.35835 .49239 Mdot
.50093 .31629 Mdot
.65202 .64568 Mdot
.6157 .43323 Mdot
.73955 .47604 Mdot
.47171 .65166 Mdot
.59964 .64076 Mdot
.65021 .42483 Mdot
.75842 .6124 Mdot
.22464 .49397 Mdot
.42392 .56701 Mdot
.64259 .79661 Mdot
.67317 .53563 Mdot
.36862 .44486 Mdot
.50666 .3485 Mdot
.61695 .57326 Mdot
.67022 .5812 Mdot
.64524 .58713 Mdot
.60072 .74295 Mdot
.49682 .48746 Mdot
.62606 .45911 Mdot
.59857 .61211 Mdot
.4782 .30628 Mdot
.42419 .27183 Mdot
.43434 .46558 Mdot
.37768 .50155 Mdot
.35956 .53687 Mdot
.35238 .51525 Mdot
.36363 .49603 Mdot
.63527 .59486 Mdot
.57663 .74083 Mdot
.49691 .51785 Mdot
.45117 .68821 Mdot
.64738 .28824 Mdot
.62927 .40066 Mdot
.62901 .45992 Mdot
.49497 .33677 Mdot
.78996 .54979 Mdot
.67191 .39575 Mdot
.63916 .41829 Mdot
.35099 .46082 Mdot
.446 .64372 Mdot
.36131 .5665 Mdot
.3933 .54474 Mdot
.62557 .44213 Mdot
.55914 .56188 Mdot
.38789 .70998 Mdot
.36174 .40095 Mdot
.51012 .30805 Mdot
.50759 .47205 Mdot
.50438 .33696 Mdot
.43018 .51682 Mdot
.20384 .63994 Mdot
.65658 .40984 Mdot
.62929 .42786 Mdot
.49021 .31252 Mdot
.47331 .76662 Mdot
.47169 .68025 Mdot
.69079 .65586 Mdot
.6531 .62207 Mdot
.42187 .53073 Mdot
.21599 .43006 Mdot
.29302 .46737 Mdot
.59222 .2798 Mdot
.64278 .58181 Mdot
.61779 .39207 Mdot
.39435 .56204 Mdot
.38412 .54311 Mdot
.48947 .31716 Mdot
.71756 .31001 Mdot
.42501 .55655 Mdot
.82674 .46136 Mdot
.31405 .27055 Mdot
.40134 .22071 Mdot
.35751 .4854 Mdot
.46367 .64509 Mdot
.67292 .41749 Mdot
.47281 .30076 Mdot
.38577 .42934 Mdot
.45906 .16952 Mdot
.48177 .68898 Mdot
.65579 .58062 Mdot
.54597 .54419 Mdot
.42606 .28737 Mdot
.3999 .44734 Mdot
.40726 .45998 Mdot
.38492 .45279 Mdot
.36095 .18536 Mdot
.65988 .43007 Mdot
.42811 .69011 Mdot
.47742 .34628 Mdot
.4335 .66285 Mdot
.60985 .40118 Mdot
.59007 .64213 Mdot
.419 .50188 Mdot
.4831 .68574 Mdot
.46223 .66781 Mdot
.64695 .56873 Mdot
.64997 .5572 Mdot
.56359 .52668 Mdot
.40479 .47528 Mdot
.58764 .38695 Mdot
.45732 .71646 Mdot
.49012 .44093 Mdot
.4742 .33055 Mdot
.65236 .61612 Mdot
.36315 .52839 Mdot
.66334 .42014 Mdot
.43283 .45547 Mdot
.46351 .68982 Mdot
.63849 .41802 Mdot
.70824 .35205 Mdot
.49357 .30267 Mdot
.39303 .46254 Mdot
.44497 .32827 Mdot
.60031 .39781 Mdot
.37174 .50327 Mdot
.76951 .61739 Mdot
.46218 .27197 Mdot
.76764 .48308 Mdot
.59111 .40075 Mdot
.69342 .46556 Mdot
.43478 .64457 Mdot
.60977 .75508 Mdot
.63231 .43014 Mdot
.7433 .63391 Mdot
.72611 .34708 Mdot
.39824 .56442 Mdot
.43627 .68558 Mdot
.66074 .52855 Mdot
.65544 .21376 Mdot
.73819 .70817 Mdot
.39846 .49931 Mdot
.59338 .44519 Mdot
.49138 .3231 Mdot
.62286 .5887 Mdot
.68886 .36666 Mdot
.47643 .27565 Mdot
.61761 .37841 Mdot
.40478 .53593 Mdot
.45373 .66328 Mdot
.64927 .61134 Mdot
.58775 .72264 Mdot
.63637 .39941 Mdot
.64852 .41671 Mdot
.39068 .56071 Mdot
.47707 .3135 Mdot
.64163 .7578 Mdot
.59974 .42024 Mdot
.33264 .25997 Mdot
.5669 .40377 Mdot
.4678 .35212 Mdot
.36305 .5136 Mdot
.3762 .26406 Mdot
.33656 .51534 Mdot
.78716 .6224 Mdot
.62492 .40137 Mdot
.45868 .69174 Mdot
.38336 .44688 Mdot
.2434 .4497 Mdot
.6296 .4424 Mdot
.50382 .44977 Mdot
.54248 .26988 Mdot
.66211 .60831 Mdot
.26794 .32184 Mdot
.39113 .47038 Mdot
.63426 .63166 Mdot
.48745 .31721 Mdot
.40827 .48436 Mdot
.38353 .51443 Mdot
.44867 .72233 Mdot
.64183 .56909 Mdot
.69835 .30819 Mdot
.66091 .62859 Mdot
.66563 .58028 Mdot
.46088 .72617 Mdot
.37458 .48328 Mdot
.63862 .42889 Mdot
.61562 .42173 Mdot
.41168 .43497 Mdot
.24398 .72017 Mdot
.4742 .67901 Mdot
.67555 .42246 Mdot
.34768 .19397 Mdot
.4344 .44621 Mdot
.25691 .3409 Mdot
.72597 .3176 Mdot
.6174 .61943 Mdot
.38801 .54674 Mdot
.44672 .6611 Mdot
.54729 .38484 Mdot
.64747 .42018 Mdot
.39053 .43918 Mdot
.65009 .60878 Mdot
.49874 .3437 Mdot
.60366 .43694 Mdot
.60199 .27937 Mdot
.38263 .45947 Mdot
.56883 .34652 Mdot
.60453 .45105 Mdot
.76478 .29809 Mdot
.7261 .56449 Mdot
.43757 .69096 Mdot
.38616 .52152 Mdot
.42452 .68015 Mdot
.48084 .34685 Mdot
.54773 .54084 Mdot
.65494 .60889 Mdot
.47235 .51153 Mdot
.15846 .57561 Mdot
.5959 .40488 Mdot
.42734 .68979 Mdot
.37698 .55217 Mdot
.5343 .73317 Mdot
.38563 .47352 Mdot
.4056 .59209 Mdot
.43908 .35188 Mdot
.62195 .60865 Mdot
.63512 .62813 Mdot
.37279 .51378 Mdot
.46796 .34733 Mdot
.63134 .39864 Mdot
.62237 .43829 Mdot
.84965 .42067 Mdot
.5564 .63043 Mdot
.26461 .38767 Mdot
.39939 .45806 Mdot
.61056 .37958 Mdot
.73473 .42872 Mdot
.63647 .57661 Mdot
.41396 .43152 Mdot
.59152 .4276 Mdot
.49159 .25286 Mdot
.27636 .41656 Mdot
.36092 .4987 Mdot
.33617 .47093 Mdot
.65829 .61912 Mdot
.48944 .47231 Mdot
.62329 .38701 Mdot
.44841 .49318 Mdot
.65152 .65723 Mdot
.27387 .43875 Mdot
.36475 .20988 Mdot
.45453 .69727 Mdot
.58481 .26385 Mdot
.63479 .59558 Mdot
.33124 .48095 Mdot
.45821 .3261 Mdot
.67231 .40597 Mdot
.6635 .42552 Mdot
.40681 .52604 Mdot
.42669 .54067 Mdot
.28718 .31809 Mdot
.43937 .65492 Mdot
.6608 .57799 Mdot
.41462 .47903 Mdot
.6555 .68397 Mdot
.3531 .52063 Mdot
.63094 .61493 Mdot
.11675 .47855 Mdot
.37488 .55457 Mdot
.38168 .47334 Mdot
.65966 .74514 Mdot
.46797 .64158 Mdot
.42764 .69816 Mdot
.22145 .38738 Mdot
.39893 .45829 Mdot
.29293 .29619 Mdot
.45869 .69869 Mdot
.47093 .68404 Mdot
.72239 .49053 Mdot
.38172 .5041 Mdot
.46299 .45021 Mdot
.62259 .62421 Mdot
.66955 .58678 Mdot
.46178 .63976 Mdot
.41745 .56562 Mdot
.62984 .563 Mdot
.54074 .80659 Mdot
.62151 .41756 Mdot
.21342 .66155 Mdot
.477 .68125 Mdot
.69184 .5799 Mdot
.63879 .57852 Mdot
.46624 .14083 Mdot
.58385 .46516 Mdot
.41709 .50009 Mdot
.39244 .45898 Mdot
.4844 .30963 Mdot
.35579 .53503 Mdot
.61903 .38242 Mdot
.64214 .59408 Mdot
.27635 .52728 Mdot
.44967 .6974 Mdot
.39661 .47669 Mdot
.79761 .52882 Mdot
.78794 .4482 Mdot
.58357 .25362 Mdot
.47213 .6711 Mdot
.43767 .69977 Mdot
.63505 .39209 Mdot
.59385 .44498 Mdot
.36563 .48483 Mdot
.61921 .58535 Mdot
.43297 .70516 Mdot
.62717 .61672 Mdot
.65682 .41139 Mdot
.63977 .42501 Mdot
.66781 .41964 Mdot
.43978 .47738 Mdot
.64213 .41274 Mdot
.69111 .35117 Mdot
.59987 .63698 Mdot
.45148 .73063 Mdot
.27978 .28041 Mdot
.5951 .7236 Mdot
.43369 .75016 Mdot
.45321 .32801 Mdot
.59763 .4001 Mdot
.65114 .63033 Mdot
.37528 .52899 Mdot
.35291 .50532 Mdot
.69762 .43865 Mdot
.63958 .63612 Mdot
.48173 .34523 Mdot
.63869 .63007 Mdot
.474 .34615 Mdot
.55047 .31687 Mdot
.34752 .51633 Mdot
.43711 .5085 Mdot
.63716 .59064 Mdot
.64034 .41468 Mdot
.60315 .41153 Mdot
.5028 .31353 Mdot
.575 .55903 Mdot
.59381 .42133 Mdot
.47247 .68839 Mdot
.39899 .68592 Mdot
.62915 .44933 Mdot
.40323 .4683 Mdot
.40746 .34271 Mdot
.4328 .79744 Mdot
.3313 .50119 Mdot
.71749 .48748 Mdot
.35081 .75292 Mdot
.36725 .45553 Mdot
.41287 .80224 Mdot
.66384 .49575 Mdot
.4365 .64459 Mdot
.61373 .38726 Mdot
.67351 .38741 Mdot
.36538 .41881 Mdot
.49332 .29149 Mdot
.39667 .4303 Mdot
.47955 .67696 Mdot
.4258 .64277 Mdot
.41232 .22831 Mdot
.76079 .66239 Mdot
.49142 .3272 Mdot
.49515 .32853 Mdot
.6314 .43255 Mdot
.83788 .60351 Mdot
.43237 .576 Mdot
.48284 .34338 Mdot
.50363 .6322 Mdot
.4054 .53325 Mdot
.31614 .36715 Mdot
.52479 .36744 Mdot
.46538 .64416 Mdot
.39961 .2589 Mdot
.63632 .43605 Mdot
.43105 .66203 Mdot
.63465 .68786 Mdot
.341 .48272 Mdot
.45107 .69461 Mdot
.63045 .61844 Mdot
.74108 .55121 Mdot
.47181 .69668 Mdot
.39746 .34233 Mdot
.63003 .56875 Mdot
.49416 .44568 Mdot
.35527 .29129 Mdot
.53281 .89947 Mdot
.63833 .59643 Mdot
.63004 .44748 Mdot
.61543 .42274 Mdot
.62363 .4382 Mdot
.43535 .65773 Mdot
.59847 .39735 Mdot
.43809 .65885 Mdot
.68341 .75807 Mdot
.48998 .76617 Mdot
.48345 .34169 Mdot
.74185 .47993 Mdot
.44502 .66872 Mdot
.19403 .61611 Mdot
.20755 .70293 Mdot
.38881 .54738 Mdot
.6728 .61633 Mdot
.48664 .33743 Mdot
.82857 .47237 Mdot
.4824 .32383 Mdot
.37405 .2457 Mdot
.2153 .60135 Mdot
.38992 .48056 Mdot
.35386 .67509 Mdot
.47194 .2942 Mdot
.46841 .66172 Mdot
.37312 .50433 Mdot
.54194 .43051 Mdot
.48253 .31956 Mdot
.48686 .3528 Mdot
.37064 .48981 Mdot
.4556 .71049 Mdot
.64201 .43329 Mdot
.67178 .61048 Mdot
.45528 .30265 Mdot
.34071 .56069 Mdot
.33412 .48962 Mdot
.4185 .51416 Mdot
.49948 .54522 Mdot
.48511 .37201 Mdot
.64384 .59674 Mdot
.4769 .82611 Mdot
.58515 .40867 Mdot
.54772 .43523 Mdot
.34325 .24579 Mdot
.69782 .48871 Mdot
.62375 .40321 Mdot
.61094 .39412 Mdot
.3625 .49302 Mdot
.50636 .36908 Mdot
.21648 .61478 Mdot
.59754 .54495 Mdot
.66913 .42588 Mdot
.61833 .43636 Mdot
.42329 .66433 Mdot
.39676 .22884 Mdot
.37975 .42949 Mdot
.6239 .56605 Mdot
.66507 .42119 Mdot
.5267 .76031 Mdot
.47651 .31022 Mdot
.20228 .58653 Mdot
.34498 .51065 Mdot
.41656 .49352 Mdot
.65429 .59921 Mdot
.6389 .6171 Mdot
.54426 .38532 Mdot
.3884 .23395 Mdot
.36361 .75851 Mdot
.56815 .72237 Mdot
.23766 .59372 Mdot
.4226 .65751 Mdot
.43429 .70377 Mdot
.77335 .52122 Mdot
.6643 .62656 Mdot
.37368 .45131 Mdot
.43019 .68246 Mdot
.55935 .45102 Mdot
.40564 .6804 Mdot
.28692 .37391 Mdot
.26391 .34477 Mdot
.40135 .51575 Mdot
.45505 .64569 Mdot
.47117 .64585 Mdot
.49078 .68863 Mdot
.64642 .5052 Mdot
.36858 .47771 Mdot
.40001 .50818 Mdot
.35991 .46673 Mdot
.52104 .71921 Mdot
.36942 .46739 Mdot
.60018 .75602 Mdot
.54786 .52194 Mdot
.25114 .54444 Mdot
.44785 .51061 Mdot
.61261 .61179 Mdot
.40479 .45139 Mdot
.46959 .34816 Mdot
.40725 .53956 Mdot
.2838 .37936 Mdot
.64698 .57531 Mdot
.41059 .64482 Mdot
.59529 .73253 Mdot
.37076 .44676 Mdot
.46826 .2869 Mdot
.71124 .58989 Mdot
.5988 .20202 Mdot
.44101 .31628 Mdot
.47357 .68705 Mdot
.62265 .41207 Mdot
.64861 .63198 Mdot
.63583 .42449 Mdot
.44261 .50469 Mdot
.77393 .5366 Mdot
.79468 .42698 Mdot
.59419 .51341 Mdot
.35337 .51596 Mdot
.4553 .4573 Mdot
.46872 .6886 Mdot
.58624 .41152 Mdot
.44249 .74573 Mdot
.38627 .44807 Mdot
.46987 .33932 Mdot
.48483 .31606 Mdot
.57043 .47505 Mdot
.75136 .31435 Mdot
.52757 .7887 Mdot
.65191 .59957 Mdot
.60372 .42663 Mdot
.46201 .30486 Mdot
.72915 .66915 Mdot
.64808 .5559 Mdot
.61725 .60665 Mdot
.65272 .57523 Mdot
.42354 .47881 Mdot
.66141 .43407 Mdot
.25261 .54236 Mdot
.6175 .3801 Mdot
.3919 .51024 Mdot
.65843 .42856 Mdot
.59064 .42224 Mdot
.46485 .30618 Mdot
.65643 .57492 Mdot
.65085 .40308 Mdot
.41233 .54524 Mdot
.45678 .70463 Mdot
.68392 .62727 Mdot
.31944 .38528 Mdot
.76764 .65019 Mdot
.28907 .51966 Mdot
.48195 .66475 Mdot
.6559 .21916 Mdot
.61596 .60855 Mdot
.52759 .68299 Mdot
.66824 .2916 Mdot
.42827 .51114 Mdot
.21189 .68861 Mdot
.63203 .45932 Mdot
.59544 .43326 Mdot
.36399 .51305 Mdot
.57756 .37429 Mdot
.39221 .47633 Mdot
.65459 .41801 Mdot
.70881 .3909 Mdot
.44271 .60717 Mdot
.63746 .40988 Mdot
.44656 .48477 Mdot
.37872 .51333 Mdot
.46118 .64161 Mdot
.6194 .45447 Mdot
.40541 .42634 Mdot
.84078 .4009 Mdot
.63583 .61407 Mdot
.65571 .51683 Mdot
.41176 .35603 Mdot
.63363 .59607 Mdot
.44456 .69448 Mdot
.4279 .45912 Mdot
.48872 .31804 Mdot
.4451 .66688 Mdot
.265 .43117 Mdot
.48835 .30021 Mdot
.19368 .6435 Mdot
.47274 .64988 Mdot
.62115 .44835 Mdot
.45969 .33419 Mdot
.34966 .53048 Mdot
.67264 .40752 Mdot
.73586 .58521 Mdot
.62565 .40381 Mdot
.35872 .48111 Mdot
.75309 .46092 Mdot
.66335 .58024 Mdot
.4002 .49685 Mdot
.59909 .43758 Mdot
.7156 .48017 Mdot
.42534 .48525 Mdot
.36817 .50926 Mdot
.36545 .21725 Mdot
.18644 .53482 Mdot
.47808 .32837 Mdot
.49057 .67006 Mdot
.39183 .54623 Mdot
.48909 .35024 Mdot
.60631 .3242 Mdot
.41989 .48217 Mdot
.48146 .69242 Mdot
.44162 .45229 Mdot
.61342 .45413 Mdot
.62972 .60178 Mdot
.61514 .51772 Mdot
.49535 .34669 Mdot
.66117 .81974 Mdot
.64953 .39552 Mdot
.43555 .50375 Mdot
.35962 .52863 Mdot
.51451 .22587 Mdot
.43628 .64597 Mdot
.29037 .72022 Mdot
.39298 .46227 Mdot
.5204 .7126 Mdot
.40567 .48442 Mdot
.65543 .44724 Mdot
.47203 .68124 Mdot
.37724 .47149 Mdot
.64558 .66795 Mdot
.32932 .50594 Mdot
.5006 .32276 Mdot
.66526 .74522 Mdot
.34284 .46871 Mdot
.13076 .54891 Mdot
.53471 .33542 Mdot
.63846 .40828 Mdot
.7803 .45806 Mdot
.88025 .46177 Mdot
.6053 .73956 Mdot
.43333 .66692 Mdot
.75215 .35593 Mdot
.63913 .42828 Mdot
.76003 .43179 Mdot
.64716 .2114 Mdot
.37884 .51987 Mdot
.39927 .44686 Mdot
.46023 .24715 Mdot
.59553 .39138 Mdot
.59984 .37868 Mdot
.42237 .55294 Mdot
.33416 .47031 Mdot
.64363 .41981 Mdot
.42234 .5391 Mdot
.43529 .53442 Mdot
.67491 .60826 Mdot
.48048 .68507 Mdot
.62014 .60388 Mdot
.62665 .56724 Mdot
.58847 .79711 Mdot
.52773 .30328 Mdot
.63091 .61256 Mdot
.6129 .59106 Mdot
.31285 .37036 Mdot
.30913 .31564 Mdot
.45391 .32375 Mdot
.78165 .33493 Mdot
.61885 .43459 Mdot
.37312 .47846 Mdot
.47808 .65585 Mdot
.37373 .75967 Mdot
.66098 .3281 Mdot
.22549 .66075 Mdot
.37951 .44934 Mdot
.63267 .44085 Mdot
.64696 .50539 Mdot
.35258 .56147 Mdot
.57906 .42944 Mdot
.41418 .474 Mdot
.63009 .38094 Mdot
.36778 .6252 Mdot
.74331 .63219 Mdot
.57907 .38951 Mdot
.46174 .73346 Mdot
.41403 .48522 Mdot
.47871 .67477 Mdot
.6346 .58069 Mdot
.45766 .33365 Mdot
.47521 .3268 Mdot
.37128 .4983 Mdot
.45161 .53372 Mdot
.55725 .3331 Mdot
.38188 .50821 Mdot
.4011 .53642 Mdot
.66476 .49487 Mdot
.40067 .53942 Mdot
.34885 .50018 Mdot
.35348 .47896 Mdot
.39811 .441 Mdot
.66774 .58353 Mdot
.79087 .54496 Mdot
.33452 .44948 Mdot
.33115 .46213 Mdot
.65376 .56107 Mdot
.70576 .30697 Mdot
.61935 .5763 Mdot
.60318 .19883 Mdot
.62638 .62741 Mdot
.474 .33501 Mdot
.56966 .22858 Mdot
.45565 .54154 Mdot
.46424 .71624 Mdot
.646 .55092 Mdot
.47898 .34845 Mdot
.64391 .59015 Mdot
.65272 .42642 Mdot
.37898 .19546 Mdot
.45161 .61487 Mdot
.47943 .54106 Mdot
.62657 .54382 Mdot
.76675 .56473 Mdot
.64437 .39443 Mdot
.47724 .6689 Mdot
.38118 .70321 Mdot
.35044 .51193 Mdot
.48563 .35172 Mdot
.3664 .48815 Mdot
.6549 .57023 Mdot
.63251 .43753 Mdot
.72098 .71822 Mdot
.4892 .31682 Mdot
.30167 .26324 Mdot
.60644 .41479 Mdot
.34937 .48322 Mdot
.62795 .56427 Mdot
.23007 .33994 Mdot
.62124 .61016 Mdot
.25024 .6637 Mdot
.42685 .66155 Mdot
.68785 .77437 Mdot
.43931 .67418 Mdot
.74208 .59098 Mdot
.22087 .30351 Mdot
.79783 .54481 Mdot
.4552 .70895 Mdot
.56959 .60804 Mdot
.40694 .51795 Mdot
.41881 .51298 Mdot
.73654 .66998 Mdot
.49051 .67241 Mdot
.37343 .53881 Mdot
.71439 .41467 Mdot
.58397 .62207 Mdot
.23742 .38395 Mdot
.61941 .39474 Mdot
.39374 .47228 Mdot
.6117 .62494 Mdot
.63479 .63469 Mdot
.63394 .3846 Mdot
.61621 .60501 Mdot
.39835 .50687 Mdot
.44405 .6696 Mdot
.66366 .35883 Mdot
.46741 .32161 Mdot
.8353 .53884 Mdot
.48395 .35886 Mdot
.62313 .40322 Mdot
.37527 .55658 Mdot
.63985 .42408 Mdot
.89285 .43486 Mdot
.40511 .5066 Mdot
.45931 .69713 Mdot
.39031 .54253 Mdot
.41292 .4891 Mdot
.39057 .44248 Mdot
.64723 .42624 Mdot
.36641 .39349 Mdot
.41691 .54299 Mdot
.65595 .6091 Mdot
.24585 .57591 Mdot
.34614 .46524 Mdot
.65059 .36937 Mdot
.30786 .33484 Mdot
.59695 .58477 Mdot
.45194 .62998 Mdot
.63343 .40631 Mdot
.44968 .70112 Mdot
.4886 .74877 Mdot
.44467 .69413 Mdot
.27266 .6435 Mdot
.38086 .68755 Mdot
.25172 .47725 Mdot
.29746 .55796 Mdot
.54186 .58993 Mdot
.4906 .67114 Mdot
.48359 .37537 Mdot
.44185 .71332 Mdot
.4606 .63649 Mdot
.07825 .45034 Mdot
.46605 .71884 Mdot
.40022 .46496 Mdot
.34583 .47221 Mdot
.76491 .58774 Mdot
.36854 .33399 Mdot
.38427 .53652 Mdot
.37669 .53607 Mdot
.45863 .31418 Mdot
.51089 .71791 Mdot
.77284 .49205 Mdot
.1797 .54969 Mdot
.77399 .4233 Mdot
.36845 .48975 Mdot
.3949 .54673 Mdot
.32913 .5316 Mdot
.17136 .43687 Mdot
.59038 .80645 Mdot
.43038 .61771 Mdot
.33491 .53647 Mdot
.80322 .57777 Mdot
.39238 .44426 Mdot
.41647 .46429 Mdot
.40352 .51639 Mdot
.63896 .42907 Mdot
.46501 .63326 Mdot
.40822 .44274 Mdot
.47097 .24863 Mdot
.41259 .46463 Mdot
.70301 .48699 Mdot
.77586 .69558 Mdot
.39066 .46998 Mdot
.44804 .6232 Mdot
.41787 .51801 Mdot
.44418 .63918 Mdot
.46602 .65434 Mdot
.37818 .56515 Mdot
.23871 .59709 Mdot
.43436 .6329 Mdot
.39142 .51081 Mdot
.64464 .43638 Mdot
.75969 .29752 Mdot
.35946 .47945 Mdot
.45636 .33254 Mdot
.39388 .45924 Mdot
.46269 .28806 Mdot
.39675 .53627 Mdot
.64887 .39424 Mdot
.40508 .77586 Mdot
.6289 .42966 Mdot
.62604 .80567 Mdot
.66609 .41452 Mdot
.34952 .22003 Mdot
.48581 .67216 Mdot
.74632 .47186 Mdot
.34095 .77333 Mdot
.67115 .51485 Mdot
.49876 .42077 Mdot
.52449 .52442 Mdot
.61864 .58692 Mdot
.42829 .66315 Mdot
.51991 .63085 Mdot
.67907 .31057 Mdot
.61275 .25748 Mdot
.59794 .42681 Mdot
.43577 .83639 Mdot
.25313 .71201 Mdot
.42828 .5272 Mdot
.34013 .68498 Mdot
.2968 .62339 Mdot
.39492 .44369 Mdot
.41412 .44789 Mdot
.6696 .47491 Mdot
.41026 .54984 Mdot
.66269 .68186 Mdot
.61913 .4028 Mdot
.47975 .34948 Mdot
.46553 .69378 Mdot
.49834 .34509 Mdot
.6694 .29721 Mdot
.52093 .52317 Mdot
.65626 .41762 Mdot
.34034 .46565 Mdot
.37463 .53167 Mdot
.45084 .63938 Mdot
.41246 .69032 Mdot
.45045 .71707 Mdot
.48885 .33081 Mdot
.61466 .40641 Mdot
.44987 .79759 Mdot
.3689 .5293 Mdot
.46165 .66916 Mdot
.50005 .40862 Mdot
.38934 .54596 Mdot
.63483 .58638 Mdot
.40962 .51359 Mdot
.45998 .70724 Mdot
.40043 .53945 Mdot
.43816 .67364 Mdot
.62304 .41463 Mdot
.35421 .46385 Mdot
.36146 .50705 Mdot
.26162 .3046 Mdot
.47731 .34253 Mdot
.48564 .68515 Mdot
.59359 .47882 Mdot
.3669 .54057 Mdot
.73595 .5 Mdot
.41157 .47018 Mdot
.44281 .76361 Mdot
.43099 .49871 Mdot
.66458 .51075 Mdot
.35106 .43398 Mdot
.36224 .47668 Mdot
.52379 .40154 Mdot
.29542 .63364 Mdot
.42177 .61208 Mdot
.61498 .57451 Mdot
.47858 .70977 Mdot
.24079 .38491 Mdot
.56333 .41179 Mdot
.58594 .42887 Mdot
.41096 .2747 Mdot
.39186 .43847 Mdot
.38755 .48049 Mdot
.60866 .57897 Mdot
.49737 .32502 Mdot
.4716 .66909 Mdot
.47402 .34604 Mdot
.28618 .29499 Mdot
.49249 .30911 Mdot
.64042 .4565 Mdot
.57181 .34548 Mdot
.46908 .80095 Mdot
.45964 .31173 Mdot
.45669 .71091 Mdot
.63776 .34561 Mdot
.38206 .43817 Mdot
.53484 .34601 Mdot
.46501 .33099 Mdot
.51341 .85744 Mdot
.34912 .49883 Mdot
.49484 .41869 Mdot
.6265 .60654 Mdot
.45782 .32341 Mdot
.62925 .57325 Mdot
.37478 .52571 Mdot
.76953 .48291 Mdot
.43298 .67035 Mdot
.65001 .56376 Mdot
.44412 .54548 Mdot
.48749 .33851 Mdot
.66316 .42858 Mdot
.61936 .55893 Mdot
.6217 .56629 Mdot
.71512 .30349 Mdot
.70097 .7424 Mdot
.61291 .4085 Mdot
.22011 .48464 Mdot
.62684 .62979 Mdot
.37429 .44159 Mdot
.51685 .69153 Mdot
.41743 .49904 Mdot
.58145 .77382 Mdot
.63112 .40143 Mdot
.77659 .56289 Mdot
.3959 .54481 Mdot
.3705 .45846 Mdot
.44498 .61671 Mdot
.62085 .42865 Mdot
.45107 .67835 Mdot
.48186 .70776 Mdot
.62176 .41566 Mdot
.43758 .68595 Mdot
.47803 .29402 Mdot
.57517 .65659 Mdot
.65158 .62366 Mdot
.66214 .60086 Mdot
.62146 .43841 Mdot
.63996 .40554 Mdot
.63868 .4195 Mdot
.41005 .51337 Mdot
.47311 .67453 Mdot
.38831 .52622 Mdot
.40988 .45779 Mdot
.2388 .56382 Mdot
.46842 .63911 Mdot
.39729 .5216 Mdot
.53999 .41464 Mdot
.52427 .34404 Mdot
.64732 .43596 Mdot
.6294 .60992 Mdot
.72803 .43293 Mdot
.73042 .59252 Mdot
.39734 .47215 Mdot
.50788 .26493 Mdot
.45209 .71334 Mdot
.487 .31967 Mdot
.48421 .36515 Mdot
.48108 .32576 Mdot
.62095 .53229 Mdot
.48961 .67896 Mdot
.18022 .56006 Mdot
.39067 .47478 Mdot
.50071 .53495 Mdot
.49176 .61531 Mdot
.54619 .32012 Mdot
.63193 .61121 Mdot
.38511 .54311 Mdot
.61109 .51891 Mdot
.393 .72866 Mdot
.41558 .49983 Mdot
.35243 .45573 Mdot
.70968 .3587 Mdot
.43482 .43937 Mdot
.42306 .68621 Mdot
.23113 .34491 Mdot
.36709 .54597 Mdot
.52083 .76317 Mdot
.8431 .54247 Mdot
.40578 .47259 Mdot
.38088 .45303 Mdot
.35678 .51349 Mdot
.40986 .53748 Mdot
.44153 .6277 Mdot
.36529 .30137 Mdot
.62102 .62681 Mdot
.49852 .5298 Mdot
.67307 .59242 Mdot
.66849 .40601 Mdot
.78223 .56109 Mdot
.42664 .66793 Mdot
.4848 .31 Mdot
.81254 .48949 Mdot
.19279 .44413 Mdot
.62218 .38709 Mdot
.54015 .80453 Mdot
.46947 .33672 Mdot
.36627 .44543 Mdot
.46979 .29114 Mdot
.65149 .44142 Mdot
.66233 .60643 Mdot
.35938 .44279 Mdot
.44025 .71041 Mdot
.47408 .6934 Mdot
.38087 .54372 Mdot
.80742 .56166 Mdot
.63123 .58922 Mdot
.62539 .55857 Mdot
.4226 .48366 Mdot
.34904 .52914 Mdot
.44837 .68106 Mdot
.60355 .42286 Mdot
.25014 .42251 Mdot
.49575 .33765 Mdot
.43731 .47029 Mdot
.4058 .53592 Mdot
.3523 .23772 Mdot
.65411 .61384 Mdot
.58824 .44253 Mdot
.42839 .50277 Mdot
.56021 .72018 Mdot
.42797 .50626 Mdot
.34566 .55058 Mdot
.64301 .43823 Mdot
.33211 .44659 Mdot
.43385 .52077 Mdot
.46766 .61897 Mdot
.62164 .58504 Mdot
.4549 .69407 Mdot
.49238 .65985 Mdot
.49511 .58054 Mdot
.63674 .58565 Mdot
.40342 .52238 Mdot
.63681 .60876 Mdot
.41959 .4832 Mdot
.3979 .55004 Mdot
.63056 .61458 Mdot
.45012 .67822 Mdot
.75148 .36001 Mdot
.79384 .53683 Mdot
.41269 .53729 Mdot
.4044 .56303 Mdot
.36409 .31608 Mdot
.37698 .39296 Mdot
.39017 .44679 Mdot
.46384 .70457 Mdot
.36613 .52226 Mdot
.63598 .57225 Mdot
.47045 .29517 Mdot
.45736 .70564 Mdot
.60241 .40658 Mdot
.63093 .38822 Mdot
.5994 .73403 Mdot
.58977 .41006 Mdot
.40781 .44954 Mdot
.4596 .75063 Mdot
.4778 .63555 Mdot
.82339 .56715 Mdot
.61961 .41833 Mdot
.45292 .31892 Mdot
.36878 .5074 Mdot
.44763 .2258 Mdot
.61386 .63033 Mdot
.14348 .60957 Mdot
.1906 .61343 Mdot
.50501 .30864 Mdot
.22645 .65444 Mdot
.65999 .40164 Mdot
.43931 .50777 Mdot
.46011 .34047 Mdot
.63361 .39189 Mdot
.4228 .52017 Mdot
.36888 .56291 Mdot
.27847 .70648 Mdot
.5221 .57432 Mdot
.63841 .61079 Mdot
.59666 .39756 Mdot
.50969 .31605 Mdot
.62374 .46095 Mdot
.48077 .66781 Mdot
.36756 .4741 Mdot
.37695 .55906 Mdot
.59989 .41411 Mdot
.58264 .40914 Mdot
.39509 .51521 Mdot
.42464 .67882 Mdot
.66068 .48185 Mdot
.37355 .49257 Mdot
.54306 .61628 Mdot
.48835 .71417 Mdot
.61606 .39891 Mdot
.36668 .46439 Mdot
.45868 .3863 Mdot
.60486 .41692 Mdot
.6491 .43536 Mdot
.3902 .54802 Mdot
.48201 .29547 Mdot
.39612 .56223 Mdot
.63183 .62727 Mdot
.48488 .83403 Mdot
.63818 .5705 Mdot
.69061 .3751 Mdot
.44664 .54345 Mdot
.54981 .68385 Mdot
.4446 .63304 Mdot
.39993 .24296 Mdot
.71758 .41756 Mdot
.42871 .5488 Mdot
.73138 .28492 Mdot
.69529 .58842 Mdot
.81465 .5372 Mdot
.52934 .20075 Mdot
.46292 .31588 Mdot
.6445 .58744 Mdot
.38193 .45242 Mdot
.67385 .61353 Mdot
.46052 .34293 Mdot
.62922 .80187 Mdot
.35983 .47128 Mdot
.47046 .68336 Mdot
.39859 .51243 Mdot
.4761 .68328 Mdot
.39372 .54833 Mdot
.3232 .51213 Mdot
.69913 .45786 Mdot
.27815 .4149 Mdot
.42916 .48974 Mdot
.33929 .20797 Mdot
.48302 .387 Mdot
.48739 .34759 Mdot
.3831 .52085 Mdot
.5745 .42211 Mdot
.63833 .63808 Mdot
.69142 .69397 Mdot
.64011 .42868 Mdot
.6158 .57801 Mdot
.44218 .68648 Mdot
.6283 .40632 Mdot
.62602 .38495 Mdot
.33396 .44293 Mdot
.48941 .29561 Mdot
.66038 .58409 Mdot
.37694 .46985 Mdot
.36018 .4721 Mdot
.21458 .47443 Mdot
.65803 .31788 Mdot
.4128 .70068 Mdot
.15891 .4965 Mdot
.47131 .72499 Mdot
.48631 .34432 Mdot
.64307 .43145 Mdot
.40212 .45353 Mdot
.39728 .49744 Mdot
.73344 .47866 Mdot
.4327 .70769 Mdot
.5532 .5383 Mdot
.44699 .77167 Mdot
.59173 .47537 Mdot
.31281 .3506 Mdot
.46541 .69763 Mdot
.31262 .35272 Mdot
.49923 .35952 Mdot
.81103 .39003 Mdot
.29364 .39313 Mdot
.62789 .60546 Mdot
.31745 .34888 Mdot
.46325 .66423 Mdot
.42101 .53607 Mdot
.62337 .44924 Mdot
.58989 .41997 Mdot
.45389 .68686 Mdot
.60331 .45926 Mdot
.46903 .30442 Mdot
.38051 .45783 Mdot
.18184 .53131 Mdot
.61336 .71327 Mdot
.61575 .43876 Mdot
.33332 .54266 Mdot
.65174 .57474 Mdot
.38029 .54401 Mdot
.46388 .30445 Mdot
.63835 .60096 Mdot
.38208 .23807 Mdot
.61388 .64749 Mdot
.37091 .50554 Mdot
.36183 .22201 Mdot
.63869 .59039 Mdot
.4123 .39523 Mdot
.3722 .48501 Mdot
.62263 .62381 Mdot
.39924 .40321 Mdot
.74177 .55726 Mdot
.59156 .51798 Mdot
.64908 .21195 Mdot
.57582 .5152 Mdot
.61772 .44588 Mdot
.7547 .56278 Mdot
.67431 .5344 Mdot
.65676 .62691 Mdot
.58212 .42799 Mdot
.51503 .30654 Mdot
.62745 .57448 Mdot
.35418 .45728 Mdot
.41075 .47281 Mdot
.60514 .80405 Mdot
.6841 .55629 Mdot
.74247 .60265 Mdot
.65189 .72268 Mdot
.36332 .53722 Mdot
.3905 .56263 Mdot
.39419 .49362 Mdot
.42852 .63841 Mdot
.64601 .61257 Mdot
.28464 .2592 Mdot
.63363 .58417 Mdot
.20342 .56579 Mdot
.62178 .43656 Mdot
.62324 .39355 Mdot
.39462 .47004 Mdot
.47923 .41789 Mdot
.34391 .28735 Mdot
.39587 .50703 Mdot
.48445 .27289 Mdot
.67468 .74126 Mdot
.3535 .53321 Mdot
.43073 .64604 Mdot
.31996 .52324 Mdot
.31457 .53066 Mdot
.65171 .62389 Mdot
.47295 .31084 Mdot
.39056 .24498 Mdot
.66574 .60045 Mdot
.38804 .48179 Mdot
.55777 .68513 Mdot
.41015 .49368 Mdot
.41636 .53291 Mdot
.20218 .61143 Mdot
.49786 .3557 Mdot
.63192 .41876 Mdot
.48153 .32858 Mdot
.44361 .63728 Mdot
.09594 .54723 Mdot
.49719 .31448 Mdot
.34904 .279 Mdot
.5847 .81962 Mdot
.31983 .35019 Mdot
.48002 .6788 Mdot
.48403 .29042 Mdot
.62889 .59638 Mdot
.76782 .30316 Mdot
.3277 .75229 Mdot
.69362 .63842 Mdot
.37791 .49201 Mdot
.43183 .71912 Mdot
.46905 .7059 Mdot
.65335 .56322 Mdot
.46718 .65668 Mdot
.43266 .42258 Mdot
.4186 .53549 Mdot
.66689 .62151 Mdot
.57037 .7103 Mdot
.61404 .57531 Mdot
.5912 .64571 Mdot
.38453 .51594 Mdot
.46094 .70028 Mdot
.44273 .48388 Mdot
.49322 .70647 Mdot
.60934 .45743 Mdot
.33241 .49757 Mdot
.47135 .30356 Mdot
.54764 .70695 Mdot
.611 .40848 Mdot
.5288 .28723 Mdot
.45134 .63827 Mdot
.59199 .57552 Mdot
.46116 .64281 Mdot
.49168 .6671 Mdot
.62287 .57039 Mdot
.44757 .65738 Mdot
.38006 .45449 Mdot
.55808 .46034 Mdot
.43932 .64818 Mdot
.6551 .58975 Mdot
.47275 .31485 Mdot
.44052 .67882 Mdot
.58087 .37213 Mdot
.36537 .50141 Mdot
.64874 .41774 Mdot
.55969 .22963 Mdot
.44497 .72572 Mdot
.50387 .34286 Mdot
.5851 .42104 Mdot
.48509 .35337 Mdot
.79804 .63469 Mdot
.68126 .60028 Mdot
.21711 .59745 Mdot
.5038 .29553 Mdot
.46137 .71765 Mdot
.57554 .2312 Mdot
.40427 .45692 Mdot
.36648 .50441 Mdot
.45735 .29077 Mdot
.4687 .70635 Mdot
.82891 .45217 Mdot
.37709 .58797 Mdot
.57504 .6373 Mdot
.65914 .55645 Mdot
.35065 .21486 Mdot
.61064 .6567 Mdot
.83833 .61407 Mdot
.42994 .55431 Mdot
.60285 .37756 Mdot
.39803 .47921 Mdot
.71525 .43711 Mdot
.48552 .33772 Mdot
.67688 .37748 Mdot
.34777 .54151 Mdot
.62871 .41395 Mdot
.35641 .49756 Mdot
.52867 .42126 Mdot
.32558 .44102 Mdot
.45272 .32345 Mdot
.7788 .46789 Mdot
.47047 .71633 Mdot
.46661 .32511 Mdot
.65538 .40404 Mdot
.33213 .3132 Mdot
.42154 .52624 Mdot
.42132 .43502 Mdot
.5914 .47508 Mdot
.47572 .67604 Mdot
.60924 .44727 Mdot
.6432 .62562 Mdot
.48201 .31136 Mdot
.3773 .53227 Mdot
.42191 .46446 Mdot
.73127 .501 Mdot
.65231 .57326 Mdot
.58662 .39984 Mdot
.62119 .59921 Mdot
.65176 .39229 Mdot
.39882 .55311 Mdot
.61715 .39196 Mdot
.43277 .45876 Mdot
.69655 .46881 Mdot
.20454 .59848 Mdot
.30998 .65483 Mdot
.62888 .39999 Mdot
.28802 .35677 Mdot
.64522 .57479 Mdot
.62035 .61208 Mdot
.51627 .821 Mdot
.2518 .66938 Mdot
.20251 .4684 Mdot
.66569 .25505 Mdot
.67243 .60126 Mdot
.65361 .57895 Mdot
.64837 .41397 Mdot
.44783 .65489 Mdot
.48037 .71545 Mdot
.64684 .3889 Mdot
.4105 .34704 Mdot
.47143 .6691 Mdot
.75957 .31534 Mdot
.22196 .41622 Mdot
.41784 .44508 Mdot
.59813 .46162 Mdot
.48232 .31767 Mdot
.40115 .33834 Mdot
.52917 .41665 Mdot
.37236 .45564 Mdot
.42756 .23545 Mdot
.61305 .43357 Mdot
.48263 .44196 Mdot
.60565 .20163 Mdot
.35219 .48206 Mdot
.37193 .47958 Mdot
.39345 .48606 Mdot
.50353 .31121 Mdot
.29441 .71638 Mdot
.37109 .46332 Mdot
.41114 .34995 Mdot
.37153 .54206 Mdot
.39213 .39906 Mdot
.47694 .32741 Mdot
.2743 .45487 Mdot
.68332 .30774 Mdot
.22999 .35512 Mdot
.32532 .43534 Mdot
.64056 .62695 Mdot
.46396 .25877 Mdot
.61809 .60124 Mdot
.28016 .64552 Mdot
.30116 .38917 Mdot
.45637 .73163 Mdot
.37575 .45353 Mdot
.62271 .40261 Mdot
.4703 .70394 Mdot
.74531 .53181 Mdot
.08154 .49775 Mdot
.6392 .62859 Mdot
.87226 .57603 Mdot
.62473 .62389 Mdot
.62697 .38445 Mdot
.44806 .68231 Mdot
.38069 .67706 Mdot
.50021 .55651 Mdot
.43876 .67969 Mdot
.78657 .40819 Mdot
.42697 .62453 Mdot
.30561 .34407 Mdot
.4314 .71273 Mdot
.6528 .58396 Mdot
.62585 .53307 Mdot
.46299 .52895 Mdot
.4013 .45985 Mdot
.52608 .51838 Mdot
.32394 .30617 Mdot
.40214 .45633 Mdot
.61765 .40465 Mdot
.22094 .61114 Mdot
.41529 .25317 Mdot
.4512 .66022 Mdot
.64481 .64758 Mdot
.36693 .48017 Mdot
.41409 .525 Mdot
.42256 .52778 Mdot
.158 .56271 Mdot
.81388 .39375 Mdot
.41497 .54436 Mdot
.37381 .54705 Mdot
.62788 .40959 Mdot
.51378 .34708 Mdot
.72403 .38929 Mdot
.23641 .52541 Mdot
.36254 .45649 Mdot
.4699 .32887 Mdot
.50888 .34508 Mdot
.42721 .51282 Mdot
.53714 .34557 Mdot
.55738 .67649 Mdot
.37569 .46984 Mdot
.22595 .61408 Mdot
.56367 .45108 Mdot
.59595 .39102 Mdot
.60156 .41117 Mdot
.48325 .67967 Mdot
.59965 .39997 Mdot
.65799 .40216 Mdot
.39118 .68836 Mdot
.56403 .52058 Mdot
.64975 .6502 Mdot
.48962 .32957 Mdot
.40124 .49742 Mdot
.41928 .61 Mdot
.55719 .70901 Mdot
.62293 .57603 Mdot
.44563 .70965 Mdot
.63311 .63769 Mdot
.44155 .32031 Mdot
.47391 .56679 Mdot
.60584 .43335 Mdot
.66963 .60633 Mdot
.60292 .63463 Mdot
.47094 .3274 Mdot
.64445 .56663 Mdot
.59847 .61926 Mdot
.33591 .48804 Mdot
.34218 .7022 Mdot
.39102 .5078 Mdot
.81904 .4976 Mdot
.66005 .57862 Mdot
.67517 .49997 Mdot
.38221 .47681 Mdot
.60659 .41776 Mdot
.45836 .54776 Mdot
.41014 .46184 Mdot
.598 .40845 Mdot
.4277 .52837 Mdot
.48578 .35747 Mdot
.4936 .7009 Mdot
.49544 .54462 Mdot
.40596 .8401 Mdot
.4886 .29475 Mdot
.74578 .52359 Mdot
.38538 .44696 Mdot
.74377 .70274 Mdot
.44198 .67599 Mdot
.43589 .47928 Mdot
.39694 .26189 Mdot
.44048 .65198 Mdot
.44585 .70267 Mdot
.40883 .52428 Mdot
.62514 .60337 Mdot
.61187 .40477 Mdot
.47381 .32516 Mdot
.83255 .5969 Mdot
.37799 .50003 Mdot
.3628 .51322 Mdot
.46725 .3316 Mdot
.64652 .57224 Mdot
.42772 .49911 Mdot
.5228 .21997 Mdot
.83939 .44842 Mdot
.61755 .61117 Mdot
.35609 .45667 Mdot
.29694 .6863 Mdot
.33064 .55495 Mdot
.66839 .80397 Mdot
.53425 .33421 Mdot
.63429 .41303 Mdot
.45361 .46688 Mdot
.11492 .52688 Mdot
.47451 .31211 Mdot
.19471 .45096 Mdot
.41203 .52918 Mdot
.36757 .52989 Mdot
.45024 .71638 Mdot
.39099 .52339 Mdot
.42726 .68432 Mdot
.39266 .82516 Mdot
.34769 .23858 Mdot
.47814 .66793 Mdot
.45925 .72084 Mdot
.37113 .26682 Mdot
.72304 .40396 Mdot
.45163 .68782 Mdot
.39201 .55121 Mdot
.28767 .46647 Mdot
.43855 .59067 Mdot
.4673 .28952 Mdot
.63514 .26484 Mdot
.41046 .60097 Mdot
.45359 .28196 Mdot
.72647 .31956 Mdot
.40614 .60557 Mdot
.56778 .58255 Mdot
.63827 .62384 Mdot
.35218 .47993 Mdot
.5888 .41614 Mdot
.58884 .40692 Mdot
.44317 .51393 Mdot
.40669 .5001 Mdot
.44629 .63713 Mdot
.4923 .31794 Mdot
.64375 .63118 Mdot
.3745 .53382 Mdot
.39084 .25418 Mdot
.49847 .32354 Mdot
.45798 .65147 Mdot
.22935 .57102 Mdot
.45867 .34657 Mdot
.32279 .49668 Mdot
.38636 .46509 Mdot
.40133 .51583 Mdot
.432 .59544 Mdot
.64283 .61683 Mdot
.60991 .24194 Mdot
.3422 .49829 Mdot
.28198 .29832 Mdot
.68782 .60838 Mdot
.34523 .44768 Mdot
.4717 .65711 Mdot
.63194 .65083 Mdot
.65951 .43947 Mdot
.48987 .58701 Mdot
.37295 .50567 Mdot
.80017 .53285 Mdot
.62587 .79157 Mdot
.60945 .45574 Mdot
.49174 .6709 Mdot
.48533 .32323 Mdot
.3975 .50583 Mdot
.24338 .60316 Mdot
.40809 .47038 Mdot
.44698 .31734 Mdot
.64598 .43974 Mdot
.63562 .62354 Mdot
.81764 .52544 Mdot
.59202 .40345 Mdot
.44882 .70147 Mdot
.48111 .14301 Mdot
.42643 .67943 Mdot
.48367 .70858 Mdot
.2428 .57245 Mdot
.64013 .61809 Mdot
.1207 .55996 Mdot
.43272 .81932 Mdot
.3393 .51987 Mdot
.6421 .575 Mdot
.45974 .68604 Mdot
.36608 .53377 Mdot
.44235 .73544 Mdot
.48861 .67284 Mdot
.39102 .55346 Mdot
.35403 .51145 Mdot
.75487 .61573 Mdot
.6426 .21533 Mdot
.48636 .32439 Mdot
.45613 .63392 Mdot
.53795 .61553 Mdot
.36161 .53037 Mdot
.38977 .47462 Mdot
.69048 .5469 Mdot
.47348 .29305 Mdot
.65649 .69101 Mdot
.41323 .52688 Mdot
.36912 .22942 Mdot
.32231 .4687 Mdot
.4354 .63364 Mdot
.61662 .59565 Mdot
.23588 .3488 Mdot
.63613 .54211 Mdot
.42823 .68811 Mdot
.48856 .31011 Mdot
.46334 .62117 Mdot
.34639 .27905 Mdot
.66323 .5748 Mdot
.46002 .70726 Mdot
.6159 .51838 Mdot
.64698 .6049 Mdot
.66804 .59122 Mdot
.24655 .56367 Mdot
.58067 .43168 Mdot
.5061 .31641 Mdot
.65807 .58092 Mdot
.52864 .68981 Mdot
.65151 .591 Mdot
.45775 .8134 Mdot
.35338 .46428 Mdot
.41678 .30232 Mdot
.68772 .37857 Mdot
.46175 .49573 Mdot
.66384 .58 Mdot
.45823 .31298 Mdot
.42288 .51568 Mdot
.46436 .66176 Mdot
.49372 .34616 Mdot
.68846 .65394 Mdot
.64318 .42211 Mdot
.45789 .64267 Mdot
.63352 .54597 Mdot
.47501 .68898 Mdot
.5183 .62746 Mdot
.5516 .83224 Mdot
.44297 .20256 Mdot
.50518 .57044 Mdot
.42041 .529 Mdot
.68273 .28151 Mdot
.40153 .43345 Mdot
.41041 .50226 Mdot
.617 .40033 Mdot
.41554 .28019 Mdot
.4506 .67873 Mdot
.82905 .4784 Mdot
.65829 .61834 Mdot
.23683 .33889 Mdot
.29878 .47416 Mdot
.4341 .51057 Mdot
.43706 .65041 Mdot
.42559 .68892 Mdot
.28239 .61732 Mdot
.66558 .43362 Mdot
.41745 .45152 Mdot
.38228 .43605 Mdot
.4334 .53473 Mdot
.66157 .6108 Mdot
.52366 .28217 Mdot
.61717 .44483 Mdot
.62042 .81736 Mdot
.64001 .44422 Mdot
.46705 .26684 Mdot
.45115 .65691 Mdot
.49662 .31382 Mdot
.38814 .47347 Mdot
.41567 .65236 Mdot
.43158 .70594 Mdot
.45207 .30435 Mdot
.45847 .33036 Mdot
.71786 .54957 Mdot
.63134 .61443 Mdot
.42381 .47096 Mdot
.36833 .46328 Mdot
.38891 .52933 Mdot
.40899 .51135 Mdot
.64788 .62691 Mdot
.42355 .50605 Mdot
.60688 .6028 Mdot
.5119 .65619 Mdot
.46333 .24279 Mdot
.57535 .51027 Mdot
.56831 .78617 Mdot
.45712 .66132 Mdot
.53501 .68256 Mdot
.39559 .58669 Mdot
.20623 .64896 Mdot
.69501 .72912 Mdot
.33932 .50369 Mdot
.62788 .3893 Mdot
.43333 .41127 Mdot
.5979 .4289 Mdot
.83423 .64689 Mdot
.71496 .50086 Mdot
.68323 .24208 Mdot
.35963 .47395 Mdot
.57395 .47375 Mdot
.51154 .73823 Mdot
.40808 .43278 Mdot
.72104 .51973 Mdot
.57374 .7781 Mdot
.78601 .48682 Mdot
.46563 .30056 Mdot
.3671 .49471 Mdot
.42175 .61028 Mdot
.3791 .45655 Mdot
.39531 .47595 Mdot
.42415 .51714 Mdot
.61124 .59117 Mdot
.42626 .46193 Mdot
.41988 .50295 Mdot
.5619 .33214 Mdot
.30123 .37112 Mdot
.58467 .41114 Mdot
.54653 .81894 Mdot
.49806 .31538 Mdot
.44337 .64141 Mdot
.79355 .3797 Mdot
.62844 .60619 Mdot
.28637 .61721 Mdot
.40576 .51348 Mdot
.7709 .58459 Mdot
.62351 .64614 Mdot
.47991 .30735 Mdot
.64965 .44384 Mdot
.72341 .26555 Mdot
.61989 .408 Mdot
.62575 .52313 Mdot
.60889 .41779 Mdot
.40113 .59015 Mdot
.44757 .63632 Mdot
.42652 .48378 Mdot
.66131 .58807 Mdot
.60461 .3989 Mdot
.36969 .32293 Mdot
.39533 .49201 Mdot
.62224 .41647 Mdot
.42627 .48328 Mdot
.47903 .54622 Mdot
.22979 .48302 Mdot
.65409 .39913 Mdot
.62725 .64599 Mdot
.65601 .60464 Mdot
.48412 .29687 Mdot
.44875 .64272 Mdot
.43802 .70573 Mdot
.63973 .60017 Mdot
.28265 .71939 Mdot
.36948 .45076 Mdot
.35763 .5237 Mdot
.25155 .32696 Mdot
.38995 .45025 Mdot
.31962 .32732 Mdot
.60369 .51677 Mdot
.46023 .65649 Mdot
.43086 .53056 Mdot
.40733 .53036 Mdot
.36969 .50546 Mdot
.50344 .62276 Mdot
.60299 .42365 Mdot
.35147 .47597 Mdot
.46111 .33693 Mdot
.54972 .37975 Mdot
.38052 .54431 Mdot
.36079 .42065 Mdot
.44 .70792 Mdot
.16222 .50604 Mdot
.62618 .62363 Mdot
.65093 .39996 Mdot
.63079 .39925 Mdot
.65142 .27589 Mdot
.54083 .74511 Mdot
.60196 .51489 Mdot
.65336 .80112 Mdot
.69861 .45778 Mdot
.47955 .34586 Mdot
.6343 .46844 Mdot
.63168 .53092 Mdot
.6477 .40449 Mdot
.6402 .6291 Mdot
.35065 .46858 Mdot
.36041 .45801 Mdot
.20065 .66386 Mdot
.42761 .51653 Mdot
.48204 .32168 Mdot
.61864 .56568 Mdot
.46286 .66492 Mdot
.48179 .30862 Mdot
.62055 .59725 Mdot
.4767 .66979 Mdot
.34072 .48956 Mdot
.34231 .48615 Mdot
.44365 .70809 Mdot
.46258 .70968 Mdot
.38423 .46833 Mdot
.70191 .37495 Mdot
.46618 .71546 Mdot
.46436 .70127 Mdot
.60977 .43717 Mdot
.59018 .4165 Mdot
.34471 .43841 Mdot
.64253 .578 Mdot
.42087 .50409 Mdot
.6262 .40542 Mdot
.49214 .30921 Mdot
.45109 .67507 Mdot
.41214 .53646 Mdot
.38669 .54219 Mdot
.47066 .32512 Mdot
.48075 .30031 Mdot
.46082 .31203 Mdot
.6109 .58099 Mdot
.38153 .52566 Mdot
.44586 .68769 Mdot
.63222 .61763 Mdot
.50968 .33995 Mdot
.46271 .29482 Mdot
.64594 .45979 Mdot
.39944 .45059 Mdot
.6279 .35266 Mdot
.10843 .49256 Mdot
.28537 .31187 Mdot
.62883 .45672 Mdot
.64703 .45074 Mdot
.33505 .35458 Mdot
.49244 .44738 Mdot
.63414 .5914 Mdot
.49922 .37044 Mdot
.38735 .24433 Mdot
.34202 .46984 Mdot
.3647 .5432 Mdot
.33 .52726 Mdot
.45947 .32065 Mdot
.42745 .2649 Mdot
.42721 .66507 Mdot
.36646 .59667 Mdot
.49976 .33305 Mdot
.58301 .40846 Mdot
.62257 .46537 Mdot
.64355 .44259 Mdot
.34718 .47474 Mdot
.31791 .65668 Mdot
.53597 .7162 Mdot
.62813 .23307 Mdot
.65783 .57442 Mdot
.42045 .60772 Mdot
.74312 .69912 Mdot
.4437 .7051 Mdot
.67074 .40918 Mdot
.47634 .34729 Mdot
.46544 .70607 Mdot
.6352 .64085 Mdot
.656 .58101 Mdot
.61794 .44002 Mdot
.62574 .43975 Mdot
.65308 .42261 Mdot
.49172 .68163 Mdot
.44924 .65676 Mdot
.37487 .50816 Mdot
.45197 .67006 Mdot
.18529 .61527 Mdot
.46671 .2835 Mdot
.63733 .36842 Mdot
.64285 .58486 Mdot
.47832 .67479 Mdot
.39459 .4952 Mdot
.49073 .46624 Mdot
.62516 .74344 Mdot
.47849 .35193 Mdot
.22063 .4765 Mdot
.82393 .65698 Mdot
.42277 .46784 Mdot
.64973 .61471 Mdot
.1824 .52367 Mdot
.39171 .48815 Mdot
.64088 .4359 Mdot
.7171 .37202 Mdot
.58264 .46349 Mdot
.41297 .46373 Mdot
.34271 .46439 Mdot
.61903 .62092 Mdot
.64439 .79904 Mdot
.37767 .50554 Mdot
.63382 .6908 Mdot
.67384 .61967 Mdot
.62328 .4465 Mdot
.82889 .37975 Mdot
.53586 .2363 Mdot
.40673 .33957 Mdot
.61613 .44207 Mdot
.41325 .4875 Mdot
.59906 .42663 Mdot
.47142 .34882 Mdot
.66278 .42028 Mdot
.42561 .66817 Mdot
.60952 .4533 Mdot
.36218 .51316 Mdot
.45339 .68922 Mdot
.638 .58928 Mdot
.21471 .38835 Mdot
.63123 .33502 Mdot
.60693 .41978 Mdot
.64482 .39183 Mdot
.42992 .52928 Mdot
.67445 .67994 Mdot
.4469 .49109 Mdot
.34947 .49573 Mdot
.67271 .59443 Mdot
.44196 .64806 Mdot
.61472 .59288 Mdot
.39295 .42259 Mdot
.51519 .21313 Mdot
.62143 .60294 Mdot
.79402 .52857 Mdot
.47098 .33877 Mdot
.5301 .45583 Mdot
.39832 .49908 Mdot
.63576 .56823 Mdot
.38123 .52364 Mdot
.43011 .65492 Mdot
.56366 .48323 Mdot
.77485 .48845 Mdot
.66431 .59726 Mdot
.80657 .52863 Mdot
.44814 .26896 Mdot
.39263 .41415 Mdot
.61892 .6089 Mdot
.40495 .26077 Mdot
.62535 .38455 Mdot
.49595 .33897 Mdot
.47128 .35579 Mdot
.49677 .34621 Mdot
.44272 .532 Mdot
.31289 .44618 Mdot
.50015 .35358 Mdot
.64304 .63826 Mdot
.45302 .32484 Mdot
.50311 .77526 Mdot
.82395 .46956 Mdot
.48267 .33824 Mdot
.37381 .48808 Mdot
.33115 .54705 Mdot
.31394 .36766 Mdot
.73918 .56494 Mdot
.70172 .25663 Mdot
.68926 .7072 Mdot
.40284 .46192 Mdot
.48834 .7107 Mdot
.47608 .65219 Mdot
.18149 .49512 Mdot
.30819 .32118 Mdot
.31521 .27355 Mdot
.46752 .72093 Mdot
.74998 .46703 Mdot
.45763 .64831 Mdot
.42536 .52321 Mdot
.36113 .52809 Mdot
.46379 .7238 Mdot
.46079 .23771 Mdot
.75617 .49269 Mdot
.82567 .55699 Mdot
.47119 .69568 Mdot
.62093 .5863 Mdot
.64693 .5592 Mdot
.66835 .58953 Mdot
.21444 .43316 Mdot
.43274 .66482 Mdot
.38772 .53562 Mdot
.62734 .39943 Mdot
.3557 .46789 Mdot
.64406 .60816 Mdot
.83068 .47281 Mdot
.43649 .67224 Mdot
.36565 .474 Mdot
.46572 .44883 Mdot
.63505 .4337 Mdot
.47234 .33489 Mdot
.4791 .53033 Mdot
.31301 .27895 Mdot
.66454 .61106 Mdot
.44951 .72675 Mdot
.69141 .49063 Mdot
.80751 .48327 Mdot
.42453 .56121 Mdot
.38479 .43398 Mdot
.83215 .60916 Mdot
.37126 .23868 Mdot
.40217 .44609 Mdot
.6424 .39333 Mdot
.72863 .47932 Mdot
.39461 .54394 Mdot
.46899 .64186 Mdot
.46369 .35205 Mdot
.486 .35248 Mdot
.35066 .43181 Mdot
.50212 .52258 Mdot
.56389 .47124 Mdot
.40498 .52172 Mdot
.32246 .50268 Mdot
.62174 .44546 Mdot
.7068 .43951 Mdot
.28745 .29291 Mdot
.48669 .30687 Mdot
.42678 .48745 Mdot
.75799 .38394 Mdot
.44383 .71701 Mdot
.61604 .45642 Mdot
.65392 .56785 Mdot
.48424 .60755 Mdot
.65258 .44158 Mdot
.40331 .54517 Mdot
.42734 .50712 Mdot
.62894 .56581 Mdot
.43379 .63508 Mdot
.4602 .32501 Mdot
.62314 .39524 Mdot
.47492 .29985 Mdot
.43867 .65465 Mdot
.4484 .66594 Mdot
.45054 .43073 Mdot
.41422 .57399 Mdot
.60269 .40805 Mdot
.43398 .4596 Mdot
.55871 .43388 Mdot
.7114 .76762 Mdot
.64635 .55113 Mdot
.41628 .45735 Mdot
.42138 .65938 Mdot
.66433 .60369 Mdot
.36097 .5238 Mdot
.84299 .5864 Mdot
.36398 .53424 Mdot
.68593 .60966 Mdot
.42839 .19653 Mdot
.46606 .3041 Mdot
.3616 .59181 Mdot
.74218 .65566 Mdot
.38917 .45277 Mdot
.63974 .40268 Mdot
.34006 .54951 Mdot
.62617 .59784 Mdot
.45115 .65929 Mdot
.68621 .79698 Mdot
.6538 .59367 Mdot
.37791 .46157 Mdot
.48192 .31038 Mdot
.42912 .70565 Mdot
.51275 .28977 Mdot
.5373 .34315 Mdot
.35197 .4194 Mdot
.43739 .46945 Mdot
.41347 .51491 Mdot
.55716 .21619 Mdot
.6527 .40273 Mdot
.46524 .69043 Mdot
.6516 .61502 Mdot
.63714 .59864 Mdot
.61381 .43583 Mdot
.6242 .65459 Mdot
.53141 .45816 Mdot
.13959 .43772 Mdot
.59547 .41197 Mdot
.5032 .33617 Mdot
.65545 .6867 Mdot
.63292 .39491 Mdot
.62154 .42063 Mdot
.6091 .43812 Mdot
.5907 .5511 Mdot
.47521 .67262 Mdot
.40027 .54652 Mdot
.45074 .63 Mdot
.41468 .48957 Mdot
.68513 .61366 Mdot
.664 .59139 Mdot
.43848 .66554 Mdot
.81717 .61939 Mdot
.33975 .72091 Mdot
.38387 .48656 Mdot
.74451 .7004 Mdot
.36189 .55255 Mdot
.33682 .3348 Mdot
.36154 .55595 Mdot
.6141 .43012 Mdot
.44123 .45691 Mdot
.43468 .53453 Mdot
.18253 .46366 Mdot
.64099 .58276 Mdot
.60156 .38778 Mdot
.3347 .51962 Mdot
.32063 .50571 Mdot
.49151 .69018 Mdot
.46574 .70425 Mdot
.47842 .35656 Mdot
.27253 .424 Mdot
.63621 .58711 Mdot
.4252 .80592 Mdot
.39838 .46018 Mdot
.49651 .24852 Mdot
.29248 .55458 Mdot
.35859 .5197 Mdot
.75247 .65454 Mdot
.31005 .64678 Mdot
.39786 .50381 Mdot
.53821 .57392 Mdot
.64775 .57397 Mdot
.49911 .20929 Mdot
.37739 .54587 Mdot
.63997 .43122 Mdot
.45162 .65247 Mdot
.42385 .68562 Mdot
.49156 .35706 Mdot
.24 .6989 Mdot
.61526 .58504 Mdot
.44421 .66091 Mdot
.39967 .48873 Mdot
.64597 .61824 Mdot
.59683 .40135 Mdot
.43462 .50281 Mdot
.29878 .33081 Mdot
.4576 .66884 Mdot
.4212 .54488 Mdot
.608 .68639 Mdot
.36355 .3614 Mdot
.48068 .16779 Mdot
.65323 .61551 Mdot
.47853 .29567 Mdot
.33054 .53555 Mdot
.26819 .69699 Mdot
.39173 .56445 Mdot
.42102 .3162 Mdot
.50914 .77717 Mdot
.47237 .29478 Mdot
.37895 .47938 Mdot
.38018 .53404 Mdot
.4885 .40509 Mdot
.49019 .3098 Mdot
.36191 .46839 Mdot
.50587 .69083 Mdot
.47396 .67982 Mdot
.66164 .3986 Mdot
.46653 .66783 Mdot
.37794 .49128 Mdot
.4077 .57573 Mdot
.45455 .71538 Mdot
.74529 .72288 Mdot
.4892 .28665 Mdot
.62512 .62025 Mdot
.36664 .55002 Mdot
.34473 .50893 Mdot
.28877 .2406 Mdot
.59977 .45184 Mdot
.73225 .40267 Mdot
.54867 .2813 Mdot
.73811 .34682 Mdot
.5335 .23545 Mdot
.58566 .1782 Mdot
.37622 .23323 Mdot
.42951 .46503 Mdot
.30665 .53416 Mdot
.5462 .64952 Mdot
.65869 .57323 Mdot
.44066 .78291 Mdot
.40167 .45971 Mdot
.39731 .47709 Mdot
.62538 .4584 Mdot
.78493 .54183 Mdot
.31388 .27361 Mdot
.49495 .47452 Mdot
.46098 .32476 Mdot
.45849 .63521 Mdot
.39766 .54875 Mdot
.54988 .55266 Mdot
.58355 .41421 Mdot
.48757 .24446 Mdot
.36744 .47464 Mdot
.20401 .6259 Mdot
.60079 .74781 Mdot
.63731 .61525 Mdot
.63328 .39932 Mdot
.33397 .25988 Mdot
.40298 .45309 Mdot
.65117 .5655 Mdot
.38264 .50129 Mdot
.68708 .44899 Mdot
.39984 .42328 Mdot
.48804 .33985 Mdot
.41433 .52876 Mdot
.45928 .26485 Mdot
.42734 .13701 Mdot
.47714 .37006 Mdot
.43971 .73169 Mdot
.62123 .37004 Mdot
.60092 .41949 Mdot
.46233 .70814 Mdot
.60147 .41599 Mdot
.28126 .5951 Mdot
.37761 .64285 Mdot
.46656 .3352 Mdot
.32455 .47627 Mdot
.48122 .33444 Mdot
.61165 .45733 Mdot
.40678 .46167 Mdot
.76535 .72188 Mdot
.60799 .4005 Mdot
.38968 .20707 Mdot
.64939 .59257 Mdot
.58262 .41008 Mdot
.37284 .54274 Mdot
.68194 .50173 Mdot
.59136 .40361 Mdot
.77237 .50318 Mdot
.37036 .50594 Mdot
.45528 .66455 Mdot
.39373 .54244 Mdot
.34643 .53023 Mdot
.59361 .38292 Mdot
.41886 .48823 Mdot
.62079 .59615 Mdot
.4792 .70921 Mdot
.76322 .30815 Mdot
.55014 .78303 Mdot
.37111 .45795 Mdot
.3975 .48822 Mdot
.47815 .63811 Mdot
.347 .48535 Mdot
.64745 .62689 Mdot
.29801 .82048 Mdot
.47112 .33858 Mdot
.61352 .37919 Mdot
.53284 .23391 Mdot
.33893 .4956 Mdot
.42333 .51175 Mdot
.85055 .56412 Mdot
.50239 .2195 Mdot
.61896 .60402 Mdot
.43008 .54324 Mdot
.59567 .40088 Mdot
.48325 .31391 Mdot
.64963 .63344 Mdot
.39991 .51602 Mdot
.38535 .47535 Mdot
.48563 .29897 Mdot
.29242 .44368 Mdot
.23456 .38803 Mdot
.63549 .56523 Mdot
.45463 .4876 Mdot
.58671 .37159 Mdot
.38183 .44428 Mdot
.2085 .45483 Mdot
.45939 .70533 Mdot
.6666 .60992 Mdot
.69202 .29979 Mdot
.40945 .45408 Mdot
.61792 .58722 Mdot
.63671 .58578 Mdot
.42314 .54996 Mdot
.42007 .66224 Mdot
.48611 .69059 Mdot
.47682 .68551 Mdot
.20733 .6921 Mdot
.39187 .33196 Mdot
.653 .42279 Mdot
.64763 .5734 Mdot
.65418 .39704 Mdot
.44976 .29243 Mdot
.59404 .5227 Mdot
.6498 .39494 Mdot
.48046 .68576 Mdot
.63515 .37163 Mdot
.37286 .52315 Mdot
.63681 .59018 Mdot
.64994 .40847 Mdot
.33639 .51225 Mdot
.67239 .67418 Mdot
.72836 .62834 Mdot
.45755 .30413 Mdot
.47068 .35757 Mdot
.37162 .53757 Mdot
.67056 .42516 Mdot
.38635 .46902 Mdot
.67541 .59539 Mdot
.6605 .68054 Mdot
.36866 .55029 Mdot
.6064 .42142 Mdot
.47345 .6292 Mdot
.32189 .27144 Mdot
.44566 .47631 Mdot
.37439 .48697 Mdot
.41609 .48597 Mdot
.38267 .50186 Mdot
.79439 .46772 Mdot
.6675 .56514 Mdot
.56718 .78537 Mdot
.59004 .23403 Mdot
.43605 .68071 Mdot
.46165 .62932 Mdot
.27555 .31876 Mdot
.55857 .66361 Mdot
.64357 .5769 Mdot
.41 .50547 Mdot
.56258 .7313 Mdot
.83752 .44636 Mdot
.82112 .64169 Mdot
.47402 .39533 Mdot
.58518 .4364 Mdot
.45575 .72581 Mdot
.61297 .39004 Mdot
.4119 .48008 Mdot
.32659 .52387 Mdot
.56145 .16279 Mdot
.65411 .63606 Mdot
.46878 .33979 Mdot
.41604 .4931 Mdot
.39395 .33645 Mdot
.62862 .40798 Mdot
.58384 .39352 Mdot
.35046 .48464 Mdot
.43957 .62601 Mdot
.37613 .17898 Mdot
.64406 .61647 Mdot
.68975 .70274 Mdot
.5088 .74415 Mdot
.65757 .72459 Mdot
.64394 .6108 Mdot
.50066 .38129 Mdot
.62534 .45606 Mdot
.26364 .52307 Mdot
.43452 .68503 Mdot
.49193 .34685 Mdot
.34825 .44521 Mdot
.44358 .71324 Mdot
.63022 .44836 Mdot
.45274 .66163 Mdot
.42346 .51915 Mdot
.68043 .60547 Mdot
.63613 .41224 Mdot
.65105 .65005 Mdot
.42717 .63893 Mdot
.48681 .3088 Mdot
.51048 .47998 Mdot
.39751 .74587 Mdot
.30642 .64181 Mdot
.35089 .47437 Mdot
.55289 .55652 Mdot
.38868 .53418 Mdot
.48186 .65306 Mdot
.39098 .49674 Mdot
.44695 .75915 Mdot
.63889 .40324 Mdot
.37432 .547 Mdot
.40748 .51914 Mdot
.49205 .80648 Mdot
.36113 .48246 Mdot
.42934 .45633 Mdot
.4004 .50585 Mdot
.43057 .73527 Mdot
.32279 .47755 Mdot
.47243 .65645 Mdot
.55796 .35774 Mdot
.62166 .42364 Mdot
.45955 .34484 Mdot
.49237 .2996 Mdot
.41156 .29795 Mdot
.65273 .2951 Mdot
.77501 .56443 Mdot
.46655 .67329 Mdot
.62626 .58652 Mdot
.38829 .50002 Mdot
.60059 .20238 Mdot
.56462 .45546 Mdot
.58713 .42796 Mdot
.55312 .78241 Mdot
.45808 .49117 Mdot
.5127 .19699 Mdot
.43514 .52564 Mdot
.21557 .68885 Mdot
.43302 .5676 Mdot
.40422 .42541 Mdot
.63165 .38189 Mdot
.44509 .296 Mdot
.3466 .49933 Mdot
.48933 .69884 Mdot
.49411 .33604 Mdot
.29981 .50507 Mdot
.58996 .3605 Mdot
.56388 .35912 Mdot
.41947 .7488 Mdot
.37933 .51642 Mdot
.63629 .41369 Mdot
.45681 .64153 Mdot
.2945 .28684 Mdot
.63196 .6186 Mdot
.67322 .64301 Mdot
.53999 .62656 Mdot
.7563 .69928 Mdot
.49868 .32293 Mdot
.25309 .51943 Mdot
.36367 .51621 Mdot
.67819 .35252 Mdot
.3751 .55372 Mdot
.83168 .46736 Mdot
.50168 .32022 Mdot
.48168 .69123 Mdot
.62276 .58309 Mdot
.46385 .6362 Mdot
.30051 .64473 Mdot
.59468 .46029 Mdot
.55179 .50757 Mdot
.6199 .41065 Mdot
.53102 .40836 Mdot
.45867 .6904 Mdot
.42535 .48577 Mdot
.13773 .43825 Mdot
.46271 .70305 Mdot
.43405 .71426 Mdot
.59576 .81842 Mdot
.73508 .75211 Mdot
.44426 .45677 Mdot
.46265 .71912 Mdot
.6168 .41448 Mdot
.48862 .32362 Mdot
.40376 .54044 Mdot
.37459 .51663 Mdot
.44407 .71247 Mdot
.597 .38269 Mdot
.27638 .67573 Mdot
.62309 .43815 Mdot
.47653 .67492 Mdot
.62931 .42932 Mdot
.67793 .49531 Mdot
.63794 .39345 Mdot
.34432 .50647 Mdot
.39034 .49769 Mdot
.60489 .26761 Mdot
.4492 .66593 Mdot
.40374 .52316 Mdot
.43042 .52537 Mdot
.4481 .68656 Mdot
.52893 .35601 Mdot
.27758 .66919 Mdot
.37859 .44986 Mdot
.3645 .49645 Mdot
.47384 .29529 Mdot
.57562 .54702 Mdot
.23593 .49816 Mdot
.42234 .51634 Mdot
.50216 .30943 Mdot
.48874 .69808 Mdot
.37745 .46875 Mdot
.81102 .40583 Mdot
.73106 .47851 Mdot
.41615 .46285 Mdot
.62462 .38483 Mdot
.43443 .53379 Mdot
.46575 .16867 Mdot
.34915 .49686 Mdot
.45534 .68312 Mdot
.44393 .65353 Mdot
.43254 .80982 Mdot
.45111 .70069 Mdot
.5898 .41945 Mdot
.64559 .6063 Mdot
.81786 .50459 Mdot
.5984 .39982 Mdot
.43672 .55684 Mdot
.44744 .82918 Mdot
.43261 .49028 Mdot
.34118 .51448 Mdot
.40687 .18215 Mdot
.60996 .39393 Mdot
.43393 .65302 Mdot
.49906 .4449 Mdot
.40562 .58006 Mdot
.66831 .60595 Mdot
.34284 .44837 Mdot
.35396 .45983 Mdot
.41976 .19682 Mdot
.77231 .43549 Mdot
.66582 .57317 Mdot
.41443 .44666 Mdot
.42283 .51536 Mdot
.57537 .42587 Mdot
.39808 .49359 Mdot
.48961 .32753 Mdot
.43477 .65815 Mdot
.6305 .39178 Mdot
.4695 .32108 Mdot
.39597 .45446 Mdot
.46027 .3163 Mdot
.64898 .41825 Mdot
.66204 .57211 Mdot
.41122 .47039 Mdot
.46594 .29004 Mdot
.46059 .31853 Mdot
.39186 .53296 Mdot
.45333 .65766 Mdot
.44203 .56067 Mdot
.3613 .47645 Mdot
.41371 .5348 Mdot
.43578 .70268 Mdot
.88814 .47152 Mdot
.35587 .52208 Mdot
.42937 .29778 Mdot
.42903 .69838 Mdot
.53006 .3875 Mdot
.6131 .38744 Mdot
.35167 .46337 Mdot
.66488 .57455 Mdot
.64463 .56872 Mdot
.63566 .44772 Mdot
.43728 .72183 Mdot
.55048 .2712 Mdot
.44135 .60847 Mdot
.38292 .57124 Mdot
.39365 .43944 Mdot
.35722 .76861 Mdot
.67995 .23602 Mdot
.43796 .63931 Mdot
.6754 .36849 Mdot
.49987 .50522 Mdot
.63454 .5707 Mdot
.58396 .40625 Mdot
.45476 .72746 Mdot
.42763 .67894 Mdot
.46213 .65843 Mdot
.48532 .35087 Mdot
.61023 .26998 Mdot
.42671 .65009 Mdot
.44915 .62306 Mdot
.37009 .51051 Mdot
.42142 .51606 Mdot
.32908 .2748 Mdot
.27053 .37618 Mdot
.4564 .31796 Mdot
.63359 .44446 Mdot
.17571 .66266 Mdot
.6748 .60292 Mdot
.53256 .80815 Mdot
.35155 .5313 Mdot
.09166 .51629 Mdot
.38336 .54682 Mdot
.40132 .49106 Mdot
.47897 .71008 Mdot
.46067 .29521 Mdot
.47796 .33773 Mdot
.46497 .69327 Mdot
.45881 .62581 Mdot
.48928 .3288 Mdot
.73344 .68525 Mdot
.82631 .41363 Mdot
.61402 .47298 Mdot
.44437 .68152 Mdot
.39331 .7281 Mdot
.63431 .56321 Mdot
.31217 .52301 Mdot
.67743 .60281 Mdot
.62551 .41405 Mdot
.64832 .44615 Mdot
.66536 .60681 Mdot
.37142 .50461 Mdot
.65536 .41664 Mdot
.42822 .46605 Mdot
.67597 .73345 Mdot
.32284 .68518 Mdot
.56193 .25134 Mdot
.33887 .43067 Mdot
.52438 .37564 Mdot
.62572 .65315 Mdot
.38598 .45932 Mdot
.76312 .36644 Mdot
.46363 .3328 Mdot
.31628 .51873 Mdot
.66822 .61172 Mdot
.44384 .16023 Mdot
.41207 .46646 Mdot
.4549 .6799 Mdot
.63809 .58034 Mdot
.48206 .58645 Mdot
.63491 .68744 Mdot
.41551 .48797 Mdot
.11395 .49554 Mdot
.42995 .73113 Mdot
.63678 .39614 Mdot
.25762 .69869 Mdot
.4358 .63762 Mdot
.45728 .38266 Mdot
.63572 .25862 Mdot
.79737 .64827 Mdot
.44419 .64034 Mdot
.58928 .44594 Mdot
.47943 .66677 Mdot
.4887 .31107 Mdot
.46358 .73256 Mdot
.63322 .40516 Mdot
.36925 .47721 Mdot
.61168 .43169 Mdot
.47063 .35199 Mdot
.23698 .39121 Mdot
.66393 .57132 Mdot
.60524 .38628 Mdot
.66098 .59516 Mdot
.34053 .3776 Mdot
.55184 .21906 Mdot
.63307 .62362 Mdot
.22655 .59263 Mdot
.38601 .4401 Mdot
.43604 .63439 Mdot
.60755 .43181 Mdot
.69921 .33335 Mdot
.5075 .47883 Mdot
.43695 .6939 Mdot
.64566 .43637 Mdot
.54378 .62299 Mdot
.22901 .64557 Mdot
.43916 .46773 Mdot
.29891 .39773 Mdot
.44391 .68599 Mdot
.60689 .45823 Mdot
.24528 .33325 Mdot
.48252 .66992 Mdot
.59492 .41569 Mdot
.62101 .58358 Mdot
.63662 .60245 Mdot
.35522 .47438 Mdot
.65978 .64183 Mdot
.6542 .43346 Mdot
.67118 .66368 Mdot
.4586 .72219 Mdot
.49212 .60634 Mdot
.46804 .28618 Mdot
.61996 .42911 Mdot
.42848 .51546 Mdot
.47169 .73992 Mdot
.71253 .47553 Mdot
.29728 .70084 Mdot
.15695 .49486 Mdot
.61413 .43592 Mdot
.43098 .67012 Mdot
.45442 .67689 Mdot
.44933 .49225 Mdot
.50284 .56665 Mdot
.55566 .27173 Mdot
.46668 .42597 Mdot
.48371 .45056 Mdot
.6662 .4034 Mdot
.56656 .43983 Mdot
.33207 .51331 Mdot
.38242 .51251 Mdot
.63146 .57336 Mdot
.36829 .48084 Mdot
.47476 .7107 Mdot
.3507 .47999 Mdot
.65223 .6132 Mdot
.61848 .40566 Mdot
.40843 .46701 Mdot
.464 .30509 Mdot
.63526 .55983 Mdot
.62959 .63856 Mdot
.61291 .42556 Mdot
.44148 .71182 Mdot
.53006 .32342 Mdot
.62663 .44019 Mdot
.3789 .51541 Mdot
.5799 .55406 Mdot
.42236 .5279 Mdot
.3728 .59434 Mdot
.48273 .6684 Mdot
.62611 .39213 Mdot
.46889 .72211 Mdot
.6573 .59002 Mdot
.60012 .23756 Mdot
.38318 .49267 Mdot
.5954 .40975 Mdot
.70889 .41306 Mdot
.28715 .51721 Mdot
.45131 .61858 Mdot
.74391 .61785 Mdot
.46913 .63588 Mdot
.62285 .44829 Mdot
.51145 .8224 Mdot
.4981 .33715 Mdot
.58652 .42701 Mdot
.74152 .28656 Mdot
.60542 .40785 Mdot
.35582 .49152 Mdot
.37105 .5358 Mdot
.6337 .39275 Mdot
.48371 .29636 Mdot
.33373 .25059 Mdot
.65869 .38908 Mdot
.43676 .64859 Mdot
.67528 .74563 Mdot
.17869 .41032 Mdot
.66679 .5541 Mdot
.62905 .57775 Mdot
.42642 .5776 Mdot
.41951 .43674 Mdot
.66638 .62014 Mdot
.63705 .64469 Mdot
.48686 .35475 Mdot
.60323 .43339 Mdot
.4472 .75275 Mdot
.61242 .62068 Mdot
.45542 .56553 Mdot
.64067 .28923 Mdot
.44127 .46649 Mdot
.51615 .74239 Mdot
.36484 .54371 Mdot
.43442 .36096 Mdot
.6529 .61408 Mdot
.41859 .5432 Mdot
.4439 .51399 Mdot
.67106 .58703 Mdot
.49043 .32452 Mdot
.57433 .61499 Mdot
.63333 .42478 Mdot
.84862 .40825 Mdot
.43811 .48327 Mdot
.35392 .49503 Mdot
.65978 .57634 Mdot
.56191 .31644 Mdot
.43483 .67339 Mdot
.47487 .64718 Mdot
.65126 .40139 Mdot
.51166 .51437 Mdot
.35847 .45885 Mdot
.37668 .46461 Mdot
.63918 .41887 Mdot
.58645 .40428 Mdot
.75563 .56141 Mdot
.37347 .53133 Mdot
.64441 .58268 Mdot
.46974 .2643 Mdot
.65546 .61324 Mdot
.42423 .52411 Mdot
.35518 .50207 Mdot
.34398 .50421 Mdot
.42784 .51575 Mdot
.64613 .64277 Mdot
.40631 .54857 Mdot
.31787 .50869 Mdot
.43161 .67914 Mdot
.41868 .50254 Mdot
.48163 .44435 Mdot
.36931 .48918 Mdot
.48859 .32524 Mdot
.23513 .52058 Mdot
.41184 .46679 Mdot
.35229 .46521 Mdot
.62457 .37516 Mdot
.38424 .48132 Mdot
.67552 .59891 Mdot
.4439 .67139 Mdot
.6489 .57418 Mdot
.64769 .56794 Mdot
.66376 .43056 Mdot
.49842 .35436 Mdot
.33913 .49043 Mdot
.47624 .34988 Mdot
.43076 .55923 Mdot
.41031 .45416 Mdot
.61869 .25471 Mdot
.22676 .70364 Mdot
.21746 .41934 Mdot
.38193 .49393 Mdot
.60918 .39641 Mdot
.61627 .38827 Mdot
.29257 .49029 Mdot
.44134 .47397 Mdot
.64499 .63012 Mdot
.63965 .5683 Mdot
.30081 .33438 Mdot
.45601 .20498 Mdot
.48913 .32515 Mdot
.56852 .5348 Mdot
.41607 .45137 Mdot
.42459 .53149 Mdot
.43545 .49595 Mdot
.65565 .39987 Mdot
.4583 .39682 Mdot
.58559 .41902 Mdot
.6076 .75203 Mdot
.66679 .59793 Mdot
.41519 .4762 Mdot
.5282 .75824 Mdot
.47023 .70091 Mdot
.44468 .67089 Mdot
.62744 .63561 Mdot
.56765 .39544 Mdot
.29726 .3052 Mdot
.81801 .6568 Mdot
.42892 .72453 Mdot
.45279 .31472 Mdot
.38328 .45682 Mdot
.61278 .40843 Mdot
.4796 .67811 Mdot
.4534 .32211 Mdot
.42398 .47815 Mdot
.61168 .2701 Mdot
.37849 .49826 Mdot
.54349 .67113 Mdot
.45631 .65031 Mdot
.83271 .45553 Mdot
.43062 .71573 Mdot
.63439 .55919 Mdot
.66068 .61768 Mdot
.36191 .5241 Mdot
.31719 .74967 Mdot
.44972 .62835 Mdot
.59275 .55403 Mdot
.50314 .33508 Mdot
.70271 .48954 Mdot
.49133 .31667 Mdot
.63741 .39855 Mdot
.49614 .33332 Mdot
.63572 .40456 Mdot
.27033 .35906 Mdot
.41707 .71598 Mdot
.4671 .32798 Mdot
.69996 .41983 Mdot
.42926 .44258 Mdot
.4574 .31049 Mdot
.34784 .54764 Mdot
.3509 .58355 Mdot
.63938 .42237 Mdot
.49964 .32053 Mdot
.42634 .48913 Mdot
.56247 .17448 Mdot
.62033 .61196 Mdot
.65018 .62815 Mdot
.36184 .55766 Mdot
.67018 .41147 Mdot
.48153 .71399 Mdot
.80994 .45577 Mdot
.62217 .55809 Mdot
.35882 .5242 Mdot
.34669 .49359 Mdot
.4598 .6282 Mdot
.50328 .78366 Mdot
.3588 .51576 Mdot
.46459 .45619 Mdot
.3719 .53164 Mdot
.61968 .61976 Mdot
.46203 .63534 Mdot
.45035 .67435 Mdot
.64942 .43274 Mdot
.46152 .71448 Mdot
.28669 .47363 Mdot
.54941 .75338 Mdot
.46384 .48425 Mdot
.65518 .59543 Mdot
.58255 .75418 Mdot
.6049 .75491 Mdot
.70241 .25957 Mdot
.4366 .61982 Mdot
.3761 .55308 Mdot
.44445 .71772 Mdot
.48534 .31565 Mdot
.45637 .66613 Mdot
.45731 .72537 Mdot
.38762 .4658 Mdot
.41313 .48785 Mdot
.6234 .3994 Mdot
.4991 .55193 Mdot
.43498 .70773 Mdot
.38685 .54663 Mdot
.41305 .43248 Mdot
.4328 .47772 Mdot
.62857 .51361 Mdot
.44338 .63479 Mdot
.65747 .78766 Mdot
.37918 .2745 Mdot
.43578 .70829 Mdot
.39205 .16904 Mdot
.71141 .42634 Mdot
.64418 .45644 Mdot
.64602 .6549 Mdot
.37724 .53538 Mdot
.59527 .39673 Mdot
.41179 .479 Mdot
.51792 .74037 Mdot
.38986 .47612 Mdot
.49081 .32922 Mdot
.43001 .46562 Mdot
.63989 .44878 Mdot
.62108 .43884 Mdot
.35196 .51082 Mdot
.40676 .46842 Mdot
.25043 .36583 Mdot
.42829 .62229 Mdot
.44392 .66457 Mdot
.5433 .27597 Mdot
.46622 .31402 Mdot
.66704 .60857 Mdot
.39683 .50068 Mdot
.66649 .42125 Mdot
.61814 .43766 Mdot
.44166 .63358 Mdot
.64039 .43467 Mdot
.64355 .61578 Mdot
.38702 .49236 Mdot
.66408 .62158 Mdot
.48688 .35141 Mdot
.45487 .63371 Mdot
.41741 .49575 Mdot
.36987 .51005 Mdot
.44394 .65326 Mdot
.33309 .50258 Mdot
.47663 .29586 Mdot
.60329 .41045 Mdot
.44951 .63834 Mdot
.64311 .60542 Mdot
.63632 .39957 Mdot
.41159 .53919 Mdot
.15687 .60239 Mdot
.3579 .49168 Mdot
.38745 .54139 Mdot
.7326 .26927 Mdot
.42382 .45656 Mdot
.61144 .43505 Mdot
.48231 .68626 Mdot
.34293 .43083 Mdot
.40064 .29489 Mdot
.88405 .5443 Mdot
.58772 .42761 Mdot
.37878 .45784 Mdot
.62321 .2092 Mdot
.37131 .46446 Mdot
.36211 .75928 Mdot
.67253 .45471 Mdot
.52007 .42405 Mdot
.37684 .56088 Mdot
.62875 .60533 Mdot
.62076 .39735 Mdot
.64072 .40629 Mdot
.63694 .77908 Mdot
.38394 .46494 Mdot
.55341 .59794 Mdot
.42305 .49162 Mdot
.63982 .60802 Mdot
.32474 .31053 Mdot
.61889 .43941 Mdot
.1772 .49027 Mdot
.38584 .53387 Mdot
.42676 .66752 Mdot
.63644 .37112 Mdot
.65313 .51196 Mdot
.41162 .53615 Mdot
.46579 .34104 Mdot
.60799 .59645 Mdot
.37372 .42412 Mdot
.65344 .60071 Mdot
.41592 .53244 Mdot
.4373 .41599 Mdot
.26216 .7116 Mdot
.4575 .65755 Mdot
.62381 .58071 Mdot
.60201 .53139 Mdot
.39661 .55353 Mdot
.44597 .63982 Mdot
.43464 .68742 Mdot
.47939 .3535 Mdot
.57598 .49968 Mdot
.59563 .67546 Mdot
.35512 .71865 Mdot
.66024 .7618 Mdot
.62478 .37199 Mdot
.7694 .47869 Mdot
.40249 .53447 Mdot
.50988 .25428 Mdot
.67287 .58562 Mdot
.35712 .48585 Mdot
.27373 .54764 Mdot
.46942 .69481 Mdot
.36214 .50137 Mdot
.4827 .33357 Mdot
.53042 .28587 Mdot
.49891 .25385 Mdot
.64242 .25453 Mdot
.62116 .41181 Mdot
.32722 .52701 Mdot
.4215 .41203 Mdot
.62859 .38292 Mdot
.35151 .45942 Mdot
.59789 .41704 Mdot
.74324 .69205 Mdot
.45644 .30754 Mdot
.43722 .64276 Mdot
.6704 .48927 Mdot
.34307 .47563 Mdot
.38636 .43749 Mdot
.48513 .36374 Mdot
.38531 .51625 Mdot
.2301 .68413 Mdot
.65399 .49518 Mdot
.65126 .40751 Mdot
.46102 .65821 Mdot
.34713 .47428 Mdot
.59224 .50856 Mdot
.36412 .47294 Mdot
.36552 .65552 Mdot
.35131 .46733 Mdot
.6129 .67807 Mdot
.45178 .65325 Mdot
.65666 .60006 Mdot
.39933 .55543 Mdot
.39524 .47966 Mdot
.43549 .25467 Mdot
.42674 .57121 Mdot
.40921 .55003 Mdot
.48801 .65158 Mdot
.48068 .67647 Mdot
.47362 .66002 Mdot
.61241 .45298 Mdot
.43668 .19953 Mdot
.65056 .58333 Mdot
.32504 .4538 Mdot
.61334 .61616 Mdot
.28479 .70319 Mdot
.45324 .31563 Mdot
.64867 .23903 Mdot
.40481 .51318 Mdot
.4712 .67541 Mdot
.76268 .39909 Mdot
.49194 .68137 Mdot
.55542 .53608 Mdot
.63624 .58758 Mdot
.46383 .69862 Mdot
.40019 .48538 Mdot
.50354 .4915 Mdot
.57325 .19789 Mdot
.65667 .58103 Mdot
.43921 .5523 Mdot
.59843 .45003 Mdot
.56281 .24177 Mdot
.1544 .57052 Mdot
.61988 .61227 Mdot
.68627 .60458 Mdot
.38366 .46333 Mdot
.47253 .70021 Mdot
.63199 .60964 Mdot
.62723 .62564 Mdot
.64272 .43317 Mdot
.41379 .49273 Mdot
.41407 .49936 Mdot
.61905 .44951 Mdot
.65193 .5741 Mdot
.37628 .56413 Mdot
.39993 .42295 Mdot
.53207 .1502 Mdot
.52599 .60974 Mdot
.85779 .41713 Mdot
.29142 .46538 Mdot
.26137 .55428 Mdot
.81821 .46404 Mdot
.42688 .68783 Mdot
.40747 .4577 Mdot
.37566 .43044 Mdot
.65331 .43458 Mdot
.37696 .48431 Mdot
.65364 .46009 Mdot
.63599 .57709 Mdot
.43323 .16897 Mdot
.59286 .72947 Mdot
.77166 .66462 Mdot
.37728 .48219 Mdot
.44345 .76164 Mdot
.4772 .31941 Mdot
.65722 .55378 Mdot
.47067 .64882 Mdot
.42942 .50421 Mdot
.24803 .36888 Mdot
.58583 .42301 Mdot
.44671 .70739 Mdot
.29416 .28954 Mdot
.5128 .38048 Mdot
.42327 .52397 Mdot
.59751 .44563 Mdot
.77293 .3895 Mdot
.45729 .5827 Mdot
.63124 .54918 Mdot
.49168 .32595 Mdot
.62025 .39472 Mdot
.64157 .56686 Mdot
.45701 .75161 Mdot
.45724 .70038 Mdot
.48047 .71868 Mdot
.21939 .45375 Mdot
.61579 .38016 Mdot
.4743 .32195 Mdot
.47998 .21266 Mdot
.44974 .224 Mdot
.48955 .33152 Mdot
.64466 .44858 Mdot
.4803 .67679 Mdot
.46737 .68781 Mdot
.4436 .67209 Mdot
.19637 .44433 Mdot
.42641 .69784 Mdot
.56757 .80398 Mdot
.43113 .48308 Mdot
.46009 .45319 Mdot
.37733 .45995 Mdot
.6533 .62805 Mdot
.44931 .64667 Mdot
.51187 .46625 Mdot
.43615 .54249 Mdot
.57772 .21556 Mdot
.35474 .48208 Mdot
.67836 .58156 Mdot
.36539 .51179 Mdot
.45178 .78605 Mdot
.43953 .71518 Mdot
.37989 .49033 Mdot
.67176 .57499 Mdot
.46966 .3076 Mdot
.45752 .61961 Mdot
.41604 .4865 Mdot
.76381 .59553 Mdot
.42669 .46001 Mdot
.77401 .64851 Mdot
.50734 .61873 Mdot
.45289 .31417 Mdot
.52094 .7007 Mdot
.57869 .41479 Mdot
.45267 .439 Mdot
.39026 .57777 Mdot
.66057 .58871 Mdot
.69734 .47384 Mdot
.62026 .4219 Mdot
.46867 .39516 Mdot
.33504 .45766 Mdot
.46667 .35092 Mdot
.42982 .61476 Mdot
.66617 .622 Mdot
.3605 .44926 Mdot
.44764 .49618 Mdot
.62931 .76374 Mdot
.32199 .49425 Mdot
.34814 .48402 Mdot
.47179 .36127 Mdot
.5631 .79801 Mdot
.36982 .49385 Mdot
.56168 .53204 Mdot
.4566 .7341 Mdot
.39158 .57191 Mdot
.54966 .80989 Mdot
.37179 .53737 Mdot
.45427 .70831 Mdot
.42323 .60885 Mdot
.56671 .65711 Mdot
.5015 .34747 Mdot
.35322 .46236 Mdot
.4369 .81192 Mdot
.38234 .52808 Mdot
.64662 .586 Mdot
.43259 .45998 Mdot
.63098 .40691 Mdot
.21613 .40829 Mdot
.65492 .42623 Mdot
.36952 .45302 Mdot
.44259 .67587 Mdot
.66548 .58476 Mdot
.19359 .48971 Mdot
.58895 .2763 Mdot
.5431 .80223 Mdot
.82917 .60405 Mdot
.49612 .31382 Mdot
.50774 .34749 Mdot
.66988 .61943 Mdot
.37849 .49128 Mdot
.55164 .82707 Mdot
.43257 .56917 Mdot
.36465 .49867 Mdot
.39103 .47529 Mdot
.5345 .22066 Mdot
.63814 .57186 Mdot
.63529 .43106 Mdot
.35692 .50993 Mdot
.40759 .54904 Mdot
.42728 .68719 Mdot
.46357 .31242 Mdot
.61329 .38762 Mdot
.46945 .33834 Mdot
.61617 .40084 Mdot
.40975 .16698 Mdot
.43022 .53999 Mdot
.47315 .30824 Mdot
.60781 .61157 Mdot
.44113 .70956 Mdot
.55092 .74699 Mdot
.63996 .40224 Mdot
.64018 .44364 Mdot
.3506 .4986 Mdot
.45651 .70919 Mdot
.47522 .71602 Mdot
.48494 .3128 Mdot
.6377 .62189 Mdot
.41091 .466 Mdot
.40832 .45102 Mdot
.40667 .6558 Mdot
.6681 .41374 Mdot
.53915 .68062 Mdot
.78324 .50945 Mdot
.37977 .494 Mdot
.46164 .72067 Mdot
.39996 .4681 Mdot
.80713 .51073 Mdot
.46755 .70721 Mdot
.37397 .5407 Mdot
.32852 .23425 Mdot
.56506 .39889 Mdot
.57338 .68435 Mdot
.34671 .50943 Mdot
.84131 .52985 Mdot
.40583 .52593 Mdot
.46945 .1402 Mdot
.68311 .34429 Mdot
.38208 .44357 Mdot
.40412 .54282 Mdot
.30177 .68329 Mdot
.39 .45109 Mdot
.62533 .44901 Mdot
.36749 .24029 Mdot
.48903 .70169 Mdot
.71109 .65436 Mdot
.24129 .52112 Mdot
.50122 .31997 Mdot
.65058 .40078 Mdot
.58172 .45742 Mdot
.48379 .34022 Mdot
.44655 .68255 Mdot
.38285 .50203 Mdot
.52622 .51141 Mdot
.65989 .3992 Mdot
.30495 .45221 Mdot
.64483 .58769 Mdot
.73523 .5129 Mdot
.59875 .48021 Mdot
.65081 .60665 Mdot
.41877 .508 Mdot
.29184 .67979 Mdot
.24558 .44427 Mdot
.81965 .39195 Mdot
.64194 .56558 Mdot
.6589 .5813 Mdot
.20412 .42119 Mdot
.45747 .28765 Mdot
.65884 .74523 Mdot
.62492 .68236 Mdot
.66952 .60078 Mdot
.4727 .59462 Mdot
.59368 .43229 Mdot
.61283 .64677 Mdot
.315 .51066 Mdot
.42052 .4613 Mdot
.39856 .48363 Mdot
.64407 .62216 Mdot
.28887 .51516 Mdot
.24507 .68525 Mdot
.66179 .59702 Mdot
.38699 .58556 Mdot
.54544 .46738 Mdot
.71747 .39225 Mdot
.62274 .44507 Mdot
.49897 .35046 Mdot
.50954 .30891 Mdot
.42843 .66629 Mdot
.49881 .35245 Mdot
.52648 .27669 Mdot
.39064 .51295 Mdot
.66048 .60728 Mdot
.70853 .47957 Mdot
.64045 .60132 Mdot
.48073 .33997 Mdot
.45347 .33522 Mdot
.43179 .67862 Mdot
.44831 .66392 Mdot
.26038 .5795 Mdot
.32782 .33661 Mdot
.36025 .47337 Mdot
.70099 .31322 Mdot
.46424 .72259 Mdot
.30949 .44412 Mdot
.4958 .35648 Mdot
.46677 .3106 Mdot
.43645 .26421 Mdot
.40486 .50626 Mdot
.39541 .77913 Mdot
.40177 .50326 Mdot
.3254 .31633 Mdot
.35523 .53371 Mdot
.64185 .43397 Mdot
.40982 .50805 Mdot
.45366 .24646 Mdot
.3416 .46871 Mdot
.42492 .44208 Mdot
.66271 .40859 Mdot
.3642 .42585 Mdot
.63116 .40901 Mdot
.36529 .45882 Mdot
.48393 .29018 Mdot
.66034 .41423 Mdot
.39524 .31993 Mdot
.44 .27 Mdot
.63661 .45297 Mdot
.46934 .34961 Mdot
.49691 .30573 Mdot
.40995 .34791 Mdot
.47091 .64884 Mdot
.36659 .57678 Mdot
.37659 .48858 Mdot
.58513 .39831 Mdot
.63377 .57378 Mdot
.39618 .54802 Mdot
.4066 .4325 Mdot
.35753 .53075 Mdot
.42833 .66418 Mdot
.5588 .26859 Mdot
.47931 .30849 Mdot
.60853 .44868 Mdot
.53298 .33472 Mdot
.67273 .41493 Mdot
.43672 .46267 Mdot
.36322 .43546 Mdot
.25623 .53293 Mdot
.73823 .42841 Mdot
.1913 .43117 Mdot
.45555 .70195 Mdot
.62349 .38542 Mdot
.47459 .28638 Mdot
.4196 .42693 Mdot
.4743 .67777 Mdot
.633 .40572 Mdot
.37927 .4982 Mdot
.44259 .54731 Mdot
.57121 .77086 Mdot
.28899 .43826 Mdot
.42089 .30365 Mdot
.63573 .44813 Mdot
.58172 .42929 Mdot
.47685 .23668 Mdot
.45665 .36542 Mdot
.5089 .4766 Mdot
.37485 .47139 Mdot
.46766 .34249 Mdot
.47947 .67901 Mdot
.22815 .4547 Mdot
.64946 .62431 Mdot
.5003 .55937 Mdot
.37868 .48346 Mdot
.51997 .39911 Mdot
.44095 .67623 Mdot
.4846 .33096 Mdot
.64658 .62182 Mdot
.50472 .35935 Mdot
.6431 .39023 Mdot
.7748 .68999 Mdot
.38246 .52365 Mdot
.35016 .48942 Mdot
.64842 .55948 Mdot
.47427 .68861 Mdot
.49242 .36296 Mdot
.68479 .73189 Mdot
.64753 .41417 Mdot
.53075 .82971 Mdot
.46747 .71499 Mdot
.40412 .72253 Mdot
.60489 .44433 Mdot
.62548 .6331 Mdot
.39724 .34215 Mdot
.64888 .61332 Mdot
.36043 .45961 Mdot
.46201 .67365 Mdot
.62324 .58773 Mdot
.49533 .56952 Mdot
.60733 .20085 Mdot
.3985 .72873 Mdot
.39201 .50667 Mdot
.51863 .17029 Mdot
.76491 .6343 Mdot
.4216 .63848 Mdot
.66241 .57097 Mdot
.35614 .48252 Mdot
.37261 .44377 Mdot
.37985 .52692 Mdot
.62811 .58803 Mdot
.67397 .29818 Mdot
.64138 .42019 Mdot
.38085 .4612 Mdot
.48584 .35456 Mdot
.62783 .41524 Mdot
.66558 .49455 Mdot
.62465 .44325 Mdot
.43045 .62829 Mdot
.4301 .45435 Mdot
.62992 .53621 Mdot
.3989 .14742 Mdot
.65156 .57646 Mdot
.65476 .443 Mdot
.43376 .52229 Mdot
.72469 .46364 Mdot
.47497 .66486 Mdot
.6491 .41627 Mdot
.35397 .49376 Mdot
.67621 .48223 Mdot
.22905 .40303 Mdot
.62241 .4422 Mdot
.47634 .67958 Mdot
.80029 .37465 Mdot
.37148 .4819 Mdot
.39958 .52793 Mdot
.4622 .6939 Mdot
.23135 .61658 Mdot
.25678 .32241 Mdot
.40434 .46822 Mdot
.65703 .6017 Mdot
.67478 .79788 Mdot
.42051 .43513 Mdot
.3709 .27068 Mdot
.62308 .39756 Mdot
.58437 .61073 Mdot
.54267 .64363 Mdot
.42095 .42781 Mdot
.67491 .73265 Mdot
.68282 .62536 Mdot
.51103 .18711 Mdot
.65889 .45706 Mdot
.61712 .34494 Mdot
.47457 .17068 Mdot
.67827 .58792 Mdot
.40914 .67686 Mdot
.69899 .69853 Mdot
.18059 .55729 Mdot
.79871 .39229 Mdot
.57984 .33717 Mdot
.24853 .36526 Mdot
.52972 .48852 Mdot
.60931 .40121 Mdot
.52374 .33838 Mdot
.41348 .47983 Mdot
.7683 .62949 Mdot
.4114 .78551 Mdot
.33284 .76682 Mdot
.52307 .1694 Mdot
.35401 .74737 Mdot
.60515 .20619 Mdot
.71258 .26287 Mdot
.26863 .50324 Mdot
.74675 .42016 Mdot
.53015 .83359 Mdot
.36513 .22068 Mdot
.67865 .75881 Mdot
.46524 .4909 Mdot
.55021 .55232 Mdot
.8048 .6213 Mdot
.42754 .75523 Mdot
.24247 .67024 Mdot
.65124 .42819 Mdot
.48392 .66814 Mdot
.69714 .69329 Mdot
.46926 .6347 Mdot
.55571 .64829 Mdot
.8048 .37193 Mdot
.62433 .20447 Mdot
.46973 .79694 Mdot
.83639 .48682 Mdot
.28082 .55938 Mdot
.39594 .84346 Mdot
.66003 .39374 Mdot
.43231 .64291 Mdot
.43466 .32477 Mdot
.46745 .22948 Mdot
.63342 .73657 Mdot
.72475 .67883 Mdot
.60054 .2506 Mdot
.34068 .36192 Mdot
.4533 .6797 Mdot
.52663 .67533 Mdot
.58441 .58054 Mdot
.59539 .73412 Mdot
.35618 .24406 Mdot
.74546 .31211 Mdot
.52572 .52782 Mdot
.7333 .6357 Mdot
.75148 .50008 Mdot
.15572 .55888 Mdot
.39226 .27226 Mdot
.33924 .41847 Mdot
.55372 .63639 Mdot
.81689 .47723 Mdot
.19648 .57093 Mdot
.30634 .34845 Mdot
.46258 .22795 Mdot
.36925 .20192 Mdot
.80798 .56034 Mdot
.23254 .29902 Mdot
.49503 .69143 Mdot
.34655 .48992 Mdot
.24013 .60628 Mdot
.4473 .8145 Mdot
.4501 .32506 Mdot
.66285 .27275 Mdot
.50117 .33644 Mdot
.42101 .68923 Mdot
.2343 .37654 Mdot
.55034 .80668 Mdot
.45267 .82194 Mdot
.50831 .31246 Mdot
.34441 .42706 Mdot
.81076 .70733 Mdot
.54499 .20039 Mdot
.57199 .71276 Mdot
.51567 .147 Mdot
.50816 .41897 Mdot
.48423 .59651 Mdot
.62496 .58558 Mdot
.46987 .16331 Mdot
.4656 .68285 Mdot
.25656 .25828 Mdot
.46036 .14453 Mdot
.24172 .49108 Mdot
.85925 .33505 Mdot
.49282 .23119 Mdot
.51857 .41886 Mdot
.6969 .6289 Mdot
.37929 .30686 Mdot
.21461 .64102 Mdot
.36433 .39244 Mdot
.73114 .47127 Mdot
.8445 .57767 Mdot
.50268 .17762 Mdot
.47962 .82391 Mdot
.74428 .71522 Mdot
.18583 .5801 Mdot
.59214 .51559 Mdot
.308 .5046 Mdot
.61459 .48495 Mdot
.73551 .31737 Mdot
.38404 .18168 Mdot
.38419 .2695 Mdot
.88367 .55582 Mdot
.4677 .36652 Mdot
.64137 .30164 Mdot
.80449 .35136 Mdot
.35749 .36096 Mdot
.52665 .64294 Mdot
.39209 .23523 Mdot
.34551 .42078 Mdot
.52583 .29928 Mdot
.69083 .28892 Mdot
.54936 .7024 Mdot
.38452 .22373 Mdot
.7935 .41653 Mdot
.6258 .76459 Mdot
.3326 .68713 Mdot
.43796 .21679 Mdot
.49138 .66631 Mdot
.32309 .3573 Mdot
.52713 .62875 Mdot
.61158 .19462 Mdot
.67656 .62295 Mdot
.65025 .1997 Mdot
.25944 .32337 Mdot
.40915 .56217 Mdot
.4183 .58451 Mdot
.50157 .68711 Mdot
.33668 .33992 Mdot
.37115 .42092 Mdot
.59558 .76401 Mdot
.67559 .2294 Mdot
.29071 .551 Mdot
.57417 .60693 Mdot
.69612 .47038 Mdot
.81449 .3664 Mdot
.25723 .61106 Mdot
.45592 .36712 Mdot
.3231 .28872 Mdot
.1706 .58512 Mdot
.6246 .42569 Mdot
.48938 .82105 Mdot
.62936 .54851 Mdot
.22687 .42418 Mdot
.35626 .72302 Mdot
.22325 .53585 Mdot
.67684 .23002 Mdot
.5615 .3553 Mdot
.247 .35004 Mdot
.34903 .3793 Mdot
.60392 .81832 Mdot
.71983 .39574 Mdot
.34462 .44658 Mdot
.73734 .64822 Mdot
.48324 .29565 Mdot
.28928 .63102 Mdot
.66585 .79032 Mdot
.58308 .31156 Mdot
.32731 .51391 Mdot
.23643 .47947 Mdot
.56602 .38336 Mdot
.50388 .4993 Mdot
.16059 .43038 Mdot
.43588 .4553 Mdot
.47091 .21226 Mdot
.80196 .57922 Mdot
.36247 .30667 Mdot
.82943 .43202 Mdot
.80255 .48119 Mdot
.26591 .26197 Mdot
.50341 .15462 Mdot
.57678 .27597 Mdot
.46832 .17666 Mdot
.57618 .17059 Mdot
.25535 .27983 Mdot
.40097 .58338 Mdot
.64178 .55747 Mdot
.13579 .5775 Mdot
.61617 .4452 Mdot
.50848 .20909 Mdot
.65914 .76285 Mdot
.62525 .49879 Mdot
.45477 .75868 Mdot
.37695 .40042 Mdot
.5326 .49948 Mdot
.41995 .64545 Mdot
.36292 .42456 Mdot
.1881 .39496 Mdot
.30823 .2316 Mdot
.21553 .33798 Mdot
.82484 .55492 Mdot
.44893 .17464 Mdot
.52968 .42712 Mdot
.48307 .79671 Mdot
.29443 .48945 Mdot
.42777 .48085 Mdot
.45217 .38018 Mdot
.49505 .231 Mdot
.23037 .48586 Mdot
.63611 .71689 Mdot
.42695 .61836 Mdot
.67656 .28104 Mdot
.48479 .90954 Mdot
.27827 .58328 Mdot
.57744 .80948 Mdot
.48736 .24511 Mdot
.33683 .32766 Mdot
.72741 .31847 Mdot
.23045 .51265 Mdot
.72702 .26888 Mdot
.41627 .66988 Mdot
.6773 .75535 Mdot
.60104 .32941 Mdot
.48534 .49926 Mdot
.56305 .26539 Mdot
.64405 .22115 Mdot
.70784 .57695 Mdot
.20868 .49798 Mdot
.65755 .68738 Mdot
.22242 .59196 Mdot
.69214 .42011 Mdot
.74256 .51882 Mdot
.64849 .7965 Mdot
.78053 .46079 Mdot
.34284 .29769 Mdot
.55171 .48064 Mdot
.50992 .73093 Mdot
.6832 .62752 Mdot
.34866 .29581 Mdot
.47553 .43418 Mdot
.46134 .19075 Mdot
.3631 .13711 Mdot
.16995 .46635 Mdot
.8474 .41668 Mdot
.71272 .31688 Mdot
.32827 .49964 Mdot
.76172 .29581 Mdot
.20601 .33651 Mdot
.43509 .13429 Mdot
.73282 .54998 Mdot
.66954 .44826 Mdot
.6207 .62884 Mdot
.20398 .38116 Mdot
.66393 .29468 Mdot
.75652 .30502 Mdot
.41066 .23491 Mdot
.62434 .63749 Mdot
.23762 .71774 Mdot
.36691 .20823 Mdot
.37416 .72852 Mdot
.28746 .44068 Mdot
.34954 .53806 Mdot
.43822 .78127 Mdot
.46508 .63145 Mdot
.7678 .48837 Mdot
.31871 .34636 Mdot
.61899 .43178 Mdot
.43587 .34831 Mdot
.7328 .66819 Mdot
.42969 .46548 Mdot
.5988 .52899 Mdot
.44232 .62144 Mdot
.74127 .42846 Mdot
.56573 .75253 Mdot
.37333 .17945 Mdot
.52978 .23749 Mdot
.38306 .56183 Mdot
.36462 .30043 Mdot
.55541 .26159 Mdot
.24558 .33227 Mdot
.66649 .62529 Mdot
.54632 .17333 Mdot
.53525 .5568 Mdot
.32193 .35589 Mdot
.42517 .78037 Mdot
.35667 .585 Mdot
.39471 .43631 Mdot
.79084 .45045 Mdot
.35637 .63638 Mdot
.49947 .53683 Mdot
.31176 .49052 Mdot
.31299 .5358 Mdot
.77218 .30464 Mdot
.53117 .29061 Mdot
.74021 .50272 Mdot
.57424 .18004 Mdot
.63103 .59565 Mdot
.44797 .71846 Mdot
.51014 .30152 Mdot
.70533 .71848 Mdot
.3748 .63258 Mdot
.22805 .40467 Mdot
.61554 .49302 Mdot
.59583 .30562 Mdot
.58501 .18808 Mdot
.54148 .17801 Mdot
.38683 .79791 Mdot
.43276 .61142 Mdot
.27406 .50371 Mdot
.69382 .73672 Mdot
.48498 .68216 Mdot
.59528 .77838 Mdot
.58191 .77756 Mdot
.41001 .17793 Mdot
.59119 .54399 Mdot
.84582 .56415 Mdot
.41643 .30787 Mdot
.65257 .27197 Mdot
.19164 .48902 Mdot
.635 .80071 Mdot
.61848 .2163 Mdot
.4622 .59334 Mdot
.31756 .70637 Mdot
.46264 .47197 Mdot
.5072 .75992 Mdot
.17439 .63336 Mdot
.49084 .27895 Mdot
.40869 .73408 Mdot
.79598 .41578 Mdot
.381 .51007 Mdot
.16116 .48323 Mdot
.71557 .69883 Mdot
.19989 .42615 Mdot
.61735 .6318 Mdot
.4224 .51303 Mdot
.34789 .45877 Mdot
.35836 .26686 Mdot
.56741 .66053 Mdot
.44741 .19593 Mdot
.69606 .77441 Mdot
.77534 .38119 Mdot
.40984 .78381 Mdot
.48762 .21676 Mdot
.75621 .3178 Mdot
.77312 .62093 Mdot
.5702 .50612 Mdot
.50357 .23365 Mdot
.3743 .35344 Mdot
.83385 .49539 Mdot
.48388 .44083 Mdot
.65822 .66063 Mdot
.63701 .74356 Mdot
.78736 .50894 Mdot
.21347 .46975 Mdot
.41511 .52715 Mdot
.29453 .28923 Mdot
.72829 .28099 Mdot
.39623 .79418 Mdot
.20541 .6426 Mdot
.16964 .45437 Mdot
.36309 .67542 Mdot
.79269 .49514 Mdot
.75731 .63807 Mdot
.60208 .83269 Mdot
.53451 .56492 Mdot
.59973 .22154 Mdot
.36476 .36516 Mdot
.58131 .18489 Mdot
.65216 .5584 Mdot
.63661 .69311 Mdot
.69798 .46549 Mdot
.4613 .18326 Mdot
.2707 .63685 Mdot
.67124 .23679 Mdot
.5149 .43831 Mdot
.27608 .24885 Mdot
.77117 .43969 Mdot
.53017 .4738 Mdot
.63321 .38816 Mdot
.55576 .35154 Mdot
.67567 .26635 Mdot
.73667 .38979 Mdot
.62124 .80368 Mdot
.62157 .46247 Mdot
.51929 .32086 Mdot
.38237 .74807 Mdot
.30581 .38814 Mdot
.7955 .45778 Mdot
.36461 .30086 Mdot
.65217 .21645 Mdot
.37654 .2432 Mdot
.28968 .2971 Mdot
.51208 .22239 Mdot
.82172 .63518 Mdot
.57119 .7073 Mdot
.5097 .26791 Mdot
.72316 .688 Mdot
.66156 .31355 Mdot
.47762 .6022 Mdot
.09171 .40477 Mdot
.78092 .67517 Mdot
.75872 .42735 Mdot
.38472 .18177 Mdot
.81266 .49687 Mdot
.74036 .43365 Mdot
.21281 .61658 Mdot
.52757 .60802 Mdot
.2721 .34354 Mdot
.3912 .47633 Mdot
.1855 .38568 Mdot
.30538 .37599 Mdot
.35429 .1927 Mdot
.77155 .31568 Mdot
.42515 .76962 Mdot
.4262 .4514 Mdot
.60427 .44853 Mdot
.55912 .6152 Mdot
.27531 .39938 Mdot
.26557 .65863 Mdot
.51717 .65014 Mdot
.68932 .46282 Mdot
.62411 .38148 Mdot
.54448 .26438 Mdot
.42969 .72451 Mdot
.65624 .28404 Mdot
.78417 .5038 Mdot
.59122 .37681 Mdot
.52218 .54077 Mdot
.3455 .30655 Mdot
.541 .64805 Mdot
.37658 .72579 Mdot
.22907 .5061 Mdot
.64458 .53196 Mdot
.6301 .44511 Mdot
.35971 .71348 Mdot
.80287 .63031 Mdot
.77654 .39511 Mdot
.369 .19935 Mdot
.53744 .34979 Mdot
.29417 .70125 Mdot
.34995 .28863 Mdot
.22396 .65953 Mdot
.28939 .72077 Mdot
.72476 .41012 Mdot
.47744 .75799 Mdot
.23842 .65701 Mdot
.71444 .66613 Mdot
.43492 .16722 Mdot
.67811 .75822 Mdot
.69097 .7422 Mdot
.68727 .44692 Mdot
.39817 .66099 Mdot
.40911 .76619 Mdot
.40154 .31851 Mdot
.50747 .48896 Mdot
.3628 .82713 Mdot
.31432 .51509 Mdot
.24906 .76799 Mdot
.61919 .61604 Mdot
.18724 .60135 Mdot
.38054 .35681 Mdot
.55518 .47829 Mdot
.49892 .42646 Mdot
.78723 .46778 Mdot
.61451 .6809 Mdot
.8063 .58564 Mdot
.29889 .74024 Mdot
.66974 .40465 Mdot
.70856 .76895 Mdot
.82705 .63235 Mdot
.32229 .6958 Mdot
.44043 .48588 Mdot
.7979 .65579 Mdot
.67656 .43672 Mdot
.22825 .48974 Mdot
.83071 .42758 Mdot
.74113 .37337 Mdot
.43847 .59047 Mdot
.33388 .33423 Mdot
.60167 .2207 Mdot
.53852 .16384 Mdot
.23601 .70442 Mdot
.69307 .29205 Mdot
.64882 .55828 Mdot
.52582 .44748 Mdot
.68387 .25509 Mdot
.48558 .58488 Mdot
.61094 .64726 Mdot
.51927 .63468 Mdot
.34001 .83468 Mdot
.5149 .20576 Mdot
.4514 .19711 Mdot
.5072 .62107 Mdot
.43473 .71929 Mdot
.56499 .6499 Mdot
.52783 .64366 Mdot
.74763 .38679 Mdot
.78033 .64636 Mdot
.52796 .63584 Mdot
.51422 .85502 Mdot
.34425 .57954 Mdot
.55987 .37877 Mdot
.40308 .77041 Mdot
.28864 .54133 Mdot
.62124 .63839 Mdot
.31562 .27941 Mdot
.79096 .38983 Mdot
.62623 .55965 Mdot
.79582 .4493 Mdot
.73562 .63227 Mdot
.40506 .69102 Mdot
.38059 .65073 Mdot
.75658 .36746 Mdot
.28098 .66501 Mdot
.47532 .77731 Mdot
.23259 .44598 Mdot
.66253 .43794 Mdot
.79265 .3794 Mdot
.64676 .40411 Mdot
.33273 .42534 Mdot
.49874 .56399 Mdot
.35552 .3957 Mdot
.19427 .41967 Mdot
.49512 .30944 Mdot
.45551 .63083 Mdot
.1921 .65375 Mdot
.4775 .70433 Mdot
.19597 .37774 Mdot
.22488 .53133 Mdot
.4283 .78322 Mdot
.57778 .28224 Mdot
.564 .30903 Mdot
.43527 .84923 Mdot
.62028 .52904 Mdot
.62686 .48929 Mdot
.52736 .76936 Mdot
.43787 .63687 Mdot
.5334 .23512 Mdot
.66407 .4156 Mdot
.53002 .59004 Mdot
.70733 .57026 Mdot
.39967 .60582 Mdot
.44473 .75508 Mdot
.52325 .56644 Mdot
.29187 .33141 Mdot
.43156 .18017 Mdot
.59707 .4098 Mdot
.26361 .76972 Mdot
.41397 .44048 Mdot
.32619 .67765 Mdot
.7251 .26458 Mdot
.24674 .72647 Mdot
.59105 .46985 Mdot
.83323 .62841 Mdot
.37497 .55459 Mdot
.73577 .3334 Mdot
.4589 .68312 Mdot
.68354 .74743 Mdot
.49864 .32702 Mdot
.36749 .3073 Mdot
.6158 .61499 Mdot
.20697 .49867 Mdot
.55478 .434 Mdot
.48011 .71781 Mdot
.72163 .34379 Mdot
.2734 .51467 Mdot
.62542 .67133 Mdot
.55028 .28865 Mdot
.32823 .70177 Mdot
.38213 .64326 Mdot
.42124 .72522 Mdot
.4644 .19719 Mdot
.69553 .74621 Mdot
.38829 .1645 Mdot
.48524 .64022 Mdot
.5184 .38066 Mdot
.61748 .76026 Mdot
.78162 .41855 Mdot
.52359 .74437 Mdot
.69896 .24263 Mdot
.30737 .35581 Mdot
.40769 .62809 Mdot
.32979 .31411 Mdot
.45601 .5208 Mdot
.54772 .51428 Mdot
.76055 .50977 Mdot
.32925 .7672 Mdot
.54344 .6732 Mdot
.19908 .5921 Mdot
.49895 .75723 Mdot
.44649 .20644 Mdot
.47991 .75309 Mdot
.57008 .40436 Mdot
.4008 .69661 Mdot
.665 .55101 Mdot
.449 .16522 Mdot
.70721 .24889 Mdot
.67801 .57296 Mdot
.5745 .2478 Mdot
.82265 .45456 Mdot
.45351 .499 Mdot
.53038 .39915 Mdot
.34997 .47826 Mdot
.28714 .49338 Mdot
.26366 .74933 Mdot
.76097 .39695 Mdot
.32433 .51922 Mdot
.50404 .18346 Mdot
.48868 .16994 Mdot
.31378 .21802 Mdot
.55867 .82839 Mdot
.43174 .66745 Mdot
.2479 .29731 Mdot
.51655 .65637 Mdot
.55971 .16365 Mdot
.7283 .40214 Mdot
.76017 .27977 Mdot
.31242 .69946 Mdot
.80535 .44832 Mdot
.22159 .63263 Mdot
.58785 .66173 Mdot
.80118 .55808 Mdot
.54705 .45203 Mdot
.72568 .49791 Mdot
.81063 .52283 Mdot
.63881 .83552 Mdot
.42345 .42618 Mdot
.75251 .61418 Mdot
.69183 .68654 Mdot
.78766 .37071 Mdot
.68455 .35331 Mdot
.4337 .46297 Mdot
.70186 .47966 Mdot
.20035 .45349 Mdot
.35904 .29303 Mdot
.52189 .32294 Mdot
.68617 .35529 Mdot
.24981 .39776 Mdot
.31543 .32307 Mdot
.68137 .75798 Mdot
.32474 .70458 Mdot
.54597 .58839 Mdot
.39483 .55368 Mdot
.44529 .74945 Mdot
.50698 .33306 Mdot
.57395 .47695 Mdot
.36267 .46321 Mdot
.58216 .3981 Mdot
.61336 .66825 Mdot
.18153 .42831 Mdot
.55423 .69659 Mdot
.74052 .67773 Mdot
.4706 .74406 Mdot
.70608 .65368 Mdot
.5318 .7521 Mdot
.17628 .4982 Mdot
.64291 .32972 Mdot
.38451 .26946 Mdot
.55179 .1968 Mdot
.38933 .22381 Mdot
.41444 .724 Mdot
.31826 .24013 Mdot
.6708 .58117 Mdot
.43191 .60088 Mdot
.6717 .69952 Mdot
.53247 .2579 Mdot
.31463 .49624 Mdot
.8041 .44724 Mdot
.61372 .4871 Mdot
.46291 .236 Mdot
.80972 .56616 Mdot
.28788 .52568 Mdot
.36118 .73977 Mdot
.53063 .17638 Mdot
.58808 .42755 Mdot
.7254 .71842 Mdot
.66633 .66842 Mdot
.62117 .34095 Mdot
.4203 .19678 Mdot
.39793 .17286 Mdot
.50976 .45181 Mdot
.36682 .34511 Mdot
.39375 .5338 Mdot
.65656 .78793 Mdot
.77212 .4118 Mdot
.39623 .39968 Mdot
.72496 .53894 Mdot
.45768 .71814 Mdot
.75445 .54271 Mdot
.54877 .56178 Mdot
.26476 .36499 Mdot
.45329 .62177 Mdot
.41166 .78918 Mdot
.48959 .29432 Mdot
.50718 .39802 Mdot
.35315 .42633 Mdot
.37434 .32838 Mdot
.47737 .83041 Mdot
.32198 .46508 Mdot
.70716 .2985 Mdot
.34744 .71413 Mdot
.68414 .73454 Mdot
.74866 .36157 Mdot
.72193 .41741 Mdot
.6082 .67726 Mdot
.39578 .68697 Mdot
.66771 .53196 Mdot
.35331 .52284 Mdot
.56854 .41433 Mdot
.48847 .69531 Mdot
.80953 .39283 Mdot
.36431 .66305 Mdot
.39385 .32304 Mdot
.62691 .51493 Mdot
.3281 .42678 Mdot
.70025 .59932 Mdot
.74809 .27339 Mdot
.58736 .66359 Mdot
.3155 .34654 Mdot
.59163 .54301 Mdot
.38279 .35278 Mdot
.22084 .54688 Mdot
.45305 .14674 Mdot
.21646 .62624 Mdot
.52012 .51378 Mdot
.19772 .61526 Mdot
.78166 .46831 Mdot
.83163 .44061 Mdot
.31161 .33854 Mdot
.49652 .40502 Mdot
.45879 .35297 Mdot
.56008 .77606 Mdot
.62273 .51995 Mdot
.51939 .30306 Mdot
.53635 .59797 Mdot
.70081 .54147 Mdot
.59547 .59426 Mdot
.39154 .40223 Mdot
.52149 .21587 Mdot
.54217 .1879 Mdot
.6702 .75292 Mdot
.6868 .61914 Mdot
.618 .34799 Mdot
.2655 .3761 Mdot
.79149 .30106 Mdot
.156 .59289 Mdot
.39173 .53307 Mdot
.69049 .58056 Mdot
.35359 .34539 Mdot
.64002 .44754 Mdot
.53558 .66069 Mdot
.53895 .74296 Mdot
.61841 .58666 Mdot
.51136 .30006 Mdot
.451 .23395 Mdot
.7815 .48551 Mdot
.30737 .39371 Mdot
.67584 .48621 Mdot
.17519 .43694 Mdot
.82222 .60139 Mdot
.77639 .41077 Mdot
.7465 .24629 Mdot
.66139 .66393 Mdot
.35371 .57387 Mdot
.24233 .58401 Mdot
.43417 .18291 Mdot
.37536 .29126 Mdot
.22411 .44426 Mdot
.71402 .43348 Mdot
.30692 .34961 Mdot
.49612 .62251 Mdot
.49817 .21928 Mdot
.74955 .54365 Mdot
.54284 .49576 Mdot
.56672 .31265 Mdot
.34242 .21675 Mdot
.36913 .75425 Mdot
.57499 .20122 Mdot
.19412 .471 Mdot
.57429 .84631 Mdot
.46258 .16071 Mdot
.43744 .27538 Mdot
.66725 .34106 Mdot
.24192 .60526 Mdot
.48219 .44429 Mdot
.47081 .59171 Mdot
.22786 .48533 Mdot
.36139 .61666 Mdot
.61114 .27114 Mdot
.18788 .55611 Mdot
.34364 .29711 Mdot
.29768 .55525 Mdot
.49572 .40819 Mdot
.37164 .7178 Mdot
.57077 .24959 Mdot
.49521 .60276 Mdot
.49227 .47193 Mdot
.40345 .28728 Mdot
.35208 .71124 Mdot
.63569 .75586 Mdot
.80639 .49103 Mdot
.54085 .86397 Mdot
.69792 .31673 Mdot
.17593 .51202 Mdot
.43197 .48356 Mdot
.34648 .17824 Mdot
.79637 .52424 Mdot
.72181 .38679 Mdot
.7898 .61974 Mdot
.57389 .36844 Mdot
.37123 .58677 Mdot
.35373 .52354 Mdot
.66983 .26611 Mdot
.40707 .73356 Mdot
.26889 .5462 Mdot
.20008 .50285 Mdot
.35206 .318 Mdot
.4099 .23884 Mdot
.40819 .31574 Mdot
.42826 .60097 Mdot
.4756 .70102 Mdot
.22122 .32859 Mdot
.51639 .48077 Mdot
.35286 .41693 Mdot
.44143 .42278 Mdot
.22322 .59491 Mdot
.85308 .57399 Mdot
.50091 .69077 Mdot
.40844 .2211 Mdot
.34011 .73679 Mdot
.47054 .53496 Mdot
.52012 .73376 Mdot
.74672 .21076 Mdot
.41173 .12644 Mdot
.48596 .70955 Mdot
.56176 .81194 Mdot
.3475 .74296 Mdot
.45733 .18897 Mdot
.60708 .32777 Mdot
.71669 .56055 Mdot
.43189 .40706 Mdot
.4862 .52636 Mdot
.34374 .43837 Mdot
.79372 .59603 Mdot
.46613 .14907 Mdot
.19441 .52139 Mdot
.5069 .18356 Mdot
.43628 .57328 Mdot
.33187 .45383 Mdot
.81418 .31093 Mdot
.67333 .24673 Mdot
.44812 .48434 Mdot
.2377 .66798 Mdot
.30843 .50356 Mdot
.40999 .4784 Mdot
.61319 .24363 Mdot
.70968 .76678 Mdot
.3454 .2923 Mdot
.46109 .1837 Mdot
.46148 .62646 Mdot
.56294 .42474 Mdot
.61815 .61476 Mdot
.50358 .44148 Mdot
.43736 .54997 Mdot
.62355 .59303 Mdot
.2737 .44772 Mdot
.80674 .43407 Mdot
.56509 .59833 Mdot
.71428 .74685 Mdot
.67616 .20996 Mdot
.37052 .6828 Mdot
.55831 .77137 Mdot
.42879 .43709 Mdot
.2978 .55241 Mdot
.26594 .40155 Mdot
.29385 .50626 Mdot
.81961 .48896 Mdot
.14896 .34789 Mdot
.71006 .5028 Mdot
.2902 .3152 Mdot
.42495 .71102 Mdot
.54704 .60611 Mdot
.39 .74019 Mdot
.63611 .35111 Mdot
.60304 .39628 Mdot
.4427 .56362 Mdot
.47093 .62434 Mdot
.60841 .59773 Mdot
.22032 .72938 Mdot
.43842 .49598 Mdot
.53398 .69169 Mdot
.56311 .1661 Mdot
.23224 .44589 Mdot
.30107 .6591 Mdot
.34409 .5201 Mdot
.59796 .73831 Mdot
.49753 .40269 Mdot
.76164 .34425 Mdot
.29664 .29067 Mdot
.51666 .19332 Mdot
.36433 .6585 Mdot
.35612 .7395 Mdot
.40538 .55006 Mdot
.45263 .29607 Mdot
.58683 .62003 Mdot
.6448 .25967 Mdot
.38558 .57431 Mdot
.52108 .15603 Mdot
.54834 .38987 Mdot
.57915 .47532 Mdot
.49138 .64299 Mdot
.29915 .23245 Mdot
.20569 .56581 Mdot
.40953 .75589 Mdot
.17567 .48436 Mdot
.53853 .28384 Mdot
.30842 .38597 Mdot
.59705 .44329 Mdot
.40108 .57986 Mdot
.48346 .65048 Mdot
.1594 .46375 Mdot
.59813 .23167 Mdot
.7193 .48506 Mdot
.73976 .5189 Mdot
.60873 .7966 Mdot
.64454 .67382 Mdot
.71887 .22388 Mdot
.54911 .30118 Mdot
.16549 .4568 Mdot
.70267 .73757 Mdot
.49735 .67995 Mdot
.79625 .46973 Mdot
.3244 .53022 Mdot
.60529 .4266 Mdot
.50217 .19009 Mdot
.31523 .44632 Mdot
.23607 .37734 Mdot
.33281 .49617 Mdot
.21082 .40132 Mdot
.47588 .26133 Mdot
.56269 .23814 Mdot
.76666 .44379 Mdot
.21726 .58725 Mdot
.79645 .3511 Mdot
.56252 .77737 Mdot
.78405 .31047 Mdot
.80063 .36707 Mdot
.54032 .17193 Mdot
.21808 .4256 Mdot
.27087 .73958 Mdot
.73597 .39797 Mdot
.76005 .37504 Mdot
.77147 .5069 Mdot
.23369 .61361 Mdot
.55954 .35058 Mdot
.50192 .67785 Mdot
.57258 .6655 Mdot
.6659 .55754 Mdot
.08838 .55338 Mdot
.42618 .24384 Mdot
.49446 .66486 Mdot
.5519 .33096 Mdot
.50482 .16859 Mdot
.23098 .59422 Mdot
.81077 .53715 Mdot
.54937 .55131 Mdot
.34935 .44133 Mdot
.37297 .64203 Mdot
.6444 .77781 Mdot
.54682 .35682 Mdot
.45828 .86748 Mdot
.80973 .61675 Mdot
.71548 .52454 Mdot
.54237 .52461 Mdot
.48585 .67004 Mdot
.49353 .77334 Mdot
.5716 .3002 Mdot
.82238 .5056 Mdot
.80621 .4431 Mdot
.68174 .25301 Mdot
.43553 .84797 Mdot
.68707 .73714 Mdot
.43213 .18172 Mdot
.77613 .43583 Mdot
.47191 .72673 Mdot
.43073 .30071 Mdot
.67365 .42841 Mdot
.73356 .47848 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
08;ooooo0_l00035ooooo`007?ooool00ol0003oooooooooo`22ooooo`;o0000aOooool001cooooo
00?o0000ooooooooool0R_ooool2o`000;gooooo000Looooo`03o`000?oooooooooo07;ooooo0_l0
000Cooooo`;o000000?oooooo`000?l000001Oooool2o`000;Kooooo000Looooo`03o`000?oooooo
oooo07;ooooo0_l0000Cooooo`;o00002?ooool6o`000;;ooooo000Looooo`03o`000?oooooooooo
09;ooooo2Ol0002^ooooo`007?ooool00ol0003oooooooooo`1nooooo`;o00003oooool2o`000003
ooooool0003o000000?ooooo1?l00009ooooo`;o0000Xoooool001cooooo00?o0000ooooooooool0
O_ooool2o`0000oooooo0_l00003ooooo`;o00003_ooool2o`0000?ooooo0_l0002Nooooo`007?oo
ool2o`0009Gooooo0_l0000Cooooo`;o0000W_ooool001cooooo00?o0000ooooooooool0X?ooool2
o`0000?ooooo0_l0002Rooooo`007?ooool00ol0003oooooooooo`2Booooo`;o00003?ooool2o`00
00?ooooo0_l0002Rooooo`007?ooool00ol0003oooooooooo`2<ooooo`;o00001?ooool3o`0001ko
oooo0_l0002Dooooo`007?ooool00ol0003oooooooooo`1jooooo`;o00004?ooool4o`0000?ooooo
1?l0000Dooooo`;o00001Oooool3o`0009Cooooo000Looooo`03o`000?oooooooooo07[ooooo1?l0
0003ooooo`;o00001_ooool3o`0000;ooooo0_l00004ooooo`?o000000?oooooo`000?l000001_oo
ool2o`0000Wooooo0_l00005ooooo`?o0000U?ooool001cooooo00?o0000ooooooooool0O?ooool2
o`0000?ooooo0_l00002ooooo`;o00000_ooool3o`0000Gooooo0_l000000ooooooo0000o`000004
o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000003o`0000?ooooo0ol00009
ooooo`;o00001?ooool2o`0008[ooooo000Looooo`03o`000?oooooooooo07kooooo0_l00005oooo
o`;o00001oooool2o`000003ooooool0003o000000?ooooo0_l00003ooooo`;o00001_ooool5o`00
00?ooooo1Ol00003ooooo`;o00000_ooool2o`0000Cooooo0_l0002:ooooo`007?ooool00ol0003o
ooooooooo`1]ooooo`;o00003oooool2o`000003ooooool0003o000000_ooooo0_l00004ooooo`;o
00002_ooool2o`0000Oooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l00005ooooo`;o
0000SOooool001cooooo00?o0000ooooooooool0KOooool2o`0000Oooooo0_l00009ooooo`;o0000
1Oooool2o`0000[ooooo0_l0000:ooooo`;o00001oooool2o`000003ooooool0003o000000Wooooo
0_l000000ooooooo0000o`00002=ooooo`007?ooool00ol0003oooooooooo`1fooooo`;o000000?o
ooooo`000?l000001Oooool2o`0000Kooooo0ol00007ooooo`;o00003?ooool3o`0001Cooooo0_l0
002@ooooo`007?ooool00ol0003oooooooooo`1booooo`;o00001Oooool2o`0000Gooooo0_l00007
ooooo`?o00001_ooool2o`0000cooooo1?l0000Eooooo`;o0000S_ooool001cooooo00?o0000oooo
ooooool0L_ooool2o`0001Kooooo0_l00005ooooo`?o00002oooool5o`0000Gooooo0_l000000ooo
oooo0000o`00000;ooooo`?o0000SOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2
ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo06oooooo0_l0000Pooooo`?o00002oooool2
o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000003?ooool2o`0008gooooo00001_oo
ooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1_ooool00ol0003oooooooooo`1]ooooo`Co00001_ooool2o`0000?ooooo0_l00005ooooo`Ko0000
00?oooooo`000?l000000_ooool2o`0001Cooooo0_l00009ooooo`;o00004_ooool2o`0008Cooooo
00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00ol0003oooooooooo`1]ooooo`;o00001Oooool2o`000003ooooool0003o000000?ooooo0_l0
0005ooooo`Ko000000?oooooo`000?l000000_ooool3o`0000;ooooo0_l0000>ooooo`;o00002_oo
ool2o`0000Gooooo0_l00008ooooo`;o000000?oooooo`000?l000002_ooool2o`0007Sooooo0000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3
o`00073ooooo0_l00002ooooo`;o00005?ooool4o`000003ooooool0003o000000;ooooo0_l0000>
ooooo`;o00000oooool2o`0000?ooooo0_l00007ooooo`?o00001_ooool4o`0000cooooo0_l0001h
ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo
00Gooooo00?o0000ooooooooool0L?ooool2o`0000;ooooo0_l0000Fooooo`;o00000_ooool2o`00
0003ooooool0003o000000Gooooo0_l00007ooooo`;o00000oooool2o`0000?ooooo0_l00008oooo
o`;o00001_ooool4o`0000;ooooo1?l00020ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413o
ooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0J_ooool2o`0000Oo
oooo0_l00006ooooo`;o00004?ooool2o`000004ooooool0003o0000ooooo`;o00001Oooool2o`00
00;ooooo0_l000000ooooooo0000o`000002o`0000_ooooo0_l0000=ooooo`[o0000P?ooool00006
oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o
0000ooooooooool0J_ooool2o`0000Oooooo0_l00006ooooo`;o00002Oooool2o`0000Gooooo0_l0
0006ooooo`;o00001oooool2o`000003ooooool0003o000000gooooo0_l0000=ooooo`;o00000_oo
ool3o`000003ooooool0003o000000Gooooo0ol00007ooooo`;o00005Oooool2o`0005Sooooo0000
1_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03
o`000?oooooooooo06kooooo0_l000000ooooooo0000o`000002o`00017ooooo0ol00004ooooo`;o
00001_ooool2o`000003ooooool0003o000000[ooooo0_l0000Mooooo`?o00001oooool6o`0000Go
oooo0_l0000Eooooo`;o0000F?ooool001cooooo00?o0000ooooooooool0H_ooool2o`0000Sooooo
1?l000000ooooooo0000o`000004o`0000Gooooo0_l00009ooooo`;o00000_ooool4o`0000Wooooo
0_l000000ooooooo0000o`000007ooooo`Co00001oooool4o`0000Gooooo0_l00009ooooo`Co0000
1_ooool2o`000004ooooool0003o0000o`0007Kooooo000Looooo`03o`000?oooooooooo04_ooooo
0_l0000Eooooo`;o00002?ooool4o`0000?ooooo1?l00005ooooo`;o000000?oooooo`000?l00000
0_l00008ooooo`;o00003_ooool2o`000004ooooool0003o0000o`0000Gooooo0_l00002ooooo`;o
00000oooool4o`0000Gooooo0_l00005ooooo`?o00000oooool2o`0000Kooooo0_l000001?oooooo
0000o`000?l0000?ooooo`;o0000IOooool001cooooo00?o0000ooooooooool0Boooool2o`00027o
oooo0_l00002ooooo`?o00001?ooool4o`0000;ooooo1?l0000;ooooo`;o00003_ooool3o`0000;o
oooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool2o`0000Cooooo0_l00008ooooo`?o
00002oooool2o`0000;ooooo0_l000000ooooooo0000o`00000<ooooo`;o00000_ooool2o`00067o
oooo000Looooo`03o`000?oooooooooo07;ooooo0_l00005ooooo`Co00004?ooool3o`0001?ooooo
0_l0000@ooooo`;o00007Oooool2o`00013ooooo0_l0001Qooooo`007?ooool00ol0003ooooooooo
o`1dooooo`;o00001?ooool2o`000003ooooool0003o000000?ooooo0_l00009ooooo`?o00000ooo
ool3o`0000gooooo0_l0000=ooooo`Go00008Oooool2o`0006oooooo000Looooo`03o`000?oooooo
oooo05gooooo0_l000000ooooooo0000o`00000Booooo`Co00001Oooool3o`0000;ooooo0_l00009
ooooo`;o00001?ooool3o`0000Kooooo0ol000000ooooooo0000o`000007ooooo`;o00001oooool7
o`0000Kooooo0_l00007ooooo`;o00003_ooool2o`0006oooooo000Looooo`03o`000?oooooooooo
05gooooo0_l000000ooooooo0000o`000005ooooo`;o00003Oooool2o`0000;ooooo1_l000001?oo
oooo0000o`000?l00003ooooo`;o00001?ooool4o`0000;ooooo0_l00002ooooo`;o00000oooool3
o`000003ooooool0003o000000Oooooo0ol00007ooooo`;o00000_ooool2o`0000?ooooo0_l00000
0ooooooo0000o`000007ooooo`;o00003?ooool2o`000003ooooool0003o000006kooooo000Loooo
o`03o`000?oooooooooo06Oooooo0_l00004ooooo`Co00000oooool3o`000003ooooool0003o0000
00Co00000oooool3o`0000?ooooo0_l00006ooooo`;o000000Coooooo`000?l0003o00000_ooool2
o`0000oooooo1_l00005ooooo`;o00001oooool2o`000003ooooool0003o000000kooooo0_l00005
ooooo`;o000000?oooooo`000?l00000K_ooool001cooooo00?o0000ooooooooool0F_ooool2o`00
00Sooooo0_l00007ooooo`Go00000_ooool3o`000003ooooool0003o000000Cooooo0_l000000ooo
oooo0000o`00000?ooooo`?o00004oooool2o`0000;ooooo0_l00005ooooo`;o00002_ooool2o`00
0003ooooool0003o000000_ooooo0_l00009ooooo`;o000000?oooooo`000?l000000_l0001Xoooo
o`007?ooool00ol0003oooooooooo`1Jooooo`;o00002?ooool2o`0000Kooooo0_l00002ooooo`;o
00000_ooool5o`000005ooooool0003o0000o`000?ooool00_l00007ooooo`;o00002_ooool2o`00
00Kooooo0_l0000=ooooo`;o00001oooool2o`0000gooooo0ol0000Dooooo`?o000000?oooooo`00
0?l000000_l0001Xooooo`007?ooool00ol0003oooooooooo`1Fooooo`;o00005?ooool2o`0000;o
oooo0_l00004ooooo`?o000000Coooooo`000?l0003o00002_ooool2o`0000Oooooo1?l000000ooo
oooo0000o`000004ooooo`;o000000?oooooo`000?l000002_ooool2o`0000_ooooo0_l0000:oooo
o`;o00004_ooool4o`0000Oooooo0_l0000;ooooo`;o0000F?ooool001cooooo0_l0001Gooooo`;o
00004Oooool2o`0002Gooooo1ol00007ooooo`;o00004oooool2o`000004ooooool0003o0000o`00
00Kooooo0_l0000Fooooo`;o00002Oooool3o`0000[ooooo0_l0001Hooooo`007?ooool00ol0003o
ooooooooo`1Yooooo`;o00004?ooool2o`0000Kooooo0_l00005ooooo`;o00001oooool2o`0000Oo
oooo1?l00002ooooo`;o00003oooool2o`000003ooooool0003o000000;ooooo0_l00003ooooo`;o
00001?ooool2o`0000Kooooo0_l00005ooooo`;o00001?ooool2o`0000Oooooo0_l0001Tooooo`00
7?ooool00ol0003oooooooooo`1@ooooo`;o0000:Oooool2o`0000Kooooo0_l00005ooooo`;o0000
1oooool2o`000003ooooool0003o000000Cooooo1?l00002ooooo`;o00001Oooool2o`0000oooooo
0_l00007ooooo`Co00001_ooool2o`0000Gooooo0_l00004ooooo`;o00001?ooool2o`0006Oooooo
000Looooo`03o`000?oooooooooo053ooooo0_l00007ooooo`;o00003Oooool3o`0000_ooooo0_l0
0006ooooo`Co000000?oooooo`000?l000002?ooool2o`0000Cooooo0_l000001?oooooo0000o`00
0?l0000@ooooo`;o00001_ooool2o`00013ooooo0_l00006ooooo`;o000000?oooooo`000?l00000
4?ooool3o`0006Kooooo000Looooo`03o`000?oooooooooo05?ooooo0_l00004ooooo`;o00000ooo
ool2o`0000Sooooo0ol0000;ooooo`;o00001Oooool5o`000003ooooool0003o000000Gooooo0_l0
00000ooooooo0000o`000004ooooo`Ko00005?ooool2o`0000;ooooo1?l00005ooooo`;o00003ooo
ool2o`000003ooooool0003o0000013ooooo0ol000000ooooooo0000o`000002ooooo`;o0000Gooo
ool001cooooo00?o0000ooooooooool0Doooool2o`0000Wooooo0_l0000;ooooo`;o00001?ooool2
o`0000;ooooo0ol00005ooooo`?o00001oooool2o`000004ooooool0003o0000o`0000Cooooo0_l0
00001?oooooo0000o`000?l0000:ooooo`;o00002_ooool2o`0000Cooooo0_l00005ooooo`;o0000
1Oooool2o`0000Sooooo0_l000000ooooooo0000o`000006ooooo`Co00002_ooool2o`000004oooo
ool0003o0000o`0005oooooo000Looooo`03o`000?oooooooooo06;ooooo0_l00007ooooo`;o0000
1?ooool2o`0000;ooooo0ol000000ooooooo0000o`00000<ooooo`;o00000_ooool2o`000004oooo
ool0003o0000ooooo`Go00002oooool3o`0000Sooooo0_l00004ooooo`?o00003?ooool4o`0000Ko
oooo0_l00009ooooo`Co00003Oooool5o`0005gooooo000Looooo`03o`000?oooooooooo06;ooooo
1Ol0000=ooooo`Co000000Coooooo`000?l0003ooooo0_l00008ooooo`;o00000oooool2o`000003
ooooool0003o000000Go00001Oooool2o`0000Kooooo0_l00008ooooo`;o000000?oooooo`000?l0
00000ol0000>ooooo`?o00002oooool2o`0000;ooooo0_l0000Booooo`Co00000oooool2o`0005So
oooo000Looooo`03o`000?oooooooooo04gooooo0_l0000Cooooo`Oo00002oooool2o`000003oooo
ool0003o000000?ooooo0_l00004ooooo`[o00000oooool7o`000004ooooool0003o0000ooooo`;o
00002oooool2o`0000Cooooo1_l00005ooooo`;o00000_ooool2o`0000Gooooo0_l0000;ooooo`;o
00000_ooool2o`0001Sooooo0ol0001Hooooo`007?ooool00ol0003oooooooooo`1=ooooo`Co0000
4Oooool3o`0000;ooooo0_l00004ooooo`?o00001oooool2o`0000Wooooo1?l00002ooooo`Co0000
0oooool2o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`;o00002Oooool2o`0000Cooooo
1?l00007ooooo`;o00000_ooool3o`000003ooooool0003o000000kooooo0_l0000Looooo`;o0000
0oooool2o`0005Cooooo000Looooo`03o`000?oooooooooo04oooooo0_l00006ooooo`;o00002Ooo
ool3o`0000Sooooo0ol0000?ooooo`;o00000_ooool2o`0000_ooooo0_l0000:ooooo`;o00001_oo
ool4o`0000Kooooo0_l00008ooooo`;o00000oooool2o`000003ooooool0003o000001;ooooo0_l0
0002ooooo`Co00003?ooool3o`0000Gooooo0_l000000ooooooo0000o`00001Dooooo`007?ooool0
0ol0003oooooooooo`1Gooooo`;o00009_ooool2o`0000;ooooo0_l0000;ooooo`;o00000_ooool4
o`0000cooooo1?l000000ooooooo0000o`000002o`000003ooooool0003o000000Sooooo0_l0000G
ooooo`;o000000?oooooo`000?l000000_ooool4o`0000cooooo1?l00004ooooo`;o0000Eoooool0
01cooooo00?o0000ooooooooool0G?ooool2o`0000Oooooo0_l00005ooooo`Co00000oooool2o`00
00Cooooo0_l00003ooooo`?o00001_ooool2o`0000Sooooo1ol00003ooooo`;o00002oooool5o`00
0004ooooool0003o0000o`0001_ooooo0_l000000ooooooo0000o`000002o`0000[ooooo0_l0000;
ooooo`;o000000?oooooo`000?l00000F_ooool001cooooo00?o0000ooooooooool0G?ooool3o`00
00Kooooo0_l00005ooooo`Ko000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000003
ooooo`?o00001_ooool2o`0000Gooooo0_l000000ooooooo0000o`000005o`000003ooooool0003o
000000Co00001?ooool2o`0000?ooooo0ol00004ooooo`;o00006oooool2o`000003ooooool0003o
000000Cooooo0_l00006ooooo`;o00002_ooool2o`0000;ooooo0_l00003ooooo`;o0000EOooool0
01cooooo00?o0000ooooooooool0FOooool6o`0000gooooo0_l00002ooooo`?o00000oooool2o`00
00Kooooo0_l0000>ooooo`;o000000?oooooo`000?l000003?l000001?oooooo0000o`000?ooool2
o`0000;ooooo1?l0000Kooooo`;o00002?ooool2o`0000;ooooo0ol00002ooooo`;o00000_ooool2
o`0000[ooooo0_l00007ooooo`;o0000EOooool001cooooo00?o0000ooooooooool0COooool2o`00
00Wooooo1Ol0000?ooooo`Co000000?oooooo`000?l000002oooool2o`0000;ooooo0_l00004oooo
o`;o00000oooool@o`0000?ooooo0_l00005ooooo`;o00001?ooool2o`00017ooooo0_l00004oooo
o`;o00002?ooool2o`0000;ooooo1ol00007ooooo`;o00003oooool4o`0005;ooooo000Looooo`;o
0000BOooool2o`0000?ooooo0_l00009ooooo`Go00003oooool4o`0000?ooooo0_l00002ooooo`;o
00002Oooool2o`0000Cooooo0_l00003oooooa7o00001?ooool2o`0000?ooooo0_l00004ooooo`Co
00001Oooool2o`0000Sooooo0_l0000;ooooo`;o00001oooool4o`0000?ooooo0_l00003ooooo`;o
00003oooool4o`0000Kooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o0000
0_ooool2o`0000Oooooo0_l0000Pooooo`;o00000_ooool2o`0000_ooooo0ol000000ooooooo0000
o`000004oooooa7o00000oooool2o`000003ooooool0003o000000?o00001Oooool2o`0000Gooooo
0_l0000Eooooo`;o00001oooool2o`0000Gooooo0_l00005ooooo`;o00003?ooool2o`0000;ooooo
0ol00004ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0A?ooool2o`0000_ooooo0_l0
000:ooooo`;o00001oooool2o`0000Gooooo0_l00003ooooo`Co000000?oooooo`000?l000002ooo
ool3o`0000Oooooo2Ol000000ooooooo0000o`000006o`0000Cooooo0ol000000ooooooo0000o`00
000Dooooo`;o00006_ooool2o`0000Gooooo0_l000000ooooooo0000o`00000<ooooo`;o00000_oo
ool3o`00053ooooo000Looooo`03o`000?oooooooooo05gooooo0_l00007ooooo`;o00001Oooool2
o`0000?ooooo1?l000000ooooooo0000o`00000;ooooo`;o00002_oooolFo`0000gooooo0_l00009
ooooo`;o00006Oooool3o`0000?ooooo1?l00002ooooo`;o00002oooool4o`0000Gooooo0_l00008
ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0FOooool2o`0000_ooooo1?l0000Joooo
o`;o00002_oooolDo`0000oooooo0ol00004ooooo`;o00005oooool2o`0000Cooooo1?l00002oooo
o`?o00000oooool2o`0000Oooooo0_l00004ooooo`;o00001Oooool2o`0000Sooooo0_l00012oooo
o`007?ooool00ol0003oooooooooo`1Iooooo`Co00000oooool3o`0000?ooooo1?l00009ooooo`;o
00003?ooool2o`000004ooooool0003o0000o`0000Gooooo0_l000000ooooooo0000o`00000Co`00
00_ooooo0_l00002ooooo`?o00001?ooool2o`0001Oooooo0_l00006ooooo`;o00000_ooool3o`00
00;ooooo0_l00007ooooo`Go000000?oooooo`000?l000000_ooool2o`00053ooooo000Looooo`03
o`000?oooooooooo03gooooo0_l0000Eooooo`Co00000_ooool3o`0000?ooooo0ol00003ooooo`?o
00001_ooool2o`0000;ooooo0_l00008ooooo`Ko000000Coooooo`000?l0003o00001Oooool9o`00
0003ooooool0003o000000co00002_ooool3o`0000;ooooo0_l0000Mooooo`;o00002Oooool4o`00
00?ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000003o`00
00;ooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00004Oooool8o`0000;o
oooo0_l00004ooooo`;o000000?oooooo`000?l000002_ooool2o`0000?ooooo0_l00006ooooo`Go
00002ooooolFo`0000?ooooo0ol00006ooooo`;o00008_ooool2o`0000Wooooo0_l00009ooooo`;o
000000?oooooo`000?l000001Oooool2o`0005Gooooo000Looooo`03o`000?oooooooooo053ooooo
1Ol00009ooooo`Co000000?oooooo`000?l000000oooool4o`0000?ooooo0_l00003ooooo`;o0000
1_ooool2o`0000_ooooo0_l000000ooooooo0000o`00000Do`0000?ooooo1Ol0000Gooooo`;o0000
Q_ooool001cooooo00?o0000ooooooooool0A?ooool2o`0000Sooooo0_l000000ooooooo0000o`00
0007ooooo`;o00000_ooool2o`0000Cooooo0_l00002ooooo`Co00000oooool2o`0000Gooooo0_l0
00000ooooooo0000o`00000>ooooo`;o00000_oooolDo`0000Oooooo0_l0000Eooooo`Co00004?oo
ool2o`0001Sooooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00001_ooool4
o`0000[ooooo1Ol00005ooooo`;o00001?ooool2o`0000[ooooo0_l000001?oooooo0000o`000?oo
ool2o`0000oooooo5?l0000?ooooo`;o000000?oooooo`000?l000002_ooool4o`0000[ooooo0_l0
0004ooooo`;o00006?ooool2o`0005[ooooo000Looooo`03o`000?oooooooooo04cooooo0_l0000=
ooooo`Oo00001oooool3o`0000Sooooo0_l00006ooooo`;o00004_ooool8o`000003ooooool0003o
000000So00001_ooool3o`0000Cooooo1Ol0000Dooooo`;o00000_ooool2o`00013ooooo0_l0000:
ooooo`;o00003Oooool2o`0001Oooooo0_l0000dooooo`007?ooool00ol0003oooooooooo`0ooooo
o`;o000000?oooooo`000?l000002?ooool2o`00013ooooo1Ol00003ooooo`Ko00002?ooool2o`00
00Kooooo0_l000001?oooooo0000o`000?l00006ooooo`;o00001_oooolCo`0000?ooooo0_l00000
1?oooooo0000o`000?l00005ooooo`;o00001_ooool2o`0000kooooo0_l0000Dooooo`;o00002_oo
ool2o`0000gooooo0_l0000Gooooo`;o0000=?ooool001cooooo00?o0000ooooooooool0?oooool2
o`000003ooooool0003o000000?ooooo1?l00005ooooo`;o00003oooool2o`0000?ooooo0ol00000
0ooooooo0000o`00000@ooooo`;o000000Coooooo`000?l0003o00001_ooool2o`0000Sooooo1Ol0
00000ooooooo0000o`00000:o`0000;ooooo0_l00009ooooo`;o00001_ooool2o`0000_ooooo0_l0
000=ooooo`;o0000L_ooool001cooooo00?o0000ooooooooool0Aoooool4o`0000Gooooo1?l00000
0ooooooo0000o`000009ooooo`;o00001?ooool2o`0000;ooooo0_l0000<ooooo`;o00000oooool2
o`000004ooooool0003o0000o`0000kooooo4ol00003ooooo`;o00000_ooool2o`0000Cooooo0_l0
000Cooooo`;o00002Oooool2o`0000;ooooo0_l00003ooooo`;o00002oooool2o`0000_ooooo0_l0
001Cooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o00006?ooool2o`0000Wooooo0_l00000
0ooooooo0000o`000002ooooo`;o00001Oooool2o`000004ooooool0003o0000o`0000Wooooo0_l0
0002ooooo`;o00000oooool3o`0000;ooooo0_l00002ooooo`?o00003OoooolDo`0000;ooooo0_l0
00001?oooooo0000o`000?l00008ooooo`Go00002oooool2o`0000Cooooo0_l00004ooooo`;o0000
1oooool2o`0000Sooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00001_ooool2o`0005?o
oooo000Looooo`;o0000;_ooool2o`0001Sooooo1?l00002ooooo`;o00001?ooool2o`0000Cooooo
0ol00004ooooo`Ko00002Oooool2o`0000;ooooo0_l00004ooooo`;o00001_ooool5o`0000Cooooo
0_l00005oooooaCo00001Oooool3o`0000Gooooo0_l000000ooooooo0000o`000003o`0000_ooooo
0_l00004ooooo`;o00005oooool2o`0000;ooooo0_l00002ooooo`;o0000Foooool001cooooo00?o
0000ooooooooool0BOooool2o`0000;ooooo0_l00004ooooo`;o00001Oooool2o`0000Cooooo1_l0
000@ooooo`;o000000?oooooo`000?l000001oooool4o`0000Cooooo0ol00004ooooo`co000000?o
ooooo`000?l000000ol00008ooooo`;o00001?ooool5o`0000;ooooo0_l0000;ooooo`;o000000Co
ooooo`000?l0003ooooo0_l0000:ooooo`So00000oooool4o`0001Wooooo0_l000000ooooooo0000
o`000015ooooo`007?ooool00ol0003oooooooooo`17ooooo`;o000000?oooooo`000?l000003_oo
ool2o`0000Cooooo1?l000000ooooooo0000o`000002ooooo`;o00002oooool5o`0000Cooooo0_l0
00000ooooooo0000o`000003ooooo`;o00000_ooool2o`0000Cooooo4_l00005ooooo`?o00000ooo
ool2o`000003ooooool0003o000000?o00000_ooool2o`0000[ooooo0_l00002ooooo`;o000000?o
ooooo`000?l000002_ooool8o`0000?ooooo1?l0000;ooooo`;o00003?ooool2o`000003ooooool0
003o000004Gooooo000Looooo`03o`000?oooooooooo04Oooooo0_l000000ooooooo0000o`000008
ooooo`;o00000oooool3o`0000Cooooo0_l00003ooooo`;o00000_ooool2o`0000gooooo0_l00003
ooooo`Co000000?oooooo`000?l000000oooool2o`0000Cooooo0_l00004oooooa3o00001Oooool3
o`0000?ooooo0_l000000ooooooo0000o`000002o`0000oooooo0_l0000>ooooo`;o00001Oooool2
o`0000Kooooo0_l0000;ooooo`?o0000E_ooool001cooooo00?o0000ooooooooool0E?ooool2o`00
00?ooooo0_l0000:ooooo`;o00001?ooool2o`0000?ooooo1?l00009ooooo`;o00002_ooool2o`00
00;ooooo0_l00006ooooo`;o000000?oooooo`000?l000002?l0000?ooooo`Co00001oooool2o`00
01Kooooo0_l0000=ooooo`;o00002_ooool3o`0005Oooooo000Looooo`03o`000?oooooooooo04go
oooo0ol00002ooooo`;o00005oooool2o`0000?ooooo1Ol0000Dooooo`;o00001_ooool6o`000003
ooooool0003o000000Go00004?ooool2o`0000_ooooo0_l0000Kooooo`;o00005?ooool2o`0005So
oooo000Looooo`03o`000?oooooooooo04gooooo0ol00002ooooo`;o00002?ooool4o`0000;ooooo
0ol0000:ooooo`;o00000_ooool2o`0001_ooooo1_l00004ooooo`;o000000?oooooo`000?l00000
0_ooool2o`0000Cooooo0_l00006ooooo`;o00001_ooool2o`0001;ooooo0ol00002ooooo`;o0000
1_ooool3o`000003ooooool0003o000001Cooooo1?l0000:ooooo`;o00000oooool2o`0004;ooooo
000Looooo`03o`000?oooooooooo04gooooo0_l00005ooooo`;o00001_ooool4o`0000;ooooo0ol0
0004ooooo`;o00000oooool3o`0001oooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo
0_l00002ooooo`;o000000?oooooo`000?l000001?ooool2o`0000kooooo1_l00009ooooo`?o0000
0_ooool3o`0000;ooooo0_l00006ooooo`;o00000_ooool2o`0000Oooooo0_l0000;ooooo`Co0000
1_ooool2o`0000;ooooo1ol00012ooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o00000ooo
ool2o`0000?ooooo0_l00002ooooo`;o00001Oooool2o`0000?ooooo0_l0000Wooooo`Go00000_oo
ool2o`0001Sooooo1Ol00009ooooo`?o00000_ooool2o`00013ooooo0_l000000ooooooo0000o`00
0003ooooo`;o00001_ooool2o`0000Cooooo0_l00007ooooo`;o00000_ooool6o`0004?ooooo000L
ooooo`03o`000?oooooooooo03cooooo0_l0000:ooooo`?o00002?ooool3o`0000?ooooo0ol00003
ooooo`;o00002_ooool2o`0002cooooo0ol0000;ooooo`;o00003oooool2o`0000;ooooo0_l00000
0ooooooo0000o`000003o`000003ooooool0003o000000;o00003oooool2o`0000;ooooo0ol00000
0ooooooo0000o`00000;ooooo`;o00001?ooool2o`0000_ooooo0_l00017ooooo`007?ooool00ol0
003oooooooooo`0booooo`;o00002?ooool2o`000003ooooool0003o000000Oooooo0ol00008oooo
o`?o00000_ooool4o`0000?ooooo0_l0000:ooooo`;o000000?oooooo`000?l000007oooool2o`00
00kooooo0_l00002ooooo`Ko00001_ooool2o`000003ooooool0003o000000Sooooo0_l000000ooo
oooo0000o`00000:o`0000gooooo0_l00002ooooo`;o00001_ooool2o`0000[ooooo0_l00006oooo
o`;o00001?ooool2o`0000Wooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0booooo`;o
00002oooool2o`0000Sooooo0_l00008ooooo`;o00000oooool2o`0001Cooooo0_l0000Oooooo`Co
00003?ooool2o`0000;ooooo1?l00007ooooo`?o000000?oooooo`000?l000000_l00007ooooo`?o
00000oooool;o`0000gooooo0_l000000ooooooo0000o`000004ooooo`;o00002_ooool4o`0000Co
oooo0_l00004ooooo`;o00002Oooool2o`0003kooooo000Looooo`03o`000?oooooooooo03Wooooo
0_l00009ooooo`;o00000oooool4o`0000Gooooo0_l0000<ooooo`;o00000_ooool2o`0002_ooooo
0_l00006ooooo`;o00003Oooool2o`0000?ooooo0ol00004ooooo`;o00001OoooolCo`0000Wooooo
0_l00002ooooo`;o000000?oooooo`000?l000001oooool2o`0000Kooooo0_l000000ooooooo0000
o`00000Aooooo`?o0000@Oooool001cooooo00?o0000ooooooooool0>Oooool2o`0000Oooooo1?l0
0002ooooo`;o000000?oooooo`000?l000001Oooool2o`0000[ooooo1?l00002ooooo`;o00008ooo
ool2o`0000Kooooo0_l00006ooooo`;o00003Oooool2o`0000?ooooo0ol00008ooooo`;o000000?o
ooooo`000?l000005ol00003ooooo`;o00002Oooool2o`0000?ooooo0_l00002ooooo`;o00000_oo
ool2o`0000Kooooo0_l00004ooooo`;o00001Oooool4o`00047ooooo00001_ooooook^k^oc8b<_l0
003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003ooooo
ooooo`12ooooo`;o00001?ooool3o`00017ooooo1_l0000Aooooo`;o00000_ooool2o`00013ooooo
0_l00007ooooo`;o00004?ooool2o`0000Sooooo0_l000000ooooooo0000o`000002ooooo`;o0000
00?oooooo`000?l000000_l000000ooooooo0000o`00000Fo`0000gooooo0_l000000ooooooo0000
o`000002o`0000;ooooo0_l0000:ooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`Go
0000@Oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0iooooo`;o00003_ooool2o`00017ooooo0ol000000ooo
oooo0000o`00000>ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Wooooo0_l0000=oooo
o`Oo00001Oooool2o`0000Gooooo0_l0000;ooooo`;o00000_ooool2o`0000;ooooo7?l000000ooo
oooo0000o`000007ooooo`;o00001?ooool3o`0000_ooooo0_l00003ooooo`;o00001_ooool2o`00
0003ooooool0003o000000?o0000@Oooool00003ooooool@413ooooo00;ooooo00?o410@oooooooo
ool02Oooool5o`0000Kooooo00?o0000ooooooooool0>Oooool2o`00017ooooo0ol00007ooooo`?o
00001?ooool2o`00017ooooo0_l0000:ooooo`?o00000oooool2o`0000gooooo0_l000000ooooooo
0000o`000002o`0000Gooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo0_l00009ooooo`?o
00000_ooool4o`000003ooooool0003o000001So00001oooool2o`0000Cooooo0ol00003ooooo`;o
00001_ooool3o`0000;ooooo0_l0001?ooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooo
ooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol00011ooooo`;o00001?ooool2o`0000?o
oooo0ol00004ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`0001?ooooo0_l00003oooo
o`;o00000_ooool5o`0001kooooo0_l000000ooooooo0000o`000002ooooo`?o000000?oooooo`00
0?l000002Oooool2o`0000?ooooo5Ol000000ooooooo0000o`000005o`0000oooooo0_l00002oooo
o`Co00001_ooool3o`0001Oooooo0_l0000jooooo`0000?oooooo`000?ooool00_ooool00ol0003o
ooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool06_ooool2o`00
02Gooooo0_l00003ooooo`?o00002_ooool2o`000003ooooool0003o000001[ooooo0_l00003oooo
o`;o00000_ooool2o`000003ooooool0003o000001_ooooo0_l000000ooooooo0000o`000006oooo
o`;o00003?ooool3o`0000?ooooo7ol0000>ooooo`Go00006?ooool2o`0000Oooooo0_l0000joooo
o`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oo
oooo00?o0000ooooooooool06_ooool2o`0002Oooooo0_l000000ooooooo0000o`00000=ooooo`;o
00002Oooool2o`0001oooooo0_l00006ooooo`;o00004?ooool6o`0000Sooooo0_l00009ooooo`?o
00000_oooolPo`0000kooooo0_l0000Cooooo`;o00001_ooool2o`0000[ooooo0_l0000gooooo`00
00KoooooogMgMonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000oooo
ooooool0=_ooool2o`0000_ooooo0_l00007ooooo`;o00001oooool2o`0000Wooooo0_l0000Ooooo
o`;o00000_ooool2o`0000;ooooo0_l0000Booooo`Co00002?ooool2o`0000Sooooo0_l00004oooo
o`co000000?oooooo`000?l000004Ol0000?ooooo`;o00003Oooool3o`0000;ooooo0_l0000Boooo
o`;o0000=oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06
ooooo`03o`000?oooooooooo03Kooooo0_l0000;ooooo`;o00001oooool2o`0000Wooooo0_l0000<
ooooo`;o00005Oooool2o`0000Oooooo0_l00002ooooo`;o00008Oooool2o`0000Gooooo1?l00000
0ooooooo0000o`00000:o`000003ooooool0003o000001?o00002?ooool4o`0000;ooooo0_l0000=
ooooo`?o00003oooool2o`0003kooooo000Looooo`03o`000?oooooooooo04Cooooo0_l0000@oooo
o`?o00003?ooool2o`0000?ooooo0_l00003ooooo`;o00002oooool2o`0000cooooo0_l0000<oooo
o`;o00000oooool2o`0000Wooooo0_l00002ooooo`;o00001oooool2o`000003ooooool0003o0000
00[o000000?oooooo`000?l000004ol00008ooooo`Oo00000_ooool2o`0000gooooo0_l00002oooo
o`?o00001oooool3o`0000Cooooo0_l00002ooooo`;o0000=?ooool001cooooo00?o0000oooooooo
ool0>oooool2o`0000;ooooo0_l00002ooooo`?o00004?ooool2o`0000[ooooo0_l00006ooooo`;o
000000?oooooo`000?l000002?l00007ooooo`;o00002_ooool2o`0000cooooo0_l00003ooooo`?o
000000?oooooo`000?l000000_ooool2o`000003ooooool0003o0000013ooooo3_l000000ooooooo
0000o`00000>o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`Co00000_ooool2o`0000;o
oooo0_l00009ooooo`;o00000_ooool3o`0000Oooooo0_l00005ooooo`?o000000?oooooo`000?l0
0000=?ooool001cooooo00?o0000ooooooooool0>oooool2o`0000;ooooo0_l00002ooooo`;o0000
00?oooooo`000?l000001_ooool2o`0000Gooooo0_l0000;ooooo`;o00002Oooool;o`0000Cooooo
1?l00003ooooo`;o00001?ooool2o`000003ooooool0003o0000013ooooo0_l000000ooooooo0000
o`000002ooooo`;o000000?oooooo`000?l000002Oooool2o`0000;ooooo0_l000000ooooooo0000
o`00000<o`000003ooooool0003o000000co000000?oooooo`000?l000000oooool2o`000003oooo
ool0003o000000gooooo0_l00007ooooo`;o00005_ooool2o`0003Oooooo000Looooo`03o`000?oo
oooooooo03gooooo0_l00004ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Gooooo0_l0
000@ooooo`?o00000_ooool2o`000004ooooool0003o0000ooooo`?o000000?oooooo`000?l00000
1?ooool<o`000004ooooool0003o0000ooooo`;o00001_ooool2o`0000Sooooo0_l00005ooooo`;o
000000?oooooo`000?l000002Oooool2o`0000;ooooo8ol00009ooooo`;o00003_ooool2o`0000?o
oooo0_l00004ooooo`;o00002_ooool2o`0003gooooo000Looooo`03o`000?oooooooooo033ooooo
0_l00005ooooo`;o00001?ooool2o`0000?ooooo0ol0000Rooooo`Oo000000?oooooo`000?l00000
0_ooool2o`000003ooooool0003o000000Co000000?oooooo`000?l000001?l00002ooooo`?o0000
1oooool2o`0000?ooooo0_l00008ooooo`;o00002?ooool2o`0000;ooooo0_l00009ooooob;o0000
2_ooool2o`0000Kooooo1?l00004ooooo`;o00002Oooool2o`0000;ooooo0_l00006ooooo`;o0000
?Oooool001cooooo00?o0000ooooooooool0<?ooool2o`0000Gooooo0_l000000ooooooo0000o`00
0006ooooo`;o00003_ooool2o`0001Kooooo1ol00004ooooo`Oo000000?oooooo`000?l000001_l0
00000ooooooo0000o`000007ooooo`;o00006oooool2o`0000;ooooo1?l00004oooooa3o000000?o
ooooo`000?l000002ol000000ooooooo0000o`00000;ooooo`;o00000oooool6o`0000Cooooo0_l0
000=ooooo`;o00001_ooool2o`0000Sooooo1?l0000aooooo`007?ooool00ol0003oooooooooo`0d
ooooo`?o00000oooool2o`0000Kooooo0_l00005ooooo`;o00001oooool2o`0001;ooooo0_l00006
ooooo`?o000000Coooooo`000?l0003ooooo0_l000001Ooooooo0000o`000?l0003ooooo00_o0000
00?oooooo`000?l000003Oooool3o`000003ooooool0003o0000017ooooo1_l00004ooooo`Co0000
00?oooooo`000?l000002Ol000000ooooooo0000o`00000;o`0000;ooooo0_l0000:ooooo`?o0000
0_ooool2o`0000;ooooo0_l00004ooooo`;o00000_ooool3o`0000Sooooo0_l00006ooooo`;o0000
2?ooool4o`0000Kooooo0_l0000Yooooo`007?ooool00ol0003oooooooooo`0Yooooo`?o00002?oo
ool3o`0001;ooooo0_l0000:ooooo`;o00000oooool2o`0000[ooooo0_l00004ooooo`;o00001?oo
ool2o`0000Cooooo1ol00003ooooo`Go000000Coooooo`000?l0003o00001?ooool2o`0000Kooooo
0ol000000ooooooo0000o`000006ooooo`;o00002Oooool2o`0000Cooooo0_l00004ooooo`;o0000
00?oooooo`000?l000005_l00003ooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`;o
00004?ooool3o`0002Cooooo0_l0000Yooooo`007?ooool00ol0003oooooooooo`0Yooooo`?o0000
5?ooool2o`0001?ooooo0_l00003ooooo`Co00002?ooool2o`000004ooooool0003o0000ooooo`Co
000000Coooooo`000?l0003o00000_ooool?o`000003ooooool0003o000000?o00001?ooool2o`00
00Sooooo1?l00003ooooo`;o000000?oooooo`000?l000003oooool2o`0000Cooooo0ol000001Ooo
oooo0000o`000?l0003ooooo01?o00002_ooool2o`000003ooooool0003o0000013ooooo0_l00000
0ooooooo0000o`000009ooooo`;o00001_ooool2o`0003gooooo000Looooo`03o`000?oooooooooo
03_ooooo0ol00002ooooo`;o00000oooool2o`000005ooooool0003o0000o`000?ooool00_l0000<
ooooo`Co00000oooool4o`000004ooooool0003o0000ooooo`;o00000_ooool3o`000003ooooool0
003o000000Oo000000?oooooo`000?l000003_l0000>ooooo`Wo00006?oooolIo`0000kooooo0_l0
000Aooooo`?o00002oooool2o`0000Kooooo1?l0000kooooo`007?ooool00ol0003oooooooooo`0k
ooooo`?o00001oooool2o`000005ooooool0003o0000o`000?ooool01?l00005ooooo`;o00001?oo
ool2o`0000Cooooo1?l00003ooooo`?o000000Coooooo`000?l0003o00000_oooolEo`0000?ooooo
0_l00009ooooo`;o00000oooool2o`000003ooooool0003o000000Ko00000oooool2o`0001?ooooo
5ol00003ooooo`;o00000oooool2o`0000Cooooo0_l0000Booooo`;o00000_ooool2o`000004oooo
ool0003o0000ooooo`Go00002?ooool3o`0003[ooooo000Looooo`;o00005oooool2o`0002Cooooo
0_l0000=ooooo`;o000000?oooooo`000?l000001Oooool2o`0000?ooooo0_l00003ooooo`Co0000
1Oooool3o`000003ooooool0003o000000Go000000?oooooo`000?l000004?l000000ooooooo0000
o`000003ooooo`;o00001Oooool3o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`Co0000
0oooool2o`0000Gooooo0_l00002ooooo`?o00002OoooolBo`000003ooooool0003o000000?ooooo
0_l00003ooooo`Co00006_ooool2o`000003ooooool0003o000000Ko00001Oooool2o`0000;ooooo
0_l0000jooooo`007?ooool00ol0003oooooooooo`0Fooooo`;o00006oooool2o`0000Oooooo0ol0
00000ooooooo0000o`000002ooooo`Ko000000?oooooo`000?l000002?ooool2o`0000?ooooo0_l0
0003ooooo`;o00001Oooool4o`0000Cooooo1?l000000ooooooo0000o`00000Ao`000003ooooool0
003o000000Go00001?ooool3o`0000Cooooo0_l00005ooooo`Co00002_ooool2o`0000;ooooo1?l0
0008ooooo`[o00000oooool2o`000003ooooool0003o000000Oooooo0_l00004ooooo`;o00002Ooo
ool2o`0001?ooooo0_l00005ooooo`;o000000?oooooo`000?l000001?l0000looooo`007?ooool0
0ol0003oooooooooo`0booooo`?o00002?ooool2o`000003ooooool0003o000000;ooooo1_l0000;
ooooo`;o00003oooool5o`0000;ooooo6?l000000ooooooo0000o`000007o`000003ooooool0003o
000000?o00004oooool3o`0000Wooooo0_l00003ooooo`;o00001_ooool9o`000003ooooool0003o
000000;o00000oooool2o`0000?ooooo0_l00006ooooo`;o00001oooool2o`00013ooooo0_l00003
ooooo`;o00000_ooool3o`000003ooooool0003o000000;ooooo0_l0000looooo`007?ooool00ol0
003oooooooooo`0booooo`;o00001_ooool2o`0001Sooooo0_l0000Cooooo`;o00000_oooolNo`00
0005ooooool0003o0000o`000?ooool00_l000000ooooooo0000o`00000Cooooo`?o00001oooool2
o`0000Gooooo0_l00002oooooa?o000000Coooooo`000?l0003o00002oooool2o`00013ooooo0_l0
0007ooooo`;o00000oooool2o`0000;ooooo0_l00004ooooo`;o00003oooool2o`0002gooooo000L
ooooo`03o`000?oooooooooo033ooooo0_l00006ooooo`Co00004_ooool2o`0000Cooooo0_l0000B
ooooobCo00009_ooool2o`0000Gooooo0ol000000ooooooo0000o`000003o`0000Cooooo1_l00002
ooooo`;o000000?oooooo`000?l000002Oooool2o`0000[ooooo1?l00005ooooo`;o00001oooool2
o`0000[ooooo0_l000000ooooooo0000o`00000?ooooo`;o0000;Oooool001cooooo00?o0000oooo
ooooool0<?ooool2o`0000;ooooo0_l00002ooooo`;o00005?ooool2o`0000[ooooo0ol00008oooo
o`;o000000?oooooo`000?l000009?l00002ooooo`;o00002_ooool2o`0000Gooooo0_l00008oooo
o`;o00002_ooool3o`0000?ooooo0_l00005ooooo`;o00005?ooool5o`0000Oooooo1?l00004oooo
o`;o00001oooool2o`000003ooooool0003o000000;o00001_ooool2o`0000;ooooo0_l0000moooo
o`007?ooool00ol0003oooooooooo`0Uooooo`;o00003Oooool2o`0000;ooooo0_l000001?oooooo
0000o`000?ooool2o`0000;ooooo0_l0000Dooooo`Go00002?ooool2o`0000;ooooo9Ol00002oooo
o`;o00001oooool2o`000003ooooool0003o000000Gooooo0_l00008ooooo`;o00001?ooool2o`00
00Gooooo1?l00008ooooo`;o00000_ooool2o`00017ooooo1?l00008ooooo`;o00001Oooool2o`00
00Oooooo2?l00007ooooo`Co0000?Oooool001cooooo00?o0000ooooooooool09Oooool2o`0000oo
oooo1?l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00003ooooo`;o00003oooool3o`00
00;ooooo0_l00006ooooo`_o000000?oooooo`000?l000006ol00005ooooo`;o00001?ooool5o`00
00?ooooo0_l00005ooooo`;o00002Oooool2o`0000;ooooo0_l00003ooooo`;o00001_ooool2o`00
00Cooooo0_l0000=ooooo`Co000000Coooooo`000?l0003o00002Oooool2o`0000?ooooo0_l00008
ooooo`?o00000oooool2o`0000Cooooo0_l000000ooooooo0000o`000002o`00017ooooo0_l0000Z
ooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00002_ooool4o`000003ooooool0003o0000
00Gooooo0_l00009ooooo`;o00000_ooool4o`0000Gooooo0ol00002oooooaCo000000?oooooo`00
0?l000001ol000000ooooooo0000o`000005o`0000;ooooo0_l00006ooooo`Co00000_ooool3o`00
00Cooooo0_l00009ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00001_ooool2o`00
013ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l000000ooooooo0000o`000002o`00
00Cooooo1ol00008ooooo`;o00002_ooool3o`000004ooooool0003o0000o`00017ooooo0_l0000Z
ooooo`007?ooool00ol0003oooooooooo`0Rooooo`;o00006_ooool2o`0000;ooooo1?l00003oooo
o`;o00000oooool2o`0000oooooo0_l00003ooooo`Co000000Coooooo`000?l0003ooooo6Ol00000
0ooooooo0000o`000009o`0000cooooo0_l00002ooooo`?o00000_ooool2o`0000Wooooo0_l00003
ooooo`Co00000_ooool5o`0000?ooooo0_l0000@ooooo`;o00002?ooool7o`0000;ooooo1ol00006
ooooo`;o000000?oooooo`000?l000002oooool2o`000003ooooool0003o000003kooooo000Loooo
o`03o`000?oooooooooo02;ooooo0_l0000=ooooo`;o00002oooool2o`0000Oooooo1?l0000Ioooo
o`?o000000?oooooo`000?l000008ol0000Dooooo`Oo00001oooool6o`0000Sooooo1?l0000Boooo
o`;o00000oooool2o`0000Kooooo1ol00002ooooo`?o000000?oooooo`000?l000001oooool2o`00
0003ooooool0003o000000Kooooo0ol00005ooooo`;o0000?_ooool001cooooo00?o0000oooooooo
ool0<Oooool2o`0000;ooooo0_l0000=ooooo`Go00007oooool2o`000003ooooool0003o000002?o
00000oooool2o`0000oooooo0_l00009ooooo`;o00000_ooool2o`0000oooooo0_l0000=ooooo`;o
00000oooool2o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l000000oooool2o`0000Wo
oooo0_l00002ooooo`;o00001Oooool3o`0004Gooooo000Looooo`03o`000?oooooooooo03Gooooo
0ol00003ooooo`;o00001oooool5o`0000?ooooo0_l0000>ooooo`;o00002oooool9o`000003oooo
ool0003o0000023o00001Oooool2o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`;o0000
5oooool2o`000003ooooool0003o000000;ooooo0_l0000<ooooo`Co00000_ooool2o`000003oooo
ool0003o000000;o00000_ooool3o`0000?ooooo0_l00009ooooo`So00001?ooool6o`0000Cooooo
0_l0000kooooo`007?ooool00ol0003oooooooooo`0Pooooo`;o00005?ooool2o`0000?ooooo0_l0
0009ooooo`;o00000oooool3o`0000gooooo0ol00004ooooo`;o00001Oooool/o`0000Gooooo0_l0
00000ooooooo0000o`000004o`0000Gooooo0_l0000Gooooo`;o000000?oooooo`000?l000000_oo
ool2o`0000_ooooo0ol00005ooooo`Ko00000_ooool4o`0000Wooooo0_l00002ooooo`Co00000_oo
ool2o`0000Cooooo1_l00004ooooo`;o0000>oooool001cooooo00?o0000ooooooooool08?ooool3
o`0000cooooo0_l00005ooooo`?o00000_ooool2o`0000Sooooo0ol00003ooooo`;o00003Oooool3
o`0000Gooooo0_l000000ooooooo0000o`00000^o`0000Sooooo0_l000000ooooooo0000o`00000;
ooooo`;o00005Oooool2o`0000_ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00000ooo
ool2o`0000Sooooo0_l00009ooooo`;o00000_ooool3o`0000Gooooo0_l00002ooooo`;o00001ooo
ool2o`0003cooooo000Looooo`03o`000?oooooooooo01Oooooo0_l00008ooooo`;o00003?ooool3
o`0000Cooooo0ol00007ooooo`;o00000oooool2o`0000;ooooo1?l0000=ooooo`;o00001_ooool2
o`000003ooooool0003o0000023o000000?oooooo`000?l000001_l00002ooooo`?o00006?ooool2
o`0001Cooooo0ol000000ooooooo0000o`000008ooooo`;o000000?oooooo`000?l000000_ooool2
o`0000kooooo0_l0000Dooooo`;o00001?ooool4o`0000?ooooo0_l0000looooo`007?ooool2o`00
01Sooooo0_l0000Gooooo`;o00001?ooool2o`0000Sooooo0_l00007ooooo`Co00005Oooool2o`00
0003ooooool0003o000000?o000000?oooooo`000?l000005Ol000000ooooooo0000o`00000=o`00
0003ooooool0003o000000Gooooo0_l000000ooooooo0000o`000003o`0000Oooooo0_l0000<oooo
o`;o00002_ooool2o`0000;ooooo0_l0000?ooooo`Co00002?ooool2o`0000;ooooo1Ol00003oooo
o`;o00003oooool7o`00047ooooo000Looooo`03o`000?oooooooooo03gooooo0_l0000Eooooo`?o
00002Oooool2o`0000?ooooo5ol000000ooooooo0000o`00000?o`000004ooooool0003o0000o`00
00Sooooo0_l000000ooooooo0000o`000003o`0000Oooooo0_l0000<ooooo`;o00003oooool2o`00
00kooooo1?l00007ooooo`?o00001?ooool5o`000003ooooool0003o000000Gooooo0_l00002oooo
o`;o00001?ooool4o`000003ooooool0003o0000047ooooo000Looooo`03o`000?oooooooooo037o
oooo0_l0000:ooooo`;o00002?ooool2o`0000_ooooo0ol00005ooooo`Ko00000_ooool/o`0000oo
oooo0_l0000>ooooo`;o00001?ooool2o`00017ooooo0_l00004ooooo`;o000000Coooooo`000?l0
003o00001?ooool2o`0000Wooooo0_l00008ooooo`;o00001Oooool2o`000003ooooool0003o0000
00;ooooo0_l00007ooooo`Go0000@?ooool001cooooo00?o0000ooooooooool0<Oooool2o`0000Wo
oooo0_l00009ooooo`;o00004oooool4o`000003ooooool0003o000000?o000000?oooooo`000?l0
00004Ol000000ooooooo0000o`00000Eo`0000gooooo0_l000000ooooooo0000o`00000;ooooo`;o
00001?ooool4o`0000;ooooo1_l0000=ooooo`;o000000?oooooo`000?l000000ol0000<ooooo`;o
00003oooool3o`000003ooooool0003o000000;ooooo0ol00004ooooo`Co000000?oooooo`000?l0
0000@?ooool001cooooo00?o0000ooooooooool0=Oooool2o`0000Gooooo0_l00009ooooo`;o0000
6?oooolRo`000003ooooool0003o000000co00001?ooool2o`0000[ooooo0_l000000ooooooo0000
o`000002o`0000Sooooo0_l00004ooooo`;o00000_ooool8o`0000Gooooo0_l00006ooooo`;o0000
0_ooool2o`0000cooooo0_l00006ooooo`?o00001_ooool4o`0000Cooooo0ol00004ooooo`;o0000
AOooool001cooooo00?o0000ooooooooool06_ooool2o`0001Wooooo0_l0000@ooooo`;o00001?oo
ool2o`0000Kooooo0_l00003ooooo`;o00001_ooool2o`000003ooooool0003o000002[o00001Ooo
ool2o`0000[ooooo0_l000000ooooooo0000o`000002o`0000Gooooo0_l000000ooooooo0000o`00
0004ooooo`;o000000Coooooo`000?l0003ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o
00000_ooool2o`0000Kooooo0ol00003ooooo`;o00004_ooool3o`0000Sooooo0_l0001Booooo`00
7?ooool00ol0003oooooooooo`0Jooooo`;o0000<Oooool4o`0000Cooooo0_l00003ooooo`;o0000
1_ooool6o`000003ooooool0003o0000017o000000?oooooo`000?l000003Ol00003ooooo`;o0000
3Oooool6o`0000?ooooo0_l00005ooooo`;o00001oooool2o`000003ooooool0003o000000?o0000
00?oooooo`000?l000002?l00007ooooo`;o00000oooool2o`0000_ooooo0_l000000ooooooo0000
o`000004ooooo`?o0000F_ooool001cooooo00?o0000ooooooooool0>oooool2o`0000Kooooo0_l0
0004ooooo`Co00000_ooool2o`000003ooooool0003o000000Kooooo0_l00006ooooo`Ko000000?o
ooooo`000?l000008?l00003ooooo`Co00003?ooool4o`0000?ooooo1?l00005ooooo`;o00000ooo
ool2o`0000Oooooo0ol00003ooooo`Oo00006_ooool2o`000003ooooool0003o000000Cooooo0ol0
0008ooooo`;o00002_ooool2o`0004Cooooo000Looooo`03o`000?oooooooooo03Sooooo0_l00000
0ooooooo0000o`000006ooooo`;o00001?ooool4o`0000Gooooo0_l00006ooooo`;o00001_ooool6
o`000003ooooool0003o000000Cooooo8ol00008ooooo`;o00000oooool2o`0000Cooooo1?l00003
ooooo`Co000000?oooooo`000?l000000_l00008ooooo`;o00000oooool2o`0000;ooooo0ol0000L
ooooo`;o00000oooool2o`0000;ooooo0_l00007ooooo`;o00001_ooool2o`0000;ooooo0_l00000
0ooooooo0000o`000011ooooo`007?ooool00ol0003oooooooooo`0Rooooo`;o00005?ooool2o`00
00Wooooo0_l00004ooooo`;o00001oooool2o`0000;ooooo0_l00002ooooo`;o00002Oooool4o`00
00Gooooo8?l00005ooooo`;o00001Oooool2o`0000_ooooo0_l00003ooooo`;o00000oooool4o`00
00[ooooo0_l00005ooooo`;o00002oooool2o`00013ooooo0_l00003ooooo`;o00000_ooool2o`00
00kooooo0ol000000ooooooo0000o`000002ooooo`;o0000@Oooool001cooooo00?o0000oooooooo
ool08_ooool2o`0001?ooooo0_l0000:ooooo`Co00002oooool2o`0000;ooooo0_l0000:ooooo`;o
00000_ooool6o`000003ooooool0003o0000017o000000?oooooo`000?l000002?l000000ooooooo
0000o`000002o`0000?ooooo0_l00003ooooo`;o00001?ooool2o`0000Oooooo0_l0000:ooooo`;o
00002_ooool3o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`;o00000oooool4o`0001Oo
oooo0_l00008ooooo`;o00001?ooool3o`000003ooooool0003o000000Wooooo0_l0000jooooo`00
7?ooool00ol0003oooooooooo`0gooooo`Co00002_ooool2o`0000Wooooo0_l0000>ooooo`Co0000
0_ooool6o`000003ooooool0003o000000oo000000?oooooo`000?l000004?l00004ooooo`;o0000
00?oooooo`000?l000001?ooool3o`0001;ooooo1?l00009ooooo`;o00001?ooool5o`0000?ooooo
0_l00005ooooo`Co00005Oooool2o`0000Sooooo0_l00006ooooo`;o00002oooool2o`0003[ooooo
000Looooo`03o`000?oooooooooo03Wooooo0_l0000:ooooo`;o00002Oooool2o`0000kooooo1?l0
0004ooooo`?o00000_oooolKo`000004ooooool0003o0000o`0000?ooooo0_l00004ooooo`;o0000
00?oooooo`000?l000000_ooool5o`0000oooooo0ol00002ooooo`;o00004Oooool3o`0000cooooo
0_l00009ooooo`;o00005?ooool2o`0000Cooooo1?l00002ooooo`?o00001Oooool2o`0003_ooooo
000Looooo`03o`000?oooooooooo04Gooooo0_l0000Cooooo`;o00003Oooool2o`0000;ooooo3ol0
00000ooooooo0000o`000005o`000003ooooool0003o000000?o000000?oooooo`000?l000000ooo
ool2o`0000Kooooo0_l00002ooooo`Co00001_ooool2o`0000Kooooo1Ol0000Fooooo`;o00001_oo
ool2o`0000gooooo1?l000001?oooooo0000o`000?ooool4o`0000cooooo0_l000001?oooooo0000
o`000?ooool2o`0000Cooooo0ol00005ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0
C_ooool2o`0000[ooooo0_l0000=ooooo`;o00000_ooool2o`000004ooooool0003o0000oooooaco
000000?oooooo`000?l000001_ooool2o`0000;ooooo0ol00007ooooo`;o00001_ooool2o`0000co
oooo1?l00004ooooo`;o00000_ooool2o`000003ooooool0003o000000Cooooo0_l00003ooooo`;o
00002?ooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`0000Cooooo0ol00008ooooo`Ko
00003Oooool2o`0000_ooooo0_l0000/ooooo`007?ooool00ol0003oooooooooo`0Kooooo`;o0000
9oooool2o`0000Sooooo0ol00003ooooo`?o00003Oooool2o`0000;ooooo1?l000000ooooooo0000
o`000004oooooaCo000000?oooooo`000?l000001Ol00002ooooo`;o00001Oooool2o`0000?ooooo
0ol0000>ooooo`;o00001oooool2o`0000?ooooo1?l00004ooooo`;o00000_ooool5o`0000Wooooo
0_l00004ooooo`;o00003?ooool2o`0000Cooooo0ol0000:ooooo`Co000000?oooooo`000?l00000
2_ooool2o`0000_ooooo0_l0000/ooooo`007?ooool2o`0001cooooo0_l0000:ooooo`;o00003_oo
ool2o`0000_ooooo0_l00009ooooo`;o00000oooool3o`0000Cooooo0_l00007ooooo`;o00000_oo
ool7o`0000Cooooo4_l000000ooooooo0000o`000007o`0000;ooooo0_l00005ooooo`;o00000ooo
ool3o`0001Oooooo0_l00003ooooo`;o00002Oooool5o`0000;ooooo0_l00004ooooo`;o00001_oo
ool2o`0000Oooooo0_l00003ooooo`;o000000?oooooo`000?l000003_ooool2o`0000?ooooo0_l0
0005ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool06Oooool2o`0000cooooo0_l0000>
ooooo`;o00004oooool2o`0000?ooooo0ol00007ooooo`Co00002_ooool6o`0000?ooooo4_l00000
0ooooooo0000o`000007o`0000oooooo0ol0000?ooooo`;o00002?ooool2o`000004ooooool0003o
0000o`0000Cooooo0_l00002ooooo`Co00000oooool2o`0000;ooooo1Ol0000>ooooo`;o00000ooo
ool2o`000003ooooool0003o000000[ooooo0_l00002ooooo`;o00002_ooool2o`0003kooooo000L
ooooo`03o`000?oooooooooo01Wooooo0_l0000Looooo`Co00001_ooool2o`0000Wooooo0_l00003
ooooo`?o00001oooool4o`000003ooooool0003o000000Kooooo0ol00007ooooo`;o00000_ooool3
o`0000;ooooo1Ol00002ooooo`;o000000?oooooo`000?l000001ol0000@ooooo`?o00002Oooool2
o`0000?ooooo0ol00007ooooo`;o00000_ooool2o`0000;ooooo1?l00009ooooo`?o000000Cooooo
o`000?l0003ooooo0_l00003ooooo`;o00004Oooool2o`0000[ooooo0_l0000=ooooo`;o00004Ooo
ool2o`0002cooooo000Looooo`03o`000?oooooooooo02Cooooo0_l00009ooooo`;o00001_ooool4
o`0000Kooooo0_l0000Eooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000006
ooooo`;o00002?ooool3o`000004ooooool0003o0000o`0000Gooooo0_l00006ooooo`So00002Ooo
ool2o`0000Kooooo0_l00007ooooo`Co00001?ooool2o`0000Gooooo0_l00008ooooo`;o00000_oo
ool?o`000003ooooool0003o000000?ooooo0_l0000Aooooo`;o00004Oooool2o`000003ooooool0
003o000000?ooooo0_l0000Aooooo`;o0000;?ooool001cooooo00?o0000ooooooooool09?ooool2
o`0000Wooooo0ol00005ooooo`;o00007oooool2o`0000?ooooo0ol0000;ooooo`Ko000000?ooooo
o`000?l000000_l000000ooooooo0000o`00000:o`0000?ooooo1?l00002ooooo`;o00001?ooool2
o`0000?ooooo0_l00006ooooo`;o00001oooool2o`0000Cooooo0_l00002ooooo`;o00000oooool2
o`0000cooooo3ol000000ooooooo0000o`00000>ooooo`;o00002_ooool3o`0000Cooooo1?l00004
ooooo`Go0000A?ooool001cooooo00?o0000ooooooooool0<?ooool2o`0000cooooo0ol00009oooo
o`Co00004?ooool2o`0000_ooooo1_l000000ooooooo0000o`00000Do`000004ooooool0003o0000
ooooo`;o00000_ooool4o`0000[ooooo0_l000000ooooooo0000o`000003ooooo`;o00000_ooool2
o`0000;ooooo0_l00002ooooo`?o00004?oooolBo`0000kooooo0_l000000ooooooo0000o`000002
ooooo`;o00000oooool3o`000004ooooool0003o0000ooooo`Co00001_ooool3o`0000[ooooo0ol0
000gooooo`007?ooool00ol0003oooooooooo`0nooooo`?o00000oooool2o`0000Cooooo1?l0000B
ooooo`;o00001?ooool2o`0000[ooooo0_l00002ooooo`Go000000?oooooo`000?l000000_l00002
ooooo`Wo000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l00005ooooo`Ko00000oooool2
o`0000;ooooo0_l00007ooooo`;o00004?ooool>o`000004ooooool0003o0000o`0000Kooooo0_l0
00000ooooooo0000o`000006ooooo`Ko00001oooool2o`000003ooooool0003o000000Wooooo0_l0
0002ooooo`?o00001Oooool3o`0003Oooooo000Looooo`03o`000?oooooooooo02kooooo0_l0000<
ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00004oooool2
o`0000Cooooo0_l0000@ooooo`Go00001_ooool2o`000003ooooool0003o000000?o00002oooool2
o`0000Gooooo0_l000000ooooooo0000o`00000Soooooa;o00001_ooool2o`000003ooooool0003o
000000;o00001_ooool3o`0001Sooooo1Ol0000oooooo`007?ooool00ol0003oooooooooo`0^oooo
o`Co00002_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool2o`00
02;ooooo0_l00002ooooo`;o00000oooool6o`0000?ooooo1?l00002ooooo`;o000000?oooooo`00
0?l000005?ooool2o`0000Cooooo0_l00003ooooo`;o00004?ooool2o`0000Gooooo5_l00008oooo
o`;o00001oooool2o`0001Sooooo0_l0000:ooooo`;o0000=_ooool001cooooo00?o0000oooooooo
ool0:?ooool2o`0000Kooooo0_l0000Aooooo`;o00001oooool2o`00027ooooo0_l00002ooooo`;o
00001Oooool4o`0000?ooooo1?l00002ooooo`Go00006_ooool2o`0000?ooooo0_l0000@ooooo`;o
00001OoooolFo`0000Sooooo0_l0000Mooooo`;o00000_ooool3o`0000Kooooo0_l000000ooooooo
0000o`000005ooooo`;o0000;oooool001cooooo00?o0000ooooooooool08oooool2o`0000?ooooo
0_l0000?ooooo`;o00002_ooool2o`0000Gooooo0_l00003ooooo`;o00006Oooool2o`0000Gooooo
0_l00006ooooo`;o00000_ooool3o`0000Gooooo1?l0000Booooo`;o00006oooool2o`0000Kooooo
7Ol00003ooooo`;o00007Oooool2o`0000?ooooo0_l00006ooooo`;o00002?ooool2o`0002oooooo
000Looooo`03o`000?oooooooooo02?ooooo0_l0000Dooooo`;o00002_ooool2o`0000Cooooo0_l0
0004ooooo`;o00001?ooool2o`0001?ooooo1_l00007ooooo`;o00001?ooool3o`0000;ooooo0_l0
000;ooooo`;o00001_ooool3o`000003ooooool0003o000001Kooooo0_l00003ooooo`;o00000_oo
ool2o`0000;ooooo5_l000000ooooooo0000o`000004o`0001?ooooo0_l00003ooooo`;o00002?oo
ool2o`0004Kooooo000Looooo`03o`000?oooooooooo03Cooooo0_l00003ooooo`;o00000oooool2
o`0000?ooooo0_l00006ooooo`;o00002_ooool2o`0001Gooooo1?l00003ooooo`Oo000000?ooooo
o`000?l000000ol00002ooooo`Co00002Oooool2o`0000Kooooo1?l0000Hooooo`;o00001oooool2
o`0000;ooooo6Ol0000@ooooo`;o00001Oooool2o`000003ooooool0003o000000;o00002Oooool2
o`0000[ooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`0dooooo`;o00000oooool2o`00
00?ooooo0_l00003ooooo`;o0000;?ooool2o`0000;ooooo1?l000001?oooooo0000o`000?ooool5
o`0000?ooooo0ol00003ooooo`;o00003?ooool4o`0000Gooooo0_l00004ooooo`;o00000_ooool4
o`0000Cooooo0_l0000=oooooaSo00000oooool2o`0000?ooooo0_l00006ooooo`Co00001_ooool2
o`0000_ooooo0_l00002ooooo`;o00001?ooool4o`0003Wooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003ooooo
ooooo`0_ooooo`;o00000oooool2o`0000Oooooo0_l000000ooooooo0000o`000003ooooo`Ko0000
9_ooool3o`000003ooooool0003o000000Sooooo0ol00009ooooo`;o00001Oooool2o`000003oooo
ool0003o000000_ooooo0_l00004ooooo`;o00000_ooool6o`0000;ooooo0_l00008ooooo`;o0000
0ooooolFo`0000Gooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o
00005oooool2o`0000Cooooo0_l0000kooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5oooo
o`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0;oooool2
o`0000cooooo0_l000000ooooooo0000o`000003ooooo`Oo00002_ooool4o`0001Sooooo1Ol00009
ooooo`;o00001oooool2o`0000Oooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00001_oo
ool2o`0000cooooo0_l00002ooooo`;o00002?ooool2o`0000;ooooo6?l0000<ooooo`;o000000?o
ooooo`000?l000000_l00007ooooo`;o00001Oooool2o`000003ooooool0003o000000_ooooo0_l0
000looooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`0oooooo`;o00000_ooool4o`0000?ooooo0_l0
000:ooooo`Co00006Oooool2o`0001Cooooo0_l0000;ooooo`;o00000_ooool2o`0000kooooo0_l0
0004ooooo`;o00000_ooool2o`0000;ooooo0_l00008ooooo`go000000?oooooo`000?l000002Ol0
0002ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Oooooo0_l00005ooooo`;o000000?o
ooooo`000?l000002oooool2o`0003cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo00Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000;oooool2o`0000Sooooo0_l0
0004ooooo`;o000000Coooooo`000?l0003o00001_ooool2o`0003Gooooo0_l00003ooooo`Co0000
1oooool2o`0000?ooooo0_l00004ooooo`;o00002oooool2o`0000Cooooo0_l00002ooooo`;o0000
0_ooool2o`000003ooooool0003o000000Cooooo3Ol00002ooooo`_o00000_ooool5o`0000_ooooo
0_l0000Hooooo`;o00000oooool2o`0003_ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oo
oooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo02oooooo
0_l00008ooooo`;o00001oooool2o`0000Kooooo0ol0000aooooo`Ko00000oooool4o`0000Oooooo
0_l00003ooooo`;o00000oooool3o`0000oooooo0_l0000;ooooo`;o00001?ooool2o`000003oooo
ool0003o000001Oo000000?oooooo`000?l000003Oooool2o`0000Cooooo0_l0000Booooo`;o0000
00?oooooo`000?l000000_l0000kooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0:oooool2o`0001_ooooo1Ol0
000aooooo`Co00000oooool3o`0000Cooooo0_l0000:ooooo`Ko00002Oooool3o`0000Cooooo0_l0
0005ooooo`Co00002ooooolKo`0001Cooooo0_l0000Eooooo`;o0000?Oooool00006oooooomgMgOo
V9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo02_ooooo
0_l0000Aooooo`?o00000oooool2o`0000;ooooo0_l00006ooooo`;o0000;?ooool2o`0000Cooooo
1?l000001?oooooo0000o`000?ooool2o`0000[ooooo1?l000000ooooooo0000o`000008ooooo`?o
00002oooool4o`000003ooooool0003o000000;o000000Coooooo`000?l0003ooooo1_l000000ooo
oooo0000o`00000>o`0000;ooooo1?l0000Dooooo`;o00005Oooool2o`0003gooooo00001_oooooo
k^k^oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003ooooooooo
o`0hooooo`Co000000?oooooo`000?l000000_l00002ooooo`Oo00001_ooool2o`0003;ooooo0ol0
00001?oooooo0000o`000?l00004ooooo`;o00002oooool3o`0000cooooo0_l00005ooooo`;o0000
0_ooool3o`000003ooooool0003o000000;o000000Coooooo`000?l0003ooooo1_l000000ooooooo
0000o`00000>o`0000;ooooo0_l0000Dooooo`Co00005oooool2o`0003_ooooo000Looooo`03o`00
0?oooooooooo03Sooooo1ol00002ooooo`Co000000?oooooo`000?l000000_l0000>ooooo`?o0000
5oooool2o`0000[ooooo0_l00007ooooo`?o00000oooool4o`0000?ooooo0_l00006ooooo`;o0000
0oooool2o`0000Sooooo1?l00003ooooo`;o00000_ooool3o`0000[ooooo1?l000000ooooooo0000
o`00000?o`0000;ooooo0_l0000Aooooo`;o000000?oooooo`000?l000000oooool2o`0000_ooooo
0ol00006ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0>oooool2o`000004ooooool0
003o0000ooooo`;o00001?ooool2o`0000oooooo0ol0000Gooooo`;o00002_ooool2o`0000Oooooo
3ol00006ooooo`;o00000oooool2o`0000[ooooo0_l0000<ooooo`;o00000_ooool2o`0000;ooooo
5_l00002ooooo`;o00004Oooool2o`000003ooooool0003o000000?ooooo0ol00004ooooo`;o0000
0oooool6o`00047ooooo000Looooo`03o`000?oooooooooo03kooooo0_l0000Mooooo`;o00005ooo
ool2o`0000oooooo0_l000000ooooooo0000o`00000<o`0000Cooooo0ol000001?oooooo0000o`00
0?l0000:ooooo`;o00002oooool3o`0000;ooooo0_l00002oooooaOo000000?oooooo`000?l00000
0oooool2o`0000oooooo0_l00004ooooo`;o00000oooool3o`0000?ooooo0_l00002ooooo`;o0000
@Oooool001cooooo00?o0000ooooooooool0>oooool2o`0000;ooooo0_l00002ooooo`;o00006?oo
ool2o`0001Gooooo1?l00009ooooo`;o00001?ooool2o`000003ooooool0003o000000So000000Co
ooooo`000?l0003o00001Oooool2o`000003ooooool0003o000000?ooooo0_l00005ooooo`?o0000
2oooool2o`0000Oooooo0_l000000ooooooo0000o`00000?o`000003ooooool0003o000000;o0000
1?ooool2o`0001[ooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`0kooooo`;o00000_oo
ool2o`0000;ooooo0_l0000Eooooo`;o00006?ooool2o`0000_ooooo0_l00005ooooo`co00000_oo
ool2o`0000gooooo1?l00003ooooo`;o00000oooool2o`00017ooooo4ol00003ooooo`;o00000ooo
ool2o`0000Sooooo0_l0000;ooooo`;o00002Oooool2o`0000Sooooo0_l0000looooo`007?ooool0
0ol0003oooooooooo`0eooooo`;o00003Oooool2o`0001Cooooo1?l0000Hooooo`;o00004?ooool=
o`000003ooooool0003o000000Sooooo0_l00003ooooo`Co00002?ooool2o`00017ooooo4Ol0000:
ooooo`;o00002?ooool4o`000003ooooool0003o000000Gooooo0ol00009ooooo`;o00001_ooool4
o`0003cooooo000Looooo`03o`000?oooooooooo03Gooooo0_l0000=ooooo`;o00003_ooool2o`00
00Kooooo0_l0000Booooo`;o00001?ooool2o`0000cooooo0_l00002oooooa7o00000oooool3o`00
0003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000006ooooo`;o00001Oooool2o`00
00Kooooo1?l00002ooooo`Wo000000?oooooo`000?l000000_l000000ooooooo0000o`00000Doooo
o`?o000000?oooooo`000?l000001Oooool2o`0000Sooooo0_l00006ooooo`Co0000?_ooool001co
oooo00?o0000ooooooooool0?Oooool4o`0001?ooooo0_l00005ooooo`;o00004oooool2o`00013o
oooo7Ol00006ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Gooooo0_l00006ooooo`Co
00000oooool:o`000004ooooool0003o0000ooooo`;o00002?ooool2o`0000;ooooo0_l00006oooo
o`;o00001_ooool2o`0000_ooooo0_l00006ooooo`;o0000@?ooool001cooooo00?o0000oooooooo
ool0>oooool6o`000003ooooool0003o0000017ooooo0_l00004ooooo`;o00000oooool2o`0001?o
oooo1Ol00008ooooo`;o000000?oooooo`000?l000005ol00009ooooo`;o00001?ooool2o`0000go
oooo0_l000000ooooooo0000o`000005ooooo`[o00000oooool2o`0000;ooooo0_l00005ooooo`;o
00000_ooool2o`0000kooooo0_l0000:ooooo`;o00001oooool2o`00043ooooo000Looooo`03o`00
0?oooooooooo03_ooooo0_l00002ooooo`;o000000?oooooo`000?l000000oooool2o`0000cooooo
1?l00005ooooo`Co00004oooool5o`0000Sooooo0_l000000ooooooo0000o`00000Ao`0000Cooooo
0_l00009ooooo`?o00000oooool2o`0000gooooo0_l000000ooooooo0000o`000005ooooo`Oo0000
00?oooooo`000?l000000_l000000ooooooo0000o`000002ooooo`;o00008Oooool2o`0000;ooooo
0_l00007ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0?oooool2o`0000Kooooo0_l0
000>ooooo`;o00001Oooool2o`000003ooooool0003o000001oooooo0_l000001?oooooo0000o`00
0?ooool@o`00013ooooo0_l00002ooooo`Co000000Coooooo`000?l0003o00002?ooool2o`0000Go
oooo0ol000001Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`000?l000000_l0000Foooo
o`;o00000_ooool2o`0000[ooooo1?l00003ooooo`;o00002_ooool2o`0003cooooo000Looooo`;o
0000@?ooool2o`0001oooooo0ol0000?ooooo`;o00001?ooool2o`0000Wooooo0_l000000ooooooo
0000o`00000;o`000003ooooool0003o000000Oo00001oooool2o`0000Kooooo1?l000000ooooooo
0000o`000003o`0000gooooo0ol00003ooooo`;o00000_ooool5o`0001Kooooo0_l00002ooooo`;o
00002?ooool4o`0000Gooooo0_l0000:ooooo`;o0000??ooool001cooooo00?o0000ooooooooool0
>oooool2o`0000Wooooo0_l0000Hooooo`?o00003oooool3o`0000?ooooo0_l00006ooooo`;o0000
00Coooooo`000?l0003ooooo3Ol000000ooooooo0000o`000007o`0000Oooooo0_l0000>ooooo`;o
00004Oooool5o`000003ooooool0003o000000?o00002?ooool5o`0000?ooooo0ol000000ooooooo
0000o`000005ooooo`;o00000_ooool2o`0000?ooooo0_l00006ooooo`?o0000B?ooool001cooooo
00?o0000ooooooooool0>oooool2o`0000Wooooo0_l00002ooooo`;o00001oooool2o`0000cooooo
0_l000000ooooooo0000o`00000=ooooo`;o00002oooool2o`0000Cooooo5_l00007ooooo`?o0000
3_ooool2o`000003ooooool0003o000000Cooooo0_l00004ooooo`;o00000_ooool2o`000003oooo
ool0003o000000;ooooo1?l00008ooooo`Go00000oooool3o`000003ooooool0003o000000Gooooo
0_l00002ooooo`;o00002oooool3o`0000Gooooo1?l0000oooooo`007?ooool00ol0003ooooooooo
o`12ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0000Oooooo0_l00009ooooo`;o0000
1?ooool2o`0000gooooo0_l00009ooooo`;o00000_ooool2o`000003ooooool0003o0000017o0000
00?oooooo`000?l000000ol00005ooooo`?o00001?ooool2o`0000Sooooo1Ol00002ooooo`Co0000
1?ooool2o`0000_ooooo1?l0000booooo`Co0000?oooool001cooooo00?o0000ooooooooool0=Ooo
ool2o`0000Kooooo0_l00003ooooo`;o000000Coooooo`000?l0003o00001_ooool2o`0000Sooooo
0_l00004ooooo`;o00003oooool2o`0000;ooooo0_l00009ooooo`;o00000_ooool2o`000003oooo
ool0003o000001Co000000Coooooo`000?l0003o00002oooool2o`0000Kooooo0_l000000ooooooo
0000o`000004ooooo`;o00005Oooool3o`000003ooooool0003o000000Kooooo0_l0000Cooooo`;o
00000_ooool2o`00053ooooo000Looooo`03o`000?oooooooooo03Gooooo0_l00006ooooo`;o0000
2oooool2o`0000;ooooo0_l00008ooooo`;o00005Oooool2o`0000;ooooo0_l0000@oooooaKo0000
00Coooooo`000?l0003o00004oooool2o`0000;ooooo0_l00003ooooo`;o00001_ooool2o`0000Wo
oooo0_l00003ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Cooooo0_l00004ooooo`;o
00001oooool2o`0000;ooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`1:ooooo`?o0000
00?oooooo`000?l000001_ooool2o`0000kooooo0_l0000Kooooo`;o00000_oooolGo`0000?ooooo
0_l0000:ooooo`;o00001oooool2o`0000Cooooo0_l00005ooooo`;o00000_ooool2o`0000Gooooo
0_l00005ooooo`;o00000oooool2o`0000Sooooo0_l00003ooooo`Co0000G?ooool001cooooo00?o
0000ooooooooool0Boooool2o`000003ooooool0003o000000Kooooo0_l0000>ooooo`;o00002Ooo
ool2o`0000Wooooo0_l00005ooooo`;o00000_oooolIo`000004ooooool0003o0000ooooo`;o0000
00?oooooo`000?l000001?ooool2o`0000gooooo0_l00004ooooo`;o00000oooool2o`0000Gooooo
0_l00005ooooo`Co000000?oooooo`000?l000003Oooool4o`0000gooooo0_l0001=ooooo`007?oo
ool00ol0003oooooooooo`1Fooooo`;o00005oooool5o`0000?ooooo0ol00002ooooo`;o00000ooo
ool2o`0000Gooooo1_l000000ooooooo0000o`00000?o`0000Cooooo0_l000000ooooooo0000o`00
0004ooooo`;o00000_ooool2o`0000_ooooo0_l00002ooooo`;o00002_ooool2o`0000Gooooo1?l0
000Qooooo`;o0000COooool001cooooo00?o0000ooooooooool0COooool2o`0000Oooooo0_l00003
ooooo`;o00002Oooool2o`0000Oooooo0_l000000ooooooo0000o`000003ooooo`?o00001_ooool3
o`0000?ooooo5ol000001?oooooo0000o`000?l00006ooooo`;o00002?ooool2o`0000_ooooo0_l0
0002ooooo`?o00003_ooool6o`0000oooooo0_l00003ooooo`?o00002_ooool2o`0004gooooo000L
ooooo`03o`000?oooooooooo04gooooo0_l0000<ooooo`;o000000?oooooo`000?l000001?ooool4
o`0000gooooo0_l00009ooooo`;o00001?oooolKo`0000Oooooo1Ol0000Fooooo`?o000000Cooooo
o`000?l0003ooooo0_l00007ooooo`;o00000_ooool2o`0000oooooo0_l00003ooooo`?o00001?oo
ool2o`0005?ooooo000Looooo`03o`000?oooooooooo04Oooooo0_l00003ooooo`;o00003oooool3
o`0000Cooooo0ol00004ooooo`;o00002?ooool2o`0000Oooooo0_l00006oooooaSo00002_ooool5
o`0000;ooooo1?l00003ooooo`;o00002_ooool4o`000004ooooool0003o0000ooooo`;o00001Ooo
ool4o`0000Sooooo0_l0000;ooooo`;o00002?ooool4o`00057ooooo000Looooo`03o`000?oooooo
oooo047ooooo0ol00003ooooo`;o00000oooool2o`0000oooooo0_l00006ooooo`;o000000Cooooo
o`000?l0003ooooo0_l0000;ooooo`;o000000?oooooo`000?l000000ol00005oooooaWo000000?o
ooooo`000?l000001oooool2o`0000Gooooo1?l00003ooooo`;o00002_ooool4o`0000Cooooo0_l0
0005ooooo`?o00002Oooool2o`0000Sooooo0_l000000ooooooo0000o`00000:ooooo`;o0000DOoo
ool001cooooo00?o0000ooooooooool0@?ooool4o`0002Cooooo0_l0000>ooooo`;o000000?ooooo
o`000?l000000_l000000ooooooo0000o`000002o`000003ooooool0003o000001co000000?ooooo
o`000?l000000_ooool4o`0001Sooooo0_l00004ooooo`;o000000?oooooo`000?l000000_ooool3
o`0001?ooooo0_l00005ooooo`;o00002?ooool2o`0000;ooooo0_l0001;ooooo`007?ooool00ol0
003oooooooooo`10ooooo`;o00008oooool2o`0001Wooooo1?l00002oooooago000000?oooooo`00
0?l000000_l00002ooooo`;o00007_ooool5o`0000;ooooo0_l0000:ooooo`Co00003Oooool2o`00
00Sooooo0_l00002ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0B_ooool2o`0000Co
oooo0_l000000ooooooo0000o`00000@ooooo`;o00005oooool2o`0000Kooooo1_l000000ooooooo
0000o`00000>o`0000Wooooo0_l00008ooooo`;o00006Oooool2o`00013ooooo1?l00004ooooo`;o
00004Oooool2o`0004oooooo000Looooo`;o0000Boooool2o`0000Cooooo0_l000000ooooooo0000
o`000007ooooo`?o00000oooool2o`0000?ooooo0_l0000Eooooo`;o00000_ooool2o`0000?ooooo
1Ol000000ooooooo0000o`00000;o`000003ooooool0003o000000;o00001Oooool3o`0000Wooooo
0_l0000Tooooo`;o00001oooool2o`0000Cooooo0_l00007ooooo`;o00000_ooool2o`0005Gooooo
000Looooo`03o`000?oooooooooo043ooooo0_l00004ooooo`;o000000?oooooo`000?l000003_oo
ool2o`000004ooooool0003o0000o`0000?ooooo0_l00002ooooo`?o00000_ooool2o`0000_ooooo
0_l00008ooooo`;o00001OoooolFo`0000Gooooo0ol00008ooooo`?o00006oooool2o`0000Oooooo
0_l00004ooooo`;o00001Oooool4o`0000Oooooo0_l00002ooooo`;o0000EOooool001cooooo00?o
0000ooooooooool0@?ooool2o`0000Cooooo0_l000000ooooooo0000o`00000<ooooo`Co00001ooo
ool3o`000003ooooool0003o000000?ooooo0_l0000;ooooo`;o00003_oooolFo`00013ooooo1?l0
0004ooooo`;o00005Oooool2o`0000gooooo0ol00004ooooo`Co00001Oooool4o`0001Cooooo0_l0
0013ooooo`007?ooool00ol0003oooooooooo`1Gooooo`;o00002_ooool2o`0000[ooooo0_l00009
ooooo`;o00002OoooolIo`00013ooooo0_l000000ooooooo0000o`000003ooooo`;o00009?ooool3
o`0000gooooo0_l0000Fooooo`;o0000@oooool001cooooo00?o0000ooooooooool0Coooool4o`00
01[ooooo1_l00007ooooo`;o00002OoooolIo`0000Oooooo0_l0000:ooooo`;o00000oooool2o`00
00[ooooo1?l0000Wooooo`;o0000F_ooool001cooooo00?o0000ooooooooool0Coooool4o`0000Wo
oooo0_l0000?ooooo`;o00000_ooool2o`00017ooooo0_l00002ooooo`Ko000000?oooooo`000?l0
00003?l00008ooooo`;o00000oooool2o`0000[ooooo0_l0000:ooooo`Co00001Oooool2o`00023o
oooo0ol00002ooooo`;o0000EOooool001cooooo00?o0000ooooooooool0BOooool2o`000003oooo
ool0003o000000[ooooo0_l000001?oooooo0000o`000?l0000Booooo`;o00000oooool2o`0000go
oooo0ol000000ooooooo0000o`00000@o`0000Sooooo0_l000000ooooooo0000o`000003ooooo`;o
00001_ooool2o`0000Kooooo0_l0000?ooooo`;o00001_ooool3o`0000_ooooo0_l00003ooooo`Co
00001?ooool2o`0000;ooooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`19ooooo`;o0000
00?oooooo`000?l000002_ooool5o`0000kooooo0_l00003ooooo`;o00000oooool2o`0000Wooooo
0_l00003ooooo`;o00000_ooool>o`000003ooooool0003o000000Sooooo0_l000000ooooooo0000
o`00000;ooooo`;o000000?oooooo`000?l000000oooool3o`000003ooooool0003o000000Cooooo
0_l0000:ooooo`;o000000Coooooo`000?l0003o00002oooool2o`0000?ooooo1?l00004ooooo`;o
00001Oooool2o`0005;ooooo000Looooo`03o`000?oooooooooo04cooooo0_l0000<ooooo`;o0000
3oooool2o`0000?ooooo0_l00005ooooo`;o00001oooool2o`000003ooooool0003o000000;o0000
00?oooooo`000?l000004?l00003ooooo`;o00005_ooool2o`0000Cooooo0_l000000ooooooo0000
o`000004ooooo`;o00002_ooool4o`0000Sooooo0_l0000@ooooo`;o00001Oooool2o`0005;ooooo
000Looooo`03o`000?oooooooooo04Cooooo0_l00006ooooo`;o00002?ooool2o`0001kooooo0ol0
0003ooooo`Co00000oooool4o`000003ooooool0003o000000?ooooo3_l00002ooooo`;o00003ooo
ool2o`0000gooooo0_l0000Cooooo`;o00002?ooool4o`0006Wooooo000Looooo`03o`000?oooooo
oooo04Cooooo0_l0000@ooooo`;o00007_ooool2o`0000Cooooo1?l00008ooooo`;o000000Cooooo
o`000?l0003ooooo1?l000000ooooooo0000o`000002o`0000;ooooo0_l00002ooooo`;o00000ooo
ool2o`0000[ooooo0_l00003ooooo`;o00002?ooool3o`0001Oooooo0ol000001?oooooo0000o`00
0?ooool2o`0006Wooooo000Looooo`03o`000?oooooooooo083ooooo0ol00005ooooo`;o000000?o
ooooo`000?l000002_l0000;ooooo`;o000000?oooooo`000?l000000oooool4o`0000Gooooo0_l0
0009ooooo`?o00005_ooool6o`0006cooooo000Looooo`03o`000?oooooooooo06_ooooo0_l0000C
ooooo`?o00001Oooool2o`0000;ooooo0_l000000ooooooo0000o`000003o`0000;ooooo0_l0000:
ooooo`;o000000?oooooo`000?l000000oooool4o`0000kooooo1Ol00009ooooo`;o00002oooool6
o`000003ooooool0003o000000;o0000Ioooool001cooooo00?o0000ooooooooool0E?ooool2o`00
00Oooooo0_l0000<ooooo`;o00000oooool4o`0000Gooooo1?l0000Booooo`;o00000_ooool5o`00
00[ooooo1?l0000Booooo`;o00000_ooool4o`000003ooooool0003o000000Oooooo0_l0000;oooo
o`;o00000_ooool7o`0006Oooooo000Looooo`03o`000?oooooooooo05Cooooo0_l00002ooooo`;o
000000?oooooo`000?l000000_l00008ooooo`;o00001?ooool2o`000003ooooool0003o000000;o
00001Oooool4o`000003ooooool0003o0000017ooooo1_l0000;ooooo`Ko00000oooool4o`0000Wo
oooo0_l00005ooooo`Co00001?ooool2o`0000;ooooo0_l00005ooooo`Co000000?oooooo`000?l0
00001?ooool2o`000003ooooool0003o000006Oooooo000Looooo`03o`000?oooooooooo05Sooooo
0_l000000ooooooo0000o`00000:ooooo`;o00001?ooool6o`0000Gooooo0_l00003ooooo`?o0000
3?ooool2o`000003ooooool0003o000000;o00000_ooool2o`0000_ooooo1_l00003ooooo`Ko0000
3_ooool4o`0000Cooooo0_l00002ooooo`;o00001Oooool4o`0000;ooooo1?l00002ooooo`Co0000
0_ooool2o`0006?ooooo000Looooo`;o0000Doooool2o`0000oooooo0_l0000:ooooo`;o00001ooo
ool2o`0000?ooooo0_l00006ooooo`;o00000_ooool2o`000003ooooool0003o000000?o000000?o
ooooo`000?l000000_l00003ooooo`Co00004_ooool3o`0000gooooo1?l0000Eooooo`Co00000_oo
ool2o`0000Cooooo0_l0001Sooooo`007?ooool00ol0003oooooooooo`1Booooo`;o00003oooool2
o`0000;ooooo0_l00005ooooo`;o00001?ooool2o`0000oooooo0_l00002ooooo`;o00000_ooool3
o`000003ooooool0003o000000?o00000_ooool5o`0000cooooo0_l00004ooooo`?o00000_ooool3
o`0000;ooooo0_l00007ooooo`;o00004_ooool2o`0001?ooooo0_l0001Looooo`007?ooool00ol0
003oooooooooo`1:ooooo`;o00006oooool2o`0000Gooooo0_l00004ooooo`;o00002oooool2o`00
00Cooooo0_l00004ooooo`?o000000?oooooo`000?l000001Oooool4o`0000;ooooo0_l00009oooo
o`;o00001?ooool2o`0000;ooooo1?l00002ooooo`;o00001?ooool5o`0000Oooooo0_l00009oooo
o`Co00004Oooool2o`0005cooooo000Looooo`03o`000?oooooooooo04[ooooo0_l0000Vooooo`;o
00000_ooool2o`0000;ooooo0_l00005ooooo`;o00001?ooool2o`0000;ooooo1?l000000ooooooo
0000o`000005ooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000Co
oooo0ol00009ooooo`;o00002_ooool5o`000003ooooool0003o000000Cooooo1?l00009ooooo`Co
00003oooool2o`0005cooooo000Looooo`03o`000?oooooooooo07;ooooo0_l00002ooooo`;o0000
0_ooool2o`0000oooooo1ol00005ooooo`;o00002?ooool2o`0000;ooooo1Ol0000Kooooo`;o0000
0_ooool2o`0000;ooooo0_l00003ooooo`?o00000oooool4o`0006gooooo000Looooo`03o`000?oo
oooooooo06Sooooo0_l0000Gooooo`;o00002Oooool2o`000004ooooool0003o0000o`0000Cooooo
0_l00003ooooo`Co00001_ooool2o`0001Oooooo0_l00007ooooo`Co00001oooool3o`0000kooooo
0_l0001Tooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00000oooool2o`0001?ooooo0ol0
0006ooooo`;o00003oooool2o`0000?ooooo0_l0000>ooooo`;o00000oooool4o`0000Wooooo0_l0
000Dooooo`;o00001oooool2o`0001Wooooo0ol0001Tooooo`007?ooool00ol0003oooooooooo`1=
ooooo`;o00000oooool2o`0001?ooooo0_l00007ooooo`;o00002Oooool2o`0000;ooooo0_l00005
ooooo`;o00001Oooool2o`0001Wooooo0_l00008ooooo`;o00000_ooool2o`0000[ooooo0_l0000N
ooooo`?o0000I?ooool001cooooo00?o0000ooooooooool0Joooool2o`0000kooooo0_l00002oooo
o`?o00002oooool2o`0000kooooo0_l000000ooooooo0000o`00000@ooooo`;o00000_ooool2o`00
0003ooooool0003o000000Oooooo0_l0000Hooooo`Co0000JOooool001cooooo00?o0000oooooooo
ool0Joooool2o`0000kooooo1?l000000ooooooo0000o`00000Eooooo`;o00001?ooool2o`000003
ooooool0003o000000;o00003_ooool3o`0000;ooooo1?l00003ooooo`;o00002oooool2o`000003
ooooool0003o000000cooooo1?l0001Yooooo`007?ooool00ol0003oooooooooo`1mooooo`;o0000
1oooool2o`0000?ooooo0_l0000:ooooo`;o00002Oooool2o`0000kooooo0ol00002ooooo`Co0000
0oooool2o`0000_ooooo0_l000000ooooooo0000o`00001iooooo`007?ooool00ol0003ooooooooo
o`21ooooo`;o00000oooool3o`0000;ooooo0_l0000Cooooo`;o00003Oooool5o`0000;ooooo0_l0
000Cooooo`;o00002_ooool2o`00073ooooo000Looooo`03o`000?oooooooooo087ooooo0ol00003
ooooo`;o00000_ooool6o`0000oooooo0_l000000ooooooo0000o`00000:ooooo`?o00000_ooool4
o`0001Wooooo0ol00003ooooo`;o0000L?ooool001cooooo00?o0000ooooooooool0OOooool2o`00
00?ooooo0_l00009ooooo`Co00004_ooool2o`0000?ooooo0_l0000:ooooo`?o00006_ooool5o`00
07?ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1mooooo`?o00000_ooool2o`0000Sooooo0_l0
000Aooooo`;o00001oooool2o`0001Sooooo0_l00004ooooo`;o00002Oooool3o`0007?ooooo0000
1_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ
8B401_ooool00ol0003oooooooooo`1Jooooo`;o00006oooool2o`0000Cooooo0ol00009ooooo`;o
000000?oooooo`000?l000000_l00005ooooo`;o00000_ooool2o`0000Cooooo0_l0000Jooooo`;o
00001Oooool2o`0000Cooooo0_l00003ooooo`Co00000_ooool2o`0000Kooooo0_l0001/ooooo`00
00?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`1Jooooo`;o00006oooool2o`000003ooooool0003o000000go
oooo0_l00003ooooo`;o00001Oooool2o`0000;ooooo0_l0000Hooooo`;o00001_ooool2o`0000Go
oooo0_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000000_l00006ooooo`;o
00000_ooool2o`0006cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo
00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000N_ooool2o`0000Kooooo0_l00002ooooo`;o
00003Oooool2o`0001Kooooo0_l00004ooooo`;o00004?ooool3o`000004ooooool0003o0000o`00
00;ooooo1?l00005ooooo`;o0000L?ooool00003ooooool0003ooooo00;ooooo00?o0000oooooooo
ool02Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0Ioooool2o`00
01Wooooo0_l00002ooooo`;o00003Oooool2o`0000Gooooo0_l0000>ooooo`Go00001?ooool2o`00
00Gooooo0_l00003ooooo`;o00000oooool5o`0000Gooooo0_l00003ooooo`;o0000L_ooool00003
ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol@413o^[Zjoooooonj^[[o410@
00Kooooo00?o0000ooooooooool0Ioooool2o`0001gooooo0_l000000ooooooo0000o`00000:oooo
o`;o00001Oooool2o`0000;ooooo0_l00007ooooo`;o000000Coooooo`000?l0003ooooo0_l00004
ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l00005ooooo`;o00002oooool2
o`0007;ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zj
o`000006ooooo`03o`000?oooooooooo08Wooooo0ol0000Dooooo`;o00001oooool2o`0000Cooooo
0_l00002ooooo`;o00000oooool2o`0000Oooooo0_l00026ooooo`0000Koooooonk^k_lb<S;o0000
oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`2:oooo
o`;o00000_ooool2o`000003ooooool0003o0000023ooooo0_l00002ooooo`;o00002?ooool2o`00
08Kooooo000Looooo`03o`000?oooooooooo08kooooo0_l000000ooooooo0000o`00000Kooooo`;o
00001oooool2o`0000Gooooo1?l00004ooooo`;o0000POooool001cooooo00?o0000ooooooooool0
GOooool2o`0002[ooooo0_l00003ooooo`?o00002_ooool2o`0000Oooooo0_l00008ooooo`;o0000
2_ooool2o`0000;ooooo1?l00004ooooo`;o00002oooool2o`0007Cooooo000Looooo`03o`000?oo
oooooooo05gooooo0_l0000Mooooo`;o00002oooool2o`0000Cooooo0_l00007ooooo`;o000000?o
ooooo`000?l000001Oooool4o`0001Cooooo0_l0000Gooooo`;o0000M?ooool001cooooo00?o0000
ooooooooool0L_ooool2o`0000Sooooo0_l00006ooooo`;o00004Oooool3o`0000Sooooo0_l0000;
ooooo`;o000000?oooooo`000?l00000UOooool001cooooo00?o0000ooooooooool0L_ooool2o`00
013ooooo0_l00008ooooo`;o00001oooool2o`00013ooooo0_l00004ooooo`;o000000?oooooo`00
0?l000003Oooool2o`0008Kooooo000Looooo`03o`000?oooooooooo08?ooooo0_l00005ooooo`;o
00000_ooool2o`0000Oooooo0_l000000ooooooo0000o`00000<ooooo`?o00001?ooool2o`0000oo
oooo0ol00026ooooo`007?ooool00ol0003oooooooooo`1[ooooo`;o00005_ooool2o`0000Gooooo
0_l0000>ooooo`;o00003?ooool2o`0000Gooooo0_l0000?ooooo`;o00002_ooool2o`0007_ooooo
000Looooo`03o`000?oooooooooo06_ooooo0_l0000Cooooo`;o00002?ooool2o`00043ooooo0_l0
001kooooo`007?ooool00ol0003oooooooooo`1mooooo`;o000000?oooooo`000?l00000aoooool0
01cooooo00?o0000ooooooooool0OOooool2o`0000oooooo0_l0000Wooooo`;o0000T?ooool001co
oooo00?o0000ooooooooool0R_ooool2o`0000;ooooo0_l0000Wooooo`;o0000T?ooool001cooooo
0_l0002;ooooo`;o0000_Oooool001cooooo00?o0000ooooooooool0Xoooool2o`000:Cooooo000L
ooooo`03o`000?oooooooooo0:?ooooo0_l0002Tooooo`007?ooool00ol0003oooooooooo`28oooo
o`;o00006Oooool2o`000:Cooooo000Looooo`03o`000?oooooooooo08Sooooo0_l0000Rooooo`;o
0000Voooool001cooooo00?o0000ooooooooool0TOooool2o`0001Wooooo0_l0002Kooooo`007?oo
ool00ol0003oooooooooo`2Aooooo`;o0000]_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo0_l0002Zooooo`;o0000W_ooool001cooooo00?o0000
ooooooooool0ZOooool2o`0009kooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0V_ooool2o`000:gooooo000Looooo`03o`000?oooooooooo09[ooooo
0_l0002]ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001;ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oo
oooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
oooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo0ol0003ooooood[ooooo000Dooooo`03
o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?oo
ool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool0
01;ooooo00?oEEEEofIVI_l00000oooooomDooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00XOooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo01Kooooo1?l0
00000ol@413oooooooooo`05o`0000?ooooo00Co410@o`000?m4A4Coc<c<1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<08cooooo002Rooooo`05o`000?ooooooooooooooool000002Oooool6o`0000co
oooo00?o0000ooooooooool00_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo00?oV9RHoa0@
4?oMgMd00oooool01OmEEEGoMgMgoooooonHV9So8B4Q08cooooo002Rooooo`05o`000?oooooooooo
ooooool000006oooool00ol0003oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oQhN7
oeEEEOooool00_ooool01Ol0003ooooooooooooooooo000008cooooo002Rooooo`05o`000?oooooo
ooooooooool000002Oooool6o`0000cooooo00?o0000ooooooooool01?ooool00onHV9So8B4Qonk^
kP03ooooo`05olc<c?lQ8B7o0000oeEEEOl000000oooool01Ol0003oV9RHoooooonHV9So8B4Q08co
oooo002Rooooo`05o`000?n7QhOoooooojVYZOl000006oooool00ol0003oooooooooo`05ooooo`03
ogMgMomVIVKooooo00;ooooo00Go8B4QohN7QoooooooV9RHo`000003ooooo`05o`000?mEEEGo0000
oa0@4?o<c<`0S?ooool00:7ooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Ioooo
o`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000003ooooo`06o`000?oooooo
oooooooooomEEEGoQhN7Soooool00<;ooooo00?o0000ooooooooool00_ooool01Ol0003o^[Zjoooo
oonHV9So410@00?ooooo00Go8B4QoiRHV?ooooooMgMgoeEEE@03ooooo`03omgMgOl@413oV9RH08ko
oooo0030ooooo`03oeEEEOmVIVKo000000Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05
olc<c?l@413o0000oc8b<_o^k^h01?ooool01?o<c<coA4A4o`000?l@412<ooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1302) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.45306 .69222 Mdot
.4499 .67441 Mdot
.64975 .45376 Mdot
.36491 .48604 Mdot
.7608 .35697 Mdot
.63441 .42365 Mdot
.59405 .63459 Mdot
.6499 .60716 Mdot
.63224 .4605 Mdot
.63039 .70046 Mdot
.62958 .59522 Mdot
.33721 .53069 Mdot
.63215 .62686 Mdot
.38691 .45711 Mdot
.73037 .24135 Mdot
.33521 .4799 Mdot
.45332 .68418 Mdot
.49032 .28255 Mdot
.377 .53459 Mdot
.67459 .43882 Mdot
.44365 .72078 Mdot
.38667 .46572 Mdot
.40859 .64691 Mdot
.38724 .45642 Mdot
.37947 .50715 Mdot
.40499 .67645 Mdot
.45592 .62516 Mdot
.40411 .50823 Mdot
.42482 .4961 Mdot
.64734 .59994 Mdot
.38097 .30334 Mdot
.73559 .27334 Mdot
.4397 .41677 Mdot
.51862 .20697 Mdot
.64484 .63763 Mdot
.29842 .65088 Mdot
.63733 .43599 Mdot
.6172 .61496 Mdot
.61239 .61542 Mdot
.64371 .6462 Mdot
.62747 .60566 Mdot
.41355 .65252 Mdot
.53267 .65763 Mdot
.70518 .40013 Mdot
.34701 .45162 Mdot
.79571 .4967 Mdot
.35534 .74832 Mdot
.41455 .43725 Mdot
.43215 .69959 Mdot
.59374 .28531 Mdot
.73529 .49958 Mdot
.61098 .64391 Mdot
.67919 .441 Mdot
.11289 .56015 Mdot
.61981 .63657 Mdot
.43479 .53063 Mdot
.64143 .44605 Mdot
.3986 .46842 Mdot
.39058 .45315 Mdot
.25498 .51199 Mdot
.37886 .43115 Mdot
.49888 .30158 Mdot
.41246 .61542 Mdot
.55602 .56905 Mdot
.6293 .4516 Mdot
.61435 .60421 Mdot
.44322 .66566 Mdot
.63297 .63344 Mdot
.42196 .5639 Mdot
.66433 .41127 Mdot
.41566 .43612 Mdot
.62447 .59759 Mdot
.45083 .63092 Mdot
.42287 .48116 Mdot
.59633 .36662 Mdot
.81271 .59698 Mdot
.53742 .30643 Mdot
.28593 .61872 Mdot
.24854 .50758 Mdot
.6337 .31815 Mdot
.37108 .52128 Mdot
.42623 .339 Mdot
.80946 .56783 Mdot
.39471 .67506 Mdot
.33175 .45489 Mdot
.51737 .25992 Mdot
.41927 .48404 Mdot
.81794 .48558 Mdot
.42764 .43253 Mdot
.55926 .31555 Mdot
.62624 .46397 Mdot
.43015 .68121 Mdot
.36346 .48929 Mdot
.43063 .47345 Mdot
.2447 .4607 Mdot
.43661 .5077 Mdot
.38856 .48584 Mdot
.42017 .70632 Mdot
.61254 .64334 Mdot
.45158 .47436 Mdot
.7085 .4244 Mdot
.63183 .47403 Mdot
.35102 .47375 Mdot
.60125 .43173 Mdot
.42624 .6184 Mdot
.4296 .47115 Mdot
.60977 .62279 Mdot
.36063 .4549 Mdot
.52806 .78914 Mdot
.45287 .66615 Mdot
.4125 .50669 Mdot
.49879 .35094 Mdot
.20248 .54014 Mdot
.43128 .69064 Mdot
.71297 .44011 Mdot
.40389 .52895 Mdot
.39824 .48514 Mdot
.44616 .67765 Mdot
.60148 .45684 Mdot
.8186 .50255 Mdot
.4047 .70438 Mdot
.65821 .61711 Mdot
.46179 .67734 Mdot
.35552 .54128 Mdot
.61944 .44516 Mdot
.73209 .43679 Mdot
.51844 .76058 Mdot
.40861 .28094 Mdot
.41789 .4816 Mdot
.55799 .67928 Mdot
.65664 .47308 Mdot
.43058 .66997 Mdot
.6374 .62934 Mdot
.35566 .42159 Mdot
.43959 .64023 Mdot
.63458 .59132 Mdot
.4914 .34098 Mdot
.70613 .55514 Mdot
.43038 .62569 Mdot
.51999 .42438 Mdot
.60322 .60168 Mdot
.62443 .65059 Mdot
.41921 .19476 Mdot
.44044 .66696 Mdot
.50355 .31264 Mdot
.64509 .62333 Mdot
.39475 .26892 Mdot
.3512 .44893 Mdot
.38351 .34375 Mdot
.3644 .77485 Mdot
.4961 .20217 Mdot
.72427 .57623 Mdot
.52098 .33141 Mdot
.64181 .58348 Mdot
.3786 .49693 Mdot
.40803 .68754 Mdot
.40435 .66201 Mdot
.37535 .43413 Mdot
.36953 .50919 Mdot
.42087 .43604 Mdot
.43351 .45504 Mdot
.3063 .52139 Mdot
.41082 .53335 Mdot
.30294 .71626 Mdot
.4265 .68364 Mdot
.37016 .48988 Mdot
.64342 .40933 Mdot
.43779 .42707 Mdot
.62588 .60132 Mdot
.39286 .47123 Mdot
.36509 .48896 Mdot
.36357 .43933 Mdot
.61586 .64644 Mdot
.77798 .31651 Mdot
.20967 .58062 Mdot
.74928 .30462 Mdot
.55286 .37078 Mdot
.62112 .41239 Mdot
.41071 .49203 Mdot
.49267 .31985 Mdot
.33603 .63734 Mdot
.36451 .46858 Mdot
.40355 .85358 Mdot
.38587 .47855 Mdot
.76309 .34387 Mdot
.44285 .52895 Mdot
.66947 .23912 Mdot
.41356 .32893 Mdot
.3881 .50385 Mdot
.52517 .63075 Mdot
.65894 .57606 Mdot
.59372 .46556 Mdot
.62868 .60967 Mdot
.64817 .41149 Mdot
.64809 .45043 Mdot
.55261 .59682 Mdot
.31712 .4984 Mdot
.45443 .43521 Mdot
.4382 .44767 Mdot
.6507 .39904 Mdot
.40628 .62715 Mdot
.48312 .32958 Mdot
.43651 .71215 Mdot
.86623 .45679 Mdot
.76831 .47479 Mdot
.5915 .65094 Mdot
.49457 .29413 Mdot
.64757 .4679 Mdot
.61271 .45784 Mdot
.50878 .35048 Mdot
.41397 .45304 Mdot
.43614 .66036 Mdot
.46707 .179 Mdot
.57861 .78308 Mdot
.38246 .1853 Mdot
.42068 .70453 Mdot
.60464 .70895 Mdot
.64175 .59935 Mdot
.65097 .43234 Mdot
.39546 .48606 Mdot
.41442 .46053 Mdot
.42025 .73199 Mdot
.423 .43872 Mdot
.47687 .69058 Mdot
.39409 .49519 Mdot
.6861 .52037 Mdot
.51434 .27591 Mdot
.55455 .59283 Mdot
.43467 .26322 Mdot
.39746 .6793 Mdot
.26256 .37892 Mdot
.60385 .43648 Mdot
.32952 .62897 Mdot
.61449 .59967 Mdot
.48798 .32044 Mdot
.61039 .44192 Mdot
.48844 .34416 Mdot
.39904 .53859 Mdot
.66026 .4185 Mdot
.51834 .34839 Mdot
.31733 .40114 Mdot
.37195 .42571 Mdot
.46333 .79271 Mdot
.64936 .63842 Mdot
.42912 .71922 Mdot
.38612 .42829 Mdot
.61253 .41295 Mdot
.384 .4044 Mdot
.74395 .61642 Mdot
.69986 .49593 Mdot
.63827 .47698 Mdot
.67445 .50554 Mdot
.49492 .30164 Mdot
.76011 .54767 Mdot
.57981 .69994 Mdot
.4505 .68993 Mdot
.43277 .51436 Mdot
.64542 .21993 Mdot
.64456 .62435 Mdot
.3714 .44446 Mdot
.59454 .24263 Mdot
.63626 .63845 Mdot
.40062 .46893 Mdot
.64561 .59224 Mdot
.4048 .6601 Mdot
.21699 .49374 Mdot
.44573 .69275 Mdot
.43592 .45135 Mdot
.6102 .62898 Mdot
.60726 .41023 Mdot
.40874 .67682 Mdot
.41093 .44623 Mdot
.40562 .50462 Mdot
.59722 .52205 Mdot
.376 .48634 Mdot
.77591 .33022 Mdot
.39128 .50006 Mdot
.65772 .44106 Mdot
.35013 .50283 Mdot
.16489 .56389 Mdot
.55197 .61782 Mdot
.44164 .66473 Mdot
.60881 .4698 Mdot
.63647 .45648 Mdot
.70182 .38524 Mdot
.62245 .66523 Mdot
.39686 .5317 Mdot
.61505 .41349 Mdot
.29438 .37456 Mdot
.61245 .59377 Mdot
.45086 .44495 Mdot
.51858 .45547 Mdot
.58343 .28784 Mdot
.67898 .44394 Mdot
.39774 .39506 Mdot
.42503 .62266 Mdot
.36332 .49505 Mdot
.6083 .45643 Mdot
.3155 .45484 Mdot
.4032 .52221 Mdot
.43535 .74998 Mdot
.60371 .52622 Mdot
.59543 .62054 Mdot
.45054 .51139 Mdot
.38201 .43858 Mdot
.64861 .41503 Mdot
.39985 .68394 Mdot
.61254 .5923 Mdot
.40965 .66112 Mdot
.6273 .22412 Mdot
.47775 .79039 Mdot
.29552 .42462 Mdot
.48531 .30016 Mdot
.57049 .2571 Mdot
.64035 .22503 Mdot
.23286 .37843 Mdot
.29281 .34032 Mdot
.53791 .1913 Mdot
.59856 .44437 Mdot
.59602 .25119 Mdot
.64044 .45223 Mdot
.37968 .51658 Mdot
.62127 .44478 Mdot
.63244 .2142 Mdot
.39265 .49355 Mdot
.62512 .43812 Mdot
.24897 .40877 Mdot
.3668 .49686 Mdot
.44992 .68432 Mdot
.83024 .41507 Mdot
.18115 .45813 Mdot
.69179 .50453 Mdot
.66899 .44451 Mdot
.32769 .299 Mdot
.38659 .48697 Mdot
.35281 .50651 Mdot
.41766 .69257 Mdot
.4141 .40174 Mdot
.51594 .3011 Mdot
.50122 .29171 Mdot
.67387 .66303 Mdot
.45851 .37968 Mdot
.44155 .52777 Mdot
.41074 .68064 Mdot
.33231 .54929 Mdot
.58512 .35807 Mdot
.59568 .27872 Mdot
.60101 .59375 Mdot
.82739 .41251 Mdot
.47763 .65428 Mdot
.60922 .56504 Mdot
.6029 .48585 Mdot
.44047 .68762 Mdot
.76585 .29908 Mdot
.62587 .61342 Mdot
.47032 .80918 Mdot
.48227 .54874 Mdot
.41117 .45386 Mdot
.6022 .61193 Mdot
.34092 .42578 Mdot
.18484 .44131 Mdot
.54506 .82219 Mdot
.48706 .48568 Mdot
.42743 .43068 Mdot
.57375 .37498 Mdot
.39457 .47707 Mdot
.78694 .57254 Mdot
.39433 .50348 Mdot
.41152 .66445 Mdot
.64744 .69711 Mdot
.66424 .65228 Mdot
.23135 .65309 Mdot
.7689 .56237 Mdot
.52185 .32995 Mdot
.39752 .49211 Mdot
.40934 .45219 Mdot
.52123 .30908 Mdot
.4125 .63702 Mdot
.43198 .44347 Mdot
.26443 .36697 Mdot
.42897 .46483 Mdot
.62224 .60689 Mdot
.46162 .5664 Mdot
.4102 .75196 Mdot
.43864 .47853 Mdot
.42982 .61212 Mdot
.5927 .64566 Mdot
.61363 .62945 Mdot
.43104 .54451 Mdot
.65008 .64229 Mdot
.3801 .47433 Mdot
.57586 .82237 Mdot
.43733 .62787 Mdot
.48601 .71145 Mdot
.4299 .64349 Mdot
.27361 .60731 Mdot
.62599 .64391 Mdot
.71056 .51557 Mdot
.31991 .46883 Mdot
.6272 .61732 Mdot
.39571 .7417 Mdot
.33844 .48095 Mdot
.3616 .42785 Mdot
.41925 .21288 Mdot
.6629 .45145 Mdot
.60615 .53193 Mdot
.64899 .60134 Mdot
.40017 .43926 Mdot
.43045 .50698 Mdot
.59549 .65005 Mdot
.57865 .80466 Mdot
.20632 .44508 Mdot
.39218 .49737 Mdot
.4181 .66902 Mdot
.42812 .66618 Mdot
.39669 .41837 Mdot
.35292 .48552 Mdot
.61588 .43392 Mdot
.59666 .42295 Mdot
.66063 .4123 Mdot
.61308 .53237 Mdot
.70685 .5137 Mdot
.76613 .41109 Mdot
.64307 .64672 Mdot
.58218 .72715 Mdot
.55493 .29983 Mdot
.44332 .45993 Mdot
.66789 .45845 Mdot
.37926 .44294 Mdot
.37204 .4745 Mdot
.60229 .6629 Mdot
.69249 .3031 Mdot
.46602 .69556 Mdot
.40163 .64673 Mdot
.61435 .58633 Mdot
.39435 .56964 Mdot
.57495 .60712 Mdot
.49154 .33475 Mdot
.45922 .20478 Mdot
.61835 .59856 Mdot
.44859 .68429 Mdot
.65225 .62774 Mdot
.4201 .46258 Mdot
.39672 .54503 Mdot
.44059 .68147 Mdot
.52852 .30961 Mdot
.39459 .40392 Mdot
.40176 .47223 Mdot
.34794 .77707 Mdot
.44036 .22521 Mdot
.67187 .5345 Mdot
.38818 .50179 Mdot
.43334 .49172 Mdot
.52395 .35192 Mdot
.42733 .46323 Mdot
.4086 .42901 Mdot
.21056 .54241 Mdot
.53446 .76272 Mdot
.5026 .28707 Mdot
.58896 .81136 Mdot
.42426 .70442 Mdot
.69135 .24388 Mdot
.6527 .42495 Mdot
.64543 .68382 Mdot
.19685 .47657 Mdot
.67873 .43668 Mdot
.72448 .58338 Mdot
.71593 .26351 Mdot
.62161 .54006 Mdot
.59706 .39474 Mdot
.4655 .63646 Mdot
.43221 .44839 Mdot
.40028 .48133 Mdot
.49578 .30975 Mdot
.43129 .65606 Mdot
.58094 .52567 Mdot
.73986 .71068 Mdot
.38702 .46958 Mdot
.48654 .69148 Mdot
.68155 .72925 Mdot
.5848 .29452 Mdot
.50475 .33265 Mdot
.51498 .29211 Mdot
.39974 .48989 Mdot
.19995 .56252 Mdot
.4056 .67835 Mdot
.40952 .44553 Mdot
.41736 .52846 Mdot
.66636 .44575 Mdot
.45137 .65083 Mdot
.60505 .46125 Mdot
.73164 .51648 Mdot
.75301 .31592 Mdot
.38711 .816 Mdot
.61927 .63976 Mdot
.77263 .62693 Mdot
.63563 .58616 Mdot
.43204 .33484 Mdot
.66763 .47151 Mdot
.35857 .49032 Mdot
.39848 .67747 Mdot
.39313 .43934 Mdot
.35451 .48928 Mdot
.41206 .45193 Mdot
.44054 .48433 Mdot
.30474 .7863 Mdot
.51987 .34185 Mdot
.33796 .50999 Mdot
.65654 .44616 Mdot
.80804 .53161 Mdot
.80404 .60195 Mdot
.40484 .45171 Mdot
.40223 .50083 Mdot
.43388 .6311 Mdot
.37444 .43657 Mdot
.62854 .5856 Mdot
.41451 .71339 Mdot
.42622 .48271 Mdot
.83357 .44411 Mdot
.41959 .50248 Mdot
.70561 .26554 Mdot
.65269 .62081 Mdot
.53917 .79158 Mdot
.3498 .53078 Mdot
.6829 .50845 Mdot
.60575 .53171 Mdot
.61249 .43871 Mdot
.66111 .60925 Mdot
.63492 .43712 Mdot
.71588 .73683 Mdot
.39771 .54849 Mdot
.37797 .4998 Mdot
.44699 .47614 Mdot
.62202 .41176 Mdot
.81288 .46111 Mdot
.76784 .52439 Mdot
.34667 .53198 Mdot
.62496 .41449 Mdot
.41986 .61383 Mdot
.40371 .24061 Mdot
.42135 .64374 Mdot
.48037 .33698 Mdot
.63485 .59927 Mdot
.52385 .30353 Mdot
.58191 .22995 Mdot
.45196 .67156 Mdot
.43974 .71814 Mdot
.64897 .42529 Mdot
.49204 .54596 Mdot
.1771 .35681 Mdot
.48327 .55157 Mdot
.41439 .30611 Mdot
.41666 .68706 Mdot
.42988 .48955 Mdot
.45242 .33427 Mdot
.49728 .57553 Mdot
.63334 .43958 Mdot
.37031 .46449 Mdot
.21502 .4878 Mdot
.61571 .43393 Mdot
.44818 .48022 Mdot
.65878 .45028 Mdot
.63335 .60574 Mdot
.65978 .46535 Mdot
.40068 .72038 Mdot
.4166 .4937 Mdot
.21782 .29369 Mdot
.49611 .26626 Mdot
.38486 .49137 Mdot
.61234 .58661 Mdot
.70355 .63349 Mdot
.35919 .4658 Mdot
.50105 .35647 Mdot
.62372 .42703 Mdot
.49373 .51423 Mdot
.39302 .49988 Mdot
.6289 .41194 Mdot
.45445 .691 Mdot
.65286 .58969 Mdot
.24871 .4757 Mdot
.66331 .5223 Mdot
.41767 .69417 Mdot
.53104 .3984 Mdot
.6592 .63446 Mdot
.43416 .49077 Mdot
.43357 .51164 Mdot
.42054 .66636 Mdot
.33477 .37375 Mdot
.34716 .47787 Mdot
.36941 .51938 Mdot
.6613 .43709 Mdot
.63193 .43414 Mdot
.26236 .4241 Mdot
.59494 .44129 Mdot
.39466 .54514 Mdot
.41928 .66409 Mdot
.36288 .48601 Mdot
.44149 .63346 Mdot
.37239 .4388 Mdot
.31325 .50366 Mdot
.41101 .63874 Mdot
.56535 .59746 Mdot
.3699 .46967 Mdot
.44996 .42587 Mdot
.36358 .45255 Mdot
.42953 .4475 Mdot
.61594 .44293 Mdot
.4975 .33408 Mdot
.43101 .52376 Mdot
.51736 .36562 Mdot
.48742 .34067 Mdot
.67189 .6279 Mdot
.66572 .44862 Mdot
.51171 .31177 Mdot
.68985 .72999 Mdot
.66391 .41837 Mdot
.50519 .3015 Mdot
.80441 .59924 Mdot
.64119 .64097 Mdot
.43069 .62321 Mdot
.36715 .49989 Mdot
.58511 .21921 Mdot
.35603 .7517 Mdot
.589 .42844 Mdot
.38945 .498 Mdot
.36994 .44833 Mdot
.39814 .6941 Mdot
.73254 .74041 Mdot
.66374 .41097 Mdot
.40984 .51809 Mdot
.44737 .66435 Mdot
.71157 .77767 Mdot
.65243 .44359 Mdot
.50098 .30296 Mdot
.6353 .64813 Mdot
.41643 .74347 Mdot
.51639 .7614 Mdot
.59373 .62962 Mdot
.58235 .4642 Mdot
.72951 .50351 Mdot
.40556 .52908 Mdot
.66791 .46147 Mdot
.38893 .19702 Mdot
.37503 .58682 Mdot
.56988 .56511 Mdot
.33493 .29076 Mdot
.43694 .68864 Mdot
.63272 .58599 Mdot
.52091 .33583 Mdot
.4167 .70285 Mdot
.45377 .68015 Mdot
.60251 .65526 Mdot
.22019 .57715 Mdot
.51733 .45879 Mdot
.6158 .61084 Mdot
.48097 .22716 Mdot
.73687 .37641 Mdot
.66927 .45694 Mdot
.51607 .30169 Mdot
.60041 .23621 Mdot
.41178 .65424 Mdot
.82656 .39778 Mdot
.42544 .205 Mdot
.38841 .48566 Mdot
.51015 .31573 Mdot
.79827 .43864 Mdot
.77632 .68212 Mdot
.63174 .6403 Mdot
.67205 .64766 Mdot
.50977 .2961 Mdot
.38508 .42934 Mdot
.39728 .2527 Mdot
.36874 .51669 Mdot
.63945 .60063 Mdot
.26059 .48536 Mdot
.45274 .67897 Mdot
.61513 .65508 Mdot
.45505 .20316 Mdot
.38079 .47241 Mdot
.36853 .46942 Mdot
.4512 .26131 Mdot
.40579 .69782 Mdot
.61231 .43804 Mdot
.40971 .52998 Mdot
.39819 .47228 Mdot
.42401 .53668 Mdot
.45412 .49792 Mdot
.2056 .52276 Mdot
.38761 .51451 Mdot
.7813 .504 Mdot
.42857 .43018 Mdot
.37681 .46231 Mdot
.42984 .61382 Mdot
.3863 .82225 Mdot
.74417 .51088 Mdot
.39468 .47233 Mdot
.42585 .49954 Mdot
.62117 .65487 Mdot
.50733 .52043 Mdot
.49749 .53067 Mdot
.49615 .50358 Mdot
.31052 .31879 Mdot
.39159 .41552 Mdot
.43951 .65737 Mdot
.51679 .35126 Mdot
.40811 .52277 Mdot
.44254 .6589 Mdot
.35315 .44945 Mdot
.61557 .43047 Mdot
.6626 .41721 Mdot
.37277 .57923 Mdot
.51635 .3148 Mdot
.48371 .62306 Mdot
.57438 .72757 Mdot
.65299 .41474 Mdot
.37755 .50246 Mdot
.6002 .66623 Mdot
.60905 .45617 Mdot
.69229 .49069 Mdot
.35321 .3805 Mdot
.40449 .68505 Mdot
.42894 .68392 Mdot
.37983 .34629 Mdot
.7255 .56122 Mdot
.26838 .71719 Mdot
.63406 .60446 Mdot
.36501 .53343 Mdot
.57257 .68463 Mdot
.42932 .68739 Mdot
.44535 .32833 Mdot
.51298 .3153 Mdot
.63833 .63778 Mdot
.57758 .39613 Mdot
.43629 .63549 Mdot
.45763 .67157 Mdot
.41667 .42411 Mdot
.40565 .46492 Mdot
.28671 .34992 Mdot
.4945 .37309 Mdot
.59256 .63053 Mdot
.51182 .29934 Mdot
.6676 .47101 Mdot
.39493 .51811 Mdot
.40711 .64727 Mdot
.73492 .38547 Mdot
.41347 .51814 Mdot
.61853 .45635 Mdot
.43514 .68506 Mdot
.49664 .29964 Mdot
.50197 .35881 Mdot
.43035 .45236 Mdot
.29168 .52337 Mdot
.61909 .61924 Mdot
.44331 .68953 Mdot
.57503 .59931 Mdot
.35212 .50149 Mdot
.40973 .47166 Mdot
.45783 .51006 Mdot
.59225 .62931 Mdot
.62893 .73936 Mdot
.48154 .32089 Mdot
.43322 .66175 Mdot
.39362 .51125 Mdot
.51425 .3044 Mdot
.60777 .72178 Mdot
.64435 .4772 Mdot
.65596 .4668 Mdot
.50669 .35902 Mdot
.5075 .3253 Mdot
.49393 .35028 Mdot
.82704 .3972 Mdot
.3932 .68872 Mdot
.47693 .65543 Mdot
.34985 .50982 Mdot
.41124 .32259 Mdot
.32473 .46128 Mdot
.60735 .59628 Mdot
.66025 .45413 Mdot
.35482 .47242 Mdot
.43603 .47074 Mdot
.41922 .55918 Mdot
.47752 .71659 Mdot
.40567 .74938 Mdot
.45342 .66106 Mdot
.37824 .54577 Mdot
.66625 .43733 Mdot
.87164 .45733 Mdot
.48991 .1576 Mdot
.35327 .53348 Mdot
.51251 .45234 Mdot
.40399 .65043 Mdot
.63416 .6529 Mdot
.4801 .25667 Mdot
.64239 .6419 Mdot
.43409 .66589 Mdot
.38963 .51586 Mdot
.58249 .7354 Mdot
.51773 .35872 Mdot
.4105 .43922 Mdot
.64552 .60507 Mdot
.41159 .43537 Mdot
.5936 .63191 Mdot
.63922 .23176 Mdot
.34093 .24878 Mdot
.38659 .47952 Mdot
.32833 .47356 Mdot
.31298 .29928 Mdot
.40146 .44857 Mdot
.47784 .35253 Mdot
.40406 .64984 Mdot
.24915 .45112 Mdot
.34322 .44898 Mdot
.35134 .58836 Mdot
.35679 .50923 Mdot
.23715 .43792 Mdot
.4114 .46871 Mdot
.58101 .30335 Mdot
.41376 .50288 Mdot
.41992 .43242 Mdot
.61355 .63604 Mdot
.61619 .65465 Mdot
.44796 .62515 Mdot
.60825 .41675 Mdot
.72768 .2826 Mdot
.40477 .47273 Mdot
.70838 .48565 Mdot
.57311 .75952 Mdot
.50719 .32784 Mdot
.43027 .66092 Mdot
.76694 .71577 Mdot
.6528 .60371 Mdot
.39622 .22131 Mdot
.26622 .41029 Mdot
.52067 .71624 Mdot
.50717 .25337 Mdot
.70004 .68071 Mdot
.49016 .30695 Mdot
.36154 .44192 Mdot
.71745 .34434 Mdot
.57651 .31864 Mdot
.34068 .38436 Mdot
.66134 .63277 Mdot
.34004 .61626 Mdot
.70545 .31845 Mdot
.48994 .35617 Mdot
.51108 .29347 Mdot
.6056 .64194 Mdot
.62383 .38342 Mdot
.32387 .51169 Mdot
.51358 .3201 Mdot
.63775 .40664 Mdot
.66963 .42555 Mdot
.67492 .42347 Mdot
.40358 .67256 Mdot
.44548 .18741 Mdot
.57632 .63527 Mdot
.59678 .61829 Mdot
.67771 .40307 Mdot
.40244 .60798 Mdot
.39962 .70995 Mdot
.64495 .43087 Mdot
.63089 .46984 Mdot
.4099 .63679 Mdot
.43196 .53726 Mdot
.39667 .55677 Mdot
.39024 .47153 Mdot
.49325 .32629 Mdot
.4108 .46327 Mdot
.62229 .41829 Mdot
.62887 .63853 Mdot
.63828 .46937 Mdot
.62193 .57909 Mdot
.77239 .43085 Mdot
.41821 .44753 Mdot
.41425 .49825 Mdot
.38718 .78718 Mdot
.46005 .67733 Mdot
.78414 .47944 Mdot
.65121 .53313 Mdot
.64348 .45155 Mdot
.4039 .42835 Mdot
.41513 .71451 Mdot
.50468 .37004 Mdot
.41532 .81143 Mdot
.35075 .48188 Mdot
.41474 .6423 Mdot
.39714 .51566 Mdot
.29504 .50687 Mdot
.17907 .60106 Mdot
.41545 .65689 Mdot
.36258 .77182 Mdot
.42459 .49849 Mdot
.72022 .68597 Mdot
.44906 .44399 Mdot
.3215 .36142 Mdot
.34719 .47821 Mdot
.42277 .70495 Mdot
.39211 .46798 Mdot
.42156 .71541 Mdot
.65352 .41806 Mdot
.63308 .65213 Mdot
.42145 .69199 Mdot
.44015 .49742 Mdot
.2611 .20182 Mdot
.6409 .60777 Mdot
.39679 .48876 Mdot
.62227 .64627 Mdot
.43074 .65191 Mdot
.43089 .69835 Mdot
.77485 .67131 Mdot
.73359 .51961 Mdot
.63325 .60728 Mdot
.39576 .51742 Mdot
.74363 .63811 Mdot
.36356 .50443 Mdot
.31215 .34514 Mdot
.43723 .52639 Mdot
.3496 .50449 Mdot
.80756 .60488 Mdot
.59586 .61787 Mdot
.2536 .70371 Mdot
.79807 .64615 Mdot
.8086 .53678 Mdot
.43006 .72981 Mdot
.49359 .36126 Mdot
.77184 .30628 Mdot
.70692 .51588 Mdot
.62556 .41295 Mdot
.35813 .46276 Mdot
.38224 .68362 Mdot
.61545 .62119 Mdot
.49782 .33935 Mdot
.38746 .48019 Mdot
.64185 .47157 Mdot
.21847 .4108 Mdot
.63592 .58047 Mdot
.41655 .65083 Mdot
.39669 .65706 Mdot
.57928 .83867 Mdot
.3898 .5056 Mdot
.41969 .49101 Mdot
.63632 .59911 Mdot
.66358 .72973 Mdot
.4853 .31994 Mdot
.24817 .40305 Mdot
.63402 .60892 Mdot
.55355 .52195 Mdot
.44615 .66969 Mdot
.37224 .44628 Mdot
.80734 .40961 Mdot
.6126 .36869 Mdot
.40636 .77702 Mdot
.49306 .31943 Mdot
.3173 .33896 Mdot
.42532 .70479 Mdot
.64081 .62681 Mdot
.70194 .57295 Mdot
.40613 .4131 Mdot
.38012 .44436 Mdot
.32486 .33757 Mdot
.66684 .6465 Mdot
.48442 .50407 Mdot
.35087 .48949 Mdot
.60799 .53593 Mdot
.35191 .46681 Mdot
.37145 .41722 Mdot
.41523 .54666 Mdot
.41511 .47846 Mdot
.40986 .64476 Mdot
.45092 .54302 Mdot
.61226 .42389 Mdot
.46968 .61856 Mdot
.55334 .53181 Mdot
.38834 .49342 Mdot
.382 .52399 Mdot
.36338 .71294 Mdot
.72346 .60891 Mdot
.42316 .68905 Mdot
.42662 .72628 Mdot
.65581 .63239 Mdot
.40588 .55873 Mdot
.60424 .42583 Mdot
.35675 .42302 Mdot
.61717 .44983 Mdot
.40728 .64877 Mdot
.64711 .44864 Mdot
.63014 .64981 Mdot
.67215 .44566 Mdot
.7074 .51307 Mdot
.64788 .62027 Mdot
.40849 .69058 Mdot
.42483 .4775 Mdot
.61383 .5854 Mdot
.41573 .26776 Mdot
.49346 .32342 Mdot
.82742 .61528 Mdot
.42614 .484 Mdot
.5275 .7658 Mdot
.32098 .42654 Mdot
.63399 .46962 Mdot
.18656 .6134 Mdot
.40219 .64684 Mdot
.51313 .2884 Mdot
.39649 .68067 Mdot
.42946 .21954 Mdot
.50001 .3244 Mdot
.82148 .57741 Mdot
.5983 .49868 Mdot
.43247 .22893 Mdot
.41998 .5526 Mdot
.44745 .2455 Mdot
.67868 .45202 Mdot
.61533 .62338 Mdot
.71104 .57756 Mdot
.41157 .43039 Mdot
.25902 .32674 Mdot
.41375 .62234 Mdot
.6092 .41725 Mdot
.63426 .63135 Mdot
.61323 .59084 Mdot
.37732 .53049 Mdot
.63263 .29736 Mdot
.38657 .43669 Mdot
.72567 .54657 Mdot
.31419 .32149 Mdot
.44626 .73549 Mdot
.39428 .49462 Mdot
.64965 .41551 Mdot
.39694 .51568 Mdot
.49197 .28793 Mdot
.42402 .18492 Mdot
.40747 .40371 Mdot
.65667 .53692 Mdot
.49852 .26554 Mdot
.44504 .68067 Mdot
.33586 .40488 Mdot
.68918 .52635 Mdot
.38886 .50788 Mdot
.22048 .73334 Mdot
.50931 .30196 Mdot
.71299 .34053 Mdot
.43437 .49806 Mdot
.39384 .53329 Mdot
.5407 .5985 Mdot
.50693 .75232 Mdot
.59356 .37178 Mdot
.39339 .44806 Mdot
.36095 .30187 Mdot
.5977 .63248 Mdot
.37193 .44123 Mdot
.40018 .48378 Mdot
.24873 .62901 Mdot
.62169 .58337 Mdot
.64201 .45779 Mdot
.68115 .44825 Mdot
.58931 .43661 Mdot
.49643 .28411 Mdot
.67086 .58016 Mdot
.43573 .31637 Mdot
.19731 .42964 Mdot
.53154 .30852 Mdot
.43379 .46676 Mdot
.46636 .33726 Mdot
.38496 .51844 Mdot
.50863 .34017 Mdot
.62526 .58196 Mdot
.42518 .69244 Mdot
.59432 .69816 Mdot
.67071 .42219 Mdot
.44491 .42752 Mdot
.48532 .31294 Mdot
.40704 .6866 Mdot
.50476 .2475 Mdot
.4435 .67428 Mdot
.63147 .61709 Mdot
.60656 .58327 Mdot
.50174 .34174 Mdot
.43142 .64725 Mdot
.61822 .55608 Mdot
.76 .699 Mdot
.40855 .54546 Mdot
.68128 .67403 Mdot
.43676 .70508 Mdot
.41782 .72633 Mdot
.42289 .71108 Mdot
.42155 .43924 Mdot
.51305 .45147 Mdot
.34325 .46125 Mdot
.59472 .6223 Mdot
.65575 .45297 Mdot
.28867 .3194 Mdot
.74682 .45425 Mdot
.50772 .39986 Mdot
.36982 .53834 Mdot
.38081 .47025 Mdot
.39963 .48958 Mdot
.34454 .44502 Mdot
.70186 .54516 Mdot
.3885 .43954 Mdot
.61199 .63538 Mdot
.62188 .42587 Mdot
.3614 .4416 Mdot
.69072 .44295 Mdot
.80228 .53119 Mdot
.53249 .31665 Mdot
.68364 .61229 Mdot
.50322 .1423 Mdot
.41099 .6893 Mdot
.61101 .4704 Mdot
.63292 .41284 Mdot
.49066 .33872 Mdot
.61865 .61326 Mdot
.44261 .67021 Mdot
.30044 .36432 Mdot
.48972 .34368 Mdot
.39441 .46971 Mdot
.50117 .44396 Mdot
.28662 .29305 Mdot
.36126 .44384 Mdot
.35918 .47492 Mdot
.68319 .46262 Mdot
.69641 .3252 Mdot
.27208 .25109 Mdot
.44944 .29456 Mdot
.4989 .33783 Mdot
.52778 .32983 Mdot
.42154 .6268 Mdot
.33785 .475 Mdot
.59359 .62661 Mdot
.46915 .54689 Mdot
.69108 .61249 Mdot
.47299 .59264 Mdot
.45263 .76702 Mdot
.35241 .47263 Mdot
.60631 .79414 Mdot
.37819 .47389 Mdot
.39396 .69062 Mdot
.40705 .6539 Mdot
.41445 .67697 Mdot
.61643 .62349 Mdot
.30289 .63561 Mdot
.60841 .62775 Mdot
.48643 .13701 Mdot
.43427 .70116 Mdot
.60471 .50958 Mdot
.65542 .4298 Mdot
.35774 .53989 Mdot
.50148 .29815 Mdot
.63186 .56754 Mdot
.42131 .56411 Mdot
.19437 .58167 Mdot
.61107 .41819 Mdot
.41075 .69313 Mdot
.69277 .68596 Mdot
.56829 .18042 Mdot
.49871 .51337 Mdot
.40047 .57312 Mdot
.48515 .25236 Mdot
.50895 .33142 Mdot
.40605 .7778 Mdot
.50986 .29744 Mdot
.64687 .60641 Mdot
.41083 .4992 Mdot
.41878 .48396 Mdot
.35254 .46363 Mdot
.41133 .44814 Mdot
.64979 .64635 Mdot
.43253 .51656 Mdot
.16488 .56376 Mdot
.65758 .41328 Mdot
.30904 .40759 Mdot
.50377 .29956 Mdot
.66347 .61105 Mdot
.62193 .42423 Mdot
.7219 .60439 Mdot
.43201 .2688 Mdot
.39306 .49837 Mdot
.35538 .46911 Mdot
.38585 .22261 Mdot
.35104 .49129 Mdot
.32057 .4931 Mdot
.62742 .41221 Mdot
.47937 .38876 Mdot
.53038 .31158 Mdot
.52843 .32431 Mdot
.6487 .624 Mdot
.40912 .6474 Mdot
.50555 .30566 Mdot
.65918 .43282 Mdot
.37227 .53967 Mdot
.42652 .51859 Mdot
.43573 .70525 Mdot
.40207 .20133 Mdot
.48165 .32978 Mdot
.73662 .65216 Mdot
.39979 .67851 Mdot
.46374 .64841 Mdot
.37922 .44506 Mdot
.44201 .75698 Mdot
.40231 .72991 Mdot
.52165 .29088 Mdot
.66314 .61213 Mdot
.46637 .26009 Mdot
.63433 .59234 Mdot
.41833 .64758 Mdot
.40364 .52288 Mdot
.40211 .66556 Mdot
.3896 .50248 Mdot
.61966 .1821 Mdot
.41876 .47755 Mdot
.1901 .43817 Mdot
.36478 .34425 Mdot
.63739 .42227 Mdot
.7177 .63371 Mdot
.65165 .42482 Mdot
.401 .6869 Mdot
.40603 .52674 Mdot
.49415 .29607 Mdot
.79771 .57747 Mdot
.39571 .6254 Mdot
.6208 .46249 Mdot
.62968 .39778 Mdot
.64131 .59196 Mdot
.34733 .47137 Mdot
.38268 .44273 Mdot
.6266 .43686 Mdot
.44983 .73452 Mdot
.43589 .63908 Mdot
.40311 .50309 Mdot
.38003 .46506 Mdot
.64031 .42331 Mdot
.74712 .71305 Mdot
.39587 .60886 Mdot
.4113 .49257 Mdot
.73183 .41815 Mdot
.60418 .6015 Mdot
.38227 .54983 Mdot
.32693 .47522 Mdot
.50936 .32343 Mdot
.23964 .51706 Mdot
.46648 .18768 Mdot
.62968 .58103 Mdot
.63879 .41063 Mdot
.39192 .50829 Mdot
.64847 .41464 Mdot
.4278 .51898 Mdot
.50359 .74512 Mdot
.65363 .47478 Mdot
.36873 .52019 Mdot
.44386 .52002 Mdot
.40577 .69849 Mdot
.35351 .47173 Mdot
.35054 .70965 Mdot
.60779 .44786 Mdot
.38375 .53182 Mdot
.2864 .51874 Mdot
.61605 .60592 Mdot
.41905 .55482 Mdot
.50688 .35215 Mdot
.29636 .36769 Mdot
.55159 .73065 Mdot
.67387 .28458 Mdot
.52941 .33035 Mdot
.40793 .43504 Mdot
.62279 .40104 Mdot
.59653 .638 Mdot
.18228 .46327 Mdot
.3827 .43184 Mdot
.64074 .60187 Mdot
.63082 .63791 Mdot
.49171 .33394 Mdot
.40617 .82465 Mdot
.43876 .4875 Mdot
.40572 .45344 Mdot
.28953 .67248 Mdot
.4572 .68772 Mdot
.4173 .46826 Mdot
.43263 .47767 Mdot
.61184 .63705 Mdot
.35261 .54782 Mdot
.35516 .6383 Mdot
.24217 .41906 Mdot
.59015 .63916 Mdot
.49766 .59897 Mdot
.67492 .44904 Mdot
.51939 .311 Mdot
.43782 .67866 Mdot
.48721 .30687 Mdot
.66703 .45429 Mdot
.43113 .47673 Mdot
.65511 .62589 Mdot
.32931 .71532 Mdot
.60618 .64269 Mdot
.63949 .2616 Mdot
.44761 .69878 Mdot
.56075 .66603 Mdot
.26735 .77454 Mdot
.76975 .58338 Mdot
.59137 .66584 Mdot
.50706 .32738 Mdot
.65607 .37837 Mdot
.37955 .46703 Mdot
.40293 .78121 Mdot
.43107 .46177 Mdot
.27969 .51215 Mdot
.64927 .40953 Mdot
.66023 .41182 Mdot
.41047 .4968 Mdot
.31023 .32931 Mdot
.59724 .63948 Mdot
.60944 .59728 Mdot
.36876 .52269 Mdot
.62744 .61669 Mdot
.40318 .46146 Mdot
.61761 .42863 Mdot
.25859 .72024 Mdot
.39022 .47639 Mdot
.34706 .43861 Mdot
.51284 .73969 Mdot
.80847 .61729 Mdot
.5748 .25059 Mdot
.64591 .80121 Mdot
.54285 .17441 Mdot
.62717 .61839 Mdot
.34129 .48681 Mdot
.49725 .60082 Mdot
.68451 .44725 Mdot
.61369 .56259 Mdot
.42569 .4677 Mdot
.42788 .46133 Mdot
.42119 .43197 Mdot
.36608 .47329 Mdot
.43482 .79979 Mdot
.44307 .56763 Mdot
.26233 .56127 Mdot
.35383 .48473 Mdot
.43253 .24935 Mdot
.65129 .61695 Mdot
.42073 .74029 Mdot
.53313 .30762 Mdot
.35278 .47161 Mdot
.45309 .60591 Mdot
.62755 .65678 Mdot
.48188 .13503 Mdot
.64907 .60681 Mdot
.63595 .45602 Mdot
.62018 .65173 Mdot
.37687 .48738 Mdot
.42776 .66637 Mdot
.51917 .56634 Mdot
.75939 .54119 Mdot
.62404 .41327 Mdot
.38516 .49172 Mdot
.62337 .523 Mdot
.6127 .42047 Mdot
.80663 .51973 Mdot
.43165 .67385 Mdot
.366 .30156 Mdot
.40363 .65961 Mdot
.37662 .52711 Mdot
.38132 .52831 Mdot
.58411 .64458 Mdot
.62657 .65154 Mdot
.4046 .65701 Mdot
.41995 .839 Mdot
.48843 .34582 Mdot
.41223 .6736 Mdot
.41609 .41408 Mdot
.52504 .48976 Mdot
.42454 .66881 Mdot
.50909 .26751 Mdot
.62223 .63917 Mdot
.45114 .63449 Mdot
.43428 .43319 Mdot
.4818 .22051 Mdot
.51741 .35238 Mdot
.67296 .47133 Mdot
.45914 .31397 Mdot
.60713 .4514 Mdot
.66186 .61123 Mdot
.64991 .42364 Mdot
.59874 .63076 Mdot
.55798 .74888 Mdot
.48043 .63532 Mdot
.60386 .67193 Mdot
.66066 .624 Mdot
.64842 .42549 Mdot
.40671 .50623 Mdot
.50171 .26154 Mdot
.34751 .5128 Mdot
.44362 .47374 Mdot
.59899 .61992 Mdot
.41679 .70207 Mdot
.41103 .73144 Mdot
.40491 .251 Mdot
.4169 .63688 Mdot
.61974 .45808 Mdot
.17782 .55931 Mdot
.71959 .46863 Mdot
.62371 .59448 Mdot
.62781 .65358 Mdot
.3686 .51524 Mdot
.63455 .43784 Mdot
.63334 .4084 Mdot
.641 .59329 Mdot
.49736 .69077 Mdot
.33149 .47323 Mdot
.41001 .72314 Mdot
.458 .67845 Mdot
.41666 .66008 Mdot
.42414 .71248 Mdot
.37178 .63359 Mdot
.63772 .64052 Mdot
.41217 .70028 Mdot
.36287 .51219 Mdot
.42687 .4638 Mdot
.48433 .55985 Mdot
.52529 .33315 Mdot
.36433 .4372 Mdot
.41636 .54756 Mdot
.37177 .44811 Mdot
.65755 .46783 Mdot
.44352 .40075 Mdot
.64565 .47467 Mdot
.62943 .40221 Mdot
.63318 .4045 Mdot
.70615 .51524 Mdot
.36813 .24672 Mdot
.56149 .1976 Mdot
.41137 .51722 Mdot
.65985 .74596 Mdot
.64542 .43986 Mdot
.18982 .59383 Mdot
.63237 .73844 Mdot
.39475 .42887 Mdot
.61133 .36306 Mdot
.62862 .433 Mdot
.40506 .64431 Mdot
.42366 .47143 Mdot
.594 .44934 Mdot
.50777 .35339 Mdot
.36566 .5263 Mdot
.65265 .47592 Mdot
.4332 .64996 Mdot
.5196 .28649 Mdot
.45949 .65639 Mdot
.63682 .40446 Mdot
.43829 .5339 Mdot
.12935 .44738 Mdot
.61582 .39854 Mdot
.72149 .70583 Mdot
.30634 .49525 Mdot
.40467 .50445 Mdot
.61028 .46638 Mdot
.46335 .67458 Mdot
.6591 .60399 Mdot
.56305 .47408 Mdot
.45048 .63892 Mdot
.66083 .41214 Mdot
.61666 .46281 Mdot
.62523 .41243 Mdot
.45472 .66471 Mdot
.38643 .41924 Mdot
.44706 .63945 Mdot
.61607 .65044 Mdot
.36474 .49947 Mdot
.64265 .22665 Mdot
.64692 .75059 Mdot
.3998 .669 Mdot
.64421 .46091 Mdot
.52154 .35506 Mdot
.38185 .47785 Mdot
.64548 .75634 Mdot
.40287 .51026 Mdot
.5971 .62046 Mdot
.21468 .53464 Mdot
.35158 .73356 Mdot
.34811 .50313 Mdot
.36719 .51324 Mdot
.60812 .60001 Mdot
.38819 .48727 Mdot
.34715 .47643 Mdot
.70874 .51905 Mdot
.45006 .6513 Mdot
.38897 .46651 Mdot
.6603 .44543 Mdot
.7299 .49173 Mdot
.33353 .46389 Mdot
.71459 .42289 Mdot
.35148 .31533 Mdot
.21557 .5495 Mdot
.43135 .46326 Mdot
.49296 .44633 Mdot
.37058 .46221 Mdot
.41278 .4416 Mdot
.37735 .516 Mdot
.48342 .82166 Mdot
.65921 .47273 Mdot
.63311 .41566 Mdot
.52597 .34076 Mdot
.3542 .3127 Mdot
.5104 .31852 Mdot
.6231 .64074 Mdot
.65246 .31381 Mdot
.64729 .47469 Mdot
.42482 .64455 Mdot
.40464 .43748 Mdot
.61514 .39917 Mdot
.37544 .44383 Mdot
.37693 .48958 Mdot
.60124 .43192 Mdot
.67429 .45742 Mdot
.70235 .32007 Mdot
.52089 .34511 Mdot
.41736 .68172 Mdot
.34577 .46377 Mdot
.48333 .32309 Mdot
.43651 .47631 Mdot
.41255 .32414 Mdot
.41735 .67757 Mdot
.44907 .64634 Mdot
.40701 .73062 Mdot
.42993 .47948 Mdot
.37995 .48407 Mdot
.60716 .62702 Mdot
.39766 .67076 Mdot
.61914 .60445 Mdot
.58311 .51742 Mdot
.6884 .37299 Mdot
.4258 .46748 Mdot
.66319 .69431 Mdot
.52022 .32456 Mdot
.62932 .4645 Mdot
.2953 .29145 Mdot
.5255 .34219 Mdot
.39201 .50328 Mdot
.6151 .41004 Mdot
.51211 .34107 Mdot
.28435 .42017 Mdot
.45004 .16172 Mdot
.52941 .34296 Mdot
.36218 .51151 Mdot
.37461 .56138 Mdot
.6328 .8093 Mdot
.53103 .33147 Mdot
.63884 .64635 Mdot
.42921 .48048 Mdot
.38636 .6704 Mdot
.48727 .30528 Mdot
.77954 .51111 Mdot
.62488 .42803 Mdot
.48027 .20888 Mdot
.45936 .51783 Mdot
.37213 .76456 Mdot
.52549 .32015 Mdot
.4389 .66775 Mdot
.31603 .45456 Mdot
.37634 .44938 Mdot
.52945 .33572 Mdot
.60803 .66561 Mdot
.61979 .44217 Mdot
.74037 .51224 Mdot
.45514 .66525 Mdot
.56984 .64122 Mdot
.64974 .46205 Mdot
.74196 .64531 Mdot
.22789 .45846 Mdot
.39369 .55519 Mdot
.61452 .81075 Mdot
.67309 .57225 Mdot
.41134 .42377 Mdot
.5195 .36142 Mdot
.62097 .58061 Mdot
.65608 .62725 Mdot
.63436 .61429 Mdot
.56834 .75602 Mdot
.49715 .50114 Mdot
.61293 .47304 Mdot
.58199 .60772 Mdot
.51862 .31146 Mdot
.46014 .25776 Mdot
.44468 .48633 Mdot
.38272 .47057 Mdot
.34497 .48414 Mdot
.3547 .4628 Mdot
.37748 .45577 Mdot
.62337 .61023 Mdot
.54347 .75223 Mdot
.49096 .5307 Mdot
.42025 .67205 Mdot
.67602 .30983 Mdot
.65489 .43291 Mdot
.61521 .47577 Mdot
.51153 .34594 Mdot
.78156 .58079 Mdot
.69109 .44408 Mdot
.64657 .4503 Mdot
.38878 .42362 Mdot
.43821 .63658 Mdot
.33389 .51862 Mdot
.365 .51269 Mdot
.62006 .45612 Mdot
.55094 .5677 Mdot
.35816 .67325 Mdot
.39915 .37721 Mdot
.54215 .33088 Mdot
.51103 .48346 Mdot
.521 .35235 Mdot
.41104 .52513 Mdot
.18955 .61305 Mdot
.66703 .45535 Mdot
.63255 .44893 Mdot
.52361 .32594 Mdot
.42906 .76275 Mdot
.43841 .6862 Mdot
.6574 .68682 Mdot
.61511 .64446 Mdot
.39593 .52742 Mdot
.22869 .39779 Mdot
.30986 .42114 Mdot
.62308 .29913 Mdot
.63678 .60877 Mdot
.65314 .41866 Mdot
.36013 .52954 Mdot
.3592 .50396 Mdot
.52018 .32865 Mdot
.74051 .33682 Mdot
.39418 .5476 Mdot
.82998 .49098 Mdot
.34136 .24805 Mdot
.43268 .20909 Mdot
.3806 .44424 Mdot
.45156 .65381 Mdot
.67828 .46581 Mdot
.51767 .30308 Mdot
.42883 .41926 Mdot
.48798 .16726 Mdot
.44005 .70065 Mdot
.64558 .61859 Mdot
.53909 .55185 Mdot
.46242 .27065 Mdot
.43322 .44991 Mdot
.43005 .46704 Mdot
.42095 .44351 Mdot
.38738 .17054 Mdot
.65506 .47145 Mdot
.40199 .65449 Mdot
.49394 .3373 Mdot
.41967 .63821 Mdot
.64109 .4189 Mdot
.5617 .64475 Mdot
.40957 .50732 Mdot
.44325 .69914 Mdot
.43909 .66964 Mdot
.64756 .60202 Mdot
.65473 .59281 Mdot
.55917 .53439 Mdot
.4177 .47656 Mdot
.62517 .39603 Mdot
.40909 .69995 Mdot
.50166 .45025 Mdot
.50127 .32311 Mdot
.61812 .63945 Mdot
.35363 .47857 Mdot
.6656 .46531 Mdot
.44994 .47482 Mdot
.42712 .68549 Mdot
.64633 .44967 Mdot
.73089 .3847 Mdot
.53164 .31976 Mdot
.41972 .45781 Mdot
.47691 .30474 Mdot
.63588 .41013 Mdot
.37762 .46689 Mdot
.75324 .64896 Mdot
.50744 .26849 Mdot
.76783 .51654 Mdot
.62485 .40649 Mdot
.69186 .50253 Mdot
.42638 .62654 Mdot
.57793 .76848 Mdot
.63267 .45273 Mdot
.72278 .66647 Mdot
.7467 .37811 Mdot
.36333 .53478 Mdot
.41098 .65672 Mdot
.66218 .56138 Mdot
.68172 .23228 Mdot
.71305 .73338 Mdot
.39766 .4877 Mdot
.59516 .44236 Mdot
.51756 .33415 Mdot
.61952 .59515 Mdot
.71328 .4034 Mdot
.52357 .28027 Mdot
.65959 .40643 Mdot
.37825 .51593 Mdot
.4355 .65875 Mdot
.61935 .63354 Mdot
.55497 .73528 Mdot
.66064 .43709 Mdot
.65481 .45571 Mdot
.35718 .52541 Mdot
.51366 .31511 Mdot
.61153 .77326 Mdot
.61802 .42319 Mdot
.36068 .23889 Mdot
.59071 .4028 Mdot
.48465 .33627 Mdot
.36455 .4668 Mdot
.40616 .24598 Mdot
.34054 .45773 Mdot
.77152 .65193 Mdot
.65146 .43017 Mdot
.42296 .68205 Mdot
.4231 .43724 Mdot
.25542 .41378 Mdot
.62248 .45946 Mdot
.51214 .45924 Mdot
.57735 .28601 Mdot
.63007 .64206 Mdot
.29169 .29446 Mdot
.41314 .46172 Mdot
.59735 .63885 Mdot
.51876 .32691 Mdot
.41365 .48595 Mdot
.37736 .48352 Mdot
.40088 .69842 Mdot
.644 .59834 Mdot
.72313 .33464 Mdot
.61932 .65563 Mdot
.65284 .62481 Mdot
.4087 .71273 Mdot
.3939 .45659 Mdot
.63749 .4568 Mdot
.62886 .43494 Mdot
.44567 .44176 Mdot
.2243 .69565 Mdot
.44088 .68742 Mdot
.67857 .47012 Mdot
.37361 .17741 Mdot
.4559 .46316 Mdot
.27901 .31239 Mdot
.7478 .34507 Mdot
.59479 .61698 Mdot
.36013 .51008 Mdot
.43124 .64994 Mdot
.56842 .39099 Mdot
.65117 .45718 Mdot
.43055 .43446 Mdot
.62165 .63254 Mdot
.51231 .35347 Mdot
.60828 .43735 Mdot
.63237 .29901 Mdot
.41539 .44684 Mdot
.60101 .36253 Mdot
.60064 .45167 Mdot
.78457 .32345 Mdot
.71544 .60255 Mdot
.40908 .66177 Mdot
.37425 .49034 Mdot
.40343 .64436 Mdot
.49623 .34098 Mdot
.54135 .54862 Mdot
.62464 .63666 Mdot
.46433 .52844 Mdot
.15253 .55 Mdot
.62657 .41161 Mdot
.40151 .65373 Mdot
.34955 .50761 Mdot
.49748 .74366 Mdot
.40762 .45923 Mdot
.37661 .56689 Mdot
.46336 .32933 Mdot
.60538 .61017 Mdot
.60015 .63608 Mdot
.3708 .47463 Mdot
.48691 .33126 Mdot
.65788 .43313 Mdot
.62062 .45052 Mdot
.85702 .44579 Mdot
.53471 .63781 Mdot
.28474 .35541 Mdot
.42644 .45948 Mdot
.65296 .40318 Mdot
.74276 .46609 Mdot
.63626 .59966 Mdot
.44769 .43758 Mdot
.60502 .42472 Mdot
.53236 .25953 Mdot
.29627 .38079 Mdot
.37375 .45533 Mdot
.36703 .42253 Mdot
.62059 .64643 Mdot
.49362 .48651 Mdot
.66001 .41842 Mdot
.44257 .51391 Mdot
.60896 .67697 Mdot
.29138 .39987 Mdot
.39303 .19399 Mdot
.41707 .68176 Mdot
.61581 .282 Mdot
.6226 .61026 Mdot
.35641 .4283 Mdot
.49133 .30757 Mdot
.68519 .45537 Mdot
.66219 .46933 Mdot
.38541 .51109 Mdot
.39724 .53759 Mdot
.31237 .29141 Mdot
.42807 .63823 Mdot
.65067 .62059 Mdot
.421 .48729 Mdot
.61845 .70439 Mdot
.35124 .46752 Mdot
.60658 .62111 Mdot
.12003 .45837 Mdot
.34708 .50912 Mdot
.40538 .45581 Mdot
.62959 .76225 Mdot
.45637 .6533 Mdot
.39749 .66098 Mdot
.2386 .35678 Mdot
.42602 .45931 Mdot
.31908 .2713 Mdot
.41877 .68699 Mdot
.43545 .68832 Mdot
.71973 .52657 Mdot
.38348 .47554 Mdot
.4764 .46597 Mdot
.59525 .62427 Mdot
.65153 .63145 Mdot
.45235 .64774 Mdot
.38496 .54952 Mdot
.63668 .58328 Mdot
.50853 .81119 Mdot
.63599 .43687 Mdot
.19742 .63524 Mdot
.44141 .69135 Mdot
.67772 .62748 Mdot
.63663 .60307 Mdot
.49216 .13957 Mdot
.58101 .4662 Mdot
.4093 .50459 Mdot
.42165 .45454 Mdot
.52116 .31894 Mdot
.34321 .48105 Mdot
.65911 .41131 Mdot
.62763 .61593 Mdot
.27377 .4826 Mdot
.41393 .67704 Mdot
.41197 .47079 Mdot
.79213 .56002 Mdot
.79366 .47978 Mdot
.61452 .2709 Mdot
.44425 .68027 Mdot
.40435 .66865 Mdot
.66521 .43077 Mdot
.59563 .44218 Mdot
.38688 .45023 Mdot
.61818 .59063 Mdot
.39802 .67037 Mdot
.60314 .61985 Mdot
.66594 .45666 Mdot
.6414 .45509 Mdot
.67106 .46612 Mdot
.44199 .49903 Mdot
.65343 .44893 Mdot
.71651 .38413 Mdot
.57138 .6362 Mdot
.40115 .71065 Mdot
.3049 .2561 Mdot
.56241 .73668 Mdot
.38874 .72799 Mdot
.48549 .30647 Mdot
.63198 .40983 Mdot
.61004 .64993 Mdot
.36186 .48692 Mdot
.36265 .45505 Mdot
.70168 .48071 Mdot
.59903 .64723 Mdot
.49756 .3404 Mdot
.60092 .64026 Mdot
.49167 .33433 Mdot
.58134 .3368 Mdot
.34985 .46146 Mdot
.4224 .5232 Mdot
.62737 .6092 Mdot
.6505 .44891 Mdot
.62775 .42014 Mdot
.53276 .33405 Mdot
.56905 .56421 Mdot
.61193 .42067 Mdot
.43371 .69284 Mdot
.37426 .64537 Mdot
.61819 .4649 Mdot
.42174 .47039 Mdot
.43624 .32171 Mdot
.39595 .78488 Mdot
.34494 .44445 Mdot
.71506 .5236 Mdot
.32145 .7259 Mdot
.40652 .43158 Mdot
.37833 .78639 Mdot
.65944 .52562 Mdot
.42827 .62814 Mdot
.65272 .41194 Mdot
.69632 .43292 Mdot
.4074 .39681 Mdot
.53623 .30759 Mdot
.43645 .4269 Mdot
.44598 .69028 Mdot
.41604 .61757 Mdot
.44463 .21776 Mdot
.73958 .69134 Mdot
.51479 .33686 Mdot
.51664 .34078 Mdot
.63032 .4536 Mdot
.82615 .62958 Mdot
.40828 .56805 Mdot
.49915 .33988 Mdot
.48684 .64815 Mdot
.38019 .51467 Mdot
.34204 .33918 Mdot
.54154 .37869 Mdot
.45331 .65421 Mdot
.43148 .24403 Mdot
.63092 .45986 Mdot
.41782 .63541 Mdot
.59746 .70371 Mdot
.36718 .43239 Mdot
.41646 .67639 Mdot
.60387 .62357 Mdot
.73209 .58696 Mdot
.42809 .6982 Mdot
.42667 .3213 Mdot
.6352 .58802 Mdot
.50418 .45547 Mdot
.38447 .27029 Mdot
.51476 .90198 Mdot
.62389 .61405 Mdot
.61979 .46398 Mdot
.62793 .43541 Mdot
.62146 .45146 Mdot
.42331 .63643 Mdot
.63443 .40862 Mdot
.42528 .6398 Mdot
.65485 .7774 Mdot
.44787 .76664 Mdot
.50029 .33906 Mdot
.74201 .51581 Mdot
.42624 .65333 Mdot
.18257 .58812 Mdot
.19061 .67946 Mdot
.36039 .51126 Mdot
.63654 .65389 Mdot
.50476 .33903 Mdot
.83015 .50215 Mdot
.51105 .32652 Mdot
.40373 .22848 Mdot
.20457 .57165 Mdot
.40528 .46781 Mdot
.33033 .64022 Mdot
.51798 .29618 Mdot
.44709 .67096 Mdot
.37776 .46869 Mdot
.5524 .43254 Mdot
.51398 .32401 Mdot
.49837 .35138 Mdot
.38665 .45744 Mdot
.41052 .6931 Mdot
.63663 .46226 Mdot
.63816 .64947 Mdot
.49877 .28982 Mdot
.31959 .50989 Mdot
.35537 .43536 Mdot
.40152 .51436 Mdot
.48981 .55578 Mdot
.49467 .37027 Mdot
.62663 .61919 Mdot
.44445 .823 Mdot
.6119 .40902 Mdot
.55713 .43609 Mdot
.37126 .22573 Mdot
.69394 .52366 Mdot
.6492 .43036 Mdot
.64682 .41518 Mdot
.37886 .45297 Mdot
.51737 .37695 Mdot
.20387 .58607 Mdot
.5957 .55285 Mdot
.66898 .47096 Mdot
.61931 .44619 Mdot
.40869 .63182 Mdot
.42807 .21617 Mdot
.42363 .4158 Mdot
.62979 .58064 Mdot
.66683 .46657 Mdot
.48912 .76682 Mdot
.51512 .31252 Mdot
.19429 .55651 Mdot
.35196 .45578 Mdot
.41296 .49978 Mdot
.63098 .62982 Mdot
.60947 .62903 Mdot
.56445 .39164 Mdot
.41911 .21965 Mdot
.33243 .73225 Mdot
.53467 .73449 Mdot
.22641 .56267 Mdot
.40967 .6265 Mdot
.39972 .66989 Mdot
.768 .55388 Mdot
.62348 .65628 Mdot
.41368 .43324 Mdot
.40757 .64979 Mdot
.56413 .45127 Mdot
.38307 .63988 Mdot
.31005 .34294 Mdot
.28636 .31593 Mdot
.38841 .49999 Mdot
.44457 .64643 Mdot
.45715 .65922 Mdot
.44932 .7053 Mdot
.64354 .53089 Mdot
.39395 .44808 Mdot
.3926 .49442 Mdot
.39484 .43385 Mdot
.48222 .73165 Mdot
.40164 .44188 Mdot
.5679 .76855 Mdot
.54359 .53038 Mdot
.24548 .50616 Mdot
.43404 .52848 Mdot
.59594 .60847 Mdot
.4338 .45707 Mdot
.48766 .33311 Mdot
.3784 .5206 Mdot
.30639 .34781 Mdot
.64382 .60758 Mdot
.39472 .61215 Mdot
.56273 .74548 Mdot
.41273 .42702 Mdot
.51547 .28661 Mdot
.69451 .63245 Mdot
.62754 .21658 Mdot
.47706 .29392 Mdot
.43533 .69274 Mdot
.64123 .43458 Mdot
.60734 .64953 Mdot
.63918 .45186 Mdot
.43018 .52277 Mdot
.76686 .56892 Mdot
.803 .45785 Mdot
.59043 .52368 Mdot
.35498 .46383 Mdot
.46717 .47691 Mdot
.43116 .68959 Mdot
.61112 .41129 Mdot
.39478 .72524 Mdot
.42477 .44081 Mdot
.49276 .32559 Mdot
.5177 .32377 Mdot
.56816 .47934 Mdot
.77099 .34127 Mdot
.49264 .79289 Mdot
.62925 .62807 Mdot
.61612 .4302 Mdot
.50583 .29634 Mdot
.70405 .69829 Mdot
.65369 .58994 Mdot
.60315 .60614 Mdot
.64741 .61215 Mdot
.42773 .49261 Mdot
.65491 .47472 Mdot
.24725 .50368 Mdot
.65889 .40808 Mdot
.38577 .48834 Mdot
.6545 .46968 Mdot
.60824 .41999 Mdot
.50821 .29967 Mdot
.64994 .6149 Mdot
.66807 .44773 Mdot
.38071 .52919 Mdot
.41421 .68944 Mdot
.64819 .66515 Mdot
.34654 .35574 Mdot
.74788 .67966 Mdot
.28877 .47058 Mdot
.4556 .68263 Mdot
.68227 .2379 Mdot
.6008 .6071 Mdot
.49532 .7002 Mdot
.69559 .31491 Mdot
.41185 .52029 Mdot
.19506 .66387 Mdot
.61791 .47706 Mdot
.60436 .43062 Mdot
.36556 .46718 Mdot
.61306 .38451 Mdot
.40962 .4668 Mdot
.65832 .4606 Mdot
.72597 .42996 Mdot
.43441 .60101 Mdot
.6526 .44405 Mdot
.44479 .50621 Mdot
.375 .47899 Mdot
.45109 .64884 Mdot
.60893 .46378 Mdot
.44294 .42601 Mdot
.85048 .42644 Mdot
.60987 .62427 Mdot
.65503 .54627 Mdot
.43914 .33611 Mdot
.62163 .60952 Mdot
.41219 .67016 Mdot
.44408 .47771 Mdot
.51909 .32862 Mdot
.42721 .65219 Mdot
.28196 .39425 Mdot
.52927 .31436 Mdot
.17971 .61724 Mdot
.45674 .66412 Mdot
.61323 .45866 Mdot
.48815 .3146 Mdot
.34141 .47437 Mdot
.68448 .45689 Mdot
.72174 .62239 Mdot
.64993 .43209 Mdot
.38455 .44234 Mdot
.75676 .49562 Mdot
.65103 .62373 Mdot
.40049 .48766 Mdot
.60432 .43526 Mdot
.71432 .51666 Mdot
.425 .49899 Mdot
.37101 .46797 Mdot
.39401 .20091 Mdot
.18412 .50455 Mdot
.50524 .32523 Mdot
.46006 .69035 Mdot
.36318 .51271 Mdot
.50102 .35103 Mdot
.64067 .34541 Mdot
.4227 .49337 Mdot
.43788 .70293 Mdot
.45838 .4716 Mdot
.60486 .45994 Mdot
.61541 .61007 Mdot
.61325 .53356 Mdot
.50767 .35327 Mdot
.63602 .83411 Mdot
.67307 .44061 Mdot
.42333 .51885 Mdot
.35071 .47709 Mdot
.54922 .23361 Mdot
.42775 .62897 Mdot
.26756 .69334 Mdot
.41987 .45756 Mdot
.48183 .72632 Mdot
.41203 .48379 Mdot
.64404 .48066 Mdot
.438 .6872 Mdot
.40399 .45096 Mdot
.60488 .68585 Mdot
.33964 .44876 Mdot
.52497 .34063 Mdot
.63548 .76289 Mdot
.3761 .42424 Mdot
.12775 .52715 Mdot
.56005 .35435 Mdot
.65465 .4438 Mdot
.78465 .49006 Mdot
.8828 .48325 Mdot
.57304 .75319 Mdot
.41774 .64087 Mdot
.77018 .38636 Mdot
.63827 .45681 Mdot
.76794 .46576 Mdot
.67378 .22951 Mdot
.37048 .48343 Mdot
.43313 .44901 Mdot
.50001 .24371 Mdot
.63386 .40279 Mdot
.64223 .39604 Mdot
.39101 .5431 Mdot
.36462 .42158 Mdot
.6486 .45431 Mdot
.39238 .53306 Mdot
.41004 .53944 Mdot
.64295 .64941 Mdot
.44152 .69685 Mdot
.60752 .60523 Mdot
.63253 .58385 Mdot
.55794 .80701 Mdot
.56023 .32554 Mdot
.60824 .61928 Mdot
.6081 .59201 Mdot
.33846 .34174 Mdot
.33629 .29047 Mdot
.48839 .30346 Mdot
.79862 .36192 Mdot
.62098 .44517 Mdot
.39641 .45227 Mdot
.45788 .67262 Mdot
.34118 .73373 Mdot
.6908 .35538 Mdot
.20916 .63391 Mdot
.41919 .43629 Mdot
.62543 .46059 Mdot
.64412 .53124 Mdot
.32839 .51097 Mdot
.59192 .42402 Mdot
.4242 .48297 Mdot
.66782 .4167 Mdot
.34396 .58962 Mdot
.72299 .66491 Mdot
.61253 .39461 Mdot
.40948 .72164 Mdot
.41667 .49151 Mdot
.44675 .68806 Mdot
.63245 .60059 Mdot
.48669 .31302 Mdot
.5044 .32153 Mdot
.3809 .46333 Mdot
.43278 .54568 Mdot
.58766 .35101 Mdot
.38065 .47815 Mdot
.37519 .51305 Mdot
.66026 .5249 Mdot
.37318 .5148 Mdot
.36291 .44915 Mdot
.38164 .43717 Mdot
.43553 .44225 Mdot
.65226 .62823 Mdot
.78314 .576 Mdot
.37037 .40789 Mdot
.36323 .41541 Mdot
.656 .60004 Mdot
.72992 .33346 Mdot
.62322 .58416 Mdot
.63169 .21367 Mdot
.59551 .6296 Mdot
.49829 .32594 Mdot
.60105 .24284 Mdot
.43761 .55199 Mdot
.4142 .70607 Mdot
.65266 .58262 Mdot
.49417 .34071 Mdot
.63142 .61502 Mdot
.65058 .46474 Mdot
.40737 .18219 Mdot
.44599 .61372 Mdot
.4678 .55236 Mdot
.6325 .56305 Mdot
.75625 .59792 Mdot
.67007 .43754 Mdot
.44933 .68269 Mdot
.35314 .66672 Mdot
.35558 .45926 Mdot
.49789 .34946 Mdot
.38501 .45294 Mdot
.65196 .60977 Mdot
.62752 .45798 Mdot
.69441 .74243 Mdot
.52022 .3282 Mdot
.32812 .24068 Mdot
.62784 .42423 Mdot
.37506 .43739 Mdot
.63443 .58267 Mdot
.25016 .31194 Mdot
.60381 .611 Mdot
.23295 .63563 Mdot
.41365 .63196 Mdot
.66051 .79308 Mdot
.41916 .65131 Mdot
.72741 .62702 Mdot
.24085 .27915 Mdot
.79036 .57558 Mdot
.41101 .69141 Mdot
.55308 .61009 Mdot
.39073 .50621 Mdot
.40252 .51392 Mdot
.7124 .69897 Mdot
.45858 .69237 Mdot
.35409 .49303 Mdot
.72533 .4549 Mdot
.56292 .62128 Mdot
.2556 .35279 Mdot
.65263 .42182 Mdot
.41336 .46527 Mdot
.58691 .62187 Mdot
.59611 .64235 Mdot
.66877 .42283 Mdot
.60342 .6043 Mdot
.39238 .49217 Mdot
.42508 .65292 Mdot
.69451 .39369 Mdot
.50172 .31153 Mdot
.83003 .56753 Mdot
.49383 .3545 Mdot
.64879 .42991 Mdot
.34654 .51149 Mdot
.64221 .45452 Mdot
.89789 .4535 Mdot
.3971 .49803 Mdot
.42009 .68651 Mdot
.36401 .50848 Mdot
.41349 .49336 Mdot
.42987 .43847 Mdot
.64628 .46099 Mdot
.40226 .3711 Mdot
.3858 .53136 Mdot
.62516 .63761 Mdot
.23614 .54227 Mdot
.38142 .42373 Mdot
.6848 .40787 Mdot
.33431 .3082 Mdot
.59202 .58337 Mdot
.44598 .62916 Mdot
.65292 .43913 Mdot
.41177 .67981 Mdot
.44286 .75075 Mdot
.41246 .67 Mdot
.25542 .61235 Mdot
.35529 .64996 Mdot
.25979 .43835 Mdot
.28484 .5134 Mdot
.52907 .59624 Mdot
.45944 .69129 Mdot
.49358 .37344 Mdot
.4002 .68392 Mdot
.4525 .64355 Mdot
.08291 .43705 Mdot
.41449 .70983 Mdot
.42234 .46562 Mdot
.37786 .42809 Mdot
.75174 .62098 Mdot
.39781 .31188 Mdot
.36331 .49917 Mdot
.35819 .49303 Mdot
.49812 .29982 Mdot
.46939 .73048 Mdot
.77148 .52506 Mdot
.17616 .52065 Mdot
.78311 .45558 Mdot
.38525 .4556 Mdot
.36538 .51569 Mdot
.32252 .47436 Mdot
.18117 .40849 Mdot
.56059 .81605 Mdot
.41971 .6018 Mdot
.32479 .47976 Mdot
.792 .60717 Mdot
.43061 .44189 Mdot
.43272 .47656 Mdot
.38945 .50227 Mdot
.63755 .45718 Mdot
.45683 .64308 Mdot
.4407 .45012 Mdot
.5119 .24865 Mdot
.43 .47439 Mdot
.69959 .52244 Mdot
.75454 .72117 Mdot
.41314 .46104 Mdot
.4436 .6198 Mdot
.3985 .51612 Mdot
.43748 .63111 Mdot
.44938 .66363 Mdot
.34644 .52296 Mdot
.2269 .56633 Mdot
.42721 .61705 Mdot
.38507 .48825 Mdot
.63691 .46625 Mdot
.77989 .3229 Mdot
.38625 .44182 Mdot
.48613 .31142 Mdot
.42237 .45598 Mdot
.50963 .28363 Mdot
.3722 .50924 Mdot
.67351 .43914 Mdot
.36878 .75477 Mdot
.63094 .44976 Mdot
.59778 .8182 Mdot
.67288 .46166 Mdot
.37697 .20175 Mdot
.45426 .69055 Mdot
.7481 .50741 Mdot
.31274 .7493 Mdot
.66884 .54748 Mdot
.51203 .42651 Mdot
.51898 .53469 Mdot
.61656 .59159 Mdot
.41464 .63408 Mdot
.50138 .64424 Mdot
.70558 .33631 Mdot
.64211 .27635 Mdot
.61138 .42676 Mdot
.40534 .82739 Mdot
.23319 .68645 Mdot
.40454 .5302 Mdot
.31666 .65204 Mdot
.27909 .58939 Mdot
.43245 .44309 Mdot
.44161 .45925 Mdot
.66309 .50705 Mdot
.37751 .53105 Mdot
.62617 .70406 Mdot
.64651 .4267 Mdot
.49433 .34234 Mdot
.42592 .69029 Mdot
.51133 .35419 Mdot
.69669 .321 Mdot
.51542 .53379 Mdot
.66006 .46126 Mdot
.37438 .42091 Mdot
.35963 .4883 Mdot
.4434 .63721 Mdot
.38702 .64954 Mdot
.40413 .69447 Mdot
.51058 .33689 Mdot
.6406 .42544 Mdot
.4123 .78893 Mdot
.35724 .48255 Mdot
.43792 .66998 Mdot
.51349 .41344 Mdot
.3615 .51048 Mdot
.62893 .60434 Mdot
.3955 .50609 Mdot
.41493 .69472 Mdot
.37298 .51462 Mdot
.41851 .64988 Mdot
.63936 .43633 Mdot
.39085 .42776 Mdot
.36816 .46119 Mdot
.28533 .2784 Mdot
.49581 .33401 Mdot
.44583 .70033 Mdot
.58666 .48576 Mdot
.34816 .49084 Mdot
.73241 .53535 Mdot
.42535 .47811 Mdot
.39845 .74855 Mdot
.4218 .51271 Mdot
.66223 .54175 Mdot
.3927 .40348 Mdot
.39018 .44227 Mdot
.53833 .40686 Mdot
.27731 .60052 Mdot
.40524 .59221 Mdot
.61815 .58068 Mdot
.42878 .71356 Mdot
.25911 .35358 Mdot
.58232 .40962 Mdot
.59886 .42469 Mdot
.44459 .259 Mdot
.43163 .43455 Mdot
.40389 .46573 Mdot
.60914 .58118 Mdot
.52078 .34012 Mdot
.44506 .6785 Mdot
.49174 .33425 Mdot
.31185 .26983 Mdot
.52727 .32486 Mdot
.62598 .47987 Mdot
.60475 .36188 Mdot
.43235 .79643 Mdot
.50047 .29892 Mdot
.41102 .69448 Mdot
.67382 .37374 Mdot
.4244 .42698 Mdot
.55795 .36243 Mdot
.49431 .31589 Mdot
.48716 .85827 Mdot
.36412 .44821 Mdot
.5087 .42409 Mdot
.61 .61133 Mdot
.49243 .30539 Mdot
.63275 .59069 Mdot
.36372 .48425 Mdot
.76975 .51621 Mdot
.41586 .64298 Mdot
.65211 .59981 Mdot
.42159 .55147 Mdot
.50465 .34052 Mdot
.65999 .47145 Mdot
.62587 .57198 Mdot
.6274 .57904 Mdot
.73856 .32972 Mdot
.67354 .7646 Mdot
.6377 .42534 Mdot
.22481 .44986 Mdot
.59423 .63246 Mdot
.41724 .42484 Mdot
.48089 .70955 Mdot
.41017 .50424 Mdot
.54926 .78438 Mdot
.65546 .43467 Mdot
.76635 .59495 Mdot
.36697 .51492 Mdot
.40791 .43641 Mdot
.43941 .61155 Mdot
.62678 .44292 Mdot
.42557 .66557 Mdot
.4327 .71445 Mdot
.63771 .43597 Mdot
.4118 .65802 Mdot
.52381 .30117 Mdot
.54588 .66527 Mdot
.61314 .64451 Mdot
.63515 .63715 Mdot
.61997 .4499 Mdot
.65797 .4432 Mdot
.64521 .45072 Mdot
.39594 .50634 Mdot
.4429 .68338 Mdot
.37261 .49527 Mdot
.43311 .46688 Mdot
.23127 .52938 Mdot
.4577 .65108 Mdot
.38174 .49991 Mdot
.55404 .41714 Mdot
.54444 .3617 Mdot
.63966 .46769 Mdot
.60927 .6161 Mdot
.73517 .47119 Mdot
.71467 .63047 Mdot
.41557 .46822 Mdot
.54798 .27725 Mdot
.40691 .69239 Mdot
.51687 .32814 Mdot
.49329 .36166 Mdot
.50891 .32648 Mdot
.62299 .54938 Mdot
.4536 .6976 Mdot
.17568 .53124 Mdot
.40978 .4644 Mdot
.49239 .54639 Mdot
.48008 .6276 Mdot
.57631 .34015 Mdot
.60979 .61901 Mdot
.35991 .50472 Mdot
.60894 .53335 Mdot
.35938 .69537 Mdot
.4084 .50312 Mdot
.39199 .421 Mdot
.73168 .39242 Mdot
.459 .45364 Mdot
.39931 .64837 Mdot
.25108 .3165 Mdot
.3453 .49617 Mdot
.48273 .76883 Mdot
.83777 .57022 Mdot
.42017 .47549 Mdot
.41834 .4405 Mdot
.35969 .46339 Mdot
.38166 .52146 Mdot
.43668 .61902 Mdot
.39465 .28075 Mdot
.59254 .62646 Mdot
.49074 .54169 Mdot
.65092 .63722 Mdot
.68151 .45528 Mdot
.77223 .59253 Mdot
.41104 .63645 Mdot
.52124 .31954 Mdot
.81178 .52054 Mdot
.20268 .4132 Mdot
.65918 .41773 Mdot
.50774 .80913 Mdot
.4941 .32343 Mdot
.40903 .4226 Mdot
.51634 .29161 Mdot
.64129 .47418 Mdot
.63147 .64098 Mdot
.40261 .4156 Mdot
.40057 .67991 Mdot
.43161 .69789 Mdot
.35654 .50203 Mdot
.79817 .5914 Mdot
.6249 .60281 Mdot
.63264 .5761 Mdot
.42386 .49609 Mdot
.3418 .47287 Mdot
.42226 .66465 Mdot
.61896 .42748 Mdot
.26619 .38797 Mdot
.5118 .34714 Mdot
.44416 .49174 Mdot
.3791 .51684 Mdot
.38039 .21861 Mdot
.62077 .6393 Mdot
.59225 .43853 Mdot
.41702 .51446 Mdot
.52632 .73236 Mdot
.41455 .5167 Mdot
.32686 .49656 Mdot
.63439 .46646 Mdot
.36728 .40513 Mdot
.41356 .52987 Mdot
.46108 .62723 Mdot
.62078 .59176 Mdot
.4192 .67986 Mdot
.46761 .68123 Mdot
.48363 .58898 Mdot
.63056 .60564 Mdot
.38539 .50573 Mdot
.61418 .6212 Mdot
.4218 .49405 Mdot
.36652 .52104 Mdot
.60662 .62056 Mdot
.42497 .66454 Mdot
.76928 .39078 Mdot
.78728 .56794 Mdot
.38422 .52378 Mdot
.36955 .53777 Mdot
.39314 .29468 Mdot
.41287 .37333 Mdot
.42787 .44259 Mdot
.41883 .69649 Mdot
.36034 .47523 Mdot
.63838 .59613 Mdot
.51637 .29583 Mdot
.41405 .69082 Mdot
.631 .41679 Mdot
.6648 .42479 Mdot
.56696 .7473 Mdot
.61608 .4118 Mdot
.43673 .45717 Mdot
.41005 .74024 Mdot
.46573 .65077 Mdot
.81443 .5959 Mdot
.63417 .4359 Mdot
.48982 .29948 Mdot
.37273 .46722 Mdot
.48234 .22037 Mdot
.5853 .62889 Mdot
.13446 .5875 Mdot
.1796 .58545 Mdot
.5374 .3301 Mdot
.21044 .6274 Mdot
.67689 .4497 Mdot
.42508 .52375 Mdot
.48487 .32005 Mdot
.66439 .4298 Mdot
.4018 .52174 Mdot
.34009 .51625 Mdot
.2573 .67906 Mdot
.51088 .58268 Mdot
.61357 .62397 Mdot
.63258 .4076 Mdot
.53772 .33839 Mdot
.61085 .47384 Mdot
.45273 .6844 Mdot
.39575 .44487 Mdot
.34693 .51507 Mdot
.623 .4195 Mdot
.60863 .40843 Mdot
.38453 .49415 Mdot
.40415 .6434 Mdot
.65374 .51143 Mdot
.38656 .4616 Mdot
.52551 .62401 Mdot
.43873 .72282 Mdot
.64739 .42211 Mdot
.40163 .43761 Mdot
.47578 .37976 Mdot
.62485 .4244 Mdot
.6417 .46839 Mdot
.36113 .51291 Mdot
.52687 .30587 Mdot
.36164 .53103 Mdot
.59883 .63296 Mdot
.45385 .83196 Mdot
.64089 .59672 Mdot
.71337 .41384 Mdot
.42524 .55106 Mdot
.51829 .69812 Mdot
.43891 .62617 Mdot
.43168 .22967 Mdot
.72781 .45729 Mdot
.39961 .54474 Mdot
.75398 .30935 Mdot
.67753 .63523 Mdot
.80876 .56756 Mdot
.56101 .20908 Mdot
.50112 .30422 Mdot
.63371 .61383 Mdot
.41937 .44086 Mdot
.639 .6525 Mdot
.48385 .32269 Mdot
.60089 .81475 Mdot
.39204 .43677 Mdot
.43558 .68741 Mdot
.38877 .49562 Mdot
.43948 .6921 Mdot
.36381 .5161 Mdot
.32904 .45449 Mdot
.70003 .49655 Mdot
.29844 .37929 Mdot
.42532 .50477 Mdot
.3654 .18978 Mdot
.49483 .38695 Mdot
.50082 .34747 Mdot
.37264 .48742 Mdot
.59124 .41678 Mdot
.5976 .64867 Mdot
.66105 .71886 Mdot
.63864 .45778 Mdot
.61847 .58353 Mdot
.41493 .6623 Mdot
.64957 .43544 Mdot
.66302 .41838 Mdot
.37015 .40314 Mdot
.5321 .3104 Mdot
.646 .62455 Mdot
.40496 .44961 Mdot
.39177 .43759 Mdot
.22079 .44061 Mdot
.68737 .34316 Mdot
.38328 .66001 Mdot
.16068 .46882 Mdot
.41869 .72034 Mdot
.50133 .34387 Mdot
.63889 .46173 Mdot
.43091 .45734 Mdot
.39821 .48543 Mdot
.73347 .51502 Mdot
.39656 .67265 Mdot
.54735 .54602 Mdot
.40389 .75961 Mdot
.58514 .48117 Mdot
.33884 .32347 Mdot
.42349 .6929 Mdot
.33856 .32543 Mdot
.50794 .36571 Mdot
.82263 .41808 Mdot
.31688 .36049 Mdot
.61162 .6115 Mdot
.34387 .32244 Mdot
.44184 .66825 Mdot
.39247 .53005 Mdot
.61404 .46081 Mdot
.60906 .41813 Mdot
.42284 .67381 Mdot
.59602 .46085 Mdot
.51268 .30224 Mdot
.41511 .44387 Mdot
.17987 .50149 Mdot
.57976 .72757 Mdot
.61582 .44652 Mdot
.32019 .48721 Mdot
.64713 .61097 Mdot
.35597 .50187 Mdot
.50792 .29765 Mdot
.62064 .6171 Mdot
.41232 .2225 Mdot
.57865 .65136 Mdot
.37545 .4677 Mdot
.39022 .20484 Mdot
.6284 .61044 Mdot
.44417 .38472 Mdot
.39114 .45572 Mdot
.59554 .62384 Mdot
.43561 .3919 Mdot
.73196 .59311 Mdot
.58799 .52772 Mdot
.67562 .23016 Mdot
.57205 .52329 Mdot
.61259 .45439 Mdot
.74426 .59733 Mdot
.67389 .57091 Mdot
.61614 .65127 Mdot
.59581 .42314 Mdot
.54721 .33002 Mdot
.63078 .58994 Mdot
.39342 .42321 Mdot
.42292 .47955 Mdot
.57596 .8149 Mdot
.67944 .60038 Mdot
.72609 .638 Mdot
.61975 .74038 Mdot
.34765 .48614 Mdot
.35666 .52735 Mdot
.39889 .48024 Mdot
.41976 .61636 Mdot
.61655 .63159 Mdot
.30954 .23675 Mdot
.62958 .60187 Mdot
.19794 .53481 Mdot
.62146 .44876 Mdot
.6561 .42378 Mdot
.41546 .46446 Mdot
.4953 .42284 Mdot
.37275 .26566 Mdot
.39063 .49002 Mdot
.53029 .28087 Mdot
.64542 .76039 Mdot
.34265 .47851 Mdot
.42157 .62394 Mdot
.31867 .46605 Mdot
.30938 .47597 Mdot
.61314 .64479 Mdot
.51212 .30973 Mdot
.42148 .23017 Mdot
.63846 .63922 Mdot
.40328 .46704 Mdot
.52604 .69869 Mdot
.40878 .49417 Mdot
.38969 .52407 Mdot
.19093 .58272 Mdot
.5066 .36168 Mdot
.6414 .44533 Mdot
.50734 .32865 Mdot
.43721 .62893 Mdot
.093 .53116 Mdot
.52752 .3323 Mdot
.37816 .25804 Mdot
.55562 .8282 Mdot
.34635 .32396 Mdot
.44516 .69197 Mdot
.52947 .30154 Mdot
.61887 .60532 Mdot
.78703 .3289 Mdot
.30101 .72589 Mdot
.66095 .67392 Mdot
.38975 .46493 Mdot
.39081 .68496 Mdot
.4222 .70247 Mdot
.65469 .60191 Mdot
.44907 .66643 Mdot
.46085 .4285 Mdot
.39043 .52765 Mdot
.62771 .65422 Mdot
.53721 .72304 Mdot
.61678 .58086 Mdot
.5618 .64932 Mdot
.37698 .48533 Mdot
.41918 .69039 Mdot
.44114 .50522 Mdot
.44657 .71909 Mdot
.60078 .46134 Mdot
.34851 .44147 Mdot
.51502 .30373 Mdot
.5135 .72027 Mdot
.63635 .42391 Mdot
.56437 .30645 Mdot
.44402 .6366 Mdot
.58769 .57645 Mdot
.45055 .64982 Mdot
.46285 .68803 Mdot
.62803 .58293 Mdot
.43357 .64818 Mdot
.41689 .44097 Mdot
.56055 .46244 Mdot
.43042 .63342 Mdot
.63843 .62422 Mdot
.50969 .31201 Mdot
.41777 .65551 Mdot
.61787 .38375 Mdot
.37478 .4606 Mdot
.65413 .45651 Mdot
.59182 .24312 Mdot
.39737 .69977 Mdot
.51832 .35595 Mdot
.60345 .41735 Mdot
.49684 .35046 Mdot
.78177 .66263 Mdot
.65462 .64625 Mdot
.20683 .56745 Mdot
.54254 .31577 Mdot
.41145 .70463 Mdot
.60656 .24615 Mdot
.43019 .46213 Mdot
.37336 .46344 Mdot
.50318 .2823 Mdot
.42173 .70249 Mdot
.83335 .48125 Mdot
.34611 .55071 Mdot
.54991 .64183 Mdot
.66148 .59755 Mdot
.378 .19702 Mdot
.57461 .66356 Mdot
.8258 .63969 Mdot
.40105 .5494 Mdot
.64561 .39677 Mdot
.41104 .47377 Mdot
.72118 .47695 Mdot
.50388 .33817 Mdot
.70194 .41871 Mdot
.33284 .48559 Mdot
.64345 .44015 Mdot
.37118 .4514 Mdot
.54072 .42543 Mdot
.35838 .40003 Mdot
.48733 .30265 Mdot
.78158 .50017 Mdot
.41919 .71173 Mdot
.49907 .31311 Mdot
.67096 .45031 Mdot
.36039 .28985 Mdot
.39776 .52437 Mdot
.45173 .44523 Mdot
.58491 .48072 Mdot
.44382 .68653 Mdot
.606 .45064 Mdot
.60647 .63962 Mdot
.51846 .31814 Mdot
.36107 .49076 Mdot
.43628 .47978 Mdot
.72744 .5364 Mdot
.64843 .61023 Mdot
.62012 .40385 Mdot
.6118 .60195 Mdot
.67704 .4381 Mdot
.3663 .5245 Mdot
.65274 .41811 Mdot
.44788 .47864 Mdot
.69514 .50548 Mdot
.19488 .56887 Mdot
.28987 .62235 Mdot
.65518 .43225 Mdot
.31195 .32714 Mdot
.64306 .60574 Mdot
.60185 .61205 Mdot
.48448 .82257 Mdot
.23407 .6415 Mdot
.20919 .43602 Mdot
.69257 .27577 Mdot
.64432 .64346 Mdot
.6454 .61563 Mdot
.65693 .45391 Mdot
.43492 .64665 Mdot
.42855 .71921 Mdot
.67552 .43279 Mdot
.43866 .32628 Mdot
.44493 .67837 Mdot
.77845 .34227 Mdot
.23662 .38425 Mdot
.4454 .45764 Mdot
.59196 .46323 Mdot
.51501 .3226 Mdot
.43062 .31725 Mdot
.54203 .42077 Mdot
.41069 .43571 Mdot
.46158 .22616 Mdot
.61763 .44076 Mdot
.49505 .45217 Mdot
.63409 .21683 Mdot
.3784 .43839 Mdot
.39484 .45203 Mdot
.40363 .47466 Mdot
.53473 .33216 Mdot
.27149 .68895 Mdot
.4055 .44039 Mdot
.43898 .3294 Mdot
.35073 .49473 Mdot
.42856 .38465 Mdot
.50513 .32354 Mdot
.28943 .41363 Mdot
.70943 .33344 Mdot
.24934 .32597 Mdot
.35816 .3959 Mdot
.60404 .63881 Mdot
.50661 .25649 Mdot
.60772 .60206 Mdot
.26231 .61398 Mdot
.32549 .35747 Mdot
.40472 .71545 Mdot
.41434 .43676 Mdot
.64901 .42924 Mdot
.42394 .70214 Mdot
.73852 .56671 Mdot
.08263 .4836 Mdot
.60218 .63926 Mdot
.86463 .59851 Mdot
.59684 .62499 Mdot
.66395 .41854 Mdot
.42137 .66516 Mdot
.35665 .63958 Mdot
.48944 .56607 Mdot
.41597 .65452 Mdot
.79718 .43892 Mdot
.41632 .60489 Mdot
.33143 .31653 Mdot
.39327 .67739 Mdot
.64128 .61845 Mdot
.62889 .55234 Mdot
.44876 .54308 Mdot
.42652 .46259 Mdot
.5215 .52872 Mdot
.35195 .28249 Mdot
.42922 .45999 Mdot
.64406 .42666 Mdot
.20847 .5821 Mdot
.4491 .24073 Mdot
.43507 .65399 Mdot
.60115 .66367 Mdot
.39108 .44833 Mdot
.39152 .51708 Mdot
.39806 .52616 Mdot
.15359 .53681 Mdot
.82491 .42178 Mdot
.38352 .53075 Mdot
.34969 .50074 Mdot
.64658 .43702 Mdot
.52921 .36299 Mdot
.74045 .42588 Mdot
.23446 .48832 Mdot
.40191 .42864 Mdot
.49934 .31823 Mdot
.52336 .36018 Mdot
.40986 .52064 Mdot
.56104 .36191 Mdot
.52664 .68973 Mdot
.40418 .44859 Mdot
.21275 .58519 Mdot
.56789 .45062 Mdot
.63444 .4028 Mdot
.62671 .41886 Mdot
.44724 .69479 Mdot
.63392 .41107 Mdot
.67475 .44955 Mdot
.36558 .64909 Mdot
.56011 .5284 Mdot
.60605 .66899 Mdot
.51195 .33679 Mdot
.40074 .48893 Mdot
.40092 .58923 Mdot
.52351 .72194 Mdot
.62648 .58702 Mdot
.40453 .68341 Mdot
.59395 .64476 Mdot
.47638 .29719 Mdot
.46105 .57405 Mdot
.61256 .43618 Mdot
.63814 .6456 Mdot
.57486 .63302 Mdot
.50105 .3181 Mdot
.64695 .59818 Mdot
.57828 .61475 Mdot
.3584 .43453 Mdot
.31705 .67036 Mdot
.38689 .48609 Mdot
.81716 .52843 Mdot
.64969 .62057 Mdot
.67114 .53226 Mdot
.40322 .45864 Mdot
.62548 .42609 Mdot
.441 .5569 Mdot
.43048 .47051 Mdot
.62572 .41499 Mdot
.40337 .53051 Mdot
.49575 .35462 Mdot
.44837 .71521 Mdot
.48549 .55527 Mdot
.37784 .82736 Mdot
.53184 .309 Mdot
.73982 .55833 Mdot
.4246 .43903 Mdot
.7193 .72848 Mdot
.42028 .65507 Mdot
.43712 .49999 Mdot
.42853 .24642 Mdot
.43026 .63721 Mdot
.40843 .67747 Mdot
.38793 .51178 Mdot
.61148 .60786 Mdot
.63986 .42245 Mdot
.50451 .31919 Mdot
.82112 .62365 Mdot
.38403 .46988 Mdot
.36466 .46634 Mdot
.49567 .31795 Mdot
.64538 .60471 Mdot
.41857 .51136 Mdot
.55653 .22851 Mdot
.8439 .47633 Mdot
.60031 .60997 Mdot
.39558 .42407 Mdot
.2758 .65625 Mdot
.31332 .50346 Mdot
.64223 .81981 Mdot
.55975 .35344 Mdot
.64776 .44366 Mdot
.4613 .48869 Mdot
.11376 .50748 Mdot
.51258 .31193 Mdot
.2037 .41969 Mdot
.38769 .51788 Mdot
.35586 .48223 Mdot
.40431 .69363 Mdot
.37625 .49557 Mdot
.40406 .64931 Mdot
.3634 .80967 Mdot
.37561 .21909 Mdot
.45061 .68263 Mdot
.40867 .70564 Mdot
.40089 .24809 Mdot
.73642 .44214 Mdot
.42078 .67224 Mdot
.36138 .51728 Mdot
.30337 .42127 Mdot
.42234 .58376 Mdot
.51409 .28823 Mdot
.66371 .28492 Mdot
.38567 .57739 Mdot
.49862 .27327 Mdot
.74816 .34723 Mdot
.38137 .57949 Mdot
.55749 .58553 Mdot
.60476 .63436 Mdot
.37983 .43696 Mdot
.61063 .41527 Mdot
.61743 .40939 Mdot
.42706 .52974 Mdot
.40235 .49551 Mdot
.43973 .63117 Mdot
.52167 .33154 Mdot
.6039 .64512 Mdot
.35811 .4898 Mdot
.4218 .23865 Mdot
.52263 .33995 Mdot
.44427 .65388 Mdot
.22182 .53825 Mdot
.48068 .32572 Mdot
.33781 .44053 Mdot
.41394 .454 Mdot
.38835 .50002 Mdot
.41463 .58425 Mdot
.61185 .63202 Mdot
.63892 .25986 Mdot
.35826 .44476 Mdot
.3073 .27275 Mdot
.65928 .65287 Mdot
.38516 .41125 Mdot
.4523 .67001 Mdot
.59046 .66115 Mdot
.65054 .47737 Mdot
.47881 .59538 Mdot
.37668 .46941 Mdot
.79431 .56387 Mdot
.59687 .8045 Mdot
.60145 .45941 Mdot
.4607 .69139 Mdot
.51336 .32888 Mdot
.39253 .49079 Mdot
.23041 .5727 Mdot
.4231 .47571 Mdot
.48386 .29606 Mdot
.63634 .46955 Mdot
.60346 .63217 Mdot
.81296 .55596 Mdot
.62367 .40866 Mdot
.41103 .67925 Mdot
.50727 .14403 Mdot
.40558 .645 Mdot
.43437 .7162 Mdot
.23383 .53869 Mdot
.6095 .6308 Mdot
.11662 .53998 Mdot
.39959 .80854 Mdot
.33989 .46206 Mdot
.64093 .60338 Mdot
.42711 .67907 Mdot
.35208 .48461 Mdot
.39412 .71102 Mdot
.45643 .6922 Mdot
.35976 .51857 Mdot
.35895 .4605 Mdot
.73771 .64874 Mdot
.66949 .23343 Mdot
.51327 .33055 Mdot
.44905 .63666 Mdot
.52094 .62393 Mdot
.35104 .4795 Mdot
.40935 .46352 Mdot
.68648 .58724 Mdot
.51964 .29637 Mdot
.6206 .71126 Mdot
.38987 .51749 Mdot
.39821 .21264 Mdot
.34888 .41886 Mdot
.42848 .61853 Mdot
.60952 .59714 Mdot
.25603 .31994 Mdot
.64329 .56706 Mdot
.40308 .65294 Mdot
.52389 .32279 Mdot
.45749 .62842 Mdot
.37539 .25793 Mdot
.65474 .61919 Mdot
.41495 .69477 Mdot
.61422 .53445 Mdot
.62251 .62733 Mdot
.647 .63405 Mdot
.23832 .52834 Mdot
.5921 .42653 Mdot
.5341 .33759 Mdot
.6468 .62062 Mdot
.49489 .7064 Mdot
.63525 .62219 Mdot
.42303 .80706 Mdot
.3898 .4275 Mdot
.45036 .28262 Mdot
.71027 .41862 Mdot
.4569 .51642 Mdot
.6516 .62378 Mdot
.49838 .29874 Mdot
.40404 .51915 Mdot
.44407 .66762 Mdot
.50642 .35162 Mdot
.6542 .68508 Mdot
.64637 .4555 Mdot
.44807 .64663 Mdot
.64119 .56965 Mdot
.43509 .69537 Mdot
.50066 .64048 Mdot
.52242 .8374 Mdot
.47464 .19714 Mdot
.49386 .57941 Mdot
.39529 .52514 Mdot
.70905 .30516 Mdot
.4392 .43406 Mdot
.40339 .50009 Mdot
.647 .42368 Mdot
.44992 .26403 Mdot
.42504 .66535 Mdot
.82977 .50828 Mdot
.62101 .64588 Mdot
.25757 .31077 Mdot
.31559 .42564 Mdot
.41819 .52323 Mdot
.42741 .63293 Mdot
.40039 .65194 Mdot
.26601 .58382 Mdot
.66047 .47565 Mdot
.44179 .46517 Mdot
.42493 .42473 Mdot
.40746 .53841 Mdot
.62797 .64333 Mdot
.56072 .3001 Mdot
.6129 .45308 Mdot
.59272 .8291 Mdot
.62917 .46889 Mdot
.51171 .26586 Mdot
.43654 .65151 Mdot
.52749 .33141 Mdot
.40918 .46133 Mdot
.40133 .61961 Mdot
.39659 .67034 Mdot
.4945 .28902 Mdot
.48922 .3109 Mdot
.71006 .58735 Mdot
.60716 .62103 Mdot
.43315 .48628 Mdot
.40357 .43816 Mdot
.37104 .49789 Mdot
.39656 .50421 Mdot
.60888 .64435 Mdot
.41068 .51357 Mdot
.59659 .59838 Mdot
.48725 .67576 Mdot
.50252 .24038 Mdot
.5716 .51827 Mdot
.53598 .79478 Mdot
.43907 .66073 Mdot
.50331 .69866 Mdot
.36365 .55684 Mdot
.1912 .62242 Mdot
.66689 .75153 Mdot
.35186 .44787 Mdot
.66198 .42367 Mdot
.46122 .41171 Mdot
.60976 .42824 Mdot
.81926 .67114 Mdot
.71062 .53627 Mdot
.70894 .26293 Mdot
.39013 .43839 Mdot
.57136 .47761 Mdot
.47037 .74621 Mdot
.44364 .43673 Mdot
.71553 .55513 Mdot
.54134 .78767 Mdot
.78561 .519 Mdot
.51073 .2963 Mdot
.38074 .45769 Mdot
.40467 .59077 Mdot
.415 .44178 Mdot
.41172 .46917 Mdot
.40457 .52102 Mdot
.60629 .59133 Mdot
.44104 .47985 Mdot
.40957 .50874 Mdot
.59316 .3502 Mdot
.32576 .34126 Mdot
.60962 .41044 Mdot
.51563 .82383 Mdot
.52763 .33354 Mdot
.43629 .63218 Mdot
.80733 .40815 Mdot
.61142 .61248 Mdot
.26972 .58337 Mdot
.39292 .50258 Mdot
.75822 .61717 Mdot
.58552 .65163 Mdot
.51926 .31368 Mdot
.63856 .47494 Mdot
.74686 .28875 Mdot
.64283 .43023 Mdot
.62618 .54254 Mdot
.62721 .42771 Mdot
.37068 .56286 Mdot
.441 .6315 Mdot
.42688 .49842 Mdot
.64376 .62787 Mdot
.63871 .41382 Mdot
.39901 .30139 Mdot
.40075 .48023 Mdot
.63734 .43678 Mdot
.427 .49786 Mdot
.46687 .55668 Mdot
.23532 .44724 Mdot
.6739 .44567 Mdot
.58812 .65271 Mdot
.62828 .63475 Mdot
.52791 .3087 Mdot
.44088 .63827 Mdot
.40141 .67402 Mdot
.62195 .61778 Mdot
.26048 .69281 Mdot
.41026 .42947 Mdot
.35268 .47211 Mdot
.27394 .29935 Mdot
.42565 .44542 Mdot
.34719 .30239 Mdot
.60056 .52887 Mdot
.44378 .66012 Mdot
.40609 .53412 Mdot
.38328 .51444 Mdot
.37471 .46668 Mdot
.48859 .63659 Mdot
.61789 .42767 Mdot
.38172 .43387 Mdot
.48772 .31774 Mdot
.57247 .38696 Mdot
.35596 .50228 Mdot
.40262 .3964 Mdot
.40166 .67732 Mdot
.1628 .47812 Mdot
.5979 .62563 Mdot
.67074 .44526 Mdot
.65703 .43313 Mdot
.67957 .29708 Mdot
.5048 .75451 Mdot
.59852 .52652 Mdot
.62609 .81599 Mdot
.69944 .49648 Mdot
.49564 .33888 Mdot
.62032 .48828 Mdot
.63508 .55291 Mdot
.66443 .44726 Mdot
.60242 .64044 Mdot
.38498 .42855 Mdot
.39943 .42814 Mdot
.18515 .63841 Mdot
.40842 .52323 Mdot
.51225 .32487 Mdot
.62411 .57628 Mdot
.44117 .66835 Mdot
.51988 .31608 Mdot
.61244 .60011 Mdot
.44838 .68291 Mdot
.36262 .4374 Mdot
.36639 .43549 Mdot
.40403 .68035 Mdot
.41571 .69921 Mdot
.41043 .4545 Mdot
.72297 .41233 Mdot
.41602 .70722 Mdot
.42077 .69451 Mdot
.61257 .44128 Mdot
.61181 .41604 Mdot
.38493 .40405 Mdot
.63931 .60599 Mdot
.40964 .51026 Mdot
.64897 .43341 Mdot
.52697 .32471 Mdot
.42731 .66349 Mdot
.38416 .52275 Mdot
.36157 .50528 Mdot
.50224 .31641 Mdot
.52389 .30937 Mdot
.50144 .30001 Mdot
.61122 .5836 Mdot
.36836 .48945 Mdot
.4169 .66652 Mdot
.60541 .62425 Mdot
.52609 .35687 Mdot
.50856 .28913 Mdot
.63134 .48602 Mdot
.43104 .45268 Mdot
.66697 .38009 Mdot
.11023 .47386 Mdot
.31059 .28555 Mdot
.6156 .47213 Mdot
.63373 .47886 Mdot
.36275 .3297 Mdot
.5023 .45762 Mdot
.62516 .60691 Mdot
.50855 .37554 Mdot
.41802 .22909 Mdot
.37464 .42451 Mdot
.34498 .49224 Mdot
.3259 .46955 Mdot
.49547 .30464 Mdot
.46378 .25227 Mdot
.41282 .63473 Mdot
.33833 .55819 Mdot
.51798 .347 Mdot
.60954 .40809 Mdot
.60949 .4786 Mdot
.63288 .47011 Mdot
.37801 .43048 Mdot
.29735 .62382 Mdot
.49992 .72896 Mdot
.65596 .25138 Mdot
.65115 .61564 Mdot
.40192 .588 Mdot
.71869 .72516 Mdot
.40566 .67776 Mdot
.68149 .45843 Mdot
.49272 .33729 Mdot
.41935 .6992 Mdot
.59472 .64999 Mdot
.64544 .61902 Mdot
.6165 .44903 Mdot
.62172 .45432 Mdot
.65369 .46252 Mdot
.45419 .70039 Mdot
.43514 .64946 Mdot
.37614 .47257 Mdot
.43059 .66123 Mdot
.1743 .58775 Mdot
.51445 .28249 Mdot
.67569 .40351 Mdot
.63462 .61074 Mdot
.44647 .68775 Mdot
.39803 .48159 Mdot
.49637 .4795 Mdot
.59359 .75859 Mdot
.4924 .34352 Mdot
.22679 .44195 Mdot
.80761 .68154 Mdot
.43453 .48312 Mdot
.61735 .63625 Mdot
.18106 .49359 Mdot
.40113 .47453 Mdot
.63396 .46326 Mdot
.73684 .4072 Mdot
.58044 .46381 Mdot
.43089 .47389 Mdot
.37772 .42135 Mdot
.59505 .61901 Mdot
.61653 .81325 Mdot
.37984 .47309 Mdot
.59705 .7066 Mdot
.63637 .65661 Mdot
.61576 .45828 Mdot
.84097 .40581 Mdot
.56998 .24764 Mdot
.43589 .31844 Mdot
.61395 .44985 Mdot
.41473 .49249 Mdot
.61247 .42725 Mdot
.48859 .33498 Mdot
.66486 .46527 Mdot
.40986 .636 Mdot
.60281 .45694 Mdot
.36427 .46585 Mdot
.42113 .67493 Mdot
.62879 .6091 Mdot
.23143 .3581 Mdot
.6664 .36022 Mdot
.62407 .42757 Mdot
.67221 .43519 Mdot
.40554 .53266 Mdot
.63964 .70464 Mdot
.4419 .51197 Mdot
.36662 .44615 Mdot
.6492 .63859 Mdot
.4331 .63585 Mdot
.60905 .5942 Mdot
.4342 .41482 Mdot
.54861 .2201 Mdot
.60919 .60519 Mdot
.78846 .55988 Mdot
.49387 .32607 Mdot
.53551 .46236 Mdot
.39773 .48742 Mdot
.64021 .59286 Mdot
.3695 .48783 Mdot
.41902 .62966 Mdot
.56167 .48893 Mdot
.77411 .52132 Mdot
.6395 .63611 Mdot
.80137 .55952 Mdot
.4895 .25997 Mdot
.43245 .40371 Mdot
.60294 .60877 Mdot
.43756 .24628 Mdot
.66271 .41752 Mdot
.5114 .34819 Mdot
.48578 .34242 Mdot
.50926 .35394 Mdot
.42087 .54176 Mdot
.34004 .40288 Mdot
.50993 .36141 Mdot
.60114 .65203 Mdot
.48693 .30385 Mdot
.46412 .77741 Mdot
.82606 .49962 Mdot
.5018 .33586 Mdot
.38996 .45901 Mdot
.31646 .493 Mdot
.33964 .3394 Mdot
.72831 .60133 Mdot
.72637 .27905 Mdot
.65965 .73047 Mdot
.42604 .46539 Mdot
.43923 .72022 Mdot
.45821 .66805 Mdot
.18357 .4648 Mdot
.33521 .29556 Mdot
.3426 .25097 Mdot
.41502 .71301 Mdot
.75265 .50216 Mdot
.44539 .65098 Mdot
.40309 .5256 Mdot
.35227 .47734 Mdot
.41137 .7126 Mdot
.49885 .23469 Mdot
.75451 .52696 Mdot
.81798 .58603 Mdot
.42831 .69692 Mdot
.6194 .59215 Mdot
.65193 .59286 Mdot
.64849 .63294 Mdot
.22665 .40083 Mdot
.4182 .63886 Mdot
.3663 .50132 Mdot
.6546 .43077 Mdot
.39043 .43149 Mdot
.61853 .62695 Mdot
.83215 .50245 Mdot
.41786 .6474 Mdot
.39447 .44327 Mdot
.47908 .46354 Mdot
.63177 .45724 Mdot
.49725 .32442 Mdot
.46874 .54334 Mdot
.34031 .25601 Mdot
.63034 .64568 Mdot
.40034 .70435 Mdot
.68724 .52492 Mdot
.8077 .51447 Mdot
.39347 .5507 Mdot
.42729 .42411 Mdot
.81971 .63549 Mdot
.40066 .22156 Mdot
.43528 .45012 Mdot
.66946 .43568 Mdot
.72831 .51581 Mdot
.36635 .51313 Mdot
.45705 .65412 Mdot
.48187 .3342 Mdot
.49786 .35042 Mdot
.39208 .40149 Mdot
.49582 .53462 Mdot
.5634 .47488 Mdot
.38688 .50669 Mdot
.33404 .4458 Mdot
.61547 .45638 Mdot
.71155 .48034 Mdot
.31324 .26793 Mdot
.52439 .31885 Mdot
.42473 .50163 Mdot
.77282 .41593 Mdot
.39978 .6891 Mdot
.60593 .46408 Mdot
.65277 .60692 Mdot
.4742 .61786 Mdot
.64238 .47493 Mdot
.37268 .52146 Mdot
.41343 .51691 Mdot
.63512 .58473 Mdot
.42638 .61827 Mdot
.49375 .30808 Mdot
.65494 .42495 Mdot
.51972 .30419 Mdot
.42753 .63739 Mdot
.43015 .65498 Mdot
.47199 .44103 Mdot
.38253 .55496 Mdot
.63009 .41782 Mdot
.44828 .4798 Mdot
.5688 .43198 Mdot
.68583 .788 Mdot
.65293 .58309 Mdot
.43742 .47047 Mdot
.40772 .62725 Mdot
.63498 .64058 Mdot
.35529 .47368 Mdot
.83304 .61272 Mdot
.35017 .48389 Mdot
.65613 .65372 Mdot
.45892 .18883 Mdot
.51021 .29935 Mdot
.33365 .55144 Mdot
.71952 .68608 Mdot
.42357 .44688 Mdot
.66025 .44139 Mdot
.3228 .49529 Mdot
.6163 .60413 Mdot
.43545 .65326 Mdot
.6607 .81431 Mdot
.63469 .62583 Mdot
.41113 .44458 Mdot
.51896 .3174 Mdot
.39489 .66873 Mdot
.55091 .30979 Mdot
.56175 .36004 Mdot
.39212 .39132 Mdot
.44478 .49088 Mdot
.39733 .51032 Mdot
.58888 .22839 Mdot
.66984 .44823 Mdot
.42781 .68762 Mdot
.61832 .63803 Mdot
.62166 .61445 Mdot
.61648 .44287 Mdot
.58447 .66329 Mdot
.53629 .46471 Mdot
.14747 .41414 Mdot
.62052 .41573 Mdot
.52007 .35112 Mdot
.61883 .70698 Mdot
.66179 .43171 Mdot
.63352 .43868 Mdot
.61141 .44159 Mdot
.58788 .55752 Mdot
.44557 .68372 Mdot
.36969 .52001 Mdot
.4449 .62822 Mdot
.41431 .49525 Mdot
.65348 .65649 Mdot
.64344 .6319 Mdot
.42265 .64477 Mdot
.80323 .64647 Mdot
.31333 .69051 Mdot
.39732 .46662 Mdot
.72018 .72634 Mdot
.33837 .50108 Mdot
.36472 .31128 Mdot
.33678 .50504 Mdot
.6211 .43907 Mdot
.4557 .47733 Mdot
.40919 .53912 Mdot
.18943 .43332 Mdot
.63506 .60775 Mdot
.6416 .40397 Mdot
.33553 .46182 Mdot
.33025 .44853 Mdot
.44943 .70673 Mdot
.42032 .69811 Mdot
.49051 .34794 Mdot
.2913 .38739 Mdot
.62926 .60607 Mdot
.39023 .79259 Mdot
.42453 .46052 Mdot
.53595 .25571 Mdot
.28131 .51033 Mdot
.35643 .46923 Mdot
.73096 .68458 Mdot
.29036 .61387 Mdot
.39414 .48993 Mdot
.52742 .58092 Mdot
.64514 .60712 Mdot
.5329 .21337 Mdot
.35286 .50165 Mdot
.63663 .45939 Mdot
.43893 .64859 Mdot
.40032 .64832 Mdot
.50021 .35845 Mdot
.22133 .67326 Mdot
.61397 .5886 Mdot
.42939 .64722 Mdot
.40558 .48178 Mdot
.61274 .63571 Mdot
.63022 .41009 Mdot
.42295 .51767 Mdot
.32461 .30365 Mdot
.43523 .66601 Mdot
.39002 .53632 Mdot
.57264 .69833 Mdot
.39365 .33854 Mdot
.50967 .16881 Mdot
.61909 .63973 Mdot
.52397 .3033 Mdot
.32149 .47883 Mdot
.24811 .66957 Mdot
.3574 .5302 Mdot
.45365 .29437 Mdot
.471 .78006 Mdot
.51832 .2971 Mdot
.39939 .45768 Mdot
.36199 .49421 Mdot
.50255 .40856 Mdot
.52525 .32387 Mdot
.39552 .43653 Mdot
.46735 .7099 Mdot
.44021 .6878 Mdot
.68064 .44725 Mdot
.44214 .67345 Mdot
.3903 .46449 Mdot
.37476 .55239 Mdot
.40762 .69648 Mdot
.72079 .74689 Mdot
.53389 .29972 Mdot
.59951 .62153 Mdot
.34301 .5002 Mdot
.35303 .45427 Mdot
.31304 .21959 Mdot
.59686 .4511 Mdot
.74554 .43942 Mdot
.58218 .29963 Mdot
.75755 .37727 Mdot
.56773 .24643 Mdot
.61346 .19089 Mdot
.40596 .21714 Mdot
.44129 .48431 Mdot
.3005 .48211 Mdot
.52107 .66137 Mdot
.6525 .61541 Mdot
.40056 .77073 Mdot
.42684 .46274 Mdot
.4121 .47166 Mdot
.61251 .47181 Mdot
.77744 .57315 Mdot
.3412 .25096 Mdot
.49842 .48781 Mdot
.49457 .30851 Mdot
.45094 .64018 Mdot
.3668 .51972 Mdot
.54218 .55968 Mdot
.60624 .41218 Mdot
.52714 .24908 Mdot
.39529 .44514 Mdot
.19097 .59815 Mdot
.56842 .7607 Mdot
.60985 .62633 Mdot
.65862 .43492 Mdot
.36207 .23887 Mdot
.4317 .45754 Mdot
.65201 .60237 Mdot
.38608 .47468 Mdot
.68584 .48924 Mdot
.43956 .41907 Mdot
.50442 .34197 Mdot
.38991 .51966 Mdot
.50249 .26051 Mdot
.45111 .1307 Mdot
.48738 .36321 Mdot
.3926 .70439 Mdot
.6634 .39884 Mdot
.61958 .42345 Mdot
.41617 .69776 Mdot
.62288 .42161 Mdot
.2662 .55949 Mdot
.35537 .60761 Mdot
.49291 .32015 Mdot
.34952 .42428 Mdot
.50331 .33204 Mdot
.6025 .46261 Mdot
.42856 .46806 Mdot
.7429 .74564 Mdot
.64018 .41717 Mdot
.41963 .1946 Mdot
.63281 .62141 Mdot
.60795 .40908 Mdot
.35133 .49612 Mdot
.67781 .53535 Mdot
.62283 .40843 Mdot
.7693 .53616 Mdot
.37481 .46752 Mdot
.43594 .66108 Mdot
.36651 .51123 Mdot
.33891 .47321 Mdot
.6339 .39598 Mdot
.41789 .49783 Mdot
.61326 .59942 Mdot
.42954 .71363 Mdot
.78236 .33438 Mdot
.51651 .78968 Mdot
.40864 .4365 Mdot
.40462 .47961 Mdot
.46522 .65389 Mdot
.37147 .43743 Mdot
.60856 .64398 Mdot
.27738 .80254 Mdot
.4941 .32606 Mdot
.65581 .40464 Mdot
.56702 .24467 Mdot
.35686 .44136 Mdot
.40692 .51706 Mdot
.84324 .59023 Mdot
.53719 .22469 Mdot
.60644 .60478 Mdot
.40178 .54183 Mdot
.62951 .4091 Mdot
.51788 .32094 Mdot
.60776 .6517 Mdot
.38726 .49888 Mdot
.40616 .46027 Mdot
.52805 .31169 Mdot
.3135 .40222 Mdot
.25228 .35678 Mdot
.64131 .59014 Mdot
.45223 .50916 Mdot
.62617 .38498 Mdot
.42281 .43339 Mdot
.21749 .4222 Mdot
.4155 .69264 Mdot
.63297 .64631 Mdot
.71757 .32531 Mdot
.43517 .463 Mdot
.6156 .59148 Mdot
.63045 .6057 Mdot
.39214 .54152 Mdot
.4054 .62868 Mdot
.44325 .70452 Mdot
.43855 .69433 Mdot
.19068 .6679 Mdot
.4219 .31073 Mdot
.6535 .46258 Mdot
.64542 .60658 Mdot
.67556 .44372 Mdot
.49343 .2795 Mdot
.59071 .53255 Mdot
.6737 .44015 Mdot
.44106 .69735 Mdot
.67402 .40723 Mdot
.36422 .481 Mdot
.62749 .60858 Mdot
.66272 .45133 Mdot
.34271 .45476 Mdot
.63636 .69922 Mdot
.70656 .66311 Mdot
.50109 .29237 Mdot
.48475 .34417 Mdot
.35358 .49089 Mdot
.67111 .47081 Mdot
.41122 .45672 Mdot
.65128 .6404 Mdot
.62347 .70234 Mdot
.34436 .50142 Mdot
.62235 .42832 Mdot
.46394 .64151 Mdot
.3496 .24931 Mdot
.44865 .49816 Mdot
.39113 .4588 Mdot
.41748 .49386 Mdot
.38569 .47505 Mdot
.79707 .49926 Mdot
.66382 .60996 Mdot
.53474 .79388 Mdot
.62 .25024 Mdot
.41332 .65297 Mdot
.45477 .63665 Mdot
.29989 .29167 Mdot
.52979 .67536 Mdot
.64069 .60602 Mdot
.40108 .50163 Mdot
.52865 .7428 Mdot
.84237 .47438 Mdot
.80554 .66744 Mdot
.48876 .39482 Mdot
.59325 .4319 Mdot
.40491 .70805 Mdot
.6507 .41362 Mdot
.41861 .48591 Mdot
.32482 .46606 Mdot
.58864 .17273 Mdot
.61087 .65736 Mdot
.49169 .32516 Mdot
.4129 .499 Mdot
.42369 .31524 Mdot
.64839 .43663 Mdot
.61827 .39874 Mdot
.37513 .439 Mdot
.4342 .61595 Mdot
.4029 .16606 Mdot
.61278 .63277 Mdot
.65986 .72647 Mdot
.46745 .75088 Mdot
.62612 .74273 Mdot
.61658 .62861 Mdot
.51127 .38594 Mdot
.61293 .46914 Mdot
.26234 .4811 Mdot
.40991 .65493 Mdot
.50461 .3507 Mdot
.38931 .41095 Mdot
.4014 .68517 Mdot
.61951 .46488 Mdot
.43557 .65659 Mdot
.40293 .52165 Mdot
.65091 .64972 Mdot
.64966 .4445 Mdot
.60738 .6695 Mdot
.41799 .61569 Mdot
.52337 .32038 Mdot
.51222 .49159 Mdot
.3613 .71748 Mdot
.28719 .60876 Mdot
.382 .43248 Mdot
.54492 .56316 Mdot
.36785 .50107 Mdot
.46227 .67176 Mdot
.39463 .47934 Mdot
.40099 .74463 Mdot
.6592 .44113 Mdot
.35008 .50097 Mdot
.3903 .50739 Mdot
.45703 .80566 Mdot
.38539 .44509 Mdot
.44688 .47504 Mdot
.39444 .49343 Mdot
.38609 .70629 Mdot
.3467 .42513 Mdot
.45323 .66993 Mdot
.58626 .3706 Mdot
.63121 .44056 Mdot
.48216 .32422 Mdot
.53242 .31625 Mdot
.4447 .27895 Mdot
.68127 .31744 Mdot
.76459 .59667 Mdot
.43904 .677 Mdot
.62317 .59673 Mdot
.39057 .47895 Mdot
.62926 .21712 Mdot
.56742 .4557 Mdot
.60063 .42403 Mdot
.51964 .78942 Mdot
.45451 .51252 Mdot
.54467 .20264 Mdot
.41328 .53373 Mdot
.19853 .66391 Mdot
.40698 .56156 Mdot
.44233 .42408 Mdot
.66848 .41862 Mdot
.48678 .28012 Mdot
.36151 .44749 Mdot
.44367 .71202 Mdot
.51114 .34479 Mdot
.306 .45222 Mdot
.62906 .37702 Mdot
.59408 .37193 Mdot
.37811 .72283 Mdot
.37322 .4815 Mdot
.64852 .44547 Mdot
.44773 .64468 Mdot
.32084 .26254 Mdot
.60461 .62489 Mdot
.63253 .6733 Mdot
.52045 .63626 Mdot
.73317 .72529 Mdot
.5232 .33969 Mdot
.25245 .47937 Mdot
.36308 .46905 Mdot
.70597 .3858 Mdot
.34757 .5083 Mdot
.83389 .49679 Mdot
.52762 .33924 Mdot
.43871 .70221 Mdot
.62272 .59151 Mdot
.45518 .64564 Mdot
.28145 .61214 Mdot
.58965 .46096 Mdot
.54883 .51583 Mdot
.64066 .43173 Mdot
.54526 .4128 Mdot
.42378 .68108 Mdot
.42467 .49942 Mdot
.14545 .41495 Mdot
.4188 .69421 Mdot
.39442 .68011 Mdot
.56711 .82798 Mdot
.71093 .77386 Mdot
.45829 .47712 Mdot
.41178 .70701 Mdot
.6355 .4316 Mdot
.51529 .33209 Mdot
.37508 .51819 Mdot
.36995 .47795 Mdot
.40209 .6848 Mdot
.63789 .39757 Mdot
.25694 .64652 Mdot
.62116 .45099 Mdot
.4451 .68638 Mdot
.63144 .44987 Mdot
.67362 .52799 Mdot
.66624 .4336 Mdot
.35447 .45212 Mdot
.39354 .47936 Mdot
.63483 .28673 Mdot
.43074 .65581 Mdot
.38509 .50649 Mdot
.40778 .53057 Mdot
.41908 .66796 Mdot
.54823 .37031 Mdot
.25841 .63953 Mdot
.41823 .43599 Mdot
.37775 .45673 Mdot
.51965 .29884 Mdot
.57054 .55353 Mdot
.2389 .46117 Mdot
.40317 .5191 Mdot
.53454 .33009 Mdot
.44322 .71118 Mdot
.40605 .44927 Mdot
.82083 .43456 Mdot
.73101 .51496 Mdot
.43353 .47517 Mdot
.66206 .41728 Mdot
.40916 .53848 Mdot
.49465 .16752 Mdot
.36555 .44679 Mdot
.42596 .67277 Mdot
.4325 .64171 Mdot
.39781 .79828 Mdot
.41292 .68084 Mdot
.60934 .41778 Mdot
.62073 .62704 Mdot
.81521 .53542 Mdot
.63289 .41016 Mdot
.41045 .55539 Mdot
.4155 .82169 Mdot
.42799 .50698 Mdot
.34584 .45729 Mdot
.43539 .17228 Mdot
.64619 .41434 Mdot
.42345 .63184 Mdot
.50873 .45416 Mdot
.37319 .55534 Mdot
.63703 .64462 Mdot
.38191 .41055 Mdot
.39237 .42487 Mdot
.45003 .18794 Mdot
.7798 .46817 Mdot
.6579 .61846 Mdot
.44246 .45802 Mdot
.40419 .51891 Mdot
.59015 .42022 Mdot
.40138 .48367 Mdot
.51333 .33547 Mdot
.42263 .63618 Mdot
.66238 .42764 Mdot
.50371 .31291 Mdot
.42661 .45362 Mdot
.49854 .30238 Mdot
.65389 .45699 Mdot
.65564 .61632 Mdot
.42498 .47803 Mdot
.51265 .28764 Mdot
.49762 .30408 Mdot
.3708 .50283 Mdot
.43787 .65424 Mdot
.4186 .56114 Mdot
.38966 .44135 Mdot
.38637 .523 Mdot
.40139 .6699 Mdot
.88978 .49173 Mdot
.35244 .47 Mdot
.46578 .27889 Mdot
.39847 .66202 Mdot
.54666 .39454 Mdot
.65213 .41165 Mdot
.38843 .42576 Mdot
.65623 .61952 Mdot
.64602 .60018 Mdot
.62423 .46852 Mdot
.39332 .69025 Mdot
.58431 .28816 Mdot
.43292 .60134 Mdot
.34946 .53279 Mdot
.43276 .43708 Mdot
.32684 .74383 Mdot
.70578 .25642 Mdot
.43081 .6254 Mdot
.70247 .40669 Mdot
.4965 .51826 Mdot
.6381 .59365 Mdot
.61224 .40698 Mdot
.40392 .70918 Mdot
.40695 .64539 Mdot
.4443 .66342 Mdot
.49799 .34847 Mdot
.63995 .28945 Mdot
.41625 .62355 Mdot
.44465 .62044 Mdot
.37136 .47032 Mdot
.40254 .51815 Mdot
.35717 .2529 Mdot
.29198 .34479 Mdot
.49394 .30075 Mdot
.62406 .4642 Mdot
.1619 .63945 Mdot
.64576 .64574 Mdot
.50008 .81182 Mdot
.34239 .47597 Mdot
.09128 .5006 Mdot
.35666 .50649 Mdot
.40504 .48473 Mdot
.42902 .7141 Mdot
.50628 .28791 Mdot
.49916 .33124 Mdot
.42589 .68938 Mdot
.45285 .63054 Mdot
.51224 .33598 Mdot
.70834 .71254 Mdot
.83504 .44117 Mdot
.60257 .48417 Mdot
.41916 .66102 Mdot
.35971 .69461 Mdot
.64101 .58741 Mdot
.31079 .46776 Mdot
.64872 .64678 Mdot
.64139 .43784 Mdot
.63646 .47595 Mdot
.63374 .64343 Mdot
.37645 .46751 Mdot
.6601 .4601 Mdot
.43967 .48464 Mdot
.64667 .75323 Mdot
.30031 .65354 Mdot
.59461 .26689 Mdot
.37676 .39566 Mdot
.54038 .38477 Mdot
.58562 .66183 Mdot
.4175 .44946 Mdot
.7797 .39671 Mdot
.49213 .31623 Mdot
.31742 .46205 Mdot
.63356 .64847 Mdot
.47161 .15538 Mdot
.42836 .47553 Mdot
.42742 .6703 Mdot
.635 .60359 Mdot
.47139 .59387 Mdot
.59765 .70333 Mdot
.41585 .49482 Mdot
.1155 .47596 Mdot
.38618 .70022 Mdot
.66349 .43513 Mdot
.23802 .67205 Mdot
.42849 .62206 Mdot
.47436 .37426 Mdot
.6641 .27845 Mdot
.77987 .67559 Mdot
.43729 .6321 Mdot
.59156 .44276 Mdot
.45232 .68271 Mdot
.52341 .32362 Mdot
.41111 .722 Mdot
.65375 .43831 Mdot
.39475 .4483 Mdot
.61811 .43864 Mdot
.48668 .33776 Mdot
.25457 .35969 Mdot
.65761 .61615 Mdot
.64578 .40531 Mdot
.63839 .63241 Mdot
.37043 .35118 Mdot
.584 .23096 Mdot
.60195 .6304 Mdot
.21639 .56202 Mdot
.42711 .43224 Mdot
.42914 .61969 Mdot
.61501 .43617 Mdot
.72357 .36293 Mdot
.50958 .49071 Mdot
.40702 .66355 Mdot
.63785 .46692 Mdot
.52471 .63155 Mdot
.21342 .61818 Mdot
.44747 .48925 Mdot
.32292 .36475 Mdot
.41644 .66354 Mdot
.5988 .46093 Mdot
.26693 .30534 Mdot
.45283 .68709 Mdot
.61715 .41771 Mdot
.62116 .59029 Mdot
.61863 .61659 Mdot
.38619 .43532 Mdot
.61584 .66629 Mdot
.64762 .47025 Mdot
.63322 .68982 Mdot
.4078 .70645 Mdot
.48089 .61698 Mdot
.51536 .28581 Mdot
.62588 .44251 Mdot
.40983 .52314 Mdot
.42006 .73514 Mdot
.71182 .51224 Mdot
.2751 .67183 Mdot
.15892 .4675 Mdot
.61663 .44315 Mdot
.41422 .6412 Mdot
.42867 .66794 Mdot
.44408 .51312 Mdot
.49168 .57576 Mdot
.58888 .28914 Mdot
.48451 .43331 Mdot
.49395 .46257 Mdot
.68126 .45257 Mdot
.57412 .4367 Mdot
.33744 .45572 Mdot
.37798 .48137 Mdot
.63441 .59276 Mdot
.39153 .44986 Mdot
.42501 .71113 Mdot
.37844 .43604 Mdot
.61997 .63731 Mdot
.6438 .42785 Mdot
.42574 .47339 Mdot
.50781 .29819 Mdot
.64309 .58524 Mdot
.59132 .64402 Mdot
.62389 .43535 Mdot
.40069 .68216 Mdot
.55734 .34499 Mdot
.622 .45535 Mdot
.37365 .4805 Mdot
.57494 .5597 Mdot
.39779 .52607 Mdot
.34346 .55696 Mdot
.45395 .68609 Mdot
.65903 .42478 Mdot
.41611 .71542 Mdot
.63964 .62612 Mdot
.62948 .25466 Mdot
.39257 .4699 Mdot
.62219 .41433 Mdot
.72021 .45449 Mdot
.28767 .46855 Mdot
.44638 .61742 Mdot
.72547 .65179 Mdot
.45925 .64778 Mdot
.61433 .45962 Mdot
.47962 .82346 Mdot
.5143 .34852 Mdot
.60072 .42302 Mdot
.76343 .31116 Mdot
.63245 .41959 Mdot
.37497 .44705 Mdot
.35435 .48911 Mdot
.66385 .43059 Mdot
.52782 .30792 Mdot
.36154 .22988 Mdot
.68425 .43601 Mdot
.4276 .63133 Mdot
.64609 .76461 Mdot
.19132 .38227 Mdot
.66745 .59574 Mdot
.63038 .59365 Mdot
.40016 .56584 Mdot
.45011 .44726 Mdot
.62765 .65294 Mdot
.59537 .65589 Mdot
.49761 .35306 Mdot
.61058 .4346 Mdot
.3997 .73675 Mdot
.5901 .61699 Mdot
.4384 .56995 Mdot
.66975 .31053 Mdot
.45017 .48803 Mdot
.47622 .75023 Mdot
.3448 .49279 Mdot
.45806 .34117 Mdot
.61982 .63846 Mdot
.38744 .53293 Mdot
.42793 .53001 Mdot
.65275 .6322 Mdot
.51592 .33429 Mdot
.5557 .61621 Mdot
.63743 .45013 Mdot
.85736 .433 Mdot
.43664 .50426 Mdot
.37092 .44818 Mdot
.65108 .61864 Mdot
.59367 .33594 Mdot
.41595 .64675 Mdot
.45948 .66233 Mdot
.66981 .44658 Mdot
.50709 .52601 Mdot
.39724 .42734 Mdot
.40836 .44577 Mdot
.6461 .45068 Mdot
.6167 .40664 Mdot
.74538 .59583 Mdot
.35905 .48719 Mdot
.63711 .61073 Mdot
.51405 .26451 Mdot
.62206 .64001 Mdot
.4015 .52525 Mdot
.36695 .45378 Mdot
.35575 .45019 Mdot
.40903 .5229 Mdot
.60279 .65911 Mdot
.37412 .52671 Mdot
.32534 .45152 Mdot
.41042 .64831 Mdot
.40895 .50744 Mdot
.49362 .45521 Mdot
.38623 .45595 Mdot
.51419 .33309 Mdot
.23399 .48355 Mdot
.42798 .47562 Mdot
.38825 .42738 Mdot
.66592 .40697 Mdot
.40126 .46345 Mdot
.64907 .64315 Mdot
.42407 .65393 Mdot
.64572 .60822 Mdot
.64845 .60188 Mdot
.65954 .47305 Mdot
.50761 .36099 Mdot
.36043 .43742 Mdot
.49156 .33967 Mdot
.40194 .55334 Mdot
.43566 .46362 Mdot
.64769 .2737 Mdot
.20863 .67897 Mdot
.23153 .38749 Mdot
.3909 .46959 Mdot
.64405 .41547 Mdot
.65415 .41453 Mdot
.30291 .44054 Mdot
.4457 .4957 Mdot
.60524 .64502 Mdot
.64301 .59604 Mdot
.32669 .30709 Mdot
.48867 .20199 Mdot
.51461 .33352 Mdot
.56367 .5424 Mdot
.44098 .46424 Mdot
.39846 .53007 Mdot
.42745 .51285 Mdot
.67459 .44689 Mdot
.47712 .39413 Mdot
.60529 .41607 Mdot
.57556 .76536 Mdot
.64113 .63811 Mdot
.42331 .48542 Mdot
.49068 .76509 Mdot
.42505 .69983 Mdot
.4249 .6544 Mdot
.5909 .63918 Mdot
.59439 .39695 Mdot
.32359 .27998 Mdot
.80126 .6819 Mdot
.38692 .69072 Mdot
.49168 .2965 Mdot
.41742 .44533 Mdot
.63767 .4252 Mdot
.44529 .69115 Mdot
.4887 .30201 Mdot
.4285 .49232 Mdot
.64134 .28963 Mdot
.38563 .46922 Mdot
.51414 .68577 Mdot
.44349 .65133 Mdot
.83655 .48448 Mdot
.39142 .68047 Mdot
.64234 .58396 Mdot
.62332 .64727 Mdot
.3558 .47439 Mdot
.29153 .72358 Mdot
.44427 .62586 Mdot
.59046 .56013 Mdot
.52048 .35038 Mdot
.6989 .52484 Mdot
.5218 .32986 Mdot
.66203 .43722 Mdot
.51442 .34463 Mdot
.65591 .43973 Mdot
.29268 .32905 Mdot
.38139 .67766 Mdot
.49775 .31538 Mdot
.70896 .46357 Mdot
.45395 .45734 Mdot
.49864 .29656 Mdot
.32973 .4929 Mdot
.32482 .5399 Mdot
.6433 .45307 Mdot
.5256 .33849 Mdot
.42331 .50278 Mdot
.59072 .1851 Mdot
.60191 .61194 Mdot
.61009 .64724 Mdot
.3364 .50725 Mdot
.67936 .46033 Mdot
.43021 .71892 Mdot
.8144 .48629 Mdot
.62907 .57332 Mdot
.35328 .47304 Mdot
.36561 .44314 Mdot
.45334 .63397 Mdot
.46548 .7853 Mdot
.35962 .46612 Mdot
.47568 .47329 Mdot
.35776 .48634 Mdot
.59627 .61802 Mdot
.45397 .64352 Mdot
.42716 .6623 Mdot
.64353 .46679 Mdot
.41289 .70207 Mdot
.30054 .42747 Mdot
.51438 .76251 Mdot
.46375 .505 Mdot
.63429 .6281 Mdot
.54978 .7654 Mdot
.57279 .76788 Mdot
.72702 .28216 Mdot
.42915 .60819 Mdot
.34854 .50809 Mdot
.39988 .69031 Mdot
.51831 .32394 Mdot
.43585 .66313 Mdot
.4061 .70881 Mdot
.41423 .45555 Mdot
.41443 .49264 Mdot
.65203 .42787 Mdot
.48863 .56183 Mdot
.3982 .67396 Mdot
.35933 .50906 Mdot
.44695 .43865 Mdot
.43563 .49701 Mdot
.62699 .53403 Mdot
.43742 .62661 Mdot
.62961 .80346 Mdot
.40939 .25618 Mdot
.39849 .67501 Mdot
.41857 .15816 Mdot
.71934 .46725 Mdot
.62959 .4821 Mdot
.60292 .67214 Mdot
.35904 .49293 Mdot
.63154 .40621 Mdot
.41923 .48502 Mdot
.47825 .74867 Mdot
.40836 .46464 Mdot
.51299 .33762 Mdot
.44127 .48508 Mdot
.62742 .47259 Mdot
.61943 .45 Mdot
.3577 .45905 Mdot
.42373 .47322 Mdot
.27068 .33546 Mdot
.41786 .60405 Mdot
.42744 .64943 Mdot
.57782 .29316 Mdot
.50495 .30581 Mdot
.63419 .64567 Mdot
.39563 .48708 Mdot
.66842 .46699 Mdot
.61824 .44711 Mdot
.43584 .62403 Mdot
.63443 .46201 Mdot
.61295 .63183 Mdot
.3952 .4731 Mdot
.6248 .65246 Mdot
.49894 .35022 Mdot
.44796 .63532 Mdot
.41214 .50209 Mdot
.37155 .46985 Mdot
.43263 .64152 Mdot
.346 .44584 Mdot
.52226 .30191 Mdot
.6287 .41962 Mdot
.44238 .63503 Mdot
.61997 .62432 Mdot
.66048 .43717 Mdot
.3823 .52411 Mdot
.14799 .57794 Mdot
.3765 .4486 Mdot
.36257 .50527 Mdot
.75548 .29274 Mdot
.44292 .4735 Mdot
.61534 .44079 Mdot
.44227 .69898 Mdot
.38217 .3973 Mdot
.43259 .27614 Mdot
.87972 .56518 Mdot
.60143 .42381 Mdot
.41401 .4425 Mdot
.65087 .22615 Mdot
.40491 .44138 Mdot
.33109 .73314 Mdot
.66549 .49178 Mdot
.53163 .42941 Mdot
.34638 .51717 Mdot
.61223 .61204 Mdot
.65182 .42462 Mdot
.65787 .44414 Mdot
.60781 .79342 Mdot
.41259 .4519 Mdot
.53942 .60252 Mdot
.41901 .50305 Mdot
.6163 .6232 Mdot
.35279 .28674 Mdot
.61757 .4491 Mdot
.17996 .46039 Mdot
.36607 .49857 Mdot
.41136 .63622 Mdot
.675 .40698 Mdot
.6516 .54011 Mdot
.38386 .52209 Mdot
.48878 .32412 Mdot
.60055 .59366 Mdot
.41713 .40653 Mdot
.62939 .63008 Mdot
.38952 .52338 Mdot
.46417 .41933 Mdot
.24173 .68551 Mdot
.44115 .65824 Mdot
.62489 .59093 Mdot
.59981 .54192 Mdot
.36433 .5231 Mdot
.43904 .63332 Mdot
.40872 .65686 Mdot
.49246 .34578 Mdot
.57216 .50742 Mdot
.5615 .68583 Mdot
.32769 .68698 Mdot
.63095 .77848 Mdot
.66636 .40316 Mdot
.77035 .51199 Mdot
.37733 .51291 Mdot
.54841 .26475 Mdot
.65543 .63177 Mdot
.37996 .44426 Mdot
.26593 .50587 Mdot
.42773 .69468 Mdot
.37266 .45801 Mdot
.50482 .33287 Mdot
.56589 .30475 Mdot
.53894 .26232 Mdot
.67042 .27435 Mdot
.64051 .43333 Mdot
.32345 .46928 Mdot
.45341 .41057 Mdot
.66583 .41797 Mdot
.38984 .423 Mdot
.61894 .42009 Mdot
.71906 .71873 Mdot
.49871 .29394 Mdot
.42943 .62742 Mdot
.66549 .52051 Mdot
.37313 .42879 Mdot
.42779 .42935 Mdot
.49401 .36065 Mdot
.37727 .48618 Mdot
.21248 .65815 Mdot
.64908 .52249 Mdot
.66459 .45128 Mdot
.44358 .66222 Mdot
.37819 .43014 Mdot
.5881 .5184 Mdot
.3941 .44134 Mdot
.34296 .61966 Mdot
.38627 .42813 Mdot
.57653 .68971 Mdot
.4387 .64934 Mdot
.63193 .63229 Mdot
.36604 .52698 Mdot
.4091 .47173 Mdot
.47244 .24454 Mdot
.39882 .56063 Mdot
.37642 .53031 Mdot
.46792 .67183 Mdot
.44715 .69079 Mdot
.45208 .67358 Mdot
.60487 .45823 Mdot
.46777 .19302 Mdot
.64035 .61622 Mdot
.35617 .40886 Mdot
.59367 .61284 Mdot
.26337 .67513 Mdot
.49179 .29735 Mdot
.6758 .2582 Mdot
.39248 .50156 Mdot
.44106 .68236 Mdot
.77525 .43166 Mdot
.4546 .70023 Mdot
.54989 .54383 Mdot
.62896 .6064 Mdot
.42193 .69204 Mdot
.40809 .47991 Mdot
.50301 .50439 Mdot
.60281 .2102 Mdot
.64585 .61957 Mdot
.41425 .55379 Mdot
.59675 .44881 Mdot
.59514 .25655 Mdot
.1491 .54539 Mdot
.60138 .61195 Mdot
.65884 .65002 Mdot
.41351 .45052 Mdot
.42709 .70134 Mdot
.61094 .61787 Mdot
.59718 .62836 Mdot
.63729 .46268 Mdot
.4117 .49673 Mdot
.40764 .50152 Mdot
.61117 .45856 Mdot
.64766 .61062 Mdot
.34528 .5209 Mdot
.43959 .41867 Mdot
.55882 .15663 Mdot
.51086 .61917 Mdot
.8653 .44104 Mdot
.30829 .41978 Mdot
.25321 .51553 Mdot
.82132 .49436 Mdot
.40203 .65187 Mdot
.43168 .46511 Mdot
.41973 .41434 Mdot
.64618 .47047 Mdot
.39465 .45927 Mdot
.64066 .48987 Mdot
.63566 .59955 Mdot
.46165 .16252 Mdot
.56022 .74229 Mdot
.7513 .69278 Mdot
.39636 .45815 Mdot
.39857 .74635 Mdot
.5104 .3189 Mdot
.66094 .59346 Mdot
.45558 .6619 Mdot
.41714 .51607 Mdot
.26791 .33833 Mdot
.60291 .4191 Mdot
.40641 .68225 Mdot
.32047 .26508 Mdot
.5257 .38793 Mdot
.40057 .52441 Mdot
.59821 .44342 Mdot
.78648 .42034 Mdot
.44424 .58456 Mdot
.63901 .57147 Mdot
.51583 .33625 Mdot
.65324 .42242 Mdot
.64493 .59623 Mdot
.40793 .74008 Mdot
.41688 .68672 Mdot
.42856 .7219 Mdot
.22907 .42015 Mdot
.65747 .40702 Mdot
.50684 .31769 Mdot
.51462 .21377 Mdot
.48439 .21908 Mdot
.51057 .33797 Mdot
.6319 .47565 Mdot
.44665 .69074 Mdot
.43079 .68777 Mdot
.42349 .6541 Mdot
.20636 .41305 Mdot
.39666 .65995 Mdot
.53627 .81172 Mdot
.431 .50042 Mdot
.47288 .47058 Mdot
.41181 .44294 Mdot
.61268 .64953 Mdot
.43981 .64192 Mdot
.51628 .47659 Mdot
.41033 .54531 Mdot
.60805 .22928 Mdot
.38062 .44011 Mdot
.6632 .6294 Mdot
.36738 .46745 Mdot
.41177 .77715 Mdot
.39778 .68426 Mdot
.39219 .46558 Mdot
.66151 .62151 Mdot
.51138 .30478 Mdot
.4527 .62292 Mdot
.41712 .49421 Mdot
.74974 .62872 Mdot
.44264 .47822 Mdot
.75494 .67764 Mdot
.49269 .63134 Mdot
.49204 .29618 Mdot
.48403 .71666 Mdot
.60027 .41153 Mdot
.4718 .45232 Mdot
.35655 .54438 Mdot
.64277 .62776 Mdot
.6953 .50988 Mdot
.63173 .43848 Mdot
.48451 .39361 Mdot
.36986 .41351 Mdot
.48437 .3343 Mdot
.41814 .59902 Mdot
.62676 .65414 Mdot
.40234 .42155 Mdot
.44022 .51653 Mdot
.59899 .77824 Mdot
.3381 .43851 Mdot
.37339 .4372 Mdot
.48422 .34902 Mdot
.53112 .8055 Mdot
.38318 .45931 Mdot
.55674 .53969 Mdot
.40501 .7186 Mdot
.35722 .53848 Mdot
.51809 .8154 Mdot
.35383 .49082 Mdot
.41075 .69002 Mdot
.40644 .59043 Mdot
.53831 .66694 Mdot
.51389 .35778 Mdot
.39051 .4261 Mdot
.40233 .80141 Mdot
.36732 .49175 Mdot
.63599 .61477 Mdot
.44696 .47999 Mdot
.65081 .43772 Mdot
.23128 .37698 Mdot
.65257 .46606 Mdot
.4094 .43135 Mdot
.4208 .65558 Mdot
.64946 .6281 Mdot
.19664 .45807 Mdot
.61989 .29536 Mdot
.51063 .80722 Mdot
.817 .63078 Mdot
.52711 .33111 Mdot
.52111 .36134 Mdot
.63173 .65456 Mdot
.39064 .46497 Mdot
.52186 .83235 Mdot
.40675 .56258 Mdot
.37626 .45826 Mdot
.40964 .46506 Mdot
.56774 .23078 Mdot
.64016 .59779 Mdot
.63381 .45565 Mdot
.36251 .46058 Mdot
.37515 .52815 Mdot
.40269 .65161 Mdot
.5036 .30257 Mdot
.6522 .41192 Mdot
.49307 .32457 Mdot
.64603 .42336 Mdot
.43691 .15796 Mdot
.40207 .53968 Mdot
.51376 .30829 Mdot
.59176 .6072 Mdot
.40159 .67971 Mdot
.51604 .75683 Mdot
.66078 .44128 Mdot
.62954 .46854 Mdot
.36558 .4488 Mdot
.41172 .69286 Mdot
.42336 .71559 Mdot
.51973 .32162 Mdot
.60569 .63218 Mdot
.42798 .47434 Mdot
.43621 .45905 Mdot
.38905 .61974 Mdot
.67559 .46159 Mdot
.508 .69616 Mdot
.77953 .54166 Mdot
.3895 .46774 Mdot
.41046 .70756 Mdot
.41996 .46758 Mdot
.80382 .5419 Mdot
.42049 .70209 Mdot
.35331 .49495 Mdot
.35534 .21414 Mdot
.58992 .39932 Mdot
.54111 .6966 Mdot
.35433 .45556 Mdot
.83709 .55808 Mdot
.38478 .51014 Mdot
.49531 .13946 Mdot
.71004 .37579 Mdot
.42321 .43287 Mdot
.37428 .52028 Mdot
.28054 .65276 Mdot
.42516 .44617 Mdot
.61551 .46187 Mdot
.39663 .2226 Mdot
.44256 .71392 Mdot
.68323 .68613 Mdot
.24005 .48325 Mdot
.52735 .33886 Mdot
.66979 .44578 Mdot
.58128 .45589 Mdot
.50124 .33821 Mdot
.42017 .66384 Mdot
.38568 .47531 Mdot
.52264 .52188 Mdot
.67867 .44747 Mdot
.32845 .40778 Mdot
.63371 .61428 Mdot
.73026 .54797 Mdot
.59093 .48825 Mdot
.62357 .63174 Mdot
.40565 .51085 Mdot
.27137 .6497 Mdot
.2586 .40848 Mdot
.83074 .41943 Mdot
.64572 .59533 Mdot
.64706 .62153 Mdot
.21731 .39013 Mdot
.50384 .27999 Mdot
.62872 .76226 Mdot
.5875 .69607 Mdot
.64175 .64162 Mdot
.46341 .60029 Mdot
.60352 .42931 Mdot
.5781 .65015 Mdot
.32078 .45408 Mdot
.43749 .47636 Mdot
.4083 .47733 Mdot
.60916 .63733 Mdot
.29016 .46583 Mdot
.22671 .65858 Mdot
.63765 .63426 Mdot
.35455 .55159 Mdot
.5476 .47275 Mdot
.73375 .43008 Mdot
.61636 .45666 Mdot
.50981 .35844 Mdot
.54122 .33161 Mdot
.41356 .63647 Mdot
.5088 .3598 Mdot
.56352 .29315 Mdot
.38308 .48883 Mdot
.62946 .64014 Mdot
.70672 .51576 Mdot
.6215 .6192 Mdot
.49949 .33522 Mdot
.48208 .31288 Mdot
.41083 .64806 Mdot
.43109 .65354 Mdot
.24876 .54458 Mdot
.35529 .31213 Mdot
.39099 .43849 Mdot
.72537 .34018 Mdot
.41194 .71173 Mdot
.33565 .40147 Mdot
.50411 .36094 Mdot
.50738 .3041 Mdot
.47449 .25305 Mdot
.39715 .4976 Mdot
.3607 .75743 Mdot
.39712 .49314 Mdot
.35345 .2924 Mdot
.34368 .47969 Mdot
.63599 .4626 Mdot
.3993 .50301 Mdot
.49243 .24115 Mdot
.37466 .42356 Mdot
.45133 .4558 Mdot
.67393 .45603 Mdot
.4073 .40322 Mdot
.64916 .43906 Mdot
.40338 .43255 Mdot
.52941 .3012 Mdot
.66699 .45997 Mdot
.42611 .29915 Mdot
.47931 .25859 Mdot
.62334 .47396 Mdot
.48679 .3344 Mdot
.53248 .3243 Mdot
.43806 .32721 Mdot
.45577 .66207 Mdot
.33685 .53345 Mdot
.39137 .46167 Mdot
.61877 .40225 Mdot
.63595 .59519 Mdot
.36588 .51785 Mdot
.44271 .43553 Mdot
.34757 .47806 Mdot
.41432 .63485 Mdot
.59177 .28584 Mdot
.51816 .31391 Mdot
.60471 .45163 Mdot
.55804 .354 Mdot
.6797 .46378 Mdot
.44849 .48363 Mdot
.40705 .4117 Mdot
.25267 .49298 Mdot
.74639 .46528 Mdot
.20275 .40078 Mdot
.41494 .68615 Mdot
.66095 .41707 Mdot
.52163 .29063 Mdot
.45199 .4325 Mdot
.44173 .68663 Mdot
.65313 .43849 Mdot
.38618 .46985 Mdot
.41934 .55207 Mdot
.53843 .78053 Mdot
.30985 .39813 Mdot
.45503 .28361 Mdot
.62415 .46894 Mdot
.59458 .42434 Mdot
.51541 .23788 Mdot
.47353 .34893 Mdot
.51136 .4882 Mdot
.40253 .44896 Mdot
.48928 .32657 Mdot
.44463 .69168 Mdot
.23823 .42023 Mdot
.61133 .64338 Mdot
.48936 .56877 Mdot
.39632 .46017 Mdot
.53437 .4047 Mdot
.41939 .65423 Mdot
.50774 .33303 Mdot
.61085 .63904 Mdot
.51504 .36831 Mdot
.672 .43294 Mdot
.75356 .71608 Mdot
.37033 .48881 Mdot
.37159 .44211 Mdot
.65286 .59423 Mdot
.43482 .69448 Mdot
.50066 .36477 Mdot
.65608 .75298 Mdot
.65614 .45347 Mdot
.50065 .83263 Mdot
.41724 .70803 Mdot
.36945 .68626 Mdot
.60456 .44488 Mdot
.59131 .63548 Mdot
.42648 .32111 Mdot
.61777 .63457 Mdot
.39883 .42934 Mdot
.43568 .6732 Mdot
.62037 .59483 Mdot
.48391 .57815 Mdot
.63568 .21618 Mdot
.36382 .69494 Mdot
.38832 .48631 Mdot
.54798 .17577 Mdot
.74635 .66516 Mdot
.41013 .61207 Mdot
.65666 .61535 Mdot
.38149 .44138 Mdot
.41526 .42569 Mdot
.36638 .48899 Mdot
.62354 .59929 Mdot
.7009 .32242 Mdot
.64661 .45301 Mdot
.4132 .44667 Mdot
.49693 .3521 Mdot
.64183 .44024 Mdot
.66105 .52475 Mdot
.61875 .45636 Mdot
.42181 .61029 Mdot
.44861 .4729 Mdot
.63458 .55747 Mdot
.42289 .13808 Mdot
.64586 .61214 Mdot
.6444 .47721 Mdot
.4129 .53078 Mdot
.72702 .50112 Mdot
.4501 .6781 Mdot
.6556 .45583 Mdot
.37188 .44735 Mdot
.67133 .51488 Mdot
.24527 .37128 Mdot
.61804 .45386 Mdot
.44201 .6896 Mdot
.81431 .40242 Mdot
.3929 .45314 Mdot
.37919 .50594 Mdot
.42382 .68709 Mdot
.21753 .58767 Mdot
.27973 .29502 Mdot
.42244 .47119 Mdot
.631 .63365 Mdot
.64853 .81454 Mdot
.4512 .4452 Mdot
.40072 .25175 Mdot
.65326 .42649 Mdot
.56757 .60908 Mdot
.51912 .65528 Mdot
.45271 .43419 Mdot
.64551 .75233 Mdot
.64692 .66365 Mdot
.54212 .1921 Mdot
.64716 .48971 Mdot
.65536 .36852 Mdot
.50378 .17089 Mdot
.65907 .63503 Mdot
.38804 .63695 Mdot
.66996 .72348 Mdot
.17631 .52834 Mdot
.81061 .42119 Mdot
.61397 .35541 Mdot
.26867 .33494 Mdot
.52947 .49822 Mdot
.64065 .41852 Mdot
.54519 .35766 Mdot
.41974 .48706 Mdot
.75058 .66039 Mdot
.37506 .76711 Mdot
.30543 .74205 Mdot
.55221 .17544 Mdot
.32451 .71951 Mdot
.63366 .22153 Mdot
.73663 .28582 Mdot
.27253 .45937 Mdot
.75643 .45574 Mdot
.50051 .83638 Mdot
.39375 .20404 Mdot
.64986 .77756 Mdot
.46269 .51121 Mdot
.54257 .55935 Mdot
.79013 .6492 Mdot
.38472 .733 Mdot
.22508 .64294 Mdot
.6481 .46496 Mdot
.45512 .68643 Mdot
.66756 .71872 Mdot
.45966 .64648 Mdot
.5301 .65845 Mdot
.8189 .39931 Mdot
.65188 .22128 Mdot
.43219 .79248 Mdot
.83597 .51622 Mdot
.26989 .51809 Mdot
.3691 .83014 Mdot
.68255 .44182 Mdot
.42385 .62305 Mdot
.46698 .3006 Mdot
.50455 .22824 Mdot
.60171 .75234 Mdot
.6987 .70672 Mdot
.63038 .26851 Mdot
.36919 .33693 Mdot
.42641 .66861 Mdot
.49624 .69302 Mdot
.57715 .58101 Mdot
.56285 .74703 Mdot
.38464 .22494 Mdot
.76575 .33883 Mdot
.51979 .53786 Mdot
.71137 .66897 Mdot
.74844 .53457 Mdot
.15171 .53324 Mdot
.42342 .25532 Mdot
.37595 .38608 Mdot
.53089 .64518 Mdot
.81795 .50793 Mdot
.19052 .54081 Mdot
.33202 .32071 Mdot
.49906 .22561 Mdot
.39746 .18712 Mdot
.79893 .59012 Mdot
.25358 .27435 Mdot
.45314 .70882 Mdot
.36797 .44044 Mdot
.227 .57624 Mdot
.41289 .80622 Mdot
.48378 .30304 Mdot
.69036 .2945 Mdot
.51777 .35007 Mdot
.39603 .65 Mdot
.2528 .34589 Mdot
.51854 .81237 Mdot
.41945 .81498 Mdot
.5383 .33474 Mdot
.38383 .39488 Mdot
.79278 .72921 Mdot
.576 .21049 Mdot
.53882 .72542 Mdot
.54227 .15155 Mdot
.52091 .42449 Mdot
.47403 .6048 Mdot
.62281 .595 Mdot
.49824 .16279 Mdot
.43276 .68258 Mdot
.27875 .23617 Mdot
.48663 .14231 Mdot
.24644 .45343 Mdot
.87161 .35362 Mdot
.52979 .23562 Mdot
.53097 .42401 Mdot
.66653 .66721 Mdot
.40938 .28667 Mdot
.19975 .61393 Mdot
.39979 .36949 Mdot
.73246 .50801 Mdot
.8355 .60415 Mdot
.53295 .18117 Mdot
.44687 .82114 Mdot
.71962 .7399 Mdot
.17895 .55127 Mdot
.58847 .5255 Mdot
.31586 .44981 Mdot
.60555 .49859 Mdot
.75644 .34472 Mdot
.41148 .1695 Mdot
.41471 .25197 Mdot
.87827 .57667 Mdot
.48055 .35427 Mdot
.67119 .32385 Mdot
.82011 .3774 Mdot
.38739 .3375 Mdot
.50455 .65722 Mdot
.42309 .2214 Mdot
.38441 .39007 Mdot
.55951 .32115 Mdot
.71658 .31352 Mdot
.51573 .71603 Mdot
.41479 .20956 Mdot
.80294 .44713 Mdot
.59535 .77882 Mdot
.30937 .65495 Mdot
.47078 .20999 Mdot
.46302 .68725 Mdot
.34967 .33094 Mdot
.5083 .64074 Mdot
.63962 .21005 Mdot
.63896 .65999 Mdot
.67631 .21723 Mdot
.28256 .29589 Mdot
.37471 .5404 Mdot
.39086 .56694 Mdot
.46313 .70672 Mdot
.36448 .3162 Mdot
.41393 .40177 Mdot
.56346 .77595 Mdot
.70151 .24934 Mdot
.28066 .50645 Mdot
.55817 .60782 Mdot
.69441 .50677 Mdot
.8286 .39278 Mdot
.24269 .57979 Mdot
.47284 .35117 Mdot
.35095 .26579 Mdot
.16335 .55818 Mdot
.63139 .44398 Mdot
.45645 .81955 Mdot
.63671 .56947 Mdot
.241 .39153 Mdot
.32834 .69172 Mdot
.22009 .50094 Mdot
.70272 .25004 Mdot
.59117 .36893 Mdot
.26791 .32092 Mdot
.38029 .35392 Mdot
.57563 .82859 Mdot
.73522 .43361 Mdot
.38448 .41015 Mdot
.71471 .6797 Mdot
.52771 .30687 Mdot
.27172 .59803 Mdot
.63852 .80673 Mdot
.61561 .33148 Mdot
.3321 .45624 Mdot
.24298 .44309 Mdot
.59458 .38901 Mdot
.50178 .51212 Mdot
.17039 .40379 Mdot
.45232 .4751 Mdot
.50533 .21184 Mdot
.79056 .60867 Mdot
.39159 .2856 Mdot
.83629 .46001 Mdot
.80306 .51258 Mdot
.28913 .23937 Mdot
.53117 .15807 Mdot
.60831 .29474 Mdot
.4981 .17593 Mdot
.60361 .1822 Mdot
.27809 .25585 Mdot
.36864 .55609 Mdot
.64867 .58738 Mdot
.12988 .5554 Mdot
.61199 .45283 Mdot
.54182 .21472 Mdot
.62988 .77942 Mdot
.61978 .51747 Mdot
.4078 .74734 Mdot
.41477 .38152 Mdot
.53076 .5093 Mdot
.40789 .61634 Mdot
.40566 .40127 Mdot
.20243 .36675 Mdot
.33352 .21134 Mdot
.23431 .31095 Mdot
.81736 .58411 Mdot
.47824 .17065 Mdot
.54061 .43141 Mdot
.44605 .79466 Mdot
.30543 .43935 Mdot
.42972 .49672 Mdot
.47066 .36957 Mdot
.53184 .23584 Mdot
.23542 .44991 Mdot
.60253 .73331 Mdot
.41486 .60009 Mdot
.70333 .30433 Mdot
.46799 .90797 Mdot
.26437 .54644 Mdot
.54711 .81789 Mdot
.52708 .24975 Mdot
.36489 .30437 Mdot
.74907 .34602 Mdot
.23061 .47619 Mdot
.75023 .29229 Mdot
.39859 .63265 Mdot
.64835 .77411 Mdot
.63603 .35004 Mdot
.4824 .51498 Mdot
.59566 .28257 Mdot
.67094 .2395 Mdot
.69482 .61996 Mdot
.21075 .46449 Mdot
.62122 .70807 Mdot
.21264 .56143 Mdot
.70024 .4657 Mdot
.73708 .55372 Mdot
.6207 .81116 Mdot
.78445 .49282 Mdot
.37153 .27544 Mdot
.55114 .48701 Mdot
.46814 .74021 Mdot
.64711 .66516 Mdot
.37755 .2741 Mdot
.4907 .44317 Mdot
.49256 .1889 Mdot
.38305 .12565 Mdot
.1761 .43739 Mdot
.85529 .4419 Mdot
.73585 .34433 Mdot
.34253 .44298 Mdot
.78188 .32105 Mdot
.22397 .31039 Mdot
.45879 .12884 Mdot
.72422 .58636 Mdot
.66184 .48665 Mdot
.59102 .62866 Mdot
.22036 .35224 Mdot
.69162 .31784 Mdot
.77639 .33103 Mdot
.44316 .22367 Mdot
.58806 .64014 Mdot
.21841 .6934 Mdot
.39529 .19273 Mdot
.3436 .69674 Mdot
.30771 .4002 Mdot
.33626 .48196 Mdot
.39802 .76819 Mdot
.45722 .64104 Mdot
.76707 .52179 Mdot
.34531 .32024 Mdot
.62322 .44341 Mdot
.46147 .32533 Mdot
.70824 .69743 Mdot
.44112 .48482 Mdot
.59606 .53907 Mdot
.43738 .61423 Mdot
.74946 .4649 Mdot
.53228 .76287 Mdot
.39998 .16622 Mdot
.56443 .24822 Mdot
.35084 .52161 Mdot
.39397 .2798 Mdot
.5888 .27771 Mdot
.2673 .30441 Mdot
.62614 .65671 Mdot
.57507 .1823 Mdot
.52628 .56466 Mdot
.34844 .3295 Mdot
.38639 .76385 Mdot
.32935 .54227 Mdot
.43399 .43366 Mdot
.79622 .48189 Mdot
.33379 .60035 Mdot
.49079 .54817 Mdot
.32701 .43648 Mdot
.30555 .48254 Mdot
.79099 .33038 Mdot
.56587 .31049 Mdot
.73648 .5379 Mdot
.60253 .19186 Mdot
.62053 .60682 Mdot
.40187 .69377 Mdot
.5451 .32407 Mdot
.67762 .74223 Mdot
.35175 .59764 Mdot
.24409 .37289 Mdot
.60854 .50807 Mdot
.62796 .32596 Mdot
.61352 .20097 Mdot
.57079 .18669 Mdot
.3547 .7782 Mdot
.42149 .59821 Mdot
.2782 .45836 Mdot
.66577 .7586 Mdot
.44716 .6977 Mdot
.56388 .7898 Mdot
.54991 .78801 Mdot
.43826 .16853 Mdot
.58827 .5515 Mdot
.83831 .59095 Mdot
.44949 .28738 Mdot
.68061 .29304 Mdot
.19477 .45758 Mdot
.60683 .81409 Mdot
.64638 .23326 Mdot
.45296 .5964 Mdot
.29347 .67659 Mdot
.4677 .49242 Mdot
.46691 .76415 Mdot
.1623 .60815 Mdot
.53582 .29076 Mdot
.37087 .70183 Mdot
.80542 .44616 Mdot
.37877 .47863 Mdot
.16474 .45514 Mdot
.68834 .72446 Mdot
.21235 .39517 Mdot
.58691 .63128 Mdot
.40532 .5171 Mdot
.38594 .42037 Mdot
.38765 .247 Mdot
.53835 .67075 Mdot
.47869 .19148 Mdot
.66943 .79363 Mdot
.78985 .41125 Mdot
.37354 .76485 Mdot
.52272 .2192 Mdot
.7752 .345 Mdot
.75672 .65194 Mdot
.56669 .5139 Mdot
.53999 .24022 Mdot
.40395 .33139 Mdot
.83241 .52504 Mdot
.49638 .45068 Mdot
.61711 .68301 Mdot
.60586 .75927 Mdot
.78384 .54097 Mdot
.22042 .43621 Mdot
.39137 .51933 Mdot
.32086 .26481 Mdot
.75119 .30511 Mdot
.36255 .7749 Mdot
.19084 .61579 Mdot
.17731 .42569 Mdot
.33916 .63973 Mdot
.79108 .52701 Mdot
.73767 .66924 Mdot
.57508 .84226 Mdot
.52461 .57256 Mdot
.62868 .23739 Mdot
.39526 .34244 Mdot
.6097 .1974 Mdot
.65589 .5958 Mdot
.60011 .70947 Mdot
.69736 .50285 Mdot
.49169 .18144 Mdot
.25395 .60544 Mdot
.69745 .2568 Mdot
.52443 .44549 Mdot
.29969 .22725 Mdot
.77807 .47248 Mdot
.53216 .48227 Mdot
.66645 .42614 Mdot
.58403 .36585 Mdot
.70217 .28843 Mdot
.75205 .42481 Mdot
.5927 .81588 Mdot
.60906 .47452 Mdot
.54559 .34405 Mdot
.34889 .72008 Mdot
.33084 .35695 Mdot
.79975 .48907 Mdot
.39396 .28021 Mdot
.67865 .23495 Mdot
.40639 .22647 Mdot
.31559 .27198 Mdot
.54659 .22949 Mdot
.80667 .66125 Mdot
.53813 .72011 Mdot
.5498 .28109 Mdot
.69678 .71487 Mdot
.69015 .33845 Mdot
.46848 .61002 Mdot
.09965 .39023 Mdot
.76074 .70205 Mdot
.76728 .46142 Mdot
.4122 .16966 Mdot
.81091 .52794 Mdot
.74769 .47021 Mdot
.20024 .58804 Mdot
.51256 .6171 Mdot
.29526 .31471 Mdot
.40902 .46593 Mdot
.2002 .35837 Mdot
.33026 .3461 Mdot
.38076 .17677 Mdot
.78964 .3423 Mdot
.38484 .75085 Mdot
.44759 .4683 Mdot
.6018 .44886 Mdot
.54084 .61988 Mdot
.29599 .36574 Mdot
.24776 .62916 Mdot
.49401 .66751 Mdot
.68715 .49999 Mdot
.66336 .41372 Mdot
.5791 .27989 Mdot
.38744 .69093 Mdot
.68429 .30593 Mdot
.78121 .53603 Mdot
.63212 .39059 Mdot
.51435 .55055 Mdot
.37409 .28426 Mdot
.51659 .66054 Mdot
.34599 .6933 Mdot
.23031 .46985 Mdot
.64863 .55952 Mdot
.62112 .46204 Mdot
.33238 .68092 Mdot
.78727 .65801 Mdot
.78921 .42598 Mdot
.39703 .18466 Mdot
.5606 .3651 Mdot
.27219 .67246 Mdot
.37902 .26732 Mdot
.20774 .63272 Mdot
.26663 .69398 Mdot
.73667 .44848 Mdot
.4315 .75563 Mdot
.22196 .62939 Mdot
.68701 .69585 Mdot
.46324 .16101 Mdot
.64927 .77694 Mdot
.66278 .76341 Mdot
.6864 .48768 Mdot
.37815 .62346 Mdot
.37139 .7437 Mdot
.43275 .29768 Mdot
.50747 .50135 Mdot
.33682 .81023 Mdot
.3174 .45877 Mdot
.2294 .74716 Mdot
.59834 .61466 Mdot
.17778 .57304 Mdot
.41016 .33536 Mdot
.55453 .48397 Mdot
.5115 .43305 Mdot
.78996 .49966 Mdot
.5781 .69303 Mdot
.79451 .61457 Mdot
.27476 .71454 Mdot
.68363 .45408 Mdot
.68277 .78915 Mdot
.81253 .65814 Mdot
.29881 .66495 Mdot
.43748 .50698 Mdot
.77987 .68266 Mdot
.67413 .48017 Mdot
.23246 .4539 Mdot
.83798 .45522 Mdot
.75843 .40613 Mdot
.42215 .58355 Mdot
.36167 .31046 Mdot
.63049 .23663 Mdot
.56672 .17157 Mdot
.21734 .6793 Mdot
.71864 .317 Mdot
.65358 .59322 Mdot
.53306 .45389 Mdot
.70961 .27671 Mdot
.47465 .59275 Mdot
.57668 .65054 Mdot
.49992 .64882 Mdot
.31703 .81803 Mdot
.54764 .21225 Mdot
.48297 .19341 Mdot
.49213 .63418 Mdot
.39266 .68615 Mdot
.53819 .65883 Mdot
.50546 .65785 Mdot
.76263 .42017 Mdot
.76192 .67515 Mdot
.50746 .64879 Mdot
.48757 .85595 Mdot
.31968 .53449 Mdot
.58651 .3858 Mdot
.36669 .74804 Mdot
.28143 .49553 Mdot
.58572 .64023 Mdot
.34304 .25659 Mdot
.80358 .41911 Mdot
.63343 .57764 Mdot
.80132 .48048 Mdot
.7144 .66571 Mdot
.3792 .64992 Mdot
.35868 .61504 Mdot
.7734 .39836 Mdot
.26184 .63487 Mdot
.43381 .77391 Mdot
.24424 .41153 Mdot
.65469 .47776 Mdot
.80651 .40789 Mdot
.66405 .44647 Mdot
.36812 .38979 Mdot
.48756 .57309 Mdot
.391 .37037 Mdot
.20712 .38943 Mdot
.529 .3268 Mdot
.44902 .63298 Mdot
.1776 .62823 Mdot
.42973 .70866 Mdot
.2119 .34984 Mdot
.22226 .496 Mdot
.38956 .76794 Mdot
.6093 .3014 Mdot
.59594 .32879 Mdot
.40703 .84097 Mdot
.62143 .54606 Mdot
.61857 .50784 Mdot
.49051 .77509 Mdot
.43097 .62333 Mdot
.56761 .24605 Mdot
.66989 .46196 Mdot
.51728 .59771 Mdot
.69619 .61265 Mdot
.3734 .57721 Mdot
.39818 .73859 Mdot
.51281 .57497 Mdot
.31705 .30384 Mdot
.46096 .17331 Mdot
.62378 .41527 Mdot
.24281 .74844 Mdot
.4453 .45044 Mdot
.30406 .64527 Mdot
.74847 .28774 Mdot
.22677 .70226 Mdot
.58549 .47356 Mdot
.81938 .65384 Mdot
.34714 .50918 Mdot
.75593 .36249 Mdot
.42835 .67623 Mdot
.65486 .76743 Mdot
.52048 .34239 Mdot
.39686 .28652 Mdot
.59642 .6125 Mdot
.20888 .46542 Mdot
.56474 .4331 Mdot
.4281 .72093 Mdot
.74287 .37458 Mdot
.27438 .46977 Mdot
.58667 .68404 Mdot
.58313 .30798 Mdot
.30387 .67094 Mdot
.36022 .60823 Mdot
.38151 .68999 Mdot
.49644 .19583 Mdot
.66773 .76762 Mdot
.41409 .15342 Mdot
.46995 .65845 Mdot
.53273 .38864 Mdot
.58631 .77408 Mdot
.79119 .45008 Mdot
.48509 .7526 Mdot
.72379 .26424 Mdot
.33282 .3277 Mdot
.38892 .59875 Mdot
.35798 .29058 Mdot
.44138 .53673 Mdot
.54423 .52287 Mdot
.75633 .54354 Mdot
.30227 .74257 Mdot
.51371 .68798 Mdot
.19045 .56257 Mdot
.45696 .76036 Mdot
.47877 .20158 Mdot
.43312 .75195 Mdot
.59493 .40315 Mdot
.37322 .65605 Mdot
.66679 .59127 Mdot
.47737 .1612 Mdot
.73155 .27101 Mdot
.66782 .62071 Mdot
.60599 .26404 Mdot
.82702 .48425 Mdot
.44581 .5192 Mdot
.54603 .4043 Mdot
.37889 .43442 Mdot
.29568 .44474 Mdot
.24243 .72613 Mdot
.77388 .42959 Mdot
.32558 .46128 Mdot
.53489 .18734 Mdot
.51804 .17186 Mdot
.33863 .19873 Mdot
.52932 .83439 Mdot
.41613 .63987 Mdot
.27033 .27211 Mdot
.49165 .67486 Mdot
.58705 .17349 Mdot
.74187 .4394 Mdot
.78117 .30389 Mdot
.28923 .66946 Mdot
.81089 .47892 Mdot
.20699 .605 Mdot
.55609 .66996 Mdot
.79207 .58828 Mdot
.55226 .45497 Mdot
.72204 .53354 Mdot
.80609 .55368 Mdot
.61428 .84763 Mdot
.45452 .43226 Mdot
.73536 .64752 Mdot
.66096 .71247 Mdot
.80271 .39907 Mdot
.71107 .38677 Mdot
.44585 .48345 Mdot
.6994 .5155 Mdot
.20919 .42164 Mdot
.38834 .27229 Mdot
.54786 .34563 Mdot
.71227 .38922 Mdot
.26778 .36521 Mdot
.34295 .29797 Mdot
.65269 .77708 Mdot
.30032 .67419 Mdot
.5334 .59421 Mdot
.36282 .52182 Mdot
.39753 .73157 Mdot
.52567 .35097 Mdot
.5708 .48167 Mdot
.39905 .43361 Mdot
.61481 .40096 Mdot
.57655 .6783 Mdot
.19278 .39906 Mdot
.52129 .71039 Mdot
.71655 .70583 Mdot
.41982 .73889 Mdot
.67704 .68571 Mdot
.49458 .75997 Mdot
.17788 .4685 Mdot
.67571 .35563 Mdot
.41505 .25197 Mdot
.58223 .20735 Mdot
.41998 .21035 Mdot
.37695 .68792 Mdot
.3448 .21945 Mdot
.65661 .62736 Mdot
.41671 .58887 Mdot
.63888 .72146 Mdot
.5683 .2714 Mdot
.32808 .44083 Mdot
.8098 .47789 Mdot
.6053 .50079 Mdot
.50083 .23358 Mdot
.80008 .59561 Mdot
.28555 .47769 Mdot
.3313 .71058 Mdot
.56018 .18367 Mdot
.60181 .42382 Mdot
.69917 .74266 Mdot
.62819 .69273 Mdot
.65835 .36502 Mdot
.45058 .18797 Mdot
.4251 .16245 Mdot
.51722 .46094 Mdot
.39618 .3226 Mdot
.3716 .50499 Mdot
.62867 .80363 Mdot
.78277 .44387 Mdot
.43226 .38659 Mdot
.71789 .57519 Mdot
.40866 .70179 Mdot
.74647 .57696 Mdot
.53988 .56835 Mdot
.28629 .33455 Mdot
.44857 .62211 Mdot
.37565 .7714 Mdot
.5327 .30911 Mdot
.52064 .40309 Mdot
.39462 .39798 Mdot
.40388 .3067 Mdot
.44563 .82741 Mdot
.34944 .41632 Mdot
.7315 .32428 Mdot
.32099 .68267 Mdot
.65544 .75539 Mdot
.76651 .39267 Mdot
.73219 .45649 Mdot
.57242 .68831 Mdot
.37063 .6469 Mdot
.66848 .56671 Mdot
.34978 .46945 Mdot
.58778 .41096 Mdot
.44385 .70908 Mdot
.82084 .42111 Mdot
.3414 .62716 Mdot
.42449 .30212 Mdot
.62553 .5348 Mdot
.36188 .39001 Mdot
.67882 .64433 Mdot
.76994 .29717 Mdot
.55547 .67218 Mdot
.3419 .32001 Mdot
.58875 .55071 Mdot
.41218 .33131 Mdot
.2165 .51289 Mdot
.4794 .14335 Mdot
.20262 .59834 Mdot
.51599 .52477 Mdot
.18619 .58704 Mdot
.78435 .50046 Mdot
.83744 .46885 Mdot
.33814 .31206 Mdot
.51002 .40935 Mdot
.47815 .3331 Mdot
.52674 .78419 Mdot
.62215 .53832 Mdot
.55247 .32613 Mdot
.52252 .605 Mdot
.69551 .5798 Mdot
.5866 .59152 Mdot
.42884 .38835 Mdot
.55492 .22396 Mdot
.57222 .19711 Mdot
.64086 .77091 Mdot
.65401 .66039 Mdot
.65695 .37207 Mdot
.28645 .34478 Mdot
.80915 .32525 Mdot
.14813 .56819 Mdot
.37064 .5028 Mdot
.67603 .62848 Mdot
.38251 .32229 Mdot
.62796 .47163 Mdot
.50872 .67569 Mdot
.5027 .7525 Mdot
.61647 .59129 Mdot
.54671 .32247 Mdot
.48735 .22871 Mdot
.78129 .5179 Mdot
.33283 .36184 Mdot
.67111 .51863 Mdot
.18519 .40807 Mdot
.80994 .62869 Mdot
.78706 .4424 Mdot
.76793 .26774 Mdot
.62152 .6872 Mdot
.32734 .52756 Mdot
.23198 .55168 Mdot
.4639 .17638 Mdot
.4053 .27185 Mdot
.23543 .41062 Mdot
.72055 .47367 Mdot
.33259 .32186 Mdot
.4826 .63655 Mdot
.53318 .2237 Mdot
.74144 .5784 Mdot
.54128 .50439 Mdot
.59878 .3323 Mdot
.36924 .19814 Mdot
.33736 .72735 Mdot
.60469 .21383 Mdot
.20011 .43943 Mdot
.54813 .85322 Mdot
.49061 .15897 Mdot
.47644 .26243 Mdot
.69698 .37131 Mdot
.22879 .57506 Mdot
.49412 .45508 Mdot
.46117 .597 Mdot
.23287 .44967 Mdot
.33666 .57994 Mdot
.64084 .29071 Mdot
.18361 .52634 Mdot
.37235 .27494 Mdot
.28571 .51007 Mdot
.50934 .41269 Mdot
.34263 .68454 Mdot
.60261 .2657 Mdot
.4837 .61292 Mdot
.49644 .48554 Mdot
.43588 .26948 Mdot
.32554 .67917 Mdot
.60522 .77107 Mdot
.80544 .52232 Mdot
.51647 .86757 Mdot
.72251 .34395 Mdot
.1758 .48255 Mdot
.43137 .50128 Mdot
.37076 .16289 Mdot
.79137 .5556 Mdot
.73883 .42336 Mdot
.77458 .64913 Mdot
.60767 .37959 Mdot
.34106 .54749 Mdot
.34962 .47023 Mdot
.69674 .28785 Mdot
.36975 .70108 Mdot
.26177 .50516 Mdot
.20121 .47053 Mdot
.38058 .2959 Mdot
.4425 .22721 Mdot
.43988 .29485 Mdot
.41125 .58683 Mdot
.42925 .70463 Mdot
.2409 .30201 Mdot
.51779 .49175 Mdot
.39267 .38938 Mdot
.46657 .42967 Mdot
.21294 .56458 Mdot
.84484 .59946 Mdot
.46089 .70949 Mdot
.44014 .21037 Mdot
.31272 .70798 Mdot
.45753 .54772 Mdot
.48081 .74331 Mdot
.7661 .2289 Mdot
.43293 .11905 Mdot
.43671 .71818 Mdot
.53081 .81876 Mdot
.31899 .71462 Mdot
.48827 .18645 Mdot
.642 .3491 Mdot
.70724 .59977 Mdot
.45995 .40519 Mdot
.47786 .53941 Mdot
.38363 .40358 Mdot
.78072 .62586 Mdot
.49295 .14785 Mdot
.19319 .48983 Mdot
.53772 .18784 Mdot
.41324 .56806 Mdot
.36598 .40999 Mdot
.82997 .33337 Mdot
.69961 .26732 Mdot
.4467 .50589 Mdot
.22062 .64082 Mdot
.31687 .44874 Mdot
.41853 .48307 Mdot
.64211 .26182 Mdot
.68389 .7872 Mdot
.37424 .27048 Mdot
.49153 .18186 Mdot
.45511 .63336 Mdot
.5768 .42117 Mdot
.59841 .61315 Mdot
.51352 .4499 Mdot
.41171 .55112 Mdot
.61745 .59872 Mdot
.28992 .40756 Mdot
.81406 .46419 Mdot
.55129 .60096 Mdot
.68811 .76912 Mdot
.70124 .22891 Mdot
.3457 .64645 Mdot
.52467 .77965 Mdot
.45586 .44961 Mdot
.28658 .50659 Mdot
.28531 .36793 Mdot
.29881 .45509 Mdot
.8189 .51973 Mdot
.16227 .32767 Mdot
.70545 .53806 Mdot
.31572 .28886 Mdot
.38932 .67294 Mdot
.53132 .6123 Mdot
.35563 .71031 Mdot
.67341 .38012 Mdot
.6391 .41099 Mdot
.42033 .56379 Mdot
.46274 .6347 Mdot
.60044 .59477 Mdot
.2022 .707 Mdot
.43019 .51436 Mdot
.50037 .70749 Mdot
.59056 .17636 Mdot
.24389 .41148 Mdot
.28115 .62733 Mdot
.3442 .46295 Mdot
.56549 .75132 Mdot
.51094 .40695 Mdot
.77945 .3732 Mdot
.3231 .26628 Mdot
.54816 .19941 Mdot
.34167 .62264 Mdot
.32686 .71043 Mdot
.37285 .52718 Mdot
.49657 .28346 Mdot
.56647 .61803 Mdot
.67286 .27983 Mdot
.35191 .53784 Mdot
.54894 .16144 Mdot
.56897 .39471 Mdot
.57542 .47953 Mdot
.47386 .66224 Mdot
.32378 .21205 Mdot
.20012 .53463 Mdot
.37096 .73088 Mdot
.1793 .45462 Mdot
.57303 .30233 Mdot
.33376 .3553 Mdot
.59903 .44055 Mdot
.36796 .5526 Mdot
.46474 .66961 Mdot
.16548 .43615 Mdot
.62741 .24822 Mdot
.71745 .52142 Mdot
.73426 .5539 Mdot
.57928 .80798 Mdot
.60497 .69156 Mdot
.74148 .2439 Mdot
.58115 .32143 Mdot
.17267 .42861 Mdot
.67527 .76022 Mdot
.46141 .70039 Mdot
.79859 .50124 Mdot
.31898 .47307 Mdot
.61735 .43117 Mdot
.53374 .19391 Mdot
.34324 .40294 Mdot
.25462 .34659 Mdot
.3498 .44041 Mdot
.22631 .37066 Mdot
.51963 .26397 Mdot
.59492 .25259 Mdot
.77292 .47701 Mdot
.20846 .55658 Mdot
.81249 .37772 Mdot
.52941 .78571 Mdot
.80177 .33597 Mdot
.81542 .39435 Mdot
.56917 .1802 Mdot
.23148 .39343 Mdot
.24901 .71516 Mdot
.74999 .43385 Mdot
.77594 .40614 Mdot
.76787 .53991 Mdot
.22009 .58437 Mdot
.58899 .36522 Mdot
.46775 .6993 Mdot
.54221 .6758 Mdot
.66582 .60015 Mdot
.08495 .53867 Mdot
.46089 .23374 Mdot
.46675 .68647 Mdot
.58157 .34934 Mdot
.53417 .17232 Mdot
.22022 .56355 Mdot
.80475 .56766 Mdot
.5418 .55843 Mdot
.39086 .40858 Mdot
.35054 .60662 Mdot
.61554 .7928 Mdot
.57172 .37 Mdot
.43323 .86282 Mdot
.79569 .64443 Mdot
.70997 .56028 Mdot
.53768 .53325 Mdot
.45565 .68879 Mdot
.45312 .77399 Mdot
.60356 .31996 Mdot
.81965 .53617 Mdot
.81245 .47352 Mdot
.7076 .27439 Mdot
.40706 .83968 Mdot
.65859 .75819 Mdot
.46169 .17492 Mdot
.78361 .46815 Mdot
.41945 .72252 Mdot
.46722 .28113 Mdot
.67342 .4738 Mdot
.73363 .51485 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo08Wooooo0_l0002nooooo`007?ooool00ol0003ooooooooo
o`29ooooo`;o0000__ooool001cooooo00?o0000ooooooooool0NOooool2o`000<kooooo000Loooo
o`03o`000?oooooooooo07Wooooo0_l0000Fooooo`;o0000]_ooool001cooooo00?o0000oooooooo
ool0Soooool4o`000;Kooooo000Looooo`03o`000?oooooooooo08oooooo0_l00008ooooo`;o0000
[_ooool001cooooo00?o0000ooooooooool0Q_ooool2o`00017ooooo0ol0002]ooooo`007?ooool0
0ol0003oooooooooo`26ooooo`;o00004_ooool5o`000:[ooooo000Looooo`03o`000?oooooooooo
09Sooooo1ol000001?oooooo0000o`000?l0002Vooooo`007?ooool00ol0003oooooooooo`2Hoooo
o`Co00001?ooool3o`000:Kooooo000Looooo`03o`000?oooooooooo09cooooo0_l0002[ooooo`00
7?ooool2o`0008Cooooo0_l0000Gooooo`;o00003_ooool2o`0009_ooooo000Looooo`03o`000?oo
oooooooo08?ooooo0_l0000@ooooo`;o00005Oooool2o`0000Cooooo0_l0002Eooooo`007?ooool0
0ol0003oooooooooo`24ooooo`;o00001?ooool2o`0000Wooooo0_l00004ooooo`?o00002oooool2
o`0000Oooooo0_l0002Eooooo`007?ooool00ol0003oooooooooo`1eooooo`;o00003Oooool4o`00
00;ooooo0_l00002ooooo`;o00000_ooool3o`0000;ooooo0_l00002ooooo`Go00002Oooool2o`00
00Cooooo0_l0002Hooooo`007?ooool00ol0003oooooooooo`1eooooo`;o00002?ooool2o`0000Go
oooo0_l00006ooooo`;o00000_ooool3o`0000;ooooo0_l00005ooooo`;o00003oooool2o`0009So
oooo000Looooo`03o`000?oooooooooo07kooooo0ol0000:ooooo`;o00003_ooool4o`0000?ooooo
0_l0002Uooooo`007?ooool00ol0003oooooooooo`1jooooo`;o00000_ooool2o`0000;ooooo0_l0
0006ooooo`?o00002oooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000000_l0
00000ooooooo0000o`000003ooooo`;o00002?ooool2o`0009?ooooo000Looooo`03o`000?oooooo
oooo07[ooooo0_l00006ooooo`;o00001_ooool2o`0000Kooooo0_l00004ooooo`;o00001_ooool2
o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Gooooo0_l0002<
ooooo`007?ooool00ol0003oooooooooo`1fooooo`Co00006?ooool3o`0000Wooooo0_l0000=oooo
o`Go00002Oooool3o`0008_ooooo000Looooo`03o`000?oooooooooo07Kooooo1?l0000Iooooo`?o
00001_ooool4o`0000Wooooo0_l00003ooooo`Co00000oooool2o`0000Gooooo0_l0002;ooooo`00
7?ooool00ol0003oooooooooo`21ooooo`;o00004Oooool2o`0000Kooooo0_l0000;ooooo`;o0000
1oooool2o`000003ooooool0003o000000;o00001oooool2o`0000Cooooo0_l00021ooooo`007?oo
ool00ol0003oooooooooo`1hooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00001Ooo
ool2o`0000Gooooo0_l00005ooooo`?o00003?ooool2o`0000Kooooo0_l00002ooooo`?o00000ooo
ool2o`0000;ooooo0_l00004ooooo`;o0000POooool001cooooo00?o0000ooooooooool0Loooool2
o`0000?ooooo0_l00003ooooo`;o00001oooool2o`0000Gooooo1_l000000ooooooo0000o`000005
ooooo`?o00003?ooool3o`0000Wooooo0_l00004ooooo`;o0000Roooool00006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo07?ooooo0_l0
0008ooooo`;o00003oooool5o`000003ooooool0003o000000;ooooo0ol000000ooooooo0000o`00
000=ooooo`?o00004_ooool2o`000003ooooool0003o000008Cooooo00001_ooooooMgMgoiRHV?oo
ooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`1looooo`?o00001Oooool3o`0000gooooo0_l00002ooooo`?o00000oooool2o`0000[o
oooo1?l0000Booooo`;o000000?oooooo`000?l00000Q?ooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo06[ooooo
0_l00008ooooo`;o000000?oooooo`000?l000000_ooool3o`0000Kooooo0ol0000?ooooo`;o0000
1_ooool2o`0000[ooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000000[ooooo
0_l00025ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ
8B7ok^k^00Kooooo0ol0001Aooooo`;o00005oooool2o`0000Sooooo0_l000000ooooooo0000o`00
0002ooooo`?o000000?oooooo`000?l000005Oooool4o`000003ooooool0003o000000;o00003_oo
ool3o`0000?ooooo0_l000000ooooooo0000o`00000:ooooo`Co0000Poooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooo
oooo057ooooo0_l0000Tooooo`;o00000_ooool3o`000003ooooool0003o000000Gooooo0_l00008
ooooo`?o00001Oooool2o`000003ooooool0003o000000;o00003_ooool2o`0001Gooooo0_l00023
ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0Noooool3o`0000Sooooo0_l000000ooooooo0000o`000005oooo
o`?o00001Oooool2o`0000_ooooo0_l0000;ooooo`;o00001Oooool2o`0008kooooo00001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oo
oooooooo06Gooooo0_l00002ooooo`;o00006?ooool4o`0000;ooooo1?l00008ooooo`;o000000?o
ooooo`000?l000001_ooool2o`0000?ooooo0_l00007ooooo`;o00000_ooool2o`0000?ooooo1?l0
0005ooooo`;o00002_ooool2o`0007_ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo06Gooooo0_l00002ooooo`;o
00001Oooool2o`0000cooooo0_l00003ooooo`Co00001?ooool2o`0000Sooooo0_l00009ooooo`;o
000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000;o00001oooool2o`0000Oo
oooo0ol00006ooooo`Go0000Noooool001cooooo00?o0000ooooooooool0L?ooool2o`0000cooooo
1?l00002ooooo`;o000000?oooooo`000?l000001?ooool2o`0001Cooooo0_l00004ooooo`;o0000
00?oooooo`000?l000004oooool2o`0000Gooooo1Ol0000;ooooo`;o0000Koooool001cooooo00?o
0000ooooooooool0H_ooool2o`0000Sooooo0_l00008ooooo`Co00000oooool5o`0000;ooooo1_l0
0003ooooo`;o00002_ooool3o`0000[ooooo0_l00006ooooo`;o00002_ooool2o`0000cooooo1Ol0
00000ooooooo0000o`000002o`0000Kooooo0_l0001_ooooo`007?ooool00ol0003oooooooooo`1R
ooooo`;o00002?ooool2o`0000Sooooo1_l000001?oooooo0000o`000?l00002ooooo`So00000_oo
ool2o`0000_ooooo0ol0000:ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`00
0002o`0000Sooooo0_l0000<ooooo`Co00000_ooool4o`0007Oooooo000Looooo`03o`000?oooooo
oooo05kooooo0_l0000Eooooo`;o00000_ooool3o`000004ooooool0003o0000ooooo`Co00001ooo
ool3o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`0000Wooooo1?l00003ooooo`;o00005_oo
ool2o`0000;ooooo0ol000000ooooooo0000o`00001gooooo`007?ooool00ol0003oooooooooo`1N
ooooo`;o00004_ooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`?o00000_ooool3
o`000003ooooool0003o000000Co00001?ooool2o`0000Cooooo0_l000001?oooooo0000o`000?oo
ool4o`0000cooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool2o`000003ooooool0
003o000000Cooooo0_l00008ooooo`?o000000?oooooo`000?l000001Oooool3o`0000Kooooo0_l0
000Cooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0L_ooool2o`0000_ooooo0_l00003
ooooo`?o000000Coooooo`000?l0003o00001oooool2o`0000Oooooo0_l00002ooooo`?o00003?oo
ool5o`0000;ooooo0_l00002ooooo`Go00001?ooool2o`0000Sooooo1?l00006ooooo`Ko00001?oo
ool2o`0001?ooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`1Gooooo`;o00002?ooool2
o`0002oooooo0_l0000:ooooo`?o00001oooool3o`0000Cooooo0_l00009ooooo`;o00000oooool2
o`0000Sooooo0_l000000ooooooo0000o`000002o`0000Kooooo0_l000001?oooooo0000o`000?l0
001]ooooo`007?ooool00ol0003oooooooooo`1Gooooo`;o000000?oooooo`000?l000001Oooool2
o`0000kooooo0ol0000Aooooo`;o00005oooool2o`0000Cooooo0_l00002ooooo`?o00005?ooool2
o`0000Oooooo0ol0000;ooooo`;o000000Coooooo`000?l0003o0000KOooool001cooooo00?o0000
ooooooooool0F_ooool2o`0000_ooooo0_l00008ooooo`?o00002oooool2o`0000Cooooo0_l00007
ooooo`;o00003?ooool2o`000003ooooool0003o000000?ooooo0_l00006ooooo`;o00003_ooool5
o`0000Oooooo0_l0000<ooooo`;o00000_ooool2o`0000gooooo0_l0001Nooooo`007?ooool00ol0
003oooooooooo`1Wooooo`;o00005_ooool3o`0000Kooooo0_l00004ooooo`;o00001_ooool2o`00
00Cooooo0_l000000ooooooo0000o`00000;ooooo`;o00001_ooool3o`0000Gooooo1ol0000Joooo
o`;o00002_ooool2o`0000;ooooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`1[ooooo`;o
000000?oooooo`000?l000001?ooool2o`0000Cooooo0_l00002ooooo`Co00001Oooool5o`0000;o
oooo0_l00006ooooo`;o00001oooool3o`000003ooooool0003o000000;ooooo0_l0000;ooooo`?o
00002_ooool2o`0000Gooooo0_l0000Cooooo`;o00003_ooool2o`0005[ooooo000Looooo`;o0000
E_ooool2o`0001Cooooo1Ol00004ooooo`;o00001?ooool2o`0000;ooooo1?l000000ooooooo0000
o`000002ooooo`Go00001oooool2o`0000Gooooo0_l00004ooooo`;o000000?oooooo`000?l00000
0_ooool2o`0000_ooooo1Ol00005ooooo`;o00001_ooool4o`0000Oooooo0_l0000=ooooo`;o0000
Ioooool001cooooo00?o0000ooooooooool0EOooool2o`0001Cooooo0ol00002ooooo`;o00002ooo
ool5o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000002?ooool2o`000003oooo
ool0003o000000;ooooo0_l00005ooooo`;o00001?ooool2o`0000kooooo0_l00004ooooo`?o0000
1_ooool2o`000003ooooool0003o000000Kooooo0_l0000=ooooo`;o0000Ioooool001cooooo00?o
0000ooooooooool0Eoooool2o`0000Kooooo0_l0000:ooooo`?o00000_ooool2o`0000Cooooo0ol0
0004ooooo`;o00000_ooool2o`0000?ooooo0_l0000:ooooo`;o00000_ooool4o`0000Oooooo0_l0
0007ooooo`;o00002_ooool2o`0000Gooooo0ol00009ooooo`;o00003Oooool2o`0000Gooooo1?l0
001Vooooo`007?ooool00ol0003oooooooooo`1Gooooo`;o00001_ooool2o`0000[ooooo0ol00008
ooooo`?o00002?ooool2o`0000[ooooo1?l000000ooooooo0000o`000002o`0000;ooooo0_l00000
0ooooooo0000o`000002ooooo`Co000000?oooooo`000?l000000oooool3o`0000[ooooo0_l00006
ooooo`;o00003?ooool2o`0000[ooooo0_l00005ooooo`Co0000I_ooool001cooooo00?o0000oooo
ooooool0I?ooool2o`0002?ooooo0_l00002ooooo`Co00000oooool2o`000005ooooool0003o0000
o`000?ooool00_l00002ooooo`;o00000_ooool4o`0000;ooooo1?l0000Dooooo`;o00002Oooool3
o`0001?ooooo0_l000000ooooooo0000o`000002o`00063ooooo000Looooo`03o`000?oooooooooo
06Cooooo0ol00007ooooo`;o00001Oooool4o`0000[ooooo0_l00004ooooo`;o00000oooool2o`00
00Oooooo0_l00004ooooo`?o00000_ooool5o`0000Cooooo0_l000000ooooooo0000o`00000=oooo
o`;o000000Coooooo`000?l0003o00002_ooool2o`00013ooooo1Ol000000ooooooo0000o`000002
o`0000gooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`1Rooooo`Go00001oooool2o`00
00Gooooo1_l000000ooooooo0000o`000005ooooo`;o00001?ooool3o`0000Kooooo0_l00009oooo
o`?o000000Coooooo`000?l0003o00002_ooool2o`0000gooooo0_l000000ooooooo0000o`000007
ooooo`;o00005?ooool4o`0001?ooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`1Doooo
o`;o00002_ooool6o`00013ooooo0_l000000ooooooo0000o`000003o`0000;ooooo0_l00007oooo
o`?o00001_ooool2o`0000[ooooo0_l000000ooooooo0000o`00000Booooo`;o00003Oooool2o`00
00?ooooo0_l00004ooooo`;o00006Oooool3o`0005cooooo000Looooo`03o`000?oooooooooo04oo
oooo0_l00003ooooo`;o00002_ooool2o`000004ooooool0003o0000o`0000oooooo1?l000000ooo
oooo0000o`000004ooooo`;o00001oooool2o`0001?ooooo0_l00003ooooo`;o00004?ooool2o`00
00gooooo0_l00007ooooo`Co00001Oooool2o`0000Gooooo0_l00003ooooo`?o00001Oooool3o`00
05cooooo000Looooo`03o`000?oooooooooo04_ooooo0_l00002ooooo`;o00002?ooool2o`0000[o
oooo0_l0000>ooooo`Co00000oooool2o`0000_ooooo0_l00002ooooo`;o00001Oooool2o`0000Co
oooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000Wooooo0_l00008oooo
o`;o000000Coooooo`000?l0003ooooo0_l0000=ooooo`;o00001Oooool5o`0000Cooooo0_l00003
ooooo`?o00000oooool2o`0005oooooo000Looooo`03o`000?oooooooooo04_ooooo0_l0000<oooo
o`;o00002_ooool2o`0000Sooooo0_l0000;ooooo`;o00000oooool2o`0000[ooooo1?l00003oooo
o`;o00001?ooool5o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000000_l00004
ooooo`?o00001oooool2o`000004ooooool0003o0000ooooo`;o00001?ooool2o`0000kooooo0_l0
00000ooooooo0000o`00000?ooooo`?o0000G_ooool001cooooo00?o0000ooooooooool0HOooool2
o`0000cooooo0_l00005ooooo`;o00000oooool3o`0000?ooooo0_l0000<ooooo`?o00000_ooool2
o`0000Kooooo3_l00005ooooo`;o00001oooool2o`0000;ooooo1?l00004ooooo`;o00003_ooool2
o`000003ooooool0003o000000oooooo1Ol0001Looooo`007?ooool00ol0003oooooooooo`1Qoooo
o`Co00002_ooool2o`0000Gooooo0_l00003ooooo`Co00000_ooool2o`0000_ooooo1?l0000:oooo
o`_o00004Oooool7o`0000_ooooo0_l00008ooooo`;o000000?oooooo`000?l000001_ooool3o`00
00Wooooo0_l00002ooooo`;o0000F?ooool001cooooo00?o0000ooooooooool0G?ooool4o`0000;o
oooo0ol00004ooooo`?o00000oooool4o`0000[ooooo0_l00002ooooo`;o00002oooool2o`0000co
oooo3?l00002ooooo`;o00003_ooool4o`0000cooooo1Ol0000@ooooo`?o00003Oooool3o`0005Oo
oooo000Looooo`03o`000?oooooooooo04?ooooo0_l0000Booooo`Wo00000_ooool2o`0000Gooooo
0ol00003ooooo`Co00002Oooool2o`0000gooooo0_l000000ooooooo0000o`000002o`0000Gooooo
0_l00004ooooo`Co000000?oooooo`000?l000001?l00002ooooo`;o00001oooool2o`0000?ooooo
1?l00006ooooo`;o00000_ooool2o`0000Cooooo0ol0000:ooooo`;o000000?oooooo`000?l00000
4_ooool4o`0005Gooooo000Looooo`03o`000?oooooooooo04?ooooo0_l0000Booooo`Ko00003?oo
ool2o`000003ooooool0003o000000[ooooo0_l00002ooooo`;o00002oooool4o`000003ooooool0
003o000000;o00001Oooool4o`000003ooooool0003o000000Wo00003?ooool2o`0000?ooooo1?l0
0006ooooo`;o00000_ooool2o`0000;ooooo0_l0000=ooooo`;o000000?oooooo`000?l000005?oo
ool2o`0000;ooooo0_l0001Aooooo`007?ooool2o`0005Kooooo0_l000000ooooooo0000o`000008
ooooo`;o00000oooool4o`000003ooooool0003o000000Gooooo0_l00003ooooo`;o00001?ooool2
o`0000Oooooo1?l00009ooooo`;o000000?oooooo`000?l000004ol00004ooooo`Co00001Oooool2
o`0000Oooooo0_l00003ooooo`;o000000?oooooo`000?l000003Oooool2o`0001[ooooo0ol0001A
ooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o00001_ooool4o`0000_ooooo0ol000001?oo
oooo0000o`000?l00004ooooo`;o00000oooool3o`0000?ooooo0_l00004ooooo`;o00001_ooool3
o`0000_ooooo0_l000000ooooooo0000o`00000Co`0000Cooooo2?l000000ooooooo0000o`000007
ooooo`;o00000oooool2o`000003ooooool0003o0000017ooooo0_l00002ooooo`;o00003Oooool2
o`0000?ooooo0_l00003ooooo`;o0000COooool001cooooo00?o0000ooooooooool0Boooool2o`00
00Kooooo0_l0000>ooooo`;o000000?oooooo`000?l000001Oooool2o`0000?ooooo0ol00003oooo
o`;o00001Oooool2o`0000;ooooo0_l000000ooooooo0000o`00000?oooooaKo00001oooool4o`00
0003ooooool0003o000001oooooo0_l000000ooooooo0000o`000002ooooo`Co00002oooool2o`00
00Gooooo0_l000000ooooooo0000o`00001=ooooo`007?ooool00ol0003oooooooooo`15ooooo`;o
00002Oooool2o`000003ooooool0003o0000017ooooo0_l000000ooooooo0000o`000007ooooo`;o
00002oooool2o`0000;ooooo1?l0000Cooooo`Go000000Coooooo`000?l0003ooooo0_l000000ooo
oooo0000o`000005o`0000;ooooo0_l00003ooooo`;o00001?ooool2o`0001[ooooo1_l00007oooo
o`;o00002oooool3o`0000Cooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`15ooooo`;o
000000?oooooo`000?l000001?ooool4o`0000Gooooo0_l0000@ooooo`?o00000oooool6o`0000So
oooo0_l00006ooooo`;o00002_ooool2o`0000Kooooo4_l00004ooooo`;o00000oooool2o`0000Co
oooo0_l0000Dooooo`;o00001?ooool4o`0000_ooooo0_l0000:ooooo`;o000000?oooooo`000?l0
0000Doooool001cooooo00?o0000ooooooooool0B?ooool2o`0000Cooooo0_l00007ooooo`Co0000
00?oooooo`000?l000002_ooool4o`0000;ooooo1?l000000ooooooo0000o`000008ooooo`;o0000
1oooool2o`0000;ooooo0_l00005ooooo`;o00001_ooool>o`000005ooooool0003o0000o`000?oo
ool00_l00004ooooo`;o00007?ooool2o`0000cooooo0_l00005ooooo`?o00002Oooool2o`000003
ooooool0003o000000?ooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`1>ooooo`?o0000
2?ooool5o`0000?ooooo0_l00005ooooo`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o
00004Oooool6o`0000kooooo4Ol000000ooooooo0000o`000004ooooo`;o00000oooool2o`0000Oo
oooo0_l00008ooooo`;o00003_ooool2o`000003ooooool0003o000000Co00000oooool2o`0000Wo
oooo0_l00006ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0Coooool2o`0000;ooooo
0_l00005ooooo`;o00001Oooool3o`0000Cooooo0_l000001?oooooo0000o`000?l0000;ooooo`;o
00000_ooool2o`0000?ooooo0_l00003ooooo`Go00003OoooolBo`0000?ooooo0_l00002ooooo`;o
00000oooool4o`0000Gooooo0_l00008ooooo`;o00003_ooool2o`000003ooooool0003o000000Co
00005oooool2o`0004gooooo000Looooo`03o`000?oooooooooo04gooooo0_l00004ooooo`;o0000
3Oooool2o`0000Cooooo1ol0000:ooooo`;o00000_ooool2o`0000?ooooo0_l00003ooooo`;o0000
00Coooooo`000?l0003o00001Oooool2o`0000Cooooo4ol00002ooooo`Oo00001Oooool2o`0000go
oooo0_l0000<ooooo`;o00001_ooool4o`0000?ooooo0_l00003ooooo`;o00003_ooool3o`0000Ko
oooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00006_ooool2o`000003oooo
ool0003o000000Wooooo0_l00004ooooo`?o00001?ooool4o`000003ooooool0003o000001?ooooo
0ol00006ooooo`Co00000oooool3o`0000?ooooo4ol00002ooooo`;o000000?oooooo`000?l00000
0_l0000:ooooo`;o00002?ooool2o`0000cooooo0_l00006ooooo`;o00001Oooool2o`0000?ooooo
0_l0000?ooooo`?o00001Oooool2o`0004Cooooo000Looooo`03o`000?oooooooooo037ooooo0_l0
000Mooooo`;o00002Oooool2o`0000Cooooo0ol00004ooooo`;o00000oooool3o`0000;ooooo0_l0
000;ooooo`;o000000Coooooo`000?l0003o00001_ooool4o`0000Cooooo0_l00004ooooo`Co0000
00?oooooo`000?l000004?l0000>ooooo`?o00000oooool2o`0002Kooooo0_l0000:ooooo`;o0000
0_ooool3o`0004[ooooo000Looooo`03o`000?oooooooooo05Cooooo0_l00003ooooo`;o00004_oo
ool3o`0000;ooooo0_l0000;ooooo`Go00001Oooool2o`0000Cooooo0_l00007oooooaSo00003ooo
ool2o`0000?ooooo0_l0000Mooooo`;o00000_ooool4o`000003ooooool0003o000000[ooooo1?l0
00000ooooooo0000o`00000;ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0Doooool3
o`0000?ooooo0_l0000;ooooo`;o00003?ooool2o`0000Cooooo1?l00003ooooo`;o00001_ooool4
o`0000;ooooo0_l00003ooooo`;o00000_oooolEo`0000cooooo0_l00002ooooo`;o00007Oooool2
o`0000?ooooo1?l00002ooooo`Co00000_ooool2o`0000_ooooo0_l00005ooooo`;o00001oooool2
o`0003gooooo000Looooo`03o`000?oooooooooo05?ooooo0_l00006ooooo`;o00001_ooool2o`00
0003ooooool0003o000000;ooooo0ol00007ooooo`;o00001?ooool4o`0000Wooooo0_l00002oooo
o`;o00001?ooool2o`000003ooooool0003o000000;ooooo5Ol0000:ooooo`Co00000_ooool2o`00
01gooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l00006oooo
o`Co00002?ooool2o`0004Kooooo000Looooo`03o`000?oooooooooo05Wooooo1?l00004ooooo`Co
000000?oooooo`000?l000000_ooool3o`0000Kooooo0_l00004ooooo`;o00000_ooool2o`0000So
oooo0_l00008ooooo`;o00001oooool@o`0000?ooooo0_l00008ooooo`;o00008_ooool2o`0000Oo
oooo1_l000000ooooooo0000o`000005ooooo`Wo00000_ooool2o`0004[ooooo000Looooo`03o`00
0?oooooooooo04kooooo0ol00008ooooo`Co00000oooool4o`0000Cooooo0_l00009ooooo`;o0000
0oooool3o`0000;ooooo0_l0000Koooooa3o00000oooool3o`000003ooooool0003o000001Wooooo
0_l0000=ooooo`;o00002?ooool4o`0000;ooooo0_l00002ooooo`Oo00000_ooool3o`0000;ooooo
0_l0001:ooooo`007?ooool2o`0004;ooooo0_l0000;ooooo`?o00002?ooool2o`0000Gooooo1?l0
0004ooooo`;o00003_ooool2o`0001cooooo0_l00002ooooo`oo00001Oooool2o`000003ooooool0
003o000000Kooooo0_l00002ooooo`;o00003?ooool4o`00023ooooo0ol00006ooooo`;o0000Cooo
ool001cooooo00?o0000ooooooooool0@Oooool2o`000003ooooool0003o000000Wooooo0ol00007
ooooo`;o00006_ooool2o`000003ooooool0003o000001cooooo0ol000000ooooooo0000o`00000=
o`0000Sooooo0ol00005ooooo`Ko00003?ooool4o`0004Sooooo0_l0000`ooooo`007?ooool00ol0
003oooooooooo`0fooooo`;o00003?ooool2o`0000Cooooo0_l00002ooooo`Co00001oooool2o`00
00gooooo0ol00002ooooo`;o00001_ooool2o`000003ooooool0003o000001cooooo1?l000000ooo
oooo0000o`00000<o`0000Sooooo0ol00007ooooo`;o00001oooool2o`0001;ooooo0_l00003oooo
o`;o00005?ooool2o`0002;ooooo0_l0000`ooooo`007?ooool00ol0003oooooooooo`0fooooo`;o
00001Oooool2o`0000Sooooo0_l000000ooooooo0000o`000002ooooo`?o00002?ooool2o`0000_o
oooo1Ol00002ooooo`;o0000:Oooool2o`000003ooooool0003o000000co00001?ooool2o`0000?o
oooo0ol00005ooooo`;o00002?ooool2o`0000oooooo0_l000000ooooooo0000o`000003ooooo`;o
00005?ooool2o`0005Cooooo000Looooo`03o`000?oooooooooo03gooooo0_l00008ooooo`;o0000
1_ooool2o`0001;ooooo1ol0000aooooo`oo00000oooool2o`0000;ooooo1?l00005ooooo`;o0000
0oooool6o`00013ooooo0_l0000@ooooo`;o00002Oooool2o`0000cooooo0_l00017ooooo`007?oo
ool00ol0003oooooooooo`1Cooooo`;o00001oooool4o`0000?ooooo1?l000000ooooooo0000o`00
000aooooo`oo00000oooool2o`0000;ooooo0ol00006ooooo`Co000000?oooooo`000?l000001?l0
000=ooooo`;o00004oooool2o`0000Wooooo0_l0000<ooooo`;o0000Aoooool001cooooo00?o0000
ooooooooool0?_ooool2o`0001;ooooo0ol00004ooooo`;o000000?oooooo`000?l000000_l00005
ooooo`;o0000>?ooool4o`000003ooooool0003o000000cooooo0_l00006ooooo`Ko00000oooool2
o`0000cooooo0ol0001eooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00001_ooool2o`00
00Cooooo0_l00004ooooo`;o00001Oooool2o`0000;ooooo0_l0000Looooo`;o000000Coooooo`00
0?l0003o00005?ooool2o`0000Kooooo0_l000000ooooooo0000o`000002ooooo`;o00002?ooool4
o`0000Cooooo0_l00003ooooo`Go00000oooool2o`0000cooooo0ol0000;ooooo`;o0000J?ooool0
01cooooo00?o0000ooooooooool0A_ooool2o`0000Cooooo0_l0000>ooooo`;o00002oooool2o`00
013ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00004Oooool3o`0000Gooooo0_l00000
1?oooooo0000o`000?l0000;ooooo`Co00001?ooool3o`0000;ooooo1?l0000Cooooo`;o00000ooo
ool2o`0000?ooooo0_l000000ooooooo0000o`00000<ooooo`;o00002_ooool2o`0004kooooo000L
ooooo`03o`000?oooooooooo04Oooooo0ol00002ooooo`;o00003_ooool2o`0000_ooooo0_l0000C
ooooo`;o00000_ooool2o`0001;ooooo0_l00005ooooo`;o00000_ooool2o`000003ooooool0003o
000000Kooooo0_l00009ooooo`;o00004?ooool2o`0000Kooooo0_l00004ooooo`;o00000oooool2
o`0000Gooooo0_l00007ooooo`Go000000?oooooo`000?l000001Oooool2o`0000Wooooo0_l00000
0ooooooo0000o`000010ooooo`007?ooool00ol0003oooooooooo`17ooooo`?o00002?ooool2o`00
00Wooooo0_l0000@ooooo`;o00003Oooool2o`0000?ooooo0_l0000<ooooo`;o00001?ooool2o`00
00_ooooo0_l00006ooooo`;o00005?ooool2o`0000Gooooo0_l00006ooooo`;o00000_ooool4o`00
00[ooooo0_l00007ooooo`;o000000Coooooo`000?l0003ooooo0_l0000@ooooo`;o000000?ooooo
o`000?l00000@?ooool001cooooo00?o0000ooooooooool0>_ooool2o`0000gooooo0_l00007oooo
o`;o00002Oooool2o`0000cooooo0_l00002ooooo`;o00004_ooool2o`0000;ooooo0_l00004oooo
o`;o00000_ooool2o`0000Cooooo0_l0000Cooooo`;o00005?ooool7o`0000cooooo1?l0000<oooo
o`;o00000oooool2o`0005gooooo000Looooo`03o`000?oooooooooo03[ooooo0_l0000<ooooo`?o
00004?ooool2o`0000kooooo0_l00009ooooo`;o00003oooool4o`0000;ooooo0_l0000>ooooo`;o
00000oooool2o`0000?ooooo0_l00003ooooo`;o00002?ooool2o`0000?ooooo0_l00006ooooo`Oo
00005_ooool7o`0000?ooooo0ol00009ooooo`;o0000DOooool001cooooo00?o0000ooooooooool0
7Oooool2o`00027ooooo0_l000000ooooooo0000o`000003ooooo`;o00002Oooool2o`0000Kooooo
0_l0000Eooooo`Ko000000Coooooo`000?l0003ooooo0_l0000:ooooo`?o00003Oooool2o`0000?o
oooo0_l00003ooooo`;o00000oooool4o`0000[ooooo0ol00003ooooo`Co00002Oooool4o`0001Co
oooo1_l00005ooooo`;o00002Oooool2o`00057ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^
kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0Moooo
o`;o00008Oooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o00001_ooool2o`00
01gooooo1?l00003ooooo`;o000000?oooooo`000?l000002_ooool4o`0000cooooo1?l0000=oooo
o`;o00002Oooool3o`0000Kooooo0_l0000;ooooo`;o00004_ooool2o`0000Cooooo0_l00004oooo
o`;o00002Oooool3o`00017ooooo0_l0000nooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5
ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo047ooooo0_l00004
ooooo`;o00000_ooool2o`0000_ooooo0_l0000Gooooo`;o00001?ooool4o`000003ooooool0003o
000000Go00001oooool2o`0000_ooooo0_l000001?oooooo0000o`000?l0000Aooooo`;o00001?oo
ool3o`000003ooooool0003o000000?ooooo0ol00003ooooo`;o00000_ooool2o`000004ooooool0
003o0000ooooo`?o00003_ooool2o`0000[ooooo0_l00009ooooo`;o00000_ooool2o`0000[ooooo
0_l00002ooooo`;o0000?_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Ooo
ool5o`0000Kooooo00?o0000ooooooooool0>oooool2o`0000Cooooo0_l00004ooooo`;o00003ooo
ool2o`000003ooooool0003o000000?ooooo0ol0000>ooooo`;o00001?ooool4o`000003ooooool0
003o000000Go00005?ooool2o`0000;ooooo0_l00004ooooo`;o00001_ooool2o`0000?ooooo0_l0
0005ooooo`;o000000?oooooo`000?l000000_ooool4o`0000?ooooo3ol00002ooooo`;o00002ooo
ool2o`0001Cooooo1?l00006ooooo`;o00000_ooool3o`000003ooooool0003o000003kooooo0000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001ooo
ool3o`0003_ooooo0_l000000ooooooo0000o`000006ooooo`?o00001?ooool2o`0000cooooo0_l0
0003ooooo`Go00001?ooool5o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_oo
ool2o`0000;ooooo1Ol00007ooooo`;o00004oooool2o`0000;ooooo0_l00002ooooo`;o00004Ooo
ool3o`0000Gooooo2Ol00003ooooo`;o00000_ooool3o`000003ooooool0003o000000Oooooo0_l0
000Dooooo`;o00002?ooool2o`0000;ooooo0ol000000ooooooo0000o`00000nooooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o
0000ooooooooool0=?ooool2o`0000Sooooo0_l00006ooooo`;o00001Oooool2o`0001?ooooo0ol0
0004ooooo`Go00001_ooool3o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`Go00001?oo
ool2o`000003ooooool0003o000000Cooooo0_l0000Aooooo`;o00000oooool2o`0000;ooooo0_l0
000<ooooo`?o00001Oooool@o`000004ooooool0003o0000ooooo`;o00002_ooool2o`0000gooooo
0_l00003ooooo`;o00002oooool2o`0000Kooooo0_l0000jooooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0=?oo
ool2o`000004ooooool0003o0000o`0001?ooooo0_l000000ooooooo0000o`000008ooooo`;o0000
1Oooool2o`0000Cooooo1?l00005ooooo`;o00000_ooool3o`0000;ooooo1Ol00003ooooo`;o0000
00?oooooo`000?l000000oooool2o`0000Oooooo0_l0000;ooooo`;o000000?oooooo`000?l00000
1_ooool3o`000003ooooool0003o000001;ooooo3_l000001Ooooooo0000o`000?l0003ooooo00Go
000000?oooooo`000?l000000oooool2o`0000;ooooo0_l00006ooooo`;o00001Oooool2o`0000?o
oooo0_l00008ooooo`;o00002Oooool2o`0003[ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMg
M`cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0gooooo`?o00002Oooool2o`00
00Cooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`000?l000001Oooool2
o`0000Gooooo0_l00004ooooo`;o00001oooool2o`000003ooooool0003o000000;o000000?ooooo
o`000?l000000ol00003ooooo`;o00000_ooool2o`0000[ooooo1?l0000;ooooo`;o000000?ooooo
o`000?l000001oooool2o`0000cooooo1?l00002oooooa[o00000_ooool2o`0000?ooooo0_l00005
ooooo`;o00000oooool2o`0000Oooooo0_l00006ooooo`;o00000oooool2o`0000Gooooo0_l0000n
ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o
0000ooooooooool0;?ooool2o`00013ooooo0ol00002ooooo`;o00001?ooool2o`000004ooooool0
003o0000ooooo`;o00000_ooool2o`0000Gooooo0_l0000Fooooo`Co00000_ooool5o`0000;ooooo
0ol000000ooooooo0000o`000002o`0000;ooooo0_l00005ooooo`Co00003_ooool3o`0000Sooooo
0_l0000:ooooo`Co00000_oooolGo`0000kooooo0_l000000ooooooo0000o`00000<ooooo`;o0000
1_ooool2o`0000?ooooo0_l00005ooooo`?o0000?Oooool001cooooo00?o0000ooooooooool0;?oo
ool2o`00013ooooo0ol0000>ooooo`;o00002Oooool2o`0001;ooooo0_l00002ooooo`Go00001?oo
ool7o`000003ooooool0003o000000?o000000?oooooo`000?l000000_l0000Eooooo`?o00002?oo
ool2o`000003ooooool0003o000000[ooooo0_l00002oooooaOo00002Oooool2o`000004ooooool0
003o0000o`0000Cooooo0_l0000;ooooo`;o00003_ooool2o`000003ooooool0003o000003gooooo
000Looooo`03o`000?oooooooooo03kooooo1?l00005ooooo`;o000000Coooooo`000?l0003o0000
3?ooool2o`0000Cooooo1?l0000;ooooo`Co000000?oooooo`000?l000001?l000000ooooooo0000
o`000005o`0000Gooooo1?l000000ooooooo0000o`000006ooooo`;o00005oooool2o`0000;ooooo
0_l00006ooooo`;o00000_ooool2o`0000;ooooo3_l00002ooooo`Oo00002Oooool2o`000003oooo
ool0003o000000Gooooo0_l00008ooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo
1?l00002ooooo`Go0000?Oooool001cooooo00?o0000ooooooooool0?_ooool4o`000003ooooool0
003o000000;ooooo0_l000001?oooooo0000o`000?l00005ooooo`;o00001Oooool2o`000004oooo
ool0003o0000ooooo`Co00002oooool4o`000004ooooool0003o0000oooooaCo000000Coooooo`00
0?l0003o00001Oooool2o`0000Sooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo0_l00000
0ooooooo0000o`00000:ooooo`;o00000_oooolMo`0000Wooooo1?l00006ooooo`;o00000_ooool2
o`0000;ooooo0_l00006ooooo`;o00000oooool4o`0000;ooooo1Ol0000mooooo`007?ooool00ol0
003oooooooooo`0fooooo`;o00002oooool2o`0000gooooo0_l00008ooooo`Co00000oooool4o`00
00Cooooo5?l00002ooooo`So000000?oooooo`000?l000001?l0000=ooooo`;o00000_ooool6o`00
00;ooooo0_l000000ooooooo0000o`00000>oooooago00002Oooool4o`0000Kooooo0ol000000ooo
oooo0000o`00000;ooooo`;o00004Oooool2o`0003Oooooo000Looooo`03o`000?oooooooooo03Co
oooo1?l00004ooooo`;o00008?ooool2o`0000?ooooo1?l00004ooooo`Co000000?oooooo`000?l0
00000_l000000ooooooo0000o`00000>o`000005ooooool0003o0000o`000?ooool01_l00002oooo
o`Co00003Oooool2o`0000Cooooo0_l000000ooooooo0000o`00000>ooooo`?o000000?oooooo`00
0?l000002?l000000ooooooo0000o`00000;o`00013ooooo0_l000000ooooooo0000o`000002o`00
00Sooooo0ol00003ooooo`;o00004Oooool2o`0003Oooooo000Looooo`03o`000?oooooooooo03Co
oooo0_l00004ooooo`Co0000<_ooool2o`0000;ooooo6Ol00002ooooo`Oo00001?ooool2o`0000Ko
oooo0_l00005ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0ol00005ooooo`?o
000000?oooooo`000?l000006?l00004ooooo`;o00002?ooool2o`000003ooooool0003o000000?o
oooo0_l00005ooooo`?o00006Oooool2o`0003Cooooo000Looooo`03o`000?oooooooooo01Oooooo
0_l0000Iooooo`;o00001_ooool2o`0000Cooooo0_l00002ooooo`;o00008?ooool2o`0000Sooooo
7_l000001?oooooo0000o`000?l00008ooooo`;o00001_ooool2o`0000Sooooo0_l00002ooooo`?o
000000?oooooo`000?l000000ol00003ooooo`?o000000?oooooo`000?l000006_l00002ooooo`;o
00002_ooool3o`0000?ooooo0_l00006ooooo`;o00003Oooool2o`0000[ooooo0_l0000dooooo`00
7?ooool00ol0003oooooooooo`0Gooooo`;o00006Oooool2o`0000;ooooo0_l00002ooooo`;o0000
00Coooooo`000?l0003ooooo0_l00002ooooo`;o00000oooool2o`0000Kooooo0_l0000<ooooo`;o
00001Oooool2o`0000;ooooo0_l000001?oooooo0000o`000?oooolKo`000003ooooool0003o0000
00Co00007oooool2o`0000Cooooo0_l00003ooooo`?o000000?oooooo`000?l000006_l00008oooo
o`;o00001?ooool2o`000004ooooool0003o0000o`0000oooooo0_l00006ooooo`;o0000@?ooool0
01cooooo00?o0000ooooooooool0=_ooool6o`000003ooooool0003o000000Gooooo1?l000000ooo
oooo0000o`000002o`0000Cooooo0_l0000<ooooo`;o00001_ooool2o`000003ooooool0003o0000
023o000000Coooooo`000?l0003o00001_ooool2o`0000Cooooo0_l0000Nooooo`Go000000?ooooo
o`000?l000002?l000000ooooooo0000o`00000=o`000003ooooool0003o000000Gooooo0_l00005
ooooo`Go00003?ooool2o`000003ooooool0003o000000[ooooo0_l00005ooooo`;o000000?ooooo
o`000?l00000<_ooool001cooooo00?o0000ooooooooool0>?ooool2o`0000Gooooo0_l00003oooo
o`Co00000oooool2o`0000oooooo0_l000000ooooooo0000o`000006ooooobGo000000?oooooo`00
0?l000000_l00005ooooo`;o00001?ooool2o`000003ooooool0003o000000Kooooo0_l0000Coooo
o`oo00000_ooool?o`000003ooooool0003o000000cooooo0_l0000=ooooo`Co00001?ooool2o`00
00Oooooo0_l00005ooooo`Go0000<_ooool001cooooo00?o0000ooooooooool09_ooool2o`0001Oo
oooo0_l00008ooooo`;o00004Oooool2o`0000Gooooo0_l00003ooooobGo000000Coooooo`000?l0
003o00002oooool2o`000003ooooool0003o000000Kooooo0_l0000Dooooo`oo000000?oooooo`00
0?l000004?l0000<ooooo`;o00003Oooool2o`0000Gooooo0ol00007ooooo`;o00001_ooool2o`00
03Cooooo000Looooo`;o00009oooool2o`0001gooooo0_l000001?oooooo0000o`000?l00002oooo
o`;o00004Oooool2o`000004ooooool0003o0000ooooo`Co000000?oooooo`000?l000003?l00000
0ooooooo0000o`00000Fo`0000Cooooo0_l00005ooooo`Co00000_ooool2o`0000kooooo1?l00006
ooooo`_o000000?oooooo`000?l000004_l0000>ooooo`;o00004?ooool2o`0000;ooooo0_l00016
ooooo`007?ooool00ol0003oooooooooo`0booooo`;o00000oooool2o`0000cooooo0_l000001Ooo
oooo0000o`000?l0003ooooo00?o00003_ooool2o`000004ooooool0003o0000ooooobco000000Co
ooooo`000?l0003o00000oooool2o`0000Gooooo2_l00002ooooo`;o00001Oooool2o`000003oooo
ool0003o000000;o00001oooool:o`000003ooooool0003o000001;o00002Oooool4o`0000Gooooo
0_l0000:ooooo`Co00003Oooool2o`0001;ooooo0_l0000Wooooo`007?ooool00ol0003ooooooooo
o`0Sooooo`;o00003Oooool2o`0000?ooooo0_l00003ooooo`;o00002?ooool4o`0000;ooooo0_l0
0009ooooo`;o00001?ooool2o`0000Cooooo0ol000000ooooooo0000o`00000Zo`0000[ooooo1_l0
00001?oooooo0000o`000?l00002ooooo`;o00001Oooool2o`0000?ooooo0_l00002ooooo`;o0000
1OoooolIo`000004ooooool0003o0000o`0000Wooooo1_l00003ooooo`;o000000?oooooo`000?l0
00001oooool2o`0000Cooooo0_l00009ooooo`;o00002?ooool3o`0000Oooooo0_l0000Wooooo`00
7?ooool00ol0003oooooooooo`0Sooooo`;o00004_ooool2o`0000?ooooo0_l00008ooooo`;o0000
0_ooool4o`0000Oooooo1?l0000:ooooo`;o000000?oooooo`000?l00000:_l0000=ooooo`;o0000
0_ooool3o`0001?ooooo0_l000000ooooooo0000o`00000Oo`0000cooooo0ol00006ooooo`;o0000
00?oooooo`000?l000002_ooool2o`000003ooooool0003o000000Kooooo0_l00008ooooo`?o0000
<?ooool001cooooo00?o0000ooooooooool0=oooool3o`0000Oooooo0_l00007ooooo`Co00001ooo
ool2o`0000cooooo0_l000001?oooooo0000o`000?oooolUo`0000;ooooo0_l00006ooooo`;o0000
0oooool2o`0000Cooooo0ol00004ooooo`;o00001_ooool2o`0000Gooooo0_l000000ooooooo0000
o`00000No`0000Kooooo0_l0000<ooooo`;o00000oooool2o`0000gooooo0ol00005ooooo`;o0000
>oooool001cooooo00?o0000ooooooooool0<?ooool2o`0000Kooooo0_l00006ooooo`?o00006?oo
ool2o`0000Cooooo1ol000000ooooooo0000o`00000So`0000;ooooo0_l00005ooooo`?o00000ooo
ool2o`0000_ooooo0_l00006ooooo`;o00001Oooool2o`0000;ooooo0_l000000ooooooo0000o`00
0002o`000003ooooool0003o0000017o000000Coooooo`000?l0003o00001?ooool4o`0000;ooooo
0_l00005ooooo`Go00001?ooool2o`0000gooooo0_l00012ooooo`007?ooool00ol0003ooooooooo
o`0`ooooo`?o00000oooool2o`0000Kooooo1?l00005ooooo`;o00003?ooool2o`0000?ooooo0ol0
0004ooooo`;o000000?oooooo`000?l000000_l00006ooooob;o00001_ooool3o`00023ooooo0_l0
0002ooooo`;o00000oooool3o`0000;ooooo4Ol000000ooooooo0000o`000005ooooo`;o00001?oo
ool2o`0000Gooooo1?l00005ooooo`;o000000?oooooo`000?l000000_l0000?ooooo`;o0000>ooo
ool001cooooo00?o0000ooooooooool08?ooool2o`0000oooooo0_l00003ooooo`;o00001_ooool2
o`0000Oooooo0_l0000<ooooo`;o00000oooool2o`0000Sooooo;?l000000ooooooo0000o`000003
ooooo`?o00005Oooool2o`0000?ooooo0_l00005ooooo`;o00001_ooool4o`000003ooooool0003o
000001;o00002oooool2o`0000?ooooo0_l00002ooooo`;o00002?ooool4o`0000Oooooo0_l00006
ooooo`;o0000>oooool001cooooo00?o0000ooooooooool08?ooool4o`0001Sooooo0_l00009oooo
o`;o00001?ooool2o`0001;ooooo0_l000000ooooooo0000o`00000]o`000004ooooool0003o0000
ooooo`;o00002oooool2o`0000Sooooo0_l00003ooooo`;o00001Oooool2o`0000Kooooo5ol0000=
ooooo`;o00000oooool2o`0000Wooooo1Ol00009ooooo`;o00002?ooool2o`0003Wooooo000Loooo
o`03o`000?oooooooooo02;ooooo0_l0000=ooooo`;o00002Oooool2o`0000Wooooo0_l00004oooo
o`?o00002Oooool2o`0000Kooooo0_l00002ooooo`?o000000?oooooo`000?l000002?l000000ooo
oooo0000o`00000Mo`000003ooooool0003o000000Oooooo0_l00005ooooo`;o00003Oooool6o`00
00Wooooo1Ol000000ooooooo0000o`00000;o`0000;ooooo0_l0000:ooooo`;o000000?oooooo`00
0?l000003_ooool3o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`?o00002?ooool2o`00
03Wooooo000Looooo`03o`000?oooooooooo037ooooo0_l00002ooooo`;o00004oooool2o`0000;o
oooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo1?l00003ooooo`?o
000000?oooooo`000?l000001ol000000ooooooo0000o`00000Mo`0000_ooooo0_l0000:ooooo`;o
00002_ooool4o`000003ooooool0003o000000Kooooo0_l00004ooooo`Co000000Coooooo`000?l0
003ooooo0ol00004ooooo`;o00001oooool2o`000003ooooool0003o000001Kooooo0_l000000ooo
oooo0000o`000002o`000004ooooool0003o0000o`0000Gooooo0_l0000>ooooo`;o0000;?ooool0
01cooooo00?o0000ooooooooool05oooool2o`0001cooooo0_l0000Aooooo`Co00001Oooool3o`00
0003ooooool0003o000000Oooooo1?l00006oooooaCo000000?oooooo`000?l000004Ol0000:oooo
o`;o000000Coooooo`000?l0003o00000_ooool2o`0000Gooooo0_l00005ooooo`;o00001?ooool2
o`0000;ooooo0ol00003ooooo`;o00001oooool2o`0000;ooooo0_l0000Aooooo`Co00006oooool3
o`0000?ooooo0ol000000ooooooo0000o`000003o`0000gooooo0_l0000/ooooo`007?ooool00ol0
003oooooooooo`0Gooooo`;o0000:Oooool2o`0000Cooooo0_l00007ooooo`;o00004Oooool2o`00
00;ooooo0_l000000ooooooo0000o`00000?o`000003ooooool0003o0000017o00000_ooool2o`00
00Kooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00002oooool3o`000003ooooool0003o
000000Kooooo0ol00002ooooo`;o00001?ooool2o`000003ooooool0003o000000Sooooo0_l00006
ooooo`;o00001Oooool2o`0001cooooo0_l00003ooooo`?o000000Coooooo`000?l0003ooooo0_l0
000kooooo`007?ooool00ol0003oooooooooo`0kooooo`;o00001Oooool2o`0000Cooooo0_l0000J
ooooo`;o00001OoooolEo`0000;ooooo3_l00002ooooo`Co00002?ooool2o`0000;ooooo1?l00000
0ooooooo0000o`000006ooooo`;o00000_ooool2o`0000Oooooo0_l00008ooooo`;o00001?ooool4
o`0000?ooooo0ol00005ooooo`Co00002_ooool2o`00013ooooo0_l00003ooooo`;o00002?ooool2
o`00017ooooo0_l0000Zooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00000_ooool2o`00
00Kooooo0_l00009ooooo`;o00002?ooool2o`0000Kooooo0_l000000ooooooo0000o`000004o`00
00?ooooo3?l000000ooooooo0000o`00000@o`0000;ooooo0_l00005ooooo`;o00003?ooool4o`00
0003ooooool0003o000002?ooooo1?l00004ooooo`;o00001oooool2o`0000[ooooo0_l00007oooo
o`;o00001oooool2o`0000[ooooo0_l000000ooooooo0000o`00000Aooooo`;o0000:_ooool001co
oooo00?o0000ooooooooool0=oooool2o`0000[ooooo0ol00008ooooo`;o00002?ooool2o`0000Ko
oooo0_l000000ooooooo0000o`000004o`0000?ooooo9_l0000Fooooo`;o00005Oooool4o`0001co
oooo0ol0000@ooooo`;o00001oooool2o`0000;ooooo0_l00006ooooo`;o00000_ooool2o`0003co
oooo000Looooo`;o00006oooool2o`0001_ooooo0_l0000;ooooo`;o00007Oooool2o`000003oooo
ool0003o000000;ooooo:?l0000<ooooo`;o000000?oooooo`000?l000001Oooool2o`0001Gooooo
1?l0000Hooooo`;o00000_ooool3o`0000Kooooo0_l000000ooooooo0000o`00000=ooooo`So0000
1oooool4o`0003cooooo000Looooo`03o`000?oooooooooo01[ooooo0_l0000Kooooo`?o00002_oo
ool2o`0000Oooooo0_l0000Cooooo`;o00001_oooolTo`0000Gooooo0_l00005ooooo`;o000000?o
ooooo`000?l000001?l00009ooooo`;o00004oooool2o`0001Sooooo1_l00007ooooo`Go00001?oo
ool2o`0000Oooooo2?l00004ooooo`;o000000Coooooo`000?l0003o0000?Oooool001cooooo00?o
0000ooooooooool08Oooool2o`0001Gooooo0_l0000Booooo`?o00000_ooool4o`0000;ooooo1?l0
00000ooooooo0000o`000004ooooo`;o00001_ooool2o`000003ooooool0003o000000Go000000?o
ooooo`000?l000006?l00004ooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`;o0000
2_ooool2o`0000Sooooo0_l0000:ooooo`;o000000?oooooo`000?l000003Oooool2o`000003oooo
ool0003o000000Cooooo1?l00008ooooo`?o00000oooool4o`0000Oooooo0_l0000:ooooo`;o0000
0_ooool2o`0003gooooo000Looooo`03o`000?oooooooooo027ooooo0_l0000Yooooo`?o00000_oo
ool4o`0000;ooooo1?l000000ooooooo0000o`000006ooooo`;o000000Coooooo`000?l0003ooooo
0_l000000ooooooo0000o`00000Eo`0000?ooooo3?l0000Fooooo`;o00002oooool2o`0000Wooooo
0ol000000ooooooo0000o`00000=ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o
00002_ooool2o`0000;ooooo0ol00008ooooo`;o00002oooool2o`0000;ooooo0_l0000mooooo`00
7?ooool00ol0003oooooooooo`13ooooo`;o00002_ooool2o`0000Kooooo1?l00009ooooo`Go0000
00Coooooo`000?l0003ooooo7_l000000ooooooo0000o`000007o`0000Sooooo1?l00008ooooo`;o
00002Oooool2o`0000_ooooo0_l0000>ooooo`;o00001oooool2o`0000;ooooo0_l00002ooooo`?o
00002?ooool3o`0000Kooooo0_l000000ooooooo0000o`000006ooooo`;o00001oooool2o`0003go
oooo000Looooo`03o`000?oooooooooo04?ooooo0_l00005ooooo`;o00000oooool2o`0000Kooooo
1?l0000:ooooo`;o00001?ooool4o`0000;ooooo9?l00004ooooo`;o00000_ooool4o`0000kooooo
0_l00003ooooo`;o00006oooool2o`0000?ooooo0_l00007ooooo`;o000000?oooooo`000?l00000
0_l00003ooooo`?o000000?oooooo`000?l000001oooool2o`0000Wooooo1?l00007ooooo`;o0000
>oooool001cooooo00?o0000ooooooooool0B_ooool2o`0000?ooooo0_l00003ooooo`;o00000ooo
ool2o`0000kooooo1_l00002oooooako00000_ooool2o`0000Kooooo0_l00003ooooo`;o00003ooo
ool2o`0000Gooooo0_l00002ooooo`?o00002Oooool2o`0000kooooo0_l00003ooooo`;o00000_oo
ool2o`000003ooooool0003o000000;o00000oooool3o`000003ooooool0003o000000Oooooo0_l0
0002ooooo`?o00001Oooool3o`000003ooooool0003o000000Cooooo0_l0000kooooo`007?ooool0
0ol0003oooooooooo`0fooooo`;o00001oooool2o`0001?ooooo0_l00003ooooo`Co00000oooool2
o`0000Oooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000001Oo00000_ooool3
o`0000;ooooo0_l0000;ooooo`;o000000?oooooo`000?l000000oooool2o`0000Gooooo0_l00000
0ooooooo0000o`000004ooooo`;o00000_ooool3o`000003ooooool0003o000000Kooooo0ol00006
ooooo`;o00000oooool4o`0000?ooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l0
0003ooooo`;o00002Oooool2o`000003ooooool0003o000000?o00001Oooool6o`00047ooooo000L
ooooo`03o`000?oooooooooo03Kooooo1?l00005ooooo`;o00006_ooool2o`0000?ooooo0_l0000:
ooooob3o00005Oooool2o`000003ooooool0003o000000;o00001Oooool2o`000003ooooool0003o
000000Cooooo0_l000000ooooooo0000o`000007o`0000Gooooo0_l00006ooooo`;o000000?ooooo
o`000?l000000_l00005ooooo`Ko00000oooool4o`0000gooooo1Ol00008ooooo`Co00001Oooool2
o`0003cooooo000Looooo`03o`000?oooooooooo02Kooooo0_l0000>ooooo`Co00003Oooool2o`00
0003ooooool0003o000001_ooooo0_l00007oooooako00001Oooool2o`0000cooooo0_l000000ooo
oooo0000o`000002o`0000[ooooo0_l00005ooooo`Go000000Coooooo`000?l0003o00004?ooool3
o`0000;ooooo0_l00002ooooo`Ko00000oooool4o`0000Wooooo0_l00003ooooo`?o00001?ooool2
o`0000Gooooo1?l00003ooooo`;o0000??ooool001cooooo00?o0000ooooooooool06oooool2o`00
00Wooooo0_l0000=ooooo`?o00003oooool2o`000003ooooool0003o000001_ooooo0_l000001?oo
oooo0000o`000?oooolIo`000003ooooool0003o000000;o000000?oooooo`000?l000001Oooool2
o`0000Oooooo1?l00006ooooo`;o00001Oooool2o`000003ooooool0003o000000;o00001oooool3
o`000003ooooool0003o000000Co00002?ooool2o`0000Oooooo0ol0000Hooooo`;o00002_ooool2
o`0000;ooooo1ol00011ooooo`007?ooool00ol0003oooooooooo`0Kooooo`;o00004Oooool2o`00
00Gooooo0_l00006ooooo`;o00000oooool2o`00023ooooo0_l00004ooooo`;o000000?oooooo`00
0?l000001_l00002ooooo`ko00000_ooool6o`0000oooooo1?l00004ooooo`?o00001?ooool4o`00
0003ooooool0003o000000;o00002?ooool2o`0000?ooooo1Ol000001?oooooo0000o`000?l00003
ooooo`;o000000?oooooo`000?l000001?ooool4o`0000gooooo0_l000000ooooooo0000o`000003
ooooo`;o00004?ooool6o`0004;ooooo000Looooo`03o`000?oooooooooo01Sooooo0_l0000Doooo
o`;o00003Oooool2o`0000?ooooo1?l00002ooooo`;o00006_ooool2o`0000Cooooo0_l00002oooo
o`So000000Coooooo`000?l0003ooooo2ol000001?oooooo0000o`000?ooool5o`0000oooooo0_l0
0005ooooo`?o00001?ooool2o`0000Gooooo0_l0000>ooooo`So00001_ooool4o`0000;ooooo1?l0
0007ooooo`Co00000_ooool6o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`0000Oooooo1Ol0
0011ooooo`007?ooool00ol0003oooooooooo`0Hooooo`;o00002?ooool2o`0000[ooooo0_l0000:
ooooo`;o00000_ooool2o`0000Cooooo0_l00002ooooo`;o00007?ooool2o`0000Oooooo0ol00002
ooooo`Co00000oooool8o`0000;ooooo0ol000001?oooooo0000o`000?ooool2o`0000Wooooo0_l0
0003ooooo`;o00001oooool2o`0000[ooooo0_l0000;ooooo`?o000000?oooooo`000?l000000_oo
ool2o`0000Sooooo1Ol0000<ooooo`Co00000oooool2o`000003ooooool0003o000000Kooooo0_l0
00001?oooooo0000o`000?ooool4o`0000Cooooo1?l000000ooooooo0000o`000011ooooo`007?oo
ool00ol0003oooooooooo`0Rooooo`;o00005_ooool2o`0000;ooooo0_l000000ooooooo0000o`00
0006ooooo`;o00000_ooool2o`0001Oooooo0ol00007ooooo`;o00000oooool3o`0000?ooooo2?l0
0002ooooo`;o000000?oooooo`000?l000001?ooool3o`0000Cooooo1?l00003ooooo`;o00004Ooo
ool6o`0000Wooooo0ol00005ooooo`Co00001_ooool2o`000003ooooool0003o000001gooooo0ol0
00001?oooooo0000o`000?ooool4o`0000Cooooo0_l00016ooooo`007?ooool00ol0003ooooooooo
o`0]ooooo`;o00004_ooool2o`0000Kooooo0_l00002ooooo`;o00000oooool2o`0001?ooooo0_l0
0002ooooo`;o00000_ooool3o`0000Gooooo0_l00002ooooo`Go000000?oooooo`000?l000000ol0
0002ooooo`?o00000oooool5o`0000;ooooo0_l00005ooooo`;o00004?ooool3o`0000;ooooo0_l0
000Aooooo`Co00001oooool2o`0000;ooooo0_l00009ooooo`;o00001_ooool3o`0000Oooooo0ol0
001Dooooo`007?ooool2o`0002kooooo0ol0000Booooo`;o00003_ooool2o`0001Cooooo0_l00000
0ooooooo0000o`000004o`0000Kooooo1?l000000ooooooo0000o`00000:o`000003ooooool0003o
000000Kooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000Gooooo0_l00007
ooooo`Co00002oooool2o`0000Wooooo0ol00008ooooo`;o00000_ooool2o`0000Wooooo0_l00006
ooooo`?o00002?ooool2o`0005Cooooo000Looooo`03o`000?oooooooooo02kooooo0_l00006oooo
o`;o00002_ooool2o`0000Cooooo0_l0000Nooooo`?o00000_ooool4o`0000?ooooo1ol000000ooo
oooo0000o`000003o`000003ooooool0003o000000Co00000_ooool2o`0000Sooooo0_l00003oooo
o`;o000000?oooooo`000?l000001Oooool2o`0000Kooooo0ol00008ooooo`;o00000oooool2o`00
0003ooooool0003o000000Oooooo0ol000000ooooooo0000o`00000Nooooo`?o00002?ooool2o`00
00[ooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`0Wooooo`;o00003Oooool2o`0000?o
oooo0_l00003ooooo`;o00001_ooool2o`0001oooooo0_l000001?oooooo0000o`000?ooool2o`00
0003ooooool0003o000000Co000000Coooooo`000?l0003ooooo1Ol000000ooooooo0000o`000003
o`0000?ooooo1?l00006ooooo`;o00000oooool4o`0000kooooo0_l00009ooooo`;o00000oooool2
o`000003ooooool0003o000000Gooooo0_l000001?oooooo0000o`000?ooool2o`0001Gooooo0_l0
00000ooooooo0000o`000004ooooo`?o00002?ooool2o`0000Gooooo0_l00003ooooo`Co0000@ooo
ool001cooooo00?o0000ooooooooool08Oooool2o`0000Cooooo0_l00008ooooo`;o00000oooool2
o`0000?ooooo0_l00003ooooo`;o00004Oooool2o`0001Gooooo1?l00004ooooo`Go00000_ooool2
o`000005ooooool0003o0000o`000?ooool01_l00006ooooo`;o00001_ooool2o`0000Cooooo0ol0
000?ooooo`;o00002Oooool2o`0000;ooooo0ol00007ooooo`;o00000oooool2o`0000?ooooo0_l0
000Aooooo`Go00001_ooool2o`0000gooooo0ol000000ooooooo0000o`000002ooooo`;o00001_oo
ool2o`0003_ooooo000Looooo`03o`000?oooooooooo027ooooo0_l0000>ooooo`;o00000oooool2
o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`Co000000?oooooo`000?l000002_ooool3
o`0001Gooooo0_l00009ooooo`?o00001_ooool4o`0000;ooooo0_l0000Dooooo`?o00003oooool3
o`0000Sooooo0_l00002ooooo`?o00001_ooool2o`0000Cooooo0_l00003ooooo`;o00000_ooool2
o`0000kooooo0_l00003ooooo`;o00000oooool2o`0000Oooooo0_l00004ooooo`?o000000?ooooo
o`000?l000002_ooool2o`0003_ooooo000Looooo`03o`000?oooooooooo03;ooooo0_l00006oooo
o`;o000000?oooooo`000?l000000_ooool7o`0000[ooooo0_l0000Qooooo`?o00001_ooool4o`00
00;ooooo0ol0000;ooooo`;o00001oooool2o`0000Sooooo1?l00004ooooo`;o00001_ooool2o`00
00_ooooo1?l00004ooooo`;o00001oooool2o`0001?ooooo0_l0000<ooooo`;o00001_ooool2o`00
01[ooooo0_l0000]ooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00001?ooool2o`0000So
oooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000;o0000;oooool2o`0000;o
oooo1Ol000001Ooooooo0000o`000?l0003ooooo00;o00001Oooool2o`0000Cooooo0_l00007oooo
o`;o00002?ooool4o`0000?ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l0000;oooo
o`;o00001Oooool6o`0000Kooooo0_l0000Eooooo`;o00001oooool2o`0000Gooooo1?l00002oooo
o`?o00001Oooool2o`0000kooooo0_l0000]ooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o
00003_ooool2o`000003ooooool0003o000000Kooooo0_l0000^ooooo`;o00000_ooool3o`0000?o
oooo0ol00007ooooo`?o00003Oooool2o`0000[ooooo0_l00003ooooo`;o000000?oooooo`000?l0
00000_l0000Eooooo`Oo00001_ooool4o`0001?ooooo0_l00007ooooo`;o00001Oooool2o`0000Co
oooo0ol00005ooooo`Co0000>oooool001cooooo00?o0000ooooooooool0=_ooool2o`0000Oooooo
0_l00006ooooo`;o0000=Oooool2o`0000_ooooo0_l00005ooooo`;o00001oooool5o`0000?ooooo
0_l00002ooooo`;o00007oooool3o`000003ooooool0003o000000Wooooo0_l00007ooooo`;o0000
0oooool2o`0001;ooooo0_l000001?oooooo0000o`000?l0000=ooooo`;o0000>oooool001cooooo
00?o0000ooooooooool0;?ooool2o`0000Sooooo0_l0000<ooooo`Go0000;Oooool2o`0000;ooooo
0_l00002ooooo`;o00004_ooool2o`0000Gooooo1ol00003ooooo`;o00005_ooool2o`0000[ooooo
1Ol00006ooooo`;o00003?ooool2o`000003ooooool0003o000000Co00001?ooool4o`0000Sooooo
2?l00006ooooo`;o00004?ooool2o`0002kooooo000Looooo`03o`000?oooooooooo02cooooo0_l0
000=ooooo`;o00000oooool2o`0000;ooooo1?l00003ooooo`;o00007Oooool2o`0000Wooooo1ol0
000Mooooo`;o00000_ooool2o`0000Wooooo0_l0000>ooooo`;o000000?oooooo`000?l000001Ooo
ool2o`000003ooooool0003o000000Ko00001Oooool2o`0000;ooooo0_l00006ooooo`;o00000ooo
ool2o`0000;ooooo0_l00004ooooo`Co00002Oooool3o`0000;ooooo0_l00006ooooo`;o00004?oo
ool2o`0002kooooo000Looooo`03o`000?oooooooooo03[ooooo0ol00003ooooo`;o00000_ooool2
o`0000Gooooo0_l00006ooooo`?o00005?ooool2o`0000Wooooo0_l000000ooooooo0000o`000009
ooooo`Co00001_ooool2o`0000kooooo0_l00003ooooo`;o00001?ooool2o`0000kooooo0_l00003
ooooo`;o00000_ooool>o`000003ooooool0003o000000Cooooo0_l00006ooooo`;o00002?ooool2
o`0000cooooo0_l00002ooooo`;o00002_ooool2o`00047ooooo000Looooo`03o`000?oooooooooo
02Sooooo0_l0000;ooooo`Oo000000?oooooo`000?l000001ol0000=ooooo`?o00008?ooool2o`00
00Oooooo0_l000000ooooooo0000o`000003o`0000Kooooo0_l0000Cooooo`;o00003Oooool2o`00
00[ooooo0_l00002oooooa7o00002Oooool2o`0000Kooooo0_l00002ooooo`Go00002_ooool2o`00
00kooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0Xooooo`;o00002oooool6o`0000;o
oooo2?l0000Booooo`;o00004oooool4o`0000Kooooo0_l00006ooooo`So00004oooool2o`0001Ko
oooo0_l0000@oooooa3o00002?ooool2o`0000Kooooo0_l00002ooooo`;o000000?oooooo`000?l0
00004Oooool2o`000003ooooool0003o000000Cooooo0_l00004ooooo`Co0000>Oooool00006oooo
ooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006
ooooo`03o`000?oooooooooo03[ooooo0_l0000Kooooo`;o00004oooool4o`0000kooooo1?l00002
ooooo`;o00003oooool3o`000003ooooool0003o000000kooooo0_l00005ooooo`;o00002Oooool2
o`0000;ooooo6?l0000Cooooo`;o00002oooool2o`0000Cooooo1Ol0000:ooooo`Co0000>Oooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RH
ob4Q8@06ooooo`03o`000?oooooooooo03[ooooo0_l00014ooooo`;o00003Oooool2o`000004oooo
ool0003o0000ooooo`Go00003_ooool3o`0000Gooooo0_l00009ooooo`;o00000_oooolHo`0001?o
oooo0_l00002ooooo`;o00001Oooool4o`0000Kooooo0ol00002ooooo`?o0000@_ooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool0>_ooool2o`0000;ooooo0_l0000Eooooo`;o00004_ooool2o`0000Co
oooo0_l0000:ooooo`;o00001_ooool4o`0000Sooooo0_l000001?oooooo0000o`000?l00003oooo
o`;o00001?ooool2o`0000Cooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo0_l00002oooo
o`;o000000?oooooo`000?l000001Oooool3o`000003ooooool0003o000001?o00000_ooool2o`00
00Oooooo0_l0000:ooooo`;o00000_ooool2o`000003ooooool0003o000000Wooooo0ol000001?oo
oooo0000o`000?l00008ooooo`;o00001?ooool2o`0003;ooooo00000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000=_ooool2
o`0000;ooooo0_l00002ooooo`;o00005Oooool3o`00017ooooo0_l00004ooooo`;o00002_ooool2
o`0000Kooooo1?l00002ooooo`;o00002?ooool2o`0000Wooooo0_l00004ooooo`;o00001Oooool3
o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000005oooooaSo00000oooool2
o`0000Oooooo0_l000000ooooooo0000o`000002ooooo`;o00001oooool2o`0000gooooo0_l0000<
ooooo`;o00001?ooool2o`0003;ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo03Kooooo0_l00008
ooooo`;o00003Oooool2o`0000Gooooo0_l0000Fooooo`;o00004oooool4o`0000;ooooo0_l00004
ooooo`;o00001Oooool2o`0000Kooooo0_l00006ooooo`;o00000oooool2o`0000;ooooo0_l0000?
oooooaCo00004Oooool6o`0001Kooooo0ol00008ooooo`;o0000>oooool00003ooooool@413ooooo
00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo
037ooooo0_l0000=ooooo`;o00003Oooool2o`0000Cooooo0_l00003ooooo`;o00004_ooool5o`00
00[ooooo1?l00002ooooo`?o00000_ooool2o`0000Gooooo0_l00005ooooo`;o00003_ooool2o`00
00[ooooo0_l000000ooooooo0000o`000004o`000003ooooool0003o000001Oo00004_ooool2o`00
01Cooooo0_l00003ooooo`;o00002?ooool2o`0003_ooooo00001_ooooooMgMgoiRHV?ooooooV9RH
ogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0aooooo`;o00007?ooool2
o`0000Cooooo0_l000000ooooooo0000o`000002o`0001Cooooo0ol00009ooooo`Oo00000_ooool2
o`000004ooooool0003o0000ooooo`;o00001oooool2o`0001?ooooo0_l00005ooooo`Co000000?o
ooooo`000?l000001?l000000ooooooo0000o`00000Do`000004ooooool0003o0000o`0000Cooooo
0_l000001?oooooo0000o`000?l00007ooooo`;o00005?ooool2o`0000cooooo0_l0000looooo`00
00Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000
ooooooooool0>Oooool3o`000003ooooool0003o0000013ooooo1?l00005ooooo`;o000000?ooooo
o`000?l000005?ooool2o`0000Wooooo0_l00003ooooo`Ko000000?oooooo`000?l000001Ol00005
ooooo`;o00000oooool2o`0000kooooo0_l00005ooooo`;o00001_ooool2o`0000?ooooo4?l00000
0ooooooo0000o`000006o`0000Cooooo0_l000001?oooooo0000o`000?l0000Nooooo`;o00002Ooo
ool4o`0003cooooo000Looooo`03o`000?oooooooooo03Oooooo1Ol000000ooooooo0000o`000003
ooooo`;o00003Oooool2o`0000Kooooo1?l0000>ooooo`;o00001?ooool2o`0000kooooo2ol00000
0ooooooo0000o`000006ooooo`Ko00002?ooool2o`0000_ooooo0ol000000ooooooo0000o`000002
ooooo`;o00000_ooool5o`000003ooooool0003o0000013o00006_ooool2o`0000;ooooo0_l0000:
ooooo`;o00000oooool2o`0000Cooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0goooo
o`;o00002Oooool2o`0001Gooooo0_l0000@ooooo`?o00003Oooool2o`0000;ooooo4?l00006oooo
o`Go00002?ooool3o`0000Oooooo0_l00002ooooo`Ko00001OoooolLo`0000Oooooo0_l0000>oooo
o`Ko00003oooool2o`0004Cooooo000Looooo`03o`000?oooooooooo03[ooooo0_l0000Nooooo`;o
000000?oooooo`000?l000003?ooool3o`0000Wooooo0_l00002ooooo`;o00000_ooool2o`0000;o
oooo3_l00008ooooo`;o00001oooool2o`000003ooooool0003o000000;o00000oooool2o`0000Go
oooo0_l00006oooooaco00001oooool2o`0000Oooooo0_l00007ooooo`;o00005Oooool2o`00043o
oooo000Looooo`03o`000?oooooooooo03[ooooo0_l00005ooooo`;o00005Oooool4o`000003oooo
ool0003o000000cooooo0_l0000:ooooo`;o00001?ooool2o`000003ooooool0003o000001;o0000
1?ooool3o`0000[ooooo1?l0000Dooooo`_o000000?oooooo`000?l000002_l000000ooooooo0000
o`000002o`0000gooooo0ol0000=ooooo`;o000000?oooooo`000?l000002oooool2o`00043ooooo
000Looooo`03o`000?oooooooooo03Kooooo0_l00009ooooo`;o000000?oooooo`000?l000001ooo
ool2o`0000Wooooo0_l0000=ooooo`;o00000_ooool2o`00013ooooo0_l000001Ooooooo0000o`00
0?l0003ooooo013o00001?ooool2o`0000gooooo0_l0000Aooooo`ko000000?oooooo`000?l00000
2?l000000ooooooo0000o`000004o`0000[ooooo0_l00002ooooo`;o00001_ooool2o`0000Gooooo
0_l000000ooooooo0000o`000007ooooo`;o000000Coooooo`000?l0003ooooo0_l0000nooooo`00
7?ooool00ol0003oooooooooo`0fooooo`;o00002?ooool2o`0000;ooooo0_l00007ooooo`;o0000
6?ooool2o`0000cooooo0_l00007oooooaGo00002Oooool2o`0000Wooooo0_l0000>ooooo`;o0000
00?oooooo`000?l000006_l00002ooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`?o
00002Oooool2o`00017ooooo0_l000001?oooooo0000o`000?ooool2o`0003kooooo000Looooo`03
o`000?oooooooooo03cooooo0_l00002ooooo`;o00001_ooool2o`0000Oooooo0_l0000<ooooo`;o
00002?ooool2o`0000[ooooo0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o000000oo
000000?oooooo`000?l000000oooool6o`0000Oooooo1?l0000=ooooo`?o00000ooooolIo`0000?o
oooo0_l00004ooooo`;o000000?oooooo`000?l000000_ooool2o`0001oooooo0_l00011ooooo`00
7?ooool00ol0003oooooooooo`0aooooo`;o00001Oooool2o`0000;ooooo0_l0000:ooooo`;o0000
1_ooool3o`0000cooooo0_l00007ooooo`Co00001?ooool2o`0000Oooooo0ol00005oooooa7o0000
00?oooooo`000?l000000oooool5o`0000;ooooo0_l00004ooooo`;o00000oooool2o`0000[ooooo
0ol000000ooooooo0000o`00000Ho`0000Cooooo0_l0000>ooooo`;o00001?ooool2o`0001Kooooo
1?l0000oooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00001Oooool2o`0000[ooooo0ol0
00000ooooooo0000o`000006ooooo`;o00005_ooool4o`0000Cooooo0_l00007ooooo`;o00001Ooo
oolEo`0000[ooooo1?l00007ooooo`;o00000oooool2o`0000Cooooo0_l00003oooooaSo00005_oo
ool2o`0000Cooooo0_l0000Hooooo`;o0000?oooool001cooooo00?o0000ooooooooool0A?ooool3
o`000003ooooool0003o000000Kooooo0_l0000=ooooo`;o00003?ooool2o`0000Oooooo0_l00007
oooooaKo00002_ooool4o`0000Kooooo0_l00004ooooo`;o00000_ooool4o`0000?ooooo6Ol00002
ooooo`;o00000_ooool2o`0001;ooooo0_l0000@ooooo`Co0000A_ooool001cooooo00?o0000oooo
ooooool0D?ooool2o`0000;ooooo0_l00009ooooo`;o00003?ooool2o`0000Cooooo1Ol00002oooo
o`;o00000_oooolGo`0000Gooooo0_l00003ooooo`Co00001_ooool2o`0000Sooooo0_l00005oooo
oaWo00000_ooool6o`00013ooooo1?l00002ooooo`;o00001Oooool2o`0000?ooooo1_l00016oooo
o`007?ooool2o`0005Gooooo0_l000000ooooooo0000o`000004ooooo`;o00001?ooool2o`0000_o
oooo0_l000000ooooooo0000o`000004o`000004ooooool0003o0000ooooo`Wo000000?oooooo`00
0?l000003Ol00004ooooo`;o00000oooool4o`00013ooooo0_l00003ooooo`Wo000000?oooooo`00
0?l000004_l000000ooooooo0000o`00000?ooooo`;o000000Coooooo`000?l0003o00000oooool3
o`0000?ooooo0ol00003ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0Aoooool2o`00
00kooooo0_l00004ooooo`?o000000?oooooo`000?l000000_l0000;ooooo`;o00001Oooool2o`00
00Cooooo6Ol000000ooooooo0000o`00000<ooooo`;o00004OoooolFo`0000?ooooo1Ol0000Boooo
o`;o000000?oooooo`000?l000001Oooool2o`0000?ooooo0_l0000=ooooo`;o0000@Oooool001co
oooo00?o0000ooooooooool0@Oooool2o`0000?ooooo0ol0000=ooooo`;o00001_ooool2o`000003
ooooool0003o000001;ooooo0_l00006oooooaco00001oooool2o`0000?ooooo0_l000000ooooooo
0000o`000003o`00017ooooo1?l000000ooooooo0000o`000008o`0000?ooooo0ol0000Yooooo`;o
00001_ooool4o`00047ooooo000Looooo`03o`000?oooooooooo047ooooo0_l00003ooooo`;o0000
3_ooool2o`0001gooooo0_l00002ooooo`;o00000_ooool9o`0000;ooooo1_l00002ooooo`Co0000
00?oooooo`000?l000002Oooool2o`0000;ooooo0ol000000ooooooo0000o`000003o`0000gooooo
1?l00002ooooo`;o000000?oooooo`000?l000000_ooool3o`000004ooooool0003o0000o`0000;o
oooo0ol0000Mooooo`;o00002_ooool2o`0000Cooooo1?l00013ooooo`007?ooool00ol0003ooooo
ooooo`0looooo`?o00007_ooool2o`0001[ooooo0_l00002oooooaOo00000_ooool2o`0000cooooo
0ol0000@ooooo`;o000000?oooooo`000?l000000_l000001?oooooo0000o`000?l0000:ooooo`Oo
00001?ooool2o`0000Wooooo0_l00003ooooo`;o00001_ooool3o`0000Sooooo0_l00006ooooo`;o
0000AOooool001cooooo00?o0000ooooooooool0>_ooool5o`0001kooooo0_l0000@ooooo`;o0000
3_oooolEo`0000;ooooo0_l00005ooooo`;o00003?ooool2o`000003ooooool0003o000000;ooooo
0_l00003ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000007o`0000Kooooo
0ol00004ooooo`Co00002Oooool4o`000003ooooool0003o000000Kooooo0_l00009ooooo`;o0000
1_ooool2o`0004Gooooo000Looooo`03o`000?oooooooooo03[ooooo0_l0000Aooooo`;o00002ooo
ool2o`0000?ooooo0_l00002ooooo`;o00002_ooool2o`0000Wooooo0_l000000ooooooo0000o`00
000Fo`0000Sooooo0_l0000<ooooo`;o000000Coooooo`000?l0003ooooo0ol00008ooooo`;o0000
00?oooooo`000?l000001ol0000=ooooo`;o00003?ooool3o`000003ooooool0003o000000?ooooo
0_l0000:ooooo`;o00002?ooool2o`0000;ooooo0_l00011ooooo`007?ooool00ol0003ooooooooo
o`14ooooo`;o00001?ooool2o`000003ooooool0003o000000Kooooo0ol00002ooooo`;o00000_oo
ool3o`0000;ooooo0_l0000<ooooo`;o00001ooooolLo`0001Gooooo0_l00004ooooo`;o00003Ooo
ool4o`0000Kooooo0_l00007ooooo`;o00001Oooool2o`0000Oooooo0_l00007ooooo`;o00002_oo
ool2o`0000cooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00001?ooool2
o`0000Kooooo0_l000001?oooooo0000o`000?l00002ooooo`Ko00004Oooool2o`0000Sooooo6ol0
0005ooooo`?o00000oooool2o`0000Gooooo0_l00002ooooo`;o00000oooool2o`0000gooooo1?l0
0006ooooo`;o00001oooool2o`0000Gooooo0_l0000Hooooo`;o00001?ooool2o`0004gooooo000L
ooooo`03o`000?oooooooooo03[ooooo0_l00004ooooo`;o000000?oooooo`000?l000002oooool4
o`0000Sooooo0_l00008ooooo`;o00004?ooool2o`000003ooooool0003o000000co000000?ooooo
o`000?l000002Ol00006ooooo`?o00000oooool2o`0000Gooooo0_l00002ooooo`;o00000oooool2
o`0000Gooooo0_l00008ooooo`;o00008?ooool2o`0000Wooooo1?l000000ooooooo0000o`000004
ooooo`;o0000COooool001cooooo00?o0000ooooooooool0>_ooool2o`0000Cooooo0_l000000ooo
oooo0000o`00000;ooooo`;o00004oooool5o`0000kooooo0_l000000ooooooo0000o`00000Fo`00
0003ooooool0003o000001_ooooo0_l00005ooooo`;o00002oooool2o`0001Wooooo0_l00002oooo
o`;o00002Oooool4o`0000Gooooo1?l00004ooooo`;o000000?oooooo`000?l00000A?ooool001co
oooo00?o0000ooooooooool0B?ooool2o`000003ooooool0003o000001Sooooo0_l000000ooooooo
0000o`000002ooooo`;o00001_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000Eo`0000;o
oooo0_l0000=ooooo`;o00003_ooool2o`000003ooooool0003o000000?ooooo0_l00004ooooo`;o
00000_ooool2o`0000Oooooo0_l000000ooooooo0000o`000005ooooo`Co000000Coooooo`000?l0
003ooooo0_l00004ooooo`;o00000_ooool2o`0000cooooo1?l00004ooooo`;o000000?oooooo`00
0?l00000A?ooool001cooooo00?o0000ooooooooool0B?ooool2o`000003ooooool0003o000000Oo
oooo0_l0000Aooooo`;o00000oooool2o`0000Kooooo0_l000000ooooooo0000o`000002oooooa_o
00003Oooool2o`0000;ooooo0_l0000:ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`00
00Cooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo0_l000001?oooooo0000o`000?l00004
ooooo`Co000000?oooooo`000?l000001oooool2o`0000;ooooo0_l0001Mooooo`007?ooool00ol0
003oooooooooo`1Aooooo`;o000000?oooooo`000?l000003?ooool2o`0000?ooooo0_l0000>oooo
oako00000_ooool2o`000003ooooool0003o000000;ooooo0_l00003ooooo`;o00000_ooool2o`00
00gooooo0ol00008ooooo`;o00000oooool6o`0000Kooooo0_l0000Hooooo`;o00000_ooool2o`00
05Oooooo000Looooo`03o`000?oooooooooo04?ooooo1?l0000:ooooo`Co00003Oooool2o`0000?o
oooo0_l00004ooooo`;o00000_ooool3o`0000Cooooo7_l000001?oooooo0000o`000?ooool2o`00
0004ooooool0003o0000o`0001Sooooo0_l00007ooooo`;o00001Oooool2o`0000[ooooo0_l00005
ooooo`;o00003oooool2o`0000;ooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`13oooo
o`Co00003?ooool2o`0001Oooooo0ol00002ooooo`?o00002_oooolDo`0000;ooooo0_l00007oooo
o`;o000000Coooooo`000?l0003o00000_ooool4o`0000?ooooo0_l00008ooooo`Co000000?ooooo
o`000?l000000_l0000@ooooo`;o00000oooool2o`0000Gooooo0_l00004ooooo`Go00003Oooool2
o`0005Cooooo000Looooo`;o0000KOooool2o`0000Kooooo0ol00003ooooo`;o000000?oooooo`00
0?l000005ol00007ooooo`;o000000Coooooo`000?l0003o00000_ooool4o`0000?ooooo0_l00008
ooooo`;o000000?oooooo`000?l000001?l0000:ooooo`Co00000_ooool2o`00013ooooo1Ol0000=
ooooo`;o0000E?ooool001cooooo00?o0000ooooooooool0A_ooool2o`0000Oooooo0_l0000Soooo
o`?o00000ooooolEo`000003ooooool0003o000000Co00001oooool2o`0001[ooooo0_l00003oooo
o`;o00001Oooool9o`0002Gooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`0nooooo`;o
00001_ooool2o`0000Oooooo0_l0000Aooooo`;o00005_oooolFo`0000?ooooo0_l00008ooooo`Co
00007Oooool2o`0000Gooooo1Ol00002ooooo`;o00004Oooool2o`0000Cooooo1?l0001Pooooo`00
7?ooool00ol0003oooooooooo`0nooooo`;o00008_ooool2o`0000;ooooo1?l00004ooooo`Co0000
2?oooolGo`000003ooooool0003o000000;o00000_ooool2o`0000?ooooo1?l00005ooooo`;o0000
5_ooool5o`0000;ooooo0ol0000Gooooo`;o00001?ooool4o`0000Cooooo0_l0001Jooooo`007?oo
ool00ol0003oooooooooo`1Vooooo`Co00001?ooool6o`0000Sooooo4_l000001?oooooo0000o`00
0?ooool4o`0000;ooooo1?l0000:ooooo`;o00005oooool4o`0000?ooooo0_l0000;ooooo`;o0000
3Oooool2o`0000Wooooo1?l0001Hooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00001?oo
ool2o`000003ooooool0003o000000Oooooo0_l00003ooooo`;o000000?oooooo`000?l000002Ooo
ool2o`0000cooooo4?l00007ooooo`Go00002?ooool3o`0002cooooo0_l0000:ooooo`;o000000?o
ooooo`000?l000002oooool4o`0000;ooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`1=
ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000007ooooo`;o00000ooo
ool5o`0000Gooooo0_l00002ooooo`;o00002_ooool4o`000003ooooool0003o000000_o00001ooo
ool4o`0000Sooooo1?l00004ooooo`;o00009_ooool4o`0000Sooooo0_l00005ooooo`;o00002Ooo
ool2o`0000;ooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00002Oooool2
o`0000Wooooo0_l00006ooooo`;o00001oooool2o`0000Gooooo4Ol0000Dooooo`;o000000?ooooo
o`000?l000000oooool2o`0001Gooooo0_l00008ooooo`;o00001Oooool5o`0000kooooo0_l00009
ooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0Boooool2o`0000kooooo0_l000000ooo
oooo0000o`000005ooooo`;o00004?ooool2o`0000?ooooo0_l00003ooooo`So00000_ooool3o`00
00_ooooo0_l0000;ooooo`;o00000oooool2o`0001Gooooo0_l00008ooooo`;o00001Oooool2o`00
0003ooooool0003o000000Cooooo0_l00008ooooo`;o00000_ooool2o`0000Gooooo0_l0001Foooo
o`007?ooool00ol0003oooooooooo`1;ooooo`;o00004Oooool2o`0000Gooooo0_l00003ooooo`;o
00003oooool3o`0000Kooooo0_l000001?oooooo0000o`000?l0000?ooooo`;o00001?ooool2o`00
00[ooooo0_l0000:ooooo`Co00006?ooool3o`0000Cooooo1?l00008ooooo`;o00000_ooool2o`00
01;ooooo0_l00019ooooo`007?ooool00ol0003oooooooooo`1Xooooo`Co00002Oooool2o`0000Co
oooo2Ol000001?oooooo0000o`000?ooool2o`0000_ooooo0_l00002ooooo`;o00001?ooool2o`00
00Kooooo0_l00006ooooo`;o00001_ooool4o`0001Oooooo1?l00004ooooo`Co00002?ooool2o`00
01Kooooo0_l00019ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00008_ooool2o`000004
ooooool0003o0000ooooo`;o00001Oooool2o`0000;ooooo0_l00002ooooo`Oo000000?oooooo`00
0?l000001_ooool3o`0000Gooooo0_l00002ooooo`;o00003?ooool2o`000003ooooool0003o0000
00?ooooo1?l00006ooooo`;o00001Oooool2o`00013ooooo0_l00008ooooo`;o00001_ooool2o`00
06?ooooo000Looooo`03o`000?oooooooooo04Cooooo0_l0000Rooooo`;o000000Coooooo`000?l0
003ooooo0_l00009ooooo`;o00000oooool2o`0000Gooooo0_l00006ooooo`?o00006_ooool2o`00
00Gooooo1?l00004ooooo`;o00001Oooool2o`0000Sooooo0_l0000Hooooo`?o0000H_ooool001co
oooo00?o0000ooooooooool0Goooool2o`0001cooooo0ol000000ooooooo0000o`000002ooooo`;o
00003Oooool2o`0000gooooo0_l0000>ooooo`;o00004Oooool2o`000004ooooool0003o0000o`00
01Wooooo0ol00002ooooo`;o0000GOooool001cooooo00?o0000ooooooooool0G_ooool3o`0000Go
oooo0_l0000=ooooo`;o00001_ooool6o`000004ooooool0003o0000o`0000gooooo0_l00002oooo
o`;o00001?ooool4o`000003ooooool0003o000000?ooooo0_l00008ooooo`;o00004_ooool5o`00
00gooooo0_l00004ooooo`?o00001Oooool2o`0000;ooooo0_l0001Mooooo`007?ooool00ol0003o
ooooooooo`17ooooo`;o00005Oooool2o`0000Kooooo0_l00008ooooo`;o000000?oooooo`000?l0
00000_l00007ooooo`Go000000?oooooo`000?l000003oooool2o`000003ooooool0003o000000Co
oooo1?l00006ooooo`;o00002?ooool4o`0001;ooooo0_l00009ooooo`;o00000oooool2o`0000Co
oooo0ol00005ooooo`;o00001_ooool2o`0005Wooooo000Looooo`;o0000B?ooool2o`0000;ooooo
0_l0000Eooooo`;o00003?ooool2o`000003ooooool0003o000000Cooooo0_l00003ooooo`Go0000
1oooool4o`0000Kooooo1_l0000Gooooo`Go00006?ooool2o`0000?ooooo0_l0000Aooooo`;o0000
1_ooool2o`0005Wooooo000Looooo`03o`000?oooooooooo04_ooooo0_l0000Eooooo`;o00003?oo
ool2o`0000Oooooo0_l00003ooooo`Ko00001Oooool5o`0000Kooooo0_l000000ooooooo0000o`00
0003o`0000Cooooo0ol0000:ooooo`;o00000_ooool2o`000003ooooool0003o000000;o00002?oo
ool2o`0000cooooo0_l000000ooooooo0000o`000002ooooo`;o0000L_ooool001cooooo00?o0000
ooooooooool0L?ooool3o`000003ooooool0003o000000cooooo0_l00004ooooo`?o000000?ooooo
o`000?l000003?ooool2o`0000Cooooo0ol000000ooooooo0000o`000007ooooo`;o00001_ooool3
o`0000Sooooo0_l0000<ooooo`;o000000?oooooo`000?l000000_ooool2o`0007;ooooo000Loooo
o`03o`000?oooooooooo077ooooo0_l000000ooooooo0000o`000009ooooo`;o00001oooool2o`00
00;ooooo0_l00003ooooo`;o00002_ooool2o`0000Gooooo0ol0000>ooooo`?o00001Oooool2o`00
00;ooooo0_l0000;ooooo`;o000000?oooooo`000?l000000ol00002ooooo`;o0000Koooool001co
oooo00?o0000ooooooooool0Ooooool2o`0000Oooooo0_l00007ooooo`;o00002_ooool2o`0000Co
oooo1?l00002ooooo`?o00002Oooool3o`0000Gooooo0_l00002ooooo`;o00001Oooool5o`000003
ooooool0003o000000;ooooo1?l00002ooooo`;o0000Koooool001cooooo00?o0000ooooooooool0
MOooool3o`0000;ooooo0_l0000<ooooo`;o00001?ooool2o`0000Cooooo0_l00005ooooo`?o0000
1Oooool3o`0000;ooooo1?l00003ooooo`;o00001?ooool4o`0000oooooo1Ol000000ooooooo0000
o`000003ooooo`;o00000_ooool2o`00073ooooo000Looooo`03o`000?oooooooooo07Gooooo0ol0
0002ooooo`?o000000?oooooo`000?l000003_ooool3o`0000?ooooo0_l00003ooooo`Go00002_oo
ool2o`0000Gooooo0_l00004ooooo`Go00005?ooool2o`000003ooooool0003o000000;ooooo1?l0
0003ooooo`;o0000Joooool001cooooo00?o0000ooooooooool0L_ooool2o`0000;ooooo0_l00003
ooooo`;o000000?oooooo`000?l000003oooool2o`0000Sooooo0_l0000Jooooo`Go00001oooool2
o`0000Wooooo0_l00003ooooo`;o00000_ooool2o`0000Gooooo0_l0001[ooooo`007?ooool00ol0
003oooooooooo`1Cooooo`;o00007Oooool3o`000003ooooool0003o000000Kooooo0_l00009oooo
o`;o00001?ooool2o`0000_ooooo0_l0000Eooooo`;o00001_ooool2o`0000Cooooo1?l00007oooo
o`;o000000?oooooo`000?l000004_ooool2o`0006Cooooo000Looooo`03o`000?oooooooooo05?o
oooo0_l0000Hooooo`Co000000Coooooo`000?l0003o00002oooool4o`0000Gooooo0_l00004oooo
o`;o00000_ooool2o`0000Oooooo0_l0000Eooooo`;o00001_ooool2o`000004ooooool0003o0000
o`0000;ooooo0_l00004ooooo`;o00001?ooool4o`00013ooooo0_l0001Tooooo`007?ooool00ol0
003oooooooooo`1]ooooo`Co00003_ooool5o`0000oooooo1?l0000@ooooo`;o00000_ooool2o`00
017ooooo0ol00008ooooo`;o00001?ooool4o`00013ooooo0_l0001Tooooo`007?ooool00ol0003o
ooooooooo`1mooooo`Co00004_ooool4o`00013ooooo0_l00002ooooo`;o00000_ooool2o`0000Oo
oooo0_l0000?ooooo`;o0000O_ooool001cooooo00?o0000ooooooooool0Goooool2o`0001Kooooo
0_l000001?oooooo0000o`000?ooool2o`0001Cooooo0_l0000Booooo`?o00000_ooool2o`000003
ooooool0003o000000Oooooo0_l0000Pooooo`?o0000K?ooool001cooooo00?o0000ooooooooool0
Goooool2o`0001Kooooo0_l000000ooooooo0000o`000006ooooo`;o00004oooool2o`0000_ooooo
0ol000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000_ooool2o`0002Gooooo
0ol0001/ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co
8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0Noooool2o`0000Gooooo0_l00005oooo
o`;o00002?ooool2o`0000;ooooo0_l00003ooooo`;o00001_ooool3o`000003ooooool0003o0000
00?o00001_ooool2o`0000cooooo1Ol0000=ooooo`;o000000?oooooo`000?l000000_ooool2o`00
06gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9So
oooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1kooooo`;o00003?ooool2o`0000;ooooo0_l0
0004ooooo`;o00001oooool2o`0000cooooo0ol0000Dooooo`Go00003Oooool2o`000003ooooool0
003o0000077ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo07gooooo0_l0000:ooooo`;o00000_oo
ool2o`0001_ooooo0_l0002Mooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09
ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`0005Kooooo0_l0000Uooooo`Co00002?oo
ool2o`0003gooooo0ol00003ooooo`;o0000NOooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool02Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0E_oo
ool2o`0002Oooooo0_l000000ooooooo0000o`00000=ooooo`;o00005_ooool2o`0000gooooo0_l0
0004ooooo`;o00002?ooool3o`000003ooooool0003o000000;o0000NOooool00003ooooool@413o
oooo00;ooooo00?o410@ooooooooool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o
0000ooooooooool0L_ooool2o`0000[ooooo0_l00002ooooo`;o00000_ooool2o`0000Wooooo0_l0
0002ooooo`;o00002_ooool3o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Cooooo0_l0
000:ooooo`Co0000Noooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zj
oooooonj^[[o000000Kooooo00?o0000ooooooooool0J_ooool2o`0000Kooooo0_l0000:ooooo`;o
00000oooool2o`000003ooooool0003o000000gooooo0_l00008ooooo`Go000000?oooooo`000?l0
00000oooool2o`0000Gooooo0_l00005ooooo`;o00000_ooool2o`0000Kooooo1?l00002ooooo`;o
0000OOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413o
ZJVY00Kooooo00?o0000ooooooooool0J_ooool2o`0000kooooo0_l00007ooooo`Co00006?ooool4
o`0000;ooooo0_l00003ooooo`;o00001_ooool2o`0000?ooooo0_l00003ooooo`Oo000000?ooooo
o`000?l000001?l00005ooooo`;o00000_ooool2o`0007Cooooo000Looooo`03o`000?oooooooooo
06?ooooo0_l0000Eooooo`;o00002Oooool2o`0001kooooo0_l00002ooooo`;o00000oooool2o`00
00;ooooo0_l00003ooooo`;o00001?ooool6o`000003ooooool0003o000000;ooooo0_l00005oooo
o`;o00000_ooool2o`0007Cooooo000Looooo`03o`000?oooooooooo06?ooooo0_l0000Eooooo`;o
00001oooool2o`0000Sooooo0_l00002ooooo`;o00001_ooool2o`0000kooooo0_l00002ooooo`?o
00003_ooool2o`0000gooooo0_l0001jooooo`007?ooool00ol0003oooooooooo`1jooooo`;o0000
1?ooool2o`000003ooooool0003o000000Sooooo0_l00002ooooo`;o00001Oooool4o`0000Sooooo
0_l00007ooooo`;o00002?ooool2o`0001Cooooo0_l0001jooooo`007?ooool00ol0003ooooooooo
o`1gooooo`;o00001oooool2o`0000_ooooo0_l00009ooooo`Co00002?ooool2o`0000_ooooo0_l0
00001?oooooo0000o`000?ooool2o`00093ooooo000Looooo`03o`000?oooooooooo07Cooooo0_l0
00000ooooooo0000o`000007ooooo`;o00002oooool2o`0002;ooooo0_l000001?oooooo0000o`00
0?ooool2o`0000Cooooo0_l0002:ooooo`007?ooool00ol0003oooooooooo`1dooooo`;o00006_oo
ool2o`0000gooooo0_l00005ooooo`Co00003Oooool2o`0000Cooooo0_l0000<ooooo`;o0000O?oo
ool001cooooo00?o0000ooooooooool0T?ooool2o`0000gooooo0_l00005ooooo`Co00008Oooool2
o`0007cooooo000Looooo`03o`000?oooooooooo083ooooo0_l00003ooooo`;o00006?ooool2o`00
00Gooooo0_l0000@ooooo`;o0000Soooool001cooooo00?o0000ooooooooool0P?ooool2o`0000?o
oooo0_l0000`ooooo`?o0000Soooool001cooooo00?o0000ooooooooool0P?ooool2o`0003Gooooo
0_l0002@ooooo`007?ooool00ol0003oooooooooo`34ooooo`;o0000Poooool001cooooo0_l00035
ooooo`;o0000Poooool001cooooo00?o0000ooooooooool0Ooooool2o`0001[ooooo0_l0000Aoooo
o`;o0000VOooool001cooooo00?o0000ooooooooool0Ooooool2o`0001Wooooo0ol0000Aooooo`;o
0000VOooool001cooooo00?o0000ooooooooool0V_ooool2o`000:gooooo000Looooo`03o`000?oo
oooooooo08Wooooo0_l0002nooooo`007?ooool00ol0003oooooooooo`29ooooo`;o00006Oooool2
o`000:?ooooo000Looooo`03o`000?oooooooooo0:Cooooo0_l0002Sooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000:Cooooo0_l0002Toooo
o`007?ooool00ol0003oooooooooo`2Sooooo`;o0000Y?ooool001cooooo00?o0000ooooooooool0
U?ooool2o`000;?ooooo000Looooo`03o`000?oooooooooo09Cooooo0_l0002cooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`004_ooool4o`000003oa0@4?oooooooooo
00?ooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool3o`000?oooooo
B_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3o
oooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000oooooooo
ool0oooooomBooooo`004_ooool00omEEEGoIVIVo`00003ooooooeCooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo002Qooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@oooo
ooooool05_ooool4o`000008oa0@4?oooooooooooiRHV?l@413o0000oc8b<_o<c<`3ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool5o`0008cooooo002Rooooo`05o`000?ooooooooooooooool0
00002Oooool6o`0000cooooo00?o0000ooooooooool00_ooool01Ol@413o^[ZjoooooomgMgOo<S8b
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0S?oo
ool00:;ooooo00Go0000ooooooooooooooooo`00000Kooooo`03o`000?oooooooooo00Kooooo00Go
0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00;ooooo00?oV9RHob4Q8Oo^k^h0
SOooool00:;ooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00003?ooool00ol0003ooooo
ooooo`05ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`03
oiRHV?lQ8B7ok^k^08cooooo002Rooooo`05o`000?n7QhOoooooojVYZOl000006oooool00ol0003o
ooooooooo`04ooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`000006oooo
o`03ogMgMomVIVKooooo08_ooooo002Qooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHoooooooo
ool06Oooool00ol0003oooooooooo`05ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooo
oooooooooa0@4007ooooo`03o`000?oooooooooo08[ooooo0032ooooo`03o`000?oooooooooo00;o
oooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0
1Ol0003o^[ZjoooooonHV9So410@08cooooo0030ooooo`03oeEEEOmVIVKo000000Cooooo00GoZJVY
oa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01OnHV9So410@
o`000?lQ8B7oc<c<08cooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1308) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.4067 .69569 Mdot
.41333 .6813 Mdot
.64415 .48014 Mdot
.37685 .443 Mdot
.77738 .3865 Mdot
.65821 .45097 Mdot
.57326 .629 Mdot
.6291 .64766 Mdot
.62715 .47243 Mdot
.59046 .71648 Mdot
.62521 .62356 Mdot
.32552 .47578 Mdot
.60268 .64824 Mdot
.41202 .44018 Mdot
.75271 .26282 Mdot
.35348 .42417 Mdot
.4112 .69036 Mdot
.53735 .28125 Mdot
.35284 .49021 Mdot
.67613 .48787 Mdot
.3912 .71302 Mdot
.40556 .44593 Mdot
.40069 .62123 Mdot
.41273 .43997 Mdot
.37072 .46841 Mdot
.3842 .6419 Mdot
.44344 .63613 Mdot
.38583 .48986 Mdot
.4069 .49807 Mdot
.63276 .64082 Mdot
.41203 .28586 Mdot
.75787 .29726 Mdot
.46894 .42927 Mdot
.5525 .21295 Mdot
.60434 .66566 Mdot
.28143 .61635 Mdot
.65033 .4602 Mdot
.60436 .62797 Mdot
.60151 .62445 Mdot
.60011 .67102 Mdot
.61672 .62981 Mdot
.4021 .63042 Mdot
.50511 .66309 Mdot
.72384 .44088 Mdot
.38343 .40879 Mdot
.79462 .52852 Mdot
.32289 .719 Mdot
.44315 .44634 Mdot
.38675 .68378 Mdot
.62429 .30833 Mdot
.73153 .53659 Mdot
.57788 .6457 Mdot
.67965 .49101 Mdot
.10868 .54142 Mdot
.58824 .6455 Mdot
.40951 .53072 Mdot
.64469 .46932 Mdot
.41065 .45757 Mdot
.41715 .44038 Mdot
.25401 .47266 Mdot
.42209 .41418 Mdot
.54357 .30428 Mdot
.4076 .59736 Mdot
.54837 .57365 Mdot
.63197 .4641 Mdot
.60986 .61793 Mdot
.4137 .6692 Mdot
.59839 .65346 Mdot
.40001 .55255 Mdot
.68765 .45882 Mdot
.44453 .44584 Mdot
.62074 .6212 Mdot
.43763 .64151 Mdot
.41565 .48568 Mdot
.62711 .38629 Mdot
.8001 .6255 Mdot
.56906 .33388 Mdot
.27188 .58416 Mdot
.24855 .4691 Mdot
.66209 .34325 Mdot
.35518 .473 Mdot
.45756 .32348 Mdot
.79972 .59801 Mdot
.37692 .63405 Mdot
.36259 .40615 Mdot
.5599 .27046 Mdot
.41126 .48496 Mdot
.81863 .51617 Mdot
.45396 .44774 Mdot
.58727 .34299 Mdot
.62058 .47112 Mdot
.3963 .66848 Mdot
.37347 .44412 Mdot
.42664 .48569 Mdot
.25367 .42353 Mdot
.41431 .51422 Mdot
.39184 .46115 Mdot
.37593 .67936 Mdot
.57924 .64619 Mdot
.44582 .49561 Mdot
.71972 .46906 Mdot
.61803 .48339 Mdot
.37481 .42591 Mdot
.62363 .43394 Mdot
.42231 .61156 Mdot
.42746 .48338 Mdot
.59425 .62785 Mdot
.39559 .41868 Mdot
.49521 .79208 Mdot
.42058 .67616 Mdot
.3924 .49598 Mdot
.51561 .3429 Mdot
.20035 .50922 Mdot
.39124 .67633 Mdot
.71913 .48439 Mdot
.37591 .50543 Mdot
.39806 .46862 Mdot
.40859 .68079 Mdot
.60718 .45381 Mdot
.81658 .53341 Mdot
.36759 .66663 Mdot
.62938 .65909 Mdot
.42299 .68983 Mdot
.33535 .49068 Mdot
.6305 .45297 Mdot
.73988 .47679 Mdot
.48342 .76406 Mdot
.44063 .26668 Mdot
.41204 .4821 Mdot
.52455 .68326 Mdot
.63976 .49898 Mdot
.4034 .66067 Mdot
.60402 .65413 Mdot
.40032 .39039 Mdot
.42545 .64448 Mdot
.63048 .62434 Mdot
.51616 .32819 Mdot
.69439 .59004 Mdot
.42501 .62247 Mdot
.53115 .43299 Mdot
.60348 .60749 Mdot
.58177 .6605 Mdot
.44907 .18604 Mdot
.4111 .66778 Mdot
.54116 .3168 Mdot
.61343 .65591 Mdot
.42594 .25388 Mdot
.38944 .40877 Mdot
.41701 .32519 Mdot
.33111 .75117 Mdot
.52893 .20465 Mdot
.71063 .61123 Mdot
.54013 .34571 Mdot
.63899 .62131 Mdot
.3777 .46072 Mdot
.37983 .65318 Mdot
.39115 .6297 Mdot
.41806 .41383 Mdot
.36256 .46222 Mdot
.44769 .44874 Mdot
.44178 .47388 Mdot
.30128 .47139 Mdot
.38156 .5156 Mdot
.27918 .68505 Mdot
.39276 .66669 Mdot
.37744 .44947 Mdot
.67457 .44705 Mdot
.46346 .44414 Mdot
.61912 .62534 Mdot
.40519 .45467 Mdot
.37479 .44509 Mdot
.40582 .40908 Mdot
.57917 .65123 Mdot
.79643 .34224 Mdot
.20132 .55137 Mdot
.76994 .33003 Mdot
.56951 .38596 Mdot
.65464 .43389 Mdot
.40058 .48381 Mdot
.5296 .31222 Mdot
.31931 .59914 Mdot
.38936 .43102 Mdot
.37765 .84317 Mdot
.39559 .45399 Mdot
.78036 .37215 Mdot
.41968 .53332 Mdot
.69528 .26028 Mdot
.44571 .31253 Mdot
.37876 .47309 Mdot
.50458 .63557 Mdot
.6527 .61684 Mdot
.595 .46273 Mdot
.61427 .63361 Mdot
.67657 .45182 Mdot
.64557 .47692 Mdot
.5416 .59768 Mdot
.32158 .44215 Mdot
.47109 .45567 Mdot
.45057 .46818 Mdot
.68415 .43962 Mdot
.40169 .60307 Mdot
.51637 .31422 Mdot
.38556 .69949 Mdot
.86954 .4807 Mdot
.76989 .50908 Mdot
.56025 .64595 Mdot
.54065 .29398 Mdot
.63375 .4884 Mdot
.61522 .45907 Mdot
.52195 .35035 Mdot
.43093 .459 Mdot
.41241 .65878 Mdot
.49677 .1765 Mdot
.54689 .79133 Mdot
.40953 .17191 Mdot
.37712 .678 Mdot
.56617 .71936 Mdot
.62937 .63701 Mdot
.66235 .46872 Mdot
.39576 .46696 Mdot
.42549 .46498 Mdot
.37116 .71153 Mdot
.4471 .45265 Mdot
.43669 .70275 Mdot
.38841 .47221 Mdot
.67549 .55323 Mdot
.55983 .28864 Mdot
.54442 .5941 Mdot
.46817 .25248 Mdot
.37703 .63907 Mdot
.2836 .34711 Mdot
.62372 .43831 Mdot
.31339 .5911 Mdot
.61291 .61467 Mdot
.5253 .30936 Mdot
.62608 .44535 Mdot
.51226 .32963 Mdot
.36957 .51021 Mdot
.67998 .46515 Mdot
.52954 .35625 Mdot
.34839 .36597 Mdot
.41764 .40388 Mdot
.42749 .78822 Mdot
.60843 .66921 Mdot
.37837 .70114 Mdot
.42887 .41766 Mdot
.64624 .42817 Mdot
.43005 .3901 Mdot
.72625 .64916 Mdot
.6925 .53335 Mdot
.62254 .49074 Mdot
.66224 .53653 Mdot
.54014 .30073 Mdot
.75024 .58066 Mdot
.54289 .70625 Mdot
.40558 .69232 Mdot
.40783 .51688 Mdot
.67273 .23941 Mdot
.61233 .65623 Mdot
.41022 .41876 Mdot
.62568 .26105 Mdot
.59718 .65966 Mdot
.41144 .45957 Mdot
.63693 .63279 Mdot
.39238 .6285 Mdot
.21939 .45951 Mdot
.39995 .69064 Mdot
.44625 .47124 Mdot
.58912 .6329 Mdot
.64114 .42307 Mdot
.3865 .64525 Mdot
.43437 .45138 Mdot
.389 .48861 Mdot
.59122 .53233 Mdot
.38389 .45144 Mdot
.79331 .35697 Mdot
.38332 .47319 Mdot
.65941 .47878 Mdot
.3526 .4473 Mdot
.16007 .53713 Mdot
.53564 .61626 Mdot
.41321 .66712 Mdot
.6047 .47 Mdot
.63298 .4724 Mdot
.72358 .42252 Mdot
.57699 .67527 Mdot
.36935 .50183 Mdot
.64855 .43026 Mdot
.31983 .34266 Mdot
.61424 .60824 Mdot
.4624 .46773 Mdot
.52398 .46649 Mdot
.61485 .31096 Mdot
.6775 .49319 Mdot
.44056 .38568 Mdot
.42133 .61523 Mdot
.36906 .44787 Mdot
.61289 .45617 Mdot
.33973 .40501 Mdot
.37766 .49916 Mdot
.38952 .73945 Mdot
.59777 .538 Mdot
.58539 .61793 Mdot
.43035 .52303 Mdot
.42094 .42281 Mdot
.67462 .45528 Mdot
.37635 .64434 Mdot
.61482 .60704 Mdot
.39547 .63339 Mdot
.65563 .24258 Mdot
.44223 .78787 Mdot
.31907 .38373 Mdot
.53006 .29224 Mdot
.60412 .27539 Mdot
.66786 .24446 Mdot
.25176 .3478 Mdot
.31852 .31192 Mdot
.56935 .19937 Mdot
.61337 .44231 Mdot
.62707 .27054 Mdot
.639 .47229 Mdot
.36427 .47528 Mdot
.63207 .45402 Mdot
.66056 .23247 Mdot
.38872 .46986 Mdot
.64014 .45244 Mdot
.26617 .37517 Mdot
.37 .45168 Mdot
.40812 .68806 Mdot
.83901 .44238 Mdot
.18762 .42834 Mdot
.68211 .53941 Mdot
.66673 .48792 Mdot
.35679 .27594 Mdot
.38985 .46032 Mdot
.35223 .45154 Mdot
.38234 .66522 Mdot
.45375 .40117 Mdot
.55543 .31838 Mdot
.54747 .29724 Mdot
.63762 .69494 Mdot
.48332 .37457 Mdot
.41799 .53188 Mdot
.38561 .64998 Mdot
.31665 .50036 Mdot
.61267 .37804 Mdot
.62638 .30105 Mdot
.60359 .59971 Mdot
.83658 .43991 Mdot
.45013 .67037 Mdot
.61088 .57932 Mdot
.59481 .48894 Mdot
.39886 .68272 Mdot
.78588 .324 Mdot
.60994 .63383 Mdot
.43703 .8054 Mdot
.46968 .55618 Mdot
.42869 .45752 Mdot
.59665 .61451 Mdot
.38107 .38809 Mdot
.19388 .41138 Mdot
.5152 .82629 Mdot
.48345 .50182 Mdot
.45491 .44539 Mdot
.59734 .39009 Mdot
.40185 .46002 Mdot
.77557 .60301 Mdot
.3828 .47811 Mdot
.39502 .63778 Mdot
.6086 .71755 Mdot
.62405 .68561 Mdot
.21636 .62472 Mdot
.7578 .59412 Mdot
.54165 .34546 Mdot
.39263 .47294 Mdot
.42891 .45482 Mdot
.55484 .32911 Mdot
.40703 .61688 Mdot
.44915 .46167 Mdot
.28622 .33613 Mdot
.43162 .47843 Mdot
.61306 .62622 Mdot
.44769 .5696 Mdot
.36648 .73284 Mdot
.4297 .49462 Mdot
.42528 .60712 Mdot
.56432 .6398 Mdot
.59062 .63568 Mdot
.40613 .54017 Mdot
.60785 .67233 Mdot
.39525 .44654 Mdot
.54717 .82923 Mdot
.42907 .63023 Mdot
.44588 .71863 Mdot
.41764 .63911 Mdot
.26096 .57313 Mdot
.58711 .65598 Mdot
.70213 .55141 Mdot
.33993 .41526 Mdot
.60752 .63765 Mdot
.35408 .71466 Mdot
.35667 .42565 Mdot
.40685 .39862 Mdot
.45011 .2034 Mdot
.65569 .48833 Mdot
.60076 .54476 Mdot
.63289 .64274 Mdot
.43259 .43765 Mdot
.40803 .50994 Mdot
.56365 .64573 Mdot
.54869 .81223 Mdot
.21552 .41284 Mdot
.38575 .47211 Mdot
.3966 .64772 Mdot
.40421 .65546 Mdot
.43947 .41483 Mdot
.36813 .43484 Mdot
.63658 .44336 Mdot
.62315 .42606 Mdot
.68452 .45909 Mdot
.60773 .54738 Mdot
.69833 .54948 Mdot
.77781 .44423 Mdot
.5993 .67096 Mdot
.54698 .73594 Mdot
.58746 .32655 Mdot
.44651 .48135 Mdot
.65657 .49588 Mdot
.41662 .42387 Mdot
.39011 .44049 Mdot
.56222 .6634 Mdot
.71715 .32833 Mdot
.4208 .70469 Mdot
.39457 .61538 Mdot
.61794 .60305 Mdot
.36879 .54095 Mdot
.56713 .60398 Mdot
.52012 .32302 Mdot
.49082 .20082 Mdot
.61631 .61687 Mdot
.407 .68708 Mdot
.61677 .66356 Mdot
.42741 .47053 Mdot
.36685 .51505 Mdot
.40241 .67866 Mdot
.56 .33364 Mdot
.43913 .39542 Mdot
.40962 .46271 Mdot
.3173 .75275 Mdot
.47285 .21842 Mdot
.66235 .56588 Mdot
.38026 .47175 Mdot
.41692 .50071 Mdot
.53326 .36306 Mdot
.43169 .47609 Mdot
.44382 .43407 Mdot
.2078 .51102 Mdot
.50056 .76739 Mdot
.54924 .2937 Mdot
.55982 .81969 Mdot
.37937 .68099 Mdot
.71622 .26569 Mdot
.66966 .46528 Mdot
.60325 .70469 Mdot
.20098 .44507 Mdot
.68199 .48737 Mdot
.70999 .61847 Mdot
.73953 .28675 Mdot
.61802 .55836 Mdot
.63011 .40799 Mdot
.44648 .65161 Mdot
.4457 .46681 Mdot
.40205 .46765 Mdot
.53701 .30748 Mdot
.41172 .65066 Mdot
.5758 .53349 Mdot
.71548 .73608 Mdot
.40292 .44882 Mdot
.4489 .70303 Mdot
.65161 .75113 Mdot
.61547 .31846 Mdot
.52965 .33179 Mdot
.55841 .30859 Mdot
.39553 .47324 Mdot
.19488 .53263 Mdot
.38357 .64391 Mdot
.43409 .44979 Mdot
.38894 .51702 Mdot
.66324 .48707 Mdot
.42778 .66188 Mdot
.60707 .45898 Mdot
.7248 .55269 Mdot
.77295 .34205 Mdot
.35641 .80056 Mdot
.58567 .64764 Mdot
.75562 .65648 Mdot
.63363 .62006 Mdot
.46324 .3191 Mdot
.65128 .50482 Mdot
.36925 .44142 Mdot
.37884 .6381 Mdot
.42784 .43229 Mdot
.36663 .4384 Mdot
.43067 .45671 Mdot
.42789 .49983 Mdot
.28034 .7641 Mdot
.5339 .35224 Mdot
.33695 .45118 Mdot
.65457 .48078 Mdot
.80192 .56286 Mdot
.79037 .63053 Mdot
.42666 .45093 Mdot
.38944 .48305 Mdot
.42537 .63062 Mdot
.4164 .41507 Mdot
.62906 .61346 Mdot
.36967 .68342 Mdot
.41711 .48924 Mdot
.83893 .47184 Mdot
.39973 .49871 Mdot
.72974 .2886 Mdot
.62161 .65889 Mdot
.50688 .79587 Mdot
.33532 .47579 Mdot
.67195 .54128 Mdot
.60033 .54441 Mdot
.63045 .44425 Mdot
.63739 .6541 Mdot
.64774 .459 Mdot
.68908 .75957 Mdot
.36798 .51959 Mdot
.37513 .46221 Mdot
.43967 .49616 Mdot
.65574 .43411 Mdot
.81691 .49147 Mdot
.76177 .55774 Mdot
.33249 .47708 Mdot
.65683 .4382 Mdot
.41588 .60179 Mdot
.43433 .2273 Mdot
.4116 .63118 Mdot
.51011 .31943 Mdot
.62554 .63135 Mdot
.55981 .32555 Mdot
.61384 .24618 Mdot
.41669 .68023 Mdot
.38762 .70791 Mdot
.66694 .4629 Mdot
.48049 .55417 Mdot
.19244 .33236 Mdot
.47068 .55877 Mdot
.44725 .29047 Mdot
.3852 .6601 Mdot
.41541 .49683 Mdot
.48333 .31673 Mdot
.48446 .58188 Mdot
.6446 .45927 Mdot
.39625 .43243 Mdot
.21816 .45379 Mdot
.63643 .44326 Mdot
.43859 .4997 Mdot
.65295 .48479 Mdot
.6198 .63475 Mdot
.6455 .49522 Mdot
.359 .68554 Mdot
.40308 .4898 Mdot
.23734 .27036 Mdot
.54053 .26823 Mdot
.38565 .46191 Mdot
.61582 .60182 Mdot
.67947 .6699 Mdot
.3874 .4254 Mdot
.51447 .35076 Mdot
.64749 .44479 Mdot
.48528 .52609 Mdot
.38448 .47454 Mdot
.66155 .43934 Mdot
.40868 .69582 Mdot
.64335 .63229 Mdot
.25508 .43718 Mdot
.65324 .55077 Mdot
.38135 .6665 Mdot
.54355 .4073 Mdot
.62118 .67175 Mdot
.41825 .50053 Mdot
.40966 .51533 Mdot
.39956 .64804 Mdot
.36708 .34553 Mdot
.36814 .42674 Mdot
.35525 .47029 Mdot
.66572 .47856 Mdot
.64806 .45497 Mdot
.27928 .38751 Mdot
.61142 .43893 Mdot
.36497 .51367 Mdot
.40001 .64504 Mdot
.37553 .44151 Mdot
.42979 .63938 Mdot
.41386 .41522 Mdot
.31504 .44894 Mdot
.40534 .61692 Mdot
.55688 .59692 Mdot
.39227 .43565 Mdot
.4723 .44321 Mdot
.39929 .41903 Mdot
.44457 .46467 Mdot
.62973 .44923 Mdot
.52455 .32648 Mdot
.40484 .52311 Mdot
.52509 .37182 Mdot
.51351 .32589 Mdot
.64057 .67004 Mdot
.66056 .48841 Mdot
.54703 .32393 Mdot
.66064 .75226 Mdot
.68269 .46666 Mdot
.54802 .31 Mdot
.79102 .62796 Mdot
.59952 .66533 Mdot
.42617 .62027 Mdot
.36795 .45398 Mdot
.61628 .2348 Mdot
.32347 .72304 Mdot
.61009 .42867 Mdot
.38367 .47025 Mdot
.40684 .42049 Mdot
.36907 .65297 Mdot
.70745 .76326 Mdot
.68742 .45833 Mdot
.38492 .50202 Mdot
.41739 .67119 Mdot
.68675 .79717 Mdot
.65389 .47624 Mdot
.54438 .30723 Mdot
.59156 .66631 Mdot
.36997 .72456 Mdot
.48123 .76462 Mdot
.57701 .62437 Mdot
.58558 .46204 Mdot
.72467 .54064 Mdot
.37735 .50708 Mdot
.65515 .49789 Mdot
.41713 .18385 Mdot
.35414 .55206 Mdot
.56437 .57046 Mdot
.3646 .26904 Mdot
.39594 .68021 Mdot
.63179 .61741 Mdot
.53762 .34863 Mdot
.37553 .67298 Mdot
.4137 .6878 Mdot
.56519 .65377 Mdot
.21181 .54737 Mdot
.52194 .47012 Mdot
.60657 .62389 Mdot
.5163 .22605 Mdot
.75453 .40939 Mdot
.659 .49572 Mdot
.55522 .31899 Mdot
.63099 .25432 Mdot
.40007 .63001 Mdot
.83764 .42449 Mdot
.45635 .19678 Mdot
.39188 .4609 Mdot
.54378 .32548 Mdot
.80511 .46977 Mdot
.75571 .7083 Mdot
.593 .65742 Mdot
.63579 .68395 Mdot
.55345 .30903 Mdot
.42771 .41781 Mdot
.42813 .23824 Mdot
.35666 .46758 Mdot
.62706 .63618 Mdot
.26575 .4445 Mdot
.41336 .68638 Mdot
.57296 .65881 Mdot
.48643 .19867 Mdot
.39708 .44579 Mdot
.39153 .43447 Mdot
.48686 .25272 Mdot
.37206 .66043 Mdot
.6308 .4437 Mdot
.38096 .51163 Mdot
.40756 .45982 Mdot
.39644 .52906 Mdot
.43834 .51424 Mdot
.20515 .49091 Mdot
.37113 .48009 Mdot
.77884 .53652 Mdot
.4559 .44526 Mdot
.40209 .43579 Mdot
.42536 .60905 Mdot
.35655 .80733 Mdot
.73915 .54674 Mdot
.40545 .45691 Mdot
.40625 .5013 Mdot
.57746 .66236 Mdot
.49957 .5309 Mdot
.48755 .54035 Mdot
.48988 .51649 Mdot
.33802 .29277 Mdot
.43588 .40774 Mdot
.41612 .65943 Mdot
.52688 .35747 Mdot
.38144 .50407 Mdot
.4172 .66323 Mdot
.39133 .41016 Mdot
.63856 .44108 Mdot
.68259 .465 Mdot
.35033 .54284 Mdot
.54809 .33024 Mdot
.46673 .63459 Mdot
.53968 .73571 Mdot
.67775 .45765 Mdot
.37287 .46372 Mdot
.56026 .66735 Mdot
.61366 .45625 Mdot
.68299 .52791 Mdot
.39076 .35469 Mdot
.37901 .64842 Mdot
.39394 .66925 Mdot
.41356 .32722 Mdot
.7132 .59592 Mdot
.247 .68961 Mdot
.62116 .63442 Mdot
.34485 .48333 Mdot
.53695 .6886 Mdot
.39204 .67209 Mdot
.47721 .31166 Mdot
.54571 .3278 Mdot
.59899 .66084 Mdot
.60158 .40566 Mdot
.42533 .63699 Mdot
.4216 .68342 Mdot
.45149 .4329 Mdot
.41726 .46101 Mdot
.31153 .32051 Mdot
.50715 .36943 Mdot
.57529 .62478 Mdot
.55352 .31384 Mdot
.65135 .50444 Mdot
.37384 .48877 Mdot
.39941 .62007 Mdot
.75196 .41986 Mdot
.38788 .5052 Mdot
.6207 .46019 Mdot
.39687 .67604 Mdot
.54214 .30058 Mdot
.51399 .35404 Mdot
.44154 .46977 Mdot
.28672 .47751 Mdot
.60194 .63249 Mdot
.3999 .68643 Mdot
.56958 .59794 Mdot
.35522 .44702 Mdot
.41456 .46879 Mdot
.44054 .52362 Mdot
.57602 .62355 Mdot
.5953 .75365 Mdot
.51889 .30622 Mdot
.40983 .65708 Mdot
.37722 .48281 Mdot
.55261 .32006 Mdot
.57088 .73333 Mdot
.62759 .49475 Mdot
.64158 .49357 Mdot
.51675 .35761 Mdot
.53604 .32942 Mdot
.51277 .33891 Mdot
.83815 .42384 Mdot
.3681 .64609 Mdot
.44898 .67157 Mdot
.3476 .45321 Mdot
.44355 .30606 Mdot
.35004 .40968 Mdot
.60916 .60641 Mdot
.65152 .48806 Mdot
.37924 .42714 Mdot
.4325 .48757 Mdot
.39502 .54632 Mdot
.4346 .72183 Mdot
.36235 .72805 Mdot
.42387 .67214 Mdot
.35119 .50397 Mdot
.66974 .48177 Mdot
.87491 .48036 Mdot
.51789 .15892 Mdot
.33664 .47991 Mdot
.51885 .46403 Mdot
.39558 .62003 Mdot
.58901 .66958 Mdot
.5199 .25353 Mdot
.60027 .6669 Mdot
.40791 .66103 Mdot
.37165 .48273 Mdot
.54802 .74474 Mdot
.52529 .3649 Mdot
.43937 .4453 Mdot
.62748 .6436 Mdot
.44242 .44238 Mdot
.57504 .62639 Mdot
.66665 .25153 Mdot
.36967 .22954 Mdot
.3953 .45522 Mdot
.34845 .41881 Mdot
.34073 .27494 Mdot
.42706 .44593 Mdot
.50075 .33567 Mdot
.39586 .61959 Mdot
.26031 .41407 Mdot
.37991 .40545 Mdot
.33272 .54913 Mdot
.35344 .45561 Mdot
.24945 .40319 Mdot
.4177 .46819 Mdot
.61097 .32819 Mdot
.39529 .49423 Mdot
.44932 .44422 Mdot
.58499 .64059 Mdot
.57388 .65897 Mdot
.43774 .63382 Mdot
.64005 .42796 Mdot
.75018 .307 Mdot
.41096 .46549 Mdot
.70355 .52517 Mdot
.5399 .76789 Mdot
.53418 .33082 Mdot
.40845 .65357 Mdot
.74493 .73996 Mdot
.63399 .64647 Mdot
.42581 .20777 Mdot
.28535 .37489 Mdot
.48524 .72309 Mdot
.54915 .2592 Mdot
.67142 .70922 Mdot
.53369 .30078 Mdot
.40289 .40963 Mdot
.73868 .37369 Mdot
.60468 .34408 Mdot
.376 .35548 Mdot
.62443 .6715 Mdot
.32394 .57807 Mdot
.72887 .34524 Mdot
.50762 .34417 Mdot
.55521 .30729 Mdot
.57586 .64032 Mdot
.66226 .40947 Mdot
.32224 .4547 Mdot
.54295 .33175 Mdot
.67138 .44105 Mdot
.68165 .47545 Mdot
.68769 .47454 Mdot
.38531 .63766 Mdot
.47544 .18183 Mdot
.55578 .62782 Mdot
.58779 .61693 Mdot
.70112 .44933 Mdot
.39247 .58362 Mdot
.36174 .67097 Mdot
.65968 .46324 Mdot
.61965 .47899 Mdot
.40469 .61428 Mdot
.40608 .53443 Mdot
.36805 .52806 Mdot
.4034 .45273 Mdot
.52673 .31733 Mdot
.42141 .4641 Mdot
.6524 .43866 Mdot
.59234 .6539 Mdot
.62546 .4834 Mdot
.62583 .6016 Mdot
.78081 .46439 Mdot
.43763 .45765 Mdot
.39848 .49122 Mdot
.35225 .76857 Mdot
.42112 .68913 Mdot
.78559 .51206 Mdot
.64384 .55976 Mdot
.64158 .47413 Mdot
.44103 .43038 Mdot
.36966 .68524 Mdot
.51474 .37011 Mdot
.38249 .80002 Mdot
.36882 .43118 Mdot
.40714 .6235 Mdot
.37677 .48891 Mdot
.29516 .45822 Mdot
.16965 .57415 Mdot
.40132 .63566 Mdot
.3294 .7474 Mdot
.40552 .49962 Mdot
.69444 .7138 Mdot
.4615 .46654 Mdot
.35034 .33308 Mdot
.36794 .42698 Mdot
.37819 .68021 Mdot
.40716 .45189 Mdot
.37338 .69077 Mdot
.67569 .46079 Mdot
.58828 .66809 Mdot
.38483 .66811 Mdot
.42133 .50876 Mdot
.28008 .18459 Mdot
.62236 .64225 Mdot
.39458 .46996 Mdot
.58323 .65534 Mdot
.41362 .6468 Mdot
.38666 .68168 Mdot
.75478 .69826 Mdot
.72633 .55554 Mdot
.61855 .63575 Mdot
.37482 .48899 Mdot
.72388 .6696 Mdot
.36213 .45449 Mdot
.33962 .31734 Mdot
.41249 .52871 Mdot
.35101 .44847 Mdot
.79386 .63317 Mdot
.5871 .6162 Mdot
.23399 .6763 Mdot
.78114 .6729 Mdot
.80189 .56792 Mdot
.37933 .71462 Mdot
.50779 .35208 Mdot
.79122 .33153 Mdot
.69809 .55147 Mdot
.65815 .43757 Mdot
.38857 .42261 Mdot
.36042 .63841 Mdot
.59853 .63098 Mdot
.52137 .33089 Mdot
.39532 .45638 Mdot
.62731 .48771 Mdot
.23312 .37897 Mdot
.63618 .61416 Mdot
.40498 .63206 Mdot
.38587 .62083 Mdot
.55215 .84559 Mdot
.3786 .47571 Mdot
.40683 .49034 Mdot
.62646 .63245 Mdot
.63211 .7497 Mdot
.523 .30752 Mdot
.26595 .37 Mdot
.61767 .63752 Mdot
.54881 .5295 Mdot
.41333 .67472 Mdot
.40977 .42077 Mdot
.81766 .43841 Mdot
.64735 .39167 Mdot
.36806 .76107 Mdot
.53012 .31222 Mdot
.34524 .31204 Mdot
.37985 .68228 Mdot
.60796 .65509 Mdot
.68927 .60956 Mdot
.44721 .41372 Mdot
.41636 .42562 Mdot
.35337 .31163 Mdot
.62847 .68236 Mdot
.47641 .51812 Mdot
.36321 .43681 Mdot
.60316 .54948 Mdot
.38027 .42175 Mdot
.41842 .39565 Mdot
.38678 .53137 Mdot
.41254 .47766 Mdot
.40248 .62076 Mdot
.43139 .54706 Mdot
.63984 .43497 Mdot
.456 .63022 Mdot
.54783 .5392 Mdot
.38626 .46618 Mdot
.36127 .48291 Mdot
.33304 .67458 Mdot
.70547 .64411 Mdot
.38758 .66746 Mdot
.37595 .70801 Mdot
.61805 .66869 Mdot
.37826 .53644 Mdot
.63038 .43146 Mdot
.40167 .39206 Mdot
.625 .45469 Mdot
.39899 .62143 Mdot
.64634 .47514 Mdot
.58658 .66388 Mdot
.66919 .49048 Mdot
.69903 .54894 Mdot
.61775 .65564 Mdot
.37824 .65598 Mdot
.41958 .48444 Mdot
.6175 .60182 Mdot
.44769 .25484 Mdot
.52845 .31541 Mdot
.81418 .64198 Mdot
.41619 .49013 Mdot
.4934 .76974 Mdot
.35331 .38533 Mdot
.62198 .48079 Mdot
.17565 .58655 Mdot
.39514 .61582 Mdot
.5579 .30305 Mdot
.37547 .63979 Mdot
.4611 .21134 Mdot
.5325 .32165 Mdot
.81143 .6065 Mdot
.59036 .50557 Mdot
.46458 .22073 Mdot
.39417 .54068 Mdot
.48165 .23818 Mdot
.67246 .498 Mdot
.59665 .63244 Mdot
.69742 .6136 Mdot
.44507 .43731 Mdot
.28207 .29892 Mdot
.40978 .6051 Mdot
.64086 .42886 Mdot
.60065 .65302 Mdot
.61586 .60629 Mdot
.35471 .48592 Mdot
.66048 .3215 Mdot
.42495 .42502 Mdot
.7145 .58137 Mdot
.34198 .29546 Mdot
.39756 .72884 Mdot
.38893 .47197 Mdot
.67497 .45632 Mdot
.37662 .48875 Mdot
.53862 .28677 Mdot
.45323 .17701 Mdot
.44901 .40138 Mdot
.64919 .56554 Mdot
.54304 .2686 Mdot
.40606 .68196 Mdot
.37284 .37121 Mdot
.67852 .55971 Mdot
.37642 .47648 Mdot
.20256 .71081 Mdot
.55051 .31391 Mdot
.73478 .36936 Mdot
.41506 .50588 Mdot
.36648 .50085 Mdot
.52775 .60052 Mdot
.47055 .75536 Mdot
.62391 .38994 Mdot
.42258 .43908 Mdot
.39161 .28265 Mdot
.57788 .62837 Mdot
.41236 .41674 Mdot
.40019 .46926 Mdot
.23518 .59814 Mdot
.62492 .60574 Mdot
.63582 .4771 Mdot
.67757 .49647 Mdot
.60681 .43482 Mdot
.54375 .28639 Mdot
.661 .62226 Mdot
.46889 .30091 Mdot
.20838 .39884 Mdot
.56304 .33414 Mdot
.43353 .48328 Mdot
.49656 .31826 Mdot
.36674 .48079 Mdot
.52696 .34065 Mdot
.62792 .60708 Mdot
.38663 .67189 Mdot
.55567 .70601 Mdot
.68506 .47255 Mdot
.46801 .44544 Mdot
.52622 .30194 Mdot
.37976 .65163 Mdot
.54556 .25215 Mdot
.40869 .67605 Mdot
.60986 .641 Mdot
.60998 .59498 Mdot
.52212 .33587 Mdot
.41658 .64359 Mdot
.6188 .57424 Mdot
.73761 .72483 Mdot
.37883 .52482 Mdot
.648 .70366 Mdot
.38727 .69276 Mdot
.36917 .70245 Mdot
.3757 .68682 Mdot
.44587 .45248 Mdot
.51957 .46303 Mdot
.37456 .41388 Mdot
.5837 .61888 Mdot
.64886 .48411 Mdot
.31436 .29265 Mdot
.7509 .49204 Mdot
.52046 .40638 Mdot
.3463 .4912 Mdot
.39869 .44436 Mdot
.39568 .47293 Mdot
.38286 .40314 Mdot
.69049 .57972 Mdot
.42468 .42882 Mdot
.58467 .639 Mdot
.64688 .44276 Mdot
.40289 .4093 Mdot
.69255 .49239 Mdot
.79615 .56267 Mdot
.55915 .3419 Mdot
.66146 .6559 Mdot
.52947 .14543 Mdot
.38054 .65699 Mdot
.60589 .47144 Mdot
.66453 .44302 Mdot
.51702 .32587 Mdot
.60642 .6279 Mdot
.41057 .67215 Mdot
.32672 .33389 Mdot
.51344 .32973 Mdot
.40725 .45494 Mdot
.51024 .45636 Mdot
.31253 .26807 Mdot
.40186 .41089 Mdot
.38106 .43154 Mdot
.67345 .50643 Mdot
.72027 .35209 Mdot
.29548 .22942 Mdot
.48528 .28118 Mdot
.52298 .33049 Mdot
.5466 .34957 Mdot
.41779 .61648 Mdot
.35977 .4213 Mdot
.57936 .62172 Mdot
.4545 .55336 Mdot
.66994 .65411 Mdot
.46108 .59865 Mdot
.41214 .76098 Mdot
.37687 .42592 Mdot
.57656 .80455 Mdot
.39441 .44475 Mdot
.36767 .6482 Mdot
.39676 .62531 Mdot
.38995 .65045 Mdot
.59713 .63336 Mdot
.28714 .60016 Mdot
.58917 .63072 Mdot
.51199 .13739 Mdot
.38721 .68699 Mdot
.59689 .51978 Mdot
.66745 .47026 Mdot
.33731 .48924 Mdot
.54675 .30371 Mdot
.63386 .59462 Mdot
.39926 .55236 Mdot
.18665 .55299 Mdot
.64234 .43067 Mdot
.37799 .6599 Mdot
.66261 .71357 Mdot
.59758 .19198 Mdot
.49101 .525 Mdot
.37661 .54815 Mdot
.52507 .25088 Mdot
.53276 .33488 Mdot
.36791 .76187 Mdot
.55303 .31045 Mdot
.62737 .64542 Mdot
.39572 .4891 Mdot
.41101 .48451 Mdot
.38297 .41988 Mdot
.43315 .45318 Mdot
.60653 .67503 Mdot
.40684 .51839 Mdot
.16008 .537 Mdot
.68188 .45889 Mdot
.33784 .37052 Mdot
.548 .30716 Mdot
.63875 .65613 Mdot
.64804 .44185 Mdot
.7045 .63985 Mdot
.46542 .25724 Mdot
.38556 .47354 Mdot
.38196 .42527 Mdot
.41495 .20773 Mdot
.36196 .43833 Mdot
.32819 .43618 Mdot
.66013 .43843 Mdot
.49733 .38913 Mdot
.56038 .33636 Mdot
.55064 .34585 Mdot
.61593 .65879 Mdot
.40092 .62212 Mdot
.54612 .31358 Mdot
.66758 .47463 Mdot
.34772 .49389 Mdot
.39968 .51601 Mdot
.38649 .692 Mdot
.43135 .18984 Mdot
.51494 .31365 Mdot
.7148 .68286 Mdot
.37932 .63975 Mdot
.43907 .66425 Mdot
.41534 .42541 Mdot
.39845 .7486 Mdot
.35866 .69991 Mdot
.56353 .31125 Mdot
.63771 .657 Mdot
.50429 .25386 Mdot
.62977 .62508 Mdot
.40772 .63128 Mdot
.37774 .50009 Mdot
.38768 .63094 Mdot
.38063 .47342 Mdot
.6464 .19778 Mdot
.41527 .47996 Mdot
.19974 .40782 Mdot
.39718 .32338 Mdot
.66152 .4525 Mdot
.69575 .66798 Mdot
.66907 .46448 Mdot
.37549 .64761 Mdot
.37838 .50548 Mdot
.54001 .29532 Mdot
.78633 .60756 Mdot
.3882 .59547 Mdot
.61787 .46674 Mdot
.66793 .4278 Mdot
.63423 .63043 Mdot
.37268 .42251 Mdot
.41901 .42649 Mdot
.64214 .45269 Mdot
.40152 .72928 Mdot
.42362 .64019 Mdot
.38844 .48538 Mdot
.40206 .44019 Mdot
.66277 .45534 Mdot
.72334 .73812 Mdot
.38413 .58122 Mdot
.40057 .48468 Mdot
.74414 .45703 Mdot
.6043 .60808 Mdot
.35424 .51092 Mdot
.3457 .41998 Mdot
.53832 .32997 Mdot
.23837 .48068 Mdot
.49688 .18501 Mdot
.63147 .60962 Mdot
.67039 .44531 Mdot
.3781 .47932 Mdot
.67482 .45487 Mdot
.40104 .51723 Mdot
.46668 .74853 Mdot
.63637 .49832 Mdot
.35426 .47064 Mdot
.42085 .52694 Mdot
.37164 .66106 Mdot
.37849 .42595 Mdot
.32266 .6725 Mdot
.61898 .44892 Mdot
.35879 .49147 Mdot
.28287 .47368 Mdot
.60992 .62054 Mdot
.39359 .5421 Mdot
.52003 .35059 Mdot
.3221 .3367 Mdot
.51751 .73743 Mdot
.69972 .30817 Mdot
.54784 .35095 Mdot
.44011 .43949 Mdot
.66068 .42637 Mdot
.57257 .63281 Mdot
.18802 .43335 Mdot
.42487 .41801 Mdot
.62685 .63811 Mdot
.59397 .65494 Mdot
.52076 .32244 Mdot
.37559 .81268 Mdot
.42438 .501 Mdot
.42587 .45293 Mdot
.27042 .63967 Mdot
.41316 .69524 Mdot
.42141 .47253 Mdot
.42542 .49 Mdot
.5832 .64015 Mdot
.33204 .49903 Mdot
.33914 .59935 Mdot
.2575 .38511 Mdot
.56664 .63225 Mdot
.4833 .60581 Mdot
.66994 .49409 Mdot
.55243 .32949 Mdot
.40235 .67409 Mdot
.53085 .29854 Mdot
.65804 .4927 Mdot
.42486 .48831 Mdot
.62068 .66384 Mdot
.30308 .68158 Mdot
.57571 .6414 Mdot
.66708 .28357 Mdot
.39812 .69639 Mdot
.52964 .66727 Mdot
.24627 .75266 Mdot
.75639 .61443 Mdot
.5541 .66524 Mdot
.53441 .33039 Mdot
.68919 .41296 Mdot
.4003 .44116 Mdot
.36567 .76501 Mdot
.43523 .47773 Mdot
.27821 .46811 Mdot
.67853 .4506 Mdot
.68455 .45841 Mdot
.39715 .48708 Mdot
.33765 .30252 Mdot
.57196 .63435 Mdot
.61047 .60885 Mdot
.35276 .47311 Mdot
.60814 .63741 Mdot
.41841 .45663 Mdot
.64152 .44134 Mdot
.23782 .69372 Mdot
.39977 .45601 Mdot
.38779 .39945 Mdot
.47673 .74423 Mdot
.79379 .64483 Mdot
.60782 .26831 Mdot
.61778 .81556 Mdot
.57261 .18251 Mdot
.60665 .63836 Mdot
.3559 .43087 Mdot
.48269 .60784 Mdot
.68245 .49579 Mdot
.61542 .57897 Mdot
.4273 .47813 Mdot
.43343 .47512 Mdot
.45035 .44429 Mdot
.38708 .43528 Mdot
.39978 .79106 Mdot
.42739 .56627 Mdot
.25417 .52566 Mdot
.36952 .43478 Mdot
.46522 .23968 Mdot
.62305 .65539 Mdot
.37293 .72243 Mdot
.56481 .33399 Mdot
.37788 .42546 Mdot
.44474 .61132 Mdot
.58223 .66871 Mdot
.50704 .13469 Mdot
.62872 .64696 Mdot
.63298 .47173 Mdot
.57827 .65866 Mdot
.38368 .45282 Mdot
.40388 .65524 Mdot
.50814 .57255 Mdot
.75031 .57448 Mdot
.65669 .43665 Mdot
.38559 .46239 Mdot
.61601 .54028 Mdot
.64252 .43318 Mdot
.80204 .55119 Mdot
.40166 .66456 Mdot
.39672 .28284 Mdot
.39162 .62723 Mdot
.35576 .48202 Mdot
.35857 .48631 Mdot
.55808 .63698 Mdot
.58295 .66285 Mdot
.39352 .62583 Mdot
.39109 .82978 Mdot
.51135 .33131 Mdot
.3905 .64576 Mdot
.45425 .41954 Mdot
.52324 .50042 Mdot
.40058 .65387 Mdot
.55401 .27587 Mdot
.58785 .64935 Mdot
.43632 .64567 Mdot
.45772 .45107 Mdot
.51622 .21987 Mdot
.5268 .3589 Mdot
.65793 .50757 Mdot
.49492 .29734 Mdot
.61567 .45158 Mdot
.63691 .65595 Mdot
.66891 .46248 Mdot
.58008 .6275 Mdot
.52431 .7558 Mdot
.46019 .64953 Mdot
.56211 .67628 Mdot
.6277 .66525 Mdot
.66641 .46262 Mdot
.38871 .49068 Mdot
.54547 .26583 Mdot
.3438 .45498 Mdot
.4375 .49347 Mdot
.58913 .61909 Mdot
.37604 .67234 Mdot
.36452 .70601 Mdot
.43591 .23752 Mdot
.41069 .62098 Mdot
.62022 .4621 Mdot
.17362 .53103 Mdot
.71914 .5096 Mdot
.62204 .61792 Mdot
.58325 .66566 Mdot
.35758 .46625 Mdot
.64688 .45914 Mdot
.66706 .43975 Mdot
.63319 .6315 Mdot
.4619 .70127 Mdot
.35277 .41886 Mdot
.36417 .6937 Mdot
.41854 .68897 Mdot
.40049 .63937 Mdot
.37602 .68941 Mdot
.35811 .59564 Mdot
.59689 .66233 Mdot
.37438 .66706 Mdot
.35588 .46066 Mdot
.43097 .47617 Mdot
.47155 .56643 Mdot
.54257 .35026 Mdot
.40721 .40792 Mdot
.38832 .53313 Mdot
.40827 .42175 Mdot
.64253 .49546 Mdot
.47335 .40521 Mdot
.62941 .49307 Mdot
.66633 .43186 Mdot
.66856 .43624 Mdot
.69734 .55083 Mdot
.3979 .22964 Mdot
.59239 .20942 Mdot
.38658 .50271 Mdot
.62936 .76454 Mdot
.65244 .46875 Mdot
.18081 .56594 Mdot
.59895 .75326 Mdot
.43465 .42468 Mdot
.64484 .38622 Mdot
.64661 .45184 Mdot
.39872 .61588 Mdot
.42313 .47933 Mdot
.60499 .44583 Mdot
.51999 .35252 Mdot
.34865 .47541 Mdot
.63519 .49873 Mdot
.41622 .64745 Mdot
.56312 .30489 Mdot
.43134 .67099 Mdot
.67154 .43845 Mdot
.41389 .5351 Mdot
.13557 .42553 Mdot
.65402 .41985 Mdot
.69541 .73161 Mdot
.31133 .44225 Mdot
.38852 .48768 Mdot
.60781 .46676 Mdot
.42586 .68837 Mdot
.63906 .64901 Mdot
.56381 .47748 Mdot
.43364 .65002 Mdot
.68475 .45897 Mdot
.6147 .46547 Mdot
.65813 .43696 Mdot
.42289 .67597 Mdot
.43134 .40843 Mdot
.4309 .64886 Mdot
.57661 .65499 Mdot
.36669 .45188 Mdot
.66999 .2463 Mdot
.61593 .76687 Mdot
.38415 .63212 Mdot
.63513 .48076 Mdot
.52988 .36403 Mdot
.3937 .45031 Mdot
.61469 .77208 Mdot
.38378 .4902 Mdot
.58702 .61865 Mdot
.21263 .50248 Mdot
.32038 .70137 Mdot
.35069 .4467 Mdot
.35808 .46378 Mdot
.60811 .60999 Mdot
.39058 .46182 Mdot
.36913 .42578 Mdot
.69964 .55452 Mdot
.42655 .66163 Mdot
.40636 .44832 Mdot
.65782 .48308 Mdot
.72681 .52966 Mdot
.36094 .41259 Mdot
.72617 .46565 Mdot
.38169 .29453 Mdot
.21166 .5182 Mdot
.43435 .479 Mdot
.50183 .46029 Mdot
.39804 .43105 Mdot
.439 .449 Mdot
.36301 .4731 Mdot
.45214 .819 Mdot
.64226 .50047 Mdot
.66305 .44515 Mdot
.53961 .35608 Mdot
.38455 .29241 Mdot
.54219 .32768 Mdot
.58734 .65127 Mdot
.67968 .33886 Mdot
.63082 .49415 Mdot
.4137 .63526 Mdot
.43654 .43935 Mdot
.65317 .41994 Mdot
.4135 .42146 Mdot
.38212 .45435 Mdot
.62351 .43408 Mdot
.66452 .49886 Mdot
.72592 .34683 Mdot
.53331 .35555 Mdot
.38889 .6567 Mdot
.37585 .41668 Mdot
.51971 .30888 Mdot
.42934 .49168 Mdot
.44483 .30766 Mdot
.39132 .65357 Mdot
.42856 .65642 Mdot
.36177 .70292 Mdot
.42214 .48943 Mdot
.38799 .45297 Mdot
.58907 .62932 Mdot
.38148 .63222 Mdot
.61291 .62193 Mdot
.57787 .52525 Mdot
.71372 .40786 Mdot
.42754 .47805 Mdot
.62702 .71816 Mdot
.54397 .34055 Mdot
.62235 .47366 Mdot
.32183 .26679 Mdot
.53865 .35676 Mdot
.38152 .476 Mdot
.65003 .42793 Mdot
.52871 .34477 Mdot
.30567 .38114 Mdot
.47788 .15709 Mdot
.54185 .3601 Mdot
.35587 .45977 Mdot
.34883 .52198 Mdot
.60489 .82212 Mdot
.54884 .35265 Mdot
.59535 .6676 Mdot
.42093 .48966 Mdot
.37043 .62706 Mdot
.53136 .29743 Mdot
.77589 .54378 Mdot
.64764 .44621 Mdot
.51323 .20827 Mdot
.44185 .5296 Mdot
.33706 .7398 Mdot
.55095 .34087 Mdot
.40966 .667 Mdot
.34055 .40479 Mdot
.41067 .42625 Mdot
.54502 .35486 Mdot
.56597 .66899 Mdot
.63318 .45127 Mdot
.73485 .54832 Mdot
.42294 .67665 Mdot
.54623 .63501 Mdot
.63856 .48546 Mdot
.72135 .67632 Mdot
.23601 .42348 Mdot
.36497 .52435 Mdot
.58603 .82164 Mdot
.66431 .6117 Mdot
.44829 .43004 Mdot
.52721 .36878 Mdot
.62487 .60247 Mdot
.62092 .6653 Mdot
.6136 .64147 Mdot
.53492 .76392 Mdot
.49148 .51421 Mdot
.60565 .47497 Mdot
.57627 .60416 Mdot
.55164 .32931 Mdot
.49685 .25078 Mdot
.43114 .5032 Mdot
.3996 .44609 Mdot
.36147 .43031 Mdot
.38554 .4205 Mdot
.40714 .43173 Mdot
.61116 .62952 Mdot
.50956 .75789 Mdot
.48043 .54046 Mdot
.39621 .65212 Mdot
.70159 .33477 Mdot
.66441 .47191 Mdot
.60558 .47864 Mdot
.52592 .34843 Mdot
.76893 .61116 Mdot
.69244 .4933 Mdot
.64465 .4757 Mdot
.43234 .41511 Mdot
.42623 .63973 Mdot
.32808 .46134 Mdot
.35699 .46213 Mdot
.62201 .46067 Mdot
.54268 .57252 Mdot
.33821 .63115 Mdot
.43853 .36412 Mdot
.56208 .35639 Mdot
.5099 .49596 Mdot
.53005 .36143 Mdot
.38327 .50864 Mdot
.17856 .58604 Mdot
.65742 .49338 Mdot
.63635 .46465 Mdot
.54554 .34399 Mdot
.38654 .751 Mdot
.39828 .67989 Mdot
.6185 .71062 Mdot
.58005 .64894 Mdot
.37 .49714 Mdot
.24545 .36611 Mdot
.33841 .38087 Mdot
.65143 .32326 Mdot
.61929 .63964 Mdot
.67499 .46105 Mdot
.34322 .4769 Mdot
.35923 .45206 Mdot
.54122 .34328 Mdot
.76017 .36515 Mdot
.36463 .51607 Mdot
.8296 .5208 Mdot
.37009 .22887 Mdot
.46407 .20171 Mdot
.41675 .42592 Mdot
.42635 .66473 Mdot
.66612 .50638 Mdot
.55563 .3214 Mdot
.46126 .43078 Mdot
.51691 .16832 Mdot
.39121 .6917 Mdot
.61723 .65294 Mdot
.53094 .55824 Mdot
.50039 .2623 Mdot
.44531 .46877 Mdot
.43072 .4808 Mdot
.44232 .45613 Mdot
.41354 .15852 Mdot
.63887 .49655 Mdot
.39213 .62195 Mdot
.52017 .32663 Mdot
.41245 .62483 Mdot
.66678 .45316 Mdot
.53681 .64126 Mdot
.39 .49393 Mdot
.39433 .69317 Mdot
.40863 .66859 Mdot
.63132 .64254 Mdot
.64293 .63645 Mdot
.55364 .54166 Mdot
.4154 .47846 Mdot
.66403 .42335 Mdot
.37279 .66461 Mdot
.509 .46319 Mdot
.53406 .32199 Mdot
.5852 .64656 Mdot
.37385 .4305 Mdot
.65118 .49911 Mdot
.44374 .49566 Mdot
.39197 .66862 Mdot
.64499 .47515 Mdot
.74847 .41937 Mdot
.55641 .34412 Mdot
.43071 .46684 Mdot
.51896 .29169 Mdot
.6683 .44291 Mdot
.39921 .43957 Mdot
.73329 .67891 Mdot
.55267 .27617 Mdot
.76307 .55011 Mdot
.66052 .43221 Mdot
.68225 .53766 Mdot
.42186 .6202 Mdot
.54522 .7771 Mdot
.63334 .46723 Mdot
.69827 .69635 Mdot
.7632 .41055 Mdot
.3431 .48436 Mdot
.39841 .63114 Mdot
.65613 .59747 Mdot
.70701 .25337 Mdot
.68595 .7563 Mdot
.39586 .46993 Mdot
.6111 .43981 Mdot
.53603 .34464 Mdot
.61914 .61504 Mdot
.73011 .44351 Mdot
.56671 .29874 Mdot
.68721 .45188 Mdot
.3637 .47373 Mdot
.41289 .65685 Mdot
.59029 .64289 Mdot
.52106 .74221 Mdot
.66515 .47817 Mdot
.64636 .48508 Mdot
.34314 .47115 Mdot
.54624 .32826 Mdot
.58035 .78461 Mdot
.6455 .43842 Mdot
.38982 .22144 Mdot
.61987 .41163 Mdot
.51397 .32078 Mdot
.39066 .42984 Mdot
.43704 .23282 Mdot
.37312 .41041 Mdot
.75273 .68028 Mdot
.66451 .46777 Mdot
.39179 .66214 Mdot
.44821 .45113 Mdot
.27271 .37915 Mdot
.62112 .4647 Mdot
.51674 .4713 Mdot
.6096 .30885 Mdot
.59087 .65755 Mdot
.31796 .26951 Mdot
.42387 .46485 Mdot
.57254 .63381 Mdot
.54145 .34091 Mdot
.40652 .4818 Mdot
.38681 .45058 Mdot
.36844 .65837 Mdot
.6316 .63762 Mdot
.74433 .363 Mdot
.57578 .66198 Mdot
.61921 .66179 Mdot
.36641 .67895 Mdot
.4166 .44552 Mdot
.63344 .47333 Mdot
.64525 .45317 Mdot
.46024 .46357 Mdot
.20684 .66995 Mdot
.39927 .68294 Mdot
.66561 .5094 Mdot
.39928 .16362 Mdot
.45643 .48695 Mdot
.30403 .28599 Mdot
.7663 .37393 Mdot
.58647 .61507 Mdot
.35541 .45763 Mdot
.415 .64564 Mdot
.58923 .40177 Mdot
.64265 .48331 Mdot
.45456 .45121 Mdot
.59236 .6439 Mdot
.52269 .35595 Mdot
.62766 .44098 Mdot
.66023 .32324 Mdot
.4365 .45512 Mdot
.63251 .38373 Mdot
.61001 .44922 Mdot
.80205 .34948 Mdot
.69811 .63893 Mdot
.39477 .63339 Mdot
.37979 .45285 Mdot
.39706 .6147 Mdot
.51936 .33109 Mdot
.53373 .55518 Mdot
.59101 .64922 Mdot
.44826 .53806 Mdot
.14946 .52474 Mdot
.65969 .43736 Mdot
.39194 .62102 Mdot
.34885 .4511 Mdot
.45977 .74669 Mdot
.42262 .45874 Mdot
.3513 .52942 Mdot
.49599 .31075 Mdot
.60017 .61522 Mdot
.57681 .63237 Mdot
.38921 .43965 Mdot
.51875 .31751 Mdot
.66634 .47401 Mdot
.62695 .45729 Mdot
.8617 .47082 Mdot
.51231 .64093 Mdot
.30918 .32546 Mdot
.43383 .47276 Mdot
.68431 .44564 Mdot
.74435 .50411 Mdot
.62603 .63282 Mdot
.46444 .45886 Mdot
.63189 .43117 Mdot
.5722 .27442 Mdot
.32203 .34812 Mdot
.40496 .42852 Mdot
.41347 .39766 Mdot
.58206 .65428 Mdot
.49061 .50141 Mdot
.67986 .46495 Mdot
.41953 .52185 Mdot
.56584 .68432 Mdot
.31587 .36405 Mdot
.42133 .18156 Mdot
.3887 .65646 Mdot
.64487 .30503 Mdot
.61075 .62891 Mdot
.40088 .39608 Mdot
.53444 .30212 Mdot
.67914 .5019 Mdot
.64624 .49984 Mdot
.37192 .47589 Mdot
.36823 .50779 Mdot
.34005 .26764 Mdot
.41854 .63272 Mdot
.61995 .65754 Mdot
.41019 .4887 Mdot
.57894 .7175 Mdot
.37915 .42188 Mdot
.59393 .62432 Mdot
.12504 .43804 Mdot
.34585 .45137 Mdot
.4239 .45442 Mdot
.59818 .77554 Mdot
.43035 .66667 Mdot
.38536 .62439 Mdot
.25918 .32723 Mdot
.43368 .47233 Mdot
.34726 .24936 Mdot
.38644 .66191 Mdot
.39516 .6786 Mdot
.71048 .56218 Mdot
.39639 .45005 Mdot
.47802 .48554 Mdot
.58262 .62068 Mdot
.61385 .66582 Mdot
.43018 .65948 Mdot
.35644 .51199 Mdot
.6356 .6179 Mdot
.47679 .81126 Mdot
.64869 .45968 Mdot
.18453 .60858 Mdot
.39742 .6861 Mdot
.6486 .66959 Mdot
.62364 .63555 Mdot
.5182 .14094 Mdot
.58357 .46464 Mdot
.39136 .49172 Mdot
.43438 .46569 Mdot
.54852 .3371 Mdot
.36179 .42738 Mdot
.68414 .45741 Mdot
.60883 .63704 Mdot
.28057 .4388 Mdot
.3896 .65001 Mdot
.41647 .47002 Mdot
.78247 .59094 Mdot
.7952 .51179 Mdot
.64384 .29294 Mdot
.40571 .68104 Mdot
.38797 .63503 Mdot
.67411 .47679 Mdot
.61175 .43974 Mdot
.41693 .43534 Mdot
.62015 .60999 Mdot
.38197 .63213 Mdot
.59282 .62113 Mdot
.6555 .49351 Mdot
.63742 .47484 Mdot
.65695 .5029 Mdot
.42286 .51088 Mdot
.65033 .48004 Mdot
.73606 .41993 Mdot
.55011 .62957 Mdot
.36242 .67239 Mdot
.3316 .23429 Mdot
.52864 .74416 Mdot
.34972 .69376 Mdot
.52912 .29706 Mdot
.66526 .44 Mdot
.57326 .65105 Mdot
.37416 .44137 Mdot
.39703 .42022 Mdot
.69625 .5213 Mdot
.56795 .64328 Mdot
.52054 .33153 Mdot
.57399 .63631 Mdot
.52049 .32274 Mdot
.60867 .36024 Mdot
.38159 .41699 Mdot
.3947 .51678 Mdot
.61397 .63218 Mdot
.64838 .47783 Mdot
.65567 .44388 Mdot
.54931 .35542 Mdot
.56339 .56964 Mdot
.64165 .43279 Mdot
.39148 .68019 Mdot
.36089 .60537 Mdot
.6144 .46817 Mdot
.42264 .4772 Mdot
.46877 .30593 Mdot
.35989 .76767 Mdot
.38354 .40289 Mdot
.70588 .55914 Mdot
.29491 .69431 Mdot
.44104 .43521 Mdot
.34424 .76629 Mdot
.65009 .55346 Mdot
.42257 .62322 Mdot
.67943 .45488 Mdot
.70374 .48243 Mdot
.44834 .39193 Mdot
.56747 .3348 Mdot
.46266 .44359 Mdot
.40153 .68915 Mdot
.41191 .60239 Mdot
.47689 .21177 Mdot
.71558 .7184 Mdot
.53262 .34404 Mdot
.5319 .34869 Mdot
.63103 .46615 Mdot
.81178 .6556 Mdot
.38418 .54779 Mdot
.52182 .33229 Mdot
.4617 .66247 Mdot
.36593 .47429 Mdot
.37181 .31562 Mdot
.55478 .39102 Mdot
.42748 .66601 Mdot
.46389 .23465 Mdot
.62669 .47101 Mdot
.41194 .62059 Mdot
.55896 .71252 Mdot
.41128 .4061 Mdot
.39148 .65186 Mdot
.59003 .62455 Mdot
.71726 .62144 Mdot
.38502 .67903 Mdot
.45911 .30545 Mdot
.63249 .6216 Mdot
.50998 .46843 Mdot
.4154 .25399 Mdot
.49716 .90284 Mdot
.60848 .63264 Mdot
.61614 .46779 Mdot
.64423 .45277 Mdot
.62676 .45849 Mdot
.41584 .62678 Mdot
.66783 .44066 Mdot
.416 .63167 Mdot
.62526 .79364 Mdot
.40696 .75958 Mdot
.52301 .33251 Mdot
.73595 .55162 Mdot
.41005 .64356 Mdot
.17455 .56023 Mdot
.17575 .65553 Mdot
.35476 .45878 Mdot
.59091 .67215 Mdot
.52547 .33628 Mdot
.82813 .53214 Mdot
.53718 .33362 Mdot
.43405 .21566 Mdot
.1979 .54201 Mdot
.41491 .46263 Mdot
.31345 .60239 Mdot
.55913 .31515 Mdot
.41326 .67646 Mdot
.39797 .4409 Mdot
.56362 .43735 Mdot
.54053 .33469 Mdot
.51514 .34307 Mdot
.41163 .44021 Mdot
.37787 .65969 Mdot
.62899 .47677 Mdot
.59365 .66956 Mdot
.54538 .29341 Mdot
.3188 .45376 Mdot
.3983 .40095 Mdot
.38049 .4919 Mdot
.47755 .56306 Mdot
.50731 .36535 Mdot
.60574 .63848 Mdot
.41277 .81617 Mdot
.64699 .42507 Mdot
.56828 .43961 Mdot
.40002 .20933 Mdot
.68353 .55749 Mdot
.66289 .46623 Mdot
.67331 .45423 Mdot
.40995 .43082 Mdot
.52558 .38351 Mdot
.19507 .55736 Mdot
.59259 .56305 Mdot
.653 .5052 Mdot
.62956 .45355 Mdot
.40411 .60907 Mdot
.45951 .20787 Mdot
.45907 .42448 Mdot
.63168 .60929 Mdot
.65201 .50076 Mdot
.4518 .7668 Mdot
.54872 .32746 Mdot
.19017 .52679 Mdot
.38714 .41395 Mdot
.39662 .49128 Mdot
.59978 .64934 Mdot
.58867 .63243 Mdot
.5839 .40226 Mdot
.45014 .20977 Mdot
.30398 .70092 Mdot
.50002 .74042 Mdot
.21999 .53166 Mdot
.40538 .60537 Mdot
.38367 .63278 Mdot
.75778 .58606 Mdot
.57895 .66544 Mdot
.44495 .44163 Mdot
.39885 .62251 Mdot
.57176 .45257 Mdot
.37217 .60178 Mdot
.33734 .31517 Mdot
.31191 .28941 Mdot
.38166 .47073 Mdot
.42536 .65374 Mdot
.4279 .67247 Mdot
.39902 .70301 Mdot
.63652 .55512 Mdot
.42291 .43954 Mdot
.38807 .47042 Mdot
.43198 .42901 Mdot
.44144 .73468 Mdot
.43209 .44097 Mdot
.53485 .77614 Mdot
.53794 .538 Mdot
.24578 .46814 Mdot
.40857 .52861 Mdot
.59213 .60914 Mdot
.44049 .47593 Mdot
.51823 .31948 Mdot
.3607 .47737 Mdot
.33334 .31937 Mdot
.62434 .64426 Mdot
.38359 .5836 Mdot
.52909 .75289 Mdot
.44754 .43435 Mdot
.55994 .30248 Mdot
.66872 .67078 Mdot
.65591 .23458 Mdot
.51997 .2838 Mdot
.39255 .68163 Mdot
.65411 .46245 Mdot
.57188 .64925 Mdot
.63845 .47118 Mdot
.40384 .5218 Mdot
.75497 .60056 Mdot
.80748 .48902 Mdot
.58487 .53286 Mdot
.38514 .42139 Mdot
.46277 .49819 Mdot
.39179 .67545 Mdot
.64536 .42613 Mdot
.35422 .6908 Mdot
.44661 .4556 Mdot
.52675 .31644 Mdot
.54291 .33789 Mdot
.56705 .48269 Mdot
.78779 .36909 Mdot
.45829 .79185 Mdot
.6001 .64675 Mdot
.63922 .44128 Mdot
.55054 .30586 Mdot
.67584 .72437 Mdot
.64378 .63285 Mdot
.60087 .61065 Mdot
.62341 .64972 Mdot
.41157 .4976 Mdot
.63757 .49914 Mdot
.248 .46528 Mdot
.68584 .45359 Mdot
.38837 .46058 Mdot
.63898 .49469 Mdot
.63836 .43005 Mdot
.55093 .31109 Mdot
.62337 .65317 Mdot
.66361 .48928 Mdot
.3577 .48669 Mdot
.38232 .65985 Mdot
.60288 .68892 Mdot
.37832 .33151 Mdot
.72512 .70742 Mdot
.30066 .42321 Mdot
.41419 .69061 Mdot
.70749 .25926 Mdot
.59832 .60994 Mdot
.45816 .70954 Mdot
.71979 .34101 Mdot
.38553 .5054 Mdot
.18075 .63867 Mdot
.60677 .48087 Mdot
.62762 .43466 Mdot
.3911 .43082 Mdot
.6507 .40607 Mdot
.41811 .46548 Mdot
.6463 .49076 Mdot
.73549 .47087 Mdot
.42869 .59736 Mdot
.65364 .47664 Mdot
.42419 .51726 Mdot
.38867 .44573 Mdot
.42866 .65985 Mdot
.60843 .46339 Mdot
.46738 .44322 Mdot
.8576 .45176 Mdot
.59303 .62904 Mdot
.64922 .57633 Mdot
.46993 .32014 Mdot
.61081 .62759 Mdot
.39237 .64299 Mdot
.4355 .49666 Mdot
.54049 .34233 Mdot
.41126 .64362 Mdot
.30485 .35959 Mdot
.55778 .33828 Mdot
.16877 .59102 Mdot
.42491 .67649 Mdot
.615 .45994 Mdot
.52821 .30495 Mdot
.36434 .42201 Mdot
.67746 .50296 Mdot
.70178 .65716 Mdot
.66189 .46779 Mdot
.42045 .42773 Mdot
.75488 .53058 Mdot
.61822 .65998 Mdot
.39756 .47227 Mdot
.6249 .43768 Mdot
.7061 .55265 Mdot
.40568 .50029 Mdot
.39424 .43532 Mdot
.42273 .18824 Mdot
.18544 .4746 Mdot
.53485 .32723 Mdot
.41485 .69872 Mdot
.35573 .46126 Mdot
.51698 .34478 Mdot
.67154 .37237 Mdot
.40723 .49445 Mdot
.38882 .69177 Mdot
.45471 .49471 Mdot
.60776 .45768 Mdot
.60687 .62303 Mdot
.60811 .5487 Mdot
.51998 .35232 Mdot
.61081 .84603 Mdot
.67346 .48805 Mdot
.39629 .51391 Mdot
.37217 .42797 Mdot
.58402 .24677 Mdot
.42189 .6236 Mdot
.24778 .66409 Mdot
.43099 .46677 Mdot
.44067 .73025 Mdot
.40698 .47894 Mdot
.62659 .49818 Mdot
.39744 .68019 Mdot
.42674 .4497 Mdot
.56356 .6938 Mdot
.37549 .40398 Mdot
.5388 .35522 Mdot
.6044 .77691 Mdot
.42174 .40566 Mdot
.12691 .5056 Mdot
.58054 .37435 Mdot
.65519 .47803 Mdot
.78446 .52247 Mdot
.88334 .50471 Mdot
.53961 .76167 Mdot
.40999 .62526 Mdot
.78451 .41754 Mdot
.63397 .47387 Mdot
.77091 .50037 Mdot
.69949 .25035 Mdot
.38249 .44531 Mdot
.4459 .46783 Mdot
.53985 .24677 Mdot
.66981 .43513 Mdot
.67858 .4323 Mdot
.36197 .50868 Mdot
.41096 .39527 Mdot
.64294 .47962 Mdot
.36536 .49946 Mdot
.38031 .52028 Mdot
.59832 .67294 Mdot
.39435 .69007 Mdot
.60451 .61334 Mdot
.63244 .61495 Mdot
.52735 .81275 Mdot
.58585 .35201 Mdot
.59646 .62406 Mdot
.6109 .60338 Mdot
.36805 .31747 Mdot
.36605 .2689 Mdot
.533 .29691 Mdot
.81283 .38931 Mdot
.63155 .45407 Mdot
.4213 .44454 Mdot
.4213 .6844 Mdot
.31148 .70214 Mdot
.71562 .38647 Mdot
.19609 .60648 Mdot
.44653 .44815 Mdot
.62238 .46775 Mdot
.63712 .55569 Mdot
.32698 .45339 Mdot
.61618 .42577 Mdot
.4154 .48798 Mdot
.68667 .4661 Mdot
.32624 .54987 Mdot
.69861 .69496 Mdot
.65067 .41471 Mdot
.36417 .69133 Mdot
.40461 .48826 Mdot
.40336 .68826 Mdot
.62325 .63033 Mdot
.52759 .30275 Mdot
.53686 .32393 Mdot
.40387 .43968 Mdot
.40865 .54215 Mdot
.61583 .37247 Mdot
.39275 .44955 Mdot
.36356 .4693 Mdot
.65074 .55288 Mdot
.36095 .46903 Mdot
.40083 .416 Mdot
.42146 .4214 Mdot
.4524 .46172 Mdot
.61648 .66393 Mdot
.77117 .60646 Mdot
.41657 .38596 Mdot
.40921 .38899 Mdot
.63924 .64436 Mdot
.75066 .36171 Mdot
.62582 .60772 Mdot
.65985 .23185 Mdot
.57847 .62508 Mdot
.53041 .32122 Mdot
.63161 .26166 Mdot
.41632 .55001 Mdot
.37242 .67446 Mdot
.64653 .62361 Mdot
.5182 .32954 Mdot
.61148 .63955 Mdot
.63786 .48805 Mdot
.43564 .17232 Mdot
.43929 .61943 Mdot
.45313 .55775 Mdot
.63379 .58928 Mdot
.74095 .63004 Mdot
.67295 .48426 Mdot
.40849 .68653 Mdot
.33406 .62571 Mdot
.38858 .41853 Mdot
.51573 .34057 Mdot
.41386 .43575 Mdot
.62882 .65063 Mdot
.6257 .4672 Mdot
.66606 .76401 Mdot
.54152 .34302 Mdot
.35585 .22101 Mdot
.65274 .44626 Mdot
.4166 .41624 Mdot
.63425 .6153 Mdot
.27282 .28539 Mdot
.59857 .61471 Mdot
.21936 .60652 Mdot
.4091 .61367 Mdot
.6324 .80912 Mdot
.40658 .63496 Mdot
.70737 .66075 Mdot
.26251 .25587 Mdot
.77881 .60587 Mdot
.37922 .65871 Mdot
.53895 .60915 Mdot
.37876 .4769 Mdot
.38142 .49247 Mdot
.6853 .72523 Mdot
.41216 .69942 Mdot
.36336 .441 Mdot
.72824 .49608 Mdot
.54733 .61673 Mdot
.27737 .32313 Mdot
.67219 .4631 Mdot
.42136 .46747 Mdot
.5763 .61549 Mdot
.56905 .63686 Mdot
.68304 .47265 Mdot
.60212 .60954 Mdot
.38954 .46868 Mdot
.40955 .64209 Mdot
.71644 .43417 Mdot
.54049 .31421 Mdot
.82134 .59622 Mdot
.51081 .34388 Mdot
.66301 .46565 Mdot
.34388 .45337 Mdot
.63841 .47502 Mdot
.90144 .47183 Mdot
.38823 .47672 Mdot
.38747 .66275 Mdot
.35937 .45805 Mdot
.40138 .48704 Mdot
.45143 .45556 Mdot
.63653 .48223 Mdot
.43997 .35757 Mdot
.36058 .49257 Mdot
.59068 .65035 Mdot
.23179 .50852 Mdot
.42646 .40938 Mdot
.70454 .45519 Mdot
.3639 .28523 Mdot
.59258 .58858 Mdot
.43475 .63752 Mdot
.65787 .47409 Mdot
.38672 .65025 Mdot
.39777 .74264 Mdot
.39262 .64311 Mdot
.243 .57998 Mdot
.33845 .60986 Mdot
.27426 .40071 Mdot
.28291 .46822 Mdot
.51548 .59977 Mdot
.41369 .69908 Mdot
.50653 .36965 Mdot
.37663 .64452 Mdot
.4326 .65546 Mdot
.08854 .42321 Mdot
.37099 .67904 Mdot
.42663 .47424 Mdot
.42226 .41063 Mdot
.73405 .65278 Mdot
.42982 .29498 Mdot
.36596 .4506 Mdot
.36686 .4431 Mdot
.54354 .3021 Mdot
.42527 .73162 Mdot
.7654 .55813 Mdot
.17613 .49184 Mdot
.78794 .48854 Mdot
.41212 .43781 Mdot
.35509 .4649 Mdot
.34048 .41952 Mdot
.19393 .38015 Mdot
.53081 .82166 Mdot
.41302 .58949 Mdot
.3405 .42371 Mdot
.77718 .63595 Mdot
.44941 .45944 Mdot
.4262 .48929 Mdot
.38069 .47316 Mdot
.63321 .47364 Mdot
.43613 .65674 Mdot
.45087 .47132 Mdot
.55281 .25572 Mdot
.42554 .48589 Mdot
.68947 .5569 Mdot
.73135 .74537 Mdot
.42438 .46438 Mdot
.43672 .6261 Mdot
.37741 .49043 Mdot
.42789 .63362 Mdot
.4193 .67192 Mdot
.33668 .4656 Mdot
.2199 .53553 Mdot
.42311 .61078 Mdot
.38802 .45995 Mdot
.62641 .48001 Mdot
.79771 .34901 Mdot
.42188 .42873 Mdot
.5278 .30117 Mdot
.43376 .46728 Mdot
.55555 .29509 Mdot
.36431 .4643 Mdot
.6749 .48741 Mdot
.33406 .72736 Mdot
.63458 .46406 Mdot
.56932 .82726 Mdot
.66094 .50084 Mdot
.40466 .18678 Mdot
.40873 .69538 Mdot
.74391 .54301 Mdot
.28602 .72162 Mdot
.6607 .58055 Mdot
.5234 .43576 Mdot
.51072 .54324 Mdot
.61845 .60957 Mdot
.40963 .6164 Mdot
.4777 .6549 Mdot
.72821 .36451 Mdot
.66957 .29926 Mdot
.63711 .43616 Mdot
.3752 .8155 Mdot
.21581 .65949 Mdot
.37616 .50713 Mdot
.29914 .61584 Mdot
.2677 .55385 Mdot
.44973 .46145 Mdot
.44541 .48039 Mdot
.65005 .53475 Mdot
.3546 .48661 Mdot
.58669 .71902 Mdot
.66417 .46199 Mdot
.51731 .33104 Mdot
.38835 .67095 Mdot
.52172 .3559 Mdot
.72064 .34757 Mdot
.50688 .54259 Mdot
.64741 .49247 Mdot
.42088 .4012 Mdot
.37162 .44069 Mdot
.42949 .64454 Mdot
.37662 .60995 Mdot
.37307 .65636 Mdot
.53 .34005 Mdot
.66125 .45678 Mdot
.37591 .77548 Mdot
.37404 .4353 Mdot
.40772 .66773 Mdot
.52586 .42149 Mdot
.35612 .45859 Mdot
.61849 .6301 Mdot
.38176 .48089 Mdot
.37945 .66462 Mdot
.36094 .46874 Mdot
.40681 .63324 Mdot
.65142 .46199 Mdot
.43268 .42099 Mdot
.39707 .42855 Mdot
.31107 .2544 Mdot
.52353 .32518 Mdot
.39606 .69623 Mdot
.58212 .48866 Mdot
.35965 .43678 Mdot
.72265 .57037 Mdot
.41954 .48524 Mdot
.35667 .72467 Mdot
.39742 .50809 Mdot
.65449 .5727 Mdot
.43754 .39387 Mdot
.42421 .43225 Mdot
.55126 .41544 Mdot
.26512 .56578 Mdot
.38994 .57032 Mdot
.62248 .6005 Mdot
.379 .6945 Mdot
.28108 .32383 Mdot
.60639 .415 Mdot
.62493 .42801 Mdot
.47919 .24985 Mdot
.45519 .45172 Mdot
.41566 .46011 Mdot
.61294 .59486 Mdot
.53541 .35162 Mdot
.40727 .68052 Mdot
.52059 .32272 Mdot
.3395 .24743 Mdot
.54924 .34561 Mdot
.61208 .48721 Mdot
.6369 .38388 Mdot
.39673 .78716 Mdot
.54574 .30347 Mdot
.37731 .66122 Mdot
.70229 .40862 Mdot
.45491 .43953 Mdot
.57694 .38014 Mdot
.53286 .3106 Mdot
.46133 .8562 Mdot
.40235 .4162 Mdot
.52068 .43329 Mdot
.60262 .61963 Mdot
.5365 .30139 Mdot
.62965 .62216 Mdot
.37739 .44094 Mdot
.76508 .54964 Mdot
.40776 .62516 Mdot
.63638 .64283 Mdot
.39591 .54072 Mdot
.52445 .33726 Mdot
.64341 .5 Mdot
.62912 .59621 Mdot
.63032 .60562 Mdot
.75887 .35751 Mdot
.64478 .78384 Mdot
.65927 .45447 Mdot
.23422 .41555 Mdot
.57512 .62709 Mdot
.45149 .43401 Mdot
.43956 .71695 Mdot
.39213 .4922 Mdot
.51681 .78992 Mdot
.6633 .47338 Mdot
.75165 .62611 Mdot
.35671 .46506 Mdot
.43936 .44078 Mdot
.4339 .61337 Mdot
.63735 .45672 Mdot
.40303 .65244 Mdot
.38203 .69871 Mdot
.65061 .46048 Mdot
.39838 .63295 Mdot
.56099 .32333 Mdot
.51616 .66899 Mdot
.57882 .64767 Mdot
.5973 .65782 Mdot
.62701 .45642 Mdot
.65784 .48018 Mdot
.6434 .47493 Mdot
.38187 .48144 Mdot
.40303 .68193 Mdot
.37501 .45499 Mdot
.43296 .48288 Mdot
.22883 .49507 Mdot
.43256 .66512 Mdot
.37754 .4652 Mdot
.56845 .4234 Mdot
.55842 .37842 Mdot
.62745 .48291 Mdot
.59933 .62243 Mdot
.7354 .51003 Mdot
.69278 .6655 Mdot
.42042 .4712 Mdot
.58523 .29886 Mdot
.37617 .65619 Mdot
.53944 .34005 Mdot
.50747 .35249 Mdot
.53603 .33156 Mdot
.62164 .56891 Mdot
.40469 .69988 Mdot
.17465 .50265 Mdot
.42 .46403 Mdot
.48084 .55457 Mdot
.46231 .64055 Mdot
.60255 .36316 Mdot
.59749 .62499 Mdot
.35921 .45297 Mdot
.60373 .54711 Mdot
.334 .6542 Mdot
.39167 .4899 Mdot
.43543 .41465 Mdot
.74831 .42815 Mdot
.46501 .47685 Mdot
.3915 .61533 Mdot
.27373 .28954 Mdot
.3531 .4398 Mdot
.44502 .76788 Mdot
.82928 .59789 Mdot
.41766 .47966 Mdot
.44307 .45185 Mdot
.3894 .42408 Mdot
.36253 .48056 Mdot
.43165 .62043 Mdot
.42594 .26527 Mdot
.57862 .62109 Mdot
.47935 .55027 Mdot
.61052 .66938 Mdot
.67426 .5012 Mdot
.75794 .62321 Mdot
.40581 .61505 Mdot
.54817 .33762 Mdot
.8071 .55178 Mdot
.21613 .38252 Mdot
.6798 .46385 Mdot
.4758 .80913 Mdot
.52895 .31591 Mdot
.4474 .42759 Mdot
.55953 .30898 Mdot
.62587 .4898 Mdot
.59243 .65776 Mdot
.44433 .41508 Mdot
.37915 .64142 Mdot
.38737 .682 Mdot
.3585 .44937 Mdot
.78521 .62074 Mdot
.61746 .62559 Mdot
.63486 .60619 Mdot
.4062 .49734 Mdot
.36576 .4211 Mdot
.40153 .64842 Mdot
.64341 .44159 Mdot
.28715 .35507 Mdot
.5255 .34974 Mdot
.42802 .50678 Mdot
.36367 .47503 Mdot
.40907 .20326 Mdot
.58688 .64837 Mdot
.60956 .4365 Mdot
.39254 .50548 Mdot
.49121 .73812 Mdot
.38946 .50505 Mdot
.33329 .43882 Mdot
.6245 .47855 Mdot
.41273 .38172 Mdot
.3848 .51496 Mdot
.44653 .64021 Mdot
.62153 .61307 Mdot
.39105 .657 Mdot
.42803 .69456 Mdot
.47053 .59551 Mdot
.61837 .63238 Mdot
.37566 .47214 Mdot
.59788 .62997 Mdot
.40613 .49425 Mdot
.35223 .47034 Mdot
.59444 .62392 Mdot
.40324 .65105 Mdot
.78328 .42229 Mdot
.77649 .5986 Mdot
.36297 .4844 Mdot
.34631 .4904 Mdot
.4245 .27841 Mdot
.44938 .36254 Mdot
.44717 .45891 Mdot
.38058 .66931 Mdot
.3817 .43253 Mdot
.62972 .63183 Mdot
.55816 .31365 Mdot
.38136 .66078 Mdot
.66059 .44429 Mdot
.67852 .47238 Mdot
.53336 .75512 Mdot
.65026 .42984 Mdot
.44267 .47721 Mdot
.36442 .71771 Mdot
.43978 .66692 Mdot
.80205 .6244 Mdot
.64822 .45771 Mdot
.53515 .29484 Mdot
.39591 .43609 Mdot
.51678 .21984 Mdot
.56971 .62165 Mdot
.12752 .566 Mdot
.17196 .5577 Mdot
.55664 .35439 Mdot
.19785 .5998 Mdot
.67175 .49561 Mdot
.39778 .5192 Mdot
.52253 .30736 Mdot
.67421 .47563 Mdot
.37676 .4975 Mdot
.3352 .45784 Mdot
.23931 .64967 Mdot
.49798 .58867 Mdot
.59526 .63154 Mdot
.66681 .43858 Mdot
.55334 .36051 Mdot
.60377 .47522 Mdot
.41053 .69013 Mdot
.42628 .43865 Mdot
.34188 .45685 Mdot
.65219 .43992 Mdot
.64331 .42265 Mdot
.38347 .46354 Mdot
.39802 .61447 Mdot
.64164 .5363 Mdot
.40853 .443 Mdot
.50649 .62829 Mdot
.38648 .71211 Mdot
.66852 .45974 Mdot
.43445 .4373 Mdot
.49475 .37574 Mdot
.65029 .44412 Mdot
.62868 .48484 Mdot
.35411 .46053 Mdot
.5608 .32931 Mdot
.34358 .47923 Mdot
.57835 .62926 Mdot
.42353 .82638 Mdot
.63075 .63434 Mdot
.72762 .45576 Mdot
.40048 .54268 Mdot
.484 .70637 Mdot
.43086 .6298 Mdot
.46375 .22129 Mdot
.73029 .49795 Mdot
.36953 .51691 Mdot
.77416 .33499 Mdot
.64601 .67536 Mdot
.79901 .59779 Mdot
.59294 .22165 Mdot
.54382 .3083 Mdot
.61362 .64063 Mdot
.44339 .4528 Mdot
.59355 .67268 Mdot
.52037 .30887 Mdot
.57225 .82418 Mdot
.4285 .42932 Mdot
.39576 .67809 Mdot
.38495 .46806 Mdot
.39562 .68494 Mdot
.35373 .46448 Mdot
.35893 .40548 Mdot
.69265 .5339 Mdot
.32458 .34689 Mdot
.40383 .50478 Mdot
.39155 .17458 Mdot
.50804 .38876 Mdot
.51855 .34077 Mdot
.38092 .44964 Mdot
.61799 .42064 Mdot
.56603 .64453 Mdot
.62804 .7394 Mdot
.63352 .47481 Mdot
.62238 .60346 Mdot
.39825 .63939 Mdot
.65881 .46944 Mdot
.68205 .46635 Mdot
.41567 .38118 Mdot
.56246 .33614 Mdot
.61332 .6574 Mdot
.42832 .44944 Mdot
.42788 .42979 Mdot
.23143 .40712 Mdot
.71231 .37195 Mdot
.37011 .61762 Mdot
.16539 .44142 Mdot
.37018 .69488 Mdot
.52067 .3375 Mdot
.63089 .47785 Mdot
.4383 .47436 Mdot
.39783 .46879 Mdot
.727 .55124 Mdot
.37972 .63304 Mdot
.54042 .55271 Mdot
.36262 .74027 Mdot
.58154 .48297 Mdot
.36835 .30029 Mdot
.38541 .67068 Mdot
.36802 .3021 Mdot
.51726 .36654 Mdot
.83118 .44609 Mdot
.3451 .33174 Mdot
.60359 .62103 Mdot
.37364 .30011 Mdot
.41124 .66999 Mdot
.36639 .49667 Mdot
.61413 .46237 Mdot
.64029 .42936 Mdot
.3967 .65596 Mdot
.59964 .45675 Mdot
.55263 .31704 Mdot
.43861 .45251 Mdot
.18145 .47199 Mdot
.54474 .73616 Mdot
.62668 .45162 Mdot
.33091 .43068 Mdot
.6241 .64873 Mdot
.35816 .44899 Mdot
.55158 .30896 Mdot
.60445 .63219 Mdot
.44301 .21136 Mdot
.54977 .64594 Mdot
.39727 .43847 Mdot
.41886 .19141 Mdot
.61352 .6339 Mdot
.47358 .38147 Mdot
.41559 .44264 Mdot
.58322 .62048 Mdot
.46797 .39145 Mdot
.71637 .62759 Mdot
.58265 .53659 Mdot
.70122 .25105 Mdot
.56711 .5308 Mdot
.61777 .45622 Mdot
.72859 .63063 Mdot
.66511 .60993 Mdot
.5761 .6558 Mdot
.6219 .42597 Mdot
.56882 .35626 Mdot
.62871 .6197 Mdot
.43611 .41825 Mdot
.41677 .48454 Mdot
.54669 .82191 Mdot
.66154 .64512 Mdot
.70462 .67088 Mdot
.58567 .75346 Mdot
.36271 .43285 Mdot
.34179 .47321 Mdot
.40206 .46577 Mdot
.41594 .60432 Mdot
.59038 .63942 Mdot
.3356 .21668 Mdot
.62072 .62884 Mdot
.19646 .50412 Mdot
.62895 .45674 Mdot
.67293 .46672 Mdot
.42318 .4685 Mdot
.50901 .43286 Mdot
.4033 .24822 Mdot
.39004 .46573 Mdot
.57156 .30155 Mdot
.61476 .77593 Mdot
.36298 .42533 Mdot
.41814 .61374 Mdot
.33958 .41317 Mdot
.32315 .42274 Mdot
.57862 .64793 Mdot
.54842 .32268 Mdot
.45286 .22009 Mdot
.59816 .66198 Mdot
.41435 .46049 Mdot
.49206 .70648 Mdot
.39792 .48379 Mdot
.36675 .48902 Mdot
.18324 .5542 Mdot
.51621 .3607 Mdot
.64526 .46887 Mdot
.53372 .33151 Mdot
.42857 .6312 Mdot
.09143 .5154 Mdot
.54497 .3512 Mdot
.40873 .24139 Mdot
.52676 .83309 Mdot
.37624 .30195 Mdot
.39995 .68963 Mdot
.565 .32646 Mdot
.61216 .62236 Mdot
.80385 .35525 Mdot
.27671 .69588 Mdot
.62081 .70072 Mdot
.40799 .44788 Mdot
.36803 .64161 Mdot
.37907 .67731 Mdot
.63685 .64566 Mdot
.41743 .67409 Mdot
.47932 .44607 Mdot
.36558 .49274 Mdot
.583 .66622 Mdot
.50267 .72967 Mdot
.62118 .59975 Mdot
.53531 .64683 Mdot
.38525 .45151 Mdot
.38456 .66483 Mdot
.42013 .51486 Mdot
.39432 .71312 Mdot
.60371 .45733 Mdot
.38889 .40211 Mdot
.55348 .32003 Mdot
.47733 .72667 Mdot
.65942 .45261 Mdot
.59464 .33285 Mdot
.43022 .64431 Mdot
.58675 .58215 Mdot
.42773 .6605 Mdot
.41937 .69811 Mdot
.62967 .6103 Mdot
.41741 .64627 Mdot
.44188 .45132 Mdot
.56475 .46504 Mdot
.42204 .63004 Mdot
.6083 .65144 Mdot
.54561 .32231 Mdot
.40353 .63686 Mdot
.65605 .40733 Mdot
.402 .43306 Mdot
.64534 .48508 Mdot
.6232 .26139 Mdot
.36512 .65841 Mdot
.52623 .3627 Mdot
.63428 .42554 Mdot
.51458 .34095 Mdot
.76279 .68961 Mdot
.61214 .67766 Mdot
.20071 .5375 Mdot
.56944 .34396 Mdot
.37154 .67105 Mdot
.63663 .26558 Mdot
.43439 .47735 Mdot
.39903 .43397 Mdot
.55031 .28923 Mdot
.37878 .67692 Mdot
.83431 .51053 Mdot
.32685 .5022 Mdot
.52618 .64132 Mdot
.64524 .64362 Mdot
.40548 .18242 Mdot
.5417 .66233 Mdot
.81076 .66518 Mdot
.37128 .523 Mdot
.681 .43465 Mdot
.41373 .47126 Mdot
.71939 .51697 Mdot
.52556 .33489 Mdot
.71538 .46465 Mdot
.34695 .42834 Mdot
.65092 .46739 Mdot
.40578 .42371 Mdot
.55201 .43247 Mdot
.40125 .37325 Mdot
.53199 .29554 Mdot
.77976 .53267 Mdot
.37305 .68454 Mdot
.53781 .31286 Mdot
.66484 .49255 Mdot
.39106 .27073 Mdot
.37257 .49607 Mdot
.46297 .46807 Mdot
.58143 .48243 Mdot
.40197 .68481 Mdot
.61531 .4505 Mdot
.57799 .63862 Mdot
.54725 .33448 Mdot
.37079 .44336 Mdot
.42701 .49392 Mdot
.7173 .57153 Mdot
.62564 .64902 Mdot
.65718 .42681 Mdot
.60952 .61426 Mdot
.67911 .48848 Mdot
.35006 .47378 Mdot
.67512 .46034 Mdot
.43918 .49837 Mdot
.68602 .54076 Mdot
.18903 .53957 Mdot
.27542 .58762 Mdot
.66519 .47168 Mdot
.33953 .3006 Mdot
.62528 .64243 Mdot
.59627 .61441 Mdot
.45335 .82001 Mdot
.21993 .61248 Mdot
.21986 .40383 Mdot
.71737 .29914 Mdot
.60155 .66941 Mdot
.61926 .6508 Mdot
.6491 .48553 Mdot
.41908 .64608 Mdot
.3779 .70069 Mdot
.68146 .48359 Mdot
.47067 .31023 Mdot
.40725 .68032 Mdot
.79463 .36994 Mdot
.25531 .35315 Mdot
.44996 .47962 Mdot
.59463 .4599 Mdot
.54206 .33473 Mdot
.46351 .30171 Mdot
.55421 .42791 Mdot
.44162 .44207 Mdot
.49538 .22205 Mdot
.63279 .44886 Mdot
.50208 .46626 Mdot
.66212 .23536 Mdot
.41863 .41974 Mdot
.42054 .44308 Mdot
.40889 .46586 Mdot
.55248 .35489 Mdot
.25181 .65903 Mdot
.43551 .44265 Mdot
.47059 .31328 Mdot
.35904 .44094 Mdot
.4627 .37989 Mdot
.53591 .32599 Mdot
.31256 .37538 Mdot
.73183 .36148 Mdot
.27158 .29824 Mdot
.40007 .36951 Mdot
.57714 .63656 Mdot
.54924 .26235 Mdot
.60655 .61119 Mdot
.2495 .58099 Mdot
.35464 .33005 Mdot
.36301 .68052 Mdot
.44334 .44571 Mdot
.66371 .46541 Mdot
.38031 .67856 Mdot
.72596 .60076 Mdot
.08486 .4694 Mdot
.57559 .63601 Mdot
.85494 .62139 Mdot
.58333 .62205 Mdot
.6826 .46684 Mdot
.40072 .64793 Mdot
.34075 .60049 Mdot
.47673 .57271 Mdot
.40283 .63434 Mdot
.80401 .47017 Mdot
.40971 .59013 Mdot
.36061 .29266 Mdot
.37435 .63547 Mdot
.61429 .64977 Mdot
.628 .57465 Mdot
.42864 .5465 Mdot
.43162 .47505 Mdot
.5142 .53765 Mdot
.38228 .26271 Mdot
.43528 .47512 Mdot
.66259 .46013 Mdot
.19996 .55299 Mdot
.48318 .23403 Mdot
.4152 .65251 Mdot
.5613 .66408 Mdot
.42092 .43738 Mdot
.37216 .48517 Mdot
.37209 .49785 Mdot
.15209 .51125 Mdot
.83294 .44974 Mdot
.35906 .49024 Mdot
.3537 .44534 Mdot
.65556 .46802 Mdot
.53841 .37532 Mdot
.75075 .46392 Mdot
.2378 .45172 Mdot
.43954 .42936 Mdot
.53546 .31676 Mdot
.53152 .36975 Mdot
.38372 .50393 Mdot
.58116 .3799 Mdot
.49357 .69747 Mdot
.42863 .44806 Mdot
.20361 .55609 Mdot
.57604 .45095 Mdot
.67028 .43549 Mdot
.65566 .44232 Mdot
.39999 .69326 Mdot
.66626 .44234 Mdot
.66945 .4943 Mdot
.35012 .6085 Mdot
.55502 .53568 Mdot
.56409 .67292 Mdot
.53086 .34129 Mdot
.3968 .47339 Mdot
.38329 .565 Mdot
.48824 .72839 Mdot
.62714 .61321 Mdot
.37999 .64714 Mdot
.56582 .63905 Mdot
.51888 .28599 Mdot
.44822 .57685 Mdot
.63227 .44266 Mdot
.59506 .66649 Mdot
.55544 .62579 Mdot
.53671 .31828 Mdot
.63377 .63903 Mdot
.56865 .60968 Mdot
.40185 .402 Mdot
.29748 .63468 Mdot
.39066 .45995 Mdot
.81152 .55938 Mdot
.6191 .65695 Mdot
.66153 .5633 Mdot
.42055 .45468 Mdot
.64953 .44556 Mdot
.42173 .55551 Mdot
.42853 .48355 Mdot
.65718 .4391 Mdot
.37507 .50636 Mdot
.51198 .34505 Mdot
.39677 .71077 Mdot
.47294 .56229 Mdot
.34949 .81209 Mdot
.56302 .33473 Mdot
.72805 .5924 Mdot
.44783 .45375 Mdot
.69279 .75205 Mdot
.4054 .63897 Mdot
.41726 .50888 Mdot
.46075 .23644 Mdot
.42045 .63357 Mdot
.38593 .64552 Mdot
.37316 .47843 Mdot
.60567 .61832 Mdot
.66316 .4545 Mdot
.53841 .32245 Mdot
.80685 .65028 Mdot
.4009 .44666 Mdot
.39105 .42961 Mdot
.5329 .31325 Mdot
.62767 .64326 Mdot
.39519 .50449 Mdot
.5903 .24215 Mdot
.84527 .50424 Mdot
.59604 .61205 Mdot
.4376 .42085 Mdot
.25901 .62386 Mdot
.31519 .4487 Mdot
.61578 .83307 Mdot
.58022 .37368 Mdot
.6508 .47275 Mdot
.45089 .50843 Mdot
.11443 .48825 Mdot
.54748 .32483 Mdot
.2164 .38866 Mdot
.36901 .48259 Mdot
.37313 .43424 Mdot
.37371 .65569 Mdot
.37717 .45798 Mdot
.39605 .61917 Mdot
.33406 .79125 Mdot
.40413 .20324 Mdot
.40961 .68742 Mdot
.36941 .67024 Mdot
.43167 .23417 Mdot
.74295 .48147 Mdot
.39641 .65278 Mdot
.3512 .46452 Mdot
.32971 .38087 Mdot
.40862 .57244 Mdot
.55869 .30351 Mdot
.69001 .30852 Mdot
.36214 .54529 Mdot
.54501 .27673 Mdot
.76648 .37629 Mdot
.35844 .5459 Mdot
.54878 .58775 Mdot
.58128 .63352 Mdot
.42038 .41978 Mdot
.64328 .42847 Mdot
.65257 .4291 Mdot
.40011 .52542 Mdot
.39317 .47942 Mdot
.42946 .63561 Mdot
.54058 .34635 Mdot
.5726 .64287 Mdot
.36929 .44078 Mdot
.45332 .22814 Mdot
.53708 .3529 Mdot
.42112 .66017 Mdot
.21905 .50573 Mdot
.51591 .30978 Mdot
.37536 .39772 Mdot
.43018 .45974 Mdot
.3816 .4707 Mdot
.39882 .56815 Mdot
.58744 .63636 Mdot
.66651 .28169 Mdot
.39852 .40968 Mdot
.33463 .24987 Mdot
.61697 .68438 Mdot
.43149 .39848 Mdot
.41789 .67911 Mdot
.55421 .65865 Mdot
.63295 .49874 Mdot
.46624 .60213 Mdot
.39678 .44057 Mdot
.78431 .59459 Mdot
.56748 .81375 Mdot
.60546 .45591 Mdot
.41508 .69978 Mdot
.5369 .33734 Mdot
.39061 .46784 Mdot
.22232 .54193 Mdot
.41955 .48193 Mdot
.52859 .28823 Mdot
.62383 .48227 Mdot
.58226 .63109 Mdot
.80447 .58639 Mdot
.65856 .43304 Mdot
.38658 .64916 Mdot
.53366 .14773 Mdot
.39899 .61688 Mdot
.38317 .70191 Mdot
.23009 .50489 Mdot
.58716 .63381 Mdot
.11438 .52033 Mdot
.36696 .79424 Mdot
.3702 .41307 Mdot
.6258 .63929 Mdot
.39589 .66397 Mdot
.36805 .43376 Mdot
.35759 .67083 Mdot
.41001 .69797 Mdot
.34919 .46505 Mdot
.39069 .42157 Mdot
.71635 .6797 Mdot
.69537 .25436 Mdot
.53571 .33835 Mdot
.43375 .64709 Mdot
.50199 .62909 Mdot
.37079 .42973 Mdot
.42041 .46311 Mdot
.67258 .62846 Mdot
.56021 .31636 Mdot
.58222 .72503 Mdot
.37077 .4841 Mdot
.42765 .19989 Mdot
.39163 .38543 Mdot
.42432 .61337 Mdot
.61058 .6088 Mdot
.27904 .29267 Mdot
.6429 .59992 Mdot
.39376 .62144 Mdot
.5479 .34183 Mdot
.44345 .64055 Mdot
.40586 .24102 Mdot
.62463 .65883 Mdot
.37943 .66468 Mdot
.60925 .54995 Mdot
.59706 .64085 Mdot
.60808 .66468 Mdot
.23555 .49309 Mdot
.61514 .42765 Mdot
.54919 .35861 Mdot
.61667 .65517 Mdot
.45706 .71465 Mdot
.60797 .64751 Mdot
.38933 .79672 Mdot
.432 .4199 Mdot
.48654 .27106 Mdot
.72331 .46198 Mdot
.43849 .52818 Mdot
.61871 .66035 Mdot
.54392 .30134 Mdot
.37977 .49761 Mdot
.41309 .67144 Mdot
.52 .34969 Mdot
.6141 .70836 Mdot
.64051 .47868 Mdot
.42768 .65613 Mdot
.64159 .60284 Mdot
.3909 .68332 Mdot
.47813 .65103 Mdot
.49358 .83894 Mdot
.50612 .19574 Mdot
.48074 .58568 Mdot
.37038 .49461 Mdot
.73258 .33113 Mdot
.46043 .45352 Mdot
.39064 .48351 Mdot
.66698 .46046 Mdot
.48554 .25495 Mdot
.40283 .65174 Mdot
.82688 .53834 Mdot
.5827 .65411 Mdot
.28097 .28423 Mdot
.34587 .3843 Mdot
.39038 .51331 Mdot
.42013 .62714 Mdot
.3915 .61885 Mdot
.25565 .5493 Mdot
.64265 .5037 Mdot
.44137 .48577 Mdot
.45633 .43684 Mdot
.37761 .51716 Mdot
.58875 .65699 Mdot
.59267 .32622 Mdot
.61902 .45528 Mdot
.56503 .83749 Mdot
.61912 .4771 Mdot
.55609 .2752 Mdot
.41746 .65169 Mdot
.54545 .35053 Mdot
.42194 .46151 Mdot
.39469 .59328 Mdot
.38073 .63125 Mdot
.54116 .28946 Mdot
.5309 .30302 Mdot
.69512 .62406 Mdot
.59434 .62465 Mdot
.42034 .49655 Mdot
.43545 .43919 Mdot
.37201 .45558 Mdot
.38367 .48052 Mdot
.57627 .64477 Mdot
.38774 .49944 Mdot
.59808 .60128 Mdot
.45353 .68969 Mdot
.54174 .24408 Mdot
.56683 .52571 Mdot
.50375 .79859 Mdot
.41396 .66179 Mdot
.46758 .7077 Mdot
.33954 .51292 Mdot
.17937 .59568 Mdot
.63709 .77081 Mdot
.39059 .40836 Mdot
.67725 .47005 Mdot
.48417 .42194 Mdot
.6346 .43609 Mdot
.80225 .69517 Mdot
.69967 .571 Mdot
.73293 .28594 Mdot
.42637 .42918 Mdot
.57034 .4802 Mdot
.42861 .74522 Mdot
.46194 .4575 Mdot
.70369 .58993 Mdot
.50891 .7923 Mdot
.7808 .55128 Mdot
.55405 .31001 Mdot
.40787 .43566 Mdot
.38862 .56859 Mdot
.44016 .45072 Mdot
.41753 .46875 Mdot
.37926 .49949 Mdot
.60916 .60148 Mdot
.43103 .49695 Mdot
.38923 .49496 Mdot
.62243 .37218 Mdot
.35435 .31521 Mdot
.64394 .4246 Mdot
.4852 .82465 Mdot
.54438 .35217 Mdot
.42664 .63369 Mdot
.81784 .43687 Mdot
.60288 .62156 Mdot
.25924 .54842 Mdot
.38256 .4763 Mdot
.74117 .64851 Mdot
.55535 .64591 Mdot
.55068 .33161 Mdot
.62336 .4888 Mdot
.76824 .31333 Mdot
.65881 .46122 Mdot
.62292 .56258 Mdot
.64966 .44777 Mdot
.3457 .52254 Mdot
.43023 .63699 Mdot
.40764 .50122 Mdot
.60932 .65805 Mdot
.66852 .44783 Mdot
.43084 .28515 Mdot
.40313 .46728 Mdot
.64968 .46067 Mdot
.40798 .5009 Mdot
.45228 .56125 Mdot
.24594 .41209 Mdot
.671 .49151 Mdot
.55672 .64762 Mdot
.59456 .65064 Mdot
.56003 .33251 Mdot
.42728 .64371 Mdot
.3829 .6373 Mdot
.60455 .63371 Mdot
.24119 .66411 Mdot
.44469 .43558 Mdot
.37746 .42574 Mdot
.29885 .27376 Mdot
.44369 .46055 Mdot
.37753 .28148 Mdot
.59493 .54005 Mdot
.41732 .66521 Mdot
.37675 .51207 Mdot
.36823 .47655 Mdot
.39757 .43721 Mdot
.46748 .64941 Mdot
.64239 .44097 Mdot
.42323 .41887 Mdot
.52633 .30709 Mdot
.59497 .39886 Mdot
.35784 .44933 Mdot
.44464 .38952 Mdot
.38133 .64015 Mdot
.16642 .45056 Mdot
.58367 .62306 Mdot
.66801 .48941 Mdot
.6657 .47348 Mdot
.70504 .32142 Mdot
.46827 .75715 Mdot
.59276 .53722 Mdot
.59845 .82789 Mdot
.69192 .53375 Mdot
.5203 .32901 Mdot
.60716 .49646 Mdot
.63391 .57806 Mdot
.66024 .4868 Mdot
.57483 .63719 Mdot
.4279 .41698 Mdot
.43816 .42731 Mdot
.17247 .61279 Mdot
.38154 .50472 Mdot
.53897 .33365 Mdot
.62778 .60006 Mdot
.41074 .66948 Mdot
.54954 .334 Mdot
.61117 .6134 Mdot
.40756 .68599 Mdot
.40547 .4069 Mdot
.40964 .40804 Mdot
.38136 .64431 Mdot
.3771 .6689 Mdot
.42779 .45743 Mdot
.73702 .45219 Mdot
.37297 .67698 Mdot
.3829 .66942 Mdot
.62842 .44609 Mdot
.64417 .42975 Mdot
.43085 .39023 Mdot
.62284 .63976 Mdot
.38848 .49613 Mdot
.66016 .46781 Mdot
.54909 .3453 Mdot
.40523 .6526 Mdot
.36353 .48353 Mdot
.36003 .45419 Mdot
.53837 .31822 Mdot
.55663 .33086 Mdot
.54617 .3054 Mdot
.61494 .59836 Mdot
.37659 .44784 Mdot
.39723 .64461 Mdot
.59042 .62604 Mdot
.53474 .36843 Mdot
.55405 .30049 Mdot
.61562 .49767 Mdot
.44177 .47044 Mdot
.69729 .41643 Mdot
.11364 .45513 Mdot
.33816 .26209 Mdot
.60801 .47481 Mdot
.61836 .49002 Mdot
.39378 .30956 Mdot
.50755 .47094 Mdot
.61457 .6287 Mdot
.51779 .37875 Mdot
.44917 .21849 Mdot
.42037 .4048 Mdot
.35562 .43658 Mdot
.34751 .41571 Mdot
.53933 .30348 Mdot
.50052 .24644 Mdot
.4078 .61526 Mdot
.32015 .51178 Mdot
.52992 .35483 Mdot
.64453 .42296 Mdot
.60041 .48037 Mdot
.62085 .48048 Mdot
.4216 .41288 Mdot
.28261 .58852 Mdot
.4622 .73392 Mdot
.68245 .27302 Mdot
.62386 .6544 Mdot
.38405 .56433 Mdot
.69213 .749 Mdot
.38394 .64349 Mdot
.6728 .5032 Mdot
.51937 .32583 Mdot
.37924 .67197 Mdot
.56313 .64552 Mdot
.6168 .65314 Mdot
.62514 .45377 Mdot
.62462 .46054 Mdot
.64155 .48874 Mdot
.40493 .70238 Mdot
.4177 .64871 Mdot
.39411 .44229 Mdot
.40848 .65413 Mdot
.16646 .56062 Mdot
.55954 .29681 Mdot
.6995 .44997 Mdot
.61656 .63928 Mdot
.4033 .68782 Mdot
.40054 .46598 Mdot
.49537 .49434 Mdot
.56083 .76899 Mdot
.51534 .33102 Mdot
.23766 .40788 Mdot
.78928 .7057 Mdot
.42353 .49514 Mdot
.58702 .64346 Mdot
.18328 .46389 Mdot
.40757 .46373 Mdot
.62647 .47578 Mdot
.75088 .44412 Mdot
.58405 .46172 Mdot
.42654 .48617 Mdot
.42381 .4041 Mdot
.58575 .61666 Mdot
.58829 .82428 Mdot
.396 .4455 Mdot
.55886 .71556 Mdot
.59017 .6745 Mdot
.61715 .46065 Mdot
.85054 .43159 Mdot
.60343 .26464 Mdot
.46881 .30285 Mdot
.62248 .45307 Mdot
.40274 .4874 Mdot
.63784 .43713 Mdot
.51779 .32159 Mdot
.65043 .49861 Mdot
.40478 .61359 Mdot
.60818 .45442 Mdot
.3911 .429 Mdot
.39506 .65515 Mdot
.61477 .6333 Mdot
.25149 .32877 Mdot
.69577 .39136 Mdot
.64736 .44536 Mdot
.67659 .48405 Mdot
.37648 .51023 Mdot
.6013 .7228 Mdot
.41901 .52012 Mdot
.40558 .41643 Mdot
.6082 .66922 Mdot
.42296 .63463 Mdot
.61125 .60598 Mdot
.46599 .42561 Mdot
.58232 .23185 Mdot
.60571 .6146 Mdot
.77867 .59086 Mdot
.52733 .31764 Mdot
.53936 .47064 Mdot
.39611 .4698 Mdot
.63295 .63057 Mdot
.37855 .44758 Mdot
.41479 .61671 Mdot
.55976 .49435 Mdot
.7687 .5543 Mdot
.60084 .66057 Mdot
.79211 .59032 Mdot
.53156 .25953 Mdot
.46587 .40855 Mdot
.59922 .61242 Mdot
.47066 .23757 Mdot
.68245 .46537 Mdot
.52471 .35031 Mdot
.5113 .32678 Mdot
.52061 .35417 Mdot
.39284 .53114 Mdot
.37812 .37046 Mdot
.51877 .36262 Mdot
.56631 .64954 Mdot
.53133 .29614 Mdot
.42605 .77325 Mdot
.82444 .52991 Mdot
.52592 .33139 Mdot
.41247 .44397 Mdot
.32353 .43698 Mdot
.36923 .31547 Mdot
.71155 .63607 Mdot
.74902 .30327 Mdot
.62789 .74986 Mdot
.42925 .47672 Mdot
.38689 .70963 Mdot
.42398 .68079 Mdot
.18911 .43476 Mdot
.36498 .27354 Mdot
.37148 .23178 Mdot
.3701 .68326 Mdot
.74958 .53744 Mdot
.42345 .6584 Mdot
.37629 .50182 Mdot
.37348 .42895 Mdot
.36807 .68046 Mdot
.53687 .23738 Mdot
.74731 .56121 Mdot
.80685 .61487 Mdot
.38587 .67822 Mdot
.62047 .61231 Mdot
.64092 .63559 Mdot
.61007 .66493 Mdot
.24294 .36905 Mdot
.41105 .62398 Mdot
.36631 .45432 Mdot
.66606 .47034 Mdot
.43035 .42376 Mdot
.59533 .63747 Mdot
.83007 .53227 Mdot
.40746 .63068 Mdot
.42645 .43643 Mdot
.48188 .48237 Mdot
.62919 .46966 Mdot
.53073 .31924 Mdot
.45389 .55035 Mdot
.36924 .23649 Mdot
.58882 .66062 Mdot
.36482 .66445 Mdot
.67659 .55803 Mdot
.80386 .5459 Mdot
.36424 .5191 Mdot
.45809 .43686 Mdot
.80456 .66157 Mdot
.43056 .20864 Mdot
.44665 .46977 Mdot
.67382 .48268 Mdot
.72138 .55218 Mdot
.3576 .46321 Mdot
.43048 .66772 Mdot
.5129 .31757 Mdot
.51526 .3416 Mdot
.43677 .39109 Mdot
.48533 .54388 Mdot
.56391 .47831 Mdot
.37595 .47403 Mdot
.36887 .40039 Mdot
.61841 .45899 Mdot
.70779 .5206 Mdot
.34098 .24573 Mdot
.55099 .33914 Mdot
.40447 .50202 Mdot
.78351 .44856 Mdot
.3733 .64889 Mdot
.60601 .46249 Mdot
.63159 .64893 Mdot
.45997 .6291 Mdot
.62654 .49123 Mdot
.35616 .47414 Mdot
.38843 .50426 Mdot
.63393 .61814 Mdot
.42243 .61152 Mdot
.53627 .30447 Mdot
.67116 .46677 Mdot
.55651 .32391 Mdot
.41848 .63148 Mdot
.41159 .64869 Mdot
.48382 .45944 Mdot
.35482 .5173 Mdot
.65916 .44425 Mdot
.43895 .49939 Mdot
.58291 .43345 Mdot
.65953 .8061 Mdot
.64653 .6243 Mdot
.43374 .48833 Mdot
.40326 .60436 Mdot
.59498 .66019 Mdot
.37876 .42826 Mdot
.82033 .63904 Mdot
.36682 .43229 Mdot
.6126 .68365 Mdot
.48923 .18497 Mdot
.55243 .31253 Mdot
.31734 .5031 Mdot
.69364 .7139 Mdot
.44134 .46072 Mdot
.66118 .4806 Mdot
.3295 .43803 Mdot
.61122 .61942 Mdot
.41584 .65226 Mdot
.63485 .82932 Mdot
.60494 .64955 Mdot
.43576 .45021 Mdot
.54805 .33434 Mdot
.3799 .62894 Mdot
.58056 .33777 Mdot
.58224 .37856 Mdot
.43523 .37857 Mdot
.42909 .50646 Mdot
.38017 .48536 Mdot
.62023 .24502 Mdot
.66509 .49063 Mdot
.39105 .67081 Mdot
.5863 .64555 Mdot
.60706 .63112 Mdot
.63019 .44952 Mdot
.54945 .66124 Mdot
.53962 .4729 Mdot
.15744 .39017 Mdot
.65243 .43571 Mdot
.52969 .35979 Mdot
.57974 .72027 Mdot
.67058 .47544 Mdot
.64547 .45887 Mdot
.62722 .44565 Mdot
.58452 .56584 Mdot
.40482 .6844 Mdot
.35501 .47099 Mdot
.43435 .63595 Mdot
.40058 .48907 Mdot
.60903 .68445 Mdot
.60643 .66063 Mdot
.41209 .6333 Mdot
.78654 .67292 Mdot
.29135 .65596 Mdot
.41124 .4553 Mdot
.69377 .75014 Mdot
.34301 .442 Mdot
.39544 .29223 Mdot
.3388 .44621 Mdot
.63662 .45018 Mdot
.44888 .49884 Mdot
.37943 .51928 Mdot
.19969 .40316 Mdot
.61916 .63754 Mdot
.67554 .44081 Mdot
.3647 .4116 Mdot
.36273 .40157 Mdot
.39898 .70427 Mdot
.38047 .67191 Mdot
.51167 .33447 Mdot
.31612 .35366 Mdot
.61735 .63162 Mdot
.35582 .77515 Mdot
.43182 .47214 Mdot
.57469 .2704 Mdot
.28034 .4658 Mdot
.3828 .42598 Mdot
.70634 .71242 Mdot
.27658 .57879 Mdot
.39219 .46858 Mdot
.51564 .58571 Mdot
.62559 .64483 Mdot
.56694 .22196 Mdot
.35573 .44747 Mdot
.63096 .47459 Mdot
.42053 .65123 Mdot
.39263 .61587 Mdot
.51304 .35233 Mdot
.20533 .64654 Mdot
.61711 .60483 Mdot
.41532 .64171 Mdot
.40472 .47226 Mdot
.58481 .63977 Mdot
.66363 .43892 Mdot
.39639 .51271 Mdot
.3534 .27992 Mdot
.40852 .6622 Mdot
.36258 .50081 Mdot
.53642 .7041 Mdot
.42674 .32107 Mdot
.53892 .17311 Mdot
.58558 .64748 Mdot
.56001 .3254 Mdot
.33688 .42319 Mdot
.2313 .64045 Mdot
.341 .47686 Mdot
.49015 .28115 Mdot
.43367 .77688 Mdot
.55899 .31633 Mdot
.41904 .45083 Mdot
.36882 .44633 Mdot
.51608 .41592 Mdot
.54823 .34352 Mdot
.43093 .43179 Mdot
.42113 .71514 Mdot
.39856 .68262 Mdot
.67748 .49573 Mdot
.40829 .67423 Mdot
.40864 .44803 Mdot
.34822 .51081 Mdot
.37403 .66037 Mdot
.69472 .76895 Mdot
.56929 .32598 Mdot
.5886 .62051 Mdot
.34825 .44203 Mdot
.38892 .41349 Mdot
.33809 .20085 Mdot
.60681 .44769 Mdot
.75281 .47731 Mdot
.6125 .32417 Mdot
.77325 .40884 Mdot
.60138 .2631 Mdot
.64129 .20674 Mdot
.43608 .20532 Mdot
.42864 .50023 Mdot
.31019 .43084 Mdot
.49287 .66909 Mdot
.62522 .65496 Mdot
.36169 .7526 Mdot
.43172 .47539 Mdot
.4159 .47071 Mdot
.60609 .47349 Mdot
.76555 .60402 Mdot
.37002 .23167 Mdot
.4957 .50177 Mdot
.53669 .3055 Mdot
.43329 .65148 Mdot
.35328 .46922 Mdot
.53354 .56539 Mdot
.63934 .42376 Mdot
.56647 .26064 Mdot
.4258 .43849 Mdot
.1814 .57046 Mdot
.53514 .76852 Mdot
.59122 .63062 Mdot
.66539 .47559 Mdot
.39125 .22152 Mdot
.43868 .47508 Mdot
.63439 .645 Mdot
.39858 .45153 Mdot
.67445 .52566 Mdot
.46805 .43269 Mdot
.52349 .33829 Mdot
.36937 .48569 Mdot
.54603 .26506 Mdot
.47448 .12677 Mdot
.5034 .35262 Mdot
.35928 .66237 Mdot
.69288 .44243 Mdot
.64666 .43969 Mdot
.37827 .6681 Mdot
.65061 .44106 Mdot
.25798 .52315 Mdot
.33858 .5703 Mdot
.52965 .31262 Mdot
.39254 .38985 Mdot
.52927 .33003 Mdot
.60428 .45933 Mdot
.42896 .48046 Mdot
.71906 .76797 Mdot
.66735 .45132 Mdot
.44949 .18594 Mdot
.6072 .64503 Mdot
.64229 .42269 Mdot
.35853 .44228 Mdot
.6678 .56775 Mdot
.65793 .43226 Mdot
.76141 .56901 Mdot
.397 .43786 Mdot
.41188 .65916 Mdot
.35907 .4617 Mdot
.36218 .42036 Mdot
.67198 .4283 Mdot
.40104 .49384 Mdot
.61219 .61352 Mdot
.37955 .69522 Mdot
.79897 .36129 Mdot
.48316 .79118 Mdot
.43979 .44138 Mdot
.40578 .46999 Mdot
.43781 .67002 Mdot
.41358 .41342 Mdot
.57632 .64421 Mdot
.25671 .78302 Mdot
.5275 .31781 Mdot
.68568 .44842 Mdot
.60069 .26109 Mdot
.39837 .40631 Mdot
.38308 .49868 Mdot
.83314 .61648 Mdot
.57227 .23502 Mdot
.60401 .61218 Mdot
.37159 .51561 Mdot
.66351 .43765 Mdot
.54497 .33606 Mdot
.57072 .65178 Mdot
.38175 .46901 Mdot
.42102 .45829 Mdot
.55843 .33525 Mdot
.34353 .36653 Mdot
.27364 .32692 Mdot
.63537 .62865 Mdot
.43299 .52192 Mdot
.66479 .41217 Mdot
.4505 .44669 Mdot
.23064 .38992 Mdot
.38106 .66344 Mdot
.59044 .66307 Mdot
.7398 .35295 Mdot
.43713 .48158 Mdot
.61769 .60871 Mdot
.61827 .63233 Mdot
.36316 .50781 Mdot
.40075 .60363 Mdot
.39276 .69778 Mdot
.39372 .68568 Mdot
.17637 .64328 Mdot
.45503 .29519 Mdot
.64135 .48865 Mdot
.62622 .64462 Mdot
.67395 .49135 Mdot
.54062 .28019 Mdot
.58547 .54205 Mdot
.67439 .48816 Mdot
.39372 .69004 Mdot
.69661 .45499 Mdot
.38014 .43912 Mdot
.6145 .63185 Mdot
.65561 .48814 Mdot
.37696 .40927 Mdot
.59663 .71681 Mdot
.67984 .69428 Mdot
.54726 .29777 Mdot
.50961 .32804 Mdot
.36457 .43912 Mdot
.65567 .50626 Mdot
.42655 .45975 Mdot
.60972 .67176 Mdot
.58365 .71662 Mdot
.34863 .44365 Mdot
.64551 .44452 Mdot
.44274 .65691 Mdot
.37871 .23071 Mdot
.43115 .51304 Mdot
.41332 .44477 Mdot
.40351 .49063 Mdot
.39808 .45147 Mdot
.79559 .53103 Mdot
.6398 .65525 Mdot
.50242 .79756 Mdot
.64887 .27069 Mdot
.40173 .63054 Mdot
.43798 .64922 Mdot
.32672 .26717 Mdot
.49851 .68228 Mdot
.62359 .64088 Mdot
.38819 .48263 Mdot
.49385 .74806 Mdot
.84401 .50243 Mdot
.78768 .69269 Mdot
.50437 .39828 Mdot
.61394 .43178 Mdot
.36593 .67105 Mdot
.677 .45532 Mdot
.4096 .48578 Mdot
.34788 .4131 Mdot
.61625 .18578 Mdot
.56916 .65936 Mdot
.52612 .31536 Mdot
.39712 .49067 Mdot
.45658 .29956 Mdot
.65705 .4692 Mdot
.65663 .42151 Mdot
.41595 .41756 Mdot
.42934 .61475 Mdot
.4295 .15603 Mdot
.58733 .63758 Mdot
.62767 .74618 Mdot
.4259 .7489 Mdot
.59268 .75647 Mdot
.59292 .63722 Mdot
.52146 .39144 Mdot
.608 .47072 Mdot
.26862 .43991 Mdot
.39845 .62873 Mdot
.51935 .34733 Mdot
.43484 .40081 Mdot
.37681 .64633 Mdot
.61534 .4686 Mdot
.41411 .65513 Mdot
.37768 .49848 Mdot
.60698 .67811 Mdot
.65135 .47468 Mdot
.56499 .67401 Mdot
.4139 .60213 Mdot
.54918 .33966 Mdot
.50957 .50375 Mdot
.33043 .68064 Mdot
.27395 .57371 Mdot
.42406 .41796 Mdot
.53626 .56849 Mdot
.36751 .45532 Mdot
.42599 .68574 Mdot
.4002 .46163 Mdot
.35814 .72019 Mdot
.66051 .47978 Mdot
.35387 .44571 Mdot
.37768 .47734 Mdot
.42301 .80028 Mdot
.41933 .43045 Mdot
.44023 .49522 Mdot
.38987 .47128 Mdot
.35357 .66352 Mdot
.38888 .38942 Mdot
.41869 .6796 Mdot
.61419 .38796 Mdot
.64233 .45832 Mdot
.51803 .30925 Mdot
.55934 .34153 Mdot
.48 .26741 Mdot
.70645 .34301 Mdot
.74967 .62796 Mdot
.40412 .67401 Mdot
.62047 .61938 Mdot
.39808 .45805 Mdot
.65754 .23529 Mdot
.57383 .45611 Mdot
.62743 .42839 Mdot
.48643 .79131 Mdot
.43555 .52493 Mdot
.57693 .21239 Mdot
.38422 .51804 Mdot
.18406 .63842 Mdot
.3804 .54014 Mdot
.46777 .44032 Mdot
.68585 .46841 Mdot
.53266 .27715 Mdot
.40049 .41382 Mdot
.39222 .70487 Mdot
.52625 .34707 Mdot
.32757 .40383 Mdot
.66652 .40459 Mdot
.62462 .39014 Mdot
.34284 .686 Mdot
.3857 .44606 Mdot
.64983 .47438 Mdot
.4285 .65414 Mdot
.34902 .24118 Mdot
.58933 .62606 Mdot
.58648 .68916 Mdot
.49867 .64249 Mdot
.70806 .74946 Mdot
.5377 .35315 Mdot
.25836 .44011 Mdot
.38801 .43033 Mdot
.72696 .42285 Mdot
.34679 .45085 Mdot
.83259 .52642 Mdot
.54164 .35624 Mdot
.38967 .69187 Mdot
.62285 .61443 Mdot
.43348 .65869 Mdot
.26811 .57763 Mdot
.59369 .45747 Mdot
.54454 .52369 Mdot
.65611 .46039 Mdot
.55876 .42043 Mdot
.39283 .66222 Mdot
.40522 .50036 Mdot
.15523 .39128 Mdot
.38197 .66748 Mdot
.37396 .63842 Mdot
.53861 .8339 Mdot
.68575 .79366 Mdot
.45197 .49917 Mdot
.37055 .67393 Mdot
.65265 .45628 Mdot
.53583 .34124 Mdot
.35989 .47297 Mdot
.38621 .44124 Mdot
.37752 .64648 Mdot
.67483 .43204 Mdot
.24162 .61559 Mdot
.62694 .45798 Mdot
.40301 .68578 Mdot
.63483 .46448 Mdot
.66357 .55907 Mdot
.67272 .47933 Mdot
.39141 .41278 Mdot
.39954 .46075 Mdot
.66262 .31023 Mdot
.41151 .64993 Mdot
.37492 .47242 Mdot
.37901 .51041 Mdot
.39779 .64784 Mdot
.56332 .38521 Mdot
.24362 .60819 Mdot
.44615 .44724 Mdot
.40665 .43262 Mdot
.55913 .3189 Mdot
.565 .56027 Mdot
.24724 .4248 Mdot
.37912 .49679 Mdot
.55336 .35327 Mdot
.39187 .70378 Mdot
.42921 .45004 Mdot
.82738 .46336 Mdot
.72439 .55128 Mdot
.42772 .48888 Mdot
.68215 .46488 Mdot
.37944 .5187 Mdot
.52367 .16972 Mdot
.40433 .41615 Mdot
.39909 .65823 Mdot
.42021 .63975 Mdot
.3637 .78276 Mdot
.3868 .65207 Mdot
.64077 .4293 Mdot
.59639 .63922 Mdot
.80873 .56632 Mdot
.66585 .4409 Mdot
.3829 .53641 Mdot
.38413 .81091 Mdot
.40557 .50828 Mdot
.3796 .41223 Mdot
.46373 .16582 Mdot
.67343 .45312 Mdot
.41773 .62281 Mdot
.51474 .46645 Mdot
.3471 .51396 Mdot
.59449 .66486 Mdot
.42867 .39565 Mdot
.43486 .41928 Mdot
.48011 .1829 Mdot
.78286 .50135 Mdot
.62814 .65995 Mdot
.44704 .47938 Mdot
.38001 .49757 Mdot
.61565 .4227 Mdot
.40095 .47017 Mdot
.53249 .34169 Mdot
.41544 .62591 Mdot
.67436 .47299 Mdot
.54113 .31714 Mdot
.4382 .46839 Mdot
.5429 .30456 Mdot
.64485 .4852 Mdot
.62745 .65724 Mdot
.41932 .48492 Mdot
.5576 .30183 Mdot
.54132 .30499 Mdot
.36813 .45879 Mdot
.41681 .65524 Mdot
.39477 .54773 Mdot
.4244 .43114 Mdot
.36494 .48548 Mdot
.38504 .63392 Mdot
.88959 .51199 Mdot
.37865 .4242 Mdot
.50505 .26965 Mdot
.38591 .62579 Mdot
.56147 .40458 Mdot
.6792 .45425 Mdot
.43148 .41706 Mdot
.62586 .65983 Mdot
.63165 .6403 Mdot
.6161 .47411 Mdot
.36734 .64764 Mdot
.61561 .31134 Mdot
.42729 .59688 Mdot
.33421 .47841 Mdot
.45422 .45508 Mdot
.29836 .71462 Mdot
.73002 .27902 Mdot
.42543 .62252 Mdot
.71981 .44979 Mdot
.48785 .52947 Mdot
.63121 .62949 Mdot
.64801 .42387 Mdot
.3648 .67192 Mdot
.39997 .61845 Mdot
.41575 .66826 Mdot
.51627 .33955 Mdot
.66742 .31318 Mdot
.41255 .60847 Mdot
.43721 .62722 Mdot
.39275 .43717 Mdot
.37911 .49551 Mdot
.38672 .23475 Mdot
.31752 .31597 Mdot
.53931 .29914 Mdot
.61892 .46993 Mdot
.15039 .61643 Mdot
.6023 .67208 Mdot
.46818 .81097 Mdot
.3644 .42345 Mdot
.09224 .485 Mdot
.3553 .45317 Mdot
.40225 .4739 Mdot
.37903 .6953 Mdot
.55227 .29735 Mdot
.52743 .32575 Mdot
.38889 .67025 Mdot
.43926 .64167 Mdot
.53152 .34101 Mdot
.68066 .73716 Mdot
.84067 .46864 Mdot
.59473 .48663 Mdot
.40157 .64254 Mdot
.33452 .65326 Mdot
.63667 .62563 Mdot
.32843 .41542 Mdot
.60521 .67472 Mdot
.65151 .46444 Mdot
.62131 .48848 Mdot
.59246 .66137 Mdot
.39803 .4391 Mdot
.64799 .4917 Mdot
.42692 .49953 Mdot
.61581 .76933 Mdot
.28299 .61896 Mdot
.62574 .2878 Mdot
.42134 .37664 Mdot
.55366 .39607 Mdot
.55057 .65925 Mdot
.43573 .45872 Mdot
.79267 .4275 Mdot
.53086 .30917 Mdot
.33965 .4102 Mdot
.58998 .66529 Mdot
.49918 .15359 Mdot
.42354 .48554 Mdot
.4014 .65783 Mdot
.62235 .63457 Mdot
.45973 .59989 Mdot
.5591 .71213 Mdot
.40184 .49001 Mdot
.11879 .45639 Mdot
.35626 .6561 Mdot
.6692 .47862 Mdot
.22142 .64394 Mdot
.4244 .61729 Mdot
.49403 .36697 Mdot
.69041 .3017 Mdot
.75983 .70195 Mdot
.42737 .63447 Mdot
.60669 .43971 Mdot
.41104 .68871 Mdot
.54695 .34215 Mdot
.36511 .69271 Mdot
.65908 .47427 Mdot
.42325 .44035 Mdot
.63485 .4478 Mdot
.51467 .32301 Mdot
.27594 .32961 Mdot
.62944 .65808 Mdot
.67803 .44432 Mdot
.60253 .65707 Mdot
.40432 .33066 Mdot
.6158 .24745 Mdot
.58273 .62888 Mdot
.2106 .53148 Mdot
.45381 .44715 Mdot
.42499 .6152 Mdot
.63432 .44418 Mdot
.74351 .39468 Mdot
.50696 .50318 Mdot
.39245 .63305 Mdot
.62658 .48112 Mdot
.50395 .63652 Mdot
.20148 .59021 Mdot
.433 .50633 Mdot
.35218 .33624 Mdot
.39854 .64185 Mdot
.60218 .45667 Mdot
.29122 .27925 Mdot
.40923 .69202 Mdot
.64836 .43452 Mdot
.62237 .61203 Mdot
.60383 .63025 Mdot
.42544 .42364 Mdot
.57165 .6732 Mdot
.63274 .4904 Mdot
.59115 .70662 Mdot
.36849 .67059 Mdot
.4658 .62763 Mdot
.55993 .30142 Mdot
.63707 .45581 Mdot
.38279 .50592 Mdot
.37137 .71558 Mdot
.70401 .54845 Mdot
.2568 .64032 Mdot
.16378 .44032 Mdot
.63008 .4498 Mdot
.40712 .62208 Mdot
.40352 .65731 Mdot
.42158 .52191 Mdot
.47866 .58196 Mdot
.61964 .3125 Mdot
.49789 .44743 Mdot
.49772 .47769 Mdot
.67532 .49938 Mdot
.58808 .43636 Mdot
.36998 .40803 Mdot
.38877 .44962 Mdot
.62959 .62554 Mdot
.42013 .43884 Mdot
.37707 .68862 Mdot
.41979 .41792 Mdot
.58779 .64619 Mdot
.66143 .46062 Mdot
.4231 .4822 Mdot
.5513 .30939 Mdot
.63901 .62386 Mdot
.5643 .63751 Mdot
.64144 .44984 Mdot
.37799 .64333 Mdot
.57822 .3675 Mdot
.62397 .46141 Mdot
.38671 .44572 Mdot
.57004 .56613 Mdot
.37193 .49755 Mdot
.3242 .51026 Mdot
.41081 .69207 Mdot
.67418 .46918 Mdot
.36995 .68698 Mdot
.60768 .65371 Mdot
.65764 .27583 Mdot
.40601 .45355 Mdot
.65458 .43602 Mdot
.72295 .49653 Mdot
.30002 .42161 Mdot
.4393 .62418 Mdot
.70246 .68315 Mdot
.43548 .66256 Mdot
.61513 .46127 Mdot
.44848 .82044 Mdot
.52647 .35308 Mdot
.62814 .42775 Mdot
.783 .33679 Mdot
.65984 .44715 Mdot
.41122 .42347 Mdot
.36663 .43819 Mdot
.67316 .47585 Mdot
.5604 .33174 Mdot
.39027 .21268 Mdot
.68878 .48653 Mdot
.42088 .62576 Mdot
.61557 .78008 Mdot
.20681 .35432 Mdot
.65178 .64201 Mdot
.62657 .62284 Mdot
.37379 .54012 Mdot
.4604 .47028 Mdot
.58334 .66494 Mdot
.56008 .65281 Mdot
.51387 .34441 Mdot
.63148 .44051 Mdot
.35678 .70882 Mdot
.58175 .61302 Mdot
.42264 .56667 Mdot
.69574 .33543 Mdot
.43687 .5062 Mdot
.4359 .74985 Mdot
.35505 .43694 Mdot
.48723 .32312 Mdot
.58689 .64699 Mdot
.36144 .49545 Mdot
.40115 .52621 Mdot
.61477 .66698 Mdot
.53484 .34328 Mdot
.54036 .61398 Mdot
.63866 .46884 Mdot
.86363 .4576 Mdot
.41544 .51173 Mdot
.40763 .42114 Mdot
.62167 .65643 Mdot
.62272 .35965 Mdot
.40633 .62828 Mdot
.42818 .67641 Mdot
.66617 .48963 Mdot
.49862 .53596 Mdot
.43714 .42507 Mdot
.43323 .44909 Mdot
.64403 .47557 Mdot
.65282 .42658 Mdot
.72992 .62906 Mdot
.37201 .43958 Mdot
.61792 .64126 Mdot
.55789 .27463 Mdot
.58718 .64989 Mdot
.37512 .50011 Mdot
.40109 .42236 Mdot
.39367 .41211 Mdot
.38216 .50499 Mdot
.56314 .65841 Mdot
.35425 .48017 Mdot
.35469 .40303 Mdot
.40157 .6241 Mdot
.3895 .49348 Mdot
.49974 .46989 Mdot
.41247 .43884 Mdot
.53453 .34088 Mdot
.2381 .44705 Mdot
.4232 .48534 Mdot
.43082 .41852 Mdot
.6911 .45371 Mdot
.41584 .45642 Mdot
.60651 .67233 Mdot
.40837 .64186 Mdot
.62514 .64598 Mdot
.63206 .64293 Mdot
.64245 .50095 Mdot
.51699 .36055 Mdot
.4033 .40543 Mdot
.51707 .32714 Mdot
.37276 .52791 Mdot
.43703 .48239 Mdot
.67486 .29654 Mdot
.19287 .65347 Mdot
.24956 .35637 Mdot
.40524 .45197 Mdot
.67122 .45268 Mdot
.67867 .45818 Mdot
.32639 .3953 Mdot
.4283 .51021 Mdot
.57353 .64341 Mdot
.63262 .63511 Mdot
.35564 .28331 Mdot
.52118 .20315 Mdot
.5345 .34156 Mdot
.55792 .54936 Mdot
.44123 .48481 Mdot
.37112 .50168 Mdot
.40278 .51231 Mdot
.67095 .49262 Mdot
.49599 .39653 Mdot
.63696 .42572 Mdot
.54265 .77383 Mdot
.60088 .66326 Mdot
.41308 .48911 Mdot
.45336 .76535 Mdot
.38224 .67757 Mdot
.40864 .64307 Mdot
.56724 .63243 Mdot
.62619 .40865 Mdot
.35214 .25794 Mdot
.78244 .70648 Mdot
.36153 .64627 Mdot
.53739 .29376 Mdot
.43885 .45529 Mdot
.65935 .45437 Mdot
.40051 .68917 Mdot
.53362 .29604 Mdot
.41239 .49793 Mdot
.66872 .31338 Mdot
.40235 .44748 Mdot
.48121 .69479 Mdot
.42198 .65733 Mdot
.83696 .5136 Mdot
.37102 .63756 Mdot
.63911 .62206 Mdot
.58323 .65692 Mdot
.37869 .42903 Mdot
.26818 .69427 Mdot
.43482 .63307 Mdot
.58784 .56868 Mdot
.53044 .35947 Mdot
.68857 .55917 Mdot
.54167 .34536 Mdot
.66623 .47908 Mdot
.52849 .34988 Mdot
.65927 .47671 Mdot
.31858 .30159 Mdot
.36211 .6327 Mdot
.5357 .31329 Mdot
.70768 .50696 Mdot
.45786 .48122 Mdot
.54443 .29957 Mdot
.33873 .43503 Mdot
.31251 .48904 Mdot
.64027 .47491 Mdot
.54025 .35418 Mdot
.40277 .50182 Mdot
.61918 .19902 Mdot
.5964 .61436 Mdot
.57507 .64831 Mdot
.33705 .44851 Mdot
.6693 .50342 Mdot
.37934 .70163 Mdot
.81498 .5171 Mdot
.63191 .60004 Mdot
.3774 .42668 Mdot
.40615 .41344 Mdot
.43818 .64579 Mdot
.42862 .78118 Mdot
.38752 .42591 Mdot
.47431 .49292 Mdot
.37162 .43818 Mdot
.58742 .61649 Mdot
.43372 .65606 Mdot
.40579 .65154 Mdot
.63102 .48476 Mdot
.37378 .66936 Mdot
.32525 .38561 Mdot
.47909 .76545 Mdot
.44973 .5206 Mdot
.60303 .65079 Mdot
.51643 .77127 Mdot
.53988 .77599 Mdot
.74956 .30654 Mdot
.42453 .60224 Mdot
.34771 .45108 Mdot
.37264 .65007 Mdot
.54316 .33854 Mdot
.41061 .66064 Mdot
.36631 .67253 Mdot
.42916 .46116 Mdot
.40245 .48727 Mdot
.66682 .46675 Mdot
.47605 .56866 Mdot
.38043 .63511 Mdot
.35553 .45642 Mdot
.4632 .46013 Mdot
.41674 .50588 Mdot
.6218 .55355 Mdot
.42963 .62903 Mdot
.60114 .81607 Mdot
.44069 .24309 Mdot
.38011 .63613 Mdot
.44478 .15021 Mdot
.71914 .50838 Mdot
.61469 .49182 Mdot
.56139 .6763 Mdot
.36764 .4435 Mdot
.66652 .4367 Mdot
.41058 .48563 Mdot
.43809 .74878 Mdot
.41901 .46303 Mdot
.53103 .34289 Mdot
.42815 .50077 Mdot
.61548 .47949 Mdot
.62655 .45613 Mdot
.39055 .41972 Mdot
.4218 .48064 Mdot
.29434 .30707 Mdot
.41141 .59042 Mdot
.4129 .64165 Mdot
.60927 .31699 Mdot
.54564 .31313 Mdot
.5917 .66347 Mdot
.39512 .46782 Mdot
.6536 .50202 Mdot
.62804 .45346 Mdot
.42952 .62513 Mdot
.62764 .47511 Mdot
.58823 .63699 Mdot
.40519 .45785 Mdot
.5812 .66247 Mdot
.51604 .34222 Mdot
.43361 .64519 Mdot
.39466 .49229 Mdot
.39322 .43699 Mdot
.42039 .6397 Mdot
.38439 .40428 Mdot
.55948 .32321 Mdot
.65683 .44429 Mdot
.42979 .64163 Mdot
.59825 .63671 Mdot
.66495 .47813 Mdot
.36141 .48324 Mdot
.14166 .5539 Mdot
.41127 .42581 Mdot
.36078 .45465 Mdot
.77628 .31742 Mdot
.43692 .49306 Mdot
.63103 .44742 Mdot
.39368 .69223 Mdot
.42718 .38104 Mdot
.46634 .26391 Mdot
.87341 .58641 Mdot
.62848 .42865 Mdot
.43903 .45061 Mdot
.67778 .24624 Mdot
.43451 .44305 Mdot
.30274 .70203 Mdot
.64926 .52082 Mdot
.5419 .43732 Mdot
.34009 .45888 Mdot
.60366 .6219 Mdot
.66935 .46447 Mdot
.65704 .48063 Mdot
.57805 .80399 Mdot
.43101 .45708 Mdot
.52549 .60444 Mdot
.39905 .49866 Mdot
.59729 .63306 Mdot
.38326 .26694 Mdot
.62591 .4544 Mdot
.18607 .4307 Mdot
.36824 .45227 Mdot
.40614 .61515 Mdot
.69741 .45474 Mdot
.64536 .56797 Mdot
.36372 .48277 Mdot
.52422 .31273 Mdot
.60311 .59932 Mdot
.45551 .40902 Mdot
.59865 .64825 Mdot
.367 .48832 Mdot
.48476 .43258 Mdot
.224 .6578 Mdot
.41668 .66156 Mdot
.62448 .61568 Mdot
.59559 .55309 Mdot
.34949 .47136 Mdot
.42812 .63718 Mdot
.39675 .62915 Mdot
.51411 .33323 Mdot
.56769 .51414 Mdot
.52716 .69023 Mdot
.30566 .65043 Mdot
.60063 .79156 Mdot
.6933 .44872 Mdot
.76639 .54544 Mdot
.36512 .47083 Mdot
.58555 .2832 Mdot
.61794 .66806 Mdot
.41632 .42542 Mdot
.26619 .46418 Mdot
.38677 .67594 Mdot
.40238 .42963 Mdot
.52955 .332 Mdot
.59646 .33084 Mdot
.57778 .27912 Mdot
.69642 .29737 Mdot
.65467 .46118 Mdot
.34438 .41545 Mdot
.47904 .42043 Mdot
.68436 .46688 Mdot
.43333 .41529 Mdot
.64843 .43728 Mdot
.69258 .74316 Mdot
.54481 .29721 Mdot
.42367 .62342 Mdot
.65511 .54931 Mdot
.41788 .40747 Mdot
.45588 .44389 Mdot
.50828 .35146 Mdot
.38481 .45231 Mdot
.19773 .63135 Mdot
.63986 .5471 Mdot
.65748 .48933 Mdot
.41596 .66675 Mdot
.42188 .41274 Mdot
.58252 .52704 Mdot
.42735 .43465 Mdot
.32684 .58156 Mdot
.42903 .41764 Mdot
.54006 .6945 Mdot
.41998 .65168 Mdot
.59855 .65182 Mdot
.34855 .47632 Mdot
.41415 .46833 Mdot
.5094 .24086 Mdot
.37085 .53361 Mdot
.35416 .48525 Mdot
.4321 .68728 Mdot
.40218 .69042 Mdot
.41563 .68195 Mdot
.60893 .45629 Mdot
.49866 .19051 Mdot
.61541 .64757 Mdot
.39986 .38002 Mdot
.58737 .61154 Mdot
.24541 .64493 Mdot
.53742 .29455 Mdot
.70133 .28028 Mdot
.38299 .47524 Mdot
.40225 .67967 Mdot
.78349 .46486 Mdot
.40541 .70254 Mdot
.5433 .55067 Mdot
.61694 .63159 Mdot
.38507 .6686 Mdot
.40751 .47301 Mdot
.49745 .51654 Mdot
.63233 .22627 Mdot
.6167 .6538 Mdot
.3872 .53762 Mdot
.60827 .44568 Mdot
.62629 .27638 Mdot
.14658 .52058 Mdot
.5959 .6141 Mdot
.61684 .68221 Mdot
.43259 .45667 Mdot
.38267 .6807 Mdot
.59897 .62504 Mdot
.58082 .62488 Mdot
.62916 .47752 Mdot
.39795 .48803 Mdot
.39222 .48811 Mdot
.61353 .45904 Mdot
.62476 .64881 Mdot
.33692 .46306 Mdot
.46823 .43209 Mdot
.58615 .16598 Mdot
.4932 .62577 Mdot
.8705 .46465 Mdot
.33638 .37981 Mdot
.25164 .47678 Mdot
.82057 .52494 Mdot
.39319 .61983 Mdot
.43324 .48059 Mdot
.45677 .4213 Mdot
.63142 .48962 Mdot
.41507 .448 Mdot
.62333 .50687 Mdot
.62578 .63223 Mdot
.48991 .15931 Mdot
.52652 .74952 Mdot
.72835 .71937 Mdot
.41692 .44864 Mdot
.35653 .72178 Mdot
.54195 .32794 Mdot
.64713 .63916 Mdot
.42517 .67396 Mdot
.39191 .50678 Mdot
.29124 .30967 Mdot
.63294 .42637 Mdot
.38191 .64768 Mdot
.34868 .24357 Mdot
.53682 .39672 Mdot
.37471 .49858 Mdot
.6137 .4414 Mdot
.79616 .45173 Mdot
.43364 .58376 Mdot
.64011 .60465 Mdot
.53365 .34456 Mdot
.67209 .46391 Mdot
.63377 .63631 Mdot
.36277 .71661 Mdot
.38554 .66001 Mdot
.37757 .70386 Mdot
.24328 .38712 Mdot
.68551 .45184 Mdot
.54065 .32368 Mdot
.54953 .21932 Mdot
.51882 .21898 Mdot
.52933 .34081 Mdot
.61756 .48518 Mdot
.40179 .68999 Mdot
.39265 .67378 Mdot
.40793 .64142 Mdot
.22003 .38206 Mdot
.38494 .6231 Mdot
.50521 .81515 Mdot
.41084 .50545 Mdot
.47212 .49098 Mdot
.43741 .44939 Mdot
.57514 .65206 Mdot
.42467 .64615 Mdot
.51664 .48844 Mdot
.38082 .52613 Mdot
.63787 .24704 Mdot
.41921 .42286 Mdot
.62832 .66986 Mdot
.39215 .43231 Mdot
.37313 .76246 Mdot
.37452 .64359 Mdot
.40898 .45032 Mdot
.63018 .66375 Mdot
.55046 .318 Mdot
.44193 .63252 Mdot
.40305 .49059 Mdot
.73129 .66031 Mdot
.43366 .4965 Mdot
.73295 .70523 Mdot
.473 .64268 Mdot
.53781 .29376 Mdot
.443 .72253 Mdot
.63179 .4201 Mdot
.47895 .47226 Mdot
.33544 .49502 Mdot
.60868 .65723 Mdot
.68593 .54463 Mdot
.64439 .45741 Mdot
.50121 .39632 Mdot
.41653 .39109 Mdot
.51489 .31889 Mdot
.40981 .58546 Mdot
.58223 .66549 Mdot
.44341 .42274 Mdot
.41624 .52272 Mdot
.56777 .78846 Mdot
.37614 .3964 Mdot
.41531 .41473 Mdot
.50679 .33312 Mdot
.49946 .80845 Mdot
.40818 .43873 Mdot
.55079 .54678 Mdot
.36221 .68494 Mdot
.33746 .48728 Mdot
.48688 .81658 Mdot
.36484 .4392 Mdot
.37995 .65737 Mdot
.39076 .56928 Mdot
.50857 .67208 Mdot
.52195 .36122 Mdot
.43302 .41911 Mdot
.36845 .78697 Mdot
.37418 .44863 Mdot
.61409 .64311 Mdot
.43731 .49929 Mdot
.65769 .47169 Mdot
.25018 .34649 Mdot
.63891 .49051 Mdot
.4431 .4369 Mdot
.40546 .63988 Mdot
.61384 .66221 Mdot
.20343 .42681 Mdot
.64845 .31925 Mdot
.4786 .80758 Mdot
.802 .65723 Mdot
.54527 .35008 Mdot
.52903 .3696 Mdot
.58645 .66938 Mdot
.4085 .44863 Mdot
.49246 .83386 Mdot
.38043 .54104 Mdot
.40462 .43253 Mdot
.41942 .46436 Mdot
.60079 .24583 Mdot
.62954 .63462 Mdot
.63182 .46999 Mdot
.39339 .42411 Mdot
.35424 .48226 Mdot
.39392 .62007 Mdot
.5464 .30941 Mdot
.67908 .45455 Mdot
.52754 .31595 Mdot
.6666 .45956 Mdot
.46376 .15201 Mdot
.37201 .51373 Mdot
.55027 .32296 Mdot
.58811 .60657 Mdot
.37999 .642 Mdot
.48063 .76035 Mdot
.66174 .48085 Mdot
.61962 .47706 Mdot
.40316 .41768 Mdot
.37874 .66046 Mdot
.37458 .69242 Mdot
.54567 .33804 Mdot
.58369 .63243 Mdot
.42406 .48444 Mdot
.44086 .47878 Mdot
.3781 .58758 Mdot
.66425 .50224 Mdot
.47311 .70518 Mdot
.77138 .57373 Mdot
.40577 .44959 Mdot
.36952 .67364 Mdot
.42358 .47397 Mdot
.79647 .57313 Mdot
.37824 .67547 Mdot
.36117 .4422 Mdot
.38281 .19715 Mdot
.61936 .40927 Mdot
.50711 .70332 Mdot
.38963 .41514 Mdot
.82956 .58625 Mdot
.37213 .47471 Mdot
.52134 .14135 Mdot
.73139 .41041 Mdot
.45107 .44629 Mdot
.35795 .47407 Mdot
.26389 .61983 Mdot
.44282 .46099 Mdot
.6145 .46406 Mdot
.42629 .20905 Mdot
.39087 .70583 Mdot
.65098 .71343 Mdot
.2444 .44591 Mdot
.54157 .35578 Mdot
.66669 .48915 Mdot
.5882 .4533 Mdot
.52408 .33261 Mdot
.40071 .64571 Mdot
.39788 .45164 Mdot
.51624 .53132 Mdot
.67498 .49531 Mdot
.36329 .3723 Mdot
.61326 .64093 Mdot
.71911 .58263 Mdot
.58517 .49184 Mdot
.59405 .64481 Mdot
.38534 .49307 Mdot
.25533 .61748 Mdot
.27692 .3741 Mdot
.83895 .44685 Mdot
.63496 .63587 Mdot
.61624 .65597 Mdot
.23412 .35949 Mdot
.55116 .28726 Mdot
.59728 .77546 Mdot
.54951 .70273 Mdot
.59977 .66622 Mdot
.45302 .60661 Mdot
.62749 .43339 Mdot
.54987 .64445 Mdot
.34738 .40442 Mdot
.43009 .49237 Mdot
.40954 .47144 Mdot
.58143 .63857 Mdot
.30372 .41847 Mdot
.21145 .6308 Mdot
.60078 .65777 Mdot
.333 .50433 Mdot
.54908 .47896 Mdot
.74324 .46948 Mdot
.61885 .45957 Mdot
.51887 .35912 Mdot
.56058 .35668 Mdot
.4081 .61741 Mdot
.51788 .35991 Mdot
.59651 .31778 Mdot
.38642 .45872 Mdot
.59165 .65557 Mdot
.69789 .55135 Mdot
.60318 .63436 Mdot
.52502 .32889 Mdot
.52292 .30006 Mdot
.40198 .62431 Mdot
.41295 .64844 Mdot
.24323 .50942 Mdot
.38569 .29201 Mdot
.42689 .42992 Mdot
.74605 .36901 Mdot
.36874 .67974 Mdot
.37216 .36849 Mdot
.51446 .35802 Mdot
.54813 .31397 Mdot
.51283 .24896 Mdot
.38856 .47648 Mdot
.32742 .73005 Mdot
.39166 .47333 Mdot
.38402 .27255 Mdot
.36326 .42655 Mdot
.62832 .47661 Mdot
.38617 .48205 Mdot
.53109 .24212 Mdot
.42059 .40392 Mdot
.45642 .47916 Mdot
.66487 .49779 Mdot
.4489 .40065 Mdot
.65551 .47118 Mdot
.4384 .43395 Mdot
.56513 .32611 Mdot
.65472 .49629 Mdot
.45975 .28457 Mdot
.51929 .25513 Mdot
.61198 .47912 Mdot
.51678 .3201 Mdot
.55445 .34799 Mdot
.46994 .31117 Mdot
.42523 .6742 Mdot
.3242 .4794 Mdot
.41136 .44697 Mdot
.65633 .42465 Mdot
.62898 .62901 Mdot
.35394 .46709 Mdot
.462 .45595 Mdot
.36843 .42706 Mdot
.40915 .61676 Mdot
.62248 .30888 Mdot
.54981 .33099 Mdot
.61349 .4508 Mdot
.57786 .37404 Mdot
.66849 .50577 Mdot
.43698 .50249 Mdot
.448 .41222 Mdot
.25571 .45347 Mdot
.74834 .50281 Mdot
.21759 .37066 Mdot
.38478 .65792 Mdot
.68151 .4642 Mdot
.56359 .31094 Mdot
.47059 .45233 Mdot
.40035 .68312 Mdot
.65854 .4739 Mdot
.40221 .44834 Mdot
.3932 .53972 Mdot
.5055 .78496 Mdot
.33881 .36309 Mdot
.49201 .27232 Mdot
.61576 .47447 Mdot
.61959 .42656 Mdot
.55409 .24491 Mdot
.49872 .3308 Mdot
.50932 .50055 Mdot
.42739 .44705 Mdot
.52336 .31498 Mdot
.39969 .689 Mdot
.25309 .38651 Mdot
.57846 .64542 Mdot
.47655 .57524 Mdot
.4154 .45001 Mdot
.54697 .41343 Mdot
.40527 .63744 Mdot
.53103 .33482 Mdot
.5811 .64107 Mdot
.52295 .3734 Mdot
.6781 .4824 Mdot
.7303 .74073 Mdot
.37836 .44887 Mdot
.41165 .41714 Mdot
.64071 .63735 Mdot
.39124 .68242 Mdot
.51164 .36065 Mdot
.62573 .77064 Mdot
.6488 .48469 Mdot
.47103 .8317 Mdot
.37335 .6788 Mdot
.34644 .64207 Mdot
.61851 .44514 Mdot
.57031 .62904 Mdot
.45893 .30527 Mdot
.58857 .64251 Mdot
.43711 .42796 Mdot
.40442 .66798 Mdot
.61985 .61545 Mdot
.47087 .58392 Mdot
.66363 .2348 Mdot
.33827 .65278 Mdot
.39135 .46127 Mdot
.57771 .18459 Mdot
.72439 .6942 Mdot
.40393 .59245 Mdot
.62906 .65706 Mdot
.41903 .42452 Mdot
.44982 .43414 Mdot
.37562 .44606 Mdot
.61913 .62179 Mdot
.72448 .34929 Mdot
.64258 .47736 Mdot
.43536 .45338 Mdot
.51388 .34288 Mdot
.64979 .46618 Mdot
.65145 .55292 Mdot
.62086 .46028 Mdot
.41779 .59971 Mdot
.44341 .49381 Mdot
.63459 .58339 Mdot
.44644 .13112 Mdot
.62224 .64875 Mdot
.62763 .4948 Mdot
.384 .51516 Mdot
.72238 .53856 Mdot
.41153 .68404 Mdot
.64689 .48573 Mdot
.40883 .42127 Mdot
.66028 .54473 Mdot
.26542 .34068 Mdot
.62236 .45804 Mdot
.39888 .68539 Mdot
.82532 .43026 Mdot
.41855 .44227 Mdot
.3714 .46736 Mdot
.38915 .66662 Mdot
.20788 .55849 Mdot
.30511 .26979 Mdot
.4225 .47827 Mdot
.59701 .65204 Mdot
.6219 .82863 Mdot
.46253 .46803 Mdot
.43162 .23773 Mdot
.66877 .46669 Mdot
.55668 .60591 Mdot
.49233 .66311 Mdot
.47026 .45451 Mdot
.61453 .76828 Mdot
.60113 .68702 Mdot
.57348 .20082 Mdot
.62937 .5098 Mdot
.68763 .40039 Mdot
.53321 .17444 Mdot
.62082 .67207 Mdot
.37854 .60079 Mdot
.6385 .74471 Mdot
.17556 .49963 Mdot
.81917 .45033 Mdot
.64658 .37954 Mdot
.29218 .30656 Mdot
.52652 .50828 Mdot
.66673 .45258 Mdot
.55959 .37565 Mdot
.40953 .48752 Mdot
.72941 .68961 Mdot
.33962 .74332 Mdot
.27972 .71375 Mdot
.58178 .18481 Mdot
.29829 .68679 Mdot
.66164 .2403 Mdot
.75858 .31035 Mdot
.28502 .41703 Mdot
.76065 .4921 Mdot
.47133 .83542 Mdot
.42259 .19115 Mdot
.62001 .79311 Mdot
.44713 .52511 Mdot
.53399 .56507 Mdot
.77259 .67629 Mdot
.34651 .7003 Mdot
.21107 .61467 Mdot
.63573 .48646 Mdot
.41174 .6931 Mdot
.63535 .74011 Mdot
.43652 .66132 Mdot
.50241 .66444 Mdot
.83013 .42665 Mdot
.67879 .24119 Mdot
.39588 .78302 Mdot
.83209 .54572 Mdot
.26716 .47648 Mdot
.34191 .81446 Mdot
.6832 .49156 Mdot
.42027 .61472 Mdot
.50637 .28647 Mdot
.5417 .23222 Mdot
.56859 .76347 Mdot
.66977 .73158 Mdot
.65859 .29071 Mdot
.40124 .31697 Mdot
.4018 .65559 Mdot
.4602 .70337 Mdot
.57337 .5841 Mdot
.52922 .75444 Mdot
.4138 .20984 Mdot
.78318 .36656 Mdot
.51128 .54612 Mdot
.68513 .69902 Mdot
.73962 .56892 Mdot
.15057 .50791 Mdot
.45553 .24399 Mdot
.41819 .36638 Mdot
.5066 .64989 Mdot
.8151 .53887 Mdot
.1884 .51092 Mdot
.36115 .29666 Mdot
.53556 .22837 Mdot
.42565 .17569 Mdot
.78615 .61951 Mdot
.27631 .25102 Mdot
.4029 .70831 Mdot
.40943 .4131 Mdot
.21848 .54601 Mdot
.37936 .79405 Mdot
.52793 .29341 Mdot
.71526 .3191 Mdot
.52824 .35722 Mdot
.3873 .61481 Mdot
.27468 .31669 Mdot
.4871 .81363 Mdot
.38699 .80445 Mdot
.55558 .35807 Mdot
.4283 .37907 Mdot
.77351 .75054 Mdot
.60713 .22474 Mdot
.50434 .73196 Mdot
.56932 .15891 Mdot
.53205 .43305 Mdot
.4615 .61311 Mdot
.62122 .61761 Mdot
.52681 .16553 Mdot
.39695 .67199 Mdot
.30195 .21573 Mdot
.51294 .14279 Mdot
.25694 .41654 Mdot
.88261 .37155 Mdot
.5669 .24571 Mdot
.54195 .432 Mdot
.6277 .69695 Mdot
.44162 .27213 Mdot
.18836 .58661 Mdot
.43744 .35516 Mdot
.72712 .54469 Mdot
.82366 .63064 Mdot
.56356 .18823 Mdot
.41492 .81458 Mdot
.69322 .76251 Mdot
.1757 .5227 Mdot
.58306 .53439 Mdot
.34183 .40139 Mdot
.59629 .50642 Mdot
.77422 .37327 Mdot
.43874 .16044 Mdot
.44609 .23972 Mdot
.87094 .5979 Mdot
.50208 .33853 Mdot
.69738 .34978 Mdot
.83312 .40342 Mdot
.42034 .31937 Mdot
.47716 .66791 Mdot
.45441 .21208 Mdot
.42786 .37395 Mdot
.58608 .34825 Mdot
.73942 .34028 Mdot
.47985 .72286 Mdot
.44532 .1996 Mdot
.80865 .47806 Mdot
.56402 .78871 Mdot
.2917 .61959 Mdot
.50339 .2077 Mdot
.41995 .69759 Mdot
.3798 .30905 Mdot
.48558 .64975 Mdot
.66733 .22861 Mdot
.59207 .67926 Mdot
.70176 .23732 Mdot
.30814 .27066 Mdot
.34937 .49582 Mdot
.36446 .53604 Mdot
.41557 .71164 Mdot
.39524 .29696 Mdot
.45363 .40117 Mdot
.5306 .78296 Mdot
.72599 .27155 Mdot
.28086 .46179 Mdot
.54562 .60632 Mdot
.68509 .54178 Mdot
.84005 .41902 Mdot
.23338 .54807 Mdot
.49738 .33348 Mdot
.38066 .24659 Mdot
.15927 .53152 Mdot
.63962 .46065 Mdot
.42432 .81412 Mdot
.63816 .6005 Mdot
.25933 .35977 Mdot
.30556 .65537 Mdot
.22156 .4664 Mdot
.72714 .2723 Mdot
.6206 .38733 Mdot
.29184 .29368 Mdot
.41518 .33485 Mdot
.54743 .83532 Mdot
.74384 .47293 Mdot
.43092 .39683 Mdot
.68843 .70827 Mdot
.56089 .3307 Mdot
.25994 .56359 Mdot
.6106 .8202 Mdot
.64555 .35633 Mdot
.36254 .40712 Mdot
.25494 .40737 Mdot
.62639 .40313 Mdot
.49466 .52367 Mdot
.18287 .37699 Mdot
.44622 .49637 Mdot
.53987 .21579 Mdot
.77555 .63746 Mdot
.42279 .2696 Mdot
.83988 .48811 Mdot
.79953 .54419 Mdot
.31346 .21872 Mdot
.55931 .16453 Mdot
.63745 .31864 Mdot
.52799 .17871 Mdot
.63121 .19692 Mdot
.30228 .23374 Mdot
.34346 .51338 Mdot
.64181 .62831 Mdot
.12611 .53371 Mdot
.61851 .4547 Mdot
.57548 .2249 Mdot
.59961 .79237 Mdot
.61149 .53303 Mdot
.36371 .72614 Mdot
.45216 .37336 Mdot
.52646 .5188 Mdot
.40225 .59473 Mdot
.44756 .3974 Mdot
.21966 .33886 Mdot
.35941 .19371 Mdot
.25538 .285 Mdot
.80639 .61309 Mdot
.50739 .17 Mdot
.55097 .43817 Mdot
.41013 .78756 Mdot
.33006 .39426 Mdot
.41102 .50194 Mdot
.49176 .35941 Mdot
.56876 .24637 Mdot
.24557 .41459 Mdot
.56723 .74454 Mdot
.406 .58426 Mdot
.72727 .33008 Mdot
.45125 .90502 Mdot
.25765 .50909 Mdot
.5169 .82227 Mdot
.56652 .2614 Mdot
.3956 .2855 Mdot
.76739 .37493 Mdot
.23584 .44028 Mdot
.77132 .317 Mdot
.39231 .60266 Mdot
.61826 .78957 Mdot
.66787 .37691 Mdot
.47217 .52742 Mdot
.62617 .30534 Mdot
.69667 .2607 Mdot
.67212 .66001 Mdot
.21708 .43139 Mdot
.58234 .72194 Mdot
.20714 .53099 Mdot
.69686 .50995 Mdot
.72565 .58798 Mdot
.59246 .82267 Mdot
.78383 .5252 Mdot
.40215 .25758 Mdot
.54992 .49373 Mdot
.42511 .73936 Mdot
.60156 .68843 Mdot
.40829 .25689 Mdot
.50066 .45727 Mdot
.52375 .19082 Mdot
.40217 .11588 Mdot
.18535 .40843 Mdot
.86049 .46704 Mdot
.7554 .37344 Mdot
.38096 .40094 Mdot
.79974 .34697 Mdot
.24405 .28511 Mdot
.48214 .12575 Mdot
.70935 .62152 Mdot
.64443 .51443 Mdot
.57547 .62257 Mdot
.23972 .32401 Mdot
.71603 .34392 Mdot
.79368 .35783 Mdot
.47572 .21734 Mdot
.56419 .63281 Mdot
.20139 .668 Mdot
.42367 .1807 Mdot
.31901 .65868 Mdot
.33616 .36462 Mdot
.3534 .42592 Mdot
.35906 .74906 Mdot
.43755 .65469 Mdot
.76141 .55527 Mdot
.37518 .29826 Mdot
.63452 .45451 Mdot
.49501 .30718 Mdot
.68062 .72375 Mdot
.42817 .5005 Mdot
.59137 .54958 Mdot
.43214 .61512 Mdot
.75166 .502 Mdot
.49829 .76737 Mdot
.42649 .15584 Mdot
.5985 .26486 Mdot
.34079 .46486 Mdot
.42522 .26429 Mdot
.62029 .29967 Mdot
.29164 .2784 Mdot
.58106 .6677 Mdot
.60415 .19469 Mdot
.51593 .57052 Mdot
.37846 .30751 Mdot
.34874 .74129 Mdot
.31564 .49145 Mdot
.45724 .45151 Mdot
.79747 .51372 Mdot
.31769 .56125 Mdot
.47902 .55616 Mdot
.36095 .3929 Mdot
.31586 .42985 Mdot
.80744 .35668 Mdot
.59523 .33699 Mdot
.72659 .57268 Mdot
.63093 .20703 Mdot
.61217 .62476 Mdot
.37199 .65437 Mdot
.5686 .3513 Mdot
.64809 .76298 Mdot
.33413 .5594 Mdot
.26407 .34223 Mdot
.59993 .51888 Mdot
.65718 .35123 Mdot
.64198 .21728 Mdot
.60039 .19889 Mdot
.32308 .75443 Mdot
.4138 .58696 Mdot
.2918 .41477 Mdot
.63619 .77741 Mdot
.39827 .69524 Mdot
.53212 .79661 Mdot
.51771 .79355 Mdot
.46633 .16246 Mdot
.58432 .56024 Mdot
.82787 .61773 Mdot
.48553 .27507 Mdot
.70606 .31719 Mdot
.20159 .42652 Mdot
.57832 .82413 Mdot
.67339 .25346 Mdot
.4444 .59941 Mdot
.27372 .64362 Mdot
.45797 .51108 Mdot
.42721 .76098 Mdot
.1529 .58319 Mdot
.57385 .31559 Mdot
.34243 .65957 Mdot
.81118 .47684 Mdot
.39126 .44839 Mdot
.17125 .4273 Mdot
.65876 .74711 Mdot
.22835 .36456 Mdot
.56952 .62416 Mdot
.3818 .49727 Mdot
.43078 .40935 Mdot
.41805 .23159 Mdot
.50779 .67617 Mdot
.5098 .19087 Mdot
.64209 .81036 Mdot
.80069 .44175 Mdot
.33823 .74037 Mdot
.5581 .22641 Mdot
.79141 .373 Mdot
.7368 .68143 Mdot
.5623 .52107 Mdot
.57644 .25286 Mdot
.43636 .31448 Mdot
.82749 .55477 Mdot
.50381 .46439 Mdot
.57373 .69393 Mdot
.57345 .77055 Mdot
.77596 .57286 Mdot
.23172 .40299 Mdot
.37059 .48665 Mdot
.34908 .24334 Mdot
.77171 .33052 Mdot
.32954 .75106 Mdot
.17957 .58884 Mdot
.18802 .39701 Mdot
.32229 .60132 Mdot
.78522 .55896 Mdot
.71454 .69832 Mdot
.54836 .84871 Mdot
.51348 .57808 Mdot
.65679 .25704 Mdot
.42865 .32527 Mdot
.63813 .21331 Mdot
.64193 .63998 Mdot
.56196 .71913 Mdot
.68883 .53881 Mdot
.52208 .18321 Mdot
.24214 .57296 Mdot
.72208 .27921 Mdot
.53203 .45488 Mdot
.32418 .2077 Mdot
.78047 .50573 Mdot
.53185 .49166 Mdot
.67873 .47429 Mdot
.61124 .38404 Mdot
.7263 .31295 Mdot
.76213 .46092 Mdot
.56395 .82447 Mdot
.60217 .47544 Mdot
.56237 .3663 Mdot
.31952 .68534 Mdot
.36061 .3303 Mdot
.79993 .52067 Mdot
.42521 .26468 Mdot
.70406 .25611 Mdot
.43681 .21417 Mdot
.34353 .24971 Mdot
.58131 .2418 Mdot
.78924 .6868 Mdot
.50362 .72691 Mdot
.58646 .30383 Mdot
.66775 .73876 Mdot
.71457 .36654 Mdot
.45644 .61957 Mdot
.10861 .37488 Mdot
.73833 .72761 Mdot
.77092 .49622 Mdot
.4395 .16069 Mdot
.80527 .55913 Mdot
.74886 .50736 Mdot
.19139 .55955 Mdot
.49528 .62325 Mdot
.32158 .28846 Mdot
.41842 .46442 Mdot
.21759 .33135 Mdot
.35936 .32031 Mdot
.40697 .16367 Mdot
.80517 .36949 Mdot
.34654 .72448 Mdot
.44514 .4897 Mdot
.61303 .44734 Mdot
.52311 .62074 Mdot
.32167 .33496 Mdot
.23423 .59839 Mdot
.46331 .68054 Mdot
.67651 .53468 Mdot
.68546 .46147 Mdot
.61159 .30183 Mdot
.36189 .64661 Mdot
.70939 .33093 Mdot
.77382 .56819 Mdot
.6707 .42119 Mdot
.50419 .5581 Mdot
.40477 .26649 Mdot
.48857 .66904 Mdot
.32196 .65445 Mdot
.23657 .43416 Mdot
.64617 .59127 Mdot
.61841 .46643 Mdot
.3111 .64347 Mdot
.76896 .68485 Mdot
.79801 .45741 Mdot
.42503 .17327 Mdot
.58031 .3822 Mdot
.254 .64127 Mdot
.40978 .25047 Mdot
.19478 .60536 Mdot
.24686 .66486 Mdot
.74164 .48781 Mdot
.38711 .74413 Mdot
.20914 .60102 Mdot
.65595 .72165 Mdot
.49136 .15803 Mdot
.61936 .79243 Mdot
.63315 .78157 Mdot
.67514 .52462 Mdot
.36516 .58805 Mdot
.33607 .71368 Mdot
.46687 .28348 Mdot
.5028 .51338 Mdot
.31058 .79088 Mdot
.34097 .40775 Mdot
.21081 .7252 Mdot
.59126 .61489 Mdot
.17179 .54507 Mdot
.4425 .31905 Mdot
.55369 .48987 Mdot
.52216 .44305 Mdot
.78832 .53177 Mdot
.5413 .69837 Mdot
.77925 .64291 Mdot
.25309 .68618 Mdot
.67767 .5009 Mdot
.65628 .80704 Mdot
.79565 .68352 Mdot
.28025 .63094 Mdot
.41548 .5142 Mdot
.75949 .70859 Mdot
.65857 .51466 Mdot
.24167 .41866 Mdot
.84208 .4829 Mdot
.77114 .43983 Mdot
.40828 .57211 Mdot
.39229 .29113 Mdot
.65845 .25631 Mdot
.59535 .18247 Mdot
.20115 .65317 Mdot
.74125 .34407 Mdot
.64187 .63652 Mdot
.53877 .46238 Mdot
.73329 .30053 Mdot
.46255 .59891 Mdot
.5484 .64521 Mdot
.47482 .66011 Mdot
.29367 .79942 Mdot
.58068 .22316 Mdot
.51438 .19357 Mdot
.47166 .64599 Mdot
.36905 .64339 Mdot
.51021 .66334 Mdot
.47792 .66837 Mdot
.77308 .45443 Mdot
.74068 .70258 Mdot
.48243 .65849 Mdot
.46136 .85389 Mdot
.3096 .48329 Mdot
.6147 .39926 Mdot
.33233 .71889 Mdot
.28499 .44997 Mdot
.56211 .63257 Mdot
.37211 .23724 Mdot
.81278 .44875 Mdot
.63512 .6087 Mdot
.80283 .512 Mdot
.68881 .69607 Mdot
.36667 .60924 Mdot
.34252 .57798 Mdot
.78644 .42987 Mdot
.24733 .60298 Mdot
.39384 .76394 Mdot
.26066 .37801 Mdot
.63658 .50169 Mdot
.81709 .43667 Mdot
.66042 .4861 Mdot
.41048 .3673 Mdot
.47459 .57922 Mdot
.42946 .35411 Mdot
.22329 .35954 Mdot
.54959 .34806 Mdot
.43545 .64313 Mdot
.16594 .60278 Mdot
.38117 .69006 Mdot
.23059 .32244 Mdot
.22437 .46108 Mdot
.35183 .74689 Mdot
.63824 .32565 Mdot
.62505 .35306 Mdot
.37888 .83019 Mdot
.61929 .5647 Mdot
.60828 .52132 Mdot
.45397 .77475 Mdot
.42634 .62061 Mdot
.60127 .26267 Mdot
.65722 .49941 Mdot
.50305 .60257 Mdot
.67563 .65291 Mdot
.35047 .54067 Mdot
.35574 .711 Mdot
.50073 .58112 Mdot
.34512 .27938 Mdot
.49007 .1699 Mdot
.65541 .43783 Mdot
.22313 .72573 Mdot
.45452 .4725 Mdot
.28749 .61003 Mdot
.76981 .31226 Mdot
.20886 .67681 Mdot
.58432 .47348 Mdot
.80315 .67902 Mdot
.34585 .45146 Mdot
.77259 .39275 Mdot
.39832 .66309 Mdot
.62487 .78418 Mdot
.53419 .35312 Mdot
.42832 .27098 Mdot
.59043 .61244 Mdot
.21499 .43254 Mdot
.57781 .43528 Mdot
.37729 .70235 Mdot
.76002 .40689 Mdot
.28458 .42625 Mdot
.54865 .6885 Mdot
.61253 .33301 Mdot
.28445 .63668 Mdot
.34343 .57151 Mdot
.35688 .64461 Mdot
.52848 .1984 Mdot
.63862 .7861 Mdot
.43952 .14509 Mdot
.44043 .67483 Mdot
.54476 .3986 Mdot
.55426 .78334 Mdot
.79671 .48218 Mdot
.44624 .75325 Mdot
.74691 .28763 Mdot
.36191 .3034 Mdot
.37221 .5687 Mdot
.38862 .27121 Mdot
.41786 .53868 Mdot
.53929 .53074 Mdot
.74678 .57696 Mdot
.27691 .71455 Mdot
.48042 .69699 Mdot
.18564 .53331 Mdot
.41568 .75544 Mdot
.51084 .20089 Mdot
.38778 .74076 Mdot
.626 .41278 Mdot
.35836 .61399 Mdot
.65333 .63697 Mdot
.50564 .16038 Mdot
.75409 .29481 Mdot
.63832 .66453 Mdot
.63609 .28513 Mdot
.82771 .51411 Mdot
.42343 .52711 Mdot
.56022 .41296 Mdot
.42082 .41697 Mdot
.31598 .39944 Mdot
.22285 .70134 Mdot
.78246 .46286 Mdot
.35122 .40973 Mdot
.56606 .19485 Mdot
.54767 .17715 Mdot
.36376 .18202 Mdot
.5003 .8367 Mdot
.4091 .62283 Mdot
.29453 .24867 Mdot
.45876 .68808 Mdot
.61483 .18646 Mdot
.74912 .47785 Mdot
.80007 .32868 Mdot
.27049 .63652 Mdot
.81262 .50981 Mdot
.19607 .57713 Mdot
.52459 .67269 Mdot
.77909 .61794 Mdot
.55824 .45923 Mdot
.71197 .5688 Mdot
.79757 .58453 Mdot
.58997 .85726 Mdot
.47269 .45183 Mdot
.71388 .67874 Mdot
.62708 .73367 Mdot
.8146 .42772 Mdot
.73113 .42358 Mdot
.43402 .50156 Mdot
.68996 .55033 Mdot
.22191 .39005 Mdot
.41937 .2564 Mdot
.56519 .36766 Mdot
.73184 .42643 Mdot
.28999 .33443 Mdot
.37318 .2767 Mdot
.62296 .79304 Mdot
.28061 .64039 Mdot
.52041 .59742 Mdot
.34923 .46946 Mdot
.35544 .70075 Mdot
.53532 .36345 Mdot
.56906 .48505 Mdot
.43492 .43187 Mdot
.6524 .42113 Mdot
.54057 .68134 Mdot
.20714 .36994 Mdot
.48628 .71766 Mdot
.68989 .73147 Mdot
.37187 .72023 Mdot
.64319 .71264 Mdot
.45724 .761 Mdot
.18284 .43904 Mdot
.70314 .38641 Mdot
.44645 .23976 Mdot
.61276 .22189 Mdot
.45082 .20112 Mdot
.35329 .64266 Mdot
.3721 .20177 Mdot
.62146 .66564 Mdot
.40354 .5741 Mdot
.60348 .7383 Mdot
.60238 .29187 Mdot
.36171 .39601 Mdot
.81168 .50884 Mdot
.59633 .50908 Mdot
.53878 .23675 Mdot
.78677 .62466 Mdot
.29486 .4308 Mdot
.30548 .67593 Mdot
.59008 .1945 Mdot
.62891 .42885 Mdot
.67118 .76437 Mdot
.58661 .70808 Mdot
.68967 .3965 Mdot
.48067 .18301 Mdot
.45209 .15513 Mdot
.52131 .47233 Mdot
.42839 .30522 Mdot
.36704 .46088 Mdot
.60018 .81614 Mdot
.78918 .47664 Mdot
.46543 .38324 Mdot
.70444 .61062 Mdot
.37146 .66614 Mdot
.7331 .61033 Mdot
.53032 .5734 Mdot
.31145 .30651 Mdot
.43931 .63039 Mdot
.34043 .74853 Mdot
.56366 .33525 Mdot
.53274 .41101 Mdot
.43838 .38795 Mdot
.43611 .29042 Mdot
.41461 .82083 Mdot
.3921 .38361 Mdot
.75273 .35179 Mdot
.29976 .64681 Mdot
.62514 .77283 Mdot
.78047 .42455 Mdot
.73509 .49647 Mdot
.53661 .69279 Mdot
.3563 .60647 Mdot
.66111 .60474 Mdot
.37646 .42242 Mdot
.61406 .41638 Mdot
.39277 .70234 Mdot
.82903 .44939 Mdot
.32518 .589 Mdot
.45801 .28725 Mdot
.62059 .55394 Mdot
.40326 .36542 Mdot
.64597 .68186 Mdot
.78979 .32189 Mdot
.52355 .67537 Mdot
.37162 .29748 Mdot
.58478 .55956 Mdot
.44436 .3149 Mdot
.21666 .47927 Mdot
.50574 .14264 Mdot
.19248 .57036 Mdot
.50859 .53435 Mdot
.17819 .55889 Mdot
.78251 .53283 Mdot
.83991 .49726 Mdot
.36788 .28938 Mdot
.52262 .41698 Mdot
.51006 .31516 Mdot
.49351 .78711 Mdot
.61816 .55667 Mdot
.57657 .35308 Mdot
.50718 .60926 Mdot
.6825 .61805 Mdot
.58522 .59321 Mdot
.46311 .38531 Mdot
.58846 .23699 Mdot
.60248 .2101 Mdot
.61034 .78536 Mdot
.6097 .68766 Mdot
.68929 .40496 Mdot
.31139 .31585 Mdot
.82486 .34968 Mdot
.14287 .54385 Mdot
.36805 .45864 Mdot
.64599 .67039 Mdot
.41437 .30414 Mdot
.61646 .47886 Mdot
.47716 .68576 Mdot
.4659 .75512 Mdot
.61849 .60923 Mdot
.57112 .35007 Mdot
.52348 .22885 Mdot
.77657 .5504 Mdot
.36328 .33497 Mdot
.66044 .54856 Mdot
.19823 .37931 Mdot
.79464 .65559 Mdot
.79362 .47472 Mdot
.7879 .29009 Mdot
.57871 .70016 Mdot
.31852 .47291 Mdot
.22675 .51919 Mdot
.49332 .17339 Mdot
.43689 .25778 Mdot
.25121 .37773 Mdot
.71923 .51406 Mdot
.36174 .29783 Mdot
.46176 .65056 Mdot
.56848 .23323 Mdot
.72779 .61218 Mdot
.5381 .51291 Mdot
.62818 .35644 Mdot
.39626 .18274 Mdot
.30872 .6949 Mdot
.63426 .2302 Mdot
.20991 .40803 Mdot
.52239 .85711 Mdot
.51874 .16044 Mdot
.51647 .25797 Mdot
.72074 .40565 Mdot
.22039 .54459 Mdot
.50028 .46962 Mdot
.45129 .60207 Mdot
.24288 .41462 Mdot
.31916 .53852 Mdot
.66825 .31453 Mdot
.18301 .49678 Mdot
.40298 .25717 Mdot
.28478 .46433 Mdot
.52206 .42062 Mdot
.32046 .64561 Mdot
.63299 .28683 Mdot
.46895 .62265 Mdot
.49401 .49999 Mdot
.46976 .25822 Mdot
.30468 .64261 Mdot
.57369 .782 Mdot
.8005 .55379 Mdot
.49256 .8685 Mdot
.74325 .37322 Mdot
.17901 .45342 Mdot
.41094 .50633 Mdot
.39461 .14993 Mdot
.78217 .58671 Mdot
.74974 .46148 Mdot
.75619 .67739 Mdot
.64332 .39992 Mdot
.32359 .49776 Mdot
.37577 .42287 Mdot
.72125 .3122 Mdot
.34168 .65886 Mdot
.2622 .46427 Mdot
.2063 .43859 Mdot
.41147 .27857 Mdot
.47521 .22057 Mdot
.47465 .28117 Mdot
.39552 .56863 Mdot
.38242 .68563 Mdot
.26275 .2766 Mdot
.51537 .50333 Mdot
.43535 .37647 Mdot
.48348 .44664 Mdot
.20695 .5343 Mdot
.83394 .62512 Mdot
.41229 .71284 Mdot
.47182 .20395 Mdot
.28889 .6749 Mdot
.44042 .55232 Mdot
.44057 .7444 Mdot
.78478 .2478 Mdot
.45358 .11355 Mdot
.3849 .70576 Mdot
.50012 .82141 Mdot
.29391 .68172 Mdot
.51911 .1876 Mdot
.67328 .37648 Mdot
.6902 .63747 Mdot
.48382 .41235 Mdot
.46475 .54768 Mdot
.42961 .38896 Mdot
.76417 .65472 Mdot
.51989 .14951 Mdot
.19577 .45869 Mdot
.56886 .19575 Mdot
.39041 .55107 Mdot
.41187 .38559 Mdot
.84398 .35579 Mdot
.72404 .29032 Mdot
.42665 .51779 Mdot
.20686 .61279 Mdot
.34361 .40059 Mdot
.41145 .48368 Mdot
.66954 .28386 Mdot
.65736 .80529 Mdot
.40488 .25302 Mdot
.52196 .18359 Mdot
.43975 .64564 Mdot
.59646 .4233 Mdot
.59216 .61377 Mdot
.5204 .46126 Mdot
.38343 .53306 Mdot
.61559 .61628 Mdot
.31365 .37041 Mdot
.81772 .49453 Mdot
.53929 .6014 Mdot
.66078 .78886 Mdot
.72536 .24998 Mdot
.3285 .60735 Mdot
.49103 .78247 Mdot
.46415 .47283 Mdot
.28674 .46029 Mdot
.30952 .33669 Mdot
.31741 .40723 Mdot
.81433 .55069 Mdot
.17705 .30714 Mdot
.69424 .57259 Mdot
.34366 .2655 Mdot
.37258 .63007 Mdot
.51484 .61515 Mdot
.32695 .67252 Mdot
.70198 .41692 Mdot
.67044 .44581 Mdot
.39789 .55144 Mdot
.44497 .64931 Mdot
.60297 .6001 Mdot
.18578 .68395 Mdot
.40506 .51526 Mdot
.46337 .7154 Mdot
.61838 .1898 Mdot
.26028 .37798 Mdot
.26653 .59345 Mdot
.3746 .41544 Mdot
.53194 .75895 Mdot
.52341 .4144 Mdot
.79412 .4028 Mdot
.35147 .24494 Mdot
.57993 .20948 Mdot
.32554 .58451 Mdot
.3015 .67621 Mdot
.35314 .47992 Mdot
.54398 .2859 Mdot
.55256 .61325 Mdot
.69877 .30316 Mdot
.33396 .48547 Mdot
.57715 .1699 Mdot
.58975 .40452 Mdot
.5735 .48193 Mdot
.44289 .6785 Mdot
.34902 .19408 Mdot
.19865 .50373 Mdot
.33638 .69706 Mdot
.18624 .42503 Mdot
.60361 .3275 Mdot
.36378 .32922 Mdot
.61642 .43939 Mdot
.34291 .50872 Mdot
.42956 .68475 Mdot
.17434 .4086 Mdot
.65566 .2688 Mdot
.70879 .55724 Mdot
.72274 .58827 Mdot
.5496 .8155 Mdot
.56434 .70057 Mdot
.76294 .26525 Mdot
.60932 .34643 Mdot
.18279 .40037 Mdot
.64644 .77989 Mdot
.41376 .70647 Mdot
.79681 .53295 Mdot
.33657 .41872 Mdot
.63965 .44266 Mdot
.56556 .20148 Mdot
.38238 .37124 Mdot
.2766 .31732 Mdot
.39069 .40195 Mdot
.24529 .34078 Mdot
.56259 .27628 Mdot
.62608 .27202 Mdot
.77439 .51071 Mdot
.20387 .52603 Mdot
.82582 .40447 Mdot
.4964 .78892 Mdot
.81721 .36189 Mdot
.82734 .42168 Mdot
.5984 .19185 Mdot
.24889 .36192 Mdot
.2292 .68894 Mdot
.7584 .47086 Mdot
.78789 .43782 Mdot
.75939 .5727 Mdot
.21066 .55496 Mdot
.61764 .38411 Mdot
.42256 .70783 Mdot
.51043 .68109 Mdot
.64781 .64673 Mdot
.08271 .52435 Mdot
.49545 .22906 Mdot
.42485 .69836 Mdot
.60845 .37074 Mdot
.56386 .17932 Mdot
.214 .53299 Mdot
.79481 .59805 Mdot
.53323 .56425 Mdot
.43629 .39897 Mdot
.33378 .56877 Mdot
.58598 .80415 Mdot
.59486 .38627 Mdot
.40835 .85592 Mdot
.77874 .67139 Mdot
.69788 .59536 Mdot
.53132 .54101 Mdot
.41103 .69508 Mdot
.41386 .76796 Mdot
.63265 .34466 Mdot
.81316 .56688 Mdot
.81495 .5042 Mdot
.73145 .29802 Mdot
.3787 .82882 Mdot
.62855 .77601 Mdot
.49094 .1716 Mdot
.7867 .50103 Mdot
.37047 .69825 Mdot
.50701 .27171 Mdot
.65802 .50956 Mdot
.72721 .55107 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0T?ooool2o`000;Oooooo000Looooo`03o`000?oooooooooo07oo
oooo0_l0000?ooooo`;o0000]oooool001cooooo00?o0000ooooooooool0Ooooool2o`000<Sooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0VOooool2
o`000:kooooo000Looooo`03o`000?oooooooooo09Kooooo0_l000000ooooooo0000o`00002^oooo
o`007?ooool00ol0003oooooooooo`2=ooooo`;o00001oooool2o`000;7ooooo000Looooo`03o`00
0?oooooooooo08gooooo0_l0000Booooo`;o0000Y_ooool001cooooo00?o0000ooooooooool0XOoo
ool4o`000:Cooooo000Looooo`03o`000?oooooooooo0:?ooooo1Ol0002Qooooo`007?ooool00ol0
003oooooooooo`2Qooooo`Oo0000XOooool001cooooo00?o0000ooooooooool0Roooool2o`0001Co
oooo1?l00003ooooo`;o0000Woooool001cooooo00?o0000ooooooooool0O?ooool2o`0000gooooo
1?l0000Fooooo`;o000000?oooooo`000?l000000_l0002Mooooo`007?ooool2o`0007gooooo0_l0
000?ooooo`;o00001?ooool2o`0000Wooooo0_l00005ooooo`;o00000oooool2o`0009gooooo000L
ooooo`03o`000?oooooooooo08Oooooo0ol00005ooooo`;o00000_ooool2o`0000Wooooo0_l0002Y
ooooo`007?ooool00ol0003oooooooooo`23ooooo`;o00000_ooool3o`0000Gooooo0_l00006oooo
o`;o00000_ooool3o`0000Kooooo0_l0000?ooooo`;o0000T_ooool001cooooo00?o0000oooooooo
ool0Poooool2o`0000Kooooo0_l00007ooooo`;o000000?oooooo`000?l000000_ooool3o`0000;o
oooo0_l00002ooooo`?o00003_ooool2o`0009;ooooo000Looooo`03o`000?oooooooooo07kooooo
1?l00009ooooo`;o00001_ooool3o`0000[ooooo0_l00003ooooo`Co00002Oooool2o`0000Oooooo
0_l0002<ooooo`007?ooool00ol0003oooooooooo`1nooooo`Co00004Oooool2o`0000oooooo0_l0
00000ooooooo0000o`000009ooooo`;o00001oooool2o`0008cooooo000Looooo`03o`000?oooooo
oooo087ooooo0_l00007ooooo`;o00003oooool3o`0000?ooooo0_l000000ooooooo0000o`000002
o`00013ooooo0_l0002?ooooo`007?ooool00ol0003oooooooooo`1kooooo`;o00001?ooool2o`00
00?ooooo0_l00002ooooo`;o00003oooool3o`0000?ooooo0_l00003ooooo`;o000000?oooooo`00
0?l000000_l0000;ooooo`;o0000Soooool001cooooo00?o0000ooooooooool0Noooool2o`0000Wo
oooo0ol00006ooooo`;o00002oooool4o`0000Wooooo1?l000000ooooooo0000o`00002Iooooo`00
7?ooool00ol0003oooooooooo`25ooooo`Co00001_ooool2o`0000gooooo0_l00008ooooo`;o0000
1?ooool2o`0000?ooooo0_l0002Dooooo`007?ooool00ol0003oooooooooo`1Gooooo`;o00006Ooo
ool2o`0000Wooooo0_l000000ooooooo0000o`000002ooooo`Co00003oooool3o`0000cooooo1?l0
0009ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o0000ROooool001cooooo00?o0000
ooooooooool0Eoooool2o`0001Wooooo0_l00009ooooo`;o000000?oooooo`000?l000000_ooool2
o`0000Sooooo0_l00007ooooo`?o000000Coooooo`000?l0003ooooo0_l00005ooooo`?o00003_oo
ool5o`0000?ooooo0_l00004ooooo`;o0000Poooool001cooooo00?o0000ooooooooool0P?ooool2
o`0000Cooooo1?l00004ooooo`;o00002oooool2o`000003ooooool0003o000000Gooooo0_l0000<
ooooo`;o00001?ooool2o`0000Wooooo0ol00022ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^
k^h5ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0LOooool2o`00017ooooo1_l0
000Dooooo`;o00000_ooool3o`000003ooooool0003o000000_ooooo0_l00009ooooo`?o00001?oo
ool2o`0008;ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1^ooooo`;o000000?oooooo`000?l0
00004Oooool4o`0000Sooooo0_l0000?ooooo`Co000000?oooooo`000?l000003?ooool3o`0000Go
oooo1_l00007ooooo`;o0000O_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool0
2_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo06kooooo0_l00009ooooo`;o0000
3?ooool2o`0000Cooooo0_l000000ooooooo0000o`000008ooooo`;o00001Oooool2o`0000Gooooo
0_l0000:ooooo`?o00001Oooool2o`000004ooooool0003o0000o`0000?ooooo0_l00002ooooo`;o
00000oooool2o`0007Wooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo
00?oV9RHob4Q8Oo^k^h01_ooool3o`0006[ooooo0_l00009ooooo`;o00000_ooool2o`0000cooooo
0_l00004ooooo`Co00000_ooool2o`0000Gooooo1?l00004ooooo`;o00001?ooool2o`0000[ooooo
1Ol00006ooooo`;o00001?ooool2o`0000Oooooo0_l0001iooooo`0000?oooooo`000?ooool00_oo
ool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0J_oo
ool2o`0000Wooooo0_l00009ooooo`?o00001oooool2o`0000;ooooo0ol00002ooooo`;o000000?o
ooooo`000?l000001?ooool2o`0000Cooooo0_l00002ooooo`Co00002_ooool2o`000003ooooool0
003o0000093ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`1Vooooo`;o00006?ooool5o`0000;ooooo1Ol00002
ooooo`;o00000_ooool2o`0000;ooooo0_l00008ooooo`;o000000Coooooo`000?l0003ooooo1?l0
000Oooooo`;o00000_ooool2o`0007[ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo
00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo06Kooooo0_l0000Fooooo`;o
00000oooool2o`0000;ooooo0ol00002ooooo`So00000oooool2o`0000Oooooo0_l000000ooooooo
0000o`00000Dooooo`;o00000_ooool2o`000003ooooool0003o000000Oooooo0_l00002ooooo`;o
0000N_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0Noooool2o`000003ooooool0003o000000?ooooo0_l00005
ooooo`[o00000oooool2o`0001Oooooo0_l00006ooooo`?o00000_ooool2o`000003ooooool0003o
000000Wooooo0_l0001looooo`007?ooool00ol0003oooooooooo`1Nooooo`;o00002Oooool2o`00
013ooooo0_l0000<ooooo`?o00000_ooool2o`0000Kooooo0ol0000Cooooo`;o00000_ooool2o`00
00Kooooo0_l0000Aooooo`Co0000N_ooool001cooooo00?o0000ooooooooool0G_ooool2o`0000;o
oooo0_l00005ooooo`;o00001Oooool2o`0000Wooooo0_l0000<ooooo`;o00000oooool3o`0000;o
oooo0_l000001?oooooo0000o`000?l0000;ooooo`?o00001Oooool2o`000003ooooool0003o0000
01cooooo0_l0001jooooo`007?ooool00ol0003oooooooooo`1Rooooo`;o00003?ooool2o`0000Wo
oooo0_l0000Booooo`;o00000_ooool2o`0000;ooooo0_l00004ooooo`;o00001Oooool3o`0000So
oooo0_l00003ooooo`;o00000oooool2o`0000;ooooo0_l00004ooooo`;o0000Q?ooool001cooooo
00?o0000ooooooooool0ROooool2o`0001;ooooo0_l00005ooooo`;o00003?ooool4o`000003oooo
ool0003o000000;o00000_ooool2o`0000;ooooo1?l00005ooooo`;o0000OOooool001cooooo00?o
0000ooooooooool0G?ooool2o`0001Kooooo0_l000000ooooooo0000o`000005ooooo`;o00002Ooo
ool2o`0000Gooooo0_l0000;ooooo`;o00001Oooool4o`0000;ooooo0_l00006ooooo`;o00000ooo
ool2o`0000Sooooo0_l00007ooooo`;o00002Oooool2o`0007;ooooo000Looooo`03o`000?oooooo
oooo05cooooo1?l0000Dooooo`Go00001Oooool2o`0000Cooooo0_l00004ooooo`;o00001?ooool2
o`0000_ooooo0_l00007ooooo`;o00000_ooool4o`0000Oooooo0_l00002ooooo`;o00003oooool2
o`0000Oooooo1?l0001booooo`007?ooool00ol0003oooooooooo`1Nooooo`;o00002?ooool2o`00
00[ooooo0ol00003ooooo`;o00002?ooool2o`0000;ooooo1?l00006ooooo`?o00001?ooool2o`00
013ooooo0ol00007ooooo`?o000000?oooooo`000?l000000_l00007ooooo`;o00002oooool5o`00
07?ooooo000Looooo`03o`000?oooooooooo06Sooooo0_l0000:ooooo`?o00000oooool2o`0000_o
oooo1Ol000000ooooooo0000o`000003ooooo`Go00000_ooool2o`00013ooooo0_l00009ooooo`;o
00000oooool2o`0000Oooooo0_l0000;ooooo`Go000000?oooooo`000?l000001oooool2o`0006Oo
oooo000Looooo`03o`000?oooooooooo06kooooo0_l00005ooooo`;o00002Oooool3o`0000Cooooo
2?l00004ooooo`Co00000_ooool2o`0000Oooooo0_l00005ooooo`Co00003?ooool2o`000003oooo
ool0003o000001?ooooo1?l00002ooooo`Co00001Oooool2o`0006Oooooo000Looooo`03o`000?oo
oooooooo06_ooooo0_l000000ooooooo0000o`00000@ooooo`?o00002?ooool2o`0000?ooooo0_l0
000@ooooo`;o00001Oooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o00000ooo
ool2o`000004ooooool0003o0000ooooo`;o00000oooool4o`0000Wooooo1_l000001?oooooo0000
o`000?l0001^ooooo`007?ooool00ol0003oooooooooo`1Looooo`;o00003Oooool2o`000003oooo
ool0003o000000Sooooo0_l00005ooooo`;o00003oooool2o`0000gooooo0_l00002ooooo`;o0000
1oooool2o`0000;ooooo0_l00002ooooo`?o00000oooool2o`0000?ooooo0_l00003ooooo`Co0000
0oooool2o`0000Sooooo1Ol0000Qooooo`;o0000C?ooool001cooooo0_l0001Gooooo`;o00001?oo
ool2o`0000_ooooo1_l00009ooooo`;o00001Oooool4o`0001Gooooo0_l00004ooooo`?o00000_oo
ool2o`0000;ooooo0_l00003ooooo`?o00001_ooool2o`0000?ooooo0_l00008ooooo`;o00001Ooo
ool2o`0000Sooooo0ol00007ooooo`?o00001_ooool2o`00017ooooo0_l0001<ooooo`007?ooool0
0ol0003oooooooooo`1Fooooo`;o00002Oooool2o`0000Kooooo0_l000001?oooooo0000o`000?l0
000Aooooo`Go00000_ooool2o`0000Gooooo0_l00004ooooo`;o00000_ooool4o`0000;ooooo1?l0
0003ooooo`Co00001?ooool2o`0000Sooooo0_l0000@ooooo`;o00002_ooool4o`0000Gooooo1_l0
0004ooooo`;o0000Goooool001cooooo00?o0000ooooooooool0D_ooool2o`0000gooooo0_l0000<
ooooo`;o00003_ooool7o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000?ooooo1?l0
0003ooooo`;o00001?ooool2o`0000;ooooo0ol00009ooooo`;o00001Oooool2o`00013ooooo0_l0
0007ooooo`;o00000oooool2o`0000Gooooo0_l000001?oooooo0000o`000?l0001Uooooo`007?oo
ool00ol0003oooooooooo`1Booooo`;o00006oooool2o`0000kooooo1?l000000ooooooo0000o`00
0004ooooo`;o00001oooool4o`0000gooooo0_l00003ooooo`;o00001?ooool3o`0000;ooooo0_l0
0009ooooo`;o00001_ooool2o`0000Wooooo0_l0000:ooooo`Ko0000IOooool001cooooo00?o0000
ooooooooool0J_ooool2o`0000cooooo0_l0000<ooooo`;o00003?ooool2o`0000Wooooo0_l00008
ooooo`;o00001?ooool2o`0000?ooooo0_l00009ooooo`?o00001Oooool4o`0001?ooooo0ol00000
0ooooooo0000o`00000=ooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0IOooool3o`00
00;ooooo1?l0000:ooooo`?o00001Oooool2o`0000Cooooo0ol00002ooooo`;o00001oooool2o`00
00;ooooo0_l00005ooooo`;o00003?ooool4o`0000kooooo0ol00007ooooo`Co00006?ooool2o`00
00[ooooo0_l000000ooooooo0000o`00001Cooooo`007?ooool00ol0003oooooooooo`19ooooo`;o
00005?ooool9o`0000?ooooo0ol00005ooooo`;o00001?ooool4o`0000?ooooo0_l00004ooooo`?o
00000_ooool2o`0000_ooooo0_l00006ooooo`;o00002_ooool4o`0000;ooooo0_l00003ooooo`;o
00001_ooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000002ooooo`Co
00004_ooool2o`0000gooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`19ooooo`;o0000
4_ooool9o`0000gooooo0_l00004ooooo`Co00002Oooool3o`0000?ooooo0_l0000<ooooo`Co0000
0_ooool3o`0000Wooooo0ol00003ooooo`;o00000oooool2o`0000Wooooo0_l00004ooooo`;o0000
1Oooool4o`0000Oooooo0_l0000<ooooo`;o0000Goooool001cooooo00?o0000ooooooooool0D_oo
ool2o`0000Wooooo0_l0000<ooooo`;o00000oooool2o`000003ooooool0003o000000;o00000_oo
ool3o`0000_ooooo0_l00003ooooo`;o00003?ooool4o`0000?ooooo0_l0000:ooooo`;o000000?o
ooooo`000?l000000ol000000ooooooo0000o`000008ooooo`;o00001_ooool2o`0000Sooooo0_l0
0006ooooo`;o00003?ooool2o`0005oooooo000Looooo`03o`000?oooooooooo05;ooooo0_l00007
ooooo`;o00003_ooool3o`000004ooooool0003o0000o`0000?ooooo0_l0000;ooooo`;o00000_oo
ool2o`0001;ooooo0_l0000=ooooo`;o00000_ooool2o`000003ooooool0003o000000?o000000?o
ooooo`000?l000000_l00006ooooo`;o00001_ooool2o`0000Sooooo0_l0000Cooooo`Co0000G_oo
ool001cooooo00?o0000ooooooooool0Foooool2o`0000oooooo0_l000000ooooooo0000o`000006
ooooo`;o00000_ooool4o`0000?ooooo0_l00002ooooo`;o00003_ooool2o`0000;ooooo0ol0000<
ooooo`Go00002_ooool4o`0001Wooooo0_l00009ooooo`;o00001Oooool4o`0005kooooo000Loooo
o`03o`000?oooooooooo04cooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`00
0?l000001Oooool2o`0000oooooo1?l00003ooooo`;o00000_ooool4o`0000?ooooo0_l00004oooo
o`;o00002?ooool6o`0000;ooooo0ol00008ooooo`;o00001?ooool4o`0000_ooooo0_l0000?oooo
o`;o00002?ooool3o`0000Sooooo0_l00008ooooo`;o0000GOooool001cooooo00?o0000oooooooo
ool0C?ooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000005ooooo`;o
00001?ooool2o`0000Wooooo1_l00007ooooo`;o00000oooool2o`0000Cooooo0_l00007ooooo`Go
00002oooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool6o`000003ooooool0003o0000
01?ooooo0_l000001?oooooo0000o`000?l00008ooooo`?o00004Oooool5o`000003ooooool0003o
000005Sooooo000Looooo`03o`000?oooooooooo05Gooooo0_l0000;ooooo`;o000000?oooooo`00
0?l000003Oooool2o`0000?ooooo1_l0000;ooooo`;o00000_ooool2o`000003ooooool0003o0000
00kooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo1_l000000ooooooo0000o`00000<
ooooo`;o00001Oooool2o`000003ooooool0003o000000Kooooo0_l0000Cooooo`Co000000Cooooo
o`000?l0003ooooo0_l0000;ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0EOooool4
o`0000;ooooo0_l00005ooooo`;o00001_ooool3o`0000Cooooo0_l00005ooooo`Oo00002Oooool4
o`0000;ooooo1?l0000Cooooo`;o000000?oooooo`000?l000002Ol0000=ooooo`;o00002oooool2
o`0000?ooooo0_l0000Cooooo`;o00002?ooool2o`0000Wooooo0_l0001;ooooo`007?ooool00ol0
003oooooooooo`1Eooooo`Co00000_ooool2o`0000Gooooo0_l00006ooooo`?o00001?ooool3o`00
0003ooooool0003o000000?o00000oooool2o`0000Wooooo0_l00006ooooo`;o00002oooool2o`00
00Wooooo3?l0000Iooooo`;o00002?ooool2o`0000Gooooo0_l0000:ooooo`;o00001Oooool3o`00
05Gooooo000Looooo`;o0000E_ooool2o`000003ooooool0003o000000[ooooo0_l00005ooooo`;o
00001Oooool6o`0000Gooooo0_l0000Booooo`;o00000_ooool2o`0000Kooooo0_l00007oooooa;o
00000_ooool2o`0000[ooooo1?l0000<ooooo`?o00000oooool4o`0000Gooooo0_l00003ooooo`;o
00001_ooool2o`0005Gooooo000Looooo`03o`000?oooooooooo05Sooooo0_l0000:ooooo`;o0000
1?ooool3o`0000Gooooo1_l0000;ooooo`;o00003?ooool6o`0000oooooo4_l00002ooooo`?o0000
1_ooool2o`000003ooooool0003o000000;o00003?ooool2o`0000Cooooo0_l000000ooooooo0000
o`000004ooooo`;o00000oooool2o`0000?ooooo0_l0001Hooooo`007?ooool00ol0003ooooooooo
o`0fooooo`;o00008oooool3o`0000?ooooo0_l00007ooooo`;o00001_ooool7o`0000[ooooo0_l0
0002ooooo`;o00000oooool3o`0000;ooooo1_l00006ooooo`;o00001_ooool@o`0000Kooooo0_l0
0006ooooo`;o00000oooool2o`0000Cooooo0_l0000?ooooo`;o00003_ooool3o`0005Oooooo000L
ooooo`03o`000?oooooooooo03Kooooo0_l0000Sooooo`?o00000oooool2o`0001Cooooo0ol00002
ooooo`;o00002Oooool2o`0000?ooooo0ol00002ooooo`;o00000_ooool2o`0000Kooooo0_l00005
oooooa7o00003Oooool2o`0000;ooooo1?l00004ooooo`;o00000oooool2o`0000Oooooo0_l00000
0ooooooo0000o`00000?ooooo`;o000000?oooooo`000?l00000E?ooool001cooooo00?o0000oooo
ooooool0Foooool2o`0000Oooooo0_l00006ooooo`;o000000?oooooo`000?l000001oooool2o`00
00;ooooo0_l0000?ooooo`;o00001_ooool4o`0000Cooooo0_l00005oooooa7o00003Oooool7o`00
00[ooooo1?l00005ooooo`;o000000?oooooo`000?l000001Oooool4o`0000Wooooo0_l000000ooo
oooo0000o`00001Aooooo`007?ooool00ol0003oooooooooo`1Fooooo`;o00002Oooool5o`0000Co
oooo1?l000000ooooooo0000o`000003ooooo`?o00002?ooool2o`0000Wooooo0_l000000ooooooo
0000o`000006ooooo`Ko00001ooooolCo`0000;ooooo0_l00009ooooo`Go00003_ooool2o`0000oo
oooo1?l0000<ooooo`?o0000D?ooool001cooooo00?o0000ooooooooool0E_ooool2o`0000Wooooo
1?l00004ooooo`Co00000_ooool2o`0000?ooooo0ol00008ooooo`;o00001?ooool2o`0000?ooooo
1Ol00004ooooo`Co00000_ooool2o`0000?ooooo0_l00002ooooo`co000000?oooooo`000?l00000
0ol00003ooooo`;o00001Oooool2o`0000;ooooo1?l00005ooooo`;o00000_ooool2o`0000Cooooo
0_l0000;ooooo`;o000000?oooooo`000?l000004?ooool3o`0004oooooo000Looooo`03o`000?oo
oooooooo04Oooooo0_l0000=ooooo`;o00002Oooool2o`0000Kooooo1?l00004ooooo`;o000000?o
ooooo`000?l000003oooool4o`0000?ooooo0_l00005ooooo`Co00001?ooool2o`000003ooooool0
003o000000;ooooo4_l0000:ooooo`;o00001?ooool2o`0000Gooooo0_l00002ooooo`?o000000?o
ooooo`000?l000003?ooool3o`000003ooooool0003o0000017ooooo0_l00003ooooo`;o0000B_oo
ool001cooooo00?o0000ooooooooool0Aoooool2o`000003ooooool0003o000000[ooooo1?l00007
ooooo`;o00003_ooool2o`0000[ooooo0_l00005ooooo`;o000000?oooooo`000?l000002?ooool2
o`0000Sooooo0_l00006oooooaCo00001_ooool2o`0000Cooooo0_l00007ooooo`;o00000_ooool2
o`000003ooooool0003o000000cooooo0_l0000Hooooo`Co0000B_ooool001cooooo00?o0000oooo
ooooool0B_ooool2o`0000;ooooo1?l00003ooooo`;o000000?oooooo`000?l000001oooool2o`00
00oooooo0_l00009ooooo`;o00001?ooool3o`000003ooooool0003o000000Sooooo0_l0000?oooo
oaGo00001?ooool4o`000004ooooool0003o0000ooooo`;o00001oooool2o`0001Oooooo0_l0000D
ooooo`;o00000oooool2o`0004Oooooo000Looooo`03o`000?oooooooooo03_ooooo0_l00006oooo
o`;o00002Oooool4o`0000?ooooo0ol0000Dooooo`;o000000?oooooo`000?l000000ol00003oooo
o`;o00001oooool2o`000003ooooool0003o000001Wooooo0_l00002oooooaCo00001Oooool2o`00
0003ooooool0003o000000;o000000?oooooo`000?l000007_ooool4o`000003ooooool0003o0000
00;o00002_ooool3o`0000Cooooo0_l000000ooooooo0000o`000017ooooo`007?ooool00ol0003o
ooooooooo`0kooooo`;o00001_ooool2o`00017ooooo0_l00002ooooo`;o00002Oooool3o`0000Co
oooo2?l00003ooooo`;o00001oooool2o`000003ooooool0003o000001Wooooo0_l000000ooooooo
0000o`00000Do`0000Kooooo0ol00003ooooo`;o00006Oooool4o`000003ooooool0003o000000?o
oooo1?l0000:ooooo`Co00000oooool2o`0004[ooooo000Looooo`03o`000?oooooooooo05Wooooo
0ol00005ooooo`;o00000_ooool3o`0000Kooooo0ol000000ooooooo0000o`00000?ooooo`;o0000
6OoooolIo`0000;ooooo0_l00002ooooo`?o00000oooool2o`0001Wooooo1?l0000Fooooo`;o0000
00?oooooo`000?l00000C?ooool001cooooo00?o0000ooooooooool0A?ooool2o`0000Kooooo0_l0
0005ooooo`;o00001?ooool2o`0000Kooooo0_l00002ooooo`;o00002?ooool2o`0002kooooo0_l0
0002oooooa;o00001?ooool2o`0000?ooooo0_l0000Iooooo`;o00002oooool2o`0000Cooooo0_l0
000=ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0A?ooool2o`0000Kooooo0_l00004
ooooo`?o00003oooool2o`0003_ooooo4ol000000ooooooo0000o`000004ooooo`;o00001?ooool2
o`0000Oooooo0_l00007ooooo`;o00001?ooool2o`0000Oooooo0_l000001?oooooo0000o`000?l0
0004ooooo`?o00002?ooool2o`0000Kooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`1>
ooooo`;o00000_ooool2o`0000Cooooo0_l0000:ooooo`Co00003?ooool2o`0002_ooooo4ol00000
0ooooooo0000o`000004ooooo`;o00001?ooool3o`0000Kooooo0_l00007ooooo`;o00003Oooool2
o`000003ooooool0003o000000Co00000_ooool2o`0000Sooooo0_l00006ooooo`?o0000Aoooool0
01cooooo0_l0001?ooooo`;o00002?ooool2o`0000_ooooo0ol0000<ooooo`;o0000;Oooool?o`00
00Cooooo0_l00003ooooo`;o00001Oooool2o`0001_ooooo0_l00005ooooo`Go00005?ooool4o`00
00Gooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`1?ooooo`;o00004_ooool4o`0003Wo
oooo4_l00003ooooo`Go000000?oooooo`000?l000002_ooool2o`0000Wooooo0_l0000;ooooo`;o
00001Oooool4o`0000?ooooo0_l00002ooooo`;o00003?ooool4o`0000Gooooo0_l0000oooooo`00
7?ooool00ol0003oooooooooo`0oooooo`;o00003?ooool4o`0000Wooooo0_l00007ooooo`;o0000
4Oooool2o`0000?ooooo0_l0000;ooooo`Co00005?oooolGo`000004ooooool0003o0000ooooo`;o
00002_ooool3o`0000Cooooo0_l00002ooooo`;o00004_ooool2o`0000Gooooo0_l00002ooooo`;o
00002oooool2o`000004ooooool0003o0000o`0000[ooooo0_l0000iooooo`007?ooool00ol0003o
ooooooooo`0oooooo`;o00001?ooool2o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o
00001oooool2o`0000?ooooo0_l0000Eooooo`;o00000oooool2o`0000_ooooo1Ol0000?ooooo`;o
00001OoooolDo`0000oooooo1?l00004ooooo`;o00008oooool2o`0000Wooooo0_l000001?oooooo
0000o`000?l0000:ooooo`;o0000>Oooool001cooooo00?o0000ooooooooool0AOooool2o`000003
ooooool0003o000000?ooooo0_l00002ooooo`;o00003?ooool2o`0000Wooooo0_l0000Oooooo`;o
000000?oooooo`000?l000003?ooool2o`0000Cooooo2Ol000001?oooooo0000o`000?ooool4o`00
00gooooo1?l00002ooooo`;o00008_ooool2o`0000;ooooo1?l000000ooooooo0000o`000009oooo
o`Co00001?ooool2o`00047ooooo000Looooo`03o`000?oooooooooo04Kooooo0_l00004ooooo`?o
00005?ooool2o`0000Cooooo0ol000000ooooooo0000o`00000@ooooo`;o00000oooool2o`0000Go
oooo0_l000000ooooooo0000o`00000Aooooo`_o00001?ooool2o`000003ooooool0003o000000_o
oooo1?l0000Uooooo`?o00000_ooool4o`000003ooooool0003o000000_ooooo0_l00004ooooo`;o
0000@Oooool001cooooo00?o0000ooooooooool0A_ooool2o`0000?ooooo0ol0000Eooooo`;o0000
1?ooool2o`000004ooooool0003o0000o`0000Kooooo0_l00008ooooo`;o000000?oooooo`000?l0
00000_l00005ooooo`;o00004?ooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool5o`00
00Oooooo0ol00002ooooo`;o0000:_ooool2o`0000?ooooo1?l00002ooooo`;o00000_ooool2o`00
00Kooooo0ol0001;ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o000000?oooooo`000?l0
00001_ooool2o`0000Kooooo0_l0000=ooooo`;o00001_ooool4o`0000Cooooo0_l000000ooooooo
0000o`000003o`0000Cooooo0_l00002ooooo`;o00006Oooool2o`0000;ooooo1Ol000000ooooooo
0000o`000003o`0000Sooooo0_l00002ooooo`;o00002?ooool6o`0000kooooo0_l0000<ooooo`;o
00001Oooool2o`0000;ooooo0_l00009ooooo`Ko00000_ooool2o`0001Oooooo0_l0000/ooooo`00
7?ooool00ol0003oooooooooo`0Pooooo`;o00007_ooool2o`000003ooooool0003o000000kooooo
0_l000001?oooooo0000o`000?ooool2o`0000Oooooo0_l00006ooooo`;o00001_ooool2o`000003
ooooool0003o000000?o00001?ooool3o`0000Kooooo0_l00006ooooo`;o00002?ooool2o`0000Ko
oooo1?l000000ooooooo0000o`000005o`0000_ooooo0ol00007ooooo`Ko00003_ooool2o`0000co
oooo0_l00006ooooo`Co00000_ooool2o`000004ooooool0003o0000ooooo`Co000000Coooooo`00
0?l0003o00000_ooool2o`0001Oooooo0_l0000/ooooo`007?ooool00ol0003oooooooooo`0Poooo
o`;o00005_ooool2o`0001Cooooo0_l000000ooooooo0000o`000002o`000004ooooool0003o0000
ooooo`;o00001oooool2o`0001_ooooo0_l00004ooooo`Co000000?oooooo`000?l000000oooool2
o`0000Sooooo0_l00002ooooo`;o00001oooool2o`0000?ooooo0_l00005ooooo`;o00001?ooool3
o`0000Sooooo0_l0000@ooooo`Co00004oooool4o`0000;ooooo0_l000001?oooooo0000o`000?oo
ool2o`0000?ooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o000000?ooooo
o`000?l000000_l00009ooooo`;o00001?ooool2o`000003ooooool0003o000000;ooooo0_l00009
ooooo`;o00001Oooool2o`000003ooooool0003o000001;ooooo0_l00002ooooo`Oo000000?ooooo
o`000?l000001oooool2o`000003ooooool0003o000000Gooooo0_l00005ooooo`;o00003?ooool2
o`0000Cooooo0ol00008ooooo`;o00002Oooool2o`0000Gooooo1?l0000Looooo`;o0000D_ooool0
01cooooo00?o0000ooooooooool0>oooool4o`0000Cooooo0ol00002ooooo`;o00002oooool2o`00
00Wooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00000=
ooooo`Co00000_ooool3o`0000;ooooo0_l0000:ooooo`;o000000?oooooo`000?l000003?ooool2
o`000003ooooool0003o000000oooooo0ol00008ooooo`Co00000oooool3o`000003ooooool0003o
000007Wooooo000Looooo`03o`000?oooooooooo04?ooooo0ol00005ooooo`;o00000_ooool3o`00
00Gooooo0_l0000;ooooo`Co00001Oooool4o`0000[ooooo0ol00004ooooo`Co00001Oooool2o`00
00Kooooo0_l0000Booooo`;o00002_ooool4o`0000;ooooo0_l00002ooooo`;o00001?ooool:o`00
0003ooooool0003o0000017ooooo0_l00002ooooo`;o00004_ooool2o`0004kooooo000Looooo`03
o`000?oooooooooo02oooooo0_l0000Booooo`?o000000?oooooo`000?l000000_ooool2o`0000;o
oooo0ol00005ooooo`;o00003Oooool2o`0000Oooooo0_l00007ooooo`;o000000?oooooo`000?l0
00000ol000000ooooooo0000o`000003o`0000;ooooo0_l000000ooooooo0000o`000002o`0000Co
oooo0_l00009ooooo`;o000000?oooooo`000?l000003Oooool2o`000003ooooool0003o000000;o
00001_ooool3o`0000Cooooo1_l00004ooooo`;o00004Oooool2o`0000;ooooo0_l0000Booooo`;o
00002Oooool2o`0004?ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0_ooooo`;o00004_ooool3o`00
0003ooooool0003o000002Wooooo0_l00004ooooo`;o000000?oooooo`000?l000001_l000000ooo
oooo0000o`000002ooooo`Co000000Coooooo`000?l0003o00001?ooool2o`0000Sooooo0_l00000
0ooooooo0000o`000003ooooo`;o00002?ooool2o`0000cooooo0_l00004ooooo`;o000000?ooooo
o`000?l000001Oooool2o`0000kooooo0_l0000Gooooo`;o00002oooool2o`0004?ooooo00001_oo
ooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0;oooool2o`0000Sooooo0_l0000[ooooo`?o00002Oooool2o`0000;ooooo0_l0
0006ooooo`?o000000?oooooo`000?l000000_l000000ooooooo0000o`000004o`000003ooooool0
003o000000Cooooo0_l00007ooooo`Co00001Oooool2o`0000?ooooo0_l00003ooooo`;o00007?oo
ool2o`0000cooooo1?l0000>ooooo`;o00001oooool2o`00053ooooo00000ooooooo410@ooooo`02
ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006ooooo`03o`000?oooooooooo03Wooooo0_l00005
ooooo`;o00008Oooool2o`000004ooooool0003o0000o`0000Wooooo0_l00002ooooo`;o00000_oo
ool2o`0000;ooooo2?l000000ooooooo0000o`000004o`000003ooooool0003o000000gooooo1Ol0
0009ooooo`Co000000?oooooo`000?l000002oooool2o`0000Gooooo0_l00007ooooo`;o00003Ooo
ool2o`00013ooooo0_l0001Iooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09
ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0000hooooo`;o00000oooool2o`000003ooooool0
003o000000Kooooo0_l00003ooooo`;o00001_ooool2o`0000cooooo0_l00006ooooo`?o000000Co
ooooo`000?l0003ooooo2ol000000ooooooo0000o`000002o`000003ooooool0003o000000;o0000
00?oooooo`000?l000000_l00002ooooo`Co00003_ooool2o`0000_ooooo0_l0000;ooooo`Go0000
1Oooool2o`0000;ooooo0_l00003ooooo`;o00003Oooool2o`00023ooooo0_l00019ooooo`0000?o
ooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo
00?o0000ooooooooool0>?ooool2o`0000?ooooo0_l00005ooooo`;o00000_ooool2o`0000?ooooo
0_l00006ooooo`;o00004?ooool2o`0000;ooooo4_l000001Ooooooo0000o`000?l0003ooooo00Ko
00000_ooool2o`0000;ooooo1?l00004ooooo`;o00003Oooool2o`0000cooooo0_l00005ooooo`Co
00000_ooool2o`0000Kooooo0_l00006ooooo`;o00000oooool2o`0000Gooooo0_l00008ooooo`;o
00005_ooool2o`0000Sooooo0_l000000ooooooo0000o`00000looooo`0000?ooooooa0@4?ooool0
0_ooool00ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0
=Oooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`000003oooo
ool0003o000000;o00001?ooool2o`0001;ooooo0_l00002ooooo`;o00000_ooool4o`0000;ooooo
3?l000000ooooooo0000o`00000<o`0000Cooooo0_l00002ooooo`Co00003Oooool2o`0000Kooooo
0_l00004ooooo`;o00001oooool2o`0000;ooooo0_l00003ooooo`;o000000Coooooo`000?l0003o
00001Oooool7o`0000Gooooo0_l00002ooooo`;o00000_ooool4o`0000Wooooo1?l00002ooooo`;o
00003oooool2o`000003ooooool0003o000003cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMg
M`cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0eooooo`;o00000_ooool6o`00
0003ooooool0003o000000Gooooo1?l000001?oooooo0000o`000?ooool2o`0001;ooooo0_l00006
ooooo`;o000000?oooooo`000?l000000_oooolAo`000003ooooool0003o000000Ko00000_ooool4
o`0000;ooooo0_l00003ooooo`;o00003_ooool2o`0000;ooooo0_l0000Fooooo`Ko00001_ooool5
o`0000[ooooo0_l00002ooooo`;o00001?ooool2o`0000Gooooo1Ol000000ooooooo0000o`00001@
ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o
0000ooooooooool0>oooool2o`0000Gooooo0_l00004ooooo`;o000000Coooooo`000?l0003o0000
0oooool2o`0000Sooooo0_l0000:ooooo`;o00000_ooool5o`0000;ooooo5Ol00002ooooo`Oo0000
2Oooool2o`0000_ooooo0_l000000ooooooo0000o`000003ooooo`?o000000?oooooo`000?l00000
3Oooool2o`0000?ooooo1?l00006ooooo`;o00000_ooool2o`0000Kooooo0_l0000<ooooo`;o0000
2?ooool2o`0005?ooooo000Looooo`03o`000?oooooooooo04;ooooo0_l00004ooooo`;o000000Co
ooooo`000?l0003o00000_ooool3o`0000Kooooo1?l00002ooooo`;o00001_ooool2o`000003oooo
ool0003o000000?o00001_oooolKo`0001Cooooo1?l00006ooooo`?o000000?oooooo`000?l00000
3Oooool2o`000003ooooool0003o000000;ooooo0_l00006ooooo`;o00002_ooool2o`000004oooo
ool0003o0000o`0001Wooooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o0000
0oooool2o`0000Oooooo0_l00003ooooo`?o00002Oooool;o`000003ooooool0003o000001Co0000
1?ooool3o`0000Gooooo0_l0000:ooooo`Go00002Oooool2o`00013ooooo0ol00002ooooo`;o0000
1Oooool4o`0000;ooooo0_l00007ooooo`?o00002Oooool2o`0000;ooooo0ol00009ooooo`;o0000
3?ooool2o`0000;ooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`0Iooooo`;o0000;_oo
ool2o`0000;ooooo1?l0000=ooooo`;o00001Oooool2o`0000?ooooo9?l00002ooooo`?o00001Ooo
ool4o`0000[ooooo0ol00009ooooo`;o000000?oooooo`000?l000001oooool2o`0000Cooooo0ol0
0002ooooo`;o000000?oooooo`000?l000002_l0000?ooooo`Ko00000_ooool3o`0000Sooooo0ol0
000<ooooo`;o000000Coooooo`000?l0003o0000>_ooool001cooooo00?o0000ooooooooool06Ooo
ool2o`0000gooooo0_l0000:ooooo`;o00000oooool2o`0000?ooooo0_l00009ooooo`;o00000_oo
ool4o`0000Sooooo0_l00003ooooo`;o00001Oooool2o`0000?ooooo0ol00002ooooo`oo000000?o
ooooo`000?l000003ol000001?oooooo0000o`000?ooool2o`0000Cooooo0_l0000Dooooo`;o0000
0oooool2o`0000Oooooo0_l00004oooooa?o00004?ooool5o`0000kooooo0ol000000ooooooo0000
o`000005ooooo`;o00000oooool4o`0003_ooooo000Looooo`03o`000?oooooooooo02Sooooo0_l0
000:ooooo`;o00000oooool2o`0000?ooooo0_l0000Iooooo`;o000000?oooooo`000?l000000ooo
ool4o`0000?ooooo0_l00003ooooob?o00000_ooool5o`0001Wooooo0_l0000@oooooaKo00004_oo
ool2o`0000?ooooo0_l0000;ooooo`Co00001Oooool2o`000003ooooool0003o000000;o0000?Ooo
ool001cooooo00?o0000ooooooooool0>Oooool2o`0000Oooooo0ol00004ooooo`;o00004Oooool2
o`0000?ooooo1?l00003ooooo`;o00000oooool2o`000003ooooool0003o0000017o000000?ooooo
o`000?l000002ol000000ooooooo0000o`000003o`0000?ooooo0_l00006ooooo`;o000000?ooooo
o`000?l000000_ooool2o`000003ooooool0003o000000;ooooo0_l00008ooooo`;o00001_ooool4
o`000003ooooool0003o000000;o000000?oooooo`000?l000003Ol0000Dooooo`;o00002oooool2
o`0000[ooooo0_l00006ooooo`;o0000=oooool001cooooo00?o0000ooooooooool0>Oooool3o`00
00Kooooo0ol00004ooooo`;o00001?ooool2o`0001Cooooo1?l000000ooooooo0000o`000004oooo
ob?o000000?oooooo`000?l000001?ooool2o`0000Kooooo0_l000001Ooooooo0000o`000?l0003o
oooo00;o000000?oooooo`000?l000000_ooool2o`0000Kooooo1Ol00004ooooo`Go000000?ooooo
o`000?l000004_l0000:ooooo`;o00007oooool2o`0000Sooooo0_l0000gooooo`007?ooool00ol0
003oooooooooo`0Uooooo`;o00002oooool2o`0000Cooooo1?l00003ooooo`;o00002?ooool2o`00
00Cooooo0ol00002ooooo`;o000000?oooooo`000?l000003?ooool7o`0000?ooooo9?l000000ooo
oooo0000o`00000@ooooo`;o00001?ooool2o`000003ooooool0003o000000;ooooo1?l000001?oo
oooo0000o`000?ooool2o`0000Cooooo1Ol000000ooooooo0000o`00000?o`000004ooooool0003o
0000o`0000Wooooo0_l0000@ooooo`;o00000oooool2o`0000Sooooo0_l00004ooooo`;o0000>ooo
ool001cooooo00?o0000ooooooooool09Oooool2o`0000_ooooo0_l00004ooooo`;o00001Oooool2
o`0000Sooooo0_l00005ooooo`;o00000_ooool2o`000003ooooool0003o000000Sooooo0_l00002
ooooo`Ko000000?oooooo`000?l000008Ol000000ooooooo0000o`000002ooooo`Co00003_ooool2
o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`Co00002_ooool5o`000003ooooool0003o
000001?o000000?oooooo`000?l000002?ooool2o`0000kooooo0_l00003ooooo`;o00000_ooool2
o`0000Cooooo0_l00004ooooo`?o0000>_ooool001cooooo00?o0000ooooooooool0<_ooool2o`00
00[ooooo0_l0000<ooooo`;o00001Oooool2o`0000cooooo0_l00002ooooo`;o00000ooooolXo`00
0003ooooool0003o000000Go00003?ooool2o`0001Wooooo1_l000000ooooooo0000o`00000Bo`00
0003ooooool0003o000000Sooooo1?l00005ooooo`;o00001oooool2o`0000Gooooo0_l00008oooo
o`;o000000?oooooo`000?l00000>_ooool001cooooo00?o0000ooooooooool0?_ooool2o`0000[o
oooo1?l00005ooooo`;o00003_ooool2o`0000Gooooo0_l00002ooooo`Go000000?oooooo`000?l0
00007?l000001?oooooo0000o`000?l00002ooooo`?o00000oooool2o`00027ooooo1_l000000ooo
oooo0000o`000002o`0000;ooooo4Ol000000ooooooo0000o`000007ooooo`;o00001Oooool2o`00
00Oooooo1?l00007ooooo`;o00000oooool3o`000003ooooool0003o000003[ooooo000Looooo`;o
0000<oooool2o`0001Kooooo0_l0000=ooooo`;o00002?ooool2o`0000Gooooo0_l000000ooooooo
0000o`00000Go`000003ooooool0003o000000[o00000_ooool3o`000003ooooool0003o000000?o
oooo0_l0000Fooooo`?o00002?ooool6o`000003ooooool0003o000000Oo000000?oooooo`000?l0
00003_l00004ooooo`;o00001?ooool2o`0000gooooo0_l00002ooooo`;o00000oooool4o`000003
ooooool0003o000000Co00001?ooool2o`0003Cooooo000Looooo`03o`000?oooooooooo027ooooo
0_l0000?ooooo`;o00000_ooool2o`0000_ooooo0_l00005ooooo`;o00000oooool2o`0000Sooooo
0_l00009ooooo`Co00000_oooolZo`000004ooooool0003o0000o`00017ooooo0_l0000;ooooo`?o
00000_ooool2o`0000Cooooo4?l000000ooooooo0000o`00000?o`0000?ooooo0_l00004ooooo`;o
00002Oooool2o`0000Kooooo0_l00005ooooo`;o00000oooool2o`0000Kooooo0_l0000dooooo`00
7?ooool00ol0003oooooooooo`0Qooooo`Co00004Oooool2o`0000Cooooo0_l00005ooooo`;o0000
2_ooool2o`0000_ooooo0_l00006ooooo`Co000000?oooooo`000?l000004Ol000000ooooooo0000
o`00000Eo`000003ooooool0003o000000Sooooo0_l000000ooooooo0000o`000005ooooo`;o0000
3?ooool2o`0000;ooooo:?l00006ooooo`;o00000oooool2o`0000Oooooo0_l00006ooooo`;o0000
5?ooool2o`0003;ooooo000Looooo`03o`000?oooooooooo02?ooooo0_l0000Gooooo`;o00001_oo
ool3o`00017ooooo0ol000000ooooooo0000o`000009ooooo`Ko00000_ooool7o`000004ooooool0
003o0000oooooaOo000000Coooooo`000?l0003o00001?ooool2o`0000Cooooo0_l000001?oooooo
0000o`000?ooool2o`0000_ooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo8Ol0000;
ooooo`;o00000oooool4o`0000;ooooo0_l00009ooooo`;o00005?ooool2o`0003;ooooo000Loooo
o`03o`000?oooooooooo03Sooooo0_l0000:ooooo`?o00002_ooool4o`0000?ooooo0ol0000<oooo
o`;o000000Goooooo`000?l0003o0000ooooo`0Lo`0000;ooooo1Ol000001?oooooo0000o`000?l0
0004ooooo`;o00001?ooool5o`000003ooooool0003o000000Cooooo0_l00005ooooo`;o00001_oo
ool2o`000003ooooool0003o000000;ooooo7Ol00007ooooo`Co00001oooool2o`0000;ooooo0_l0
0004ooooo`?o00003?ooool2o`0000cooooo0_l0000`ooooo`007?ooool00ol0003oooooooooo`0h
ooooo`;o00002_ooool2o`0000Oooooo0_l00002ooooo`Co00000_ooool4o`0000oooooo0ol00000
0ooooooo0000o`00000Ko`0000;ooooo0_l00003ooooo`;o00002oooool9o`0000?ooooo0_l00007
ooooo`;o00001?ooool2o`000003ooooool0003o000000;ooooo3?l00002ooooo`ko00002?ooool5
o`0000Kooooo0_l00008ooooo`?o00003?ooool2o`0000Wooooo0_l000000ooooooo0000o`00000`
ooooo`007?ooool00ol0003oooooooooo`0Hooooo`;o0000:_ooool2o`0000Kooooo0ol00008oooo
o`?o00004?ooool2o`0000;ooooo8ol000001?oooooo0000o`000?l0000:ooooo`Ko000000?ooooo
o`000?l000000oooool2o`0000Oooooo0_l0000;oooooaco00002Oooool4o`000004ooooool0003o
0000ooooo`;o00000oooool2o`0000cooooo0ol00009ooooo`;o00001Oooool2o`0003?ooooo000L
ooooo`03o`000?oooooooooo01Sooooo0_l0000Mooooo`;o00004oooool5o`0000Kooooo0ol00004
ooooo`;o00001?ooool2o`0000Gooooo:_l00003ooooo`;o00001Oooool9o`0000?ooooo0ol0000<
ooooo`;o00001OoooolLo`0000Wooooo0_l00003ooooo`;o000000?oooooo`000?l000000oooool2
o`0000cooooo0ol00009ooooo`;o00001Oooool2o`0000_ooooo0_l0000Vooooo`007?ooool00ol0
003oooooooooo`0gooooo`Co00004oooool3o`0000;ooooo0_l00003ooooo`;o00001?ooool2o`00
00Cooooo;_l000000ooooooo0000o`000003ooooo`;o00002_ooool4o`0000Cooooo0_l0000<oooo
o`;o00001?oooolNo`0000oooooo0ol0000=ooooo`?o00001?ooool2o`0000Oooooo0_l0000Boooo
o`;o00009_ooool001cooooo00?o0000ooooooooool0>Oooool2o`0000Sooooo0_l00009ooooo`;o
00000oooool2o`0000Cooooo0_l0000;oooooaSo00000_ooool@o`000003ooooool0003o000000;o
00002Oooool2o`0000oooooo0_l00002ooooo`Co00002OoooolNo`0000oooooo0_l000001?oooooo
0000o`000?l0000:ooooo`?o00000oooool3o`0001;ooooo0_l0000_ooooo`007?ooool00ol0003o
ooooooooo`13ooooo`;o00001Oooool2o`0000gooooo0_l00006ooooo`;o00000oooool2o`000003
ooooool0003o000000?o000000?oooooo`000?l000003Ol00002oooooa3o000000?oooooo`000?l0
00001_ooool2o`0000?ooooo0_l0000?ooooo`;o00000_ooool8o`0000Cooooo6ol00007ooooo`;o
00002oooool5o`0000cooooo0_l00002ooooo`;o00002Oooool2o`0000Oooooo0ol0000_ooooo`00
7?ooool00ol0003oooooooooo`0Jooooo`;o0000;_ooool2o`0001Gooooo0_l00006ooooo`;o0000
00Coooooo`000?l0003ooooo3_l000000ooooooo0000o`00000?o`0000;ooooo0_l00005ooooo`?o
00006Oooool7o`0000Cooooo1?l00002oooooa3o000000?oooooo`000?l000001?l00005ooooo`;o
00000oooool2o`0000Kooooo0_l0000?ooooo`;o00003Oooool2o`0000Oooooo0_l0000`ooooo`00
7?ooool00ol0003oooooooooo`0Jooooo`;o00001Oooool2o`0003oooooo0_l00005ooooo`Go0000
00?oooooo`000?l000006_l000000ooooooo0000o`000003ooooo`;o00001Oooool2o`0000[ooooo
0_l0000?ooooo`;o00000_ooool2o`0000;ooooo0_l00004oooooa_o00002?ooool2o`0000Gooooo
0_l0000=ooooo`;o00001?ooool2o`0000Wooooo0_l0000jooooo`007?ooool00ol0003ooooooooo
o`0Qooooo`;o00004oooool2o`0000Oooooo0_l0000Qooooo`?o00001?ooool3o`000003ooooool0
003o000001co00000_ooool2o`0000;ooooo0_l00003ooooo`;o00003?ooool2o`0000?ooooo0_l0
0005ooooo`;o00001oooool3o`000003ooooool0003o000000Cooooo7?l0000>ooooo`;o000000Co
ooooo`000?l0003ooooo0_l00007ooooo`;o00001?ooool2o`0000;ooooo0_l00005ooooo`;o0000
>_ooool001cooooo00?o0000ooooooooool0=_ooool2o`0000Oooooo0_l00006ooooo`Co00006?oo
ool2o`0000Cooooo0_l00002ooooob;o000000?oooooo`000?l000001?ooool2o`0000Gooooo0_l0
000:ooooo`;o00001?ooool5o`0000Kooooo0_l00008oooooaSo000000?oooooo`000?l000004Ooo
ool2o`000003ooooool0003o0000017ooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0h
ooooo`;o00003Oooool4o`0001[ooooo0_l00002ooooo`;o00000_ooool3o`0000;ooooo8?l00000
1?oooooo0000o`000?ooool2o`0000Gooooo0_l00003ooooo`;o00002oooool2o`000003ooooool0
003o000000gooooo0_l000000ooooooo0000o`000002oooooaCo000000?oooooo`000?l000002?oo
ool6o`0000[ooooo0_l0000=ooooo`;o00001Oooool2o`0003[ooooo000Looooo`;o0000=_ooool2
o`000003ooooool0003o000002Wooooo1?l000000ooooooo0000o`000004ooooo`;o00000_oooolO
o`0000;ooooo0_l00004ooooo`;o000000Coooooo`000?l0003o00000oooool2o`0000;ooooo0_l0
000Iooooo`;o000000?oooooo`000?l000000_ooool>o`000003ooooool0003o000000?o00002ooo
ool6o`0000[ooooo0_l000000ooooooo0000o`000002o`0000oooooo0_l0000jooooo`007?ooool0
0ol0003oooooooooo`0eooooo`;o00001Oooool3o`0000;ooooo0_l00004ooooo`;o00006_ooool2
o`000003ooooool0003o000000;o00001?ooool2o`0000;ooooo2_l000000ooooooo0000o`00000>
o`0000;ooooo0_l00008ooooo`;o000000Coooooo`000?l0003o00000_ooool7o`0002?ooooo4?l0
000Cooooo`Co00001Oooool2o`000003ooooool0003o000000;o00001oooool2o`0000Oooooo0ol0
000:ooooo`;o0000;?ooool001cooooo00?o0000ooooooooool09_ooool2o`0000Gooooo0_l00006
ooooo`;o00001Oooool3o`0000;ooooo1?l00002ooooo`;o00006_ooool2o`000003ooooool0003o
000000;o00001?ooool2o`0000;ooooo5?l000000ooooooo0000o`000003o`0001Gooooo1Ol0000F
ooooo`Co00001oooool2o`0000Cooooo0_l000000ooooooo0000o`000008o`0000Sooooo0_l0000:
ooooo`Co00002?ooool2o`0000Wooooo0_l00007ooooo`?o00002_ooool2o`0002cooooo000Loooo
o`03o`000?oooooooooo02Kooooo0_l00005ooooo`;o00002oooool2o`000004ooooool0003o0000
ooooo`;o000000?oooooo`000?l000000oooool2o`000003ooooool0003o000000?ooooo0_l0000D
ooooo`;o00001?ooool5o`000003ooooool0003o000000_o000000?oooooo`000?l000002_l00003
ooooo`Co00005?ooool2o`0001?ooooo1?l00007ooooo`Co00001Oooool9o`0000Kooooo0_l00000
0ooooooo0000o`000002ooooo`;o00000oooool2o`0000;ooooo0_l00005ooooo`Ko00002?ooool2
o`0000Gooooo0_l0000looooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00002_ooool2o`00
0004ooooool0003o0000ooooo`;o00001_ooool2o`000003ooooool0003o000000?ooooo0_l0000B
ooooo`Co00000ooooolOo`000003ooooool0003o000000;ooooo1?l00009ooooo`;o00000_ooool2
o`0000Gooooo0_l00002ooooo`;o00002?ooool2o`0000Oooooo0_l00009ooooo`;o00001oooool4
o`0000Wooooo0_l00005ooooo`;o00000oooool2o`0000Wooooo1?l000001?oooooo0000o`000?oo
ool5o`000003ooooool0003o000000?ooooo1Ol0000?ooooo`;o0000:_ooool001cooooo00?o0000
ooooooooool06_ooool2o`0001;ooooo0_l0000dooooo`;o00001Oooool4o`000004ooooool0003o
0000oooooaOo000000?oooooo`000?l000003_ooool7o`0000Wooooo0_l00008ooooo`;o00005ooo
ool2o`0000;ooooo0_l0000Booooo`;o00004oooool2o`000003ooooool0003o000000?o00000_oo
ool3o`000004ooooool0003o0000ooooo`;o00003oooool2o`0002[ooooo000Looooo`03o`000?oo
oooooooo01[ooooo0_l00005ooooo`;o00007_ooool2o`0000?ooooo0_l0000Xooooo`;o000000?o
ooooo`000?l000003_l000000ooooooo0000o`000003o`0000kooooo0_l00002ooooo`;o000000?o
ooooo`000?l000001oooool2o`0001Gooooo0ol0000=ooooo`;o00000_ooool2o`0001;ooooo0_l0
000Mooooo`?o0000@Oooool001cooooo00?o0000ooooooooool08Oooool2o`0000Wooooo0_l00007
ooooo`;o00002_ooool2o`0000?ooooo0_l00008ooooo`;o00006oooool3o`0000?ooooo1?l00000
1?oooooo0000o`000?l00002ooooo`Go000000?oooooo`000?l000001_l00003ooooo`;o00001ooo
ool2o`0000kooooo0_l0000:ooooo`;o00002Oooool3o`000003ooooool0003o000000_ooooo0_l0
000=ooooo`;o00000_ooool2o`0001Oooooo0_l00003ooooo`;o00002?ooool2o`0003gooooo000L
ooooo`03o`000?oooooooooo01Oooooo0_l0000Cooooo`?o00001_ooool2o`0000Sooooo0_l0000>
ooooo`?o00006oooool3o`0000?ooooo1ol00004ooooo`Co000000?oooooo`000?l000000_l00000
0ooooooo0000o`000006o`0000[ooooo1Ol0000>ooooo`;o00001?ooool3o`0000;ooooo0_l00008
ooooo`;o00002oooool2o`0000Kooooo0ol00004ooooo`;o000000Coooooo`000?l0003o00005ooo
ool2o`0000?ooooo0_l00005ooooo`;o000000Coooooo`000?l0003o0000??ooool001cooooo00?o
0000ooooooooool05oooool2o`0001Cooooo0_l0000;ooooo`;o00000oooool2o`0000kooooo0_l0
000Mooooo`;o00000oooool7o`0000?ooooo1ol000001?oooooo0000o`000?l00002ooooo`Go0000
1oooool2o`0000;ooooo1Ol0000>ooooo`Co00000oooool2o`0000;ooooo0ol0000Looooo`Go0000
1Oooool2o`0001Sooooo0_l000000ooooooo0000o`000007ooooo`;o00000_ooool2o`0003cooooo
000Looooo`03o`000?oooooooooo033ooooo0_l00003ooooo`;o00000oooool4o`0000;ooooo0ol0
00000ooooooo0000o`00000Xooooo`;o00001?ooool3o`0000?ooooo1Ol00002ooooo`Oo00000ooo
ool3o`0000Sooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00005ooooo`;o00000_oo
ool2o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000007?ooool2o`0000cooooo0_l0
0007ooooo`;o00001_ooool2o`000003ooooool0003o000000?o00001oooool4o`0003gooooo000L
ooooo`03o`000?oooooooooo02Gooooo0_l00009ooooo`;o00000oooool2o`0000;ooooo0_l00000
0ooooooo0000o`000002ooooo`Ko0000;oooool2o`0000;ooooo1Ol00002ooooo`Oo00006?ooool4
o`000003ooooool0003o000000Gooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l0
00000ooooooo0000o`000002o`0000Gooooo0_l0000:ooooo`;o00001oooool2o`0000?ooooo0_l0
0009ooooo`;o00001oooool2o`0000Kooooo1Ol000000ooooooo0000o`000004ooooo`;o000000?o
ooooo`000?l000000_l0000mooooo`007?ooool00ol0003oooooooooo`0Uooooo`;o00002Oooool2
o`0000Oooooo0_l00002ooooo`;o000000?oooooo`000?l000001?l0000Nooooo`;o00003Oooool9
o`0000Cooooo0_l000000ooooooo0000o`000002o`0000Oooooo0_l0000>ooooo`;o000000?ooooo
o`000?l000000_l00006ooooo`;o00001?ooool2o`0000Cooooo1Ol000001?oooooo0000o`000?l0
0003ooooo`;o00002?ooool4o`0000;ooooo0_l00003ooooo`Oo00002?ooool2o`000003ooooool0
003o000000Cooooo0_l00007ooooo`?o00000oooool2o`0000Cooooo0_l00002ooooo`;o0000?_oo
ool001cooooo00?o0000ooooooooool08?ooool2o`0000kooooo0_l00008ooooo`;o000000?ooooo
o`000?l000001_ooool2o`0001gooooo0_l00008ooooo`;o00000oooool<o`000003ooooool0003o
000000;ooooo0_l00008ooooo`;o00002?ooool2o`000004ooooool0003o0000ooooo`;o00000ooo
ool2o`0000Cooooo1?l000000ooooooo0000o`000002o`0000Oooooo0_l00002ooooo`?o00001?oo
ool2o`0000Oooooo0_l00004ooooo`;o000000?oooooo`000?l000000_ooool4o`0000Wooooo1Ol0
0004ooooo`;o00001oooool2o`0000[ooooo0_l00002ooooo`;o0000?_ooool001cooooo00?o0000
ooooooooool08?ooool2o`0000Wooooo0_l0000=ooooo`;o000000?oooooo`000?l000001Oooool3
o`0002Oooooo0_l00004ooooo`Ko00000_ooool7o`0001Gooooo1Ol00004ooooo`?o00001Oooool2
o`0000?ooooo1?l00008ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o00003Oooool2
o`000003ooooool0003o000000;ooooo0ol0000;ooooo`;o00001?ooool2o`0000Sooooo0_l00006
ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0:oooool2o`0000Oooooo0_l00007oooo
o`;o00000_ooool5o`0000;ooooo0_l0000Tooooo`;o000000Coooooo`000?l0003o00001Oooool2
o`000003ooooool0003o000000;o000000?oooooo`000?l000001?ooool3o`0000Wooooo0_l00005
ooooo`;o00001Oooool3o`0000_ooooo0_l00009ooooo`;o00000oooool5o`0000Sooooo0_l00005
ooooo`;o00001_ooool2o`0000_ooooo0_l00002ooooo`Co00001Oooool2o`000003ooooool0003o
000000Kooooo0ol00007ooooo`;o0000?Oooool001cooooo0_l0000eooooo`;o00002oooool4o`00
00?ooooo0_l00005ooooo`?o00005?ooool4o`0000Oooooo0ol00003ooooo`So00001?ooool2o`00
00;ooooo0ol00006ooooo`;o000000?oooooo`000?l000000oooool2o`0000Sooooo0_l00009oooo
o`Ko00002Oooool2o`0000;ooooo1?l00008ooooo`;o00000_ooool5o`0000Oooooo0_l000000ooo
oooo0000o`000002o`0000Gooooo0_l000001?oooooo0000o`000?l00006ooooo`?o000000?ooooo
o`000?l000001oooool2o`0000;ooooo0_l00003ooooo`;o0000?Oooool001cooooo00?o0000oooo
ooooool0:_ooool2o`0000cooooo0ol00002ooooo`?o00003oooool3o`000003ooooool0003o0000
017ooooo1?l00005ooooo`;o00001_ooool2o`0000;ooooo0_l000000ooooooo0000o`000003oooo
o`;o00001_ooool2o`0000?ooooo0_l00006ooooo`;o00004_ooool3o`0000;ooooo0_l00009oooo
o`So00000_ooool2o`0000Oooooo1_l00003ooooo`;o00000_ooool2o`000003ooooool0003o0000
00?o00000oooool3o`000003ooooool0003o000000Oooooo0ol000000ooooooo0000o`000002o`00
00Cooooo1?l000000ooooooo0000o`000012ooooo`007?ooool00ol0003oooooooooo`0Zooooo`;o
00003?ooool3o`000003ooooool0003o000000;o000000?oooooo`000?l000004?ooool2o`0001[o
oooo0_l0000=ooooo`;o00001Oooool2o`0000Cooooo0_l00003ooooo`;o00000oooool2o`000003
ooooool0003o0000013ooooo1?l0000@ooooo`;o00001Oooool3o`0000?ooooo0_l00002ooooo`?o
00001_ooool2o`0000;ooooo0_l000000ooooooo0000o`000003o`0000?ooooo0ol000000ooooooo
0000o`000007ooooo`Co00000_ooool2o`0000Cooooo1?l00005ooooo`;o0000?_ooool001cooooo
00?o0000ooooooooool0=?ooool4o`0000;ooooo2Ol0000Vooooo`;o00006_ooool2o`0000Sooooo
0_l00004ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Oooooo0ol00008ooooo`;o0000
1?ooool2o`0000Wooooo0_l00004ooooo`Co00001Oooool2o`0000;ooooo1_l000000ooooooo0000
o`000003o`0000Cooooo0_l0000:ooooo`Co00000oooool2o`0000Gooooo1?l00003ooooo`;o0000
?_ooool001cooooo00?o0000ooooooooool0<_ooool6o`0000;ooooo0_l00004ooooo`;o00008Ooo
ool2o`0000Cooooo0_l0000Tooooo`;o00001?ooool4o`0000Oooooo0_l00007ooooo`;o00002Ooo
ool2o`0000Cooooo0_l000000ooooooo0000o`000006ooooo`Co00001?ooool2o`0000Cooooo0ol0
0002ooooo`Ko00000oooool4o`0000[ooooo0_l00003ooooo`?o00001?ooool2o`0000;ooooo1ol0
0013ooooo`007?ooool00ol0003oooooooooo`0Vooooo`;o00002_ooool2o`0000?ooooo0_l0000H
ooooo`?o00003oooool2o`0001Cooooo0_l0000<ooooo`;o00001_ooool2o`0000Cooooo1?l0000@
ooooo`?o00002Oooool2o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`Co00001_ooool2
o`0000;ooooo0_l0000>ooooo`;o00002_ooool2o`0000kooooo1_l00014ooooo`007?ooool00ol0
003oooooooooo`0Vooooo`;o00003oooool2o`0001Sooooo0ol0000Eooooo`;o00002_ooool2o`00
00;ooooo1ol00006ooooo`?o00001Oooool2o`0000Gooooo1?l0000@ooooo`?o00001oooool4o`00
00?ooooo0ol00008ooooo`?o00001_ooool3o`0000;ooooo1?l0000<ooooo`;o00001oooool2o`00
00Kooooo0_l00002ooooo`;o00001oooool5o`0004?ooooo000Looooo`03o`000?oooooooooo03Oo
oooo0_l00002ooooo`;o0000;?ooool5o`0000Oooooo0_l00003ooooo`Ko000000?oooooo`000?l0
00000oooool2o`0000Kooooo0_l00007ooooo`;o00002?ooool2o`000003ooooool0003o000000Co
oooo0_l000000ooooooo0000o`000004ooooo`?o00001Oooool2o`0000Wooooo0_l00006ooooo`;o
000000?oooooo`000?l000000_ooool2o`0000Oooooo0ol00002ooooo`Oo00000_ooool2o`0000Go
oooo0ol00002ooooo`;o00001oooool2o`000003ooooool0003o000004?ooooo000Looooo`03o`00
0?oooooooooo03?ooooo0_l00002ooooo`;o00000_ooool2o`0000kooooo0_l00004ooooo`;o0000
0_ooool2o`0001?ooooo1?l0000=ooooo`;o00000_ooool4o`0001Cooooo0_l00008ooooo`;o0000
00?oooooo`000?l000000_ooool2o`0000?ooooo0ol00004ooooo`;o00003oooool2o`000003oooo
ool0003o000000Oooooo0_l0000;ooooo`?o00001?ooool5o`0000Kooooo0_l000000ooooooo0000
o`000002ooooo`?o00001Oooool2o`0004Sooooo000Looooo`03o`000?oooooooooo03?ooooo0_l0
0007ooooo`;o00003Oooool2o`0000Cooooo1ol0000>ooooo`;o00001?ooool2o`00017ooooo0_l0
000=ooooo`;o00001oooool2o`0000[ooooo0_l00003ooooo`;o00001?ooool2o`0001Gooooo0_l0
00000ooooooo0000o`000002o`0000?ooooo0_l0000Nooooo`?o00001Oooool3o`0000Gooooo0_l0
0018ooooo`007?ooool00ol0003oooooooooo`0looooo`;o00003Oooool4o`0000Cooooo0_l00000
0ooooooo0000o`00000>ooooo`;o00001?ooool2o`0000_ooooo0_l0000Cooooo`;o00001_ooool6
o`0000?ooooo0_l00002ooooo`;o00007_ooool3o`0000Cooooo0_l00003ooooo`;o00000_ooool2
o`0000Oooooo0_l00006ooooo`;o00002Oooool3o`0005Oooooo000Looooo`03o`000?oooooooooo
02kooooo0_l0000Kooooo`Co00001_ooool2o`0000oooooo0_l0000Aooooo`;o000000?oooooo`00
0?l000000_ooool2o`0000Oooooo0_l0000:ooooo`Oo00000oooool2o`0001Gooooo0_l00003oooo
o`;o00001_ooool3o`0000Cooooo0_l00007ooooo`;o00001oooool2o`0000Kooooo1?l00008oooo
o`;o00003Oooool2o`0004Sooooo000Looooo`03o`000?oooooooooo02kooooo0_l00005ooooo`?o
000000?oooooo`000?l000006_ooool3o`0000kooooo0_l0000;ooooo`;o00000_ooool4o`000003
ooooool0003o000000;ooooo1Ol00004ooooo`;o00002_ooool2o`000003ooooool0003o000000[o
oooo0_l00008ooooo`;o00001_ooool2o`0000?ooooo0_l0000=ooooo`;o00006_ooool4o`0000So
oooo0_l00006ooooo`;o00000oooool4o`0000Oooooo0_l0000<ooooo`;o0000;oooool001cooooo
00?o0000ooooooooool0<oooool8o`0000?ooooo0_l0000Fooooo`Co00002?ooool2o`0000;ooooo
0_l0000;ooooo`;o00000_ooool2o`0000Sooooo1?l0000Cooooo`;o00001?ooool2o`0000Cooooo
0_l00008ooooo`;o00003Oooool2o`0000_ooooo0_l0000Booooo`;o000000?oooooo`000?l00000
1?ooool3o`0000Sooooo0_l00005ooooo`?o000000?oooooo`000?l000000_ooool2o`0000Oooooo
0_l0000<ooooo`;o0000;oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Co
oooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo03?ooooo0_l00002oooo
o`;o00001Oooool2o`0001?ooooo0_l00003ooooo`;o00002?ooool2o`0000;ooooo0_l0000Doooo
o`;o000000?oooooo`000?l000000ol0000Jooooo`;o00003Oooool2o`0000_ooooo0_l000000ooo
oooo0000o`00000;ooooo`;o00000_ooool2o`0000kooooo0_l000000ooooooo0000o`000004oooo
o`Co00001oooool2o`0000Gooooo0ol000000ooooooo0000o`00001:ooooo`0000KoooooogMgMonH
V9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o
0000ooooooooool0=oooool2o`0001[ooooo0_l0000Looooo`;o00001oooool4o`000003ooooool0
003o000000;o00001?ooool3o`0000_ooooo0_l0000>ooooo`;o00001_ooool2o`0000;ooooo0_l0
0007ooooo`;o00001_ooool3o`0000Cooooo0ol00002ooooo`;o00003oooool2o`0000?ooooo0_l0
0003ooooo`;o00001oooool2o`0000Oooooo0_l0000:ooooo`;o0000@?ooool00003ooooool@413o
oooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool0=oooool2o`0000Cooooo0_l00009ooooo`?o00003oooool2o`0000Sooooo0_l0
0004ooooo`?o00001?ooool2o`0000Oooooo0_l00003ooooo`Co000000Coooooo`000?l0003ooooo
0ol00003ooooo`;o00000oooool2o`000003ooooool0003o000000gooooo0ol00005ooooo`;o0000
0oooool2o`0000;ooooo0_l00009ooooo`oo00000_ooool2o`0000cooooo0_l00003ooooo`;o0000
4_ooool2o`000004ooooool0003o0000ooooo`Co00001Oooool2o`000003ooooool0003o000000_o
oooo0_l0000`ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`00
0?nHV9SooooooiRHV?lQ8B401_ooool3o`0003;ooooo0_l00009ooooo`;o000000?oooooo`000?l0
00001_ooool3o`0000;ooooo0_l0000;ooooo`;o00001_ooool5o`0000?ooooo0ol00008ooooo`Co
00000oooool2o`000004ooooool0003o0000ooooo`Ko00001Oooool4o`000003ooooool0003o0000
00;o00002_ooool2o`0000;ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00001oooool2
o`0000Oooooo3Ol000001?oooooo0000o`000?l00002ooooo`;o00005Oooool2o`0000Oooooo0_l0
0005ooooo`;o00001?ooool4o`0000Sooooo0_l0000;ooooo`;o0000<?ooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o
0000ooooooooool0<_ooool2o`0000Sooooo0_l00002ooooo`;o00000_ooool2o`0000Oooooo0_l0
000Cooooo`;o000000?oooooo`000?l000002Oooool3o`0000;ooooo1?l00003ooooo`Wo000000?o
ooooo`000?l000001oooool2o`0000?ooooo0_l00003ooooo`;o00001Oooool2o`0000Gooooo0ol0
00000ooooooo0000o`000002o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo
0_l000000ooooooo0000o`000002ooooo`go00001?ooool2o`0001?ooooo0_l00007ooooo`;o0000
0_ooool6o`0000Wooooo0_l00013ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0>?ooool2o`0000;ooooo0_l0
0006ooooo`;o00001Oooool2o`0001[ooooo0_l00005ooooo`Oo00002Oooool7o`000003ooooool0
003o000000Oooooo0_l00008ooooo`;o00001_ooool2o`0000Cooooo0_l00002ooooo`Co00000_oo
ool2o`000003ooooool0003o000000?o00000_ooool4o`000003ooooool0003o000000co00001Ooo
ool2o`0000Oooooo0_l0000Gooooo`Ko000000?oooooo`000?l000001_ooool2o`0004?ooooo0000
1_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003ooooo
ooooo`0dooooo`;o00000_ooool2o`0000Gooooo0_l00003ooooo`;o00001Oooool2o`0000gooooo
0_l0000;ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l00002ooooo`;o0000
1oooool4o`000004ooooool0003o0000o`0000Gooooo0_l0000:ooooo`;o00001_ooool2o`0000So
oooo0_l00008ooooo`;o00001?oooolBo`0000Oooooo0_l00006ooooo`;o00000oooool4o`0000Co
oooo0ol0000:ooooo`;o00001?ooool2o`0004_ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^
kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`0dooooo`;o00002Oooool4
o`000003ooooool0003o000000Gooooo0_l0000=ooooo`;o000000?oooooo`000?l000002oooool2
o`0000Gooooo0_l00004ooooo`;o000000?oooooo`000?l000001ol000000ooooooo0000o`000005
o`0000;ooooo0_l00003ooooo`;o00003oooool2o`0000Oooooo0_l00002ooooo`;o00001OoooolF
o`0000Oooooo0_l00009ooooo`Ko00001?ooool3o`0000Kooooo0_l00002ooooo`;o00002_ooool2
o`0004Gooooo000Looooo`03o`000?oooooooooo02gooooo0_l0000Booooo`;o00002?ooool2o`00
00;ooooo0_l00007ooooo`;o00000oooool2o`0001;ooooo0_l000000ooooooo0000o`000004oooo
oa7o00001oooool2o`0000oooooo0_l00005ooooo`So00001OoooolFo`0000?ooooo0_l00008oooo
o`;o00000oooool2o`0000;ooooo0_l0000=ooooo`;o00001Oooool2o`0000Oooooo0_l00005oooo
o`Co0000??ooool001cooooo00?o0000ooooooooool0;Oooool2o`00023ooooo0_l000000ooooooo
0000o`000004ooooo`;o000000?oooooo`000?l000005oooool2o`0000Cooooo4?l000000ooooooo
0000o`000004ooooo`;o00004oooool2o`0000;ooooo0_l00002ooooo`;o00001Oooool2o`000003
ooooool0003o000000Go000000?oooooo`000?l000003?l00002ooooo`;o00002?ooool2o`0000Oo
oooo1?l0000Booooo`Go00002oooool4o`0000Gooooo0_l0000eooooo`007?ooool00ol0003ooooo
ooooo`13ooooo`;o00002oooool4o`0000Oooooo0_l0000Loooooa7o000000?oooooo`000?l00000
1?ooool2o`0000;ooooo0_l00006ooooo`;o00001oooool2o`0000gooooo6ol00003ooooo`;o0000
2Oooool2o`0000?ooooo1?l0000;ooooo`;o00001oooool3o`0000?ooooo0_l00008ooooo`;o0000
1Oooool2o`0003Gooooo000Looooo`03o`000?oooooooooo04?ooooo0_l0000;ooooo`;o00005ooo
ool2o`0000[ooooo0_l00002oooooaCo00001oooool3o`0000Gooooo0ol0000Booooo`;o00000_oo
oolKo`0000?ooooo0_l00009ooooo`;o00001Oooool2o`0000Wooooo1?l00008ooooo`?o000000Co
ooooo`000?l0003o00002?ooool2o`0003cooooo000Looooo`03o`000?oooooooooo047ooooo0_l0
000Dooooo`;o00004?ooool3o`0000Wooooo0_l000000ooooooo0000o`00000Co`0000?ooooo1_l0
0006ooooo`;o000000?oooooo`000?l000000_l0000<ooooo`Co00000_oooolJo`0000Sooooo0_l0
000<ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000;ooooo`;o000000?o
ooooo`000?l000001_ooool2o`0003oooooo000Looooo`03o`000?oooooooooo03gooooo0_l00002
ooooo`;o00005?ooool2o`00017ooooo0_l00006ooooo`;o000000?oooooo`000?l000005ol00002
ooooo`Co00002oooool4o`0000cooooo0_l00002oooooaco00002?ooool2o`00013ooooo0_l00002
ooooo`;o00003_ooool3o`0000Sooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0moooo
o`;o00005Oooool2o`0000?ooooo0_l00002ooooo`;o00004oooool2o`0000;ooooo6?l00006oooo
o`;o00002_ooool2o`0000cooooo0_l00002oooooago000000?oooooo`000?l000004Oooool2o`00
01?ooooo0ol00003ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0=oooool3o`0000go
oooo0_l00007ooooo`;o00000_ooool2o`000003ooooool0003o000000;o00000_ooool2o`0001;o
oooo0_l00002ooooo`Oo000000?oooooo`000?l000000ol000000ooooooo0000o`000006o`000004
ooooool0003o0000o`0000?ooooo1?l0000:ooooo`;o00003?ooool2o`0000;ooooo8?l0000:oooo
o`;o000000?oooooo`000?l000001?l0000Cooooo`?o00003?ooool2o`00043ooooo000Looooo`03
o`000?oooooooooo03Kooooo1?l0000=ooooo`;o00001_ooool3o`0000;ooooo1Ol00006ooooo`Co
00002_ooool6o`000003ooooool0003o000000Go000000?oooooo`000?l000004Ol00003ooooo`;o
00000_ooool2o`0000Kooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo0_l00007ooooo`co
000000?oooooo`000?l000003ol0000:ooooo`;o000000?oooooo`000?l000000_l0000Fooooo`;o
00002_ooool4o`00043ooooo000Looooo`03o`000?oooooooooo03Kooooo0_l00007ooooo`;o0000
0oooool2o`0000Kooooo0_l000000ooooooo0000o`000004ooooo`;o00002?ooool4o`000003oooo
ool0003o000000Oooooo8?l00008ooooo`?o00001_ooool2o`0000?ooooo0_l00002ooooo`;o0000
0_ooool2o`000003ooooool0003o0000013o000000?oooooo`000?l000003ol000000ooooooo0000
o`00000<ooooo`;o00005_ooool2o`0000?ooooo0_l00005ooooo`;o0000@_ooool001cooooo00?o
0000ooooooooool0?oooool2o`0000?ooooo0_l00004ooooo`Co00004?ooool2o`0000Cooooo0_l0
000:oooooa7o000000?oooooo`000?l000002ol00003ooooo`Go00000oooool2o`0000kooooo0_l0
0002ooooob3o000000?oooooo`000?l000000_ooool2o`0000cooooo0_l00005ooooo`;o00000ooo
ool2o`0000oooooo0_l00019ooooo`007?ooool2o`0004_ooooo0_l0000Booooo`Co00002?ooool2
o`0000Sooooo4ol000000ooooooo0000o`000005o`0000?ooooo1?l00002ooooo`Co00001Oooool2
o`0000Oooooo0_l00005oooooa[o000000Coooooo`000?l0003ooooo0_l0000Gooooo`;o000000?o
ooooo`000?l000000_l0000Cooooo`;o0000AOooool001cooooo00?o0000ooooooooool0=Oooool2
o`0000Cooooo0_l000000ooooooo0000o`00000Pooooo`;o00000oooool2o`0000;ooooo0ol00008
oooooaSo000000?oooooo`000?l000000oooool2o`0000?ooooo0ol00007ooooo`;o00003ooooolH
o`000004ooooool0003o0000o`0000Gooooo0_l000000ooooooo0000o`000002o`00017ooooo0_l0
0007ooooo`;o00002?ooool2o`0000;ooooo1?l00013ooooo`007?ooool00ol0003oooooooooo`0e
ooooo`;o00001?ooool2o`000003ooooool0003o000000Gooooo0_l00007ooooo`;o00002oooool2
o`0000?ooooo0_l00002ooooo`?o00000_ooool4o`0000?ooooo0_l000000ooooooo0000o`00000I
o`0000Wooooo1?l0000Eooooo`;o000000?oooooo`000?l000006Ol00005ooooo`;o000000?ooooo
o`000?l000000_l00006ooooo`;o00004?ooool4o`0000Sooooo0_l000001?oooooo0000o`000?oo
ool2o`0004?ooooo000Looooo`03o`000?oooooooooo04;ooooo0_l000000ooooooo0000o`000007
ooooo`;o00002oooool2o`0000Oooooo0_l00005ooooo`?o00000_ooool2o`000003ooooool0003o
000001Wo00002?ooool2o`000003ooooool0003o000001Cooooo0ol000000ooooooo0000o`00000I
o`0000Wooooo0_l00007ooooo`Co00001_ooool2o`0000Kooooo0_l0000=ooooo`?o0000AOooool0
01cooooo00?o0000ooooooooool0@_ooool2o`0000Oooooo1?l0000Mooooo`;o000000?oooooo`00
0?l000007?l00005ooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`000003o`00
00Sooooo0_l000000ooooooo0000o`000002oooooaSo000000?oooooo`000?l000002Oooool2o`00
00Wooooo0_l00006ooooo`;o00005_ooool4o`0004?ooooo000Looooo`03o`000?oooooooooo03ko
oooo0_l0000;ooooo`Co00008?oooolGo`000003ooooool0003o000000Co00001Oooool2o`0000?o
oooo0_l00003ooooo`;o000000?oooooo`000?l000000ol00004ooooo`;o00000_ooool2o`0000;o
oooo1Ol00003oooooa?o000000?oooooo`000?l000003oooool3o`0002Cooooo0_l00013ooooo`00
7?ooool00ol0003oooooooooo`0nooooo`?o0000;oooool?o`000003ooooool0003o000000Co0000
00?oooooo`000?l000001?l000000ooooooo0000o`000007ooooo`;o00000_ooool3o`0000Kooooo
0_l00002ooooo`;o00001_ooool6o`0000;ooooo4_l00002ooooo`Go00001?ooool2o`0000;ooooo
0_l00002ooooo`?o000000?oooooo`000?l000001?ooool2o`00063ooooo000Looooo`03o`000?oo
oooooooo03oooooo0_l0000Tooooo`?o00002?oooolLo`0000;ooooo0_l00007ooooo`;o00000_oo
ool3o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0000[ooooo1Ol000000ooooooo0000
o`00000?o`0000;ooooo1Ol00004ooooo`;o00000_ooool2o`0000Kooooo0_l00004ooooo`;o0000
4?ooool5o`0004_ooooo000Looooo`03o`000?oooooooooo043ooooo0_l00006ooooo`;o00004?oo
ool2o`0000;ooooo1?l00003ooooo`Go00002?oooolGo`0000;ooooo0_l000000ooooooo0000o`00
000Aooooo`;o00000oooool3o`0000[ooooo1ol00002ooooo`So00000_ooool3o`0000Gooooo0_l0
000Gooooo`;o00002Oooool2o`0000?ooooo1ol0001;ooooo`007?ooool00ol0003oooooooooo`10
ooooo`;o00001_ooool2o`00013ooooo0_l00002ooooo`Co00001_ooool2o`0000Sooooo5ol00002
ooooo`?o00001Oooool2o`0000cooooo0_l00003ooooo`;o00002oooool2o`0000?ooooo0_l00002
ooooo`?o00000_ooool4o`0000Wooooo0_l0000Dooooo`Go000000?oooooo`000?l000001Oooool3
o`0000?ooooo0_l00008ooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0G?ooool2o`00
0003ooooool0003o000000Oooooo0_l00008oooooaKo00001?ooool2o`0000Gooooo0_l00009oooo
o`;o00000_ooool2o`0000?ooooo0_l00003ooooo`;o00003oooool2o`0000;ooooo1_l000000ooo
oooo0000o`000004ooooo`;o00004?ooool2o`0000;ooooo0ol00003ooooo`Co00000oooool2o`00
00cooooo1?l00016ooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00005?ooool2o`0000Ko
oooo0_l00003ooooo`;o000000?oooooo`000?l000000oooool2o`0000;ooooo0_l00002ooooo`;o
00000ooooolIo`0000gooooo0_l00005ooooo`;o00000_ooool2o`0000?ooooo0_l00003ooooo`;o
00001_ooool2o`0000cooooo2?l000001?oooooo0000o`000?ooool2o`00013ooooo0_l00002oooo
o`;o00001_ooool2o`0000Sooooo0_l00007ooooo`;o0000B?ooool001cooooo00?o0000oooooooo
ool0>Oooool2o`0000cooooo0_l00004ooooo`Co00001_ooool2o`0000Cooooo0_l00005ooooo`;o
00001_ooool2o`0000?ooooo6_l00005ooooo`?o00001?ooool2o`0001;ooooo0_l000000ooooooo
0000o`000004ooooo`;o00001Oooool2o`0000;ooooo1Ol000000ooooooo0000o`000002o`0000;o
oooo0_l0000Looooo`;o00002Oooool4o`0000Gooooo0_l0001:ooooo`007?ooool00ol0003ooooo
ooooo`17ooooo`;o00001?ooool2o`0000kooooo0_l0000@ooooo`;o00000_oooolHo`0000Gooooo
0ol0000Dooooo`;o00000_ooool2o`000003ooooool0003o000000_ooooo0_l00002ooooo`Go0000
9Oooool2o`0000Wooooo0_l00006ooooo`?o0000B_ooool001cooooo00?o0000ooooooooool0B_oo
ool2o`0000Oooooo0_l000000ooooooo0000o`000004ooooo`;o00000oooool2o`0000_ooooo0ol0
0002oooooa;o00000_ooool2o`00013ooooo0_l0000<ooooo`;o00000_ooool3o`0000Gooooo0_l0
0002ooooo`;o00004_ooool2o`0000cooooo0_l00004ooooo`;o00001_ooool2o`0001?ooooo0_l0
0003ooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0B_ooool2o`0000Oooooo0_l00000
0ooooooo0000o`000004ooooo`;o00000oooool2o`0000Oooooo0_l00002ooooo`;o00000oooool7
o`0000;ooooo3Ol0000?ooooo`?o00000_ooool2o`0000gooooo0_l00005ooooo`;o00000_ooool2
o`0000oooooo0_l000000ooooooo0000o`00000<ooooo`Go000000?oooooo`000?l000000oooool2
o`000003ooooool0003o000000Sooooo0_l0000>ooooo`;o0000A_ooool001cooooo0_l00016oooo
o`;o00006?ooool4o`000003ooooool0003o000000Cooooo0_l000001?oooooo0000o`000?ooool3
o`0000;ooooo4ol0000:ooooo`;o00001?ooool2o`0000?ooooo0_l0000=ooooo`;o00001_ooool2
o`0000;ooooo0_l0000<ooooo`Co00004Oooool3o`000003ooooool0003o000000?ooooo0_l0000;
ooooo`Co0000E?ooool001cooooo00?o0000ooooooooool0AOooool2o`0001Sooooo1?l000000ooo
oooo0000o`000007ooooo`;o000000?oooooo`000?l000001?l000000ooooooo0000o`00000>o`00
00?ooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo0_l00009ooooo`;o00001oooool2o`00
00?ooooo0_l00003ooooo`;o00000_ooool2o`0000Kooooo0_l00004ooooo`;o00001oooool2o`00
01Wooooo0_l000000ooooooo0000o`000004ooooo`;o0000E?ooool001cooooo00?o0000oooooooo
ool0L_ooool@o`000003ooooool0003o000000?o00000_ooool2o`0000;ooooo0_l00002ooooo`Ko
000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00001oooool2o`000003ooooool0003o0000
00Co00002?ooool3o`0000;ooooo0_l0000=ooooo`;o00002oooool2o`0000[ooooo1?l000000ooo
oooo0000o`000003ooooo`;o00001_ooool2o`000003ooooool0003o000004[ooooo000Looooo`03
o`000?oooooooooo03kooooo0_l0000`ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooo
oooo0000o`000006o`0000;ooooo0_l000000ooooooo0000o`000009ooooo`;o000000?oooooo`00
0?l000000oooool2o`000003ooooool0003o000000oooooo0_l00002ooooo`;o00002?ooool3o`00
00Kooooo0ol0000?ooooo`;o00001?ooool2o`0000[ooooo0_l00008ooooo`?o00001Oooool2o`00
0003ooooool0003o000004[ooooo000Looooo`03o`000?oooooooooo03kooooo0_l0000Gooooo`;o
00004?ooool2o`0000Gooooo0_l00003ooooo`;o00000oooool5o`0000?ooooo0ol0000<ooooo`;o
00007oooool2o`00013ooooo0ol00006ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooo
oooo0000o`000006ooooo`;o00000_ooool2o`0000oooooo0_l0001Dooooo`007?ooool00ol0003o
ooooooooo`1Fooooo`?o00001?ooool2o`0000[ooooo0_l00004ooooo`;o000000Coooooo`000?l0
003ooooo1?l000000ooooooo0000o`000002o`0000Cooooo1Ol00004ooooo`;o00001?ooool4o`00
01gooooo0_l00004ooooo`So00000_ooool2o`0000Wooooo0_l000001?oooooo0000o`000?ooool2
o`0000Wooooo0_l00002ooooo`;o0000IOooool001cooooo00?o0000ooooooooool0E_ooool2o`00
00Gooooo0_l00006ooooo`;o000000?oooooo`000?l000001Oooool:o`0000cooooo0_l00004oooo
o`Co00000_ooool4o`0000Gooooo0_l0000Fooooo`Co00000_ooool8o`0000;ooooo0_l00004oooo
o`;o00006oooool2o`0000;ooooo0_l0001Nooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o
00002_ooool2o`000003ooooool0003o000000Kooooo1ol0000Booooo`;o000000Coooooo`000?l0
003o00002Oooool4o`0001Oooooo0ol00003ooooo`Co00000oooool2o`0000Kooooo0_l00007oooo
o`;o00004_ooool2o`0000;ooooo0_l0001Nooooo`007?ooool00ol0003oooooooooo`11ooooo`;o
00000_ooool2o`0001;ooooo0_l0000:ooooo`;o00001_ooool2o`000003ooooool0003o000000Go
00004_ooool2o`000003ooooool0003o000000Wooooo1Ol0000Mooooo`;o00001Oooool2o`0000oo
oooo0_l00005ooooo`Go00003oooool2o`0005_ooooo000Looooo`03o`000?oooooooooo047ooooo
0_l00002ooooo`;o00008_ooool2o`0000;ooooo0_l000000ooooooo0000o`000004o`0000Oooooo
1?l0000Fooooo`;o00000_ooool2o`0000?ooooo0_l0000Gooooo`;o00007Oooool5o`0000oooooo
0_l0001Kooooo`007?ooool00ol0003oooooooooo`1Wooooo`Co00001oooool3o`0000Sooooo1?l0
0005ooooo`;o00000oooool2o`0000kooooo0_l00003ooooo`;o0000=?ooool2o`0000Cooooo1?l0
000<ooooo`;o0000Foooool001cooooo00?o0000ooooooooool0Ioooool2o`0000[ooooo0_l0000A
ooooo`;o00000oooool3o`0000Cooooo0_l0000<ooooo`;o00002_ooool4o`0000Kooooo0_l0000@
ooooo`;o00003?ooool2o`0000Cooooo1?l0001Yooooo`007?ooool00ol0003oooooooooo`2<oooo
o`;o00001?ooool2o`0000Sooooo0_l00006ooooo`;o00001_ooool4o`0000Kooooo0_l00008oooo
o`;o00001_ooool2o`0000_ooooo0_l00002ooooo`;o00002_ooool4o`00063ooooo000Looooo`03
o`000?oooooooooo06[ooooo0_l00002ooooo`;o00000_ooool2o`0000Kooooo0ol00009ooooo`;o
00005?ooool2o`000003ooooool0003o000000?ooooo0_l00007ooooo`;o00004Oooool2o`0000Ko
oooo0_l000000ooooooo0000o`000008ooooo`;o00000_ooool2o`0000[ooooo1_l00003ooooo`;o
0000FOooool001cooooo00?o0000ooooooooool0J_ooool3o`000003ooooool0003o000000;ooooo
0_l00006ooooo`Go00001oooool3o`0000;ooooo0_l0000:ooooo`;o00001_ooool2o`0000Cooooo
0_l000000ooooooo0000o`000004ooooo`;o00001?ooool2o`0001;ooooo0_l000001?oooooo0000
o`000?l0000?ooooo`;o00002_ooool2o`0000?ooooo0_l0001Iooooo`007?ooool00ol0003ooooo
ooooo`1Wooooo`;o00000_ooool2o`0000;ooooo0_l00009ooooo`;o000000?oooooo`000?l00000
2?ooool2o`0000;ooooo0_l00005ooooo`;o00000oooool2o`0000Cooooo0_l00006ooooo`;o0000
00?oooooo`000?l000001?ooool2o`0000Cooooo0_l0000Booooo`;o00000_ooool2o`0000Cooooo
0_l00009ooooo`;o00002oooool2o`0005gooooo000Looooo`;o0000J?ooool3o`000003ooooool0
003o000000;ooooo1?l00007ooooo`;o00000_ooool2o`0000Oooooo0_l000001?oooooo0000o`00
0?l00005ooooo`Co00001oooool2o`0000Sooooo0_l0000Oooooo`Co00001?ooool4o`0000Wooooo
0ol00002ooooo`;o00001_ooool2o`0000_ooooo0_l0001@ooooo`007?ooool00ol0003ooooooooo
o`1<ooooo`;o00005Oooool7o`000003ooooool0003o000000Cooooo0ol00006ooooo`;o00000_oo
ool2o`0000Oooooo0_l000000ooooooo0000o`000003o`0000Gooooo0_l0000Aooooo`?o00004?oo
ool2o`0000;ooooo0ol00007ooooo`Co00001?ooool2o`000003ooooool0003o000000Sooooo0ol0
0002ooooo`;o00004oooool2o`00053ooooo000Looooo`03o`000?oooooooooo04cooooo0_l0000E
ooooo`Co00002oooool2o`0000oooooo0_l00008ooooo`;o00001Oooool3o`00013ooooo1?l0000?
ooooo`;o000000?oooooo`000?l000000_l0000Booooo`;o00001_ooool4o`0006[ooooo000Loooo
o`03o`000?oooooooooo083ooooo0_l000000ooooooo0000o`00000?ooooo`?o000000?oooooo`00
0?l000002?ooool2o`0000?ooooo1?l0000Booooo`;o00007?ooool3o`0006_ooooo000Looooo`03
o`000?oooooooooo07Cooooo0ol00009ooooo`Co00000oooool2o`0000Sooooo0_l00005ooooo`;o
00002?ooool2o`0000Gooooo0_l000000ooooooo0000o`000007ooooo`;o00006?ooool2o`0000_o
oooo0ol00003ooooo`;o0000IOooool001cooooo00?o0000ooooooooool0Eoooool2o`0001?ooooo
0_l00005ooooo`Co00001Oooool2o`0000Cooooo0_l00003ooooo`;o00001_ooool4o`0000Gooooo
0ol0000?ooooo`Co00001oooool2o`0001;ooooo0_l00004ooooo`;o00001?ooool3o`0000Gooooo
0_l00003ooooo`;o0000IOooool001cooooo00?o0000ooooooooool0Eoooool2o`0001?ooooo0_l0
00000ooooooo0000o`000004o`0000Oooooo0_l00005ooooo`;o00002?ooool5o`0000Kooooo0ol0
0002ooooo`Co00002Oooool4o`0000Cooooo0_l0000@ooooo`;o00000oooool2o`0000[ooooo0ol0
0006ooooo`;o00001_ooool2o`00067ooooo000Looooo`03o`000?oooooooooo06oooooo1?l0000@
ooooo`;o00002?ooool2o`0000kooooo1?l00003ooooo`;o00001?ooool4o`0000Cooooo0_l00003
ooooo`;o00002oooool2o`000003ooooool0003o000000;ooooo0_l0000Aooooo`;o00001_ooool2
o`00067ooooo000Looooo`03o`000?oooooooooo073ooooo0_l00004ooooo`;o00003oooool2o`00
00Oooooo0_l0000Booooo`;o00001_ooool3o`0000Sooooo0_l00005ooooo`?o00000oooool2o`00
0005ooooool0003o0000o`000?ooool00_l0001looooo`007?ooool00ol0003oooooooooo`1`oooo
o`;o00001?ooool2o`0000oooooo1?l00005ooooo`;o00006?ooool5o`0000oooooo1Ol000000ooo
oooo0000o`000002ooooo`;o000000?oooooo`000?l00000O?ooool001cooooo00?o0000oooooooo
ool0Qoooool4o`0001oooooo0_l000000ooooooo0000o`000008ooooo`;o00002?ooool2o`000003
ooooool0003o000000Cooooo0ol000000ooooooo0000o`00001iooooo`007?ooool00ol0003ooooo
ooooo`1@ooooo`;o00008?ooool2o`0000Wooooo0_l00008ooooo`;o00004oooool2o`0000;ooooo
0_l00007ooooo`;o00001Oooool2o`0000Gooooo1?l00009ooooo`;o000000Coooooo`000?l0003o
oooo0_l00002ooooo`;o0000NOooool001cooooo00?o0000ooooooooool0D?ooool2o`00023ooooo
1?l00007ooooo`;o00000_ooool2o`0000Cooooo0_l00003ooooo`;o00003_ooool3o`000003oooo
ool0003o000000Oooooo0_l00005ooooo`;o00001oooool2o`0000Oooooo0_l00003ooooo`;o0000
0oooool4o`0007Wooooo000Looooo`03o`000?oooooooooo067ooooo0_l00006ooooo`;o00002Ooo
ool2o`0000Oooooo0ol000000ooooooo0000o`000004ooooo`;o00000oooool2o`0000_ooooo0ol0
00000ooooooo0000o`000005ooooo`;o00002?ooool2o`0000?ooooo1?l0000;ooooo`;o000000?o
ooooo`000?l000001Oooool2o`0000Gooooo0_l0001dooooo`0000Koooooonk^k_lb<S;o0000oc8b
<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000oooooooo
ool0HOooool2o`0000Kooooo0_l00008ooooo`;o00000_ooool2o`0000Gooooo0_l0000Aooooo`;o
00001_ooool3o`000003ooooool0003o000000?ooooo1?l00008ooooo`;o00000oooool4o`0000So
oooo0_l00004ooooo`Co00002_ooool2o`0000Kooooo0_l0001/ooooo`0000KoooooogMgMonHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000
ooooooooool0Loooool2o`0000;ooooo0_l00002ooooo`;o00005?ooool2o`0000[ooooo2Ol00003
ooooo`;o00005?ooool2o`0000Cooooo1?l0000Booooo`;o0000K?ooool00003ooooool@413ooooo
00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool0G?ooool2o`0001;ooooo0_l00007ooooo`Co00002Oooool2o`0001Oooooo1?l00006
ooooo`;o0000<?ooool2o`0006cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000G?ooool2o`0001;ooooo0_l00007
ooooo`;o00002oooool2o`0001Sooooo0_l0002Wooooo`0000?oooooo`000?ooool00_ooool00ol0
003oooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`1j
ooooo`;o00003_ooool2o`0002cooooo0_l000000ooooooo0000o`00000Eooooo`;o0000MOooool0
0003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol@413o^[Zjoooooonj^[[o
410@00Kooooo00?o0000ooooooooool0L?ooool2o`0000Sooooo0_l0000>ooooo`;o00002oooool3
o`0000Cooooo0_l0000Hooooo`;o000000?oooooo`000?l000003Oooool2o`0000Gooooo0ol0001e
ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`1^ooooo`Co00001?ooool2o`000003ooooool0003o000001Wooooo
0_l000001?oooooo0000o`000?l00004ooooo`;o00002?ooool2o`0000Cooooo0_l0000Jooooo`;o
000000?oooooo`000?l000000_ooool2o`0007Kooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^
kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo06_ooooo0_l00000
0ooooooo0000o`000006ooooo`;o000000?oooooo`000?l000002?ooool2o`000003ooooool0003o
000000cooooo0_l000001?oooooo0000o`000?ooool2o`0000Cooooo0_l00006ooooo`;o00001?oo
ool3o`0000Cooooo0_l00008ooooo`;o00001?ooool2o`0000Kooooo0_l0001jooooo`007?ooool0
0ol0003oooooooooo`1[ooooo`;o00002Oooool2o`0000[ooooo0ol000000ooooooo0000o`000007
ooooo`;o00002Oooool2o`0000Cooooo0_l0000=ooooo`;o00001?ooool2o`0000Sooooo0_l00004
ooooo`;o0000P_ooool001cooooo00?o0000ooooooooool0P_ooool3o`0000Wooooo1?l00008oooo
o`;o00000oooool2o`0000?ooooo0_l00003ooooo`;o00000oooool2o`0000;ooooo0_l00007oooo
o`;o00000_ooool6o`0008Cooooo000Looooo`03o`000?oooooooooo08?ooooo0_l00009ooooo`Co
00002?ooool2o`0000?ooooo0_l00003ooooo`;o00000oooool2o`0000?ooooo0_l00002ooooo`?o
000000?oooooo`000?l000000_l000000ooooooo0000o`000002o`0000;ooooo1?l00024ooooo`00
7?ooool00ol0003oooooooooo`26ooooo`;o00004_ooool2o`0000Sooooo0_l0000=ooooo`Oo0000
00?oooooo`000?l000001?l00028ooooo`007?ooool00ol0003oooooooooo`1gooooo`;o00000_oo
ool2o`0000Wooooo0_l0000Looooo`;o00002?ooool2o`0000Gooooo0_l00008ooooo`;o00001Ooo
ool2o`0000;ooooo0_l0001mooooo`007?ooool00ol0003oooooooooo`1gooooo`;o00000_ooool2
o`0001Sooooo0_l00005ooooo`;o00002Oooool2o`0000;ooooo0_l000000ooooooo0000o`00000D
ooooo`Co00000_ooool2o`0007gooooo000Looooo`03o`000?oooooooooo09Gooooo0_l00005oooo
o`;o000000?oooooo`000?l000001_ooool2o`0000;ooooo0_l000000ooooooo0000o`000004oooo
o`;o00003_ooool2o`0008?ooooo000Looooo`03o`000?oooooooooo09Gooooo0_l00006ooooo`Co
00003Oooool2o`0000Cooooo0_l0002Cooooo`007?ooool00ol0003oooooooooo`1gooooo`;o0000
9?ooool2o`000:[ooooo000Looooo`03o`000?oooooooooo07Oooooo0_l0000gooooo`;o00004Ooo
ool2o`0008Cooooo000Looooo`03o`000?oooooooooo0:kooooo1?l0000Aooooo`;o0000Q?ooool0
01cooooo0_l0002_ooooo`;o0000VOooool001cooooo00?o0000ooooooooool0POooool2o`0000oo
oooo0_l0002eooooo`007?ooool00ol0003oooooooooo`21ooooo`;o00003oooool2o`0001;ooooo
0_l0000Dooooo`;o0000Roooool001cooooo00?o0000ooooooooool0T_ooool2o`0001;ooooo0_l0
000Dooooo`;o0000Roooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`2Looooo`;o0000Zoooool001cooooo00?o0000ooooooooool0W?ooool2o`000:_o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o
0000oooooom;ooooo`007?ooool00ol0003oooooooooo`2?ooooo`;o00003Oooool2o`000:Wooooo
000Looooo`03o`000?oooooooooo08oooooo0_l0000=ooooo`;o0000ZOooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?oooooo
Boooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom:ooooo`00
5?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o
0000ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o0000ooooooooool0oooooomB
ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?oo
ooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`004_ooool00omEEEGoIVIVo`00
003ooooooeCooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Qooooo`04oa0@
4?l0003o0000ooooo`;o000000?o410@ooooooooool05_ooool4o`000008oa0@4?oooooooooooiRH
V?l@413o0000oc8b<_o<c<`3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo<c<co8B4Q
o`000?lQ8B7oc<c<08cooooo002Rooooo`05o`000?ooooooooooooooool000002Oooool6o`0000co
oooo00?o0000ooooooooool00_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40S?ooool00:;ooooo00Go0000
ooooooooooooooooo`00000Kooooo`03o`000?oooooooooo00Kooooo00Go0000oooooooooooooooo
oa0@4003ooooo`05oa0@4?ooooooooooooooool000000oooool00ol0003oooooooooo`2:ooooo`00
X_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l0000<ooooo`03o`000?oooooooooo00Go
oooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go<S8boiRH
V?ooooooV9RHoc8b<P2<ooooo`00X_ooool01Ol0003oQhN7oooooonYZJWo000001_ooooo00?o0000
ooooooooool01?ooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000000ooo
ool01Oo<c<co0000o`000?l0003oc<c<08cooooo002Qooooo`03oa0@4?l0003oMgMg00;o000000?o
V9RHooooooooool06Oooool00ol0003oooooooooo`05ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go
410@oooooooooooooooooa0@4003ooooo`05oa0@4?nj^[[ooooookZj^_l@4100S?ooool00<;ooooo
00?o0000ooooooooool00_ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05o`000?nj^[[ooooookZj^_l00000S?ooool00<3ooooo00?oEEEEofIV
I_l000001?ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0S?ooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1314) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.35823 .67794 Mdot
.36875 .67117 Mdot
.63807 .49499 Mdot
.40825 .41407 Mdot
.7904 .41667 Mdot
.67053 .48892 Mdot
.5658 .62605 Mdot
.59024 .67737 Mdot
.63108 .47904 Mdot
.54891 .72415 Mdot
.60551 .65861 Mdot
.33618 .41935 Mdot
.57216 .65759 Mdot
.43246 .43932 Mdot
.77361 .28559 Mdot
.39594 .38587 Mdot
.36359 .67697 Mdot
.5832 .29333 Mdot
.35472 .43393 Mdot
.65822 .52536 Mdot
.34368 .68736 Mdot
.42442 .4382 Mdot
.39706 .60895 Mdot
.43302 .43972 Mdot
.38497 .42625 Mdot
.37745 .61235 Mdot
.41905 .64815 Mdot
.37856 .45191 Mdot
.38712 .47472 Mdot
.59807 .67519 Mdot
.4448 .27391 Mdot
.77806 .32246 Mdot
.48226 .45228 Mdot
.58614 .22301 Mdot
.56146 .67226 Mdot
.27047 .57993 Mdot
.65804 .48871 Mdot
.59035 .64621 Mdot
.59139 .64154 Mdot
.55543 .67433 Mdot
.59556 .657 Mdot
.39373 .61881 Mdot
.47645 .66415 Mdot
.73374 .48401 Mdot
.43167 .39271 Mdot
.78925 .56046 Mdot
.29399 .68398 Mdot
.44759 .4644 Mdot
.35177 .64945 Mdot
.65147 .33637 Mdot
.72107 .57277 Mdot
.55846 .63977 Mdot
.66098 .52981 Mdot
.10619 .52305 Mdot
.56583 .64581 Mdot
.384 .51046 Mdot
.64676 .48936 Mdot
.4184 .44975 Mdot
.4352 .4434 Mdot
.2593 .43429 Mdot
.45649 .42383 Mdot
.58332 .32412 Mdot
.40513 .58705 Mdot
.54122 .5776 Mdot
.64168 .47727 Mdot
.60117 .6431 Mdot
.37594 .66146 Mdot
.56509 .65797 Mdot
.38047 .52997 Mdot
.68786 .5097 Mdot
.44911 .46466 Mdot
.60465 .65394 Mdot
.41059 .65178 Mdot
.40043 .47236 Mdot
.6564 .4122 Mdot
.78424 .65359 Mdot
.58749 .36415 Mdot
.26391 .54835 Mdot
.25439 .43155 Mdot
.68667 .37228 Mdot
.36924 .4197 Mdot
.49106 .31345 Mdot
.78631 .62779 Mdot
.37438 .6004 Mdot
.41052 .37789 Mdot
.60035 .28983 Mdot
.39803 .4682 Mdot
.81551 .54696 Mdot
.45567 .47051 Mdot
.60803 .37227 Mdot
.62697 .474 Mdot
.36675 .64559 Mdot
.40496 .41235 Mdot
.40832 .48174 Mdot
.2681 .38782 Mdot
.38793 .49578 Mdot
.40414 .43721 Mdot
.34849 .63806 Mdot
.55907 .64086 Mdot
.42194 .50287 Mdot
.72013 .51433 Mdot
.6154 .48312 Mdot
.41744 .40073 Mdot
.65397 .4518 Mdot
.41472 .61526 Mdot
.41013 .48078 Mdot
.58388 .63836 Mdot
.43718 .40992 Mdot
.46265 .79006 Mdot
.37673 .67279 Mdot
.3785 .46162 Mdot
.54318 .33353 Mdot
.20232 .47863 Mdot
.35902 .64703 Mdot
.71466 .52792 Mdot
.36237 .4586 Mdot
.40204 .44698 Mdot
.36591 .6666 Mdot
.62597 .45667 Mdot
.81069 .56435 Mdot
.35093 .62186 Mdot
.58419 .68527 Mdot
.37496 .68522 Mdot
.33849 .43295 Mdot
.64937 .46963 Mdot
.74017 .51721 Mdot
.4486 .76158 Mdot
.4737 .25831 Mdot
.40047 .46689 Mdot
.49166 .68174 Mdot
.62331 .50778 Mdot
.3753 .64583 Mdot
.56806 .66243 Mdot
.44814 .38222 Mdot
.39856 .64903 Mdot
.60848 .66219 Mdot
.55313 .32175 Mdot
.67661 .62355 Mdot
.41187 .62894 Mdot
.53995 .44394 Mdot
.60275 .62837 Mdot
.54849 .65371 Mdot
.4789 .18111 Mdot
.37509 .65824 Mdot
.57499 .33387 Mdot
.57323 .67095 Mdot
.45809 .24396 Mdot
.43693 .3967 Mdot
.45252 .313 Mdot
.29948 .72338 Mdot
.56151 .21119 Mdot
.69124 .64435 Mdot
.55531 .35501 Mdot
.61725 .66314 Mdot
.39565 .42638 Mdot
.36789 .61847 Mdot
.38727 .60804 Mdot
.45421 .42083 Mdot
.38364 .41665 Mdot
.44955 .46843 Mdot
.4263 .48479 Mdot
.31032 .42218 Mdot
.36176 .47345 Mdot
.25929 .6506 Mdot
.36614 .64084 Mdot
.40394 .4188 Mdot
.68497 .49617 Mdot
.46792 .46821 Mdot
.60047 .65569 Mdot
.41736 .44356 Mdot
.40526 .41395 Mdot
.44888 .40766 Mdot
.55456 .64475 Mdot
.81233 .36841 Mdot
.19707 .52216 Mdot
.7879 .35634 Mdot
.58221 .40253 Mdot
.67981 .47389 Mdot
.39203 .45901 Mdot
.57073 .31967 Mdot
.30973 .55971 Mdot
.42561 .41525 Mdot
.35188 .83077 Mdot
.41211 .43549 Mdot
.79435 .40112 Mdot
.39475 .52034 Mdot
.71953 .28406 Mdot
.47995 .30223 Mdot
.38703 .43517 Mdot
.483 .63643 Mdot
.63248 .65946 Mdot
.60647 .46085 Mdot
.59104 .65754 Mdot
.68272 .50123 Mdot
.64144 .49417 Mdot
.53269 .59762 Mdot
.3464 .39154 Mdot
.46935 .47841 Mdot
.43818 .48505 Mdot
.69819 .49066 Mdot
.40112 .59 Mdot
.55922 .31111 Mdot
.34279 .66587 Mdot
.87051 .50447 Mdot
.76627 .54356 Mdot
.54137 .63467 Mdot
.58524 .3106 Mdot
.62447 .4948 Mdot
.6322 .4635 Mdot
.54229 .34526 Mdot
.42934 .4662 Mdot
.38131 .65171 Mdot
.5262 .17761 Mdot
.5148 .79501 Mdot
.43645 .1617 Mdot
.35014 .63748 Mdot
.52721 .72229 Mdot
.59791 .67063 Mdot
.6594 .50283 Mdot
.40195 .4441 Mdot
.42166 .46632 Mdot
.33056 .67635 Mdot
.44609 .47122 Mdot
.39088 .70096 Mdot
.39354 .44196 Mdot
.6593 .58356 Mdot
.59934 .31454 Mdot
.53632 .59466 Mdot
.50218 .24793 Mdot
.37284 .60484 Mdot
.30862 .31763 Mdot
.65237 .4551 Mdot
.30424 .55188 Mdot
.60497 .64247 Mdot
.56876 .31348 Mdot
.65058 .46149 Mdot
.5489 .3206 Mdot
.35586 .46026 Mdot
.67488 .5133 Mdot
.54247 .35634 Mdot
.38671 .33926 Mdot
.45879 .40877 Mdot
.39286 .7789 Mdot
.56244 .67818 Mdot
.33791 .66404 Mdot
.45846 .43175 Mdot
.6762 .46264 Mdot
.46967 .39479 Mdot
.70427 .67963 Mdot
.6774 .56796 Mdot
.61453 .49164 Mdot
.64474 .56257 Mdot
.58262 .31771 Mdot
.73532 .61283 Mdot
.50634 .70571 Mdot
.35848 .67388 Mdot
.38198 .49355 Mdot
.69907 .26185 Mdot
.57227 .67034 Mdot
.44687 .42075 Mdot
.65533 .28401 Mdot
.55958 .66182 Mdot
.41731 .45167 Mdot
.60734 .67194 Mdot
.38859 .6081 Mdot
.22612 .426 Mdot
.35537 .66726 Mdot
.43195 .48546 Mdot
.57669 .63792 Mdot
.67375 .45433 Mdot
.37691 .61718 Mdot
.43696 .46348 Mdot
.38137 .45342 Mdot
.58382 .54071 Mdot
.40671 .42489 Mdot
.80792 .38414 Mdot
.38975 .43871 Mdot
.64958 .50642 Mdot
.38472 .40078 Mdot
.15847 .51062 Mdot
.52247 .61258 Mdot
.37679 .65935 Mdot
.61247 .46863 Mdot
.63564 .48284 Mdot
.73782 .46238 Mdot
.5374 .66945 Mdot
.36 .45049 Mdot
.67727 .46633 Mdot
.34997 .31463 Mdot
.60923 .63686 Mdot
.45164 .4883 Mdot
.52579 .47865 Mdot
.64235 .33952 Mdot
.65785 .52992 Mdot
.47707 .39086 Mdot
.41289 .61925 Mdot
.39898 .41171 Mdot
.63144 .46047 Mdot
.37937 .3675 Mdot
.3671 .4537 Mdot
.34679 .71986 Mdot
.5898 .54819 Mdot
.58461 .62491 Mdot
.40379 .51644 Mdot
.45037 .43196 Mdot
.6782 .50342 Mdot
.37001 .60879 Mdot
.61019 .63598 Mdot
.3883 .61526 Mdot
.68302 .2644 Mdot
.40766 .78041 Mdot
.35096 .34847 Mdot
.57691 .30066 Mdot
.63564 .29989 Mdot
.69429 .26699 Mdot
.27412 .31854 Mdot
.34757 .2868 Mdot
.6008 .21099 Mdot
.63943 .45179 Mdot
.65626 .29461 Mdot
.64037 .48667 Mdot
.37492 .42641 Mdot
.64978 .47142 Mdot
.68792 .25385 Mdot
.39552 .44064 Mdot
.6569 .47641 Mdot
.28788 .34331 Mdot
.39704 .41489 Mdot
.36204 .67233 Mdot
.84487 .46952 Mdot
.1973 .39894 Mdot
.66578 .57126 Mdot
.64962 .51838 Mdot
.38803 .25688 Mdot
.40357 .43514 Mdot
.38166 .40354 Mdot
.36174 .63029 Mdot
.48202 .4158 Mdot
.58269 .34605 Mdot
.58871 .31921 Mdot
.59504 .71735 Mdot
.50756 .3735 Mdot
.39258 .51765 Mdot
.37341 .62043 Mdot
.31607 .448 Mdot
.6383 .40188 Mdot
.6541 .32846 Mdot
.60465 .61997 Mdot
.84282 .46722 Mdot
.41169 .67835 Mdot
.60848 .59863 Mdot
.59247 .48809 Mdot
.35899 .65923 Mdot
.80355 .34959 Mdot
.58849 .65431 Mdot
.40465 .79739 Mdot
.45564 .55919 Mdot
.42908 .46346 Mdot
.59485 .63024 Mdot
.42993 .37044 Mdot
.20606 .38179 Mdot
.48554 .82648 Mdot
.47188 .51389 Mdot
.45817 .46914 Mdot
.6195 .40913 Mdot
.41112 .44432 Mdot
.76022 .63273 Mdot
.3857 .44154 Mdot
.38559 .61858 Mdot
.567 .72998 Mdot
.57587 .70391 Mdot
.20486 .59539 Mdot
.74208 .62496 Mdot
.55647 .35609 Mdot
.39549 .44567 Mdot
.43119 .46175 Mdot
.57555 .35396 Mdot
.40261 .60951 Mdot
.44122 .47931 Mdot
.3117 .30766 Mdot
.41579 .4806 Mdot
.59656 .65179 Mdot
.43454 .56933 Mdot
.32673 .70541 Mdot
.40619 .4907 Mdot
.41814 .61081 Mdot
.54971 .63035 Mdot
.57566 .64085 Mdot
.38276 .51918 Mdot
.56043 .68055 Mdot
.41778 .43039 Mdot
.51844 .83239 Mdot
.41014 .63817 Mdot
.40411 .71551 Mdot
.39675 .63922 Mdot
.25419 .53811 Mdot
.55583 .65247 Mdot
.68711 .58561 Mdot
.37894 .37458 Mdot
.58391 .65475 Mdot
.31874 .67779 Mdot
.39936 .38861 Mdot
.45276 .39614 Mdot
.48101 .19822 Mdot
.64073 .50949 Mdot
.59292 .55616 Mdot
.59695 .67652 Mdot
.44661 .45214 Mdot
.38348 .48653 Mdot
.54524 .63497 Mdot
.51855 .81573 Mdot
.22845 .38118 Mdot
.39202 .43986 Mdot
.38018 .62851 Mdot
.37899 .64204 Mdot
.46673 .43333 Mdot
.40652 .40221 Mdot
.66073 .46775 Mdot
.65525 .4454 Mdot
.68438 .50939 Mdot
.59935 .56068 Mdot
.68313 .58339 Mdot
.78499 .4777 Mdot
.55488 .67379 Mdot
.5111 .73868 Mdot
.61191 .35817 Mdot
.42767 .49285 Mdot
.6375 .51593 Mdot
.44721 .43 Mdot
.41917 .42237 Mdot
.5316 .65238 Mdot
.73851 .3558 Mdot
.37039 .69616 Mdot
.39413 .59737 Mdot
.61388 .6336 Mdot
.34981 .49981 Mdot
.56561 .60571 Mdot
.55953 .32067 Mdot
.52203 .20124 Mdot
.60549 .64708 Mdot
.3617 .67047 Mdot
.57141 .67945 Mdot
.41867 .47175 Mdot
.35196 .46512 Mdot
.3635 .65925 Mdot
.57753 .36045 Mdot
.4746 .40529 Mdot
.41374 .45228 Mdot
.28804 .72486 Mdot
.50508 .21637 Mdot
.64773 .59569 Mdot
.389 .43545 Mdot
.39331 .48482 Mdot
.54245 .36658 Mdot
.41717 .47903 Mdot
.45762 .4547 Mdot
.20933 .47994 Mdot
.46672 .76638 Mdot
.59097 .31598 Mdot
.53053 .82426 Mdot
.34951 .6416 Mdot
.73944 .28965 Mdot
.66704 .50612 Mdot
.55839 .71468 Mdot
.20885 .41405 Mdot
.66483 .5288 Mdot
.68986 .65152 Mdot
.76107 .31162 Mdot
.61015 .57589 Mdot
.66343 .43363 Mdot
.41383 .66275 Mdot
.43411 .48196 Mdot
.40521 .44949 Mdot
.57769 .32179 Mdot
.38601 .64427 Mdot
.56957 .54045 Mdot
.68928 .75915 Mdot
.42061 .43801 Mdot
.40687 .70333 Mdot
.6201 .76931 Mdot
.64199 .34743 Mdot
.55882 .33512 Mdot
.59071 .3379 Mdot
.39697 .4481 Mdot
.19374 .50301 Mdot
.37596 .61356 Mdot
.43797 .4622 Mdot
.36678 .47991 Mdot
.64728 .51498 Mdot
.39011 .66519 Mdot
.62334 .46002 Mdot
.71151 .58787 Mdot
.79001 .36899 Mdot
.32641 .78239 Mdot
.56226 .64568 Mdot
.73527 .68453 Mdot
.61406 .66008 Mdot
.49706 .30907 Mdot
.6305 .52104 Mdot
.40343 .40751 Mdot
.37494 .60516 Mdot
.44763 .44481 Mdot
.4031 .40363 Mdot
.43086 .46439 Mdot
.40214 .49314 Mdot
.25669 .73978 Mdot
.5474 .35542 Mdot
.3637 .39802 Mdot
.64475 .50361 Mdot
.79184 .59399 Mdot
.77337 .65842 Mdot
.4328 .45748 Mdot
.38582 .44992 Mdot
.40715 .63675 Mdot
.45257 .42113 Mdot
.61548 .65154 Mdot
.34183 .63917 Mdot
.39934 .47616 Mdot
.84105 .4996 Mdot
.38165 .46963 Mdot
.75169 .31354 Mdot
.57731 .67954 Mdot
.4747 .79541 Mdot
.34725 .41757 Mdot
.65508 .57047 Mdot
.5925 .55568 Mdot
.65515 .46383 Mdot
.59506 .68673 Mdot
.65719 .48605 Mdot
.66094 .77971 Mdot
.35107 .47133 Mdot
.39279 .42545 Mdot
.41439 .4995 Mdot
.68049 .47485 Mdot
.81726 .522 Mdot
.75079 .59064 Mdot
.34324 .41909 Mdot
.67868 .47898 Mdot
.41288 .59856 Mdot
.46542 .21868 Mdot
.39836 .62744 Mdot
.55119 .31172 Mdot
.59945 .6644 Mdot
.5819 .35423 Mdot
.64491 .26699 Mdot
.37157 .67318 Mdot
.34158 .67829 Mdot
.66709 .50263 Mdot
.46698 .55859 Mdot
.20976 .30807 Mdot
.45677 .56178 Mdot
.48181 .28121 Mdot
.36662 .62857 Mdot
.39415 .48051 Mdot
.51921 .30609 Mdot
.47015 .58567 Mdot
.65476 .48382 Mdot
.42922 .42139 Mdot
.22559 .42053 Mdot
.66069 .46757 Mdot
.41286 .50148 Mdot
.64092 .50479 Mdot
.59312 .66254 Mdot
.62924 .5073 Mdot
.33282 .63844 Mdot
.38946 .46525 Mdot
.25824 .248 Mdot
.58419 .27974 Mdot
.39975 .43304 Mdot
.61303 .63061 Mdot
.6496 .70122 Mdot
.42766 .40963 Mdot
.53753 .34157 Mdot
.66765 .47705 Mdot
.47256 .53365 Mdot
.38942 .44048 Mdot
.68132 .4831 Mdot
.35986 .67967 Mdot
.61392 .67424 Mdot
.26726 .40011 Mdot
.63887 .57614 Mdot
.36036 .6305 Mdot
.5541 .41827 Mdot
.57275 .68948 Mdot
.39436 .48575 Mdot
.38377 .49334 Mdot
.38138 .63149 Mdot
.40402 .32489 Mdot
.41113 .3966 Mdot
.3714 .4178 Mdot
.65447 .51143 Mdot
.66061 .48397 Mdot
.3019 .35335 Mdot
.6389 .4486 Mdot
.35124 .46273 Mdot
.3835 .62931 Mdot
.40832 .41209 Mdot
.40514 .64693 Mdot
.45093 .4196 Mdot
.33515 .39791 Mdot
.40148 .60822 Mdot
.55248 .59823 Mdot
.42425 .42066 Mdot
.47785 .46706 Mdot
.43962 .41291 Mdot
.43464 .47973 Mdot
.65136 .46664 Mdot
.55968 .32696 Mdot
.37896 .4981 Mdot
.53542 .37413 Mdot
.55234 .31834 Mdot
.59615 .69912 Mdot
.64438 .51365 Mdot
.5735 .34428 Mdot
.62986 .77111 Mdot
.67665 .51528 Mdot
.58299 .33323 Mdot
.77427 .65601 Mdot
.55816 .66866 Mdot
.41401 .6273 Mdot
.39386 .41496 Mdot
.64688 .25454 Mdot
.29409 .68885 Mdot
.63878 .44081 Mdot
.39219 .43705 Mdot
.44385 .41996 Mdot
.3601 .61059 Mdot
.68121 .78396 Mdot
.68797 .50924 Mdot
.37006 .46131 Mdot
.37725 .66608 Mdot
.66136 .81453 Mdot
.64766 .50043 Mdot
.58235 .32771 Mdot
.55193 .66476 Mdot
.32868 .6952 Mdot
.4463 .76189 Mdot
.57294 .62467 Mdot
.59517 .4617 Mdot
.71306 .57675 Mdot
.36244 .46124 Mdot
.63562 .51663 Mdot
.44536 .17423 Mdot
.33934 .51061 Mdot
.55918 .5761 Mdot
.39616 .2514 Mdot
.35888 .65444 Mdot
.61462 .65668 Mdot
.55189 .35529 Mdot
.35256 .63198 Mdot
.36646 .67693 Mdot
.54071 .64271 Mdot
.2079 .51739 Mdot
.52268 .48251 Mdot
.59493 .64516 Mdot
.55107 .23011 Mdot
.76746 .44335 Mdot
.63946 .51781 Mdot
.58216 .34641 Mdot
.6603 .27661 Mdot
.3928 .6166 Mdot
.84591 .45096 Mdot
.48709 .19268 Mdot
.40436 .43708 Mdot
.57055 .34281 Mdot
.80809 .50111 Mdot
.73302 .73305 Mdot
.55829 .65714 Mdot
.59036 .70775 Mdot
.58695 .33595 Mdot
.45767 .43127 Mdot
.45969 .22872 Mdot
.37475 .41661 Mdot
.59674 .6686 Mdot
.27786 .40517 Mdot
.36669 .67543 Mdot
.54338 .64941 Mdot
.51747 .19854 Mdot
.41949 .43135 Mdot
.42468 .41928 Mdot
.52268 .25073 Mdot
.35835 .61869 Mdot
.65578 .4637 Mdot
.36274 .46853 Mdot
.41475 .44875 Mdot
.37188 .49922 Mdot
.4123 .51341 Mdot
.20885 .45949 Mdot
.37627 .4344 Mdot
.77168 .56906 Mdot
.45918 .46929 Mdot
.43014 .42829 Mdot
.41764 .61334 Mdot
.32734 .78987 Mdot
.72798 .58181 Mdot
.41576 .4452 Mdot
.385 .47693 Mdot
.5441 .65405 Mdot
.48853 .53853 Mdot
.47468 .54627 Mdot
.47834 .52573 Mdot
.36821 .27052 Mdot
.468 .4226 Mdot
.38296 .65519 Mdot
.54039 .35615 Mdot
.3667 .46087 Mdot
.38141 .65926 Mdot
.43815 .39931 Mdot
.66384 .46771 Mdot
.67777 .51402 Mdot
.33593 .49815 Mdot
.56992 .34997 Mdot
.44373 .64423 Mdot
.50436 .73779 Mdot
.67868 .50689 Mdot
.39008 .42478 Mdot
.52804 .65728 Mdot
.63224 .4609 Mdot
.66574 .5609 Mdot
.43199 .3392 Mdot
.37016 .61394 Mdot
.36506 .64399 Mdot
.44936 .31468 Mdot
.6951 .62899 Mdot
.2283 .66001 Mdot
.59417 .66337 Mdot
.35214 .42555 Mdot
.50252 .68624 Mdot
.36223 .64445 Mdot
.51285 .30216 Mdot
.5701 .34617 Mdot
.56025 .66415 Mdot
.62642 .42161 Mdot
.40316 .64258 Mdot
.37481 .67943 Mdot
.46457 .4562 Mdot
.41976 .45722 Mdot
.33993 .29424 Mdot
.52448 .36489 Mdot
.57085 .6241 Mdot
.58416 .34081 Mdot
.63068 .52069 Mdot
.37173 .44269 Mdot
.39657 .6066 Mdot
.76382 .45526 Mdot
.3702 .46642 Mdot
.63611 .46752 Mdot
.3621 .65203 Mdot
.58398 .31915 Mdot
.53525 .34527 Mdot
.42842 .48176 Mdot
.29227 .43227 Mdot
.58518 .64727 Mdot
.3575 .66338 Mdot
.56914 .60195 Mdot
.38761 .40197 Mdot
.41204 .46026 Mdot
.41615 .52288 Mdot
.57253 .62357 Mdot
.56036 .76298 Mdot
.56456 .30599 Mdot
.38095 .64818 Mdot
.37844 .44068 Mdot
.57966 .34549 Mdot
.53286 .73857 Mdot
.61576 .49721 Mdot
.62696 .5033 Mdot
.53488 .35066 Mdot
.56372 .339 Mdot
.54345 .32872 Mdot
.84648 .45022 Mdot
.362 .60466 Mdot
.40981 .67926 Mdot
.37553 .40263 Mdot
.4779 .2956 Mdot
.39381 .37445 Mdot
.60682 .63115 Mdot
.63772 .50576 Mdot
.42034 .40486 Mdot
.41203 .48782 Mdot
.37359 .5194 Mdot
.39071 .71581 Mdot
.3234 .69811 Mdot
.38169 .6715 Mdot
.34527 .44812 Mdot
.65562 .5166 Mdot
.876 .50326 Mdot
.5459 .16344 Mdot
.34613 .42126 Mdot
.52103 .47711 Mdot
.39379 .60301 Mdot
.54845 .6669 Mdot
.55912 .25775 Mdot
.55783 .67059 Mdot
.37744 .64998 Mdot
.37466 .43666 Mdot
.51269 .74817 Mdot
.53694 .3647 Mdot
.44533 .46186 Mdot
.59163 .67366 Mdot
.45011 .46094 Mdot
.56942 .62512 Mdot
.69282 .2745 Mdot
.39941 .21389 Mdot
.41095 .43605 Mdot
.39051 .37997 Mdot
.3706 .25419 Mdot
.4368 .45442 Mdot
.53418 .32225 Mdot
.39411 .60282 Mdot
.27701 .37854 Mdot
.42907 .3873 Mdot
.32201 .50532 Mdot
.38035 .40688 Mdot
.26648 .36967 Mdot
.41446 .46243 Mdot
.63643 .35752 Mdot
.3815 .46254 Mdot
.45432 .46565 Mdot
.56811 .64037 Mdot
.54396 .64982 Mdot
.41509 .64483 Mdot
.67133 .45816 Mdot
.77023 .33279 Mdot
.41237 .45516 Mdot
.6906 .56242 Mdot
.50612 .77099 Mdot
.5618 .33836 Mdot
.38241 .64405 Mdot
.72142 .76261 Mdot
.5956 .67964 Mdot
.45563 .19845 Mdot
.30983 .34202 Mdot
.44909 .7231 Mdot
.59004 .27251 Mdot
.63953 .73335 Mdot
.57825 .31247 Mdot
.44675 .40639 Mdot
.75555 .40447 Mdot
.62828 .3725 Mdot
.41634 .33634 Mdot
.57621 .69148 Mdot
.31462 .53802 Mdot
.74863 .37387 Mdot
.5362 .33189 Mdot
.58912 .33509 Mdot
.5608 .63504 Mdot
.69281 .4481 Mdot
.34233 .40117 Mdot
.56582 .34678 Mdot
.68717 .48947 Mdot
.66975 .52082 Mdot
.67731 .52245 Mdot
.38015 .60966 Mdot
.50529 .18002 Mdot
.54562 .62046 Mdot
.58689 .62581 Mdot
.70783 .50023 Mdot
.38493 .56142 Mdot
.3432 .62385 Mdot
.66196 .49755 Mdot
.61971 .47896 Mdot
.4019 .60476 Mdot
.38141 .51244 Mdot
.34952 .48256 Mdot
.41781 .4409 Mdot
.56678 .3216 Mdot
.41987 .46258 Mdot
.67528 .47626 Mdot
.56097 .65428 Mdot
.62146 .48556 Mdot
.61949 .63566 Mdot
.78476 .49833 Mdot
.4344 .47027 Mdot
.38554 .46274 Mdot
.31875 .74598 Mdot
.37311 .68355 Mdot
.78252 .54492 Mdot
.63198 .58458 Mdot
.64082 .48951 Mdot
.45808 .45023 Mdot
.34073 .64113 Mdot
.52909 .36744 Mdot
.35075 .78519 Mdot
.40924 .40016 Mdot
.40042 .61685 Mdot
.37358 .44485 Mdot
.30765 .41145 Mdot
.1635 .54743 Mdot
.39001 .62251 Mdot
.298 .71872 Mdot
.38525 .47492 Mdot
.66599 .73843 Mdot
.45113 .48727 Mdot
.38347 .30995 Mdot
.41082 .39662 Mdot
.34932 .64015 Mdot
.42074 .44333 Mdot
.33994 .64896 Mdot
.67463 .5078 Mdot
.54869 .66489 Mdot
.36121 .63469 Mdot
.39469 .49597 Mdot
.29909 .16853 Mdot
.58883 .66906 Mdot
.39893 .4452 Mdot
.55383 .65001 Mdot
.38953 .64255 Mdot
.35307 .64745 Mdot
.73233 .72371 Mdot
.71274 .59051 Mdot
.59159 .66218 Mdot
.37223 .44354 Mdot
.70041 .69859 Mdot
.38893 .41131 Mdot
.37065 .29367 Mdot
.38652 .51023 Mdot
.38225 .40086 Mdot
.77693 .66085 Mdot
.58662 .62471 Mdot
.21716 .64729 Mdot
.76157 .69867 Mdot
.79124 .59889 Mdot
.3354 .6838 Mdot
.53206 .34099 Mdot
.80819 .35734 Mdot
.68271 .5852 Mdot
.68001 .47935 Mdot
.43007 .40827 Mdot
.3556 .59545 Mdot
.58436 .6437 Mdot
.55482 .32766 Mdot
.41004 .43682 Mdot
.62001 .49037 Mdot
.25159 .34802 Mdot
.6199 .65469 Mdot
.39416 .62276 Mdot
.38597 .59519 Mdot
.52523 .84927 Mdot
.38489 .43677 Mdot
.39164 .4686 Mdot
.5992 .66576 Mdot
.5991 .76536 Mdot
.56769 .31002 Mdot
.28806 .3387 Mdot
.58962 .66259 Mdot
.54301 .53615 Mdot
.37252 .6658 Mdot
.44556 .42247 Mdot
.82468 .4671 Mdot
.67839 .42282 Mdot
.33185 .73998 Mdot
.5711 .32013 Mdot
.37649 .28939 Mdot
.34895 .64315 Mdot
.57006 .66615 Mdot
.66996 .64461 Mdot
.47261 .4332 Mdot
.4458 .43128 Mdot
.38517 .29011 Mdot
.58066 .70315 Mdot
.46178 .52638 Mdot
.40105 .4002 Mdot
.59542 .56192 Mdot
.42419 .40159 Mdot
.46142 .3982 Mdot
.36369 .49595 Mdot
.40406 .46443 Mdot
.39842 .61011 Mdot
.41205 .54083 Mdot
.6683 .46403 Mdot
.43438 .64167 Mdot
.54136 .5455 Mdot
.39685 .43631 Mdot
.36707 .42957 Mdot
.31282 .62956 Mdot
.68222 .67636 Mdot
.36303 .63666 Mdot
.33417 .67257 Mdot
.57043 .68462 Mdot
.35701 .49776 Mdot
.66144 .45437 Mdot
.44911 .38496 Mdot
.64375 .46686 Mdot
.39579 .60756 Mdot
.64334 .49379 Mdot
.54964 .65939 Mdot
.65043 .52211 Mdot
.68395 .58299 Mdot
.57635 .67419 Mdot
.36506 .61963 Mdot
.40378 .47483 Mdot
.61414 .63181 Mdot
.48047 .24768 Mdot
.5687 .32146 Mdot
.79818 .66844 Mdot
.3982 .47601 Mdot
.45942 .76797 Mdot
.39665 .35702 Mdot
.62039 .48121 Mdot
.16804 .55978 Mdot
.39454 .59832 Mdot
.59315 .33165 Mdot
.37112 .60442 Mdot
.4926 .20763 Mdot
.5673 .33014 Mdot
.79797 .63531 Mdot
.58433 .50879 Mdot
.49654 .21731 Mdot
.37142 .51203 Mdot
.51575 .2365 Mdot
.6512 .5301 Mdot
.58199 .64324 Mdot
.67762 .64777 Mdot
.45619 .45804 Mdot
.30772 .27327 Mdot
.40791 .59812 Mdot
.67164 .45953 Mdot
.56683 .65924 Mdot
.61117 .63589 Mdot
.35923 .43019 Mdot
.68503 .34953 Mdot
.45114 .43646 Mdot
.6973 .61465 Mdot
.37254 .2734 Mdot
.35124 .71004 Mdot
.39403 .4422 Mdot
.6776 .50437 Mdot
.3736 .44463 Mdot
.58443 .30054 Mdot
.48241 .17273 Mdot
.47885 .41568 Mdot
.63688 .59296 Mdot
.58658 .28119 Mdot
.36369 .66528 Mdot
.41693 .35057 Mdot
.66219 .59084 Mdot
.38279 .43565 Mdot
.1861 .68754 Mdot
.58221 .33868 Mdot
.7523 .39982 Mdot
.39016 .48805 Mdot
.35866 .44812 Mdot
.51561 .60027 Mdot
.43439 .752 Mdot
.65331 .41467 Mdot
.43935 .4465 Mdot
.42417 .26842 Mdot
.57084 .62799 Mdot
.44922 .42018 Mdot
.40281 .44906 Mdot
.2262 .56636 Mdot
.61709 .64076 Mdot
.63413 .48757 Mdot
.65731 .53238 Mdot
.63387 .44393 Mdot
.58859 .30338 Mdot
.63845 .66405 Mdot
.5046 .29249 Mdot
.22281 .36843 Mdot
.58049 .36228 Mdot
.41498 .48551 Mdot
.53508 .30718 Mdot
.37261 .4318 Mdot
.55144 .33939 Mdot
.61836 .64356 Mdot
.35961 .63934 Mdot
.51759 .70611 Mdot
.67534 .5203 Mdot
.47197 .4693 Mdot
.57234 .3076 Mdot
.36882 .61713 Mdot
.58542 .26347 Mdot
.36882 .66286 Mdot
.58238 .65862 Mdot
.60993 .6181 Mdot
.55191 .33201 Mdot
.39328 .6422 Mdot
.6142 .59538 Mdot
.71333 .74883 Mdot
.35765 .48305 Mdot
.61015 .7267 Mdot
.34698 .65911 Mdot
.3319 .66251 Mdot
.34359 .64564 Mdot
.44514 .47052 Mdot
.52205 .47602 Mdot
.42195 .39125 Mdot
.58292 .62447 Mdot
.63846 .50103 Mdot
.34271 .2689 Mdot
.74853 .52999 Mdot
.5322 .41617 Mdot
.34848 .4335 Mdot
.42159 .43167 Mdot
.3973 .44801 Mdot
.43206 .38683 Mdot
.67309 .61277 Mdot
.44826 .43969 Mdot
.56904 .6391 Mdot
.66863 .47519 Mdot
.44692 .40606 Mdot
.67738 .53601 Mdot
.78592 .59395 Mdot
.57254 .36602 Mdot
.6279 .69236 Mdot
.55584 .15127 Mdot
.36595 .62216 Mdot
.61264 .47009 Mdot
.68084 .48777 Mdot
.55534 .32057 Mdot
.59158 .64778 Mdot
.37227 .66136 Mdot
.35736 .3075 Mdot
.54986 .32133 Mdot
.41839 .44536 Mdot
.51404 .47125 Mdot
.34042 .24585 Mdot
.44541 .40694 Mdot
.41906 .40939 Mdot
.65172 .5378 Mdot
.74013 .38104 Mdot
.31982 .20969 Mdot
.52314 .27639 Mdot
.55603 .32866 Mdot
.55743 .36342 Mdot
.41003 .61789 Mdot
.40447 .38744 Mdot
.57752 .62388 Mdot
.43909 .55397 Mdot
.6395 .69007 Mdot
.44735 .60406 Mdot
.37342 .74845 Mdot
.41914 .40224 Mdot
.54631 .81103 Mdot
.41865 .42855 Mdot
.3609 .606 Mdot
.39281 .60923 Mdot
.37528 .6247 Mdot
.58155 .64421 Mdot
.2778 .5631 Mdot
.57832 .63649 Mdot
.53761 .14034 Mdot
.35005 .65289 Mdot
.58869 .5264 Mdot
.66177 .50755 Mdot
.34124 .43087 Mdot
.58554 .32606 Mdot
.6266 .62869 Mdot
.37965 .52928 Mdot
.18279 .52443 Mdot
.67216 .46221 Mdot
.36253 .62262 Mdot
.62933 .73647 Mdot
.62703 .20681 Mdot
.47918 .53304 Mdot
.35714 .51201 Mdot
.56426 .25645 Mdot
.55832 .34003 Mdot
.33184 .74087 Mdot
.58587 .33713 Mdot
.59032 .67473 Mdot
.38525 .45902 Mdot
.39817 .46768 Mdot
.42733 .40211 Mdot
.43492 .4638 Mdot
.55861 .68234 Mdot
.38093 .4944 Mdot
.1585 .51049 Mdot
.68175 .50878 Mdot
.37439 .34085 Mdot
.58454 .33045 Mdot
.59597 .68879 Mdot
.67008 .47543 Mdot
.68162 .67251 Mdot
.49956 .25203 Mdot
.39083 .44066 Mdot
.4236 .40551 Mdot
.44426 .19686 Mdot
.39907 .4004 Mdot
.35754 .38698 Mdot
.68087 .48143 Mdot
.51509 .39435 Mdot
.57645 .36266 Mdot
.56231 .36372 Mdot
.57326 .67505 Mdot
.3969 .61006 Mdot
.57978 .33502 Mdot
.65863 .51037 Mdot
.34805 .43658 Mdot
.37535 .48641 Mdot
.34693 .65775 Mdot
.46061 .18221 Mdot
.558 .30977 Mdot
.68953 .71081 Mdot
.37472 .60692 Mdot
.40035 .67178 Mdot
.44539 .43039 Mdot
.35733 .7325 Mdot
.3259 .65706 Mdot
.59344 .34239 Mdot
.5944 .68885 Mdot
.54199 .25472 Mdot
.60738 .66239 Mdot
.39613 .62444 Mdot
.36655 .45456 Mdot
.38443 .60597 Mdot
.38796 .43682 Mdot
.67304 .21624 Mdot
.40402 .46815 Mdot
.21264 .37779 Mdot
.4323 .30879 Mdot
.67161 .4922 Mdot
.66907 .69842 Mdot
.66728 .50518 Mdot
.36774 .61086 Mdot
.36395 .46025 Mdot
.58445 .31168 Mdot
.77122 .63694 Mdot
.38465 .57166 Mdot
.62829 .46977 Mdot
.69217 .47368 Mdot
.60676 .6688 Mdot
.4173 .39672 Mdot
.44664 .43389 Mdot
.65814 .47811 Mdot
.35508 .71202 Mdot
.39995 .64432 Mdot
.38346 .45073 Mdot
.42679 .43146 Mdot
.67025 .49488 Mdot
.69784 .76109 Mdot
.37447 .55402 Mdot
.3914 .45962 Mdot
.74957 .49688 Mdot
.60305 .62954 Mdot
.34458 .45697 Mdot
.3865 .37967 Mdot
.56448 .34144 Mdot
.24246 .445 Mdot
.52695 .18619 Mdot
.61939 .64793 Mdot
.68324 .49295 Mdot
.38173 .43882 Mdot
.67866 .50327 Mdot
.37623 .48872 Mdot
.42991 .74518 Mdot
.62083 .50523 Mdot
.37022 .41762 Mdot
.39437 .51422 Mdot
.35768 .61895 Mdot
.42046 .40345 Mdot
.30307 .62983 Mdot
.64184 .45917 Mdot
.35897 .4364 Mdot
.28921 .42952 Mdot
.59941 .64529 Mdot
.37116 .51343 Mdot
.54109 .34422 Mdot
.35228 .30955 Mdot
.483 .73814 Mdot
.72275 .33451 Mdot
.55784 .36545 Mdot
.4506 .45762 Mdot
.68786 .46952 Mdot
.5626 .62829 Mdot
.19706 .40385 Mdot
.45588 .42978 Mdot
.59511 .66973 Mdot
.56107 .65607 Mdot
.56031 .32073 Mdot
.34575 .79789 Mdot
.3989 .49124 Mdot
.43083 .45823 Mdot
.25641 .60454 Mdot
.364 .68269 Mdot
.41342 .46839 Mdot
.40514 .48383 Mdot
.56711 .63896 Mdot
.33101 .44322 Mdot
.33015 .56041 Mdot
.27734 .3526 Mdot
.55697 .62521 Mdot
.46673 .61029 Mdot
.64954 .52526 Mdot
.57343 .35262 Mdot
.36626 .6556 Mdot
.57701 .30794 Mdot
.64015 .51465 Mdot
.40558 .48214 Mdot
.57431 .68261 Mdot
.28229 .64334 Mdot
.55996 .63568 Mdot
.69252 .30909 Mdot
.35164 .67142 Mdot
.50031 .66325 Mdot
.22604 .72932 Mdot
.73872 .64434 Mdot
.52357 .65549 Mdot
.56222 .33825 Mdot
.71145 .45515 Mdot
.42503 .43077 Mdot
.33026 .74404 Mdot
.41899 .4828 Mdot
.28569 .42522 Mdot
.6854 .50062 Mdot
.68491 .50881 Mdot
.38755 .45866 Mdot
.36808 .27959 Mdot
.56104 .62901 Mdot
.60663 .63475 Mdot
.36692 .41882 Mdot
.58445 .6551 Mdot
.42374 .45521 Mdot
.66584 .47015 Mdot
.21943 .66548 Mdot
.41304 .4401 Mdot
.43685 .38596 Mdot
.44053 .74208 Mdot
.77612 .67175 Mdot
.63915 .29171 Mdot
.58919 .82691 Mdot
.60248 .19388 Mdot
.58282 .65452 Mdot
.39654 .3916 Mdot
.46583 .6125 Mdot
.66339 .53482 Mdot
.61237 .60007 Mdot
.41284 .47695 Mdot
.41905 .47965 Mdot
.45512 .46619 Mdot
.42099 .41652 Mdot
.36602 .77807 Mdot
.41442 .5597 Mdot
.25236 .48997 Mdot
.40775 .40314 Mdot
.49811 .23557 Mdot
.58042 .67811 Mdot
.33073 .69305 Mdot
.5825 .36295 Mdot
.42023 .40265 Mdot
.43131 .6206 Mdot
.54412 .66301 Mdot
.53217 .13686 Mdot
.59039 .67666 Mdot
.63619 .48244 Mdot
.54753 .65077 Mdot
.40551 .42563 Mdot
.37896 .64157 Mdot
.49591 .57643 Mdot
.73609 .60704 Mdot
.67957 .47762 Mdot
.39934 .43331 Mdot
.60573 .55444 Mdot
.67124 .46454 Mdot
.79348 .58257 Mdot
.37195 .64744 Mdot
.42928 .26928 Mdot
.38853 .60624 Mdot
.36295 .4269 Mdot
.36233 .43138 Mdot
.54374 .62754 Mdot
.54767 .65661 Mdot
.39037 .6067 Mdot
.36277 .81782 Mdot
.54705 .32144 Mdot
.37853 .62123 Mdot
.47489 .44131 Mdot
.51808 .51078 Mdot
.37816 .63747 Mdot
.59623 .29482 Mdot
.56216 .64825 Mdot
.40692 .65496 Mdot
.45668 .47465 Mdot
.55011 .22405 Mdot
.53948 .3577 Mdot
.63577 .52829 Mdot
.53519 .29088 Mdot
.6369 .459 Mdot
.59379 .68773 Mdot
.66873 .50383 Mdot
.57373 .62846 Mdot
.49019 .75705 Mdot
.43083 .65985 Mdot
.5261 .66927 Mdot
.58084 .68867 Mdot
.66695 .50207 Mdot
.37971 .45468 Mdot
.58814 .27895 Mdot
.37014 .40243 Mdot
.41347 .49587 Mdot
.5868 .62852 Mdot
.35331 .63171 Mdot
.32771 .66647 Mdot
.46752 .2291 Mdot
.40377 .61716 Mdot
.63415 .46836 Mdot
.17293 .50302 Mdot
.71011 .5492 Mdot
.60791 .65221 Mdot
.54635 .65989 Mdot
.37659 .4162 Mdot
.65647 .48548 Mdot
.68495 .4864 Mdot
.60511 .66904 Mdot
.42298 .70274 Mdot
.39632 .38198 Mdot
.33249 .64936 Mdot
.37057 .68167 Mdot
.38728 .62491 Mdot
.34228 .64868 Mdot
.3503 .55956 Mdot
.55794 .66413 Mdot
.35572 .62598 Mdot
.37924 .41153 Mdot
.41663 .47853 Mdot
.45768 .56952 Mdot
.55408 .36073 Mdot
.45032 .4073 Mdot
.36516 .49908 Mdot
.44409 .42224 Mdot
.62679 .50565 Mdot
.49485 .41992 Mdot
.61808 .49629 Mdot
.68911 .47791 Mdot
.68824 .48349 Mdot
.68194 .58452 Mdot
.4284 .21679 Mdot
.62326 .22495 Mdot
.37071 .46312 Mdot
.59759 .77923 Mdot
.65259 .49508 Mdot
.1754 .53816 Mdot
.56412 .76313 Mdot
.45747 .44185 Mdot
.67501 .4164 Mdot
.66197 .48099 Mdot
.39726 .60158 Mdot
.40931 .4743 Mdot
.62717 .45072 Mdot
.53984 .34639 Mdot
.36123 .41945 Mdot
.61976 .50505 Mdot
.39061 .64516 Mdot
.59621 .33538 Mdot
.38919 .67466 Mdot
.68905 .48697 Mdot
.38925 .51848 Mdot
.14367 .40351 Mdot
.68529 .45872 Mdot
.66726 .75452 Mdot
.3326 .39326 Mdot
.38178 .4524 Mdot
.61815 .46653 Mdot
.37845 .68565 Mdot
.59942 .68418 Mdot
.56537 .48168 Mdot
.40174 .65781 Mdot
.68471 .50933 Mdot
.62635 .46747 Mdot
.68039 .47883 Mdot
.37878 .67416 Mdot
.46492 .42172 Mdot
.40012 .65559 Mdot
.54932 .64702 Mdot
.39434 .4127 Mdot
.69619 .26903 Mdot
.58364 .77907 Mdot
.38157 .60383 Mdot
.6309 .48971 Mdot
.54006 .366 Mdot
.41387 .43162 Mdot
.58277 .78386 Mdot
.37709 .4507 Mdot
.58552 .62666 Mdot
.215 .47073 Mdot
.29434 .66311 Mdot
.38294 .39948 Mdot
.37889 .41485 Mdot
.60464 .63423 Mdot
.40284 .43669 Mdot
.41248 .3966 Mdot
.68409 .58823 Mdot
.38915 .66429 Mdot
.42303 .44041 Mdot
.64558 .50779 Mdot
.71676 .56666 Mdot
.40763 .38187 Mdot
.72831 .50968 Mdot
.41426 .27863 Mdot
.21214 .48715 Mdot
.41766 .48307 Mdot
.50386 .47651 Mdot
.43136 .42174 Mdot
.44206 .46457 Mdot
.37565 .42413 Mdot
.42147 .8124 Mdot
.62483 .51087 Mdot
.67823 .4883 Mdot
.54878 .36335 Mdot
.41715 .27702 Mdot
.56814 .34315 Mdot
.56012 .64928 Mdot
.70302 .3673 Mdot
.61839 .49791 Mdot
.39692 .63275 Mdot
.44804 .4557 Mdot
.68463 .45843 Mdot
.44725 .42579 Mdot
.40332 .42547 Mdot
.65381 .45182 Mdot
.64295 .52484 Mdot
.74574 .37552 Mdot
.54489 .35809 Mdot
.37069 .62901 Mdot
.42244 .39444 Mdot
.56434 .3088 Mdot
.40738 .48827 Mdot
.47917 .29727 Mdot
.3739 .6286 Mdot
.39328 .66116 Mdot
.32696 .66163 Mdot
.40293 .48065 Mdot
.40817 .42895 Mdot
.57928 .63549 Mdot
.37962 .60163 Mdot
.5999 .64858 Mdot
.57195 .53165 Mdot
.73171 .44612 Mdot
.41305 .47709 Mdot
.58759 .73512 Mdot
.56087 .3542 Mdot
.6263 .47665 Mdot
.35032 .24513 Mdot
.54772 .36323 Mdot
.38654 .43919 Mdot
.67933 .46503 Mdot
.54962 .34458 Mdot
.33404 .34618 Mdot
.50547 .15563 Mdot
.54982 .36906 Mdot
.37987 .41094 Mdot
.33694 .47012 Mdot
.57661 .83173 Mdot
.55809 .36753 Mdot
.55389 .66811 Mdot
.40191 .47978 Mdot
.36879 .59083 Mdot
.57767 .30716 Mdot
.76758 .57635 Mdot
.66676 .47812 Mdot
.54572 .21213 Mdot
.4194 .52876 Mdot
.30424 .70993 Mdot
.56528 .36017 Mdot
.37471 .65641 Mdot
.38056 .36759 Mdot
.44218 .42763 Mdot
.554 .3665 Mdot
.53196 .65946 Mdot
.65265 .47049 Mdot
.72307 .58349 Mdot
.37844 .67479 Mdot
.52992 .62631 Mdot
.63018 .49531 Mdot
.6972 .70479 Mdot
.24877 .38933 Mdot
.34796 .4766 Mdot
.55727 .82909 Mdot
.64531 .65179 Mdot
.46392 .45248 Mdot
.53742 .37092 Mdot
.61854 .63651 Mdot
.57406 .68394 Mdot
.58406 .66182 Mdot
.501 .76645 Mdot
.48041 .52385 Mdot
.60992 .47307 Mdot
.57719 .60897 Mdot
.57294 .35195 Mdot
.53346 .2505 Mdot
.40476 .49882 Mdot
.42079 .43355 Mdot
.40285 .3946 Mdot
.42894 .40442 Mdot
.43608 .42915 Mdot
.59281 .65255 Mdot
.47543 .75777 Mdot
.46688 .54574 Mdot
.37717 .63193 Mdot
.72351 .36242 Mdot
.65835 .50632 Mdot
.60742 .47621 Mdot
.54569 .34595 Mdot
.75227 .64054 Mdot
.6771 .53665 Mdot
.64174 .49276 Mdot
.46209 .43077 Mdot
.40214 .64546 Mdot
.34683 .40563 Mdot
.3792 .41311 Mdot
.63674 .46868 Mdot
.53472 .57622 Mdot
.3289 .58851 Mdot
.47638 .35993 Mdot
.57194 .37764 Mdot
.50385 .50777 Mdot
.54065 .36273 Mdot
.3656 .4668 Mdot
.17093 .55906 Mdot
.63934 .51465 Mdot
.64457 .48061 Mdot
.55984 .35821 Mdot
.34664 .73237 Mdot
.36037 .65637 Mdot
.57592 .72589 Mdot
.55726 .64329 Mdot
.3634 .44672 Mdot
.266 .3356 Mdot
.37647 .34935 Mdot
.67641 .35151 Mdot
.58884 .66513 Mdot
.67394 .50745 Mdot
.35491 .41937 Mdot
.3882 .40776 Mdot
.55754 .35399 Mdot
.77626 .39451 Mdot
.35004 .46565 Mdot
.8257 .55079 Mdot
.39981 .21327 Mdot
.4953 .19871 Mdot
.4458 .4318 Mdot
.38749 .66678 Mdot
.64379 .53296 Mdot
.58097 .34856 Mdot
.4745 .45445 Mdot
.54578 .17276 Mdot
.34977 .66101 Mdot
.57774 .67191 Mdot
.52193 .56306 Mdot
.53866 .26183 Mdot
.43246 .4832 Mdot
.41393 .48157 Mdot
.4392 .47182 Mdot
.43936 .14938 Mdot
.62344 .50465 Mdot
.39064 .60174 Mdot
.55703 .32347 Mdot
.40287 .62233 Mdot
.67465 .49634 Mdot
.51655 .63359 Mdot
.37832 .45817 Mdot
.35082 .66502 Mdot
.37316 .65683 Mdot
.59562 .67547 Mdot
.61102 .67714 Mdot
.54724 .54791 Mdot
.40523 .46729 Mdot
.69136 .46704 Mdot
.35619 .62281 Mdot
.51067 .47797 Mdot
.56786 .33176 Mdot
.56291 .64463 Mdot
.41395 .40329 Mdot
.63212 .51494 Mdot
.41934 .50173 Mdot
.36448 .64164 Mdot
.6424 .49274 Mdot
.76071 .45516 Mdot
.5686 .36616 Mdot
.42347 .47161 Mdot
.56534 .29314 Mdot
.68357 .48982 Mdot
.42559 .4288 Mdot
.7101 .70674 Mdot
.59525 .2947 Mdot
.75337 .58327 Mdot
.68491 .47586 Mdot
.66585 .56964 Mdot
.41109 .6252 Mdot
.51194 .78076 Mdot
.64016 .48002 Mdot
.67045 .72296 Mdot
.77539 .44377 Mdot
.34988 .4261 Mdot
.39121 .61604 Mdot
.64186 .63536 Mdot
.73092 .27681 Mdot
.65738 .7765 Mdot
.39971 .44617 Mdot
.63812 .44907 Mdot
.55362 .35061 Mdot
.60832 .64764 Mdot
.73903 .48541 Mdot
.60154 .32916 Mdot
.69249 .5033 Mdot
.37568 .42501 Mdot
.38278 .65045 Mdot
.56941 .64541 Mdot
.48669 .74314 Mdot
.65429 .51074 Mdot
.63605 .49986 Mdot
.35888 .41449 Mdot
.5701 .34695 Mdot
.5484 .79161 Mdot
.67057 .47103 Mdot
.41962 .20788 Mdot
.65161 .43208 Mdot
.55491 .31472 Mdot
.4273 .41535 Mdot
.46846 .22459 Mdot
.42137 .38744 Mdot
.73106 .70702 Mdot
.66161 .50384 Mdot
.36863 .63624 Mdot
.44819 .47053 Mdot
.29495 .34655 Mdot
.63269 .47053 Mdot
.51675 .48444 Mdot
.63771 .33755 Mdot
.55684 .65591 Mdot
.34625 .24747 Mdot
.42078 .465 Mdot
.56193 .62895 Mdot
.55912 .35231 Mdot
.39722 .46224 Mdot
.40927 .42652 Mdot
.3568 .61475 Mdot
.59935 .67236 Mdot
.76168 .39274 Mdot
.54312 .65321 Mdot
.574 .6799 Mdot
.34232 .63304 Mdot
.43103 .44643 Mdot
.63524 .48368 Mdot
.65999 .48076 Mdot
.45115 .48487 Mdot
.19176 .64332 Mdot
.35909 .6598 Mdot
.64317 .53549 Mdot
.42471 .15265 Mdot
.43734 .50088 Mdot
.33145 .26226 Mdot
.78112 .40368 Mdot
.58643 .62331 Mdot
.38094 .40927 Mdot
.39104 .6427 Mdot
.60905 .41702 Mdot
.63477 .49619 Mdot
.45372 .47343 Mdot
.56979 .64748 Mdot
.53917 .35202 Mdot
.65457 .45962 Mdot
.68476 .35135 Mdot
.43553 .46764 Mdot
.66201 .41115 Mdot
.63173 .45476 Mdot
.81695 .37579 Mdot
.67486 .67235 Mdot
.38788 .61461 Mdot
.40297 .42277 Mdot
.39636 .59888 Mdot
.55344 .32624 Mdot
.52517 .56033 Mdot
.56427 .65018 Mdot
.42923 .53826 Mdot
.14929 .49967 Mdot
.68125 .48023 Mdot
.39078 .60067 Mdot
.37824 .40168 Mdot
.42231 .7427 Mdot
.42458 .45973 Mdot
.33747 .48041 Mdot
.53582 .30151 Mdot
.59711 .63351 Mdot
.56693 .63022 Mdot
.41922 .42112 Mdot
.56037 .31534 Mdot
.65816 .50907 Mdot
.64336 .46983 Mdot
.8638 .49568 Mdot
.48987 .63992 Mdot
.33736 .29859 Mdot
.42102 .47824 Mdot
.69432 .49676 Mdot
.73917 .54204 Mdot
.59862 .66571 Mdot
.45916 .4815 Mdot
.66297 .4552 Mdot
.60953 .29779 Mdot
.35285 .31961 Mdot
.43726 .42506 Mdot
.45773 .39846 Mdot
.55395 .64859 Mdot
.48071 .51346 Mdot
.67491 .51311 Mdot
.3924 .50766 Mdot
.52677 .67992 Mdot
.34631 .33249 Mdot
.44963 .17268 Mdot
.37075 .62864 Mdot
.671 .33241 Mdot
.5931 .65183 Mdot
.44824 .38953 Mdot
.5782 .31439 Mdot
.65858 .53747 Mdot
.62807 .51247 Mdot
.38007 .43206 Mdot
.35608 .45675 Mdot
.36968 .24733 Mdot
.4014 .63409 Mdot
.57679 .67729 Mdot
.39493 .47003 Mdot
.5385 .7226 Mdot
.42321 .40088 Mdot
.58628 .63571 Mdot
.13182 .41751 Mdot
.37459 .4007 Mdot
.42857 .45777 Mdot
.5658 .78456 Mdot
.39025 .67054 Mdot
.3849 .598 Mdot
.28284 .29925 Mdot
.42125 .47782 Mdot
.37694 .23083 Mdot
.36608 .63114 Mdot
.35953 .65244 Mdot
.69489 .59626 Mdot
.41573 .43357 Mdot
.46699 .50153 Mdot
.58117 .62506 Mdot
.56819 .67915 Mdot
.39326 .66453 Mdot
.34579 .45871 Mdot
.61702 .65855 Mdot
.44547 .80693 Mdot
.65731 .48715 Mdot
.17472 .58158 Mdot
.35623 .6608 Mdot
.60769 .70102 Mdot
.59482 .6659 Mdot
.54426 .14498 Mdot
.59147 .4647 Mdot
.38068 .45755 Mdot
.4266 .47356 Mdot
.56581 .35542 Mdot
.40453 .39284 Mdot
.68525 .50786 Mdot
.58515 .65541 Mdot
.29604 .3972 Mdot
.37539 .62401 Mdot
.41229 .46264 Mdot
.76887 .6213 Mdot
.79245 .54402 Mdot
.67064 .31935 Mdot
.364 .66419 Mdot
.38294 .6098 Mdot
.66237 .51652 Mdot
.63895 .4493 Mdot
.4389 .43947 Mdot
.61201 .64334 Mdot
.38005 .60191 Mdot
.58789 .63267 Mdot
.63776 .51314 Mdot
.63712 .48717 Mdot
.63543 .52276 Mdot
.39603 .49927 Mdot
.64237 .49974 Mdot
.7494 .45745 Mdot
.5371 .62151 Mdot
.34299 .6254 Mdot
.3595 .21529 Mdot
.49424 .74569 Mdot
.32145 .64903 Mdot
.57593 .30504 Mdot
.68351 .48577 Mdot
.55 .64237 Mdot
.40736 .41101 Mdot
.43745 .41235 Mdot
.68155 .55811 Mdot
.5514 .63391 Mdot
.5539 .32748 Mdot
.56168 .63139 Mdot
.55995 .32075 Mdot
.63251 .38643 Mdot
.42758 .39877 Mdot
.37132 .48364 Mdot
.59208 .65641 Mdot
.64269 .49692 Mdot
.67396 .4824 Mdot
.55771 .37011 Mdot
.55805 .57518 Mdot
.67073 .46357 Mdot
.35656 .65031 Mdot
.35521 .56906 Mdot
.62376 .46925 Mdot
.41063 .4725 Mdot
.50415 .29703 Mdot
.32542 .74609 Mdot
.43272 .38699 Mdot
.69031 .59313 Mdot
.27253 .65865 Mdot
.4546 .45447 Mdot
.31149 .74233 Mdot
.63645 .57854 Mdot
.40975 .62837 Mdot
.68262 .5048 Mdot
.69545 .52952 Mdot
.48108 .40136 Mdot
.58515 .36449 Mdot
.46744 .46774 Mdot
.35711 .66731 Mdot
.40962 .59638 Mdot
.50884 .21039 Mdot
.68929 .74299 Mdot
.55217 .34717 Mdot
.54869 .35067 Mdot
.63926 .47786 Mdot
.79484 .68131 Mdot
.36374 .51515 Mdot
.55413 .32908 Mdot
.42845 .67103 Mdot
.37691 .42689 Mdot
.40471 .29736 Mdot
.56473 .40422 Mdot
.38789 .66847 Mdot
.49645 .23056 Mdot
.63187 .4779 Mdot
.40474 .61779 Mdot
.52054 .71365 Mdot
.45381 .40778 Mdot
.37509 .6273 Mdot
.58344 .63299 Mdot
.69706 .65393 Mdot
.35395 .64384 Mdot
.4939 .2961 Mdot
.61206 .66092 Mdot
.51016 .48274 Mdot
.44742 .24264 Mdot
.47973 .90201 Mdot
.5887 .65243 Mdot
.62578 .46965 Mdot
.65956 .47974 Mdot
.64226 .47046 Mdot
.40356 .62667 Mdot
.68488 .48761 Mdot
.40058 .63122 Mdot
.59488 .80654 Mdot
.36798 .74599 Mdot
.55467 .33022 Mdot
.72378 .5865 Mdot
.38956 .63691 Mdot
.16993 .53271 Mdot
.16309 .63134 Mdot
.37951 .40969 Mdot
.54847 .67065 Mdot
.55353 .33498 Mdot
.82251 .56229 Mdot
.56141 .34306 Mdot
.46465 .20734 Mdot
.19525 .5125 Mdot
.41705 .45642 Mdot
.3038 .5632 Mdot
.58749 .34503 Mdot
.37146 .66715 Mdot
.42384 .42876 Mdot
.57474 .44496 Mdot
.56246 .34683 Mdot
.54273 .3335 Mdot
.43222 .43903 Mdot
.36257 .62237 Mdot
.629 .48283 Mdot
.55168 .66923 Mdot
.58852 .31323 Mdot
.33823 .40107 Mdot
.44587 .39397 Mdot
.37385 .4497 Mdot
.46382 .56677 Mdot
.52552 .3584 Mdot
.58221 .65389 Mdot
.38198 .80589 Mdot
.67795 .4601 Mdot
.58 .4463 Mdot
.42916 .19672 Mdot
.66706 .58922 Mdot
.66174 .50171 Mdot
.67816 .50176 Mdot
.43836 .43062 Mdot
.53527 .38962 Mdot
.19021 .52868 Mdot
.58729 .57415 Mdot
.63179 .52251 Mdot
.64822 .46933 Mdot
.4031 .59853 Mdot
.49086 .20403 Mdot
.47613 .4473 Mdot
.61971 .6476 Mdot
.63221 .51718 Mdot
.41528 .76067 Mdot
.5722 .34832 Mdot
.18992 .49733 Mdot
.43323 .39998 Mdot
.38432 .46134 Mdot
.56951 .65621 Mdot
.57672 .63728 Mdot
.60185 .41694 Mdot
.48121 .20435 Mdot
.27969 .66492 Mdot
.46508 .74012 Mdot
.21825 .50077 Mdot
.40435 .59523 Mdot
.38099 .60397 Mdot
.74287 .61745 Mdot
.54334 .65785 Mdot
.45275 .46152 Mdot
.39532 .60851 Mdot
.58121 .45643 Mdot
.36791 .56991 Mdot
.36811 .29139 Mdot
.34 .26578 Mdot
.39061 .43584 Mdot
.39247 .65703 Mdot
.38507 .67424 Mdot
.35016 .67938 Mdot
.62534 .57707 Mdot
.43919 .44707 Mdot
.3947 .44052 Mdot
.4527 .4444 Mdot
.40073 .72899 Mdot
.44365 .45443 Mdot
.50138 .77863 Mdot
.5309 .54445 Mdot
.25173 .43101 Mdot
.3828 .5073 Mdot
.59289 .62205 Mdot
.42416 .48535 Mdot
.55925 .31658 Mdot
.37068 .42534 Mdot
.36392 .29488 Mdot
.58872 .6718 Mdot
.37478 .55632 Mdot
.49487 .75462 Mdot
.4603 .45664 Mdot
.59487 .3319 Mdot
.63574 .70274 Mdot
.68351 .25585 Mdot
.56565 .28654 Mdot
.35619 .65247 Mdot
.65885 .49288 Mdot
.55039 .64027 Mdot
.64085 .48567 Mdot
.37805 .49584 Mdot
.73847 .6312 Mdot
.80805 .52039 Mdot
.57822 .54042 Mdot
.42817 .40485 Mdot
.44417 .51038 Mdot
.35989 .64683 Mdot
.67626 .46007 Mdot
.3263 .64511 Mdot
.44341 .47334 Mdot
.56713 .32085 Mdot
.56182 .35126 Mdot
.56739 .48647 Mdot
.80151 .39748 Mdot
.42462 .78589 Mdot
.57195 .65475 Mdot
.6642 .46834 Mdot
.58682 .33081 Mdot
.64522 .74679 Mdot
.61407 .67477 Mdot
.59984 .62977 Mdot
.58424 .67457 Mdot
.3909 .47804 Mdot
.62155 .50683 Mdot
.2545 .4278 Mdot
.6899 .50466 Mdot
.40246 .4342 Mdot
.62435 .50285 Mdot
.66913 .45882 Mdot
.58415 .3364 Mdot
.58203 .67684 Mdot
.64629 .51678 Mdot
.3613 .43157 Mdot
.36519 .62593 Mdot
.55534 .69641 Mdot
.41359 .31378 Mdot
.69988 .73295 Mdot
.32365 .37996 Mdot
.36617 .67963 Mdot
.73122 .28298 Mdot
.59821 .62726 Mdot
.4185 .70952 Mdot
.74036 .36925 Mdot
.36856 .46495 Mdot
.16901 .61309 Mdot
.60708 .4784 Mdot
.65763 .45498 Mdot
.42697 .41639 Mdot
.68353 .44035 Mdot
.4168 .46093 Mdot
.63216 .50393 Mdot
.73695 .51246 Mdot
.42234 .59881 Mdot
.64719 .50046 Mdot
.397 .50649 Mdot
.41421 .42476 Mdot
.39177 .66401 Mdot
.62158 .46383 Mdot
.47269 .46721 Mdot
.86217 .47698 Mdot
.58217 .63824 Mdot
.63766 .60665 Mdot
.50384 .30978 Mdot
.59423 .65099 Mdot
.38114 .6206 Mdot
.4101 .49672 Mdot
.55768 .35261 Mdot
.39019 .63798 Mdot
.33304 .32835 Mdot
.57275 .36269 Mdot
.16094 .56486 Mdot
.38025 .67591 Mdot
.63133 .46395 Mdot
.5726 .31196 Mdot
.40919 .39077 Mdot
.65647 .53732 Mdot
.67685 .68856 Mdot
.65982 .50192 Mdot
.44655 .43595 Mdot
.74725 .56534 Mdot
.57418 .67773 Mdot
.39892 .44902 Mdot
.65378 .45542 Mdot
.69129 .58711 Mdot
.38504 .47561 Mdot
.42578 .42193 Mdot
.45148 .17931 Mdot
.19038 .44506 Mdot
.56464 .33632 Mdot
.36462 .68693 Mdot
.37869 .41183 Mdot
.54297 .33602 Mdot
.69732 .40414 Mdot
.38943 .47209 Mdot
.34836 .65915 Mdot
.4335 .50603 Mdot
.62478 .45939 Mdot
.5958 .64479 Mdot
.5998 .56226 Mdot
.53996 .34616 Mdot
.5858 .8555 Mdot
.65552 .52364 Mdot
.37315 .48164 Mdot
.414 .4003 Mdot
.61835 .2653 Mdot
.40907 .6283 Mdot
.2315 .63291 Mdot
.4237 .47177 Mdot
.3993 .72483 Mdot
.39964 .46075 Mdot
.61322 .50054 Mdot
.35972 .65584 Mdot
.43377 .45671 Mdot
.52445 .69216 Mdot
.42484 .38323 Mdot
.54847 .3619 Mdot
.57236 .78674 Mdot
.4604 .41311 Mdot
.1283 .48409 Mdot
.59656 .39525 Mdot
.64718 .50249 Mdot
.77969 .55501 Mdot
.88191 .52625 Mdot
.50557 .76477 Mdot
.40123 .62083 Mdot
.79499 .44901 Mdot
.63522 .48435 Mdot
.76874 .53528 Mdot
.7239 .27367 Mdot
.41047 .41981 Mdot
.43361 .48281 Mdot
.5789 .25615 Mdot
.68978 .48277 Mdot
.69774 .4817 Mdot
.35126 .45564 Mdot
.45606 .39395 Mdot
.63761 .49381 Mdot
.35874 .44618 Mdot
.35954 .4782 Mdot
.55311 .67508 Mdot
.35236 .66185 Mdot
.60079 .63496 Mdot
.61677 .65441 Mdot
.49671 .81429 Mdot
.60491 .37923 Mdot
.58822 .63742 Mdot
.60909 .62896 Mdot
.40091 .29842 Mdot
.39769 .25145 Mdot
.57903 .30789 Mdot
.82416 .41681 Mdot
.64935 .47107 Mdot
.43448 .44924 Mdot
.37431 .67999 Mdot
.28624 .6653 Mdot
.73485 .42029 Mdot
.1864 .57861 Mdot
.44901 .46742 Mdot
.63116 .47316 Mdot
.62592 .57791 Mdot
.34917 .39952 Mdot
.64699 .44132 Mdot
.39889 .47379 Mdot
.68163 .51556 Mdot
.31669 .50615 Mdot
.67087 .72173 Mdot
.68364 .45082 Mdot
.33369 .64637 Mdot
.3915 .46531 Mdot
.35872 .66817 Mdot
.59882 .66214 Mdot
.57301 .30946 Mdot
.56793 .33567 Mdot
.42822 .43252 Mdot
.38582 .52309 Mdot
.6417 .39761 Mdot
.41386 .43039 Mdot
.37897 .422 Mdot
.63694 .57801 Mdot
.3772 .4201 Mdot
.44211 .41115 Mdot
.45166 .43105 Mdot
.44431 .48064 Mdot
.57102 .67953 Mdot
.75514 .63604 Mdot
.4609 .38391 Mdot
.45517 .38477 Mdot
.60227 .68109 Mdot
.76772 .39121 Mdot
.61672 .6436 Mdot
.68726 .25316 Mdot
.57392 .62592 Mdot
.56654 .32798 Mdot
.66066 .28484 Mdot
.39659 .53655 Mdot
.34948 .63159 Mdot
.62265 .66679 Mdot
.55369 .32423 Mdot
.58449 .659 Mdot
.6278 .49687 Mdot
.46377 .16584 Mdot
.42415 .62968 Mdot
.43827 .55778 Mdot
.62703 .62099 Mdot
.72127 .66054 Mdot
.657 .52065 Mdot
.36298 .67133 Mdot
.32458 .58407 Mdot
.43216 .40489 Mdot
.54475 .33141 Mdot
.43684 .4374 Mdot
.58813 .67913 Mdot
.63423 .475 Mdot
.63641 .78255 Mdot
.55791 .35404 Mdot
.38448 .20447 Mdot
.67022 .48191 Mdot
.45211 .42259 Mdot
.6178 .65533 Mdot
.29765 .2607 Mdot
.59618 .63185 Mdot
.20967 .57663 Mdot
.40503 .60751 Mdot
.6039 .82229 Mdot
.39316 .62662 Mdot
.68279 .69136 Mdot
.28548 .23399 Mdot
.76337 .63539 Mdot
.36406 .62256 Mdot
.5278 .60667 Mdot
.38408 .43767 Mdot
.37401 .45078 Mdot
.65591 .74822 Mdot
.36198 .68555 Mdot
.39875 .40316 Mdot
.72267 .53668 Mdot
.53729 .61186 Mdot
.30228 .29559 Mdot
.67045 .50664 Mdot
.41728 .46491 Mdot
.57568 .61768 Mdot
.55663 .62943 Mdot
.67299 .51962 Mdot
.60107 .62952 Mdot
.39691 .44048 Mdot
.39022 .63524 Mdot
.72868 .47782 Mdot
.57621 .33108 Mdot
.80941 .62488 Mdot
.53895 .33259 Mdot
.66227 .50144 Mdot
.37114 .40134 Mdot
.63774 .48792 Mdot
.90355 .48992 Mdot
.38997 .44479 Mdot
.36607 .63274 Mdot
.38423 .41181 Mdot
.39024 .46191 Mdot
.44779 .47542 Mdot
.63096 .49171 Mdot
.477 .35187 Mdot
.35971 .43783 Mdot
.56307 .65073 Mdot
.2327 .47508 Mdot
.4615 .42044 Mdot
.7084 .5056 Mdot
.39583 .26663 Mdot
.59365 .60155 Mdot
.4104 .64732 Mdot
.65203 .50242 Mdot
.37381 .62162 Mdot
.35522 .72579 Mdot
.38119 .62093 Mdot
.23577 .54678 Mdot
.32974 .57005 Mdot
.29467 .36515 Mdot
.29083 .42414 Mdot
.50173 .60061 Mdot
.36343 .68639 Mdot
.52404 .36515 Mdot
.37018 .60913 Mdot
.39752 .66209 Mdot
.09522 .40879 Mdot
.34551 .63518 Mdot
.41538 .47376 Mdot
.45835 .4196 Mdot
.71242 .68251 Mdot
.46359 .28408 Mdot
.39465 .41136 Mdot
.40036 .40697 Mdot
.58422 .32183 Mdot
.38145 .72236 Mdot
.75457 .59081 Mdot
.17962 .46325 Mdot
.78837 .52187 Mdot
.4343 .43761 Mdot
.37538 .41398 Mdot
.3791 .37759 Mdot
.20952 .35196 Mdot
.50107 .82332 Mdot
.4084 .58061 Mdot
.37832 .38039 Mdot
.75892 .66378 Mdot
.44309 .47762 Mdot
.40611 .48397 Mdot
.3882 .43669 Mdot
.6348 .48372 Mdot
.40031 .66456 Mdot
.43674 .48759 Mdot
.5927 .26962 Mdot
.40736 .48098 Mdot
.67307 .58939 Mdot
.70669 .76774 Mdot
.42144 .46504 Mdot
.41862 .63635 Mdot
.37291 .44647 Mdot
.40714 .64089 Mdot
.37815 .66821 Mdot
.35532 .4088 Mdot
.21756 .5048 Mdot
.41553 .61468 Mdot
.40273 .43352 Mdot
.62452 .48335 Mdot
.81289 .3755 Mdot
.44666 .43775 Mdot
.57381 .30816 Mdot
.42505 .47423 Mdot
.59477 .32117 Mdot
.38339 .41918 Mdot
.6572 .5242 Mdot
.30231 .69406 Mdot
.64371 .47902 Mdot
.54074 .83286 Mdot
.6392 .52377 Mdot
.43244 .17531 Mdot
.36004 .67932 Mdot
.7337 .57808 Mdot
.26164 .69064 Mdot
.64672 .61339 Mdot
.53203 .44769 Mdot
.50026 .5497 Mdot
.61116 .64151 Mdot
.40451 .61106 Mdot
.44899 .6614 Mdot
.74664 .39457 Mdot
.69446 .32573 Mdot
.6655 .46295 Mdot
.34573 .80086 Mdot
.20121 .63142 Mdot
.36164 .46054 Mdot
.28848 .57771 Mdot
.26281 .51757 Mdot
.44194 .47936 Mdot
.42687 .49157 Mdot
.63305 .55653 Mdot
.35865 .4308 Mdot
.54579 .72598 Mdot
.66595 .50004 Mdot
.55204 .32478 Mdot
.36111 .64016 Mdot
.53869 .35138 Mdot
.74076 .37623 Mdot
.49598 .54916 Mdot
.63206 .50612 Mdot
.46196 .40706 Mdot
.40584 .4087 Mdot
.40169 .65118 Mdot
.37512 .57925 Mdot
.36135 .6161 Mdot
.55343 .34147 Mdot
.66811 .49472 Mdot
.34114 .75754 Mdot
.41117 .40678 Mdot
.37318 .65536 Mdot
.5363 .4325 Mdot
.38093 .41029 Mdot
.59627 .65853 Mdot
.38294 .44257 Mdot
.36049 .62747 Mdot
.3774 .4199 Mdot
.39438 .62535 Mdot
.65735 .49054 Mdot
.45864 .43719 Mdot
.43259 .41917 Mdot
.3384 .233 Mdot
.56003 .32511 Mdot
.35043 .6696 Mdot
.58081 .49012 Mdot
.39783 .3978 Mdot
.70683 .60423 Mdot
.40329 .47538 Mdot
.31938 .69241 Mdot
.37562 .47638 Mdot
.64166 .60274 Mdot
.47397 .40257 Mdot
.44546 .44238 Mdot
.56232 .42641 Mdot
.25913 .53021 Mdot
.37655 .54484 Mdot
.61789 .63305 Mdot
.34136 .656 Mdot
.30627 .2963 Mdot
.63395 .42981 Mdot
.65683 .44805 Mdot
.51399 .24698 Mdot
.45392 .47409 Mdot
.41949 .45537 Mdot
.61225 .61975 Mdot
.54865 .35605 Mdot
.36524 .66521 Mdot
.56004 .3208 Mdot
.36863 .22818 Mdot
.56129 .36249 Mdot
.60827 .48626 Mdot
.66673 .41232 Mdot
.36258 .77347 Mdot
.58505 .32506 Mdot
.36126 .62318 Mdot
.72218 .44822 Mdot
.46264 .4637 Mdot
.59176 .39915 Mdot
.57366 .32108 Mdot
.43573 .85124 Mdot
.44303 .41243 Mdot
.52978 .44542 Mdot
.59576 .639 Mdot
.57989 .31539 Mdot
.6096 .66003 Mdot
.4101 .4131 Mdot
.75555 .58269 Mdot
.40001 .619 Mdot
.60024 .67856 Mdot
.37304 .51315 Mdot
.5523 .33492 Mdot
.62583 .51094 Mdot
.62326 .62935 Mdot
.62055 .64246 Mdot
.77579 .38637 Mdot
.61513 .79993 Mdot
.66858 .4919 Mdot
.24808 .38207 Mdot
.569 .62566 Mdot
.46377 .45737 Mdot
.39627 .713 Mdot
.38084 .45851 Mdot
.48429 .79056 Mdot
.6564 .50636 Mdot
.73282 .6559 Mdot
.37673 .41492 Mdot
.449 .45827 Mdot
.42264 .62121 Mdot
.65159 .47691 Mdot
.38029 .63841 Mdot
.3411 .66275 Mdot
.65801 .48908 Mdot
.39019 .61755 Mdot
.58431 .35294 Mdot
.48644 .66799 Mdot
.55744 .64172 Mdot
.5608 .66033 Mdot
.64408 .46935 Mdot
.64748 .50596 Mdot
.64146 .49136 Mdot
.38258 .44302 Mdot
.36188 .66244 Mdot
.39812 .42067 Mdot
.41471 .48479 Mdot
.23144 .46125 Mdot
.39308 .67029 Mdot
.39218 .42916 Mdot
.58186 .43316 Mdot
.56712 .39376 Mdot
.62338 .48647 Mdot
.59142 .63845 Mdot
.72839 .54835 Mdot
.66587 .69653 Mdot
.41383 .46669 Mdot
.61694 .32934 Mdot
.36352 .6183 Mdot
.55844 .3499 Mdot
.5316 .34144 Mdot
.56223 .34054 Mdot
.61545 .58964 Mdot
.35529 .68025 Mdot
.17719 .47423 Mdot
.41908 .46146 Mdot
.46735 .55899 Mdot
.43685 .65109 Mdot
.62518 .38844 Mdot
.58822 .63885 Mdot
.38757 .40835 Mdot
.59578 .55941 Mdot
.31997 .60924 Mdot
.38213 .45643 Mdot
.46426 .43163 Mdot
.75922 .46495 Mdot
.45132 .49532 Mdot
.3914 .59469 Mdot
.29866 .26449 Mdot
.38945 .39592 Mdot
.40828 .76086 Mdot
.81774 .62565 Mdot
.40572 .46993 Mdot
.44322 .46871 Mdot
.42989 .41005 Mdot
.36969 .42875 Mdot
.4179 .62913 Mdot
.45839 .25521 Mdot
.57722 .62306 Mdot
.46574 .55481 Mdot
.56387 .67973 Mdot
.65275 .53387 Mdot
.73962 .65264 Mdot
.4024 .60649 Mdot
.56525 .35553 Mdot
.79856 .58298 Mdot
.23298 .3524 Mdot
.67565 .51235 Mdot
.44429 .80466 Mdot
.56882 .32234 Mdot
.46483 .44963 Mdot
.59134 .33878 Mdot
.61758 .49167 Mdot
.55764 .65701 Mdot
.4699 .43464 Mdot
.3738 .60823 Mdot
.35324 .64833 Mdot
.3893 .40554 Mdot
.76866 .64932 Mdot
.59939 .65463 Mdot
.62326 .64473 Mdot
.38701 .47358 Mdot
.41099 .39106 Mdot
.38209 .63361 Mdot
.66704 .4718 Mdot
.3125 .32462 Mdot
.5446 .34695 Mdot
.40138 .49958 Mdot
.37467 .42584 Mdot
.43797 .19178 Mdot
.5624 .64695 Mdot
.63722 .44615 Mdot
.37317 .47011 Mdot
.45576 .73742 Mdot
.37131 .46743 Mdot
.36397 .38899 Mdot
.62402 .48094 Mdot
.45791 .37677 Mdot
.36428 .4748 Mdot
.42007 .65217 Mdot
.611 .64743 Mdot
.37156 .63125 Mdot
.3799 .69145 Mdot
.45591 .60019 Mdot
.59431 .65993 Mdot
.38563 .43223 Mdot
.58475 .64255 Mdot
.38877 .47106 Mdot
.36856 .41653 Mdot
.58694 .63581 Mdot
.38126 .63742 Mdot
.79328 .4541 Mdot
.76167 .62856 Mdot
.36726 .43176 Mdot
.34898 .43267 Mdot
.45737 .26779 Mdot
.48448 .35854 Mdot
.44142 .47624 Mdot
.35812 .6321 Mdot
.4189 .41057 Mdot
.60211 .66734 Mdot
.58764 .34305 Mdot
.36404 .62592 Mdot
.67711 .48608 Mdot
.66879 .51688 Mdot
.49913 .75739 Mdot
.67879 .46712 Mdot
.42551 .48769 Mdot
.32531 .68381 Mdot
.40007 .67421 Mdot
.78642 .65252 Mdot
.65856 .48568 Mdot
.58105 .30731 Mdot
.42622 .42375 Mdot
.5507 .22412 Mdot
.56667 .61919 Mdot
.12271 .54491 Mdot
.16768 .5303 Mdot
.56536 .37389 Mdot
.18878 .57175 Mdot
.65098 .52776 Mdot
.37322 .48847 Mdot
.56736 .30954 Mdot
.66321 .51586 Mdot
.36757 .45169 Mdot
.358 .40266 Mdot
.22497 .61869 Mdot
.48376 .59186 Mdot
.58181 .64159 Mdot
.68555 .48514 Mdot
.56065 .37689 Mdot
.60796 .47293 Mdot
.36308 .67622 Mdot
.44185 .44889 Mdot
.36686 .40308 Mdot
.67431 .4771 Mdot
.67571 .45532 Mdot
.39716 .43249 Mdot
.39717 .59949 Mdot
.62621 .55589 Mdot
.42836 .43857 Mdot
.48669 .62886 Mdot
.34038 .68359 Mdot
.67062 .50183 Mdot
.44817 .45289 Mdot
.51508 .37443 Mdot
.67005 .47867 Mdot
.62303 .48884 Mdot
.37763 .41054 Mdot
.58074 .35758 Mdot
.35367 .42143 Mdot
.57066 .62885 Mdot
.39385 .81743 Mdot
.601 .66968 Mdot
.73301 .49938 Mdot
.37787 .51846 Mdot
.44812 .7077 Mdot
.41178 .63852 Mdot
.4957 .21773 Mdot
.72461 .53808 Mdot
.35308 .46858 Mdot
.7916 .36144 Mdot
.60378 .70446 Mdot
.78559 .62759 Mdot
.62466 .23836 Mdot
.58147 .3283 Mdot
.58478 .66132 Mdot
.44276 .46962 Mdot
.55001 .67247 Mdot
.56493 .30926 Mdot
.54347 .83011 Mdot
.45025 .4426 Mdot
.36019 .65261 Mdot
.39463 .43657 Mdot
.35588 .65812 Mdot
.37444 .413 Mdot
.40602 .37548 Mdot
.67759 .56846 Mdot
.35576 .31884 Mdot
.38172 .47822 Mdot
.41755 .16237 Mdot
.5226 .3939 Mdot
.54655 .33322 Mdot
.40614 .42149 Mdot
.64955 .43841 Mdot
.54855 .63446 Mdot
.59307 .75496 Mdot
.63411 .48462 Mdot
.61654 .63683 Mdot
.38618 .6229 Mdot
.6564 .50055 Mdot
.67619 .51484 Mdot
.46018 .37717 Mdot
.57885 .36349 Mdot
.57228 .67198 Mdot
.43488 .4577 Mdot
.44952 .44264 Mdot
.24632 .37442 Mdot
.73233 .40328 Mdot
.36823 .58292 Mdot
.17294 .41442 Mdot
.33583 .65256 Mdot
.55 .33213 Mdot
.62968 .48482 Mdot
.4232 .48267 Mdot
.40176 .44692 Mdot
.7141 .58651 Mdot
.37761 .60123 Mdot
.53266 .55815 Mdot
.32443 .71425 Mdot
.58192 .48377 Mdot
.40059 .28184 Mdot
.3598 .63726 Mdot
.40027 .28354 Mdot
.53146 .36281 Mdot
.83669 .47399 Mdot
.37759 .30788 Mdot
.59532 .64078 Mdot
.40607 .28265 Mdot
.37392 .66018 Mdot
.36128 .44381 Mdot
.62843 .46511 Mdot
.671 .45957 Mdot
.37494 .63567 Mdot
.61515 .45695 Mdot
.58162 .343 Mdot
.43893 .46717 Mdot
.18652 .44287 Mdot
.50907 .73871 Mdot
.64727 .46604 Mdot
.36291 .38325 Mdot
.58543 .67446 Mdot
.38923 .40507 Mdot
.5858 .33472 Mdot
.58686 .64901 Mdot
.47384 .20467 Mdot
.52946 .63516 Mdot
.42526 .42651 Mdot
.44755 .18173 Mdot
.59038 .65714 Mdot
.49979 .38492 Mdot
.43262 .44376 Mdot
.58173 .62534 Mdot
.49423 .40052 Mdot
.69551 .65991 Mdot
.57611 .54421 Mdot
.72552 .2744 Mdot
.56133 .53727 Mdot
.63649 .46311 Mdot
.70813 .66202 Mdot
.64653 .64961 Mdot
.54826 .64754 Mdot
.65388 .44458 Mdot
.58101 .38007 Mdot
.61083 .65749 Mdot
.4626 .43618 Mdot
.40187 .47251 Mdot
.51736 .82507 Mdot
.6308 .68438 Mdot
.67893 .70042 Mdot
.55034 .76141 Mdot
.40278 .39714 Mdot
.35605 .4159 Mdot
.40669 .44825 Mdot
.41252 .60173 Mdot
.57252 .64315 Mdot
.36246 .19921 Mdot
.59853 .65932 Mdot
.19902 .47373 Mdot
.64534 .47088 Mdot
.66835 .50937 Mdot
.41761 .46704 Mdot
.51878 .44687 Mdot
.43501 .23542 Mdot
.39948 .43889 Mdot
.60435 .33328 Mdot
.58309 .7876 Mdot
.40658 .3922 Mdot
.41113 .61487 Mdot
.37859 .37307 Mdot
.35379 .37744 Mdot
.55706 .64184 Mdot
.57518 .34442 Mdot
.48428 .21473 Mdot
.55905 .66465 Mdot
.41838 .45457 Mdot
.45675 .70774 Mdot
.3904 .45696 Mdot
.36671 .43791 Mdot
.17935 .52582 Mdot
.53281 .35414 Mdot
.64752 .48955 Mdot
.56111 .33846 Mdot
.40915 .6389 Mdot
.09126 .49976 Mdot
.55539 .36342 Mdot
.44021 .22934 Mdot
.49806 .83425 Mdot
.40876 .28492 Mdot
.35585 .66632 Mdot
.58662 .35683 Mdot
.59916 .64832 Mdot
.81809 .38184 Mdot
.25564 .6628 Mdot
.5757 .71693 Mdot
.42434 .4414 Mdot
.36339 .60112 Mdot
.35181 .63801 Mdot
.59895 .68075 Mdot
.37564 .66856 Mdot
.4839 .46877 Mdot
.36339 .44005 Mdot
.54589 .66043 Mdot
.46767 .72997 Mdot
.61737 .63152 Mdot
.51284 .63957 Mdot
.40753 .42595 Mdot
.36321 .63182 Mdot
.39322 .50103 Mdot
.34593 .68921 Mdot
.61997 .45819 Mdot
.43759 .38947 Mdot
.58028 .34609 Mdot
.44056 .72592 Mdot
.6701 .49083 Mdot
.6184 .36316 Mdot
.40244 .65132 Mdot
.58569 .59254 Mdot
.39068 .66401 Mdot
.36923 .68955 Mdot
.61782 .64816 Mdot
.39207 .64509 Mdot
.44261 .46775 Mdot
.56983 .46926 Mdot
.40521 .63425 Mdot
.57288 .66385 Mdot
.57377 .34187 Mdot
.39037 .62553 Mdot
.6881 .4437 Mdot
.43216 .42622 Mdot
.63536 .49916 Mdot
.65308 .28432 Mdot
.35374 .61338 Mdot
.53798 .36224 Mdot
.66694 .45211 Mdot
.54362 .33128 Mdot
.74131 .71522 Mdot
.56353 .68889 Mdot
.19869 .50768 Mdot
.58459 .37168 Mdot
.3511 .62796 Mdot
.66505 .28929 Mdot
.41852 .48192 Mdot
.42975 .42462 Mdot
.59274 .3109 Mdot
.3519 .63749 Mdot
.83183 .53994 Mdot
.32499 .44783 Mdot
.50469 .63663 Mdot
.60979 .68291 Mdot
.43298 .17123 Mdot
.51338 .65444 Mdot
.79331 .69033 Mdot
.35264 .47717 Mdot
.6984 .48479 Mdot
.40964 .46123 Mdot
.70962 .55557 Mdot
.5545 .33401 Mdot
.71662 .51153 Mdot
.3862 .38564 Mdot
.65264 .49314 Mdot
.44132 .42199 Mdot
.56173 .44179 Mdot
.44676 .36229 Mdot
.5785 .30561 Mdot
.77319 .56522 Mdot
.34335 .64194 Mdot
.57553 .32753 Mdot
.64565 .52014 Mdot
.42347 .25638 Mdot
.36581 .44762 Mdot
.45217 .48864 Mdot
.58197 .48318 Mdot
.35961 .66385 Mdot
.63709 .45812 Mdot
.56379 .63505 Mdot
.56662 .35242 Mdot
.40339 .40991 Mdot
.40436 .48801 Mdot
.70105 .60523 Mdot
.58638 .6758 Mdot
.68527 .46835 Mdot
.60322 .63951 Mdot
.66124 .52774 Mdot
.36383 .41842 Mdot
.67457 .5071 Mdot
.4136 .50085 Mdot
.67007 .57343 Mdot
.18705 .51045 Mdot
.26714 .55154 Mdot
.65908 .50675 Mdot
.37004 .27796 Mdot
.59075 .67136 Mdot
.59461 .62988 Mdot
.4228 .81352 Mdot
.20964 .58262 Mdot
.23432 .37223 Mdot
.73969 .32471 Mdot
.55736 .67375 Mdot
.5805 .67207 Mdot
.63761 .50213 Mdot
.39318 .64624 Mdot
.33781 .66324 Mdot
.66531 .52602 Mdot
.50575 .30093 Mdot
.36534 .66503 Mdot
.80782 .39807 Mdot
.27762 .32347 Mdot
.43206 .49329 Mdot
.60743 .45859 Mdot
.56331 .3482 Mdot
.49878 .29288 Mdot
.56457 .43757 Mdot
.44972 .46034 Mdot
.52871 .22294 Mdot
.65405 .46863 Mdot
.5022 .48192 Mdot
.6893 .25701 Mdot
.45122 .42771 Mdot
.43513 .44771 Mdot
.41081 .45376 Mdot
.56075 .37184 Mdot
.23594 .62711 Mdot
.44463 .45772 Mdot
.50532 .30365 Mdot
.39495 .40023 Mdot
.49267 .38329 Mdot
.56603 .33636 Mdot
.34253 .34154 Mdot
.75017 .39123 Mdot
.29632 .27242 Mdot
.44494 .35758 Mdot
.56439 .63324 Mdot
.59071 .27623 Mdot
.6031 .63432 Mdot
.24209 .54714 Mdot
.3878 .30784 Mdot
.33878 .63342 Mdot
.44824 .464 Mdot
.66293 .5018 Mdot
.35169 .63991 Mdot
.70787 .63332 Mdot
.08831 .45498 Mdot
.56333 .63205 Mdot
.84317 .64455 Mdot
.58066 .62648 Mdot
.67641 .51539 Mdot
.382 .63245 Mdot
.3319 .56156 Mdot
.46287 .57615 Mdot
.39162 .62276 Mdot
.80696 .50163 Mdot
.40563 .57938 Mdot
.39242 .27314 Mdot
.37135 .60004 Mdot
.578 .66747 Mdot
.62165 .59892 Mdot
.40879 .53902 Mdot
.4179 .47823 Mdot
.50453 .5446 Mdot
.41428 .24738 Mdot
.42044 .48101 Mdot
.66637 .49773 Mdot
.19552 .52391 Mdot
.51704 .23276 Mdot
.38684 .64858 Mdot
.53047 .65318 Mdot
.43965 .44407 Mdot
.37321 .43882 Mdot
.36431 .44877 Mdot
.15355 .48582 Mdot
.83788 .47758 Mdot
.36001 .43523 Mdot
.38707 .39997 Mdot
.65533 .49714 Mdot
.54457 .38364 Mdot
.75468 .50275 Mdot
.24619 .41603 Mdot
.45768 .44865 Mdot
.57203 .32891 Mdot
.54007 .37411 Mdot
.36822 .46227 Mdot
.59746 .39952 Mdot
.45868 .69912 Mdot
.4361 .45701 Mdot
.19858 .527 Mdot
.5868 .45439 Mdot
.68992 .48334 Mdot
.67508 .48133 Mdot
.35413 .66979 Mdot
.68256 .48828 Mdot
.64898 .52505 Mdot
.34295 .56989 Mdot
.54891 .54208 Mdot
.52892 .6647 Mdot
.55306 .34329 Mdot
.3976 .44918 Mdot
.36772 .53546 Mdot
.45243 .72817 Mdot
.61438 .65043 Mdot
.37165 .61358 Mdot
.55182 .63011 Mdot
.5646 .28804 Mdot
.43607 .57737 Mdot
.65769 .46406 Mdot
.55429 .66685 Mdot
.54624 .61889 Mdot
.57172 .33128 Mdot
.60022 .67458 Mdot
.56687 .61028 Mdot
.44868 .39743 Mdot
.28462 .59639 Mdot
.40436 .43552 Mdot
.80209 .59024 Mdot
.57654 .6762 Mdot
.64696 .59249 Mdot
.42642 .45549 Mdot
.66852 .47909 Mdot
.40465 .5454 Mdot
.41087 .48178 Mdot
.67835 .47996 Mdot
.36132 .459 Mdot
.5392 .33416 Mdot
.34774 .68756 Mdot
.45911 .56554 Mdot
.32147 .79452 Mdot
.58016 .36271 Mdot
.71068 .62513 Mdot
.44589 .47242 Mdot
.66474 .77301 Mdot
.39 .62898 Mdot
.39124 .49274 Mdot
.49319 .2318 Mdot
.402 .63633 Mdot
.37645 .6169 Mdot
.37898 .43469 Mdot
.59852 .64029 Mdot
.67116 .49462 Mdot
.56973 .33595 Mdot
.78984 .67653 Mdot
.42112 .43496 Mdot
.42773 .41547 Mdot
.57252 .32354 Mdot
.592 .67358 Mdot
.3754 .47111 Mdot
.62364 .26079 Mdot
.84351 .53222 Mdot
.59548 .62756 Mdot
.46195 .43952 Mdot
.2472 .58971 Mdot
.33545 .39769 Mdot
.58917 .84355 Mdot
.59614 .39471 Mdot
.64828 .496 Mdot
.42819 .51484 Mdot
.11698 .46899 Mdot
.57317 .34533 Mdot
.23257 .35817 Mdot
.37291 .4347 Mdot
.41107 .40539 Mdot
.36217 .61604 Mdot
.39736 .4242 Mdot
.39437 .60256 Mdot
.30532 .77033 Mdot
.43292 .19118 Mdot
.3634 .67308 Mdot
.35008 .62608 Mdot
.46306 .22515 Mdot
.74228 .52119 Mdot
.37684 .63269 Mdot
.37194 .41189 Mdot
.36495 .3476 Mdot
.39791 .55792 Mdot
.59348 .33248 Mdot
.71346 .33511 Mdot
.34497 .50352 Mdot
.58941 .29191 Mdot
.78107 .40622 Mdot
.34219 .50355 Mdot
.54185 .58972 Mdot
.57027 .63336 Mdot
.45217 .4289 Mdot
.67375 .46089 Mdot
.68089 .46797 Mdot
.37484 .49736 Mdot
.39081 .45036 Mdot
.40714 .64347 Mdot
.55521 .3559 Mdot
.55622 .63518 Mdot
.40389 .4071 Mdot
.48503 .22261 Mdot
.54874 .3585 Mdot
.38561 .6596 Mdot
.22087 .47359 Mdot
.56027 .3072 Mdot
.42505 .37725 Mdot
.42836 .46615 Mdot
.3906 .43577 Mdot
.38533 .54745 Mdot
.57298 .6391 Mdot
.69203 .30709 Mdot
.44373 .40355 Mdot
.3635 .23006 Mdot
.56823 .69901 Mdot
.46915 .40767 Mdot
.37303 .67322 Mdot
.52698 .64798 Mdot
.61794 .50381 Mdot
.45122 .6079 Mdot
.42335 .4276 Mdot
.77046 .62473 Mdot
.53782 .81921 Mdot
.62284 .45756 Mdot
.36455 .688 Mdot
.55877 .34553 Mdot
.3982 .44074 Mdot
.21894 .51126 Mdot
.4053 .47306 Mdot
.57524 .29555 Mdot
.62091 .4835 Mdot
.57294 .63221 Mdot
.79221 .61659 Mdot
.68312 .47566 Mdot
.37444 .62058 Mdot
.56023 .1542 Mdot
.39717 .60287 Mdot
.3404 .66748 Mdot
.23152 .47144 Mdot
.57466 .63717 Mdot
.11403 .50082 Mdot
.33533 .77666 Mdot
.41768 .38777 Mdot
.59343 .66978 Mdot
.36946 .64159 Mdot
.40711 .4014 Mdot
.33933 .62275 Mdot
.36044 .68265 Mdot
.36953 .41143 Mdot
.43219 .40894 Mdot
.69144 .70795 Mdot
.71985 .27788 Mdot
.55749 .34524 Mdot
.40371 .65527 Mdot
.48177 .63058 Mdot
.41177 .40056 Mdot
.42002 .46112 Mdot
.64898 .66737 Mdot
.58768 .34659 Mdot
.54248 .73146 Mdot
.37303 .43704 Mdot
.45719 .19119 Mdot
.43997 .37237 Mdot
.41562 .61851 Mdot
.60673 .63478 Mdot
.30448 .26745 Mdot
.63105 .63879 Mdot
.392 .60272 Mdot
.56258 .3585 Mdot
.41668 .65235 Mdot
.43726 .22866 Mdot
.5798 .68174 Mdot
.36044 .6275 Mdot
.60094 .56395 Mdot
.57522 .64883 Mdot
.56468 .67401 Mdot
.23815 .45838 Mdot
.6456 .44216 Mdot
.55695 .37273 Mdot
.5759 .673 Mdot
.41725 .7137 Mdot
.57581 .66109 Mdot
.35682 .78261 Mdot
.45894 .43578 Mdot
.52381 .26742 Mdot
.72641 .50686 Mdot
.41483 .52599 Mdot
.57435 .67839 Mdot
.58479 .32135 Mdot
.36949 .45381 Mdot
.37427 .66287 Mdot
.54165 .34319 Mdot
.57045 .72232 Mdot
.63656 .4916 Mdot
.39271 .66044 Mdot
.6291 .64248 Mdot
.35424 .65247 Mdot
.45072 .65757 Mdot
.46504 .83688 Mdot
.53718 .19848 Mdot
.46621 .58953 Mdot
.36535 .44488 Mdot
.7529 .35889 Mdot
.45787 .47707 Mdot
.38619 .45115 Mdot
.66903 .50115 Mdot
.52141 .25259 Mdot
.38063 .63765 Mdot
.82034 .5686 Mdot
.55453 .64876 Mdot
.30659 .25976 Mdot
.38681 .35395 Mdot
.36883 .47678 Mdot
.40581 .63028 Mdot
.39101 .59816 Mdot
.25144 .51444 Mdot
.62434 .51491 Mdot
.42066 .49297 Mdot
.46597 .46105 Mdot
.35846 .47288 Mdot
.55599 .6542 Mdot
.61767 .35717 Mdot
.63823 .4633 Mdot
.53722 .8426 Mdot
.62077 .47734 Mdot
.59774 .29472 Mdot
.38865 .64969 Mdot
.55607 .36327 Mdot
.42212 .46115 Mdot
.39134 .57357 Mdot
.37926 .60023 Mdot
.5864 .3055 Mdot
.57537 .31235 Mdot
.67381 .65846 Mdot
.58633 .63624 Mdot
.3979 .48438 Mdot
.44738 .45498 Mdot
.39558 .41889 Mdot
.38436 .44379 Mdot
.55798 .63826 Mdot
.37335 .46099 Mdot
.60002 .61835 Mdot
.41326 .69335 Mdot
.58027 .25379 Mdot
.56135 .53202 Mdot
.47169 .79773 Mdot
.3803 .65548 Mdot
.42962 .7085 Mdot
.33228 .45874 Mdot
.17079 .56882 Mdot
.60618 .78654 Mdot
.43804 .39706 Mdot
.66928 .51453 Mdot
.49883 .43973 Mdot
.66341 .46103 Mdot
.78331 .71871 Mdot
.68266 .60413 Mdot
.75484 .31076 Mdot
.44902 .44112 Mdot
.57134 .4831 Mdot
.38795 .73612 Mdot
.45696 .4804 Mdot
.68582 .62317 Mdot
.47654 .79206 Mdot
.77152 .58338 Mdot
.5868 .33729 Mdot
.43354 .43266 Mdot
.37448 .54217 Mdot
.44161 .46651 Mdot
.41392 .46267 Mdot
.36793 .45504 Mdot
.60854 .62558 Mdot
.40609 .49347 Mdot
.37716 .45841 Mdot
.6493 .39838 Mdot
.38636 .2937 Mdot
.67562 .45764 Mdot
.45503 .82146 Mdot
.55448 .36374 Mdot
.40616 .6403 Mdot
.82509 .46548 Mdot
.59445 .64059 Mdot
.25508 .51304 Mdot
.38693 .44017 Mdot
.72026 .67802 Mdot
.53574 .63451 Mdot
.5708 .35297 Mdot
.61633 .48983 Mdot
.78725 .33892 Mdot
.66299 .4957 Mdot
.61528 .58228 Mdot
.66703 .48065 Mdot
.33442 .47071 Mdot
.40694 .64504 Mdot
.38611 .47795 Mdot
.56913 .66942 Mdot
.67993 .49393 Mdot
.46426 .27482 Mdot
.40616 .45011 Mdot
.6572 .48847 Mdot
.38651 .47793 Mdot
.43788 .56111 Mdot
.26138 .37806 Mdot
.65153 .52422 Mdot
.53628 .63602 Mdot
.56521 .65352 Mdot
.57819 .35961 Mdot
.40042 .6494 Mdot
.37875 .60727 Mdot
.58562 .65005 Mdot
.22519 .63367 Mdot
.45718 .45637 Mdot
.41973 .40254 Mdot
.32577 .25061 Mdot
.43696 .47607 Mdot
.41 .26516 Mdot
.58733 .54993 Mdot
.38044 .66101 Mdot
.35979 .46641 Mdot
.37688 .42995 Mdot
.42639 .42583 Mdot
.43925 .65837 Mdot
.66672 .47056 Mdot
.45438 .42972 Mdot
.57039 .31233 Mdot
.61678 .41548 Mdot
.38872 .4051 Mdot
.47911 .39719 Mdot
.37628 .60862 Mdot
.17305 .42337 Mdot
.58017 .62741 Mdot
.64994 .52043 Mdot
.65809 .50826 Mdot
.72732 .34841 Mdot
.43204 .75343 Mdot
.58526 .54646 Mdot
.57056 .83661 Mdot
.67674 .56821 Mdot
.55546 .32538 Mdot
.6 .49605 Mdot
.62659 .60519 Mdot
.64509 .5123 Mdot
.56189 .63242 Mdot
.4583 .43046 Mdot
.45812 .44607 Mdot
.16269 .58708 Mdot
.3664 .46156 Mdot
.56232 .34469 Mdot
.62132 .63425 Mdot
.37391 .65934 Mdot
.56844 .35392 Mdot
.60469 .63992 Mdot
.36258 .67004 Mdot
.44973 .40516 Mdot
.45182 .40895 Mdot
.3742 .61221 Mdot
.35627 .62934 Mdot
.4286 .46272 Mdot
.74361 .4932 Mdot
.34817 .63428 Mdot
.35932 .63411 Mdot
.65229 .46361 Mdot
.67397 .46271 Mdot
.47018 .39527 Mdot
.591 .66789 Mdot
.37591 .45877 Mdot
.65863 .50066 Mdot
.56135 .36214 Mdot
.38132 .64047 Mdot
.3683 .43153 Mdot
.38746 .40967 Mdot
.57261 .33267 Mdot
.57596 .35642 Mdot
.58434 .32734 Mdot
.61352 .62566 Mdot
.40458 .41708 Mdot
.38244 .62643 Mdot
.58261 .63429 Mdot
.5425 .37392 Mdot
.59174 .3271 Mdot
.60562 .4983 Mdot
.42821 .48238 Mdot
.71695 .45904 Mdot
.11875 .43626 Mdot
.36754 .24195 Mdot
.61229 .47338 Mdot
.61175 .49023 Mdot
.42728 .2951 Mdot
.50678 .48542 Mdot
.59532 .65462 Mdot
.52915 .38146 Mdot
.48042 .21257 Mdot
.45999 .41134 Mdot
.39391 .39516 Mdot
.38969 .3775 Mdot
.58091 .31986 Mdot
.53697 .24705 Mdot
.40365 .60829 Mdot
.31599 .46049 Mdot
.54359 .35514 Mdot
.6766 .45639 Mdot
.60163 .47686 Mdot
.61965 .48056 Mdot
.45687 .42199 Mdot
.27429 .55182 Mdot
.42416 .73126 Mdot
.70709 .29766 Mdot
.58162 .67803 Mdot
.36824 .53504 Mdot
.66394 .77017 Mdot
.37642 .6135 Mdot
.65102 .5346 Mdot
.55704 .32226 Mdot
.35558 .63336 Mdot
.54481 .63471 Mdot
.57732 .67171 Mdot
.64451 .46637 Mdot
.6389 .47031 Mdot
.63003 .49942 Mdot
.35489 .68305 Mdot
.39068 .64737 Mdot
.42036 .42668 Mdot
.38207 .64455 Mdot
.16187 .53371 Mdot
.59698 .32517 Mdot
.70573 .50148 Mdot
.58754 .66279 Mdot
.35889 .66772 Mdot
.4056 .44718 Mdot
.48733 .5074 Mdot
.52718 .77435 Mdot
.55058 .32348 Mdot
.25299 .37472 Mdot
.76913 .72908 Mdot
.40102 .48601 Mdot
.56687 .64364 Mdot
.18895 .43459 Mdot
.41167 .45132 Mdot
.62782 .48057 Mdot
.7589 .4819 Mdot
.59345 .46171 Mdot
.40799 .48201 Mdot
.46235 .41219 Mdot
.58537 .62413 Mdot
.55981 .83195 Mdot
.41906 .4303 Mdot
.52052 .71706 Mdot
.5468 .67286 Mdot
.63274 .46559 Mdot
.85758 .45704 Mdot
.63539 .28736 Mdot
.50442 .29424 Mdot
.6427 .46413 Mdot
.39087 .46323 Mdot
.66564 .46426 Mdot
.55812 .31794 Mdot
.63173 .51393 Mdot
.40219 .60406 Mdot
.62689 .4574 Mdot
.42816 .41506 Mdot
.37467 .63344 Mdot
.59157 .65773 Mdot
.27454 .30084 Mdot
.71833 .42693 Mdot
.66717 .47735 Mdot
.66044 .52304 Mdot
.36041 .46417 Mdot
.56062 .7334 Mdot
.39189 .50543 Mdot
.44505 .41502 Mdot
.56226 .67803 Mdot
.40296 .63902 Mdot
.60833 .63215 Mdot
.48149 .44826 Mdot
.61581 .24823 Mdot
.60082 .63703 Mdot
.7648 .62128 Mdot
.56702 .32239 Mdot
.54106 .48013 Mdot
.39996 .44626 Mdot
.6056 .66824 Mdot
.40612 .41837 Mdot
.40789 .61564 Mdot
.55752 .49997 Mdot
.7586 .58696 Mdot
.56172 .66518 Mdot
.77907 .62061 Mdot
.57296 .26705 Mdot
.4883 .42586 Mdot
.59786 .63027 Mdot
.50385 .23435 Mdot
.67735 .51427 Mdot
.54379 .34698 Mdot
.54972 .31783 Mdot
.53916 .34869 Mdot
.36891 .49942 Mdot
.42266 .3515 Mdot
.53339 .35774 Mdot
.54507 .63894 Mdot
.57786 .30575 Mdot
.38937 .76343 Mdot
.81911 .5604 Mdot
.55708 .33172 Mdot
.42986 .44229 Mdot
.35076 .38762 Mdot
.402 .29672 Mdot
.68955 .66837 Mdot
.76931 .32891 Mdot
.59461 .76483 Mdot
.41513 .47755 Mdot
.34091 .6803 Mdot
.37777 .67885 Mdot
.198 .40513 Mdot
.39674 .25571 Mdot
.4014 .21626 Mdot
.34222 .63919 Mdot
.74062 .57237 Mdot
.38819 .65972 Mdot
.3646 .45524 Mdot
.41456 .40193 Mdot
.34256 .63531 Mdot
.57421 .24562 Mdot
.73471 .59482 Mdot
.79235 .64343 Mdot
.35496 .64379 Mdot
.61088 .646 Mdot
.60938 .67578 Mdot
.56598 .67564 Mdot
.26304 .33838 Mdot
.40262 .62049 Mdot
.39238 .41403 Mdot
.66072 .50657 Mdot
.45532 .43855 Mdot
.57708 .64544 Mdot
.82446 .56224 Mdot
.39637 .62371 Mdot
.44364 .44731 Mdot
.4731 .49896 Mdot
.63493 .47874 Mdot
.56804 .32677 Mdot
.43796 .55106 Mdot
.39932 .22064 Mdot
.55309 .65724 Mdot
.34986 .61876 Mdot
.66039 .58879 Mdot
.79614 .57728 Mdot
.34869 .46941 Mdot
.4676 .46113 Mdot
.78683 .6872 Mdot
.46069 .20002 Mdot
.43318 .48461 Mdot
.65865 .52019 Mdot
.70789 .58738 Mdot
.3789 .41419 Mdot
.38988 .67149 Mdot
.55475 .31163 Mdot
.54374 .33215 Mdot
.47387 .39818 Mdot
.47221 .5494 Mdot
.56525 .4825 Mdot
.38438 .43366 Mdot
.41799 .37639 Mdot
.6352 .46529 Mdot
.69574 .55877 Mdot
.37016 .22671 Mdot
.56632 .3589 Mdot
.3833 .47618 Mdot
.78993 .48156 Mdot
.36533 .61034 Mdot
.61965 .46252 Mdot
.59159 .67993 Mdot
.43868 .6398 Mdot
.61717 .49335 Mdot
.36924 .42095 Mdot
.37102 .4659 Mdot
.61562 .65829 Mdot
.41481 .61528 Mdot
.57845 .31822 Mdot
.66703 .50812 Mdot
.58012 .35101 Mdot
.40215 .63292 Mdot
.38717 .64251 Mdot
.48302 .48007 Mdot
.34264 .46507 Mdot
.67613 .48508 Mdot
.41328 .5015 Mdot
.59989 .44024 Mdot
.63287 .82169 Mdot
.62224 .66745 Mdot
.41269 .48932 Mdot
.40254 .59257 Mdot
.55769 .66077 Mdot
.41928 .40532 Mdot
.80491 .66528 Mdot
.40681 .39955 Mdot
.56407 .69569 Mdot
.51927 .18505 Mdot
.58425 .33886 Mdot
.31581 .45093 Mdot
.6651 .73849 Mdot
.43481 .47492 Mdot
.6496 .50902 Mdot
.35886 .3883 Mdot
.60093 .64539 Mdot
.38736 .64887 Mdot
.60894 .84177 Mdot
.57233 .66008 Mdot
.43867 .4637 Mdot
.56724 .35297 Mdot
.37917 .59762 Mdot
.60072 .36836 Mdot
.5989 .39864 Mdot
.47427 .37926 Mdot
.4025 .50013 Mdot
.37847 .44457 Mdot
.65068 .26595 Mdot
.64682 .51897 Mdot
.36258 .64251 Mdot
.56452 .64463 Mdot
.58921 .65037 Mdot
.65155 .46717 Mdot
.52114 .65157 Mdot
.54084 .48229 Mdot
.16944 .36599 Mdot
.67717 .47391 Mdot
.5407 .36041 Mdot
.53956 .7258 Mdot
.66042 .51311 Mdot
.6557 .48426 Mdot
.65145 .46248 Mdot
.57989 .57504 Mdot
.3616 .66616 Mdot
.37064 .41821 Mdot
.41096 .64574 Mdot
.38834 .46279 Mdot
.56078 .69453 Mdot
.56564 .66934 Mdot
.39726 .62974 Mdot
.76727 .69851 Mdot
.27512 .61822 Mdot
.42054 .44875 Mdot
.66577 .77131 Mdot
.37605 .39329 Mdot
.42818 .27847 Mdot
.3686 .39487 Mdot
.65602 .47234 Mdot
.42556 .50679 Mdot
.35912 .47646 Mdot
.21319 .37331 Mdot
.59043 .66376 Mdot
.69047 .49058 Mdot
.41208 .38329 Mdot
.41076 .37427 Mdot
.34992 .68086 Mdot
.35634 .63418 Mdot
.54529 .32437 Mdot
.34617 .32377 Mdot
.59439 .65865 Mdot
.32272 .754 Mdot
.42022 .47627 Mdot
.61145 .29288 Mdot
.28868 .42244 Mdot
.42382 .40666 Mdot
.67916 .7375 Mdot
.26913 .54247 Mdot
.39857 .44244 Mdot
.50328 .58803 Mdot
.58929 .67308 Mdot
.60083 .23496 Mdot
.38786 .40257 Mdot
.6323 .48281 Mdot
.39079 .65163 Mdot
.39237 .59619 Mdot
.53562 .34288 Mdot
.19222 .61897 Mdot
.61258 .63511 Mdot
.39372 .63966 Mdot
.40327 .45464 Mdot
.5686 .6397 Mdot
.68306 .48391 Mdot
.3735 .48041 Mdot
.38449 .26016 Mdot
.37703 .65147 Mdot
.35586 .44674 Mdot
.50042 .70338 Mdot
.4616 .30972 Mdot
.56827 .18079 Mdot
.56234 .64552 Mdot
.58216 .35423 Mdot
.37323 .37906 Mdot
.21813 .60997 Mdot
.35278 .4188 Mdot
.52875 .277 Mdot
.39761 .76824 Mdot
.5867 .34603 Mdot
.42844 .4518 Mdot
.39986 .41051 Mdot
.52784 .42703 Mdot
.56181 .36008 Mdot
.44997 .44628 Mdot
.37268 .70571 Mdot
.35888 .65887 Mdot
.65732 .53177 Mdot
.36965 .66104 Mdot
.4246 .44199 Mdot
.34012 .45566 Mdot
.35971 .62004 Mdot
.66756 .78866 Mdot
.59148 .35747 Mdot
.58543 .62917 Mdot
.38259 .39522 Mdot
.43481 .40077 Mdot
.3636 .18452 Mdot
.62859 .45253 Mdot
.75377 .51574 Mdot
.63843 .35341 Mdot
.78493 .44095 Mdot
.63364 .28551 Mdot
.66888 .22565 Mdot
.46638 .19771 Mdot
.4027 .4941 Mdot
.33429 .38453 Mdot
.46218 .67201 Mdot
.58237 .67945 Mdot
.32513 .72897 Mdot
.41771 .47854 Mdot
.41141 .46263 Mdot
.61138 .47188 Mdot
.74939 .63389 Mdot
.39989 .21601 Mdot
.48674 .51358 Mdot
.5783 .31959 Mdot
.40051 .65894 Mdot
.3704 .41615 Mdot
.52457 .56958 Mdot
.67199 .45383 Mdot
.60459 .27905 Mdot
.44169 .44844 Mdot
.17542 .54282 Mdot
.50138 .77106 Mdot
.57978 .63794 Mdot
.65631 .50932 Mdot
.42109 .2081 Mdot
.4231 .48345 Mdot
.59695 .67888 Mdot
.41588 .43628 Mdot
.65508 .55586 Mdot
.47968 .45628 Mdot
.55109 .33493 Mdot
.37089 .43723 Mdot
.58847 .27827 Mdot
.49756 .12522 Mdot
.52851 .34076 Mdot
.3455 .61538 Mdot
.70383 .49409 Mdot
.67063 .47289 Mdot
.35753 .62941 Mdot
.67243 .47678 Mdot
.25637 .48672 Mdot
.32773 .5305 Mdot
.57062 .32007 Mdot
.44136 .37771 Mdot
.55982 .33351 Mdot
.61976 .45969 Mdot
.41274 .47992 Mdot
.6942 .78843 Mdot
.67646 .49551 Mdot
.47934 .18107 Mdot
.57748 .659 Mdot
.67485 .45473 Mdot
.39368 .4008 Mdot
.65242 .59857 Mdot
.68308 .47449 Mdot
.74873 .60133 Mdot
.42556 .42586 Mdot
.38077 .65161 Mdot
.3813 .41405 Mdot
.40746 .38826 Mdot
.69479 .47546 Mdot
.38553 .46678 Mdot
.60522 .6408 Mdot
.34133 .65712 Mdot
.81281 .38854 Mdot
.45024 .78762 Mdot
.44884 .45897 Mdot
.40567 .454 Mdot
.39658 .67627 Mdot
.45165 .41741 Mdot
.55847 .63788 Mdot
.23628 .76223 Mdot
.56705 .32268 Mdot
.69352 .49966 Mdot
.63308 .28315 Mdot
.44511 .40013 Mdot
.37088 .45698 Mdot
.8203 .64278 Mdot
.60708 .25025 Mdot
.60108 .63348 Mdot
.35496 .46786 Mdot
.68376 .48264 Mdot
.56421 .35167 Mdot
.54722 .64222 Mdot
.39196 .43477 Mdot
.42399 .45824 Mdot
.57507 .36077 Mdot
.38087 .33871 Mdot
.29821 .29906 Mdot
.60896 .66808 Mdot
.40654 .51699 Mdot
.69434 .4523 Mdot
.45347 .46813 Mdot
.24774 .35843 Mdot
.36218 .6278 Mdot
.55285 .66073 Mdot
.75832 .38207 Mdot
.41876 .48694 Mdot
.61112 .63998 Mdot
.59429 .65982 Mdot
.35251 .45488 Mdot
.40037 .58999 Mdot
.34782 .66881 Mdot
.35437 .65704 Mdot
.16449 .61839 Mdot
.48996 .28626 Mdot
.62996 .49924 Mdot
.58994 .6734 Mdot
.65461 .52627 Mdot
.58605 .29398 Mdot
.57881 .55033 Mdot
.65634 .52438 Mdot
.35203 .66131 Mdot
.69961 .5077 Mdot
.41337 .41392 Mdot
.59264 .65661 Mdot
.64078 .50928 Mdot
.42547 .38892 Mdot
.55481 .72607 Mdot
.64924 .721 Mdot
.5884 .31971 Mdot
.54746 .31789 Mdot
.40091 .40271 Mdot
.63392 .5254 Mdot
.42617 .46342 Mdot
.56224 .68132 Mdot
.54264 .72268 Mdot
.38219 .39648 Mdot
.66645 .47539 Mdot
.40725 .66667 Mdot
.4088 .21593 Mdot
.40439 .50761 Mdot
.42974 .44347 Mdot
.38923 .46623 Mdot
.41562 .43584 Mdot
.78986 .56289 Mdot
.5976 .6887 Mdot
.47029 .79651 Mdot
.67596 .29512 Mdot
.39345 .61857 Mdot
.40624 .65874 Mdot
.35551 .24583 Mdot
.46556 .68391 Mdot
.59068 .66915 Mdot
.38541 .44867 Mdot
.45888 .74712 Mdot
.84249 .53054 Mdot
.76767 .7171 Mdot
.51953 .40682 Mdot
.64363 .44465 Mdot
.3468 .62533 Mdot
.68006 .50455 Mdot
.39642 .46744 Mdot
.39052 .37589 Mdot
.64403 .20181 Mdot
.53994 .64894 Mdot
.56708 .31939 Mdot
.38506 .46127 Mdot
.49149 .29043 Mdot
.65539 .499 Mdot
.68675 .46192 Mdot
.45098 .42359 Mdot
.41889 .62192 Mdot
.45575 .14899 Mdot
.57201 .63985 Mdot
.59382 .7613 Mdot
.38562 .73914 Mdot
.55803 .76537 Mdot
.57587 .64353 Mdot
.53275 .39876 Mdot
.61528 .46991 Mdot
.28208 .40051 Mdot
.39246 .61397 Mdot
.54281 .34013 Mdot
.47026 .41217 Mdot
.36946 .61075 Mdot
.62433 .46988 Mdot
.38454 .64996 Mdot
.36755 .45313 Mdot
.55873 .68599 Mdot
.64714 .49751 Mdot
.52919 .66618 Mdot
.41127 .59753 Mdot
.5647 .35788 Mdot
.50252 .5147 Mdot
.3084 .63686 Mdot
.267 .5375 Mdot
.45544 .42925 Mdot
.52753 .57244 Mdot
.39255 .41553 Mdot
.37906 .68373 Mdot
.40884 .44404 Mdot
.32077 .68627 Mdot
.64964 .50793 Mdot
.38703 .40031 Mdot
.38298 .43716 Mdot
.39001 .79067 Mdot
.44393 .43743 Mdot
.4152 .49922 Mdot
.39512 .44246 Mdot
.33876 .61543 Mdot
.43787 .3755 Mdot
.37335 .67428 Mdot
.64126 .41046 Mdot
.65388 .48156 Mdot
.56262 .30801 Mdot
.5729 .36585 Mdot
.51622 .2632 Mdot
.72778 .37121 Mdot
.7306 .65785 Mdot
.36731 .65717 Mdot
.60591 .65236 Mdot
.41039 .44006 Mdot
.68502 .25669 Mdot
.58283 .45894 Mdot
.65937 .44995 Mdot
.45362 .78814 Mdot
.41039 .52137 Mdot
.60914 .22607 Mdot
.36296 .47795 Mdot
.17223 .61248 Mdot
.35911 .50354 Mdot
.47492 .46443 Mdot
.67909 .51728 Mdot
.57847 .28613 Mdot
.44299 .40884 Mdot
.34516 .67702 Mdot
.54677 .34483 Mdot
.3622 .36422 Mdot
.69577 .44244 Mdot
.65418 .41506 Mdot
.31842 .64025 Mdot
.41201 .42272 Mdot
.64634 .49613 Mdot
.39463 .65915 Mdot
.3785 .22316 Mdot
.58186 .6335 Mdot
.54211 .69011 Mdot
.47509 .64473 Mdot
.68144 .77135 Mdot
.54894 .3592 Mdot
.2704 .40234 Mdot
.42507 .41375 Mdot
.74075 .46219 Mdot
.37599 .4007 Mdot
.82786 .55616 Mdot
.55054 .3651 Mdot
.3488 .65994 Mdot
.61089 .64955 Mdot
.39684 .66515 Mdot
.26081 .54204 Mdot
.60712 .45691 Mdot
.5391 .53073 Mdot
.66187 .49323 Mdot
.57049 .4309 Mdot
.36909 .63727 Mdot
.38465 .47531 Mdot
.16699 .36735 Mdot
.36007 .6318 Mdot
.37011 .60229 Mdot
.51016 .83615 Mdot
.65992 .81125 Mdot
.42958 .50832 Mdot
.34853 .63009 Mdot
.66276 .48821 Mdot
.55571 .34765 Mdot
.37338 .42198 Mdot
.41603 .41991 Mdot
.36997 .61136 Mdot
.69509 .48073 Mdot
.2308 .58336 Mdot
.64281 .47025 Mdot
.35975 .66567 Mdot
.64356 .47944 Mdot
.64853 .58788 Mdot
.65954 .51716 Mdot
.43703 .40177 Mdot
.40913 .44294 Mdot
.68746 .33756 Mdot
.38635 .64349 Mdot
.38489 .43187 Mdot
.362 .46594 Mdot
.38066 .6297 Mdot
.57437 .40075 Mdot
.23354 .57565 Mdot
.44938 .46653 Mdot
.43514 .42945 Mdot
.58529 .3484 Mdot
.55901 .56655 Mdot
.26079 .38957 Mdot
.3696 .45269 Mdot
.56198 .37115 Mdot
.34512 .67536 Mdot
.43495 .45876 Mdot
.83068 .49212 Mdot
.71127 .58658 Mdot
.40752 .48493 Mdot
.67738 .51382 Mdot
.35929 .47577 Mdot
.5527 .17523 Mdot
.44437 .41383 Mdot
.37468 .63983 Mdot
.39792 .64171 Mdot
.33083 .7636 Mdot
.37265 .62323 Mdot
.6714 .45985 Mdot
.57621 .64732 Mdot
.79848 .59708 Mdot
.68329 .48685 Mdot
.36084 .50012 Mdot
.35364 .79707 Mdot
.38194 .48296 Mdot
.42732 .39329 Mdot
.49199 .16281 Mdot
.67912 .50111 Mdot
.40708 .62455 Mdot
.51592 .48012 Mdot
.3381 .45957 Mdot
.55477 .66492 Mdot
.46814 .40248 Mdot
.46114 .43666 Mdot
.51002 .18172 Mdot
.78134 .53489 Mdot
.58258 .68504 Mdot
.42897 .49174 Mdot
.36967 .45394 Mdot
.64648 .4388 Mdot
.40257 .45026 Mdot
.55365 .34506 Mdot
.40388 .62558 Mdot
.66503 .5143 Mdot
.57475 .33413 Mdot
.42703 .47838 Mdot
.58277 .32386 Mdot
.63493 .49893 Mdot
.583 .68269 Mdot
.40333 .47496 Mdot
.59354 .33018 Mdot
.58157 .323 Mdot
.39041 .41821 Mdot
.38603 .65216 Mdot
.37374 .52096 Mdot
.4464 .44154 Mdot
.36792 .43393 Mdot
.38148 .60619 Mdot
.88761 .5324 Mdot
.42154 .40227 Mdot
.54505 .26934 Mdot
.38493 .59977 Mdot
.57368 .41721 Mdot
.68295 .50416 Mdot
.46042 .43252 Mdot
.58043 .68335 Mdot
.59745 .67418 Mdot
.62045 .47432 Mdot
.36081 .60536 Mdot
.64301 .33989 Mdot
.42123 .59784 Mdot
.34436 .4201 Mdot
.45069 .47624 Mdot
.27303 .6813 Mdot
.75234 .30348 Mdot
.41213 .62917 Mdot
.72695 .49507 Mdot
.47538 .5367 Mdot
.605 .66656 Mdot
.67919 .45956 Mdot
.34535 .62569 Mdot
.39745 .60541 Mdot
.37779 .66231 Mdot
.54579 .33077 Mdot
.69185 .34059 Mdot
.40897 .60413 Mdot
.41839 .63768 Mdot
.4234 .4221 Mdot
.37045 .45164 Mdot
.41725 .22066 Mdot
.34653 .29043 Mdot
.58273 .3154 Mdot
.62656 .47232 Mdot
.14118 .59368 Mdot
.55643 .67669 Mdot
.43681 .80572 Mdot
.40876 .39182 Mdot
.09461 .46928 Mdot
.38382 .4062 Mdot
.40048 .45374 Mdot
.34099 .65699 Mdot
.59182 .32248 Mdot
.56179 .32882 Mdot
.36185 .6401 Mdot
.41197 .65248 Mdot
.55359 .34364 Mdot
.65101 .75864 Mdot
.84314 .49609 Mdot
.59328 .48534 Mdot
.38583 .62859 Mdot
.3208 .60829 Mdot
.61221 .66627 Mdot
.36242 .37248 Mdot
.55752 .6811 Mdot
.65542 .49197 Mdot
.61495 .48901 Mdot
.55523 .66021 Mdot
.42524 .42755 Mdot
.63291 .50587 Mdot
.40145 .49209 Mdot
.58373 .78142 Mdot
.27177 .58239 Mdot
.65437 .31379 Mdot
.46409 .37318 Mdot
.56407 .40867 Mdot
.52318 .6492 Mdot
.43246 .46961 Mdot
.8018 .45841 Mdot
.57284 .31803 Mdot
.37894 .37106 Mdot
.55135 .66282 Mdot
.52664 .15484 Mdot
.40602 .47903 Mdot
.37607 .6416 Mdot
.59475 .66435 Mdot
.44603 .60556 Mdot
.52066 .71322 Mdot
.38851 .46445 Mdot
.1239 .43672 Mdot
.34498 .60956 Mdot
.65715 .51414 Mdot
.20811 .61464 Mdot
.41433 .6234 Mdot
.51644 .36026 Mdot
.71409 .3279 Mdot
.7376 .72695 Mdot
.40623 .6414 Mdot
.63254 .44725 Mdot
.36401 .67542 Mdot
.56177 .35797 Mdot
.33363 .6483 Mdot
.6527 .5035 Mdot
.43878 .44786 Mdot
.65639 .46946 Mdot
.55477 .31685 Mdot
.3006 .3016 Mdot
.58468 .68461 Mdot
.68992 .49456 Mdot
.565 .66352 Mdot
.44065 .31698 Mdot
.64668 .26848 Mdot
.57502 .63092 Mdot
.2092 .50101 Mdot
.45597 .47 Mdot
.41556 .62114 Mdot
.6584 .46662 Mdot
.75875 .42787 Mdot
.49969 .51436 Mdot
.38664 .61219 Mdot
.62392 .48441 Mdot
.48212 .63751 Mdot
.19326 .56193 Mdot
.40661 .50301 Mdot
.38587 .3132 Mdot
.38479 .62527 Mdot
.61836 .45743 Mdot
.31764 .25546 Mdot
.36143 .67676 Mdot
.67492 .46998 Mdot
.61218 .64686 Mdot
.58815 .64729 Mdot
.45241 .43549 Mdot
.53449 .66571 Mdot
.62234 .49582 Mdot
.54777 .71306 Mdot
.34915 .62596 Mdot
.44499 .63689 Mdot
.59537 .33075 Mdot
.65209 .47617 Mdot
.36652 .46357 Mdot
.33015 .68248 Mdot
.68947 .5831 Mdot
.24299 .60684 Mdot
.17141 .41354 Mdot
.65128 .46727 Mdot
.401 .61537 Mdot
.37747 .64303 Mdot
.39439 .50924 Mdot
.46444 .5856 Mdot
.64667 .34097 Mdot
.50389 .4649 Mdot
.49376 .49297 Mdot
.65417 .53312 Mdot
.60676 .44209 Mdot
.41845 .38352 Mdot
.41128 .42737 Mdot
.60688 .66265 Mdot
.43808 .44453 Mdot
.34337 .6483 Mdot
.453 .42659 Mdot
.56493 .64601 Mdot
.66521 .49721 Mdot
.40751 .47628 Mdot
.58537 .33498 Mdot
.61541 .66567 Mdot
.55102 .62864 Mdot
.65978 .47577 Mdot
.37188 .60907 Mdot
.5935 .38987 Mdot
.63766 .4704 Mdot
.41294 .42326 Mdot
.5648 .57284 Mdot
.36441 .4484 Mdot
.32002 .45781 Mdot
.3628 .67811 Mdot
.66752 .51179 Mdot
.33989 .64315 Mdot
.57082 .66494 Mdot
.68385 .30081 Mdot
.41874 .44349 Mdot
.6785 .47569 Mdot
.71665 .53771 Mdot
.32316 .37878 Mdot
.42171 .63487 Mdot
.67573 .71126 Mdot
.39726 .66912 Mdot
.63033 .46488 Mdot
.41796 .81355 Mdot
.54292 .35109 Mdot
.66027 .4499 Mdot
.79994 .3631 Mdot
.67452 .48757 Mdot
.44456 .42586 Mdot
.40323 .40349 Mdot
.66221 .51524 Mdot
.57899 .35921 Mdot
.41949 .19916 Mdot
.67361 .53114 Mdot
.40712 .62958 Mdot
.58416 .79178 Mdot
.22497 .32681 Mdot
.61909 .68249 Mdot
.60696 .65889 Mdot
.35371 .5006 Mdot
.44801 .48978 Mdot
.54677 .65911 Mdot
.53647 .64107 Mdot
.54098 .33428 Mdot
.65831 .462 Mdot
.32175 .66959 Mdot
.58232 .61848 Mdot
.40989 .55816 Mdot
.71801 .3632 Mdot
.41084 .50568 Mdot
.39651 .74205 Mdot
.3931 .39507 Mdot
.5228 .31091 Mdot
.56363 .646 Mdot
.35841 .44086 Mdot
.3758 .49903 Mdot
.56822 .68078 Mdot
.55385 .34844 Mdot
.52872 .6103 Mdot
.64291 .48455 Mdot
.86745 .48196 Mdot
.38924 .49414 Mdot
.44402 .42118 Mdot
.57875 .67781 Mdot
.64862 .38705 Mdot
.3973 .6207 Mdot
.38332 .67779 Mdot
.64826 .51913 Mdot
.48711 .5429 Mdot
.45892 .44346 Mdot
.43799 .4611 Mdot
.64141 .49221 Mdot
.68204 .46549 Mdot
.70968 .66042 Mdot
.40688 .40823 Mdot
.58676 .66505 Mdot
.59905 .29463 Mdot
.56124 .64821 Mdot
.36483 .4528 Mdot
.4391 .41724 Mdot
.43903 .40264 Mdot
.36663 .46224 Mdot
.5355 .647 Mdot
.36293 .42487 Mdot
.40037 .37165 Mdot
.39655 .61263 Mdot
.37831 .45745 Mdot
.49849 .48557 Mdot
.43372 .43866 Mdot
.55524 .34619 Mdot
.24726 .41147 Mdot
.40586 .47859 Mdot
.45911 .43373 Mdot
.69494 .50573 Mdot
.42242 .45309 Mdot
.55933 .67964 Mdot
.38973 .63405 Mdot
.58814 .67348 Mdot
.59605 .67617 Mdot
.62486 .51154 Mdot
.53334 .35427 Mdot
.44907 .40231 Mdot
.55451 .32158 Mdot
.35291 .48426 Mdot
.41832 .48745 Mdot
.69952 .32276 Mdot
.17962 .62734 Mdot
.27119 .32652 Mdot
.41952 .44187 Mdot
.678 .49921 Mdot
.67907 .50761 Mdot
.3608 .35796 Mdot
.40151 .50296 Mdot
.55667 .636 Mdot
.60196 .6713 Mdot
.38698 .2636 Mdot
.55335 .20843 Mdot
.55479 .34672 Mdot
.55144 .5555 Mdot
.42096 .49218 Mdot
.36126 .45152 Mdot
.37866 .48487 Mdot
.65106 .52496 Mdot
.51338 .40493 Mdot
.66932 .45406 Mdot
.50915 .77722 Mdot
.56031 .66765 Mdot
.39664 .47268 Mdot
.41679 .75945 Mdot
.35344 .64045 Mdot
.38911 .6353 Mdot
.55751 .62555 Mdot
.6589 .43242 Mdot
.38239 .23952 Mdot
.76174 .73015 Mdot
.35493 .60205 Mdot
.58293 .30785 Mdot
.43692 .46944 Mdot
.66872 .49189 Mdot
.35644 .66641 Mdot
.57966 .30743 Mdot
.39134 .47896 Mdot
.69307 .34078 Mdot
.42133 .43667 Mdot
.4457 .69718 Mdot
.3878 .65783 Mdot
.83401 .54286 Mdot
.36742 .59973 Mdot
.61681 .66392 Mdot
.55247 .65129 Mdot
.41876 .40582 Mdot
.24787 .66225 Mdot
.41304 .64315 Mdot
.58363 .57891 Mdot
.54124 .36045 Mdot
.67202 .59153 Mdot
.55654 .35602 Mdot
.6545 .51215 Mdot
.5461 .34922 Mdot
.65101 .50508 Mdot
.34744 .27734 Mdot
.35844 .59127 Mdot
.57413 .32607 Mdot
.69649 .54762 Mdot
.44094 .49701 Mdot
.58589 .31992 Mdot
.3728 .38737 Mdot
.31616 .43656 Mdot
.63926 .48904 Mdot
.55012 .36214 Mdot
.38209 .47465 Mdot
.64763 .21621 Mdot
.59473 .62992 Mdot
.55388 .64067 Mdot
.36522 .39608 Mdot
.64715 .5324 Mdot
.33827 .66512 Mdot
.81169 .5481 Mdot
.62389 .63561 Mdot
.41912 .40318 Mdot
.44694 .41241 Mdot
.40851 .6558 Mdot
.39304 .77188 Mdot
.42745 .41011 Mdot
.46041 .50721 Mdot
.40744 .40699 Mdot
.58677 .62519 Mdot
.39829 .66304 Mdot
.38228 .64005 Mdot
.62491 .49025 Mdot
.35377 .62769 Mdot
.35922 .35064 Mdot
.44408 .76246 Mdot
.42741 .52394 Mdot
.57016 .65947 Mdot
.48288 .77173 Mdot
.50644 .77905 Mdot
.76967 .33232 Mdot
.419 .6042 Mdot
.37694 .40122 Mdot
.36424 .61082 Mdot
.56158 .35197 Mdot
.37914 .65187 Mdot
.34618 .6269 Mdot
.4267 .46639 Mdot
.39077 .46291 Mdot
.66397 .50492 Mdot
.46222 .57213 Mdot
.37753 .60352 Mdot
.38186 .40853 Mdot
.45675 .48263 Mdot
.39149 .4894 Mdot
.61274 .57135 Mdot
.4113 .63724 Mdot
.57217 .82539 Mdot
.47264 .23531 Mdot
.37688 .60423 Mdot
.47073 .14521 Mdot
.71024 .54816 Mdot
.60791 .49172 Mdot
.52554 .6693 Mdot
.40074 .40778 Mdot
.68649 .48311 Mdot
.39714 .46812 Mdot
.39876 .74144 Mdot
.41925 .45998 Mdot
.55209 .34482 Mdot
.40215 .49418 Mdot
.61568 .47869 Mdot
.64393 .46884 Mdot
.43306 .4073 Mdot
.40757 .47408 Mdot
.32087 .28122 Mdot
.40716 .5808 Mdot
.39236 .63768 Mdot
.63621 .34628 Mdot
.57977 .33422 Mdot
.55353 .66187 Mdot
.40091 .44418 Mdot
.63304 .51953 Mdot
.64708 .46818 Mdot
.41357 .63335 Mdot
.62928 .48094 Mdot
.57308 .64004 Mdot
.41486 .4456 Mdot
.5467 .65545 Mdot
.54393 .33306 Mdot
.40478 .65354 Mdot
.38239 .46056 Mdot
.42385 .42234 Mdot
.39807 .64179 Mdot
.43335 .38894 Mdot
.58299 .35224 Mdot
.67446 .48348 Mdot
.40375 .64883 Mdot
.57945 .64714 Mdot
.65417 .51055 Mdot
.36695 .42989 Mdot
.13792 .53016 Mdot
.44285 .42774 Mdot
.38774 .41049 Mdot
.79476 .34296 Mdot
.41315 .49514 Mdot
.65361 .46638 Mdot
.35088 .66352 Mdot
.46869 .38067 Mdot
.50103 .25832 Mdot
.86512 .60804 Mdot
.66037 .45084 Mdot
.44079 .46586 Mdot
.7035 .26924 Mdot
.4436 .45747 Mdot
.2784 .66635 Mdot
.62908 .5392 Mdot
.55035 .44715 Mdot
.3636 .40406 Mdot
.5947 .64145 Mdot
.66747 .50538 Mdot
.64661 .50557 Mdot
.54778 .81063 Mdot
.43079 .4649 Mdot
.51227 .60377 Mdot
.38121 .46904 Mdot
.5819 .64414 Mdot
.41548 .25165 Mdot
.64469 .4673 Mdot
.19541 .40142 Mdot
.39528 .41404 Mdot
.40259 .60686 Mdot
.70062 .50729 Mdot
.63404 .59522 Mdot
.36898 .43111 Mdot
.56663 .31554 Mdot
.60432 .61923 Mdot
.48051 .42748 Mdot
.56978 .65472 Mdot
.36737 .43754 Mdot
.49577 .45246 Mdot
.20928 .62883 Mdot
.382 .65745 Mdot
.61102 .65165 Mdot
.58864 .56416 Mdot
.36512 .41629 Mdot
.40516 .6442 Mdot
.39117 .61276 Mdot
.54813 .32453 Mdot
.56292 .51995 Mdot
.49317 .68887 Mdot
.29064 .61058 Mdot
.56958 .80072 Mdot
.7003 .50116 Mdot
.75756 .57854 Mdot
.37897 .42406 Mdot
.61949 .30985 Mdot
.57052 .68401 Mdot
.44593 .43108 Mdot
.27381 .42368 Mdot
.35697 .64267 Mdot
.43499 .42396 Mdot
.55861 .33519 Mdot
.62082 .3611 Mdot
.61366 .30459 Mdot
.71994 .32317 Mdot
.66028 .4926 Mdot
.38533 .37619 Mdot
.49486 .43916 Mdot
.67837 .51585 Mdot
.46259 .43152 Mdot
.67337 .4723 Mdot
.66432 .76486 Mdot
.58702 .31751 Mdot
.41037 .62916 Mdot
.64033 .57492 Mdot
.45722 .41324 Mdot
.46019 .46801 Mdot
.53276 .34033 Mdot
.40664 .42614 Mdot
.186 .60391 Mdot
.62689 .56843 Mdot
.64152 .5117 Mdot
.37875 .66121 Mdot
.4571 .42197 Mdot
.57629 .53373 Mdot
.44555 .44646 Mdot
.31739 .54181 Mdot
.45858 .43181 Mdot
.50455 .69265 Mdot
.39014 .65163 Mdot
.56661 .65699 Mdot
.36046 .42019 Mdot
.41214 .45962 Mdot
.54582 .2433 Mdot
.35113 .49096 Mdot
.35922 .42946 Mdot
.38593 .68766 Mdot
.35692 .66907 Mdot
.37008 .67372 Mdot
.62686 .45888 Mdot
.52917 .19199 Mdot
.58034 .66696 Mdot
.44677 .3697 Mdot
.58793 .62094 Mdot
.23142 .61302 Mdot
.58281 .30878 Mdot
.72481 .30494 Mdot
.388 .43981 Mdot
.36278 .65989 Mdot
.78735 .4985 Mdot
.35526 .68358 Mdot
.53593 .5563 Mdot
.59419 .65832 Mdot
.36101 .63529 Mdot
.40442 .45736 Mdot
.48718 .52598 Mdot
.66131 .24592 Mdot
.57682 .67208 Mdot
.36469 .50407 Mdot
.63144 .45178 Mdot
.65534 .30109 Mdot
.14686 .49591 Mdot
.59448 .62932 Mdot
.56799 .69668 Mdot
.43204 .4658 Mdot
.35157 .64354 Mdot
.58921 .64001 Mdot
.57647 .62695 Mdot
.62855 .48343 Mdot
.38739 .45997 Mdot
.38374 .45558 Mdot
.63054 .4626 Mdot
.58585 .67502 Mdot
.35714 .40682 Mdot
.48017 .4556 Mdot
.61369 .17803 Mdot
.47332 .62903 Mdot
.87345 .48804 Mdot
.37369 .34806 Mdot
.2562 .43889 Mdot
.81603 .55568 Mdot
.39207 .60064 Mdot
.416 .48337 Mdot
.47595 .44352 Mdot
.62188 .49443 Mdot
.4283 .44693 Mdot
.60934 .51154 Mdot
.5989 .66516 Mdot
.51798 .15933 Mdot
.49227 .75094 Mdot
.70326 .74386 Mdot
.42887 .44875 Mdot
.31949 .68832 Mdot
.56782 .34314 Mdot
.61445 .68016 Mdot
.38182 .6739 Mdot
.37214 .47093 Mdot
.31749 .28349 Mdot
.66544 .45195 Mdot
.37274 .61544 Mdot
.37823 .22543 Mdot
.54661 .40679 Mdot
.36552 .45118 Mdot
.64033 .45135 Mdot
.80191 .48335 Mdot
.42472 .58232 Mdot
.62737 .6445 Mdot
.55237 .34849 Mdot
.66977 .50707 Mdot
.60214 .67274 Mdot
.32434 .68182 Mdot
.36685 .6288 Mdot
.3364 .66738 Mdot
.2617 .35515 Mdot
.69091 .50295 Mdot
.57005 .33881 Mdot
.5841 .22927 Mdot
.55272 .22364 Mdot
.55259 .34152 Mdot
.61392 .48495 Mdot
.35688 .66833 Mdot
.36143 .64633 Mdot
.38978 .63328 Mdot
.23721 .35171 Mdot
.38489 .59644 Mdot
.47429 .8144 Mdot
.38697 .48433 Mdot
.45765 .50582 Mdot
.44052 .46404 Mdot
.55065 .64395 Mdot
.3969 .65004 Mdot
.51268 .50035 Mdot
.35898 .48581 Mdot
.66665 .26863 Mdot
.44936 .43088 Mdot
.58071 .69262 Mdot
.42668 .41823 Mdot
.33661 .74254 Mdot
.36869 .60692 Mdot
.42303 .44375 Mdot
.58385 .68916 Mdot
.57959 .34222 Mdot
.41951 .64437 Mdot
.38894 .46583 Mdot
.70902 .68968 Mdot
.40858 .49519 Mdot
.70853 .73081 Mdot
.44777 .65066 Mdot
.58324 .30817 Mdot
.40107 .71829 Mdot
.66578 .44587 Mdot
.47192 .4914 Mdot
.33622 .43795 Mdot
.56917 .6683 Mdot
.6699 .57707 Mdot
.65607 .48261 Mdot
.5173 .40439 Mdot
.46046 .39099 Mdot
.55633 .31388 Mdot
.40438 .57381 Mdot
.54569 .65925 Mdot
.46486 .44345 Mdot
.38938 .50614 Mdot
.53597 .79425 Mdot
.4258 .37637 Mdot
.45207 .42001 Mdot
.54153 .32151 Mdot
.46802 .80699 Mdot
.43139 .4352 Mdot
.54406 .5528 Mdot
.33566 .6382 Mdot
.34253 .42871 Mdot
.45597 .8135 Mdot
.4011 .40295 Mdot
.36536 .622 Mdot
.37702 .5441 Mdot
.47794 .67248 Mdot
.53575 .3577 Mdot
.46008 .43554 Mdot
.33578 .76892 Mdot
.40231 .41586 Mdot
.58301 .66319 Mdot
.41146 .50018 Mdot
.65382 .50092 Mdot
.27248 .31735 Mdot
.62685 .4993 Mdot
.45495 .45681 Mdot
.38946 .62981 Mdot
.57003 .67618 Mdot
.21386 .39591 Mdot
.67368 .3474 Mdot
.44697 .8034 Mdot
.78429 .68319 Mdot
.55616 .36277 Mdot
.53846 .37285 Mdot
.54676 .66548 Mdot
.42405 .44228 Mdot
.46334 .83164 Mdot
.35925 .50471 Mdot
.43406 .42783 Mdot
.41848 .46123 Mdot
.63317 .26583 Mdot
.59983 .66913 Mdot
.63671 .48065 Mdot
.43281 .413 Mdot
.3614 .42677 Mdot
.39255 .60154 Mdot
.58235 .33141 Mdot
.68258 .50442 Mdot
.56787 .32112 Mdot
.66948 .5003 Mdot
.49038 .14915 Mdot
.35598 .46574 Mdot
.57616 .34606 Mdot
.58937 .6171 Mdot
.37429 .60927 Mdot
.44541 .75779 Mdot
.64986 .50964 Mdot
.62126 .47738 Mdot
.44284 .41445 Mdot
.36265 .62362 Mdot
.33975 .65141 Mdot
.5634 .35376 Mdot
.57309 .634 Mdot
.40698 .47869 Mdot
.42316 .48761 Mdot
.37018 .55814 Mdot
.64212 .52766 Mdot
.43602 .70649 Mdot
.75877 .60538 Mdot
.4217 .44076 Mdot
.34798 .62929 Mdot
.41368 .47113 Mdot
.78513 .60407 Mdot
.35257 .63584 Mdot
.39614 .40248 Mdot
.41058 .18343 Mdot
.65071 .42988 Mdot
.47229 .70406 Mdot
.43453 .40268 Mdot
.81885 .61453 Mdot
.38113 .4314 Mdot
.54739 .14588 Mdot
.74666 .44707 Mdot
.45425 .46808 Mdot
.37089 .42171 Mdot
.25253 .58512 Mdot
.43587 .47595 Mdot
.62734 .46642 Mdot
.45621 .19977 Mdot
.34411 .67745 Mdot
.61524 .73526 Mdot
.25417 .40957 Mdot
.55063 .36463 Mdot
.64895 .5192 Mdot
.6015 .45429 Mdot
.55521 .33115 Mdot
.38341 .63052 Mdot
.41536 .43579 Mdot
.50733 .53891 Mdot
.65449 .52981 Mdot
.40611 .34873 Mdot
.58432 .66123 Mdot
.70203 .61587 Mdot
.58264 .49321 Mdot
.57 .64927 Mdot
.37603 .45404 Mdot
.24423 .5837 Mdot
.30012 .34188 Mdot
.84418 .47408 Mdot
.60353 .67304 Mdot
.57511 .67323 Mdot
.2543 .32979 Mdot
.59369 .30882 Mdot
.56485 .78436 Mdot
.51225 .70207 Mdot
.55785 .66965 Mdot
.43912 .61421 Mdot
.65796 .45392 Mdot
.53031 .63373 Mdot
.39035 .36964 Mdot
.40764 .48937 Mdot
.40689 .45796 Mdot
.56678 .63688 Mdot
.32852 .37576 Mdot
.19947 .60211 Mdot
.56331 .66277 Mdot
.32963 .44927 Mdot
.54958 .48627 Mdot
.74558 .50963 Mdot
.63513 .46594 Mdot
.53523 .35343 Mdot
.56989 .37733 Mdot
.40316 .61097 Mdot
.53421 .35386 Mdot
.62359 .34829 Mdot
.40269 .43151 Mdot
.55908 .65499 Mdot
.6825 .58506 Mdot
.5843 .64939 Mdot
.55828 .32914 Mdot
.57033 .30332 Mdot
.39673 .61322 Mdot
.38811 .64339 Mdot
.24357 .47457 Mdot
.41829 .2768 Mdot
.4488 .44213 Mdot
.76271 .39916 Mdot
.34348 .63486 Mdot
.41545 .34779 Mdot
.53326 .35027 Mdot
.5807 .33699 Mdot
.55067 .25171 Mdot
.39036 .44488 Mdot
.29686 .69734 Mdot
.39461 .44519 Mdot
.41644 .25729 Mdot
.40636 .39322 Mdot
.6286 .48229 Mdot
.38465 .44672 Mdot
.56909 .24913 Mdot
.46053 .41035 Mdot
.43983 .49513 Mdot
.64357 .52423 Mdot
.47904 .41457 Mdot
.65275 .49888 Mdot
.45356 .45216 Mdot
.58694 .35656 Mdot
.6359 .51484 Mdot
.49522 .27683 Mdot
.55871 .25917 Mdot
.61286 .47776 Mdot
.55774 .31609 Mdot
.56491 .36788 Mdot
.50486 .30176 Mdot
.38175 .67414 Mdot
.33291 .42318 Mdot
.42697 .44341 Mdot
.68541 .46542 Mdot
.60369 .66494 Mdot
.37266 .41493 Mdot
.45807 .47911 Mdot
.41124 .39701 Mdot
.40407 .61107 Mdot
.64973 .33701 Mdot
.57059 .35184 Mdot
.63493 .45737 Mdot
.5929 .39465 Mdot
.64629 .53402 Mdot
.41107 .50263 Mdot
.47387 .43134 Mdot
.26486 .4152 Mdot
.74376 .54033 Mdot
.23565 .34114 Mdot
.3678 .6264 Mdot
.6772 .51313 Mdot
.59365 .34208 Mdot
.47069 .47552 Mdot
.35961 .66095 Mdot
.65263 .50285 Mdot
.42056 .43713 Mdot
.37036 .51025 Mdot
.47271 .78427 Mdot
.37457 .33488 Mdot
.53014 .26934 Mdot
.61985 .47456 Mdot
.65117 .44367 Mdot
.59215 .25776 Mdot
.53424 .3174 Mdot
.50261 .51189 Mdot
.43614 .45542 Mdot
.56509 .31678 Mdot
.35601 .6655 Mdot
.27237 .3541 Mdot
.55915 .63988 Mdot
.46266 .57863 Mdot
.42698 .44852 Mdot
.55786 .42441 Mdot
.3909 .62756 Mdot
.55747 .33849 Mdot
.56477 .63836 Mdot
.53368 .37545 Mdot
.66267 .52297 Mdot
.70545 .76349 Mdot
.40502 .41908 Mdot
.44856 .42008 Mdot
.60802 .67699 Mdot
.35499 .65197 Mdot
.53009 .35268 Mdot
.59422 .78452 Mdot
.638 .50136 Mdot
.44181 .82704 Mdot
.34719 .63624 Mdot
.33719 .59696 Mdot
.64351 .4564 Mdot
.5628 .62459 Mdot
.49372 .29592 Mdot
.5687 .644 Mdot
.45694 .44617 Mdot
.37122 .65267 Mdot
.60843 .64855 Mdot
.45678 .58745 Mdot
.69073 .25649 Mdot
.32519 .60721 Mdot
.40374 .43692 Mdot
.60759 .19664 Mdot
.6995 .72092 Mdot
.40102 .57871 Mdot
.58471 .68366 Mdot
.44807 .43221 Mdot
.4623 .45713 Mdot
.40519 .4152 Mdot
.6033 .65315 Mdot
.74423 .37811 Mdot
.63904 .49211 Mdot
.4361 .46559 Mdot
.54191 .33279 Mdot
.65282 .49159 Mdot
.63756 .57822 Mdot
.63616 .46769 Mdot
.41423 .59725 Mdot
.41929 .50017 Mdot
.62746 .61285 Mdot
.46959 .12652 Mdot
.58407 .67305 Mdot
.61576 .49727 Mdot
.36364 .4745 Mdot
.7108 .57485 Mdot
.36624 .67188 Mdot
.63594 .50066 Mdot
.44471 .42224 Mdot
.64432 .57107 Mdot
.28909 .31184 Mdot
.63913 .46729 Mdot
.35746 .66152 Mdot
.83326 .45802 Mdot
.43458 .4457 Mdot
.38627 .42606 Mdot
.36439 .63741 Mdot
.20244 .52919 Mdot
.33245 .24714 Mdot
.40973 .47309 Mdot
.56549 .65608 Mdot
.59507 .83995 Mdot
.45165 .48855 Mdot
.46319 .22869 Mdot
.66535 .50632 Mdot
.55166 .60489 Mdot
.46296 .66644 Mdot
.46903 .47743 Mdot
.58229 .78018 Mdot
.55377 .69321 Mdot
.60488 .21311 Mdot
.61314 .51703 Mdot
.71151 .43838 Mdot
.56271 .18141 Mdot
.57233 .68951 Mdot
.37527 .57163 Mdot
.60533 .76166 Mdot
.17838 .47109 Mdot
.82435 .47941 Mdot
.67551 .40967 Mdot
.31853 .28067 Mdot
.52084 .51766 Mdot
.67507 .49592 Mdot
.56832 .39173 Mdot
.39523 .46864 Mdot
.70526 .71662 Mdot
.30628 .71453 Mdot
.25663 .68237 Mdot
.6115 .19736 Mdot
.27688 .6498 Mdot
.68869 .26224 Mdot
.77811 .33609 Mdot
.30539 .37745 Mdot
.75911 .52875 Mdot
.44254 .83086 Mdot
.45146 .18207 Mdot
.58939 .8052 Mdot
.42504 .52689 Mdot
.52509 .5693 Mdot
.75238 .70221 Mdot
.31667 .65775 Mdot
.20057 .58568 Mdot
.62733 .49443 Mdot
.36333 .67973 Mdot
.60123 .75685 Mdot
.3988 .6685 Mdot
.47332 .66599 Mdot
.83838 .45387 Mdot
.70467 .26398 Mdot
.36116 .76892 Mdot
.82483 .57533 Mdot
.27201 .43576 Mdot
.31489 .79665 Mdot
.66503 .53223 Mdot
.4123 .61786 Mdot
.5491 .28427 Mdot
.57827 .24133 Mdot
.53443 .76954 Mdot
.63868 .75277 Mdot
.68443 .3168 Mdot
.4358 .30307 Mdot
.37769 .64003 Mdot
.42094 .70445 Mdot
.5712 .59051 Mdot
.49504 .75621 Mdot
.44322 .19879 Mdot
.7975 .39494 Mdot
.50073 .55227 Mdot
.65549 .72509 Mdot
.72524 .60239 Mdot
.15235 .48271 Mdot
.488 .23829 Mdot
.46047 .35904 Mdot
.48141 .65046 Mdot
.8084 .56987 Mdot
.19013 .4813 Mdot
.39302 .27705 Mdot
.57156 .23617 Mdot
.45369 .16764 Mdot
.76978 .64815 Mdot
.30039 .22938 Mdot
.35261 .68837 Mdot
.44917 .41425 Mdot
.21459 .51566 Mdot
.34703 .77829 Mdot
.57492 .30039 Mdot
.73711 .34602 Mdot
.54122 .35666 Mdot
.38738 .5907 Mdot
.29951 .28954 Mdot
.45597 .81055 Mdot
.35557 .79056 Mdot
.56339 .37617 Mdot
.46938 .37832 Mdot
.75318 .77101 Mdot
.63796 .24298 Mdot
.46944 .73223 Mdot
.59659 .16902 Mdot
.5408 .44391 Mdot
.44511 .62146 Mdot
.60765 .65142 Mdot
.55545 .17147 Mdot
.36479 .64896 Mdot
.32582 .19721 Mdot
.53922 .14604 Mdot
.27286 .38114 Mdot
.89224 .38881 Mdot
.60349 .26143 Mdot
.55109 .44207 Mdot
.58289 .71585 Mdot
.47504 .26352 Mdot
.18049 .55904 Mdot
.47475 .3487 Mdot
.71516 .58045 Mdot
.80905 .65712 Mdot
.59417 .19868 Mdot
.38388 .80447 Mdot
.66558 .78265 Mdot
.17604 .49437 Mdot
.57651 .54188 Mdot
.38246 .36559 Mdot
.5892 .50939 Mdot
.78856 .40262 Mdot
.46579 .15455 Mdot
.47803 .23278 Mdot
.8617 .61953 Mdot
.5341 .32521 Mdot
.71933 .37863 Mdot
.84341 .42928 Mdot
.45531 .30741 Mdot
.44515 .67336 Mdot
.4857 .20729 Mdot
.46874 .37136 Mdot
.60575 .37637 Mdot
.75889 .3686 Mdot
.44322 .72258 Mdot
.4758 .19374 Mdot
.81056 .50922 Mdot
.53218 .79414 Mdot
.28053 .58218 Mdot
.53551 .20992 Mdot
.36994 .68952 Mdot
.41264 .29246 Mdot
.45925 .65475 Mdot
.69426 .25006 Mdot
.54616 .67911 Mdot
.72624 .25978 Mdot
.33574 .24808 Mdot
.34826 .4389 Mdot
.34631 .49199 Mdot
.36555 .69975 Mdot
.42815 .28307 Mdot
.48194 .41579 Mdot
.49753 .785 Mdot
.74868 .29569 Mdot
.29042 .41842 Mdot
.53672 .60426 Mdot
.66904 .57419 Mdot
.84885 .44494 Mdot
.22925 .51614 Mdot
.53159 .31972 Mdot
.41168 .23152 Mdot
.1584 .5051 Mdot
.65012 .48082 Mdot
.39306 .80495 Mdot
.6277 .63835 Mdot
.28156 .32955 Mdot
.28965 .61546 Mdot
.22748 .43256 Mdot
.74976 .29645 Mdot
.64904 .41144 Mdot
.31828 .26883 Mdot
.45205 .32293 Mdot
.5192 .83848 Mdot
.74534 .51291 Mdot
.46927 .40503 Mdot
.65926 .73328 Mdot
.58005 .35868 Mdot
.25424 .5285 Mdot
.5823 .83056 Mdot
.67178 .38557 Mdot
.41033 .37861 Mdot
.27195 .37307 Mdot
.65837 .42745 Mdot
.48344 .53204 Mdot
.19782 .35025 Mdot
.42236 .50366 Mdot
.57413 .22412 Mdot
.75711 .66526 Mdot
.45528 .25906 Mdot
.84016 .51631 Mdot
.79193 .57575 Mdot
.33856 .20026 Mdot
.58749 .17395 Mdot
.66316 .34701 Mdot
.55788 .18497 Mdot
.65882 .2147 Mdot
.32755 .2138 Mdot
.33539 .45891 Mdot
.61493 .67042 Mdot
.12451 .51228 Mdot
.63812 .46261 Mdot
.609 .23955 Mdot
.56861 .8014 Mdot
.60118 .54488 Mdot
.32431 .6958 Mdot
.48602 .37394 Mdot
.51975 .52731 Mdot
.4 .58041 Mdot
.47927 .40951 Mdot
.23956 .31164 Mdot
.38561 .17883 Mdot
.27839 .26048 Mdot
.79201 .64178 Mdot
.53636 .17283 Mdot
.55991 .44701 Mdot
.37556 .77584 Mdot
.36584 .35767 Mdot
.38837 .48124 Mdot
.51692 .34957 Mdot
.60515 .26255 Mdot
.26059 .38037 Mdot
.53079 .74997 Mdot
.40028 .57034 Mdot
.74796 .35777 Mdot
.43436 .90057 Mdot
.25766 .47191 Mdot
.48685 .82265 Mdot
.60469 .28 Mdot
.42819 .27181 Mdot
.78204 .40472 Mdot
.24593 .40526 Mdot
.79002 .34265 Mdot
.39137 .58233 Mdot
.5874 .80148 Mdot
.69451 .4091 Mdot
.457 .53379 Mdot
.65351 .33311 Mdot
.72084 .2845 Mdot
.64131 .69432 Mdot
.22749 .39891 Mdot
.54217 .72816 Mdot
.20593 .50065 Mdot
.68222 .54914 Mdot
.70848 .62096 Mdot
.56393 .83084 Mdot
.77859 .5577 Mdot
.43415 .24456 Mdot
.54749 .50089 Mdot
.38299 .72971 Mdot
.55418 .69516 Mdot
.44031 .24463 Mdot
.50358 .47392 Mdot
.55472 .19653 Mdot
.42051 .10772 Mdot
.19751 .37978 Mdot
.86307 .49203 Mdot
.77099 .40362 Mdot
.43054 .38351 Mdot
.81502 .37325 Mdot
.26595 .26104 Mdot
.50523 .12501 Mdot
.68886 .65453 Mdot
.62424 .52883 Mdot
.57269 .62259 Mdot
.2618 .29689 Mdot
.73667 .37228 Mdot
.80818 .38505 Mdot
.50799 .21573 Mdot
.55373 .62505 Mdot
.18671 .6418 Mdot
.45201 .17221 Mdot
.30282 .61641 Mdot
.37153 .33569 Mdot
.39532 .38699 Mdot
.3225 .72431 Mdot
.40272 .66332 Mdot
.75079 .58832 Mdot
.40765 .28112 Mdot
.65123 .47352 Mdot
.53519 .29872 Mdot
.65062 .74659 Mdot
.40222 .49396 Mdot
.58444 .55947 Mdot
.42079 .62304 Mdot
.74753 .53916 Mdot
.46438 .76615 Mdot
.4526 .14841 Mdot
.63109 .28747 Mdot
.36059 .40887 Mdot
.45763 .25416 Mdot
.64866 .32705 Mdot
.31807 .25468 Mdot
.54377 .66132 Mdot
.63335 .21035 Mdot
.50466 .57431 Mdot
.4112 .29073 Mdot
.31355 .71313 Mdot
.3185 .43828 Mdot
.45592 .47482 Mdot
.7945 .54576 Mdot
.30895 .5198 Mdot
.46544 .56028 Mdot
.40754 .3661 Mdot
.34212 .383 Mdot
.82135 .3832 Mdot
.61833 .36681 Mdot
.71075 .60636 Mdot
.65913 .22542 Mdot
.59727 .65008 Mdot
.36175 .6137 Mdot
.58159 .37658 Mdot
.61727 .78033 Mdot
.32333 .51772 Mdot
.28759 .31328 Mdot
.59123 .52543 Mdot
.68252 .3807 Mdot
.67005 .23685 Mdot
.63007 .2145 Mdot
.2929 .72691 Mdot
.40857 .57788 Mdot
.31406 .37452 Mdot
.60561 .79274 Mdot
.3522 .67033 Mdot
.50015 .79891 Mdot
.48543 .79435 Mdot
.49432 .15975 Mdot
.57877 .56916 Mdot
.81455 .64457 Mdot
.52297 .2709 Mdot
.72847 .34397 Mdot
.21199 .39581 Mdot
.54963 .8307 Mdot
.69905 .27673 Mdot
.43363 .60487 Mdot
.25915 .60816 Mdot
.4376 .51879 Mdot
.38884 .75125 Mdot
.14618 .55862 Mdot
.60098 .34867 Mdot
.32797 .61262 Mdot
.81321 .50773 Mdot
.41383 .42848 Mdot
.18058 .39964 Mdot
.62749 .76614 Mdot
.24774 .33477 Mdot
.56519 .62083 Mdot
.37101 .45494 Mdot
.46417 .42273 Mdot
.44908 .22075 Mdot
.47619 .67668 Mdot
.54054 .19423 Mdot
.61442 .82441 Mdot
.80775 .47233 Mdot
.30517 .71073 Mdot
.59319 .23828 Mdot
.80451 .40153 Mdot
.71378 .70891 Mdot
.55726 .52731 Mdot
.61218 .27143 Mdot
.47076 .30368 Mdot
.81899 .58479 Mdot
.50468 .47994 Mdot
.53246 .69351 Mdot
.54002 .77708 Mdot
.76377 .60439 Mdot
.24722 .37057 Mdot
.37104 .4388 Mdot
.37866 .22525 Mdot
.78956 .3568 Mdot
.29818 .72314 Mdot
.17163 .56184 Mdot
.2016 .36856 Mdot
.31262 .56173 Mdot
.77509 .59066 Mdot
.68843 .72476 Mdot
.52183 .852 Mdot
.50157 .5813 Mdot
.68348 .28028 Mdot
.46369 .31427 Mdot
.66623 .23247 Mdot
.60775 .67934 Mdot
.52341 .72145 Mdot
.6732 .5722 Mdot
.55234 .18859 Mdot
.23556 .5398 Mdot
.74474 .30366 Mdot
.53691 .46595 Mdot
.34924 .1904 Mdot
.77822 .53926 Mdot
.5287 .50149 Mdot
.66779 .5182 Mdot
.63709 .40661 Mdot
.74762 .33946 Mdot
.76678 .49767 Mdot
.53508 .8295 Mdot
.60627 .47281 Mdot
.57163 .38513 Mdot
.29689 .64468 Mdot
.39426 .30921 Mdot
.79598 .55245 Mdot
.45763 .25454 Mdot
.72804 .27969 Mdot
.46748 .20634 Mdot
.37299 .23077 Mdot
.61565 .25931 Mdot
.76957 .71152 Mdot
.46861 .72736 Mdot
.6169 .33487 Mdot
.63678 .75912 Mdot
.73439 .39704 Mdot
.43885 .62959 Mdot
.11861 .35879 Mdot
.71411 .75139 Mdot
.76942 .53135 Mdot
.4666 .15489 Mdot
.79572 .59025 Mdot
.7436 .54446 Mdot
.18639 .53109 Mdot
.47606 .62608 Mdot
.35045 .2654 Mdot
.41781 .46046 Mdot
.23744 .30494 Mdot
.39194 .29948 Mdot
.43298 .15353 Mdot
.81795 .39692 Mdot
.31219 .69078 Mdot
.42282 .49816 Mdot
.63628 .45491 Mdot
.50669 .61837 Mdot
.35172 .30795 Mdot
.22523 .56673 Mdot
.42641 .68594 Mdot
.65922 .56515 Mdot
.68362 .51157 Mdot
.64048 .32979 Mdot
.35526 .6024 Mdot
.73104 .35843 Mdot
.76206 .60001 Mdot
.69667 .46601 Mdot
.49221 .56322 Mdot
.43701 .25377 Mdot
.45758 .67261 Mdot
.3069 .61176 Mdot
.24767 .39936 Mdot
.63523 .62703 Mdot
.62903 .46987 Mdot
.29751 .60303 Mdot
.74811 .71045 Mdot
.80289 .48909 Mdot
.45285 .16519 Mdot
.59639 .40118 Mdot
.24016 .60816 Mdot
.44167 .23841 Mdot
.18519 .57756 Mdot
.23054 .63383 Mdot
.73937 .5273 Mdot
.34571 .72464 Mdot
.19999 .57209 Mdot
.62218 .7428 Mdot
.51929 .15823 Mdot
.58869 .80444 Mdot
.60261 .79622 Mdot
.65564 .55511 Mdot
.35634 .55372 Mdot
.30546 .6763 Mdot
.50287 .27648 Mdot
.49375 .52335 Mdot
.28465 .76942 Mdot
.38108 .36978 Mdot
.19347 .70238 Mdot
.59046 .6266 Mdot
.16922 .51741 Mdot
.47672 .30869 Mdot
.55218 .4964 Mdot
.5294 .4554 Mdot
.7822 .56392 Mdot
.50514 .69703 Mdot
.76075 .67029 Mdot
.23434 .65557 Mdot
.65674 .53577 Mdot
.62943 .82235 Mdot
.77651 .70822 Mdot
.2675 .59464 Mdot
.38901 .49668 Mdot
.73706 .73316 Mdot
.63651 .53652 Mdot
.25571 .38438 Mdot
.84292 .51062 Mdot
.77919 .47403 Mdot
.3974 .55735 Mdot
.42495 .27698 Mdot
.68503 .27951 Mdot
.62422 .19647 Mdot
.18763 .62626 Mdot
.76035 .3726 Mdot
.60982 .6768 Mdot
.54224 .47217 Mdot
.75455 .32613 Mdot
.44855 .60433 Mdot
.52827 .63469 Mdot
.44433 .66679 Mdot
.27035 .77918 Mdot
.61359 .23841 Mdot
.54545 .19774 Mdot
.44518 .65416 Mdot
.36375 .60317 Mdot
.48167 .66337 Mdot
.44592 .67365 Mdot
.77874 .48913 Mdot
.71702 .7282 Mdot
.45332 .66385 Mdot
.43539 .84885 Mdot
.31524 .43133 Mdot
.64346 .41997 Mdot
.30175 .68327 Mdot
.29837 .40634 Mdot
.55133 .62453 Mdot
.40233 .22166 Mdot
.81841 .47841 Mdot
.62227 .64797 Mdot
.80022 .54372 Mdot
.65974 .72261 Mdot
.36285 .57435 Mdot
.332 .53926 Mdot
.79544 .46161 Mdot
.23774 .56992 Mdot
.35603 .74814 Mdot
.28149 .34605 Mdot
.62019 .50946 Mdot
.8244 .46533 Mdot
.64565 .51198 Mdot
.45396 .35812 Mdot
.46063 .58251 Mdot
.46798 .3465 Mdot
.24261 .33039 Mdot
.56043 .36458 Mdot
.40767 .65243 Mdot
.15712 .57727 Mdot
.34491 .65202 Mdot
.2518 .29594 Mdot
.23099 .42691 Mdot
.31634 .72052 Mdot
.66368 .35422 Mdot
.65072 .38111 Mdot
.35111 .81696 Mdot
.61249 .58373 Mdot
.59792 .52929 Mdot
.4183 .76872 Mdot
.41393 .6277 Mdot
.63355 .285 Mdot
.63659 .51952 Mdot
.48766 .6046 Mdot
.64688 .6882 Mdot
.33599 .49533 Mdot
.32047 .67264 Mdot
.48734 .58461 Mdot
.37549 .25875 Mdot
.51899 .16999 Mdot
.67792 .47773 Mdot
.20479 .70189 Mdot
.44026 .48964 Mdot
.27723 .57301 Mdot
.78882 .33777 Mdot
.19323 .65038 Mdot
.58831 .4733 Mdot
.78465 .7037 Mdot
.37455 .40076 Mdot
.78546 .42368 Mdot
.37121 .64317 Mdot
.59399 .79739 Mdot
.54697 .35644 Mdot
.46104 .26103 Mdot
.5906 .62385 Mdot
.22515 .40027 Mdot
.59288 .44199 Mdot
.33679 .66519 Mdot
.77275 .44005 Mdot
.30328 .38535 Mdot
.51283 .68538 Mdot
.63752 .3622 Mdot
.2709 .59989 Mdot
.33218 .53229 Mdot
.34965 .60011 Mdot
.56027 .20491 Mdot
.60867 .80131 Mdot
.46472 .13951 Mdot
.39775 .68101 Mdot
.55491 .40982 Mdot
.5217 .7879 Mdot
.79809 .51455 Mdot
.4081 .74702 Mdot
.76802 .31251 Mdot
.39392 .28366 Mdot
.35814 .53515 Mdot
.42104 .25655 Mdot
.39436 .52495 Mdot
.53293 .53761 Mdot
.732 .60956 Mdot
.25404 .6836 Mdot
.4446 .69918 Mdot
.1846 .50426 Mdot
.37603 .74351 Mdot
.54249 .20443 Mdot
.34554 .7209 Mdot
.6591 .43607 Mdot
.35334 .57595 Mdot
.62337 .67858 Mdot
.53379 .16282 Mdot
.77455 .31997 Mdot
.59363 .69432 Mdot
.66383 .3108 Mdot
.82484 .54417 Mdot
.39708 .51617 Mdot
.5725 .42448 Mdot
.45416 .42624 Mdot
.34659 .36021 Mdot
.20517 .67529 Mdot
.78664 .49658 Mdot
.39546 .37499 Mdot
.59721 .20579 Mdot
.57739 .18579 Mdot
.38897 .16795 Mdot
.47154 .83535 Mdot
.40199 .61779 Mdot
.3201 .22735 Mdot
.42006 .69212 Mdot
.64276 .20243 Mdot
.74974 .51682 Mdot
.8167 .35386 Mdot
.25692 .60131 Mdot
.81043 .54091 Mdot
.18902 .549 Mdot
.49403 .67036 Mdot
.76241 .64675 Mdot
.5641 .46505 Mdot
.69572 .60254 Mdot
.78522 .61498 Mdot
.56581 .86441 Mdot
.47342 .47499 Mdot
.68875 .70713 Mdot
.59097 .74942 Mdot
.82318 .45624 Mdot
.74432 .46237 Mdot
.40786 .49962 Mdot
.67397 .58312 Mdot
.23832 .35911 Mdot
.45149 .24557 Mdot
.57546 .38705 Mdot
.74442 .46557 Mdot
.31589 .30613 Mdot
.40547 .25987 Mdot
.59245 .80561 Mdot
.2665 .60404 Mdot
.50749 .5981 Mdot
.36631 .41472 Mdot
.32323 .65823 Mdot
.54382 .36829 Mdot
.56883 .4886 Mdot
.4526 .44859 Mdot
.68366 .45934 Mdot
.50684 .67762 Mdot
.22444 .34124 Mdot
.45019 .71812 Mdot
.66115 .75411 Mdot
.33005 .68957 Mdot
.60569 .73346 Mdot
.42053 .75573 Mdot
.19106 .40996 Mdot
.72443 .42074 Mdot
.4784 .23287 Mdot
.64298 .24026 Mdot
.48163 .19612 Mdot
.34567 .59806 Mdot
.39988 .1872 Mdot
.57447 .68461 Mdot
.39321 .55706 Mdot
.5661 .74924 Mdot
.6331 .31916 Mdot
.40898 .3691 Mdot
.80962 .53999 Mdot
.58896 .51281 Mdot
.57604 .2454 Mdot
.76999 .65297 Mdot
.31473 .38724 Mdot
.28563 .6368 Mdot
.62013 .20862 Mdot
.66075 .45128 Mdot
.6419 .78317 Mdot
.54402 .71352 Mdot
.71328 .43339 Mdot
.51059 .1819 Mdot
.47883 .15097 Mdot
.52144 .48474 Mdot
.46256 .29378 Mdot
.38803 .41881 Mdot
.5712 .82534 Mdot
.79128 .50982 Mdot
.49393 .38823 Mdot
.68501 .64413 Mdot
.35427 .62337 Mdot
.7146 .64217 Mdot
.52068 .57675 Mdot
.33968 .28147 Mdot
.41834 .64168 Mdot
.30708 .72096 Mdot
.58059 .3634 Mdot
.5434 .42141 Mdot
.47534 .39384 Mdot
.47 .28022 Mdot
.38437 .81087 Mdot
.44014 .37054 Mdot
.77054 .38054 Mdot
.28516 .60789 Mdot
.59374 .78652 Mdot
.79028 .45678 Mdot
.73023 .53617 Mdot
.50162 .69094 Mdot
.35002 .56923 Mdot
.64426 .64419 Mdot
.42068 .39935 Mdot
.64456 .43342 Mdot
.34602 .67415 Mdot
.83412 .47756 Mdot
.31575 .54946 Mdot
.49336 .27916 Mdot
.61173 .57148 Mdot
.44701 .35398 Mdot
.60425 .70923 Mdot
.80739 .34721 Mdot
.49232 .67344 Mdot
.40396 .27971 Mdot
.57911 .56857 Mdot
.47858 .30456 Mdot
.22125 .44627 Mdot
.53199 .14473 Mdot
.18618 .54223 Mdot
.49842 .54177 Mdot
.17371 .53104 Mdot
.77601 .56521 Mdot
.83908 .52579 Mdot
.40005 .27123 Mdot
.53379 .4279 Mdot
.5523 .30842 Mdot
.46059 .7849 Mdot
.60998 .57397 Mdot
.59238 .37934 Mdot
.49106 .61042 Mdot
.66184 .65453 Mdot
.58698 .60312 Mdot
.49199 .39155 Mdot
.6217 .25478 Mdot
.63266 .22673 Mdot
.57905 .79604 Mdot
.56145 .6985 Mdot
.71249 .44439 Mdot
.33971 .28999 Mdot
.83847 .37408 Mdot
.14026 .51977 Mdot
.39047 .41806 Mdot
.60389 .70102 Mdot
.44828 .29178 Mdot
.61701 .47834 Mdot
.44208 .6893 Mdot
.4294 .75127 Mdot
.61136 .64117 Mdot
.58535 .37638 Mdot
.55903 .23423 Mdot
.76729 .58276 Mdot
.39781 .31416 Mdot
.64495 .57538 Mdot
.21418 .35076 Mdot
.77652 .68181 Mdot
.796 .50738 Mdot
.80619 .31307 Mdot
.53649 .70247 Mdot
.32963 .4182 Mdot
.22656 .48691 Mdot
.5225 .17396 Mdot
.46938 .24924 Mdot
.27116 .34613 Mdot
.7097 .55303 Mdot
.39366 .27827 Mdot
.43222 .66056 Mdot
.60351 .24759 Mdot
.70887 .64433 Mdot
.5331 .52094 Mdot
.65423 .38451 Mdot
.42328 .17049 Mdot
.28503 .65739 Mdot
.66322 .25018 Mdot
.22323 .37708 Mdot
.49686 .85796 Mdot
.54689 .16511 Mdot
.55606 .26126 Mdot
.73794 .44271 Mdot
.21665 .51413 Mdot
.49918 .48523 Mdot
.43857 .6085 Mdot
.25765 .38058 Mdot
.31104 .49321 Mdot
.69258 .342 Mdot
.18613 .46748 Mdot
.43498 .24426 Mdot
.29405 .41989 Mdot
.53285 .43181 Mdot
.30709 .60364 Mdot
.66095 .31269 Mdot
.44958 .63072 Mdot
.48492 .51217 Mdot
.50433 .25343 Mdot
.29093 .60314 Mdot
.54139 .78843 Mdot
.79152 .58518 Mdot
.46887 .86678 Mdot
.75977 .4038 Mdot
.18559 .42464 Mdot
.38677 .48523 Mdot
.41791 .13943 Mdot
.76896 .61732 Mdot
.7542 .50045 Mdot
.73492 .70411 Mdot
.67606 .43071 Mdot
.3238 .44329 Mdot
.41986 .39918 Mdot
.74295 .33868 Mdot
.32736 .6121 Mdot
.26952 .4245 Mdot
.21525 .4071 Mdot
.44399 .26663 Mdot
.50766 .21884 Mdot
.51121 .27514 Mdot
.38193 .54609 Mdot
.34824 .64819 Mdot
.28639 .25275 Mdot
.50903 .51397 Mdot
.4743 .37642 Mdot
.48833 .46816 Mdot
.20523 .50409 Mdot
.82047 .65085 Mdot
.3622 .69911 Mdot
.50325 .20199 Mdot
.2699 .6383 Mdot
.42367 .54946 Mdot
.40095 .73774 Mdot
.80256 .26727 Mdot
.47383 .10991 Mdot
.34018 .67373 Mdot
.46963 .82003 Mdot
.27363 .64488 Mdot
.54974 .19255 Mdot
.69916 .4089 Mdot
.66647 .67213 Mdot
.50122 .42764 Mdot
.44982 .55058 Mdot
.46951 .39297 Mdot
.74441 .68228 Mdot
.54687 .15408 Mdot
.20203 .42807 Mdot
.59999 .20709 Mdot
.37048 .52248 Mdot
.45744 .38143 Mdot
.85616 .378 Mdot
.74624 .31533 Mdot
.39948 .50879 Mdot
.19657 .58417 Mdot
.38501 .36559 Mdot
.39901 .46748 Mdot
.69483 .30938 Mdot
.63044 .8208 Mdot
.43678 .24035 Mdot
.55226 .18896 Mdot
.41008 .65617 Mdot
.61958 .43343 Mdot
.59163 .62627 Mdot
.52339 .47417 Mdot
.361 .49614 Mdot
.60553 .64603 Mdot
.34379 .33757 Mdot
.81772 .52502 Mdot
.52954 .60068 Mdot
.6327 .80574 Mdot
.7482 .27289 Mdot
.31892 .56746 Mdot
.45772 .77999 Mdot
.45163 .4923 Mdot
.29745 .41554 Mdot
.33795 .30863 Mdot
.34797 .36605 Mdot
.80602 .58162 Mdot
.19317 .28649 Mdot
.677 .60548 Mdot
.3735 .2457 Mdot
.37089 .59443 Mdot
.49844 .61474 Mdot
.30734 .62889 Mdot
.72058 .45894 Mdot
.68288 .49339 Mdot
.37796 .52733 Mdot
.41333 .66058 Mdot
.60412 .62004 Mdot
.17116 .66044 Mdot
.37991 .48971 Mdot
.42464 .71486 Mdot
.64632 .2063 Mdot
.28107 .34604 Mdot
.25765 .55823 Mdot
.42162 .39257 Mdot
.49786 .76113 Mdot
.53471 .4251 Mdot
.8053 .43261 Mdot
.38124 .22704 Mdot
.61169 .22334 Mdot
.31614 .54485 Mdot
.28178 .63775 Mdot
.36209 .42439 Mdot
.58876 .3029 Mdot
.54503 .60969 Mdot
.72202 .32924 Mdot
.33997 .4275 Mdot
.60562 .18128 Mdot
.60985 .41913 Mdot
.57412 .48431 Mdot
.40028 .68415 Mdot
.37458 .17865 Mdot
.20127 .47316 Mdot
.30919 .65501 Mdot
.19633 .39581 Mdot
.62901 .35727 Mdot
.39754 .30882 Mdot
.64459 .45134 Mdot
.33655 .45304 Mdot
.38324 .68474 Mdot
.18592 .38111 Mdot
.68216 .29316 Mdot
.69366 .59155 Mdot
.70542 .62131 Mdot
.51978 .81903 Mdot
.5248 .70077 Mdot
.78299 .2877 Mdot
.63336 .37454 Mdot
.19572 .37232 Mdot
.61666 .79637 Mdot
.36281 .69355 Mdot
.79082 .56474 Mdot
.3736 .37599 Mdot
.66358 .46963 Mdot
.59737 .21273 Mdot
.42753 .35367 Mdot
.30156 .29016 Mdot
.43921 .39039 Mdot
.26747 .31213 Mdot
.60248 .29828 Mdot
.65531 .29624 Mdot
.77088 .54462 Mdot
.20352 .49569 Mdot
.83621 .4311 Mdot
.46368 .78708 Mdot
.8302 .38797 Mdot
.8363 .44888 Mdot
.6278 .20675 Mdot
.27006 .33166 Mdot
.2117 .66124 Mdot
.76104 .50846 Mdot
.79581 .46972 Mdot
.74607 .6049 Mdot
.20568 .52531 Mdot
.64505 .40794 Mdot
.37306 .69986 Mdot
.47791 .68126 Mdot
.61161 .68565 Mdot
.08167 .51023 Mdot
.52957 .2297 Mdot
.37533 .69286 Mdot
.63265 .3952 Mdot
.59365 .18962 Mdot
.21225 .50242 Mdot
.78117 .6279 Mdot
.52426 .56854 Mdot
.47185 .40985 Mdot
.32338 .52844 Mdot
.55582 .81165 Mdot
.616 .40591 Mdot
.38367 .84679 Mdot
.7591 .69732 Mdot
.67979 .62894 Mdot
.52344 .54734 Mdot
.36216 .68088 Mdot
.37635 .75595 Mdot
.65821 .37335 Mdot
.80303 .5974 Mdot
.81359 .53507 Mdot
.75292 .32348 Mdot
.35075 .81548 Mdot
.59748 .79017 Mdot
.51999 .17182 Mdot
.78531 .53425 Mdot
.33441 .65707 Mdot
.54772 .27162 Mdot
.63583 .53051 Mdot
.71435 .58635 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo08Gooooo0_l0000?
ooooo`;o0000/Oooool001cooooo00?o0000ooooooooool0QOooool2o`0000oooooo0_l0002aoooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2N
ooooo`Co0000Yoooool001cooooo00?o0000ooooooooool0UOooool2o`0000Oooooo1?l0002Woooo
o`007?ooool00ol0003oooooooooo`2Eooooo`;o0000/_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`2Yooooo`;o0000W_ooool001cooooo00?o0000
ooooooooool0Q?ooool2o`0000gooooo0_l0000Dooooo`Co0000W?ooool001cooooo00?o0000oooo
ooooool0Q?ooool2o`0000gooooo0_l0000Fooooo`;o0000W?ooool001cooooo00?o0000oooooooo
ool0UOooool2o`0001;ooooo1ol0002Iooooo`007?ooool00ol0003oooooooooo`2;ooooo`;o0000
0_ooool3o`0000?ooooo0_l00005ooooo`;o00002oooool7o`0009Wooooo000Looooo`;o0000Qooo
ool2o`000003ooooool0003o000000;o00000_ooool3o`0000Kooooo0_l00002ooooo`;o00004ooo
ool2o`0009Kooooo000Looooo`03o`000?oooooooooo08Kooooo0_l000000ooooooo0000o`000009
ooooo`;o00000_ooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`000004ooooool0003o
0000o`0009Gooooo000Looooo`03o`000?oooooooooo09Cooooo0_l00007ooooo`;o000000?ooooo
o`000?l000000_ooool5o`0000Gooooo0_l00002ooooo`;o0000UOooool001cooooo00?o0000oooo
ooooool0Q?ooool2o`0000Cooooo0_l0000@ooooo`?o00001Oooool3o`0000?ooooo0_l0002Moooo
o`007?ooool00ol0003oooooooooo`24ooooo`;o00001?ooool2o`0000?ooooo0_l00002ooooo`;o
00001oooool2o`0000cooooo0_l00002ooooo`;o0000VOooool001cooooo00?o0000ooooooooool0
GOooool2o`0001cooooo0_l0000Booooo`?o000000?oooooo`000?l000006Oooool2o`0000kooooo
0_l00029ooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o00007?ooool2o`0000Wooooo0_l0
00000ooooooo0000o`000004ooooo`?o00004oooool2o`0000[ooooo0_l0000;ooooo`;o0000ROoo
ool001cooooo00?o0000ooooooooool0Q_ooool2o`000003ooooool0003o000000;ooooo1?l00008
ooooo`;o00002_ooool3o`0000;ooooo0_l00002ooooo`Go00002?ooool2o`0008cooooo000Loooo
o`03o`000?oooooooooo08Wooooo0_l00002ooooo`?o00002Oooool2o`0000_ooooo0ol000000ooo
oooo0000o`000002ooooo`Co00002Oooool2o`0000Oooooo0_l00023ooooo`007?ooool00ol0003o
ooooooooo`1fooooo`;o00000_ooool2o`0001?ooooo0_l00007ooooo`;o00001_ooool2o`0000Go
oooo0_l0000:ooooo`Co00002_ooool2o`000003ooooool0003o000008?ooooo000Looooo`03o`00
0?oooooooooo07;ooooo0_l00002ooooo`;o00000_ooool2o`0000Kooooo0_l0000:ooooo`?o0000
00?oooooo`000?l000001?ooool2o`0000Kooooo1?l0000?ooooo`Co00002_ooool2o`0008Kooooo
000Looooo`03o`000?oooooooooo07;ooooo0_l0000:ooooo`;o00000_ooool2o`0000[ooooo0ol0
00000ooooooo0000o`00000>ooooo`;o000000?oooooo`000?l000000_l00008ooooo`;o00001Ooo
ool2o`0008oooooo000Looooo`03o`000?oooooooooo06kooooo0_l0000>ooooo`;o00009Oooool4
o`0000Oooooo0ol00005ooooo`;o00000oooool2o`0008[ooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`1^ooooo`;o00006Ooo
ool4o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l000003?ooool2o`0000Gooooo0ol0
000;ooooo`;o000000?oooooo`000?l00000Qoooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo08So
oooo1ol00002ooooo`;o00001?ooool5o`0000cooooo0_l00002ooooo`;o000000Coooooo`000?l0
003o00003_ooool4o`0000?ooooo0_l00020ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413o
ooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0I_ooool2o`0000[o
oooo0_l0000Aooooo`;o000000?oooooo`000?l000000_ooool3o`000003ooooool0003o000000Co
00000_ooool3o`0000;ooooo0_l00005ooooo`;o00001Oooool4o`000003ooooool0003o000000_o
oooo0_l00003ooooo`?o00000_ooool2o`00083ooooo00000ooooooo0000ooooo`02ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0006Kooooo0_l00002ooooo`;o0000
1_ooool2o`00017ooooo0_l00005ooooo`;o00000_ooool6o`0000;ooooo0_l00003ooooo`;o0000
00?oooooo`000?l000000_ooool4o`0000?ooooo1?l0000>ooooo`;o00001?ooool2o`0000Sooooo
0_l0001jooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomV
IVKooooo00Gooooo00?o0000ooooooooool0J_ooool2o`0000gooooo0_l0000Kooooo`;o000000Co
ooooo`000?l0003ooooo0_l00002ooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`;o0000
2_ooool2o`0000gooooo0_l0001jooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0NOooool2o`0000[ooooo0_l0
000<ooooo`Go000000?oooooo`000?l000000ol0000>ooooo`;o00000_ooool4o`0000[ooooo0ol0
0005ooooo`Co00001?ooool2o`0007Wooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo
00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo06Cooooo0_l0000Oooooo`;o
00003?ooool3o`0000Cooooo1?l00004ooooo`;o00001_ooool2o`000004ooooool0003o0000oooo
o`;o000000?oooooo`000?l000002_ooool2o`0000Gooooo1_l00002ooooo`;o0000NOooool00006
ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o
0000ooooooooool0I?ooool2o`000003ooooool0003o000000Sooooo0_l0000;ooooo`;o00006?oo
ool4o`0000Kooooo0_l00006ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Wooooo1Ol0
0006ooooo`?o00001_ooool2o`0007Gooooo000Looooo`03o`000?oooooooooo06Oooooo0_l00008
ooooo`;o00002oooool5o`0000Cooooo0_l0000?ooooo`Co000000?oooooo`000?l000001?l0000K
ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Cooooo0_l000000ooooooo0000o`000003
ooooo`;o0000L?ooool001cooooo00?o0000ooooooooool0O_ooool5o`000004ooooool0003o0000
ooooo`;o00001Oooool2o`0000?ooooo0_l00008ooooo`Ko0000;?ooool2o`0000Kooooo0_l0001`
ooooo`007?ooool00ol0003oooooooooo`1gooooo`;o00001Oooool3o`0000?ooooo0_l00008oooo
o`;o00000oooool3o`0000Cooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0ol00005oooo
o`;o00000_ooool2o`0000Kooooo0_l00024ooooo`007?ooool00ol0003oooooooooo`1Tooooo`;o
00003oooool5o`0000Gooooo0_l0000Booooo`?o00001?ooool2o`0000cooooo0_l00005ooooo`?o
00001Oooool2o`0000;ooooo0_l00005ooooo`?o00000_ooool2o`000003ooooool0003o000000Ko
oooo0_l000000ooooooo0000o`00001booooo`007?ooool00ol0003oooooooooo`1Nooooo`;o0000
1?ooool2o`0000cooooo2?l0000@ooooo`?o00001Oooool4o`0000Sooooo0_l00008ooooo`;o0000
1Oooool2o`0000Wooooo0_l00006ooooo`;o00000oooool2o`000003ooooool0003o000000Kooooo
0_l000000ooooooo0000o`00001booooo`007?ooool00ol0003oooooooooo`1Nooooo`;o00002_oo
ool2o`0000Kooooo1ol00009ooooo`;o00001_ooool3o`0000Gooooo1?l00002ooooo`;o00000_oo
ool4o`0000Cooooo0_l00002ooooo`;o00001Oooool2o`0000Wooooo0_l0000Iooooo`;o0000L_oo
ool001cooooo00?o0000ooooooooool0FOooool2o`0000oooooo0_l0000Fooooo`;o00001_ooool2
o`0000[ooooo1?l00002ooooo`Ko00000_ooool2o`0000cooooo0_l00002ooooo`;o00001oooool2
o`0001Cooooo0ol0001aooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o00007Oooool2o`00
013ooooo1?l00008ooooo`;o00000oooool2o`000003ooooool0003o000000;o00000_ooool2o`00
00cooooo0_l00002ooooo`;o00001Oooool4o`000003ooooool0003o000000;o000000?oooooo`00
0?l000003Oooool2o`00077ooooo000Looooo`03o`000?oooooooooo07Cooooo0_l00002ooooo`;o
00004?ooool6o`0000_ooooo0_l0000Kooooo`;o00000oooool2o`0000?ooooo1?l000000ooooooo
0000o`000002ooooo`Co0000N_ooool001cooooo00?o0000ooooooooool0Joooool2o`000003oooo
ool0003o000000;o00000_ooool4o`00017ooooo1?l000000ooooooo0000o`000003o`0001_ooooo
0_l00007ooooo`?o00004Oooool4o`0000Cooooo0_l0001dooooo`007?ooool00ol0003ooooooooo
o`1@ooooo`;o00005_ooool:o`0000;ooooo1?l0000;ooooo`;o00001?ooool4o`0000;ooooo1?l0
0002ooooo`;o000000?oooooo`000?l000001Oooool2o`0000;ooooo0_l00006ooooo`;o000000?o
ooooo`000?l000001Oooool4o`0000Oooooo0_l00002ooooo`;o00003Oooool2o`0007Cooooo000L
ooooo`;o0000DOooool2o`0001Cooooo1Ol00002ooooo`;o00001Oooool2o`0000Oooooo0_l00004
ooooo`;o00004?ooool2o`000003ooooool0003o000000Gooooo0_l00002ooooo`;o000000?ooooo
o`000?l000000_ooool3o`0000;ooooo0_l00004ooooo`;o00002Oooool3o`000003ooooool0003o
000000kooooo0_l00008ooooo`;o0000JOooool001cooooo00?o0000ooooooooool0FOooool2o`00
00Sooooo1Ol0000=ooooo`;o00001_ooool2o`0000Cooooo0_l00005ooooo`;o00001Oooool2o`00
00cooooo0ol00004ooooo`;o00000_ooool4o`000003ooooool0003o000000Sooooo0_l00006oooo
o`;o00000oooool2o`0000Kooooo0_l00004ooooo`;o00001Oooool5o`0006Wooooo000Looooo`03
o`000?oooooooooo05Wooooo0_l00008ooooo`?o00003oooool2o`0000?ooooo0_l000000ooooooo
0000o`000005ooooo`Co00000_ooool2o`0000Gooooo0_l00003ooooo`;o00001oooool3o`0000Co
oooo0_l00004ooooo`;o00001?ooool4o`0000;ooooo0ol00002ooooo`;o00001oooool2o`0000Ko
oooo0_l0000:ooooo`Go0000J_ooool001cooooo00?o0000ooooooooool0Doooool2o`0000;ooooo
0_l00004ooooo`;o000000?oooooo`000?l000005?ooool2o`000005ooooool0003o0000o`000?oo
ool00_l000000ooooooo0000o`000002ooooo`Co00002?ooool4o`0000;ooooo0_l00007ooooo`;o
00004?ooool5o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`000003
ooooool0003o0000017ooooo1Ol00009ooooo`;o0000Goooool001cooooo00?o0000ooooooooool0
Doooool2o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l000001_ooool2o`0000cooooo
0_l000001?oooooo0000o`000?l00004ooooo`;o00003_ooool4o`0000?ooooo0_l0000;ooooo`;o
00001Oooool2o`0000Cooooo0ol00006ooooo`;o00001?ooool3o`000004ooooool0003o0000oooo
o`;o00004Oooool4o`000003ooooool0003o000000;o00001Oooool2o`0005oooooo000Looooo`03
o`000?oooooooooo05gooooo1?l00007ooooo`;o000000Coooooo`000?l0003ooooo0_l0000:oooo
o`;o000000?oooooo`000?l000000_ooool2o`0000Wooooo0_l00003ooooo`;o00001?ooool2o`00
00_ooooo1?l00003ooooo`;o00002Oooool2o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`00
00?ooooo0_l00002ooooo`Co00002?ooool9o`0001kooooo0_l00016ooooo`007?ooool00ol0003o
ooooooooo`1Oooooo`;o00000oooool2o`0000Gooooo1Ol00004ooooo`;o00001oooool2o`0000;o
oooo0_l00003ooooo`Co00000_ooool2o`0000?ooooo0_l0000Cooooo`Co00000oooool2o`0000Oo
oooo0_l00005ooooo`;o00001_ooool2o`0000?ooooo0_l00002ooooo`Co00000oooool2o`0000Oo
oooo0_l000000ooooooo0000o`00000Nooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0
GOooool2o`000003ooooool0003o000000;ooooo0_l00006ooooo`;o00001_ooool3o`0000Gooooo
1?l00006ooooo`Co00000oooool2o`0001Oooooo1?l00003ooooo`?o00003?ooool3o`0000Cooooo
0_l00009ooooo`;o00001Oooool2o`0000Oooooo0_l000000ooooooo0000o`000004ooooo`;o0000
1_ooool2o`0005Sooooo000Looooo`03o`000?oooooooooo05gooooo0_l000000ooooooo0000o`00
000Cooooo`;o00001Oooool4o`0000Cooooo1Ol00004ooooo`;o00001?ooool2o`0000Sooooo0_l0
00000ooooooo0000o`000002o`0000;ooooo1?l00004ooooo`;o00003?ooool2o`0000Gooooo0_l0
000>ooooo`;o00002?ooool4o`0000Kooooo1Ol00003ooooo`;o0000F?ooool001cooooo00?o0000
ooooooooool0KOooool2o`0000Gooooo0_l00006ooooo`;o000000?oooooo`000?l000000_ooool6
o`0000[ooooo0_l00008ooooo`;o000000?oooooo`000?l000000_l00002ooooo`Co00004?ooool4
o`0000?ooooo0_l0000@ooooo`;o00001_ooool6o`0000Gooooo1_l0001Mooooo`007?ooool00ol0
003oooooooooo`1Tooooo`?o00001?ooool4o`0000Gooooo0_l00006ooooo`Wo00000_ooool2o`00
00cooooo0_l00002ooooo`;o00000_ooool2o`0001_ooooo0ol00004ooooo`;o00001oooool2o`00
00kooooo0ol00009ooooo`;o000000Coooooo`000?l0003o0000GOooool001cooooo00?o0000oooo
ooooool0Hoooool4o`0000Cooooo0_l0000?ooooo`Oo00001?ooool2o`0000[ooooo1?l00002oooo
o`Co00004_ooool2o`0000Oooooo0_l000000ooooooo0000o`00000=ooooo`;o00001?ooool5o`00
00Gooooo0_l0000:ooooo`;o00000_ooool2o`0000_ooooo0_l0001@ooooo`007?ooool00ol0003o
ooooooooo`0kooooo`;o00009_ooool2o`0000Sooooo0_l0000=ooooo`Co000000?oooooo`000?l0
00004?ooool2o`0000Kooooo0_l0000Booooo`;o00000oooool2o`0000;ooooo0_l0000?ooooo`Co
00000oooool6o`00013ooooo0_l0000?ooooo`;o00000_ooool2o`0004cooooo000Looooo`03o`00
0?oooooooooo03_ooooo0_l0000Qooooo`;o00002oooool4o`0000Gooooo0_l000000ooooooo0000
o`000002o`0000Oooooo0_l0000:ooooo`;o00003?ooool2o`0000cooooo0_l00008ooooo`;o0000
1_ooool2o`000003ooooool0003o000000Sooooo1Ol00006ooooo`;o00005_ooool2o`0000gooooo
0_l0001<ooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o00002oooool4o`0000?ooooo2_l0
0006ooooo`;o00000oooool2o`0000Gooooo0_l00003ooooo`;o00001oooool6o`0000Sooooo0_l0
0008ooooo`;o00001?ooool7o`0000;ooooo0_l00007ooooo`;o00000oooool2o`0000Gooooo1?l0
000@ooooo`;o0000Foooool001cooooo00?o0000ooooooooool0C_ooool2o`000003ooooool0003o
000000_ooooo1?l00008ooooo`?o00001Oooool2o`000003ooooool0003o000000?ooooo0_l00002
ooooo`Co00001Oooool2o`0000[ooooo0_l00002ooooo`?o00000oooool5o`0001;ooooo0_l00000
1?oooooo0000o`000?ooool3o`000003ooooool0003o000000Go00003?ooool2o`0000Gooooo1?l0
0006ooooo`;o00002oooool3o`0005Oooooo000Looooo`;o0000Coooool2o`000003ooooool0003o
000000;ooooo0_l000000ooooooo0000o`000003ooooo`Go00002?ooool2o`00013ooooo1_l0000E
ooooo`?o00000oooool2o`000004ooooool0003o0000o`0000Oooooo0_l0000;ooooo`Go00001?oo
ool4o`0000Oooooo0_l00004ooooo`;o00001oooool2o`0000Kooooo0_l0000;ooooo`?o0000Eooo
ool001cooooo00?o0000ooooooooool0EOooool2o`000003ooooool0003o000000?ooooo0ol0000L
ooooo`;o00003?ooool2o`0000Wooooo0_l000000ooooooo0000o`000006ooooo`Go00001Oooool2
o`0000Wooooo2?l00007ooooo`;o00001Oooool2o`0000Cooooo0_l00007ooooo`;o00004_ooool2
o`000003ooooool0003o000005Kooooo000Looooo`03o`000?oooooooooo04Wooooo0_l0000Goooo
o`?o00002oooool2o`0000Sooooo0_l0000>ooooo`;o00001?ooool2o`0000?ooooo0_l000000ooo
oooo0000o`000006ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o00001_ooool;o`00
00Oooooo0_l0000Gooooo`;o00002Oooool2o`0000Cooooo0_l000000ooooooo0000o`00001Foooo
o`007?ooool00ol0003oooooooooo`10ooooo`;o00001oooool2o`0001Oooooo0ol00005ooooo`;o
00000oooool3o`0000Gooooo2?l0000:ooooo`;o00001Oooool4o`0000?ooooo0_l00005ooooo`Co
00000oooool3o`0000;ooooo0_l00004ooooo`oo00001_ooool2o`0000gooooo0_l00007ooooo`?o
00002?ooool2o`0000Oooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`10ooooo`;o0000
2?ooool2o`0000Oooooo0_l00005ooooo`;o00003_ooool2o`0000?ooooo0_l00006ooooo`So0000
1?ooool2o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo
1_l00004ooooo`;o00001oooool@o`0000Kooooo0_l0000:ooooo`Go00001oooool3o`00013ooooo
1Ol000000ooooooo0000o`00000:ooooo`;o0000AOooool001cooooo00?o0000ooooooooool0B_oo
ool2o`0000Oooooo0_l00005ooooo`;o00004_ooool2o`0000[ooooo0_l000000ooooooo0000o`00
0004ooooo`;o00001_ooool2o`000004ooooool0003o0000o`0000;ooooo0_l00007ooooo`;o0000
4Oooool?o`000003ooooool0003o0000013ooooo1?l00006ooooo`;o00004_ooool3o`000004oooo
ool0003o0000ooooo`;o00002_ooool2o`0004Gooooo000Looooo`03o`000?oooooooooo05Gooooo
0_l0000:ooooo`;o00002oooool4o`0000_ooooo0_l0000<ooooo`;o000000?oooooo`000?l00000
0oooool2o`0001Cooooo0ol00002oooooa3o000000?oooooo`000?l000002Oooool2o`0000[ooooo
0_l00003ooooo`;o00004_ooool2o`0000Oooooo0_l0001?ooooo`007?ooool00ol0003ooooooooo
o`1Eooooo`;o00002_ooool2o`0000cooooo0ol0000Mooooo`;o00006?oooolFo`0000_ooooo0_l0
000:ooooo`;o00001oooool2o`0000Gooooo0_l0000@ooooo`?o0000C_ooool001cooooo00?o0000
ooooooooool0E_ooool2o`0000[ooooo0_l00009ooooo`;o00004?ooool2o`0000kooooo0_l0000I
oooooaKo00007_ooool3o`0000Gooooo0_l00004ooooo`;o00000oooool2o`0000Kooooo0_l0001>
ooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00003Oooool4o`0000[ooooo0_l00004oooo
o`;o00000oooool2o`00013ooooo0_l0000Yooooo`;o000000?oooooo`000?l000004ol00003oooo
o`;o00002?ooool4o`0000_ooooo0_l00004ooooo`;o000000?oooooo`000?l000000oooool2o`00
00?ooooo0_l00003ooooo`;o0000DOooool001cooooo00?o0000ooooooooool0AOooool2o`0000Co
oooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l0000>ooooo`;o00000oooool2o`0003_o
oooo0_l000000ooooooo0000o`00000Co`0000?ooooo0_l00005ooooo`;o000000?oooooo`000?l0
00000_l00003ooooo`;o00003?ooool2o`000003ooooool0003o000000gooooo0_l0001Aooooo`00
7?ooool00ol0003oooooooooo`1;ooooo`Ko00000oooool2o`0000;ooooo0_l0000Cooooo`;o0000
1oooool2o`0003;ooooo2_l000000ooooooo0000o`000009o`000003ooooool0003o000000;ooooo
0_l00005ooooo`;o00000_ooool2o`0000Cooooo0_l0000<ooooo`;o000000?oooooo`000?l00000
3Oooool2o`00057ooooo000Looooo`03o`000?oooooooooo04gooooo0_l00003ooooo`?o00005ooo
ool2o`0000Oooooo0ol0000;ooooo`;o00009_oooolEo`000003ooooool0003o000000;ooooo0_l0
0004ooooo`;o00000_ooool3o`0000[ooooo0_l00006ooooo`;o000000?oooooo`000?l000003Ooo
ool2o`000004ooooool0003o0000ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0AOoo
ool2o`0000;ooooo0_l00007ooooo`?o00001Oooool2o`00013ooooo0_l00007ooooo`Oo00001ooo
ool2o`0000Cooooo0_l0000Mooooo`oo00000_ooool5o`0000gooooo1ol0000:ooooo`?o00003ooo
ool3o`0000Sooooo0_l000000ooooooo0000o`00001;ooooo`007?ooool00ol0003oooooooooo`15
ooooo`;o00000_ooool2o`0000oooooo0_l00002ooooo`;o000000?oooooo`000?l000002Oooool2
o`0000Sooooo1_l0000=ooooo`;o00007OoooolGo`0000kooooo0ol0000=ooooo`;o00002_ooool2
o`0000?ooooo0ol0000;ooooo`Co0000BOooool001cooooo00?o0000ooooooooool0E?ooool2o`00
00;ooooo2?l000000ooooooo0000o`000006ooooo`;o00002?ooool2o`0000kooooo0_l0000?oooo
o`;o00005?oooolEo`0000cooooo1?l00005ooooo`;o000000?oooooo`000?l000001?ooool2o`00
00[ooooo0_l000000ooooooo0000o`00000?ooooo`?o00000_ooool2o`0004Gooooo000Looooo`;o
0000?_ooool2o`0000?ooooo0_l0000:ooooo`;o00001?ooool2o`0000;ooooo0_l00002ooooo`;o
00002oooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`000004ooooool0003o0000o`00
00Oooooo0_l000001?oooooo0000o`000?l0000>ooooo`Co00003?ooool2o`0000?ooooo5?l00002
ooooo`;o00001_ooool2o`0000;ooooo1?l00005ooooo`;o000000?oooooo`000?l000000_ooool2
o`0000_ooooo0_l00002ooooo`;o00004oooool3o`0004Gooooo000Looooo`03o`000?oooooooooo
03gooooo0_l000000ooooooo0000o`000002o`0000Cooooo0ol00003ooooo`;o00001_ooool2o`00
00Kooooo0_l0000>ooooo`;o000000?oooooo`000?l000000oooool3o`000003ooooool0003o0000
00Cooooo0_l00002ooooo`Go00001?ooool2o`0000Oooooo0ol0000;ooooo`;o00000_oooolDo`00
00?ooooo0_l00006ooooo`;o00000oooool2o`0000[ooooo0_l000000ooooooo0000o`00000;oooo
o`;o00005oooool2o`0000;ooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o
00001_ooool3o`0000Kooooo0_l00002ooooo`?o00001_ooool2o`0001[ooooo0_l000000ooooooo
0000o`000007ooooo`?o00001?ooool2o`0000Sooooo0_l0000?oooooaGo00003oooool2o`0000Ko
oooo0_l00002ooooo`;o000000?oooooo`000?l000003oooool2o`0000kooooo0ol00006ooooo`;o
0000@_ooool001cooooo00?o0000ooooooooool08oooool2o`0002?ooooo1?l000000ooooooo0000
o`000002ooooo`;o00000_ooool2o`0001Kooooo0_l00002ooooo`Co00002?ooool2o`0000kooooo
0_l000000ooooooo0000o`000002o`0000?ooooo0_l000000ooooooo0000o`00000;ooooo`oo0000
00?oooooo`000?l000001Ol00005ooooo`Co00000_ooool4o`0000Oooooo0_l0000Dooooo`Co0000
00?oooooo`000?l000000_l00009ooooo`?o00001?ooool2o`0004Cooooo000Looooo`03o`000?oo
oooooooo02?ooooo0_l0000Sooooo`Co000000?oooooo`000?l000007_ooool2o`0000;ooooo1?l0
000Hooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o000000?oooooo`000?l000002?oo
ool2o`000003ooooool0003o000001;o000000?oooooo`000?l000001Oooool5o`000003ooooool0
003o000000;o00006?ooool4o`000003ooooool0003o000000?ooooo1?l0000:ooooo`;o000000Co
ooooo`000?l0003ooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00009ooo
ool2o`0000oooooo0_l00003ooooo`;o00001?ooool3o`0000Kooooo0_l0000:ooooo`;o00005Ooo
oolIo`0000Sooooo0ol00003ooooo`;o00006?ooool4o`0001Cooooo0_l000000ooooooo0000o`00
0017ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00002Oooool2o`0000Gooooo0_l0000E
ooooo`;o00003oooool2o`0000?ooooo0_l00003ooooo`Co00001_ooool2o`0002?ooooo1?l00000
0ooooooo0000o`00000@o`0000;ooooo0_l00004ooooo`;o00006_ooool2o`0000[ooooo0_l00004
ooooo`;o00002?ooool2o`0000Gooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`0coooo
o`;o00001oooool4o`0000Gooooo0_l000000ooooooo0000o`000003ooooo`;o00001?ooool2o`00
01gooooo0_l00003ooooo`?o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000005
ooooo`;o000000?oooooo`000?l000000_l00006ooooo`;o00004Oooool2o`000003ooooool0003o
000000Wo00001?ooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0
003o0000017ooooo0_l00004ooooo`;o00001_ooool6o`0000Cooooo0_l00008ooooo`;o00001Ooo
ool2o`0004?ooooo000Looooo`03o`000?oooooooooo03cooooo0_l00004ooooo`;o00001?ooool2
o`0000;ooooo1?l00003ooooo`Co00002oooool2o`0000kooooo0_l00003ooooo`?o000000?ooooo
o`000?l000001ol00004ooooo`Oo00001?ooool4o`0000?ooooo0_l00005ooooo`;o000000?ooooo
o`000?l000001?ooool4o`0000?ooooo1Ol00004ooooo`;o00001_ooool2o`0000Cooooo1?l00006
ooooo`;o00001oooool2o`0000cooooo1?l000001?oooooo0000o`000?l00002ooooo`;o00003ooo
ool3o`0000Kooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`11ooooo`?o000000?ooooo
o`000?l000001Oooool4o`000003ooooool0003o000000;ooooo0ol00007ooooo`;o000000?ooooo
o`000?l000000oooool2o`0000Kooooo0_l00005ooooo`Wo000000?oooooo`000?l000001ol00000
0ooooooo0000o`000002o`0000?ooooo1ol00002ooooo`;o00001Oooool2o`000003ooooool0003o
000000Cooooo1?l00003ooooo`Oo000000Coooooo`000?l0003o00001Oooool2o`0000Oooooo0_l0
0006ooooo`;o00004_ooool2o`0000Gooooo1?l00002ooooo`;o00003oooool4o`0000Gooooo0_l0
0003ooooo`;o0000=Oooool001cooooo00?o0000ooooooooool0>Oooool2o`000004ooooool0003o
0000ooooo`Co00000_ooool4o`0000Oooooo0ol00002ooooo`?o00001oooool2o`0000Cooooo1?l0
0006ooooo`;o00001Oooool7o`0000Gooooo1ol00003ooooo`;o00000oooool7o`00013ooooo0_l0
0008ooooo`Ko000000Goooooo`000?l0003o0000ooooo`02o`0000;ooooo0_l0000=ooooo`;o0000
2?ooool2o`0000[ooooo0_l00005ooooo`?o00001_ooool2o`0000kooooo0_l0000:ooooo`;o0000
=Oooool001cooooo00?o0000ooooooooool0>Oooool2o`000004ooooool0003o0000ooooo`;o0000
1_ooool2o`0000Cooooo1_l00002ooooo`;o00003_ooool2o`0000;ooooo1?l00005ooooo`;o0000
0_ooool3o`000003ooooool0003o000000?o00000_ooool9o`0000Cooooo2_l00004ooooo`;o0000
2_ooool2o`0000?ooooo0_l0000:ooooo`;o00000_ooool2o`0000;ooooo0_l0000=ooooo`?o0000
1oooool2o`00017ooooo0_l00004ooooo`;o000000?oooooo`000?l000002oooool2o`000004oooo
ool0003o0000o`00043ooooo000Looooo`03o`000?oooooooooo04gooooo1?l00002ooooo`;o0000
2_ooool2o`0000;ooooo0_l00004ooooo`Co000000?oooooo`000?l000001?l000000ooooooo0000
o`000003ooooo`;o000000Coooooo`000?l0003ooooo3?l00002ooooo`Ko00002?ooool2o`000003
ooooool0003o000000cooooo0_l00007ooooo`?o00004Oooool2o`0000?ooooo1?l00003ooooo`;o
00006oooool2o`0000?ooooo0_l00009ooooo`;o000000Coooooo`000?l0003o0000@?ooool001co
oooo00?o0000ooooooooool0COooool2o`0000;ooooo1?l0000:ooooo`;o00000_ooool2o`0000Wo
oooo1_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000001?l000000ooooooo
0000o`000007o`000003ooooool0003o000000;ooooo0_l00003ooooo`;o00001?ooool4o`0000Wo
oooo0_l0000:ooooo`?o00001?ooool2o`0000Sooooo0_l000000ooooooo0000o`000003ooooo`;o
00001Oooool2o`00023ooooo0_l00009ooooo`?o00001?ooool2o`0001;ooooo0_l0000Yooooo`00
00Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo
00Cooooo00?o0000ooooooooool0COooool2o`0000;ooooo0_l0000Eooooo`;o00000oooool2o`00
00;ooooo0ol00002ooooo`;o00001Oooool7o`000003ooooool0003o000000go000000?oooooo`00
0?l000000_l00003ooooo`?o00001oooool2o`0000;ooooo0_l00008ooooo`?o00001_ooool2o`00
00Sooooo0_l0000Wooooo`;o00000_ooool4o`0000cooooo0_l00004ooooo`;o00004_ooool2o`00
02Wooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0??ooool2o`0000?ooooo0ol0000Tooooo`;o00000oooool2
o`0000Cooooo7ol00003ooooo`Go00000_ooool2o`0000Kooooo1?l0000<ooooo`?o00001_ooool3
o`0000[ooooo0_l0000Oooooo`;o00000_ooool3o`0000;ooooo1_l00005ooooo`;o00001Oooool2
o`00047ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006oooo
o`03o`000?oooooooooo03Oooooo0_l00003ooooo`;o00000oooool3o`000004ooooool0003o0000
o`0000Gooooo0_l00004ooooo`;o00001oooool2o`0000_ooooo0_l00003ooooo`;o00000_ooool4
o`0000;ooooo7?l000000ooooooo0000o`000003o`0000[ooooo0_l00003ooooo`;o00004Oooool5
o`0000Wooooo0_l000000ooooooo0000o`000002o`0001[ooooo0_l00002ooooo`Co000000?ooooo
o`000?l000000_ooool2o`0000Gooooo1_l000000ooooooo0000o`000011ooooo`0000?oooooo`00
0?ooool00_ooool00ol0003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0000g
ooooo`;o00000oooool2o`0000Oooooo0ol00005ooooo`;o00001?ooool3o`0000;ooooo0_l00002
ooooo`;o00002oooool4o`000004ooooool0003o0000oooooaoo000000?oooooo`000?l000001Ol0
00000ooooooo0000o`000002ooooo`;o00002_ooool2o`0000cooooo1?l000000ooooooo0000o`00
0003o`0000_ooooo1Ol0000Iooooo`;o00001Oooool2o`000003ooooool0003o000000Kooooo1?l0
00000ooooooo0000o`000002o`0004Cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`0[ooooo`;o00003ooo
ool3o`0000gooooo0_l00006ooooo`;o000000Coooooo`000?l0003o00000oooool2o`0000_ooooo
1Ol00002oooooaoo00001?ooool4o`000003ooooool0003o000000;ooooo0_l00004ooooo`?o0000
3_ooool2o`000003ooooool0003o000000;o00000oooool2o`0000Cooooo0_l00006ooooo`;o0000
4Oooool2o`0000Wooooo0_l00006ooooo`?o00000_ooool2o`000003ooooool0003o000000Co0000
0_ooool2o`0004Gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?o
MgMgolc<c?l000001oooool00ol0003oooooooooo`0Kooooo`;o00003_ooool2o`0000oooooo0ol0
0003ooooo`;o00002?ooool2o`0000Wooooo0_l00004ooooo`;o00003_ooool2o`000003ooooool0
003o000000;o00001?ooool5o`000003ooooool0003o000000_o000000?oooooo`000?l000001_l0
00000ooooooo0000o`000003o`0000Wooooo1?l00007ooooo`;o00000oooool3o`0000kooooo0ol0
0004ooooo`;o000000?oooooo`000?l000003_ooool3o`00017ooooo0ol00002ooooo`;o000000?o
ooooo`000?l00000COooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4
o`000007ooooo`03o`000?oooooooooo01_ooooo0_l0000Mooooo`;o00001_ooool2o`0000Wooooo
1?l0000?ooooo`;o00003_ooool3o`000003ooooool0003o000001ko000000?oooooo`000?l00000
0ol0000;ooooo`;o00001oooool4o`000003ooooool0003o0000013ooooo0_l00004ooooo`co0000
00?oooooo`000?l000001?ooool3o`0006Sooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPgo
oooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`0dooooo`;o00001?ooool2o`0000Co
oooo0_l0000;ooooo`Co000000?oooooo`000?l000002Oooool2o`000003ooooool0003o000000oo
oooo7ol000001Ooooooo0000o`000?l0003ooooo00Go00005_ooool2o`0001?ooooo0_l00006oooo
o`[o000000?oooooo`000?l00000Koooool001cooooo00?o0000ooooooooool09oooool2o`0000_o
oooo0_l0000:ooooo`;o00002_ooool2o`0000Cooooo0_l00007ooooo`Co00002?ooool2o`0000Co
oooo0_l000000ooooooo0000o`00000Ro`0000Cooooo0ol0000>ooooo`;o00001Oooool2o`0000Go
oooo0_l00007ooooo`Co000000?oooooo`000?l000002Oooool3o`0000Cooooo0_l0000Tooooo`;o
00002Oooool2o`0003oooooo000Looooo`03o`000?oooooooooo02Oooooo0_l0000Mooooo`;o0000
1?ooool2o`0000gooooo0ol00009ooooo`Co000000?oooooo`000?l000009ol00003ooooo`?o0000
0_ooool2o`0000[ooooo0_l00002ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Oooooo
1?l00004ooooo`;o00000oooool2o`0000Sooooo0_l0000?ooooo`;o000000?oooooo`000?l00000
4?ooool2o`0000Wooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0eooooo`;o00000_oo
ool2o`0000_ooooo0_l0000<ooooo`?o00000oooool4o`0000?ooooo0_l00005ooooo`?o000000?o
ooooo`000?l00000:?l00007ooooo`;o00003_ooool2o`0000;ooooo0_l00003ooooo`;o00002_oo
ool2o`0000Cooooo0_l00003ooooo`;o00002_ooool2o`0000gooooo0_l000000ooooooo0000o`00
000>ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0=Oooool2o`0000;ooooo0_l0000;
ooooo`?o00001_ooool2o`0000?ooooo0ol00002ooooo`Co00001?ooool2o`0000Gooooo0_l00000
1?oooooo0000o`000?ooool3o`000004ooooool0003o0000ooooob7o00000_ooool2o`000003oooo
ool0003o000000;ooooo0_l00007ooooo`Co00001Oooool4o`000003ooooool0003o000001[ooooo
0_l00005ooooo`;o00002oooool2o`0000_ooooo0_l00006ooooo`;o0000C?ooool001cooooo00?o
0000ooooooooool0?_ooool2o`0000Kooooo0ol00005ooooo`?o00002?ooool3o`0000oooooo:Ol0
0004ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Oooooo1?l00007ooooo`;o000000?o
ooooo`000?l000004_ooool2o`0000Cooooo1?l00004ooooo`;o00003?ooool2o`0000_ooooo0_l0
000Iooooo`;o0000>Oooool001cooooo00?o0000ooooooooool0?_ooool2o`0000Kooooo0_l00006
ooooo`?o00002Oooool3o`0000Kooooo0_l00005ooooobko00004Oooool3o`0000[ooooo0_l00000
0ooooooo0000o`00000:ooooo`;o00000oooool2o`0000;ooooo2?l00002ooooo`;o00002_ooool2
o`0001cooooo0_l00008ooooo`Co0000>Oooool001cooooo00?o0000ooooooooool08oooool4o`00
01?ooooo0_l0000:ooooo`;o00001oooool4o`0000;ooooo0_l00004ooooo`;o00001_ooool2o`00
00Gooooo0_l000000ooooooo0000o`00000Lo`0000;ooooo2ol0000Aooooo`?o00003Oooool2o`00
00[ooooo0_l00007ooooo`So00003_ooool2o`0001cooooo0_l00008ooooo`;o0000>oooool001co
oooo00?o0000ooooooooool08oooool4o`0001?ooooo0_l0000Dooooo`?o00000_ooool2o`0000co
oooo0ol00003ooooo`;o00000_ooool2o`0000;ooooo9_l00006ooooo`?o00005?ooool2o`0000Wo
oooo0_l0000=ooooo`?o000000?oooooo`000?l000003oooool2o`0001;ooooo0_l0001@ooooo`00
7?ooool00ol0003oooooooooo`0iooooo`;o00005Oooool2o`0001;ooooo0ol000001?oooooo0000
o`000?l00002ooooo`;o00000_ooool?o`000003ooooool0003o0000017o00000oooool2o`0000Co
oooo0ol0000?ooooo`;o00000_ooool3o`0000Oooooo1_l00009ooooo`Go00002Oooool2o`0000;o
oooo0_l00003ooooo`;o00001oooool2o`0000Oooooo1?l00002ooooo`;o0000C?ooool001cooooo
00?o0000ooooooooool0>Oooool3o`0000Sooooo0_l00005ooooo`;o00006?ooool2o`000003oooo
ool0003o000000Oooooo9?l00002ooooo`;o00003oooool2o`0000;ooooo0_l000000ooooooo0000
o`000002ooooo`;o00000_ooool4o`0000;ooooo0_l00002ooooo`;o00001oooool9o`000003oooo
ool0003o000000Cooooo1_l00004ooooo`;o00001?ooool4o`0000Oooooo0_l000001?oooooo0000
o`000?ooool2o`0001?ooooo0_l0000gooooo`007?ooool00ol0003oooooooooo`0jooooo`;o0000
2?ooool2o`0000Gooooo0_l0000Fooooo`;o000000Coooooo`000?l0003o00000oooool2o`0000;o
oooo9Ol00002ooooo`Co00002_ooool2o`000005ooooool0003o0000o`000?ooool00_l000001?oo
oooo0000o`000?ooool2o`0000?ooooo1?l0000?ooooo`Go000000?oooooo`000?l000001?l00006
ooooo`?o00001Oooool2o`000004ooooool0003o0000ooooo`;o00000oooool2o`0000Oooooo0_l0
0004ooooo`;o00003?ooool2o`0000;ooooo0_l0000gooooo`007?ooool2o`0006Cooooo0_l00000
1?oooooo0000o`000?l00003ooooo`;o00000_oooolUo`0000;ooooo1?l00002ooooo`;o00001_oo
ool2o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l000005?ooool8o`000003ooooool0
003o000000Co00000oooool2o`000004ooooool0003o0000o`0000Oooooo0_l00006ooooo`;o0000
3Oooool2o`0000cooooo0_l000000ooooooo0000o`00000hooooo`007?ooool00ol0003ooooooooo
o`0Iooooo`;o0000B?ooool2o`0000Gooooo0ol000000ooooooo0000o`00000=o`000003ooooool0
003o000000Wo000000?oooooo`000?l000002Ol000000ooooooo0000o`000003o`0000;ooooo0_l0
0009ooooo`;o00004Oooool2o`0000?ooooo0_l00006oooooaCo00000_ooool2o`0000?ooooo0_l0
000>ooooo`?o00002?ooool2o`0000gooooo1?l0000hooooo`007?ooool00ol0003oooooooooo`0I
ooooo`;o0000;oooool2o`0001Sooooo0_l00002oooooaGo000000?oooooo`000?l000005Ol00000
0ooooooo0000o`000002o`0000kooooo0_l0000?ooooo`Co00000oooool?o`000003ooooool0003o
000000So000000?oooooo`000?l000001_ooool2o`0000_ooooo0_l000001?oooooo0000o`000?l0
0007ooooo`?o000000?oooooo`000?l000001Oooool2o`000003ooooool0003o000000;o00001?oo
ool2o`0003Cooooo000Looooo`03o`000?oooooooooo043ooooo0_l00005ooooo`;o000000?ooooo
o`000?l000005oooool3o`0000;ooooo1ol000000ooooooo0000o`00000To`0000;ooooo0_l0000O
ooooo`?o000000Goooooo`000?l0003o0000ooooo`0>o`000005ooooool0003o0000o`000?ooool0
2Ol00008ooooo`?o00002?ooool2o`0000_ooooo1_l00005ooooo`;o000000?oooooo`000?l00000
1_ooool2o`0003Cooooo000Looooo`03o`000?oooooooooo03Oooooo0_l00007ooooo`;o00001Ooo
ool2o`0001[ooooo0_l00004ooooo`?o00000_oooolSo`0000;ooooo0ol000000ooooooo0000o`00
0007ooooo`;o00006?ooool6o`000003ooooool0003o000000;ooooo2_l000000ooooooo0000o`00
000;o`0000Sooooo0ol00004ooooo`Co00000oooool2o`0000[ooooo0_l00018ooooo`007?ooool0
0ol0003oooooooooo`0gooooo`Co0000<Oooool;o`000003ooooool0003o000001oo00001oooool2
o`0000Wooooo0_l00006ooooo`;o00001oooool2o`0000Oooooo7?l0000;ooooo`Co00000oooool2
o`0001?ooooo0_l00004ooooo`;o0000>Oooool001cooooo00?o0000ooooooooool06oooool2o`00
00Gooooo0_l0000Booooo`;o000000?oooooo`000?l000001oooool2o`0002Gooooo6Ol000000ooo
oooo0000o`00000Ho`0000kooooo0_l00006ooooo`Co00003?oooolNo`0000gooooo0_l0000?oooo
o`;o00001oooool2o`0000Cooooo0ol0000hooooo`007?ooool00ol0003oooooooooo`0Kooooo`;o
00001Oooool2o`0001;ooooo0_l00005ooooo`?o00000_ooool4o`000003ooooool0003o000000Oo
oooo0_l0000Gooooo`?o00000_ooool6o`000003ooooool0003o000001co000000?oooooo`000?l0
00000_l000000ooooooo0000o`000002o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`00
00Cooooo0_l00007ooooo`;o00001?ooool2o`0000Cooooo1Ol000000ooooooo0000o`00000:o`00
0003ooooool0003o000000Wo00006_ooool2o`0000Cooooo0_l00002ooooo`;o00001oooool5o`00
03Sooooo000Looooo`03o`000?oooooooooo03Kooooo0_l00005ooooo`?o00001?ooool2o`000005
ooooool0003o0000o`000?ooool00_l00003ooooo`;o00006ooooolVo`0000;ooooo0ol00008oooo
o`;o000000?oooooo`000?l000000ol00004ooooo`;o00003Oooool2o`0000?ooooo1Ol000000ooo
oooo0000o`000004o`000003ooooool0003o0000017o00006Oooool2o`0000Sooooo0_l00007oooo
o`Co00001?ooool2o`0003?ooooo000Looooo`03o`000?oooooooooo03Kooooo0_l00006ooooo`Co
00001_ooool2o`000003ooooool0003o0000023ooooo4?l000000ooooooo0000o`00000Co`0000;o
oooo0ol000000ooooooo0000o`000005ooooo`Wo00000oooool2o`0001;ooooo3ol000000ooooooo
0000o`00000>o`0000Wooooo0_l0000@ooooo`;o00002Oooool4o`000004ooooool0003o0000o`00
00Kooooo0_l0000cooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00002_ooool2o`0000;o
oooo1?l0000Xooooo`;o00000_ooool@o`000003ooooool0003o000000[o000000Coooooo`000?l0
003o00000_ooool2o`0000;ooooo0_l00002ooooo`;o00001?ooool:o`0000?ooooo0_l00006oooo
o`Co000000?oooooo`000?l000001_oooolPo`0000Sooooo0_l00008ooooo`;o00001_ooool4o`00
00;ooooo0_l00003ooooo`Co000000Coooooo`000?l0003o00002?ooool2o`00037ooooo000Loooo
o`03o`000?oooooooooo02Kooooo0_l00006ooooo`;o00002_ooool2o`0002kooooo0_l00002oooo
o`Go00000_oooolNo`0000_ooooo2_l00004ooooo`;o000000?oooooo`000?l000000oooool7o`00
00;ooooo0_l00003oooooaoo00002_ooool3o`0000Gooooo0_l00008ooooo`;o00000_ooool2o`00
01?ooooo0_l0000aooooo`007?ooool00ol0003oooooooooo`0Vooooo`;o00001_ooool2o`00017o
oooo0_l00003ooooo`;o00002?ooool2o`0001gooooo1?l00002oooooaSo00000_ooool2o`0000go
oooo0_l000001?oooooo0000o`000?ooool4o`0000Oooooo0_l00004ooooo`Ko00000_ooool2o`00
00?ooooo4ol000000ooooooo0000o`000006o`000003ooooool0003o000000[ooooo0ol0000;oooo
o`;o00001_ooool2o`0001Gooooo0_l0000_ooooo`007?ooool00ol0003oooooooooo`11ooooo`;o
00000oooool2o`0000Kooooo1?l0000Kooooo`?o00001Oooool8o`000003ooooool0003o000000go
000000Coooooo`000?l0003o00001Oooool2o`0001gooooo0_l00002ooooo`;o00000_ooool2o`00
00?ooooo7?l000000ooooooo0000o`00000Hooooo`;o00001_ooool2o`0000Oooooo0_l00009oooo
o`;o000000?oooooo`000?l000002?ooool2o`0002Gooooo000Looooo`03o`000?oooooooooo03Go
oooo0_l00007ooooo`;o00003_ooool2o`00017ooooo0_l00006ooooo`;o00000_ooool3o`0000So
oooo1Ol000000ooooooo0000o`000004o`000003ooooool0003o000000Ko000000Coooooo`000?l0
003o00001Oooool2o`0000Gooooo0_l0000Jooooo`;o00001oooool=o`000003ooooool0003o0000
00co000000?oooooo`000?l000000_l00005ooooo`;o00001?ooool2o`0001[ooooo0_l00009oooo
o`;o00002oooool2o`0002Gooooo000Looooo`03o`000?oooooooooo02cooooo0_l00007ooooo`;o
00000oooool2o`0000;ooooo0_l0000Qooooo`;o00001_ooool2o`0000Gooooo1?l00002ooooo`So
000000?oooooo`000?l000003?l00002ooooo`;o00003?ooool2o`00017ooooo0_l00007ooooo`;o
00001?ooool4o`000003ooooool0003o000001[o000000?oooooo`000?l000001Oooool2o`0000Co
oooo1?l00003ooooo`;o00001?ooool3o`00013ooooo0_l00005ooooo`;o0000<_ooool001cooooo
0_l0000Kooooo`;o00001Oooool2o`0000Wooooo0ol0000;ooooo`;o00000oooool3o`000003oooo
ool0003o000002Cooooo0_l00003ooooo`_o000000?oooooo`000?l000003?l00002ooooo`?o0000
1oooool4o`0000_ooooo0_l00003ooooo`;o00001?ooool5o`0000cooooo9Ol00006ooooo`;o0000
1?ooool3o`0000;ooooo0_l00004ooooo`?o00001?ooool3o`0000Sooooo0ol0000iooooo`007?oo
ool00ol0003oooooooooo`0Jooooo`;o00001Oooool2o`0000[ooooo0_l00005ooooo`;o00000_oo
ool2o`000003ooooool0003o000000;ooooo1_l0000Vooooo`go00001?ooool;o`0000?ooooo0_l0
0008ooooo`Co00002oooool2o`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l000004?oo
oolLo`000003ooooool0003o000000;o00001_ooool2o`0000Gooooo0_l0000?ooooo`?o00002?oo
ool2o`0000Sooooo1?l0000^ooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00000_ooool2
o`0000;ooooo0_l000000ooooooo0000o`000008o`0001kooooo1?l00004ooooo`?o00000oooool4
o`0000Cooooo2ol000001Ooooooo0000o`000?l0003ooooo00;o00001_ooool3o`0000Oooooo0_l0
0003ooooo`;o00008ooooolOo`0000Cooooo0_l00007ooooo`;o00003?ooool2o`0000?ooooo0_l0
000Aooooo`Co0000;_ooool001cooooo00?o0000ooooooooool05oooool2o`0001Oooooo0_l00007
ooooo`;o00000_ooool2o`0002Cooooo1?l00004ooooo`;o00002?ooool2o`0000;ooooo2ol00002
ooooo`Go00000_ooool2o`0000;ooooo0ol00007ooooo`;o00000oooool2o`0000?ooooo0_l0000C
ooooo`Co00002?oooolNo`0000Cooooo0ol00003ooooo`;o00000oooool2o`0000Sooooo1?l00002
ooooo`?o00002?ooool2o`0003Wooooo000Looooo`03o`000?oooooooooo01Oooooo0_l0000<oooo
o`;o00002Oooool2o`0000Oooooo0_l000000ooooooo0000o`000005ooooo`;o00002_ooool2o`00
01[ooooo0_l00003ooooo`;o00000oooool2o`000003ooooool0003o000000Ko00000_ooool2o`00
00Cooooo0_l00003ooooo`;o00001oooool6o`0000Cooooo1?l000000ooooooo0000o`00000Coooo
o`Co00001?ooool2o`0000;ooooo6?l00007ooooo`;o00000_ooool2o`000003ooooool0003o0000
00;o00000oooool2o`0000Sooooo0_l00004ooooo`;o00002Oooool2o`0003Wooooo000Looooo`03
o`000?oooooooooo02Gooooo0_l0000Eooooo`;o00001?ooool3o`0000;ooooo0_l00005ooooo`?o
00007oooool4o`000004ooooool0003o0000ooooo`;o00000_ooool8o`0000?ooooo0_l0000=oooo
o`Ko00000oooool5o`0001Sooooo0_l00004ooooo`?o00000_ooool9o`000003ooooool0003o0000
00Wo00002Oooool3o`0000Cooooo1ol0000<ooooo`;o00003?ooool2o`0003[ooooo000Looooo`03
o`000?oooooooooo02[ooooo0_l00007ooooo`;o00002oooool4o`0000?ooooo0_l00005ooooo`;o
00000_ooool2o`0000gooooo0_l00002ooooo`;o00002oooool2o`0000;ooooo3?l00005ooooo`;o
000000?oooooo`000?l000004oooool2o`0000Cooooo0_l0000<ooooo`;o00003_ooool2o`0000;o
oooo0_l000000ooooooo0000o`00000@o`0000[ooooo0_l00005ooooo`;o000000Coooooo`000?l0
003o00003?ooool2o`0000;ooooo0_l00008ooooo`;o0000>_ooool001cooooo00?o0000oooooooo
ool07oooool2o`0000Wooooo0_l00007ooooo`;o00001oooool2o`0000;ooooo0_l0000@ooooo`;o
00003Oooool2o`0000;ooooo0_l0000>ooooo`Wo00001?ooool3o`0000Gooooo0_l0000Aooooo`;o
00001_ooool2o`0000;ooooo0_l00008ooooo`;o00005?ooool8o`000003ooooool0003o000000Ko
00004oooool2o`0000gooooo0_l00005ooooo`;o000000?oooooo`000?l00000@Oooool001cooooo
00?o0000ooooooooool07oooool2o`0001Kooooo0ol00002ooooo`;o000000?oooooo`000?l00000
=?ooool3o`0000;ooooo1?l00004ooooo`?o00000_ooool2o`0000Wooooo0_l00004ooooo`Co0000
00?oooooo`000?l000002_ooool2o`00013ooooo0ol0000;oooooa7o00004oooool2o`0000gooooo
0_l00008ooooo`;o00001Oooool2o`0000cooooo0_l0000/ooooo`007?ooool00ol0003ooooooooo
o`0gooooo`[o00003_ooool2o`0001Cooooo0_l0000@ooooo`?o00000_ooool2o`0000Gooooo1_l0
0009ooooo`;o00001?ooool4o`0000Wooooo0_l0000:ooooo`;o00002?ooool5o`0000Oooooo0_l0
00000ooooooo0000o`00000:o`0000Sooooo0_l00004ooooo`;o00001_ooool2o`0000Gooooo0_l0
000Aooooo`;o00001Oooool2o`0000cooooo0_l0000/ooooo`007?ooool00ol0003oooooooooo`0Y
ooooo`;o00002?ooool4o`0000;ooooo0ol000001?oooooo0000o`000?l0000?ooooo`?o00004ooo
ool5o`0000gooooo0ol0000:ooooo`Co00004Oooool2o`0000[ooooo0_l00004ooooo`;o00001?oo
ool4o`000003ooooool0003o000000Kooooo0_l00007ooooo`;o00000_ooool;o`000003ooooool0
003o000000Gooooo0_l00004ooooo`;o00001_ooool2o`000003ooooool0003o000000;ooooo0_l0
00000ooooooo0000o`00000Fooooo`;o00003?ooool2o`0002_ooooo000Looooo`03o`000?oooooo
oooo02Wooooo0_l00006ooooo`Ko00000_ooool2o`0001Gooooo0_l0000Eooooo`?o00001oooool2
o`000003ooooool0003o000000;ooooo0_l0000Gooooo`;o00000oooool5o`00013ooooo0_l00006
ooooo`;o000000Coooooo`000?l0003o00004_ooool;o`000003ooooool0003o000001Kooooo0_l0
0005ooooo`;o00000_ooool3o`0000Oooooo0_l00008ooooo`;o00003?ooool2o`0002_ooooo000L
ooooo`03o`000?oooooooooo037ooooo0_l00002ooooo`;o00006?ooool2o`0000;ooooo0_l0000=
ooooo`;o00003Oooool2o`000003ooooool0003o000000Oooooo0_l00009ooooo`;o00001oooool2
o`0000?ooooo1?l000000ooooooo0000o`00000<ooooo`;o00000_ooool2o`0000Cooooo0_l00002
ooooo`;o00004_ooool;o`0000;ooooo0_l0000;ooooo`Ko00002oooool2o`0000;ooooo0ol00007
ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0=Oooool2o`0001;ooooo0_l00004oooo
o`;o00000_ooool2o`0000gooooo0ol00003ooooo`;o00004oooool2o`0000;ooooo0ol00004oooo
o`;o00003Oooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000Kooooo0_l00002
ooooo`;o00001?ooool9o`0000gooooo1?l00003ooooo`Co00001?ooool2o`0000_ooooo1_l00003
ooooo`?o00002?ooool2o`0000Sooooo0_l00005ooooo`;o0000?Oooool001cooooo00?o0000oooo
ooooool09?ooool2o`0000oooooo0_l00002ooooo`;o00003_ooool2o`0000Kooooo0_l000000ooo
oooo0000o`00000=ooooo`;o00000oooool2o`0000cooooo0ol00008ooooo`?o00005_ooool2o`00
00;ooooo1Ol00006ooooo`;o00001?ooool2o`0000Cooooo1ol00004ooooo`;o00001oooool2o`00
027ooooo1Ol00004ooooo`Oo00000_ooool4o`000003ooooool0003o000000?ooooo1Ol0000loooo
o`007?ooool00ol0003oooooooooo`0Tooooo`;o00002oooool2o`0000;ooooo0_l00002ooooo`;o
00003_ooool4o`0000Cooooo0_l000000ooooooo0000o`00000=ooooo`;o00004Oooool5o`0000Go
oooo0_l0000Booooo`Co00000_ooool2o`0000Cooooo0_l00004ooooo`;o000000Coooooo`000?l0
003ooooo1Ol00006ooooo`;o000000?oooooo`000?l000001?ooool2o`0001cooooo0_l0000<oooo
o`Co00001Oooool4o`000003ooooool0003o000000;ooooo1?l00002ooooo`?o000000Coooooo`00
0?l0003ooooo0_l0000looooo`007?ooool2o`0003;ooooo0_l00007ooooo`;o00003Oooool4o`00
00Gooooo0_l0000?ooooo`;o00004oooool3o`0000Gooooo0_l00004ooooo`;o00000oooool2o`00
0003ooooool0003o000000Cooooo1?l00005ooooo`Co00001Oooool2o`0000Cooooo1?l00008oooo
o`Ko00007?ooool2o`0000;ooooo0_l00003ooooo`;o00001?ooool2o`0001?ooooo0_l00004oooo
o`?o000000?oooooo`000?l00000?oooool001cooooo00?o0000ooooooooool0>_ooool2o`0001Ko
oooo1Ol00008ooooo`;o00000_ooool2o`0000_ooooo0_l00004ooooo`;o00003_ooool2o`0000?o
oooo0_l000000ooooooo0000o`000006ooooo`;o00001Oooool4o`0000cooooo0_l00009ooooo`;o
000000Coooooo`000?l0003o00007?ooool2o`0000Oooooo0_l00004ooooo`;o00005?ooool2o`00
00Oooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`1Cooooo`Co00002?ooool2o`0000oo
oooo0_l00004ooooo`;o00001?ooool3o`0000cooooo0_l00007ooooo`;o00002Oooool2o`0000Wo
oooo0_l000000ooooooo0000o`000002o`0000cooooo0_l00002ooooo`;o00001Oooool4o`0000Go
oooo0_l0000@ooooo`;o00005?ooool2o`0000Cooooo0_l00004ooooo`;o00000_ooool2o`0003ko
oooo000Looooo`03o`000?oooooooooo02cooooo0_l00005ooooo`?o000000?oooooo`000?l00000
5oooool2o`0000oooooo0_l00005ooooo`;o00001?ooool2o`0000Gooooo0ol00004ooooo`Co0000
00?oooooo`000?l000000_l00006ooooo`;o00000oooool2o`000004ooooool0003o0000o`00017o
oooo1Ol00003ooooo`;o00002Oooool2o`000005ooooool0003o0000o`000?ooool00_l00005oooo
o`Co00001Oooool2o`0000Oooooo0_l00002ooooo`;o00000oooool2o`0001Cooooo0_l0000:oooo
o`?o000000?oooooo`000?l00000?_ooool001cooooo00?o0000ooooooooool0;?ooool2o`0000Go
oooo0ol000000ooooooo0000o`000002ooooo`;o00004oooool2o`0000Gooooo0_l00006ooooo`Go
00001?ooool2o`0000Cooooo0_l00005ooooo`;o00000_ooool2o`0000?ooooo0_l000000ooooooo
0000o`000002o`0000Gooooo0ol00003ooooo`Ko00001_ooool2o`0000Sooooo1Ol0000?ooooo`;o
00000_ooool3o`0000gooooo0_l00004ooooo`;o00001?ooool2o`000004ooooool0003o0000o`00
01Wooooo0_l00002ooooo`;o00001oooool4o`0003oooooo000Looooo`03o`000?oooooooooo037o
oooo0_l000000ooooooo0000o`000005ooooo`;o00002Oooool2o`0000oooooo0_l00006ooooo`;o
000000?oooooo`000?l000001?ooool2o`0000oooooo0_l0000?ooooo`;o00001Oooool2o`0000Wo
oooo0_l00008ooooo`;o00002_ooool2o`0000Oooooo0_l000001?oooooo0000o`000?l0000=oooo
o`;o00000_ooool4o`0000Oooooo0_l0000@ooooo`;o00001_ooool5o`000003ooooool0003o0000
00Gooooo0_l000001?oooooo0000o`000?l0000oooooo`007?ooool00ol0003oooooooooo`0aoooo
o`;o000000?oooooo`000?l000003oooool3o`0001cooooo0_l00008ooooo`Co00005oooool2o`00
00Kooooo1?l0000Booooo`;o00002Oooool2o`0000Cooooo0_l000000ooooooo0000o`000002oooo
o`;o00001oooool2o`0000Sooooo1?l00002ooooo`;o00002oooool2o`0000Sooooo0_l00006oooo
o`Go000000?oooooo`000?l000001Oooool2o`000003ooooool0003o0000043ooooo000Looooo`03
o`000?oooooooooo03Cooooo0_l00004ooooo`;o000000?oooooo`000?l000001_ooool2o`0000?o
oooo0_l0000Hooooo`;o000000?oooooo`000?l000000oooool6o`0000;ooooo1?l000000ooooooo
0000o`000003ooooo`;o00002Oooool2o`0000Kooooo1?l0000Booooo`?o00003_ooool2o`0000Wo
oooo0_l00003ooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`;o000000Coooooo`00
0?l0003o00002oooool3o`0000Gooooo0_l00008ooooo`;o00002_ooool2o`0000;ooooo0_l00010
ooooo`007?ooool00ol0003oooooooooo`0jooooo`;o000000?oooooo`000?l000002Oooool4o`00
00[ooooo0_l0000?ooooo`;o00000oooool2o`0000Cooooo1_l000000ooooooo0000o`000002o`00
0003ooooool0003o000000;o00004?ooool2o`0000cooooo0_l00006ooooo`;o00002?ooool4o`00
00?ooooo1?l00005ooooo`?o00001oooool4o`000004ooooool0003o0000ooooo`Go00002_ooool2
o`000003ooooool0003o000000Gooooo0_l0000>ooooo`;o00001?ooool2o`0000?ooooo0_l0000o
ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00001oooool3o`0000Gooooo0_l00006oooo
o`;o00003?ooool2o`0000;ooooo0_l0000Cooooo`;o000000?oooooo`000?l000001oooool2o`00
00;ooooo1?l00007ooooo`;o00001oooool2o`0000Sooooo0_l000000ooooooo0000o`000003oooo
o`;o00000oooool4o`0000Cooooo1?l00003ooooo`Co00001Oooool2o`0000?ooooo0ol000000ooo
oooo0000o`000003o`0000Kooooo0_l0000;ooooo`?o00001Oooool2o`0000Gooooo0_l00002oooo
o`;o00001Oooool4o`0000Oooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o
00001?ooool2o`000004ooooool0003o0000o`0000Gooooo0_l0000Booooo`;o00001?ooool2o`00
01?ooooo0_l00005ooooo`;o00001_ooool5o`0000Oooooo0_l00007ooooo`;o00002?ooool4o`00
00Cooooo0_l00003ooooo`Co00001?ooool2o`0000Kooooo0_l00006ooooo`;o00000oooool3o`00
0004ooooool0003o0000o`0000Sooooo0_l0000<ooooo`?o00000_ooool4o`0000Gooooo0_l00002
ooooo`;o00001oooool2o`000003ooooool0003o000004Gooooo000Looooo`03o`000?oooooooooo
03Gooooo0_l00005ooooo`;o00000_ooool2o`0000Gooooo0_l00003ooooo`;o00001_ooool5o`00
00gooooo0_l0000<ooooo`Co00000oooool2o`000003ooooool0003o000000?o00000oooool2o`00
00[ooooo0_l00007ooooo`;o00000_ooool2o`0002;ooooo0ol00004ooooo`;o00001_ooool2o`00
00?ooooo0_l000000ooooooo0000o`000002o`0000Oooooo1_l00006ooooo`?o000000?oooooo`00
0?l000000_l00005ooooo`Ko00000_ooool2o`00047ooooo000Looooo`03o`000?oooooooooo037o
oooo0_l00009ooooo`?o000000?oooooo`000?l000001Oooool2o`0000?ooooo1?l00005ooooo`Co
00003Oooool2o`0000cooooo0_l00005ooooo`;o00000oooool2o`0000Cooooo0_l00009ooooo`Ko
00001?ooool2o`0000?ooooo0_l0000Qooooo`?o00001?ooool2o`0000?ooooo0_l000000ooooooo
0000o`000003ooooo`;o000000?oooooo`000?l000000ol00003ooooo`Co000000?oooooo`000?l0
00002?ooool8o`0000Cooooo1Ol00004ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0
<Oooool2o`0000[ooooo0_l0000>ooooo`?o00005oooool2o`0000_ooooo0_l00004ooooo`;o0000
0_ooool4o`0000oooooo1_l00009ooooo`;o00002_ooool2o`0000Sooooo0_l0000<ooooo`;o0000
2Oooool2o`0000;ooooo1_l000000ooooooo0000o`000003o`0000?ooooo1?l000000ooooooo0000
o`000007ooooo`Go00000oooool2o`0000?ooooo1_l00016ooooo`0000Koooooonk^k_lb<S;o0000
oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000oooo
ooooool0:_ooool2o`00027ooooo0_l0000Hooooo`;o00002?ooool2o`000003ooooool0003o0000
00Cooooo0_l00002ooooo`?o00004oooool2o`0000?ooooo0_l0000Aooooo`;o00002?ooool2o`00
00;ooooo0_l00008ooooo`;o00001Oooool2o`000003ooooool0003o000000?ooooo1_l000000ooo
oooo0000o`000004o`0000Cooooo0_l0000:ooooo`?o00001Oooool2o`000003ooooool0003o0000
00Ko0000A_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEE
ogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo02[ooooo0_l0000Cooooo`;o00004_oo
ool2o`0000Cooooo0_l0000?ooooo`;o00001?ooool3o`0000;ooooo0_l00002ooooo`Go000000?o
ooooo`000?l000001?l0000Dooooo`;o00003oooool2o`0000kooooo0_l00008ooooo`;o00001?oo
ool3o`000004ooooool0003o0000o`0000Gooooo0_l00004ooooo`Co00002oooool2o`0000kooooo
1?l000001?oooooo0000o`000?l00016ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooo
ooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0oooooo`;o
00004_ooool3o`0000?ooooo0_l0000?ooooo`;o000000?oooooo`000?l000000ol00002oooooa?o
00002Oooool2o`0000oooooo0_l000000ooooooo0000o`000003ooooo`?o00001?ooool2o`00013o
oooo1_l00002ooooo`;o00000oooool3o`0000cooooo0_l0000;ooooo`;o00001oooool2o`0000Oo
oooo0_l000001?oooooo0000o`000?l00016ooooo`0000?oooooo`000?ooool00_ooool00ol0003o
ooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0003gooooo0_l0000Aoooo
o`;o00000_ooool2o`0000Gooooo1?l0000>oooooaOo000000?oooooo`000?l000002Oooool2o`00
00gooooo1?l000000ooooooo0000o`000002ooooo`?o00001Oooool2o`0000?ooooo0_l00004oooo
o`Co00000oooool3o`000003ooooool0003o000000Gooooo0_l000000ooooooo0000o`00000<oooo
o`;o00002?ooool2o`0000Gooooo0_l00003ooooo`;o00001oooool2o`0004[ooooo00000ooooooo
0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006oooo
o`03o`000?oooooooooo03Wooooo0_l00002ooooo`;o00004Oooool2o`000003ooooool0003o0000
00Kooooo1?l000000ooooooo0000o`00000>oooooaKo00000oooool2o`0000;ooooo0ol0000;oooo
o`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`00
00?ooooo0ol00004ooooo`Co00002Oooool2o`000003ooooool0003o000000;o00002Oooool4o`00
00;ooooo1ol00003ooooo`;o00001Oooool2o`0000;ooooo0ol00005ooooo`;o0000C?ooool00003
ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03
o`000?oooooooooo03Wooooo0_l0000?ooooo`?o00000oooool2o`000003ooooool0003o000000Co
oooo0_l00005ooooo`;o00000_ooool4o`0000Cooooo0_l00003oooooa;o000000?oooooo`000?l0
00000oooool8o`0000[ooooo0_l00006ooooo`;o00000oooool2o`000003ooooool0003o000000Co
00000oooool2o`0000;ooooo0_l0000>ooooo`;o000000?oooooo`000?l000002oooool4o`0000Co
oooo1Ol00005ooooo`?o00000_ooool2o`0000;ooooo0ol00005ooooo`;o00006?ooool2o`0003;o
oooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0
003oooooooooo`0dooooo`;o00003Oooool2o`0000Gooooo0ol00003ooooo`;o00001oooool4o`00
00?ooooo0_l00002ooooo`Go00000oooool2o`0000?ooooo4Ol00002ooooo`;o00001Oooool2o`00
00;ooooo0_l00003ooooo`;o00001_ooool2o`0000Sooooo1?l000000ooooooo0000o`000002o`00
00Gooooo0_l00002ooooo`;o00007Oooool2o`00017ooooo0ol0000Xooooo`;o0000<_ooool00006
ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oo
oooooooo03?ooooo0ol0000:ooooo`;o000000?oooooo`000?l000000_ooool2o`00017ooooo0ol0
0003ooooo`;o00001Oooool2o`000004ooooool0003o0000oooooaWo00001Oooool2o`0000Oooooo
0_l00006ooooo`Co00001_ooool4o`000003ooooool0003o000000Oooooo0_l0000Booooo`;o0000
1?ooool2o`0000Oooooo0_l00006ooooo`?o00002Oooool2o`0000kooooo0_l00009ooooo`;o0000
@Oooool001cooooo00?o0000ooooooooool0<_ooool3o`0000Kooooo0_l00003ooooo`;o00000ooo
ool4o`0000gooooo0_l00002ooooo`;o00000oooool2o`0000Wooooo0_l000000ooooooo0000o`00
000:o`000003ooooool0003o000000[o00001Oooool2o`00017ooooo0_l000000ooooooo0000o`00
000;ooooo`;o00001oooool4o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l00000
1?ooool2o`0000Cooooo0_l0000?ooooo`?o00002Oooool4o`0000Oooooo0_l00003ooooo`;o0000
00?oooooo`000?l000001_ooool2o`00047ooooo000Looooo`03o`000?oooooooooo03;ooooo0_l0
0007ooooo`;o00002?ooool2o`0000oooooo0_l00007ooooo`;o00003OoooolLo`0000?ooooo0_l0
000Booooo`;o00002?ooool5o`0000Cooooo0_l000000ooooooo0000o`00000<o`0000?ooooo0_l0
000Gooooo`?o00002Oooool2o`0000Kooooo0ol000000ooooooo0000o`000003ooooo`;o00005?oo
ool2o`0003?ooooo000Looooo`03o`000?oooooooooo06[ooooo8?l00003ooooo`;o00007?ooool7
o`000003ooooool0003o000000[o000000?oooooo`000?l000000ol00003ooooo`;o00003_ooool2
o`000003ooooool0003o000000Cooooo1?l00008ooooo`;o00001_ooool3o`000003ooooool0003o
000000Sooooo0_l0000?ooooo`;o0000<oooool001cooooo00?o0000ooooooooool0=oooool4o`00
00kooooo0_l0000Ooooooago00004?ooool2o`0000oooooo0_l00003oooooaCo000000?oooooo`00
0?l000000_l00005ooooo`;o00002oooool2o`000003ooooool0003o000000Kooooo0_l00008oooo
o`;o00001oooool2o`0000;ooooo1?l00005ooooo`;o000000?oooooo`000?l00000@Oooool001co
oooo00?o0000ooooooooool0=oooool4o`0000Gooooo0_l00007ooooo`;o00005?ooool5o`0000So
oooo7?l00003ooooo`;o000000?oooooo`000?l000001_ooool6o`0000cooooo0_l00003oooooaWo
000000Goooooo`000?l0003o0000ooooo`02o`0000cooooo0_l00003ooooo`;o00003?ooool2o`00
00Kooooo0_l00004ooooo`Co00002?ooool2o`00047ooooo000Looooo`03o`000?oooooooooo037o
oooo0_l0000;ooooo`Co00000oooool4o`0001Kooooo1Ol00006oooooako00000oooool2o`000003
ooooool0003o000000Kooooo0_l000001?oooooo0000o`000?l00008ooooo`;o00000_ooool2o`00
00Gooooo6ol0000?ooooo`;o00000oooool2o`0000;ooooo0_l00008ooooo`;o00000_ooool2o`00
0004ooooool0003o0000o`0005?ooooo000Looooo`03o`000?oooooooooo037ooooo0_l0000;oooo
o`;o00001Oooool4o`00013ooooo0_l00005ooooo`;o00002?ooool@o`000003ooooool0003o0000
00[o00001_ooool2o`0000[ooooo0_l00005ooooo`;o00000_ooool2o`0000;ooooo5Ol000000ooo
oooo0000o`000009o`0000Cooooo0_l0000Cooooo`;o00003?ooool6o`000003ooooool0003o0000
00Kooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o00000_ooool3o`0000Go
oooo0_l00002ooooo`;o00000_oooolBo`000003ooooool0003o000000[o00001?ooool4o`0000[o
oooo1?l00003ooooo`;o000000?oooooo`000?l000000ooooolSo`0000;ooooo0_l0000Rooooo`;o
000000Coooooo`000?l0003ooooo0_l00006ooooo`;o0000B?ooool001cooooo00?o0000oooooooo
ool0>Oooool4o`0001Oooooo0_l00002ooooo`;o00002_ooool2o`0000;ooooo7_l00003ooooo`Co
00003?ooool4o`0000Kooooo0_l00005ooooob7o00006Oooool2o`0000_ooooo0_l0000:ooooo`?o
00001oooool2o`00043ooooo000Looooo`03o`000?oooooooooo03Wooooo1?l0000Hooooo`;o0000
00?oooooo`000?l000000oooool2o`0000Oooooo0_l000000ooooooo0000o`00000Lo`0000;ooooo
0_l000000ooooooo0000o`000009ooooo`;o00004OoooolQo`0000;ooooo0_l00007ooooo`;o0000
0oooool4o`0000?ooooo1?l00006ooooo`;o00003oooool3o`0000Gooooo1?l00005ooooo`;o0000
>Oooool001cooooo00?o0000ooooooooool0@oooool2o`00013ooooo0_l00006ooooo`;o00001_oo
oolRo`0000Gooooo0_l00009ooooo`;o00003Oooool3o`000003ooooool0003o000001ko00000ooo
ool3o`0000Kooooo1?l000000ooooooo0000o`000002o`0000?ooooo0_l00008ooooo`;o00001_oo
ool4o`0000gooooo0_l00007ooooo`;o0000>Oooool001cooooo0_l0000looooo`;o00001_ooool2
o`0000cooooo0_l00003ooooo`;o00003Oooool2o`000003ooooool0003o000001go00000oooool2
o`0000;ooooo0_l00009ooooo`;o00002ooooolRo`0000Kooooo0_l00008ooooo`;o00000_ooool2
o`0000kooooo0_l00006ooooo`Co00001?ooool2o`0000Wooooo0_l00010ooooo`007?ooool00ol0
003oooooooooo`0kooooo`;o00002oooool2o`0000Oooooo0_l00003ooooo`;o00002Oooool2o`00
00Kooooo7_l00003ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000Kooooo0_l00008
ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`_o000000?oooooo`000?l000003Ol0
0006ooooo`;o00000oooool2o`0000Oooooo0_l000000ooooooo0000o`000009ooooo`Co00002?oo
ool2o`0000?ooooo0ol00009ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0B?ooool2
o`0000_ooooo0_l00002ooooo`;o00001_ooool7o`000003ooooool0003o000001So00002?ooool8
o`00013ooooo0_l000000ooooooo0000o`000003o`0000;ooooo6ol0000;ooooo`;o00000_ooool2
o`0000?ooooo0_l000000ooooooo0000o`000009ooooo`;o00002_ooool4o`000003ooooool0003o
000000Kooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0dooooo`;o00002oooool2o`00
00?ooooo0_l0000=ooooo`;o00000_ooool2o`0000Sooooo1Ol000000ooooooo0000o`00000Jo`00
00?ooooo1Ol000001?oooooo0000o`000?l0000Gooooo`?o00000_oooolJo`0000?ooooo0_l0000;
ooooo`;o00001Oooool2o`0000;ooooo0ol000000ooooooo0000o`000002ooooo`;o00002oooool4
o`0000Sooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0dooooo`;o00002oooool2o`00
00?ooooo0_l00005ooooo`Co00001_ooool2o`0000?ooooo0_l00008oooooa_o00000_ooool2o`00
00?ooooo0ol00003ooooo`Co00001Oooool4o`0000Cooooo0_l00007ooooo`?o00000_ooool<o`00
0003ooooool0003o000000_o00000oooool4o`00013ooooo0_l00002ooooo`?o000000?oooooo`00
0?l000002oooool2o`0000Cooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o
00001oooool4o`0000Kooooo1?l000000ooooooo0000o`000009oooooa;o000000?oooooo`000?l0
00002Ol00008ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000004o`00
00?ooooo0_l00007ooooo`Co000000?oooooo`000?l000006Ol00004ooooo`;o000000?oooooo`00
0?l000008Oooool3o`0000gooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o
00004Oooool4o`0000[ooooo1?l000000ooooooo0000o`00000=o`000003ooooool0003o000000Co
000000?oooooo`000?l000001?ooool2o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l0
00000_ooool2o`000003ooooool0003o000000Sooooo1_l000000ooooooo0000o`00000Ho`0000Oo
oooo0_l0000;ooooo`;o00005?ooool3o`0000[ooooo0_l000000ooooooo0000o`000015ooooo`00
7?ooool00ol0003oooooooooo`1Tooooo`?o00000_oooolGo`0000Oooooo0_l00004ooooo`;o0000
0_ooool3o`0000?ooooo0_l00003ooooo`?o00002?ooool2o`0000;ooooo0_l000000ooooooo0000
o`00000Fo`0000oooooo1?l000000ooooooo0000o`000002o`0001Gooooo0_l00003ooooo`;o0000
1Oooool2o`0004Sooooo000Looooo`03o`000?oooooooooo03oooooo0_l0000Oooooo`;o00000_oo
ool2o`0000;ooooo2?l000000ooooooo0000o`00000=o`0000gooooo0_l00002ooooo`?o00000ooo
ool2o`0000?ooooo0_l0000@oooooaSo00003oooool4o`000003ooooool0003o000001cooooo0_l0
0003ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0?oooool2o`0001oooooo0_l00002
ooooo`;o00000_ooool2o`000003ooooool0003o000000So000000?oooooo`000?l000001ol00002
ooooo`?o00004oooool2o`0000Sooooo0_l00004ooooo`;o00001OoooolCo`000003ooooool0003o
000000;o000000?oooooo`000?l000004Oooool2o`0000Gooooo0_l00003ooooo`;o00005Oooool2
o`0004[ooooo000Looooo`03o`000?oooooooooo04oooooo0ol00003ooooo`;o00001oooool2o`00
00Cooooo1_l000001?oooooo0000o`000?ooool=o`0000;ooooo0_l00002ooooo`?o00004oooool2
o`0000?ooooo0_l00003ooooo`;o00001?ooool2o`0000Gooooo0_l000000ooooooo0000o`00000F
o`0001Sooooo0_l000000ooooooo0000o`000002o`0000Kooooo0_l00008ooooo`;o000000Cooooo
o`000?l0003ooooo0_l00019ooooo`007?ooool00ol0003oooooooooo`1?ooooo`?o00000oooool2
o`0000Gooooo1?l00004ooooo`Wo000000?oooooo`000?l000002ol00002ooooo`?o00001oooool2
o`0000[ooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo0_l0000<
ooooo`_o00000_ooool9o`0000;ooooo0_l0000Iooooo`;o00001Oooool2o`000003ooooool0003o
000000Sooooo0_l000001?oooooo0000o`000?ooool2o`0004Wooooo000Looooo`03o`000?oooooo
oooo03Wooooo0_l0000Qooooo`;o00001_ooool7o`000003ooooool0003o000000?o000000?ooooo
o`000?l000002?l00002ooooo`;o00001oooool2o`0000?ooooo0_l00005ooooo`;o00001oooool2
o`000003ooooool0003o000000;ooooo0_l0000=ooooo`?o000000?oooooo`000?l000001?l00000
0ooooooo0000o`000002o`0000;ooooo0_l00004ooooo`;o00000oooool2o`0000Sooooo0_l00009
ooooo`;o00001_ooool2o`0000oooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`0ioooo
o`;o00005_ooool2o`0000Wooooo0_l00004ooooo`Co000000?oooooo`000?l000000oooool5o`00
00;ooooo2Ol00009ooooo`;o00001Oooool2o`0000kooooo0_l000001?oooooo0000o`000?l00005
ooooo`;o00000oooool2o`0000Gooooo0_l000000ooooooo0000o`000004o`000004ooooool0003o
0000o`0000Sooooo0_l00002ooooo`Co00002?ooool4o`0000Oooooo0_l0000Gooooo`Co0000BOoo
ool001cooooo00?o0000ooooooooool0DOooool2o`0000_ooooo0_l00002ooooo`So00002?ooool2
o`0000;ooooo1?l00008ooooo`;o000000?oooooo`000?l000006?ooool3o`0000Gooooo1?l00000
0ooooooo0000o`000002ooooo`Go00000_ooool4o`0000;ooooo0_l00009ooooo`;o00000_ooool3
o`0000_ooooo0_l0000Rooooo`;o0000BOooool001cooooo00?o0000ooooooooool0GOooool3o`00
00Gooooo1Ol00008ooooo`;o000000?oooooo`000?l000002oooool2o`0000Wooooo0_l0000Aoooo
o`;o00001oooool2o`0000Gooooo1ol00006ooooo`;o00003_ooool2o`0000Kooooo0ol00008oooo
o`;o00004Oooool4o`0005;ooooo000Looooo`;o0000@?ooool2o`0001cooooo0_l00006ooooo`;o
00002oooool5o`0000Cooooo0_l0000@ooooo`;o00000_ooool2o`0000gooooo0_l000000ooooooo
0000o`000002ooooo`;o00002?ooool6o`0000Oooooo1_l0000;ooooo`;o00001?ooool3o`000003
ooooool0003o000000Gooooo0_l0000Aooooo`Co0000D_ooool001cooooo00?o0000ooooooooool0
>oooool2o`0000;ooooo0_l0000aooooo`Go00001?ooool2o`0000?ooooo0_l00003ooooo`?o0000
1Oooool2o`0000;ooooo0_l00003ooooo`;o00001oooool2o`0000;ooooo0_l00002ooooo`;o0000
0_ooool2o`0000[ooooo1?l00003ooooo`Ko00001oooool2o`0000;ooooo0_l00008ooooo`;o0000
1?ooool2o`0000[ooooo0_l00004ooooo`;o00002?ooool2o`0004cooooo000Looooo`03o`000?oo
oooooooo03_ooooo0_l0000Yooooo`;o00003Oooool2o`0000Wooooo0_l00003ooooo`?o00000_oo
ool2o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o00001oooool4o`000003ooooool0
003o000000Gooooo0_l0000:ooooo`Co000000?oooooo`000?l000000_ooool2o`0000Wooooo0_l0
000?ooooo`Go00000_ooool2o`0000Gooooo0ol00004ooooo`;o00001Oooool2o`000003ooooool0
003o000004cooooo000Looooo`03o`000?oooooooooo05oooooo0_l00005ooooo`;o00001_ooool2
o`0000Gooooo0_l0000=ooooo`;o00000_ooool4o`0000;ooooo0_l000000ooooooo0000o`00000>
ooooo`;o000000?oooooo`000?l000005_ooool2o`0000;ooooo0_l0000Fooooo`;o00000_ooool3
o`0000Cooooo0ol00004ooooo`;o00000oooool2o`0000Oooooo0_l0001?ooooo`007?ooool00ol0
003oooooooooo`1Oooooo`;o000000?oooooo`000?l000000_ooool2o`0000Kooooo1?l0000;oooo
o`;o00001Oooool2o`0000;ooooo0_l0000Kooooo`;o00001_ooool3o`00013ooooo0_l0000Foooo
o`;o00000_ooool2o`0000Kooooo0_l00009ooooo`;o00001Oooool2o`00057ooooo000Looooo`03
o`000?oooooooooo063ooooo1?l00002ooooo`;o00002?ooool2o`0000Wooooo1?l000000ooooooo
0000o`000002ooooo`Co00007Oooool2o`0000Kooooo0ol00002ooooo`;o00000oooool2o`000003
ooooool0003o000000;ooooo0_l0000Qooooo`;o00002_ooool2o`0000Oooooo0_l0001Aooooo`00
7?ooool00ol0003oooooooooo`1Mooooo`;o000000Coooooo`000?l0003ooooo0_l00008ooooo`;o
00003?ooool2o`0000;ooooo0ol00004ooooo`;o00001_ooool2o`0001Gooooo0_l0000;ooooo`;o
00000oooool2o`000003ooooool0003o000000;ooooo0_l0000Qooooo`;o00002_ooool2o`0000Oo
oooo0_l00003ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0GOooool5o`000003oooo
ool0003o000000Sooooo0_l00009ooooo`;o00001Oooool2o`0000_ooooo1?l0000Fooooo`?o0000
0_ooool3o`0000Sooooo0_l0000Gooooo`;o00000_ooool2o`000003ooooool0003o000000Oooooo
0_l00009ooooo`;o00003oooool2o`0004cooooo000Looooo`03o`000?oooooooooo05[ooooo0_l0
00000ooooooo0000o`000003o`0000?ooooo0_l00006ooooo`;o000000?oooooo`000?l000001_oo
ool2o`0000Cooooo0_l0000;ooooo`Go00005_ooool3o`0000;ooooo1ol00004ooooo`?o00002Ooo
ool2o`0000_ooooo1_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000002Ooo
ool2o`0005gooooo000Looooo`03o`000?oooooooooo04Kooooo0_l0000Booooo`?o00002?ooool3
o`0000Gooooo0_l000000ooooooo0000o`000007ooooo`;o00000oooool2o`0000_ooooo0_l00002
ooooo`;o00000oooool2o`0001Gooooo1ol00005ooooo`;o00002Oooool2o`0000gooooo0_l00009
ooooo`;o00001oooool2o`0000Gooooo0_l00008ooooo`;o0000DOooool001cooooo00?o0000oooo
ooooool0A_ooool2o`0001?ooooo0_l00009ooooo`;o00001Oooool2o`000003ooooool0003o0000
00Oooooo0_l00003ooooo`;o00001_ooool2o`0000Oooooo0_l00003ooooo`?o00005Oooool2o`00
00Kooooo0_l0000Zooooo`Co000000?oooooo`000?l000001Oooool2o`0000Kooooo1?l0001Aoooo
o`007?ooool00ol0003oooooooooo`1]ooooo`;o000000?oooooo`000?l000005?ooool2o`0000co
oooo0ol0000Eooooo`;o00001?ooool4o`0000Gooooo0_l00004ooooo`;o000000?oooooo`000?l0
00001_ooool2o`0000Cooooo0_l0000<ooooo`Co00001_ooool4o`0000Kooooo0_l0001Cooooo`00
7?ooool00ol0003oooooooooo`1jooooo`;o00000oooool2o`0000oooooo0_l00007ooooo`;o0000
1Oooool4o`0000Gooooo0_l00007ooooo`;o00001oooool2o`0000Cooooo0_l000000ooooooo0000
o`000003ooooo`;o000000?oooooo`000?l000001?ooool5o`0000;ooooo0_l0000?ooooo`Co0000
Foooool001cooooo00?o0000ooooooooool0D?ooool2o`0001Kooooo0_l0000@ooooo`;o000000?o
ooooo`000?l000000_l0000:ooooo`;o00000oooool2o`000003ooooool0003o000000Cooooo0_l0
0005ooooo`Co00001Oooool2o`0001kooooo0_l00009ooooo`?o00000_ooool2o`0006kooooo000L
ooooo`03o`000?oooooooooo053ooooo0_l0000?ooooo`;o00001Oooool4o`0000[ooooo0_l00002
ooooo`;o000000Coooooo`000?l0003o00001Oooool2o`000004ooooool0003o0000ooooo`;o0000
1_ooool2o`0000Gooooo0_l0000Zooooo`;o00005?ooool2o`0000?ooooo0_l0001Vooooo`007?oo
ool00ol0003oooooooooo`1Qooooo`;o000000?oooooo`000?l000001_l00004ooooo`;o00000_oo
ool4o`0000Wooooo0_l00002ooooo`;o000000?oooooo`000?l000001oooool2o`0000Oooooo0_l0
00000ooooooo0000o`000004ooooo`;o00008Oooool2o`0000Kooooo1Ol00009ooooo`;o00000ooo
ool2o`0006Kooooo000Looooo`;o0000IOooool4o`0000Sooooo0_l00002ooooo`Co00000oooool2
o`0000Cooooo0_l00005ooooo`;o00001oooool2o`0000Wooooo0ol00004ooooo`;o00001?ooool2
o`0000Wooooo0_l00006ooooo`;o00004?ooool5o`00017ooooo0_l0001Sooooo`007?ooool00ol0
003oooooooooo`1Uooooo`;o00003oooool2o`0000?ooooo0_l0000;ooooo`?o00004Oooool2o`00
00_ooooo0_l00009ooooo`;o00001_ooool2o`0000kooooo0_l00005ooooo`Co00003Oooool2o`00
06?ooooo000Looooo`03o`000?oooooooooo06Gooooo0_l00004ooooo`;o00002_ooool2o`0000co
oooo0_l00002ooooo`;o00004?ooool5o`0001gooooo0_l000000ooooooo0000o`00000:ooooo`;o
00001Oooool4o`0007;ooooo000Looooo`03o`000?oooooooooo06_ooooo0_l0000:ooooo`;o0000
2_ooool4o`0000Kooooo0_l00008ooooo`;o00000_ooool5o`0001gooooo0_l000000ooooooo0000
o`000009ooooo`;o00000oooool2o`0000[ooooo0_l0001[ooooo`007?ooool00ol0003ooooooooo
o`19ooooo`;o00007Oooool2o`00017ooooo0_l00004ooooo`Go00001oooool3o`0000Oooooo0_l0
0005ooooo`;o00003oooool2o`000004ooooool0003o0000o`0000Sooooo0_l00002ooooo`;o0000
2?ooool2o`0000?ooooo0_l0000:ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o0000
H?ooool001cooooo00?o0000ooooooooool0BOooool2o`0001gooooo0_l0000Aooooo`;o00001?oo
ool2o`0000[ooooo0ol00003ooooo`?o00002?ooool4o`0000gooooo1_l00008ooooo`Ko00001Ooo
ool2o`0000[ooooo0_l00009ooooo`Co00001?ooool2o`00063ooooo000Looooo`03o`000?oooooo
oooo05Wooooo0_l0000>ooooo`;o00001oooool2o`0000Wooooo0_l00005ooooo`;o00002oooool5
o`0000Wooooo0ol00008ooooo`;o00001Oooool2o`0000[ooooo1?l00005ooooo`Co00002_ooool2
o`0000cooooo0_l0001Uooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o00001?ooool2o`00
00Sooooo0_l00007ooooo`;o00002?ooool3o`0000Gooooo0_l0000;ooooo`;o00001_ooool2o`00
00Cooooo1?l00007ooooo`;o00006_ooool2o`000003ooooool0003o000000Wooooo0_l00004oooo
o`;o00001_ooool2o`0000gooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`1Oooooo`;o
00004Oooool2o`0000;ooooo0_l00004ooooo`;o00006oooool2o`0000Cooooo1?l00004ooooo`;o
00008?ooool2o`0000Wooooo0_l00004ooooo`;o00005Oooool2o`0005Kooooo000Looooo`03o`00
0?oooooooooo06Wooooo0_l00002ooooo`;o00000oooool3o`000003ooooool0003o000000Cooooo
0_l0000Qooooo`Go00000oooool2o`0000?ooooo0_l0000<ooooo`;o00005_ooool4o`0007?ooooo
000Looooo`03o`000?oooooooooo05Cooooo0_l0000Cooooo`;o00000_ooool2o`0000Cooooo0_l0
0007ooooo`;o00000oooool2o`0000kooooo0_l0000<ooooo`Ko00001oooool2o`0000_ooooo0ol0
0002ooooo`;o00001Oooool2o`0000_ooooo0ol0001dooooo`007?ooool00ol0003oooooooooo`1D
ooooo`;o00004?ooool2o`0000Kooooo1?l0000?ooooo`;o00003_ooool3o`0000;ooooo0_l00006
ooooo`;o00000oooool2o`0000oooooo0_l00003ooooo`?o000000Coooooo`000?l0003o00001Ooo
ool2o`0000Cooooo1?l00004ooooo`?o00000oooool2o`0006kooooo000Looooo`03o`000?oooooo
oooo06Kooooo0_l00006ooooo`Co00005?ooool2o`0000Oooooo1_l000000ooooooo0000o`000006
ooooo`;o00001_ooool2o`0000cooooo1?l00002ooooo`;o000000?oooooo`000?l000000_ooool2
o`0000Sooooo1?l00005ooooo`;o00000oooool2o`0006kooooo000Looooo`03o`000?oooooooooo
06Oooooo0_l00007ooooo`;o00002Oooool2o`0000Wooooo0_l00007ooooo`?o000000?oooooo`00
0?l000001Oooool2o`0000[ooooo0_l00004ooooo`;o00002?ooool2o`0000;ooooo0_l000001Ooo
oooo0000o`000?l0003ooooo00;o00004_ooool2o`0000Oooooo0_l0001Yooooo`0000Koooooonk^
k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo
00?o0000ooooooooool0IOooool4o`0000Oooooo0_l00009ooooo`;o00005_ooool2o`0000;ooooo
0_l000000ooooooo0000o`00000=ooooo`Oo00002_ooool2o`0000;ooooo0_l000000ooooooo0000
o`00000Booooo`;o00001oooool2o`0006Wooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Go
oooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1Soooo
o`Co00002?ooool2o`0000oooooo0_l0000Cooooo`Co000000?oooooo`000?l000001oooool2o`00
00Cooooo0ol00002ooooo`;o00002?ooool4o`000004ooooool0003o0000ooooo`?o00000_ooool2
o`0008;ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo06?ooooo0_l00008ooooo`Co00003oooool2
o`0001?ooooo0ol00007ooooo`;o00000_ooool2o`00013ooooo0_l000000ooooooo0000o`000003
ooooo`;o000000?oooooo`000?l000000_ooool3o`0008;ooooo00000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000KOooool2
o`0001kooooo0_l00006ooooo`;o00002?ooool2o`0001Cooooo0_l00004ooooo`;o00001Oooool4
o`0008?ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Goc<c<o`00
0?l0003o0000olc<c006ooooo`03o`000?oooooooooo06gooooo0_l00009ooooo`?o000000?ooooo
o`000?l000003?ooool2o`000003ooooool0003o000002Kooooo0_l00004ooooo`Co00000oooool2
o`0000Kooooo0_l0001mooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09oooo
o`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`1hooooo`?o000000?ooooo
o`000?l000003?ooool2o`000003ooooool0003o000000Gooooo0_l0000Uooooo`Co00002oooool2
o`0007gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zj
o`000006ooooo`03o`000?oooooooooo07Wooooo0_l0000:ooooo`;o00001_ooool2o`000003oooo
ool0003o000000;ooooo0_l0000Hooooo`;o000000?oooooo`000?l000008?ooool2o`0007Cooooo
00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06oooo
o`03o`000?oooooooooo06kooooo0_l00009ooooo`;o00002Oooool4o`0000Sooooo0_l00004oooo
o`;o00001_ooool2o`0000Gooooo0_l00007ooooo`;o000000?oooooo`000?l000008?ooool2o`00
07Cooooo000Looooo`03o`000?oooooooooo06kooooo0_l00002ooooo`;o00002?ooool2o`0000Ko
oooo1?l00008ooooo`;o00001?ooool2o`0000Kooooo0_l00005ooooo`;o00001?ooool2o`0002Ko
oooo0_l0001dooooo`007?ooool00ol0003oooooooooo`1^ooooo`;o00000_ooool2o`0000Sooooo
0_l0000Booooo`;o00000oooool2o`0000kooooo0_l00004ooooo`;o00004oooool2o`0000Oooooo
0ol0001mooooo`007?ooool00ol0003oooooooooo`2@ooooo`;o00000oooool2o`0000?ooooo0_l0
0003ooooo`;o00000oooool2o`0000?ooooo0_l0000;ooooo`;o00002?ooool2o`0000;ooooo0_l0
0003ooooo`?o0000OOooool001cooooo00?o0000ooooooooool0S?ooool2o`0000cooooo0_l00003
ooooo`;o00000oooool2o`0000?ooooo0_l0000;ooooo`;o00001?ooool2o`0000Kooooo0_l00003
ooooo`;o0000O_ooool001cooooo00?o0000ooooooooool0Koooool2o`0001_ooooo0_l0000<oooo
o`;o00003_ooool2o`000003ooooool0003o000000Ko000000Coooooo`000?l0003ooooo0_l00000
0ooooooo0000o`00002;ooooo`007?ooool00ol0003oooooooooo`1_ooooo`;o00006oooool2o`00
00Gooooo0_l00009ooooo`;o00001Oooool2o`0000?ooooo2ol00003ooooo`?o0000S_ooool001co
oooo00?o0000ooooooooool0Toooool4o`0000Oooooo0_l00002ooooo`;o000000?oooooo`000?l0
00001Oooool2o`0000Cooooo0_l00002ooooo`Co0000Soooool001cooooo00?o0000ooooooooool0
Toooool4o`0000_ooooo0_l000000ooooooo0000o`00000?ooooo`;o00001_ooool2o`0008Wooooo
000Looooo`03o`000?oooooooooo0:Gooooo0_l00004ooooo`;o00003oooool4o`0000;ooooo0_l0
0025ooooo`007?ooool00ol0003oooooooooo`1iooooo`;o0000<?ooool2o`0000oooooo0_l00004
ooooo`;o0000QOooool001cooooo00?o0000ooooooooool0NOooool2o`0000oooooo0_l0000Koooo
o`;o0000X?ooool001cooooo0_l0002;ooooo`;o00006_ooool3o`000:3ooooo000Looooo`03o`00
0?oooooooooo08[ooooo0_l0000Jooooo`;o00004oooool2o`0008cooooo000Looooo`03o`000?oo
oooooooo09kooooo0_l0000Kooooo`;o0000S?ooool001cooooo00?o0000ooooooooool0W_ooool2
o`000:Wooooo000Looooo`03o`000?oooooooooo0;Cooooo0_l0002Cooooo`007?ooool00ol0003o
ooooooooo`2Eooooo`;o00007Oooool2o`0009?ooooo000Looooo`03o`000?oooooooooo09Gooooo
0_l0002booooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool2o`0008[ooooo0_l0000=ooooo`;o0000[oooool001cooooo00?o0000ooooooooool0ROoo
ool2o`0000gooooo0_l0002_ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0
003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001;ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo
B_ooool001Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood[ooooo000D
ooooo`03o`000?oooooooooo00Gooooo0ol0003ooooood[ooooo000Dooooo`03o`000?oooooooooo
0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003ooooo
ooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001;ooooo00?oEEEE
ofIVI_l00000oooooomDooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00XOoo
ool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo01Kooooo1?l000002?l@413ooooo
oooooonHV9So410@o`000?lb<S;oc<c<1?ooool4o`000003oa0@4?oooooooooo00;ooooo0_l00000
0ol@413oooooooooo`2:ooooo`00X_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l0000<
ooooo`03o`000?oooooooooo00;ooooo00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0Roooool00:;ooooo00Go0000ooooooooooooooooo`00
000Kooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`Go0000S?ooool00:;ooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00003?oo
ool00ol0003oooooooooo`05ooooo`03ojVYZOl@413ooooo00Gooooo00?o0000ooooooooool00_oo
ool01?m4A4CogMgMooooool0002=ooooo`00X_ooool01Ol0003oQhN7oooooonYZJWo000001_ooooo
00?o0000ooooooooool01?ooool00ol@413o0000okZj^P06ooooo`03o`000?oooooooooo00;ooooo
00CogMgMoeEEEOoooooo0000SOooool00:7ooooo00?o410@o`000?mgMgL00_l000000onHV9Sooooo
ooooo`0Iooooo`03o`000?oooooooooo00Gooooo00?o^[Zjob4Q8Oooool01Oooool00ol0003ooooo
ooooo`03ooooo`03ogMgMoo<c<co000008gooooo0032ooooo`03o`000?oooooooooo00;ooooo00Go
410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooooooo00?ooooo00?ok^k^odA4A?l00000
SOooool00<3ooooo00?oEEEEofIVI_l000001?ooool01OnYZJWo410@o`000?l@413oZJVY00Cooooo
00?oEEEEofIVI_l000001_ooool00omgMgOo0000ooooo`2<ooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1320) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.31955 .64095 Mdot
.3292 .64059 Mdot
.63928 .50594 Mdot
.44313 .40791 Mdot
.79961 .44711 Mdot
.66559 .52804 Mdot
.5637 .63436 Mdot
.54432 .6862 Mdot
.6455 .49172 Mdot
.50744 .72281 Mdot
.56783 .68609 Mdot
.36758 .37092 Mdot
.54722 .65955 Mdot
.43922 .4434 Mdot
.79283 .3094 Mdot
.44747 .37521 Mdot
.32316 .64326 Mdot
.62447 .31754 Mdot
.38649 .38383 Mdot
.63358 .54434 Mdot
.30673 .64713 Mdot
.43512 .43642 Mdot
.38737 .60748 Mdot
.43926 .44411 Mdot
.41866 .3983 Mdot
.37494 .59603 Mdot
.38182 .65134 Mdot
.39496 .40939 Mdot
.38415 .43155 Mdot
.55152 .69103 Mdot
.47865 .26781 Mdot
.79587 .34858 Mdot
.4775 .47498 Mdot
.61902 .23709 Mdot
.52815 .66263 Mdot
.26618 .54249 Mdot
.65789 .51864 Mdot
.56824 .66688 Mdot
.57269 .66475 Mdot
.52204 .66203 Mdot
.56232 .67755 Mdot
.37866 .61446 Mdot
.44718 .66061 Mdot
.73444 .52763 Mdot
.47179 .40327 Mdot
.77957 .59232 Mdot
.27031 .64388 Mdot
.43175 .47138 Mdot
.33574 .60742 Mdot
.67408 .36863 Mdot
.70401 .60706 Mdot
.55105 .63926 Mdot
.63466 .55115 Mdot
.10544 .50482 Mdot
.55255 .64802 Mdot
.36756 .47084 Mdot
.64975 .50959 Mdot
.42247 .43917 Mdot
.43774 .44831 Mdot
.27034 .3976 Mdot
.46737 .4464 Mdot
.6112 .35535 Mdot
.40152 .58458 Mdot
.5345 .581 Mdot
.65503 .49876 Mdot
.57741 .67255 Mdot
.33884 .63678 Mdot
.5419 .65465 Mdot
.36579 .49675 Mdot
.66705 .55263 Mdot
.43295 .47255 Mdot
.57071 .68251 Mdot
.3706 .65141 Mdot
.3951 .43978 Mdot
.68177 .44479 Mdot
.7653 .68094 Mdot
.59546 .38945 Mdot
.26226 .51205 Mdot
.26559 .39562 Mdot
.70645 .40446 Mdot
.4098 .3824 Mdot
.52617 .31019 Mdot
.76936 .65692 Mdot
.378 .58134 Mdot
.46067 .37476 Mdot
.63656 .31781 Mdot
.39623 .43494 Mdot
.80859 .57778 Mdot
.43583 .48053 Mdot
.62214 .40101 Mdot
.64513 .4858 Mdot
.34595 .61512 Mdot
.44222 .4042 Mdot
.39389 .45312 Mdot
.28756 .35404 Mdot
.37401 .45322 Mdot
.42329 .42029 Mdot
.34152 .59495 Mdot
.5512 .64036 Mdot
.3957 .48599 Mdot
.7095 .55777 Mdot
.62726 .48472 Mdot
.45837 .40415 Mdot
.67929 .48859 Mdot
.39532 .62247 Mdot
.39554 .45373 Mdot
.5705 .65742 Mdot
.46496 .4242 Mdot
.43046 .78325 Mdot
.333 .64834 Mdot
.3873 .41593 Mdot
.5813 .33339 Mdot
.20836 .44837 Mdot
.3413 .61038 Mdot
.69951 .56882 Mdot
.37733 .40532 Mdot
.41446 .42455 Mdot
.33042 .63374 Mdot
.65221 .474 Mdot
.80107 .59521 Mdot
.3517 .58375 Mdot
.53658 .68865 Mdot
.32793 .6604 Mdot
.36579 .38091 Mdot
.66591 .49996 Mdot
.73281 .55718 Mdot
.41443 .75346 Mdot
.5072 .25585 Mdot
.39885 .43584 Mdot
.45972 .67504 Mdot
.61842 .50645 Mdot
.34956 .62233 Mdot
.54047 .65949 Mdot
.48644 .39354 Mdot
.36107 .64274 Mdot
.56818 .69023 Mdot
.59572 .33041 Mdot
.6533 .65455 Mdot
.38432 .63359 Mdot
.5455 .45633 Mdot
.58937 .66074 Mdot
.53138 .64248 Mdot
.50877 .18007 Mdot
.34057 .63316 Mdot
.59916 .35859 Mdot
.53726 .66862 Mdot
.4907 .23951 Mdot
.47321 .41036 Mdot
.48908 .30793 Mdot
.27067 .69211 Mdot
.59345 .22176 Mdot
.66682 .67455 Mdot
.57317 .35949 Mdot
.57677 .6954 Mdot
.42586 .40678 Mdot
.36589 .59327 Mdot
.38304 .59971 Mdot
.46806 .44274 Mdot
.42398 .39097 Mdot
.43105 .47535 Mdot
.40341 .47072 Mdot
.33208 .37724 Mdot
.36656 .41801 Mdot
.24429 .61353 Mdot
.34917 .61061 Mdot
.4369 .40804 Mdot
.67112 .54231 Mdot
.45175 .48467 Mdot
.5664 .68063 Mdot
.42668 .43448 Mdot
.44125 .40557 Mdot
.4742 .42699 Mdot
.54422 .63977 Mdot
.82551 .39474 Mdot
.19689 .49295 Mdot
.80291 .38321 Mdot
.59101 .41962 Mdot
.68393 .5229 Mdot
.39866 .42421 Mdot
.60708 .34294 Mdot
.30735 .52011 Mdot
.4535 .42121 Mdot
.32654 .81639 Mdot
.42962 .42536 Mdot
.80489 .43047 Mdot
.37524 .4905 Mdot
.74179 .31012 Mdot
.51524 .29865 Mdot
.41341 .40546 Mdot
.46102 .63337 Mdot
.59748 .69582 Mdot
.6256 .46795 Mdot
.55919 .67428 Mdot
.66555 .54446 Mdot
.64247 .50787 Mdot
.52603 .59765 Mdot
.38735 .35333 Mdot
.45102 .4919 Mdot
.41335 .47998 Mdot
.68997 .54178 Mdot
.39814 .58755 Mdot
.60443 .32491 Mdot
.3183 .61895 Mdot
.86913 .52819 Mdot
.75744 .5779 Mdot
.53393 .62675 Mdot
.62055 .34176 Mdot
.62801 .49708 Mdot
.65567 .48291 Mdot
.57389 .3426 Mdot
.41674 .45898 Mdot
.34817 .63245 Mdot
.5554 .18245 Mdot
.48248 .79407 Mdot
.46319 .15458 Mdot
.34288 .5957 Mdot
.48883 .71753 Mdot
.55389 .68784 Mdot
.64779 .52798 Mdot
.4166 .42274 Mdot
.41185 .45269 Mdot
.30304 .62962 Mdot
.42614 .47495 Mdot
.34512 .68507 Mdot
.41267 .41479 Mdot
.63871 .6108 Mdot
.62862 .3511 Mdot
.53035 .59562 Mdot
.53611 .24932 Mdot
.37546 .58474 Mdot
.33703 .29126 Mdot
.67666 .49076 Mdot
.30228 .51204 Mdot
.58052 .67431 Mdot
.60949 .33487 Mdot
.67189 .49495 Mdot
.5932 .32637 Mdot
.37027 .40441 Mdot
.65198 .5473 Mdot
.56513 .35311 Mdot
.42973 .32287 Mdot
.48022 .43124 Mdot
.35973 .76521 Mdot
.52465 .668 Mdot
.31607 .61541 Mdot
.46279 .45429 Mdot
.68968 .51087 Mdot
.49604 .41329 Mdot
.67862 .70716 Mdot
.65602 .59844 Mdot
.62019 .49094 Mdot
.62431 .58328 Mdot
.61498 .34874 Mdot
.7156 .64337 Mdot
.47081 .6985 Mdot
.32204 .63639 Mdot
.37086 .44773 Mdot
.72395 .28686 Mdot
.5371 .66756 Mdot
.46306 .43934 Mdot
.68273 .31131 Mdot
.5346 .65355 Mdot
.42032 .43953 Mdot
.56177 .69574 Mdot
.38365 .6007 Mdot
.23697 .39351 Mdot
.32464 .62726 Mdot
.40756 .47574 Mdot
.56611 .65167 Mdot
.69274 .50083 Mdot
.3714 .5998 Mdot
.42392 .4631 Mdot
.3957 .41248 Mdot
.57611 .54648 Mdot
.43424 .41436 Mdot
.81955 .41152 Mdot
.41259 .40979 Mdot
.63889 .52174 Mdot
.43298 .38023 Mdot
.16013 .48415 Mdot
.51245 .60802 Mdot
.34063 .63556 Mdot
.63072 .47457 Mdot
.64645 .49719 Mdot
.74423 .50349 Mdot
.50929 .65354 Mdot
.38135 .39793 Mdot
.68781 .51487 Mdot
.38379 .29139 Mdot
.58806 .67174 Mdot
.42707 .4912 Mdot
.52358 .49079 Mdot
.66478 .37229 Mdot
.63216 .54895 Mdot
.50303 .40725 Mdot
.39141 .62566 Mdot
.43871 .39924 Mdot
.6564 .48036 Mdot
.42857 .34726 Mdot
.38492 .40363 Mdot
.30866 .69303 Mdot
.58072 .55533 Mdot
.57953 .6469 Mdot
.38177 .49066 Mdot
.45647 .45047 Mdot
.66044 .54289 Mdot
.37195 .58624 Mdot
.58944 .67132 Mdot
.3784 .60726 Mdot
.70888 .28925 Mdot
.37437 .76833 Mdot
.38929 .32101 Mdot
.61931 .32455 Mdot
.6637 .33027 Mdot
.71911 .29225 Mdot
.29951 .29128 Mdot
.37918 .26565 Mdot
.63176 .22606 Mdot
.66694 .47902 Mdot
.68268 .32323 Mdot
.64728 .5029 Mdot
.41101 .39073 Mdot
.66506 .50149 Mdot
.714 .27802 Mdot
.41502 .41556 Mdot
.6666 .51007 Mdot
.31359 .31399 Mdot
.4351 .39999 Mdot
.32489 .637 Mdot
.84789 .49627 Mdot
.21006 .37009 Mdot
.64442 .59899 Mdot
.63124 .53093 Mdot
.42081 .24227 Mdot
.4245 .41857 Mdot
.42913 .38008 Mdot
.35476 .59822 Mdot
.49493 .43976 Mdot
.59684 .37325 Mdot
.61812 .35312 Mdot
.54871 .7287 Mdot
.53112 .37595 Mdot
.37347 .48551 Mdot
.36748 .59964 Mdot
.33097 .39771 Mdot
.66124 .43012 Mdot
.6775 .36022 Mdot
.59521 .65177 Mdot
.84619 .49411 Mdot
.36657 .67236 Mdot
.59953 .62142 Mdot
.59626 .48801 Mdot
.33232 .62146 Mdot
.81864 .37552 Mdot
.56038 .67033 Mdot
.37323 .78549 Mdot
.44172 .55836 Mdot
.41839 .45688 Mdot
.58307 .65794 Mdot
.47574 .3728 Mdot
.22129 .35289 Mdot
.45596 .82282 Mdot
.45464 .5185 Mdot
.4393 .48094 Mdot
.63993 .43236 Mdot
.42225 .43009 Mdot
.74107 .66126 Mdot
.40775 .4083 Mdot
.37458 .6082 Mdot
.52424 .7334 Mdot
.52692 .70527 Mdot
.19707 .56539 Mdot
.72202 .65425 Mdot
.57291 .36121 Mdot
.41116 .41858 Mdot
.42099 .45739 Mdot
.58632 .37469 Mdot
.39009 .61172 Mdot
.41724 .47726 Mdot
.3402 .28231 Mdot
.39899 .45829 Mdot
.56727 .67507 Mdot
.42294 .56713 Mdot
.29244 .67077 Mdot
.38788 .46023 Mdot
.40085 .61827 Mdot
.54541 .62767 Mdot
.56316 .65264 Mdot
.36639 .48263 Mdot
.52163 .66924 Mdot
.43706 .42633 Mdot
.48961 .83185 Mdot
.37655 .64078 Mdot
.36308 .70306 Mdot
.36575 .63354 Mdot
.25351 .5028 Mdot
.53904 .64535 Mdot
.66607 .61702 Mdot
.42936 .35355 Mdot
.55724 .667 Mdot
.29322 .63183 Mdot
.45024 .38014 Mdot
.48382 .41431 Mdot
.51185 .19723 Mdot
.6308 .5176 Mdot
.58302 .56509 Mdot
.55 .69111 Mdot
.43874 .46256 Mdot
.37494 .44027 Mdot
.53875 .62818 Mdot
.48826 .81516 Mdot
.24492 .35043 Mdot
.41326 .4123 Mdot
.36464 .61206 Mdot
.35403 .62217 Mdot
.46964 .45755 Mdot
.44981 .39759 Mdot
.67545 .50666 Mdot
.68203 .48255 Mdot
.66316 .55074 Mdot
.58859 .57149 Mdot
.66204 .61441 Mdot
.78763 .51134 Mdot
.52197 .66135 Mdot
.47521 .73499 Mdot
.62801 .39053 Mdot
.40229 .47966 Mdot
.6241 .52065 Mdot
.45588 .44691 Mdot
.44413 .422 Mdot
.51313 .63789 Mdot
.75623 .38498 Mdot
.324 .67077 Mdot
.39156 .59261 Mdot
.59389 .67026 Mdot
.34522 .44896 Mdot
.56548 .61466 Mdot
.60046 .33457 Mdot
.55282 .20594 Mdot
.57706 .67805 Mdot
.3258 .63472 Mdot
.5297 .67348 Mdot
.40641 .45407 Mdot
.36304 .40834 Mdot
.33444 .62477 Mdot
.58499 .38114 Mdot
.4942 .4276 Mdot
.41772 .43699 Mdot
.26116 .69404 Mdot
.53693 .21906 Mdot
.6285 .62333 Mdot
.41453 .4072 Mdot
.3825 .44453 Mdot
.55864 .36545 Mdot
.40081 .45823 Mdot
.44645 .47088 Mdot
.2152 .44923 Mdot
.43333 .75986 Mdot
.62158 .35058 Mdot
.50104 .82504 Mdot
.33993 .59867 Mdot
.7606 .31541 Mdot
.65046 .53642 Mdot
.51432 .71323 Mdot
.22026 .38384 Mdot
.63823 .55303 Mdot
.66481 .68147 Mdot
.78024 .33778 Mdot
.59834 .59192 Mdot
.69001 .47184 Mdot
.37042 .66114 Mdot
.41044 .47417 Mdot
.41458 .42855 Mdot
.60931 .35003 Mdot
.35594 .62971 Mdot
.56274 .54584 Mdot
.66177 .7796 Mdot
.43292 .43343 Mdot
.364 .69221 Mdot
.5876 .78352 Mdot
.66342 .38008 Mdot
.59075 .34607 Mdot
.60836 .37126 Mdot
.41031 .42123 Mdot
.19669 .4735 Mdot
.37334 .59582 Mdot
.42546 .46302 Mdot
.36628 .42652 Mdot
.63163 .52605 Mdot
.34579 .6509 Mdot
.64814 .47472 Mdot
.69204 .6208 Mdot
.80396 .3964 Mdot
.2977 .76174 Mdot
.55001 .64541 Mdot
.7119 .71056 Mdot
.57492 .69188 Mdot
.53264 .30624 Mdot
.61643 .52235 Mdot
.44466 .39958 Mdot
.3768 .58685 Mdot
.44501 .45791 Mdot
.44658 .39628 Mdot
.41899 .45895 Mdot
.38425 .45978 Mdot
.23428 .71386 Mdot
.56867 .35483 Mdot
.41089 .36415 Mdot
.63781 .5162 Mdot
.7779 .62471 Mdot
.75323 .6853 Mdot
.42518 .4558 Mdot
.40139 .41364 Mdot
.37474 .63823 Mdot
.46663 .44241 Mdot
.58185 .68632 Mdot
.33562 .59247 Mdot
.39188 .44184 Mdot
.83996 .52727 Mdot
.38368 .42377 Mdot
.77115 .33996 Mdot
.53342 .67718 Mdot
.44269 .79025 Mdot
.38395 .37082 Mdot
.63432 .59538 Mdot
.58266 .56447 Mdot
.67391 .49987 Mdot
.54471 .69802 Mdot
.65943 .51639 Mdot
.63191 .79688 Mdot
.3583 .41484 Mdot
.4246 .40393 Mdot
.39012 .47643 Mdot
.68372 .52396 Mdot
.81389 .55264 Mdot
.73489 .6225 Mdot
.37773 .37127 Mdot
.67872 .52714 Mdot
.4037 .6032 Mdot
.49678 .21487 Mdot
.37515 .62511 Mdot
.59711 .31994 Mdot
.55909 .68521 Mdot
.59205 .37894 Mdot
.67442 .29201 Mdot
.32975 .64484 Mdot
.3096 .63367 Mdot
.65292 .5342 Mdot
.4528 .55941 Mdot
.22888 .28425 Mdot
.44286 .56128 Mdot
.51727 .27866 Mdot
.35844 .6007 Mdot
.38556 .44139 Mdot
.55844 .30498 Mdot
.45482 .58675 Mdot
.65952 .51308 Mdot
.45121 .42839 Mdot
.23704 .38829 Mdot
.67553 .50648 Mdot
.38862 .47758 Mdot
.63427 .5144 Mdot
.55638 .67898 Mdot
.62352 .50917 Mdot
.32628 .58988 Mdot
.39224 .42644 Mdot
.28021 .22691 Mdot
.62466 .29997 Mdot
.42359 .41427 Mdot
.59524 .66688 Mdot
.61533 .72653 Mdot
.45883 .41806 Mdot
.57275 .3367 Mdot
.67309 .51818 Mdot
.45734 .53594 Mdot
.41103 .4106 Mdot
.67762 .5314 Mdot
.31953 .64394 Mdot
.56797 .7012 Mdot
.28474 .36491 Mdot
.62116 .5982 Mdot
.35383 .59737 Mdot
.5624 .43083 Mdot
.52658 .68584 Mdot
.38273 .44624 Mdot
.37216 .44821 Mdot
.36298 .61544 Mdot
.44394 .31291 Mdot
.45566 .39551 Mdot
.41281 .38265 Mdot
.63853 .52914 Mdot
.66324 .51766 Mdot
.32952 .32248 Mdot
.66719 .47572 Mdot
.3639 .406 Mdot
.36562 .61543 Mdot
.44461 .40655 Mdot
.36762 .64505 Mdot
.46674 .44023 Mdot
.37064 .35622 Mdot
.39026 .60983 Mdot
.55004 .60268 Mdot
.44864 .42438 Mdot
.46597 .48545 Mdot
.46442 .42837 Mdot
.41171 .47266 Mdot
.6693 .4993 Mdot
.59658 .34008 Mdot
.36708 .45224 Mdot
.55045 .37417 Mdot
.59695 .32679 Mdot
.54509 .71042 Mdot
.6305 .52291 Mdot
.59078 .36569 Mdot
.59806 .78621 Mdot
.65279 .55 Mdot
.60466 .36355 Mdot
.75435 .68308 Mdot
.52826 .65814 Mdot
.38738 .63293 Mdot
.43282 .39762 Mdot
.6763 .27809 Mdot
.26946 .64976 Mdot
.66809 .46811 Mdot
.41547 .41072 Mdot
.46173 .437 Mdot
.36432 .57985 Mdot
.65427 .80224 Mdot
.66738 .55237 Mdot
.38132 .41116 Mdot
.33678 .64218 Mdot
.6357 .82957 Mdot
.64204 .51659 Mdot
.60808 .3582 Mdot
.52587 .65238 Mdot
.29503 .65627 Mdot
.41205 .75353 Mdot
.57029 .63828 Mdot
.60872 .46719 Mdot
.69478 .6106 Mdot
.37544 .40752 Mdot
.62228 .52018 Mdot
.47344 .1681 Mdot
.33499 .46286 Mdot
.55339 .58192 Mdot
.4291 .23823 Mdot
.33584 .61689 Mdot
.57756 .68975 Mdot
.5712 .35741 Mdot
.34778 .59296 Mdot
.32485 .64518 Mdot
.53008 .63194 Mdot
.2084 .4874 Mdot
.51934 .49458 Mdot
.57184 .66959 Mdot
.58507 .23921 Mdot
.77561 .47768 Mdot
.62452 .52349 Mdot
.59618 .3732 Mdot
.68769 .30287 Mdot
.37977 .61171 Mdot
.85139 .47699 Mdot
.51771 .19263 Mdot
.42352 .42037 Mdot
.59016 .36218 Mdot
.80721 .53257 Mdot
.7086 .75591 Mdot
.53733 .64971 Mdot
.54115 .71673 Mdot
.60607 .36795 Mdot
.46247 .45364 Mdot
.49156 .22415 Mdot
.41656 .38423 Mdot
.55424 .6856 Mdot
.29616 .36824 Mdot
.32574 .64368 Mdot
.52941 .63739 Mdot
.5481 .20261 Mdot
.43738 .42824 Mdot
.44994 .42366 Mdot
.55808 .25498 Mdot
.35957 .58585 Mdot
.67446 .50022 Mdot
.37054 .41386 Mdot
.42106 .43561 Mdot
.36177 .45115 Mdot
.38835 .4922 Mdot
.21662 .4286 Mdot
.40662 .39662 Mdot
.75988 .60127 Mdot
.44036 .48159 Mdot
.44637 .434 Mdot
.39896 .62102 Mdot
.29921 .77009 Mdot
.71078 .61524 Mdot
.42444 .43423 Mdot
.38118 .43164 Mdot
.52659 .64119 Mdot
.47507 .54259 Mdot
.46027 .54818 Mdot
.46339 .52981 Mdot
.40041 .2525 Mdot
.4779 .44806 Mdot
.34677 .63681 Mdot
.56405 .35186 Mdot
.37906 .4092 Mdot
.34324 .63918 Mdot
.47247 .4139 Mdot
.67764 .50874 Mdot
.65432 .54986 Mdot
.33456 .44749 Mdot
.58473 .36721 Mdot
.41435 .64846 Mdot
.46908 .7335 Mdot
.65868 .54556 Mdot
.42325 .40136 Mdot
.50617 .64254 Mdot
.65696 .48122 Mdot
.6431 .58801 Mdot
.47388 .33442 Mdot
.36962 .59116 Mdot
.34637 .61242 Mdot
.48624 .30943 Mdot
.67175 .65952 Mdot
.21269 .62877 Mdot
.55636 .68033 Mdot
.38753 .37725 Mdot
.47007 .67815 Mdot
.34473 .6106 Mdot
.55082 .3013 Mdot
.58744 .36444 Mdot
.53333 .6556 Mdot
.65107 .44472 Mdot
.36811 .64057 Mdot
.32897 .65385 Mdot
.45288 .47533 Mdot
.41749 .44507 Mdot
.37108 .27175 Mdot
.54723 .35965 Mdot
.56873 .63627 Mdot
.60089 .37029 Mdot
.61668 .52195 Mdot
.39704 .39871 Mdot
.38868 .60492 Mdot
.77047 .4911 Mdot
.37763 .41557 Mdot
.65706 .48848 Mdot
.33913 .6171 Mdot
.61496 .35089 Mdot
.5687 .3389 Mdot
.40625 .46964 Mdot
.30707 .38969 Mdot
.56421 .66363 Mdot
.32852 .62457 Mdot
.5682 .61215 Mdot
.43487 .3833 Mdot
.4107 .44068 Mdot
.39414 .50613 Mdot
.57037 .63702 Mdot
.52424 .76683 Mdot
.60957 .32327 Mdot
.35046 .62906 Mdot
.40354 .40211 Mdot
.59448 .37099 Mdot
.49453 .73699 Mdot
.61783 .49567 Mdot
.62434 .50456 Mdot
.5642 .34427 Mdot
.58994 .35336 Mdot
.58404 .32958 Mdot
.85203 .47617 Mdot
.36752 .57589 Mdot
.36411 .67253 Mdot
.42361 .37498 Mdot
.5132 .29209 Mdot
.44529 .36197 Mdot
.59044 .66537 Mdot
.63116 .51319 Mdot
.45743 .40946 Mdot
.39282 .46188 Mdot
.35981 .47915 Mdot
.34856 .69991 Mdot
.29081 .66021 Mdot
.33691 .65086 Mdot
.36684 .39296 Mdot
.63604 .53408 Mdot
.87492 .52612 Mdot
.57385 .17107 Mdot
.38111 .37311 Mdot
.51859 .49001 Mdot
.38957 .59952 Mdot
.52125 .65288 Mdot
.59694 .26872 Mdot
.52659 .65959 Mdot
.3475 .62775 Mdot
.40374 .39689 Mdot
.47716 .74549 Mdot
.55622 .36058 Mdot
.43135 .4682 Mdot
.5473 .68462 Mdot
.43606 .47069 Mdot
.56712 .63612 Mdot
.71716 .3003 Mdot
.42982 .202 Mdot
.42847 .42483 Mdot
.44224 .36572 Mdot
.40198 .23742 Mdot
.43007 .45699 Mdot
.57742 .31969 Mdot
.38985 .59957 Mdot
.29883 .34533 Mdot
.47211 .39499 Mdot
.32174 .45801 Mdot
.4265 .38158 Mdot
.28787 .33797 Mdot
.41053 .44406 Mdot
.65661 .38979 Mdot
.38872 .41859 Mdot
.43729 .4764 Mdot
.55861 .64659 Mdot
.52976 .63788 Mdot
.37877 .64759 Mdot
.68909 .50432 Mdot
.78756 .35959 Mdot
.4147 .43772 Mdot
.67016 .5957 Mdot
.47211 .76879 Mdot
.58961 .35121 Mdot
.35421 .62665 Mdot
.69681 .78337 Mdot
.54758 .69243 Mdot
.48562 .1933 Mdot
.33896 .31279 Mdot
.41307 .7164 Mdot
.62848 .29275 Mdot
.6053 .75248 Mdot
.61538 .34038 Mdot
.47362 .42476 Mdot
.7678 .4362 Mdot
.6471 .40278 Mdot
.45901 .32802 Mdot
.52838 .69017 Mdot
.31245 .49696 Mdot
.76444 .40383 Mdot
.57561 .32837 Mdot
.60846 .36823 Mdot
.55549 .63754 Mdot
.70895 .49553 Mdot
.38063 .35917 Mdot
.58477 .36134 Mdot
.67844 .53821 Mdot
.64444 .54928 Mdot
.65139 .55603 Mdot
.37815 .59591 Mdot
.53497 .18206 Mdot
.54392 .6189 Mdot
.58058 .64906 Mdot
.69755 .54916 Mdot
.37967 .53966 Mdot
.34411 .58053 Mdot
.65341 .527 Mdot
.63494 .48423 Mdot
.39277 .60676 Mdot
.36554 .47247 Mdot
.35095 .42752 Mdot
.42899 .43318 Mdot
.60374 .3415 Mdot
.41353 .44861 Mdot
.67851 .5232 Mdot
.54181 .64969 Mdot
.63184 .48949 Mdot
.5968 .67385 Mdot
.78412 .53243 Mdot
.41763 .46574 Mdot
.39137 .4218 Mdot
.28758 .71998 Mdot
.32673 .65725 Mdot
.77494 .57785 Mdot
.61604 .60721 Mdot
.6455 .50482 Mdot
.44941 .46818 Mdot
.33328 .594 Mdot
.54939 .36358 Mdot
.32044 .76726 Mdot
.45278 .39773 Mdot
.38374 .61735 Mdot
.39682 .40134 Mdot
.33115 .36906 Mdot
.16064 .52068 Mdot
.37395 .61508 Mdot
.26963 .68644 Mdot
.38269 .43028 Mdot
.63571 .7594 Mdot
.42664 .49013 Mdot
.41972 .29295 Mdot
.45542 .39532 Mdot
.34073 .59731 Mdot
.42891 .4369 Mdot
.32746 .60122 Mdot
.65486 .54336 Mdot
.52288 .65126 Mdot
.35125 .60157 Mdot
.37834 .45757 Mdot
.3179 .1537 Mdot
.54851 .67938 Mdot
.4138 .42102 Mdot
.53934 .64252 Mdot
.35913 .63095 Mdot
.33793 .6064 Mdot
.70794 .74721 Mdot
.69309 .62325 Mdot
.55574 .67754 Mdot
.3968 .39958 Mdot
.67391 .72456 Mdot
.43124 .39127 Mdot
.40444 .27477 Mdot
.36927 .47173 Mdot
.43081 .37849 Mdot
.75695 .6876 Mdot
.58093 .64778 Mdot
.20343 .61698 Mdot
.73961 .72307 Mdot
.7768 .62942 Mdot
.30286 .6404 Mdot
.56769 .33423 Mdot
.82256 .38342 Mdot
.66148 .6161 Mdot
.67953 .52793 Mdot
.46137 .41844 Mdot
.3609 .56313 Mdot
.56655 .66093 Mdot
.59322 .33668 Mdot
.42731 .42461 Mdot
.62708 .49156 Mdot
.27349 .3185 Mdot
.58414 .69044 Mdot
.376 .61838 Mdot
.38701 .58371 Mdot
.49827 .84972 Mdot
.4108 .40475 Mdot
.39145 .43045 Mdot
.55799 .68585 Mdot
.56491 .77645 Mdot
.61036 .33014 Mdot
.31399 .3099 Mdot
.55423 .6762 Mdot
.53645 .54156 Mdot
.33435 .63807 Mdot
.46079 .44008 Mdot
.82837 .49568 Mdot
.70154 .4615 Mdot
.29845 .71457 Mdot
.60699 .34369 Mdot
.4103 .2715 Mdot
.33853 .59968 Mdot
.5389 .66332 Mdot
.64468 .67657 Mdot
.4756 .45875 Mdot
.45397 .44692 Mdot
.41943 .27372 Mdot
.53082 .70647 Mdot
.44416 .52724 Mdot
.44667 .39181 Mdot
.58532 .57228 Mdot
.46213 .40915 Mdot
.48852 .41808 Mdot
.35695 .44476 Mdot
.40289 .43695 Mdot
.3873 .60953 Mdot
.39659 .52616 Mdot
.6833 .50866 Mdot
.40346 .64747 Mdot
.53426 .55057 Mdot
.41917 .414 Mdot
.40199 .38743 Mdot
.30572 .58284 Mdot
.65464 .70474 Mdot
.35078 .60463 Mdot
.30781 .62514 Mdot
.52645 .6784 Mdot
.3513 .44669 Mdot
.68402 .49565 Mdot
.48615 .39773 Mdot
.66345 .49393 Mdot
.38764 .60527 Mdot
.64406 .50923 Mdot
.52791 .64721 Mdot
.6299 .5353 Mdot
.66292 .61413 Mdot
.53675 .67291 Mdot
.36364 .59188 Mdot
.39566 .44416 Mdot
.59527 .66847 Mdot
.51342 .24622 Mdot
.60485 .34299 Mdot
.77958 .6944 Mdot
.39118 .44088 Mdot
.426 .76075 Mdot
.44505 .34477 Mdot
.63404 .48608 Mdot
.16378 .5329 Mdot
.39155 .5942 Mdot
.61415 .36674 Mdot
.37438 .58288 Mdot
.52397 .20846 Mdot
.5982 .34924 Mdot
.7813 .66359 Mdot
.58113 .51044 Mdot
.52828 .21872 Mdot
.35878 .46805 Mdot
.54943 .24031 Mdot
.62703 .54446 Mdot
.56539 .65888 Mdot
.65232 .6787 Mdot
.44329 .4723 Mdot
.33538 .25031 Mdot
.40051 .6014 Mdot
.68852 .50592 Mdot
.54211 .65663 Mdot
.59022 .67163 Mdot
.39374 .3833 Mdot
.70542 .38074 Mdot
.45363 .45425 Mdot
.67469 .64555 Mdot
.40517 .25569 Mdot
.31059 .68145 Mdot
.41282 .41532 Mdot
.65936 .5431 Mdot
.397 .4012 Mdot
.62407 .32812 Mdot
.51149 .17211 Mdot
.49194 .44027 Mdot
.61995 .61864 Mdot
.62671 .30258 Mdot
.33023 .63076 Mdot
.46279 .34437 Mdot
.64111 .61922 Mdot
.41021 .40241 Mdot
.17124 .66382 Mdot
.60055 .3675 Mdot
.76518 .43122 Mdot
.37874 .44551 Mdot
.38185 .39551 Mdot
.50484 .59839 Mdot
.3991 .74272 Mdot
.67914 .44656 Mdot
.43791 .45366 Mdot
.45802 .25962 Mdot
.56717 .63954 Mdot
.4651 .44001 Mdot
.41337 .42641 Mdot
.22204 .53396 Mdot
.59133 .67806 Mdot
.64168 .49881 Mdot
.63133 .55135 Mdot
.66281 .46819 Mdot
.62564 .33379 Mdot
.60404 .69894 Mdot
.54141 .29177 Mdot
.24039 .33884 Mdot
.58751 .38434 Mdot
.39573 .46201 Mdot
.57877 .30871 Mdot
.40548 .39244 Mdot
.58398 .34369 Mdot
.59034 .6809 Mdot
.3471 .60429 Mdot
.48112 .69871 Mdot
.64983 .55292 Mdot
.45693 .48641 Mdot
.61415 .33064 Mdot
.36713 .59287 Mdot
.62327 .28104 Mdot
.33434 .63232 Mdot
.55306 .66804 Mdot
.5993 .65031 Mdot
.58871 .33801 Mdot
.36158 .63346 Mdot
.6033 .61803 Mdot
.68757 .7706 Mdot
.35742 .42825 Mdot
.56923 .7421 Mdot
.32574 .614 Mdot
.31215 .61285 Mdot
.33283 .59933 Mdot
.42575 .47384 Mdot
.51998 .48891 Mdot
.46578 .39656 Mdot
.57866 .64556 Mdot
.63511 .51024 Mdot
.37304 .24868 Mdot
.73958 .5675 Mdot
.54204 .4291 Mdot
.37876 .38217 Mdot
.43843 .43001 Mdot
.4106 .42144 Mdot
.47428 .39563 Mdot
.65037 .64345 Mdot
.44927 .45468 Mdot
.56019 .64654 Mdot
.67516 .51762 Mdot
.47395 .42446 Mdot
.65057 .56774 Mdot
.77175 .62478 Mdot
.57879 .3825 Mdot
.58585 .7183 Mdot
.58239 .15991 Mdot
.36261 .59477 Mdot
.63033 .47552 Mdot
.67336 .53454 Mdot
.59787 .33112 Mdot
.56767 .66876 Mdot
.33702 .63368 Mdot
.39137 .28592 Mdot
.59352 .32767 Mdot
.42591 .43638 Mdot
.51172 .48564 Mdot
.36973 .22679 Mdot
.47237 .42488 Mdot
.45343 .41216 Mdot
.62656 .5544 Mdot
.75568 .41145 Mdot
.34476 .19209 Mdot
.56122 .27969 Mdot
.59336 .33848 Mdot
.56937 .36918 Mdot
.38988 .62336 Mdot
.45474 .38215 Mdot
.57455 .64106 Mdot
.42526 .55002 Mdot
.60212 .71779 Mdot
.43034 .60854 Mdot
.33729 .73033 Mdot
.45848 .40658 Mdot
.51568 .81352 Mdot
.43901 .42576 Mdot
.36644 .5763 Mdot
.38497 .60475 Mdot
.36524 .60482 Mdot
.56434 .6591 Mdot
.27528 .52537 Mdot
.56822 .65199 Mdot
.56324 .14593 Mdot
.33219 .60967 Mdot
.58184 .5295 Mdot
.64591 .53296 Mdot
.37038 .37947 Mdot
.61146 .35826 Mdot
.60658 .66674 Mdot
.36502 .49547 Mdot
.18269 .49595 Mdot
.68718 .50885 Mdot
.36047 .59228 Mdot
.59377 .75414 Mdot
.65618 .22467 Mdot
.46468 .53644 Mdot
.34836 .46542 Mdot
.60189 .26854 Mdot
.58675 .34962 Mdot
.29852 .7156 Mdot
.60443 .3684 Mdot
.54571 .68425 Mdot
.39395 .41908 Mdot
.39669 .43468 Mdot
.4638 .41145 Mdot
.42225 .46172 Mdot
.51923 .67049 Mdot
.36982 .44836 Mdot
.16017 .48401 Mdot
.66066 .54885 Mdot
.41632 .32054 Mdot
.60775 .36186 Mdot
.54468 .70042 Mdot
.6759 .51883 Mdot
.65426 .70129 Mdot
.53371 .25288 Mdot
.41184 .41184 Mdot
.45905 .41202 Mdot
.47386 .19013 Mdot
.445 .3905 Mdot
.40313 .35333 Mdot
.67861 .52989 Mdot
.53117 .40512 Mdot
.58318 .38223 Mdot
.5725 .37317 Mdot
.5341 .67129 Mdot
.38652 .60842 Mdot
.60112 .36309 Mdot
.64192 .53208 Mdot
.37672 .38433 Mdot
.36921 .437 Mdot
.3267 .61263 Mdot
.48985 .1784 Mdot
.60371 .32265 Mdot
.6615 .73543 Mdot
.37593 .58843 Mdot
.35381 .66279 Mdot
.45439 .44598 Mdot
.31966 .71009 Mdot
.30976 .60683 Mdot
.60897 .37587 Mdot
.54337 .69939 Mdot
.5788 .26215 Mdot
.56703 .68967 Mdot
.37594 .62112 Mdot
.38382 .40405 Mdot
.38257 .59545 Mdot
.41281 .40721 Mdot
.69919 .23725 Mdot
.40032 .43942 Mdot
.22864 .34854 Mdot
.46913 .3013 Mdot
.66375 .53092 Mdot
.63875 .72429 Mdot
.65127 .536 Mdot
.36951 .58629 Mdot
.37736 .40739 Mdot
.61954 .34271 Mdot
.75256 .66535 Mdot
.38328 .55249 Mdot
.64876 .4841 Mdot
.6947 .52618 Mdot
.56273 .69332 Mdot
.46013 .39983 Mdot
.45253 .44939 Mdot
.66617 .51211 Mdot
.31387 .68499 Mdot
.36465 .63992 Mdot
.39919 .41235 Mdot
.44182 .43375 Mdot
.66083 .53165 Mdot
.6711 .78161 Mdot
.36734 .52566 Mdot
.39775 .42412 Mdot
.74803 .53678 Mdot
.58888 .66213 Mdot
.36056 .40065 Mdot
.43811 .36291 Mdot
.58838 .35594 Mdot
.25164 .41039 Mdot
.5567 .19129 Mdot
.58797 .68503 Mdot
.67173 .53926 Mdot
.40717 .4035 Mdot
.66089 .5431 Mdot
.36882 .43996 Mdot
.39402 .73559 Mdot
.61782 .50345 Mdot
.41177 .3817 Mdot
.37465 .48172 Mdot
.35888 .58564 Mdot
.45848 .40838 Mdot
.29413 .58472 Mdot
.66644 .48706 Mdot
.38988 .38725 Mdot
.30417 .38788 Mdot
.57445 .67297 Mdot
.3584 .46987 Mdot
.57402 .34086 Mdot
.38593 .28707 Mdot
.44864 .73273 Mdot
.7425 .36312 Mdot
.56858 .37162 Mdot
.43848 .46873 Mdot
.69385 .52084 Mdot
.56013 .63391 Mdot
.20922 .37489 Mdot
.46215 .45168 Mdot
.55228 .68497 Mdot
.54041 .65083 Mdot
.60088 .33527 Mdot
.31695 .78048 Mdot
.38302 .45525 Mdot
.42338 .4547 Mdot
.24828 .56779 Mdot
.32067 .65027 Mdot
.4057 .44728 Mdot
.39074 .45248 Mdot
.55898 .64496 Mdot
.35158 .3901 Mdot
.32738 .52173 Mdot
.30119 .32225 Mdot
.55566 .62824 Mdot
.44828 .61176 Mdot
.62783 .53803 Mdot
.58541 .37206 Mdot
.33839 .62357 Mdot
.61679 .33403 Mdot
.62687 .52104 Mdot
.39204 .45135 Mdot
.53004 .67853 Mdot
.26873 .60173 Mdot
.55436 .63744 Mdot
.71515 .33773 Mdot
.31981 .62955 Mdot
.4735 .65481 Mdot
.20696 .70494 Mdot
.71708 .67246 Mdot
.50193 .64152 Mdot
.58987 .35149 Mdot
.72166 .50163 Mdot
.44126 .43197 Mdot
.29744 .71904 Mdot
.39958 .46289 Mdot
.30112 .38468 Mdot
.6686 .54553 Mdot
.66402 .55064 Mdot
.39581 .42059 Mdot
.4008 .26105 Mdot
.55843 .6334 Mdot
.58778 .66879 Mdot
.40793 .38028 Mdot
.55729 .66762 Mdot
.42143 .447 Mdot
.67718 .51196 Mdot
.2037 .63583 Mdot
.42667 .429 Mdot
.47776 .39611 Mdot
.40495 .73374 Mdot
.7556 .69767 Mdot
.66765 .3205 Mdot
.56044 .83507 Mdot
.63211 .20835 Mdot
.55676 .666 Mdot
.44675 .38105 Mdot
.44695 .61411 Mdot
.63614 .5583 Mdot
.60241 .6242 Mdot
.39961 .45297 Mdot
.40151 .46031 Mdot
.43777 .47722 Mdot
.44958 .41898 Mdot
.33394 .7613 Mdot
.40487 .55023 Mdot
.25672 .45469 Mdot
.45026 .39931 Mdot
.53084 .23683 Mdot
.53638 .67841 Mdot
.29674 .65332 Mdot
.58971 .38592 Mdot
.45889 .40759 Mdot
.40877 .62902 Mdot
.5199 .64822 Mdot
.55738 .14158 Mdot
.54477 .68575 Mdot
.64717 .49738 Mdot
.53285 .63985 Mdot
.43291 .41395 Mdot
.35436 .62175 Mdot
.48312 .57758 Mdot
.71698 .63805 Mdot
.68065 .52621 Mdot
.42311 .41411 Mdot
.59367 .56484 Mdot
.68491 .51066 Mdot
.78093 .61366 Mdot
.34688 .62097 Mdot
.46303 .26124 Mdot
.38484 .59886 Mdot
.39943 .38326 Mdot
.39625 .38581 Mdot
.5397 .62271 Mdot
.52822 .64438 Mdot
.38549 .60064 Mdot
.33519 .80332 Mdot
.5912 .3258 Mdot
.36927 .60467 Mdot
.47343 .46594 Mdot
.51001 .51954 Mdot
.35701 .61766 Mdot
.6331 .32396 Mdot
.54775 .64688 Mdot
.36514 .65228 Mdot
.43537 .4839 Mdot
.58333 .23299 Mdot
.56234 .35314 Mdot
.61737 .53383 Mdot
.57723 .29514 Mdot
.66227 .4833 Mdot
.54329 .69798 Mdot
.65322 .53627 Mdot
.56946 .64218 Mdot
.45615 .7526 Mdot
.39304 .66168 Mdot
.49823 .65454 Mdot
.5327 .68976 Mdot
.65324 .53374 Mdot
.39359 .41202 Mdot
.62768 .30018 Mdot
.41782 .37119 Mdot
.39044 .47163 Mdot
.57903 .65164 Mdot
.34846 .59326 Mdot
.3062 .6173 Mdot
.49936 .22574 Mdot
.38564 .61974 Mdot
.65489 .48751 Mdot
.17587 .4751 Mdot
.69262 .58601 Mdot
.57463 .68332 Mdot
.52435 .64643 Mdot
.41837 .38531 Mdot
.6594 .51546 Mdot
.67849 .53514 Mdot
.56105 .69231 Mdot
.38288 .69498 Mdot
.44806 .37151 Mdot
.32032 .59957 Mdot
.32528 .65335 Mdot
.37075 .61494 Mdot
.32964 .60179 Mdot
.34666 .52418 Mdot
.53147 .65446 Mdot
.35355 .59029 Mdot
.42319 .38405 Mdot
.40081 .45739 Mdot
.44359 .56966 Mdot
.56871 .36399 Mdot
.4754 .42706 Mdot
.35704 .44907 Mdot
.46003 .43895 Mdot
.62265 .50632 Mdot
.50552 .44152 Mdot
.62091 .49506 Mdot
.68902 .52915 Mdot
.68411 .53362 Mdot
.66073 .61534 Mdot
.45944 .2081 Mdot
.65363 .24392 Mdot
.38044 .413 Mdot
.56503 .78976 Mdot
.64931 .51766 Mdot
.17353 .51053 Mdot
.52805 .76758 Mdot
.45418 .46216 Mdot
.6985 .45322 Mdot
.66643 .51673 Mdot
.3923 .60067 Mdot
.39934 .44808 Mdot
.65477 .47007 Mdot
.57144 .34208 Mdot
.40152 .37732 Mdot
.61693 .50317 Mdot
.35793 .634 Mdot
.61524 .37091 Mdot
.34231 .65895 Mdot
.68233 .53667 Mdot
.37107 .48484 Mdot
.15371 .38131 Mdot
.69876 .50894 Mdot
.63768 .77417 Mdot
.3675 .35287 Mdot
.39677 .41213 Mdot
.639 .47583 Mdot
.33072 .66313 Mdot
.54928 .699 Mdot
.56716 .48738 Mdot
.35871 .65185 Mdot
.66356 .55088 Mdot
.64789 .48132 Mdot
.68032 .52755 Mdot
.33378 .6513 Mdot
.47591 .44647 Mdot
.35853 .64909 Mdot
.53768 .63789 Mdot
.43464 .3964 Mdot
.72071 .29445 Mdot
.55057 .78687 Mdot
.38174 .59089 Mdot
.63728 .49805 Mdot
.55752 .36352 Mdot
.43368 .4242 Mdot
.55002 .79139 Mdot
.39488 .40755 Mdot
.57927 .64917 Mdot
.22178 .43945 Mdot
.27583 .61981 Mdot
.43191 .37792 Mdot
.4211 .3861 Mdot
.58677 .66738 Mdot
.42284 .41896 Mdot
.45665 .39643 Mdot
.66272 .61918 Mdot
.34543 .64944 Mdot
.43257 .43681 Mdot
.63535 .51955 Mdot
.69961 .60153 Mdot
.45832 .37796 Mdot
.72084 .55264 Mdot
.44851 .26832 Mdot
.21712 .4564 Mdot
.39864 .46199 Mdot
.49847 .49118 Mdot
.45229 .43013 Mdot
.42698 .46768 Mdot
.41302 .38982 Mdot
.39142 .80197 Mdot
.61775 .50994 Mdot
.67103 .5332 Mdot
.56413 .36396 Mdot
.45135 .26723 Mdot
.58872 .36042 Mdot
.54528 .64613 Mdot
.72181 .39841 Mdot
.62014 .49642 Mdot
.37052 .62838 Mdot
.43748 .46588 Mdot
.69842 .50843 Mdot
.4592 .4438 Mdot
.4316 .41215 Mdot
.67916 .48851 Mdot
.62372 .53342 Mdot
.76153 .40558 Mdot
.56519 .35601 Mdot
.35997 .60451 Mdot
.46479 .40055 Mdot
.60871 .32629 Mdot
.38977 .45861 Mdot
.51448 .2938 Mdot
.36173 .60687 Mdot
.35002 .64942 Mdot
.30831 .61169 Mdot
.39134 .44802 Mdot
.43213 .4182 Mdot
.56959 .65206 Mdot
.38129 .58692 Mdot
.572 .67554 Mdot
.56575 .53648 Mdot
.74222 .48624 Mdot
.39964 .45325 Mdot
.54608 .74423 Mdot
.5767 .36317 Mdot
.64287 .48697 Mdot
.38021 .22683 Mdot
.56356 .36325 Mdot
.41009 .40752 Mdot
.69028 .51425 Mdot
.5787 .34681 Mdot
.36816 .31681 Mdot
.53294 .1574 Mdot
.56171 .37164 Mdot
.42404 .38411 Mdot
.34535 .41388 Mdot
.54809 .83816 Mdot
.56765 .37401 Mdot
.52512 .65598 Mdot
.39123 .44652 Mdot
.37341 .56661 Mdot
.6175 .33346 Mdot
.75466 .60836 Mdot
.67169 .51827 Mdot
.57753 .22036 Mdot
.39925 .515 Mdot
.27518 .67553 Mdot
.5761 .37202 Mdot
.34168 .6312 Mdot
.42996 .34793 Mdot
.45447 .44182 Mdot
.5656 .37046 Mdot
.50932 .64416 Mdot
.66778 .50296 Mdot
.70515 .61683 Mdot
.33329 .65167 Mdot
.52109 .61887 Mdot
.63257 .501 Mdot
.67019 .73014 Mdot
.26583 .35647 Mdot
.35248 .42059 Mdot
.52824 .83306 Mdot
.61611 .68819 Mdot
.45409 .47248 Mdot
.55332 .36976 Mdot
.5955 .67449 Mdot
.52939 .67994 Mdot
.5515 .67129 Mdot
.46694 .76355 Mdot
.46575 .52849 Mdot
.62542 .47651 Mdot
.57719 .62427 Mdot
.58548 .37116 Mdot
.56941 .25649 Mdot
.38371 .46826 Mdot
.43648 .43065 Mdot
.45038 .38796 Mdot
.46328 .41443 Mdot
.44939 .43884 Mdot
.56441 .67265 Mdot
.44163 .75198 Mdot
.45211 .54653 Mdot
.36071 .6123 Mdot
.74137 .39221 Mdot
.64458 .52921 Mdot
.62075 .47815 Mdot
.57535 .34537 Mdot
.73183 .66849 Mdot
.65031 .56817 Mdot
.64372 .50735 Mdot
.46695 .45423 Mdot
.36582 .64216 Mdot
.38642 .36287 Mdot
.42231 .38513 Mdot
.6569 .48969 Mdot
.52708 .57903 Mdot
.32872 .5488 Mdot
.51077 .36247 Mdot
.57653 .39283 Mdot
.49377 .517 Mdot
.55963 .35924 Mdot
.37391 .4137 Mdot
.16672 .53199 Mdot
.62627 .5206 Mdot
.65474 .50294 Mdot
.57352 .36574 Mdot
.31029 .708 Mdot
.33513 .61974 Mdot
.53165 .73124 Mdot
.54777 .64068 Mdot
.38716 .39658 Mdot
.28986 .30683 Mdot
.42082 .32915 Mdot
.69707 .38313 Mdot
.55171 .67709 Mdot
.65455 .54261 Mdot
.39393 .37417 Mdot
.43257 .38813 Mdot
.57509 .3603 Mdot
.7885 .42453 Mdot
.36081 .40885 Mdot
.81837 .58088 Mdot
.43018 .20142 Mdot
.52638 .19996 Mdot
.45357 .4473 Mdot
.34312 .65058 Mdot
.62103 .54335 Mdot
.59395 .37411 Mdot
.46648 .47595 Mdot
.57455 .18059 Mdot
.32606 .61741 Mdot
.53942 .6725 Mdot
.51268 .566 Mdot
.57629 .26848 Mdot
.40869 .47404 Mdot
.3973 .45753 Mdot
.42013 .47043 Mdot
.46484 .14303 Mdot
.62055 .5034 Mdot
.38811 .59552 Mdot
.59714 .33496 Mdot
.38159 .62369 Mdot
.66271 .53575 Mdot
.50117 .62445 Mdot
.38986 .41337 Mdot
.32376 .62215 Mdot
.34064 .6303 Mdot
.54942 .68926 Mdot
.56357 .70147 Mdot
.54026 .55305 Mdot
.40163 .43981 Mdot
.6983 .51935 Mdot
.35562 .58797 Mdot
.5062 .49176 Mdot
.59727 .35106 Mdot
.5514 .64523 Mdot
.45447 .40394 Mdot
.62077 .5169 Mdot
.3936 .48277 Mdot
.34783 .60997 Mdot
.6442 .50788 Mdot
.7675 .49148 Mdot
.57578 .38005 Mdot
.40938 .45799 Mdot
.611 .3088 Mdot
.67439 .53724 Mdot
.44314 .43105 Mdot
.68426 .7319 Mdot
.63243 .32359 Mdot
.73858 .61553 Mdot
.68677 .52608 Mdot
.64435 .59731 Mdot
.38612 .63006 Mdot
.47838 .77945 Mdot
.65196 .49912 Mdot
.64024 .7457 Mdot
.78302 .47711 Mdot
.38424 .37715 Mdot
.37933 .61006 Mdot
.61779 .67296 Mdot
.7531 .30226 Mdot
.62787 .79358 Mdot
.41358 .42222 Mdot
.66638 .47565 Mdot
.57587 .35465 Mdot
.57871 .68003 Mdot
.73975 .52748 Mdot
.62377 .36652 Mdot
.67557 .55011 Mdot
.41251 .3904 Mdot
.34982 .63253 Mdot
.55538 .65047 Mdot
.45245 .73803 Mdot
.63889 .52852 Mdot
.63405 .50785 Mdot
.40068 .37282 Mdot
.58688 .36504 Mdot
.5159 .79408 Mdot
.67965 .51601 Mdot
.44985 .19822 Mdot
.67992 .46532 Mdot
.60007 .32529 Mdot
.45454 .42246 Mdot
.50007 .22128 Mdot
.46694 .39174 Mdot
.70696 .73167 Mdot
.64845 .53049 Mdot
.35365 .60876 Mdot
.42847 .47589 Mdot
.32157 .31684 Mdot
.65239 .48779 Mdot
.51204 .49674 Mdot
.66041 .37067 Mdot
.53711 .64812 Mdot
.376 .22876 Mdot
.41228 .45103 Mdot
.55928 .63395 Mdot
.5772 .36022 Mdot
.39989 .43023 Mdot
.43467 .41742 Mdot
.35983 .58137 Mdot
.55404 .69013 Mdot
.7748 .42328 Mdot
.52616 .64027 Mdot
.53106 .67537 Mdot
.33941 .58728 Mdot
.43279 .44703 Mdot
.6455 .49737 Mdot
.66535 .51517 Mdot
.42704 .48827 Mdot
.17923 .61597 Mdot
.33195 .62208 Mdot
.62027 .54642 Mdot
.44973 .14451 Mdot
.41025 .49392 Mdot
.36068 .24166 Mdot
.79206 .43398 Mdot
.58146 .64622 Mdot
.42579 .38373 Mdot
.35991 .63221 Mdot
.62759 .43662 Mdot
.63571 .50455 Mdot
.4324 .48134 Mdot
.55393 .65195 Mdot
.56641 .34719 Mdot
.67603 .49618 Mdot
.70506 .38265 Mdot
.42019 .4648 Mdot
.68681 .44494 Mdot
.65882 .4763 Mdot
.82914 .40218 Mdot
.64676 .70157 Mdot
.37866 .60635 Mdot
.43338 .41005 Mdot
.39257 .59642 Mdot
.59319 .33442 Mdot
.5163 .56369 Mdot
.54775 .64948 Mdot
.41209 .53008 Mdot
.15207 .47454 Mdot
.67996 .52898 Mdot
.38854 .59431 Mdot
.42668 .3762 Mdot
.38592 .73229 Mdot
.41839 .45062 Mdot
.34137 .42551 Mdot
.57977 .30464 Mdot
.58232 .66233 Mdot
.56296 .63842 Mdot
.44512 .42115 Mdot
.60381 .33016 Mdot
.64253 .53081 Mdot
.66131 .49557 Mdot
.86333 .52041 Mdot
.46798 .63509 Mdot
.36842 .27549 Mdot
.4036 .46089 Mdot
.68159 .54563 Mdot
.72701 .57902 Mdot
.55759 .68536 Mdot
.43703 .49004 Mdot
.68468 .49725 Mdot
.64216 .3295 Mdot
.38758 .29634 Mdot
.45338 .43663 Mdot
.48586 .41813 Mdot
.54059 .64173 Mdot
.4658 .51965 Mdot
.6521 .54719 Mdot
.37357 .47135 Mdot
.49453 .66684 Mdot
.38148 .3067 Mdot
.47775 .16728 Mdot
.36027 .60425 Mdot
.69322 .36353 Mdot
.56518 .67243 Mdot
.48398 .40424 Mdot
.6143 .34258 Mdot
.63199 .55821 Mdot
.61929 .51265 Mdot
.41103 .39808 Mdot
.373 .40155 Mdot
.40067 .23085 Mdot
.37234 .63259 Mdot
.53462 .67516 Mdot
.39278 .43392 Mdot
.4985 .71929 Mdot
.46199 .40796 Mdot
.57401 .65732 Mdot
.14043 .39681 Mdot
.42318 .3729 Mdot
.42236 .45257 Mdot
.53265 .78916 Mdot
.34407 .65587 Mdot
.38558 .58647 Mdot
.30907 .27347 Mdot
.404 .46075 Mdot
.40767 .21589 Mdot
.35628 .60241 Mdot
.33765 .61547 Mdot
.67353 .62778 Mdot
.43333 .42687 Mdot
.44664 .50767 Mdot
.57714 .64502 Mdot
.52788 .67141 Mdot
.34856 .65239 Mdot
.36082 .40217 Mdot
.57891 .69213 Mdot
.41456 .79839 Mdot
.65864 .51713 Mdot
.16813 .55434 Mdot
.32975 .62119 Mdot
.55908 .71832 Mdot
.55479 .68239 Mdot
.57027 .15169 Mdot
.6027 .46932 Mdot
.39199 .41462 Mdot
.41013 .46196 Mdot
.57889 .36826 Mdot
.45241 .38741 Mdot
.66485 .55017 Mdot
.55745 .66835 Mdot
.31923 .3592 Mdot
.3658 .60435 Mdot
.4091 .44243 Mdot
.75139 .65073 Mdot
.78539 .57636 Mdot
.69395 .3496 Mdot
.33113 .62991 Mdot
.37965 .59828 Mdot
.64049 .53978 Mdot
.6671 .4764 Mdot
.44314 .44829 Mdot
.58516 .67835 Mdot
.38148 .58756 Mdot
.57717 .65603 Mdot
.62612 .51864 Mdot
.64444 .50068 Mdot
.61938 .52697 Mdot
.37799 .46249 Mdot
.639 .51185 Mdot
.75635 .49588 Mdot
.53225 .61692 Mdot
.34334 .58157 Mdot
.38812 .19931 Mdot
.45981 .74122 Mdot
.30909 .59906 Mdot
.6173 .32968 Mdot
.67754 .53422 Mdot
.54114 .63545 Mdot
.44478 .40505 Mdot
.46343 .42662 Mdot
.65966 .58985 Mdot
.5459 .63096 Mdot
.59275 .3358 Mdot
.55798 .63554 Mdot
.60067 .33498 Mdot
.65272 .41523 Mdot
.46608 .40839 Mdot
.36757 .43233 Mdot
.56073 .67442 Mdot
.64129 .51042 Mdot
.67281 .5264 Mdot
.56603 .37658 Mdot
.55211 .58083 Mdot
.68525 .50949 Mdot
.33769 .61145 Mdot
.35368 .53601 Mdot
.64428 .48073 Mdot
.40129 .44788 Mdot
.54088 .29588 Mdot
.29339 .72078 Mdot
.47465 .39608 Mdot
.66891 .62446 Mdot
.25565 .6196 Mdot
.44389 .46897 Mdot
.28104 .71516 Mdot
.61937 .6006 Mdot
.38288 .63218 Mdot
.66338 .54675 Mdot
.67333 .56888 Mdot
.50144 .42152 Mdot
.59261 .3885 Mdot
.45127 .4842 Mdot
.32553 .62836 Mdot
.40216 .59938 Mdot
.54037 .21354 Mdot
.66127 .7647 Mdot
.57794 .35075 Mdot
.5732 .35139 Mdot
.65283 .4972 Mdot
.77549 .70643 Mdot
.35284 .47031 Mdot
.59193 .3373 Mdot
.38887 .66996 Mdot
.41229 .39251 Mdot
.43997 .28508 Mdot
.57212 .41773 Mdot
.34276 .65241 Mdot
.52884 .23169 Mdot
.64697 .49163 Mdot
.38588 .62088 Mdot
.48338 .7072 Mdot
.47743 .42876 Mdot
.36323 .60682 Mdot
.57409 .65337 Mdot
.67223 .68351 Mdot
.34086 .60392 Mdot
.52972 .29403 Mdot
.57233 .6916 Mdot
.50464 .49577 Mdot
.48006 .23657 Mdot
.46217 .89949 Mdot
.56208 .66938 Mdot
.64626 .4823 Mdot
.66586 .51421 Mdot
.66007 .49511 Mdot
.37912 .62769 Mdot
.67742 .53612 Mdot
.37384 .62972 Mdot
.5642 .81592 Mdot
.33176 .7268 Mdot
.59159 .33866 Mdot
.7056 .61958 Mdot
.36328 .62631 Mdot
.16877 .50532 Mdot
.15262 .6069 Mdot
.42435 .38295 Mdot
.51874 .65622 Mdot
.5881 .34161 Mdot
.81339 .59252 Mdot
.5857 .35461 Mdot
.49547 .20347 Mdot
.19669 .48312 Mdot
.41653 .44234 Mdot
.30144 .52361 Mdot
.60168 .37545 Mdot
.33298 .63859 Mdot
.44208 .42974 Mdot
.58411 .45503 Mdot
.58317 .35852 Mdot
.58095 .33307 Mdot
.4393 .44301 Mdot
.36065 .59211 Mdot
.64079 .49259 Mdot
.52248 .65603 Mdot
.62137 .34652 Mdot
.37465 .35861 Mdot
.48042 .40975 Mdot
.3933 .40471 Mdot
.44951 .56739 Mdot
.5513 .35161 Mdot
.55692 .66517 Mdot
.35217 .79234 Mdot
.69264 .50879 Mdot
.59059 .45605 Mdot
.45854 .18806 Mdot
.64567 .61807 Mdot
.65011 .52929 Mdot
.66148 .54176 Mdot
.44966 .44147 Mdot
.54692 .39668 Mdot
.18932 .49995 Mdot
.57911 .58505 Mdot
.61683 .52482 Mdot
.66525 .49892 Mdot
.39709 .60056 Mdot
.5221 .2046 Mdot
.47189 .47078 Mdot
.58851 .68486 Mdot
.61942 .51873 Mdot
.38008 .74909 Mdot
.58724 .36778 Mdot
.19366 .46804 Mdot
.46892 .41257 Mdot
.39156 .41992 Mdot
.54652 .65678 Mdot
.56659 .65127 Mdot
.6179 .43525 Mdot
.5123 .20333 Mdot
.2612 .62498 Mdot
.43049 .73382 Mdot
.22121 .47005 Mdot
.39885 .59624 Mdot
.38134 .59061 Mdot
.72347 .64733 Mdot
.52285 .64396 Mdot
.43815 .47266 Mdot
.38676 .60583 Mdot
.59134 .46383 Mdot
.36659 .54199 Mdot
.40158 .27226 Mdot
.37001 .24557 Mdot
.41533 .40872 Mdot
.35188 .64532 Mdot
.33864 .6559 Mdot
.31415 .63837 Mdot
.61048 .59647 Mdot
.43735 .45395 Mdot
.41456 .41484 Mdot
.44892 .46091 Mdot
.36166 .7155 Mdot
.43478 .46219 Mdot
.46777 .77604 Mdot
.52296 .54936 Mdot
.2629 .39543 Mdot
.3673 .46596 Mdot
.58632 .64836 Mdot
.40164 .46952 Mdot
.60254 .3305 Mdot
.40794 .38702 Mdot
.39739 .27503 Mdot
.54632 .68091 Mdot
.36837 .52865 Mdot
.46064 .75058 Mdot
.44789 .47372 Mdot
.61566 .36752 Mdot
.59739 .72689 Mdot
.70981 .28002 Mdot
.61008 .30125 Mdot
.33596 .61318 Mdot
.6551 .52172 Mdot
.54247 .63441 Mdot
.64835 .50275 Mdot
.36726 .44911 Mdot
.71766 .66015 Mdot
.8047 .55187 Mdot
.57093 .54601 Mdot
.46247 .41433 Mdot
.4199 .50701 Mdot
.34189 .61085 Mdot
.69146 .50825 Mdot
.31631 .59471 Mdot
.42246 .47453 Mdot
.60442 .34114 Mdot
.57935 .36159 Mdot
.56832 .49149 Mdot
.81202 .42616 Mdot
.39187 .7753 Mdot
.54942 .65775 Mdot
.67742 .50946 Mdot
.6092 .36338 Mdot
.61287 .76503 Mdot
.56795 .70163 Mdot
.58657 .66059 Mdot
.54133 .679 Mdot
.38476 .43692 Mdot
.61747 .50517 Mdot
.26629 .39196 Mdot
.67174 .55015 Mdot
.42449 .41712 Mdot
.62247 .50248 Mdot
.68718 .50406 Mdot
.60349 .36685 Mdot
.53827 .6787 Mdot
.62991 .52693 Mdot
.39513 .38531 Mdot
.35973 .59728 Mdot
.51237 .6882 Mdot
.45133 .30356 Mdot
.67272 .75575 Mdot
.35615 .34313 Mdot
.32326 .64802 Mdot
.75304 .3087 Mdot
.58704 .65702 Mdot
.37841 .70039 Mdot
.75693 .39904 Mdot
.37747 .41352 Mdot
.15992 .5872 Mdot
.61944 .4796 Mdot
.68083 .49403 Mdot
.45356 .42304 Mdot
.70447 .48466 Mdot
.41299 .445 Mdot
.62811 .5084 Mdot
.7302 .55352 Mdot
.41016 .6055 Mdot
.64172 .51621 Mdot
.37675 .47257 Mdot
.43916 .41997 Mdot
.34756 .65094 Mdot
.6444 .47602 Mdot
.45865 .48501 Mdot
.86416 .50192 Mdot
.56949 .65609 Mdot
.62015 .63677 Mdot
.54009 .30705 Mdot
.56656 .67277 Mdot
.37095 .60634 Mdot
.38793 .46996 Mdot
.57626 .35931 Mdot
.36285 .62766 Mdot
.36549 .30156 Mdot
.58023 .37973 Mdot
.15617 .5386 Mdot
.33416 .65416 Mdot
.6546 .48258 Mdot
.6124 .33607 Mdot
.45677 .38831 Mdot
.63032 .5567 Mdot
.64798 .71569 Mdot
.64873 .52779 Mdot
.45092 .45084 Mdot
.73378 .5993 Mdot
.53269 .67377 Mdot
.4109 .42332 Mdot
.67761 .49197 Mdot
.6704 .61886 Mdot
.38208 .43064 Mdot
.44861 .42636 Mdot
.48013 .17406 Mdot
.19883 .41602 Mdot
.59241 .35201 Mdot
.31991 .65598 Mdot
.42253 .38385 Mdot
.57989 .33527 Mdot
.71674 .43959 Mdot
.3875 .43129 Mdot
.32657 .61478 Mdot
.40709 .49705 Mdot
.64997 .47519 Mdot
.57267 .66996 Mdot
.58904 .57345 Mdot
.57172 .34191 Mdot
.56084 .86249 Mdot
.63237 .54051 Mdot
.36994 .43095 Mdot
.45621 .40129 Mdot
.6512 .28894 Mdot
.38235 .63182 Mdot
.21927 .60014 Mdot
.40941 .45829 Mdot
.35951 .71106 Mdot
.40267 .43107 Mdot
.61313 .49831 Mdot
.33522 .61877 Mdot
.42639 .45607 Mdot
.48935 .68196 Mdot
.47088 .38804 Mdot
.56473 .36202 Mdot
.53956 .79238 Mdot
.47843 .43658 Mdot
.13197 .46242 Mdot
.60824 .41689 Mdot
.64022 .51743 Mdot
.7703 .58754 Mdot
.87849 .54794 Mdot
.47132 .76237 Mdot
.3815 .62148 Mdot
.80151 .48044 Mdot
.64498 .49773 Mdot
.76137 .57014 Mdot
.74661 .29914 Mdot
.44043 .41369 Mdot
.40977 .47457 Mdot
.61615 .27148 Mdot
.68619 .53345 Mdot
.69492 .53471 Mdot
.36871 .39977 Mdot
.48712 .41176 Mdot
.63981 .50491 Mdot
.3833 .39405 Mdot
.36162 .42252 Mdot
.5197 .66193 Mdot
.32689 .61985 Mdot
.58368 .66599 Mdot
.58116 .689 Mdot
.46601 .81164 Mdot
.61803 .40581 Mdot
.57396 .65985 Mdot
.59342 .66385 Mdot
.4362 .28531 Mdot
.4307 .23849 Mdot
.61803 .33527 Mdot
.83244 .44423 Mdot
.66496 .50093 Mdot
.43271 .45166 Mdot
.32839 .65409 Mdot
.26741 .62404 Mdot
.74821 .45576 Mdot
.18012 .55032 Mdot
.43117 .47433 Mdot
.64947 .48827 Mdot
.61099 .59763 Mdot
.39082 .3594 Mdot
.67555 .47335 Mdot
.3931 .43971 Mdot
.65774 .5535 Mdot
.31684 .4599 Mdot
.64069 .74461 Mdot
.70126 .4988 Mdot
.32309 .59716 Mdot
.39364 .42801 Mdot
.32579 .63025 Mdot
.56025 .68334 Mdot
.6138 .33336 Mdot
.59437 .35428 Mdot
.44189 .43553 Mdot
.36884 .48962 Mdot
.66439 .42689 Mdot
.43461 .4234 Mdot
.41705 .39095 Mdot
.61973 .60006 Mdot
.41677 .3884 Mdot
.46732 .42789 Mdot
.45801 .45065 Mdot
.42014 .48059 Mdot
.5294 .67332 Mdot
.73528 .66429 Mdot
.49434 .39746 Mdot
.49022 .39835 Mdot
.55288 .69856 Mdot
.78076 .42145 Mdot
.58889 .68038 Mdot
.71341 .27726 Mdot
.57063 .64012 Mdot
.59938 .34681 Mdot
.68744 .31216 Mdot
.38105 .51331 Mdot
.34579 .59053 Mdot
.58184 .69973 Mdot
.59457 .33293 Mdot
.55406 .66994 Mdot
.62945 .50044 Mdot
.49178 .16277 Mdot
.39615 .63763 Mdot
.42514 .55401 Mdot
.60992 .65662 Mdot
.6977 .68876 Mdot
.63471 .53876 Mdot
.32599 .63658 Mdot
.32347 .54417 Mdot
.46504 .41673 Mdot
.58365 .33265 Mdot
.44343 .44534 Mdot
.54191 .68591 Mdot
.65089 .49166 Mdot
.60596 .79768 Mdot
.57522 .36063 Mdot
.41372 .1912 Mdot
.67088 .52333 Mdot
.46509 .44359 Mdot
.5816 .6901 Mdot
.32417 .23826 Mdot
.58288 .66027 Mdot
.20409 .54616 Mdot
.39301 .61091 Mdot
.57524 .83246 Mdot
.37269 .62075 Mdot
.65456 .71804 Mdot
.3094 .21381 Mdot
.74425 .66377 Mdot
.36134 .59351 Mdot
.51973 .60396 Mdot
.40958 .40465 Mdot
.39258 .40556 Mdot
.62489 .76742 Mdot
.31837 .65264 Mdot
.44343 .39256 Mdot
.70852 .57542 Mdot
.53234 .60958 Mdot
.32975 .27076 Mdot
.65248 .53944 Mdot
.41036 .44806 Mdot
.57522 .63365 Mdot
.55344 .63103 Mdot
.64779 .55071 Mdot
.58755 .66108 Mdot
.41607 .41658 Mdot
.36487 .62546 Mdot
.73088 .5228 Mdot
.60189 .35724 Mdot
.79422 .6532 Mdot
.57803 .33022 Mdot
.65065 .52957 Mdot
.41922 .37107 Mdot
.64438 .50156 Mdot
.90424 .50783 Mdot
.40811 .41368 Mdot
.35508 .60375 Mdot
.42718 .38806 Mdot
.39525 .42477 Mdot
.42515 .47896 Mdot
.63585 .49931 Mdot
.51194 .35238 Mdot
.3898 .38854 Mdot
.54638 .64897 Mdot
.23869 .44213 Mdot
.47398 .44454 Mdot
.69639 .55307 Mdot
.4296 .25286 Mdot
.58909 .62119 Mdot
.3725 .64793 Mdot
.64341 .52144 Mdot
.3668 .601 Mdot
.31664 .70194 Mdot
.37073 .60666 Mdot
.23376 .51325 Mdot
.32781 .53145 Mdot
.32042 .33263 Mdot
.30738 .38281 Mdot
.48824 .59885 Mdot
.31915 .65457 Mdot
.54678 .36008 Mdot
.37194 .58672 Mdot
.35291 .65302 Mdot
.10306 .39377 Mdot
.34114 .59056 Mdot
.40318 .45275 Mdot
.47213 .44289 Mdot
.68734 .70956 Mdot
.49837 .27961 Mdot
.43572 .39569 Mdot
.44268 .39682 Mdot
.61336 .35363 Mdot
.34044 .70422 Mdot
.73896 .62252 Mdot
.18664 .43488 Mdot
.78438 .55529 Mdot
.44169 .44362 Mdot
.41848 .3829 Mdot
.43002 .35642 Mdot
.22761 .32438 Mdot
.47129 .82104 Mdot
.40441 .57633 Mdot
.42942 .35854 Mdot
.73748 .69022 Mdot
.41958 .47732 Mdot
.39124 .45335 Mdot
.41306 .40732 Mdot
.64512 .49707 Mdot
.35475 .65678 Mdot
.41157 .48121 Mdot
.63036 .28994 Mdot
.39381 .45173 Mdot
.65146 .619 Mdot
.68098 .78794 Mdot
.41263 .45162 Mdot
.38625 .64229 Mdot
.39507 .40195 Mdot
.37239 .6415 Mdot
.33614 .64495 Mdot
.39775 .36752 Mdot
.21993 .47419 Mdot
.39636 .62206 Mdot
.42518 .41691 Mdot
.6363 .49005 Mdot
.82529 .40212 Mdot
.44963 .45222 Mdot
.6148 .33227 Mdot
.40868 .4612 Mdot
.62158 .35737 Mdot
.42226 .3925 Mdot
.63323 .54236 Mdot
.27556 .65521 Mdot
.65526 .50136 Mdot
.51192 .83488 Mdot
.62164 .53012 Mdot
.46015 .16727 Mdot
.31982 .64363 Mdot
.71753 .61166 Mdot
.24043 .65694 Mdot
.62674 .64552 Mdot
.53658 .46104 Mdot
.48827 .5534 Mdot
.58592 .67653 Mdot
.39031 .6142 Mdot
.41608 .66188 Mdot
.76045 .42572 Mdot
.71599 .35524 Mdot
.68207 .50606 Mdot
.31721 .78368 Mdot
.18964 .60248 Mdot
.37532 .40655 Mdot
.28519 .53889 Mdot
.26451 .48124 Mdot
.4179 .47784 Mdot
.40181 .47777 Mdot
.6143 .57235 Mdot
.39273 .38343 Mdot
.50496 .72434 Mdot
.65408 .53168 Mdot
.59307 .33215 Mdot
.34729 .60611 Mdot
.56656 .34635 Mdot
.75671 .40636 Mdot
.48345 .55276 Mdot
.62653 .51 Mdot
.48358 .42974 Mdot
.44546 .40226 Mdot
.36242 .64639 Mdot
.37716 .55696 Mdot
.36303 .58572 Mdot
.58327 .34693 Mdot
.65956 .52998 Mdot
.30855 .73574 Mdot
.45024 .40468 Mdot
.3417 .62899 Mdot
.54357 .44556 Mdot
.42526 .38445 Mdot
.56149 .67906 Mdot
.40513 .40676 Mdot
.35608 .59487 Mdot
.41706 .38842 Mdot
.37429 .6206 Mdot
.65599 .51911 Mdot
.45863 .45919 Mdot
.45511 .42905 Mdot
.36689 .21454 Mdot
.59795 .33881 Mdot
.32036 .62688 Mdot
.58221 .49248 Mdot
.44511 .38735 Mdot
.6855 .63587 Mdot
.39499 .44421 Mdot
.28893 .652 Mdot
.37489 .42691 Mdot
.62339 .63182 Mdot
.49521 .42399 Mdot
.44534 .45472 Mdot
.57075 .43904 Mdot
.25949 .49445 Mdot
.36627 .51496 Mdot
.59727 .67067 Mdot
.32397 .60844 Mdot
.33407 .27163 Mdot
.66184 .45495 Mdot
.68284 .48643 Mdot
.54854 .25009 Mdot
.43239 .48191 Mdot
.41875 .44367 Mdot
.60023 .65301 Mdot
.56886 .35612 Mdot
.33102 .63185 Mdot
.60068 .33511 Mdot
.39878 .21233 Mdot
.57241 .37115 Mdot
.61634 .48598 Mdot
.69111 .44712 Mdot
.33023 .7559 Mdot
.61176 .3571 Mdot
.35935 .59177 Mdot
.73323 .4906 Mdot
.44697 .47962 Mdot
.60239 .41897 Mdot
.60765 .34656 Mdot
.41014 .84344 Mdot
.46701 .42956 Mdot
.53466 .45921 Mdot
.57742 .66598 Mdot
.61473 .34487 Mdot
.57049 .68956 Mdot
.44504 .4086 Mdot
.74101 .61489 Mdot
.38197 .61911 Mdot
.55188 .69519 Mdot
.35973 .4702 Mdot
.58734 .34062 Mdot
.61851 .51032 Mdot
.60352 .66736 Mdot
.59306 .68068 Mdot
.78902 .41596 Mdot
.58501 .81251 Mdot
.66205 .52852 Mdot
.26606 .34984 Mdot
.56655 .63627 Mdot
.45134 .47585 Mdot
.35396 .69862 Mdot
.39134 .41537 Mdot
.45184 .78639 Mdot
.64332 .52756 Mdot
.71018 .68376 Mdot
.41918 .38454 Mdot
.43668 .46821 Mdot
.39925 .62969 Mdot
.66255 .50641 Mdot
.35732 .6202 Mdot
.3193 .61495 Mdot
.65758 .51882 Mdot
.37769 .61076 Mdot
.59507 .37937 Mdot
.45728 .66253 Mdot
.54906 .63985 Mdot
.53673 .6532 Mdot
.66216 .49582 Mdot
.63789 .51977 Mdot
.64457 .50636 Mdot
.40454 .40676 Mdot
.33137 .62661 Mdot
.4317 .40491 Mdot
.39594 .46108 Mdot
.23895 .42816 Mdot
.34677 .6574 Mdot
.42141 .40581 Mdot
.59352 .44587 Mdot
.57314 .40755 Mdot
.63296 .49127 Mdot
.57517 .66271 Mdot
.71408 .58523 Mdot
.63512 .72272 Mdot
.40711 .44644 Mdot
.64036 .36556 Mdot
.36337 .58944 Mdot
.57881 .35773 Mdot
.56706 .33445 Mdot
.58808 .35331 Mdot
.60373 .61052 Mdot
.31664 .64206 Mdot
.18327 .44596 Mdot
.41391 .4472 Mdot
.45319 .55986 Mdot
.40352 .65464 Mdot
.64427 .416 Mdot
.57286 .66081 Mdot
.43175 .38809 Mdot
.58551 .56939 Mdot
.31794 .56545 Mdot
.39385 .41501 Mdot
.46841 .45548 Mdot
.76429 .50221 Mdot
.42562 .49654 Mdot
.39058 .587 Mdot
.32539 .24177 Mdot
.4389 .37976 Mdot
.37302 .74842 Mdot
.80316 .65316 Mdot
.40015 .44203 Mdot
.42529 .47127 Mdot
.46002 .41985 Mdot
.40497 .38857 Mdot
.38989 .63584 Mdot
.49142 .2508 Mdot
.5746 .64005 Mdot
.4514 .55546 Mdot
.52456 .66996 Mdot
.62759 .55005 Mdot
.71755 .68029 Mdot
.39195 .60869 Mdot
.57848 .3679 Mdot
.78615 .61394 Mdot
.25286 .32328 Mdot
.65317 .54719 Mdot
.41323 .79594 Mdot
.60434 .34388 Mdot
.4568 .47068 Mdot
.60854 .37221 Mdot
.6236 .49143 Mdot
.53689 .64928 Mdot
.47197 .4594 Mdot
.37478 .58894 Mdot
.33738 .60733 Mdot
.43462 .38731 Mdot
.74877 .67678 Mdot
.5666 .67911 Mdot
.59407 .68331 Mdot
.38481 .4306 Mdot
.45798 .38973 Mdot
.36176 .61773 Mdot
.67675 .51404 Mdot
.34157 .29757 Mdot
.57386 .34561 Mdot
.38125 .46664 Mdot
.41114 .39019 Mdot
.46707 .18421 Mdot
.54904 .64626 Mdot
.66596 .4723 Mdot
.37725 .42021 Mdot
.4207 .7306 Mdot
.37774 .41697 Mdot
.41182 .35761 Mdot
.63766 .48823 Mdot
.49459 .38668 Mdot
.36755 .42042 Mdot
.38134 .65467 Mdot
.58104 .68115 Mdot
.35868 .60707 Mdot
.33197 .67042 Mdot
.43941 .6031 Mdot
.55917 .67832 Mdot
.41468 .40256 Mdot
.56772 .66056 Mdot
.38774 .43006 Mdot
.41072 .37983 Mdot
.57435 .65784 Mdot
.35855 .62017 Mdot
.79925 .48587 Mdot
.743 .65741 Mdot
.4008 .38893 Mdot
.37982 .38167 Mdot
.49096 .26314 Mdot
.51723 .35949 Mdot
.41893 .47511 Mdot
.3513 .59711 Mdot
.45248 .41296 Mdot
.55935 .68904 Mdot
.60279 .37401 Mdot
.3592 .5963 Mdot
.672 .531 Mdot
.6451 .54533 Mdot
.46482 .75393 Mdot
.68835 .51612 Mdot
.40172 .47286 Mdot
.29594 .63963 Mdot
.35318 .6647 Mdot
.76772 .67995 Mdot
.66061 .51724 Mdot
.61949 .33559 Mdot
.44746 .42798 Mdot
.58393 .23315 Mdot
.56711 .62929 Mdot
.12001 .52405 Mdot
.16683 .50303 Mdot
.57063 .38548 Mdot
.18329 .54333 Mdot
.62757 .54161 Mdot
.36676 .43853 Mdot
.61035 .32934 Mdot
.64143 .53997 Mdot
.38685 .40244 Mdot
.40273 .36458 Mdot
.21467 .58648 Mdot
.46876 .59214 Mdot
.5666 .6578 Mdot
.68012 .53425 Mdot
.56588 .38589 Mdot
.6228 .47599 Mdot
.32327 .64206 Mdot
.43776 .45708 Mdot
.41384 .3696 Mdot
.67724 .52309 Mdot
.69363 .50267 Mdot
.42227 .41186 Mdot
.39293 .59793 Mdot
.60913 .56994 Mdot
.43727 .43967 Mdot
.46675 .62577 Mdot
.30624 .64076 Mdot
.65591 .53642 Mdot
.43946 .46404 Mdot
.53637 .37571 Mdot
.67334 .52106 Mdot
.63092 .49251 Mdot
.42222 .38217 Mdot
.58939 .38085 Mdot
.39135 .37509 Mdot
.56668 .64012 Mdot
.36494 .80536 Mdot
.55696 .6897 Mdot
.72918 .54263 Mdot
.36287 .47956 Mdot
.41171 .7021 Mdot
.37804 .64166 Mdot
.52743 .21899 Mdot
.71069 .57652 Mdot
.36188 .41183 Mdot
.80606 .38836 Mdot
.55505 .71978 Mdot
.76862 .65674 Mdot
.65571 .25885 Mdot
.60704 .35831 Mdot
.55234 .67155 Mdot
.42432 .47155 Mdot
.51885 .65844 Mdot
.60898 .32724 Mdot
.51444 .83244 Mdot
.4485 .45803 Mdot
.33784 .61611 Mdot
.41748 .41238 Mdot
.33155 .61837 Mdot
.41812 .38153 Mdot
.45666 .36966 Mdot
.65627 .59898 Mdot
.3908 .29611 Mdot
.3781 .43113 Mdot
.44336 .1531 Mdot
.53697 .40366 Mdot
.58413 .33528 Mdot
.43638 .4116 Mdot
.67814 .47159 Mdot
.5426 .62966 Mdot
.55684 .76505 Mdot
.64388 .49709 Mdot
.59371 .67422 Mdot
.37169 .61242 Mdot
.64759 .52402 Mdot
.65251 .54935 Mdot
.49602 .38742 Mdot
.58539 .38437 Mdot
.53583 .66863 Mdot
.42629 .45764 Mdot
.44797 .45758 Mdot
.2651 .34295 Mdot
.74699 .43628 Mdot
.37134 .55733 Mdot
.18331 .38765 Mdot
.32152 .60352 Mdot
.58734 .33667 Mdot
.63988 .49426 Mdot
.40226 .46627 Mdot
.41433 .4243 Mdot
.69497 .61959 Mdot
.38009 .58492 Mdot
.52443 .56219 Mdot
.29075 .68227 Mdot
.58543 .4863 Mdot
.43488 .26867 Mdot
.34867 .60267 Mdot
.43461 .27028 Mdot
.55345 .357 Mdot
.83907 .50165 Mdot
.41327 .28969 Mdot
.57571 .66701 Mdot
.44041 .27064 Mdot
.33863 .63393 Mdot
.38739 .3934 Mdot
.65114 .48127 Mdot
.68805 .50567 Mdot
.35688 .6135 Mdot
.63905 .46832 Mdot
.59758 .37033 Mdot
.42297 .46706 Mdot
.19501 .41423 Mdot
.47339 .73487 Mdot
.66661 .49594 Mdot
.41025 .35269 Mdot
.5422 .67988 Mdot
.43481 .3869 Mdot
.60584 .36634 Mdot
.56382 .66594 Mdot
.50479 .20238 Mdot
.51763 .6248 Mdot
.44471 .42922 Mdot
.47623 .17577 Mdot
.55913 .67352 Mdot
.52201 .3946 Mdot
.43586 .4465 Mdot
.57739 .64566 Mdot
.51256 .4177 Mdot
.67017 .68918 Mdot
.56873 .55005 Mdot
.7481 .29986 Mdot
.55497 .54243 Mdot
.65984 .48586 Mdot
.68356 .6907 Mdot
.61815 .68599 Mdot
.53621 .63776 Mdot
.68103 .48084 Mdot
.58642 .39921 Mdot
.57324 .68865 Mdot
.46345 .45915 Mdot
.39597 .44096 Mdot
.48791 .82439 Mdot
.58998 .71321 Mdot
.64989 .72601 Mdot
.51409 .76376 Mdot
.44924 .39027 Mdot
.39659 .37241 Mdot
.41645 .42897 Mdot
.4018 .60679 Mdot
.55927 .65156 Mdot
.38973 .18452 Mdot
.56223 .68136 Mdot
.20554 .4437 Mdot
.66211 .49778 Mdot
.64914 .53961 Mdot
.40903 .44981 Mdot
.52294 .46243 Mdot
.4674 .22747 Mdot
.41897 .41765 Mdot
.62521 .37032 Mdot
.55062 .79512 Mdot
.45422 .38811 Mdot
.39262 .62089 Mdot
.42872 .35199 Mdot
.39708 .3449 Mdot
.5486 .63967 Mdot
.59176 .36706 Mdot
.51569 .2141 Mdot
.53199 .65538 Mdot
.41872 .44226 Mdot
.42104 .70247 Mdot
.39909 .42165 Mdot
.39633 .39249 Mdot
.17912 .49758 Mdot
.55996 .34757 Mdot
.65013 .51033 Mdot
.58924 .35069 Mdot
.37521 .64094 Mdot
.09252 .48401 Mdot
.56809 .36782 Mdot
.47226 .22202 Mdot
.46936 .83171 Mdot
.44318 .2735 Mdot
.32555 .62654 Mdot
.59587 .38362 Mdot
.57177 .67481 Mdot
.82954 .40849 Mdot
.23871 .62718 Mdot
.52922 .72132 Mdot
.4326 .43842 Mdot
.36906 .57357 Mdot
.34354 .59739 Mdot
.54995 .69588 Mdot
.33448 .64329 Mdot
.47393 .48704 Mdot
.39191 .39194 Mdot
.52349 .64669 Mdot
.43287 .72414 Mdot
.59782 .66884 Mdot
.49491 .62968 Mdot
.43398 .41571 Mdot
.35439 .60068 Mdot
.37564 .46292 Mdot
.30752 .65045 Mdot
.64504 .47145 Mdot
.47697 .40123 Mdot
.59464 .37183 Mdot
.40408 .71827 Mdot
.66384 .52894 Mdot
.63571 .39455 Mdot
.36299 .64694 Mdot
.58119 .60683 Mdot
.34672 .65022 Mdot
.32307 .662 Mdot
.58639 .68461 Mdot
.35889 .63501 Mdot
.42539 .47019 Mdot
.57483 .47563 Mdot
.37498 .63506 Mdot
.54264 .66392 Mdot
.5926 .36404 Mdot
.37191 .61781 Mdot
.70695 .48945 Mdot
.44925 .43396 Mdot
.634 .5069 Mdot
.6807 .31169 Mdot
.35748 .57833 Mdot
.55829 .35758 Mdot
.68897 .49573 Mdot
.58281 .33182 Mdot
.71771 .73904 Mdot
.52008 .68041 Mdot
.20087 .47797 Mdot
.59106 .39379 Mdot
.34897 .58874 Mdot
.69105 .31707 Mdot
.3998 .46172 Mdot
.449 .4311 Mdot
.62532 .34534 Mdot
.34392 .59702 Mdot
.82608 .56937 Mdot
.34195 .39531 Mdot
.48573 .62901 Mdot
.56081 .70475 Mdot
.46039 .16338 Mdot
.49055 .64284 Mdot
.77364 .71484 Mdot
.35624 .4213 Mdot
.69373 .53731 Mdot
.40855 .43936 Mdot
.69195 .5915 Mdot
.58928 .34159 Mdot
.70555 .55616 Mdot
.43763 .36838 Mdot
.65084 .51661 Mdot
.45843 .437 Mdot
.56929 .45286 Mdot
.48843 .36503 Mdot
.61862 .33199 Mdot
.76197 .59757 Mdot
.33517 .59566 Mdot
.60408 .35377 Mdot
.6277 .52986 Mdot
.45696 .24718 Mdot
.38853 .39853 Mdot
.42764 .49175 Mdot
.58568 .48573 Mdot
.32924 .62642 Mdot
.66282 .48278 Mdot
.55831 .63966 Mdot
.58118 .36646 Mdot
.44297 .40128 Mdot
.38801 .45594 Mdot
.67931 .63664 Mdot
.54212 .68168 Mdot
.69254 .51895 Mdot
.58174 .6711 Mdot
.63529 .54915 Mdot
.40483 .37815 Mdot
.65524 .54285 Mdot
.38927 .47738 Mdot
.64882 .60225 Mdot
.18895 .48149 Mdot
.26526 .51492 Mdot
.64473 .53012 Mdot
.40278 .25972 Mdot
.54808 .68235 Mdot
.58314 .65744 Mdot
.39284 .8032 Mdot
.20338 .55211 Mdot
.25225 .3416 Mdot
.75911 .35204 Mdot
.52396 .66216 Mdot
.54104 .6746 Mdot
.63366 .51051 Mdot
.35886 .63678 Mdot
.31653 .6145 Mdot
.63925 .55066 Mdot
.54266 .29959 Mdot
.33119 .63174 Mdot
.8179 .4264 Mdot
.30316 .29591 Mdot
.40623 .48324 Mdot
.6278 .46674 Mdot
.58248 .36035 Mdot
.53503 .29152 Mdot
.57292 .44916 Mdot
.43606 .47004 Mdot
.56143 .22871 Mdot
.67001 .50265 Mdot
.49532 .49565 Mdot
.71515 .28145 Mdot
.46031 .44779 Mdot
.43432 .45115 Mdot
.41482 .43558 Mdot
.56729 .3804 Mdot
.22444 .59355 Mdot
.43334 .465 Mdot
.54206 .30189 Mdot
.44176 .3873 Mdot
.51717 .39362 Mdot
.59299 .35323 Mdot
.37798 .31389 Mdot
.76406 .42204 Mdot
.32302 .24894 Mdot
.48701 .35867 Mdot
.55959 .63881 Mdot
.62943 .29749 Mdot
.58566 .66671 Mdot
.24025 .5128 Mdot
.4239 .29181 Mdot
.33529 .58684 Mdot
.43257 .47153 Mdot
.65081 .53035 Mdot
.34227 .59889 Mdot
.68485 .6635 Mdot
.09308 .44013 Mdot
.55919 .63718 Mdot
.8294 .6679 Mdot
.57603 .64596 Mdot
.65252 .54991 Mdot
.36257 .61672 Mdot
.3292 .5231 Mdot
.4483 .57699 Mdot
.37461 .6165 Mdot
.80601 .53321 Mdot
.40223 .57378 Mdot
.42626 .25855 Mdot
.37587 .57853 Mdot
.54312 .66995 Mdot
.60878 .6244 Mdot
.39291 .52246 Mdot
.40175 .45824 Mdot
.49314 .54903 Mdot
.44744 .2367 Mdot
.40147 .46255 Mdot
.65612 .53059 Mdot
.19512 .49483 Mdot
.55045 .23683 Mdot
.35337 .63409 Mdot
.51129 .63864 Mdot
.44004 .45211 Mdot
.40107 .39721 Mdot
.38641 .39853 Mdot
.15807 .46034 Mdot
.8397 .50521 Mdot
.39169 .38698 Mdot
.43531 .38134 Mdot
.6495 .52115 Mdot
.55398 .38974 Mdot
.75216 .54159 Mdot
.25931 .38168 Mdot
.45001 .46688 Mdot
.60132 .35215 Mdot
.55336 .37514 Mdot
.3792 .41108 Mdot
.6099 .4205 Mdot
.42319 .69443 Mdot
.42759 .45816 Mdot
.19767 .49784 Mdot
.59887 .46204 Mdot
.68591 .53395 Mdot
.67436 .52653 Mdot
.32226 .62924 Mdot
.67457 .5357 Mdot
.62758 .53743 Mdot
.34146 .53325 Mdot
.5422 .54732 Mdot
.50326 .64936 Mdot
.58158 .34818 Mdot
.40992 .42238 Mdot
.35691 .49906 Mdot
.41683 .72149 Mdot
.58156 .68508 Mdot
.37073 .59211 Mdot
.54786 .6287 Mdot
.6095 .3025 Mdot
.42463 .57714 Mdot
.67562 .50176 Mdot
.52637 .65508 Mdot
.54458 .61792 Mdot
.59944 .35385 Mdot
.55363 .69232 Mdot
.56748 .62013 Mdot
.48042 .41492 Mdot
.27925 .55687 Mdot
.42471 .41942 Mdot
.78899 .62088 Mdot
.53531 .67429 Mdot
.62793 .61937 Mdot
.42285 .44934 Mdot
.67205 .52022 Mdot
.39151 .5286 Mdot
.39538 .4552 Mdot
.6776 .52785 Mdot
.37618 .40515 Mdot
.57753 .33162 Mdot
.30917 .64864 Mdot
.44502 .5656 Mdot
.2943 .77485 Mdot
.58704 .38451 Mdot
.6882 .65562 Mdot
.42519 .47563 Mdot
.63567 .79097 Mdot
.36924 .62028 Mdot
.37733 .45141 Mdot
.52552 .23242 Mdot
.37115 .63482 Mdot
.37138 .59916 Mdot
.40834 .39885 Mdot
.57808 .66878 Mdot
.66163 .53214 Mdot
.59499 .35601 Mdot
.77025 .70211 Mdot
.43559 .43182 Mdot
.45473 .42285 Mdot
.60537 .34794 Mdot
.54763 .68488 Mdot
.37819 .42211 Mdot
.65572 .28409 Mdot
.83864 .56031 Mdot
.58511 .6557 Mdot
.46023 .46193 Mdot
.24087 .55437 Mdot
.37109 .35609 Mdot
.56264 .85131 Mdot
.60762 .41636 Mdot
.64575 .51456 Mdot
.40385 .5036 Mdot
.12149 .44949 Mdot
.58983 .36625 Mdot
.2519 .32865 Mdot
.40382 .39443 Mdot
.45117 .40357 Mdot
.36359 .58634 Mdot
.42861 .40669 Mdot
.39012 .59947 Mdot
.27784 .74723 Mdot
.4619 .18296 Mdot
.32519 .63879 Mdot
.34907 .58657 Mdot
.49473 .22101 Mdot
.73432 .56041 Mdot
.35998 .61265 Mdot
.41625 .379 Mdot
.40657 .32375 Mdot
.39006 .54145 Mdot
.61401 .36758 Mdot
.73351 .36419 Mdot
.3407 .45342 Mdot
.62877 .31785 Mdot
.79174 .43667 Mdot
.33852 .4535 Mdot
.53661 .59204 Mdot
.56441 .64341 Mdot
.46002 .44932 Mdot
.68917 .50818 Mdot
.68933 .51753 Mdot
.36446 .44988 Mdot
.40443 .41777 Mdot
.37119 .64343 Mdot
.5724 .36013 Mdot
.55056 .63473 Mdot
.44525 .39963 Mdot
.51669 .22203 Mdot
.56701 .35836 Mdot
.34558 .64267 Mdot
.22727 .44183 Mdot
.606 .32161 Mdot
.47218 .38033 Mdot
.4161 .45815 Mdot
.41536 .40867 Mdot
.37482 .52199 Mdot
.56279 .64956 Mdot
.71478 .33563 Mdot
.47343 .42056 Mdot
.39342 .21358 Mdot
.52052 .69586 Mdot
.48855 .43087 Mdot
.33059 .646 Mdot
.50978 .6344 Mdot
.61593 .50186 Mdot
.43311 .61196 Mdot
.44268 .4286 Mdot
.7528 .65395 Mdot
.50792 .82084 Mdot
.6485 .47271 Mdot
.31969 .65729 Mdot
.5825 .35443 Mdot
.41672 .41775 Mdot
.22033 .4806 Mdot
.3978 .44398 Mdot
.61877 .31686 Mdot
.63283 .48786 Mdot
.56705 .64462 Mdot
.77636 .64626 Mdot
.68536 .52537 Mdot
.36785 .60064 Mdot
.58703 .16352 Mdot
.39144 .60183 Mdot
.31563 .61985 Mdot
.23794 .43854 Mdot
.5653 .6496 Mdot
.11561 .48123 Mdot
.30534 .75623 Mdot
.46421 .3901 Mdot
.55104 .68361 Mdot
.35007 .61393 Mdot
.45062 .39729 Mdot
.34044 .57806 Mdot
.3185 .648 Mdot
.41404 .37704 Mdot
.46233 .42039 Mdot
.6637 .7329 Mdot
.74249 .30365 Mdot
.58214 .35317 Mdot
.36197 .65083 Mdot
.46089 .62826 Mdot
.45447 .39994 Mdot
.41471 .44776 Mdot
.61696 .70032 Mdot
.60115 .3767 Mdot
.50257 .73011 Mdot
.40224 .39597 Mdot
.48681 .18652 Mdot
.48294 .378 Mdot
.39423 .62583 Mdot
.58782 .66886 Mdot
.33179 .24477 Mdot
.60567 .67778 Mdot
.38859 .59777 Mdot
.57515 .36832 Mdot
.3772 .65391 Mdot
.46928 .22096 Mdot
.53448 .68155 Mdot
.35603 .59486 Mdot
.59008 .57567 Mdot
.55648 .65688 Mdot
.52919 .66561 Mdot
.24592 .42449 Mdot
.67417 .47344 Mdot
.56414 .37911 Mdot
.53739 .67184 Mdot
.37746 .70404 Mdot
.54682 .66442 Mdot
.32584 .76516 Mdot
.46004 .45803 Mdot
.561 .27119 Mdot
.7194 .55061 Mdot
.39389 .50924 Mdot
.5323 .67435 Mdot
.61408 .35342 Mdot
.38674 .40502 Mdot
.33706 .63671 Mdot
.57522 .34029 Mdot
.52575 .72577 Mdot
.64066 .50285 Mdot
.34999 .6484 Mdot
.60166 .6814 Mdot
.33491 .6119 Mdot
.41898 .65847 Mdot
.43669 .83135 Mdot
.56776 .20524 Mdot
.45052 .59085 Mdot
.39019 .39633 Mdot
.76969 .38797 Mdot
.43616 .48621 Mdot
.40069 .41472 Mdot
.6553 .53476 Mdot
.55692 .25657 Mdot
.35806 .61984 Mdot
.81029 .59883 Mdot
.54094 .64222 Mdot
.33389 .23779 Mdot
.4338 .33748 Mdot
.36966 .42432 Mdot
.37831 .63195 Mdot
.38936 .59124 Mdot
.25331 .47961 Mdot
.61493 .51388 Mdot
.39625 .47428 Mdot
.45222 .47918 Mdot
.3641 .41676 Mdot
.53778 .64651 Mdot
.63533 .3897 Mdot
.66119 .48731 Mdot
.50938 .84428 Mdot
.63694 .4839 Mdot
.63416 .32414 Mdot
.35372 .63642 Mdot
.5686 .36809 Mdot
.41587 .44952 Mdot
.38968 .55853 Mdot
.38153 .58507 Mdot
.62347 .33576 Mdot
.61379 .33836 Mdot
.64704 .68919 Mdot
.57365 .65773 Mdot
.38584 .44756 Mdot
.4374 .46499 Mdot
.43127 .4017 Mdot
.40513 .40862 Mdot
.55114 .63794 Mdot
.38404 .41249 Mdot
.59272 .64792 Mdot
.37004 .68521 Mdot
.6171 .2692 Mdot
.55545 .53713 Mdot
.43984 .79227 Mdot
.34505 .63498 Mdot
.39103 .70113 Mdot
.34565 .40342 Mdot
.16553 .54181 Mdot
.57451 .79846 Mdot
.47372 .41124 Mdot
.64657 .54393 Mdot
.50264 .46066 Mdot
.68184 .50317 Mdot
.76263 .74142 Mdot
.66018 .6347 Mdot
.77433 .337 Mdot
.44874 .45619 Mdot
.57353 .48765 Mdot
.34957 .72007 Mdot
.43445 .4881 Mdot
.66251 .65385 Mdot
.44431 .78703 Mdot
.75794 .61494 Mdot
.60513 .369 Mdot
.44505 .43954 Mdot
.36382 .51064 Mdot
.42539 .46865 Mdot
.41004 .44378 Mdot
.38454 .40508 Mdot
.59492 .6597 Mdot
.38661 .46319 Mdot
.38884 .41279 Mdot
.67261 .42911 Mdot
.42092 .27747 Mdot
.69238 .50534 Mdot
.42506 .81438 Mdot
.56736 .36758 Mdot
.37178 .64054 Mdot
.82902 .49398 Mdot
.57534 .66628 Mdot
.25717 .47771 Mdot
.40961 .40843 Mdot
.69591 .70514 Mdot
.52636 .62554 Mdot
.58344 .37025 Mdot
.62351 .48977 Mdot
.8037 .36523 Mdot
.65552 .52673 Mdot
.60298 .60096 Mdot
.6699 .52018 Mdot
.34244 .4151 Mdot
.37025 .64452 Mdot
.38136 .43322 Mdot
.53569 .66479 Mdot
.66812 .53795 Mdot
.4985 .27072 Mdot
.41471 .42967 Mdot
.65752 .5178 Mdot
.38167 .43352 Mdot
.42532 .55759 Mdot
.28128 .34567 Mdot
.62962 .53828 Mdot
.52658 .62666 Mdot
.54566 .65211 Mdot
.58594 .38091 Mdot
.36231 .64422 Mdot
.37851 .59233 Mdot
.5622 .66558 Mdot
.21293 .60182 Mdot
.4451 .47176 Mdot
.45865 .40719 Mdot
.35422 .23031 Mdot
.4157 .4717 Mdot
.44403 .25398 Mdot
.57857 .55713 Mdot
.34154 .64001 Mdot
.36967 .41068 Mdot
.41018 .39437 Mdot
.44594 .42956 Mdot
.40436 .66019 Mdot
.67746 .51289 Mdot
.461 .45106 Mdot
.61096 .33483 Mdot
.63753 .437 Mdot
.43438 .38654 Mdot
.50185 .41602 Mdot
.37622 .59148 Mdot
.18261 .39645 Mdot
.57517 .6464 Mdot
.63037 .53318 Mdot
.64304 .53022 Mdot
.74599 .37748 Mdot
.39674 .74387 Mdot
.57701 .55302 Mdot
.54246 .84222 Mdot
.65534 .59853 Mdot
.59499 .33531 Mdot
.60152 .4937 Mdot
.6121 .63408 Mdot
.63187 .52233 Mdot
.55772 .63643 Mdot
.46367 .45307 Mdot
.45195 .46541 Mdot
.15575 .5612 Mdot
.37831 .40964 Mdot
.58482 .35668 Mdot
.59918 .67271 Mdot
.33922 .63316 Mdot
.58137 .36912 Mdot
.58242 .67224 Mdot
.32653 .63489 Mdot
.47641 .42445 Mdot
.47531 .4294 Mdot
.37305 .59306 Mdot
.35192 .59345 Mdot
.4186 .45597 Mdot
.74262 .53428 Mdot
.34347 .5917 Mdot
.35059 .59968 Mdot
.67187 .49773 Mdot
.68808 .51009 Mdot
.49618 .41394 Mdot
.55076 .68047 Mdot
.38766 .41228 Mdot
.64892 .526 Mdot
.57262 .37084 Mdot
.3563 .62276 Mdot
.40189 .38945 Mdot
.43098 .38898 Mdot
.59885 .35571 Mdot
.5854 .3769 Mdot
.60974 .35886 Mdot
.59828 .66096 Mdot
.43854 .40729 Mdot
.36724 .61226 Mdot
.57267 .65374 Mdot
.55491 .37573 Mdot
.61562 .36196 Mdot
.60648 .49593 Mdot
.4058 .47002 Mdot
.7253 .5051 Mdot
.12567 .41711 Mdot
.39819 .22548 Mdot
.62846 .47741 Mdot
.61794 .48957 Mdot
.46256 .28692 Mdot
.50013 .49821 Mdot
.56416 .67588 Mdot
.54382 .38507 Mdot
.51171 .21131 Mdot
.47934 .4345 Mdot
.44298 .38226 Mdot
.44127 .36266 Mdot
.61253 .3501 Mdot
.57268 .25372 Mdot
.39158 .61107 Mdot
.32648 .4094 Mdot
.5667 .35255 Mdot
.69373 .50417 Mdot
.61259 .4781 Mdot
.63381 .48519 Mdot
.46912 .44477 Mdot
.27259 .51454 Mdot
.38686 .72154 Mdot
.72929 .32494 Mdot
.53733 .67936 Mdot
.35725 .49868 Mdot
.63466 .78828 Mdot
.37364 .59616 Mdot
.6262 .54988 Mdot
.5979 .33393 Mdot
.34887 .5963 Mdot
.53834 .62783 Mdot
.53931 .67207 Mdot
.66432 .49415 Mdot
.65762 .49239 Mdot
.62949 .50358 Mdot
.31506 .64543 Mdot
.35651 .63594 Mdot
.44152 .42579 Mdot
.35368 .62681 Mdot
.16061 .50689 Mdot
.62133 .36182 Mdot
.69423 .55035 Mdot
.55282 .67465 Mdot
.32618 .62989 Mdot
.41658 .42747 Mdot
.47396 .51574 Mdot
.49304 .77458 Mdot
.59277 .33 Mdot
.2724 .34296 Mdot
.74736 .75137 Mdot
.38696 .45142 Mdot
.5551 .64752 Mdot
.19802 .40587 Mdot
.41721 .43475 Mdot
.64145 .49042 Mdot
.76079 .51991 Mdot
.60631 .46715 Mdot
.39354 .45309 Mdot
.48052 .43593 Mdot
.58039 .64651 Mdot
.53105 .83621 Mdot
.43792 .42723 Mdot
.48318 .71105 Mdot
.51587 .65776 Mdot
.6552 .48468 Mdot
.86209 .48219 Mdot
.66478 .31551 Mdot
.54119 .29336 Mdot
.66431 .49128 Mdot
.39471 .42613 Mdot
.68132 .50727 Mdot
.60119 .33092 Mdot
.62113 .51588 Mdot
.3934 .60622 Mdot
.65298 .47511 Mdot
.45532 .42282 Mdot
.35844 .61145 Mdot
.55934 .67482 Mdot
.30018 .27485 Mdot
.73354 .46531 Mdot
.67255 .51805 Mdot
.63591 .54374 Mdot
.37176 .40901 Mdot
.51904 .73575 Mdot
.37366 .46799 Mdot
.46642 .43305 Mdot
.52462 .6678 Mdot
.36986 .63768 Mdot
.59083 .66693 Mdot
.47816 .47187 Mdot
.64838 .26901 Mdot
.5821 .66769 Mdot
.74701 .65067 Mdot
.60336 .34241 Mdot
.54027 .49014 Mdot
.41367 .42248 Mdot
.56196 .69216 Mdot
.43863 .40937 Mdot
.38962 .62035 Mdot
.55494 .50586 Mdot
.74378 .61876 Mdot
.53367 .65722 Mdot
.76225 .65017 Mdot
.61244 .28189 Mdot
.49631 .44953 Mdot
.58498 .65982 Mdot
.53678 .23648 Mdot
.65383 .54974 Mdot
.57335 .34514 Mdot
.59493 .32446 Mdot
.56903 .34398 Mdot
.35963 .45036 Mdot
.46801 .34703 Mdot
.55801 .35153 Mdot
.53711 .6307 Mdot
.61818 .33178 Mdot
.35448 .74857 Mdot
.81019 .59087 Mdot
.59216 .34183 Mdot
.43531 .44334 Mdot
.39359 .35167 Mdot
.43717 .28384 Mdot
.6632 .6972 Mdot
.78695 .35561 Mdot
.5601 .77504 Mdot
.40054 .45535 Mdot
.30807 .63622 Mdot
.33132 .65534 Mdot
.21003 .37607 Mdot
.42996 .24247 Mdot
.432 .20459 Mdot
.336 .59259 Mdot
.72577 .60613 Mdot
.3472 .64465 Mdot
.38168 .40369 Mdot
.45575 .40323 Mdot
.33848 .5893 Mdot
.61024 .25924 Mdot
.71675 .62692 Mdot
.7747 .6714 Mdot
.34143 .60464 Mdot
.5821 .67995 Mdot
.56221 .69956 Mdot
.52891 .66753 Mdot
.2865 .30938 Mdot
.38264 .62205 Mdot
.4323 .39584 Mdot
.64591 .53143 Mdot
.455 .45847 Mdot
.56042 .65638 Mdot
.8154 .59231 Mdot
.3766 .62067 Mdot
.44027 .45712 Mdot
.45468 .50715 Mdot
.64887 .49437 Mdot
.60094 .34706 Mdot
.4237 .5466 Mdot
.43018 .20874 Mdot
.53279 .64713 Mdot
.35196 .58056 Mdot
.63954 .61674 Mdot
.78435 .60847 Mdot
.35719 .41268 Mdot
.45426 .47976 Mdot
.7667 .71207 Mdot
.49097 .1956 Mdot
.40885 .47588 Mdot
.63593 .53962 Mdot
.68819 .62024 Mdot
.42147 .38565 Mdot
.34354 .6565 Mdot
.60054 .3222 Mdot
.58245 .33261 Mdot
.49744 .41788 Mdot
.45776 .55094 Mdot
.56684 .48817 Mdot
.41276 .40245 Mdot
.46681 .37648 Mdot
.65751 .48633 Mdot
.67579 .5931 Mdot
.40032 .21109 Mdot
.5774 .37167 Mdot
.38049 .43007 Mdot
.79194 .51467 Mdot
.36811 .58382 Mdot
.64275 .4741 Mdot
.5443 .68941 Mdot
.40946 .64559 Mdot
.62197 .49258 Mdot
.40916 .38321 Mdot
.37862 .41551 Mdot
.57763 .69131 Mdot
.39539 .62252 Mdot
.61216 .34694 Mdot
.64904 .53769 Mdot
.5918 .37547 Mdot
.37369 .63213 Mdot
.35786 .6291 Mdot
.47021 .49498 Mdot
.35378 .40829 Mdot
.67213 .52967 Mdot
.38893 .47791 Mdot
.61762 .45278 Mdot
.60614 .83456 Mdot
.58102 .70007 Mdot
.39248 .46393 Mdot
.39837 .59179 Mdot
.53388 .65182 Mdot
.45643 .40913 Mdot
.78698 .69115 Mdot
.45124 .39537 Mdot
.51859 .68981 Mdot
.54901 .18903 Mdot
.60207 .3689 Mdot
.32961 .40046 Mdot
.63474 .7594 Mdot
.41489 .4693 Mdot
.63706 .52338 Mdot
.40499 .35476 Mdot
.57533 .67406 Mdot
.35349 .63473 Mdot
.58323 .8517 Mdot
.54529 .66115 Mdot
.42501 .46455 Mdot
.58122 .36741 Mdot
.38214 .5819 Mdot
.61243 .39691 Mdot
.61171 .42008 Mdot
.50508 .39031 Mdot
.3818 .46814 Mdot
.40058 .40459 Mdot
.67959 .29087 Mdot
.62909 .52945 Mdot
.34631 .60922 Mdot
.55261 .64637 Mdot
.56411 .66853 Mdot
.6691 .49981 Mdot
.50091 .63836 Mdot
.53965 .49214 Mdot
.18344 .34177 Mdot
.68184 .52201 Mdot
.56114 .35649 Mdot
.49962 .72312 Mdot
.64129 .53556 Mdot
.65983 .51411 Mdot
.67194 .49629 Mdot
.57273 .58456 Mdot
.3286 .63017 Mdot
.41188 .38239 Mdot
.37382 .64695 Mdot
.39328 .42394 Mdot
.5166 .68704 Mdot
.53336 .66256 Mdot
.37289 .62618 Mdot
.74566 .72286 Mdot
.26588 .57842 Mdot
.42455 .44023 Mdot
.63671 .78949 Mdot
.42599 .36807 Mdot
.46232 .27046 Mdot
.41722 .36464 Mdot
.66895 .50666 Mdot
.39929 .49302 Mdot
.36233 .42056 Mdot
.22969 .34422 Mdot
.55378 .67756 Mdot
.68125 .53992 Mdot
.46202 .38208 Mdot
.4607 .3705 Mdot
.31327 .64026 Mdot
.34876 .59756 Mdot
.58809 .32703 Mdot
.38034 .29908 Mdot
.56027 .67762 Mdot
.29169 .7296 Mdot
.40437 .45872 Mdot
.6444 .32302 Mdot
.30526 .3817 Mdot
.4584 .4131 Mdot
.65009 .75931 Mdot
.26821 .50571 Mdot
.41567 .41907 Mdot
.4908 .58771 Mdot
.5459 .68222 Mdot
.63388 .25212 Mdot
.4348 .38395 Mdot
.6437 .49477 Mdot
.35396 .6396 Mdot
.39077 .58968 Mdot
.57036 .33699 Mdot
.18214 .59067 Mdot
.59186 .67137 Mdot
.36363 .63169 Mdot
.40949 .43015 Mdot
.55946 .64658 Mdot
.67865 .53255 Mdot
.37089 .42985 Mdot
.4172 .24484 Mdot
.34624 .62873 Mdot
.37992 .39354 Mdot
.46533 .69626 Mdot
.49748 .30517 Mdot
.59748 .19173 Mdot
.55021 .64537 Mdot
.59231 .37908 Mdot
.42316 .35449 Mdot
.20888 .57843 Mdot
.39126 .37304 Mdot
.56753 .28125 Mdot
.36314 .75464 Mdot
.6005 .37571 Mdot
.42698 .44853 Mdot
.44015 .39906 Mdot
.5361 .44122 Mdot
.57386 .36916 Mdot
.44557 .46051 Mdot
.32752 .68311 Mdot
.33254 .62104 Mdot
.6314 .55065 Mdot
.33599 .63126 Mdot
.4323 .439 Mdot
.3564 .39959 Mdot
.36004 .58795 Mdot
.63971 .8057 Mdot
.60119 .38667 Mdot
.57781 .6515 Mdot
.43257 .37419 Mdot
.46942 .41407 Mdot
.38926 .17071 Mdot
.65604 .47243 Mdot
.74835 .55405 Mdot
.65904 .38594 Mdot
.79257 .47313 Mdot
.66345 .31336 Mdot
.69581 .24733 Mdot
.49676 .19431 Mdot
.38421 .46129 Mdot
.37038 .34674 Mdot
.42975 .66962 Mdot
.53731 .68132 Mdot
.29199 .70068 Mdot
.40143 .45832 Mdot
.40859 .4417 Mdot
.62788 .4762 Mdot
.72924 .66231 Mdot
.43044 .20417 Mdot
.47321 .52058 Mdot
.61118 .34825 Mdot
.35692 .65211 Mdot
.41269 .38085 Mdot
.51561 .57204 Mdot
.69176 .49965 Mdot
.6403 .30395 Mdot
.43801 .45665 Mdot
.17299 .51529 Mdot
.46749 .76831 Mdot
.56816 .65409 Mdot
.64117 .52935 Mdot
.45134 .1986 Mdot
.40181 .4669 Mdot
.54901 .6929 Mdot
.43134 .42874 Mdot
.63182 .57854 Mdot
.47247 .47802 Mdot
.58654 .33971 Mdot
.40039 .39467 Mdot
.62786 .29941 Mdot
.52053 .12606 Mdot
.56402 .33335 Mdot
.34881 .57533 Mdot
.69512 .54484 Mdot
.67824 .51743 Mdot
.35276 .59441 Mdot
.67632 .52148 Mdot
.26111 .4508 Mdot
.32418 .4881 Mdot
.60677 .34325 Mdot
.48336 .38573 Mdot
.59239 .34561 Mdot
.64428 .47233 Mdot
.3976 .45515 Mdot
.66873 .80674 Mdot
.66456 .53651 Mdot
.50921 .18009 Mdot
.54961 .66444 Mdot
.69332 .50167 Mdot
.44046 .38682 Mdot
.63229 .62719 Mdot
.68624 .52428 Mdot
.73144 .63243 Mdot
.4454 .42899 Mdot
.34795 .63194 Mdot
.42355 .38737 Mdot
.45659 .38473 Mdot
.69587 .5286 Mdot
.38839 .42455 Mdot
.58206 .6732 Mdot
.32321 .6095 Mdot
.82368 .41596 Mdot
.41788 .77923 Mdot
.43612 .46857 Mdot
.41147 .43165 Mdot
.34926 .66465 Mdot
.46901 .43838 Mdot
.55181 .63799 Mdot
.21646 .74057 Mdot
.60319 .3427 Mdot
.67876 .5477 Mdot
.66318 .31057 Mdot
.47648 .41718 Mdot
.38531 .40811 Mdot
.80485 .66894 Mdot
.64084 .2701 Mdot
.58492 .66484 Mdot
.36416 .41115 Mdot
.68038 .53168 Mdot
.58032 .36389 Mdot
.53831 .63374 Mdot
.41703 .40915 Mdot
.41919 .44918 Mdot
.58273 .37973 Mdot
.42315 .3205 Mdot
.3254 .27382 Mdot
.56537 .69427 Mdot
.38406 .49314 Mdot
.70856 .50118 Mdot
.43499 .4776 Mdot
.26844 .32825 Mdot
.35684 .59643 Mdot
.52975 .64957 Mdot
.77286 .41222 Mdot
.3973 .46653 Mdot
.58712 .67523 Mdot
.55925 .67825 Mdot
.37057 .39934 Mdot
.39766 .58718 Mdot
.3194 .62454 Mdot
.33157 .61637 Mdot
.15505 .59321 Mdot
.52581 .28437 Mdot
.62956 .5034 Mdot
.54619 .683 Mdot
.63067 .54255 Mdot
.6263 .31965 Mdot
.57091 .55686 Mdot
.63257 .54186 Mdot
.32711 .61909 Mdot
.68343 .55437 Mdot
.44655 .41158 Mdot
.5609 .67499 Mdot
.63098 .51749 Mdot
.46909 .39545 Mdot
.51271 .72614 Mdot
.61575 .74269 Mdot
.6176 .3535 Mdot
.5928 .323 Mdot
.44535 .39383 Mdot
.61723 .52943 Mdot
.41657 .45444 Mdot
.52241 .6707 Mdot
.502 .72002 Mdot
.43192 .37494 Mdot
.67362 .51618 Mdot
.36217 .66174 Mdot
.4395 .20507 Mdot
.38184 .47919 Mdot
.43431 .44403 Mdot
.39139 .42694 Mdot
.43153 .42826 Mdot
.77985 .59466 Mdot
.54626 .70146 Mdot
.43839 .79084 Mdot
.70053 .3233 Mdot
.37868 .61404 Mdot
.36245 .65497 Mdot
.38571 .22793 Mdot
.4316 .67993 Mdot
.54959 .68095 Mdot
.40208 .41252 Mdot
.42436 .74023 Mdot
.83781 .55875 Mdot
.74576 .7403 Mdot
.53219 .42014 Mdot
.67204 .4748 Mdot
.34666 .58388 Mdot
.6611 .54495 Mdot
.39562 .43319 Mdot
.44203 .36151 Mdot
.67164 .22055 Mdot
.52559 .6362 Mdot
.60533 .33976 Mdot
.39212 .42043 Mdot
.52732 .28846 Mdot
.64812 .52226 Mdot
.69794 .5128 Mdot
.46348 .44401 Mdot
.39516 .62979 Mdot
.4818 .14489 Mdot
.56158 .64927 Mdot
.55872 .77142 Mdot
.3477 .72272 Mdot
.52226 .7689 Mdot
.56115 .65435 Mdot
.54416 .40898 Mdot
.63387 .47649 Mdot
.30195 .36373 Mdot
.38147 .60898 Mdot
.57781 .33849 Mdot
.48661 .43661 Mdot
.37071 .58763 Mdot
.64461 .48148 Mdot
.35113 .63349 Mdot
.38573 .40346 Mdot
.51755 .67476 Mdot
.64386 .51446 Mdot
.5028 .65083 Mdot
.40299 .60146 Mdot
.57684 .36948 Mdot
.49174 .52282 Mdot
.29839 .58998 Mdot
.26657 .50093 Mdot
.46222 .45105 Mdot
.51895 .57486 Mdot
.43148 .39702 Mdot
.33142 .66141 Mdot
.42103 .42812 Mdot
.29171 .64329 Mdot
.63785 .52272 Mdot
.43512 .38158 Mdot
.40922 .40348 Mdot
.35829 .77721 Mdot
.44805 .45016 Mdot
.39081 .47674 Mdot
.41336 .41635 Mdot
.34155 .57223 Mdot
.48133 .38184 Mdot
.33025 .64734 Mdot
.66604 .43891 Mdot
.66068 .51105 Mdot
.60779 .32416 Mdot
.57913 .38258 Mdot
.55239 .26591 Mdot
.74481 .40128 Mdot
.70774 .68573 Mdot
.33771 .62583 Mdot
.57296 .68227 Mdot
.42506 .42692 Mdot
.71118 .28097 Mdot
.59304 .46564 Mdot
.68424 .48986 Mdot
.42131 .78016 Mdot
.38836 .50101 Mdot
.64074 .24349 Mdot
.36458 .42286 Mdot
.16313 .58622 Mdot
.35135 .45429 Mdot
.46279 .48327 Mdot
.65448 .5532 Mdot
.62099 .30603 Mdot
.4695 .42594 Mdot
.31256 .63313 Mdot
.57691 .34508 Mdot
.40633 .33702 Mdot
.713 .4875 Mdot
.68004 .44723 Mdot
.30926 .59113 Mdot
.43928 .41689 Mdot
.64435 .51301 Mdot
.35214 .6486 Mdot
.40891 .20864 Mdot
.5727 .6526 Mdot
.50402 .67788 Mdot
.45029 .64275 Mdot
.6538 .79061 Mdot
.56657 .35912 Mdot
.28796 .36659 Mdot
.45422 .41964 Mdot
.74709 .50271 Mdot
.42469 .37388 Mdot
.81976 .58602 Mdot
.56425 .36701 Mdot
.32625 .61579 Mdot
.57926 .68277 Mdot
.35136 .65526 Mdot
.25979 .50609 Mdot
.62769 .46557 Mdot
.53253 .53661 Mdot
.65676 .52437 Mdot
.57981 .4434 Mdot
.35309 .61 Mdot
.382 .43012 Mdot
.18072 .34338 Mdot
.35273 .59826 Mdot
.37428 .57987 Mdot
.48165 .83475 Mdot
.63376 .82642 Mdot
.40357 .49724 Mdot
.34588 .58871 Mdot
.66128 .52192 Mdot
.57932 .35376 Mdot
.41236 .38681 Mdot
.44395 .41794 Mdot
.37076 .58863 Mdot
.69287 .5332 Mdot
.22484 .55022 Mdot
.66062 .4954 Mdot
.32803 .62834 Mdot
.65486 .50148 Mdot
.62931 .61405 Mdot
.63823 .53788 Mdot
.4702 .41603 Mdot
.42206 .42769 Mdot
.7085 .3681 Mdot
.35669 .6293 Mdot
.41444 .40175 Mdot
.37177 .41123 Mdot
.36398 .61341 Mdot
.58143 .41609 Mdot
.22853 .54226 Mdot
.43206 .47397 Mdot
.44857 .43839 Mdot
.59809 .37658 Mdot
.55248 .57215 Mdot
.27908 .356 Mdot
.3877 .40428 Mdot
.56856 .38051 Mdot
.31353 .63097 Mdot
.42554 .45839 Mdot
.83066 .52081 Mdot
.69191 .6196 Mdot
.39159 .4554 Mdot
.65405 .54944 Mdot
.36293 .41982 Mdot
.58167 .18416 Mdot
.46686 .43157 Mdot
.35367 .61673 Mdot
.36473 .63645 Mdot
.29986 .74131 Mdot
.3651 .60137 Mdot
.68816 .50616 Mdot
.55835 .65678 Mdot
.78452 .62752 Mdot
.67644 .53496 Mdot
.35349 .44989 Mdot
.32426 .78037 Mdot
.37563 .43586 Mdot
.46861 .40179 Mdot
.52015 .16318 Mdot
.66262 .54199 Mdot
.38324 .62774 Mdot
.51195 .49312 Mdot
.35198 .40317 Mdot
.52822 .65367 Mdot
.49087 .42404 Mdot
.46156 .45929 Mdot
.53972 .1844 Mdot
.77525 .56849 Mdot
.53542 .68721 Mdot
.40366 .47952 Mdot
.38678 .40521 Mdot
.67533 .47035 Mdot
.41231 .42694 Mdot
.58041 .35009 Mdot
.38011 .62695 Mdot
.64361 .54029 Mdot
.59885 .3586 Mdot
.40728 .46586 Mdot
.61101 .35482 Mdot
.63383 .50646 Mdot
.53665 .68513 Mdot
.39529 .44391 Mdot
.61533 .36555 Mdot
.61081 .3534 Mdot
.42817 .39724 Mdot
.35051 .63656 Mdot
.35995 .48142 Mdot
.44662 .45475 Mdot
.4 .3907 Mdot
.38073 .59343 Mdot
.8838 .55302 Mdot
.45999 .40808 Mdot
.58434 .27723 Mdot
.38516 .58869 Mdot
.58282 .4314 Mdot
.66402 .54652 Mdot
.464 .45549 Mdot
.53438 .68377 Mdot
.55154 .68984 Mdot
.63817 .48184 Mdot
.36644 .57564 Mdot
.66539 .37262 Mdot
.4097 .60422 Mdot
.37902 .37208 Mdot
.42804 .48143 Mdot
.25188 .6445 Mdot
.77236 .32946 Mdot
.38441 .63389 Mdot
.72356 .54016 Mdot
.46069 .53909 Mdot
.56237 .69068 Mdot
.69385 .50856 Mdot
.34527 .58324 Mdot
.38992 .60442 Mdot
.33928 .63906 Mdot
.58485 .33278 Mdot
.71246 .37106 Mdot
.3979 .60871 Mdot
.38539 .64325 Mdot
.44699 .42481 Mdot
.3892 .40399 Mdot
.44844 .21074 Mdot
.37822 .26889 Mdot
.61649 .34632 Mdot
.64568 .48447 Mdot
.13424 .57099 Mdot
.52123 .66449 Mdot
.40594 .79631 Mdot
.456 .38911 Mdot
.09846 .45321 Mdot
.42976 .38368 Mdot
.40838 .42741 Mdot
.32305 .60923 Mdot
.61849 .35756 Mdot
.59658 .34342 Mdot
.3477 .60662 Mdot
.37169 .65255 Mdot
.58156 .34886 Mdot
.61997 .77644 Mdot
.84247 .52343 Mdot
.59833 .48532 Mdot
.3673 .61673 Mdot
.319 .56463 Mdot
.56971 .69507 Mdot
.40804 .34381 Mdot
.51914 .66889 Mdot
.65359 .51829 Mdot
.6225 .48883 Mdot
.53223 .65027 Mdot
.4439 .42993 Mdot
.62737 .51033 Mdot
.38429 .45811 Mdot
.55084 .78919 Mdot
.26729 .54476 Mdot
.67928 .34446 Mdot
.49956 .3817 Mdot
.57201 .42218 Mdot
.50452 .63591 Mdot
.41668 .46379 Mdot
.80708 .48928 Mdot
.6092 .34294 Mdot
.42875 .35033 Mdot
.5268 .65057 Mdot
.55403 .15927 Mdot
.39427 .44909 Mdot
.35301 .61938 Mdot
.55593 .6814 Mdot
.42869 .61042 Mdot
.4835 .70673 Mdot
.39218 .42519 Mdot
.13093 .41682 Mdot
.34903 .57043 Mdot
.63852 .53345 Mdot
.19825 .58442 Mdot
.3901 .62971 Mdot
.54302 .35415 Mdot
.73458 .35657 Mdot
.71353 .75012 Mdot
.37134 .6414 Mdot
.66107 .47039 Mdot
.32421 .6418 Mdot
.5749 .36715 Mdot
.32196 .59892 Mdot
.64303 .52264 Mdot
.43646 .45418 Mdot
.67119 .50491 Mdot
.5993 .32723 Mdot
.328 .2763 Mdot
.53722 .68838 Mdot
.67771 .54299 Mdot
.53741 .65803 Mdot
.47829 .31092 Mdot
.67595 .2937 Mdot
.56932 .64524 Mdot
.21226 .47069 Mdot
.43642 .48034 Mdot
.39261 .62811 Mdot
.67448 .50419 Mdot
.76902 .4618 Mdot
.48846 .52233 Mdot
.3798 .60318 Mdot
.63496 .49033 Mdot
.45981 .63454 Mdot
.18889 .53322 Mdot
.38378 .47477 Mdot
.42275 .2967 Mdot
.36924 .61324 Mdot
.64324 .47011 Mdot
.34567 .23437 Mdot
.32202 .64151 Mdot
.68336 .51745 Mdot
.58245 .68126 Mdot
.56602 .66588 Mdot
.45521 .45438 Mdot
.50844 .64989 Mdot
.62542 .49637 Mdot
.50594 .70894 Mdot
.34836 .58587 Mdot
.41799 .64207 Mdot
.61673 .36668 Mdot
.66345 .50632 Mdot
.37694 .41136 Mdot
.29984 .63801 Mdot
.66876 .6149 Mdot
.23417 .57189 Mdot
.1818 .38698 Mdot
.66883 .4997 Mdot
.38512 .61633 Mdot
.3526 .62175 Mdot
.37473 .47473 Mdot
.44913 .58684 Mdot
.66886 .37351 Mdot
.50133 .48163 Mdot
.48258 .5045 Mdot
.62879 .55009 Mdot
.62752 .45525 Mdot
.46652 .38562 Mdot
.43531 .41952 Mdot
.5664 .68952 Mdot
.43864 .45134 Mdot
.33082 .60181 Mdot
.46249 .44764 Mdot
.55174 .64747 Mdot
.65577 .52938 Mdot
.39698 .44812 Mdot
.60532 .36635 Mdot
.57356 .69627 Mdot
.54754 .62727 Mdot
.669 .51172 Mdot
.3731 .58811 Mdot
.6036 .41186 Mdot
.65657 .49148 Mdot
.43948 .41797 Mdot
.55872 .57938 Mdot
.38676 .39832 Mdot
.33196 .40568 Mdot
.32207 .644 Mdot
.64697 .54059 Mdot
.33118 .59567 Mdot
.54039 .66308 Mdot
.70747 .32923 Mdot
.42757 .43548 Mdot
.6814 .52411 Mdot
.70097 .57649 Mdot
.35554 .34224 Mdot
.39042 .64186 Mdot
.6461 .73549 Mdot
.35097 .65892 Mdot
.65316 .48246 Mdot
.38808 .80293 Mdot
.56952 .34835 Mdot
.68493 .49025 Mdot
.81401 .38973 Mdot
.66918 .53007 Mdot
.45742 .44203 Mdot
.44676 .39626 Mdot
.64112 .53864 Mdot
.5869 .38109 Mdot
.44901 .18944 Mdot
.64647 .56126 Mdot
.37983 .63202 Mdot
.55201 .79941 Mdot
.24552 .30013 Mdot
.57317 .7092 Mdot
.56887 .6872 Mdot
.34797 .45017 Mdot
.42275 .49038 Mdot
.52537 .64598 Mdot
.52515 .63005 Mdot
.57909 .33266 Mdot
.67742 .50059 Mdot
.29942 .62127 Mdot
.58034 .63869 Mdot
.40057 .54682 Mdot
.7361 .39325 Mdot
.38673 .48132 Mdot
.35908 .72774 Mdot
.44234 .38162 Mdot
.56293 .30901 Mdot
.55079 .64655 Mdot
.38657 .38993 Mdot
.36457 .45234 Mdot
.52682 .67286 Mdot
.57775 .35304 Mdot
.52081 .60684 Mdot
.65066 .50378 Mdot
.86885 .50609 Mdot
.37547 .45189 Mdot
.46085 .4381 Mdot
.53545 .67687 Mdot
.67063 .418 Mdot
.37925 .61876 Mdot
.3363 .65813 Mdot
.62995 .53066 Mdot
.47351 .54651 Mdot
.45426 .46412 Mdot
.42617 .46231 Mdot
.64391 .50678 Mdot
.69201 .51536 Mdot
.6853 .68916 Mdot
.44648 .40269 Mdot
.55052 .67536 Mdot
.63509 .32429 Mdot
.54706 .64624 Mdot
.38374 .40189 Mdot
.46082 .43188 Mdot
.47092 .4178 Mdot
.37799 .41032 Mdot
.52107 .634 Mdot
.40056 .3819 Mdot
.45146 .36248 Mdot
.38458 .6106 Mdot
.39043 .41288 Mdot
.48985 .49869 Mdot
.44052 .44393 Mdot
.58028 .35221 Mdot
.2611 .37726 Mdot
.39446 .44862 Mdot
.46183 .45624 Mdot
.67782 .55224 Mdot
.42229 .44455 Mdot
.52144 .66804 Mdot
.36545 .62412 Mdot
.54479 .68151 Mdot
.54942 .69012 Mdot
.61736 .51062 Mdot
.56031 .34781 Mdot
.47773 .42092 Mdot
.59671 .33134 Mdot
.35297 .42959 Mdot
.3968 .46666 Mdot
.721 .35187 Mdot
.16901 .60074 Mdot
.29601 .29858 Mdot
.42929 .43508 Mdot
.66302 .53998 Mdot
.65868 .54633 Mdot
.40337 .33135 Mdot
.38039 .47099 Mdot
.55071 .63557 Mdot
.55688 .69146 Mdot
.42008 .24849 Mdot
.58493 .21785 Mdot
.57962 .35232 Mdot
.5442 .56066 Mdot
.39674 .4737 Mdot
.38166 .3993 Mdot
.37234 .43657 Mdot
.62895 .53871 Mdot
.52734 .41889 Mdot
.68977 .49889 Mdot
.47538 .77551 Mdot
.53072 .65832 Mdot
.39225 .4372 Mdot
.38152 .74805 Mdot
.34291 .60065 Mdot
.3642 .62466 Mdot
.55612 .62879 Mdot
.68632 .46886 Mdot
.41377 .22499 Mdot
.73941 .75255 Mdot
.36076 .56898 Mdot
.62039 .33716 Mdot
.42003 .46708 Mdot
.66214 .52862 Mdot
.3258 .62699 Mdot
.6186 .33506 Mdot
.38451 .43798 Mdot
.71361 .37119 Mdot
.4344 .43309 Mdot
.40896 .69246 Mdot
.34815 .64274 Mdot
.82785 .57209 Mdot
.37268 .57518 Mdot
.57593 .69572 Mdot
.53713 .64255 Mdot
.45574 .40917 Mdot
.23133 .62797 Mdot
.37728 .64564 Mdot
.57671 .58987 Mdot
.56141 .35678 Mdot
.65033 .62108 Mdot
.573 .36121 Mdot
.63807 .52966 Mdot
.57289 .34855 Mdot
.64078 .52215 Mdot
.37855 .25689 Mdot
.36336 .56051 Mdot
.60438 .35147 Mdot
.67582 .58343 Mdot
.41409 .49244 Mdot
.61577 .35252 Mdot
.42283 .36123 Mdot
.33519 .38779 Mdot
.64474 .50332 Mdot
.5656 .36321 Mdot
.38063 .42813 Mdot
.67568 .23634 Mdot
.58319 .65756 Mdot
.54593 .63686 Mdot
.41296 .36359 Mdot
.62357 .54465 Mdot
.31562 .6167 Mdot
.80452 .57914 Mdot
.60058 .67439 Mdot
.45782 .40732 Mdot
.46961 .43126 Mdot
.36638 .65365 Mdot
.35908 .75788 Mdot
.45835 .4183 Mdot
.43887 .51032 Mdot
.44771 .40217 Mdot
.5808 .64835 Mdot
.35327 .65431 Mdot
.3571 .62318 Mdot
.6316 .49457 Mdot
.35111 .59036 Mdot
.4 .32473 Mdot
.40976 .75387 Mdot
.40562 .51326 Mdot
.54429 .65914 Mdot
.44952 .76688 Mdot
.47278 .77707 Mdot
.78705 .35913 Mdot
.40511 .611 Mdot
.42553 .37493 Mdot
.36718 .58337 Mdot
.5787 .36196 Mdot
.34695 .63083 Mdot
.34551 .58469 Mdot
.41484 .45696 Mdot
.39488 .42584 Mdot
.64921 .53314 Mdot
.44781 .57278 Mdot
.37926 .58737 Mdot
.42693 .3839 Mdot
.43395 .48962 Mdot
.37899 .44785 Mdot
.60004 .58687 Mdot
.37822 .64047 Mdot
.54289 .83125 Mdot
.50476 .23282 Mdot
.37853 .58755 Mdot
.49654 .14315 Mdot
.6928 .58514 Mdot
.61259 .49054 Mdot
.49766 .65465 Mdot
.44249 .39773 Mdot
.68268 .53283 Mdot
.39565 .43422 Mdot
.36128 .72753 Mdot
.41511 .44639 Mdot
.57984 .34873 Mdot
.38383 .46096 Mdot
.63054 .48192 Mdot
.66239 .49539 Mdot
.46403 .4195 Mdot
.39848 .44652 Mdot
.34964 .25848 Mdot
.40357 .57621 Mdot
.36429 .62905 Mdot
.65762 .37922 Mdot
.60169 .36243 Mdot
.52945 .65073 Mdot
.41586 .42197 Mdot
.61888 .52164 Mdot
.66515 .49731 Mdot
.38292 .63807 Mdot
.6425 .49159 Mdot
.56212 .65021 Mdot
.42358 .43378 Mdot
.52817 .64315 Mdot
.58213 .33349 Mdot
.36388 .65003 Mdot
.39081 .41791 Mdot
.44708 .42529 Mdot
.36477 .63662 Mdot
.47434 .39892 Mdot
.59408 .37805 Mdot
.67228 .52746 Mdot
.36544 .64574 Mdot
.56063 .65916 Mdot
.63894 .52829 Mdot
.40167 .38756 Mdot
.1368 .50656 Mdot
.45481 .44234 Mdot
.43077 .38978 Mdot
.81066 .36906 Mdot
.39047 .47057 Mdot
.67113 .5007 Mdot
.32488 .62063 Mdot
.50076 .39256 Mdot
.53586 .2591 Mdot
.85489 .63011 Mdot
.68463 .49131 Mdot
.42517 .4676 Mdot
.72756 .29472 Mdot
.43267 .46415 Mdot
.25965 .62679 Mdot
.61037 .54651 Mdot
.55615 .45841 Mdot
.40969 .36833 Mdot
.57478 .66701 Mdot
.65127 .53628 Mdot
.63761 .51885 Mdot
.51711 .81328 Mdot
.4186 .45924 Mdot
.50045 .60115 Mdot
.38378 .42305 Mdot
.56462 .65933 Mdot
.44888 .24119 Mdot
.6639 .49492 Mdot
.2078 .37265 Mdot
.43446 .39806 Mdot
.39183 .60914 Mdot
.68498 .55424 Mdot
.61774 .62116 Mdot
.40277 .38962 Mdot
.60731 .33548 Mdot
.59526 .65067 Mdot
.48706 .45303 Mdot
.54794 .65611 Mdot
.39717 .39263 Mdot
.49486 .47272 Mdot
.19784 .59883 Mdot
.34477 .63803 Mdot
.57767 .68448 Mdot
.57968 .57372 Mdot
.40727 .37749 Mdot
.369 .64296 Mdot
.38167 .60692 Mdot
.59026 .32914 Mdot
.55817 .52479 Mdot
.46013 .68201 Mdot
.28396 .56923 Mdot
.53798 .80585 Mdot
.68692 .54999 Mdot
.74368 .6109 Mdot
.41577 .39226 Mdot
.64774 .34424 Mdot
.52673 .67771 Mdot
.45421 .44685 Mdot
.28789 .38534 Mdot
.34329 .60519 Mdot
.45282 .43427 Mdot
.59061 .34596 Mdot
.63876 .39291 Mdot
.64386 .33837 Mdot
.74047 .35128 Mdot
.65625 .52276 Mdot
.43673 .35873 Mdot
.49829 .46112 Mdot
.65426 .55164 Mdot
.46687 .45501 Mdot
.68047 .51881 Mdot
.63486 .78342 Mdot
.61799 .35054 Mdot
.38288 .63312 Mdot
.62223 .59705 Mdot
.47606 .43585 Mdot
.44206 .48129 Mdot
.56866 .33392 Mdot
.43326 .41516 Mdot
.17738 .5759 Mdot
.611 .58611 Mdot
.62982 .51965 Mdot
.34048 .63883 Mdot
.46931 .44483 Mdot
.56967 .53864 Mdot
.44228 .45775 Mdot
.3149 .50109 Mdot
.46284 .45438 Mdot
.47098 .68471 Mdot
.35352 .63914 Mdot
.5438 .65515 Mdot
.40031 .37739 Mdot
.41123 .44035 Mdot
.58136 .25153 Mdot
.34902 .43782 Mdot
.39415 .3828 Mdot
.33769 .66969 Mdot
.32422 .63012 Mdot
.32859 .64427 Mdot
.65241 .47615 Mdot
.55928 .19749 Mdot
.54502 .67144 Mdot
.48785 .37544 Mdot
.58354 .64448 Mdot
.22182 .57981 Mdot
.61989 .33828 Mdot
.74581 .33179 Mdot
.4106 .40906 Mdot
.33363 .62483 Mdot
.78671 .5323 Mdot
.31505 .64632 Mdot
.52798 .56066 Mdot
.56042 .67726 Mdot
.35071 .60192 Mdot
.40819 .43273 Mdot
.47364 .53134 Mdot
.68931 .26891 Mdot
.5387 .67194 Mdot
.35541 .4556 Mdot
.65922 .47362 Mdot
.68128 .33046 Mdot
.14999 .47118 Mdot
.5834 .65682 Mdot
.52102 .6927 Mdot
.41889 .46084 Mdot
.33977 .60186 Mdot
.57258 .66227 Mdot
.57243 .64305 Mdot
.63993 .49267 Mdot
.39469 .42132 Mdot
.39562 .41569 Mdot
.65444 .48113 Mdot
.54217 .68065 Mdot
.40066 .367 Mdot
.47339 .47757 Mdot
.64127 .19276 Mdot
.45184 .62848 Mdot
.87418 .51126 Mdot
.41722 .32698 Mdot
.26639 .40257 Mdot
.80778 .58639 Mdot
.38936 .59529 Mdot
.39749 .46085 Mdot
.47351 .46784 Mdot
.62596 .49523 Mdot
.43072 .4452 Mdot
.6039 .50963 Mdot
.55817 .68525 Mdot
.54597 .16262 Mdot
.45803 .7465 Mdot
.67652 .76583 Mdot
.42964 .44686 Mdot
.29013 .64623 Mdot
.58858 .36014 Mdot
.56701 .70542 Mdot
.33613 .6533 Mdot
.37595 .42047 Mdot
.34602 .26036 Mdot
.68792 .49486 Mdot
.37035 .59471 Mdot
.40876 .21081 Mdot
.55542 .41852 Mdot
.38557 .40095 Mdot
.66786 .47922 Mdot
.80355 .51502 Mdot
.41544 .58309 Mdot
.59857 .68332 Mdot
.57696 .352 Mdot
.65171 .53919 Mdot
.55632 .69255 Mdot
.29597 .63685 Mdot
.35838 .60108 Mdot
.31269 .61901 Mdot
.28394 .32485 Mdot
.67377 .54935 Mdot
.59297 .35858 Mdot
.61776 .24346 Mdot
.58594 .23299 Mdot
.58281 .34634 Mdot
.62417 .48555 Mdot
.3247 .62931 Mdot
.34298 .6116 Mdot
.36603 .62354 Mdot
.25752 .32244 Mdot
.38597 .58452 Mdot
.44359 .80948 Mdot
.37845 .43973 Mdot
.43497 .50821 Mdot
.42612 .46619 Mdot
.54097 .6368 Mdot
.35928 .64245 Mdot
.50464 .51056 Mdot
.35717 .43154 Mdot
.69379 .29382 Mdot
.45662 .44901 Mdot
.5312 .69405 Mdot
.45201 .42426 Mdot
.30282 .71821 Mdot
.37172 .58334 Mdot
.42997 .43892 Mdot
.53485 .69238 Mdot
.59631 .36849 Mdot
.38392 .6486 Mdot
.39146 .42645 Mdot
.6835 .71627 Mdot
.38747 .46702 Mdot
.68218 .7539 Mdot
.41737 .65312 Mdot
.62043 .33771 Mdot
.36025 .70505 Mdot
.69033 .48789 Mdot
.45306 .50134 Mdot
.36071 .38501 Mdot
.5366 .66408 Mdot
.64878 .60593 Mdot
.66136 .51342 Mdot
.53078 .4175 Mdot
.49143 .40791 Mdot
.60144 .32554 Mdot
.40024 .56568 Mdot
.5242 .64572 Mdot
.46072 .46574 Mdot
.37188 .46756 Mdot
.50375 .79543 Mdot
.47272 .37942 Mdot
.46719 .44114 Mdot
.58629 .32229 Mdot
.43678 .80125 Mdot
.44176 .43973 Mdot
.5368 .55775 Mdot
.32949 .5903 Mdot
.37307 .37798 Mdot
.42537 .80637 Mdot
.44538 .39418 Mdot
.36239 .59414 Mdot
.36647 .5142 Mdot
.44706 .66812 Mdot
.55978 .35201 Mdot
.46133 .45812 Mdot
.30495 .74773 Mdot
.43792 .4047 Mdot
.54974 .67128 Mdot
.38776 .47496 Mdot
.64567 .52205 Mdot
.29777 .29015 Mdot
.62694 .50136 Mdot
.44284 .47075 Mdot
.36834 .62052 Mdot
.53121 .67023 Mdot
.22768 .36591 Mdot
.69469 .37899 Mdot
.41578 .79494 Mdot
.76406 .70835 Mdot
.56892 .3676 Mdot
.553 .37284 Mdot
.52069 .6511 Mdot
.43174 .43876 Mdot
.43439 .8258 Mdot
.35121 .45585 Mdot
.44917 .43646 Mdot
.41374 .44657 Mdot
.66404 .29045 Mdot
.5563 .68844 Mdot
.64889 .49678 Mdot
.45989 .42426 Mdot
.39791 .38226 Mdot
.38938 .59681 Mdot
.60548 .36158 Mdot
.66351 .54647 Mdot
.60463 .342 Mdot
.65623 .53457 Mdot
.51688 .14939 Mdot
.36657 .40931 Mdot
.59141 .36904 Mdot
.58563 .64055 Mdot
.3746 .59037 Mdot
.41088 .74947 Mdot
.6368 .52401 Mdot
.6374 .48425 Mdot
.46539 .43146 Mdot
.35992 .59323 Mdot
.32573 .60349 Mdot
.57845 .36491 Mdot
.56619 .64611 Mdot
.39507 .44958 Mdot
.39999 .47087 Mdot
.36477 .52895 Mdot
.62188 .53619 Mdot
.39818 .70002 Mdot
.74193 .63596 Mdot
.43148 .43604 Mdot
.34589 .5877 Mdot
.40397 .44943 Mdot
.76998 .63446 Mdot
.34539 .59614 Mdot
.44167 .39003 Mdot
.4385 .17298 Mdot
.67885 .46242 Mdot
.43733 .69875 Mdot
.46801 .41583 Mdot
.80499 .64263 Mdot
.41224 .3985 Mdot
.57345 .15309 Mdot
.75573 .48482 Mdot
.43578 .47804 Mdot
.41028 .38486 Mdot
.24697 .54931 Mdot
.41499 .47082 Mdot
.64941 .48135 Mdot
.4863 .19467 Mdot
.31166 .6333 Mdot
.57719 .75087 Mdot
.26879 .37474 Mdot
.56456 .36648 Mdot
.63037 .53123 Mdot
.61958 .46281 Mdot
.59137 .33985 Mdot
.36468 .61632 Mdot
.4314 .42803 Mdot
.49639 .5441 Mdot
.62958 .54641 Mdot
.45231 .33895 Mdot
.55213 .67114 Mdot
.67956 .64682 Mdot
.58334 .49496 Mdot
.5526 .65313 Mdot
.39148 .40907 Mdot
.23857 .54884 Mdot
.32764 .31277 Mdot
.84652 .501 Mdot
.55749 .69376 Mdot
.53671 .67141 Mdot
.27747 .30158 Mdot
.62688 .34291 Mdot
.53167 .78884 Mdot
.47665 .69437 Mdot
.52729 .65881 Mdot
.41933 .6215 Mdot
.68155 .49318 Mdot
.51923 .62392 Mdot
.44121 .35508 Mdot
.3894 .45996 Mdot
.40928 .43506 Mdot
.55995 .64327 Mdot
.36269 .33998 Mdot
.19093 .57268 Mdot
.53673 .65641 Mdot
.34705 .39552 Mdot
.54863 .49433 Mdot
.74072 .54953 Mdot
.65709 .4867 Mdot
.56241 .34732 Mdot
.57458 .39148 Mdot
.38946 .61344 Mdot
.56128 .34756 Mdot
.64368 .38195 Mdot
.42667 .41561 Mdot
.53971 .64889 Mdot
.66127 .61594 Mdot
.56193 .66419 Mdot
.59441 .34073 Mdot
.61421 .32404 Mdot
.38427 .61128 Mdot
.35774 .63057 Mdot
.24956 .44027 Mdot
.45247 .26721 Mdot
.44784 .45675 Mdot
.77506 .43007 Mdot
.33962 .58923 Mdot
.46084 .34064 Mdot
.56311 .3435 Mdot
.60042 .36528 Mdot
.58741 .26081 Mdot
.4083 .41404 Mdot
.27053 .65996 Mdot
.41094 .4176 Mdot
.4501 .24708 Mdot
.45361 .38896 Mdot
.64084 .49199 Mdot
.40308 .41069 Mdot
.60565 .26192 Mdot
.48041 .43349 Mdot
.41329 .4901 Mdot
.62443 .53308 Mdot
.49275 .43888 Mdot
.64652 .51996 Mdot
.4444 .46679 Mdot
.59631 .38361 Mdot
.62362 .51892 Mdot
.53117 .27608 Mdot
.59678 .27009 Mdot
.62738 .48027 Mdot
.60176 .3288 Mdot
.57232 .37918 Mdot
.54164 .30025 Mdot
.33598 .65348 Mdot
.36185 .37399 Mdot
.43265 .4418 Mdot
.69467 .5161 Mdot
.56221 .68872 Mdot
.41551 .38159 Mdot
.43601 .48777 Mdot
.45556 .396 Mdot
.39001 .61399 Mdot
.67232 .36936 Mdot
.58399 .36921 Mdot
.66111 .48061 Mdot
.60332 .41557 Mdot
.62269 .54622 Mdot
.38712 .47764 Mdot
.47792 .45744 Mdot
.27957 .37875 Mdot
.73246 .57714 Mdot
.25662 .3127 Mdot
.36058 .59988 Mdot
.65418 .54882 Mdot
.60936 .37568 Mdot
.45343 .49034 Mdot
.33136 .62355 Mdot
.64347 .5222 Mdot
.43358 .43282 Mdot
.3583 .46528 Mdot
.44012 .77855 Mdot
.41511 .31498 Mdot
.56811 .27414 Mdot
.63738 .48162 Mdot
.67884 .47827 Mdot
.6285 .27605 Mdot
.57764 .3161 Mdot
.49202 .52043 Mdot
.42888 .45713 Mdot
.60582 .33555 Mdot
.32621 .62577 Mdot
.29562 .32368 Mdot
.55172 .63978 Mdot
.44802 .57955 Mdot
.42866 .4452 Mdot
.56595 .43693 Mdot
.37074 .61982 Mdot
.58759 .34769 Mdot
.55762 .64274 Mdot
.54869 .37602 Mdot
.63771 .54555 Mdot
.67944 .78399 Mdot
.4374 .40906 Mdot
.46473 .43962 Mdot
.56028 .69953 Mdot
.33568 .61191 Mdot
.55864 .3456 Mdot
.5619 .79427 Mdot
.63452 .51019 Mdot
.41274 .8187 Mdot
.34178 .59253 Mdot
.33946 .55722 Mdot
.6691 .48601 Mdot
.56179 .63126 Mdot
.52954 .29384 Mdot
.55605 .64912 Mdot
.45093 .46476 Mdot
.34273 .62498 Mdot
.57803 .6808 Mdot
.44175 .58903 Mdot
.71651 .28093 Mdot
.32461 .5641 Mdot
.42326 .4198 Mdot
.63721 .2118 Mdot
.67235 .74477 Mdot
.39877 .57136 Mdot
.53761 .68746 Mdot
.45476 .44912 Mdot
.44977 .47505 Mdot
.4403 .40641 Mdot
.57043 .68103 Mdot
.75984 .4083 Mdot
.64227 .50486 Mdot
.42194 .46384 Mdot
.58064 .33196 Mdot
.65216 .51589 Mdot
.62024 .60045 Mdot
.657 .48862 Mdot
.40511 .60183 Mdot
.39374 .48094 Mdot
.61219 .6452 Mdot
.49253 .12422 Mdot
.54244 .67796 Mdot
.61779 .49572 Mdot
.36728 .41986 Mdot
.69246 .60882 Mdot
.32743 .6395 Mdot
.63339 .50836 Mdot
.46043 .43935 Mdot
.62512 .59337 Mdot
.31573 .28542 Mdot
.65965 .49065 Mdot
.32985 .62271 Mdot
.83815 .48552 Mdot
.43555 .44937 Mdot
.41969 .39919 Mdot
.35087 .60633 Mdot
.2012 .49981 Mdot
.36125 .22748 Mdot
.40038 .44755 Mdot
.54374 .65382 Mdot
.5683 .84852 Mdot
.42704 .4914 Mdot
.49503 .22466 Mdot
.64917 .53517 Mdot
.54991 .60832 Mdot
.4317 .66465 Mdot
.45074 .49116 Mdot
.54926 .78769 Mdot
.51199 .68343 Mdot
.63578 .22885 Mdot
.60465 .51561 Mdot
.7262 .48017 Mdot
.59206 .19175 Mdot
.52627 .68563 Mdot
.37442 .54764 Mdot
.57094 .77399 Mdot
.18474 .44273 Mdot
.82619 .5084 Mdot
.69846 .44537 Mdot
.34711 .25782 Mdot
.51272 .52556 Mdot
.66331 .53578 Mdot
.57406 .40582 Mdot
.39395 .43315 Mdot
.67875 .74092 Mdot
.27655 .68136 Mdot
.23679 .64843 Mdot
.641 .21302 Mdot
.26185 .6094 Mdot
.71427 .28705 Mdot
.79497 .36269 Mdot
.3328 .342 Mdot
.75175 .56524 Mdot
.41393 .82275 Mdot
.4803 .17675 Mdot
.5584 .81367 Mdot
.4042 .51554 Mdot
.5162 .57182 Mdot
.7298 .72655 Mdot
.29998 .60866 Mdot
.19381 .55615 Mdot
.63076 .49866 Mdot
.3215 .64623 Mdot
.56586 .76854 Mdot
.35261 .65926 Mdot
.44335 .6628 Mdot
.84371 .48074 Mdot
.72905 .28916 Mdot
.32841 .75078 Mdot
.81407 .60503 Mdot
.28361 .39701 Mdot
.28858 .77697 Mdot
.63794 .55671 Mdot
.39174 .6242 Mdot
.59213 .29291 Mdot
.61362 .25541 Mdot
.49962 .77033 Mdot
.60605 .7698 Mdot
.70712 .34627 Mdot
.47186 .29583 Mdot
.35491 .61941 Mdot
.38068 .69618 Mdot
.56778 .60005 Mdot
.46084 .75225 Mdot
.47293 .19189 Mdot
.80851 .42369 Mdot
.48878 .5557 Mdot
.62332 .74668 Mdot
.70546 .63412 Mdot
.15715 .45746 Mdot
.5205 .23804 Mdot
.49891 .36174 Mdot
.45594 .64685 Mdot
.79796 .60077 Mdot
.1958 .45194 Mdot
.42701 .26245 Mdot
.60653 .24879 Mdot
.48159 .16301 Mdot
.75007 .67572 Mdot
.32541 .20972 Mdot
.31181 .65181 Mdot
.46975 .43412 Mdot
.21534 .48525 Mdot
.31631 .75928 Mdot
.61798 .32305 Mdot
.75551 .37473 Mdot
.56417 .35278 Mdot
.38917 .57904 Mdot
.32672 .26496 Mdot
.42515 .80336 Mdot
.32544 .77361 Mdot
.56852 .38671 Mdot
.50199 .38907 Mdot
.73202 .79031 Mdot
.66794 .265 Mdot
.43475 .72639 Mdot
.62387 .18184 Mdot
.54642 .45623 Mdot
.42316 .62746 Mdot
.57509 .68257 Mdot
.58408 .18071 Mdot
.34261 .61649 Mdot
.35004 .18076 Mdot
.56546 .15206 Mdot
.29382 .34788 Mdot
.90056 .40537 Mdot
.63859 .28236 Mdot
.55757 .45368 Mdot
.53567 .7226 Mdot
.50895 .26109 Mdot
.17623 .53136 Mdot
.51033 .34866 Mdot
.69676 .61402 Mdot
.79184 .6833 Mdot
.62447 .21244 Mdot
.35384 .79102 Mdot
.63714 .79998 Mdot
.18006 .46614 Mdot
.56924 .54755 Mdot
.43171 .34699 Mdot
.58569 .51004 Mdot
.79925 .43241 Mdot
.49265 .15183 Mdot
.51006 .23106 Mdot
.85052 .64156 Mdot
.57635 .32202 Mdot
.73653 .40958 Mdot
.85085 .45479 Mdot
.49135 .30222 Mdot
.40959 .67194 Mdot
.51694 .20698 Mdot
.50309 .37911 Mdot
.61906 .40375 Mdot
.77467 .39803 Mdot
.40676 .71539 Mdot
.50628 .19201 Mdot
.80865 .54047 Mdot
.49993 .79494 Mdot
.2765 .5438 Mdot
.56704 .21656 Mdot
.32363 .66238 Mdot
.44756 .28187 Mdot
.42993 .65486 Mdot
.72001 .2741 Mdot
.51165 .66441 Mdot
.74941 .28426 Mdot
.36482 .22859 Mdot
.37575 .38607 Mdot
.34491 .43894 Mdot
.32019 .67292 Mdot
.46248 .27513 Mdot
.49486 .43977 Mdot
.46439 .78213 Mdot
.76924 .32142 Mdot
.30827 .37791 Mdot
.53141 .60367 Mdot
.64786 .6028 Mdot
.85487 .47043 Mdot
.23029 .48421 Mdot
.57431 .317 Mdot
.44359 .22081 Mdot
.1608 .47868 Mdot
.65858 .50755 Mdot
.36276 .79231 Mdot
.60257 .67737 Mdot
.30717 .30154 Mdot
.28206 .57378 Mdot
.23771 .3998 Mdot
.77025 .32219 Mdot
.67435 .44201 Mdot
.34667 .24686 Mdot
.4894 .31848 Mdot
.49088 .83803 Mdot
.73967 .55259 Mdot
.49022 .42743 Mdot
.628 .75424 Mdot
.58818 .38132 Mdot
.25469 .49328 Mdot
.55376 .83776 Mdot
.69324 .41858 Mdot
.46056 .37556 Mdot
.29361 .34078 Mdot
.68551 .4627 Mdot
.46941 .53619 Mdot
.21507 .32387 Mdot
.39607 .48721 Mdot
.60766 .23666 Mdot
.73551 .69164 Mdot
.48841 .25423 Mdot
.83722 .54454 Mdot
.78019 .60709 Mdot
.36411 .18416 Mdot
.61563 .18636 Mdot
.6845 .37899 Mdot
.58756 .19479 Mdot
.68599 .23524 Mdot
.35353 .19624 Mdot
.34919 .40297 Mdot
.57078 .69923 Mdot
.12513 .49089 Mdot
.66148 .48676 Mdot
.64171 .25838 Mdot
.53707 .8064 Mdot
.59033 .552 Mdot
.29186 .65689 Mdot
.51499 .38109 Mdot
.5111 .53401 Mdot
.3984 .5733 Mdot
.49578 .43255 Mdot
.26178 .28554 Mdot
.41191 .16673 Mdot
.3029 .2378 Mdot
.77445 .66987 Mdot
.56513 .17917 Mdot
.56665 .4575 Mdot
.34271 .76002 Mdot
.40974 .33277 Mdot
.38106 .43763 Mdot
.54808 .34183 Mdot
.64006 .28392 Mdot
.28012 .34778 Mdot
.49391 .74926 Mdot
.39634 .55903 Mdot
.7651 .38692 Mdot
.41709 .89458 Mdot
.26402 .43555 Mdot
.45686 .81909 Mdot
.64038 .30518 Mdot
.46207 .26366 Mdot
.79282 .43502 Mdot
.26056 .37156 Mdot
.8061 .36896 Mdot
.39186 .57057 Mdot
.55605 .80961 Mdot
.71441 .44545 Mdot
.44012 .53307 Mdot
.67641 .36515 Mdot
.74302 .31054 Mdot
.60452 .72095 Mdot
.24171 .36743 Mdot
.50204 .72626 Mdot
.20909 .47048 Mdot
.65883 .58168 Mdot
.68608 .65169 Mdot
.53512 .83561 Mdot
.76873 .59016 Mdot
.46702 .23654 Mdot
.54396 .50818 Mdot
.34355 .71233 Mdot
.51184 .68624 Mdot
.47308 .2375 Mdot
.49872 .4891 Mdot
.58528 .20611 Mdot
.43811 .10111 Mdot
.21255 .35163 Mdot
.86307 .51687 Mdot
.78244 .43447 Mdot
.4745 .3906 Mdot
.82757 .39964 Mdot
.28928 .23852 Mdot
.52822 .12662 Mdot
.66351 .68438 Mdot
.60926 .53112 Mdot
.57089 .63626 Mdot
.28615 .27138 Mdot
.75315 .40224 Mdot
.81969 .41249 Mdot
.53984 .21883 Mdot
.55206 .62632 Mdot
.17448 .61497 Mdot
.48018 .16721 Mdot
.29672 .57294 Mdot
.41182 .3149 Mdot
.44675 .3759 Mdot
.28957 .6948 Mdot
.35749 .65698 Mdot
.73517 .62035 Mdot
.44195 .26946 Mdot
.66469 .50395 Mdot
.57875 .30221 Mdot
.6189 .7654 Mdot
.38396 .46076 Mdot
.57585 .56763 Mdot
.39636 .63116 Mdot
.73693 .57576 Mdot
.43095 .75942 Mdot
.4785 .14386 Mdot
.6611 .31578 Mdot
.40477 .36993 Mdot
.49061 .24965 Mdot
.67252 .35906 Mdot
.34612 .23367 Mdot
.52074 .64676 Mdot
.66221 .22906 Mdot
.49295 .57554 Mdot
.44596 .27986 Mdot
.2823 .68 Mdot
.33758 .38866 Mdot
.43443 .48358 Mdot
.78724 .5779 Mdot
.30832 .47684 Mdot
.4513 .56092 Mdot
.45751 .35943 Mdot
.3813 .34653 Mdot
.83254 .40967 Mdot
.63543 .39749 Mdot
.68947 .63792 Mdot
.68674 .24679 Mdot
.56912 .67455 Mdot
.36425 .58394 Mdot
.58706 .39643 Mdot
.58565 .79386 Mdot
.32127 .47291 Mdot
.31412 .28671 Mdot
.58415 .52799 Mdot
.70286 .41357 Mdot
.69731 .2594 Mdot
.65937 .23323 Mdot
.26516 .69641 Mdot
.40407 .57263 Mdot
.34383 .33914 Mdot
.57436 .80441 Mdot
.32086 .62866 Mdot
.46802 .79661 Mdot
.4532 .79042 Mdot
.52218 .16034 Mdot
.57124 .57773 Mdot
.79855 .67114 Mdot
.56046 .2744 Mdot
.74738 .3728 Mdot
.22573 .36597 Mdot
.52067 .83376 Mdot
.72278 .30265 Mdot
.41745 .61183 Mdot
.25057 .57099 Mdot
.41477 .51233 Mdot
.35253 .73584 Mdot
.1422 .53412 Mdot
.6157 .38236 Mdot
.32771 .5687 Mdot
.81151 .5387 Mdot
.43606 .42213 Mdot
.19265 .37229 Mdot
.59508 .78128 Mdot
.27009 .30634 Mdot
.56526 .62977 Mdot
.38702 .40669 Mdot
.47459 .44724 Mdot
.48056 .21453 Mdot
.44429 .67222 Mdot
.57083 .20148 Mdot
.58674 .83561 Mdot
.81091 .50291 Mdot
.27587 .67655 Mdot
.62722 .25462 Mdot
.81444 .43025 Mdot
.68822 .73384 Mdot
.55169 .5326 Mdot
.64613 .29563 Mdot
.50611 .29946 Mdot
.80712 .6146 Mdot
.49873 .4939 Mdot
.49579 .68296 Mdot
.506 .77866 Mdot
.74743 .63496 Mdot
.26656 .3394 Mdot
.39937 .39576 Mdot
.40919 .21068 Mdot
.80447 .3836 Mdot
.2696 .69184 Mdot
.16712 .53474 Mdot
.2179 .34066 Mdot
.31019 .52217 Mdot
.76081 .62181 Mdot
.6601 .748 Mdot
.49523 .85214 Mdot
.48928 .58183 Mdot
.70825 .30672 Mdot
.49967 .31012 Mdot
.6936 .2546 Mdot
.55908 .70098 Mdot
.48552 .71624 Mdot
.65193 .6017 Mdot
.5823 .19768 Mdot
.23423 .50642 Mdot
.76503 .32981 Mdot
.53835 .47758 Mdot
.37455 .17545 Mdot
.77116 .5729 Mdot
.52298 .51078 Mdot
.64367 .54557 Mdot
.66068 .4342 Mdot
.76576 .36749 Mdot
.76585 .53454 Mdot
.506 .83084 Mdot
.6205 .47576 Mdot
.57666 .40024 Mdot
.28357 .59994 Mdot
.43071 .29464 Mdot
.78775 .58428 Mdot
.49062 .25003 Mdot
.75019 .30536 Mdot
.49833 .20295 Mdot
.40351 .21534 Mdot
.64874 .28164 Mdot
.74788 .73507 Mdot
.43377 .72164 Mdot
.63889 .37081 Mdot
.60447 .7755 Mdot
.74915 .42903 Mdot
.41345 .63645 Mdot
.12967 .34209 Mdot
.68847 .77298 Mdot
.76274 .56647 Mdot
.49351 .15229 Mdot
.78235 .62103 Mdot
.73178 .58082 Mdot
.18529 .50261 Mdot
.45551 .62521 Mdot
.38123 .24601 Mdot
.41393 .44552 Mdot
.25946 .27957 Mdot
.42719 .28437 Mdot
.45859 .14626 Mdot
.8277 .42449 Mdot
.2839 .65018 Mdot
.39704 .48145 Mdot
.66321 .47959 Mdot
.49194 .6134 Mdot
.38516 .28554 Mdot
.22101 .53445 Mdot
.38584 .68139 Mdot
.63736 .5906 Mdot
.6613 .55179 Mdot
.66433 .36254 Mdot
.36114 .56945 Mdot
.74886 .38783 Mdot
.74601 .63091 Mdot
.70346 .51853 Mdot
.47913 .56552 Mdot
.47008 .24638 Mdot
.42434 .67054 Mdot
.30223 .56848 Mdot
.26323 .36588 Mdot
.61454 .66415 Mdot
.6494 .48469 Mdot
.29271 .56169 Mdot
.72505 .73439 Mdot
.80371 .52085 Mdot
.48055 .16048 Mdot
.60868 .42163 Mdot
.23115 .57362 Mdot
.47416 .23141 Mdot
.179 .54939 Mdot
.21819 .60123 Mdot
.72961 .56608 Mdot
.30848 .69867 Mdot
.19473 .54272 Mdot
.58648 .75888 Mdot
.54717 .16168 Mdot
.55762 .81279 Mdot
.57147 .80727 Mdot
.63216 .57788 Mdot
.35097 .51891 Mdot
.2824 .63233 Mdot
.53928 .27673 Mdot
.48126 .52966 Mdot
.2597 .74626 Mdot
.43097 .35026 Mdot
.17752 .67903 Mdot
.58242 .65181 Mdot
.17009 .48989 Mdot
.51201 .30502 Mdot
.54963 .50326 Mdot
.53241 .46885 Mdot
.77167 .59594 Mdot
.4708 .68931 Mdot
.73922 .69631 Mdot
.21908 .62316 Mdot
.63056 .55497 Mdot
.60254 .83494 Mdot
.75534 .73189 Mdot
.26128 .55691 Mdot
.37439 .45493 Mdot
.71292 .75594 Mdot
.61555 .54492 Mdot
.27416 .35159 Mdot
.84061 .53835 Mdot
.78246 .50832 Mdot
.3894 .54048 Mdot
.45906 .26845 Mdot
.7097 .30584 Mdot
.65294 .21335 Mdot
.17693 .59872 Mdot
.77574 .4022 Mdot
.56233 .70053 Mdot
.54306 .48258 Mdot
.77303 .35312 Mdot
.43141 .60861 Mdot
.51618 .6244 Mdot
.40955 .66666 Mdot
.2476 .75767 Mdot
.64576 .25772 Mdot
.57603 .20583 Mdot
.41319 .65634 Mdot
.36917 .57579 Mdot
.45311 .65898 Mdot
.41046 .67214 Mdot
.77954 .52386 Mdot
.69144 .75154 Mdot
.42086 .66347 Mdot
.40944 .84091 Mdot
.33574 .38368 Mdot
.67015 .44892 Mdot
.2773 .64166 Mdot
.32056 .36644 Mdot
.54954 .62466 Mdot
.43332 .2101 Mdot
.8205 .50796 Mdot
.59085 .68585 Mdot
.79344 .57557 Mdot
.62817 .7448 Mdot
.36317 .54463 Mdot
.32788 .49857 Mdot
.80035 .49333 Mdot
.23347 .53609 Mdot
.32095 .72734 Mdot
.30623 .31638 Mdot
.61466 .50775 Mdot
.82836 .49389 Mdot
.63246 .52248 Mdot
.49398 .36021 Mdot
.4458 .58362 Mdot
.50487 .3462 Mdot
.26471 .3025 Mdot
.57076 .37259 Mdot
.36726 .6506 Mdot
.15117 .5518 Mdot
.3294 .60611 Mdot
.27513 .2708 Mdot
.24195 .39383 Mdot
.28444 .68956 Mdot
.68457 .38631 Mdot
.67224 .41251 Mdot
.32405 .80146 Mdot
.60095 .60222 Mdot
.58925 .53203 Mdot
.38381 .75751 Mdot
.38705 .63324 Mdot
.66342 .31277 Mdot
.62157 .52376 Mdot
.4718 .60354 Mdot
.61205 .71648 Mdot
.33534 .44398 Mdot
.29693 .62506 Mdot
.47319 .58527 Mdot
.40746 .24226 Mdot
.54772 .17362 Mdot
.67919 .52575 Mdot
.18801 .67728 Mdot
.41459 .48551 Mdot
.27386 .53516 Mdot
.8053 .36397 Mdot
.18004 .62321 Mdot
.59627 .4762 Mdot
.76411 .72752 Mdot
.42312 .37292 Mdot
.79441 .45485 Mdot
.34968 .61669 Mdot
.56257 .80682 Mdot
.56763 .35552 Mdot
.49435 .25695 Mdot
.58395 .64906 Mdot
.23906 .36898 Mdot
.60765 .45318 Mdot
.31443 .61652 Mdot
.78095 .47346 Mdot
.32957 .34857 Mdot
.48014 .67572 Mdot
.6576 .39409 Mdot
.26415 .56156 Mdot
.32788 .49029 Mdot
.35457 .56472 Mdot
.59161 .21529 Mdot
.57826 .81302 Mdot
.48971 .13665 Mdot
.34984 .66936 Mdot
.56298 .42221 Mdot
.48883 .78768 Mdot
.79533 .54704 Mdot
.37154 .73457 Mdot
.78683 .33855 Mdot
.42815 .26907 Mdot
.34919 .49638 Mdot
.45459 .24701 Mdot
.37571 .49663 Mdot
.52541 .54301 Mdot
.71222 .6405 Mdot
.23428 .65022 Mdot
.40769 .69418 Mdot
.18745 .47535 Mdot
.33905 .72551 Mdot
.57361 .21209 Mdot
.30781 .69408 Mdot
.68649 .4734 Mdot
.3537 .54275 Mdot
.57957 .70785 Mdot
.56179 .16853 Mdot
.79265 .34615 Mdot
.54188 .70395 Mdot
.68826 .34068 Mdot
.81851 .57432 Mdot
.3767 .48608 Mdot
.58184 .43776 Mdot
.46364 .44781 Mdot
.38545 .3298 Mdot
.1896 .6483 Mdot
.78629 .53044 Mdot
.44693 .3635 Mdot
.62795 .22017 Mdot
.60687 .19775 Mdot
.41411 .15649 Mdot
.44298 .83043 Mdot
.38403 .61929 Mdot
.34665 .20843 Mdot
.37839 .6856 Mdot
.6705 .22116 Mdot
.74365 .55556 Mdot
.83094 .3792 Mdot
.24928 .56457 Mdot
.80432 .57211 Mdot
.18582 .52065 Mdot
.46491 .6634 Mdot
.74223 .67432 Mdot
.56898 .47278 Mdot
.67389 .63383 Mdot
.76916 .64486 Mdot
.54173 .86909 Mdot
.45741 .49052 Mdot
.66073 .73211 Mdot
.55334 .75918 Mdot
.82849 .48464 Mdot
.75048 .50222 Mdot
.38546 .47156 Mdot
.65266 .61279 Mdot
.25805 .32925 Mdot
.48419 .24015 Mdot
.58051 .40344 Mdot
.74986 .50569 Mdot
.34478 .28108 Mdot
.43921 .24792 Mdot
.56161 .81459 Mdot
.25885 .56602 Mdot
.49512 .5964 Mdot
.40929 .37715 Mdot
.30651 .60824 Mdot
.55856 .36837 Mdot
.56941 .49323 Mdot
.44591 .46378 Mdot
.69722 .50927 Mdot
.4764 .6684 Mdot
.2444 .31338 Mdot
.41413 .71186 Mdot
.63095 .77329 Mdot
.29723 .64819 Mdot
.56573 .74723 Mdot
.38505 .74484 Mdot
.20236 .38141 Mdot
.73924 .4573 Mdot
.51043 .23121 Mdot
.6724 .26222 Mdot
.51237 .19525 Mdot
.34963 .5611 Mdot
.4279 .17582 Mdot
.52947 .681 Mdot
.38551 .53809 Mdot
.52746 .75374 Mdot
.6588 .35237 Mdot
.45894 .36352 Mdot
.80363 .57126 Mdot
.58459 .51381 Mdot
.61198 .25935 Mdot
.74993 .68019 Mdot
.34384 .34899 Mdot
.27359 .59455 Mdot
.64986 .22593 Mdot
.68474 .49197 Mdot
.61182 .79863 Mdot
.50298 .70896 Mdot
.72852 .47372 Mdot
.54029 .18466 Mdot
.50544 .14996 Mdot
.51747 .49666 Mdot
.49771 .28906 Mdot
.42603 .39582 Mdot
.54191 .83107 Mdot
.78905 .54312 Mdot
.51658 .40064 Mdot
.66037 .67462 Mdot
.35376 .58715 Mdot
.69153 .67168 Mdot
.51114 .57831 Mdot
.37025 .26006 Mdot
.38368 .64623 Mdot
.27694 .68944 Mdot
.58739 .38527 Mdot
.55196 .43401 Mdot
.50054 .41166 Mdot
.5048 .27647 Mdot
.35501 .79778 Mdot
.48315 .3755 Mdot
.78472 .41013 Mdot
.27825 .56741 Mdot
.56154 .79614 Mdot
.79594 .489 Mdot
.71754 .57458 Mdot
.46838 .68321 Mdot
.34844 .53464 Mdot
.61733 .68137 Mdot
.46127 .40491 Mdot
.67342 .46351 Mdot
.31486 .62978 Mdot
.83603 .50555 Mdot
.31326 .50941 Mdot
.52937 .27807 Mdot
.59924 .58683 Mdot
.48831 .35444 Mdot
.55691 .7244 Mdot
.82252 .37286 Mdot
.46234 .66678 Mdot
.43823 .26728 Mdot
.57151 .57711 Mdot
.51386 .3009 Mdot
.23013 .41414 Mdot
.55817 .14965 Mdot
.18371 .51402 Mdot
.48624 .54623 Mdot
.17276 .50335 Mdot
.76495 .59744 Mdot
.83502 .55431 Mdot
.4341 .25811 Mdot
.54179 .44116 Mdot
.59846 .31762 Mdot
.42812 .77771 Mdot
.59804 .58953 Mdot
.60106 .40315 Mdot
.47478 .60842 Mdot
.63446 .68723 Mdot
.58424 .62091 Mdot
.51402 .40583 Mdot
.65385 .27705 Mdot
.6623 .24674 Mdot
.54712 .80266 Mdot
.51606 .69275 Mdot
.72575 .48769 Mdot
.37065 .26786 Mdot
.84985 .39839 Mdot
.14033 .49572 Mdot
.4283 .39717 Mdot
.5543 .71652 Mdot
.48336 .28589 Mdot
.63229 .48234 Mdot
.40486 .68537 Mdot
.39388 .74147 Mdot
.58635 .67632 Mdot
.59189 .39793 Mdot
.59372 .24465 Mdot
.75358 .61447 Mdot
.43527 .30046 Mdot
.62604 .59862 Mdot
.23272 .32289 Mdot
.75574 .70705 Mdot
.79419 .54016 Mdot
.82262 .33641 Mdot
.49742 .69455 Mdot
.35882 .37067 Mdot
.23133 .4549 Mdot
.55148 .17817 Mdot
.50224 .24632 Mdot
.29484 .31645 Mdot
.69209 .58929 Mdot
.42771 .26376 Mdot
.39482 .66221 Mdot
.63749 .26657 Mdot
.68532 .67396 Mdot
.52638 .52794 Mdot
.67616 .41618 Mdot
.45023 .16153 Mdot
.26817 .61576 Mdot
.6911 .27353 Mdot
.23987 .34699 Mdot
.47134 .85578 Mdot
.57498 .17293 Mdot
.59446 .27162 Mdot
.74845 .48125 Mdot
.21763 .48359 Mdot
.49081 .49841 Mdot
.42077 .6151 Mdot
.27683 .34808 Mdot
.31367 .44614 Mdot
.71306 .3725 Mdot
.19296 .43851 Mdot
.46781 .23635 Mdot
.31229 .37854 Mdot
.54023 .44532 Mdot
.30348 .56147 Mdot
.68544 .34287 Mdot
.42521 .63522 Mdot
.47099 .51925 Mdot
.53889 .25487 Mdot
.28537 .56245 Mdot
.50857 .79018 Mdot
.77858 .61623 Mdot
.44514 .86243 Mdot
.77182 .43524 Mdot
.19532 .39641 Mdot
.37784 .44054 Mdot
.4407 .13127 Mdot
.75182 .64701 Mdot
.75214 .53945 Mdot
.71117 .72881 Mdot
.69988 .47116 Mdot
.34239 .39165 Mdot
.46082 .40422 Mdot
.76142 .36682 Mdot
.32697 .56822 Mdot
.28299 .38673 Mdot
.22774 .37657 Mdot
.4774 .26041 Mdot
.53969 .22191 Mdot
.5481 .27661 Mdot
.37133 .51874 Mdot
.33448 .60408 Mdot
.31142 .23084 Mdot
.49929 .52238 Mdot
.50594 .38616 Mdot
.4801 .48628 Mdot
.20789 .474 Mdot
.80453 .67645 Mdot
.3175 .67059 Mdot
.53439 .20435 Mdot
.25706 .59896 Mdot
.41006 .54107 Mdot
.36305 .72425 Mdot
.81931 .2871 Mdot
.49383 .1081 Mdot
.31147 .62733 Mdot
.43937 .81462 Mdot
.25961 .60494 Mdot
.57997 .20129 Mdot
.71833 .44509 Mdot
.63728 .70203 Mdot
.50917 .44802 Mdot
.43505 .54847 Mdot
.49677 .4107 Mdot
.72169 .70807 Mdot
.57393 .16158 Mdot
.21184 .39817 Mdot
.63071 .22185 Mdot
.35762 .48227 Mdot
.49286 .39352 Mdot
.86644 .39984 Mdot
.76583 .34194 Mdot
.3783 .47737 Mdot
.1899 .55499 Mdot
.43458 .34827 Mdot
.39742 .43516 Mdot
.71731 .33795 Mdot
.60344 .83354 Mdot
.46942 .23266 Mdot
.58224 .19804 Mdot
.36787 .65461 Mdot
.6448 .45246 Mdot
.58334 .65214 Mdot
.52187 .48707 Mdot
.35485 .44473 Mdot
.57796 .67727 Mdot
.37906 .3107 Mdot
.81397 .55563 Mdot
.52217 .59975 Mdot
.60423 .81951 Mdot
.76947 .29735 Mdot
.31656 .52793 Mdot
.42495 .77244 Mdot
.42644 .49432 Mdot
.31749 .37428 Mdot
.36967 .28458 Mdot
.38796 .33469 Mdot
.79403 .61239 Mdot
.21047 .26597 Mdot
.65448 .63584 Mdot
.40463 .22974 Mdot
.3757 .57205 Mdot
.48266 .61134 Mdot
.29927 .58311 Mdot
.72874 .504 Mdot
.67106 .53938 Mdot
.36344 .49211 Mdot
.36993 .65933 Mdot
.59483 .65169 Mdot
.1584 .63666 Mdot
.371 .44238 Mdot
.3859 .70626 Mdot
.674 .22557 Mdot
.30576 .31637 Mdot
.2549 .52238 Mdot
.465 .3979 Mdot
.4637 .75772 Mdot
.54311 .43815 Mdot
.81303 .46232 Mdot
.41197 .21277 Mdot
.6429 .24084 Mdot
.31369 .50444 Mdot
.26939 .59623 Mdot
.39996 .3811 Mdot
.62594 .33317 Mdot
.54235 .60991 Mdot
.74211 .35758 Mdot
.37008 .37688 Mdot
.63394 .19549 Mdot
.62901 .43846 Mdot
.57633 .48829 Mdot
.35273 .67329 Mdot
.40024 .16583 Mdot
.20783 .44296 Mdot
.29331 .60739 Mdot
.20943 .36714 Mdot
.64855 .38962 Mdot
.43398 .295 Mdot
.67156 .4821 Mdot
.35365 .39763 Mdot
.33508 .66511 Mdot
.2001 .35399 Mdot
.70633 .32097 Mdot
.6726 .62324 Mdot
.68283 .65205 Mdot
.48983 .81859 Mdot
.4881 .69245 Mdot
.80141 .31097 Mdot
.65292 .40491 Mdot
.21132 .34473 Mdot
.58632 .80932 Mdot
.31798 .66357 Mdot
.78058 .59642 Mdot
.4231 .35197 Mdot
.67604 .50998 Mdot
.62865 .22748 Mdot
.47251 .35075 Mdot
.32893 .26565 Mdot
.47772 .40309 Mdot
.2924 .28529 Mdot
.63676 .32984 Mdot
.68168 .32509 Mdot
.76232 .5785 Mdot
.20743 .46555 Mdot
.84374 .45746 Mdot
.43133 .78032 Mdot
.84061 .41398 Mdot
.84226 .47575 Mdot
.65689 .22468 Mdot
.2945 .30327 Mdot
.19677 .63235 Mdot
.75782 .54613 Mdot
.79953 .50164 Mdot
.72816 .63578 Mdot
.20497 .49561 Mdot
.66962 .43749 Mdot
.32664 .67644 Mdot
.44522 .67624 Mdot
.56297 .70779 Mdot
.08188 .49613 Mdot
.56307 .23552 Mdot
.32801 .66948 Mdot
.65378 .42296 Mdot
.6232 .20305 Mdot
.21505 .47199 Mdot
.76391 .65703 Mdot
.51527 .57108 Mdot
.48932 .43368 Mdot
.32063 .48567 Mdot
.52523 .81528 Mdot
.63497 .42903 Mdot
.35919 .83543 Mdot
.73702 .72182 Mdot
.65616 .65986 Mdot
.51469 .55184 Mdot
.32025 .64683 Mdot
.34105 .73883 Mdot
.67928 .40539 Mdot
.78925 .6277 Mdot
.80841 .56606 Mdot
.77166 .35036 Mdot
.32354 .79983 Mdot
.56569 .80045 Mdot
.54884 .17562 Mdot
.77951 .56753 Mdot
.31759 .60742 Mdot
.58762 .28012 Mdot
.61654 .53665 Mdot
.69526 .61944 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`0008cooooo0_l0002looooo`007?ooool00ol0003oooooooooo`2;ooooo`;o0000
_?ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2M
ooooo`;o0000Z_ooool001cooooo00?o0000ooooooooool0WOooool2o`000:[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo09cooooo0_l00007
ooooo`;o0000X_ooool001cooooo00?o0000ooooooooool0W?ooool2o`0000Oooooo0_l000000ooo
oooo0000o`00002Oooooo`007?ooool00ol0003oooooooooo`2;ooooo`;o00006oooool2o`0009oo
oooo000Looooo`03o`000?oooooooooo08_ooooo0_l0002looooo`007?ooool00ol0003ooooooooo
o`2Kooooo`;o0000[?ooool001cooooo00?o0000ooooooooool0Voooool2o`000:cooooo000Loooo
o`03o`000?oooooooooo08kooooo0_l00003ooooo`;o00000oooool2o`0000Cooooo0_l0000Aoooo
o`;o0000U_ooool001cooooo00?o0000ooooooooool0S_ooool2o`000003ooooool0003o000000;o
00000oooool3o`0000?ooooo0_l0000Aooooo`Co0000U?ooool001cooooo00?o0000ooooooooool0
TOooool2o`0000Kooooo0_l00005ooooo`;o00000_ooool2o`0000cooooo0ol0002Dooooo`007?oo
ool2o`0006Gooooo0_l0000Vooooo`;o00003_ooool3o`000003ooooool0003o000000;ooooo0_l0
000<ooooo`Oo0000T?ooool001cooooo00?o0000ooooooooool0I?ooool2o`0001gooooo0_l00007
ooooo`;o00001Oooool2o`0000Oooooo0ol0000Eooooo`Go0000T?ooool001cooooo00?o0000oooo
ooooool0Poooool2o`0000kooooo0_l0000Dooooo`;o00001Oooool2o`0000Oooooo0_l0002>oooo
o`007?ooool00ol0003oooooooooo`2>ooooo`;o00002?ooool3o`000003ooooool0003o000000So
oooo0_l000000ooooooo0000o`000003ooooo`Co00001Oooool4o`0008kooooo000Looooo`03o`00
0?oooooooooo07kooooo0_l0000>ooooo`;o00000_ooool2o`0000Cooooo0ol000000ooooooo0000
o`000007ooooo`?o00001_ooool2o`0000Oooooo0_l00002ooooo`;o0000S?ooool001cooooo00?o
0000ooooooooool0O_ooool2o`0000;ooooo0_l0000>ooooo`;o00000_ooool4o`0000_ooooo0_l0
000<ooooo`;o00001_ooool2o`0008cooooo000Looooo`03o`000?oooooooooo07_ooooo0_l00005
ooooo`;o00003_ooool2o`0000;ooooo1?l00008ooooo`;o00003oooool2o`0000;ooooo0_l0002@
ooooo`007?ooool00ol0003oooooooooo`1kooooo`;o00003_ooool2o`0000_ooooo0_l00008oooo
o`;o00002_ooool2o`0000Oooooo0_l0002@ooooo`007?ooool00ol0003oooooooooo`1fooooo`;o
00003oooool2o`0000;ooooo0_l0000:ooooo`?o000000?oooooo`000?l000004Oooool3o`0000Ko
oooo0_l0002@ooooo`007?ooool00ol0003oooooooooo`1^ooooo`;o00001_ooool2o`0000oooooo
0_l0000>ooooo`?o000000?oooooo`000?l000001Oooool2o`0000_ooooo0_l00003ooooo`;o0000
00Coooooo`000?l0003ooooo0_l0002=ooooo`007?ooool00ol0003oooooooooo`1^ooooo`;o0000
0oooool2o`0000Kooooo0_l0000Eooooo`Co00003?ooool2o`0000Kooooo1?l00003ooooo`;o0000
00Coooooo`000?l0003ooooo1Ol0000;ooooo`;o0000P?ooool001cooooo00?o0000ooooooooool0
Loooool2o`0000Kooooo0_l0000Eooooo`Co00001?ooool2o`0000kooooo1?l00003ooooo`;o0000
1_ooool2o`0000Wooooo0_l000000ooooooo0000o`000020ooooo`007?ooool00ol0003ooooooooo
o`2>ooooo`;o000000?oooooo`000?l000000oooool2o`0000;ooooo0_l0000@ooooo`;o000000?o
ooooo`000?l000004oooool2o`0008?ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo
0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`1/ooooo`;o00005Oooool2o`0000Wooooo
0_l000000ooooooo0000o`000003ooooo`;o00000_ooool2o`0000Gooooo0_l000000ooooooo0000
o`000009ooooo`Co00002_ooool3o`0000gooooo0_l0001jooooo`0000KoooooogMgMonHV9Sooooo
oiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000oooo
ooooool0K?ooool2o`000003ooooool0003o000001;ooooo0_l0000Aooooo`;o00000_ooool6o`00
0003ooooool0003o000000?o00002oooool2o`0000Sooooo1Ol0000:ooooo`;o000000?oooooo`00
0?l00000N_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00onHV9So
8B4Qonk^kP07ooooo`03o`000?oooooooooo06oooooo0_l00009ooooo`;o00004_ooool3o`0000Wo
oooo1_l00003ooooo`;o00000_ooool2o`0000Wooooo0_l00005ooooo`Co00001?ooool2o`0000Oo
oooo0_l0001mooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRH
V?lQ8B7ok^k^00Kooooo0ol0001jooooo`;o00003?ooool2o`0000Cooooo0ol0000=ooooo`Co0000
00?oooooo`000?l000000_ooool2o`0000Gooooo0_l00002ooooo`;o00000_ooool2o`000003oooo
ool0003o000000Kooooo0_l00004ooooo`;o0000P?ooool00003ooooool0003ooooo00;ooooo00?o
0000ooooooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo08Sooooo1Ol0
000@ooooo`Go000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00000_ooool4o`0000?ooooo
1ol0000;ooooo`;o0000P?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool03Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06gooooo0_l0000Booooo`;o00001Ooo
ool5o`0000Cooooo0_l0000:ooooo`;o00001?ooool5o`0000;ooooo0_l00004ooooo`;o00000ooo
ool4o`000003ooooool0003o000000kooooo0_l0001mooooo`0000KoooooogMgMonHV9SooooooiRH
V?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`1Vooooo`;o
00001Oooool2o`0000oooooo0_l000000ooooooo0000o`000005ooooo`?o00000oooool2o`000003
ooooool0003o000000oooooo1_l0000?ooooo`;o00004Oooool3o`0007cooooo00001_ooooook^k^
oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooo
oooo067ooooo0_l00003ooooo`;o00002oooool2o`0000Oooooo2?l00005ooooo`;o00000oooool2
o`0000Sooooo0_l00004ooooo`;o00000_ooool4o`0000Kooooo0_l00009ooooo`;o00000oooool2
o`0000Wooooo0_l00002ooooo`?o00000_ooool2o`0007Oooooo000Looooo`03o`000?oooooooooo
067ooooo0_l0000@ooooo`;o00001oooool2o`000003ooooool0003o000000?o00005?ooool2o`00
00Cooooo0_l00004ooooo`;o00001_ooool2o`0000Kooooo0_l00004ooooo`Co00002Oooool2o`00
00?ooooo0_l00002ooooo`;o0000Moooool001cooooo00?o0000ooooooooool0POooool2o`0000Wo
oooo0_l00007ooooo`;o00001_ooool4o`0000Oooooo0_l000001?oooooo0000o`000?l00006oooo
o`;o00000_ooool4o`0000cooooo0_l0000<ooooo`;o0000LOooool001cooooo00?o0000oooooooo
ool0S?ooool2o`0000Oooooo0ol00004ooooo`Go00000oooool2o`0000;ooooo0_l000001?oooooo
0000o`000?l0000:ooooo`;o00000oooool2o`0000Wooooo0ol00006ooooo`?o00000_ooool2o`00
077ooooo000Looooo`03o`000?oooooooooo05Oooooo0_l0000Iooooo`Co00000_ooool2o`0000Co
oooo0_l00003ooooo`;o00003oooool4o`0000Cooooo1?l00004ooooo`;o00001_ooool2o`0000oo
oooo0_l00009ooooo`?o00001?ooool5o`0000?ooooo0_l0001`ooooo`007?ooool00ol0003ooooo
ooooo`1Gooooo`;o00002?ooool2o`0000cooooo0_l000000ooooooo0000o`000008o`0000;ooooo
1?l000000ooooooo0000o`00000?ooooo`;o00002?ooool2o`0001?ooooo0_l0000Cooooo`Go0000
0_ooool2o`0000;ooooo0_l00002ooooo`;o0000L?ooool001cooooo00?o0000ooooooooool0HOoo
ool2o`0000[ooooo1?l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo1?l0
000Cooooo`?o00002?ooool4o`0000?ooooo0ol00009ooooo`;o00001Oooool3o`0000kooooo0_l0
0005ooooo`?o0000M?ooool001cooooo00?o0000ooooooooool0KOooool2o`0001oooooo0_l00004
ooooo`Ko00001_ooool4o`0000?ooooo1_l00002ooooo`;o00000_ooool2o`0000Gooooo0ol00005
ooooo`;o00003_ooool2o`0000Cooooo0_l000000ooooooo0000o`00001/ooooo`007?ooool00ol0
003oooooooooo`1Jooooo`;o00000oooool2o`0000Gooooo0_l000000ooooooo0000o`000002oooo
o`;o00004?ooool2o`0000Oooooo0_l00004ooooo`;o00001?ooool6o`0000;ooooo0_l00007oooo
o`;o00000_ooool4o`0000;ooooo0_l00002ooooo`;o00001Oooool2o`0000Kooooo0_l000000ooo
oooo0000o`00000Aooooo`;o000000?oooooo`000?l000000_ooool2o`0006Sooooo000Looooo`03
o`000?oooooooooo05[ooooo0_l00003ooooo`;o00001Oooool2o`000003ooooool0003o000000Ko
oooo0_l0000<ooooo`Co00000_ooool2o`000003ooooool0003o000000Cooooo0_l00006ooooo`;o
00000_ooool4o`0000Oooooo0_l00008ooooo`;o00002Oooool2o`0000Wooooo0_l00006ooooo`;o
00004?ooool2o`0006Sooooo000Looooo`03o`000?oooooooooo06Kooooo1?l00007ooooo`;o0000
00?oooooo`000?l000000_ooool2o`0000Oooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o
00001?ooool2o`0000[ooooo0_l00007ooooo`;o00002_ooool2o`0000cooooo0_l00006ooooo`;o
00001Oooool3o`0000;ooooo0_l0001fooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o0000
00?oooooo`000?l000000oooool2o`0000Gooooo0ol000000ooooooo0000o`00000:ooooo`?o0000
1?ooool2o`000003ooooool0003o000000?o00000_ooool2o`0000Sooooo0_l00002ooooo`;o0000
1Oooool2o`00017ooooo0_l00002ooooo`;o00000_ooool2o`0000Gooooo0_l00003ooooo`Co0000
1_ooool2o`000003ooooool0003o000006Wooooo000Looooo`;o0000I_ooool2o`0000;ooooo0_l0
0002ooooo`;o00001_ooool2o`0000kooooo0_l00004ooooo`;o000000?oooooo`000?l000000ol0
0002ooooo`;o00001Oooool2o`000003ooooool0003o000000Wooooo0_l00002ooooo`;o00002Ooo
ool2o`0000Kooooo0_l00007ooooo`;o00001oooool2o`0000Kooooo0_l000000ooooooo0000o`00
001Yooooo`007?ooool00ol0003oooooooooo`1Yooooo`;o00004oooool2o`0000Sooooo0_l00002
ooooo`;o00003Oooool3o`0000cooooo0ol000000ooooooo0000o`000002ooooo`;o00000_ooool2
o`000003ooooool0003o000000Wooooo0_l00002ooooo`Co00004_ooool2o`0006Wooooo000Loooo
o`03o`000?oooooooooo06gooooo0ol00007ooooo`;o00001Oooool4o`0000Gooooo1?l000000ooo
oooo0000o`00000=ooooo`Co00000_ooool2o`0000Oooooo0ol00004ooooo`?o000000Coooooo`00
0?l0003o00003?ooool2o`0000;ooooo0_l00003ooooo`?o00003_ooool2o`0006Wooooo000Loooo
o`03o`000?oooooooooo06gooooo0ol00005ooooo`Co00001Oooool4o`0000Gooooo1?l00006oooo
o`Co00000_ooool2o`0000Cooooo0_l00002ooooo`?o00001_ooool2o`0000Gooooo0_l00002oooo
o`;o00001?ooool2o`0000Gooooo0ol00008ooooo`?o000000?oooooo`000?l000003?ooool2o`00
06Sooooo000Looooo`03o`000?oooooooooo06gooooo0_l00006ooooo`;o00001oooool3o`0000Ko
oooo0_l00008ooooo`Co00000_ooool2o`0000?ooooo0_l00004ooooo`;o00001_ooool2o`0000co
oooo0_l000000ooooooo0000o`000004ooooo`Co00003?ooool2o`0000Cooooo0_l00006ooooo`;o
0000J?ooool001cooooo00?o0000ooooooooool0@Oooool2o`0002?ooooo0ol0000>ooooo`;o0000
3_ooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo
0_l0000Booooo`;o00001_ooool2o`0000Oooooo0_l00008ooooo`;o00002?ooool4o`00073ooooo
000Looooo`03o`000?oooooooooo047ooooo0_l0000Cooooo`;o00003_ooool3o`0000cooooo1?l0
000>ooooo`go00001?ooool2o`0000Cooooo0_l0000@ooooo`;o00001Oooool2o`0000Gooooo1?l0
0003ooooo`;o00001?ooool3o`000003ooooool0003o000000Cooooo0_l00005ooooo`;o0000Jooo
ool001cooooo00?o0000ooooooooool0E_ooool2o`000003ooooool0003o000000Kooooo0_l00003
ooooo`Go00002_ooool4o`0000Kooooo0_l000001?oooooo0000o`000?ooool;o`000004ooooool0
003o0000o`0000[ooooo0_l0000Booooo`;o00000oooool2o`0000Cooooo1Ol00002ooooo`?o0000
1Oooool2o`000003ooooool0003o000000_ooooo0ol0001Zooooo`007?ooool00ol0003ooooooooo
o`1Iooooo`;o00000oooool2o`000003ooooool0003o000000?ooooo1Ol00009ooooo`?o00001_oo
ool7o`000003ooooool0003o000000Gooooo0_l00004ooooo`;o00003?ooool2o`0000Oooooo1?l0
00000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Gooooo0_l0
0002ooooo`;o00001oooool2o`0000[ooooo0_l00007ooooo`;o0000HOooool001cooooo00?o0000
ooooooooool0DOooool2o`0000_ooooo0_l00007ooooo`;o00002oooool2o`0000Oooooo0_l00000
0ooooooo0000o`000003ooooo`;o00001_ooool2o`0000?ooooo0_l0000:ooooo`Co00000_ooool2
o`0000;ooooo1Ol000000ooooooo0000o`000002ooooo`Go00000oooool3o`0000_ooooo0_l00007
ooooo`;o00001Oooool2o`0000Wooooo1Ol0001Qooooo`007?ooool00ol0003oooooooooo`1Aoooo
o`;o00006?ooool3o`0001Oooooo0_l00006ooooo`?o00003_ooool2o`0000Cooooo0_l00002oooo
o`;o00002Oooool4o`0000?ooooo0ol00006ooooo`;o00000_ooool2o`0000?ooooo0_l000000ooo
oooo0000o`000007ooooo`;o00002Oooool4o`0006;ooooo000Looooo`03o`000?oooooooooo04Oo
oooo0_l00008ooooo`;o00002?ooool2o`0000Kooooo0_l00006ooooo`?o00001_ooool2o`0000?o
oooo1?l0000:ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000Wooooo0_l0000<oooo
o`;o00003?ooool2o`0000cooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o0000
00;o00004?ooool4o`0000Wooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`17ooooo`;o
00002?ooool2o`0000Sooooo0_l00005ooooo`?o00003oooool2o`0000?ooooo1?l0000:ooooo`;o
000000Coooooo`000?l0003o00001_ooool2o`0000Cooooo0_l00003ooooo`;o00001oooool3o`00
02;ooooo0_l00002ooooo`?o00003oooool4o`000003ooooool0003o000000;o00001Oooool2o`00
01Cooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`1Mooooo`?o00000_ooool2o`0000Ko
oooo0_l0000=ooooo`?o00001oooool2o`000003ooooool0003o000000_ooooo0_l00009ooooo`;o
00000oooool2o`0000?ooooo1_l0000Kooooo`;o00001Oooool2o`0000;ooooo0_l000000ooooooo
0000o`000002o`0000Oooooo2Ol0000Kooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0
GOooool3o`0000[ooooo0_l0000=ooooo`;o00002?ooool8o`0001Sooooo0_l00003ooooo`Ko0000
2_ooool2o`0000?ooooo0_l00009ooooo`?o00002Oooool2o`000003ooooool0003o000000;o0000
0oooool2o`0000Kooooo0_l000000ooooooo0000o`00001Nooooo`007?ooool00ol0003ooooooooo
o`1Looooo`;o000000?oooooo`000?l000002_ooool2o`0000gooooo0ol00008ooooo`Ko00002ooo
ool2o`0000_ooooo0_l00003ooooo`;o00000_ooool2o`0000[ooooo0_l00003ooooo`;o00002Ooo
ool3o`0000?ooooo0_l00008ooooo`;o00001?ooool2o`0000Kooooo0_l000000ooooooo0000o`00
000;ooooo`;o0000DOooool001cooooo0_l0001=ooooo`;o00002?ooool2o`0000Cooooo0_l00000
1?oooooo0000o`000?l00009ooooo`;o00001_ooool2o`0000?ooooo1Ol00009ooooo`;o00000_oo
ool2o`0000Wooooo0ol00009ooooo`Go00001_ooool5o`00017ooooo0_l00003ooooo`Co00000ooo
ool2o`0001Gooooo0_l00008ooooo`;o00001Oooool2o`00057ooooo000Looooo`03o`000?oooooo
oooo04cooooo0_l00004ooooo`;o00000_ooool2o`0000Cooooo0_l00002ooooo`;o00004Oooool2
o`0000?ooooo0_l0000@ooooo`;o00000oooool2o`0000Cooooo0_l00005ooooo`;o00000oooool5
o`0000Kooooo1Ol00007ooooo`?o00001oooool2o`0000?ooooo0ol00002ooooo`;o00003_ooool2
o`0000Oooooo1?l00004ooooo`Ko0000E_ooool001cooooo00?o0000ooooooooool0D_ooool4o`00
00Cooooo1?l0000Jooooo`;o00005Oooool2o`0000_ooooo1?l00003ooooo`;o00001?ooool2o`00
0003ooooool0003o000000Cooooo0_l00004ooooo`?o00001oooool2o`0000;ooooo1?l00002oooo
o`;o00003_ooool2o`0000Cooooo0ol00002ooooo`;o00001?ooool2o`000004ooooool0003o0000
o`0005Kooooo000Looooo`03o`000?oooooooooo05Cooooo0_l00003ooooo`?o00001_ooool2o`00
01?ooooo0ol0000Nooooo`Go000000Coooooo`000?l0003o00000_ooool2o`0000;ooooo1?l00000
0ooooooo0000o`000004ooooo`?o00000oooool2o`0000Wooooo0_l000000ooooooo0000o`000004
ooooo`;o00001_ooool2o`0000cooooo0ol00008ooooo`Ko00002oooool2o`0004Wooooo000Loooo
o`03o`000?oooooooooo04cooooo0_l00002ooooo`;o00001oooool2o`0000Oooooo0_l00003oooo
o`;o000000?oooooo`000?l000002oooool2o`0001?ooooo0_l0000:ooooo`Go00000_ooool2o`00
00Kooooo0_l0000:ooooo`;o00000oooool2o`0000Wooooo0_l0000?ooooo`;o00000oooool5o`00
00oooooo0ol000000ooooooo0000o`00000;ooooo`;o000000?oooooo`000?l00000A_ooool001co
oooo00?o0000ooooooooool0C?ooool2o`0000;ooooo0_l0000:ooooo`;o00000_ooool4o`000003
ooooool0003o000000;o000000?oooooo`000?l000002?ooool2o`000003ooooool0003o000000Wo
oooo0ol00007ooooo`;o0000:Oooool3o`0000_ooooo0_l0000<ooooo`?o00000oooool6o`0001Co
oooo0_l0000<ooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0EOooool2o`0000Gooooo
0_l00002ooooo`;o00000oooool2o`0000gooooo0_l0000<ooooo`?o00005_ooool2o`0001[ooooo
0ol00004ooooo`?o00001?ooool5o`000003ooooool0003o000000Kooooo0ol00007ooooo`;o0000
5?ooool2o`0005Cooooo000Looooo`03o`000?oooooooooo04Sooooo0_l00006ooooo`;o00000ooo
ool2o`0000Oooooo0_l00007ooooo`;o00004_ooool2o`0000Kooooo0_l000000ooooooo0000o`00
0002o`00017ooooo0_l0000Jooooo`?o000000?oooooo`000?l000001_l00002ooooo`Go000000Co
ooooo`000?l0003ooooo0_l00005ooooo`;o00000oooool2o`0000Kooooo0_l0000Booooo`;o0000
DOooool001cooooo00?o0000ooooooooool0@_ooool2o`0000;ooooo1?l00004ooooo`Co00001ooo
ool2o`000003ooooool0003o000000;o00001oooool2o`0001;ooooo0_l000000ooooooo0000o`00
0002o`000004ooooool0003o0000ooooo`Co0000;Oooool2o`0000;ooooo3?l00003ooooo`?o0000
00?oooooo`000?l000001Oooool2o`0000?ooooo0_l00004ooooo`Co00001Oooool2o`0000_ooooo
0_l0001Aooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00000_ooool2o`0000Kooooo1?l0
00000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000008?ooool4o`0000;ooooo0ol0
000:ooooo`;o00009?ooool2o`0000;ooooo3_l000001?oooooo0000o`000?l0000=ooooo`;o0000
1?ooool4o`0000Gooooo0_l0001Nooooo`007?ooool00ol0003oooooooooo`1>ooooo`Co000000?o
ooooo`000?l000009?ooool2o`0000Cooooo0_l00003ooooo`?o00002_ooool2o`0002Cooooo4_l0
0002ooooo`Co00001Oooool2o`0000Cooooo0_l00006ooooo`;o00002_ooool2o`0000Gooooo1?l0
001@ooooo`007?ooool00ol0003oooooooooo`1Tooooo`;o00004oooool3o`0000?ooooo1?l0000C
ooooo`;o00006oooool4o`000003ooooool0003o000000;o000000?oooooo`000?l000002ol00000
0ooooooo0000o`000002o`0000Gooooo0_l00004ooooo`;o00004_ooool2o`0000Gooooo1?l0001@
ooooo`007?ooool00ol0003oooooooooo`1Jooooo`;o00002?ooool2o`0001Cooooo0_l00004oooo
o`?o00001_ooool2o`0000_ooooo0_l0000KoooooaOo00000oooool2o`0001Gooooo0ol0000Aoooo
o`Ko00002Oooool2o`00043ooooo000Looooo`03o`000?oooooooooo04?ooooo0_l00005ooooo`;o
00000_ooool2o`0000?ooooo0_l00005ooooo`Co00003_ooool2o`0000Cooooo0_l0000<ooooo`;o
00001oooool2o`0000Cooooo0_l000000ooooooo0000o`00000Qooooo`Go000000?oooooo`000?l0
00003?l00004ooooo`;o00003Oooool2o`0000Kooooo0ol0000@ooooo`Oo00002Oooool2o`00043o
oooo000Looooo`03o`000?oooooooooo02Kooooo0_l0000?ooooo`?o00001oooool4o`0000;ooooo
0_l000000ooooooo0000o`000002ooooo`;o00000_ooool5o`0000Gooooo0_l0000:ooooo`;o0000
0_ooool2o`0000;ooooo1?l0000=ooooo`;o00002_ooool4o`000004ooooool0003o0000o`0001Wo
oooo0_l00003ooooo`Ko000000?oooooo`000?l000003_l00005ooooo`;o00002?ooool5o`0001Oo
oooo1?l0001@ooooo`007?ooool00ol0003oooooooooo`0Vooooo`;o00003oooool3o`0000Oooooo
0_l00004ooooo`;o000000?oooooo`000?l000001_ooool2o`000003ooooool0003o000000?o0000
0_ooool3o`0000Wooooo0_l00006ooooo`;o00000oooool2o`000003ooooool0003o000000?ooooo
0_l00002ooooo`;o00001?ooool3o`0000?ooooo0_l00004ooooo`?o00002_ooool2o`0000cooooo
0_l00002oooooaSo00001Oooool2o`0000Sooooo1?l00005ooooo`;o00004Oooool2o`0000Oooooo
0_l00019ooooo`007?ooool2o`0004Sooooo0_l000000ooooooo0000o`000002o`0000Gooooo0_l0
00000ooooooo0000o`000002o`0000;ooooo0ol00008ooooo`;o00000oooool2o`0000Oooooo0_l0
00000ooooooo0000o`000003ooooo`;o00002?ooool4o`0000Wooooo1?l00008ooooo`Co00003_oo
oolGo`0001Gooooo0_l00002ooooo`;o00004oooool2o`0000Gooooo0ol00018ooooo`007?ooool0
0ol0003oooooooooo`0mooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o00000ooo
ool2o`0000Gooooo1Ol00002ooooo`;o00002oooool2o`0000?ooooo0_l00006ooooo`;o00001?oo
ool4o`000004ooooool0003o0000ooooo`;o00000_ooool5o`0000_ooooo0_l0000:ooooo`?o0000
2_oooolKo`0000Sooooo0_l0000:ooooo`;o00001_ooool2o`0000Gooooo0_l00004ooooo`;o0000
0_ooool2o`0000Kooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00000_oo
ool2o`000003ooooool0003o000000gooooo1_l000000ooooooo0000o`00000Hooooo`?o00000ooo
ool4o`000003ooooool0003o000000?o00000_ooool4o`0000;ooooo0_l0000=ooooo`;o00001_oo
ool2o`0000Sooooo6_l000000ooooooo0000o`000008ooooo`;o00004Oooool3o`0000?ooooo1?l0
0004ooooo`;o00000_ooool2o`0000?ooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`1C
ooooo`;o00000_ooool2o`0000_ooooo0_l0000?ooooo`Go000000?oooooo`000?l000000oooool4
o`0000;ooooo2?l00003ooooo`;o00001oooool5o`0000Gooooo0_l00007oooooa_o00003oooool3
o`0000_ooooo0_l00004ooooo`Co00003Oooool2o`0004_ooooo000Looooo`03o`000?oooooooooo
06Cooooo0_l0000@ooooo`Oo00001Oooool2o`0000;ooooo3Ol00007ooooo`;o000000Coooooo`00
0?l0003o00000_ooool4o`0000Sooooo0_l000000ooooooo0000o`00000Eo`0000cooooo0_l00000
1?oooooo0000o`000?l0000Cooooo`;o00003Oooool4o`0004Wooooo000Looooo`03o`000?oooooo
oooo04Kooooo0_l0000:ooooo`;o00001Oooool2o`0000?ooooo0_l0000Jooooo`;o00000oooool2
o`000003ooooool0003o000000Co00000oooool8o`0000Sooooo0_l000000ooooooo0000o`000002
ooooo`;o00002ooooolIo`0000Cooooo0_l00006ooooo`;o00000_ooool2o`0000?ooooo0_l0000;
ooooo`;o000000?oooooo`000?l000003oooool2o`000004ooooool0003o0000o`0004Gooooo000L
ooooo`03o`000?oooooooooo043ooooo0_l00004ooooo`;o00000_ooool3o`0000Gooooo0_l00005
ooooo`Oo00001?ooool2o`0000;ooooo0_l0000Cooooo`Wo000000Coooooo`000?l0003ooooo1Ol0
0002ooooo`;o00002?ooool2o`0001;ooooo6_l00003ooooo`;o00002Oooool3o`0000?ooooo0_l0
0003ooooo`;o00001_ooool2o`0000Sooooo0ol0000:ooooo`Go0000@oooool001cooooo00?o0000
ooooooooool0>oooool2o`0000?ooooo0ol00007ooooo`?o00001?ooool2o`0000Oooooo1?l00006
ooooo`;o00000_ooool2o`0000Oooooo0_l000001?oooooo0000o`000?ooool4o`0000;ooooo2Ol0
00001?oooooo0000o`000?ooool2o`0000;ooooo0_l000001?oooooo0000o`000?l0000LoooooaWo
00000oooool2o`0000Gooooo0ol000000ooooooo0000o`000009ooooo`Co00003_ooool3o`0000_o
oooo1?l00013ooooo`007?ooool00ol0003oooooooooo`0kooooo`;o00000oooool3o`0000kooooo
0_l000000ooooooo0000o`00000=ooooo`;o00003?ooool5o`000003ooooool0003o000000Wo0000
00?oooooo`000?l000000ol000000ooooooo0000o`000003ooooo`;o000000Coooooo`000?l0003o
00000oooool6o`0001;ooooo0ol000000ooooooo0000o`00000Ao`000003ooooool0003o000000?o
oooo0_l00005ooooo`Co00003Oooool2o`0000Wooooo0_l000000ooooooo0000o`00000Booooo`?o
0000@?ooool001cooooo00?o0000ooooooooool0@?ooool3o`0000?ooooo0_l00009ooooo`;o0000
00?oooooo`000?l000002_ooool5o`0000?ooooo0_l00008ooooo`Go000000?oooooo`000?l00000
2ol000000ooooooo0000o`000003o`0000;ooooo0ol000000ooooooo0000o`000003o`000003oooo
ool0003o000000Co00003?ooool3o`0000;ooooo1?l00002ooooo`Co00000_ooool:o`00013ooooo
0ol0000Hooooo`;o000000?oooooo`000?l000004_ooool3o`00043ooooo000Looooo`03o`000?oo
oooooooo02kooooo0_l0000>ooooo`;o000000?oooooo`000?l000000oooool2o`0000Wooooo0_l0
0004ooooo`;o00001_ooool5o`0000Cooooo0_l00009ooooo`Co000000?oooooo`000?l000000_l0
0002ooooo`So000000?oooooo`000?l000002_l000000ooooooo0000o`000002o`000003ooooool0
003o000000Cooooo0ol00002ooooo`;o00000oooool3o`0000;ooooo1?l000000ooooooo0000o`00
000<o`000003ooooool0003o000000kooooo1?l00005ooooo`;o000000Coooooo`000?l0003ooooo
0_l0000<ooooo`;o00006Oooool2o`0003gooooo000Looooo`03o`000?oooooooooo02kooooo0_l0
000>ooooo`;o00001?ooool2o`0000_ooooo0_l00004ooooo`;o00001Oooool4o`0000Oooooo0_l0
0008ooooo`go000000?oooooo`000?l000004Ol00002ooooo`;o000000?oooooo`000?l000001?oo
ool3o`0000;ooooo0_l0000=ooooo`go00001?ooool2o`0000Oooooo0_l00003ooooo`Co00001Ooo
ool2o`000003ooooool0003o000000?o00007_ooool2o`0000Cooooo0_l000000ooooooo0000o`00
000mooooo`007?ooool00ol0003oooooooooo`0gooooo`?o00002_ooool2o`0001;ooooo1?l00002
ooooo`Co00001oooool2o`0000Kooooo0_l00003ooooo`?o000000?oooooo`000?l000006_l00003
ooooo`;o00000_ooool2o`0000;ooooo0_l0000:ooooo`;o00001Oooool>o`0000;ooooo0_l00007
ooooo`;o00000oooool2o`0000Oooooo0_l00002ooooo`Co00003?ooool2o`000004ooooool0003o
0000ooooo`;o00002_ooool2o`0000Cooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0g
ooooo`?o00003oooool2o`0000gooooo1?l00003ooooo`?o00001oooool3o`0000;ooooo0_l00000
0ooooooo0000o`000003ooooo`;o00000_oooolNo`000003ooooool0003o000000;ooooo1_l0000:
ooooo`;o000000?oooooo`000?l000000_ooool4o`0000?ooooo1ol00006ooooo`;o000000?ooooo
o`000?l000000_ooool5o`0000Oooooo0_l0000Booooo`;o000000Coooooo`000?l0003ooooo0ol0
000:ooooo`;o000000?oooooo`000?l00000@_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^
1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo01kooooo
0_l0000Yooooo`Co00001_ooool2o`0000_ooooo0_l00008ooooo`?o000000?oooooo`000?l00000
0oooool2o`0000?ooooo4ol000000ooooooo0000o`00000:o`0000;ooooo1?l000001?oooooo0000
o`000?l00002ooooo`;o00002_ooool2o`0000Gooooo0_l00003ooooo`Co00002?ooool2o`000005
ooooool0003o0000o`000?ooool01Ol0000Gooooo`Co00001oooool2o`0000[ooooo0_l000000ooo
oooo0000o`000012ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01kooooo0_l0000:ooooo`;o00003?ooool2
o`0000;ooooo0_l0000;ooooo`Co00001Oooool3o`0000?ooooo0_l0000Aooooo`Co00001?ooool2
o`0000?ooooo6ol000000ooooooo0000o`000003o`000003ooooool0003o000000;o000000?ooooo
o`000?l000000oooool4o`0000Kooooo0_l00007ooooo`;o00000_ooool3o`0000Gooooo0_l00006
ooooo`?o00001?ooool2o`0001Oooooo1?l0000Booooo`;o00001Oooool2o`0003oooooo00000ooo
oooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006ooooo`03o`000?oooooooooo
02[ooooo0_l0000<ooooo`;o00000_ooool2o`0000?ooooo0_l00007ooooo`;o00001_ooool4o`00
00;ooooo0_l0000>ooooo`;o000000?oooooo`000?l000001Ol00002ooooo`?o000000?oooooo`00
0?l000007ol000000ooooooo0000o`000003o`0000Oooooo0_l00006ooooo`;o00002?ooool2o`00
0004ooooool0003o0000o`0000Gooooo0_l00006ooooo`;o00006_ooool2o`0000Wooooo0_l00004
ooooo`;o00001oooool2o`0000Gooooo0ol00005ooooo`;o00001?ooool2o`00037ooooo00000ooo
oooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool3
o`00047ooooo0_l00007ooooo`;o00001oooool3o`00017ooooo0ol00004ooooo`Go000000Gooooo
o`000?l0003o0000ooooo`04o`000003ooooool0003o000001[o000000?oooooo`000?l000000ol0
0005ooooo`;o00004_ooool2o`000005ooooool0003o0000o`000?ooool00_l00005ooooo`;o0000
0oooool2o`000003ooooool0003o000001Oooooo0_l00005ooooo`;o000000Coooooo`000?l0003o
00001?ooool2o`0000kooooo1?l00004ooooo`;o00001?ooool2o`00037ooooo00000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003o
ooooooooo`0mooooo`;o00005?ooool2o`0001;ooooo0ol00003ooooo`Oo000000?oooooo`000?l0
00004ol000000ooooooo0000o`00000>o`0000Sooooo0ol00003ooooo`Co00002_ooool4o`0000Co
oooo0_l00004ooooo`?o00001_ooool4o`0000Oooooo0_l00007ooooo`;o00002_ooool2o`000003
ooooool0003o000000Co000000?oooooo`000?l000003_ooool4o`0001Gooooo0_l0000Vooooo`00
00?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo
00?o0000ooooooooool0?Oooool2o`0002Oooooo1?l00003ooooobWo00000oooool2o`000003oooo
ool0003o000000;ooooo0_l000000ooooooo0000o`000004ooooo`Ko00001oooool5o`0000[ooooo
0_l00009ooooo`;o00001oooool2o`0000Oooooo0_l0000>ooooo`Go00004oooool2o`0001Gooooo
0_l0000Vooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co000000Oo
oooo00?o0000ooooooooool0C_ooool2o`0001Kooooo0_l00007ooooob3o000000?oooooo`000?l0
00004?l0000;ooooo`;o00001oooool2o`0000Sooooo0_l0000Eooooo`;o00004_ooool2o`0000Go
oooo0ol00002ooooo`;o00000_ooool2o`0000Wooooo0_l00002ooooo`?o0000??ooool00006oooo
ooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo
03cooooo0_l00009ooooo`;o00001Oooool2o`0001cooooo0_l00002ooooobco000000?oooooo`00
0?l000000_l0000Oooooo`;o00003_ooool2o`0000Gooooo0_l00008ooooo`;o00002?ooool2o`00
00Gooooo0_l00003ooooo`;o00000_ooool2o`0000Wooooo0_l00003ooooo`Co0000>_ooool001co
oooo00?o0000ooooooooool09Oooool4o`0001?ooooo0ol00008ooooo`;o00008oooool2o`0000;o
oooo7_l000000ooooooo0000o`00000@o`0000;ooooo0_l00004ooooo`;o00001_ooool2o`0000?o
oooo0_l000000ooooooo0000o`000005ooooo`Co00002Oooool2o`000003ooooool0003o000000Co
oooo1?l00003ooooo`;o00000_ooool2o`0001Wooooo0_l0000:ooooo`;o00000oooool2o`0003[o
oooo000Looooo`03o`000?oooooooooo02Gooooo1?l0000Dooooo`;o0000<?ooool:o`000003oooo
ool0003o000000co000000?oooooo`000?l000003_l000001Ooooooo0000o`000?l0003ooooo00?o
00000_ooool2o`0000?ooooo0ol00006ooooo`;o00000oooool2o`000004ooooool0003o0000oooo
o`;o00000_ooool5o`0000Sooooo0_l00007ooooo`Co00000oooool2o`0001_ooooo1?l0000:oooo
o`;o0000?oooool001cooooo00?o0000ooooooooool0C?ooool2o`00027ooooo4Ol000000ooooooo
0000o`00000Bo`000004ooooool0003o0000o`0000?ooooo1Ol00007ooooo`?o00002?ooool2o`00
0003ooooool0003o000000Cooooo0_l00002ooooo`Go00003?ooool2o`00027ooooo0_l00002oooo
o`Ko00001Oooool2o`0000Cooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o
00007Oooool2o`000003ooooool0003o000000;ooooo3_l000000ooooooo0000o`00000Fo`0000;o
oooo1?l0000Dooooo`;o000000?oooooo`000?l000006Oooool2o`000003ooooool0003o000001go
oooo0ol00002ooooo`;o00000_ooool2o`0000Gooooo1Ol000000ooooooo0000o`00000nooooo`00
7?ooool00ol0003oooooooooo`13ooooo`;o00001Oooool2o`0001oooooo0_l000000ooooooo0000
o`000002o`000003ooooool0003o000001go000000?oooooo`000?l000002_l0000=ooooo`;o0000
1Oooool2o`0001Gooooo0_l00007ooooo`?o000000?oooooo`000?l000005oooool2o`000003oooo
ool0003o000000?ooooo0_l00008ooooo`Ko0000@Oooool001cooooo00?o0000ooooooooool0@ooo
ool2o`0000Gooooo0_l0000Sooooo`?o00000_ooool[o`0000gooooo0_l00002ooooo`;o000000?o
ooooo`000?l000001Oooool2o`0000kooooo1?l00005ooooo`;o00000_ooool2o`0001Oooooo0_l0
0003ooooo`;o000000?oooooo`000?l000000oooool2o`000003ooooool0003o000000;o000000?o
ooooo`000?l00000@_ooool001cooooo00?o0000ooooooooool0>Oooool2o`0001Oooooo0_l0000L
ooooo`;o00000_ooool[o`00017ooooo0_l00002ooooo`;o00001?ooool2o`0000Wooooo0_l00000
1?oooooo0000o`000?ooool3o`0000Gooooo0_l0000Jooooo`;o00001?ooool4o`000004ooooool0
003o0000ooooo`Go0000Aoooool001cooooo00?o0000ooooooooool06oooool2o`0001cooooo1?l0
0007ooooo`;o00001?ooool2o`000003ooooool0003o000000?ooooo0_l0000Hooooo`Co00000ooo
ool8o`000003ooooool0003o0000027o00003_ooool2o`0000Gooooo1?l000000ooooooo0000o`00
000:ooooo`;o000000?oooooo`000?l000000ol00006ooooo`Go00003Oooool2o`0000Sooooo0_l0
0005ooooo`?o000000Coooooo`000?l0003ooooo0ol00019ooooo`007?ooool00ol0003ooooooooo
o`0Kooooo`;o00006oooool2o`000003ooooool0003o000000?ooooo0_l00002ooooo`Co00000_oo
ool2o`000003ooooool0003o000001gooooo1?l00003ooooobGo00001?ooool3o`000003ooooool0
003o000000Sooooo1Ol00007ooooo`;o000000?oooooo`000?l000003_ooool2o`0000[ooooo1?l0
000<ooooo`;o0000H_ooool001cooooo00?o0000ooooooooool0>?ooool2o`0000Gooooo0ol00004
ooooo`;o00000_ooool2o`0001Kooooo0_l00005ooooo`;o00001Oooool2o`0000?ooooo2ol00000
0ooooooo0000o`00000Fo`0000Oooooo0_l00008ooooo`Go00002_ooool2o`0000;ooooo0_l0000A
ooooo`;o00001Oooool2o`000004ooooool0003o0000o`0000;ooooo0_l00003ooooo`Co00008ooo
ool2o`0003cooooo000Looooo`03o`000?oooooooooo02Cooooo0_l0000Booooo`;o00001Oooool5
o`0001kooooo0_l00005ooooo`;o000000?oooooo`000?l000001?l00002oooooa[o000000?ooooo
o`000?l000002?l00004ooooo`;o00000oooool2o`0000Sooooo0ol00007ooooo`;o00001Oooool2
o`00017ooooo0_l00004ooooo`;o000000?oooooo`000?l000001_l00003ooooo`Co00006?ooool2
o`0000Wooooo0_l0000looooo`007?ooool2o`0002Gooooo0_l0000Fooooo`;o00000_ooool4o`00
00gooooo0_l0000Fooooo`;o000000?oooooo`000?l000002ol000000ooooooo0000o`00000Io`00
0004ooooool0003o0000o`0000Cooooo0_l00003ooooo`;o00004_ooool2o`0001Kooooo0_l00006
ooooo`;o000000?oooooo`000?l000000_ooool2o`00027ooooo0_l00017ooooo`007?ooool00ol0
003oooooooooo`0Looooo`;o00007_ooool2o`0000Wooooo0_l00007ooooo`?o00005ooooolNo`00
0003ooooool0003o000000_o00001?ooool2o`0001Gooooo0_l00002ooooo`;o00000oooool2o`00
00Kooooo0_l000001?oooooo0000o`000?ooool2o`0000Cooooo0_l00003ooooo`;o00002_ooool2
o`0001gooooo0_l0000Aooooo`;o0000=_ooool001cooooo00?o0000ooooooooool07?ooool2o`00
017ooooo0_l0000Booooo`;o00000_ooool2o`0000Oooooo0_l0000Cooooo`;o00000oooool3o`00
0003ooooool0003o000000;o00001?oooolSo`000003ooooool0003o0000017ooooo0ol000001?oo
oooo0000o`000?ooool3o`0000?ooooo1?l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l0
0009ooooo`;o00002_ooool2o`0000_ooooo0_l000000ooooooo0000o`00000=ooooo`;o00003_oo
ool2o`000003ooooool0003o000003Kooooo000Looooo`03o`000?oooooooooo02oooooo0ol0000A
ooooo`;o00007_ooool4o`0000Oooooo0_l00007ooooob;o00001Oooool4o`0000Sooooo1_l00000
1?oooooo0000o`000?ooool2o`0000Kooooo0_l0000Rooooo`;o00002_ooool2o`000003ooooool0
003o000000Gooooo0_l0000Fooooo`;o0000>Oooool001cooooo00?o0000ooooooooool09oooool2
o`0000Oooooo0_l0000aooooo`;o00001?ooool2o`0000_ooooo3Ol000000ooooooo0000o`00000?
o`000003ooooool0003o000000Kooooo1?l00004ooooo`;o00000_ooool3o`0000oooooo0_l00000
0ooooooo0000o`000004ooooo`;o00004?ooool6o`0000?ooooo0_l0000Dooooo`;o00003?ooool2
o`0004?ooooo000Looooo`03o`000?oooooooooo02Oooooo0_l0000>ooooo`;o00000_ooool2o`00
00?ooooo0_l0000Wooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000=o`00
0003ooooool0003o000000ko00000_ooool2o`0000kooooo0_l0000Dooooo`So000000?oooooo`00
0?l000000ol0000=ooooo`Ko00003Oooool2o`0001Sooooo0_l00013ooooo`007?ooool00ol0003o
ooooooooo`0gooooo`;o00000_ooool2o`0000?ooooo0ol000000ooooooo0000o`00000Wooooo`Ko
000000?oooooo`000?l000007_l00002ooooo`;o00004Oooool2o`0001;ooooo0_l000000ooooooo
0000o`000002o`0000?ooooo0ol00002ooooo`?o00000_ooool6o`000003ooooool0003o000000?o
00003Oooool2o`0002Kooooo0_l0000eooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o0000
3Oooool2o`0000;ooooo1_l0000Oooooo`;o00002?oooolTo`0000?ooooo1?l00003ooooo`;o0000
2_ooool2o`0000[ooooo0_l00009ooooo`;o00002_ooool>o`000004ooooool0003o0000o`0000;o
oooo0_l00007ooooo`;o00003oooool2o`0000;ooooo0_l0000Booooo`;o0000=Oooool001cooooo
00?o0000ooooooooool0;Oooool3o`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l00000
0_ooool6o`0001[ooooo0_l00003ooooo`;o00003?oooolOo`0000;ooooo0_l000001?oooooo0000
o`000?l00003ooooo`;o00005_ooool4o`0000Gooooo0_l00006ooooo`ko000000?oooooo`000?l0
00000ol000001?oooooo0000o`000?l00002ooooo`;o00001oooool2o`0000oooooo0ol000000ooo
oooo0000o`00000>ooooo`;o000000?oooooo`000?l00000=_ooool001cooooo00?o0000oooooooo
ool0;_ooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o00000oooool2o`0000oo
oooo0ol0000>ooooo`;o00003oooool3o`0000;ooooo5_l000000ooooooo0000o`000003o`0000;o
oooo1Ol0000Booooo`;o00002_ooool2o`0000Gooooo0_l00003oooooaSo00003Oooool2o`0000ko
oooo0_l000000ooooooo0000o`00000Aooooo`;o000000?oooooo`000?l00000=_ooool001cooooo
00?o0000ooooooooool08_ooool2o`0000gooooo0_l00007ooooo`Ko00001?ooool2o`0000Wooooo
1Ol0000Looooo`Go000000?oooooo`000?l000006_l000001?oooooo0000o`000?ooool2o`0000Oo
oooo0_l0000:ooooo`Co00005?oooolEo`000004ooooool0003o0000o`0000cooooo0_l00005oooo
o`;o00001oooool2o`0000Oooooo0_l0000;ooooo`;o00001?ooool2o`0003?ooooo000Looooo`03
o`000?oooooooooo01[ooooo0_l00006ooooo`;o00003?ooool2o`0000Sooooo1?l00004ooooo`Co
000000?oooooo`000?l000002Oooool2o`00013ooooo0_l0000:ooooo`Wo000000?oooooo`000?l0
00000ol000000ooooooo0000o`00000<o`000003ooooool0003o000000Go00000_ooool2o`0000Go
oooo0_l000000ooooooo0000o`000009ooooo`;o00002oooool2o`0000?ooooo0_l00003ooooo`;o
000000?oooooo`000?l000003ol000001?oooooo0000o`000?l00005ooooo`;o00002_ooool4o`00
0003ooooool0003o000000cooooo0ol00006ooooo`;o000000?oooooo`000?l000000_l00004oooo
o`;o0000<oooool001cooooo00?o0000ooooooooool06_ooool2o`0001Cooooo0_l0000>ooooo`Go
00000_ooool2o`0001_ooooo1?l0000=ooooo`Co00001?ooool2o`0000Cooooo0_l00002ooooo`Go
00000oooool4o`000003ooooool0003o000000Co00001?ooool2o`0000;ooooo0_l000001?oooooo
0000o`000?l0000<ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`?o00000ooooolD
o`000003ooooool0003o000000?o00000oooool5o`0000;ooooo0_l00003ooooo`;o00000oooool2
o`0000_ooooo1Ol00005ooooo`;o000000?oooooo`000?l00000>oooool001cooooo00?o0000oooo
ooooool09Oooool2o`0000gooooo0_l0000:ooooo`;o00009?ooool3o`0000Wooooo2_l000000ooo
oooo0000o`000004ooooo`;o000000?oooooo`000?l000001?l00003ooooo`Co00000oooool2o`00
00Kooooo0_l000000ooooooo0000o`000002ooooo`?o00001?ooool2o`0000Kooooo1ol00003oooo
o`;o00000ooooolDo`000003ooooool0003o000000Co00001?ooool4o`0000;ooooo1?l00009oooo
o`?o00001oooool2o`000003ooooool0003o000004Gooooo000Looooo`03o`000?oooooooooo02Go
oooo0_l00003ooooo`;o00002?ooool2o`0000Kooooo0_l000000ooooooo0000o`00000>ooooo`Co
00005?ooool2o`0000Wooooo2_l00002ooooo`;o00000_ooool3o`000003ooooool0003o000000Co
00000oooool4o`0000;ooooo0_l00006ooooo`_o00001?ooool4o`0000Gooooo0_l00002ooooo`?o
00001?ooool2o`000003ooooool0003o000001Wo00001?ooool2o`0000Kooooo0_l00009ooooo`?o
00002?ooool2o`0000Oooooo0_l00004ooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0
5oooool2o`00017ooooo0_l0000:ooooo`Co00000_ooool5o`0000kooooo1?l0000?ooooo`;o0000
0oooool2o`0000Gooooo1?l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000?o
oooo1_l00003ooooo`;o00003?ooool2o`0000Cooooo1ol000000ooooooo0000o`000002o`0000Oo
oooo0_l00005ooooo`;o00000oooool2o`0000Cooooo7_l00002ooooo`Co00003_ooool2o`0000co
oooo0_l00007ooooo`;o00001?ooool3o`0003Oooooo000Looooo`;o00006?ooool2o`0001gooooo
1_l000001?oooooo0000o`000?l0000Cooooo`;o00003Oooool3o`0000;ooooo0_l00005ooooo`Co
000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00000oooool3o`0000Gooooo0_l00006oooo
o`;o00002_ooool3o`000003ooooool0003o000000;ooooo0ol0000KoooooaWo000000?oooooo`00
0?l000000_l000000ooooooo0000o`000002o`0000?ooooo0_l00009ooooo`;o00003?ooool2o`00
00_ooooo1Ol00003ooooo`;o0000<_ooool001cooooo00?o0000ooooooooool07oooool2o`00017o
oooo1?l00002ooooo`Co00000_ooool2o`0000oooooo0_l00002ooooo`;o00003Oooool3o`0000_o
oooo0_l00008ooooo`;o00000oooool2o`0000kooooo0_l00008ooooo`;o00005?ooool2o`0001?o
oooo3ol000000ooooooo0000o`00000:o`0000;ooooo0_l00003ooooo`Co00000oooool4o`0000;o
oooo0_l0000:ooooo`;o00000_ooool2o`0000Oooooo1?l00004ooooo`;o0000<_ooool001cooooo
00?o0000ooooooooool07oooool2o`0000Sooooo0_l00005ooooo`Ko00000_ooool2o`0000kooooo
0_l00005ooooo`Ko00003Oooool2o`0001Sooooo0_l000000ooooooo0000o`000004ooooo`;o0000
1_ooool2o`000003ooooool0003o000000Oooooo0_l0000Dooooo`?o00004_oooolLo`0000Sooooo
0ol00003ooooo`Co00000_ooool2o`0000kooooo0_l000000ooooooo0000o`000003ooooo`?o0000
1oooool2o`0000[ooooo0_l0000Uooooo`007?ooool00ol0003oooooooooo`0Yooooo`;o00001Ooo
ool2o`000003ooooool0003o000000;o00004Oooool2o`0000Oooooo1?l0000=ooooo`;o00003_oo
ool2o`0000Sooooo0_l00007ooooo`;o00000oooool5o`000003ooooool0003o000000kooooo0_l0
0004ooooo`;o00001Oooool2o`000003ooooool0003o000000Oooooo0ol00004ooooo`;o00000_oo
ool=o`000003ooooool0003o000000go00001oooool2o`0000Kooooo0_l00008ooooo`;o00002ooo
ool4o`000004ooooool0003o0000o`0000Oooooo0_l0000:ooooo`;o00009Oooool001cooooo00?o
0000ooooooooool0=Oooool2o`000003ooooool0003o000000kooooo1?l00005ooooo`;o00002ooo
ool2o`0000;ooooo0_l0000>ooooo`?o00000oooool2o`0000;ooooo0_l00002ooooo`;o000000?o
ooooo`000?l000001Oooool3o`0001?ooooo0_l00004ooooo`;o00001Oooool2o`0000[ooooo0ol0
0004ooooo`;o00000_ooool=o`000003ooooool0003o000000go00006Oooool4o`0000_ooooo0_l0
000=ooooo`;o0000;oooool001cooooo00?o0000ooooooooool0=?ooool2o`0000;ooooo0_l0000>
ooooo`Co00001Oooool3o`000003ooooool0003o000000Oooooo0_l0000Cooooo`;o00000oooool2
o`0000Cooooo1?l000000ooooooo0000o`00000Aooooo`;o00001Oooool2o`0001_ooooo0_l00005
ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`00000@o`000003ooooool0003o
000000?o00006oooool3o`0000;ooooo0_l0000Booooo`;o000000?oooooo`000?l00000;oooool0
01cooooo00?o0000ooooooooool0=?ooool2o`0001cooooo0_l000000ooooooo0000o`000009oooo
o`;o00003?ooool2o`0000?ooooo1?l00007ooooo`Co00003_ooool2o`0000;ooooo1?l00005oooo
o`;o00000oooool2o`0001gooooo0_l00002oooooako00004?ooool2o`0000Sooooo0_l00002oooo
o`;o00004_ooool2o`0003;ooooo000Looooo`03o`000?oooooooooo033ooooo0_l00007ooooo`;o
00005?ooool2o`0000oooooo0ol00004ooooo`;o00001Oooool2o`0000Gooooo0ol00004ooooo`;o
00004_ooool2o`0000;ooooo1?l00003ooooo`Go00000_ooool2o`00023ooooo7ol00007ooooo`;o
00001oooool2o`0000cooooo0_l00007ooooo`;o00000_ooool2o`0000Gooooo0_l0000booooo`00
7?ooool00ol0003oooooooooo`0Sooooo`;o00002oooool2o`0000Oooooo0_l0000Dooooo`;o0000
1Oooool2o`0000Kooooo0_l000000ooooooo0000o`000004ooooo`;o00001?ooool2o`0000Gooooo
1?l00004ooooo`?o00005oooool2o`0000?ooooo1Ol00003ooooo`;o00003Oooool2o`00013ooooo
4Ol000000ooooooo0000o`000005o`000003ooooool0003o000000[ooooo0_l0000=ooooo`;o0000
1_ooool2o`0000Oooooo0_l00002ooooo`;o00002?ooool2o`0002oooooo000Looooo`03o`000?oo
oooooooo02?ooooo0_l0000aooooo`;o00001_ooool2o`0000?ooooo0_l00008ooooo`;o00001?oo
ool3o`0000Gooooo1?l0000>ooooo`;o00001Oooool2o`0000gooooo0_l00002ooooo`;o00002Ooo
ool2o`0000Gooooo0ol00009ooooo`?o000000?oooooo`000?l000002ol000000ooooooo0000o`00
0007o`0000_ooooo0ol0000;ooooo`;o00004_ooool2o`0000Oooooo1?l0000_ooooo`007?ooool0
0ol0003oooooooooo`0booooo`;o00000_ooool2o`0002_ooooo0_l00002ooooo`;o00002_ooool3
o`0000Gooooo0_l00005ooooo`;o00002Oooool2o`0000Cooooo1Ol000000ooooooo0000o`00000<
ooooo`;o00001_ooool2o`0000Sooooo1Ol00004ooooo`;o000000?oooooo`000?l000005?l00000
0ooooooo0000o`000002o`0000_ooooo0ol0000=ooooo`?o00001?ooool2o`0000Wooooo0_l00007
ooooo`;o0000<Oooool001cooooo00?o0000ooooooooool0:oooool2o`0000Gooooo0ol000000ooo
oooo0000o`000002ooooo`;o00002?ooool2o`0000oooooo0_l0000@ooooo`;o00000_ooool4o`00
01?ooooo0_l00007ooooo`;o00001_ooool2o`000004ooooool0003o0000ooooo`;o00001oooool2
o`0000_ooooo0_l0000;ooooo`;o00001?ooool2o`000003ooooool0003o000001Wo00003Oooool2
o`0000Kooooo0_l00004ooooo`?o00001?ooool2o`0004Gooooo000Looooo`03o`000?oooooooooo
02_ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00001Oooool2o`0000Sooooo0_l00002
ooooo`;o00002oooool2o`0000;ooooo0_l0000@ooooo`Ko00002?ooool2o`00013ooooo0_l00004
ooooo`Ko00002oooool2o`0000Gooooo0_l00006ooooo`;o000000Coooooo`000?l0003o00003Ooo
oolLo`0000gooooo1?l00004ooooo`;o00002oooool4o`0000Oooooo0_l0000jooooo`007?ooool0
0ol0003oooooooooo`0_ooooo`;o000000?oooooo`000?l000005?ooool2o`0000oooooo0_l0000D
ooooo`;o00001oooool5o`0000Cooooo0_l0000>ooooo`Ko00004_ooool3o`0000Gooooo0_l00000
1?oooooo0000o`000?l0000=oooooaco00001oooool2o`0000Kooooo1?l0000;ooooo`;o00000ooo
ool3o`0000Oooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`0booooo`;o00001?ooool2
o`0000;ooooo0_l00009ooooo`;o00002_ooool2o`000003ooooool0003o000000gooooo0_l00008
ooooo`;o000000Coooooo`000?l0003o00000oooool2o`000003ooooool0003o000000Cooooo0_l0
000?ooooo`;o00000oooool2o`0000Cooooo0_l00008ooooo`;o000000?oooooo`000?l000001Ooo
ool2o`00017ooooo5ol000000ooooooo0000o`000002o`0000Oooooo1?l00006ooooo`;o00002Ooo
ool4o`0000?ooooo0_l00007ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0>?ooool2
o`0000;ooooo0_l000000ooooooo0000o`000006ooooo`;o00002_ooool2o`000003ooooool0003o
000000gooooo0_l00008ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000Kooooo0_l0
0006ooooo`;o00001oooool2o`0000Gooooo0ol000001?oooooo0000o`000?ooool2o`0000Sooooo
0_l00003ooooo`;o00000oooool8o`0000Wooooo6_l00002ooooo`;o00002Oooool2o`0000Oooooo
0_l00008ooooo`;o000000?oooooo`000?l000002oooool2o`0000cooooo0_l0000]ooooo`007?oo
ool2o`0003Oooooo0ol00006ooooo`;o00001?ooool2o`0000?ooooo0_l000000ooooooo0000o`00
000Hooooo`;o00003Oooool2o`0000Kooooo1?l00004ooooo`;o00000_ooool2o`0000?ooooo1Ol0
0002ooooo`;o00000_ooool4o`0000Sooooo0_l00002ooooo`Co00001Oooool6o`0000Wooooo0_l0
0002oooooaOo000000Coooooo`000?l0003o00001Oooool2o`0000Gooooo0_l00003ooooo`;o0000
2oooool2o`0001Wooooo0_l0000]ooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o00001ooo
ool3o`0000Gooooo0_l00005ooooo`;o00000oooool2o`000003ooooool0003o000001Sooooo0_l0
000@ooooo`;o00001Oooool2o`0000Cooooo0_l00002ooooo`;o00001Oooool3o`0000Gooooo1Ol0
0005ooooo`;o000000?oooooo`000?l000000_ooool4o`0000Oooooo0_l000000ooooooo0000o`00
0002ooooo`;o00002_oooolBo`000004ooooool0003o0000ooooo`?o00001Oooool2o`000004oooo
ool0003o0000ooooo`Go00004Oooool2o`000003ooooool0003o000001Cooooo0_l0000/ooooo`00
7?ooool00ol0003oooooooooo`0]ooooo`;o00001?ooool2o`0000Gooooo0ol000000ooooooo0000
o`00000;ooooo`;o00001?ooool2o`0000Cooooo0_l0000Booooo`;o00002?ooool6o`0000_ooooo
0_l00007ooooo`;o00002?ooool4o`0000Kooooo0_l00007ooooo`;o00002?ooool5o`000003oooo
ool0003o000000[ooooo1_l000000ooooooo0000o`000006o`000003ooooool0003o000000?o0000
00Coooooo`000?l0003ooooo0_l00003ooooo`;o000000?oooooo`000?l000001_l0000:ooooo`;o
00001Oooool2o`000003ooooool0003o000000Cooooo0_l0000>ooooo`;o0000;?ooool001cooooo
00?o0000ooooooooool0<oooool2o`0000Gooooo0ol0000>ooooo`;o00001?ooool2o`0000Cooooo
0_l0000Booooo`;o00002?ooool4o`0000;ooooo1?l00007ooooo`;o00001?ooool2o`000003oooo
ool0003o000000[ooooo0_l0000>ooooo`;o00002Oooool5o`0000gooooo1Ol00003ooooo`;o0000
2?ooool2o`0000Gooooo1?l00005ooooo`?o000000?oooooo`000?l000002oooool2o`0000Sooooo
0_l00004ooooo`Co0000>_ooool001cooooo00?o0000ooooooooool0;oooool2o`00027ooooo0_l0
0005ooooo`Co00000_ooool2o`0000gooooo0_l000001?oooooo0000o`000?l00007ooooo`Co0000
1oooool2o`0000Cooooo0_l000000ooooooo0000o`00000Fooooo`?o000000?oooooo`000?l00000
0_l0000Kooooo`?o000000?oooooo`000?l000004oooool2o`0000Kooooo0_l0000Oooooo`?o0000
>_ooool001cooooo00?o0000ooooooooool0;oooool2o`0000_ooooo0_l0000?ooooo`;o000000?o
ooooo`000?l000000_l00005ooooo`Co00000_ooool2o`0000?ooooo1?l00006ooooo`Ko00000_oo
ool2o`0000Kooooo0_l0000<ooooo`Go00001oooool2o`0000Wooooo0ol000001?oooooo0000o`00
0?l00003ooooo`;o00002_ooool3o`000003ooooool0003o000000oooooo0_l0000Iooooo`;o0000
1Oooool2o`0000;ooooo0_l0000=ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0??oo
ool2o`0000oooooo0_l000000ooooooo0000o`000005ooooo`Co00000oooool2o`0000Cooooo1Ol0
0006ooooo`Go00000_ooool2o`0000Kooooo0_l00006ooooo`;o00001?ooool4o`0000Sooooo0_l0
0009ooooo`?o00004Oooool5o`000003ooooool0003o0000013ooooo0ol00005ooooo`;o00001_oo
ool2o`0000Sooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool2o`0000;ooooo0ol0
0008ooooo`;o00001?ooool2o`0003kooooo000Looooo`03o`000?oooooooooo02Sooooo0_l0000@
ooooo`;o00003?ooool2o`0000?ooooo0ol00007ooooo`Co00000oooool2o`0000Kooooo0ol00002
ooooo`;o000000Coooooo`000?l0003ooooo0ol00002ooooo`;o00001?ooool6o`0000Cooooo0_l0
0004ooooo`Co00005?ooool2o`0000[ooooo0_l00005ooooo`;o000000Coooooo`000?l0003o0000
1Oooool4o`0000Wooooo0ol00005ooooo`;o00001_ooool2o`0000_ooooo0_l00006ooooo`;o0000
0_ooool3o`0000Kooooo0_l00006ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0:?oo
ool2o`00013ooooo0_l0000;ooooo`?o00001?ooool2o`0000Sooooo0_l00003ooooo`;o00003?oo
ool2o`000003ooooool0003o000000?ooooo1Ol00004ooooo`Ko00003?ooool2o`0000cooooo0_l0
0006ooooo`?o00002Oooool2o`0000Oooooo1Ol00004ooooo`Co00007?ooool2o`000003ooooool0
003o000000Gooooo0_l00006ooooo`;o000000?oooooo`000?l000001Oooool2o`000003ooooool0
003o000000?ooooo0_l000000ooooooo0000o`00000nooooo`007?ooool00ol0003oooooooooo`0f
ooooo`;o00002?ooool2o`0000Gooooo0_l0000:ooooo`;o00000oooool2o`0000?ooooo0_l0000<
ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000003o`0000Kooooo1?l00004
ooooo`;o00001_ooool2o`0000Wooooo0_l000000ooooooo0000o`000004ooooo`;o000000?ooooo
o`000?l000003oooool2o`000004ooooool0003o0000ooooo`;o00002oooool3o`0001Cooooo1ol0
0003ooooo`Co00001?ooool4o`000005ooooool0003o0000o`000?ooool01Ol00003ooooo`;o0000
00?oooooo`000?l00000@Oooool001cooooo00?o0000ooooooooool0=_ooool2o`0000Sooooo0_l0
0002ooooo`;o00003Oooool2o`0001Kooooo0ol000000ooooooo0000o`000009o`000003ooooool0
003o000000;ooooo0ol00004ooooo`;o00001_ooool2o`0000Wooooo1?l00005ooooo`;o00000ooo
ool2o`000003ooooool0003o000000Cooooo1?l00002ooooo`;o00004Oooool3o`0000Kooooo0_l0
000<ooooo`;o000000?oooooo`000?l000000oooool4o`0000Kooooo1?l00002ooooo`;o000000Co
ooooo`000?l0003o00001?ooool3o`000003ooooool0003o0000047ooooo000Looooo`03o`000?oo
oooooooo03gooooo0_l00005ooooo`;o00005_ooool3o`000003ooooool0003o000000[ooooo4Ol0
0002ooooo`;o00000_ooool2o`0000Sooooo0ol0000;ooooo`;o00002_ooool2o`000003ooooool0
003o000000Cooooo1?l00002ooooo`Co00003Oooool2o`0000Wooooo0_l00004ooooo`;o00003_oo
ool4o`00013ooooo0_l00004ooooo`;o00000_ooool2o`00047ooooo000Looooo`03o`000?oooooo
oooo033ooooo0ol0000:ooooo`;o00000oooool2o`0001Sooooo0ol000000ooooooo0000o`000007
oooooaSo00000_ooool2o`0000Sooooo1Ol00004ooooo`;o00001?ooool2o`0001Sooooo1?l00005
ooooo`;o00000_ooool2o`0000;ooooo0_l00004ooooo`;o00002Oooool2o`0000?ooooo0_l00005
ooooo`;o00004?ooool2o`0000Cooooo0_l00005ooooo`;o000000?oooooo`000?l00000@Oooool0
01cooooo00?o0000ooooooooool0<?ooool3o`0000Cooooo0_l00009ooooo`;o00006Oooool2o`00
00;ooooo0_l00003oooooa[o00003?ooool6o`0000Cooooo0_l00004ooooo`;o00006_ooool2o`00
00Cooooo0ol00002ooooo`;o00001_ooool4o`0000?ooooo0_l00009ooooo`;o00001Oooool2o`00
013ooooo0_l0000;ooooo`;o000000?oooooo`000?l00000@Oooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oo
oooooooo02oooooo0_l00006ooooo`;o00003?ooool2o`0001Kooooo0_l00002ooooo`;o00000ooo
oolGo`000003ooooool0003o000000cooooo0_l000000ooooooo0000o`000004ooooo`;o00005?oo
ool2o`0000_ooooo0_l00004ooooo`?o00001_ooool2o`0000;ooooo0_l00005ooooo`;o00001?oo
ool2o`0000?ooooo0_l0000Gooooo`;o000000?oooooo`000?l000002?ooool4o`0004;ooooo0000
1_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B401_ooool00ol0003oooooooooo`0_ooooo`;o00005?ooool2o`0000gooooo0ol0000<ooooo`Co
000000?oooooo`000?l000005_l0000Eooooo`;o00001_ooool2o`0000[ooooo1?l0000Booooo`;o
00000_ooool2o`000005ooooool0003o0000o`000?ooool00_l00002ooooo`;o00001_ooool4o`00
00?ooooo0_l0000Hooooo`Go00001?ooool2o`0000;ooooo0ol00012ooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`0fooooo`;o00001Oooool2o`0000Gooooo0_l0000:ooooo`;o00000_ooool3o`00
0003ooooool0003o000000Oooooo1_l000000ooooooo0000o`00000Go`0001[ooooo1?l000000ooo
oooo0000o`000004ooooo`Go00002_ooool2o`0000cooooo0_l000000ooooooo0000o`000004o`00
00;ooooo0_l000000ooooooo0000o`000003ooooo`;o00004oooool2o`0000Oooooo1Ol000000ooo
oooo0000o`000004ooooo`;o000000?oooooo`000?l00000A?ooool00003ooooool0003ooooo00;o
oooo00?o0000ooooooooool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0000coooo
o`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000;ooooo1Ol0000:oooo
o`;o00000_ooool2o`0000;ooooo0_l00007ooooo`;o000000?oooooo`000?l000004Ol000000ooo
oooo0000o`000008o`0000Wooooo0_l00009ooooo`;o00000oooool2o`0000;ooooo0ol00004oooo
o`?o00001_ooool2o`0000Cooooo0_l00008ooooo`?o000000?oooooo`000?l000001Ol00004oooo
o`Go00003?ooool2o`0000[ooooo0_l00006ooooo`Co00002?ooool2o`0000;ooooo0_l00014oooo
o`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`01_ooool00ol0003oooooooooo`0cooooo`;o00001Oooool2o`0000Gooooo1?l0000<oooo
o`;o000000?oooooo`000?l000003ooooolNo`0000Sooooo0_l00009ooooo`;o00001oooool2o`00
00Cooooo0_l00002ooooo`;o00001?ooool2o`0000kooooo0ol00003ooooo`;o00002?ooool3o`00
00gooooo0_l00007ooooo`;o00002Oooool2o`0000[ooooo0_l00004ooooo`;o0000@_ooool00003
ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03
o`000?oooooooooo02kooooo0_l0000Qooooo`;o00002OoooolWo`0000Gooooo0_l0000<ooooo`;o
00002oooool4o`0000;ooooo0_l00004ooooo`;o00002?ooool2o`0000Wooooo0_l00009ooooo`;o
00003?ooool2o`0000;ooooo0_l00005ooooo`;o00001oooool2o`0000Oooooo0ol00008ooooo`;o
0000@_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008oooo
o`03o`000?oooooooooo02kooooo0_l0000Qooooo`;o00002OoooolVo`0000;ooooo0_l00002oooo
o`?o00000oooool2o`0000Kooooo0_l000000ooooooo0000o`000008ooooo`Co00000_ooool2o`00
0004ooooool0003o0000ooooo`;o00001?ooool2o`0000;ooooo0_l00005ooooo`;o00000_ooool2
o`0000Kooooo0_l00002ooooo`;o00002oooool3o`000003ooooool0003o000000;ooooo0_l00007
ooooo`;o000000?oooooo`000?l000001oooool3o`000003ooooool0003o000004Wooooo00001_oo
ooook^k^oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003ooooo
ooooo`0eooooo`;o00005Oooool2o`0000Gooooo0_l0000;ooooo`So000000?oooooo`000?l00000
4ol00002ooooo`;o00000_ooool3o`000004ooooool0003o0000o`0000;ooooo0ol00009ooooo`;o
000000?oooooo`000?l000003_ooool2o`0000Kooooo0ol00009ooooo`;o00001oooool2o`000003
ooooool0003o000000;ooooo0_l000000ooooooo0000o`000002o`0000Oooooo0ol00002ooooo`Co
00001Oooool4o`000004ooooool0003o0000o`0000Kooooo1_l00002ooooo`;o0000AOooool001co
oooo00?o0000ooooooooool0=Oooool4o`0000Gooooo0_l0000<ooooo`;o00001Oooool2o`0000_o
oooo7Ol000000ooooooo0000o`000005ooooo`;o00001_ooool2o`0000gooooo0_l00008ooooo`;o
000000?oooooo`000?l000000_ooool2o`0000Gooooo0_l0000:ooooo`;o00001?ooool2o`000004
ooooool0003o0000ooooo`Co00000oooool5o`0000Oooooo1_l00007ooooo`Co000000Coooooo`00
0?l0003o00001Oooool5o`0000Cooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`0goooo
o`;o00001Oooool2o`0000oooooo0_l00005ooooo`;o00001_oooolRo`0000Cooooo0_l0000Poooo
o`;o000000?oooooo`000?l000000_ooool2o`0000Kooooo0_l00003ooooo`Co000000Coooooo`00
0?l0003o00000oooool5o`0000;ooooo1_l000000ooooooo0000o`000003o`0000Cooooo1?l00000
0ooooooo0000o`000008ooooo`;o000000?oooooo`000?l000000oooool2o`0000Cooooo1Ol0001;
ooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00002_ooool2o`0000[ooooo1_l000000ooo
oooo0000o`000005ooooob?o00001?ooool2o`0001Wooooo0_l00003ooooo`?o00001Oooool2o`00
0003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000004o`000003ooooool0003o0000
00?o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o000000Goooooo`000?l0003o0000oooo
o`06o`0000?ooooo1?l000000ooooooo0000o`000008ooooo`?o00001Oooool2o`0000;ooooo1ol0
001;ooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00002_ooool2o`0000;ooooo0_l00000
0ooooooo0000o`000005ooooo`Co00002?ooool2o`000005ooooool0003o0000o`000?ooool06ol0
0007ooooo`;o00002?ooool2o`0000;ooooo0_l00009ooooo`;o00000oooool5o`000003ooooool0
003o000000Ko00001_ooool2o`0000Kooooo1?l00004ooooo`Co00002Oooool4o`0000Cooooo0_l0
0006ooooo`;o00001?ooool3o`0000Wooooo2?l0001:ooooo`007?ooool00ol0003oooooooooo`11
ooooo`;o00001?ooool2o`000003ooooool0003o000000Gooooo0_l0000<ooooob7o000000?ooooo
o`000?l000000oooool2o`0000Oooooo1ol00004ooooo`;o000000?oooooo`000?l000002?ooool2
o`000003ooooool0003o000000[o00005?ooool2o`0000_ooooo0_l0000<ooooo`;o00002?ooool2
o`0000Sooooo1_l0000Cooooo`;o0000=Oooool001cooooo00?o0000ooooooooool0??ooool2o`00
00?ooooo0_l0000Eooooo`;o00000_ooool2o`000003ooooool0003o000001oo000000?oooooo`00
0?l000003?ooool2o`000003ooooool0003o000000Kooooo0_l000000ooooooo0000o`000006oooo
o`Go000000?oooooo`000?l000002Ol000000ooooooo0000o`00000:ooooo`;o00000_ooool2o`00
00kooooo0_l00008ooooo`;o00001oooool2o`0000?ooooo0_l00008ooooo`;o00005oooool2o`00
03Gooooo000Looooo`03o`000?oooooooooo033ooooo0_l0000:ooooo`Co00006?ooool2o`0000;o
oooo0_l00002ooooo`Co000000?oooooo`000?l000005_l00006ooooo`;o000000?oooooo`000?l0
00002_ooool4o`0000[ooooo1?l000000ooooooo0000o`000003o`000003ooooool0003o000000co
00002_ooool2o`000004ooooool0003o0000o`0000Sooooo1?l00002ooooo`Ko00001?ooool2o`00
00Kooooo0ol000000ooooooo0000o`000002o`0000Gooooo0_l0001Aooooo`007?ooool00ol0003o
ooooooooo`0`ooooo`;o00003?ooool2o`0001cooooo2?l000000ooooooo0000o`00000Ho`0000Co
oooo0_l000000ooooooo0000o`00000:ooooo`Co00002Oooool6o`0000;ooooo5Ol0000:ooooo`;o
00002Oooool4o`0000Cooooo1Ol00006ooooo`?o00000_ooool2o`0000;ooooo1?l00005ooooo`;o
0000DOooool001cooooo00?o0000ooooooooool0E_ooool2o`0000?ooooo9?l00005ooooo`;o0000
2Oooool2o`0000_ooooo0_l000000ooooooo0000o`000004o`0000;ooooo5Ol0000Cooooo`;o0000
2oooool2o`0000Kooooo0ol0000Kooooo`;o00003?ooool2o`0003Oooooo000Looooo`03o`000?oo
oooooooo04kooooo0_l00004ooooo`Co00000oooool2o`0000?ooooo0_l000000ooooooo0000o`00
0007o`000003ooooool0003o000000ko00001?ooool2o`000003ooooool0003o000000Wooooo0_l0
000;ooooo`;o000000?oooooo`000?l000000ol00002oooooaKo00001oooool2o`0000?ooooo0_l0
0005ooooo`;o00001_ooool2o`0000cooooo0_l0000?ooooo`Co00002?ooool2o`0000cooooo0_l0
000gooooo`007?ooool00ol0003oooooooooo`0jooooo`;o00003Oooool2o`0000?ooooo0_l00004
ooooo`;o00001Oooool4o`000003ooooool0003o000000Wo000000?oooooo`000?l000003Ol00004
ooooo`Ko00002oooool2o`0000kooooo1?l000000ooooooo0000o`00000Ho`0000Cooooo0_l00003
ooooo`;o00003Oooool4o`0000cooooo0_l00007ooooo`;o00001?ooool4o`0004oooooo000Loooo
o`;o0000>oooool2o`0000cooooo0ol00009ooooo`;o00000oooool3o`000004ooooool0003o0000
ooooo`Oo000000?oooooo`000?l000004Ol00004ooooo`;o00000_ooool2o`0000_ooooo0_l0000>
ooooo`?o00000_oooolLo`0001Sooooo1?l0000:ooooo`;o00001_ooool3o`0000;ooooo0_l0001C
ooooo`007?ooool00ol0003oooooooooo`18ooooo`;o00003?ooool2o`000005ooooool0003o0000
o`000?ooool00_l000000ooooooo0000o`00000Ho`0000Gooooo0_l00003ooooo`;o00000_ooool2
o`0000cooooo0_l00006ooooo`Ko000000?oooooo`000?l000002?l000000ooooooo0000o`00000:
o`000003ooooool0003o000000;o00003oooool2o`000003ooooool0003o000000Gooooo1?l00009
ooooo`;o00001_ooool4o`000003ooooool0003o000000Sooooo0_l000000ooooooo0000o`000016
ooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o00002_ooool2o`0000?ooooo1?l00005oooo
oa;o000000Coooooo`000?l0003o00001Oooool2o`000003ooooool0003o000000;o00000_ooool2
o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000;ooooo6ol00002ooooo`;o000000?ooooo
o`000?l000003?ooool2o`000003ooooool0003o000000Oooooo0_l00009ooooo`;o00001Oooool2
o`000004ooooool0003o0000ooooo`Co00001_ooool2o`000003ooooool0003o000004Kooooo000L
ooooo`03o`000?oooooooooo04[ooooo0_l00008ooooo`;o00001Oooool3o`0000Kooooo4ol00005
ooooo`;o00000_ooool6o`0000Sooooo0ol0000Coooooago000000?oooooo`000?l000003Oooool2
o`0000?ooooo0_l0000=ooooo`;o00001_ooool3o`0000Cooooo1?l0001Aooooo`007?ooool00ol0
003oooooooooo`0dooooo`;o00007_ooool2o`0000Gooooo0_l00007ooooo`Oo00000oooool3o`00
0003ooooool0003o000000?o00001Oooool3o`000004ooooool0003o0000ooooo`Co000000?ooooo
o`000?l000000_ooool4o`000003ooooool0003o000000;o00003Oooool2o`000003ooooool0003o
000001[o00000oooool2o`0000_ooooo0_l00003ooooo`;o00000oooool2o`0000Sooooo0_l00002
ooooo`Oo00002_ooool2o`0004gooooo000Looooo`03o`000?oooooooooo03Cooooo0_l0000^oooo
o`?o000000Coooooo`000?l0003o00000oooool3o`0000cooooo0_l00002ooooo`;o00000_ooool2
o`000003ooooool0003o000000;ooooo0ol00002ooooo`Co00002?ooool2o`0000?ooooo0_l00002
oooooago000000?oooooo`000?l000005Oooool2o`0000cooooo1?l000001?oooooo0000o`000?oo
ool2o`0000Oooooo0_l0000>ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0Foooool2
o`0000Kooooo0_l000000ooooooo0000o`000004o`0000;ooooo0_l0000;ooooo`;o00001?ooool2
o`0000?ooooo1?l00003ooooo`;o00000oooool2o`0000?ooooo0_l00004ooooo`;o00001_oooolN
o`0002Oooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo1?l00006ooooo`;o0000?Oooool0
01cooooo00?o0000ooooooooool0Foooool2o`0000Kooooo2Ol00002ooooo`?o00000_ooool2o`00
00Kooooo0_l00004ooooo`?o00000_ooool4o`0000?ooooo0_l00008ooooo`;o00003?oooolLo`00
00Cooooo0_l0000Dooooo`Co00001_ooool2o`0000?ooooo0_l000000ooooooo0000o`000009oooo
o`;o00001_ooool4o`0004Gooooo000Looooo`03o`000?oooooooooo03Wooooo0_l0000Kooooo`;o
00003?ooool4o`0000Oooooo0_l00002ooooo`;o00003?ooool3o`0000Wooooo0_l00003ooooo`;o
00001?ooool2o`0000[ooooo0_l000000ooooooo0000o`00000Io`0000?ooooo0_l00007ooooo`;o
00000oooool4o`0000Cooooo1?l00006ooooo`;o00001_ooool5o`0000Kooooo0_l00008ooooo`;o
0000AOooool001cooooo00?o0000ooooooooool0=_ooool2o`000003ooooool0003o000001_ooooo
1?l0000<ooooo`;o00008?ooool2o`0000?ooooo0_l00003ooooo`;o000000Coooooo`000?l0003o
oooo0_l00006ooooo`;o00000_oooolOo`0000_ooooo1?l000000ooooooo0000o`000002o`0000ko
oooo0_l00008ooooo`?o00001?ooool2o`0000[ooooo0_l00015ooooo`007?ooool00ol0003ooooo
ooooo`0fooooo`;o00007_ooool4o`000003ooooool0003o000000Cooooo0_l00004ooooo`;o0000
4Oooool2o`0000cooooo0_l00008ooooo`Go00001?ooool4o`000004ooooool0003o0000ooooob3o
00000_ooool2o`0000Wooooo0_l00002ooooo`;o000000?oooooo`000?l000003?ooool2o`0000Wo
oooo0ol00002ooooo`?o00001Oooool2o`0004[ooooo000Looooo`03o`000?oooooooooo05Cooooo
1?l00003ooooo`;o00001?ooool3o`0000?ooooo0_l00003ooooo`;o00001_ooool2o`000004oooo
ool0003o0000ooooo`;o00001?ooool2o`00013ooooo1Ol00004ooooo`Co00000oooool3o`0000;o
oooo6ol00003ooooo`;o00003Oooool2o`000003ooooool0003o000000Wooooo0ol0000<ooooo`;o
00000_ooool2o`0000Kooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`1Dooooo`Co0000
00?oooooo`000?l000001oooool2o`0000Sooooo0_l00006ooooo`;o000000?oooooo`000?l00000
1oooool2o`0001?ooooo0_l0000;oooooaco00001_ooool3o`0000?ooooo0_l00002ooooo`;o0000
1?ooool4o`0000?ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00003?ooool3o`0005Go
oooo000Looooo`03o`000?oooooooooo05Cooooo1?l000000ooooooo0000o`00000Hooooo`;o0000
3?ooool2o`0001;ooooo0_l00004ooooo`;o00001_ooool4o`000003ooooool0003o000001;o0000
2?ooool2o`0000Cooooo0_l00002ooooo`;o00001_ooool2o`0000;ooooo0ol00002ooooo`;o0000
2_ooool3o`0000Cooooo0_l00008ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0DOoo
ool2o`000003ooooool0003o000000Cooooo0_l00004ooooo`?o00004?ooool2o`0000Cooooo0_l0
0006ooooo`;o00000oooool2o`0000oooooo0_l00002ooooo`;o000000?oooooo`000?l000001?oo
ool3o`000003ooooool0003o000000;o00000_ooool>o`0000;ooooo0_l0000Jooooo`;o00003ooo
ool3o`0000_ooooo0_l000000ooooooo0000o`00001;ooooo`007?ooool00ol0003oooooooooo`1A
ooooo`?o00001_ooool2o`0000Cooooo0ol0000<ooooo`;o00001oooool3o`0000Kooooo0_l00003
ooooo`;o00000_ooool2o`0000Oooooo2?l00003ooooo`;o00001Oooool2o`0000;ooooo0_l00002
ooooo`go00001?ooool4o`0001;ooooo0_l0000Fooooo`;o00001?ooool2o`0000Gooooo0_l0001>
ooooo`007?ooool2o`0005?ooooo0_l00007ooooo`;o00000oooool2o`000003ooooool0003o0000
00Sooooo1?l00006ooooo`?o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00001_ooool2
o`0000Oooooo1?l00002ooooo`;o00004_ooool>o`0000Gooooo0_l00003ooooo`;o00001?ooool2
o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000005_ooool2o`0000Cooooo0_l0
0002ooooo`;o0000DOooool001cooooo00?o0000ooooooooool0@?ooool2o`0001Wooooo0_l00006
ooooo`;o00001_ooool4o`0000;ooooo0ol00003ooooo`;o00000_ooool2o`000003ooooool0003o
000000;ooooo0_l000000ooooooo0000o`00000Uooooo`Co00000_ooool6o`000003ooooool0003o
000000[ooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l0000;ooooo`;o00005_oo
ool2o`00057ooooo000Looooo`03o`000?oooooooooo043ooooo0_l0000Oooooo`;o00002?ooool2
o`0000Cooooo0ol00003ooooo`;o000000?oooooo`000?l000002Oooool2o`0001;ooooo0_l0000<
ooooo`Co000000?oooooo`000?l000001?ooool4o`0000;ooooo0_l0000Gooooo`;o00001_ooool2
o`0000?ooooo0_l00007ooooo`;o00002Oooool2o`0000Cooooo0_l0001?ooooo`007?ooool00ol0
003oooooooooo`1Qooooo`;o000000?oooooo`000?l000002oooool2o`0000Oooooo0_l0000Moooo
o`;o00001Oooool3o`0000Cooooo1?l00002ooooo`;o00001?ooool7o`0001oooooo1?l00006oooo
o`;o00000_ooool2o`0000Wooooo1?l00002ooooo`;o0000Coooool001cooooo00?o0000oooooooo
ool0B?ooool2o`0001[ooooo0_l00006ooooo`;o00000oooool2o`00013ooooo0_l0000Dooooo`;o
00001Oooool5o`0000Sooooo0_l00007ooooo`;o00001?ooool2o`0001gooooo0_l00006ooooo`;o
00003oooool3o`0005;ooooo000Looooo`03o`000?oooooooooo04Sooooo0_l0000>ooooo`;o0000
0oooool2o`0000gooooo0_l00004ooooo`;o00003?ooool5o`0001Gooooo0ol00006ooooo`;o0000
1oooool2o`0000;ooooo0_l0000:ooooo`;o00001Oooool2o`0000[ooooo0_l00009ooooo`;o0000
6Oooool4o`00053ooooo000Looooo`03o`000?oooooooooo05Sooooo1?l000000ooooooo0000o`00
0002o`0000gooooo0_l00002ooooo`;o00003?ooool4o`0001Kooooo0ol000001?oooooo0000o`00
0?l0000;ooooo`;o00000_ooool4o`0000Oooooo0_l00003ooooo`;o000000?oooooo`000?l00000
2_ooool4o`0000Oooooo0_l0000Kooooo`;o0000D?ooool001cooooo00?o0000ooooooooool0F_oo
ool7o`0000cooooo0ol0000:ooooo`;o00001?ooool2o`0000;ooooo0_l00003ooooo`;o00004ooo
ool5o`0000Gooooo1?l00005ooooo`?o00001oooool2o`0000?ooooo0ol00008ooooo`;o00001?oo
ool2o`0001Wooooo1?l0001Iooooo`007?ooool00ol0003oooooooooo`1Looooo`;o00002_ooool4
o`000003ooooool0003o000000?ooooo0_l00006ooooo`;o00002?ooool2o`0000?ooooo0_l0000D
ooooo`Ko00000_ooool5o`0000Gooooo0_l0000>ooooo`;o000000?oooooo`000?l000001Oooool3
o`000003ooooool0003o000000Kooooo0_l0000@ooooo`;o000000?oooooo`000?l000000_l0001I
ooooo`007?ooool00ol0003oooooooooo`1Kooooo`;o00002?ooool2o`000003ooooool0003o0000
00;o00001Oooool3o`0001Gooooo0_l0000Dooooo`?o000000?oooooo`000?l000000_ooool2o`00
00Gooooo0_l000000ooooooo0000o`00000;ooooo`;o00001?ooool2o`0000Kooooo0_l000000ooo
oooo0000o`000006ooooo`;o00002_ooool2o`0000Cooooo0_l00009ooooo`;o0000Doooool001co
oooo00?o0000ooooooooool0Foooool2o`0000Sooooo0_l00003ooooo`;o00001Oooool3o`0000Ko
oooo0_l00009ooooo`;o00001oooool2o`0000oooooo0_l00008ooooo`;o00000oooool2o`0000ko
oooo0_l0000Cooooo`Go00000_ooool2o`0000Kooooo0ol0000=ooooo`Co0000Doooool001cooooo
00?o0000ooooooooool0HOooool2o`0000Oooooo0_l00003ooooo`;o00001?ooool2o`0000?ooooo
1?l00002ooooo`;o00000oooool2o`000003ooooool0003o000000Cooooo0_l00005ooooo`Co0000
1_ooool2o`0000Cooooo1_l0000Sooooo`;o00000oooool5o`0000;ooooo1?l00004ooooo`;o0000
1?ooool2o`0000Gooooo0_l000000ooooooo0000o`00001Eooooo`007?ooool00ol0003ooooooooo
o`1Qooooo`;o00002?ooool2o`0000;ooooo0_l00004ooooo`;o00001Oooool2o`0000;ooooo0_l0
0006ooooo`;o00001Oooool2o`0000Cooooo1?l00004ooooo`;o00001_ooool4o`0002Gooooo0_l0
0003ooooo`;o00001oooool2o`0000Oooooo0_l000000ooooooo0000o`000005ooooo`;o0000F?oo
ool001cooooo00?o0000ooooooooool0@oooool2o`0001Wooooo0_l0000;ooooo`;o00003oooool2
o`0000Sooooo0_l00007ooooo`;o000000?oooooo`000?l000002Oooool2o`0001Kooooo0_l0000R
ooooo`;o00002_ooool2o`0000Oooooo0_l00004ooooo`;o0000Doooool001cooooo00?o0000oooo
ooooool0@oooool2o`0001Wooooo0_l0000Iooooo`;o000000?oooooo`000?l000000_l00006oooo
o`;o00002_ooool2o`0001[ooooo0_l00005ooooo`;o00003Oooool2o`0000;ooooo0_l00002oooo
o`;o00002Oooool4o`0001?ooooo0_l00004ooooo`;o0000Doooool001cooooo00?o0000oooooooo
ool0DOooool2o`0000Cooooo0_l00006ooooo`;o00005oooool3o`0000;ooooo0ol0000Aooooo`;o
00001?ooool2o`0001Gooooo0_l00004ooooo`;o00003_ooool2o`000004ooooool0003o0000o`00
00;ooooo0_l00005ooooo`;o00000_ooool2o`0000Wooooo0_l0001Uooooo`007?ooool2o`0005;o
oooo0_l00004ooooo`;o00001_ooool2o`0000Kooooo0_l00006ooooo`;o00001?ooool2o`000003
ooooool0003o000000Sooooo0_l0000=ooooo`?o00000oooool2o`0000Cooooo0_l0000Eooooo`;o
00000_ooool2o`0000gooooo0_l00003ooooo`;o00001Oooool2o`0000gooooo1?l00009ooooo`;o
0000F?ooool001cooooo00?o0000ooooooooool0Ioooool2o`0000Kooooo0_l00004ooooo`;o0000
00?oooooo`000?l000001oooool4o`0000Oooooo0_l00002ooooo`Go00002?ooool2o`0000Wooooo
0_l0000>ooooo`;o00000oooool2o`0000;ooooo0_l00005ooooo`;o00004?ooool2o`000003oooo
ool0003o000000Gooooo0_l00006ooooo`;o000000?oooooo`000?l00000F?ooool001cooooo00?o
0000ooooooooool0Goooool2o`0000Oooooo0_l00008ooooo`;o00001Oooool2o`0000Kooooo1?l0
0007ooooo`;o00000_ooool5o`0001?ooooo0_l0000Cooooo`;o00000_ooool2o`0000Gooooo0_l0
000=ooooo`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`Co00001_ooool2o`0005_ooooo
000Looooo`03o`000?oooooooooo04gooooo0_l0000@ooooo`;o00000_ooool2o`0000?ooooo0_l0
0002ooooo`;o00000oooool3o`0000Gooooo0_l0000=ooooo`?o00002?ooool2o`0001_ooooo0_l0
0009ooooo`;o00003Oooool3o`0000;ooooo0_l00006ooooo`;o00002Oooool4o`0006?ooooo000L
ooooo`03o`000?oooooooooo04gooooo0_l0000>ooooo`;o00001?ooool2o`0000Cooooo0_l00000
0ooooooo0000o`000003ooooo`;o00005?ooool4o`0000Sooooo1?l0000<ooooo`;o00002oooool2
o`0000Wooooo0_l0000=ooooo`?o00000_ooool2o`0007Sooooo000Looooo`03o`000?oooooooooo
05gooooo0_l00007ooooo`;o000000?oooooo`000?l000001_ooool2o`0001Cooooo0_l0000;oooo
o`?o00003?ooool2o`0000;ooooo0_l00008ooooo`;o00004?ooool4o`0000cooooo0_l00003oooo
o`;o0000Koooool001cooooo00?o0000ooooooooool0I?ooool4o`0000Wooooo0_l00003ooooo`;o
00005_ooool2o`0000Cooooo1?l0000>ooooo`Co00001oooool2o`000003ooooool0003o000000_o
oooo2?l0000:ooooo`;o00000oooool2o`0006oooooo000Looooo`03o`000?oooooooooo05gooooo
0_l00005ooooo`;o00004?ooool2o`0000kooooo0_l00006ooooo`;o00001?ooool4o`0000Oooooo
0_l00005ooooo`Co00002?ooool4o`0000_ooooo0_l00004ooooo`;o00004oooool2o`0006_ooooo
000Looooo`03o`000?oooooooooo05cooooo0ol00007ooooo`;o00005?ooool2o`0000Sooooo0_l0
000<ooooo`;o000000?oooooo`000?l000000oooool2o`000003ooooool0003o0000017ooooo0_l0
0002ooooo`;o00002Oooool2o`0000Kooooo1?l0000?ooooo`;o0000Joooool001cooooo00?o0000
ooooooooool0F_ooool4o`0000Sooooo0_l00009ooooo`;o00002Oooool2o`0000Wooooo0_l00002
ooooo`;o00001oooool5o`0000?ooooo0_l00003ooooo`;o00003oooool6o`0000Wooooo0_l00003
ooooo`;o000000?oooooo`000?l000000_l0001looooo`007?ooool00ol0003oooooooooo`1Joooo
o`;o00001oooool2o`000003ooooool0003o000000Wooooo0_l0000Aooooo`Ko000000?oooooo`00
0?l000001_ooool2o`000003ooooool0003o000000;o00001oooool2o`00017ooooo0_l00008oooo
o`;o00001_ooool2o`0000_ooooo0_l000000ooooooo0000o`00001aooooo`007?ooool00ol0003o
ooooooooo`1Sooooo`;o000000?oooooo`000?l000007?ooool3o`000003ooooool0003o000000Wo
oooo0_l00003ooooo`;o00008Oooool2o`000003ooooool0003o000000[ooooo0_l00007ooooo`;o
000000Coooooo`000?l0003ooooo0_l00004ooooo`;o0000J?ooool001cooooo00?o0000oooooooo
ool0Hoooool2o`00017ooooo0_l0000@ooooo`;o00000oooool4o`0000[ooooo0_l0000Booooo`;o
00002_ooool2o`000003ooooool0003o000000[ooooo0_l0000=ooooo`;o00001?ooool2o`0006So
oooo000Looooo`03o`000?oooooooooo06oooooo0_l00005ooooo`;o00004oooool6o`0000[ooooo
0_l00004ooooo`;o00001_ooool2o`0000Cooooo0_l00003ooooo`;o00002?ooool2o`0000[ooooo
0ol00004ooooo`;o00001_ooool2o`0000oooooo0_l0001Mooooo`0000Koooooonk^k_lb<S;o0000
oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000oooo
ooooool0Koooool2o`000003ooooool0003o000001Oooooo0ol000000ooooooo0000o`000008oooo
o`;o00001_ooool2o`000003ooooool0003o000000?ooooo1?l00002ooooo`;o00000_ooool3o`00
00Cooooo0_l0000<ooooo`;o000000?oooooo`000?l000001?ooool2o`0001Oooooo0_l0001Moooo
o`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonH
V9So8B4Q00Kooooo00?o0000ooooooooool0Koooool2o`000003ooooool0003o000000cooooo1Ol0
0006ooooo`;o00001oooool2o`0000?ooooo0_l00004ooooo`?o00000_ooool2o`0000Gooooo0_l0
0002ooooo`;o00000_ooool2o`0000Gooooo0_l0000<ooooo`?o0000O_ooool00003ooooool@413o
oooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool0IOooool2o`0000Wooooo0_l0000>ooooo`Go00003oooool2o`0000Wooooo0ol0
000=ooooo`?o000000Goooooo`000?l0003o0000ooooo`02o`0000Sooooo1?l00004ooooo`Co0000
O?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Olb<S;oV9RHoooo
oonHV9So<S8b00Kooooo0ol0001Uooooo`?o000000?oooooo`000?l000001Oooool2o`0000Sooooo
1?l00005ooooo`;o000000?oooooo`000?l000000_ooool2o`0002;ooooo1?l00002ooooo`;o0000
00?oooooo`000?l000002?ooool4o`0000Kooooo0_l00004ooooo`;o0000M_ooool00003ooooool0
003ooooo00;ooooo00?o0000ooooooooool02Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo
00?o0000ooooooooool0I_ooool2o`000003ooooool0003o000000Sooooo0_l00005ooooo`Co0000
2?ooool2o`0000;ooooo0_l0000Oooooo`;o000000?oooooo`000?l000000oooool2o`0000;ooooo
0_l0000Cooooo`;o00000oooool2o`0000;ooooo0_l0001booooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooo
ooooo`1cooooo`;o00004Oooool2o`0000Cooooo0_l0000Mooooo`;o00001?ooool4o`000004oooo
ool0003o0000o`0000;ooooo0_l0000?ooooo`;o00001oooool2o`0007;ooooo00001_ooooooMgMg
oiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooo
oooo08cooooo0_l00006ooooo`;o00006oooool2o`0000?ooooo1ol0002<ooooo`0000Koooooonk^
k_lb<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003ooooo
ooooo`26ooooo`;o00000oooool2o`0000Oooooo0_l00005ooooo`;o00001oooool2o`000003oooo
ool0003o000000Sooooo1?l00003ooooo`Co0000SOooool001cooooo00?o0000ooooooooool0I_oo
ool2o`0001[ooooo0_l00002ooooo`;o00000oooool2o`0000Cooooo0_l00008ooooo`;o00001ooo
ool2o`000003ooooool0003o000000Wooooo0ol0002Dooooo`007?ooool00ol0003oooooooooo`1V
ooooo`;o00006_ooool2o`0000gooooo0_l00002ooooo`;o00001?ooool2o`0000Cooooo0_l0000M
ooooo`;o0000Qoooool001cooooo00?o0000ooooooooool0Poooool2o`0000_ooooo0_l00003oooo
o`;o00001?ooool2o`0000;ooooo1?l0000Mooooo`;o0000Qoooool001cooooo00?o0000oooooooo
ool0Poooool2o`0000Cooooo0_l00005ooooo`;o00002Oooool2o`0000;ooooo0_l0000Yooooo`;o
0000OOooool001cooooo00?o0000ooooooooool0ROooool5o`0001?ooooo0_l00009ooooo`?o0000
6oooool3o`0007cooooo000Looooo`03o`000?oooooooooo08[ooooo1?l00007ooooo`;o00001?oo
ool2o`0000Cooooo1_l000000ooooooo0000o`000002ooooo`?o00002?ooool2o`0000Oooooo0ol0
0008ooooo`;o0000O?ooool001cooooo00?o0000ooooooooool0LOooool2o`0002;ooooo0_l00002
ooooo`Co00001_ooool4o`000003ooooool0003o000000;o00001_ooool2o`0000?ooooo0_l00002
ooooo`;o00000oooool3o`0008Kooooo000Looooo`03o`000?oooooooooo077ooooo0_l0000Voooo
o`;o000000?oooooo`000?l000001Oooool2o`0000Cooooo0ol00002ooooo`Ko00001oooool2o`00
00?ooooo0_l00027ooooo`007?ooool00ol0003oooooooooo`21ooooo`;o00006Oooool2o`0000ko
oooo1_l0002Gooooo`007?ooool00ol0003oooooooooo`21ooooo`;o00007oooool2o`0000Sooooo
0_l0002Kooooo`007?ooool00ol0003oooooooooo`2Nooooo`;o00000_ooool2o`00017ooooo0_l0
002Booooo`007?ooool2o`0009kooooo0ol0000Cooooo`Co00000oooool2o`0008gooooo000Loooo
o`03o`000?oooooooooo09Gooooo0_l00006ooooo`;o00005?ooool2o`0000Gooooo0_l0002=oooo
o`007?ooool00ol0003oooooooooo`2Eooooo`;o0000/_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`2=ooooo`;o00008oooool2o`0009Gooooo000L
ooooo`03o`000?oooooooooo08gooooo0_l0000Sooooo`;o0000UOooool001cooooo00?o0000oooo
ooooool0[?ooool2o`0009_ooooo000Looooo`03o`000?oooooooooo0:cooooo0_l0002Kooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`24ooooo`;o0000`oooool001cooooo00?o0000
ooooooooool0Q?ooool2o`000<?ooooo000Looooo`;o0000Toooool2o`000;Gooooo000Looooo`03
o`000?oooooooooo09;ooooo0_l0002eooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001;ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood[o
oooo000Dooooo`03o`000?oooooooooo00Gooooo0ol0003ooooood[ooooo000Dooooo`03o`000?oo
oooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0
003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001;ooooo
00?oEEEEofIVI_l00000oooooomDooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00XOooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo01Kooooo1?l000002?l@
413ooooooooooonHV9So410@o`000?lb<S;oc<c<0oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP2<ooooo`00X_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l0000<ooooo`03
o`000?oooooooooo00;ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg08cooooo002Rooooo`05o`000?oooooo
ooooooooool000006oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o
V9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@08cooooo002Rooooo`05o`000?oo
ooooooooooooool000002Oooool6o`0000cooooo00?o0000ooooooooool01Oooool00onYZJWo410@
ooooo`04ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00002<ooooo`00
X_ooool01Ol0003oQhN7oooooonYZJWo000001_ooooo00?o0000ooooooooool01?ooool00ol@413o
0000okZj^P06ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00002<oooo
o`00XOooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo01Wooooo00?o0000oooooooo
ool01Oooool00onj^[[o8B4Qooooo`06ooooo`05o`000?ooooooooooooooool@41000oooool00ol@
413oooooooooo`2:ooooo`00`_ooool00ol0003oooooooooo`02ooooo`05oa0@4?nHV9SooooookZj
^_l000000oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`2<ooooo`00`?ooool00omEEEGoIVIVo`000004ooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP2<ooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1326) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.29953 .59213 Mdot
.30574 .59615 Mdot
.64735 .52266 Mdot
.46464 .41825 Mdot
.805 .47759 Mdot
.64698 .55813 Mdot
.55577 .65619 Mdot
.50525 .67531 Mdot
.66075 .51881 Mdot
.46785 .71239 Mdot
.52186 .69351 Mdot
.41428 .33851 Mdot
.52824 .66144 Mdot
.43539 .43959 Mdot
.81019 .33394 Mdot
.48928 .39033 Mdot
.30004 .59609 Mdot
.65811 .35228 Mdot
.43806 .35765 Mdot
.61607 .54742 Mdot
.28546 .59729 Mdot
.43803 .43175 Mdot
.36477 .6068 Mdot
.43491 .44009 Mdot
.45558 .39328 Mdot
.36572 .58944 Mdot
.33753 .63861 Mdot
.43238 .38144 Mdot
.40897 .38797 Mdot
.50737 .68469 Mdot
.5129 .26796 Mdot
.8111 .37538 Mdot
.45816 .48579 Mdot
.65065 .25496 Mdot
.51024 .64925 Mdot
.26892 .50493 Mdot
.64926 .54605 Mdot
.53551 .68249 Mdot
.54035 .68464 Mdot
.50436 .64587 Mdot
.52333 .68349 Mdot
.35334 .60713 Mdot
.41787 .65239 Mdot
.72602 .57028 Mdot
.48924 .42781 Mdot
.76573 .62382 Mdot
.25377 .59988 Mdot
.41237 .45346 Mdot
.33636 .57033 Mdot
.69106 .40384 Mdot
.68071 .63845 Mdot
.54401 .65137 Mdot
.61278 .55598 Mdot
.10644 .48647 Mdot
.53962 .65863 Mdot
.37024 .41875 Mdot
.65121 .53372 Mdot
.42831 .42332 Mdot
.43099 .44162 Mdot
.28653 .36321 Mdot
.45458 .46172 Mdot
.62441 .3885 Mdot
.39081 .58844 Mdot
.52783 .58372 Mdot
.6623 .53135 Mdot
.53792 .69251 Mdot
.31413 .59795 Mdot
.52741 .65422 Mdot
.36068 .45367 Mdot
.63555 .57803 Mdot
.41265 .45542 Mdot
.52626 .6934 Mdot
.32643 .63237 Mdot
.41135 .40135 Mdot
.69976 .48331 Mdot
.74349 .70709 Mdot
.59763 .40764 Mdot
.26709 .47597 Mdot
.28171 .36184 Mdot
.7207 .43895 Mdot
.45937 .37412 Mdot
.56187 .31428 Mdot
.74914 .68496 Mdot
.37783 .57796 Mdot
.49869 .39268 Mdot
.66646 .3538 Mdot
.41549 .39884 Mdot
.79798 .60859 Mdot
.41177 .46502 Mdot
.63014 .42831 Mdot
.66384 .51419 Mdot
.33599 .58397 Mdot
.46685 .41485 Mdot
.40069 .41076 Mdot
.31124 .32287 Mdot
.38615 .40076 Mdot
.44277 .41159 Mdot
.34775 .56338 Mdot
.54344 .6523 Mdot
.38207 .44648 Mdot
.68804 .59706 Mdot
.6474 .49991 Mdot
.4781 .4241 Mdot
.6867 .53748 Mdot
.36204 .62227 Mdot
.40128 .41224 Mdot
.54489 .67869 Mdot
.4679 .44344 Mdot
.39886 .77177 Mdot
.30208 .60636 Mdot
.42198 .37973 Mdot
.62335 .34887 Mdot
.21847 .41852 Mdot
.3377 .57636 Mdot
.67448 .60461 Mdot
.41926 .36658 Mdot
.43411 .40701 Mdot
.31223 .59021 Mdot
.67463 .50873 Mdot
.78764 .62595 Mdot
.36005 .56093 Mdot
.49816 .67312 Mdot
.29241 .61884 Mdot
.41191 .34508 Mdot
.66893 .53977 Mdot
.71775 .5955 Mdot
.38131 .7402 Mdot
.54058 .25931 Mdot
.41655 .40154 Mdot
.42947 .66384 Mdot
.62809 .5088 Mdot
.33161 .59284 Mdot
.52309 .65594 Mdot
.50835 .41715 Mdot
.32255 .61816 Mdot
.51949 .69656 Mdot
.63397 .3562 Mdot
.62516 .68185 Mdot
.3458 .62563 Mdot
.54744 .46939 Mdot
.55767 .69201 Mdot
.526 .63885 Mdot
.53855 .18277 Mdot
.31807 .59583 Mdot
.61387 .38283 Mdot
.51384 .65874 Mdot
.52341 .2404 Mdot
.48511 .43517 Mdot
.5256 .31026 Mdot
.24573 .65828 Mdot
.6246 .23633 Mdot
.63818 .70074 Mdot
.59964 .36476 Mdot
.52551 .70716 Mdot
.45422 .40471 Mdot
.36327 .58063 Mdot
.36732 .59839 Mdot
.45775 .45932 Mdot
.46396 .39203 Mdot
.41009 .45644 Mdot
.39371 .43215 Mdot
.36426 .33919 Mdot
.39986 .36987 Mdot
.2351 .57442 Mdot
.34136 .58244 Mdot
.46045 .41396 Mdot
.64268 .57216 Mdot
.42629 .48101 Mdot
.52418 .68879 Mdot
.43434 .42364 Mdot
.46516 .41526 Mdot
.47376 .44988 Mdot
.53893 .64684 Mdot
.83579 .42099 Mdot
.20094 .46366 Mdot
.81489 .41048 Mdot
.59639 .43653 Mdot
.66516 .56713 Mdot
.42451 .39353 Mdot
.63122 .37556 Mdot
.31183 .48095 Mdot
.46145 .43519 Mdot
.30179 .80014 Mdot
.44295 .42007 Mdot
.81185 .46 Mdot
.36783 .44664 Mdot
.76162 .338 Mdot
.55065 .30225 Mdot
.44728 .39407 Mdot
.43927 .62667 Mdot
.55127 .71875 Mdot
.64793 .48671 Mdot
.5237 .67905 Mdot
.63687 .56976 Mdot
.64807 .52654 Mdot
.5212 .59822 Mdot
.43781 .33253 Mdot
.42627 .48731 Mdot
.3955 .44787 Mdot
.66306 .58246 Mdot
.38678 .59106 Mdot
.64211 .35532 Mdot
.31571 .57115 Mdot
.8654 .55192 Mdot
.74336 .61154 Mdot
.53227 .62836 Mdot
.6416 .38114 Mdot
.64345 .50854 Mdot
.6731 .51957 Mdot
.61274 .35169 Mdot
.41008 .43214 Mdot
.32258 .60042 Mdot
.58428 .19095 Mdot
.45007 .7885 Mdot
.48972 .1505 Mdot
.34828 .56506 Mdot
.4525 .70525 Mdot
.5109 .68374 Mdot
.6361 .5436 Mdot
.43677 .40764 Mdot
.41185 .42384 Mdot
.29368 .57761 Mdot
.40669 .45227 Mdot
.30417 .65769 Mdot
.44007 .39935 Mdot
.61466 .63455 Mdot
.6441 .39126 Mdot
.52558 .59739 Mdot
.56954 .25637 Mdot
.3746 .57985 Mdot
.36805 .26877 Mdot
.68327 .53896 Mdot
.30738 .47252 Mdot
.53925 .69573 Mdot
.63898 .36944 Mdot
.67686 .54021 Mdot
.63448 .35024 Mdot
.41151 .36238 Mdot
.62541 .56208 Mdot
.59814 .3554 Mdot
.47437 .31807 Mdot
.47677 .45547 Mdot
.32839 .7477 Mdot
.50308 .65111 Mdot
.31551 .56754 Mdot
.44555 .46444 Mdot
.67988 .56024 Mdot
.50547 .43879 Mdot
.65014 .73106 Mdot
.63077 .6241 Mdot
.63689 .49979 Mdot
.60291 .59862 Mdot
.63198 .38494 Mdot
.69136 .67148 Mdot
.43746 .68533 Mdot
.30481 .58869 Mdot
.38673 .39495 Mdot
.74686 .31399 Mdot
.51455 .658 Mdot
.45539 .4543 Mdot
.70697 .34245 Mdot
.52199 .64796 Mdot
.42673 .4218 Mdot
.51134 .69569 Mdot
.36694 .5996 Mdot
.25174 .36255 Mdot
.31435 .58117 Mdot
.39369 .43988 Mdot
.54642 .67171 Mdot
.6901 .55221 Mdot
.36091 .59022 Mdot
.41182 .44072 Mdot
.43074 .38393 Mdot
.56857 .54938 Mdot
.45406 .41633 Mdot
.82809 .43891 Mdot
.44364 .39616 Mdot
.63541 .5327 Mdot
.47679 .38922 Mdot
.16505 .4576 Mdot
.50584 .60412 Mdot
.3161 .59798 Mdot
.65397 .49489 Mdot
.65795 .52325 Mdot
.74295 .54478 Mdot
.49401 .63614 Mdot
.42725 .36418 Mdot
.6749 .56307 Mdot
.42012 .27377 Mdot
.54839 .69879 Mdot
.4033 .47078 Mdot
.5175 .50134 Mdot
.68105 .40775 Mdot
.61251 .55228 Mdot
.51583 .43042 Mdot
.35655 .62311 Mdot
.46822 .40879 Mdot
.67503 .51779 Mdot
.47865 .34628 Mdot
.4278 .37034 Mdot
.27633 .66066 Mdot
.57144 .55909 Mdot
.55923 .67622 Mdot
.37201 .44827 Mdot
.44235 .4574 Mdot
.63344 .56447 Mdot
.37161 .5787 Mdot
.55013 .69926 Mdot
.35877 .60122 Mdot
.73264 .31663 Mdot
.34262 .75219 Mdot
.43187 .30295 Mdot
.65151 .36118 Mdot
.68674 .36603 Mdot
.74177 .31976 Mdot
.32734 .26659 Mdot
.41255 .24887 Mdot
.66177 .24443 Mdot
.68329 .52295 Mdot
.70535 .35583 Mdot
.65453 .52752 Mdot
.45602 .38186 Mdot
.66716 .54024 Mdot
.73838 .30453 Mdot
.44099 .40177 Mdot
.6616 .54715 Mdot
.34262 .28796 Mdot
.46523 .40695 Mdot
.3062 .59048 Mdot
.84802 .52273 Mdot
.22569 .3421 Mdot
.62014 .62228 Mdot
.62334 .5338 Mdot
.45464 .23233 Mdot
.44478 .41145 Mdot
.47432 .38674 Mdot
.35388 .57651 Mdot
.49046 .46287 Mdot
.60335 .39279 Mdot
.63198 .38986 Mdot
.50176 .7279 Mdot
.55399 .38113 Mdot
.36795 .43911 Mdot
.35904 .58727 Mdot
.35911 .35411 Mdot
.6797 .46307 Mdot
.69556 .39533 Mdot
.56917 .68585 Mdot
.84664 .52069 Mdot
.32178 .65108 Mdot
.58312 .64639 Mdot
.60397 .49244 Mdot
.32363 .58044 Mdot
.83108 .4016 Mdot
.52767 .67798 Mdot
.34308 .77001 Mdot
.42863 .55508 Mdot
.41269 .43199 Mdot
.55391 .68744 Mdot
.5103 .39035 Mdot
.2392 .325 Mdot
.42641 .81534 Mdot
.43614 .5147 Mdot
.41432 .46816 Mdot
.65768 .46 Mdot
.43487 .41712 Mdot
.71835 .68802 Mdot
.44162 .39128 Mdot
.35579 .59932 Mdot
.48211 .72745 Mdot
.48417 .6908 Mdot
.19321 .53468 Mdot
.69788 .68127 Mdot
.59802 .36612 Mdot
.43638 .40047 Mdot
.41392 .43438 Mdot
.59534 .38683 Mdot
.36384 .61153 Mdot
.39939 .44777 Mdot
.37101 .26078 Mdot
.3999 .41804 Mdot
.52852 .68617 Mdot
.41192 .56454 Mdot
.26539 .63018 Mdot
.39174 .41325 Mdot
.36974 .62109 Mdot
.5433 .63641 Mdot
.54373 .67012 Mdot
.36413 .43358 Mdot
.49921 .65071 Mdot
.44689 .42661 Mdot
.46061 .82762 Mdot
.33517 .62667 Mdot
.32491 .68248 Mdot
.33161 .61347 Mdot
.25891 .46776 Mdot
.53115 .6464 Mdot
.64008 .64463 Mdot
.47999 .35464 Mdot
.52847 .67361 Mdot
.28169 .58128 Mdot
.48878 .39703 Mdot
.49246 .44006 Mdot
.54271 .20046 Mdot
.6328 .52398 Mdot
.5723 .57079 Mdot
.50628 .68366 Mdot
.4218 .45198 Mdot
.3952 .38976 Mdot
.53716 .63271 Mdot
.45779 .8105 Mdot
.26451 .32114 Mdot
.44225 .39827 Mdot
.34751 .59517 Mdot
.33396 .59589 Mdot
.45176 .47055 Mdot
.47716 .41401 Mdot
.67062 .55083 Mdot
.69242 .53154 Mdot
.63261 .57359 Mdot
.57619 .57899 Mdot
.63613 .64156 Mdot
.78578 .54492 Mdot
.50473 .64539 Mdot
.44006 .72479 Mdot
.63671 .42116 Mdot
.38852 .44138 Mdot
.62559 .52131 Mdot
.44447 .45455 Mdot
.45473 .42894 Mdot
.50474 .62651 Mdot
.76993 .41541 Mdot
.28713 .63238 Mdot
.37876 .59505 Mdot
.55582 .70035 Mdot
.36011 .39558 Mdot
.56093 .63098 Mdot
.63406 .36373 Mdot
.58319 .21484 Mdot
.53389 .69548 Mdot
.30867 .58876 Mdot
.50374 .65749 Mdot
.40756 .42034 Mdot
.40038 .36246 Mdot
.32198 .58466 Mdot
.59171 .3927 Mdot
.49551 .45272 Mdot
.42702 .41801 Mdot
.23763 .66108 Mdot
.56836 .22639 Mdot
.60484 .64875 Mdot
.44673 .39609 Mdot
.39889 .39696 Mdot
.58435 .3638 Mdot
.40101 .41905 Mdot
.4242 .4651 Mdot
.22533 .41902 Mdot
.40072 .74808 Mdot
.63698 .38896 Mdot
.47133 .822 Mdot
.34495 .56529 Mdot
.77943 .34261 Mdot
.63139 .55153 Mdot
.47408 .70057 Mdot
.23497 .35467 Mdot
.61376 .55965 Mdot
.63575 .70724 Mdot
.79685 .36493 Mdot
.58343 .60574 Mdot
.70267 .5195 Mdot
.32484 .64135 Mdot
.39629 .44003 Mdot
.43127 .40971 Mdot
.62683 .38305 Mdot
.32889 .60348 Mdot
.55591 .54944 Mdot
.63346 .79701 Mdot
.43892 .42803 Mdot
.32363 .67118 Mdot
.5545 .79356 Mdot
.67889 .41509 Mdot
.61996 .36686 Mdot
.61449 .39883 Mdot
.43394 .40142 Mdot
.20369 .44398 Mdot
.36505 .58811 Mdot
.41288 .44184 Mdot
.39463 .37606 Mdot
.62712 .53059 Mdot
.30819 .61622 Mdot
.67123 .50684 Mdot
.66701 .65046 Mdot
.81474 .42415 Mdot
.27081 .73898 Mdot
.53946 .65491 Mdot
.68602 .73405 Mdot
.52446 .7029 Mdot
.56875 .31105 Mdot
.61695 .52002 Mdot
.47206 .41273 Mdot
.37372 .58265 Mdot
.42881 .45371 Mdot
.47585 .41106 Mdot
.41149 .43389 Mdot
.38976 .4107 Mdot
.21367 .68693 Mdot
.59991 .35848 Mdot
.46519 .35708 Mdot
.63899 .5281 Mdot
.76018 .65463 Mdot
.73024 .71068 Mdot
.4178 .43655 Mdot
.43373 .38929 Mdot
.33522 .62339 Mdot
.45659 .45841 Mdot
.5337 .70412 Mdot
.34439 .55727 Mdot
.40765 .40059 Mdot
.83578 .55485 Mdot
.41374 .38229 Mdot
.78782 .3675 Mdot
.50392 .66219 Mdot
.41103 .78055 Mdot
.43598 .34584 Mdot
.61146 .61599 Mdot
.57206 .57002 Mdot
.67474 .54521 Mdot
.49888 .68717 Mdot
.65189 .54593 Mdot
.60244 .81084 Mdot
.39116 .36566 Mdot
.45547 .40184 Mdot
.3825 .43158 Mdot
.66428 .56771 Mdot
.80679 .58331 Mdot
.7143 .65259 Mdot
.42814 .34285 Mdot
.65773 .56686 Mdot
.38224 .60855 Mdot
.52833 .21581 Mdot
.34326 .61318 Mdot
.63973 .34533 Mdot
.51613 .68589 Mdot
.59751 .39495 Mdot
.70151 .3207 Mdot
.30272 .6009 Mdot
.29729 .58207 Mdot
.63443 .55187 Mdot
.43893 .55726 Mdot
.24951 .26129 Mdot
.42972 .55845 Mdot
.5526 .28286 Mdot
.35382 .58139 Mdot
.40338 .3962 Mdot
.59874 .31359 Mdot
.43906 .58516 Mdot
.65442 .54396 Mdot
.45455 .43858 Mdot
.25228 .35757 Mdot
.67082 .55078 Mdot
.38096 .43218 Mdot
.63771 .52429 Mdot
.51825 .67922 Mdot
.6316 .51366 Mdot
.33578 .55058 Mdot
.4186 .39004 Mdot
.3029 .20735 Mdot
.66047 .3277 Mdot
.44734 .40791 Mdot
.55957 .69834 Mdot
.57808 .74522 Mdot
.46772 .43568 Mdot
.61539 .34608 Mdot
.65992 .55707 Mdot
.44201 .53319 Mdot
.44206 .3954 Mdot
.65406 .56899 Mdot
.29722 .5954 Mdot
.51598 .70589 Mdot
.30675 .33234 Mdot
.60094 .61706 Mdot
.35394 .57506 Mdot
.56843 .44466 Mdot
.49236 .66643 Mdot
.39789 .39849 Mdot
.38766 .3957 Mdot
.34394 .59673 Mdot
.4852 .31048 Mdot
.48284 .41524 Mdot
.46161 .37682 Mdot
.6295 .53752 Mdot
.65332 .54975 Mdot
.36133 .29597 Mdot
.68486 .51922 Mdot
.40259 .36116 Mdot
.34531 .59861 Mdot
.46668 .41816 Mdot
.32614 .62464 Mdot
.45817 .4568 Mdot
.41688 .32825 Mdot
.36537 .61009 Mdot
.54652 .61045 Mdot
.45588 .43392 Mdot
.44333 .48945 Mdot
.46445 .44646 Mdot
.39791 .43938 Mdot
.67185 .54163 Mdot
.62787 .36627 Mdot
.38044 .39865 Mdot
.57124 .37416 Mdot
.63662 .35308 Mdot
.49658 .70306 Mdot
.62863 .52754 Mdot
.60385 .38204 Mdot
.5657 .79734 Mdot
.62478 .56535 Mdot
.61483 .39038 Mdot
.73152 .70868 Mdot
.51336 .64639 Mdot
.34911 .62672 Mdot
.46532 .40354 Mdot
.70379 .30494 Mdot
.25133 .60689 Mdot
.68796 .51016 Mdot
.44481 .3991 Mdot
.45589 .45188 Mdot
.36962 .56554 Mdot
.62702 .81774 Mdot
.63594 .57803 Mdot
.41995 .37267 Mdot
.30867 .6019 Mdot
.61013 .84217 Mdot
.6415 .53162 Mdot
.62029 .38876 Mdot
.51488 .64124 Mdot
.27129 .6099 Mdot
.37888 .74008 Mdot
.55829 .66349 Mdot
.62428 .47954 Mdot
.67045 .64117 Mdot
.41611 .36685 Mdot
.6244 .51972 Mdot
.50148 .16548 Mdot
.34451 .41214 Mdot
.54633 .5874 Mdot
.46295 .22975 Mdot
.32918 .57875 Mdot
.52786 .70338 Mdot
.60009 .36183 Mdot
.35287 .56648 Mdot
.29962 .5989 Mdot
.527 .63006 Mdot
.21338 .45739 Mdot
.51198 .50456 Mdot
.53587 .68671 Mdot
.61795 .25309 Mdot
.77889 .5118 Mdot
.62385 .52371 Mdot
.60286 .39226 Mdot
.71237 .33253 Mdot
.35613 .60573 Mdot
.85407 .50265 Mdot
.54826 .19666 Mdot
.44285 .41185 Mdot
.60634 .37884 Mdot
.80249 .56407 Mdot
.68286 .7765 Mdot
.52679 .64777 Mdot
.49366 .7102 Mdot
.61384 .39474 Mdot
.44554 .46379 Mdot
.52363 .22452 Mdot
.46375 .38137 Mdot
.51252 .68219 Mdot
.3197 .33457 Mdot
.30131 .59767 Mdot
.52514 .63372 Mdot
.5784 .21086 Mdot
.44564 .42814 Mdot
.45727 .43439 Mdot
.59257 .26514 Mdot
.3643 .56899 Mdot
.67487 .54583 Mdot
.40697 .36842 Mdot
.43006 .41982 Mdot
.37611 .39692 Mdot
.37593 .45241 Mdot
.22847 .39843 Mdot
.44917 .38255 Mdot
.74341 .6326 Mdot
.41503 .46966 Mdot
.4471 .43876 Mdot
.36657 .62251 Mdot
.27263 .74827 Mdot
.68791 .64609 Mdot
.43315 .42166 Mdot
.4065 .38613 Mdot
.52139 .6345 Mdot
.4608 .54284 Mdot
.44576 .54634 Mdot
.44742 .52837 Mdot
.43395 .23912 Mdot
.46538 .4672 Mdot
.31831 .60316 Mdot
.59804 .35388 Mdot
.41898 .37003 Mdot
.31449 .60293 Mdot
.48171 .43841 Mdot
.67059 .5537 Mdot
.62596 .56628 Mdot
.34931 .39603 Mdot
.59952 .37909 Mdot
.37946 .64459 Mdot
.43456 .72288 Mdot
.63097 .56544 Mdot
.45642 .39904 Mdot
.49406 .62791 Mdot
.67497 .51893 Mdot
.61806 .60911 Mdot
.51388 .33988 Mdot
.36677 .58142 Mdot
.3385 .58187 Mdot
.52307 .31171 Mdot
.64388 .68641 Mdot
.20054 .59625 Mdot
.51736 .68012 Mdot
.4402 .35328 Mdot
.44022 .66536 Mdot
.33926 .57901 Mdot
.58921 .30902 Mdot
.60315 .37862 Mdot
.51962 .6482 Mdot
.67261 .47567 Mdot
.32881 .62098 Mdot
.2962 .61075 Mdot
.42829 .47346 Mdot
.42098 .42321 Mdot
.4042 .25359 Mdot
.57727 .35708 Mdot
.55825 .66061 Mdot
.60818 .39313 Mdot
.6175 .51965 Mdot
.44112 .37625 Mdot
.36765 .60544 Mdot
.77186 .52682 Mdot
.41371 .37306 Mdot
.67076 .52519 Mdot
.33084 .58104 Mdot
.63049 .38673 Mdot
.61096 .34562 Mdot
.39604 .43279 Mdot
.32967 .35129 Mdot
.53559 .67749 Mdot
.31908 .58065 Mdot
.56268 .62811 Mdot
.47615 .39299 Mdot
.4202 .41465 Mdot
.38026 .47521 Mdot
.55897 .66214 Mdot
.48751 .76491 Mdot
.64606 .35591 Mdot
.32651 .59915 Mdot
.44335 .3838 Mdot
.60278 .3891 Mdot
.45701 .72827 Mdot
.63264 .50148 Mdot
.63515 .5112 Mdot
.60331 .34778 Mdot
.61341 .37193 Mdot
.62687 .34728 Mdot
.85478 .50175 Mdot
.37274 .56262 Mdot
.31938 .65022 Mdot
.47227 .37726 Mdot
.54856 .29561 Mdot
.49147 .37204 Mdot
.55537 .69572 Mdot
.63602 .52128 Mdot
.47331 .42801 Mdot
.39357 .41769 Mdot
.3607 .42812 Mdot
.31054 .67568 Mdot
.26657 .61587 Mdot
.30267 .61117 Mdot
.41131 .35362 Mdot
.62428 .53928 Mdot
.87165 .549 Mdot
.60169 .182 Mdot
.43247 .34604 Mdot
.51163 .50071 Mdot
.37213 .60153 Mdot
.50937 .6394 Mdot
.63272 .28574 Mdot
.51075 .64639 Mdot
.32607 .59598 Mdot
.44715 .38041 Mdot
.44201 .73679 Mdot
.58584 .35799 Mdot
.41372 .45045 Mdot
.50836 .67594 Mdot
.41581 .45634 Mdot
.55726 .65975 Mdot
.73914 .32848 Mdot
.46058 .19395 Mdot
.44263 .41879 Mdot
.48845 .37621 Mdot
.43442 .2249 Mdot
.42004 .4412 Mdot
.62283 .33383 Mdot
.37231 .60169 Mdot
.32497 .31523 Mdot
.49552 .41896 Mdot
.33297 .41008 Mdot
.47176 .38639 Mdot
.313 .30879 Mdot
.41761 .41682 Mdot
.67125 .42385 Mdot
.42129 .38242 Mdot
.41447 .4624 Mdot
.54488 .6625 Mdot
.52541 .63433 Mdot
.33481 .63386 Mdot
.68425 .55444 Mdot
.80193 .38713 Mdot
.42471 .41599 Mdot
.64431 .62399 Mdot
.43824 .76132 Mdot
.61507 .37004 Mdot
.33042 .59974 Mdot
.67149 .80193 Mdot
.50387 .68328 Mdot
.5158 .19239 Mdot
.37181 .28808 Mdot
.37814 .70359 Mdot
.66315 .31917 Mdot
.5696 .76635 Mdot
.63861 .37777 Mdot
.47473 .4479 Mdot
.77537 .46834 Mdot
.66108 .43454 Mdot
.50109 .33078 Mdot
.49124 .67167 Mdot
.3179 .4553 Mdot
.77598 .43463 Mdot
.61978 .34063 Mdot
.6158 .39653 Mdot
.54815 .65333 Mdot
.70931 .54573 Mdot
.43068 .33451 Mdot
.60431 .37419 Mdot
.65121 .57415 Mdot
.61957 .55893 Mdot
.62206 .57121 Mdot
.3675 .59163 Mdot
.56449 .18791 Mdot
.54361 .62674 Mdot
.55855 .67876 Mdot
.67213 .58975 Mdot
.37696 .51768 Mdot
.35491 .55215 Mdot
.64016 .54757 Mdot
.65604 .50494 Mdot
.36974 .60866 Mdot
.36792 .42038 Mdot
.37596 .3751 Mdot
.43671 .42467 Mdot
.63048 .37226 Mdot
.41596 .42238 Mdot
.66026 .56406 Mdot
.53061 .65117 Mdot
.65079 .50623 Mdot
.55697 .70391 Mdot
.7789 .56624 Mdot
.40596 .43791 Mdot
.42113 .38639 Mdot
.25956 .69131 Mdot
.29305 .61417 Mdot
.76282 .61045 Mdot
.59654 .62772 Mdot
.65207 .5272 Mdot
.42785 .46518 Mdot
.3417 .55731 Mdot
.57729 .36107 Mdot
.29193 .74664 Mdot
.47914 .41577 Mdot
.35437 .61283 Mdot
.43929 .37782 Mdot
.36379 .33321 Mdot
.16112 .49378 Mdot
.35013 .6043 Mdot
.24532 .65148 Mdot
.40862 .38612 Mdot
.6042 .77632 Mdot
.40305 .46915 Mdot
.45801 .28269 Mdot
.48281 .41496 Mdot
.34611 .56477 Mdot
.4339 .42704 Mdot
.33344 .56047 Mdot
.62951 .56062 Mdot
.51238 .63899 Mdot
.34966 .57652 Mdot
.38701 .40591 Mdot
.3363 .14014 Mdot
.51296 .67308 Mdot
.43627 .40422 Mdot
.5333 .64488 Mdot
.32962 .60672 Mdot
.33859 .57072 Mdot
.68201 .76835 Mdot
.66797 .65278 Mdot
.51894 .67786 Mdot
.44039 .37665 Mdot
.64509 .74687 Mdot
.46852 .3974 Mdot
.44007 .26128 Mdot
.37106 .42011 Mdot
.47617 .38608 Mdot
.7342 .71294 Mdot
.55968 .67773 Mdot
.19305 .58561 Mdot
.71556 .74568 Mdot
.75863 .65909 Mdot
.28651 .58909 Mdot
.61102 .34123 Mdot
.83412 .40947 Mdot
.63547 .64319 Mdot
.65793 .56791 Mdot
.4694 .43721 Mdot
.36841 .54179 Mdot
.53936 .67778 Mdot
.62863 .36073 Mdot
.44208 .4177 Mdot
.64496 .50427 Mdot
.29838 .291 Mdot
.5349 .70846 Mdot
.34873 .60836 Mdot
.38194 .58385 Mdot
.47106 .84696 Mdot
.44614 .3915 Mdot
.4153 .39217 Mdot
.51495 .68543 Mdot
.53023 .78263 Mdot
.64273 .3648 Mdot
.34307 .28436 Mdot
.5191 .67593 Mdot
.52919 .5455 Mdot
.31066 .59652 Mdot
.4529 .45348 Mdot
.82868 .52403 Mdot
.7142 .50525 Mdot
.26873 .68571 Mdot
.63053 .37616 Mdot
.4458 .25898 Mdot
.34337 .5652 Mdot
.51922 .65687 Mdot
.61453 .70361 Mdot
.4587 .47385 Mdot
.44307 .45314 Mdot
.45538 .26293 Mdot
.48666 .69312 Mdot
.4273 .52087 Mdot
.47906 .40717 Mdot
.57345 .57972 Mdot
.47709 .43001 Mdot
.49475 .44397 Mdot
.37465 .39039 Mdot
.41822 .40561 Mdot
.36319 .60841 Mdot
.38647 .505 Mdot
.67537 .55659 Mdot
.36494 .64285 Mdot
.5266 .55406 Mdot
.44475 .40418 Mdot
.45114 .37194 Mdot
.31179 .53993 Mdot
.62388 .72842 Mdot
.34704 .57867 Mdot
.30141 .57352 Mdot
.49727 .65956 Mdot
.36765 .39248 Mdot
.68597 .54536 Mdot
.50556 .42247 Mdot
.6716 .53373 Mdot
.36659 .6052 Mdot
.64807 .52872 Mdot
.52029 .63921 Mdot
.6194 .53602 Mdot
.63703 .64139 Mdot
.50993 .66114 Mdot
.36318 .57784 Mdot
.40851 .40493 Mdot
.55853 .69952 Mdot
.54615 .25037 Mdot
.62987 .37423 Mdot
.75859 .71951 Mdot
.40785 .39939 Mdot
.39347 .74837 Mdot
.49174 .34898 Mdot
.65439 .50555 Mdot
.16284 .50572 Mdot
.3776 .59683 Mdot
.62154 .39894 Mdot
.37485 .57692 Mdot
.55507 .21371 Mdot
.62095 .37497 Mdot
.76158 .69104 Mdot
.58037 .51261 Mdot
.55971 .2248 Mdot
.36463 .41434 Mdot
.58239 .24932 Mdot
.61175 .54465 Mdot
.5403 .67568 Mdot
.62257 .70506 Mdot
.42095 .46376 Mdot
.36454 .23047 Mdot
.38015 .60648 Mdot
.68249 .55569 Mdot
.52628 .65556 Mdot
.55075 .69987 Mdot
.44552 .36229 Mdot
.72082 .41443 Mdot
.43747 .4579 Mdot
.64733 .67297 Mdot
.43919 .24285 Mdot
.27755 .6456 Mdot
.43978 .39981 Mdot
.63258 .56382 Mdot
.43952 .37788 Mdot
.65302 .3669 Mdot
.54054 .17509 Mdot
.48634 .46331 Mdot
.59847 .64273 Mdot
.66186 .33161 Mdot
.31472 .58731 Mdot
.50524 .35173 Mdot
.61602 .64428 Mdot
.44743 .38946 Mdot
.15805 .63994 Mdot
.60932 .39063 Mdot
.77343 .46318 Mdot
.3953 .39566 Mdot
.42882 .36284 Mdot
.49588 .59491 Mdot
.36518 .72815 Mdot
.69774 .48502 Mdot
.4273 .44526 Mdot
.49261 .25659 Mdot
.55547 .66322 Mdot
.45677 .45586 Mdot
.43209 .4073 Mdot
.22291 .50109 Mdot
.54811 .70444 Mdot
.65368 .5203 Mdot
.61068 .55488 Mdot
.68424 .50809 Mdot
.65098 .37388 Mdot
.56048 .72252 Mdot
.57799 .29878 Mdot
.26074 .31055 Mdot
.59249 .39793 Mdot
.39522 .41949 Mdot
.62322 .32335 Mdot
.45125 .37866 Mdot
.61825 .35976 Mdot
.5456 .70569 Mdot
.3455 .57551 Mdot
.44765 .68471 Mdot
.62162 .56645 Mdot
.43237 .48568 Mdot
.64472 .36733 Mdot
.3642 .58116 Mdot
.65808 .30416 Mdot
.31556 .59118 Mdot
.52503 .67071 Mdot
.57363 .68494 Mdot
.62521 .35864 Mdot
.32913 .6105 Mdot
.58614 .64158 Mdot
.6608 .7898 Mdot
.3835 .37568 Mdot
.52654 .74915 Mdot
.32519 .57005 Mdot
.31255 .56448 Mdot
.3389 .56168 Mdot
.40694 .45096 Mdot
.51347 .4998 Mdot
.48949 .41951 Mdot
.55949 .67448 Mdot
.64129 .52208 Mdot
.40474 .23229 Mdot
.72404 .60371 Mdot
.54841 .44435 Mdot
.42935 .35158 Mdot
.44496 .43012 Mdot
.43397 .40179 Mdot
.49681 .42001 Mdot
.62275 .67073 Mdot
.43402 .45489 Mdot
.54604 .66375 Mdot
.6619 .55806 Mdot
.47522 .44782 Mdot
.62076 .58589 Mdot
.75371 .6547 Mdot
.58681 .39019 Mdot
.5382 .73183 Mdot
.609 .17139 Mdot
.36046 .57961 Mdot
.65339 .4954 Mdot
.64846 .56819 Mdot
.63481 .3584 Mdot
.53359 .68309 Mdot
.31581 .59404 Mdot
.42761 .26992 Mdot
.63405 .35183 Mdot
.43246 .42426 Mdot
.50375 .49715 Mdot
.39999 .21113 Mdot
.47359 .44742 Mdot
.46835 .42803 Mdot
.60618 .55741 Mdot
.76658 .44275 Mdot
.36996 .17677 Mdot
.59824 .29031 Mdot
.62739 .36249 Mdot
.58901 .37174 Mdot
.35592 .62079 Mdot
.4908 .40065 Mdot
.55953 .66825 Mdot
.41385 .54342 Mdot
.55971 .7362 Mdot
.40939 .61021 Mdot
.30425 .70756 Mdot
.47631 .42617 Mdot
.48474 .81191 Mdot
.44857 .42771 Mdot
.37194 .56244 Mdot
.36495 .60344 Mdot
.35374 .58979 Mdot
.53945 .67498 Mdot
.27975 .48793 Mdot
.54761 .67348 Mdot
.58891 .15417 Mdot
.33234 .57021 Mdot
.57721 .53073 Mdot
.63121 .54545 Mdot
.4184 .34576 Mdot
.62286 .39094 Mdot
.57296 .70041 Mdot
.36028 .45164 Mdot
.18647 .46748 Mdot
.67893 .5579 Mdot
.36118 .57593 Mdot
.55684 .76616 Mdot
.68452 .24538 Mdot
.44947 .53517 Mdot
.35619 .41269 Mdot
.63735 .28645 Mdot
.61507 .3666 Mdot
.26882 .68692 Mdot
.61221 .394 Mdot
.50752 .67456 Mdot
.42488 .38659 Mdot
.41597 .39902 Mdot
.47663 .43264 Mdot
.41162 .43842 Mdot
.49593 .65089 Mdot
.38536 .39527 Mdot
.16511 .45746 Mdot
.63117 .56999 Mdot
.46074 .31109 Mdot
.6181 .39122 Mdot
.49767 .68973 Mdot
.6615 .55937 Mdot
.62351 .72536 Mdot
.56739 .25956 Mdot
.44168 .39682 Mdot
.47253 .43093 Mdot
.50353 .1875 Mdot
.47875 .40506 Mdot
.4558 .34047 Mdot
.65587 .56865 Mdot
.54384 .42038 Mdot
.59007 .39276 Mdot
.5878 .37694 Mdot
.50914 .65848 Mdot
.36341 .60713 Mdot
.61228 .3876 Mdot
.62948 .54185 Mdot
.42643 .35207 Mdot
.39155 .38524 Mdot
.32667 .5695 Mdot
.51902 .17841 Mdot
.64282 .35221 Mdot
.63153 .75619 Mdot
.37208 .58345 Mdot
.30964 .63421 Mdot
.44404 .45282 Mdot
.28646 .68261 Mdot
.31238 .55912 Mdot
.61346 .40293 Mdot
.49729 .68798 Mdot
.61418 .27565 Mdot
.51898 .69529 Mdot
.34656 .61052 Mdot
.42651 .36986 Mdot
.37037 .59422 Mdot
.44565 .39472 Mdot
.72441 .26047 Mdot
.41494 .40519 Mdot
.24738 .32043 Mdot
.50652 .30125 Mdot
.6436 .55852 Mdot
.60594 .74499 Mdot
.63216 .55186 Mdot
.37013 .5769 Mdot
.41822 .3679 Mdot
.64012 .38159 Mdot
.73058 .69226 Mdot
.38299 .53702 Mdot
.6674 .51561 Mdot
.67546 .57352 Mdot
.51352 .69457 Mdot
.48274 .42124 Mdot
.44022 .45377 Mdot
.6597 .54825 Mdot
.27987 .6509 Mdot
.32671 .61809 Mdot
.43321 .38668 Mdot
.44429 .43517 Mdot
.64114 .55664 Mdot
.6436 .79934 Mdot
.36396 .49452 Mdot
.42399 .39276 Mdot
.73954 .57598 Mdot
.55612 .69288 Mdot
.40034 .35674 Mdot
.48624 .37083 Mdot
.61048 .3727 Mdot
.26561 .37745 Mdot
.58606 .20022 Mdot
.54127 .70706 Mdot
.64453 .57032 Mdot
.44472 .38772 Mdot
.63367 .565 Mdot
.38937 .3876 Mdot
.35969 .72045 Mdot
.62913 .50652 Mdot
.46118 .3751 Mdot
.36997 .434 Mdot
.36398 .56826 Mdot
.47491 .42767 Mdot
.29713 .54093 Mdot
.67834 .53026 Mdot
.44027 .36255 Mdot
.32643 .35018 Mdot
.53532 .69053 Mdot
.36346 .41658 Mdot
.61412 .35038 Mdot
.4219 .27007 Mdot
.41509 .72148 Mdot
.75851 .39346 Mdot
.5865 .37386 Mdot
.4185 .45671 Mdot
.67734 .56941 Mdot
.55341 .65355 Mdot
.22433 .34678 Mdot
.44622 .46228 Mdot
.51158 .68017 Mdot
.52872 .65077 Mdot
.63382 .36472 Mdot
.28954 .76078 Mdot
.39201 .40613 Mdot
.41744 .43441 Mdot
.24669 .53015 Mdot
.29342 .60333 Mdot
.41235 .41504 Mdot
.39911 .40838 Mdot
.54616 .66165 Mdot
.39022 .34838 Mdot
.3304 .48299 Mdot
.3285 .29482 Mdot
.55198 .64394 Mdot
.42846 .60967 Mdot
.61615 .53735 Mdot
.59628 .38375 Mdot
.32502 .58622 Mdot
.64417 .37214 Mdot
.62737 .52359 Mdot
.40078 .4082 Mdot
.50017 .66139 Mdot
.26407 .55833 Mdot
.54738 .65237 Mdot
.73428 .36902 Mdot
.30881 .58139 Mdot
.44947 .64317 Mdot
.18935 .68002 Mdot
.6918 .69818 Mdot
.48847 .62718 Mdot
.61497 .37045 Mdot
.7198 .54917 Mdot
.44529 .43356 Mdot
.26802 .69087 Mdot
.39684 .42243 Mdot
.32323 .3479 Mdot
.63925 .57295 Mdot
.63335 .5741 Mdot
.42513 .38898 Mdot
.43506 .2474 Mdot
.55235 .65168 Mdot
.55012 .69681 Mdot
.45868 .3707 Mdot
.52799 .67398 Mdot
.42192 .42771 Mdot
.66779 .55557 Mdot
.19088 .6052 Mdot
.4384 .42004 Mdot
.49936 .42087 Mdot
.37065 .71977 Mdot
.73251 .72218 Mdot
.69212 .35419 Mdot
.53146 .84011 Mdot
.66108 .22579 Mdot
.52899 .67269 Mdot
.48583 .3968 Mdot
.42651 .61205 Mdot
.61107 .566 Mdot
.58463 .65051 Mdot
.40439 .41414 Mdot
.39984 .42122 Mdot
.41451 .46353 Mdot
.46054 .43091 Mdot
.30391 .74126 Mdot
.39798 .54035 Mdot
.26695 .42031 Mdot
.47615 .41575 Mdot
.56309 .24334 Mdot
.5053 .66458 Mdot
.27401 .60568 Mdot
.59356 .40095 Mdot
.47582 .42723 Mdot
.37627 .63008 Mdot
.51047 .63574 Mdot
.58267 .14892 Mdot
.50586 .67521 Mdot
.6583 .52399 Mdot
.52832 .63808 Mdot
.45351 .41503 Mdot
.33447 .59577 Mdot
.47018 .576 Mdot
.69322 .66665 Mdot
.65998 .56746 Mdot
.44715 .40742 Mdot
.58092 .5706 Mdot
.67533 .55874 Mdot
.76442 .64416 Mdot
.33145 .58977 Mdot
.49742 .25909 Mdot
.36918 .59863 Mdot
.45072 .36655 Mdot
.44696 .36616 Mdot
.53944 .62844 Mdot
.522 .63774 Mdot
.3683 .60053 Mdot
.30853 .78649 Mdot
.63333 .34833 Mdot
.35586 .59268 Mdot
.45405 .47805 Mdot
.49927 .52557 Mdot
.33917 .59425 Mdot
.66165 .36221 Mdot
.53694 .65416 Mdot
.32152 .62986 Mdot
.41064 .4682 Mdot
.61556 .24649 Mdot
.5957 .35415 Mdot
.61033 .53134 Mdot
.61811 .3092 Mdot
.6776 .52422 Mdot
.49795 .68641 Mdot
.63312 .5536 Mdot
.5554 .66679 Mdot
.42267 .74254 Mdot
.35051 .65085 Mdot
.47922 .63746 Mdot
.49461 .67248 Mdot
.63495 .55181 Mdot
.42953 .38198 Mdot
.66266 .32855 Mdot
.46929 .36913 Mdot
.38558 .42628 Mdot
.55555 .68024 Mdot
.35315 .56729 Mdot
.30386 .56669 Mdot
.53129 .22739 Mdot
.35391 .61589 Mdot
.66981 .52285 Mdot
.18248 .44715 Mdot
.66739 .61833 Mdot
.52877 .69694 Mdot
.51696 .63649 Mdot
.46427 .38364 Mdot
.65257 .54534 Mdot
.65276 .57208 Mdot
.51296 .69255 Mdot
.34383 .67876 Mdot
.49106 .38578 Mdot
.32769 .5556 Mdot
.29429 .60866 Mdot
.34845 .6019 Mdot
.33502 .56208 Mdot
.34724 .48789 Mdot
.51877 .64611 Mdot
.35813 .56869 Mdot
.46808 .3862 Mdot
.40166 .41835 Mdot
.42963 .56772 Mdot
.59291 .3664 Mdot
.47476 .45048 Mdot
.37255 .39452 Mdot
.45305 .45224 Mdot
.63245 .51127 Mdot
.50341 .46316 Mdot
.63658 .50282 Mdot
.66705 .57361 Mdot
.65919 .57434 Mdot
.63477 .64233 Mdot
.49072 .20379 Mdot
.68277 .2661 Mdot
.41801 .37321 Mdot
.53185 .79599 Mdot
.64494 .53835 Mdot
.17532 .48277 Mdot
.49131 .76627 Mdot
.43436 .46404 Mdot
.71284 .49486 Mdot
.65624 .55153 Mdot
.37354 .60351 Mdot
.40796 .4104 Mdot
.67769 .50604 Mdot
.61117 .34981 Mdot
.4544 .36305 Mdot
.62824 .50593 Mdot
.32666 .60844 Mdot
.62117 .40271 Mdot
.30238 .62348 Mdot
.6558 .57548 Mdot
.36658 .43766 Mdot
.1657 .35906 Mdot
.69048 .56064 Mdot
.60723 .79021 Mdot
.41213 .32466 Mdot
.43172 .38459 Mdot
.66274 .50156 Mdot
.29328 .62362 Mdot
.5014 .69072 Mdot
.56828 .49439 Mdot
.31665 .62534 Mdot
.6329 .574 Mdot
.6683 .51273 Mdot
.65887 .56815 Mdot
.30059 .61007 Mdot
.46385 .46531 Mdot
.31766 .62247 Mdot
.53381 .64022 Mdot
.4674 .40383 Mdot
.74302 .32209 Mdot
.51677 .79001 Mdot
.37337 .58955 Mdot
.65107 .51617 Mdot
.58498 .3613 Mdot
.44638 .42256 Mdot
.51667 .79443 Mdot
.43361 .38023 Mdot
.55751 .67817 Mdot
.23284 .40877 Mdot
.26743 .57345 Mdot
.47719 .38615 Mdot
.46544 .38628 Mdot
.55014 .6954 Mdot
.44346 .41037 Mdot
.48286 .41654 Mdot
.63651 .64639 Mdot
.30863 .6144 Mdot
.43619 .42994 Mdot
.63465 .52862 Mdot
.67598 .63317 Mdot
.49559 .39648 Mdot
.70371 .59273 Mdot
.48383 .26385 Mdot
.22646 .4261 Mdot
.39695 .4211 Mdot
.48669 .50084 Mdot
.45395 .44058 Mdot
.41104 .44663 Mdot
.4579 .38279 Mdot
.36206 .78802 Mdot
.62536 .51081 Mdot
.64728 .56561 Mdot
.58973 .36425 Mdot
.48651 .26331 Mdot
.60698 .37638 Mdot
.53562 .65174 Mdot
.73542 .43138 Mdot
.63522 .50322 Mdot
.33813 .61258 Mdot
.41915 .45353 Mdot
.69047 .56013 Mdot
.44911 .45488 Mdot
.45399 .4128 Mdot
.68664 .53737 Mdot
.61621 .53173 Mdot
.77294 .43651 Mdot
.59633 .35772 Mdot
.35149 .5856 Mdot
.48573 .42338 Mdot
.64397 .35931 Mdot
.39408 .41293 Mdot
.54986 .29741 Mdot
.35039 .58881 Mdot
.31168 .61727 Mdot
.30861 .56276 Mdot
.40278 .40504 Mdot
.4499 .41732 Mdot
.5485 .67448 Mdot
.37611 .58562 Mdot
.53161 .69018 Mdot
.55996 .5396 Mdot
.7452 .52688 Mdot
.40419 .41437 Mdot
.50354 .7449 Mdot
.59862 .37015 Mdot
.66152 .51326 Mdot
.41104 .21213 Mdot
.58991 .36329 Mdot
.44369 .39272 Mdot
.67793 .56327 Mdot
.61284 .35832 Mdot
.40656 .29433 Mdot
.56045 .16238 Mdot
.58178 .37189 Mdot
.46857 .38682 Mdot
.37413 .36466 Mdot
.51925 .84138 Mdot
.58397 .37607 Mdot
.51163 .64326 Mdot
.4038 .40374 Mdot
.37819 .55359 Mdot
.64504 .37171 Mdot
.7371 .63934 Mdot
.65882 .5562 Mdot
.60862 .23283 Mdot
.38565 .49021 Mdot
.25115 .63771 Mdot
.59096 .37758 Mdot
.32026 .59491 Mdot
.4799 .34774 Mdot
.44706 .45006 Mdot
.5854 .37163 Mdot
.49791 .62941 Mdot
.66796 .54311 Mdot
.68153 .64739 Mdot
.30007 .61023 Mdot
.51846 .61521 Mdot
.64527 .51437 Mdot
.64105 .75182 Mdot
.28659 .32557 Mdot
.38093 .36941 Mdot
.49884 .83344 Mdot
.57876 .7162 Mdot
.43051 .47201 Mdot
.57658 .36853 Mdot
.555 .70388 Mdot
.49856 .6621 Mdot
.5214 .67112 Mdot
.43312 .75524 Mdot
.44977 .52761 Mdot
.64741 .4932 Mdot
.5678 .64802 Mdot
.59691 .383 Mdot
.60416 .2684 Mdot
.38367 .41882 Mdot
.44323 .42905 Mdot
.48431 .40541 Mdot
.47396 .43483 Mdot
.44558 .44428 Mdot
.52835 .68253 Mdot
.40859 .74069 Mdot
.43786 .54333 Mdot
.3454 .59249 Mdot
.75476 .42352 Mdot
.63326 .54188 Mdot
.64116 .49182 Mdot
.6117 .35487 Mdot
.70787 .69443 Mdot
.62059 .58632 Mdot
.64921 .52727 Mdot
.44998 .46689 Mdot
.32622 .62084 Mdot
.43842 .3406 Mdot
.46683 .38644 Mdot
.6699 .52606 Mdot
.51983 .58074 Mdot
.33463 .51271 Mdot
.54114 .3701 Mdot
.5815 .40225 Mdot
.4805 .52195 Mdot
.58971 .3579 Mdot
.41085 .36992 Mdot
.16593 .50462 Mdot
.62725 .52283 Mdot
.65904 .5338 Mdot
.59456 .37053 Mdot
.27841 .67911 Mdot
.32652 .58078 Mdot
.48795 .72629 Mdot
.54084 .65 Mdot
.43356 .36727 Mdot
.31655 .2805 Mdot
.46751 .32217 Mdot
.71258 .41734 Mdot
.51682 .67431 Mdot
.62979 .55975 Mdot
.44764 .35495 Mdot
.47147 .39577 Mdot
.60009 .36666 Mdot
.79682 .45486 Mdot
.39723 .36219 Mdot
.80759 .61097 Mdot
.4609 .19342 Mdot
.55719 .20541 Mdot
.4425 .45311 Mdot
.3066 .6143 Mdot
.608 .54176 Mdot
.60082 .39151 Mdot
.44308 .48216 Mdot
.60307 .19189 Mdot
.32331 .57297 Mdot
.51233 .66251 Mdot
.50341 .56703 Mdot
.61238 .28169 Mdot
.39525 .43878 Mdot
.39946 .41645 Mdot
.40482 .44368 Mdot
.49019 .13943 Mdot
.63211 .50805 Mdot
.37408 .59698 Mdot
.63194 .36185 Mdot
.34843 .6165 Mdot
.63938 .5609 Mdot
.49097 .61516 Mdot
.4258 .37995 Mdot
.31812 .57593 Mdot
.32049 .59344 Mdot
.50696 .68157 Mdot
.51169 .70285 Mdot
.53283 .55672 Mdot
.41544 .40654 Mdot
.68346 .56911 Mdot
.36078 .5682 Mdot
.49637 .50192 Mdot
.61894 .3757 Mdot
.54055 .65585 Mdot
.47547 .42193 Mdot
.62478 .51674 Mdot
.38183 .44127 Mdot
.34127 .58086 Mdot
.64913 .528 Mdot
.76888 .52773 Mdot
.58558 .38569 Mdot
.40629 .42553 Mdot
.65063 .33655 Mdot
.64796 .57077 Mdot
.44722 .43434 Mdot
.65641 .75391 Mdot
.66131 .36166 Mdot
.71896 .64619 Mdot
.66626 .57058 Mdot
.61999 .62035 Mdot
.34923 .62392 Mdot
.44483 .77312 Mdot
.66012 .52913 Mdot
.60844 .76414 Mdot
.7862 .51027 Mdot
.43639 .35107 Mdot
.35716 .60409 Mdot
.58412 .7046 Mdot
.7732 .32931 Mdot
.59782 .80732 Mdot
.43526 .4048 Mdot
.68433 .51878 Mdot
.60531 .3624 Mdot
.53395 .69788 Mdot
.73225 .56896 Mdot
.63299 .40192 Mdot
.64459 .58127 Mdot
.45718 .3828 Mdot
.32339 .60162 Mdot
.54008 .66251 Mdot
.41887 .72706 Mdot
.6302 .53734 Mdot
.64198 .51979 Mdot
.45481 .35845 Mdot
.60237 .37872 Mdot
.48298 .79193 Mdot
.6665 .55993 Mdot
.48028 .19263 Mdot
.69702 .50966 Mdot
.63931 .35337 Mdot
.46121 .43679 Mdot
.53181 .22288 Mdot
.49374 .41435 Mdot
.6809 .75379 Mdot
.63456 .54577 Mdot
.34502 .5843 Mdot
.4079 .4549 Mdot
.3518 .29081 Mdot
.66789 .52126 Mdot
.50297 .50618 Mdot
.67661 .40637 Mdot
.52765 .64664 Mdot
.40676 .21358 Mdot
.41338 .42303 Mdot
.55275 .65291 Mdot
.60136 .36793 Mdot
.42111 .39854 Mdot
.45208 .41876 Mdot
.36635 .56422 Mdot
.50961 .68575 Mdot
.78361 .45434 Mdot
.52117 .63358 Mdot
.50343 .65956 Mdot
.34959 .55515 Mdot
.42882 .43682 Mdot
.65719 .52257 Mdot
.65671 .54974 Mdot
.40349 .46712 Mdot
.16937 .58803 Mdot
.32292 .58073 Mdot
.60588 .5457 Mdot
.47457 .13905 Mdot
.39084 .46416 Mdot
.3911 .22451 Mdot
.79904 .46454 Mdot
.5611 .6765 Mdot
.46992 .38767 Mdot
.3291 .60831 Mdot
.64422 .46047 Mdot
.64555 .51896 Mdot
.40888 .46318 Mdot
.53809 .66232 Mdot
.60324 .35124 Mdot
.67901 .54383 Mdot
.72033 .41639 Mdot
.40824 .43915 Mdot
.70385 .48412 Mdot
.67872 .5153 Mdot
.83848 .42851 Mdot
.61517 .72558 Mdot
.35961 .60069 Mdot
.45667 .41271 Mdot
.3767 .59961 Mdot
.63012 .35856 Mdot
.50737 .5652 Mdot
.53525 .6558 Mdot
.39961 .51544 Mdot
.15783 .44922 Mdot
.65763 .56889 Mdot
.37531 .59591 Mdot
.47413 .38078 Mdot
.35133 .71622 Mdot
.41738 .4277 Mdot
.36486 .37431 Mdot
.62325 .31957 Mdot
.54984 .68981 Mdot
.55311 .65972 Mdot
.45601 .4291 Mdot
.63883 .36104 Mdot
.6308 .54141 Mdot
.66889 .5335 Mdot
.8603 .5451 Mdot
.4471 .627 Mdot
.40157 .25677 Mdot
.40059 .42304 Mdot
.65189 .58138 Mdot
.70802 .61412 Mdot
.51499 .68475 Mdot
.41157 .47631 Mdot
.68541 .54703 Mdot
.66709 .36899 Mdot
.42501 .2792 Mdot
.44995 .44578 Mdot
.4919 .44388 Mdot
.53491 .64532 Mdot
.44889 .51895 Mdot
.62555 .56206 Mdot
.37443 .42038 Mdot
.4702 .64898 Mdot
.41995 .28772 Mdot
.50581 .16538 Mdot
.35185 .58563 Mdot
.7106 .39757 Mdot
.52902 .68304 Mdot
.4994 .42994 Mdot
.6362 .37921 Mdot
.60836 .56432 Mdot
.62557 .51326 Mdot
.45095 .3871 Mdot
.41622 .36182 Mdot
.43255 .21846 Mdot
.33666 .61723 Mdot
.50646 .66142 Mdot
.41388 .39552 Mdot
.4607 .70754 Mdot
.47789 .42896 Mdot
.54744 .68112 Mdot
.151 .37588 Mdot
.47264 .37464 Mdot
.41837 .43218 Mdot
.49898 .78912 Mdot
.30485 .62083 Mdot
.37915 .58658 Mdot
.33727 .25043 Mdot
.40092 .4232 Mdot
.43895 .20478 Mdot
.35142 .58112 Mdot
.33134 .57866 Mdot
.64709 .65574 Mdot
.44413 .42406 Mdot
.4244 .50087 Mdot
.55877 .67322 Mdot
.50367 .65511 Mdot
.30934 .61951 Mdot
.40008 .35781 Mdot
.52851 .70615 Mdot
.38417 .78586 Mdot
.65085 .54574 Mdot
.16483 .52673 Mdot
.32249 .57853 Mdot
.50801 .71985 Mdot
.51496 .68022 Mdot
.59647 .16118 Mdot
.61564 .48003 Mdot
.42654 .38232 Mdot
.40372 .42903 Mdot
.59561 .37598 Mdot
.48608 .40569 Mdot
.63418 .57423 Mdot
.52749 .6745 Mdot
.34894 .32592 Mdot
.3544 .58984 Mdot
.41797 .41452 Mdot
.73025 .67871 Mdot
.7742 .60845 Mdot
.71281 .38303 Mdot
.31594 .58706 Mdot
.36644 .59483 Mdot
.62318 .54691 Mdot
.68451 .51998 Mdot
.43443 .4459 Mdot
.54105 .70117 Mdot
.37574 .58631 Mdot
.55078 .6824 Mdot
.62849 .52135 Mdot
.65429 .52376 Mdot
.6168 .52475 Mdot
.38343 .41059 Mdot
.64311 .52612 Mdot
.75695 .53437 Mdot
.53138 .61873 Mdot
.35408 .55264 Mdot
.41714 .18651 Mdot
.42602 .73082 Mdot
.31415 .55285 Mdot
.64737 .36729 Mdot
.65234 .57082 Mdot
.53801 .64086 Mdot
.46793 .41711 Mdot
.46488 .44462 Mdot
.63307 .61552 Mdot
.54311 .64001 Mdot
.62895 .35954 Mdot
.55103 .65347 Mdot
.63389 .36429 Mdot
.66863 .44669 Mdot
.48071 .43115 Mdot
.3926 .38104 Mdot
.52455 .68041 Mdot
.64556 .52713 Mdot
.65345 .56242 Mdot
.58097 .37865 Mdot
.54502 .58602 Mdot
.67657 .55795 Mdot
.33468 .57507 Mdot
.35503 .50399 Mdot
.66577 .50959 Mdot
.4093 .41181 Mdot
.57756 .30266 Mdot
.2646 .6926 Mdot
.4968 .42058 Mdot
.64251 .65216 Mdot
.24564 .57799 Mdot
.42279 .46148 Mdot
.25385 .68544 Mdot
.59949 .61978 Mdot
.34523 .62371 Mdot
.63416 .57009 Mdot
.64247 .59736 Mdot
.50684 .4461 Mdot
.5953 .40525 Mdot
.42571 .48026 Mdot
.314 .58261 Mdot
.38288 .60504 Mdot
.57149 .22123 Mdot
.63212 .78308 Mdot
.60946 .36085 Mdot
.6058 .3582 Mdot
.66203 .52858 Mdot
.75398 .73062 Mdot
.35831 .41786 Mdot
.62749 .36037 Mdot
.34627 .65673 Mdot
.45559 .38414 Mdot
.47648 .27937 Mdot
.5777 .43145 Mdot
.30552 .61615 Mdot
.56081 .23791 Mdot
.66184 .51999 Mdot
.3534 .61694 Mdot
.44849 .69372 Mdot
.4755 .45267 Mdot
.35115 .58988 Mdot
.55064 .67848 Mdot
.64358 .70916 Mdot
.34235 .57034 Mdot
.56554 .29931 Mdot
.52206 .70061 Mdot
.49412 .50505 Mdot
.51297 .23571 Mdot
.44421 .89526 Mdot
.5295 .67888 Mdot
.66655 .51233 Mdot
.65782 .54947 Mdot
.66835 .53234 Mdot
.34438 .61797 Mdot
.6513 .57204 Mdot
.33945 .61595 Mdot
.53321 .82163 Mdot
.29891 .70298 Mdot
.62631 .36135 Mdot
.68184 .64991 Mdot
.33545 .60578 Mdot
.17113 .47786 Mdot
.14437 .58233 Mdot
.46952 .3861 Mdot
.50424 .64068 Mdot
.62212 .36121 Mdot
.80081 .6226 Mdot
.61034 .36966 Mdot
.52654 .20398 Mdot
.20228 .45365 Mdot
.42243 .42057 Mdot
.30615 .48466 Mdot
.60659 .398 Mdot
.30948 .59624 Mdot
.44753 .43266 Mdot
.59161 .46738 Mdot
.60582 .37077 Mdot
.62324 .34833 Mdot
.43572 .4394 Mdot
.36139 .57591 Mdot
.65689 .51547 Mdot
.50871 .64205 Mdot
.63912 .38553 Mdot
.42267 .33158 Mdot
.49223 .43547 Mdot
.43442 .3772 Mdot
.43536 .56543 Mdot
.5854 .34989 Mdot
.52977 .67237 Mdot
.32355 .77585 Mdot
.68439 .55912 Mdot
.59954 .46863 Mdot
.48804 .18322 Mdot
.62026 .64343 Mdot
.63644 .54631 Mdot
.63476 .56433 Mdot
.44389 .44625 Mdot
.55919 .40653 Mdot
.19243 .47117 Mdot
.56828 .59467 Mdot
.61565 .52247 Mdot
.66923 .53856 Mdot
.37767 .60488 Mdot
.55311 .20951 Mdot
.45076 .48082 Mdot
.54198 .70725 Mdot
.62241 .51738 Mdot
.34669 .73265 Mdot
.60035 .38128 Mdot
.20135 .43873 Mdot
.47977 .436 Mdot
.42258 .38531 Mdot
.52959 .65922 Mdot
.54704 .6718 Mdot
.63149 .45662 Mdot
.54336 .20669 Mdot
.25001 .58215 Mdot
.39686 .72187 Mdot
.22885 .43945 Mdot
.38182 .60121 Mdot
.37333 .58908 Mdot
.69987 .67501 Mdot
.51624 .63411 Mdot
.41662 .45979 Mdot
.36551 .6052 Mdot
.60025 .47463 Mdot
.36717 .51588 Mdot
.43686 .25836 Mdot
.40131 .22907 Mdot
.44615 .3977 Mdot
.31501 .61432 Mdot
.30125 .61793 Mdot
.2975 .58792 Mdot
.59276 .61325 Mdot
.42675 .44501 Mdot
.44123 .40094 Mdot
.43015 .45904 Mdot
.32536 .69545 Mdot
.41943 .44848 Mdot
.43435 .76846 Mdot
.51457 .55245 Mdot
.27888 .36193 Mdot
.37266 .41288 Mdot
.56358 .68037 Mdot
.39348 .42998 Mdot
.63789 .36068 Mdot
.456 .37653 Mdot
.43279 .26041 Mdot
.51037 .67241 Mdot
.3654 .49882 Mdot
.42692 .74082 Mdot
.42434 .46854 Mdot
.62278 .40027 Mdot
.55542 .74259 Mdot
.73432 .30665 Mdot
.64965 .32604 Mdot
.33228 .57552 Mdot
.64525 .54567 Mdot
.53949 .64097 Mdot
.6553 .52833 Mdot
.38248 .3956 Mdot
.69285 .68671 Mdot
.79751 .58334 Mdot
.56372 .54918 Mdot
.4734 .43439 Mdot
.39939 .48753 Mdot
.33762 .57719 Mdot
.68361 .55838 Mdot
.32416 .55048 Mdot
.40429 .44907 Mdot
.63116 .37238 Mdot
.60138 .37056 Mdot
.56904 .49776 Mdot
.81916 .45496 Mdot
.36028 .76054 Mdot
.53102 .66219 Mdot
.66986 .55404 Mdot
.61854 .39333 Mdot
.57948 .77888 Mdot
.51598 .70635 Mdot
.55507 .69087 Mdot
.5085 .66786 Mdot
.4059 .3922 Mdot
.62773 .50751 Mdot
.28289 .35831 Mdot
.64075 .57893 Mdot
.44583 .4105 Mdot
.63459 .50865 Mdot
.68266 .55376 Mdot
.61215 .39212 Mdot
.50652 .66578 Mdot
.62527 .53001 Mdot
.44613 .36492 Mdot
.35708 .57957 Mdot
.47923 .66829 Mdot
.49009 .30133 Mdot
.64419 .77537 Mdot
.39589 .31475 Mdot
.29656 .60144 Mdot
.77261 .33601 Mdot
.55817 .68833 Mdot
.33993 .68315 Mdot
.76919 .4299 Mdot
.41478 .37172 Mdot
.15352 .56097 Mdot
.63913 .49215 Mdot
.68438 .54317 Mdot
.46011 .43662 Mdot
.7101 .53395 Mdot
.41836 .41948 Mdot
.63631 .51615 Mdot
.71527 .59266 Mdot
.38801 .6108 Mdot
.64159 .53111 Mdot
.37603 .42241 Mdot
.45305 .42393 Mdot
.30934 .61732 Mdot
.66772 .50557 Mdot
.4342 .48546 Mdot
.86361 .52661 Mdot
.54528 .6771 Mdot
.5959 .66607 Mdot
.57712 .3125 Mdot
.5297 .68433 Mdot
.35534 .59522 Mdot
.38512 .42303 Mdot
.60162 .36653 Mdot
.33419 .6066 Mdot
.40111 .28028 Mdot
.58878 .38774 Mdot
.15451 .51221 Mdot
.29925 .61362 Mdot
.67249 .51852 Mdot
.63986 .37217 Mdot
.48858 .4082 Mdot
.60753 .56154 Mdot
.61632 .7379 Mdot
.63679 .54423 Mdot
.43798 .45357 Mdot
.71468 .63161 Mdot
.506 .65937 Mdot
.4328 .40325 Mdot
.6832 .54045 Mdot
.64443 .64687 Mdot
.40789 .38599 Mdot
.45437 .43524 Mdot
.50868 .17251 Mdot
.2108 .3875 Mdot
.61572 .37279 Mdot
.28939 .61051 Mdot
.46781 .38559 Mdot
.62158 .34956 Mdot
.72911 .47744 Mdot
.41178 .39 Mdot
.3253 .57116 Mdot
.38859 .46707 Mdot
.67251 .50851 Mdot
.5362 .68754 Mdot
.57635 .58149 Mdot
.61153 .34984 Mdot
.53604 .86702 Mdot
.6176 .54227 Mdot
.39597 .38064 Mdot
.47879 .4206 Mdot
.68151 .317 Mdot
.34494 .62312 Mdot
.21146 .566 Mdot
.40607 .42577 Mdot
.32269 .69027 Mdot
.42222 .40141 Mdot
.62575 .50124 Mdot
.32734 .58 Mdot
.41838 .43768 Mdot
.45961 .66555 Mdot
.4991 .41053 Mdot
.59179 .36262 Mdot
.50624 .79343 Mdot
.47173 .45905 Mdot
.13798 .44031 Mdot
.61573 .43837 Mdot
.63973 .53069 Mdot
.75645 .61962 Mdot
.87308 .56984 Mdot
.43723 .75447 Mdot
.34974 .61468 Mdot
.80403 .51157 Mdot
.65661 .52237 Mdot
.74896 .60439 Mdot
.76726 .32638 Mdot
.45855 .42049 Mdot
.39566 .44 Mdot
.65083 .29219 Mdot
.66159 .57525 Mdot
.67191 .57937 Mdot
.41159 .35875 Mdot
.4975 .43774 Mdot
.64839 .52248 Mdot
.4309 .36284 Mdot
.39147 .37181 Mdot
.50187 .64483 Mdot
.32196 .57557 Mdot
.54819 .69286 Mdot
.53186 .70548 Mdot
.43531 .80491 Mdot
.62574 .43145 Mdot
.54532 .68272 Mdot
.55962 .69559 Mdot
.47286 .27868 Mdot
.46464 .23026 Mdot
.64416 .3739 Mdot
.83772 .47153 Mdot
.66751 .53979 Mdot
.42548 .4398 Mdot
.29572 .61076 Mdot
.2568 .57971 Mdot
.75563 .49208 Mdot
.17742 .52166 Mdot
.41058 .45559 Mdot
.66557 .51945 Mdot
.59312 .61481 Mdot
.44326 .33987 Mdot
.69167 .51931 Mdot
.41002 .39987 Mdot
.62751 .57261 Mdot
.32771 .41328 Mdot
.60889 .76319 Mdot
.69955 .55123 Mdot
.331 .555 Mdot
.41852 .39213 Mdot
.31253 .58452 Mdot
.51816 .68554 Mdot
.64266 .37014 Mdot
.61477 .376 Mdot
.44297 .43642 Mdot
.36383 .444 Mdot
.68237 .46042 Mdot
.44758 .42277 Mdot
.45961 .38674 Mdot
.59979 .61916 Mdot
.46119 .38468 Mdot
.46724 .44743 Mdot
.44337 .45865 Mdot
.3999 .45311 Mdot
.50361 .65722 Mdot
.71186 .69063 Mdot
.51296 .42078 Mdot
.50876 .42265 Mdot
.50395 .69238 Mdot
.78967 .45213 Mdot
.54407 .70462 Mdot
.73788 .30371 Mdot
.55754 .66559 Mdot
.6236 .37394 Mdot
.71112 .34315 Mdot
.37205 .48129 Mdot
.35282 .56279 Mdot
.53072 .7142 Mdot
.63184 .35805 Mdot
.5241 .67252 Mdot
.64281 .51176 Mdot
.5197 .16315 Mdot
.35683 .63386 Mdot
.41393 .54827 Mdot
.58105 .69091 Mdot
.67081 .71396 Mdot
.62019 .54201 Mdot
.30721 .59062 Mdot
.3287 .50692 Mdot
.4736 .43752 Mdot
.6253 .34992 Mdot
.43674 .44418 Mdot
.50377 .67346 Mdot
.6645 .52313 Mdot
.57509 .8092 Mdot
.59989 .36704 Mdot
.44322 .18132 Mdot
.65433 .55904 Mdot
.4543 .45848 Mdot
.53204 .70656 Mdot
.35184 .21849 Mdot
.55193 .68889 Mdot
.20284 .51517 Mdot
.36699 .61214 Mdot
.54661 .83949 Mdot
.34495 .60793 Mdot
.62368 .74022 Mdot
.33387 .19557 Mdot
.72165 .69045 Mdot
.36078 .57763 Mdot
.51468 .60228 Mdot
.44544 .39045 Mdot
.43328 .37718 Mdot
.59287 .78258 Mdot
.2904 .60588 Mdot
.47623 .40604 Mdot
.68599 .61079 Mdot
.53015 .61155 Mdot
.35918 .24923 Mdot
.63055 .55551 Mdot
.41449 .41941 Mdot
.56365 .66014 Mdot
.54938 .64541 Mdot
.62095 .56259 Mdot
.55563 .69161 Mdot
.44091 .40329 Mdot
.33697 .6062 Mdot
.72311 .56688 Mdot
.61659 .38374 Mdot
.77601 .68092 Mdot
.62187 .34374 Mdot
.63654 .54693 Mdot
.47036 .36994 Mdot
.65366 .52424 Mdot
.90352 .52558 Mdot
.43799 .39489 Mdot
.34979 .58128 Mdot
.46797 .39206 Mdot
.42186 .39123 Mdot
.40424 .45526 Mdot
.64916 .51581 Mdot
.54463 .35773 Mdot
.43965 .36344 Mdot
.53458 .65438 Mdot
.24956 .41004 Mdot
.46271 .46315 Mdot
.67 .59218 Mdot
.46451 .24421 Mdot
.57609 .64563 Mdot
.32907 .63036 Mdot
.63858 .53583 Mdot
.35761 .58791 Mdot
.28318 .67263 Mdot
.35496 .59531 Mdot
.23717 .47975 Mdot
.33139 .49381 Mdot
.3507 .30417 Mdot
.33123 .34561 Mdot
.47565 .59464 Mdot
.28972 .6085 Mdot
.57663 .35748 Mdot
.3713 .57915 Mdot
.31204 .62284 Mdot
.11218 .37812 Mdot
.34954 .55931 Mdot
.40668 .41676 Mdot
.46172 .46117 Mdot
.65958 .73333 Mdot
.53333 .2818 Mdot
.46864 .40399 Mdot
.47273 .40929 Mdot
.62728 .38825 Mdot
.3039 .67891 Mdot
.71879 .6526 Mdot
.19714 .40676 Mdot
.77599 .58841 Mdot
.43681 .44169 Mdot
.46577 .38179 Mdot
.48082 .35864 Mdot
.24802 .29781 Mdot
.44145 .81487 Mdot
.39622 .57805 Mdot
.48056 .36105 Mdot
.71319 .71476 Mdot
.401 .44955 Mdot
.3988 .40939 Mdot
.44573 .39499 Mdot
.65714 .52206 Mdot
.31197 .628 Mdot
.39386 .44819 Mdot
.66452 .31603 Mdot
.40166 .40957 Mdot
.62559 .64502 Mdot
.65462 .80568 Mdot
.41314 .42372 Mdot
.34365 .63347 Mdot
.43756 .37683 Mdot
.33151 .6246 Mdot
.3062 .60434 Mdot
.45193 .3516 Mdot
.22695 .44368 Mdot
.36335 .62232 Mdot
.44643 .41092 Mdot
.6547 .51006 Mdot
.83474 .42868 Mdot
.43605 .45352 Mdot
.64404 .36942 Mdot
.40338 .42727 Mdot
.63355 .39435 Mdot
.46183 .39185 Mdot
.61705 .54494 Mdot
.25533 .61212 Mdot
.66051 .53326 Mdot
.48284 .83329 Mdot
.61675 .52807 Mdot
.48785 .16254 Mdot
.29767 .5951 Mdot
.69568 .64294 Mdot
.22309 .62126 Mdot
.60011 .6755 Mdot
.53668 .47444 Mdot
.4756 .5542 Mdot
.54292 .70057 Mdot
.36216 .61365 Mdot
.38013 .65471 Mdot
.76954 .45758 Mdot
.73347 .38719 Mdot
.67633 .55413 Mdot
.29002 .76427 Mdot
.18128 .57275 Mdot
.41645 .36619 Mdot
.28938 .50057 Mdot
.27255 .44547 Mdot
.3996 .44883 Mdot
.38909 .43896 Mdot
.5955 .58231 Mdot
.4445 .36166 Mdot
.46573 .71403 Mdot
.63695 .55108 Mdot
.63142 .35623 Mdot
.34418 .57718 Mdot
.60398 .35062 Mdot
.76816 .43745 Mdot
.47024 .55332 Mdot
.63389 .51615 Mdot
.48179 .45427 Mdot
.47053 .41534 Mdot
.32167 .62244 Mdot
.37943 .54132 Mdot
.36645 .57139 Mdot
.61543 .36179 Mdot
.64158 .55451 Mdot
.27882 .71074 Mdot
.47194 .42016 Mdot
.32212 .59305 Mdot
.54706 .45977 Mdot
.46911 .3879 Mdot
.52174 .68371 Mdot
.44105 .38814 Mdot
.35689 .57475 Mdot
.46135 .38493 Mdot
.34598 .60895 Mdot
.64778 .54478 Mdot
.43951 .46499 Mdot
.45664 .44195 Mdot
.39605 .19925 Mdot
.62958 .36611 Mdot
.31145 .57908 Mdot
.5854 .49708 Mdot
.48086 .40223 Mdot
.65911 .66419 Mdot
.40803 .4045 Mdot
.26803 .60529 Mdot
.40367 .37936 Mdot
.59944 .6595 Mdot
.49859 .4496 Mdot
.4313 .45187 Mdot
.57655 .45268 Mdot
.26608 .45908 Mdot
.36155 .47953 Mdot
.55951 .70178 Mdot
.3271 .56456 Mdot
.36385 .25038 Mdot
.6842 .491 Mdot
.69084 .53582 Mdot
.58237 .25886 Mdot
.40873 .46378 Mdot
.42275 .4233 Mdot
.5731 .68785 Mdot
.5992 .35959 Mdot
.3142 .58878 Mdot
.63382 .36443 Mdot
.42952 .20008 Mdot
.58939 .37495 Mdot
.6332 .49476 Mdot
.70734 .48711 Mdot
.30012 .73502 Mdot
.62376 .39021 Mdot
.36087 .57465 Mdot
.73532 .53376 Mdot
.42124 .47282 Mdot
.60903 .43864 Mdot
.62859 .37905 Mdot
.38444 .83289 Mdot
.46579 .4486 Mdot
.53476 .4731 Mdot
.54291 .68873 Mdot
.63478 .3814 Mdot
.5217 .69784 Mdot
.46539 .42002 Mdot
.7217 .64557 Mdot
.3518 .61308 Mdot
.5052 .68864 Mdot
.36451 .41686 Mdot
.62248 .35983 Mdot
.626 .51138 Mdot
.56892 .70066 Mdot
.54899 .70693 Mdot
.79846 .44589 Mdot
.55469 .82157 Mdot
.64425 .55562 Mdot
.28757 .31953 Mdot
.55679 .65962 Mdot
.42665 .47281 Mdot
.31531 .67549 Mdot
.42554 .3823 Mdot
.4196 .77757 Mdot
.63376 .53983 Mdot
.68421 .70899 Mdot
.46529 .38369 Mdot
.41741 .45474 Mdot
.36381 .6289 Mdot
.66156 .54186 Mdot
.33722 .59657 Mdot
.31935 .56788 Mdot
.64894 .54591 Mdot
.35563 .60353 Mdot
.59952 .39729 Mdot
.42914 .65282 Mdot
.54226 .65035 Mdot
.52402 .6494 Mdot
.66931 .53425 Mdot
.63626 .53061 Mdot
.65043 .52737 Mdot
.44067 .38765 Mdot
.3189 .58421 Mdot
.45936 .40791 Mdot
.39601 .41875 Mdot
.25113 .39613 Mdot
.30609 .62409 Mdot
.45208 .40063 Mdot
.60241 .46055 Mdot
.57831 .42006 Mdot
.6511 .50827 Mdot
.54383 .68526 Mdot
.69255 .61945 Mdot
.60169 .74346 Mdot
.41382 .41563 Mdot
.65419 .40317 Mdot
.36464 .57541 Mdot
.60436 .36691 Mdot
.61033 .34108 Mdot
.61257 .37047 Mdot
.58712 .63107 Mdot
.2966 .59251 Mdot
.19291 .41783 Mdot
.41725 .42174 Mdot
.43931 .55778 Mdot
.36451 .64803 Mdot
.65931 .44587 Mdot
.54371 .68253 Mdot
.47095 .39519 Mdot
.57392 .57618 Mdot
.32583 .52679 Mdot
.42763 .38401 Mdot
.45111 .4685 Mdot
.76364 .53942 Mdot
.40229 .47665 Mdot
.382 .58846 Mdot
.35336 .2218 Mdot
.48109 .39202 Mdot
.33976 .73119 Mdot
.78577 .68028 Mdot
.41295 .40684 Mdot
.40792 .44834 Mdot
.46724 .43772 Mdot
.45297 .37528 Mdot
.35034 .63013 Mdot
.52457 .25214 Mdot
.56018 .6673 Mdot
.43746 .55287 Mdot
.50162 .65247 Mdot
.60905 .55202 Mdot
.69209 .70551 Mdot
.36767 .60988 Mdot
.59568 .3754 Mdot
.76989 .6444 Mdot
.27546 .29567 Mdot
.62626 .56281 Mdot
.38275 .78318 Mdot
.62884 .37467 Mdot
.43376 .47243 Mdot
.61431 .39971 Mdot
.64096 .50206 Mdot
.5267 .64717 Mdot
.45394 .47291 Mdot
.3711 .58309 Mdot
.33754 .57123 Mdot
.47342 .3963 Mdot
.72575 .70263 Mdot
.52527 .688 Mdot
.54947 .70905 Mdot
.41013 .38772 Mdot
.4885 .41011 Mdot
.34148 .5977 Mdot
.66587 .55669 Mdot
.37356 .27475 Mdot
.61045 .35409 Mdot
.38311 .41595 Mdot
.45647 .38158 Mdot
.49622 .18052 Mdot
.53825 .65476 Mdot
.68527 .51457 Mdot
.41038 .37581 Mdot
.38672 .71806 Mdot
.41297 .37398 Mdot
.46524 .35025 Mdot
.65676 .5099 Mdot
.51884 .40676 Mdot
.39968 .37184 Mdot
.33678 .64111 Mdot
.53534 .70024 Mdot
.34879 .58671 Mdot
.2926 .63421 Mdot
.42055 .6033 Mdot
.52062 .68126 Mdot
.45013 .39314 Mdot
.54043 .67848 Mdot
.41278 .3893 Mdot
.46104 .37252 Mdot
.54725 .68171 Mdot
.33786 .5974 Mdot
.80106 .51737 Mdot
.7207 .68455 Mdot
.44953 .37218 Mdot
.43071 .35182 Mdot
.52473 .26468 Mdot
.54783 .36448 Mdot
.40157 .44698 Mdot
.35268 .57285 Mdot
.46706 .42813 Mdot
.51385 .68883 Mdot
.60825 .3975 Mdot
.35757 .57836 Mdot
.64951 .56487 Mdot
.62247 .55552 Mdot
.43093 .74477 Mdot
.67451 .56422 Mdot
.39154 .43349 Mdot
.28029 .58895 Mdot
.30905 .63613 Mdot
.74616 .70622 Mdot
.65195 .54743 Mdot
.64498 .3747 Mdot
.4524 .43549 Mdot
.61619 .24674 Mdot
.55999 .6515 Mdot
.11943 .50316 Mdot
.16944 .47571 Mdot
.58008 .39138 Mdot
.1815 .51452 Mdot
.61376 .54125 Mdot
.38811 .38591 Mdot
.64321 .36386 Mdot
.62363 .54776 Mdot
.43027 .37093 Mdot
.45709 .35206 Mdot
.20877 .55312 Mdot
.45363 .58942 Mdot
.54196 .67597 Mdot
.65469 .57257 Mdot
.5767 .39109 Mdot
.64416 .49138 Mdot
.30104 .59485 Mdot
.42479 .44739 Mdot
.46683 .36476 Mdot
.65936 .56315 Mdot
.68966 .55408 Mdot
.44825 .40528 Mdot
.37587 .60135 Mdot
.5921 .57821 Mdot
.4369 .43558 Mdot
.44735 .61931 Mdot
.28929 .58951 Mdot
.63463 .55586 Mdot
.42147 .45373 Mdot
.5586 .3791 Mdot
.65789 .55921 Mdot
.64856 .50758 Mdot
.46867 .38399 Mdot
.59496 .39525 Mdot
.44471 .35399 Mdot
.55479 .6635 Mdot
.33685 .79029 Mdot
.51181 .68751 Mdot
.71628 .58386 Mdot
.36285 .42877 Mdot
.37585 .68988 Mdot
.33599 .62835 Mdot
.55887 .22494 Mdot
.68863 .61184 Mdot
.39719 .36447 Mdot
.81751 .41562 Mdot
.50481 .71982 Mdot
.74835 .68478 Mdot
.68524 .28285 Mdot
.61948 .38812 Mdot
.52171 .67195 Mdot
.4071 .44785 Mdot
.50302 .6422 Mdot
.64358 .36059 Mdot
.48513 .83111 Mdot
.43112 .45653 Mdot
.33092 .57935 Mdot
.44487 .40178 Mdot
.32566 .57727 Mdot
.46605 .38018 Mdot
.49769 .38531 Mdot
.63102 .62473 Mdot
.42847 .27962 Mdot
.40407 .38404 Mdot
.46895 .14675 Mdot
.54942 .41719 Mdot
.62427 .35271 Mdot
.45748 .41605 Mdot
.6941 .51762 Mdot
.54054 .63661 Mdot
.51967 .76933 Mdot
.65629 .52104 Mdot
.55298 .7031 Mdot
.35093 .60057 Mdot
.63904 .54091 Mdot
.62484 .56448 Mdot
.51967 .40746 Mdot
.59092 .39665 Mdot
.51267 .65784 Mdot
.41718 .43866 Mdot
.43104 .45581 Mdot
.28723 .31331 Mdot
.75619 .47027 Mdot
.37513 .5389 Mdot
.19639 .36137 Mdot
.32736 .55931 Mdot
.62534 .35641 Mdot
.65529 .51584 Mdot
.39597 .4271 Mdot
.43422 .40674 Mdot
.67023 .64949 Mdot
.37687 .58318 Mdot
.51628 .56444 Mdot
.26275 .64576 Mdot
.59052 .49186 Mdot
.47057 .26114 Mdot
.34749 .57541 Mdot
.47039 .26274 Mdot
.58492 .35468 Mdot
.83837 .52902 Mdot
.45092 .27782 Mdot
.54077 .68812 Mdot
.47609 .26445 Mdot
.31643 .59527 Mdot
.43521 .36523 Mdot
.67071 .51499 Mdot
.68223 .55537 Mdot
.34258 .59069 Mdot
.66364 .49476 Mdot
.60541 .39085 Mdot
.4087 .44306 Mdot
.20693 .38606 Mdot
.43843 .72458 Mdot
.67237 .53734 Mdot
.46283 .34368 Mdot
.50839 .66897 Mdot
.47381 .39607 Mdot
.61438 .39332 Mdot
.53343 .67845 Mdot
.53584 .20446 Mdot
.51377 .61895 Mdot
.44965 .43428 Mdot
.50482 .17356 Mdot
.52429 .6786 Mdot
.53915 .40994 Mdot
.43111 .43894 Mdot
.55854 .67394 Mdot
.52076 .43945 Mdot
.64121 .71441 Mdot
.56112 .55362 Mdot
.76862 .32706 Mdot
.54839 .54614 Mdot
.67432 .52487 Mdot
.65558 .71591 Mdot
.58184 .71453 Mdot
.53227 .63896 Mdot
.69257 .52955 Mdot
.58949 .41393 Mdot
.52443 .69931 Mdot
.44429 .4682 Mdot
.41106 .40285 Mdot
.45828 .81986 Mdot
.54229 .72899 Mdot
.61854 .74707 Mdot
.47748 .76029 Mdot
.48196 .40707 Mdot
.45064 .35525 Mdot
.43211 .41156 Mdot
.37812 .61146 Mdot
.54196 .66637 Mdot
.41717 .17271 Mdot
.5208 .68584 Mdot
.21601 .41403 Mdot
.66783 .5356 Mdot
.62846 .55309 Mdot
.41238 .41953 Mdot
.52081 .4774 Mdot
.50027 .22434 Mdot
.44197 .40636 Mdot
.63379 .40519 Mdot
.51766 .79829 Mdot
.4869 .40711 Mdot
.3598 .62006 Mdot
.4793 .35235 Mdot
.4472 .32896 Mdot
.54205 .64988 Mdot
.60343 .38384 Mdot
.54697 .21813 Mdot
.51863 .64704 Mdot
.42377 .42232 Mdot
.38596 .69099 Mdot
.42657 .39226 Mdot
.44392 .37125 Mdot
.1827 .46931 Mdot
.59708 .34861 Mdot
.6509 .53448 Mdot
.61534 .36935 Mdot
.334 .62595 Mdot
.09523 .46792 Mdot
.58928 .36985 Mdot
.50473 .21933 Mdot
.44062 .82556 Mdot
.4789 .26805 Mdot
.31559 .5809 Mdot
.59884 .40205 Mdot
.53194 .68959 Mdot
.83812 .43508 Mdot
.22666 .58947 Mdot
.48483 .71353 Mdot
.43502 .43102 Mdot
.37442 .56057 Mdot
.34786 .567 Mdot
.50354 .6881 Mdot
.30656 .60178 Mdot
.45392 .49363 Mdot
.44022 .36746 Mdot
.5158 .63624 Mdot
.399 .71241 Mdot
.56126 .70058 Mdot
.48161 .61906 Mdot
.45291 .41706 Mdot
.35189 .57826 Mdot
.38124 .41068 Mdot
.28405 .60161 Mdot
.66907 .50155 Mdot
.49514 .42646 Mdot
.60244 .38994 Mdot
.36884 .70447 Mdot
.64511 .55732 Mdot
.64692 .42584 Mdot
.32186 .62334 Mdot
.57133 .62343 Mdot
.3091 .61601 Mdot
.28875 .61962 Mdot
.53953 .70587 Mdot
.32642 .60995 Mdot
.40857 .44751 Mdot
.57903 .4839 Mdot
.33724 .62097 Mdot
.52158 .6601 Mdot
.60613 .38211 Mdot
.34684 .60502 Mdot
.71023 .53911 Mdot
.44904 .44091 Mdot
.64256 .51916 Mdot
.7051 .343 Mdot
.36595 .55911 Mdot
.58939 .35617 Mdot
.69015 .54654 Mdot
.62509 .34853 Mdot
.69236 .76065 Mdot
.49031 .6598 Mdot
.20723 .44827 Mdot
.59356 .41003 Mdot
.35585 .56362 Mdot
.71382 .34845 Mdot
.39782 .42149 Mdot
.45104 .43877 Mdot
.64364 .38556 Mdot
.3483 .56698 Mdot
.81703 .59893 Mdot
.37509 .35159 Mdot
.4697 .61929 Mdot
.50925 .70477 Mdot
.48775 .1587 Mdot
.47302 .62923 Mdot
.75194 .73839 Mdot
.38545 .37 Mdot
.66934 .58077 Mdot
.41988 .41196 Mdot
.66716 .62326 Mdot
.62279 .36209 Mdot
.6828 .5957 Mdot
.48448 .3777 Mdot
.64664 .53897 Mdot
.45326 .44977 Mdot
.5744 .46513 Mdot
.52221 .3781 Mdot
.64676 .3704 Mdot
.74608 .62909 Mdot
.34259 .55975 Mdot
.62062 .38264 Mdot
.62165 .53059 Mdot
.4913 .24335 Mdot
.43393 .36959 Mdot
.40375 .47186 Mdot
.59094 .4914 Mdot
.31791 .58276 Mdot
.67831 .52411 Mdot
.54898 .65729 Mdot
.59831 .37599 Mdot
.46959 .41306 Mdot
.39485 .40963 Mdot
.65257 .66462 Mdot
.50694 .67016 Mdot
.67697 .5677 Mdot
.54264 .69465 Mdot
.61429 .55387 Mdot
.45689 .36633 Mdot
.63006 .56046 Mdot
.38147 .43228 Mdot
.6241 .62676 Mdot
.19481 .45251 Mdot
.26999 .4785 Mdot
.63265 .5426 Mdot
.43701 .2464 Mdot
.51045 .67477 Mdot
.55436 .6871 Mdot
.36353 .78936 Mdot
.20138 .52106 Mdot
.27326 .3125 Mdot
.77532 .38074 Mdot
.50634 .64678 Mdot
.5118 .66488 Mdot
.63988 .52126 Mdot
.32513 .61144 Mdot
.31654 .56687 Mdot
.6157 .5574 Mdot
.57973 .30632 Mdot
.31438 .58879 Mdot
.82476 .45476 Mdot
.33126 .27107 Mdot
.38964 .44771 Mdot
.65063 .48684 Mdot
.60398 .3717 Mdot
.57113 .2976 Mdot
.57859 .46183 Mdot
.41607 .45577 Mdot
.59343 .23921 Mdot
.6698 .54443 Mdot
.48246 .50399 Mdot
.73919 .30822 Mdot
.44713 .4584 Mdot
.42685 .44075 Mdot
.42631 .41464 Mdot
.5797 .38379 Mdot
.21778 .55866 Mdot
.41682 .44945 Mdot
.57917 .30823 Mdot
.47846 .40042 Mdot
.53525 .41006 Mdot
.61496 .37416 Mdot
.41731 .29359 Mdot
.77342 .45351 Mdot
.35115 .22827 Mdot
.52272 .36961 Mdot
.55043 .65764 Mdot
.66401 .32531 Mdot
.54954 .6944 Mdot
.24409 .47856 Mdot
.46191 .28251 Mdot
.34591 .55221 Mdot
.41287 .45424 Mdot
.63604 .54756 Mdot
.34625 .56728 Mdot
.65748 .69039 Mdot
.09924 .42467 Mdot
.55106 .65593 Mdot
.81368 .6913 Mdot
.5574 .67355 Mdot
.62462 .56506 Mdot
.3427 .59747 Mdot
.33211 .48464 Mdot
.43342 .57562 Mdot
.34941 .60589 Mdot
.80121 .56484 Mdot
.39517 .57409 Mdot
.46134 .24919 Mdot
.37726 .57227 Mdot
.517 .66369 Mdot
.5892 .65058 Mdot
.38276 .49854 Mdot
.40155 .41962 Mdot
.48092 .55054 Mdot
.48139 .23103 Mdot
.39816 .42321 Mdot
.63902 .55206 Mdot
.1989 .46567 Mdot
.58312 .246 Mdot
.32408 .60538 Mdot
.50207 .6264 Mdot
.42973 .44596 Mdot
.44511 .37845 Mdot
.43196 .36807 Mdot
.16569 .43471 Mdot
.83845 .53255 Mdot
.44217 .36363 Mdot
.47767 .39154 Mdot
.64239 .54069 Mdot
.56692 .39535 Mdot
.74318 .57978 Mdot
.27667 .3493 Mdot
.42887 .46461 Mdot
.62025 .37947 Mdot
.57301 .37519 Mdot
.41796 .37127 Mdot
.61846 .44202 Mdot
.388 .68359 Mdot
.41764 .44003 Mdot
.20098 .46859 Mdot
.61017 .47407 Mdot
.66106 .57545 Mdot
.65454 .5636 Mdot
.31095 .58202 Mdot
.64889 .56984 Mdot
.61637 .53672 Mdot
.34417 .49765 Mdot
.5351 .55119 Mdot
.48781 .6329 Mdot
.61354 .3615 Mdot
.43287 .40182 Mdot
.3541 .4562 Mdot
.38232 .70882 Mdot
.5339 .7031 Mdot
.36661 .58303 Mdot
.54519 .63902 Mdot
.6493 .32753 Mdot
.41199 .57736 Mdot
.67453 .54768 Mdot
.51355 .64331 Mdot
.5442 .62597 Mdot
.61779 .37943 Mdot
.50803 .6873 Mdot
.56206 .63918 Mdot
.48849 .44059 Mdot
.28193 .51749 Mdot
.4443 .41219 Mdot
.7722 .65095 Mdot
.5077 .66119 Mdot
.60483 .64386 Mdot
.42108 .4304 Mdot
.65754 .55778 Mdot
.38324 .50659 Mdot
.40006 .41337 Mdot
.65632 .56663 Mdot
.4181 .36581 Mdot
.62102 .34468 Mdot
.2864 .59939 Mdot
.43132 .56332 Mdot
.26849 .75341 Mdot
.59208 .39782 Mdot
.66121 .68295 Mdot
.40571 .45216 Mdot
.60605 .80567 Mdot
.34339 .60509 Mdot
.39023 .40013 Mdot
.55748 .23816 Mdot
.33448 .61822 Mdot
.3614 .58965 Mdot
.44873 .3855 Mdot
.54126 .69082 Mdot
.64129 .55761 Mdot
.61363 .37778 Mdot
.74832 .72663 Mdot
.44177 .42913 Mdot
.46105 .43721 Mdot
.62608 .37879 Mdot
.50841 .6764 Mdot
.41003 .37765 Mdot
.68544 .31157 Mdot
.83084 .58833 Mdot
.55743 .68654 Mdot
.44011 .46813 Mdot
.24048 .51832 Mdot
.41745 .32829 Mdot
.53608 .85628 Mdot
.61487 .43773 Mdot
.64519 .53346 Mdot
.38668 .47525 Mdot
.12806 .4295 Mdot
.6029 .3818 Mdot
.274 .30063 Mdot
.44883 .37874 Mdot
.47346 .41977 Mdot
.36651 .57248 Mdot
.45605 .40678 Mdot
.3726 .60171 Mdot
.25227 .72247 Mdot
.49095 .17845 Mdot
.3049 .59235 Mdot
.35695 .56166 Mdot
.52658 .22174 Mdot
.71895 .59808 Mdot
.34477 .59224 Mdot
.46552 .37613 Mdot
.4516 .31111 Mdot
.38535 .52374 Mdot
.62107 .39951 Mdot
.74963 .3952 Mdot
.35357 .40093 Mdot
.66089 .35334 Mdot
.7984 .46736 Mdot
.35132 .40138 Mdot
.53177 .59535 Mdot
.55106 .66467 Mdot
.44581 .45922 Mdot
.6814 .55779 Mdot
.6745 .56564 Mdot
.37937 .396 Mdot
.43272 .39432 Mdot
.32966 .6255 Mdot
.59864 .36484 Mdot
.54583 .64703 Mdot
.47244 .41311 Mdot
.54821 .22633 Mdot
.59632 .36039 Mdot
.31309 .60769 Mdot
.2381 .41073 Mdot
.64476 .35217 Mdot
.50439 .40078 Mdot
.41031 .43105 Mdot
.44621 .3977 Mdot
.36898 .49181 Mdot
.54573 .66783 Mdot
.73411 .36684 Mdot
.47744 .4446 Mdot
.42398 .20067 Mdot
.48268 .6775 Mdot
.48703 .45539 Mdot
.30232 .60253 Mdot
.5009 .62313 Mdot
.62778 .50462 Mdot
.4115 .61276 Mdot
.4488 .43234 Mdot
.73158 .68174 Mdot
.47778 .81855 Mdot
.67195 .50503 Mdot
.28852 .61221 Mdot
.609 .36707 Mdot
.44048 .40457 Mdot
.22646 .45 Mdot
.41005 .40635 Mdot
.65458 .35028 Mdot
.65245 .50587 Mdot
.55209 .66734 Mdot
.75712 .67497 Mdot
.66515 .56945 Mdot
.35842 .58839 Mdot
.61378 .17564 Mdot
.37203 .60415 Mdot
.3124 .57122 Mdot
.24914 .40654 Mdot
.54739 .66974 Mdot
.11917 .46133 Mdot
.2774 .73328 Mdot
.49279 .41201 Mdot
.51156 .67808 Mdot
.33898 .58597 Mdot
.47795 .41419 Mdot
.35168 .54716 Mdot
.29353 .59999 Mdot
.46446 .3724 Mdot
.46867 .4392 Mdot
.63393 .75401 Mdot
.7629 .33125 Mdot
.6099 .36581 Mdot
.31949 .62642 Mdot
.44006 .62232 Mdot
.47861 .4186 Mdot
.4173 .42277 Mdot
.57857 .72494 Mdot
.60564 .39878 Mdot
.46375 .72073 Mdot
.44674 .37854 Mdot
.5165 .18592 Mdot
.51362 .39678 Mdot
.35955 .62431 Mdot
.55012 .69688 Mdot
.36046 .22502 Mdot
.567 .7087 Mdot
.37267 .59945 Mdot
.59342 .37375 Mdot
.33232 .63842 Mdot
.50172 .21786 Mdot
.5014 .66581 Mdot
.35687 .57469 Mdot
.57704 .58438 Mdot
.53623 .66747 Mdot
.50912 .65181 Mdot
.25859 .39182 Mdot
.69066 .51904 Mdot
.57808 .38136 Mdot
.5113 .66085 Mdot
.33952 .68661 Mdot
.524 .66371 Mdot
.29676 .74478 Mdot
.44125 .46517 Mdot
.59708 .2818 Mdot
.70218 .59129 Mdot
.38063 .47974 Mdot
.50523 .65956 Mdot
.62803 .38843 Mdot
.42869 .37248 Mdot
.31326 .59683 Mdot
.61537 .35073 Mdot
.48241 .71849 Mdot
.65032 .52193 Mdot
.31214 .61618 Mdot
.56031 .71033 Mdot
.33263 .57373 Mdot
.3842 .65227 Mdot
.40844 .8224 Mdot
.59787 .21606 Mdot
.43409 .58948 Mdot
.43654 .3693 Mdot
.78265 .41798 Mdot
.41098 .47137 Mdot
.43252 .38936 Mdot
.63543 .55418 Mdot
.59154 .26654 Mdot
.33788 .5968 Mdot
.79675 .62894 Mdot
.53487 .6459 Mdot
.36238 .21867 Mdot
.48157 .33633 Mdot
.39972 .37543 Mdot
.3415 .62072 Mdot
.3782 .59291 Mdot
.26121 .4453 Mdot
.61979 .51307 Mdot
.38747 .43227 Mdot
.42639 .47622 Mdot
.39751 .36837 Mdot
.52928 .64617 Mdot
.64627 .42189 Mdot
.67445 .52701 Mdot
.48129 .84259 Mdot
.65807 .50625 Mdot
.66238 .36253 Mdot
.32247 .60759 Mdot
.58939 .37034 Mdot
.41668 .42492 Mdot
.38842 .54784 Mdot
.37765 .58389 Mdot
.64803 .37566 Mdot
.63904 .37509 Mdot
.61613 .71473 Mdot
.54684 .68113 Mdot
.39925 .40139 Mdot
.41955 .45275 Mdot
.46143 .40539 Mdot
.43972 .38932 Mdot
.54479 .65037 Mdot
.42162 .37527 Mdot
.5692 .68139 Mdot
.32815 .66557 Mdot
.65146 .28981 Mdot
.54935 .54081 Mdot
.40837 .78232 Mdot
.31888 .60041 Mdot
.35342 .6862 Mdot
.37814 .3571 Mdot
.16358 .51444 Mdot
.54252 .80635 Mdot
.4849 .43613 Mdot
.62424 .55522 Mdot
.49529 .47829 Mdot
.67847 .55171 Mdot
.74043 .76302 Mdot
.63284 .6617 Mdot
.79118 .36432 Mdot
.43257 .45548 Mdot
.57573 .49399 Mdot
.31443 .69813 Mdot
.40941 .47225 Mdot
.63452 .68078 Mdot
.41244 .77738 Mdot
.73996 .64546 Mdot
.61253 .39494 Mdot
.44207 .4415 Mdot
.35929 .47295 Mdot
.40941 .4462 Mdot
.41753 .41623 Mdot
.42663 .37102 Mdot
.56399 .69282 Mdot
.38889 .41531 Mdot
.42538 .37886 Mdot
.69054 .4642 Mdot
.4572 .26703 Mdot
.68659 .55612 Mdot
.3954 .80357 Mdot
.58898 .3693 Mdot
.33158 .62338 Mdot
.82958 .52222 Mdot
.54106 .68744 Mdot
.2654 .44293 Mdot
.44272 .3929 Mdot
.6688 .72923 Mdot
.52433 .62304 Mdot
.59642 .3808 Mdot
.64134 .50094 Mdot
.81733 .392 Mdot
.64162 .54913 Mdot
.58697 .6181 Mdot
.65601 .55627 Mdot
.3698 .36579 Mdot
.32844 .62586 Mdot
.40559 .38741 Mdot
.5155 .6554 Mdot
.64208 .56669 Mdot
.53282 .27304 Mdot
.43053 .41056 Mdot
.64968 .54523 Mdot
.40565 .38781 Mdot
.41425 .55265 Mdot
.30499 .31564 Mdot
.61719 .53836 Mdot
.52435 .624 Mdot
.532 .65572 Mdot
.59246 .39307 Mdot
.32266 .62036 Mdot
.37046 .58872 Mdot
.53271 .67694 Mdot
.20476 .56866 Mdot
.42271 .46476 Mdot
.47596 .42677 Mdot
.38364 .21317 Mdot
.40112 .44146 Mdot
.47898 .24809 Mdot
.56919 .56115 Mdot
.31291 .60259 Mdot
.40767 .36603 Mdot
.45296 .38379 Mdot
.4502 .43543 Mdot
.36521 .65218 Mdot
.66728 .55639 Mdot
.44549 .46109 Mdot
.6399 .37018 Mdot
.65607 .46367 Mdot
.47375 .39549 Mdot
.51009 .44039 Mdot
.36991 .58635 Mdot
.19503 .36999 Mdot
.55652 .67354 Mdot
.62117 .53482 Mdot
.63156 .54139 Mdot
.76066 .40815 Mdot
.36287 .72906 Mdot
.56839 .55658 Mdot
.5141 .84461 Mdot
.63014 .62406 Mdot
.63052 .36071 Mdot
.61022 .49676 Mdot
.58998 .66362 Mdot
.63005 .5281 Mdot
.55037 .65408 Mdot
.44703 .46418 Mdot
.43116 .4649 Mdot
.15176 .53512 Mdot
.41796 .36985 Mdot
.60817 .37057 Mdot
.5606 .70383 Mdot
.31738 .59494 Mdot
.59625 .37841 Mdot
.54247 .69576 Mdot
.30897 .58927 Mdot
.47735 .44891 Mdot
.47319 .45223 Mdot
.36705 .58549 Mdot
.35528 .5702 Mdot
.4135 .43152 Mdot
.73401 .57457 Mdot
.35068 .56207 Mdot
.35063 .57446 Mdot
.67485 .54226 Mdot
.67888 .55918 Mdot
.50524 .43946 Mdot
.51354 .67546 Mdot
.42476 .37769 Mdot
.63829 .54325 Mdot
.58977 .37475 Mdot
.33463 .59796 Mdot
.45013 .37344 Mdot
.46986 .39538 Mdot
.61593 .38041 Mdot
.59363 .38838 Mdot
.62113 .39038 Mdot
.56665 .69468 Mdot
.46208 .41465 Mdot
.34865 .59724 Mdot
.54934 .67778 Mdot
.57386 .37587 Mdot
.62486 .39593 Mdot
.61688 .49872 Mdot
.39554 .43287 Mdot
.72244 .55166 Mdot
.13446 .39755 Mdot
.42964 .21292 Mdot
.65093 .49567 Mdot
.63438 .49773 Mdot
.49867 .28565 Mdot
.48841 .50663 Mdot
.52577 .68407 Mdot
.5608 .39048 Mdot
.54296 .21466 Mdot
.47381 .45786 Mdot
.48243 .39636 Mdot
.48851 .37176 Mdot
.62904 .38491 Mdot
.60716 .2661 Mdot
.36559 .61168 Mdot
.35042 .36385 Mdot
.59981 .35571 Mdot
.68872 .55541 Mdot
.6299 .48828 Mdot
.65454 .50476 Mdot
.45742 .46136 Mdot
.27772 .47758 Mdot
.35132 .70559 Mdot
.7486 .35443 Mdot
.50528 .6657 Mdot
.35438 .45566 Mdot
.60478 .80305 Mdot
.36493 .58862 Mdot
.60825 .55142 Mdot
.63305 .36133 Mdot
.35171 .57024 Mdot
.53679 .63212 Mdot
.5126 .66218 Mdot
.67206 .5345 Mdot
.66857 .52861 Mdot
.64072 .51389 Mdot
.29292 .59623 Mdot
.32438 .6091 Mdot
.45017 .42959 Mdot
.33001 .5995 Mdot
.16267 .48001 Mdot
.63139 .39773 Mdot
.66732 .58972 Mdot
.5195 .67396 Mdot
.3131 .58437 Mdot
.43329 .41068 Mdot
.45753 .51743 Mdot
.45871 .76948 Mdot
.63246 .35383 Mdot
.29534 .31324 Mdot
.72422 .77221 Mdot
.39734 .40527 Mdot
.54175 .6603 Mdot
.21044 .37774 Mdot
.42835 .41608 Mdot
.65862 .51454 Mdot
.75657 .55769 Mdot
.6208 .47903 Mdot
.40048 .41053 Mdot
.47427 .45928 Mdot
.56011 .67629 Mdot
.50193 .83702 Mdot
.44675 .42787 Mdot
.44792 .69797 Mdot
.49989 .6407 Mdot
.6717 .52072 Mdot
.86401 .50683 Mdot
.69042 .34862 Mdot
.57781 .30029 Mdot
.67401 .53222 Mdot
.42056 .39169 Mdot
.67466 .55476 Mdot
.63685 .36036 Mdot
.62564 .51634 Mdot
.37065 .60849 Mdot
.67486 .51039 Mdot
.46147 .43755 Mdot
.34503 .59012 Mdot
.52335 .67946 Mdot
.3278 .25137 Mdot
.74113 .50507 Mdot
.65964 .55662 Mdot
.61787 .54804 Mdot
.41102 .36597 Mdot
.478 .72941 Mdot
.37644 .41627 Mdot
.46285 .45106 Mdot
.50319 .65096 Mdot
.33186 .61971 Mdot
.55465 .69696 Mdot
.45932 .48376 Mdot
.67908 .29366 Mdot
.54547 .69292 Mdot
.7255 .67851 Mdot
.62951 .3728 Mdot
.53683 .49963 Mdot
.43513 .40503 Mdot
.51371 .69313 Mdot
.46059 .41616 Mdot
.35698 .61842 Mdot
.55184 .51189 Mdot
.72442 .64912 Mdot
.51887 .6494 Mdot
.74196 .67854 Mdot
.64877 .30321 Mdot
.489 .47027 Mdot
.55416 .68968 Mdot
.56913 .24382 Mdot
.62564 .56581 Mdot
.61041 .35341 Mdot
.6364 .3492 Mdot
.60786 .34991 Mdot
.37451 .39588 Mdot
.50918 .35549 Mdot
.59263 .35115 Mdot
.53482 .63375 Mdot
.6466 .37001 Mdot
.32192 .72938 Mdot
.7977 .62125 Mdot
.62418 .36451 Mdot
.43303 .43642 Mdot
.44491 .33395 Mdot
.47364 .27737 Mdot
.63342 .72172 Mdot
.80172 .38306 Mdot
.52506 .78018 Mdot
.40309 .41659 Mdot
.29411 .58456 Mdot
.29689 .61369 Mdot
.22506 .34786 Mdot
.46426 .23404 Mdot
.46299 .19686 Mdot
.34467 .5576 Mdot
.70522 .63791 Mdot
.31262 .61064 Mdot
.42468 .36819 Mdot
.47694 .422 Mdot
.34812 .55629 Mdot
.64423 .27778 Mdot
.69378 .65665 Mdot
.7541 .69837 Mdot
.34216 .57138 Mdot
.53704 .70018 Mdot
.51041 .69965 Mdot
.50749 .65293 Mdot
.31283 .28274 Mdot
.35021 .61586 Mdot
.46617 .40178 Mdot
.63236 .5444 Mdot
.4364 .46189 Mdot
.53912 .67029 Mdot
.80296 .62225 Mdot
.34727 .61062 Mdot
.42632 .44943 Mdot
.43322 .50365 Mdot
.6614 .52345 Mdot
.62423 .37519 Mdot
.41241 .53899 Mdot
.46148 .20078 Mdot
.52458 .64278 Mdot
.36153 .55785 Mdot
.61487 .64135 Mdot
.76866 .63917 Mdot
.39065 .36402 Mdot
.42851 .4781 Mdot
.74443 .73582 Mdot
.52147 .19546 Mdot
.39447 .44081 Mdot
.62042 .54373 Mdot
.66298 .64972 Mdot
.46596 .38622 Mdot
.30423 .62126 Mdot
.64106 .34997 Mdot
.62449 .349 Mdot
.5043 .44339 Mdot
.44343 .54885 Mdot
.56779 .49509 Mdot
.44899 .39153 Mdot
.50232 .39538 Mdot
.67237 .52369 Mdot
.64971 .62236 Mdot
.43106 .19905 Mdot
.592 .37802 Mdot
.40693 .38456 Mdot
.78961 .54774 Mdot
.37046 .5731 Mdot
.66659 .50262 Mdot
.50326 .67827 Mdot
.37324 .64232 Mdot
.63863 .50187 Mdot
.45857 .37431 Mdot
.41476 .37359 Mdot
.52742 .70458 Mdot
.3621 .62232 Mdot
.63126 .38196 Mdot
.62969 .55144 Mdot
.59872 .39136 Mdot
.33793 .61776 Mdot
.33038 .60431 Mdot
.44984 .49849 Mdot
.38788 .36059 Mdot
.65053 .5641 Mdot
.38099 .43275 Mdot
.63509 .47135 Mdot
.5795 .84471 Mdot
.52977 .71399 Mdot
.39192 .41945 Mdot
.38435 .59599 Mdot
.52249 .64639 Mdot
.47284 .42723 Mdot
.7667 .7163 Mdot
.4798 .41283 Mdot
.48376 .66994 Mdot
.57847 .19692 Mdot
.60994 .39278 Mdot
.35664 .35634 Mdot
.60314 .77622 Mdot
.40195 .43875 Mdot
.63287 .53254 Mdot
.45793 .34303 Mdot
.53523 .69182 Mdot
.32365 .60601 Mdot
.55771 .85904 Mdot
.52565 .66074 Mdot
.41159 .44265 Mdot
.59756 .37683 Mdot
.38026 .58062 Mdot
.61713 .42202 Mdot
.62057 .44211 Mdot
.52609 .40903 Mdot
.38249 .41784 Mdot
.43965 .38298 Mdot
.70616 .31925 Mdot
.62291 .53126 Mdot
.34116 .57904 Mdot
.5407 .65755 Mdot
.53147 .68009 Mdot
.67133 .54187 Mdot
.4878 .625 Mdot
.53585 .50143 Mdot
.19933 .31781 Mdot
.66383 .56538 Mdot
.59262 .35627 Mdot
.46134 .71217 Mdot
.62653 .54391 Mdot
.65383 .54486 Mdot
.67593 .54124 Mdot
.56315 .5932 Mdot
.31431 .58588 Mdot
.461 .37581 Mdot
.33048 .63032 Mdot
.42107 .38918 Mdot
.48342 .6668 Mdot
.51509 .65243 Mdot
.34114 .61245 Mdot
.72198 .74557 Mdot
.26469 .53783 Mdot
.4288 .42569 Mdot
.60708 .80438 Mdot
.4762 .37087 Mdot
.49721 .26857 Mdot
.47094 .36168 Mdot
.66593 .54644 Mdot
.3833 .45787 Mdot
.39336 .37052 Mdot
.2489 .31626 Mdot
.51772 .67626 Mdot
.65319 .57709 Mdot
.49602 .4021 Mdot
.50029 .387 Mdot
.29541 .58976 Mdot
.3509 .57123 Mdot
.63063 .34751 Mdot
.41743 .28036 Mdot
.52187 .68179 Mdot
.26352 .70266 Mdot
.4027 .42193 Mdot
.67121 .36028 Mdot
.32879 .34494 Mdot
.47121 .43147 Mdot
.61979 .77744 Mdot
.27392 .46929 Mdot
.43886 .40454 Mdot
.47885 .58503 Mdot
.5091 .67304 Mdot
.66532 .27321 Mdot
.47569 .39351 Mdot
.65762 .51937 Mdot
.32016 .6105 Mdot
.38029 .59154 Mdot
.61314 .34495 Mdot
.17521 .56174 Mdot
.55271 .70047 Mdot
.33163 .61046 Mdot
.42702 .40649 Mdot
.54551 .6632 Mdot
.65419 .57045 Mdot
.39765 .38008 Mdot
.45105 .23421 Mdot
.32462 .59594 Mdot
.4276 .36028 Mdot
.43221 .6835 Mdot
.53339 .30781 Mdot
.62636 .206 Mdot
.53963 .65504 Mdot
.59764 .39527 Mdot
.47502 .35282 Mdot
.20386 .54598 Mdot
.44466 .3522 Mdot
.60513 .29301 Mdot
.33072 .73673 Mdot
.60536 .39747 Mdot
.42419 .43317 Mdot
.46935 .40957 Mdot
.53978 .45664 Mdot
.59192 .37383 Mdot
.42764 .45602 Mdot
.28968 .65057 Mdot
.32409 .58022 Mdot
.61111 .55404 Mdot
.31731 .59126 Mdot
.4344 .43115 Mdot
.39489 .35519 Mdot
.36354 .5715 Mdot
.61161 .81988 Mdot
.60351 .4079 Mdot
.55478 .67941 Mdot
.47912 .38222 Mdot
.47904 .43746 Mdot
.41489 .15943 Mdot
.67804 .5094 Mdot
.73651 .59146 Mdot
.67399 .42043 Mdot
.79603 .50511 Mdot
.6896 .34618 Mdot
.72159 .27143 Mdot
.5273 .1951 Mdot
.38871 .41206 Mdot
.41491 .32054 Mdot
.39621 .66148 Mdot
.50374 .66708 Mdot
.26305 .66885 Mdot
.40131 .41949 Mdot
.41819 .4136 Mdot
.65042 .49441 Mdot
.70537 .68869 Mdot
.46138 .19622 Mdot
.45723 .52163 Mdot
.62952 .38257 Mdot
.31524 .62444 Mdot
.4622 .37506 Mdot
.50692 .57286 Mdot
.69002 .55091 Mdot
.67181 .3351 Mdot
.42525 .44731 Mdot
.1742 .48759 Mdot
.43379 .7603 Mdot
.54596 .67481 Mdot
.63105 .53947 Mdot
.48179 .19321 Mdot
.3953 .42746 Mdot
.50457 .68467 Mdot
.44147 .42369 Mdot
.60802 .59402 Mdot
.45109 .48633 Mdot
.62274 .35847 Mdot
.44612 .3761 Mdot
.66281 .32757 Mdot
.54361 .1293 Mdot
.60707 .33875 Mdot
.35926 .54976 Mdot
.66916 .5862 Mdot
.66434 .55997 Mdot
.35519 .5717 Mdot
.65984 .56145 Mdot
.27184 .41583 Mdot
.32928 .44376 Mdot
.63077 .37565 Mdot
.51017 .40736 Mdot
.62115 .36775 Mdot
.66827 .50196 Mdot
.40146 .41464 Mdot
.643 .82265 Mdot
.64011 .5629 Mdot
.539 .18284 Mdot
.52579 .66599 Mdot
.69006 .55311 Mdot
.47782 .39931 Mdot
.60759 .65338 Mdot
.66671 .56914 Mdot
.70967 .66163 Mdot
.45028 .43464 Mdot
.32288 .59983 Mdot
.46612 .38905 Mdot
.49068 .40411 Mdot
.67578 .57546 Mdot
.417 .38602 Mdot
.54147 .69609 Mdot
.32597 .56499 Mdot
.83156 .44332 Mdot
.38633 .76631 Mdot
.41683 .45457 Mdot
.42714 .40916 Mdot
.30581 .63404 Mdot
.46158 .45635 Mdot
.54525 .65092 Mdot
.19763 .71846 Mdot
.62917 .37294 Mdot
.64839 .58132 Mdot
.68976 .34285 Mdot
.48283 .44239 Mdot
.42549 .37345 Mdot
.7869 .69473 Mdot
.67257 .29416 Mdot
.55021 .69286 Mdot
.40044 .36464 Mdot
.65628 .57097 Mdot
.59998 .37319 Mdot
.53541 .6372 Mdot
.44692 .39934 Mdot
.41894 .42738 Mdot
.59057 .38953 Mdot
.46748 .31337 Mdot
.35465 .25177 Mdot
.51482 .69722 Mdot
.37302 .45248 Mdot
.70603 .55199 Mdot
.41223 .46164 Mdot
.29224 .29996 Mdot
.35624 .57663 Mdot
.52041 .64196 Mdot
.7832 .44301 Mdot
.39293 .42462 Mdot
.54497 .70046 Mdot
.52073 .68128 Mdot
.41411 .3593 Mdot
.38666 .59051 Mdot
.31255 .57657 Mdot
.32723 .57555 Mdot
.14809 .56782 Mdot
.56144 .28947 Mdot
.6409 .51381 Mdot
.50873 .67384 Mdot
.61529 .5438 Mdot
.65857 .3555 Mdot
.56226 .56085 Mdot
.61693 .54398 Mdot
.32265 .57506 Mdot
.65257 .58885 Mdot
.46413 .42329 Mdot
.52422 .68085 Mdot
.63302 .52403 Mdot
.49282 .41902 Mdot
.47207 .71703 Mdot
.58043 .75903 Mdot
.63122 .38998 Mdot
.6355 .34627 Mdot
.47672 .40823 Mdot
.61297 .52702 Mdot
.41339 .42885 Mdot
.49899 .6521 Mdot
.46356 .70859 Mdot
.4784 .38274 Mdot
.66189 .55606 Mdot
.31693 .63762 Mdot
.47055 .19833 Mdot
.37582 .43193 Mdot
.43192 .43607 Mdot
.41763 .38974 Mdot
.44195 .42352 Mdot
.76571 .62603 Mdot
.49834 .69178 Mdot
.40689 .78065 Mdot
.72184 .35467 Mdot
.35368 .60682 Mdot
.31852 .63085 Mdot
.41683 .2138 Mdot
.3974 .67035 Mdot
.51245 .67491 Mdot
.43497 .38919 Mdot
.39082 .72786 Mdot
.83019 .58687 Mdot
.72222 .76194 Mdot
.54053 .43692 Mdot
.68862 .52008 Mdot
.35634 .55726 Mdot
.63307 .56678 Mdot
.41632 .39715 Mdot
.48932 .37046 Mdot
.69857 .24182 Mdot
.52133 .63032 Mdot
.63281 .37171 Mdot
.42264 .38605 Mdot
.56302 .29363 Mdot
.64072 .54025 Mdot
.6871 .56375 Mdot
.45253 .45786 Mdot
.35898 .62758 Mdot
.50781 .14368 Mdot
.54513 .66671 Mdot
.5229 .77622 Mdot
.31298 .70071 Mdot
.48592 .76679 Mdot
.54115 .66963 Mdot
.55428 .42247 Mdot
.6572 .49847 Mdot
.32725 .33048 Mdot
.35937 .60464 Mdot
.61837 .35097 Mdot
.48141 .46027 Mdot
.37 .5791 Mdot
.66566 .51043 Mdot
.32331 .60333 Mdot
.42865 .37079 Mdot
.4915 .65437 Mdot
.64415 .53182 Mdot
.48666 .63407 Mdot
.38251 .60695 Mdot
.59346 .37577 Mdot
.47836 .52692 Mdot
.30178 .54487 Mdot
.27269 .46474 Mdot
.44665 .4619 Mdot
.51078 .57582 Mdot
.46481 .40214 Mdot
.29431 .62153 Mdot
.43558 .41481 Mdot
.27442 .59381 Mdot
.63393 .53264 Mdot
.4774 .39164 Mdot
.44605 .38939 Mdot
.32806 .76029 Mdot
.43643 .45094 Mdot
.38277 .4323 Mdot
.43937 .4009 Mdot
.35233 .54182 Mdot
.51054 .40235 Mdot
.30116 .60383 Mdot
.6856 .47356 Mdot
.65666 .54364 Mdot
.64452 .35621 Mdot
.58702 .39046 Mdot
.58777 .27515 Mdot
.75723 .43272 Mdot
.6816 .7109 Mdot
.32277 .58772 Mdot
.52811 .69497 Mdot
.43897 .41734 Mdot
.73553 .30768 Mdot
.60232 .47607 Mdot
.68989 .53961 Mdot
.38977 .76757 Mdot
.37577 .46549 Mdot
.67102 .26439 Mdot
.3948 .37279 Mdot
.1568 .55954 Mdot
.36405 .40012 Mdot
.43904 .4862 Mdot
.62507 .57 Mdot
.65769 .33535 Mdot
.47044 .44692 Mdot
.30015 .58227 Mdot
.61295 .35571 Mdot
.455 .32487 Mdot
.71672 .53546 Mdot
.6985 .48596 Mdot
.31557 .54678 Mdot
.45542 .42188 Mdot
.64551 .53133 Mdot
.31348 .61774 Mdot
.43981 .19774 Mdot
.55025 .67701 Mdot
.47609 .65778 Mdot
.42493 .63644 Mdot
.6256 .80688 Mdot
.5955 .36078 Mdot
.31025 .33364 Mdot
.46314 .43443 Mdot
.74605 .54338 Mdot
.47341 .37674 Mdot
.80834 .61586 Mdot
.58725 .36751 Mdot
.32446 .57179 Mdot
.53284 .70002 Mdot
.31014 .62434 Mdot
.2651 .47038 Mdot
.65042 .48581 Mdot
.52509 .54083 Mdot
.64419 .54868 Mdot
.58627 .45698 Mdot
.34372 .58492 Mdot
.40815 .38558 Mdot
.19631 .31961 Mdot
.35275 .57494 Mdot
.37587 .57295 Mdot
.45302 .82974 Mdot
.60765 .83904 Mdot
.38613 .46577 Mdot
.35371 .5612 Mdot
.64879 .55085 Mdot
.60798 .36417 Mdot
.4594 .38002 Mdot
.45768 .42603 Mdot
.36929 .58002 Mdot
.66986 .57774 Mdot
.22405 .5164 Mdot
.66853 .53292 Mdot
.31555 .58387 Mdot
.66018 .53301 Mdot
.6065 .63745 Mdot
.62301 .54367 Mdot
.47819 .43944 Mdot
.43653 .41538 Mdot
.72496 .40118 Mdot
.32961 .60366 Mdot
.45055 .39241 Mdot
.40985 .36734 Mdot
.34609 .59579 Mdot
.5862 .43091 Mdot
.2289 .50833 Mdot
.4114 .45599 Mdot
.44533 .44336 Mdot
.60286 .39664 Mdot
.54486 .5767 Mdot
.30137 .32475 Mdot
.43001 .37271 Mdot
.58052 .38421 Mdot
.30245 .58067 Mdot
.41616 .4386 Mdot
.82731 .54941 Mdot
.66696 .64934 Mdot
.39754 .41129 Mdot
.6259 .56565 Mdot
.39447 .37016 Mdot
.61034 .19644 Mdot
.46428 .45009 Mdot
.33832 .59105 Mdot
.32895 .61519 Mdot
.27142 .7164 Mdot
.35648 .58696 Mdot
.68197 .55582 Mdot
.53749 .6689 Mdot
.76692 .65727 Mdot
.65097 .5706 Mdot
.36842 .39548 Mdot
.29631 .76117 Mdot
.39867 .38652 Mdot
.48777 .4256 Mdot
.5483 .167 Mdot
.63547 .5654 Mdot
.34773 .62056 Mdot
.50321 .50317 Mdot
.38728 .35698 Mdot
.51634 .64345 Mdot
.49369 .44946 Mdot
.44229 .46709 Mdot
.56924 .19094 Mdot
.76447 .60178 Mdot
.4982 .67117 Mdot
.38944 .44189 Mdot
.42861 .37263 Mdot
.69247 .51539 Mdot
.43105 .40676 Mdot
.61149 .36209 Mdot
.34551 .61805 Mdot
.62474 .5496 Mdot
.61368 .38262 Mdot
.39915 .42992 Mdot
.62459 .38797 Mdot
.64271 .51875 Mdot
.5005 .66989 Mdot
.40845 .40449 Mdot
.62322 .39857 Mdot
.62537 .38673 Mdot
.46244 .39981 Mdot
.32057 .60551 Mdot
.35996 .43111 Mdot
.43215 .45289 Mdot
.44801 .37287 Mdot
.37082 .59126 Mdot
.87815 .57393 Mdot
.47625 .42819 Mdot
.6217 .29229 Mdot
.37724 .58888 Mdot
.58912 .44647 Mdot
.63476 .57036 Mdot
.44627 .46602 Mdot
.49973 .66756 Mdot
.50809 .68369 Mdot
.66011 .50571 Mdot
.37215 .56158 Mdot
.68167 .40805 Mdot
.38814 .6097 Mdot
.42986 .34411 Mdot
.40555 .45995 Mdot
.236 .60501 Mdot
.78987 .35659 Mdot
.34574 .62591 Mdot
.70978 .58268 Mdot
.44576 .53704 Mdot
.51495 .69238 Mdot
.68576 .5592 Mdot
.35538 .55562 Mdot
.36902 .60557 Mdot
.31247 .60032 Mdot
.62606 .35093 Mdot
.72849 .40395 Mdot
.37305 .61213 Mdot
.34253 .63379 Mdot
.45448 .43298 Mdot
.43145 .37363 Mdot
.47997 .20509 Mdot
.41178 .25178 Mdot
.63503 .38348 Mdot
.66494 .51359 Mdot
.12954 .54833 Mdot
.5019 .64721 Mdot
.37572 .78294 Mdot
.48751 .40881 Mdot
.10384 .43659 Mdot
.4725 .39026 Mdot
.42831 .40376 Mdot
.32598 .56469 Mdot
.63001 .39354 Mdot
.62504 .3691 Mdot
.34396 .57793 Mdot
.32717 .63408 Mdot
.61303 .36201 Mdot
.58812 .79039 Mdot
.83871 .55065 Mdot
.60741 .49065 Mdot
.34518 .60086 Mdot
.3269 .52626 Mdot
.51833 .7013 Mdot
.45865 .33287 Mdot
.49688 .64957 Mdot
.64698 .54229 Mdot
.64036 .49978 Mdot
.52209 .64423 Mdot
.44858 .43415 Mdot
.63445 .51692 Mdot
.39091 .40929 Mdot
.51728 .79239 Mdot
.26994 .50702 Mdot
.69931 .379 Mdot
.52517 .39884 Mdot
.57769 .43605 Mdot
.49326 .62328 Mdot
.40659 .43564 Mdot
.80841 .51988 Mdot
.63251 .37681 Mdot
.47915 .35025 Mdot
.51707 .64057 Mdot
.58144 .1668 Mdot
.40393 .40771 Mdot
.33578 .5928 Mdot
.51639 .68051 Mdot
.40697 .61232 Mdot
.44866 .6932 Mdot
.4194 .38917 Mdot
.13995 .39656 Mdot
.35926 .5443 Mdot
.62632 .54046 Mdot
.19219 .55331 Mdot
.35334 .62565 Mdot
.57508 .35246 Mdot
.75137 .3872 Mdot
.688 .77108 Mdot
.33077 .62382 Mdot
.68239 .50995 Mdot
.30183 .59499 Mdot
.59423 .37257 Mdot
.3294 .55587 Mdot
.6374 .53634 Mdot
.42603 .44445 Mdot
.66889 .54679 Mdot
.63787 .35513 Mdot
.35752 .2543 Mdot
.49879 .67317 Mdot
.64872 .57713 Mdot
.52149 .65275 Mdot
.51596 .31279 Mdot
.70276 .32259 Mdot
.55326 .66927 Mdot
.21968 .44063 Mdot
.41228 .46529 Mdot
.35681 .6254 Mdot
.67184 .54854 Mdot
.77433 .4959 Mdot
.47462 .52608 Mdot
.36265 .59906 Mdot
.65339 .50919 Mdot
.43764 .62787 Mdot
.18841 .50411 Mdot
.37957 .42665 Mdot
.46166 .2874 Mdot
.34895 .59946 Mdot
.66754 .49908 Mdot
.37478 .21633 Mdot
.30069 .59375 Mdot
.6686 .56305 Mdot
.53665 .70124 Mdot
.53488 .6802 Mdot
.43857 .45915 Mdot
.49453 .63334 Mdot
.64111 .50641 Mdot
.46797 .69492 Mdot
.35678 .56047 Mdot
.38516 .63979 Mdot
.6243 .40002 Mdot
.66227 .54243 Mdot
.41553 .37009 Mdot
.28514 .58666 Mdot
.64294 .64285 Mdot
.23105 .53596 Mdot
.19485 .36089 Mdot
.67122 .5416 Mdot
.35625 .61276 Mdot
.3336 .59451 Mdot
.37336 .42478 Mdot
.43316 .58562 Mdot
.68518 .40879 Mdot
.4911 .4939 Mdot
.46679 .50955 Mdot
.60979 .55247 Mdot
.64884 .47707 Mdot
.49729 .40703 Mdot
.45095 .4207 Mdot
.51861 .69471 Mdot
.4294 .44433 Mdot
.33596 .56273 Mdot
.44905 .45979 Mdot
.53939 .65763 Mdot
.63974 .551 Mdot
.40643 .40876 Mdot
.61393 .39298 Mdot
.52202 .7054 Mdot
.54518 .63734 Mdot
.66203 .54991 Mdot
.37088 .5812 Mdot
.60907 .43246 Mdot
.66849 .5272 Mdot
.45475 .42278 Mdot
.55085 .58515 Mdot
.4324 .36817 Mdot
.35851 .35996 Mdot
.2988 .59643 Mdot
.62655 .55234 Mdot
.33903 .5577 Mdot
.52058 .65788 Mdot
.72774 .36056 Mdot
.43414 .42503 Mdot
.66194 .56653 Mdot
.67666 .61105 Mdot
.395 .31394 Mdot
.34846 .63499 Mdot
.61452 .75532 Mdot
.3085 .62816 Mdot
.67152 .51743 Mdot
.3589 .78886 Mdot
.60512 .35369 Mdot
.69022 .54015 Mdot
.82513 .41652 Mdot
.64802 .56219 Mdot
.44903 .45239 Mdot
.47599 .41114 Mdot
.62431 .54633 Mdot
.59309 .39391 Mdot
.47871 .18345 Mdot
.61778 .57508 Mdot
.34266 .62175 Mdot
.51949 .8029 Mdot
.26816 .27474 Mdot
.52138 .71756 Mdot
.52194 .69504 Mdot
.36246 .39639 Mdot
.40005 .4668 Mdot
.51836 .63676 Mdot
.5221 .62567 Mdot
.62204 .34665 Mdot
.67674 .5481 Mdot
.29429 .57 Mdot
.56481 .6685 Mdot
.39437 .53451 Mdot
.74954 .42488 Mdot
.37803 .43632 Mdot
.3243 .70796 Mdot
.48237 .39544 Mdot
.60498 .3182 Mdot
.53929 .65627 Mdot
.43587 .36219 Mdot
.37806 .39843 Mdot
.50165 .65562 Mdot
.60765 .36248 Mdot
.51642 .60494 Mdot
.65597 .5309 Mdot
.86786 .53005 Mdot
.3883 .39996 Mdot
.45435 .45215 Mdot
.50577 .66304 Mdot
.68753 .45228 Mdot
.35031 .61099 Mdot
.29873 .61948 Mdot
.62265 .53272 Mdot
.45923 .54643 Mdot
.43374 .4656 Mdot
.41381 .44185 Mdot
.64972 .52707 Mdot
.67897 .56459 Mdot
.65747 .71447 Mdot
.47091 .41628 Mdot
.51747 .67244 Mdot
.66302 .36279 Mdot
.53685 .65321 Mdot
.42766 .3684 Mdot
.45883 .44758 Mdot
.47744 .44122 Mdot
.41722 .37008 Mdot
.51643 .62645 Mdot
.45217 .3663 Mdot
.49567 .37436 Mdot
.36031 .60779 Mdot
.42659 .38005 Mdot
.47555 .50583 Mdot
.43583 .44097 Mdot
.60975 .36365 Mdot
.2791 .34502 Mdot
.40441 .40747 Mdot
.44373 .46515 Mdot
.64633 .5843 Mdot
.42423 .42676 Mdot
.4998 .64979 Mdot
.33833 .60553 Mdot
.50888 .67178 Mdot
.50646 .68235 Mdot
.62452 .51114 Mdot
.59725 .34895 Mdot
.48123 .44608 Mdot
.634 .35785 Mdot
.37747 .37682 Mdot
.39254 .42449 Mdot
.73863 .3833 Mdot
.16104 .57364 Mdot
.32344 .27317 Mdot
.43548 .42616 Mdot
.63684 .56413 Mdot
.63062 .56613 Mdot
.45028 .31774 Mdot
.37964 .42101 Mdot
.54561 .64794 Mdot
.51069 .68887 Mdot
.45436 .23822 Mdot
.61578 .23127 Mdot
.60931 .36325 Mdot
.53673 .56443 Mdot
.38807 .43186 Mdot
.42697 .36532 Mdot
.39499 .38583 Mdot
.61645 .53844 Mdot
.53583 .43688 Mdot
.68874 .54974 Mdot
.44171 .7687 Mdot
.51557 .64802 Mdot
.41119 .39748 Mdot
.34803 .73173 Mdot
.3456 .56924 Mdot
.33723 .60507 Mdot
.5522 .64489 Mdot
.70074 .51523 Mdot
.44585 .21465 Mdot
.7157 .77334 Mdot
.36901 .54947 Mdot
.6446 .37657 Mdot
.40672 .44083 Mdot
.64424 .55575 Mdot
.31537 .58144 Mdot
.6447 .37386 Mdot
.40499 .39284 Mdot
.72959 .40399 Mdot
.44007 .42901 Mdot
.37218 .68063 Mdot
.3145 .60941 Mdot
.81848 .60145 Mdot
.37618 .56519 Mdot
.52457 .70678 Mdot
.53133 .64324 Mdot
.47231 .42692 Mdot
.21912 .59191 Mdot
.33391 .63129 Mdot
.56656 .60023 Mdot
.59269 .35663 Mdot
.62436 .64712 Mdot
.59807 .36617 Mdot
.62881 .53757 Mdot
.60759 .35581 Mdot
.63636 .53432 Mdot
.41121 .24058 Mdot
.36979 .53946 Mdot
.62262 .38106 Mdot
.6481 .61267 Mdot
.39362 .46416 Mdot
.63014 .38844 Mdot
.47563 .36104 Mdot
.367 .34658 Mdot
.65265 .52563 Mdot
.5914 .36419 Mdot
.40829 .38327 Mdot
.70273 .25913 Mdot
.55431 .68721 Mdot
.54149 .64563 Mdot
.46716 .35785 Mdot
.60921 .54391 Mdot
.31431 .56853 Mdot
.79358 .61016 Mdot
.56156 .70537 Mdot
.47526 .42646 Mdot
.4669 .45111 Mdot
.32219 .63196 Mdot
.32713 .7398 Mdot
.46717 .43563 Mdot
.41708 .50039 Mdot
.47215 .41661 Mdot
.55919 .6782 Mdot
.31182 .62446 Mdot
.33469 .59887 Mdot
.64825 .50945 Mdot
.35649 .5668 Mdot
.44486 .30982 Mdot
.37657 .74023 Mdot
.38994 .49014 Mdot
.52635 .6588 Mdot
.41669 .75682 Mdot
.43926 .77005 Mdot
.80148 .38668 Mdot
.37914 .61558 Mdot
.47369 .37851 Mdot
.37008 .57188 Mdot
.60072 .37044 Mdot
.32326 .59821 Mdot
.35519 .5572 Mdot
.41043 .42922 Mdot
.42087 .39164 Mdot
.63302 .54816 Mdot
.4333 .57113 Mdot
.37461 .58484 Mdot
.47054 .38855 Mdot
.40896 .47365 Mdot
.39396 .39773 Mdot
.58477 .59957 Mdot
.33669 .62747 Mdot
.51327 .8336 Mdot
.53685 .23553 Mdot
.37409 .58449 Mdot
.52236 .14404 Mdot
.6675 .61755 Mdot
.6269 .49617 Mdot
.47844 .63763 Mdot
.47195 .40994 Mdot
.65799 .57306 Mdot
.41562 .39789 Mdot
.32639 .70807 Mdot
.41857 .42217 Mdot
.61214 .36062 Mdot
.38869 .41152 Mdot
.65202 .50019 Mdot
.66979 .53409 Mdot
.47071 .43926 Mdot
.4086 .40865 Mdot
.38004 .23932 Mdot
.39563 .57786 Mdot
.33394 .60875 Mdot
.6728 .41424 Mdot
.6131 .38748 Mdot
.51941 .64242 Mdot
.43687 .40654 Mdot
.62015 .51956 Mdot
.67034 .53733 Mdot
.34219 .6283 Mdot
.65868 .51622 Mdot
.54482 .66775 Mdot
.43296 .42065 Mdot
.52245 .63693 Mdot
.62388 .34958 Mdot
.32128 .62687 Mdot
.42338 .3835 Mdot
.45418 .43338 Mdot
.32886 .61537 Mdot
.49455 .42373 Mdot
.59929 .39537 Mdot
.65225 .56275 Mdot
.3242 .62384 Mdot
.53704 .67211 Mdot
.63041 .53721 Mdot
.45084 .37179 Mdot
.13834 .48285 Mdot
.44694 .45066 Mdot
.46918 .39588 Mdot
.82387 .3955 Mdot
.38626 .42512 Mdot
.6721 .54387 Mdot
.32021 .57501 Mdot
.52123 .41309 Mdot
.57015 .26597 Mdot
.8427 .65257 Mdot
.68934 .54119 Mdot
.40986 .44518 Mdot
.74946 .32229 Mdot
.41688 .44826 Mdot
.24795 .58432 Mdot
.59836 .54512 Mdot
.55904 .47037 Mdot
.4639 .36059 Mdot
.54007 .68744 Mdot
.63196 .55206 Mdot
.63678 .52978 Mdot
.48613 .81184 Mdot
.41103 .43379 Mdot
.49055 .59697 Mdot
.41431 .38188 Mdot
.53944 .67534 Mdot
.48323 .23583 Mdot
.6712 .53477 Mdot
.22307 .34471 Mdot
.46614 .40501 Mdot
.36723 .61021 Mdot
.65447 .58943 Mdot
.59645 .64597 Mdot
.45073 .3743 Mdot
.63727 .3688 Mdot
.56985 .68474 Mdot
.47533 .4729 Mdot
.53107 .65999 Mdot
.44458 .37202 Mdot
.48291 .48697 Mdot
.18994 .5679 Mdot
.31623 .60286 Mdot
.53054 .69995 Mdot
.56864 .58092 Mdot
.459 .36757 Mdot
.32819 .62366 Mdot
.36106 .60316 Mdot
.63124 .35116 Mdot
.55343 .52889 Mdot
.42859 .67014 Mdot
.2863 .52832 Mdot
.506 .80689 Mdot
.65747 .58704 Mdot
.72496 .64188 Mdot
.45791 .38668 Mdot
.6678 .38384 Mdot
.49802 .65919 Mdot
.44329 .45328 Mdot
.30757 .34997 Mdot
.3428 .57328 Mdot
.45126 .44378 Mdot
.61998 .36666 Mdot
.65058 .4249 Mdot
.66562 .37866 Mdot
.75754 .38124 Mdot
.64513 .54725 Mdot
.48605 .36473 Mdot
.48923 .47869 Mdot
.62533 .56813 Mdot
.44957 .46738 Mdot
.66502 .56236 Mdot
.6047 .79854 Mdot
.63345 .3877 Mdot
.34475 .62443 Mdot
.6018 .6158 Mdot
.46986 .45748 Mdot
.41652 .47067 Mdot
.61207 .34147 Mdot
.45285 .41613 Mdot
.17201 .54737 Mdot
.5932 .6001 Mdot
.63058 .5247 Mdot
.3133 .60084 Mdot
.45758 .46149 Mdot
.56352 .54136 Mdot
.42714 .45145 Mdot
.31982 .45975 Mdot
.44556 .46453 Mdot
.43979 .67145 Mdot
.32025 .60978 Mdot
.52858 .65604 Mdot
.45336 .36221 Mdot
.42076 .41487 Mdot
.61557 .26518 Mdot
.36909 .38432 Mdot
.44608 .3622 Mdot
.29672 .63531 Mdot
.31161 .58368 Mdot
.3025 .59972 Mdot
.67402 .51108 Mdot
.58896 .20692 Mdot
.5171 .66597 Mdot
.5185 .39246 Mdot
.56379 .67562 Mdot
.2171 .54554 Mdot
.64343 .37761 Mdot
.76395 .36037 Mdot
.4429 .39409 Mdot
.32151 .58418 Mdot
.78159 .56586 Mdot
.29228 .59732 Mdot
.51995 .56327 Mdot
.52223 .68171 Mdot
.34913 .57639 Mdot
.42439 .40714 Mdot
.45854 .53193 Mdot
.71569 .29471 Mdot
.51224 .66172 Mdot
.36754 .40108 Mdot
.68003 .51265 Mdot
.70304 .36388 Mdot
.15603 .44624 Mdot
.55506 .68674 Mdot
.48437 .67353 Mdot
.41004 .43516 Mdot
.34293 .56784 Mdot
.5423 .68317 Mdot
.55686 .66915 Mdot
.65622 .51481 Mdot
.42384 .38859 Mdot
.42842 .38582 Mdot
.67318 .51715 Mdot
.50777 .66947 Mdot
.45504 .35304 Mdot
.45231 .48634 Mdot
.6685 .21001 Mdot
.42946 .62395 Mdot
.87268 .53438 Mdot
.46336 .31841 Mdot
.28174 .36833 Mdot
.79585 .61704 Mdot
.37515 .59724 Mdot
.3971 .41942 Mdot
.45364 .47941 Mdot
.64222 .50597 Mdot
.42889 .43396 Mdot
.60803 .50881 Mdot
.51547 .68515 Mdot
.57379 .16922 Mdot
.42438 .73628 Mdot
.64868 .78489 Mdot
.42703 .4342 Mdot
.27156 .59776 Mdot
.60713 .37606 Mdot
.51511 .70977 Mdot
.30089 .61359 Mdot
.40894 .37524 Mdot
.37625 .24078 Mdot
.68983 .54545 Mdot
.36438 .58502 Mdot
.43979 .19988 Mdot
.56291 .4318 Mdot
.4299 .36909 Mdot
.68385 .52363 Mdot
.8012 .54668 Mdot
.40297 .58581 Mdot
.55548 .71078 Mdot
.60793 .36112 Mdot
.63026 .5547 Mdot
.50966 .68934 Mdot
.28187 .58598 Mdot
.35348 .58165 Mdot
.30985 .56972 Mdot
.30948 .29689 Mdot
.64297 .57956 Mdot
.61056 .37819 Mdot
.64998 .2617 Mdot
.61817 .24683 Mdot
.61561 .36098 Mdot
.64344 .49856 Mdot
.31262 .58314 Mdot
.33756 .57864 Mdot
.3391 .60546 Mdot
.28062 .29479 Mdot
.38076 .5845 Mdot
.41304 .8006 Mdot
.39879 .39081 Mdot
.41266 .49619 Mdot
.41134 .44478 Mdot
.53753 .6419 Mdot
.32151 .61668 Mdot
.49327 .51757 Mdot
.38151 .37854 Mdot
.71861 .322 Mdot
.44351 .45651 Mdot
.49132 .67709 Mdot
.45818 .43634 Mdot
.27262 .69032 Mdot
.37295 .57536 Mdot
.43306 .42922 Mdot
.49472 .67612 Mdot
.60548 .3884 Mdot
.34009 .63737 Mdot
.41802 .38946 Mdot
.65547 .7395 Mdot
.38677 .41965 Mdot
.65445 .77408 Mdot
.38283 .64818 Mdot
.64426 .37715 Mdot
.32249 .68396 Mdot
.696 .53872 Mdot
.4298 .49716 Mdot
.40423 .34642 Mdot
.51678 .6556 Mdot
.62393 .63073 Mdot
.65532 .54565 Mdot
.53979 .43453 Mdot
.50408 .43363 Mdot
.64 .35441 Mdot
.3955 .56141 Mdot
.51713 .63594 Mdot
.43935 .47129 Mdot
.37534 .41548 Mdot
.4712 .79199 Mdot
.50523 .39956 Mdot
.45798 .4577 Mdot
.63051 .34147 Mdot
.40582 .79134 Mdot
.43967 .43915 Mdot
.52906 .56107 Mdot
.33908 .55235 Mdot
.42205 .34577 Mdot
.39505 .7953 Mdot
.4765 .40854 Mdot
.36085 .57892 Mdot
.36159 .47854 Mdot
.41644 .65896 Mdot
.5941 .35214 Mdot
.4425 .46611 Mdot
.27646 .72386 Mdot
.4636 .41235 Mdot
.5203 .66968 Mdot
.38194 .42862 Mdot
.63944 .53807 Mdot
.32545 .26546 Mdot
.63974 .51075 Mdot
.4212 .4621 Mdot
.34271 .60465 Mdot
.50752 .65607 Mdot
.24463 .33704 Mdot
.71054 .41328 Mdot
.38515 .78236 Mdot
.74158 .73232 Mdot
.59001 .37001 Mdot
.57422 .37235 Mdot
.50986 .63796 Mdot
.43424 .43055 Mdot
.40551 .81637 Mdot
.36319 .40173 Mdot
.44715 .44253 Mdot
.41762 .42116 Mdot
.69248 .31909 Mdot
.51215 .68602 Mdot
.65984 .52506 Mdot
.46374 .44115 Mdot
.44973 .36459 Mdot
.374 .59881 Mdot
.61646 .38946 Mdot
.63436 .56994 Mdot
.63057 .37324 Mdot
.63612 .55479 Mdot
.54341 .15274 Mdot
.40445 .36414 Mdot
.6019 .38522 Mdot
.56767 .67214 Mdot
.36992 .58422 Mdot
.37746 .73597 Mdot
.63221 .53279 Mdot
.65833 .50686 Mdot
.46308 .44933 Mdot
.36022 .57637 Mdot
.33091 .56145 Mdot
.59813 .37281 Mdot
.55049 .66793 Mdot
.40408 .40861 Mdot
.39166 .43044 Mdot
.36267 .49806 Mdot
.61285 .534 Mdot
.36104 .68627 Mdot
.72093 .66496 Mdot
.43611 .42855 Mdot
.35417 .56029 Mdot
.4097 .4151 Mdot
.7511 .66387 Mdot
.34969 .56738 Mdot
.47667 .40284 Mdot
.46645 .16578 Mdot
.69677 .5055 Mdot
.40319 .68772 Mdot
.47661 .43822 Mdot
.78816 .67041 Mdot
.45141 .38837 Mdot
.59971 .1631 Mdot
.75858 .52269 Mdot
.41267 .46266 Mdot
.45874 .37666 Mdot
.2477 .51297 Mdot
.40114 .44015 Mdot
.6694 .51385 Mdot
.5166 .19383 Mdot
.29931 .58213 Mdot
.53779 .75985 Mdot
.2877 .34209 Mdot
.58791 .36706 Mdot
.62253 .53341 Mdot
.63929 .47994 Mdot
.62531 .36227 Mdot
.34411 .59865 Mdot
.44204 .42327 Mdot
.48443 .54631 Mdot
.61233 .54807 Mdot
.49711 .34305 Mdot
.52192 .67156 Mdot
.65238 .67439 Mdot
.58637 .49894 Mdot
.53638 .66201 Mdot
.42999 .37853 Mdot
.23879 .51338 Mdot
.3587 .28753 Mdot
.84595 .52764 Mdot
.5097 .69117 Mdot
.51111 .66016 Mdot
.30318 .2754 Mdot
.64661 .38352 Mdot
.49796 .78864 Mdot
.44396 .68056 Mdot
.51196 .64627 Mdot
.39221 .62388 Mdot
.68556 .54248 Mdot
.51611 .61876 Mdot
.48937 .36157 Mdot
.39287 .4139 Mdot
.42338 .40963 Mdot
.54792 .66123 Mdot
.40388 .31329 Mdot
.18607 .54256 Mdot
.52195 .65129 Mdot
.38244 .35173 Mdot
.5459 .50241 Mdot
.72854 .58827 Mdot
.67185 .52372 Mdot
.59959 .34942 Mdot
.58054 .40014 Mdot
.36201 .61263 Mdot
.59836 .34914 Mdot
.65655 .41631 Mdot
.44831 .41125 Mdot
.52941 .64906 Mdot
.63527 .643 Mdot
.5337 .67596 Mdot
.62624 .36527 Mdot
.64853 .35892 Mdot
.35956 .60815 Mdot
.32917 .60545 Mdot
.2609 .40702 Mdot
.48759 .26351 Mdot
.43155 .45516 Mdot
.78296 .46139 Mdot
.34903 .55702 Mdot
.50377 .34662 Mdot
.60285 .34662 Mdot
.61051 .3888 Mdot
.62257 .27573 Mdot
.43785 .39527 Mdot
.24986 .61897 Mdot
.43695 .39967 Mdot
.48471 .24211 Mdot
.48592 .40779 Mdot
.65727 .5151 Mdot
.43692 .3889 Mdot
.64019 .27995 Mdot
.47562 .45732 Mdot
.3932 .46051 Mdot
.61701 .5316 Mdot
.48807 .46216 Mdot
.64155 .53746 Mdot
.42409 .46009 Mdot
.59916 .40227 Mdot
.62623 .51984 Mdot
.56678 .28208 Mdot
.63273 .28717 Mdot
.64894 .49705 Mdot
.63844 .35834 Mdot
.58357 .38336 Mdot
.5786 .30675 Mdot
.30071 .61374 Mdot
.40636 .339 Mdot
.43254 .43327 Mdot
.68137 .56578 Mdot
.51608 .69086 Mdot
.46405 .37808 Mdot
.41075 .47301 Mdot
.4824 .41565 Mdot
.36206 .61333 Mdot
.68919 .40464 Mdot
.59754 .38028 Mdot
.67831 .52108 Mdot
.60949 .43579 Mdot
.60775 .5458 Mdot
.37998 .43152 Mdot
.46207 .47373 Mdot
.29907 .34489 Mdot
.71456 .61234 Mdot
.28008 .28588 Mdot
.35549 .58236 Mdot
.62626 .56513 Mdot
.6139 .403 Mdot
.42881 .48723 Mdot
.3214 .5816 Mdot
.63802 .53639 Mdot
.43977 .42817 Mdot
.36553 .41116 Mdot
.40808 .76802 Mdot
.45811 .30471 Mdot
.60474 .28599 Mdot
.65946 .50494 Mdot
.69213 .52616 Mdot
.66219 .29928 Mdot
.62311 .33043 Mdot
.47859 .52481 Mdot
.41919 .44034 Mdot
.63638 .36797 Mdot
.31667 .58052 Mdot
.32227 .29598 Mdot
.54418 .65228 Mdot
.43294 .57836 Mdot
.42764 .43232 Mdot
.57168 .45066 Mdot
.34459 .6058 Mdot
.61707 .36572 Mdot
.54655 .65895 Mdot
.56865 .37676 Mdot
.61786 .55103 Mdot
.65271 .80194 Mdot
.46003 .41504 Mdot
.45671 .45538 Mdot
.50868 .69818 Mdot
.33312 .57421 Mdot
.59695 .34656 Mdot
.5291 .79985 Mdot
.64082 .52164 Mdot
.38399 .80691 Mdot
.34911 .56151 Mdot
.34752 .52454 Mdot
.68089 .53109 Mdot
.55579 .65178 Mdot
.56535 .29911 Mdot
.54143 .66215 Mdot
.4305 .46363 Mdot
.32601 .59033 Mdot
.53295 .69788 Mdot
.42552 .58862 Mdot
.7405 .30767 Mdot
.33313 .52726 Mdot
.44311 .41125 Mdot
.66614 .22988 Mdot
.64356 .76526 Mdot
.39343 .56962 Mdot
.49967 .67249 Mdot
.44205 .45522 Mdot
.42553 .47103 Mdot
.4639 .41524 Mdot
.52692 .69223 Mdot
.77097 .43936 Mdot
.65003 .5245 Mdot
.41002 .43976 Mdot
.62348 .34709 Mdot
.64796 .53962 Mdot
.60017 .61972 Mdot
.67064 .52527 Mdot
.38446 .60749 Mdot
.38263 .43895 Mdot
.58712 .67768 Mdot
.51545 .1242 Mdot
.51009 .66792 Mdot
.63258 .5015 Mdot
.39967 .37136 Mdot
.66799 .63935 Mdot
.30562 .59416 Mdot
.64106 .51967 Mdot
.45311 .45277 Mdot
.60405 .61175 Mdot
.34471 .26202 Mdot
.67117 .52867 Mdot
.32131 .5799 Mdot
.83992 .51261 Mdot
.42888 .44057 Mdot
.45562 .39474 Mdot
.3457 .58015 Mdot
.20427 .47033 Mdot
.39098 .21106 Mdot
.40901 .41083 Mdot
.52941 .65519 Mdot
.54158 .85426 Mdot
.40328 .47101 Mdot
.52702 .22559 Mdot
.63152 .5496 Mdot
.54752 .61704 Mdot
.39901 .6571 Mdot
.42589 .48646 Mdot
.51553 .79056 Mdot
.48111 .66296 Mdot
.66567 .24784 Mdot
.60654 .51354 Mdot
.73151 .52368 Mdot
.62108 .20545 Mdot
.49223 .66614 Mdot
.37498 .52662 Mdot
.53603 .78139 Mdot
.19468 .41454 Mdot
.82459 .53723 Mdot
.71338 .4852 Mdot
.3773 .2385 Mdot
.50259 .53088 Mdot
.63975 .5614 Mdot
.57906 .41803 Mdot
.41521 .39586 Mdot
.6505 .76202 Mdot
.25156 .64492 Mdot
.22092 .61256 Mdot
.66979 .23152 Mdot
.25466 .56682 Mdot
.73783 .31422 Mdot
.80893 .38991 Mdot
.36608 .31203 Mdot
.73857 .60089 Mdot
.38549 .81124 Mdot
.50904 .1752 Mdot
.5271 .81838 Mdot
.38942 .49285 Mdot
.50756 .57272 Mdot
.70517 .74889 Mdot
.2998 .5593 Mdot
.19094 .526 Mdot
.64518 .51152 Mdot
.29677 .59871 Mdot
.52969 .77489 Mdot
.30961 .62949 Mdot
.41303 .65468 Mdot
.84608 .50719 Mdot
.75142 .31639 Mdot
.29807 .72921 Mdot
.80013 .63452 Mdot
.30116 .36102 Mdot
.26349 .75568 Mdot
.61247 .56438 Mdot
.35753 .62215 Mdot
.63259 .31098 Mdot
.64706 .27412 Mdot
.46459 .76562 Mdot
.57252 .78248 Mdot
.72581 .37852 Mdot
.50858 .29588 Mdot
.33669 .59419 Mdot
.34165 .67948 Mdot
.56077 .6118 Mdot
.42713 .7426 Mdot
.50275 .18913 Mdot
.81612 .45261 Mdot
.47624 .55631 Mdot
.58963 .7634 Mdot
.68057 .66312 Mdot
.16498 .43203 Mdot
.55266 .2431 Mdot
.53141 .3719 Mdot
.43074 .63916 Mdot
.78373 .63143 Mdot
.20529 .42267 Mdot
.46231 .25318 Mdot
.63987 .26598 Mdot
.50942 .16177 Mdot
.72722 .70171 Mdot
.35096 .19228 Mdot
.28637 .60382 Mdot
.46511 .45338 Mdot
.22065 .45495 Mdot
.28765 .73752 Mdot
.65144 .35877 Mdot
.77015 .40481 Mdot
.59753 .35468 Mdot
.38558 .57848 Mdot
.35574 .24352 Mdot
.39464 .79214 Mdot
.29694 .75396 Mdot
.57818 .3927 Mdot
.52397 .40822 Mdot
.71028 .8082 Mdot
.69633 .29027 Mdot
.40099 .7147 Mdot
.65084 .19731 Mdot
.54848 .46922 Mdot
.3955 .6281 Mdot
.52956 .69681 Mdot
.61246 .19321 Mdot
.33318 .58281 Mdot
.37434 .16646 Mdot
.59184 .1609 Mdot
.31901 .31749 Mdot
.90762 .42126 Mdot
.67105 .30803 Mdot
.56116 .46609 Mdot
.48975 .71663 Mdot
.54273 .26474 Mdot
.17563 .50334 Mdot
.54385 .3539 Mdot
.67247 .64445 Mdot
.77219 .70883 Mdot
.65402 .22938 Mdot
.32502 .77456 Mdot
.60835 .81427 Mdot
.18775 .43796 Mdot
.56192 .55093 Mdot
.48128 .34731 Mdot
.58581 .51134 Mdot
.80621 .46244 Mdot
.51944 .15226 Mdot
.54198 .23452 Mdot
.83742 .66392 Mdot
.62138 .33539 Mdot
.74863 .44196 Mdot
.85551 .47999 Mdot
.5275 .30422 Mdot
.37198 .66254 Mdot
.54806 .21113 Mdot
.52921 .39431 Mdot
.62668 .42994 Mdot
.78657 .42825 Mdot
.37145 .702 Mdot
.53679 .19433 Mdot
.80295 .57179 Mdot
.46739 .7911 Mdot
.27993 .50557 Mdot
.59792 .22757 Mdot
.28899 .6203 Mdot
.48349 .27777 Mdot
.39834 .64922 Mdot
.74417 .30031 Mdot
.49118 .64489 Mdot
.77084 .31032 Mdot
.39487 .21243 Mdot
.42485 .35284 Mdot
.36391 .38585 Mdot
.28441 .63463 Mdot
.49761 .27345 Mdot
.49036 .46288 Mdot
.43134 .77449 Mdot
.78743 .34842 Mdot
.33311 .34155 Mdot
.52804 .60549 Mdot
.62321 .62718 Mdot
.85817 .49558 Mdot
.23653 .45246 Mdot
.61961 .32974 Mdot
.47602 .21448 Mdot
.16643 .45219 Mdot
.65796 .53979 Mdot
.3336 .77648 Mdot
.56296 .70783 Mdot
.33558 .27648 Mdot
.28359 .53229 Mdot
.25198 .3685 Mdot
.78836 .34917 Mdot
.6934 .47882 Mdot
.3764 .22819 Mdot
.52632 .32179 Mdot
.46238 .83405 Mdot
.72669 .59101 Mdot
.49098 .45245 Mdot
.59543 .77077 Mdot
.59395 .39499 Mdot
.26123 .45844 Mdot
.52497 .84181 Mdot
.70872 .45457 Mdot
.49829 .39371 Mdot
.31926 .31131 Mdot
.70153 .50685 Mdot
.45436 .53581 Mdot
.23444 .29823 Mdot
.38201 .44833 Mdot
.63988 .25326 Mdot
.71107 .71607 Mdot
.52175 .25527 Mdot
.83117 .57269 Mdot
.76444 .63789 Mdot
.38981 .17052 Mdot
.64342 .20164 Mdot
.70048 .41372 Mdot
.61686 .20803 Mdot
.71222 .25821 Mdot
.37986 .18119 Mdot
.38336 .35679 Mdot
.51887 .70599 Mdot
.12802 .46928 Mdot
.67499 .52672 Mdot
.67276 .28106 Mdot
.50515 .80732 Mdot
.58029 .55452 Mdot
.26851 .61119 Mdot
.53833 .39371 Mdot
.50089 .53816 Mdot
.39278 .57246 Mdot
.49488 .45698 Mdot
.28595 .26104 Mdot
.43818 .15742 Mdot
.32851 .21732 Mdot
.7539 .69695 Mdot
.59365 .18904 Mdot
.57108 .46919 Mdot
.31186 .74065 Mdot
.45735 .32176 Mdot
.40238 .39061 Mdot
.58673 .34124 Mdot
.6723 .31008 Mdot
.30346 .31749 Mdot
.45717 .74227 Mdot
.39296 .55051 Mdot
.77831 .41707 Mdot
.39928 .887 Mdot
.27626 .40042 Mdot
.42695 .81163 Mdot
.67174 .33672 Mdot
.49661 .26146 Mdot
.79965 .46558 Mdot
.27916 .33978 Mdot
.81937 .39566 Mdot
.38931 .56642 Mdot
.5244 .81392 Mdot
.72667 .48456 Mdot
.42464 .52635 Mdot
.69384 .40029 Mdot
.76276 .33838 Mdot
.56347 .7392 Mdot
.25937 .33742 Mdot
.46324 .7161 Mdot
.21654 .44052 Mdot
.6307 .60612 Mdot
.65908 .6792 Mdot
.50594 .83696 Mdot
.75438 .62208 Mdot
.50042 .23374 Mdot
.53922 .51511 Mdot
.3079 .68856 Mdot
.47964 .66608 Mdot
.50629 .23564 Mdot
.48714 .49931 Mdot
.6153 .21933 Mdot
.45506 .09595 Mdot
.23008 .32434 Mdot
.86049 .54163 Mdot
.78958 .46558 Mdot
.50029 .41409 Mdot
.83725 .42596 Mdot
.31365 .21788 Mdot
.55132 .13061 Mdot
.63425 .70994 Mdot
.60426 .52796 Mdot
.55968 .66151 Mdot
.31229 .24795 Mdot
.76516 .43331 Mdot
.82811 .43992 Mdot
.57124 .22654 Mdot
.54922 .63924 Mdot
.16484 .58763 Mdot
.50828 .16571 Mdot
.30119 .53122 Mdot
.45478 .30361 Mdot
.48848 .39095 Mdot
.26118 .66153 Mdot
.31399 .62987 Mdot
.71479 .65062 Mdot
.47753 .26358 Mdot
.66498 .54166 Mdot
.62155 .31676 Mdot
.58614 .77998 Mdot
.38891 .41141 Mdot
.56587 .5734 Mdot
.35979 .62905 Mdot
.7199 .61092 Mdot
.39834 .74744 Mdot
.50437 .14218 Mdot
.68712 .34928 Mdot
.4591 .3587 Mdot
.52373 .25084 Mdot
.69079 .39457 Mdot
.37521 .2157 Mdot
.5123 .6351 Mdot
.69019 .25054 Mdot
.48131 .57441 Mdot
.48185 .27529 Mdot
.25636 .64293 Mdot
.37023 .34711 Mdot
.40995 .46714 Mdot
.77592 .60982 Mdot
.31637 .43352 Mdot
.4375 .55875 Mdot
.5006 .37121 Mdot
.42882 .32384 Mdot
.84088 .43613 Mdot
.6468 .42825 Mdot
.66317 .66626 Mdot
.71318 .27074 Mdot
.53022 .68735 Mdot
.36802 .57033 Mdot
.58999 .4111 Mdot
.55362 .80352 Mdot
.32925 .42664 Mdot
.34303 .26314 Mdot
.57985 .52871 Mdot
.71735 .44888 Mdot
.72318 .2845 Mdot
.68768 .25487 Mdot
.24082 .66368 Mdot
.39669 .57248 Mdot
.3798 .3103 Mdot
.54286 .81211 Mdot
.31036 .58094 Mdot
.43597 .78978 Mdot
.42114 .78191 Mdot
.55004 .16432 Mdot
.56153 .58473 Mdot
.77994 .69721 Mdot
.59685 .28492 Mdot
.76244 .40323 Mdot
.24256 .33722 Mdot
.49139 .8332 Mdot
.74415 .33084 Mdot
.39351 .61581 Mdot
.24876 .53288 Mdot
.3967 .49258 Mdot
.31889 .71558 Mdot
.14095 .50948 Mdot
.62011 .41167 Mdot
.33737 .53252 Mdot
.80606 .56975 Mdot
.44945 .42304 Mdot
.20732 .34551 Mdot
.56208 .79221 Mdot
.29503 .27982 Mdot
.55865 .65148 Mdot
.42792 .37373 Mdot
.46198 .46535 Mdot
.5123 .21293 Mdot
.41268 .66286 Mdot
.60068 .21263 Mdot
.55911 .84383 Mdot
.81025 .53335 Mdot
.25158 .63893 Mdot
.65944 .27512 Mdot
.82099 .45908 Mdot
.6607 .75575 Mdot
.54579 .53671 Mdot
.67717 .32473 Mdot
.54163 .30233 Mdot
.79185 .64426 Mdot
.48686 .50297 Mdot
.46575 .66508 Mdot
.4716 .77508 Mdot
.727 .66411 Mdot
.28919 .31008 Mdot
.4447 .37605 Mdot
.44023 .19981 Mdot
.81639 .41079 Mdot
.24486 .65799 Mdot
.16601 .50731 Mdot
.23663 .31364 Mdot
.31452 .48307 Mdot
.74242 .6519 Mdot
.63022 .76761 Mdot
.46841 .84915 Mdot
.47715 .57988 Mdot
.73043 .33593 Mdot
.53555 .3132 Mdot
.71968 .27928 Mdot
.50767 .69903 Mdot
.44966 .70376 Mdot
.62697 .62677 Mdot
.61184 .21032 Mdot
.23829 .47313 Mdot
.7827 .35725 Mdot
.53628 .48877 Mdot
.39987 .16293 Mdot
.75945 .60614 Mdot
.51496 .51839 Mdot
.62145 .55479 Mdot
.6798 .46717 Mdot
.78042 .39665 Mdot
.75935 .57102 Mdot
.47668 .82848 Mdot
.64112 .49001 Mdot
.58103 .41153 Mdot
.28152 .55424 Mdot
.46903 .28724 Mdot
.77552 .6159 Mdot
.52376 .25124 Mdot
.77014 .33267 Mdot
.52939 .20393 Mdot
.43461 .20367 Mdot
.67957 .30818 Mdot
.72444 .75708 Mdot
.39986 .70999 Mdot
.65154 .40732 Mdot
.5714 .78769 Mdot
.75871 .46199 Mdot
.38032 .63563 Mdot
.14186 .32491 Mdot
.66188 .79205 Mdot
.75106 .60101 Mdot
.52035 .15285 Mdot
.76517 .65116 Mdot
.71347 .61553 Mdot
.18809 .47406 Mdot
.43435 .62055 Mdot
.41328 .23061 Mdot
.41852 .4206 Mdot
.28327 .25569 Mdot
.46399 .27549 Mdot
.48404 .14176 Mdot
.83457 .45192 Mdot
.26434 .60402 Mdot
.38451 .44114 Mdot
.68034 .52139 Mdot
.47945 .60651 Mdot
.42089 .26848 Mdot
.22177 .50168 Mdot
.34471 .66635 Mdot
.61365 .61088 Mdot
.63076 .57331 Mdot
.68193 .39864 Mdot
.3693 .55031 Mdot
.76248 .41864 Mdot
.7258 .66035 Mdot
.69027 .56907 Mdot
.46575 .56487 Mdot
.50374 .2445 Mdot
.38977 .66231 Mdot
.30781 .52777 Mdot
.28271 .33432 Mdot
.58322 .69731 Mdot
.66756 .51657 Mdot
.29695 .52158 Mdot
.70015 .75626 Mdot
.80056 .55261 Mdot
.50818 .15909 Mdot
.6172 .4427 Mdot
.22766 .53809 Mdot
.50704 .22942 Mdot
.17639 .52083 Mdot
.21019 .56724 Mdot
.71252 .60312 Mdot
.27643 .66767 Mdot
.19348 .51283 Mdot
.54965 .76945 Mdot
.57489 .1684 Mdot
.52624 .81737 Mdot
.54008 .81441 Mdot
.60819 .59321 Mdot
.35014 .48203 Mdot
.27008 .5841 Mdot
.57521 .28387 Mdot
.46691 .5317 Mdot
.23634 .72185 Mdot
.48099 .35118 Mdot
.16309 .6555 Mdot
.55802 .6821 Mdot
.17456 .46235 Mdot
.54742 .30844 Mdot
.54609 .51018 Mdot
.53071 .48173 Mdot
.75678 .62738 Mdot
.43877 .67599 Mdot
.71498 .72047 Mdot
.20767 .5893 Mdot
.6083 .55923 Mdot
.57574 .84476 Mdot
.73238 .7542 Mdot
.26222 .51866 Mdot
.3854 .4024 Mdot
.68747 .77653 Mdot
.60297 .54344 Mdot
.29637 .32093 Mdot
.83522 .56602 Mdot
.78105 .54253 Mdot
.38461 .52218 Mdot
.49397 .26597 Mdot
.73183 .33489 Mdot
.68102 .23294 Mdot
.16911 .57058 Mdot
.78718 .43253 Mdot
.51052 .70084 Mdot
.54103 .49271 Mdot
.78843 .38111 Mdot
.41056 .61004 Mdot
.5118 .61824 Mdot
.37182 .65803 Mdot
.22595 .73529 Mdot
.67633 .28072 Mdot
.60611 .21781 Mdot
.37702 .6504 Mdot
.37379 .5636 Mdot
.42503 .65024 Mdot
.37304 .66283 Mdot
.77554 .55842 Mdot
.66441 .77215 Mdot
.386 .65623 Mdot
.38344 .83015 Mdot
.36846 .34365 Mdot
.69057 .48601 Mdot
.26124 .59549 Mdot
.35013 .33161 Mdot
.54733 .63581 Mdot
.46476 .20255 Mdot
.81903 .5374 Mdot
.54455 .70912 Mdot
.78267 .60726 Mdot
.59499 .76224 Mdot
.3652 .51807 Mdot
.33131 .4559 Mdot
.80113 .52481 Mdot
.23478 .50182 Mdot
.28924 .70241 Mdot
.33429 .28975 Mdot
.62284 .50833 Mdot
.82894 .5222 Mdot
.63035 .52864 Mdot
.52784 .37074 Mdot
.43027 .58266 Mdot
.5394 .35201 Mdot
.28922 .27637 Mdot
.58715 .37567 Mdot
.32378 .62958 Mdot
.14811 .52617 Mdot
.3325 .5656 Mdot
.30015 .24743 Mdot
.25696 .36239 Mdot
.25725 .65495 Mdot
.70013 .421 Mdot
.68863 .44686 Mdot
.29789 .78383 Mdot
.58544 .61956 Mdot
.58401 .5317 Mdot
.3509 .74172 Mdot
.34862 .6268 Mdot
.68966 .34547 Mdot
.62138 .52197 Mdot
.45621 .59945 Mdot
.57275 .73685 Mdot
.3514 .39237 Mdot
.28944 .574 Mdot
.45896 .58304 Mdot
.44055 .23027 Mdot
.57629 .18077 Mdot
.65897 .56624 Mdot
.17297 .65228 Mdot
.39467 .45518 Mdot
.27763 .49749 Mdot
.81903 .39062 Mdot
.16936 .59543 Mdot
.60616 .48412 Mdot
.74173 .75019 Mdot
.47259 .37461 Mdot
.79926 .486 Mdot
.33644 .58808 Mdot
.53082 .81239 Mdot
.59862 .35851 Mdot
.52773 .25884 Mdot
.56119 .68023 Mdot
.25638 .33911 Mdot
.62165 .46897 Mdot
.31313 .56807 Mdot
.78459 .5067 Mdot
.36218 .31725 Mdot
.45179 .66132 Mdot
.67228 .42785 Mdot
.26485 .52274 Mdot
.33217 .44589 Mdot
.36364 .54057 Mdot
.62221 .22951 Mdot
.54765 .82111 Mdot
.51465 .13649 Mdot
.30628 .64013 Mdot
.56943 .43574 Mdot
.45577 .78261 Mdot
.78844 .57945 Mdot
.33718 .71677 Mdot
.80318 .36546 Mdot
.46387 .26005 Mdot
.34857 .4523 Mdot
.48903 .24279 Mdot
.36728 .4557 Mdot
.5173 .54669 Mdot
.68774 .66891 Mdot
.21827 .61503 Mdot
.37092 .68209 Mdot
.19413 .4465 Mdot
.30535 .70247 Mdot
.60409 .22388 Mdot
.27572 .66187 Mdot
.69957 .52115 Mdot
.35661 .51239 Mdot
.52825 .71998 Mdot
.58964 .17751 Mdot
.80818 .37305 Mdot
.49467 .69283 Mdot
.70833 .37414 Mdot
.80864 .60451 Mdot
.36987 .4406 Mdot
.58845 .45223 Mdot
.44997 .46064 Mdot
.42963 .31004 Mdot
.17629 .62068 Mdot
.78144 .56408 Mdot
.49226 .37458 Mdot
.65784 .23781 Mdot
.63591 .21294 Mdot
.43903 .14765 Mdot
.41446 .82202 Mdot
.35306 .61456 Mdot
.37377 .19217 Mdot
.33722 .66844 Mdot
.69755 .24244 Mdot
.73079 .59321 Mdot
.84267 .40451 Mdot
.24822 .52701 Mdot
.7944 .60328 Mdot
.18654 .49204 Mdot
.43771 .65251 Mdot
.71881 .70009 Mdot
.57239 .48194 Mdot
.64705 .66158 Mdot
.74959 .67367 Mdot
.51765 .87136 Mdot
.4334 .48953 Mdot
.63064 .75314 Mdot
.5149 .76256 Mdot
.83039 .51274 Mdot
.74962 .54217 Mdot
.38262 .42344 Mdot
.62718 .63862 Mdot
.28069 .30101 Mdot
.51712 .24009 Mdot
.58434 .41645 Mdot
.74818 .54585 Mdot
.37598 .25995 Mdot
.47402 .24104 Mdot
.53044 .81987 Mdot
.25847 .52729 Mdot
.48399 .59271 Mdot
.4607 .36881 Mdot
.3079 .55968 Mdot
.58198 .36727 Mdot
.57006 .49911 Mdot
.42652 .4589 Mdot
.68869 .56058 Mdot
.44954 .65497 Mdot
.26666 .28685 Mdot
.37902 .69933 Mdot
.59986 .78871 Mdot
.2769 .59895 Mdot
.52434 .75337 Mdot
.3513 .72881 Mdot
.21664 .35358 Mdot
.74735 .49508 Mdot
.54235 .23472 Mdot
.70031 .28731 Mdot
.54311 .19854 Mdot
.35828 .53348 Mdot
.45599 .16763 Mdot
.49785 .66298 Mdot
.38107 .51759 Mdot
.48829 .75133 Mdot
.67774 .38967 Mdot
.50074 .37712 Mdot
.79381 .60248 Mdot
.58362 .51485 Mdot
.64586 .27817 Mdot
.72684 .70583 Mdot
.38046 .31807 Mdot
.27098 .55114 Mdot
.67869 .24615 Mdot
.68902 .5419 Mdot
.58132 .81063 Mdot
.46552 .69502 Mdot
.73512 .51569 Mdot
.56981 .19128 Mdot
.53205 .15206 Mdot
.50951 .50626 Mdot
.53306 .29125 Mdot
.46199 .39715 Mdot
.51227 .83328 Mdot
.78246 .57621 Mdot
.53183 .41901 Mdot
.63139 .70089 Mdot
.35993 .5659 Mdot
.66445 .69805 Mdot
.50213 .57817 Mdot
.40244 .24266 Mdot
.34014 .63533 Mdot
.25112 .65487 Mdot
.59207 .39887 Mdot
.55768 .44818 Mdot
.511 .43602 Mdot
.53967 .27935 Mdot
.32672 .78178 Mdot
.51484 .39328 Mdot
.79496 .44011 Mdot
.27987 .52695 Mdot
.52891 .80164 Mdot
.79736 .52097 Mdot
.69702 .61043 Mdot
.43731 .67034 Mdot
.3503 .50097 Mdot
.58159 .71123 Mdot
.47967 .42611 Mdot
.69267 .50576 Mdot
.30442 .58003 Mdot
.83476 .53328 Mdot
.31776 .46918 Mdot
.56505 .2838 Mdot
.58414 .59942 Mdot
.52451 .36402 Mdot
.5079 .7259 Mdot
.83505 .39854 Mdot
.43408 .65596 Mdot
.4738 .26047 Mdot
.56174 .58403 Mdot
.54926 .30438 Mdot
.24312 .38314 Mdot
.58445 .15738 Mdot
.18515 .4856 Mdot
.47311 .54755 Mdot
.17543 .4756 Mdot
.74933 .62891 Mdot
.82789 .58276 Mdot
.46932 .2503 Mdot
.54594 .45589 Mdot
.64113 .3432 Mdot
.39636 .7658 Mdot
.58318 .60266 Mdot
.60424 .42348 Mdot
.45909 .6034 Mdot
.60185 .71404 Mdot
.573 .64475 Mdot
.52716 .42595 Mdot
.68394 .30327 Mdot
.69073 .2698 Mdot
.51481 .80519 Mdot
.48037 .67362 Mdot
.72886 .53247 Mdot
.40342 .24994 Mdot
.85892 .42235 Mdot
.14316 .47155 Mdot
.46257 .39987 Mdot
.50387 .71548 Mdot
.51882 .28679 Mdot
.65385 .50169 Mdot
.36704 .67361 Mdot
.35988 .72635 Mdot
.54348 .70071 Mdot
.5944 .41476 Mdot
.6271 .2599 Mdot
.73537 .64506 Mdot
.47431 .29457 Mdot
.60479 .61837 Mdot
.25361 .29613 Mdot
.73262 .73091 Mdot
.78817 .57285 Mdot
.83708 .3599 Mdot
.46388 .67791 Mdot
.40199 .33598 Mdot
.24083 .42348 Mdot
.58022 .18599 Mdot
.53504 .249 Mdot
.32167 .28941 Mdot
.66712 .62125 Mdot
.4631 .25462 Mdot
.35276 .65176 Mdot
.66946 .2898 Mdot
.65775 .70026 Mdot
.51843 .53325 Mdot
.69274 .451 Mdot
.47707 .15566 Mdot
.26001 .57147 Mdot
.71724 .29968 Mdot
.25946 .31824 Mdot
.44564 .85064 Mdot
.60295 .1841 Mdot
.63073 .28838 Mdot
.75228 .5202 Mdot
.22322 .45318 Mdot
.47675 .50572 Mdot
.3961 .61831 Mdot
.29974 .31778 Mdot
.32743 .39998 Mdot
.72893 .4054 Mdot
.20345 .40972 Mdot
.50117 .23366 Mdot
.33806 .34167 Mdot
.54351 .45982 Mdot
.30914 .52171 Mdot
.70539 .3767 Mdot
.39614 .63399 Mdot
.45463 .51985 Mdot
.57289 .26221 Mdot
.28847 .52237 Mdot
.47536 .78716 Mdot
.76166 .64661 Mdot
.42119 .85545 Mdot
.77926 .46703 Mdot
.20825 .36875 Mdot
.39773 .39117 Mdot
.46298 .12539 Mdot
.73095 .6753 Mdot
.74356 .57782 Mdot
.6854 .75108 Mdot
.71074 .51801 Mdot
.37649 .34909 Mdot
.47985 .42533 Mdot
.77638 .39619 Mdot
.33645 .53185 Mdot
.30184 .35175 Mdot
.24358 .3472 Mdot
.51117 .26025 Mdot
.57126 .22962 Mdot
.58431 .28511 Mdot
.36579 .48623 Mdot
.33754 .56669 Mdot
.33738 .21119 Mdot
.48697 .52728 Mdot
.52865 .40327 Mdot
.4624 .49468 Mdot
.21483 .44407 Mdot
.78622 .70168 Mdot
.28293 .63087 Mdot
.56521 .21102 Mdot
.25165 .5579 Mdot
.40054 .52919 Mdot
.32775 .70491 Mdot
.83492 .30708 Mdot
.51377 .10806 Mdot
.30329 .57663 Mdot
.40934 .80539 Mdot
.25322 .56304 Mdot
.60974 .2137 Mdot
.7301 .48375 Mdot
.60416 .72613 Mdot
.50624 .46771 Mdot
.42231 .54296 Mdot
.50768 .43582 Mdot
.69644 .73155 Mdot
.60098 .1721 Mdot
.22509 .36918 Mdot
.66054 .23985 Mdot
.35783 .43257 Mdot
.51386 .41606 Mdot
.87483 .42126 Mdot
.78251 .36978 Mdot
.37441 .42884 Mdot
.18701 .52526 Mdot
.48374 .35015 Mdot
.41612 .39993 Mdot
.73632 .36909 Mdot
.57652 .8435 Mdot
.50252 .23004 Mdot
.6118 .21068 Mdot
.32324 .63378 Mdot
.66811 .48168 Mdot
.55853 .6828 Mdot
.516 .49824 Mdot
.37241 .3904 Mdot
.53512 .69567 Mdot
.41793 .2909 Mdot
.8065 .58625 Mdot
.51713 .5992 Mdot
.57571 .83017 Mdot
.78894 .32305 Mdot
.32071 .48913 Mdot
.39299 .76008 Mdot
.4028 .47432 Mdot
.34524 .33787 Mdot
.40379 .26526 Mdot
.43382 .31541 Mdot
.77834 .64276 Mdot
.22875 .24589 Mdot
.62719 .66281 Mdot
.43662 .21795 Mdot
.37902 .56288 Mdot
.46807 .60524 Mdot
.30362 .53951 Mdot
.72653 .54954 Mdot
.64388 .56991 Mdot
.35981 .44649 Mdot
.32452 .63939 Mdot
.56888 .68569 Mdot
.14754 .6128 Mdot
.39013 .39025 Mdot
.34862 .69035 Mdot
.70091 .24739 Mdot
.33377 .28972 Mdot
.25847 .48651 Mdot
.48789 .42076 Mdot
.42993 .74868 Mdot
.54787 .45298 Mdot
.81707 .49179 Mdot
.44322 .20226 Mdot
.67286 .26168 Mdot
.31846 .46362 Mdot
.26591 .55327 Mdot
.45195 .36516 Mdot
.65159 .37317 Mdot
.54118 .6161 Mdot
.75861 .38772 Mdot
.41793 .34375 Mdot
.66185 .21244 Mdot
.64644 .46251 Mdot
.57892 .49425 Mdot
.30904 .64621 Mdot
.42583 .15559 Mdot
.21842 .41318 Mdot
.29185 .5592 Mdot
.22533 .3393 Mdot
.66225 .42316 Mdot
.47224 .28845 Mdot
.68499 .52841 Mdot
.39153 .35355 Mdot
.29555 .62796 Mdot
.21662 .3275 Mdot
.72742 .35179 Mdot
.64644 .6513 Mdot
.65564 .67949 Mdot
.45967 .81416 Mdot
.45566 .67704 Mdot
.81807 .33481 Mdot
.66781 .43724 Mdot
.22933 .31792 Mdot
.55577 .81862 Mdot
.28496 .62076 Mdot
.76625 .62769 Mdot
.47463 .34967 Mdot
.66846 .55347 Mdot
.65893 .24564 Mdot
.5125 .36042 Mdot
.35813 .24434 Mdot
.49446 .42846 Mdot
.31959 .26078 Mdot
.66218 .36989 Mdot
.70417 .35795 Mdot
.74886 .61176 Mdot
.21556 .43566 Mdot
.84827 .48349 Mdot
.39959 .76884 Mdot
.84828 .43981 Mdot
.84524 .50221 Mdot
.68518 .24545 Mdot
.32169 .2774 Mdot
.18462 .60259 Mdot
.7487 .58316 Mdot
.79911 .53342 Mdot
.7058 .66463 Mdot
.20873 .4658 Mdot
.6887 .47277 Mdot
.28876 .64109 Mdot
.41314 .66635 Mdot
.5112 .70968 Mdot
.08333 .48182 Mdot
.59568 .24633 Mdot
.29002 .63159 Mdot
.67096 .45431 Mdot
.65212 .21953 Mdot
.22229 .44182 Mdot
.74332 .68497 Mdot
.5065 .57194 Mdot
.48641 .45781 Mdot
.32658 .44141 Mdot
.49431 .81489 Mdot
.65126 .45566 Mdot
.33497 .82189 Mdot
.71281 .74448 Mdot
.62782 .68694 Mdot
.5053 .55426 Mdot
.29553 .59901 Mdot
.30849 .71734 Mdot
.69506 .44015 Mdot
.77193 .65736 Mdot
.79944 .59703 Mdot
.78736 .3783 Mdot
.29725 .78205 Mdot
.53354 .80673 Mdot
.57751 .18298 Mdot
.76918 .60053 Mdot
.32162 .56099 Mdot
.62551 .29604 Mdot
.60794 .53402 Mdot
.67054 .64937 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0T?ooool2o`00
0;Oooooo000Looooo`;o0000TOooool2o`000;Oooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2S
ooooo`;o0000Y?ooool001cooooo00?o0000ooooooooool0Xoooool2o`000:Cooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo09?ooooo0_l0000?
ooooo`;o0000Xoooool001cooooo00?o0000ooooooooool0Toooool2o`0000oooooo0_l0002Soooo
o`007?ooool00ol0003oooooooooo`2]ooooo`Co0000V?ooool001cooooo00?o0000ooooooooool0
[Oooool4o`0009Sooooo000Looooo`03o`000?oooooooooo0:?ooooo0_l0002Tooooo`007?ooool0
0ol0003oooooooooo`1Zooooo`;o0000:_ooool2o`0000?ooooo0_l00006ooooo`;o0000Y?ooool0
01cooooo00?o0000ooooooooool0J_ooool2o`0002[ooooo0_l000000ooooooo0000o`000002o`00
00?ooooo0ol00003ooooo`;o0000XOooool001cooooo00?o0000ooooooooool0Roooool2o`0000So
oooo0_l00002ooooo`;o00001Oooool3o`0000?ooooo0_l0002Qooooo`007?ooool00ol0003ooooo
ooooo`2;ooooo`;o00002?ooool2o`0000Cooooo0_l0000Looooo`;o0000S_ooool001cooooo0_l0
002Looooo`;o00002?ooool2o`0000;ooooo0_l00002ooooo`;o00002_ooool2o`0008kooooo000L
ooooo`03o`000?oooooooooo08Oooooo0_l0000>ooooo`;o00003?ooool2o`0000;ooooo0_l00002
ooooo`;o00003Oooool2o`0008_ooooo000Looooo`03o`000?oooooooooo08?ooooo0_l00002oooo
o`;o00000_ooool2o`0000[ooooo0_l00002ooooo`;o00001?ooool2o`0001Oooooo1?l0002;oooo
o`007?ooool00ol0003oooooooooo`1nooooo`;o00000oooool2o`0000Kooooo0_l0000>ooooo`;o
00001?ooool3o`0000kooooo0_l00006ooooo`Ko0000ROooool001cooooo00?o0000ooooooooool0
O_ooool2o`0001Cooooo0_l00005ooooo`;o00000_ooool5o`000003ooooool0003o000000Sooooo
0_l000000ooooooo0000o`000008ooooo`Go0000R?ooool001cooooo00?o0000ooooooooool0M_oo
ool2o`0001Sooooo0_l00002ooooo`;o00002Oooool4o`0000;ooooo0_l00007ooooo`?o00001_oo
ool4o`0000Cooooo0_l00028ooooo`007?ooool00ol0003oooooooooo`1fooooo`;o00000oooool2
o`0001?ooooo0_l0000Looooo`;o00001oooool4o`0000Cooooo0_l000000ooooooo0000o`000025
ooooo`007?ooool00ol0003oooooooooo`1kooooo`;o00001oooool2o`0001[ooooo1?l00008oooo
o`;o00004Oooool2o`000003ooooool0003o000008Gooooo000Looooo`03o`000?oooooooooo07Co
oooo0_l0000>ooooo`;o00005_ooool2o`0000;ooooo1?l000000ooooooo0000o`000005ooooo`;o
00003_ooool2o`0000Kooooo0_l00023ooooo`007?ooool00ol0003oooooooooo`1dooooo`;o0000
0_ooool2o`0001;ooooo0_l0000>ooooo`?o00001_ooool2o`00013ooooo0_l00003ooooo`;o0000
1_ooool2o`0008?ooooo000Looooo`03o`000?oooooooooo07Sooooo0_l0000Booooo`;o00002_oo
ool2o`000003ooooool0003o000000;o00003?ooool2o`0000[ooooo0ol00006ooooo`;o0000Qooo
ool001cooooo00?o0000ooooooooool0Q?ooool2o`0001;ooooo0_l000000ooooooo0000o`000003
ooooo`;o00000_ooool2o`0000Gooooo0_l0000;ooooo`?o00001Oooool2o`0008Oooooo000Loooo
o`03o`000?oooooooooo08Cooooo0_l0000Jooooo`;o00000_ooool2o`0000kooooo0_l00003oooo
o`;o00000_ooool2o`0008[ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44
ooooo`Go00001_ooool00ol0003oooooooooo`1^ooooo`;o00001_ooool2o`0001[ooooo0_l00004
ooooo`?o00001Oooool2o`0000;ooooo0_l0000>ooooo`?o00000oooool2o`000004ooooool0003o
0000ooooo`;o000000?oooooo`000?l00000Q?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo06Wo
oooo0_l00003ooooo`;o00001_ooool2o`0001[ooooo0ol00003ooooo`?o00002Oooool6o`000004
ooooool0003o0000ooooo`;o00001Oooool2o`000003ooooool0003o000000;o00001?ooool5o`00
08Cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^
k^h01oooool00ol0003oooooooooo`1Yooooo`;o00004_ooool2o`0000Wooooo0_l000000ooooooo
0000o`000005ooooo`Go00003oooool4o`000003ooooool0003o000000?o00002?ooool2o`0000So
oooo0_l0000<ooooo`;o0000Moooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
2oooool00onHV9So8B4Qonk^kP06ooooo`?o0000OOooool2o`0000Oooooo1?l000001?oooooo0000
o`000?l00004ooooo`Go00005_ooool2o`0000cooooo0_l0000@ooooo`;o000000?oooooo`000?l0
0000Moooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIV
ooooo`05ooooo`03o`000?oooooooooo08Kooooo2?l00004ooooo`?o00000oooool2o`0000;ooooo
0_l00009ooooo`Go000000?oooooo`000?l000000_ooool2o`0000Sooooo0_l00009ooooo`Co0000
0oooool2o`0007[ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`1Oooooo`;o0000:?ooool4o`0000_ooooo0_l0
0002ooooo`;o00002Oooool5o`000003ooooool0003o000000;ooooo0_l00009ooooo`;o00001ooo
ool5o`0007oooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo
V9RHoa0@4006ooooo`03o`000?oooooooooo05oooooo0_l00009ooooo`;o00003oooool2o`000003
ooooool0003o000000;ooooo0_l0000Yooooo`Go00000_ooool2o`0000;ooooo0_l00002ooooo`;o
00001Oooool4o`0000kooooo0_l0001booooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Zooooo`;o00003Oooool=
o`0000;ooooo0_l00003ooooo`;o00002?ooool2o`0000[ooooo0_l00008ooooo`Ko000000?ooooo
o`000?l000000_ooool4o`0000?ooooo0_l000001?oooooo0000o`000?l00006ooooo`;o00001_oo
ool4o`0007;ooooo000Looooo`03o`000?oooooooooo06;ooooo0_l00003ooooo`;o00001_ooool2
o`0000Gooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000_ooool2
o`0000;ooooo1?l000000ooooooo0000o`000008ooooo`;o00001_ooool2o`0000;ooooo0_l00003
ooooo`;o00000oooool3o`000003ooooool0003o000000Oooooo0_l00002ooooo`Ko00001oooool2
o`0000Kooooo0_l0001dooooo`007?ooool00ol0003oooooooooo`1Rooooo`;o00000oooool2o`00
00Kooooo0_l000000ooooooo0000o`000002ooooo`;o00004Oooool3o`0001?ooooo0ol00006oooo
o`;o00001?ooool2o`0000Kooooo0_l00006ooooo`;o000000Coooooo`000?l0003ooooo0_l0000:
ooooo`;o0000Moooool001cooooo00?o0000ooooooooool0Koooool2o`000003ooooool0003o0000
00Oooooo0_l0000Rooooo`?o00001?ooool5o`0000_ooooo0_l00008ooooo`;o00000_ooool2o`00
00[ooooo0_l0001gooooo`007?ooool00ol0003oooooooooo`1_ooooo`Co00002?ooool2o`0000co
oooo0_l0000Dooooo`;o00001Oooool5o`0000?ooooo0_l00002ooooo`;o000000Coooooo`000?l0
003o00001_ooool4o`00017ooooo0_l0001dooooo`007?ooool00ol0003oooooooooo`1^ooooo`;o
000000?oooooo`000?l000000_l00002ooooo`;o00001_ooool2o`0000;ooooo0_l00004ooooo`Co
00001_ooool2o`0000[ooooo1?l00004ooooo`Co00000oooool2o`0000;ooooo0_l000001?oooooo
0000o`000?l00006ooooo`;o00001_ooool2o`0000Wooooo1_l0001booooo`007?ooool00ol0003o
ooooooooo`1^ooooo`;o00000oooool2o`0000;ooooo0_l00006ooooo`?o000000?oooooo`000?l0
00001_ooool2o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`;o00001?ooool4o`0001?o
oooo0_l0000:ooooo`Ko00002Oooool2o`0000;ooooo0ol000000ooooooo0000o`00001^ooooo`00
7?ooool00ol0003oooooooooo`20ooooo`;o00003Oooool3o`000003ooooool0003o000000Cooooo
0_l00004ooooo`Ko00001_ooool3o`0001Cooooo1?l000000ooooooo0000o`00000=ooooo`;o0000
00?oooooo`000?l00000K_ooool001cooooo00?o0000ooooooooool0Moooool3o`0000oooooo0_l0
0004ooooo`?o000000?oooooo`000?l000001?ooool2o`0000Kooooo1Ol00005ooooo`?o00000ooo
ool3o`0000Wooooo0_l00008ooooo`;o00002Oooool3o`0007Cooooo000Looooo`03o`000?oooooo
oooo07Kooooo1?l00005ooooo`;o000000?oooooo`000?l000001Oooool4o`0000?ooooo0_l00004
ooooo`;o00000_ooool3o`0000Oooooo1?l00008ooooo`Co00002Oooool2o`0001?ooooo0ol0000:
ooooo`;o0000J?ooool001cooooo00?o0000ooooooooool0Aoooool2o`0002Oooooo0ol00003oooo
o`;o00001oooool2o`000003ooooool0003o000000Oooooo0_l00006ooooo`;o000000?oooooo`00
0?l000000_ooool4o`0000;ooooo0_l00004ooooo`;o00002?ooool2o`000003ooooool0003o0000
00;o00000oooool2o`0001Kooooo0ol00004ooooo`Co00000_ooool2o`0006Sooooo000Looooo`03
o`000?oooooooooo04Oooooo0_l0000Eooooo`;o00000_ooool2o`0000cooooo0ol0000?ooooo`;o
00001_ooool2o`0000Kooooo0ol00003ooooo`;o00000_ooool2o`0000;ooooo0_l00008ooooo`;o
00001oooool4o`0000;ooooo0ol00002ooooo`;o00001?ooool3o`0000_ooooo1?l00003ooooo`Co
00000oooool2o`0006Oooooo000Looooo`;o0000Goooool2o`0000;ooooo0_l00003ooooo`;o0000
00?oooooo`000?l000000oooool5o`0000_ooooo0_l000000ooooooo0000o`000006ooooo`;o0000
1_ooool2o`000004ooooool0003o0000ooooo`;o00003?ooool3o`000003ooooool0003o000000;o
oooo0_l00009ooooo`;o00000oooool2o`0000Cooooo0ol0000=ooooo`;o00001_ooool2o`0000;o
oooo0_l0001Wooooo`007?ooool00ol0003oooooooooo`1Wooooo`;o000000?oooooo`000?l00000
0oooool5o`0000_ooooo1Ol0000>ooooo`Go00003oooool3o`0000Gooooo0_l0000Eooooo`;o0000
1Oooool2o`0000;ooooo0_l0000:ooooo`;o0000Joooool001cooooo00?o0000ooooooooool0F?oo
ool2o`0001Kooooo0_l0000=ooooo`?o00002?ooool2o`0000Kooooo0ol00007ooooo`;o00002?oo
ool2o`0000gooooo0_l0000>ooooo`;o00001Oooool2o`0000;ooooo0_l0000:ooooo`;o00001_oo
ool2o`0006?ooooo000Looooo`03o`000?oooooooooo04gooooo0_l00009ooooo`?o00002Oooool2
o`0000oooooo0ol00007ooooo`;o00002?ooool6o`0000Cooooo1Ol00004ooooo`Co00000_ooool2
o`0000Cooooo0_l00002ooooo`;o00001oooool2o`0000;ooooo0_l0000=ooooo`;o00005_ooool2
o`0000;ooooo0_l00002ooooo`;o0000Goooool001cooooo00?o0000ooooooooool0COooool2o`00
00[ooooo0_l00009ooooo`;o00001_ooool2o`0000Oooooo0ol0000Aooooo`Ko000000Coooooo`00
0?l0003ooooo2_l000000ooooooo0000o`000002ooooo`;o00000oooool3o`0000;ooooo0_l00007
ooooo`?o000000?oooooo`000?l000003Oooool2o`0000Gooooo0_l00005ooooo`?o00001oooool2
o`0000Kooooo0_l0001Oooooo`007?ooool00ol0003oooooooooo`1Vooooo`?o00000oooool2o`00
017ooooo0_l0000?ooooo`?o00000_ooool:o`0000Sooooo0_l00004ooooo`;o00001_ooool3o`00
00Cooooo0ol00002ooooo`;o000000?oooooo`000?l000001_ooool2o`000003ooooool0003o0000
00Gooooo0ol000000ooooooo0000o`00001]ooooo`007?ooool00ol0003oooooooooo`1Vooooo`?o
00002oooool2o`0000Wooooo0_l00004ooooo`Co00002?ooool2o`0000Gooooo0_l00003ooooo`?o
00000oooool2o`0000Sooooo0_l00006ooooo`;o00001Oooool3o`000005ooooool0003o0000o`00
0?ooool00_l00006ooooo`;o00003?ooool2o`000003ooooool0003o000000Gooooo0_l0001Soooo
o`007?ooool00ol0003oooooooooo`1Uooooo`;o000000?oooooo`000?l000002_ooool2o`0000oo
oooo1?l0000?ooooo`;o00001?ooool2o`0000?ooooo0_l00004ooooo`;o00005Oooool2o`0001;o
oooo0_l00007ooooo`;o00001Oooool2o`000003ooooool0003o0000063ooooo000Looooo`03o`00
0?oooooooooo05?ooooo0_l00005ooooo`;o00000oooool2o`0000Cooooo0_l000001?oooooo0000
o`000?l0000;ooooo`;o00003Oooool2o`0000cooooo0_l00004ooooo`;o00000oooool2o`0000Wo
oooo0_l0000@ooooo`;o00001oooool4o`0000Kooooo0_l00002ooooo`Co00004Oooool2o`00063o
oooo000Looooo`03o`000?oooooooooo05?ooooo0_l00005ooooo`Co000000?oooooo`000?l00000
1?ooool2o`0000;ooooo0_l0000;ooooo`;o00003_ooool3o`0000Kooooo0_l00002ooooo`;o0000
00?oooooo`000?l000000ol0000Aooooo`;o00003Oooool2o`0000Oooooo1?l00004ooooo`Co0000
0_ooool2o`0001;ooooo0_l0001Qooooo`007?ooool00ol0003oooooooooo`1Looooo`;o00001?oo
ool5o`0001Sooooo0_l00003ooooo`Go00001_ooool5o`0000;ooooo1Ol0000>ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0000;ooooo0_l00008ooooo`;o00000oooool2o`0000Oooooo1?l0
0007ooooo`?o000000?oooooo`000?l000002Oooool2o`00067ooooo000Looooo`03o`000?oooooo
oooo05Oooooo0_l00009ooooo`?o00001oooool2o`00017ooooo0_l00003ooooo`;o00002oooool3
o`0000[ooooo0_l00009ooooo`;o00001Oooool2o`0000;ooooo0_l000001?oooooo0000o`000?oo
ool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000Gooooo0_l0000;ooooo`?o000000?o
ooooo`000?l000002_ooool2o`00063ooooo000Looooo`03o`000?oooooooooo05?ooooo0_l00002
ooooo`;o00004oooool2o`0000?ooooo0_l00002ooooo`;o00003_ooool2o`0000_ooooo0_l00000
1?oooooo0000o`000?l00006ooooo`;o00001Oooool2o`0000gooooo0_l000001?oooooo0000o`00
0?ooool2o`0000;ooooo0_l000000ooooooo0000o`000006ooooo`Co00004oooool2o`0000Gooooo
0_l0001Pooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00002?ooool2o`0000Kooooo0_l0
0002ooooo`;o000000Coooooo`000?l0003ooooo1?l00002ooooo`;o00003Oooool3o`0000_ooooo
0_l000001?oooooo0000o`000?l0000=ooooo`;o00000_ooool2o`0000Sooooo0_l0000:ooooo`;o
00001Oooool2o`000003ooooool0003o000000;o00000oooool2o`0000Cooooo0_l00006ooooo`Co
0000Ioooool001cooooo00?o0000ooooooooool0Eoooool2o`0000Cooooo0_l00006ooooo`Ko0000
1?ooool2o`0000oooooo0_l00002ooooo`;o00004?ooool2o`00017ooooo0_l00008ooooo`;o0000
2_ooool4o`0000?ooooo0_l00008ooooo`;o00001?ooool5o`0000?ooooo0_l00005ooooo`;o0000
H_ooool001cooooo00?o0000ooooooooool0B?ooool2o`0000?ooooo1?l00005ooooo`?o00002?oo
ool2o`0000;ooooo1?l00009ooooo`;o00003?ooool2o`0000;ooooo0_l0000@ooooo`;o00002Ooo
ool2o`0000_ooooo0ol00002ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Cooooo0_l0
000>ooooo`Co00002_ooool2o`0006;ooooo000Looooo`;o0000BOooool2o`0000?ooooo1?l00004
ooooo`Co00000_ooool2o`0000Cooooo0_l00002ooooo`;o00002oooool2o`0002Oooooo0_l00004
ooooo`;o00002oooool3o`0000?ooooo1_l0000=ooooo`;o00002_ooool2o`00013ooooo0_l00007
ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0EOooool4o`0000;ooooo0_l0000Aoooo
o`;o00006Oooool2o`0000Gooooo0ol00008ooooo`;o00001?ooool2o`0000Gooooo0_l00002oooo
o`;o000000?oooooo`000?l000000oooool2o`0000;ooooo0_l0000Eooooo`;o000000Coooooo`00
0?l0003o00001Oooool2o`0000Wooooo0_l00005ooooo`Co0000FOooool001cooooo00?o0000oooo
ooooool0K_ooool2o`0001Wooooo0_l00005ooooo`?o00005Oooool3o`000004ooooool0003o0000
ooooo`;o00001oooool3o`0001Cooooo0_l000000ooooooo0000o`000006ooooo`;o00001Oooool2
o`0000Sooooo1?l0000Looooo`;o0000??ooool001cooooo00?o0000ooooooooool0DOooool2o`00
00Oooooo0_l00006ooooo`;o00005?ooool2o`0000kooooo0_l00003ooooo`;o00002oooool2o`00
00_ooooo1?l00003ooooo`;o00002?ooool3o`000003ooooool0003o000000Oooooo0_l0000?oooo
o`Go00001_ooool2o`0000Sooooo1?l00008ooooo`;o00004_ooool2o`0003cooooo000Looooo`03
o`000?oooooooooo04Wooooo0_l00006ooooo`;o00000_ooool2o`0000?ooooo1?l00004ooooo`Co
00003Oooool2o`0000?ooooo0_l00003ooooo`Co00001oooool2o`0000?ooooo1?l000000ooooooo
0000o`000002o`0000Cooooo0_l00008ooooo`Go000000?oooooo`000?l000000_ooool2o`0000Go
oooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000001?ooool2o`0000?o
oooo0_l0000:ooooo`Oo00003oooool2o`000003ooooool0003o000000Kooooo0_l0001@ooooo`00
7?ooool00ol0003oooooooooo`19ooooo`;o00000_ooool2o`0000Kooooo0_l00003ooooo`Co0000
00?oooooo`000?l000000oooool4o`0000_ooooo0_l00008ooooo`Co00002?ooool2o`0000Cooooo
0_l000000ooooooo0000o`000002o`0000kooooo1?l00002ooooo`;o00001oooool4o`000003oooo
ool0003o000000Gooooo0_l00005ooooo`;o00000_ooool2o`0000Sooooo0_l00004ooooo`?o0000
3Oooool4o`000004ooooool0003o0000o`0005Oooooo000Looooo`03o`000?oooooooooo03cooooo
0ol00008ooooo`;o00001?ooool2o`0000;ooooo0_l00007ooooo`;o00000_ooool3o`0000?ooooo
1?l0000:ooooo`;o00001?ooool2o`0000?ooooo0_l0000:ooooo`;o00001?ooool2o`0000;ooooo
0_l000000ooooooo0000o`00000Kooooo`;o00003?ooool2o`0000?ooooo0ol0000;ooooo`;o0000
1?ooool2o`000003ooooool0003o000000?ooooo0_l00006ooooo`Go000000?oooooo`000?l00000
Eoooool001cooooo00?o0000ooooooooool0??ooool3o`0000Sooooo0_l00004ooooo`;o00000_oo
ool3o`0000Kooooo0_l000000ooooooo0000o`000004o`000003ooooool0003o000000cooooo0_l0
0004ooooo`;o00002Oooool2o`0000[ooooo2Ol0000?ooooo`;o00006?ooool2o`0000Cooooo0_l0
000;ooooo`;o00001oooool2o`000003ooooool0003o000000;o00000_ooool2o`0000Gooooo1Ol0
000:ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0:_ooool2o`0001_ooooo0_l00000
1?oooooo0000o`000?ooool2o`0000?ooooo0_l00005ooooo`;o00000_ooool3o`000003ooooool0
003o000000_ooooo0_l0000Booooo`?o00000oooool2o`0000Kooooo0ol000000ooooooo0000o`00
000Aooooo`;o00007_ooool2o`0000Kooooo0_l00003ooooo`;o00000_ooool2o`0000Kooooo0_l0
0004ooooo`;o00001_ooool4o`0000[ooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`0Z
ooooo`;o00005oooool2o`0000;ooooo0_l000000ooooooo0000o`00000=ooooo`;o00000oooool2
o`0000kooooo0_l0000Booooo`Co00000_ooool2o`0000Cooooo1?l0000eooooo`;o00001_ooool2
o`0000;ooooo0ol00002ooooo`;o00004_ooool2o`0000Oooooo1?l0001@ooooo`007?ooool00ol0
003oooooooooo`13ooooo`;o00006oooool2o`0000Gooooo0_l00005ooooo`;o00005?ooool4o`00
00Kooooo0_l0000?ooooo`;o00009?ooool4o`0000Kooooo0_l00002ooooo`?o00005_ooool4o`00
00Cooooo1Ol0001@ooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o00001_ooool3o`000004
ooooool0003o0000ooooo`;o00001Oooool2o`0000;ooooo0_l0000Booooo`Ko000000?oooooo`00
0?l000000_ooool2o`0000cooooo0_l0000Tooooo`Co00002Oooool3o`000003ooooool0003o0000
00cooooo0_l00004ooooo`;o00000_ooool2o`0000Cooooo1?l0000;ooooo`;o000000?oooooo`00
0?l00000@Oooool001cooooo00?o0000ooooooooool0Boooool3o`0000?ooooo0_l00005ooooo`;o
00001oooool2o`000003ooooool0003o000000Kooooo0_l00004ooooo`;o00002oooool2o`0000;o
oooo0_l00003ooooo`Co000000?oooooo`000?l000000_ooool2o`0000Kooooo0_l0000[ooooo`?o
00001oooool4o`0000;ooooo0_l0000<ooooo`;o00000oooool3o`0000Sooooo1Ol0000:ooooo`;o
000000?oooooo`000?l00000@Oooool001cooooo00?o0000ooooooooool0AOooool2o`0000Cooooo
0ol00002ooooo`?o00001?ooool2o`0000oooooo1_l00005ooooo`;o00002_ooool3o`000003oooo
ool0003o000000Kooooo0ol00002ooooo`;o00001oooool2o`0000Sooooo0_l0000Fooooo`;o0000
1?ooool4o`000004ooooool0003o0000ooooo`;o00001Oooool2o`0000Cooooo0_l0000Aooooo`;o
00002Oooool2o`000003ooooool0003o0000053ooooo000Looooo`03o`000?oooooooooo04Gooooo
0ol00008ooooo`;o00001Oooool2o`000003ooooool0003o000000cooooo1?l00007ooooo`?o0000
2_ooool2o`0000;ooooo0_l000001Ooooooo0000o`000?l0003ooooo00?o00000_ooool5o`0000Wo
oooo0_l00003ooooo`;o00005_ooool2o`0000Cooooo1?l000001?oooooo0000o`000?ooool2o`00
0003ooooool0003o000000kooooo0_l00003ooooo`Co00005?ooool2o`0004kooooo000Looooo`03
o`000?oooooooooo043ooooo0_l00003ooooo`?o00000oooool2o`0000[ooooo0_l000001?oooooo
0000o`000?ooool2o`0000Kooooo1Ol00009ooooo`Co00002Oooool<o`0000Gooooo1?l00003oooo
o`?o00000oooool4o`0001cooooo1?l000000ooooooo0000o`000009o`0000kooooo0_l00003oooo
o`Co00005?ooool2o`0004kooooo000Looooo`;o0000@Oooool2o`0000?ooooo0_l00004ooooo`;o
00002Oooool3o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`Go00002Oooool6o`0000;o
oooo0_l00003ooooo`Oo00000_ooool3o`0000Oooooo0_l000000ooooooo0000o`000003o`000003
ooooool0003o000000;ooooo0_l0000Hooooo`;o00000_ooool@o`0000?ooooo0_l00008ooooo`?o
00001_ooool2o`0001Kooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`13ooooo`;o0000
4Oooool2o`0000Kooooo1?l00004ooooo`?o00003Oooool4o`000003ooooool0003o000000Gooooo
0_l00002ooooo`oo000000?oooooo`000?l000000ol000000ooooooo0000o`000002ooooo`;o0000
2Oooool4o`0000Sooooo0_l000001?oooooo0000o`000?oooolCo`000003ooooool0003o000000Co
00001?ooool3o`0000Kooooo0_l00002ooooo`;o00004_ooool2o`0004_ooooo000Looooo`03o`00
0?oooooooooo04?ooooo0_l00004ooooo`;o00004oooool2o`0000Oooooo0_l00007ooooo`?o0000
0oooool:o`0000;ooooo0_l00002ooooo`oo00000_ooool3o`0000Kooooo1?l00007ooooo`Co0000
2?ooool>o`0000;ooooo2Ol00002ooooo`Go00001_ooool2o`0000;ooooo0_l00004ooooo`?o0000
1Oooool2o`0000cooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`0booooo`;o00005Ooo
ool2o`0000?ooooo0_l00008ooooo`;o00005_ooool3o`0000Cooooo1Ol000001?oooooo0000o`00
0?l00002ooooo`?o00001_ooool2o`000003ooooool0003o000000Ko00000_ooool2o`0000Sooooo
0_l00009ooooo`;o00002OoooolLo`0000Wooooo0_l00002ooooo`;o00001?ooool2o`0000Kooooo
0_l00009ooooo`;o000000?oooooo`000?l000003Oooool2o`0003_ooooo000Looooo`03o`000?oo
oooooooo03;ooooo0_l00008ooooo`;o00004?ooool4o`0000Gooooo1?l00003ooooo`;o00004Ooo
ool2o`0000Oooooo0_l000000ooooooo0000o`000002o`000004ooooool0003o0000o`0000;ooooo
2?l000000ooooooo0000o`000008o`000003ooooool0003o000000Kooooo0_l00008ooooo`;o0000
2OoooolJo`000003ooooool0003o000000?o00002Oooool2o`0000Kooooo0_l00009ooooo`;o0000
1?ooool2o`00013ooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0looooo`;o00004?oo
ool4o`0000Gooooo1?l00003ooooo`;o00003_ooool2o`0000Cooooo1?l00002ooooo`co000000?o
ooooo`000?l000005?l00006ooooo`;o00000_ooool2o`0000Gooooo0_l00008oooooaOo000000Co
ooooo`000?l0003ooooo1Ol00003ooooo`;o00001?ooool2o`0000Kooooo0_l00009ooooo`;o0000
1oooool6o`0004Kooooo000Looooo`03o`000?oooooooooo043ooooo0_l00003ooooo`;o00001ooo
ool2o`0000Sooooo0_l0000Dooooo`;o00001?ooool6o`000003ooooool0003o000001[o00000ooo
ool2o`0000_ooooo0_l00005ooooo`;o00002?oooolJo`0000?ooooo0_l00004ooooo`;o00001?oo
ool2o`0000Sooooo0_l0000?ooooo`Oo0000A_ooool001cooooo00?o0000ooooooooool0??ooool2
o`0000;ooooo0_l00003ooooo`;o00001oooool2o`0000Sooooo0_l0000Nooooob7o000000?ooooo
o`000?l000000_l000000ooooooo0000o`000005ooooo`Go000000?oooooo`000?l000002OoooolK
o`000003ooooool0003o000000;o00005?ooool2o`0000gooooo1?l0001;ooooo`007?ooool00ol0
003oooooooooo`0looooo`;o0000=Oooool2o`000004ooooool0003o0000ooooo`Oo000000?ooooo
o`000?l000002?l000000ooooooo0000o`00000;o`000003ooooool0003o000000Go00001Oooool5
o`000003ooooool0003o000000Sooooo7?l000000ooooooo0000o`00000=ooooo`;o00005_ooool2
o`0000Oooooo0ol00013ooooo`007?ooool00ol0003oooooooooo`0Qooooo`;o00002_ooool2o`00
01;ooooo0_l0000@ooooo`;o00007_ooool2o`000003ooooool0003o000000?o000000?oooooo`00
0?l000000_l000000ooooooo0000o`00000Bo`000003ooooool0003o000000;ooooo1ol00005oooo
o`;o00003OoooolMo`0000;ooooo0_l0000;ooooo`?o00001?ooool2o`0001;ooooo0_l00005oooo
o`?o0000@oooool001cooooo00?o0000ooooooooool08Oooool2o`0000[ooooo0_l0000Booooo`;o
00004?ooool2o`0002;ooooo1?l000000ooooooo0000o`000006o`000003ooooool0003o0000017o
00000_ooool3o`0000;ooooo0_l00005ooooo`;o00002?ooool4o`000003ooooool0003o000001[o
00000oooool2o`0000Wooooo1?l00005ooooo`;o00002?ooool2o`0000Cooooo0_l00002ooooo`;o
0000Boooool001cooooo00?o0000ooooooooool0Boooool2o`0002Oooooo0_l00006oooooako0000
5_ooool4o`0000Cooooo1?l00002ooooo`Go000000?oooooo`000?l000002_l00005ooooo`;o0000
2?ooool2o`0000?ooooo0_l00006ooooo`;o00001?ooool2o`0000Cooooo0_l00002ooooo`;o0000
0oooool2o`0004Kooooo000Looooo`03o`000?oooooooooo043ooooo0ol00008ooooo`;o00009Ooo
ool4o`0000Cooooo8?l00002ooooo`Go00006?ooool4o`000003ooooool0003o0000013o00001Ooo
ool2o`0000gooooo0_l00004ooooo`Co00000_ooool2o`000003ooooool0003o000000cooooo0_l0
0016ooooo`007?ooool00ol0003oooooooooo`10ooooo`?o0000;oooool2o`000004ooooool0003o
0000o`0000;ooooo7ol00002ooooo`Ko000000?oooooo`000?l000003_ooool2o`0000Kooooo5Ol0
0009ooooo`;o00004?ooool2o`0000Cooooo0_l000000ooooooo0000o`00000<ooooo`Co000000?o
ooooo`000?l00000@Oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo
0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo053ooooo0_l0000Looooo`;o0000
1?ooool4o`0000?ooooo8_l000000ooooooo0000o`000002ooooo`Go00001?ooool2o`0000Gooooo
0_l00004oooooaOo00002Oooool2o`0001Wooooo0_l0000>ooooo`;o000000?oooooo`000?l00000
@Oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Zooooo`;o00008_ooool4o`0001cooooo0_l000000ooooooo
0000o`000009o`000003ooooool0003o000000?o000000?oooooo`000?l000007?l00002ooooo`Co
000000Coooooo`000?l0003ooooo0_l00007ooooo`;o00000_ooool3o`000003ooooool0003o0000
00ko000000?oooooo`000?l000003_ooool3o`00013ooooo0_l000000ooooooo0000o`000003oooo
o`Co00002_ooool4o`0003oooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wo
oooo1Ol00006ooooo`03o`000?oooooooooo02Sooooo1?l0000Kooooo`;o00001Oooool2o`0001Oo
oooo0_l00005ooooo`;o000000?oooooo`000?l000005?l00002ooooo`Ko000000?oooooo`000?l0
00004?l000000ooooooo0000o`000002ooooo`?o00002_ooool2o`0000?ooooo0_l000000ooooooo
0000o`00000>o`0000kooooo0_l000001?oooooo0000o`000?l00003ooooo`;o00002oooool2o`00
00Kooooo1?l0000:ooooo`Co000000?oooooo`000?l00000??ooool00003ooooool0003ooooo00;o
oooo00?o0000ooooooooool02Oooool01?m4A4CogMgMooooool00007ooooo`?o0000:?ooool2o`00
01gooooo0_l0000=ooooo`;o00003oooool2o`0000Gooooo0ol000000ooooooo0000o`000002o`00
0003ooooool0003o000000Oo000000?oooooo`000?l000001?l00002ooooo`go000000Coooooo`00
0?l0003o00000_ooool3o`000003ooooool0003o000000;o00000oooool3o`0000oooooo0_l00002
ooooo`oo00001Oooool2o`0000Oooooo0_l00002ooooo`;o00000oooool2o`0000?ooooo0_l0000:
ooooo`;o00005?ooool3o`0003cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`1Fooooo`;o00005_ooool3
o`000003ooooool0003o000000;o00000ooooolMo`000003ooooool0003o000000Ko000000?ooooo
o`000?l000000_l00004ooooo`;o00003oooool2o`0000;ooooo1?l00002ooooo`Go00000_ooool2
o`0000Gooooo0_l00005ooooo`;o00000_ooool4o`0000Sooooo0ol00009ooooo`Co00004_ooool2
o`0000;ooooo0_l0000iooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:oooo
o`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0??ooool2o`0000[ooooo0_l00003oooo
o`;o00000_ooool2o`0002Oooooo9_l00002ooooo`;o000000?oooooo`000?l000000_l00009oooo
o`;o00002_ooool4o`0000Sooooo0_l00004ooooo`;o00001_ooool7o`0000[ooooo0_l00008oooo
o`;o000000?oooooo`000?l000004oooool2o`000003ooooool0003o000003Wooooo00001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0l
ooooo`Co00002?ooool4o`000003ooooool0003o000000;ooooo0_l0000Eooooo`;o00000_ooool2
o`0000Gooooo0_l00003ooooobSo00000_ooool2o`000003ooooool0003o000000;o000000Cooooo
o`000?l0003o00001Oooool2o`0000Gooooo0_l000000ooooooo0000o`000004o`0000Cooooo0_l0
0008ooooo`;o00001oooool4o`0001Kooooo0_l0000@ooooo`;o00001?ooool2o`0003cooooo0000
1_ooooook^k^oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooo
ooooo`0looooo`Co00000_ooool3o`0000Gooooo0_l000000ooooooo0000o`00000Hooooo`?o0000
0_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000/o`0000Gooooo0_l00002ooooo`?o0000
3?ooool2o`000004ooooool0003o0000o`0000Oooooo0_l0000?ooooo`Co00001Oooool2o`000004
ooooool0003o0000ooooo`;o00003_ooool2o`0000gooooo0ol00011ooooo`007?ooool00ol0003o
ooooooooo`0kooooo`?o00001?ooool3o`00013ooooo0_l0000@ooooo`;o00001ooooolIo`000003
ooooool0003o000000oo00000_ooool8o`000003ooooool0003o000000Oooooo0_l00007ooooo`Oo
00004_ooool2o`0000Cooooo1?l00005ooooo`;o000000?oooooo`000?l000000ol0000<ooooo`Co
000000Coooooo`000?l0003o00002_ooool4o`0003oooooo000Looooo`03o`000?oooooooooo03_o
oooo0_l00006ooooo`Co00003?ooool4o`0001[ooooo;ol000000ooooooo0000o`000002o`0000Co
oooo0_l00002ooooo`Co00001oooool4o`0000oooooo0_l00004ooooo`;o00001?ooool2o`0000Oo
oooo0_l00002ooooo`Co00003?ooool2o`0000?ooooo0ol0000<ooooo`;o00000_ooool2o`0000[o
oooo0_l00009ooooo`;o00009?ooool001cooooo00?o0000ooooooooool07Oooool2o`00023ooooo
0_l00004ooooo`;o00001?ooool2o`0000Kooooo0_l0000Oooooob7o000000?oooooo`000?l00000
3Ol00004ooooo`;o00000_ooool2o`000003ooooool0003o000000Kooooo0_l00006ooooo`;o0000
0oooool2o`0000Cooooo0_l000000ooooooo0000o`000002o`000004ooooool0003o0000ooooo`?o
00001oooool2o`0000kooooo0ol0000Booooo`;o00001Oooool2o`0000Gooooo0_l00003ooooo`;o
00002Oooool2o`0002Cooooo000Looooo`03o`000?oooooooooo01gooooo0_l0000Pooooo`;o0000
1Oooool2o`0000?ooooo0_l0000Jooooo`;o00003OoooolOo`000003ooooool0003o000000Oo0000
00Coooooo`000?l0003o00001?ooool2o`0000Oooooo0_l0000>ooooo`;o00000oooool2o`0000Oo
oooo1?l000001?oooooo0000o`000?ooool3o`0001Oooooo0ol0000Booooo`;o00001Oooool2o`00
00Gooooo0_l0000dooooo`007?ooool00ol0003oooooooooo`0Vooooo`;o00007_ooool2o`0001oo
oooo0_l00008ooooo`?o00000_oooolTo`000003ooooool0003o000000?o00001?ooool2o`000003
ooooool0003o000001;ooooo0_l0000;ooooo`?o00000oooool2o`0000Oooooo0_l0000Mooooo`;o
00001?ooool2o`0000gooooo1?l0000jooooo`007?ooool00ol0003oooooooooo`0Vooooo`;o0000
2_ooool2o`0002oooooo0_l0000<ooooobWo00000oooool5o`0000;ooooo0_l0000=ooooo`;o0000
0oooool2o`000003ooooool0003o000000Gooooo0_l00003ooooo`Co00000oooool2o`0001_ooooo
0_l00005ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`0000gooooo1?l0000jooooo`00
7?ooool00ol0003oooooooooo`0Nooooo`;o00004_ooool2o`0000kooooo0_l0000Oooooo`;o0000
3?ooool>o`000003ooooool0003o000001co00000_ooool4o`0000Kooooo1?l00005ooooo`Co0000
00?oooooo`000?l000001?ooool2o`0000;ooooo0_l00003ooooo`;o00002_ooool4o`0001Cooooo
0_l00005ooooo`;o000000?oooooo`000?l000000ol00002ooooo`;o00003_ooool3o`0003[ooooo
000Looooo`03o`000?oooooooooo01kooooo0_l00009ooooo`;o00001oooool2o`0000Gooooo0_l0
0003ooooo`;o00000_ooool2o`0000?ooooo0_l0000Zooooo`?o000000?oooooo`000?l00000:ol0
00000ooooooo0000o`000003ooooo`Co00001oooool2o`000003ooooool0003o000000Cooooo0_l0
0002ooooo`Co00003Oooool4o`0000Oooooo0_l00006ooooo`;o00003_ooool4o`0000Cooooo0_l0
0009ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0003Oooooo000Looooo`03o`000?oo
oooooooo02Wooooo0_l0000>ooooo`;o00000oooool2o`0000?ooooo1_l00009ooooo`;o00004_oo
ool2o`0000_ooooo0ol00002ooooobco000000?oooooo`000?l000006oooool6o`0001Kooooo0_l0
0006ooooo`;o00001oooool2o`0000Cooooo1?l00002ooooo`;o000000?oooooo`000?l000002Ooo
ool3o`0000Cooooo0_l0000gooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00003Oooool2
o`0000;ooooo1_l00009ooooo`?o000000?oooooo`000?l000003oooool4o`0000Sooooo1?l00002
ooooo`Ko000000?oooooo`000?l000005Ol000000ooooooo0000o`000006o`000003ooooool0003o
000000;o00002_ooool2o`0000Gooooo0_l00005ooooo`;o00001oooool3o`0000[ooooo0_l0000K
ooooo`;o00001?ooool2o`0000Cooooo0_l00003ooooo`;o00002?ooool2o`0003gooooo000Loooo
o`03o`000?oooooooooo02oooooo0ol00006ooooo`;o000000Coooooo`000?l0003ooooo1_l00002
ooooo`;o00002Oooool2o`0000;ooooo0_l0000@ooooo`?o00001oooool6o`000004ooooool0003o
0000ooooob3o000000Coooooo`000?l0003o00000_ooool2o`0000_ooooo0_l000000ooooooo0000
o`000002ooooo`;o00001Oooool2o`0001Cooooo0_l000000ooooooo0000o`000005ooooo`;o0000
1oooool2o`0001Wooooo0_l00017ooooo`007?ooool2o`00037ooooo1?l00004ooooo`;o000000Co
ooooo`000?l0003o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`00000Rooooo`;o0000
0_ooool2o`000003ooooool0003o000000Co000000?oooooo`000?l000003ol000000ooooooo0000
o`00000:o`0000?ooooo1?l0000Aooooo`;o00000oooool2o`0000?ooooo0_l0000Hooooo`;o0000
1Oooool3o`0000Kooooo0_l0000Fooooo`;o00001_ooool2o`0000Cooooo0_l0000looooo`007?oo
ool00ol0003oooooooooo`0booooo`;o00002?ooool4o`0000Cooooo1?l000000ooooooo0000o`00
000Iooooo`;o00001oooool6o`000003ooooool0003o000000;o00001?oooolTo`0000kooooo0_l0
0006ooooo`Co000000?oooooo`000?l000004oooool2o`0000Cooooo0_l00004ooooo`?o00000ooo
ool2o`0001?ooooo0_l00002ooooo`Ko00001?ooool5o`000003ooooool0003o000003cooooo000L
ooooo`03o`000?oooooooooo03;ooooo0_l0000:ooooo`;o00000_ooool5o`0000[ooooo0_l0000A
ooooo`;o00000_ooool2o`0000Gooooo1?l000000ooooooo0000o`000003ooooo`;o000000?ooooo
o`000?l000007_l000000ooooooo0000o`00000=ooooo`Co00002?ooool2o`000003ooooool0003o
000000cooooo0_l00005ooooo`;o00001?ooool2o`0000[ooooo0_l0000Booooo`?o00000_ooool2
o`0000;ooooo0_l00005ooooo`Co0000?oooool001cooooo00?o0000ooooooooool08oooool2o`00
00gooooo0_l0000>ooooo`;o00003Oooool4o`0000oooooo0_l00002ooooo`;o00001Oooool2o`00
00Sooooo0_l000000ooooooo0000o`000002oooooaCo000000?oooooo`000?l000001Ol000000ooo
oooo0000o`00000=ooooo`Co00002?ooool2o`000003ooooool0003o000000?ooooo0_l00007oooo
o`;o00000_ooool2o`0000?ooooo0_l00006ooooo`;o00006_ooool2o`0000?ooooo0_l00007oooo
o`;o000000?oooooo`000?l00000@?ooool001cooooo00?o0000ooooooooool08oooool2o`00013o
oooo0_l00007ooooo`;o00004oooool4o`0000gooooo0_l0000Eooooo`?o00000_oooolHo`000003
ooooool0003o000000?o00000_ooool2o`0000_ooooo0ol00008ooooo`;o00001_ooool2o`0000_o
oooo0ol000001?oooooo0000o`000?l00005ooooo`?o000000?oooooo`000?l000005?ooool2o`00
00;ooooo0_l00002ooooo`;o00000oooool6o`000003ooooool0003o0000043ooooo000Looooo`03
o`000?oooooooooo01_ooooo0_l0000Hooooo`;o00000_ooool2o`0000;ooooo1Ol0000>ooooo`;o
00000oooool2o`0000gooooo0_l0000@ooooo`;o00000_oooolFo`0000;ooooo0ol00005ooooo`Co
00000_ooool3o`00013ooooo0_l00002ooooo`;o00000oooool2o`00013ooooo0_l000000ooooooo
0000o`000006ooooo`;o00000_ooool2o`0001Cooooo0_l00002ooooo`Co00000_ooool2o`000003
ooooool0003o000000;o0000AOooool001cooooo00?o0000ooooooooool06oooool2o`0000Wooooo
0_l0000@ooooo`?o00000_ooool5o`0000kooooo1?l000000ooooooo0000o`00000<ooooo`;o0000
4Oooool2o`0000;ooooo0_l00002oooooa?o000000Coooooo`000?l0003o00001_ooool2o`0000Co
oooo0_l0000;ooooo`;o00000_ooool3o`000004ooooool0003o0000o`0000?ooooo0_l000000ooo
oooo0000o`000005ooooo`;o00004Oooool2o`0001Oooooo0_l00004ooooo`?o00000_ooool2o`00
0003ooooool0003o000004Oooooo000Looooo`03o`000?oooooooooo02Kooooo0_l00003ooooo`;o
00002oooool5o`000004ooooool0003o0000o`0000Wooooo0_l00006ooooo`;o000000?oooooo`00
0?l000002Oooool2o`000003ooooool0003o000000cooooo0_l0000<oooooaGo00000oooool2o`00
00;ooooo0_l0000=ooooo`;o00000_ooool2o`0000;ooooo0_l00002ooooo`;o00001oooool2o`00
0003ooooool0003o000000;ooooo0_l00003ooooo`;o00003_ooool3o`0001Cooooo0_l00004oooo
o`;o00004_ooool2o`0003_ooooo000Looooo`03o`000?oooooooooo02_ooooo0_l00006ooooo`Co
00000_ooool4o`0000gooooo0_l00007ooooo`;o00002oooool2o`0000oooooo0_l00005ooooo`Co
00000oooool5o`000003ooooool0003o000000Ko00000oooool4o`0000?ooooo0_l0000Aooooo`?o
00004_ooool5o`0000Oooooo0_l00002ooooo`;o00001_ooool2o`0000;ooooo0ol0000^ooooo`;o
0000>oooool001cooooo00?o0000ooooooooool0<Oooool6o`0001;ooooo0_l000000ooooooo0000
o`000005ooooo`Go00006_ooool2o`0000Cooooo1?l00003ooooo`;o000000?oooooo`000?l00000
0oooool2o`0000Oooooo0_l00009ooooo`Co00001_ooool2o`0000Cooooo0_l0000Booooo`?o0000
0_ooool5o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`;o00001?ooool2o`0000[ooooo
0_l0000Gooooo`;o00003_ooool2o`0003Gooooo000Looooo`03o`000?oooooooooo01Oooooo0_l0
000@ooooo`;o00001_ooool2o`000004ooooool0003o0000o`0001;ooooo0_l000000ooooooo0000
o`000006ooooo`Co00002_ooool2o`0000Cooooo0_l00004ooooo`;o00000_ooool2o`000004oooo
ool0003o0000ooooo`;o00003Oooool2o`0000?ooooo0_l000001?oooooo0000o`000?l00009oooo
o`Co00001_ooool2o`0000;ooooo0_l0000;ooooo`;o00003?ooool5o`0000?ooooo0_l00007oooo
o`;o00001_ooool2o`000003ooooool0003o000000Oooooo0_l0000Gooooo`;o00003_ooool2o`00
03Gooooo000Looooo`03o`000?oooooooooo01Oooooo0_l00006ooooo`;o00002?ooool2o`0000[o
oooo0_l000000ooooooo0000o`00000Fooooo`;o00003_ooool4o`0000Cooooo0_l00004ooooo`;o
00000oooool4o`00013ooooo1ol000000ooooooo0000o`000002o`0001Kooooo0_l0000;ooooo`Co
00001oooool2o`0000cooooo0_l00004ooooo`;o00001_ooool6o`000003ooooool0003o000000;o
oooo0ol0000Eooooo`;o00003_ooool2o`0003Oooooo000Looooo`03o`000?oooooooooo01oooooo
0_l0000Dooooo`;o000000?oooooo`000?l000005_ooool2o`0000Gooooo0_l00007ooooo`;o0000
0_ooool2o`0000;ooooo0_l00003ooooo`;o00001?ooool2o`0000Wooooo0_l00007ooooo`Oo0000
00?oooooo`000?l000000_l00006ooooo`;o00003oooool2o`0000cooooo0_l00007ooooo`;o0000
1_ooool2o`0000Cooooo0ol0000;ooooo`Wo00000_ooool3o`0001Gooooo0_l0000>ooooo`;o0000
=oooool001cooooo00?o0000ooooooooool0=Oooool2o`0000;ooooo0_l0000Looooo`;o00002ooo
ool2o`0000Oooooo0_l00005ooooo`;o00001?ooool6o`0000Oooooo1?l000000ooooooo0000o`00
000;ooooo`;o00003oooool2o`00013ooooo0_l00002ooooo`Co00001Oooool2o`000003ooooool0
003o000000Co00002?ooool2o`0000Kooooo0_l0000>ooooo`;o00004_ooool2o`00047ooooo000L
ooooo`03o`000?oooooooooo037ooooo0_l00006ooooo`;o0000;Oooool2o`0000Sooooo1?l00004
ooooo`Go00004Oooool4o`0000Sooooo0_l0000>ooooo`;o00001oooool5o`0000;ooooo0_l00002
ooooo`Co00001_ooool9o`000003ooooool0003o000000Cooooo0_l00008ooooo`;o00002Oooool2
o`000003ooooool0003o000001;ooooo0_l0000;ooooo`;o0000=?ooool001cooooo00?o0000oooo
ooooool0<Oooool2o`0002?ooooo0_l0000@ooooo`;o00000_ooool2o`0000Cooooo0ol00004oooo
o`Co00001Oooool2o`0000Cooooo0_l00004ooooo`Ko00002?ooool2o`0000;ooooo0_l00002oooo
o`;o00001_ooool2o`0000Oooooo1ol00006ooooo`;o000000Coooooo`000?l0003ooooo1?l00000
0ooooooo0000o`000007o`0000kooooo0_l00009ooooo`;o00001oooool2o`0001Wooooo0_l0000d
ooooo`007?ooool2o`0004Gooooo0ol00002ooooo`;o00002oooool2o`0000;ooooo0_l0000@oooo
o`Co00000_ooool3o`0000Cooooo0_l00007ooooo`So00001?ooool2o`0000[ooooo0_l000001?oo
oooo0000o`000?ooool6o`0000Cooooo0ol00008ooooo`;o00000oooool3o`0000Gooooo0_l00000
0ooooooo0000o`00000Ao`00023ooooo0_l0000Hooooo`;o0000=Oooool001cooooo00?o0000oooo
ooooool08oooool2o`0000gooooo0_l000000ooooooo0000o`000003ooooo`;o00002?ooool3o`00
00;ooooo0_l00009ooooo`;o00001?ooool2o`0001;ooooo1?l00008ooooo`;o00002?ooool4o`00
0003ooooool0003o000000kooooo0ol000001?oooooo0000o`000?ooool6o`0000Cooooo0ol00000
0ooooooo0000o`000005ooooo`;o00001?ooool2o`0000[ooooo4Ol0000gooooo`;o000000?ooooo
o`000?l00000=Oooool001cooooo00?o0000ooooooooool08oooool2o`0000cooooo0ol000000ooo
oooo0000o`000003ooooo`;o00006?ooool2o`000003ooooool0003o000000kooooo0_l00007oooo
o`;o00001oooool3o`0000gooooo0_l0000<ooooo`So000000?oooooo`000?l000000ol00009oooo
o`;o00006?oooolDo`000003ooooool0003o000000?o00000_ooool2o`0000Oooooo0_l0000<oooo
o`;o00000_ooool2o`0000kooooo0_l000001?oooooo0000o`000?ooool2o`0003;ooooo000Loooo
o`03o`000?oooooooooo02[ooooo0_l00005ooooo`?o00004oooool2o`0000_ooooo0_l000000ooo
oooo0000o`00000>ooooo`;o00004?ooool2o`0001Wooooo0_l000000ooooooo0000o`000002oooo
o`Co000000?oooooo`000?l000000_l0000:ooooo`;o00004_ooool2o`0000?ooooo6ol00002oooo
o`;o00001oooool2o`0000cooooo0ol000000ooooooo0000o`00000>ooooo`;o00001?ooool2o`00
03;ooooo000Looooo`03o`000?oooooooooo02[ooooo0_l00002ooooo`;o00002oooool2o`0000[o
oooo0_l000001?oooooo0000o`000?ooool2o`0001[ooooo0_l00005ooooo`;o00008_ooool2o`00
01Sooooo0ol00008ooooo`Co00001?ooool3o`0000;ooooo6?l000000ooooooo0000o`00000Hoooo
o`;o000000?oooooo`000?l000000oooool2o`0000Oooooo0_l000000ooooooo0000o`00000joooo
o`007?ooool00ol0003oooooooooo`0^ooooo`;o000000?oooooo`000?l000001?ooool2o`0000;o
oooo0_l000000ooooooo0000o`000005ooooo`;o00000oooool2o`000003ooooool0003o000001[o
oooo0_l00005ooooo`;o00000_ooool2o`0000Sooooo0_l0000:ooooo`;o00007oooool2o`0000;o
oooo0_l00008ooooo`Co00001?ooool2o`0000?ooooo6Ol000000ooooooo0000o`000009ooooo`;o
00003?ooool2o`0000Kooooo0_l00007ooooo`;o000000?oooooo`000?l00000>_ooool001cooooo
00?o0000ooooooooool0<Oooool2o`0000Cooooo0_l00005ooooo`;o00001Oooool2o`0000?ooooo
0_l00005ooooo`;o00001Oooool2o`0001Wooooo0ol000001?oooooo0000o`000?l00004ooooo`;o
00002_ooool2o`0000;ooooo1Ol00009ooooo`;o00001_ooool2o`0000Gooooo0_l0000=ooooo`;o
00002OoooolMo`000003ooooool0003o000000Kooooo0_l00004ooooo`;o00003Oooool2o`000003
ooooool0003o000004Cooooo000Looooo`03o`000?oooooooooo03Kooooo0_l00006ooooo`;o0000
2_ooool2o`0000Gooooo0ol00004ooooo`Co000000?oooooo`000?l000000_ooool2o`00013ooooo
0_l00002ooooo`Co00003?ooool2o`0000Gooooo1Ol00005ooooo`;o00000_ooool2o`0000Kooooo
0_l0000Nooooo`Ko000000?oooooo`000?l000005Ol000000ooooooo0000o`00000<ooooo`Co0000
2_ooool3o`000003ooooool0003o000000Cooooo0ol00003ooooo`?o0000=oooool001cooooo00?o
0000ooooooooool0;?ooool2o`0000Sooooo0_l000001?oooooo0000o`000?l00002ooooo`;o0000
4_ooool2o`0000Kooooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool2o`0000Gooooo
0_l0000:ooooo`;o00002oooool3o`0000Sooooo0_l00003ooooo`Co00001?ooool2o`0002Cooooo
6?l000000ooooooo0000o`000002o`0000Wooooo0_l00007ooooo`;o00002_ooool3o`0000Oooooo
0ol00003ooooo`?o00004?ooool2o`0002Gooooo000Looooo`03o`000?oooooooooo02cooooo0_l0
0004ooooo`;o00001Oooool3o`00017ooooo0_l000000ooooooo0000o`000005ooooo`Co00001Ooo
ool2o`0000Cooooo1?l00003ooooo`;o00001oooool2o`000003ooooool0003o000000?ooooo0_l0
0006ooooo`;o00001_ooool2o`0000Kooooo1_l00002ooooo`;o00004?ooool2o`0000Oooooo0_l0
0006oooooako00002oooool2o`0000;ooooo0_l00006ooooo`?o00001oooool2o`0000Oooooo0_l0
0002ooooo`Co00001?ooool2o`0000_ooooo0_l0000Uooooo`007?ooool00ol0003oooooooooo`0b
ooooo`;o00006?ooool3o`000003ooooool0003o000000Gooooo1?l00003ooooo`Co00001?ooool6
o`0000[ooooo0_l00006ooooo`;o00003_ooool2o`000004ooooool0003o0000ooooo`;o00000_oo
ool4o`0000?ooooo0_l0000?ooooo`;o00001_ooool4o`0000Gooooo7_l0000:ooooo`;o00000ooo
ool2o`0000Kooooo0ol0000Dooooo`Co00001?ooool3o`00037ooooo000Looooo`03o`000?oooooo
oooo02kooooo0_l0000;ooooo`;o00003oooool3o`0000Wooooo0_l00004ooooo`;o00002_ooool2
o`0000Gooooo0_l00009ooooo`;o00003_ooool7o`000003ooooool0003o000000Wooooo0_l00004
ooooo`;o00004Oooool4o`0000Kooooo6Ol00002ooooo`;o00001?ooool4o`0000;ooooo1?l00005
ooooo`;o00003?ooool2o`000003ooooool0003o000000Kooooo1?l00007ooooo`Co0000;oooool0
01cooooo00?o0000ooooooooool0;_ooool2o`0000_ooooo0_l00009ooooo`?o00001?ooool2o`00
00?ooooo0_l0000Mooooo`;o00001_ooool2o`000003ooooool0003o000000kooooo1_l0000=oooo
o`;o00001?ooool2o`0000Oooooo0_l0000BoooooaOo00000_ooool5o`0000?ooooo1?l00004oooo
o`;o00001Oooool2o`0000cooooo0_l000001?oooooo0000o`000?ooool4o`000003ooooool0003o
000000_ooooo0_l0000_ooooo`007?ooool00ol0003oooooooooo`16ooooo`?o00002Oooool2o`00
00Wooooo1?l000000ooooooo0000o`00000;ooooo`;o000000?oooooo`000?l000001ol00003oooo
o`;o00000_ooool2o`0000Wooooo0_l0000@ooooo`;o00001_ooool2o`0000Gooooo0ol000001?oo
oooo0000o`000?l0000=ooooo`oo000000?oooooo`000?l000003?l00003ooooo`;o00003oooool2
o`00013ooooo1?l0000:ooooo`;o0000<oooool001cooooo00?o0000ooooooooool0>Oooool2o`00
02;ooooo1?l000000ooooooo0000o`00000;ooooo`_o00001?ooool2o`0000;ooooo1Ol00003oooo
o`;o00001_ooool2o`0001?ooooo0_l00006ooooo`;o000000Coooooo`000?l0003o00002ooooolN
o`0000Gooooo0_l00009ooooo`Co00000_ooool2o`0000Cooooo0ol0000Gooooo`;o0000<oooool0
01cooooo00?o0000ooooooooool0=?ooool2o`0000?ooooo0_l00004ooooo`;o00000_ooool2o`00
01Wooooo0_l00003ooooo`;o00002_ooool4o`0000Oooooo0_l00007ooooo`Co00000oooool2o`00
0003ooooool0003o000000;ooooo0ol00002ooooo`;o00000_ooool2o`0000Sooooo0_l00002oooo
o`;o00001?ooool2o`0000oooooo7ol00005ooooo`;o00002Oooool4o`0000Sooooo1Ol000000ooo
oooo0000o`00000Booooo`;o0000<oooool001cooooo0_l0000Wooooo`;o00003?ooool2o`0000Wo
oooo0_l00002ooooo`;o00003oooool2o`0000gooooo0_l000001?oooooo0000o`000?ooool2o`00
00Cooooo1?l000000ooooooo0000o`000004ooooo`Co00001Oooool2o`0000Oooooo0ol00002oooo
o`;o00000oooool6o`0000Sooooo0_l00002ooooo`Co00000_ooool2o`000003ooooool0003o0000
00Co00002?oooolKo`000004ooooool0003o0000o`0000Gooooo0_l000000ooooooo0000o`000002
o`0000Gooooo0_l0000<ooooo`;o000000?oooooo`000?l000001oooool2o`0000;ooooo0_l00005
ooooo`;o000000?oooooo`000?l00000<?ooool001cooooo00?o0000ooooooooool09_ooool2o`00
01?ooooo0_l00003ooooo`;o00004Oooool3o`0000;ooooo0_l00008ooooo`;o00000_ooool2o`00
0005ooooool0003o0000o`000?ooool01_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l0
0005ooooo`;o00001Oooool4o`0000Oooooo1Ol00006ooooo`;o000000?oooooo`000?l000000_oo
ool2o`000003ooooool0003o000000Gooooo1_l0000;oooooaco000000Coooooo`000?l0003ooooo
0_l00002ooooo`Co00005_ooool2o`0000Oooooo0_l00002ooooo`;o00001_ooool4o`00033ooooo
000Looooo`03o`000?oooooooooo03_ooooo0_l00003ooooo`;o00004Oooool2o`0000?ooooo0_l0
0008ooooo`;o00000oooool;o`0000Gooooo0_l0000:ooooo`;o00000_ooool2o`000004ooooool0
003o0000o`0000Sooooo1?l00007ooooo`;o000000?oooooo`000?l000000_ooool4o`0000Oooooo
0_l000000ooooooo0000o`000002ooooo`;o00001oooool>o`000003ooooool0003o000000_o0000
00Coooooo`000?l0003ooooo0_l00003ooooo`;o00005oooool2o`0000[ooooo0_l00007ooooo`;o
0000<_ooool001cooooo00?o0000ooooooooool0;oooool2o`0001;ooooo0_l00009ooooo`;o0000
0_ooool2o`0000Oooooo0_l000000ooooooo0000o`000004o`0000?ooooo3_l0000Booooo`Ko0000
2_ooool2o`00013ooooo0_l0000:ooooo`?o000000?oooooo`000?l000001_ooool?o`000003oooo
ool0003o000000_o00005?ooool2o`0000Cooooo0_l0000Booooo`;o0000>oooool001cooooo00?o
0000ooooooooool0;_ooool3o`0000Cooooo0_l0000<ooooo`;o00002Oooool3o`000003ooooool0
003o000000Oooooo0_l000000ooooooo0000o`000004o`000003ooooool0003o000001;o00001?oo
ool2o`0000Wooooo1Ol0000Hooooo`;o000000?oooooo`000?l000002Oooool5o`0000Wooooo2_l0
00000ooooooo0000o`00000@o`0001Cooooo0_l00004ooooo`;o0000Coooool001cooooo00?o0000
ooooooooool0;_ooool2o`0000Gooooo0_l0000:ooooo`;o00003?ooool2o`00013ooooo0ol00000
0ooooooo0000o`00000Bo`0000;ooooo1?l00003ooooo`;o00001?ooool4o`0000Sooooo0_l0000;
ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`000003ooooool0003o000000Kooooo1?l0
000;ooooo`?o000000?oooooo`000?l000005_l0000Kooooo`?o00001?ooool3o`0000Sooooo0_l0
000looooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00003?ooool2o`0000?ooooo1?l0000<
ooooo`;o00003_ooool2o`000003ooooool0003o000001Co00000oooool3o`0000Cooooo0_l00004
ooooo`Co00002?ooool2o`0000[ooooo0ol000000ooooooo0000o`000005ooooo`;o00005Oooool3
o`000003ooooool0003o000001Ko00002Oooool2o`000003ooooool0003o000000gooooo0ol00004
ooooo`?o00002?ooool2o`0003cooooo000Looooo`03o`000?oooooooooo02cooooo0_l00005oooo
o`;o00000_ooool2o`000003ooooool0003o000000?ooooo1?l0000<ooooo`Co00002Oooool2o`00
0003ooooool0003o000001Go000000?oooooo`000?l000000oooool3o`0000Wooooo0ol0000Eoooo
o`?o00004oooool2o`000003ooooool0003o000000_ooooo4Ol000000ooooooo0000o`000004o`00
00Wooooo1Ol00007ooooo`;o00003?ooool3o`0000Kooooo0_l0000<ooooo`;o0000;oooool001co
oooo00?o0000ooooooooool0<Oooool4o`0000;ooooo0_l0000@ooooo`;o00001_ooool4o`0000Go
oooo1_l000000ooooooo0000o`00000Fo`0000?ooooo0ol0000:ooooo`;o00003_ooool2o`0000Ko
oooo0ol0000@ooooo`Co000000?oooooo`000?l000002_oooolBo`000003ooooool0003o000000ko
oooo0_l000000ooooooo0000o`000006ooooo`;o00001oooool2o`0000?ooooo0ol00006ooooo`;o
00003?ooool3o`0002kooooo000Looooo`03o`000?oooooooooo037ooooo0_l0000Fooooo`;o0000
00?oooooo`000?l000001Oooool2o`0000Gooooo1ol000000ooooooo0000o`00000Eo`000004oooo
ool0003o0000ooooo`;o00000oooool2o`0000Gooooo0_l0000:ooooo`;o00000_ooool2o`0000Co
oooo1Ol00009ooooo`;o00001Oooool2o`000003ooooool0003o000000Cooooo0_l00006ooooo`;o
00000_ooool5o`000003ooooool0003o000000Wo00004Oooool5o`0000[ooooo1?l0000Kooooo`;o
0000;_ooool001cooooo00?o0000ooooooooool0C?ooool2o`0000;ooooo0_l00006ooooo`;o0000
0_ooool2o`000003ooooool0003o000001_o000000?oooooo`000?l000000oooool2o`0000Gooooo
0_l0000:ooooo`Co00001_ooool2o`0000Cooooo0_l00006ooooo`;o00001_ooool4o`0000Cooooo
0_l0000<ooooo`Oo00001?ooool2o`0001Cooooo1?l0000:ooooo`Co0000Boooool001cooooo00?o
0000ooooooooool0:oooool2o`00023ooooo1Ol00002ooooo`;o00000_ooool2o`0000;ooooo7_l0
000>ooooo`;o00001oooool2o`0000Cooooo0ol0000;ooooo`;o000000?oooooo`000?l000002Ooo
ool7o`0000Cooooo0_l0000=ooooo`Go00000_ooool4o`0000_ooooo1?l00007ooooo`?o00002ooo
ool2o`000004ooooool0003o0000ooooo`;o00001Oooool2o`0003kooooo000Looooo`03o`000?oo
oooooooo02_ooooo0_l00005ooooo`?o00001_ooool2o`00013ooooo0ol00004ooooo`;o00000_oo
ool3o`000003ooooool0003o000000;o000000?oooooo`000?l000001Ol000000ooooooo0000o`00
000?o`0000Gooooo0_l00007ooooo`Go00001?ooool2o`0000Gooooo0_l0000>ooooo`;o00000ooo
ool4o`0000;ooooo0_l00003ooooo`;o00001?ooool2o`0000Kooooo0_l00006ooooo`;o00000_oo
ool6o`0000_ooooo1?l00008ooooo`;o00003_ooool2o`000003ooooool0003o000000Gooooo0ol0
000mooooo`007?ooool00ol0003oooooooooo`0booooo`?o00001_ooool2o`0000?ooooo0_l00004
ooooo`;o00003ooooolVo`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l000000_l00003
ooooo`;o00006oooool4o`0001Gooooo0_l00008ooooo`Co000000?oooooo`000?l000000_l0000?
ooooo`?o00003Oooool2o`0000Sooooo0_l00006ooooo`;o0000?Oooool00006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`00
0?oooooooooo043ooooo0_l000001?oooooo0000o`000?ooool2o`0000gooooo:?l00009ooooo`;o
000000?oooooo`000?l000001Oooool2o`0000Oooooo0_l0000Hooooo`;o00003Oooool2o`0000co
oooo0ol00002ooooo`Co00001oooool3o`0000;ooooo0_l000000ooooooo0000o`000003o`0000_o
oooo0_l0000@ooooo`;o0000?Oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q
8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo03?ooooo0_l00008
ooooo`;o00001?ooool2o`0000cooooo0_l00002ooooo`;o00000_oooolIo`000003ooooool0003o
000000Ko00007?ooool4o`000004ooooool0003o0000o`0000Sooooo1?l00008ooooo`Co00002ooo
ool2o`0000Wooooo0_l00007ooooo`;o00000_ooool4o`0000;ooooo0ol00002ooooo`;o00000ooo
ool3o`0001?ooooo0_l00017ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0cooooo`;o00002?oo
ool2o`00013ooooo1?l000000ooooooo0000o`000002o`000003ooooool0003o0000023o00005Ooo
ool2o`0000Gooooo0_l00003ooooo`?o00001Oooool7o`0000Wooooo0ol00003ooooo`;o000000Co
ooooo`000?l0003ooooo0_l0000;ooooo`;o00002oooool4o`0000Oooooo0ol0000Hooooo`;o0000
1?ooool2o`00047ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go
0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000>?ooool2o`0001Gooooo0_l00003ooooo`Co0000
00Coooooo`000?l0003ooooo7_l0000;ooooo`;o00002Oooool3o`00013ooooo1Ol0000<ooooo`;o
00001?ooool2o`000004ooooool0003o0000ooooo`;o00008_ooool4o`0000Cooooo0_l00002oooo
o`;o00000oooool3o`0000Kooooo0_l00006ooooo`;o0000@Oooool00003ooooool0003ooooo00;o
oooo00?o0000ooooooooool02Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000oooo
ooooool0>?ooool4o`0000gooooo0_l00007ooooo`Go00000_oooolRo`0000[ooooo0_l0000:oooo
o`;o000000?oooooo`000?l000000_ooool2o`0000Oooooo1Ol00002ooooo`;o00004?ooool2o`00
00gooooo0_l0000<ooooo`;o00002oooool2o`000003ooooool0003o000000?ooooo0_l000001Ooo
oooo0000o`000?l0003ooooo00Go00001_ooool2o`0000?ooooo0_l000000ooooooo0000o`000011
ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`03oeEEEOn7QhOooooo
00Sooooo00?o0000ooooooooool0>_ooool2o`0000gooooo0_l00003ooooo`;o00000_ooool5o`00
00;ooooo8ol0000;ooooo`;o00002oooool2o`0000;ooooo0_l00007ooooo`;o000000?oooooo`00
0?l000000_ooool2o`00013ooooo0_l00009ooooo`;o00000_ooool2o`0000cooooo0_l0000>oooo
o`;o00001_ooool2o`0000;ooooo0_l00003ooooo`Co00000oooool2o`0000;ooooo0_l00014oooo
o`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000
ooooooooool0;?ooool2o`0001Kooooo0_l00008ooooo`?o00000oooool2o`0000Cooooo1ol00000
0ooooooo0000o`00000Ho`0000Cooooo1?l00003ooooo`;o00007oooool2o`0000Cooooo0_l00002
ooooo`;o00003?ooool2o`0000;ooooo0ol00008ooooo`;o00001oooool2o`000005ooooool0003o
0000o`000?ooool00_l00003ooooo`Co00001_ooool3o`0000?ooooo0_l00002ooooo`Co00000_oo
ool3o`0000;ooooo0_l00014ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`04olc<
c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0;?ooool2o`0001Gooooo0ol00009ooooo`;o
00000_ooool3o`0000Cooooo7ol000000ooooooo0000o`000002o`0000;ooooo1?l00003ooooo`;o
00004oooool2o`0000Oooooo0_l000000ooooooo0000o`000004ooooo`;o00000_ooool2o`0000Wo
oooo0_l000000ooooooo0000o`000002ooooo`;o00001?ooool2o`0000?ooooo0_l00007ooooo`;o
000000Goooooo`000?l0003o0000ooooo`02o`000003ooooool0003o000000Co00001_ooool3o`00
00?ooooo0_l00002ooooo`;o00001?ooool2o`0000?ooooo0_l00014ooooo`007?ooool00ol0003o
ooooooooo`13ooooo`;o00002?ooool2o`0000Cooooo0_l00006oooooaWo00000oooool2o`0000?o
oooo0ol0000Mooooo`;o00001?ooool5o`0000;ooooo0_l000000ooooooo0000o`000002o`0000_o
oooo2_l00005ooooo`;o00002Oooool2o`0000_ooooo1?l0000Booooo`;o00001Oooool2o`0000;o
oooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00003Oooool2o`0000Kooooo
0_l0000:ooooo`_o000000?oooooo`000?l000003?l000000ooooooo0000o`000007ooooo`;o0000
2_ooool2o`0000?ooooo0_l00005ooooo`;o00000_ooool2o`0000Oooooo1?l00003ooooo`;o0000
00?oooooo`000?l000000_l0000:ooooo`?o00000_ooool6o`000003ooooool0003o000000gooooo
0_l00006ooooo`;o00004oooool2o`0000_ooooo0_l00018ooooo`007?ooool00ol0003ooooooooo
o`0fooooo`;o00003Oooool2o`0001;ooooo7Ol00006ooooo`;o00002_ooool5o`000003ooooool0
003o000000Gooooo0_l00002ooooo`Go000000?oooooo`000?l000001_ooool2o`0000gooooo0_l0
0002ooooo`;o00000oooool2o`0000Gooooo0_l000000ooooooo0000o`000003ooooo`?o00001?oo
ool2o`0000Kooooo0_l0000Booooo`?o000000?oooooo`000?l000002?ooool4o`0004Kooooo000L
ooooo`03o`000?oooooooooo05cooooo0_l000000ooooooo0000o`00000Do`0000Oooooo0ol00009
ooooo`Oo00003?ooool7o`0000;ooooo1Ol00004ooooo`;o00001?ooool2o`000003ooooool0003o
000000Kooooo0_l00006ooooo`Go00000oooool3o`0000Cooooo0_l0000Jooooo`?o000000?ooooo
o`000?l000001Oooool2o`0000;ooooo0ol00016ooooo`007?ooool00ol0003oooooooooo`1Boooo
o`;o00001?ooool2o`0000;ooooo0_l00002oooooaCo00000_ooool2o`0000Gooooo0_l0000;oooo
o`Go00001oooool2o`0000?ooooo1ol00002ooooo`_o00000oooool3o`0000Kooooo0_l000000ooo
oooo0000o`000007ooooo`?o00009Oooool5o`000003ooooool0003o000000Gooooo0_l000000ooo
oooo0000o`000018ooooo`007?ooool00ol0003oooooooooo`1Booooo`;o00001?ooool5o`0000?o
oooo5?l00002ooooo`;o00001Oooool2o`0001Oooooo0_l00002ooooo`Ko00001?ooool9o`0000Go
oooo0_l00007ooooo`;o00002_ooool2o`0000oooooo0_l0000:ooooo`;o00002?ooool4o`0000Wo
oooo0_l00002ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0FOooool6o`000004oooo
ool0003o0000o`0000;ooooo2_l000000ooooooo0000o`000006ooooo`;o00000oooool2o`0000Oo
oooo0_l0000@ooooo`Oo00000oooool7o`000003ooooool0003o000000Co00004Oooool2o`000003
ooooool0003o000001;ooooo0_l0000:ooooo`;o00002?ooool2o`0000_ooooo0_l00003ooooo`;o
0000Aoooool001cooooo00?o0000ooooooooool0<?ooool2o`0001cooooo0_l00009ooooo`;o0000
0_ooool2o`000003ooooool0003o000000?o000000?oooooo`000?l000001ol00009ooooo`?o0000
2oooool4o`0000kooooo0_l00003ooooo`;o00000oooool?o`0000;ooooo0_l0000<ooooo`;o0000
00?oooooo`000?l000000_ooool2o`0000_ooooo0_l00002ooooo`;o00001_ooool2o`0000Wooooo
0_l00007ooooo`?o00002?ooool2o`0004Oooooo000Looooo`03o`000?oooooooooo033ooooo0_l0
000Looooo`Co00002?ooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool6o`0000Oooooo
0_l000001?oooooo0000o`000?ooool2o`0000gooooo0_l00004ooooo`;o00002?ooool2o`0000Go
oooo4_l00002ooooo`;o00001_ooool2o`0000;ooooo0_l00003ooooo`_o00001_ooool3o`000003
ooooool0003o000000?ooooo0_l000000ooooooo0000o`000005ooooo`;o00000_ooool2o`0000Oo
oooo0ol000000ooooooo0000o`00001>ooooo`007?ooool00ol0003oooooooooo`1>ooooo`Ko0000
0_ooool2o`0000;ooooo0_l00005ooooo`;o00000oooool2o`0000;ooooo0_l00007ooooo`;o0000
00?oooooo`000?l000000_l0000Dooooo`;o00003?ooool2o`000003ooooool0003o000000go0000
00Coooooo`000?l0003o00001?ooool3o`000005ooooool0003o0000o`000?ooool01Ol000000ooo
oooo0000o`000003o`000003ooooool0003o000000?o00001oooool3o`0000?ooooo1?l00006oooo
o`Co000000?oooooo`000?l000000_l00005ooooo`Co000000?oooooo`000?l000000_ooool2o`00
04[ooooo000Looooo`03o`000?oooooooooo04kooooo0_l00002ooooo`;o00000_ooool2o`0000Wo
oooo0_l0000@ooooo`;o00000oooool3o`0000?ooooo0_l0000Eooooo`;o00001OoooolFo`0000?o
oooo1?l000000ooooooo0000o`000002ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooo
oooo0000o`000002ooooo`Go00001?ooool5o`000003ooooool0003o000000;o00002?ooool4o`00
0003ooooool0003o000000;o00001Oooool4o`0000Gooooo0_l0001:ooooo`007?ooool2o`0003Go
oooo0_l0000Fooooo`;o00002Oooool2o`000003ooooool0003o000000Sooooo0ol00007ooooo`?o
00000_ooool2o`0000;ooooo1?l00003ooooo`;o00001?ooool8o`0000Wooooo0_l00006oooooaOo
000000?oooooo`000?l000000oooool4o`0000?ooooo0_l00004ooooo`;o00001?ooool3o`0000Co
oooo1?l00002ooooo`;o00002?ooool6o`0000?ooooo0_l00006ooooo`Co00005Oooool2o`0003Wo
oooo000Looooo`03o`000?oooooooooo037ooooo0_l000000ooooooo0000o`00000Fooooo`Ko0000
1Oooool2o`000003ooooool0003o000000Sooooo0ol00007ooooo`?o00000_ooool2o`0000;ooooo
1?l00007ooooo`[o00000_ooool2o`0000cooooo6?l00006ooooo`Co00001?ooool2o`0000Wooooo
0ol00005ooooo`;o00000oooool2o`0000Sooooo1?l00005ooooo`;o00000_ooool8o`0001Gooooo
0_l0000iooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00006Oooool6o`0000gooooo0_l0
000<ooooo`;o00001_ooool2o`000003ooooool0003o000000;o00000_ooool2o`0000;ooooo1?l0
0003ooooo`;o00000oooool2o`0000Oooooo0_l00003ooooo`;o000000?oooooo`000?l000004_l0
000?ooooo`;o00002_ooool2o`0000kooooo0_l0000Aooooo`So0000D?ooool001cooooo00?o0000
ooooooooool0BOooool2o`000003ooooool0003o000000?ooooo0_l00003ooooo`;o00001oooool2
o`0000cooooo0_l00006ooooo`;o00000oooool2o`000004ooooool0003o0000o`0000Cooooo0_l0
0003ooooo`;o00001?ooool2o`0000Kooooo0_l00003oooooaWo00002_ooool2o`0000Wooooo0_l0
0002ooooo`;o00003_ooool2o`0000?ooooo0_l00003ooooo`;o00002Oooool6o`00053ooooo000L
ooooo`03o`000?oooooooooo04Wooooo1?l00004ooooo`;o00000oooool2o`0001gooooo0_l00004
ooooo`Co00000oooool2o`0000Cooooo0_l00005ooooo`;o00000oooool2o`0000?ooooo0_l00000
0ooooooo0000o`00000Go`0000Oooooo0_l000000ooooooo0000o`000007ooooo`Co00000_ooool6
o`0000Gooooo0_l00006ooooo`Co000000?oooooo`000?l000000_l00006ooooo`;o000000?ooooo
o`000?l000005oooool2o`0003_ooooo000Looooo`03o`000?oooooooooo04_ooooo0_l00009oooo
o`;o00003oooool2o`0000?ooooo0_l00007ooooo`;o00001?ooool2o`0000Gooooo0_l00004oooo
o`;o000000?oooooo`000?l000001Oooool4o`0000;ooooo0ol000000ooooooo0000o`00000Fo`00
00Sooooo1?l00008ooooo`;o00001_ooool6o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`00
00?ooooo1?l00006ooooo`;o00006_ooool2o`0003_ooooo000Looooo`03o`000?oooooooooo05;o
oooo0_l00002ooooo`;o00003Oooool4o`000003ooooool0003o000000;o00003oooool2o`0000?o
oooo0_l00003ooooo`;o000000Coooooo`000?l0003o00001Oooool2o`0000Cooooo0ol000000ooo
oooo0000o`00000;o`000003ooooool0003o000000[o00002?ooool2o`0000Oooooo0_l0000;oooo
o`;o00001_ooool3o`0001gooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`1Booooo`;o
00001?ooool2o`0000_ooooo0_l00003ooooo`;o00001oooool2o`0000Sooooo0_l00008ooooo`;o
000000Coooooo`000?l0003o00002ooooolBo`000003ooooool0003o000000[o00004?ooool2o`00
00Gooooo1?l0000:ooooo`?o00004Oooool2o`0000[ooooo0_l0001;ooooo`007?ooool00ol0003o
ooooooooo`1Hooooo`;o00001oooool4o`0000kooooo0_l0000Fooooo`;o00000oooool2o`0000Ko
oooo7ol00008ooooo`;o00003Oooool4o`0000_ooooo0_l000000ooooooo0000o`000008ooooo`;o
00001?ooool4o`0005Gooooo000Looooo`03o`000?oooooooooo03[ooooo0_l0000Kooooo`;o0000
1_ooool6o`0000Kooooo0ol0000Mooooo`?o00000_ooool2o`000003ooooool0003o000000Cooooo
0_l000001Ooooooo0000o`000?l0003ooooo01Go00001_ooool2o`0000;ooooo0_l0000@ooooo`?o
00003?ooool2o`0000Kooooo1?l000000ooooooo0000o`000003ooooo`;o00001oooool2o`0004co
oooo000Looooo`03o`000?oooooooooo03[ooooo0_l0000Kooooo`Co00001?ooool2o`0000Gooooo
0_l00003ooooo`?o00001oooool2o`0000?ooooo0_l0000=ooooo`;o000000?oooooo`000?l00000
1Oooool2o`0000_ooooo5ol00004ooooo`;o00002_ooool2o`000003ooooool0003o000000Gooooo
1?l0000:ooooo`;o00001oooool4o`000003ooooool0003o000000Wooooo0_l000000ooooooo0000
o`00001<ooooo`007?ooool00ol0003oooooooooo`1?ooooo`;o00000oooool2o`0000?ooooo0_l0
000:ooooo`?o00000oooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo
0_l0000=ooooo`?o00000_ooool2o`0000kooooo5_l000000ooooooo0000o`000002o`0000kooooo
0_l000001?oooooo0000o`000?ooool2o`0000Cooooo0_l00008ooooo`Co00001Oooool2o`0000;o
oooo0_l00002ooooo`Co00001_ooool2o`0004oooooo000Looooo`03o`000?oooooooooo04;ooooo
0_l0000;ooooo`;o00000oooool2o`0000[ooooo0_l00003ooooo`;o00001?ooool2o`0000;ooooo
0_l000000ooooooo0000o`00000;ooooo`;o00002Oooool2o`0000;ooooo0_l0000>oooooaKo0000
00?oooooo`000?l000000_l0000?ooooo`;o00000oooool2o`0000kooooo0_l00002ooooo`;o0000
0oooool2o`0000Kooooo1?l0001Gooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00003Ooo
ool6o`0000Wooooo0_l00003ooooo`;o00001oooool2o`0000Kooooo0_l00002ooooo`;o00000ooo
ool2o`0001Wooooo0_l000000ooooooo0000o`000007o`000003ooooool0003o000000co000000Co
ooooo`000?l0003ooooo0_l0000=ooooo`;o00002?ooool2o`0000gooooo1?l000001Ooooooo0000
o`000?l0003ooooo00;o00002?ooool2o`0000kooooo0_l00013ooooo`007?ooool00ol0003ooooo
ooooo`1Aooooo`Ko00003_ooool3o`0000Kooooo0_l00006ooooo`;o00000_ooool2o`0001;ooooo
0_l00003ooooo`?o00001?ooool2o`000003ooooool0003o000001Oo00000oooool2o`0001Oooooo
0_l0000>ooooo`?o00000_ooool2o`000003ooooool0003o000000Sooooo0_l00006ooooo`;o0000
1_ooool2o`0004?ooooo000Looooo`03o`000?oooooooooo06;ooooo0_l00002ooooo`;o00009_oo
ool2o`0000?ooooo0ol00004ooooo`;o00001OoooolEo`0000Cooooo0_l0000Hooooo`;o00001ooo
ool2o`0000?ooooo0_l0000=ooooo`;o00001oooool4o`0004_ooooo000Looooo`;o0000Hoooool2
o`00017ooooo1?l0000Eooooo`;o00001_ooool2o`0000Wooooo5ol00002ooooo`;o00003Oooool2
o`000003ooooool0003o000000Cooooo1?l00007ooooo`;o00001oooool4o`0000Oooooo0_l00007
ooooo`Co0000Boooool001cooooo00?o0000ooooooooool0D_ooool2o`0000Kooooo0_l000000ooo
oooo0000o`000002o`000003ooooool0003o000000?ooooo0_l0000;ooooo`Go00005Oooool2o`00
00Kooooo0_l00006ooooo`;o00000_ooool2o`000003ooooool0003o0000017o00000_ooool2o`00
00Sooooo1?l000001?oooooo0000o`000?ooool2o`0000Cooooo0_l0000Booooo`Co00004_ooool2
o`0004_ooooo000Looooo`03o`000?oooooooooo05;ooooo0_l00006ooooo`;o000000?oooooo`00
0?l000000_l00005ooooo`?o00001Oooool2o`0000Cooooo0_l000000ooooooo0000o`00000Eoooo
o`?o000000?oooooo`000?l000002_ooool2o`0000;ooooo4ol00005ooooo`;o00002?ooool4o`00
00?ooooo0_l0000@ooooo`;o00002Oooool2o`0000Cooooo0ol0001Hooooo`007?ooool00ol0003o
ooooooooo`1Gooooo`;o00001_ooool2o`0000Gooooo0_l00006ooooo`;o00002?ooool2o`0000Co
oooo0_l0000?ooooo`;o000000Coooooo`000?l0003o00002?ooool2o`0000?ooooo5?l00003oooo
o`;o00003oooool5o`0000_ooooo0_l000000ooooooo0000o`000009ooooo`Co00000_ooool3o`00
00Kooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`1Gooooo`;o00007oooool2o`0000Co
oooo0_l0000Booooo`Co00001?ooool2o`000003ooooool0003o000000?ooooo1?l00002ooooo`Co
000000?oooooo`000?l000001ol00003ooooo`;o00001Oooool2o`0000Sooooo1Ol00003ooooo`;o
00000_ooool2o`0000;ooooo0_l0000=ooooo`Co00002_ooool2o`00053ooooo000Looooo`03o`00
0?oooooooooo05Cooooo0_l0000:ooooo`;o00000_ooool2o`0000Cooooo0_l00002ooooo`;o0000
3_ooool3o`00017ooooo1_l00002ooooo`?o00000oooool2o`0000Cooooo1Ol0000=ooooo`?o0000
1Oooool2o`0000;ooooo0_l00006ooooo`;o00000oooool3o`0000;ooooo0_l0000;ooooo`?o0000
1Oooool2o`0000Sooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`0looooo`;o00005_oo
ool2o`0000[ooooo0_l00002ooooo`;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`00
0002ooooo`;o00000oooool2o`0000?ooooo0_l0000Booooo`;o000000Coooooo`000?l0003ooooo
1?l00003ooooo`?o00000oooool4o`0000Gooooo0_l00007ooooo`?o00002Oooool2o`0000_ooooo
0_l0000@ooooo`?o00003Oooool4o`0005;ooooo000Looooo`03o`000?oooooooooo03cooooo0_l0
000;ooooo`;o00000oooool2o`00027ooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0
003o000000Cooooo0_l00004ooooo`;o00002?ooool2o`0000Cooooo0_l00005ooooo`?o00001Ooo
ool2o`0000Gooooo0_l000000ooooooo0000o`00000Fooooo`;o00006?ooool2o`0000Cooooo0_l0
0007ooooo`;o0000E?ooool001cooooo00?o0000ooooooooool0BOooool2o`0000?ooooo0_l00006
ooooo`;o00006Oooool2o`0000[ooooo0_l00004ooooo`;o00001?ooool4o`0000Kooooo0_l00006
ooooo`;o00001?ooool2o`0000oooooo0_l00004ooooo`;o00001_ooool2o`0000;ooooo0_l00000
1?oooooo0000o`000?ooool2o`0001kooooo0_l00003ooooo`;o0000F?ooool001cooooo00?o0000
ooooooooool0E_ooool2o`0000Gooooo0_l00006ooooo`;o00001oooool2o`000003ooooool0003o
000000;o00001_ooool2o`0000Oooooo0_l00005ooooo`;o00001?ooool2o`0000Gooooo1Ol00002
ooooo`Co00002Oooool2o`0000[ooooo0_l00006ooooo`;o00000_ooool2o`000003ooooool0003o
000000cooooo0_l0000Hooooo`;o0000F?ooool001cooooo00?o0000ooooooooool0GOooool2o`00
00Kooooo0_l00004ooooo`Go00000_ooool3o`0000Kooooo0_l00007ooooo`;o000000?oooooo`00
0?l000002?ooool2o`0000Gooooo0ol00004ooooo`;o00002_ooool3o`0001Wooooo0_l00006oooo
o`;o00001?ooool2o`0000Oooooo0_l0000:ooooo`;o000000?oooooo`000?l000000_ooool2o`00
05Kooooo000Looooo`03o`000?oooooooooo04Kooooo0_l0000>ooooo`;o00001_ooool2o`0000_o
oooo1?l00008ooooo`;o00003_ooool2o`0002;ooooo0_l0000Rooooo`;o000000?oooooo`000?l0
00001oooool2o`000003ooooool0003o000000[ooooo0_l000001Ooooooo0000o`000?l0003ooooo
00;o0000E_ooool001cooooo00?o0000ooooooooool0A_ooool2o`0000cooooo1?l00002ooooo`;o
00000_ooool2o`0000Sooooo0_l0000=ooooo`;o00003Oooool2o`0000Cooooo0_l0000Tooooo`;o
00000_ooool2o`0000cooooo0_l0000<ooooo`;o00001oooool2o`00017ooooo1?l0001Gooooo`00
7?ooool00ol0003oooooooooo`1Dooooo`;o00001?ooool2o`0000?ooooo0_l000000ooooooo0000
o`000003ooooo`?o00001?ooool2o`0000Oooooo0ol00007ooooo`;o00000oooool3o`0000?ooooo
0_l0000Tooooo`?o000000?oooooo`000?l000003?ooool2o`000003ooooool0003o000000Sooooo
0_l0000Mooooo`;o0000Eoooool001cooooo00?o0000ooooooooool0GOooool4o`000003ooooool0
003o000000?ooooo0_l00005ooooo`;o00001oooool3o`0000Oooooo0_l00003ooooo`Co00001ooo
ool2o`0000gooooo0_l0000?ooooo`Co00000oooool2o`0000Kooooo0ol00004ooooo`;o00002?oo
ool2o`00017ooooo0_l0001Sooooo`007?ooool00ol0003oooooooooo`1Eooooo`;o00001?ooool4
o`0000Sooooo0_l0000Eooooo`;o00001_ooool4o`0000Oooooo0_l0000=ooooo`;o00003oooool2
o`0000Gooooo0_l00006ooooo`?o00000_ooool2o`0000Oooooo0_l0000Dooooo`Go0000H?ooool0
01cooooo0_l0001Fooooo`;o00001?ooool2o`0000[ooooo0_l0000Cooooo`Co00002?ooool2o`00
017ooooo0_l0000:ooooo`;o00007?ooool2o`0000Oooooo0_l0000;ooooo`;o00001?ooool2o`00
00;ooooo1?l00004ooooo`;o0000F_ooool001cooooo00?o0000ooooooooool0E?ooool2o`0000Oo
oooo0_l0000=ooooo`;o00003_ooool2o`0000[ooooo1?l0000?ooooo`;o00002_ooool2o`00023o
oooo1Ol00003ooooo`;o00001_ooool4o`0000Cooooo0_l00007ooooo`;o000000?oooooo`000?l0
0000F_ooool001cooooo00?o0000ooooooooool0D_ooool4o`0000Oooooo0_l0000=ooooo`;o0000
5_ooool2o`0000?ooooo0ol0000Kooooo`;o00006oooool2o`0000?ooooo1Ol00003ooooo`Co0000
1?ooool2o`0000Gooooo0_l00006ooooo`Co0000GOooool001cooooo00?o0000ooooooooool0D_oo
ool2o`0001?ooooo0_l00008ooooo`;o00002Oooool2o`0000Kooooo0_l00003ooooo`;o00003?oo
ool2o`0001;ooooo0_l0000<ooooo`;o00002Oooool2o`0000?ooooo0_l00008ooooo`;o00002?oo
ool2o`000003ooooool0003o000000Kooooo0_l0001Oooooo`007?ooool00ol0003oooooooooo`1J
ooooo`;o000000?oooooo`000?l000002?ooool2o`0000Sooooo0_l00009ooooo`;o00002oooool4
o`0000[ooooo0_l0000:ooooo`;o00001_ooool2o`0000cooooo0_l000001?oooooo0000o`000?l0
0003ooooo`;o00003?ooool2o`0000_ooooo0_l00008ooooo`;o00001?ooool2o`0005[ooooo000L
ooooo`03o`000?oooooooooo05[ooooo0_l000000ooooooo0000o`00000Kooooo`;o000000?ooooo
o`000?l000003?ooool2o`0000Kooooo0_l00005ooooo`Co00001Oooool2o`0000cooooo0_l00002
ooooo`;o00001Oooool3o`0000?ooooo0_l00009ooooo`;o000000?oooooo`000?l000005Oooool2
o`0000Cooooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`1Jooooo`;o00007_ooool6o`00
0003ooooool0003o000000Kooooo0_l000000ooooooo0000o`000003ooooo`Co00001Oooool4o`00
00Oooooo0_l00008ooooo`Co00000_ooool2o`0000_ooooo0_l00005ooooo`;o00000_ooool2o`00
00_ooooo0_l0001]ooooo`007?ooool00ol0003oooooooooo`1/ooooo`;o00003Oooool2o`000004
ooooool0003o0000ooooo`;o00001_ooool5o`0000?ooooo0_l0000Booooo`;o00002?ooool2o`00
00gooooo0_l00009ooooo`;o00002Oooool2o`0000Cooooo1?l00009ooooo`;o0000H?ooool001co
oooo00?o0000ooooooooool0IOooool3o`0000Cooooo0_l0000@ooooo`;o00002?ooool2o`000003
ooooool0003o000000;o00001_ooool2o`00017ooooo0_l0000Dooooo`;o00003Oooool2o`0000;o
oooo0_l000000ooooooo0000o`000006ooooo`;o00001oooool4o`00063ooooo000Looooo`03o`00
0?oooooooooo06Gooooo0ol000000ooooooo0000o`00000Gooooo`;o000000Coooooo`000?l0003o
oooo0_l00003ooooo`;o00001_ooool2o`0000oooooo1?l0000>ooooo`;o00001_ooool2o`0000Co
oooo0_l00005ooooo`;o00000_ooool2o`0000Oooooo1?l00007ooooo`;o0000H_ooool001cooooo
00?o0000ooooooooool0GOooool2o`0000Oooooo0_l000000ooooooo0000o`00000Eooooo`Co0000
00?oooooo`000?l000007oooool3o`000003ooooool0003o000000cooooo0_l000000ooooooo0000
o`000003ooooo`;o00001?ooool2o`0001;ooooo1?l0001[ooooo`007?ooool00ol0003ooooooooo
o`1Mooooo`;o00001oooool2o`0000kooooo0_l000000ooooooo0000o`000005ooooo`Co000000?o
ooooo`000?l000002Oooool2o`0001Gooooo1Ol0000:ooooo`;o00000oooool4o`0000_ooooo0_l0
0003ooooo`;o0000N?ooool001cooooo00?o0000ooooooooool0GOooool2o`000003ooooool0003o
0000013ooooo0_l00002ooooo`;o000000?oooooo`000?l000001_ooool2o`0000gooooo0_l00005
ooooo`;o00003oooool2o`0000cooooo0_l00005ooooo`;o00002oooool2o`0000?ooooo0_l0001h
ooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o00002?ooool2o`0000Gooooo0ol00005oooo
o`;o00001Oooool2o`0000Sooooo0_l00002ooooo`;o00001?ooool2o`000003ooooool0003o0000
00Gooooo0_l00004ooooo`;o00004?ooool2o`0000?ooooo0_l00002ooooo`Co00004?ooool2o`00
07Cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Zooooo`;o00001Oooool3o`0000Sooooo0_l0
0002ooooo`;o00002?ooool2o`0000;ooooo0_l00004ooooo`?o00000_ooool2o`0000?ooooo0_l0
00001?oooooo0000o`000?ooool2o`0000[ooooo0_l000000ooooooo0000o`000006ooooo`;o0000
0_ooool4o`00013ooooo0_l0001dooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o
8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0O?ooool3o`00
01Kooooo0_l00002ooooo`;o00001_ooool2o`000003ooooool0003o000000?ooooo0_l00005oooo
o`;o000000Coooooo`000?l0003o00005?ooool2o`0000Oooooo0_l0001dooooo`0000?ooooooa0@
4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`1Nooooo`;o00007Oooool2o`0000?ooooo0_l0000Pooooo`;o00000_ooool3
o`0000Wooooo0_l0000;ooooo`;o00001oooool2o`000003ooooool0003o000007[ooooo00000ooo
oooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06
ooooo`?o0000G_ooool2o`0001gooooo0_l00003ooooo`;o00008?ooool3o`000003ooooool0003o
000000Kooooo0_l0000?ooooo`;o00002_ooool2o`000003ooooool0003o000000Cooooo0_l0001a
ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05olc<c?l0003o0000
o`000?o<c<`01_ooool00ol0003oooooooooo`1mooooo`;o00000_ooool2o`0000Oooooo0_l0000E
ooooo`Ko000000?oooooo`000?l000001?l00002ooooo`;o00003oooool2o`0000Cooooo0_l00007
ooooo`?o00000oooool2o`00077ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo
00Wooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo07Wooooo0_l00006
ooooo`;o00001oooool2o`0001Cooooo1Ol00005ooooo`Co00002Oooool2o`0000Gooooo0_l00000
0ooooooo0000o`000004ooooo`;o00002?ooool2o`00013ooooo0_l0001Tooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003ooooo
ooooo`1iooooo`;o00003?ooool2o`0000Sooooo0_l00007ooooo`;o00001?ooool2o`0000Oooooo
0_l00002ooooo`;o00002?ooool4o`0000?ooooo1?l0000Qooooo`;o0000I?ooool00006ooooooo^
k^ko<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000oooo
ooooool0NOooool2o`0000cooooo0_l00003ooooo`;o00000oooool3o`0000Kooooo0_l000000ooo
oooo0000o`000008ooooo`Co000000Coooooo`000?l0003o00002_ooool2o`0000Gooooo1?l00025
ooooo`007?ooool00ol0003oooooooooo`20ooooo`;o00001Oooool2o`0000?ooooo0_l00004oooo
o`;o00000oooool2o`0000Cooooo0_l00008ooooo`;o00000oooool2o`0000?ooooo0_l0000?oooo
o`;o00001?ooool2o`0007oooooo000Looooo`03o`000?oooooooooo06Wooooo0_l0000Eooooo`;o
000000?oooooo`000?l000003?ooool2o`0000;ooooo1?l0000>ooooo`Co00000oooool5o`00013o
oooo0_l00003ooooo`;o0000Ooooool001cooooo00?o0000ooooooooool0JOooool2o`0001Kooooo
1?l0000<ooooo`;o00000_ooool2o`0001;ooooo0_l00003ooooo`Co00004Oooool2o`0000Sooooo
0_l0001jooooo`007?ooool00ol0003oooooooooo`21ooooo`;o00002?ooool2o`0000Gooooo0_l0
000iooooo`;o0000N_ooool001cooooo00?o0000ooooooooool0NOooool2o`00013ooooo0_l00002
ooooo`;o000000?oooooo`000?l000000oooool2o`000003ooooool0003o000001_ooooo0_l0002@
ooooo`007?ooool00ol0003oooooooooo`1iooooo`;o00005?ooool2o`000003ooooool0003o0000
00?ooooo2Ol00003ooooo`;o00004_ooool2o`00093ooooo000Looooo`03o`000?oooooooooo07Wo
oooo0_l0000Gooooo`;o00001Oooool2o`000003ooooool0003o000000Oo0000Y?ooool001cooooo
00?o0000ooooooooool0Woooool4o`0000Kooooo0_l00003ooooo`;o00004_ooool2o`0008Gooooo
000Looooo`03o`000?oooooooooo09Wooooo0_l0000:ooooo`Ko00000oooool2o`0000;ooooo0_l0
0003ooooo`;o00002Oooool2o`0008Gooooo000Looooo`03o`000?oooooooooo09Wooooo0_l00008
ooooo`Ko00002Oooool2o`0000?ooooo0ol00008ooooo`;o0000QOooool001cooooo00?o0000oooo
ooooool0U?ooool3o`0000cooooo0_l0000Booooo`?o0000Soooool001cooooo0_l0002>ooooo`;o
00001Oooool3o`000;;ooooo000Looooo`03o`000?oooooooooo08Gooooo0_l00006ooooo`;o0000
7Oooool2o`0009_ooooo000Looooo`03o`000?oooooooooo08Gooooo0_l0000Sooooo`Co00000ooo
ool2o`0009Kooooo000Looooo`03o`000?oooooooooo0:[ooooo0_l00005ooooo`;o0000U_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Zooooo`;o
0000WOooool001cooooo00?o0000ooooooooool0Y?ooool2o`0000Cooooo0_l0002Mooooo`007?oo
ool00ol0003oooooooooo`2Tooooo`;o0000Xoooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`1nooooo`;o0000bOooool001cooooo00?o0000ooooooooool0O_ooool2o`000<Wooooo000Loooo
o`03o`000?oooooooooo08gooooo0_l0002jooooo`007?ooool00ol0003oooooooooo`2=ooooo`;o
0000^_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Booooo`Co0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05
ooooo`?o0000oooooom:ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03
o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?oo
ool00ol0003oooooooooo`3ooooooe;ooooo000Booooo`03oeEEEOmVIVKo00000?ooooooE?ooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:7ooooo00Co410@o`000?l0003ooooo
0_l000000ol@413oooooooooo`0Fooooo`Co000000So410@ooooooooooooV9RHoa0@4?l0003o<S8b
olc<c0?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0S?ooool00:;ooooo00Go0000
ooooooooooooooooo`000009ooooo`Ko00003?ooool00ol0003oooooooooo`02ooooo`05oa0@4?nj
^[[oooooogMgMolb<S800oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoEEEEogMgMooo
ooooV9RHob4Q8@2<ooooo`00X_ooool01Ol0003ooooooooooooooooo000001_ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`02ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go0000oooo
ooooooooooooo`00002<ooooo`00X_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l0000<
ooooo`03o`000?oooooooooo00Gooooo00?oZJVYoa0@4?ooool01?ooool00onHV9So8B4Qonk^kP03
ooooo`05o`000?nHV9SooooooiRHV?lQ8B40S?ooool00:;ooooo00Go0000ohN7QoooooooZJVYo`00
000Kooooo`03o`000?oooooooooo00Cooooo00?o410@o`000?nj^[X01_ooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0S?ooool00:7ooooo00?o410@o`000?mgMgL00_l0
00000onHV9Soooooooooo`0Iooooo`03o`000?oooooooooo00Gooooo00?o^[Zjob4Q8Oooool01_oo
ool01_l0003oooooooooooooooooEEEEohN7Qhoooooo0032ooooo`03o`000?oooooooooo00;ooooo
00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool00ooM
gMgo410@oiRHV02>ooooo`00`?ooool00omEEEGoIVIVo`000004ooooo`05ojVYZOl@413o0000oa0@
4?nYZJT00oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo00Coc<c<odA4A?l0003o410@S?oo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1332) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.30168 .54318 Mdot
.30384 .54903 Mdot
.65311 .55074 Mdot
.46724 .42859 Mdot
.80634 .50793 Mdot
.62536 .57377 Mdot
.5311 .68215 Mdot
.48219 .65637 Mdot
.66444 .55798 Mdot
.43208 .69343 Mdot
.48068 .68065 Mdot
.46811 .32619 Mdot
.50826 .667 Mdot
.43318 .42103 Mdot
.82556 .35894 Mdot
.50821 .41802 Mdot
.29914 .54668 Mdot
.68084 .39547 Mdot
.49072 .36209 Mdot
.61271 .54651 Mdot
.28318 .54498 Mdot
.44043 .41792 Mdot
.33145 .59465 Mdot
.43254 .42096 Mdot
.48 .40503 Mdot
.34535 .58253 Mdot
.29684 .60712 Mdot
.47488 .37878 Mdot
.45401 .36446 Mdot
.47666 .66399 Mdot
.54696 .27444 Mdot
.82369 .40259 Mdot
.43456 .47977 Mdot
.68042 .27632 Mdot
.50301 .64338 Mdot
.27876 .46827 Mdot
.63597 .5676 Mdot
.49757 .68495 Mdot
.49952 .69038 Mdot
.49999 .63643 Mdot
.48849 .67488 Mdot
.32351 .58715 Mdot
.38886 .63945 Mdot
.70905 .61034 Mdot
.48238 .44891 Mdot
.7479 .6546 Mdot
.24617 .55346 Mdot
.4098 .41448 Mdot
.3442 .54721 Mdot
.70157 .4411 Mdot
.65198 .66583 Mdot
.52571 .67183 Mdot
.60336 .55284 Mdot
.10921 .46775 Mdot
.51778 .67458 Mdot
.39744 .36777 Mdot
.64691 .56117 Mdot
.44112 .40417 Mdot
.42911 .41872 Mdot
.30716 .33168 Mdot
.43253 .45349 Mdot
.62857 .41383 Mdot
.36947 .59093 Mdot
.52114 .58573 Mdot
.65554 .56821 Mdot
.4924 .6926 Mdot
.30803 .55512 Mdot
.51263 .66165 Mdot
.37039 .40478 Mdot
.60616 .58503 Mdot
.40876 .41654 Mdot
.4838 .68391 Mdot
.29031 .59397 Mdot
.44754 .37598 Mdot
.70805 .52608 Mdot
.7192 .73159 Mdot
.60057 .41866 Mdot
.27837 .44084 Mdot
.30204 .33075 Mdot
.72876 .47493 Mdot
.49679 .39199 Mdot
.59683 .32569 Mdot
.72587 .71141 Mdot
.36329 .57931 Mdot
.51569 .42053 Mdot
.68757 .39635 Mdot
.45203 .37736 Mdot
.78376 .63898 Mdot
.40265 .42591 Mdot
.63296 .45364 Mdot
.6699 .55599 Mdot
.33354 .55816 Mdot
.47131 .42774 Mdot
.43345 .37472 Mdot
.33837 .29514 Mdot
.42602 .3595 Mdot
.45825 .40776 Mdot
.35527 .54859 Mdot
.52472 .67228 Mdot
.39185 .39521 Mdot
.65674 .62956 Mdot
.66532 .53261 Mdot
.47302 .44154 Mdot
.67082 .58622 Mdot
.3218 .6051 Mdot
.43277 .37614 Mdot
.5069 .69105 Mdot
.45289 .44893 Mdot
.36815 .756 Mdot
.29226 .55656 Mdot
.46864 .36892 Mdot
.65808 .38152 Mdot
.23262 .38926 Mdot
.34076 .55333 Mdot
.64165 .63288 Mdot
.47292 .35667 Mdot
.45683 .39782 Mdot
.31321 .54814 Mdot
.68096 .55694 Mdot
.77074 .65613 Mdot
.36392 .55386 Mdot
.47741 .65099 Mdot
.2746 .56753 Mdot
.46688 .33162 Mdot
.65364 .5784 Mdot
.69517 .63084 Mdot
.34979 .72226 Mdot
.57331 .2686 Mdot
.45076 .38009 Mdot
.401 .6484 Mdot
.64508 .52534 Mdot
.32319 .56186 Mdot
.50854 .65901 Mdot
.51109 .44305 Mdot
.29627 .57656 Mdot
.47712 .68146 Mdot
.65986 .39468 Mdot
.59283 .70402 Mdot
.30691 .59807 Mdot
.54565 .48178 Mdot
.51079 .70866 Mdot
.52041 .6482 Mdot
.56834 .18927 Mdot
.31247 .55575 Mdot
.62488 .40185 Mdot
.50017 .65272 Mdot
.55602 .24666 Mdot
.47346 .45276 Mdot
.56111 .31997 Mdot
.22535 .62275 Mdot
.65451 .25459 Mdot
.60622 .72195 Mdot
.63185 .37882 Mdot
.47611 .69578 Mdot
.47036 .41181 Mdot
.35086 .57468 Mdot
.33923 .58992 Mdot
.43576 .45378 Mdot
.4866 .4098 Mdot
.40652 .41579 Mdot
.41168 .3855 Mdot
.40434 .31021 Mdot
.45208 .34489 Mdot
.23265 .5339 Mdot
.33787 .56055 Mdot
.46735 .42276 Mdot
.61319 .5821 Mdot
.40695 .45506 Mdot
.4854 .67909 Mdot
.44432 .40936 Mdot
.46979 .42686 Mdot
.45478 .45748 Mdot
.52495 .66435 Mdot
.84319 .4473 Mdot
.20921 .43437 Mdot
.82362 .43782 Mdot
.5991 .45236 Mdot
.63319 .59421 Mdot
.46142 .38088 Mdot
.64147 .40838 Mdot
.32295 .44262 Mdot
.45245 .43839 Mdot
.27785 .78219 Mdot
.45193 .41374 Mdot
.81509 .48961 Mdot
.37925 .39539 Mdot
.77867 .36725 Mdot
.58525 .31284 Mdot
.47433 .39922 Mdot
.41846 .61658 Mdot
.49929 .7244 Mdot
.66697 .51851 Mdot
.49206 .67258 Mdot
.61109 .57657 Mdot
.65063 .5539 Mdot
.51692 .59996 Mdot
.48987 .33142 Mdot
.40704 .46399 Mdot
.40181 .40004 Mdot
.62661 .60636 Mdot
.36318 .59281 Mdot
.66621 .39698 Mdot
.32891 .53462 Mdot
.85924 .57574 Mdot
.7242 .64385 Mdot
.52774 .63999 Mdot
.64727 .41794 Mdot
.65873 .53709 Mdot
.67247 .56612 Mdot
.64958 .37779 Mdot
.42328 .39572 Mdot
.31114 .56186 Mdot
.61296 .20315 Mdot
.41765 .77831 Mdot
.5162 .14945 Mdot
.35465 .55078 Mdot
.41925 .6862 Mdot
.47988 .66566 Mdot
.63008 .55587 Mdot
.45783 .40035 Mdot
.43084 .39148 Mdot
.30369 .53036 Mdot
.40696 .40954 Mdot
.27149 .62188 Mdot
.46604 .39729 Mdot
.58771 .65494 Mdot
.6464 .42672 Mdot
.52079 .60003 Mdot
.60192 .26886 Mdot
.35933 .57989 Mdot
.40096 .25066 Mdot
.66624 .58614 Mdot
.31932 .43399 Mdot
.49117 .69562 Mdot
.65241 .40788 Mdot
.65967 .5836 Mdot
.66459 .38895 Mdot
.46621 .34721 Mdot
.60895 .56291 Mdot
.6372 .37104 Mdot
.51765 .32526 Mdot
.45585 .4634 Mdot
.29919 .72691 Mdot
.49614 .63915 Mdot
.33025 .53148 Mdot
.42472 .44905 Mdot
.6501 .59897 Mdot
.49745 .46067 Mdot
.61955 .75071 Mdot
.60272 .64482 Mdot
.65607 .52446 Mdot
.58163 .60884 Mdot
.6365 .41594 Mdot
.66314 .69635 Mdot
.40679 .66719 Mdot
.30869 .54297 Mdot
.42956 .35557 Mdot
.7674 .34271 Mdot
.50111 .65285 Mdot
.43684 .44805 Mdot
.72719 .37666 Mdot
.51248 .65245 Mdot
.44138 .40188 Mdot
.47201 .67608 Mdot
.33795 .59056 Mdot
.27002 .33335 Mdot
.32187 .54211 Mdot
.4058 .3917 Mdot
.51297 .68831 Mdot
.66605 .59781 Mdot
.34161 .57993 Mdot
.41802 .40324 Mdot
.47222 .37925 Mdot
.56226 .55025 Mdot
.46126 .41983 Mdot
.83346 .46631 Mdot
.47057 .39785 Mdot
.63818 .54797 Mdot
.49833 .41401 Mdot
.1733 .43087 Mdot
.5017 .60149 Mdot
.30927 .55627 Mdot
.67184 .53134 Mdot
.65914 .55967 Mdot
.73418 .58514 Mdot
.48875 .62423 Mdot
.48061 .36098 Mdot
.64403 .59781 Mdot
.4581 .2623 Mdot
.49849 .70579 Mdot
.3949 .42964 Mdot
.50804 .50881 Mdot
.69052 .44463 Mdot
.60571 .54956 Mdot
.51427 .45346 Mdot
.31661 .6025 Mdot
.47676 .42457 Mdot
.67513 .56583 Mdot
.52172 .36297 Mdot
.47789 .36644 Mdot
.25042 .62453 Mdot
.5631 .55952 Mdot
.52094 .69965 Mdot
.38215 .39682 Mdot
.42591 .4403 Mdot
.61256 .56963 Mdot
.35807 .57741 Mdot
.50023 .70756 Mdot
.33125 .58633 Mdot
.7538 .34592 Mdot
.31277 .73248 Mdot
.47629 .29514 Mdot
.66966 .40494 Mdot
.70325 .4057 Mdot
.76189 .34901 Mdot
.35695 .24502 Mdot
.44701 .23686 Mdot
.69028 .26581 Mdot
.67812 .5733 Mdot
.72336 .39168 Mdot
.65373 .55975 Mdot
.48905 .39684 Mdot
.65196 .57749 Mdot
.76044 .33279 Mdot
.4647 .39964 Mdot
.64284 .57781 Mdot
.37413 .26587 Mdot
.47606 .42124 Mdot
.30848 .54505 Mdot
.84526 .54887 Mdot
.24395 .31528 Mdot
.59375 .64127 Mdot
.62887 .5398 Mdot
.48894 .22736 Mdot
.45952 .40924 Mdot
.49821 .41085 Mdot
.3492 .56481 Mdot
.47259 .47462 Mdot
.61126 .40415 Mdot
.63418 .41987 Mdot
.45727 .71499 Mdot
.57672 .38918 Mdot
.38306 .38679 Mdot
.34292 .57657 Mdot
.39752 .32047 Mdot
.69177 .50038 Mdot
.70727 .43279 Mdot
.52753 .71057 Mdot
.84417 .54695 Mdot
.28412 .61662 Mdot
.55839 .67194 Mdot
.61399 .50325 Mdot
.32897 .54724 Mdot
.84081 .42781 Mdot
.49542 .67544 Mdot
.31439 .75136 Mdot
.41662 .55008 Mdot
.4251 .39748 Mdot
.50893 .70311 Mdot
.52896 .41603 Mdot
.25958 .29853 Mdot
.39697 .80422 Mdot
.4207 .50375 Mdot
.40275 .43134 Mdot
.67123 .4921 Mdot
.44954 .40534 Mdot
.69241 .71243 Mdot
.47318 .39297 Mdot
.33113 .58289 Mdot
.44222 .71217 Mdot
.45297 .66547 Mdot
.19352 .50331 Mdot
.67015 .70532 Mdot
.6296 .37874 Mdot
.46307 .39516 Mdot
.42407 .40001 Mdot
.61099 .39418 Mdot
.32828 .59767 Mdot
.4049 .40109 Mdot
.40347 .2435 Mdot
.42739 .37905 Mdot
.49019 .68096 Mdot
.40038 .56247 Mdot
.24705 .58532 Mdot
.42411 .37087 Mdot
.32991 .60828 Mdot
.53337 .65637 Mdot
.51212 .68527 Mdot
.38229 .38142 Mdot
.49185 .63677 Mdot
.44949 .42133 Mdot
.4314 .8197 Mdot
.29869 .59243 Mdot
.29138 .65542 Mdot
.30547 .57792 Mdot
.27037 .43353 Mdot
.51979 .65831 Mdot
.61015 .66777 Mdot
.52063 .37455 Mdot
.49928 .67386 Mdot
.28715 .53192 Mdot
.50287 .42463 Mdot
.48008 .45884 Mdot
.57347 .20781 Mdot
.64212 .53998 Mdot
.5615 .57299 Mdot
.47664 .66248 Mdot
.41652 .41937 Mdot
.44094 .35628 Mdot
.53045 .64849 Mdot
.42718 .80178 Mdot
.28682 .29383 Mdot
.46812 .39822 Mdot
.32998 .57415 Mdot
.32177 .56563 Mdot
.42846 .46002 Mdot
.47955 .4339 Mdot
.64688 .58676 Mdot
.68107 .58204 Mdot
.60606 .57838 Mdot
.56327 .5825 Mdot
.60657 .66431 Mdot
.77955 .57809 Mdot
.50048 .63638 Mdot
.40649 .70839 Mdot
.63873 .44915 Mdot
.40043 .39158 Mdot
.63768 .53301 Mdot
.42896 .43973 Mdot
.45268 .42898 Mdot
.50343 .62175 Mdot
.77943 .44678 Mdot
.26355 .58522 Mdot
.35161 .59376 Mdot
.50614 .71277 Mdot
.39429 .34993 Mdot
.54678 .65238 Mdot
.6535 .40101 Mdot
.61292 .22787 Mdot
.48768 .69122 Mdot
.31167 .54508 Mdot
.49279 .64402 Mdot
.43078 .38606 Mdot
.45398 .33972 Mdot
.32474 .54945 Mdot
.60377 .39876 Mdot
.48027 .46873 Mdot
.44446 .39956 Mdot
.21802 .62682 Mdot
.59907 .2382 Mdot
.57659 .67144 Mdot
.47244 .40018 Mdot
.44071 .36389 Mdot
.61913 .3704 Mdot
.42739 .38051 Mdot
.41022 .43363 Mdot
.23958 .38947 Mdot
.36937 .73141 Mdot
.63886 .42222 Mdot
.44137 .81511 Mdot
.35249 .54851 Mdot
.79564 .37087 Mdot
.62089 .55756 Mdot
.44016 .67866 Mdot
.25273 .32686 Mdot
.60172 .55628 Mdot
.60362 .72791 Mdot
.81063 .39271 Mdot
.56635 .61722 Mdot
.69873 .57082 Mdot
.28676 .60474 Mdot
.4078 .39285 Mdot
.45319 .39739 Mdot
.63352 .41103 Mdot
.31211 .56808 Mdot
.54927 .55138 Mdot
.60478 .81116 Mdot
.44365 .41611 Mdot
.28865 .64203 Mdot
.52124 .79925 Mdot
.68789 .45133 Mdot
.64218 .39467 Mdot
.61601 .41722 Mdot
.46097 .39388 Mdot
.21475 .41468 Mdot
.34593 .58119 Mdot
.41791 .40485 Mdot
.44461 .3462 Mdot
.63361 .54038 Mdot
.28848 .56821 Mdot
.67967 .55341 Mdot
.63724 .67587 Mdot
.82208 .4519 Mdot
.24616 .71457 Mdot
.52027 .67165 Mdot
.6581 .75452 Mdot
.47682 .69032 Mdot
.60412 .32333 Mdot
.6302 .52646 Mdot
.47662 .42983 Mdot
.3566 .58185 Mdot
.41953 .42607 Mdot
.48073 .43101 Mdot
.42288 .39796 Mdot
.42392 .36813 Mdot
.19532 .65956 Mdot
.63682 .3746 Mdot
.50979 .37477 Mdot
.64391 .54757 Mdot
.73889 .68332 Mdot
.70471 .73406 Mdot
.42491 .40432 Mdot
.4701 .38541 Mdot
.30057 .58914 Mdot
.43536 .45215 Mdot
.48349 .69835 Mdot
.35606 .53904 Mdot
.44545 .37269 Mdot
.82854 .58236 Mdot
.46101 .36406 Mdot
.80148 .39585 Mdot
.49012 .6473 Mdot
.37993 .76654 Mdot
.4901 .34678 Mdot
.58712 .63259 Mdot
.56145 .57212 Mdot
.65414 .58588 Mdot
.46822 .66279 Mdot
.63766 .56956 Mdot
.57288 .82145 Mdot
.44219 .33703 Mdot
.47335 .41078 Mdot
.40214 .38087 Mdot
.63215 .59404 Mdot
.79608 .61384 Mdot
.68931 .68012 Mdot
.48326 .33878 Mdot
.62723 .58848 Mdot
.34892 .60478 Mdot
.55991 .22136 Mdot
.3127 .5852 Mdot
.67081 .3845 Mdot
.4819 .67089 Mdot
.60607 .40285 Mdot
.72522 .35232 Mdot
.29763 .5516 Mdot
.30593 .5346 Mdot
.62245 .56005 Mdot
.42585 .55286 Mdot
.27132 .23956 Mdot
.41733 .55397 Mdot
.58686 .29361 Mdot
.34514 .5686 Mdot
.44485 .36641 Mdot
.63755 .33144 Mdot
.42324 .58091 Mdot
.64076 .57027 Mdot
.44558 .43552 Mdot
.27094 .32863 Mdot
.64709 .58685 Mdot
.40027 .38099 Mdot
.64573 .54395 Mdot
.48838 .66821 Mdot
.64692 .53164 Mdot
.35092 .52578 Mdot
.45998 .37354 Mdot
.32595 .18955 Mdot
.69015 .36193 Mdot
.4637 .40878 Mdot
.51094 .71405 Mdot
.53925 .75727 Mdot
.45704 .44305 Mdot
.65414 .37384 Mdot
.63447 .58293 Mdot
.42862 .5264 Mdot
.47024 .39611 Mdot
.62333 .58747 Mdot
.29668 .54562 Mdot
.46981 .68912 Mdot
.33245 .3032 Mdot
.57871 .63285 Mdot
.35043 .56371 Mdot
.57179 .45905 Mdot
.47542 .64406 Mdot
.43901 .36437 Mdot
.43026 .35654 Mdot
.32664 .57287 Mdot
.52557 .3179 Mdot
.48409 .43708 Mdot
.49641 .39577 Mdot
.63093 .54683 Mdot
.63559 .57308 Mdot
.39626 .27453 Mdot
.68225 .5698 Mdot
.45671 .3401 Mdot
.32573 .57519 Mdot
.46878 .42991 Mdot
.29398 .58498 Mdot
.43745 .45211 Mdot
.46822 .31666 Mdot
.33027 .59754 Mdot
.53933 .6211 Mdot
.44981 .4333 Mdot
.42085 .47597 Mdot
.44829 .44887 Mdot
.40956 .39305 Mdot
.65451 .58158 Mdot
.64725 .3994 Mdot
.42043 .35563 Mdot
.59878 .37716 Mdot
.66401 .39286 Mdot
.45769 .68038 Mdot
.63657 .53942 Mdot
.62006 .39473 Mdot
.53315 .80441 Mdot
.60635 .56614 Mdot
.62016 .409 Mdot
.70614 .73231 Mdot
.50698 .64402 Mdot
.30916 .60121 Mdot
.47874 .41898 Mdot
.7285 .33438 Mdot
.24126 .56159 Mdot
.69048 .56021 Mdot
.46897 .40075 Mdot
.43863 .44657 Mdot
.36684 .56298 Mdot
.59977 .83038 Mdot
.60642 .5852 Mdot
.47101 .36198 Mdot
.30112 .55504 Mdot
.58483 .85222 Mdot
.64281 .55198 Mdot
.62509 .41124 Mdot
.51108 .64166 Mdot
.26034 .5595 Mdot
.34736 .722 Mdot
.5283 .68966 Mdot
.63964 .49933 Mdot
.64105 .66741 Mdot
.46988 .35441 Mdot
.63756 .53109 Mdot
.52958 .16625 Mdot
.36895 .36463 Mdot
.53798 .592 Mdot
.49716 .22615 Mdot
.33368 .54956 Mdot
.47909 .69317 Mdot
.63441 .37711 Mdot
.35658 .5558 Mdot
.29642 .54907 Mdot
.52345 .63904 Mdot
.2227 .42755 Mdot
.50143 .51123 Mdot
.49492 .68759 Mdot
.64927 .27136 Mdot
.77735 .54542 Mdot
.63474 .53347 Mdot
.61129 .40333 Mdot
.73356 .36493 Mdot
.32627 .58796 Mdot
.85387 .52798 Mdot
.57877 .20469 Mdot
.45811 .408 Mdot
.62411 .39351 Mdot
.79402 .59537 Mdot
.65615 .79448 Mdot
.516 .65629 Mdot
.45329 .68964 Mdot
.61724 .41264 Mdot
.42496 .44842 Mdot
.55571 .22982 Mdot
.49453 .40093 Mdot
.48218 .66572 Mdot
.34742 .30505 Mdot
.29906 .54836 Mdot
.52151 .64221 Mdot
.60812 .22323 Mdot
.44763 .42142 Mdot
.45034 .43469 Mdot
.62556 .28068 Mdot
.36114 .56459 Mdot
.65383 .58637 Mdot
.46013 .34874 Mdot
.4448 .40327 Mdot
.41563 .35299 Mdot
.38363 .40145 Mdot
.24411 .36919 Mdot
.48436 .39266 Mdot
.7225 .66254 Mdot
.40257 .43364 Mdot
.44079 .42994 Mdot
.32609 .60784 Mdot
.24803 .72486 Mdot
.65988 .67333 Mdot
.44514 .40704 Mdot
.45305 .36125 Mdot
.51842 .64071 Mdot
.44707 .53963 Mdot
.43248 .54145 Mdot
.43321 .52197 Mdot
.4683 .23065 Mdot
.44215 .46631 Mdot
.30609 .56156 Mdot
.63786 .36975 Mdot
.47154 .35922 Mdot
.30392 .5592 Mdot
.46817 .45341 Mdot
.64497 .58858 Mdot
.60654 .56768 Mdot
.37961 .35079 Mdot
.62011 .38935 Mdot
.34131 .63061 Mdot
.40158 .70626 Mdot
.61034 .5692 Mdot
.47611 .40958 Mdot
.4899 .61838 Mdot
.67426 .56675 Mdot
.59247 .62472 Mdot
.5499 .35402 Mdot
.35242 .57744 Mdot
.33678 .55821 Mdot
.55881 .32146 Mdot
.61225 .70862 Mdot
.19206 .56286 Mdot
.48708 .66801 Mdot
.49284 .35818 Mdot
.41328 .64881 Mdot
.33964 .55651 Mdot
.62639 .32486 Mdot
.62254 .39126 Mdot
.51061 .65057 Mdot
.6868 .51417 Mdot
.2981 .58286 Mdot
.28362 .55958 Mdot
.40995 .4463 Mdot
.43694 .39814 Mdot
.43855 .24023 Mdot
.61488 .36293 Mdot
.53018 .68727 Mdot
.6142 .40755 Mdot
.63096 .52653 Mdot
.48378 .38165 Mdot
.33459 .59543 Mdot
.76808 .56205 Mdot
.46556 .35732 Mdot
.66651 .56898 Mdot
.33297 .5525 Mdot
.63443 .41639 Mdot
.65122 .37069 Mdot
.41309 .38712 Mdot
.35854 .31838 Mdot
.50106 .68234 Mdot
.32589 .54445 Mdot
.54867 .64835 Mdot
.49503 .41692 Mdot
.4431 .39188 Mdot
.37912 .43191 Mdot
.52977 .68889 Mdot
.45078 .75704 Mdot
.6688 .39841 Mdot
.31458 .56327 Mdot
.47997 .38915 Mdot
.61362 .40038 Mdot
.42115 .71254 Mdot
.6513 .52277 Mdot
.65101 .53246 Mdot
.64457 .36788 Mdot
.6341 .39344 Mdot
.66125 .3817 Mdot
.85469 .527 Mdot
.37062 .56099 Mdot
.2822 .61482 Mdot
.50348 .40134 Mdot
.58319 .30596 Mdot
.52149 .3977 Mdot
.50686 .70928 Mdot
.64641 .54056 Mdot
.4666 .44116 Mdot
.42264 .37489 Mdot
.38152 .37627 Mdot
.27823 .64522 Mdot
.25304 .56729 Mdot
.28865 .56142 Mdot
.46694 .33934 Mdot
.62642 .54409 Mdot
.86614 .57199 Mdot
.62932 .19608 Mdot
.48723 .34502 Mdot
.50098 .50793 Mdot
.34068 .59512 Mdot
.50625 .63551 Mdot
.66563 .30796 Mdot
.50503 .64186 Mdot
.31722 .56058 Mdot
.4848 .38965 Mdot
.40809 .72201 Mdot
.62453 .36643 Mdot
.41255 .41258 Mdot
.48405 .65889 Mdot
.41013 .41945 Mdot
.52994 .68606 Mdot
.75832 .35851 Mdot
.49152 .18979 Mdot
.45271 .41261 Mdot
.51669 .40281 Mdot
.46729 .21683 Mdot
.42288 .40923 Mdot
.66306 .363 Mdot
.34075 .59535 Mdot
.35455 .28887 Mdot
.49469 .44467 Mdot
.35582 .36537 Mdot
.49655 .40934 Mdot
.34106 .28282 Mdot
.43987 .39129 Mdot
.67983 .45887 Mdot
.4666 .37031 Mdot
.40571 .42468 Mdot
.51854 .68109 Mdot
.52156 .64305 Mdot
.29591 .60016 Mdot
.65786 .59724 Mdot
.81325 .41508 Mdot
.4447 .39633 Mdot
.61466 .64671 Mdot
.40499 .74861 Mdot
.63669 .39336 Mdot
.31628 .56617 Mdot
.64578 .818 Mdot
.47504 .66105 Mdot
.54607 .19558 Mdot
.40742 .26866 Mdot
.3451 .68529 Mdot
.69298 .35076 Mdot
.53311 .77498 Mdot
.64609 .41414 Mdot
.45678 .45655 Mdot
.77812 .50059 Mdot
.66988 .46724 Mdot
.54011 .34359 Mdot
.47104 .64786 Mdot
.33131 .41405 Mdot
.78316 .466 Mdot
.65955 .37028 Mdot
.61782 .41559 Mdot
.52737 .67591 Mdot
.69403 .59369 Mdot
.48374 .3303 Mdot
.62709 .38859 Mdot
.61881 .59011 Mdot
.60687 .55737 Mdot
.60087 .57178 Mdot
.34489 .58516 Mdot
.59391 .19755 Mdot
.53648 .6438 Mdot
.51864 .701 Mdot
.63656 .61809 Mdot
.37712 .49492 Mdot
.36469 .53901 Mdot
.62933 .5615 Mdot
.66973 .54302 Mdot
.33504 .59904 Mdot
.39377 .36898 Mdot
.42037 .33777 Mdot
.44487 .412 Mdot
.64351 .4055 Mdot
.43456 .39363 Mdot
.63063 .58821 Mdot
.51673 .66201 Mdot
.66531 .54082 Mdot
.50692 .71616 Mdot
.76919 .59963 Mdot
.41624 .39712 Mdot
.46408 .37301 Mdot
.23529 .66075 Mdot
.27842 .56234 Mdot
.7464 .64234 Mdot
.57377 .64624 Mdot
.65252 .55757 Mdot
.41253 .43619 Mdot
.35432 .53732 Mdot
.61326 .36603 Mdot
.26553 .72376 Mdot
.48 .43613 Mdot
.32027 .59241 Mdot
.48164 .38153 Mdot
.40323 .30553 Mdot
.16501 .46659 Mdot
.32375 .58275 Mdot
.22589 .6147 Mdot
.45478 .36284 Mdot
.57217 .78901 Mdot
.39541 .42728 Mdot
.49684 .27961 Mdot
.48428 .43685 Mdot
.3535 .54884 Mdot
.44153 .41129 Mdot
.34757 .53566 Mdot
.6127 .56353 Mdot
.50917 .63754 Mdot
.34701 .56183 Mdot
.42405 .3635 Mdot
.3541 .12785 Mdot
.48956 .66053 Mdot
.46016 .39763 Mdot
.52209 .65846 Mdot
.30974 .5711 Mdot
.34533 .54909 Mdot
.65494 .78673 Mdot
.63818 .67813 Mdot
.48989 .66797 Mdot
.48306 .38142 Mdot
.61469 .76513 Mdot
.48575 .41667 Mdot
.47668 .25351 Mdot
.39763 .36891 Mdot
.50012 .41103 Mdot
.70901 .73641 Mdot
.52041 .70096 Mdot
.18623 .55334 Mdot
.68974 .76611 Mdot
.73698 .68746 Mdot
.28911 .5386 Mdot
.65279 .36612 Mdot
.84293 .43564 Mdot
.60578 .66591 Mdot
.62688 .5895 Mdot
.45755 .44525 Mdot
.37388 .52841 Mdot
.50346 .68584 Mdot
.65266 .39564 Mdot
.45322 .41143 Mdot
.66165 .53473 Mdot
.32555 .2661 Mdot
.48386 .70388 Mdot
.31973 .58497 Mdot
.36286 .58583 Mdot
.44343 .84098 Mdot
.47565 .39658 Mdot
.45629 .37242 Mdot
.48143 .66973 Mdot
.49504 .78384 Mdot
.6593 .40585 Mdot
.37449 .26269 Mdot
.49149 .667 Mdot
.52155 .54795 Mdot
.30698 .55204 Mdot
.4355 .44552 Mdot
.82564 .5521 Mdot
.71554 .55132 Mdot
.24327 .65439 Mdot
.64057 .40837 Mdot
.48224 .25227 Mdot
.35159 .54726 Mdot
.5052 .65619 Mdot
.58063 .72436 Mdot
.4346 .46806 Mdot
.42879 .43749 Mdot
.49215 .25806 Mdot
.45418 .6679 Mdot
.41436 .50908 Mdot
.48657 .42942 Mdot
.56088 .58351 Mdot
.46841 .44489 Mdot
.48155 .46228 Mdot
.41561 .34807 Mdot
.44875 .38423 Mdot
.32933 .59484 Mdot
.38208 .47851 Mdot
.64764 .59368 Mdot
.32342 .62427 Mdot
.51873 .55602 Mdot
.46504 .4042 Mdot
.49285 .38488 Mdot
.32748 .50447 Mdot
.591 .74673 Mdot
.34391 .56169 Mdot
.3137 .5298 Mdot
.4847 .64177 Mdot
.40545 .34827 Mdot
.66501 .59166 Mdot
.5048 .44783 Mdot
.66045 .5758 Mdot
.33381 .5946 Mdot
.64896 .55536 Mdot
.51625 .64454 Mdot
.62449 .53857 Mdot
.60746 .66423 Mdot
.4959 .65098 Mdot
.35312 .57231 Mdot
.4431 .37641 Mdot
.50944 .71411 Mdot
.57826 .26005 Mdot
.64154 .40654 Mdot
.73549 .74341 Mdot
.44637 .37197 Mdot
.36223 .73124 Mdot
.53072 .36728 Mdot
.66825 .5426 Mdot
.16535 .47816 Mdot
.34909 .59458 Mdot
.62139 .42135 Mdot
.36187 .57694 Mdot
.58585 .22335 Mdot
.63554 .40094 Mdot
.7391 .7172 Mdot
.5812 .51663 Mdot
.59058 .23547 Mdot
.39289 .36413 Mdot
.61423 .26327 Mdot
.61072 .54269 Mdot
.50561 .68554 Mdot
.5895 .72552 Mdot
.40892 .43009 Mdot
.39467 .21404 Mdot
.34705 .60262 Mdot
.65517 .59734 Mdot
.51102 .66161 Mdot
.50074 .7085 Mdot
.49435 .37181 Mdot
.73059 .44986 Mdot
.4224 .43672 Mdot
.61597 .69591 Mdot
.47409 .23511 Mdot
.25299 .60457 Mdot
.46552 .39737 Mdot
.61247 .56849 Mdot
.48177 .38176 Mdot
.66741 .4105 Mdot
.56972 .18171 Mdot
.46718 .47355 Mdot
.57233 .66494 Mdot
.69072 .3672 Mdot
.31744 .54727 Mdot
.5407 .36965 Mdot
.58741 .666 Mdot
.47799 .39616 Mdot
.14662 .61621 Mdot
.61643 .40584 Mdot
.77682 .49531 Mdot
.43813 .36067 Mdot
.48228 .36098 Mdot
.48882 .59092 Mdot
.33329 .70893 Mdot
.70614 .52834 Mdot
.42434 .41821 Mdot
.52745 .25943 Mdot
.52614 .68795 Mdot
.43695 .45031 Mdot
.45548 .39642 Mdot
.22909 .46804 Mdot
.49715 .71014 Mdot
.65882 .55433 Mdot
.60231 .55122 Mdot
.68865 .5575 Mdot
.6612 .41609 Mdot
.51175 .73298 Mdot
.61338 .31288 Mdot
.28345 .28408 Mdot
.60088 .40506 Mdot
.42264 .37711 Mdot
.66269 .34953 Mdot
.48851 .39109 Mdot
.64746 .38844 Mdot
.49431 .70923 Mdot
.34572 .55812 Mdot
.41783 .66564 Mdot
.60347 .56618 Mdot
.41145 .46481 Mdot
.65918 .40861 Mdot
.35098 .57569 Mdot
.68896 .3321 Mdot
.31479 .55074 Mdot
.49929 .66924 Mdot
.53363 .71112 Mdot
.65242 .39195 Mdot
.3063 .57384 Mdot
.56239 .66521 Mdot
.63345 .80612 Mdot
.43064 .34061 Mdot
.48328 .74721 Mdot
.33672 .53954 Mdot
.32818 .52734 Mdot
.35073 .54038 Mdot
.40796 .40854 Mdot
.50318 .50727 Mdot
.48785 .44291 Mdot
.52229 .6986 Mdot
.64967 .54538 Mdot
.43723 .22005 Mdot
.70214 .63761 Mdot
.55022 .46022 Mdot
.48395 .34919 Mdot
.44578 .42226 Mdot
.4607 .39416 Mdot
.49548 .44588 Mdot
.59082 .6934 Mdot
.42199 .43139 Mdot
.51845 .68278 Mdot
.63529 .5851 Mdot
.4573 .45675 Mdot
.595 .5916 Mdot
.73203 .68322 Mdot
.60212 .3951 Mdot
.48904 .73171 Mdot
.63556 .18566 Mdot
.35007 .572 Mdot
.67128 .53159 Mdot
.61947 .58255 Mdot
.65859 .39706 Mdot
.49582 .68357 Mdot
.31258 .55308 Mdot
.46523 .25994 Mdot
.66319 .39046 Mdot
.44279 .40822 Mdot
.49139 .50411 Mdot
.43072 .19908 Mdot
.45592 .45552 Mdot
.46283 .43795 Mdot
.59684 .5525 Mdot
.77276 .47466 Mdot
.39513 .16381 Mdot
.63322 .30758 Mdot
.65035 .39628 Mdot
.61806 .37832 Mdot
.31705 .60005 Mdot
.50221 .42836 Mdot
.5263 .69406 Mdot
.4053 .5361 Mdot
.51433 .74474 Mdot
.38446 .60688 Mdot
.27485 .68108 Mdot
.47022 .4418 Mdot
.45351 .80612 Mdot
.44973 .42339 Mdot
.37028 .56052 Mdot
.33361 .59219 Mdot
.33796 .57462 Mdot
.50552 .68442 Mdot
.29093 .45167 Mdot
.51263 .69026 Mdot
.61481 .16511 Mdot
.34167 .5444 Mdot
.57484 .53172 Mdot
.62566 .55341 Mdot
.47406 .33614 Mdot
.62595 .41486 Mdot
.52854 .72149 Mdot
.37079 .40234 Mdot
.19411 .43895 Mdot
.6503 .59681 Mdot
.35353 .56951 Mdot
.5191 .77261 Mdot
.71145 .26853 Mdot
.43556 .5298 Mdot
.38312 .36314 Mdot
.66987 .30938 Mdot
.63974 .39102 Mdot
.24334 .6558 Mdot
.61646 .41091 Mdot
.48451 .65745 Mdot
.46654 .37629 Mdot
.45223 .37787 Mdot
.46647 .44642 Mdot
.41957 .40135 Mdot
.4876 .63529 Mdot
.42783 .35521 Mdot
.17338 .43074 Mdot
.60747 .57398 Mdot
.50492 .31341 Mdot
.62194 .41187 Mdot
.46555 .66513 Mdot
.63416 .58569 Mdot
.59054 .74393 Mdot
.60002 .27183 Mdot
.46892 .3968 Mdot
.46404 .44269 Mdot
.53333 .18889 Mdot
.4879 .42765 Mdot
.50559 .34929 Mdot
.62491 .58855 Mdot
.551 .43857 Mdot
.60255 .39846 Mdot
.61355 .38186 Mdot
.49686 .64858 Mdot
.33021 .594 Mdot
.62027 .40484 Mdot
.6275 .54972 Mdot
.48136 .34773 Mdot
.43859 .35104 Mdot
.3381 .54001 Mdot
.54822 .18221 Mdot
.66893 .39366 Mdot
.6003 .77272 Mdot
.35471 .58173 Mdot
.27836 .58995 Mdot
.42964 .43802 Mdot
.25839 .65143 Mdot
.329 .52259 Mdot
.61395 .42106 Mdot
.46632 .66328 Mdot
.64737 .29451 Mdot
.47755 .6801 Mdot
.31671 .58521 Mdot
.47727 .36506 Mdot
.34499 .58872 Mdot
.47286 .39841 Mdot
.74817 .28549 Mdot
.44707 .3814 Mdot
.26858 .2939 Mdot
.54336 .30915 Mdot
.62295 .57149 Mdot
.57184 .76021 Mdot
.62109 .55836 Mdot
.35852 .57494 Mdot
.47156 .35692 Mdot
.6454 .41776 Mdot
.70559 .71715 Mdot
.38295 .52502 Mdot
.67133 .5593 Mdot
.6408 .60584 Mdot
.47416 .676 Mdot
.4795 .44172 Mdot
.42651 .43564 Mdot
.64077 .57704 Mdot
.25397 .61165 Mdot
.29888 .57889 Mdot
.4718 .3832 Mdot
.4417 .42526 Mdot
.6228 .56828 Mdot
.61572 .81402 Mdot
.36592 .45949 Mdot
.46169 .37991 Mdot
.72429 .61369 Mdot
.50872 .70804 Mdot
.4542 .33518 Mdot
.51791 .39616 Mdot
.63183 .39187 Mdot
.28385 .34655 Mdot
.6151 .21304 Mdot
.48984 .70717 Mdot
.61538 .58147 Mdot
.47774 .39289 Mdot
.61234 .57027 Mdot
.4353 .35165 Mdot
.32764 .70051 Mdot
.64673 .52428 Mdot
.49732 .39388 Mdot
.38799 .38144 Mdot
.36152 .56373 Mdot
.46811 .44194 Mdot
.31082 .50198 Mdot
.6683 .57726 Mdot
.49077 .36887 Mdot
.35455 .31764 Mdot
.49194 .68929 Mdot
.39037 .36587 Mdot
.65122 .37748 Mdot
.45937 .25896 Mdot
.38311 .70473 Mdot
.77044 .42513 Mdot
.61441 .37901 Mdot
.41155 .42153 Mdot
.64403 .60389 Mdot
.53104 .67858 Mdot
.24217 .31982 Mdot
.42604 .44751 Mdot
.48308 .66373 Mdot
.51561 .66015 Mdot
.65247 .40165 Mdot
.26383 .73914 Mdot
.42908 .36613 Mdot
.4263 .4026 Mdot
.25232 .49243 Mdot
.28693 .5518 Mdot
.43796 .38612 Mdot
.4339 .37205 Mdot
.52009 .68138 Mdot
.44049 .32362 Mdot
.33966 .44398 Mdot
.35846 .27097 Mdot
.53567 .66785 Mdot
.4079 .60362 Mdot
.6203 .53818 Mdot
.61416 .39178 Mdot
.32529 .55263 Mdot
.65533 .41205 Mdot
.63786 .53582 Mdot
.4353 .37309 Mdot
.48685 .64448 Mdot
.26966 .51527 Mdot
.52746 .67462 Mdot
.74928 .4024 Mdot
.31699 .5394 Mdot
.42841 .62885 Mdot
.17351 .65502 Mdot
.6634 .72084 Mdot
.48217 .61589 Mdot
.63626 .39356 Mdot
.70625 .59421 Mdot
.44349 .42491 Mdot
.24262 .66034 Mdot
.42168 .38012 Mdot
.35075 .31592 Mdot
.61046 .58081 Mdot
.60618 .57923 Mdot
.46511 .3782 Mdot
.4703 .23893 Mdot
.53146 .67629 Mdot
.50087 .70579 Mdot
.49854 .38813 Mdot
.4987 .67362 Mdot
.43406 .40181 Mdot
.64148 .58782 Mdot
.18118 .57386 Mdot
.44928 .41016 Mdot
.49793 .44706 Mdot
.33838 .70084 Mdot
.70718 .74481 Mdot
.71121 .39181 Mdot
.50238 .84191 Mdot
.68897 .24602 Mdot
.50032 .67383 Mdot
.50037 .42373 Mdot
.40521 .60582 Mdot
.596 .56291 Mdot
.55833 .67686 Mdot
.43344 .37968 Mdot
.42491 .38116 Mdot
.40512 .42593 Mdot
.45495 .43474 Mdot
.27625 .71848 Mdot
.39326 .53136 Mdot
.28257 .38735 Mdot
.47743 .4346 Mdot
.59461 .25491 Mdot
.48982 .64977 Mdot
.26542 .55444 Mdot
.60035 .40921 Mdot
.46913 .44221 Mdot
.3366 .61815 Mdot
.50778 .63316 Mdot
.6081 .15887 Mdot
.48274 .65672 Mdot
.65877 .56043 Mdot
.52231 .64888 Mdot
.46193 .41849 Mdot
.32216 .56588 Mdot
.45785 .57175 Mdot
.66534 .69204 Mdot
.6287 .59068 Mdot
.46397 .4083 Mdot
.56921 .57204 Mdot
.64642 .59508 Mdot
.74426 .67361 Mdot
.32586 .55949 Mdot
.53196 .26295 Mdot
.34044 .59123 Mdot
.49554 .37916 Mdot
.49324 .3765 Mdot
.53322 .64442 Mdot
.51811 .64453 Mdot
.33818 .5921 Mdot
.28302 .76754 Mdot
.66505 .38628 Mdot
.33671 .57815 Mdot
.42973 .46917 Mdot
.48729 .52817 Mdot
.32618 .56786 Mdot
.679 .40629 Mdot
.5191 .66913 Mdot
.28819 .58874 Mdot
.40045 .42919 Mdot
.64644 .26425 Mdot
.63573 .36851 Mdot
.61623 .53214 Mdot
.65561 .33147 Mdot
.67226 .57243 Mdot
.46793 .66186 Mdot
.62028 .56021 Mdot
.52365 .69061 Mdot
.39029 .72717 Mdot
.3092 .62649 Mdot
.46804 .62159 Mdot
.47419 .64938 Mdot
.62281 .5604 Mdot
.47259 .37682 Mdot
.69175 .36307 Mdot
.50658 .39109 Mdot
.40889 .37739 Mdot
.51488 .69997 Mdot
.35622 .5568 Mdot
.31831 .52549 Mdot
.56312 .23401 Mdot
.31802 .59462 Mdot
.66764 .56663 Mdot
.19273 .41915 Mdot
.6364 .64471 Mdot
.48323 .68828 Mdot
.51392 .639 Mdot
.49319 .40317 Mdot
.63855 .56971 Mdot
.62086 .58925 Mdot
.47509 .67389 Mdot
.30812 .65497 Mdot
.5129 .41342 Mdot
.34369 .52709 Mdot
.28357 .55708 Mdot
.32472 .57978 Mdot
.34803 .5383 Mdot
.35338 .44968 Mdot
.51118 .64839 Mdot
.35786 .5616 Mdot
.49399 .40736 Mdot
.42836 .38053 Mdot
.41605 .56402 Mdot
.62532 .37598 Mdot
.45543 .45853 Mdot
.41156 .35051 Mdot
.43632 .44467 Mdot
.64858 .53043 Mdot
.49027 .47785 Mdot
.65498 .52676 Mdot
.63217 .60073 Mdot
.6251 .59605 Mdot
.60519 .66496 Mdot
.52212 .2038 Mdot
.71002 .29104 Mdot
.46924 .36085 Mdot
.49842 .79781 Mdot
.63953 .55923 Mdot
.18083 .45475 Mdot
.45445 .75904 Mdot
.41721 .43974 Mdot
.71699 .53901 Mdot
.63611 .57645 Mdot
.34097 .59737 Mdot
.43866 .37975 Mdot
.68478 .55456 Mdot
.64954 .37498 Mdot
.49986 .37753 Mdot
.64584 .52322 Mdot
.30657 .57067 Mdot
.6202 .42482 Mdot
.27911 .5743 Mdot
.62197 .59472 Mdot
.38253 .38537 Mdot
.17969 .3368 Mdot
.66277 .6037 Mdot
.5764 .80246 Mdot
.46189 .31105 Mdot
.47246 .38053 Mdot
.67628 .54329 Mdot
.27229 .57339 Mdot
.46796 .66702 Mdot
.5684 .50225 Mdot
.28759 .58136 Mdot
.60598 .57893 Mdot
.67396 .55735 Mdot
.6275 .59042 Mdot
.2879 .55978 Mdot
.44069 .46367 Mdot
.29011 .57862 Mdot
.52496 .65456 Mdot
.47996 .42065 Mdot
.76276 .35145 Mdot
.48251 .78846 Mdot
.35111 .58695 Mdot
.66011 .54931 Mdot
.62155 .3687 Mdot
.45208 .41815 Mdot
.48292 .79298 Mdot
.47643 .37886 Mdot
.51802 .69995 Mdot
.248 .37901 Mdot
.27105 .52712 Mdot
.50086 .4115 Mdot
.49203 .40599 Mdot
.5014 .70487 Mdot
.45958 .40746 Mdot
.48314 .43811 Mdot
.60652 .66924 Mdot
.29029 .56656 Mdot
.44069 .41516 Mdot
.64054 .54457 Mdot
.64676 .66038 Mdot
.50992 .42461 Mdot
.67732 .62825 Mdot
.51955 .26546 Mdot
.24011 .39637 Mdot
.42279 .37925 Mdot
.4709 .50378 Mdot
.44382 .43651 Mdot
.4134 .40749 Mdot
.48954 .39875 Mdot
.33359 .7707 Mdot
.64168 .52505 Mdot
.62037 .57966 Mdot
.62409 .37287 Mdot
.52201 .26544 Mdot
.62663 .39204 Mdot
.51977 .66618 Mdot
.74341 .46561 Mdot
.65359 .52607 Mdot
.31003 .58133 Mdot
.41394 .41901 Mdot
.66294 .60335 Mdot
.43199 .44367 Mdot
.46396 .41728 Mdot
.67084 .58612 Mdot
.62323 .53412 Mdot
.77988 .46803 Mdot
.63451 .37172 Mdot
.34037 .57004 Mdot
.48122 .44442 Mdot
.66463 .40153 Mdot
.42648 .37192 Mdot
.58449 .30789 Mdot
.33704 .57154 Mdot
.29 .57064 Mdot
.3244 .52413 Mdot
.43892 .37234 Mdot
.45806 .41728 Mdot
.51264 .69153 Mdot
.35641 .58518 Mdot
.48964 .68604 Mdot
.55503 .54163 Mdot
.74085 .56707 Mdot
.43312 .37968 Mdot
.46143 .7367 Mdot
.62701 .38188 Mdot
.66893 .55386 Mdot
.44233 .20113 Mdot
.62498 .37222 Mdot
.47326 .39554 Mdot
.64694 .59987 Mdot
.64543 .38362 Mdot
.44752 .2796 Mdot
.58794 .17057 Mdot
.61126 .37591 Mdot
.49387 .40816 Mdot
.41865 .33007 Mdot
.49012 .84136 Mdot
.61073 .37994 Mdot
.50749 .64043 Mdot
.44056 .37216 Mdot
.37726 .55001 Mdot
.65647 .41209 Mdot
.71513 .66865 Mdot
.63437 .5815 Mdot
.63864 .24934 Mdot
.38073 .456 Mdot
.23326 .59742 Mdot
.61559 .38365 Mdot
.31473 .55627 Mdot
.52236 .36514 Mdot
.43331 .4383 Mdot
.61484 .37692 Mdot
.49501 .62089 Mdot
.65039 .57991 Mdot
.6528 .67414 Mdot
.28735 .5598 Mdot
.51734 .61789 Mdot
.65722 .54316 Mdot
.61049 .76942 Mdot
.3105 .29723 Mdot
.42799 .33523 Mdot
.46909 .83028 Mdot
.53617 .73394 Mdot
.41183 .44593 Mdot
.60783 .37208 Mdot
.50469 .71479 Mdot
.48469 .6441 Mdot
.49666 .66629 Mdot
.40009 .74163 Mdot
.43536 .52159 Mdot
.66666 .52554 Mdot
.54516 .67549 Mdot
.61521 .39141 Mdot
.63712 .28559 Mdot
.4124 .37095 Mdot
.44549 .42018 Mdot
.49276 .42997 Mdot
.46289 .44633 Mdot
.43595 .43273 Mdot
.49254 .67862 Mdot
.37684 .72429 Mdot
.42553 .53741 Mdot
.33118 .57074 Mdot
.76337 .45582 Mdot
.62975 .55259 Mdot
.66075 .5199 Mdot
.64702 .37995 Mdot
.68079 .71772 Mdot
.59482 .59223 Mdot
.65076 .55531 Mdot
.42744 .45495 Mdot
.29658 .58114 Mdot
.49224 .34175 Mdot
.49292 .40687 Mdot
.66521 .5691 Mdot
.51289 .58155 Mdot
.34445 .47925 Mdot
.56799 .38173 Mdot
.59129 .40929 Mdot
.46609 .52202 Mdot
.62854 .36809 Mdot
.4638 .35276 Mdot
.16865 .47685 Mdot
.63821 .53522 Mdot
.65148 .5674 Mdot
.62365 .37987 Mdot
.25158 .64694 Mdot
.33052 .54942 Mdot
.44688 .71111 Mdot
.52437 .66857 Mdot
.48365 .3684 Mdot
.34538 .25712 Mdot
.51258 .32889 Mdot
.72217 .45341 Mdot
.4912 .66428 Mdot
.61347 .5628 Mdot
.49835 .36445 Mdot
.48924 .41699 Mdot
.63072 .38041 Mdot
.80106 .48542 Mdot
.45029 .33765 Mdot
.79348 .64076 Mdot
.49179 .18929 Mdot
.58769 .215 Mdot
.42842 .43699 Mdot
.28896 .56575 Mdot
.60891 .53903 Mdot
.6106 .40134 Mdot
.41974 .46669 Mdot
.63129 .20654 Mdot
.33362 .54085 Mdot
.49683 .65383 Mdot
.49455 .56613 Mdot
.64617 .30063 Mdot
.40789 .39138 Mdot
.42829 .37769 Mdot
.41139 .40084 Mdot
.51538 .13854 Mdot
.64931 .52765 Mdot
.34585 .59282 Mdot
.65375 .39841 Mdot
.31373 .59144 Mdot
.61865 .57019 Mdot
.48504 .60723 Mdot
.47119 .37223 Mdot
.32819 .54 Mdot
.31623 .55528 Mdot
.47869 .6615 Mdot
.46833 .68384 Mdot
.52507 .55863 Mdot
.44637 .38271 Mdot
.65114 .60698 Mdot
.35971 .56251 Mdot
.48258 .50683 Mdot
.63375 .40005 Mdot
.52035 .67319 Mdot
.47255 .43835 Mdot
.63928 .52915 Mdot
.39482 .38973 Mdot
.33918 .5593 Mdot
.65015 .55573 Mdot
.76489 .56349 Mdot
.60467 .38989 Mdot
.4259 .38855 Mdot
.68164 .37372 Mdot
.61771 .58442 Mdot
.44411 .42695 Mdot
.62712 .77228 Mdot
.67893 .40576 Mdot
.69474 .67449 Mdot
.63266 .59772 Mdot
.59375 .63897 Mdot
.31028 .5986 Mdot
.41169 .76173 Mdot
.65583 .56521 Mdot
.57585 .77804 Mdot
.78481 .54296 Mdot
.48995 .35319 Mdot
.32808 .5874 Mdot
.54378 .72611 Mdot
.7909 .35753 Mdot
.5677 .81758 Mdot
.45915 .39723 Mdot
.68207 .56931 Mdot
.6374 .38114 Mdot
.48613 .69281 Mdot
.71688 .60856 Mdot
.63241 .43054 Mdot
.61175 .59392 Mdot
.48907 .39832 Mdot
.31056 .56327 Mdot
.51523 .67762 Mdot
.3868 .71057 Mdot
.6315 .54723 Mdot
.65172 .54438 Mdot
.50235 .3725 Mdot
.62202 .39085 Mdot
.44974 .78509 Mdot
.63783 .58981 Mdot
.51084 .19096 Mdot
.69805 .5604 Mdot
.66562 .39414 Mdot
.45119 .43934 Mdot
.56348 .22933 Mdot
.49576 .44055 Mdot
.65334 .77296 Mdot
.62742 .55614 Mdot
.33816 .5645 Mdot
.4061 .41283 Mdot
.38477 .26914 Mdot
.66752 .56423 Mdot
.49071 .51174 Mdot
.68584 .44334 Mdot
.51726 .65605 Mdot
.43797 .20213 Mdot
.43244 .3921 Mdot
.53097 .67768 Mdot
.63061 .38214 Mdot
.45571 .3816 Mdot
.45827 .41998 Mdot
.36588 .56044 Mdot
.47748 .66626 Mdot
.78792 .48551 Mdot
.51838 .63956 Mdot
.49127 .64522 Mdot
.3602 .53985 Mdot
.43132 .41358 Mdot
.65921 .55865 Mdot
.63774 .57567 Mdot
.39653 .42459 Mdot
.16222 .55966 Mdot
.3283 .547 Mdot
.60402 .54172 Mdot
.49916 .13625 Mdot
.3896 .41801 Mdot
.42225 .21115 Mdot
.80191 .49517 Mdot
.52264 .70088 Mdot
.49423 .40954 Mdot
.30811 .57205 Mdot
.65748 .48847 Mdot
.65464 .54675 Mdot
.40185 .42202 Mdot
.51406 .67584 Mdot
.64312 .37095 Mdot
.65886 .58739 Mdot
.72993 .45187 Mdot
.41682 .39958 Mdot
.71138 .52678 Mdot
.67968 .56517 Mdot
.84487 .4548 Mdot
.58131 .74368 Mdot
.33218 .58652 Mdot
.46574 .41921 Mdot
.34607 .59619 Mdot
.65544 .39471 Mdot
.49872 .56483 Mdot
.51691 .66918 Mdot
.3925 .49652 Mdot
.16662 .42358 Mdot
.62618 .5901 Mdot
.34781 .59267 Mdot
.50237 .40553 Mdot
.31931 .69531 Mdot
.43136 .39815 Mdot
.40481 .3352 Mdot
.6622 .34482 Mdot
.50364 .70124 Mdot
.52667 .68402 Mdot
.45337 .43006 Mdot
.65925 .40121 Mdot
.62866 .55043 Mdot
.65858 .57401 Mdot
.85475 .56976 Mdot
.42793 .61608 Mdot
.43606 .24289 Mdot
.42399 .38294 Mdot
.61721 .59837 Mdot
.68249 .646 Mdot
.48196 .66928 Mdot
.39836 .441 Mdot
.66335 .59262 Mdot
.6819 .41233 Mdot
.46397 .26878 Mdot
.43783 .43732 Mdot
.47784 .46146 Mdot
.52297 .66 Mdot
.43334 .51192 Mdot
.60906 .56295 Mdot
.40141 .36946 Mdot
.45351 .63028 Mdot
.46029 .27621 Mdot
.53391 .16688 Mdot
.34053 .57031 Mdot
.72228 .43382 Mdot
.49266 .67952 Mdot
.49332 .45368 Mdot
.64287 .41411 Mdot
.59481 .56037 Mdot
.64127 .52706 Mdot
.48192 .39721 Mdot
.471 .35018 Mdot
.4649 .21018 Mdot
.30567 .58435 Mdot
.4929 .64852 Mdot
.45313 .37373 Mdot
.42656 .68822 Mdot
.46973 .44467 Mdot
.5073 .69445 Mdot
.16358 .35474 Mdot
.50547 .39861 Mdot
.42857 .40185 Mdot
.46492 .78424 Mdot
.28262 .57192 Mdot
.35838 .58712 Mdot
.3669 .23048 Mdot
.42409 .38328 Mdot
.47057 .19754 Mdot
.34413 .56669 Mdot
.33509 .55094 Mdot
.61647 .67921 Mdot
.44965 .41743 Mdot
.40778 .48232 Mdot
.52243 .69726 Mdot
.49419 .64233 Mdot
.28668 .57199 Mdot
.45392 .33589 Mdot
.47872 .69669 Mdot
.35451 .76954 Mdot
.63719 .56863 Mdot
.16485 .4986 Mdot
.3296 .54496 Mdot
.46183 .70546 Mdot
.48537 .66628 Mdot
.62272 .17346 Mdot
.62831 .49641 Mdot
.47032 .3746 Mdot
.42146 .38922 Mdot
.62028 .38455 Mdot
.49421 .43087 Mdot
.6066 .57971 Mdot
.49798 .67345 Mdot
.38367 .29848 Mdot
.33827 .57512 Mdot
.44185 .39006 Mdot
.70576 .70466 Mdot
.75889 .64002 Mdot
.72634 .41894 Mdot
.31857 .54775 Mdot
.34152 .58679 Mdot
.61954 .54858 Mdot
.68141 .57054 Mdot
.42814 .42473 Mdot
.49065 .70145 Mdot
.35556 .58562 Mdot
.50925 .69781 Mdot
.64019 .53505 Mdot
.65652 .55709 Mdot
.6275 .52962 Mdot
.41734 .36523 Mdot
.64792 .54959 Mdot
.75136 .57232 Mdot
.52818 .62733 Mdot
.364 .53925 Mdot
.44631 .177 Mdot
.3936 .71476 Mdot
.33106 .5176 Mdot
.66164 .40963 Mdot
.62112 .5878 Mdot
.52753 .65807 Mdot
.47044 .43003 Mdot
.44968 .44778 Mdot
.6045 .63518 Mdot
.53159 .66038 Mdot
.65388 .39488 Mdot
.52935 .67741 Mdot
.6529 .40135 Mdot
.67942 .48075 Mdot
.47094 .44782 Mdot
.44104 .34862 Mdot
.49156 .67405 Mdot
.64865 .55226 Mdot
.62656 .58176 Mdot
.60643 .38125 Mdot
.53684 .59026 Mdot
.64802 .59534 Mdot
.33981 .55021 Mdot
.35968 .47123 Mdot
.67417 .55292 Mdot
.43846 .3817 Mdot
.61317 .31655 Mdot
.23964 .66226 Mdot
.49515 .44628 Mdot
.61203 .67539 Mdot
.24368 .53487 Mdot
.41127 .42885 Mdot
.23044 .6541 Mdot
.57724 .63618 Mdot
.30722 .59583 Mdot
.60925 .5755 Mdot
.6095 .61408 Mdot
.49715 .46598 Mdot
.59989 .41518 Mdot
.40662 .4537 Mdot
.32045 .5431 Mdot
.35084 .60264 Mdot
.6019 .23322 Mdot
.60236 .79792 Mdot
.64136 .38304 Mdot
.64093 .3785 Mdot
.6576 .56612 Mdot
.73058 .75353 Mdot
.38359 .36713 Mdot
.65229 .39469 Mdot
.30624 .63143 Mdot
.48704 .39833 Mdot
.51346 .28054 Mdot
.58199 .4453 Mdot
.28666 .56722 Mdot
.59205 .24912 Mdot
.66433 .55957 Mdot
.317 .59514 Mdot
.41712 .67441 Mdot
.45517 .46061 Mdot
.33651 .57285 Mdot
.51167 .6955 Mdot
.61198 .73006 Mdot
.34779 .55147 Mdot
.60046 .31158 Mdot
.47635 .68653 Mdot
.48004 .50917 Mdot
.546 .24016 Mdot
.42564 .88933 Mdot
.49592 .67758 Mdot
.67302 .55595 Mdot
.63866 .57636 Mdot
.6591 .57282 Mdot
.31002 .59001 Mdot
.61973 .58812 Mdot
.30834 .58505 Mdot
.50216 .82367 Mdot
.26989 .6755 Mdot
.65072 .39476 Mdot
.65309 .67648 Mdot
.31388 .57405 Mdot
.17713 .4502 Mdot
.13829 .55756 Mdot
.49511 .40802 Mdot
.50117 .63267 Mdot
.64842 .39206 Mdot
.78496 .6523 Mdot
.63445 .38968 Mdot
.55763 .20893 Mdot
.21199 .42433 Mdot
.43981 .39757 Mdot
.31737 .44693 Mdot
.6107 .41165 Mdot
.30639 .55118 Mdot
.44552 .42601 Mdot
.59672 .48102 Mdot
.63094 .38722 Mdot
.6583 .38086 Mdot
.43352 .42117 Mdot
.35368 .56962 Mdot
.66432 .55295 Mdot
.50516 .63714 Mdot
.64257 .42049 Mdot
.47515 .32289 Mdot
.48187 .45544 Mdot
.47864 .37709 Mdot
.42186 .56154 Mdot
.62595 .3599 Mdot
.50107 .67436 Mdot
.29634 .75674 Mdot
.65566 .60054 Mdot
.60604 .4832 Mdot
.51764 .18221 Mdot
.59135 .66509 Mdot
.62811 .55791 Mdot
.61347 .57026 Mdot
.43357 .43284 Mdot
.57077 .41876 Mdot
.19963 .44232 Mdot
.55524 .60218 Mdot
.62739 .52746 Mdot
.65483 .57778 Mdot
.34483 .60038 Mdot
.58385 .2187 Mdot
.42647 .47003 Mdot
.49046 .70786 Mdot
.63673 .52806 Mdot
.31565 .71205 Mdot
.61874 .39183 Mdot
.213 .40959 Mdot
.46743 .45063 Mdot
.46576 .37345 Mdot
.51078 .66689 Mdot
.51339 .68884 Mdot
.64204 .48074 Mdot
.57426 .21433 Mdot
.24765 .53763 Mdot
.36487 .70471 Mdot
.2411 .40935 Mdot
.35076 .59971 Mdot
.35145 .58657 Mdot
.67249 .69971 Mdot
.5136 .63609 Mdot
.40852 .42328 Mdot
.33296 .59389 Mdot
.60757 .48841 Mdot
.36997 .49 Mdot
.47318 .25006 Mdot
.43335 .21661 Mdot
.47084 .40083 Mdot
.29459 .56921 Mdot
.28213 .56786 Mdot
.30252 .53927 Mdot
.57281 .62744 Mdot
.42418 .41755 Mdot
.46548 .39926 Mdot
.41707 .43171 Mdot
.29292 .6701 Mdot
.41739 .41468 Mdot
.40152 .75589 Mdot
.50586 .55363 Mdot
.29898 .33103 Mdot
.40359 .36355 Mdot
.52311 .70477 Mdot
.41313 .38372 Mdot
.65886 .40048 Mdot
.49298 .39226 Mdot
.46927 .25138 Mdot
.48827 .65818 Mdot
.36698 .46572 Mdot
.3943 .72561 Mdot
.40895 .43775 Mdot
.62209 .42337 Mdot
.51116 .74944 Mdot
.75643 .33514 Mdot
.68237 .35888 Mdot
.33796 .54898 Mdot
.63388 .56421 Mdot
.52851 .65924 Mdot
.65357 .56089 Mdot
.42423 .35425 Mdot
.66456 .71022 Mdot
.78645 .61452 Mdot
.5574 .55075 Mdot
.46265 .44568 Mdot
.38911 .45448 Mdot
.34009 .55396 Mdot
.65505 .59972 Mdot
.34076 .51986 Mdot
.40745 .40506 Mdot
.64389 .406 Mdot
.62852 .38397 Mdot
.56909 .50502 Mdot
.82286 .48386 Mdot
.33023 .74198 Mdot
.5095 .66983 Mdot
.64416 .58829 Mdot
.6212 .41409 Mdot
.54565 .78814 Mdot
.46965 .68969 Mdot
.50846 .70603 Mdot
.49026 .65407 Mdot
.44914 .36526 Mdot
.64503 .52408 Mdot
.30362 .32741 Mdot
.60952 .58878 Mdot
.46085 .40941 Mdot
.65144 .53001 Mdot
.65641 .59609 Mdot
.61741 .40902 Mdot
.4901 .65137 Mdot
.63243 .53869 Mdot
.49336 .37476 Mdot
.34834 .56954 Mdot
.45849 .6443 Mdot
.52859 .30773 Mdot
.61483 .7915 Mdot
.44035 .29641 Mdot
.29136 .55077 Mdot
.78962 .36453 Mdot
.51296 .70675 Mdot
.30508 .65899 Mdot
.777 .46151 Mdot
.46709 .35716 Mdot
.14986 .53438 Mdot
.65872 .51883 Mdot
.66459 .58956 Mdot
.45052 .43839 Mdot
.69997 .58315 Mdot
.43826 .39363 Mdot
.64969 .53713 Mdot
.69232 .62855 Mdot
.35567 .60779 Mdot
.64326 .55171 Mdot
.40195 .37136 Mdot
.45521 .42424 Mdot
.28839 .56974 Mdot
.67793 .55014 Mdot
.41284 .46554 Mdot
.86055 .55114 Mdot
.50828 .6905 Mdot
.56446 .69208 Mdot
.6134 .32591 Mdot
.49225 .68088 Mdot
.33431 .57961 Mdot
.41086 .37467 Mdot
.63184 .38138 Mdot
.31247 .57389 Mdot
.43882 .26505 Mdot
.60553 .39284 Mdot
.156 .48545 Mdot
.28395 .56298 Mdot
.67281 .56488 Mdot
.65108 .41037 Mdot
.49482 .43382 Mdot
.59561 .55681 Mdot
.58294 .75474 Mdot
.62998 .5568 Mdot
.42526 .43362 Mdot
.6902 .66138 Mdot
.49376 .64682 Mdot
.45894 .39423 Mdot
.6651 .58721 Mdot
.61433 .67037 Mdot
.45426 .36219 Mdot
.44789 .43306 Mdot
.5373 .17458 Mdot
.22611 .35972 Mdot
.63458 .39571 Mdot
.27796 .55804 Mdot
.49425 .4067 Mdot
.65655 .38128 Mdot
.73428 .51641 Mdot
.45505 .36808 Mdot
.33614 .54059 Mdot
.38694 .42144 Mdot
.67958 .55583 Mdot
.49459 .68833 Mdot
.56312 .58569 Mdot
.64977 .37524 Mdot
.51144 .86913 Mdot
.61866 .54251 Mdot
.44505 .35019 Mdot
.476 .43957 Mdot
.70809 .3487 Mdot
.30724 .59506 Mdot
.20851 .53067 Mdot
.42557 .38855 Mdot
.29012 .66387 Mdot
.45425 .38448 Mdot
.64356 .51808 Mdot
.33163 .54935 Mdot
.42444 .40553 Mdot
.43581 .64584 Mdot
.50413 .43796 Mdot
.62717 .37266 Mdot
.4725 .78986 Mdot
.44963 .46332 Mdot
.14639 .41765 Mdot
.61913 .45887 Mdot
.64246 .54991 Mdot
.73821 .65076 Mdot
.86558 .59199 Mdot
.40391 .74117 Mdot
.31581 .59079 Mdot
.80251 .54225 Mdot
.65901 .55806 Mdot
.73147 .63751 Mdot
.78549 .35487 Mdot
.4612 .42602 Mdot
.40733 .39254 Mdot
.68217 .3175 Mdot
.62678 .59853 Mdot
.63593 .60857 Mdot
.46679 .34413 Mdot
.48748 .4586 Mdot
.6539 .55147 Mdot
.48407 .36266 Mdot
.44158 .34156 Mdot
.49772 .63405 Mdot
.33108 .54216 Mdot
.50042 .7016 Mdot
.48171 .69846 Mdot
.40472 .79417 Mdot
.62868 .45519 Mdot
.50457 .6936 Mdot
.51173 .71228 Mdot
.51011 .27892 Mdot
.49892 .22693 Mdot
.65416 .4134 Mdot
.8398 .49867 Mdot
.65257 .57745 Mdot
.42716 .41276 Mdot
.2832 .5595 Mdot
.25622 .53398 Mdot
.75709 .52851 Mdot
.17839 .49243 Mdot
.40736 .4153 Mdot
.6673 .56141 Mdot
.57291 .62948 Mdot
.49609 .34321 Mdot
.68831 .57051 Mdot
.44765 .37392 Mdot
.60353 .57524 Mdot
.34909 .3695 Mdot
.57627 .77719 Mdot
.6788 .59869 Mdot
.34658 .52826 Mdot
.45857 .37498 Mdot
.31782 .54385 Mdot
.48353 .67209 Mdot
.65531 .40992 Mdot
.6312 .39728 Mdot
.43998 .42511 Mdot
.37689 .39276 Mdot
.69389 .49767 Mdot
.45265 .41923 Mdot
.48762 .40304 Mdot
.57755 .63541 Mdot
.49026 .40232 Mdot
.45012 .45151 Mdot
.4259 .44213 Mdot
.40188 .40664 Mdot
.49282 .64375 Mdot
.68524 .71444 Mdot
.51483 .44576 Mdot
.50871 .4477 Mdot
.46885 .66957 Mdot
.79432 .48298 Mdot
.493 .70709 Mdot
.76004 .33192 Mdot
.52627 .69086 Mdot
.63799 .40202 Mdot
.73087 .37705 Mdot
.37231 .44118 Mdot
.35873 .55183 Mdot
.47952 .70755 Mdot
.65696 .39518 Mdot
.49732 .66938 Mdot
.65675 .53912 Mdot
.54766 .16691 Mdot
.31452 .61248 Mdot
.40486 .54222 Mdot
.54166 .71614 Mdot
.64122 .73547 Mdot
.62153 .54311 Mdot
.30916 .5457 Mdot
.33853 .47169 Mdot
.46108 .44806 Mdot
.6588 .38376 Mdot
.4307 .4254 Mdot
.48228 .65432 Mdot
.6637 .56358 Mdot
.54413 .81701 Mdot
.6303 .38054 Mdot
.47295 .17485 Mdot
.62945 .57998 Mdot
.43365 .45048 Mdot
.48171 .6998 Mdot
.38024 .20162 Mdot
.50619 .70239 Mdot
.20614 .48372 Mdot
.33093 .60002 Mdot
.51804 .84339 Mdot
.31775 .58206 Mdot
.59111 .75742 Mdot
.35849 .17945 Mdot
.69593 .71486 Mdot
.35188 .57062 Mdot
.51078 .60237 Mdot
.47605 .39532 Mdot
.47787 .37617 Mdot
.5604 .79346 Mdot
.28224 .55351 Mdot
.48496 .42733 Mdot
.656 .64106 Mdot
.52678 .61788 Mdot
.38995 .23133 Mdot
.6172 .55971 Mdot
.43594 .3906 Mdot
.53514 .68885 Mdot
.53309 .66863 Mdot
.60544 .56158 Mdot
.50874 .7069 Mdot
.4635 .40062 Mdot
.31443 .57538 Mdot
.70604 .60799 Mdot
.62582 .40449 Mdot
.75499 .70767 Mdot
.65961 .37495 Mdot
.62767 .55839 Mdot
.50683 .39242 Mdot
.65576 .5569 Mdot
.90131 .54327 Mdot
.46827 .39261 Mdot
.34315 .56565 Mdot
.48947 .41212 Mdot
.46141 .37707 Mdot
.40353 .41071 Mdot
.65913 .54749 Mdot
.57594 .36754 Mdot
.48989 .36931 Mdot
.51741 .66758 Mdot
.26505 .3791 Mdot
.43972 .46097 Mdot
.63438 .61945 Mdot
.50015 .24093 Mdot
.55291 .6719 Mdot
.29282 .59293 Mdot
.63777 .55255 Mdot
.34162 .57602 Mdot
.25558 .63936 Mdot
.33402 .57941 Mdot
.24614 .44667 Mdot
.34031 .45652 Mdot
.38448 .28059 Mdot
.36089 .31382 Mdot
.46468 .58836 Mdot
.2797 .55591 Mdot
.61401 .36309 Mdot
.35747 .57774 Mdot
.28618 .57674 Mdot
.12267 .36174 Mdot
.35838 .54512 Mdot
.43296 .38307 Mdot
.43888 .45849 Mdot
.62976 .75324 Mdot
.5676 .2907 Mdot
.4807 .42161 Mdot
.47961 .42798 Mdot
.63103 .41552 Mdot
.27297 .64826 Mdot
.69433 .68029 Mdot
.21109 .37893 Mdot
.76326 .62106 Mdot
.43251 .42368 Mdot
.49562 .40235 Mdot
.51975 .38004 Mdot
.27031 .27273 Mdot
.41158 .80486 Mdot
.38054 .58117 Mdot
.51854 .38332 Mdot
.68636 .73687 Mdot
.40495 .40341 Mdot
.43293 .37253 Mdot
.4727 .39865 Mdot
.65957 .55824 Mdot
.28295 .58273 Mdot
.40033 .39999 Mdot
.69424 .34688 Mdot
.43497 .37463 Mdot
.59608 .66703 Mdot
.628 .82071 Mdot
.43176 .39235 Mdot
.30293 .60481 Mdot
.48102 .37932 Mdot
.29744 .58804 Mdot
.29728 .556 Mdot
.502 .36238 Mdot
.23865 .41353 Mdot
.32304 .60589 Mdot
.46088 .41016 Mdot
.66632 .54698 Mdot
.84118 .45527 Mdot
.4241 .43199 Mdot
.65713 .40991 Mdot
.42259 .38775 Mdot
.6338 .42451 Mdot
.48523 .40839 Mdot
.61574 .54467 Mdot
.24356 .56619 Mdot
.65281 .56819 Mdot
.45348 .82815 Mdot
.62572 .53184 Mdot
.51561 .16115 Mdot
.29738 .54545 Mdot
.66859 .67082 Mdot
.21019 .58439 Mdot
.56693 .70062 Mdot
.53231 .4864 Mdot
.46303 .55199 Mdot
.49255 .70248 Mdot
.32584 .59824 Mdot
.34307 .6394 Mdot
.77373 .48974 Mdot
.74625 .42101 Mdot
.64988 .59268 Mdot
.26444 .74295 Mdot
.17621 .54233 Mdot
.47036 .35412 Mdot
.30068 .46381 Mdot
.28669 .41096 Mdot
.40438 .40218 Mdot
.4026 .38941 Mdot
.57821 .58583 Mdot
.49402 .37058 Mdot
.42999 .69548 Mdot
.6246 .56142 Mdot
.65821 .39338 Mdot
.34368 .5585 Mdot
.64395 .37091 Mdot
.77501 .46919 Mdot
.45718 .55074 Mdot
.64776 .53525 Mdot
.46204 .465 Mdot
.47362 .43057 Mdot
.29268 .58041 Mdot
.38054 .53124 Mdot
.36056 .56784 Mdot
.64414 .38801 Mdot
.62468 .56714 Mdot
.2524 .68323 Mdot
.47119 .43481 Mdot
.31761 .55593 Mdot
.54628 .4737 Mdot
.49345 .40935 Mdot
.48727 .67371 Mdot
.47528 .39038 Mdot
.35223 .56555 Mdot
.49018 .40262 Mdot
.31758 .58357 Mdot
.63609 .56563 Mdot
.42025 .44479 Mdot
.4449 .43962 Mdot
.42551 .1873 Mdot
.64843 .40032 Mdot
.32075 .53889 Mdot
.58933 .50471 Mdot
.49196 .42628 Mdot
.62855 .68826 Mdot
.44306 .37575 Mdot
.25918 .55513 Mdot
.45362 .35428 Mdot
.56934 .68443 Mdot
.48513 .46726 Mdot
.42225 .42668 Mdot
.5798 .46657 Mdot
.27874 .42475 Mdot
.36513 .43853 Mdot
.51018 .71634 Mdot
.34114 .53579 Mdot
.39499 .23295 Mdot
.69496 .53563 Mdot
.67644 .58577 Mdot
.61496 .27296 Mdot
.40142 .4226 Mdot
.43791 .39962 Mdot
.532 .71314 Mdot
.63549 .37496 Mdot
.31584 .54813 Mdot
.65272 .40142 Mdot
.46051 .19157 Mdot
.61624 .3809 Mdot
.65253 .51738 Mdot
.71383 .53021 Mdot
.27255 .71138 Mdot
.62709 .41483 Mdot
.35442 .56827 Mdot
.72864 .57632 Mdot
.40551 .44129 Mdot
.61219 .45745 Mdot
.63718 .40914 Mdot
.3587 .81963 Mdot
.44823 .45142 Mdot
.53009 .48537 Mdot
.49868 .6948 Mdot
.64037 .41502 Mdot
.47782 .68398 Mdot
.46651 .43033 Mdot
.69783 .67401 Mdot
.31828 .59087 Mdot
.47225 .66635 Mdot
.39151 .36607 Mdot
.64984 .39125 Mdot
.64225 .52591 Mdot
.52282 .72028 Mdot
.49758 .71282 Mdot
.80397 .47614 Mdot
.52435 .82695 Mdot
.62549 .56994 Mdot
.31206 .29175 Mdot
.52964 .68574 Mdot
.40904 .44447 Mdot
.28221 .6457 Mdot
.46964 .37375 Mdot
.38793 .76423 Mdot
.6317 .5516 Mdot
.65545 .73096 Mdot
.49387 .40375 Mdot
.41211 .41901 Mdot
.32211 .61174 Mdot
.64679 .57446 Mdot
.32299 .56828 Mdot
.33351 .53396 Mdot
.63589 .56726 Mdot
.32762 .58592 Mdot
.60611 .40635 Mdot
.40228 .63907 Mdot
.52515 .66986 Mdot
.51307 .65521 Mdot
.65831 .5748 Mdot
.64026 .54717 Mdot
.65141 .55636 Mdot
.47543 .38976 Mdot
.32302 .54715 Mdot
.47124 .41779 Mdot
.42385 .37706 Mdot
.26762 .3655 Mdot
.28135 .57607 Mdot
.47216 .4074 Mdot
.6085 .47673 Mdot
.58376 .43225 Mdot
.66459 .54286 Mdot
.50175 .6937 Mdot
.66444 .64951 Mdot
.56693 .75849 Mdot
.43844 .38762 Mdot
.65858 .43876 Mdot
.3561 .571 Mdot
.63333 .38355 Mdot
.6523 .36556 Mdot
.63496 .39184 Mdot
.56575 .65107 Mdot
.29816 .54305 Mdot
.20611 .38981 Mdot
.43585 .39422 Mdot
.42618 .55344 Mdot
.32365 .62886 Mdot
.66996 .47796 Mdot
.50348 .69212 Mdot
.48928 .41627 Mdot
.56184 .57917 Mdot
.3388 .49424 Mdot
.47004 .37673 Mdot
.42811 .45744 Mdot
.75737 .57607 Mdot
.39252 .43811 Mdot
.35978 .58962 Mdot
.38217 .2048 Mdot
.49978 .41808 Mdot
.309 .70994 Mdot
.76573 .70668 Mdot
.44457 .38103 Mdot
.41027 .40687 Mdot
.45543 .44422 Mdot
.4919 .38925 Mdot
.30925 .60527 Mdot
.55743 .25925 Mdot
.5275 .69367 Mdot
.42474 .54795 Mdot
.49373 .63923 Mdot
.60278 .54823 Mdot
.66377 .72771 Mdot
.33254 .59875 Mdot
.62081 .38413 Mdot
.75009 .67391 Mdot
.30018 .27009 Mdot
.60904 .56408 Mdot
.35306 .76661 Mdot
.64051 .40616 Mdot
.4139 .44862 Mdot
.61555 .41803 Mdot
.65913 .52957 Mdot
.51628 .65574 Mdot
.43021 .46394 Mdot
.35422 .58098 Mdot
.34433 .54882 Mdot
.49035 .41837 Mdot
.69998 .72634 Mdot
.48669 .67941 Mdot
.49767 .71488 Mdot
.45508 .36516 Mdot
.4934 .43528 Mdot
.32438 .57194 Mdot
.63924 .58716 Mdot
.40767 .25671 Mdot
.64671 .37844 Mdot
.41368 .36874 Mdot
.48955 .39688 Mdot
.52544 .18064 Mdot
.51957 .6706 Mdot
.68568 .56496 Mdot
.46135 .35674 Mdot
.35448 .70043 Mdot
.4645 .35742 Mdot
.51166 .36561 Mdot
.66781 .54812 Mdot
.52901 .43143 Mdot
.45147 .34621 Mdot
.29586 .60965 Mdot
.48582 .69571 Mdot
.33802 .56891 Mdot
.26673 .58774 Mdot
.39956 .59953 Mdot
.48837 .67126 Mdot
.47675 .40079 Mdot
.50373 .68714 Mdot
.45623 .36835 Mdot
.49895 .39123 Mdot
.50677 .69463 Mdot
.3226 .56932 Mdot
.79879 .54841 Mdot
.69511 .7094 Mdot
.49167 .38405 Mdot
.48513 .35039 Mdot
.55816 .27233 Mdot
.57696 .37352 Mdot
.40702 .40136 Mdot
.35161 .56107 Mdot
.46179 .43717 Mdot
.47825 .67144 Mdot
.61208 .41212 Mdot
.34958 .56892 Mdot
.62234 .58071 Mdot
.6117 .55551 Mdot
.39798 .73019 Mdot
.64317 .59839 Mdot
.40882 .38556 Mdot
.28194 .53775 Mdot
.27717 .59236 Mdot
.7221 .7309 Mdot
.63652 .57055 Mdot
.65455 .41433 Mdot
.44648 .43172 Mdot
.64706 .26457 Mdot
.53718 .67882 Mdot
.12095 .48197 Mdot
.17565 .44821 Mdot
.59618 .39557 Mdot
.18352 .4852 Mdot
.61559 .54036 Mdot
.43429 .34984 Mdot
.66046 .40529 Mdot
.61913 .54952 Mdot
.4793 .36882 Mdot
.50568 .36531 Mdot
.20764 .5188 Mdot
.43903 .58382 Mdot
.50661 .68712 Mdot
.62222 .59116 Mdot
.59356 .39512 Mdot
.66367 .52149 Mdot
.30112 .54583 Mdot
.42133 .41764 Mdot
.50741 .38505 Mdot
.63041 .58682 Mdot
.66461 .59896 Mdot
.46626 .40766 Mdot
.34428 .59703 Mdot
.57631 .58046 Mdot
.43698 .41956 Mdot
.42917 .60971 Mdot
.29204 .53935 Mdot
.6194 .56288 Mdot
.4152 .4207 Mdot
.58258 .38497 Mdot
.63164 .5828 Mdot
.66305 .5404 Mdot
.49605 .40578 Mdot
.60414 .40227 Mdot
.49631 .36171 Mdot
.52539 .68781 Mdot
.30979 .77252 Mdot
.47776 .66907 Mdot
.69452 .62171 Mdot
.38348 .37668 Mdot
.34172 .67156 Mdot
.29855 .59473 Mdot
.58976 .23551 Mdot
.65926 .64235 Mdot
.44993 .33931 Mdot
.82565 .44288 Mdot
.4596 .70467 Mdot
.72503 .71123 Mdot
.71243 .30974 Mdot
.62481 .41014 Mdot
.49622 .66699 Mdot
.41007 .40587 Mdot
.49974 .6329 Mdot
.66334 .40262 Mdot
.45552 .82619 Mdot
.41916 .43031 Mdot
.33433 .55122 Mdot
.46695 .40263 Mdot
.33249 .54602 Mdot
.49702 .40113 Mdot
.51937 .41279 Mdot
.60292 .64557 Mdot
.46758 .26997 Mdot
.45207 .3579 Mdot
.49443 .14322 Mdot
.55785 .4339 Mdot
.65643 .38606 Mdot
.46372 .42214 Mdot
.69148 .56904 Mdot
.53139 .65539 Mdot
.48198 .76752 Mdot
.65985 .55689 Mdot
.50259 .71272 Mdot
.32727 .58048 Mdot
.634 .55631 Mdot
.60696 .56523 Mdot
.52958 .43193 Mdot
.60045 .4032 Mdot
.49983 .65111 Mdot
.42294 .40535 Mdot
.41955 .42964 Mdot
.31214 .28615 Mdot
.75981 .50463 Mdot
.3779 .52612 Mdot
.2121 .33568 Mdot
.34295 .5308 Mdot
.65431 .39009 Mdot
.66302 .5522 Mdot
.41736 .3829 Mdot
.45709 .39772 Mdot
.64064 .67522 Mdot
.35885 .58346 Mdot
.50814 .56511 Mdot
.24143 .60597 Mdot
.59597 .50094 Mdot
.50692 .2595 Mdot
.34682 .55944 Mdot
.50684 .26117 Mdot
.62461 .36348 Mdot
.83456 .55613 Mdot
.48954 .27281 Mdot
.49746 .69263 Mdot
.51236 .26436 Mdot
.3119 .55438 Mdot
.48592 .36789 Mdot
.67407 .56077 Mdot
.65507 .59699 Mdot
.33125 .5675 Mdot
.6792 .53588 Mdot
.61383 .40359 Mdot
.41435 .40299 Mdot
.2221 .35857 Mdot
.40504 .70815 Mdot
.65823 .57889 Mdot
.51057 .356 Mdot
.48936 .65465 Mdot
.49083 .41837 Mdot
.61828 .41156 Mdot
.49888 .68091 Mdot
.56684 .2109 Mdot
.51301 .6196 Mdot
.44565 .42877 Mdot
.5335 .175 Mdot
.49278 .67284 Mdot
.54978 .42898 Mdot
.43112 .41695 Mdot
.52174 .69764 Mdot
.51767 .46021 Mdot
.60951 .73483 Mdot
.55403 .55528 Mdot
.78673 .3555 Mdot
.54174 .54846 Mdot
.66935 .57091 Mdot
.62494 .73687 Mdot
.54038 .73316 Mdot
.52456 .65232 Mdot
.68256 .5802 Mdot
.59297 .42593 Mdot
.47874 .68693 Mdot
.42259 .45186 Mdot
.44631 .37682 Mdot
.42846 .81144 Mdot
.49229 .73038 Mdot
.58577 .7632 Mdot
.44109 .7507 Mdot
.48932 .43043 Mdot
.50047 .36646 Mdot
.45225 .39932 Mdot
.34303 .60512 Mdot
.51365 .68157 Mdot
.44454 .16376 Mdot
.48513 .67433 Mdot
.23038 .38499 Mdot
.65613 .57484 Mdot
.61785 .55657 Mdot
.43452 .38909 Mdot
.5127 .48923 Mdot
.53344 .22616 Mdot
.46177 .40355 Mdot
.63335 .43378 Mdot
.48434 .79715 Mdot
.49397 .43232 Mdot
.32059 .60192 Mdot
.52085 .37135 Mdot
.49714 .33097 Mdot
.52528 .66931 Mdot
.61831 .39608 Mdot
.57805 .22671 Mdot
.51052 .64892 Mdot
.43925 .39981 Mdot
.35238 .67377 Mdot
.4636 .38168 Mdot
.48846 .37936 Mdot
.19007 .44096 Mdot
.63886 .36468 Mdot
.64612 .56143 Mdot
.63745 .39308 Mdot
.29832 .59096 Mdot
.09943 .45127 Mdot
.61961 .37699 Mdot
.53742 .22148 Mdot
.41174 .81576 Mdot
.51515 .26889 Mdot
.32306 .54259 Mdot
.60367 .41183 Mdot
.49026 .68595 Mdot
.84368 .4616 Mdot
.22018 .55038 Mdot
.4459 .69403 Mdot
.43922 .41489 Mdot
.37269 .55911 Mdot
.35325 .55246 Mdot
.47137 .66515 Mdot
.29984 .55382 Mdot
.43222 .48601 Mdot
.4881 .37339 Mdot
.51285 .63779 Mdot
.36685 .69541 Mdot
.51253 .71655 Mdot
.47272 .60838 Mdot
.46002 .41945 Mdot
.34673 .56478 Mdot
.41493 .36434 Mdot
.27899 .54867 Mdot
.68099 .54663 Mdot
.49002 .44987 Mdot
.61275 .40093 Mdot
.33573 .68516 Mdot
.62477 .57178 Mdot
.65227 .45614 Mdot
.2922 .58145 Mdot
.5555 .64139 Mdot
.28929 .56833 Mdot
.27113 .56835 Mdot
.48843 .70473 Mdot
.30517 .57174 Mdot
.41124 .40658 Mdot
.5819 .49366 Mdot
.30336 .58808 Mdot
.505 .66046 Mdot
.62125 .39619 Mdot
.32122 .58107 Mdot
.69779 .58791 Mdot
.44044 .43296 Mdot
.65251 .54442 Mdot
.72539 .37747 Mdot
.3681 .55353 Mdot
.62898 .36659 Mdot
.66914 .5938 Mdot
.65941 .3821 Mdot
.66565 .77967 Mdot
.47662 .63856 Mdot
.21776 .4188 Mdot
.59677 .42133 Mdot
.36014 .55515 Mdot
.73254 .38269 Mdot
.42318 .38005 Mdot
.44324 .43297 Mdot
.64779 .42212 Mdot
.35352 .55278 Mdot
.80475 .62824 Mdot
.41988 .32118 Mdot
.45693 .608 Mdot
.46583 .68523 Mdot
.51511 .1573 Mdot
.46066 .61562 Mdot
.72851 .76065 Mdot
.43405 .33747 Mdot
.63302 .60836 Mdot
.44498 .38985 Mdot
.63672 .64959 Mdot
.64802 .39313 Mdot
.64996 .62721 Mdot
.51251 .40436 Mdot
.64004 .56099 Mdot
.4379 .44294 Mdot
.57711 .47771 Mdot
.54658 .39777 Mdot
.65903 .4118 Mdot
.72572 .65937 Mdot
.3539 .54079 Mdot
.62927 .40643 Mdot
.62912 .53654 Mdot
.52601 .24498 Mdot
.4826 .37058 Mdot
.39474 .43129 Mdot
.5965 .5006 Mdot
.3234 .54541 Mdot
.67288 .57277 Mdot
.52528 .67976 Mdot
.62205 .38606 Mdot
.47459 .42838 Mdot
.42945 .37017 Mdot
.62171 .68821 Mdot
.48732 .65436 Mdot
.64429 .60242 Mdot
.49443 .69783 Mdot
.60613 .55151 Mdot
.49987 .38246 Mdot
.61316 .56367 Mdot
.40067 .38122 Mdot
.5968 .64694 Mdot
.2046 .42354 Mdot
.28125 .44311 Mdot
.62881 .55261 Mdot
.47221 .23825 Mdot
.48648 .65965 Mdot
.50957 .70326 Mdot
.33506 .77216 Mdot
.20391 .48951 Mdot
.29685 .28552 Mdot
.78807 .41043 Mdot
.5014 .63858 Mdot
.49487 .65482 Mdot
.64929 .54365 Mdot
.30316 .57217 Mdot
.33146 .53146 Mdot
.60482 .55498 Mdot
.61574 .32045 Mdot
.31597 .54823 Mdot
.82837 .48314 Mdot
.36125 .2495 Mdot
.39728 .39843 Mdot
.66942 .52011 Mdot
.62908 .38657 Mdot
.6062 .31067 Mdot
.58187 .47488 Mdot
.41065 .4191 Mdot
.62429 .25416 Mdot
.65079 .58205 Mdot
.46634 .50565 Mdot
.76083 .33672 Mdot
.42862 .4449 Mdot
.42728 .41457 Mdot
.44665 .39673 Mdot
.60135 .38673 Mdot
.21646 .52264 Mdot
.41513 .41379 Mdot
.61526 .32221 Mdot
.49124 .42393 Mdot
.54567 .43026 Mdot
.63294 .39612 Mdot
.45887 .28148 Mdot
.77798 .48522 Mdot
.38024 .21066 Mdot
.55038 .38735 Mdot
.5261 .68085 Mdot
.6931 .35881 Mdot
.50112 .7037 Mdot
.25365 .44494 Mdot
.50043 .28037 Mdot
.35847 .53369 Mdot
.40963 .41556 Mdot
.62687 .55843 Mdot
.35211 .55151 Mdot
.62657 .71302 Mdot
.10686 .40842 Mdot
.52774 .67969 Mdot
.7961 .71452 Mdot
.52094 .69669 Mdot
.60643 .56575 Mdot
.32528 .57258 Mdot
.3411 .44584 Mdot
.41857 .572 Mdot
.32204 .58348 Mdot
.7926 .59625 Mdot
.38152 .57653 Mdot
.49724 .24537 Mdot
.36703 .57301 Mdot
.49936 .65855 Mdot
.56234 .67605 Mdot
.37912 .46812 Mdot
.42732 .38128 Mdot
.46857 .54901 Mdot
.51572 .23036 Mdot
.42209 .38147 Mdot
.62506 .56359 Mdot
.20688 .43649 Mdot
.61471 .25997 Mdot
.30766 .56662 Mdot
.50081 .62027 Mdot
.42529 .42079 Mdot
.48495 .38659 Mdot
.48209 .36784 Mdot
.17637 .40885 Mdot
.8341 .55967 Mdot
.49144 .3711 Mdot
.49733 .41634 Mdot
.63616 .55874 Mdot
.58217 .40186 Mdot
.72799 .61664 Mdot
.29772 .31942 Mdot
.41342 .43628 Mdot
.63128 .40373 Mdot
.6002 .37792 Mdot
.47015 .35936 Mdot
.62293 .46318 Mdot
.35402 .66684 Mdot
.42222 .40665 Mdot
.20864 .43925 Mdot
.62008 .49006 Mdot
.62627 .59837 Mdot
.62663 .58348 Mdot
.31841 .54101 Mdot
.6189 .58429 Mdot
.62088 .53777 Mdot
.3509 .46182 Mdot
.52758 .55341 Mdot
.48067 .61961 Mdot
.64332 .38645 Mdot
.46006 .39331 Mdot
.36393 .40897 Mdot
.34965 .69088 Mdot
.48384 .69741 Mdot
.35098 .57856 Mdot
.5335 .66008 Mdot
.68205 .36088 Mdot
.39678 .57707 Mdot
.65233 .58733 Mdot
.5089 .64204 Mdot
.53698 .64283 Mdot
.62989 .40196 Mdot
.47525 .66651 Mdot
.54484 .66399 Mdot
.47489 .45797 Mdot
.29256 .47984 Mdot
.45869 .40937 Mdot
.75202 .68008 Mdot
.49409 .64927 Mdot
.57753 .66575 Mdot
.43153 .40287 Mdot
.63243 .58157 Mdot
.38011 .48018 Mdot
.43107 .37604 Mdot
.62629 .58722 Mdot
.47201 .3551 Mdot
.65863 .3756 Mdot
.28282 .54691 Mdot
.41832 .55939 Mdot
.24442 .73054 Mdot
.60065 .40486 Mdot
.63045 .70616 Mdot
.4064 .40879 Mdot
.5763 .81694 Mdot
.31913 .5788 Mdot
.43079 .36101 Mdot
.58876 .24894 Mdot
.30359 .58386 Mdot
.34237 .57986 Mdot
.48182 .39441 Mdot
.49599 .69452 Mdot
.62217 .56908 Mdot
.62903 .39777 Mdot
.72439 .74972 Mdot
.44455 .4191 Mdot
.45081 .43953 Mdot
.6357 .40724 Mdot
.48373 .65922 Mdot
.4603 .35779 Mdot
.71188 .34229 Mdot
.82018 .61635 Mdot
.51308 .70515 Mdot
.41955 .4485 Mdot
.24659 .48219 Mdot
.46886 .31695 Mdot
.50962 .85843 Mdot
.61809 .45803 Mdot
.64356 .5562 Mdot
.3833 .43282 Mdot
.13672 .40883 Mdot
.61973 .39393 Mdot
.29839 .27463 Mdot
.487 .38946 Mdot
.47259 .43555 Mdot
.35973 .56897 Mdot
.46993 .4146 Mdot
.34099 .59553 Mdot
.22914 .69652 Mdot
.52009 .17774 Mdot
.30611 .54575 Mdot
.36179 .55336 Mdot
.55844 .22733 Mdot
.69644 .63296 Mdot
.33106 .57012 Mdot
.49955 .39708 Mdot
.497 .31064 Mdot
.38373 .50558 Mdot
.62075 .4216 Mdot
.76142 .42765 Mdot
.38398 .35407 Mdot
.68274 .39665 Mdot
.80091 .4981 Mdot
.38086 .35468 Mdot
.52593 .59898 Mdot
.52158 .68659 Mdot
.42725 .44453 Mdot
.65288 .59818 Mdot
.64256 .59941 Mdot
.42016 .3534 Mdot
.46565 .38805 Mdot
.29572 .58786 Mdot
.63105 .37823 Mdot
.52966 .66879 Mdot
.47661 .43034 Mdot
.57941 .23542 Mdot
.6327 .37368 Mdot
.29894 .56223 Mdot
.25323 .38061 Mdot
.67037 .394 Mdot
.51652 .4281 Mdot
.42426 .39511 Mdot
.47088 .40088 Mdot
.36939 .45627 Mdot
.51527 .68535 Mdot
.74937 .40015 Mdot
.46114 .45554 Mdot
.45482 .19143 Mdot
.45808 .65203 Mdot
.46848 .46803 Mdot
.29585 .55299 Mdot
.49959 .61712 Mdot
.64549 .52191 Mdot
.38661 .60853 Mdot
.44653 .42677 Mdot
.7071 .70753 Mdot
.44735 .81229 Mdot
.68124 .55181 Mdot
.27598 .55987 Mdot
.63595 .38696 Mdot
.46227 .40116 Mdot
.2374 .41963 Mdot
.44308 .37852 Mdot
.67894 .3929 Mdot
.66669 .54161 Mdot
.52055 .68911 Mdot
.73467 .7023 Mdot
.6321 .59604 Mdot
.34167 .57692 Mdot
.64049 .19062 Mdot
.33924 .59701 Mdot
.32576 .53292 Mdot
.26488 .37572 Mdot
.51513 .68776 Mdot
.12477 .4409 Mdot
.25196 .70838 Mdot
.49635 .43839 Mdot
.48469 .66249 Mdot
.33346 .56163 Mdot
.48011 .43441 Mdot
.36329 .53018 Mdot
.28949 .54886 Mdot
.50132 .39279 Mdot
.45582 .44625 Mdot
.60283 .7709 Mdot
.78069 .36018 Mdot
.63753 .38675 Mdot
.28871 .58374 Mdot
.42001 .61292 Mdot
.47733 .43805 Mdot
.43509 .39492 Mdot
.53678 .74056 Mdot
.60971 .41193 Mdot
.42744 .70358 Mdot
.48588 .38784 Mdot
.54626 .18927 Mdot
.5288 .42233 Mdot
.31881 .60541 Mdot
.50085 .70583 Mdot
.39001 .20845 Mdot
.5193 .7249 Mdot
.3426 .59389 Mdot
.62042 .38171 Mdot
.29291 .60426 Mdot
.53439 .21954 Mdot
.48535 .64809 Mdot
.35226 .56549 Mdot
.56335 .58938 Mdot
.50898 .67735 Mdot
.50072 .64416 Mdot
.27566 .3608 Mdot
.68757 .57015 Mdot
.6017 .38382 Mdot
.4971 .65192 Mdot
.30511 .66267 Mdot
.5039 .66456 Mdot
.26988 .72196 Mdot
.42139 .44636 Mdot
.63131 .29853 Mdot
.67529 .62705 Mdot
.37853 .43897 Mdot
.49297 .64641 Mdot
.63155 .41617 Mdot
.47731 .36881 Mdot
.30845 .55375 Mdot
.65184 .3786 Mdot
.44325 .70063 Mdot
.6555 .55267 Mdot
.2912 .56974 Mdot
.50985 .7228 Mdot
.33942 .54768 Mdot
.34777 .63813 Mdot
.38022 .81017 Mdot
.62728 .23074 Mdot
.41735 .5852 Mdot
.48456 .3723 Mdot
.79164 .44854 Mdot
.39936 .43355 Mdot
.46934 .38448 Mdot
.62121 .56234 Mdot
.62466 .28198 Mdot
.32316 .56888 Mdot
.77997 .65852 Mdot
.52264 .66051 Mdot
.39158 .20267 Mdot
.52485 .34975 Mdot
.45064 .34877 Mdot
.30628 .59059 Mdot
.35277 .59182 Mdot
.27477 .412 Mdot
.63506 .52315 Mdot
.40617 .38298 Mdot
.40794 .44868 Mdot
.44966 .34234 Mdot
.51864 .65681 Mdot
.65066 .45237 Mdot
.6678 .57255 Mdot
.45276 .83754 Mdot
.67062 .5455 Mdot
.67961 .40656 Mdot
.30481 .56747 Mdot
.61937 .37741 Mdot
.43305 .39581 Mdot
.3859 .54181 Mdot
.35901 .58432 Mdot
.65721 .41628 Mdot
.64823 .41225 Mdot
.58228 .73414 Mdot
.50681 .69399 Mdot
.4385 .36734 Mdot
.41468 .41855 Mdot
.4746 .41751 Mdot
.47358 .39016 Mdot
.52691 .6714 Mdot
.47076 .36528 Mdot
.52937 .70758 Mdot
.29161 .63639 Mdot
.68262 .31491 Mdot
.54327 .54326 Mdot
.37745 .76815 Mdot
.30887 .55972 Mdot
.31848 .66458 Mdot
.4244 .3258 Mdot
.16503 .48662 Mdot
.51034 .81019 Mdot
.47271 .45334 Mdot
.61325 .55602 Mdot
.47918 .48727 Mdot
.65326 .59241 Mdot
.71695 .78321 Mdot
.60155 .68438 Mdot
.80511 .39241 Mdot
.42072 .43066 Mdot
.57739 .5019 Mdot
.28336 .67164 Mdot
.39812 .43404 Mdot
.60256 .703 Mdot
.38118 .76331 Mdot
.71792 .67433 Mdot
.61624 .41206 Mdot
.43573 .42791 Mdot
.36445 .42965 Mdot
.41265 .40601 Mdot
.44028 .39084 Mdot
.4767 .36606 Mdot
.51826 .71292 Mdot
.41995 .37086 Mdot
.47149 .37106 Mdot
.70122 .50297 Mdot
.49438 .26276 Mdot
.65975 .59934 Mdot
.3661 .78923 Mdot
.61972 .37645 Mdot
.29823 .58686 Mdot
.82681 .55019 Mdot
.49814 .69251 Mdot
.27937 .40928 Mdot
.47256 .39492 Mdot
.63949 .74969 Mdot
.52234 .62947 Mdot
.61674 .38913 Mdot
.65983 .52891 Mdot
.82814 .41896 Mdot
.62895 .56363 Mdot
.56778 .63361 Mdot
.6325 .57937 Mdot
.41245 .32997 Mdot
.29475 .58757 Mdot
.45157 .36151 Mdot
.50331 .65196 Mdot
.61627 .57681 Mdot
.56658 .28175 Mdot
.45213 .39738 Mdot
.63687 .56741 Mdot
.45139 .36185 Mdot
.40452 .54768 Mdot
.33175 .2886 Mdot
.62098 .53923 Mdot
.52222 .63058 Mdot
.5148 .66655 Mdot
.60401 .39933 Mdot
.2947 .57876 Mdot
.34944 .58478 Mdot
.4995 .67946 Mdot
.20095 .53446 Mdot
.40948 .43229 Mdot
.46954 .44198 Mdot
.41364 .19946 Mdot
.41045 .3965 Mdot
.51452 .24774 Mdot
.56056 .56217 Mdot
.30322 .55803 Mdot
.46141 .34743 Mdot
.48568 .39628 Mdot
.44515 .43 Mdot
.32518 .63302 Mdot
.64055 .58799 Mdot
.42605 .44585 Mdot
.65265 .40886 Mdot
.67058 .49567 Mdot
.49122 .41788 Mdot
.50311 .4616 Mdot
.35084 .58276 Mdot
.21025 .34402 Mdot
.52013 .69615 Mdot
.62661 .53893 Mdot
.62912 .55098 Mdot
.77098 .43995 Mdot
.33107 .70967 Mdot
.56068 .55746 Mdot
.48545 .84384 Mdot
.60217 .64468 Mdot
.65384 .39674 Mdot
.62326 .50765 Mdot
.55917 .69077 Mdot
.63737 .54082 Mdot
.52848 .67765 Mdot
.4259 .44997 Mdot
.41477 .43824 Mdot
.15073 .50867 Mdot
.4707 .35826 Mdot
.63246 .38873 Mdot
.51116 .71844 Mdot
.31282 .55467 Mdot
.61866 .38689 Mdot
.49356 .6983 Mdot
.31152 .54563 Mdot
.45886 .45876 Mdot
.45296 .45894 Mdot
.34937 .58058 Mdot
.35515 .56081 Mdot
.42597 .39774 Mdot
.71797 .61306 Mdot
.35776 .5493 Mdot
.34922 .5609 Mdot
.65647 .5839 Mdot
.64957 .59764 Mdot
.4969 .46115 Mdot
.48809 .6624 Mdot
.47169 .36966 Mdot
.63167 .55728 Mdot
.6167 .3809 Mdot
.32027 .56759 Mdot
.49128 .38565 Mdot
.48832 .41582 Mdot
.62802 .40139 Mdot
.60857 .39494 Mdot
.62484 .4132 Mdot
.52114 .71544 Mdot
.46802 .42434 Mdot
.32881 .57645 Mdot
.51108 .69408 Mdot
.60078 .37847 Mdot
.62546 .42061 Mdot
.63249 .51147 Mdot
.41263 .38692 Mdot
.70885 .59575 Mdot
.14526 .37748 Mdot
.46155 .20427 Mdot
.66924 .53044 Mdot
.65367 .52085 Mdot
.53476 .29159 Mdot
.47342 .50944 Mdot
.48971 .67729 Mdot
.57892 .39792 Mdot
.57407 .22247 Mdot
.45208 .4636 Mdot
.49775 .42216 Mdot
.51923 .39736 Mdot
.63416 .41398 Mdot
.63984 .2836 Mdot
.32978 .59886 Mdot
.38523 .32707 Mdot
.6384 .37237 Mdot
.66277 .59957 Mdot
.64833 .50955 Mdot
.66872 .54193 Mdot
.43494 .45535 Mdot
.28945 .44174 Mdot
.31849 .68432 Mdot
.76455 .38566 Mdot
.48907 .65047 Mdot
.36434 .40826 Mdot
.57474 .81432 Mdot
.34545 .58147 Mdot
.60244 .54745 Mdot
.65494 .3986 Mdot
.35324 .55831 Mdot
.53036 .64752 Mdot
.49724 .65384 Mdot
.66022 .57663 Mdot
.66224 .57018 Mdot
.65421 .53903 Mdot
.2916 .54552 Mdot
.30469 .56981 Mdot
.44937 .42592 Mdot
.31627 .56572 Mdot
.16816 .45296 Mdot
.63112 .42609 Mdot
.63122 .61586 Mdot
.49327 .66623 Mdot
.31839 .54403 Mdot
.45357 .39966 Mdot
.4416 .51248 Mdot
.42463 .75903 Mdot
.66073 .39165 Mdot
.32114 .2862 Mdot
.69997 .79132 Mdot
.43449 .36876 Mdot
.518 .67735 Mdot
.22607 .35042 Mdot
.4467 .39934 Mdot
.66611 .55327 Mdot
.74643 .59478 Mdot
.6349 .49749 Mdot
.43346 .37442 Mdot
.45245 .46496 Mdot
.52176 .70022 Mdot
.47246 .83438 Mdot
.4485 .4221 Mdot
.41589 .67883 Mdot
.49623 .63006 Mdot
.67062 .56617 Mdot
.86334 .53111 Mdot
.71088 .38572 Mdot
.61329 .31431 Mdot
.66347 .57615 Mdot
.46024 .37632 Mdot
.64798 .59201 Mdot
.65839 .39973 Mdot
.64028 .52944 Mdot
.33603 .59941 Mdot
.68006 .55884 Mdot
.45093 .44008 Mdot
.33308 .56875 Mdot
.49153 .6725 Mdot
.35684 .2308 Mdot
.74132 .54506 Mdot
.6346 .58241 Mdot
.61389 .54763 Mdot
.465 .3498 Mdot
.43883 .7144 Mdot
.40623 .36662 Mdot
.4444 .45122 Mdot
.49635 .63911 Mdot
.30087 .58352 Mdot
.5057 .70954 Mdot
.43525 .47829 Mdot
.70698 .32161 Mdot
.49783 .69928 Mdot
.70059 .70418 Mdot
.64242 .40528 Mdot
.5309 .50756 Mdot
.4589 .39728 Mdot
.47521 .67483 Mdot
.46583 .42438 Mdot
.31913 .59876 Mdot
.54791 .51754 Mdot
.70072 .67732 Mdot
.50933 .65078 Mdot
.71843 .70519 Mdot
.68104 .3299 Mdot
.47047 .47953 Mdot
.50802 .70461 Mdot
.60067 .25613 Mdot
.60663 .56702 Mdot
.64708 .3778 Mdot
.66653 .38842 Mdot
.64715 .3729 Mdot
.41381 .35187 Mdot
.54296 .37366 Mdot
.63389 .36424 Mdot
.52846 .64825 Mdot
.65914 .41143 Mdot
.2921 .70662 Mdot
.78185 .65116 Mdot
.64666 .39577 Mdot
.43409 .41686 Mdot
.49627 .33638 Mdot
.51076 .27771 Mdot
.60124 .74118 Mdot
.81349 .41097 Mdot
.48958 .78019 Mdot
.43069 .38037 Mdot
.30076 .53594 Mdot
.28194 .5626 Mdot
.24285 .32082 Mdot
.49893 .23065 Mdot
.49414 .19311 Mdot
.35609 .53962 Mdot
.67936 .66668 Mdot
.29615 .56466 Mdot
.47693 .36235 Mdot
.47361 .43935 Mdot
.35877 .54031 Mdot
.6756 .30068 Mdot
.66625 .68308 Mdot
.73086 .72389 Mdot
.34699 .55229 Mdot
.48718 .69705 Mdot
.46912 .6797 Mdot
.49887 .64355 Mdot
.34134 .259 Mdot
.31538 .5921 Mdot
.48068 .41841 Mdot
.62719 .55358 Mdot
.41954 .43925 Mdot
.50876 .68156 Mdot
.78726 .65184 Mdot
.31708 .58578 Mdot
.42086 .42053 Mdot
.41553 .48915 Mdot
.6613 .56194 Mdot
.63726 .40335 Mdot
.4041 .53031 Mdot
.49296 .19695 Mdot
.51735 .65069 Mdot
.36601 .55 Mdot
.58684 .66271 Mdot
.74925 .66899 Mdot
.44161 .33561 Mdot
.40899 .45239 Mdot
.7203 .75808 Mdot
.55205 .19946 Mdot
.40577 .39283 Mdot
.62016 .54465 Mdot
.63306 .67483 Mdot
.49246 .40623 Mdot
.28188 .57225 Mdot
.66912 .39066 Mdot
.65876 .38228 Mdot
.49444 .46391 Mdot
.43028 .54394 Mdot
.56776 .50283 Mdot
.47731 .3988 Mdot
.51773 .42296 Mdot
.66883 .56884 Mdot
.61955 .64582 Mdot
.46202 .19077 Mdot
.61601 .38447 Mdot
.45422 .36043 Mdot
.78303 .58046 Mdot
.36179 .57116 Mdot
.67864 .54643 Mdot
.47835 .65704 Mdot
.33321 .62684 Mdot
.65712 .52756 Mdot
.49614 .39175 Mdot
.46633 .35853 Mdot
.47832 .69416 Mdot
.32184 .60518 Mdot
.63744 .41314 Mdot
.61994 .55624 Mdot
.6095 .39997 Mdot
.30606 .58563 Mdot
.31224 .56966 Mdot
.42942 .48959 Mdot
.43806 .33187 Mdot
.62353 .58088 Mdot
.39989 .3815 Mdot
.65077 .49612 Mdot
.55312 .85202 Mdot
.47874 .70673 Mdot
.41983 .37526 Mdot
.35681 .59654 Mdot
.51377 .65175 Mdot
.4668 .44031 Mdot
.74433 .74037 Mdot
.4829 .43412 Mdot
.46328 .64562 Mdot
.60765 .20868 Mdot
.61557 .4083 Mdot
.39407 .32186 Mdot
.57102 .78878 Mdot
.41294 .39498 Mdot
.63663 .54595 Mdot
.50701 .35354 Mdot
.49101 .69 Mdot
.30686 .56686 Mdot
.5325 .86379 Mdot
.50713 .66437 Mdot
.41651 .40461 Mdot
.62086 .3863 Mdot
.36344 .58269 Mdot
.61697 .44286 Mdot
.62538 .4639 Mdot
.53604 .43177 Mdot
.41183 .36981 Mdot
.47845 .38577 Mdot
.72952 .35032 Mdot
.62983 .53784 Mdot
.34065 .55783 Mdot
.51927 .6746 Mdot
.49637 .68001 Mdot
.65393 .58139 Mdot
.48133 .61408 Mdot
.5297 .5091 Mdot
.217 .2944 Mdot
.63287 .59189 Mdot
.63209 .36839 Mdot
.42638 .69348 Mdot
.62408 .54889 Mdot
.6397 .57038 Mdot
.65814 .5838 Mdot
.55133 .60009 Mdot
.3182 .5459 Mdot
.49672 .3945 Mdot
.29383 .59363 Mdot
.46225 .37495 Mdot
.46442 .64306 Mdot
.50475 .6496 Mdot
.31192 .58317 Mdot
.69654 .76625 Mdot
.27229 .498 Mdot
.4396 .40614 Mdot
.5773 .81584 Mdot
.51032 .39516 Mdot
.53218 .27309 Mdot
.51159 .38243 Mdot
.64639 .58058 Mdot
.38696 .40849 Mdot
.44417 .3416 Mdot
.27045 .28991 Mdot
.49031 .66611 Mdot
.6194 .59455 Mdot
.50647 .43009 Mdot
.52085 .41445 Mdot
.29881 .54051 Mdot
.35204 .55854 Mdot
.66366 .38394 Mdot
.4563 .26828 Mdot
.48878 .6726 Mdot
.23867 .67381 Mdot
.42631 .38364 Mdot
.68947 .40297 Mdot
.35788 .31335 Mdot
.46261 .44224 Mdot
.58883 .79166 Mdot
.2861 .43399 Mdot
.46138 .39987 Mdot
.46808 .58025 Mdot
.48689 .65759 Mdot
.69443 .29774 Mdot
.49427 .41716 Mdot
.66195 .55652 Mdot
.30098 .5685 Mdot
.35576 .59168 Mdot
.65308 .37135 Mdot
.17158 .53209 Mdot
.50272 .7105 Mdot
.30782 .57539 Mdot
.45322 .39185 Mdot
.51848 .68201 Mdot
.62274 .58885 Mdot
.44712 .35074 Mdot
.48543 .22861 Mdot
.31642 .55966 Mdot
.48163 .3574 Mdot
.40138 .66587 Mdot
.56835 .31763 Mdot
.65463 .22341 Mdot
.5203 .67188 Mdot
.60596 .40323 Mdot
.51776 .37133 Mdot
.2034 .51272 Mdot
.49641 .35943 Mdot
.64032 .3115 Mdot
.30075 .71521 Mdot
.61005 .41029 Mdot
.43129 .40725 Mdot
.47698 .42586 Mdot
.53821 .4715 Mdot
.61916 .38106 Mdot
.4174 .42715 Mdot
.2611 .61121 Mdot
.32943 .54737 Mdot
.60325 .55063 Mdot
.31596 .55179 Mdot
.43876 .41446 Mdot
.44724 .33098 Mdot
.35868 .56684 Mdot
.58356 .83105 Mdot
.60479 .42155 Mdot
.51471 .6989 Mdot
.50512 .40843 Mdot
.46604 .45124 Mdot
.44031 .15075 Mdot
.68303 .55852 Mdot
.71836 .62709 Mdot
.68266 .45601 Mdot
.79519 .53663 Mdot
.71065 .38297 Mdot
.74565 .29749 Mdot
.55791 .20002 Mdot
.42193 .36857 Mdot
.46374 .30796 Mdot
.36244 .64724 Mdot
.48675 .65031 Mdot
.23908 .63454 Mdot
.42725 .38102 Mdot
.4427 .38963 Mdot
.66906 .52873 Mdot
.67821 .71233 Mdot
.4925 .19224 Mdot
.44211 .51681 Mdot
.63579 .41246 Mdot
.28725 .57981 Mdot
.49803 .39436 Mdot
.49872 .57207 Mdot
.66663 .59686 Mdot
.69778 .37142 Mdot
.42167 .41798 Mdot
.17911 .45958 Mdot
.40079 .74713 Mdot
.51041 .68974 Mdot
.63037 .54931 Mdot
.51237 .19176 Mdot
.41653 .38281 Mdot
.47458 .66255 Mdot
.44834 .41508 Mdot
.58549 .60271 Mdot
.42745 .47657 Mdot
.65109 .39029 Mdot
.4871 .38529 Mdot
.69196 .36178 Mdot
.56698 .13495 Mdot
.64989 .36125 Mdot
.3679 .53748 Mdot
.63301 .61339 Mdot
.636 .58824 Mdot
.35387 .56193 Mdot
.63168 .58591 Mdot
.28804 .3825 Mdot
.34416 .39951 Mdot
.64109 .40816 Mdot
.51894 .43385 Mdot
.64205 .39609 Mdot
.68021 .54665 Mdot
.43107 .3779 Mdot
.61733 .83602 Mdot
.61774 .57235 Mdot
.56879 .1894 Mdot
.50333 .66737 Mdot
.66557 .59842 Mdot
.49157 .42278 Mdot
.57823 .67648 Mdot
.63363 .59686 Mdot
.68384 .68808 Mdot
.44578 .4295 Mdot
.31185 .56158 Mdot
.49042 .40865 Mdot
.49962 .43141 Mdot
.64082 .60755 Mdot
.46133 .36938 Mdot
.49254 .69762 Mdot
.34005 .53548 Mdot
.8363 .47065 Mdot
.35591 .74917 Mdot
.41186 .41848 Mdot
.45129 .39374 Mdot
.27586 .58859 Mdot
.44034 .45434 Mdot
.52688 .67213 Mdot
.18017 .69628 Mdot
.64208 .40515 Mdot
.61449 .59611 Mdot
.71151 .37903 Mdot
.46758 .45684 Mdot
.47453 .36702 Mdot
.76664 .71983 Mdot
.70129 .32177 Mdot
.50249 .70332 Mdot
.45373 .3414 Mdot
.62412 .59086 Mdot
.6255 .38488 Mdot
.52753 .65256 Mdot
.47003 .40255 Mdot
.43256 .39918 Mdot
.60544 .39516 Mdot
.51108 .31793 Mdot
.38529 .23328 Mdot
.47348 .67921 Mdot
.38114 .40183 Mdot
.6873 .59909 Mdot
.40477 .42245 Mdot
.31854 .27419 Mdot
.35032 .56658 Mdot
.51488 .64679 Mdot
.78918 .47407 Mdot
.41676 .3795 Mdot
.49461 .70418 Mdot
.48843 .67136 Mdot
.46933 .3464 Mdot
.36341 .59233 Mdot
.32322 .53739 Mdot
.33463 .54561 Mdot
.14362 .54211 Mdot
.59601 .30125 Mdot
.65438 .53913 Mdot
.48597 .65784 Mdot
.61497 .5431 Mdot
.67956 .39917 Mdot
.55403 .56253 Mdot
.61646 .5438 Mdot
.33186 .54218 Mdot
.61704 .60748 Mdot
.46318 .43179 Mdot
.49101 .67402 Mdot
.64226 .54017 Mdot
.49172 .44375 Mdot
.43501 .69892 Mdot
.54423 .76982 Mdot
.63348 .41949 Mdot
.66752 .38445 Mdot
.48368 .42924 Mdot
.62174 .52958 Mdot
.42795 .39588 Mdot
.49086 .6376 Mdot
.42897 .68924 Mdot
.5042 .40873 Mdot
.63657 .58376 Mdot
.28209 .59689 Mdot
.50175 .19564 Mdot
.39537 .37975 Mdot
.43369 .41569 Mdot
.45949 .37256 Mdot
.44875 .41534 Mdot
.74761 .65666 Mdot
.46486 .66737 Mdot
.37601 .76623 Mdot
.73916 .38866 Mdot
.32396 .58713 Mdot
.28575 .58864 Mdot
.44844 .20341 Mdot
.36388 .65509 Mdot
.48776 .66124 Mdot
.47091 .38632 Mdot
.35893 .71043 Mdot
.81966 .61501 Mdot
.69733 .78168 Mdot
.54282 .45475 Mdot
.68507 .57101 Mdot
.36331 .5469 Mdot
.61076 .57165 Mdot
.45372 .37681 Mdot
.52056 .39573 Mdot
.7243 .26528 Mdot
.51901 .63617 Mdot
.64561 .40648 Mdot
.46535 .37403 Mdot
.59775 .30562 Mdot
.63553 .55715 Mdot
.6572 .60474 Mdot
.43273 .44865 Mdot
.31749 .60797 Mdot
.53381 .14531 Mdot
.51564 .68418 Mdot
.48663 .77553 Mdot
.28223 .67436 Mdot
.44955 .75887 Mdot
.51065 .68286 Mdot
.56149 .43818 Mdot
.67331 .53709 Mdot
.35686 .30168 Mdot
.32902 .58935 Mdot
.65368 .38075 Mdot
.46089 .46928 Mdot
.35657 .57713 Mdot
.67358 .55366 Mdot
.309 .56456 Mdot
.47823 .36745 Mdot
.48053 .63535 Mdot
.64423 .55426 Mdot
.47893 .62 Mdot
.34977 .60379 Mdot
.61892 .38328 Mdot
.4642 .52639 Mdot
.31661 .50649 Mdot
.28521 .42968 Mdot
.42649 .44749 Mdot
.50297 .57542 Mdot
.47947 .41768 Mdot
.27431 .57084 Mdot
.45169 .40433 Mdot
.27221 .54296 Mdot
.63725 .54681 Mdot
.49704 .41631 Mdot
.47723 .39506 Mdot
.29963 .74036 Mdot
.42596 .43025 Mdot
.40187 .38159 Mdot
.46445 .39781 Mdot
.36368 .52274 Mdot
.52229 .4289 Mdot
.29369 .55392 Mdot
.6972 .51333 Mdot
.64239 .57179 Mdot
.6674 .39838 Mdot
.60206 .39545 Mdot
.62162 .29029 Mdot
.76476 .46491 Mdot
.6527 .73275 Mdot
.3227 .55227 Mdot
.48405 .68639 Mdot
.45167 .40874 Mdot
.75745 .33622 Mdot
.61037 .49005 Mdot
.67289 .58868 Mdot
.35928 .75077 Mdot
.37839 .41835 Mdot
.69934 .28838 Mdot
.44552 .34399 Mdot
.15331 .53245 Mdot
.39836 .35344 Mdot
.41664 .46929 Mdot
.60359 .5714 Mdot
.68689 .37237 Mdot
.45325 .45321 Mdot
.30882 .53577 Mdot
.64729 .38153 Mdot
.50282 .32867 Mdot
.70721 .58277 Mdot
.70663 .5295 Mdot
.33234 .51238 Mdot
.45814 .42467 Mdot
.64542 .55503 Mdot
.29081 .57184 Mdot
.47092 .19069 Mdot
.51233 .69435 Mdot
.4587 .63633 Mdot
.39959 .62585 Mdot
.59726 .82001 Mdot
.63174 .37344 Mdot
.33637 .3043 Mdot
.4542 .43905 Mdot
.73788 .58317 Mdot
.50464 .40119 Mdot
.79367 .64543 Mdot
.61936 .37441 Mdot
.33518 .5406 Mdot
.48407 .6935 Mdot
.28395 .57776 Mdot
.27671 .43563 Mdot
.66918 .5188 Mdot
.51724 .5435 Mdot
.63084 .56533 Mdot
.59025 .47132 Mdot
.33696 .56403 Mdot
.45471 .36209 Mdot
.21367 .29634 Mdot
.34991 .56277 Mdot
.36558 .57317 Mdot
.42423 .82117 Mdot
.5817 .84904 Mdot
.38579 .4192 Mdot
.36008 .5506 Mdot
.63193 .57031 Mdot
.63779 .38425 Mdot
.4926 .39744 Mdot
.45661 .42923 Mdot
.35532 .57763 Mdot
.63389 .60598 Mdot
.2288 .48219 Mdot
.65876 .57336 Mdot
.32072 .54496 Mdot
.65279 .56777 Mdot
.58018 .65809 Mdot
.62215 .5461 Mdot
.46428 .45216 Mdot
.45179 .40547 Mdot
.73615 .4361 Mdot
.31236 .56867 Mdot
.47758 .4006 Mdot
.46343 .35002 Mdot
.32865 .57363 Mdot
.58948 .44547 Mdot
.23495 .47417 Mdot
.40763 .41623 Mdot
.43641 .43186 Mdot
.60873 .40781 Mdot
.53648 .57947 Mdot
.327 .29654 Mdot
.47812 .37002 Mdot
.60172 .38732 Mdot
.31182 .53568 Mdot
.42234 .40458 Mdot
.82069 .57793 Mdot
.63721 .67481 Mdot
.43057 .37297 Mdot
.60691 .56696 Mdot
.44561 .34193 Mdot
.63867 .21204 Mdot
.44612 .4515 Mdot
.32856 .56496 Mdot
.30253 .57775 Mdot
.246 .68948 Mdot
.34181 .57454 Mdot
.65453 .59718 Mdot
.50874 .6793 Mdot
.7459 .68592 Mdot
.62013 .58655 Mdot
.4057 .35047 Mdot
.27009 .73983 Mdot
.44591 .35598 Mdot
.48207 .44678 Mdot
.5765 .17419 Mdot
.61318 .57168 Mdot
.31059 .59451 Mdot
.49091 .50918 Mdot
.43714 .32897 Mdot
.51091 .64445 Mdot
.47848 .46595 Mdot
.42147 .44915 Mdot
.5986 .20129 Mdot
.74931 .6344 Mdot
.47875 .64972 Mdot
.40085 .39235 Mdot
.47717 .36887 Mdot
.69133 .56653 Mdot
.45531 .39523 Mdot
.64161 .38537 Mdot
.31072 .59084 Mdot
.61832 .55163 Mdot
.62496 .40155 Mdot
.41764 .38679 Mdot
.629 .4135 Mdot
.65286 .54425 Mdot
.48182 .65013 Mdot
.44336 .37605 Mdot
.62305 .42204 Mdot
.63031 .413 Mdot
.47957 .41445 Mdot
.30544 .56468 Mdot
.37929 .37939 Mdot
.42209 .4282 Mdot
.49027 .38364 Mdot
.34771 .58683 Mdot
.87059 .59517 Mdot
.46884 .44313 Mdot
.65613 .31343 Mdot
.35496 .58826 Mdot
.59275 .46163 Mdot
.60944 .57608 Mdot
.42475 .4512 Mdot
.48259 .64822 Mdot
.47792 .66374 Mdot
.67236 .54615 Mdot
.37088 .55958 Mdot
.69115 .4449 Mdot
.3562 .60704 Mdot
.48511 .34126 Mdot
.40152 .41621 Mdot
.22625 .5638 Mdot
.80463 .38457 Mdot
.30675 .5983 Mdot
.68607 .62093 Mdot
.43225 .53129 Mdot
.47658 .675 Mdot
.65731 .60112 Mdot
.36346 .54409 Mdot
.33572 .59636 Mdot
.3049 .55599 Mdot
.6587 .38528 Mdot
.73933 .43857 Mdot
.33715 .60322 Mdot
.30194 .60451 Mdot
.4496 .43157 Mdot
.47861 .3719 Mdot
.51167 .20377 Mdot
.4465 .23952 Mdot
.63959 .41678 Mdot
.67108 .55613 Mdot
.12704 .52549 Mdot
.49684 .63575 Mdot
.34636 .76594 Mdot
.49336 .43388 Mdot
.11083 .41927 Mdot
.49423 .41297 Mdot
.45601 .391 Mdot
.34016 .5352 Mdot
.63096 .42171 Mdot
.64306 .39965 Mdot
.34296 .55893 Mdot
.29032 .59645 Mdot
.64257 .38643 Mdot
.55593 .80027 Mdot
.83196 .57778 Mdot
.6187 .50258 Mdot
.32371 .57678 Mdot
.3397 .49388 Mdot
.47341 .68487 Mdot
.50717 .34032 Mdot
.48937 .63488 Mdot
.6376 .56341 Mdot
.65935 .52711 Mdot
.51475 .64985 Mdot
.44508 .42786 Mdot
.64781 .53624 Mdot
.42605 .3677 Mdot
.48328 .79101 Mdot
.27977 .47018 Mdot
.71341 .41658 Mdot
.54 .42119 Mdot
.58169 .45019 Mdot
.48893 .6146 Mdot
.41835 .39588 Mdot
.80587 .55012 Mdot
.64145 .41013 Mdot
.52128 .36847 Mdot
.51314 .64299 Mdot
.60877 .17742 Mdot
.43792 .37501 Mdot
.32556 .56457 Mdot
.48612 .6675 Mdot
.3809 .60883 Mdot
.41737 .67387 Mdot
.46111 .37357 Mdot
.1511 .37587 Mdot
.36837 .52924 Mdot
.62672 .54643 Mdot
.19007 .52137 Mdot
.31297 .60279 Mdot
.61272 .35901 Mdot
.76407 .41933 Mdot
.66137 .78947 Mdot
.29743 .58681 Mdot
.68612 .55951 Mdot
.30176 .54618 Mdot
.6219 .38123 Mdot
.34517 .52833 Mdot
.63665 .552 Mdot
.42415 .41652 Mdot
.64832 .58294 Mdot
.66333 .39547 Mdot
.38848 .236 Mdot
.47801 .65129 Mdot
.61582 .59147 Mdot
.50929 .65537 Mdot
.55241 .32245 Mdot
.72612 .35439 Mdot
.52017 .69118 Mdot
.23147 .41088 Mdot
.40283 .42657 Mdot
.31608 .60471 Mdot
.64944 .58612 Mdot
.77468 .52978 Mdot
.46017 .52494 Mdot
.33544 .58739 Mdot
.66582 .5453 Mdot
.41631 .61772 Mdot
.19203 .47458 Mdot
.40287 .37565 Mdot
.50112 .28588 Mdot
.32706 .5783 Mdot
.68084 .54301 Mdot
.40453 .20164 Mdot
.30167 .5448 Mdot
.63809 .59358 Mdot
.48659 .69779 Mdot
.49868 .68313 Mdot
.42244 .43866 Mdot
.48984 .62245 Mdot
.65774 .53339 Mdot
.43623 .67314 Mdot
.36225 .55167 Mdot
.34833 .62819 Mdot
.62363 .42404 Mdot
.64683 .57535 Mdot
.46838 .35652 Mdot
.28885 .53647 Mdot
.61311 .66627 Mdot
.23417 .49943 Mdot
.2105 .33533 Mdot
.65405 .58114 Mdot
.32163 .59364 Mdot
.3228 .56438 Mdot
.39743 .37302 Mdot
.41686 .5818 Mdot
.69481 .44565 Mdot
.47547 .49889 Mdot
.44968 .50689 Mdot
.60314 .54886 Mdot
.66676 .50803 Mdot
.50444 .43476 Mdot
.4562 .42042 Mdot
.47767 .67938 Mdot
.42625 .41932 Mdot
.34833 .53956 Mdot
.42918 .44751 Mdot
.51835 .67368 Mdot
.62633 .56342 Mdot
.43888 .37751 Mdot
.61812 .41095 Mdot
.47409 .69155 Mdot
.53426 .65812 Mdot
.64109 .57989 Mdot
.35546 .57945 Mdot
.61106 .45122 Mdot
.6633 .56908 Mdot
.45708 .42476 Mdot
.54168 .58957 Mdot
.48234 .36825 Mdot
.39663 .32455 Mdot
.29757 .54678 Mdot
.61724 .55484 Mdot
.35238 .53605 Mdot
.5056 .65807 Mdot
.74399 .39429 Mdot
.44317 .41013 Mdot
.63077 .5914 Mdot
.64531 .6395 Mdot
.4391 .29546 Mdot
.30664 .60905 Mdot
.58182 .77039 Mdot
.28055 .58178 Mdot
.67291 .56337 Mdot
.33063 .7715 Mdot
.64327 .37438 Mdot
.67293 .58916 Mdot
.83314 .44336 Mdot
.6232 .57757 Mdot
.43337 .44166 Mdot
.48079 .43113 Mdot
.62079 .54885 Mdot
.6038 .40035 Mdot
.50854 .18116 Mdot
.59585 .5755 Mdot
.30641 .59231 Mdot
.48661 .80223 Mdot
.29239 .2511 Mdot
.47159 .7067 Mdot
.47976 .6819 Mdot
.39732 .35065 Mdot
.3945 .42324 Mdot
.51522 .64046 Mdot
.52028 .63143 Mdot
.65842 .37838 Mdot
.65403 .58899 Mdot
.30653 .52482 Mdot
.53131 .69639 Mdot
.39074 .52269 Mdot
.75802 .45766 Mdot
.39462 .38409 Mdot
.29292 .68371 Mdot
.49838 .42138 Mdot
.64521 .33789 Mdot
.51922 .67258 Mdot
.48804 .36574 Mdot
.41756 .35467 Mdot
.4918 .64145 Mdot
.63888 .38286 Mdot
.51315 .60575 Mdot
.65194 .5631 Mdot
.86448 .55392 Mdot
.42888 .35988 Mdot
.43731 .4456 Mdot
.49127 .64909 Mdot
.69805 .48927 Mdot
.31878 .58815 Mdot
.27908 .56891 Mdot
.62886 .53862 Mdot
.44558 .54302 Mdot
.41614 .44085 Mdot
.41849 .40549 Mdot
.65122 .55559 Mdot
.64743 .60144 Mdot
.62694 .7356 Mdot
.47321 .43147 Mdot
.49308 .66374 Mdot
.68017 .40678 Mdot
.51966 .6683 Mdot
.47887 .3648 Mdot
.44329 .44555 Mdot
.46274 .45303 Mdot
.46996 .35786 Mdot
.51497 .6287 Mdot
.49666 .37975 Mdot
.52381 .40038 Mdot
.32752 .59244 Mdot
.47168 .37296 Mdot
.45869 .50556 Mdot
.43244 .42236 Mdot
.63928 .38518 Mdot
.30073 .31533 Mdot
.43844 .37518 Mdot
.42313 .4483 Mdot
.61243 .5987 Mdot
.43613 .40309 Mdot
.49306 .63642 Mdot
.31578 .57575 Mdot
.48766 .65669 Mdot
.47774 .66168 Mdot
.64068 .52476 Mdot
.63892 .36507 Mdot
.46419 .45873 Mdot
.65852 .39614 Mdot
.42223 .33937 Mdot
.41654 .3792 Mdot
.75184 .41656 Mdot
.1558 .54616 Mdot
.35281 .25084 Mdot
.44308 .41201 Mdot
.61488 .57133 Mdot
.60966 .56972 Mdot
.49738 .31809 Mdot
.40683 .37097 Mdot
.52897 .66955 Mdot
.47601 .6694 Mdot
.48926 .23312 Mdot
.64555 .24856 Mdot
.63936 .38458 Mdot
.52894 .56643 Mdot
.40702 .38288 Mdot
.48004 .36179 Mdot
.44226 .35334 Mdot
.62009 .53907 Mdot
.53725 .4555 Mdot
.66569 .59567 Mdot
.40851 .7568 Mdot
.50767 .647 Mdot
.44997 .37308 Mdot
.31689 .71119 Mdot
.35044 .55288 Mdot
.31551 .57467 Mdot
.53532 .66901 Mdot
.69884 .56661 Mdot
.47829 .20844 Mdot
.69091 .79219 Mdot
.3734 .54043 Mdot
.65311 .41559 Mdot
.41461 .39984 Mdot
.62538 .57002 Mdot
.32246 .5429 Mdot
.65473 .41359 Mdot
.44804 .36506 Mdot
.74041 .43851 Mdot
.44361 .4177 Mdot
.33691 .66204 Mdot
.29838 .56447 Mdot
.80597 .63057 Mdot
.37105 .56499 Mdot
.47551 .69476 Mdot
.52164 .65562 Mdot
.46663 .43974 Mdot
.21181 .55454 Mdot
.29603 .59671 Mdot
.55367 .60931 Mdot
.63197 .3687 Mdot
.59465 .66917 Mdot
.6296 .37881 Mdot
.63047 .54633 Mdot
.64373 .37787 Mdot
.63757 .54982 Mdot
.44479 .22874 Mdot
.37467 .52526 Mdot
.63175 .40657 Mdot
.6168 .63465 Mdot
.39147 .41858 Mdot
.63328 .41754 Mdot
.5151 .38255 Mdot
.40847 .31604 Mdot
.65409 .557 Mdot
.62565 .3736 Mdot
.45604 .36051 Mdot
.72817 .28416 Mdot
.50945 .70328 Mdot
.52743 .66508 Mdot
.51078 .37633 Mdot
.60872 .54123 Mdot
.32871 .53167 Mdot
.77898 .64072 Mdot
.51211 .72 Mdot
.46919 .44133 Mdot
.44779 .45408 Mdot
.28755 .59153 Mdot
.29755 .7183 Mdot
.45661 .44265 Mdot
.40234 .4793 Mdot
.47388 .43253 Mdot
.51963 .701 Mdot
.285 .57851 Mdot
.31948 .5683 Mdot
.66195 .54176 Mdot
.35852 .5589 Mdot
.49064 .30694 Mdot
.34506 .722 Mdot
.38337 .45673 Mdot
.50897 .66383 Mdot
.38475 .74186 Mdot
.40623 .75802 Mdot
.81285 .41466 Mdot
.34273 .60844 Mdot
.50364 .40315 Mdot
.36249 .56975 Mdot
.62822 .38344 Mdot
.31354 .56057 Mdot
.36269 .54617 Mdot
.42574 .39396 Mdot
.46048 .37654 Mdot
.62457 .55656 Mdot
.4191 .56739 Mdot
.35571 .58397 Mdot
.49403 .41059 Mdot
.39744 .4359 Mdot
.43579 .36136 Mdot
.56788 .6092 Mdot
.29941 .59422 Mdot
.48331 .83251 Mdot
.56866 .24338 Mdot
.35555 .58347 Mdot
.54831 .14776 Mdot
.63641 .64395 Mdot
.64532 .51475 Mdot
.46695 .62171 Mdot
.47857 .42788 Mdot
.62464 .59403 Mdot
.45276 .37679 Mdot
.29486 .68408 Mdot
.43632 .39553 Mdot
.64327 .38484 Mdot
.42228 .36819 Mdot
.6688 .53592 Mdot
.6588 .57497 Mdot
.45755 .44759 Mdot
.44039 .37904 Mdot
.41151 .22414 Mdot
.38004 .58105 Mdot
.31056 .57546 Mdot
.68128 .45016 Mdot
.62085 .40524 Mdot
.51384 .6463 Mdot
.45873 .39967 Mdot
.63373 .52811 Mdot
.65665 .57766 Mdot
.30319 .5985 Mdot
.66496 .55467 Mdot
.51465 .68468 Mdot
.44579 .40621 Mdot
.51872 .64403 Mdot
.65805 .38258 Mdot
.2896 .58508 Mdot
.46745 .37283 Mdot
.44913 .43162 Mdot
.30235 .57786 Mdot
.49087 .44773 Mdot
.60701 .40414 Mdot
.62556 .58113 Mdot
.29331 .58317 Mdot
.50601 .68072 Mdot
.63173 .5473 Mdot
.49275 .38454 Mdot
.14257 .45881 Mdot
.43289 .43867 Mdot
.48743 .41583 Mdot
.83427 .42205 Mdot
.41042 .37674 Mdot
.65303 .58324 Mdot
.33026 .54055 Mdot
.52852 .43714 Mdot
.60336 .27861 Mdot
.82863 .67531 Mdot
.6713 .58975 Mdot
.41364 .40546 Mdot
.76884 .35142 Mdot
.41597 .4128 Mdot
.24464 .54012 Mdot
.59607 .54068 Mdot
.55916 .48223 Mdot
.50744 .37895 Mdot
.49741 .69166 Mdot
.62081 .55834 Mdot
.64122 .54698 Mdot
.45485 .80621 Mdot
.42266 .39758 Mdot
.48277 .59189 Mdot
.46168 .36422 Mdot
.50525 .68461 Mdot
.51794 .23566 Mdot
.65934 .57631 Mdot
.24101 .3179 Mdot
.47818 .42056 Mdot
.33198 .59873 Mdot
.6188 .60917 Mdot
.56989 .66916 Mdot
.49114 .38688 Mdot
.65142 .40661 Mdot
.52885 .71004 Mdot
.45297 .47631 Mdot
.51118 .66861 Mdot
.48848 .38051 Mdot
.46433 .491 Mdot
.18574 .53609 Mdot
.30505 .56016 Mdot
.48252 .69175 Mdot
.55674 .58512 Mdot
.50063 .38495 Mdot
.29587 .58508 Mdot
.33116 .58936 Mdot
.66188 .38832 Mdot
.54866 .53234 Mdot
.39909 .65396 Mdot
.29754 .48983 Mdot
.47364 .80374 Mdot
.62136 .60803 Mdot
.70162 .67074 Mdot
.48657 .40188 Mdot
.67794 .42472 Mdot
.48574 .64191 Mdot
.42887 .43777 Mdot
.33188 .31844 Mdot
.34597 .55438 Mdot
.43999 .43683 Mdot
.64237 .39455 Mdot
.65652 .45618 Mdot
.67657 .42068 Mdot
.7708 .41262 Mdot
.63254 .56514 Mdot
.52086 .3884 Mdot
.47115 .48605 Mdot
.60494 .56943 Mdot
.42699 .45513 Mdot
.63532 .59048 Mdot
.57429 .81004 Mdot
.63639 .41905 Mdot
.30657 .59622 Mdot
.57952 .63134 Mdot
.44777 .46095 Mdot
.40322 .43587 Mdot
.65352 .36699 Mdot
.46068 .41876 Mdot
.16998 .51819 Mdot
.57433 .61029 Mdot
.63986 .53887 Mdot
.30497 .55687 Mdot
.43505 .45559 Mdot
.55857 .54306 Mdot
.41999 .42283 Mdot
.33247 .41866 Mdot
.4247 .44915 Mdot
.41167 .65425 Mdot
.30163 .56797 Mdot
.51228 .66394 Mdot
.49959 .37604 Mdot
.44326 .39247 Mdot
.6479 .28372 Mdot
.40929 .34268 Mdot
.49477 .37204 Mdot
.26917 .58935 Mdot
.31771 .54269 Mdot
.29843 .55048 Mdot
.67903 .55922 Mdot
.61818 .2203 Mdot
.49776 .65987 Mdot
.53621 .4161 Mdot
.52599 .70161 Mdot
.21771 .51041 Mdot
.65127 .41591 Mdot
.77884 .39029 Mdot
.47174 .39587 Mdot
.32481 .54877 Mdot
.77211 .59893 Mdot
.29019 .5463 Mdot
.51199 .56438 Mdot
.48907 .67285 Mdot
.34684 .56135 Mdot
.45123 .39019 Mdot
.44419 .52795 Mdot
.73982 .32273 Mdot
.49727 .65326 Mdot
.40266 .35439 Mdot
.68255 .56246 Mdot
.71966 .40059 Mdot
.16503 .42094 Mdot
.51047 .70359 Mdot
.46213 .64864 Mdot
.42098 .39789 Mdot
.34978 .54959 Mdot
.50199 .69126 Mdot
.52336 .69316 Mdot
.66434 .55198 Mdot
.46452 .37685 Mdot
.46943 .37868 Mdot
.67429 .56417 Mdot
.48851 .65451 Mdot
.50405 .36571 Mdot
.42862 .47725 Mdot
.69495 .22963 Mdot
.40692 .61526 Mdot
.86891 .5575 Mdot
.50858 .32302 Mdot
.30158 .33676 Mdot
.78045 .64724 Mdot
.3466 .59358 Mdot
.42422 .37817 Mdot
.42919 .4703 Mdot
.65878 .53393 Mdot
.43346 .4117 Mdot
.6196 .51547 Mdot
.48199 .6699 Mdot
.60159 .17902 Mdot
.39197 .72056 Mdot
.62017 .80072 Mdot
.4322 .4103 Mdot
.26683 .54704 Mdot
.627 .39189 Mdot
.46805 .69376 Mdot
.28527 .56333 Mdot
.46014 .35524 Mdot
.40759 .22514 Mdot
.66938 .59294 Mdot
.3479 .57863 Mdot
.47107 .1928 Mdot
.56786 .44674 Mdot
.48007 .36707 Mdot
.67814 .574 Mdot
.7949 .5781 Mdot
.38433 .58736 Mdot
.50381 .72018 Mdot
.64014 .38213 Mdot
.61766 .55893 Mdot
.47496 .66919 Mdot
.28531 .53551 Mdot
.34474 .56856 Mdot
.32384 .53047 Mdot
.33755 .27189 Mdot
.61094 .59081 Mdot
.62699 .3959 Mdot
.68012 .28361 Mdot
.64901 .26488 Mdot
.64495 .38755 Mdot
.66232 .5284 Mdot
.31893 .54279 Mdot
.33891 .55508 Mdot
.31629 .5762 Mdot
.30589 .2693 Mdot
.36131 .58599 Mdot
.3828 .7878 Mdot
.44388 .35925 Mdot
.3985 .47162 Mdot
.41486 .40614 Mdot
.52662 .65869 Mdot
.29679 .57462 Mdot
.47986 .52011 Mdot
.42754 .34181 Mdot
.74039 .35252 Mdot
.42719 .44052 Mdot
.46776 .65235 Mdot
.4495 .43673 Mdot
.24659 .65983 Mdot
.36173 .57451 Mdot
.43941 .41204 Mdot
.47194 .65226 Mdot
.61568 .40139 Mdot
.29917 .60707 Mdot
.45995 .37267 Mdot
.62557 .75881 Mdot
.41492 .37287 Mdot
.62582 .79094 Mdot
.34582 .63437 Mdot
.65241 .4159 Mdot
.28939 .65669 Mdot
.68048 .58862 Mdot
.41119 .47929 Mdot
.45807 .32854 Mdot
.50413 .65321 Mdot
.59628 .65137 Mdot
.63999 .57203 Mdot
.54257 .45274 Mdot
.49765 .45684 Mdot
.66534 .39548 Mdot
.38763 .561 Mdot
.51417 .63861 Mdot
.41808 .45134 Mdot
.40539 .36586 Mdot
.43841 .78389 Mdot
.51822 .42682 Mdot
.43678 .45267 Mdot
.66651 .37631 Mdot
.37534 .77741 Mdot
.43601 .42431 Mdot
.52123 .5628 Mdot
.35335 .52971 Mdot
.47784 .33839 Mdot
.36529 .78049 Mdot
.48324 .42938 Mdot
.35085 .57171 Mdot
.3653 .43716 Mdot
.38641 .64504 Mdot
.63505 .36589 Mdot
.42193 .4483 Mdot
.25081 .69795 Mdot
.47081 .4238 Mdot
.49705 .66456 Mdot
.40375 .37804 Mdot
.63651 .55473 Mdot
.35488 .24382 Mdot
.65494 .53578 Mdot
.40998 .42848 Mdot
.31909 .57799 Mdot
.49701 .64569 Mdot
.26437 .30976 Mdot
.72047 .44946 Mdot
.35532 .76591 Mdot
.71714 .75472 Mdot
.62016 .3774 Mdot
.60304 .37528 Mdot
.50688 .63464 Mdot
.43911 .41393 Mdot
.37682 .80361 Mdot
.39655 .35458 Mdot
.43812 .43267 Mdot
.43652 .39414 Mdot
.71741 .35094 Mdot
.47907 .66816 Mdot
.65891 .56221 Mdot
.45066 .44437 Mdot
.49591 .37654 Mdot
.34427 .59415 Mdot
.62178 .40918 Mdot
.60947 .57546 Mdot
.64279 .40628 Mdot
.62114 .56327 Mdot
.5701 .15921 Mdot
.45834 .34366 Mdot
.61631 .39636 Mdot
.53227 .7002 Mdot
.35245 .58125 Mdot
.34578 .71777 Mdot
.63602 .54562 Mdot
.67053 .54625 Mdot
.44557 .45007 Mdot
.35263 .56922 Mdot
.34528 .53511 Mdot
.62459 .38345 Mdot
.51885 .68855 Mdot
.43739 .37572 Mdot
.41122 .38324 Mdot
.36505 .46424 Mdot
.61807 .53477 Mdot
.3261 .66589 Mdot
.69617 .69159 Mdot
.44167 .41415 Mdot
.36081 .5498 Mdot
.43621 .38419 Mdot
.72879 .69176 Mdot
.35409 .55422 Mdot
.48783 .42505 Mdot
.49435 .16183 Mdot
.69973 .55533 Mdot
.37046 .67138 Mdot
.46344 .45036 Mdot
.76858 .69754 Mdot
.48123 .39845 Mdot
.62597 .17587 Mdot
.75537 .56014 Mdot
.40447 .42384 Mdot
.49464 .39407 Mdot
.25513 .47678 Mdot
.41138 .39547 Mdot
.67396 .55899 Mdot
.547 .19712 Mdot
.30808 .53531 Mdot
.49779 .76197 Mdot
.31031 .31227 Mdot
.62031 .37432 Mdot
.62841 .53898 Mdot
.65765 .50656 Mdot
.64933 .39481 Mdot
.32502 .57441 Mdot
.44899 .41524 Mdot
.47208 .54543 Mdot
.60865 .54586 Mdot
.53586 .35929 Mdot
.49665 .66697 Mdot
.62122 .69757 Mdot
.59048 .50616 Mdot
.51316 .67422 Mdot
.47488 .37458 Mdot
.24522 .47783 Mdot
.39237 .26687 Mdot
.84242 .55399 Mdot
.47376 .6709 Mdot
.49738 .65131 Mdot
.3308 .25187 Mdot
.65203 .42163 Mdot
.46388 .7836 Mdot
.41462 .66215 Mdot
.506 .64277 Mdot
.35817 .61733 Mdot
.66632 .58951 Mdot
.5155 .62063 Mdot
.5248 .38424 Mdot
.42473 .37191 Mdot
.44878 .39107 Mdot
.52168 .68221 Mdot
.44921 .29719 Mdot
.18499 .51169 Mdot
.51049 .65476 Mdot
.43018 .3233 Mdot
.54142 .50972 Mdot
.70924 .62477 Mdot
.66843 .56855 Mdot
.64095 .36691 Mdot
.59142 .40626 Mdot
.32617 .59736 Mdot
.63989 .36591 Mdot
.66254 .4499 Mdot
.46172 .41186 Mdot
.5171 .65936 Mdot
.60561 .6657 Mdot
.50089 .67984 Mdot
.64718 .39763 Mdot
.66864 .40218 Mdot
.32677 .59222 Mdot
.31056 .5698 Mdot
.27714 .37521 Mdot
.52302 .26589 Mdot
.42027 .42953 Mdot
.78633 .4928 Mdot
.35903 .54184 Mdot
.54063 .36343 Mdot
.64456 .36649 Mdot
.61837 .40486 Mdot
.6554 .29572 Mdot
.4679 .39276 Mdot
.23631 .5755 Mdot
.46401 .39507 Mdot
.51978 .24249 Mdot
.49255 .43247 Mdot
.66482 .5529 Mdot
.47227 .38767 Mdot
.67205 .30259 Mdot
.45421 .46417 Mdot
.39283 .41377 Mdot
.62419 .53439 Mdot
.46942 .47333 Mdot
.63826 .55595 Mdot
.41282 .42829 Mdot
.60382 .41224 Mdot
.63915 .53242 Mdot
.60112 .2945 Mdot
.66575 .30954 Mdot
.6673 .53068 Mdot
.66118 .39868 Mdot
.60489 .38691 Mdot
.61455 .32067 Mdot
.28502 .56344 Mdot
.45916 .32267 Mdot
.43611 .41432 Mdot
.64957 .6036 Mdot
.47839 .67457 Mdot
.49718 .39819 Mdot
.39874 .43579 Mdot
.48334 .43724 Mdot
.32589 .59794 Mdot
.69949 .44185 Mdot
.6179 .38924 Mdot
.67511 .57049 Mdot
.61213 .45471 Mdot
.60584 .54241 Mdot
.39984 .38011 Mdot
.43801 .47007 Mdot
.32256 .31438 Mdot
.69032 .64472 Mdot
.30555 .26114 Mdot
.34519 .57053 Mdot
.60749 .56656 Mdot
.61425 .42136 Mdot
.4089 .46512 Mdot
.32669 .54669 Mdot
.63699 .55251 Mdot
.44404 .41688 Mdot
.39551 .36175 Mdot
.37686 .75293 Mdot
.50129 .30495 Mdot
.63915 .30403 Mdot
.67224 .54501 Mdot
.68433 .57707 Mdot
.69236 .32674 Mdot
.66324 .35864 Mdot
.46427 .5244 Mdot
.42297 .40798 Mdot
.65138 .40556 Mdot
.3242 .5429 Mdot
.35157 .27165 Mdot
.52525 .67273 Mdot
.41767 .57485 Mdot
.43395 .40956 Mdot
.57468 .46473 Mdot
.31926 .58015 Mdot
.64161 .39185 Mdot
.52234 .67964 Mdot
.59466 .37993 Mdot
.61145 .55019 Mdot
.62565 .81707 Mdot
.46624 .42322 Mdot
.43719 .4499 Mdot
.46878 .67736 Mdot
.33941 .54843 Mdot
.63915 .36283 Mdot
.49607 .80117 Mdot
.64969 .54469 Mdot
.35554 .79178 Mdot
.35706 .54745 Mdot
.35679 .49699 Mdot
.66977 .57927 Mdot
.53392 .67773 Mdot
.60025 .31135 Mdot
.51641 .67837 Mdot
.41488 .4364 Mdot
.32232 .55633 Mdot
.48545 .69203 Mdot
.4082 .58548 Mdot
.76211 .33611 Mdot
.34558 .49657 Mdot
.45871 .40779 Mdot
.69391 .2507 Mdot
.6137 .78205 Mdot
.38216 .5713 Mdot
.47929 .6513 Mdot
.42693 .43831 Mdot
.40886 .44155 Mdot
.46889 .42599 Mdot
.48502 .68358 Mdot
.77755 .471 Mdot
.65336 .55414 Mdot
.41754 .40126 Mdot
.65912 .37963 Mdot
.6403 .56246 Mdot
.57778 .63614 Mdot
.66636 .56897 Mdot
.35201 .6048 Mdot
.39703 .38767 Mdot
.55227 .70512 Mdot
.53847 .12645 Mdot
.49143 .65529 Mdot
.65123 .52273 Mdot
.45157 .34585 Mdot
.63846 .66544 Mdot
.30525 .54749 Mdot
.65116 .54354 Mdot
.43606 .44512 Mdot
.58165 .62638 Mdot
.37537 .24212 Mdot
.66409 .57179 Mdot
.32791 .5453 Mdot
.83854 .53938 Mdot
.42862 .41617 Mdot
.47891 .40606 Mdot
.34201 .56189 Mdot
.21183 .44072 Mdot
.42124 .19815 Mdot
.43901 .38083 Mdot
.51339 .66406 Mdot
.515 .85718 Mdot
.39479 .42995 Mdot
.55899 .23147 Mdot
.62252 .55639 Mdot
.54 .63031 Mdot
.36586 .64376 Mdot
.4067 .46258 Mdot
.48134 .78877 Mdot
.4633 .64001 Mdot
.69401 .2698 Mdot
.61714 .51843 Mdot
.72742 .56725 Mdot
.64954 .22242 Mdot
.47544 .64381 Mdot
.37698 .50742 Mdot
.50069 .78382 Mdot
.20813 .38653 Mdot
.81956 .5659 Mdot
.71922 .52743 Mdot
.40857 .22307 Mdot
.49143 .53327 Mdot
.61854 .57086 Mdot
.5846 .42986 Mdot
.45384 .37502 Mdot
.62107 .77949 Mdot
.23229 .60614 Mdot
.2096 .57553 Mdot
.6974 .2527 Mdot
.25674 .52341 Mdot
.7589 .34318 Mdot
.81997 .41743 Mdot
.40388 .2887 Mdot
.71966 .63496 Mdot
.35734 .79651 Mdot
.53785 .17737 Mdot
.49556 .81926 Mdot
.38313 .46078 Mdot
.49939 .57202 Mdot
.67885 .76883 Mdot
.3147 .51809 Mdot
.19218 .4953 Mdot
.65866 .5409 Mdot
.29367 .54841 Mdot
.4931 .7757 Mdot
.28058 .58381 Mdot
.38281 .64162 Mdot
.84539 .53331 Mdot
.77147 .34515 Mdot
.27045 .70483 Mdot
.78297 .6636 Mdot
.32365 .32863 Mdot
.24 .73308 Mdot
.59794 .56109 Mdot
.3178 .60227 Mdot
.66843 .33668 Mdot
.678 .29697 Mdot
.42984 .75538 Mdot
.5386 .7907 Mdot
.73977 .41299 Mdot
.54488 .30338 Mdot
.32483 .56618 Mdot
.30619 .65532 Mdot
.54927 .62441 Mdot
.39448 .72756 Mdot
.53269 .19043 Mdot
.82019 .48164 Mdot
.46384 .55401 Mdot
.55514 .7751 Mdot
.65135 .68848 Mdot
.17583 .40638 Mdot
.58426 .25337 Mdot
.5578 .38714 Mdot
.40627 .62757 Mdot
.76599 .6615 Mdot
.21867 .39381 Mdot
.49843 .2496 Mdot
.67111 .28734 Mdot
.53726 .16385 Mdot
.7016 .7256 Mdot
.37668 .1772 Mdot
.27993 .55081 Mdot
.44496 .4546 Mdot
.23062 .42475 Mdot
.26137 .71347 Mdot
.67122 .40249 Mdot
.78074 .43593 Mdot
.63707 .37009 Mdot
.36972 .58208 Mdot
.38599 .2255 Mdot
.36472 .77713 Mdot
.27035 .73203 Mdot
.59378 .39695 Mdot
.53404 .43153 Mdot
.6882 .82449 Mdot
.72233 .31824 Mdot
.36891 .69774 Mdot
.67731 .21539 Mdot
.54689 .48161 Mdot
.36253 .62073 Mdot
.48385 .68878 Mdot
.64057 .20892 Mdot
.33293 .55542 Mdot
.39849 .15435 Mdot
.61827 .17259 Mdot
.34758 .29069 Mdot
.91349 .4365 Mdot
.69982 .33768 Mdot
.56201 .4785 Mdot
.44915 .69831 Mdot
.57583 .27434 Mdot
.17875 .47489 Mdot
.57605 .36399 Mdot
.64313 .67068 Mdot
.75036 .73338 Mdot
.68243 .24932 Mdot
.29765 .75543 Mdot
.57948 .82536 Mdot
.19913 .40972 Mdot
.55527 .55261 Mdot
.52343 .36467 Mdot
.58858 .51547 Mdot
.80926 .49249 Mdot
.54634 .15578 Mdot
.57355 .24304 Mdot
.82246 .68649 Mdot
.66193 .36443 Mdot
.75534 .47522 Mdot
.85739 .50498 Mdot
.5628 .31353 Mdot
.33442 .64455 Mdot
.57896 .21962 Mdot
.54627 .4147 Mdot
.62938 .45404 Mdot
.7944 .45884 Mdot
.33818 .68298 Mdot
.56737 .2007 Mdot
.79352 .60292 Mdot
.43466 .78258 Mdot
.29057 .46867 Mdot
.62789 .24265 Mdot
.2709 .56917 Mdot
.51983 .2804 Mdot
.36522 .63718 Mdot
.76622 .32811 Mdot
.48345 .62904 Mdot
.79028 .33751 Mdot
.42542 .19985 Mdot
.47991 .34748 Mdot
.40175 .34322 Mdot
.26071 .58848 Mdot
.53278 .27837 Mdot
.47246 .4746 Mdot
.3989 .76203 Mdot
.80298 .37632 Mdot
.36351 .31056 Mdot
.52414 .60997 Mdot
.59599 .6473 Mdot
.8587 .52042 Mdot
.24781 .42126 Mdot
.66048 .35642 Mdot
.50874 .21268 Mdot
.1754 .42553 Mdot
.64615 .57037 Mdot
.30583 .75782 Mdot
.5136 .72242 Mdot
.36601 .25488 Mdot
.29443 .49321 Mdot
.26993 .33898 Mdot
.80382 .37703 Mdot
.70323 .5205 Mdot
.40703 .21316 Mdot
.56174 .33258 Mdot
.43368 .82656 Mdot
.70662 .62707 Mdot
.47416 .46731 Mdot
.56223 .78266 Mdot
.6036 .40173 Mdot
.27366 .42453 Mdot
.49596 .84263 Mdot
.71734 .49245 Mdot
.5146 .42162 Mdot
.34802 .28527 Mdot
.70342 .55615 Mdot
.44034 .53131 Mdot
.25558 .27378 Mdot
.39077 .39721 Mdot
.6704 .27363 Mdot
.68412 .73802 Mdot
.5548 .26221 Mdot
.82211 .60085 Mdot
.74488 .66773 Mdot
.41543 .15939 Mdot
.67061 .21976 Mdot
.7103 .45032 Mdot
.64557 .2247 Mdot
.73695 .28324 Mdot
.40626 .16878 Mdot
.43172 .32728 Mdot
.47169 .69051 Mdot
.13323 .44723 Mdot
.66842 .57266 Mdot
.7013 .30711 Mdot
.47285 .80404 Mdot
.57277 .55361 Mdot
.25696 .56149 Mdot
.55558 .41065 Mdot
.48996 .53955 Mdot
.38012 .5749 Mdot
.47879 .47162 Mdot
.31159 .23855 Mdot
.46429 .15086 Mdot
.35476 .19928 Mdot
.73067 .72259 Mdot
.62192 .20241 Mdot
.57317 .48125 Mdot
.28348 .71828 Mdot
.50419 .32544 Mdot
.44715 .36154 Mdot
.62858 .35361 Mdot
.70079 .34017 Mdot
.32992 .29019 Mdot
.42151 .72894 Mdot
.38843 .5457 Mdot
.78752 .44796 Mdot
.38081 .87782 Mdot
.29379 .36731 Mdot
.39716 .80045 Mdot
.69738 .37351 Mdot
.53131 .26537 Mdot
.80238 .49619 Mdot
.30124 .31048 Mdot
.82977 .4225 Mdot
.38025 .56792 Mdot
.49246 .81429 Mdot
.73118 .52491 Mdot
.41306 .51541 Mdot
.70488 .43764 Mdot
.77974 .36757 Mdot
.51986 .74865 Mdot
.28007 .30933 Mdot
.42754 .69803 Mdot
.22825 .41088 Mdot
.60179 .62293 Mdot
.62818 .70252 Mdot
.4764 .83487 Mdot
.73564 .65301 Mdot
.53411 .23617 Mdot
.53314 .52076 Mdot
.27707 .65993 Mdot
.46 .6425 Mdot
.53972 .23908 Mdot
.47129 .50249 Mdot
.64452 .23623 Mdot
.47145 .09216 Mdot
.24996 .29828 Mdot
.85538 .56635 Mdot
.79239 .49679 Mdot
.5032 .44114 Mdot
.84399 .45228 Mdot
.33864 .19938 Mdot
.57472 .13702 Mdot
.60201 .73035 Mdot
.60993 .52821 Mdot
.53077 .68872 Mdot
.33972 .22701 Mdot
.77257 .46514 Mdot
.83336 .46736 Mdot
.60188 .2387 Mdot
.53614 .66157 Mdot
.15777 .55994 Mdot
.53641 .16764 Mdot
.31449 .4939 Mdot
.49808 .30266 Mdot
.50704 .41859 Mdot
.23811 .62579 Mdot
.2833 .58582 Mdot
.68992 .67836 Mdot
.51367 .26375 Mdot
.64929 .57686 Mdot
.66024 .34103 Mdot
.55293 .79008 Mdot
.42257 .36822 Mdot
.55538 .57635 Mdot
.318 .60975 Mdot
.69674 .64364 Mdot
.36701 .7306 Mdot
.53019 .14329 Mdot
.70771 .38701 Mdot
.50514 .37479 Mdot
.55658 .25776 Mdot
.70238 .43241 Mdot
.40494 .20107 Mdot
.50964 .63397 Mdot
.71668 .27441 Mdot
.47036 .57086 Mdot
.5182 .27738 Mdot
.23671 .60311 Mdot
.41294 .31699 Mdot
.40051 .42742 Mdot
.76052 .64122 Mdot
.33318 .39159 Mdot
.42448 .55447 Mdot
.52964 .39552 Mdot
.47919 .31702 Mdot
.84628 .46241 Mdot
.65261 .45833 Mdot
.63271 .69049 Mdot
.73786 .29682 Mdot
.49057 .68314 Mdot
.36237 .56735 Mdot
.59392 .4223 Mdot
.52142 .80902 Mdot
.3479 .38183 Mdot
.37363 .24304 Mdot
.5781 .52973 Mdot
.72529 .48593 Mdot
.74705 .31159 Mdot
.7144 .27897 Mdot
.22052 .62954 Mdot
.38372 .57431 Mdot
.42029 .28918 Mdot
.51119 .81596 Mdot
.31863 .53984 Mdot
.40413 .77852 Mdot
.38953 .769 Mdot
.57793 .17162 Mdot
.55054 .58963 Mdot
.75897 .72246 Mdot
.63134 .30175 Mdot
.77327 .43483 Mdot
.26216 .31001 Mdot
.46179 .8291 Mdot
.76269 .36074 Mdot
.36178 .61175 Mdot
.2544 .4947 Mdot
.38765 .46183 Mdot
.28848 .69139 Mdot
.14243 .48457 Mdot
.6187 .43322 Mdot
.35036 .50418 Mdot
.79696 .60066 Mdot
.45361 .42086 Mdot
.22444 .31956 Mdot
.52884 .79892 Mdot
.32198 .25573 Mdot
.5362 .67838 Mdot
.47608 .36918 Mdot
.43876 .46243 Mdot
.5442 .21596 Mdot
.38164 .64849 Mdot
.62988 .22753 Mdot
.53175 .84909 Mdot
.80574 .56354 Mdot
.2334 .59884 Mdot
.6892 .29937 Mdot
.82418 .48793 Mdot
.6318 .77419 Mdot
.53967 .53962 Mdot
.70361 .35814 Mdot
.57633 .31231 Mdot
.7735 .67329 Mdot
.4713 .50577 Mdot
.44326 .64408 Mdot
.43715 .76615 Mdot
.70287 .69109 Mdot
.31454 .28327 Mdot
.48625 .38425 Mdot
.47151 .1928 Mdot
.82507 .43802 Mdot
.22464 .62247 Mdot
.1684 .47947 Mdot
.25751 .28795 Mdot
.32535 .44473 Mdot
.72019 .68034 Mdot
.59938 .78325 Mdot
.44119 .84301 Mdot
.46591 .57563 Mdot
.74945 .36729 Mdot
.57038 .32341 Mdot
.74385 .30604 Mdot
.46759 .67786 Mdot
.41676 .68477 Mdot
.5993 .64732 Mdot
.64075 .22651 Mdot
.24782 .44039 Mdot
.79747 .38565 Mdot
.53084 .4984 Mdot
.42501 .1529 Mdot
.74318 .63859 Mdot
.50508 .5232 Mdot
.6115 .55452 Mdot
.69219 .5051 Mdot
.79143 .42666 Mdot
.74745 .60671 Mdot
.44711 .82246 Mdot
.66061 .51797 Mdot
.5874 .42175 Mdot
.29183 .51148 Mdot
.50779 .28759 Mdot
.75931 .64695 Mdot
.55662 .25818 Mdot
.78758 .36123 Mdot
.56046 .20934 Mdot
.46605 .19579 Mdot
.70698 .33829 Mdot
.69952 .7772 Mdot
.36766 .69306 Mdot
.65539 .44133 Mdot
.538 .79563 Mdot
.76293 .49531 Mdot
.34201 .62381 Mdot
.15525 .30739 Mdot
.63474 .80831 Mdot
.73431 .63449 Mdot
.54731 .15652 Mdot
.74447 .68018 Mdot
.68894 .6474 Mdot
.1949 .44541 Mdot
.41336 .61199 Mdot
.44609 .21943 Mdot
.43749 .39449 Mdot
.30839 .23369 Mdot
.50169 .27332 Mdot
.50937 .14005 Mdot
.83826 .47934 Mdot
.25586 .55471 Mdot
.3972 .3903 Mdot
.67659 .57142 Mdot
.46972 .59856 Mdot
.45809 .25719 Mdot
.2278 .46871 Mdot
.30676 .64155 Mdot
.58909 .62643 Mdot
.60512 .57728 Mdot
.69226 .43647 Mdot
.37327 .54178 Mdot
.77164 .45046 Mdot
.70173 .68761 Mdot
.66018 .60931 Mdot
.45274 .56143 Mdot
.53759 .2482 Mdot
.35485 .64747 Mdot
.32135 .49163 Mdot
.30553 .30532 Mdot
.54333 .72087 Mdot
.67075 .56021 Mdot
.30923 .48432 Mdot
.67375 .77569 Mdot
.79349 .58416 Mdot
.53582 .16092 Mdot
.62168 .46348 Mdot
.23021 .50189 Mdot
.54013 .23256 Mdot
.17743 .49173 Mdot
.20695 .5321 Mdot
.68822 .63696 Mdot
.25016 .63323 Mdot
.19643 .48248 Mdot
.51216 .77449 Mdot
.60259 .1783 Mdot
.4946 .81809 Mdot
.50853 .81776 Mdot
.58567 .60152 Mdot
.35606 .44219 Mdot
.27119 .53534 Mdot
.60971 .29743 Mdot
.45253 .52921 Mdot
.21504 .69665 Mdot
.52235 .36992 Mdot
.15032 .63214 Mdot
.51608 .70282 Mdot
.18272 .43459 Mdot
.58199 .31892 Mdot
.54129 .51634 Mdot
.52459 .49266 Mdot
.73772 .65788 Mdot
.40971 .65845 Mdot
.68835 .7423 Mdot
.20046 .55435 Mdot
.59756 .55449 Mdot
.54922 .8517 Mdot
.7079 .7748 Mdot
.27076 .48113 Mdot
.4243 .36033 Mdot
.66103 .79462 Mdot
.60245 .53886 Mdot
.32171 .29307 Mdot
.82686 .59364 Mdot
.77506 .57635 Mdot
.38302 .50318 Mdot
.52905 .26977 Mdot
.75084 .36602 Mdot
.70796 .25495 Mdot
.1643 .54188 Mdot
.79453 .46321 Mdot
.46854 .68104 Mdot
.53621 .50162 Mdot
.8006 .40981 Mdot
.38598 .60657 Mdot
.51075 .61785 Mdot
.33363 .64038 Mdot
.20581 .71237 Mdot
.70448 .30698 Mdot
.63544 .23355 Mdot
.33888 .63486 Mdot
.37061 .56242 Mdot
.39775 .63719 Mdot
.33567 .64505 Mdot
.76675 .59261 Mdot
.63642 .78967 Mdot
.35016 .64183 Mdot
.35741 .81662 Mdot
.41033 .31416 Mdot
.70034 .5295 Mdot
.25593 .54709 Mdot
.38532 .30302 Mdot
.5363 .6568 Mdot
.49636 .19921 Mdot
.81397 .56668 Mdot
.49258 .71142 Mdot
.76795 .63845 Mdot
.56099 .7747 Mdot
.3689 .49261 Mdot
.34367 .41258 Mdot
.79782 .55591 Mdot
.24194 .46755 Mdot
.26134 .67426 Mdot
.36482 .26681 Mdot
.63918 .52163 Mdot
.82617 .55023 Mdot
.6373 .54141 Mdot
.55482 .38699 Mdot
.41422 .57941 Mdot
.57178 .36318 Mdot
.31558 .25252 Mdot
.61383 .38063 Mdot
.28979 .58941 Mdot
.14793 .5002 Mdot
.34455 .54023 Mdot
.32637 .22625 Mdot
.27559 .33285 Mdot
.23558 .61791 Mdot
.70954 .45752 Mdot
.69876 .48358 Mdot
.27295 .76432 Mdot
.56642 .63555 Mdot
.58261 .53165 Mdot
.32006 .72192 Mdot
.30873 .60098 Mdot
.71085 .38213 Mdot
.63352 .53061 Mdot
.4415 .59244 Mdot
.53097 .749 Mdot
.38315 .34782 Mdot
.29934 .52718 Mdot
.44532 .57813 Mdot
.47417 .22302 Mdot
.60478 .1914 Mdot
.6285 .58892 Mdot
.15983 .62727 Mdot
.39676 .40785 Mdot
.28835 .46096 Mdot
.82998 .41745 Mdot
.1613 .56729 Mdot
.61621 .49721 Mdot
.71779 .77137 Mdot
.50546 .39857 Mdot
.79996 .51695 Mdot
.33016 .56153 Mdot
.49886 .81399 Mdot
.63581 .37378 Mdot
.56073 .26666 Mdot
.5205 .70347 Mdot
.27674 .31108 Mdot
.63341 .48899 Mdot
.32776 .53069 Mdot
.78361 .53951 Mdot
.39967 .29258 Mdot
.42761 .64363 Mdot
.68117 .46282 Mdot
.27343 .48472 Mdot
.34651 .40123 Mdot
.37095 .525 Mdot
.65175 .24736 Mdot
.51701 .82559 Mdot
.53972 .13897 Mdot
.27409 .59738 Mdot
.57366 .45032 Mdot
.4227 .77266 Mdot
.77748 .61137 Mdot
.30572 .69447 Mdot
.81678 .39285 Mdot
.50032 .25691 Mdot
.36015 .40528 Mdot
.52388 .24399 Mdot
.37504 .4065 Mdot
.50871 .54853 Mdot
.65917 .69395 Mdot
.20657 .57875 Mdot
.33574 .66327 Mdot
.20473 .41759 Mdot
.27555 .67546 Mdot
.63374 .23957 Mdot
.24987 .62605 Mdot
.69453 .57302 Mdot
.36187 .48282 Mdot
.47673 .71301 Mdot
.6174 .18979 Mdot
.82101 .40038 Mdot
.46118 .66809 Mdot
.7231 .41046 Mdot
.79538 .6344 Mdot
.38408 .3882 Mdot
.59237 .46715 Mdot
.42943 .44895 Mdot
.47602 .30211 Mdot
.16537 .59279 Mdot
.77221 .59724 Mdot
.52079 .40082 Mdot
.68638 .25844 Mdot
.66413 .2313 Mdot
.46373 .14135 Mdot
.386 .81023 Mdot
.31824 .59294 Mdot
.40109 .17868 Mdot
.30021 .642 Mdot
.72337 .26592 Mdot
.71129 .62878 Mdot
.85177 .42965 Mdot
.25439 .48947 Mdot
.78073 .63402 Mdot
.19131 .46309 Mdot
.41256 .63808 Mdot
.69251 .72353 Mdot
.57409 .49198 Mdot
.61608 .68487 Mdot
.72675 .70092 Mdot
.4935 .87129 Mdot
.41263 .47065 Mdot
.59921 .76982 Mdot
.476 .7593 Mdot
.82894 .54052 Mdot
.74196 .58135 Mdot
.40812 .37401 Mdot
.59835 .66034 Mdot
.30571 .27498 Mdot
.55005 .24545 Mdot
.58881 .42851 Mdot
.73961 .58515 Mdot
.40877 .2432 Mdot
.50949 .23944 Mdot
.49911 .82138 Mdot
.26596 .489 Mdot
.47461 .58723 Mdot
.50102 .38714 Mdot
.32413 .52124 Mdot
.61438 .37232 Mdot
.57021 .50611 Mdot
.41498 .42889 Mdot
.66044 .6031 Mdot
.42626 .63863 Mdot
.29077 .26212 Mdot
.34573 .6812 Mdot
.56839 .80017 Mdot
.27245 .54718 Mdot
.48249 .75134 Mdot
.3199 .7084 Mdot
.23369 .32676 Mdot
.7489 .53314 Mdot
.57391 .24331 Mdot
.72595 .31498 Mdot
.57381 .2059 Mdot
.36692 .51272 Mdot
.48404 .16261 Mdot
.48341 .64431 Mdot
.37998 .49579 Mdot
.44946 .7417 Mdot
.68879 .42889 Mdot
.52689 .40298 Mdot
.78022 .63328 Mdot
.5853 .51824 Mdot
.67708 .3013 Mdot
.7011 .72936 Mdot
.42256 .29598 Mdot
.27887 .50894 Mdot
.70608 .26902 Mdot
.67052 .59017 Mdot
.55076 .81897 Mdot
.43388 .67367 Mdot
.73319 .55784 Mdot
.59916 .20172 Mdot
.5588 .15728 Mdot
.4985 .51255 Mdot
.56783 .30027 Mdot
.48129 .41234 Mdot
.48229 .83202 Mdot
.7716 .60875 Mdot
.53826 .44017 Mdot
.59901 .72186 Mdot
.36105 .55992 Mdot
.63408 .72045 Mdot
.49388 .57648 Mdot
.4356 .22967 Mdot
.29967 .60484 Mdot
.23041 .61823 Mdot
.60014 .40624 Mdot
.56009 .46271 Mdot
.50581 .45823 Mdot
.57377 .2888 Mdot
.29967 .76319 Mdot
.532 .41811 Mdot
.80134 .4705 Mdot
.29013 .48832 Mdot
.49603 .80291 Mdot
.79459 .55248 Mdot
.66921 .64209 Mdot
.40903 .65346 Mdot
.35581 .46666 Mdot
.54003 .73071 Mdot
.47297 .44385 Mdot
.69641 .5554 Mdot
.31398 .53615 Mdot
.8303 .5608 Mdot
.32945 .42929 Mdot
.59943 .29602 Mdot
.5674 .60897 Mdot
.55397 .38018 Mdot
.46166 .71369 Mdot
.84503 .42437 Mdot
.40765 .64133 Mdot
.50999 .25954 Mdot
.55076 .58878 Mdot
.58385 .3149 Mdot
.25995 .35356 Mdot
.61088 .16797 Mdot
.19055 .45693 Mdot
.46001 .54551 Mdot
.18186 .44762 Mdot
.72935 .65922 Mdot
.81773 .61129 Mdot
.50524 .24808 Mdot
.54548 .47047 Mdot
.67283 .3819 Mdot
.3656 .7495 Mdot
.5664 .61318 Mdot
.605 .44013 Mdot
.44469 .59567 Mdot
.56584 .73351 Mdot
.55074 .67109 Mdot
.53 .44767 Mdot
.711 .3327 Mdot
.71725 .29548 Mdot
.48216 .80364 Mdot
.45737 .6487 Mdot
.72202 .5767 Mdot
.43732 .23669 Mdot
.86565 .44615 Mdot
.14879 .44711 Mdot
.47962 .41459 Mdot
.45939 .69827 Mdot
.55386 .29464 Mdot
.66958 .53854 Mdot
.33062 .65428 Mdot
.32807 .70661 Mdot
.49309 .7031 Mdot
.59652 .42755 Mdot
.65866 .27947 Mdot
.71295 .67388 Mdot
.51368 .2972 Mdot
.5816 .63482 Mdot
.27638 .27096 Mdot
.70745 .75294 Mdot
.77804 .60503 Mdot
.84952 .38336 Mdot
.4371 .6563 Mdot
.4533 .31776 Mdot
.25504 .39292 Mdot
.60881 .1974 Mdot
.5674 .25726 Mdot
.35092 .26562 Mdot
.63648 .64758 Mdot
.49929 .25122 Mdot
.31164 .62828 Mdot
.69852 .31664 Mdot
.62696 .72232 Mdot
.50965 .53641 Mdot
.70283 .4884 Mdot
.50387 .1529 Mdot
.26202 .52644 Mdot
.74102 .32804 Mdot
.28159 .29133 Mdot
.41956 .84249 Mdot
.63068 .19841 Mdot
.66402 .31056 Mdot
.74951 .55882 Mdot
.23358 .42287 Mdot
.46005 .50578 Mdot
.3647 .61364 Mdot
.32571 .29034 Mdot
.35123 .35777 Mdot
.7396 .44 Mdot
.21754 .38141 Mdot
.53482 .2362 Mdot
.36977 .31063 Mdot
.54215 .47393 Mdot
.32203 .48575 Mdot
.71981 .41347 Mdot
.36305 .62523 Mdot
.43918 .51429 Mdot
.60579 .27516 Mdot
.29992 .48455 Mdot
.44188 .77933 Mdot
.7411 .67585 Mdot
.39691 .84586 Mdot
.78199 .49889 Mdot
.22416 .34193 Mdot
.44269 .35887 Mdot
.48493 .12174 Mdot
.70667 .70156 Mdot
.72873 .61489 Mdot
.65804 .77048 Mdot
.7078 .56698 Mdot
.42172 .31973 Mdot
.47365 .44342 Mdot
.78761 .42653 Mdot
.34944 .50307 Mdot
.32515 .32035 Mdot
.26244 .3194 Mdot
.5449 .26613 Mdot
.60203 .24189 Mdot
.61892 .30005 Mdot
.36743 .44806 Mdot
.34718 .54458 Mdot
.36384 .19399 Mdot
.47347 .52809 Mdot
.54159 .42498 Mdot
.44166 .49068 Mdot
.22603 .41441 Mdot
.76578 .72623 Mdot
.26097 .58337 Mdot
.59552 .22187 Mdot
.25476 .51626 Mdot
.39488 .51606 Mdot
.29589 .68084 Mdot
.84934 .32693 Mdot
.53378 .10976 Mdot
.31463 .53297 Mdot
.37955 .79245 Mdot
.25575 .52042 Mdot
.63884 .22976 Mdot
.73441 .52345 Mdot
.56881 .74363 Mdot
.49385 .48143 Mdot
.41213 .53568 Mdot
.50149 .4583 Mdot
.66907 .75228 Mdot
.62795 .18558 Mdot
.2416 .34133 Mdot
.68898 .26082 Mdot
.37639 .38117 Mdot
.51835 .44155 Mdot
.88131 .44224 Mdot
.79606 .39853 Mdot
.39595 .37672 Mdot
.18808 .49498 Mdot
.52456 .36871 Mdot
.45168 .37862 Mdot
.75126 .40226 Mdot
.54984 .85055 Mdot
.53589 .23255 Mdot
.64073 .22688 Mdot
.28766 .5943 Mdot
.68356 .52074 Mdot
.51622 .70359 Mdot
.50623 .50609 Mdot
.41254 .34761 Mdot
.48839 .69231 Mdot
.45887 .27893 Mdot
.79542 .61673 Mdot
.51281 .59987 Mdot
.54724 .8375 Mdot
.80636 .34955 Mdot
.33077 .45116 Mdot
.36216 .74327 Mdot
.39345 .43468 Mdot
.37912 .30776 Mdot
.43942 .25121 Mdot
.48173 .30953 Mdot
.75923 .67235 Mdot
.24778 .22652 Mdot
.59579 .68539 Mdot
.46905 .21028 Mdot
.37421 .56351 Mdot
.45543 .59695 Mdot
.31822 .5021 Mdot
.71444 .59302 Mdot
.61519 .58069 Mdot
.37228 .39619 Mdot
.28694 .60203 Mdot
.52722 .71037 Mdot
.13859 .58903 Mdot
.43516 .3539 Mdot
.31425 .66815 Mdot
.72648 .27138 Mdot
.36424 .26675 Mdot
.26849 .45132 Mdot
.4853 .44326 Mdot
.39706 .73434 Mdot
.54812 .46785 Mdot
.81747 .52096 Mdot
.47472 .19569 Mdot
.70095 .28552 Mdot
.33073 .42311 Mdot
.27251 .511 Mdot
.49711 .37844 Mdot
.6622 .41569 Mdot
.53571 .62791 Mdot
.77116 .4192 Mdot
.47322 .33375 Mdot
.68893 .23195 Mdot
.6605 .49134 Mdot
.58124 .50212 Mdot
.27499 .60679 Mdot
.45119 .14796 Mdot
.23292 .38405 Mdot
.30501 .51616 Mdot
.2438 .31263 Mdot
.66982 .45685 Mdot
.5109 .28977 Mdot
.67565 .57838 Mdot
.44263 .32816 Mdot
.27165 .57918 Mdot
.2354 .30199 Mdot
.74481 .38501 Mdot
.61608 .67485 Mdot
.62458 .70262 Mdot
.42933 .80571 Mdot
.42827 .65713 Mdot
.83285 .35893 Mdot
.67728 .47109 Mdot
.24952 .2923 Mdot
.52512 .82423 Mdot
.2673 .56988 Mdot
.74798 .65821 Mdot
.51827 .36696 Mdot
.64336 .58692 Mdot
.68768 .26688 Mdot
.54425 .37907 Mdot
.38857 .22654 Mdot
.48816 .45108 Mdot
.34842 .23909 Mdot
.67588 .41337 Mdot
.72185 .39412 Mdot
.73052 .64389 Mdot
.22785 .40615 Mdot
.84976 .50929 Mdot
.36879 .75299 Mdot
.85322 .46544 Mdot
.84512 .52833 Mdot
.71205 .26864 Mdot
.35094 .25462 Mdot
.17539 .57228 Mdot
.73391 .61907 Mdot
.79455 .56489 Mdot
.67943 .69061 Mdot
.21691 .43602 Mdot
.6997 .51275 Mdot
.26192 .59768 Mdot
.38189 .65147 Mdot
.46546 .69225 Mdot
.08601 .46708 Mdot
.62706 .26174 Mdot
.26597 .58402 Mdot
.68275 .4892 Mdot
.68011 .23894 Mdot
.23404 .41193 Mdot
.71964 .71121 Mdot
.49821 .57115 Mdot
.4674 .46954 Mdot
.34198 .39755 Mdot
.46302 .81046 Mdot
.66375 .48577 Mdot
.31111 .80626 Mdot
.68679 .76489 Mdot
.59549 .70879 Mdot
.49585 .55448 Mdot
.29221 .54842 Mdot
.27918 .69239 Mdot
.70456 .47697 Mdot
.7513 .68606 Mdot
.78678 .62767 Mdot
.79987 .40698 Mdot
.27224 .76237 Mdot
.50117 .80889 Mdot
.60606 .19388 Mdot
.75457 .63295 Mdot
.33754 .52909 Mdot
.66004 .31818 Mdot
.61209 .53346 Mdot
.64098 .67514 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Eooooo`;o0000/_oo
ool001cooooo00?o0000ooooooooool0UOooool2o`000;;ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Z
ooooo`;o0000WOooool001cooooo00?o0000ooooooooool0Z_ooool2o`0009gooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`2Jooooo`;o0000[Oooool001cooooo00?o0000ooooooooool0V_ooool2
o`000:gooooo000Looooo`03o`000?oooooooooo06oooooo0_l0000jooooo`;o0000W?ooool001co
oooo00?o0000ooooooooool0Koooool2o`0003[ooooo0_l0002Looooo`007?ooool00ol0003ooooo
ooooo`2dooooo`;o0000Toooool001cooooo00?o0000ooooooooool0W_ooool2o`0001Cooooo0_l0
00000ooooooo0000o`00002@ooooo`007?ooool00ol0003oooooooooo`2Cooooo`;o00002Oooool2
o`0000;ooooo1?l00006ooooo`;o00002Oooool2o`00093ooooo000Looooo`03o`000?oooooooooo
09?ooooo0_l00008ooooo`;o00000oooool4o`0000;ooooo0_l00002ooooo`;o0000Voooool001co
oooo00?o0000ooooooooool0WOooool2o`0000Wooooo1?l0002Mooooo`007?ooool00ol0003ooooo
ooooo`2;ooooo`;o00000_ooool2o`0001?ooooo0_l00004ooooo`;o00000_ooool2o`0009Wooooo
000Looooo`;o0000Qoooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`0000_ooooo0_l0
0002ooooo`;o00002?ooool2o`0009Wooooo000Looooo`03o`000?oooooooooo07kooooo0_l00006
ooooo`;o00002oooool2o`0000_ooooo0_l0000<ooooo`;o0000VOooool001cooooo00?o0000oooo
ooooool0O_ooool2o`0000?ooooo0_l0000Oooooo`;o00002?ooool2o`0000;ooooo0_l000000ooo
oooo0000o`00000;ooooo`;o0000QOooool001cooooo00?o0000ooooooooool0Poooool2o`0001Co
oooo0_l00002ooooo`;o00001Oooool2o`0000Cooooo0_l00006ooooo`;o000000?oooooo`000?l0
00002oooool2o`0008Gooooo000Looooo`03o`000?oooooooooo07gooooo0_l0000>ooooo`;o0000
2_ooool2o`0000;ooooo0_l00005ooooo`;o00001?ooool3o`0001Oooooo0_l00023ooooo`007?oo
ool00ol0003oooooooooo`1mooooo`;o000000?oooooo`000?l000002oooool2o`0001Wooooo1Ol0
00000ooooooo0000o`00000Cooooo`?o0000Poooool001cooooo00?o0000ooooooooool0P?ooool2
o`0002Kooooo1?l00002ooooo`;o00002?ooool2o`000003ooooool0003o000000Kooooo0_l00024
ooooo`007?ooool00ol0003oooooooooo`2Fooooo`;o00004_ooool3o`0000[ooooo0ol000000ooo
oooo0000o`000008ooooo`?o0000POooool001cooooo00?o0000ooooooooool0Moooool2o`0001Co
oooo0_l00007ooooo`;o00003Oooool2o`0000?ooooo0ol0000:ooooo`;o00001oooool4o`000003
ooooool0003o000000?o0000Ooooool001cooooo00?o0000ooooooooool0LOooool2o`0000Cooooo
0_l00006ooooo`;o00003?ooool2o`0001;ooooo0_l00002ooooo`Co00000_ooool2o`0001?ooooo
1?l00004ooooo`;o0000Ooooool001cooooo00?o0000ooooooooool0LOooool2o`0000cooooo0_l0
000Pooooo`;o000000Coooooo`000?l0003ooooo0_l00005ooooo`;o00001Oooool2o`0000Wooooo
0_l00027ooooo`007?ooool00ol0003oooooooooo`26ooooo`;o00007?ooool2o`0000Sooooo0_l0
0005ooooo`;o00004Oooool2o`000003ooooool0003o000007cooooo000Looooo`03o`000?oooooo
oooo06Kooooo0_l0000Nooooo`;o00002_ooool2o`000003ooooool0003o000000Gooooo0_l0000;
ooooo`;o00000oooool2o`0000Gooooo0_l0000>ooooo`;o000000Coooooo`000?l0003ooooo0ol0
001kooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Kooooo
00?o0000ooooooooool0I_ooool2o`0002Sooooo1?l000000ooooooo0000o`000005ooooo`?o0000
0oooool3o`0000Cooooo0_l00003ooooo`;o00001Oooool2o`0000[ooooo0_l00002ooooo`;o0000
1Oooool2o`0007_ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1booooo`;o00007?ooool8o`00
00Cooooo1Ol000001?oooooo0000o`000?l00009ooooo`;o00004Oooool2o`0000Kooooo0_l0001n
ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^
00Oooooo00?o0000ooooooooool0J_ooool2o`0000Cooooo1?l0000?ooooo`Oo00002_ooool4o`00
00Cooooo1Ol0000=ooooo`Go00002_ooool2o`0000?ooooo0_l00005ooooo`;o0000O_ooool00003
ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06ooooo`?o
0000J_ooool2o`0000Cooooo0_l00006ooooo`;o000000?oooooo`000?l000000oooool2o`000003
ooooool0003o000000Go000000Coooooo`000?l0003o00001oooool2o`0000Kooooo0_l0000?oooo
o`Go00000_ooool2o`0000Kooooo1?l000000ooooooo0000o`000002ooooo`;o000000?oooooo`00
0?l00000O_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00omgMgOo
IVIVooooo`05ooooo`03o`000?oooooooooo07Sooooo0_l000000ooooooo0000o`000003ooooo`;o
00002Oooool5o`0000;ooooo0_l0000>ooooo`;o00000_ooool2o`0000gooooo1Ol00005ooooo`;o
00000_ooool2o`000003ooooool0003o0000087ooooo00000ooooooo410@ooooo`02ooooo`03oa0@
4?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1hooooo`;o0000
00?oooooo`000?l000004Oooool2o`0000;ooooo0_l00004ooooo`;o00002?ooool2o`0000;ooooo
0_l00009ooooo`;o00001?ooool3o`0000Sooooo0ol00004ooooo`;o000000?oooooo`000?l00000
Noooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So410@
00Kooooo00?o0000ooooooooool0N?ooool2o`000003ooooool0003o000000Sooooo0_l0000<oooo
o`Co000000?oooooo`000?l000005oooool5o`000003ooooool0003o000000Wooooo0_l00005oooo
o`;o000000?oooooo`000?l00000Noooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0N?ooool2o`0000;ooooo0_l0
0002ooooo`;o00000oooool2o`0000cooooo1?l0000:ooooo`;o00003oooool4o`000003ooooool0
003o000000;ooooo0_l00007ooooo`;o00001_ooool2o`0000[ooooo0_l0001_ooooo`007?ooool0
0ol0003oooooooooo`1looooo`;o00000_ooool2o`0000Oooooo0_l00009ooooo`;o00002oooool2
o`0000[ooooo0_l00008ooooo`;o00000_ooool2o`0000Oooooo0_l0000Booooo`;o0000Koooool0
01cooooo00?o0000ooooooooool0ROooool3o`000003ooooool0003o000000Gooooo0_l0000Doooo
o`Go00000oooool2o`0000Cooooo1?l00009ooooo`;o00003oooool2o`00077ooooo000Looooo`03
o`000?oooooooooo087ooooo0ol00006ooooo`;o000000?oooooo`000?l000001oooool2o`0001;o
oooo0ol00005ooooo`;o00000oooool6o`000003ooooool0003o000000;ooooo0_l000000ooooooo
0000o`000008ooooo`Co00000oooool2o`00077ooooo000Looooo`03o`000?oooooooooo04gooooo
0_l0000Gooooo`;o00000oooool2o`0000gooooo0_l00005ooooo`?o00004_ooool2o`0000?ooooo
0_l000000ooooooo0000o`00000:ooooo`;o00001_ooool2o`0000?ooooo0ol000001?oooooo0000
o`000?ooool2o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l000001Ol0001fooooo`00
7?ooool00ol0003oooooooooo`1=ooooo`;o00005oooool2o`0000?ooooo0_l00003ooooo`;o0000
00?oooooo`000?l000001Oooool2o`0000Gooooo0_l00007ooooo`;o000000?oooooo`000?l00000
1Oooool2o`0000Cooooo0ol000000ooooooo0000o`000004ooooo`;o00001?ooool2o`0000Gooooo
1?l00003ooooo`;o00002Oooool2o`0000?ooooo0ol000000ooooooo0000o`000002o`0000kooooo
0_l0001Yooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o00003_ooool2o`000003ooooool0
003o000000Cooooo1_l0000;ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Cooooo0ol0
00000ooooooo0000o`000004ooooo`;o00001?ooool4o`0000?ooooo1?l0000;ooooo`;o000000?o
ooooo`000?l000000oooool2o`000004ooooool0003o0000o`0000Kooooo0_l00006ooooo`Co0000
JOooool001cooooo00?o0000ooooooooool0H?ooool2o`0001Oooooo1_l0000;ooooo`;o000000?o
ooooo`000?l000001oooool2o`0000?ooooo0_l00007ooooo`;o00001?ooool4o`0000Cooooo0ol0
0003ooooo`;o00000_ooool2o`0000;ooooo0_l00009ooooo`;o000000?oooooo`000?l000001?oo
ool2o`0000Kooooo0_l0001[ooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o00002oooool2
o`0000[ooooo0_l0000;ooooo`;o00003_ooool2o`000003ooooool0003o000000Kooooo0ol0000:
ooooo`Co00001?ooool4o`0000Gooooo0_l00003ooooo`;o00000_ooool2o`000004ooooool0003o
0000o`0000Sooooo0_l00002ooooo`;o00002Oooool2o`0006kooooo000Looooo`03o`000?oooooo
oooo05Cooooo0_l0000;ooooo`;o00002_ooool2o`0000Oooooo0_l0000Booooo`Go00001_ooool3
o`0000Oooooo0_l000001?oooooo0000o`000?ooool2o`0000Gooooo1?l00007ooooo`;o00001_oo
ool3o`0000Kooooo1?l0000=ooooo`;o0000K_ooool001cooooo00?o0000ooooooooool0L?ooool2
o`0000Cooooo0_l00007ooooo`Co00001oooool3o`00017ooooo0ol00004ooooo`Co00001Oooool3
o`0000Cooooo1?l00007ooooo`;o00001_ooool2o`0001;ooooo0_l0001[ooooo`007?ooool00ol0
003oooooooooo`1`ooooo`;o00003Oooool4o`0001_ooooo1?l000001?oooooo0000o`000?ooool3
o`0000;ooooo0_l00002ooooo`Co00000_ooool4o`0000;ooooo1?l0000?ooooo`Co00002?ooool4
o`0006_ooooo000Looooo`;o0000G?ooool2o`0000_ooooo0_l00005ooooo`;o000000?oooooo`00
0?l000002oooool2o`0000[ooooo0_l00008ooooo`?o000000?oooooo`000?l000000oooool4o`00
0003ooooool0003o000000Kooooo0_l00004ooooo`;o00002?ooool4o`0000gooooo1_l00008oooo
o`;o00000_ooool2o`0006Wooooo000Looooo`03o`000?oooooooooo05_ooooo0_l00006ooooo`;o
00000oooool2o`0000Cooooo0ol000001?oooooo0000o`000?l0000:ooooo`;o00002_ooool2o`00
00Sooooo1_l00003ooooo`;o00006_ooool2o`000003ooooool0003o000000Sooooo0_l00003oooo
o`;o00000oooool2o`0000_ooooo0ol000000ooooooo0000o`00001Uooooo`007?ooool00ol0003o
ooooooooo`1Sooooo`Co00001Oooool4o`0000?ooooo0_l0000<ooooo`;o00003_ooool2o`0000Co
oooo0_l00003ooooo`;o000000?oooooo`000?l000004?ooool2o`0000;ooooo0_l00003ooooo`;o
000000?oooooo`000?l000000_l00006ooooo`;o00002?ooool2o`0000Sooooo0_l00002ooooo`;o
000000?oooooo`000?l00000IOooool001cooooo00?o0000ooooooooool0H?ooool2o`0000?ooooo
0_l00004ooooo`?o00004oooool2o`0000kooooo1?l00007ooooo`;o000000?oooooo`000?l00000
0ol00004ooooo`;o00001oooool2o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`;o0000
0oooool2o`0001Gooooo0ol0001[ooooo`007?ooool00ol0003oooooooooo`1Kooooo`;o00000ooo
ool2o`0000Wooooo0_l00009ooooo`;o00006Oooool4o`0000Sooooo0_l00002ooooo`Co00000ooo
ool3o`0000Gooooo0ol00005ooooo`;o00002_ooool2o`0000;ooooo0_l00004ooooo`;o00003?oo
ool2o`0006_ooooo000Looooo`03o`000?oooooooooo05_ooooo0_l00009ooooo`;o00001_ooool2
o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`;o00003Oooool2o`0000Cooooo0_l0000:
ooooo`;o00001?ooool5o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000002
o`00013ooooo0_l00002ooooo`;o00001?ooool3o`0000_ooooo0_l00009ooooo`;o0000H?ooool0
01cooooo00?o0000ooooooooool0G_ooool4o`0000Cooooo0_l00006ooooo`;o00000oooool2o`00
0004ooooool0003o0000ooooo`;o000000?oooooo`000?l000000oooool2o`0000Sooooo0_l00003
ooooo`;o000000Coooooo`000?l0003o00003_ooool7o`0000;ooooo0_l00003ooooo`;o00000_oo
ool2o`0000Sooooo0_l0000=ooooo`;o00002oooool4o`0000;ooooo0ol00002ooooo`;o0000H?oo
ool001cooooo00?o0000ooooooooool0Coooool2o`0000?ooooo1?l00006ooooo`Co00002?ooool2
o`0000;ooooo0_l000000ooooooo0000o`000006ooooo`;o00001_ooool2o`0000gooooo0_l00000
1?oooooo0000o`000?l00005ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`?o00001ooo
ool2o`0000;ooooo0_l00007ooooo`?o00000_ooool2o`0000Wooooo0_l00005ooooo`;o00001_oo
ool2o`0000;ooooo0ol00003ooooo`;o0000Goooool001cooooo00?o0000ooooooooool0Coooool2
o`0000?ooooo1?l00005ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l00002
ooooo`;o000000?oooooo`000?l000002_ooool2o`0001?ooooo0_l00007ooooo`;o00000_ooool2
o`0000Sooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00006ooooo`Co000000?ooooo
o`000?l000002Oooool2o`0000Gooooo0_l000000ooooooo0000o`00000:ooooo`;o000000?ooooo
o`000?l00000Goooool001cooooo00?o0000ooooooooool0GOooool2o`000003ooooool0003o0000
00;ooooo0_l0000Gooooo`;o00003oooool2o`000004ooooool0003o0000o`0000[ooooo0_l00002
ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l00007ooooo`;o00001oooool3
o`0000oooooo0_l00005ooooo`;o00002Oooool3o`0006;ooooo000Looooo`03o`000?oooooooooo
06_ooooo0_l0000<ooooo`;o00004oooool2o`000003ooooool0003o000000_ooooo0ol000000ooo
oooo0000o`000003o`0000;ooooo0_l00009ooooo`;o00002_ooool2o`0000Gooooo0_l00009oooo
o`;o00004?ooool2o`0006?ooooo000Looooo`03o`000?oooooooooo05Sooooo0_l00003ooooo`;o
00000oooool2o`000003ooooool0003o000000Cooooo1?l0000:ooooo`;o00005_ooool2o`0000co
oooo0_l00002ooooo`Co00003Oooool2o`00017ooooo0_l00002ooooo`?o000000?oooooo`000?l0
00002?ooool2o`0000Gooooo0_l00007ooooo`;o000000Coooooo`000?l0003ooooo0_l0001Hoooo
o`007?ooool00ol0003oooooooooo`1@ooooo`;o00001_ooool2o`0000?ooooo0_l00003ooooo`;o
000000Coooooo`000?l0003ooooo0_l00003ooooo`Co00003_ooool2o`0000Cooooo0_l0000Hoooo
o`Co00005?ooool2o`0001;ooooo0ol000000ooooooo0000o`000005ooooo`;o000000?oooooo`00
0?l000001?ooool3o`0000Oooooo0_l000001?oooooo0000o`000?ooool2o`0005Sooooo000Loooo
o`03o`000?oooooooooo04gooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool2o`00
00Sooooo0_l00002ooooo`Co00000oooool4o`0000kooooo0_l00004ooooo`;o00006_ooool3o`00
00Kooooo0_l00009ooooo`Co00003Oooool2o`0000kooooo0_l00007ooooo`;o00000_ooool2o`00
06Cooooo000Looooo`03o`000?oooooooooo04?ooooo0_l00008ooooo`;o00001Oooool2o`0000;o
oooo0ol00007ooooo`;o000000?oooooo`000?l000000_l000001?oooooo0000o`000?ooool2o`00
00oooooo0_l0000;ooooo`;o00002_ooool2o`0000Wooooo0_l00006ooooo`;o00001?ooool2o`00
00?ooooo0_l00004ooooo`;o00000_ooool2o`0000Gooooo0_l00006ooooo`;o00004oooool4o`00
06;ooooo000Looooo`03o`000?oooooooooo04;ooooo0ol00008ooooo`;o00000_ooool2o`000003
ooooool0003o000000?ooooo0_l00006ooooo`;o00000_ooool3o`0000;ooooo0_l0000=ooooo`;o
00000oooool2o`0000Kooooo0_l00003ooooo`;o000000?oooooo`000?l000001oooool2o`0000[o
oooo0_l0000;ooooo`;o00002Oooool2o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`;o
00000oooool2o`000003ooooool0003o000000Gooooo0_l00004ooooo`;o00001Oooool2o`0000Go
oooo1?l0001Iooooo`007?ooool2o`0004?ooooo0_l00009ooooo`;o00000_ooool2o`0000kooooo
0_l00003ooooo`;o00002?ooool2o`0000Oooooo0_l0000;ooooo`;o00000oooool2o`000003oooo
ool0003o000001?ooooo0_l0000@ooooo`;o00001oooool3o`000004ooooool0003o0000ooooo`;o
00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000005ooooo`;o00000_ooool4o`0000co
oooo1?l0001Iooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00007Oooool4o`0000Cooooo
0_l00007ooooo`;o00007?ooool2o`0000Gooooo0_l0000=ooooo`;o00001_ooool2o`0000Oooooo
0_l00005ooooo`;o00000_ooool2o`000003ooooool0003o000000;o00001oooool3o`0000;ooooo
0_l0001[ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00006?ooool2o`0001Gooooo0_l0
0006ooooo`Co000000?oooooo`000?l000002?ooool4o`0000Cooooo0_l0000Fooooo`;o00000ooo
ool5o`0000Oooooo0_l00003ooooo`;o00002oooool2o`0000;ooooo0_l00009ooooo`Go00002Ooo
ool2o`0000Oooooo0ol0000;ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0;oooool2
o`00023ooooo0ol00003ooooo`;o00001Oooool4o`0000_ooooo0_l00003ooooo`Co000000?ooooo
o`000?l000001_ooool3o`00017ooooo0_l00004ooooo`;o000000?oooooo`000?l000000ol00007
ooooo`;o00000oooool2o`0000_ooooo0_l00002ooooo`;o000000?oooooo`000?l000001oooool2
o`0000Sooooo1?l00008ooooo`?o000000?oooooo`000?l000002?ooool2o`0005Wooooo000Loooo
o`03o`000?oooooooooo04_ooooo0_l00004ooooo`?o00000_ooool3o`0000Gooooo0_l000000ooo
oooo0000o`00000>ooooo`Go00002_ooool2o`00013ooooo0ol00004ooooo`;o00000oooool4o`00
00_ooooo0_l00004ooooo`;o00000_ooool2o`000003ooooool0003o000000?ooooo1_l00007oooo
o`;o00000oooool2o`000003ooooool0003o000000;o00003?ooool2o`0000Wooooo0_l0001Hoooo
o`007?ooool00ol0003oooooooooo`1;ooooo`?o00002?ooool2o`0000Kooooo0_l000000ooooooo
0000o`000002ooooo`;o00001oooool2o`000003ooooool0003o000000kooooo0ol0000>ooooo`Go
000000?oooooo`000?l000001_ooool2o`00017ooooo0_l00002ooooo`;o000000?oooooo`000?l0
00000oooool2o`0000;ooooo0_l00007ooooo`;o00000oooool2o`0000Oooooo0_l00003ooooo`;o
00001oooool2o`0000Gooooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`15ooooo`;o0000
1?ooool3o`0000Cooooo0_l00009ooooo`?o00001Oooool2o`000003ooooool0003o000000Cooooo
1Ol0000>ooooo`?o000000?oooooo`000?l000002?ooool2o`0000?ooooo0ol000000ooooooo0000
o`000004ooooo`;o00000_ooool2o`0000?ooooo0_l00009ooooo`;o000000?oooooo`000?l00000
0_ooool3o`0000Oooooo0_l0000>ooooo`;o00001Oooool2o`0000?ooooo0_l00006ooooo`?o0000
Goooool001cooooo00?o0000ooooooooool0AOooool2o`0000Cooooo0_l00005ooooo`;o00002Ooo
ool2o`0000Oooooo1?l00005ooooo`Co00002Oooool3o`0000Kooooo0_l00008ooooo`Co00001?oo
ool2o`0000Gooooo0_l000001?oooooo0000o`000?l00003ooooo`;o00001oooool4o`000003oooo
ool0003o000000;ooooo0_l00009ooooo`;o00003Oooool2o`0000Gooooo0_l00004ooooo`Co0000
0oooool2o`0000Cooooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o00006Ooo
ool2o`0001Cooooo0ol00006ooooo`Go000000?oooooo`000?l000001?ooool2o`000004ooooool0
003o0000ooooo`;o00001oooool3o`000003ooooool0003o000000[ooooo1?l00002ooooo`;o0000
1_ooool4o`000004ooooool0003o0000o`0000;ooooo0_l0000Fooooo`Co00002Oooool2o`0005[o
oooo000Looooo`03o`000?oooooooooo04Sooooo0_l00004ooooo`;o00001?ooool2o`0000Wooooo
0_l00004ooooo`;o00004_ooool2o`0000;ooooo0_l00007ooooo`So00000oooool2o`000003oooo
ool0003o000000[ooooo0_l000001?oooooo0000o`000?l0000@ooooo`;o00001_ooool4o`000003
ooooool0003o000000?ooooo0_l0000Cooooo`;o00003_ooool2o`0000Kooooo0_l0000Iooooo`;o
0000=oooool001cooooo00?o0000ooooooooool0B?ooool2o`0000Cooooo0_l00004ooooo`;o0000
1oooool5o`0000?ooooo0_l0000Booooo`;o00001oooool4o`0000;ooooo2?l000001?oooooo0000
o`000?ooool2o`0000?ooooo1?l000000ooooooo0000o`000002o`000003ooooool0003o000002Ko
oooo0_l00004ooooo`;o00001_ooool2o`000004ooooool0003o0000o`0000kooooo0_l00004oooo
o`Co00006Oooool2o`0003Oooooo000Looooo`03o`000?oooooooooo047ooooo0_l0000Aooooo`Co
00001Oooool5o`0001kooooo1_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l0
00000_l00002ooooo`Co000000?oooooo`000?l000000_l000000ooooooo0000o`00000Cooooo`;o
00005_ooool2o`0000Cooooo0_l00006ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Co
oooo0_l00007ooooo`?o0000E?ooool001cooooo00?o0000ooooooooool0=oooool2o`0000Sooooo
0_l0000Aooooo`Co00001_ooool2o`00023ooooo0_l00003ooooo`Ko000000Coooooo`000?l0003o
oooo0ol00004ooooo`?o00001?ooool2o`0001Cooooo0_l0000Iooooo`;o00001Oooool2o`0000Wo
oooo1Ol00004ooooo`;o00001oooool4o`0000Oooooo0_l0001:ooooo`007?ooool00ol0003ooooo
ooooo`0gooooo`;o00002?ooool2o`0000Sooooo0_l00007ooooo`;o00002?ooool2o`0002Gooooo
0_l000001Ooooooo0000o`000?l0003ooooo00Oo000000?oooooo`000?l000001_l000000ooooooo
0000o`000002ooooo`;o0000:oooool2o`0000?ooooo1?l00009ooooo`Co00003_ooool4o`0000Oo
oooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`11ooooo`;o00000_ooool2o`0000Cooooo
0_l00007ooooo`;o0000:Oooool4o`0000;ooooo1Ol00002ooooo`Oo000000?oooooo`000?l00000
0oooool6o`0000;ooooo0_l00009ooooo`;o00009Oooool2o`0000_ooooo0_l000000ooooooo0000
o`00000>ooooo`Co0000D_ooool001cooooo00?o0000ooooooooool0@Oooool2o`0000;ooooo0_l0
000Aooooo`;o00007oooool2o`0000Cooooo1Ol00003ooooo`;o00001?ooool:o`000003ooooool0
003o000000Go00003Oooool2o`0002Gooooo0_l00009ooooo`;o00000oooool2o`0000cooooo2?l0
001@ooooo`007?ooool2o`0004Oooooo0_l0000@ooooo`;o00007_ooool3o`000005ooooool0003o
0000o`000?ooool01Ol00004ooooo`;o000000?oooooo`000?l000000ol000000ooooooo0000o`00
0003o`000003ooooool0003o000000?o00000oooool2o`0000Gooooo0_l0000Zooooo`;o00002?oo
ool3o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00001_ooool2o`000004ooooool0
003o0000ooooo`;o00002Oooool2o`0004Gooooo000Looooo`03o`000?oooooooooo04Kooooo0_l0
0009ooooo`;o00009Oooool3o`000003ooooool0003o000000Wo00000_ooool8o`000003ooooool0
003o000000?o00000_ooool4o`0000?ooooo0ol00004ooooo`;o00001_ooool2o`0001Oooooo0_l0
0009ooooo`;o00002?ooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool3o`0000;ooooo
0_l00005ooooo`Co00002_ooool2o`0004Gooooo000Looooo`03o`000?oooooooooo037ooooo0_l0
000Nooooo`;o00009Oooool3o`0000;ooooo1?l00002ooooo`co000000?oooooo`000?l000001_l0
0003ooooo`;o00001?ooool3o`0000_ooooo0_l0000Gooooo`;o00002Oooool2o`0001?ooooo0_l0
0003ooooo`;o00001Oooool4o`0000?ooooo0ol0001;ooooo`007?ooool00ol0003oooooooooo`0a
ooooo`;o00004Oooool4o`0002Kooooo0_l00008ooooo`;o00000oooool4o`0000?ooooo1_l00000
0ooooooo0000o`00000;o`000004ooooool0003o0000ooooo`?o00000oooool2o`0000Kooooo0_l0
000Gooooo`;o00000oooool2o`0000Wooooo0ol00004ooooo`;o000000?oooooo`000?l000000_oo
ool2o`0000Gooooo0_l00009ooooo`;o00001Oooool5o`0000Wooooo0_l000000ooooooo0000o`00
000looooo`007?ooool00ol0003oooooooooo`0Tooooo`;o00007_ooool4o`0000kooooo0_l0000F
ooooo`;o00002Oooool2o`0000;ooooo0_l00007oooooaGo000000?oooooo`000?l000000ol00005
ooooo`;o00000_ooool2o`0000[ooooo0_l0000;ooooo`?o00000_ooool2o`0000;ooooo0_l00000
0ooooooo0000o`000003ooooo`;o00001?ooool5o`0000;ooooo0_l0000@ooooo`?o00001?ooool5
o`0000Wooooo0_l000000ooooooo0000o`00000looooo`007?ooool00ol0003oooooooooo`0Toooo
o`;o0000;Oooool2o`000003ooooool0003o000001Sooooo0_l00002ooooo`;o00000oooool9o`00
0003ooooool0003o000000oo000000?oooooo`000?l000003Ol00002ooooo`;o00001?ooool2o`00
00Sooooo0ol0000:ooooo`?o000000Coooooo`000?l0003ooooo1?l000001Ooooooo0000o`000?l0
003ooooo00?o00001?ooool5o`0000_ooooo0_l00004ooooo`;o00000_ooool2o`0000Kooooo0ol0
001:ooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00001Oooool2o`0000Oooooo0_l0000B
ooooo`;o00000_ooool2o`0000?ooooo2Ol000000ooooooo0000o`00000Oo`000003ooooool0003o
000000Co000000?oooooo`000?l000002Oooool2o`0000[ooooo0_l000000ooooooo0000o`00000:
o`000003ooooool0003o000000Sooooo0_l0000;ooooo`;o00001?ooool2o`0000Oooooo0_l00002
ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0C?ooool2o`0000kooooo0_l0000@oooo
o`;o00002Oooool2o`000003ooooool0003o0000017o000000?oooooo`000?l000003ol00003oooo
o`Oo000000?oooooo`000?l000002Oooool2o`0000Wooooo4_l00007ooooo`Ko00003oooool2o`00
00Oooooo0_l00004ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0E_ooool2o`0001Ko
oooo0_l0000=ooooob_o00001?ooool3o`0000Wooooo0_l00006oooooaCo00001_ooool3o`0000;o
oooo0_l0000Nooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0:oooool4o`0002?ooooo
0_l00002ooooo`;o00008?ooool3o`0000;ooooo7Ol000000ooooooo0000o`000007o`000003oooo
ool0003o000000Kooooo0_l00009ooooo`;o00001Oooool3o`000003ooooool0003o000000oo0000
00?oooooo`000?l000000oooool2o`0000?ooooo0_l00007ooooo`Co00005Oooool2o`0004Kooooo
000Looooo`03o`000?oooooooooo02_ooooo1?l0000Booooo`Co00002?ooool4o`000003ooooool0
003o000002?ooooo1Ol000000ooooooo0000o`00000Uo`000003ooooool0003o000000Kooooo0_l0
00000ooooooo0000o`000003ooooo`;o00001_oooolJo`0000cooooo0_l00003ooooo`Co00005Ooo
ool2o`0004Kooooo000Looooo`03o`000?oooooooooo047ooooo1?l00003ooooo`;o00000oooool4
o`000003ooooool0003o000000Kooooo0_l0000Aooooo`;o00002?oooolbo`0000Cooooo0_l00000
0ooooooo0000o`000003ooooo`;o00001_ooool2o`000003ooooool0003o000000ko000000?ooooo
o`000?l000001_l0000:ooooo`;o00001Oooool2o`0001Kooooo0_l0000<ooooo`;o0000=oooool0
01cooooo00?o0000ooooooooool0@?ooool2o`0000Gooooo0ol0000>ooooo`Co00004Oooool2o`00
00[ooooo0_l000001Ooooooo0000o`000?l0003ooooo01;o00000oooool9o`000003ooooool0003o
000000So00001_ooool4o`0000Kooooo0_l00005ooooo`?o000000?oooooo`000?l000002_l00000
0ooooooo0000o`000006o`0000Wooooo0ol00005ooooo`;o00000_ooool2o`0000Gooooo0_l00008
ooooo`;o000000?oooooo`000?l000003?ooool2o`0003Oooooo000Looooo`03o`000?oooooooooo
03oooooo0ol00005ooooo`Go00003?ooool2o`0001oooooo0_l00002oooooaGo00000_ooool?o`00
00;ooooo0_l00008ooooo`Co00001Oooool3o`0000Gooooo0ol00002oooooa?o00002_ooool3o`00
00Oooooo1?l00005ooooo`;o00000_ooool2o`0000Cooooo0_l00018ooooo`0000Koooooonk^k_lb
<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000
ooooooooool0?oooool2o`0000;ooooo0_l00003ooooo`Co00000oooool2o`0001Sooooo0_l0000<
ooooo`Co00000_ooool6o`0000;ooooo7_l00002ooooo`;o00004Oooool2o`0000Oooooo0_l00000
0ooooooo0000o`00000Bo`000003ooooool0003o000000Sooooo0_l00002ooooo`;o00000oooool2
o`0000_ooooo0_l00007ooooo`Go0000@_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Ooo
ool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`13ooooo`;o00001Ooo
ool2o`0000?ooooo0_l0000Hooooo`;o00002_ooool5o`0000;ooooo:ol000000ooooooo0000o`00
000Coooooa_o000000?oooooo`000?l000000ol00005ooooo`;o00000_ooool2o`0000Gooooo0_l0
000Aooooo`Ko0000@_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool5
o`0000Kooooo00?o0000ooooooooool0B_ooool2o`0001oooooo0ol00007ooooo`Go000000?ooooo
o`000?l000001?l000000ooooooo0000o`00000Vo`0000Cooooo0_l00008ooooo`;o00000oooool?
o`000003ooooool0003o000000So00000_ooool5o`0000Wooooo0_l00005ooooo`Co00003Oooool4
o`0004Kooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgM
gOoooooo00001oooool3o`0006_ooooo1?l00006ooooo`;o000000?oooooo`000?l00000:?l00002
ooooo`Go00001Oooool2o`0000Sooooo0ol00004ooooo`Oo000000?oooooo`000?l000003ol00000
1?oooooo0000o`000?ooool2o`0000Sooooo0_l00008ooooo`;o00003Oooool2o`0000Kooooo0ol0
000oooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGo
ooooo`0000Oooooo00?o0000ooooooooool0=Oooool2o`0000oooooo0_l0000Uooooo`;o00000_oo
ool2o`0000;ooooo0_l000001?oooooo0000o`000?l00005ooooob;o000000?oooooo`000?l00000
1?l0000@ooooo`;o000000Coooooo`000?l0003ooooo6Ol000001?oooooo0000o`000?ooool2o`00
00?ooooo0_l00003ooooo`;o00002?ooool2o`0001Gooooo0ol0000oooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooooooo
ool07oooool2o`0000Sooooo0_l0000:ooooo`?o00003_ooool2o`0000?ooooo0_l0000:ooooo`;o
00006?ooool7o`0000;ooooo0_l000000ooooooo0000o`00000;o`000003ooooool0003o000001Go
000000?oooooo`000?l000005oooool2o`000003ooooool0003o000001Co000000Coooooo`000?l0
003ooooo0_l00006ooooo`;o00007Oooool2o`0004Oooooo00001_ooooooMgMgoiRHV?ooooooV9RH
ogMgM`cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0Oooooo`;o00002?ooool2
o`0000_ooooo0_l00005ooooo`;o00000_ooool2o`0000?ooooo1?l000000ooooooo0000o`000009
ooooo`Go00004Oooool2o`0000Cooooo0ol000000ooooooo0000o`000002ooooo`;o000000?ooooo
o`000?l000008ol0000?ooooo`;o00002Oooool2o`000003ooooool0003o000001Ko00000_ooool3
o`0000_ooooo0_l0000Cooooo`;o00000_ooool2o`0000;ooooo0_l00013ooooo`0000Koooooonk^
k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0?Ooo
ool2o`0000;ooooo0ol00002ooooo`Ko00002_ooool2o`000003ooooool0003o000000gooooo0_l0
0002ooooo`;o00003_ooool2o`000003ooooool0003o000000Go000000?oooooo`000?l000002?l0
00001?oooooo0000o`000?ooool<o`0000;ooooo1?l00007ooooo`;o000000?oooooo`000?l00000
3?oooolHo`000003ooooool0003o000000;o00002_ooool3o`0000?ooooo0_l00009ooooo`;o0000
0oooool2o`0000;ooooo0_l00002ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0;?oo
ool2o`00017ooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool2o`0001cooooo0_l0
000=ooooo`;o00000_ooool3o`000003ooooool0003o000002Ko000000?oooooo`000?l000000_l0
0002ooooo`;o00003oooool2o`0000?ooooo4Ol00003ooooo`;o00002_ooool4o`0000Cooooo0_l0
0002ooooo`;o00001Oooool2o`0000_ooooo0_l000001?oooooo0000o`000?ooool2o`0003gooooo
000Looooo`03o`000?oooooooooo023ooooo0_l0000:ooooo`;o00001?ooool2o`0000Oooooo0_l0
0002ooooo`;o00000_ooool2o`0000Cooooo0_l00002ooooo`;o00006Oooool2o`0000gooooo0_l0
00001?oooooo0000o`000?l00002ooooobOo00000_ooool6o`0000Sooooo0_l00003ooooo`;o0000
00?oooooo`000?l000000ol000000ooooooo0000o`00000?o`0000?ooooo0_l0000:ooooo`;o0000
0_ooool2o`0000Gooooo0ol00002ooooo`;o000000?oooooo`000?l000003_ooool5o`0003gooooo
000Looooo`03o`000?oooooooooo023ooooo0_l0000@ooooo`;o00001oooool2o`0000;ooooo1_l0
0002ooooo`Co00000_ooool2o`0000Kooooo1?l0000?ooooo`;o00004?oooolPo`0000;ooooo2_l0
0002ooooo`;o00000_ooool2o`0000Sooooo0_l00003ooooo`Go000000Coooooo`000?l0003ooooo
3_l00006ooooo`;o00003_ooool2o`0000Gooooo0_l00003ooooo`;o000000?oooooo`000?l00000
4?ooool4o`0000;ooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0booooo`;o000000?o
ooooo`000?l000002?ooool4o`0000;ooooo1Ol0000;ooooo`Co00003oooool2o`0001;ooooo1ol0
00000ooooooo0000o`00000Qo`000003ooooool0003o000000;ooooo0_l0000?ooooo`?o00001_oo
ool;o`0000Oooooo0_l0000Jooooo`Co00001?ooool3o`0000_ooooo1ol0000hooooo`007?ooool0
0ol0003oooooooooo`0eooooo`;o00003_ooool2o`0001;ooooo0_l0000<ooooo`;o00002_ooool2
o`0000Sooooo9_l000000ooooooo0000o`000002o`0000Cooooo1Ol00009ooooo`Ko00002Oooool3
o`0000;ooooo0_l0000<ooooo`;o00005_ooool4o`0000Cooooo0ol0000>ooooo`;o00000_ooool2
o`0003Kooooo000Looooo`03o`000?oooooooooo03Gooooo0_l0000Mooooo`;o00000oooool2o`00
00Wooooo0_l000000ooooooo0000o`00000:ooooo`;o00000_ooool4o`000003ooooool0003o0000
02Go000000?oooooo`000?l000001_l000000ooooooo0000o`000004o`0000Oooooo0ol00008oooo
o`;o00000oooool2o`00013ooooo0_l00002ooooo`Co00000oooool2o`0002Sooooo0_l0000foooo
o`007?ooool00ol0003oooooooooo`0hooooo`;o00001_ooool2o`000003ooooool0003o000000oo
oooo1?l000000ooooooo0000o`000009ooooo`;o00003Oooool2o`0000;ooooo1?l000000ooooooo
0000o`00000To`0000?ooooo0_l000000ooooooo0000o`000002o`0000Gooooo0_l00007ooooo`;o
00002Oooool2o`0000?ooooo0_l0000Aooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o
00000_ooool2o`0000[ooooo0_l000000ooooooo0000o`00000Booooo`;o00005Oooool2o`0002;o
oooo000Looooo`03o`000?oooooooooo03Sooooo0_l000000ooooooo0000o`000003ooooo`;o0000
00?oooooo`000?l000004Oooool2o`0001_ooooo0_l00002ooooo`;o00000ooooolPo`000004oooo
ool0003o0000ooooo`;o00001_ooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o
00003?ooool2o`0000oooooo0_l00009ooooo`;o00000_ooool2o`0000Sooooo1?l00008ooooo`;o
000000?oooooo`000?l000003?ooool2o`0000Cooooo0_l0000Eooooo`;o00008_ooool001cooooo
00?o0000ooooooooool09Oooool2o`0001?ooooo1Ol000001?oooooo0000o`000?l0000:ooooo`;o
00002?ooool5o`0000Wooooo0_l00009ooooo`;o000000?oooooo`000?l000001?l00003oooooa3o
000000?oooooo`000?l000004?l000000ooooooo0000o`000002o`000003ooooool0003o000000Co
oooo0_l00002ooooo`;o00000_ooool2o`0000cooooo0_l00002ooooo`;o00002_ooool3o`0000Oo
oooo0_l00002ooooo`Co00002Oooool3o`0000Sooooo0_l0000?ooooo`;o000000?oooooo`000?l0
00003Oooool2o`0002gooooo000Looooo`03o`000?oooooooooo02Gooooo0_l0000Cooooo`Go0000
0_ooool2o`0000[ooooo1?l00006ooooo`Go00002Oooool3o`0000?ooooo0_l00003ooooo`;o0000
0oooool2o`0000Oooooo4?l000000ooooooo0000o`00000>o`000003ooooool0003o000000Go0000
4_ooool2o`000003ooooool0003o000000Oooooo0_l0000:ooooo`;o00002?ooool7o`0002Kooooo
0_l000000ooooooo0000o`000008ooooo`;o00000oooool2o`0002gooooo000Looooo`03o`000?oo
oooooooo02Sooooo0_l00003ooooo`;o00001_ooool4o`0000?ooooo0_l0000>ooooo`;o000000?o
ooooo`000?l000004_ooool2o`000003ooooool0003o000000?ooooo0_l00007ooooo`;o00002ooo
oolGo`000004ooooool0003o0000ooooo`Wo00000oooool2o`0000_ooooo0_l00002ooooo`;o0000
00?oooooo`000?l000003_ooool2o`0000oooooo0ol00006ooooo`;o00004Oooool2o`000004oooo
ool0003o0000o`0000oooooo0_l00005ooooo`;o0000<_ooool001cooooo0_l0000Nooooo`;o0000
2Oooool2o`0000?ooooo0_l00006ooooo`Co00004oooool2o`0000Kooooo0_l00005ooooo`;o0000
1_ooool2o`0000?ooooo0_l00005ooooo`;o00000oooool2o`0000_ooooo5_l00002ooooo`[o0000
1Oooool2o`0000_ooooo1_l00004ooooo`;o00000_ooool2o`0000Oooooo0_l00002ooooo`;o0000
00?oooooo`000?l000001Oooool4o`0000Gooooo0_l000001?oooooo0000o`000?ooool3o`0000_o
oooo1?l000001?oooooo0000o`000?l00008ooooo`;o00001Oooool2o`0003Wooooo000Looooo`03
o`000?oooooooooo01gooooo0_l0000Dooooo`;o000000Coooooo`000?l0003o00006oooool2o`00
00Gooooo0_l0000;ooooo`;o00001Oooool2o`0000[ooooo0_l00003ooooo`?o000000?oooooo`00
0?l000004_l000000ooooooo0000o`000003o`0000Gooooo0_l00006ooooo`Co00002?ooool4o`00
00Cooooo0_l00002ooooo`;o00000oooool4o`0000Cooooo0_l000000ooooooo0000o`000005oooo
o`Co00001Oooool2o`0000;ooooo1Ol0000;ooooo`;o00003_ooool2o`0000Cooooo1?l0000hoooo
o`007?ooool00ol0003oooooooooo`0cooooo`;o00000_ooool2o`000003ooooool0003o000002oo
oooo0_l00007ooooo`;o00000_ooool5o`0000?ooooo0_l00005oooooako00001_ooool4o`0001Co
oooo1?l000000ooooooo0000o`000002o`0000Cooooo0ol00003ooooo`;o00000_ooool2o`0000Oo
oooo0_l00002ooooo`;o00002Oooool4o`0001Oooooo1?l0000hooooo`007?ooool00ol0003ooooo
ooooo`0[ooooo`;o00002Oooool2o`0000;ooooo0_l0000Nooooo`;o00003oooool2o`000003oooo
ool0003o000000?ooooo0ol00002ooooo`Co00002oooool2o`0000;ooooo0_l000000ooooooo0000
o`000006o`000005ooooool0003o0000o`000?ooool00_l000000ooooooo0000o`000003o`000003
ooooool0003o000000Wooooo0_l00005ooooo`;o00001Oooool2o`0000Cooooo1?l00009ooooo`?o
00000oooool2o`000004ooooool0003o0000o`0000Oooooo0_l0000=ooooo`Co00000oooool2o`00
00?ooooo0_l0000>ooooo`;o0000>Oooool001cooooo00?o0000ooooooooool0:oooool2o`0000Wo
oooo0_l00002ooooo`;o00007_ooool2o`0000;ooooo0_l0000>ooooo`;o00000oooool2o`0000Co
oooo0ol00004ooooo`Co00000oooool3o`000004ooooool0003o0000ooooo`Co00001Oooool4o`00
00;ooooo1Ol00002ooooo`;o00002Oooool2o`000003ooooool0003o000000;ooooo0ol00004oooo
o`;o00001_ooool4o`00013ooooo0_l0000Jooooo`;o00000_ooool2o`0000?ooooo0_l0000>oooo
o`?o0000>?ooool001cooooo00?o0000ooooooooool06?ooool2o`0000Kooooo0_l0000@ooooo`;o
00001_ooool2o`0000_ooooo0_l00002ooooo`;o00004Oooool2o`00013ooooo0_l000000ooooooo
0000o`00000;ooooo`Co000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00000?o`00
0004ooooool0003o0000o`0000kooooo0_l00002ooooo`;o00000oooool4o`0000;ooooo0_l00007
ooooo`?o00003Oooool2o`000003ooooool0003o000001?ooooo0_l00005ooooo`Co000000Gooooo
o`000?l0003o0000ooooo`02o`0000_ooooo0_l00002ooooo`Co0000=_ooool001cooooo00?o0000
ooooooooool06?ooool2o`0000Kooooo0_l0000@ooooo`;o00004_ooool3o`0000;ooooo0_l0000:
ooooo`;o00000_ooool2o`0001?ooooo0_l000000ooooooo0000o`000002ooooo`;o00002?ooool=
o`0000Cooooo2_l00002ooooo`;o00003Oooool3o`0000Wooooo0_l00002ooooo`;o00005oooool4
o`0001Cooooo0_l00007ooooo`Ko00000oooool2o`0000Wooooo0ol00003ooooo`;o0000=_ooool0
01cooooo00?o0000ooooooooool0A_ooool2o`000003ooooool0003o000000cooooo0_l00002oooo
o`;o00003Oooool2o`0000Gooooo0_l00004ooooo`;o00001Oooool2o`0000;ooooo1?l000000ooo
oooo0000o`000004o`0000Gooooo1Ol000000ooooooo0000o`00000Aooooo`Go00003?ooool2o`00
01[ooooo0_l0000Nooooo`?o00000_ooool2o`000003ooooool0003o000000[ooooo0_l0000koooo
o`007?ooool00ol0003oooooooooo`0cooooo`;o000000?oooooo`000?l000000oooool2o`0000co
oooo0_l00004ooooo`;o00006Oooool2o`0000Gooooo0_l0000;ooooo`;o00001Oooool4o`0000Ko
oooo0_l00003ooooo`Ko00004Oooool5o`0000Wooooo0_l000000ooooooo0000o`000004ooooo`;o
00007Oooool2o`0000Kooooo0_l00007ooooo`;o00000oooool2o`0000Cooooo0_l00002ooooo`;o
0000A_ooool001cooooo00?o0000ooooooooool0<_ooool3o`000003ooooool0003o000000?ooooo
0_l0000?ooooo`;o000000?oooooo`000?l000002_ooool2o`0000oooooo0_l0000:ooooo`;o0000
1Oooool2o`000004ooooool0003o0000ooooo`Oo00000oooool2o`0000Cooooo0ol00003ooooo`;o
00005_ooool2o`0000?ooooo0ol00007ooooo`;o00004_ooool2o`0000Wooooo0_l00006ooooo`;o
00001oooool2o`0000?ooooo0_l00008ooooo`;o00002Oooool2o`0003_ooooo000Looooo`03o`00
0?oooooooooo02Cooooo0_l0000<ooooo`?o00001oooool2o`0000Wooooo0_l00003ooooo`;o0000
1_ooool2o`0000Gooooo0_l0000?ooooo`;o00001?ooool2o`0000Cooooo0_l00005ooooo`Go0000
1Oooool3o`0000Wooooo0_l00004ooooo`Co00003_ooool3o`0000;ooooo0ol000000ooooooo0000
o`000002o`0000Cooooo0_l000000ooooooo0000o`00000:ooooo`;o00001oooool2o`000003oooo
ool0003o000002?ooooo0_l00007ooooo`Co000000?oooooo`000?l00000>oooool001cooooo00?o
0000ooooooooool09?ooool2o`0000Gooooo0_l00002ooooo`;o00001oooool2o`0000;ooooo0_l0
00000ooooooo0000o`000006ooooo`;o00000oooool2o`0000Kooooo0ol00007ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0000_ooooo0_l0000=ooooo`;o00001_ooool2o`0000[ooooo0_l0
0006ooooo`;o00002Oooool3o`0000;ooooo0ol00002ooooo`;o00000_ooool2o`0000Kooooo0_l0
00000ooooooo0000o`00000:ooooo`;o00001Oooool2o`0000?ooooo0_l00004ooooo`;o00001ooo
ool2o`0000oooooo0_l000000ooooooo0000o`000004o`0000Gooooo1?l0000nooooo`007?ooool0
0ol0003oooooooooo`0[ooooo`;o00000_ooool2o`000003ooooool0003o000000Cooooo0_l00005
ooooo`;o00003_ooool2o`0000;ooooo1?l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l0
0002ooooo`;o00007?ooool2o`0000?ooooo0ol0000:ooooo`;o000000?oooooo`000?l000002Ooo
ool2o`0000?ooooo0ol0000Gooooo`;o00001_ooool2o`0000Kooooo1?l00004ooooo`;o00000ooo
ool4o`0000Gooooo0_l0000?ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Gooooo0ol0
000oooooo`007?ooool00ol0003oooooooooo`0booooo`;o00000_ooool2o`0000Oooooo0_l0000=
ooooo`?o00000_ooool2o`0000Kooooo1?l00006ooooo`;o00003Oooool2o`0000gooooo0_l00003
ooooo`;o00000_ooool2o`0000Gooooo0_l00003ooooo`;o00002Oooool2o`0000;ooooo0_l0000>
ooooo`;o00002Oooool2o`0000;ooooo0_l00002ooooo`;o00001_ooool3o`000003ooooool0003o
000000;ooooo0_l00003ooooo`Co00000_ooool2o`00017ooooo0_l00009ooooo`Co000000?ooooo
o`000?l00000?oooool001cooooo00?o0000ooooooooool0=_ooool2o`000003ooooool0003o0000
00;o00004Oooool3o`0000_ooooo0ol00003ooooo`;o000000?oooooo`000?l000000oooool3o`00
00Oooooo0_l000000ooooooo0000o`00000Cooooo`;o00001Oooool2o`0001;ooooo0_l0000>oooo
o`Co00001oooool2o`0000;ooooo0_l0000;ooooo`;o000000?oooooo`000?l000003Oooool2o`00
00gooooo0_l00002ooooo`?o000000?oooooo`000?l000000oooool6o`0004;ooooo000Looooo`03
o`000?oooooooooo03;ooooo0_l00005ooooo`Co00004_ooool2o`0000Cooooo0_l00005ooooo`;o
00001?ooool2o`0000Kooooo1Ol000000ooooooo0000o`000005ooooo`?o00000_ooool2o`0002_o
oooo0_l0000>ooooo`;o00002Oooool2o`0000;ooooo1?l00004ooooo`;o00001?ooool2o`0000Ko
oooo0_l0000Dooooo`;o00000oooool2o`000003ooooool0003o000000Go00002_ooool2o`0003[o
oooo000Looooo`;o0000;Oooool2o`0000Cooooo0_l0000Cooooo`?o00002oooool2o`0001Kooooo
0_l000000ooooooo0000o`000006ooooo`;o00000_ooool2o`0001Wooooo0_l0000@ooooo`?o0000
3?ooool2o`0000Cooooo0_l00004ooooo`;o00000_ooool6o`0000;ooooo0_l0000;ooooo`?o0000
6Oooool3o`0000;ooooo1Ol0000:ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0;?oo
ool2o`0000gooooo0_l0000:ooooo`?o00005oooool2o`000004ooooool0003o0000ooooo`;o0000
1Oooool2o`0000Wooooo0_l0000:ooooo`;o00003_ooool4o`0000?ooooo0_l0000<ooooo`;o0000
2Oooool2o`000005ooooool0003o0000o`000?ooool01?l00004ooooo`?o00001Oooool2o`0000oo
oooo0_l000000ooooooo0000o`00000Aooooo`;o00001?ooool3o`0001Oooooo0_l0000dooooo`00
7?ooool00ol0003oooooooooo`0kooooo`;o00009?ooool5o`000003ooooool0003o000000Gooooo
0_l00007ooooo`Co00002_ooool2o`0000Oooooo0_l000000ooooooo0000o`000004o`0000;ooooo
0_l000001?oooooo0000o`000?ooool4o`0000Kooooo0_l0000:ooooo`;o00000_ooool2o`000003
ooooool0003o000000Kooooo1Ol00009ooooo`;o000000?oooooo`000?l000001_ooool2o`000003
ooooool0003o0000017ooooo0_l0000=ooooo`;o00003oooool2o`0003Cooooo000Looooo`03o`00
0?oooooooooo02gooooo0_l0000Dooooo`;o00004?ooool4o`0000[ooooo0_l0000Booooo`Co0000
2?ooool2o`0000Wooooo0_l000000ooooooo0000o`000008o`000004ooooool0003o0000ooooo`Co
00001Oooool3o`000003ooooool0003o000000Oooooo0_l00005ooooo`;o00002Oooool2o`0000Ko
oooo0_l000001?oooooo0000o`000?ooool2o`0000Kooooo0_l0000Sooooo`;o00003?ooool2o`00
03Oooooo000Looooo`03o`000?oooooooooo02gooooo0_l00009ooooo`;o00001?ooool2o`0000?o
oooo0_l0000@ooooo`Co00000_ooool2o`0000_ooooo0_l00009ooooo`;o00003_ooool2o`0000Co
oooo0_l000000ooooooo0000o`000008ooooo`Co00000_ooool7o`0000Gooooo0_l00002ooooo`;o
00007?ooool2o`0000?ooooo0_l0000:ooooo`;o00000_ooool2o`0002oooooo0_l0000gooooo`00
7?ooool00ol0003oooooooooo`0hooooo`;o00001?ooool2o`0000oooooo0_l00003ooooo`;o0000
1Oooool2o`0000;ooooo0_l00007ooooo`;o00002Oooool2o`0000Sooooo0_l00003ooooo`;o0000
1Oooool5o`0000kooooo1Ol0000;ooooo`;o00002oooool4o`0000Sooooo0_l00003ooooo`;o0000
0_ooool2o`0000_ooooo0_l00002ooooo`;o00002_ooool2o`0001?ooooo0_l00017ooooo`007?oo
ool00ol0003oooooooooo`0dooooo`;o00002_ooool2o`0000gooooo0_l00003ooooo`;o00002Ooo
ool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000004?ooool2o`0000?ooooo0_l0
0007ooooo`?o00002_ooool2o`0001;ooooo1?l00009ooooo`Co00002?ooool2o`0000Kooooo2ol0
000Cooooo`;o00004oooool2o`0004Oooooo000Looooo`03o`000?oooooooooo03Cooooo0_l00004
ooooo`;o00001?ooool2o`000003ooooool0003o000000[ooooo0ol0000Aooooo`;o000000?ooooo
o`000?l000000_l000000ooooooo0000o`000005ooooo`;o00001oooool2o`0000cooooo0ol00008
ooooo`;o00000_ooool2o`0000Kooooo0_l00007ooooo`;o00000oooool2o`0000[ooooo0_l00009
ooooo`;o00001?ooool=o`0000;ooooo0_l00005ooooo`;o00002?ooool2o`0001Wooooo0_l0000;
ooooo`;o0000=?ooool001cooooo00?o0000ooooooooool09_ooool2o`0001;ooooo0_l00007oooo
o`;o00002_ooool4o`0000gooooo0_l00002ooooo`Go00001Oooool2o`0000;ooooo0_l000000ooo
oooo0000o`000006o`0000[ooooo1Ol00006ooooo`Co00002_ooool2o`0000Oooooo0_l0000Noooo
o`[o000000Coooooo`000?l0003o00000oooool2o`0000Gooooo0ol00006ooooo`?o00006Oooool2
o`0000_ooooo0_l0000dooooo`007?ooool00ol0003oooooooooo`0Vooooo`;o0000:Oooool2o`00
0003ooooool0003o000000Sooooo1?l00002ooooo`Go000000?oooooo`000?l000001?l00004oooo
o`Oo00003?ooool2o`0000Cooooo1?l000001Ooooooo0000o`000?l0003ooooo00;o00000oooool2
o`0002Gooooo0_l00002oooooa;o00002?ooool5o`000003ooooool0003o000000;ooooo0_l00006
ooooo`;o00006oooool2o`000003ooooool0003o000003Gooooo000Looooo`03o`000?oooooooooo
02kooooo0_l00004ooooo`;o00002_ooool2o`0001;ooooo0_l00004ooooo`;o00000_ooool3o`00
0004ooooool0003o0000ooooo`co000000?oooooo`000?l000001_l00002ooooo`;o00000_ooool2
o`0000Oooooo2?l00005ooooo`;o00000oooool2o`00017ooooo0_l00007ooooo`Co00001ooooolF
o`0000Sooooo2?l0000:ooooo`;o00001?ooool2o`0001Gooooo0_l000001?oooooo0000o`000?oo
ool2o`0003;ooooo000Looooo`03o`000?oooooooooo02gooooo0ol00004ooooo`;o00002?ooool4
o`0000Kooooo0_l000000ooooooo0000o`000003ooooo`;o00000_ooool2o`0000?ooooo0ol00003
ooooo`Go000000?oooooo`000?l000003Ol00004ooooo`;o00000_ooool2o`0000;ooooo1?l00005
ooooo`Co00003oooool2o`00013ooooo0_l00007ooooo`Co00002?ooool6o`000003ooooool0003o
000000co00001_ooool2o`0000Cooooo0_l00009ooooo`;o00001oooool2o`0001Gooooo0_l00004
ooooo`;o0000<_ooool001cooooo00?o0000ooooooooool0;Oooool2o`0000[ooooo0_l00003oooo
o`;o00002?ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000000_ooool2o`00
00;ooooo1?l00002oooooaGo000000?oooooo`000?l000002_ooool4o`0000;ooooo0_l0000Doooo
o`;o00001?ooool2o`0001cooooo0_l000000ooooooo0000o`000009o`000003ooooool0003o0000
00[o00000oooool2o`0000oooooo0_l0000=ooooo`;o00003oooool2o`0003Sooooo000Looooo`03
o`000?oooooooooo03;ooooo0_l00005ooooo`;o00004Oooool3o`0000Wooooo2Ol000000ooooooo
0000o`00000Do`0000;ooooo0_l00004ooooo`;o00001?ooool2o`000003ooooool0003o000000;o
oooo0_l0000<ooooo`;o00001Oooool2o`0000Sooooo0_l00003ooooo`;o00002ooooolMo`0000[o
oooo0_l0000Dooooo`;o000000?oooooo`000?l000002Oooool2o`0000;ooooo0_l0000jooooo`00
7?ooool00ol0003oooooooooo`0[ooooo`;o00001Oooool2o`0000;ooooo0_l0000Dooooo`;o0000
1oooool2o`000004ooooool0003o0000oooooa[o000000?oooooo`000?l000000_ooool2o`0000Co
oooo0_l00006ooooo`?o00000_ooool2o`0000cooooo0_l00007ooooo`;o00001_ooool3o`0000;o
oooo0ol0000:oooooago00002_ooool2o`0001Cooooo0_l00004ooooo`;o00001_ooool2o`0000;o
oooo0_l0000Booooo`;o00009_ooool001cooooo00?o0000ooooooooool0:oooool2o`0000;ooooo
0_l00005ooooo`;o00005oooool2o`0000;ooooo1?l000001?oooooo0000o`000?oooolIo`0000Ko
oooo0_l00004ooooo`;o00001?ooool4o`0000?ooooo0_l00003ooooo`;o00000_ooool2o`0000co
oooo1?l00005ooooo`;o00000oooool2o`0000cooooo6ol0000Booooo`;o00002_ooool4o`0000Co
oooo0_l0000;ooooo`;o00004Oooool2o`0002Kooooo000Looooo`;o0000<?ooool2o`0001?ooooo
0_l00009ooooo`;o00000_oooolRo`0000;ooooo0_l000000ooooooo0000o`000004ooooo`;o0000
0_ooool4o`0000Wooooo1ol00009ooooo`;o00000oooool2o`0000Cooooo0_l00003ooooo`Co0000
2ooooolKo`0001;ooooo0_l0000:ooooo`;o00001Oooool4o`0000Gooooo0_l00003ooooo`?o0000
0oooool2o`0003?ooooo000Looooo`03o`000?oooooooooo03Wooooo0_l00009ooooo`;o00001_oo
ool2o`0000Wooooo7ol000000ooooooo0000o`00000;ooooo`;o000000?oooooo`000?l000002?oo
ool5o`0000_ooooo0_l00005ooooo`;o00000_ooool2o`000003ooooool0003o000000Co000000?o
ooooo`000?l000001_oooolMo`0000[ooooo0_l0000Gooooo`Ko00001?ooool3o`0000?ooooo0ol0
0003ooooo`?o0000<_ooool001cooooo00?o0000ooooooooool0>Oooool2o`0000;ooooo0_l00002
ooooo`;o00002Oooool2o`000005ooooool0003o0000o`000?ooool00_l00002oooooaoo00003_oo
ool5o`0000[ooooo0_l00008ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`00
0005ooooo`Co00000oooool2o`0000Kooooo7ol000000ooooooo0000o`000003o`0000;ooooo0_l0
000Gooooo`?o00001oooool2o`000004ooooool0003o0000ooooo`;o00001Oooool2o`0003;ooooo
000Looooo`03o`000?oooooooooo02Wooooo0_l00005ooooo`?o00002_ooool2o`0000;ooooo0_l0
000<ooooo`Ko000000?oooooo`000?l000007ol0000=ooooo`Co00005Oooool2o`0000Kooooo1?l0
0007ooooo`Go00002?oooolVo`0000Oooooo0_l00004ooooo`Co00002oooool2o`0000[ooooo0_l0
0009ooooo`;o0000<Oooool001cooooo00?o0000ooooooooool0:Oooool2o`0000Gooooo0ol00008
ooooo`;o00003_ooool2o`0000?ooooo0ol00003ooooo`Ko000000?oooooo`000?l000006Ol00002
ooooo`;o00000_ooool2o`0000Cooooo0ol00008ooooo`;o00005Oooool3o`0000Oooooo1Ol00008
ooooo`?o000000?oooooo`000?l000006ol000000ooooooo0000o`000009ooooo`;o00001?ooool4
o`000004ooooool0003o0000o`0001;ooooo0ol00009ooooo`;o0000<Oooool001cooooo00?o0000
ooooooooool0>oooool2o`0000Wooooo0_l00003ooooo`;o00000oooool2o`0000Gooooo8Ol00002
ooooo`;o00000_ooool2o`0000?ooooo1?l00008ooooo`;o00003?ooool3o`000003ooooool0003o
000000;o000000?oooooo`000?l000000_l00006ooooo`Co00002_oooolSo`0001Cooooo0ol00006
ooooo`;o00000_ooool2o`0000;ooooo0_l00002ooooo`;o00001_ooool2o`0003Gooooo000Loooo
o`03o`000?oooooooooo037ooooo0_l0000Cooooo`;o00000oooool2o`000003ooooool0003o0000
00Cooooo8?l000001?oooooo0000o`000?ooool2o`0000Wooooo0ol0000Gooooo`?o000000?ooooo
o`000?l000000_l00003ooooo`;o00005_ooool5o`000003ooooool0003o000000Go00000ooooolA
o`000003ooooool0003o000000Cooooo0_l00003ooooo`;o00003oooool2o`0000;ooooo0_l00000
1?oooooo0000o`000?l0000:ooooo`;o0000=Oooool001cooooo00?o0000ooooooooool0<Oooool2
o`0000;ooooo0_l0000Gooooo`;o00000ooooolQo`0000Cooooo0_l0000:ooooo`;o00002oooool2
o`0000;ooooo0_l00007ooooo`;o00004oooool4o`0000Sooooo8_l000000ooooooo0000o`000004
ooooo`;o00000oooool2o`000003ooooool0003o000001?ooooo0_l0000;ooooo`;o00000_ooool2
o`00037ooooo000Looooo`03o`000?oooooooooo03Gooooo1?l00007ooooo`;o00001oooool2o`00
00Sooooo4_l000000ooooooo0000o`00000=o`0000?ooooo0ol00009ooooo`;o00002oooool2o`00
0004ooooool0003o0000o`0000Oooooo1?l0000Aooooo`Co00001ooooolBo`000003ooooool0003o
000000ko00003oooool2o`00023ooooo0ol000000ooooooo0000o`00000aooooo`007?ooool00ol0
003oooooooooo`0gooooo`;o00001_ooool3o`0000Oooooo0_l0000:oooooaCo000000?oooooo`00
0?l000002Ol00003ooooo`?o00000_ooool2o`0000Gooooo0_l00007ooooo`;o00001Oooool2o`00
00Oooooo0_l000000ooooooo0000o`00000?ooooo`Co00002Oooool8o`000003ooooool0003o0000
00;ooooo3?l000000ooooooo0000o`000002o`0000;ooooo0_l00007ooooo`Co00001oooool2o`00
00Cooooo0ol00003ooooo`;o00001oooool2o`000003ooooool0003o000000Oooooo0_l0000doooo
o`007?ooool00ol0003oooooooooo`0oooooo`;o00005?oooolOo`0000Cooooo0_l00003ooooo`;o
00001?ooool5o`0000Gooooo0_l00005ooooo`;o00001oooool2o`0000Cooooo0_l00005ooooo`;o
00001Oooool4o`0000;ooooo0_l00008oooooa_o00002oooool4o`0000;ooooo0_l00003ooooo`;o
00001?ooool5o`000003ooooool0003o000000Oooooo0_l000000ooooooo0000o`00000mooooo`00
7?ooool00ol0003oooooooooo`11ooooo`;o00003_oooolUo`0000;ooooo0_l00009ooooo`Go0000
0oooool2o`0000Oooooo0_l0000=ooooo`;o00001Oooool2o`0000Kooooo0ol00002ooooo`;o0000
2?oooolCo`0000;ooooo0_l000001?oooooo0000o`000?l00004ooooo`Co00002?ooool3o`0000co
oooo0_l000000ooooooo0000o`000009ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0
@Oooool2o`0000[ooooo0_l00002ooooo`Co00000_oooolOo`0000?ooooo0_l00006ooooo`;o0000
00?oooooo`000?l000001Oooool2o`0000Wooooo0_l0000>ooooo`;o00002Oooool4o`0000?ooooo
0_l00007oooooa[o00001?ooool5o`0000Oooooo0ol0000@ooooo`;o00002Oooool2o`0003kooooo
000Looooo`03o`000?oooooooooo02Wooooo0_l0000Rooooo`;o00000_oooolUo`0000?ooooo0_l0
0006ooooo`;o000000?oooooo`000?l000003Oooool2o`000003ooooool0003o000000?ooooo0_l0
0009ooooo`;o00000oooool3o`000003ooooool0003o000000Co00000oooool2o`0000Oooooo6_l0
0004ooooo`;o00002_ooool3o`0005_ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo
0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0Yooooo`;o
00001oooool2o`0001gooooo0_l000000ooooooo0000o`00000Po`0001Kooooo0_l00005ooooo`;o
00001?ooool4o`0000kooooo0ol000000ooooooo0000o`000002ooooo`;o00002?ooool2o`0000?o
oooo4Ol000000ooooooo0000o`000005o`0000?ooooo0_l00002ooooo`Co00003oooool2o`0001;o
oooo0_l0000:ooooo`;o0000<_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q
8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo03;ooooo0_l0000D
ooooo`;o00002ooooolOo`0001Sooooo0ol000000ooooooo0000o`000007ooooo`;o00004?ooool2
o`00013ooooo0_l00004ooooo`[o000000?oooooo`000?l000002?l00006ooooo`;o00000_ooool4
o`0000Wooooo0_l00004ooooo`Co00001Oooool2o`0000Wooooo0_l0000:ooooo`Co0000<?ooool0
0003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool0B?ooool2o`0000Oooooo0_l00002ooooo`;o000000Cooooo
o`000?l0003ooooo5ol0000<ooooo`;o00003Oooool2o`000003ooooool0003o000000?ooooo0_l0
000<ooooo`Ko00001_ooool2o`0001;ooooo2Ol000000ooooooo0000o`000008o`0000;ooooo1?l0
0005ooooo`;o00002oooool2o`0000Gooooo0ol00005ooooo`;o00005oooool2o`00033ooooo0000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oiRHV?ooooooV9RHob4Q
8@06ooooo`?o0000B?ooool3o`0000Kooooo0_l00006ooooo`;o000000Coooooo`000?l0003ooooo
4Ol0000>ooooo`;o00005Oooool2o`0000Sooooo0_l000000ooooooo0000o`000005o`0000Kooooo
1?l00007ooooo`;o00001oooool4o`000003ooooool0003o000000;o000000?oooooo`000?l00000
2?l00002ooooo`Co00006Oooool3o`0000Gooooo0ol00006ooooo`;o0000@?ooool00003ooooool0
003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo
00?o0000ooooooooool0B?ooool5o`000003ooooool0003o000000Wooooo1?l000000ooooooo0000
o`000007o`0000?ooooo1ol00009ooooo`;o00001?ooool3o`0001cooooo0_l000001?oooooo0000
o`000?l0000<ooooo`;o00001oooool2o`0000cooooo3_l0000Sooooo`;o00000oooool3o`0000Ko
oooo0_l00010ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`03oeEE
EOn7QhOooooo00Sooooo00?o0000ooooooooool0B?ooool2o`000004ooooool0003o0000ooooo`;o
00001_ooool2o`000003ooooool0003o000000ko00000oooool6o`0000Kooooo1?l00004ooooo`?o
00001Oooool2o`0000Oooooo0_l00003ooooo`;o00000_ooool2o`0000Oooooo0_l0000;ooooo`;o
00000oooool2o`0000;ooooo0_l0000:oooooa3o00003Oooool2o`000003ooooool0003o000000So
oooo0_l00006ooooo`Co0000C_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool00ooM
gMgo410@oiRHV008ooooo`03o`000?oooooooooo04oooooo1?l00003ooooo`;o00001?ooool3o`00
0003ooooool0003o000000Oo00000oooool2o`0000;ooooo1?l00004ooooo`Co00001oooool2o`00
00?ooooo0_l00007ooooo`;o00000oooool2o`0000;ooooo0_l0000:ooooo`;o00002?ooool2o`00
00?ooooo1_l0000:ooooo`?o00000_ooool4o`0000;ooooo0_l000000ooooooo0000o`00000=oooo
o`Go00002?ooool2o`0000Kooooo1?l0000;ooooo`;o0000@Oooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo04Kooooo0_l0
0007ooooo`Co00001Oooool2o`0000Sooooo1Ol0000;ooooo`?o00002oooool2o`000003ooooool0
003o000000;o00002oooool2o`0000Gooooo1?l00009ooooo`;o00003?ooool2o`000003ooooool0
003o000000Wooooo0_l00005ooooo`?o00005oooool8o`0000kooooo0_l000001?oooooo0000o`00
0?ooool2o`0000Gooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00006?oo
ool5o`0000gooooo0ol0000?ooooo`;o00001Oooool4o`0000_ooooo0_l000000ooooooo0000o`00
0004o`0000Wooooo0_l00005ooooo`Co00000_ooool2o`000003ooooool0003o000000;o000000?o
ooooo`000?l000002oooool2o`0000cooooo0_l00005ooooo`Co00006?ooool6o`00017ooooo0_l0
00000ooooooo0000o`000005ooooo`?o0000@?ooool001cooooo00?o0000ooooooooool0;?ooool2
o`0001Wooooo1?l00009ooooo`;o00000oooool2o`0000oooooo0_l00005ooooo`?o00003oooool3
o`000003ooooool0003o000000_ooooo0_l00002ooooo`;o000000?oooooo`000?l000002Ol00000
0ooooooo0000o`000002ooooo`;o00001oooool2o`0001Cooooo0ol0000>ooooo`;o000000?ooooo
o`000?l000002Oooool4o`0000Oooooo0_l00009ooooo`;o00001_ooool2o`00043ooooo000Loooo
o`03o`000?oooooooooo04Gooooo0_l00007ooooo`;o00001?ooool2o`0000oooooo0_l00004oooo
o`;o00001Oooool2o`00023ooooo0_l00002ooooo`;o000000?oooooo`000?l000001Ol000001?oo
oooo0000o`000?l00005ooooo`;o00000_ooool2o`0000cooooo0_l000000ooooooo0000o`000008
ooooo`;o00003oooool2o`000003ooooool0003o000000?ooooo0_l00006ooooo`;o00001oooool2
o`0005?ooooo000Looooo`03o`000?oooooooooo033ooooo0_l0000Aooooo`Co00000oooool2o`00
0004ooooool0003o0000o`00017ooooo0_l00002ooooo`;o00000_ooool6o`0000?ooooo0_l0000:
ooooo`Co00006Oooool2o`0000_ooooo1?l00003ooooo`;o00001Oooool2o`000004ooooool0003o
0000ooooo`?o000000?oooooo`000?l000003Oooool2o`0000Oooooo0_l00008ooooo`?o000000?o
ooooo`000?l000005?ooool2o`0004_ooooo000Looooo`03o`000?oooooooooo033ooooo0_l0000A
ooooo`?o00001?ooool2o`000003ooooool0003o000001;ooooo0ol000000ooooooo0000o`000002
ooooo`Ko00000oooool2o`0000[ooooo1?l00005ooooo`;o00001oooool2o`0000Oooooo0_l00002
ooooo`;o00001Oooool:o`0000Sooooo0_l000001?oooooo0000o`000?ooool2o`00017ooooo0_l0
00000ooooooo0000o`000004ooooo`;o00000oooool3o`0000;ooooo0ol000000ooooooo0000o`00
000Dooooo`;o00001?ooool2o`0004Gooooo000Looooo`03o`000?oooooooooo02gooooo0_l0000E
ooooo`;o00002?ooool2o`00013ooooo1?l000001?oooooo0000o`000?l00003ooooo`Co00006?oo
ool2o`0000Oooooo0_l00007ooooo`;o00000_ooool;o`0000Cooooo0_l00007ooooo`Go000000?o
ooooo`000?l000004?ooool2o`0000?ooooo0_l00004ooooo`;o00000oooool3o`0000?ooooo0_l0
000<ooooo`;o00001oooool2o`0000Kooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`0]
ooooo`;o00006oooool2o`0000;ooooo0_l0000;ooooo`;o00000oooool2o`0000Cooooo0_l00002
ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Sooooo0_l0000Booooo`;o00001Oooool2
o`000003ooooool0003o000000[o00003Oooool3o`000003ooooool0003o000000?o00001?ooool2
o`0000;ooooo0_l00006ooooo`;o00003Oooool4o`0000Kooooo0_l00003ooooo`;o00000oooool3
o`0000Oooooo0_l00003ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0B_ooool2o`00
00?ooooo0_l0000:ooooo`;o00003?ooool6o`0000Cooooo0_l00006ooooo`Ko000000?oooooo`00
0?l000000oooool2o`0000Sooooo1?l00002ooooo`?o000000?oooooo`000?l000003Ol0000:oooo
o`;o00000_ooool3o`0000;ooooo0_l00002ooooo`;o00000_ooool2o`0000Oooooo0_l0000<oooo
o`;o00000_ooool2o`0000Cooooo0_l00002ooooo`?o000000?oooooo`000?l000000_l000001?oo
oooo0000o`000?ooool2o`0000?ooooo0_l00002ooooo`;o0000B?ooool001cooooo00?o0000oooo
ooooool0Coooool2o`0000Wooooo0_l00002ooooo`Co00001oooool2o`000003ooooool0003o0000
00;o00002Oooool4o`0000;ooooo1Ol00003ooooo`;o00002Oooool3o`0000;ooooo0_l000000ooo
oooo0000o`00000>o`000003ooooool0003o000000Cooooo0_l0000:ooooo`;o00003oooool2o`00
0004ooooool0003o0000o`0000;ooooo0_l00008ooooo`;o00002?ooool2o`0000;ooooo0ol00002
ooooo`;o000000Coooooo`000?l0003ooooo1?l000000ooooooo0000o`000019ooooo`007?ooool0
0ol0003oooooooooo`1Gooooo`Go00000_ooool4o`0000Oooooo0_l00003ooooo`;o00000oooool2
o`0000Cooooo0ol00005ooooo`;o00001?ooool2o`000003ooooool0003o000000;o00000oooool4
o`0000;ooooo4Ol000000ooooooo0000o`000002o`0000Cooooo0_l00004ooooo`;o00001?ooool2
o`000003ooooool0003o000000;ooooo0ol00004ooooo`;o00001?ooool3o`0000;ooooo0_l00002
ooooo`Co000000?oooooo`000?l000001_ooool4o`0000Cooooo0_l00002ooooo`;o00001?ooool2
o`0000?ooooo0_l00019ooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o00001Oooool5o`00
00oooooo0_l00005ooooo`Go00000oooool4o`0000?ooooo0_l00002ooooo`;o00001Oooool4o`00
00?ooooo6ol00002ooooo`;o00001oooool2o`0000Gooooo1?l00002ooooo`?o00001?ooool2o`00
00Oooooo0_l00004ooooo`Co000000?oooooo`000?l000001_ooool4o`0000Sooooo0_l00005oooo
o`;o00000_ooool2o`0004Wooooo000Looooo`;o0000Coooool4o`0000?ooooo0_l0000Iooooo`Co
00001?ooool2o`0000Gooooo0_l00002ooooo`;o00003?oooolJo`0000?ooooo0_l00004ooooo`;o
00002?ooool3o`0000[ooooo0_l00007ooooo`;o00001_ooool2o`0000kooooo0_l00005ooooo`;o
00001Oooool4o`0004_ooooo000Looooo`03o`000?oooooooooo03Gooooo0_l0000@ooooo`;o0000
0_ooool2o`0000?ooooo0_l00009ooooo`;o00000oooool2o`0000Kooooo0_l00008ooooo`;o0000
1?ooool2o`0000Cooooo0_l000001?oooooo0000o`000?l0000=ooooo`;o000000?oooooo`000?l0
00005Ol00003ooooo`;o00001?ooool2o`0000Gooooo0_l000000ooooooo0000o`00000[ooooo`?o
000000?oooooo`000?l000002Oooool4o`0004_ooooo000Looooo`03o`000?oooooooooo03Gooooo
0_l0000@ooooo`;o00000_ooool2o`0000gooooo0ol00002ooooo`?o00001_ooool2o`0000Sooooo
0_l0000:ooooo`;o000000Coooooo`000?l0003o00000oooool2o`000003ooooool0003o000000co
oooo5?l0000=ooooo`Co0000;_ooool3o`000003ooooool0003o000000Kooooo0_l000000ooooooo
0000o`00001=ooooo`007?ooool00ol0003oooooooooo`0looooo`;o00002oooool5o`0000Sooooo
0_l00002ooooo`;o00000oooool2o`0000Wooooo0_l0000Eooooo`;o00001?ooool2o`000003oooo
ool0003o000000Sooooo0_l000000ooooooo0000o`000004o`000003ooooool0003o000000co0000
3Oooool2o`0000Cooooo0_l0000=ooooo`;o00003?ooool2o`0000[ooooo0ol000001?oooooo0000
o`000?ooool2o`0000Cooooo1?l000000ooooooo0000o`00001=ooooo`007?ooool00ol0003ooooo
ooooo`0looooo`;o00002oooool5o`0000Sooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo
0_l00003ooooo`?o00005oooool2o`0000kooooo6Ol000000ooooooo0000o`000007ooooo`;o0000
0oooool3o`000003ooooool0003o000000?o00002_ooool2o`0000cooooo0_l00009ooooo`Co0000
2_ooool2o`0000Cooooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o00003ooo
ool2o`0000;ooooo0_l000000ooooooo0000o`000004o`000003ooooool0003o000000Cooooo0_l0
000>ooooo`?o000000Coooooo`000?l0003o00002OoooolMo`000003ooooool0003o000000Cooooo
0_l000000ooooooo0000o`000002o`000003ooooool0003o000000?o000000?oooooo`000?l00000
0_l00007ooooo`;o00000_ooool2o`0000Oooooo0_l0000<ooooo`;o00001Oooool2o`0000_ooooo
0_l0001<ooooo`007?ooool00ol0003oooooooooo`1Kooooo`;o00001Oooool2o`0000;ooooo0_l0
0007ooooo`;o00003_ooool3o`0000;ooooo0_l00009oooooago00000oooool2o`0000;ooooo1?l0
00001?oooooo0000o`000?ooool5o`000003ooooool0003o000000?o00001_ooool3o`000003oooo
ool0003o000000?ooooo0_l00002ooooo`;o00001Oooool2o`0000;ooooo0_l00008ooooo`Co0000
Eoooool001cooooo00?o0000ooooooooool0B_ooool2o`0000Gooooo0_l00005ooooo`;o000000?o
ooooo`000?l000003_ooool2o`0000;ooooo0_l00004ooooo`;o00003Oooool2o`0000?ooooo0ol0
0009ooooo`co000000?oooooo`000?l000002?l00003ooooo`Go000000Coooooo`000?l0003ooooo
0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o000000Oooooo0_l000001?oooooo0000
o`000?ooool4o`0000Sooooo0ol00002ooooo`?o00001oooool4o`000003ooooool0003o000000;o
oooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o00001Oooool2o`000003oooo
ool0003o000000Co00004Oooool2o`0000;ooooo0_l00004ooooo`;o00003Oooool2o`0000?ooooo
0ol00009ooooo`co000000?oooooo`000?l000001ol00002ooooo`;o000000?oooooo`000?l00000
0ol00003ooooo`;o00002Oooool3o`0000Cooooo1?l00002ooooo`;o000000?oooooo`000?l00000
2Oooool4o`0000;ooooo0ol00006ooooo`Go000000?oooooo`000?l000000_ooool2o`00013ooooo
0_l0000nooooo`007?ooool00ol0003oooooooooo`1Dooooo`Co0000:oooool2o`0000Kooooo0_l0
0004ooooo`;o000000?oooooo`000?l000006Ol00003ooooo`?o00000oooool2o`0000Wooooo0ol0
0004ooooo`Co00000_ooool2o`0000[ooooo1_l00004ooooo`;o00001Oooool5o`0001Oooooo0_l0
000nooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o00001_ooool2o`0000Cooooo0_l0000<
ooooo`;o000000?oooooo`000?l000005?ooool2o`0000Kooooo0_l00004ooooo`;o000000?ooooo
o`000?l000005ol0000Gooooo`;o00001_ooool2o`0000Oooooo0_l00005ooooo`Co00001_ooool2
o`0000;ooooo2?l0001Gooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o00001_ooool2o`00
00?ooooo0ol00006ooooo`;o00000oooool6o`0001Gooooo0_l0000>oooooaOo00002_ooool2o`00
00Oooooo1?l00002ooooo`;o00003oooool2o`0001?ooooo2?l0000Eooooo`;o0000@?ooool001co
oooo00?o0000ooooooooool0C?ooool2o`0000gooooo0ol00006ooooo`;o00000oooool2o`000003
ooooool0003o000001Kooooo0_l000001?oooooo0000o`000?l00005ooooo`;o00000ooooolHo`00
00Wooooo0_l00007ooooo`Co00000_ooool6o`0000Kooooo0_l00008ooooo`;o00001?ooool2o`00
00[ooooo1_l0000Eooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0C?ooool2o`0000Wo
oooo0_l000000ooooooo0000o`00000Booooo`;o00005oooool3o`0000Gooooo0_l00002oooooaWo
00001_ooool4o`00013ooooo1_l00004ooooo`;o00000_ooool2o`0000?ooooo0ol00002ooooo`Go
00001_ooool2o`000003ooooool0003o000005_ooooo000Looooo`03o`000?oooooooooo05Oooooo
0_l000000ooooooo0000o`000004ooooo`;o00000_ooool2o`0000Sooooo0_l00003ooooo`?o0000
4Oooool4o`0000;ooooo0_l00004oooooaOo00002?ooool4o`0000Kooooo0_l00006ooooo`;o0000
1?ooool2o`0000Kooooo1?l00003ooooo`;o00000oooool2o`000003ooooool0003o000000Kooooo
0_l0001Nooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00002Oooool2o`0000?ooooo0_l0
0005ooooo`;o00004?ooool2o`0000;ooooo0_l0000=ooooo`?o00004Oooool5o`000005ooooool0
003o0000o`000?ooool00_l000001?oooooo0000o`000?oooolDo`00017ooooo0_l00006ooooo`Co
00002_ooool4o`00023ooooo0_l0001Aooooo`007?ooool2o`0003Sooooo0_l00009ooooo`;o0000
0oooool2o`0000Gooooo0_l0000Gooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo
0_l0000Aooooo`;o000000?oooooo`000?l000001?l000000ooooooo0000o`000005oooooa?o0000
2Oooool2o`00013ooooo0_l0000<ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Cooooo
0_l0000<ooooo`;o0000DOooool001cooooo00?o0000ooooooooool0E?ooool2o`00017ooooo0_l0
00000ooooooo0000o`000003ooooo`;o00000_ooool2o`0000Cooooo0_l0000<ooooo`;o00000ooo
ool2o`0000Cooooo0_l00005oooooa;o00001Oooool2o`0000;ooooo0_l00007ooooo`;o000000?o
ooooo`000?l000001Oooool3o`0000gooooo0_l00007ooooo`Co00000_ooool4o`000003ooooool0
003o000005cooooo000Looooo`03o`000?oooooooooo05Cooooo0_l00005ooooo`;o00002_ooool2
o`0000[ooooo0_l00004ooooo`;o00001?ooool3o`0000Gooooo0_l00009ooooo`;o000000Cooooo
o`000?l0003ooooo4_l00006ooooo`;o00002oooool2o`000003ooooool0003o000000Gooooo1?l0
000;ooooo`;o00002?ooool4o`0000;ooooo0_l00003ooooo`;o00001?ooool2o`0000;ooooo0_l0
001Booooo`007?ooool00ol0003oooooooooo`1>ooooo`;o00001Oooool2o`0000Cooooo0_l00004
ooooo`Go000000?oooooo`000?l000000_l00006ooooo`;o00001oooool2o`0000?ooooo0ol0000;
ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000002?l0
0002ooooo`Go00004_ooool2o`0000?ooooo0_l00004ooooo`;o00002Oooool4o`0000Kooooo0_l0
0002ooooo`;o00000_ooool4o`0000Oooooo0_l00002ooooo`;o0000D_ooool001cooooo00?o0000
ooooooooool0?oooool2o`0000gooooo0_l000000ooooooo0000o`000002ooooo`;o00002_ooool5
o`0000;ooooo0ol00006ooooo`;o00001oooool2o`0000Cooooo0_l00003ooooo`;o00001?ooool4
o`0000?ooooo0_l00003ooooo`;o00000oooool8o`000003ooooool0003o000000Go00004_ooool2
o`0000?ooooo0_l00003ooooo`;o00002_ooool2o`0000?ooooo1ol00006ooooo`Co0000Goooool0
01cooooo00?o0000ooooooooool0?oooool2o`0000_ooooo0_l00003ooooo`;o00002oooool2o`00
00?ooooo0_l0000Gooooo`;o00001oooool2o`0000Cooooo0ol00003ooooo`?o00000oooool2o`00
00?ooooo3?l000001?oooooo0000o`000?ooool2o`0001[ooooo0_l0000?ooooo`Oo000000?ooooo
o`000?l000001Oooool2o`0000;ooooo0_l0000Aooooo`;o0000B?ooool001cooooo00?o0000oooo
ooooool0C?ooool2o`0000Sooooo1?l00003ooooo`?o00003Oooool2o`0000gooooo0_l0000Coooo
o`;o00002oooool7o`000003ooooool0003o000000Cooooo0_l0000Looooo`;o00003Oooool2o`00
00?ooooo0_l000000ooooooo0000o`000009ooooo`;o00001oooool2o`0000Sooooo0_l00018oooo
o`007?ooool00ol0003oooooooooo`1Dooooo`Ko00000oooool2o`0000Gooooo0_l00006ooooo`Co
00003?ooool2o`0000?ooooo0_l0000Mooooo`Go000000?oooooo`000?l000000_l00003ooooo`;o
00004?ooool4o`0000Gooooo1?l00008ooooo`;o00000oooool2o`0000;ooooo0_l0000;ooooo`;o
00001oooool4o`0005;ooooo000Looooo`03o`000?oooooooooo04gooooo0_l00004ooooo`?o0000
3_ooool2o`0000Kooooo1?l00007ooooo`;o00000oooool2o`0000?ooooo0_l0000Kooooo`;o0000
0_ooool5o`000003ooooool0003o000000?ooooo0_l0000:ooooo`;o000000Coooooo`000?l0003o
oooo1?l00005ooooo`;o00002_ooool2o`0000Oooooo0_l000000ooooooo0000o`000008ooooo`;o
00001oooool4o`0005;ooooo000Looooo`03o`000?oooooooooo04gooooo0_l00004ooooo`;o0000
2?ooool2o`0001Sooooo0_l00002ooooo`?o00001oooool2o`0001Oooooo0_l00005ooooo`;o0000
1_ooool2o`0000[ooooo0_l000000ooooooo0000o`000002ooooo`;o00004_ooool2o`0000[ooooo
0_l00008ooooo`;o00002Oooool2o`0005;ooooo000Looooo`03o`000?oooooooooo04cooooo0_l0
0006ooooo`;o00001oooool2o`0000?ooooo0_l0000>ooooo`Co00001Oooool5o`0000Gooooo0_l0
000Dooooo`?o00003_ooool2o`0001;ooooo0_l000000ooooooo0000o`00000;ooooo`?o000000?o
ooooo`000?l000002_ooool4o`0000;ooooo0ol0001Pooooo`007?ooool00ol0003oooooooooo`1:
ooooo`Co00001_ooool2o`0000cooooo0_l0000>ooooo`Co00001oooool3o`0001_ooooo0ol00004
ooooo`;o00001_ooool4o`0000Kooooo0_l00003ooooo`;o00001Oooool5o`0000?ooooo0_l00003
ooooo`;o000000Coooooo`000?l0003o00003_ooool3o`0000;ooooo0ol00007ooooo`;o0000Eooo
ool001cooooo00?o0000ooooooooool0B_ooool2o`00037ooooo0_l0000Cooooo`;o00003_ooool2
o`0000Kooooo1?l00006ooooo`;o00000oooool2o`0000Oooooo0_l00003ooooo`?o00000oooool2
o`0000_ooooo0ol00004ooooo`Co00002oooool2o`0005Oooooo000Looooo`03o`000?oooooooooo
05;ooooo1?l00008ooooo`;o00002?ooool2o`0000oooooo0_l00003ooooo`?o00003Oooool2o`00
00;ooooo0_l0000Gooooo`;o00004oooool2o`0000Gooooo0_l0000Aooooo`?o00001_ooool2o`00
00Wooooo0_l0001Iooooo`007?ooool00ol0003oooooooooo`1Booooo`Co00002?ooool2o`0000So
oooo0_l00008ooooo`;o00001Oooool2o`0000?ooooo0ol0000=ooooo`;o00004oooool2o`0000Ko
oooo0_l00008ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo0_l0000Jooooo`;o
00001?ooool2o`0000Oooooo0_l000000ooooooo0000o`00001Iooooo`007?ooool00ol0003ooooo
ooooo`1Booooo`;o00007_ooool2o`0000[ooooo0_l0000Iooooo`;o00002?ooool2o`00013ooooo
0_l00002ooooo`;o000000?oooooo`000?l000007_ooool2o`0000Cooooo0_l00007ooooo`;o0000
G?ooool001cooooo0_l0001Sooooo`;o00003?ooool5o`0000Wooooo1?l0000:ooooo`;o00002ooo
ool2o`0000Oooooo0_l000000ooooooo0000o`000002ooooo`;o00004Oooool2o`0000Oooooo0_l0
0005ooooo`;o00006Oooool2o`00063ooooo000Looooo`03o`000?oooooooooo06;ooooo0_l0000<
ooooo`Ko000000?oooooo`000?l000001oooool2o`0000[ooooo0_l0000;ooooo`;o00001oooool2
o`000003ooooool0003o000000;ooooo0_l0000Jooooo`;o00000_ooool2o`000003ooooool0003o
000000Cooooo0_l00002ooooo`;o00002_ooool2o`0000?ooooo0_l000000ooooooo0000o`00001M
ooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o00005Oooool2o`000003ooooool0003o0000
00Kooooo1?l00005ooooo`;o00001Oooool2o`0001[ooooo0_l0000=ooooo`Co00002oooool2o`00
00Oooooo0_l00002ooooo`;o00002_ooool2o`000003ooooool0003o000000?ooooo0_l0001Moooo
o`007?ooool00ol0003oooooooooo`1Mooooo`;o000000?oooooo`000?l000004_ooool2o`0000Wo
oooo1?l00003ooooo`Co00001?ooool4o`0000Gooooo0_l0000Booooo`;o00001oooool4o`0000;o
oooo1?l00009ooooo`;o00007?ooool3o`000003ooooool0003o000005kooooo000Looooo`03o`00
0?oooooooooo05Gooooo0_l00007ooooo`Co00005_ooool2o`0000Cooooo1_l00002ooooo`;o0000
1_ooool4o`0000Gooooo0_l00005ooooo`;o00005?ooool4o`0000;ooooo0_l0000;ooooo`;o0000
7Oooool2o`000003ooooool0003o000005kooooo000Looooo`03o`000?oooooooooo05Gooooo0_l0
0007ooooo`;o00003Oooool5o`0000Cooooo1_l00002ooooo`;o00000_ooool2o`0000Kooooo0_l0
000Booooo`;o00006_ooool2o`0000Sooooo0_l0000Eooooo`Go0000JOooool001cooooo00?o0000
ooooooooool0EOooool2o`000003ooooool0003o000001?ooooo1Ol00004ooooo`Oo00003Oooool2
o`0000gooooo0_l0000Booooo`;o00004?ooool2o`0000;ooooo0ol0000Cooooo`Oo0000JOooool0
01cooooo00?o0000ooooooooool0F?ooool2o`0000Oooooo0_l00005ooooo`?o00001?ooool2o`00
00Kooooo0_l00002ooooo`;o00002Oooool2o`00017ooooo0_l0000:ooooo`;o00001_ooool2o`00
00[ooooo0_l00004ooooo`?o000000?oooooo`000?l000000oooool2o`0000Kooooo1?l00005oooo
o`;o00002_ooool2o`0006;ooooo000Looooo`03o`000?oooooooooo067ooooo0_l00005ooooo`?o
00006oooool2o`0001;ooooo1?l00005ooooo`Co00000_ooool2o`0000Kooooo0ol00005ooooo`;o
00001?ooool3o`0000Kooooo0ol00005ooooo`Co00000oooool2o`0000Wooooo0_l000000ooooooo
0000o`00001Rooooo`007?ooool00ol0003oooooooooo`1cooooo`;o000000?oooooo`000?l00000
2?ooool2o`0000;ooooo0_l0000Dooooo`Co00001Oooool2o`0000Cooooo0_l00006ooooo`?o0000
0oooool2o`00013ooooo0_l0000<ooooo`;o00001_ooool2o`000003ooooool0003o000006Gooooo
000Looooo`03o`000?oooooooooo05Oooooo0_l0000Jooooo`;o000000?oooooo`000?l000002?oo
ool2o`0000;ooooo0_l00006ooooo`;o00003Oooool2o`0001[ooooo0_l0000;ooooo`Co00003?oo
ool2o`0000Wooooo0_l0001Xooooo`007?ooool00ol0003oooooooooo`1Gooooo`;o00006_ooool2
o`0001Cooooo1ol00003ooooo`;o00001_ooool6o`0001;ooooo0_l0000:ooooo`;o00000oooool4
o`0000cooooo0_l00009ooooo`;o00001?ooool2o`0006;ooooo000Looooo`03o`000?oooooooooo
07Wooooo0_l0000>ooooo`Co000000?oooooo`000?l000000oooool2o`0000Sooooo1?l0000<oooo
o`;o00001?ooool2o`0000[ooooo0_l0000@ooooo`;o00004_ooool2o`0006;ooooo000Looooo`03
o`000?oooooooooo07?ooooo0_l00004ooooo`;o00006oooool2o`000003ooooool0003o0000013o
oooo1?l000000ooooooo0000o`000004ooooo`;o00004?ooool2o`000003ooooool0003o000000Co
oooo1?l0000;ooooo`;o0000Ioooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q
8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo073ooooo0_l00000
0ooooooo0000o`000003ooooo`;o00001_ooool2o`0001Cooooo0_l000000ooooooo0000o`00000@
ooooo`;o00000oooool4o`0000;ooooo0_l00003ooooo`;o00001oooool2o`0000;ooooo0_l00000
0ooooooo0000o`000004ooooo`Co00002?ooool2o`000003ooooool0003o000006Oooooo00001_oo
ooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40
1_ooool00ol0003oooooooooo`1`ooooo`;o00001_ooool2o`0000Kooooo0_l0000Gooooo`?o0000
3oooool2o`0000Gooooo0_l00007ooooo`;o00001oooool2o`0000_ooooo1?l00008ooooo`;o0000
J_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool0L?ooool2o`0000_ooooo0_l0000Kooooo`;o0000
0_ooool2o`0000Kooooo1?l000000ooooooo0000o`000004ooooo`;o00000_ooool2o`0000Wooooo
0_l00004ooooo`;o00002oooool2o`0007Cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oo
oooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000Moooool2o`0000Cooooo
0_l00008ooooo`;o00003Oooool2o`000005ooooool0003o0000o`000?ooool00ol00006ooooo`Co
00001oooool2o`0000;ooooo1?l00007ooooo`;o00001?ooool2o`00087ooooo00000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03
o`000?oooooooooo067ooooo0_l0000Dooooo`;o00001?ooool2o`0000?ooooo0_l00003ooooo`?o
00001_ooool2o`0000Cooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00002_ooool2o`00
00cooooo0_l0000Aooooo`;o0000OOooool00003ooooool@413ooooo00;ooooo00?o410@oooooooo
ool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0HOooool2o`00
01[ooooo0_l00003ooooo`;o00001?ooool2o`0000Kooooo0_l00004ooooo`;o00001oooool2o`00
00Gooooo0_l000000ooooooo0000o`00000Oooooo`;o0000OOooool00006oooooomgMgOoV9RHoooo
oonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0N?oo
ool4o`0000_ooooo0_l00005ooooo`;o00000oooool2o`0000[ooooo0_l000000ooooooo0000o`00
0002ooooo`;o00003oooool2o`0000Sooooo0_l00007ooooo`;o0000OOooool00006ooooooo^k^ko
<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000oooooooo
ool0N?ooool4o`0000Kooooo0_l00003ooooo`;o00000oooool4o`0000?ooooo0_l00007ooooo`Co
00000_ooool2o`0001?ooooo0ol00007ooooo`;o000000?oooooo`000?l00000Poooool001cooooo
00?o0000ooooooooool0L?ooool2o`00013ooooo0_l00008ooooo`;o00003_ooool4o`000004oooo
ool0003o0000o`0000Wooooo1?l00004ooooo`Go00002_ooool2o`000003ooooool0003o000000Go
oooo0_l0001iooooo`007?ooool00ol0003oooooooooo`1`ooooo`?o00004oooool4o`0001?ooooo
0ol000000ooooooo0000o`00000:ooooo`Co00001?ooool4o`0000Gooooo0_l00007ooooo`?o0000
1?ooool2o`0007Wooooo000Looooo`03o`000?oooooooooo077ooooo0_l0000Cooooo`Co00000ooo
ool2o`0000kooooo1?l00006ooooo`;o00003Oooool4o`0000Cooooo0_l00008ooooo`;o00004_oo
ool2o`0006_ooooo000Looooo`03o`000?oooooooooo08Wooooo0_l00002ooooo`;o000000?ooooo
o`000?l000003Oooool2o`0000?ooooo0_l000000ooooooo0000o`00000?ooooo`;o00008_ooool2
o`0006_ooooo000Looooo`03o`000?oooooooooo08Wooooo0_l00005ooooo`Co000000?oooooo`00
0?l000003Oooool2o`000003ooooool0003o0000017ooooo0_l00003ooooo`;o0000R?ooool001co
oooo00?o0000ooooooooool0T_ooool2o`000005ooooool0003o0000o`000?ooool00_l0000Ooooo
o`;o00000oooool2o`0008Sooooo000Looooo`03o`000?oooooooooo08oooooo0_l00005ooooo`Go
00004oooool2o`0001Gooooo0_l00022ooooo`007?ooool00ol0003oooooooooo`2?ooooo`;o0000
1_ooool2o`0001Gooooo0_l0000Eooooo`;o0000P_ooool001cooooo00?o0000ooooooooool0QOoo
ool2o`0000Gooooo0_l0000<ooooo`Oo00001?ooool2o`000:;ooooo000Looooo`03o`000?oooooo
oooo07gooooo0_l00006ooooo`;o00001Oooool2o`0000cooooo1ol00004ooooo`;o0000X_ooool0
01cooooo00?o0000ooooooooool0OOooool2o`0002[ooooo0_l0000>ooooo`;o0000S_ooool001co
oooo0_l0002Zooooo`;o00001?ooool3o`0000Oooooo0ol0002=ooooo`007?ooool00ol0003ooooo
ooooo`2_ooooo`?o00002?ooool2o`0008gooooo000Looooo`03o`000?oooooooooo0:;ooooo1?l0
002Sooooo`007?ooool00ol0003oooooooooo`2Rooooo`Co0000Xoooool001cooooo00?o0000oooo
ooooool0ZOooool2o`0009kooooo000Looooo`03o`000?oooooooooo0:Wooooo0_l0002Nooooo`00
7?ooool00ol0003oooooooooo`2Mooooo`;o00000oooool2o`000:Gooooo000Looooo`03o`000?oo
oooooooo09gooooo0_l00003ooooo`;o0000YOooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`1hooooo`;o0000coooool001cooooo00?o0000oooooooo
ool0N?ooool2o`000<oooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0Qoooool2o`000<3ooooo000Looooo`03o`000?oooooooooo08Oooooo0_l00030
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Booooo`Co0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05
ooooo`?o0000oooooom:ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03
o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?oo
ool00ol0003oooooooooo`3ooooooe;ooooo000Booooo`03oeEEEOmVIVKo00000?ooooooE?ooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:7ooooo00Co410@o`000?l0003ooooo
0_l000000ol@413oooooooooo`0Fooooo`Co000000So410@ooooooooooooV9RHoa0@4?l0003o<S8b
olc<c0?ooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`Go0000S?ooool00:;ooooo00Go0000
ooooooooooooooooo`000009ooooo`Ko00003?ooool00ol0003oooooooooo`02ooooo`05oa0@4?nj
^[[oooooogMgMolb<S800oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoV9RHob4Q8Oo^
k^koooooodA4A02<ooooo`00X_ooool01Ol0003ooooooooooooooooo000001_ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?oV9RHob4Q
8Oo^k^h0SOooool00:;ooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00003?ooool00ol0
003oooooooooo`05ooooo`03ojVYZOl@413ooooo00Gooooo00?oZJVYoa0@4?ooool01?ooool00onH
V9So8B4Qonk^kP2<ooooo`00X_ooool01Ol0003oQhN7oooooonYZJWo000001_ooooo00?o0000oooo
ooooool01?ooool00ol@413o0000okZj^P05ooooo`03oa0@4?l0003o^[Zj00Kooooo00?oMgMgofIV
I_ooool0Roooool00:7ooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Iooooo`03
o`000?oooooooooo00Gooooo00?o^[Zjob4Q8Oooool01Oooool00onj^[[o8B4Qooooo`06ooooo`03
o`000?oooooooooo08[ooooo0032ooooo`03o`000?oooooooooo00;ooooo00Go410@oiRHV?oooooo
^[Zjo`000003ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01Ol0003o^[ZjoooooonHV9So
410@08cooooo0030ooooo`03oeEEEOmVIVKo000000Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03
ooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01OnHV9So410@o`000?lQ8B7oc<c<08cooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1338) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.31983 .50681 Mdot
.31849 .51254 Mdot
.64692 .58644 Mdot
.46029 .42494 Mdot
.80371 .53811 Mdot
.61095 .58008 Mdot
.48942 .69935 Mdot
.47283 .64241 Mdot
.64901 .59884 Mdot
.40164 .66794 Mdot
.45481 .65701 Mdot
.5194 .33467 Mdot
.48202 .67194 Mdot
.44508 .39319 Mdot
.83881 .38407 Mdot
.50237 .44193 Mdot
.31589 .508 Mdot
.69011 .44148 Mdot
.52635 .38933 Mdot
.62066 .55367 Mdot
.29942 .50011 Mdot
.45159 .39654 Mdot
.30041 .56355 Mdot
.44476 .39265 Mdot
.4857 .41741 Mdot
.31785 .56383 Mdot
.26964 .56083 Mdot
.50365 .39642 Mdot
.50041 .37023 Mdot
.46305 .64364 Mdot
.58018 .2873 Mdot
.83344 .42994 Mdot
.41835 .45801 Mdot
.70789 .3007 Mdot
.49454 .6499 Mdot
.29533 .43354 Mdot
.62258 .58383 Mdot
.46297 .67341 Mdot
.46082 .67883 Mdot
.49616 .64092 Mdot
.4644 .65927 Mdot
.30033 .55225 Mdot
.36051 .62181 Mdot
.68384 .64642 Mdot
.46215 .45143 Mdot
.7263 .68405 Mdot
.24909 .50683 Mdot
.43499 .37208 Mdot
.34678 .53733 Mdot
.70494 .47921 Mdot
.61899 .68803 Mdot
.49066 .68857 Mdot
.60718 .55281 Mdot
.11378 .44843 Mdot
.483 .68479 Mdot
.44557 .33383 Mdot
.63458 .58819 Mdot
.46277 .38762 Mdot
.44453 .38841 Mdot
.33144 .30353 Mdot
.42245 .42108 Mdot
.63174 .43018 Mdot
.33755 .58335 Mdot
.5139 .58689 Mdot
.6347 .59897 Mdot
.45448 .67446 Mdot
.31733 .51958 Mdot
.48844 .67195 Mdot
.39773 .35812 Mdot
.589 .58082 Mdot
.43275 .3731 Mdot
.45458 .66153 Mdot
.27235 .54329 Mdot
.48846 .37419 Mdot
.70572 .57075 Mdot
.69277 .75399 Mdot
.60817 .42644 Mdot
.29566 .40744 Mdot
.32587 .30284 Mdot
.73031 .51158 Mdot
.50851 .41891 Mdot
.62985 .34377 Mdot
.69999 .73581 Mdot
.33421 .57302 Mdot
.5108 .44542 Mdot
.69737 .44151 Mdot
.49054 .37857 Mdot
.76625 .66871 Mdot
.42106 .37853 Mdot
.63163 .47625 Mdot
.6551 .60059 Mdot
.33131 .53901 Mdot
.46368 .42729 Mdot
.4798 .36266 Mdot
.36793 .27128 Mdot
.48043 .34527 Mdot
.47007 .4033 Mdot
.35217 .54438 Mdot
.48956 .68831 Mdot
.42817 .35011 Mdot
.61905 .65296 Mdot
.66822 .57788 Mdot
.45632 .43885 Mdot
.63611 .62174 Mdot
.28781 .56782 Mdot
.47838 .36313 Mdot
.46547 .68598 Mdot
.43772 .43009 Mdot
.33874 .73619 Mdot
.30338 .51175 Mdot
.50713 .38418 Mdot
.67773 .42477 Mdot
.25059 .36096 Mdot
.33979 .54065 Mdot
.60497 .65233 Mdot
.51746 .37558 Mdot
.47723 .3956 Mdot
.32644 .51775 Mdot
.6646 .6059 Mdot
.75051 .68534 Mdot
.35383 .5532 Mdot
.47137 .6355 Mdot
.27743 .51551 Mdot
.51896 .34136 Mdot
.62589 .60439 Mdot
.66554 .66171 Mdot
.32045 .70024 Mdot
.6049 .28351 Mdot
.48787 .37962 Mdot
.37452 .62925 Mdot
.65713 .55912 Mdot
.32195 .53407 Mdot
.48765 .66703 Mdot
.497 .46049 Mdot
.29082 .52923 Mdot
.45139 .65582 Mdot
.66869 .43565 Mdot
.55726 .71999 Mdot
.28129 .553 Mdot
.54017 .49243 Mdot
.46062 .70347 Mdot
.50249 .66538 Mdot
.5981 .1994 Mdot
.31998 .52281 Mdot
.63884 .41807 Mdot
.48669 .65505 Mdot
.58807 .25824 Mdot
.45264 .44856 Mdot
.59437 .33663 Mdot
.20993 .58633 Mdot
.68276 .27628 Mdot
.57186 .73745 Mdot
.66278 .40688 Mdot
.44085 .66868 Mdot
.4743 .4151 Mdot
.32788 .5623 Mdot
.30867 .56504 Mdot
.42434 .42359 Mdot
.4869 .42506 Mdot
.43142 .37136 Mdot
.45554 .35316 Mdot
.44977 .29177 Mdot
.50643 .34945 Mdot
.23779 .49283 Mdot
.33177 .54379 Mdot
.46431 .42076 Mdot
.59623 .57967 Mdot
.40614 .41269 Mdot
.45927 .65929 Mdot
.46053 .39353 Mdot
.46322 .42554 Mdot
.43562 .43998 Mdot
.49492 .68236 Mdot
.84755 .47345 Mdot
.22184 .40519 Mdot
.82908 .46538 Mdot
.60023 .467 Mdot
.60175 .602 Mdot
.49388 .38813 Mdot
.64438 .43324 Mdot
.34043 .40563 Mdot
.44384 .42104 Mdot
.25495 .76277 Mdot
.46156 .40259 Mdot
.81463 .51923 Mdot
.41213 .34922 Mdot
.79259 .39734 Mdot
.61791 .33 Mdot
.48654 .40959 Mdot
.39905 .60324 Mdot
.44855 .71227 Mdot
.67483 .56121 Mdot
.46832 .66095 Mdot
.5986 .57375 Mdot
.6428 .58657 Mdot
.51101 .60222 Mdot
.53556 .34901 Mdot
.40288 .4259 Mdot
.43702 .35721 Mdot
.59273 .61311 Mdot
.32912 .58233 Mdot
.67341 .43992 Mdot
.34521 .51597 Mdot
.85069 .59966 Mdot
.70027 .67404 Mdot
.51226 .65882 Mdot
.64357 .44484 Mdot
.66076 .58028 Mdot
.64954 .60872 Mdot
.67462 .41736 Mdot
.45818 .36829 Mdot
.31408 .52634 Mdot
.64118 .21892 Mdot
.38572 .76355 Mdot
.54272 .15133 Mdot
.35002 .54598 Mdot
.39016 .66202 Mdot
.46482 .64688 Mdot
.62847 .57219 Mdot
.47576 .39796 Mdot
.46629 .37162 Mdot
.32595 .49691 Mdot
.43595 .36683 Mdot
.24835 .58093 Mdot
.48305 .40225 Mdot
.55771 .67155 Mdot
.64114 .4526 Mdot
.51427 .60314 Mdot
.63276 .28641 Mdot
.33016 .57123 Mdot
.43511 .23724 Mdot
.63161 .61903 Mdot
.33796 .39706 Mdot
.45178 .67613 Mdot
.65313 .44042 Mdot
.6272 .61269 Mdot
.67755 .43321 Mdot
.51648 .36077 Mdot
.60751 .56236 Mdot
.67112 .40362 Mdot
.55639 .344 Mdot
.43476 .44718 Mdot
.27251 .70342 Mdot
.49238 .64047 Mdot
.34735 .51302 Mdot
.4202 .41087 Mdot
.61224 .61829 Mdot
.47758 .46899 Mdot
.58749 .76575 Mdot
.57284 .66078 Mdot
.66546 .56512 Mdot
.56131 .61362 Mdot
.63599 .43658 Mdot
.63157 .7171 Mdot
.37923 .64518 Mdot
.32612 .51085 Mdot
.48461 .34426 Mdot
.78514 .37244 Mdot
.48717 .65599 Mdot
.42805 .41824 Mdot
.74247 .41326 Mdot
.49466 .66472 Mdot
.46472 .38634 Mdot
.45078 .64944 Mdot
.30739 .56465 Mdot
.29142 .3064 Mdot
.33643 .51874 Mdot
.44597 .35346 Mdot
.47125 .68975 Mdot
.62716 .62786 Mdot
.31745 .55932 Mdot
.44918 .36908 Mdot
.50164 .39486 Mdot
.5575 .55075 Mdot
.4624 .41419 Mdot
.83559 .49373 Mdot
.48531 .40596 Mdot
.63952 .57359 Mdot
.49351 .43552 Mdot
.18498 .40385 Mdot
.49815 .60083 Mdot
.3173 .52118 Mdot
.67359 .57869 Mdot
.64386 .59628 Mdot
.71845 .62372 Mdot
.48875 .62021 Mdot
.52008 .38417 Mdot
.60806 .613 Mdot
.49675 .25728 Mdot
.45148 .69015 Mdot
.41175 .38012 Mdot
.49644 .51252 Mdot
.69273 .48183 Mdot
.61129 .55197 Mdot
.49993 .46843 Mdot
.28547 .56239 Mdot
.46959 .42897 Mdot
.65235 .60987 Mdot
.55132 .39098 Mdot
.51471 .38787 Mdot
.23135 .58607 Mdot
.55698 .55881 Mdot
.47169 .70476 Mdot
.41527 .35042 Mdot
.42677 .40305 Mdot
.60502 .56947 Mdot
.33115 .5687 Mdot
.45205 .69318 Mdot
.30594 .5567 Mdot
.77175 .37649 Mdot
.28526 .70978 Mdot
.52043 .29789 Mdot
.67238 .44703 Mdot
.71174 .44749 Mdot
.77891 .37934 Mdot
.38771 .22689 Mdot
.48198 .22989 Mdot
.71681 .28983 Mdot
.65056 .61626 Mdot
.73568 .42983 Mdot
.64019 .59239 Mdot
.49838 .41841 Mdot
.62535 .6025 Mdot
.77978 .36219 Mdot
.48038 .40274 Mdot
.61911 .5958 Mdot
.40729 .24821 Mdot
.47127 .42597 Mdot
.3248 .51237 Mdot
.83955 .5748 Mdot
.26458 .29001 Mdot
.56561 .65619 Mdot
.63877 .56062 Mdot
.52338 .22739 Mdot
.46967 .4053 Mdot
.49535 .43335 Mdot
.33468 .5545 Mdot
.45078 .46949 Mdot
.62736 .41333 Mdot
.63241 .43922 Mdot
.41878 .69052 Mdot
.59947 .40057 Mdot
.42016 .34279 Mdot
.32102 .55805 Mdot
.44315 .29842 Mdot
.69579 .54084 Mdot
.71177 .47135 Mdot
.47686 .71787 Mdot
.83871 .57298 Mdot
.25824 .57307 Mdot
.52449 .69357 Mdot
.62396 .51965 Mdot
.33746 .52793 Mdot
.84764 .45395 Mdot
.46833 .66564 Mdot
.28755 .72993 Mdot
.40556 .54424 Mdot
.45811 .37083 Mdot
.4603 .69661 Mdot
.53077 .44186 Mdot
.28202 .2739 Mdot
.36773 .78953 Mdot
.41119 .4879 Mdot
.41738 .3838 Mdot
.67827 .52832 Mdot
.4668 .39483 Mdot
.66371 .73383 Mdot
.49084 .40474 Mdot
.30852 .554 Mdot
.40686 .68824 Mdot
.43472 .6378 Mdot
.19816 .47134 Mdot
.63934 .72565 Mdot
.66134 .40516 Mdot
.48306 .39866 Mdot
.45561 .37162 Mdot
.63563 .40483 Mdot
.29628 .56406 Mdot
.43943 .35951 Mdot
.43696 .23071 Mdot
.47268 .36097 Mdot
.46099 .66442 Mdot
.3863 .55969 Mdot
.23853 .53807 Mdot
.47453 .3528 Mdot
.29294 .57574 Mdot
.50719 .67809 Mdot
.47255 .68699 Mdot
.42089 .33876 Mdot
.48922 .63452 Mdot
.45426 .40617 Mdot
.40195 .80816 Mdot
.27966 .54396 Mdot
.26359 .62363 Mdot
.29662 .53451 Mdot
.28762 .4009 Mdot
.49546 .67458 Mdot
.57709 .68585 Mdot
.54393 .40478 Mdot
.47184 .66816 Mdot
.30755 .49148 Mdot
.49225 .44518 Mdot
.45673 .45806 Mdot
.60402 .21929 Mdot
.64796 .57088 Mdot
.55208 .57256 Mdot
.46395 .64266 Mdot
.43646 .37979 Mdot
.49414 .35308 Mdot
.5096 .66917 Mdot
.39655 .78905 Mdot
.31127 .26898 Mdot
.48354 .40439 Mdot
.31535 .54704 Mdot
.31785 .53561 Mdot
.41683 .42659 Mdot
.46539 .43797 Mdot
.61578 .60544 Mdot
.64949 .62354 Mdot
.59325 .57367 Mdot
.55158 .58252 Mdot
.57396 .68211 Mdot
.76909 .61079 Mdot
.49658 .64129 Mdot
.37553 .68638 Mdot
.63603 .47326 Mdot
.44016 .3507 Mdot
.64889 .56151 Mdot
.42889 .40482 Mdot
.45054 .4143 Mdot
.50182 .6254 Mdot
.78452 .4787 Mdot
.25478 .5331 Mdot
.31658 .57652 Mdot
.45564 .7035 Mdot
.44261 .32018 Mdot
.5211 .67473 Mdot
.65836 .43653 Mdot
.64182 .24484 Mdot
.45216 .66998 Mdot
.32735 .51442 Mdot
.48779 .64194 Mdot
.47019 .36816 Mdot
.50907 .34488 Mdot
.33308 .52662 Mdot
.62537 .40635 Mdot
.45818 .46775 Mdot
.46841 .38723 Mdot
.20276 .59196 Mdot
.62884 .25442 Mdot
.54354 .69005 Mdot
.48461 .40884 Mdot
.4916 .3601 Mdot
.65719 .39108 Mdot
.47171 .36194 Mdot
.42142 .38882 Mdot
.25779 .361 Mdot
.33981 .71034 Mdot
.63495 .44399 Mdot
.41116 .80436 Mdot
.35057 .54282 Mdot
.80901 .39979 Mdot
.62162 .56607 Mdot
.4145 .65162 Mdot
.27324 .30081 Mdot
.60394 .55405 Mdot
.56932 .74285 Mdot
.82156 .42094 Mdot
.54785 .62605 Mdot
.6785 .61791 Mdot
.26357 .55631 Mdot
.44742 .35526 Mdot
.47542 .39255 Mdot
.63695 .43048 Mdot
.30947 .53134 Mdot
.54307 .55225 Mdot
.57599 .82191 Mdot
.45487 .39777 Mdot
.26101 .60722 Mdot
.48813 .80066 Mdot
.69 .4878 Mdot
.65563 .42456 Mdot
.62076 .42733 Mdot
.48289 .39626 Mdot
.22985 .38568 Mdot
.31927 .5633 Mdot
.44798 .37007 Mdot
.50008 .34571 Mdot
.6421 .56481 Mdot
.29112 .51936 Mdot
.66591 .60264 Mdot
.60385 .69614 Mdot
.82606 .47984 Mdot
.22405 .68896 Mdot
.48658 .68482 Mdot
.62859 .77148 Mdot
.44483 .66359 Mdot
.63736 .34239 Mdot
.64492 .54991 Mdot
.46601 .43276 Mdot
.32665 .57091 Mdot
.43351 .38693 Mdot
.46818 .43672 Mdot
.45629 .36939 Mdot
.47557 .35065 Mdot
.17955 .63215 Mdot
.66893 .40687 Mdot
.53338 .40582 Mdot
.64342 .57754 Mdot
.71436 .71024 Mdot
.67703 .75496 Mdot
.45297 .37509 Mdot
.49526 .3975 Mdot
.28358 .54166 Mdot
.42492 .42152 Mdot
.44475 .67403 Mdot
.35938 .53492 Mdot
.4893 .37025 Mdot
.81832 .60975 Mdot
.50533 .37489 Mdot
.81201 .4247 Mdot
.48407 .64225 Mdot
.34982 .74842 Mdot
.53306 .3703 Mdot
.56151 .64554 Mdot
.55222 .57168 Mdot
.62176 .61029 Mdot
.45555 .63772 Mdot
.62207 .58633 Mdot
.54348 .82855 Mdot
.49817 .33422 Mdot
.47692 .41654 Mdot
.44725 .34449 Mdot
.60111 .60113 Mdot
.78195 .64388 Mdot
.66038 .70419 Mdot
.53031 .35762 Mdot
.60158 .59327 Mdot
.3106 .58377 Mdot
.59137 .23157 Mdot
.29505 .54427 Mdot
.68627 .43097 Mdot
.46278 .65161 Mdot
.624 .41074 Mdot
.74473 .38605 Mdot
.31158 .51074 Mdot
.32688 .50194 Mdot
.6206 .56883 Mdot
.4139 .54656 Mdot
.29396 .21937 Mdot
.40555 .54829 Mdot
.61943 .31048 Mdot
.32897 .55438 Mdot
.49308 .36519 Mdot
.67234 .35698 Mdot
.40777 .57357 Mdot
.62346 .58914 Mdot
.44142 .41369 Mdot
.29258 .30195 Mdot
.61587 .60568 Mdot
.44494 .3436 Mdot
.6473 .57641 Mdot
.46918 .65515 Mdot
.65615 .56713 Mdot
.36264 .51416 Mdot
.49838 .38161 Mdot
.34901 .17364 Mdot
.71256 .40112 Mdot
.4726 .40814 Mdot
.45957 .70867 Mdot
.5001 .76254 Mdot
.4438 .42806 Mdot
.68054 .41574 Mdot
.61013 .59346 Mdot
.41866 .51709 Mdot
.48648 .4046 Mdot
.59968 .59004 Mdot
.31401 .50588 Mdot
.43985 .66017 Mdot
.3609 .27801 Mdot
.55462 .64587 Mdot
.33638 .5545 Mdot
.57239 .47331 Mdot
.47165 .62942 Mdot
.49003 .3592 Mdot
.48501 .34563 Mdot
.31448 .54386 Mdot
.56291 .33488 Mdot
.4678 .44357 Mdot
.50504 .42172 Mdot
.63571 .5671 Mdot
.61798 .587 Mdot
.43332 .25873 Mdot
.65737 .61552 Mdot
.51118 .34697 Mdot
.31191 .54489 Mdot
.46045 .42702 Mdot
.28201 .53522 Mdot
.42621 .42285 Mdot
.51838 .32218 Mdot
.29779 .56524 Mdot
.52657 .63299 Mdot
.44567 .41528 Mdot
.40909 .44782 Mdot
.43468 .42681 Mdot
.44904 .35645 Mdot
.62449 .60734 Mdot
.65511 .43113 Mdot
.47592 .33818 Mdot
.63299 .38823 Mdot
.67412 .43599 Mdot
.43327 .65018 Mdot
.64476 .5663 Mdot
.64211 .40965 Mdot
.50073 .80736 Mdot
.60281 .56314 Mdot
.62978 .42113 Mdot
.67856 .75347 Mdot
.49657 .65318 Mdot
.28097 .55741 Mdot
.47458 .42624 Mdot
.74979 .36559 Mdot
.24058 .51539 Mdot
.67346 .61001 Mdot
.48207 .40666 Mdot
.42998 .41803 Mdot
.34948 .56225 Mdot
.57268 .83994 Mdot
.58911 .58106 Mdot
.5131 .37967 Mdot
.31238 .51523 Mdot
.55993 .85969 Mdot
.63928 .5796 Mdot
.63117 .42584 Mdot
.50048 .65313 Mdot
.26427 .50878 Mdot
.31804 .69987 Mdot
.48268 .70312 Mdot
.65175 .5265 Mdot
.60774 .68834 Mdot
.51656 .37133 Mdot
.64955 .55958 Mdot
.55778 .17046 Mdot
.40594 .32635 Mdot
.52832 .59478 Mdot
.53148 .22753 Mdot
.33871 .53312 Mdot
.44474 .66706 Mdot
.66571 .40741 Mdot
.34703 .55148 Mdot
.31204 .50828 Mdot
.50976 .65667 Mdot
.23664 .39801 Mdot
.4891 .51378 Mdot
.45944 .67292 Mdot
.67852 .29351 Mdot
.77107 .57847 Mdot
.64649 .55978 Mdot
.6281 .41262 Mdot
.75043 .39937 Mdot
.30147 .55466 Mdot
.85081 .5531 Mdot
.60899 .2167 Mdot
.4698 .40336 Mdot
.6457 .41131 Mdot
.78187 .62624 Mdot
.6288 .80953 Mdot
.49436 .67037 Mdot
.42405 .66037 Mdot
.6248 .42279 Mdot
.42073 .41026 Mdot
.58758 .24007 Mdot
.49921 .42468 Mdot
.46661 .64863 Mdot
.3783 .28025 Mdot
.31492 .5092 Mdot
.50669 .65954 Mdot
.63715 .23956 Mdot
.45311 .40477 Mdot
.44503 .41672 Mdot
.65643 .30111 Mdot
.34322 .56117 Mdot
.62126 .61044 Mdot
.51159 .35889 Mdot
.46565 .38985 Mdot
.47064 .33303 Mdot
.41516 .3542 Mdot
.26335 .34132 Mdot
.49844 .41245 Mdot
.69749 .69031 Mdot
.41565 .38601 Mdot
.44263 .40573 Mdot
.28993 .57311 Mdot
.22568 .70025 Mdot
.62768 .6959 Mdot
.46283 .39259 Mdot
.50187 .36702 Mdot
.50556 .65624 Mdot
.43473 .53346 Mdot
.42122 .53464 Mdot
.42258 .51233 Mdot
.503 .22717 Mdot
.42415 .44272 Mdot
.3109 .52298 Mdot
.67214 .40263 Mdot
.51514 .37742 Mdot
.31124 .51995 Mdot
.44786 .44554 Mdot
.61328 .60543 Mdot
.60177 .5644 Mdot
.4217 .3172 Mdot
.64662 .40579 Mdot
.30429 .60563 Mdot
.37113 .68422 Mdot
.60363 .56782 Mdot
.47952 .41768 Mdot
.48936 .61489 Mdot
.65085 .61004 Mdot
.56683 .63519 Mdot
.58087 .37433 Mdot
.32682 .56518 Mdot
.33316 .54139 Mdot
.59214 .33828 Mdot
.57779 .7253 Mdot
.18762 .52887 Mdot
.46849 .65393 Mdot
.53022 .38562 Mdot
.38926 .62929 Mdot
.33632 .54228 Mdot
.6604 .34774 Mdot
.64665 .40873 Mdot
.49468 .66174 Mdot
.69044 .55801 Mdot
.28692 .53514 Mdot
.29271 .51085 Mdot
.41261 .40237 Mdot
.46501 .38056 Mdot
.47354 .23193 Mdot
.65447 .3824 Mdot
.48578 .70254 Mdot
.62678 .41729 Mdot
.64556 .55049 Mdot
.50703 .40423 Mdot
.30215 .56635 Mdot
.75941 .59649 Mdot
.51231 .3718 Mdot
.64216 .60711 Mdot
.33584 .53471 Mdot
.63432 .43591 Mdot
.68049 .41078 Mdot
.45603 .35511 Mdot
.39196 .29168 Mdot
.46701 .67487 Mdot
.33749 .52351 Mdot
.52465 .66961 Mdot
.48898 .43548 Mdot
.47376 .38139 Mdot
.39579 .38337 Mdot
.48458 .70347 Mdot
.41459 .7428 Mdot
.67515 .44207 Mdot
.31522 .52948 Mdot
.49828 .40715 Mdot
.63256 .41091 Mdot
.38829 .69039 Mdot
.66265 .56056 Mdot
.65844 .57099 Mdot
.67752 .40424 Mdot
.65181 .41798 Mdot
.68008 .42619 Mdot
.85173 .55204 Mdot
.3545 .56159 Mdot
.25725 .57046 Mdot
.50785 .42826 Mdot
.61592 .3228 Mdot
.53052 .42774 Mdot
.45703 .70062 Mdot
.65027 .5745 Mdot
.45147 .43368 Mdot
.47131 .35448 Mdot
.42129 .33504 Mdot
.25266 .61049 Mdot
.25214 .51753 Mdot
.29643 .51412 Mdot
.51881 .35155 Mdot
.6342 .56169 Mdot
.85837 .59519 Mdot
.65658 .21327 Mdot
.53164 .36718 Mdot
.48825 .51072 Mdot
.30671 .57027 Mdot
.50073 .64376 Mdot
.69483 .33438 Mdot
.49675 .64993 Mdot
.31925 .52923 Mdot
.50115 .4108 Mdot
.37625 .70162 Mdot
.66324 .39088 Mdot
.43846 .37222 Mdot
.47264 .6456 Mdot
.43173 .37615 Mdot
.48612 .70154 Mdot
.77411 .38973 Mdot
.52251 .18943 Mdot
.46291 .40239 Mdot
.52157 .43274 Mdot
.5005 .21319 Mdot
.44803 .37688 Mdot
.69197 .40367 Mdot
.30666 .57051 Mdot
.3865 .26693 Mdot
.47636 .45542 Mdot
.38837 .32788 Mdot
.49501 .43132 Mdot
.37121 .26056 Mdot
.47224 .37855 Mdot
.68213 .49421 Mdot
.50489 .38395 Mdot
.42446 .3785 Mdot
.47949 .68987 Mdot
.50625 .66049 Mdot
.2722 .55154 Mdot
.61924 .62216 Mdot
.82133 .44328 Mdot
.47114 .3854 Mdot
.58293 .66396 Mdot
.373 .73091 Mdot
.65344 .41978 Mdot
.31384 .53257 Mdot
.61991 .83146 Mdot
.46336 .64061 Mdot
.57644 .20284 Mdot
.44488 .25504 Mdot
.31487 .6623 Mdot
.71709 .38646 Mdot
.49682 .77831 Mdot
.64433 .44088 Mdot
.43746 .44039 Mdot
.77599 .53271 Mdot
.67306 .50056 Mdot
.57354 .36458 Mdot
.46516 .62953 Mdot
.35275 .37491 Mdot
.78578 .49764 Mdot
.68632 .4132 Mdot
.62312 .42593 Mdot
.48958 .69256 Mdot
.6647 .63395 Mdot
.53133 .34597 Mdot
.65179 .41 Mdot
.59491 .59036 Mdot
.6088 .55751 Mdot
.59324 .56658 Mdot
.31566 .56541 Mdot
.62305 .21085 Mdot
.51674 .66455 Mdot
.46927 .70384 Mdot
.5986 .63272 Mdot
.38069 .47124 Mdot
.36521 .53605 Mdot
.62351 .57504 Mdot
.66502 .58997 Mdot
.30039 .56974 Mdot
.44013 .33317 Mdot
.47523 .3223 Mdot
.45878 .39579 Mdot
.64796 .43261 Mdot
.46706 .37589 Mdot
.60399 .59516 Mdot
.49086 .67523 Mdot
.66314 .58631 Mdot
.45558 .70758 Mdot
.75518 .63227 Mdot
.45211 .36376 Mdot
.5014 .38423 Mdot
.21515 .62908 Mdot
.28554 .51128 Mdot
.72591 .67293 Mdot
.54731 .66263 Mdot
.64112 .59018 Mdot
.42121 .39218 Mdot
.35923 .53167 Mdot
.65244 .38425 Mdot
.24161 .69915 Mdot
.46447 .43995 Mdot
.29428 .55457 Mdot
.50567 .40289 Mdot
.44743 .28744 Mdot
.17236 .43899 Mdot
.30412 .54907 Mdot
.21178 .57697 Mdot
.50199 .36952 Mdot
.53996 .79723 Mdot
.41376 .37781 Mdot
.53547 .28402 Mdot
.46807 .44354 Mdot
.35091 .54364 Mdot
.4574 .39271 Mdot
.35603 .52616 Mdot
.61006 .56513 Mdot
.50166 .64767 Mdot
.33596 .55096 Mdot
.47739 .34716 Mdot
.37114 .11682 Mdot
.47524 .65132 Mdot
.47933 .39802 Mdot
.49698 .67594 Mdot
.30536 .53202 Mdot
.34594 .53956 Mdot
.62708 .80204 Mdot
.60475 .69838 Mdot
.47029 .6563 Mdot
.50673 .40363 Mdot
.58323 .77898 Mdot
.48152 .42933 Mdot
.51381 .25189 Mdot
.44553 .33466 Mdot
.49711 .4344 Mdot
.68173 .75753 Mdot
.47093 .70535 Mdot
.1832 .52052 Mdot
.66245 .78403 Mdot
.71219 .71399 Mdot
.30864 .49727 Mdot
.68384 .40596 Mdot
.84877 .46164 Mdot
.57299 .68369 Mdot
.60066 .59395 Mdot
.44291 .4303 Mdot
.37595 .52126 Mdot
.46634 .67937 Mdot
.66179 .43255 Mdot
.46414 .40195 Mdot
.66434 .57888 Mdot
.35435 .2443 Mdot
.4421 .6798 Mdot
.29971 .54821 Mdot
.3306 .57742 Mdot
.41538 .83191 Mdot
.48947 .40885 Mdot
.49667 .37803 Mdot
.46325 .65054 Mdot
.45972 .78017 Mdot
.66005 .44336 Mdot
.40744 .24534 Mdot
.47196 .65712 Mdot
.51377 .54891 Mdot
.31893 .51668 Mdot
.42874 .41484 Mdot
.8193 .57985 Mdot
.70584 .59675 Mdot
.22253 .62146 Mdot
.64369 .43259 Mdot
.5191 .25164 Mdot
.35105 .54125 Mdot
.48747 .66224 Mdot
.54439 .73797 Mdot
.41866 .44106 Mdot
.43043 .40285 Mdot
.52914 .25954 Mdot
.43519 .63968 Mdot
.40697 .49445 Mdot
.47398 .43965 Mdot
.54922 .58395 Mdot
.45118 .43819 Mdot
.45883 .4623 Mdot
.4706 .32888 Mdot
.48354 .38088 Mdot
.29879 .56231 Mdot
.38439 .44705 Mdot
.61259 .61174 Mdot
.28668 .59175 Mdot
.51087 .55631 Mdot
.477 .40601 Mdot
.51105 .41148 Mdot
.34603 .47686 Mdot
.55682 .75931 Mdot
.33427 .54885 Mdot
.33503 .50153 Mdot
.48232 .63363 Mdot
.45769 .32364 Mdot
.6279 .62246 Mdot
.48768 .46211 Mdot
.63252 .60762 Mdot
.30211 .56511 Mdot
.64056 .58623 Mdot
.50197 .65907 Mdot
.63593 .55634 Mdot
.57483 .68208 Mdot
.48521 .64993 Mdot
.33137 .56214 Mdot
.48521 .37117 Mdot
.45822 .70753 Mdot
.60929 .27503 Mdot
.64574 .43194 Mdot
.71066 .76565 Mdot
.49038 .3704 Mdot
.3329 .70986 Mdot
.55779 .39394 Mdot
.66416 .58903 Mdot
.17133 .45008 Mdot
.31386 .57554 Mdot
.62272 .43396 Mdot
.33472 .57057 Mdot
.61606 .23731 Mdot
.64607 .42384 Mdot
.71422 .74165 Mdot
.58297 .52307 Mdot
.62065 .25064 Mdot
.43987 .32962 Mdot
.6445 .28185 Mdot
.62067 .55 Mdot
.46801 .68117 Mdot
.55419 .73951 Mdot
.42304 .38486 Mdot
.42531 .20122 Mdot
.30921 .58078 Mdot
.617 .62035 Mdot
.48744 .6707 Mdot
.45213 .69456 Mdot
.52245 .40067 Mdot
.73413 .48626 Mdot
.42739 .39746 Mdot
.58148 .71347 Mdot
.50934 .23259 Mdot
.23755 .56023 Mdot
.48267 .40191 Mdot
.60585 .56858 Mdot
.50556 .40314 Mdot
.66731 .44999 Mdot
.59886 .19176 Mdot
.44521 .46554 Mdot
.54094 .68392 Mdot
.7116 .40795 Mdot
.32999 .51991 Mdot
.56671 .39381 Mdot
.55519 .68336 Mdot
.49132 .41026 Mdot
.13708 .59286 Mdot
.62995 .4167 Mdot
.77529 .52739 Mdot
.49064 .3552 Mdot
.52124 .38496 Mdot
.4833 .58688 Mdot
.30414 .68577 Mdot
.70333 .57375 Mdot
.44214 .3845 Mdot
.56205 .26817 Mdot
.48136 .7005 Mdot
.42688 .42065 Mdot
.47757 .3937 Mdot
.24079 .43516 Mdot
.44903 .6939 Mdot
.64786 .59285 Mdot
.60675 .55126 Mdot
.67292 .60775 Mdot
.6575 .45165 Mdot
.46216 .72961 Mdot
.64622 .33327 Mdot
.30803 .25991 Mdot
.61753 .41222 Mdot
.47022 .35597 Mdot
.69438 .3844 Mdot
.50259 .41415 Mdot
.66435 .4244 Mdot
.4473 .69117 Mdot
.33846 .54727 Mdot
.39212 .64322 Mdot
.60034 .56152 Mdot
.40523 .42832 Mdot
.65819 .4453 Mdot
.32716 .56307 Mdot
.71523 .36364 Mdot
.3256 .52071 Mdot
.47506 .66542 Mdot
.4846 .72152 Mdot
.66472 .4299 Mdot
.3008 .53184 Mdot
.53103 .686 Mdot
.60582 .81934 Mdot
.48702 .33094 Mdot
.44053 .7362 Mdot
.34739 .52567 Mdot
.34699 .50679 Mdot
.35533 .53376 Mdot
.43748 .36658 Mdot
.49072 .51049 Mdot
.46958 .45031 Mdot
.47334 .70505 Mdot
.64876 .58032 Mdot
.47008 .21211 Mdot
.67415 .66795 Mdot
.54707 .47491 Mdot
.5281 .37182 Mdot
.45138 .40393 Mdot
.4825 .39624 Mdot
.4769 .45669 Mdot
.55526 .71019 Mdot
.43105 .39284 Mdot
.47841 .69092 Mdot
.60915 .59575 Mdot
.4378 .44098 Mdot
.57659 .58845 Mdot
.70706 .7098 Mdot
.62661 .4028 Mdot
.44167 .71759 Mdot
.66192 .20276 Mdot
.32944 .55998 Mdot
.67306 .57879 Mdot
.60041 .58335 Mdot
.66563 .43677 Mdot
.46276 .67097 Mdot
.32221 .52095 Mdot
.50339 .25631 Mdot
.6751 .43385 Mdot
.46054 .39158 Mdot
.47679 .50542 Mdot
.46165 .1908 Mdot
.43717 .43874 Mdot
.4509 .42844 Mdot
.5995 .5504 Mdot
.77405 .50683 Mdot
.42007 .15324 Mdot
.66509 .33054 Mdot
.65965 .43138 Mdot
.65269 .39681 Mdot
.28707 .55996 Mdot
.48988 .4475 Mdot
.47885 .70479 Mdot
.3979 .52909 Mdot
.46835 .74338 Mdot
.35577 .59648 Mdot
.24954 .65199 Mdot
.45389 .43695 Mdot
.42205 .79622 Mdot
.45285 .40788 Mdot
.35442 .56118 Mdot
.30342 .56296 Mdot
.31962 .55313 Mdot
.46864 .68035 Mdot
.30837 .41745 Mdot
.46982 .69071 Mdot
.64079 .1787 Mdot
.34729 .53337 Mdot
.57443 .53436 Mdot
.62759 .56721 Mdot
.52426 .3507 Mdot
.62931 .42966 Mdot
.47877 .7274 Mdot
.3991 .3559 Mdot
.20577 .41042 Mdot
.61325 .61643 Mdot
.33383 .56047 Mdot
.48145 .77355 Mdot
.73642 .29379 Mdot
.42451 .52165 Mdot
.42604 .32627 Mdot
.69862 .33635 Mdot
.65734 .42057 Mdot
.22251 .62308 Mdot
.62563 .42098 Mdot
.47392 .64494 Mdot
.50055 .38857 Mdot
.49033 .37908 Mdot
.44899 .43807 Mdot
.45163 .36897 Mdot
.48583 .62996 Mdot
.48312 .34275 Mdot
.18508 .40371 Mdot
.59771 .57 Mdot
.54633 .3275 Mdot
.62862 .42456 Mdot
.45102 .63866 Mdot
.60801 .59542 Mdot
.55618 .75665 Mdot
.63109 .28928 Mdot
.48515 .40407 Mdot
.44882 .43302 Mdot
.56316 .19429 Mdot
.47628 .43917 Mdot
.54343 .37542 Mdot
.60001 .5919 Mdot
.55166 .45706 Mdot
.62448 .40579 Mdot
.6463 .39677 Mdot
.48735 .64893 Mdot
.29992 .56217 Mdot
.6334 .41784 Mdot
.63139 .5663 Mdot
.52691 .3691 Mdot
.49376 .34632 Mdot
.34795 .52691 Mdot
.57753 .18969 Mdot
.67842 .43864 Mdot
.56837 .78475 Mdot
.32523 .56963 Mdot
.26547 .53765 Mdot
.43052 .40393 Mdot
.2358 .61771 Mdot
.34843 .50106 Mdot
.61733 .43169 Mdot
.45306 .63744 Mdot
.67767 .31801 Mdot
.45275 .65494 Mdot
.29759 .54657 Mdot
.51524 .38625 Mdot
.3135 .56819 Mdot
.48627 .408 Mdot
.76995 .31187 Mdot
.48449 .37773 Mdot
.29178 .2694 Mdot
.57825 .32483 Mdot
.61124 .57693 Mdot
.53714 .7697 Mdot
.62114 .56672 Mdot
.33344 .56723 Mdot
.51644 .37508 Mdot
.64189 .44346 Mdot
.67802 .73942 Mdot
.38303 .5165 Mdot
.65369 .60362 Mdot
.60292 .61966 Mdot
.45282 .65032 Mdot
.46194 .44381 Mdot
.43051 .39966 Mdot
.61831 .59366 Mdot
.23657 .56926 Mdot
.29093 .53217 Mdot
.49812 .39725 Mdot
.4467 .40294 Mdot
.61381 .57463 Mdot
.58772 .82552 Mdot
.37535 .42062 Mdot
.49484 .38768 Mdot
.70275 .64895 Mdot
.45893 .70107 Mdot
.50896 .33941 Mdot
.52707 .42691 Mdot
.65185 .4154 Mdot
.30578 .31822 Mdot
.64351 .22955 Mdot
.44492 .68634 Mdot
.59823 .58009 Mdot
.49379 .40799 Mdot
.60435 .5698 Mdot
.49081 .34462 Mdot
.29861 .67655 Mdot
.6587 .55916 Mdot
.50744 .4206 Mdot
.4286 .33954 Mdot
.34412 .56076 Mdot
.4522 .43546 Mdot
.3309 .46987 Mdot
.63822 .61382 Mdot
.52191 .39633 Mdot
.38696 .2909 Mdot
.45631 .67161 Mdot
.43604 .32995 Mdot
.67595 .41788 Mdot
.49757 .25415 Mdot
.35345 .68315 Mdot
.77803 .45774 Mdot
.64906 .39516 Mdot
.43129 .37861 Mdot
.60597 .61941 Mdot
.49132 .69668 Mdot
.26246 .29435 Mdot
.42194 .40998 Mdot
.4687 .64805 Mdot
.49142 .67311 Mdot
.65717 .43623 Mdot
.24012 .716 Mdot
.48091 .353 Mdot
.45512 .37504 Mdot
.26563 .45554 Mdot
.30052 .50632 Mdot
.47496 .37381 Mdot
.48194 .36117 Mdot
.48043 .69134 Mdot
.4949 .31866 Mdot
.35594 .40503 Mdot
.39021 .2512 Mdot
.50205 .68936 Mdot
.38712 .59336 Mdot
.63269 .55291 Mdot
.64011 .40437 Mdot
.33092 .5293 Mdot
.65318 .44531 Mdot
.64772 .56424 Mdot
.48219 .36294 Mdot
.48332 .63747 Mdot
.28598 .47517 Mdot
.49043 .69166 Mdot
.75966 .43728 Mdot
.33453 .51311 Mdot
.41044 .61253 Mdot
.15969 .63032 Mdot
.6324 .73972 Mdot
.48091 .60896 Mdot
.653 .4196 Mdot
.682 .63452 Mdot
.44802 .40409 Mdot
.22161 .62832 Mdot
.46779 .35721 Mdot
.38227 .28937 Mdot
.59502 .57727 Mdot
.59274 .57451 Mdot
.49823 .38893 Mdot
.506 .23578 Mdot
.49301 .69513 Mdot
.45318 .69191 Mdot
.51317 .41644 Mdot
.47165 .66748 Mdot
.46043 .38062 Mdot
.61128 .60222 Mdot
.1748 .54224 Mdot
.46277 .39793 Mdot
.47941 .45868 Mdot
.30891 .6777 Mdot
.67996 .76514 Mdot
.72354 .43198 Mdot
.47327 .84048 Mdot
.71531 .26874 Mdot
.4725 .66908 Mdot
.4899 .44345 Mdot
.38351 .59518 Mdot
.594 .55805 Mdot
.52277 .69823 Mdot
.47649 .36608 Mdot
.46952 .36041 Mdot
.42306 .37947 Mdot
.44797 .42024 Mdot
.25131 .69359 Mdot
.38918 .52446 Mdot
.30307 .35656 Mdot
.46339 .43688 Mdot
.62488 .27135 Mdot
.48232 .64384 Mdot
.27298 .50479 Mdot
.61398 .41632 Mdot
.45286 .43646 Mdot
.29807 .59033 Mdot
.50244 .64168 Mdot
.63375 .17142 Mdot
.47304 .64307 Mdot
.64301 .59647 Mdot
.50338 .66701 Mdot
.46388 .41371 Mdot
.31787 .53604 Mdot
.44675 .5652 Mdot
.63395 .71332 Mdot
.60105 .59608 Mdot
.47314 .408 Mdot
.55996 .5704 Mdot
.611 .61209 Mdot
.72068 .70149 Mdot
.32558 .53442 Mdot
.56617 .27283 Mdot
.30874 .56694 Mdot
.51782 .40783 Mdot
.51811 .40457 Mdot
.51394 .66501 Mdot
.50316 .66013 Mdot
.30664 .56606 Mdot
.25892 .7468 Mdot
.67993 .43131 Mdot
.31588 .55455 Mdot
.41528 .4404 Mdot
.47493 .52719 Mdot
.31855 .54012 Mdot
.68321 .45058 Mdot
.48743 .68217 Mdot
.27458 .53708 Mdot
.41701 .38086 Mdot
.67545 .28581 Mdot
.67118 .4 Mdot
.63025 .54529 Mdot
.6878 .3602 Mdot
.64498 .61274 Mdot
.45577 .63693 Mdot
.61899 .56744 Mdot
.47769 .70046 Mdot
.35973 .70682 Mdot
.27569 .59021 Mdot
.46374 .60899 Mdot
.46838 .63239 Mdot
.62053 .56933 Mdot
.50381 .39337 Mdot
.71356 .40242 Mdot
.51841 .42143 Mdot
.45644 .3463 Mdot
.46608 .69949 Mdot
.34596 .55214 Mdot
.33988 .49933 Mdot
.59458 .2456 Mdot
.29129 .55531 Mdot
.64481 .60628 Mdot
.20669 .39121 Mdot
.60206 .66444 Mdot
.45106 .66471 Mdot
.50375 .65187 Mdot
.4966 .4252 Mdot
.6225 .5871 Mdot
.59682 .5903 Mdot
.45516 .64916 Mdot
.27769 .62513 Mdot
.51097 .43974 Mdot
.3576 .51328 Mdot
.2941 .50902 Mdot
.30725 .5475 Mdot
.35483 .52972 Mdot
.36724 .40977 Mdot
.49645 .66008 Mdot
.34291 .55722 Mdot
.49429 .42838 Mdot
.47238 .3627 Mdot
.40244 .55876 Mdot
.65977 .39992 Mdot
.43576 .44151 Mdot
.46565 .32864 Mdot
.42975 .41461 Mdot
.65792 .5672 Mdot
.47061 .48079 Mdot
.66392 .56741 Mdot
.59837 .60857 Mdot
.59513 .59893 Mdot
.57253 .6827 Mdot
.55358 .20809 Mdot
.73472 .31829 Mdot
.51266 .37754 Mdot
.46486 .79532 Mdot
.63147 .58147 Mdot
.19016 .42636 Mdot
.41802 .74549 Mdot
.42182 .3975 Mdot
.71093 .58338 Mdot
.61574 .5897 Mdot
.30582 .57236 Mdot
.47998 .37016 Mdot
.67043 .6049 Mdot
.6767 .41469 Mdot
.52255 .40787 Mdot
.65831 .55733 Mdot
.30364 .52975 Mdot
.62029 .43741 Mdot
.27757 .52167 Mdot
.59402 .59635 Mdot
.41993 .3417 Mdot
.19567 .31474 Mdot
.62302 .63085 Mdot
.54552 .8107 Mdot
.51168 .313 Mdot
.50072 .39592 Mdot
.67013 .59274 Mdot
.27072 .52081 Mdot
.45265 .64082 Mdot
.56724 .51043 Mdot
.27998 .5294 Mdot
.59278 .57419 Mdot
.65764 .6034 Mdot
.60044 .59513 Mdot
.29692 .51255 Mdot
.4236 .43839 Mdot
.28418 .5282 Mdot
.50172 .6737 Mdot
.47435 .42839 Mdot
.77936 .38189 Mdot
.44805 .78221 Mdot
.31926 .57107 Mdot
.65262 .59067 Mdot
.65993 .39106 Mdot
.45824 .40589 Mdot
.4489 .78702 Mdot
.50454 .39751 Mdot
.4689 .70242 Mdot
.26702 .35062 Mdot
.28747 .48459 Mdot
.49764 .43501 Mdot
.49373 .42621 Mdot
.45394 .69148 Mdot
.47112 .40411 Mdot
.46651 .44366 Mdot
.57333 .68706 Mdot
.29401 .51881 Mdot
.45389 .39477 Mdot
.64356 .57299 Mdot
.61337 .68209 Mdot
.50132 .4471 Mdot
.64289 .65696 Mdot
.55505 .27336 Mdot
.25786 .36767 Mdot
.46918 .35751 Mdot
.45483 .49963 Mdot
.43963 .41311 Mdot
.44274 .36892 Mdot
.49724 .41996 Mdot
.30632 .75042 Mdot
.65461 .55638 Mdot
.60301 .58124 Mdot
.66041 .39644 Mdot
.55727 .27382 Mdot
.64855 .41195 Mdot
.48991 .68054 Mdot
.7455 .50059 Mdot
.66316 .56583 Mdot
.29665 .53969 Mdot
.43489 .37795 Mdot
.62322 .63065 Mdot
.42789 .41056 Mdot
.46609 .41431 Mdot
.63619 .62167 Mdot
.63663 .5518 Mdot
.78218 .49981 Mdot
.66891 .40256 Mdot
.32492 .55189 Mdot
.4626 .44715 Mdot
.66874 .44251 Mdot
.4761 .35539 Mdot
.61719 .32489 Mdot
.3217 .55043 Mdot
.29052 .52191 Mdot
.34483 .50087 Mdot
.4852 .36515 Mdot
.46245 .40994 Mdot
.46905 .69155 Mdot
.32463 .57321 Mdot
.45698 .66739 Mdot
.55062 .54334 Mdot
.7296 .60596 Mdot
.47627 .36585 Mdot
.42142 .71904 Mdot
.65715 .40549 Mdot
.656 .59861 Mdot
.47383 .19408 Mdot
.66141 .39649 Mdot
.4888 .40645 Mdot
.60945 .61701 Mdot
.66727 .41964 Mdot
.48949 .27317 Mdot
.61558 .18187 Mdot
.64752 .39127 Mdot
.49365 .42882 Mdot
.47191 .31446 Mdot
.46081 .83806 Mdot
.64488 .39407 Mdot
.49909 .64993 Mdot
.48643 .36626 Mdot
.36826 .5499 Mdot
.6542 .44605 Mdot
.68915 .69556 Mdot
.61104 .59223 Mdot
.66718 .2696 Mdot
.38759 .41421 Mdot
.222 .55573 Mdot
.64697 .39912 Mdot
.32116 .52461 Mdot
.55082 .39342 Mdot
.43238 .40686 Mdot
.6506 .39383 Mdot
.49506 .62025 Mdot
.62256 .603 Mdot
.62005 .696 Mdot
.29635 .51237 Mdot
.51207 .62555 Mdot
.6554 .58451 Mdot
.57904 .78265 Mdot
.33678 .27202 Mdot
.4834 .32409 Mdot
.43897 .82365 Mdot
.49135 .74092 Mdot
.41408 .40257 Mdot
.64515 .38687 Mdot
.45401 .70447 Mdot
.48171 .63548 Mdot
.47552 .66131 Mdot
.36854 .72303 Mdot
.4244 .51213 Mdot
.67245 .57008 Mdot
.50804 .69812 Mdot
.64126 .40458 Mdot
.66769 .30751 Mdot
.46285 .34441 Mdot
.45281 .40218 Mdot
.47949 .44374 Mdot
.44619 .43529 Mdot
.43788 .40432 Mdot
.46422 .66502 Mdot
.347 .70323 Mdot
.41525 .52974 Mdot
.31899 .54561 Mdot
.767 .48884 Mdot
.63078 .56991 Mdot
.67021 .56114 Mdot
.67131 .41783 Mdot
.65108 .73772 Mdot
.57617 .58927 Mdot
.64177 .58753 Mdot
.41861 .41957 Mdot
.2872 .53306 Mdot
.53588 .36393 Mdot
.4938 .42736 Mdot
.64098 .60635 Mdot
.50581 .58124 Mdot
.3571 .44707 Mdot
.59216 .39668 Mdot
.60513 .41663 Mdot
.45234 .51759 Mdot
.66605 .39507 Mdot
.51312 .36578 Mdot
.17493 .44854 Mdot
.64826 .56395 Mdot
.63265 .59545 Mdot
.65616 .40168 Mdot
.23019 .6126 Mdot
.33679 .53072 Mdot
.41104 .68648 Mdot
.49165 .68537 Mdot
.51722 .39264 Mdot
.37565 .23718 Mdot
.55221 .34854 Mdot
.72527 .49043 Mdot
.47369 .65521 Mdot
.61129 .56509 Mdot
.53049 .39367 Mdot
.48414 .43186 Mdot
.66083 .4072 Mdot
.80113 .51614 Mdot
.50572 .34002 Mdot
.77629 .66999 Mdot
.52274 .18894 Mdot
.61774 .22873 Mdot
.43059 .40217 Mdot
.29346 .51763 Mdot
.62051 .54652 Mdot
.62927 .41063 Mdot
.40952 .43315 Mdot
.65896 .22444 Mdot
.34475 .52535 Mdot
.48392 .65291 Mdot
.48626 .56358 Mdot
.67679 .32446 Mdot
.44838 .35433 Mdot
.4742 .36074 Mdot
.44561 .3629 Mdot
.54056 .1403 Mdot
.65951 .56477 Mdot
.31195 .57198 Mdot
.66043 .43506 Mdot
.29069 .55011 Mdot
.60923 .57346 Mdot
.4822 .60173 Mdot
.5064 .38869 Mdot
.34195 .52117 Mdot
.32298 .52487 Mdot
.46647 .64342 Mdot
.44201 .65466 Mdot
.51741 .55921 Mdot
.48308 .37808 Mdot
.61127 .62693 Mdot
.34349 .55898 Mdot
.46743 .50594 Mdot
.64575 .422 Mdot
.48566 .68593 Mdot
.45733 .43594 Mdot
.65153 .55891 Mdot
.43432 .34717 Mdot
.33362 .54389 Mdot
.64104 .58733 Mdot
.7559 .59838 Mdot
.63232 .39947 Mdot
.46508 .36589 Mdot
.70165 .41777 Mdot
.59789 .58413 Mdot
.44685 .40609 Mdot
.59688 .78679 Mdot
.68329 .45019 Mdot
.6664 .69956 Mdot
.59978 .60532 Mdot
.56596 .6535 Mdot
.2833 .55513 Mdot
.37935 .74552 Mdot
.63725 .59729 Mdot
.54291 .78708 Mdot
.77891 .57501 Mdot
.53056 .37863 Mdot
.30308 .55541 Mdot
.50011 .73664 Mdot
.80595 .38652 Mdot
.53763 .82414 Mdot
.47907 .397 Mdot
.65746 .61512 Mdot
.66446 .41259 Mdot
.45005 .6703 Mdot
.6941 .64502 Mdot
.62826 .45003 Mdot
.5878 .59255 Mdot
.49725 .41937 Mdot
.31251 .52698 Mdot
.47936 .68464 Mdot
.35692 .68914 Mdot
.63581 .56783 Mdot
.65085 .58118 Mdot
.52837 .40302 Mdot
.64666 .40811 Mdot
.41652 .77347 Mdot
.60753 .60124 Mdot
.54142 .19322 Mdot
.68243 .60961 Mdot
.6748 .43761 Mdot
.44235 .4208 Mdot
.59486 .24064 Mdot
.47868 .45292 Mdot
.62469 .7888 Mdot
.62666 .57029 Mdot
.32847 .54664 Mdot
.433 .3689 Mdot
.41954 .25239 Mdot
.64653 .60469 Mdot
.47694 .51238 Mdot
.68749 .48016 Mdot
.49535 .67103 Mdot
.46945 .19456 Mdot
.46687 .37327 Mdot
.49175 .69598 Mdot
.65934 .40827 Mdot
.48992 .3844 Mdot
.46046 .41205 Mdot
.35013 .56012 Mdot
.46232 .64562 Mdot
.78777 .51685 Mdot
.50618 .65496 Mdot
.48609 .64162 Mdot
.36169 .53705 Mdot
.44973 .38643 Mdot
.64471 .59571 Mdot
.61738 .59039 Mdot
.41664 .37535 Mdot
.15786 .53098 Mdot
.3372 .52726 Mdot
.61326 .54603 Mdot
.52365 .13601 Mdot
.4136 .3685 Mdot
.45381 .20165 Mdot
.80057 .52586 Mdot
.47321 .70706 Mdot
.49303 .42996 Mdot
.30349 .53169 Mdot
.66587 .52073 Mdot
.65098 .58499 Mdot
.42316 .37459 Mdot
.4797 .68247 Mdot
.67517 .40705 Mdot
.62461 .61496 Mdot
.73325 .48828 Mdot
.45088 .36576 Mdot
.70867 .57095 Mdot
.65747 .61141 Mdot
.84827 .48094 Mdot
.5462 .75549 Mdot
.30641 .55748 Mdot
.46569 .41699 Mdot
.3105 .57482 Mdot
.66472 .43355 Mdot
.49054 .56281 Mdot
.48598 .68041 Mdot
.39096 .47484 Mdot
.17858 .39759 Mdot
.59979 .59405 Mdot
.31366 .57319 Mdot
.50366 .43096 Mdot
.29055 .67043 Mdot
.46162 .37618 Mdot
.45543 .31281 Mdot
.69397 .37799 Mdot
.45715 .69011 Mdot
.48417 .6981 Mdot
.4502 .41563 Mdot
.66314 .44002 Mdot
.63166 .56767 Mdot
.63236 .60501 Mdot
.84667 .59439 Mdot
.41085 .6025 Mdot
.47125 .23417 Mdot
.46766 .36083 Mdot
.58881 .59886 Mdot
.65109 .67316 Mdot
.46396 .65066 Mdot
.40759 .39257 Mdot
.62594 .62213 Mdot
.68487 .45506 Mdot
.50357 .26546 Mdot
.43563 .40938 Mdot
.45464 .45918 Mdot
.49653 .67776 Mdot
.42205 .50015 Mdot
.60757 .56246 Mdot
.4504 .33681 Mdot
.44374 .61295 Mdot
.50133 .27264 Mdot
.56211 .17184 Mdot
.32478 .55219 Mdot
.72749 .47135 Mdot
.46363 .66566 Mdot
.47234 .46142 Mdot
.64175 .43868 Mdot
.59369 .55603 Mdot
.65373 .55822 Mdot
.49316 .41368 Mdot
.51902 .3671 Mdot
.49752 .20615 Mdot
.29113 .53986 Mdot
.48498 .64549 Mdot
.49371 .37668 Mdot
.39729 .66328 Mdot
.45237 .439 Mdot
.46365 .68861 Mdot
.17823 .3334 Mdot
.51189 .4269 Mdot
.45711 .37633 Mdot
.43079 .77447 Mdot
.28312 .51987 Mdot
.32556 .57584 Mdot
.39736 .21401 Mdot
.4675 .36113 Mdot
.50225 .1943 Mdot
.33002 .5524 Mdot
.33848 .53513 Mdot
.58263 .69746 Mdot
.45737 .40346 Mdot
.40068 .45492 Mdot
.47381 .70416 Mdot
.48973 .64177 Mdot
.2866 .52159 Mdot
.50879 .34013 Mdot
.44228 .67037 Mdot
.32595 .74976 Mdot
.6225 .58539 Mdot
.1683 .46991 Mdot
.33953 .52655 Mdot
.42492 .67795 Mdot
.46855 .65148 Mdot
.64902 .18846 Mdot
.63873 .51885 Mdot
.50414 .39004 Mdot
.4615 .36278 Mdot
.65032 .40256 Mdot
.48051 .44517 Mdot
.59275 .57505 Mdot
.47132 .66674 Mdot
.42194 .27782 Mdot
.31938 .55369 Mdot
.47448 .37929 Mdot
.67836 .72794 Mdot
.73974 .67051 Mdot
.73374 .45652 Mdot
.33039 .52103 Mdot
.3123 .56424 Mdot
.62621 .55938 Mdot
.6559 .61577 Mdot
.43944 .39222 Mdot
.44809 .68082 Mdot
.32367 .57299 Mdot
.46291 .69262 Mdot
.64976 .56528 Mdot
.64415 .59283 Mdot
.64174 .55096 Mdot
.4703 .34377 Mdot
.64442 .58185 Mdot
.74 .60909 Mdot
.51757 .64188 Mdot
.36462 .53635 Mdot
.47541 .17086 Mdot
.36324 .69355 Mdot
.35028 .49522 Mdot
.66061 .44707 Mdot
.59797 .58909 Mdot
.50135 .67796 Mdot
.46152 .42833 Mdot
.43616 .42674 Mdot
.57514 .64952 Mdot
.50307 .68151 Mdot
.66333 .43279 Mdot
.49045 .69483 Mdot
.65768 .43634 Mdot
.68403 .51696 Mdot
.45226 .44258 Mdot
.49652 .34568 Mdot
.46693 .6614 Mdot
.64281 .58408 Mdot
.60577 .58706 Mdot
.63946 .39353 Mdot
.52747 .59272 Mdot
.6121 .61348 Mdot
.34188 .5376 Mdot
.36903 .4366 Mdot
.66131 .60003 Mdot
.47848 .37132 Mdot
.64623 .33698 Mdot
.2189 .6306 Mdot
.4764 .45683 Mdot
.57832 .69344 Mdot
.25096 .49176 Mdot
.42571 .3847 Mdot
.21127 .62176 Mdot
.55269 .65005 Mdot
.28305 .55091 Mdot
.59799 .57202 Mdot
.57971 .62063 Mdot
.47775 .47327 Mdot
.60954 .42227 Mdot
.40655 .41072 Mdot
.33487 .51863 Mdot
.31294 .58302 Mdot
.63147 .24948 Mdot
.57232 .80895 Mdot
.66523 .4166 Mdot
.66869 .41295 Mdot
.63772 .59915 Mdot
.70564 .77479 Mdot
.42617 .32907 Mdot
.66227 .43169 Mdot
.27381 .596 Mdot
.49584 .41796 Mdot
.55017 .28893 Mdot
.58464 .45955 Mdot
.29025 .51785 Mdot
.62224 .26507 Mdot
.64767 .59977 Mdot
.29025 .55525 Mdot
.38986 .65105 Mdot
.43487 .44354 Mdot
.32028 .5509 Mdot
.46596 .69325 Mdot
.57826 .74563 Mdot
.34538 .54287 Mdot
.63311 .33018 Mdot
.44705 .65989 Mdot
.46504 .50757 Mdot
.57875 .24988 Mdot
.40633 .88175 Mdot
.46711 .66735 Mdot
.65789 .60194 Mdot
.61745 .59156 Mdot
.63356 .6046 Mdot
.28939 .54693 Mdot
.59682 .58866 Mdot
.29234 .54179 Mdot
.47105 .82207 Mdot
.24518 .64546 Mdot
.66112 .4307 Mdot
.6204 .69821 Mdot
.30547 .53669 Mdot
.1868 .42214 Mdot
.13436 .53273 Mdot
.49472 .42953 Mdot
.49794 .63758 Mdot
.66185 .42743 Mdot
.76601 .68126 Mdot
.65534 .41591 Mdot
.58876 .21817 Mdot
.22593 .39519 Mdot
.4672 .38243 Mdot
.33474 .41078 Mdot
.62054 .42028 Mdot
.31913 .51567 Mdot
.44839 .40651 Mdot
.59957 .49524 Mdot
.65534 .41184 Mdot
.67842 .4243 Mdot
.44515 .39355 Mdot
.33385 .56063 Mdot
.65296 .59558 Mdot
.49942 .6451 Mdot
.63838 .44413 Mdot
.52456 .33301 Mdot
.45937 .45629 Mdot
.50735 .39756 Mdot
.40876 .55581 Mdot
.66629 .38535 Mdot
.47259 .67007 Mdot
.27085 .73539 Mdot
.61633 .62351 Mdot
.61003 .49926 Mdot
.54731 .18497 Mdot
.55914 .6824 Mdot
.62569 .57191 Mdot
.60523 .57047 Mdot
.43648 .40264 Mdot
.57977 .43339 Mdot
.21106 .41345 Mdot
.54126 .60706 Mdot
.64214 .54892 Mdot
.62716 .60484 Mdot
.30778 .57744 Mdot
.61413 .23215 Mdot
.4131 .44039 Mdot
.44508 .68745 Mdot
.64999 .55601 Mdot
.28748 .68801 Mdot
.64364 .40674 Mdot
.22857 .38081 Mdot
.44826 .44252 Mdot
.50216 .38582 Mdot
.48367 .67396 Mdot
.4712 .69048 Mdot
.6484 .50733 Mdot
.60496 .22624 Mdot
.25534 .49341 Mdot
.33526 .68302 Mdot
.25783 .38011 Mdot
.31367 .58057 Mdot
.31974 .57102 Mdot
.64187 .7207 Mdot
.50501 .64832 Mdot
.4277 .37854 Mdot
.30192 .56394 Mdot
.61263 .50451 Mdot
.37574 .46335 Mdot
.51006 .24767 Mdot
.4658 .20825 Mdot
.48313 .40809 Mdot
.29561 .5227 Mdot
.2857 .51654 Mdot
.32238 .50415 Mdot
.55093 .63918 Mdot
.44255 .38389 Mdot
.48115 .40308 Mdot
.42772 .39004 Mdot
.26526 .64077 Mdot
.44048 .37685 Mdot
.36979 .73859 Mdot
.49732 .55292 Mdot
.32254 .30319 Mdot
.45459 .33407 Mdot
.47298 .71046 Mdot
.45798 .35305 Mdot
.66323 .43933 Mdot
.50505 .41746 Mdot
.50638 .24831 Mdot
.47597 .64856 Mdot
.37504 .42888 Mdot
.3635 .7053 Mdot
.41753 .39246 Mdot
.62234 .43671 Mdot
.46666 .74732 Mdot
.77574 .36484 Mdot
.70709 .3978 Mdot
.34179 .53554 Mdot
.62404 .58017 Mdot
.50133 .67938 Mdot
.63917 .59296 Mdot
.48006 .33948 Mdot
.63334 .72987 Mdot
.77185 .64514 Mdot
.55207 .5514 Mdot
.44632 .43453 Mdot
.39405 .41125 Mdot
.33886 .54078 Mdot
.61594 .62233 Mdot
.35682 .50182 Mdot
.4393 .36372 Mdot
.64789 .43325 Mdot
.65649 .40798 Mdot
.56809 .51277 Mdot
.82313 .51271 Mdot
.30214 .72014 Mdot
.48087 .67478 Mdot
.61288 .6046 Mdot
.62654 .42613 Mdot
.51188 .79289 Mdot
.43936 .66069 Mdot
.45914 .69889 Mdot
.47984 .64734 Mdot
.49665 .36739 Mdot
.65742 .5577 Mdot
.32775 .29973 Mdot
.58926 .58602 Mdot
.47036 .40643 Mdot
.66006 .56891 Mdot
.61851 .62016 Mdot
.62792 .41978 Mdot
.48147 .64524 Mdot
.64219 .56256 Mdot
.51952 .40303 Mdot
.33019 .55721 Mdot
.44922 .62309 Mdot
.56524 .32285 Mdot
.58502 .8039 Mdot
.48682 .28918 Mdot
.30589 .50718 Mdot
.80382 .39379 Mdot
.46294 .70362 Mdot
.27533 .62936 Mdot
.78016 .49353 Mdot
.5134 .37262 Mdot
.1489 .50737 Mdot
.669 .55908 Mdot
.62847 .62057 Mdot
.44258 .4196 Mdot
.67559 .62692 Mdot
.46939 .37877 Mdot
.65476 .57425 Mdot
.6619 .65954 Mdot
.31751 .58997 Mdot
.63978 .57976 Mdot
.45042 .33833 Mdot
.45549 .41278 Mdot
.28984 .52053 Mdot
.6667 .59925 Mdot
.40585 .42978 Mdot
.85495 .57561 Mdot
.46674 .68686 Mdot
.52631 .71077 Mdot
.64739 .3464 Mdot
.46238 .66613 Mdot
.3132 .55383 Mdot
.45968 .34584 Mdot
.66076 .40867 Mdot
.30471 .5357 Mdot
.47762 .25627 Mdot
.63148 .40191 Mdot
.16071 .45808 Mdot
.29082 .51351 Mdot
.65072 .6081 Mdot
.65059 .44134 Mdot
.47991 .4476 Mdot
.5961 .55347 Mdot
.54867 .7659 Mdot
.62767 .57269 Mdot
.43127 .39709 Mdot
.66088 .68748 Mdot
.48659 .64491 Mdot
.48141 .39495 Mdot
.63001 .61911 Mdot
.58105 .68874 Mdot
.50207 .36864 Mdot
.44464 .41363 Mdot
.56599 .18033 Mdot
.24464 .33294 Mdot
.65009 .41973 Mdot
.28746 .50797 Mdot
.49495 .42813 Mdot
.67676 .4239 Mdot
.73225 .55553 Mdot
.49872 .37379 Mdot
.34643 .52649 Mdot
.40884 .37154 Mdot
.66405 .60451 Mdot
.45872 .67315 Mdot
.55076 .58634 Mdot
.67665 .41505 Mdot
.48695 .86884 Mdot
.62894 .55477 Mdot
.49925 .35005 Mdot
.4596 .43952 Mdot
.73001 .38319 Mdot
.28364 .5502 Mdot
.21077 .49451 Mdot
.46484 .36563 Mdot
.26271 .63338 Mdot
.48666 .38518 Mdot
.65769 .54995 Mdot
.33756 .53146 Mdot
.4518 .37551 Mdot
.41765 .62493 Mdot
.48902 .45493 Mdot
.66299 .39841 Mdot
.43859 .78172 Mdot
.43007 .44325 Mdot
.1573 .3944 Mdot
.61936 .47764 Mdot
.64068 .57801 Mdot
.71596 .68039 Mdot
.8559 .61443 Mdot
.37207 .72272 Mdot
.29254 .55068 Mdot
.79695 .57241 Mdot
.64505 .59521 Mdot
.70925 .66872 Mdot
.80099 .38415 Mdot
.45795 .41867 Mdot
.44712 .3548 Mdot
.70947 .34643 Mdot
.5952 .60266 Mdot
.59852 .62031 Mdot
.51762 .35736 Mdot
.4652 .46233 Mdot
.64686 .58747 Mdot
.52135 .3874 Mdot
.49808 .33885 Mdot
.49476 .63638 Mdot
.34237 .52507 Mdot
.45473 .68768 Mdot
.44342 .67324 Mdot
.37442 .77949 Mdot
.62786 .47658 Mdot
.46232 .68557 Mdot
.46065 .70764 Mdot
.54708 .28627 Mdot
.53332 .2286 Mdot
.65152 .44555 Mdot
.83873 .52575 Mdot
.62578 .60293 Mdot
.44793 .38265 Mdot
.29232 .51065 Mdot
.26682 .48947 Mdot
.75281 .56448 Mdot
.18316 .46257 Mdot
.43244 .37141 Mdot
.64858 .60276 Mdot
.5506 .64187 Mdot
.53822 .3666 Mdot
.66473 .61731 Mdot
.48992 .37277 Mdot
.5933 .57022 Mdot
.37954 .33194 Mdot
.54327 .78632 Mdot
.64277 .63437 Mdot
.35918 .51612 Mdot
.49649 .38166 Mdot
.33265 .51749 Mdot
.46313 .65357 Mdot
.65427 .44377 Mdot
.64668 .41845 Mdot
.44581 .40146 Mdot
.41005 .34721 Mdot
.69763 .53778 Mdot
.45774 .40712 Mdot
.49263 .42134 Mdot
.55312 .64909 Mdot
.49503 .4227 Mdot
.43456 .43062 Mdot
.42547 .40468 Mdot
.43314 .36212 Mdot
.48798 .64176 Mdot
.65589 .73504 Mdot
.50172 .46296 Mdot
.4929 .46321 Mdot
.45201 .64309 Mdot
.79467 .51404 Mdot
.44714 .68802 Mdot
.77949 .36128 Mdot
.48007 .70256 Mdot
.64675 .42628 Mdot
.74587 .4132 Mdot
.38582 .39578 Mdot
.35167 .54917 Mdot
.43745 .68239 Mdot
.66565 .43466 Mdot
.47376 .66374 Mdot
.65805 .58126 Mdot
.57571 .17402 Mdot
.28034 .57341 Mdot
.39636 .53671 Mdot
.49598 .72841 Mdot
.60961 .75277 Mdot
.63091 .5573 Mdot
.32499 .51331 Mdot
.35242 .43744 Mdot
.44404 .43546 Mdot
.67647 .42698 Mdot
.44038 .39462 Mdot
.47429 .64104 Mdot
.64403 .60185 Mdot
.51322 .82101 Mdot
.66045 .40697 Mdot
.50255 .17181 Mdot
.60887 .58751 Mdot
.42478 .41857 Mdot
.44259 .67449 Mdot
.40897 .1878 Mdot
.45847 .69342 Mdot
.21427 .45189 Mdot
.29673 .56785 Mdot
.48968 .84409 Mdot
.30094 .54484 Mdot
.55756 .76935 Mdot
.383 .16556 Mdot
.66753 .73639 Mdot
.33179 .56022 Mdot
.50606 .60389 Mdot
.49073 .40833 Mdot
.50759 .39632 Mdot
.52792 .80002 Mdot
.2945 .506 Mdot
.47398 .43697 Mdot
.62073 .6643 Mdot
.51851 .62772 Mdot
.42153 .21736 Mdot
.61694 .5652 Mdot
.47026 .37507 Mdot
.49061 .70629 Mdot
.49916 .68923 Mdot
.60541 .5593 Mdot
.45919 .69998 Mdot
.47889 .40246 Mdot
.30465 .53798 Mdot
.6801 .6446 Mdot
.63712 .42073 Mdot
.73149 .73307 Mdot
.68359 .41886 Mdot
.62504 .57187 Mdot
.51768 .42259 Mdot
.6438 .59216 Mdot
.89754 .56104 Mdot
.48819 .4009 Mdot
.33035 .55102 Mdot
.48753 .42857 Mdot
.49684 .38536 Mdot
.43215 .36601 Mdot
.65337 .58883 Mdot
.60611 .38192 Mdot
.52096 .39636 Mdot
.48741 .67972 Mdot
.28478 .34992 Mdot
.42358 .43433 Mdot
.59696 .63369 Mdot
.53588 .24313 Mdot
.51844 .69442 Mdot
.27498 .54267 Mdot
.6357 .57612 Mdot
.32065 .55674 Mdot
.23412 .60358 Mdot
.3132 .55349 Mdot
.26062 .41452 Mdot
.35482 .41923 Mdot
.42061 .26252 Mdot
.39481 .28815 Mdot
.45565 .58047 Mdot
.29055 .50687 Mdot
.65352 .38212 Mdot
.33041 .56857 Mdot
.2825 .52503 Mdot
.13466 .34463 Mdot
.35676 .54289 Mdot
.4738 .36796 Mdot
.42409 .4309 Mdot
.59849 .7689 Mdot
.60051 .30601 Mdot
.47429 .42964 Mdot
.46937 .43362 Mdot
.63244 .43321 Mdot
.24826 .61405 Mdot
.66601 .70476 Mdot
.22838 .35163 Mdot
.74643 .6527 Mdot
.44268 .39465 Mdot
.49906 .42624 Mdot
.53964 .4108 Mdot
.29409 .24958 Mdot
.3818 .79113 Mdot
.35497 .57865 Mdot
.53624 .41424 Mdot
.65744 .756 Mdot
.43803 .36124 Mdot
.48094 .36077 Mdot
.48597 .40804 Mdot
.64528 .59573 Mdot
.27484 .52994 Mdot
.43557 .35641 Mdot
.71855 .38159 Mdot
.48091 .36376 Mdot
.56339 .68446 Mdot
.60134 .83286 Mdot
.46624 .37289 Mdot
.27483 .55923 Mdot
.50709 .40079 Mdot
.28214 .53939 Mdot
.30857 .51369 Mdot
.53467 .3917 Mdot
.25485 .3842 Mdot
.28842 .56936 Mdot
.46978 .40697 Mdot
.6593 .59204 Mdot
.84454 .48174 Mdot
.43181 .39489 Mdot
.65575 .44493 Mdot
.46333 .36276 Mdot
.63047 .44395 Mdot
.48688 .42317 Mdot
.62494 .55422 Mdot
.24166 .51916 Mdot
.63291 .59693 Mdot
.42375 .81951 Mdot
.63953 .55165 Mdot
.54347 .163 Mdot
.31478 .50611 Mdot
.63711 .69429 Mdot
.20218 .54691 Mdot
.5284 .71772 Mdot
.52393 .49554 Mdot
.45126 .54706 Mdot
.44889 .68303 Mdot
.29422 .56307 Mdot
.30772 .61528 Mdot
.77295 .52197 Mdot
.75389 .45618 Mdot
.61479 .61252 Mdot
.24077 .72013 Mdot
.17465 .51126 Mdot
.51701 .3713 Mdot
.31804 .42937 Mdot
.30635 .37843 Mdot
.43825 .36005 Mdot
.44376 .35027 Mdot
.56444 .58376 Mdot
.52307 .39934 Mdot
.39908 .6704 Mdot
.62074 .57134 Mdot
.66818 .43399 Mdot
.33694 .54637 Mdot
.67571 .40742 Mdot
.77708 .50126 Mdot
.44514 .54544 Mdot
.65469 .57116 Mdot
.43962 .45304 Mdot
.46338 .43108 Mdot
.28477 .53075 Mdot
.37916 .52581 Mdot
.34047 .5632 Mdot
.66266 .42182 Mdot
.616 .57511 Mdot
.22964 .654 Mdot
.45878 .43237 Mdot
.3234 .52624 Mdot
.54118 .48576 Mdot
.49253 .42933 Mdot
.46448 .65754 Mdot
.49426 .4046 Mdot
.33597 .55695 Mdot
.49476 .42283 Mdot
.29954 .54586 Mdot
.62424 .58271 Mdot
.42027 .40403 Mdot
.4381 .41632 Mdot
.45512 .17878 Mdot
.65525 .43256 Mdot
.33751 .51509 Mdot
.59302 .51465 Mdot
.48072 .44056 Mdot
.59471 .70718 Mdot
.48564 .37068 Mdot
.26452 .50545 Mdot
.50494 .36048 Mdot
.53318 .70348 Mdot
.46348 .46898 Mdot
.43464 .38938 Mdot
.58091 .48013 Mdot
.29713 .39215 Mdot
.38031 .39409 Mdot
.45839 .71027 Mdot
.3521 .52339 Mdot
.42698 .21956 Mdot
.69089 .58424 Mdot
.64251 .62416 Mdot
.64577 .29195 Mdot
.42238 .37497 Mdot
.46443 .38224 Mdot
.48231 .72222 Mdot
.66787 .40631 Mdot
.32828 .51948 Mdot
.65751 .43626 Mdot
.49159 .1869 Mdot
.64941 .39758 Mdot
.66487 .55458 Mdot
.71015 .57437 Mdot
.24793 .68566 Mdot
.63012 .43029 Mdot
.3354 .56016 Mdot
.71392 .61691 Mdot
.4127 .39501 Mdot
.61257 .47478 Mdot
.64069 .4309 Mdot
.33304 .8038 Mdot
.43335 .42925 Mdot
.52119 .49455 Mdot
.45754 .68124 Mdot
.63919 .43778 Mdot
.45007 .65824 Mdot
.45858 .42566 Mdot
.66988 .69938 Mdot
.29404 .55208 Mdot
.45758 .64219 Mdot
.43762 .33045 Mdot
.6635 .42783 Mdot
.65482 .55771 Mdot
.47096 .72303 Mdot
.44869 .69723 Mdot
.80539 .50656 Mdot
.49412 .82871 Mdot
.61418 .57756 Mdot
.33875 .26707 Mdot
.48599 .70115 Mdot
.41314 .39993 Mdot
.25593 .61124 Mdot
.50435 .38888 Mdot
.35726 .74658 Mdot
.63273 .57081 Mdot
.62442 .74904 Mdot
.49669 .42602 Mdot
.43355 .37689 Mdot
.28619 .57578 Mdot
.62416 .59651 Mdot
.31628 .53825 Mdot
.34857 .5177 Mdot
.6228 .58355 Mdot
.3039 .55395 Mdot
.62109 .41426 Mdot
.37698 .62155 Mdot
.49144 .68678 Mdot
.49317 .6675 Mdot
.63164 .60536 Mdot
.64143 .5746 Mdot
.64136 .58864 Mdot
.49487 .4043 Mdot
.33368 .52364 Mdot
.47026 .41991 Mdot
.47124 .35688 Mdot
.28803 .33681 Mdot
.27858 .52335 Mdot
.47881 .4134 Mdot
.61166 .49369 Mdot
.58837 .44544 Mdot
.66112 .5879 Mdot
.46033 .68307 Mdot
.63091 .67398 Mdot
.53164 .7675 Mdot
.47416 .37514 Mdot
.65452 .46976 Mdot
.3346 .56303 Mdot
.6599 .41121 Mdot
.6837 .40499 Mdot
.65375 .41761 Mdot
.53891 .66958 Mdot
.31666 .5047 Mdot
.22273 .36219 Mdot
.46742 .37726 Mdot
.41414 .54715 Mdot
.28745 .59741 Mdot
.67491 .51191 Mdot
.46248 .68359 Mdot
.48464 .43137 Mdot
.55099 .57881 Mdot
.35369 .46597 Mdot
.50235 .39145 Mdot
.41784 .42312 Mdot
.74584 .61173 Mdot
.40437 .38919 Mdot
.32614 .57843 Mdot
.41135 .19099 Mdot
.49233 .43918 Mdot
.28126 .68539 Mdot
.74337 .73198 Mdot
.48305 .37556 Mdot
.44056 .36664 Mdot
.44203 .42784 Mdot
.50669 .41458 Mdot
.27898 .56217 Mdot
.58953 .27196 Mdot
.48024 .70535 Mdot
.41346 .54148 Mdot
.49037 .63851 Mdot
.60863 .54963 Mdot
.63306 .74622 Mdot
.29865 .56777 Mdot
.65101 .40263 Mdot
.72696 .70201 Mdot
.3265 .24703 Mdot
.60664 .56328 Mdot
.32455 .74656 Mdot
.64526 .43094 Mdot
.41382 .40654 Mdot
.61995 .42822 Mdot
.66537 .5724 Mdot
.49491 .67013 Mdot
.41646 .43289 Mdot
.32536 .56878 Mdot
.3456 .53881 Mdot
.48419 .43359 Mdot
.67186 .74735 Mdot
.45987 .66056 Mdot
.44841 .69972 Mdot
.50066 .37155 Mdot
.47785 .44792 Mdot
.31394 .54172 Mdot
.61024 .6001 Mdot
.44325 .24379 Mdot
.67229 .41631 Mdot
.46509 .34377 Mdot
.49869 .41879 Mdot
.55478 .18459 Mdot
.48677 .68355 Mdot
.66464 .61295 Mdot
.50979 .36849 Mdot
.32481 .67829 Mdot
.51157 .37123 Mdot
.54089 .39542 Mdot
.65961 .59356 Mdot
.52496 .45361 Mdot
.50556 .35042 Mdot
.26807 .56415 Mdot
.44802 .67276 Mdot
.32454 .54943 Mdot
.25642 .53547 Mdot
.37712 .59066 Mdot
.46699 .65697 Mdot
.48686 .41235 Mdot
.46573 .68049 Mdot
.49933 .37485 Mdot
.51106 .41911 Mdot
.46318 .68826 Mdot
.31514 .53873 Mdot
.79241 .5789 Mdot
.66666 .73131 Mdot
.51081 .41026 Mdot
.52845 .37371 Mdot
.59058 .28609 Mdot
.60593 .38679 Mdot
.44129 .36081 Mdot
.3394 .55313 Mdot
.45073 .42711 Mdot
.45955 .64934 Mdot
.62123 .42095 Mdot
.3315 .5576 Mdot
.60364 .58342 Mdot
.6146 .55906 Mdot
.3668 .71042 Mdot
.60719 .61301 Mdot
.45258 .35132 Mdot
.30025 .49447 Mdot
.26292 .54047 Mdot
.69593 .75357 Mdot
.62056 .58609 Mdot
.65153 .4465 Mdot
.44473 .41153 Mdot
.67607 .28619 Mdot
.49748 .69925 Mdot
.12458 .46031 Mdot
.18548 .42029 Mdot
.61991 .40257 Mdot
.18958 .45532 Mdot
.6273 .55124 Mdot
.49049 .34224 Mdot
.6617 .44345 Mdot
.62532 .55968 Mdot
.51396 .39085 Mdot
.53595 .39511 Mdot
.21167 .48376 Mdot
.42563 .5756 Mdot
.46771 .68313 Mdot
.59646 .59282 Mdot
.6171 .40228 Mdot
.67176 .56402 Mdot
.31807 .50852 Mdot
.44079 .38187 Mdot
.52364 .41619 Mdot
.6048 .59385 Mdot
.62539 .62793 Mdot
.47503 .40927 Mdot
.30864 .57429 Mdot
.56438 .57757 Mdot
.44834 .39504 Mdot
.41279 .59741 Mdot
.31174 .49898 Mdot
.61596 .56877 Mdot
.43456 .38002 Mdot
.60849 .39529 Mdot
.60839 .59137 Mdot
.66173 .58509 Mdot
.49698 .42873 Mdot
.62273 .40985 Mdot
.53068 .39025 Mdot
.48082 .69983 Mdot
.284 .75238 Mdot
.46072 .64755 Mdot
.66446 .65429 Mdot
.42388 .33558 Mdot
.31049 .64796 Mdot
.27779 .54611 Mdot
.61987 .25058 Mdot
.62436 .66624 Mdot
.50561 .3418 Mdot
.83056 .47038 Mdot
.42339 .67701 Mdot
.6991 .7356 Mdot
.73658 .33894 Mdot
.63181 .42473 Mdot
.47477 .66134 Mdot
.44104 .3658 Mdot
.49674 .63677 Mdot
.66666 .44274 Mdot
.42552 .81769 Mdot
.43016 .39005 Mdot
.33776 .53478 Mdot
.47938 .4064 Mdot
.34065 .5295 Mdot
.5013 .42597 Mdot
.51943 .44051 Mdot
.57294 .66167 Mdot
.50724 .26752 Mdot
.5026 .3631 Mdot
.51985 .14242 Mdot
.56116 .45196 Mdot
.6727 .42776 Mdot
.46231 .41769 Mdot
.66976 .61661 Mdot
.50618 .67661 Mdot
.44416 .75952 Mdot
.64652 .59512 Mdot
.45268 .70062 Mdot
.30821 .54965 Mdot
.63047 .57549 Mdot
.60402 .56284 Mdot
.52557 .45395 Mdot
.61862 .41025 Mdot
.48754 .65351 Mdot
.45097 .37425 Mdot
.4309 .38976 Mdot
.3391 .262 Mdot
.75789 .53888 Mdot
.37922 .51825 Mdot
.23029 .31077 Mdot
.35593 .51806 Mdot
.66772 .42965 Mdot
.65254 .59433 Mdot
.46237 .35565 Mdot
.47747 .39574 Mdot
.6073 .69584 Mdot
.32759 .57351 Mdot
.5003 .56416 Mdot
.22734 .5642 Mdot
.60097 .51261 Mdot
.5433 .26413 Mdot
.33795 .549 Mdot
.5433 .26593 Mdot
.66409 .38808 Mdot
.8277 .58305 Mdot
.52821 .275 Mdot
.458 .67866 Mdot
.54851 .27063 Mdot
.32068 .52146 Mdot
.51914 .39327 Mdot
.65499 .60603 Mdot
.61705 .61998 Mdot
.32184 .54355 Mdot
.67697 .58632 Mdot
.62992 .41375 Mdot
.44656 .36631 Mdot
.24042 .332 Mdot
.37423 .68616 Mdot
.62885 .60816 Mdot
.54498 .38392 Mdot
.47894 .647 Mdot
.48459 .4339 Mdot
.62641 .42228 Mdot
.4666 .67199 Mdot
.59775 .22154 Mdot
.50882 .62625 Mdot
.4464 .40867 Mdot
.56227 .18013 Mdot
.46857 .66174 Mdot
.55272 .44904 Mdot
.44703 .38866 Mdot
.47302 .70389 Mdot
.50449 .47383 Mdot
.57587 .74991 Mdot
.54783 .55558 Mdot
.80212 .38473 Mdot
.5351 .54976 Mdot
.64328 .61008 Mdot
.59238 .75313 Mdot
.49666 .74146 Mdot
.50287 .67137 Mdot
.65209 .62281 Mdot
.59875 .43624 Mdot
.44867 .66121 Mdot
.41731 .41334 Mdot
.48708 .3739 Mdot
.39852 .79926 Mdot
.44391 .71703 Mdot
.55227 .7742 Mdot
.40562 .73482 Mdot
.47591 .44213 Mdot
.53089 .39625 Mdot
.47331 .39304 Mdot
.30496 .5806 Mdot
.47587 .68588 Mdot
.47172 .15779 Mdot
.46261 .65616 Mdot
.24849 .35687 Mdot
.63005 .60376 Mdot
.61987 .56342 Mdot
.47047 .37301 Mdot
.50006 .49611 Mdot
.56659 .23292 Mdot
.47554 .4031 Mdot
.62892 .45414 Mdot
.45072 .79168 Mdot
.47964 .44608 Mdot
.28849 .56375 Mdot
.54603 .40106 Mdot
.54068 .34985 Mdot
.49191 .68645 Mdot
.63975 .40972 Mdot
.60862 .23985 Mdot
.49569 .66014 Mdot
.46509 .38339 Mdot
.32143 .65137 Mdot
.49451 .39025 Mdot
.51226 .40488 Mdot
.20135 .41257 Mdot
.67487 .39752 Mdot
.63387 .58775 Mdot
.65415 .42016 Mdot
.2805 .54243 Mdot
.10514 .4339 Mdot
.65475 .39675 Mdot
.57011 .22844 Mdot
.38283 .8025 Mdot
.55117 .27622 Mdot
.33688 .51995 Mdot
.61479 .41946 Mdot
.45746 .66784 Mdot
.84625 .48798 Mdot
.21982 .51052 Mdot
.4151 .6664 Mdot
.45324 .39344 Mdot
.35773 .56022 Mdot
.34779 .54668 Mdot
.45748 .64084 Mdot
.3122 .51357 Mdot
.41733 .46609 Mdot
.51672 .39939 Mdot
.50374 .64992 Mdot
.33713 .67375 Mdot
.46041 .71226 Mdot
.46776 .59935 Mdot
.46192 .413 Mdot
.33322 .55287 Mdot
.46803 .34149 Mdot
.29302 .50152 Mdot
.67193 .59731 Mdot
.46964 .45678 Mdot
.63139 .41103 Mdot
.30572 .66124 Mdot
.6122 .57832 Mdot
.65222 .48479 Mdot
.28355 .5314 Mdot
.53322 .65944 Mdot
.29173 .51979 Mdot
.27278 .51623 Mdot
.44495 .68287 Mdot
.30181 .52965 Mdot
.44157 .36699 Mdot
.5833 .50438 Mdot
.28641 .54195 Mdot
.48445 .66504 Mdot
.64156 .41148 Mdot
.30397 .54624 Mdot
.67136 .63017 Mdot
.44021 .40782 Mdot
.65134 .5818 Mdot
.74062 .4144 Mdot
.35776 .55363 Mdot
.66687 .39382 Mdot
.63149 .62651 Mdot
.67828 .42584 Mdot
.63794 .79576 Mdot
.47418 .6259 Mdot
.2325 .38963 Mdot
.60398 .42965 Mdot
.34983 .55295 Mdot
.74642 .41907 Mdot
.46904 .35833 Mdot
.44183 .40994 Mdot
.64303 .44895 Mdot
.34769 .54711 Mdot
.78944 .65721 Mdot
.47136 .30687 Mdot
.44776 .59629 Mdot
.43883 .65524 Mdot
.54255 .15903 Mdot
.45319 .60251 Mdot
.70367 .78128 Mdot
.49019 .32979 Mdot
.59654 .61859 Mdot
.47657 .38155 Mdot
.60286 .66973 Mdot
.66069 .42781 Mdot
.6116 .64842 Mdot
.5158 .43322 Mdot
.63038 .5829 Mdot
.43175 .41414 Mdot
.57759 .49015 Mdot
.56063 .42088 Mdot
.65665 .44741 Mdot
.70123 .68757 Mdot
.35706 .53601 Mdot
.63761 .42423 Mdot
.6407 .55825 Mdot
.56049 .25211 Mdot
.51495 .39414 Mdot
.41056 .38183 Mdot
.60157 .51243 Mdot
.33519 .52256 Mdot
.64539 .6133 Mdot
.48544 .69414 Mdot
.65052 .4048 Mdot
.46554 .43019 Mdot
.47946 .35639 Mdot
.58762 .70654 Mdot
.47788 .64506 Mdot
.60663 .61797 Mdot
.45278 .68014 Mdot
.6108 .55343 Mdot
.51876 .41222 Mdot
.61031 .56551 Mdot
.44534 .34395 Mdot
.5674 .66291 Mdot
.21846 .39478 Mdot
.29857 .4095 Mdot
.63017 .56918 Mdot
.50782 .23542 Mdot
.47386 .64808 Mdot
.46076 .69734 Mdot
.30775 .75198 Mdot
.21123 .4575 Mdot
.32243 .26114 Mdot
.79707 .44081 Mdot
.49642 .64438 Mdot
.48211 .65191 Mdot
.64984 .57888 Mdot
.30006 .52881 Mdot
.3482 .51365 Mdot
.60777 .55491 Mdot
.64915 .34133 Mdot
.32829 .51964 Mdot
.82868 .51146 Mdot
.39248 .23159 Mdot
.43312 .35405 Mdot
.67621 .5641 Mdot
.65473 .41009 Mdot
.63889 .33003 Mdot
.58293 .48797 Mdot
.43237 .37616 Mdot
.65366 .27332 Mdot
.6215 .60488 Mdot
.45059 .50032 Mdot
.77971 .36636 Mdot
.42513 .40925 Mdot
.44662 .38403 Mdot
.47201 .38714 Mdot
.63072 .3961 Mdot
.22092 .48592 Mdot
.43958 .37467 Mdot
.64885 .34302 Mdot
.48155 .43833 Mdot
.54729 .45088 Mdot
.64874 .41886 Mdot
.5009 .27797 Mdot
.77775 .51705 Mdot
.40982 .19632 Mdot
.56956 .40891 Mdot
.4855 .69545 Mdot
.71571 .39674 Mdot
.45422 .69013 Mdot
.26895 .41242 Mdot
.53874 .28573 Mdot
.36381 .52778 Mdot
.43411 .37281 Mdot
.62454 .57127 Mdot
.34789 .54523 Mdot
.59293 .73069 Mdot
.11602 .39125 Mdot
.48768 .69557 Mdot
.77688 .73729 Mdot
.47251 .70253 Mdot
.60317 .5629 Mdot
.31391 .54276 Mdot
.35694 .40691 Mdot
.40388 .56582 Mdot
.30243 .54854 Mdot
.78031 .62721 Mdot
.35852 .5749 Mdot
.53328 .24726 Mdot
.34299 .56972 Mdot
.48235 .65874 Mdot
.52752 .69684 Mdot
.38361 .43169 Mdot
.47114 .36238 Mdot
.45689 .54472 Mdot
.55012 .23476 Mdot
.46728 .35838 Mdot
.61922 .57303 Mdot
.21919 .40738 Mdot
.64479 .27849 Mdot
.30779 .52754 Mdot
.50034 .62263 Mdot
.44077 .38713 Mdot
.50375 .40868 Mdot
.51654 .39137 Mdot
.19028 .38277 Mdot
.82674 .58662 Mdot
.52081 .39875 Mdot
.49126 .43649 Mdot
.62983 .57861 Mdot
.59959 .4112 Mdot
.70693 .65126 Mdot
.32175 .29251 Mdot
.42178 .3926 Mdot
.64111 .4232 Mdot
.63442 .38909 Mdot
.51416 .3767 Mdot
.62392 .48336 Mdot
.32252 .64463 Mdot
.44955 .37458 Mdot
.22067 .40999 Mdot
.62737 .50953 Mdot
.5949 .60218 Mdot
.60463 .58858 Mdot
.33475 .51547 Mdot
.59881 .58464 Mdot
.63332 .55303 Mdot
.36315 .42484 Mdot
.52005 .55429 Mdot
.4801 .61184 Mdot
.66351 .42022 Mdot
.48283 .39521 Mdot
.38879 .36319 Mdot
.31968 .66834 Mdot
.44559 .67335 Mdot
.32489 .56498 Mdot
.50489 .68176 Mdot
.70636 .40058 Mdot
.37808 .57339 Mdot
.61956 .61006 Mdot
.49896 .65233 Mdot
.51761 .66333 Mdot
.64177 .421 Mdot
.4602 .64424 Mdot
.51323 .68756 Mdot
.45202 .45398 Mdot
.31014 .44514 Mdot
.46907 .40476 Mdot
.72869 .7078 Mdot
.48522 .64707 Mdot
.54575 .684 Mdot
.45811 .37933 Mdot
.60973 .59089 Mdot
.38297 .44944 Mdot
.47725 .36177 Mdot
.60183 .59159 Mdot
.51764 .37335 Mdot
.68246 .4193 Mdot
.2982 .50141 Mdot
.40556 .55392 Mdot
.22241 .70659 Mdot
.61749 .41197 Mdot
.59677 .72443 Mdot
.43593 .36598 Mdot
.54662 .8246 Mdot
.30464 .5433 Mdot
.48429 .35001 Mdot
.61907 .26453 Mdot
.29012 .53842 Mdot
.31798 .55982 Mdot
.4953 .41183 Mdot
.45582 .67879 Mdot
.61271 .57477 Mdot
.64493 .41737 Mdot
.69878 .771 Mdot
.45309 .40066 Mdot
.44197 .42065 Mdot
.64109 .42849 Mdot
.47218 .64557 Mdot
.50859 .36888 Mdot
.73407 .37551 Mdot
.80668 .64416 Mdot
.4634 .7023 Mdot
.41747 .40817 Mdot
.25959 .44677 Mdot
.51894 .32278 Mdot
.48324 .85782 Mdot
.61822 .47653 Mdot
.6364 .58273 Mdot
.39914 .38395 Mdot
.14754 .38745 Mdot
.64258 .40886 Mdot
.32444 .25115 Mdot
.50284 .41205 Mdot
.45927 .43394 Mdot
.33895 .56359 Mdot
.47187 .41673 Mdot
.30676 .57082 Mdot
.20878 .66977 Mdot
.54934 .18069 Mdot
.32245 .51145 Mdot
.35251 .55204 Mdot
.59009 .23778 Mdot
.66716 .66357 Mdot
.31946 .54512 Mdot
.50691 .42392 Mdot
.54001 .3225 Mdot
.38526 .48752 Mdot
.62215 .4339 Mdot
.76847 .46114 Mdot
.4279 .32016 Mdot
.6917 .44232 Mdot
.7992 .52886 Mdot
.42338 .32008 Mdot
.51836 .60244 Mdot
.47842 .69608 Mdot
.42459 .40788 Mdot
.61476 .61947 Mdot
.60635 .61364 Mdot
.47583 .33612 Mdot
.49045 .39597 Mdot
.28099 .53854 Mdot
.66271 .40585 Mdot
.49593 .68817 Mdot
.46566 .43313 Mdot
.60993 .2492 Mdot
.66659 .40318 Mdot
.30521 .51914 Mdot
.27236 .35195 Mdot
.67965 .4395 Mdot
.50887 .45082 Mdot
.45927 .36869 Mdot
.48312 .40815 Mdot
.3788 .41597 Mdot
.47465 .68983 Mdot
.76008 .43501 Mdot
.44128 .44259 Mdot
.48576 .186 Mdot
.44661 .62836 Mdot
.44583 .46034 Mdot
.30905 .51082 Mdot
.49905 .61838 Mdot
.65841 .55562 Mdot
.35864 .59768 Mdot
.44843 .40787 Mdot
.67977 .73071 Mdot
.41667 .80205 Mdot
.66859 .60189 Mdot
.28405 .50905 Mdot
.65862 .41532 Mdot
.47773 .40189 Mdot
.25292 .39006 Mdot
.48378 .37266 Mdot
.68931 .4393 Mdot
.66365 .58757 Mdot
.47602 .69701 Mdot
.70943 .72774 Mdot
.60008 .6031 Mdot
.31994 .55737 Mdot
.66691 .20842 Mdot
.30465 .57086 Mdot
.34362 .51215 Mdot
.28474 .34669 Mdot
.47305 .69133 Mdot
.13245 .41978 Mdot
.22933 .68209 Mdot
.47997 .45165 Mdot
.47072 .64852 Mdot
.32825 .5413 Mdot
.46545 .43878 Mdot
.3686 .52302 Mdot
.30494 .50503 Mdot
.51205 .42113 Mdot
.44117 .42987 Mdot
.57095 .78328 Mdot
.79554 .38993 Mdot
.65975 .41633 Mdot
.27897 .532 Mdot
.40125 .60028 Mdot
.46134 .43935 Mdot
.46639 .37711 Mdot
.49348 .74691 Mdot
.61953 .42042 Mdot
.39503 .67963 Mdot
.50338 .41016 Mdot
.57612 .19651 Mdot
.52789 .44676 Mdot
.28555 .56663 Mdot
.45314 .69193 Mdot
.42001 .19529 Mdot
.46811 .72544 Mdot
.30884 .57057 Mdot
.65238 .40072 Mdot
.26812 .55638 Mdot
.56713 .22595 Mdot
.48061 .63895 Mdot
.33604 .55692 Mdot
.55019 .59074 Mdot
.4754 .67902 Mdot
.49262 .64872 Mdot
.2967 .332 Mdot
.66396 .61693 Mdot
.63279 .39401 Mdot
.48533 .6517 Mdot
.27559 .63361 Mdot
.48101 .66665 Mdot
.24556 .69727 Mdot
.41993 .40625 Mdot
.66277 .32063 Mdot
.64014 .65551 Mdot
.39214 .39175 Mdot
.48638 .64394 Mdot
.63242 .43411 Mdot
.5127 .38965 Mdot
.3187 .51886 Mdot
.67553 .41925 Mdot
.41038 .67425 Mdot
.64696 .5894 Mdot
.29226 .5217 Mdot
.45754 .71692 Mdot
.34363 .53524 Mdot
.31236 .6153 Mdot
.35224 .79477 Mdot
.65573 .24917 Mdot
.40062 .57774 Mdot
.51504 .39665 Mdot
.79648 .4796 Mdot
.4132 .38481 Mdot
.49558 .39632 Mdot
.6178 .5695 Mdot
.65564 .30238 Mdot
.31586 .53878 Mdot
.76008 .6873 Mdot
.49593 .678 Mdot
.42116 .18996 Mdot
.55902 .37421 Mdot
.50416 .35254 Mdot
.28643 .54559 Mdot
.31841 .57579 Mdot
.29366 .38037 Mdot
.6498 .54991 Mdot
.45092 .34811 Mdot
.40994 .4046 Mdot
.50522 .34513 Mdot
.49574 .67255 Mdot
.64948 .4805 Mdot
.64072 .61024 Mdot
.42397 .82929 Mdot
.66392 .59247 Mdot
.68387 .45077 Mdot
.30517 .52637 Mdot
.65433 .39693 Mdot
.46445 .37607 Mdot
.37974 .54007 Mdot
.3273 .57423 Mdot
.65339 .44961 Mdot
.64719 .44085 Mdot
.54668 .74682 Mdot
.4636 .68786 Mdot
.48828 .36132 Mdot
.43575 .37805 Mdot
.47271 .42214 Mdot
.4934 .40322 Mdot
.49193 .68895 Mdot
.51086 .38249 Mdot
.47964 .71666 Mdot
.26307 .60036 Mdot
.70988 .34355 Mdot
.5371 .54498 Mdot
.34751 .74994 Mdot
.31433 .52341 Mdot
.28769 .6375 Mdot
.47775 .31322 Mdot
.16996 .45827 Mdot
.47813 .80995 Mdot
.45178 .44856 Mdot
.61587 .56028 Mdot
.46009 .48551 Mdot
.61762 .61481 Mdot
.6925 .80169 Mdot
.56685 .7016 Mdot
.81606 .42098 Mdot
.43086 .39135 Mdot
.57803 .51069 Mdot
.25695 .64169 Mdot
.41181 .38505 Mdot
.56754 .7193 Mdot
.35097 .74505 Mdot
.69211 .70087 Mdot
.6245 .42192 Mdot
.44131 .40035 Mdot
.38251 .384 Mdot
.44314 .36739 Mdot
.47286 .37858 Mdot
.5142 .38682 Mdot
.46639 .71338 Mdot
.47078 .34967 Mdot
.50743 .38792 Mdot
.70357 .54414 Mdot
.53168 .26502 Mdot
.62037 .62522 Mdot
.33743 .7715 Mdot
.65514 .3964 Mdot
.28368 .53866 Mdot
.82074 .57783 Mdot
.45855 .67916 Mdot
.2987 .37745 Mdot
.48886 .40554 Mdot
.60858 .76614 Mdot
.51309 .64403 Mdot
.64423 .40362 Mdot
.66618 .5719 Mdot
.83598 .44612 Mdot
.62153 .57605 Mdot
.54551 .64754 Mdot
.61129 .58919 Mdot
.46426 .31161 Mdot
.28049 .53786 Mdot
.50071 .36617 Mdot
.48912 .65723 Mdot
.60223 .57685 Mdot
.59907 .29665 Mdot
.4748 .39174 Mdot
.62329 .58439 Mdot
.50039 .36632 Mdot
.39472 .54284 Mdot
.36072 .26513 Mdot
.63274 .55422 Mdot
.51266 .64555 Mdot
.48645 .67695 Mdot
.62513 .40692 Mdot
.28772 .5303 Mdot
.31919 .56834 Mdot
.46802 .67168 Mdot
.20176 .49945 Mdot
.42184 .38723 Mdot
.45328 .43658 Mdot
.44391 .18935 Mdot
.44762 .3593 Mdot
.55 .25305 Mdot
.55369 .56165 Mdot
.31163 .51867 Mdot
.5129 .3582 Mdot
.49649 .4157 Mdot
.4452 .4092 Mdot
.28948 .60283 Mdot
.61053 .60167 Mdot
.42302 .40829 Mdot
.65273 .44128 Mdot
.67816 .53246 Mdot
.48522 .43378 Mdot
.48503 .47189 Mdot
.32157 .56782 Mdot
.22812 .31878 Mdot
.47188 .70148 Mdot
.63744 .55822 Mdot
.63155 .56839 Mdot
.77676 .47256 Mdot
.30202 .6864 Mdot
.55469 .55722 Mdot
.45651 .8399 Mdot
.57238 .66059 Mdot
.66182 .43401 Mdot
.63613 .52768 Mdot
.52027 .7102 Mdot
.6443 .56796 Mdot
.48953 .6945 Mdot
.42028 .41251 Mdot
.42126 .3951 Mdot
.15263 .48171 Mdot
.51514 .37594 Mdot
.65499 .41388 Mdot
.45881 .71304 Mdot
.32109 .52225 Mdot
.64739 .40317 Mdot
.45191 .67998 Mdot
.32692 .51476 Mdot
.4383 .44412 Mdot
.43376 .44031 Mdot
.32211 .56528 Mdot
.34183 .555 Mdot
.4585 .37168 Mdot
.695 .64859 Mdot
.3531 .54636 Mdot
.3381 .55159 Mdot
.62461 .61053 Mdot
.61236 .6167 Mdot
.47692 .46918 Mdot
.47308 .65129 Mdot
.50852 .38688 Mdot
.62831 .57428 Mdot
.64982 .39785 Mdot
.31519 .53605 Mdot
.50918 .4114 Mdot
.48416 .43041 Mdot
.64114 .41947 Mdot
.63292 .4045 Mdot
.62962 .42745 Mdot
.4687 .71757 Mdot
.4637 .4224 Mdot
.31265 .54783 Mdot
.46643 .69178 Mdot
.63484 .38965 Mdot
.62593 .43537 Mdot
.64729 .53623 Mdot
.4557 .35468 Mdot
.68528 .63553 Mdot
.15811 .35686 Mdot
.49363 .19971 Mdot
.67213 .57677 Mdot
.66493 .55952 Mdot
.56977 .30481 Mdot
.45814 .50616 Mdot
.46341 .66176 Mdot
.59801 .40809 Mdot
.60482 .23483 Mdot
.43182 .44506 Mdot
.48826 .44089 Mdot
.52791 .42782 Mdot
.63551 .4335 Mdot
.67016 .30567 Mdot
.29658 .56607 Mdot
.42782 .30077 Mdot
.67126 .40572 Mdot
.62336 .6273 Mdot
.66178 .54256 Mdot
.665 .58862 Mdot
.42306 .42483 Mdot
.30726 .40785 Mdot
.28924 .65872 Mdot
.77681 .41804 Mdot
.48142 .64373 Mdot
.38948 .36244 Mdot
.54473 .82188 Mdot
.31873 .56315 Mdot
.6086 .54897 Mdot
.6612 .43593 Mdot
.34281 .55172 Mdot
.51008 .66809 Mdot
.48416 .65329 Mdot
.63178 .60803 Mdot
.63781 .60508 Mdot
.65641 .57921 Mdot
.30879 .50343 Mdot
.30312 .52797 Mdot
.45075 .40947 Mdot
.31421 .53225 Mdot
.17711 .42554 Mdot
.62791 .44438 Mdot
.59426 .62766 Mdot
.47356 .65824 Mdot
.3329 .51801 Mdot
.47382 .39427 Mdot
.42897 .50214 Mdot
.39134 .7433 Mdot
.67184 .43382 Mdot
.34903 .26241 Mdot
.67486 .80843 Mdot
.48438 .35926 Mdot
.4814 .68685 Mdot
.2447 .32415 Mdot
.46995 .3888 Mdot
.65413 .59677 Mdot
.73073 .63045 Mdot
.64643 .5226 Mdot
.48001 .36246 Mdot
.43191 .44695 Mdot
.47241 .70585 Mdot
.44267 .82835 Mdot
.4531 .40596 Mdot
.38781 .65516 Mdot
.49432 .63093 Mdot
.6478 .60773 Mdot
.86008 .55527 Mdot
.72481 .42554 Mdot
.64621 .33472 Mdot
.63463 .60998 Mdot
.49665 .38393 Mdot
.61364 .61053 Mdot
.66328 .43858 Mdot
.65217 .55992 Mdot
.30092 .57073 Mdot
.66227 .60705 Mdot
.44166 .42115 Mdot
.32181 .5457 Mdot
.46804 .66044 Mdot
.38675 .21344 Mdot
.73444 .58426 Mdot
.61057 .59313 Mdot
.62129 .55508 Mdot
.51496 .36316 Mdot
.4036 .69126 Mdot
.45727 .3377 Mdot
.43098 .4265 Mdot
.49256 .64062 Mdot
.28845 .53688 Mdot
.45597 .69985 Mdot
.41876 .45618 Mdot
.73131 .35207 Mdot
.45426 .68377 Mdot
.67271 .72703 Mdot
.64734 .43169 Mdot
.52294 .51336 Mdot
.47888 .39684 Mdot
.4546 .64992 Mdot
.46219 .42085 Mdot
.28929 .55977 Mdot
.5431 .52258 Mdot
.67315 .70258 Mdot
.49372 .66105 Mdot
.69208 .72954 Mdot
.70854 .36072 Mdot
.44922 .47353 Mdot
.45908 .69714 Mdot
.63087 .27319 Mdot
.60235 .56396 Mdot
.67302 .41595 Mdot
.67971 .43359 Mdot
.67649 .41121 Mdot
.46847 .33102 Mdot
.56741 .39739 Mdot
.67142 .39431 Mdot
.50822 .66846 Mdot
.65691 .44723 Mdot
.26555 .68104 Mdot
.76282 .68031 Mdot
.65762 .42846 Mdot
.44879 .39088 Mdot
.53956 .35717 Mdot
.54756 .28501 Mdot
.56743 .75512 Mdot
.82211 .43915 Mdot
.45382 .77505 Mdot
.47412 .36442 Mdot
.3217 .50032 Mdot
.28915 .51246 Mdot
.26312 .29528 Mdot
.53371 .23239 Mdot
.52536 .19324 Mdot
.35909 .53573 Mdot
.64883 .69134 Mdot
.30076 .51971 Mdot
.51676 .38353 Mdot
.45764 .43753 Mdot
.36047 .53755 Mdot
.70368 .32718 Mdot
.63488 .70527 Mdot
.70536 .74755 Mdot
.34423 .54313 Mdot
.44816 .67468 Mdot
.44552 .65129 Mdot
.49185 .64666 Mdot
.37134 .2386 Mdot
.29124 .55157 Mdot
.47634 .4272 Mdot
.62844 .56852 Mdot
.42375 .39791 Mdot
.4726 .6815 Mdot
.76851 .68073 Mdot
.29735 .54724 Mdot
.43837 .38369 Mdot
.40603 .46681 Mdot
.64354 .59921 Mdot
.6452 .42668 Mdot
.39795 .52199 Mdot
.5245 .19707 Mdot
.49894 .66604 Mdot
.35874 .54946 Mdot
.55531 .67989 Mdot
.72645 .69741 Mdot
.49747 .33229 Mdot
.40867 .40972 Mdot
.69464 .77851 Mdot
.58273 .20764 Mdot
.44532 .35419 Mdot
.62896 .55729 Mdot
.59968 .69473 Mdot
.49389 .42664 Mdot
.28215 .51995 Mdot
.68058 .43644 Mdot
.67763 .42571 Mdot
.47416 .47046 Mdot
.41901 .53727 Mdot
.56648 .51088 Mdot
.48878 .41147 Mdot
.5125 .4475 Mdot
.64429 .60842 Mdot
.58711 .66342 Mdot
.49307 .18631 Mdot
.64678 .39994 Mdot
.50313 .36716 Mdot
.77241 .61271 Mdot
.33912 .56621 Mdot
.66993 .59643 Mdot
.46887 .64021 Mdot
.2957 .59844 Mdot
.66503 .56933 Mdot
.50812 .41847 Mdot
.51217 .37352 Mdot
.44353 .66778 Mdot
.28781 .56794 Mdot
.63826 .43452 Mdot
.62191 .56453 Mdot
.62952 .40903 Mdot
.2903 .54113 Mdot
.30821 .53254 Mdot
.41573 .47031 Mdot
.49357 .32619 Mdot
.60435 .58431 Mdot
.44425 .34376 Mdot
.66161 .52741 Mdot
.52703 .85648 Mdot
.43719 .6812 Mdot
.46872 .3526 Mdot
.32097 .58167 Mdot
.49595 .66499 Mdot
.45205 .43313 Mdot
.72021 .76301 Mdot
.468 .4406 Mdot
.45577 .62455 Mdot
.63635 .22422 Mdot
.62718 .41843 Mdot
.43885 .29866 Mdot
.53873 .79687 Mdot
.45079 .36005 Mdot
.64009 .57105 Mdot
.54307 .38088 Mdot
.45521 .67137 Mdot
.30705 .52721 Mdot
.50763 .86595 Mdot
.4831 .66933 Mdot
.44713 .36889 Mdot
.64952 .40415 Mdot
.33244 .57551 Mdot
.61526 .45927 Mdot
.62654 .48485 Mdot
.53455 .45341 Mdot
.46262 .34327 Mdot
.50008 .40383 Mdot
.74888 .38335 Mdot
.64064 .55987 Mdot
.33575 .54392 Mdot
.48401 .68602 Mdot
.46564 .66919 Mdot
.62416 .60676 Mdot
.47967 .60692 Mdot
.52159 .51462 Mdot
.23627 .27183 Mdot
.60291 .59969 Mdot
.6686 .39759 Mdot
.39598 .66874 Mdot
.62957 .56305 Mdot
.6227 .5884 Mdot
.62591 .6117 Mdot
.53835 .60456 Mdot
.3315 .51939 Mdot
.50637 .42086 Mdot
.2752 .54369 Mdot
.49889 .38437 Mdot
.45796 .62308 Mdot
.49156 .65651 Mdot
.29629 .54221 Mdot
.66965 .78457 Mdot
.28874 .46067 Mdot
.46033 .38774 Mdot
.54758 .82366 Mdot
.51919 .42593 Mdot
.56656 .28406 Mdot
.52967 .41381 Mdot
.61944 .60046 Mdot
.41578 .36016 Mdot
.50048 .34059 Mdot
.29393 .26561 Mdot
.47188 .65554 Mdot
.59249 .59516 Mdot
.49443 .45024 Mdot
.52054 .44163 Mdot
.31844 .50308 Mdot
.34188 .55123 Mdot
.68043 .42894 Mdot
.49601 .26322 Mdot
.46627 .65811 Mdot
.21758 .64373 Mdot
.46883 .36311 Mdot
.69707 .44722 Mdot
.39103 .2876 Mdot
.44803 .43156 Mdot
.55765 .80171 Mdot
.30426 .40055 Mdot
.47822 .40035 Mdot
.45882 .57371 Mdot
.47546 .64698 Mdot
.72061 .32519 Mdot
.48819 .43518 Mdot
.64829 .59636 Mdot
.30163 .52484 Mdot
.3214 .57753 Mdot
.68133 .4124 Mdot
.17134 .50179 Mdot
.45324 .69833 Mdot
.30045 .53389 Mdot
.47997 .3891 Mdot
.47889 .69043 Mdot
.59835 .59097 Mdot
.50074 .35208 Mdot
.51999 .22803 Mdot
.3195 .52808 Mdot
.52285 .3809 Mdot
.37326 .64425 Mdot
.60132 .33417 Mdot
.68194 .24385 Mdot
.48645 .68499 Mdot
.62358 .41107 Mdot
.54308 .40157 Mdot
.20779 .4788 Mdot
.53213 .38764 Mdot
.67203 .33561 Mdot
.2737 .69074 Mdot
.62113 .41881 Mdot
.45458 .38204 Mdot
.46889 .43009 Mdot
.53127 .48365 Mdot
.65181 .39946 Mdot
.43132 .38645 Mdot
.24236 .56747 Mdot
.33766 .52837 Mdot
.60806 .55138 Mdot
.32559 .52224 Mdot
.45331 .39278 Mdot
.50223 .33034 Mdot
.3397 .56146 Mdot
.55571 .83903 Mdot
.61022 .4308 Mdot
.46621 .69848 Mdot
.50479 .43394 Mdot
.44687 .44207 Mdot
.46544 .1446 Mdot
.66568 .60774 Mdot
.6943 .65999 Mdot
.68479 .49171 Mdot
.79014 .56762 Mdot
.72531 .42259 Mdot
.76747 .32499 Mdot
.58857 .20906 Mdot
.47354 .34948 Mdot
.51249 .30984 Mdot
.32968 .6269 Mdot
.48013 .64168 Mdot
.22049 .59876 Mdot
.47127 .36216 Mdot
.47536 .37967 Mdot
.67277 .57468 Mdot
.64821 .73258 Mdot
.52367 .19211 Mdot
.42975 .50732 Mdot
.63754 .433 Mdot
.28093 .52792 Mdot
.5077 .42124 Mdot
.49112 .56996 Mdot
.62802 .62744 Mdot
.71645 .41193 Mdot
.44075 .38236 Mdot
.18783 .43113 Mdot
.36912 .72904 Mdot
.46864 .68833 Mdot
.63357 .5683 Mdot
.54296 .19427 Mdot
.46168 .35498 Mdot
.46204 .64125 Mdot
.45841 .40073 Mdot
.56546 .60449 Mdot
.41328 .45069 Mdot
.66518 .42798 Mdot
.50636 .40893 Mdot
.71407 .40071 Mdot
.59084 .14298 Mdot
.68365 .39828 Mdot
.36816 .53402 Mdot
.59564 .62506 Mdot
.60742 .59873 Mdot
.34007 .55514 Mdot
.60625 .59395 Mdot
.30912 .35154 Mdot
.36903 .35848 Mdot
.64425 .43281 Mdot
.51028 .45524 Mdot
.65434 .42535 Mdot
.67115 .59719 Mdot
.47603 .36305 Mdot
.59179 .8467 Mdot
.60679 .57448 Mdot
.59855 .19958 Mdot
.47876 .66788 Mdot
.62651 .62807 Mdot
.48254 .43765 Mdot
.54413 .69489 Mdot
.60085 .60503 Mdot
.65433 .71095 Mdot
.44594 .40932 Mdot
.3148 .52658 Mdot
.49065 .42686 Mdot
.48587 .44837 Mdot
.60239 .62161 Mdot
.50203 .37936 Mdot
.45159 .67876 Mdot
.35164 .52256 Mdot
.83785 .49797 Mdot
.32705 .72824 Mdot
.43374 .37634 Mdot
.47725 .38882 Mdot
.2641 .53613 Mdot
.42689 .42714 Mdot
.49145 .68948 Mdot
.16432 .67431 Mdot
.6472 .43136 Mdot
.58836 .59567 Mdot
.72715 .41813 Mdot
.44611 .44827 Mdot
.51215 .38638 Mdot
.74441 .74391 Mdot
.72626 .35218 Mdot
.45537 .69096 Mdot
.50868 .34673 Mdot
.59792 .59355 Mdot
.65376 .40643 Mdot
.50494 .67265 Mdot
.4813 .40863 Mdot
.46157 .37777 Mdot
.62985 .40368 Mdot
.55127 .33409 Mdot
.4168 .21868 Mdot
.4499 .65249 Mdot
.41194 .35443 Mdot
.65439 .63693 Mdot
.42532 .37607 Mdot
.34656 .25141 Mdot
.33389 .55647 Mdot
.49977 .66064 Mdot
.79078 .50539 Mdot
.4637 .35308 Mdot
.44949 .68597 Mdot
.46695 .65707 Mdot
.51892 .36153 Mdot
.32953 .5821 Mdot
.33996 .51528 Mdot
.34227 .53057 Mdot
.14161 .51606 Mdot
.62856 .31917 Mdot
.65646 .57943 Mdot
.47468 .6464 Mdot
.62507 .55269 Mdot
.68676 .44492 Mdot
.54681 .56239 Mdot
.62615 .55411 Mdot
.34285 .5256 Mdot
.58616 .61194 Mdot
.45533 .42426 Mdot
.46661 .66091 Mdot
.64792 .57113 Mdot
.47338 .45317 Mdot
.40308 .67348 Mdot
.50797 .77512 Mdot
.63211 .43848 Mdot
.68339 .43047 Mdot
.47167 .43753 Mdot
.63621 .54685 Mdot
.46115 .37208 Mdot
.48823 .63456 Mdot
.39953 .66399 Mdot
.50353 .43389 Mdot
.61091 .59559 Mdot
.26413 .54583 Mdot
.53299 .19692 Mdot
.43907 .34075 Mdot
.44947 .38974 Mdot
.49871 .38049 Mdot
.45845 .40124 Mdot
.72578 .68594 Mdot
.44886 .64024 Mdot
.34614 .74775 Mdot
.75178 .42454 Mdot
.30063 .55252 Mdot
.27268 .53657 Mdot
.48027 .19706 Mdot
.33193 .63432 Mdot
.47365 .65024 Mdot
.49499 .3987 Mdot
.32938 .68859 Mdot
.80626 .64291 Mdot
.67139 .79924 Mdot
.53858 .47076 Mdot
.66018 .61707 Mdot
.35898 .54577 Mdot
.60206 .56987 Mdot
.49204 .37943 Mdot
.53052 .42614 Mdot
.74826 .29049 Mdot
.50831 .65136 Mdot
.64886 .4348 Mdot
.50148 .38596 Mdot
.63032 .32381 Mdot
.63072 .57718 Mdot
.61725 .62848 Mdot
.42521 .41595 Mdot
.28372 .56909 Mdot
.55993 .14974 Mdot
.47563 .68937 Mdot
.45004 .76929 Mdot
.25597 .64471 Mdot
.4137 .74479 Mdot
.47306 .68408 Mdot
.56419 .45523 Mdot
.67167 .58559 Mdot
.38956 .27802 Mdot
.30227 .55756 Mdot
.67511 .42212 Mdot
.43864 .45724 Mdot
.3302 .56758 Mdot
.66022 .60037 Mdot
.31039 .52692 Mdot
.51425 .389 Mdot
.47951 .62534 Mdot
.63837 .58206 Mdot
.4779 .61156 Mdot
.31165 .58339 Mdot
.65007 .40084 Mdot
.45081 .52175 Mdot
.337 .47629 Mdot
.30361 .39647 Mdot
.42221 .41029 Mdot
.49573 .57387 Mdot
.47592 .4258 Mdot
.27473 .51853 Mdot
.4689 .39581 Mdot
.28638 .49625 Mdot
.63983 .5721 Mdot
.49103 .43629 Mdot
.4917 .40901 Mdot
.27335 .71792 Mdot
.43413 .39489 Mdot
.4466 .34482 Mdot
.48169 .40138 Mdot
.37116 .51171 Mdot
.51653 .45212 Mdot
.30639 .51046 Mdot
.69873 .55682 Mdot
.62333 .59137 Mdot
.67367 .44146 Mdot
.62633 .40307 Mdot
.65319 .31075 Mdot
.76727 .4977 Mdot
.62161 .75064 Mdot
.32956 .5272 Mdot
.45295 .66364 Mdot
.46532 .39882 Mdot
.77658 .36595 Mdot
.61621 .50673 Mdot
.63741 .62461 Mdot
.3303 .73008 Mdot
.40132 .36916 Mdot
.72507 .315 Mdot
.50144 .34407 Mdot
.15266 .50492 Mdot
.44831 .32422 Mdot
.40725 .4365 Mdot
.59626 .56652 Mdot
.70665 .41517 Mdot
.43597 .43448 Mdot
.32909 .50464 Mdot
.6702 .41927 Mdot
.54491 .34749 Mdot
.68576 .62603 Mdot
.70348 .57501 Mdot
.35084 .48859 Mdot
.45697 .41537 Mdot
.63853 .58341 Mdot
.29026 .52319 Mdot
.5021 .18746 Mdot
.4671 .6931 Mdot
.45063 .61769 Mdot
.37476 .6109 Mdot
.56897 .82977 Mdot
.66604 .40231 Mdot
.36533 .2791 Mdot
.44452 .42284 Mdot
.72301 .62136 Mdot
.50919 .42852 Mdot
.77602 .67438 Mdot
.65582 .39456 Mdot
.34585 .52597 Mdot
.44815 .66983 Mdot
.27975 .52519 Mdot
.29422 .40257 Mdot
.67633 .56231 Mdot
.5091 .54437 Mdot
.62128 .57853 Mdot
.59182 .48551 Mdot
.32818 .54545 Mdot
.50243 .36888 Mdot
.23264 .27386 Mdot
.33687 .55348 Mdot
.34135 .5693 Mdot
.3952 .80901 Mdot
.55618 .85632 Mdot
.40882 .36947 Mdot
.3535 .5488 Mdot
.61788 .58244 Mdot
.66202 .41491 Mdot
.50045 .42114 Mdot
.45282 .41749 Mdot
.32886 .56714 Mdot
.59795 .61613 Mdot
.23945 .44796 Mdot
.63294 .60471 Mdot
.33379 .52036 Mdot
.63322 .59666 Mdot
.55009 .67534 Mdot
.62968 .55975 Mdot
.44507 .44165 Mdot
.46802 .39666 Mdot
.74152 .47226 Mdot
.30913 .53192 Mdot
.48754 .41282 Mdot
.51373 .36244 Mdot
.31502 .54576 Mdot
.59154 .45953 Mdot
.24691 .44021 Mdot
.43204 .37226 Mdot
.43878 .40397 Mdot
.62211 .41611 Mdot
.52775 .58014 Mdot
.35506 .27193 Mdot
.51236 .39119 Mdot
.63077 .39666 Mdot
.3317 .50631 Mdot
.45114 .37327 Mdot
.81081 .6062 Mdot
.60383 .69511 Mdot
.4789 .35928 Mdot
.60262 .56409 Mdot
.50184 .34193 Mdot
.66632 .23083 Mdot
.43194 .42793 Mdot
.32247 .53994 Mdot
.2947 .5329 Mdot
.22391 .66116 Mdot
.32196 .55591 Mdot
.61654 .61976 Mdot
.47399 .68002 Mdot
.72182 .71296 Mdot
.59815 .58737 Mdot
.45811 .3255 Mdot
.2459 .71682 Mdot
.49822 .3565 Mdot
.46258 .44956 Mdot
.60485 .18463 Mdot
.60389 .57133 Mdot
.28632 .55129 Mdot
.47686 .51004 Mdot
.49232 .32265 Mdot
.49872 .65592 Mdot
.45588 .46401 Mdot
.41823 .40961 Mdot
.6276 .21537 Mdot
.72992 .66573 Mdot
.47351 .63546 Mdot
.44024 .35142 Mdot
.51257 .38961 Mdot
.6709 .61481 Mdot
.47844 .39282 Mdot
.6634 .41835 Mdot
.2892 .54803 Mdot
.62338 .56045 Mdot
.63914 .41786 Mdot
.46023 .35828 Mdot
.63223 .43013 Mdot
.6517 .58195 Mdot
.47665 .63774 Mdot
.48563 .37111 Mdot
.6236 .43568 Mdot
.63346 .43041 Mdot
.47818 .42349 Mdot
.30788 .52479 Mdot
.41742 .33706 Mdot
.43344 .39045 Mdot
.51005 .40929 Mdot
.31664 .56865 Mdot
.861 .61676 Mdot
.45222 .43701 Mdot
.6866 .33952 Mdot
.32194 .57454 Mdot
.5942 .47623 Mdot
.59769 .57261 Mdot
.41894 .41345 Mdot
.4784 .63692 Mdot
.46435 .64433 Mdot
.66485 .59369 Mdot
.35557 .56053 Mdot
.69342 .48215 Mdot
.31812 .58959 Mdot
.53109 .36152 Mdot
.42682 .36939 Mdot
.22339 .52179 Mdot
.81643 .41305 Mdot
.28103 .55316 Mdot
.65332 .65261 Mdot
.42154 .52306 Mdot
.45569 .65071 Mdot
.61773 .62517 Mdot
.36122 .54255 Mdot
.30239 .56788 Mdot
.3144 .51825 Mdot
.67518 .42815 Mdot
.74445 .47436 Mdot
.30015 .57501 Mdot
.2743 .55853 Mdot
.44678 .41384 Mdot
.51132 .39314 Mdot
.5434 .20669 Mdot
.48177 .23243 Mdot
.63773 .43901 Mdot
.656 .60128 Mdot
.12667 .50233 Mdot
.49366 .63748 Mdot
.31823 .74555 Mdot
.47835 .44688 Mdot
.11947 .40109 Mdot
.49078 .43225 Mdot
.48234 .39068 Mdot
.35187 .52228 Mdot
.62937 .43951 Mdot
.65206 .42829 Mdot
.33614 .54623 Mdot
.27063 .54614 Mdot
.66307 .4197 Mdot
.52384 .80602 Mdot
.82226 .60481 Mdot
.62938 .5208 Mdot
.30927 .54471 Mdot
.35434 .46563 Mdot
.44577 .65734 Mdot
.54688 .36351 Mdot
.48743 .63084 Mdot
.62695 .5825 Mdot
.66673 .56967 Mdot
.49781 .66369 Mdot
.44675 .40754 Mdot
.65409 .57206 Mdot
.47764 .35193 Mdot
.44905 .78504 Mdot
.29641 .43537 Mdot
.7206 .4559 Mdot
.54329 .44439 Mdot
.58374 .46453 Mdot
.48764 .61052 Mdot
.45458 .36454 Mdot
.79939 .57984 Mdot
.64312 .43453 Mdot
.54805 .39758 Mdot
.50095 .65566 Mdot
.63611 .19116 Mdot
.48268 .36626 Mdot
.32104 .53753 Mdot
.46821 .65284 Mdot
.35075 .5977 Mdot
.39024 .65054 Mdot
.49912 .38247 Mdot
.16439 .35469 Mdot
.37219 .52205 Mdot
.63305 .5635 Mdot
.19211 .48863 Mdot
.28283 .56099 Mdot
.65241 .37814 Mdot
.77225 .45255 Mdot
.63394 .80498 Mdot
.28312 .53829 Mdot
.66864 .6091 Mdot
.31847 .50917 Mdot
.65386 .40141 Mdot
.35824 .51564 Mdot
.63545 .57492 Mdot
.4433 .3831 Mdot
.61919 .60366 Mdot
.67158 .4376 Mdot
.42038 .22169 Mdot
.4719 .63608 Mdot
.59204 .59085 Mdot
.49062 .66489 Mdot
.58617 .33951 Mdot
.74526 .38831 Mdot
.47445 .6981 Mdot
.24756 .38183 Mdot
.42075 .37921 Mdot
.28395 .56457 Mdot
.61806 .60693 Mdot
.77013 .56315 Mdot
.44686 .51961 Mdot
.30788 .56038 Mdot
.66023 .59047 Mdot
.3963 .60421 Mdot
.19985 .44471 Mdot
.45008 .34157 Mdot
.54007 .29254 Mdot
.30998 .54796 Mdot
.67426 .59395 Mdot
.43465 .19043 Mdot
.31905 .50806 Mdot
.60557 .60471 Mdot
.44731 .67506 Mdot
.46492 .67321 Mdot
.42598 .39905 Mdot
.48992 .61907 Mdot
.66243 .57612 Mdot
.41169 .64732 Mdot
.35427 .55058 Mdot
.31114 .60565 Mdot
.62314 .4383 Mdot
.62352 .59713 Mdot
.51455 .37271 Mdot
.30891 .49557 Mdot
.58016 .68458 Mdot
.24398 .46279 Mdot
.2286 .31054 Mdot
.62439 .60667 Mdot
.29437 .55647 Mdot
.31955 .53544 Mdot
.44405 .33727 Mdot
.40049 .57487 Mdot
.69745 .48322 Mdot
.45871 .49596 Mdot
.43543 .49723 Mdot
.60875 .5502 Mdot
.67602 .5472 Mdot
.4903 .45281 Mdot
.45891 .41076 Mdot
.45338 .65444 Mdot
.44242 .38673 Mdot
.35432 .53148 Mdot
.42376 .41225 Mdot
.48396 .68464 Mdot
.62012 .5739 Mdot
.48164 .36875 Mdot
.62679 .42168 Mdot
.44187 .66388 Mdot
.50682 .68004 Mdot
.61645 .59592 Mdot
.32753 .56848 Mdot
.61079 .46786 Mdot
.63943 .60508 Mdot
.45626 .41462 Mdot
.53161 .59205 Mdot
.51642 .39187 Mdot
.44274 .30145 Mdot
.31434 .5072 Mdot
.62047 .56185 Mdot
.35875 .52899 Mdot
.48644 .66397 Mdot
.75562 .42974 Mdot
.45926 .39317 Mdot
.6019 .59793 Mdot
.60962 .66041 Mdot
.48527 .2878 Mdot
.2757 .56585 Mdot
.5486 .78052 Mdot
.2733 .52885 Mdot
.65193 .60717 Mdot
.30357 .75127 Mdot
.67309 .41066 Mdot
.63729 .62499 Mdot
.83802 .4703 Mdot
.60649 .58136 Mdot
.43005 .40976 Mdot
.46814 .43686 Mdot
.62704 .5605 Mdot
.62407 .40783 Mdot
.53841 .1826 Mdot
.58552 .57023 Mdot
.28517 .54722 Mdot
.45348 .79742 Mdot
.31778 .22959 Mdot
.43199 .6799 Mdot
.45319 .65741 Mdot
.44688 .32178 Mdot
.41553 .37377 Mdot
.50371 .65417 Mdot
.5111 .64597 Mdot
.68036 .42205 Mdot
.61997 .61263 Mdot
.32944 .49292 Mdot
.48379 .70963 Mdot
.38912 .51267 Mdot
.76131 .49102 Mdot
.43643 .34328 Mdot
.26561 .65606 Mdot
.48924 .44069 Mdot
.68015 .36597 Mdot
.48526 .68461 Mdot
.5221 .39209 Mdot
.47277 .33558 Mdot
.48831 .63901 Mdot
.66388 .41479 Mdot
.50836 .60864 Mdot
.63633 .59312 Mdot
.85869 .57787 Mdot
.48291 .34765 Mdot
.42978 .41619 Mdot
.48363 .64455 Mdot
.70139 .52843 Mdot
.29652 .55015 Mdot
.28172 .51673 Mdot
.63943 .55971 Mdot
.43328 .53697 Mdot
.4203 .39834 Mdot
.44793 .37094 Mdot
.64185 .58804 Mdot
.60931 .61895 Mdot
.59442 .75207 Mdot
.46249 .43143 Mdot
.47519 .65656 Mdot
.68449 .45091 Mdot
.48836 .68203 Mdot
.51645 .38694 Mdot
.43337 .42027 Mdot
.44349 .44135 Mdot
.51488 .37507 Mdot
.5083 .63949 Mdot
.51826 .40876 Mdot
.53192 .42967 Mdot
.29915 .55912 Mdot
.50617 .38963 Mdot
.44344 .49814 Mdot
.44365 .39361 Mdot
.66215 .41661 Mdot
.32523 .28866 Mdot
.48291 .36678 Mdot
.41975 .40926 Mdot
.58555 .59829 Mdot
.46067 .38306 Mdot
.49032 .63512 Mdot
.30519 .53907 Mdot
.47656 .64699 Mdot
.46547 .64289 Mdot
.65393 .55537 Mdot
.67479 .39802 Mdot
.4426 .44777 Mdot
.6663 .43609 Mdot
.47763 .32481 Mdot
.46363 .35273 Mdot
.76017 .45111 Mdot
.15339 .51829 Mdot
.38348 .23197 Mdot
.45773 .39441 Mdot
.60545 .57208 Mdot
.60269 .5678 Mdot
.54085 .33232 Mdot
.45644 .34092 Mdot
.49483 .68852 Mdot
.45901 .64658 Mdot
.52429 .23326 Mdot
.67385 .26936 Mdot
.6627 .41628 Mdot
.52116 .567 Mdot
.45193 .34855 Mdot
.51919 .38469 Mdot
.49609 .35119 Mdot
.63213 .55344 Mdot
.53116 .47135 Mdot
.62727 .62598 Mdot
.3763 .73999 Mdot
.49511 .65642 Mdot
.49203 .37387 Mdot
.28863 .68716 Mdot
.34576 .5455 Mdot
.30597 .53813 Mdot
.50103 .6903 Mdot
.68051 .6146 Mdot
.51091 .20649 Mdot
.66529 .80885 Mdot
.37065 .53869 Mdot
.64978 .44659 Mdot
.44896 .36435 Mdot
.61405 .57754 Mdot
.33629 .51981 Mdot
.65197 .44605 Mdot
.49605 .36647 Mdot
.74557 .47418 Mdot
.45362 .39889 Mdot
.30479 .63747 Mdot
.30286 .52054 Mdot
.79048 .65937 Mdot
.35258 .56477 Mdot
.441 .66748 Mdot
.4986 .67317 Mdot
.45225 .43255 Mdot
.20991 .51637 Mdot
.27459 .54761 Mdot
.53908 .61645 Mdot
.66838 .39783 Mdot
.56167 .68664 Mdot
.6613 .40522 Mdot
.63574 .5664 Mdot
.67088 .4141 Mdot
.63771 .57428 Mdot
.47872 .22163 Mdot
.37745 .51665 Mdot
.63905 .42572 Mdot
.58458 .64997 Mdot
.41528 .36911 Mdot
.63293 .43642 Mdot
.53313 .41381 Mdot
.45617 .29805 Mdot
.64261 .59099 Mdot
.66133 .39818 Mdot
.50433 .36852 Mdot
.7515 .31097 Mdot
.46066 .69726 Mdot
.49644 .68408 Mdot
.53325 .40746 Mdot
.61916 .54798 Mdot
.34619 .51241 Mdot
.761 .67052 Mdot
.45939 .71528 Mdot
.45331 .43577 Mdot
.43183 .43169 Mdot
.27204 .54006 Mdot
.27081 .69401 Mdot
.44374 .42741 Mdot
.39741 .44922 Mdot
.46225 .4327 Mdot
.47019 .70472 Mdot
.28008 .5261 Mdot
.31407 .53605 Mdot
.6599 .58591 Mdot
.34561 .55534 Mdot
.53448 .31634 Mdot
.31577 .69979 Mdot
.38923 .41503 Mdot
.48463 .6705 Mdot
.35436 .72229 Mdot
.37419 .74119 Mdot
.82098 .44289 Mdot
.30422 .58363 Mdot
.50677 .4296 Mdot
.34077 .56552 Mdot
.6567 .4074 Mdot
.31679 .52693 Mdot
.35905 .54491 Mdot
.46109 .36915 Mdot
.49665 .38428 Mdot
.62461 .56833 Mdot
.4051 .56157 Mdot
.32465 .57188 Mdot
.49217 .43052 Mdot
.40999 .38687 Mdot
.48848 .35408 Mdot
.55039 .61536 Mdot
.2788 .54593 Mdot
.45307 .82792 Mdot
.59985 .25628 Mdot
.32481 .57141 Mdot
.57446 .15431 Mdot
.60198 .66362 Mdot
.65949 .54713 Mdot
.46231 .60871 Mdot
.46869 .43278 Mdot
.59614 .59674 Mdot
.49141 .37869 Mdot
.26738 .65662 Mdot
.46669 .37845 Mdot
.66486 .4191 Mdot
.47401 .34946 Mdot
.6689 .58267 Mdot
.63187 .60584 Mdot
.44169 .43236 Mdot
.48163 .37099 Mdot
.44356 .21307 Mdot
.35432 .57854 Mdot
.30213 .53564 Mdot
.68289 .48593 Mdot
.63342 .41851 Mdot
.49942 .65951 Mdot
.47684 .39822 Mdot
.64752 .55394 Mdot
.62854 .60611 Mdot
.27835 .55179 Mdot
.65208 .59705 Mdot
.47465 .68883 Mdot
.46388 .39253 Mdot
.50384 .65996 Mdot
.67685 .42565 Mdot
.27858 .53357 Mdot
.50366 .38656 Mdot
.44645 .41351 Mdot
.29447 .53289 Mdot
.47123 .45564 Mdot
.62373 .41217 Mdot
.60554 .58585 Mdot
.28299 .53336 Mdot
.47129 .67843 Mdot
.63592 .56806 Mdot
.51124 .41115 Mdot
.14956 .4343 Mdot
.43187 .40685 Mdot
.48343 .42984 Mdot
.84184 .44879 Mdot
.45839 .34687 Mdot
.62243 .60747 Mdot
.34288 .523 Mdot
.52262 .45786 Mdot
.6348 .29661 Mdot
.81281 .69815 Mdot
.63516 .62465 Mdot
.44429 .36762 Mdot
.78518 .38151 Mdot
.44089 .37449 Mdot
.25101 .4959 Mdot
.60358 .54213 Mdot
.55651 .49323 Mdot
.52826 .41013 Mdot
.45855 .67792 Mdot
.62098 .5665 Mdot
.64217 .57518 Mdot
.42333 .79646 Mdot
.45642 .36897 Mdot
.47715 .58658 Mdot
.50566 .3755 Mdot
.46834 .68023 Mdot
.5527 .24067 Mdot
.63136 .60717 Mdot
.26135 .29255 Mdot
.47317 .42701 Mdot
.29825 .56738 Mdot
.58683 .61473 Mdot
.53741 .68873 Mdot
.50805 .41233 Mdot
.65322 .43889 Mdot
.47857 .71822 Mdot
.43246 .46131 Mdot
.48275 .67541 Mdot
.51133 .40583 Mdot
.44562 .4836 Mdot
.18542 .50353 Mdot
.31131 .52134 Mdot
.44818 .66743 Mdot
.54524 .58612 Mdot
.51748 .41454 Mdot
.28336 .53614 Mdot
.3037 .55902 Mdot
.67554 .43171 Mdot
.54372 .53531 Mdot
.37173 .63396 Mdot
.31592 .45526 Mdot
.441 .79654 Mdot
.58879 .61369 Mdot
.67411 .69671 Mdot
.49279 .41988 Mdot
.67793 .46393 Mdot
.48317 .63453 Mdot
.43027 .40314 Mdot
.35969 .29125 Mdot
.34186 .54432 Mdot
.43719 .41055 Mdot
.65586 .42463 Mdot
.65671 .48607 Mdot
.67642 .46055 Mdot
.77995 .44504 Mdot
.62247 .57971 Mdot
.53553 .41901 Mdot
.45127 .48088 Mdot
.59908 .56498 Mdot
.41825 .41955 Mdot
.60544 .60007 Mdot
.54392 .81771 Mdot
.63437 .43955 Mdot
.28232 .55099 Mdot
.55558 .64392 Mdot
.42928 .43923 Mdot
.41461 .38846 Mdot
.68403 .40746 Mdot
.46289 .41298 Mdot
.17141 .48833 Mdot
.55535 .61631 Mdot
.64725 .56829 Mdot
.31377 .51894 Mdot
.42301 .42518 Mdot
.55445 .54456 Mdot
.43617 .38479 Mdot
.3532 .37933 Mdot
.42012 .41098 Mdot
.38659 .63388 Mdot
.30258 .52478 Mdot
.48664 .67323 Mdot
.52344 .40636 Mdot
.47339 .38188 Mdot
.67777 .30652 Mdot
.46227 .32103 Mdot
.5226 .40103 Mdot
.25775 .53711 Mdot
.3333 .51644 Mdot
.31301 .51037 Mdot
.66099 .60689 Mdot
.64665 .23742 Mdot
.48053 .65825 Mdot
.54049 .44097 Mdot
.47669 .71006 Mdot
.22412 .47478 Mdot
.64797 .44569 Mdot
.79023 .42108 Mdot
.4876 .40555 Mdot
.33364 .52616 Mdot
.7584 .63137 Mdot
.30691 .50342 Mdot
.50416 .56381 Mdot
.46627 .65851 Mdot
.33628 .55049 Mdot
.48013 .38653 Mdot
.43208 .5204 Mdot
.76108 .35235 Mdot
.48456 .65287 Mdot
.45406 .32694 Mdot
.66248 .61046 Mdot
.73005 .43946 Mdot
.17711 .39527 Mdot
.46147 .6985 Mdot
.45338 .6264 Mdot
.45507 .36784 Mdot
.3481 .54232 Mdot
.46199 .68164 Mdot
.47619 .702 Mdot
.65374 .59494 Mdot
.49891 .38749 Mdot
.50043 .39244 Mdot
.65267 .60837 Mdot
.47852 .64617 Mdot
.53434 .39556 Mdot
.41406 .45212 Mdot
.72025 .25142 Mdot
.38485 .6025 Mdot
.86287 .58073 Mdot
.54934 .3405 Mdot
.32511 .30837 Mdot
.76178 .67665 Mdot
.31221 .57309 Mdot
.47091 .3579 Mdot
.4148 .44185 Mdot
.66281 .57711 Mdot
.45241 .38677 Mdot
.63363 .53323 Mdot
.46355 .65107 Mdot
.62939 .19206 Mdot
.36149 .69977 Mdot
.59135 .81316 Mdot
.45276 .38482 Mdot
.27774 .49914 Mdot
.6489 .41211 Mdot
.43558 .66439 Mdot
.29183 .5143 Mdot
.5096 .36611 Mdot
.43956 .21358 Mdot
.63197 .626 Mdot
.32265 .56295 Mdot
.5024 .1896 Mdot
.56954 .46223 Mdot
.5157 .3897 Mdot
.65017 .61674 Mdot
.78474 .60911 Mdot
.35891 .58281 Mdot
.45221 .70964 Mdot
.66525 .41515 Mdot
.61796 .56494 Mdot
.45825 .64575 Mdot
.30496 .49369 Mdot
.32877 .55408 Mdot
.34298 .50821 Mdot
.36741 .25031 Mdot
.58906 .58874 Mdot
.64536 .41478 Mdot
.70771 .30867 Mdot
.67795 .28666 Mdot
.66355 .42206 Mdot
.66816 .57205 Mdot
.33409 .51735 Mdot
.33718 .54076 Mdot
.30512 .53971 Mdot
.33277 .24647 Mdot
.32888 .57674 Mdot
.35314 .7713 Mdot
.4957 .35824 Mdot
.39582 .43687 Mdot
.44479 .36888 Mdot
.5002 .67821 Mdot
.29288 .52793 Mdot
.46626 .51825 Mdot
.48374 .33024 Mdot
.75848 .38474 Mdot
.42733 .4042 Mdot
.45975 .63048 Mdot
.44307 .41759 Mdot
.22512 .62764 Mdot
.33651 .56867 Mdot
.45559 .39159 Mdot
.4646 .63291 Mdot
.63325 .41267 Mdot
.27125 .56116 Mdot
.49894 .38092 Mdot
.5944 .77391 Mdot
.46479 .34743 Mdot
.59665 .80429 Mdot
.30962 .61101 Mdot
.64904 .4464 Mdot
.26196 .62492 Mdot
.64669 .62791 Mdot
.40295 .45093 Mdot
.51159 .33318 Mdot
.4888 .65894 Mdot
.56623 .66786 Mdot
.6216 .58969 Mdot
.53856 .4692 Mdot
.47762 .46596 Mdot
.67359 .43846 Mdot
.37288 .5612 Mdot
.50412 .65157 Mdot
.41487 .41121 Mdot
.45644 .33667 Mdot
.40571 .77108 Mdot
.51166 .45024 Mdot
.42552 .42302 Mdot
.68794 .42146 Mdot
.3457 .75966 Mdot
.44417 .3978 Mdot
.51351 .56314 Mdot
.36279 .52075 Mdot
.52666 .3553 Mdot
.3363 .76212 Mdot
.47122 .43733 Mdot
.33022 .56029 Mdot
.3809 .39239 Mdot
.35735 .62643 Mdot
.67174 .39677 Mdot
.41904 .40876 Mdot
.22828 .67056 Mdot
.46598 .42404 Mdot
.47694 .66063 Mdot
.45024 .34359 Mdot
.63323 .57647 Mdot
.38545 .22556 Mdot
.65907 .57707 Mdot
.42502 .38376 Mdot
.30532 .5427 Mdot
.48931 .64679 Mdot
.28652 .28444 Mdot
.72391 .48671 Mdot
.32666 .74594 Mdot
.69111 .77516 Mdot
.655 .39743 Mdot
.63871 .38785 Mdot
.50143 .64303 Mdot
.45394 .39268 Mdot
.3485 .78755 Mdot
.44578 .32434 Mdot
.43913 .40588 Mdot
.4679 .37774 Mdot
.73791 .38519 Mdot
.46244 .64788 Mdot
.64169 .59766 Mdot
.43871 .4244 Mdot
.52014 .40566 Mdot
.31003 .57196 Mdot
.63063 .4222 Mdot
.59819 .57208 Mdot
.64687 .43265 Mdot
.61694 .5701 Mdot
.59701 .16873 Mdot
.51155 .352 Mdot
.63809 .40889 Mdot
.48422 .71286 Mdot
.32383 .56781 Mdot
.3164 .69552 Mdot
.63995 .57035 Mdot
.66328 .59306 Mdot
.4323 .42612 Mdot
.33339 .55972 Mdot
.35496 .52441 Mdot
.65427 .40483 Mdot
.47514 .69516 Mdot
.48183 .36636 Mdot
.45628 .35146 Mdot
.37383 .42701 Mdot
.63175 .54862 Mdot
.29484 .63994 Mdot
.66799 .71517 Mdot
.45524 .39482 Mdot
.35469 .54831 Mdot
.4752 .37121 Mdot
.70337 .71762 Mdot
.34683 .54868 Mdot
.47789 .4371 Mdot
.52228 .16106 Mdot
.68678 .60474 Mdot
.33994 .65016 Mdot
.44503 .43937 Mdot
.74652 .72362 Mdot
.4917 .41399 Mdot
.65224 .19136 Mdot
.74642 .59667 Mdot
.42406 .37724 Mdot
.50494 .41961 Mdot
.26951 .44161 Mdot
.44911 .35927 Mdot
.65632 .60466 Mdot
.5775 .20454 Mdot
.32858 .50378 Mdot
.45772 .75722 Mdot
.33578 .28578 Mdot
.6567 .39508 Mdot
.63886 .55964 Mdot
.66916 .54275 Mdot
.66016 .42977 Mdot
.31215 .54387 Mdot
.45867 .40136 Mdot
.46033 .54171 Mdot
.61649 .55108 Mdot
.56601 .3835 Mdot
.47504 .66171 Mdot
.58698 .7155 Mdot
.59462 .51602 Mdot
.48015 .68067 Mdot
.50694 .39309 Mdot
.25828 .44294 Mdot
.42781 .25128 Mdot
.83592 .58018 Mdot
.45604 .64625 Mdot
.48589 .65149 Mdot
.35972 .23135 Mdot
.64727 .45101 Mdot
.42972 .77363 Mdot
.38894 .6404 Mdot
.49676 .65139 Mdot
.32094 .59931 Mdot
.63015 .62162 Mdot
.51032 .62863 Mdot
.54257 .4141 Mdot
.4746 .35401 Mdot
.47792 .38522 Mdot
.48117 .69311 Mdot
.49583 .29268 Mdot
.18788 .48013 Mdot
.4918 .66531 Mdot
.4837 .31347 Mdot
.53532 .51576 Mdot
.68314 .65783 Mdot
.64415 .60799 Mdot
.67547 .40126 Mdot
.60717 .41351 Mdot
.29501 .56246 Mdot
.67516 .39954 Mdot
.66173 .48157 Mdot
.46896 .4088 Mdot
.49296 .67354 Mdot
.57285 .68346 Mdot
.46864 .67316 Mdot
.65645 .42997 Mdot
.67277 .44467 Mdot
.29879 .55845 Mdot
.307 .5316 Mdot
.29777 .34554 Mdot
.55818 .2745 Mdot
.43142 .39015 Mdot
.78509 .52424 Mdot
.35971 .53971 Mdot
.56908 .38699 Mdot
.67806 .40256 Mdot
.63215 .41682 Mdot
.68521 .32006 Mdot
.48785 .40072 Mdot
.23086 .53061 Mdot
.48369 .3993 Mdot
.55474 .24834 Mdot
.47812 .44544 Mdot
.6534 .59583 Mdot
.49469 .4006 Mdot
.7005 .32901 Mdot
.43337 .44707 Mdot
.41958 .36514 Mdot
.63739 .55273 Mdot
.44741 .4665 Mdot
.63332 .57854 Mdot
.42726 .38495 Mdot
.61461 .41989 Mdot
.65022 .56205 Mdot
.63345 .31279 Mdot
.69497 .33615 Mdot
.67062 .57637 Mdot
.66693 .43904 Mdot
.63433 .3973 Mdot
.64797 .34136 Mdot
.29151 .51428 Mdot
.51193 .3263 Mdot
.4519 .39064 Mdot
.61038 .62252 Mdot
.45751 .65139 Mdot
.50375 .42387 Mdot
.41118 .38694 Mdot
.46703 .44317 Mdot
.29445 .56282 Mdot
.7027 .47996 Mdot
.64505 .40433 Mdot
.64905 .61296 Mdot
.61215 .47184 Mdot
.61508 .54736 Mdot
.44475 .34283 Mdot
.4208 .44572 Mdot
.34921 .28773 Mdot
.66025 .67292 Mdot
.33245 .23899 Mdot
.32738 .55571 Mdot
.60341 .56415 Mdot
.61742 .43213 Mdot
.40365 .42812 Mdot
.33638 .52586 Mdot
.63526 .57549 Mdot
.45451 .39864 Mdot
.44392 .32901 Mdot
.34694 .73357 Mdot
.54263 .31611 Mdot
.67043 .32741 Mdot
.6656 .59268 Mdot
.65588 .62117 Mdot
.71827 .35757 Mdot
.69338 .39737 Mdot
.45075 .51973 Mdot
.44903 .37608 Mdot
.65387 .43814 Mdot
.33742 .52099 Mdot
.38266 .25118 Mdot
.48971 .68896 Mdot
.40248 .5685 Mdot
.45435 .38568 Mdot
.57528 .4784 Mdot
.30354 .54435 Mdot
.65776 .42242 Mdot
.4832 .69185 Mdot
.62668 .38979 Mdot
.61719 .55546 Mdot
.59848 .82922 Mdot
.46326 .4203 Mdot
.42725 .42038 Mdot
.44677 .64929 Mdot
.34305 .53589 Mdot
.67571 .39551 Mdot
.46291 .79828 Mdot
.64929 .57987 Mdot
.32771 .7736 Mdot
.35415 .54431 Mdot
.36691 .47217 Mdot
.6384 .61607 Mdot
.49469 .69716 Mdot
.6329 .32993 Mdot
.47968 .68619 Mdot
.42272 .39326 Mdot
.32604 .52975 Mdot
.45009 .66922 Mdot
.38995 .57878 Mdot
.78101 .36567 Mdot
.35886 .47 Mdot
.47033 .40367 Mdot
.72007 .27391 Mdot
.58323 .79487 Mdot
.36201 .57049 Mdot
.47334 .63689 Mdot
.42878 .40214 Mdot
.41486 .3965 Mdot
.46319 .42425 Mdot
.45567 .66205 Mdot
.77939 .50288 Mdot
.6444 .58873 Mdot
.45022 .36741 Mdot
.67997 .42357 Mdot
.62936 .58398 Mdot
.55315 .64998 Mdot
.64204 .607 Mdot
.31371 .58552 Mdot
.43796 .34662 Mdot
.51012 .72159 Mdot
.56175 .13094 Mdot
.47976 .64924 Mdot
.66261 .56048 Mdot
.50575 .35012 Mdot
.60515 .68615 Mdot
.32068 .51226 Mdot
.65113 .5802 Mdot
.42932 .41486 Mdot
.55821 .63742 Mdot
.40705 .22611 Mdot
.63814 .60738 Mdot
.33819 .52561 Mdot
.83405 .56591 Mdot
.44618 .3862 Mdot
.48415 .41733 Mdot
.33299 .5477 Mdot
.22381 .41125 Mdot
.45169 .18889 Mdot
.47947 .37116 Mdot
.48727 .67416 Mdot
.48857 .85728 Mdot
.41145 .38044 Mdot
.59069 .24231 Mdot
.62348 .56661 Mdot
.5249 .64643 Mdot
.33322 .6242 Mdot
.40314 .42367 Mdot
.44695 .78229 Mdot
.45686 .62075 Mdot
.72026 .29433 Mdot
.63115 .53457 Mdot
.71466 .60895 Mdot
.67705 .24247 Mdot
.47174 .62925 Mdot
.38069 .48974 Mdot
.46524 .7814 Mdot
.225 .35896 Mdot
.8112 .59426 Mdot
.71586 .57026 Mdot
.44042 .21169 Mdot
.47997 .53251 Mdot
.6086 .57387 Mdot
.58975 .44253 Mdot
.49332 .37817 Mdot
.5909 .79312 Mdot
.2192 .56605 Mdot
.20331 .53789 Mdot
.72337 .2762 Mdot
.26904 .48125 Mdot
.77697 .37331 Mdot
.82784 .44515 Mdot
.44467 .27276 Mdot
.69533 .66649 Mdot
.32972 .77875 Mdot
.56674 .18327 Mdot
.46395 .81642 Mdot
.38791 .42093 Mdot
.49182 .57 Mdot
.65116 .78602 Mdot
.33691 .48912 Mdot
.1977 .46405 Mdot
.65808 .58389 Mdot
.30963 .50646 Mdot
.45628 .77099 Mdot
.27182 .53089 Mdot
.35313 .6235 Mdot
.84169 .5592 Mdot
.78867 .37482 Mdot
.24598 .67839 Mdot
.76294 .69188 Mdot
.35 .30031 Mdot
.21842 .70953 Mdot
.59734 .55661 Mdot
.2864 .5627 Mdot
.69844 .36798 Mdot
.70584 .32326 Mdot
.39593 .73955 Mdot
.5048 .79448 Mdot
.74844 .44901 Mdot
.57948 .31845 Mdot
.3192 .53805 Mdot
.27604 .62524 Mdot
.53308 .6373 Mdot
.36361 .70741 Mdot
.56265 .19576 Mdot
.82077 .51071 Mdot
.45224 .54905 Mdot
.52065 .78155 Mdot
.61855 .7092 Mdot
.18987 .3805 Mdot
.61482 .26867 Mdot
.57811 .40577 Mdot
.38298 .6122 Mdot
.745 .69051 Mdot
.23572 .36553 Mdot
.53469 .25191 Mdot
.69954 .31219 Mdot
.56522 .16927 Mdot
.67361 .74683 Mdot
.40228 .16457 Mdot
.29314 .50333 Mdot
.42972 .43038 Mdot
.2452 .39514 Mdot
.23785 .68772 Mdot
.67547 .44596 Mdot
.78708 .46769 Mdot
.67145 .40252 Mdot
.34018 .57738 Mdot
.41696 .21123 Mdot
.33568 .75849 Mdot
.24603 .70833 Mdot
.61623 .40388 Mdot
.53188 .45336 Mdot
.66593 .83904 Mdot
.74524 .34821 Mdot
.33926 .67609 Mdot
.70294 .23589 Mdot
.54167 .49232 Mdot
.32667 .60359 Mdot
.45116 .66549 Mdot
.66803 .22773 Mdot
.33333 .53669 Mdot
.42228 .14448 Mdot
.64478 .18707 Mdot
.37853 .26802 Mdot
.9182 .45114 Mdot
.72409 .3704 Mdot
.56003 .49024 Mdot
.41656 .67072 Mdot
.60762 .28971 Mdot
.1857 .44585 Mdot
.60686 .37882 Mdot
.60986 .69174 Mdot
.72667 .75658 Mdot
.70921 .27196 Mdot
.27202 .73401 Mdot
.55084 .83312 Mdot
.21417 .38169 Mdot
.5495 .55313 Mdot
.55206 .39263 Mdot
.59292 .52329 Mdot
.80837 .52259 Mdot
.57346 .16237 Mdot
.60444 .25651 Mdot
.8058 .70909 Mdot
.69068 .40562 Mdot
.75651 .5088 Mdot
.85641 .52991 Mdot
.59614 .32974 Mdot
.3001 .6184 Mdot
.60948 .23249 Mdot
.55333 .43715 Mdot
.62826 .47555 Mdot
.79809 .48989 Mdot
.30797 .65925 Mdot
.59785 .21107 Mdot
.78051 .63358 Mdot
.40208 .76937 Mdot
.30778 .43415 Mdot
.65664 .26165 Mdot
.27197 .51696 Mdot
.55579 .29009 Mdot
.33192 .61836 Mdot
.78565 .35694 Mdot
.48316 .62168 Mdot
.80745 .36538 Mdot
.4562 .19099 Mdot
.52602 .36823 Mdot
.45255 .31799 Mdot
.25041 .53774 Mdot
.5673 .29 Mdot
.45065 .4694 Mdot
.36739 .74504 Mdot
.81568 .40478 Mdot
.39799 .2857 Mdot
.5171 .61672 Mdot
.56663 .66328 Mdot
.85645 .54509 Mdot
.26404 .39104 Mdot
.69204 .39392 Mdot
.54154 .21544 Mdot
.18781 .39861 Mdot
.62686 .59332 Mdot
.27973 .73669 Mdot
.46123 .7191 Mdot
.39778 .23718 Mdot
.313 .45819 Mdot
.29113 .31167 Mdot
.81645 .40544 Mdot
.70263 .5649 Mdot
.43815 .20187 Mdot
.59449 .35016 Mdot
.40468 .81559 Mdot
.67979 .65958 Mdot
.45151 .46286 Mdot
.52893 .7898 Mdot
.6227 .40922 Mdot
.29174 .39226 Mdot
.46686 .84023 Mdot
.71865 .53155 Mdot
.50888 .44594 Mdot
.379 .26327 Mdot
.69064 .60489 Mdot
.42862 .52374 Mdot
.27815 .2509 Mdot
.42594 .35138 Mdot
.69857 .29727 Mdot
.6551 .75692 Mdot
.58714 .27487 Mdot
.81006 .62883 Mdot
.72182 .69608 Mdot
.44082 .15083 Mdot
.69689 .24051 Mdot
.7134 .48784 Mdot
.6733 .24456 Mdot
.75965 .30987 Mdot
.43251 .15903 Mdot
.48638 .31819 Mdot
.44058 .66209 Mdot
.1408 .42457 Mdot
.6412 .61069 Mdot
.72665 .33587 Mdot
.44027 .79673 Mdot
.56877 .55212 Mdot
.2593 .51112 Mdot
.56584 .43037 Mdot
.47893 .53819 Mdot
.35756 .5736 Mdot
.45692 .46973 Mdot
.33818 .21846 Mdot
.49021 .14704 Mdot
.38126 .18382 Mdot
.70515 .74634 Mdot
.64971 .21913 Mdot
.57299 .49303 Mdot
.25788 .69356 Mdot
.54601 .34331 Mdot
.49752 .36295 Mdot
.66848 .37968 Mdot
.72471 .37332 Mdot
.35861 .26644 Mdot
.38787 .70945 Mdot
.38044 .544 Mdot
.79243 .4793 Mdot
.36159 .867 Mdot
.31587 .33693 Mdot
.36764 .78559 Mdot
.71548 .41454 Mdot
.56563 .2754 Mdot
.80092 .52683 Mdot
.32604 .28418 Mdot
.83721 .44956 Mdot
.36134 .56775 Mdot
.4604 .81084 Mdot
.72797 .5653 Mdot
.4061 .50269 Mdot
.70873 .47593 Mdot
.79361 .3976 Mdot
.47567 .74943 Mdot
.30328 .28361 Mdot
.39615 .67344 Mdot
.2442 .38187 Mdot
.57388 .63288 Mdot
.59431 .72081 Mdot
.44656 .82939 Mdot
.71285 .6823 Mdot
.56772 .24379 Mdot
.52599 .52484 Mdot
.25156 .6279 Mdot
.4517 .62197 Mdot
.57294 .24779 Mdot
.45505 .4984 Mdot
.67251 .25647 Mdot
.48741 .08968 Mdot
.27182 .27384 Mdot
.84773 .59101 Mdot
.79073 .52798 Mdot
.48709 .4568 Mdot
.84771 .47845 Mdot
.36386 .18316 Mdot
.59856 .14585 Mdot
.56771 .745 Mdot
.62256 .5388 Mdot
.48576 .7039 Mdot
.36788 .20884 Mdot
.77516 .49741 Mdot
.83537 .49483 Mdot
.63156 .2552 Mdot
.50625 .68382 Mdot
.15339 .53198 Mdot
.56463 .17304 Mdot
.33327 .46176 Mdot
.53977 .31253 Mdot
.50054 .44207 Mdot
.22068 .58862 Mdot
.27277 .53317 Mdot
.66104 .70265 Mdot
.54969 .27025 Mdot
.62404 .60005 Mdot
.69236 .37272 Mdot
.51975 .79575 Mdot
.47427 .3497 Mdot
.54557 .57634 Mdot
.28346 .57145 Mdot
.66782 .6726 Mdot
.33754 .7094 Mdot
.55607 .14716 Mdot
.72132 .42762 Mdot
.52918 .40569 Mdot
.58871 .27027 Mdot
.70658 .47124 Mdot
.43502 .18994 Mdot
.50341 .64364 Mdot
.74112 .30031 Mdot
.46058 .56533 Mdot
.55416 .28629 Mdot
.22379 .56167 Mdot
.46191 .3004 Mdot
.41826 .37916 Mdot
.74135 .67157 Mdot
.35812 .3533 Mdot
.41237 .54829 Mdot
.54173 .42427 Mdot
.5271 .3264 Mdot
.84877 .48857 Mdot
.65316 .4871 Mdot
.59894 .70967 Mdot
.76024 .32454 Mdot
.45965 .66617 Mdot
.34236 .56373 Mdot
.60104 .43135 Mdot
.48925 .8105 Mdot
.37654 .34225 Mdot
.40528 .2268 Mdot
.57839 .53274 Mdot
.72643 .52363 Mdot
.76847 .34014 Mdot
.73892 .30518 Mdot
.20467 .59471 Mdot
.36254 .5729 Mdot
.46352 .27663 Mdot
.4795 .81587 Mdot
.33554 .51459 Mdot
.37287 .76296 Mdot
.3588 .75183 Mdot
.60598 .1821 Mdot
.53913 .5919 Mdot
.73596 .74652 Mdot
.66296 .32406 Mdot
.77973 .46724 Mdot
.28415 .28473 Mdot
.4318 .8215 Mdot
.77795 .39177 Mdot
.32484 .59594 Mdot
.26795 .45745 Mdot
.39074 .4222 Mdot
.26184 .6642 Mdot
.14667 .45923 Mdot
.6166 .4478 Mdot
.36288 .48148 Mdot
.78431 .63112 Mdot
.45705 .40906 Mdot
.24382 .2947 Mdot
.49579 .80135 Mdot
.35029 .23457 Mdot
.4967 .69851 Mdot
.51165 .38923 Mdot
.42255 .43564 Mdot
.57625 .2235 Mdot
.35169 .62929 Mdot
.65818 .24609 Mdot
.50464 .85133 Mdot
.79745 .59325 Mdot
.22179 .55734 Mdot
.71589 .32668 Mdot
.82396 .51672 Mdot
.60196 .78889 Mdot
.53339 .54157 Mdot
.72468 .39487 Mdot
.60912 .32888 Mdot
.75224 .70134 Mdot
.4555 .50182 Mdot
.42779 .62278 Mdot
.40313 .75194 Mdot
.6754 .71527 Mdot
.34188 .25948 Mdot
.5066 .40764 Mdot
.50284 .18967 Mdot
.83052 .46548 Mdot
.20933 .5861 Mdot
.17435 .45108 Mdot
.28018 .26398 Mdot
.34247 .4076 Mdot
.69445 .70653 Mdot
.56811 .79466 Mdot
.41348 .83385 Mdot
.456 .56925 Mdot
.76472 .40017 Mdot
.60313 .34029 Mdot
.7656 .33429 Mdot
.44523 .64936 Mdot
.38781 .66081 Mdot
.56956 .66346 Mdot
.66869 .24605 Mdot
.26277 .40863 Mdot
.80914 .41463 Mdot
.52251 .50549 Mdot
.44987 .14536 Mdot
.72269 .66961 Mdot
.49432 .52504 Mdot
.61492 .55831 Mdot
.69587 .54664 Mdot
.79854 .45723 Mdot
.73048 .64106 Mdot
.41719 .81276 Mdot
.67049 .55858 Mdot
.59514 .43221 Mdot
.31245 .4751 Mdot
.54594 .29606 Mdot
.73941 .67695 Mdot
.58875 .27073 Mdot
.80222 .39057 Mdot
.59152 .219 Mdot
.49753 .1919 Mdot
.73023 .371 Mdot
.67343 .79514 Mdot
.3379 .67142 Mdot
.65165 .47106 Mdot
.50477 .79924 Mdot
.7618 .52866 Mdot
.30377 .59877 Mdot
.16985 .28965 Mdot
.60734 .82154 Mdot
.71284 .66613 Mdot
.57448 .16328 Mdot
.72049 .70759 Mdot
.65875 .67511 Mdot
.20583 .41669 Mdot
.39312 .59976 Mdot
.47914 .21265 Mdot
.46823 .37871 Mdot
.33434 .21394 Mdot
.53925 .27807 Mdot
.53467 .14103 Mdot
.83881 .50671 Mdot
.26051 .50567 Mdot
.43698 .34845 Mdot
.65003 .61427 Mdot
.46276 .59014 Mdot
.49607 .2521 Mdot
.2393 .43588 Mdot
.27539 .60889 Mdot
.56401 .63746 Mdot
.59323 .57246 Mdot
.69485 .47464 Mdot
.36986 .54041 Mdot
.77615 .48295 Mdot
.67419 .712 Mdot
.62001 .63447 Mdot
.44082 .55552 Mdot
.57108 .25746 Mdot
.32138 .62587 Mdot
.33912 .46026 Mdot
.33096 .27939 Mdot
.49878 .73243 Mdot
.65246 .60394 Mdot
.32725 .45089 Mdot
.64619 .79233 Mdot
.78263 .61526 Mdot
.56359 .16602 Mdot
.62273 .48329 Mdot
.23928 .46544 Mdot
.57314 .24077 Mdot
.18223 .46199 Mdot
.2088 .49611 Mdot
.65728 .66601 Mdot
.2301 .59656 Mdot
.20377 .45181 Mdot
.47478 .77409 Mdot
.6303 .1914 Mdot
.46288 .81507 Mdot
.47697 .81724 Mdot
.56584 .60277 Mdot
.37125 .40041 Mdot
.28674 .49067 Mdot
.64201 .31682 Mdot
.4398 .52288 Mdot
.19613 .67101 Mdot
.5483 .39902 Mdot
.13934 .60922 Mdot
.46659 .70307 Mdot
.19446 .40678 Mdot
.61462 .33598 Mdot
.53534 .52139 Mdot
.51486 .50022 Mdot
.7148 .68675 Mdot
.3837 .63749 Mdot
.65976 .76128 Mdot
.19781 .51876 Mdot
.59962 .55185 Mdot
.52298 .85579 Mdot
.68221 .79339 Mdot
.28679 .44546 Mdot
.47866 .34477 Mdot
.63392 .8099 Mdot
.61236 .54336 Mdot
.34932 .2686 Mdot
.81556 .62114 Mdot
.76462 .60963 Mdot
.38476 .48394 Mdot
.56366 .27987 Mdot
.76616 .39863 Mdot
.73323 .27902 Mdot
.16261 .51267 Mdot
.79767 .49428 Mdot
.44404 .65229 Mdot
.52896 .50857 Mdot
.8094 .43895 Mdot
.35789 .59625 Mdot
.50748 .62306 Mdot
.29867 .61366 Mdot
.1875 .68922 Mdot
.7295 .33579 Mdot
.66368 .25288 Mdot
.30268 .60932 Mdot
.35365 .5627 Mdot
.37157 .62003 Mdot
.30136 .61924 Mdot
.75347 .62596 Mdot
.60782 .8038 Mdot
.31549 .61949 Mdot
.33154 .80048 Mdot
.45803 .29702 Mdot
.69751 .57628 Mdot
.26316 .49955 Mdot
.42462 .2818 Mdot
.50937 .67922 Mdot
.52803 .19992 Mdot
.80541 .5956 Mdot
.44542 .69268 Mdot
.7496 .66872 Mdot
.5269 .78198 Mdot
.37504 .46705 Mdot
.36584 .37112 Mdot
.79045 .58646 Mdot
.25516 .43388 Mdot
.23768 .64386 Mdot
.39704 .24805 Mdot
.65359 .55106 Mdot
.82009 .57793 Mdot
.64383 .56833 Mdot
.57477 .40679 Mdot
.39793 .57293 Mdot
.60209 .37887 Mdot
.34322 .23138 Mdot
.64743 .39604 Mdot
.27533 .53814 Mdot
.15064 .47377 Mdot
.35165 .53034 Mdot
.3533 .20759 Mdot
.29739 .30572 Mdot
.21976 .57952 Mdot
.71224 .49492 Mdot
.70198 .52213 Mdot
.24947 .74325 Mdot
.54391 .65016 Mdot
.5843 .53442 Mdot
.29173 .69874 Mdot
.28078 .55694 Mdot
.72573 .42164 Mdot
.64659 .55619 Mdot
.42836 .58282 Mdot
.48858 .75312 Mdot
.42681 .31568 Mdot
.32205 .49199 Mdot
.4329 .57046 Mdot
.50804 .2205 Mdot
.63302 .20549 Mdot
.60211 .59443 Mdot
.14875 .60259 Mdot
.42731 .36093 Mdot
.30548 .42661 Mdot
.83804 .44448 Mdot
.15591 .53896 Mdot
.62498 .51498 Mdot
.6926 .79076 Mdot
.51191 .42686 Mdot
.79642 .54756 Mdot
.32639 .53885 Mdot
.46683 .81173 Mdot
.66873 .40541 Mdot
.59284 .28027 Mdot
.47056 .70743 Mdot
.29963 .28534 Mdot
.64207 .51318 Mdot
.3458 .5107 Mdot
.77811 .5717 Mdot
.44043 .27537 Mdot
.40756 .62414 Mdot
.68387 .49832 Mdot
.28973 .44881 Mdot
.3713 .35961 Mdot
.37523 .51591 Mdot
.67981 .26859 Mdot
.48645 .82637 Mdot
.56506 .14409 Mdot
.25751 .54665 Mdot
.57535 .46507 Mdot
.39014 .75789 Mdot
.7627 .64267 Mdot
.27777 .66859 Mdot
.82767 .42063 Mdot
.53692 .25995 Mdot
.38563 .36056 Mdot
.55853 .25067 Mdot
.40259 .35888 Mdot
.5001 .54842 Mdot
.62717 .7147 Mdot
.19956 .54193 Mdot
.30381 .63858 Mdot
.21923 .38896 Mdot
.25014 .64564 Mdot
.66216 .25898 Mdot
.23066 .58799 Mdot
.67185 .61967 Mdot
.37006 .45256 Mdot
.43375 .68848 Mdot
.64488 .20527 Mdot
.83103 .42794 Mdot
.44396 .64016 Mdot
.73171 .4487 Mdot
.77896 .6638 Mdot
.42101 .34392 Mdot
.59392 .48165 Mdot
.42302 .4139 Mdot
.52169 .30628 Mdot
.157 .56492 Mdot
.75872 .62978 Mdot
.52782 .4306 Mdot
.71311 .28177 Mdot
.6912 .25253 Mdot
.48817 .13759 Mdot
.35773 .79519 Mdot
.29256 .55389 Mdot
.42842 .16805 Mdot
.27016 .60845 Mdot
.74741 .29119 Mdot
.68547 .66116 Mdot
.85821 .45466 Mdot
.26816 .45292 Mdot
.76363 .66407 Mdot
.20023 .43389 Mdot
.38967 .62057 Mdot
.66379 .74407 Mdot
.574 .50224 Mdot
.58188 .70288 Mdot
.70102 .72609 Mdot
.46922 .86891 Mdot
.40469 .43766 Mdot
.56702 .7819 Mdot
.43704 .74897 Mdot
.82417 .56795 Mdot
.72796 .61901 Mdot
.45686 .34367 Mdot
.56667 .67758 Mdot
.33245 .25165 Mdot
.58253 .25617 Mdot
.59399 .44024 Mdot
.72462 .62282 Mdot
.44258 .23105 Mdot
.54491 .24322 Mdot
.46772 .8192 Mdot
.28141 .45252 Mdot
.46701 .58091 Mdot
.51616 .41647 Mdot
.34504 .49712 Mdot
.65203 .38996 Mdot
.56945 .51374 Mdot
.42837 .38655 Mdot
.62059 .62898 Mdot
.40655 .62032 Mdot
.31625 .23962 Mdot
.31526 .6582 Mdot
.5369 .80751 Mdot
.28527 .49933 Mdot
.44084 .74093 Mdot
.2914 .68436 Mdot
.25328 .30123 Mdot
.7441 .57072 Mdot
.60479 .25684 Mdot
.74869 .34454 Mdot
.60428 .21734 Mdot
.37414 .49659 Mdot
.51208 .16071 Mdot
.4806 .63466 Mdot
.38262 .4728 Mdot
.41216 .72462 Mdot
.69112 .46795 Mdot
.53446 .43137 Mdot
.76318 .66339 Mdot
.58859 .52492 Mdot
.70501 .32798 Mdot
.67307 .75026 Mdot
.46782 .28375 Mdot
.29696 .47078 Mdot
.73144 .29409 Mdot
.63409 .62459 Mdot
.52026 .8236 Mdot
.40886 .64824 Mdot
.72324 .59874 Mdot
.62814 .21589 Mdot
.58576 .16565 Mdot
.48589 .51447 Mdot
.60097 .31597 Mdot
.48101 .42316 Mdot
.45201 .82727 Mdot
.75672 .64059 Mdot
.53531 .45971 Mdot
.56424 .7368 Mdot
.34639 .55775 Mdot
.60123 .73818 Mdot
.48649 .57361 Mdot
.4693 .22128 Mdot
.27258 .55831 Mdot
.21518 .58049 Mdot
.61599 .41329 Mdot
.55896 .47681 Mdot
.48834 .47012 Mdot
.60641 .30447 Mdot
.27416 .74236 Mdot
.53397 .44314 Mdot
.80355 .50112 Mdot
.308 .45311 Mdot
.46302 .80004 Mdot
.78763 .58341 Mdot
.63527 .66775 Mdot
.38354 .63331 Mdot
.36652 .43069 Mdot
.49586 .73944 Mdot
.45545 .44072 Mdot
.68304 .6052 Mdot
.33339 .50808 Mdot
.82277 .5881 Mdot
.34854 .39073 Mdot
.63185 .31417 Mdot
.55005 .6151 Mdot
.57672 .40024 Mdot
.4225 .68859 Mdot
.85218 .45001 Mdot
.38332 .62331 Mdot
.54617 .26484 Mdot
.53943 .59088 Mdot
.6165 .332 Mdot
.28023 .32582 Mdot
.63735 .18135 Mdot
.20007 .42802 Mdot
.44778 .54063 Mdot
.19203 .4194 Mdot
.70532 .68759 Mdot
.80461 .63949 Mdot
.54119 .25162 Mdot
.5404 .48313 Mdot
.68971 .42838 Mdot
.33632 .72911 Mdot
.5486 .6207 Mdot
.60547 .45406 Mdot
.43215 .58548 Mdot
.52796 .74517 Mdot
.51635 .69398 Mdot
.52243 .46549 Mdot
.73422 .36454 Mdot
.74121 .32328 Mdot
.44922 .79798 Mdot
.44657 .62603 Mdot
.70608 .61859 Mdot
.47187 .22832 Mdot
.86998 .46962 Mdot
.15728 .42211 Mdot
.47812 .42363 Mdot
.42584 .66929 Mdot
.58752 .30932 Mdot
.66793 .58569 Mdot
.29779 .62813 Mdot
.29911 .683 Mdot
.44896 .68398 Mdot
.60135 .43769 Mdot
.68777 .30283 Mdot
.68667 .70022 Mdot
.55184 .30865 Mdot
.55659 .64823 Mdot
.30063 .24783 Mdot
.68057 .77274 Mdot
.76401 .63667 Mdot
.8599 .40658 Mdot
.41713 .63296 Mdot
.50577 .3178 Mdot
.27357 .36373 Mdot
.63705 .21234 Mdot
.59888 .27092 Mdot
.38182 .24556 Mdot
.60245 .66755 Mdot
.53561 .25378 Mdot
.27768 .59322 Mdot
.72398 .34636 Mdot
.59375 .73954 Mdot
.50048 .5373 Mdot
.70572 .52739 Mdot
.53069 .15321 Mdot
.27561 .48368 Mdot
.76183 .35795 Mdot
.30576 .26673 Mdot
.39302 .8314 Mdot
.65801 .21587 Mdot
.69347 .33712 Mdot
.74049 .59638 Mdot
.24853 .39327 Mdot
.4447 .49874 Mdot
.32874 .59849 Mdot
.35391 .26635 Mdot
.38298 .32242 Mdot
.74455 .47574 Mdot
.23513 .35372 Mdot
.56837 .24393 Mdot
.40585 .28622 Mdot
.53611 .48581 Mdot
.33907 .4536 Mdot
.7278 .45205 Mdot
.32786 .60755 Mdot
.42708 .50391 Mdot
.63695 .29329 Mdot
.31796 .45028 Mdot
.40857 .76653 Mdot
.7171 .70341 Mdot
.37223 .83368 Mdot
.77996 .53063 Mdot
.24284 .31617 Mdot
.49485 .35694 Mdot
.50668 .12021 Mdot
.67938 .72518 Mdot
.708 .64977 Mdot
.6295 .78664 Mdot
.6917 .61352 Mdot
.47314 .30627 Mdot
.45619 .44087 Mdot
.79484 .45747 Mdot
.36215 .47971 Mdot
.35191 .29302 Mdot
.2839 .2936 Mdot
.57806 .27803 Mdot
.63177 .25855 Mdot
.65107 .32071 Mdot
.37941 .40551 Mdot
.35049 .53648 Mdot
.39046 .17946 Mdot
.46033 .52494 Mdot
.54395 .44721 Mdot
.4254 .47535 Mdot
.24152 .38529 Mdot
.74351 .74975 Mdot
.25319 .53161 Mdot
.62524 .23693 Mdot
.26721 .47557 Mdot
.3926 .50312 Mdot
.26819 .65312 Mdot
.86251 .34639 Mdot
.55404 .1132 Mdot
.33487 .5053 Mdot
.35032 .77597 Mdot
.26813 .4789 Mdot
.6669 .24925 Mdot
.73133 .56314 Mdot
.53232 .7543 Mdot
.47557 .48533 Mdot
.40385 .52821 Mdot
.48268 .46871 Mdot
.64001 .76977 Mdot
.65471 .20196 Mdot
.26103 .31495 Mdot
.71557 .28442 Mdot
.413 .33825 Mdot
.50748 .46051 Mdot
.8859 .4629 Mdot
.80627 .42777 Mdot
.44086 .33904 Mdot
.1933 .46412 Mdot
.5511 .39709 Mdot
.48946 .37922 Mdot
.76167 .43689 Mdot
.52346 .85472 Mdot
.5692 .24014 Mdot
.66868 .24643 Mdot
.27012 .5432 Mdot
.68658 .56676 Mdot
.46654 .70384 Mdot
.49411 .50987 Mdot
.46678 .32677 Mdot
.45193 .67138 Mdot
.50044 .27522 Mdot
.78095 .64671 Mdot
.50751 .60124 Mdot
.51897 .84157 Mdot
.82147 .37647 Mdot
.34684 .414 Mdot
.333 .72235 Mdot
.40725 .38532 Mdot
.4174 .28486 Mdot
.47598 .24276 Mdot
.52786 .3174 Mdot
.73696 .70077 Mdot
.26731 .20813 Mdot
.56086 .70257 Mdot
.50173 .20688 Mdot
.35687 .564 Mdot
.44523 .58705 Mdot
.33775 .47166 Mdot
.6931 .63308 Mdot
.59862 .57923 Mdot
.40307 .3504 Mdot
.26487 .55263 Mdot
.47652 .71752 Mdot
.13159 .56554 Mdot
.49005 .34666 Mdot
.28415 .64088 Mdot
.75019 .29713 Mdot
.3964 .24793 Mdot
.28472 .41766 Mdot
.4669 .44899 Mdot
.36586 .71491 Mdot
.54383 .48106 Mdot
.81415 .54981 Mdot
.5063 .19305 Mdot
.72655 .31189 Mdot
.35075 .38415 Mdot
.2894 .47187 Mdot
.51964 .40777 Mdot
.65879 .45178 Mdot
.52264 .64288 Mdot
.7795 .45168 Mdot
.52379 .3471 Mdot
.71475 .25379 Mdot
.6692 .5248 Mdot
.58272 .51128 Mdot
.25424 .55944 Mdot
.47628 .1429 Mdot
.25119 .35593 Mdot
.32737 .48338 Mdot
.26457 .28751 Mdot
.67125 .49002 Mdot
.5488 .29927 Mdot
.64497 .61854 Mdot
.49767 .32467 Mdot
.26619 .52619 Mdot
.25615 .27777 Mdot
.75786 .41994 Mdot
.58251 .69323 Mdot
.59055 .72062 Mdot
.39891 .79335 Mdot
.40608 .63495 Mdot
.84565 .38306 Mdot
.6809 .50623 Mdot
.27154 .26824 Mdot
.49459 .82614 Mdot
.26735 .5176 Mdot
.72603 .68737 Mdot
.54605 .39639 Mdot
.61316 .60291 Mdot
.71441 .29085 Mdot
.56644 .40267 Mdot
.41973 .21255 Mdot
.46726 .45665 Mdot
.37823 .2206 Mdot
.67697 .45517 Mdot
.73364 .43258 Mdot
.70766 .67418 Mdot
.24429 .37731 Mdot
.84824 .53499 Mdot
.33934 .73303 Mdot
.85538 .491 Mdot
.84192 .55426 Mdot
.73697 .29393 Mdot
.38158 .23533 Mdot
.16926 .54164 Mdot
.71374 .65307 Mdot
.78598 .59588 Mdot
.64947 .71292 Mdot
.22964 .40642 Mdot
.70094 .55598 Mdot
.24733 .54903 Mdot
.35197 .63189 Mdot
.43425 .66245 Mdot
.08993 .45174 Mdot
.65672 .28149 Mdot
.25775 .53122 Mdot
.68791 .52683 Mdot
.7067 .26097 Mdot
.25013 .3828 Mdot
.69331 .73523 Mdot
.49052 .56898 Mdot
.44494 .46135 Mdot
.36698 .35712 Mdot
.43143 .80198 Mdot
.67079 .5192 Mdot
.28775 .7887 Mdot
.65928 .78269 Mdot
.56013 .72446 Mdot
.48666 .55267 Mdot
.30809 .50582 Mdot
.25353 .66483 Mdot
.70726 .51491 Mdot
.72769 .71327 Mdot
.77072 .65774 Mdot
.80903 .43612 Mdot
.24872 .74112 Mdot
.46873 .80705 Mdot
.63433 .20828 Mdot
.73583 .66419 Mdot
.35306 .51355 Mdot
.69032 .34526 Mdot
.62538 .54394 Mdot
.60764 .69579 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Kooooo`;o0000[?oo
ool001cooooo00?o0000ooooooooool0Voooool2o`000:cooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0;3ooooo0_l0002Gooooo`007?ooool00ol0003o
ooooooooo`1eooooo`;o0000>Oooool2o`0009Oooooo000Looooo`03o`000?oooooooooo07Gooooo
0_l0003Booooo`007?ooool00ol0003oooooooooo`2Qooooo`;o0000Y_ooool001cooooo00?o0000
ooooooooool0XOooool2o`000:Kooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0/oooool2o`0009Cooooo000Looooo`03o`000?oooooooooo0;?ooooo
0_l0002Dooooo`007?ooool00ol0003oooooooooo`2Kooooo`;o00002Oooool2o`000:7ooooo000L
ooooo`03o`000?oooooooooo09_ooooo0_l00009ooooo`;o00000_ooool4o`0009_ooooo000Loooo
o`03o`000?oooooooooo08Gooooo0_l0000<ooooo`;o00000_ooool2o`0000cooooo0_l00003oooo
o`Co00001_ooool2o`0000Kooooo0_l0002;ooooo`007?ooool00ol0003oooooooooo`25ooooo`;o
00001oooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`0000Sooooo0_l0000:ooooo`;o
000000?oooooo`000?l000001_ooool2o`000003ooooool0003o000008Sooooo000Looooo`03o`00
0?oooooooooo08kooooo0_l0000;ooooo`;o00005?ooool3o`0000_ooooo0_l00028ooooo`007?oo
ool2o`0008Kooooo0_l00004ooooo`;o00007?ooool2o`0000;ooooo0_l00003ooooo`;o0000UOoo
ool001cooooo00?o0000ooooooooool0QOooool2o`0000Cooooo0_l0000Looooo`;o00000_ooool2
o`0000Sooooo0_l0002@ooooo`007?ooool00ol0003oooooooooo`29ooooo`;o00002_ooool2o`00
01Gooooo0_l00009ooooo`;o0000T?ooool001cooooo00?o0000ooooooooool0ROooool2o`0000[o
oooo0_l0000<ooooo`;o000000?oooooo`000?l000001?ooool3o`0000Sooooo0_l0002@ooooo`00
7?ooool00ol0003oooooooooo`1iooooo`;o00001?ooool2o`0002;ooooo0_l000000ooooooo0000
o`000005ooooo`;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`00002=ooooo`007?oo
ool00ol0003oooooooooo`1iooooo`;o00001?ooool2o`0000Kooooo0_l0000Zooooo`;o00000_oo
ool2o`000003ooooool0003o000000;ooooo0_l00029ooooo`007?ooool00ol0003oooooooooo`27
ooooo`;o00003_ooool2o`0000Kooooo0_l0000@ooooo`Go00002?ooool2o`0000[ooooo0_l0001m
ooooo`007?ooool00ol0003oooooooooo`1^ooooo`;o00009oooool2o`0000Kooooo0_l0000@oooo
o`Go000000?oooooo`000?l000004Oooool2o`0007gooooo000Looooo`03o`000?oooooooooo06ko
oooo0_l00014ooooo`;o000000?oooooo`000?l00000T?ooool001cooooo00?o0000ooooooooool0
Noooool2o`0001?ooooo0_l0000Mooooo`;o00000_ooool3o`0001Gooooo0ol0001kooooo`007?oo
ool00ol0003oooooooooo`1booooo`;o00001?ooool2o`000003ooooool0003o000001?ooooo0_l0
000Iooooo`;o00000_ooool3o`000004ooooool0003o0000o`0000_ooooo0_l000000ooooooo0000
o`000005ooooo`?o0000Noooool001cooooo00?o0000ooooooooool0L_ooool2o`0000Cooooo0_l0
000Pooooo`Co000000?oooooo`000?l000002_ooool2o`000003ooooool0003o000000;o00000_oo
ool2o`0000_ooooo0_l000000ooooooo0000o`000008ooooo`;o0000NOooool001cooooo00?o0000
ooooooooool0POooool2o`0000;ooooo0_l00002ooooo`Go000000Coooooo`000?l0003ooooo0_l0
0006ooooo`Co000000Coooooo`000?l0003o00001?ooool2o`0000Kooooo0_l00008ooooo`;o0000
5?ooool3o`0007Sooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go
00001_ooool00ol0003oooooooooo`21ooooo`?o000000?oooooo`000?l000000_ooool5o`000003
ooooool0003o000000?o00002_ooool5o`0000?ooooo0ol00003ooooo`;o00002_ooool2o`0000Go
oooo0_l00008ooooo`Co00000_ooool3o`0007Oooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMg
M`Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`21
ooooo`?o000000?oooooo`000?l000002Oooool2o`0000?ooooo0ol00006ooooo`Go00000oooool5
o`000004ooooool0003o0000o`0000Cooooo0_l00002ooooo`;o00001_ooool2o`0000Sooooo1?l0
0003ooooo`;o0000Moooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool0
0onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo087ooooo0_l00002ooooo`;o00003_ooool5
o`0000?ooooo1?l00006ooooo`Co00000_ooool2o`0000Cooooo0_l00002ooooo`;o00001_ooool2
o`0008Sooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q
8Oo^k^h01_ooool3o`0008Kooooo0_l00003ooooo`;o00000oooool2o`0000Kooooo0_l00003oooo
o`;o00002?ooool3o`0000gooooo0_l00006ooooo`;o00004?ooool4o`0007Cooooo00000ooooooo
0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003o
ooooooooo`26ooooo`;o00000oooool2o`0000?ooooo0_l0000<ooooo`;o00005oooool3o`00013o
oooo0_l00002ooooo`;o000000?oooooo`000?l000000_l0001dooooo`0000?ooooooa0@4?ooool0
0_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
Doooool2o`0001[ooooo0_l00003ooooo`;o00007_ooool2o`0000Sooooo0ol000000ooooooo0000
o`000009ooooo`;o000000?oooooo`000?l000001_ooool5o`0000gooooo0_l00002ooooo`;o0000
1Oooool2o`0007;ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oo
ooooV9RHoa0@4006ooooo`03o`000?oooooooooo05?ooooo0_l0000Jooooo`;o00000oooool2o`00
00kooooo0_l00005ooooo`;o00001oooool3o`0000Sooooo0_l000000ooooooo0000o`000009oooo
o`;o000000?oooooo`000?l000002?ooool3o`000003ooooool0003o000000Oooooo0_l000001?oo
oooo0000o`000?l00008ooooo`;o0000L_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2ooo
ool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0JOooool2o`0000oooooo
0_l000000ooooooo0000o`000005ooooo`?o00001?ooool3o`0000Oooooo0_l000000ooooooo0000
o`000005ooooo`;o00002oooool2o`00013ooooo0_l00007ooooo`?o000000?oooooo`000?l00000
1?ooool2o`0007Kooooo000Looooo`03o`000?oooooooooo06Wooooo0ol0000>ooooo`;o000000?o
ooooo`000?l000001_ooool2o`0000Cooooo0ol0000:ooooo`;o00001Oooool2o`0000_ooooo0_l0
000=ooooo`;o00001?ooool3o`0000Cooooo0_l00007ooooo`?o0000MOooool001cooooo00?o0000
ooooooooool0G?ooool2o`0000cooooo0_l0000;ooooo`;o00002oooool5o`0000cooooo0_l0000:
ooooo`;o00006?ooool9o`0000Cooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l0
001eooooo`007?ooool00ol0003oooooooooo`1Looooo`;o00006Oooool2o`0000_ooooo1Ol0000<
ooooo`;o000000?oooooo`000?l000001oooool2o`0001Cooooo0_l00003ooooo`Ko00002Oooool3
o`000004ooooool0003o0000ooooo`;o0000MOooool001cooooo00?o0000ooooooooool0NOooool3
o`0000Cooooo0_l00003ooooo`;o00004Oooool2o`0000Kooooo0_l00004ooooo`;o000000?ooooo
o`000?l000002Oooool2o`000003ooooool0003o000000Sooooo0_l00008ooooo`;o00001Oooool2
o`000003ooooool0003o000007;ooooo000Looooo`03o`000?oooooooooo06Cooooo0_l0000Coooo
o`?o00001?ooool2o`0000Sooooo0_l0000:ooooo`;o000000?oooooo`000?l000001Oooool2o`00
00?ooooo0ol000000ooooooo0000o`000009ooooo`?o00002_ooool2o`0000;ooooo0_l00006oooo
o`;o00001_ooool2o`0007;ooooo000Looooo`03o`000?oooooooooo06Cooooo0_l00006ooooo`;o
00000oooool2o`0000Kooooo0_l000000ooooooo0000o`00000<ooooo`Co00002?ooool2o`000003
ooooool0003o000000Oooooo0_l000000ooooooo0000o`000005o`0000Sooooo0ol00005ooooo`;o
00001?ooool5o`0000Kooooo0_l00006ooooo`;o0000L_ooool001cooooo00?o0000ooooooooool0
K?ooool4o`000003ooooool0003o000000Gooooo0ol000000ooooooo0000o`00000>ooooo`;o0000
1oooool3o`000003ooooool0003o000000Kooooo0ol00003ooooo`;o000000?oooooo`000?l00000
0oooool2o`0000?ooooo0_l00006ooooo`;o00000oooool5o`000003ooooool0003o000001Sooooo
0_l0001Vooooo`007?ooool00ol0003oooooooooo`1Sooooo`;o00000oooool2o`0000Cooooo0_l0
0005ooooo`Go00000oooool2o`0000_ooooo0_l00009ooooo`;o00002_ooool2o`0000cooooo0_l0
000:ooooo`?o00000oooool5o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`00
000Aooooo`;o0000I_ooool001cooooo00?o0000ooooooooool0Hoooool2o`0000?ooooo0_l0000;
ooooo`?o00001Oooool2o`0000_ooooo0_l0000;ooooo`;o00004Oooool2o`0000Cooooo0_l00003
ooooo`?o00000oooool4o`0000?ooooo1?l00005ooooo`;o000000?oooooo`000?l000002?ooool2
o`0000Gooooo0_l0001Xooooo`007?ooool00ol0003oooooooooo`1_ooooo`;o00001oooool2o`00
00Oooooo0_l00009ooooo`;o00002Oooool2o`00017ooooo0_l000001?oooooo0000o`000?ooool2
o`0000?ooooo0ol00004ooooo`?o00003_ooool2o`0000?ooooo0_l000000ooooooo0000o`000005
o`0000?ooooo0_l0001Xooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o00001_ooool4o`00
00Gooooo0_l00007ooooo`;o00000oooool2o`0000;ooooo0_l00009ooooo`;o00004oooool3o`00
00Gooooo0_l00002ooooo`;o000000?oooooo`000?l000000oooool3o`0000Gooooo0_l00003oooo
o`;o00002Oooool2o`0000;ooooo0ol000000ooooooo0000o`000002o`000003ooooool0003o0000
06gooooo000Looooo`;o0000F?ooool2o`0000?ooooo1?l00006ooooo`Co00000oooool2o`0000Go
oooo0_l00003ooooo`Ko00000_ooool2o`0000;ooooo1?l0000Dooooo`;o00000_ooool6o`0000;o
oooo1Ol00002ooooo`Co00000_ooool4o`0000Sooooo0_l00002ooooo`;o000000?oooooo`000?l0
00001_ooool2o`0000;ooooo0_l0000?ooooo`;o0000HOooool001cooooo00?o0000ooooooooool0
Eoooool2o`0000?ooooo0_l00008ooooo`Co00000oooool2o`0000Gooooo0_l00003ooooo`Co0000
2?ooool4o`0000Cooooo0_l0000>ooooo`?o00000oooool4o`0000?ooooo1?l000001?oooooo0000
o`000?ooool2o`0000Cooooo0_l0000<ooooo`Go00002Oooool2o`0000Oooooo0_l00005ooooo`Co
0000HOooool001cooooo00?o0000ooooooooool0SOooool2o`0000Sooooo0_l00005ooooo`Co0000
2?ooool2o`0000?ooooo0_l00005ooooo`;o000000?oooooo`000?l000000_l00002ooooo`Co0000
1Oooool3o`0000Wooooo0_l000000ooooooo0000o`000004ooooo`;o00001Oooool2o`0006?ooooo
000Looooo`03o`000?oooooooooo063ooooo0_l00003ooooo`;o00001?ooool2o`0000Sooooo0_l0
000Booooo`;o00003?ooool2o`0000Gooooo1?l00006ooooo`;o000000?oooooo`000?l000002Ooo
ool2o`000003ooooool0003o000000;o00000_ooool4o`0000Kooooo0_l00007ooooo`?o00000_oo
ool2o`0000Wooooo0_l0001Uooooo`007?ooool00ol0003oooooooooo`1Gooooo`;o00001oooool2
o`0000?ooooo0_l00003ooooo`?o000000?oooooo`000?l000001Oooool4o`0000cooooo0_l00002
ooooo`;o00004_ooool2o`0000Wooooo0_l000000ooooooo0000o`000002o`0001Kooooo0_l0000;
ooooo`?o00003Oooool2o`0006Gooooo000Looooo`03o`000?oooooooooo05Oooooo0_l00003oooo
o`;o00000_ooool2o`0000Sooooo0_l00002ooooo`Go00001?ooool2o`000003ooooool0003o0000
00Wooooo0_l0000Fooooo`;o000000Coooooo`000?l0003o00001_ooool2o`0000;ooooo0ol0000E
ooooo`?o0000POooool001cooooo00?o0000ooooooooool0E?ooool2o`0000Gooooo0ol00002oooo
o`?o00001oooool2o`0000;ooooo1Ol00004ooooo`;o000000?oooooo`000?l000009?ooool3o`00
00Kooooo0_l00002ooooo`Co00000_ooool2o`0000Kooooo0_l00007ooooo`Co00003Oooool6o`00
00[ooooo0_l0001Rooooo`007?ooool00ol0003oooooooooo`18ooooo`?o00002Oooool3o`000004
ooooool0003o0000ooooo`;o00001?ooool2o`0000Oooooo0_l00002ooooo`Co00000_ooool2o`00
0003ooooool0003o000001Cooooo0_l0000<ooooo`;o00000_ooool2o`0000gooooo2?l00005oooo
o`?o000000?oooooo`000?l000000oooool2o`000003ooooool0003o000000;o00001_ooool2o`00
00;ooooo1_l00008ooooo`Go0000HOooool001cooooo00?o0000ooooooooool0B?ooool3o`0000[o
oooo0_l000000ooooooo0000o`00000@ooooo`;o00001?ooool2o`0000;ooooo0_l0000Eooooo`Co
00001?ooool2o`0000Kooooo0_l00002ooooo`;o00001oooool2o`0000Gooooo1ol00005ooooo`?o
000000Coooooo`000?l0003ooooo0_l00003ooooo`Co00001_ooool2o`0000Oooooo0_l00007oooo
o`;o000000Coooooo`000?l0003o0000H?ooool001cooooo00?o0000ooooooooool0Coooool2o`00
01Oooooo0_l00007ooooo`Co00001_ooool2o`0000Sooooo0_l00004ooooo`;o00001_ooool2o`00
00[ooooo0_l00007ooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o0000
00;o00000_ooool2o`000003ooooool0003o000000Gooooo0_l0000:ooooo`;o00002_ooool2o`00
00_ooooo0_l000000ooooooo0000o`00001Mooooo`007?ooool00ol0003oooooooooo`1?ooooo`;o
00005oooool2o`0000Oooooo1?l00002ooooo`;o00000_ooool2o`0000Sooooo0ol0000Gooooo`;o
00002_ooool2o`0000Kooooo0_l00003ooooo`;o00000oooool2o`0000oooooo0_l00002ooooo`;o
00004?ooool2o`0000Cooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o0000
0oooool3o`0000Gooooo0_l000000ooooooo0000o`00000<ooooo`;o00001Oooool4o`0000;ooooo
1?l0000<ooooo`;o00005?ooool3o`000003ooooool0003o000000;o00000_ooool2o`0000Kooooo
0ol00002ooooo`;o00002oooool2o`0000;ooooo0_l00004ooooo`;o00002_ooool3o`0006;ooooo
000Looooo`03o`000?oooooooooo05;ooooo0_l00005ooooo`;o00000oooool3o`0000Gooooo0_l0
00000ooooooo0000o`000003ooooo`;o00002?ooool2o`000003ooooool0003o000000Go00000_oo
ool2o`0000Sooooo0_l00004ooooo`;o00001?ooool2o`0000kooooo0ol000000ooooooo0000o`00
0002o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000000oooool2o`0000Kooooo0ol0
000<ooooo`;o00002oooool2o`0006;ooooo000Looooo`03o`000?oooooooooo03?ooooo0_l0000M
ooooo`;o00004_ooool2o`0000Kooooo0_l000000ooooooo0000o`000005ooooo`Oo00003oooool2
o`0000[ooooo0_l0000Cooooo`Co00000_ooool2o`0000;ooooo0_l00007ooooo`;o00001Oooool3
o`0000;ooooo0_l00008ooooo`;o00002_ooool3o`0000Sooooo0_l0001Hooooo`007?ooool00ol0
003oooooooooo`0cooooo`;o00005_ooool2o`0000Cooooo0ol00005ooooo`;o00002_ooool2o`00
00Sooooo1?l00007ooooo`Co00004?ooool2o`0000gooooo0_l0000=ooooo`;o00000oooool2o`00
00;ooooo0_l0000;ooooo`;o00001oooool2o`000003ooooool0003o000000Wooooo0_l00009oooo
o`Co00000_ooool4o`000003ooooool0003o000005Sooooo000Looooo`03o`000?oooooooooo04_o
oooo0_l00004ooooo`?o00001Oooool2o`0000[ooooo0_l00008ooooo`;o00006oooool2o`0000;o
oooo0ol0000:ooooo`;o00001_ooool2o`0000Gooooo1?l0000?ooooo`;o00002Oooool3o`0000co
oooo0_l00004ooooo`;o00001Oooool2o`0000;ooooo1?l00002ooooo`;o0000Eoooool001cooooo
0_l0001@ooooo`;o00001?ooool2o`00013ooooo0_l00005ooooo`;o00005oooool2o`0000;ooooo
0ol00002ooooo`Co00004Oooool2o`0000Oooooo0_l0000?ooooo`;o00002Oooool2o`0000Gooooo
0_l0000<ooooo`;o000000?oooooo`000?l000002Oooool2o`000003ooooool0003o000005Oooooo
000Looooo`03o`000?oooooooooo04oooooo0_l00004ooooo`;o00001?ooool2o`0000Sooooo1Ol0
0004ooooo`;o00005oooool2o`0000;ooooo0ol00004ooooo`;o00006_ooool2o`00017ooooo0_l0
000>ooooo`;o00002Oooool2o`0000Cooooo0_l00009ooooo`;o0000F_ooool001cooooo00?o0000
ooooooooool0Foooool4o`0000Kooooo1Ol0000[ooooo`?o00003_ooool2o`0000gooooo0_l00008
ooooo`Co00003_ooool2o`0000;ooooo1Ol00002ooooo`;o00003_ooool2o`0005_ooooo000Loooo
o`03o`000?oooooooooo04Oooooo0_l0000Booooo`Co00001oooool2o`0002gooooo0ol0000;oooo
o`;o000000?oooooo`000?l000001oooool2o`0000Cooooo0_l00004ooooo`;o00000_ooool2o`00
00Cooooo0_l00009ooooo`;o00000oooool5o`0000Sooooo0_l00008ooooo`;o00001Oooool2o`00
05Cooooo000Looooo`03o`000?oooooooooo04Oooooo0_l0000Booooo`;o00002Oooool2o`0002So
oooo0_l000000ooooooo0000o`000002ooooo`Co00001oooool3o`0000Oooooo0_l000000ooooooo
0000o`00000:ooooo`;o00002?ooool2o`0000?ooooo0_l00004ooooo`;o00003Oooool2o`000003
ooooool0003o000000Cooooo0_l00006ooooo`;o000000Coooooo`000?l0003ooooo0_l0001Aoooo
o`007?ooool00ol0003oooooooooo`0looooo`;o00003Oooool2o`0000Cooooo0_l00008ooooo`;o
0000:_ooool2o`0000Oooooo0_l000001?oooooo0000o`000?ooool5o`0000Oooooo0_l00006oooo
o`Co00004Oooool2o`0000Sooooo0ol000000ooooooo0000o`00000@ooooo`;o00001oooool2o`00
00Kooooo0_l00004ooooo`;o0000DOooool001cooooo00?o0000ooooooooool0??ooool2o`0000So
oooo0_l00003ooooo`;o00001?ooool2o`0000gooooo0_l0000Sooooo`Co00000oooool2o`000003
ooooool0003o000000Gooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Go
oooo1_l0000:ooooo`;o00001Oooool2o`0000Oooooo0ol00002ooooo`;o00002Oooool2o`000003
ooooool0003o000000_ooooo0_l000000ooooooo0000o`00001Looooo`007?ooool00ol0003ooooo
ooooo`16ooooo`;o00006?ooool2o`0001Oooooo0_l0000:ooooo`Co00000oooool5o`000003oooo
ool0003o000000?ooooo0_l000000ooooooo0000o`000003o`0000;ooooo0_l00002ooooo`;o0000
00?oooooo`000?l000000_ooool2o`0000Kooooo0_l00002ooooo`;o00002_ooool2o`0000;ooooo
0_l00006ooooo`;o000000?oooooo`000?l000000oooool2o`000003ooooool0003o000000Cooooo
0_l00008ooooo`;o0000G?ooool001cooooo00?o0000ooooooooool0C?ooool2o`0000Wooooo0_l0
000Pooooo`;o00003?ooool2o`0000Cooooo0ol000001?oooooo0000o`000?l00003ooooo`Co0000
00?oooooo`000?l000000_l00003ooooo`Co00001Oooool2o`0000Kooooo0_l00002ooooo`;o0000
2_ooool3o`0000;ooooo0_l00005ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0000Oo
oooo0_l00003ooooo`;o00001Oooool2o`0000Cooooo1?l0001Booooo`007?ooool00ol0003ooooo
ooooo`1<ooooo`;o00002Oooool2o`00027ooooo0_l00004ooooo`;o00001Oooool2o`0000?ooooo
1ol000000ooooooo0000o`000005o`0000;ooooo0ol00003ooooo`;o00000_ooool2o`0000Gooooo
0_l00008ooooo`;o00002?ooool2o`000003ooooool0003o000000;ooooo0_l00009ooooo`Ko0000
1_ooool3o`0000;ooooo0ol00005ooooo`;o00001?ooool4o`0005;ooooo000Looooo`03o`000?oo
oooooooo04[ooooo0_l0000Aooooo`;o00006Oooool4o`0000Cooooo0_l00005ooooo`;o000000?o
ooooo`000?l000000_l00002ooooo`;o00000_ooool3o`0000;ooooo1?l000001?oooooo0000o`00
0?l00006ooooo`;o00000oooool4o`0000kooooo0_l00002ooooo`Go00000oooool4o`0000Kooooo
1?l00008ooooo`?o00000_ooool2o`0006;ooooo000Looooo`03o`000?oooooooooo03Kooooo0_l0
000Booooo`Co00003oooool2o`0001Wooooo0_l0000;ooooo`?o00000_ooool5o`000003ooooool0
003o000000;ooooo1?l000000ooooooo0000o`000002o`000005ooooool0003o0000o`000?ooool0
0_l000000ooooooo0000o`000002o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o0000
2Oooool4o`0000;ooooo0ol00003ooooo`Ko00001?ooool2o`0000Sooooo0_l0000Eooooo`;o0000
D_ooool001cooooo00?o0000ooooooooool0=_ooool2o`0001Cooooo0_l0000<ooooo`;o00001ooo
ool2o`0001gooooo1_l00003ooooo`So00000_ooool4o`0000Gooooo0_l00002ooooo`;o000000?o
ooooo`000?l000000_l00006ooooo`;o00000_ooool2o`0000Sooooo0_l000000ooooooo0000o`00
0002ooooo`;o00002?ooool2o`0000Oooooo0_l00004ooooo`Co00001oooool3o`0000[ooooo0_l0
001Booooo`007?ooool00ol0003oooooooooo`1Booooo`;o00001_ooool2o`0000Oooooo0_l0000M
ooooo`Oo00000_ooool8o`000004ooooool0003o0000ooooo`?o00001?ooool6o`000003ooooool0
003o000000Sooooo0_l0000:ooooo`Co000000?oooooo`000?l000000_ooool2o`0000Sooooo0ol0
0006ooooo`;o00000_ooool6o`0000Oooooo1Ol00009ooooo`;o0000DOooool001cooooo00?o0000
ooooooooool0:?ooool2o`0002Sooooo0_l0000Sooooo`;o00003?ooool4o`000003ooooool0003o
000000_o000000?oooooo`000?l000002_l000000ooooooo0000o`000007ooooo`Go00002?ooool2
o`0000?ooooo0_l00007ooooo`Co00000_ooool2o`0000[ooooo0_l00006ooooo`;o00001_ooool2
o`0000;ooooo0_l00005ooooo`;o0000DOooool001cooooo00?o0000ooooooooool0:?ooool2o`00
02oooooo0_l00002ooooo`;o00006?ooool2o`0000Sooooo0_l00002ooooo`;o00000_oooolKo`00
00;ooooo0_l000000ooooooo0000o`000002ooooo`?o000000?oooooo`000?l000005_ooool4o`00
00;ooooo0_l00002ooooo`;o00001oooool2o`0000Gooooo0_l00002ooooo`;o00001_ooool2o`00
02?ooooo0_l0000cooooo`007?ooool2o`0005Cooooo0_l00004ooooo`;o00000_ooool2o`00023o
oooo1_l00002ooooo`Oo000000?oooooo`000?l000004ol00002ooooo`Wo000000?oooooo`000?l0
00002oooool2o`00013ooooo0_l00002ooooo`;o00001oooool2o`0000Gooooo0_l00002ooooo`;o
00001Oooool2o`0002Cooooo0_l0000cooooo`007?ooool00ol0003oooooooooo`16ooooo`;o0000
00?oooooo`000?l000002?ooool4o`0000;ooooo0_l00006ooooo`;o00003_ooool2o`0000cooooo
0_l000001?oooooo0000o`000?l00002oooooaGo000000?oooooo`000?l000001Ol000000ooooooo
0000o`000002o`000003ooooool0003o000000;o00000_ooool2o`0000_ooooo0_l0000Yooooo`Co
00000_ooool2o`0000?ooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`0`ooooo`Co0000
4_ooool2o`000003ooooool0003o000000;ooooo0ol00005ooooo`;o00002?ooool4o`0000kooooo
1?l00009ooooo`;o00000_ooool3o`0000;ooooo4ol000000ooooooo0000o`000007o`000003oooo
ool0003o000000;o0000;_ooool2o`0000oooooo1?l00007ooooo`;o00001_ooool2o`0004cooooo
000Looooo`03o`000?oooooooooo033ooooo1?l0000Aooooo`;o00001_ooool3o`0000oooooo0_l0
000Booooo`Co00001_ooool4o`000004ooooool0003o0000o`0000Gooooo5_l00002ooooo`Co0000
00Goooooo`000?l0003o0000ooooo`02o`0002[ooooo0_l00003ooooo`;o00002?ooool2o`0000co
oooo0_l00005ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0AOooool2o`0000Oooooo
1?l0000Rooooo`?o00000oooool7o`0000;ooooo0_l00002ooooo`[o000000?oooooo`000?l00000
4ol000000ooooooo0000o`000003o`0002oooooo0_l00004ooooo`;o00000_ooool2o`0000cooooo
0_l00003ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0AOooool2o`0000;ooooo0_l0
0003ooooo`Co00000oooool2o`0002?ooooo0ol00008ooooob;o00000_ooool3o`0000;ooooo0_l0
0007ooooo`;o00008?ooool2o`0000Oooooo0_l000000ooooooo0000o`000004ooooo`;o00000ooo
ool2o`0000Kooooo1?l00006ooooo`;o0000AOooool001cooooo00?o0000ooooooooool0BOooool2
o`0000Gooooo0_l00003ooooo`;o0000:?ooool^o`000003ooooool0003o000000Oooooo0_l0000P
ooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00000oooool2o`0000Kooooo1?l00006
ooooo`;o0000AOooool001cooooo00?o0000ooooooooool0D?ooool2o`00027ooooo0_l0000:oooo
o`Ko00000_oooolVo`0003;ooooo0_l00006ooooo`Co00004?ooool2o`0004cooooo000Looooo`03
o`000?oooooooooo06oooooo0_l00002ooooo`;o00003?ooool<o`000003ooooool0003o000001Ko
00000_ooool3o`0000;ooooo0_l00003ooooo`;o00001Oooool2o`0002;ooooo0_l00008ooooo`Ko
00003?ooool5o`0004_ooooo000Looooo`03o`000?oooooooooo04cooooo0_l0000?ooooo`;o0000
00?oooooo`000?l000003Oooool2o`0001;ooooo2_l000000ooooooo0000o`00000Bo`000004oooo
ool0003o0000o`0000;ooooo0ol00002ooooo`;o00000oooool2o`0000Gooooo0_l0000Eooooo`;o
00002oooool3o`0000Sooooo0_l000000ooooooo0000o`00000:ooooo`Co000000?oooooo`000?l0
00002Oooool2o`00043ooooo000Looooo`03o`000?oooooooooo03[ooooo0_l00006ooooo`;o0000
0oooool2o`0000?ooooo0_l00002ooooo`;o00002_ooool3o`000003ooooool0003o000000gooooo
0_l0000Aooooo`_o000000Coooooo`000?l0003ooooo4?l00002ooooo`Go000000?oooooo`000?l0
00000_ooool2o`00017ooooo0ol0000=ooooo`;o00000oooool2o`0000Oooooo0_l00006ooooo`;o
00003oooool6o`0000[ooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0jooooo`;o0000
1_ooool2o`0000?ooooo0_l00003ooooo`Ko00002_ooool2o`00013ooooo0ol00008ooooo`;o0000
0_ooool3o`0000;ooooo9_l00005ooooo`;o00001Oooool2o`0000[ooooo0ol0000=ooooo`?o0000
0_ooool2o`0000Oooooo0_l00006ooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo
0_l00004ooooo`Co00000oooool3o`0000[ooooo1?l0000hooooo`007?ooool00ol0003ooooooooo
o`0/ooooo`;o00003?ooool2o`0000_ooooo0_l00002ooooo`Ko00007Oooool2o`0000Wooooo0_l0
0002ooooo`?o000000?oooooo`000?l00000:?l00002ooooo`;o00001Oooool3o`0000[ooooo0_l0
0009ooooo`Oo00000_ooool2o`0000Oooooo0_l00005ooooo`;o00000_ooool2o`000003ooooool0
003o000000?o00000_ooool2o`0000Cooooo0_l00005ooooo`Co00002Oooool4o`0003Sooooo000L
ooooo`03o`000?oooooooooo02cooooo0_l0000Fooooo`;o000000Goooooo`000?l0003o0000oooo
o`02o`000003ooooool0003o000001gooooo0_l0000Aoooooaco000000?oooooo`000?l000003?l0
0004ooooo`;o00001?ooool2o`0000[ooooo0_l00005ooooo`[o00000_ooool3o`0000kooooo0_l0
0005ooooo`Co00002?ooool2o`0000Gooooo1Ol00015ooooo`0000Koooooonk^k_lb<S;o0000oc8b
<_o^k^h5ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0
8_ooool2o`0001_ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0ol00002ooooo`;o0000
1oooool4o`0000kooooo0_l00009ooooo`;o00000_ooool2o`0000;ooooo6ol00002ooooo`oo0000
0oooool4o`000003ooooool0003o000001;ooooo3ol00006ooooo`;o00003oooool2o`0000Sooooo
0ol00004ooooo`Co0000A_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Rooooo`;o00002oooool2o`0000Go
oooo0_l00007ooooo`;o00000_ooool2o`000003ooooool0003o000000Cooooo0ol00003ooooo`;o
00001oooool6o`0000Wooooo0_l0000<ooooo`Ko00000ooooolJo`000003ooooool0003o000000[o
000000?oooooo`000?l000002?l000000ooooooo0000o`000007ooooo`;o00000oooool2o`0000Go
oooo4Ol00003ooooo`;o00001_ooool2o`000003ooooool0003o000000oooooo0_l00006ooooo`;o
0000A_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo
00?o0000ooooooooool0;oooool2o`0000Gooooo0_l000000ooooooo0000o`000008ooooo`;o0000
00Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00000Aooooo`;o00002Oooool2o`0000ko
oooo0_l00006oooooaWo000000?oooooo`000?l000001Ol000000ooooooo0000o`000002o`000003
ooooool0003o000000Ko00001?ooool2o`000003ooooool0003o000000?ooooo0_l00003ooooo`;o
00001Oooool3o`0000;ooooo3_l000000ooooooo0000o`000003ooooo`;o000000Coooooo`000?l0
003ooooo0_l00006ooooo`;o00000oooool2o`0000Oooooo0_l00003ooooo`;o0000A?ooool00003
ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?m4A4CogMgMooooool00007oooo
o`?o00008oooool2o`00017ooooo0_l000000ooooooo0000o`00000>ooooo`;o00003oooool4o`00
0003ooooool0003o000001Cooooo0_l0000;ooooob7o000000?oooooo`000?l000001?l00003oooo
o`?o00001?ooool3o`000003ooooool0003o000000Gooooo0_l00004ooooo`Oo00000_ooool>o`00
0003ooooool0003o000000?ooooo1?l0000:ooooo`;o00000oooool2o`0000Oooooo0_l00003oooo
o`;o0000A?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?oMgMgo
EEEEooooool00007ooooo`03o`000?oooooooooo02?ooooo0_l0000Cooooo`;o00002_ooool2o`00
0003ooooool0003o0000017ooooo1?l000000ooooooo0000o`00000:ooooo`;o00000oooool2o`00
00?ooooo0_l000000ooooooo0000o`000007ooooob[o00000_ooool3o`0000Cooooo0_l00002oooo
o`;o00001Oooool2o`0000?ooooo6?l000000ooooooo0000o`000003ooooo`Co00007oooool2o`00
04;ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oMgMgolc<c?l0
00001oooool00ol0003oooooooooo`0hooooo`;o000000?oooooo`000?l000001_ooool3o`000003
ooooool0003o000000Wooooo0_l00008ooooo`?o000000?oooooo`000?l000002Oooool3o`0000;o
oooo0_l00006ooooo`;o00001ooooolBo`0000;ooooo5_l00002ooooo`;o00001_ooool5o`0000Co
oooo0_l00004oooooaSo000000?oooooo`000?l000001?ooool2o`00023ooooo0_l0000<ooooo`;o
0000=?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007oooo
o`03o`000?oooooooooo03_ooooo0_l000001?oooooo0000o`000?l00002ooooo`Co00002oooool4
o`0000Kooooo0ol000000ooooooo0000o`000007ooooo`;o000000?oooooo`000?l000000_ooool2
o`0000;ooooo0_l00006ooooo`;o00000_oooolDo`000003ooooool0003o000001Co000000?ooooo
o`000?l000001oooool4o`0000Gooooo0ol00004oooooaOo00001oooool4o`0002cooooo0_l0000d
ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o
0000ooooooooool0?_ooool5o`000004ooooool0003o0000o`0000[ooooo0_l000000ooooooo0000
o`00000Cooooo`;o00000_ooool2o`0000Gooooo0_l00004ooooo`Co00000_oooolWo`000003oooo
ool0003o000000Co00004Oooool4o`000003ooooool0003o000001Oo00001Oooool2o`000003oooo
ool0003o000000Kooooo0ol0000Cooooo`Co0000@_ooool001cooooo00?o0000ooooooooool0?ooo
ool4o`0000kooooo0_l00006ooooo`;o00001Oooool2o`0000_ooooo0_l00008ooooo`;o000000Co
ooooo`000?l0003o00000oooool2o`0000;ooooo1_l000000ooooooo0000o`00000Qo`0001?ooooo
0_l000000ooooooo0000o`00000Go`0000?ooooo1?l000001?oooooo0000o`000?ooool2o`0000?o
oooo0ol00009ooooo`;o00002?ooool4o`0004;ooooo000Looooo`03o`000?oooooooooo02Oooooo
0_l0000@ooooo`Co00000_ooool2o`0001Sooooo0_l00005ooooo`;o00003_ooool2o`0000Cooooo
0ol000000ooooooo0000o`000008ooooobCo00000_ooool2o`0000Kooooo0_l0000=ooooo`;o0000
00?oooooo`000?l000006?l00002ooooo`;o00001_ooool2o`0000Gooooo0_l000000ooooooo0000
o`000005ooooo`;o00000_ooool2o`0000Kooooo1_l0000nooooo`007?ooool00ol0003ooooooooo
o`0Wooooo`;o000000?oooooo`000?l000000oooool2o`0000Sooooo1?l0000cooooo`Co00000_oo
ool2o`0000;ooooo0ol00002ooooo`;o00000ooooolSo`0000?ooooo1?l00004ooooo`;o00003_oo
oolLo`0000[ooooo0_l00005ooooo`Go00002Oooool2o`0000Gooooo1ol0000nooooo`007?ooool0
0ol0003oooooooooo`0Zooooo`;o00000oooool2o`0000Gooooo0_l000001?oooooo0000o`000?l0
000Tooooo`;o00004?ooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo9ol0
00000ooooooo0000o`00000Dooooo`;o00000_ooool:o`000003ooooool0003o000000?o000000?o
ooooo`000?l000000_l0000<ooooo`?o00001_ooool2o`00013ooooo1?l00004ooooo`;o0000?Ooo
ool001cooooo00?o0000ooooooooool0=_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000Q
ooooo`;o00000_ooool2o`0000gooooo0_l000000ooooooo0000o`000007ooooo`?o00000_ooool:
o`000003ooooool0003o000001[o00002Oooool2o`0000[ooooo1?l00002oooooaSo00002Oooool3
o`000003ooooool0003o000000Gooooo0_l0000>ooooo`;o00001_ooool3o`0003cooooo000Loooo
o`03o`000?oooooooooo01kooooo0_l0000Iooooo`;o00000_ooool2o`00013ooooo0_l0000;oooo
o`;o00000_ooool2o`0000;ooooo0_l0000=ooooo`;o000000Coooooo`000?l0003ooooo0_l00004
ooooo`Co000000?oooooo`000?l000004_l000000ooooooo0000o`00000Ao`0000Sooooo0_l00003
ooooo`;o00000oooool6o`000005ooooool0003o0000o`000?ooool05Ol00009ooooo`;o00000_oo
ool2o`0000Gooooo0_l0000Gooooo`;o0000??ooool001cooooo00?o0000ooooooooool07_ooool2
o`0000gooooo0_l0000:ooooo`;o00000_ooool2o`0000_ooooo0ol00002ooooo`;o00002oooool3
o`000003ooooool0003o000001;ooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo0_l00000
0ooooooo0000o`000002o`000003ooooool0003o000000ko000000?oooooo`000?l000001_l00002
ooooo`Co00000_ooool2o`0000Cooooo0_l00007ooooo`;o00000oooool3o`0000Cooooo5_l0000<
ooooo`;o00000_ooool2o`0000Kooooo0ol0000=ooooo`;o0000A?ooool001cooooo00?o0000oooo
ooooool0;Oooool2o`0000Gooooo0_l0000Dooooo`Co00003oooool2o`00013ooooo0_l00003oooo
o`;o00001oooool2o`000004ooooool0003o0000o`0000?ooooo6_l00002ooooo`;o00003?ooool2
o`0000_ooooo1Ol00004oooooaGo000000?oooooo`000?l000002oooool2o`0000Sooooo0ol0000=
ooooo`;o00000_ooool2o`00043ooooo000Looooo`03o`000?oooooooooo03Cooooo0_l0000Foooo
o`;o00000_ooool2o`0000;ooooo0_l0000Iooooo`;o00003ooooolNo`000004ooooool0003o0000
ooooo`;o000000?oooooo`000?l000000_ooool5o`0000kooooo0ol000000ooooooo0000o`000004
oooooaGo000000?oooooo`000?l000000ol00008ooooo`;o00002?ooool2o`0000[ooooo0_l00002
ooooo`;o00000_ooool2o`00043ooooo000Looooo`03o`000?oooooooooo03Wooooo0_l00002oooo
o`;o00004Oooool2o`0000;ooooo0_l00003ooooo`;o00001_ooool2o`0001oooooo5?l000001Ooo
oooo0000o`000?l0003ooooo00?o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00
0002ooooo`Ko00003?ooool3o`0000[ooooo4_l000000ooooooo0000o`000004o`0001Wooooo0_l0
0003ooooo`;o00001_ooool4o`000003ooooool0003o000003_ooooo000Looooo`03o`000?oooooo
oooo027ooooo0_l0000Booooo`;o00000_ooool2o`0000;ooooo0_l0000;ooooo`;o00001Oooool2
o`0000Kooooo0ol00005ooooo`;o00003Oooool2o`0000Oooooo0_l00002ooooo`;o00000_ooool2
o`0000;ooooo0_l00002ooooo`So000000?oooooo`000?l000000_l000000ooooooo0000o`000005
o`000004ooooool0003o0000ooooo`?o00000oooool2o`0000?ooooo0_l000000ooooooo0000o`00
0009ooooo`;o00002?ooool2o`000003ooooool0003o000000_o00000_ooool3o`000003ooooool0
003o000000;ooooo0_l00002ooooo`;o00001Oooool2o`0000?ooooo0_l00009ooooo`;o00003Ooo
ool2o`000003ooooool0003o000000;o0000>Oooool001cooooo0_l0000Kooooo`;o00001Oooool2
o`00017ooooo0ol00007ooooo`;o00000_ooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool4
o`0000Sooooo0_l000000ooooooo0000o`000007ooooo`;o00000_ooool2o`0000?ooooo0_l00002
ooooo`So00001?ooool2o`000003ooooool0003o000000?o000000?oooooo`000?l000003Ol00000
0ooooooo0000o`000002o`0000;ooooo0_l00003ooooo`Go000000?oooooo`000?l000004?ooool2
o`000003ooooool0003o000000;ooooo3Ol000001?oooooo0000o`000?l00002ooooo`;o00000_oo
ool2o`0000Cooooo0ol00003ooooo`;o00000_ooool2o`0000;ooooo1?l0000Aooooo`Co000000?o
ooooo`000?l000004oooool2o`00027ooooo000Looooo`03o`000?oooooooooo01[ooooo0_l0000H
ooooo`?o00000oooool2o`0000;ooooo0_l00002ooooo`;o00003oooool2o`0000?ooooo0_l00006
ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`000003ooooool0003o000000Sooooo0_l0
0008ooooo`?o00000_ooool2o`0000Kooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo
1Ol000000ooooooo0000o`000002o`0000?ooooo1?l000000ooooooo0000o`000003o`0000;ooooo
0_l00003ooooo`;o00003?ooool2o`0000Gooooo0ol000000ooooooo0000o`000006o`000004oooo
ool0003o0000ooooo`Go00003?ooool2o`0000Sooooo0_l00002ooooo`Co00005Oooool5o`00017o
oooo0_l0000Qooooo`007?ooool00ol0003oooooooooo`0aooooo`;o000000?oooooo`000?l00000
1?ooool2o`0000Gooooo0_l0000@ooooo`;o00002oooool5o`0000Gooooo0_l0000Booooo`;o0000
1?ooool2o`0000Gooooo0_l00002ooooo`Co000000?oooooo`000?l000002?l00004ooooo`;o0000
0_ooool6o`0000?ooooo0_l00002ooooo`;o00003?ooool2o`0000Kooooo0_l0000=ooooo`;o0000
00?oooooo`000?l000002Oooool2o`0000?ooooo0_l00004ooooo`;o00001_ooool2o`0000?ooooo
1?l0000>ooooo`;o000000?oooooo`000?l00000=?ooool001cooooo00?o0000ooooooooool09Ooo
ool2o`0000Gooooo0_l00003ooooo`;o000000?oooooo`000?l000002oooool2o`00013ooooo0_l0
0005ooooo`;o00001_ooool2o`0000Gooooo0ol0000Hooooo`;o00000oooool6o`000005ooooool0
003o0000o`000?ooool02?l00002ooooo`;o000000?oooooo`000?l000000oooool2o`0000;ooooo
0_l00003ooooo`;o00002Oooool4o`0000Kooooo0_l0000Booooo`;o00003?ooool2o`0000?ooooo
0_l00004ooooo`;o00000oooool2o`000003ooooool0003o000000?ooooo1?l0000>ooooo`;o0000
=oooool001cooooo00?o0000ooooooooool09Oooool2o`0000Gooooo0_l00009ooooo`?o000000?o
ooooo`000?l000000_l0000=ooooo`;o00003?ooool2o`0000gooooo0ol0000:ooooo`;o00004Ooo
ool2o`0000;ooooo2?l000000ooooooo0000o`000003ooooo`So00001oooool2o`0000Wooooo0_l0
0003ooooo`Co00001_ooool2o`0001;ooooo0_l0000Looooo`;o00006?ooool2o`0000[ooooo0_l0
000[ooooo`007?ooool00ol0003oooooooooo`0gooooo`?o000000?oooooo`000?l000000_l0000;
ooooo`Co00008Oooool2o`0000Gooooo0_l00008ooooo`;o00000_ooool2o`0000Oooooo2?l00002
ooooo`;o00000_ooool3o`000003ooooool0003o000000Gooooo0_l0000=ooooo`Co000000?ooooo
o`000?l000000oooool2o`0000;ooooo0_l0000Cooooo`;o00000oooool2o`0001[ooooo0_l00000
0ooooooo0000o`00000;ooooo`?o00004?ooool2o`0002_ooooo000Looooo`03o`000?oooooooooo
03?ooooo0_l0000Eooooo`;o00004Oooool2o`0000Wooooo0_l00005ooooo`Co00000oooool2o`00
00Sooooo0_l000001?oooooo0000o`000?l00007ooooo`So000000?oooooo`000?l000001Ol00002
ooooo`;o00001Oooool2o`0000?ooooo0_l0000:ooooo`;o00001_ooool2o`0000;ooooo0_l0000;
ooooo`?o00002_ooool2o`0001[ooooo0_l000000ooooooo0000o`00000;ooooo`Go00002Oooool2
o`00033ooooo000Looooo`03o`000?oooooooooo02gooooo0_l00004ooooo`;o00002?ooool2o`00
01_ooooo0_l000000ooooooo0000o`000009ooooo`Co00001Oooool4o`0000?ooooo0ol00008oooo
o`;o00002Oooool7o`000003ooooool0003o000000Go00000_ooool3o`0000Oooooo1?l00009oooo
o`;o00002oooool2o`0000Kooooo0_l00003ooooo`?o00003oooool3o`0000Cooooo0_l00002oooo
o`?o00002Oooool2o`0000oooooo1?l000000ooooooo0000o`000006ooooo`;o0000<?ooool001co
oooo00?o0000ooooooooool0;Oooool2o`0000kooooo0_l00006ooooo`;o00003?ooool2o`0000Co
oooo0ol00006ooooo`;o00001_ooool2o`000003ooooool0003o000000Cooooo0_l00003ooooo`Go
00002Oooool2o`0000Kooooo0_l00007ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Oo
oooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo0_l00005ooooo`;o00001?ooool4o`000003
ooooool0003o000000?o00004Oooool2o`0000;ooooo0ol00004ooooo`;o00000_ooool3o`0000Wo
oooo0_l0000Dooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0>Oooool2o`0000Gooooo
0_l00003ooooo`;o00003?ooool2o`0000Cooooo0_l00007ooooo`;o00001_ooool2o`000003oooo
ool0003o000000?ooooo0_l00007ooooo`;o00002Oooool2o`0002Kooooo0_l00002ooooo`;o0000
0oooool4o`0000;ooooo0_l00004ooooo`Co000000Coooooo`000?l0003o00004Oooool8o`0000[o
oooo0_l0000;ooooo`;o000000Coooooo`000?l0003o00002?ooool2o`0000Gooooo0_l0000goooo
o`007?ooool00ol0003oooooooooo`0^ooooo`;o00002Oooool2o`0000Gooooo0_l0000Aooooo`?o
00004Oooool2o`0000Wooooo0_l0000Kooooo`;o00001?ooool2o`0001Gooooo0ol00008ooooo`Co
00000_ooool2o`0000Kooooo1?l00006ooooo`;o00000_ooool2o`0000Oooooo1ol0000Eooooo`;o
000000Coooooo`000?l0003ooooo0ol00008ooooo`;o00001?ooool3o`0003Oooooo000Looooo`03
o`000?oooooooooo02kooooo0_l0000Aooooo`;o000000?oooooo`000?l000003_ooool4o`0000;o
oooo0_l0000;ooooo`;o00002Oooool2o`0000Gooooo0_l0000Booooo`Co000000Coooooo`000?l0
003ooooo1?l0000@ooooo`Ko00003Oooool3o`0000Oooooo1?l00005ooooo`Ko00001Oooool2o`00
0003ooooool0003o000000;o00002_ooool2o`0000_ooooo0_l0000Eooooo`?o0000=oooool001co
oooo00?o0000ooooooooool0=?ooool2o`0000Gooooo0_l00004ooooo`;o000000?oooooo`000?l0
00003Oooool2o`000003ooooool0003o000000;ooooo0_l0000>ooooo`;o00000_ooool2o`0000Wo
oooo0_l00007ooooo`;o00002Oooool2o`0000?ooooo0_l00003ooooo`;o00004?ooool5o`0000co
oooo1?l0000:ooooo`;o00001_ooool4o`0000Kooooo1?l00006ooooo`;o000000Coooooo`000?l0
003ooooo0ol00008ooooo`;o00006?ooool3o`0003Oooooo000Looooo`03o`000?oooooooooo03Co
oooo0_l00005ooooo`;o00004Oooool2o`0000?ooooo0_l00004ooooo`;o00001Oooool2o`0000?o
oooo0_l00003ooooo`;o00000_ooool2o`0000Sooooo0ol00007ooooo`;o0000:?ooool2o`0000Co
oooo0_l00004ooooo`Co00005?ooool2o`0000Cooooo0_l00003ooooo`?o00001_ooool2o`000003
ooooool0003o000000?o00001oooool4o`0000Sooooo0_l0000>ooooo`Go0000=Oooool001cooooo
00?o0000ooooooooool0@Oooool2o`0000Oooooo0_l00002ooooo`?o00002?ooool2o`0000?ooooo
1Ol00002ooooo`Co00001Oooool2o`0000Sooooo0_l00006ooooo`;o00009?ooool2o`0000Cooooo
0_l00003ooooo`?o00000_ooool4o`0000Gooooo0_l00002ooooo`;o00004Oooool2o`0000;ooooo
0ol00007ooooo`;o00000_ooool2o`0000Wooooo0_l00005ooooo`;o00000oooool2o`0000_ooooo
0_l00004ooooo`;o0000=Oooool001cooooo00?o0000ooooooooool0@?ooool3o`0000Oooooo0_l0
0002ooooo`?o00002?ooool2o`0000?ooooo1Ol00003ooooo`?o00000oooool4o`0000Kooooo0_l0
0008ooooo`;o00002?ooool5o`000004ooooool0003o0000o`0000cooooo0_l00005ooooo`;o0000
2Oooool2o`0000?ooooo0_l00007ooooo`;o00000_ooool2o`0001Gooooo0_l00008ooooo`;o0000
3oooool2o`000003ooooool0003o000000?o00000_ooool2o`0000_ooooo0_l0000kooooo`007?oo
ool2o`0003Gooooo0_l00008ooooo`Co00003?ooool2o`0000;ooooo0_l00003ooooo`Wo000000Go
ooooo`000?l0003o0000ooooo`03o`000003ooooool0003o000000Co000000?oooooo`000?l00000
1?ooool2o`0000gooooo0_l00003ooooo`Wo00003?ooool2o`0000;ooooo0_l0000Mooooo`;o0000
4oooool2o`000003ooooool0003o000001;ooooo0_l00005ooooo`;o000000?oooooo`000?l00000
0ol00004ooooo`;o00002Oooool2o`0003_ooooo000Looooo`03o`000?oooooooooo02Gooooo0_l0
0007ooooo`;o00001?ooool2o`0000?ooooo0_l00003ooooo`;o00004_ooool2o`000003ooooool0
003o000001So000000?oooooo`000?l000002_ooool2o`0000;ooooo0_l00003ooooo`Go00001Ooo
ool3o`00017ooooo0_l0000Booooo`;o000000?oooooo`000?l000001_ooool3o`0001;ooooo0_l0
000Eooooo`;o00002Oooool3o`0000Gooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`0U
ooooo`;o00001_ooool3o`0000Wooooo0_l0000Booooo`;o00000_ooool3o`000003ooooool0003o
000000?ooooo4Ol00002ooooo`;o00003Oooool2o`0000;ooooo0_l00005ooooo`?o00001oooool5
o`000003ooooool0003o000000gooooo0_l0000?ooooo`;o000000?oooooo`000?l000001oooool3
o`0000Wooooo0_l00008ooooo`;o00007Oooool3o`0000;ooooo0_l00003ooooo`;o00002Oooool2
o`0003[ooooo000Looooo`03o`000?oooooooooo02gooooo0_l0000Eooooo`;o00001oooool2o`00
00;ooooo0ol00005oooooa;o000000Coooooo`000?l0003o00006Oooool2o`0000Oooooo1Ol00000
0ooooooo0000o`000002ooooo`Co00001oooool4o`0000[ooooo0_l00002ooooo`;o00002_ooool2
o`0000;ooooo0_l00005ooooo`;o00002?ooool2o`0001Oooooo0_l00004ooooo`;o00000oooool2
o`0000?ooooo0_l00003ooooo`;o00001?ooool2o`0003[ooooo000Looooo`03o`000?oooooooooo
037ooooo0_l00002ooooo`;o00003Oooool2o`0000_ooooo0ol00005ooooo`oo000000Coooooo`00
0?l0003ooooo2?l000000ooooooo0000o`000004ooooo`;o00002Oooool2o`0000oooooo0_l00002
ooooo`Go00001_ooool4o`0000[ooooo0ol000000ooooooo0000o`000002o`0000?ooooo0ol00006
ooooo`;o00000oooool2o`0000Sooooo0_l0000@ooooo`;o00001oooool2o`0000[ooooo0_l00007
ooooo`Co0000?_ooool001cooooo00?o0000ooooooooool0:_ooool2o`0000Gooooo0_l00002oooo
o`;o00002Oooool2o`0000Sooooo0_l00009oooooaoo000000?oooooo`000?l000001_l00007oooo
o`Co00003oooool2o`000005ooooool0003o0000o`000?ooool00_l00006ooooo`;o00000_ooool2
o`0000Wooooo0_l00003ooooo`;o000000?oooooo`000?l000000ol00005ooooo`;o00001?ooool2
o`0000Sooooo0_l000000ooooooo0000o`000006ooooo`;o00001Oooool2o`0000kooooo0_l00000
0ooooooo0000o`000004o`0000Kooooo0ol0000nooooo`007?ooool00ol0003oooooooooo`0Zoooo
o`;o00000_ooool2o`0000gooooo0_l000000ooooooo0000o`000008ooooo`?o000000?oooooo`00
0?l000000ooooolLo`000004ooooool0003o0000o`0000?ooooo1Ol00009ooooo`;o00000oooool2
o`0000;ooooo1?l00003ooooo`;o00001?ooool2o`0000[ooooo0_l00002ooooo`;o00004Oooool2
o`0000Sooooo0_l00003ooooo`;o00002?ooool2o`0000;ooooo0_l00006ooooo`;o00005Oooool2
o`000003ooooool0003o000000;ooooo0_l00003ooooo`;o000000?oooooo`000?l00000?oooool0
01cooooo00?o0000ooooooooool0;_ooool2o`0000Sooooo0_l00003ooooo`;o00001_ooool2o`00
00Cooooo0_l000000ooooooo0000o`000003ooooobKo00001Oooool2o`0000Gooooo0ol000000ooo
oooo0000o`000006o`0000?ooooo0_l0000Dooooo`;o000000?oooooo`000?l000002oooool2o`00
0003ooooool0003o000000Sooooo1?l000000ooooooo0000o`000002o`0000Gooooo0ol00008oooo
o`;o00005Oooool2o`0000[ooooo1?l00012ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o
00002oooool2o`0000cooooo9_l00002ooooo`;o000000?oooooo`000?l000001Oooool4o`0000;o
oooo0_l00002ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Sooooo0_l000001?oooooo
0000o`000?ooool2o`0000_ooooo1Ol0000:ooooo`;o00000oooool4o`0000?ooooo0ol00008oooo
o`;o00001_ooool2o`0000gooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o0000
00Sooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00006?ooool:o`000003
ooooool0003o000000oo000000?oooooo`000?l000000_l00003ooooo`;o00000_ooool2o`000004
ooooool0003o0000o`0000Kooooo0_l00009ooooo`;o00000oooool2o`0000Cooooo0_l00008oooo
o`;o00004_ooool2o`0000kooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l00000
1?oooooo0000o`000?ooool2o`0000;ooooo0ol00005ooooo`;o00002_ooool2o`0000;ooooo0_l0
00000ooooooo0000o`000002o`000003ooooool0003o000000_ooooo0_l0000jooooo`007?ooool0
0ol0003oooooooooo`0Xooooo`;o00001?ooool4o`0000Oooooo0_l0000<ooooo`;o00001_ooool3
o`0000?ooooo2?l000000ooooooo0000o`00000Do`0000[ooooo0ol00002ooooo`;o00004_ooool3
o`00037ooooo0_l00006ooooo`;o00000oooool3o`000003ooooool0003o000000;ooooo0ol00003
ooooo`;o00003?ooool2o`0000;ooooo1?l000001?oooooo0000o`000?ooool2o`00013ooooo0_l0
000eooooo`007?ooool00ol0003oooooooooo`0Xooooo`;o00001?ooool4o`0001Gooooo0_l00006
ooooo`?o00000ooooolCo`000003ooooool0003o000000So000000?oooooo`000?l000003Oooool4
o`0000;ooooo0_l0000=ooooo`;o00004oooool2o`0000Sooooo1Ol0000=ooooo`?o00003?ooool2
o`0000cooooo0_l0000@ooooo`Co00005?ooool4o`0003Gooooo000Looooo`03o`000?oooooooooo
03kooooo0_l0000:ooooo`;o00000_oooolJo`000003ooooool0003o000000co00001_ooool2o`00
00Gooooo0ol00002ooooo`;o00003Oooool2o`0000Gooooo0_l0000<ooooo`;o00002?ooool5o`00
00[ooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00003oooool2o`00017ooooo0_l0000=
ooooo`;o00003Oooool2o`0003Oooooo000Looooo`03o`000?oooooooooo02oooooo0_l00002oooo
o`;o00002?ooool3o`0000[ooooo0_l00002ooooobWo000000?oooooo`000?l000000oooool2o`00
00Cooooo0ol00003ooooo`;o00000oooool2o`0000;ooooo0_l00004ooooo`;o00001Oooool2o`00
00Sooooo0_l0000Kooooo`;o00001_ooool2o`0000kooooo0ol0000Aooooo`;o00003Oooool2o`00
04Kooooo000Looooo`03o`000?oooooooooo02oooooo0_l00002ooooo`Co00001_ooool2o`0001?o
oooo9?l00002ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000009ooooo`;o
000000Coooooo`000?l0003o00003_ooool2o`0000Gooooo1?l00002ooooo`?o00003_ooool2o`00
0003ooooool0003o000000;ooooo0_l0000:ooooo`;o000000?oooooo`000?l000001_ooool2o`00
0003ooooool0003o000006Kooooo000Looooo`03o`000?oooooooooo03Gooooo0_l00007ooooo`;o
00004?oooolTo`0000Cooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000So
oooo1_l0000?ooooo`;o00001oooool2o`0000;ooooo0ol0000>ooooo`;o000000?oooooo`000?l0
00002?l00005ooooo`?o000000?oooooo`000?l000000_l00004ooooo`;o000000?oooooo`000?l0
00007?ooool2o`00017ooooo0_l0000eooooo`007?ooool2o`0003oooooo0_l0000=ooooo`;o0000
00?oooooo`000?l000006_l000000ooooooo0000o`000004o`000003ooooool0003o000000[ooooo
1Ol00008ooooo`Co00003_ooool2o`0000;ooooo0_l00005ooooo`;o00001Oooool2o`0000cooooo
0_l000000ooooooo0000o`000004o`000003ooooool0003o000000Wo00001?ooool2o`0000Cooooo
0_l0000Oooooo`;o00001?ooool2o`0000_ooooo0_l0000eooooo`007?ooool00ol0003ooooooooo
o`1=ooooo`;o00000oooool2o`000003ooooool0003o000001co000000?oooooo`000?l000002_oo
ool4o`0000_ooooo0_l00009ooooo`;o00000_ooool3o`0000;ooooo1?l00003ooooo`;o000000?o
ooooo`000?l000001?l00002ooooo`;o00001ooooolFo`00037ooooo0_l00007ooooo`;o000000?o
ooooo`000?l00000=_ooool001cooooo00?o0000ooooooooool0A?ooool2o`0000cooooo8?l0000>
ooooo`?o00002?ooool2o`0000gooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o
000000Kooooo1Ol00003ooooo`;o00001_oooolIo`0000Wooooo0ol00008ooooo`;o00008_ooool2
o`000004ooooool0003o0000ooooo`;o0000<oooool001cooooo00?o0000ooooooooool0A?ooool2
o`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l000003_l000000ooooooo0000o`00000=
o`0000Sooooo0_l00003ooooo`Co00002?ooool2o`0001Gooooo1?l00008ooooo`Go00002_ooool3
o`000003ooooool0003o000001Go00001?ooool2o`000004ooooool0003o0000o`0000Sooooo0_l0
000Rooooo`;o00001?ooool2o`0003?ooooo000Looooo`03o`000?oooooooooo04Gooooo0_l00002
ooooo`;o00001?ooool2o`0000?ooooo3_l000000ooooooo0000o`00000=o`0000?ooooo0_l00003
ooooo`;o00000oooool3o`0001[ooooo0_l00005ooooo`?o00002?ooool5o`0000[ooooo7Ol00002
ooooo`;o00003?ooool2o`0000[ooooo0_l0000Fooooo`;o00004?ooool2o`0002Oooooo000Loooo
o`03o`000?oooooooooo02Oooooo0_l00006ooooo`;o00004_ooool5o`0000_ooooo7ol00003oooo
o`;o00002?ooool3o`0000_ooooo0_l00003ooooo`;o00001_ooool4o`000005ooooool0003o0000
o`000?ooool00_l00009ooooo`Co00002ooooolDo`000003ooooool0003o000000Ko00001_ooool2
o`0000Oooooo0ol00005ooooo`;o00000oooool2o`0001?ooooo0_l0000Cooooo`;o00009oooool0
01cooooo00?o0000ooooooooool09oooool2o`0000Kooooo0_l0000Booooo`;o000000Coooooo`00
0?l0003ooooo1?l00006ooooo`;o000000?oooooo`000?l000001?l000000ooooooo0000o`00000>
o`0000;ooooo1Ol0000;ooooo`;o00003?ooool2o`000003ooooool0003o000000;o00001_ooool4
o`000004ooooool0003o0000o`0000Cooooo0_l0000Eoooooago000000?oooooo`000?l000000ooo
ool2o`0000Oooooo0_l00006ooooo`;o00002_ooool2o`0000Wooooo0_l000000ooooooo0000o`00
000looooo`007?ooool00ol0003oooooooooo`19ooooo`Co00000oooool2o`0000Kooooo1?l00000
0ooooooo0000o`00000?o`0000Cooooo0_l0000;ooooo`;o00002?ooool2o`0000Gooooo0_l0000:
ooooo`;o00002?ooool2o`0000Sooooo1?l00006ooooo`;o000000?oooooo`000?l000001?l00000
0ooooooo0000o`00000Co`0000;ooooo0_l00004ooooo`?o000000?oooooo`000?l000001oooool2
o`0000Wooooo0_l00002ooooo`Co00001oooool2o`0003oooooo000Looooo`03o`000?oooooooooo
053ooooo0_l00005ooooo`Ko000000?oooooo`000?l000002ol000000ooooooo0000o`000002oooo
o`Co00000oooool2o`0000Gooooo0_l000000ooooooo0000o`000004ooooo`Co00001_ooool2o`00
00Oooooo1Ol0000Aooooo`Co00001_ooool2o`000003ooooool0003o000001[o00002?ooool6o`00
00Oooooo0_l00009ooooo`;o00001?ooool2o`0000cooooo0_l00003ooooo`;o0000=Oooool001co
oooo00?o0000ooooooooool0@Oooool2o`0000gooooo0_l00005ooooo`Ko000000?oooooo`000?l0
00003Ol00002ooooo`Go00000oooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`00
00Cooooo0_l00008ooooo`;o00001oooool2o`000003ooooool0003o000000kooooo1?l00003oooo
o`;o00001ooooolLo`0000Kooooo1_l0000Booooo`Co00000oooool2o`0000Oooooo0_l00004oooo
o`;o00000oooool3o`0003Cooooo000Looooo`03o`000?oooooooooo047ooooo1Ol00007ooooo`;o
00004?ooool;o`000003ooooool0003o000000;ooooo0ol00009ooooo`;o000000?oooooo`000?l0
00004?ooool2o`0000;ooooo0_l0000;ooooo`;o00001Oooool2o`0000?ooooo1?l00003ooooo`;o
00001_oooolMo`0000Kooooo0_l0000Fooooo`;o00001Oooool4o`0000Cooooo0ol00003ooooo`;o
00001Oooool3o`0003?ooooo000Looooo`03o`000?oooooooooo04;ooooo1?l00007ooooo`;o0000
4?ooool5o`000003ooooool0003o000000;o000000?oooooo`000?l000001Oooool2o`0001Cooooo
0_l00007ooooo`;o00000_ooool2o`0000_ooooo0_l00005ooooo`;o00001Oooool2o`0000?ooooo
0_l00006oooooa_o00001_ooool2o`0000Cooooo0_l00006ooooo`;o00003oooool2o`0000;ooooo
0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l00006ooooo`;o0000<oooool001cooooo
00?o0000ooooooooool0@?ooool2o`0000Gooooo0_l0000Fooooo`Go00000oooool2o`000003oooo
ool0003o000000Gooooo0_l0000Dooooo`Co00000_ooool2o`0000Sooooo1?l00008ooooo`;o0000
2?ooool4o`0000?ooooo0_l00006ooooo`So000000?oooooo`000?l000004ol00003ooooo`;o0000
1?ooool2o`0000Kooooo0_l0000?ooooo`?o00002?ooool4o`0003kooooo000Looooo`03o`000?oo
oooooooo043ooooo0_l00002ooooo`;o000000?oooooo`000?l000003Oooool2o`0000Gooooo0_l0
0003ooooo`Co00004Oooool2o`00013ooooo0_l00002ooooo`;o00001?ooool2o`0000;ooooo1?l0
0008ooooo`;o00001_ooool6o`0000Kooooo0ol00002ooooo`go000000?oooooo`000?l000001_l0
00000ooooooo0000o`000005o`0002?ooooo0_l00008ooooo`Co00001Oooool2o`0003Oooooo0000
1_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<
c<`01_ooool00ol0003oooooooooo`0Yooooo`;o00004oooool2o`0000Cooooo0_l0000@ooooo`;o
000000?oooooo`000?l000000_ooool2o`0000Cooooo0ol0000Aooooo`;o000000?oooooo`000?l0
00005oooool2o`0001?ooooo1Ol00002ooooo`;o00001_ooool3o`000003ooooool0003o000001co
00009_ooool2o`0000?ooooo0_l0000:ooooo`;o0000=oooool00006oooooomgMgOoV9RHoooooonH
V9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooo
oooo02Wooooo0_l0000Cooooo`?o00001_ooool2o`0000cooooo0ol000001?oooooo0000o`000?l0
000:ooooo`;o00002?ooool3o`0000Kooooo0ol00006ooooo`;o00002_ooool2o`0001Sooooo1Ol0
000>oooooako00002?ooool2o`0000[ooooo1?l00002ooooo`;o00001_ooool2o`0000;ooooo0_l0
00000ooooooo0000o`000002o`0000Wooooo0_l00002ooooo`;o0000=?ooool00003ooooool@413o
oooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool0?oooool2o`0000?ooooo0_l000000ooooooo0000o`000009ooooo`;o000000?o
ooooo`000?l000000oooool4o`000003ooooool0003o000000Cooooo1?l00005ooooo`Go00001_oo
ool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000002_ooool2o`0000Cooooo
0_l0000Booooo`;o00004?ooool?o`000003ooooool0003o000000co00002Oooool2o`0000Cooooo
0_l00004ooooo`Co000000Coooooo`000?l0003o00001_ooool2o`0000Gooooo0_l0000;ooooo`Ko
0000=?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oV9RH
oooooonHV9So8B4Q00Kooooo0ol0000]ooooo`;o00005Oooool2o`0000;ooooo0_l00008ooooo`;o
00001_ooool4o`000003ooooool0003o000000Cooooo1?l00005ooooo`;o000000?oooooo`000?l0
00001_ooool2o`000003ooooool0003o000000?o000000?oooooo`000?l000002oooool2o`0000?o
oooo0_l00003ooooo`;o00000oooool2o`000003ooooool0003o000000Co00003Oooool2o`0000Co
oooo3ol000000ooooooo0000o`00000;o`00013ooooo0_l00009ooooo`;o00007Oooool2o`0003Ko
oooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oeEEEOl0003o
410@olc<c006ooooo`03o`000?oooooooooo02gooooo0_l0000Iooooo`;o00004?ooool2o`0000?o
oooo1?l00003ooooo`;o00004Oooool2o`0000;ooooo0ol00002ooooo`;o00002oooool2o`0000So
oooo0_l00003ooooo`;o000000?oooooo`000?l000001?l00004ooooo`;o00001oooool2o`0000Oo
oooo6ol00002ooooo`Go00002_ooool2o`0001Wooooo0_l000000ooooooo0000o`000010ooooo`00
00?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo
00?o0000ooooooooool0:_ooool2o`0002Gooooo0_l000000ooooooo0000o`000002o`0000Oooooo
1?l00003ooooo`?o00005?ooool2o`0001?ooooo0ol00003ooooo`;o00001oooool2o`0000Sooooo
0ol00006ooooo`;o00002OoooolJo`000003ooooool0003o000000?o00001Oooool2o`0000?ooooo
0_l00002ooooo`;o00001_ooool2o`0000Cooooo0_l00007ooooo`;o000000?oooooo`000?l00000
@?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03
o`000?oooooooooo02[ooooo0_l0000Kooooo`;o00001Oooool5o`000003ooooool0003o000000;o
00001oooool4o`0000Cooooo0_l0000=ooooo`;o000000?oooooo`000?l000001oooool2o`0000ko
oooo0ol00002ooooo`?o000000?oooooo`000?l000001?ooool2o`0000Wooooo0_l0000=ooooo`;o
00000_ooool2o`0000;ooooo5_l000000ooooooo0000o`000008ooooo`;o00001oooool3o`0000Go
oooo1?l00002ooooo`;o00002Oooool2o`00047ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^
kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`17ooooo`;o00001?ooool4
o`0000cooooo0_l000000ooooooo0000o`000002o`0001;ooooo0_l000000ooooooo0000o`000007
ooooo`;o00002?ooool2o`0000Wooooo0ol000000ooooooo0000o`00000Booooo`;o00000_ooool2
o`0000Kooooo1?l00002oooooa[o00000_ooool2o`0000oooooo0_l00006ooooo`?o000000?ooooo
o`000?l000002_ooool2o`0000[ooooo0_l0000eooooo`007?ooool00ol0003oooooooooo`19oooo
o`;o00000_ooool2o`0000kooooo1ol00004ooooo`;o00008_ooool2o`000003ooooool0003o0000
00[ooooo0_l000000ooooooo0000o`000004ooooo`;o00001Oooool2o`0000;ooooo1_l00006oooo
o`Go000000?oooooo`000?l000001_l00003ooooo`co000000?oooooo`000?l000000_ooool2o`00
00?ooooo1?l0000Dooooo`;o00005_ooool4o`0003?ooooo000Looooo`03o`000?oooooooooo047o
oooo0_l00002ooooo`;o00000_ooool2o`0001?ooooo0_l00003ooooo`;o00000oooool2o`0000Oo
oooo0_l00002ooooo`Co00000_ooool2o`0000?ooooo0_l0000=ooooo`Co00001_ooool7o`0000Co
oooo0_l00005ooooo`;o000000Coooooo`000?l0003ooooo0_l00006ooooo`;o00000oooool9o`00
0003ooooool0003o000000ko000000?oooooo`000?l000001oooool4o`000003ooooool0003o0000
00;o00006_ooool2o`0000gooooo0_l0000cooooo`007?ooool00ol0003oooooooooo`11ooooo`;o
00000_ooool2o`0000[ooooo0ol00002ooooo`;o00001_ooool2o`0000?ooooo0_l00004ooooo`;o
00001?ooool4o`0000;ooooo2?l00003ooooo`?o000000Coooooo`000?l0003ooooo0_l00005oooo
o`Go00001_ooool:o`0000_ooooo0_l00009ooooo`;o00000oooool9o`000003ooooool0003o0000
00Wo00000oooool2o`0000kooooo1Ol0000Jooooo`;o0000@_ooool001cooooo00?o0000oooooooo
ool0AOooool2o`0000Oooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00001Oooool2o`00
00Kooooo1_l00004ooooo`?o00001oooool2o`0000Kooooo0_l000001?oooooo0000o`000?ooool2
o`0000Cooooo1_l00003ooooo`Co00001Oooool8o`0000Oooooo0_l0000=ooooo`?o00000_ooool@
o`0000Kooooo0_l000000ooooooo0000o`000009ooooo`Co00001oooool2o`0000Oooooo0_l0001=
ooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00004?ooool5o`0000Oooooo0_l00006oooo
o`;o00001Oooool2o`0000Kooooo1?l00006ooooo`?o00001?ooool2o`0000?ooooo0_l0000@oooo
o`;o000000?oooooo`000?l000003ol000000ooooooo0000o`000003o`0000Oooooo0_l0000=oooo
o`;o00001?ooool8o`0000?ooooo0_l00006ooooo`Co000000?oooooo`000?l000003Oooool2o`00
00Gooooo1?l00005ooooo`?o00001_ooool2o`0004Cooooo000Looooo`03o`000?oooooooooo033o
oooo0_l00005ooooo`;o00002Oooool4o`0000cooooo0_l00002ooooo`;o00004?ooool2o`0000Go
oooo0_l00004ooooo`?o000000?oooooo`000?l000000_l00007ooooo`;o00001oooool2o`0000?o
oooo1Ol00002ooooo`Ko00000oooool2o`0000?ooooo0_l0000>ooooo`;o00001Oooool3o`0000Co
oooo1?l00004ooooo`;o00001Oooool4o`0000Gooooo0_l0000;ooooo`;o00001Oooool4o`0000Go
oooo0ol00006ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0=oooool2o`0001Wooooo
0_l00002ooooo`;o00004?ooool2o`0000Gooooo0_l00004ooooo`;o00000_ooool3o`0000Cooooo
0_l00002ooooo`;o00002Oooool3o`000003ooooool0003o000000_o00001oooool4o`0000Oooooo
1?l000000ooooooo0000o`000005ooooo`?o00001Oooool2o`0000Gooooo0_l00002ooooo`;o0000
00?oooooo`000?l000001?ooool5o`0001;ooooo1Ol00004ooooo`;o0000COooool001cooooo00?o
0000ooooooooool0F_ooool4o`000003ooooool0003o000001Sooooo1?l00003ooooo`;o00001ooo
ool9o`0000?ooooo2ol000000ooooooo0000o`000006ooooo`;o00001?ooool2o`000003ooooool0
003o000000;o00004?ooool2o`0000Wooooo0_l00007ooooo`?o00005oooool2o`0000cooooo0_l0
0015ooooo`007?ooool00ol0003oooooooooo`1@ooooo`Co00001Oooool5o`000003ooooool0003o
000001Sooooo1Ol0000;oooooa[o000000?oooooo`000?l000000_l00007ooooo`;o0000>?ooool2
o`0000Oooooo1?l0000<ooooo`;o0000AOooool001cooooo00?o0000ooooooooool0@oooool2o`00
00Cooooo0_l000000ooooooo0000o`000006o`0000Gooooo0_l0000:ooooo`;o00003oooool3o`00
00?ooooo0_l0000Aoooooa[o00001_ooool6o`0002Cooooo0ol00002ooooo`;o00002Oooool2o`00
00Oooooo1?l000001?oooooo0000o`000?ooool2o`0000Kooooo0_l00015ooooo`007?ooool00ol0
003oooooooooo`13ooooo`;o00001?ooool2o`000003ooooool0003o000000?o00004?ooool2o`00
00;ooooo0_l0000?ooooo`?o00002?ooool3o`0000Wooooo6?l00002ooooo`;o00001?ooool2o`00
0003ooooool0003o000000?o00000_ooool2o`0000[ooooo0_l0000Dooooo`?o00000_ooool6o`00
01?ooooo0_l000000ooooooo0000o`000006ooooo`;o0000AOooool001cooooo0_l0001>ooooo`;o
00004_ooool2o`0000;ooooo0_l00004ooooo`;o00003_ooool2o`0000Cooooo1?l00004ooooo`;o
000000?oooooo`000?l000005Ol0000:ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`00
0003ooooool0003o000000Gooooo1?l0000;ooooo`;o00003?ooool6o`0000_ooooo0_l0001Hoooo
o`007?ooool00ol0003oooooooooo`17ooooo`;o00001?ooool2o`0000Cooooo0_l0000@ooooo`;o
00001?ooool2o`0000gooooo0ol00006ooooo`;o00001?oooolJo`0000[ooooo0_l000000ooooooo
0000o`000002ooooo`;o00001?ooool2o`0000Gooooo0_l00002ooooo`;o00001Oooool2o`0000;o
oooo0_l00002ooooo`;o00003?ooool4o`0000Wooooo0_l0001Hooooo`007?ooool00ol0003ooooo
ooooo`17ooooo`;o00002_ooool2o`0000Gooooo0_l00007ooooo`;o00005Oooool2o`0000oooooo
1ol000000ooooooo0000o`00000@o`0000oooooo0_l0000?ooooo`;o00001Oooool3o`0000Gooooo
0_l00004ooooo`;o00002?ooool2o`00017ooooo0_l00004ooooo`;o0000B_ooool001cooooo00?o
0000ooooooooool0AOooool2o`0000cooooo0_l00005ooooo`;o00001?ooool2o`000003ooooool0
003o000001Gooooo0ol00009ooooo`;o00000ooooolJo`0000Cooooo0_l00009ooooo`Co00002_oo
ool2o`0000Wooooo0_l00004ooooo`?o00000oooool4o`000003ooooool0003o000001Oooooo0_l0
0004ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0AOooool2o`0000Sooooo1?l0000=
ooooo`;o000000?oooooo`000?l000005Oooool6o`0000Kooooo0_l000000ooooooo0000o`00000>
o`000003ooooool0003o000000[o00000oooool2o`0000?ooooo0_l00004ooooo`Co00000_ooool3
o`0000?ooooo1?l00002ooooo`;o00002oooool4o`0000;ooooo1?l000000ooooooo0000o`00000;
ooooo`;o00001oooool2o`0000?ooooo0_l00002ooooo`;o0000B_ooool001cooooo00?o0000oooo
ooooool0Coooool4o`00013ooooo0_l0000Hooooo`Co00000_ooool2o`0000Cooooo7Ol00008oooo
o`;o00001?ooool3o`0000?ooooo0ol00003ooooo`;o00001?ooool3o`0000;ooooo0_l00005oooo
o`;o000000?oooooo`000?l000000_l00005ooooo`;o00001?ooool2o`0000?ooooo1?l00007oooo
o`;o00000oooool2o`0004kooooo000Looooo`03o`000?oooooooooo03cooooo0_l00002ooooo`;o
00001?ooool2o`0000oooooo0_l00002ooooo`;o00001oooool2o`0001Oooooo1?l00002ooooo`?o
000000?oooooo`000?l000000_oooolIo`0000?ooooo0_l00002ooooo`;o00001oooool2o`0000[o
oooo0_l00005ooooo`;o00000_ooool2o`0000Gooooo0_l00003ooooo`;o00001Oooool2o`0000?o
oooo0ol000000ooooooo0000o`000002o`000003ooooool0003o000000;ooooo0_l000000ooooooo
0000o`000002o`000003ooooool0003o000004oooooo000Looooo`03o`000?oooooooooo03;ooooo
0_l00008ooooo`;o00000_ooool2o`0000Cooooo0_l0000?ooooo`;o00000_ooool2o`0000Oooooo
0_l00004ooooo`;o00004Oooool4o`000003ooooool0003o000000;o000000?oooooo`000?l00000
0_ooool=o`000003ooooool0003o000000Wo00000oooool2o`0000;ooooo0_l00004ooooo`;o0000
3Oooool2o`0000Oooooo0_l00005ooooo`;o000000?oooooo`000?l000000_l00009ooooo`Go0000
0_ooool3o`0000;ooooo0ol000001?oooooo0000o`000?ooool4o`000003ooooool0003o000004oo
oooo000Looooo`03o`000?oooooooooo03;ooooo0_l0000Yooooo`;o00002oooool2o`00017ooooo
1?l000000ooooooo0000o`000002ooooo`;o00001?ooool:o`0000;ooooo2ol00003ooooo`;o0000
1oooool4o`0001Kooooo0_l00005ooooo`Oo00002Oooool4o`0000Cooooo0_l00002ooooo`?o0000
1Oooool2o`0000;ooooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00003ooo
ool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`00017ooooo0_l00007ooooo`;o000000Co
ooooo`000?l0003ooooo6?l00002ooooo`;o00001oooool4o`000003ooooool0003o000001cooooo
0_l0000Aooooo`;o00001Oooool2o`0000Kooooo0_l0001Cooooo`007?ooool00ol0003ooooooooo
o`17ooooo`;o00000oooool2o`0000Gooooo0_l00008ooooo`;o00000_ooool2o`0000?ooooo0_l0
00000ooooooo0000o`000004ooooo`;o00003?ooool2o`0000Oooooo0_l000000ooooooo0000o`00
000Io`0000gooooo2?l0000:ooooo`;o00007oooool3o`0000gooooo1?l0001Aooooo`007?ooool0
0ol0003oooooooooo`17ooooo`;o00001?ooool2o`0000Cooooo0_l00003ooooo`;o000000?ooooo
o`000?l000001?l00008ooooo`;o00001?ooool2o`0000Cooooo0ol0000:ooooo`;o00001_ooool2
o`000003ooooool0003o000001Co00001_ooool2o`000003ooooool0003o000000;o000000?ooooo
o`000?l000000_l000000ooooooo0000o`000003o`0000Kooooo1?l0000Oooooo`;o00000_ooool2
o`0000Kooooo0_l00003ooooo`?o0000DOooool001cooooo00?o0000ooooooooool0>Oooool2o`00
00[ooooo0_l00003ooooo`;o000000?oooooo`000?l000002Oooool5o`000004ooooool0003o0000
o`0000Kooooo0_l00007ooooo`;o00000oooool3o`0000Sooooo1?l000000ooooooo0000o`000002
ooooo`;o00000_oooolHo`0000Cooooo1ol00003ooooo`;o000000?oooooo`000?l000000ol00006
ooooo`?o000000?oooooo`000?l000003?ooool2o`0000_ooooo0ol000000ooooooo0000o`000002
ooooo`;o00001_ooool2o`000003ooooool0003o000005Cooooo000Looooo`03o`000?oooooooooo
03Wooooo0_l0000:ooooo`;o00000oooool2o`0000Wooooo0_l00003ooooo`;o00002oooool2o`00
00Oooooo0_l00008ooooo`;o00000oooool3o`0000;ooooo0ol00002ooooo`;o00000_oooolDo`00
00;ooooo0_l00006ooooo`Co00001oooool2o`000003ooooool0003o000000Oooooo0_l000000ooo
oooo0000o`000008ooooo`;o00000_ooool2o`0000[ooooo1?l00005ooooo`;o00001?ooool2o`00
00?ooooo0ol0001Cooooo`007?ooool00ol0003oooooooooo`1>ooooo`Co00000_ooool3o`0000co
oooo0_l0000=ooooo`;o00001_ooool2o`0000?ooooo0_l00003ooooo`;o00001ooooolAo`000003
ooooool0003o000000?ooooo1Ol00004ooooo`;o00002Oooool3o`0000Cooooo1Ol00004ooooo`;o
000000?oooooo`000?l000000_ooool2o`0000_ooooo0_l000000ooooooo0000o`00000=ooooo`;o
00001?ooool2o`0005?ooooo000Looooo`03o`000?oooooooooo04cooooo1_l00002ooooo`;o0000
1Oooool2o`0000Kooooo0_l0000=ooooo`;o00006_oooolBo`000004ooooool0003o0000ooooo`Ko
00000oooool2o`0000Wooooo0ol00004ooooo`Go00000_ooool4o`000003ooooool0003o000000[o
oooo0_l00003ooooo`;o00002Oooool3o`0001[ooooo0_l00013ooooo`007?ooool2o`0004Oooooo
0_l00003ooooo`?o00003Oooool2o`0000Kooooo0ol0000<ooooo`;o00000_ooool2o`0001Kooooo
4_l000000ooooooo0000o`000003ooooo`Co00002_ooool2o`0000?ooooo0_l00005ooooo`?o0000
0oooool2o`0000gooooo1?l00002ooooo`Co00001oooool4o`0000;ooooo0_l00003ooooo`;o0000
4Oooool2o`0004?ooooo000Looooo`03o`000?oooooooooo04Kooooo0_l00003ooooo`;o00002?oo
ool2o`0000cooooo0ol00007ooooo`;o00000oooool2o`0000;ooooo0_l0000Fooooo`oo000000?o
ooooo`000?l000002Oooool2o`0000Oooooo1?l00003ooooo`;o00006?ooool6o`0000;ooooo1?l0
0006ooooo`Go00000_ooool2o`0000?ooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`15
ooooo`;o00003_ooool2o`0001Kooooo0_l00002ooooo`?o00007?ooool>o`0000_ooooo0_l00007
ooooo`;o00001Oooool6o`0000_ooooo0_l00007ooooo`Ko00001Oooool2o`0000Gooooo0ol00000
0ooooooo0000o`00001Nooooo`007?ooool00ol0003oooooooooo`13ooooo`Co00001Oooool2o`00
00_ooooo0_l0000=ooooo`Go00001?ooool4o`0000Gooooo0_l0000Cooooo`Go000000?oooooo`00
0?l000001?l000000ooooooo0000o`000007ooooo`Co00002?ooool2o`0000Sooooo1_l00004oooo
o`;o00000oooool2o`0000Gooooo0_l0000;ooooo`;o00000_ooool6o`000003ooooool0003o0000
01Oooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00001oooool2o`0000_o
oooo0_l0000=ooooo`Go00001_ooool2o`0000Gooooo0_l0000Booooo`ko00002Oooool4o`0000So
oooo0_l00006ooooo`;o00001?ooool2o`0000Cooooo0_l00003ooooo`;o00000oooool4o`0000Co
oooo0_l00009ooooo`Co000000?oooooo`000?l000000_l0000Gooooo`;o0000AOooool001cooooo
00?o0000ooooooooool0B_ooool4o`0002Gooooo0_l0000Gooooo`Co000000?oooooo`000?l00000
0ol000000ooooooo0000o`000003o`0001gooooo1?l0000;ooooo`Co00000oooool2o`0000Cooooo
1Ol0000:ooooo`;o000000?oooooo`000?l000000_l0001Nooooo`007?ooool00ol0003ooooooooo
o`1:ooooo`Co00001oooool2o`0000Oooooo0_l0000Cooooo`;o00004?ooool2o`0000Gooooo0_l0
0003ooooo`Go000000Coooooo`000?l0003o00003_ooool2o`0000Oooooo0_l00002ooooo`;o0000
1?ooool3o`0000[ooooo0ol0000:ooooo`;o000000?oooooo`000?l000001oooool2o`0006Kooooo
000Looooo`03o`000?oooooooooo04_ooooo0_l00008ooooo`;o00001oooool2o`0000Sooooo0_l0
0005ooooo`;o00000oooool3o`0000kooooo0_l00005ooooo`;o00001?ooool:o`0000Kooooo0_l0
0004ooooo`;o00001oooool2o`0000;ooooo0_l00005ooooo`?o00003_ooool2o`0001;ooooo0_l0
000<ooooo`;o0000F?ooool001cooooo00?o0000ooooooooool0J?ooool2o`0000Gooooo0_l00003
ooooo`?o00002oooool2o`00013ooooo0ol00002ooooo`?o00001_ooool2o`0000kooooo0_l00004
ooooo`;o00000oooool3o`0000cooooo0ol0000:ooooo`;o00001Oooool2o`0000gooooo0_l0001H
ooooo`007?ooool00ol0003oooooooooo`1Wooooo`;o000000?oooooo`000?l000002?ooool2o`00
00cooooo0_l0000>ooooo`Co00000_ooool2o`0000?ooooo0_l0000Cooooo`;o00001?ooool2o`00
00Cooooo0_l0000:ooooo`Co00002Oooool4o`0000;ooooo0_l000001?oooooo0000o`000?ooool2
o`0006Cooooo000Looooo`03o`000?oooooooooo05[ooooo0_l0000;ooooo`Go00002?ooool3o`00
01_ooooo0_l00004ooooo`;o00000oooool3o`0001gooooo0_l0000;ooooo`;o00000oooool2o`00
00Cooooo1_l00002ooooo`;o00001?ooool2o`0000Wooooo0_l0001Iooooo`007?ooool00ol0003o
ooooooooo`1Dooooo`?o00000oooool2o`0000cooooo0_l000000ooooooo0000o`000002o`0000Ko
oooo0_l00009ooooo`;o00007?ooool2o`0001gooooo0_l0000@ooooo`Co000000Coooooo`000?l0
003o00000_ooool2o`0000;ooooo1Ol00008ooooo`;o00000_ooool2o`0005Wooooo000Looooo`03
o`000?oooooooooo05Cooooo1Ol0000Aooooo`Go00001Oooool2o`0000[ooooo0_l00009ooooo`;o
00004_ooool2o`0000cooooo0_l00005ooooo`Co00002?ooool2o`0000kooooo0ol000001?oooooo
0000o`000?l00006ooooo`Go00002?ooool2o`0000gooooo0_l0001>ooooo`007?ooool00ol0003o
ooooooooo`1=ooooo`;o00002?ooool2o`00017ooooo0_l00008ooooo`Co00001Oooool2o`0000co
oooo0_l0000?ooooo`Go00003?ooool2o`000003ooooool0003o000000;ooooo1?l00005ooooo`;o
000000?oooooo`000?l000002?ooool2o`0000Cooooo0_l00003ooooo`;o000000?oooooo`000?l0
00002_ooool2o`0001?ooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o0000
1_ooool2o`0001Oooooo0_l00004ooooo`Co00000oooool4o`0000Cooooo0_l00006ooooo`;o0000
1oooool2o`0000Kooooo1?l00008ooooo`;o00001_ooool2o`0000?ooooo0_l00006ooooo`;o0000
2oooool2o`0000Sooooo0_l00002ooooo`;o00002_ooool2o`0000Sooooo0_l0001Iooooo`007?oo
ool00ol0003oooooooooo`1=ooooo`;o000000?oooooo`000?l000000oooool2o`0000gooooo1?l0
0005ooooo`Go00000_ooool2o`000003ooooool0003o000000;ooooo0_l00006ooooo`?o00003_oo
ool2o`0000Oooooo0_l00009ooooo`;o00001?ooool2o`0000Gooooo0_l000000ooooooo0000o`00
000@ooooo`;o00002?ooool5o`0000Sooooo0_l00008ooooo`;o000000?oooooo`000?l00000FOoo
ool001cooooo0_l0001Aooooo`;o00003Oooool3o`0000;ooooo1?l00005ooooo`Go00001Oooool2
o`0000_ooooo0_l00004ooooo`;o00002?ooool2o`000003ooooool0003o000000Cooooo0_l0000?
ooooo`;o00001oooool3o`0000cooooo0ol000000ooooooo0000o`00000:ooooo`?o00002?ooool2
o`0000Sooooo0_l000000ooooooo0000o`00001Iooooo`007?ooool00ol0003oooooooooo`1Ioooo
o`;o00001?ooool3o`0000Cooooo0_l00005ooooo`?o000000?oooooo`000?l000003?ooool2o`00
00Wooooo0_l0000;ooooo`;o00000_ooool2o`0000cooooo0_l0000<ooooo`;o00001?ooool2o`00
00?ooooo0_l00002ooooo`?o00003_ooool4o`0000;ooooo0ol0000>ooooo`;o0000FOooool001co
oooo00?o0000ooooooooool0FOooool2o`0000Gooooo0_l0000?ooooo`;o00003?ooool2o`00013o
oooo0_l00008ooooo`;o00003?ooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o
00001_ooool2o`0000?ooooo0_l0000=ooooo`?o00001?ooool4o`000004ooooool0003o0000o`00
00Sooooo0_l0001Oooooo`007?ooool00ol0003oooooooooo`1Yooooo`;o00000_ooool2o`0000co
oooo0_l0000@ooooo`;o00000_ooool2o`0001_ooooo0_l000000ooooooo0000o`000002ooooo`;o
00006_ooool3o`0000Cooooo1?l0000<ooooo`;o0000Goooool001cooooo00?o0000ooooooooool0
Coooool2o`0001Sooooo0ol000000ooooooo0000o`000006ooooo`;o00000oooool3o`00013ooooo
0_l0000@ooooo`;o00004?ooool2o`00023ooooo0_l0000Aooooo`;o0000HOooool001cooooo00?o
0000ooooooooool0Coooool2o`0001Wooooo0_l00009ooooo`;o00000oooool2o`0000Gooooo0_l0
000Looooo`;o00003Oooool2o`0000_ooooo0_l00005ooooo`;o00003oooool2o`0000Cooooo0_l0
0008ooooo`;o000000?oooooo`000?l00000HOooool001cooooo00?o0000ooooooooool0Ooooool4
o`0000_ooooo0_l0000Iooooo`Co000000Coooooo`000?l0003ooooo0_l00008ooooo`;o00000_oo
ool2o`000003ooooool0003o000000Sooooo0_l0000;ooooo`;o00002?ooool2o`0006Cooooo000L
ooooo`03o`000?oooooooooo06[ooooo0_l00003ooooo`;o00003_ooool3o`0000cooooo1?l0000G
ooooo`Co00001?ooool2o`0000cooooo0_l00007ooooo`;o00000_ooool2o`0000_ooooo0_l00004
ooooo`;o0000J?ooool001cooooo00?o0000ooooooooool0Ioooool2o`000003ooooool0003o0000
00;ooooo0ol0000?ooooo`;o00000_ooool2o`0000;ooooo0_l00006ooooo`;o00001?ooool2o`00
0003ooooool0003o000000Kooooo0_l0000=ooooo`;o00002oooool2o`0000Wooooo0_l0000?oooo
o`;o00000_ooool6o`0006Kooooo000Looooo`03o`000?oooooooooo06Oooooo0_l00005ooooo`;o
00005?ooool2o`0000;ooooo0_l00006ooooo`;o00001?ooool2o`000003ooooool0003o000000?o
oooo0_l000000ooooooo0000o`00000=ooooo`;o00002?ooool2o`000003ooooool0003o000001ko
oooo0ol000000ooooooo0000o`00001Vooooo`007?ooool00ol0003oooooooooo`1Wooooo`;o0000
3Oooool2o`0001?ooooo0_l000000ooooooo0000o`000002ooooo`?o00002Oooool2o`0000Gooooo
1?l00005ooooo`;o00001?ooool2o`0000Cooooo0_l0000Rooooo`;o000000?oooooo`000?l00000
I_ooool001cooooo00?o0000ooooooooool0M_ooool2o`0001?ooooo1Ol00002ooooo`?o00004?oo
ool4o`0000Gooooo0_l00004ooooo`Ko00006?ooool3o`000003ooooool0003o000000Wooooo0_l0
001Vooooo`007?ooool00ol0003oooooooooo`1]ooooo`;o00001Oooool2o`0001Oooooo0ol0000M
ooooo`;o00001_ooool5o`0000Cooooo0_l00009ooooo`;o00001Oooool5o`000003ooooool0003o
0000077ooooo000Looooo`03o`000?oooooooooo05[ooooo0_l0000Aooooo`;o00001Oooool2o`00
00;ooooo0_l00003ooooo`;o00003oooool2o`0001Sooooo0_l00003ooooo`;o00003oooool4o`00
00Gooooo1?l00005ooooo`;o00002oooool2o`0006[ooooo00001_ooooook^k^oc8b<_l0003o<S8b
onk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003ooooooooo
o`1Jooooo`;o00006?ooool2o`0000;ooooo0_l00003ooooo`?o00003oooool2o`0000oooooo0_l0
00000ooooooo0000o`000003ooooo`;o00004_ooool2o`0000;ooooo0_l00005ooooo`;o00001Ooo
ool2o`0000[ooooo0_l000000ooooooo0000o`00001Zooooo`0000KoooooogMgMonHV9SooooooiRH
V?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000oooooooo
ool0Koooool3o`0000cooooo0_l00005ooooo`?o00000oooool3o`000005ooooool0003o0000o`00
0?ooool00_l0000;ooooo`;o000000?oooooo`000?l000000_l00004ooooo`?o00001oooool2o`00
00?ooooo1?l0000=ooooo`;o000000?oooooo`000?l000001oooool2o`000003ooooool0003o0000
06gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo06Sooooo0_l00005ooooo`?o00003?ooool2o`00
00Gooooo0ol00003ooooo`Oo000000?oooooo`000?l000001_ooool2o`0000?ooooo0_l00003oooo
o`;o000000Coooooo`000?l0003ooooo0ol00007ooooo`;o00000oooool2o`0000oooooo0_l00009
ooooo`?o0000L?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Olb
<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0001Xooooo`;o00003oooool2o`0000?ooooo0_l00004
ooooo`;o00000_ooool2o`0000Cooooo0_l00003ooooo`;o00001_ooool4o`000003ooooool0003o
000000Kooooo0_l00007ooooo`;o00003oooool2o`0000Cooooo0_l0000<ooooo`;o00001Oooool2
o`0006[ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Goc<c<o`00
0?l0003o0000olc<c006ooooo`03o`000?oooooooooo06Sooooo0_l0000?ooooo`;o00001oooool4
o`0000;ooooo0_l0000Cooooo`;o00001oooool2o`0000Wooooo0_l00007ooooo`;o00000_ooool2
o`0000;ooooo0_l00004ooooo`Co00004Oooool2o`0006[ooooo00000ooooooo410@ooooo`02oooo
o`03oa0@4?oooooooooo00Wooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooo
oooo07gooooo1?l000000ooooooo0000o`00000Aooooo`;o000000?oooooo`000?l000001Oooool2
o`0000Gooooo0_l00003ooooo`;o00002Oooool2o`0000;ooooo0_l00002ooooo`;o00002?ooool4
o`0000Sooooo0_l000000ooooooo0000o`00001`ooooo`0000KoooooogMgMonHV9SooooooiRHV?mg
MgL;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`1mooooo`Co0000
0oooool2o`0000cooooo1Ol000001?oooooo0000o`000?ooool2o`0000;ooooo0_l0000:ooooo`Co
00001oooool2o`00013ooooo1?l00008ooooo`;o000000?oooooo`000?l00000L?ooool00006oooo
ooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000
ooooooooool0P?ooool2o`0000;ooooo0_l0000<ooooo`Co00000_ooool2o`000003ooooool0003o
0000013ooooo0_l0000=ooooo`;o0000Roooool001cooooo00?o0000ooooooooool0P?ooool2o`00
00Cooooo0_l0000;ooooo`?o000000Coooooo`000?l0003o00004oooool2o`0000gooooo0_l0002;
ooooo`007?ooool00ol0003oooooooooo`26ooooo`;o000000?oooooo`000?l000002?ooool6o`00
00[ooooo0_l00008ooooo`;o00002?ooool2o`0000Sooooo0ol00025ooooo`007?ooool00ol0003o
ooooooooo`26ooooo`;o000000?oooooo`000?l000000_l00008ooooo`;o00003?ooool4o`0000Co
oooo1Ol00007ooooo`;o00002?ooool3o`0008Gooooo000Looooo`03o`000?oooooooooo08_ooooo
0ol000000ooooooo0000o`000009ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Cooooo
0_l000000ooooooo0000o`00000;ooooo`;o0000S?ooool001cooooo00?o0000ooooooooool0O?oo
ool2o`0000Sooooo0_l00004ooooo`Go00002Oooool2o`000003ooooool0003o000000kooooo0_l0
0006ooooo`;o00001?ooool2o`0000;ooooo0_l00005ooooo`;o0000POooool001cooooo00?o0000
ooooooooool0MOooool2o`0000Gooooo0_l00005ooooo`;o000000?oooooo`000?l000001Oooool2
o`0000kooooo0_l0000>ooooo`Co00001?ooool2o`0000Sooooo0ol00004ooooo`;o0000POooool0
01cooooo00?o0000ooooooooool0MOooool2o`0000cooooo0_l0000Zooooo`;o00003oooool2o`00
08Oooooo000Looooo`03o`000?oooooooooo097ooooo1ol0000Iooooo`;o00000oooool2o`0001go
oooo0_l0001booooo`007?ooool00ol0003oooooooooo`2Aooooo`Oo00003Oooool2o`0000[ooooo
0_l00003ooooo`;o00007Oooool2o`0007;ooooo000Looooo`03o`000?oooooooooo09_ooooo0_l0
0008ooooo`;o00005Oooool2o`0008_ooooo000Looooo`03o`000?oooooooooo09_ooooo0_l0000O
ooooo`;o0000Roooool001cooooo0_l0002Qooooo`;o0000Yoooool001cooooo00?o0000oooooooo
ool0X?ooool2o`0000Cooooo0_l0002Qooooo`007?ooool00ol0003oooooooooo`2Iooooo`Co0000
2Oooool3o`0000Sooooo0_l0002Fooooo`007?ooool00ol0003oooooooooo`2Iooooo`Co00002_oo
ool2o`0000Sooooo0ol0002Eooooo`007?ooool00ol0003oooooooooo`2booooo`;o0000UOooool0
01cooooo00?o0000ooooooooool0L_ooool2o`0002gooooo0_l0002Vooooo`007?ooool00ol0003o
ooooooooo`1booooo`;o00008Oooool2o`0000?ooooo0_l00005ooooo`;o0000Y_ooool001cooooo
00?o0000ooooooooool0UOooool2o`0000?ooooo0_l0002]ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0P?ooool2o`000<Oooooo000Looooo`03o`000?oooooooooo083ooooo0_l00037ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`004_ooool4o`000003
oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Ooo
ool3o`000?ooooooB_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0
003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo
00?o0000ooooooooool0oooooomBooooo`004_ooool00omEEEGoIVIVo`00003ooooooeCooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo002Qooooo`04oa0@4?l0003o0000ooooo`;o
000000?o410@ooooooooool05_ooool4o`000008oa0@4?oooooooooooiRHV?l@413o0000oc8b<_o<
c<`3ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<08co
oooo002Rooooo`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo00?o0000oooooooo
ool00_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00Go410@okZj^_ooooooMgMgoc8b<P03
ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40S?ooool00:;ooooo00Go0000ooooooooooooooooo`00
000Kooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool0R_ooool00:;ooooo00Go0000oooooooooooooooo
o`000009ooooo`Ko00003?ooool00ol0003oooooooooo`05ooooo`03ojVYZOl@413ooooo00Gooooo
00?oZJVYoa0@4?ooool00_ooool01Olb<S;oV9RHoooooonHV9So<S8b08cooooo002Rooooo`05o`00
0?n7QhOoooooojVYZOl000006oooool00ol0003oooooooooo`04ooooo`03oa0@4?l0003o^[Zj00Go
oooo00?o410@o`000?nj^[X00oooool01Oo<c<co0000o`000?l0003oc<c<08cooooo002Qooooo`03
oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool06Oooool00ol0003oooooooooo`05ooooo`03
okZj^_lQ8B7ooooo00Gooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413o^[Zjoooooonj^[[o410@
08cooooo0032ooooo`03o`000?oooooooooo00;ooooo00Go410@oiRHV?oooooo^[Zjo`000003oooo
o`05oa0@4?nHV9SooooookZj^_l000000oooool01Ol0003o^[Zjoooooonj^[[o000008cooooo0030
ooooo`03oeEEEOmVIVKo000000Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05ojVYZOl@
413o0000oa0@4?nYZJT00oooool01OnYZJWo410@o`000?l@413oZJVY08cooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1344) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.34118 .48793 Mdot
.33715 .49262 Mdot
.62522 .61931 Mdot
.45995 .40388 Mdot
.79694 .56813 Mdot
.60675 .58741 Mdot
.43878 .69704 Mdot
.46688 .64029 Mdot
.61736 .62839 Mdot
.37728 .63883 Mdot
.4446 .63636 Mdot
.56054 .36129 Mdot
.44971 .66964 Mdot
.47511 .37028 Mdot
.84985 .40907 Mdot
.48229 .4479 Mdot
.33771 .48668 Mdot
.6855 .48398 Mdot
.53599 .42183 Mdot
.62995 .57706 Mdot
.32685 .46952 Mdot
.47658 .37739 Mdot
.28429 .51794 Mdot
.47532 .36969 Mdot
.48126 .41698 Mdot
.29548 .52876 Mdot
.26144 .50707 Mdot
.51004 .41603 Mdot
.52876 .39633 Mdot
.45943 .63317 Mdot
.61163 .30636 Mdot
.84033 .45748 Mdot
.4158 .42485 Mdot
.73238 .3275 Mdot
.47337 .66148 Mdot
.31773 .40178 Mdot
.61139 .59871 Mdot
.43883 .65399 Mdot
.43378 .65622 Mdot
.48118 .65343 Mdot
.44971 .64536 Mdot
.29376 .50965 Mdot
.33326 .59919 Mdot
.65123 .67723 Mdot
.44633 .43035 Mdot
.70149 .71158 Mdot
.2637 .46205 Mdot
.48226 .3484 Mdot
.33551 .5302 Mdot
.70088 .51715 Mdot
.58305 .70424 Mdot
.44528 .6893 Mdot
.61786 .56646 Mdot
.12012 .42838 Mdot
.44186 .68014 Mdot
.50251 .32534 Mdot
.61551 .61079 Mdot
.49048 .38039 Mdot
.47843 .36673 Mdot
.35839 .27921 Mdot
.43836 .37791 Mdot
.64102 .44238 Mdot
.30203 .55931 Mdot
.50609 .58662 Mdot
.60721 .61761 Mdot
.43257 .64869 Mdot
.33185 .49775 Mdot
.45331 .67494 Mdot
.44062 .32296 Mdot
.5861 .57625 Mdot
.47975 .34752 Mdot
.44151 .63925 Mdot
.27692 .49097 Mdot
.51731 .39139 Mdot
.69296 .6146 Mdot
.66463 .77376 Mdot
.62048 .43585 Mdot
.31827 .37657 Mdot
.35235 .27856 Mdot
.72526 .54826 Mdot
.49796 .43425 Mdot
.65963 .36793 Mdot
.67196 .75761 Mdot
.30167 .54811 Mdot
.49131 .45509 Mdot
.69514 .48548 Mdot
.51532 .39574 Mdot
.74573 .69725 Mdot
.46597 .34386 Mdot
.62748 .49565 Mdot
.62158 .63383 Mdot
.32432 .52138 Mdot
.46037 .40822 Mdot
.51998 .37716 Mdot
.39908 .25182 Mdot
.53023 .36137 Mdot
.48228 .39588 Mdot
.33411 .53831 Mdot
.44455 .68828 Mdot
.48225 .32767 Mdot
.57954 .66656 Mdot
.64946 .62526 Mdot
.44834 .41332 Mdot
.59484 .63702 Mdot
.2719 .5168 Mdot
.5187 .37647 Mdot
.43139 .66542 Mdot
.44221 .39333 Mdot
.31121 .71275 Mdot
.32614 .48229 Mdot
.52248 .4104 Mdot
.67845 .46895 Mdot
.27222 .33408 Mdot
.32769 .52846 Mdot
.5682 .66338 Mdot
.53792 .40854 Mdot
.49279 .39647 Mdot
.33875 .50234 Mdot
.62871 .64314 Mdot
.7275 .71305 Mdot
.33041 .54506 Mdot
.46832 .63237 Mdot
.29917 .47172 Mdot
.55836 .37032 Mdot
.59763 .61491 Mdot
.62971 .68636 Mdot
.29398 .67474 Mdot
.63459 .30383 Mdot
.51263 .39447 Mdot
.35014 .60645 Mdot
.65318 .60477 Mdot
.32323 .51139 Mdot
.45641 .67051 Mdot
.47462 .4612 Mdot
.30507 .48801 Mdot
.44242 .63309 Mdot
.66409 .46944 Mdot
.5195 .72891 Mdot
.27807 .50079 Mdot
.53146 .50041 Mdot
.41781 .67777 Mdot
.46778 .67892 Mdot
.62776 .21316 Mdot
.33105 .50197 Mdot
.65763 .43786 Mdot
.46457 .66066 Mdot
.61914 .27501 Mdot
.44105 .42125 Mdot
.62427 .35942 Mdot
.19964 .54964 Mdot
.70878 .30098 Mdot
.53595 .74688 Mdot
.68228 .44614 Mdot
.4242 .63745 Mdot
.47587 .40704 Mdot
.30279 .5349 Mdot
.2888 .52376 Mdot
.43788 .38128 Mdot
.47716 .42371 Mdot
.47943 .34537 Mdot
.50804 .35058 Mdot
.49782 .28478 Mdot
.54615 .37829 Mdot
.25133 .45252 Mdot
.32043 .525 Mdot
.4655 .40361 Mdot
.59458 .578 Mdot
.42989 .36639 Mdot
.44642 .64132 Mdot
.48443 .38232 Mdot
.46131 .40647 Mdot
.43452 .40335 Mdot
.45171 .68758 Mdot
.84885 .49967 Mdot
.23877 .37649 Mdot
.83124 .49312 Mdot
.60002 .48069 Mdot
.58348 .59827 Mdot
.50986 .40416 Mdot
.64816 .45111 Mdot
.36426 .37085 Mdot
.45282 .38913 Mdot
.23329 .74214 Mdot
.47787 .38887 Mdot
.81037 .54888 Mdot
.46148 .31954 Mdot
.8031 .42788 Mdot
.64755 .35294 Mdot
.48789 .41244 Mdot
.38157 .58694 Mdot
.40661 .68368 Mdot
.66628 .60945 Mdot
.45061 .64978 Mdot
.60023 .57465 Mdot
.62222 .61627 Mdot
.50313 .60437 Mdot
.5684 .38048 Mdot
.41898 .38105 Mdot
.49087 .33893 Mdot
.56928 .60822 Mdot
.29402 .55342 Mdot
.66651 .47564 Mdot
.35185 .50944 Mdot
.83972 .62374 Mdot
.67209 .70119 Mdot
.48159 .67602 Mdot
.63967 .46026 Mdot
.64064 .62434 Mdot
.61185 .63528 Mdot
.68147 .46168 Mdot
.50205 .36417 Mdot
.32458 .50057 Mdot
.66872 .23812 Mdot
.35457 .74439 Mdot
.56934 .15615 Mdot
.33105 .53841 Mdot
.36554 .63434 Mdot
.45907 .63706 Mdot
.62433 .59637 Mdot
.48997 .39683 Mdot
.50469 .37293 Mdot
.34889 .47899 Mdot
.48578 .3453 Mdot
.23501 .53716 Mdot
.49131 .40507 Mdot
.52452 .68373 Mdot
.63463 .46809 Mdot
.50562 .60564 Mdot
.66137 .30859 Mdot
.29919 .54376 Mdot
.46999 .22863 Mdot
.59255 .63135 Mdot
.36294 .3628 Mdot
.42935 .64833 Mdot
.64893 .46241 Mdot
.59254 .62229 Mdot
.67355 .47401 Mdot
.54734 .39385 Mdot
.61453 .57375 Mdot
.69015 .44749 Mdot
.58768 .3717 Mdot
.43016 .41205 Mdot
.24869 .67787 Mdot
.47925 .65139 Mdot
.35525 .50677 Mdot
.44418 .36737 Mdot
.57928 .6191 Mdot
.45671 .46051 Mdot
.55449 .77596 Mdot
.5412 .67206 Mdot
.6558 .61313 Mdot
.54285 .61317 Mdot
.63935 .44922 Mdot
.59738 .73294 Mdot
.35482 .62 Mdot
.34341 .49598 Mdot
.53353 .36259 Mdot
.79975 .40269 Mdot
.46414 .66172 Mdot
.44449 .37749 Mdot
.75219 .45154 Mdot
.46253 .67364 Mdot
.49267 .38114 Mdot
.44497 .62851 Mdot
.28827 .52272 Mdot
.31537 .28205 Mdot
.34409 .50939 Mdot
.5001 .34306 Mdot
.43206 .67343 Mdot
.58598 .63842 Mdot
.2988 .52526 Mdot
.49529 .35733 Mdot
.50983 .41374 Mdot
.55405 .55185 Mdot
.46936 .39741 Mdot
.83442 .52125 Mdot
.48991 .40917 Mdot
.63053 .60604 Mdot
.47565 .43669 Mdot
.20012 .37674 Mdot
.49294 .60138 Mdot
.33062 .49895 Mdot
.65452 .62699 Mdot
.61524 .62293 Mdot
.69654 .65937 Mdot
.48589 .62389 Mdot
.5335 .41614 Mdot
.58016 .61198 Mdot
.53557 .259 Mdot
.41952 .6599 Mdot
.45449 .3409 Mdot
.48424 .51183 Mdot
.68775 .51814 Mdot
.62225 .56881 Mdot
.47953 .47023 Mdot
.27391 .51051 Mdot
.46302 .414 Mdot
.61384 .638 Mdot
.56501 .42193 Mdot
.52546 .41689 Mdot
.21914 .54643 Mdot
.55299 .55858 Mdot
.4242 .68752 Mdot
.46572 .32143 Mdot
.45505 .36446 Mdot
.60846 .5763 Mdot
.30126 .54235 Mdot
.41803 .66298 Mdot
.29386 .51599 Mdot
.78618 .40771 Mdot
.2605 .68466 Mdot
.56197 .31126 Mdot
.66336 .48037 Mdot
.71125 .48922 Mdot
.79258 .41026 Mdot
.41906 .21251 Mdot
.5171 .22804 Mdot
.74079 .31597 Mdot
.60915 .6415 Mdot
.74148 .46926 Mdot
.61579 .6177 Mdot
.48972 .42709 Mdot
.5987 .61312 Mdot
.79601 .39218 Mdot
.48915 .40338 Mdot
.59981 .60369 Mdot
.4413 .23523 Mdot
.46608 .41283 Mdot
.34161 .49664 Mdot
.83096 .6007 Mdot
.28723 .2666 Mdot
.53567 .6671 Mdot
.63977 .59666 Mdot
.55779 .23245 Mdot
.4805 .39688 Mdot
.47839 .43627 Mdot
.31317 .53444 Mdot
.43565 .4485 Mdot
.65147 .42865 Mdot
.63473 .45094 Mdot
.38909 .65783 Mdot
.6228 .41578 Mdot
.47242 .31771 Mdot
.302 .52697 Mdot
.49249 .28907 Mdot
.69088 .58294 Mdot
.70872 .50992 Mdot
.42594 .70626 Mdot
.83032 .59896 Mdot
.24562 .52452 Mdot
.48223 .70569 Mdot
.63096 .54203 Mdot
.33732 .51812 Mdot
.85153 .48007 Mdot
.44719 .65301 Mdot
.26292 .70616 Mdot
.39489 .53726 Mdot
.50013 .36578 Mdot
.42147 .67073 Mdot
.51813 .45965 Mdot
.30611 .25147 Mdot
.339 .77147 Mdot
.40824 .46954 Mdot
.45935 .34572 Mdot
.6771 .56785 Mdot
.48711 .38801 Mdot
.63265 .75161 Mdot
.49452 .41249 Mdot
.29789 .51577 Mdot
.37773 .65791 Mdot
.4281 .6144 Mdot
.20739 .43892 Mdot
.6061 .74152 Mdot
.6827 .4438 Mdot
.49413 .40278 Mdot
.49794 .36427 Mdot
.66497 .42674 Mdot
.28083 .51625 Mdot
.49217 .34249 Mdot
.47108 .22257 Mdot
.51658 .37073 Mdot
.44393 .64617 Mdot
.36918 .5529 Mdot
.24058 .49024 Mdot
.52266 .3651 Mdot
.2709 .5273 Mdot
.46514 .69089 Mdot
.43452 .67231 Mdot
.47318 .31496 Mdot
.48117 .64337 Mdot
.47068 .3857 Mdot
.37249 .79309 Mdot
.28426 .49271 Mdot
.24217 .58875 Mdot
.30597 .49503 Mdot
.31 .37056 Mdot
.45608 .68191 Mdot
.54173 .69801 Mdot
.54813 .43462 Mdot
.44718 .65782 Mdot
.33489 .4643 Mdot
.47196 .44435 Mdot
.44077 .43548 Mdot
.63413 .23472 Mdot
.6384 .6098 Mdot
.54489 .57069 Mdot
.46049 .63311 Mdot
.47917 .35485 Mdot
.53575 .3775 Mdot
.4721 .68483 Mdot
.36615 .77247 Mdot
.33731 .24697 Mdot
.48997 .40683 Mdot
.30805 .51581 Mdot
.31944 .50964 Mdot
.43025 .38194 Mdot
.45475 .41856 Mdot
.59052 .60908 Mdot
.60632 .64687 Mdot
.59402 .57273 Mdot
.54237 .57991 Mdot
.53902 .69422 Mdot
.75468 .64244 Mdot
.48116 .65397 Mdot
.34799 .65968 Mdot
.63065 .49319 Mdot
.49572 .33629 Mdot
.64591 .60258 Mdot
.45532 .367 Mdot
.46211 .38871 Mdot
.49258 .63574 Mdot
.78502 .51102 Mdot
.26218 .48164 Mdot
.28699 .53946 Mdot
.41453 .67482 Mdot
.49783 .31035 Mdot
.48312 .69079 Mdot
.65505 .4628 Mdot
.66948 .2656 Mdot
.43402 .64371 Mdot
.3418 .50011 Mdot
.47543 .65075 Mdot
.50971 .37371 Mdot
.55 .37317 Mdot
.33589 .51407 Mdot
.65368 .42301 Mdot
.44097 .4493 Mdot
.49415 .38455 Mdot
.19214 .55692 Mdot
.65718 .27477 Mdot
.50579 .70195 Mdot
.4872 .41052 Mdot
.52978 .38308 Mdot
.689 .42737 Mdot
.51525 .37068 Mdot
.46068 .35123 Mdot
.27973 .33416 Mdot
.31278 .68535 Mdot
.63399 .45676 Mdot
.38095 .78996 Mdot
.33376 .5364 Mdot
.81939 .42912 Mdot
.62406 .58707 Mdot
.3969 .62382 Mdot
.29605 .27684 Mdot
.61419 .56509 Mdot
.53367 .75178 Mdot
.82937 .4493 Mdot
.52816 .63193 Mdot
.64464 .6558 Mdot
.25878 .50218 Mdot
.5005 .34564 Mdot
.49413 .3932 Mdot
.64519 .44454 Mdot
.31745 .50109 Mdot
.53744 .55279 Mdot
.54724 .82907 Mdot
.47764 .38066 Mdot
.24126 .56878 Mdot
.45541 .79777 Mdot
.68533 .5236 Mdot
.66297 .45309 Mdot
.63346 .4372 Mdot
.49593 .40113 Mdot
.2489 .35746 Mdot
.29674 .52934 Mdot
.4938 .35705 Mdot
.54345 .3717 Mdot
.63896 .60178 Mdot
.31161 .48096 Mdot
.63189 .64181 Mdot
.56796 .7105 Mdot
.82658 .50798 Mdot
.20471 .66258 Mdot
.44421 .68323 Mdot
.59787 .78465 Mdot
.4318 .63486 Mdot
.66701 .36735 Mdot
.64969 .58874 Mdot
.45826 .41447 Mdot
.29681 .54096 Mdot
.47214 .3575 Mdot
.45733 .4194 Mdot
.50003 .36335 Mdot
.52447 .36376 Mdot
.16656 .60499 Mdot
.68614 .4496 Mdot
.53362 .43542 Mdot
.62996 .61139 Mdot
.68715 .73478 Mdot
.64763 .7729 Mdot
.49369 .36444 Mdot
.50318 .41113 Mdot
.28951 .49293 Mdot
.4398 .37939 Mdot
.42473 .6431 Mdot
.34831 .53285 Mdot
.52093 .38931 Mdot
.80516 .63688 Mdot
.52881 .40261 Mdot
.81916 .45381 Mdot
.47304 .64894 Mdot
.32118 .7265 Mdot
.55606 .40529 Mdot
.53462 .65471 Mdot
.54523 .56989 Mdot
.59075 .61678 Mdot
.45416 .62324 Mdot
.6091 .59986 Mdot
.51428 .83209 Mdot
.546 .35598 Mdot
.47638 .40996 Mdot
.50392 .33675 Mdot
.58357 .5972 Mdot
.76462 .67319 Mdot
.62803 .72396 Mdot
.56052 .39116 Mdot
.58963 .59097 Mdot
.27989 .54435 Mdot
.62235 .24632 Mdot
.29655 .50111 Mdot
.68467 .47545 Mdot
.45454 .63871 Mdot
.64973 .42549 Mdot
.75948 .42109 Mdot
.33306 .48653 Mdot
.34797 .48605 Mdot
.62151 .58805 Mdot
.40296 .53898 Mdot
.3171 .20102 Mdot
.39414 .541 Mdot
.64928 .33284 Mdot
.30977 .53021 Mdot
.52728 .3881 Mdot
.70086 .38815 Mdot
.39331 .56308 Mdot
.60778 .60266 Mdot
.45699 .38178 Mdot
.31665 .27788 Mdot
.59041 .60935 Mdot
.5017 .33412 Mdot
.63357 .61338 Mdot
.45541 .64649 Mdot
.64693 .61129 Mdot
.36556 .51058 Mdot
.51831 .40316 Mdot
.3718 .15975 Mdot
.72674 .44395 Mdot
.48008 .40102 Mdot
.41496 .68326 Mdot
.4615 .76136 Mdot
.44758 .39493 Mdot
.6881 .46199 Mdot
.59581 .59571 Mdot
.41175 .50677 Mdot
.49175 .40917 Mdot
.59048 .58755 Mdot
.3373 .48341 Mdot
.42794 .63075 Mdot
.39119 .25723 Mdot
.52846 .65594 Mdot
.31425 .53566 Mdot
.57004 .48661 Mdot
.47063 .6264 Mdot
.5293 .3813 Mdot
.53329 .36438 Mdot
.31024 .51309 Mdot
.59502 .36018 Mdot
.45331 .42538 Mdot
.49317 .43415 Mdot
.63296 .59888 Mdot
.60593 .5972 Mdot
.47156 .24888 Mdot
.61651 .64518 Mdot
.55063 .37638 Mdot
.30775 .51205 Mdot
.45858 .40572 Mdot
.29282 .48775 Mdot
.43972 .38129 Mdot
.56163 .3438 Mdot
.28106 .51801 Mdot
.50832 .64539 Mdot
.45839 .386 Mdot
.41281 .4097 Mdot
.44258 .38875 Mdot
.50134 .34787 Mdot
.59456 .61616 Mdot
.65701 .45691 Mdot
.52957 .35086 Mdot
.66821 .4119 Mdot
.66902 .47348 Mdot
.42308 .62251 Mdot
.63966 .60439 Mdot
.66685 .43428 Mdot
.46861 .80611 Mdot
.60982 .57073 Mdot
.64731 .43506 Mdot
.64922 .7717 Mdot
.47224 .66548 Mdot
.27405 .50477 Mdot
.46803 .41551 Mdot
.76705 .39788 Mdot
.25052 .47012 Mdot
.6391 .64928 Mdot
.48722 .4072 Mdot
.44602 .37826 Mdot
.31998 .54932 Mdot
.54586 .84636 Mdot
.58612 .57646 Mdot
.53099 .41009 Mdot
.33111 .49093 Mdot
.53536 .86452 Mdot
.62554 .60945 Mdot
.64435 .43892 Mdot
.47498 .66766 Mdot
.28393 .46375 Mdot
.29163 .67435 Mdot
.43221 .69514 Mdot
.6567 .56083 Mdot
.57189 .70324 Mdot
.5403 .40455 Mdot
.64767 .6012 Mdot
.58616 .17797 Mdot
.45146 .30108 Mdot
.51811 .5955 Mdot
.56569 .23394 Mdot
.3336 .52252 Mdot
.42943 .63754 Mdot
.68368 .44833 Mdot
.32475 .54051 Mdot
.33467 .48454 Mdot
.48054 .67361 Mdot
.25493 .36931 Mdot
.47659 .51189 Mdot
.43711 .65084 Mdot
.705 .319 Mdot
.76029 .6106 Mdot
.64547 .5998 Mdot
.65271 .42848 Mdot
.76255 .43515 Mdot
.2925 .51196 Mdot
.84488 .5782 Mdot
.63879 .23253 Mdot
.48207 .39571 Mdot
.66801 .43784 Mdot
.76631 .65632 Mdot
.60102 .82152 Mdot
.45823 .67788 Mdot
.40717 .62943 Mdot
.64106 .43461 Mdot
.44505 .36705 Mdot
.61886 .25507 Mdot
.48664 .43235 Mdot
.45903 .63978 Mdot
.41113 .26057 Mdot
.33641 .48724 Mdot
.47567 .67562 Mdot
.66505 .25971 Mdot
.47107 .38389 Mdot
.45688 .38664 Mdot
.68439 .32573 Mdot
.31458 .54494 Mdot
.59033 .61661 Mdot
.5448 .39067 Mdot
.49042 .38402 Mdot
.52601 .3416 Mdot
.46535 .32413 Mdot
.28585 .31526 Mdot
.49366 .42302 Mdot
.66887 .7152 Mdot
.45637 .34641 Mdot
.46383 .37684 Mdot
.27026 .52344 Mdot
.20582 .67488 Mdot
.59234 .71286 Mdot
.48655 .38353 Mdot
.53218 .39444 Mdot
.47696 .67228 Mdot
.42461 .5253 Mdot
.41173 .52637 Mdot
.41556 .50083 Mdot
.53776 .22881 Mdot
.4256 .40285 Mdot
.32503 .49603 Mdot
.69159 .44688 Mdot
.53449 .40918 Mdot
.32741 .494 Mdot
.43915 .41468 Mdot
.58893 .60756 Mdot
.60821 .57075 Mdot
.47106 .29807 Mdot
.67276 .43448 Mdot
.27424 .57082 Mdot
.34401 .65767 Mdot
.60809 .57424 Mdot
.47711 .41263 Mdot
.48653 .61721 Mdot
.61233 .63711 Mdot
.54141 .64112 Mdot
.6064 .39815 Mdot
.30021 .53632 Mdot
.3233 .52432 Mdot
.62202 .36128 Mdot
.54141 .73587 Mdot
.18744 .49451 Mdot
.45598 .64507 Mdot
.54276 .41984 Mdot
.36816 .6072 Mdot
.32431 .52715 Mdot
.68954 .37623 Mdot
.67062 .43666 Mdot
.46472 .67129 Mdot
.68183 .60433 Mdot
.29725 .4902 Mdot
.3172 .47523 Mdot
.44311 .35771 Mdot
.4973 .37773 Mdot
.50886 .22877 Mdot
.6888 .41569 Mdot
.43497 .69717 Mdot
.64782 .4311 Mdot
.64986 .58968 Mdot
.50646 .42325 Mdot
.28338 .52117 Mdot
.74608 .62978 Mdot
.53654 .40328 Mdot
.60672 .62884 Mdot
.33059 .5216 Mdot
.63848 .44812 Mdot
.69183 .45736 Mdot
.50755 .35254 Mdot
.42837 .27163 Mdot
.43999 .65843 Mdot
.3411 .51462 Mdot
.48942 .68639 Mdot
.47231 .43351 Mdot
.50203 .38509 Mdot
.43212 .34091 Mdot
.43375 .69708 Mdot
.37968 .72235 Mdot
.66761 .47836 Mdot
.32282 .50356 Mdot
.49752 .41947 Mdot
.65814 .42946 Mdot
.35955 .66295 Mdot
.65652 .60816 Mdot
.64577 .61576 Mdot
.69429 .45026 Mdot
.6664 .44639 Mdot
.68008 .47067 Mdot
.84592 .57707 Mdot
.32592 .55121 Mdot
.24576 .52136 Mdot
.49204 .44077 Mdot
.64578 .34539 Mdot
.52034 .44995 Mdot
.41695 .67261 Mdot
.63719 .61393 Mdot
.44854 .40531 Mdot
.5195 .36422 Mdot
.4733 .31224 Mdot
.2341 .57317 Mdot
.26506 .46978 Mdot
.3191 .47992 Mdot
.55419 .38341 Mdot
.63587 .59405 Mdot
.84831 .61861 Mdot
.68319 .23352 Mdot
.5565 .40191 Mdot
.47529 .50873 Mdot
.28379 .52723 Mdot
.48201 .65835 Mdot
.71963 .364 Mdot
.47478 .66274 Mdot
.32557 .50613 Mdot
.49689 .4238 Mdot
.34742 .6762 Mdot
.69296 .42982 Mdot
.48515 .35105 Mdot
.46442 .64248 Mdot
.47729 .34894 Mdot
.43546 .69648 Mdot
.78623 .42163 Mdot
.55346 .19291 Mdot
.47882 .38979 Mdot
.50687 .45072 Mdot
.5337 .2141 Mdot
.48919 .36174 Mdot
.70655 .45115 Mdot
.2836 .52743 Mdot
.41991 .24984 Mdot
.45611 .44396 Mdot
.42777 .3001 Mdot
.47938 .43445 Mdot
.4026 .24243 Mdot
.50327 .38215 Mdot
.67803 .52902 Mdot
.52103 .40892 Mdot
.46936 .34584 Mdot
.43678 .68105 Mdot
.47459 .67638 Mdot
.27043 .49836 Mdot
.58264 .62753 Mdot
.82607 .47163 Mdot
.49724 .38553 Mdot
.54979 .67566 Mdot
.34299 .70841 Mdot
.66579 .44864 Mdot
.31936 .50484 Mdot
.59401 .84217 Mdot
.46079 .63095 Mdot
.60676 .21407 Mdot
.48342 .24737 Mdot
.28852 .63544 Mdot
.73476 .4251 Mdot
.46119 .77643 Mdot
.64267 .4571 Mdot
.43546 .40445 Mdot
.7691 .56461 Mdot
.67046 .53407 Mdot
.60028 .39057 Mdot
.4656 .62226 Mdot
.38178 .33999 Mdot
.78378 .5295 Mdot
.69559 .46061 Mdot
.63679 .43671 Mdot
.44233 .69163 Mdot
.62434 .66267 Mdot
.56605 .37681 Mdot
.67299 .44105 Mdot
.58585 .5861 Mdot
.61823 .57144 Mdot
.59749 .56768 Mdot
.29295 .52853 Mdot
.65177 .22771 Mdot
.48273 .68174 Mdot
.42305 .68456 Mdot
.56506 .63549 Mdot
.38831 .44683 Mdot
.35329 .53509 Mdot
.6189 .59417 Mdot
.63805 .63313 Mdot
.27973 .5233 Mdot
.49681 .32106 Mdot
.52956 .33086 Mdot
.48157 .3824 Mdot
.65107 .45311 Mdot
.50201 .37633 Mdot
.59012 .59358 Mdot
.45237 .67932 Mdot
.63856 .62978 Mdot
.41278 .67983 Mdot
.73725 .6636 Mdot
.50053 .35591 Mdot
.5183 .40683 Mdot
.19929 .59685 Mdot
.30952 .472 Mdot
.70185 .70155 Mdot
.51667 .67552 Mdot
.61817 .6171 Mdot
.45833 .35345 Mdot
.35075 .52985 Mdot
.68688 .41701 Mdot
.22042 .67334 Mdot
.453 .4197 Mdot
.28712 .50794 Mdot
.50642 .42151 Mdot
.49396 .27967 Mdot
.18328 .41082 Mdot
.29926 .50967 Mdot
.20305 .53898 Mdot
.53044 .39658 Mdot
.5078 .80095 Mdot
.45792 .34 Mdot
.57281 .29639 Mdot
.45351 .42553 Mdot
.33344 .53718 Mdot
.48319 .37938 Mdot
.35235 .52379 Mdot
.61524 .57744 Mdot
.47982 .66276 Mdot
.31677 .53293 Mdot
.52731 .36152 Mdot
.38732 .10704 Mdot
.46141 .64878 Mdot
.49218 .39956 Mdot
.45649 .68395 Mdot
.31412 .49887 Mdot
.33283 .5315 Mdot
.59869 .81411 Mdot
.56883 .71277 Mdot
.45511 .64823 Mdot
.50666 .42267 Mdot
.55111 .78826 Mdot
.47077 .42316 Mdot
.55089 .2565 Mdot
.50245 .32611 Mdot
.47911 .4383 Mdot
.65281 .77585 Mdot
.42348 .68756 Mdot
.1842 .4872 Mdot
.63401 .79909 Mdot
.68477 .7381 Mdot
.33552 .47129 Mdot
.69825 .45311 Mdot
.85165 .48767 Mdot
.53784 .69569 Mdot
.58836 .59114 Mdot
.44544 .39626 Mdot
.37317 .51843 Mdot
.43649 .66106 Mdot
.66041 .46238 Mdot
.47989 .39045 Mdot
.64492 .62489 Mdot
.38414 .22597 Mdot
.41833 .64669 Mdot
.29682 .50649 Mdot
.29698 .5496 Mdot
.3871 .81977 Mdot
.49041 .41413 Mdot
.52005 .3997 Mdot
.45562 .63835 Mdot
.42457 .77177 Mdot
.6528 .46939 Mdot
.44118 .23257 Mdot
.45534 .65021 Mdot
.50607 .54829 Mdot
.33483 .49646 Mdot
.44763 .37485 Mdot
.80961 .60727 Mdot
.68591 .63862 Mdot
.20662 .5877 Mdot
.64823 .45021 Mdot
.55583 .2572 Mdot
.33547 .5354 Mdot
.45976 .6667 Mdot
.50679 .74426 Mdot
.42273 .39961 Mdot
.45794 .36648 Mdot
.56573 .26751 Mdot
.42859 .61576 Mdot
.40472 .47852 Mdot
.45947 .42606 Mdot
.53952 .58178 Mdot
.44545 .40925 Mdot
.44163 .44212 Mdot
.52588 .33655 Mdot
.50868 .39208 Mdot
.28406 .51608 Mdot
.39503 .41138 Mdot
.58397 .61299 Mdot
.2618 .54833 Mdot
.50329 .55518 Mdot
.4844 .40296 Mdot
.50484 .43054 Mdot
.36386 .45459 Mdot
.52186 .76606 Mdot
.31751 .53027 Mdot
.35342 .48888 Mdot
.47711 .6391 Mdot
.51445 .32283 Mdot
.5886 .63275 Mdot
.46517 .45813 Mdot
.5995 .62209 Mdot
.28429 .52014 Mdot
.62099 .61433 Mdot
.47189 .67348 Mdot
.64054 .59117 Mdot
.5399 .69424 Mdot
.46772 .65569 Mdot
.30527 .53736 Mdot
.5174 .38702 Mdot
.41451 .68109 Mdot
.63861 .29513 Mdot
.65015 .45116 Mdot
.68447 .78589 Mdot
.52158 .39018 Mdot
.3061 .68476 Mdot
.57165 .42276 Mdot
.63776 .63211 Mdot
.18087 .42142 Mdot
.28564 .53678 Mdot
.6302 .44319 Mdot
.30309 .54639 Mdot
.64537 .25549 Mdot
.6575 .44621 Mdot
.68737 .76394 Mdot
.5845 .53154 Mdot
.64948 .2701 Mdot
.49635 .31771 Mdot
.67247 .3046 Mdot
.63104 .57366 Mdot
.43609 .66382 Mdot
.51751 .74677 Mdot
.46455 .34939 Mdot
.45612 .19207 Mdot
.27993 .53987 Mdot
.58175 .62416 Mdot
.45362 .6732 Mdot
.41725 .66432 Mdot
.52317 .42896 Mdot
.73115 .52293 Mdot
.45971 .36074 Mdot
.54477 .72484 Mdot
.5447 .23541 Mdot
.23156 .51423 Mdot
.49132 .40457 Mdot
.60965 .57638 Mdot
.50614 .4216 Mdot
.65723 .47968 Mdot
.628 .20529 Mdot
.43187 .44089 Mdot
.50421 .69674 Mdot
.7233 .45194 Mdot
.33934 .50665 Mdot
.58304 .41989 Mdot
.51966 .69522 Mdot
.49052 .4164 Mdot
.12946 .57006 Mdot
.65135 .43209 Mdot
.76895 .55932 Mdot
.53219 .37789 Mdot
.53404 .41705 Mdot
.47854 .58335 Mdot
.27835 .65945 Mdot
.68948 .61814 Mdot
.47985 .3623 Mdot
.59568 .28284 Mdot
.43205 .69145 Mdot
.44183 .37934 Mdot
.49456 .39554 Mdot
.25809 .40313 Mdot
.41541 .66214 Mdot
.62079 .6239 Mdot
.61756 .56483 Mdot
.63907 .64768 Mdot
.64814 .47573 Mdot
.41482 .71299 Mdot
.67516 .35898 Mdot
.33397 .23844 Mdot
.64148 .42453 Mdot
.51793 .36469 Mdot
.71672 .42533 Mdot
.49572 .42707 Mdot
.66881 .45918 Mdot
.41576 .65873 Mdot
.32131 .53212 Mdot
.37042 .61848 Mdot
.60841 .5679 Mdot
.41959 .38383 Mdot
.65066 .46999 Mdot
.30178 .53493 Mdot
.73624 .39765 Mdot
.33605 .50423 Mdot
.45074 .65867 Mdot
.43318 .71495 Mdot
.66466 .46287 Mdot
.31115 .49577 Mdot
.49215 .69952 Mdot
.57807 .8293 Mdot
.53871 .34715 Mdot
.39978 .71602 Mdot
.34622 .52029 Mdot
.35895 .4994 Mdot
.34579 .53033 Mdot
.48727 .34625 Mdot
.47785 .50892 Mdot
.45192 .43372 Mdot
.4251 .68916 Mdot
.63144 .61692 Mdot
.50316 .20841 Mdot
.6407 .69336 Mdot
.53914 .48678 Mdot
.5503 .40686 Mdot
.47066 .38204 Mdot
.4957 .40083 Mdot
.45629 .44571 Mdot
.51714 .71985 Mdot
.46596 .35981 Mdot
.43552 .68091 Mdot
.59339 .59684 Mdot
.43533 .40525 Mdot
.56787 .58202 Mdot
.67933 .73377 Mdot
.65676 .42102 Mdot
.40075 .68984 Mdot
.68784 .22254 Mdot
.30546 .53436 Mdot
.65389 .627 Mdot
.59651 .58231 Mdot
.66073 .46799 Mdot
.4404 .65211 Mdot
.3338 .50209 Mdot
.54163 .25925 Mdot
.67092 .47275 Mdot
.48599 .38111 Mdot
.46305 .50111 Mdot
.49257 .18632 Mdot
.43626 .40249 Mdot
.45172 .40028 Mdot
.60917 .55909 Mdot
.77031 .53908 Mdot
.44467 .14507 Mdot
.69273 .35796 Mdot
.65978 .46008 Mdot
.68306 .43097 Mdot
.27706 .50852 Mdot
.46934 .44496 Mdot
.42889 .69363 Mdot
.39105 .52278 Mdot
.42396 .73249 Mdot
.32502 .57741 Mdot
.22863 .62114 Mdot
.44797 .40995 Mdot
.39063 .78235 Mdot
.46849 .38581 Mdot
.32603 .55088 Mdot
.2869 .51911 Mdot
.30536 .52274 Mdot
.43698 .66378 Mdot
.33111 .38597 Mdot
.43067 .67297 Mdot
.66677 .19485 Mdot
.33954 .52704 Mdot
.57492 .53958 Mdot
.6274 .59249 Mdot
.55879 .38266 Mdot
.63934 .44132 Mdot
.42873 .71839 Mdot
.44274 .32148 Mdot
.22147 .38206 Mdot
.58113 .61776 Mdot
.30812 .53791 Mdot
.44446 .76912 Mdot
.75894 .32069 Mdot
.41622 .51202 Mdot
.47845 .30735 Mdot
.72295 .36636 Mdot
.66744 .45186 Mdot
.20644 .58953 Mdot
.64349 .43335 Mdot
.46558 .64304 Mdot
.51415 .40903 Mdot
.51475 .39592 Mdot
.44413 .40762 Mdot
.4972 .35925 Mdot
.4807 .63596 Mdot
.53307 .36005 Mdot
.20024 .37661 Mdot
.60121 .57166 Mdot
.58197 .35238 Mdot
.64316 .43707 Mdot
.44899 .62116 Mdot
.59285 .59592 Mdot
.52097 .76338 Mdot
.65986 .31147 Mdot
.49128 .40782 Mdot
.44729 .40286 Mdot
.59291 .2036 Mdot
.46131 .42736 Mdot
.56412 .40924 Mdot
.58936 .58919 Mdot
.54559 .4731 Mdot
.65294 .42229 Mdot
.67839 .4269 Mdot
.46973 .65637 Mdot
.28502 .51655 Mdot
.65348 .43458 Mdot
.63064 .59491 Mdot
.55095 .40394 Mdot
.53888 .36968 Mdot
.34561 .52159 Mdot
.60683 .2008 Mdot
.67202 .47806 Mdot
.536 .79219 Mdot
.29648 .53879 Mdot
.27293 .48542 Mdot
.45719 .36731 Mdot
.21879 .58255 Mdot
.36204 .49164 Mdot
.62688 .44006 Mdot
.45151 .62148 Mdot
.7043 .34526 Mdot
.44408 .63349 Mdot
.29657 .50416 Mdot
.52729 .4159 Mdot
.28965 .52945 Mdot
.48896 .4112 Mdot
.78936 .33915 Mdot
.51182 .3908 Mdot
.31655 .2473 Mdot
.6097 .34757 Mdot
.60926 .58567 Mdot
.5023 .77348 Mdot
.6233 .58712 Mdot
.30373 .54278 Mdot
.53744 .40776 Mdot
.63941 .45798 Mdot
.64834 .75858 Mdot
.38131 .51103 Mdot
.6186 .63476 Mdot
.57244 .61722 Mdot
.44654 .63051 Mdot
.44933 .42182 Mdot
.46042 .36423 Mdot
.60097 .60169 Mdot
.22781 .52523 Mdot
.30296 .49016 Mdot
.50537 .41296 Mdot
.46854 .3779 Mdot
.61264 .58628 Mdot
.55978 .83364 Mdot
.39543 .38025 Mdot
.51088 .40456 Mdot
.67572 .6808 Mdot
.41791 .67412 Mdot
.55205 .36601 Mdot
.51567 .44866 Mdot
.66864 .44478 Mdot
.33072 .29298 Mdot
.67103 .24964 Mdot
.41683 .65323 Mdot
.59655 .57902 Mdot
.49392 .41674 Mdot
.60769 .57599 Mdot
.53763 .36624 Mdot
.27325 .64947 Mdot
.65427 .60567 Mdot
.49598 .43483 Mdot
.48329 .31958 Mdot
.3156 .54521 Mdot
.44784 .40743 Mdot
.35266 .44363 Mdot
.59992 .63118 Mdot
.52573 .42568 Mdot
.42221 .27044 Mdot
.4359 .64769 Mdot
.49181 .3157 Mdot
.68214 .46268 Mdot
.53593 .25585 Mdot
.32687 .65735 Mdot
.7811 .49103 Mdot
.68134 .42711 Mdot
.47558 .35036 Mdot
.57456 .61769 Mdot
.44151 .69623 Mdot
.28487 .27071 Mdot
.4462 .36732 Mdot
.46054 .64106 Mdot
.45426 .67808 Mdot
.65447 .46181 Mdot
.21871 .69175 Mdot
.52699 .36982 Mdot
.49511 .36614 Mdot
.2865 .42104 Mdot
.32642 .47586 Mdot
.50854 .38117 Mdot
.52249 .37759 Mdot
.43654 .68307 Mdot
.54475 .33366 Mdot
.38023 .36777 Mdot
.42299 .23584 Mdot
.4549 .6974 Mdot
.3669 .57863 Mdot
.63989 .5856 Mdot
.66906 .4291 Mdot
.3324 .51442 Mdot
.64669 .46689 Mdot
.64317 .60427 Mdot
.5214 .37905 Mdot
.47603 .64419 Mdot
.31134 .44112 Mdot
.44347 .69157 Mdot
.7649 .4732 Mdot
.34702 .50265 Mdot
.39573 .59464 Mdot
.14805 .60614 Mdot
.59943 .75429 Mdot
.47961 .6077 Mdot
.66569 .44823 Mdot
.64849 .6679 Mdot
.46846 .37965 Mdot
.20516 .59549 Mdot
.51557 .36386 Mdot
.41641 .26868 Mdot
.59436 .5759 Mdot
.59304 .57315 Mdot
.51221 .4077 Mdot
.54181 .2381 Mdot
.44372 .69623 Mdot
.41964 .66239 Mdot
.50383 .43522 Mdot
.44756 .65716 Mdot
.49438 .37413 Mdot
.58998 .6035 Mdot
.17193 .51036 Mdot
.48226 .38684 Mdot
.45793 .4495 Mdot
.28299 .65118 Mdot
.65126 .78275 Mdot
.72785 .47352 Mdot
.44429 .83579 Mdot
.73968 .29357 Mdot
.44686 .65907 Mdot
.47016 .44117 Mdot
.36221 .57987 Mdot
.60218 .56177 Mdot
.47951 .70926 Mdot
.5153 .37711 Mdot
.51495 .36793 Mdot
.46755 .34566 Mdot
.45596 .39143 Mdot
.22943 .66717 Mdot
.3841 .51968 Mdot
.32781 .32864 Mdot
.45407 .41623 Mdot
.65339 .29236 Mdot
.47083 .649 Mdot
.29621 .46259 Mdot
.63455 .42695 Mdot
.44761 .4088 Mdot
.26982 .54835 Mdot
.48467 .65674 Mdot
.65948 .18649 Mdot
.46654 .64095 Mdot
.61451 .62239 Mdot
.46733 .68072 Mdot
.47062 .3982 Mdot
.31909 .50996 Mdot
.43733 .55674 Mdot
.5998 .72963 Mdot
.58711 .59303 Mdot
.48052 .40134 Mdot
.55399 .56828 Mdot
.58271 .61247 Mdot
.69422 .72722 Mdot
.32503 .51418 Mdot
.59923 .28865 Mdot
.28743 .52538 Mdot
.51316 .4322 Mdot
.51538 .43031 Mdot
.47937 .68189 Mdot
.4721 .67495 Mdot
.28666 .5234 Mdot
.23648 .72462 Mdot
.67679 .47431 Mdot
.3019 .5211 Mdot
.4206 .39885 Mdot
.4636 .52293 Mdot
.31602 .51326 Mdot
.67473 .48896 Mdot
.4462 .68186 Mdot
.28396 .48626 Mdot
.46044 .34351 Mdot
.70197 .31073 Mdot
.69285 .44377 Mdot
.63998 .57567 Mdot
.71355 .39328 Mdot
.60582 .63508 Mdot
.45459 .62275 Mdot
.6213 .58592 Mdot
.42972 .68829 Mdot
.3318 .68206 Mdot
.25437 .54569 Mdot
.46316 .60089 Mdot
.46712 .62711 Mdot
.62111 .5883 Mdot
.51263 .41419 Mdot
.72722 .44525 Mdot
.50652 .44163 Mdot
.51181 .34561 Mdot
.42328 .67766 Mdot
.32333 .54035 Mdot
.35714 .48715 Mdot
.62524 .26194 Mdot
.28419 .5068 Mdot
.60928 .63021 Mdot
.22427 .36358 Mdot
.56633 .67729 Mdot
.43684 .63892 Mdot
.47847 .66762 Mdot
.48434 .43088 Mdot
.60877 .60066 Mdot
.58764 .58679 Mdot
.44935 .63137 Mdot
.25375 .59111 Mdot
.49216 .45086 Mdot
.36206 .50983 Mdot
.31924 .4745 Mdot
.3026 .51068 Mdot
.34866 .52654 Mdot
.3907 .37044 Mdot
.46712 .67112 Mdot
.31715 .54196 Mdot
.48064 .43167 Mdot
.51512 .37171 Mdot
.38874 .55067 Mdot
.68568 .43823 Mdot
.43373 .40523 Mdot
.52155 .33322 Mdot
.44852 .37518 Mdot
.64813 .61232 Mdot
.45249 .47155 Mdot
.6528 .61498 Mdot
.57643 .60371 Mdot
.58022 .59325 Mdot
.5375 .69471 Mdot
.58495 .21662 Mdot
.75632 .34722 Mdot
.53237 .4082 Mdot
.43148 .78857 Mdot
.61898 .60433 Mdot
.20338 .39782 Mdot
.38269 .72569 Mdot
.4552 .35756 Mdot
.69519 .62563 Mdot
.60238 .59723 Mdot
.28181 .52867 Mdot
.5146 .38254 Mdot
.63656 .6451 Mdot
.68544 .46008 Mdot
.51842 .43422 Mdot
.6551 .60358 Mdot
.31476 .49615 Mdot
.62583 .44577 Mdot
.29671 .47621 Mdot
.58097 .59071 Mdot
.47208 .31677 Mdot
.21359 .29302 Mdot
.58194 .64001 Mdot
.51468 .81485 Mdot
.55684 .32997 Mdot
.5083 .41384 Mdot
.6423 .63691 Mdot
.28894 .47343 Mdot
.45019 .62376 Mdot
.56472 .51847 Mdot
.2948 .48273 Mdot
.59323 .57294 Mdot
.62249 .63732 Mdot
.58731 .59201 Mdot
.32031 .47895 Mdot
.42765 .39725 Mdot
.29962 .48391 Mdot
.46177 .68502 Mdot
.46651 .41708 Mdot
.79259 .4129 Mdot
.41368 .7714 Mdot
.2916 .53586 Mdot
.62619 .62607 Mdot
.69079 .42865 Mdot
.47331 .38851 Mdot
.41501 .77673 Mdot
.50983 .41731 Mdot
.42348 .68275 Mdot
.28956 .3241 Mdot
.31424 .45027 Mdot
.47924 .43913 Mdot
.48155 .4296 Mdot
.42043 .66243 Mdot
.48226 .39721 Mdot
.45241 .42462 Mdot
.53774 .69898 Mdot
.31454 .48216 Mdot
.4794 .378 Mdot
.63372 .60862 Mdot
.57733 .6975 Mdot
.48041 .4516 Mdot
.60304 .6766 Mdot
.58945 .28749 Mdot
.2795 .34054 Mdot
.51638 .36522 Mdot
.44208 .48971 Mdot
.45633 .38006 Mdot
.49042 .35201 Mdot
.48793 .42739 Mdot
.28065 .72752 Mdot
.65305 .60057 Mdot
.60053 .58187 Mdot
.68832 .435 Mdot
.59138 .2884 Mdot
.66939 .44021 Mdot
.44879 .6825 Mdot
.74148 .53571 Mdot
.65329 .61335 Mdot
.30173 .49873 Mdot
.479 .35242 Mdot
.58216 .63986 Mdot
.45026 .37085 Mdot
.4715 .40032 Mdot
.59492 .63701 Mdot
.64329 .58701 Mdot
.77974 .53177 Mdot
.68948 .4454 Mdot
.30953 .52564 Mdot
.44827 .42577 Mdot
.66095 .4744 Mdot
.52235 .36865 Mdot
.64697 .34762 Mdot
.30893 .52241 Mdot
.30961 .48254 Mdot
.3598 .49051 Mdot
.52187 .38282 Mdot
.47266 .39447 Mdot
.42973 .673 Mdot
.29417 .54158 Mdot
.43926 .64514 Mdot
.54654 .54533 Mdot
.71209 .64257 Mdot
.51533 .37678 Mdot
.38553 .69204 Mdot
.67983 .4413 Mdot
.6237 .63321 Mdot
.50537 .1909 Mdot
.6889 .43551 Mdot
.49184 .41208 Mdot
.57832 .61657 Mdot
.67458 .45828 Mdot
.53151 .2753 Mdot
.64316 .19621 Mdot
.68138 .42226 Mdot
.47988 .43155 Mdot
.5257 .31955 Mdot
.43148 .83155 Mdot
.67823 .42346 Mdot
.47635 .66391 Mdot
.52193 .3845 Mdot
.34932 .54643 Mdot
.6472 .46823 Mdot
.65965 .71933 Mdot
.59735 .59542 Mdot
.69375 .29325 Mdot
.41011 .37031 Mdot
.21782 .51365 Mdot
.67754 .42941 Mdot
.33038 .50413 Mdot
.56308 .42424 Mdot
.45628 .37062 Mdot
.68313 .42672 Mdot
.48992 .62602 Mdot
.59657 .61146 Mdot
.58439 .71215 Mdot
.31988 .47848 Mdot
.49977 .63632 Mdot
.63309 .62411 Mdot
.547 .79133 Mdot
.36471 .2503 Mdot
.5361 .33673 Mdot
.40864 .81359 Mdot
.44682 .73782 Mdot
.44449 .35821 Mdot
.68018 .41633 Mdot
.41301 .67537 Mdot
.476 .64095 Mdot
.45396 .65614 Mdot
.33919 .69973 Mdot
.41709 .50062 Mdot
.65892 .61861 Mdot
.46009 .70651 Mdot
.66981 .43002 Mdot
.69503 .33334 Mdot
.51762 .34878 Mdot
.47291 .38195 Mdot
.46139 .43391 Mdot
.44415 .40312 Mdot
.46193 .37243 Mdot
.44544 .64916 Mdot
.31983 .67806 Mdot
.40699 .52155 Mdot
.31152 .51732 Mdot
.76543 .52217 Mdot
.62757 .59677 Mdot
.66243 .60921 Mdot
.67875 .45999 Mdot
.61917 .75385 Mdot
.56694 .58289 Mdot
.62076 .61604 Mdot
.43658 .3749 Mdot
.29899 .48888 Mdot
.56225 .3982 Mdot
.48089 .43053 Mdot
.6063 .62743 Mdot
.4987 .58006 Mdot
.37385 .41501 Mdot
.61444 .41444 Mdot
.62305 .42725 Mdot
.44102 .50972 Mdot
.69264 .43599 Mdot
.54142 .39812 Mdot
.18489 .41962 Mdot
.64375 .60432 Mdot
.60857 .61374 Mdot
.68213 .4376 Mdot
.21437 .57703 Mdot
.33456 .51954 Mdot
.3824 .65515 Mdot
.4477 .68752 Mdot
.52367 .42149 Mdot
.40671 .22095 Mdot
.58293 .37766 Mdot
.7216 .52764 Mdot
.45766 .65032 Mdot
.61634 .57837 Mdot
.53743 .42626 Mdot
.47105 .42713 Mdot
.68081 .44511 Mdot
.79693 .54687 Mdot
.54964 .36608 Mdot
.7563 .69822 Mdot
.55364 .19243 Mdot
.64703 .24646 Mdot
.45856 .36609 Mdot
.31463 .48094 Mdot
.63161 .57012 Mdot
.65521 .42765 Mdot
.4203 .38962 Mdot
.68573 .2455 Mdot
.34456 .51907 Mdot
.46469 .65698 Mdot
.47888 .55962 Mdot
.70344 .35219 Mdot
.50168 .34569 Mdot
.51771 .37169 Mdot
.49576 .34994 Mdot
.56579 .14466 Mdot
.65105 .61121 Mdot
.28611 .53187 Mdot
.65746 .46308 Mdot
.28818 .5028 Mdot
.60994 .58195 Mdot
.47977 .59923 Mdot
.51825 .41292 Mdot
.34594 .51406 Mdot
.33126 .50559 Mdot
.46194 .63572 Mdot
.43316 .62744 Mdot
.51004 .55833 Mdot
.51061 .38999 Mdot
.57543 .63004 Mdot
.31637 .54355 Mdot
.454 .49963 Mdot
.65895 .44483 Mdot
.44301 .68331 Mdot
.45078 .41135 Mdot
.64944 .60158 Mdot
.4899 .3292 Mdot
.32139 .52637 Mdot
.62042 .61535 Mdot
.74211 .63204 Mdot
.66462 .42105 Mdot
.50818 .36819 Mdot
.70862 .46481 Mdot
.59338 .58207 Mdot
.46617 .38017 Mdot
.56602 .79714 Mdot
.67488 .4887 Mdot
.63443 .72048 Mdot
.5797 .60069 Mdot
.53655 .66405 Mdot
.27802 .50309 Mdot
.34846 .7246 Mdot
.6101 .61847 Mdot
.50994 .79133 Mdot
.76871 .60631 Mdot
.54813 .4136 Mdot
.29301 .5134 Mdot
.45569 .73655 Mdot
.81808 .4158 Mdot
.5078 .82702 Mdot
.49284 .39873 Mdot
.61673 .64495 Mdot
.67865 .45152 Mdot
.43209 .64272 Mdot
.66473 .6772 Mdot
.62591 .46201 Mdot
.57782 .58548 Mdot
.4883 .42696 Mdot
.32303 .49999 Mdot
.43965 .6768 Mdot
.33005 .66343 Mdot
.63249 .59944 Mdot
.63226 .61891 Mdot
.5289 .43222 Mdot
.67111 .43622 Mdot
.38354 .75721 Mdot
.5882 .60041 Mdot
.57196 .19943 Mdot
.65217 .6511 Mdot
.66894 .47501 Mdot
.45209 .38788 Mdot
.62554 .2566 Mdot
.4585 .44283 Mdot
.59522 .80111 Mdot
.62455 .59374 Mdot
.31611 .52462 Mdot
.48209 .3447 Mdot
.45528 .24073 Mdot
.61162 .63036 Mdot
.46402 .50828 Mdot
.68186 .51563 Mdot
.4584 .67907 Mdot
.50092 .19089 Mdot
.50384 .37447 Mdot
.44224 .69599 Mdot
.67905 .44495 Mdot
.51016 .39896 Mdot
.46985 .39441 Mdot
.32192 .5481 Mdot
.45796 .63409 Mdot
.78297 .5481 Mdot
.47839 .67125 Mdot
.47469 .6496 Mdot
.34875 .53553 Mdot
.48326 .36943 Mdot
.61628 .62324 Mdot
.60291 .5989 Mdot
.46233 .33955 Mdot
.15643 .50213 Mdot
.33774 .51747 Mdot
.62507 .56478 Mdot
.54816 .13829 Mdot
.46093 .33358 Mdot
.48545 .19614 Mdot
.79505 .55642 Mdot
.42437 .69128 Mdot
.4787 .43199 Mdot
.31311 .49742 Mdot
.66709 .5566 Mdot
.62934 .62138 Mdot
.46985 .34232 Mdot
.44117 .67542 Mdot
.69034 .45233 Mdot
.58947 .62264 Mdot
.73002 .52494 Mdot
.49849 .35636 Mdot
.69605 .61415 Mdot
.61821 .64242 Mdot
.84863 .50715 Mdot
.51044 .76091 Mdot
.29349 .5168 Mdot
.46922 .40192 Mdot
.28366 .53391 Mdot
.66189 .46517 Mdot
.4831 .55939 Mdot
.4461 .67936 Mdot
.39499 .45149 Mdot
.19372 .37134 Mdot
.58756 .59087 Mdot
.28668 .53421 Mdot
.48654 .44014 Mdot
.26578 .64254 Mdot
.49839 .37215 Mdot
.5098 .30947 Mdot
.71763 .41638 Mdot
.42351 .66304 Mdot
.43524 .69177 Mdot
.46088 .38946 Mdot
.65667 .46854 Mdot
.62984 .59602 Mdot
.60128 .6201 Mdot
.836 .61913 Mdot
.39641 .58679 Mdot
.50685 .23068 Mdot
.51348 .36679 Mdot
.5748 .59159 Mdot
.61481 .69395 Mdot
.45601 .63901 Mdot
.44333 .34892 Mdot
.58732 .63121 Mdot
.67646 .49294 Mdot
.54298 .26948 Mdot
.45659 .37455 Mdot
.43904 .43578 Mdot
.4552 .68505 Mdot
.41598 .48561 Mdot
.61453 .57385 Mdot
.50743 .3318 Mdot
.44 .59771 Mdot
.54197 .27722 Mdot
.59049 .1801 Mdot
.3092 .52575 Mdot
.72577 .50928 Mdot
.44465 .64912 Mdot
.45186 .44839 Mdot
.64231 .45343 Mdot
.60178 .56017 Mdot
.65137 .60204 Mdot
.48906 .41997 Mdot
.54524 .4011 Mdot
.5301 .20638 Mdot
.29713 .49578 Mdot
.47104 .65208 Mdot
.51903 .39677 Mdot
.3734 .63501 Mdot
.44572 .41081 Mdot
.42857 .66618 Mdot
.19494 .31199 Mdot
.497 .44209 Mdot
.49543 .36861 Mdot
.39675 .75993 Mdot
.30355 .47732 Mdot
.29369 .54476 Mdot
.4282 .20112 Mdot
.51318 .36688 Mdot
.53388 .19502 Mdot
.31206 .52963 Mdot
.33174 .52373 Mdot
.54646 .70961 Mdot
.47469 .38622 Mdot
.40496 .42076 Mdot
.42575 .68864 Mdot
.47672 .65158 Mdot
.30608 .48026 Mdot
.55167 .36693 Mdot
.42465 .63927 Mdot
.29894 .72683 Mdot
.61011 .59961 Mdot
.17526 .44063 Mdot
.33981 .51824 Mdot
.40063 .64433 Mdot
.45788 .6434 Mdot
.67513 .2061 Mdot
.64457 .54694 Mdot
.51555 .41228 Mdot
.5082 .36324 Mdot
.6776 .43443 Mdot
.4617 .43611 Mdot
.59279 .57353 Mdot
.44793 .65635 Mdot
.46237 .26434 Mdot
.30473 .52294 Mdot
.50409 .38435 Mdot
.64852 .74798 Mdot
.71718 .69935 Mdot
.73437 .49482 Mdot
.33871 .50785 Mdot
.29173 .52537 Mdot
.63174 .58607 Mdot
.61479 .64445 Mdot
.47226 .36536 Mdot
.42304 .65008 Mdot
.29362 .54073 Mdot
.42552 .66907 Mdot
.64382 .60626 Mdot
.61815 .62103 Mdot
.64707 .58849 Mdot
.52345 .35334 Mdot
.62716 .61473 Mdot
.72327 .64403 Mdot
.49667 .65809 Mdot
.35241 .53535 Mdot
.50434 .16807 Mdot
.33592 .66793 Mdot
.36469 .48286 Mdot
.65197 .47306 Mdot
.58961 .58619 Mdot
.45928 .68808 Mdot
.45832 .40757 Mdot
.44361 .38932 Mdot
.5451 .65887 Mdot
.45946 .69165 Mdot
.66137 .46367 Mdot
.4418 .6941 Mdot
.65474 .46222 Mdot
.68172 .55461 Mdot
.44353 .41425 Mdot
.54105 .37017 Mdot
.44955 .64892 Mdot
.62424 .61482 Mdot
.59781 .58809 Mdot
.67365 .41976 Mdot
.5176 .59322 Mdot
.58244 .61437 Mdot
.33165 .52774 Mdot
.38528 .40029 Mdot
.62793 .63763 Mdot
.51274 .38218 Mdot
.67527 .36287 Mdot
.20253 .59826 Mdot
.45587 .44555 Mdot
.54222 .70543 Mdot
.26833 .45056 Mdot
.46713 .35086 Mdot
.19646 .58898 Mdot
.52549 .66123 Mdot
.28148 .49929 Mdot
.60044 .5732 Mdot
.55548 .61816 Mdot
.45763 .46561 Mdot
.62486 .43179 Mdot
.43151 .36447 Mdot
.34321 .50849 Mdot
.28178 .5447 Mdot
.65969 .26974 Mdot
.54219 .81613 Mdot
.6758 .45482 Mdot
.68099 .45476 Mdot
.609 .62002 Mdot
.67951 .79407 Mdot
.47905 .30973 Mdot
.66146 .4622 Mdot
.25219 .5538 Mdot
.48812 .4249 Mdot
.58525 .30474 Mdot
.58482 .47383 Mdot
.31155 .47936 Mdot
.65084 .28556 Mdot
.61564 .62796 Mdot
.28346 .50618 Mdot
.36671 .62496 Mdot
.43204 .40741 Mdot
.30768 .52173 Mdot
.4269 .67191 Mdot
.54318 .75555 Mdot
.3295 .53363 Mdot
.66246 .35436 Mdot
.43633 .63306 Mdot
.45191 .50089 Mdot
.61078 .26475 Mdot
.38627 .87255 Mdot
.44534 .65317 Mdot
.6235 .63657 Mdot
.60204 .5997 Mdot
.60235 .62069 Mdot
.28984 .49982 Mdot
.58885 .58543 Mdot
.29651 .49783 Mdot
.44008 .81691 Mdot
.225 .61379 Mdot
.6614 .46073 Mdot
.58481 .7143 Mdot
.3104 .50221 Mdot
.20023 .39395 Mdot
.13261 .50794 Mdot
.48026 .43286 Mdot
.48456 .65059 Mdot
.6646 .45924 Mdot
.74437 .70903 Mdot
.67029 .44753 Mdot
.61966 .23157 Mdot
.24396 .36671 Mdot
.49725 .38066 Mdot
.3579 .37689 Mdot
.63903 .43135 Mdot
.33562 .49575 Mdot
.46681 .38159 Mdot
.60026 .50957 Mdot
.67372 .44479 Mdot
.67945 .46886 Mdot
.47487 .37058 Mdot
.30802 .53805 Mdot
.62293 .62927 Mdot
.48017 .65917 Mdot
.63646 .45771 Mdot
.56455 .35944 Mdot
.44298 .43464 Mdot
.51184 .41918 Mdot
.39634 .54766 Mdot
.6967 .42377 Mdot
.44621 .65988 Mdot
.24739 .7122 Mdot
.58015 .62785 Mdot
.61126 .51601 Mdot
.57704 .19154 Mdot
.52391 .69418 Mdot
.6227 .59398 Mdot
.60811 .57706 Mdot
.4623 .37028 Mdot
.58479 .44985 Mdot
.22672 .38478 Mdot
.52713 .60891 Mdot
.64817 .58638 Mdot
.5981 .61617 Mdot
.28037 .53516 Mdot
.64363 .24975 Mdot
.419 .39897 Mdot
.41628 .65433 Mdot
.65009 .59782 Mdot
.26273 .66129 Mdot
.66999 .4332 Mdot
.24795 .35279 Mdot
.44097 .41151 Mdot
.51755 .40833 Mdot
.44916 .67255 Mdot
.43158 .674 Mdot
.64987 .536 Mdot
.63505 .24229 Mdot
.27392 .45185 Mdot
.30878 .65738 Mdot
.27875 .35242 Mdot
.28317 .54218 Mdot
.29196 .53613 Mdot
.60863 .73714 Mdot
.48198 .66444 Mdot
.47243 .3479 Mdot
.28507 .51909 Mdot
.61498 .52213 Mdot
.38585 .43566 Mdot
.54699 .25131 Mdot
.49841 .20404 Mdot
.4868 .40892 Mdot
.31361 .48601 Mdot
.30775 .47605 Mdot
.34416 .48653 Mdot
.52716 .64839 Mdot
.48056 .36221 Mdot
.4894 .40418 Mdot
.46542 .35574 Mdot
.24282 .60882 Mdot
.48407 .35582 Mdot
.33977 .71676 Mdot
.48929 .55064 Mdot
.34874 .27888 Mdot
.51151 .33197 Mdot
.42338 .69499 Mdot
.51001 .35243 Mdot
.65711 .46807 Mdot
.49569 .43103 Mdot
.54357 .25132 Mdot
.46388 .64737 Mdot
.39252 .3898 Mdot
.33543 .68046 Mdot
.45463 .35177 Mdot
.628 .44564 Mdot
.42358 .73657 Mdot
.79176 .39518 Mdot
.72294 .4411 Mdot
.33341 .52622 Mdot
.61521 .59765 Mdot
.4586 .68917 Mdot
.61467 .61726 Mdot
.53219 .35471 Mdot
.59988 .745 Mdot
.75391 .6748 Mdot
.54779 .55226 Mdot
.44472 .4025 Mdot
.41834 .36576 Mdot
.32706 .52789 Mdot
.58034 .62617 Mdot
.36735 .49365 Mdot
.4902 .34551 Mdot
.65053 .45351 Mdot
.6775 .44278 Mdot
.56584 .52058 Mdot
.81987 .54169 Mdot
.2765 .6955 Mdot
.44709 .67074 Mdot
.58928 .60658 Mdot
.63983 .43776 Mdot
.47849 .79294 Mdot
.42703 .63103 Mdot
.41933 .67215 Mdot
.46681 .64968 Mdot
.52819 .39195 Mdot
.65426 .6035 Mdot
.35441 .27572 Mdot
.58351 .58034 Mdot
.48004 .39815 Mdot
.64846 .61496 Mdot
.58284 .62468 Mdot
.64678 .43331 Mdot
.46928 .64942 Mdot
.64068 .60002 Mdot
.51791 .42991 Mdot
.30821 .53302 Mdot
.44831 .60825 Mdot
.59821 .34601 Mdot
.55496 .81245 Mdot
.53267 .29354 Mdot
.33038 .47978 Mdot
.81493 .42343 Mdot
.41921 .67953 Mdot
.25172 .59601 Mdot
.77857 .52577 Mdot
.53678 .40448 Mdot
.15069 .47995 Mdot
.6626 .60683 Mdot
.58968 .631 Mdot
.45315 .3871 Mdot
.63953 .66109 Mdot
.50134 .38004 Mdot
.64064 .61627 Mdot
.62509 .68363 Mdot
.28387 .55586 Mdot
.62573 .60994 Mdot
.50748 .33337 Mdot
.4663 .39118 Mdot
.30978 .48116 Mdot
.63451 .64004 Mdot
.41927 .38561 Mdot
.84679 .60004 Mdot
.4315 .66716 Mdot
.48365 .71924 Mdot
.67717 .37293 Mdot
.44357 .64845 Mdot
.30091 .51879 Mdot
.51456 .34769 Mdot
.67962 .44622 Mdot
.31069 .50102 Mdot
.51697 .25423 Mdot
.66247 .42249 Mdot
.16867 .43017 Mdot
.31419 .47633 Mdot
.61323 .63567 Mdot
.64667 .46159 Mdot
.46062 .43813 Mdot
.60498 .55941 Mdot
.51396 .77135 Mdot
.62343 .59605 Mdot
.4629 .36293 Mdot
.62735 .70879 Mdot
.47242 .65262 Mdot
.49602 .39921 Mdot
.59137 .63042 Mdot
.54544 .70109 Mdot
.53115 .3959 Mdot
.45902 .38403 Mdot
.59485 .18955 Mdot
.26607 .30753 Mdot
.66381 .44629 Mdot
.3127 .47036 Mdot
.4813 .43194 Mdot
.67815 .46784 Mdot
.72335 .59389 Mdot
.52484 .39812 Mdot
.34483 .52067 Mdot
.4537 .33418 Mdot
.62876 .64197 Mdot
.43647 .65051 Mdot
.54051 .58409 Mdot
.68511 .46039 Mdot
.46255 .86613 Mdot
.63612 .58435 Mdot
.54084 .37651 Mdot
.45005 .41609 Mdot
.74654 .41957 Mdot
.28259 .49897 Mdot
.2186 .45803 Mdot
.50822 .36784 Mdot
.24092 .60017 Mdot
.50731 .39707 Mdot
.65848 .59482 Mdot
.33436 .52059 Mdot
.49262 .36379 Mdot
.40488 .60406 Mdot
.46708 .45153 Mdot
.68864 .4383 Mdot
.40476 .76904 Mdot
.42913 .40549 Mdot
.17075 .37055 Mdot
.61734 .49439 Mdot
.62774 .60962 Mdot
.69017 .70772 Mdot
.84413 .63715 Mdot
.34245 .69942 Mdot
.28914 .50423 Mdot
.78748 .60197 Mdot
.61691 .62318 Mdot
.68288 .69728 Mdot
.81349 .41378 Mdot
.46323 .39728 Mdot
.50046 .34503 Mdot
.7322 .37798 Mdot
.57789 .59656 Mdot
.56919 .61733 Mdot
.55029 .39018 Mdot
.44629 .44553 Mdot
.62434 .61989 Mdot
.53223 .4189 Mdot
.54473 .36216 Mdot
.48342 .64789 Mdot
.3431 .51795 Mdot
.42344 .65952 Mdot
.42391 .64198 Mdot
.34478 .76107 Mdot
.6244 .4951 Mdot
.42986 .66266 Mdot
.41604 .68267 Mdot
.58264 .30107 Mdot
.56759 .23533 Mdot
.64527 .46605 Mdot
.83455 .55289 Mdot
.59866 .61376 Mdot
.48494 .36555 Mdot
.31687 .47486 Mdot
.28922 .44975 Mdot
.74307 .59943 Mdot
.19201 .43218 Mdot
.48036 .34611 Mdot
.61449 .63058 Mdot
.52607 .65167 Mdot
.56313 .40091 Mdot
.62507 .65051 Mdot
.51943 .39147 Mdot
.59574 .5703 Mdot
.41654 .30288 Mdot
.51024 .79063 Mdot
.59897 .65358 Mdot
.36155 .51368 Mdot
.51694 .40189 Mdot
.3427 .50612 Mdot
.45324 .64036 Mdot
.64814 .46612 Mdot
.66275 .44317 Mdot
.46913 .37625 Mdot
.45872 .3175 Mdot
.69286 .57922 Mdot
.47205 .38896 Mdot
.48369 .42505 Mdot
.52617 .66001 Mdot
.48467 .42785 Mdot
.43979 .39268 Mdot
.45285 .36493 Mdot
.48528 .33984 Mdot
.47569 .65068 Mdot
.62425 .75185 Mdot
.48053 .4658 Mdot
.47076 .46194 Mdot
.44878 .62499 Mdot
.79053 .54508 Mdot
.4176 .65573 Mdot
.79585 .39124 Mdot
.4304 .69241 Mdot
.65574 .4482 Mdot
.75554 .45092 Mdot
.41551 .35266 Mdot
.3307 .54133 Mdot
.41208 .64815 Mdot
.66199 .46658 Mdot
.4513 .65634 Mdot
.63772 .62347 Mdot
.60393 .1845 Mdot
.26305 .52243 Mdot
.38715 .53109 Mdot
.44853 .72745 Mdot
.57657 .76537 Mdot
.63637 .58811 Mdot
.3411 .49759 Mdot
.37107 .40371 Mdot
.44267 .40177 Mdot
.67609 .46946 Mdot
.47102 .36766 Mdot
.46856 .64038 Mdot
.61144 .62659 Mdot
.48252 .82113 Mdot
.68075 .44468 Mdot
.5321 .17221 Mdot
.59957 .59057 Mdot
.44189 .37643 Mdot
.42226 .64268 Mdot
.43766 .17717 Mdot
.42227 .66675 Mdot
.22747 .42004 Mdot
.27838 .5198 Mdot
.46155 .84157 Mdot
.30066 .50483 Mdot
.52346 .77591 Mdot
.40717 .15396 Mdot
.63687 .75444 Mdot
.30687 .53625 Mdot
.49908 .60645 Mdot
.49164 .41472 Mdot
.51299 .41855 Mdot
.4956 .80207 Mdot
.32064 .47221 Mdot
.46108 .42384 Mdot
.58271 .67965 Mdot
.50383 .63912 Mdot
.45352 .20741 Mdot
.62113 .58288 Mdot
.50462 .37834 Mdot
.43979 .70415 Mdot
.45205 .69577 Mdot
.61428 .57019 Mdot
.4187 .67319 Mdot
.48838 .40207 Mdot
.30881 .50256 Mdot
.64617 .67516 Mdot
.654 .43851 Mdot
.70596 .75669 Mdot
.6889 .46526 Mdot
.6223 .59344 Mdot
.50525 .44204 Mdot
.61844 .62036 Mdot
.89213 .57913 Mdot
.49577 .40807 Mdot
.31341 .52894 Mdot
.47547 .42695 Mdot
.51416 .40448 Mdot
.48267 .34203 Mdot
.62815 .62548 Mdot
.63612 .40147 Mdot
.5246 .42546 Mdot
.44743 .67995 Mdot
.30825 .32306 Mdot
.43013 .39253 Mdot
.56366 .63685 Mdot
.57126 .25105 Mdot
.47412 .706 Mdot
.28026 .49082 Mdot
.62603 .60453 Mdot
.3029 .52584 Mdot
.2189 .56636 Mdot
.30119 .51857 Mdot
.28048 .38403 Mdot
.37613 .38265 Mdot
.45806 .25026 Mdot
.43146 .26905 Mdot
.44882 .57185 Mdot
.31634 .47094 Mdot
.68808 .41497 Mdot
.30078 .54171 Mdot
.29995 .48081 Mdot
.14817 .32675 Mdot
.33962 .53888 Mdot
.51216 .37637 Mdot
.43267 .38892 Mdot
.56625 .78005 Mdot
.63093 .3273 Mdot
.46571 .41805 Mdot
.45996 .41765 Mdot
.63905 .44516 Mdot
.23002 .5776 Mdot
.63429 .72519 Mdot
.24884 .32526 Mdot
.7259 .6828 Mdot
.47246 .36942 Mdot
.48559 .43342 Mdot
.53933 .43988 Mdot
.31897 .22872 Mdot
.35236 .77381 Mdot
.32309 .56333 Mdot
.53307 .44185 Mdot
.62678 .77171 Mdot
.4902 .34272 Mdot
.5221 .3766 Mdot
.48873 .41101 Mdot
.61668 .62368 Mdot
.28889 .48115 Mdot
.48967 .33727 Mdot
.73693 .41888 Mdot
.51994 .37873 Mdot
.52794 .69612 Mdot
.57473 .84202 Mdot
.50372 .37371 Mdot
.26713 .50595 Mdot
.5091 .42108 Mdot
.28997 .49063 Mdot
.32911 .48716 Mdot
.54357 .42522 Mdot
.27532 .35629 Mdot
.2714 .51871 Mdot
.47928 .39808 Mdot
.6309 .63145 Mdot
.84478 .50827 Mdot
.46496 .36173 Mdot
.64889 .46816 Mdot
.5094 .36471 Mdot
.63063 .45566 Mdot
.47831 .42221 Mdot
.63313 .58074 Mdot
.2509 .47296 Mdot
.60759 .6149 Mdot
.39383 .80739 Mdot
.64529 .58828 Mdot
.57143 .16816 Mdot
.33778 .4841 Mdot
.60218 .71223 Mdot
.19937 .50922 Mdot
.48632 .72513 Mdot
.51254 .50049 Mdot
.44104 .54002 Mdot
.4222 .65232 Mdot
.28002 .51431 Mdot
.27798 .58343 Mdot
.76721 .55406 Mdot
.75579 .49211 Mdot
.58482 .61487 Mdot
.21928 .69622 Mdot
.17672 .47966 Mdot
.54069 .40468 Mdot
.34046 .39771 Mdot
.33091 .34871 Mdot
.49092 .342 Mdot
.49941 .33879 Mdot
.55568 .57927 Mdot
.52486 .42816 Mdot
.37384 .64139 Mdot
.61983 .58972 Mdot
.66459 .46796 Mdot
.32116 .53041 Mdot
.69046 .45288 Mdot
.77425 .53347 Mdot
.43467 .538 Mdot
.64292 .61379 Mdot
.43098 .42142 Mdot
.45765 .41119 Mdot
.29845 .48601 Mdot
.37392 .5229 Mdot
.31112 .54459 Mdot
.66977 .45636 Mdot
.61383 .5883 Mdot
.21078 .62372 Mdot
.45395 .40915 Mdot
.33044 .50689 Mdot
.53228 .495 Mdot
.47871 .43115 Mdot
.45104 .64423 Mdot
.49689 .41491 Mdot
.31218 .53702 Mdot
.48439 .42776 Mdot
.29871 .50475 Mdot
.61333 .59933 Mdot
.4492 .36169 Mdot
.45288 .38145 Mdot
.48465 .17375 Mdot
.65598 .45798 Mdot
.34741 .50599 Mdot
.59562 .5267 Mdot
.46356 .43185 Mdot
.55852 .72019 Mdot
.51807 .387 Mdot
.2849 .46139 Mdot
.53889 .38991 Mdot
.49237 .7138 Mdot
.44494 .45345 Mdot
.47112 .35996 Mdot
.57975 .49299 Mdot
.32055 .36209 Mdot
.40959 .35237 Mdot
.41361 .68461 Mdot
.35146 .51997 Mdot
.45938 .21034 Mdot
.67176 .63097 Mdot
.59936 .64337 Mdot
.67401 .31528 Mdot
.46891 .34211 Mdot
.49569 .37835 Mdot
.43095 .71443 Mdot
.6859 .44851 Mdot
.33861 .50508 Mdot
.65468 .46206 Mdot
.52271 .18605 Mdot
.68025 .42959 Mdot
.66165 .6012 Mdot
.69672 .6172 Mdot
.22657 .65847 Mdot
.63951 .44204 Mdot
.30943 .53881 Mdot
.692 .65417 Mdot
.44802 .3517 Mdot
.61091 .49029 Mdot
.64762 .44707 Mdot
.30771 .7856 Mdot
.43996 .39078 Mdot
.50923 .49916 Mdot
.42991 .65582 Mdot
.64103 .45122 Mdot
.44001 .63369 Mdot
.4584 .40329 Mdot
.63833 .72075 Mdot
.2891 .50607 Mdot
.45492 .62805 Mdot
.49375 .31708 Mdot
.66541 .46068 Mdot
.65243 .60209 Mdot
.42106 .7088 Mdot
.4132 .66544 Mdot
.80267 .53713 Mdot
.46415 .82681 Mdot
.61082 .58838 Mdot
.36698 .24587 Mdot
.43541 .69599 Mdot
.44534 .35573 Mdot
.23675 .57395 Mdot
.51663 .41168 Mdot
.32806 .72493 Mdot
.6282 .5989 Mdot
.59171 .76277 Mdot
.48392 .43157 Mdot
.47849 .35073 Mdot
.2661 .526 Mdot
.60244 .60795 Mdot
.31619 .51045 Mdot
.35294 .51256 Mdot
.61175 .59872 Mdot
.29486 .51289 Mdot
.64431 .42683 Mdot
.3534 .60027 Mdot
.44682 .68847 Mdot
.45955 .67481 Mdot
.60056 .61981 Mdot
.631 .60816 Mdot
.61958 .61637 Mdot
.49752 .41518 Mdot
.33866 .5123 Mdot
.46978 .40741 Mdot
.51817 .36631 Mdot
.31181 .31062 Mdot
.29694 .47782 Mdot
.47987 .40921 Mdot
.61192 .51057 Mdot
.59124 .45942 Mdot
.63549 .62987 Mdot
.43043 .65915 Mdot
.59385 .6915 Mdot
.49627 .77061 Mdot
.50704 .38143 Mdot
.64598 .49486 Mdot
.30695 .54034 Mdot
.677 .44748 Mdot
.69879 .45215 Mdot
.66788 .4475 Mdot
.50566 .68398 Mdot
.33984 .48381 Mdot
.24274 .33531 Mdot
.50122 .3775 Mdot
.40313 .53952 Mdot
.26181 .55646 Mdot
.67356 .5475 Mdot
.43136 .66115 Mdot
.4717 .42709 Mdot
.54254 .57642 Mdot
.36974 .44001 Mdot
.51311 .41203 Mdot
.43345 .37837 Mdot
.72941 .64572 Mdot
.44104 .34586 Mdot
.29293 .54762 Mdot
.44052 .18047 Mdot
.47313 .43893 Mdot
.25703 .6583 Mdot
.71911 .75582 Mdot
.51254 .38835 Mdot
.48986 .34863 Mdot
.44664 .39348 Mdot
.49898 .43002 Mdot
.26871 .50931 Mdot
.62027 .29026 Mdot
.42981 .6954 Mdot
.40329 .53405 Mdot
.47949 .64851 Mdot
.61981 .5648 Mdot
.60055 .76057 Mdot
.27984 .52063 Mdot
.67801 .43495 Mdot
.70104 .72811 Mdot
.35388 .22691 Mdot
.61323 .57367 Mdot
.29769 .72335 Mdot
.65066 .45018 Mdot
.44148 .3616 Mdot
.63202 .4377 Mdot
.65061 .61984 Mdot
.45877 .67806 Mdot
.42593 .38919 Mdot
.29703 .53816 Mdot
.33325 .53075 Mdot
.47004 .42856 Mdot
.64181 .76517 Mdot
.44595 .64264 Mdot
.41157 .66786 Mdot
.52795 .39752 Mdot
.45885 .4369 Mdot
.31173 .51127 Mdot
.59086 .60095 Mdot
.47953 .23616 Mdot
.68065 .45958 Mdot
.51955 .34971 Mdot
.48972 .42759 Mdot
.58418 .19224 Mdot
.44501 .68241 Mdot
.626 .64758 Mdot
.53699 .39924 Mdot
.29843 .65244 Mdot
.53639 .40246 Mdot
.54914 .42766 Mdot
.63021 .6326 Mdot
.50932 .46644 Mdot
.54506 .37928 Mdot
.25811 .51073 Mdot
.4286 .64359 Mdot
.31146 .52372 Mdot
.26313 .48331 Mdot
.35372 .57606 Mdot
.45288 .64591 Mdot
.48595 .41448 Mdot
.43537 .66135 Mdot
.52443 .39927 Mdot
.5003 .43589 Mdot
.42854 .66553 Mdot
.31504 .51001 Mdot
.78213 .60876 Mdot
.63581 .74965 Mdot
.50542 .42957 Mdot
.54938 .40878 Mdot
.6212 .30571 Mdot
.63539 .40527 Mdot
.4932 .34491 Mdot
.31731 .53688 Mdot
.45256 .39902 Mdot
.45343 .63467 Mdot
.63914 .43213 Mdot
.3087 .53425 Mdot
.59921 .58395 Mdot
.62277 .57701 Mdot
.3382 .68599 Mdot
.57959 .61158 Mdot
.50651 .34671 Mdot
.328 .46426 Mdot
.26824 .48736 Mdot
.66802 .77368 Mdot
.60832 .59856 Mdot
.64489 .46698 Mdot
.46068 .38255 Mdot
.70256 .31116 Mdot
.44718 .70264 Mdot
.13031 .43806 Mdot
.19901 .39227 Mdot
.64931 .41838 Mdot
.19981 .425 Mdot
.63606 .57972 Mdot
.53832 .36319 Mdot
.65411 .47049 Mdot
.63093 .58561 Mdot
.52222 .41881 Mdot
.54299 .42799 Mdot
.22121 .44846 Mdot
.41416 .56495 Mdot
.43457 .66504 Mdot
.5855 .58874 Mdot
.64597 .41745 Mdot
.66206 .61237 Mdot
.33908 .48858 Mdot
.48088 .35948 Mdot
.515 .44041 Mdot
.59172 .59294 Mdot
.58472 .63766 Mdot
.48069 .40363 Mdot
.28258 .53223 Mdot
.5573 .57383 Mdot
.47572 .37396 Mdot
.39884 .58275 Mdot
.33798 .47481 Mdot
.61811 .58436 Mdot
.47756 .3536 Mdot
.63719 .41161 Mdot
.59624 .59303 Mdot
.638 .62828 Mdot
.48249 .43384 Mdot
.64889 .42439 Mdot
.53996 .42381 Mdot
.43197 .69038 Mdot
.25979 .73018 Mdot
.45552 .63427 Mdot
.62723 .67963 Mdot
.47681 .31385 Mdot
.28355 .62 Mdot
.2805 .49417 Mdot
.64874 .26997 Mdot
.5864 .6824 Mdot
.54884 .36838 Mdot
.83215 .49802 Mdot
.39929 .64366 Mdot
.671 .75733 Mdot
.75712 .36975 Mdot
.64593 .4384 Mdot
.45357 .65553 Mdot
.49067 .3484 Mdot
.48435 .64916 Mdot
.65883 .47314 Mdot
.39539 .80567 Mdot
.46737 .35726 Mdot
.33163 .523 Mdot
.48564 .405 Mdot
.33797 .52115 Mdot
.48748 .43481 Mdot
.50278 .45518 Mdot
.54114 .67301 Mdot
.54654 .27255 Mdot
.53542 .39129 Mdot
.54529 .14431 Mdot
.55853 .46916 Mdot
.67241 .46731 Mdot
.46664 .39985 Mdot
.63208 .65234 Mdot
.46466 .68941 Mdot
.40671 .74539 Mdot
.61807 .62426 Mdot
.41406 .67048 Mdot
.30141 .51272 Mdot
.62309 .59998 Mdot
.61109 .57143 Mdot
.51016 .46687 Mdot
.64397 .42332 Mdot
.46626 .66007 Mdot
.49301 .36228 Mdot
.46813 .35756 Mdot
.36747 .24125 Mdot
.75055 .57275 Mdot
.37728 .51405 Mdot
.25075 .28692 Mdot
.35788 .51564 Mdot
.66708 .46491 Mdot
.62345 .62822 Mdot
.51223 .35815 Mdot
.49283 .39673 Mdot
.57142 .71059 Mdot
.29623 .54395 Mdot
.4929 .56205 Mdot
.22072 .52163 Mdot
.60444 .52687 Mdot
.57895 .27507 Mdot
.31959 .53296 Mdot
.57898 .27705 Mdot
.69466 .42665 Mdot
.81777 .60972 Mdot
.56586 .28451 Mdot
.43207 .65413 Mdot
.5837 .28323 Mdot
.33249 .50143 Mdot
.52509 .42262 Mdot
.61852 .6372 Mdot
.58192 .62371 Mdot
.31505 .51786 Mdot
.65402 .63365 Mdot
.65365 .43009 Mdot
.4948 .35322 Mdot
.26159 .30668 Mdot
.34679 .65954 Mdot
.59669 .61981 Mdot
.56119 .41695 Mdot
.4666 .64867 Mdot
.47013 .42911 Mdot
.6431 .43461 Mdot
.4418 .65602 Mdot
.62823 .23638 Mdot
.49715 .63754 Mdot
.4639 .38165 Mdot
.59119 .18875 Mdot
.45017 .65053 Mdot
.54777 .46694 Mdot
.47984 .36882 Mdot
.42536 .68767 Mdot
.48581 .4768 Mdot
.541 .7594 Mdot
.54271 .55578 Mdot
.81453 .41427 Mdot
.52879 .55027 Mdot
.60583 .63183 Mdot
.55855 .76428 Mdot
.45292 .74009 Mdot
.4641 .68386 Mdot
.60916 .64771 Mdot
.60539 .44728 Mdot
.43709 .63486 Mdot
.43995 .36866 Mdot
.51659 .39019 Mdot
.36866 .7834 Mdot
.40236 .68944 Mdot
.5184 .77993 Mdot
.37206 .71267 Mdot
.45951 .4297 Mdot
.53623 .42817 Mdot
.49244 .3919 Mdot
.27693 .5373 Mdot
.43698 .67451 Mdot
.49874 .15474 Mdot
.45095 .64175 Mdot
.27012 .33017 Mdot
.60074 .6175 Mdot
.62453 .58396 Mdot
.50629 .37715 Mdot
.48557 .49667 Mdot
.59952 .24451 Mdot
.48573 .39994 Mdot
.62525 .46729 Mdot
.41721 .78201 Mdot
.46074 .43636 Mdot
.27522 .51269 Mdot
.55284 .4314 Mdot
.57243 .38102 Mdot
.44735 .68855 Mdot
.66511 .43276 Mdot
.63836 .25737 Mdot
.46656 .67068 Mdot
.49522 .37961 Mdot
.29423 .62464 Mdot
.50856 .40596 Mdot
.51023 .42695 Mdot
.21662 .38426 Mdot
.69691 .44219 Mdot
.61541 .60997 Mdot
.66588 .44938 Mdot
.28631 .49186 Mdot
.11241 .41568 Mdot
.68453 .43221 Mdot
.60252 .24014 Mdot
.35406 .78584 Mdot
.58602 .29002 Mdot
.34349 .51088 Mdot
.63327 .42952 Mdot
.43927 .64581 Mdot
.84576 .51443 Mdot
.22622 .47053 Mdot
.39355 .63547 Mdot
.48005 .37666 Mdot
.33038 .5516 Mdot
.32853 .53775 Mdot
.45531 .62695 Mdot
.33195 .4894 Mdot
.41359 .43735 Mdot
.51761 .42624 Mdot
.47984 .66569 Mdot
.31062 .64808 Mdot
.41431 .68834 Mdot
.46532 .59246 Mdot
.46999 .39619 Mdot
.31355 .53226 Mdot
.52272 .34957 Mdot
.32006 .4676 Mdot
.64207 .64062 Mdot
.45055 .44129 Mdot
.65696 .42895 Mdot
.27978 .63363 Mdot
.60892 .58729 Mdot
.64754 .51125 Mdot
.29688 .48587 Mdot
.5033 .6752 Mdot
.31197 .48162 Mdot
.29324 .47074 Mdot
.41902 .65032 Mdot
.31357 .49488 Mdot
.49049 .34968 Mdot
.5831 .51529 Mdot
.29158 .49467 Mdot
.45596 .66652 Mdot
.66506 .43519 Mdot
.30156 .50768 Mdot
.63329 .6622 Mdot
.46074 .37658 Mdot
.63214 .61963 Mdot
.75011 .45303 Mdot
.33449 .54694 Mdot
.69389 .43488 Mdot
.58968 .63925 Mdot
.67835 .46992 Mdot
.60945 .8087 Mdot
.47381 .62435 Mdot
.25131 .36126 Mdot
.61393 .43972 Mdot
.32645 .543 Mdot
.75487 .45692 Mdot
.51584 .36583 Mdot
.46011 .37929 Mdot
.63716 .4643 Mdot
.32818 .53798 Mdot
.77132 .68545 Mdot
.52343 .30998 Mdot
.44226 .58466 Mdot
.42875 .62712 Mdot
.57011 .16396 Mdot
.4498 .59153 Mdot
.67779 .79998 Mdot
.54111 .34696 Mdot
.56878 .61509 Mdot
.50364 .38733 Mdot
.56721 .68333 Mdot
.66346 .45863 Mdot
.57318 .65929 Mdot
.49946 .44845 Mdot
.61711 .60432 Mdot
.4503 .37589 Mdot
.57595 .50185 Mdot
.56408 .44435 Mdot
.64866 .47103 Mdot
.67311 .71302 Mdot
.34539 .53299 Mdot
.65129 .44099 Mdot
.64255 .59548 Mdot
.59443 .26476 Mdot
.52025 .42169 Mdot
.45225 .3417 Mdot
.60505 .52688 Mdot
.34043 .5125 Mdot
.60587 .63579 Mdot
.43839 .68959 Mdot
.6761 .43633 Mdot
.45959 .41198 Mdot
.52405 .37199 Mdot
.5513 .71881 Mdot
.46753 .64637 Mdot
.57589 .61629 Mdot
.42724 .65206 Mdot
.62146 .56971 Mdot
.51152 .4356 Mdot
.61524 .57788 Mdot
.50206 .33475 Mdot
.53588 .67433 Mdot
.23623 .36652 Mdot
.32125 .37848 Mdot
.62771 .59582 Mdot
.54355 .23804 Mdot
.46316 .64529 Mdot
.42131 .67172 Mdot
.28198 .72917 Mdot
.22362 .42535 Mdot
.34942 .23979 Mdot
.80229 .47164 Mdot
.47881 .65706 Mdot
.46448 .65485 Mdot
.63338 .61671 Mdot
.31294 .49317 Mdot
.35539 .50777 Mdot
.61802 .56862 Mdot
.67835 .36783 Mdot
.33849 .50523 Mdot
.82561 .53989 Mdot
.42438 .21757 Mdot
.48752 .33377 Mdot
.66591 .6126 Mdot
.67477 .44315 Mdot
.66809 .35477 Mdot
.5819 .50038 Mdot
.47786 .3494 Mdot
.68096 .29627 Mdot
.59452 .61223 Mdot
.43854 .48956 Mdot
.79538 .39657 Mdot
.44918 .36835 Mdot
.48307 .36547 Mdot
.49639 .38726 Mdot
.66422 .41766 Mdot
.23176 .44911 Mdot
.48467 .35362 Mdot
.67822 .36956 Mdot
.46535 .43054 Mdot
.54036 .46836 Mdot
.66374 .44483 Mdot
.54237 .28325 Mdot
.77265 .54883 Mdot
.43948 .18541 Mdot
.58032 .43197 Mdot
.4377 .6907 Mdot
.73098 .438 Mdot
.42148 .6614 Mdot
.28967 .38184 Mdot
.57566 .29901 Mdot
.35797 .52691 Mdot
.48111 .34828 Mdot
.62242 .59267 Mdot
.32966 .53678 Mdot
.55741 .74277 Mdot
.12675 .37312 Mdot
.43919 .69258 Mdot
.75629 .75931 Mdot
.42563 .68582 Mdot
.61028 .57085 Mdot
.31082 .51197 Mdot
.38086 .36949 Mdot
.38929 .55669 Mdot
.29853 .50828 Mdot
.76459 .65736 Mdot
.32829 .56194 Mdot
.56898 .25502 Mdot
.31046 .55116 Mdot
.45934 .66004 Mdot
.48573 .70838 Mdot
.39917 .39136 Mdot
.51456 .37055 Mdot
.44666 .5383 Mdot
.58432 .24427 Mdot
.5146 .36447 Mdot
.61756 .58955 Mdot
.2358 .37867 Mdot
.67265 .30111 Mdot
.31938 .49728 Mdot
.49252 .6313 Mdot
.47698 .36299 Mdot
.50055 .42407 Mdot
.52411 .42028 Mdot
.2074 .35667 Mdot
.8163 .61332 Mdot
.52259 .42716 Mdot
.47337 .43591 Mdot
.62021 .60134 Mdot
.61868 .42398 Mdot
.68075 .68276 Mdot
.34808 .26896 Mdot
.45857 .35406 Mdot
.65474 .44256 Mdot
.66963 .41324 Mdot
.53425 .4082 Mdot
.62194 .5019 Mdot
.29481 .61777 Mdot
.49184 .36138 Mdot
.23714 .38111 Mdot
.63109 .53204 Mdot
.57795 .59599 Mdot
.59576 .58861 Mdot
.34543 .50518 Mdot
.59389 .5828 Mdot
.64037 .58624 Mdot
.38273 .38736 Mdot
.51264 .55383 Mdot
.47932 .61098 Mdot
.67165 .45595 Mdot
.49674 .40043 Mdot
.42744 .32626 Mdot
.2933 .64202 Mdot
.42595 .64294 Mdot
.29901 .53471 Mdot
.46126 .69269 Mdot
.72125 .44471 Mdot
.35606 .56367 Mdot
.58955 .61529 Mdot
.47447 .66615 Mdot
.48442 .68068 Mdot
.65713 .44161 Mdot
.45675 .63143 Mdot
.46888 .69984 Mdot
.43864 .42759 Mdot
.33284 .41405 Mdot
.48056 .39607 Mdot
.70275 .73353 Mdot
.46995 .65348 Mdot
.50955 .69632 Mdot
.49387 .37141 Mdot
.59752 .59355 Mdot
.3934 .41494 Mdot
.51895 .37468 Mdot
.59112 .5897 Mdot
.53973 .40674 Mdot
.68739 .46544 Mdot
.32543 .47011 Mdot
.39315 .54611 Mdot
.20266 .68198 Mdot
.64157 .42434 Mdot
.56106 .7371 Mdot
.4862 .34467 Mdot
.51711 .8286 Mdot
.30442 .50617 Mdot
.53078 .3688 Mdot
.64781 .28474 Mdot
.29749 .49419 Mdot
.2987 .52596 Mdot
.49191 .42032 Mdot
.43046 .65282 Mdot
.61175 .5855 Mdot
.66251 .44134 Mdot
.67186 .79007 Mdot
.47428 .38116 Mdot
.45198 .38749 Mdot
.64999 .44582 Mdot
.4642 .64209 Mdot
.53581 .39909 Mdot
.7514 .41032 Mdot
.79062 .67155 Mdot
.42014 .67839 Mdot
.44379 .36397 Mdot
.27937 .41313 Mdot
.56201 .34471 Mdot
.457 .85451 Mdot
.61619 .49298 Mdot
.62113 .609 Mdot
.43637 .34141 Mdot
.1606 .36532 Mdot
.66778 .43404 Mdot
.35165 .23063 Mdot
.49737 .42578 Mdot
.45324 .41085 Mdot
.30974 .54384 Mdot
.47317 .40637 Mdot
.28346 .52777 Mdot
.19139 .64265 Mdot
.57871 .1873 Mdot
.34055 .49422 Mdot
.32977 .54367 Mdot
.62117 .25289 Mdot
.63189 .68833 Mdot
.31224 .5173 Mdot
.49364 .43697 Mdot
.57747 .34605 Mdot
.38964 .47032 Mdot
.62975 .44298 Mdot
.77053 .49532 Mdot
.47972 .30305 Mdot
.6874 .48491 Mdot
.79325 .55942 Mdot
.47387 .30108 Mdot
.50893 .60482 Mdot
.43259 .68514 Mdot
.4498 .36695 Mdot
.58055 .62191 Mdot
.57861 .61181 Mdot
.5299 .34833 Mdot
.50117 .40664 Mdot
.28959 .48946 Mdot
.68301 .44518 Mdot
.44973 .6928 Mdot
.4578 .41454 Mdot
.63943 .26751 Mdot
.68752 .44488 Mdot
.32348 .48941 Mdot
.29511 .32528 Mdot
.67295 .47941 Mdot
.48825 .4584 Mdot
.50246 .36532 Mdot
.48675 .40895 Mdot
.40046 .37436 Mdot
.43387 .67652 Mdot
.76573 .47093 Mdot
.43661 .40828 Mdot
.51675 .18437 Mdot
.44512 .61117 Mdot
.43281 .43353 Mdot
.3311 .48502 Mdot
.49303 .62468 Mdot
.65613 .60178 Mdot
.32889 .57899 Mdot
.46578 .38256 Mdot
.65011 .75072 Mdot
.38599 .78806 Mdot
.63556 .64251 Mdot
.30863 .46966 Mdot
.67275 .44941 Mdot
.48807 .40082 Mdot
.27287 .36178 Mdot
.51527 .38698 Mdot
.68506 .48223 Mdot
.63822 .63086 Mdot
.43063 .68382 Mdot
.6819 .75076 Mdot
.58147 .59858 Mdot
.30195 .52576 Mdot
.69272 .22888 Mdot
.28201 .52661 Mdot
.35339 .50464 Mdot
.30825 .32001 Mdot
.43207 .67634 Mdot
.14226 .39783 Mdot
.20978 .65487 Mdot
.45984 .44241 Mdot
.46122 .64304 Mdot
.32063 .5208 Mdot
.45433 .41931 Mdot
.36564 .52127 Mdot
.33058 .47725 Mdot
.50016 .43793 Mdot
.44464 .39469 Mdot
.53858 .79105 Mdot
.80718 .42013 Mdot
.67256 .45085 Mdot
.29211 .48408 Mdot
.38439 .58468 Mdot
.4513 .41709 Mdot
.5007 .37659 Mdot
.4507 .74455 Mdot
.63786 .4312 Mdot
.36765 .65072 Mdot
.49916 .42484 Mdot
.60593 .20758 Mdot
.51362 .46236 Mdot
.27096 .51504 Mdot
.4196 .66239 Mdot
.45005 .18562 Mdot
.41893 .71031 Mdot
.28501 .52872 Mdot
.68035 .43431 Mdot
.263 .50236 Mdot
.59957 .2371 Mdot
.47352 .64389 Mdot
.31224 .53705 Mdot
.53883 .58889 Mdot
.44133 .66889 Mdot
.47309 .65936 Mdot
.32104 .30598 Mdot
.62416 .64985 Mdot
.66702 .41685 Mdot
.46641 .65713 Mdot
.25187 .60099 Mdot
.45294 .66484 Mdot
.22408 .67124 Mdot
.44733 .36324 Mdot
.69057 .34711 Mdot
.59982 .67445 Mdot
.42449 .34795 Mdot
.47306 .65169 Mdot
.63831 .44595 Mdot
.52219 .41731 Mdot
.33322 .49808 Mdot
.68067 .46368 Mdot
.38542 .64333 Mdot
.62288 .62113 Mdot
.31133 .48333 Mdot
.41133 .69328 Mdot
.335 .52701 Mdot
.28201 .58459 Mdot
.32477 .77639 Mdot
.68277 .27108 Mdot
.38451 .56655 Mdot
.51818 .42356 Mdot
.79709 .51108 Mdot
.45408 .34467 Mdot
.50437 .4106 Mdot
.61902 .58627 Mdot
.68368 .32702 Mdot
.31547 .51054 Mdot
.73758 .71475 Mdot
.4546 .68484 Mdot
.45073 .18062 Mdot
.58195 .4039 Mdot
.54301 .38129 Mdot
.28862 .49724 Mdot
.28862 .53991 Mdot
.31731 .35121 Mdot
.653 .59098 Mdot
.5066 .34284 Mdot
.43883 .35921 Mdot
.54724 .37259 Mdot
.45755 .68056 Mdot
.64394 .50562 Mdot
.60375 .63011 Mdot
.39488 .81778 Mdot
.63526 .63438 Mdot
.67552 .48933 Mdot
.31846 .49474 Mdot
.68416 .43215 Mdot
.50025 .37434 Mdot
.36717 .53772 Mdot
.29569 .54441 Mdot
.64532 .47127 Mdot
.64465 .45895 Mdot
.51014 .75281 Mdot
.42905 .66551 Mdot
.52669 .38193 Mdot
.47963 .35313 Mdot
.46964 .41088 Mdot
.4974 .41341 Mdot
.4461 .69052 Mdot
.5268 .41116 Mdot
.42842 .70681 Mdot
.24358 .56 Mdot
.7327 .37477 Mdot
.53112 .54606 Mdot
.31901 .72802 Mdot
.32702 .49861 Mdot
.26228 .60638 Mdot
.53048 .3205 Mdot
.17841 .42933 Mdot
.44621 .80573 Mdot
.44046 .4207 Mdot
.62317 .57882 Mdot
.44441 .47375 Mdot
.58497 .61837 Mdot
.6674 .81824 Mdot
.52979 .71239 Mdot
.82377 .44976 Mdot
.46693 .35863 Mdot
.57742 .51999 Mdot
.23555 .60964 Mdot
.45227 .34437 Mdot
.53039 .72904 Mdot
.32232 .72292 Mdot
.66306 .72438 Mdot
.64154 .43382 Mdot
.46718 .37216 Mdot
.41499 .34313 Mdot
.49154 .35122 Mdot
.50363 .38265 Mdot
.52591 .41588 Mdot
.41806 .69366 Mdot
.52127 .35932 Mdot
.51961 .41311 Mdot
.69725 .58605 Mdot
.56839 .274 Mdot
.58225 .63186 Mdot
.30978 .75073 Mdot
.68498 .43207 Mdot
.29185 .49094 Mdot
.81136 .60514 Mdot
.43209 .65487 Mdot
.32279 .34825 Mdot
.49259 .41154 Mdot
.57655 .77821 Mdot
.49159 .66084 Mdot
.67258 .43126 Mdot
.65171 .6196 Mdot
.84083 .47339 Mdot
.61683 .59318 Mdot
.51969 .65932 Mdot
.59986 .59352 Mdot
.51806 .31246 Mdot
.28964 .48876 Mdot
.53192 .39314 Mdot
.4644 .66406 Mdot
.6023 .57864 Mdot
.62934 .31738 Mdot
.4944 .39223 Mdot
.6114 .59961 Mdot
.53158 .39311 Mdot
.38339 .53762 Mdot
.39111 .24566 Mdot
.63941 .5869 Mdot
.49027 .6626 Mdot
.44857 .67711 Mdot
.65313 .42331 Mdot
.30151 .48716 Mdot
.29309 .53329 Mdot
.44276 .65702 Mdot
.20761 .46387 Mdot
.4621 .35034 Mdot
.44781 .4092 Mdot
.47426 .18287 Mdot
.49902 .34892 Mdot
.58495 .26409 Mdot
.54888 .56101 Mdot
.32853 .49326 Mdot
.54619 .39027 Mdot
.49005 .42379 Mdot
.46276 .38117 Mdot
.2631 .56417 Mdot
.5899 .60255 Mdot
.44828 .36649 Mdot
.64815 .46289 Mdot
.67686 .57305 Mdot
.47065 .42947 Mdot
.46436 .46745 Mdot
.29501 .53455 Mdot
.24842 .29454 Mdot
.42575 .68422 Mdot
.64046 .59381 Mdot
.62922 .59641 Mdot
.77781 .50563 Mdot
.27632 .66004 Mdot
.55047 .55723 Mdot
.42745 .83284 Mdot
.54083 .67184 Mdot
.65925 .46332 Mdot
.64447 .55704 Mdot
.47609 .7182 Mdot
.63815 .60552 Mdot
.44125 .69313 Mdot
.44304 .36892 Mdot
.45648 .3555 Mdot
.15755 .4542 Mdot
.53566 .40799 Mdot
.67182 .44594 Mdot
.41305 .68848 Mdot
.33214 .50231 Mdot
.67512 .43298 Mdot
.42669 .65142 Mdot
.34128 .50011 Mdot
.43392 .40918 Mdot
.43314 .40312 Mdot
.29699 .53284 Mdot
.31787 .53974 Mdot
.49975 .36666 Mdot
.66582 .68006 Mdot
.33385 .54006 Mdot
.31763 .53489 Mdot
.59233 .6188 Mdot
.58038 .61756 Mdot
.45616 .46039 Mdot
.46033 .64697 Mdot
.52125 .41311 Mdot
.62262 .59753 Mdot
.68039 .4301 Mdot
.31734 .50818 Mdot
.50324 .42934 Mdot
.47194 .42597 Mdot
.65804 .44023 Mdot
.66258 .42509 Mdot
.64152 .43963 Mdot
.41936 .7005 Mdot
.4639 .40439 Mdot
.30572 .51451 Mdot
.42811 .67097 Mdot
.67 .41395 Mdot
.63193 .44535 Mdot
.65411 .57225 Mdot
.50748 .35192 Mdot
.65307 .66919 Mdot
.17309 .33573 Mdot
.52568 .1992 Mdot
.65424 .62506 Mdot
.65904 .60718 Mdot
.60242 .32525 Mdot
.44563 .49806 Mdot
.44732 .64627 Mdot
.61791 .42191 Mdot
.63488 .25153 Mdot
.4293 .40836 Mdot
.46918 .43761 Mdot
.51658 .4495 Mdot
.64135 .44624 Mdot
.69731 .33153 Mdot
.27955 .51812 Mdot
.47487 .28604 Mdot
.68862 .44957 Mdot
.58355 .63592 Mdot
.6639 .58521 Mdot
.63893 .63218 Mdot
.43609 .38203 Mdot
.33037 .37661 Mdot
.26437 .6299 Mdot
.78498 .45127 Mdot
.47042 .64825 Mdot
.4285 .32572 Mdot
.51487 .8257 Mdot
.29653 .52886 Mdot
.61986 .5642 Mdot
.65742 .46422 Mdot
.32092 .53817 Mdot
.4732 .6841 Mdot
.46453 .65744 Mdot
.59871 .62184 Mdot
.60485 .62417 Mdot
.63801 .62102 Mdot
.3343 .47789 Mdot
.31577 .49455 Mdot
.46597 .38538 Mdot
.31987 .50486 Mdot
.18966 .39769 Mdot
.62844 .45553 Mdot
.56375 .62791 Mdot
.4553 .65234 Mdot
.34247 .50679 Mdot
.49175 .39305 Mdot
.42135 .48873 Mdot
.35943 .72239 Mdot
.66791 .47046 Mdot
.37832 .2423 Mdot
.64917 .82335 Mdot
.5255 .37788 Mdot
.43968 .68037 Mdot
.26605 .29928 Mdot
.49381 .3867 Mdot
.62318 .63082 Mdot
.71006 .66398 Mdot
.65176 .55404 Mdot
.52027 .37717 Mdot
.42845 .4109 Mdot
.42423 .68928 Mdot
.41269 .819 Mdot
.47014 .38468 Mdot
.3638 .6285 Mdot
.48583 .64075 Mdot
.61093 .63337 Mdot
.85417 .57946 Mdot
.73094 .46712 Mdot
.67518 .3605 Mdot
.59945 .62542 Mdot
.5152 .40344 Mdot
.58549 .61243 Mdot
.65759 .46756 Mdot
.64925 .60291 Mdot
.27947 .52454 Mdot
.62551 .64254 Mdot
.4514 .38767 Mdot
.31315 .51931 Mdot
.45084 .64919 Mdot
.41699 .19954 Mdot
.72105 .62195 Mdot
.59635 .59575 Mdot
.62991 .57876 Mdot
.5446 .39604 Mdot
.37392 .66181 Mdot
.51405 .33779 Mdot
.44032 .38695 Mdot
.47924 .65162 Mdot
.29729 .49221 Mdot
.4167 .67122 Mdot
.41656 .42198 Mdot
.75147 .38418 Mdot
.42579 .6559 Mdot
.64233 .74645 Mdot
.65143 .45208 Mdot
.51325 .51634 Mdot
.49284 .39848 Mdot
.44844 .6315 Mdot
.46414 .40208 Mdot
.27893 .50911 Mdot
.53717 .52682 Mdot
.64216 .72408 Mdot
.46458 .67015 Mdot
.66339 .75099 Mdot
.73068 .3943 Mdot
.43467 .4537 Mdot
.42036 .67049 Mdot
.65918 .29468 Mdot
.60897 .57091 Mdot
.68146 .45968 Mdot
.67547 .47567 Mdot
.68807 .45681 Mdot
.52405 .33778 Mdot
.58239 .42285 Mdot
.69652 .43716 Mdot
.47107 .68379 Mdot
.64892 .47101 Mdot
.24262 .65338 Mdot
.74103 .70821 Mdot
.66088 .45685 Mdot
.47924 .3716 Mdot
.56876 .39003 Mdot
.58302 .29967 Mdot
.53257 .7634 Mdot
.82742 .46745 Mdot
.41813 .76484 Mdot
.51498 .37418 Mdot
.3451 .48158 Mdot
.31298 .47465 Mdot
.28553 .2716 Mdot
.56838 .23936 Mdot
.55651 .19727 Mdot
.3474 .53348 Mdot
.61443 .71071 Mdot
.31972 .48699 Mdot
.53094 .41446 Mdot
.45001 .413 Mdot
.34714 .53564 Mdot
.72788 .35646 Mdot
.60044 .72226 Mdot
.67801 .76889 Mdot
.32843 .53312 Mdot
.42739 .6452 Mdot
.43891 .6263 Mdot
.47422 .6571 Mdot
.40217 .22189 Mdot
.28738 .50413 Mdot
.46858 .4176 Mdot
.62706 .59403 Mdot
.45646 .35898 Mdot
.4382 .66816 Mdot
.7471 .70849 Mdot
.29581 .5045 Mdot
.47793 .35887 Mdot
.40609 .43876 Mdot
.61288 .62451 Mdot
.65434 .44741 Mdot
.39304 .51491 Mdot
.55598 .20115 Mdot
.46453 .67746 Mdot
.33804 .54425 Mdot
.52039 .69198 Mdot
.7007 .72383 Mdot
.54591 .3531 Mdot
.43424 .36374 Mdot
.66785 .79672 Mdot
.61329 .21978 Mdot
.49926 .34309 Mdot
.63497 .58658 Mdot
.56384 .70868 Mdot
.48141 .43004 Mdot
.30251 .47695 Mdot
.67517 .47793 Mdot
.6778 .4695 Mdot
.45391 .46054 Mdot
.40929 .5293 Mdot
.56385 .51876 Mdot
.48791 .41532 Mdot
.49309 .45742 Mdot
.6076 .63134 Mdot
.55351 .67521 Mdot
.52416 .18566 Mdot
.67693 .43001 Mdot
.533 .39512 Mdot
.75793 .64401 Mdot
.30852 .54596 Mdot
.64001 .63936 Mdot
.46494 .63494 Mdot
.26765 .55929 Mdot
.65244 .617 Mdot
.49786 .4337 Mdot
.53514 .40471 Mdot
.42769 .63763 Mdot
.27183 .51693 Mdot
.64278 .44808 Mdot
.62528 .58627 Mdot
.65647 .42666 Mdot
.29541 .49623 Mdot
.31561 .5011 Mdot
.41218 .44379 Mdot
.54382 .34343 Mdot
.59901 .58507 Mdot
.50099 .33373 Mdot
.66452 .5645 Mdot
.50116 .85808 Mdot
.41249 .64705 Mdot
.51841 .36045 Mdot
.28792 .5478 Mdot
.46324 .67465 Mdot
.44925 .40522 Mdot
.69474 .78386 Mdot
.45495 .42268 Mdot
.45682 .61266 Mdot
.66425 .24335 Mdot
.64726 .43206 Mdot
.48761 .28772 Mdot
.5065 .80043 Mdot
.50127 .35207 Mdot
.6329 .60492 Mdot
.56069 .41453 Mdot
.4353 .64678 Mdot
.31913 .49656 Mdot
.48297 .86549 Mdot
.45216 .66862 Mdot
.49383 .35553 Mdot
.67588 .43515 Mdot
.29919 .54908 Mdot
.61371 .47228 Mdot
.62445 .50429 Mdot
.52267 .4685 Mdot
.51795 .3476 Mdot
.50148 .41852 Mdot
.76376 .41755 Mdot
.6415 .59695 Mdot
.32257 .52788 Mdot
.44186 .68196 Mdot
.44326 .65323 Mdot
.59478 .61548 Mdot
.47825 .60478 Mdot
.51188 .51731 Mdot
.25694 .25039 Mdot
.58595 .59675 Mdot
.6927 .43994 Mdot
.3708 .6401 Mdot
.63168 .59129 Mdot
.60788 .60161 Mdot
.5923 .62057 Mdot
.52519 .60616 Mdot
.34064 .50726 Mdot
.49485 .43436 Mdot
.27974 .49171 Mdot
.5164 .40525 Mdot
.45955 .61245 Mdot
.46646 .66518 Mdot
.2993 .50034 Mdot
.64162 .80021 Mdot
.31253 .42777 Mdot
.48891 .37856 Mdot
.51801 .82779 Mdot
.50578 .44504 Mdot
.59944 .3014 Mdot
.52437 .44016 Mdot
.59648 .60728 Mdot
.46564 .32862 Mdot
.54585 .36543 Mdot
.31889 .24374 Mdot
.4565 .64904 Mdot
.58041 .58915 Mdot
.47303 .45031 Mdot
.50413 .45643 Mdot
.34178 .48306 Mdot
.32052 .53723 Mdot
.67876 .47281 Mdot
.53576 .2654 Mdot
.45163 .6461 Mdot
.20035 .61301 Mdot
.51257 .36926 Mdot
.69372 .48964 Mdot
.42682 .26812 Mdot
.44779 .40101 Mdot
.52639 .80751 Mdot
.32761 .36973 Mdot
.48958 .4002 Mdot
.45153 .56592 Mdot
.46482 .64579 Mdot
.74322 .35477 Mdot
.47192 .43271 Mdot
.61856 .62634 Mdot
.31696 .49135 Mdot
.28993 .54365 Mdot
.69143 .45903 Mdot
.17466 .47092 Mdot
.41576 .66836 Mdot
.30929 .49698 Mdot
.49978 .39451 Mdot
.43609 .68095 Mdot
.58855 .58787 Mdot
.54083 .37944 Mdot
.55456 .23254 Mdot
.32664 .50549 Mdot
.53879 .41451 Mdot
.34805 .61912 Mdot
.63118 .35677 Mdot
.70787 .26703 Mdot
.44404 .68325 Mdot
.64908 .42556 Mdot
.54864 .43224 Mdot
.21741 .44455 Mdot
.54344 .42169 Mdot
.69911 .36398 Mdot
.24996 .66405 Mdot
.64085 .43034 Mdot
.48965 .37038 Mdot
.46184 .4144 Mdot
.51987 .49154 Mdot
.68087 .43288 Mdot
.47082 .35565 Mdot
.23371 .52161 Mdot
.33707 .51856 Mdot
.61898 .56589 Mdot
.33488 .50543 Mdot
.48061 .37629 Mdot
.54952 .35189 Mdot
.31156 .54279 Mdot
.52814 .84377 Mdot
.61997 .43962 Mdot
.42394 .67683 Mdot
.48651 .44308 Mdot
.44034 .41013 Mdot
.49033 .14101 Mdot
.62928 .64485 Mdot
.66487 .68913 Mdot
.68039 .5268 Mdot
.78093 .59793 Mdot
.73234 .46412 Mdot
.78661 .35342 Mdot
.61907 .22201 Mdot
.52345 .36118 Mdot
.55722 .32586 Mdot
.30008 .60045 Mdot
.4713 .64573 Mdot
.20741 .56228 Mdot
.51481 .37049 Mdot
.50435 .38525 Mdot
.65626 .62322 Mdot
.61589 .74876 Mdot
.55479 .19586 Mdot
.42183 .49527 Mdot
.64345 .44659 Mdot
.29666 .48215 Mdot
.49587 .43546 Mdot
.48422 .5668 Mdot
.58677 .63839 Mdot
.72664 .45511 Mdot
.48049 .35978 Mdot
.20045 .40245 Mdot
.33949 .70631 Mdot
.43156 .66999 Mdot
.63064 .59795 Mdot
.57351 .20077 Mdot
.51201 .35701 Mdot
.4596 .63049 Mdot
.47746 .38524 Mdot
.54954 .60077 Mdot
.41456 .41373 Mdot
.66647 .46199 Mdot
.50251 .42591 Mdot
.72828 .44312 Mdot
.61509 .15335 Mdot
.7029 .44473 Mdot
.35803 .53302 Mdot
.56554 .62405 Mdot
.58995 .59816 Mdot
.31635 .5387 Mdot
.59273 .59376 Mdot
.33438 .32371 Mdot
.40265 .32409 Mdot
.64843 .45073 Mdot
.48973 .46249 Mdot
.66149 .45268 Mdot
.64115 .64028 Mdot
.51722 .37466 Mdot
.56658 .85462 Mdot
.60735 .58068 Mdot
.6282 .21339 Mdot
.45088 .66379 Mdot
.58544 .63835 Mdot
.46642 .4307 Mdot
.50572 .70624 Mdot
.58069 .60084 Mdot
.62176 .72946 Mdot
.46312 .38179 Mdot
.32485 .50122 Mdot
.47881 .42787 Mdot
.46559 .44314 Mdot
.57131 .61974 Mdot
.52278 .4041 Mdot
.42733 .65027 Mdot
.35175 .51906 Mdot
.83617 .52535 Mdot
.30032 .70391 Mdot
.47897 .35048 Mdot
.49828 .39228 Mdot
.2722 .48407 Mdot
.4371 .38597 Mdot
.44543 .69059 Mdot
.15022 .65276 Mdot
.6516 .45177 Mdot
.57637 .58851 Mdot
.73557 .45929 Mdot
.43686 .41724 Mdot
.52453 .41464 Mdot
.72057 .7666 Mdot
.7469 .38442 Mdot
.42175 .66278 Mdot
.54896 .37542 Mdot
.58628 .58983 Mdot
.67699 .43975 Mdot
.46532 .68587 Mdot
.48517 .4079 Mdot
.49719 .37316 Mdot
.65986 .42301 Mdot
.58509 .36033 Mdot
.44871 .20807 Mdot
.44275 .6299 Mdot
.46095 .32322 Mdot
.61173 .66111 Mdot
.4713 .34471 Mdot
.37575 .23206 Mdot
.3111 .53521 Mdot
.46902 .67365 Mdot
.78779 .53682 Mdot
.51441 .35701 Mdot
.42074 .65511 Mdot
.45278 .64595 Mdot
.54879 .39508 Mdot
.29442 .55343 Mdot
.34883 .50707 Mdot
.33819 .52271 Mdot
.14205 .48975 Mdot
.65811 .34256 Mdot
.63788 .62121 Mdot
.46487 .64473 Mdot
.6338 .57944 Mdot
.68015 .48576 Mdot
.54092 .56177 Mdot
.63413 .58156 Mdot
.34298 .5186 Mdot
.56476 .60659 Mdot
.45744 .39987 Mdot
.44974 .64832 Mdot
.63818 .60998 Mdot
.45416 .43948 Mdot
.3775 .6438 Mdot
.47228 .77486 Mdot
.63494 .45009 Mdot
.68141 .47452 Mdot
.45917 .42259 Mdot
.64435 .58113 Mdot
.50113 .36907 Mdot
.48055 .64301 Mdot
.37581 .63548 Mdot
.48524 .44223 Mdot
.5947 .5978 Mdot
.26624 .49202 Mdot
.56417 .20219 Mdot
.49565 .32719 Mdot
.48055 .37138 Mdot
.51948 .40269 Mdot
.47708 .3856 Mdot
.70077 .71328 Mdot
.44625 .621 Mdot
.31779 .72558 Mdot
.75917 .46165 Mdot
.29374 .51 Mdot
.28212 .48551 Mdot
.51215 .19466 Mdot
.30322 .60819 Mdot
.46142 .64668 Mdot
.50203 .4117 Mdot
.30289 .66299 Mdot
.79025 .67041 Mdot
.64464 .81438 Mdot
.52831 .48228 Mdot
.61932 .64792 Mdot
.34036 .54164 Mdot
.60565 .57433 Mdot
.51567 .39736 Mdot
.5208 .44886 Mdot
.77002 .31706 Mdot
.48273 .6682 Mdot
.64999 .45528 Mdot
.51695 .40798 Mdot
.65978 .34752 Mdot
.62193 .6012 Mdot
.57891 .63456 Mdot
.44422 .3741 Mdot
.26804 .51751 Mdot
.58628 .15691 Mdot
.43471 .67707 Mdot
.41379 .7577 Mdot
.23456 .61306 Mdot
.37901 .72467 Mdot
.43669 .67052 Mdot
.56178 .47156 Mdot
.64826 .63214 Mdot
.42421 .25983 Mdot
.29055 .51444 Mdot
.67814 .46555 Mdot
.42906 .42715 Mdot
.30115 .54074 Mdot
.62659 .63716 Mdot
.32165 .49854 Mdot
.52408 .41754 Mdot
.47816 .62735 Mdot
.62295 .61017 Mdot
.47722 .60961 Mdot
.28074 .54443 Mdot
.67871 .43291 Mdot
.43976 .51414 Mdot
.35758 .45282 Mdot
.32717 .36588 Mdot
.44619 .36771 Mdot
.48892 .5714 Mdot
.46919 .41615 Mdot
.2949 .47294 Mdot
.48756 .39024 Mdot
.31323 .46022 Mdot
.63191 .60536 Mdot
.47332 .43559 Mdot
.49175 .41587 Mdot
.24956 .69348 Mdot
.46661 .3633 Mdot
.50323 .33651 Mdot
.49108 .40349 Mdot
.37359 .50629 Mdot
.49782 .46245 Mdot
.32919 .48303 Mdot
.69003 .60127 Mdot
.60593 .60396 Mdot
.66626 .47694 Mdot
.65632 .42109 Mdot
.68155 .33576 Mdot
.76456 .53065 Mdot
.5889 .76414 Mdot
.33333 .51196 Mdot
.43898 .63943 Mdot
.48305 .38937 Mdot
.79241 .39631 Mdot
.6193 .52547 Mdot
.59482 .64071 Mdot
.30337 .70594 Mdot
.44387 .33101 Mdot
.74765 .34355 Mdot
.5451 .37016 Mdot
.15489 .47692 Mdot
.50501 .31778 Mdot
.41669 .39408 Mdot
.60134 .56865 Mdot
.71525 .46085 Mdot
.43819 .39741 Mdot
.34845 .49057 Mdot
.67682 .46015 Mdot
.57682 .37749 Mdot
.65433 .66256 Mdot
.68925 .61935 Mdot
.36632 .47255 Mdot
.46519 .39412 Mdot
.62195 .61108 Mdot
.30854 .48334 Mdot
.53325 .18807 Mdot
.42767 .67265 Mdot
.44931 .60416 Mdot
.35075 .59147 Mdot
.54085 .8361 Mdot
.68783 .44376 Mdot
.39621 .25851 Mdot
.45188 .39107 Mdot
.70219 .65688 Mdot
.49331 .44176 Mdot
.75565 .70237 Mdot
.68643 .43051 Mdot
.34484 .52001 Mdot
.43081 .64129 Mdot
.29714 .47964 Mdot
.31695 .37198 Mdot
.66698 .61068 Mdot
.5011 .54359 Mdot
.61474 .59448 Mdot
.59128 .49896 Mdot
.31698 .52361 Mdot
.53124 .39628 Mdot
.25303 .25243 Mdot
.31536 .53532 Mdot
.30908 .54983 Mdot
.36618 .7935 Mdot
.53095 .86086 Mdot
.45425 .33276 Mdot
.33278 .5419 Mdot
.60945 .59427 Mdot
.67518 .45148 Mdot
.48964 .43059 Mdot
.46104 .39272 Mdot
.30041 .53939 Mdot
.57126 .61229 Mdot
.25622 .41451 Mdot
.60188 .62032 Mdot
.34128 .50962 Mdot
.608 .61496 Mdot
.51596 .68795 Mdot
.63401 .58907 Mdot
.43948 .40872 Mdot
.48636 .3901 Mdot
.74057 .50894 Mdot
.31675 .50127 Mdot
.48604 .4153 Mdot
.54412 .395 Mdot
.30896 .51473 Mdot
.59187 .47335 Mdot
.26496 .40738 Mdot
.47954 .34644 Mdot
.46278 .37282 Mdot
.64403 .42852 Mdot
.51935 .57908 Mdot
.38476 .25137 Mdot
.52058 .41828 Mdot
.6641 .41814 Mdot
.34945 .49385 Mdot
.49384 .36176 Mdot
.79783 .63412 Mdot
.56796 .7095 Mdot
.5218 .37403 Mdot
.60915 .57119 Mdot
.54622 .36759 Mdot
.6929 .25261 Mdot
.43995 .38884 Mdot
.31859 .5158 Mdot
.30564 .49277 Mdot
.20538 .63205 Mdot
.30438 .52623 Mdot
.58166 .62319 Mdot
.43992 .66833 Mdot
.69511 .73789 Mdot
.5911 .58483 Mdot
.51483 .32511 Mdot
.22405 .69255 Mdot
.53662 .38316 Mdot
.44731 .42847 Mdot
.63315 .19834 Mdot
.6065 .57658 Mdot
.28379 .50123 Mdot
.46366 .50587 Mdot
.54286 .3382 Mdot
.4717 .66909 Mdot
.4394 .443 Mdot
.44344 .36551 Mdot
.65605 .23301 Mdot
.70676 .69517 Mdot
.46993 .63403 Mdot
.49565 .33692 Mdot
.52212 .41722 Mdot
.63403 .65162 Mdot
.49582 .39565 Mdot
.67316 .45467 Mdot
.28877 .50048 Mdot
.629 .58466 Mdot
.65804 .43792 Mdot
.50944 .35859 Mdot
.64149 .44247 Mdot
.63229 .61997 Mdot
.47145 .63909 Mdot
.51773 .38728 Mdot
.62975 .445 Mdot
.64229 .44306 Mdot
.47215 .41597 Mdot
.32157 .49536 Mdot
.46837 .31222 Mdot
.46946 .35982 Mdot
.50539 .42846 Mdot
.29128 .53186 Mdot
.84941 .63874 Mdot
.44686 .40886 Mdot
.71221 .36926 Mdot
.29165 .541 Mdot
.59353 .49005 Mdot
.59978 .57352 Mdot
.44126 .36926 Mdot
.47304 .63977 Mdot
.46004 .63475 Mdot
.63557 .63558 Mdot
.32771 .5509 Mdot
.68852 .51858 Mdot
.28433 .55568 Mdot
.55917 .39562 Mdot
.47584 .34095 Mdot
.22798 .47966 Mdot
.8252 .4418 Mdot
.27768 .50089 Mdot
.61356 .67515 Mdot
.41348 .51374 Mdot
.44904 .63281 Mdot
.58047 .63058 Mdot
.34447 .54001 Mdot
.28242 .52264 Mdot
.33073 .49474 Mdot
.67429 .46927 Mdot
.74341 .51062 Mdot
.27629 .52857 Mdot
.26715 .5052 Mdot
.46017 .3857 Mdot
.51822 .41895 Mdot
.57506 .21383 Mdot
.51722 .23056 Mdot
.63906 .45208 Mdot
.62202 .63487 Mdot
.12839 .47879 Mdot
.48208 .64871 Mdot
.2918 .72219 Mdot
.4595 .4362 Mdot
.12982 .38197 Mdot
.4756 .43219 Mdot
.50005 .39726 Mdot
.35213 .51887 Mdot
.63213 .45045 Mdot
.65743 .45302 Mdot
.32081 .52976 Mdot
.27295 .49319 Mdot
.6718 .45531 Mdot
.49193 .80743 Mdot
.80961 .63164 Mdot
.63648 .54555 Mdot
.30623 .51018 Mdot
.37023 .43955 Mdot
.43631 .63066 Mdot
.57319 .39575 Mdot
.48143 .63777 Mdot
.61523 .60136 Mdot
.65377 .61768 Mdot
.46545 .67484 Mdot
.46499 .3811 Mdot
.64182 .61418 Mdot
.5253 .36649 Mdot
.41497 .77466 Mdot
.31888 .40362 Mdot
.72021 .49571 Mdot
.53568 .4635 Mdot
.58347 .47857 Mdot
.48498 .61128 Mdot
.50202 .35858 Mdot
.7892 .60903 Mdot
.64628 .45116 Mdot
.55733 .42828 Mdot
.47351 .67012 Mdot
.66326 .20783 Mdot
.51933 .38179 Mdot
.31982 .51314 Mdot
.45666 .64407 Mdot
.31878 .57729 Mdot
.36722 .62453 Mdot
.51812 .4042 Mdot
.1799 .33313 Mdot
.36943 .51981 Mdot
.63375 .59435 Mdot
.19849 .45531 Mdot
.27283 .50857 Mdot
.68747 .40977 Mdot
.77572 .48657 Mdot
.60601 .81741 Mdot
.29163 .4904 Mdot
.63264 .64711 Mdot
.33902 .48946 Mdot
.68082 .43585 Mdot
.36111 .51304 Mdot
.62681 .60361 Mdot
.48162 .36226 Mdot
.59398 .6097 Mdot
.66583 .4728 Mdot
.45267 .21152 Mdot
.46851 .63337 Mdot
.58287 .58541 Mdot
.4598 .671 Mdot
.61615 .36301 Mdot
.75961 .42357 Mdot
.4291 .6834 Mdot
.26775 .35399 Mdot
.46537 .34416 Mdot
.27112 .51245 Mdot
.59088 .61173 Mdot
.76083 .59568 Mdot
.43606 .51125 Mdot
.29199 .51973 Mdot
.63286 .63106 Mdot
.37811 .58757 Mdot
.21209 .41458 Mdot
.50707 .33634 Mdot
.57709 .3075 Mdot
.30394 .5128 Mdot
.64676 .63887 Mdot
.4648 .18279 Mdot
.34002 .48873 Mdot
.5843 .60267 Mdot
.42636 .64511 Mdot
.44007 .65545 Mdot
.45742 .36106 Mdot
.48693 .62271 Mdot
.64517 .62192 Mdot
.39418 .62084 Mdot
.33251 .54344 Mdot
.27973 .57288 Mdot
.62771 .44747 Mdot
.60156 .60789 Mdot
.53763 .40504 Mdot
.3359 .4695 Mdot
.54498 .69696 Mdot
.26103 .42722 Mdot
.24894 .28678 Mdot
.59499 .61555 Mdot
.28556 .50934 Mdot
.32069 .51067 Mdot
.50095 .32754 Mdot
.38458 .56421 Mdot
.69287 .52029 Mdot
.44484 .48616 Mdot
.42622 .48321 Mdot
.61988 .56538 Mdot
.67289 .59233 Mdot
.46867 .45026 Mdot
.46992 .39232 Mdot
.4449 .63363 Mdot
.47835 .364 Mdot
.34683 .52792 Mdot
.44592 .37012 Mdot
.44257 .68085 Mdot
.61753 .59078 Mdot
.51679 .38279 Mdot
.64399 .4343 Mdot
.4283 .63405 Mdot
.46392 .69224 Mdot
.59802 .6018 Mdot
.29875 .53953 Mdot
.60923 .4823 Mdot
.60599 .62539 Mdot
.46534 .39305 Mdot
.5214 .59218 Mdot
.52358 .4206 Mdot
.49291 .2919 Mdot
.33692 .48492 Mdot
.62589 .58336 Mdot
.35239 .52728 Mdot
.45791 .66723 Mdot
.7621 .46634 Mdot
.48395 .38111 Mdot
.58644 .5949 Mdot
.57258 .67355 Mdot
.53099 .29148 Mdot
.26349 .51311 Mdot
.51518 .78562 Mdot
.28779 .47991 Mdot
.61493 .63588 Mdot
.27808 .72847 Mdot
.6859 .45504 Mdot
.59459 .641 Mdot
.83968 .49729 Mdot
.60278 .58472 Mdot
.45242 .37144 Mdot
.45722 .41949 Mdot
.63162 .58754 Mdot
.65151 .42353 Mdot
.56834 .18774 Mdot
.58612 .56771 Mdot
.28627 .4977 Mdot
.42046 .78855 Mdot
.34384 .21054 Mdot
.40757 .64575 Mdot
.44304 .63542 Mdot
.50293 .31441 Mdot
.46161 .33798 Mdot
.4768 .66983 Mdot
.48867 .66294 Mdot
.68307 .4675 Mdot
.58797 .61774 Mdot
.352 .47474 Mdot
.43266 .70249 Mdot
.38783 .50479 Mdot
.7592 .52465 Mdot
.49257 .3275 Mdot
.24283 .62602 Mdot
.47007 .43813 Mdot
.70782 .4002 Mdot
.44344 .68194 Mdot
.52928 .42261 Mdot
.52766 .34599 Mdot
.47796 .64823 Mdot
.67644 .45267 Mdot
.50053 .61273 Mdot
.61273 .61514 Mdot
.85041 .60187 Mdot
.53099 .36545 Mdot
.44731 .37656 Mdot
.47101 .65044 Mdot
.697 .5684 Mdot
.29267 .50608 Mdot
.30358 .47436 Mdot
.64081 .59621 Mdot
.42303 .52893 Mdot
.45336 .35731 Mdot
.49322 .35761 Mdot
.6204 .61639 Mdot
.57699 .6185 Mdot
.5606 .76344 Mdot
.45687 .41087 Mdot
.45739 .65252 Mdot
.67629 .48964 Mdot
.44694 .68246 Mdot
.5278 .41691 Mdot
.44663 .38197 Mdot
.43867 .40766 Mdot
.53613 .4072 Mdot
.49057 .65529 Mdot
.513 .43305 Mdot
.52187 .45152 Mdot
.28693 .51382 Mdot
.51733 .41336 Mdot
.43245 .48542 Mdot
.47388 .36948 Mdot
.67383 .45268 Mdot
.35191 .26543 Mdot
.51911 .38232 Mdot
.445 .36573 Mdot
.57207 .59084 Mdot
.49272 .37588 Mdot
.48152 .64457 Mdot
.30827 .50367 Mdot
.46538 .64671 Mdot
.46146 .63448 Mdot
.65315 .59915 Mdot
.69656 .44276 Mdot
.43485 .41517 Mdot
.66172 .46801 Mdot
.53156 .33511 Mdot
.51451 .35665 Mdot
.76315 .48649 Mdot
.15377 .4901 Mdot
.41485 .21687 Mdot
.48204 .38072 Mdot
.60746 .57822 Mdot
.60727 .57353 Mdot
.57694 .35877 Mdot
.51329 .34065 Mdot
.44862 .69232 Mdot
.45443 .63233 Mdot
.55932 .2387 Mdot
.70015 .29339 Mdot
.67446 .45284 Mdot
.5136 .56621 Mdot
.50723 .34399 Mdot
.53223 .4162 Mdot
.53809 .37642 Mdot
.63924 .58567 Mdot
.51864 .48136 Mdot
.58679 .63632 Mdot
.34575 .71846 Mdot
.46885 .66736 Mdot
.52006 .39372 Mdot
.26381 .66041 Mdot
.3277 .53574 Mdot
.30956 .50354 Mdot
.4534 .69764 Mdot
.64823 .65413 Mdot
.54348 .20884 Mdot
.63908 .82309 Mdot
.3575 .53763 Mdot
.64345 .46594 Mdot
.49773 .35376 Mdot
.61074 .58826 Mdot
.34322 .51046 Mdot
.64542 .46682 Mdot
.52844 .39087 Mdot
.74462 .51032 Mdot
.476 .38042 Mdot
.27743 .60807 Mdot
.32079 .48898 Mdot
.77227 .68742 Mdot
.32247 .55259 Mdot
.42513 .63655 Mdot
.45931 .6829 Mdot
.44976 .40483 Mdot
.21384 .47786 Mdot
.27592 .49506 Mdot
.52334 .62081 Mdot
.69241 .44011 Mdot
.52582 .69818 Mdot
.68263 .44382 Mdot
.6335 .59844 Mdot
.68149 .457 Mdot
.6288 .60502 Mdot
.51275 .2192 Mdot
.37646 .51215 Mdot
.65106 .44277 Mdot
.55264 .65922 Mdot
.4629 .33466 Mdot
.63699 .44825 Mdot
.52905 .4409 Mdot
.50657 .29371 Mdot
.61854 .61874 Mdot
.68777 .43727 Mdot
.53289 .39683 Mdot
.77215 .33908 Mdot
.4213 .67157 Mdot
.45212 .68997 Mdot
.53254 .43652 Mdot
.6302 .57064 Mdot
.35489 .50571 Mdot
.73998 .69904 Mdot
.41286 .69177 Mdot
.44834 .40847 Mdot
.43727 .39276 Mdot
.27891 .48824 Mdot
.24723 .66761 Mdot
.44801 .39433 Mdot
.40421 .41248 Mdot
.4559 .41179 Mdot
.42326 .68626 Mdot
.29693 .48044 Mdot
.3166 .50744 Mdot
.63574 .62789 Mdot
.32086 .54229 Mdot
.57354 .3376 Mdot
.28941 .67423 Mdot
.41147 .37078 Mdot
.45215 .67079 Mdot
.32615 .69851 Mdot
.34377 .71972 Mdot
.82576 .47126 Mdot
.27546 .541 Mdot
.49027 .44111 Mdot
.31018 .54654 Mdot
.67808 .44248 Mdot
.32586 .50281 Mdot
.34092 .54105 Mdot
.50327 .36711 Mdot
.51491 .40366 Mdot
.62457 .59086 Mdot
.39125 .55302 Mdot
.29487 .54038 Mdot
.47769 .43182 Mdot
.44924 .34503 Mdot
.53139 .37549 Mdot
.53305 .6176 Mdot
.28172 .49413 Mdot
.42279 .82004 Mdot
.62995 .27405 Mdot
.29523 .54007 Mdot
.60101 .16366 Mdot
.56623 .67634 Mdot
.6609 .59139 Mdot
.46173 .60009 Mdot
.46001 .41644 Mdot
.58252 .59183 Mdot
.51583 .39644 Mdot
.24441 .62669 Mdot
.49989 .37769 Mdot
.67347 .4562 Mdot
.52381 .36149 Mdot
.64697 .62927 Mdot
.60035 .62032 Mdot
.44326 .39736 Mdot
.51509 .38431 Mdot
.47602 .20615 Mdot
.32225 .56302 Mdot
.30901 .49929 Mdot
.67769 .5206 Mdot
.6529 .43503 Mdot
.46958 .67252 Mdot
.49042 .3978 Mdot
.64964 .5945 Mdot
.59802 .61809 Mdot
.27628 .49934 Mdot
.62119 .62953 Mdot
.43449 .67571 Mdot
.48722 .38432 Mdot
.47276 .67514 Mdot
.67717 .46893 Mdot
.29072 .485 Mdot
.51803 .40977 Mdot
.46022 .38523 Mdot
.30546 .49263 Mdot
.45199 .44094 Mdot
.64852 .42638 Mdot
.59862 .58702 Mdot
.29499 .48696 Mdot
.43969 .66476 Mdot
.63239 .59967 Mdot
.50523 .43044 Mdot
.15931 .40909 Mdot
.45594 .37028 Mdot
.47178 .42498 Mdot
.84638 .47548 Mdot
.51309 .34757 Mdot
.59321 .61492 Mdot
.34517 .51622 Mdot
.5063 .46895 Mdot
.66371 .31937 Mdot
.79541 .72082 Mdot
.59307 .63934 Mdot
.49234 .35231 Mdot
.79834 .41216 Mdot
.48578 .3545 Mdot
.26803 .45375 Mdot
.61382 .55506 Mdot
.55122 .50276 Mdot
.52447 .43723 Mdot
.43298 .65393 Mdot
.62333 .58685 Mdot
.63103 .60906 Mdot
.39184 .78276 Mdot
.50042 .36317 Mdot
.47244 .58174 Mdot
.52858 .40326 Mdot
.43691 .66343 Mdot
.58704 .25104 Mdot
.59903 .6209 Mdot
.28375 .26901 Mdot
.46662 .41508 Mdot
.27982 .52007 Mdot
.56379 .61007 Mdot
.49903 .70127 Mdot
.50163 .42928 Mdot
.65001 .46126 Mdot
.42739 .70777 Mdot
.4241 .43174 Mdot
.44763 .67284 Mdot
.50881 .42699 Mdot
.4329 .46683 Mdot
.18927 .47035 Mdot
.32649 .49509 Mdot
.43248 .63941 Mdot
.53503 .58465 Mdot
.50902 .4364 Mdot
.29339 .48906 Mdot
.29031 .51626 Mdot
.67246 .4717 Mdot
.5386 .53797 Mdot
.34666 .61027 Mdot
.33887 .42513 Mdot
.40835 .78536 Mdot
.56591 .60872 Mdot
.64291 .71885 Mdot
.48468 .42405 Mdot
.66891 .49792 Mdot
.47736 .6407 Mdot
.4576 .36659 Mdot
.38992 .26884 Mdot
.32581 .53244 Mdot
.45672 .37646 Mdot
.66306 .45329 Mdot
.65198 .51393 Mdot
.66669 .49408 Mdot
.78474 .47823 Mdot
.61457 .59613 Mdot
.53011 .44497 Mdot
.43689 .46465 Mdot
.60537 .56917 Mdot
.43631 .37479 Mdot
.58755 .59824 Mdot
.51361 .8215 Mdot
.63607 .45179 Mdot
.28075 .49919 Mdot
.52987 .65346 Mdot
.43087 .4003 Mdot
.45392 .34773 Mdot
.69738 .45461 Mdot
.47058 .39692 Mdot
.17639 .45788 Mdot
.537 .6178 Mdot
.6399 .60737 Mdot
.32985 .49487 Mdot
.43581 .38237 Mdot
.55089 .54656 Mdot
.47562 .35796 Mdot
.38175 .34388 Mdot
.44404 .36744 Mdot
.36454 .61081 Mdot
.3177 .49191 Mdot
.45134 .67446 Mdot
.52056 .43334 Mdot
.50141 .3851 Mdot
.70441 .33288 Mdot
.51845 .32257 Mdot
.52311 .42926 Mdot
.26395 .48446 Mdot
.34385 .50545 Mdot
.33435 .48711 Mdot
.62415 .64168 Mdot
.67406 .25815 Mdot
.45877 .65819 Mdot
.53218 .46079 Mdot
.42627 .69749 Mdot
.23681 .43918 Mdot
.64243 .46388 Mdot
.79784 .45241 Mdot
.49175 .41061 Mdot
.3366 .51414 Mdot
.74086 .66256 Mdot
.33282 .47683 Mdot
.49672 .56213 Mdot
.45133 .64638 Mdot
.31735 .53283 Mdot
.50192 .39306 Mdot
.42296 .51097 Mdot
.77907 .3829 Mdot
.46507 .65744 Mdot
.51108 .32414 Mdot
.62424 .64482 Mdot
.73322 .47945 Mdot
.19228 .36931 Mdot
.42104 .67326 Mdot
.45377 .61301 Mdot
.50039 .36132 Mdot
.33208 .53476 Mdot
.43244 .65927 Mdot
.42809 .68847 Mdot
.62405 .62944 Mdot
.51387 .40725 Mdot
.51091 .41141 Mdot
.61493 .63718 Mdot
.46702 .64772 Mdot
.54072 .42839 Mdot
.41465 .41589 Mdot
.74401 .27509 Mdot
.36378 .58559 Mdot
.85448 .60419 Mdot
.58235 .3684 Mdot
.3515 .28363 Mdot
.74024 .7048 Mdot
.28571 .53318 Mdot
.51736 .36693 Mdot
.41952 .40091 Mdot
.6448 .62286 Mdot
.48471 .37174 Mdot
.64341 .56305 Mdot
.45545 .63895 Mdot
.65699 .20816 Mdot
.33386 .67453 Mdot
.56237 .82198 Mdot
.48641 .37075 Mdot
.30299 .45965 Mdot
.66949 .44056 Mdot
.42039 .6329 Mdot
.3148 .47748 Mdot
.53853 .39699 Mdot
.47194 .20615 Mdot
.59023 .63897 Mdot
.29905 .53153 Mdot
.5337 .19028 Mdot
.56751 .47709 Mdot
.52477 .41868 Mdot
.60859 .64164 Mdot
.77096 .63941 Mdot
.32806 .56757 Mdot
.40986 .68143 Mdot
.67701 .45387 Mdot
.62212 .5835 Mdot
.45406 .63118 Mdot
.3324 .4656 Mdot
.30991 .52986 Mdot
.35557 .49999 Mdot
.39833 .23257 Mdot
.58149 .58253 Mdot
.66498 .43995 Mdot
.73209 .33622 Mdot
.70436 .31174 Mdot
.67014 .45715 Mdot
.65348 .62016 Mdot
.34366 .50678 Mdot
.32611 .5267 Mdot
.3077 .50406 Mdot
.3607 .22669 Mdot
.2958 .54781 Mdot
.32443 .75134 Mdot
.53381 .38358 Mdot
.40761 .39555 Mdot
.49204 .35362 Mdot
.45804 .6877 Mdot
.30783 .48822 Mdot
.45403 .51245 Mdot
.53641 .34488 Mdot
.77245 .41794 Mdot
.45462 .36564 Mdot
.46106 .61989 Mdot
.45501 .3859 Mdot
.20837 .59449 Mdot
.3053 .54609 Mdot
.48296 .37728 Mdot
.46408 .62502 Mdot
.65753 .43104 Mdot
.26265 .50758 Mdot
.51929 .40311 Mdot
.56239 .78451 Mdot
.51774 .35285 Mdot
.56721 .81394 Mdot
.27911 .57887 Mdot
.64292 .46525 Mdot
.24073 .59027 Mdot
.60301 .64929 Mdot
.40753 .41457 Mdot
.55542 .35796 Mdot
.46295 .66515 Mdot
.53374 .67961 Mdot
.60617 .60159 Mdot
.52826 .48108 Mdot
.45626 .45696 Mdot
.66736 .47477 Mdot
.35043 .55499 Mdot
.47898 .66743 Mdot
.43928 .36605 Mdot
.51324 .33606 Mdot
.37342 .75372 Mdot
.49169 .45914 Mdot
.43912 .38118 Mdot
.6918 .46832 Mdot
.31724 .73842 Mdot
.47095 .37262 Mdot
.50608 .56199 Mdot
.36183 .5195 Mdot
.55863 .3884 Mdot
.30852 .74059 Mdot
.45899 .4221 Mdot
.30576 .53516 Mdot
.41074 .35074 Mdot
.32982 .60296 Mdot
.69527 .4402 Mdot
.44475 .36503 Mdot
.2091 .64226 Mdot
.4641 .40735 Mdot
.45517 .65688 Mdot
.50708 .33839 Mdot
.62413 .60277 Mdot
.41658 .21098 Mdot
.6417 .62091 Mdot
.467 .34981 Mdot
.30536 .50621 Mdot
.47256 .65582 Mdot
.31062 .26148 Mdot
.7205 .52417 Mdot
.29967 .72275 Mdot
.66383 .79325 Mdot
.68431 .43303 Mdot
.67403 .41404 Mdot
.483 .65784 Mdot
.48108 .3767 Mdot
.32084 .76846 Mdot
.50224 .31634 Mdot
.46154 .37441 Mdot
.50117 .37819 Mdot
.75332 .42099 Mdot
.45678 .63583 Mdot
.61272 .62212 Mdot
.44707 .38843 Mdot
.51682 .43194 Mdot
.28488 .53065 Mdot
.64714 .43618 Mdot
.60065 .57331 Mdot
.65031 .4524 Mdot
.61797 .58597 Mdot
.6241 .18125 Mdot
.54859 .38273 Mdot
.66438 .43114 Mdot
.43293 .706 Mdot
.29653 .53619 Mdot
.29007 .66986 Mdot
.63335 .60438 Mdot
.6342 .63449 Mdot
.44148 .38709 Mdot
.30833 .53707 Mdot
.35283 .52188 Mdot
.67854 .43887 Mdot
.43115 .68146 Mdot
.51867 .38124 Mdot
.5094 .34978 Mdot
.39197 .38782 Mdot
.64047 .58042 Mdot
.26866 .60979 Mdot
.63689 .73498 Mdot
.4802 .37906 Mdot
.33431 .54205 Mdot
.51064 .37963 Mdot
.67538 .7408 Mdot
.32641 .53853 Mdot
.46363 .42683 Mdot
.55023 .16347 Mdot
.65946 .64786 Mdot
.3126 .6246 Mdot
.44078 .40617 Mdot
.72241 .74825 Mdot
.48786 .41911 Mdot
.6783 .20952 Mdot
.73216 .63167 Mdot
.46954 .34472 Mdot
.49428 .43251 Mdot
.29054 .40873 Mdot
.50023 .3501 Mdot
.62051 .63724 Mdot
.60795 .21594 Mdot
.34845 .48925 Mdot
.41821 .74567 Mdot
.36332 .26297 Mdot
.68674 .43156 Mdot
.64048 .59585 Mdot
.66916 .58599 Mdot
.66144 .45944 Mdot
.30877 .51154 Mdot
.47712 .38585 Mdot
.44995 .53567 Mdot
.62726 .57173 Mdot
.58645 .41069 Mdot
.45343 .65602 Mdot
.55054 .72741 Mdot
.59784 .52833 Mdot
.44258 .67444 Mdot
.5151 .41607 Mdot
.27787 .40973 Mdot
.46421 .24094 Mdot
.82658 .60627 Mdot
.45164 .62996 Mdot
.46689 .65736 Mdot
.38938 .21419 Mdot
.63984 .46898 Mdot
.39568 .75887 Mdot
.36686 .61615 Mdot
.4737 .66403 Mdot
.28714 .56871 Mdot
.59052 .63318 Mdot
.49745 .64107 Mdot
.54185 .44195 Mdot
.52207 .36629 Mdot
.50157 .39058 Mdot
.43603 .68515 Mdot
.54114 .30004 Mdot
.19498 .44797 Mdot
.46026 .67215 Mdot
.53549 .32305 Mdot
.5277 .51999 Mdot
.6508 .68619 Mdot
.60774 .63093 Mdot
.6949 .44663 Mdot
.62746 .4246 Mdot
.2811 .51424 Mdot
.69585 .44464 Mdot
.65542 .51038 Mdot
.47741 .39869 Mdot
.45497 .67947 Mdot
.53772 .69547 Mdot
.44203 .65862 Mdot
.65882 .45703 Mdot
.66444 .47879 Mdot
.28724 .51314 Mdot
.31557 .49965 Mdot
.32217 .31862 Mdot
.59217 .28932 Mdot
.46823 .3582 Mdot
.77922 .55551 Mdot
.3446 .53736 Mdot
.58876 .41296 Mdot
.69591 .44867 Mdot
.65323 .43327 Mdot
.71126 .34786 Mdot
.49569 .40771 Mdot
.23431 .48561 Mdot
.49404 .40367 Mdot
.58916 .25973 Mdot
.45981 .43457 Mdot
.62313 .62974 Mdot
.5003 .4127 Mdot
.72494 .35835 Mdot
.42933 .4115 Mdot
.46949 .33368 Mdot
.64335 .58835 Mdot
.43332 .44299 Mdot
.62253 .60407 Mdot
.46838 .35195 Mdot
.63273 .42985 Mdot
.64645 .60375 Mdot
.66281 .33628 Mdot
.71971 .36595 Mdot
.65294 .62447 Mdot
.66068 .47051 Mdot
.6676 .42029 Mdot
.67721 .36769 Mdot
.31452 .4773 Mdot
.55677 .34844 Mdot
.48139 .37383 Mdot
.57643 .62376 Mdot
.45029 .63462 Mdot
.49081 .4349 Mdot
.45062 .34548 Mdot
.453 .42448 Mdot
.28039 .51423 Mdot
.69847 .51782 Mdot
.67266 .43235 Mdot
.60927 .63802 Mdot
.61043 .48696 Mdot
.62666 .56727 Mdot
.50155 .33327 Mdot
.42182 .406 Mdot
.37804 .2653 Mdot
.62509 .69541 Mdot
.3602 .21977 Mdot
.30772 .52996 Mdot
.60983 .5718 Mdot
.62668 .44043 Mdot
.41838 .38369 Mdot
.33845 .5159 Mdot
.62624 .60381 Mdot
.47674 .38093 Mdot
.50086 .3197 Mdot
.31893 .71031 Mdot
.5798 .33784 Mdot
.6976 .35498 Mdot
.63702 .63522 Mdot
.61351 .64849 Mdot
.73936 .39058 Mdot
.71108 .44323 Mdot
.43964 .51189 Mdot
.49042 .36198 Mdot
.65096 .4611 Mdot
.34304 .51217 Mdot
.41479 .23493 Mdot
.44433 .68891 Mdot
.38742 .55895 Mdot
.48677 .37255 Mdot
.57326 .4912 Mdot
.30284 .50614 Mdot
.66612 .45328 Mdot
.4381 .68588 Mdot
.6611 .41102 Mdot
.62653 .57609 Mdot
.57138 .83823 Mdot
.46521 .40247 Mdot
.4423 .37922 Mdot
.44105 .62575 Mdot
.33399 .5272 Mdot
.69866 .43996 Mdot
.42987 .79123 Mdot
.63219 .61701 Mdot
.30086 .75261 Mdot
.33609 .5391 Mdot
.37863 .44859 Mdot
.59892 .63324 Mdot
.44431 .6991 Mdot
.66226 .35408 Mdot
.43895 .67832 Mdot
.45898 .35504 Mdot
.32918 .51128 Mdot
.4329 .64187 Mdot
.37131 .56747 Mdot
.79673 .39577 Mdot
.37318 .44561 Mdot
.48214 .39632 Mdot
.74414 .29911 Mdot
.55235 .80356 Mdot
.33355 .55998 Mdot
.4693 .63536 Mdot
.45727 .36494 Mdot
.44946 .35353 Mdot
.46222 .40543 Mdot
.44193 .64047 Mdot
.7764 .53489 Mdot
.6216 .61877 Mdot
.49706 .357 Mdot
.68162 .46864 Mdot
.61559 .60415 Mdot
.52594 .66107 Mdot
.60668 .62868 Mdot
.28167 .54827 Mdot
.49398 .33136 Mdot
.46426 .72559 Mdot
.58532 .13764 Mdot
.46531 .651 Mdot
.65654 .60807 Mdot
.54534 .37896 Mdot
.56938 .70072 Mdot
.33884 .4938 Mdot
.63325 .61845 Mdot
.44802 .37516 Mdot
.53388 .64515 Mdot
.43922 .21411 Mdot
.60358 .62607 Mdot
.33975 .51684 Mdot
.82641 .59231 Mdot
.48116 .36655 Mdot
.4803 .41578 Mdot
.31774 .52856 Mdot
.24037 .38218 Mdot
.48219 .18333 Mdot
.51351 .38283 Mdot
.45104 .67566 Mdot
.46231 .8546 Mdot
.45397 .34102 Mdot
.62169 .25791 Mdot
.62502 .58888 Mdot
.50071 .66281 Mdot
.3034 .59827 Mdot
.42049 .37835 Mdot
.41266 .77125 Mdot
.45784 .60973 Mdot
.74387 .32087 Mdot
.64145 .5635 Mdot
.69412 .64737 Mdot
.70324 .26539 Mdot
.47076 .62629 Mdot
.38608 .4739 Mdot
.43015 .7743 Mdot
.24522 .33221 Mdot
.79948 .62227 Mdot
.70386 .61201 Mdot
.47265 .2044 Mdot
.46929 .52886 Mdot
.60919 .58171 Mdot
.59351 .4562 Mdot
.51758 .39746 Mdot
.56026 .80266 Mdot
.21247 .52548 Mdot
.20234 .50001 Mdot
.74724 .30161 Mdot
.29182 .44343 Mdot
.7917 .40401 Mdot
.83255 .47302 Mdot
.48717 .26455 Mdot
.66619 .69456 Mdot
.30296 .75825 Mdot
.59575 .19271 Mdot
.4325 .80996 Mdot
.40747 .37763 Mdot
.4849 .56693 Mdot
.62242 .80017 Mdot
.35734 .47125 Mdot
.20775 .43241 Mdot
.63571 .6254 Mdot
.33367 .48134 Mdot
.41979 .76094 Mdot
.28472 .48106 Mdot
.32486 .60002 Mdot
.83496 .58505 Mdot
.80284 .405 Mdot
.22496 .65049 Mdot
.74037 .71892 Mdot
.37905 .27658 Mdot
.19898 .68543 Mdot
.60657 .56242 Mdot
.2744 .51103 Mdot
.72196 .4032 Mdot
.72999 .35222 Mdot
.36356 .71821 Mdot
.47142 .79363 Mdot
.75113 .48592 Mdot
.61112 .3405 Mdot
.31823 .51226 Mdot
.25239 .59115 Mdot
.51224 .64952 Mdot
.33541 .68274 Mdot
.59252 .20505 Mdot
.81774 .5399 Mdot
.44218 .542 Mdot
.48643 .78282 Mdot
.5831 .72449 Mdot
.20706 .35459 Mdot
.64378 .2888 Mdot
.59271 .42639 Mdot
.36119 .59314 Mdot
.72121 .71795 Mdot
.25639 .33828 Mdot
.57056 .26022 Mdot
.72463 .33988 Mdot
.59332 .17793 Mdot
.64369 .76489 Mdot
.42755 .15443 Mdot
.31986 .46923 Mdot
.43678 .39056 Mdot
.26425 .36655 Mdot
.21738 .66083 Mdot
.66688 .48144 Mdot
.78897 .49997 Mdot
.69119 .44652 Mdot
.30551 .55562 Mdot
.44828 .20074 Mdot
.30791 .73664 Mdot
.22425 .68335 Mdot
.6441 .41838 Mdot
.51891 .46795 Mdot
.64361 .85175 Mdot
.76449 .37942 Mdot
.31276 .65045 Mdot
.72736 .25863 Mdot
.53325 .50055 Mdot
.29301 .57563 Mdot
.43636 .63959 Mdot
.69448 .24944 Mdot
.32745 .52119 Mdot
.44567 .13678 Mdot
.67111 .20422 Mdot
.41091 .24993 Mdot
.92178 .46525 Mdot
.74326 .40516 Mdot
.55544 .50054 Mdot
.39377 .63901 Mdot
.63732 .31051 Mdot
.19671 .41643 Mdot
.63731 .399 Mdot
.57399 .70685 Mdot
.7015 .77807 Mdot
.7339 .29689 Mdot
.24846 .71071 Mdot
.52239 .83743 Mdot
.23285 .35408 Mdot
.54474 .55369 Mdot
.56507 .42321 Mdot
.59729 .53427 Mdot
.80352 .55266 Mdot
.60079 .17198 Mdot
.6342 .27477 Mdot
.78764 .73144 Mdot
.70428 .45346 Mdot
.75203 .54245 Mdot
.85253 .5549 Mdot
.62635 .35214 Mdot
.27188 .58558 Mdot
.63927 .24957 Mdot
.55033 .45795 Mdot
.62461 .49399 Mdot
.79748 .52126 Mdot
.28182 .6317 Mdot
.6281 .22528 Mdot
.76413 .66345 Mdot
.36996 .7516 Mdot
.33032 .40272 Mdot
.68364 .28422 Mdot
.29198 .47102 Mdot
.59001 .30697 Mdot
.30118 .59228 Mdot
.80223 .38631 Mdot
.48183 .62405 Mdot
.82193 .39337 Mdot
.487 .18591 Mdot
.55067 .40295 Mdot
.50817 .31365 Mdot
.25472 .48673 Mdot
.60005 .30823 Mdot
.43556 .44832 Mdot
.33741 .72373 Mdot
.82548 .43357 Mdot
.43503 .26741 Mdot
.50608 .62335 Mdot
.53509 .67473 Mdot
.85136 .56976 Mdot
.28487 .36245 Mdot
.71157 .43876 Mdot
.57413 .22272 Mdot
.20364 .37164 Mdot
.60658 .60791 Mdot
.25565 .71351 Mdot
.41361 .69801 Mdot
.43027 .22357 Mdot
.33635 .42804 Mdot
.31505 .28698 Mdot
.82617 .43416 Mdot
.69148 .60931 Mdot
.46944 .19445 Mdot
.6237 .37334 Mdot
.37559 .80125 Mdot
.64675 .68713 Mdot
.43635 .43931 Mdot
.49574 .7921 Mdot
.64923 .42394 Mdot
.31478 .36238 Mdot
.43776 .83462 Mdot
.71273 .57057 Mdot
.48894 .45461 Mdot
.41127 .24571 Mdot
.66466 .64768 Mdot
.41963 .51458 Mdot
.30185 .22994 Mdot
.47941 .32726 Mdot
.72388 .32361 Mdot
.62438 .77238 Mdot
.61805 .29326 Mdot
.79525 .65644 Mdot
.69573 .72233 Mdot
.46596 .14478 Mdot
.72185 .26368 Mdot
.7095 .52544 Mdot
.69966 .26739 Mdot
.77983 .33761 Mdot
.45855 .15198 Mdot
.53819 .33011 Mdot
.42777 .63236 Mdot
.15079 .40117 Mdot
.60386 .6308 Mdot
.74824 .36656 Mdot
.40768 .78543 Mdot
.5678 .55305 Mdot
.27647 .46505 Mdot
.56819 .45073 Mdot
.4688 .53426 Mdot
.32715 .56071 Mdot
.44012 .45146 Mdot
.36524 .20104 Mdot
.51599 .14597 Mdot
.40765 .17108 Mdot
.67775 .76777 Mdot
.6768 .23915 Mdot
.57064 .50402 Mdot
.23539 .66712 Mdot
.57888 .37222 Mdot
.53192 .3887 Mdot
.69933 .41678 Mdot
.74343 .4085 Mdot
.38877 .24668 Mdot
.35745 .68424 Mdot
.36657 .54097 Mdot
.793 .51107 Mdot
.34167 .85461 Mdot
.3417 .31001 Mdot
.33871 .76728 Mdot
.72473 .45803 Mdot
.5987 .29147 Mdot
.79529 .55736 Mdot
.35289 .26128 Mdot
.84162 .47668 Mdot
.33292 .55795 Mdot
.42852 .80363 Mdot
.71747 .60467 Mdot
.40336 .48946 Mdot
.70511 .51411 Mdot
.80408 .42806 Mdot
.43266 .74173 Mdot
.32848 .26068 Mdot
.37003 .64456 Mdot
.26421 .35397 Mdot
.54748 .63696 Mdot
.55833 .73334 Mdot
.41658 .82061 Mdot
.68652 .70921 Mdot
.60079 .25659 Mdot
.51765 .52706 Mdot
.23169 .59378 Mdot
.45137 .60843 Mdot
.60553 .26172 Mdot
.44209 .48825 Mdot
.69884 .27984 Mdot
.50308 .08845 Mdot
.29529 .25135 Mdot
.83749 .61577 Mdot
.78461 .55895 Mdot
.46496 .45224 Mdot
.84837 .50469 Mdot
.38894 .16936 Mdot
.6228 .15707 Mdot
.53214 .75367 Mdot
.63399 .56335 Mdot
.43484 .69845 Mdot
.39632 .19375 Mdot
.77281 .52987 Mdot
.83408 .52239 Mdot
.65976 .27581 Mdot
.4619 .69487 Mdot
.15179 .50387 Mdot
.59304 .18175 Mdot
.35419 .43379 Mdot
.57761 .33306 Mdot
.4804 .4469 Mdot
.20913 .55082 Mdot
.28444 .48295 Mdot
.62867 .72263 Mdot
.58475 .28303 Mdot
.59968 .61033 Mdot
.717 .40932 Mdot
.48682 .79678 Mdot
.5239 .36191 Mdot
.53722 .57472 Mdot
.26649 .52031 Mdot
.63374 .69644 Mdot
.3106 .68434 Mdot
.58211 .15372 Mdot
.72664 .46975 Mdot
.5283 .43429 Mdot
.61954 .28833 Mdot
.70301 .50985 Mdot
.46514 .18236 Mdot
.48401 .65909 Mdot
.76302 .32774 Mdot
.45239 .55821 Mdot
.5886 .30227 Mdot
.21804 .51966 Mdot
.51302 .29852 Mdot
.46262 .34292 Mdot
.71883 .7003 Mdot
.38982 .32076 Mdot
.4012 .54063 Mdot
.53729 .44937 Mdot
.56742 .35056 Mdot
.84823 .51479 Mdot
.649 .5141 Mdot
.56279 .72304 Mdot
.7798 .35334 Mdot
.44188 .64632 Mdot
.31242 .54624 Mdot
.60991 .44184 Mdot
.4574 .80791 Mdot
.41294 .31087 Mdot
.43744 .21456 Mdot
.57961 .53861 Mdot
.72071 .56129 Mdot
.78696 .36958 Mdot
.76075 .33298 Mdot
.19353 .55968 Mdot
.33402 .56174 Mdot
.5079 .27303 Mdot
.44808 .81198 Mdot
.34656 .50463 Mdot
.34259 .74328 Mdot
.32941 .7307 Mdot
.63402 .19579 Mdot
.52822 .59148 Mdot
.71131 .76898 Mdot
.69075 .35081 Mdot
.78161 .50016 Mdot
.30808 .26174 Mdot
.40162 .81044 Mdot
.78959 .42344 Mdot
.29031 .56641 Mdot
.28923 .42286 Mdot
.40967 .37844 Mdot
.23936 .63491 Mdot
.1537 .43332 Mdot
.61772 .45794 Mdot
.375 .46212 Mdot
.76835 .66086 Mdot
.47012 .38975 Mdot
.2652 .27127 Mdot
.46313 .79943 Mdot
.37939 .21664 Mdot
.44633 .70156 Mdot
.52168 .41649 Mdot
.42862 .39364 Mdot
.608 .2356 Mdot
.32365 .60513 Mdot
.68512 .26802 Mdot
.47779 .85051 Mdot
.78555 .62249 Mdot
.2172 .51543 Mdot
.7389 .35632 Mdot
.82023 .54561 Mdot
.57152 .79961 Mdot
.52707 .54274 Mdot
.73956 .43414 Mdot
.639 .35141 Mdot
.72849 .72794 Mdot
.44293 .49251 Mdot
.41886 .60274 Mdot
.37006 .73242 Mdot
.64505 .73596 Mdot
.37055 .23913 Mdot
.50363 .4252 Mdot
.53414 .19041 Mdot
.83269 .4931 Mdot
.19914 .54946 Mdot
.18396 .42207 Mdot
.30428 .2421 Mdot
.36602 .37252 Mdot
.66569 .72975 Mdot
.53655 .80177 Mdot
.38555 .82169 Mdot
.44786 .56141 Mdot
.77585 .43401 Mdot
.63273 .36311 Mdot
.7845 .36351 Mdot
.43944 .62485 Mdot
.36308 .63338 Mdot
.53776 .67491 Mdot
.69524 .26868 Mdot
.28288 .37857 Mdot
.8176 .44396 Mdot
.51198 .50919 Mdot
.47445 .14026 Mdot
.69845 .69857 Mdot
.48359 .52358 Mdot
.62343 .57669 Mdot
.6899 .58988 Mdot
.80173 .48838 Mdot
.70888 .67331 Mdot
.3872 .79953 Mdot
.66407 .6063 Mdot
.6031 .4441 Mdot
.338 .44687 Mdot
.58197 .31275 Mdot
.71629 .70528 Mdot
.61957 .28884 Mdot
.81379 .42026 Mdot
.6223 .23284 Mdot
.52902 .1919 Mdot
.74858 .40548 Mdot
.64645 .81064 Mdot
.31137 .64576 Mdot
.64367 .49535 Mdot
.47192 .79838 Mdot
.75533 .56176 Mdot
.2735 .56167 Mdot
.18569 .27183 Mdot
.57988 .83155 Mdot
.68723 .69527 Mdot
.60185 .17307 Mdot
.69381 .73283 Mdot
.62366 .69715 Mdot
.22092 .38806 Mdot
.37428 .58391 Mdot
.51239 .21018 Mdot
.50066 .37909 Mdot
.36069 .19669 Mdot
.57569 .28994 Mdot
.55999 .14466 Mdot
.83624 .53411 Mdot
.27933 .4612 Mdot
.4927 .33214 Mdot
.60949 .63963 Mdot
.45853 .58217 Mdot
.53424 .2534 Mdot
.25639 .40382 Mdot
.2524 .57089 Mdot
.53864 .64446 Mdot
.59457 .57186 Mdot
.68973 .51173 Mdot
.35539 .53938 Mdot
.77581 .51579 Mdot
.64365 .73283 Mdot
.57904 .64324 Mdot
.4305 .54734 Mdot
.60382 .2722 Mdot
.29171 .59808 Mdot
.35887 .43222 Mdot
.35827 .25693 Mdot
.453 .73227 Mdot
.61726 .63411 Mdot
.3489 .42088 Mdot
.61774 .80592 Mdot
.76821 .64565 Mdot
.59148 .1743 Mdot
.62091 .50152 Mdot
.25534 .42977 Mdot
.60568 .25397 Mdot
.19107 .43171 Mdot
.21611 .45975 Mdot
.62073 .68851 Mdot
.21634 .55872 Mdot
.21578 .42079 Mdot
.438 .76837 Mdot
.65781 .20755 Mdot
.43133 .80839 Mdot
.44564 .81296 Mdot
.5505 .59853 Mdot
.39756 .36026 Mdot
.31376 .4555 Mdot
.67105 .34125 Mdot
.42968 .51432 Mdot
.17979 .6453 Mdot
.55689 .42942 Mdot
.13023 .58693 Mdot
.42175 .68164 Mdot
.20996 .37899 Mdot
.64421 .3589 Mdot
.52814 .52496 Mdot
.50275 .50316 Mdot
.6885 .71334 Mdot
.36073 .61366 Mdot
.62955 .77696 Mdot
.20007 .48269 Mdot
.60934 .56028 Mdot
.49696 .85695 Mdot
.6556 .80971 Mdot
.30935 .41303 Mdot
.52916 .35974 Mdot
.60635 .8222 Mdot
.62412 .56167 Mdot
.37852 .24795 Mdot
.80147 .64833 Mdot
.75011 .64174 Mdot
.38969 .46515 Mdot
.59691 .29626 Mdot
.77743 .43215 Mdot
.75644 .30479 Mdot
.16405 .48301 Mdot
.7965 .52565 Mdot
.43675 .62639 Mdot
.51965 .51285 Mdot
.81468 .46839 Mdot
.32774 .57768 Mdot
.49724 .63276 Mdot
.27039 .57958 Mdot
.17117 .66612 Mdot
.75084 .36645 Mdot
.69038 .2755 Mdot
.27326 .57507 Mdot
.32444 .55164 Mdot
.34672 .59861 Mdot
.273 .58683 Mdot
.73608 .65797 Mdot
.57886 .81442 Mdot
.28539 .59006 Mdot
.30607 .78194 Mdot
.5082 .29332 Mdot
.68231 .62204 Mdot
.28394 .45696 Mdot
.46637 .26845 Mdot
.4672 .69244 Mdot
.55963 .20463 Mdot
.7934 .6241 Mdot
.41334 .65966 Mdot
.72796 .69752 Mdot
.49294 .78407 Mdot
.3849 .44106 Mdot
.39739 .33493 Mdot
.77921 .61639 Mdot
.27437 .40165 Mdot
.2184 .61209 Mdot
.43018 .23377 Mdot
.65513 .59416 Mdot
.81068 .6053 Mdot
.63755 .60555 Mdot
.58796 .42844 Mdot
.38165 .56271 Mdot
.63122 .39906 Mdot
.37159 .21329 Mdot
.67967 .42695 Mdot
.28404 .48723 Mdot
.15632 .44679 Mdot
.34562 .52595 Mdot
.38048 .19171 Mdot
.32177 .28136 Mdot
.20997 .5406 Mdot
.70802 .53238 Mdot
.69783 .56135 Mdot
.22768 .72094 Mdot
.51733 .66271 Mdot
.58774 .5415 Mdot
.26649 .67286 Mdot
.27427 .5043 Mdot
.73307 .4631 Mdot
.6477 .59633 Mdot
.41753 .57123 Mdot
.44696 .7495 Mdot
.47729 .29868 Mdot
.34687 .47089 Mdot
.42229 .56077 Mdot
.54192 .22283 Mdot
.66087 .22289 Mdot
.58919 .59214 Mdot
.13984 .5784 Mdot
.47952 .33517 Mdot
.32795 .39508 Mdot
.84314 .47159 Mdot
.15333 .51053 Mdot
.63046 .53725 Mdot
.66652 .80806 Mdot
.49703 .44207 Mdot
.78878 .57778 Mdot
.32172 .5178 Mdot
.43501 .80565 Mdot
.68717 .44813 Mdot
.62327 .29957 Mdot
.42252 .6896 Mdot
.32454 .26233 Mdot
.64589 .54113 Mdot
.35575 .50363 Mdot
.76822 .60316 Mdot
.48309 .26606 Mdot
.39151 .60351 Mdot
.68016 .5337 Mdot
.31262 .41642 Mdot
.40533 .3248 Mdot
.37496 .51144 Mdot
.70586 .29286 Mdot
.45611 .82356 Mdot
.59055 .15173 Mdot
.25835 .49334 Mdot
.57414 .47932 Mdot
.35846 .73844 Mdot
.74441 .67281 Mdot
.25395 .64007 Mdot
.8356 .44851 Mdot
.57298 .26931 Mdot
.42362 .32449 Mdot
.59265 .26287 Mdot
.44754 .32403 Mdot
.49191 .54663 Mdot
.59254 .73036 Mdot
.19759 .50487 Mdot
.27661 .60917 Mdot
.23758 .36086 Mdot
.22938 .61401 Mdot
.68891 .28179 Mdot
.2182 .54878 Mdot
.63448 .65509 Mdot
.38323 .42098 Mdot
.40493 .65405 Mdot
.67195 .22383 Mdot
.83811 .45564 Mdot
.44082 .61812 Mdot
.73334 .48778 Mdot
.75966 .69224 Mdot
.47354 .31897 Mdot
.59337 .49538 Mdot
.44413 .37128 Mdot
.5638 .32261 Mdot
.15129 .53719 Mdot
.74138 .66108 Mdot
.51578 .45134 Mdot
.73751 .30731 Mdot
.71663 .27638 Mdot
.51241 .13633 Mdot
.32994 .77707 Mdot
.28639 .50651 Mdot
.45558 .16032 Mdot
.24839 .5702 Mdot
.76922 .31784 Mdot
.65387 .68926 Mdot
.86203 .47976 Mdot
.28932 .41884 Mdot
.74339 .6929 Mdot
.21344 .40448 Mdot
.36919 .60022 Mdot
.63303 .76112 Mdot
.57222 .51216 Mdot
.54548 .71472 Mdot
.67294 .74858 Mdot
.44482 .8642 Mdot
.41416 .39576 Mdot
.53434 .78927 Mdot
.39882 .73177 Mdot
.81609 .59509 Mdot
.70823 .65432 Mdot
.51328 .3437 Mdot
.53232 .68957 Mdot
.36035 .23143 Mdot
.61414 .27213 Mdot
.59883 .4528 Mdot
.70388 .65796 Mdot
.477 .22363 Mdot
.57982 .25258 Mdot
.43649 .81343 Mdot
.30407 .41933 Mdot
.46127 .57407 Mdot
.50671 .43696 Mdot
.36089 .48489 Mdot
.68549 .42343 Mdot
.5675 .52158 Mdot
.46834 .35373 Mdot
.58096 .63657 Mdot
.39042 .60058 Mdot
.34261 .21972 Mdot
.28871 .6312 Mdot
.50549 .8106 Mdot
.31187 .46245 Mdot
.40069 .72228 Mdot
.26645 .6575 Mdot
.27508 .27732 Mdot
.73338 .60707 Mdot
.63451 .27517 Mdot
.76794 .37532 Mdot
.63435 .23266 Mdot
.38032 .48446 Mdot
.54011 .16194 Mdot
.47551 .63917 Mdot
.38946 .449 Mdot
.37773 .70001 Mdot
.685 .50507 Mdot
.52512 .45314 Mdot
.74298 .69226 Mdot
.59198 .53455 Mdot
.72904 .35739 Mdot
.64319 .76802 Mdot
.5139 .28184 Mdot
.32247 .439 Mdot
.7543 .32091 Mdot
.59231 .63865 Mdot
.49001 .82439 Mdot
.39038 .6218 Mdot
.70606 .6371 Mdot
.65656 .23362 Mdot
.61294 .17694 Mdot
.47334 .51204 Mdot
.63145 .33774 Mdot
.47419 .4178 Mdot
.42168 .81921 Mdot
.73813 .67115 Mdot
.52369 .47331 Mdot
.52795 .74534 Mdot
.3199 .54441 Mdot
.56663 .75073 Mdot
.48003 .56993 Mdot
.50319 .21747 Mdot
.26575 .50479 Mdot
.20552 .54239 Mdot
.63895 .42502 Mdot
.55401 .4892 Mdot
.46735 .46702 Mdot
.63659 .32592 Mdot
.2505 .71963 Mdot
.5226 .46111 Mdot
.80157 .53194 Mdot
.33124 .42222 Mdot
.43018 .79305 Mdot
.77668 .61365 Mdot
.59734 .68588 Mdot
.36085 .61024 Mdot
.38442 .3935 Mdot
.4515 .73785 Mdot
.44664 .4145 Mdot
.65417 .64828 Mdot
.34966 .49675 Mdot
.81204 .61513 Mdot
.37507 .35511 Mdot
.66128 .3376 Mdot
.53281 .61735 Mdot
.59313 .42217 Mdot
.39351 .65503 Mdot
.85658 .47568 Mdot
.36118 .6021 Mdot
.58156 .27639 Mdot
.52867 .59033 Mdot
.64613 .35491 Mdot
.3035 .30036 Mdot
.66377 .19743 Mdot
.21378 .39899 Mdot
.43724 .53341 Mdot
.20606 .39111 Mdot
.67775 .71335 Mdot
.78878 .66731 Mdot
.57668 .261 Mdot
.53116 .49267 Mdot
.69016 .47409 Mdot
.30911 .70509 Mdot
.53021 .62473 Mdot
.60595 .46641 Mdot
.42214 .57374 Mdot
.4893 .74923 Mdot
.47139 .70539 Mdot
.50687 .4749 Mdot
.75291 .39793 Mdot
.76207 .3526 Mdot
.41634 .78833 Mdot
.44507 .60937 Mdot
.6822 .65646 Mdot
.5067 .22489 Mdot
.87191 .49303 Mdot
.1687 .39655 Mdot
.47202 .41604 Mdot
.40581 .63657 Mdot
.61869 .33052 Mdot
.64401 .63119 Mdot
.27058 .59671 Mdot
.27364 .65634 Mdot
.42162 .65313 Mdot
.60737 .44837 Mdot
.71378 .32931 Mdot
.65707 .72337 Mdot
.5871 .32899 Mdot
.52956 .65855 Mdot
.32596 .22711 Mdot
.65236 .78995 Mdot
.7464 .66716 Mdot
.8682 .42949 Mdot
.40361 .60994 Mdot
.55272 .33531 Mdot
.2961 .33651 Mdot
.66475 .23065 Mdot
.62888 .28989 Mdot
.41364 .22954 Mdot
.56678 .68086 Mdot
.57152 .26237 Mdot
.25534 .54986 Mdot
.74521 .37804 Mdot
.55889 .75136 Mdot
.49153 .536 Mdot
.70106 .56697 Mdot
.55757 .15651 Mdot
.30011 .44656 Mdot
.77927 .38876 Mdot
.33146 .24485 Mdot
.36617 .81748 Mdot
.68462 .2364 Mdot
.71834 .36696 Mdot
.72572 .63227 Mdot
.26794 .36478 Mdot
.43351 .4864 Mdot
.29423 .57082 Mdot
.38361 .24623 Mdot
.42041 .29562 Mdot
.74334 .51193 Mdot
.25602 .32714 Mdot
.60138 .25684 Mdot
.44463 .26899 Mdot
.52606 .49419 Mdot
.35896 .42414 Mdot
.72856 .49138 Mdot
.29495 .58023 Mdot
.41983 .49075 Mdot
.66565 .31604 Mdot
.3405 .41988 Mdot
.37569 .74896 Mdot
.69026 .72869 Mdot
.34726 .81901 Mdot
.77328 .56219 Mdot
.26406 .29174 Mdot
.53402 .38188 Mdot
.52835 .12073 Mdot
.6496 .74555 Mdot
.68211 .68155 Mdot
.60005 .79932 Mdot
.66425 .65387 Mdot
.52489 .30999 Mdot
.44706 .41515 Mdot
.798 .48904 Mdot
.37467 .4595 Mdot
.38109 .27014 Mdot
.30756 .2701 Mdot
.60974 .29597 Mdot
.65995 .27935 Mdot
.67967 .3462 Mdot
.40479 .36342 Mdot
.33934 .531 Mdot
.41691 .16762 Mdot
.44886 .51867 Mdot
.53626 .46557 Mdot
.41845 .45149 Mdot
.26112 .35718 Mdot
.71975 .77191 Mdot
.26087 .48078 Mdot
.65393 .25595 Mdot
.28922 .43843 Mdot
.3929 .4915 Mdot
.24516 .62284 Mdot
.87436 .3652 Mdot
.57463 .11834 Mdot
.35195 .49392 Mdot
.32197 .75617 Mdot
.29056 .44136 Mdot
.6935 .27192 Mdot
.72129 .60184 Mdot
.4954 .75806 Mdot
.45787 .47876 Mdot
.397 .52078 Mdot
.46147 .46282 Mdot
.60964 .78367 Mdot
.68108 .2212 Mdot
.2831 .29036 Mdot
.73976 .31018 Mdot
.46244 .31172 Mdot
.48688 .46589 Mdot
.8886 .48336 Mdot
.81301 .45742 Mdot
.49765 .32692 Mdot
.20287 .43282 Mdot
.56155 .42736 Mdot
.51404 .39538 Mdot
.76706 .47255 Mdot
.4973 .85593 Mdot
.6021 .25276 Mdot
.69522 .26908 Mdot
.27453 .4906 Mdot
.67448 .61481 Mdot
.42137 .68244 Mdot
.48139 .50888 Mdot
.5225 .3317 Mdot
.43285 .64465 Mdot
.54155 .27999 Mdot
.76331 .67592 Mdot
.50042 .603 Mdot
.49101 .84224 Mdot
.83415 .40345 Mdot
.36936 .37844 Mdot
.30607 .69782 Mdot
.44647 .34334 Mdot
.45835 .26976 Mdot
.5128 .24004 Mdot
.56861 .33836 Mdot
.71199 .72743 Mdot
.28711 .19097 Mdot
.52345 .71303 Mdot
.53437 .20779 Mdot
.32789 .55384 Mdot
.43786 .57618 Mdot
.35798 .44672 Mdot
.66385 .66799 Mdot
.59741 .57854 Mdot
.44881 .31811 Mdot
.26242 .49843 Mdot
.42568 .70565 Mdot
.12654 .54243 Mdot
.5362 .36822 Mdot
.25925 .60996 Mdot
.77157 .32421 Mdot
.42947 .23358 Mdot
.30657 .38641 Mdot
.45046 .43051 Mdot
.3371 .69086 Mdot
.53528 .49147 Mdot
.80714 .57839 Mdot
.53781 .19434 Mdot
.7491 .34014 Mdot
.37843 .34863 Mdot
.31462 .43864 Mdot
.51492 .43316 Mdot
.64917 .47657 Mdot
.50043 .65879 Mdot
.7834 .4849 Mdot
.55985 .37808 Mdot
.73895 .27769 Mdot
.67008 .56224 Mdot
.58294 .52134 Mdot
.24779 .50838 Mdot
.50117 .14044 Mdot
.27295 .32928 Mdot
.35084 .46079 Mdot
.28729 .26423 Mdot
.66692 .52204 Mdot
.58438 .31712 Mdot
.60319 .6398 Mdot
.54685 .34273 Mdot
.28037 .47667 Mdot
.27856 .25516 Mdot
.76611 .45606 Mdot
.54658 .70555 Mdot
.55443 .73277 Mdot
.36865 .77719 Mdot
.38872 .61181 Mdot
.85643 .40694 Mdot
.67814 .54211 Mdot
.29504 .24609 Mdot
.46432 .82431 Mdot
.28573 .47046 Mdot
.70094 .7146 Mdot
.55536 .4276 Mdot
.5907 .60524 Mdot
.73854 .317 Mdot
.57886 .42767 Mdot
.45126 .20242 Mdot
.44874 .43968 Mdot
.40853 .20555 Mdot
.66709 .4896 Mdot
.73865 .47229 Mdot
.68081 .70179 Mdot
.26464 .34962 Mdot
.84373 .56075 Mdot
.31186 .70938 Mdot
.85464 .51664 Mdot
.83567 .58016 Mdot
.75945 .32085 Mdot
.41296 .21984 Mdot
.1664 .51082 Mdot
.68884 .68431 Mdot
.77353 .62616 Mdot
.61655 .73071 Mdot
.24689 .37742 Mdot
.69232 .59988 Mdot
.24585 .4988 Mdot
.32411 .60752 Mdot
.41966 .63118 Mdot
.09509 .43565 Mdot
.68406 .30505 Mdot
.26687 .47983 Mdot
.68532 .56638 Mdot
.73144 .28531 Mdot
.27039 .35495 Mdot
.66479 .75643 Mdot
.48356 .56571 Mdot
.43203 .43469 Mdot
.40026 .32316 Mdot
.39983 .78979 Mdot
.67087 .5555 Mdot
.26509 .76942 Mdot
.6306 .79754 Mdot
.52287 .73328 Mdot
.47829 .54908 Mdot
.33278 .47984 Mdot
.23189 .63551 Mdot
.70291 .55322 Mdot
.70153 .73851 Mdot
.7515 .68674 Mdot
.81467 .46557 Mdot
.22694 .71865 Mdot
.43656 .80119 Mdot
.66214 .22602 Mdot
.71339 .69369 Mdot
.35872 .50922 Mdot
.71548 .37594 Mdot
.63611 .57075 Mdot
.57177 .71058 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0X?ooool2o`000:Oooooo000Looooo`03o`000?oooooooooo0:3ooooo0_l0
002Wooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0N_ooool2o`000<gooooo000Looooo`03o`000?oooooo
oooo07[ooooo0_l0003=ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0]oooool2o`00093ooooo
000Looooo`03o`000?oooooooooo0:Sooooo0_l0000=ooooo`;o0000T?ooool001cooooo00?o0000
ooooooooool0Z?ooool2o`0009oooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo08gooooo0_l0000Dooooo`;o00002Oooool2o`0000[ooooo0_l0
002=ooooo`007?ooool00ol0003oooooooooo`2=ooooo`;o00001oooool2o`0000Cooooo0_l00000
0ooooooo0000o`000002ooooo`;o00002Oooool2o`0000[ooooo0_l0002=ooooo`007?ooool00ol0
003oooooooooo`2Fooooo`;o00001?ooool2o`000003ooooool0003o000000cooooo0_l0002Joooo
o`007?ooool00ol0003oooooooooo`2=ooooo`;o00001Oooool2o`0000kooooo0_l00007ooooo`;o
00000oooool4o`0009?ooooo000Looooo`03o`000?oooooooooo08gooooo0_l00005ooooo`;o0000
3_ooool2o`0000cooooo1?l0002Cooooo`007?ooool2o`0009;ooooo0_l0000Vooooo`;o000000?o
ooooo`000?l000001_ooool2o`0008?ooooo000Looooo`03o`000?oooooooooo087ooooo0_l00004
ooooo`;o00002?ooool2o`0000_ooooo0_l0000Aooooo`;o00000_ooool2o`0000;ooooo1Ol00006
ooooo`;o0000Poooool001cooooo00?o0000ooooooooool0MOooool2o`0000[ooooo0_l00004oooo
o`;o00005Oooool2o`00017ooooo0_l00002ooooo`;o00001?ooool2o`0000[ooooo0_l00020oooo
o`007?ooool00ol0003oooooooooo`1eooooo`;o00006Oooool2o`0001[ooooo0_l0000Iooooo`;o
0000P?ooool001cooooo00?o0000ooooooooool0T?ooool2o`0001[ooooo0_l000000ooooooo0000
o`000004ooooo`;o00002?ooool2o`0008Sooooo000Looooo`03o`000?oooooooooo08Cooooo0_l0
000Jooooo`;o00003Oooool2o`0000Cooooo0ol00007ooooo`;o0000R?ooool001cooooo00?o0000
ooooooooool0Noooool2o`0000Cooooo0_l000000ooooooo0000o`00000Jooooo`;o00001oooool2
o`0000_ooooo0_l00007ooooo`;o0000R?ooool001cooooo00?o0000ooooooooool0Noooool2o`00
00Cooooo0_l0000Gooooo`;o00003Oooool2o`00017ooooo0_l000001?oooooo0000o`000?l00027
ooooo`007?ooool00ol0003oooooooooo`2:ooooo`;o00003_ooool2o`0001oooooo1?l000001?oo
oooo0000o`000?ooool2o`0008Cooooo000Looooo`03o`000?oooooooooo08[ooooo0ol00002oooo
o`;o0000:_ooool4o`0000Cooooo0_l00002ooooo`;o0000P?ooool001cooooo00?o0000oooooooo
ool0Roooool2o`0000;ooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l00009oooo
o`;o00005_ooool3o`000003ooooool0003o000000Gooooo0_l00020ooooo`007?ooool00ol0003o
ooooooooo`2;ooooo`;o000000?oooooo`000?l000000oooool2o`000004ooooool0003o0000oooo
o`Go00001_ooool4o`00013ooooo0_l00003ooooo`;o000000?oooooo`000?l000004?ooool2o`00
07Gooooo000Looooo`03o`000?oooooooooo08_ooooo0_l000000ooooooo0000o`00000:ooooo`Co
00002?ooool2o`000004ooooool0003o0000o`0000Wooooo0_l000000ooooooo0000o`000002oooo
o`?o00004oooool2o`0007Gooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44
ooooo`Go00001_ooool00ol0003oooooooooo`1Jooooo`;o00007?ooool2o`0000?ooooo0_l0000A
ooooo`;o00003Oooool3o`0000Kooooo1?l00004ooooo`;o00000oooool2o`000003ooooool0003o
000000Ko0000ROooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo05[ooooo0_l0000Eooooo`;o0000
1Oooool2o`0000?ooooo0_l0000Aooooo`;o00000oooool2o`0000?ooooo0_l00003ooooo`?o0000
00?oooooo`000?l000000oooool5o`0000?ooooo0_l00006ooooo`Co00000_ooool2o`0000[ooooo
0_l000000ooooooo0000o`000006ooooo`;o0000L_ooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo077ooooo0_l0
000Aooooo`;o00003oooool2o`0000?ooooo0_l00007ooooo`;o00000_ooool2o`000004ooooool0
003o0000o`0000?ooooo0ol00003ooooo`;o00004_ooool2o`000003ooooool0003o000000Gooooo
0ol0001booooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ
8B7ok^k^00Kooooo0ol0001Sooooo`;o00003_ooool2o`0000oooooo0_l000000ooooooo0000o`00
0005ooooo`?o00005_ooool2o`0000Sooooo1?l000001?oooooo0000o`000?l00008ooooo`;o0000
1oooool2o`0000Sooooo0_l0001cooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooooooo
o`0<ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0Hoooool2o`0000kooooo0_l0
000<ooooo`;o00001?ooool2o`0000Gooooo0ol00005ooooo`?o00001Oooool2o`00017ooooo1?l0
0002ooooo`;o00001?ooool2o`0000;ooooo0_l00005ooooo`;o00003?ooool4o`0006oooooo0000
0ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`21ooooo`;o00002oooool4o`0000Cooooo0ol00005ooooo`Co00001_ooool4
o`000003ooooool0003o000000?ooooo0_l00009ooooo`;o00000_ooool2o`0000Gooooo0_l00008
ooooo`So0000Koooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooo
oonHV9So410@00Kooooo00?o0000ooooooooool0K?ooool2o`0001Kooooo0_l00008ooooo`Go0000
3Oooool2o`000003ooooool0003o000000?ooooo1?l000000ooooooo0000o`00000Booooo`;o0000
3oooool4o`0000?ooooo0_l0001^ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1/ooooo`;o00001oooool2o`00
00Cooooo0_l00007ooooo`;o00001?ooool3o`0000;ooooo1?l0000@ooooo`;o00001Oooool2o`00
00_ooooo0_l00008ooooo`;o00001Oooool2o`0000oooooo0_l0001^ooooo`007?ooool00ol0003o
ooooooooo`1eooooo`;o000000Coooooo`000?l0003ooooo0_l00006ooooo`Go00000_ooool3o`00
01?ooooo0_l00008ooooo`;o00002oooool2o`000003ooooool0003o000000Gooooo0ol00004oooo
o`;o0000Ooooool001cooooo00?o0000ooooooooool0K?ooool2o`0000?ooooo0_l00005ooooo`;o
00001_ooool5o`000003ooooool0003o000001Sooooo0_l000000ooooooo0000o`00000Eooooo`;o
00001_ooool3o`0001Cooooo0_l0001^ooooo`007?ooool00ol0003oooooooooo`1/ooooo`;o0000
0oooool2o`0000cooooo1Ol00004ooooo`;o00002oooool4o`0000[ooooo0_l00007ooooo`;o0000
2Oooool2o`0000[ooooo1?l0000<ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo
0000o`00001[ooooo`007?ooool00ol0003oooooooooo`1Vooooo`;o00001oooool4o`0000Kooooo
0_l00004ooooo`;o00001oooool2o`0000_ooooo1?l00008ooooo`;o00002Oooool2o`0000Wooooo
0_l0000<ooooo`;o000000?oooooo`000?l000001_ooool2o`000004ooooool0003o0000ooooo`;o
00001?ooool2o`0006_ooooo000Looooo`03o`000?oooooooooo05kooooo0_l00004ooooo`Co0000
1_ooool5o`0000Kooooo0_l00008ooooo`;o00004?ooool2o`0000[ooooo1Ol00005ooooo`;o0000
6oooool2o`0000Kooooo0_l000001?oooooo0000o`000?l00007ooooo`;o0000J_ooool001cooooo
00?o0000ooooooooool0G_ooool2o`0000Cooooo0_l00008ooooo`;o000000?oooooo`000?l00000
0oooool2o`0000Kooooo0_l00003ooooo`;o00000oooool2o`0000;ooooo0_l00007ooooo`;o0000
2_ooool5o`0000Gooooo0_l00003ooooo`?o00004oooool2o`0000;ooooo1?l00003ooooo`;o0000
00?oooooo`000?l000001?ooool2o`000003ooooool0003o000006[ooooo000Looooo`03o`000?oo
oooooooo077ooooo0_l00003ooooo`;o00001_ooool2o`0000?ooooo0_l000000ooooooo0000o`00
0002o`0000;ooooo0_l0000:ooooo`;o00004oooool2o`000005ooooool0003o0000o`000?ooool0
0ol0000;ooooo`;o00000_ooool8o`0000?ooooo0_l00007ooooo`?o0000K?ooool001cooooo00?o
0000ooooooooool0JOooool2o`0000?ooooo0_l00005ooooo`;o00003?ooool2o`000003ooooool0
003o000000Cooooo0_l0000:ooooo`;o00002Oooool2o`0000Oooooo0ol00003ooooo`Go00002?oo
ool2o`000003ooooool0003o000000Cooooo1?l00009ooooo`;o000000Coooooo`000?l0003ooooo
0_l0001/ooooo`007?ooool00ol0003oooooooooo`1Oooooo`;o00002?ooool2o`0000?ooooo0_l0
0004ooooo`Go00001_ooool2o`0000oooooo0_l000000ooooooo0000o`00000>ooooo`;o00001ooo
ool3o`0000?ooooo0_l000000ooooooo0000o`000008ooooo`?o00002?ooool2o`0000Wooooo0_l0
00000ooooooo0000o`00001_ooooo`007?ooool00ol0003oooooooooo`1Looooo`;o000000?ooooo
o`000?l000000oooool2o`0000;ooooo0_l00009ooooo`?o000000?oooooo`000?l000001?l00002
ooooo`;o000000?oooooo`000?l000003?ooool2o`000003ooooool0003o000002Gooooo0_l00003
ooooo`?o00002?ooool2o`0000Sooooo0_l00005ooooo`;o0000K?ooool001cooooo00?o0000oooo
ooooool0G?ooool2o`0000Gooooo0ol00002ooooo`Co00001oooool2o`0000;ooooo1_l00005oooo
o`;o00004Oooool2o`0000;ooooo0_l0000Oooooo`;o00000oooool2o`0000Gooooo0_l00006oooo
o`;o00001?ooool2o`0000Gooooo0_l0001/ooooo`007?ooool2o`00057ooooo0_l0000:ooooo`;o
00000_ooool2o`000003ooooool0003o000000Gooooo0_l00007ooooo`;o00000_ooool6o`000003
ooooool0003o000000;ooooo0_l000000ooooooo0000o`00000:ooooo`;o00000_ooool2o`0000;o
oooo0_l0000Booooo`?o00001_ooool2o`0000?ooooo0_l00009ooooo`;o00000_ooool6o`0000Ko
oooo0_l00006ooooo`;o0000JOooool001cooooo00?o0000ooooooooool0C_ooool4o`0000Gooooo
0_l00003ooooo`;o00000_ooool2o`00017ooooo0_l00004ooooo`;o00000oooool2o`0000;ooooo
0_l000000ooooooo0000o`00000:ooooo`;o00004Oooool2o`0000Cooooo0_l000001?oooooo0000
o`000?l00005ooooo`?o000000?oooooo`000?l000000_l00003ooooo`?o00000_ooool3o`0000;o
oooo1_l00006ooooo`;o00001Oooool3o`0006Wooooo000Looooo`03o`000?oooooooooo04kooooo
0_l00007ooooo`;o00006?ooool2o`0000Sooooo1?l0000Uooooo`;o00001?ooool2o`0000?ooooo
1?l00002ooooo`;o00000_ooool2o`0000Cooooo1?l00002ooooo`Co00000oooool4o`000003oooo
ool0003o000000Cooooo0_l00004ooooo`;o0000J_ooool001cooooo00?o0000ooooooooool0HOoo
ool2o`0000Cooooo0_l00006ooooo`Co00002?ooool4o`0000?ooooo0_l00002ooooo`;o00008_oo
ool4o`000003ooooool0003o000000;o00000oooool4o`0000;ooooo0_l000001?oooooo0000o`00
0?l00004ooooo`?o00000oooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0000oo
oooo0_l0001Oooooo`007?ooool00ol0003oooooooooo`1Jooooo`;o00001?ooool3o`0000?ooooo
0ol00006ooooo`;o000000?oooooo`000?l000003_ooool2o`0000;ooooo0_l0000:ooooo`;o0000
1_ooool2o`0000kooooo1?l00008ooooo`Wo00000_ooool2o`0000Cooooo0_l0000;ooooo`;o0000
4Oooool3o`0005oooooo000Looooo`03o`000?oooooooooo05[ooooo0_l00004ooooo`;o00001?oo
ool2o`0000Oooooo0_l000000ooooooo0000o`000003ooooo`;o00004Oooool2o`0000Kooooo0_l0
0005ooooo`?o00003_ooool2o`0000Sooooo1?l00002ooooo`;o000000?oooooo`000?l000000_oo
ool4o`0000;ooooo0_l00003ooooo`;o00002?ooool2o`0000Oooooo1Ol00003ooooo`;o0000H?oo
ool001cooooo00?o0000ooooooooool0F?ooool4o`0000Cooooo0_l0000;ooooo`Co00001_ooool3
o`000003ooooool0003o000000Oooooo2?l000000ooooooo0000o`000002ooooo`;o000000?ooooo
o`000?l000000oooool2o`0000oooooo0_l000000ooooooo0000o`000005ooooo`Co00001Oooool2
o`0000Cooooo0_l00007ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00000ooo
ool2o`000003ooooool0003o000000Co0000IOooool001cooooo00?o0000ooooooooool0>Oooool2
o`0001Oooooo0_l00004ooooo`?o00001Oooool2o`0000_ooooo0_l00009ooooo`;o000000?ooooo
o`000?l000001oooool6o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000002oooool2
o`0000[ooooo0ol00006ooooo`;o00002?ooool2o`0000;ooooo0_l00009ooooo`;o000000?ooooo
o`000?l000001_ooool6o`0006Wooooo000Looooo`03o`000?oooooooooo03Wooooo0_l0000Goooo
o`;o00001Oooool2o`000003ooooool0003o0000017ooooo0_l00006ooooo`;o00003_ooool2o`00
01Sooooo0_l00006ooooo`;o00000oooool2o`0000Gooooo0_l000001?oooooo0000o`000?l00005
ooooo`;o00000_ooool3o`0000;ooooo0ol00006ooooo`?o00001Oooool5o`0000Kooooo0_l00007
ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0E_ooool2o`0000Cooooo0_l00005oooo
o`;o00002Oooool5o`0000Cooooo0_l0000Tooooo`;o00002_ooool2o`000003ooooool0003o0000
00Oooooo0_l000001?oooooo0000o`000?l0000:ooooo`;o00000_ooool3o`0000Kooooo0ol00007
ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Gooooo1?l0001Iooooo`007?ooool00ol0
003oooooooooo`1Fooooo`;o00002oooool4o`0000Oooooo1Ol0000Zooooo`;o00001?ooool2o`00
00Oooooo0_l0000<ooooo`;o00000_ooool2o`0001?ooooo0_l00007ooooo`;o000000?oooooo`00
0?l000002oooool2o`0005_ooooo000Looooo`03o`000?oooooooooo06?ooooo1?l00007ooooo`;o
00009_ooool2o`0000Kooooo0_l00003ooooo`;o00001oooool2o`0000Kooooo0_l00004ooooo`;o
00000_ooool2o`0000oooooo0ol00008ooooo`Co00003?ooool2o`0005gooooo000Looooo`03o`00
0?oooooooooo04gooooo0ol0000Cooooo`;o00002Oooool2o`0002Kooooo0_l00003ooooo`Go0000
3?ooool2o`0000Kooooo0_l00004ooooo`Oo00001?ooool2o`0000Kooooo1Ol00008ooooo`;o0000
3_ooool2o`0005gooooo000Looooo`03o`000?oooooooooo04gooooo0ol00002ooooo`;o00001?oo
ool2o`0000Wooooo0_l0000fooooo`?o00002oooool2o`0000cooooo0_l00002ooooo`Ko00001?oo
ool5o`0000?ooooo0_l000000ooooooo0000o`00001gooooo`007?ooool00ol0003oooooooooo`12
ooooo`;o00002Oooool2o`0000?ooooo0_l00004ooooo`;o00003_ooool2o`0003;ooooo0_l00003
ooooo`;o00001_ooool2o`0000cooooo0_l00002ooooo`;o00000_ooool2o`0000Cooooo1Ol00002
ooooo`;o00000_ooool4o`0000[ooooo1Ol00009ooooo`;o0000Foooool001cooooo00?o0000oooo
ooooool0@_ooool2o`0000Wooooo0_l0000Iooooo`;o00006oooool2o`0000kooooo0_l0000:oooo
o`Co00001?ooool2o`0000_ooooo0_l00006ooooo`;o00000_ooool2o`000003ooooool0003o0000
00Gooooo0_l00004ooooo`;o00001Oooool2o`0000?ooooo1Ol00008ooooo`?o0000Foooool001co
oooo0_l0001Dooooo`;o00002_ooool2o`0002Cooooo1?l00006ooooo`;o00001?ooool4o`0000[o
oooo0_l00007ooooo`;o00002?ooool6o`0000;ooooo0ol000000ooooooo0000o`000003ooooo`;o
00003_ooool4o`0000Oooooo0_l00007ooooo`;o000000Coooooo`000?l0003o0000F?ooool001co
oooo00?o0000ooooooooool0Doooool2o`0000[ooooo0_l0000Sooooo`;o000000?oooooo`000?l0
00001_ooool2o`0000Gooooo1?l0000Booooo`;o00002Oooool6o`0000;ooooo0_l00006ooooo`;o
000000?oooooo`000?l000002oooool2o`0000Wooooo0_l0000:ooooo`?o0000F?ooool001cooooo
00?o0000ooooooooool0DOooool4o`00013ooooo0_l0000Mooooo`;o00004_ooool2o`0001kooooo
1_l00005ooooo`;o000000?oooooo`000?l000000_ooool2o`0000_ooooo0_l000000ooooooo0000
o`00000@ooooo`;o00001?ooool2o`0005Gooooo000Looooo`03o`000?oooooooooo057ooooo1?l0
000=ooooo`;o000000?oooooo`000?l000001?ooool2o`0001Gooooo0_l0000Dooooo`;o00001?oo
ool2o`0000;ooooo0_l00002ooooo`?o00003oooool2o`0000;ooooo0_l000000ooooooo0000o`00
0002ooooo`;o000000?oooooo`000?l000000oooool2o`0000Kooooo0_l00005ooooo`;o00001?oo
ool2o`0000[ooooo0_l00004ooooo`;o0000EOooool001cooooo00?o0000ooooooooool0??ooool2
o`0002Cooooo0_l00007ooooo`;o00005Oooool2o`0000kooooo2?l00004ooooo`;o000000Gooooo
o`000?l0003o0000ooooo`04o`0000[ooooo0_l00004ooooo`;o00001?ooool2o`0000[ooooo0_l0
0006ooooo`;o00002oooool3o`0000Wooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`0l
ooooo`;o00006oooool2o`0003Oooooo1ol00003ooooo`Oo00000_ooool2o`0000cooooo0_l00004
ooooo`;o00006?ooool3o`000003ooooool0003o000000Oooooo0ol00009ooooo`?o00001oooool2
o`00057ooooo000Looooo`03o`000?oooooooooo05Wooooo0_l00005ooooo`;o00000oooool2o`00
02Oooooo0_l000001?oooooo0000o`000?l00002ooooo`;o000000Coooooo`000?l0003ooooo1_l0
0005ooooo`;o00004Oooool2o`0000gooooo0_l00009ooooo`;o000000?oooooo`000?l000002?oo
ool2o`0000Wooooo0ol00007ooooo`;o0000DOooool001cooooo00?o0000ooooooooool0H?ooool2
o`0000?ooooo0_l0000Dooooo`;o000000?oooooo`000?l000002oooool5o`000003ooooool0003o
000000Go000000?oooooo`000?l000000_ooool5o`000003ooooool0003o000000Oo00001oooool2
o`0000Gooooo0_l0000=ooooo`;o00002Oooool2o`0000_ooooo0_l0000;ooooo`;o000000?ooooo
o`000?l000000_l000000ooooooo0000o`00001Aooooo`007?ooool00ol0003oooooooooo`1=oooo
o`;o00002oooool4o`0000;ooooo0_l00007ooooo`;o00004?ooool2o`000003ooooool0003o0000
00;o00001?ooool3o`0000;ooooo1Ol00002ooooo`Co00002?ooool3o`000003ooooool0003o0000
00?o00000_ooool3o`0000Gooooo1?l0000;ooooo`;o00002Oooool2o`0000kooooo0_l0000:oooo
o`;o00001Oooool2o`000003ooooool0003o000000;o00000_ooool2o`00053ooooo000Looooo`03
o`000?oooooooooo02cooooo0_l0000Oooooo`Co00001?ooool2o`0000?ooooo1?l00009ooooo`Co
00005?ooool3o`0000Cooooo0ol00005ooooo`;o00000oooool3o`0000;ooooo2Ol000001?oooooo
0000o`000?l0000<ooooo`;o00002?ooool2o`0000?ooooo0_l00007ooooo`Co00003Oooool3o`00
00Oooooo0_l000001?oooooo0000o`000?ooool2o`0000Sooooo0_l000000ooooooo0000o`00001@
ooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00007_ooool2o`000003ooooool0003o0000
00?ooooo0ol0000@ooooo`;o00008oooool2o`0000Kooooo0_l00002ooooo`co00000_ooool4o`00
0003ooooool0003o000000Cooooo0_l00008ooooo`;o00002?ooool2o`0000;ooooo0_l0000?oooo
o`;o00000oooool2o`0000?ooooo0_l00004ooooo`;o00002?ooool2o`0005?ooooo000Looooo`03
o`000?oooooooooo03Oooooo0_l0000Booooo`?o00001_ooool5o`0002Cooooo0_l0000=ooooo`;o
00000_ooool7o`000004ooooool0003o0000ooooo`Wo00000_ooool9o`000004ooooool0003o0000
o`0000Gooooo0_l0000;ooooo`;o00002?ooool2o`0000gooooo1Ol0000@ooooo`;o0000E?ooool0
01cooooo00?o0000ooooooooool0=Oooool4o`0001;ooooo0_l00003ooooo`;o00000oooool4o`00
00?ooooo0_l0000Oooooo`;o00004Oooool7o`000004ooooool0003o0000ooooo`[o000000?ooooo
o`000?l000001?l000001?oooooo0000o`000?ooool2o`0000?ooooo1_l0000>ooooo`;o00001?oo
ool2o`0000;ooooo0ol00004ooooo`;o00000_ooool2o`000003ooooool0003o000000Oooooo0_l0
0007ooooo`;o00001?ooool2o`0004kooooo000Looooo`03o`000?oooooooooo03Gooooo0_l0000I
ooooo`;o00001Oooool2o`0000?ooooo0_l0000Jooooo`;o00003oooool3o`0000?ooooo1Ol00003
ooooo`;o000000?oooooo`000?l000002Ol000001Ooooooo0000o`000?l0003ooooo00;o000000?o
ooooo`000?l000001_ooool6o`0000Sooooo0_l00004ooooo`;o00002?ooool5o`0000;ooooo0_l0
000<ooooo`Co00001?ooool2o`0000Gooooo1?l00002ooooo`;o0000B_ooool001cooooo00?o0000
ooooooooool0Eoooool2o`0001oooooo0_l00009ooooo`;o00001?ooool3o`000003ooooool0003o
000001Ko00000_ooool2o`0000Cooooo0ol00003ooooo`;o00003_ooool2o`0000gooooo0_l00002
ooooo`;o00004?ooool2o`0000Gooooo0ol00005ooooo`;o00001?ooool2o`0004[ooooo000Loooo
o`03o`000?oooooooooo07Sooooo0_l00009ooooo`;o00001ooooolJo`0000;ooooo2?l00003oooo
o`;o00000oooool2o`0000Gooooo0_l000000ooooooo0000o`00000:ooooo`;o00000_ooool3o`00
00Cooooo0_l00002ooooo`;o00000_ooool4o`0000[ooooo0_l000000ooooooo0000o`00001Eoooo
o`007?ooool2o`0005?ooooo0_l0000Aooooo`;o000000?oooooo`000?l000003Oooool2o`0000Wo
oooo0_l00002ooooo`;o00001?oooolRo`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l0
00001Oooool2o`000003ooooool0003o000000[ooooo0_l00003ooooo`;o00001?ooool2o`0000;o
oooo0_l00002ooooo`Co00003Oooool2o`0005Gooooo000Looooo`03o`000?oooooooooo04gooooo
0_l00003ooooo`?o00000_ooool2o`0000[ooooo1?l000000ooooooo0000o`00000=ooooo`;o0000
2?ooool4o`000003ooooool0003o000000Cooooo2_l000000ooooooo0000o`00000Ao`0000Cooooo
1Ol00002ooooo`;o00000_ooool2o`0000gooooo0_l00002ooooo`;o000000?oooooo`000?l00000
3?ooool2o`0000;ooooo0_l00006ooooo`;o00002Oooool2o`0000?ooooo0_l000000ooooooo0000
o`00001;ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00001_ooool2o`0000?ooooo0_l0
0003ooooo`Oo00002_ooool2o`00017ooooo0_l00009ooooo`Co00002?oooolKo`000003ooooool0
003o000000?ooooo0ol00008ooooo`;o00003Oooool3o`000003ooooool0003o000000?o00000_oo
ool4o`0000Sooooo1?l00006ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o00000ooo
ool2o`000003ooooool0003o000004_ooooo000Looooo`03o`000?oooooooooo043ooooo0_l00006
ooooo`;o00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0001kooooo0_l0000C
ooooo`Co000000?oooooo`000?l000003ol000001Ooooooo0000o`000?l0003ooooo00Go00000ooo
ool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000Cooooo0_l00007ooooo`Co0000
0_ooool3o`0000?ooooo1?l000000ooooooo0000o`000003ooooo`Co00001oooool3o`000003oooo
ool0003o000000;o0000FOooool001cooooo00?o0000ooooooooool0BOooool2o`0000;ooooo0ol0
00000ooooooo0000o`000002ooooo`;o00000_ooool2o`0000Sooooo0ol0000<ooooo`;o00002Ooo
ool2o`0000cooooo9?l00002ooooo`Go00000_ooool4o`0000;ooooo0_l00004ooooo`Go000000Co
ooooo`000?l0003ooooo0_l00009ooooo`;o00000oooool2o`0000Wooooo0ol0001Nooooo`007?oo
ool00ol0003oooooooooo`0`ooooo`;o00004oooool2o`0000;ooooo0_l00003ooooo`;o00000ooo
ool4o`0000;ooooo0_l00008ooooo`?o000000?oooooo`000?l000002Oooool2o`0000Wooooo0_l0
00000ooooooo0000o`000002ooooo`;o00000_ooool/o`0000Kooooo0_l00008ooooo`Co00000_oo
ool2o`0000cooooo0_l00005ooooo`;o00001Oooool3o`0001;ooooo0_l0000Kooooo`;o0000;ooo
ool001cooooo00?o0000ooooooooool0<?ooool2o`0000Wooooo0_l00008ooooo`;o00000_ooool2
o`000004ooooool0003o0000ooooo`;o000000Coooooo`000?l0003o00004_ooool2o`0000oooooo
0_l00006ooooo`;o00000_ooool2o`0000;ooooo3?l000000ooooooo0000o`00000Fo`000003oooo
ool0003o000000;o00001oooool2o`0001Oooooo0_l000001?oooooo0000o`000?ooool3o`0000Co
oooo0_l00003ooooo`Go00001_ooool3o`0000Wooooo0_l0000Kooooo`;o0000;oooool001cooooo
00?o0000ooooooooool0=?ooool2o`0000Gooooo0_l000000ooooooo0000o`000009ooooo`;o0000
00Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00000=ooooo`Co00000_ooool2o`0000[o
oooo0_l00003ooooo`;o000000?oooooo`000?l000001?ooool3o`0000Oooooo9_l000000ooooooo
0000o`000004ooooo`Go00005Oooool2o`000004ooooool0003o0000ooooo`?o00002Oooool4o`00
00Oooooo1Ol00008ooooo`;o0000Boooool001cooooo00?o0000ooooooooool09Oooool2o`0000go
oooo0_l00005ooooo`;o000000?oooooo`000?l000008Oooool4o`0000;ooooo0_l0000:ooooo`;o
00000oooool2o`000004ooooool0003o0000ooooo`;o000000Coooooo`000?l0003o00001_ooool2
o`000003ooooool0003o000002;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o
000000[ooooo0_l0000?ooooo`?o00003oooool2o`0000Kooooo0_l00002ooooo`;o00001?ooool2
o`0004_ooooo000Looooo`03o`000?oooooooooo02Gooooo0_l0000Fooooo`;o00002_ooool5o`00
00[ooooo0_l0000:ooooo`?o000000?oooooo`000?l000001oooool2o`000003ooooool0003o0000
00Sooooo0_l000000ooooooo0000o`000002ooooo`;o00000_oooolXo`000003ooooool0003o0000
00;o00000_ooool4o`0000_ooooo0_l0000?ooooo`;o00000_ooool2o`0000Oooooo0_l00003oooo
o`;o00000_ooool2o`0000Kooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`0mooooo`;o
000000?oooooo`000?l000001oooool5o`0000[ooooo0_l0000:ooooo`?o000000?oooooo`000?l0
00001oooool2o`000003ooooool0003o000000Oooooo0_l00002ooooo`;o000000Coooooo`000?l0
003o00000_oooolXo`000003ooooool0003o000000So00008?ooool2o`0000Oooooo0_l00003oooo
o`;o00000_ooool2o`0000Gooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`0Vooooo`;o
00006?ooool2o`000003ooooool0003o000000?o000000Coooooo`000?l0003o00002oooool2o`00
0003ooooool0003o000001[ooooo0_l00005ooooo`;o00001Oooool3o`000003ooooool0003o0000
02[o000000Coooooo`000?l0003o0000=oooool3o`0000?ooooo0_l00002ooooo`;o0000C_ooool0
01cooooo00?o0000ooooooooool09_ooool2o`0001_ooooo1Ol00002ooooo`;o00002oooool2o`00
0003ooooool0003o000000Cooooo0_l00006ooooo`;o00003?ooool2o`000004ooooool0003o0000
ooooo`;o00001_ooool3o`000003ooooool0003o000001So000000?oooooo`000?l000002?l00000
0ooooooo0000o`000004o`0003_ooooo0ol00007ooooo`;o00001_ooool2o`0004Kooooo000Loooo
o`03o`000?oooooooooo04Cooooo0_l0000Jooooo`;o00001_ooool2o`0000oooooo0_l000000ooo
oooo0000o`000006ooooobgo000000Coooooo`000?l0003ooooo0_l00008ooooo`;o00007oooool2
o`0000[ooooo0_l0000;ooooo`;o00001_ooool2o`0004Kooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003ooooooooo
o`0mooooo`Co00000oooool2o`0003?ooooo0_l000000ooooooo0000o`000002o`0000Cooooo;Ol0
00001?oooooo0000o`000?ooool2o`0000Sooooo0_l0000Oooooo`;o00000_ooool2o`0000Kooooo
0_l0000;ooooo`;o00001?ooool2o`0000Kooooo0_l00010ooooo`0000KoooooogMgMonHV9Sooooo
oiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03?o
oooo0_l00008ooooo`Co00009_ooool2o`00013ooooo0_l00003ooooo`;o000000?oooooo`000?l0
00000ol000000ooooooo0000o`00000No`000003ooooool0003o000000Ko00000_ooool2o`0000;o
oooo0_l0000/ooooo`;o00001?ooool2o`00017ooooo1?l00006ooooo`;o0000@?ooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo00?o0000ooooooooool0
:oooool2o`0000Kooooo0_l00005ooooo`;o00000_ooool2o`0000;ooooo0_l0000Sooooo`;o0000
0_ooool2o`0001Cooooo2?l00002ooooobGo00000_ooool3o`000003ooooool0003o000000Wooooo
0_l00006ooooo`Co00005Oooool2o`0000Kooooo0ol00004ooooo`;o00000_ooool2o`0000Kooooo
1?l00018ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04odA4A?oM
gMgoooooo`0000Oooooo0ol0000[ooooo`Co00002oooool2o`000004ooooool0003o0000o`0000;o
oooo0_l0000<ooooo`;o00000oooool2o`0000cooooo0_l00003ooooo`;o000000?oooooo`000?l0
00003?ooool2o`0000Wooooo7Ol000000ooooooo0000o`00000Ao`0000cooooo0_l00006ooooo`Co
00005Oooool2o`0000?ooooo0_l00002ooooo`;o00001?ooool2o`0000;ooooo0_l00009ooooo`;o
0000Aoooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?oMgMgoEEEE
ooooool00007ooooo`03o`000?oooooooooo02gooooo0_l0000>ooooo`;o00000oooool2o`0000co
oooo0_l00003ooooo`;o00003?ooool3o`0000;ooooo0_l0000;ooooo`;o00000_ooool2o`0000[o
oooo6ol000000ooooooo0000o`00000Bo`0000Cooooo0_l0000@ooooo`;o00006_ooool2o`0000Go
oooo0ol0000<ooooo`;o000000Coooooo`000?l0003o00002?ooool2o`0003cooooo00000ooooooo
410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oMgMgolc<c?l000001oooool00ol0003o
ooooooooo`0`ooooo`;o00004?ooool2o`0000cooooo1?l00007ooooo`;o00001oooool2o`0000oo
oooo0_l0000>ooooo`;o000000?oooooo`000?l000007_l000000ooooooo0000o`000003o`000003
ooooool0003o000000Co00001?ooool2o`00013ooooo0_l0000Hooooo`;o00001oooool3o`0000_o
oooo0ol00002ooooo`;o00002?ooool2o`0000?ooooo1?l0000eooooo`0000KoooooogMgMonHV9So
oooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0<?ooool2o`00
00Kooooo0_l0000Hooooo`;o00000oooool2o`0000;ooooo0_l0000Pooooo`;o000000?oooooo`00
0?l000000_l00003ooooobOo000000?oooooo`000?l000000_ooool2o`0000Kooooo0_l0000>oooo
o`;o00001_ooool4o`0000Gooooo0_l00007ooooo`;o00001oooool4o`0000[ooooo1_l0000>oooo
o`Co0000=Oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06
ooooo`03o`000?oooooooooo03Sooooo0_l00007ooooo`;o00003Oooool2o`0000Gooooo0_l00008
ooooo`;o00001Oooool2o`0000cooooo0_l00004ooooo`?o000000?oooooo`000?l000000ol00002
oooooa;o000000?oooooo`000?l000004Ol000000ooooooo0000o`000002ooooo`;o00001oooool2
o`0000Oooooo0_l00005ooooo`;o00001_ooool6o`0000?ooooo0_l0000Booooo`;o00003?ooool4
o`0000;ooooo0ol00012ooooo`007?ooool00ol0003oooooooooo`0Qooooo`;o00006Oooool2o`00
00?ooooo0_l0000=ooooo`;o00001Oooool2o`0000Sooooo0ol00004ooooo`;o00003?ooool2o`00
00Cooooo0_l00003ooooo`Co00001OoooolSo`000003ooooool0003o000000;ooooo0ol00006oooo
o`;o00001oooool2o`000003ooooool0003o000000Cooooo1?l00003ooooo`[o000000?oooooo`00
0?l000001?ooool2o`0000gooooo0_l000000ooooooo0000o`000005ooooo`;o00001?ooool4o`00
047ooooo000Looooo`03o`000?oooooooooo027ooooo0_l0000Dooooo`?o00000_ooool2o`0000Co
oooo0_l00002ooooo`;o00004Oooool3o`0000?ooooo0_l000000ooooooo0000o`000007ooooo`;o
000000?oooooo`000?l000002Oooool2o`0000Gooooo0_l000000ooooooo0000o`000003ooooobCo
000000?oooooo`000?l000001?ooool2o`0000Gooooo0_l0000;ooooo`;o00001?oooolAo`000003
ooooool0003o000000Cooooo0_l00005ooooo`;o000000?oooooo`000?l000001Ol000000ooooooo
0000o`000003ooooo`;o00001?ooool2o`000004ooooool0003o0000o`00047ooooo000Looooo`03
o`000?oooooooooo03Oooooo0ol00008ooooo`;o00000_ooool2o`00017ooooo0ol00003ooooo`;o
00001oooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000001_ooool2o`00
00Gooooo0_l000001?oooooo0000o`000?l00002ooooo`;o000000?oooooo`000?l000001ol00000
0ooooooo0000o`00000=o`000003ooooool0003o000000So00001?ooool5o`000005ooooool0003o
0000o`000?ooool00_l00006ooooo`;o000000?oooooo`000?l000000oooool@o`0000;ooooo0_l0
000;ooooo`;o000000?oooooo`000?l000001?l00007ooooo`?o00000oooool2o`000003ooooool0
003o000004;ooooo000Looooo`03o`000?oooooooooo03Sooooo0_l00003ooooo`;o00001_ooool2
o`0000[ooooo0_l00007ooooo`;o00001_ooool2o`0000Cooooo1?l00005ooooo`;o00004?ooool3
o`0000;ooooo0_l000001?oooooo0000o`000?oooolLo`000003ooooool0003o000000ko00000_oo
ool2o`0000Kooooo4Ol00003ooooo`So00001?ooool2o`0000Cooooo0_l00006ooooo`;o00002?oo
ool2o`0000;ooooo0_l00002ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool08oooool2
o`0000kooooo0_l000000ooooooo0000o`000005ooooo`;o00001_ooool2o`0000Sooooo1?l0000?
ooooo`;o00001_ooool2o`0001cooooo0_l000000ooooooo0000o`00000Lo`000003ooooool0003o
000000Wo00000oooool2o`000003ooooool0003o000000;o00002?ooool2o`000003ooooool0003o
000001Co00001Oooool2o`0000Cooooo0_l0000Dooooo`;o00000oooool2o`0000kooooo0_l0000a
ooooo`007?ooool00ol0003oooooooooo`0Sooooo`;o00002Oooool2o`0000?ooooo0_l000000ooo
oooo0000o`000002ooooo`?o000000?oooooo`000?l000000_l0000=ooooo`;o00006Oooool2o`00
00?ooooo1?l0000Cooooo`;o000000?oooooo`000?l000000_ooool4o`000003ooooool0003o0000
00ko000000?oooooo`000?l000003_l00006ooooo`Co00002_ooool2o`000003ooooool0003o0000
01?o00003Oooool2o`0000[ooooo0ol00006ooooo`;o00000oooool5o`0000_ooooo0_l0000aoooo
o`007?ooool00ol0003oooooooooo`0Kooooo`;o00004Oooool2o`0000[ooooo0ol000000ooooooo
0000o`000002o`0002gooooo1?l00007ooooo`;o00002_ooool2o`000003ooooool0003o000000?o
000000?oooooo`000?l000001?l000000ooooooo0000o`00000Do`0000;ooooo1?l00007ooooo`;o
00002oooool3o`000003ooooool0003o000000Ko00000_ooool<o`0000cooooo0_l00006ooooo`;o
00000_ooool3o`0000gooooo0ol0000nooooo`007?ooool00ol0003oooooooooo`0Kooooo`;o0000
2_ooool2o`0001Oooooo0_l00007ooooo`;o00003oooool2o`0000Kooooo0_l000000ooooooo0000
o`00000=ooooo`?o00000oooool2o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`_o0000
00?oooooo`000?l000003Ol000000ooooooo0000o`000006o`000003ooooool0003o000001Cooooo
7Ol00002ooooo`;o00001Oooool2o`0000Sooooo0_l0001Cooooo`007?ooool00ol0003ooooooooo
o`0Wooooo`;o00003?ooool2o`0000Wooooo0_l00007ooooo`;o00003oooool3o`0000Cooooo0ol0
00000ooooooo0000o`00000=ooooo`?o00000_ooool2o`0000Gooooo0_l000000ooooooo0000o`00
0004oooooa[o000000Coooooo`000?l0003ooooo1ol0000Doooooaoo00000_ooool2o`0000;ooooo
1Ol0000Looooo`;o0000?oooool001cooooo00?o0000ooooooooool0=Oooool2o`0000cooooo0_l0
000Fooooo`;o00001?ooool2o`0000cooooo0_l00004ooooo`;o00000_ooool2o`0000Oooooo0_l0
0005ooooo`oo00000_ooool9o`000003ooooool0003o000000;ooooo0ol000000ooooooo0000o`00
0005ooooo`;o00002oooool4o`0000Cooooo0ol000000ooooooo0000o`00000Go`000003ooooool0
003o000000?o00006oooool4o`0003oooooo000Looooo`03o`000?oooooooooo02oooooo0_l0000;
ooooo`;o00001Oooool3o`0000;ooooo0_l0000Aooooo`;o000000?oooooo`000?l000002_ooool2
o`0000?ooooo1?l00002ooooo`Co000000Coooooo`000?l0003o00001Oooool2o`0000Kooooo2Ol0
0002ooooo`Ko00000oooool2o`000004ooooool0003o0000ooooo`?o000000Coooooo`000?l0003o
oooo0_l00006ooooo`;o00002oooool4o`0000Cooooo6?l000000ooooooo0000o`000003ooooo`Co
00007?ooool2o`0000;ooooo1?l0000kooooo`007?ooool2o`00033ooooo0_l0000;ooooo`;o0000
1_ooool2o`0000;ooooo0_l00004ooooo`;o00000oooool4o`0000?ooooo0_l00002ooooo`;o0000
0_ooool2o`0000Kooooo0_l00005ooooo`;o00001?ooool2o`000003ooooool0003o000000?o0000
1Oooool2o`0000Cooooo0ol00002ooooo`co000000?oooooo`000?l000000_l000001?oooooo0000
o`000?ooool4o`0000?ooooo0_l00008ooooo`;o00000oooool2o`0000Gooooo0ol00004ooooo`_o
000000?oooooo`000?l000002ol000000ooooooo0000o`000003ooooo`;o00002?ooool3o`0000Oo
oooo0_l00002ooooo`;o00001oooool6o`0003_ooooo000Looooo`03o`000?oooooooooo02oooooo
0_l0000<ooooo`;o00003oooool2o`0000?ooooo1?l00003ooooo`;o00001_ooool2o`0000cooooo
1?l00009ooooo`;o00001Oooool2o`0000?ooooo1_l00004ooooo`Oo000000Coooooo`000?l0003o
00000_ooool3o`000003ooooool0003o000000?o00003?ooool2o`0000?ooooo0_l00003ooooo`;o
00001ooooolLo`0000?ooooo0ol00006ooooo`Co00001oooool2o`0000;ooooo0_l00005ooooo`Co
00000_ooool2o`0003_ooooo000Looooo`03o`000?oooooooooo02oooooo0_l00005ooooo`;o0000
1Oooool2o`0000Cooooo0_l0000>ooooo`;o00001?ooool2o`0000Oooooo0_l0000<ooooo`Co0000
5Oooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000Kooooo0ol00002ooooo`;o
00001Oooool2o`0000Kooooo0_l0000<ooooo`Co00001?ooool2o`000003ooooool0003o000001Wo
00001Oooool2o`0000Kooooo0ol00002ooooo`;o00003Oooool4o`0000Cooooo0ol0000jooooo`00
7?ooool00ol0003oooooooooo`0fooooo`;o00002_ooool3o`0001;ooooo1?l00004ooooo`;o0000
00?oooooo`000?l000002_ooool2o`0000Kooooo0_l0000Hooooo`Go000000?oooooo`000?l00000
0oooool3o`0000;ooooo0_l00003ooooo`?o000000?oooooo`000?l000001?ooool2o`0000_ooooo
0ol00006ooooo`;o00000ooooolFo`0000Gooooo0_l000001?oooooo0000o`000?ooool2o`0000Co
oooo1_l0000=ooooo`;o00001oooool2o`0003[ooooo000Looooo`03o`000?oooooooooo043ooooo
1?l0000>ooooo`;o00000oooool4o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l0
00000oooool4o`0000?ooooo0_l00006ooooo`;o00004_ooool2o`0000Cooooo1?l000001?oooooo
0000o`000?l00003ooooo`Go00000oooool5o`000004ooooool0003o0000o`00013ooooo0_l0000:
ooooo`;o000000?oooooo`000?l000002_l000000ooooooo0000o`000006o`0000;ooooo0_l00000
0ooooooo0000o`000003ooooo`?o00001_ooool2o`0005Cooooo000Looooo`03o`000?oooooooooo
043ooooo0_l0000@ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o00001?ooool4
o`000003ooooool0003o000000;o00002oooool2o`0000?ooooo0_l0000<ooooo`?o00001Oooool6
o`000003ooooool0003o000000?o000000?oooooo`000?l000000_ooool5o`0000?ooooo0_l00002
ooooo`;o00004Oooool2o`0000Cooooo0ol000000ooooooo0000o`00000Ao`0000Cooooo0_l00006
ooooo`;o00002?ooool2o`0000oooooo0_l00002ooooo`;o00007Oooool2o`0001oooooo000Loooo
o`03o`000?oooooooooo03Gooooo0_l00003ooooo`;o00002_ooool2o`0000Kooooo0_l00002oooo
o`;o00000_ooool2o`000003ooooool0003o000000?o00000oooool:o`0000;ooooo0_l0000<oooo
o`;o00001?ooool2o`0000Kooooo0_l00006ooooo`Go00000_ooool4o`0000Gooooo0ol000001?oo
oooo0000o`000?l00002ooooo`Ko00000_ooool2o`0000gooooo0_l00004ooooo`;o000000?ooooo
o`000?l000004ol00009ooooo`Co000000?oooooo`000?l000001Oooool3o`0000kooooo0_l00002
ooooo`;o00007Oooool2o`0001oooooo000Looooo`03o`000?oooooooooo03Gooooo0_l00003oooo
o`;o00002_ooool2o`0000Kooooo0_l00002ooooo`;o00001Oooool6o`0000;ooooo1ol000000ooo
oooo0000o`000002ooooo`;o000000Coooooo`000?l0003ooooo0_l00005ooooo`?o00001?ooool2
o`0000[ooooo1?l00007ooooo`;o00001oooool2o`0000?ooooo0_l00004ooooo`?o00000oooool3
o`0000Gooooo1?l00006ooooo`;o00001?oooolEo`0000Wooooo0ol000001?oooooo0000o`000?l0
0006ooooo`;o00002_ooool2o`0000;ooooo0_l000000ooooooo0000o`000006o`0003Wooooo000L
ooooo`03o`000?oooooooooo02oooooo0_l0000Mooooo`;o00001oooool2o`000003ooooool0003o
0000013o00000oooool3o`000003ooooool0003o000000Gooooo0_l0000Aooooo`Co00002Oooool2
o`0000Gooooo0_l00003ooooo`;o00001Oooool2o`0000Cooooo1?l00003ooooo`Co00001_ooool2
o`0000Sooooo4?l0000;ooooo`;o000000?oooooo`000?l000001oooool2o`0000[ooooo0_l00005
ooooo`Wo000000?oooooo`000?l00000=Oooool001cooooo00?o0000ooooooooool09_ooool2o`00
00Gooooo1?l00005ooooo`;o00002_ooool2o`0000;ooooo0_l0000;ooooo`;o00000_ooool2o`00
0004ooooool0003o0000ooooo`oo00000_ooool3o`0000oooooo0_l0000?ooooo`;o00001oooool2
o`0000Gooooo0_l0000Booooo`Co000000?oooooo`000?l000004oooool2o`000003ooooool0003o
000000Wo00003Oooool2o`0000oooooo0_l0000Aooooo`So0000<oooool001cooooo00?o0000oooo
ooooool09_ooool2o`0000Gooooo0_l00003ooooo`;o00000_ooool2o`0000Gooooo0_l00003oooo
o`;o00000_ooool2o`0000Wooooo1?l00004oooooaOo00000oooool2o`0000_ooooo0_l00005oooo
o`;o00002?ooool2o`0001;ooooo0_l000000ooooooo0000o`00000=ooooo`;o000000?oooooo`00
0?l000000oooool2o`000003ooooool0003o000000kooooo2?l000000ooooooo0000o`00000=oooo
o`;o00003oooool2o`0001Cooooo0_l000000ooooooo0000o`000007ooooo`;o0000:_ooool001co
oooo00?o0000ooooooooool0<_ooool2o`0000Wooooo0_l00009ooooo`;o00001oooool3o`000004
ooooool0003o0000ooooo`So000000Coooooo`000?l0003o00000_ooool9o`0000;ooooo1?l00003
ooooo`;o00002Oooool2o`0000;ooooo1?l00002ooooo`;o00005_ooool2o`000003ooooool0003o
000001Gooooo0_l000000ooooooo0000o`00000@ooooo`?o00000_ooool4o`000003ooooool0003o
0000013ooooo0_l00002ooooo`;o00001Oooool2o`00023ooooo0_l0000Zooooo`007?ooool00ol0
003oooooooooo`0hooooo`;o00003_ooool2o`0000Gooooo0_l000000ooooooo0000o`00000Oo`00
00Gooooo0_l00005ooooo`;o00000_ooool4o`0000;ooooo1_l0000Looooo`;o00000oooool2o`00
00?ooooo0_l0000<ooooo`;o00004?ooool8o`000003ooooool0003o000000?ooooo0_l00005oooo
o`;o00001?ooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool4o`00
00kooooo0_l0000fooooo`007?ooool00ol0003oooooooooo`0Zooooo`;o00000_ooool2o`0000So
oooo0_l0000@ooooo`;o00000oooool2o`0000;ooooo3ol000000ooooooo0000o`00000?o`0000So
oooo0_l000000ooooooo0000o`000004ooooo`;o00001?ooool3o`0001Oooooo0_l00002ooooo`Co
00000oooool2o`0000?ooooo0ol00005ooooo`;o00001?ooool2o`00013ooooo1Ol00004ooooo`;o
00000oooool2o`0000Cooooo0ol00006ooooo`;o00001?ooool4o`0000?ooooo1?l0000>ooooo`;o
0000=_ooool001cooooo00?o0000ooooooooool0:_ooool2o`0000;ooooo0_l00009ooooo`;o0000
3oooool2o`0000Cooooo0_l000000ooooooo0000o`00000Qo`0000Kooooo0_l00007ooooo`;o0000
1Oooool2o`0001Oooooo1ol0000:ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Cooooo
2?l00002ooooo`?o00001Oooool2o`000003ooooool0003o000000Cooooo0_l00006ooooo`;o0000
00?oooooo`000?l000000_l00005ooooo`;o00000_ooool2o`0000;ooooo0_l0000>ooooo`?o0000
2_ooool2o`00033ooooo000Looooo`03o`000?oooooooooo03Wooooo0_l0000Aooooo`;o00000_oo
oolQo`0000?ooooo0_l0000?ooooo`;o00001_ooool2o`0000_ooooo0_l0000;ooooo`Co00003_oo
ool2o`0000;ooooo0_l00005ooooo`Oo00000_ooool3o`0000Gooooo0_l000000ooooooo0000o`00
000<ooooo`;o00000oooool2o`0000Wooooo0_l0000Booooo`Go00002?ooool2o`00033ooooo000L
ooooo`;o0000?oooool2o`0000cooooo0_l00004ooooo`ko000000?oooooo`000?l000004?l0000@
ooooo`?o00001oooool5o`000003ooooool0003o000000Gooooo0_l00006ooooo`?o00001?ooool2
o`0000Kooooo0_l00004ooooo`Co000000?oooooo`000?l000002?ooool2o`0000gooooo0_l0000S
ooooo`Co00003?ooool2o`000004ooooool0003o0000ooooo`;o0000=oooool001cooooo00?o0000
ooooooooool0;_ooool3o`0000_ooooo1?l0000@ooooob?o00001oooool2o`0000Oooooo0ol00009
ooooo`?o000000?oooooo`000?l000002oooool5o`0000Cooooo0_l00004ooooo`Co00000oooool5
o`000003ooooool0003o000000Sooooo0ol0000aooooo`Co00004_ooool2o`0003Oooooo000Loooo
o`03o`000?oooooooooo02Oooooo0_l00005ooooo`?o00002oooool2o`0001;ooooo8_l00004oooo
o`;o00000_ooool2o`0000Kooooo0_l0000?ooooo`;o00002oooool2o`0000gooooo0_l00005oooo
o`;o00003oooool2o`0000Cooooo0_l0000<ooooo`;o00007?ooool2o`0000kooooo0_l00005oooo
o`;o0000=oooool001cooooo00?o0000ooooooooool09oooool2o`0000Gooooo0_l00002ooooo`Co
00001oooool2o`0000kooooo0_l000000ooooooo0000o`00000@o`000003ooooool0003o0000013o
000000?oooooo`000?l000000_l00008ooooo`;o00000_ooool2o`0000Cooooo0_l00005ooooo`;o
00000_ooool4o`0000Sooooo0_l0000Jooooo`;o00000_ooool2o`0000Sooooo0_l00002ooooo`;o
00002?ooool2o`0000Cooooo0ol00004ooooo`;o00000oooool3o`0000Wooooo1?l000001?oooooo
0000o`000?l00008ooooo`;o00001?ooool3o`0003Oooooo000Looooo`03o`000?oooooooooo02ko
oooo0_l00002ooooo`Co00001oooool2o`0000Cooooo0_l00003ooooo`;o00000oooool2o`000003
ooooool0003o000002?o000000?oooooo`000?l000000_l00009ooooo`;o000000?oooooo`000?l0
00000_ooool4o`0000;ooooo0_l000001?oooooo0000o`000?ooool6o`0000Oooooo1?l0000?oooo
o`;o00001oooool2o`0000;ooooo0_l0000:ooooo`Co00002Oooool2o`0000?ooooo0ol00004oooo
o`;o00000oooool3o`0000_ooooo0_l000001?oooooo0000o`000?l0000>ooooo`;o0000>?ooool0
01cooooo00?o0000ooooooooool0@oooool2o`0000?ooooo0_l00008ooooob;o00000_ooool3o`00
00?ooooo0_l00005ooooo`Co000000?oooooo`000?l000000ol00003ooooo`;o00001?ooool3o`00
0003ooooool0003o000000Oooooo1?l0000?ooooo`;o00000_ooool2o`0000Oooooo0_l0000:oooo
o`?o00002?ooool4o`0000;ooooo0ol0000;ooooo`;o00002?ooool2o`0001Gooooo1Ol0000eoooo
o`007?ooool00ol0003oooooooooo`13ooooo`;o00003_oooolDo`000003ooooool0003o000000go
00000_ooool2o`000003ooooool0003o000000Oooooo0_l000000ooooooo0000o`000004ooooo`;o
00004oooool2o`0000?ooooo0_l00009ooooo`?o00000_ooool4o`0000Oooooo0_l0000Eooooo`So
00005_ooool2o`0001Gooooo1Ol0000eooooo`007?ooool00ol0003oooooooooo`13ooooo`?o0000
0_ooool2o`0000;ooooo0_l00004ooooo`Co000000?oooooo`000?l000001?l000000ooooooo0000
o`00000Ao`000003ooooool0003o000000Co000000?oooooo`000?l000001?l000000ooooooo0000
o`00000<ooooo`;o00000oooool2o`0001?ooooo0_l00009ooooo`Co000000?oooooo`000?l00000
0_l00008ooooo`;o00003oooool2o`000003ooooool0003o000000;ooooo1Ol00009ooooo`;o0000
2Oooool2o`0000Sooooo0_l0000:ooooo`;o0000??ooool001cooooo00?o0000ooooooooool0@Ooo
ool2o`000003ooooool0003o000000Co00000_ooool2o`0000Cooooo1?l000000ooooooo0000o`00
000Ho`0000;ooooo0_l000000ooooooo0000o`000003ooooo`Co000000?oooooo`000?l000000_l0
0002ooooo`;o00002oooool2o`0000Cooooo0_l0000=ooooo`;o00002_ooool3o`0000?ooooo0_l0
0008ooooo`?o00003_ooool2o`000004ooooool0003o0000ooooo`;o00001_ooool2o`000004oooo
ool0003o0000ooooo`?o00001oooool4o`0000;ooooo0_l00004ooooo`;o00002_ooool3o`0003_o
oooo000Looooo`03o`000?oooooooooo047ooooo0_l00003ooooo`;o00001?ooool2o`0000Gooooo
8?l0000>ooooo`?o00000_ooool2o`0000gooooo0_l00002ooooo`;o00002Oooool2o`0000;ooooo
0_l000000ooooooo0000o`00000Aooooo`;o000000?oooooo`000?l000000_ooool2o`00017ooooo
1Ol00006ooooo`;o000000?oooooo`000?l000000ol00008ooooo`;o00001?ooool4o`0000;ooooo
0_l0000;ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0E?oooolOo`0000Oooooo0_l0
0005ooooo`;o00000oooool2o`0000gooooo0_l0000=ooooo`;o00001Oooool2o`0000gooooo0_l0
0002ooooo`;o000000?oooooo`000?l000001_ooool2o`0000gooooo0ol00007ooooo`;o00000ooo
ool2o`0000cooooo2?l00004ooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0EooooolL
o`0000Oooooo0_l00003ooooo`;o00002Oooool2o`0000;ooooo0_l00005ooooo`;o00008oooool2
o`000004ooooool0003o0000o`0000Wooooo0_l0000;ooooo`;o000000?oooooo`000?l000001ooo
ool2o`0000Wooooo0_l00006ooooo`Ko00001_ooool2o`0000Wooooo0_l0000kooooo`007?ooool0
0ol0003oooooooooo`0]ooooo`;o00006_ooool2o`0000_ooooo7Ol000000ooooooo0000o`000003
ooooo`;o00000_ooool4o`0000Sooooo0ol000001?oooooo0000o`000?l00005ooooo`;o00001Ooo
ool2o`0000gooooo0_l0000;ooooo`;o00000oooool3o`0000Wooooo0_l00004ooooo`;o00001Ooo
ool2o`000003ooooool0003o000001;ooooo0_l00009ooooo`;o00000_ooool2o`0000?ooooo0_l0
0009ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0;Oooool2o`0000oooooo0_l00000
0ooooooo0000o`000006ooooo`;o00002ooooolHo`0000;ooooo0_l000001?oooooo0000o`000?l0
0003ooooo`;o000000?oooooo`000?l000000ol00008ooooo`;o000000Coooooo`000?l0003o0000
3Oooool2o`0000gooooo0_l0000:ooooo`?o000000?oooooo`000?l000003?ooool2o`0000?ooooo
0ol0000Uooooo`;o00001?ooool2o`0000?ooooo0_l00003ooooo`Co0000?oooool001cooooo00?o
0000ooooooooool09Oooool2o`0001Oooooo1Ol0000CoooooaSo00000_ooool2o`000003ooooool0
003o000000Oooooo0_l000000ooooooo0000o`00000;ooooo`;o00004Oooool2o`0000Kooooo0_l0
000>ooooo`;o00000_ooool2o`0000cooooo0_l00003ooooo`;o00002?ooool2o`0001Kooooo0_l0
0004ooooo`;o00003_ooool4o`0003oooooo000Looooo`03o`000?oooooooooo02Gooooo0_l0000H
ooooo`;o00000_ooool2o`0000[ooooo0_l00006oooooaGo00000_ooool2o`0000cooooo0ol00009
ooooo`;o00000_ooool2o`0000kooooo0_l000000ooooooo0000o`000006ooooo`Co00000oooool3
o`0001Sooooo1?l000000ooooooo0000o`000007ooooo`?o00005_ooool2o`0000Wooooo1_l00006
ooooo`;o0000@?ooool001cooooo0_l0000nooooo`;o000000Coooooo`000?l0003ooooo0_l0000:
ooooo`Co000000?oooooo`000?l000000_oooolCo`0000?ooooo0_l0000;ooooo`Co00002Oooool2
o`0000kooooo0_l000001?oooooo0000o`000?l00003ooooo`;o00001Oooool3o`0000?ooooo0ol0
000Jooooo`;o000000?oooooo`000?l000001oooool2o`0000oooooo0_l0000=ooooo`;o00000_oo
ool6o`0000;ooooo0_l00002ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0?Oooool2
o`000004ooooool0003o0000ooooo`;o00002Oooool5o`000003ooooool0003o000000;ooooo0_l0
0002ooooo`?o00000_ooool2o`000003ooooool0003o000000Co00002_ooool2o`0000Gooooo0_l0
000Kooooo`;o000000?oooooo`000?l000001?ooool4o`0000?ooooo0_l000000ooooooo0000o`00
0005o`0000?ooooo0_l0000Iooooo`;o00003oooool2o`0000Gooooo0_l0000;ooooo`Co00002?oo
ool4o`0000Kooooo0_l0000looooo`007?ooool00ol0003oooooooooo`0kooooo`;o00004Oooool2
o`000003ooooool0003o000000Gooooo0ol000000ooooooo0000o`000002ooooo`;o00000oooool5
o`0000Cooooo0_l00004ooooo`;o00001Oooool2o`0000gooooo0_l0000Dooooo`;o000000?ooooo
o`000?l000001_ooool7o`0000?ooooo0_l0000=ooooo`;o00002?ooool4o`0000?ooooo0ol00002
ooooo`;o00001Oooool2o`0001;ooooo0_l00002ooooo`;o00000oooool5o`0000Sooooo0_l00004
ooooo`;o0000=_ooool001cooooo00?o0000ooooooooool0>oooool2o`0000Kooooo0_l00006oooo
o`;o00001?ooool4o`0000?ooooo0ol00003ooooo`Co00001_ooool3o`0000?ooooo0_l0000:oooo
o`?o00003Oooool2o`0000?ooooo0_l00007ooooo`?o00001Oooool4o`0000Wooooo1Ol0000>oooo
o`Ko00002?ooool2o`0000Gooooo0ol00002ooooo`;o00006_ooool2o`000003ooooool0003o0000
00;o000000Coooooo`000?l0003o00004?ooool2o`0003Kooooo000Looooo`03o`000?oooooooooo
03_ooooo0_l00003ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Kooooo1?l00007oooo
o`;o00001Oooool6o`0000gooooo1_l00007ooooo`;o00001oooool3o`0000Oooooo0ol000000ooo
oooo0000o`000002o`000004ooooool0003o0000o`0000Sooooo0_l000001?oooooo0000o`000?l0
000>ooooo`Co00000oooool2o`000004ooooool0003o0000ooooo`;o00000oooool2o`0000;ooooo
0_l00007ooooo`;o00001Oooool2o`0000[ooooo0_l00002ooooo`?o00000_ooool2o`000003oooo
ool0003o000000kooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`10ooooo`;o000000?o
ooooo`000?l000003Oooool2o`000003ooooool0003o000000Cooooo0_l00008ooooo`Ko00001Ooo
ool2o`0000Kooooo0ol000000ooooooo0000o`000005ooooo`Co00001oooool3o`0000Sooooo0_l0
00000ooooooo0000o`000002o`000003ooooool0003o000000;o00001oooool2o`000003ooooool0
003o000000oooooo0ol000000ooooooo0000o`000003o`000004ooooool0003o0000ooooo`;o0000
0oooool6o`0000?ooooo0_l00002ooooo`;o00001Oooool2o`0000[ooooo0_l00002ooooo`?o0000
5Oooool2o`0003Wooooo000Looooo`03o`000?oooooooooo04?ooooo0_l00006ooooo`;o00001Ooo
ool2o`0000Kooooo0ol0000:ooooo`;o00001oooool2o`0000?ooooo0_l00002ooooo`;o00002?oo
ool2o`0000[ooooo0_l00008ooooo`?o00001oooool2o`0000_ooooo0_l00009ooooo`;o000000?o
ooooo`000?l000002_l0000:ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo0ol0
000Dooooo`;o00001oooool2o`0004Sooooo000Looooo`03o`000?oooooooooo02Kooooo0_l0000S
ooooo`Go00001Oooool2o`0000?ooooo1?l00009ooooo`;o00003?ooool2o`0000gooooo0_l00008
ooooo`;o00002?ooool5o`00013ooooo0_l000000ooooooo0000o`000009oooooa;o00001?ooool2
o`0000Gooooo0_l00005ooooo`?o00000_ooool2o`0000[ooooo0_l0000=ooooo`;o00004?ooool2
o`0003Kooooo000Looooo`03o`000?oooooooooo02Kooooo0_l0000Pooooo`?o00000_ooool3o`00
00Gooooo1?l00002ooooo`?o00009_ooool3o`0000Oooooo0_l00002ooooo`;o00001?ooool2o`00
0003ooooool0003o000000kooooo1?l00002ooooo`;o00002_oooolAo`0000?ooooo0_l00005oooo
o`;o00002_ooool2o`0000[ooooo0_l0000Oooooo`;o0000=_ooool001cooooo00?o0000oooooooo
ool0:_ooool2o`0001Kooooo0_l00003ooooo`Co00002_ooool4o`0000;ooooo0_l00007ooooo`Go
00001_ooool2o`0000;ooooo0_l0000@ooooo`;o00000oooool2o`0000Kooooo0_l0000Gooooo`?o
00000oooool2o`0000Sooooo2ol000000ooooooo0000o`000002o`000003ooooool0003o000000[o
oooo0_l0000Rooooo`;o00001?ooool2o`0000_ooooo0_l0000hooooo`007?ooool00ol0003ooooo
ooooo`0Zooooo`;o00005_ooool2o`0000?ooooo0_l0000;ooooo`;o000000?oooooo`000?l00000
0oooool2o`0000Kooooo1Ol00006ooooo`;o000000Coooooo`000?l0003o00005Oooool2o`0000[o
oooo0_l00006ooooo`;o00001Oooool2o`0000Cooooo0ol00003ooooo`;o00000_ooool2o`0000?o
oooo3?l000000ooooooo0000o`000007o`0000gooooo0_l0000Mooooo`;o00001?ooool2o`0000So
oooo0_l000001?oooooo0000o`000?ooool2o`0000[ooooo0_l0000Yooooo`007?ooool00ol0003o
ooooooooo`13ooooo`;o00003oooool2o`000004ooooool0003o0000o`0000;ooooo0_l00009oooo
o`;o00002Oooool2o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o00003?ooool2o`00
00?ooooo0_l00003ooooo`Co00001?ooool2o`0000Gooooo0_l00003ooooo`Co00000oooool2o`00
0004ooooool0003o0000o`0000;ooooo2ol000000ooooooo0000o`000009o`0000gooooo0_l0000/
ooooo`?o00001?ooool2o`0000[ooooo0_l0000Yooooo`007?ooool00ol0003oooooooooo`0Woooo
o`;o00005_ooool2o`0000;ooooo0_l0000@ooooo`Go00006?ooool2o`0000;ooooo1Ol00002oooo
o`?o00003?ooool2o`0000?ooooo0_l00005ooooo`;o00001oooool2o`0000Oooooo1?l00006oooo
o`;o00000_oooolIo`0000?ooooo1?l00005ooooo`Co0000:_ooool2o`0003cooooo000Looooo`03
o`000?oooooooooo02Oooooo0_l0000Cooooo`;o000000?oooooo`000?l000002Oooool3o`000004
ooooool0003o0000o`0000Cooooo0_l00002ooooo`;o00005oooool2o`0000?ooooo0ol00003oooo
o`;o00008_ooool2o`0000Gooooo0_l000000ooooooo0000o`000009oooooaco00000_ooool4o`00
00Cooooo0_l000000ooooooo0000o`00001Xooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5
ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0??oo
ool2o`000003ooooool0003o000000Oooooo1Ol000001?oooooo0000o`000?l00008ooooo`;o0000
0oooool2o`0000kooooo0_l00002ooooo`;o00006_ooool2o`0000?ooooo0_l0000?ooooo`Ko0000
00?oooooo`000?l000002Oooool;o`000003ooooool0003o0000017o00000_ooool2o`0000?ooooo
0_l00009ooooo`;o00008?ooool2o`0003kooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0moooo
o`Go00001_ooool2o`0000Cooooo0_l00004ooooo`;o00002?ooool2o`0000kooooo0_l00002oooo
o`;o00002Oooool2o`0000oooooo0_l00003ooooo`;o00003oooool6o`0000gooooo7_l00002oooo
o`;o00003_ooool2o`0000[ooooo0_l0000@ooooo`;o00000_ooool2o`0003kooooo00000ooooooo
410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo03gooooo1Ol00009ooooo`;o000000?oooooo`000?l000001?ooool2o`00
00Gooooo0_l000001?oooooo0000o`000?l00005ooooo`;o000000?oooooo`000?l000000_ooool4
o`0000?ooooo0_l00007ooooo`;o00003?ooool2o`0000Gooooo0_l00004ooooo`;o00002oooool2
o`0000Sooooo0_l00007oooooaco00002Oooool2o`0000oooooo0_l00003ooooo`;o00001Oooool2
o`0000Wooooo0_l00003ooooo`;o00000oooool2o`0003Sooooo00000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000?_ooool2
o`0000_ooooo0_l000000ooooooo0000o`00000;ooooo`;o000000Coooooo`000?l0003o00001Ooo
ool5o`0000;ooooo1?l000000ooooooo0000o`000002o`0000Gooooo0_l00007ooooo`;o00001Ooo
ool2o`0000Gooooo0ol00003ooooo`;o00000_ooool2o`000003ooooool0003o000000kooooo0_l0
0008oooooaco00001oooool3o`0000Oooooo0_l00006ooooo`;o00001_ooool2o`0000;ooooo1?l0
000<ooooo`;o00000oooool3o`0003Oooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo02cooooo0_l0
0004ooooo`;o00006_ooool2o`000003ooooool0003o000001;ooooo1?l00005ooooo`;o00000_oo
ool2o`0000Oooooo0_l00003ooooo`;o00000_ooool2o`0000Sooooo0_l00003ooooo`;o00000ooo
ool2o`0000;ooooo2?l00003ooooo`;o00001_ooool2o`0000?ooooo0_l000000ooooooo0000o`00
000Mo`0000Cooooo1?l00007ooooo`?o00003_ooool2o`0000Cooooo0_l00006ooooo`;o00000ooo
ool3o`0000Cooooo1?l0000eooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09
ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0;?ooool2o`0000Cooooo0_l0000E
ooooo`Co00001?ooool2o`0000?ooooo0_l00007ooooo`;o00001?ooool3o`0000Kooooo0_l00004
ooooo`;o00002_ooool2o`0000_ooooo1_l00004ooooo`?o00001?ooool6o`0000?ooooo0_l0000;
ooooo`Go00000oooool7o`000003ooooool0003o0000017o00000oooool2o`000003ooooool0003o
000000Kooooo0_l00003ooooo`;o00002_ooool2o`0000;ooooo0_l000000ooooooo0000o`000004
ooooo`Go000000?oooooo`000?l000001oooool2o`0003Gooooo00001_ooooooMgMgoiRHV?oooooo
V9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`13ooooo`;o00001?oo
ool4o`0000Cooooo0_l000000ooooooo0000o`000002o`0000Oooooo0_l00005ooooo`;o00001Ooo
ool2o`0000;ooooo1Ol00005ooooo`;o00000_ooool2o`0000cooooo1ol00003ooooo`Go00000ooo
ool2o`0000Kooooo0_l0000:oooooa3o000000?oooooo`000?l000004Ol00006ooooo`;o00000_oo
ool2o`0000Oooooo0_l00007ooooo`;o00001Oooool2o`000003ooooool0003o000000Cooooo0_l0
00000ooooooo0000o`000011ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`04olc<
c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0?Oooool2o`0000Cooooo1ol00007ooooo`;o
000000?oooooo`000?l000005oooool2o`0000;ooooo1?l00006ooooo`;o00000_ooool2o`0000Ko
oooo0_l00004ooooo`;o000000?oooooo`000?l000000_l00004ooooo`Co00000oooool2o`0000co
oooo0_l00004ooooo`ko000000?oooooo`000?l000005Ol00004ooooo`?o000000?oooooo`000?l0
00004?ooool2o`0000?ooooo0_l0000:ooooo`?o00001Oooool2o`0003_ooooo000Looooo`03o`00
0?oooooooooo03gooooo0_l00006ooooo`Go00004_ooool2o`0001?ooooo1_l0000@ooooo`;o0000
0_ooool2o`0000?ooooo0_l00008ooooo`;o00003Oooool6o`0000;ooooo0_l00002oooooaoo0000
0oooool2o`0000?ooooo1Ol0000Gooooo`?o00002Oooool3o`0000Gooooo0_l00002ooooo`;o0000
=oooool001cooooo00?o0000ooooooooool0Aoooool2o`0000oooooo0_l00002ooooo`;o00003ooo
ool2o`000004ooooool0003o0000ooooo`Co00001?ooool3o`0000gooooo1_l000000ooooooo0000
o`000006ooooo`;o00002_ooool2o`000003ooooool0003o000000;o00001?ooool2o`0000;ooooo
7ol00006ooooo`Co000000?oooooo`000?l000001Oooool2o`00017ooooo0_l0000Aooooo`;o0000
0_ooool2o`0003Oooooo000Looooo`03o`000?oooooooooo047ooooo0_l00004ooooo`;o00000ooo
ool2o`0000[ooooo0_l00002ooooo`;o00001?ooool2o`0000Wooooo0_l000001?oooooo0000o`00
0?ooool3o`0000Gooooo1?l00007ooooo`;o00000oooool:o`000004ooooool0003o0000ooooo`Go
00000oooool2o`0000?ooooo1?l0000:oooooaoo00001oooool4o`0000Sooooo0_l0000Cooooo`;o
000000?oooooo`000?l000000_l0000:ooooo`?o0000>_ooool001cooooo00?o0000ooooooooool0
@Oooool2o`0000Sooooo0ol0000>ooooo`;o00001?ooool2o`0000oooooo0ol00007ooooo`;o0000
1oooool<o`000003ooooool0003o000000Wo00000oooool2o`0000Gooooo0_l00009ooooo`?o0000
00?oooooo`000?l000006_l0000;ooooo`;o00005oooool2o`0000;ooooo0_l000000ooooooo0000
o`000002o`0000_ooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`1;ooooo`?o00001?oo
ool2o`0000Kooooo0_l0000Fooooo`;o00003Oooool2o`0000;ooooo4_l000001?oooooo0000o`00
0?ooool3o`0001Gooooo0_l00002ooooo`Oo000000?oooooo`000?l000004_l00003ooooo`;o0000
1_ooool2o`0000oooooo0_l00006ooooo`;o0000D?ooool001cooooo00?o0000ooooooooool0?ooo
ool2o`00017ooooo0_l00003ooooo`Go00005_ooool3o`0000cooooo0_l00002ooooo`Co000000?o
ooooo`000?l000002ol00005ooooo`Co00002?ooool2o`0000gooooo7?l00003ooooo`;o00004?oo
ool4o`000003ooooool0003o000000;o00003_ooool2o`0000;ooooo0_l00014ooooo`007?ooool0
0ol0003oooooooooo`0oooooo`;o00001oooool4o`0000_ooooo1Ol0000Fooooo`?o000000?ooooo
o`000?l000001?ooool2o`0000;ooooo0_l00003oooooa;o000000?oooooo`000?l000000_ooool5
o`0000Oooooo0_l00004ooooo`;o00000oooool3o`0000;ooooo6ol0000?ooooo`;o00001?ooool4
o`000003ooooool0003o0000013ooooo0_l000001?oooooo0000o`000?l00009ooooo`;o0000>Ooo
ool001cooooo00?o0000ooooooooool0B?ooool4o`0000?ooooo0_l00009ooooo`;o00006Oooool4
o`0000?ooooo0_l00002ooooo`;o00001?oooolEo`000003ooooool0003o000000Co00003?ooool2
o`0000?ooooo0ol00002ooooo`Oo000000?oooooo`000?l000003_l0000;ooooo`;o00001Oooool2
o`0001?ooooo0_l00009ooooo`;o00002_ooool4o`0003Oooooo000Looooo`03o`000?oooooooooo
03[ooooo0_l00004ooooo`;o00003Oooool2o`0000;ooooo0_l00007ooooo`;o00005oooool6o`00
0003ooooool0003o000000Oooooo5ol00002ooooo`Co00002_ooool2o`0000[ooooo6?l0000;oooo
o`;o00001oooool2o`0000[ooooo0ol00004ooooo`;o00005oooool2o`0003Oooooo000Looooo`03
o`000?oooooooooo03Oooooo0_l000000ooooooo0000o`000004ooooo`;o00004Oooool2o`0000Oo
oooo0_l00003ooooo`;o00004Oooool7o`0000?ooooo0_l000001?oooooo0000o`000?oooolHo`00
00;ooooo0_l000000ooooooo0000o`000007ooooo`Co00002_ooool2o`0000?ooooo1?l000000ooo
oooo0000o`00000;o`0001Gooooo0_l000000ooooooo0000o`000002o`0000Gooooo1?l00002oooo
o`;o0000DOooool001cooooo00?o0000ooooooooool0=oooool2o`0001cooooo0_l0000:ooooo`;o
00004Oooool2o`000003ooooool0003o000000Gooooo0_l000000ooooooo0000o`000003o`000003
ooooool0003o000001?o00001Oooool4o`0000;ooooo0_l000001?oooooo0000o`000?l0000Coooo
o`ko00000oooool5o`0000Sooooo0_l00007ooooo`Co00001oooool2o`0000;ooooo0_l00009oooo
o`;o0000A_ooool001cooooo0_l0000^ooooo`;o00005_ooool2o`0000kooooo0_l000000ooooooo
0000o`000003ooooo`;o00000_ooool3o`00013ooooo0_l0000<oooooa[o00001oooool2o`0000;o
oooo0_l0000Gooooo`ko00000_ooool6o`0000Sooooo0_l0000Qooooo`;o0000A_ooool001cooooo
00?o0000ooooooooool0;Oooool2o`00017ooooo0_l00003ooooo`;o00001?ooool2o`0000_ooooo
0_l00003ooooo`;o00000oooool2o`00013ooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo
0_l000000ooooooo0000o`00000Io`0000Wooooo1Ol0000Cooooo`;o00001_ooool2o`000003oooo
ool0003o000000;ooooo1?l00002ooooo`;o00001oooool2o`0000?ooooo0_l0001Uooooo`007?oo
ool00ol0003oooooooooo`10ooooo`;o00001?ooool2o`0000?ooooo0_l00003ooooo`;o000000?o
ooooo`000?l000000_l0000:ooooo`;o00000oooool2o`0000Cooooo0_l00009ooooo`?o000000Co
ooooo`000?l0003o00000_ooool2o`000003ooooool0003o000001co00001oooool4o`000003oooo
ool0003o0000013ooooo0_l00009ooooo`;o00000_ooool3o`0000?ooooo0_l00004ooooo`;o0000
00Coooooo`000?l0003ooooo1?l00007ooooo`;o00002?ooool2o`0000Sooooo0_l00018ooooo`00
7?ooool00ol0003oooooooooo`13ooooo`;o000000?oooooo`000?l000002?ooool9o`0000Sooooo
0_l00003ooooo`;o00001?ooool3o`0000Oooooo0ol00002ooooo`;o00001_oooolNo`0000Cooooo
1Ol00003ooooo`;o000000?oooooo`000?l000001?ooool2o`0000_ooooo0_l00007ooooo`;o0000
3?ooool2o`0000;ooooo1Ol00008ooooo`Co00001_ooool3o`0000Oooooo0_l00018ooooo`007?oo
ool00ol0003oooooooooo`0oooooo`;o00000_ooool2o`0000Sooooo0_l00003ooooo`;o00000_oo
ool3o`0000Kooooo0_l00006ooooo`;o00001?ooool2o`0000;ooooo0_l00003ooooo`;o00002ooo
oolKo`000003ooooool0003o000000?ooooo1Ol00002ooooo`;o00000oooool2o`0000?ooooo0ol0
000;ooooo`;o00000_ooool2o`000003ooooool0003o000000;o00000oooool2o`0000_ooooo0_l0
0003ooooo`;o00001oooool3o`0000Gooooo1?l0001Aooooo`007?ooool00ol0003oooooooooo`0d
ooooo`;o00002Oooool2o`0000Kooooo1?l00002ooooo`;o00004?ooool2o`0000Kooooo1?l00006
ooooo`;o00003oooool;o`0000;ooooo3_l00002ooooo`;o00000oooool2o`0000Cooooo0ol00008
ooooo`;o000000?oooooo`000?l000003Oooool2o`000003ooooool0003o000000?ooooo1?l00000
0ooooooo0000o`00000=ooooo`;o00001oooool5o`0000?ooooo0_l00006ooooo`;o0000Boooool0
01cooooo00?o0000ooooooooool0=?ooool2o`0000oooooo1_l00002ooooo`;o00003?ooool2o`00
00cooooo0_l0000GoooooaWo00003oooool2o`0000cooooo0_l0000Eooooo`?o00000_ooool2o`00
01Kooooo0_l000000ooooooo0000o`00000;ooooo`?o0000B_ooool001cooooo00?o0000oooooooo
ool0A?ooool3o`0000cooooo0_l00005ooooo`?o00009_oooolGo`00013ooooo1?l00008ooooo`;o
00006?ooool2o`00013ooooo0_l00008ooooo`Co00001Oooool2o`0000Kooooo0_l0001:ooooo`00
7?ooool00ol0003oooooooooo`0oooooo`;o00000oooool2o`0000gooooo0_l00005ooooo`Co0000
2oooool2o`0000;ooooo0_l0000CoooooaWo00001Oooool2o`0000;ooooo0_l00004ooooo`Co0000
00Coooooo`000?l0003o00000_ooool4o`0000Oooooo0ol00002ooooo`;o00002?ooool4o`0000;o
oooo0_l0000<ooooo`;o00002_ooool2o`000004ooooool0003o0000ooooo`?o00001_ooool2o`00
04[ooooo000Looooo`03o`000?oooooooooo03oooooo0_l0000<ooooo`;o00003Oooool2o`0000Ko
oooo0_l00003ooooo`;o00000_ooool2o`0001?ooooo1_l000000ooooooo0000o`00000@o`0000Go
oooo0_l00002ooooo`;o00001?ooool3o`0000;ooooo0ol00002ooooo`;o00001?ooool2o`0000?o
oooo0ol00002ooooo`;o00000_ooool2o`0000Cooooo1?l00002ooooo`;o00006oooool2o`000003
ooooool0003o000005?ooooo000Looooo`03o`000?oooooooooo03kooooo0_l00005ooooo`;o0000
1_ooool2o`0001Gooooo0_l00002ooooo`?o00005_oooolBo`000003ooooool0003o000000;ooooo
1?l0000>ooooo`;o00002?ooool2o`0000Cooooo0ol0000:ooooo`?o00002_ooool2o`0000;ooooo
1?l0000<ooooo`;o0000Goooool001cooooo00?o0000ooooooooool0?Oooool3o`0000Gooooo0_l0
000:ooooo`;o00003Oooool4o`0000Cooooo1?l00004ooooo`;o00003_oooolMo`0000?ooooo0_l0
0005ooooo`;o00002oooool2o`0000Gooooo0_l000000ooooooo0000o`000007ooooo`Co00001Ooo
ool2o`0000Kooooo1_l0000:ooooo`;o00001_ooool2o`0000Gooooo0_l0001@ooooo`007?ooool0
0ol0003oooooooooo`0mooooo`;o00004_ooool2o`0000gooooo1?l00006ooooo`;o00001?ooool2
o`0000gooooo1_l000000ooooooo0000o`00000@o`0000?ooooo0_l00003ooooo`;o00000_ooool2
o`000003ooooool0003o000000;o00004oooool2o`0000Kooooo0_l000000ooooooo0000o`000003
ooooo`Go000000?oooooo`000?l000001_ooool2o`0001;ooooo0_l00005ooooo`;o0000D?ooool0
01cooooo00?o0000ooooooooool0@oooool4o`0002?ooooo0_l0000=ooooo`;o00000oooool3o`00
0005ooooool0003o0000o`000?ooool04?l00003ooooo`;o00002Oooool3o`0000;ooooo0_l0000B
ooooo`;o00001oooool2o`000003ooooool0003o000000?ooooo0_l000001?oooooo0000o`000?oo
ool2o`0001Sooooo0_l00003ooooo`;o00000_ooool2o`00053ooooo000Looooo`03o`000?oooooo
oooo04?ooooo1?l00006ooooo`;o00001oooool2o`0001;ooooo0_l0000=ooooo`;o00000oooool2
o`0000;ooooo5?l00003ooooo`;o00002_ooool3o`0000?ooooo0ol0000?ooooo`;o00001Oooool2
o`000003ooooool0003o000000?ooooo0_l00007ooooo`;o00001?ooool2o`0000Gooooo1?l00008
ooooo`;o00000oooool2o`0005Cooooo000Looooo`03o`000?oooooooooo04Cooooo0_l00007oooo
o`;o00001oooool2o`0000Sooooo0_l00004ooooo`;o00006_ooool<o`000003ooooool0003o0000
00?o00003?ooool4o`000003ooooool0003o000000?o000000?oooooo`000?l000000_l00009oooo
o`;o00002_ooool2o`000004ooooool0003o0000ooooo`Co00001oooool2o`0000?ooooo0ol00002
ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o00000_ooool3o`0000;ooooo0_l0001E
ooooo`007?ooool2o`0004Gooooo0_l0000Jooooo`;o00001?ooool2o`0000;ooooo1?l00009oooo
o`;o00002_ooool3o`000003ooooool0003o000000Ko000000?oooooo`000?l000000oooool2o`00
00Gooooo2?l00003ooooo`?o000000?oooooo`000?l000000_l00006ooooo`;o000000?oooooo`00
0?l000003Oooool2o`000003ooooool0003o000000_ooooo1Ol00003ooooo`?o00000oooool3o`00
0003ooooool0003o000000;ooooo0ol00002ooooo`;o0000EOooool001cooooo00?o0000oooooooo
ool0G_ooool2o`000003ooooool0003o000000Oooooo1?l00009ooooo`;o00002oooool2o`0000?o
oooo1ol00005ooooo`;o00001Oooool4o`000003ooooool0003o000000[ooooo0_l00006ooooo`?o
00000_ooool2o`0001_ooooo1?l00005ooooo`;o00000oooool3o`0000Gooooo0_l00003ooooo`;o
0000EOooool001cooooo00?o0000ooooooooool0D_ooool2o`0000[ooooo1Ol00008ooooo`;o0000
6_ooool6o`000003ooooool0003o000000;ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o
00001_ooool2o`0000Wooooo1?l00006ooooo`?o000000?oooooo`000?l000008?ooool2o`0000Oo
oooo0_l00006ooooo`;o00000oooool2o`0005Gooooo000Looooo`03o`000?oooooooooo04gooooo
0_l00003ooooo`;o00002oooool2o`000003ooooool0003o000000;o00001Oooool3o`0001Kooooo
1ol00007ooooo`;o000000?oooooo`000?l000001Ol00005ooooo`;o00002Oooool4o`0000?ooooo
1_l0000;ooooo`;o00000_ooool2o`00017ooooo0ol00007ooooo`;o00001_ooool4o`0005Sooooo
000Looooo`03o`000?oooooooooo04gooooo1?l0000@ooooo`Go00001_ooool2o`0000Oooooo0_l0
000<ooooo`Co000000?oooooo`000?l000003_ooool6o`0000Sooooo1?l00004ooooo`;o00000ooo
ool5o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00002ooooo`;o0000
3Oooool3o`000004ooooool0003o0000o`0000;ooooo0_l00007ooooo`;o00000oooool3o`0005So
oooo000Looooo`03o`000?oooooooooo04gooooo1?l0000@ooooo`;o00002?ooool2o`0000Sooooo
0_l00007ooooo`;o00000oooool2o`0000?ooooo0ol0000Aooooo`;o00002?ooool4o`0000?ooooo
0_l00006ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`;o00004oooool5o`0000;o
oooo0_l00002ooooo`;o00001oooool2o`000003ooooool0003o000005_ooooo000Looooo`03o`00
0?oooooooooo04Kooooo0_l00006ooooo`;o00006oooool4o`0000?ooooo0_l0000:ooooo`;o0000
2?ooool3o`0000cooooo1?l00009ooooo`;o00001oooool4o`000003ooooool0003o000001Kooooo
0_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Cooooo
0_l00004ooooo`?o0000F_ooool001cooooo00?o0000ooooooooool0A_ooool2o`0000Kooooo0_l0
000;ooooo`Go00001Oooool2o`0000Gooooo0ol00002ooooo`?o00001?ooool2o`0000Cooooo0_l0
0008ooooo`;o00003Oooool4o`0000Wooooo0_l00009ooooo`;o000000Coooooo`000?l0003o0000
2_ooool2o`0000Oooooo1ol00003ooooo`;o00002_ooool2o`0000Kooooo0_l00005ooooo`;o0000
4?ooool2o`0004Sooooo000Looooo`03o`000?oooooooooo04Kooooo0_l000000ooooooo0000o`00
000@ooooo`Go00001?ooool5o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000Cooooo
1?l00003ooooo`;o00004oooool2o`0000Gooooo0_l0000Aooooo`;o00001?ooool2o`0000Gooooo
0_l00003ooooo`;o00001oooool7o`0000?ooooo1?l00008ooooo`Co00007Oooool2o`0004Sooooo
000Looooo`03o`000?oooooooooo04Wooooo0_l0000<ooooo`?o00000oooool2o`0000Gooooo1Ol0
00001?oooooo0000o`000?ooool2o`0000Sooooo1?l0000Cooooo`;o00000oooool2o`0000Gooooo
0_l00009ooooo`;o00000_ooool2o`0000;ooooo1?l00009ooooo`;o00000oooool2o`0000Gooooo
1_l000000ooooooo0000o`000005ooooo`;o00001_ooool6o`000003ooooool0003o000000Cooooo
0_l0001Nooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o00001?ooool3o`0000?ooooo0_l0
0005ooooo`;o000000?oooooo`000?l000002oooool2o`0000Sooooo0_l00006ooooo`;o00001_oo
ool3o`0001Cooooo0_l00002ooooo`;o00001?ooool3o`0000_ooooo1?l00003ooooo`Co00001Ooo
ool2o`0000Gooooo0_l00006ooooo`Ko000000?oooooo`000?l000001?ooool2o`00017ooooo0_l0
001;ooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o00005?ooool2o`0000_ooooo0_l00008
ooooo`;o00001_ooool2o`0000Oooooo0_l0000Eooooo`;o00001?ooool2o`0000;ooooo1?l00009
ooooo`?o00001?ooool2o`0000Gooooo1Ol00009ooooo`Co000000?oooooo`000?l000000_l0000J
ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0H?ooool2o`000003ooooool0003o0000
00cooooo0_l0000Cooooo`;o00001Oooool5o`0001Cooooo0_l00004ooooo`;o00001?ooool2o`00
00kooooo0_l00007ooooo`;o000000?oooooo`000?l000002Oooool4o`000003ooooool0003o0000
00;o0000Ioooool001cooooo00?o0000ooooooooool0B?ooool2o`0001Kooooo0_l000000ooooooo
0000o`00000<ooooo`;o00004oooool2o`000003ooooool0003o000000;ooooo1Ol0000Pooooo`;o
00003Oooool3o`0001Cooooo0_l000001?oooooo0000o`000?ooool4o`0006Oooooo000Looooo`03
o`000?oooooooooo04Sooooo0_l0000Fooooo`;o00002_ooool2o`000003ooooool0003o000001So
oooo0_l00004ooooo`;o00004?ooool2o`0000kooooo0_l0000<ooooo`Co00005Oooool2o`0006oo
oooo000Looooo`03o`000?oooooooooo06cooooo0_l000000ooooooo0000o`00000?ooooo`;o0000
0_ooool2o`0000Wooooo0_l0000@ooooo`;o000000?oooooo`000?l000000_ooool4o`0000Gooooo
0_l0000<ooooo`;o00003?ooool4o`0001Kooooo0_l0001Pooooo`007?ooool2o`0006;ooooo0_l0
0003ooooo`;o00003_ooool2o`0000Sooooo0_l00002ooooo`;o00001oooool2o`0000cooooo0_l0
0007ooooo`;o00000_ooool4o`0000Kooooo1?l0000>ooooo`;o00001Oooool6o`0000?ooooo0_l0
00001?oooooo0000o`000?ooool2o`0000_ooooo0_l0001Pooooo`007?ooool00ol0003ooooooooo
o`1Nooooo`;o000000?oooooo`000?l000000oooool2o`0000cooooo1?l0000Eooooo`;o00003?oo
ool2o`0000Gooooo0_l00005ooooo`?o00001_ooool4o`0000Wooooo0_l00003ooooo`Go000000Co
ooooo`000?l0003o00000_ooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0006go
oooo000Looooo`03o`000?oooooooooo05kooooo0_l00005ooooo`;o00003Oooool4o`000003oooo
ool0003o000002Oooooo0_l00005ooooo`?o000000?oooooo`000?l000004?ooool2o`0000Cooooo
1?l000001?oooooo0000o`000?l00007ooooo`Co00002_ooool2o`0000;ooooo0_l0001Qooooo`00
7?ooool00ol0003oooooooooo`1Oooooo`;o00001?ooool2o`0001;ooooo0_l00002ooooo`;o0000
1?ooool2o`0001Sooooo0_l0000=ooooo`?o00004?ooool2o`0000kooooo0_l00003ooooo`Co0000
2_ooool2o`0000;ooooo0_l0000:ooooo`;o0000EOooool001cooooo00?o0000ooooooooool0Gooo
ool2o`0000_ooooo0_l0000?ooooo`;o00001?ooool4o`0000_ooooo0_l00009ooooo`;o00000ooo
ool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000004ooooo`;o00002?oo
ool2o`000003ooooool0003o000000Wooooo0_l00003ooooo`;o00001Oooool2o`0001[ooooo0_l0
001Eooooo`007?ooool00ol0003oooooooooo`1/ooooo`;o00005_ooool3o`0000_ooooo0_l0000>
ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000Oooooo0_l00004ooooo`;o00000_oo
ool2o`0000cooooo0_l000000ooooooo0000o`00000<ooooo`;o00002Oooool2o`00067ooooo000L
ooooo`03o`000?oooooooooo05;ooooo0_l0000@ooooo`;o00001?ooool2o`0001Cooooo0_l00002
ooooo`;o00001Oooool4o`0001Oooooo0_l0000:ooooo`;o00001?ooool2o`0000;ooooo0_l0000?
ooooo`;o00002Oooool2o`000003ooooool0003o000000Kooooo0_l000000ooooooo0000o`00001Q
ooooo`007?ooool00ol0003oooooooooo`1Booooo`;o00004?ooool2o`0000Cooooo0_l00007oooo
o`;o00002oooool5o`000003ooooool0003o000000?ooooo1?l0000>ooooo`;o00001?ooool2o`00
02;ooooo0ol00003ooooo`Co00001oooool2o`0000Wooooo0_l000000ooooooo0000o`00001Qoooo
o`007?ooool00ol0003oooooooooo`1Zooooo`;o00000oooool2o`0000;ooooo0_l0000=ooooo`?o
000000?oooooo`000?l000000_l0000<ooooo`;o00001Oooool4o`0000;ooooo0_l000000ooooooo
0000o`000008ooooo`;o00005Oooool3o`0000Gooooo0ol00002ooooo`?o00003oooool2o`00067o
oooo000Looooo`03o`000?oooooooooo06Kooooo0ol00006ooooo`;o00000oooool2o`0000gooooo
0_l00003ooooo`;o00002?ooool2o`0000;ooooo0_l00007ooooo`;o00001Oooool2o`0000Sooooo
0_l00006ooooo`;o00003oooool2o`0000Gooooo0_l00002ooooo`?o00002Oooool2o`0006Oooooo
000Looooo`03o`000?oooooooooo063ooooo0_l00004ooooo`?o00002oooool2o`0000gooooo0ol0
000<ooooo`;o00004Oooool2o`0000gooooo0_l00002ooooo`;o00003oooool2o`0001Gooooo0_l0
001Wooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o00004_ooool2o`0000Gooooo0ol00006
ooooo`;o00005?ooool4o`0000Oooooo0_l0000<ooooo`?o00002?ooool2o`0000;ooooo0_l0000<
ooooo`;o00003?ooool2o`0006Wooooo000Looooo`03o`000?oooooooooo063ooooo0_l0000=oooo
o`;o00000oooool2o`0000Cooooo1?l00003ooooo`Co00005Oooool4o`0000Kooooo0_l00009oooo
o`;o00000_ooool2o`0000Wooooo0_l00002ooooo`;o00003?ooool2o`0000Wooooo0_l000000ooo
oooo0000o`00001Yooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o00003Oooool2o`0000Oo
oooo1?l00002ooooo`;o000000?oooooo`000?l000001?l000000ooooooo0000o`00000Hooooo`Co
00001?ooool3o`000004ooooool0003o0000o`0001oooooo0_l00004ooooo`;o00000oooool2o`00
06cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1cooooo`Co000000?oooooo`000?l000001?oo
ool2o`0000Gooooo0_l000000ooooooo0000o`00000;ooooo`;o000000?oooooo`000?l000000ooo
ool2o`0000?ooooo0_l00006ooooo`?o000000?oooooo`000?l000008?ooool2o`0000;ooooo1?l0
00000ooooooo0000o`00001^ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0Loooool4o`00017o
oooo0_l0000;ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`00000;ooooo`;o
00002?ooool2o`0001?ooooo0_l00009ooooo`?o00000_ooool2o`0006kooooo00000ooooooo410@
ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo07[ooooo0_l0000Dooooo`;o000000Coooooo`000?l0003ooooo0_l00002oooo
o`;o00001Oooool2o`00017ooooo1?l00007ooooo`;o00001Oooool2o`000005ooooool0003o0000
o`000?ooool00_l00006ooooo`;o000000?oooooo`000?l00000Koooool00003ooooool0003ooooo
00;ooooo00?o0000ooooooooool02Oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0001f
ooooo`;o00000_ooool2o`0000_ooooo0_l000000ooooooo0000o`000004ooooo`;o000000Cooooo
o`000?l0003ooooo0_l00005ooooo`;o00000_ooool2o`0000Sooooo0_l00003ooooo`Co00000_oo
ool2o`0000Kooooo0ol00005ooooo`;o00000_ooool2o`000003ooooool0003o000000Wooooo0_l0
001_ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05olc<c?l0003o
0000o`000?o<c<`01_ooool00ol0003oooooooooo`1fooooo`;o00001Oooool2o`0000Sooooo0_l0
00001?oooooo0000o`000?ooool2o`0000Gooooo0_l00007ooooo`;o00000_ooool2o`0000Sooooo
0_l00003ooooo`Co00002_ooool2o`0000Gooooo0_l00022ooooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooo
ooooo`1looooo`?o00002Oooool4o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000
o`000006ooooo`;o00002Oooool2o`0001Wooooo0_l000000ooooooo0000o`00000:ooooo`;o0000
0_ooool2o`0007;ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oo
oooo^[Zjo`000006ooooo`03o`000?oooooooooo07cooooo0_l000000ooooooo0000o`000007oooo
o`?o00000_ooool3o`000003ooooool0003o000000Wooooo0_l00002ooooo`;o00001Oooool2o`00
00Oooooo0_l0000@ooooo`;o00002_ooool2o`000003ooooool0003o000000;ooooo0_l0001boooo
o`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_oo
ool00ol0003oooooooooo`1oooooo`Co00001oooool2o`000004ooooool0003o0000o`00013ooooo
0_l000000ooooooo0000o`000007ooooo`;o00000_ooool2o`0000;ooooo0_l00002ooooo`;o0000
1Oooool2o`0000gooooo0_l0001iooooo`007?ooool00ol0003oooooooooo`1]ooooo`;o00001?oo
ool2o`0000Sooooo0_l00002ooooo`?o000000?oooooo`000?l000000oooool3o`0001Kooooo0_l0
0007ooooo`;o00001_ooool2o`0000;ooooo0_l00005ooooo`Co00002oooool2o`0000Gooooo0_l0
001booooo`007?ooool00ol0003oooooooooo`1]ooooo`;o00001?ooool2o`0000Gooooo0_l00000
0ooooooo0000o`000003ooooo`Ko00000oooool2o`0000cooooo0_l00008ooooo`;o00003_ooool2
o`0000[ooooo1?l0000Booooo`;o0000L_ooool001cooooo00?o0000ooooooooool0N_ooool2o`00
00Sooooo1?l00008ooooo`;o000000?oooooo`000?l000001?ooool4o`0000Kooooo0_l0000>oooo
o`;o00002_ooool4o`0000Wooooo0_l000000ooooooo0000o`00001hooooo`007?ooool00ol0003o
ooooooooo`2@ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Cooooo1_l0000Uooooo`;o
000000?oooooo`000?l00000N?ooool001cooooo00?o0000ooooooooool0Toooool2o`0000cooooo
1_l00007ooooo`;o00002?ooool2o`0008oooooo000Looooo`03o`000?oooooooooo08Oooooo0ol0
000Iooooo`?o00002?ooool2o`0000;ooooo0_l00004ooooo`?o0000S_ooool001cooooo00?o0000
ooooooooool0Qoooool5o`000003ooooool0003o000001Cooooo0_l000000ooooooo0000o`000004
ooooo`;o00001?ooool2o`0000Gooooo0_l0002>ooooo`007?ooool00ol0003oooooooooo`2:oooo
o`;o000000?oooooo`000?l000005oooool2o`0000Cooooo0_l00008ooooo`;o0000TOooool001co
oooo00?o0000ooooooooool0T_ooool2o`0000Sooooo0_l0000:ooooo`;o00003?ooool3o`0000Co
oooo0_l0002:ooooo`007?ooool00ol0003oooooooooo`2Booooo`;o00002?ooool2o`0000[ooooo
0_l00004ooooo`;o00001oooool2o`0000Cooooo0_l0002:ooooo`007?ooool00ol0003ooooooooo
o`2^ooooo`;o0000VOooool001cooooo0_l0002Hooooo`;o0000=?ooool2o`0007[ooooo000Loooo
o`03o`000?oooooooooo06_ooooo0_l0000Tooooo`?o00000oooool2o`0000Gooooo0_l0000Doooo
o`;o00005oooool2o`0007[ooooo000Looooo`03o`000?oooooooooo06_ooooo0_l0000Tooooo`?o
00002_ooool3o`0001?ooooo0_l0002Cooooo`007?ooool00ol0003oooooooooo`2Nooooo`?o0000
2?ooool2o`0009kooooo000Looooo`03o`000?oooooooooo08gooooo0_l0000Jooooo`?o0000WOoo
ool001cooooo00?o0000ooooooooool0SOooool2o`0000?ooooo0_l00005ooooo`;o00003oooool2
o`0009gooooo000Looooo`03o`000?oooooooooo09;ooooo0_l00005ooooo`;o0000[_ooool001co
oooo00?o0000ooooooooool0N_ooool2o`000<gooooo000Looooo`03o`000?oooooooooo07[ooooo
0_l0003=ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`004_ooool4o`000003oa0@4?oooooooooo
00?ooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool3o`000?oooooo
B_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3o
oooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000oooooooo
ool0oooooomBooooo`004_ooool00omEEEGoIVIVo`00003ooooooeCooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo002Qooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@oooo
ooooool05_ooool4o`000008oa0@4?oooooooooooiRHV?l@413o0000oc8b<_o<c<`5ooooo`;o0000
00?o410@ooooooooool00oooool2o`000003oa0@4?oooooooooo08[ooooo002Rooooo`05o`000?oo
ooooooooooooool000002Oooool6o`0000cooooo00?o0000ooooooooool00_ooool01Ol@413o^[Zj
oooooomgMgOo<S8b00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2;ooooo`00
X_ooool01Ol0003ooooooooooooooooo000001_ooooo00?o0000ooooooooool01_ooool01?l0003o
ooooooooooooool5o`0000?ooooo1Ol0002<ooooo`00X_ooool01Ol0003ooooooooooooooooo0000
00Wooooo1_l0000<ooooo`03o`000?oooooooooo00Gooooo00?oZJVYoa0@4?ooool00_ooool01?m4
A4CogMgMooooool00004ooooo`04odA4A?oMgMgoooooo`0008gooooo002Rooooo`05o`000?n7QhOo
ooooojVYZOl000006oooool00ol0003oooooooooo`04ooooo`03oa0@4?l0003o^[Zj00?ooooo00Co
gMgMoeEEEOoooooo00001?ooool01?oMgMgoEEEEooooool0002=ooooo`00XOooool00ol@413o0000
ogMgM`02o`000003oiRHV?oooooooooo01Wooooo00?o0000ooooooooool01Oooool00onj^[[o8B4Q
ooooo`03ooooo`03ogMgMoo<c<co000000Gooooo00?oMgMgolc<c?l00000SOooool00<;ooooo00?o
0000ooooooooool00_ooool01Ol@413oV9RHoooooonj^[[o000000Cooooo00?ok^k^odA4A?l00000
1Oooool00oo^k^koA4A4o`00002=ooooo`00`?ooool00omEEEGoIVIVo`000004ooooo`05ojVYZOl@
413o0000oa0@4?nYZJT01Oooool00omgMgOo0000ooooo`05ooooo`03ogMgMol0003ooooo08cooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1350) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.35301 .48149 Mdot
.34654 .48493 Mdot
.59331 .64002 Mdot
.47963 .37649 Mdot
.78625 .59783 Mdot
.60502 .60521 Mdot
.39293 .67256 Mdot
.45124 .64685 Mdot
.58142 .64009 Mdot
.3589 .60833 Mdot
.44024 .62713 Mdot
.5858 .39848 Mdot
.41722 .65584 Mdot
.51486 .36533 Mdot
.85858 .43372 Mdot
.4652 .431 Mdot
.35164 .47924 Mdot
.67009 .51915 Mdot
.52314 .44276 Mdot
.62728 .61451 Mdot
.35323 .45434 Mdot
.51053 .37088 Mdot
.291 .46967 Mdot
.51544 .36514 Mdot
.48317 .40077 Mdot
.28971 .48426 Mdot
.27438 .45479 Mdot
.50207 .42137 Mdot
.53132 .42261 Mdot
.45152 .63542 Mdot
.64015 .33125 Mdot
.84426 .48509 Mdot
.43024 .38565 Mdot
.75344 .35617 Mdot
.43803 .66604 Mdot
.3447 .37369 Mdot
.60029 .61626 Mdot
.42449 .63577 Mdot
.4197 .63357 Mdot
.45014 .66414 Mdot
.43763 .6382 Mdot
.30468 .47012 Mdot
.30846 .57149 Mdot
.61255 .7008 Mdot
.45117 .39351 Mdot
.67401 .73653 Mdot
.29041 .42268 Mdot
.53333 .35496 Mdot
.31484 .51233 Mdot
.68979 .55366 Mdot
.54538 .71353 Mdot
.40095 .66926 Mdot
.62324 .59624 Mdot
.12826 .40753 Mdot
.40506 .65836 Mdot
.55526 .34339 Mdot
.5937 .62701 Mdot
.51705 .38392 Mdot
.51965 .36581 Mdot
.3872 .25903 Mdot
.48139 .34436 Mdot
.65803 .45943 Mdot
.27511 .51858 Mdot
.49806 .58521 Mdot
.58305 .62518 Mdot
.42407 .62746 Mdot
.33886 .48684 Mdot
.41517 .66288 Mdot
.49324 .30485 Mdot
.59253 .5818 Mdot
.53204 .35225 Mdot
.43657 .62713 Mdot
.30203 .4474 Mdot
.526 .41189 Mdot
.67115 .65498 Mdot
.63523 .79061 Mdot
.63703 .44952 Mdot
.34539 .34907 Mdot
.38067 .25821 Mdot
.71364 .58423 Mdot
.48247 .42667 Mdot
.68479 .39703 Mdot
.64229 .77633 Mdot
.27915 .50446 Mdot
.47121 .44432 Mdot
.68156 .52373 Mdot
.52122 .41321 Mdot
.72265 .72413 Mdot
.52272 .3384 Mdot
.62171 .51139 Mdot
.58121 .64724 Mdot
.31399 .4988 Mdot
.47666 .38001 Mdot
.53885 .40453 Mdot
.43108 .23689 Mdot
.55858 .39666 Mdot
.4999 .38714 Mdot
.30898 .51715 Mdot
.40106 .66771 Mdot
.53906 .33365 Mdot
.54189 .67079 Mdot
.61148 .66087 Mdot
.46449 .37717 Mdot
.56007 .63416 Mdot
.28017 .46407 Mdot
.53847 .4032 Mdot
.41125 .6389 Mdot
.47494 .35794 Mdot
.28613 .68612 Mdot
.34677 .46943 Mdot
.5158 .42721 Mdot
.66637 .50209 Mdot
.29704 .30923 Mdot
.31037 .50601 Mdot
.53342 .66704 Mdot
.53213 .43571 Mdot
.50594 .39561 Mdot
.3393 .49492 Mdot
.58352 .66021 Mdot
.70212 .73872 Mdot
.30247 .51999 Mdot
.45789 .63948 Mdot
.33067 .44361 Mdot
.57913 .40832 Mdot
.5787 .61664 Mdot
.5892 .70305 Mdot
.27105 .64643 Mdot
.66149 .32911 Mdot
.52037 .41041 Mdot
.32824 .57991 Mdot
.62766 .64835 Mdot
.32203 .4911 Mdot
.42018 .66162 Mdot
.4578 .4445 Mdot
.3285 .46194 Mdot
.44078 .6229 Mdot
.65529 .49174 Mdot
.4807 .73042 Mdot
.2982 .45471 Mdot
.52034 .50481 Mdot
.39238 .64121 Mdot
.42148 .67665 Mdot
.65697 .23029 Mdot
.33485 .48963 Mdot
.67615 .46684 Mdot
.43199 .65976 Mdot
.64846 .29678 Mdot
.45337 .38158 Mdot
.64989 .3872 Mdot
.19457 .51304 Mdot
.73197 .32816 Mdot
.49926 .75001 Mdot
.6852 .488 Mdot
.42277 .61392 Mdot
.48741 .38988 Mdot
.28927 .49332 Mdot
.28951 .47643 Mdot
.47903 .34664 Mdot
.47553 .40324 Mdot
.53296 .3502 Mdot
.54936 .37588 Mdot
.54551 .28958 Mdot
.56151 .41592 Mdot
.27399 .41467 Mdot
.30847 .49861 Mdot
.48335 .38012 Mdot
.6008 .58877 Mdot
.47698 .33281 Mdot
.4385 .63256 Mdot
.51187 .3802 Mdot
.47856 .37936 Mdot
.46072 .363 Mdot
.40593 .6725 Mdot
.84707 .52611 Mdot
.25991 .34877 Mdot
.83001 .52108 Mdot
.59816 .49364 Mdot
.58032 .59556 Mdot
.51103 .41395 Mdot
.65756 .46872 Mdot
.39422 .33989 Mdot
.48584 .36075 Mdot
.21307 .7206 Mdot
.50264 .37912 Mdot
.80234 .57857 Mdot
.51847 .31189 Mdot
.81012 .45856 Mdot
.67306 .38074 Mdot
.49065 .4025 Mdot
.36628 .56789 Mdot
.37872 .64442 Mdot
.64013 .65416 Mdot
.43429 .64191 Mdot
.60685 .59016 Mdot
.59364 .63572 Mdot
.49329 .60569 Mdot
.5853 .41664 Mdot
.45721 .342 Mdot
.54386 .35273 Mdot
.55928 .59921 Mdot
.27172 .50792 Mdot
.65382 .49907 Mdot
.34503 .50489 Mdot
.82641 .6479 Mdot
.64045 .72443 Mdot
.43652 .68168 Mdot
.64321 .47031 Mdot
.60257 .6549 Mdot
.57279 .64126 Mdot
.67254 .49895 Mdot
.53631 .38276 Mdot
.33205 .48427 Mdot
.69519 .26058 Mdot
.3248 .72129 Mdot
.59611 .16378 Mdot
.30616 .51527 Mdot
.34532 .60465 Mdot
.44891 .63892 Mdot
.61032 .62548 Mdot
.5039 .39364 Mdot
.53161 .39062 Mdot
.36359 .4725 Mdot
.53734 .35495 Mdot
.23129 .49188 Mdot
.49835 .40004 Mdot
.48859 .68974 Mdot
.63351 .47787 Mdot
.4951 .60703 Mdot
.68692 .33485 Mdot
.28027 .49852 Mdot
.50503 .2248 Mdot
.56262 .62781 Mdot
.39377 .3327 Mdot
.42195 .6249 Mdot
.64908 .47729 Mdot
.56942 .61944 Mdot
.65996 .50256 Mdot
.55252 .42826 Mdot
.61835 .60167 Mdot
.69061 .49252 Mdot
.60997 .40427 Mdot
.45037 .37013 Mdot
.22807 .65082 Mdot
.45002 .6617 Mdot
.35019 .50379 Mdot
.4928 .33993 Mdot
.56143 .61123 Mdot
.44561 .43805 Mdot
.52094 .78113 Mdot
.50828 .67818 Mdot
.62525 .65496 Mdot
.52762 .60851 Mdot
.65134 .46262 Mdot
.5613 .74316 Mdot
.3337 .59189 Mdot
.34834 .49022 Mdot
.56041 .39902 Mdot
.81098 .43297 Mdot
.431 .66027 Mdot
.48728 .34729 Mdot
.7559 .4908 Mdot
.42155 .66869 Mdot
.51783 .38614 Mdot
.44501 .62063 Mdot
.29 .47538 Mdot
.34136 .26068 Mdot
.33772 .50249 Mdot
.54811 .36335 Mdot
.40518 .64582 Mdot
.55304 .63291 Mdot
.29492 .48401 Mdot
.53683 .37275 Mdot
.50348 .41978 Mdot
.55161 .55437 Mdot
.49051 .37846 Mdot
.83 .54896 Mdot
.49438 .40176 Mdot
.60692 .63593 Mdot
.46585 .41442 Mdot
.21871 .34975 Mdot
.48568 .60207 Mdot
.33711 .487 Mdot
.617 .66409 Mdot
.58421 .63479 Mdot
.66929 .69106 Mdot
.47428 .63278 Mdot
.52323 .43774 Mdot
.56745 .60548 Mdot
.57387 .26749 Mdot
.40622 .62773 Mdot
.51176 .32711 Mdot
.47294 .50702 Mdot
.67631 .55271 Mdot
.62552 .60128 Mdot
.46207 .4583 Mdot
.28711 .45965 Mdot
.47406 .38612 Mdot
.57305 .64506 Mdot
.56354 .44917 Mdot
.51448 .43326 Mdot
.21377 .50628 Mdot
.55071 .56012 Mdot
.38991 .65333 Mdot
.52342 .31637 Mdot
.50401 .34553 Mdot
.61252 .59858 Mdot
.28259 .4984 Mdot
.40285 .62931 Mdot
.29958 .47447 Mdot
.79682 .43914 Mdot
.23884 .65771 Mdot
.59866 .33511 Mdot
.64968 .50218 Mdot
.70123 .529 Mdot
.80252 .44122 Mdot
.45048 .20195 Mdot
.55211 .23123 Mdot
.76178 .34371 Mdot
.56824 .64583 Mdot
.74013 .50937 Mdot
.58849 .63168 Mdot
.48091 .41476 Mdot
.58085 .61612 Mdot
.80892 .42231 Mdot
.49835 .3973 Mdot
.58894 .61045 Mdot
.47573 .22702 Mdot
.47688 .38732 Mdot
.34642 .49035 Mdot
.81954 .62644 Mdot
.31149 .24537 Mdot
.50407 .67339 Mdot
.6211 .63652 Mdot
.592 .24254 Mdot
.49801 .38643 Mdot
.46786 .41572 Mdot
.29621 .49999 Mdot
.43507 .41676 Mdot
.6768 .45645 Mdot
.6452 .4619 Mdot
.36957 .6225 Mdot
.64721 .43595 Mdot
.52952 .31639 Mdot
.29551 .48724 Mdot
.5417 .29286 Mdot
.67668 .62437 Mdot
.69811 .54732 Mdot
.382 .67782 Mdot
.81906 .62479 Mdot
.2467 .47452 Mdot
.43513 .70466 Mdot
.63247 .56952 Mdot
.32532 .50482 Mdot
.85247 .50635 Mdot
.42981 .64147 Mdot
.24088 .68051 Mdot
.38436 .52827 Mdot
.53388 .38239 Mdot
.40056 .63687 Mdot
.49736 .46274 Mdot
.33146 .23154 Mdot
.31118 .75035 Mdot
.41113 .45026 Mdot
.51598 .33473 Mdot
.66682 .60917 Mdot
.50907 .38586 Mdot
.59976 .76525 Mdot
.4946 .4074 Mdot
.30256 .47698 Mdot
.35578 .62431 Mdot
.4294 .59791 Mdot
.22146 .40638 Mdot
.57099 .75232 Mdot
.68757 .48644 Mdot
.5018 .40064 Mdot
.53359 .37965 Mdot
.68876 .46307 Mdot
.28966 .46646 Mdot
.54308 .35716 Mdot
.50522 .21897 Mdot
.5413 .39785 Mdot
.43361 .63411 Mdot
.34969 .53995 Mdot
.25388 .44429 Mdot
.54994 .3969 Mdot
.27138 .47326 Mdot
.41626 .68479 Mdot
.40741 .64669 Mdot
.52962 .31376 Mdot
.45841 .6553 Mdot
.5004 .37147 Mdot
.34338 .77478 Mdot
.30863 .45245 Mdot
.22717 .55221 Mdot
.32425 .46798 Mdot
.33681 .34342 Mdot
.41166 .67082 Mdot
.50448 .70388 Mdot
.53588 .45607 Mdot
.42573 .64489 Mdot
.35996 .44938 Mdot
.45955 .4208 Mdot
.44463 .39786 Mdot
.66344 .25397 Mdot
.60966 .64404 Mdot
.53972 .56919 Mdot
.45226 .6362 Mdot
.52768 .35785 Mdot
.55165 .41263 Mdot
.42452 .68376 Mdot
.33651 .7523 Mdot
.36443 .22808 Mdot
.4962 .40022 Mdot
.30892 .48386 Mdot
.32126 .48737 Mdot
.47059 .34433 Mdot
.46506 .38476 Mdot
.57827 .6078 Mdot
.56438 .65052 Mdot
.60167 .58391 Mdot
.53563 .57704 Mdot
.50208 .70006 Mdot
.73667 .67269 Mdot
.44973 .66456 Mdot
.32478 .62926 Mdot
.62408 .50872 Mdot
.54811 .3531 Mdot
.62183 .64394 Mdot
.50271 .34747 Mdot
.49246 .36698 Mdot
.4737 .6481 Mdot
.78081 .54367 Mdot
.28622 .43661 Mdot
.27538 .4881 Mdot
.39163 .63761 Mdot
.55146 .32128 Mdot
.43618 .69295 Mdot
.65332 .48096 Mdot
.69539 .28983 Mdot
.42822 .625 Mdot
.34365 .49385 Mdot
.44775 .6592 Mdot
.53436 .39497 Mdot
.5688 .41148 Mdot
.32773 .50117 Mdot
.68149 .45333 Mdot
.43843 .41772 Mdot
.51612 .3894 Mdot
.18608 .52213 Mdot
.68353 .29902 Mdot
.46445 .70507 Mdot
.49171 .40066 Mdot
.54194 .41447 Mdot
.70525 .47394 Mdot
.54041 .39691 Mdot
.51563 .34024 Mdot
.30491 .30954 Mdot
.28895 .65704 Mdot
.64003 .46638 Mdot
.35112 .77204 Mdot
.30965 .51559 Mdot
.82653 .45851 Mdot
.61687 .61933 Mdot
.38696 .5976 Mdot
.32076 .25529 Mdot
.62084 .59223 Mdot
.49735 .75456 Mdot
.83406 .47781 Mdot
.50777 .63469 Mdot
.60085 .68054 Mdot
.27357 .45079 Mdot
.54713 .36627 Mdot
.50936 .39466 Mdot
.66043 .46301 Mdot
.32723 .48 Mdot
.53242 .55324 Mdot
.51851 .83265 Mdot
.50877 .37374 Mdot
.22928 .52841 Mdot
.42322 .79062 Mdot
.67441 .55814 Mdot
.66662 .47944 Mdot
.65346 .45266 Mdot
.50423 .40097 Mdot
.2717 .33061 Mdot
.29004 .48549 Mdot
.53608 .37137 Mdot
.56319 .40975 Mdot
.61642 .63943 Mdot
.33752 .45988 Mdot
.58682 .66129 Mdot
.5306 .71828 Mdot
.82361 .53633 Mdot
.18833 .63583 Mdot
.40408 .66282 Mdot
.56629 .7937 Mdot
.43092 .61698 Mdot
.69169 .3971 Mdot
.63554 .63444 Mdot
.47062 .38334 Mdot
.28061 .49438 Mdot
.52101 .35418 Mdot
.4662 .38671 Mdot
.53557 .38067 Mdot
.5523 .39651 Mdot
.15639 .57835 Mdot
.6855 .49234 Mdot
.51612 .45072 Mdot
.60243 .63871 Mdot
.6578 .75639 Mdot
.61685 .78749 Mdot
.53079 .37647 Mdot
.50103 .41294 Mdot
.31331 .4557 Mdot
.48202 .3461 Mdot
.42116 .61811 Mdot
.32589 .52109 Mdot
.53033 .41296 Mdot
.78921 .6636 Mdot
.52698 .42652 Mdot
.82288 .48298 Mdot
.44768 .65655 Mdot
.2946 .70121 Mdot
.55732 .43799 Mdot
.50637 .66053 Mdot
.54023 .56854 Mdot
.57233 .61394 Mdot
.45397 .62161 Mdot
.59799 .61505 Mdot
.48525 .832 Mdot
.57522 .39336 Mdot
.48557 .39228 Mdot
.55332 .35865 Mdot
.5809 .59491 Mdot
.7445 .70127 Mdot
.59284 .73865 Mdot
.57025 .42694 Mdot
.5892 .59476 Mdot
.26716 .49234 Mdot
.65238 .26542 Mdot
.31326 .46607 Mdot
.66991 .51137 Mdot
.44504 .63672 Mdot
.67668 .45301 Mdot
.76914 .45679 Mdot
.34872 .47731 Mdot
.35907 .48132 Mdot
.61445 .61815 Mdot
.39318 .52954 Mdot
.34045 .18471 Mdot
.38275 .5315 Mdot
.67541 .35991 Mdot
.29748 .49472 Mdot
.5362 .4163 Mdot
.72228 .42302 Mdot
.38025 .54972 Mdot
.59501 .61574 Mdot
.49421 .35843 Mdot
.34265 .2568 Mdot
.57798 .60793 Mdot
.55276 .35421 Mdot
.6034 .64268 Mdot
.43956 .64331 Mdot
.6164 .65019 Mdot
.3587 .50843 Mdot
.51757 .41994 Mdot
.3941 .14792 Mdot
.73174 .48884 Mdot
.49456 .38886 Mdot
.38612 .64571 Mdot
.42404 .75406 Mdot
.47779 .36207 Mdot
.67868 .50268 Mdot
.59182 .60227 Mdot
.40727 .49672 Mdot
.49548 .40312 Mdot
.59178 .59296 Mdot
.35355 .47547 Mdot
.42828 .61142 Mdot
.42258 .24098 Mdot
.50008 .66283 Mdot
.29594 .50161 Mdot
.5648 .49827 Mdot
.46272 .63266 Mdot
.54292 .41292 Mdot
.55896 .40053 Mdot
.31259 .4835 Mdot
.6202 .39115 Mdot
.45906 .3907 Mdot
.47907 .42329 Mdot
.61427 .63345 Mdot
.5979 .61078 Mdot
.51019 .2451 Mdot
.57263 .65396 Mdot
.56744 .41448 Mdot
.31193 .48111 Mdot
.47737 .37694 Mdot
.31919 .45389 Mdot
.4808 .34749 Mdot
.5934 .3776 Mdot
.28849 .46772 Mdot
.48359 .65588 Mdot
.49203 .36235 Mdot
.43497 .36826 Mdot
.47847 .35461 Mdot
.54648 .36903 Mdot
.57557 .61563 Mdot
.65946 .47763 Mdot
.56466 .38574 Mdot
.69708 .44872 Mdot
.65672 .49877 Mdot
.42383 .60235 Mdot
.61483 .64161 Mdot
.68519 .47059 Mdot
.43697 .80073 Mdot
.61574 .59458 Mdot
.66932 .45838 Mdot
.6185 .78658 Mdot
.43437 .66856 Mdot
.29133 .45564 Mdot
.47611 .39063 Mdot
.78006 .43048 Mdot
.27173 .42793 Mdot
.59379 .67228 Mdot
.49427 .3984 Mdot
.48811 .34869 Mdot
.29175 .51692 Mdot
.51914 .84963 Mdot
.59254 .58198 Mdot
.5242 .43246 Mdot
.34409 .48062 Mdot
.51102 .86666 Mdot
.60099 .6341 Mdot
.66395 .45908 Mdot
.43528 .6718 Mdot
.31591 .42938 Mdot
.26876 .64606 Mdot
.39006 .66642 Mdot
.6515 .60094 Mdot
.53463 .71145 Mdot
.5371 .4344 Mdot
.62463 .64379 Mdot
.61465 .1887 Mdot
.50143 .28981 Mdot
.5083 .59404 Mdot
.5996 .24538 Mdot
.31909 .50562 Mdot
.42772 .61736 Mdot
.6845 .49028 Mdot
.29965 .51255 Mdot
.35111 .4758 Mdot
.43634 .67949 Mdot
.27746 .34205 Mdot
.46566 .50601 Mdot
.42573 .63228 Mdot
.72811 .34714 Mdot
.74523 .64145 Mdot
.6236 .64184 Mdot
.67798 .45708 Mdot
.76949 .47169 Mdot
.30189 .47087 Mdot
.8361 .60348 Mdot
.66775 .25205 Mdot
.4999 .38687 Mdot
.68308 .47394 Mdot
.74768 .68523 Mdot
.57293 .83029 Mdot
.41571 .66904 Mdot
.40127 .60247 Mdot
.66361 .45447 Mdot
.4938 .34026 Mdot
.64896 .27471 Mdot
.47556 .41724 Mdot
.44715 .64144 Mdot
.44508 .24611 Mdot
.35037 .47937 Mdot
.43033 .6787 Mdot
.69139 .28343 Mdot
.50204 .3706 Mdot
.49053 .36171 Mdot
.70869 .35382 Mdot
.28969 .50925 Mdot
.57216 .61359 Mdot
.55157 .4253 Mdot
.51422 .38607 Mdot
.56645 .37392 Mdot
.52351 .31891 Mdot
.31113 .29158 Mdot
.48618 .4143 Mdot
.63733 .73645 Mdot
.51283 .33306 Mdot
.5025 .36047 Mdot
.27351 .46961 Mdot
.18864 .64912 Mdot
.55491 .72337 Mdot
.51223 .38266 Mdot
.53551 .42367 Mdot
.43384 .67665 Mdot
.41667 .51597 Mdot
.40397 .5175 Mdot
.41168 .48944 Mdot
.57237 .23541 Mdot
.45212 .36094 Mdot
.33607 .48108 Mdot
.69228 .49271 Mdot
.52828 .43405 Mdot
.33926 .48103 Mdot
.45654 .3745 Mdot
.57834 .60566 Mdot
.61445 .59323 Mdot
.52299 .29437 Mdot
.68889 .47422 Mdot
.2548 .5296 Mdot
.32102 .62753 Mdot
.61313 .59647 Mdot
.48401 .39466 Mdot
.47773 .62346 Mdot
.57227 .64326 Mdot
.51669 .64244 Mdot
.62724 .42382 Mdot
.28645 .4927 Mdot
.31084 .50014 Mdot
.64752 .38913 Mdot
.50397 .73985 Mdot
.19175 .45998 Mdot
.44109 .64276 Mdot
.53218 .44493 Mdot
.35006 .58265 Mdot
.30913 .50279 Mdot
.71227 .40868 Mdot
.6857 .4747 Mdot
.4247 .66833 Mdot
.66115 .64813 Mdot
.32134 .45856 Mdot
.34437 .45721 Mdot
.49578 .33249 Mdot
.52328 .38784 Mdot
.54416 .23069 Mdot
.71108 .45885 Mdot
.39062 .67039 Mdot
.67212 .45601 Mdot
.63509 .63537 Mdot
.49504 .42376 Mdot
.2878 .47118 Mdot
.72865 .66142 Mdot
.53381 .43176 Mdot
.57403 .63291 Mdot
.31784 .50307 Mdot
.65126 .46154 Mdot
.68516 .50062 Mdot
.54787 .37746 Mdot
.46644 .25847 Mdot
.42158 .63987 Mdot
.33084 .50477 Mdot
.4448 .69134 Mdot
.4657 .40903 Mdot
.52069 .39616 Mdot
.48374 .31566 Mdot
.38994 .66959 Mdot
.3472 .69603 Mdot
.65352 .50252 Mdot
.32849 .48531 Mdot
.49107 .41431 Mdot
.68207 .46127 Mdot
.33574 .63156 Mdot
.62914 .65172 Mdot
.61232 .65255 Mdot
.69222 .49635 Mdot
.67454 .47806 Mdot
.66677 .50465 Mdot
.83727 .60229 Mdot
.29636 .52246 Mdot
.24823 .47106 Mdot
.47456 .42862 Mdot
.67166 .37285 Mdot
.49957 .4552 Mdot
.39549 .63634 Mdot
.60575 .64568 Mdot
.4707 .37066 Mdot
.54821 .39462 Mdot
.52911 .3108 Mdot
.22227 .53449 Mdot
.29192 .42869 Mdot
.3434 .4633 Mdot
.56697 .42074 Mdot
.62019 .63218 Mdot
.83597 .64226 Mdot
.70874 .25653 Mdot
.55949 .43576 Mdot
.46416 .50249 Mdot
.28317 .47557 Mdot
.44762 .66824 Mdot
.73951 .39582 Mdot
.4384 .66781 Mdot
.328 .48897 Mdot
.48777 .41727 Mdot
.32266 .64649 Mdot
.70648 .47758 Mdot
.5339 .35947 Mdot
.44783 .64704 Mdot
.52951 .35154 Mdot
.39122 .66985 Mdot
.79452 .45382 Mdot
.58428 .20017 Mdot
.50251 .38045 Mdot
.48567 .4482 Mdot
.56664 .21946 Mdot
.53 .37117 Mdot
.70521 .49873 Mdot
.28287 .47558 Mdot
.45401 .23772 Mdot
.44988 .41386 Mdot
.47125 .28296 Mdot
.46956 .41452 Mdot
.43459 .22865 Mdot
.52374 .39537 Mdot
.66831 .56297 Mdot
.51553 .4253 Mdot
.52527 .3429 Mdot
.40167 .65533 Mdot
.42885 .67869 Mdot
.29089 .44997 Mdot
.55823 .62017 Mdot
.82754 .50012 Mdot
.5173 .39251 Mdot
.51568 .68187 Mdot
.31573 .68165 Mdot
.67218 .47893 Mdot
.32531 .48393 Mdot
.56809 .85002 Mdot
.45376 .63422 Mdot
.63682 .22911 Mdot
.5222 .2458 Mdot
.26679 .60556 Mdot
.74547 .46533 Mdot
.42637 .76943 Mdot
.64807 .46952 Mdot
.46077 .36422 Mdot
.75747 .5959 Mdot
.66228 .56771 Mdot
.62064 .41863 Mdot
.46183 .62596 Mdot
.41723 .3115 Mdot
.77711 .56148 Mdot
.68721 .50451 Mdot
.65768 .45373 Mdot
.39785 .66932 Mdot
.57856 .67689 Mdot
.5843 .41363 Mdot
.68338 .47942 Mdot
.58837 .58889 Mdot
.622 .60217 Mdot
.60572 .58173 Mdot
.28824 .48245 Mdot
.67964 .24796 Mdot
.43684 .68621 Mdot
.39126 .64973 Mdot
.53898 .62931 Mdot
.40102 .42157 Mdot
.33096 .52452 Mdot
.60841 .61977 Mdot
.59589 .65915 Mdot
.28315 .47083 Mdot
.5514 .33469 Mdot
.57258 .36062 Mdot
.51 .37794 Mdot
.6582 .47166 Mdot
.52733 .39073 Mdot
.58826 .59687 Mdot
.41137 .66574 Mdot
.59791 .65717 Mdot
.38655 .64176 Mdot
.71591 .69304 Mdot
.54111 .3756 Mdot
.5148 .42209 Mdot
.18771 .56455 Mdot
.33936 .44948 Mdot
.67484 .72751 Mdot
.48141 .68297 Mdot
.59046 .63311 Mdot
.51255 .3401 Mdot
.32999 .52006 Mdot
.70929 .4604 Mdot
.2022 .64677 Mdot
.46296 .38495 Mdot
.30094 .4648 Mdot
.49597 .42241 Mdot
.54054 .28231 Mdot
.1978 .38236 Mdot
.30855 .47374 Mdot
.19993 .50108 Mdot
.53254 .42388 Mdot
.47566 .80014 Mdot
.5154 .32876 Mdot
.60735 .31653 Mdot
.45909 .39093 Mdot
.30895 .51593 Mdot
.51327 .37741 Mdot
.33449 .51651 Mdot
.6172 .60562 Mdot
.4428 .67058 Mdot
.29969 .50147 Mdot
.55614 .39572 Mdot
.40256 .09848 Mdot
.4406 .64928 Mdot
.50312 .39708 Mdot
.41085 .67293 Mdot
.32687 .47621 Mdot
.3119 .51154 Mdot
.56986 .82276 Mdot
.5314 .72062 Mdot
.43788 .64429 Mdot
.49552 .42346 Mdot
.51861 .79286 Mdot
.47199 .39845 Mdot
.58735 .26736 Mdot
.55516 .34437 Mdot
.46723 .41827 Mdot
.62261 .79099 Mdot
.38942 .65306 Mdot
.18948 .45362 Mdot
.60467 .81107 Mdot
.65529 .75924 Mdot
.35846 .45937 Mdot
.69412 .50006 Mdot
.85154 .51391 Mdot
.50062 .70138 Mdot
.58801 .59402 Mdot
.47518 .36194 Mdot
.36345 .51452 Mdot
.41753 .63916 Mdot
.65746 .48355 Mdot
.50266 .38171 Mdot
.60659 .65808 Mdot
.41439 .21138 Mdot
.41231 .61776 Mdot
.3094 .46997 Mdot
.27534 .50396 Mdot
.3588 .80477 Mdot
.49087 .40552 Mdot
.52164 .41898 Mdot
.44594 .63727 Mdot
.39026 .75866 Mdot
.64703 .48519 Mdot
.47527 .22447 Mdot
.43626 .64583 Mdot
.49864 .54647 Mdot
.3418 .48757 Mdot
.49155 .34734 Mdot
.79666 .63437 Mdot
.6576 .67503 Mdot
.19555 .55363 Mdot
.65839 .4682 Mdot
.59185 .26896 Mdot
.31169 .51597 Mdot
.42481 .66105 Mdot
.46876 .74342 Mdot
.45122 .35774 Mdot
.50515 .34911 Mdot
.60119 .28199 Mdot
.42999 .59931 Mdot
.40679 .46284 Mdot
.46263 .39372 Mdot
.5323 .57879 Mdot
.46544 .37228 Mdot
.44181 .40696 Mdot
.56839 .36756 Mdot
.51961 .40584 Mdot
.29227 .46833 Mdot
.41668 .37431 Mdot
.57004 .60767 Mdot
.25174 .49813 Mdot
.49608 .5531 Mdot
.49577 .39345 Mdot
.48968 .42829 Mdot
.38118 .4356 Mdot
.48662 .76706 Mdot
.30229 .50017 Mdot
.36103 .48577 Mdot
.45895 .64993 Mdot
.56384 .34553 Mdot
.55883 .62761 Mdot
.45139 .43683 Mdot
.57442 .62313 Mdot
.28928 .47107 Mdot
.59435 .63353 Mdot
.4286 .67473 Mdot
.62583 .63312 Mdot
.503 .70014 Mdot
.43805 .6583 Mdot
.28888 .49677 Mdot
.52946 .40915 Mdot
.38719 .64345 Mdot
.66543 .31996 Mdot
.65917 .46988 Mdot
.65734 .80385 Mdot
.53017 .41393 Mdot
.28253 .65648 Mdot
.57294 .44908 Mdot
.5961 .65821 Mdot
.19409 .39235 Mdot
.27653 .48488 Mdot
.64532 .45562 Mdot
.28106 .50341 Mdot
.67323 .27763 Mdot
.6691 .47162 Mdot
.65906 .78366 Mdot
.58467 .54188 Mdot
.67648 .29359 Mdot
.55114 .33008 Mdot
.6975 .33104 Mdot
.62973 .61163 Mdot
.41511 .64102 Mdot
.48032 .7473 Mdot
.51966 .3419 Mdot
.48684 .18668 Mdot
.27005 .48701 Mdot
.55995 .6165 Mdot
.41665 .66169 Mdot
.40126 .62995 Mdot
.50581 .43978 Mdot
.72142 .5591 Mdot
.5099 .34652 Mdot
.50689 .72946 Mdot
.57989 .24346 Mdot
.2354 .46838 Mdot
.49874 .39972 Mdot
.6134 .5997 Mdot
.49571 .42227 Mdot
.64561 .49842 Mdot
.65677 .222 Mdot
.43541 .40576 Mdot
.4626 .70051 Mdot
.72483 .49737 Mdot
.33598 .49844 Mdot
.59001 .44514 Mdot
.4811 .69976 Mdot
.48919 .40717 Mdot
.12382 .54783 Mdot
.67479 .45887 Mdot
.75774 .59071 Mdot
.54809 .4116 Mdot
.52333 .43862 Mdot
.47361 .58001 Mdot
.25654 .6307 Mdot
.66608 .65857 Mdot
.52386 .36419 Mdot
.62736 .30339 Mdot
.39203 .66212 Mdot
.4839 .34709 Mdot
.50779 .39643 Mdot
.28091 .37286 Mdot
.40073 .62758 Mdot
.58709 .63964 Mdot
.62339 .59412 Mdot
.59384 .67096 Mdot
.6403 .48907 Mdot
.37405 .68439 Mdot
.69921 .38888 Mdot
.36079 .21995 Mdot
.66889 .44779 Mdot
.54673 .39416 Mdot
.72914 .47011 Mdot
.48504 .4191 Mdot
.66529 .48755 Mdot
.40295 .62531 Mdot
.30322 .50413 Mdot
.35253 .59194 Mdot
.61535 .59048 Mdot
.45664 .34425 Mdot
.64504 .48453 Mdot
.28858 .49268 Mdot
.75161 .43296 Mdot
.33597 .49462 Mdot
.42672 .64818 Mdot
.38671 .69317 Mdot
.65993 .48686 Mdot
.32725 .47194 Mdot
.44708 .70153 Mdot
.55024 .83593 Mdot
.5735 .38266 Mdot
.36334 .68728 Mdot
.33047 .51141 Mdot
.35823 .49889 Mdot
.32414 .51826 Mdot
.53785 .35691 Mdot
.46658 .50306 Mdot
.45284 .39959 Mdot
.38938 .65555 Mdot
.59931 .6433 Mdot
.53617 .20897 Mdot
.60278 .71251 Mdot
.52747 .4944 Mdot
.54891 .43796 Mdot
.50316 .3691 Mdot
.50432 .40059 Mdot
.44932 .4164 Mdot
.47728 .72168 Mdot
.51516 .35092 Mdot
.40111 .65429 Mdot
.58929 .60134 Mdot
.46006 .36487 Mdot
.56844 .5793 Mdot
.64939 .7546 Mdot
.68519 .45339 Mdot
.37056 .65128 Mdot
.71292 .24482 Mdot
.29142 .49471 Mdot
.6162 .66387 Mdot
.60016 .59333 Mdot
.65377 .48835 Mdot
.42695 .63561 Mdot
.33643 .49156 Mdot
.5793 .26887 Mdot
.65854 .49954 Mdot
.51375 .38072 Mdot
.45233 .49243 Mdot
.52344 .18564 Mdot
.46299 .36276 Mdot
.47676 .36854 Mdot
.6172 .5815 Mdot
.76163 .57114 Mdot
.46884 .13925 Mdot
.71531 .38878 Mdot
.6588 .48144 Mdot
.69854 .4758 Mdot
.29191 .45949 Mdot
.45762 .42018 Mdot
.38893 .66262 Mdot
.38309 .51608 Mdot
.38268 .71294 Mdot
.29589 .54874 Mdot
.21229 .58938 Mdot
.46678 .37412 Mdot
.35969 .76477 Mdot
.49886 .36987 Mdot
.29657 .52223 Mdot
.29202 .47205 Mdot
.30128 .48669 Mdot
.41561 .64164 Mdot
.35835 .35794 Mdot
.40478 .64447 Mdot
.69247 .21348 Mdot
.32004 .51255 Mdot
.57515 .54707 Mdot
.61528 .62539 Mdot
.57283 .41979 Mdot
.65716 .45788 Mdot
.38372 .6961 Mdot
.49577 .30445 Mdot
.24123 .35427 Mdot
.56398 .61068 Mdot
.29023 .49906 Mdot
.40862 .75946 Mdot
.77859 .34875 Mdot
.41044 .50206 Mdot
.53303 .30796 Mdot
.74235 .3984 Mdot
.67037 .48202 Mdot
.19516 .55567 Mdot
.66671 .45504 Mdot
.44804 .64811 Mdot
.51017 .42023 Mdot
.52068 .4129 Mdot
.46566 .37028 Mdot
.53672 .37568 Mdot
.46373 .64784 Mdot
.56178 .39647 Mdot
.21886 .34963 Mdot
.60846 .58827 Mdot
.60912 .38498 Mdot
.6641 .45725 Mdot
.45039 .61597 Mdot
.58933 .60035 Mdot
.48548 .76424 Mdot
.6855 .33782 Mdot
.49623 .40187 Mdot
.47163 .36806 Mdot
.62255 .21669 Mdot
.46292 .39584 Mdot
.56683 .4403 Mdot
.58992 .59335 Mdot
.5337 .48422 Mdot
.68119 .45232 Mdot
.69827 .46994 Mdot
.43872 .66006 Mdot
.29264 .46922 Mdot
.6751 .46193 Mdot
.61572 .6293 Mdot
.55129 .43611 Mdot
.56018 .40711 Mdot
.32889 .51203 Mdot
.63594 .21543 Mdot
.65724 .50514 Mdot
.50347 .79496 Mdot
.28201 .49232 Mdot
.2994 .44193 Mdot
.50404 .3491 Mdot
.20728 .54677 Mdot
.3665 .48871 Mdot
.64328 .4528 Mdot
.45249 .61797 Mdot
.72659 .37536 Mdot
.44159 .62435 Mdot
.31099 .46821 Mdot
.51686 .43384 Mdot
.28528 .48097 Mdot
.49224 .40244 Mdot
.80604 .36694 Mdot
.52266 .40755 Mdot
.3425 .2279 Mdot
.63638 .37603 Mdot
.60786 .60621 Mdot
.46758 .77165 Mdot
.61631 .61884 Mdot
.2839 .50033 Mdot
.5321 .43496 Mdot
.64461 .46835 Mdot
.61695 .77414 Mdot
.37659 .50636 Mdot
.57833 .64573 Mdot
.55647 .60804 Mdot
.44486 .62343 Mdot
.45887 .38555 Mdot
.50848 .34954 Mdot
.59128 .60992 Mdot
.22786 .48086 Mdot
.32557 .46229 Mdot
.50104 .41581 Mdot
.50486 .36484 Mdot
.60978 .60954 Mdot
.5318 .83841 Mdot
.4276 .34359 Mdot
.51141 .41499 Mdot
.64402 .70791 Mdot
.3952 .63803 Mdot
.57511 .40425 Mdot
.49469 .4513 Mdot
.67734 .47875 Mdot
.35803 .27122 Mdot
.69719 .27305 Mdot
.407 .62189 Mdot
.60212 .59095 Mdot
.49099 .40987 Mdot
.61207 .59765 Mdot
.56142 .40361 Mdot
.25224 .62002 Mdot
.62825 .64932 Mdot
.4807 .42581 Mdot
.54034 .32496 Mdot
.29026 .51019 Mdot
.46858 .37201 Mdot
.37452 .42105 Mdot
.56778 .63095 Mdot
.51003 .43924 Mdot
.45902 .25639 Mdot
.4271 .62918 Mdot
.54732 .32514 Mdot
.67258 .5001 Mdot
.57385 .264 Mdot
.30411 .62806 Mdot
.77938 .52484 Mdot
.70013 .47131 Mdot
.5275 .35136 Mdot
.55813 .60883 Mdot
.39508 .67359 Mdot
.309 .24922 Mdot
.4947 .34122 Mdot
.44688 .64349 Mdot
.41332 .66619 Mdot
.65364 .47986 Mdot
.19981 .66681 Mdot
.54985 .40275 Mdot
.53044 .37869 Mdot
.31389 .39053 Mdot
.35024 .46204 Mdot
.52791 .39893 Mdot
.54039 .4064 Mdot
.40006 .65689 Mdot
.58306 .36549 Mdot
.41264 .33507 Mdot
.45622 .22503 Mdot
.40528 .68416 Mdot
.34753 .55922 Mdot
.62926 .62843 Mdot
.69046 .46753 Mdot
.32514 .49919 Mdot
.64413 .47969 Mdot
.61793 .64363 Mdot
.53846 .40667 Mdot
.45396 .65418 Mdot
.34136 .41466 Mdot
.39858 .67009 Mdot
.7647 .50986 Mdot
.34574 .49797 Mdot
.38467 .5756 Mdot
.13861 .5826 Mdot
.56494 .76398 Mdot
.47429 .61012 Mdot
.67248 .47862 Mdot
.60756 .69214 Mdot
.5035 .36588 Mdot
.19327 .56239 Mdot
.54567 .39211 Mdot
.45202 .25395 Mdot
.60131 .58687 Mdot
.60055 .58364 Mdot
.50988 .41793 Mdot
.57744 .24582 Mdot
.39656 .67515 Mdot
.40481 .62958 Mdot
.48623 .43142 Mdot
.42646 .6447 Mdot
.52411 .38324 Mdot
.58223 .60351 Mdot
.17271 .47847 Mdot
.50699 .38127 Mdot
.44897 .42229 Mdot
.26131 .62202 Mdot
.62145 .79731 Mdot
.72337 .51504 Mdot
.41554 .82789 Mdot
.76163 .32011 Mdot
.42452 .64555 Mdot
.45976 .41579 Mdot
.34158 .55949 Mdot
.61044 .57941 Mdot
.43232 .70705 Mdot
.53558 .4013 Mdot
.54225 .39482 Mdot
.52379 .34129 Mdot
.4863 .36448 Mdot
.21085 .63971 Mdot
.37638 .51417 Mdot
.35598 .30431 Mdot
.46638 .38245 Mdot
.6794 .31757 Mdot
.44609 .65542 Mdot
.32921 .43321 Mdot
.65983 .44639 Mdot
.46738 .37301 Mdot
.25803 .4971 Mdot
.45132 .66802 Mdot
.68508 .20398 Mdot
.45045 .64717 Mdot
.58414 .63388 Mdot
.42046 .67783 Mdot
.49072 .37992 Mdot
.32077 .48735 Mdot
.4301 .54707 Mdot
.5636 .74025 Mdot
.58596 .59447 Mdot
.49458 .38941 Mdot
.55119 .56776 Mdot
.56935 .60676 Mdot
.6655 .75014 Mdot
.32068 .49425 Mdot
.63013 .3104 Mdot
.2872 .47665 Mdot
.4954 .43522 Mdot
.49832 .43536 Mdot
.43279 .68514 Mdot
.42774 .67604 Mdot
.28832 .4748 Mdot
.2159 .70134 Mdot
.6626 .5052 Mdot
.30061 .48325 Mdot
.44941 .35688 Mdot
.45395 .516 Mdot
.316 .48754 Mdot
.65902 .51825 Mdot
.40609 .66315 Mdot
.31146 .44761 Mdot
.51751 .33369 Mdot
.72536 .33838 Mdot
.69565 .49101 Mdot
.63512 .61899 Mdot
.73254 .42903 Mdot
.56875 .63734 Mdot
.45454 .6214 Mdot
.61581 .61662 Mdot
.39269 .65723 Mdot
.3073 .65341 Mdot
.24629 .49666 Mdot
.46254 .59751 Mdot
.46011 .63249 Mdot
.614 .618 Mdot
.50532 .42219 Mdot
.73175 .49001 Mdot
.486 .43891 Mdot
.55458 .37293 Mdot
.39658 .6435 Mdot
.29868 .51143 Mdot
.36502 .48386 Mdot
.6545 .28288 Mdot
.29939 .46228 Mdot
.57465 .6356 Mdot
.24551 .33667 Mdot
.53051 .68374 Mdot
.43313 .62351 Mdot
.43836 .6737 Mdot
.47494 .41435 Mdot
.59717 .61528 Mdot
.58964 .59054 Mdot
.44614 .62613 Mdot
.23671 .55473 Mdot
.47225 .43986 Mdot
.35511 .50788 Mdot
.34613 .45737 Mdot
.30987 .47668 Mdot
.32896 .51699 Mdot
.42443 .33601 Mdot
.4265 .66982 Mdot
.29325 .50841 Mdot
.4721 .41265 Mdot
.53954 .39754 Mdot
.37537 .53933 Mdot
.69458 .4834 Mdot
.45856 .36447 Mdot
.56636 .36227 Mdot
.49209 .34816 Mdot
.61692 .65147 Mdot
.44228 .45316 Mdot
.62065 .6552 Mdot
.56976 .59753 Mdot
.57948 .59051 Mdot
.5004 .70042 Mdot
.61599 .22927 Mdot
.77441 .37729 Mdot
.52676 .43216 Mdot
.39879 .77776 Mdot
.60082 .62585 Mdot
.22061 .36932 Mdot
.34963 .70003 Mdot
.50787 .34073 Mdot
.67141 .66383 Mdot
.59557 .60796 Mdot
.28038 .47604 Mdot
.53093 .4043 Mdot
.59115 .66723 Mdot
.67706 .50005 Mdot
.49903 .44032 Mdot
.63057 .64809 Mdot
.32941 .4746 Mdot
.63816 .45723 Mdot
.32732 .44651 Mdot
.58164 .58888 Mdot
.52895 .31515 Mdot
.23333 .2719 Mdot
.54919 .63429 Mdot
.48389 .81486 Mdot
.59299 .36024 Mdot
.50235 .41865 Mdot
.59902 .66475 Mdot
.32035 .43987 Mdot
.45095 .61955 Mdot
.56071 .52596 Mdot
.32339 .45112 Mdot
.60079 .58357 Mdot
.58031 .65075 Mdot
.58666 .59391 Mdot
.3447 .46286 Mdot
.45818 .35629 Mdot
.32698 .45509 Mdot
.4144 .67773 Mdot
.47395 .39078 Mdot
.80205 .44397 Mdot
.38012 .75618 Mdot
.28121 .48692 Mdot
.58941 .64525 Mdot
.70568 .47584 Mdot
.49995 .37535 Mdot
.38182 .76225 Mdot
.50109 .42204 Mdot
.39286 .64821 Mdot
.31514 .30005 Mdot
.34503 .42599 Mdot
.46686 .41921 Mdot
.47401 .41132 Mdot
.4055 .62999 Mdot
.49886 .388 Mdot
.45899 .38956 Mdot
.50019 .70444 Mdot
.33889 .46275 Mdot
.51189 .37351 Mdot
.60715 .63986 Mdot
.53988 .70613 Mdot
.46299 .43462 Mdot
.56145 .6862 Mdot
.62173 .30792 Mdot
.3046 .31565 Mdot
.54525 .39365 Mdot
.43452 .47639 Mdot
.49499 .3568 Mdot
.53698 .3645 Mdot
.47953 .41369 Mdot
.25697 .70238 Mdot
.63051 .6453 Mdot
.60368 .59609 Mdot
.6991 .48179 Mdot
.62335 .30921 Mdot
.6819 .47651 Mdot
.40708 .66569 Mdot
.73124 .57034 Mdot
.62215 .6543 Mdot
.31863 .46784 Mdot
.52887 .35573 Mdot
.54944 .63412 Mdot
.49622 .34639 Mdot
.48966 .38203 Mdot
.56014 .63418 Mdot
.63105 .63114 Mdot
.77255 .56382 Mdot
.69164 .49071 Mdot
.30126 .49149 Mdot
.4554 .38917 Mdot
.65038 .49453 Mdot
.54708 .39962 Mdot
.67271 .37521 Mdot
.30372 .48891 Mdot
.33516 .4601 Mdot
.36513 .48777 Mdot
.53598 .40938 Mdot
.49491 .37888 Mdot
.40421 .64384 Mdot
.27842 .4934 Mdot
.43122 .62981 Mdot
.54266 .54768 Mdot
.68917 .67618 Mdot
.53586 .4011 Mdot
.35612 .65713 Mdot
.68766 .48327 Mdot
.58325 .64841 Mdot
.53679 .19162 Mdot
.69911 .48251 Mdot
.4933 .40516 Mdot
.56233 .60887 Mdot
.66979 .49142 Mdot
.57234 .2859 Mdot
.67052 .21343 Mdot
.70323 .46605 Mdot
.47169 .41204 Mdot
.57195 .34418 Mdot
.40232 .82192 Mdot
.70032 .46624 Mdot
.43895 .66962 Mdot
.53475 .4105 Mdot
.32231 .53107 Mdot
.64356 .48106 Mdot
.62729 .73916 Mdot
.59318 .60316 Mdot
.71771 .31984 Mdot
.44919 .33395 Mdot
.22071 .47182 Mdot
.69588 .47199 Mdot
.33261 .49075 Mdot
.56011 .45094 Mdot
.50126 .35062 Mdot
.70163 .47158 Mdot
.47641 .63553 Mdot
.58064 .61357 Mdot
.54686 .72178 Mdot
.34466 .46212 Mdot
.47977 .64775 Mdot
.59607 .6492 Mdot
.51467 .7954 Mdot
.39371 .23241 Mdot
.5757 .36922 Mdot
.37853 .80027 Mdot
.40431 .72561 Mdot
.49716 .33369 Mdot
.70491 .45828 Mdot
.38983 .6377 Mdot
.45667 .65134 Mdot
.43042 .64883 Mdot
.3129 .67223 Mdot
.41304 .48902 Mdot
.62605 .65979 Mdot
.40937 .69649 Mdot
.69029 .46873 Mdot
.71849 .36232 Mdot
.55694 .37921 Mdot
.50472 .3708 Mdot
.45864 .40303 Mdot
.46906 .36666 Mdot
.50435 .35617 Mdot
.43219 .6374 Mdot
.2961 .6494 Mdot
.40015 .51293 Mdot
.30972 .48725 Mdot
.75861 .55551 Mdot
.61216 .6282 Mdot
.63544 .65386 Mdot
.67143 .49574 Mdot
.58553 .76555 Mdot
.56689 .57978 Mdot
.59288 .63443 Mdot
.48114 .34137 Mdot
.32355 .45869 Mdot
.56908 .43234 Mdot
.47298 .41175 Mdot
.57483 .63155 Mdot
.49171 .57787 Mdot
.39629 .38351 Mdot
.63548 .43499 Mdot
.64432 .44369 Mdot
.43284 .49968 Mdot
.7015 .4844 Mdot
.54262 .43011 Mdot
.19864 .39039 Mdot
.61842 .64397 Mdot
.58701 .62358 Mdot
.69255 .48127 Mdot
.20399 .541 Mdot
.32225 .50409 Mdot
.36198 .6213 Mdot
.40339 .66941 Mdot
.51024 .43506 Mdot
.43805 .20865 Mdot
.60303 .411 Mdot
.71105 .56416 Mdot
.43732 .64762 Mdot
.61742 .60731 Mdot
.52337 .44637 Mdot
.46926 .40211 Mdot
.68491 .48661 Mdot
.7885 .57753 Mdot
.57272 .4044 Mdot
.73389 .72505 Mdot
.58443 .1997 Mdot
.67507 .26799 Mdot
.50588 .34934 Mdot
.33967 .46165 Mdot
.63158 .6079 Mdot
.68062 .458 Mdot
.45456 .34898 Mdot
.71116 .2694 Mdot
.33001 .50971 Mdot
.43506 .65721 Mdot
.47245 .55465 Mdot
.72539 .38283 Mdot
.54785 .36707 Mdot
.54137 .39929 Mdot
.54166 .36684 Mdot
.59111 .15151 Mdot
.6209 .65195 Mdot
.28091 .48048 Mdot
.65482 .48247 Mdot
.30561 .46191 Mdot
.61065 .60425 Mdot
.47536 .59883 Mdot
.51057 .42567 Mdot
.33551 .50672 Mdot
.33191 .49238 Mdot
.45162 .63989 Mdot
.43464 .61208 Mdot
.50306 .55659 Mdot
.52249 .4061 Mdot
.55072 .62205 Mdot
.29174 .50922 Mdot
.44434 .48958 Mdot
.67126 .47187 Mdot
.40338 .66196 Mdot
.46775 .37674 Mdot
.62607 .64479 Mdot
.5453 .34066 Mdot
.30792 .50022 Mdot
.59321 .63373 Mdot
.72415 .66391 Mdot
.69144 .4575 Mdot
.53743 .39012 Mdot
.70135 .50975 Mdot
.59748 .59103 Mdot
.50159 .36444 Mdot
.53478 .80333 Mdot
.65918 .51806 Mdot
.59952 .73646 Mdot
.57514 .59602 Mdot
.50571 .67021 Mdot
.29661 .45627 Mdot
.31963 .69945 Mdot
.58426 .62789 Mdot
.47696 .79075 Mdot
.75434 .63649 Mdot
.54243 .44217 Mdot
.30112 .47217 Mdot
.41261 .72675 Mdot
.82715 .44526 Mdot
.47812 .82612 Mdot
.50418 .39706 Mdot
.57288 .65386 Mdot
.67761 .49025 Mdot
.42728 .62292 Mdot
.62989 .70362 Mdot
.62879 .4714 Mdot
.58053 .58393 Mdot
.48006 .4136 Mdot
.33159 .48282 Mdot
.40651 .65401 Mdot
.30699 .6341 Mdot
.6135 .63346 Mdot
.59858 .64516 Mdot
.51098 .44573 Mdot
.68638 .47465 Mdot
.35156 .73656 Mdot
.58324 .60014 Mdot
.60239 .20952 Mdot
.61062 .68021 Mdot
.65589 .50009 Mdot
.48625 .35934 Mdot
.65498 .27706 Mdot
.45187 .41306 Mdot
.5652 .80967 Mdot
.61241 .62406 Mdot
.30611 .49535 Mdot
.53518 .35165 Mdot
.49142 .23434 Mdot
.57609 .63732 Mdot
.45363 .50046 Mdot
.67025 .5489 Mdot
.41491 .67016 Mdot
.53229 .1911 Mdot
.5299 .39096 Mdot
.39567 .67385 Mdot
.68374 .48566 Mdot
.51526 .41108 Mdot
.49313 .37673 Mdot
.29377 .51702 Mdot
.45002 .63513 Mdot
.77363 .57929 Mdot
.43587 .67655 Mdot
.44825 .65792 Mdot
.32524 .52311 Mdot
.52068 .37134 Mdot
.58466 .63577 Mdot
.59472 .60948 Mdot
.51985 .33159 Mdot
.15795 .47314 Mdot
.32615 .50464 Mdot
.6285 .59782 Mdot
.5728 .143 Mdot
.51891 .32499 Mdot
.51708 .19458 Mdot
.78528 .5868 Mdot
.38761 .65767 Mdot
.47068 .4117 Mdot
.32733 .47447 Mdot
.65984 .59565 Mdot
.59475 .64455 Mdot
.5267 .34015 Mdot
.40837 .65405 Mdot
.68713 .49623 Mdot
.56695 .61818 Mdot
.72006 .56109 Mdot
.5395 .37444 Mdot
.67488 .65405 Mdot
.57493 .65236 Mdot
.84593 .53357 Mdot
.47454 .76014 Mdot
.29863 .47478 Mdot
.48699 .38152 Mdot
.27742 .48155 Mdot
.6565 .48669 Mdot
.47652 .55493 Mdot
.4079 .66098 Mdot
.40497 .42697 Mdot
.21206 .3451 Mdot
.58746 .5933 Mdot
.27933 .4828 Mdot
.47111 .42463 Mdot
.24557 .61248 Mdot
.5281 .38519 Mdot
.56065 .32502 Mdot
.73263 .45814 Mdot
.40773 .63205 Mdot
.3936 .66435 Mdot
.49109 .36659 Mdot
.65045 .4866 Mdot
.61429 .62941 Mdot
.57715 .6227 Mdot
.82285 .64385 Mdot
.38503 .5694 Mdot
.54245 .23236 Mdot
.54206 .39301 Mdot
.57354 .58797 Mdot
.57524 .70713 Mdot
.44578 .6382 Mdot
.498 .32625 Mdot
.55903 .62558 Mdot
.66096 .52336 Mdot
.58138 .28091 Mdot
.49893 .35344 Mdot
.44321 .39816 Mdot
.40945 .67292 Mdot
.41459 .47073 Mdot
.6183 .60178 Mdot
.55722 .35429 Mdot
.44052 .58663 Mdot
.58121 .28996 Mdot
.61893 .19164 Mdot
.30097 .49133 Mdot
.71672 .54663 Mdot
.4318 .63675 Mdot
.4456 .41891 Mdot
.65069 .46688 Mdot
.61018 .57758 Mdot
.6277 .64581 Mdot
.48557 .40862 Mdot
.54554 .43301 Mdot
.56254 .21079 Mdot
.31745 .46263 Mdot
.44347 .65778 Mdot
.52313 .41645 Mdot
.35461 .60531 Mdot
.46446 .37375 Mdot
.40897 .63757 Mdot
.21367 .29073 Mdot
.47768 .43307 Mdot
.52883 .38055 Mdot
.36366 .74085 Mdot
.33284 .45155 Mdot
.27607 .49673 Mdot
.45902 .19195 Mdot
.54179 .39286 Mdot
.56539 .19953 Mdot
.29939 .49591 Mdot
.31684 .50531 Mdot
.50874 .71507 Mdot
.50262 .37492 Mdot
.42237 .38302 Mdot
.39014 .65526 Mdot
.44793 .66053 Mdot
.33382 .45591 Mdot
.57422 .40525 Mdot
.42266 .61545 Mdot
.27398 .70121 Mdot
.59882 .61574 Mdot
.18581 .41086 Mdot
.32689 .50646 Mdot
.38933 .6118 Mdot
.44348 .64305 Mdot
.70078 .22627 Mdot
.64323 .58039 Mdot
.50887 .42325 Mdot
.54108 .38669 Mdot
.69207 .4766 Mdot
.45752 .40574 Mdot
.60022 .58381 Mdot
.42733 .6444 Mdot
.50351 .25839 Mdot
.30073 .4864 Mdot
.52259 .39739 Mdot
.61674 .76426 Mdot
.69176 .72588 Mdot
.72754 .53293 Mdot
.33462 .49883 Mdot
.29011 .47945 Mdot
.6229 .62345 Mdot
.57158 .65224 Mdot
.51659 .35999 Mdot
.41574 .62219 Mdot
.27867 .49223 Mdot
.4047 .63793 Mdot
.61692 .64529 Mdot
.58747 .6357 Mdot
.63335 .63362 Mdot
.55863 .3864 Mdot
.59801 .63861 Mdot
.7019 .67649 Mdot
.46417 .6703 Mdot
.32976 .52439 Mdot
.53317 .16859 Mdot
.31241 .63851 Mdot
.37359 .4772 Mdot
.64438 .4883 Mdot
.59175 .59143 Mdot
.41144 .67864 Mdot
.47582 .37815 Mdot
.47892 .35558 Mdot
.51488 .6639 Mdot
.4107 .68191 Mdot
.6572 .48515 Mdot
.39627 .6715 Mdot
.65353 .48033 Mdot
.67208 .59323 Mdot
.46021 .37597 Mdot
.56188 .40807 Mdot
.43451 .64049 Mdot
.59603 .63638 Mdot
.59784 .59838 Mdot
.69891 .46027 Mdot
.50815 .59165 Mdot
.56764 .60827 Mdot
.31366 .50812 Mdot
.41041 .36461 Mdot
.58479 .65505 Mdot
.52993 .40273 Mdot
.69929 .39304 Mdot
.19053 .56572 Mdot
.44912 .41605 Mdot
.50453 .71078 Mdot
.29585 .41425 Mdot
.52081 .34505 Mdot
.18598 .55626 Mdot
.49556 .66856 Mdot
.30232 .45555 Mdot
.60743 .58904 Mdot
.53853 .61047 Mdot
.44585 .44569 Mdot
.64504 .44691 Mdot
.47969 .33193 Mdot
.33769 .50147 Mdot
.26827 .49306 Mdot
.68606 .2938 Mdot
.51201 .81935 Mdot
.67313 .49012 Mdot
.67685 .49384 Mdot
.58233 .62813 Mdot
.65259 .8111 Mdot
.53418 .31099 Mdot
.65831 .48405 Mdot
.2418 .50788 Mdot
.48137 .41176 Mdot
.61728 .32784 Mdot
.58219 .48754 Mdot
.33837 .45831 Mdot
.67718 .31022 Mdot
.58062 .63855 Mdot
.29923 .46143 Mdot
.34757 .5969 Mdot
.45539 .36602 Mdot
.30356 .48761 Mdot
.40335 .64111 Mdot
.50732 .75967 Mdot
.30794 .51083 Mdot
.68732 .38306 Mdot
.43599 .61869 Mdot
.44257 .49079 Mdot
.6414 .28462 Mdot
.36556 .86175 Mdot
.42876 .64014 Mdot
.58147 .6509 Mdot
.59355 .60936 Mdot
.57741 .62388 Mdot
.30907 .46087 Mdot
.59147 .5904 Mdot
.31558 .46371 Mdot
.40945 .80807 Mdot
.20958 .58132 Mdot
.65935 .4829 Mdot
.54735 .72397 Mdot
.32177 .47613 Mdot
.21752 .36577 Mdot
.13305 .48316 Mdot
.4711 .41354 Mdot
.45544 .66297 Mdot
.66252 .48434 Mdot
.72046 .73509 Mdot
.67589 .48157 Mdot
.64995 .24903 Mdot
.26602 .33939 Mdot
.52103 .38957 Mdot
.38658 .34645 Mdot
.66322 .45127 Mdot
.34291 .48729 Mdot
.50095 .36583 Mdot
.59844 .52334 Mdot
.68042 .48246 Mdot
.66718 .50278 Mdot
.51449 .36533 Mdot
.29006 .49909 Mdot
.58487 .64494 Mdot
.44532 .66806 Mdot
.64189 .46738 Mdot
.59047 .39576 Mdot
.44655 .39752 Mdot
.50159 .42485 Mdot
.38449 .53708 Mdot
.71331 .47043 Mdot
.42354 .64564 Mdot
.22623 .68757 Mdot
.55609 .61981 Mdot
.60929 .53249 Mdot
.60671 .20184 Mdot
.48599 .69904 Mdot
.611 .62276 Mdot
.61191 .59894 Mdot
.50608 .35509 Mdot
.58486 .46722 Mdot
.24659 .35676 Mdot
.51365 .60762 Mdot
.63574 .6319 Mdot
.57805 .61781 Mdot
.27385 .48213 Mdot
.67183 .27127 Mdot
.44756 .35689 Mdot
.40579 .62244 Mdot
.62956 .64225 Mdot
.24186 .63261 Mdot
.68805 .47157 Mdot
.27093 .32615 Mdot
.46027 .37238 Mdot
.51316 .4224 Mdot
.41471 .65779 Mdot
.40447 .64593 Mdot
.64597 .56649 Mdot
.66417 .26234 Mdot
.30296 .41623 Mdot
.28616 .62853 Mdot
.30349 .32692 Mdot
.27082 .49019 Mdot
.28122 .48737 Mdot
.57335 .7484 Mdot
.44391 .67279 Mdot
.52651 .34693 Mdot
.29068 .47089 Mdot
.61391 .54037 Mdot
.40182 .40683 Mdot
.58345 .26099 Mdot
.53096 .20396 Mdot
.4927 .39927 Mdot
.33587 .46568 Mdot
.33667 .45273 Mdot
.3561 .48079 Mdot
.50141 .65452 Mdot
.52437 .36469 Mdot
.49789 .39801 Mdot
.51686 .3474 Mdot
.22583 .57537 Mdot
.5306 .36261 Mdot
.31215 .69087 Mdot
.48209 .54689 Mdot
.37683 .2584 Mdot
.55987 .35657 Mdot
.38484 .66165 Mdot
.54959 .37892 Mdot
.65107 .48643 Mdot
.48271 .42239 Mdot
.58034 .26041 Mdot
.44322 .65002 Mdot
.42135 .35267 Mdot
.31088 .65163 Mdot
.50974 .336 Mdot
.64091 .45717 Mdot
.38325 .71784 Mdot
.80437 .42567 Mdot
.72887 .487 Mdot
.31606 .50817 Mdot
.60352 .61879 Mdot
.41059 .67912 Mdot
.58813 .63053 Mdot
.56446 .3907 Mdot
.56473 .75503 Mdot
.73306 .70301 Mdot
.54429 .55391 Mdot
.46996 .36645 Mdot
.46158 .33051 Mdot
.31038 .50518 Mdot
.55743 .61797 Mdot
.37026 .49022 Mdot
.54021 .35849 Mdot
.65742 .47162 Mdot
.68468 .48326 Mdot
.56221 .52808 Mdot
.81308 .57074 Mdot
.25382 .66854 Mdot
.41505 .65474 Mdot
.57937 .60514 Mdot
.66031 .45589 Mdot
.44558 .78832 Mdot
.42725 .61107 Mdot
.3979 .63684 Mdot
.4429 .65351 Mdot
.53409 .41941 Mdot
.6297 .64782 Mdot
.38283 .25563 Mdot
.58916 .58335 Mdot
.49673 .38692 Mdot
.61568 .6534 Mdot
.56045 .61738 Mdot
.66991 .45692 Mdot
.44471 .65482 Mdot
.6192 .63941 Mdot
.5007 .43683 Mdot
.29423 .4956 Mdot
.45 .60068 Mdot
.62548 .37561 Mdot
.52475 .81708 Mdot
.57569 .30924 Mdot
.35095 .46847 Mdot
.82286 .45322 Mdot
.39223 .64326 Mdot
.23458 .56052 Mdot
.7721 .55818 Mdot
.53334 .43262 Mdot
.15533 .45211 Mdot
.63704 .652 Mdot
.56086 .62628 Mdot
.48758 .35946 Mdot
.59491 .68263 Mdot
.52409 .39252 Mdot
.607 .64964 Mdot
.58365 .69905 Mdot
.2643 .50893 Mdot
.60073 .63455 Mdot
.55678 .35633 Mdot
.4933 .37183 Mdot
.33609 .45895 Mdot
.58975 .66171 Mdot
.45537 .34565 Mdot
.83605 .62464 Mdot
.4099 .64039 Mdot
.43884 .71676 Mdot
.70118 .40407 Mdot
.43169 .63544 Mdot
.302 .48104 Mdot
.5554 .37654 Mdot
.68298 .4869 Mdot
.32291 .47549 Mdot
.55616 .25887 Mdot
.6891 .45777 Mdot
.17992 .40178 Mdot
.34166 .45673 Mdot
.57363 .6425 Mdot
.64794 .47534 Mdot
.45566 .40775 Mdot
.61321 .57891 Mdot
.47914 .77121 Mdot
.60997 .62459 Mdot
.51109 .35064 Mdot
.59039 .72423 Mdot
.44391 .659 Mdot
.50581 .39985 Mdot
.56248 .62638 Mdot
.50817 .70707 Mdot
.53361 .42393 Mdot
.49393 .36146 Mdot
.62356 .20234 Mdot
.29006 .28394 Mdot
.67303 .47614 Mdot
.34241 .44934 Mdot
.47234 .41334 Mdot
.66669 .50101 Mdot
.70815 .63033 Mdot
.52678 .42114 Mdot
.32889 .51099 Mdot
.51138 .32075 Mdot
.58393 .65923 Mdot
.42555 .63157 Mdot
.53286 .58085 Mdot
.67656 .50011 Mdot
.43809 .86095 Mdot
.62726 .6249 Mdot
.55731 .41332 Mdot
.46362 .38042 Mdot
.75743 .45692 Mdot
.30352 .45593 Mdot
.23238 .42182 Mdot
.53772 .38991 Mdot
.22491 .56552 Mdot
.51484 .40769 Mdot
.63988 .6413 Mdot
.32123 .50471 Mdot
.5306 .3752 Mdot
.39752 .58391 Mdot
.45402 .42818 Mdot
.69668 .48482 Mdot
.37174 .75202 Mdot
.45389 .36383 Mdot
.18678 .34625 Mdot
.61332 .50871 Mdot
.60229 .63591 Mdot
.66148 .73209 Mdot
.8302 .66008 Mdot
.31594 .67181 Mdot
.30531 .46348 Mdot
.77421 .63086 Mdot
.5851 .63621 Mdot
.65311 .72229 Mdot
.82288 .4436 Mdot
.48665 .37394 Mdot
.54741 .36563 Mdot
.74983 .41104 Mdot
.57496 .59251 Mdot
.55326 .60793 Mdot
.55821 .42621 Mdot
.44323 .41304 Mdot
.59231 .63971 Mdot
.52036 .43875 Mdot
.57052 .40026 Mdot
.45655 .66023 Mdot
.32967 .50817 Mdot
.4101 .62937 Mdot
.42101 .61679 Mdot
.31624 .7393 Mdot
.61939 .51028 Mdot
.41257 .6356 Mdot
.38742 .64536 Mdot
.61528 .32314 Mdot
.60151 .24717 Mdot
.64366 .47823 Mdot
.82726 .58014 Mdot
.58032 .61653 Mdot
.5246 .37027 Mdot
.34428 .45664 Mdot
.32054 .41817 Mdot
.72824 .63278 Mdot
.20495 .4014 Mdot
.53323 .35154 Mdot
.57784 .63952 Mdot
.49921 .65848 Mdot
.56905 .4343 Mdot
.5785 .66445 Mdot
.52752 .41337 Mdot
.60379 .58291 Mdot
.45767 .2833 Mdot
.4772 .79008 Mdot
.55697 .65611 Mdot
.35204 .51094 Mdot
.5176 .41813 Mdot
.33921 .49944 Mdot
.44326 .63715 Mdot
.64576 .47985 Mdot
.67509 .47358 Mdot
.50648 .36426 Mdot
.51476 .30829 Mdot
.67934 .62006 Mdot
.49878 .37468 Mdot
.47851 .40874 Mdot
.49659 .66731 Mdot
.47715 .41184 Mdot
.47351 .35614 Mdot
.50192 .34419 Mdot
.53971 .34957 Mdot
.44799 .65929 Mdot
.59078 .76427 Mdot
.46234 .45296 Mdot
.45495 .44409 Mdot
.44943 .61984 Mdot
.782 .57609 Mdot
.40654 .62395 Mdot
.80889 .42135 Mdot
.39052 .66218 Mdot
.66615 .47153 Mdot
.75948 .48955 Mdot
.45958 .32111 Mdot
.30428 .5172 Mdot
.4039 .61641 Mdot
.65561 .48792 Mdot
.42897 .64696 Mdot
.6003 .65224 Mdot
.63205 .19817 Mdot
.26676 .46769 Mdot
.37688 .52351 Mdot
.40309 .71435 Mdot
.54259 .773 Mdot
.6249 .62809 Mdot
.34523 .49114 Mdot
.39577 .37126 Mdot
.46892 .36484 Mdot
.66427 .50074 Mdot
.51414 .36045 Mdot
.45222 .64777 Mdot
.5789 .63453 Mdot
.45205 .81736 Mdot
.68525 .48625 Mdot
.56168 .17597 Mdot
.59787 .60137 Mdot
.48559 .34502 Mdot
.41907 .61638 Mdot
.46616 .16969 Mdot
.40412 .63417 Mdot
.24597 .38875 Mdot
.28462 .46781 Mdot
.43357 .8358 Mdot
.3133 .47139 Mdot
.48914 .77719 Mdot
.43081 .14467 Mdot
.60443 .76854 Mdot
.29078 .49701 Mdot
.48959 .60851 Mdot
.49116 .40682 Mdot
.50289 .42529 Mdot
.46344 .79967 Mdot
.34799 .45535 Mdot
.46536 .39243 Mdot
.54452 .68706 Mdot
.48216 .65009 Mdot
.48544 .2015 Mdot
.61776 .61438 Mdot
.52751 .39407 Mdot
.3916 .68188 Mdot
.40336 .68061 Mdot
.6195 .59792 Mdot
.39657 .63751 Mdot
.49887 .39586 Mdot
.32045 .4753 Mdot
.60587 .69758 Mdot
.6729 .46481 Mdot
.67889 .77809 Mdot
.67771 .50555 Mdot
.61113 .62212 Mdot
.48476 .4385 Mdot
.58815 .63546 Mdot
.88504 .59772 Mdot
.49874 .40535 Mdot
.30081 .49639 Mdot
.47213 .40492 Mdot
.51371 .4175 Mdot
.53697 .34976 Mdot
.59131 .64637 Mdot
.6654 .42729 Mdot
.50906 .43835 Mdot
.40816 .66249 Mdot
.33483 .29916 Mdot
.46416 .35277 Mdot
.53713 .63125 Mdot
.60586 .26456 Mdot
.42526 .70217 Mdot
.30571 .44888 Mdot
.60511 .63157 Mdot
.29705 .48708 Mdot
.20975 .52852 Mdot
.30237 .48108 Mdot
.30518 .35604 Mdot
.40506 .34907 Mdot
.49605 .24397 Mdot
.46959 .25674 Mdot
.44414 .563 Mdot
.34518 .45187 Mdot
.71082 .45777 Mdot
.28271 .4975 Mdot
.32873 .45265 Mdot
.16322 .3082 Mdot
.31372 .52096 Mdot
.534 .39854 Mdot
.46924 .35045 Mdot
.53343 .78649 Mdot
.65781 .35382 Mdot
.4727 .39097 Mdot
.46936 .38678 Mdot
.65399 .46007 Mdot
.21806 .54008 Mdot
.59984 .74083 Mdot
.27217 .30028 Mdot
.7022 .71074 Mdot
.51378 .36269 Mdot
.47424 .41754 Mdot
.52319 .45665 Mdot
.3446 .2104 Mdot
.32371 .75324 Mdot
.29185 .53301 Mdot
.51487 .4553 Mdot
.59477 .78353 Mdot
.54163 .35591 Mdot
.54084 .4055 Mdot
.49225 .40214 Mdot
.58458 .63637 Mdot
.31834 .44636 Mdot
.54361 .35001 Mdot
.7488 .45757 Mdot
.53762 .40553 Mdot
.49004 .70101 Mdot
.54819 .84814 Mdot
.53039 .39038 Mdot
.28227 .45462 Mdot
.4983 .42411 Mdot
.31505 .4543 Mdot
.34572 .47605 Mdot
.53165 .44858 Mdot
.2997 .33047 Mdot
.27816 .46561 Mdot
.49632 .3863 Mdot
.5902 .65264 Mdot
.84187 .53502 Mdot
.51333 .35148 Mdot
.64485 .4819 Mdot
.54082 .3886 Mdot
.63727 .46529 Mdot
.47735 .40276 Mdot
.62742 .61995 Mdot
.27185 .42998 Mdot
.58547 .62363 Mdot
.36406 .79207 Mdot
.63193 .63288 Mdot
.59953 .17643 Mdot
.35344 .47643 Mdot
.56481 .72382 Mdot
.20191 .47159 Mdot
.44306 .72279 Mdot
.4996 .50052 Mdot
.4329 .53131 Mdot
.4135 .62344 Mdot
.29049 .46474 Mdot
.25672 .54637 Mdot
.75646 .58567 Mdot
.75166 .52845 Mdot
.56926 .6096 Mdot
.20023 .67159 Mdot
.18258 .4477 Mdot
.53751 .4346 Mdot
.36721 .36929 Mdot
.35947 .32268 Mdot
.54247 .35578 Mdot
.5496 .35836 Mdot
.55231 .57623 Mdot
.50784 .44035 Mdot
.35429 .61046 Mdot
.61217 .61784 Mdot
.65653 .49081 Mdot
.30449 .50284 Mdot
.68687 .49668 Mdot
.76652 .56566 Mdot
.42638 .52893 Mdot
.61071 .64955 Mdot
.44497 .38013 Mdot
.47267 .38046 Mdot
.32502 .45612 Mdot
.36234 .51827 Mdot
.28751 .50667 Mdot
.66807 .48649 Mdot
.60922 .61186 Mdot
.19591 .59301 Mdot
.47167 .3767 Mdot
.3303 .49274 Mdot
.52051 .50007 Mdot
.47123 .41091 Mdot
.43926 .63841 Mdot
.49417 .41075 Mdot
.29355 .50117 Mdot
.47704 .41156 Mdot
.31206 .47003 Mdot
.60107 .61824 Mdot
.50048 .33933 Mdot
.49146 .35535 Mdot
.51405 .17216 Mdot
.6578 .47781 Mdot
.34351 .5008 Mdot
.59615 .54012 Mdot
.46125 .40162 Mdot
.521 .72664 Mdot
.52997 .40958 Mdot
.31696 .42767 Mdot
.54542 .42335 Mdot
.4486 .71374 Mdot
.43972 .42452 Mdot
.51897 .35524 Mdot
.57615 .5047 Mdot
.34822 .33535 Mdot
.45156 .32071 Mdot
.38414 .64675 Mdot
.33607 .51335 Mdot
.49178 .20524 Mdot
.6396 .66998 Mdot
.56028 .64316 Mdot
.69896 .34232 Mdot
.52581 .33918 Mdot
.52181 .3869 Mdot
.38503 .69154 Mdot
.68621 .49141 Mdot
.33681 .49691 Mdot
.65361 .48017 Mdot
.55376 .18889 Mdot
.69759 .47336 Mdot
.63921 .64745 Mdot
.67499 .65657 Mdot
.20871 .63033 Mdot
.65679 .45842 Mdot
.2904 .50065 Mdot
.66397 .68688 Mdot
.50266 .33134 Mdot
.60762 .50363 Mdot
.66056 .46591 Mdot
.28303 .76526 Mdot
.47501 .35472 Mdot
.49585 .49841 Mdot
.41749 .6305 Mdot
.65133 .46479 Mdot
.43873 .62172 Mdot
.47906 .375 Mdot
.60384 .73737 Mdot
.30392 .46472 Mdot
.45166 .62693 Mdot
.54906 .32794 Mdot
.66198 .48592 Mdot
.62875 .64622 Mdot
.37848 .67972 Mdot
.39663 .62911 Mdot
.79585 .56784 Mdot
.43438 .82123 Mdot
.60717 .60934 Mdot
.39615 .22846 Mdot
.39141 .66924 Mdot
.49878 .33246 Mdot
.22446 .53512 Mdot
.51011 .4237 Mdot
.30098 .69966 Mdot
.61094 .62995 Mdot
.55778 .77169 Mdot
.47424 .4147 Mdot
.52942 .35394 Mdot
.26765 .47135 Mdot
.58744 .61518 Mdot
.31854 .48573 Mdot
.34375 .50772 Mdot
.60052 .61656 Mdot
.30289 .47301 Mdot
.67078 .45099 Mdot
.33196 .57504 Mdot
.40234 .66964 Mdot
.41877 .66751 Mdot
.57689 .62198 Mdot
.60559 .63755 Mdot
.59189 .63372 Mdot
.49436 .41138 Mdot
.33103 .50173 Mdot
.48326 .38584 Mdot
.54572 .39557 Mdot
.33833 .28747 Mdot
.3271 .44813 Mdot
.48828 .39428 Mdot
.60914 .52649 Mdot
.59116 .47426 Mdot
.59505 .65494 Mdot
.4155 .63332 Mdot
.555 .70132 Mdot
.46112 .76792 Mdot
.52673 .39792 Mdot
.63572 .5135 Mdot
.28767 .50022 Mdot
.67998 .48645 Mdot
.69521 .49958 Mdot
.67445 .47978 Mdot
.46649 .69075 Mdot
.35499 .47675 Mdot
.26581 .30966 Mdot
.52594 .39084 Mdot
.39328 .53003 Mdot
.24878 .50964 Mdot
.66552 .58447 Mdot
.41461 .63547 Mdot
.46969 .40251 Mdot
.53623 .57404 Mdot
.3882 .415 Mdot
.50718 .42124 Mdot
.47604 .34265 Mdot
.70869 .67747 Mdot
.49562 .32276 Mdot
.27389 .49988 Mdot
.4696 .1732 Mdot
.46293 .41518 Mdot
.23673 .62941 Mdot
.69344 .77776 Mdot
.52504 .40654 Mdot
.53838 .36105 Mdot
.47817 .36043 Mdot
.48565 .42383 Mdot
.28192 .45752 Mdot
.64874 .31387 Mdot
.38853 .66528 Mdot
.39434 .52501 Mdot
.45272 .65944 Mdot
.62495 .59528 Mdot
.56663 .77022 Mdot
.28539 .46887 Mdot
.69191 .47722 Mdot
.67293 .75164 Mdot
.38184 .20997 Mdot
.61737 .60044 Mdot
.27296 .69745 Mdot
.66045 .46955 Mdot
.49277 .33423 Mdot
.65138 .45247 Mdot
.61526 .65767 Mdot
.41589 .66961 Mdot
.46146 .34929 Mdot
.28287 .49216 Mdot
.31274 .51128 Mdot
.46761 .40275 Mdot
.61022 .77937 Mdot
.43735 .6332 Mdot
.39339 .63065 Mdot
.52978 .42284 Mdot
.45532 .40573 Mdot
.31507 .48327 Mdot
.58481 .60237 Mdot
.51609 .23377 Mdot
.67305 .49689 Mdot
.55781 .38105 Mdot
.48058 .41518 Mdot
.61352 .20365 Mdot
.40507 .66272 Mdot
.57983 .6623 Mdot
.53669 .42964 Mdot
.27612 .62355 Mdot
.53417 .43118 Mdot
.53885 .45162 Mdot
.58905 .65294 Mdot
.48906 .46537 Mdot
.55973 .41652 Mdot
.26798 .45753 Mdot
.42406 .6211 Mdot
.30409 .49154 Mdot
.2871 .43792 Mdot
.33005 .55497 Mdot
.4388 .64101 Mdot
.48792 .40249 Mdot
.41669 .63856 Mdot
.52557 .4216 Mdot
.48318 .42963 Mdot
.40947 .63702 Mdot
.31821 .48466 Mdot
.76801 .63784 Mdot
.60306 .76388 Mdot
.49068 .42792 Mdot
.54665 .43912 Mdot
.64894 .33082 Mdot
.66469 .43029 Mdot
.54256 .3602 Mdot
.297 .50463 Mdot
.47829 .36809 Mdot
.44677 .63214 Mdot
.66293 .45185 Mdot
.29355 .49681 Mdot
.60149 .59644 Mdot
.62247 .61035 Mdot
.31305 .65744 Mdot
.5672 .60498 Mdot
.55048 .37107 Mdot
.35516 .44759 Mdot
.29272 .44185 Mdot
.63887 .79092 Mdot
.59845 .61361 Mdot
.64272 .47879 Mdot
.49616 .36172 Mdot
.72592 .33883 Mdot
.39757 .68464 Mdot
.13817 .4151 Mdot
.21634 .36422 Mdot
.67922 .44704 Mdot
.21436 .39446 Mdot
.63015 .6209 Mdot
.56409 .40081 Mdot
.64734 .48694 Mdot
.62263 .62255 Mdot
.51034 .43228 Mdot
.53011 .45012 Mdot
.23665 .41351 Mdot
.40496 .55266 Mdot
.4133 .64088 Mdot
.5867 .59047 Mdot
.67603 .4446 Mdot
.63326 .65616 Mdot
.35107 .48158 Mdot
.52635 .36297 Mdot
.49447 .44326 Mdot
.58996 .59753 Mdot
.55267 .63185 Mdot
.49296 .39109 Mdot
.27799 .47968 Mdot
.55481 .57211 Mdot
.51252 .36809 Mdot
.38784 .56637 Mdot
.35834 .4646 Mdot
.61471 .61298 Mdot
.52718 .35554 Mdot
.66683 .43607 Mdot
.59369 .60074 Mdot
.5981 .65571 Mdot
.47191 .41591 Mdot
.67638 .45169 Mdot
.52728 .44613 Mdot
.39265 .6609 Mdot
.23744 .70631 Mdot
.44835 .63338 Mdot
.585 .69563 Mdot
.53294 .31449 Mdot
.26194 .58882 Mdot
.30431 .45137 Mdot
.6758 .29341 Mdot
.54777 .69038 Mdot
.57058 .40681 Mdot
.83033 .52589 Mdot
.38755 .61134 Mdot
.64126 .77596 Mdot
.77361 .40147 Mdot
.66581 .45967 Mdot
.43076 .64811 Mdot
.53906 .36149 Mdot
.45636 .66162 Mdot
.64945 .49213 Mdot
.3654 .7904 Mdot
.51753 .35013 Mdot
.31736 .50472 Mdot
.49499 .39575 Mdot
.32322 .50733 Mdot
.47474 .42009 Mdot
.48141 .45047 Mdot
.50799 .67917 Mdot
.58464 .28503 Mdot
.54071 .42332 Mdot
.57079 .14881 Mdot
.55003 .4829 Mdot
.66268 .49627 Mdot
.4869 .37821 Mdot
.58577 .67055 Mdot
.41611 .68326 Mdot
.37075 .72543 Mdot
.58504 .63781 Mdot
.39429 .63356 Mdot
.30742 .47727 Mdot
.60677 .62662 Mdot
.61651 .59637 Mdot
.49004 .46616 Mdot
.67191 .44822 Mdot
.43352 .6605 Mdot
.53194 .37451 Mdot
.51795 .35098 Mdot
.39667 .22423 Mdot
.73792 .60571 Mdot
.37064 .50986 Mdot
.27319 .26445 Mdot
.34663 .51159 Mdot
.66027 .49029 Mdot
.58595 .64461 Mdot
.54748 .38558 Mdot
.50576 .39581 Mdot
.53401 .71875 Mdot
.27818 .49704 Mdot
.48617 .55881 Mdot
.22161 .47916 Mdot
.60503 .54274 Mdot
.61299 .29233 Mdot
.30144 .5035 Mdot
.61298 .29459 Mdot
.70996 .47392 Mdot
.8048 .63616 Mdot
.60164 .30167 Mdot
.42008 .63085 Mdot
.61695 .30228 Mdot
.33618 .49018 Mdot
.51101 .43677 Mdot
.5771 .64771 Mdot
.5604 .61613 Mdot
.31139 .49003 Mdot
.6143 .66854 Mdot
.67791 .45887 Mdot
.53912 .36899 Mdot
.28528 .28305 Mdot
.32361 .62921 Mdot
.57423 .61964 Mdot
.55957 .44613 Mdot
.44367 .65268 Mdot
.46728 .40332 Mdot
.66559 .45565 Mdot
.42453 .63948 Mdot
.65795 .25516 Mdot
.4768 .64959 Mdot
.49897 .36362 Mdot
.62002 .20097 Mdot
.43342 .64207 Mdot
.53581 .47976 Mdot
.519 .36822 Mdot
.39054 .65402 Mdot
.46852 .46826 Mdot
.50545 .76317 Mdot
.53841 .55634 Mdot
.82385 .44402 Mdot
.52263 .55016 Mdot
.57119 .63473 Mdot
.52395 .77015 Mdot
.41084 .72984 Mdot
.41681 .67831 Mdot
.56623 .65277 Mdot
.61164 .46088 Mdot
.43557 .6206 Mdot
.48806 .33824 Mdot
.52642 .41063 Mdot
.33933 .76413 Mdot
.37213 .65071 Mdot
.48441 .7805 Mdot
.34144 .68473 Mdot
.46016 .39759 Mdot
.52121 .44699 Mdot
.50933 .3925 Mdot
.26944 .48405 Mdot
.40695 .65021 Mdot
.52563 .15457 Mdot
.44097 .63645 Mdot
.29483 .30543 Mdot
.57884 .62049 Mdot
.61932 .6173 Mdot
.52949 .39462 Mdot
.47205 .49098 Mdot
.63163 .26095 Mdot
.49889 .39244 Mdot
.62571 .47684 Mdot
.38435 .76838 Mdot
.45679 .4057 Mdot
.28692 .46165 Mdot
.54335 .45466 Mdot
.58974 .41636 Mdot
.40262 .67012 Mdot
.68516 .46831 Mdot
.66667 .27909 Mdot
.42638 .66911 Mdot
.52057 .38728 Mdot
.27198 .59442 Mdot
.50876 .41401 Mdot
.49594 .42927 Mdot
.23591 .3564 Mdot
.70027 .49127 Mdot
.59427 .62642 Mdot
.67159 .47941 Mdot
.311 .45301 Mdot
.12123 .39655 Mdot
.69862 .47756 Mdot
.63429 .25646 Mdot
.32582 .7661 Mdot
.61868 .31041 Mdot
.33594 .50336 Mdot
.6572 .44762 Mdot
.43079 .6303 Mdot
.84214 .54107 Mdot
.23988 .43116 Mdot
.38083 .60564 Mdot
.51329 .37321 Mdot
.30057 .52557 Mdot
.30452 .51312 Mdot
.45256 .62612 Mdot
.34585 .47963 Mdot
.42324 .40281 Mdot
.50248 .43404 Mdot
.44094 .67284 Mdot
.28816 .61909 Mdot
.38241 .65094 Mdot
.46324 .58827 Mdot
.49185 .37808 Mdot
.29819 .49875 Mdot
.56019 .38208 Mdot
.34883 .44943 Mdot
.59794 .66731 Mdot
.44779 .40856 Mdot
.68137 .46012 Mdot
.25862 .60329 Mdot
.60659 .607 Mdot
.63926 .53504 Mdot
.32375 .45498 Mdot
.46513 .68398 Mdot
.33739 .4607 Mdot
.32531 .43963 Mdot
.4112 .62062 Mdot
.32955 .47286 Mdot
.53828 .3625 Mdot
.58094 .52613 Mdot
.3139 .45827 Mdot
.42282 .65804 Mdot
.68333 .47014 Mdot
.31164 .47394 Mdot
.58793 .6807 Mdot
.50059 .35787 Mdot
.59799 .64553 Mdot
.7534 .49269 Mdot
.30575 .52403 Mdot
.7034 .48346 Mdot
.55498 .63462 Mdot
.66581 .50278 Mdot
.58037 .81832 Mdot
.46585 .63095 Mdot
.27403 .3343 Mdot
.62602 .45276 Mdot
.2997 .51567 Mdot
.75744 .4957 Mdot
.54442 .39378 Mdot
.49819 .35914 Mdot
.63809 .47405 Mdot
.30407 .51304 Mdot
.75079 .71256 Mdot
.57051 .3301 Mdot
.4397 .5743 Mdot
.42986 .6091 Mdot
.59778 .17194 Mdot
.4487 .58316 Mdot
.65123 .81647 Mdot
.57548 .38255 Mdot
.55427 .60572 Mdot
.52002 .39883 Mdot
.53095 .69032 Mdot
.66228 .48309 Mdot
.53747 .66183 Mdot
.47882 .44144 Mdot
.59967 .62432 Mdot
.49312 .34985 Mdot
.57217 .51246 Mdot
.5577 .46475 Mdot
.64291 .48438 Mdot
.64205 .73496 Mdot
.32255 .51987 Mdot
.6688 .46451 Mdot
.6243 .63735 Mdot
.62694 .28283 Mdot
.50707 .43279 Mdot
.50933 .32624 Mdot
.6056 .54292 Mdot
.33207 .50296 Mdot
.56825 .63797 Mdot
.3967 .66438 Mdot
.68948 .47745 Mdot
.47338 .38228 Mdot
.54586 .40312 Mdot
.5135 .72433 Mdot
.44631 .65161 Mdot
.56026 .60801 Mdot
.41808 .62601 Mdot
.62472 .60193 Mdot
.49214 .43674 Mdot
.61695 .60597 Mdot
.55279 .35518 Mdot
.5024 .68068 Mdot
.25792 .33921 Mdot
.34843 .35086 Mdot
.61298 .62773 Mdot
.57908 .24606 Mdot
.44464 .64813 Mdot
.3997 .63757 Mdot
.25816 .70411 Mdot
.24131 .39362 Mdot
.3773 .22175 Mdot
.80354 .50285 Mdot
.44549 .66577 Mdot
.43687 .65558 Mdot
.60091 .64462 Mdot
.33042 .47114 Mdot
.34965 .50462 Mdot
.62272 .59884 Mdot
.70214 .39863 Mdot
.33662 .49694 Mdot
.81918 .56845 Mdot
.45633 .20759 Mdot
.54289 .3444 Mdot
.63808 .6566 Mdot
.68257 .48199 Mdot
.69265 .38389 Mdot
.57876 .51181 Mdot
.52967 .35236 Mdot
.70558 .32258 Mdot
.57862 .6127 Mdot
.43177 .47599 Mdot
.80769 .4269 Mdot
.49675 .34393 Mdot
.52351 .36873 Mdot
.51542 .39286 Mdot
.69254 .45379 Mdot
.24937 .41311 Mdot
.5322 .36126 Mdot
.70203 .4005 Mdot
.46327 .40146 Mdot
.5265 .4791 Mdot
.67427 .47524 Mdot
.58214 .29751 Mdot
.76276 .58038 Mdot
.4691 .17786 Mdot
.5828 .45457 Mdot
.39562 .66498 Mdot
.73824 .48122 Mdot
.40712 .62976 Mdot
.31516 .35407 Mdot
.60961 .31999 Mdot
.34018 .52015 Mdot
.53259 .35395 Mdot
.61177 .62174 Mdot
.30604 .51317 Mdot
.5208 .74884 Mdot
.13911 .35401 Mdot
.39544 .66802 Mdot
.73469 .78026 Mdot
.39198 .65228 Mdot
.61607 .59509 Mdot
.31391 .48313 Mdot
.41304 .33649 Mdot
.37571 .54424 Mdot
.30916 .47232 Mdot
.74578 .68631 Mdot
.29697 .53406 Mdot
.60386 .26855 Mdot
.28366 .51287 Mdot
.42961 .65549 Mdot
.43992 .70783 Mdot
.42835 .35278 Mdot
.54002 .39635 Mdot
.43851 .53002 Mdot
.61769 .25893 Mdot
.54454 .39201 Mdot
.61081 .61583 Mdot
.2566 .35089 Mdot
.69767 .32738 Mdot
.33152 .47843 Mdot
.47603 .64262 Mdot
.52148 .3623 Mdot
.49019 .42011 Mdot
.51127 .43455 Mdot
.22767 .33095 Mdot
.80289 .63978 Mdot
.50625 .43816 Mdot
.46489 .41217 Mdot
.6039 .62509 Mdot
.63901 .44139 Mdot
.65031 .71001 Mdot
.37601 .24909 Mdot
.51242 .34072 Mdot
.67021 .46768 Mdot
.69796 .4509 Mdot
.52863 .43331 Mdot
.61755 .5181 Mdot
.27224 .58708 Mdot
.53188 .37302 Mdot
.25787 .35319 Mdot
.63028 .55671 Mdot
.57531 .59209 Mdot
.59579 .59732 Mdot
.34237 .49955 Mdot
.59752 .59191 Mdot
.62919 .62921 Mdot
.41121 .35232 Mdot
.50559 .55235 Mdot
.47365 .61451 Mdot
.6696 .48768 Mdot
.5053 .40117 Mdot
.47558 .30375 Mdot
.27135 .61265 Mdot
.42224 .61883 Mdot
.28699 .49076 Mdot
.41208 .68397 Mdot
.72557 .49111 Mdot
.33152 .54572 Mdot
.57262 .61214 Mdot
.43586 .67031 Mdot
.43907 .68595 Mdot
.67276 .46877 Mdot
.45084 .63161 Mdot
.41821 .6942 Mdot
.44748 .38781 Mdot
.35929 .38664 Mdot
.49868 .38594 Mdot
.67472 .75678 Mdot
.4415 .65812 Mdot
.46916 .7004 Mdot
.5258 .3811 Mdot
.59445 .602 Mdot
.41397 .37895 Mdot
.53999 .40217 Mdot
.59118 .59489 Mdot
.53511 .4356 Mdot
.67605 .50504 Mdot
.35205 .4546 Mdot
.38092 .53574 Mdot
.18535 .65707 Mdot
.66906 .4477 Mdot
.52405 .74367 Mdot
.53794 .35469 Mdot
.48776 .82886 Mdot
.31473 .47483 Mdot
.55372 .40352 Mdot
.67436 .3092 Mdot
.31881 .46171 Mdot
.29424 .48441 Mdot
.48703 .41092 Mdot
.41992 .62876 Mdot
.60969 .60825 Mdot
.67656 .47235 Mdot
.64405 .80661 Mdot
.50622 .37138 Mdot
.48645 .35898 Mdot
.66367 .46651 Mdot
.44804 .64664 Mdot
.53566 .42882 Mdot
.76349 .4459 Mdot
.7722 .69816 Mdot
.39383 .64256 Mdot
.49423 .33727 Mdot
.30542 .38267 Mdot
.59343 .37869 Mdot
.43085 .84846 Mdot
.61231 .50697 Mdot
.59855 .63036 Mdot
.48984 .31733 Mdot
.17593 .34259 Mdot
.68598 .47095 Mdot
.37955 .21331 Mdot
.48696 .41922 Mdot
.46988 .37765 Mdot
.28704 .50507 Mdot
.4862 .38747 Mdot
.28248 .47576 Mdot
.17708 .61552 Mdot
.60805 .19755 Mdot
.34762 .48765 Mdot
.30241 .51844 Mdot
.65113 .27254 Mdot
.59196 .70554 Mdot
.31017 .48772 Mdot
.47775 .42609 Mdot
.60643 .37839 Mdot
.39676 .45445 Mdot
.64491 .4554 Mdot
.76732 .52996 Mdot
.53326 .30368 Mdot
.67223 .52081 Mdot
.78306 .58975 Mdot
.5269 .29882 Mdot
.49817 .60565 Mdot
.39645 .65594 Mdot
.49811 .34339 Mdot
.56054 .614 Mdot
.56605 .60493 Mdot
.56617 .38281 Mdot
.50327 .40854 Mdot
.31532 .4532 Mdot
.6866 .48763 Mdot
.4023 .67603 Mdot
.47026 .38312 Mdot
.66723 .2901 Mdot
.69045 .48945 Mdot
.34036 .47486 Mdot
.32095 .30122 Mdot
.65773 .50709 Mdot
.46844 .44679 Mdot
.53575 .38387 Mdot
.49264 .39925 Mdot
.43546 .33806 Mdot
.40371 .64959 Mdot
.76602 .50759 Mdot
.459 .3679 Mdot
.54769 .18643 Mdot
.44719 .60247 Mdot
.43966 .39543 Mdot
.34846 .47481 Mdot
.47956 .63323 Mdot
.63289 .64703 Mdot
.30039 .55146 Mdot
.49953 .36566 Mdot
.61856 .76704 Mdot
.35571 .77046 Mdot
.59035 .66444 Mdot
.33924 .44647 Mdot
.67569 .48453 Mdot
.49964 .39479 Mdot
.29688 .33555 Mdot
.52798 .40764 Mdot
.66958 .51737 Mdot
.5971 .65768 Mdot
.39628 .65335 Mdot
.65258 .77088 Mdot
.57815 .59495 Mdot
.29653 .48639 Mdot
.71757 .25183 Mdot
.28234 .47422 Mdot
.3499 .50156 Mdot
.33478 .29628 Mdot
.40289 .64815 Mdot
.15427 .37509 Mdot
.19345 .62717 Mdot
.45288 .41289 Mdot
.44552 .6453 Mdot
.31218 .4959 Mdot
.46419 .3852 Mdot
.35221 .5175 Mdot
.3523 .4654 Mdot
.48189 .43128 Mdot
.47576 .3603 Mdot
.506 .79414 Mdot
.81547 .45043 Mdot
.67431 .48524 Mdot
.32033 .45058 Mdot
.3697 .56641 Mdot
.46375 .38184 Mdot
.52629 .38984 Mdot
.40978 .73416 Mdot
.66195 .45063 Mdot
.34574 .61894 Mdot
.48877 .41974 Mdot
.63553 .22229 Mdot
.49286 .46321 Mdot
.28044 .46249 Mdot
.40477 .62956 Mdot
.48009 .17946 Mdot
.37695 .68137 Mdot
.28277 .47741 Mdot
.69402 .47774 Mdot
.27911 .45136 Mdot
.63149 .25283 Mdot
.45246 .65283 Mdot
.29357 .50124 Mdot
.53007 .58534 Mdot
.4137 .64891 Mdot
.43918 .66426 Mdot
.34807 .28326 Mdot
.57768 .66322 Mdot
.69498 .4541 Mdot
.43595 .65845 Mdot
.2343 .56637 Mdot
.42263 .6544 Mdot
.2057 .64434 Mdot
.49794 .33911 Mdot
.71383 .377 Mdot
.5584 .6831 Mdot
.47257 .31885 Mdot
.44522 .65864 Mdot
.65265 .46017 Mdot
.51117 .4313 Mdot
.33943 .48802 Mdot
.6708 .49983 Mdot
.36842 .61157 Mdot
.59046 .6394 Mdot
.33593 .46189 Mdot
.37754 .65613 Mdot
.3166 .50975 Mdot
.25984 .54824 Mdot
.29816 .75535 Mdot
.70785 .29615 Mdot
.36944 .55179 Mdot
.50443 .43259 Mdot
.79334 .54283 Mdot
.51087 .32998 Mdot
.50225 .41355 Mdot
.61404 .61501 Mdot
.70802 .35517 Mdot
.31802 .4853 Mdot
.71284 .74036 Mdot
.40918 .67226 Mdot
.48024 .17466 Mdot
.59357 .43334 Mdot
.55618 .41763 Mdot
.30978 .45827 Mdot
.2761 .48912 Mdot
.34489 .32528 Mdot
.63711 .63706 Mdot
.55248 .36705 Mdot
.49049 .33107 Mdot
.56636 .41087 Mdot
.41335 .67076 Mdot
.63534 .52703 Mdot
.57112 .63213 Mdot
.36589 .8033 Mdot
.59267 .65798 Mdot
.65983 .51908 Mdot
.33294 .47592 Mdot
.6984 .47735 Mdot
.52767 .38806 Mdot
.34892 .52907 Mdot
.27755 .49728 Mdot
.64021 .48268 Mdot
.64828 .47205 Mdot
.47332 .75217 Mdot
.4098 .63736 Mdot
.54031 .41192 Mdot
.52894 .35681 Mdot
.4806 .38829 Mdot
.49564 .4101 Mdot
.40078 .67106 Mdot
.51938 .43052 Mdot
.38354 .67964 Mdot
.23304 .51733 Mdot
.75055 .40753 Mdot
.52516 .54657 Mdot
.29252 .70281 Mdot
.33517 .48437 Mdot
.24292 .57281 Mdot
.57519 .34638 Mdot
.19052 .39991 Mdot
.41483 .79754 Mdot
.45331 .38076 Mdot
.62174 .61228 Mdot
.43663 .45489 Mdot
.56671 .61257 Mdot
.64188 .83271 Mdot
.49099 .71597 Mdot
.82821 .47866 Mdot
.5165 .35082 Mdot
.57521 .52951 Mdot
.21936 .57641 Mdot
.50903 .32845 Mdot
.49218 .73178 Mdot
.29584 .69733 Mdot
.63137 .74419 Mdot
.66453 .45422 Mdot
.50823 .36017 Mdot
.45944 .31427 Mdot
.53817 .3647 Mdot
.52359 .39597 Mdot
.5155 .43292 Mdot
.38213 .65812 Mdot
.55309 .39136 Mdot
.5115 .42679 Mdot
.6824 .62667 Mdot
.60365 .28972 Mdot
.55485 .6248 Mdot
.28357 .72724 Mdot
.69904 .47763 Mdot
.31652 .45568 Mdot
.79869 .63215 Mdot
.41958 .63137 Mdot
.35078 .32245 Mdot
.49417 .40534 Mdot
.5438 .78568 Mdot
.45675 .67243 Mdot
.69121 .47131 Mdot
.61672 .65794 Mdot
.84253 .50072 Mdot
.60779 .61744 Mdot
.49003 .66771 Mdot
.5963 .60361 Mdot
.5668 .33218 Mdot
.31575 .45271 Mdot
.53624 .42266 Mdot
.42956 .6623 Mdot
.60678 .59524 Mdot
.65636 .34337 Mdot
.5103 .39428 Mdot
.59964 .61681 Mdot
.53599 .42241 Mdot
.37071 .52894 Mdot
.42227 .23041 Mdot
.62798 .62911 Mdot
.45424 .67376 Mdot
.41096 .66104 Mdot
.68084 .45325 Mdot
.32653 .45897 Mdot
.28432 .486 Mdot
.42419 .64094 Mdot
.21878 .42821 Mdot
.51726 .3407 Mdot
.46722 .37343 Mdot
.50468 .18004 Mdot
.54437 .36833 Mdot
.61849 .2808 Mdot
.5457 .56161 Mdot
.34058 .48116 Mdot
.55343 .42532 Mdot
.48336 .41227 Mdot
.49857 .36242 Mdot
.24778 .52033 Mdot
.58291 .6028 Mdot
.49704 .34203 Mdot
.64815 .47726 Mdot
.66568 .61536 Mdot
.46736 .40401 Mdot
.45038 .44988 Mdot
.28451 .48813 Mdot
.2709 .27163 Mdot
.3932 .65076 Mdot
.62384 .635 Mdot
.61356 .6292 Mdot
.77389 .53907 Mdot
.25461 .63131 Mdot
.54764 .55861 Mdot
.39854 .82276 Mdot
.50797 .67797 Mdot
.65595 .48366 Mdot
.64323 .5946 Mdot
.42986 .71396 Mdot
.61281 .64121 Mdot
.39636 .67007 Mdot
.49087 .34028 Mdot
.50997 .3402 Mdot
.16552 .42614 Mdot
.53018 .43403 Mdot
.67822 .48176 Mdot
.38136 .6508 Mdot
.33523 .49061 Mdot
.69162 .47415 Mdot
.41807 .62521 Mdot
.34323 .4937 Mdot
.45588 .36806 Mdot
.45954 .36249 Mdot
.28724 .48816 Mdot
.29514 .5071 Mdot
.533 .38268 Mdot
.6315 .7061 Mdot
.30775 .51826 Mdot
.29872 .50344 Mdot
.57192 .61638 Mdot
.56349 .61026 Mdot
.44526 .43774 Mdot
.44161 .6473 Mdot
.51289 .42799 Mdot
.60833 .62481 Mdot
.69731 .4739 Mdot
.32123 .48494 Mdot
.48916 .42623 Mdot
.47064 .40167 Mdot
.67456 .46859 Mdot
.68787 .46024 Mdot
.66065 .45799 Mdot
.37954 .66722 Mdot
.48175 .37959 Mdot
.30858 .4814 Mdot
.40485 .64115 Mdot
.69812 .4519 Mdot
.6459 .45749 Mdot
.64713 .6159 Mdot
.54819 .37683 Mdot
.61371 .69464 Mdot
.19017 .31425 Mdot
.55765 .20259 Mdot
.6174 .66266 Mdot
.63264 .65171 Mdot
.63106 .35227 Mdot
.43717 .48668 Mdot
.43555 .63691 Mdot
.63854 .43999 Mdot
.66369 .27243 Mdot
.45209 .36647 Mdot
.46118 .41125 Mdot
.49558 .45259 Mdot
.65546 .46195 Mdot
.72065 .36043 Mdot
.28712 .46701 Mdot
.52335 .28314 Mdot
.68765 .49341 Mdot
.55301 .62968 Mdot
.65013 .63165 Mdot
.59716 .65912 Mdot
.47686 .34639 Mdot
.35799 .34889 Mdot
.24442 .59888 Mdot
.78892 .48491 Mdot
.44649 .65465 Mdot
.47698 .30356 Mdot
.48517 .82569 Mdot
.29031 .48501 Mdot
.62511 .59457 Mdot
.65397 .48337 Mdot
.29841 .5081 Mdot
.4258 .68377 Mdot
.43454 .65743 Mdot
.57407 .62248 Mdot
.57639 .62815 Mdot
.60192 .65081 Mdot
.35443 .46755 Mdot
.3313 .47404 Mdot
.49753 .36764 Mdot
.3256 .48429 Mdot
.20585 .36967 Mdot
.63501 .46511 Mdot
.54193 .61982 Mdot
.43438 .64723 Mdot
.33845 .4999 Mdot
.50799 .39267 Mdot
.4185 .47409 Mdot
.32973 .69677 Mdot
.65743 .49529 Mdot
.40838 .2261 Mdot
.62311 .8359 Mdot
.54246 .40835 Mdot
.40373 .65688 Mdot
.28978 .27618 Mdot
.51424 .39044 Mdot
.58416 .64624 Mdot
.6851 .69462 Mdot
.64862 .5912 Mdot
.53905 .40472 Mdot
.44955 .36881 Mdot
.38875 .65529 Mdot
.38286 .80647 Mdot
.50081 .3704 Mdot
.34378 .59967 Mdot
.46438 .65361 Mdot
.57333 .63908 Mdot
.84561 .60375 Mdot
.72855 .50913 Mdot
.6992 .39049 Mdot
.57182 .6258 Mdot
.51522 .41769 Mdot
.57173 .60785 Mdot
.65176 .48625 Mdot
.62484 .64566 Mdot
.28185 .47183 Mdot
.58095 .65749 Mdot
.48593 .35875 Mdot
.30897 .48971 Mdot
.43492 .64169 Mdot
.44724 .18914 Mdot
.70202 .65718 Mdot
.59222 .60269 Mdot
.6263 .61612 Mdot
.54787 .42924 Mdot
.35079 .62841 Mdot
.55973 .36518 Mdot
.47784 .35203 Mdot
.44983 .66188 Mdot
.32004 .46012 Mdot
.39628 .63504 Mdot
.43229 .3819 Mdot
.767 .41717 Mdot
.41445 .62796 Mdot
.60997 .7619 Mdot
.65939 .47121 Mdot
.50276 .51625 Mdot
.50438 .39691 Mdot
.44549 .62561 Mdot
.48362 .37806 Mdot
.29329 .4608 Mdot
.53041 .52983 Mdot
.60841 .74108 Mdot
.42541 .6673 Mdot
.63288 .76913 Mdot
.74705 .42942 Mdot
.43282 .42477 Mdot
.39992 .63605 Mdot
.68487 .32021 Mdot
.615 .59403 Mdot
.67363 .49751 Mdot
.66103 .50545 Mdot
.68189 .49865 Mdot
.56662 .36881 Mdot
.58822 .44744 Mdot
.70386 .48624 Mdot
.42362 .68242 Mdot
.64313 .48451 Mdot
.22365 .62432 Mdot
.71691 .73431 Mdot
.66218 .48009 Mdot
.51654 .36946 Mdot
.58144 .42497 Mdot
.61566 .32147 Mdot
.49724 .76596 Mdot
.82953 .4959 Mdot
.38349 .74976 Mdot
.53758 .39912 Mdot
.35981 .47527 Mdot
.34132 .45423 Mdot
.3097 .25007 Mdot
.60254 .25161 Mdot
.58753 .20516 Mdot
.32456 .52113 Mdot
.5771 .72393 Mdot
.33951 .4704 Mdot
.5215 .43516 Mdot
.46594 .37772 Mdot
.32329 .52251 Mdot
.74766 .38769 Mdot
.56379 .7333 Mdot
.6493 .78748 Mdot
.30749 .50975 Mdot
.42224 .62138 Mdot
.4411 .61485 Mdot
.44161 .66326 Mdot
.43332 .20907 Mdot
.30399 .46233 Mdot
.47486 .39258 Mdot
.61389 .62615 Mdot
.5082 .34273 Mdot
.41272 .646 Mdot
.72343 .73459 Mdot
.31018 .46794 Mdot
.52456 .36002 Mdot
.41686 .40656 Mdot
.58146 .63414 Mdot
.66579 .47016 Mdot
.38755 .508 Mdot
.58731 .20917 Mdot
.42011 .67324 Mdot
.30996 .524 Mdot
.48249 .697 Mdot
.67266 .74767 Mdot
.57662 .38997 Mdot
.48342 .33234 Mdot
.64026 .81246 Mdot
.64349 .23582 Mdot
.54754 .36282 Mdot
.62493 .62599 Mdot
.52657 .71606 Mdot
.47362 .41163 Mdot
.33211 .45057 Mdot
.66017 .50728 Mdot
.66559 .50205 Mdot
.44379 .43742 Mdot
.40122 .52039 Mdot
.55975 .52608 Mdot
.48844 .40452 Mdot
.47256 .4479 Mdot
.57271 .63543 Mdot
.51917 .68138 Mdot
.55516 .18869 Mdot
.69503 .47229 Mdot
.53574 .42463 Mdot
.73994 .67397 Mdot
.28496 .50631 Mdot
.59573 .66507 Mdot
.45411 .64092 Mdot
.25231 .5132 Mdot
.61906 .65644 Mdot
.48272 .42614 Mdot
.53159 .43175 Mdot
.42605 .61628 Mdot
.27998 .46417 Mdot
.65538 .46384 Mdot
.61825 .61954 Mdot
.68223 .45802 Mdot
.31585 .46184 Mdot
.32605 .4788 Mdot
.41992 .41224 Mdot
.57911 .37808 Mdot
.60066 .59707 Mdot
.55242 .35333 Mdot
.65678 .60601 Mdot
.47534 .85679 Mdot
.40489 .6158 Mdot
.5502 .39095 Mdot
.27061 .49845 Mdot
.42129 .67003 Mdot
.47129 .37099 Mdot
.66834 .80256 Mdot
.4621 .3886 Mdot
.45724 .61037 Mdot
.69099 .26592 Mdot
.67105 .45634 Mdot
.53668 .28952 Mdot
.4743 .79944 Mdot
.54402 .37286 Mdot
.60945 .63704 Mdot
.55969 .44451 Mdot
.42727 .62809 Mdot
.33194 .47773 Mdot
.45834 .86243 Mdot
.41925 .65687 Mdot
.53708 .37017 Mdot
.69034 .47637 Mdot
.27699 .50427 Mdot
.61286 .48311 Mdot
.61966 .5214 Mdot
.50453 .47311 Mdot
.55782 .37808 Mdot
.4942 .41647 Mdot
.77384 .45231 Mdot
.62226 .6378 Mdot
.30742 .50209 Mdot
.4037 .6599 Mdot
.42766 .63857 Mdot
.57625 .61526 Mdot
.47368 .60584 Mdot
.50146 .51695 Mdot
.27878 .23033 Mdot
.58314 .5962 Mdot
.69839 .48811 Mdot
.35085 .60945 Mdot
.61919 .62743 Mdot
.59588 .61515 Mdot
.57055 .61781 Mdot
.51258 .60491 Mdot
.33649 .49951 Mdot
.48015 .42463 Mdot
.30473 .44924 Mdot
.51466 .4197 Mdot
.45956 .61165 Mdot
.4302 .66462 Mdot
.31579 .46735 Mdot
.61271 .81291 Mdot
.34098 .40022 Mdot
.51746 .38153 Mdot
.48859 .82817 Mdot
.48505 .44186 Mdot
.6295 .32501 Mdot
.50445 .44911 Mdot
.58382 .61064 Mdot
.52385 .32352 Mdot
.56952 .40367 Mdot
.34493 .22459 Mdot
.43787 .64587 Mdot
.58184 .58749 Mdot
.45822 .42916 Mdot
.4826 .45249 Mdot
.35675 .47632 Mdot
.29886 .50716 Mdot
.66486 .50537 Mdot
.57477 .27498 Mdot
.43802 .6402 Mdot
.18712 .58216 Mdot
.53962 .39405 Mdot
.67992 .52688 Mdot
.46406 .25511 Mdot
.47338 .3669 Mdot
.49514 .80905 Mdot
.35541 .34242 Mdot
.50104 .39552 Mdot
.44596 .55753 Mdot
.44516 .64957 Mdot
.76188 .38581 Mdot
.46598 .40799 Mdot
.58377 .63958 Mdot
.33453 .47232 Mdot
.27434 .49383 Mdot
.68377 .50172 Mdot
.18162 .43964 Mdot
.39732 .63236 Mdot
.32508 .47162 Mdot
.51194 .40003 Mdot
.40137 .65474 Mdot
.5899 .59189 Mdot
.55522 .41567 Mdot
.58895 .24211 Mdot
.32919 .48922 Mdot
.52978 .43979 Mdot
.326 .59071 Mdot
.65689 .38435 Mdot
.73189 .29264 Mdot
.40397 .6627 Mdot
.67602 .45269 Mdot
.53703 .4546 Mdot
.23252 .41052 Mdot
.53247 .44632 Mdot
.72088 .39556 Mdot
.2299 .63577 Mdot
.66567 .45152 Mdot
.52394 .37707 Mdot
.47301 .38561 Mdot
.50583 .49373 Mdot
.69556 .47671 Mdot
.52101 .35167 Mdot
.23521 .47526 Mdot
.32478 .50497 Mdot
.62415 .59619 Mdot
.33424 .49468 Mdot
.51392 .37343 Mdot
.58025 .38845 Mdot
.28894 .50534 Mdot
.50071 .84526 Mdot
.63438 .45227 Mdot
.39766 .64319 Mdot
.46974 .42774 Mdot
.46079 .37088 Mdot
.51503 .13994 Mdot
.58359 .66206 Mdot
.63104 .71342 Mdot
.67015 .56088 Mdot
.76773 .62745 Mdot
.73098 .50628 Mdot
.80269 .38234 Mdot
.64909 .2388 Mdot
.55341 .39387 Mdot
.59393 .35476 Mdot
.27601 .56871 Mdot
.44933 .6532 Mdot
.19977 .52552 Mdot
.54023 .39648 Mdot
.52207 .39817 Mdot
.62071 .66211 Mdot
.58174 .76035 Mdot
.58578 .20345 Mdot
.41793 .48209 Mdot
.6572 .4633 Mdot
.32533 .45179 Mdot
.48024 .42628 Mdot
.47795 .56283 Mdot
.55361 .63301 Mdot
.72741 .49946 Mdot
.52591 .36288 Mdot
.21709 .37371 Mdot
.31268 .67941 Mdot
.40765 .64271 Mdot
.61335 .63119 Mdot
.60395 .21113 Mdot
.54809 .38445 Mdot
.45325 .63286 Mdot
.50519 .37643 Mdot
.5391 .59445 Mdot
.43466 .37235 Mdot
.66174 .48766 Mdot
.49056 .42297 Mdot
.73367 .48758 Mdot
.63983 .16606 Mdot
.70501 .49334 Mdot
.33795 .52441 Mdot
.54578 .61499 Mdot
.58579 .59986 Mdot
.29498 .50528 Mdot
.59038 .59879 Mdot
.36297 .29973 Mdot
.44269 .29887 Mdot
.65811 .46864 Mdot
.46958 .45242 Mdot
.66608 .47811 Mdot
.59684 .66648 Mdot
.5388 .40097 Mdot
.54144 .85978 Mdot
.60943 .60109 Mdot
.6574 .23058 Mdot
.4225 .65206 Mdot
.55272 .63275 Mdot
.46384 .40234 Mdot
.46438 .70879 Mdot
.57615 .59642 Mdot
.58664 .74287 Mdot
.49834 .36311 Mdot
.33168 .48493 Mdot
.47351 .40795 Mdot
.456 .41599 Mdot
.55379 .61035 Mdot
.52057 .42353 Mdot
.41929 .6248 Mdot
.33717 .51271 Mdot
.83133 .55292 Mdot
.27634 .67665 Mdot
.52989 .35412 Mdot
.51271 .39745 Mdot
.29893 .44075 Mdot
.47557 .34977 Mdot
.40034 .67062 Mdot
.13793 .63179 Mdot
.65981 .4711 Mdot
.57703 .58597 Mdot
.73614 .50133 Mdot
.45279 .37634 Mdot
.51496 .43122 Mdot
.69556 .78756 Mdot
.76274 .41767 Mdot
.40641 .63093 Mdot
.5663 .41358 Mdot
.58685 .59174 Mdot
.68711 .48069 Mdot
.41753 .68073 Mdot
.4925 .39735 Mdot
.5266 .38487 Mdot
.6868 .45685 Mdot
.61023 .39307 Mdot
.48057 .2015 Mdot
.44281 .62041 Mdot
.51871 .31528 Mdot
.56675 .66965 Mdot
.52739 .3435 Mdot
.40553 .2164 Mdot
.2943 .49913 Mdot
.42617 .67311 Mdot
.78031 .56828 Mdot
.54976 .38583 Mdot
.4103 .62482 Mdot
.43872 .64096 Mdot
.55351 .42947 Mdot
.27196 .50807 Mdot
.34398 .5021 Mdot
.32212 .50858 Mdot
.14503 .46318 Mdot
.68362 .37043 Mdot
.6017 .65084 Mdot
.44611 .64888 Mdot
.62866 .61917 Mdot
.66446 .51811 Mdot
.5362 .56142 Mdot
.62763 .62129 Mdot
.32904 .50855 Mdot
.55526 .59744 Mdot
.48098 .37179 Mdot
.43514 .64024 Mdot
.60935 .64398 Mdot
.45094 .40737 Mdot
.35834 .61231 Mdot
.43729 .76918 Mdot
.64604 .46141 Mdot
.66678 .50864 Mdot
.46504 .39037 Mdot
.63579 .62597 Mdot
.53213 .38534 Mdot
.4582 .65479 Mdot
.35752 .6057 Mdot
.46924 .42608 Mdot
.5897 .60293 Mdot
.28829 .44454 Mdot
.5952 .21137 Mdot
.55 .34185 Mdot
.51753 .37037 Mdot
.51884 .42048 Mdot
.50467 .37637 Mdot
.67314 .73802 Mdot
.44808 .61407 Mdot
.29152 .70012 Mdot
.76093 .49963 Mdot
.30439 .47035 Mdot
.30984 .44606 Mdot
.54395 .19615 Mdot
.27949 .57741 Mdot
.44244 .64787 Mdot
.49979 .41238 Mdot
.2802 .63433 Mdot
.77187 .69711 Mdot
.61727 .82688 Mdot
.51374 .48752 Mdot
.57389 .65836 Mdot
.31313 .52339 Mdot
.61117 .59442 Mdot
.5202 .41447 Mdot
.50014 .45451 Mdot
.78919 .3446 Mdot
.44236 .67598 Mdot
.65548 .47249 Mdot
.51297 .42174 Mdot
.68503 .37573 Mdot
.60509 .6264 Mdot
.5505 .62756 Mdot
.489 .34467 Mdot
.27537 .4641 Mdot
.61289 .16677 Mdot
.40372 .65062 Mdot
.37861 .74085 Mdot
.21822 .58026 Mdot
.34657 .69887 Mdot
.41 .64681 Mdot
.55431 .48519 Mdot
.60738 .66491 Mdot
.45995 .24732 Mdot
.29846 .47131 Mdot
.66792 .4993 Mdot
.44005 .38728 Mdot
.28362 .49682 Mdot
.58381 .6537 Mdot
.33191 .48083 Mdot
.51278 .43276 Mdot
.46709 .63624 Mdot
.59879 .63251 Mdot
.47235 .61214 Mdot
.26771 .49256 Mdot
.69406 .47579 Mdot
.43159 .50445 Mdot
.37703 .43353 Mdot
.3551 .33878 Mdot
.49446 .34148 Mdot
.48255 .5682 Mdot
.47635 .3919 Mdot
.32644 .44249 Mdot
.50759 .38761 Mdot
.34466 .43762 Mdot
.60841 .63656 Mdot
.46505 .41181 Mdot
.49034 .4077 Mdot
.22858 .66754 Mdot
.51367 .35395 Mdot
.55296 .35798 Mdot
.49943 .39882 Mdot
.37003 .50315 Mdot
.47669 .45588 Mdot
.3484 .47176 Mdot
.67136 .64344 Mdot
.59282 .61513 Mdot
.65311 .50023 Mdot
.68479 .45322 Mdot
.70593 .36443 Mdot
.75663 .56346 Mdot
.55504 .77283 Mdot
.32778 .49813 Mdot
.43455 .62543 Mdot
.50549 .3835 Mdot
.80482 .4268 Mdot
.61876 .54554 Mdot
.55776 .63801 Mdot
.27913 .67879 Mdot
.49901 .31271 Mdot
.76663 .37348 Mdot
.56581 .40841 Mdot
.16008 .44848 Mdot
.55758 .33441 Mdot
.44776 .3526 Mdot
.60918 .58552 Mdot
.71144 .5061 Mdot
.46859 .35917 Mdot
.35623 .4862 Mdot
.67001 .49439 Mdot
.59611 .4122 Mdot
.61449 .68965 Mdot
.66548 .65962 Mdot
.37863 .46188 Mdot
.49031 .37308 Mdot
.59746 .63227 Mdot
.33393 .46016 Mdot
.5643 .19237 Mdot
.40324 .64221 Mdot
.45067 .59652 Mdot
.3281 .56723 Mdot
.51276 .83897 Mdot
.69161 .48875 Mdot
.42818 .24261 Mdot
.48376 .3616 Mdot
.6762 .68887 Mdot
.47504 .4304 Mdot
.73299 .72889 Mdot
.70123 .47675 Mdot
.32945 .51052 Mdot
.42704 .62101 Mdot
.32671 .4499 Mdot
.34413 .34471 Mdot
.6404 .65514 Mdot
.49348 .54127 Mdot
.60552 .61649 Mdot
.58846 .51135 Mdot
.30752 .49528 Mdot
.53344 .42422 Mdot
.27461 .23231 Mdot
.29692 .50214 Mdot
.28329 .51066 Mdot
.33752 .77479 Mdot
.50589 .8626 Mdot
.51206 .31988 Mdot
.30591 .51898 Mdot
.60225 .61192 Mdot
.67545 .4876 Mdot
.47865 .4177 Mdot
.48871 .36904 Mdot
.28416 .4952 Mdot
.55857 .6033 Mdot
.27908 .38288 Mdot
.57738 .62327 Mdot
.33508 .50147 Mdot
.58569 .62396 Mdot
.47815 .69362 Mdot
.62249 .6273 Mdot
.46114 .36927 Mdot
.50697 .38657 Mdot
.73289 .54541 Mdot
.32663 .47967 Mdot
.48734 .40312 Mdot
.54796 .42837 Mdot
.3104 .48374 Mdot
.58998 .48674 Mdot
.28884 .37677 Mdot
.53247 .35118 Mdot
.50469 .35709 Mdot
.66973 .45204 Mdot
.51173 .57677 Mdot
.41541 .23507 Mdot
.5092 .43076 Mdot
.69226 .45424 Mdot
.35459 .48993 Mdot
.53283 .3748 Mdot
.78184 .66148 Mdot
.53063 .71729 Mdot
.54257 .4035 Mdot
.61504 .59445 Mdot
.56853 .40595 Mdot
.71799 .27715 Mdot
.47627 .35326 Mdot
.31533 .49104 Mdot
.32564 .46605 Mdot
.19054 .60263 Mdot
.29763 .48834 Mdot
.56056 .61555 Mdot
.41346 .64741 Mdot
.66641 .7601 Mdot
.59383 .59147 Mdot
.5637 .34881 Mdot
.20475 .66745 Mdot
.5482 .41737 Mdot
.453 .39177 Mdot
.66122 .21505 Mdot
.61089 .59712 Mdot
.30305 .4582 Mdot
.45318 .49782 Mdot
.5803 .37141 Mdot
.43144 .67112 Mdot
.43986 .40829 Mdot
.49312 .33814 Mdot
.68355 .25409 Mdot
.68048 .72197 Mdot
.45798 .64212 Mdot
.54785 .35379 Mdot
.51115 .43119 Mdot
.58791 .67111 Mdot
.5085 .3975 Mdot
.67155 .48802 Mdot
.30776 .46067 Mdot
.62192 .62057 Mdot
.6764 .46716 Mdot
.54528 .38412 Mdot
.65843 .45975 Mdot
.59788 .64585 Mdot
.4552 .64798 Mdot
.5295 .40954 Mdot
.6435 .45681 Mdot
.65876 .46055 Mdot
.47835 .39376 Mdot
.33446 .47837 Mdot
.52395 .30809 Mdot
.51779 .35378 Mdot
.49129 .42702 Mdot
.28434 .48377 Mdot
.8358 .66101 Mdot
.46677 .37268 Mdot
.73243 .40153 Mdot
.27722 .49153 Mdot
.59073 .50272 Mdot
.60681 .58878 Mdot
.48902 .3394 Mdot
.45567 .64925 Mdot
.45097 .63749 Mdot
.59247 .65911 Mdot
.29814 .52331 Mdot
.67711 .55329 Mdot
.26467 .50872 Mdot
.56617 .43073 Mdot
.53228 .34353 Mdot
.24045 .43831 Mdot
.83074 .47064 Mdot
.29773 .45459 Mdot
.57054 .68692 Mdot
.40767 .50413 Mdot
.4451 .62721 Mdot
.55441 .623 Mdot
.31817 .52434 Mdot
.28596 .47155 Mdot
.34071 .48374 Mdot
.66297 .49923 Mdot
.73582 .54674 Mdot
.27546 .47524 Mdot
.28278 .45404 Mdot
.49346 .36344 Mdot
.50689 .42947 Mdot
.60636 .22508 Mdot
.55256 .23386 Mdot
.64888 .46421 Mdot
.58105 .6484 Mdot
.13224 .45483 Mdot
.45468 .66066 Mdot
.26754 .6963 Mdot
.45613 .40509 Mdot
.1419 .36191 Mdot
.46862 .4099 Mdot
.50994 .40192 Mdot
.33775 .51266 Mdot
.6426 .46102 Mdot
.66318 .4754 Mdot
.30479 .50215 Mdot
.29635 .44734 Mdot
.67019 .48739 Mdot
.46023 .80459 Mdot
.79421 .65815 Mdot
.63712 .57645 Mdot
.31256 .4788 Mdot
.38867 .41436 Mdot
.43703 .6168 Mdot
.58477 .42889 Mdot
.46297 .64995 Mdot
.60075 .62102 Mdot
.62022 .65742 Mdot
.42265 .67172 Mdot
.5001 .36411 Mdot
.60946 .64908 Mdot
.55096 .39919 Mdot
.38159 .75998 Mdot
.34586 .37556 Mdot
.71147 .5345 Mdot
.51968 .47364 Mdot
.58048 .49185 Mdot
.47769 .61548 Mdot
.54029 .3788 Mdot
.77532 .63759 Mdot
.65594 .4677 Mdot
.55069 .45327 Mdot
.43225 .67302 Mdot
.6899 .22732 Mdot
.53486 .40709 Mdot
.31843 .49005 Mdot
.44229 .64259 Mdot
.28984 .54679 Mdot
.34823 .59657 Mdot
.51665 .4204 Mdot
.1976 .31132 Mdot
.35792 .51628 Mdot
.6184 .63099 Mdot
.20946 .42171 Mdot
.28735 .45788 Mdot
.71158 .45052 Mdot
.77424 .52116 Mdot
.57762 .82665 Mdot
.31667 .45514 Mdot
.5867 .66627 Mdot
.35035 .48244 Mdot
.69307 .47925 Mdot
.35196 .51035 Mdot
.60635 .63164 Mdot
.52499 .36557 Mdot
.5802 .61058 Mdot
.65471 .49594 Mdot
.48496 .20546 Mdot
.45745 .64081 Mdot
.58596 .58648 Mdot
.42172 .66457 Mdot
.64142 .39122 Mdot
.76881 .45949 Mdot
.39576 .65194 Mdot
.29172 .32802 Mdot
.52209 .33817 Mdot
.2825 .46042 Mdot
.57642 .61003 Mdot
.74701 .627 Mdot
.42837 .50116 Mdot
.29509 .47578 Mdot
.59207 .65384 Mdot
.362 .56797 Mdot
.22884 .38454 Mdot
.55555 .35984 Mdot
.61048 .33072 Mdot
.30893 .47904 Mdot
.60394 .66883 Mdot
.49501 .1787 Mdot
.35159 .48202 Mdot
.5787 .5992 Mdot
.42148 .6206 Mdot
.42408 .63774 Mdot
.50787 .34496 Mdot
.47564 .63109 Mdot
.60824 .65624 Mdot
.38332 .59532 Mdot
.30503 .52 Mdot
.25844 .53283 Mdot
.63936 .45859 Mdot
.58689 .61452 Mdot
.53386 .43346 Mdot
.35941 .45704 Mdot
.50797 .70316 Mdot
.28519 .39403 Mdot
.27125 .26435 Mdot
.57634 .61545 Mdot
.29862 .46481 Mdot
.32113 .48891 Mdot
.55389 .34545 Mdot
.36955 .54992 Mdot
.68168 .55568 Mdot
.43676 .47216 Mdot
.42292 .46717 Mdot
.62487 .59604 Mdot
.65604 .6381 Mdot
.45539 .42705 Mdot
.49478 .37534 Mdot
.44202 .62503 Mdot
.52164 .36405 Mdot
.32632 .51711 Mdot
.49284 .34299 Mdot
.4049 .65951 Mdot
.60994 .61656 Mdot
.53227 .406 Mdot
.66666 .45595 Mdot
.42777 .61411 Mdot
.41475 .68521 Mdot
.58913 .60797 Mdot
.28296 .49429 Mdot
.60686 .49482 Mdot
.5762 .62981 Mdot
.49123 .37244 Mdot
.51187 .59027 Mdot
.5106 .4344 Mdot
.54286 .29637 Mdot
.35235 .47709 Mdot
.62065 .61765 Mdot
.33296 .51894 Mdot
.42339 .66009 Mdot
.76303 .50371 Mdot
.51247 .37908 Mdot
.58446 .59528 Mdot
.53609 .67949 Mdot
.57417 .30625 Mdot
.27309 .45991 Mdot
.48172 .78574 Mdot
.31771 .44477 Mdot
.57487 .64392 Mdot
.25454 .70353 Mdot
.68111 .49637 Mdot
.55748 .63829 Mdot
.83806 .5245 Mdot
.60371 .59995 Mdot
.49764 .3483 Mdot
.46606 .38673 Mdot
.62184 .62456 Mdot
.67924 .45249 Mdot
.59818 .19662 Mdot
.59272 .57507 Mdot
.30752 .45717 Mdot
.388 .77588 Mdot
.37021 .19421 Mdot
.39898 .61324 Mdot
.43983 .62526 Mdot
.55602 .32895 Mdot
.51926 .32958 Mdot
.43539 .67456 Mdot
.45218 .67375 Mdot
.67089 .50424 Mdot
.56953 .61333 Mdot
.36759 .46654 Mdot
.38707 .67575 Mdot
.38534 .49889 Mdot
.75155 .55831 Mdot
.5476 .34036 Mdot
.2248 .59459 Mdot
.46143 .41237 Mdot
.72746 .43785 Mdot
.40456 .6611 Mdot
.51525 .43945 Mdot
.56565 .37954 Mdot
.45185 .65843 Mdot
.67525 .48928 Mdot
.48942 .61647 Mdot
.58856 .62765 Mdot
.83968 .62602 Mdot
.5563 .40061 Mdot
.49024 .34832 Mdot
.44491 .65659 Mdot
.68484 .60788 Mdot
.30667 .46699 Mdot
.33373 .44864 Mdot
.62228 .63686 Mdot
.41491 .51959 Mdot
.50641 .33918 Mdot
.53535 .37136 Mdot
.59238 .63438 Mdot
.55979 .61015 Mdot
.52599 .76956 Mdot
.47238 .37975 Mdot
.43524 .64893 Mdot
.66062 .51982 Mdot
.40608 .66425 Mdot
.5168 .43481 Mdot
.48626 .35175 Mdot
.46126 .36801 Mdot
.53111 .43383 Mdot
.45867 .66781 Mdot
.49479 .43576 Mdot
.50118 .45743 Mdot
.29622 .46863 Mdot
.50955 .42525 Mdot
.42738 .47037 Mdot
.51467 .36385 Mdot
.67359 .4873 Mdot
.38008 .24591 Mdot
.5343 .40728 Mdot
.49449 .3393 Mdot
.57041 .58678 Mdot
.52179 .38297 Mdot
.45771 .65654 Mdot
.31922 .47571 Mdot
.44467 .65056 Mdot
.45206 .6383 Mdot
.63165 .64421 Mdot
.69949 .49176 Mdot
.45251 .37384 Mdot
.65446 .48896 Mdot
.57291 .36669 Mdot
.55008 .38556 Mdot
.76056 .52246 Mdot
.15708 .46162 Mdot
.44636 .20566 Mdot
.51155 .37729 Mdot
.61085 .59932 Mdot
.61273 .59507 Mdot
.60258 .39292 Mdot
.55799 .36816 Mdot
.40168 .67475 Mdot
.44881 .63071 Mdot
.59399 .2495 Mdot
.7238 .32017 Mdot
.67386 .48787 Mdot
.5066 .56437 Mdot
.55233 .36865 Mdot
.52184 .43703 Mdot
.55468 .41247 Mdot
.62872 .62806 Mdot
.50248 .48353 Mdot
.55503 .6307 Mdot
.3175 .69269 Mdot
.43045 .66793 Mdot
.52628 .41521 Mdot
.24291 .63166 Mdot
.30518 .51112 Mdot
.32016 .47648 Mdot
.40394 .68337 Mdot
.60541 .68085 Mdot
.57579 .21542 Mdot
.61246 .83476 Mdot
.33544 .5275 Mdot
.64235 .47715 Mdot
.54067 .3717 Mdot
.6072 .6092 Mdot
.33605 .50294 Mdot
.64323 .47895 Mdot
.53508 .41888 Mdot
.73717 .54637 Mdot
.50789 .37228 Mdot
.25614 .57535 Mdot
.33885 .47279 Mdot
.75171 .71435 Mdot
.29294 .52168 Mdot
.42394 .61388 Mdot
.41323 .67413 Mdot
.47194 .37096 Mdot
.22379 .43955 Mdot
.29899 .44981 Mdot
.50691 .62216 Mdot
.69803 .48811 Mdot
.48753 .70273 Mdot
.6875 .48642 Mdot
.615 .63357 Mdot
.67563 .49569 Mdot
.60655 .634 Mdot
.54668 .22138 Mdot
.37055 .5082 Mdot
.66711 .46541 Mdot
.52125 .66347 Mdot
.52071 .32739 Mdot
.64959 .46097 Mdot
.50991 .45245 Mdot
.55532 .30319 Mdot
.58944 .63447 Mdot
.69688 .48355 Mdot
.53452 .4256 Mdot
.78974 .36799 Mdot
.39981 .63745 Mdot
.40519 .67506 Mdot
.51458 .45094 Mdot
.63042 .60772 Mdot
.35057 .50285 Mdot
.71639 .72575 Mdot
.37942 .65453 Mdot
.46816 .37311 Mdot
.47125 .35511 Mdot
.3055 .44637 Mdot
.2272 .63971 Mdot
.47856 .36184 Mdot
.42509 .37323 Mdot
.47102 .37988 Mdot
.39017 .65159 Mdot
.32624 .45048 Mdot
.32138 .48394 Mdot
.59631 .65375 Mdot
.29562 .51123 Mdot
.60488 .3688 Mdot
.2666 .64598 Mdot
.45089 .33425 Mdot
.41763 .65862 Mdot
.3009 .67098 Mdot
.31561 .69412 Mdot
.82727 .49978 Mdot
.26588 .48805 Mdot
.47317 .42788 Mdot
.28579 .50795 Mdot
.68536 .48332 Mdot
.33099 .48678 Mdot
.31394 .52326 Mdot
.53498 .38568 Mdot
.51485 .4176 Mdot
.61453 .62227 Mdot
.37825 .54135 Mdot
.27974 .49265 Mdot
.47016 .41089 Mdot
.50546 .32703 Mdot
.54924 .40936 Mdot
.51676 .61589 Mdot
.30552 .45201 Mdot
.39265 .80881 Mdot
.65827 .29649 Mdot
.2802 .49259 Mdot
.62775 .17571 Mdot
.53049 .68268 Mdot
.64419 .63823 Mdot
.46131 .59631 Mdot
.47031 .3859 Mdot
.5825 .59063 Mdot
.52102 .41402 Mdot
.22622 .59531 Mdot
.52495 .38989 Mdot
.67058 .48922 Mdot
.55346 .39428 Mdot
.60696 .66225 Mdot
.57635 .62225 Mdot
.47273 .36162 Mdot
.52991 .40579 Mdot
.50846 .2034 Mdot
.29109 .53227 Mdot
.32315 .47313 Mdot
.66703 .55336 Mdot
.67433 .46185 Mdot
.42742 .67253 Mdot
.50341 .39462 Mdot
.63154 .63949 Mdot
.5765 .61915 Mdot
.29725 .45285 Mdot
.58339 .64377 Mdot
.40467 .64939 Mdot
.51203 .38367 Mdot
.42815 .6766 Mdot
.66538 .50113 Mdot
.31864 .45048 Mdot
.51251 .42361 Mdot
.49386 .36316 Mdot
.32561 .46582 Mdot
.44885 .40855 Mdot
.67511 .453 Mdot
.59916 .59819 Mdot
.32154 .45465 Mdot
.41625 .64441 Mdot
.61325 .63353 Mdot
.49003 .42847 Mdot
.17188 .38327 Mdot
.5012 .35014 Mdot
.47128 .40071 Mdot
.84788 .50226 Mdot
.55444 .37567 Mdot
.57558 .61386 Mdot
.33298 .50797 Mdot
.48643 .46668 Mdot
.68921 .34626 Mdot
.77667 .743 Mdot
.55723 .63577 Mdot
.53806 .36627 Mdot
.80786 .44279 Mdot
.5325 .3629 Mdot
.2957 .41678 Mdot
.62134 .5798 Mdot
.54369 .51027 Mdot
.50486 .44678 Mdot
.42082 .63138 Mdot
.61652 .61867 Mdot
.60492 .63811 Mdot
.36083 .76536 Mdot
.53596 .38084 Mdot
.46815 .57721 Mdot
.52635 .42677 Mdot
.41587 .64132 Mdot
.62041 .26661 Mdot
.57502 .62191 Mdot
.30784 .24758 Mdot
.47553 .38936 Mdot
.28582 .46845 Mdot
.55204 .60093 Mdot
.45609 .70398 Mdot
.48799 .42506 Mdot
.65074 .47694 Mdot
.38273 .68058 Mdot
.43381 .3936 Mdot
.41367 .65687 Mdot
.49478 .42829 Mdot
.4292 .44453 Mdot
.19749 .43683 Mdot
.33776 .48129 Mdot
.42939 .62081 Mdot
.52703 .58161 Mdot
.48965 .43575 Mdot
.31898 .45524 Mdot
.29682 .47236 Mdot
.66029 .49983 Mdot
.53342 .54018 Mdot
.32429 .58287 Mdot
.36443 .39883 Mdot
.37624 .77043 Mdot
.55529 .59946 Mdot
.60871 .73636 Mdot
.47985 .40857 Mdot
.65413 .52544 Mdot
.45782 .65154 Mdot
.50482 .34892 Mdot
.42162 .25137 Mdot
.3061 .5075 Mdot
.49774 .35476 Mdot
.66651 .47961 Mdot
.64336 .53947 Mdot
.65175 .51998 Mdot
.78493 .51202 Mdot
.60423 .61734 Mdot
.51109 .45629 Mdot
.43214 .4413 Mdot
.61251 .58927 Mdot
.48091 .34117 Mdot
.58376 .59827 Mdot
.48343 .82135 Mdot
.64604 .46285 Mdot
.30175 .45505 Mdot
.50226 .65984 Mdot
.45936 .35951 Mdot
.51009 .33231 Mdot
.69238 .50079 Mdot
.49167 .37901 Mdot
.1851 .42698 Mdot
.52047 .615 Mdot
.61266 .64362 Mdot
.34005 .48328 Mdot
.47639 .34652 Mdot
.54768 .54932 Mdot
.52335 .35739 Mdot
.41706 .31474 Mdot
.49263 .33988 Mdot
.34554 .58518 Mdot
.33461 .47323 Mdot
.41445 .661 Mdot
.50143 .44114 Mdot
.52029 .39566 Mdot
.72723 .36201 Mdot
.56658 .34667 Mdot
.50558 .43994 Mdot
.28788 .43886 Mdot
.34077 .49926 Mdot
.34914 .47845 Mdot
.58007 .65576 Mdot
.69988 .2822 Mdot
.43095 .65381 Mdot
.51463 .47011 Mdot
.38531 .66604 Mdot
.25618 .40455 Mdot
.64299 .47487 Mdot
.80157 .4839 Mdot
.49437 .40409 Mdot
.32814 .50167 Mdot
.71996 .69196 Mdot
.35397 .46568 Mdot
.48987 .55934 Mdot
.43763 .64017 Mdot
.30013 .50181 Mdot
.51447 .40091 Mdot
.41668 .50042 Mdot
.7934 .41383 Mdot
.43488 .65778 Mdot
.56134 .34591 Mdot
.57913 .65867 Mdot
.72841 .51949 Mdot
.21058 .34332 Mdot
.39835 .63866 Mdot
.45462 .60909 Mdot
.53726 .37954 Mdot
.30927 .51334 Mdot
.41666 .6348 Mdot
.39164 .65641 Mdot
.58564 .64592 Mdot
.51137 .41894 Mdot
.50607 .41918 Mdot
.57423 .64504 Mdot
.44479 .65225 Mdot
.52696 .44943 Mdot
.43361 .37487 Mdot
.76582 .30031 Mdot
.34401 .56437 Mdot
.84375 .62779 Mdot
.60515 .40205 Mdot
.37989 .2629 Mdot
.71628 .73113 Mdot
.27952 .4815 Mdot
.54468 .39556 Mdot
.44696 .35865 Mdot
.60741 .65664 Mdot
.51987 .37393 Mdot
.64168 .603 Mdot
.44547 .63769 Mdot
.6841 .22722 Mdot
.30988 .64546 Mdot
.53329 .82719 Mdot
.52166 .37469 Mdot
.33566 .43295 Mdot
.68166 .47681 Mdot
.41953 .60871 Mdot
.34165 .45829 Mdot
.53989 .42864 Mdot
.5043 .20288 Mdot
.55555 .63449 Mdot
.28969 .4885 Mdot
.56489 .19468 Mdot
.56151 .49003 Mdot
.51279 .43396 Mdot
.56776 .64564 Mdot
.75383 .66867 Mdot
.2973 .53963 Mdot
.38293 .6427 Mdot
.67464 .49045 Mdot
.618 .61548 Mdot
.44926 .62935 Mdot
.35801 .45065 Mdot
.29786 .49458 Mdot
.35493 .49843 Mdot
.42973 .21883 Mdot
.58611 .58361 Mdot
.67937 .47326 Mdot
.75279 .36563 Mdot
.72761 .33945 Mdot
.6677 .48728 Mdot
.61858 .65901 Mdot
.33952 .50026 Mdot
.31067 .5037 Mdot
.31854 .47559 Mdot
.38918 .21021 Mdot
.27557 .50125 Mdot
.29713 .72828 Mdot
.54517 .41666 Mdot
.43635 .35507 Mdot
.53711 .36718 Mdot
.41049 .67742 Mdot
.33033 .46388 Mdot
.44465 .50382 Mdot
.57273 .37961 Mdot
.78201 .45157 Mdot
.50296 .34601 Mdot
.46022 .62181 Mdot
.48978 .35987 Mdot
.19633 .56097 Mdot
.28269 .50439 Mdot
.51468 .37593 Mdot
.45936 .62899 Mdot
.68068 .4621 Mdot
.27559 .45535 Mdot
.51835 .42061 Mdot
.52987 .79047 Mdot
.55473 .38352 Mdot
.53753 .8198 Mdot
.25774 .54067 Mdot
.64242 .47629 Mdot
.22575 .55406 Mdot
.56118 .65203 Mdot
.4274 .37488 Mdot
.58258 .39527 Mdot
.42786 .66213 Mdot
.4991 .68589 Mdot
.5948 .61378 Mdot
.51348 .4864 Mdot
.44591 .43272 Mdot
.65485 .4988 Mdot
.32342 .53781 Mdot
.43898 .6738 Mdot
.48865 .33601 Mdot
.55977 .36262 Mdot
.34221 .73215 Mdot
.47124 .44923 Mdot
.48028 .34713 Mdot
.67997 .50896 Mdot
.29048 .71409 Mdot
.51039 .36345 Mdot
.49905 .56007 Mdot
.34836 .5157 Mdot
.56934 .42481 Mdot
.28238 .71621 Mdot
.46529 .38985 Mdot
.29097 .49548 Mdot
.45326 .31954 Mdot
.30518 .57463 Mdot
.70029 .48921 Mdot
.49462 .33864 Mdot
.19348 .61358 Mdot
.47968 .38192 Mdot
.43037 .65024 Mdot
.5548 .36233 Mdot
.60527 .62906 Mdot
.44781 .20017 Mdot
.60528 .65333 Mdot
.5213 .34414 Mdot
.3153 .47549 Mdot
.44127 .66137 Mdot
.33621 .24121 Mdot
.71011 .56086 Mdot
.27484 .69678 Mdot
.63567 .80877 Mdot
.69784 .47824 Mdot
.70124 .45352 Mdot
.44893 .66824 Mdot
.51391 .37407 Mdot
.29424 .74666 Mdot
.55561 .33124 Mdot
.50269 .35711 Mdot
.52539 .39124 Mdot
.76337 .45754 Mdot
.44821 .63587 Mdot
.58317 .63236 Mdot
.4822 .3568 Mdot
.49864 .43753 Mdot
.28107 .47886 Mdot
.66845 .45899 Mdot
.60757 .58932 Mdot
.65821 .47077 Mdot
.61354 .6139 Mdot
.65118 .19664 Mdot
.56113 .42 Mdot
.68584 .4666 Mdot
.38666 .68069 Mdot
.28414 .49033 Mdot
.2674 .64149 Mdot
.61019 .63706 Mdot
.59165 .65728 Mdot
.4787 .35275 Mdot
.29104 .49859 Mdot
.33616 .51529 Mdot
.68893 .48073 Mdot
.39836 .65167 Mdot
.53481 .40629 Mdot
.55073 .37595 Mdot
.42134 .35094 Mdot
.63304 .62421 Mdot
.24842 .57687 Mdot
.60348 .75038 Mdot
.51161 .3748 Mdot
.30724 .52004 Mdot
.53048 .39956 Mdot
.64533 .7608 Mdot
.3023 .51223 Mdot
.46479 .3968 Mdot
.57826 .16901 Mdot
.62075 .68018 Mdot
.28949 .59518 Mdot
.46412 .36757 Mdot
.69676 .77099 Mdot
.4855 .40714 Mdot
.70383 .23022 Mdot
.71326 .66456 Mdot
.5259 .3421 Mdot
.48083 .42266 Mdot
.31731 .37932 Mdot
.54449 .37033 Mdot
.57869 .64919 Mdot
.6381 .23119 Mdot
.35717 .48483 Mdot
.38059 .72769 Mdot
.39225 .24418 Mdot
.70066 .47791 Mdot
.62229 .63642 Mdot
.6548 .63183 Mdot
.66039 .48208 Mdot
.313 .48144 Mdot
.50451 .37655 Mdot
.44162 .52768 Mdot
.628 .60736 Mdot
.59761 .43751 Mdot
.43027 .64834 Mdot
.51299 .73275 Mdot
.5989 .54241 Mdot
.40986 .65431 Mdot
.50607 .42526 Mdot
.3035 .3795 Mdot
.50091 .23601 Mdot
.81433 .63215 Mdot
.44842 .62644 Mdot
.43604 .65893 Mdot
.41925 .20061 Mdot
.63745 .47887 Mdot
.3626 .73954 Mdot
.34822 .58976 Mdot
.43662 .66821 Mdot
.26392 .52811 Mdot
.55987 .62876 Mdot
.47503 .65348 Mdot
.5265 .45923 Mdot
.54862 .39759 Mdot
.51617 .39911 Mdot
.39833 .65841 Mdot
.58267 .31906 Mdot
.20638 .41547 Mdot
.42116 .66585 Mdot
.57835 .35058 Mdot
.51875 .52218 Mdot
.6134 .70841 Mdot
.57311 .63519 Mdot
.69529 .49397 Mdot
.65133 .44269 Mdot
.29139 .46534 Mdot
.69751 .49296 Mdot
.6454 .53604 Mdot
.49467 .38529 Mdot
.41266 .66787 Mdot
.50053 .70116 Mdot
.42249 .64156 Mdot
.6607 .47876 Mdot
.65104 .50106 Mdot
.29697 .46838 Mdot
.32721 .47773 Mdot
.34965 .29509 Mdot
.62397 .31035 Mdot
.5177 .35154 Mdot
.76874 .58657 Mdot
.31966 .52252 Mdot
.60011 .43872 Mdot
.69475 .49587 Mdot
.67572 .46088 Mdot
.7329 .37826 Mdot
.49897 .40504 Mdot
.24699 .44188 Mdot
.50106 .40115 Mdot
.62233 .27649 Mdot
.45727 .40324 Mdot
.58474 .64542 Mdot
.49792 .41171 Mdot
.74481 .38972 Mdot
.44998 .36948 Mdot
.52706 .33123 Mdot
.63018 .63227 Mdot
.43555 .40869 Mdot
.60324 .62855 Mdot
.52117 .34688 Mdot
.65638 .44763 Mdot
.62141 .64497 Mdot
.68828 .36407 Mdot
.73943 .39796 Mdot
.61605 .66178 Mdot
.65221 .4906 Mdot
.69409 .45816 Mdot
.7011 .39839 Mdot
.34153 .45794 Mdot
.58778 .38383 Mdot
.51625 .37255 Mdot
.55579 .61488 Mdot
.44482 .62974 Mdot
.47696 .42236 Mdot
.50697 .32826 Mdot
.45948 .38965 Mdot
.29084 .46491 Mdot
.68731 .55397 Mdot
.69045 .47232 Mdot
.56952 .64216 Mdot
.60748 .49991 Mdot
.62896 .60171 Mdot
.55293 .35309 Mdot
.44618 .36358 Mdot
.40823 .24735 Mdot
.58597 .71078 Mdot
.38837 .20372 Mdot
.29643 .49313 Mdot
.61537 .59564 Mdot
.64275 .45307 Mdot
.45517 .34407 Mdot
.32793 .50402 Mdot
.60581 .63131 Mdot
.50798 .37319 Mdot
.55457 .3351 Mdot
.29348 .68361 Mdot
.61014 .36849 Mdot
.71988 .38571 Mdot
.59401 .65991 Mdot
.56926 .65584 Mdot
.75523 .42479 Mdot
.71519 .49137 Mdot
.43155 .50198 Mdot
.53057 .37229 Mdot
.65158 .47735 Mdot
.33447 .50408 Mdot
.44734 .22301 Mdot
.40058 .66814 Mdot
.37328 .54594 Mdot
.52056 .37609 Mdot
.56865 .5025 Mdot
.31371 .47375 Mdot
.66835 .48187 Mdot
.39894 .6606 Mdot
.69138 .44502 Mdot
.62548 .61158 Mdot
.54424 .84409 Mdot
.48401 .37908 Mdot
.48437 .34728 Mdot
.44307 .61564 Mdot
.31574 .50923 Mdot
.70374 .48924 Mdot
.39742 .78021 Mdot
.59981 .64391 Mdot
.2754 .72915 Mdot
.31035 .51895 Mdot
.39325 .42557 Mdot
.56557 .63227 Mdot
.39616 .67871 Mdot
.68714 .38275 Mdot
.40494 .65468 Mdot
.51223 .34177 Mdot
.32575 .49495 Mdot
.42839 .62288 Mdot
.35259 .55103 Mdot
.80914 .426 Mdot
.38975 .42217 Mdot
.49947 .38732 Mdot
.76573 .32592 Mdot
.52128 .80807 Mdot
.30265 .53478 Mdot
.45669 .64344 Mdot
.50556 .34756 Mdot
.50376 .33366 Mdot
.47991 .37921 Mdot
.43614 .62837 Mdot
.7686 .56692 Mdot
.59136 .63685 Mdot
.53817 .37388 Mdot
.66905 .50417 Mdot
.59885 .62298 Mdot
.49605 .66836 Mdot
.57413 .63277 Mdot
.26627 .4978 Mdot
.54823 .34605 Mdot
.41857 .7176 Mdot
.60928 .14648 Mdot
.44083 .65346 Mdot
.62922 .65166 Mdot
.56023 .41633 Mdot
.53225 .70875 Mdot
.34673 .48669 Mdot
.59964 .64562 Mdot
.49169 .34782 Mdot
.50874 .64929 Mdot
.47138 .20622 Mdot
.57408 .62881 Mdot
.32803 .50547 Mdot
.81569 .61857 Mdot
.52151 .36787 Mdot
.48352 .3992 Mdot
.30381 .49916 Mdot
.26127 .35417 Mdot
.51272 .18147 Mdot
.52997 .4037 Mdot
.41339 .66175 Mdot
.43615 .84913 Mdot
.51121 .32685 Mdot
.65144 .27812 Mdot
.61625 .62126 Mdot
.46686 .67406 Mdot
.27881 .56672 Mdot
.46028 .34001 Mdot
.37916 .75583 Mdot
.45821 .60718 Mdot
.76441 .34893 Mdot
.64019 .60347 Mdot
.66707 .68136 Mdot
.72757 .29084 Mdot
.46287 .63255 Mdot
.39314 .46016 Mdot
.39581 .76245 Mdot
.26842 .30676 Mdot
.78462 .64979 Mdot
.68427 .65079 Mdot
.50484 .20125 Mdot
.46004 .52273 Mdot
.61022 .60341 Mdot
.5945 .47112 Mdot
.52149 .41589 Mdot
.52933 .8081 Mdot
.21212 .48495 Mdot
.20695 .46217 Mdot
.76856 .32854 Mdot
.32248 .41271 Mdot
.80281 .43482 Mdot
.83405 .50101 Mdot
.52996 .26429 Mdot
.63304 .71812 Mdot
.27746 .73529 Mdot
.62459 .20579 Mdot
.40149 .79978 Mdot
.44342 .33983 Mdot
.4786 .56305 Mdot
.59281 .81103 Mdot
.37271 .46124 Mdot
.22251 .40065 Mdot
.59759 .65203 Mdot
.3523 .47167 Mdot
.38446 .74568 Mdot
.31415 .44406 Mdot
.29958 .57124 Mdot
.82521 .61093 Mdot
.81364 .43517 Mdot
.20763 .62173 Mdot
.71566 .74423 Mdot
.40987 .25768 Mdot
.18183 .66112 Mdot
.61459 .58322 Mdot
.28726 .46019 Mdot
.73859 .44067 Mdot
.7499 .38307 Mdot
.33367 .69185 Mdot
.43864 .78824 Mdot
.74747 .5233 Mdot
.63839 .36845 Mdot
.31823 .48836 Mdot
.23558 .55478 Mdot
.48579 .65941 Mdot
.31067 .65405 Mdot
.62228 .21813 Mdot
.81108 .56919 Mdot
.43414 .53336 Mdot
.4526 .77893 Mdot
.54601 .73366 Mdot
.22733 .32906 Mdot
.67045 .31337 Mdot
.60159 .44784 Mdot
.34118 .5702 Mdot
.69512 .74323 Mdot
.28031 .31262 Mdot
.60543 .27451 Mdot
.74577 .36966 Mdot
.62153 .18976 Mdot
.61222 .77939 Mdot
.45234 .14677 Mdot
.34828 .45137 Mdot
.47225 .3532 Mdot
.2875 .33971 Mdot
.20015 .63324 Mdot
.65219 .50538 Mdot
.78629 .53269 Mdot
.69222 .49227 Mdot
.27865 .51539 Mdot
.4795 .19417 Mdot
.28193 .71192 Mdot
.20521 .65754 Mdot
.67386 .44447 Mdot
.50003 .471 Mdot
.62136 .8626 Mdot
.77972 .41124 Mdot
.29023 .62146 Mdot
.7502 .28329 Mdot
.52243 .5053 Mdot
.26815 .53839 Mdot
.43241 .62367 Mdot
.71951 .27385 Mdot
.31614 .50074 Mdot
.46854 .13127 Mdot
.69699 .22396 Mdot
.444 .2366 Mdot
.92427 .47898 Mdot
.75691 .44094 Mdot
.54843 .50882 Mdot
.38059 .60811 Mdot
.66398 .33621 Mdot
.21178 .38674 Mdot
.6666 .42542 Mdot
.5366 .71528 Mdot
.67528 .79753 Mdot
.75606 .32369 Mdot
.22726 .68594 Mdot
.49403 .83828 Mdot
.25499 .32745 Mdot
.54076 .55476 Mdot
.56328 .45004 Mdot
.59983 .5484 Mdot
.79468 .58278 Mdot
.62828 .18452 Mdot
.66211 .29757 Mdot
.76824 .75321 Mdot
.70101 .50088 Mdot
.74184 .57576 Mdot
.84584 .58012 Mdot
.65238 .3797 Mdot
.25183 .54858 Mdot
.66781 .2707 Mdot
.53831 .47319 Mdot
.61956 .50894 Mdot
.79251 .55274 Mdot
.2605 .60131 Mdot
.65772 .24318 Mdot
.74478 .69209 Mdot
.33898 .72965 Mdot
.35709 .37475 Mdot
.70833 .31001 Mdot
.32398 .43924 Mdot
.62112 .33087 Mdot
.27623 .55979 Mdot
.81558 .41572 Mdot
.47122 .6328 Mdot
.83363 .42123 Mdot
.51778 .18459 Mdot
.55143 .4354 Mdot
.55977 .33009 Mdot
.2741 .43971 Mdot
.62966 .3329 Mdot
.43506 .41649 Mdot
.30957 .6985 Mdot
.8321 .46241 Mdot
.47342 .25592 Mdot
.4908 .62937 Mdot
.5015 .6811 Mdot
.84351 .59463 Mdot
.30984 .33631 Mdot
.71819 .48703 Mdot
.60639 .2345 Mdot
.22288 .34493 Mdot
.59023 .61822 Mdot
.2339 .68865 Mdot
.37691 .66263 Mdot
.4629 .21432 Mdot
.36218 .40214 Mdot
.34112 .2653 Mdot
.83271 .46296 Mdot
.67078 .65058 Mdot
.50069 .19092 Mdot
.64888 .40098 Mdot
.34671 .78381 Mdot
.60872 .70831 Mdot
.43939 .40323 Mdot
.46273 .78959 Mdot
.67692 .45153 Mdot
.34206 .3357 Mdot
.4089 .82587 Mdot
.69981 .60845 Mdot
.4693 .44258 Mdot
.44414 .23277 Mdot
.62807 .68117 Mdot
.4132 .50456 Mdot
.32634 .21116 Mdot
.53664 .33129 Mdot
.74573 .35204 Mdot
.59233 .78391 Mdot
.64659 .31708 Mdot
.77783 .68338 Mdot
.66726 .7458 Mdot
.49079 .1412 Mdot
.74507 .28895 Mdot
.69861 .56225 Mdot
.72412 .29289 Mdot
.79712 .36601 Mdot
.48432 .14754 Mdot
.57898 .36054 Mdot
.42771 .61252 Mdot
.16327 .37704 Mdot
.57067 .63275 Mdot
.76559 .39843 Mdot
.37561 .7704 Mdot
.56862 .55764 Mdot
.30709 .42782 Mdot
.56272 .46922 Mdot
.4601 .52814 Mdot
.29586 .53224 Mdot
.43717 .42107 Mdot
.3924 .18652 Mdot
.54168 .14757 Mdot
.43372 .16108 Mdot
.64896 .78641 Mdot
.70273 .26223 Mdot
.56628 .51378 Mdot
.21633 .63947 Mdot
.6002 .40669 Mdot
.53944 .41975 Mdot
.71824 .46091 Mdot
.75657 .44471 Mdot
.41974 .23113 Mdot
.33123 .65405 Mdot
.34702 .53127 Mdot
.7891 .54312 Mdot
.32119 .8407 Mdot
.37046 .28711 Mdot
.31078 .74584 Mdot
.72415 .50246 Mdot
.6295 .31356 Mdot
.78544 .58768 Mdot
.38111 .24204 Mdot
.84287 .50388 Mdot
.30225 .53267 Mdot
.39708 .79264 Mdot
.7005 .6417 Mdot
.4035 .47707 Mdot
.6942 .55112 Mdot
.8111 .45867 Mdot
.39234 .72622 Mdot
.35511 .24083 Mdot
.34933 .61327 Mdot
.28797 .32784 Mdot
.52328 .63546 Mdot
.5211 .73963 Mdot
.38672 .80863 Mdot
.6573 .73305 Mdot
.63276 .27445 Mdot
.50875 .52726 Mdot
.2175 .55858 Mdot
.45266 .60231 Mdot
.63684 .28068 Mdot
.43458 .47456 Mdot
.72291 .30594 Mdot
.51857 .08842 Mdot
.32003 .23111 Mdot
.82476 .64052 Mdot
.77399 .58968 Mdot
.45247 .42837 Mdot
.84596 .53115 Mdot
.41367 .15806 Mdot
.64743 .17065 Mdot
.49595 .75621 Mdot
.63497 .60051 Mdot
.38993 .67184 Mdot
.4246 .18178 Mdot
.76547 .56233 Mdot
.82954 .55013 Mdot
.68592 .30024 Mdot
.41215 .68627 Mdot
.15297 .47565 Mdot
.62145 .19379 Mdot
.37676 .40854 Mdot
.60899 .3629 Mdot
.4642 .42876 Mdot
.20341 .51277 Mdot
.31316 .44537 Mdot
.59339 .7375 Mdot
.61786 .30219 Mdot
.58371 .61487 Mdot
.73359 .44901 Mdot
.4542 .7932 Mdot
.55323 .39468 Mdot
.53071 .57256 Mdot
.27174 .46627 Mdot
.59551 .71375 Mdot
.28689 .656 Mdot
.60841 .16293 Mdot
.72288 .51203 Mdot
.50978 .44689 Mdot
.64818 .31167 Mdot
.69195 .5469 Mdot
.49531 .17831 Mdot
.44921 .66955 Mdot
.78192 .35619 Mdot
.44595 .5501 Mdot
.6202 .32513 Mdot
.21935 .47776 Mdot
.56145 .31137 Mdot
.51971 .33489 Mdot
.69351 .72677 Mdot
.42663 .29555 Mdot
.39092 .53107 Mdot
.52018 .46288 Mdot
.59635 .38509 Mdot
.84462 .54121 Mdot
.64099 .53894 Mdot
.52541 .73 Mdot
.79619 .38275 Mdot
.43223 .63261 Mdot
.2875 .5091 Mdot
.61963 .45531 Mdot
.42604 .80126 Mdot
.45433 .2893 Mdot
.4696 .20643 Mdot
.5805 .54709 Mdot
.70839 .59796 Mdot
.80223 .39939 Mdot
.77942 .36183 Mdot
.18699 .52486 Mdot
.30327 .5366 Mdot
.55172 .27838 Mdot
.41709 .80418 Mdot
.34379 .49946 Mdot
.3138 .71993 Mdot
.30195 .70599 Mdot
.66187 .21241 Mdot
.51865 .58887 Mdot
.68547 .78949 Mdot
.71382 .38099 Mdot
.77866 .53353 Mdot
.33352 .24137 Mdot
.37158 .79612 Mdot
.79743 .45531 Mdot
.26621 .52548 Mdot
.31703 .39252 Mdot
.44599 .34021 Mdot
.22135 .60434 Mdot
.16354 .4068 Mdot
.6222 .46727 Mdot
.38757 .4453 Mdot
.74943 .68944 Mdot
.49691 .37374 Mdot
.28828 .24954 Mdot
.431 .79328 Mdot
.40877 .20222 Mdot
.39705 .68281 Mdot
.51118 .43041 Mdot
.46177 .35341 Mdot
.63921 .25208 Mdot
.29892 .57613 Mdot
.71019 .29303 Mdot
.45105 .84662 Mdot
.77018 .65096 Mdot
.21958 .47371 Mdot
.75779 .38753 Mdot
.81301 .57452 Mdot
.54068 .80625 Mdot
.52046 .54309 Mdot
.7477 .47478 Mdot
.66483 .37886 Mdot
.70285 .75253 Mdot
.43509 .47984 Mdot
.41618 .5853 Mdot
.33875 .70805 Mdot
.61245 .75256 Mdot
.39997 .22251 Mdot
.4918 .42321 Mdot
.56534 .19487 Mdot
.83149 .52093 Mdot
.1941 .51294 Mdot
.19736 .39272 Mdot
.32942 .22259 Mdot
.39588 .34121 Mdot
.63451 .74945 Mdot
.50494 .80451 Mdot
.35754 .80673 Mdot
.44162 .55269 Mdot
.78251 .46837 Mdot
.65832 .39076 Mdot
.80016 .39317 Mdot
.44189 .61381 Mdot
.34254 .60378 Mdot
.50416 .68121 Mdot
.71986 .29411 Mdot
.3077 .35105 Mdot
.82263 .47336 Mdot
.50033 .50898 Mdot
.49874 .13757 Mdot
.67111 .72465 Mdot
.47367 .51913 Mdot
.62308 .61042 Mdot
.67416 .63195 Mdot
.80082 .51989 Mdot
.68338 .70272 Mdot
.35742 .78297 Mdot
.63913 .65163 Mdot
.60989 .45891 Mdot
.36342 .4253 Mdot
.61419 .33751 Mdot
.69046 .73133 Mdot
.64818 .31225 Mdot
.82218 .45014 Mdot
.65243 .25068 Mdot
.56041 .19567 Mdot
.76168 .4408 Mdot
.61879 .82346 Mdot
.28892 .61674 Mdot
.63398 .51357 Mdot
.43957 .79318 Mdot
.74356 .59428 Mdot
.25586 .5167 Mdot
.20272 .25407 Mdot
.55232 .83834 Mdot
.65819 .72098 Mdot
.62936 .18583 Mdot
.66499 .75528 Mdot
.58478 .71219 Mdot
.24022 .35991 Mdot
.35709 .56452 Mdot
.54553 .21202 Mdot
.52438 .39138 Mdot
.38705 .18213 Mdot
.60989 .30907 Mdot
.58539 .15081 Mdot
.83056 .56171 Mdot
.31046 .42555 Mdot
.54713 .34616 Mdot
.56908 .64397 Mdot
.45558 .57532 Mdot
.57203 .26101 Mdot
.27899 .37347 Mdot
.23817 .52996 Mdot
.51326 .64734 Mdot
.60238 .58352 Mdot
.67772 .54653 Mdot
.33193 .52811 Mdot
.77045 .54887 Mdot
.61074 .74943 Mdot
.54565 .63846 Mdot
.42224 .5377 Mdot
.63496 .29225 Mdot
.2684 .56519 Mdot
.38078 .4063 Mdot
.38684 .2382 Mdot
.40882 .72123 Mdot
.57761 .64421 Mdot
.37349 .39359 Mdot
.58856 .81629 Mdot
.75052 .6749 Mdot
.61954 .18563 Mdot
.61666 .51749 Mdot
.27853 .39611 Mdot
.63716 .27208 Mdot
.20398 .40104 Mdot
.22917 .42357 Mdot
.58019 .70287 Mdot
.20871 .52036 Mdot
.23259 .39 Mdot
.40238 .75754 Mdot
.68484 .22661 Mdot
.40021 .79797 Mdot
.41473 .80484 Mdot
.54089 .59239 Mdot
.43486 .32708 Mdot
.345 .43208 Mdot
.69594 .36977 Mdot
.42241 .50425 Mdot
.16612 .61975 Mdot
.54976 .45396 Mdot
.12302 .56531 Mdot
.39253 .6463 Mdot
.22919 .35156 Mdot
.66968 .38675 Mdot
.51984 .52684 Mdot
.48991 .50114 Mdot
.65948 .73693 Mdot
.34083 .58712 Mdot
.59807 .78898 Mdot
.20756 .44649 Mdot
.61737 .583 Mdot
.47101 .8552 Mdot
.62836 .82354 Mdot
.33688 .38469 Mdot
.55887 .39477 Mdot
.57845 .8314 Mdot
.62853 .59343 Mdot
.4086 .23134 Mdot
.78473 .67499 Mdot
.73187 .67232 Mdot
.39793 .44717 Mdot
.62763 .31887 Mdot
.78435 .46616 Mdot
.77709 .33182 Mdot
.16883 .45296 Mdot
.79092 .55707 Mdot
.43879 .61352 Mdot
.50899 .51407 Mdot
.81634 .49797 Mdot
.29889 .54984 Mdot
.47938 .64375 Mdot
.25108 .54092 Mdot
.15692 .64329 Mdot
.76801 .39823 Mdot
.71498 .30109 Mdot
.25362 .53522 Mdot
.2949 .52195 Mdot
.32384 .57274 Mdot
.25266 .5502 Mdot
.71503 .688 Mdot
.54965 .82134 Mdot
.26262 .55527 Mdot
.28131 .76122 Mdot
.55657 .30317 Mdot
.65615 .66277 Mdot
.31549 .42334 Mdot
.50902 .26322 Mdot
.41797 .68723 Mdot
.59106 .21332 Mdot
.77816 .652 Mdot
.39995 .62488 Mdot
.70359 .72424 Mdot
.45924 .78106 Mdot
.39976 .41418 Mdot
.43632 .30723 Mdot
.76424 .64546 Mdot
.29914 .37202 Mdot
.2037 .57976 Mdot
.46374 .22409 Mdot
.63706 .64032 Mdot
.79797 .63236 Mdot
.61234 .6408 Mdot
.59434 .45037 Mdot
.36588 .54845 Mdot
.65919 .42445 Mdot
.40024 .1985 Mdot
.6991 .47053 Mdot
.31119 .44838 Mdot
.16499 .41925 Mdot
.32611 .51515 Mdot
.40757 .17872 Mdot
.34816 .26015 Mdot
.20625 .50153 Mdot
.69694 .56913 Mdot
.6863 .6001 Mdot
.20779 .69772 Mdot
.48632 .67132 Mdot
.59071 .55239 Mdot
.24479 .64494 Mdot
.29188 .45541 Mdot
.73213 .50525 Mdot
.62835 .64025 Mdot
.40943 .55833 Mdot
.40724 .73868 Mdot
.52969 .29772 Mdot
.3659 .4606 Mdot
.41408 .54941 Mdot
.57564 .22984 Mdot
.68796 .24346 Mdot
.58821 .59526 Mdot
.13315 .55481 Mdot
.53612 .34014 Mdot
.3549 .36705 Mdot
.84513 .49873 Mdot
.15361 .4821 Mdot
.63109 .56307 Mdot
.63982 .82307 Mdot
.47772 .43307 Mdot
.77696 .60749 Mdot
.31547 .49457 Mdot
.40369 .79573 Mdot
.68758 .49169 Mdot
.65108 .32425 Mdot
.38745 .65487 Mdot
.35095 .24232 Mdot
.64361 .57257 Mdot
.35272 .50149 Mdot
.7541 .6335 Mdot
.52625 .26491 Mdot
.37958 .58209 Mdot
.67052 .56867 Mdot
.34026 .38835 Mdot
.44613 .2996 Mdot
.36914 .50776 Mdot
.72929 .31966 Mdot
.42594 .817 Mdot
.6164 .16187 Mdot
.27687 .44443 Mdot
.56953 .49221 Mdot
.32831 .71477 Mdot
.72307 .70126 Mdot
.23466 .60977 Mdot
.84061 .47659 Mdot
.60772 .285 Mdot
.47008 .30163 Mdot
.62539 .28048 Mdot
.50264 .30876 Mdot
.48448 .54319 Mdot
.55607 .74022 Mdot
.20082 .46779 Mdot
.25544 .57654 Mdot
.25969 .33377 Mdot
.21352 .58143 Mdot
.71338 .30765 Mdot
.21239 .50904 Mdot
.58848 .67452 Mdot
.40322 .38861 Mdot
.39215 .61892 Mdot
.69822 .24535 Mdot
.84226 .4835 Mdot
.44345 .60779 Mdot
.72724 .52674 Mdot
.73786 .7194 Mdot
.53094 .31845 Mdot
.59051 .50796 Mdot
.49056 .34265 Mdot
.59935 .35024 Mdot
.14836 .50966 Mdot
.72064 .69058 Mdot
.49463 .45383 Mdot
.75911 .3346 Mdot
.73994 .30252 Mdot
.53657 .13751 Mdot
.30297 .75619 Mdot
.30141 .46339 Mdot
.48253 .15546 Mdot
.23504 .5294 Mdot
.7884 .34547 Mdot
.61759 .71165 Mdot
.86316 .50489 Mdot
.31675 .38874 Mdot
.72048 .72003 Mdot
.23101 .37533 Mdot
.35134 .5771 Mdot
.60068 .77428 Mdot
.56858 .52142 Mdot
.50741 .71971 Mdot
.64298 .76792 Mdot
.4203 .85712 Mdot
.44386 .35429 Mdot
.5015 .79187 Mdot
.36276 .70805 Mdot
.80464 .62202 Mdot
.6835 .68643 Mdot
.55655 .37157 Mdot
.49588 .69524 Mdot
.38892 .21459 Mdot
.6441 .29318 Mdot
.60188 .46725 Mdot
.67814 .68971 Mdot
.51148 .22083 Mdot
.61385 .26736 Mdot
.40567 .80397 Mdot
.33207 .39062 Mdot
.45715 .56737 Mdot
.48747 .43472 Mdot
.36946 .48058 Mdot
.70544 .46847 Mdot
.56419 .52928 Mdot
.52016 .34822 Mdot
.55073 .63008 Mdot
.37803 .5797 Mdot
.36943 .20269 Mdot
.26692 .60109 Mdot
.47416 .80943 Mdot
.34322 .43973 Mdot
.36377 .69602 Mdot
.24551 .62854 Mdot
.29876 .25537 Mdot
.7173 .64151 Mdot
.66238 .29802 Mdot
.78338 .40673 Mdot
.66365 .25176 Mdot
.38547 .47623 Mdot
.56819 .16622 Mdot
.45781 .6495 Mdot
.40138 .42442 Mdot
.34774 .66851 Mdot
.67174 .53891 Mdot
.50482 .46049 Mdot
.72009 .71942 Mdot
.59379 .54702 Mdot
.74865 .3887 Mdot
.61182 .78226 Mdot
.55883 .29034 Mdot
.35084 .41394 Mdot
.7742 .34901 Mdot
.5572 .63483 Mdot
.45992 .82142 Mdot
.37796 .59578 Mdot
.68271 .67208 Mdot
.68401 .2548 Mdot
.64015 .19125 Mdot
.46259 .50572 Mdot
.65812 .36474 Mdot
.47823 .39652 Mdot
.39152 .8078 Mdot
.71636 .69986 Mdot
.50668 .47783 Mdot
.49097 .74735 Mdot
.29367 .51234 Mdot
.53097 .75769 Mdot
.47418 .56567 Mdot
.53706 .21821 Mdot
.28125 .45355 Mdot
.20163 .50427 Mdot
.66592 .44689 Mdot
.54573 .4989 Mdot
.45249 .4501 Mdot
.66326 .35238 Mdot
.22895 .6954 Mdot
.50293 .46632 Mdot
.79539 .56289 Mdot
.35771 .39541 Mdot
.39788 .78212 Mdot
.7619 .64297 Mdot
.55759 .69556 Mdot
.34104 .5843 Mdot
.41141 .35797 Mdot
.40885 .72697 Mdot
.46235 .37753 Mdot
.61329 .67887 Mdot
.35256 .49302 Mdot
.7983 .64188 Mdot
.40829 .3247 Mdot
.6868 .36538 Mdot
.51662 .61567 Mdot
.60345 .4446 Mdot
.37608 .61979 Mdot
.85821 .50153 Mdot
.34149 .57761 Mdot
.61527 .29418 Mdot
.51933 .58766 Mdot
.67161 .38272 Mdot
.32925 .27766 Mdot
.68986 .2161 Mdot
.23177 .37025 Mdot
.42893 .52451 Mdot
.22403 .36298 Mdot
.64732 .73576 Mdot
.77048 .6943 Mdot
.61104 .27623 Mdot
.51882 .49773 Mdot
.6763 .51289 Mdot
.28458 .6779 Mdot
.51193 .62519 Mdot
.60645 .47849 Mdot
.41518 .5609 Mdot
.4507 .74599 Mdot
.42189 .70049 Mdot
.48827 .47303 Mdot
.76678 .43202 Mdot
.77946 .3829 Mdot
.38403 .77495 Mdot
.44716 .60047 Mdot
.6517 .68877 Mdot
.54148 .22636 Mdot
.87142 .51657 Mdot
.18313 .37051 Mdot
.47822 .39373 Mdot
.3984 .60684 Mdot
.64605 .3574 Mdot
.60287 .6618 Mdot
.25033 .56191 Mdot
.25228 .62736 Mdot
.41239 .62378 Mdot
.61372 .46127 Mdot
.73611 .35824 Mdot
.62474 .74254 Mdot
.61742 .3573 Mdot
.50036 .6654 Mdot
.35198 .20906 Mdot
.62317 .80428 Mdot
.72564 .69601 Mdot
.87442 .45201 Mdot
.39616 .58815 Mdot
.58872 .36748 Mdot
.32201 .31192 Mdot
.69156 .2522 Mdot
.65663 .31386 Mdot
.44581 .21772 Mdot
.5307 .68765 Mdot
.60633 .27704 Mdot
.24565 .50194 Mdot
.7618 .41082 Mdot
.52307 .7575 Mdot
.48316 .53252 Mdot
.68881 .60598 Mdot
.58454 .16264 Mdot
.3315 .41796 Mdot
.79294 .41986 Mdot
.35821 .22595 Mdot
.33932 .80093 Mdot
.7101 .25968 Mdot
.73812 .39904 Mdot
.70598 .66581 Mdot
.29151 .33818 Mdot
.4281 .4717 Mdot
.26882 .53231 Mdot
.41414 .23023 Mdot
.46111 .27785 Mdot
.73559 .54796 Mdot
.27985 .30213 Mdot
.63328 .27478 Mdot
.48473 .25915 Mdot
.5132 .49788 Mdot
.38194 .39656 Mdot
.72138 .5303 Mdot
.26997 .54463 Mdot
.41695 .47675 Mdot
.69104 .34283 Mdot
.36608 .39287 Mdot
.344 .72694 Mdot
.66117 .75108 Mdot
.32222 .802 Mdot
.76197 .59332 Mdot
.28747 .26901 Mdot
.54669 .41543 Mdot
.55002 .12323 Mdot
.61781 .76214 Mdot
.65193 .70912 Mdot
.57 .80828 Mdot
.62757 .68551 Mdot
.57153 .3304 Mdot
.46216 .3783 Mdot
.79696 .52102 Mdot
.38793 .44155 Mdot
.41178 .25199 Mdot
.33294 .24927 Mdot
.63898 .31959 Mdot
.68598 .30402 Mdot
.70385 .37554 Mdot
.44373 .32903 Mdot
.3175 .51526 Mdot
.44303 .15855 Mdot
.43995 .51001 Mdot
.52079 .47554 Mdot
.42241 .42224 Mdot
.28455 .33076 Mdot
.69495 .79237 Mdot
.2846 .43579 Mdot
.68115 .27879 Mdot
.31892 .40733 Mdot
.3941 .48178 Mdot
.22706 .59108 Mdot
.88479 .38322 Mdot
.5956 .12516 Mdot
.35644 .49079 Mdot
.29494 .73342 Mdot
.32081 .41041 Mdot
.71808 .29745 Mdot
.705 .63837 Mdot
.45862 .7553 Mdot
.44639 .46423 Mdot
.39006 .51331 Mdot
.44851 .44252 Mdot
.57825 .79363 Mdot
.70667 .2431 Mdot
.30738 .26796 Mdot
.7611 .3376 Mdot
.51749 .30443 Mdot
.46749 .45545 Mdot
.88943 .50379 Mdot
.81617 .48719 Mdot
.55154 .34269 Mdot
.21698 .40129 Mdot
.55707 .45313 Mdot
.52061 .41204 Mdot
.76714 .50895 Mdot
.47122 .85419 Mdot
.63399 .27034 Mdot
.71983 .29453 Mdot
.29939 .44616 Mdot
.64832 .65796 Mdot
.39167 .6469 Mdot
.46989 .50352 Mdot
.56742 .36045 Mdot
.42677 .62483 Mdot
.58114 .29331 Mdot
.7429 .70389 Mdot
.49136 .60411 Mdot
.46314 .83957 Mdot
.84417 .43025 Mdot
.39856 .34621 Mdot
.28203 .67018 Mdot
.50244 .32396 Mdot
.50046 .26263 Mdot
.54958 .243 Mdot
.60067 .37018 Mdot
.68492 .75171 Mdot
.30697 .17518 Mdot
.48419 .716 Mdot
.56682 .21293 Mdot
.2977 .52613 Mdot
.43324 .5654 Mdot
.37815 .42497 Mdot
.62799 .6962 Mdot
.60306 .5912 Mdot
.50286 .30412 Mdot
.28035 .44841 Mdot
.38193 .67683 Mdot
.12352 .51971 Mdot
.5588 .40499 Mdot
.24016 .57679 Mdot
.79018 .35218 Mdot
.46297 .2238 Mdot
.33316 .35844 Mdot
.4538 .39523 Mdot
.31163 .66269 Mdot
.52352 .49761 Mdot
.7964 .60678 Mdot
.56919 .19941 Mdot
.76815 .36974 Mdot
.41279 .31891 Mdot
.34406 .41247 Mdot
.49633 .43712 Mdot
.64077 .49061 Mdot
.46825 .67083 Mdot
.78261 .51868 Mdot
.57659 .41559 Mdot
.76112 .30331 Mdot
.66172 .60275 Mdot
.58151 .5318 Mdot
.25641 .45774 Mdot
.52592 .14049 Mdot
.29782 .30467 Mdot
.37112 .44548 Mdot
.31158 .24312 Mdot
.6574 .55268 Mdot
.61595 .34297 Mdot
.56421 .6406 Mdot
.58177 .37717 Mdot
.31058 .43845 Mdot
.30231 .23446 Mdot
.7692 .49298 Mdot
.5091 .71131 Mdot
.51712 .73856 Mdot
.33904 .75749 Mdot
.37596 .5882 Mdot
.86508 .43039 Mdot
.66919 .57829 Mdot
.31969 .22614 Mdot
.43424 .81873 Mdot
.31752 .43583 Mdot
.67327 .73924 Mdot
.54797 .45253 Mdot
.58138 .60521 Mdot
.75962 .34481 Mdot
.58192 .45172 Mdot
.48268 .19624 Mdot
.44749 .40586 Mdot
.43891 .19407 Mdot
.65189 .51488 Mdot
.73621 .51251 Mdot
.6507 .72594 Mdot
.28864 .32372 Mdot
.8363 .58676 Mdot
.28693 .68252 Mdot
.85099 .54245 Mdot
.82636 .60612 Mdot
.77906 .34892 Mdot
.44456 .2083 Mdot
.16692 .48 Mdot
.66001 .71184 Mdot
.75751 .65545 Mdot
.58123 .74332 Mdot
.26852 .34965 Mdot
.67424 .64161 Mdot
.25798 .44993 Mdot
.2996 .57852 Mdot
.41881 .60724 Mdot
.10148 .41876 Mdot
.70845 .33192 Mdot
.29311 .43628 Mdot
.67422 .60671 Mdot
.75391 .31158 Mdot
.29449 .32903 Mdot
.6346 .77443 Mdot
.47728 .56159 Mdot
.43849 .39709 Mdot
.43961 .29797 Mdot
.3686 .77393 Mdot
.66305 .59426 Mdot
.24339 .74868 Mdot
.60098 .80923 Mdot
.48465 .73493 Mdot
.47107 .54404 Mdot
.35251 .46951 Mdot
.21453 .60514 Mdot
.69154 .59104 Mdot
.67338 .76127 Mdot
.72958 .71425 Mdot
.81672 .49514 Mdot
.20711 .69527 Mdot
.40489 .79142 Mdot
.68915 .24696 Mdot
.68785 .72072 Mdot
.35194 .50672 Mdot
.73498 .40894 Mdot
.63442 .61116 Mdot
.53435 .71877 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0YOooool2o`000:;ooooo000Looooo`03o`000?oooooooooo0:Gooooo0_l0
002Rooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo0_l00020ooooo`;o0000b?ooool001cooooo00?o0000ooooooooool0
Ooooool2o`000<Sooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0:oooooo0_l0000=
ooooo`;o0000ROooool001cooooo00?o0000ooooooooool0[oooool2o`0000gooooo0_l00029oooo
o`007?ooool00ol0003oooooooooo`2Dooooo`;o0000/oooool001cooooo00?o0000ooooooooool0
U?ooool2o`000;?ooooo000Looooo`03o`000?oooooooooo09kooooo0_l0000;ooooo`;o0000W?oo
ool001cooooo00?o0000ooooooooool0UOooool2o`0000Gooooo1?l00004ooooo`;o000000?ooooo
o`000?l000000_ooool2o`0009cooooo000Looooo`03o`000?oooooooooo09Gooooo0_l00005oooo
o`;o00001_ooool2o`000003ooooool0003o000000gooooo0_l0002Aooooo`007?ooool00ol0003o
ooooooooo`28ooooo`;o00001Oooool2o`0000Wooooo0_l0000@ooooo`;o00002?ooool2o`0000[o
oooo0_l00025ooooo`007?ooool00ol0003oooooooooo`1looooo`;o00002_ooool2o`0000Gooooo
0_l00009ooooo`;o00004?ooool2o`0000Sooooo0_l0000:ooooo`;o0000QOooool001cooooo0_l0
001mooooo`;o0000>?ooool2o`0000;ooooo1?l0002;ooooo`007?ooool00ol0003oooooooooo`2I
ooooo`;o00003?ooool2o`00017ooooo1?l0002;ooooo`007?ooool00ol0003oooooooooo`23oooo
o`;o00001oooool2o`0000_ooooo0_l0000<ooooo`;o0000X?ooool001cooooo00?o0000oooooooo
ool0Poooool2o`0000Cooooo0_l000000ooooooo0000o`00000/ooooo`;o00001_ooool4o`0008?o
oooo000Looooo`03o`000?oooooooooo08Wooooo0_l0000_ooooo`;o00000_ooool2o`0000;ooooo
1?l00006ooooo`;o0000Noooool001cooooo00?o0000ooooooooool0ZOooool2o`0000[ooooo0_l0
00000ooooooo0000o`000004ooooo`;o00000oooool2o`0000Oooooo0_l0001kooooo`007?ooool0
0ol0003oooooooooo`2Dooooo`;o00003Oooool2o`0000Cooooo0_l0000:ooooo`;o000000?ooooo
o`000?l000001?ooool2o`0000?ooooo0_l0000:ooooo`;o0000N?ooool001cooooo00?o0000oooo
ooooool0H?ooool2o`0003;ooooo0ol000000ooooooo0000o`000009ooooo`;o00006Oooool2o`00
00oooooo0_l0001hooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o0000<oooool2o`000003
ooooool0003o000000?ooooo0_l0000Dooooo`;o00002_ooool2o`0000Oooooo0_l0001oooooo`00
7?ooool00ol0003oooooooooo`21ooooo`;o00004_ooool2o`000003ooooool0003o000000?ooooo
0_l000001?oooooo0000o`000?ooool2o`0000kooooo0_l0000:ooooo`;o00001oooool2o`0007oo
oooo000Looooo`03o`000?oooooooooo07[ooooo0_l00005ooooo`;o00000oooool2o`00013ooooo
0_l00003ooooo`;o000000Coooooo`000?l0003ooooo0ol0000Rooooo`;o0000Ooooool001cooooo
00?o0000ooooooooool0Joooool2o`0000gooooo1?l00008ooooo`;o00004_ooool2o`0000Sooooo
1?l00006ooooo`;o00005Oooool2o`000004ooooool0003o0000o`0007kooooo000Looooo`03o`00
0?oooooooooo06_ooooo0_l0000?ooooo`;o00004?ooool2o`0000[ooooo0_l0000:ooooo`;o0000
1_ooool5o`00017ooooo1?l000000ooooooo0000o`00001nooooo`0000Koooooonk^k_lb<S;o0000
oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0S_ooool2o`000003
ooooool0003o000000cooooo0_l00008ooooo`Co00000oooool3o`000003ooooool0003o000000ko
oooo1?l00004ooooo`;o0000Noooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q
8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo07Gooooo0_l0000D
ooooo`;o00001?ooool2o`0000Gooooo0ol00004ooooo`;o00000oooool2o`0000?ooooo1_l00003
ooooo`Co00002Oooool2o`0000Cooooo0ol00004ooooo`;o00000_ooool2o`0007Oooooo00000ooo
oooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0
003oooooooooo`1eooooo`;o00001oooool2o`0000_ooooo0_l0000;ooooo`?o00002Oooool2o`00
00Oooooo0_l00003ooooo`Go00000oooool2o`0000?ooooo0_l000000ooooooo0000o`000006oooo
o`;o00001?ooool2o`0007Oooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_o
oooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0007Cooooo0_l00008ooooo`;o000000Coooooo`000?l0
003ooooo0_l00008ooooo`?o00001oooool4o`0000Cooooo0_l0000?ooooo`;o000000Coooooo`00
0?l0003o00000oooool2o`0000Gooooo0ol00002ooooo`?o000000?oooooo`000?l00000OOooool0
0003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`05oooo
o`03o`000?oooooooooo07Cooooo0_l00004ooooo`;o00001Oooool2o`000003ooooool0003o0000
00Oooooo1?l00007ooooo`Ko00000_ooool3o`0000Kooooo0_l00006ooooo`;o00001oooool3o`00
00Cooooo0_l000000ooooooo0000o`000003o`0001;ooooo0_l0001/ooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0Koooool2o`0000Wooooo0_l0000=ooooo`Ko000000?oooooo`000?l000000oooool2o`0000?o
oooo1?l00003ooooo`;o00001_ooool3o`0000oooooo0_l00007ooooo`;o000000?oooooo`000?l0
00004_ooool2o`0006cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj
^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo06Kooooo0_l00004ooooo`;o000000?ooooo
o`000?l000001oooool2o`000003ooooool0003o000000Kooooo0_l00004ooooo`Ko000000?ooooo
o`000?l000000oooool2o`0001?ooooo0_l000000ooooooo0000o`000004ooooo`;o00001_ooool2
o`000003ooooool0003o000000;o0000Qoooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2ooo
ool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0I_ooool2o`0000Cooooo
0_l0000:ooooo`;o000000?oooooo`000?l000001_ooool2o`0000kooooo0_l0000Hooooo`;o0000
1?ooool3o`000003ooooool0003o000000?ooooo1_l00009ooooo`;o00001_ooool2o`000003oooo
ool0003o000000Gooooo0_l0001Zooooo`007?ooool00ol0003oooooooooo`1hooooo`;o000000?o
ooooo`000?l000000oooool2o`0000_ooooo0_l00004ooooo`;o00005_ooool2o`0000Oooooo0_l0
00000ooooooo0000o`000003ooooo`;o00002?ooool2o`0000?ooooo0_l00006ooooo`;o000000?o
ooooo`000?l000001?ooool3o`0006[ooooo000Looooo`03o`000?oooooooooo077ooooo0_l0000=
ooooo`;o00001_ooool2o`0000?ooooo0_l0000Aooooo`Co00001oooool2o`000003ooooool0003o
000000Cooooo0_l0000@ooooo`;o00005?ooool2o`0006_ooooo000Looooo`03o`000?oooooooooo
06Oooooo0_l00003ooooo`;o00000oooool2o`0000Cooooo0_l00004ooooo`?o00002?ooool2o`00
00Cooooo0_l00003ooooo`;o00000_ooool2o`0000Oooooo1?l0000:ooooo`;o00001?ooool2o`00
01Gooooo0_l00005ooooo`;o00002oooool2o`0006Sooooo000Looooo`03o`000?oooooooooo06Co
oooo0_l000000ooooooo0000o`000003ooooo`;o00000oooool2o`0000Cooooo0_l00004ooooo`?o
000000?oooooo`000?l000002oooool4o`000003ooooool0003o000000;ooooo0_l00007ooooo`;o
00002_ooool2o`0001?ooooo0_l00008ooooo`;o00001Oooool2o`0000Kooooo1?l000001?oooooo
0000o`000?l0001Wooooo`007?ooool00ol0003oooooooooo`1Gooooo`;o00002oooool2o`0000Ko
oooo0_l00003ooooo`Co00002?ooool2o`0000;ooooo1_l00002ooooo`;o00001Oooool2o`0000Go
oooo0_l00007ooooo`;o00002_ooool3o`0000Sooooo0_l00008ooooo`;o000000?oooooo`000?l0
00001Oooool2o`0000Gooooo0_l00006ooooo`Co00000_ooool3o`0006Kooooo000Looooo`03o`00
0?oooooooooo05Gooooo1?l0000;ooooo`;o00000_ooool2o`0000;ooooo0_l00005ooooo`;o0000
1oooool3o`0000;ooooo1_l00002ooooo`;o00000_ooool2o`0001Gooooo0_l00006ooooo`?o0000
00?oooooo`000?l000001Oooool2o`0000_ooooo0_l00005ooooo`;o00001Oooool2o`0000gooooo
0_l0001Vooooo`007?ooool00ol0003oooooooooo`1Eooooo`;o00001oooool2o`0000Cooooo0_l0
0002ooooo`;o00004_ooool2o`0000?ooooo1_l000000ooooooo0000o`000002ooooo`?o00003Ooo
ool2o`000003ooooool0003o000000?ooooo0_l00006ooooo`;o00000_ooool2o`0000Cooooo0_l0
0009ooooo`;o00002?ooool4o`0007[ooooo000Looooo`03o`000?oooooooooo05kooooo0_l0000J
ooooo`;o00001oooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`0000[ooooo0_l00000
0ooooooo0000o`00000Eooooo`;o00002Oooool2o`0000[ooooo1?l0001hooooo`007?ooool00ol0
003oooooooooo`1Qooooo`;o00001_ooool2o`0000?ooooo1?l00006ooooo`Co00002_ooool3o`00
00Oooooo0_l0000Mooooo`;o00002oooool3o`00013ooooo0_l0000Aooooo`;o0000IOooool001co
oooo00?o0000ooooooooool0HOooool2o`0000Kooooo0_l00003ooooo`Co00001_ooool2o`0000;o
oooo0_l00008ooooo`?o00001?ooool2o`0000kooooo0_l00003ooooo`;o00000_ooool2o`0000Oo
oooo0_l00007ooooo`?o000000?oooooo`000?l000000ol0000Aooooo`;o00002?ooool2o`000004
ooooool0003o0000ooooo`Co0000Hoooool001cooooo00?o0000ooooooooool0H?ooool3o`0000Go
oooo0_l0000<ooooo`Co00000_ooool2o`0000?ooooo0_l0000:ooooo`;o00000oooool2o`0000Wo
oooo0_l00003ooooo`;o00000_ooool2o`00013ooooo0ol00004ooooo`?o00003Oooool2o`000003
ooooool0003o000000Gooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l0001Soooo
o`007?ooool2o`0005_ooooo0_l00004ooooo`?o00001Oooool2o`0000cooooo0_l00009ooooo`?o
000000?oooooo`000?l000002oooool2o`0002Wooooo0_l000000ooooooo0000o`00000:ooooo`;o
000000Coooooo`000?l0003o00000_ooool3o`0000;ooooo0_l000001?oooooo0000o`000?l00006
ooooo`;o0000H_ooool001cooooo00?o0000ooooooooool0?_ooool2o`0001[ooooo0_l000000ooo
oooo0000o`000002ooooo`;o000000?oooooo`000?l000007?ooool2o`000003ooooool0003o0000
00Sooooo0_l00002ooooo`;o0000:?ooool2o`000003ooooool0003o000000Oooooo0_l000000ooo
oooo0000o`000002ooooo`Oo00000oooool2o`000003ooooool0003o000000Kooooo0_l0001Roooo
o`007?ooool00ol0003oooooooooo`0nooooo`;o00007Oooool2o`0000Gooooo0_l00006ooooo`;o
00002Oooool4o`0000Kooooo0_l0000<ooooo`Wo00002?ooool2o`0002Oooooo0ol00006ooooo`Co
00001?ooool2o`0000Kooooo0_l0001Uooooo`007?ooool00ol0003oooooooooo`1[ooooo`Co0000
2?ooool5o`0000Gooooo0_l0000>ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o0000
1?ooool2o`0000oooooo0_l00003ooooo`;o000000Coooooo`000?l0003o00002Oooool2o`0000;o
oooo0ol0000Booooo`;o00000_ooool3o`0006Cooooo000Looooo`03o`000?oooooooooo05Cooooo
0ol0000Dooooo`Co00002Oooool4o`0001kooooo0_l00003ooooo`;o000000?oooooo`000?l00000
1?ooool2o`0000Oooooo0_l00003ooooo`Ko00001Oooool2o`0000;ooooo0_l00002ooooo`;o0000
2Oooool2o`0000Sooooo1?l000000ooooooo0000o`00001Tooooo`007?ooool00ol0003ooooooooo
o`1Dooooo`?o00005?ooool2o`0000_ooooo0_l0000Uooooo`;o000000?oooooo`000?l000000ooo
ool3o`0000gooooo0_l00002ooooo`;o00001?ooool2o`000003ooooool0003o000000;o00002?oo
ool2o`0000;ooooo0_l00007ooooo`;o000000?oooooo`000?l00000Ioooool001cooooo00?o0000
ooooooooool0F_ooool2o`0000Cooooo0_l00009ooooo`;o0000>_ooool2o`0000kooooo0ol00000
1?oooooo0000o`000?l00002ooooo`;o00000_ooool4o`0000;ooooo0_l00004ooooo`;o00000ooo
ool4o`0000Cooooo0_l00004ooooo`;o0000I?ooool001cooooo00?o0000ooooooooool0B?ooool2
o`0000[ooooo0_l00004ooooo`;o00001?ooool2o`0000oooooo0_l00015ooooo`;o00000_ooool2
o`0000;ooooo0_l00008ooooo`?o00000oooool2o`0000;ooooo1Ol00006ooooo`;o00000_ooool2
o`000003ooooool0003o0000067ooooo000Looooo`03o`000?oooooooooo04Sooooo0_l0000:oooo
o`;o00001?ooool2o`0001Gooooo0_l00014ooooo`;o00002?ooool4o`000003ooooool0003o0000
00;ooooo0ol00002ooooo`Co000000?oooooo`000?l000000_l00007ooooo`;o00001Oooool2o`00
067ooooo000Looooo`03o`000?oooooooooo05[ooooo0_l0000;ooooo`;o0000:Oooool2o`0001_o
oooo0_l00006ooooo`;o00002?ooool4o`000003ooooool0003o000000;ooooo0_l00003ooooo`Co
00000_ooool6o`0000[ooooo0_l0001Rooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o0000
3?ooool2o`0002Wooooo0_l000000ooooooo0000o`00000?ooooo`;o00001?ooool2o`000003oooo
ool0003o000000Sooooo0_l00005ooooo`;o00000oooool5o`000003ooooool0003o000000?ooooo
0ol00002ooooo`Ko00001Oooool2o`0000?ooooo0_l0001Rooooo`007?ooool00ol0003ooooooooo
o`1Iooooo`Co00004?ooool2o`0002;ooooo0_l00002ooooo`;o00003oooool2o`0000Cooooo0_l0
0008ooooo`;o000000Coooooo`000?l0003o00001?ooool4o`000003ooooool0003o000000?o0000
00?oooooo`000?l000000_l00002ooooo`;o00002_ooool2o`000003ooooool0003o000000kooooo
0_l0001Gooooo`007?ooool00ol0003oooooooooo`1Kooooo`;o00003Oooool2o`000003ooooool0
003o000000Kooooo0_l0000Iooooo`?o00008oooool2o`0000;ooooo0_l00006ooooo`;o00002Ooo
ool2o`0000kooooo0_l0000?ooooo`Co0000Eoooool001cooooo00?o0000ooooooooool0@_ooool2
o`0001gooooo0_l00007ooooo`;o00002Oooool2o`0001Wooooo0_l0000=ooooo`;o00002_ooool4
o`0000?ooooo0_l00005ooooo`;o00001Oooool2o`000003ooooool0003o000000Gooooo0_l00009
ooooo`;o00001oooool2o`0000Wooooo0_l00003ooooo`;o0000FOooool001cooooo00?o0000oooo
ooooool0@_ooool2o`0001gooooo0_l0000;ooooo`;o0000;oooool2o`0000Gooooo0_l00003oooo
o`Co00000oooool2o`0000Gooooo0_l00005ooooo`;o000000Coooooo`000?l0003o00001?ooool2
o`000003ooooool0003o000000Kooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0
003o000000?ooooo0_l000000ooooooo0000o`000004o`0005gooooo000Looooo`03o`000?oooooo
oooo06Wooooo0_l00003ooooo`;o00005oooool2o`0000;ooooo0_l0000Iooooo`Co00000_ooool3
o`0000[ooooo0_l00008ooooo`?o00001oooool4o`000004ooooool0003o0000o`0000?ooooo0_l0
00000ooooooo0000o`000005ooooo`Oo000000?oooooo`000?l00000GOooool001cooooo0_l0001F
ooooo`;o00003?ooool4o`0000;ooooo0_l00007ooooo`;o00004oooool2o`0000;ooooo1?l00006
ooooo`;o00004?ooool3o`0000?ooooo0_l0000:ooooo`;o00001Oooool2o`0000gooooo0_l00000
1?oooooo0000o`000?l00005ooooo`?o00001Oooool5o`0000kooooo0_l0001Booooo`007?ooool0
0ol0003oooooooooo`1Eooooo`Co00001?ooool2o`0000Cooooo1?l00002ooooo`;o00001Oooool4
o`0001Sooooo0ol00006ooooo`Co00001?ooool2o`000003ooooool0003o000000;ooooo0_l00000
0ooooooo0000o`000002o`0000Kooooo0_l0000=ooooo`;o00000oooool2o`000003ooooool0003o
0000013ooooo0ol00007ooooo`;o00001oooool2o`0000Cooooo1?l0001Booooo`007?ooool00ol0
003oooooooooo`1Cooooo`;o00000_ooool2o`0000?ooooo0ol0000Aooooo`;o00006?ooool2o`00
00_ooooo0_l00003ooooo`?o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l00006oooo
o`;o00001?ooool2o`0000cooooo0_l000000ooooooo0000o`00000Aooooo`;o00001oooool2o`00
0003ooooool0003o000000Cooooo0_l00004ooooo`;o0000E?ooool001cooooo00?o0000oooooooo
ool0<Oooool2o`00023ooooo0_l00007ooooo`Go0000:Oooool2o`00013ooooo0_l00002ooooo`;o
000000Coooooo`000?l0003ooooo1Ol0000<ooooo`;o00002Oooool2o`000003ooooool0003o0000
00Co00003?ooool3o`0000Sooooo1?l000000ooooooo0000o`00001Pooooo`007?ooool00ol0003o
ooooooooo`0aooooo`;o00002Oooool2o`0001Gooooo0_l00002ooooo`;o00001?ooool4o`0000Co
oooo0_l0000Mooooo`;o00006?ooool4o`000003ooooool0003o000000Oo00001oooool2o`0000;o
oooo0_l00009ooooo`;o000000?oooooo`000?l000001?l00004ooooo`;o000000?oooooo`000?l0
00000_ooool4o`0000Sooooo0_l0000=ooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0
>_ooool4o`0001Wooooo0_l00006ooooo`;o00001?ooool2o`0001gooooo0_l0000;ooooo`;o0000
1_ooool2o`0000?ooooo0_l00005ooooo`Oo00001oooool2o`0000gooooo0_l00005ooooo`;o0000
0oooool3o`000003ooooool0003o000000;ooooo0_l0000Iooooo`;o0000E_ooool001cooooo00?o
0000ooooooooool0>_ooool2o`0002?ooooo0_l0000Qooooo`Co00002Oooool4o`0000?ooooo0_l0
00000ooooooo0000o`000002o`0000Kooooo2?l0000>ooooo`;o00001oooool2o`0000Cooooo0_l0
0002ooooo`Co00001?ooool2o`0000?ooooo0_l0000:ooooo`Ko00002Oooool2o`0005?ooooo000L
ooooo`03o`000?oooooooooo06kooooo0_l000000ooooooo0000o`00000?ooooo`;o00002oooool2
o`000003ooooool0003o000000;ooooo0_l00003ooooo`Co00000oooool3o`000004ooooool0003o
0000ooooo`;o00001?ooool2o`0000Sooooo0_l00007ooooo`Co00000_ooool2o`0000;ooooo0_l0
0006ooooo`;o00000oooool4o`0000Cooooo0_l00002ooooo`Ko00002Oooool2o`0005?ooooo000L
ooooo`03o`000?oooooooooo05Cooooo0_l00004ooooo`;o00004?ooool4o`000003ooooool0003o
000000kooooo0_l0000<ooooo`;o000000?oooooo`000?l000002Oooool4o`000004ooooool0003o
0000ooooo`?o00001?ooool5o`000003ooooool0003o0000013ooooo1?l000000ooooooo0000o`00
0005ooooo`;o00002Oooool2o`0000Cooooo0_l0000?ooooo`;o000000?oooooo`000?l00000D_oo
ool001cooooo00?o0000ooooooooool0A_ooool2o`0000Oooooo0_l00003ooooo`;o00001?ooool4
o`000003ooooool0003o000000_ooooo0_l0000Cooooo`;o00001oooool4o`00013ooooo2_l00004
ooooo`So00004Oooool3o`000003ooooool0003o000000Gooooo0_l000000ooooooo0000o`00000:
ooooo`;o00002Oooool2o`0000Kooooo0_l000001?oooooo0000o`000?l0001Aooooo`007?ooool0
0ol0003oooooooooo`16ooooo`;o00001oooool2o`0000Cooooo0_l00002ooooo`So0000:Oooool4
o`0000Cooooo0_l00004ooooo`?o000000?oooooo`000?l000002ol00002ooooo`;o00000_ooool9
o`0000_ooooo1Ol00004ooooo`;o000000?oooooo`000?l000000_ooool2o`0000[ooooo0_l00000
0ooooooo0000o`000006ooooo`;o00002_ooool2o`000003ooooool0003o000004kooooo000Loooo
o`03o`000?oooooooooo04Kooooo0_l00009ooooo`;o00000_ooool2o`0000;ooooo0_l00002oooo
o`?o00003Oooool2o`0000gooooo0_l00004ooooo`;o00002_ooool3o`000003ooooool0003o0000
00?ooooo1?l000000ooooooo0000o`00000;o`0000;ooooo0_l00002ooooo`Wo00001oooool2o`00
00;ooooo0_l000001?oooooo0000o`000?ooool2o`000004ooooool0003o0000ooooo`;o00002_oo
ool2o`0000;ooooo0_l000000ooooooo0000o`00000?ooooo`;o00001?ooool2o`0004kooooo000L
ooooo`03o`000?oooooooooo04cooooo0_l00003ooooo`;o00000_ooool2o`0000Cooooo1?l00002
ooooo`;o00002?ooool4o`0000gooooo0_l00004ooooo`;o00000_ooool2o`0000;ooooo0_l00002
ooooo`?o00001_ooool2o`0000;ooooo3Ol00003ooooo`;o00000_ooool4o`0000cooooo0_l00003
ooooo`;o00000oooool2o`0000Wooooo0_l00005ooooo`;o00002oooool2o`0000Wooooo0_l0001D
ooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00000_ooool2o`000003ooooool0003o0000
00Gooooo0ol00004ooooo`;o00002?ooool2o`0000?ooooo0_l0000:ooooo`?o00000oooool2o`00
00;ooooo0_l00002ooooo`Go00000oooool2o`0000Cooooo4Ol000001?oooooo0000o`000?ooool3
o`0001Cooooo0_l0000>ooooo`;o00001Oooool2o`0000_ooooo0ol00008ooooo`;o0000E?ooool0
01cooooo00?o0000ooooooooool0=Oooool2o`0000[ooooo0_l0000=ooooo`;o000000Coooooo`00
0?l0003ooooo0_l00002ooooo`;o00003_ooool4o`0000;ooooo0_l0000:ooooo`?o00002?ooool2
o`0000?ooooo0ol000000ooooooo0000o`000002o`000003ooooool0003o000001Go000000?ooooo
o`000?l000001?l00003ooooo`;o00003?ooool2o`0000_ooooo0_l0000:ooooo`Co00001oooool3
o`0000Sooooo0ol00007ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0=Oooool2o`00
00;ooooo0_l00006ooooo`;o00000_ooool2o`0000oooooo0_l0000Booooo`Co00000_ooool2o`00
00Sooooo0_l00002ooooo`;o00001oooool2o`0000Oooooo0ol00002oooooaKo00000_ooool<o`00
00_ooooo0_l0000;ooooo`;o00002Oooool5o`0000Sooooo0_l00008ooooo`?o00001_ooool3o`00
04[ooooo000Looooo`;o0000>_ooool2o`0000Kooooo1_l00009ooooo`?o000000?oooooo`000?l0
00005_ooool3o`0000;ooooo0_l00007ooooo`;o00000_ooool4o`0000?ooooo0_l00009ooooo`Co
000000?oooooo`000?l000006ol000001Ooooooo0000o`000?l0003ooooo00?o00001Oooool2o`00
01_ooooo0_l0000;ooooo`;o00002Oooool2o`0000;ooooo0ol000000ooooooo0000o`00001;oooo
o`007?ooool00ol0003oooooooooo`0Yooooo`;o00006?ooool2o`0000;ooooo0_l00007ooooo`?o
000000?oooooo`000?l000002_ooool2o`000003ooooool0003o000000Oooooo0ol00002ooooo`;o
00003Oooool4o`000003ooooool0003o000000;o00001OoooolIo`000003ooooool0003o000000So
000000?oooooo`000?l000000oooool2o`0000Gooooo0_l00008ooooo`;o00001oooool4o`0000co
oooo0_l0000:ooooo`;o00001?ooool2o`0000;ooooo0ol00002ooooo`;o0000B_ooool001cooooo
00?o0000ooooooooool0:Oooool2o`0001cooooo1ol00002ooooo`?o00003?ooool3o`000003oooo
ool0003o000001gooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000Co0000
00?oooooo`000?l000008Ol00009ooooo`;o00002_ooool2o`0000Oooooo1?l0000<ooooo`;o0000
2_ooool2o`000003ooooool0003o000000Oooooo0_l000000ooooooo0000o`00001:ooooo`007?oo
ool00ol0003oooooooooo`19ooooo`Go00000oooool2o`0000cooooo0_l00007ooooo`;o00001ooo
ool2o`0000oooooo0_l00006ooooo`Wo000000?oooooo`000?l000003Ol000000ooooooo0000o`00
000>o`0000Wooooo0_l00006ooooo`;o00001oooool2o`0000Sooooo0_l00008ooooo`;o00001ooo
ool2o`0000Cooooo0_l00007ooooo`;o0000COooool001cooooo00?o0000ooooooooool0:_ooool2
o`0001Wooooo0_l00003ooooo`;o00007?ooool2o`0000Oooooo0_l0000?ooooo`;o00002Oooool]
o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000001oooool2o`0000Sooooo0_l0000<
ooooo`Co000000?oooooo`000?l000003?ooool2o`0004kooooo000Looooo`03o`000?oooooooooo
02[ooooo0_l0000Gooooo`Co0000>oooool2o`0000Wooooo8?l000000ooooooo0000o`00000<o`00
0003ooooool0003o000000?ooooo0_l0000>ooooo`;o00001oooool3o`0000Cooooo0_l00002oooo
o`Co00001oooool2o`0000Kooooo0_l00004ooooo`;o0000B?ooool001cooooo00?o0000oooooooo
ool0@oooool3o`0002[ooooo0_l00002ooooo`;o00003?ooool2o`0000Kooooo0_l000000ooooooo
0000o`00000Jo`0000;ooooo3_l000001?oooooo0000o`000?l00004ooooo`?o00002?ooool2o`00
00Cooooo0_l00007ooooo`?o00001?ooool2o`0000gooooo0_l0000:ooooo`Co000000?oooooo`00
0?l00000AOooool001cooooo00?o0000ooooooooool0>?ooool2o`0000Gooooo0_l00003ooooo`;o
00000_ooool2o`0001?ooooo0_l0000Aooooo`;o00000_ooool2o`0000Oooooo0_l0000:ooooo`?o
00000_ooool<o`000003ooooool0003o000001Ko000000?oooooo`000?l000001ol00002ooooo`Go
00002?ooool2o`0000cooooo0_l00002ooooo`;o00003_ooool2o`0000Kooooo0_l00005ooooo`;o
00000oooool2o`0004Gooooo000Looooo`03o`000?oooooooooo02kooooo0_l00008ooooo`;o0000
1Oooool2o`0000;ooooo0_l00002ooooo`?o00003Oooool3o`0000?ooooo0_l0000=ooooo`?o0000
00?oooooo`000?l000002oooool2o`0000Gooooo1ol00003ooooobGo000000?oooooo`000?l00000
0oooool2o`0000Cooooo0_l00006ooooo`;o00003Oooool3o`000003ooooool0003o000000;ooooo
0_l000000ooooooo0000o`000005ooooo`;o00001?ooool2o`0000Gooooo0ol0001Aooooo`007?oo
ool00ol0003oooooooooo`0^ooooo`;o000000?oooooo`000?l000004?ooool2o`0000;ooooo0_l0
000>ooooo`Go00004?ooool3o`000003ooooool0003o000001;ooooo1ol00004oooooaWo000000?o
ooooo`000?l000002?l000000ooooooo0000o`000002ooooo`?o00000_ooool2o`0000;ooooo0_l0
0004ooooo`;o00000_ooool2o`0000Wooooo0ol00002ooooo`;o00001?ooool2o`000003ooooool0
003o000000;ooooo1?l00009ooooo`;o000000?oooooo`000?l00000Coooool001cooooo00?o0000
ooooooooool0<Oooool2o`0002Oooooo0_l00003ooooo`;o00000_ooool2o`0001kooooo0_l00008
ooooobKo000000?oooooo`000?l000001Ol00002ooooo`;o00000_ooool2o`0000Sooooo0_l00003
ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo0_l00007ooooo`;o00001?ooool2
o`0000cooooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`0dooooo`;o00001oooool2o`00
00Sooooo0_l0000>ooooo`;o00001_ooool2o`0000;ooooo0_l00005ooooo`;o00004Oooool2o`00
00Cooooo1?l00002ooooo`;o00000_ooool5o`000003ooooool0003o000002Co00000_ooool2o`00
01?ooooo2Ol00002ooooo`Co00001Oooool2o`0000;ooooo0_l00006ooooo`;o00001oooool2o`00
00Cooooo1?l0000Iooooo`;o0000:oooool001cooooo00?o0000ooooooooool0=?ooool2o`0000Oo
oooo0_l00002ooooo`;o00001?ooool2o`0000kooooo0_l00006ooooo`;o00002Oooool2o`0000Go
oooo0_l0000:ooooo`;o00001_ooool2o`000003ooooool0003o000000?o000000Coooooo`000?l0
003ooooo9Ol000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000_ooool2o`00
00_ooooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool4o`0000Oooooo1?l00005oooo
o`Oo00000oooool2o`0000Cooooo1?l0000Iooooo`;o0000:oooool001cooooo00?o0000oooooooo
ool0?Oooool2o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`0001Cooooo0ol00003ooooo`;o
000000?oooooo`000?l000001?ooool2o`0000cooooo0_l00007ooooo`;o000000Coooooo`000?l0
003ooooo8ol000000ooooooo0000o`000002o`0000;ooooo0ol00003ooooo`;o00000_ooool2o`00
00_ooooo0_l000000ooooooo0000o`000002ooooo`;o00001oooool2o`0000Cooooo0ol00006oooo
o`?o000000?oooooo`000?l000000_l0001Cooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5
ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0>oooool4
o`0000Wooooo0_l000001?oooooo0000o`000?l0000;ooooo`;o00001oooool3o`0000?ooooo0_l0
00000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l000001oooool2o`0000Sooooo0_l0
0004ooooo`Ko000000?oooooo`000?l000006_l00002ooooo`;o000000?oooooo`000?l000000_l0
0005ooooo`Co00000_ooool2o`0000Gooooo1?l000000ooooooo0000o`00000;ooooo`;o00001?oo
ool2o`0000Oooooo0ol0000?ooooo`;o0000Aoooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Tooooo`;o0000
5Oooool3o`0000Cooooo0_l00007ooooo`;o00002_ooool4o`0000Sooooo0_l0000;ooooo`;o0000
00Coooooo`000?l0003ooooo1?l0000?ooooo`Co00000_ooool3o`000004ooooool0003o0000oooo
oaoo00000_ooool4o`000003ooooool0003o000000;ooooo1?l00002ooooo`;o00001Oooool2o`00
00cooooo1_l00005ooooo`;o00001?ooool2o`0001;ooooo0_l00017ooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`09ooooo`Go00001_ooool00ol0003oooooooooo`0Tooooo`;o
00005?ooool2o`0000Kooooo0_l0000Cooooo`;o00004_ooool2o`0000?ooooo0_l000000ooooooo
0000o`000003ooooo`;o00004Oooool:o`000003ooooool0003o000001go000000Coooooo`000?l0
003ooooo1Ol0000Mooooo`Co000000?oooooo`000?l000001?ooool2o`0000Cooooo0ol00006oooo
o`?o00002Oooool2o`0004Kooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wo
oooo00CoA4A4omgMgOoooooo00001oooool3o`0003Oooooo0_l000000ooooooo0000o`000003oooo
o`;o00000_ooool4o`0002Cooooo0_l00005ooooo`?o00004Oooool2o`0000?ooooo:_l000000ooo
oooo0000o`000003ooooo`;o00001?ooool2o`0000cooooo0_l0000?ooooo`;o00002?ooool5o`00
00Kooooo1?l00008ooooo`;o0000A_ooool00003ooooool0003ooooo00;ooooo00?o0000oooooooo
ool02Oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo03Oooooo0_l00006oooo
o`;o00000_ooool4o`0000Wooooo0_l0000Pooooo`;o00001?ooool2o`0000cooooo0_l00002oooo
o`?o000000?oooooo`000?l00000:Ol00008ooooo`?o00002oooool2o`0000oooooo0_l00008oooo
o`;o00002oooool2o`00053ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[o
oooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0Vooooo`;o00002Oooool2o`00017o
oooo0_l0000:ooooo`;o00004_ooool2o`00017ooooo0ol00005ooooo`;o00000oooool2o`0000Co
oooo2Ol000000ooooooo0000o`00000<o`000003ooooool0003o000000Wo000000?oooooo`000?l0
00002Ol00005ooooo`;o000000?oooooo`000?l000007?ooool2o`0000;ooooo0_l00005ooooo`;o
00000oooool2o`0000Wooooo0_l0001<ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<oooo
o`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool09_ooool2o`0000Wooooo0_l00006oooo
o`;o00003Oooool2o`0001[ooooo0_l00006ooooo`;o00002Oooool2o`0000Kooooo0_l00003oooo
o`?o00000ooooolHo`000003ooooool0003o000001Go00001?ooool4o`0002;ooooo0_l00005oooo
o`;o00000oooool2o`0000;ooooo0_l00003ooooo`Co0000C?ooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo02Wooooo0_l0000>
ooooo`;o00001?ooool2o`0000Oooooo0ol00002ooooo`;o00001_ooool2o`0000Gooooo0_l00006
ooooo`?o00001?ooool5o`0000[ooooo0ol000000ooooooo0000o`000005ooooo`;o00001Oooool5
o`000003ooooool0003o000002?o000000?oooooo`000?l000000_l00002ooooo`Co0000;_ooool2
o`0000;ooooo0_l00003ooooo`;o00000oooool2o`0004Wooooo000Looooo`03o`000?oooooooooo
02Wooooo0_l0000Dooooo`;o00002?ooool2o`0000;ooooo0_l00006ooooo`;o00001Oooool2o`00
0003ooooool0003o000000?ooooo0ol000001?oooooo0000o`000?ooool2o`000003ooooool0003o
000000[ooooo0ol000000ooooooo0000o`00000:ooooobgo000000?oooooo`000?l000001?l00008
ooooo`;o0000;?ooool3o`0000Oooooo0_l00005ooooo`;o0000@_ooool001cooooo00?o0000oooo
ooooool07Oooool2o`0001?ooooo0_l0000<ooooo`;o00001_ooool2o`0001;ooooo0_l000000ooo
oooo0000o`000003ooooo`;o00000_ooool2o`0000cooooo0_l00007ooooo`;o00002OoooolOo`00
0003ooooool0003o000000Co000000?oooooo`000?l000001Ol00002ooooo`Co00002?ooool2o`00
02cooooo0ol00007ooooo`;o00000oooool4o`0000Cooooo0_l0000looooo`007?ooool00ol0003o
ooooooooo`0Mooooo`;o00004oooool2o`0000cooooo0_l00005ooooo`?o00004Oooool2o`0000Ko
oooo0_l0000Aooooo`;o00000oooool2o`0000;ooooo0_l00004ooooo`;o00000_ooool7o`000003
ooooool0003o000001co00001?ooool5o`00013ooooo0_l00008ooooo`;o00004oooool2o`0000Wo
oooo0_l0000:ooooo`;o00000oooool2o`0000Kooooo0_l0000looooo`007?ooool00ol0003ooooo
ooooo`0booooo`;o00001?ooool2o`0000gooooo0_l0000<ooooo`;o00001?ooool2o`0000?ooooo
1Ol00007ooooo`;o00001?ooool2o`0000?ooooo0_l00002ooooo`?o000000Coooooo`000?l0003o
00000oooool2o`0000;ooooo1?l000000ooooooo0000o`000002o`0000?ooooo7ol000000ooooooo
0000o`000002ooooo`;o00003Oooool2o`0000Sooooo1Ol0000@ooooo`;o00002Oooool2o`0000go
oooo1?l00014ooooo`007?ooool00ol0003oooooooooo`0booooo`;o00001?ooool2o`0000Wooooo
0_l0000@ooooo`;o00001?ooool2o`0000?ooooo1Ol00007ooooo`;o00001?ooool2o`0000?ooooo
0_l00003ooooo`;o00000_ooool2o`0000gooooo4?l000000ooooooo0000o`000007o`000003oooo
ool0003o000000_o00000_ooool3o`0001Sooooo0ol0000Cooooo`;o00000oooool2o`0000Wooooo
0_l00005ooooo`Co00002Oooool2o`0000Gooooo0_l0000booooo`007?ooool00ol0003ooooooooo
o`13ooooo`;o00001Oooool2o`0000Wooooo0_l00004ooooo`;o00001_ooool2o`0000;ooooo1?l0
00000ooooooo0000o`000009ooooo`;o00005?ooool8o`000003ooooool0003o000001[o00000_oo
ool3o`0000?ooooo0_l000000ooooooo0000o`00000Eooooo`;o00005?ooool2o`0000?ooooo0ol0
0003ooooo`;o00000oooool2o`0000Sooooo0_l00008ooooo`;o00000oooool4o`0003;ooooo000L
ooooo`03o`000?oooooooooo03cooooo0_l0000<ooooo`;o00003Oooool4o`0000Kooooo0_l00002
ooooo`Co000000?oooooo`000?l000002Oooool3o`0001?ooooo1?l00002ooooo`;o00000_oooolJ
o`000004ooooool0003o0000ooooo`;o00001_ooool2o`0000cooooo0_l000000ooooooo0000o`00
0005ooooo`;o00006Oooool2o`0000?ooooo0_l0000:ooooo`;o000000?oooooo`000?l000003Ooo
ool2o`0003Cooooo000Looooo`03o`000?oooooooooo03Oooooo0_l00003ooooo`;o00001oooool2
o`0000?ooooo0_l00009ooooo`;o00000_ooool4o`0000Cooooo1ol00004ooooo`;o00002_ooool2
o`0001;ooooo1Ol00002ooooo`;o000000?oooooo`000?l000000_oooolCo`000003ooooool0003o
000000Oo00001oooool3o`0000[ooooo1Ol00005ooooo`;o00004Oooool2o`0001Gooooo1?l00000
0ooooooo0000o`000013ooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00003?ooool2o`00
00?ooooo0_l000000ooooooo0000o`000006ooooo`;o00000oooool6o`000004ooooool0003o0000
ooooo`Co00001?ooool2o`0000cooooo0_l0000=ooooo`;o000000?oooooo`000?l000000_l00005
ooooo`Oo000000?oooooo`000?l000002ol00002ooooo`Oo000000?oooooo`000?l000002?ooool3
o`0000_ooooo0_l00002ooooo`;o00005_ooool2o`0000;ooooo0_l00004ooooo`Co00002Oooool6
o`0004Cooooo000Looooo`03o`000?oooooooooo04gooooo1?l00005ooooo`;o00000_oooolBo`00
00Wooooo0_l00003ooooo`;o00003?ooool3o`0000;ooooo1_l00002ooooo`;o000000?oooooo`00
0?l000000_l000000ooooooo0000o`000005o`0000;ooooo1Ol000000ooooooo0000o`000004oooo
o`;o00002?ooool2o`0000;ooooo0_l0000:ooooo`Ko000000?oooooo`000?l000000_ooool3o`00
00?ooooo0_l0000=ooooo`;o00001?ooool4o`0000_ooooo1?l00002ooooo`Co0000?_ooool001co
oooo00?o0000ooooooooool0<?ooool2o`0000Kooooo0_l00006ooooo`;o00003Oooool2o`0000Go
oooo0ol000001?oooooo0000o`000?ooool9o`000003ooooool0003o000000Co000000?oooooo`00
0?l000000ol00002ooooo`;o00000oooool2o`0000;ooooo0_l00008ooooo`;o00000oooool2o`00
0005ooooool0003o0000o`000?ooool01?l00002ooooo`;o00001?ooool4o`0000;ooooo1Ol00007
ooooo`?o000000?oooooo`000?l000000oooool3o`0000;ooooo0_l00009ooooo`;o000000Cooooo
o`000?l0003ooooo2_l00002ooooo`Co00002Oooool2o`0000Kooooo1?l0000;ooooo`;o00001?oo
ool4o`0003kooooo000Looooo`;o0000<?ooool3o`0000Kooooo0_l00006ooooo`;o00003_ooool2
o`0000?ooooo1?l00002ooooo`So000000?oooooo`000?l000003Ol0000;ooooo`;o00000_ooool2
o`0000_ooooo0_l00003ooooo`Co000000Goooooo`000?l0003o0000ooooo`02o`000003ooooool0
003o000000_o000000?oooooo`000?l000000_ooool3o`000004ooooool0003o0000ooooo`Ko0000
00?oooooo`000?l000002?ooool3o`000003ooooool0003o000000_o00001?ooool2o`0000;ooooo
0_l00005ooooo`;o00003?ooool4o`0000Wooooo1?l0000?ooooo`;o0000;oooool001cooooo00?o
0000ooooooooool09oooool2o`0000Kooooo0_l00002ooooo`;o00001Oooool2o`0001Cooooo0_l0
0003ooooo`Go000000?oooooo`000?l000005_l0000:ooooo`;o00000oooool2o`0000Kooooo1?l0
00001?oooooo0000o`000?ooool5o`0000;ooooo0_l00002ooooo`Co000000?oooooo`000?l00000
0_l00002ooooo`;o000000?oooooo`000?l000002?l00004ooooo`?o000000?oooooo`000?l00000
1_ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000004ol000000ooooooo0000
o`00000Cooooo`Co00000_ooool3o`0000Cooooo1?l0000?ooooo`;o0000;oooool001cooooo00?o
0000ooooooooool09oooool2o`0000[ooooo0_l00005ooooo`;o00005?ooool2o`000003ooooool0
003o000001ko00002_ooool2o`0000_ooooo1?l00004ooooo`Co000000?oooooo`000?l000001?oo
ool4o`000005ooooool0003o0000o`000?ooool00_l00002ooooo`Wo00001oooool2o`0000Wooooo
0_l000000ooooooo0000o`000002oooooaWo00001Oooool2o`0000?ooooo0_l000000ooooooo0000
o`000004o`0000Kooooo0ol00002ooooo`?o000000?oooooo`000?l000000_l0000nooooo`007?oo
ool00ol0003oooooooooo`0_ooooo`;o00002_ooool2o`0001?ooooo0_l000000ooooooo0000o`00
0002o`000003ooooool0003o000000ko000000?oooooo`000?l000001?l00002ooooo`So00000ooo
ool2o`0001Cooooo0_l00003ooooo`;o00001_ooool5o`0000;ooooo0ol000000ooooooo0000o`00
000Fooooo`Co00001_oooolIo`000003ooooool0003o000000;ooooo0_l00003ooooo`;o000000?o
ooooo`000?l000001?l0000;ooooo`?o00000oooool2o`0003kooooo000Looooo`03o`000?oooooo
oooo02_ooooo0_l00002ooooo`;o00002_ooool2o`0000?ooooo0_l0000Coooooa_o000000?ooooo
o`000?l000001_l00003ooooo`;o00000_ooool2o`0000_ooooo0_l0000=ooooo`Ko00000oooool4
o`0000Sooooo0_l0000?ooooo`Co00001ooooolAo`000003ooooool0003o000000;ooooo0_l00000
0ooooooo0000o`00000>ooooo`;o00004_ooool3o`0003cooooo000Looooo`03o`000?oooooooooo
02_ooooo0_l0000Aooooo`Co00004OoooolPo`000003ooooool0003o000000[ooooo0_l00004oooo
o`;o00001Oooool2o`0000_ooooo2?l00003ooooo`;o00002_ooool2o`0000Oooooo0_l00004oooo
o`;o00001?ooool2o`0000;ooooo5?l00002ooooo`?o00002oooool2o`0000_ooooo0_l0000=oooo
o`?o0000??ooool001cooooo00?o0000ooooooooool0?_ooool2o`0000Wooooo0_l00002ooooo`;o
00001?oooolEo`000003ooooool0003o000000Ko00000oooool2o`0000gooooo0_l000001?oooooo
0000o`000?l0000;ooooo`;o00001?ooool3o`0000;ooooo0ol000000ooooooo0000o`00000>oooo
o`;o00001Oooool2o`000004ooooool0003o0000ooooo`;o00001?ooool2o`0000;ooooo5?l00000
0ooooooo0000o`000002o`000003ooooool0003o000000?ooooo0_l00003ooooo`;o00002_ooool3
o`0000gooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00003?ooool2o`00
00Cooooo0_l00003ooooo`;o00000_ooool2o`0000Cooooo1?l000000ooooooo0000o`00000:o`00
0003ooooool0003o000000[o000000?oooooo`000?l000003oooool3o`000004ooooool0003o0000
ooooo`;o00002?ooool2o`0000Gooooo0_l00002ooooo`?o000000?oooooo`000?l000000_l00004
ooooo`;o00001_ooool2o`0000Sooooo0_l00009ooooo`;o000000?oooooo`000?l000006Ol00003
ooooo`;o00002oooool2o`0000;ooooo0_l0000;ooooo`;o000000?oooooo`000?l00000?Oooool0
01cooooo00?o0000ooooooooool0;_ooool4o`0000cooooo0_l00004ooooo`;o00000oooool2o`00
0003ooooool0003o000000Gooooo8Ol00002ooooo`;o000000?oooooo`000?l000001?ooool2o`00
00?ooooo0_l000000ooooooo0000o`000003o`0000oooooo0_l00003ooooo`;o00000oooool2o`00
00Cooooo0_l0000?ooooo`;o00002Oooool3o`000003ooooool0003o000001So00002_ooool2o`00
00Gooooo0_l0000?ooooo`;o00001?ooool2o`0003[ooooo000Looooo`03o`000?oooooooooo02ko
oooo0_l00003ooooo`?o00003_ooool2o`0000?ooooo0_l000000ooooooo0000o`000008oooooago
00000oooool2o`000003ooooool0003o000000Cooooo0_l00003ooooo`;o00000oooool3o`0001Go
oooo0_l00002ooooo`Co000000?oooooo`000?l000004?ooool2o`0000?ooooo0_l00004ooooo`;o
000000?oooooo`000?l000006?l0000;ooooo`;o00006?ooool6o`0001Wooooo0_l0000Oooooo`00
7?ooool00ol0003oooooooooo`0Xooooo`;o00001?ooool2o`0000?ooooo0ol0000>ooooo`Co0000
3Oooool8o`000004ooooool0003o0000ooooo`Co000000?oooooo`000?l000002ol000000ooooooo
0000o`000006ooooo`;o00001_ooool2o`0000Cooooo0_l0000Eooooo`;o00001?ooool2o`000003
ooooool0003o000000?ooooo0_l0000@ooooo`Co00001OoooolJo`0000Sooooo0_l0000Iooooo`Ko
00006oooool2o`0001oooooo000Looooo`03o`000?oooooooooo02Sooooo0_l00004ooooo`;o0000
4Oooool2o`0000?ooooo0_l0000<ooooo`co000000?oooooo`000?l000004ol00006ooooo`;o0000
1_ooool2o`0001Wooooo0_l00002ooooo`;o00001Oooool2o`0000?ooooo0ol0000Aooooo`;o0000
1ooooolGo`0000Wooooo0_l0000>ooooo`;o00000oooool2o`0000Cooooo0_l00005ooooo`;o0000
>Oooool001cooooo00?o0000ooooooooool0@Oooool2o`00013ooooo7?l000000ooooooo0000o`00
0003o`0000gooooo0_l00006ooooo`;o000000?oooooo`000?l000004?ooool2o`0000;ooooo0_l0
0005ooooo`;o00001?ooool2o`0000Oooooo0_l000000ooooooo0000o`00000>oooooaOo00000_oo
ool2o`0000;ooooo1?l00006ooooo`;o00001oooool2o`0000?ooooo0_l00002ooooo`;o00001ooo
ool2o`0003Wooooo000Looooo`03o`000?oooooooooo04Oooooo0_l0000:oooooaoo000000?ooooo
o`000?l000000_l0000;ooooo`;o00001_ooool7o`0000Gooooo0_l0000;ooooo`;o00003_ooool4
o`0000;ooooo0_l000000ooooooo0000o`00000>oooooaOo00000_ooool2o`000003ooooool0003o
000000?o00001?ooool4o`00013ooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`17oooo
o`;o00002_oooolOo`0000?ooooo0_l0000Eooooo`;o000000?oooooo`000?l000001Oooool2o`00
00Wooooo0_l00005ooooo`;o00002Oooool4o`0000;ooooo0_l00004ooooo`Co00002Oooool2o`00
0003ooooool0003o000000Co000000?oooooo`000?l000000_l000000ooooooo0000o`000006o`00
00;ooooo0_l000000ooooooo0000o`000002o`0000Gooooo0ol00002ooooo`;o00003Oooool2o`00
04;ooooo000Looooo`03o`000?oooooooooo04cooooo1_l000000ooooooo0000o`00000Mo`0000oo
oooo0_l0000<ooooo`;o00003?ooool2o`0000;ooooo2Ol0000:ooooo`;o00002Oooool4o`0000_o
oooo1ol000000ooooooo0000o`00000;o`0000Gooooo0_l00008ooooo`;o00000_ooool2o`0000go
oooo0_l00003ooooo`;o00000oooool2o`0003Sooooo000Looooo`;o0000?_ooool4o`0000_ooooo
1_l000000ooooooo0000o`00000@o`000003ooooool0003o000000_o00001_ooool2o`0000Kooooo
0_l000001?oooooo0000o`000?ooool4o`0000Cooooo0ol00009ooooo`Ko00000_ooool5o`0000Ko
oooo0_l00004ooooo`;o00003?ooool2o`0000[ooooo5Ol00005ooooo`;o000000?oooooo`000?l0
00001_ooool2o`00013ooooo0_l00002ooooo`Co000000Coooooo`000?l0003o00000_ooool2o`00
03Cooooo000Looooo`03o`000?oooooooooo03gooooo1?l0000;ooooo`;o00001ooooolNo`000003
ooooool0003o000000?ooooo0_l00006ooooo`[o00000_ooool2o`000004ooooool0003o0000oooo
o`Co00001?ooool2o`0000;ooooo0_l00004ooooo`;o00001oooool2o`0000Gooooo1?l00003oooo
o`;o00001?ooool2o`0000_ooooo4ol00005ooooo`?o000000?oooooo`000?l000001_ooool3o`00
00_ooooo0_l00006ooooo`Co000000?oooooo`000?l000000_l000000ooooooo0000o`000002o`00
00Kooooo0_l0000Zooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00000_ooool2o`0000Oo
oooo0ol00007oooooago00000_ooool2o`000004ooooool0003o0000ooooo`;o00001Oooool3o`00
0004ooooool0003o0000ooooo`;o00000oooool2o`0000Cooooo1Ol0000=ooooo`?o00003Oooool4
o`0000?ooooo0_l00004ooooo`?o00002_ooool>o`0000Kooooo0_l00002ooooo`;o000000?ooooo
o`000?l000002?ooool3o`0000[ooooo0_l0000;ooooo`Go00000_ooool2o`0000Kooooo0_l0000Z
ooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o00004_ooool3o`0000Oooooo1?l00003oooo
o`;o000000Coooooo`000?l0003ooooo4ol000001?oooooo0000o`000?ooool4o`000003ooooool0
003o000000?o000000?oooooo`000?l000003oooool2o`0000Kooooo1Ol00007ooooo`;o00001Ooo
ool2o`0000Gooooo0ol0000<ooooo`;o00001Oooool6o`0000Oooooo1ol000001?oooooo0000o`00
0?l00005ooooo`;o000000?oooooo`000?l000001?ooool3o`000003ooooool0003o000000Kooooo
0_l0000Jooooo`;o0000=_ooool001cooooo00?o0000ooooooooool0;Oooool2o`0000cooooo1Ol0
00000ooooooo0000o`00000:ooooo`?o00000_ooool2o`0000Cooooo5?l000000ooooooo0000o`00
0004o`0000;ooooo1?l00002ooooo`;o000000?oooooo`000?l000002oooool2o`0001;ooooo0_l0
00000ooooooo0000o`000009ooooo`?o00001?ooool6o`000003ooooool0003o000000Kooooo1_l0
00001?oooooo0000o`000?l00008ooooo`Ko00001Oooool2o`0000Gooooo2?l00006ooooo`;o0000
1?ooool2o`0001Cooooo0_l0000fooooo`007?ooool00ol0003oooooooooo`0kooooo`Go00002?oo
ool2o`0000Cooooo0ol00006ooooo`?o000000?oooooo`000?l000003ol000000ooooooo0000o`00
0002ooooo`?o00000oooool6o`000003ooooool0003o000000Cooooo0_l0000:ooooo`;o00003Ooo
ool5o`00013ooooo1_l000000ooooooo0000o`000009ooooo`;o00000_ooool3o`0000?ooooo0_l0
0004ooooo`Co00003Oooool2o`0000;ooooo0_l0000>ooooo`;o00005?ooool2o`0000Cooooo0_l0
000`ooooo`007?ooool00ol0003oooooooooo`0Tooooo`;o00006_ooool2o`0000Kooooo0_l00003
ooooo`Co00001Oooool3o`0000;ooooo6Ol00005ooooo`;o00001?ooool2o`0000;ooooo0ol0000:
ooooo`;o00001?ooool2o`0000Oooooo0ol0000Sooooo`;o00002Oooool8o`0000oooooo1?l0000?
ooooo`;o00001?ooool2o`0001Gooooo0_l0000`ooooo`007?ooool00ol0003oooooooooo`0Toooo
o`;o00004oooool2o`0000Gooooo0_l0000;ooooo`;o00001oooool2o`0000?ooooo3ol000000ooo
oooo0000o`000002ooooo`;o000000?oooooo`000?l000002oooool2o`0000;ooooo0_l0000=oooo
o`;o00000_ooool2o`0000gooooo0_l0000>ooooo`;o00002?ooool2o`0000Cooooo0ol00008oooo
o`Wo00004?ooool2o`0000Cooooo0_l00002ooooo`;o00000oooool4o`0000?ooooo0ol00008oooo
o`;o0000?Oooool001cooooo00?o0000ooooooooool0>Oooool2o`0000;ooooo0_l0000Dooooo`;o
00001_oooolAo`0000_ooooo0_l00003ooooo`;o00002_ooool2o`0000Sooooo0_l0000Aooooo`;o
00002oooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o000000?oooooo`000?l0
00000_ooool2o`0000Wooooo1?l00002ooooo`;o000000?oooooo`000?l000004oooool2o`0000;o
oooo0_l00003ooooo`?o00001?ooool2o`0000Wooooo1?l000000ooooooo0000o`00000hooooo`00
7?ooool00ol0003oooooooooo`0iooooo`;o00000_ooool2o`000003ooooool0003o000000Gooooo
1?l00004ooooo`;o000000Coooooo`000?l0003o00002?ooool6o`000004ooooool0003o0000oooo
o`Go00000_ooool2o`0000Gooooo1_l000000ooooooo0000o`000009ooooo`?o00000_ooool2o`00
00Cooooo0_l0000=ooooo`;o00000_ooool2o`0000_ooooo0ol00002ooooo`Co00001oooool2o`00
00Oooooo0_l00004ooooo`;o00001_ooool3o`0000Cooooo0_l00006ooooo`;o00001_ooool2o`00
00Oooooo0_l0000?ooooo`Co000000?oooooo`000?l00000>?ooool001cooooo00?o0000oooooooo
ool0@?ooool2o`0000Gooooo1Ol00003ooooo`;o000000?oooooo`000?l000000_l00005ooooo`Go
00001Oooool2o`000004ooooool0003o0000o`0000;ooooo0ol00005ooooo`;o00000_ooool5o`00
00Wooooo1ol00004ooooo`;o00001Oooool2o`0000Kooooo0_l00002ooooo`;o00000_ooool2o`00
00Sooooo0_l00002ooooo`Co00001oooool2o`0000Oooooo0_l0000<ooooo`;o00001Oooool2o`00
00Gooooo0ol00006ooooo`;o00000oooool2o`0000Gooooo0_l0000Aooooo`;o0000>?ooool001co
oooo00?o0000ooooooooool0A?ooool3o`0000?ooooo0_l00003ooooo`?o00000_ooool2o`0000Go
oooo1_l00004ooooo`;o00001_ooool2o`0000Wooooo1_l0000;ooooo`Co00003?ooool2o`0000ko
oooo0_l0000>ooooo`;o00001oooool2o`0000Sooooo0_l0000Eooooo`;o00000_ooool4o`0000[o
oooo0_l00002ooooo`;o000000?oooooo`000?l000004?ooool3o`0003Sooooo000Looooo`03o`00
0?oooooooooo04Cooooo0ol00008ooooo`?o000000?oooooo`000?l000001_ooool6o`0000Cooooo
0_l0000Aooooo`?o00002_ooool2o`0000;ooooo0_l00011ooooo`Co00004oooool2o`0000Cooooo
0_l0000>ooooo`;o00003Oooool2o`0000Cooooo0ol0000hooooo`007?ooool00ol0003ooooooooo
o`0oooooo`;o00000_ooool2o`0000Wooooo1?l000000ooooooo0000o`000008ooooo`Co00001?oo
ool2o`0000Oooooo0_l00006ooooo`Go00002_ooool2o`0001Kooooo0_l0000;ooooo`;o00003_oo
ool2o`0000;ooooo0_l00004ooooo`;o00001_ooool4o`0000Kooooo0_l0000Pooooo`;o00003_oo
ool2o`0000Cooooo0ol0000hooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00000_ooool2
o`0000Wooooo1?l00002ooooo`;o00001oooool2o`0000oooooo0_l00006ooooo`?o00007?ooool2
o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`;o00000oooool2o`0000kooooo0_l00002
ooooo`Go000000?oooooo`000?l000001_ooool3o`0000Oooooo0_l0000Pooooo`Co000000Cooooo
o`000?l0003o00003_ooool5o`0003Kooooo000Looooo`03o`000?oooooooooo02Gooooo0_l0000I
ooooo`;o00003_ooool2o`0000;ooooo0_l00004ooooo`;o00003?ooool2o`0000cooooo0_l0000@
ooooo`;o00002oooool2o`0000;ooooo0ol00002ooooo`;o00001Oooool4o`0000Cooooo0_l00008
ooooo`Co00000_ooool6o`0000;ooooo0_l0000Aooooo`;o00000oooool4o`0000Cooooo0_l00003
ooooo`Co00003?ooool2o`000004ooooool0003o0000o`00017ooooo0_l0000fooooo`007?ooool2
o`0002Kooooo0_l0000Iooooo`;o00003?ooool5o`0000Oooooo1Ol00009ooooo`;o00001Oooool2
o`0000;ooooo1ol00009ooooo`;o00000oooool2o`0000?ooooo0_l0000:ooooo`;o00000oooool2
o`0000Kooooo0ol00004ooooo`?o00001oooool4o`0000;ooooo1?l00004ooooo`;o00003oooool4
o`0000?ooooo1?l00004ooooo`;o00000oooool4o`0000Sooooo0_l0000Booooo`;o0000?Oooool0
01cooooo00?o0000ooooooooool0??ooool2o`0000Sooooo0_l00006ooooo`;o000000?oooooo`00
0?l000002Oooool4o`0000oooooo0_l00002ooooo`?o00000_ooool2o`0000Kooooo0_l000000ooo
oooo0000o`000007ooooo`?o00003_ooool2o`000003ooooool0003o000000Cooooo0_l000000ooo
oooo0000o`000002ooooo`?o00003?ooool2o`000003ooooool0003o0000017ooooo0_l000000ooo
oooo0000o`000003o`000003ooooool0003o000000?o00005_ooool2o`0000Kooooo0_l0000:oooo
o`;o0000?Oooool001cooooo00?o0000ooooooooool0:?ooool2o`0000oooooo0_l000000ooooooo
0000o`000008ooooo`;o000000?oooooo`000?l000001oooool2o`0000[ooooo0_l00007ooooo`;o
00002oooool2o`0000[ooooo0_l0000:ooooo`;o00002?ooool3o`0000Cooooo0_l000000ooooooo
0000o`000007ooooo`So00002oooool2o`0000_ooooo0_l00007ooooo`;o000000Coooooo`000?l0
003ooooo1_l0000Eooooo`;o00002?ooool3o`0000[ooooo0_l0000mooooo`007?ooool00ol0003o
ooooooooo`0Xooooo`;o00003oooool2o`000003ooooool0003o000000Gooooo0_l00004ooooo`;o
00001oooool2o`0000;ooooo0_l0000?ooooo`;o00000_ooool4o`0001;ooooo0_l0000:ooooo`;o
00001oooool3o`000005ooooool0003o0000o`000?ooool01?l00009ooooo`Ko00001?ooool2o`00
01;ooooo0_l0000<ooooo`;o000000?oooooo`000?l000002oooool2o`0000Oooooo0_l000000ooo
oooo0000o`000002ooooo`;o00001?ooool2o`0004[ooooo000Looooo`03o`000?oooooooooo03_o
oooo0ol00005ooooo`;o00000oooool2o`0000Cooooo0_l00006ooooo`;o00004oooool4o`0001;o
oooo1?l00008ooooo`;o00002?ooool6o`000003ooooool0003o000000[ooooo0_l000000ooooooo
0000o`000002o`0000Cooooo0_l0000Booooo`;o00002_ooool4o`0000Kooooo0_l00002ooooo`;o
000000Coooooo`000?l0003o00001oooool4o`000003ooooool0003o000000Co00001?ooool2o`00
00Wooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0Tooooo`;o00004oooool5o`0000Oo
oooo0_l000000ooooooo0000o`000004ooooo`;o00000oooool2o`0001Oooooo0_l00002ooooo`;o
00000_ooool2o`0000Cooooo0_l00007ooooo`;o00001?ooool2o`0000;ooooo0_l00007ooooo`Co
00001oooool2o`0000Oooooo0_l000000ooooooo0000o`00000Jooooo`;o00000oooool2o`0000Go
oooo0ol00007ooooo`;o00000_ooool2o`000003ooooool0003o000000[ooooo0_l000000ooooooo
0000o`000004o`0000Cooooo0_l00009ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0
9?ooool2o`0001?ooooo0ol00009ooooo`;o000000?oooooo`000?l000002Oooool2o`000004oooo
ool0003o0000o`0000kooooo0_l00003ooooo`;o00000_ooool6o`0000?ooooo0ol0000=ooooo`;o
00001_ooool2o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`;o00002Oooool2o`000003
ooooool0003o000001Wooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000000Oo
oooo0_l00002ooooo`;o00004?ooool4o`000003ooooool0003o000000?ooooo0_l00003ooooo`Co
0000@Oooool001cooooo00?o0000ooooooooool0E_ooool3o`0000Gooooo1?l00003ooooo`Co0000
0_ooool2o`0000Gooooo0ol00004ooooo`;o00005_ooool2o`0000Kooooo0_l0000>ooooo`;o0000
00Coooooo`000?l0003ooooo0ol0000Hooooo`;o000000?oooooo`000?l000001?ooool2o`000003
ooooool0003o000000Oooooo0_l00009ooooo`;o00002?ooool4o`0000;ooooo0_l00003ooooo`;o
00000oooool4o`00047ooooo000Looooo`03o`000?oooooooooo04Kooooo0_l00003ooooo`;o0000
0_ooool2o`0000gooooo1?l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l0000<ooooo`;o
00004?ooool2o`0000?ooooo0_l0000Gooooo`?o00001?ooool2o`0000_ooooo0_l0000>ooooo`;o
00006oooool2o`000003ooooool0003o000000Gooooo0_l0000>ooooo`;o0000@oooool001cooooo
00?o0000ooooooooool0;oooool2o`0001?ooooo1?l00002ooooo`Oo00001_ooool2o`0000Cooooo
1?l00007ooooo`;o000000Coooooo`000?l0003ooooo0_l00009ooooo`;o00004?ooool2o`0000?o
oooo0_l00002ooooo`;o00001_ooool2o`0000Cooooo0_l00005ooooo`?o00001?ooool2o`0000_o
oooo0_l00003ooooo`?o00001_ooool2o`0000Wooooo0_l0000Eooooo`;o00002oooool4o`0000?o
oooo0_l000000ooooooo0000o`000013ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o0000
3Oooool8o`0000Cooooo0_l000000ooooooo0000o`000002o`0000Kooooo0_l00004ooooo`?o0000
1oooool2o`0000;ooooo0_l000000ooooooo0000o`000007ooooo`;o00006oooool4o`0000Cooooo
0_l00004ooooo`;o00000oooool5o`0000Cooooo0_l00002ooooo`?o00001_ooool2o`0000;ooooo
1ol00003ooooo`Co00001oooool2o`0001cooooo0_l000001?oooooo0000o`000?ooool4o`0000?o
oooo0_l00006ooooo`;o00001?ooool2o`0003Sooooo000Looooo`03o`000?oooooooooo02Wooooo
0_l0000>ooooo`;o00000oooool7o`00027ooooo0ol00002ooooo`;o000000?oooooo`000?l00000
1oooool3o`0000?ooooo0_l0000?ooooo`;o00001_ooool2o`0000oooooo1?l00009ooooo`?o0000
0_ooool?o`0000Gooooo0_l00005ooooo`;o00003_ooool2o`0000kooooo0_l000000ooooooo0000
o`000005ooooo`;o00002Oooool2o`0000Cooooo0_l0000hooooo`007?ooool00ol0003ooooooooo
o`0Yooooo`;o00003_ooool2o`0001[ooooo0_l0000?ooooo`;o00000oooool5o`0000Sooooo0_l0
0003ooooo`;o00001?ooool2o`0000Kooooo0_l000000ooooooo0000o`00000>ooooo`;o00001Ooo
ool2o`000003ooooool0003o000000cooooo2?l000000ooooooo0000o`000006o`0000gooooo0_l0
000>ooooo`;o00003?ooool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000003?oo
ool2o`0003_ooooo000Looooo`03o`000?oooooooooo047ooooo0_l00003ooooo`;o00002Oooool2
o`0000;ooooo0_l0000?ooooo`;o00000oooool4o`0000Oooooo0_l00005ooooo`;o00001?ooool2
o`0000Kooooo0_l00006ooooo`;o00002Oooool2o`0000?ooooo1?l000000ooooooo0000o`00000<
oooooa3o00002Oooool2o`0000cooooo0_l0000Cooooo`;o00000_ooool4o`000003ooooool0003o
000000oooooo0_l0000kooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?oo
ool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0??ooool2o`0000?ooooo
0_l00003ooooo`;o00002Oooool2o`0001?ooooo0_l000000ooooooo0000o`000002ooooo`Co0000
1Oooool2o`0001_ooooo0_l0000<ooooo`Ko00001Oooool2o`0000Wooooo4ol00005ooooo`;o0000
0oooool2o`000003ooooool0003o000000Cooooo0_l0000?ooooo`;o00000_ooool4o`0000;ooooo
0_l000000ooooooo0000o`00001<ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o
8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0??ooool2o`00
00Oooooo0ol0000=ooooo`;o00000oooool2o`0000gooooo0_l00002ooooo`Co00001_ooool4o`00
01Cooooo0_l000000ooooooo0000o`00000=ooooo`;o00002?ooool3o`0000Wooooo4ol00003oooo
o`;o00001?ooool3o`000003ooooool0003o000001Gooooo0_l00002ooooo`Co00006?ooool2o`00
03Wooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo04Gooooo0ol00004ooooo`;o00001oooool2o`00
00?ooooo0_l0000@ooooo`?o00002?ooool5o`0000cooooo0_l00004ooooo`?o000000?oooooo`00
0?l000000oooool2o`0001;ooooo0_l00004ooooo`?o000000?oooooo`000?l000004ol00003oooo
o`;o00001?ooool2o`0000Kooooo0_l00005ooooo`;o00003_ooool2o`0000Sooooo0_l0000@oooo
o`;o00003?ooool2o`0002_ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wo
oooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000>_ooool2o`00013ooooo0_l00002oooo
o`Go00005oooool2o`0000cooooo0_l00003ooooo`;o00001Oooool4o`0000Cooooo0ol000000ooo
oooo0000o`000003ooooo`;o000000?oooooo`000?l000005?ooool4o`000004ooooool0003o0000
oooooaOo000000Coooooo`000?l0003ooooo0_l00006ooooo`;o00001Oooool2o`0001Sooooo0_l0
000>ooooo`;o00003_ooool2o`0002_ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo03[ooooo0_l0
0006ooooo`Co00002_ooool5o`0001Oooooo0_l000001?oooooo0000o`000?l00006ooooo`;o0000
1Oooool2o`0000Gooooo0_l00006ooooo`?o00001Oooool2o`0000;ooooo1_l00003ooooo`;o0000
2oooool7o`000003ooooool0003o000000Ko000000?oooooo`000?l000003?l000000ooooooo0000
o`000003o`0000Oooooo0_l0000>ooooo`;o00006oooool2o`000004ooooool0003o0000ooooo`;o
0000>?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7
ooooo`08ooooo`03o`000?oooooooooo04;ooooo1?l0000=ooooo`;o00005oooool7o`0000Gooooo
0_l00004ooooo`;o00001?ooool3o`000003ooooool0003o000000;ooooo0_l00002ooooo`?o0000
0oooool2o`0000?ooooo1Ol00003ooooo`;o00000oooool2o`0000Kooooo2ol000000ooooooo0000
o`000002o`000003ooooool0003o000000Co000000Coooooo`000?l0003o00001oooool2o`000003
ooooool0003o000000;o00000_ooool3o`0000;ooooo0_l0000:ooooo`;o00002oooool2o`0000Co
oooo0_l00008ooooo`;o00001?ooool2o`0003Sooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMg
M`_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`19ooooo`;o000000?oooooo`00
0?l000001_ooool2o`0001Sooooo1Ol000000ooooooo0000o`000002ooooo`Go000000?oooooo`00
0?l000001?ooool7o`000003ooooool0003o000000;ooooo1?l00002ooooo`;o00000oooool4o`00
00Cooooo0_l00003ooooo`;o000000?oooooo`000?l000000ooooolDo`000003ooooool0003o0000
00Go00002Oooool4o`0000;ooooo0_l00003ooooo`;o00005oooool2o`0000Cooooo0_l00007oooo
o`;o0000?oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@
4106ooooo`03o`000?oooooooooo03Kooooo0_l00003ooooo`;o00003?ooool2o`000003ooooool0
003o000000Kooooo0_l0000Hooooo`Go000000?oooooo`000?l000001?ooool3o`000003ooooool0
003o000000;o00001?ooool:o`000004ooooool0003o0000o`0000;ooooo0ol0000;ooooo`?o0000
1?ooool2o`000003ooooool0003o000001co00000_ooool2o`0000Cooooo0_l0000booooo`;o0000
?oooool001cooooo00?o0000ooooooooool0=_ooool2o`0000?ooooo0_l0000Mooooo`;o00004Ooo
ool3o`0000cooooo5Ol00005ooooo`?o00000_ooool2o`0000Oooooo0ol00007ooooo`;o000000?o
ooooo`000?l000005ol00004ooooo`;o00001?ooool2o`0002oooooo0_l00012ooooo`007?ooool0
0ol0003oooooooooo`0booooo`;o00003?ooool2o`0000cooooo0_l000000ooooooo0000o`000007
ooooo`?o00004?ooool2o`0000?ooooo0_l00002ooooo`;o00001?ooool2o`000003ooooool0003o
000001?o00001oooool2o`0000oooooo0_l000000ooooooo0000o`00000:o`000004ooooool0003o
0000ooooo`ko00003?ooool2o`0002Oooooo0_l000000ooooooo0000o`000012ooooo`007?ooool0
0ol0003oooooooooo`0booooo`;o00003?ooool2o`0000?ooooo0_l00007ooooo`;o000000?ooooo
o`000?l000000oooool2o`0000;ooooo0ol0000Cooooo`So00001_oooolFo`0000?ooooo0_l00008
ooooo`;o00002Oooool2o`000003ooooool0003o000000?o000000?oooooo`000?l000001_l00002
ooooo`ko00002oooool3o`0002Oooooo0_l00002ooooo`;o00001?ooool2o`0003_ooooo000Loooo
o`03o`000?oooooooooo03_ooooo0_l00008ooooo`;o00001oooool2o`0000Kooooo0_l00007oooo
o`;o00001?ooool2o`0000Wooooo0_l00002ooooo`;o00002?oooolCo`000003ooooool0003o0000
00?ooooo0_l00008ooooo`Co00002_ooool6o`000003ooooool0003o000001Go00002oooool4o`00
01?ooooo0_l00005ooooo`;o00003_ooool2o`0000Cooooo1?l0000iooooo`007?ooool00ol0003o
ooooooooo`0kooooo`;o00000oooool2o`0000Oooooo0_l000000ooooooo0000o`000004o`0000Oo
oooo0_l00004ooooo`;o00001?ooool3o`0000Kooooo0_l0000<oooooa[o000000?oooooo`000?l0
00000oooool2o`0000Gooooo0_l00006ooooo`;o00000_oooolNo`0000gooooo0_l00006ooooo`;o
00002oooool2o`0000Gooooo1?l0000<ooooo`;o00001Oooool3o`0003Wooooo000Looooo`03o`00
0?oooooooooo02Wooooo0_l0000Booooo`;o000000?oooooo`000?l000001oooool5o`000004oooo
ool0003o0000o`0000Gooooo1?l00005ooooo`;o00000oooool3o`000003ooooool0003o000000?o
oooo0_l0000<oooooako00000_ooool2o`0000gooooo0_l00002oooooako00000_ooool4o`0000Co
oooo0_l00009ooooo`;o00001Oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool3o`0000?o
oooo0_l00012ooooo`007?ooool00ol0003oooooooooo`0Yooooo`;o00003_ooool2o`0000;ooooo
0_l00008ooooo`;o00000_ooool2o`0000;ooooo0_l00006ooooo`;o00001oooool2o`0000Oooooo
0_l0000Aoooooako00001oooool2o`0000?ooooo0_l00007oooooako00000_ooool4o`0000Cooooo
0_l0000@ooooo`;o00001_ooool2o`0000cooooo1Ol000000ooooooo0000o`000012ooooo`007?oo
ool00ol0003oooooooooo`0iooooo`;o00001_ooool4o`000004ooooool0003o0000o`0001Wooooo
0_l0000GoooooaSo000000Coooooo`000?l0003ooooo0_l00008ooooo`;o00000oooool2o`0000Go
oooo0_l00002ooooo`;o00000_oooolJo`0000;ooooo0_l0000>ooooo`;o00003_ooool2o`0000?o
oooo1?l00007ooooo`?o00001?ooool2o`0003oooooo000Looooo`03o`000?oooooooooo02oooooo
0_l0000@ooooo`Co000000?oooooo`000?l000002oooool2o`0000gooooo0_l0000Eoooooa[o0000
1?ooool2o`0000_ooooo0_l00007ooooo`;o00000_oooolNo`0000;ooooo0_l00003ooooo`?o0000
1oooool3o`0000;ooooo0_l00007ooooo`;o00001?ooool6o`0000Gooooo1?l00005ooooo`;o0000
0_ooool2o`0003_ooooo000Looooo`03o`000?oooooooooo02oooooo0_l0000>ooooo`;o00002ooo
ool2o`0000Gooooo0ol0000;ooooo`;o00000_ooool2o`00013ooooo7?l00004ooooo`?o00002_oo
ool2o`0000cooooo6Ol000000ooooooo0000o`000008ooooo`?o00001oooool2o`0000?ooooo0_l0
0007ooooo`;o00001?ooool2o`0000Wooooo0_l00006ooooo`;o00000oooool2o`0003_ooooo000L
ooooo`03o`000?oooooooooo03[ooooo0_l00002ooooo`?o00002oooool2o`0000Gooooo0ol00006
ooooo`;o00000oooool2o`0000;ooooo0_l0000@ooooo`Oo000000?oooooo`000?l000001?l00000
0ooooooo0000o`00000=o`000003ooooool0003o000000;o00001oooool4o`00013ooooo6Ol00005
ooooo`;o00007oooool2o`0000Gooooo0_l0000:ooooo`Co0000?_ooool001cooooo0_l0000koooo
o`;o00000_ooool2o`0000Kooooo0_l0000Dooooo`;o00000oooool2o`0001;ooooo0_l000000ooo
oooo0000o`00000Ko`000003ooooool0003o000000?o00001_ooool4o`0000kooooo6ol00005oooo
o`;o000000?oooooo`000?l000000_ooool2o`0001[ooooo0_l000000ooooooo0000o`000002o`00
00cooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`16ooooo`;o00006?ooool3o`0000Go
oooo0_l0000;ooooo`;o000000?oooooo`000?l000006ol00002ooooo`Co00001?ooool2o`0001;o
oooo6ol00008ooooo`?o000000?oooooo`000?l000005_ooool2o`0000;ooooo0_l000000ooooooo
0000o`00001>ooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00001?ooool2o`0000Wooooo
0_l0000<ooooo`Co00001?ooool4o`0000Cooooo0_l00006ooooo`;o00001OoooolNo`0000;ooooo
1?l00003ooooo`?o00004?ooool2o`0000;ooooo5?l000000ooooooo0000o`000002o`000003oooo
ool0003o000000Cooooo1?l00007ooooo`;o00004?ooool2o`0000[ooooo0_l00019ooooo`007?oo
ool00ol0003oooooooooo`0gooooo`Co00001?ooool2o`0000Wooooo0_l0000<ooooo`Co00001_oo
ool2o`0000cooooo0_l00005oooooaco00001oooool2o`0000;ooooo1Ol00008ooooo`;o00001?oo
ool2o`0000Cooooo5_l00002ooooo`;o00000oooool5o`0000Oooooo0_l00007ooooo`;o00003ooo
ool2o`0000;ooooo0_l0000:ooooo`Co0000>oooool001cooooo00?o0000ooooooooool0=oooool2
o`0002Wooooo0_l0000Coooooaco00001oooool2o`0000?ooooo1_l000000ooooooo0000o`000003
ooooo`;o00002ooooolBo`0000Oooooo0_l000000ooooooo0000o`000002o`0000cooooo0_l00000
0ooooooo0000o`000002o`0000oooooo0_l000000ooooooo0000o`00000;ooooo`Co0000>oooool0
01cooooo00?o0000ooooooooool0?Oooool4o`0000Kooooo0_l0000Iooooo`;o00004ooooolLo`00
00Sooooo0_l000001?oooooo0000o`000?l00002ooooo`;o000000?oooooo`000?l000000_ooool2
o`0000cooooo3ol0000:ooooo`;o00000oooool2o`0000[ooooo1?l000000ooooooo0000o`00000D
ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0?Oooool4o`0000Kooooo0_l00006oooo
o`;o00001oooool2o`0000Cooooo0_l0000=ooooo`;o00002OoooolNo`0000Cooooo2Ol00007oooo
o`Co00001_ooool2o`0000Cooooo2?l00002ooooo`;o00001_ooool2o`0001Cooooo0_l0000=oooo
o`;o0000E_ooool001cooooo00?o0000ooooooooool0?Oooool2o`00013ooooo0_l00007ooooo`;o
00001?ooool2o`0000;ooooo0ol00008ooooo`;o00003?oooolKo`0000Cooooo0_l000001?oooooo
0000o`000?ooool3o`0000Wooooo0_l00006ooooo`;o00001?ooool5o`000003ooooool0003o0000
00;ooooo0_l00006ooooo`;o00003?ooool2o`0000kooooo1Ol00002ooooo`;o0000E_ooool001co
oooo00?o0000ooooooooool0?Oooool2o`0001Oooooo0_l0000:ooooo`?o00004oooool<o`000003
ooooool0003o000000Oo000000?oooooo`000?l000000_l000000ooooooo0000o`00000:ooooo`;o
00005_ooool2o`000003ooooool0003o000000;o00004oooool2o`0000Kooooo1?l00002ooooo`Co
00001_ooool5o`000003ooooool0003o000000Wooooo0_l0001<ooooo`007?ooool00ol0003ooooo
ooooo`1;ooooo`;o00002Oooool5o`0000Oooooo0_l0000Cooooo`Go000000?oooooo`000?l00000
3ol0000Cooooo`;o00001oooool2o`0000cooooo0_l000000ooooooo0000o`000002ooooo`;o0000
0_ooool2o`000003ooooool0003o000000[ooooo0_l00008ooooo`;o00000_ooool4o`0000cooooo
0_l00009ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0Boooool2o`0000[ooooo1?l0
00000ooooooo0000o`000004ooooo`?o00004_ooool:o`000003ooooool0003o000000So00003Ooo
ool2o`0000Cooooo1?l000001?oooooo0000o`000?l00002ooooo`?o00001_ooool2o`0000Oooooo
2_l000000ooooooo0000o`000002o`0000_ooooo0_l0000Rooooo`;o0000C_ooool001cooooo00?o
0000ooooooooool0A_ooool2o`00017ooooo0_l000000ooooooo0000o`000005ooooo`;o00001_oo
ool2o`0000Wooooo0ol000000ooooooo0000o`00000Ao`0000Kooooo0_l00004ooooo`;o00000ooo
ool4o`0000;ooooo0ol00002ooooo`;o00001oooool3o`0000Kooooo1?l00002ooooo`;o00001Ooo
ool2o`0000_ooooo0_l00003ooooo`;o00004_ooool3o`0000Sooooo0_l0001>ooooo`007?ooool0
0ol0003oooooooooo`16ooooo`Co00003oooool2o`00013ooooo0_l00005ooooo`;o00000_ooool2
o`0000Gooooo0_l000000ooooooo0000o`00000;o`0000Kooooo0_l00006ooooo`;o000000?ooooo
o`000?l000002Oooool2o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l000003?ooool2
o`0000;ooooo0_l00006ooooo`;o00000_ooool2o`0000;ooooo1?l00008ooooo`;o00002?ooool4
o`0005Oooooo000Looooo`03o`000?oooooooooo04Kooooo1?l0000Hooooo`?o00001?ooool2o`00
00Oooooo0_l00005ooooo`;o00002Oooool2o`0000Oooooo0_l00005ooooo`;o00001Oooool2o`00
00cooooo0_l00002ooooo`?o00001_ooool2o`0000[ooooo1?l0000:ooooo`;o00000_ooool6o`00
00[ooooo1?l00006ooooo`Co0000Eoooool001cooooo00?o0000ooooooooool0@?ooool2o`0000Go
oooo0_l0000Iooooo`?o00001?ooool2o`0000kooooo0ol00008ooooo`;o00001?ooool2o`000003
ooooool0003o000000Gooooo0_l00002ooooo`;o00000oooool2o`0000[ooooo0_l00003ooooo`;o
000000?oooooo`000?l000001oooool2o`0000Kooooo1?l0000@ooooo`;o00000oooool2o`0000So
oooo0ol00006ooooo`;o00001_ooool2o`00057ooooo000Looooo`03o`000?oooooooooo043ooooo
0_l00005ooooo`;o00002_ooool5o`0000Cooooo0_l00003ooooo`Co00000_ooool2o`0000Cooooo
0_l00003ooooo`;o00001Oooool3o`0000Gooooo0_l000000ooooooo0000o`000004ooooo`;o0000
3?ooool4o`000003ooooool0003o000001;ooooo0_l00007ooooo`;o00001Oooool2o`000003oooo
ool0003o000000;ooooo0_l0000Aooooo`;o00002?ooool2o`000003ooooool0003o000000cooooo
0ol0001@ooooo`007?ooool2o`00047ooooo1?l0000?ooooo`Go00000oooool5o`000004ooooool0
003o0000ooooo`;o000000?oooooo`000?l000001?ooool3o`0000;ooooo0_l00005ooooo`;o0000
1_ooool2o`0000;ooooo0_l00006ooooo`;o00001?ooool4o`0000;ooooo1?l00002ooooo`?o0000
3oooool2o`0000Oooooo0_l00005ooooo`Co00000oooool2o`0001_ooooo1Ol00004ooooo`;o0000
1oooool2o`00053ooooo000Looooo`03o`000?oooooooooo04;ooooo0_l0000;ooooo`?o00000ooo
ool2o`0000Cooooo1Ol00004ooooo`;o00002?ooool2o`0001Gooooo0ol00002ooooo`;o000000Co
ooooo`000?l0003ooooo0_l000000ooooooo0000o`000002o`0000;ooooo1?l00002ooooo`Co0000
3_ooool2o`0000Kooooo0_l000000ooooooo0000o`000005ooooo`;o00001?ooool2o`0000oooooo
0_l00009ooooo`Co000000?oooooo`000?l000000_ooool2o`0005Wooooo000Looooo`03o`000?oo
oooooooo04Wooooo0_l00004ooooo`?o00002Oooool2o`000003ooooool0003o000000[ooooo0_l0
0006ooooo`;o00004_ooool2o`000003ooooool0003o000000;o00000oooool2o`000003ooooool0
003o000000Kooooo0_l00002ooooo`Co00002Oooool2o`0000Wooooo1?l000001?oooooo0000o`00
0?l00003ooooo`;o00001Oooool2o`0000;ooooo0_l0000;ooooo`;o00003_ooool2o`0000;ooooo
0_l0001Iooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00004oooool2o`0000[ooooo0_l0
0006ooooo`;o00005Oooool4o`0000Kooooo0_l0000;ooooo`Co00001Oooool2o`000003ooooool0
003o000000Wooooo0_l00002ooooo`Co00000oooool3o`0000Cooooo0_l00002ooooo`Go00003_oo
ool2o`0006Oooooo000Looooo`03o`000?oooooooooo05Sooooo0_l000000ooooooo0000o`00000L
ooooo`;o00001?ooool2o`0000Oooooo0_l00004ooooo`;o00000oooool2o`0000_ooooo1?l00005
ooooo`?o000000?oooooo`000?l000002oooool3o`000003ooooool0003o000000;o000000?ooooo
o`000?l000000_l00002ooooo`;o00001?ooool3o`000003ooooool0003o000000_ooooo0_l00007
ooooo`;o00001Oooool2o`0005Oooooo000Looooo`03o`000?oooooooooo05Sooooo0_l000000ooo
oooo0000o`00000:ooooo`;o00004?ooool2o`0000Cooooo0_l00007ooooo`;o000000Coooooo`00
0?l0003ooooo0_l0000:ooooo`Co00000oooool2o`0000Cooooo2?l0000;ooooo`;o00000_ooool4
o`0000?ooooo0_l00002ooooo`;o00002?ooool2o`0001Cooooo0_l00005ooooo`;o0000Eoooool0
01cooooo00?o0000ooooooooool0@_ooool2o`0001Cooooo0_l00008ooooo`;o00000oooool2o`00
013ooooo0_l00009ooooo`;o00001Oooool2o`0000gooooo1?l00003ooooo`;o00001?ooool6o`00
01gooooo0_l0000Jooooo`;o00001?ooool2o`0005_ooooo000Looooo`03o`000?oooooooooo04;o
oooo0_l0000Nooooo`;o00000_ooool2o`00017ooooo0_l00006ooooo`;o000000?oooooo`000?l0
00001_ooool2o`0000Wooooo0_l00008ooooo`;o00001_ooool3o`0000;ooooo1?l0000Hooooo`;o
00001?ooool4o`0000Gooooo0_l000000ooooooo0000o`000008ooooo`;o00001?ooool2o`0005_o
oooo000Looooo`03o`000?oooooooooo06Kooooo0_l0000=ooooo`;o00001Oooool2o`0000;ooooo
1?l00008ooooo`;o00002Oooool2o`0000[ooooo1?l00007ooooo`Co00000_ooool2o`0000;ooooo
0_l00002ooooo`;o00003_ooool2o`0000;ooooo1?l00002ooooo`;o000000Coooooo`000?l0003o
oooo0ol00002ooooo`;o00000_ooool4o`0000;ooooo0_l0001Looooo`007?ooool00ol0003ooooo
ooooo`1Fooooo`Co00000oooool2o`0000_ooooo1?l00007ooooo`;o000000?oooooo`000?l00000
0_ooool2o`0000;ooooo1?l0000Mooooo`Ko00001oooool2o`0000Cooooo0_l00002ooooo`;o0000
0_ooool2o`0000kooooo0_l00002ooooo`;o00001?ooool3o`0000Cooooo0_l00002ooooo`;o0000
0_ooool4o`000004ooooool0003o0000o`0005cooooo000Looooo`03o`000?oooooooooo05Kooooo
1?l00003ooooo`;o00002oooool4o`0000[ooooo0_l00007ooooo`?o00005?ooool2o`0000;ooooo
0_l00003ooooo`Co00000_ooool2o`0002[ooooo0_l00002ooooo`;o00000oooool2o`0000Oooooo
0_l00003ooooo`;o0000GOooool001cooooo00?o0000ooooooooool0E_ooool2o`0000Cooooo0_l0
000=ooooo`;o00005?ooool2o`0001Gooooo1_l00005ooooo`;o00000_ooool2o`0000Gooooo0_l0
0003ooooo`;o00006?ooool3o`0000;ooooo0ol00007ooooo`;o00001oooool4o`00063ooooo000L
ooooo`03o`000?oooooooooo05Kooooo0_l00004ooooo`;o00004?ooool2o`00017ooooo0_l0000G
ooooo`;o00002?ooool2o`0000Sooooo0_l00003ooooo`;o00002?ooool7o`0000Oooooo1Ol00002
ooooo`;o00000oooool2o`0000Oooooo0_l00003ooooo`Co0000H?ooool001cooooo00?o0000oooo
ooooool0Hoooool2o`0000Wooooo0_l00002ooooo`;o00000oooool2o`0000Sooooo0_l0000Moooo
o`;o00000_ooool4o`0000Wooooo1?l00008ooooo`Oo00001?ooool2o`000003ooooool0003o0000
00Gooooo0_l00003ooooo`;o00001oooool2o`0000;ooooo0_l0001Sooooo`007?ooool00ol0003o
ooooooooo`1Sooooo`;o00003Oooool2o`0000?ooooo0_l0000Looooo`;o00002Oooool2o`0000Co
oooo0_l00009ooooo`Co00001?ooool4o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`Co
00003?ooool2o`0000Gooooo0_l00004ooooo`?o00004Oooool2o`0004oooooo000Looooo`03o`00
0?oooooooooo05cooooo0_l00003ooooo`;o00005_ooool2o`0001Cooooo0_l00004ooooo`;o0000
00?oooooo`000?l000000_ooool2o`0000Sooooo0_l0000;ooooo`;o00001?ooool4o`0000[ooooo
1?l0000:ooooo`Co00001Oooool2o`0000Gooooo0_l0000Aooooo`;o0000Coooool001cooooo0_l0
001<ooooo`;o00003oooool2o`0000?ooooo0_l0000Fooooo`;o00005?ooool2o`0000Oooooo0_l0
0002ooooo`Co00001Oooool2o`0000oooooo0_l00008ooooo`;o000000?oooooo`000?l000001Ooo
ool2o`0000Oooooo1_l0001`ooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o00005?ooool2
o`0000;ooooo0_l00003ooooo`;o00002Oooool2o`0000;ooooo0_l0000;ooooo`;o00003_ooool2
o`0000Kooooo0_l00005ooooo`;o00003oooool2o`0000Sooooo0_l000000ooooooo0000o`000005
ooooo`;o00001oooool3o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o00004oooool2
o`00057ooooo000Looooo`03o`000?oooooooooo05gooooo1?l00004ooooo`;o00000oooool2o`00
00Wooooo1Ol00005ooooo`;o00001Oooool2o`0000Wooooo0_l00003ooooo`;o00001Oooool3o`00
00Kooooo0_l0000<ooooo`Co00002oooool2o`0000[ooooo0_l000000ooooooo0000o`000002o`00
0003ooooool0003o000000;ooooo0_l00004ooooo`;o00004oooool2o`00057ooooo000Looooo`03
o`000?oooooooooo05gooooo1?l00009ooooo`;o00002oooool3o`000003ooooool0003o000000;o
oooo1?l0000>ooooo`;o00000oooool2o`0000Gooooo0ol000000ooooooo0000o`000003ooooo`;o
000000?oooooo`000?l000002Oooool2o`0000?ooooo0_l0000Dooooo`[o0000L?ooool001cooooo
00?o0000ooooooooool0F?ooool2o`0001kooooo0_l000000ooooooo0000o`000002o`0000;ooooo
0_l0000Cooooo`;o00002?ooool3o`0000Kooooo0_l0000>ooooo`;o00001oooool2o`000003oooo
ool0003o000000Oooooo0_l000000ooooooo0000o`000002ooooo`Co0000L?ooool001cooooo00?o
0000ooooooooool0F?ooool2o`0000cooooo0_l00002ooooo`;o00001Oooool2o`0000Gooooo0_l0
0003ooooo`;o00006oooool2o`0000;ooooo1?l0000Booooo`;o00001?ooool4o`000003ooooool0
003o000000?o000000?oooooo`000?l000001oooool2o`0000Oooooo0_l0001`ooooo`007?ooool0
0ol0003oooooooooo`1Hooooo`;o00003?ooool2o`0000;ooooo0_l00005ooooo`;o00001_ooool2
o`0000cooooo0_l000000ooooooo0000o`000006ooooo`;o00001_ooool2o`0000;ooooo0_l00007
ooooo`;o00002oooool2o`0000Cooooo1?l000000ooooooo0000o`000002o`0000;ooooo0_l00003
ooooo`;o000000?oooooo`000?l00000N_ooool001cooooo00?o0000ooooooooool0K_ooool4o`00
00Cooooo0_l000000ooooooo0000o`00000<ooooo`;o000000?oooooo`000?l000001_ooool4o`00
00;ooooo1?l0000:ooooo`?o00000oooool2o`0000?ooooo0_l000000ooooooo0000o`00000;oooo
o`;o00000_ooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0000gooooo0_l0001X
ooooo`007?ooool00ol0003oooooooooo`1Zooooo`So00000_ooool4o`000004ooooool0003o0000
o`0001Sooooo0_l00002ooooo`;o00003?ooool2o`0000Cooooo0_l00003ooooo`;o000000?ooooo
o`000?l000002Oooool2o`0000Cooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l0
000=ooooo`;o0000J?ooool001cooooo00?o0000ooooooooool0J_ooool4o`0000Kooooo0_l00003
ooooo`?o00000_ooool2o`0000oooooo0_l0000:ooooo`;o00008_ooool2o`0000Cooooo0_l00003
ooooo`;o000000?oooooo`000?l000002_ooool2o`0000;ooooo0_l0001Zooooo`007?ooool00ol0
003oooooooooo`1mooooo`?o00003oooool4o`0000Oooooo0ol00008ooooo`;o00006oooool3o`00
00Sooooo0_l0000:ooooo`;o00000_ooool2o`0000cooooo0_l0001Looooo`007?ooool00ol0003o
ooooooooo`1]ooooo`;o000000?oooooo`000?l000002oooool3o`00017ooooo0_l00007ooooo`;o
00002Oooool2o`0001Kooooo0_l00003ooooo`?o00003Oooool2o`0001Oooooo0_l0001Looooo`00
7?ooool00ol0003oooooooooo`1]ooooo`;o000000?oooooo`000?l000006Oooool4o`0000[ooooo
0_l0000?ooooo`;o000000?oooooo`000?l000003_ooool2o`0000Cooooo1?l00008ooooo`;o0000
00?oooooo`000?l000002_ooool2o`0006Wooooo000Looooo`03o`000?oooooooooo07?ooooo0_l0
000;ooooo`;o00001?ooool2o`0000?ooooo1?l00004ooooo`;o00000_ooool4o`0000gooooo1?l0
00000ooooooo0000o`00000?ooooo`;o00001Oooool3o`0000?ooooo0ol000000ooooooo0000o`00
000:ooooo`;o000000?oooooo`000?l00000JOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^
1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo07?o
oooo0_l00008ooooo`;o000000?oooooo`000?l000001?ooool4o`000003ooooool0003o000000?o
oooo0_l000000ooooooo0000o`000002ooooo`;o00001_ooool4o`0000;ooooo0_l000000ooooooo
0000o`00000:ooooo`;o00000_ooool2o`0000Cooooo0_l00006ooooo`;o00000oooool3o`0000go
oooo0_l000000ooooooo0000o`00001Yooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5oooo
o`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0Loooool4
o`0000Kooooo1?l00002ooooo`;o00000oooool2o`000003ooooool0003o000000?ooooo0_l0000=
ooooo`So00003Oooool2o`0000;ooooo0_l0000<ooooo`;o00004?ooool2o`0000Cooooo0_l0001Y
ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`1eooooo`Co00001Oooool3o`0000;ooooo0_l00005
ooooo`;o00001oooool2o`000004ooooool0003o0000o`0000Oooooo0_l000000ooooooo0000o`00
000Qooooo`;o00004?ooool2o`0006oooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000IOooool2o`0000?ooooo0_l0
0007ooooo`;o00000_ooool2o`0000Gooooo0ol00006ooooo`;o000000?oooooo`000?l000001ooo
ool2o`000004ooooool0003o0000o`00017ooooo0_l0000Yooooo`;o0000L_ooool00003ooooool0
003ooooo00;ooooo00?o0000ooooooooool02Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo
00?o0000ooooooooool0IOooool2o`0000?ooooo0_l00004ooooo`Go00001?ooool2o`0000Gooooo
0_l000001Ooooooo0000o`000?l0003ooooo00;o00002Oooool2o`0000cooooo0_l00008ooooo`Co
00006Oooool2o`0000Cooooo0_l00003ooooo`;o000000?oooooo`000?l00000L_ooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00Ko
oooo00?o0000ooooooooool0L?ooool3o`0000Kooooo1Ol00002ooooo`Ko00003?ooool2o`0000;o
oooo0_l00005ooooo`;o000000?oooooo`000?l000001?ooool4o`0000;ooooo0_l00006ooooo`?o
00002?ooool2o`0000Kooooo0_l00002ooooo`Co00000oooool2o`0007Gooooo00001_ooooooMgMg
oiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooo
oooo07[ooooo1?l00003ooooo`;o00004oooool2o`0000Gooooo0_l00007ooooo`Co00002_ooool3
o`0000Kooooo2?l00006ooooo`?o00000_ooool2o`0007Oooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo09Wooooo
0_l0000Rooooo`;o00000_ooool4o`0000Oooooo0_l00002ooooo`;o0000Moooool001cooooo00?o
0000ooooooooool0Qoooool4o`0000Cooooo0_l00008ooooo`;o00003?ooool2o`00013ooooo1?l0
000Cooooo`;o0000Moooool001cooooo00?o0000ooooooooool0Ooooool2o`0000Kooooo1?l00004
ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Sooooo0_l00002ooooo`;o00000_ooool2
o`0000;ooooo0_l00008ooooo`Co00004oooool2o`0007Oooooo000Looooo`03o`000?oooooooooo
07kooooo0ol00008ooooo`;o00001oooool2o`0000Gooooo0_l00008ooooo`;o00001_ooool2o`00
00;ooooo0_l00004ooooo`;o00003_ooool2o`000003ooooool0003o000000;ooooo0_l0001koooo
o`007?ooool00ol0003oooooooooo`1nooooo`;o000000?oooooo`000?l000000_l0000Cooooo`Go
00003?ooool2o`0000[ooooo0_l000000ooooooo0000o`00000;ooooo`;o000000?oooooo`000?l0
00000_ooool2o`0007_ooooo000Looooo`03o`000?oooooooooo087ooooo1?l0000Cooooo`Go0000
3?ooool2o`0000_ooooo1?l0000;ooooo`;o0000P_ooool001cooooo00?o0000ooooooooool0V_oo
ool3o`0000Sooooo0_l0000?ooooo`Co00004oooool2o`0007[ooooo000Looooo`03o`000?oooooo
oooo08Wooooo0_l0000?ooooo`;o00002Oooool2o`0000Sooooo0_l0000Booooo`;o00000_ooool2
o`0000Cooooo0_l0001jooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o00008_ooool2o`00
00Sooooo0_l00008ooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`?o00004Oooool2o`00
00;ooooo0_l00020ooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o0000;?ooool2o`0000So
oooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo0_l0002Gooooo`007?ooool00ol0003ooooo
ooooo`2?ooooo`;o00003_ooool2o`0000cooooo0_l0002Jooooo`007?ooool00ol0003ooooooooo
o`28ooooo`Co00000oooool2o`0000kooooo0_l00004ooooo`;o00001_ooool3o`0009Wooooo000L
ooooo`;o0000ROooool4o`0001Wooooo0_l00007ooooo`;o00001Oooool2o`0009;ooooo000Loooo
o`03o`000?oooooooooo09Gooooo0_l0000Nooooo`;o0000T_ooool001cooooo00?o0000oooooooo
ool0QOooool2o`0000kooooo1?l0002`ooooo`007?ooool00ol0003oooooooooo`1cooooo`;o0000
4?ooool2o`0000Cooooo0_l0000:ooooo`;o00004oooool2o`0009_ooooo000Looooo`03o`000?oo
oooooooo07?ooooo0_l0000Fooooo`;o00001?ooool2o`0000kooooo0_l00009ooooo`;o00006?oo
ool2o`00087ooooo000Looooo`03o`000?oooooooooo097ooooo0_l0000>ooooo`?o00008_ooool2
o`00087ooooo000Looooo`03o`000?oooooooooo0:;ooooo0_l0002Uooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001;ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood[o
oooo000Dooooo`03o`000?oooooooooo00Gooooo0ol0003ooooood[ooooo000Dooooo`03o`000?oo
oooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0
003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001;ooooo
00?oEEEEofIVI_l00000oooooomDooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00XOooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo01Kooooo1?l000002?l@
413ooooooooooonHV9So410@o`000?lb<S;oc<c<1?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP2<ooooo`00X_ooool01Ol0003ooooooooooooooooo0000
00Wooooo1_l0000<ooooo`03o`000?oooooooooo00;ooooo00Go410@okZj^_ooooooMgMgoc8b<P07
ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg08cooooo002Rooooo`05o`00
0?ooooooooooooooool000006oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`2:ooooo`00X_ooool01Ol0003o
oooooooooooooooo000000Wooooo1_l0000<ooooo`03o`000?oooooooooo00Gooooo00?oZJVYoa0@
4?ooool01_ooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool0R_ooool0
0:;ooooo00Go0000ohN7QoooooooZJVYo`00000Kooooo`03o`000?oooooooooo00Cooooo00?o410@
o`000?nj^[X01?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooooooooooooooo
o`00002<ooooo`00XOooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo01Wooooo00?o
0000ooooooooool01Oooool00onj^[[o8B4Qooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go
410@oooooooooooooooooa0@402<ooooo`00`_ooool00ol0003oooooooooo`02ooooo`05oa0@4?nH
V9SooooookZj^_l000001?ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0S?ooool00<3ooooo00?oEEEEofIVI_l000001?ooool01OnYZJWo410@o`000?l@413oZJVY00Co
oooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0S?ooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1356) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.35075 .47763 Mdot
.3424 .47783 Mdot
.56177 .64615 Mdot
.51872 .36053 Mdot
.77149 .62719 Mdot
.59514 .63316 Mdot
.36198 .63313 Mdot
.42087 .6493 Mdot
.55368 .63734 Mdot
.34623 .57763 Mdot
.42999 .62841 Mdot
.5938 .4356 Mdot
.39136 .63241 Mdot
.54907 .38039 Mdot
.86493 .45794 Mdot
.4676 .39794 Mdot
.35132 .47513 Mdot
.64964 .54421 Mdot
.50273 .44129 Mdot
.60426 .65488 Mdot
.37026 .4493 Mdot
.54236 .38061 Mdot
.31634 .43187 Mdot
.54957 .38072 Mdot
.50295 .37993 Mdot
.30415 .44117 Mdot
.30639 .41235 Mdot
.49859 .40738 Mdot
.51855 .4311 Mdot
.43039 .64124 Mdot
.66438 .36138 Mdot
.84504 .51265 Mdot
.46346 .34926 Mdot
.77069 .38614 Mdot
.39589 .6539 Mdot
.37525 .34976 Mdot
.58418 .63718 Mdot
.41375 .62418 Mdot
.41268 .61935 Mdot
.40711 .66061 Mdot
.41915 .63508 Mdot
.32565 .44171 Mdot
.28831 .53886 Mdot
.5697 .71536 Mdot
.48319 .35709 Mdot
.64453 .75824 Mdot
.3266 .3923 Mdot
.5686 .38617 Mdot
.29728 .47713 Mdot
.67255 .58772 Mdot
.5071 .71571 Mdot
.36972 .63302 Mdot
.61253 .63632 Mdot
.13825 .38586 Mdot
.38167 .62637 Mdot
.59095 .38195 Mdot
.57192 .63848 Mdot
.53672 .39453 Mdot
.5518 .38455 Mdot
.41719 .24321 Mdot
.53888 .33789 Mdot
.67731 .4873 Mdot
.26605 .46808 Mdot
.4905 .58239 Mdot
.56657 .62926 Mdot
.42056 .61813 Mdot
.33418 .47569 Mdot
.38384 .63608 Mdot
.54826 .30565 Mdot
.59757 .60195 Mdot
.5695 .38294 Mdot
.4279 .62594 Mdot
.33697 .42118 Mdot
.5212 .41971 Mdot
.64208 .68935 Mdot
.60495 .80412 Mdot
.6564 .46977 Mdot
.37613 .32569 Mdot
.4102 .24201 Mdot
.69583 .61857 Mdot
.48187 .3985 Mdot
.70396 .4298 Mdot
.61149 .79157 Mdot
.27902 .4512 Mdot
.46494 .4172 Mdot
.66056 .55439 Mdot
.51707 .41693 Mdot
.69755 .74879 Mdot
.57092 .36397 Mdot
.61521 .5232 Mdot
.5484 .6432 Mdot
.30696 .46699 Mdot
.51408 .36073 Mdot
.53515 .42467 Mdot
.46336 .22652 Mdot
.55956 .43174 Mdot
.52398 .38308 Mdot
.29028 .47766 Mdot
.37104 .63164 Mdot
.58402 .36574 Mdot
.50782 .66722 Mdot
.56436 .67565 Mdot
.50605 .35069 Mdot
.5409 .62304 Mdot
.30973 .42142 Mdot
.5358 .42358 Mdot
.40269 .6171 Mdot
.52673 .34398 Mdot
.26416 .65685 Mdot
.35507 .46455 Mdot
.50424 .42251 Mdot
.65133 .52185 Mdot
.32464 .28707 Mdot
.29862 .46918 Mdot
.50122 .66428 Mdot
.51248 .44144 Mdot
.52103 .39363 Mdot
.32846 .48117 Mdot
.54156 .6564 Mdot
.67503 .76175 Mdot
.28412 .47687 Mdot
.43237 .64702 Mdot
.36 .43138 Mdot
.58096 .44348 Mdot
.56995 .62071 Mdot
.54634 .71035 Mdot
.25213 .61591 Mdot
.68455 .35871 Mdot
.51867 .41446 Mdot
.30966 .54941 Mdot
.58495 .67766 Mdot
.31883 .46772 Mdot
.38801 .6384 Mdot
.45585 .41611 Mdot
.3475 .4503 Mdot
.43379 .62527 Mdot
.65044 .50629 Mdot
.44172 .72442 Mdot
.33068 .42528 Mdot
.50826 .5051 Mdot
.38513 .60729 Mdot
.37827 .652 Mdot
.68531 .25069 Mdot
.32905 .47496 Mdot
.68493 .50492 Mdot
.39671 .64505 Mdot
.67513 .32314 Mdot
.4926 .34818 Mdot
.67047 .41858 Mdot
.19444 .47677 Mdot
.75182 .35735 Mdot
.46242 .74683 Mdot
.6736 .52386 Mdot
.4254 .6043 Mdot
.51416 .37549 Mdot
.29597 .44731 Mdot
.31039 .43557 Mdot
.53593 .33809 Mdot
.49602 .37637 Mdot
.5714 .38145 Mdot
.56482 .41218 Mdot
.59033 .30564 Mdot
.55301 .44483 Mdot
.30553 .38165 Mdot
.30365 .46305 Mdot
.51867 .36581 Mdot
.60183 .61523 Mdot
.53555 .32507 Mdot
.42445 .63145 Mdot
.53634 .38789 Mdot
.5159 .3617 Mdot
.51069 .33862 Mdot
.37055 .63876 Mdot
.84228 .55286 Mdot
.285 .32272 Mdot
.82545 .54925 Mdot
.59415 .50584 Mdot
.58404 .60584 Mdot
.51004 .40947 Mdot
.67056 .49257 Mdot
.42949 .31465 Mdot
.53347 .35417 Mdot
.19445 .69847 Mdot
.53162 .37981 Mdot
.79057 .60825 Mdot
.57277 .32659 Mdot
.81358 .48922 Mdot
.69345 .41223 Mdot
.50638 .38671 Mdot
.35353 .54621 Mdot
.36758 .60484 Mdot
.59963 .68731 Mdot
.41407 .63529 Mdot
.60505 .62025 Mdot
.56517 .64366 Mdot
.48244 .60523 Mdot
.58697 .44896 Mdot
.51166 .32244 Mdot
.57734 .38923 Mdot
.56103 .59625 Mdot
.27012 .45476 Mdot
.64472 .51258 Mdot
.32691 .49115 Mdot
.81078 .67204 Mdot
.60613 .74301 Mdot
.38822 .66636 Mdot
.65516 .48529 Mdot
.55821 .66371 Mdot
.54631 .63359 Mdot
.657 .52262 Mdot
.54993 .40886 Mdot
.33158 .46959 Mdot
.72008 .28596 Mdot
.29721 .69474 Mdot
.62298 .17415 Mdot
.28948 .47426 Mdot
.32951 .57327 Mdot
.42565 .64275 Mdot
.58366 .65119 Mdot
.52132 .39069 Mdot
.54074 .41049 Mdot
.36777 .47023 Mdot
.57131 .38835 Mdot
.23703 .44665 Mdot
.51304 .39087 Mdot
.45038 .6884 Mdot
.6391 .48767 Mdot
.48375 .60644 Mdot
.70858 .36453 Mdot
.28516 .44568 Mdot
.53981 .22576 Mdot
.54851 .61901 Mdot
.42936 .30851 Mdot
.42063 .61461 Mdot
.65627 .49273 Mdot
.56069 .61637 Mdot
.64704 .51916 Mdot
.53736 .44865 Mdot
.60588 .63909 Mdot
.67534 .53012 Mdot
.62348 .4371 Mdot
.49492 .33895 Mdot
.21095 .62275 Mdot
.40781 .65882 Mdot
.33315 .49286 Mdot
.55026 .34306 Mdot
.55805 .60601 Mdot
.44993 .40745 Mdot
.48711 .78126 Mdot
.47413 .67869 Mdot
.57978 .68047 Mdot
.51685 .60158 Mdot
.66905 .4847 Mdot
.52398 .74729 Mdot
.31626 .5609 Mdot
.34047 .48237 Mdot
.56038 .4338 Mdot
.81871 .46317 Mdot
.39568 .6447 Mdot
.54257 .3449 Mdot
.75342 .53031 Mdot
.38335 .64488 Mdot
.53551 .39662 Mdot
.43827 .62463 Mdot
.31158 .43516 Mdot
.36884 .24258 Mdot
.32155 .48519 Mdot
.57297 .40087 Mdot
.39298 .61775 Mdot
.53473 .62072 Mdot
.30796 .44444 Mdot
.55781 .40236 Mdot
.50073 .40726 Mdot
.54937 .55837 Mdot
.5246 .37007 Mdot
.8224 .57685 Mdot
.5093 .38903 Mdot
.57366 .65448 Mdot
.48006 .38064 Mdot
.24075 .32338 Mdot
.47649 .60217 Mdot
.3328 .47468 Mdot
.56899 .68227 Mdot
.55977 .63592 Mdot
.63798 .71801 Mdot
.45334 .64174 Mdot
.50358 .43642 Mdot
.56717 .60526 Mdot
.61095 .28269 Mdot
.40569 .60576 Mdot
.56707 .34347 Mdot
.46383 .49908 Mdot
.66004 .58488 Mdot
.61123 .64225 Mdot
.45516 .43622 Mdot
.31862 .42226 Mdot
.5077 .3631 Mdot
.54373 .637 Mdot
.54978 .46762 Mdot
.49978 .42619 Mdot
.21499 .46616 Mdot
.54904 .5635 Mdot
.37504 .61444 Mdot
.57636 .3354 Mdot
.55485 .35687 Mdot
.60416 .63245 Mdot
.287 .44674 Mdot
.40201 .60468 Mdot
.3189 .44118 Mdot
.80355 .47031 Mdot
.22067 .62943 Mdot
.62798 .36814 Mdot
.64026 .51423 Mdot
.68233 .56456 Mdot
.80887 .4721 Mdot
.4818 .19529 Mdot
.58654 .23936 Mdot
.77942 .37269 Mdot
.53933 .63556 Mdot
.73113 .5494 Mdot
.56502 .63721 Mdot
.49035 .38812 Mdot
.57199 .62181 Mdot
.81826 .45235 Mdot
.51517 .38896 Mdot
.58134 .62398 Mdot
.50996 .22368 Mdot
.50891 .36592 Mdot
.33842 .48179 Mdot
.80533 .65207 Mdot
.33699 .22658 Mdot
.471 .67436 Mdot
.58399 .66607 Mdot
.62534 .25755 Mdot
.5234 .38114 Mdot
.48045 .38261 Mdot
.29471 .45617 Mdot
.45246 .38022 Mdot
.6932 .49704 Mdot
.66245 .48089 Mdot
.36004 .58877 Mdot
.67183 .46336 Mdot
.58049 .33811 Mdot
.30557 .44703 Mdot
.58782 .30914 Mdot
.65383 .66247 Mdot
.68059 .58198 Mdot
.35098 .63688 Mdot
.80499 .65052 Mdot
.26154 .42608 Mdot
.38829 .68958 Mdot
.62682 .60144 Mdot
.30994 .47889 Mdot
.85046 .53285 Mdot
.41192 .63177 Mdot
.22175 .65342 Mdot
.37431 .51646 Mdot
.54856 .40685 Mdot
.39569 .60876 Mdot
.47987 .44981 Mdot
.35771 .21435 Mdot
.28483 .72658 Mdot
.41953 .43129 Mdot
.56786 .35574 Mdot
.64653 .64945 Mdot
.53036 .38941 Mdot
.56541 .77434 Mdot
.50504 .39302 Mdot
.31876 .44505 Mdot
.34105 .58984 Mdot
.43273 .58984 Mdot
.24054 .37437 Mdot
.53449 .75754 Mdot
.67679 .52433 Mdot
.51467 .39393 Mdot
.55043 .40483 Mdot
.69747 .50872 Mdot
.31733 .42875 Mdot
.57375 .39317 Mdot
.53911 .2199 Mdot
.54218 .42211 Mdot
.42041 .62929 Mdot
.32889 .51895 Mdot
.27873 .4025 Mdot
.5507 .4271 Mdot
.29503 .42433 Mdot
.37095 .65757 Mdot
.39364 .61978 Mdot
.58062 .33434 Mdot
.41993 .65893 Mdot
.5357 .3729 Mdot
.31516 .75341 Mdot
.33994 .42991 Mdot
.21852 .51513 Mdot
.34003 .45298 Mdot
.36716 .32018 Mdot
.37538 .64043 Mdot
.46637 .70269 Mdot
.51459 .46162 Mdot
.40645 .631 Mdot
.3781 .44249 Mdot
.47051 .38438 Mdot
.47352 .35993 Mdot
.69135 .27681 Mdot
.56999 .66162 Mdot
.53642 .56895 Mdot
.43031 .64223 Mdot
.56281 .38486 Mdot
.5429 .43777 Mdot
.37776 .66122 Mdot
.30825 .72892 Mdot
.3922 .21255 Mdot
.51161 .38935 Mdot
.31693 .45415 Mdot
.32162 .46477 Mdot
.52755 .33087 Mdot
.50171 .35635 Mdot
.57525 .61395 Mdot
.53332 .63942 Mdot
.60411 .61021 Mdot
.53167 .5753 Mdot
.46395 .69892 Mdot
.71555 .70094 Mdot
.40655 .66066 Mdot
.30644 .59602 Mdot
.61777 .52004 Mdot
.58012 .39125 Mdot
.58061 .67093 Mdot
.55291 .35737 Mdot
.53394 .36374 Mdot
.44367 .65578 Mdot
.77185 .57656 Mdot
.32281 .40343 Mdot
.28953 .43627 Mdot
.38617 .60448 Mdot
.59517 .35125 Mdot
.38742 .67776 Mdot
.65719 .49741 Mdot
.7189 .31714 Mdot
.42488 .61887 Mdot
.3331 .48297 Mdot
.40703 .65557 Mdot
.53918 .41535 Mdot
.56516 .4438 Mdot
.31442 .478 Mdot
.69863 .49636 Mdot
.45498 .38078 Mdot
.53196 .39741 Mdot
.18447 .48762 Mdot
.70718 .32671 Mdot
.4211 .69827 Mdot
.50849 .38624 Mdot
.53154 .43309 Mdot
.70355 .52267 Mdot
.54214 .42091 Mdot
.56526 .36129 Mdot
.33283 .28778 Mdot
.26898 .62604 Mdot
.65361 .48141 Mdot
.32223 .75095 Mdot
.29171 .47662 Mdot
.83034 .48784 Mdot
.59271 .65243 Mdot
.38405 .57427 Mdot
.34688 .23649 Mdot
.61305 .6311 Mdot
.46092 .7512 Mdot
.83559 .50636 Mdot
.48692 .63419 Mdot
.55306 .68923 Mdot
.30603 .40933 Mdot
.57007 .40295 Mdot
.52381 .39561 Mdot
.67686 .4913 Mdot
.33198 .46355 Mdot
.52773 .55368 Mdot
.4897 .83265 Mdot
.53921 .38109 Mdot
.22473 .48761 Mdot
.39182 .7793 Mdot
.65861 .59084 Mdot
.66829 .50519 Mdot
.67596 .47944 Mdot
.51588 .39603 Mdot
.29786 .30582 Mdot
.30332 .44224 Mdot
.55835 .40085 Mdot
.5582 .44146 Mdot
.57817 .66414 Mdot
.35522 .45231 Mdot
.54366 .65946 Mdot
.49266 .71915 Mdot
.81725 .56478 Mdot
.17502 .609 Mdot
.37706 .62907 Mdot
.53402 .79846 Mdot
.43027 .61248 Mdot
.71021 .43023 Mdot
.60096 .67283 Mdot
.50711 .35877 Mdot
.28903 .4428 Mdot
.56081 .37712 Mdot
.50124 .3585 Mdot
.55099 .40696 Mdot
.55319 .42834 Mdot
.14903 .55227 Mdot
.67079 .52693 Mdot
.49568 .44471 Mdot
.56867 .65253 Mdot
.62692 .7746 Mdot
.58518 .79842 Mdot
.55102 .4006 Mdot
.50465 .40122 Mdot
.34163 .43583 Mdot
.53902 .33981 Mdot
.42278 .60766 Mdot
.30153 .49203 Mdot
.52348 .42368 Mdot
.77064 .68959 Mdot
.51292 .43075 Mdot
.82324 .51215 Mdot
.40939 .6538 Mdot
.27062 .67317 Mdot
.5419 .45751 Mdot
.47697 .66211 Mdot
.53701 .56845 Mdot
.56634 .61447 Mdot
.44335 .62766 Mdot
.58365 .63451 Mdot
.45621 .82836 Mdot
.58216 .43245 Mdot
.51109 .37577 Mdot
.5803 .39865 Mdot
.5847 .60574 Mdot
.72203 .72764 Mdot
.55556 .74759 Mdot
.56216 .45415 Mdot
.59095 .61216 Mdot
.27732 .43886 Mdot
.68083 .28864 Mdot
.33429 .44449 Mdot
.6506 .53459 Mdot
.42479 .63896 Mdot
.69521 .49376 Mdot
.77359 .49262 Mdot
.35041 .47228 Mdot
.35649 .47976 Mdot
.59187 .64984 Mdot
.38449 .51808 Mdot
.3638 .17056 Mdot
.37219 .51892 Mdot
.69688 .3907 Mdot
.30023 .45331 Mdot
.52584 .43022 Mdot
.73628 .45986 Mdot
.36919 .53359 Mdot
.58132 .63254 Mdot
.54066 .35893 Mdot
.37006 .23896 Mdot
.57492 .61385 Mdot
.58282 .39417 Mdot
.56655 .65584 Mdot
.41575 .63996 Mdot
.57247 .67086 Mdot
.34269 .4988 Mdot
.50975 .41848 Mdot
.4158 .13819 Mdot
.72691 .53341 Mdot
.51943 .3802 Mdot
.37636 .60731 Mdot
.38812 .74102 Mdot
.52671 .3491 Mdot
.66007 .53068 Mdot
.5885 .62034 Mdot
.40441 .48697 Mdot
.50891 .39081 Mdot
.59363 .61262 Mdot
.35594 .47248 Mdot
.43036 .60467 Mdot
.45438 .22939 Mdot
.4696 .66511 Mdot
.29316 .4572 Mdot
.55681 .50754 Mdot
.44164 .64202 Mdot
.53337 .43275 Mdot
.55764 .43446 Mdot
.31952 .45647 Mdot
.63796 .42469 Mdot
.49259 .35752 Mdot
.48208 .39381 Mdot
.58064 .65899 Mdot
.58674 .63154 Mdot
.54851 .24738 Mdot
.5377 .64568 Mdot
.56192 .44548 Mdot
.32115 .45446 Mdot
.51677 .35916 Mdot
.34684 .43762 Mdot
.53738 .34004 Mdot
.61104 .41658 Mdot
.31561 .42888 Mdot
.45195 .66141 Mdot
.53678 .36016 Mdot
.47564 .33493 Mdot
.53152 .34391 Mdot
.56751 .40508 Mdot
.56801 .61785 Mdot
.66504 .49883 Mdot
.57357 .42481 Mdot
.71242 .49483 Mdot
.64692 .51362 Mdot
.42843 .59261 Mdot
.57558 .66417 Mdot
.68845 .5124 Mdot
.40574 .79124 Mdot
.60853 .6306 Mdot
.6866 .49442 Mdot
.58687 .79781 Mdot
.39198 .65334 Mdot
.32428 .42175 Mdot
.5059 .36769 Mdot
.78854 .46311 Mdot
.30415 .39202 Mdot
.5467 .67642 Mdot
.51183 .38662 Mdot
.54231 .34665 Mdot
.27864 .46835 Mdot
.49236 .84975 Mdot
.59755 .60214 Mdot
.50734 .43309 Mdot
.34373 .47339 Mdot
.48667 .86612 Mdot
.5711 .64859 Mdot
.68225 .49139 Mdot
.391 .65669 Mdot
.35189 .40832 Mdot
.24991 .61563 Mdot
.36443 .62581 Mdot
.63383 .64353 Mdot
.4969 .71264 Mdot
.5179 .44387 Mdot
.58358 .67285 Mdot
.64309 .20265 Mdot
.55175 .29246 Mdot
.49933 .59076 Mdot
.63258 .26169 Mdot
.30478 .47509 Mdot
.42779 .61086 Mdot
.67129 .52488 Mdot
.28695 .46815 Mdot
.35362 .47185 Mdot
.38879 .6642 Mdot
.30375 .31708 Mdot
.45729 .49727 Mdot
.41758 .62272 Mdot
.74728 .37732 Mdot
.72628 .67057 Mdot
.58345 .67096 Mdot
.69365 .4982 Mdot
.77114 .50843 Mdot
.32327 .4403 Mdot
.8245 .62892 Mdot
.69533 .27501 Mdot
.52419 .3829 Mdot
.6839 .51358 Mdot
.72639 .71244 Mdot
.5445 .83578 Mdot
.37932 .64144 Mdot
.4042 .58289 Mdot
.68462 .48755 Mdot
.5509 .34422 Mdot
.67719 .2987 Mdot
.48462 .38704 Mdot
.4223 .6435 Mdot
.47937 .237 Mdot
.35012 .47475 Mdot
.38425 .65964 Mdot
.71552 .31031 Mdot
.53732 .3736 Mdot
.53615 .35852 Mdot
.72865 .38451 Mdot
.28284 .4597 Mdot
.5664 .61411 Mdot
.53703 .44616 Mdot
.53333 .39366 Mdot
.58263 .41546 Mdot
.5763 .3391 Mdot
.3387 .27079 Mdot
.4941 .39158 Mdot
.6036 .75334 Mdot
.56632 .35163 Mdot
.5448 .36713 Mdot
.2995 .42243 Mdot
.17427 .62327 Mdot
.51642 .72682 Mdot
.5347 .3898 Mdot
.52138 .43487 Mdot
.38792 .66003 Mdot
.41088 .50577 Mdot
.39776 .50749 Mdot
.41003 .47891 Mdot
.60631 .24691 Mdot
.50105 .33331 Mdot
.33702 .46997 Mdot
.67681 .53118 Mdot
.50959 .43732 Mdot
.3393 .47188 Mdot
.49981 .34452 Mdot
.57673 .61238 Mdot
.60844 .62833 Mdot
.57331 .30534 Mdot
.68824 .51694 Mdot
.24643 .48497 Mdot
.30282 .59454 Mdot
.60581 .6308 Mdot
.50821 .37627 Mdot
.46191 .6298 Mdot
.5444 .635 Mdot
.49303 .63995 Mdot
.64454 .4507 Mdot
.29457 .44517 Mdot
.30379 .46563 Mdot
.66796 .42053 Mdot
.46627 .73717 Mdot
.20063 .42534 Mdot
.41716 .64063 Mdot
.51144 .4496 Mdot
.3352 .55563 Mdot
.30045 .46614 Mdot
.72818 .44368 Mdot
.68529 .51552 Mdot
.38563 .64664 Mdot
.6306 .68469 Mdot
.34511 .44321 Mdot
.36193 .45154 Mdot
.55375 .33756 Mdot
.53766 .40212 Mdot
.57895 .23759 Mdot
.71896 .50719 Mdot
.36189 .63003 Mdot
.69015 .49413 Mdot
.59996 .67329 Mdot
.49232 .40453 Mdot
.31266 .43086 Mdot
.70759 .6908 Mdot
.51544 .43959 Mdot
.55399 .62825 Mdot
.30587 .47244 Mdot
.66963 .48401 Mdot
.66622 .53309 Mdot
.56245 .41271 Mdot
.50528 .25212 Mdot
.40843 .62483 Mdot
.31432 .48249 Mdot
.39613 .68022 Mdot
.48434 .37569 Mdot
.52966 .40549 Mdot
.54106 .3125 Mdot
.36198 .62899 Mdot
.31856 .66471 Mdot
.64277 .51639 Mdot
.32827 .46801 Mdot
.49725 .39509 Mdot
.69376 .50386 Mdot
.31738 .59739 Mdot
.58547 .68071 Mdot
.56778 .66944 Mdot
.67493 .53377 Mdot
.67441 .51046 Mdot
.65045 .52493 Mdot
.82582 .62768 Mdot
.27878 .47689 Mdot
.26469 .4229 Mdot
.47535 .39805 Mdot
.69253 .40405 Mdot
.48202 .44091 Mdot
.39077 .60566 Mdot
.56606 .65959 Mdot
.5156 .35022 Mdot
.55062 .42462 Mdot
.58023 .32985 Mdot
.21719 .49552 Mdot
.3289 .39842 Mdot
.35714 .45783 Mdot
.55895 .44948 Mdot
.58598 .66294 Mdot
.82143 .66602 Mdot
.73281 .28206 Mdot
.54507 .45686 Mdot
.45592 .49323 Mdot
.30591 .43106 Mdot
.40315 .66207 Mdot
.75413 .42903 Mdot
.39523 .65556 Mdot
.32477 .47013 Mdot
.49272 .3948 Mdot
.30267 .61339 Mdot
.70219 .52603 Mdot
.56577 .39036 Mdot
.41801 .6476 Mdot
.56822 .38065 Mdot
.36272 .62967 Mdot
.79873 .48588 Mdot
.61487 .21106 Mdot
.53059 .3806 Mdot
.47329 .4257 Mdot
.59912 .22897 Mdot
.55451 .39629 Mdot
.68853 .54086 Mdot
.30565 .4309 Mdot
.48824 .23047 Mdot
.46755 .37589 Mdot
.51652 .2766 Mdot
.48265 .38218 Mdot
.46663 .21919 Mdot
.53218 .40736 Mdot
.65342 .59597 Mdot
.50514 .42083 Mdot
.57038 .36992 Mdot
.3822 .62221 Mdot
.38304 .65872 Mdot
.32611 .41696 Mdot
.54892 .6119 Mdot
.82567 .52871 Mdot
.53033 .40042 Mdot
.48097 .68222 Mdot
.292 .65116 Mdot
.67221 .50914 Mdot
.32732 .46504 Mdot
.54208 .855 Mdot
.43307 .64111 Mdot
.66618 .24776 Mdot
.56048 .25027 Mdot
.25035 .57359 Mdot
.74901 .50646 Mdot
.39278 .75751 Mdot
.66107 .48708 Mdot
.51009 .33949 Mdot
.74112 .62631 Mdot
.64851 .60151 Mdot
.63567 .44724 Mdot
.44582 .63432 Mdot
.45708 .29105 Mdot
.76571 .59337 Mdot
.66703 .53777 Mdot
.67974 .48293 Mdot
.36767 .63169 Mdot
.53439 .67613 Mdot
.58642 .44693 Mdot
.67927 .51735 Mdot
.59248 .60603 Mdot
.60802 .64171 Mdot
.60743 .60974 Mdot
.30465 .43897 Mdot
.70624 .27133 Mdot
.38784 .67112 Mdot
.37886 .61235 Mdot
.52172 .61827 Mdot
.41968 .3959 Mdot
.30573 .49804 Mdot
.58664 .64616 Mdot
.5512 .6627 Mdot
.30884 .42782 Mdot
.59209 .37 Mdot
.59646 .40256 Mdot
.53691 .38488 Mdot
.66884 .49469 Mdot
.53798 .40721 Mdot
.58927 .61324 Mdot
.3791 .63591 Mdot
.5534 .66212 Mdot
.37894 .60464 Mdot
.69179 .71995 Mdot
.55866 .40728 Mdot
.50649 .41779 Mdot
.1804 .5325 Mdot
.36329 .4415 Mdot
.64549 .75013 Mdot
.44231 .68224 Mdot
.56515 .63958 Mdot
.56327 .35897 Mdot
.3057 .49359 Mdot
.71664 .50898 Mdot
.18711 .61979 Mdot
.49979 .3553 Mdot
.32722 .43518 Mdot
.49392 .40411 Mdot
.58523 .29529 Mdot
.21601 .35382 Mdot
.32516 .44701 Mdot
.20222 .46351 Mdot
.51884 .43291 Mdot
.44364 .79486 Mdot
.56926 .34801 Mdot
.63761 .3442 Mdot
.49247 .35771 Mdot
.29101 .47652 Mdot
.5393 .38717 Mdot
.31158 .49343 Mdot
.60249 .64171 Mdot
.39782 .66078 Mdot
.2957 .45932 Mdot
.55736 .43022 Mdot
.41689 .0911 Mdot
.41108 .64444 Mdot
.51821 .39248 Mdot
.37337 .64193 Mdot
.33494 .46064 Mdot
.29566 .47447 Mdot
.54068 .82789 Mdot
.49342 .72161 Mdot
.41392 .63937 Mdot
.49285 .40462 Mdot
.48592 .79284 Mdot
.49713 .37073 Mdot
.6226 .2844 Mdot
.59035 .38317 Mdot
.47796 .38474 Mdot
.59155 .80263 Mdot
.37483 .61402 Mdot
.19913 .41986 Mdot
.57461 .8198 Mdot
.62434 .77696 Mdot
.37147 .45585 Mdot
.67512 .53748 Mdot
.84846 .54038 Mdot
.46232 .69995 Mdot
.59041 .61055 Mdot
.52466 .34716 Mdot
.34816 .50403 Mdot
.40648 .62159 Mdot
.65856 .50129 Mdot
.52975 .38156 Mdot
.56065 .66964 Mdot
.44468 .20055 Mdot
.41518 .60169 Mdot
.32876 .44487 Mdot
.27612 .45053 Mdot
.3309 .78702 Mdot
.50414 .38896 Mdot
.5133 .42112 Mdot
.4249 .63992 Mdot
.35735 .74113 Mdot
.64847 .49744 Mdot
.5091 .22114 Mdot
.41162 .63916 Mdot
.49174 .54346 Mdot
.33598 .47787 Mdot
.54562 .34826 Mdot
.78053 .66095 Mdot
.62289 .70438 Mdot
.18918 .5198 Mdot
.67158 .49288 Mdot
.62656 .28681 Mdot
.29289 .47821 Mdot
.39132 .64105 Mdot
.43106 .73562 Mdot
.50073 .33087 Mdot
.55352 .36065 Mdot
.63465 .30277 Mdot
.43348 .59171 Mdot
.41232 .44884 Mdot
.49344 .36182 Mdot
.52775 .57651 Mdot
.50991 .34791 Mdot
.46482 .36835 Mdot
.58835 .40959 Mdot
.52165 .4109 Mdot
.3183 .43178 Mdot
.45043 .34169 Mdot
.56816 .60849 Mdot
.25687 .44623 Mdot
.48946 .54989 Mdot
.5166 .38431 Mdot
.48558 .40473 Mdot
.39911 .41901 Mdot
.45148 .76241 Mdot
.29845 .45992 Mdot
.35633 .48338 Mdot
.42509 .65518 Mdot
.59643 .38534 Mdot
.54475 .61761 Mdot
.45464 .40532 Mdot
.56208 .62215 Mdot
.31398 .43172 Mdot
.5673 .64289 Mdot
.38449 .65481 Mdot
.59063 .6674 Mdot
.46493 .6991 Mdot
.40149 .64835 Mdot
.29269 .44944 Mdot
.5255 .42057 Mdot
.37877 .60607 Mdot
.6888 .34902 Mdot
.67091 .4944 Mdot
.62967 .81924 Mdot
.52274 .4242 Mdot
.2628 .62571 Mdot
.56316 .46942 Mdot
.55161 .66186 Mdot
.21099 .36313 Mdot
.29324 .43427 Mdot
.66567 .47697 Mdot
.28154 .45023 Mdot
.69908 .30347 Mdot
.67633 .50287 Mdot
.62974 .80047 Mdot
.58277 .55333 Mdot
.70098 .32074 Mdot
.59328 .36362 Mdot
.71885 .36054 Mdot
.6082 .65334 Mdot
.40338 .62116 Mdot
.44327 .74119 Mdot
.56718 .3657 Mdot
.51748 .185 Mdot
.28475 .43416 Mdot
.55307 .60961 Mdot
.38577 .63613 Mdot
.40031 .60411 Mdot
.49027 .42584 Mdot
.70489 .59387 Mdot
.5581 .36237 Mdot
.46868 .72718 Mdot
.61425 .25672 Mdot
.24911 .42407 Mdot
.51353 .39094 Mdot
.60401 .63407 Mdot
.49385 .40383 Mdot
.63902 .50793 Mdot
.68484 .24183 Mdot
.45921 .3676 Mdot
.41828 .6939 Mdot
.71562 .54158 Mdot
.32311 .4814 Mdot
.58824 .46792 Mdot
.44065 .696 Mdot
.50176 .38886 Mdot
.12018 .52616 Mdot
.69015 .49808 Mdot
.74176 .62133 Mdot
.53954 .4351 Mdot
.50335 .43729 Mdot
.46862 .57659 Mdot
.23921 .60012 Mdot
.63527 .69238 Mdot
.5557 .38666 Mdot
.65599 .32954 Mdot
.36936 .6227 Mdot
.54027 .3421 Mdot
.5215 .39561 Mdot
.30878 .34556 Mdot
.40089 .60207 Mdot
.55791 .64104 Mdot
.61386 .63411 Mdot
.54702 .67492 Mdot
.63994 .49748 Mdot
.34212 .64627 Mdot
.7175 .4217 Mdot
.38812 .20462 Mdot
.69148 .48444 Mdot
.54965 .42334 Mdot
.73118 .51603 Mdot
.48942 .39412 Mdot
.66075 .50879 Mdot
.4039 .60182 Mdot
.2957 .46331 Mdot
.33838 .56372 Mdot
.61041 .6259 Mdot
.51074 .32379 Mdot
.64717 .49601 Mdot
.29606 .44646 Mdot
.7612 .46873 Mdot
.32603 .47892 Mdot
.40399 .63381 Mdot
.349 .65903 Mdot
.65775 .5048 Mdot
.33876 .45784 Mdot
.40023 .69062 Mdot
.52221 .83921 Mdot
.58554 .42348 Mdot
.33322 .65129 Mdot
.31017 .4871 Mdot
.34561 .49204 Mdot
.3012 .48845 Mdot
.57027 .3904 Mdot
.45806 .49407 Mdot
.48062 .36279 Mdot
.37266 .61607 Mdot
.5634 .65305 Mdot
.56891 .21368 Mdot
.56188 .72404 Mdot
.51376 .49653 Mdot
.53088 .45374 Mdot
.53908 .37349 Mdot
.51623 .39584 Mdot
.46519 .37861 Mdot
.43707 .71543 Mdot
.55899 .37011 Mdot
.38274 .62116 Mdot
.58735 .61759 Mdot
.50903 .33953 Mdot
.57351 .58575 Mdot
.61786 .77175 Mdot
.70135 .49805 Mdot
.35396 .60938 Mdot
.7368 .26935 Mdot
.2962 .44958 Mdot
.56817 .68155 Mdot
.59943 .61965 Mdot
.65178 .50292 Mdot
.41537 .62581 Mdot
.32868 .47724 Mdot
.6157 .28505 Mdot
.64773 .51524 Mdot
.5371 .38976 Mdot
.44571 .48104 Mdot
.55414 .18864 Mdot
.51308 .33982 Mdot
.52191 .35301 Mdot
.61509 .61581 Mdot
.74786 .6027 Mdot
.49254 .13579 Mdot
.73229 .4219 Mdot
.66142 .50052 Mdot
.69487 .52339 Mdot
.32318 .42511 Mdot
.46943 .38336 Mdot
.36652 .62194 Mdot
.37439 .50668 Mdot
.3461 .68573 Mdot
.27461 .5117 Mdot
.2006 .55728 Mdot
.51 .34999 Mdot
.32987 .74367 Mdot
.53589 .37063 Mdot
.27901 .4767 Mdot
.31553 .43419 Mdot
.30974 .45065 Mdot
.40315 .62192 Mdot
.38939 .33415 Mdot
.39388 .61657 Mdot
.71755 .23435 Mdot
.30098 .48098 Mdot
.57406 .55654 Mdot
.58719 .65505 Mdot
.56784 .45003 Mdot
.6775 .48562 Mdot
.34659 .66308 Mdot
.55076 .30631 Mdot
.26495 .32768 Mdot
.56101 .60679 Mdot
.29162 .45185 Mdot
.3744 .74488 Mdot
.795 .37756 Mdot
.4064 .4922 Mdot
.58288 .32738 Mdot
.75651 .43171 Mdot
.66851 .50948 Mdot
.18855 .52207 Mdot
.6867 .49002 Mdot
.41722 .64844 Mdot
.5046 .41273 Mdot
.51697 .41632 Mdot
.51135 .34669 Mdot
.55553 .40437 Mdot
.4318 .65522 Mdot
.56365 .43227 Mdot
.24092 .32326 Mdot
.60687 .61907 Mdot
.62655 .42071 Mdot
.68344 .49009 Mdot
.44438 .62008 Mdot
.58803 .61689 Mdot
.45011 .75931 Mdot
.70713 .36763 Mdot
.51035 .39052 Mdot
.51801 .34907 Mdot
.65167 .23333 Mdot
.49215 .36363 Mdot
.55462 .46235 Mdot
.5921 .61147 Mdot
.51836 .48824 Mdot
.69894 .49518 Mdot
.69948 .51863 Mdot
.40031 .64994 Mdot
.31797 .43264 Mdot
.68817 .50073 Mdot
.58468 .65773 Mdot
.5341 .45356 Mdot
.55556 .43893 Mdot
.30849 .48657 Mdot
.66454 .23339 Mdot
.6439 .52099 Mdot
.47091 .79312 Mdot
.29175 .44226 Mdot
.33638 .41455 Mdot
.55281 .35974 Mdot
.20108 .5109 Mdot
.36142 .48561 Mdot
.6641 .47416 Mdot
.44487 .62317 Mdot
.74408 .40745 Mdot
.43309 .6269 Mdot
.33116 .44462 Mdot
.50118 .4285 Mdot
.30363 .43611 Mdot
.50743 .38788 Mdot
.81971 .3949 Mdot
.52231 .41435 Mdot
.36921 .21142 Mdot
.65723 .40846 Mdot
.59622 .63599 Mdot
.43319 .76437 Mdot
.59266 .65168 Mdot
.28627 .44891 Mdot
.51264 .44081 Mdot
.65795 .4847 Mdot
.58433 .7857 Mdot
.3675 .49914 Mdot
.54734 .64024 Mdot
.55382 .60223 Mdot
.43591 .62739 Mdot
.49582 .35346 Mdot
.55547 .36372 Mdot
.58319 .62551 Mdot
.23669 .43701 Mdot
.34528 .44903 Mdot
.50238 .40299 Mdot
.54316 .37197 Mdot
.59506 .64001 Mdot
.50372 .83976 Mdot
.47043 .31693 Mdot
.50947 .41042 Mdot
.60869 .72937 Mdot
.38962 .60667 Mdot
.57712 .44033 Mdot
.47888 .43346 Mdot
.67558 .51294 Mdot
.38703 .25329 Mdot
.72144 .29945 Mdot
.40889 .60178 Mdot
.60172 .61831 Mdot
.50076 .39201 Mdot
.60444 .63127 Mdot
.5591 .43705 Mdot
.23595 .5889 Mdot
.5853 .67864 Mdot
.48133 .39693 Mdot
.5869 .35439 Mdot
.28249 .46089 Mdot
.5129 .34973 Mdot
.3974 .40075 Mdot
.55059 .62354 Mdot
.49341 .42803 Mdot
.49664 .2487 Mdot
.42096 .62136 Mdot
.59164 .35602 Mdot
.65641 .52372 Mdot
.61065 .27869 Mdot
.28597 .59596 Mdot
.77278 .55904 Mdot
.70017 .5201 Mdot
.56697 .37923 Mdot
.55545 .60327 Mdot
.36277 .6351 Mdot
.33447 .23015 Mdot
.55123 .34588 Mdot
.42038 .6447 Mdot
.37998 .63752 Mdot
.65837 .49678 Mdot
.18355 .64153 Mdot
.54687 .4306 Mdot
.54911 .40182 Mdot
.346 .36522 Mdot
.36322 .45868 Mdot
.53214 .41286 Mdot
.53513 .4269 Mdot
.37976 .62232 Mdot
.60473 .40654 Mdot
.45174 .3101 Mdot
.48928 .21875 Mdot
.36332 .6515 Mdot
.32973 .53479 Mdot
.59709 .66626 Mdot
.69508 .513 Mdot
.31398 .47497 Mdot
.64976 .49195 Mdot
.5771 .66784 Mdot
.53348 .4257 Mdot
.41676 .65585 Mdot
.37198 .3948 Mdot
.36754 .63272 Mdot
.759 .54673 Mdot
.33208 .48679 Mdot
.37775 .55597 Mdot
.13142 .55976 Mdot
.52944 .76848 Mdot
.4644 .61353 Mdot
.67266 .5092 Mdot
.56223 .70498 Mdot
.54158 .3716 Mdot
.18591 .52956 Mdot
.55025 .42128 Mdot
.48838 .2452 Mdot
.60285 .61338 Mdot
.60345 .60928 Mdot
.5062 .41106 Mdot
.61224 .2589 Mdot
.36273 .63739 Mdot
.40358 .60617 Mdot
.48116 .40529 Mdot
.40705 .6314 Mdot
.54167 .39979 Mdot
.5812 .61355 Mdot
.17726 .44666 Mdot
.5326 .38469 Mdot
.46086 .38567 Mdot
.24437 .59092 Mdot
.59083 .80851 Mdot
.70948 .55496 Mdot
.38692 .81687 Mdot
.78076 .34797 Mdot
.40513 .63057 Mdot
.47449 .37952 Mdot
.32258 .53359 Mdot
.61121 .60927 Mdot
.3861 .69119 Mdot
.53526 .42024 Mdot
.54534 .42075 Mdot
.57024 .36752 Mdot
.5315 .3573 Mdot
.19572 .61165 Mdot
.36583 .50499 Mdot
.38678 .28427 Mdot
.50431 .35551 Mdot
.70208 .3465 Mdot
.40921 .65205 Mdot
.36189 .41719 Mdot
.68414 .47818 Mdot
.51124 .34962 Mdot
.2645 .44313 Mdot
.40703 .66405 Mdot
.71019 .2237 Mdot
.41995 .64911 Mdot
.56044 .63533 Mdot
.37686 .6525 Mdot
.5237 .37123 Mdot
.32131 .46445 Mdot
.42491 .53677 Mdot
.52607 .74466 Mdot
.58871 .60932 Mdot
.51902 .3806 Mdot
.55036 .57016 Mdot
.56811 .60739 Mdot
.63513 .76981 Mdot
.31519 .46878 Mdot
.65769 .33773 Mdot
.30851 .43422 Mdot
.48524 .41501 Mdot
.48727 .41697 Mdot
.38443 .66763 Mdot
.38319 .65547 Mdot
.31075 .43366 Mdot
.19736 .67727 Mdot
.64738 .52332 Mdot
.3123 .44792 Mdot
.4985 .32965 Mdot
.44668 .50716 Mdot
.31811 .46137 Mdot
.64164 .53847 Mdot
.37802 .63054 Mdot
.34441 .42695 Mdot
.56923 .35547 Mdot
.74506 .36817 Mdot
.68141 .53168 Mdot
.60897 .66139 Mdot
.74457 .466 Mdot
.54616 .62874 Mdot
.44389 .62755 Mdot
.59391 .64976 Mdot
.374 .61884 Mdot
.28699 .62162 Mdot
.25161 .4466 Mdot
.45849 .59751 Mdot
.43945 .64138 Mdot
.59167 .6494 Mdot
.50006 .41026 Mdot
.7265 .53443 Mdot
.47684 .41362 Mdot
.57148 .41177 Mdot
.38774 .61116 Mdot
.28714 .46667 Mdot
.36201 .48173 Mdot
.6816 .30811 Mdot
.32774 .4322 Mdot
.55228 .63046 Mdot
.27011 .3111 Mdot
.49524 .6837 Mdot
.42895 .62087 Mdot
.39275 .66039 Mdot
.48661 .38438 Mdot
.58298 .634 Mdot
.59297 .60863 Mdot
.43451 .63044 Mdot
.22649 .51745 Mdot
.46746 .41129 Mdot
.3379 .49743 Mdot
.36312 .45215 Mdot
.32356 .45 Mdot
.30617 .49049 Mdot
.46664 .31108 Mdot
.38586 .64909 Mdot
.28584 .46101 Mdot
.48599 .38166 Mdot
.54093 .42074 Mdot
.36263 .52419 Mdot
.68546 .5262 Mdot
.50756 .33848 Mdot
.58948 .4043 Mdot
.54549 .34933 Mdot
.57241 .67216 Mdot
.44267 .42937 Mdot
.57468 .67758 Mdot
.57298 .60072 Mdot
.58443 .60087 Mdot
.46212 .69905 Mdot
.64636 .24594 Mdot
.78868 .40803 Mdot
.50949 .43478 Mdot
.3671 .76291 Mdot
.57726 .6436 Mdot
.24179 .34132 Mdot
.32011 .66944 Mdot
.55992 .35592 Mdot
.64139 .69627 Mdot
.58728 .62763 Mdot
.30316 .42984 Mdot
.53007 .41859 Mdot
.54575 .66909 Mdot
.65976 .52693 Mdot
.48532 .42239 Mdot
.58857 .67921 Mdot
.33798 .46108 Mdot
.65572 .47507 Mdot
.35644 .4336 Mdot
.58662 .60098 Mdot
.58015 .33605 Mdot
.25472 .25164 Mdot
.52979 .62204 Mdot
.45321 .81082 Mdot
.61681 .39913 Mdot
.50092 .40572 Mdot
.5525 .67089 Mdot
.35384 .42267 Mdot
.44288 .62472 Mdot
.55539 .53267 Mdot
.35138 .43698 Mdot
.60363 .60934 Mdot
.54538 .64582 Mdot
.58945 .60937 Mdot
.35844 .45785 Mdot
.51028 .33276 Mdot
.35116 .44271 Mdot
.37264 .64868 Mdot
.50422 .36637 Mdot
.80791 .47495 Mdot
.34799 .73675 Mdot
.29566 .43802 Mdot
.55541 .64688 Mdot
.70257 .52446 Mdot
.53268 .37517 Mdot
.34989 .74375 Mdot
.49747 .40721 Mdot
.38128 .6122 Mdot
.34321 .27907 Mdot
.37417 .40955 Mdot
.47695 .3855 Mdot
.48845 .38153 Mdot
.40393 .60693 Mdot
.52269 .38289 Mdot
.49333 .35657 Mdot
.46174 .70268 Mdot
.35419 .45579 Mdot
.54131 .38346 Mdot
.57102 .65702 Mdot
.50214 .70745 Mdot
.46408 .40193 Mdot
.52139 .68556 Mdot
.65067 .33438 Mdot
.33259 .29365 Mdot
.54876 .42201 Mdot
.43246 .46183 Mdot
.54218 .3583 Mdot
.56408 .39628 Mdot
.49034 .38641 Mdot
.23566 .67551 Mdot
.58968 .67748 Mdot
.60024 .62452 Mdot
.69081 .52762 Mdot
.65193 .33596 Mdot
.68072 .51463 Mdot
.37642 .63316 Mdot
.71484 .60388 Mdot
.57655 .67795 Mdot
.33641 .44933 Mdot
.56505 .38396 Mdot
.53016 .62186 Mdot
.54933 .35126 Mdot
.5215 .37186 Mdot
.54095 .62307 Mdot
.59747 .66884 Mdot
.76053 .59564 Mdot
.67758 .52947 Mdot
.30553 .45369 Mdot
.49028 .35465 Mdot
.64484 .5063 Mdot
.54617 .42698 Mdot
.6934 .40651 Mdot
.30931 .45377 Mdot
.35339 .45162 Mdot
.36021 .48495 Mdot
.5299 .42557 Mdot
.52709 .37368 Mdot
.39399 .61578 Mdot
.28795 .44127 Mdot
.42269 .62449 Mdot
.53879 .55017 Mdot
.66197 .70595 Mdot
.53558 .42033 Mdot
.33514 .61742 Mdot
.67954 .5223 Mdot
.54903 .64542 Mdot
.56803 .19604 Mdot
.69033 .52806 Mdot
.50597 .39055 Mdot
.56055 .60451 Mdot
.66057 .51475 Mdot
.61071 .30497 Mdot
.69726 .23336 Mdot
.70741 .51489 Mdot
.48621 .38097 Mdot
.60354 .38353 Mdot
.37335 .80918 Mdot
.70445 .51513 Mdot
.39484 .65741 Mdot
.52829 .42537 Mdot
.29649 .49976 Mdot
.64824 .4927 Mdot
.59273 .7544 Mdot
.58888 .62213 Mdot
.73843 .34889 Mdot
.50055 .31378 Mdot
.23088 .43057 Mdot
.69576 .51925 Mdot
.32651 .47427 Mdot
.54515 .46782 Mdot
.55012 .35864 Mdot
.70154 .52034 Mdot
.45404 .64431 Mdot
.57348 .61981 Mdot
.50852 .72444 Mdot
.35894 .45708 Mdot
.45134 .65486 Mdot
.55701 .65464 Mdot
.4822 .79492 Mdot
.42321 .21845 Mdot
.5951 .411 Mdot
.34901 .78382 Mdot
.3653 .7053 Mdot
.55475 .33996 Mdot
.71405 .50652 Mdot
.38422 .6036 Mdot
.42175 .65516 Mdot
.40553 .63686 Mdot
.29039 .64114 Mdot
.41137 .47829 Mdot
.57957 .68444 Mdot
.36469 .66958 Mdot
.69395 .51381 Mdot
.73741 .39359 Mdot
.56944 .4178 Mdot
.53882 .37588 Mdot
.48337 .3675 Mdot
.51658 .34638 Mdot
.54876 .36547 Mdot
.41682 .63072 Mdot
.27647 .61793 Mdot
.39428 .50332 Mdot
.31447 .45686 Mdot
.74633 .58851 Mdot
.58293 .65427 Mdot
.59287 .68537 Mdot
.65845 .51916 Mdot
.55057 .77247 Mdot
.57166 .58549 Mdot
.56567 .64227 Mdot
.53919 .33515 Mdot
.34647 .44454 Mdot
.55917 .45751 Mdot
.48737 .38134 Mdot
.5557 .62778 Mdot
.48501 .57483 Mdot
.42578 .35427 Mdot
.65606 .45953 Mdot
.66747 .46827 Mdot
.42792 .48875 Mdot
.69158 .5303 Mdot
.52494 .44438 Mdot
.21621 .36107 Mdot
.57735 .66843 Mdot
.57039 .63117 Mdot
.68537 .52369 Mdot
.19886 .50496 Mdot
.30813 .47625 Mdot
.34944 .58758 Mdot
.37115 .63439 Mdot
.49577 .42448 Mdot
.46932 .20028 Mdot
.61309 .44331 Mdot
.69384 .59899 Mdot
.41063 .64106 Mdot
.60151 .64334 Mdot
.50262 .44511 Mdot
.49237 .3719 Mdot
.67447 .52279 Mdot
.77586 .6081 Mdot
.57383 .43993 Mdot
.70958 .7499 Mdot
.61499 .21058 Mdot
.70133 .29303 Mdot
.55388 .36144 Mdot
.35555 .45499 Mdot
.6121 .6504 Mdot
.695 .50035 Mdot
.50729 .32622 Mdot
.7348 .29588 Mdot
.31064 .48552 Mdot
.40076 .64556 Mdot
.46688 .54903 Mdot
.74225 .41544 Mdot
.57004 .40399 Mdot
.54112 .4231 Mdot
.56557 .40087 Mdot
.61659 .16076 Mdot
.57614 .67547 Mdot
.30058 .43327 Mdot
.65725 .49925 Mdot
.33239 .43613 Mdot
.59928 .63621 Mdot
.46871 .59889 Mdot
.50128 .417 Mdot
.31706 .48681 Mdot
.32466 .4749 Mdot
.42691 .64474 Mdot
.43483 .60912 Mdot
.49644 .5541 Mdot
.52329 .41328 Mdot
.53923 .61106 Mdot
.28421 .46086 Mdot
.43911 .47752 Mdot
.67756 .50465 Mdot
.37738 .62799 Mdot
.50921 .35236 Mdot
.58468 .67447 Mdot
.58534 .37649 Mdot
.30188 .46366 Mdot
.56641 .6421 Mdot
.70258 .69336 Mdot
.70357 .50464 Mdot
.5451 .41445 Mdot
.68136 .5479 Mdot
.59869 .61547 Mdot
.54143 .36909 Mdot
.50328 .8052 Mdot
.64177 .53827 Mdot
.56235 .74678 Mdot
.57906 .60274 Mdot
.47364 .67134 Mdot
.32867 .42556 Mdot
.29369 .67071 Mdot
.56524 .63179 Mdot
.4441 .78546 Mdot
.73611 .66521 Mdot
.52278 .45352 Mdot
.32175 .44067 Mdot
.3726 .70851 Mdot
.83288 .47446 Mdot
.44852 .8215 Mdot
.51886 .39328 Mdot
.53795 .64566 Mdot
.66653 .51994 Mdot
.42537 .61635 Mdot
.59066 .72293 Mdot
.63629 .48297 Mdot
.58627 .59578 Mdot
.49076 .38669 Mdot
.3325 .4683 Mdot
.38653 .62425 Mdot
.28843 .60191 Mdot
.58008 .65838 Mdot
.56158 .65372 Mdot
.49188 .43562 Mdot
.68588 .51585 Mdot
.32144 .71198 Mdot
.584 .61187 Mdot
.63238 .22323 Mdot
.56299 .6939 Mdot
.6456 .51465 Mdot
.5346 .35343 Mdot
.68243 .30175 Mdot
.46992 .37522 Mdot
.53466 .81433 Mdot
.58614 .65202 Mdot
.30509 .45941 Mdot
.57203 .38406 Mdot
.52744 .23326 Mdot
.552 .63242 Mdot
.44656 .49024 Mdot
.6542 .57949 Mdot
.37798 .64189 Mdot
.56348 .19504 Mdot
.53941 .40938 Mdot
.363 .63561 Mdot
.67432 .52146 Mdot
.51492 .41092 Mdot
.52749 .37087 Mdot
.27992 .46943 Mdot
.42954 .64029 Mdot
.75972 .61006 Mdot
.38959 .66126 Mdot
.40857 .65506 Mdot
.30018 .49346 Mdot
.54842 .38914 Mdot
.5593 .63683 Mdot
.58567 .628 Mdot
.57147 .35437 Mdot
.16252 .44409 Mdot
.31071 .47932 Mdot
.61555 .6394 Mdot
.59749 .15002 Mdot
.57246 .34519 Mdot
.54855 .1969 Mdot
.77141 .61692 Mdot
.36934 .61717 Mdot
.48576 .38021 Mdot
.3367 .45969 Mdot
.6431 .63615 Mdot
.55949 .65041 Mdot
.57282 .36799 Mdot
.38766 .62544 Mdot
.67 .53078 Mdot
.55934 .61388 Mdot
.70338 .59579 Mdot
.55835 .40543 Mdot
.64678 .6884 Mdot
.5404 .64499 Mdot
.8402 .56035 Mdot
.43891 .75342 Mdot
.31803 .44073 Mdot
.5201 .3695 Mdot
.29666 .43223 Mdot
.65523 .50302 Mdot
.47072 .54974 Mdot
.38106 .63003 Mdot
.42131 .4018 Mdot
.23359 .31926 Mdot
.59028 .60946 Mdot
.29745 .43404 Mdot
.47575 .3925 Mdot
.23018 .58098 Mdot
.54271 .40425 Mdot
.60092 .35743 Mdot
.73882 .50131 Mdot
.40463 .60993 Mdot
.36869 .62534 Mdot
.53333 .36244 Mdot
.65038 .50008 Mdot
.58355 .65668 Mdot
.56437 .62372 Mdot
.80728 .66849 Mdot
.37731 .55091 Mdot
.57754 .23911 Mdot
.54656 .41945 Mdot
.57843 .59521 Mdot
.53417 .71182 Mdot
.42402 .64055 Mdot
.55656 .33228 Mdot
.54642 .61615 Mdot
.6428 .54594 Mdot
.61784 .29965 Mdot
.5469 .35892 Mdot
.47185 .36005 Mdot
.3725 .64113 Mdot
.41708 .45692 Mdot
.60579 .63915 Mdot
.58625 .39524 Mdot
.44126 .58003 Mdot
.61781 .31083 Mdot
.64726 .20638 Mdot
.30549 .45338 Mdot
.70024 .5822 Mdot
.41716 .62999 Mdot
.4603 .38171 Mdot
.66565 .48685 Mdot
.61141 .60664 Mdot
.58614 .6761 Mdot
.49828 .38721 Mdot
.52758 .44827 Mdot
.59453 .21922 Mdot
.33964 .44443 Mdot
.40532 .65178 Mdot
.51598 .42054 Mdot
.3409 .57482 Mdot
.50811 .34829 Mdot
.402 .61464 Mdot
.23432 .26989 Mdot
.47468 .40414 Mdot
.54667 .40182 Mdot
.33241 .7175 Mdot
.35748 .44154 Mdot
.28286 .44334 Mdot
.48966 .18649 Mdot
.54645 .41917 Mdot
.59666 .20791 Mdot
.3004 .45528 Mdot
.30341 .47325 Mdot
.47042 .71343 Mdot
.5346 .37698 Mdot
.45481 .34829 Mdot
.37357 .61613 Mdot
.40634 .65664 Mdot
.35524 .44656 Mdot
.57549 .44081 Mdot
.42476 .60583 Mdot
.25158 .67343 Mdot
.58365 .63564 Mdot
.20006 .38084 Mdot
.31004 .4811 Mdot
.38873 .58567 Mdot
.41842 .64239 Mdot
.72557 .2487 Mdot
.63286 .61842 Mdot
.50167 .41382 Mdot
.5505 .41468 Mdot
.68879 .52032 Mdot
.48039 .36951 Mdot
.60319 .60931 Mdot
.40783 .63183 Mdot
.54448 .25983 Mdot
.30966 .45007 Mdot
.52993 .40776 Mdot
.58347 .77631 Mdot
.6641 .74956 Mdot
.71282 .56994 Mdot
.32171 .48082 Mdot
.30845 .43809 Mdot
.59438 .65947 Mdot
.53795 .64349 Mdot
.55399 .37808 Mdot
.41673 .60789 Mdot
.28917 .4405 Mdot
.39859 .612 Mdot
.57535 .66809 Mdot
.56119 .63887 Mdot
.59872 .67146 Mdot
.56625 .42409 Mdot
.56585 .64895 Mdot
.67675 .70574 Mdot
.42176 .67105 Mdot
.30449 .49726 Mdot
.56188 .17238 Mdot
.29342 .60607 Mdot
.37538 .47427 Mdot
.64406 .49846 Mdot
.59425 .61116 Mdot
.37012 .64802 Mdot
.5148 .35884 Mdot
.53131 .34498 Mdot
.48457 .66415 Mdot
.36794 .65128 Mdot
.65703 .50227 Mdot
.36495 .63323 Mdot
.65788 .49706 Mdot
.65488 .63167 Mdot
.50283 .34733 Mdot
.55727 .44004 Mdot
.41544 .63452 Mdot
.56621 .64596 Mdot
.59509 .62235 Mdot
.70773 .50886 Mdot
.49955 .58837 Mdot
.56567 .60739 Mdot
.29913 .47298 Mdot
.44518 .33421 Mdot
.54557 .65215 Mdot
.53059 .41682 Mdot
.71727 .42614 Mdot
.18291 .53345 Mdot
.46527 .37821 Mdot
.46613 .709 Mdot
.33104 .38568 Mdot
.56623 .36936 Mdot
.17983 .5238 Mdot
.46277 .67056 Mdot
.33359 .42865 Mdot
.6059 .61934 Mdot
.52972 .60188 Mdot
.44722 .41842 Mdot
.6678 .47087 Mdot
.53862 .32582 Mdot
.3222 .48447 Mdot
.27796 .43956 Mdot
.70991 .32117 Mdot
.48175 .81869 Mdot
.66372 .51645 Mdot
.66335 .52182 Mdot
.56374 .63058 Mdot
.62524 .82561 Mdot
.58375 .33218 Mdot
.65883 .50204 Mdot
.2424 .46071 Mdot
.49309 .38635 Mdot
.64438 .3577 Mdot
.57632 .50021 Mdot
.35684 .4509 Mdot
.70045 .33865 Mdot
.55435 .63581 Mdot
.32813 .43144 Mdot
.33234 .56708 Mdot
.50306 .33808 Mdot
.31036 .45282 Mdot
.39537 .61338 Mdot
.47122 .75794 Mdot
.29348 .47135 Mdot
.70686 .41515 Mdot
.43337 .61791 Mdot
.43749 .47886 Mdot
.66974 .30919 Mdot
.34439 .84936 Mdot
.41249 .63014 Mdot
.54609 .64662 Mdot
.58502 .62697 Mdot
.56362 .62463 Mdot
.33546 .43759 Mdot
.59443 .60994 Mdot
.33761 .44413 Mdot
.37936 .79572 Mdot
.19887 .54865 Mdot
.66064 .50175 Mdot
.50905 .72668 Mdot
.33163 .4574 Mdot
.2386 .33804 Mdot
.13571 .45835 Mdot
.48455 .38193 Mdot
.41313 .66278 Mdot
.66162 .50483 Mdot
.69475 .75896 Mdot
.67233 .51341 Mdot
.67905 .27031 Mdot
.29171 .31399 Mdot
.53492 .40146 Mdot
.4203 .3211 Mdot
.68564 .48455 Mdot
.33722 .4782 Mdot
.54004 .36952 Mdot
.59391 .53591 Mdot
.67444 .51728 Mdot
.65151 .52305 Mdot
.54884 .38008 Mdot
.29148 .45177 Mdot
.55259 .64353 Mdot
.40106 .66047 Mdot
.65535 .48286 Mdot
.60091 .43298 Mdot
.47573 .35987 Mdot
.49579 .40969 Mdot
.3742 .52376 Mdot
.71445 .51952 Mdot
.40446 .62993 Mdot
.20759 .66188 Mdot
.54663 .61104 Mdot
.60395 .54776 Mdot
.63612 .21561 Mdot
.44638 .69601 Mdot
.58613 .65011 Mdot
.60356 .6324 Mdot
.55054 .36608 Mdot
.57952 .48372 Mdot
.27059 .33008 Mdot
.50192 .60348 Mdot
.60247 .67117 Mdot
.56869 .62111 Mdot
.29254 .4313 Mdot
.69818 .29645 Mdot
.49593 .32907 Mdot
.40758 .60144 Mdot
.58983 .67507 Mdot
.22518 .60253 Mdot
.68982 .51466 Mdot
.29714 .30153 Mdot
.505 .34487 Mdot
.50515 .41668 Mdot
.38808 .6321 Mdot
.3924 .61739 Mdot
.63599 .5988 Mdot
.6917 .28609 Mdot
.33873 .3895 Mdot
.26812 .59711 Mdot
.33145 .30435 Mdot
.283 .43705 Mdot
.2953 .43834 Mdot
.53655 .75398 Mdot
.39802 .66324 Mdot
.56897 .37452 Mdot
.31524 .4325 Mdot
.60873 .55818 Mdot
.4252 .37782 Mdot
.6189 .27666 Mdot
.5633 .2079 Mdot
.51019 .38603 Mdot
.34976 .45734 Mdot
.35933 .44422 Mdot
.35402 .47827 Mdot
.4737 .65701 Mdot
.55566 .3874 Mdot
.51433 .3891 Mdot
.56222 .36851 Mdot
.21439 .54133 Mdot
.56126 .39053 Mdot
.28771 .66148 Mdot
.4758 .54197 Mdot
.40615 .24197 Mdot
.58698 .39807 Mdot
.3638 .61971 Mdot
.56282 .41474 Mdot
.65102 .50025 Mdot
.48524 .3949 Mdot
.6161 .27553 Mdot
.4121 .64669 Mdot
.46094 .32373 Mdot
.29062 .61958 Mdot
.56323 .35268 Mdot
.65943 .47606 Mdot
.34704 .69197 Mdot
.81324 .45607 Mdot
.72421 .53249 Mdot
.30084 .47475 Mdot
.58427 .64149 Mdot
.36927 .64807 Mdot
.56569 .63624 Mdot
.5704 .42858 Mdot
.5284 .75948 Mdot
.70979 .72926 Mdot
.54112 .5563 Mdot
.51753 .34682 Mdot
.51709 .31571 Mdot
.29927 .46859 Mdot
.5492 .61008 Mdot
.36535 .48653 Mdot
.57076 .3931 Mdot
.66827 .4941 Mdot
.67705 .52058 Mdot
.55727 .53499 Mdot
.80279 .59987 Mdot
.23444 .63982 Mdot
.39106 .63023 Mdot
.57797 .61267 Mdot
.68133 .48642 Mdot
.41323 .77912 Mdot
.42972 .60372 Mdot
.393 .60732 Mdot
.40876 .64869 Mdot
.52245 .43082 Mdot
.58763 .67853 Mdot
.41238 .23971 Mdot
.59425 .6011 Mdot
.52226 .38051 Mdot
.57052 .67263 Mdot
.55311 .61043 Mdot
.68799 .49361 Mdot
.40878 .65075 Mdot
.58049 .66628 Mdot
.48822 .41988 Mdot
.2973 .45191 Mdot
.44936 .59926 Mdot
.646 .40935 Mdot
.49441 .81776 Mdot
.61328 .33573 Mdot
.35911 .46518 Mdot
.82733 .48285 Mdot
.38385 .60856 Mdot
.22385 .52427 Mdot
.76076 .59042 Mdot
.51464 .43989 Mdot
.16282 .42398 Mdot
.59569 .68478 Mdot
.54791 .61724 Mdot
.53547 .35454 Mdot
.548 .68902 Mdot
.53458 .40581 Mdot
.56448 .66319 Mdot
.54059 .70462 Mdot
.26341 .45562 Mdot
.5706 .64864 Mdot
.58462 .39726 Mdot
.53104 .36767 Mdot
.35481 .45078 Mdot
.54584 .66167 Mdot
.50893 .32424 Mdot
.82284 .64927 Mdot
.40061 .61718 Mdot
.39482 .70388 Mdot
.71861 .43836 Mdot
.41822 .62897 Mdot
.31504 .44742 Mdot
.56976 .4151 Mdot
.67274 .5217 Mdot
.33292 .45766 Mdot
.59442 .27008 Mdot
.70161 .50418 Mdot
.19451 .37306 Mdot
.36026 .45022 Mdot
.54603 .63503 Mdot
.65668 .49084 Mdot
.47724 .37081 Mdot
.61318 .61008 Mdot
.4445 .7656 Mdot
.58409 .65037 Mdot
.5565 .36669 Mdot
.55106 .73279 Mdot
.40452 .65285 Mdot
.5177 .39647 Mdot
.5495 .61789 Mdot
.47017 .70602 Mdot
.51969 .43371 Mdot
.53863 .361 Mdot
.65202 .21838 Mdot
.31622 .26262 Mdot
.67511 .5083 Mdot
.36547 .44183 Mdot
.4856 .38234 Mdot
.65214 .52089 Mdot
.68741 .66395 Mdot
.51585 .42666 Mdot
.30902 .48576 Mdot
.56762 .33479 Mdot
.54229 .65555 Mdot
.4181 .62211 Mdot
.52835 .57837 Mdot
.65936 .52663 Mdot
.41349 .85328 Mdot
.59738 .66284 Mdot
.549 .44125 Mdot
.5033 .35241 Mdot
.76225 .49454 Mdot
.3343 .42977 Mdot
.2524 .38677 Mdot
.54548 .41452 Mdot
.21468 .53038 Mdot
.51724 .40841 Mdot
.60348 .67891 Mdot
.30696 .47596 Mdot
.55186 .39958 Mdot
.39558 .56591 Mdot
.46112 .3929 Mdot
.68644 .52822 Mdot
.34023 .73094 Mdot
.5022 .33593 Mdot
.2054 .32179 Mdot
.60792 .52032 Mdot
.5706 .65072 Mdot
.63065 .75283 Mdot
.81418 .68308 Mdot
.29329 .64048 Mdot
.3311 .43715 Mdot
.75727 .65883 Mdot
.55924 .63741 Mdot
.62069 .74303 Mdot
.82885 .47313 Mdot
.5253 .36409 Mdot
.57076 .40252 Mdot
.76212 .4449 Mdot
.57943 .59974 Mdot
.54978 .60135 Mdot
.5454 .44989 Mdot
.46218 .37493 Mdot
.56134 .64515 Mdot
.50089 .43507 Mdot
.57281 .43672 Mdot
.41525 .66142 Mdot
.31127 .48418 Mdot
.40817 .60962 Mdot
.42308 .60626 Mdot
.28943 .71458 Mdot
.6133 .52191 Mdot
.40601 .61578 Mdot
.37802 .6075 Mdot
.64332 .35211 Mdot
.63448 .26388 Mdot
.65034 .49067 Mdot
.8169 .60753 Mdot
.57131 .62174 Mdot
.55172 .39151 Mdot
.36224 .45086 Mdot
.35529 .39612 Mdot
.70883 .66394 Mdot
.22216 .37066 Mdot
.57076 .38292 Mdot
.55155 .63487 Mdot
.46985 .66129 Mdot
.55873 .45881 Mdot
.53675 .65953 Mdot
.52119 .42183 Mdot
.60579 .61014 Mdot
.50092 .2734 Mdot
.44428 .78481 Mdot
.52446 .64609 Mdot
.33319 .49845 Mdot
.51097 .41724 Mdot
.32495 .48405 Mdot
.42332 .63818 Mdot
.65119 .49287 Mdot
.67857 .50849 Mdot
.54457 .37289 Mdot
.56933 .31998 Mdot
.65749 .65806 Mdot
.53244 .37381 Mdot
.49367 .38223 Mdot
.46431 .66941 Mdot
.49022 .38364 Mdot
.52648 .34163 Mdot
.5543 .35412 Mdot
.57645 .38432 Mdot
.40715 .65579 Mdot
.5559 .77198 Mdot
.45651 .42844 Mdot
.45401 .41564 Mdot
.4417 .62472 Mdot
.76908 .60694 Mdot
.40771 .60311 Mdot
.81837 .45136 Mdot
.36815 .62213 Mdot
.67443 .50058 Mdot
.75757 .52841 Mdot
.51281 .30718 Mdot
.287 .47503 Mdot
.40731 .5955 Mdot
.65356 .50349 Mdot
.40642 .63463 Mdot
.55765 .65984 Mdot
.65995 .21499 Mdot
.29175 .41938 Mdot
.36499 .51195 Mdot
.36224 .69106 Mdot
.50805 .77544 Mdot
.59294 .66379 Mdot
.33664 .48187 Mdot
.42736 .34254 Mdot
.51757 .34502 Mdot
.65079 .51927 Mdot
.55209 .37646 Mdot
.42088 .65044 Mdot
.55631 .63215 Mdot
.42186 .80972 Mdot
.67503 .5228 Mdot
.59126 .183 Mdot
.59326 .6247 Mdot
.54259 .34177 Mdot
.42178 .60475 Mdot
.49431 .16547 Mdot
.40044 .60898 Mdot
.26978 .35887 Mdot
.31206 .42658 Mdot
.40574 .82686 Mdot
.33007 .44852 Mdot
.45486 .77327 Mdot
.4539 .13767 Mdot
.57058 .77826 Mdot
.29377 .45078 Mdot
.47808 .60921 Mdot
.5033 .39006 Mdot
.49635 .41092 Mdot
.43147 .79285 Mdot
.36576 .45003 Mdot
.4965 .36237 Mdot
.50753 .68655 Mdot
.45306 .65655 Mdot
.51719 .19971 Mdot
.59685 .64944 Mdot
.53554 .40948 Mdot
.35553 .64393 Mdot
.36372 .6463 Mdot
.60895 .63632 Mdot
.39128 .60706 Mdot
.5166 .38836 Mdot
.33144 .45599 Mdot
.56174 .70987 Mdot
.68432 .50146 Mdot
.65084 .79691 Mdot
.6584 .53289 Mdot
.5867 .64982 Mdot
.47626 .41267 Mdot
.56182 .63922 Mdot
.87625 .61693 Mdot
.50918 .39476 Mdot
.30087 .45646 Mdot
.49231 .37561 Mdot
.50896 .41378 Mdot
.57443 .38313 Mdot
.55588 .64909 Mdot
.69027 .46089 Mdot
.49322 .42659 Mdot
.37988 .63133 Mdot
.3638 .27882 Mdot
.51831 .33347 Mdot
.51852 .62071 Mdot
.63912 .28349 Mdot
.37844 .68287 Mdot
.33931 .42477 Mdot
.57566 .65047 Mdot
.30673 .44796 Mdot
.20637 .49069 Mdot
.31523 .44771 Mdot
.33405 .3315 Mdot
.44129 .32176 Mdot
.53391 .24365 Mdot
.50841 .25112 Mdot
.44091 .55451 Mdot
.36586 .44531 Mdot
.71926 .50589 Mdot
.28785 .44618 Mdot
.35398 .44099 Mdot
.1798 .28915 Mdot
.2917 .48423 Mdot
.53629 .4173 Mdot
.52455 .33474 Mdot
.50024 .78809 Mdot
.68002 .38463 Mdot
.50317 .36568 Mdot
.50367 .36051 Mdot
.67333 .4849 Mdot
.21219 .50231 Mdot
.56321 .75103 Mdot
.29804 .27722 Mdot
.67598 .73595 Mdot
.55026 .37772 Mdot
.48344 .3867 Mdot
.50152 .45547 Mdot
.37065 .19481 Mdot
.29645 .72975 Mdot
.27239 .48985 Mdot
.49423 .44912 Mdot
.56179 .79132 Mdot
.5736 .39139 Mdot
.53615 .42664 Mdot
.50767 .38768 Mdot
.55877 .63713 Mdot
.35006 .42933 Mdot
.57893 .38641 Mdot
.75404 .49697 Mdot
.53362 .42438 Mdot
.45077 .69823 Mdot
.5216 .8512 Mdot
.54016 .40939 Mdot
.31571 .41584 Mdot
.49418 .40696 Mdot
.34372 .43565 Mdot
.34893 .47003 Mdot
.51054 .45258 Mdot
.32742 .30752 Mdot
.30686 .42146 Mdot
.5225 .37975 Mdot
.55075 .65324 Mdot
.83584 .56215 Mdot
.55745 .36913 Mdot
.64886 .49397 Mdot
.54886 .41576 Mdot
.65057 .47973 Mdot
.49764 .3772 Mdot
.60082 .65932 Mdot
.30446 .39362 Mdot
.56937 .63005 Mdot
.33496 .77372 Mdot
.59744 .67039 Mdot
.6277 .18774 Mdot
.35509 .47331 Mdot
.52603 .72827 Mdot
.20986 .43419 Mdot
.40052 .71113 Mdot
.48722 .4957 Mdot
.42674 .52153 Mdot
.41419 .60739 Mdot
.31901 .42805 Mdot
.24451 .50646 Mdot
.74084 .61658 Mdot
.74133 .56478 Mdot
.5663 .60937 Mdot
.18373 .64658 Mdot
.19244 .41546 Mdot
.51831 .44431 Mdot
.39796 .34464 Mdot
.39123 .30116 Mdot
.57429 .39163 Mdot
.57767 .39694 Mdot
.55272 .57768 Mdot
.49138 .42767 Mdot
.34021 .57886 Mdot
.59055 .64789 Mdot
.65206 .50615 Mdot
.29756 .46315 Mdot
.66955 .53097 Mdot
.75383 .59749 Mdot
.42013 .51875 Mdot
.56772 .66604 Mdot
.48381 .34489 Mdot
.51075 .3582 Mdot
.34915 .44274 Mdot
.34596 .50629 Mdot
.28342 .45613 Mdot
.66339 .51032 Mdot
.59302 .64138 Mdot
.18513 .5624 Mdot
.51252 .35496 Mdot
.32319 .4741 Mdot
.50767 .50041 Mdot
.48681 .37982 Mdot
.41987 .63641 Mdot
.50213 .3949 Mdot
.29198 .45543 Mdot
.49036 .38337 Mdot
.33039 .44669 Mdot
.58317 .6391 Mdot
.55596 .34886 Mdot
.54064 .35439 Mdot
.54331 .17393 Mdot
.66364 .49777 Mdot
.32774 .48751 Mdot
.59345 .55416 Mdot
.4866 .36737 Mdot
.48307 .72632 Mdot
.52553 .42123 Mdot
.35276 .4066 Mdot
.53039 .44139 Mdot
.40445 .70321 Mdot
.45213 .3892 Mdot
.55876 .37644 Mdot
.57011 .51492 Mdot
.37926 .31282 Mdot
.50213 .30421 Mdot
.3735 .60749 Mdot
.31438 .49196 Mdot
.52398 .20436 Mdot
.59781 .69807 Mdot
.53441 .63075 Mdot
.71986 .37236 Mdot
.57271 .36649 Mdot
.53744 .40033 Mdot
.34804 .65652 Mdot
.67202 .52675 Mdot
.32497 .48092 Mdot
.65809 .49698 Mdot
.58462 .19535 Mdot
.69606 .52115 Mdot
.60029 .68263 Mdot
.64658 .69042 Mdot
.19452 .60165 Mdot
.67687 .48573 Mdot
.29036 .45312 Mdot
.63139 .71423 Mdot
.55956 .34169 Mdot
.6031 .51526 Mdot
.67484 .49313 Mdot
.25939 .74311 Mdot
.52858 .34155 Mdot
.48347 .49261 Mdot
.41349 .61571 Mdot
.66763 .48601 Mdot
.43356 .62304 Mdot
.51938 .3591 Mdot
.56709 .7485 Mdot
.32931 .43718 Mdot
.43764 .63299 Mdot
.5923 .36027 Mdot
.65996 .5053 Mdot
.5872 .67699 Mdot
.34735 .63942 Mdot
.39544 .60116 Mdot
.78489 .59849 Mdot
.40484 .81203 Mdot
.59355 .63792 Mdot
.42572 .21493 Mdot
.36331 .62912 Mdot
.5563 .3399 Mdot
.21907 .49594 Mdot
.50221 .41515 Mdot
.27661 .67142 Mdot
.58079 .6543 Mdot
.52303 .77556 Mdot
.48581 .38434 Mdot
.56661 .38275 Mdot
.29122 .42214 Mdot
.57708 .62611 Mdot
.32129 .46194 Mdot
.32436 .4924 Mdot
.58409 .63757 Mdot
.32218 .44252 Mdot
.69179 .48865 Mdot
.31334 .54555 Mdot
.37032 .63408 Mdot
.38241 .64209 Mdot
.56473 .6231 Mdot
.5716 .65438 Mdot
.56558 .64107 Mdot
.50174 .39545 Mdot
.31658 .48051 Mdot
.51444 .36963 Mdot
.54774 .42359 Mdot
.36697 .26784 Mdot
.35555 .43541 Mdot
.51128 .3792 Mdot
.60353 .54065 Mdot
.58721 .4891 Mdot
.55226 .65809 Mdot
.4099 .61627 Mdot
.51592 .70313 Mdot
.4265 .75964 Mdot
.53215 .4113 Mdot
.62577 .5264 Mdot
.28891 .45111 Mdot
.67098 .51933 Mdot
.67646 .53763 Mdot
.67291 .51132 Mdot
.42263 .68681 Mdot
.35618 .47419 Mdot
.29162 .28584 Mdot
.53703 .40619 Mdot
.38461 .51851 Mdot
.24834 .46067 Mdot
.65008 .62226 Mdot
.4076 .61711 Mdot
.49238 .37245 Mdot
.53239 .57274 Mdot
.41047 .39082 Mdot
.50194 .41106 Mdot
.53368 .33285 Mdot
.68446 .7063 Mdot
.55502 .32677 Mdot
.27807 .44626 Mdot
.49834 .16932 Mdot
.47731 .38019 Mdot
.22064 .5993 Mdot
.66684 .79739 Mdot
.5246 .41551 Mdot
.56762 .3943 Mdot
.528 .34816 Mdot
.48609 .39815 Mdot
.31427 .41776 Mdot
.67392 .34228 Mdot
.3641 .62425 Mdot
.38607 .51425 Mdot
.41121 .65894 Mdot
.61431 .6358 Mdot
.53175 .77492 Mdot
.31213 .42777 Mdot
.68813 .52065 Mdot
.64323 .77205 Mdot
.41 .19637 Mdot
.60604 .63735 Mdot
.25092 .66941 Mdot
.67208 .49517 Mdot
.55096 .33709 Mdot
.67378 .47807 Mdot
.5687 .67565 Mdot
.37902 .64203 Mdot
.51604 .32959 Mdot
.2925 .44266 Mdot
.2964 .47481 Mdot
.49067 .37149 Mdot
.57751 .78957 Mdot
.42327 .63115 Mdot
.39107 .60063 Mdot
.51721 .43013 Mdot
.47847 .36886 Mdot
.32125 .45802 Mdot
.58366 .61475 Mdot
.55234 .2366 Mdot
.65873 .52132 Mdot
.56907 .41955 Mdot
.4898 .38818 Mdot
.64256 .21847 Mdot
.37777 .62959 Mdot
.53823 .65721 Mdot
.51911 .44003 Mdot
.25855 .59231 Mdot
.51607 .43942 Mdot
.51793 .45929 Mdot
.5498 .65276 Mdot
.47363 .45036 Mdot
.55044 .44445 Mdot
.29702 .41258 Mdot
.42385 .61245 Mdot
.30722 .45567 Mdot
.3239 .40496 Mdot
.30805 .52654 Mdot
.41736 .63794 Mdot
.50464 .38464 Mdot
.40644 .62062 Mdot
.51468 .42608 Mdot
.48035 .40192 Mdot
.40274 .61461 Mdot
.32201 .46101 Mdot
.75033 .66582 Mdot
.56881 .7736 Mdot
.4865 .40508 Mdot
.52797 .45343 Mdot
.67263 .36076 Mdot
.69009 .464 Mdot
.57118 .39572 Mdot
.29133 .46012 Mdot
.5234 .3538 Mdot
.42987 .63611 Mdot
.68518 .48487 Mdot
.29579 .45233 Mdot
.59869 .62351 Mdot
.603 .64913 Mdot
.2921 .62547 Mdot
.56725 .60475 Mdot
.56924 .40863 Mdot
.37548 .44043 Mdot
.32984 .41103 Mdot
.60884 .80493 Mdot
.58501 .63393 Mdot
.64902 .4906 Mdot
.53993 .36297 Mdot
.74558 .36864 Mdot
.35813 .64929 Mdot
.14818 .39147 Mdot
.2374 .33661 Mdot
.69995 .48862 Mdot
.2333 .36412 Mdot
.60283 .66119 Mdot
.56413 .43574 Mdot
.64751 .49886 Mdot
.59478 .65868 Mdot
.49735 .42216 Mdot
.50882 .45309 Mdot
.2582 .37982 Mdot
.39885 .53942 Mdot
.40236 .61983 Mdot
.59066 .60625 Mdot
.69817 .48443 Mdot
.58942 .68589 Mdot
.34897 .47694 Mdot
.5582 .38766 Mdot
.48088 .42314 Mdot
.59011 .61516 Mdot
.53511 .61969 Mdot
.51672 .38053 Mdot
.29855 .43118 Mdot
.55545 .57474 Mdot
.54561 .38036 Mdot
.38034 .54887 Mdot
.36805 .4621 Mdot
.59577 .6463 Mdot
.56405 .38267 Mdot
.69219 .47113 Mdot
.59078 .62075 Mdot
.55411 .66093 Mdot
.48318 .38434 Mdot
.69563 .49226 Mdot
.5064 .44754 Mdot
.37086 .62187 Mdot
.2172 .68117 Mdot
.42988 .63794 Mdot
.54125 .70112 Mdot
.58289 .3368 Mdot
.24624 .55556 Mdot
.3371 .42624 Mdot
.70035 .32052 Mdot
.51008 .6903 Mdot
.56981 .44108 Mdot
.82522 .55396 Mdot
.38623 .58469 Mdot
.61038 .79109 Mdot
.78577 .43363 Mdot
.68326 .49312 Mdot
.40638 .63664 Mdot
.56776 .39505 Mdot
.41464 .66228 Mdot
.64569 .50374 Mdot
.33612 .77205 Mdot
.56103 .37128 Mdot
.30422 .47321 Mdot
.51434 .38532 Mdot
.30663 .47922 Mdot
.48168 .38921 Mdot
.46985 .42775 Mdot
.47355 .67962 Mdot
.6206 .30496 Mdot
.52587 .43828 Mdot
.59636 .15577 Mdot
.5368 .49142 Mdot
.65254 .51392 Mdot
.5224 .36718 Mdot
.54094 .67051 Mdot
.37117 .65565 Mdot
.33751 .70013 Mdot
.55794 .63831 Mdot
.39072 .60312 Mdot
.32156 .4487 Mdot
.58045 .64897 Mdot
.60799 .63288 Mdot
.47438 .45172 Mdot
.69387 .4865 Mdot
.39698 .64661 Mdot
.55325 .40008 Mdot
.56079 .37228 Mdot
.4262 .21101 Mdot
.72026 .63718 Mdot
.35882 .50176 Mdot
.2973 .24368 Mdot
.32623 .49656 Mdot
.65524 .50752 Mdot
.55357 .64396 Mdot
.55641 .41816 Mdot
.52077 .39362 Mdot
.49597 .72002 Mdot
.28457 .44402 Mdot
.47993 .55475 Mdot
.23004 .43705 Mdot
.60188 .55926 Mdot
.64444 .31575 Mdot
.29512 .46181 Mdot
.64429 .31838 Mdot
.70868 .5228 Mdot
.78889 .66219 Mdot
.63414 .32615 Mdot
.41524 .61779 Mdot
.64711 .32758 Mdot
.32958 .47618 Mdot
.49538 .42651 Mdot
.54506 .64143 Mdot
.55381 .60947 Mdot
.31306 .45975 Mdot
.56589 .68452 Mdot
.69242 .49977 Mdot
.56216 .40118 Mdot
.31112 .26156 Mdot
.30528 .59605 Mdot
.5645 .61977 Mdot
.54441 .46414 Mdot
.41002 .64868 Mdot
.48998 .37178 Mdot
.68552 .48983 Mdot
.41056 .62666 Mdot
.68629 .27771 Mdot
.44665 .65676 Mdot
.54039 .36646 Mdot
.64861 .21649 Mdot
.41343 .63476 Mdot
.51976 .48455 Mdot
.54963 .38568 Mdot
.37497 .61529 Mdot
.45872 .45083 Mdot
.46969 .76123 Mdot
.53469 .55748 Mdot
.82975 .47348 Mdot
.51659 .54939 Mdot
.55028 .628 Mdot
.48901 .77061 Mdot
.37163 .71178 Mdot
.37395 .65067 Mdot
.53353 .64237 Mdot
.61607 .4771 Mdot
.43239 .61988 Mdot
.54615 .33752 Mdot
.52242 .41921 Mdot
.31114 .74175 Mdot
.35613 .60884 Mdot
.4505 .77602 Mdot
.31515 .65183 Mdot
.48868 .36355 Mdot
.50055 .44422 Mdot
.52544 .3941 Mdot
.28626 .43169 Mdot
.39024 .6219 Mdot
.55241 .15726 Mdot
.42254 .63614 Mdot
.32225 .28328 Mdot
.56732 .62345 Mdot
.59588 .65276 Mdot
.53638 .41137 Mdot
.46224 .48056 Mdot
.66239 .28188 Mdot
.51926 .38599 Mdot
.62985 .48735 Mdot
.35259 .75084 Mdot
.47978 .36926 Mdot
.31749 .42359 Mdot
.52342 .46413 Mdot
.59344 .44854 Mdot
.37013 .63469 Mdot
.69036 .51075 Mdot
.69296 .3047 Mdot
.38624 .64841 Mdot
.53637 .39958 Mdot
.25538 .56171 Mdot
.50857 .40776 Mdot
.48916 .40976 Mdot
.25914 .32963 Mdot
.68607 .53409 Mdot
.57274 .63857 Mdot
.67144 .50895 Mdot
.34146 .43193 Mdot
.13162 .3765 Mdot
.69357 .5246 Mdot
.66482 .27712 Mdot
.29867 .74359 Mdot
.64777 .33711 Mdot
.31947 .4847 Mdot
.68123 .47769 Mdot
.42204 .62457 Mdot
.83544 .5681 Mdot
.26108 .39374 Mdot
.37635 .57867 Mdot
.54241 .3844 Mdot
.2804 .48257 Mdot
.28969 .4713 Mdot
.43893 .63232 Mdot
.34605 .47322 Mdot
.44787 .36707 Mdot
.49089 .4183 Mdot
.39529 .66139 Mdot
.27047 .58748 Mdot
.36876 .61032 Mdot
.45954 .58603 Mdot
.52573 .37081 Mdot
.29709 .4565 Mdot
.57089 .42101 Mdot
.36991 .44268 Mdot
.55105 .67303 Mdot
.46942 .37029 Mdot
.69414 .50262 Mdot
.2428 .57113 Mdot
.59488 .6357 Mdot
.6278 .55581 Mdot
.3491 .441 Mdot
.4205 .68112 Mdot
.35456 .45312 Mdot
.35743 .42425 Mdot
.41324 .60347 Mdot
.33953 .45993 Mdot
.56646 .39546 Mdot
.57687 .53639 Mdot
.34044 .43849 Mdot
.39276 .63763 Mdot
.68741 .51108 Mdot
.32693 .44927 Mdot
.54163 .68394 Mdot
.54527 .36367 Mdot
.56092 .65353 Mdot
.75023 .53259 Mdot
.28465 .4832 Mdot
.69439 .5303 Mdot
.53545 .62247 Mdot
.6506 .52226 Mdot
.5508 .82445 Mdot
.44587 .64035 Mdot
.30024 .30948 Mdot
.63934 .47038 Mdot
.28479 .47107 Mdot
.75397 .5347 Mdot
.54796 .42154 Mdot
.54292 .36267 Mdot
.64709 .48535 Mdot
.28946 .47098 Mdot
.72823 .73807 Mdot
.60695 .36463 Mdot
.43854 .56602 Mdot
.43238 .60291 Mdot
.62554 .18284 Mdot
.44771 .57734 Mdot
.62433 .83054 Mdot
.58794 .42328 Mdot
.55236 .59989 Mdot
.52721 .40669 Mdot
.49495 .69066 Mdot
.66249 .50395 Mdot
.50604 .65701 Mdot
.47098 .41477 Mdot
.5777 .64173 Mdot
.54517 .35146 Mdot
.56622 .52154 Mdot
.54337 .47785 Mdot
.64535 .49487 Mdot
.60877 .75266 Mdot
.29904 .48878 Mdot
.68178 .49849 Mdot
.58652 .66885 Mdot
.65718 .306 Mdot
.49478 .42024 Mdot
.56536 .34052 Mdot
.60238 .55959 Mdot
.31654 .48201 Mdot
.54523 .62901 Mdot
.37088 .62663 Mdot
.68594 .51944 Mdot
.50997 .35996 Mdot
.54265 .42837 Mdot
.47532 .72295 Mdot
.41281 .64975 Mdot
.5587 .60312 Mdot
.41691 .61278 Mdot
.6102 .64262 Mdot
.48214 .4145 Mdot
.60209 .64185 Mdot
.58221 .39513 Mdot
.46733 .68097 Mdot
.28318 .31357 Mdot
.37928 .32744 Mdot
.58384 .65466 Mdot
.61378 .25942 Mdot
.41472 .64644 Mdot
.39444 .60879 Mdot
.23668 .67728 Mdot
.26436 .3631 Mdot
.40563 .20717 Mdot
.80084 .53421 Mdot
.40202 .65886 Mdot
.40324 .64579 Mdot
.56352 .65517 Mdot
.34154 .45921 Mdot
.33219 .49318 Mdot
.61064 .63883 Mdot
.71958 .43232 Mdot
.32479 .48082 Mdot
.80943 .59707 Mdot
.48822 .20163 Mdot
.58167 .37999 Mdot
.59615 .68821 Mdot
.67642 .51847 Mdot
.7118 .41621 Mdot
.57334 .52191 Mdot
.56782 .38151 Mdot
.72681 .35173 Mdot
.57237 .6178 Mdot
.43028 .4615 Mdot
.81636 .45713 Mdot
.55111 .34975 Mdot
.55215 .38959 Mdot
.52889 .39915 Mdot
.70658 .5006 Mdot
.27406 .37921 Mdot
.56332 .39071 Mdot
.71942 .43438 Mdot
.4883 .36827 Mdot
.50951 .48078 Mdot
.67664 .50875 Mdot
.61851 .32043 Mdot
.74801 .6113 Mdot
.49846 .17382 Mdot
.57712 .4745 Mdot
.36963 .62667 Mdot
.73699 .52475 Mdot
.40543 .60786 Mdot
.3447 .33002 Mdot
.63905 .34838 Mdot
.31633 .49936 Mdot
.56875 .38482 Mdot
.58741 .65009 Mdot
.29064 .47221 Mdot
.48379 .74876 Mdot
.15308 .33402 Mdot
.36705 .6295 Mdot
.71244 .79983 Mdot
.37768 .61455 Mdot
.60845 .63132 Mdot
.32065 .45714 Mdot
.45216 .31124 Mdot
.36317 .52823 Mdot
.32669 .44641 Mdot
.72432 .71351 Mdot
.27573 .4926 Mdot
.6373 .28772 Mdot
.27596 .46127 Mdot
.39908 .64061 Mdot
.39383 .69471 Mdot
.47015 .32364 Mdot
.54225 .42029 Mdot
.43227 .52065 Mdot
.64984 .27846 Mdot
.54938 .42045 Mdot
.59113 .64547 Mdot
.28143 .32466 Mdot
.71914 .35672 Mdot
.33617 .46516 Mdot
.44973 .65081 Mdot
.5555 .38352 Mdot
.49196 .39848 Mdot
.49677 .42477 Mdot
.25098 .30606 Mdot
.78655 .66579 Mdot
.49139 .42458 Mdot
.48116 .37818 Mdot
.57975 .64569 Mdot
.66074 .46487 Mdot
.61648 .7321 Mdot
.40494 .23305 Mdot
.56286 .35942 Mdot
.68024 .50147 Mdot
.71216 .49763 Mdot
.51029 .43702 Mdot
.61083 .5313 Mdot
.25567 .55376 Mdot
.55434 .39899 Mdot
.28272 .32686 Mdot
.62422 .58275 Mdot
.57988 .5996 Mdot
.5943 .61978 Mdot
.3276 .48603 Mdot
.59831 .61634 Mdot
.59655 .66675 Mdot
.44821 .324 Mdot
.49885 .55006 Mdot
.46239 .61947 Mdot
.6634 .51221 Mdot
.51638 .39698 Mdot
.52785 .29753 Mdot
.25439 .58104 Mdot
.42334 .60904 Mdot
.29662 .44415 Mdot
.36803 .65441 Mdot
.71876 .53665 Mdot
.30762 .51815 Mdot
.56767 .61337 Mdot
.3921 .65582 Mdot
.38986 .67209 Mdot
.68111 .50405 Mdot
.43315 .63743 Mdot
.3715 .67026 Mdot
.48274 .35152 Mdot
.38885 .36283 Mdot
.52419 .38132 Mdot
.64524 .77701 Mdot
.40375 .65063 Mdot
.42628 .69494 Mdot
.54434 .39976 Mdot
.59049 .62231 Mdot
.446 .34616 Mdot
.53772 .42402 Mdot
.59232 .61389 Mdot
.51556 .44346 Mdot
.65714 .53118 Mdot
.36922 .44954 Mdot
.36979 .52216 Mdot
.17062 .63212 Mdot
.69164 .48443 Mdot
.48658 .74392 Mdot
.57189 .38844 Mdot
.45841 .82548 Mdot
.32813 .45197 Mdot
.55036 .43336 Mdot
.69787 .33752 Mdot
.34123 .44452 Mdot
.30715 .44425 Mdot
.49737 .38987 Mdot
.41667 .61621 Mdot
.59592 .63893 Mdot
.68055 .50887 Mdot
.61566 .82045 Mdot
.53933 .37746 Mdot
.53496 .35331 Mdot
.67664 .49584 Mdot
.41852 .64746 Mdot
.51868 .43872 Mdot
.77018 .48159 Mdot
.75171 .7236 Mdot
.38578 .60898 Mdot
.55176 .34145 Mdot
.33636 .35665 Mdot
.61067 .4176 Mdot
.40468 .83962 Mdot
.60722 .5185 Mdot
.57239 .64441 Mdot
.54851 .31741 Mdot
.19351 .31947 Mdot
.68874 .51309 Mdot
.4077 .19934 Mdot
.49057 .39557 Mdot
.51043 .35438 Mdot
.28441 .45451 Mdot
.5152 .37294 Mdot
.3052 .43079 Mdot
.16589 .58863 Mdot
.63722 .2112 Mdot
.34154 .48023 Mdot
.28497 .47527 Mdot
.67927 .29646 Mdot
.54947 .71379 Mdot
.31433 .45747 Mdot
.47919 .39629 Mdot
.62525 .41506 Mdot
.40616 .44046 Mdot
.66525 .47662 Mdot
.7588 .56468 Mdot
.5827 .32144 Mdot
.65154 .54719 Mdot
.76872 .61976 Mdot
.57728 .31249 Mdot
.48705 .60435 Mdot
.37797 .61967 Mdot
.5523 .35042 Mdot
.55527 .60789 Mdot
.56624 .60401 Mdot
.57709 .42281 Mdot
.50947 .40018 Mdot
.34455 .4348 Mdot
.67504 .52451 Mdot
.36585 .64067 Mdot
.50699 .35838 Mdot
.69267 .31661 Mdot
.67728 .52798 Mdot
.34554 .46704 Mdot
.3493 .28039 Mdot
.64333 .52347 Mdot
.46231 .42015 Mdot
.5487 .40918 Mdot
.51017 .38597 Mdot
.48138 .3136 Mdot
.38868 .61945 Mdot
.76087 .54447 Mdot
.50619 .3411 Mdot
.57842 .19209 Mdot
.44703 .60104 Mdot
.46976 .35732 Mdot
.3522 .46996 Mdot
.45855 .64125 Mdot
.59185 .67985 Mdot
.27841 .51579 Mdot
.53929 .36828 Mdot
.58561 .77925 Mdot
.32642 .74958 Mdot
.54573 .66529 Mdot
.36491 .43779 Mdot
.6698 .51496 Mdot
.51788 .3882 Mdot
.32441 .31214 Mdot
.52567 .41847 Mdot
.64938 .54178 Mdot
.55256 .66201 Mdot
.38005 .61773 Mdot
.62201 .78769 Mdot
.58236 .60374 Mdot
.307 .44715 Mdot
.74106 .27705 Mdot
.30601 .42967 Mdot
.33397 .4912 Mdot
.36362 .27608 Mdot
.38937 .61795 Mdot
.16846 .35164 Mdot
.1805 .59936 Mdot
.47094 .37519 Mdot
.41787 .64508 Mdot
.30838 .46394 Mdot
.50068 .35617 Mdot
.33205 .50291 Mdot
.36242 .46258 Mdot
.47848 .40324 Mdot
.52611 .34634 Mdot
.47336 .7926 Mdot
.82025 .48061 Mdot
.66836 .51435 Mdot
.34953 .43492 Mdot
.35761 .54562 Mdot
.5025 .3535 Mdot
.53801 .40582 Mdot
.37144 .71662 Mdot
.68479 .4832 Mdot
.32922 .5855 Mdot
.49134 .39721 Mdot
.66455 .24049 Mdot
.47647 .44867 Mdot
.31077 .42045 Mdot
.40356 .60613 Mdot
.50994 .17682 Mdot
.3455 .6418 Mdot
.30435 .43211 Mdot
.68946 .52218 Mdot
.3129 .41188 Mdot
.66225 .27288 Mdot
.41663 .65412 Mdot
.29193 .45549 Mdot
.52454 .58185 Mdot
.39555 .62541 Mdot
.39768 .65334 Mdot
.37712 .26427 Mdot
.53641 .65762 Mdot
.70828 .50133 Mdot
.40018 .64698 Mdot
.22289 .53095 Mdot
.39589 .63502 Mdot
.19056 .61695 Mdot
.55424 .34651 Mdot
.73202 .40931 Mdot
.51904 .68173 Mdot
.52875 .31044 Mdot
.40568 .65353 Mdot
.67188 .48408 Mdot
.49848 .42197 Mdot
.33368 .47683 Mdot
.65536 .52224 Mdot
.35888 .58096 Mdot
.56035 .64349 Mdot
.35269 .45378 Mdot
.35996 .61352 Mdot
.30018 .47632 Mdot
.24679 .50863 Mdot
.27289 .73203 Mdot
.73039 .32397 Mdot
.35587 .53333 Mdot
.49302 .41824 Mdot
.78523 .57478 Mdot
.56586 .34649 Mdot
.50492 .40252 Mdot
.59387 .6473 Mdot
.72796 .38594 Mdot
.32133 .46131 Mdot
.68645 .76362 Mdot
.37278 .64035 Mdot
.50947 .17211 Mdot
.59533 .45992 Mdot
.54559 .44337 Mdot
.3376 .43587 Mdot
.2894 .43727 Mdot
.3756 .3034 Mdot
.60168 .67513 Mdot
.57375 .40591 Mdot
.54945 .33216 Mdot
.56204 .44287 Mdot
.37653 .64142 Mdot
.62433 .54449 Mdot
.55236 .62608 Mdot
.33736 .78592 Mdot
.549 .65932 Mdot
.64209 .53986 Mdot
.33924 .46425 Mdot
.69355 .52434 Mdot
.54023 .40577 Mdot
.32669 .51008 Mdot
.28377 .4441 Mdot
.64394 .49229 Mdot
.65948 .48883 Mdot
.43677 .74513 Mdot
.40274 .61506 Mdot
.53158 .4303 Mdot
.56438 .38495 Mdot
.51083 .3693 Mdot
.50357 .39554 Mdot
.36826 .63469 Mdot
.5049 .4279 Mdot
.35113 .63944 Mdot
.23091 .47404 Mdot
.76319 .44114 Mdot
.51913 .54639 Mdot
.26857 .67492 Mdot
.33362 .47166 Mdot
.2299 .53795 Mdot
.60538 .38613 Mdot
.2063 .37028 Mdot
.38407 .78551 Mdot
.493 .34755 Mdot
.60113 .65035 Mdot
.43808 .43262 Mdot
.56233 .60984 Mdot
.61618 .84499 Mdot
.45159 .71198 Mdot
.82938 .50757 Mdot
.55992 .37107 Mdot
.57119 .53872 Mdot
.20838 .54279 Mdot
.56482 .34313 Mdot
.45373 .72739 Mdot
.2721 .66892 Mdot
.59768 .75968 Mdot
.68545 .48793 Mdot
.54857 .37153 Mdot
.51093 .30127 Mdot
.56473 .39717 Mdot
.53164 .40763 Mdot
.50072 .42671 Mdot
.36368 .61601 Mdot
.55719 .4257 Mdot
.50132 .41866 Mdot
.65968 .66377 Mdot
.63649 .31204 Mdot
.54229 .61437 Mdot
.25928 .70153 Mdot
.69389 .52487 Mdot
.3439 .43781 Mdot
.78285 .65869 Mdot
.41445 .6178 Mdot
.38189 .30088 Mdot
.50637 .39132 Mdot
.51057 .78837 Mdot
.41154 .67 Mdot
.69254 .51619 Mdot
.57 .67691 Mdot
.84106 .52823 Mdot
.58797 .64417 Mdot
.45649 .67024 Mdot
.5907 .62504 Mdot
.60376 .36758 Mdot
.34512 .43455 Mdot
.52249 .43466 Mdot
.39314 .64516 Mdot
.60262 .62562 Mdot
.67898 .3738 Mdot
.52466 .39608 Mdot
.58336 .63701 Mdot
.52241 .43431 Mdot
.35658 .51531 Mdot
.45368 .21946 Mdot
.59532 .66613 Mdot
.40823 .66973 Mdot
.38288 .63199 Mdot
.69819 .496 Mdot
.34824 .44637 Mdot
.29874 .43919 Mdot
.40908 .62737 Mdot
.23542 .39308 Mdot
.56613 .36288 Mdot
.51083 .3498 Mdot
.53496 .18078 Mdot
.56644 .40348 Mdot
.64995 .30293 Mdot
.54332 .56363 Mdot
.34028 .4725 Mdot
.53944 .44707 Mdot
.49394 .38815 Mdot
.54098 .36533 Mdot
.24335 .47432 Mdot
.5821 .61356 Mdot
.55239 .34849 Mdot
.6554 .49224 Mdot
.64384 .6558 Mdot
.48951 .37236 Mdot
.4491 .42434 Mdot
.29709 .4408 Mdot
.2952 .25039 Mdot
.37986 .61407 Mdot
.58749 .66718 Mdot
.58318 .65598 Mdot
.76489 .57262 Mdot
.23731 .6008 Mdot
.54536 .56147 Mdot
.36979 .80965 Mdot
.47386 .67849 Mdot
.65723 .50064 Mdot
.62861 .63707 Mdot
.38536 .69821 Mdot
.57416 .66234 Mdot
.36609 .63184 Mdot
.54858 .3418 Mdot
.56153 .35711 Mdot
.17659 .39772 Mdot
.51113 .43868 Mdot
.67362 .51526 Mdot
.3676 .61 Mdot
.32853 .47585 Mdot
.6905 .5184 Mdot
.41733 .61212 Mdot
.33281 .48265 Mdot
.50254 .33974 Mdot
.50973 .33758 Mdot
.29902 .44246 Mdot
.2881 .46098 Mdot
.54775 .40639 Mdot
.59307 .72546 Mdot
.28875 .47796 Mdot
.29343 .46021 Mdot
.56453 .61592 Mdot
.56081 .60619 Mdot
.44982 .40703 Mdot
.4135 .64388 Mdot
.50164 .42075 Mdot
.58283 .64917 Mdot
.69539 .52137 Mdot
.32373 .46312 Mdot
.48665 .40257 Mdot
.49373 .37234 Mdot
.68244 .50517 Mdot
.69897 .50595 Mdot
.68034 .48817 Mdot
.35516 .62401 Mdot
.51795 .36424 Mdot
.31882 .4523 Mdot
.39647 .61432 Mdot
.71183 .49889 Mdot
.66564 .47847 Mdot
.62342 .65949 Mdot
.56317 .41238 Mdot
.5695 .70979 Mdot
.2093 .29264 Mdot
.58935 .21 Mdot
.56954 .68128 Mdot
.5898 .68267 Mdot
.65418 .38463 Mdot
.43324 .47424 Mdot
.4191 .63267 Mdot
.66028 .46378 Mdot
.69067 .29722 Mdot
.49884 .33698 Mdot
.47912 .37583 Mdot
.47929 .43561 Mdot
.67341 .48706 Mdot
.73955 .39155 Mdot
.31477 .42754 Mdot
.57067 .29183 Mdot
.67199 .529 Mdot
.53705 .61772 Mdot
.62071 .673 Mdot
.55222 .66355 Mdot
.53378 .33642 Mdot
.38934 .32556 Mdot
.22977 .5665 Mdot
.78844 .51861 Mdot
.41021 .65181 Mdot
.52944 .29785 Mdot
.45551 .82195 Mdot
.30393 .44207 Mdot
.61483 .63506 Mdot
.65581 .49948 Mdot
.28943 .46365 Mdot
.37881 .66202 Mdot
.40028 .64533 Mdot
.56234 .6215 Mdot
.55954 .62659 Mdot
.55978 .66005 Mdot
.3626 .46516 Mdot
.33972 .46187 Mdot
.53664 .36808 Mdot
.32721 .46547 Mdot
.22564 .3418 Mdot
.64761 .479 Mdot
.52994 .6091 Mdot
.40927 .63869 Mdot
.32398 .48388 Mdot
.52451 .39318 Mdot
.41978 .46017 Mdot
.30313 .66709 Mdot
.64957 .51048 Mdot
.43875 .21394 Mdot
.59676 .84598 Mdot
.53576 .42952 Mdot
.38217 .62454 Mdot
.3155 .25527 Mdot
.53001 .39659 Mdot
.55117 .64413 Mdot
.65675 .72167 Mdot
.63438 .63253 Mdot
.53517 .42493 Mdot
.49451 .33773 Mdot
.37232 .61561 Mdot
.35355 .79079 Mdot
.53672 .3725 Mdot
.32785 .56891 Mdot
.42805 .65985 Mdot
.54846 .63222 Mdot
.83445 .62841 Mdot
.71714 .55028 Mdot
.71737 .42342 Mdot
.55812 .6221 Mdot
.50978 .41508 Mdot
.56955 .6097 Mdot
.65172 .50045 Mdot
.58301 .67416 Mdot
.30706 .42775 Mdot
.54141 .65245 Mdot
.53472 .35272 Mdot
.31184 .45789 Mdot
.41461 .6356 Mdot
.47725 .18235 Mdot
.67828 .68895 Mdot
.58852 .62098 Mdot
.60234 .65577 Mdot
.53128 .4469 Mdot
.3343 .59336 Mdot
.58128 .40663 Mdot
.53251 .34148 Mdot
.40756 .65883 Mdot
.34321 .44395 Mdot
.3922 .60518 Mdot
.46742 .3458 Mdot
.77769 .45033 Mdot
.41265 .61164 Mdot
.57605 .77291 Mdot
.67006 .49531 Mdot
.49237 .51298 Mdot
.51909 .39333 Mdot
.43451 .6297 Mdot
.52034 .36461 Mdot
.32367 .427 Mdot
.52303 .53139 Mdot
.57244 .75291 Mdot
.38683 .64626 Mdot
.60105 .7834 Mdot
.75755 .46519 Mdot
.44612 .39097 Mdot
.39556 .60783 Mdot
.70717 .34926 Mdot
.60836 .62953 Mdot
.6587 .52225 Mdot
.64622 .52289 Mdot
.66424 .52927 Mdot
.58583 .41071 Mdot
.58538 .46951 Mdot
.69322 .53222 Mdot
.37736 .6592 Mdot
.64546 .49507 Mdot
.20883 .59435 Mdot
.69098 .75812 Mdot
.66486 .50219 Mdot
.54717 .38454 Mdot
.57922 .45469 Mdot
.64386 .35009 Mdot
.46184 .76288 Mdot
.82831 .52443 Mdot
.35055 .73003 Mdot
.53815 .4204 Mdot
.36177 .47377 Mdot
.36164 .44735 Mdot
.33521 .231 Mdot
.63571 .26888 Mdot
.6182 .21669 Mdot
.3003 .49124 Mdot
.53787 .73004 Mdot
.34859 .4629 Mdot
.50375 .4331 Mdot
.50699 .35193 Mdot
.29867 .49171 Mdot
.76268 .42016 Mdot
.52571 .73772 Mdot
.61968 .803 Mdot
.29401 .47022 Mdot
.42242 .61156 Mdot
.43849 .61632 Mdot
.39998 .6543 Mdot
.46442 .20014 Mdot
.33097 .43536 Mdot
.50357 .36828 Mdot
.58566 .65443 Mdot
.55906 .35785 Mdot
.39754 .62281 Mdot
.69798 .75857 Mdot
.33085 .44387 Mdot
.55919 .38422 Mdot
.43982 .37293 Mdot
.55841 .6336 Mdot
.67527 .49954 Mdot
.38102 .49995 Mdot
.61818 .22089 Mdot
.37932 .64793 Mdot
.28763 .48534 Mdot
.44249 .6939 Mdot
.64294 .76834 Mdot
.58557 .42958 Mdot
.54235 .32855 Mdot
.61217 .82555 Mdot
.67282 .25548 Mdot
.57292 .40015 Mdot
.59442 .66238 Mdot
.4888 .71649 Mdot
.48792 .38156 Mdot
.35763 .44021 Mdot
.64486 .52467 Mdot
.65087 .52137 Mdot
.44891 .40668 Mdot
.39435 .51023 Mdot
.55439 .53262 Mdot
.50338 .38644 Mdot
.46469 .42253 Mdot
.55093 .62926 Mdot
.48455 .68168 Mdot
.58598 .19532 Mdot
.69482 .519 Mdot
.52106 .43572 Mdot
.71894 .70203 Mdot
.28201 .45426 Mdot
.5498 .66923 Mdot
.42809 .64655 Mdot
.25009 .46407 Mdot
.5727 .67738 Mdot
.48242 .39812 Mdot
.51358 .438 Mdot
.42695 .60867 Mdot
.3095 .42139 Mdot
.67209 .48814 Mdot
.59353 .65361 Mdot
.6962 .50112 Mdot
.33917 .44276 Mdot
.3322 .46196 Mdot
.44037 .37873 Mdot
.59447 .41902 Mdot
.59779 .62352 Mdot
.58314 .39311 Mdot
.63727 .64811 Mdot
.44945 .85264 Mdot
.40842 .59557 Mdot
.55492 .42355 Mdot
.27615 .44466 Mdot
.38223 .64583 Mdot
.51589 .35084 Mdot
.64142 .81891 Mdot
.49659 .35755 Mdot
.45104 .61405 Mdot
.71599 .29154 Mdot
.68918 .49379 Mdot
.58345 .30343 Mdot
.44222 .79398 Mdot
.56279 .40702 Mdot
.57462 .65719 Mdot
.54463 .46303 Mdot
.42195 .62066 Mdot
.33704 .46492 Mdot
.43352 .85675 Mdot
.39165 .63443 Mdot
.55991 .40067 Mdot
.68757 .5192 Mdot
.27731 .45094 Mdot
.61224 .49455 Mdot
.61254 .53549 Mdot
.48687 .46547 Mdot
.5711 .41709 Mdot
.49752 .39875 Mdot
.77895 .48713 Mdot
.58428 .66765 Mdot
.29997 .4645 Mdot
.37941 .62664 Mdot
.4132 .6283 Mdot
.5688 .61806 Mdot
.46532 .60795 Mdot
.49122 .51349 Mdot
.30152 .2119 Mdot
.58592 .60858 Mdot
.68611 .53113 Mdot
.33591 .57775 Mdot
.58856 .65934 Mdot
.58228 .63286 Mdot
.56256 .616 Mdot
.50164 .60099 Mdot
.32268 .48242 Mdot
.4818 .39551 Mdot
.33838 .42451 Mdot
.50791 .41593 Mdot
.45217 .61635 Mdot
.39178 .64734 Mdot
.33493 .44713 Mdot
.58319 .82255 Mdot
.3717 .37768 Mdot
.53878 .39329 Mdot
.45918 .82489 Mdot
.47491 .41699 Mdot
.65543 .3544 Mdot
.48632 .43571 Mdot
.57777 .61999 Mdot
.57604 .34581 Mdot
.56987 .43877 Mdot
.37166 .20836 Mdot
.41251 .64035 Mdot
.58699 .59988 Mdot
.46373 .39403 Mdot
.47019 .43081 Mdot
.35802 .47448 Mdot
.29046 .46312 Mdot
.64882 .52468 Mdot
.61216 .29169 Mdot
.41765 .63682 Mdot
.17783 .55152 Mdot
.54373 .41851 Mdot
.65958 .55724 Mdot
.502 .24849 Mdot
.52022 .34945 Mdot
.46392 .80634 Mdot
.3868 .31951 Mdot
.51816 .38979 Mdot
.44203 .54914 Mdot
.4138 .64771 Mdot
.7762 .41768 Mdot
.4854 .37489 Mdot
.55568 .63852 Mdot
.34336 .46236 Mdot
.28363 .44061 Mdot
.6646 .5332 Mdot
.19246 .40807 Mdot
.39465 .60384 Mdot
.33759 .45624 Mdot
.52126 .40124 Mdot
.38252 .62163 Mdot
.59266 .61011 Mdot
.54537 .44164 Mdot
.6225 .25662 Mdot
.32538 .47107 Mdot
.50939 .44324 Mdot
.3078 .55907 Mdot
.67759 .41567 Mdot
.75352 .32036 Mdot
.37709 .62892 Mdot
.69487 .49312 Mdot
.51577 .46088 Mdot
.25335 .3775 Mdot
.5116 .45103 Mdot
.73681 .42913 Mdot
.21374 .60642 Mdot
.6876 .48626 Mdot
.54621 .39562 Mdot
.50729 .36202 Mdot
.49182 .48953 Mdot
.6916 .52234 Mdot
.5624 .37511 Mdot
.24693 .43007 Mdot
.30943 .47862 Mdot
.61322 .63653 Mdot
.32462 .47787 Mdot
.54264 .38507 Mdot
.59081 .42801 Mdot
.28546 .4559 Mdot
.47326 .84351 Mdot
.65196 .47087 Mdot
.38895 .61155 Mdot
.47269 .3955 Mdot
.50638 .34414 Mdot
.53959 .14132 Mdot
.54104 .6587 Mdot
.59371 .73172 Mdot
.65495 .59359 Mdot
.75066 .65591 Mdot
.72071 .54778 Mdot
.81546 .41141 Mdot
.67814 .25916 Mdot
.5559 .42744 Mdot
.61943 .39286 Mdot
.25901 .53347 Mdot
.41363 .65269 Mdot
.19729 .48897 Mdot
.54233 .42051 Mdot
.52902 .40785 Mdot
.57308 .68297 Mdot
.54618 .76688 Mdot
.61645 .21467 Mdot
.41743 .46981 Mdot
.67405 .4891 Mdot
.35231 .43861 Mdot
.48071 .39727 Mdot
.47227 .55815 Mdot
.53523 .62085 Mdot
.71818 .54291 Mdot
.55798 .38728 Mdot
.23768 .34533 Mdot
.28942 .6489 Mdot
.39722 .61721 Mdot
.58159 .65696 Mdot
.6339 .22516 Mdot
.55769 .41782 Mdot
.43385 .63958 Mdot
.53507 .38002 Mdot
.53432 .5892 Mdot
.47389 .33807 Mdot
.65838 .50634 Mdot
.48998 .40088 Mdot
.72961 .53184 Mdot
.66484 .181 Mdot
.69063 .5372 Mdot
.31323 .50159 Mdot
.53677 .60501 Mdot
.58592 .61367 Mdot
.28947 .45945 Mdot
.58969 .61653 Mdot
.39405 .28017 Mdot
.48653 .2838 Mdot
.67106 .49292 Mdot
.46152 .42844 Mdot
.66903 .50406 Mdot
.55036 .67148 Mdot
.53759 .42247 Mdot
.51624 .86215 Mdot
.60066 .63272 Mdot
.68572 .25103 Mdot
.39795 .63339 Mdot
.53451 .62055 Mdot
.48811 .36926 Mdot
.42149 .70172 Mdot
.58 .6037 Mdot
.54954 .75057 Mdot
.54036 .36563 Mdot
.33076 .4698 Mdot
.49084 .37868 Mdot
.47127 .37879 Mdot
.54908 .60332 Mdot
.50986 .42359 Mdot
.4186 .61268 Mdot
.3157 .49215 Mdot
.82335 .58069 Mdot
.25562 .64703 Mdot
.56682 .38321 Mdot
.5237 .40012 Mdot
.33617 .41317 Mdot
.53149 .33818 Mdot
.36829 .63402 Mdot
.12747 .61149 Mdot
.67044 .49556 Mdot
.58262 .59543 Mdot
.72825 .54316 Mdot
.49472 .34419 Mdot
.5013 .42495 Mdot
.66986 .80643 Mdot
.77358 .45116 Mdot
.40416 .60822 Mdot
.56065 .44465 Mdot
.59039 .60755 Mdot
.68121 .52028 Mdot
.37306 .65355 Mdot
.51155 .38454 Mdot
.54201 .40285 Mdot
.70043 .50223 Mdot
.62596 .42781 Mdot
.51227 .199 Mdot
.43707 .62381 Mdot
.5731 .33143 Mdot
.52725 .66393 Mdot
.57151 .37172 Mdot
.43543 .2045 Mdot
.29423 .45441 Mdot
.38364 .65175 Mdot
.76826 .59967 Mdot
.55809 .41985 Mdot
.4107 .6063 Mdot
.41736 .63785 Mdot
.53836 .44995 Mdot
.27021 .45495 Mdot
.32736 .48865 Mdot
.30502 .47939 Mdot
.15055 .43638 Mdot
.70416 .4018 Mdot
.55961 .65991 Mdot
.41512 .64783 Mdot
.60249 .65925 Mdot
.64546 .54042 Mdot
.53245 .56174 Mdot
.60015 .66039 Mdot
.31052 .48405 Mdot
.55566 .59407 Mdot
.523 .35835 Mdot
.41602 .63481 Mdot
.5698 .66134 Mdot
.47323 .36953 Mdot
.34531 .58064 Mdot
.40335 .75833 Mdot
.66377 .48096 Mdot
.649 .52961 Mdot
.49772 .3606 Mdot
.60569 .66699 Mdot
.54516 .40747 Mdot
.42018 .65846 Mdot
.3446 .57546 Mdot
.47346 .39344 Mdot
.58665 .6191 Mdot
.32476 .41114 Mdot
.62575 .22425 Mdot
.58798 .379 Mdot
.54714 .38596 Mdot
.51037 .41992 Mdot
.5348 .37956 Mdot
.64356 .75951 Mdot
.4435 .61696 Mdot
.26787 .67199 Mdot
.75695 .53781 Mdot
.32528 .44167 Mdot
.34379 .42445 Mdot
.57553 .20146 Mdot
.26213 .5433 Mdot
.41351 .64482 Mdot
.50434 .39996 Mdot
.2619 .60322 Mdot
.75139 .72263 Mdot
.58954 .83661 Mdot
.49833 .48512 Mdot
.53598 .65068 Mdot
.2902 .48641 Mdot
.60577 .62752 Mdot
.51545 .41695 Mdot
.48251 .44029 Mdot
.80542 .3727 Mdot
.39537 .66485 Mdot
.66602 .49323 Mdot
.50544 .41604 Mdot
.70516 .40739 Mdot
.57953 .64744 Mdot
.53575 .61558 Mdot
.54542 .34422 Mdot
.30441 .41923 Mdot
.63961 .1792 Mdot
.38779 .62017 Mdot
.34551 .7191 Mdot
.20691 .54709 Mdot
.31769 .66824 Mdot
.39516 .62155 Mdot
.54245 .49432 Mdot
.55978 .67671 Mdot
.49603 .24048 Mdot
.32068 .43816 Mdot
.65393 .51992 Mdot
.47464 .35013 Mdot
.28906 .44626 Mdot
.54582 .65042 Mdot
.33441 .46713 Mdot
.49883 .42443 Mdot
.44353 .64582 Mdot
.5709 .64585 Mdot
.46211 .61648 Mdot
.27775 .43908 Mdot
.69112 .52088 Mdot
.42626 .49391 Mdot
.3964 .41704 Mdot
.38655 .31611 Mdot
.55096 .34593 Mdot
.47642 .56437 Mdot
.50514 .36877 Mdot
.35733 .4283 Mdot
.52814 .38944 Mdot
.37158 .42599 Mdot
.57424 .65606 Mdot
.48158 .37792 Mdot
.50208 .39006 Mdot
.21064 .64054 Mdot
.55613 .37132 Mdot
.58048 .39787 Mdot
.51464 .39084 Mdot
.35926 .497 Mdot
.46558 .43457 Mdot
.35456 .46722 Mdot
.64423 .68 Mdot
.58043 .63038 Mdot
.64359 .51352 Mdot
.70115 .4977 Mdot
.72553 .39582 Mdot
.74328 .59587 Mdot
.52042 .77646 Mdot
.31684 .47603 Mdot
.42817 .62329 Mdot
.53003 .38501 Mdot
.81352 .4572 Mdot
.61354 .56581 Mdot
.53574 .62578 Mdot
.25815 .64918 Mdot
.55643 .31713 Mdot
.78169 .40427 Mdot
.56248 .44113 Mdot
.16831 .41971 Mdot
.5965 .37036 Mdot
.4971 .32629 Mdot
.60841 .61627 Mdot
.69479 .54728 Mdot
.52037 .34074 Mdot
.35108 .48221 Mdot
.65851 .51706 Mdot
.60353 .44508 Mdot
.56916 .70528 Mdot
.63438 .69319 Mdot
.38753 .45587 Mdot
.52828 .36627 Mdot
.57023 .64464 Mdot
.35249 .45114 Mdot
.59514 .20034 Mdot
.39447 .61407 Mdot
.44976 .59423 Mdot
.30817 .53766 Mdot
.4846 .8384 Mdot
.67891 .52811 Mdot
.46053 .23154 Mdot
.53147 .3532 Mdot
.64622 .71653 Mdot
.47456 .40027 Mdot
.7085 .75345 Mdot
.69685 .52496 Mdot
.30973 .48577 Mdot
.42604 .61432 Mdot
.35435 .43722 Mdot
.37486 .32153 Mdot
.59984 .68802 Mdot
.48656 .53754 Mdot
.58724 .64166 Mdot
.58343 .52241 Mdot
.30602 .46034 Mdot
.51939 .43379 Mdot
.29713 .21375 Mdot
.29335 .45818 Mdot
.27735 .45862 Mdot
.30975 .7532 Mdot
.48082 .86154 Mdot
.56822 .33405 Mdot
.28707 .47767 Mdot
.5886 .63588 Mdot
.6672 .51664 Mdot
.48639 .38888 Mdot
.5301 .36232 Mdot
.29083 .44549 Mdot
.55927 .59904 Mdot
.30759 .35444 Mdot
.56408 .62423 Mdot
.32006 .48287 Mdot
.56925 .63042 Mdot
.43748 .69068 Mdot
.59135 .66165 Mdot
.50763 .34322 Mdot
.52857 .38824 Mdot
.71818 .5809 Mdot
.33186 .46294 Mdot
.50377 .38465 Mdot
.53162 .44634 Mdot
.31794 .45511 Mdot
.58531 .49966 Mdot
.31788 .34967 Mdot
.57046 .38216 Mdot
.54839 .36643 Mdot
.69048 .48907 Mdot
.50509 .57377 Mdot
.44649 .22308 Mdot
.49738 .42002 Mdot
.70611 .50107 Mdot
.34717 .48431 Mdot
.55362 .40094 Mdot
.76306 .68796 Mdot
.49274 .71817 Mdot
.53917 .42653 Mdot
.60816 .63001 Mdot
.56743 .44007 Mdot
.7411 .30412 Mdot
.5305 .34132 Mdot
.31463 .46309 Mdot
.3425 .45234 Mdot
.17945 .5733 Mdot
.306 .44917 Mdot
.55434 .60908 Mdot
.39676 .62424 Mdot
.63625 .77921 Mdot
.59581 .6129 Mdot
.59471 .38941 Mdot
.18816 .64187 Mdot
.53634 .43898 Mdot
.48625 .35595 Mdot
.68869 .23467 Mdot
.60403 .63001 Mdot
.33276 .43139 Mdot
.44625 .48721 Mdot
.59904 .41271 Mdot
.38853 .65351 Mdot
.46214 .36983 Mdot
.55074 .34145 Mdot
.70965 .27827 Mdot
.6517 .74558 Mdot
.43043 .64899 Mdot
.57948 .39185 Mdot
.49853 .42186 Mdot
.54242 .67214 Mdot
.52111 .3969 Mdot
.66438 .51393 Mdot
.33471 .43656 Mdot
.59556 .65687 Mdot
.68486 .5053 Mdot
.55568 .41573 Mdot
.67745 .4878 Mdot
.56061 .65367 Mdot
.42327 .65203 Mdot
.52524 .42084 Mdot
.66295 .47689 Mdot
.67721 .48855 Mdot
.50515 .37149 Mdot
.3382 .46699 Mdot
.57644 .32391 Mdot
.55892 .37441 Mdot
.48753 .40471 Mdot
.30062 .43761 Mdot
.82022 .68345 Mdot
.51088 .34901 Mdot
.74692 .43534 Mdot
.28842 .43949 Mdot
.58579 .51427 Mdot
.60561 .61868 Mdot
.54695 .33944 Mdot
.42263 .65316 Mdot
.42832 .64266 Mdot
.54853 .6604 Mdot
.27966 .47874 Mdot
.66081 .58566 Mdot
.26382 .45538 Mdot
.55522 .45581 Mdot
.5748 .37434 Mdot
.26113 .39917 Mdot
.83309 .49952 Mdot
.33034 .42489 Mdot
.52851 .68736 Mdot
.40332 .49447 Mdot
.43293 .63098 Mdot
.54289 .61288 Mdot
.29374 .49036 Mdot
.31085 .42996 Mdot
.33815 .4746 Mdot
.65085 .517 Mdot
.72142 .58195 Mdot
.29867 .42705 Mdot
.31642 .41568 Mdot
.53704 .36208 Mdot
.49645 .41719 Mdot
.63709 .24037 Mdot
.58728 .24223 Mdot
.66546 .48417 Mdot
.54749 .64414 Mdot
.13816 .43042 Mdot
.41297 .6608 Mdot
.24596 .66838 Mdot
.47966 .36852 Mdot
.15575 .34101 Mdot
.48577 .37773 Mdot
.51862 .40097 Mdot
.31626 .49247 Mdot
.65966 .47925 Mdot
.66931 .50042 Mdot
.29832 .46284 Mdot
.33218 .41784 Mdot
.66401 .51249 Mdot
.4287 .79753 Mdot
.7761 .68407 Mdot
.62942 .61227 Mdot
.32348 .45333 Mdot
.41105 .38995 Mdot
.43484 .61638 Mdot
.58324 .45718 Mdot
.42933 .65662 Mdot
.58087 .64059 Mdot
.57359 .67896 Mdot
.38204 .64822 Mdot
.54075 .36768 Mdot
.56686 .66472 Mdot
.55019 .42914 Mdot
.34955 .7412 Mdot
.37638 .35166 Mdot
.6943 .57072 Mdot
.50127 .4723 Mdot
.57446 .50375 Mdot
.46546 .62008 Mdot
.55571 .40897 Mdot
.758 .66523 Mdot
.66996 .49081 Mdot
.53261 .46617 Mdot
.3881 .65569 Mdot
.71564 .24937 Mdot
.53063 .42331 Mdot
.31744 .46461 Mdot
.41806 .64132 Mdot
.26988 .50826 Mdot
.33314 .5669 Mdot
.50882 .41806 Mdot
.21742 .28955 Mdot
.34011 .50383 Mdot
.58546 .66083 Mdot
.22525 .3883 Mdot
.31954 .42108 Mdot
.72288 .49666 Mdot
.76764 .55608 Mdot
.54887 .83256 Mdot
.34433 .43741 Mdot
.54253 .66559 Mdot
.34769 .47735 Mdot
.68744 .52265 Mdot
.3332 .49802 Mdot
.57643 .65153 Mdot
.55543 .38849 Mdot
.57508 .6173 Mdot
.64718 .50978 Mdot
.51708 .2036 Mdot
.43098 .64782 Mdot
.5909 .60189 Mdot
.38654 .64166 Mdot
.66148 .42277 Mdot
.77275 .49557 Mdot
.38085 .61643 Mdot
.31898 .30468 Mdot
.57059 .36339 Mdot
.31375 .42017 Mdot
.57223 .61437 Mdot
.7289 .6567 Mdot
.42366 .49036 Mdot
.31487 .43892 Mdot
.55114 .65538 Mdot
.34833 .54544 Mdot
.25021 .35522 Mdot
.58131 .40051 Mdot
.63832 .36154 Mdot
.32103 .45097 Mdot
.55577 .67833 Mdot
.52505 .17813 Mdot
.34911 .4775 Mdot
.58131 .60765 Mdot
.42218 .61033 Mdot
.41178 .62519 Mdot
.55763 .35946 Mdot
.45577 .63952 Mdot
.56267 .66924 Mdot
.37872 .57145 Mdot
.28591 .47824 Mdot
.24856 .4887 Mdot
.65677 .47636 Mdot
.57721 .62521 Mdot
.51485 .4409 Mdot
.37357 .45271 Mdot
.47013 .70241 Mdot
.31578 .36508 Mdot
.29522 .24357 Mdot
.56876 .61825 Mdot
.32554 .4336 Mdot
.32017 .46571 Mdot
.58885 .38436 Mdot
.35585 .5318 Mdot
.66501 .589 Mdot
.43487 .4564 Mdot
.4249 .45119 Mdot
.61383 .6366 Mdot
.62632 .6775 Mdot
.46287 .39131 Mdot
.5295 .37118 Mdot
.4328 .62768 Mdot
.55435 .38489 Mdot
.30372 .48892 Mdot
.54915 .34591 Mdot
.38053 .62709 Mdot
.59002 .64528 Mdot
.52966 .42068 Mdot
.68614 .49075 Mdot
.42901 .60734 Mdot
.36974 .65733 Mdot
.58309 .62235 Mdot
.29077 .44415 Mdot
.60334 .50633 Mdot
.55811 .62748 Mdot
.52931 .36653 Mdot
.50368 .58672 Mdot
.49638 .42415 Mdot
.58905 .31416 Mdot
.35365 .47348 Mdot
.59663 .65389 Mdot
.30906 .49443 Mdot
.39128 .63941 Mdot
.75841 .54127 Mdot
.53756 .38763 Mdot
.58727 .60884 Mdot
.50076 .67866 Mdot
.61225 .33172 Mdot
.30324 .41553 Mdot
.44834 .78101 Mdot
.35025 .42725 Mdot
.54596 .63684 Mdot
.23333 .6769 Mdot
.66481 .5269 Mdot
.53527 .626 Mdot
.83327 .55202 Mdot
.59794 .62809 Mdot
.54913 .3539 Mdot
.50112 .35843 Mdot
.59273 .65947 Mdot
.6974 .49447 Mdot
.62788 .2089 Mdot
.59823 .59438 Mdot
.33663 .43344 Mdot
.35653 .75939 Mdot
.39654 .1807 Mdot
.4021 .5905 Mdot
.43129 .62663 Mdot
.59691 .36261 Mdot
.57163 .35144 Mdot
.38999 .65919 Mdot
.40599 .66865 Mdot
.65352 .52694 Mdot
.56432 .61219 Mdot
.37536 .46327 Mdot
.35587 .63487 Mdot
.38066 .49247 Mdot
.7382 .59144 Mdot
.58708 .3766 Mdot
.21175 .5624 Mdot
.47843 .37696 Mdot
.73914 .47722 Mdot
.37889 .62805 Mdot
.49686 .43179 Mdot
.57846 .42009 Mdot
.41097 .65771 Mdot
.66574 .51752 Mdot
.47547 .61876 Mdot
.56821 .63484 Mdot
.82654 .65031 Mdot
.5547 .43317 Mdot
.54409 .34801 Mdot
.40732 .65202 Mdot
.66515 .64549 Mdot
.32935 .44077 Mdot
.35994 .43872 Mdot
.58487 .66713 Mdot
.40871 .5094 Mdot
.55976 .35337 Mdot
.55786 .40034 Mdot
.56539 .64185 Mdot
.55675 .60468 Mdot
.49101 .77025 Mdot
.51103 .35751 Mdot
.40825 .64039 Mdot
.64255 .54113 Mdot
.37704 .63138 Mdot
.50058 .42922 Mdot
.53914 .34756 Mdot
.50847 .34241 Mdot
.51204 .43921 Mdot
.41541 .66758 Mdot
.48452 .41516 Mdot
.48305 .44454 Mdot
.32116 .43467 Mdot
.50085 .41586 Mdot
.42773 .45486 Mdot
.55 .37923 Mdot
.66626 .51505 Mdot
.40914 .23028 Mdot
.53011 .42301 Mdot
.55166 .34381 Mdot
.57499 .59263 Mdot
.5404 .39775 Mdot
.41819 .65952 Mdot
.33029 .4555 Mdot
.41257 .64802 Mdot
.42852 .64378 Mdot
.59149 .67749 Mdot
.68496 .53404 Mdot
.49567 .34232 Mdot
.65186 .50371 Mdot
.59349 .4087 Mdot
.55854 .41988 Mdot
.75224 .55856 Mdot
.16336 .43294 Mdot
.47779 .1984 Mdot
.53834 .3857 Mdot
.60268 .63207 Mdot
.60638 .62918 Mdot
.61678 .42884 Mdot
.57781 .40871 Mdot
.36631 .639 Mdot
.43247 .63577 Mdot
.62775 .26546 Mdot
.74426 .34918 Mdot
.66597 .51561 Mdot
.50016 .56191 Mdot
.5725 .40725 Mdot
.50292 .43481 Mdot
.54643 .43934 Mdot
.59673 .66578 Mdot
.48694 .47721 Mdot
.5384 .61896 Mdot
.29244 .66326 Mdot
.38971 .65016 Mdot
.51907 .42212 Mdot
.22623 .60148 Mdot
.29155 .46996 Mdot
.33026 .45665 Mdot
.3628 .64995 Mdot
.55769 .69193 Mdot
.60758 .22597 Mdot
.58547 .84376 Mdot
.31028 .50297 Mdot
.64978 .48929 Mdot
.5612 .40423 Mdot
.59367 .63784 Mdot
.31984 .48448 Mdot
.6494 .49097 Mdot
.52354 .43117 Mdot
.72299 .58155 Mdot
.53971 .3794 Mdot
.24147 .54066 Mdot
.34611 .46469 Mdot
.72917 .73971 Mdot
.27673 .47451 Mdot
.42627 .60491 Mdot
.37412 .64445 Mdot
.51647 .35126 Mdot
.24024 .40208 Mdot
.33348 .42155 Mdot
.49047 .62041 Mdot
.68575 .53096 Mdot
.44794 .69944 Mdot
.67675 .52428 Mdot
.58108 .65964 Mdot
.66125 .52229 Mdot
.57483 .65305 Mdot
.58022 .22807 Mdot
.35898 .50059 Mdot
.67991 .49777 Mdot
.49091 .66266 Mdot
.57315 .34945 Mdot
.66812 .48266 Mdot
.49031 .4429 Mdot
.59863 .32607 Mdot
.56344 .6396 Mdot
.6875 .52753 Mdot
.51951 .43557 Mdot
.804 .39738 Mdot
.39462 .60876 Mdot
.36832 .641 Mdot
.49433 .44397 Mdot
.61119 .64996 Mdot
.33405 .49237 Mdot
.69077 .75012 Mdot
.36318 .61247 Mdot
.51186 .3502 Mdot
.52496 .33937 Mdot
.34016 .42224 Mdot
.21091 .61082 Mdot
.52747 .34948 Mdot
.46123 .33958 Mdot
.50986 .35667 Mdot
.37658 .61322 Mdot
.3537 .43764 Mdot
.32471 .46255 Mdot
.55389 .65803 Mdot
.28526 .46485 Mdot
.62613 .4059 Mdot
.2478 .61563 Mdot
.50296 .31454 Mdot
.38907 .63458 Mdot
.27926 .64035 Mdot
.29054 .66493 Mdot
.82544 .52839 Mdot
.27915 .4349 Mdot
.47491 .39677 Mdot
.28124 .45619 Mdot
.67755 .52103 Mdot
.32871 .47059 Mdot
.29088 .48675 Mdot
.54679 .4098 Mdot
.50962 .41474 Mdot
.58893 .65258 Mdot
.3663 .5263 Mdot
.28977 .4412 Mdot
.48606 .37929 Mdot
.5623 .33859 Mdot
.54213 .43432 Mdot
.50261 .61093 Mdot
.33772 .42756 Mdot
.36309 .79437 Mdot
.68398 .32316 Mdot
.2902 .44137 Mdot
.65462 .19037 Mdot
.49533 .68257 Mdot
.6105 .67787 Mdot
.4576 .59595 Mdot
.50504 .36045 Mdot
.58718 .60319 Mdot
.51634 .4173 Mdot
.21301 .56313 Mdot
.53713 .40479 Mdot
.6628 .51393 Mdot
.55569 .42772 Mdot
.55998 .67384 Mdot
.56415 .62291 Mdot
.52279 .34523 Mdot
.5283 .41876 Mdot
.54071 .20472 Mdot
.27205 .48864 Mdot
.33505 .45612 Mdot
.65193 .58416 Mdot
.68769 .50024 Mdot
.38486 .65206 Mdot
.52028 .391 Mdot
.59343 .67451 Mdot
.5666 .62099 Mdot
.33071 .42313 Mdot
.55239 .6416 Mdot
.38949 .61991 Mdot
.53381 .39031 Mdot
.38331 .65627 Mdot
.65126 .52028 Mdot
.34839 .43392 Mdot
.50393 .41704 Mdot
.53749 .36219 Mdot
.34266 .45213 Mdot
.47043 .37038 Mdot
.69404 .49294 Mdot
.59612 .6233 Mdot
.34789 .4396 Mdot
.40114 .62417 Mdot
.57985 .65822 Mdot
.48569 .40513 Mdot
.18727 .35699 Mdot
.55036 .35823 Mdot
.49494 .37196 Mdot
.84633 .52925 Mdot
.56947 .41403 Mdot
.56911 .61659 Mdot
.31416 .48613 Mdot
.47167 .45143 Mdot
.71046 .37646 Mdot
.75686 .76432 Mdot
.53686 .62373 Mdot
.56349 .39836 Mdot
.81393 .47338 Mdot
.56228 .39212 Mdot
.33136 .38812 Mdot
.61836 .61516 Mdot
.53446 .51505 Mdot
.4871 .4331 Mdot
.41536 .61868 Mdot
.59293 .65172 Mdot
.57075 .65417 Mdot
.33094 .74443 Mdot
.55112 .40736 Mdot
.46386 .57316 Mdot
.51229 .43046 Mdot
.40359 .62188 Mdot
.65225 .28719 Mdot
.56346 .62179 Mdot
.33322 .22854 Mdot
.50642 .36639 Mdot
.31276 .42774 Mdot
.55096 .59584 Mdot
.41098 .69556 Mdot
.48673 .4008 Mdot
.65811 .49332 Mdot
.35011 .64069 Mdot
.46411 .35595 Mdot
.3883 .63079 Mdot
.489 .40812 Mdot
.43528 .41934 Mdot
.21027 .40326 Mdot
.33799 .47122 Mdot
.42782 .61571 Mdot
.52146 .57853 Mdot
.48095 .4119 Mdot
.34582 .43878 Mdot
.31876 .43774 Mdot
.64873 .51629 Mdot
.52792 .54177 Mdot
.30558 .55165 Mdot
.39249 .37549 Mdot
.3452 .75188 Mdot
.55557 .59552 Mdot
.5722 .74848 Mdot
.4947 .38302 Mdot
.63804 .54647 Mdot
.42267 .65585 Mdot
.55342 .36023 Mdot
.45405 .2389 Mdot
.29482 .46758 Mdot
.54529 .35897 Mdot
.66807 .50519 Mdot
.63137 .56243 Mdot
.63651 .53823 Mdot
.78056 .54627 Mdot
.5858 .64115 Mdot
.49097 .44814 Mdot
.43857 .41411 Mdot
.60909 .62271 Mdot
.539 .3348 Mdot
.58541 .6108 Mdot
.45333 .81732 Mdot
.66294 .48185 Mdot
.33337 .42785 Mdot
.47281 .6621 Mdot
.51074 .33553 Mdot
.56471 .34875 Mdot
.6731 .53723 Mdot
.52496 .37132 Mdot
.19769 .39586 Mdot
.5068 .60912 Mdot
.57259 .66369 Mdot
.33798 .47398 Mdot
.53327 .3362 Mdot
.54443 .55273 Mdot
.56023 .38136 Mdot
.4571 .29373 Mdot
.55014 .34287 Mdot
.32988 .55696 Mdot
.34264 .46315 Mdot
.38502 .63421 Mdot
.48661 .42463 Mdot
.52979 .40485 Mdot
.74564 .39315 Mdot
.59813 .38681 Mdot
.49004 .42586 Mdot
.32482 .40613 Mdot
.3264 .4849 Mdot
.34982 .47345 Mdot
.54193 .65037 Mdot
.72354 .3092 Mdot
.40137 .64045 Mdot
.49552 .46608 Mdot
.36097 .6239 Mdot
.28237 .37228 Mdot
.65198 .4881 Mdot
.80136 .51548 Mdot
.50747 .39064 Mdot
.31437 .4786 Mdot
.69634 .71893 Mdot
.36357 .46313 Mdot
.48356 .55565 Mdot
.41746 .63652 Mdot
.2957 .45982 Mdot
.52215 .40372 Mdot
.41277 .49 Mdot
.80393 .44477 Mdot
.40016 .64579 Mdot
.59425 .38582 Mdot
.53944 .65288 Mdot
.71509 .55857 Mdot
.232 .3177 Mdot
.39245 .60882 Mdot
.44971 .6117 Mdot
.55302 .40739 Mdot
.29276 .47435 Mdot
.40959 .61809 Mdot
.37386 .6177 Mdot
.55242 .64482 Mdot
.50635 .41284 Mdot
.50282 .40889 Mdot
.54466 .63756 Mdot
.41114 .64917 Mdot
.50578 .45052 Mdot
.47165 .3401 Mdot
.78534 .3268 Mdot
.32626 .5385 Mdot
.8307 .65166 Mdot
.61775 .43602 Mdot
.40958 .24641 Mdot
.69042 .75514 Mdot
.29864 .43321 Mdot
.54686 .42288 Mdot
.49467 .33005 Mdot
.56179 .66897 Mdot
.54598 .39024 Mdot
.62363 .64671 Mdot
.42423 .63999 Mdot
.71031 .24896 Mdot
.29028 .61327 Mdot
.50412 .82875 Mdot
.54655 .3922 Mdot
.36661 .41839 Mdot
.68027 .51469 Mdot
.42458 .59737 Mdot
.35923 .45196 Mdot
.52256 .44151 Mdot
.53644 .20368 Mdot
.53612 .62242 Mdot
.30047 .44419 Mdot
.59588 .20282 Mdot
.55194 .49985 Mdot
.49816 .42541 Mdot
.53908 .63519 Mdot
.73368 .69635 Mdot
.27552 .50023 Mdot
.37401 .60428 Mdot
.66446 .51783 Mdot
.59624 .65047 Mdot
.43394 .63465 Mdot
.37596 .44433 Mdot
.3006 .45345 Mdot
.342 .49066 Mdot
.46109 .20922 Mdot
.59141 .59921 Mdot
.68168 .51113 Mdot
.76942 .39632 Mdot
.74717 .36925 Mdot
.6625 .51049 Mdot
.57147 .67903 Mdot
.32456 .4848 Mdot
.30067 .46782 Mdot
.32995 .45498 Mdot
.41783 .1972 Mdot
.27849 .44776 Mdot
.27178 .70264 Mdot
.53348 .43666 Mdot
.48061 .32561 Mdot
.56217 .39849 Mdot
.37027 .64626 Mdot
.34732 .45306 Mdot
.43836 .49344 Mdot
.5863 .42082 Mdot
.78698 .48522 Mdot
.55391 .35641 Mdot
.44746 .62932 Mdot
.53677 .35656 Mdot
.18897 .52768 Mdot
.28198 .45154 Mdot
.54126 .38734 Mdot
.44164 .63721 Mdot
.69206 .50384 Mdot
.30784 .41318 Mdot
.50994 .41962 Mdot
.49705 .79174 Mdot
.56422 .42057 Mdot
.50772 .82184 Mdot
.24627 .49913 Mdot
.65044 .48875 Mdot
.217 .51734 Mdot
.52992 .64085 Mdot
.46366 .34063 Mdot
.59083 .43337 Mdot
.39225 .64389 Mdot
.46288 .68567 Mdot
.58263 .63106 Mdot
.49785 .48381 Mdot
.45262 .39989 Mdot
.64559 .51278 Mdot
.29773 .50734 Mdot
.39323 .66089 Mdot
.54695 .33578 Mdot
.58302 .40421 Mdot
.31297 .70677 Mdot
.46345 .42418 Mdot
.53701 .33937 Mdot
.65928 .53787 Mdot
.26601 .68723 Mdot
.54758 .3755 Mdot
.49259 .55724 Mdot
.32745 .50015 Mdot
.56132 .45259 Mdot
.25846 .68956 Mdot
.49828 .36034 Mdot
.29522 .44983 Mdot
.50417 .30377 Mdot
.28542 .54177 Mdot
.68732 .53277 Mdot
.55191 .34324 Mdot
.18148 .58483 Mdot
.51485 .36427 Mdot
.40421 .63773 Mdot
.57899 .40254 Mdot
.57764 .64915 Mdot
.47887 .19321 Mdot
.56121 .66458 Mdot
.56704 .36881 Mdot
.32794 .45283 Mdot
.40092 .65265 Mdot
.36288 .22387 Mdot
.69296 .59579 Mdot
.25271 .66862 Mdot
.60696 .82143 Mdot
.69236 .52462 Mdot
.71349 .50087 Mdot
.40445 .66285 Mdot
.54217 .38548 Mdot
.2692 .72257 Mdot
.59611 .36578 Mdot
.5471 .36482 Mdot
.53638 .40601 Mdot
.76786 .49429 Mdot
.42763 .64004 Mdot
.56098 .63374 Mdot
.53314 .34835 Mdot
.48642 .41934 Mdot
.30188 .43221 Mdot
.68558 .49436 Mdot
.60587 .61974 Mdot
.66953 .4942 Mdot
.59433 .64614 Mdot
.67804 .21481 Mdot
.55092 .44722 Mdot
.69233 .50987 Mdot
.35282 .64126 Mdot
.29495 .44214 Mdot
.24888 .611 Mdot
.57512 .65779 Mdot
.54856 .65796 Mdot
.5328 .34265 Mdot
.29257 .45202 Mdot
.3137 .49347 Mdot
.68271 .52132 Mdot
.38306 .61772 Mdot
.53116 .42277 Mdot
.56594 .41283 Mdot
.46121 .32241 Mdot
.60371 .66479 Mdot
.23451 .54243 Mdot
.56817 .76083 Mdot
.5402 .38409 Mdot
.28746 .47951 Mdot
.5333 .41523 Mdot
.61383 .7771 Mdot
.2889 .46929 Mdot
.49294 .36538 Mdot
.60634 .17757 Mdot
.57421 .69893 Mdot
.27171 .56276 Mdot
.51148 .34385 Mdot
.67005 .79135 Mdot
.49942 .38613 Mdot
.72841 .25311 Mdot
.69046 .69461 Mdot
.57122 .36947 Mdot
.48378 .39397 Mdot
.34844 .35438 Mdot
.56503 .40521 Mdot
.54525 .64356 Mdot
.66752 .25007 Mdot
.35279 .48156 Mdot
.34591 .70373 Mdot
.42189 .22952 Mdot
.69528 .52572 Mdot
.58515 .66689 Mdot
.62658 .67264 Mdot
.66208 .50197 Mdot
.32153 .45543 Mdot
.53457 .37956 Mdot
.4352 .5185 Mdot
.60937 .64885 Mdot
.60053 .46262 Mdot
.40589 .63644 Mdot
.47504 .73136 Mdot
.59656 .5575 Mdot
.38833 .62658 Mdot
.49847 .41313 Mdot
.33402 .35346 Mdot
.53745 .23646 Mdot
.7993 .65783 Mdot
.43579 .63153 Mdot
.3998 .64735 Mdot
.44907 .19068 Mdot
.64334 .48854 Mdot
.3314 .71594 Mdot
.33315 .56125 Mdot
.39375 .65462 Mdot
.25424 .48155 Mdot
.545 .61876 Mdot
.44197 .66028 Mdot
.50482 .45992 Mdot
.54901 .42669 Mdot
.52457 .40386 Mdot
.3772 .62248 Mdot
.61774 .34869 Mdot
.22239 .38306 Mdot
.38517 .64228 Mdot
.6065 .39086 Mdot
.50942 .52205 Mdot
.5724 .72294 Mdot
.55143 .62931 Mdot
.67933 .53356 Mdot
.67609 .47052 Mdot
.31947 .42906 Mdot
.68221 .5339 Mdot
.63251 .5583 Mdot
.52227 .37782 Mdot
.37822 .63847 Mdot
.46223 .69974 Mdot
.40749 .62656 Mdot
.66496 .50036 Mdot
.64174 .51353 Mdot
.32191 .43502 Mdot
.33388 .46193 Mdot
.37947 .2755 Mdot
.65235 .33732 Mdot
.56027 .37255 Mdot
.75374 .61701 Mdot
.29557 .48945 Mdot
.60394 .46321 Mdot
.67782 .53469 Mdot
.68941 .50029 Mdot
.74978 .41043 Mdot
.50956 .39473 Mdot
.26946 .40123 Mdot
.51383 .39371 Mdot
.65354 .29842 Mdot
.48203 .36722 Mdot
.55216 .64383 Mdot
.50374 .39821 Mdot
.75979 .4224 Mdot
.49473 .33835 Mdot
.5764 .35754 Mdot
.59579 .66924 Mdot
.45764 .37073 Mdot
.57673 .64719 Mdot
.56543 .37122 Mdot
.68043 .47722 Mdot
.57972 .67128 Mdot
.70894 .39519 Mdot
.75382 .43131 Mdot
.56842 .67964 Mdot
.6489 .50387 Mdot
.70517 .50597 Mdot
.71866 .43202 Mdot
.35937 .45152 Mdot
.60215 .42314 Mdot
.54473 .38638 Mdot
.54898 .60729 Mdot
.43063 .63308 Mdot
.4814 .39221 Mdot
.56328 .34127 Mdot
.49371 .35687 Mdot
.31923 .4284 Mdot
.67019 .5878 Mdot
.69109 .5165 Mdot
.543 .63279 Mdot
.60333 .51141 Mdot
.61365 .64365 Mdot
.58366 .39302 Mdot
.49217 .3331 Mdot
.43911 .23391 Mdot
.54462 .71794 Mdot
.41661 .191 Mdot
.30095 .45158 Mdot
.6077 .63142 Mdot
.66334 .47411 Mdot
.50883 .32306 Mdot
.31252 .48007 Mdot
.57632 .6509 Mdot
.53912 .38009 Mdot
.59416 .37095 Mdot
.27124 .65403 Mdot
.63151 .40464 Mdot
.73682 .41859 Mdot
.54953 .66229 Mdot
.53408 .64665 Mdot
.76561 .45943 Mdot
.70509 .53707 Mdot
.42648 .49127 Mdot
.55404 .39751 Mdot
.65856 .49401 Mdot
.31775 .4843 Mdot
.47975 .21549 Mdot
.37039 .63181 Mdot
.36022 .52921 Mdot
.5448 .39224 Mdot
.56157 .5119 Mdot
.32839 .45052 Mdot
.66736 .50786 Mdot
.37569 .62449 Mdot
.70965 .48946 Mdot
.60459 .65166 Mdot
.51709 .84675 Mdot
.51986 .36561 Mdot
.5405 .34261 Mdot
.43954 .61788 Mdot
.29986 .47529 Mdot
.69124 .53412 Mdot
.36599 .76529 Mdot
.56329 .65385 Mdot
.25177 .70374 Mdot
.29026 .48021 Mdot
.4118 .403 Mdot
.54754 .62358 Mdot
.36019 .64132 Mdot
.7067 .41481 Mdot
.38494 .62374 Mdot
.56219 .36018 Mdot
.31805 .47265 Mdot
.42618 .61709 Mdot
.33453 .52894 Mdot
.81795 .45612 Mdot
.40983 .39938 Mdot
.52359 .38288 Mdot
.78438 .35391 Mdot
.49006 .80842 Mdot
.27985 .49537 Mdot
.42828 .64943 Mdot
.55469 .35975 Mdot
.55993 .34528 Mdot
.51696 .3626 Mdot
.42663 .62663 Mdot
.7559 .5986 Mdot
.56284 .64255 Mdot
.55787 .4041 Mdot
.6522 .52571 Mdot
.57821 .64023 Mdot
.46341 .67035 Mdot
.55419 .6282 Mdot
.27246 .44378 Mdot
.58449 .38368 Mdot
.37589 .69911 Mdot
.63347 .1574 Mdot
.40748 .64723 Mdot
.58559 .68071 Mdot
.55115 .44457 Mdot
.49476 .70973 Mdot
.34133 .47921 Mdot
.56196 .65485 Mdot
.54543 .34875 Mdot
.48299 .64991 Mdot
.50342 .20242 Mdot
.55735 .6255 Mdot
.31162 .48115 Mdot
.802 .64473 Mdot
.55149 .38743 Mdot
.50438 .37907 Mdot
.30026 .46017 Mdot
.28635 .32785 Mdot
.5431 .18324 Mdot
.52989 .41747 Mdot
.38371 .63408 Mdot
.40998 .84083 Mdot
.5667 .34275 Mdot
.67918 .30267 Mdot
.59088 .65324 Mdot
.42428 .67427 Mdot
.26138 .5313 Mdot
.51575 .32233 Mdot
.3471 .73623 Mdot
.45281 .60989 Mdot
.78151 .37813 Mdot
.62206 .64716 Mdot
.63505 .70995 Mdot
.74953 .31851 Mdot
.44185 .64192 Mdot
.40122 .44884 Mdot
.36284 .74623 Mdot
.2943 .28318 Mdot
.76676 .67656 Mdot
.65843 .68496 Mdot
.53681 .20211 Mdot
.45245 .51483 Mdot
.59958 .63522 Mdot
.59166 .48656 Mdot
.51521 .41887 Mdot
.49822 .80935 Mdot
.21816 .4448 Mdot
.21723 .42462 Mdot
.78693 .35656 Mdot
.35638 .39013 Mdot
.81026 .4655 Mdot
.83227 .52914 Mdot
.57188 .27186 Mdot
.59676 .73621 Mdot
.25369 .71038 Mdot
.65313 .22215 Mdot
.37115 .78608 Mdot
.49258 .31636 Mdot
.47287 .55845 Mdot
.56258 .81846 Mdot
.38264 .45654 Mdot
.24217 .36939 Mdot
.55599 .65774 Mdot
.3578 .46857 Mdot
.35106 .72551 Mdot
.34788 .42468 Mdot
.27987 .53775 Mdot
.81258 .63684 Mdot
.82102 .46529 Mdot
.19417 .59248 Mdot
.68949 .76726 Mdot
.44172 .2436 Mdot
.16708 .63682 Mdot
.61276 .61653 Mdot
.31853 .42275 Mdot
.74822 .47901 Mdot
.76527 .41516 Mdot
.30724 .66111 Mdot
.40652 .77834 Mdot
.73725 .5607 Mdot
.65997 .40068 Mdot
.3188 .46341 Mdot
.2255 .51757 Mdot
.45352 .66405 Mdot
.29018 .6221 Mdot
.6515 .23482 Mdot
.80086 .59857 Mdot
.42809 .52365 Mdot
.41925 .77011 Mdot
.50795 .73623 Mdot
.25061 .30434 Mdot
.69392 .34197 Mdot
.6045 .46928 Mdot
.32359 .54304 Mdot
.6674 .76575 Mdot
.30704 .28918 Mdot
.63862 .29457 Mdot
.76259 .40089 Mdot
.64964 .20472 Mdot
.57964 .78992 Mdot
.47662 .14157 Mdot
.36837 .44509 Mdot
.52686 .33858 Mdot
.31441 .31547 Mdot
.1863 .60534 Mdot
.64046 .51912 Mdot
.77909 .5658 Mdot
.67706 .53084 Mdot
.27052 .46395 Mdot
.51062 .19149 Mdot
.25826 .6849 Mdot
.18911 .63126 Mdot
.69646 .48332 Mdot
.4827 .4613 Mdot
.59919 .87161 Mdot
.79068 .44322 Mdot
.27245 .58982 Mdot
.77106 .30956 Mdot
.51048 .50609 Mdot
.25486 .4955 Mdot
.42841 .62054 Mdot
.74263 .30064 Mdot
.30667 .46972 Mdot
.49093 .1279 Mdot
.72207 .24603 Mdot
.47727 .22793 Mdot
.92569 .49246 Mdot
.76482 .47699 Mdot
.53952 .51451 Mdot
.37617 .58037 Mdot
.68656 .36614 Mdot
.23103 .35728 Mdot
.69109 .45914 Mdot
.49862 .71674 Mdot
.64847 .81462 Mdot
.77522 .35192 Mdot
.20864 .66009 Mdot
.46567 .83573 Mdot
.28034 .30239 Mdot
.53721 .55639 Mdot
.54944 .46817 Mdot
.59864 .5648 Mdot
.78194 .61269 Mdot
.65568 .19993 Mdot
.6874 .32449 Mdot
.7479 .77404 Mdot
.68267 .54101 Mdot
.726 .60809 Mdot
.83639 .60574 Mdot
.67327 .41107 Mdot
.24024 .50938 Mdot
.69454 .29557 Mdot
.52117 .47915 Mdot
.61372 .52038 Mdot
.7832 .58435 Mdot
.24462 .56903 Mdot
.6862 .26461 Mdot
.72288 .71899 Mdot
.31003 .70395 Mdot
.38742 .35074 Mdot
.73002 .33855 Mdot
.35659 .42328 Mdot
.64729 .3612 Mdot
.25925 .5231 Mdot
.82564 .44503 Mdot
.45011 .64215 Mdot
.8423 .44878 Mdot
.5484 .18697 Mdot
.5344 .45311 Mdot
.59929 .36456 Mdot
.30791 .40152 Mdot
.65465 .36338 Mdot
.45261 .3799 Mdot
.28457 .66999 Mdot
.83557 .4913 Mdot
.51244 .25112 Mdot
.4719 .63344 Mdot
.46627 .68134 Mdot
.83293 .61985 Mdot
.33832 .31337 Mdot
.71111 .53397 Mdot
.63792 .25056 Mdot
.24554 .31893 Mdot
.57654 .63032 Mdot
.21473 .66254 Mdot
.35534 .61937 Mdot
.49542 .20924 Mdot
.39005 .37943 Mdot
.36879 .24693 Mdot
.83614 .49179 Mdot
.64229 .68587 Mdot
.53179 .19121 Mdot
.66955 .43198 Mdot
.31856 .76345 Mdot
.56728 .72152 Mdot
.46478 .36463 Mdot
.43002 .78239 Mdot
.69611 .49235 Mdot
.37269 .31302 Mdot
.38014 .81404 Mdot
.68043 .64422 Mdot
.4643 .41432 Mdot
.47711 .22433 Mdot
.58338 .7029 Mdot
.40869 .49455 Mdot
.35133 .19476 Mdot
.58298 .36171 Mdot
.76372 .38201 Mdot
.55933 .79137 Mdot
.67167 .34583 Mdot
.75807 .70924 Mdot
.63706 .766 Mdot
.51535 .14006 Mdot
.76611 .31597 Mdot
.6813 .59709 Mdot
.74613 .32069 Mdot
.81125 .39478 Mdot
.50974 .14569 Mdot
.60284 .40202 Mdot
.42954 .60557 Mdot
.17821 .35234 Mdot
.55149 .6263 Mdot
.77844 .43091 Mdot
.34462 .75176 Mdot
.56914 .56564 Mdot
.34403 .40334 Mdot
.55044 .48265 Mdot
.45288 .52046 Mdot
.27532 .4898 Mdot
.4519 .38515 Mdot
.41943 .17498 Mdot
.56731 .15179 Mdot
.45932 .15386 Mdot
.61924 .80195 Mdot
.72704 .28803 Mdot
.55994 .52189 Mdot
.20083 .61112 Mdot
.61034 .44032 Mdot
.52654 .43487 Mdot
.72428 .50883 Mdot
.76381 .4812 Mdot
.45102 .21985 Mdot
.31016 .62004 Mdot
.32436 .51115 Mdot
.78073 .57545 Mdot
.30038 .82539 Mdot
.40122 .26869 Mdot
.28444 .72169 Mdot
.71318 .54538 Mdot
.65679 .3413 Mdot
.77149 .61775 Mdot
.41014 .22667 Mdot
.84098 .5313 Mdot
.27966 .49248 Mdot
.36649 .77812 Mdot
.67798 .67528 Mdot
.40549 .46641 Mdot
.67679 .5855 Mdot
.81455 .48923 Mdot
.35548 .70366 Mdot
.38269 .2243 Mdot
.3338 .58079 Mdot
.31503 .30423 Mdot
.50217 .62979 Mdot
.4833 .73944 Mdot
.35739 .79349 Mdot
.62595 .75312 Mdot
.66279 .29708 Mdot
.49981 .52535 Mdot
.20886 .5231 Mdot
.45076 .60199 Mdot
.66598 .30444 Mdot
.43278 .45957 Mdot
.74418 .33435 Mdot
.53398 .08956 Mdot
.34567 .21334 Mdot
.80958 .66524 Mdot
.75901 .61986 Mdot
.45982 .39328 Mdot
.84052 .55796 Mdot
.43791 .14926 Mdot
.67231 .18646 Mdot
.45969 .75268 Mdot
.61923 .64331 Mdot
.36036 .6313 Mdot
.45268 .1731 Mdot
.75311 .59444 Mdot
.82183 .57807 Mdot
.70935 .32803 Mdot
.36761 .65734 Mdot
.157 .44738 Mdot
.64973 .20902 Mdot
.40195 .38519 Mdot
.63162 .39898 Mdot
.46827 .39482 Mdot
.20334 .47493 Mdot
.34663 .42557 Mdot
.55601 .74659 Mdot
.6479 .32753 Mdot
.57489 .62299 Mdot
.74207 .48995 Mdot
.42195 .78514 Mdot
.55522 .42781 Mdot
.52602 .57083 Mdot
.2989 .41957 Mdot
.55463 .72339 Mdot
.26706 .62504 Mdot
.63481 .17466 Mdot
.70932 .55257 Mdot
.49072 .43619 Mdot
.67361 .33982 Mdot
.67427 .58092 Mdot
.52531 .17779 Mdot
.40427 .66398 Mdot
.79753 .38529 Mdot
.44123 .5416 Mdot
.64724 .35444 Mdot
.22783 .43634 Mdot
.60295 .33821 Mdot
.57028 .35828 Mdot
.666 .75043 Mdot
.46652 .27845 Mdot
.38189 .51927 Mdot
.49927 .46064 Mdot
.61173 .42294 Mdot
.83797 .56802 Mdot
.62952 .56128 Mdot
.48751 .73029 Mdot
.80914 .41244 Mdot
.42091 .62725 Mdot
.2815 .45827 Mdot
.629 .47239 Mdot
.3952 .79074 Mdot
.49842 .27806 Mdot
.50164 .20238 Mdot
.57981 .5578 Mdot
.68993 .6328 Mdot
.81393 .42925 Mdot
.79466 .39135 Mdot
.18494 .49033 Mdot
.28017 .49796 Mdot
.59368 .29248 Mdot
.38664 .7927 Mdot
.32901 .48677 Mdot
.28719 .69343 Mdot
.277 .67835 Mdot
.68917 .23189 Mdot
.51105 .58495 Mdot
.65891 .80776 Mdot
.73165 .41358 Mdot
.77077 .56719 Mdot
.36004 .22389 Mdot
.34222 .77876 Mdot
.80133 .48705 Mdot
.25686 .47761 Mdot
.34932 .36755 Mdot
.49628 .31735 Mdot
.20791 .57303 Mdot
.17622 .37986 Mdot
.62886 .48049 Mdot
.40138 .4308 Mdot
.72796 .71637 Mdot
.53195 .37172 Mdot
.31272 .22979 Mdot
.39949 .78288 Mdot
.43817 .19135 Mdot
.35857 .64671 Mdot
.499 .42126 Mdot
.51535 .33264 Mdot
.66926 .27271 Mdot
.27963 .54287 Mdot
.73281 .32073 Mdot
.42429 .8397 Mdot
.75158 .67834 Mdot
.22912 .43254 Mdot
.77219 .41969 Mdot
.80232 .6035 Mdot
.50955 .80871 Mdot
.51385 .54256 Mdot
.74877 .51607 Mdot
.68558 .41014 Mdot
.67581 .77464 Mdot
.43243 .46611 Mdot
.41769 .57205 Mdot
.31022 .67952 Mdot
.57805 .7645 Mdot
.42967 .20972 Mdot
.49061 .40192 Mdot
.59632 .20308 Mdot
.82699 .54899 Mdot
.19399 .47674 Mdot
.21457 .36326 Mdot
.35526 .2057 Mdot
.43132 .31568 Mdot
.60153 .76498 Mdot
.4733 .80293 Mdot
.3299 .78909 Mdot
.43731 .54375 Mdot
.78453 .50278 Mdot
.67885 .42215 Mdot
.81234 .42298 Mdot
.4394 .61514 Mdot
.32632 .57227 Mdot
.46916 .68151 Mdot
.742 .32196 Mdot
.33651 .32696 Mdot
.82429 .50272 Mdot
.48906 .50489 Mdot
.52279 .13727 Mdot
.64131 .74724 Mdot
.46523 .51222 Mdot
.60342 .6495 Mdot
.6496 .66977 Mdot
.7958 .55171 Mdot
.6548 .72865 Mdot
.32843 .76334 Mdot
.5988 .68533 Mdot
.6141 .47592 Mdot
.3878 .40781 Mdot
.64049 .36946 Mdot
.66255 .75455 Mdot
.67357 .34046 Mdot
.82711 .47981 Mdot
.68132 .27233 Mdot
.5916 .20321 Mdot
.76937 .47625 Mdot
.59072 .83346 Mdot
.27126 .58507 Mdot
.62445 .52639 Mdot
.40775 .78359 Mdot
.72665 .6256 Mdot
.25172 .46764 Mdot
.22086 .23654 Mdot
.52456 .84183 Mdot
.62654 .74258 Mdot
.65677 .20147 Mdot
.63461 .77453 Mdot
.54372 .71921 Mdot
.26365 .33297 Mdot
.34202 .54149 Mdot
.57825 .21808 Mdot
.53564 .40531 Mdot
.41325 .17038 Mdot
.64047 .33524 Mdot
.61092 .15938 Mdot
.82179 .58943 Mdot
.34705 .40202 Mdot
.58365 .38345 Mdot
.54131 .63419 Mdot
.45284 .56963 Mdot
.6088 .27497 Mdot
.30668 .34599 Mdot
.23236 .48795 Mdot
.48809 .64657 Mdot
.60469 .61012 Mdot
.66069 .57823 Mdot
.30645 .50181 Mdot
.76006 .58186 Mdot
.57591 .76124 Mdot
.52355 .62664 Mdot
.41627 .52693 Mdot
.6635 .31737 Mdot
.25255 .52916 Mdot
.40602 .38196 Mdot
.41609 .22342 Mdot
.3683 .70098 Mdot
.54785 .63847 Mdot
.40164 .36893 Mdot
.55883 .82326 Mdot
.72997 .70251 Mdot
.64754 .20003 Mdot
.61007 .53051 Mdot
.30843 .36624 Mdot
.66683 .29481 Mdot
.22111 .3704 Mdot
.24832 .38837 Mdot
.53803 .70802 Mdot
.20695 .48209 Mdot
.2543 .36001 Mdot
.36833 .74187 Mdot
.71098 .24834 Mdot
.36982 .78405 Mdot
.38436 .79308 Mdot
.53672 .58765 Mdot
.48032 .30532 Mdot
.37332 .41802 Mdot
.71587 .40137 Mdot
.41775 .49367 Mdot
.15519 .5945 Mdot
.53146 .46635 Mdot
.11771 .54435 Mdot
.3823 .61075 Mdot
.25209 .32504 Mdot
.68999 .41833 Mdot
.51118 .52679 Mdot
.47848 .49459 Mdot
.62848 .75691 Mdot
.32437 .55781 Mdot
.56568 .79713 Mdot
.22047 .41051 Mdot
.6147 .61791 Mdot
.44498 .85056 Mdot
.6008 .83467 Mdot
.36782 .36091 Mdot
.56106 .43048 Mdot
.55018 .83742 Mdot
.61795 .63436 Mdot
.43909 .21889 Mdot
.76553 .70078 Mdot
.71044 .70076 Mdot
.40933 .4306 Mdot
.65454 .34731 Mdot
.78673 .50019 Mdot
.79486 .35972 Mdot
.17693 .42263 Mdot
.78099 .5886 Mdot
.43737 .61352 Mdot
.49818 .51189 Mdot
.81448 .5276 Mdot
.27701 .51359 Mdot
.45299 .65139 Mdot
.2409 .49993 Mdot
.14478 .62088 Mdot
.78076 .43059 Mdot
.7369 .32925 Mdot
.24408 .49243 Mdot
.27797 .47562 Mdot
.30417 .5421 Mdot
.24068 .51133 Mdot
.69105 .71545 Mdot
.52021 .82456 Mdot
.24829 .51725 Mdot
.25769 .73869 Mdot
.59953 .32623 Mdot
.62159 .69544 Mdot
.35136 .40102 Mdot
.55132 .26611 Mdot
.3718 .66146 Mdot
.62196 .22579 Mdot
.75984 .679 Mdot
.40129 .59966 Mdot
.67709 .74834 Mdot
.42594 .77312 Mdot
.42094 .38714 Mdot
.48009 .28975 Mdot
.7458 .67331 Mdot
.32868 .34609 Mdot
.19359 .54731 Mdot
.49707 .21902 Mdot
.60008 .6773 Mdot
.78208 .65893 Mdot
.57407 .66172 Mdot
.59376 .47144 Mdot
.35112 .52983 Mdot
.68384 .45624 Mdot
.4288 .18706 Mdot
.69979 .51928 Mdot
.34388 .42757 Mdot
.17669 .39134 Mdot
.30451 .48721 Mdot
.4344 .16873 Mdot
.37601 .24235 Mdot
.20848 .46271 Mdot
.67955 .60413 Mdot
.66765 .63737 Mdot
.18994 .67392 Mdot
.45098 .67327 Mdot
.59084 .56658 Mdot
.22694 .61554 Mdot
.32488 .42191 Mdot
.72234 .54682 Mdot
.58935 .67314 Mdot
.40447 .54508 Mdot
.36994 .72136 Mdot
.57926 .31198 Mdot
.37715 .45659 Mdot
.40831 .53734 Mdot
.6088 .24142 Mdot
.71389 .2669 Mdot
.59 .61181 Mdot
.12869 .53178 Mdot
.5793 .37254 Mdot
.38549 .34313 Mdot
.844 .52604 Mdot
.15674 .45365 Mdot
.62551 .59181 Mdot
.61286 .83561 Mdot
.4747 .40415 Mdot
.76114 .63653 Mdot
.31161 .46539 Mdot
.3731 .78219 Mdot
.67307 .52779 Mdot
.67516 .35365 Mdot
.37149 .61477 Mdot
.37837 .22555 Mdot
.63421 .60732 Mdot
.3373 .49224 Mdot
.73603 .66238 Mdot
.56858 .27179 Mdot
.3721 .56031 Mdot
.65529 .60306 Mdot
.37103 .36484 Mdot
.49091 .28518 Mdot
.35713 .50026 Mdot
.74957 .34857 Mdot
.39619 .80688 Mdot
.6424 .17442 Mdot
.31121 .40593 Mdot
.56169 .5028 Mdot
.30059 .68745 Mdot
.69922 .72745 Mdot
.22007 .57835 Mdot
.84251 .50463 Mdot
.64026 .30683 Mdot
.52063 .29367 Mdot
.65599 .3032 Mdot
.55879 .31441 Mdot
.47801 .53839 Mdot
.51845 .7438 Mdot
.20934 .43088 Mdot
.24079 .54201 Mdot
.28519 .30842 Mdot
.20247 .54859 Mdot
.73497 .33611 Mdot
.213 .46936 Mdot
.54215 .67662 Mdot
.43179 .3578 Mdot
.39268 .59187 Mdot
.72325 .26952 Mdot
.84324 .51129 Mdot
.44264 .6074 Mdot
.71293 .56461 Mdot
.71403 .7447 Mdot
.58137 .34175 Mdot
.58553 .51928 Mdot
.54764 .34375 Mdot
.62556 .38661 Mdot
.14818 .48234 Mdot
.69716 .71769 Mdot
.47845 .43678 Mdot
.77752 .36319 Mdot
.76067 .33055 Mdot
.56072 .14106 Mdot
.27732 .73293 Mdot
.32847 .43442 Mdot
.50914 .15339 Mdot
.22968 .4878 Mdot
.80461 .37368 Mdot
.5778 .72708 Mdot
.8616 .53022 Mdot
.34868 .36371 Mdot
.69541 .74489 Mdot
.25301 .34695 Mdot
.33636 .55114 Mdot
.56705 .78311 Mdot
.56324 .52959 Mdot
.46881 .71753 Mdot
.61172 .78361 Mdot
.39565 .8477 Mdot
.49126 .32628 Mdot
.46862 .78977 Mdot
.33041 .67872 Mdot
.79002 .64863 Mdot
.65496 .7147 Mdot
.57424 .41122 Mdot
.4579 .69386 Mdot
.4177 .2013 Mdot
.67152 .31893 Mdot
.60167 .4832 Mdot
.64855 .71732 Mdot
.54571 .22262 Mdot
.64635 .28741 Mdot
.37545 .79097 Mdot
.36349 .36688 Mdot
.45354 .56093 Mdot
.48001 .40945 Mdot
.36874 .47844 Mdot
.70778 .51736 Mdot
.55953 .53651 Mdot
.56394 .37163 Mdot
.53434 .61788 Mdot
.3698 .55811 Mdot
.39641 .18866 Mdot
.25059 .56882 Mdot
.44298 .80408 Mdot
.37006 .42892 Mdot
.33209 .6631 Mdot
.22894 .59808 Mdot
.32396 .23566 Mdot
.69655 .6733 Mdot
.68761 .32499 Mdot
.79476 .43831 Mdot
.69159 .2744 Mdot
.38818 .47046 Mdot
.59625 .17353 Mdot
.42439 .65433 Mdot
.41907 .39946 Mdot
.32394 .6316 Mdot
.65416 .56829 Mdot
.48561 .45012 Mdot
.69502 .74431 Mdot
.59255 .5614 Mdot
.7635 .42122 Mdot
.57945 .79262 Mdot
.60055 .30909 Mdot
.37946 .39399 Mdot
.7908 .37796 Mdot
.53752 .62289 Mdot
.42996 .81458 Mdot
.37146 .57083 Mdot
.65457 .70271 Mdot
.71005 .27907 Mdot
.66723 .20845 Mdot
.45452 .4967 Mdot
.67981 .3958 Mdot
.503 .37338 Mdot
.36194 .79317 Mdot
.69197 .72612 Mdot
.48969 .47185 Mdot
.45395 .74284 Mdot
.28316 .46481 Mdot
.49481 .7589 Mdot
.46889 .56087 Mdot
.57058 .22334 Mdot
.31492 .4145 Mdot
.2033 .46644 Mdot
.68923 .48196 Mdot
.53485 .50495 Mdot
.4505 .42457 Mdot
.68537 .38299 Mdot
.20974 .67006 Mdot
.48437 .45664 Mdot
.78503 .59381 Mdot
.3867 .37227 Mdot
.36659 .76733 Mdot
.74355 .67104 Mdot
.51814 .69666 Mdot
.32456 .55543 Mdot
.44757 .32857 Mdot
.36939 .70793 Mdot
.50392 .34963 Mdot
.56565 .69392 Mdot
.34301 .48588 Mdot
.7816 .6681 Mdot
.44679 .30154 Mdot
.70746 .39655 Mdot
.50253 .61075 Mdot
.60772 .46686 Mdot
.3699 .58777 Mdot
.85702 .52756 Mdot
.32466 .54966 Mdot
.64629 .31807 Mdot
.51196 .58381 Mdot
.69198 .41423 Mdot
.35689 .25814 Mdot
.71527 .23712 Mdot
.25404 .34234 Mdot
.42259 .51455 Mdot
.24587 .33553 Mdot
.61475 .75414 Mdot
.74999 .72007 Mdot
.64358 .29705 Mdot
.50551 .49754 Mdot
.65541 .53991 Mdot
.26336 .64809 Mdot
.49446 .62221 Mdot
.6055 .49148 Mdot
.41107 .54821 Mdot
.413 .73584 Mdot
.37514 .67949 Mdot
.47349 .46019 Mdot
.7756 .46614 Mdot
.79304 .41373 Mdot
.35268 .75783 Mdot
.44732 .59842 Mdot
.61606 .71462 Mdot
.57587 .23259 Mdot
.86853 .5404 Mdot
.20051 .3442 Mdot
.50509 .37137 Mdot
.40118 .5853 Mdot
.66838 .38885 Mdot
.55645 .67048 Mdot
.23737 .52535 Mdot
.23542 .59667 Mdot
.41306 .60691 Mdot
.61882 .47709 Mdot
.75426 .38892 Mdot
.59029 .75716 Mdot
.64065 .39165 Mdot
.4692 .66738 Mdot
.37837 .19385 Mdot
.59331 .81547 Mdot
.70227 .72265 Mdot
.87854 .47417 Mdot
.39472 .56918 Mdot
.60981 .40758 Mdot
.35071 .29067 Mdot
.717 .27665 Mdot
.6811 .34235 Mdot
.47786 .21012 Mdot
.49499 .68784 Mdot
.63936 .29753 Mdot
.24857 .45251 Mdot
.77347 .44402 Mdot
.48682 .75784 Mdot
.47567 .52718 Mdot
.66943 .64307 Mdot
.61162 .17161 Mdot
.36421 .39798 Mdot
.80273 .45091 Mdot
.38559 .21025 Mdot
.31283 .78188 Mdot
.73402 .28549 Mdot
.75247 .43251 Mdot
.68214 .6962 Mdot
.31868 .31428 Mdot
.42806 .45646 Mdot
.25675 .48704 Mdot
.44501 .21841 Mdot
.50361 .26914 Mdot
.72108 .58305 Mdot
.30628 .27925 Mdot
.66323 .29751 Mdot
.5252 .2566 Mdot
.49985 .49609 Mdot
.40914 .37087 Mdot
.70579 .56752 Mdot
.25528 .50388 Mdot
.41778 .46364 Mdot
.7123 .37286 Mdot
.39471 .36891 Mdot
.31447 .70095 Mdot
.63044 .7701 Mdot
.29749 .78284 Mdot
.74599 .62364 Mdot
.3127 .24836 Mdot
.53573 .43679 Mdot
.57174 .12768 Mdot
.58449 .77449 Mdot
.61834 .73155 Mdot
.53935 .81339 Mdot
.58374 .70652 Mdot
.60763 .36503 Mdot
.50329 .35005 Mdot
.79169 .55333 Mdot
.40278 .42558 Mdot
.44328 .23852 Mdot
.35956 .2314 Mdot
.66451 .34851 Mdot
.70918 .33206 Mdot
.72288 .40767 Mdot
.49254 .30852 Mdot
.29747 .48138 Mdot
.46868 .15223 Mdot
.43374 .49991 Mdot
.50283 .47484 Mdot
.4382 .39057 Mdot
.31137 .30676 Mdot
.66956 .8108 Mdot
.32087 .40207 Mdot
.70631 .30508 Mdot
.35266 .38347 Mdot
.39494 .4741 Mdot
.21408 .55854 Mdot
.89378 .40039 Mdot
.61691 .13365 Mdot
.34861 .48556 Mdot
.26977 .70822 Mdot
.35469 .38723 Mdot
.7401 .32545 Mdot
.68328 .67175 Mdot
.42243 .74635 Mdot
.44331 .44516 Mdot
.38295 .50426 Mdot
.45012 .41369 Mdot
.54612 .7995 Mdot
.73106 .26735 Mdot
.33341 .2481 Mdot
.77923 .36628 Mdot
.57079 .31622 Mdot
.45944 .43245 Mdot
.88842 .52433 Mdot
.81577 .51694 Mdot
.58863 .38045 Mdot
.23575 .3701 Mdot
.54112 .46839 Mdot
.51758 .4157 Mdot
.76184 .5456 Mdot
.44505 .84954 Mdot
.66411 .29258 Mdot
.74195 .3224 Mdot
.33528 .41851 Mdot
.61104 .69162 Mdot
.38114 .61067 Mdot
.46097 .49492 Mdot
.59158 .40247 Mdot
.424 .61775 Mdot
.61775 .31505 Mdot
.72018 .73013 Mdot
.48112 .60373 Mdot
.43527 .83359 Mdot
.85143 .45669 Mdot
.43394 .3198 Mdot
.26146 .63999 Mdot
.56045 .33269 Mdot
.54245 .26354 Mdot
.58583 .25165 Mdot
.62139 .40807 Mdot
.65633 .77321 Mdot
.3267 .16086 Mdot
.44431 .71111 Mdot
.59877 .22207 Mdot
.2782 .48207 Mdot
.43051 .55532 Mdot
.39945 .40525 Mdot
.58674 .71597 Mdot
.60221 .61913 Mdot
.55773 .30908 Mdot
.31503 .41032 Mdot
.35147 .63556 Mdot
.12253 .49734 Mdot
.55502 .43709 Mdot
.22711 .54249 Mdot
.80575 .38069 Mdot
.49624 .21862 Mdot
.36356 .33449 Mdot
.4846 .35921 Mdot
.29019 .63105 Mdot
.51028 .49871 Mdot
.78206 .63488 Mdot
.60033 .20833 Mdot
.7834 .40019 Mdot
.45216 .29694 Mdot
.37414 .39216 Mdot
.48498 .41755 Mdot
.63944 .4989 Mdot
.4271 .67232 Mdot
.77719 .55293 Mdot
.57471 .44809 Mdot
.78085 .3303 Mdot
.64305 .64369 Mdot
.57802 .54217 Mdot
.28017 .41178 Mdot
.55058 .14301 Mdot
.32537 .28274 Mdot
.38825 .43523 Mdot
.33704 .22444 Mdot
.64405 .58182 Mdot
.64128 .37568 Mdot
.53969 .62944 Mdot
.59801 .41789 Mdot
.34681 .41671 Mdot
.32706 .21591 Mdot
.76703 .53016 Mdot
.47096 .71002 Mdot
.47933 .73781 Mdot
.31072 .73459 Mdot
.36806 .56456 Mdot
.87158 .45331 Mdot
.6538 .6146 Mdot
.34516 .2086 Mdot
.4045 .80946 Mdot
.35272 .4166 Mdot
.64368 .76064 Mdot
.52907 .46445 Mdot
.57956 .61412 Mdot
.77729 .3739 Mdot
.57604 .47245 Mdot
.51399 .19402 Mdot
.47107 .36759 Mdot
.46904 .18624 Mdot
.63727 .53125 Mdot
.72569 .55237 Mdot
.6181 .74589 Mdot
.31579 .30035 Mdot
.82592 .61298 Mdot
.26522 .65296 Mdot
.84447 .56858 Mdot
.81412 .63216 Mdot
.79543 .37772 Mdot
.47607 .20075 Mdot
.17091 .44921 Mdot
.62813 .73489 Mdot
.73812 .68331 Mdot
.54405 .75013 Mdot
.2942 .32385 Mdot
.64797 .67817 Mdot
.28387 .4063 Mdot
.28044 .54542 Mdot
.42409 .59556 Mdot
.10911 .40105 Mdot
.72921 .36151 Mdot
.3305 .40606 Mdot
.65461 .64575 Mdot
.77369 .33938 Mdot
.3219 .30583 Mdot
.60321 .78869 Mdot
.47164 .55675 Mdot
.46748 .35881 Mdot
.48258 .28244 Mdot
.33836 .75467 Mdot
.64634 .63407 Mdot
.2229 .72683 Mdot
.57065 .81756 Mdot
.44632 .72943 Mdot
.46503 .53785 Mdot
.35959 .46669 Mdot
.20155 .57423 Mdot
.67357 .6274 Mdot
.6439 .78102 Mdot
.70545 .73971 Mdot
.81525 .52473 Mdot
.18938 .67132 Mdot
.37407 .77788 Mdot
.71491 .27079 Mdot
.65988 .74474 Mdot
.33417 .49556 Mdot
.74856 .44327 Mdot
.61277 .6542 Mdot
.4963 .72009 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`24ooooo`;o00009?oo
ool2o`0009gooooo000Looooo`03o`000?oooooooooo08Cooooo0_l0000Tooooo`;o0000WOooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo09cooooo0_l0000Hooooo`;o0000TOooool001co
oooo00?o0000ooooooooool0W?ooool2o`0001Sooooo0_l0002Aooooo`007?ooool00ol0003ooooo
ooooo`35ooooo`;o0000P_ooool001cooooo00?o0000ooooooooool0Poooool2o`0000_ooooo0_l0
000:ooooo`;o00002?ooool2o`0001gooooo0_l00022ooooo`007?ooool00ol0003oooooooooo`23
ooooo`;o00002oooool2o`0000[ooooo0_l00006ooooo`Co00001?ooool2o`0000Cooooo0_l0002E
ooooo`007?ooool00ol0003oooooooooo`2Gooooo`;o00002oooool2o`0000Kooooo0_l000001?oo
oooo0000o`000?ooool2o`0009Gooooo000Looooo`03o`000?oooooooooo09Oooooo0_l00009oooo
o`;o00002oooool2o`0009Sooooo000Looooo`03o`000?oooooooooo08[ooooo0_l0000Fooooo`;o
00006_ooool2o`0008Wooooo000Looooo`;o0000Roooool2o`0000Sooooo0_l0000<ooooo`;o0000
4Oooool2o`0000Oooooo0_l00029ooooo`007?ooool00ol0003oooooooooo`2Aooooo`;o000000?o
ooooo`000?l000003?ooool2o`00017ooooo0_l00007ooooo`;o0000ROooool001cooooo00?o0000
ooooooooool0TOooool2o`0001gooooo0_l0000<ooooo`;o00000oooool2o`0000Gooooo0_l0001m
ooooo`007?ooool00ol0003oooooooooo`1Vooooo`;o0000B?ooool2o`00017ooooo1?l00003oooo
o`;o0000OOooool001cooooo00?o0000ooooooooool0I_ooool2o`0003Gooooo0_l0000Vooooo`;o
0000P_ooool001cooooo00?o0000ooooooooool0ROooool2o`0001;ooooo0_l0002Zooooo`007?oo
ool00ol0003oooooooooo`1booooo`;o00003_ooool2o`0000Gooooo0_l0000Cooooo`;o00000_oo
ool2o`0001oooooo0_l00024ooooo`007?ooool00ol0003oooooooooo`1booooo`;o00003_ooool2
o`000003ooooool0003o000000Sooooo0_l0000=ooooo`;o00000_ooool2o`0000Wooooo0_l00004
ooooo`;o00002Oooool2o`0000?ooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l0
001jooooo`007?ooool00ol0003oooooooooo`25ooooo`;o00002?ooool2o`0000gooooo0_l00002
ooooo`;o00000oooool2o`0000Cooooo0_l00004ooooo`;o00002Oooool2o`000003ooooool0003o
000000Cooooo0_l000001?oooooo0000o`000?ooool2o`0007[ooooo000Looooo`03o`000?oooooo
oooo07gooooo0_l0000Sooooo`;o00000oooool2o`000003ooooool0003o000001Gooooo0_l00009
ooooo`;o00001_ooool2o`0007?ooooo000Looooo`03o`000?oooooooooo07gooooo0_l0000Hoooo
o`;o00004Oooool2o`000003ooooool0003o000000gooooo0_l00009ooooo`;o00000oooool2o`00
00Kooooo0_l0001cooooo`007?ooool00ol0003oooooooooo`28ooooo`;o00002oooool4o`0000;o
oooo0_l00007ooooo`;o00001oooool3o`0000cooooo0_l00009ooooo`;o00003_ooool2o`00073o
oooo000Looooo`03o`000?oooooooooo07gooooo0_l00009ooooo`;o00001?ooool2o`0000Gooooo
0_l00004ooooo`;o00001oooool2o`0000Sooooo1?l0000Fooooo`;o00001oooool2o`0000Cooooo
0_l0001`ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Ko
oooo00?o0000ooooooooool0Moooool2o`0000Cooooo0_l00005ooooo`;o00001Oooool2o`000003
ooooool0003o000000Sooooo0_l00008ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o
00003_ooool2o`0000Oooooo0_l0001fooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5oooo
o`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0K_ooool2
o`0000Gooooo1?l00008ooooo`;o000000?oooooo`000?l000001Oooool2o`0000_ooooo0ol00007
ooooo`?o00001?ooool2o`0000?ooooo0_l00003ooooo`Co000000?oooooo`000?l000000ol0002<
ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^
00Oooooo00?o0000ooooooooool0K_ooool2o`0000Gooooo0_l0000:ooooo`;o000000?oooooo`00
0?l000004Oooool4o`0000Sooooo0ol00008ooooo`;o00000oooool4o`0000?ooooo0ol0000Boooo
o`Co0000M_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So
8B4Qonk^kP06ooooo`?o0000POooool2o`000003ooooool0003o000000Oooooo0_l00004ooooo`Ko
00000_ooool2o`0000;ooooo0ol000001?oooooo0000o`000?l00005ooooo`;o00002_ooool2o`00
00Gooooo0_l0000=ooooo`Oo0000MOooool00003ooooool0003ooooo00;ooooo00?o0000oooooooo
ool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo073ooooo0_l00008ooooo`;o
00002?ooool2o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`Ko00000_ooool2o`0000;o
oooo0ol00002ooooo`Co00000_ooool4o`0000Wooooo0_l00003ooooo`Co00003Oooool4o`000003
ooooool0003o000007Gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1/ooooo`;o00000_ooool2o`0000?ooooo
0_l00003ooooo`;o00001?ooool2o`0000Sooooo0_l00006ooooo`;o00002Oooool2o`0000Gooooo
1?l00002ooooo`Co00001Oooool2o`0000Oooooo1Ol00007ooooo`;o00001?ooool3o`0000Cooooo
0_l0001booooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRH
V?l@41001_ooool00ol0003oooooooooo`1Nooooo`;o00003?ooool2o`0000Kooooo0ol00003oooo
o`;o00001?ooool2o`0000Gooooo0ol00008ooooo`;o00000oooool2o`0000Cooooo0_l0000Doooo
o`;o00001oooool5o`0000?ooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0ol00004
ooooo`;o0000L_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`00
0?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0GOooool3o`0000gooooo0_l000000ooooooo0000
o`000002ooooo`;o00001?ooool4o`0000Wooooo0ol000000ooooooo0000o`00000:ooooo`;o0000
7?ooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Kooooo0_l00003ooooo`;o0000
Koooool001cooooo00?o0000ooooooooool0GOooool2o`0000Sooooo0_l00004ooooo`;o000000?o
ooooo`000?l000002_ooool2o`0000Sooooo0ol00002ooooo`Co00002Oooool2o`0001_ooooo0_l0
00000ooooooo0000o`00000:ooooo`?o00001?ooool7o`000003ooooool0003o000000?ooooo0_l0
001_ooooo`007?ooool00ol0003oooooooooo`1Wooooo`;o00007Oooool2o`0000?ooooo1ol00002
ooooo`;o00000_ooool2o`000003ooooool0003o000000?o00000_ooool2o`0000Oooooo0_l0000;
ooooo`;o00000oooool2o`0000Kooooo0_l00004ooooo`Oo0000Moooool001cooooo00?o0000oooo
ooooool0J_ooool2o`0000Gooooo0ol00005ooooo`;o00002?ooool2o`0000Kooooo1ol00002oooo
o`;o000000?oooooo`000?l000000_ooool5o`0000;ooooo0_l00007ooooo`Co00001oooool2o`00
00Gooooo1?l00004ooooo`Co000000?oooooo`000?l000001?ooool2o`00017ooooo0_l0001Toooo
o`007?ooool00ol0003oooooooooo`1Zooooo`;o00001Oooool3o`0000?ooooo1?l00006ooooo`Co
00002?ooool2o`0000Cooooo0_l00002ooooo`;o00002Oooool2o`0000Sooooo0ol00007ooooo`;o
00001oooool2o`000003ooooool0003o000000;ooooo0ol000000ooooooo0000o`000004ooooo`;o
00004Oooool2o`0006Cooooo000Looooo`03o`000?oooooooooo06;ooooo0_l00005ooooo`?o0000
2oooool2o`0000Sooooo0_l00002ooooo`;o00002Oooool2o`000003ooooool0003o000000;ooooo
0_l00002ooooo`;o00003oooool2o`0000_ooooo0_l00004ooooo`;o000000?oooooo`000?l00000
0_ooool2o`0000;ooooo0_l0001mooooo`007?ooool00ol0003oooooooooo`1Rooooo`;o00001Ooo
ool2o`0000Kooooo0_l0000=ooooo`?o00000_ooool2o`0000Cooooo0_l00003ooooo`Co00000ooo
ool2o`0000;ooooo0_l0000;ooooo`;o00003Oooool4o`0000Cooooo0_l0000?ooooo`;o00000_oo
ool2o`0000Kooooo0_l000000ooooooo0000o`00001Xooooo`007?ooool00ol0003oooooooooo`14
ooooo`;o00008?ooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o00003Oooool2
o`0000Wooooo0_l00005ooooo`;o00001?ooool2o`0000kooooo0_l000000ooooooo0000o`000003
ooooo`;o00001Oooool2o`0001Oooooo0_l00002ooooo`;o00001_ooool2o`000003ooooool0003o
000000Cooooo0_l0001Rooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00008?ooool2o`00
00Gooooo0_l00005ooooo`;o00003?ooool2o`0000Sooooo0_l00002ooooo`;o00001_ooool2o`00
017ooooo0_l00003ooooo`;o00001_ooool2o`000003ooooool0003o000001?ooooo0_l0000:oooo
o`;o00001oooool2o`0006;ooooo000Looooo`03o`000?oooooooooo07Cooooo1?l00008ooooo`Co
00002?ooool2o`0000;ooooo0_l0000;ooooo`;o00006Oooool2o`000003ooooool0003o000000Go
oooo0_l00007ooooo`;o00001oooool2o`0000Gooooo0_l00008ooooo`;o0000H_ooool001cooooo
00?o0000ooooooooool0G?ooool3o`0001Gooooo1?l00008ooooo`Ko00001_ooool2o`0000gooooo
1?l0000;ooooo`;o00003oooool2o`0000Gooooo0_l00007ooooo`;o000000?oooooo`000?l00000
1?ooool2o`0000Gooooo0_l0000:ooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0G?oo
ool3o`0000?ooooo0_l00005ooooo`;o00002Oooool2o`0000_ooooo0_l000000ooooooo0000o`00
0006ooooo`;o00003Oooool2o`000004ooooool0003o0000o`0000Wooooo0_l00002ooooo`;o0000
4Oooool2o`0000_ooooo0_l00005ooooo`;o00003?ooool2o`0000;ooooo0ol0001Oooooo`007?oo
ool2o`00053ooooo0_l0000;ooooo`;o00001?ooool2o`0000Gooooo0_l00009ooooo`;o00002ooo
ool2o`0001_ooooo1ol00009ooooo`;o00000_ooool2o`0000Oooooo0_l00004ooooo`;o00002?oo
ool2o`0000Sooooo0_l00004ooooo`;o00001_ooool4o`000003ooooool0003o000005oooooo000L
ooooo`03o`000?oooooooooo04oooooo0_l0000;ooooo`;o00001Oooool2o`0001Gooooo0_l0000T
ooooo`Go00003Oooool2o`0000Oooooo0_l0000>ooooo`;o00002?ooool4o`0000;ooooo0_l00008
ooooo`;o00000_ooool2o`0005kooooo000Looooo`03o`000?oooooooooo06?ooooo0_l0000;oooo
o`;o00002?ooool2o`0002_ooooo0_l0000Kooooo`Go00003_ooool2o`00013ooooo0_l0001Noooo
o`007?ooool00ol0003oooooooooo`1Qooooo`;o00003Oooool2o`0003Gooooo0_l00004ooooo`;o
00005?ooool6o`0000oooooo0_l0001_ooooo`007?ooool00ol0003oooooooooo`1Qooooo`Co0000
4_ooool2o`0003?ooooo0ol0000Dooooo`?o00001?ooool2o`0000cooooo0_l000000ooooooo0000
o`00001/ooooo`007?ooool00ol0003oooooooooo`1Sooooo`;o00004_ooool2o`0003?ooooo0_l0
00000ooooooo0000o`00000Gooooo`Co00003oooool2o`0000Oooooo0_l00004ooooo`;o0000GOoo
ool001cooooo00?o0000ooooooooool0B?ooool2o`00023ooooo0_l00007ooooo`;o00002_ooool2
o`0001oooooo0_l0000=ooooo`;o00003?ooool2o`0000Wooooo0_l000000ooooooo0000o`00000<
ooooo`;o00002Oooool2o`000004ooooool0003o0000ooooo`Co0000Foooool001cooooo00?o0000
ooooooooool0B?ooool2o`00023ooooo0_l00007ooooo`;o00002_ooool2o`0001kooooo0ol0000C
ooooo`?o00001Oooool2o`0000cooooo0_l00006ooooo`;o000000Coooooo`000?l0003ooooo0ol0
0006ooooo`Co000000?oooooo`000?l000000oooool2o`0005_ooooo000Looooo`03o`000?oooooo
oooo07;ooooo0_l00004ooooo`;o00009Oooool2o`0000?ooooo0_l0000?ooooo`?o00002_ooool5
o`0000cooooo0_l000000ooooooo0000o`000002ooooo`;o000000Coooooo`000?l0003o00000_oo
ool2o`000003ooooool0003o000000Kooooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`1M
ooooo`;o000000?oooooo`000?l000002_ooool2o`0000Cooooo0_l00004ooooo`;o00006_ooool2
o`0000Sooooo0_l00004ooooo`;o00007?ooool5o`0000Sooooo0_l00003ooooo`;o00001Oooool5
o`0000?ooooo1?l00006ooooo`;o0000F_ooool001cooooo00?o0000ooooooooool0G?ooool3o`00
0003ooooool0003o000000Cooooo0_l00004ooooo`Co00000_ooool2o`0000Sooooo0_l0000Foooo
o`;o00000oooool2o`0000?ooooo0_l0000Sooooo`;o00002_ooool2o`0000;ooooo0ol00005oooo
o`;o00001_ooool2o`0000Gooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1Kooooo`?o
00001oooool3o`0000Kooooo0_l0000:ooooo`Co00006oooool5o`0002Gooooo1Ol00004ooooo`;o
00001Oooool2o`0000Sooooo0_l00007ooooo`;o00000_ooool3o`0005cooooo000Looooo`03o`00
0?oooooooooo03Oooooo0_l0000Rooooo`;o00000oooool2o`0000?ooooo1Ol0000@ooooo`;o0000
7_ooool4o`0002Kooooo1_l000000ooooooo0000o`000005o`0000Oooooo0_l00002ooooo`;o0000
1oooool4o`000003ooooool0003o000005cooooo000Looooo`03o`000?oooooooooo03Oooooo0_l0
000:ooooo`;o00006oooool2o`0000Cooooo1?l00004ooooo`;o00008Oooool2o`0000Gooooo0_l0
000Eooooo`;o00001Oooool2o`0000_ooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo
1?l00007ooooo`;o00002_ooool2o`000003ooooool0003o000005oooooo000Looooo`03o`000?oo
oooooooo043ooooo0_l000000ooooooo0000o`00000Sooooo`;o00001?ooool2o`00027ooooo0_l0
0005ooooo`;o00002oooool2o`0000Sooooo0_l00005ooooo`;o00000_ooool2o`000003ooooool0
003o000000Cooooo0_l00007ooooo`;o00001_ooool3o`0000Wooooo0_l00003ooooo`;o0000H_oo
ool001cooooo00?o0000ooooooooool0@?ooool2o`0002Kooooo0_l0000Uooooo`Co00004_ooool2
o`000003ooooool0003o0000013ooooo0_l000000ooooooo0000o`00000=ooooo`?o000000?ooooo
o`000?l000000_ooool3o`0000;ooooo0_l00002ooooo`Go00002Oooool2o`0005cooooo000Loooo
o`;o0000G_ooool2o`0000Cooooo0_l0000Cooooo`;o000000?oooooo`000?l000004?ooool4o`00
017ooooo0_l00004ooooo`;o00006oooool2o`0000Gooooo0ol000000ooooooo0000o`000002oooo
o`;o00000_ooool3o`0000;ooooo1?l00006ooooo`;o00000_ooool4o`0005[ooooo000Looooo`03
o`000?oooooooooo04kooooo0_l00007ooooo`;o00001?ooool2o`0000Cooooo0ol00002ooooo`;o
00003?ooool4o`000003ooooool0003o0000013ooooo0_l0000@ooooo`Go00005_ooool2o`0000Wo
oooo0_l00003ooooo`;o00000oooool4o`0000;ooooo0_l000000ooooooo0000o`000002o`000003
ooooool0003o000000;o00001_ooool2o`0000Cooooo0_l0001Jooooo`007?ooool00ol0003ooooo
ooooo`1>ooooo`;o00001oooool2o`0000Cooooo0_l00002ooooo`Wo00003?ooool2o`00023ooooo
0_l00005ooooo`?o000000?oooooo`000?l000002Oooool3o`0000Gooooo0_l00002ooooo`Co0000
1Oooool2o`000003ooooool0003o000000;ooooo1?l000000ooooooo0000o`000003o`000003oooo
ool0003o000000;ooooo0ol000000ooooooo0000o`000002o`000003ooooool0003o000000Wooooo
0_l0001Jooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o00002Oooool2o`0000;ooooo0ol0
00000ooooooo0000o`000002ooooo`Co00007oooool2o`0000Gooooo0_l00007ooooo`;o00000_oo
ool2o`0000Gooooo0_l00003ooooo`;o00001?ooool5o`0000?ooooo0_l00003ooooo`?o000000?o
ooooo`000?l000000_ooool5o`0000Cooooo0_l00004ooooo`;o00000_ooool2o`0000;ooooo0_l0
0006ooooo`;o000000?oooooo`000?l000000_l0000>ooooo`;o0000D?ooool001cooooo00?o0000
ooooooooool0E?ooool2o`0000;ooooo1Ol000000ooooooo0000o`000006ooooo`;o00000_ooool2
o`0000Wooooo1?l0000?ooooo`;o00001Oooool2o`0000?ooooo0_l00003ooooo`;o000000Cooooo
o`000?l0003ooooo0_l00007ooooo`;o00000_ooool2o`0000?ooooo0_l00005ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0000Cooooo0_l00004ooooo`;o00002Oooool2o`0000;ooooo0_l0
0009ooooo`Co00003_ooool2o`00053ooooo000Looooo`03o`000?oooooooooo05Cooooo0_l00002
ooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000Co00000_ooool2
o`0000Wooooo1?l000000ooooooo0000o`00000<ooooo`;o00001Oooool2o`0000?ooooo0ol00002
ooooo`;o000000Coooooo`000?l0003ooooo0ol00002ooooo`;o00001_ooool2o`0000Cooooo0_l0
0002ooooo`Co00000_ooool2o`0000Oooooo0_l00004ooooo`;o000000?oooooo`000?l000003Ooo
ool2o`0001Kooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`0kooooo`;o00002oooool2
o`0000;ooooo0_l0000Aooooo`;o000000?oooooo`000?l000000_l0000>ooooo`;o00001?ooool2
o`0000cooooo0ol0000:ooooo`;o00001Oooool3o`000003ooooool0003o000000;ooooo0_l00008
ooooo`;o000000Goooooo`000?l0003o0000ooooo`03o`0000Cooooo0_l00007ooooo`;o00001_oo
ool3o`0000Cooooo1?l00005ooooo`;o00001oooool2o`0000Sooooo0_l00003ooooo`;o0000D_oo
ool001cooooo00?o0000ooooooooool0>oooool2o`0000;ooooo0_l00007ooooo`;o000000Cooooo
o`000?l0003o00002oooool2o`0001Wooooo1?l00002ooooo`;o00002Oooool2o`0000;ooooo0_l0
00000ooooooo0000o`000004ooooo`;o00002Oooool2o`0000?ooooo1?l00008ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0000?ooooo0_l00009ooooo`;o00001_ooool3o`0000Cooooo2?l0
0004ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o000000?oooooo`000?l00000
1?l0001Fooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00002Oooool3o`000003ooooool0
003o000000Sooooo0ol000000ooooooo0000o`00000Hooooo`;o00000oooool2o`0000Sooooo0_l0
0005ooooo`Co00000_ooool2o`000004ooooool0003o0000ooooo`;o00000_ooool4o`000003oooo
ool0003o000000?o00001?ooool3o`0000[ooooo0_l000000ooooooo0000o`000003ooooo`;o0000
1?ooool2o`0000?ooooo0_l0000<ooooo`Ko00000_ooool2o`000003ooooool0003o000000Cooooo
0ol000000ooooooo0000o`000004o`0005Kooooo000Looooo`03o`000?oooooooooo04[ooooo0_l0
0002ooooo`;o00000_ooool2o`0000Cooooo0ol000000ooooooo0000o`00000<ooooo`;o00002_oo
ool3o`0000;ooooo0_l0000Aooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o0000
0_ooool4o`000004ooooool0003o0000o`0000Kooooo1?l00003ooooo`;o00000oooool3o`000003
ooooool0003o000000?ooooo0_l00009ooooo`;o00000_ooool3o`0000[ooooo0ol00004ooooo`?o
00001?ooool2o`000004ooooool0003o0000o`0000cooooo0_l0001<ooooo`007?ooool00ol0003o
ooooooooo`1@ooooo`Ko00000_ooool3o`0000kooooo1Ol00009ooooo`;o00005Oooool2o`0000go
oooo1?l00003ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000?o
oooo0_l000001?oooooo0000o`000?l00007ooooo`;o00002Oooool5o`0000oooooo0ol00007oooo
o`;o00001Oooool2o`0000Gooooo0ol0001<ooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o
00007?ooool2o`0000;ooooo1_l0000Cooooo`;o000000?oooooo`000?l000001?ooool2o`0000Oo
oooo0_l0000@ooooo`;o00002?ooool2o`0000?ooooo1Ol000000ooooooo0000o`000009o`0000;o
oooo1Ol000000ooooooo0000o`000005o`0000Oooooo0_l00007ooooo`;o00000_ooool3o`00013o
oooo0_l00009ooooo`;o00000oooool2o`0000Gooooo0_l0001=ooooo`007?ooool00ol0003ooooo
ooooo`0^ooooo`;o00006Oooool5o`0000Cooooo0_l0000Nooooo`;o00001oooool2o`00013ooooo
0_l00007ooooo`?o00000ooooolAo`000003ooooool0003o000000co00001?ooool2o`000003oooo
ool0003o000000Oooooo0_l000000ooooooo0000o`000003o`0000_ooooo0ol00007ooooo`Co0000
00?oooooo`000?l00000FOooool001cooooo00?o0000ooooooooool0;oooool2o`0001Sooooo1?l0
0012ooooo`;o000000?oooooo`000?l000001?l00005oooooa3o000000?oooooo`000?l000001_l0
00000ooooooo0000o`000003o`0000Cooooo0_l000000ooooooo0000o`00000:ooooo`Go00000ooo
ool2o`0000Kooooo0ol00007ooooo`Co00002oooool2o`0004oooooo000Looooo`03o`000?oooooo
oooo02oooooo0_l0000<ooooo`;o00001oooool2o`0000?ooooo0_l00002ooooo`;o0000:?ooool2
o`0000?ooooo0_l00007ooooo`;o00001_ooool2o`000003ooooool0003o000000?o00001_oooolI
o`000003ooooool0003o000000;o00004?ooool2o`0000Gooooo0_l00003ooooo`Co00000oooool2
o`0001Sooooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00001oooool2o`00
0003ooooool0003o000000?ooooo0ol0000?ooooo`?o00001?ooool2o`00013ooooo0_l00003oooo
o`;o00001oooool2o`0000Cooooo0_l00005ooooo`;o00000oooool2o`000003ooooool0003o0000
01go00004?ooool2o`0000Cooooo0_l00003ooooo`Go00000oooool4o`0006Oooooo000Looooo`;o
0000B_ooool2o`0000?ooooo0_l0000@ooooo`?o000000Coooooo`000?l0003ooooo0_l0000=oooo
o`;o00000_ooool2o`00017ooooo0_l000001?oooooo0000o`000?ooool5o`000004ooooool0003o
0000ooooo`;o00000_oooolIo`0000cooooo0_l00005ooooo`?o00000_ooool2o`000003ooooool0
003o000000;o00001?ooool2o`0000;ooooo1?l00008ooooo`Ko00002?ooool2o`0004gooooo000L
ooooo`03o`000?oooooooooo03?ooooo0_l000000ooooooo0000o`00000:ooooo`;o00008?ooool2
o`0000?ooooo0_l0000;ooooo`?o000000?oooooo`000?l000005?ooool2o`000004ooooool0003o
0000ooooo`;o000000Coooooo`000?l0003ooooo4?l000000ooooooo0000o`000009o`0000Kooooo
0_l00005ooooo`;o00001Oooool3o`0000Gooooo0_l00002ooooo`;o00000_ooool2o`0000Cooooo
0_l00004ooooo`;o00000_ooool6o`0000Kooooo1Ol0001<ooooo`007?ooool00ol0003ooooooooo
o`0cooooo`;o000000Coooooo`000?l0003ooooo0_l00007ooooo`;o00002_ooool2o`00013ooooo
0_l00007ooooo`?o000000?oooooo`000?l000002?ooool2o`0000kooooo0_l0000:ooooo`;o0000
1?ooool?o`000003ooooool0003o000000go00000oooool5o`0000gooooo0ol000000ooooooo0000
o`000005ooooo`;o00003?ooool4o`0000kooooo0_l000001?oooooo0000o`000?l0001;ooooo`00
7?ooool00ol0003oooooooooo`0iooooo`;o00003?ooool2o`0000Gooooo0ol00003ooooo`;o0000
2_ooool2o`0000Sooooo0_l000000ooooooo0000o`00000Hooooo`Co00002?oooolEo`000003oooo
ool0003o000000ko00000_ooool3o`000003ooooool0003o000000gooooo0_l000000ooooooo0000
o`000008ooooo`;o00002Oooool2o`0000Sooooo0_l0000:ooooo`Co0000BOooool001cooooo00?o
0000ooooooooool0@Oooool4o`0000;ooooo0_l00006ooooo`;o000000?oooooo`000?l000000_l0
000Nooooo`;o00001Oooool2o`0000cooooo0_l00009ooooobGo000000Coooooo`000?l0003ooooo
1?l0000;ooooo`Co00001?ooool2o`000003ooooool0003o000000;ooooo0_l00009ooooo`;o0000
00?oooooo`000?l000001Oooool2o`0000Oooooo0_l00003ooooo`;o0000BOooool001cooooo00?o
0000ooooooooool0@Oooool4o`0000?ooooo0_l00008ooooo`;o00003?ooool2o`000003ooooool0
003o000000Sooooo0ol00004ooooo`?o00001?ooool2o`0001Kooooo0_l00003ooooo`;o000000?o
ooooo`000?l000006ol00002ooooo`;o000000?oooooo`000?l000001Ol00008ooooo`Co000000Co
ooooo`000?l0003ooooo0_l000000ooooooo0000o`000002ooooo`;o00001Oooool2o`0000;ooooo
0_l000000ooooooo0000o`00000>ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0B?oo
ool2o`000003ooooool0003o000001?ooooo0_l000000ooooooo0000o`000008ooooo`?o00000_oo
ool2o`000003ooooool0003o000000Gooooo0_l000000ooooooo0000o`00000=ooooo`;o000000?o
ooooo`000?l000001?l000000ooooooo0000o`000004o`0000;ooooo6?l00002ooooo`;o000000?o
ooooo`000?l000001Ol00004ooooo`;o00000_ooool2o`0000?ooooo0_l00008ooooo`;o00001Ooo
ool2o`0000[ooooo0ol00008ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0?oooool2
o`0000?ooooo0_l00003ooooo`Co00002oooool2o`0001Cooooo0_l00002ooooo`;o00001_ooool4
o`000003ooooool0003o000000;o00002oooool2o`000003ooooool0003o000001go000000?ooooo
o`000?l000001ol00003ooooo`Go00001_ooool2o`0000;ooooo0_l0000Dooooo`;o00000_ooool2
o`0000Kooooo0ol0001Hooooo`007?ooool00ol0003oooooooooo`0kooooo`;o00000_ooool2o`00
00?ooooo0_l00003ooooo`?o00003?ooool2o`00023ooooo1?l00003ooooo`;o00002?ooool2o`00
00Cooooo0ol000000ooooooo0000o`00000;o`000003ooooool0003o000000_o000000?oooooo`00
0?l000001ol00003ooooo`?o00006Oooool2o`0000Wooooo1?l0000Aooooo`;o00001oooool2o`00
04Gooooo000Looooo`03o`000?oooooooooo02Oooooo0_l0000Booooo`;o00003Oooool2o`0000?o
oooo0_l0000Tooooo`;o00001Oooool2o`0000Sooooo0_l00003ooooo`;o00001Oooool5o`000003
ooooool0003o000001oo000000Coooooo`000?l0003o00004?ooool2o`0000[ooooo0_l00008oooo
o`?o00002Oooool2o`0000Sooooo0ol000000ooooooo0000o`000002o`000003ooooool0003o0000
04Gooooo000Looooo`03o`000?oooooooooo02Oooooo0_l0000=ooooo`;o00001Oooool2o`00013o
oooo0ol00003ooooo`;o00002Oooool2o`0001?ooooo0_l00004ooooo`;o00002Oooool2o`0000?o
oooo0_l00002ooooobWo000000?oooooo`000?l000000_l0000@ooooo`;o00005?ooool2o`0000[o
oooo0_l00009ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000015ooooo`00
7?ooool00ol0003oooooooooo`0fooooo`;o00001Oooool2o`0000Kooooo0_l00009ooooo`;o0000
0oooool2o`0000Wooooo0_l0000=ooooo`;o00002_ooool2o`0000?ooooo0_l00009ooooo`;o0000
0_ooool5o`000003ooooool0003o000000So000000?oooooo`000?l000007?l00002ooooo`;o0000
3oooool2o`0000Kooooo1?l0000<ooooo`;o00002Oooool2o`0000cooooo0_l00015ooooo`007?oo
ool00ol0003oooooooooo`0Yooooo`;o00006_ooool2o`0000Oooooo0_l0000Hooooo`;o00001Ooo
ool2o`0000kooooo0ol00003ooooo`;o00002?ooool2o`000004ooooool0003o0000ooooobko0000
1?ooool2o`0000Sooooo0_l00006ooooo`Co00003?ooool2o`0000Wooooo0_l000000ooooooo0000
o`000006ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0:Oooool2o`0001[ooooo0_l0
0006ooooo`?o00006?ooool4o`0000?ooooo0ol0000=ooooo`;o000000Coooooo`000?l0003ooooo
0_l00004ooooo`Ko000000?oooooo`000?l000000ooooolSo`0000?ooooo1_l00004ooooo`;o0000
3?ooool2o`0000Sooooo0_l00008ooooo`;o00001_ooool2o`0000Cooooo0_l00006ooooo`;o0000
B?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413o
ooooooooo`04ooooo`03o`000?oooooooooo02cooooo0_l00008ooooo`;o00003Oooool2o`0000;o
oooo0_l00002ooooo`;o00000_ooool2o`0000cooooo0_l00005ooooo`Ko00001?ooool2o`0000Co
oooo1?l00008ooooo`;o00001oooool6o`000005ooooool0003o0000o`000?ooool09_l000000ooo
oooo0000o`000002ooooo`;o00000_ooool2o`0000Gooooo0_l00007ooooo`;o00002?ooool2o`00
00_ooooo1?l000000ooooooo0000o`00000;ooooo`;o0000BOooool00006oooooomgMgOoV9RHoooo
oonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0/
ooooo`;o00002?ooool2o`0000Gooooo0_l0000:ooooo`;o00001_ooool2o`0000cooooo0_l00005
ooooo`;o00002?ooool2o`0000?ooooo1Ol0000;ooooo`;o00002ooooolPo`000003ooooool0003o
000000So00002?ooool2o`0000Gooooo0_l0000;ooooo`;o00001oooool2o`0000Cooooo0_l00002
ooooo`Co00001_ooool2o`0000Kooooo0_l00004ooooo`Co0000@Oooool00003ooooool@413ooooo
00;ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo00?o0000ooooooooool0=_ooool2o`00
00Gooooo0_l0000Booooo`;o00005?ooool2o`0000Oooooo0_l000000ooooooo0000o`000002o`00
00[ooooo0_l000001?oooooo0000o`000?l00008ooooo`;o00000ooooolNo`000003ooooool0003o
000000So00002?ooool2o`0000;ooooo0_l0000>ooooo`;o00001oooool2o`0000Cooooo0_l0000<
ooooo`;o00000oooool2o`0000Cooooo0_l000000ooooooo0000o`000002o`00047ooooo00000ooo
oooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool3
o`00023ooooo0_l0000Dooooo`;o00002Oooool2o`0000Oooooo0_l00005ooooo`;o000000Cooooo
o`000?l0003ooooo0_l00007ooooo`;o00000oooool4o`0000?ooooo1?l00003ooooo`;o00002?oo
ool2o`0000;ooooo1_l00008ooooo`;o00000_oooolAo`000003ooooool0003o000001_o00000ooo
ool2o`0000;ooooo0_l00008ooooo`;o00003?ooool2o`0000;ooooo0_l0000=ooooo`;o00001Ooo
ool2o`0000Cooooo0_l0000Kooooo`;o0000:Oooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool02Oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo023ooooo0_l0
000Oooooo`;o00001oooool2o`0000Sooooo0_l000001?oooooo0000o`000?l00006ooooo`?o0000
0_ooool5o`0000;ooooo1?l0000=ooooo`?o00000_ooool2o`000003ooooool0003o000000Wooooo
0_l000001?oooooo0000o`000?ooool<o`0000?ooooo7Ol00006ooooo`?o00002?ooool2o`0000So
oooo0_l00002ooooo`;o00000_ooool2o`0000gooooo0_l00004ooooo`;o00008_ooool2o`0002Wo
oooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oMgMgolc<c?l00000
1oooool00ol0003oooooooooo`0kooooo`;o00006oooool2o`0000Kooooo0ol00002ooooo`Go0000
1Oooool2o`0000Wooooo0_l00002ooooo`;o00003_ooool4o`0000Cooooo:Ol00002ooooo`?o0000
0_ooool5o`0000?ooooo0_l00002ooooo`;o00002Oooool2o`0000;ooooo0_l00004ooooo`;o0000
00?oooooo`000?l000000_ooool2o`0000[ooooo1?l0001;ooooo`0000KoooooogMgMonHV9Sooooo
oiRHV?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0>oooool2o`0000Oo
oooo0_l0000Aooooo`;o00001?ooool2o`000003ooooool0003o000000?o000000Coooooo`000?l0
003o00001_ooool2o`0000Gooooo0_l00002ooooo`;o00004_ooool2o`0000Cooooo0_l00002oooo
o`;o000000?oooooo`000?l000008ol000001?oooooo0000o`000?l00002ooooo`;o00001_ooool2
o`0000;ooooo0_l00003ooooo`;o00000_ooool4o`0000;ooooo0_l00004ooooo`;o000000?ooooo
o`000?l000000_ooool4o`0000[ooooo0_l00005ooooo`Co0000@_ooool00006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo03_ooooo0_l0
0007ooooo`;o00004Oooool2o`0000Cooooo2?l000000ooooooo0000o`000004o`0000[ooooo0_l0
000Cooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`00000Lo`0000;ooooo2_l0
00001?oooooo0000o`000?l00006ooooo`;o00003_ooool3o`000003ooooool0003o000000;o0000
0oooool2o`0000Kooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l00007ooooo`;o
00000oooool4o`0004;ooooo000Looooo`03o`000?oooooooooo03_ooooo0_l0000Rooooo`Ko0000
00?oooooo`000?l000001?l000000ooooooo0000o`000002o`000005ooooool0003o0000o`000?oo
ool00_l00005ooooo`;o00003?ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l0
00008ol000000ooooooo0000o`000003ooooo`?o00000_ooool2o`0000;ooooo0_l0000=ooooo`Co
00000_ooool3o`0000?ooooo0ol00005ooooo`Go00001_ooool2o`000003ooooool0003o000000Co
oooo0_l00019ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00002?ooool2o`0001cooooo
4Ol000000ooooooo0000o`000002o`000005ooooool0003o0000o`000?ooool00_l00005ooooo`?o
00002_ooool2o`0000;ooooo1ol00002ooooo`;o000000?oooooo`000?l000007_l000000ooooooo
0000o`000003o`0000?ooooo0_l00003ooooo`;o00002oooool3o`0000Cooooo0_l00005ooooo`Co
00001Oooool2o`0000Kooooo0_l000001?oooooo0000o`000?l0001?ooooo`007?ooool00ol0003o
ooooooooo`0aooooo`Co000000?oooooo`000?l000001Oooool2o`0000Cooooo0_l00008ooooo`;o
00000oooool2o`0000Oooooo5ol0000<ooooo`;o00002_ooool2o`0000;ooooo0ol000001?oooooo
0000o`000?l00003ooooobOo000000Coooooo`000?l0003ooooo0_l00003ooooo`;o000000?ooooo
o`000?l000001_ooool4o`0000;ooooo0_l0000:ooooo`;o00000oooool2o`0000Oooooo0ol00000
0ooooooo0000o`00000;ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0<Oooool2o`00
00?ooooo0_l00005ooooo`;o00001?ooool2o`0000Sooooo0_l00002ooooo`?o00001ooooolGo`00
00?ooooo0_l00008ooooo`;o00003Oooool3o`0000;ooooo8?l000001?oooooo0000o`000?ooool6
o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000001_ooool2
o`0000Cooooo0_l0000:ooooo`;o00000oooool2o`0000Oooooo0_l0000?ooooo`;o0000@oooool0
01cooooo00?o0000ooooooooool0:Oooool2o`0001;ooooo0_l000000ooooooo0000o`000005oooo
o`;o00001?ooool2o`0000;ooooo0_l0000:oooooaGo00000_ooool3o`0000Sooooo1?l00009oooo
o`;o00000oooool3o`000004ooooool0003o0000o`0000?ooooo1ol000000ooooooo0000o`00000?
o`0000;ooooo0_l00002ooooo`Co00001oooool2o`000003ooooool0003o000001Oooooo1_l00005
ooooo`;o00000oooool2o`0000Kooooo0ol00009ooooo`;o0000@_ooool001cooooo00?o0000oooo
ooooool0:Oooool2o`0000Kooooo0_l0000=ooooo`;o00001Oooool2o`0000Cooooo0_l0000:oooo
oa[o000000?oooooo`000?l000002Oooool4o`0000;ooooo0_l00004ooooo`?o00000oooool3o`00
0004ooooool0003o0000ooooo`Co000000?oooooo`000?l000003Ol000000ooooooo0000o`000006
o`000004ooooool0003o0000ooooo`Go000000?oooooo`000?l000001?ooool2o`0000oooooo0_l0
0009ooooo`Co000000?oooooo`000?l000001?ooool2o`0000?ooooo0ol00005ooooo`Co00002?oo
ool2o`0004;ooooo000Looooo`03o`000?oooooooooo02gooooo0_l00002ooooo`;o00003Oooool2
o`0000Cooooo1Ol0000<oooooaco00001oooool2o`0000Wooooo0_l00004ooooo`;o00000oooool5
o`0000?ooooo3?l000000ooooooo0000o`000007o`000003ooooool0003o000000Co000000Cooooo
o`000?l0003ooooo0_l000000ooooooo0000o`000003o`0000Cooooo1?l0000=ooooo`;o00003_oo
ool2o`0000Oooooo1Ol00007ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0;Oooool2
o`00017ooooo0_l00004ooooo`Go00002ooooolOo`0000Gooooo0_l0000Dooooo`;o000000?ooooo
o`000?l000000oooool6o`000003ooooool0003o000000So000000?oooooo`000?l000001?l00000
0ooooooo0000o`000006o`0000Cooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l0000M
ooooo`;o00001oooool2o`0000gooooo0_l00019ooooo`007?ooool00ol0003oooooooooo`1Boooo
o`;o00000_ooool<o`000003ooooool0003o000001Co00001oooool2o`0001Oooooo0_l000000ooo
oooo0000o`000002ooooo`co000000?oooooo`000?l000002ol00008ooooo`?o00008Oooool2o`00
00Oooooo0_l00003ooooo`;o00001oooool3o`0004Wooooo000Looooo`03o`000?oooooooooo037o
oooo0_l0000@ooooo`;o00002oooool4o`000003ooooool0003o000000_o00000_oooolEo`0000Oo
oooo0_l0000:ooooo`;o00002oooool2o`000003ooooool0003o000001go00001Oooool2o`000003
ooooool0003o000002Cooooo0_l00004ooooo`;o00000oooool2o`000003ooooool0003o000000Co
oooo0_l00002ooooo`;o00001Oooool2o`0003oooooo000Looooo`03o`000?oooooooooo02oooooo
1?l000000ooooooo0000o`000002o`0000_ooooo0_l00004ooooo`;o00000oooool4o`0000?ooooo
6_l000000ooooooo0000o`000006o`0000Oooooo0_l000000ooooooo0000o`000008ooooo`;o0000
2Oooool4o`000003ooooool0003o000000Go000000?oooooo`000?l000001ol00002ooooo`Oo0000
00?oooooo`000?l000001_l000000ooooooo0000o`000009ooooo`;o00007?ooool2o`0000Wooooo
0_l000000ooooooo0000o`000008ooooo`;o00001Oooool2o`0000Cooooo0_l0000iooooo`007?oo
ool2o`00033ooooo0_l00003ooooo`Co00004Oooool2o`0000;ooooo0ol00006ooooob7o00002?oo
ool2o`000003ooooool0003o000000;ooooo0_l00009ooooo`;o00000_ooool:o`0000;ooooo0ol0
0004ooooo`Wo000000?oooooo`000?l000001Ol00002ooooo`Co00003?ooool2o`000003ooooool0
003o000002Oooooo1?l00006ooooo`;o00000oooool2o`0000Kooooo0_l0000iooooo`007?ooool0
0ol0003oooooooooo`0_ooooo`;o00007?ooool2o`0000?ooooo6?l000000ooooooo0000o`000008
o`000003ooooool0003o000000kooooo0ol00008ooooo`;o00000_ooool7o`0000?ooooo1Ol00002
ooooo`Wo00001?ooool4o`000003ooooool0003o000001Cooooo0_l0000Wooooo`Co00001_ooool2
o`0000?ooooo0_l0000?ooooo`;o0000<?ooool001cooooo00?o0000ooooooooool0:?ooool2o`00
00Gooooo0_l0000Qooooob;o000000?oooooo`000?l000001Ol00008ooooo`;o000000Coooooo`00
0?l0003ooooo0_l0000>ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo2Ol00002
ooooo`Co00000oooool4o`0001kooooo0_l0000Xooooo`Co00002Oooool2o`0000;ooooo1?l0000`
ooooo`007?ooool00ol0003oooooooooo`0Xooooo`;o00008Oooool4o`0000Oooooo4Ol000000ooo
oooo0000o`000003o`000003ooooool0003o000000Co000000?oooooo`000?l000001Ol00008oooo
o`So00002_ooool2o`000004ooooool0003o0000o`0000;ooooo1?l000001?oooooo0000o`000?l0
0006ooooo`?o00000_ooool3o`0000Kooooo0_l00002ooooo`;o00004Oooool2o`0000Oooooo1Ol0
000<ooooo`;o00002?ooool2o`0000gooooo1?l00009ooooo`;o00000_ooool2o`0003;ooooo000L
ooooo`03o`000?oooooooooo03kooooo1?l00009ooooo`Go00001?oooolTo`0000cooooo0ol00000
1?oooooo0000o`000?l0000;ooooo`;o000000?oooooo`000?l000000oooool4o`000003ooooool0
003o000000Go00000oooool2o`000003ooooool0003o000000;o00002_ooool4o`0000oooooo1?l0
00000ooooooo0000o`000004ooooo`?o00003?ooool2o`0000Sooooo0_l00005ooooo`;o00002?oo
ool2o`00047ooooo000Looooo`03o`000?oooooooooo03kooooo1_l0000:ooooo`;o00001?ooool2
o`0000;ooooo8?l00008ooooo`;o00000_ooool2o`0000?ooooo0_l0000?ooooo`;o000000?ooooo
o`000?l000001oooool5o`0000;ooooo1Ol00009ooooo`;o00000_ooool5o`0000oooooo0_l00000
0ooooooo0000o`000004ooooo`;o00004?ooool2o`0000;ooooo0_l00004ooooo`;o00000_ooool2
o`0000Gooooo0_l000001?oooooo0000o`000?l00010ooooo`007?ooool00ol0003oooooooooo`0n
ooooo`;o000000Coooooo`000?l0003o00002_ooool2o`0000?ooooo0_l00002oooooaGo000000?o
ooooo`000?l000001ol00004ooooo`;o00001?ooool2o`0000;ooooo0_l00003ooooo`;o00003ooo
ool2o`000003ooooool0003o000000[ooooo0_l000000ooooooo0000o`000003o`0000;ooooo0_l0
0005ooooo`?o00001?ooool3o`0000Sooooo0_l00002ooooo`?o00000_ooool2o`000003ooooool0
003o000001Cooooo0_l00002ooooo`?o00000oooool2o`0000Oooooo1?l00002ooooo`;o0000@?oo
ool001cooooo00?o0000ooooooooool0@Oooool2o`0000Cooooo0_l0000:ooooo`;o00000_ooool;
o`000003ooooool0003o0000017o00001?ooool2o`000003ooooool0003o000000Gooooo0_l0000E
ooooo`;o00000_ooool2o`0000_ooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool2
o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000Kooooo0_l000000ooooooo0000o`00
0002ooooo`?o000000Goooooo`000?l0003o0000ooooo`02o`0000?ooooo0_l0000Dooooo`;o0000
3?ooool6o`0000;ooooo0ol0000>ooooo`;o0000;Oooool001cooooo00?o0000ooooooooool0>ooo
ool2o`000003ooooool0003o000000Oooooo0_l00002ooooo`;o00002OoooolNo`0000;ooooo0_l0
0005ooooo`;o00002_ooool2o`0000oooooo0ol00002ooooo`?o00005Oooool3o`0000?ooooo0_l0
0005ooooo`?o00000_ooool2o`0000Kooooo1Ol00003ooooo`;o00000_ooool2o`0000gooooo0_l0
0007ooooo`?o00002oooool4o`0000;ooooo1?l0000=ooooo`;o0000;Oooool001cooooo00?o0000
ooooooooool0>oooool2o`000003ooooool0003o000000_ooooo0_l00003ooooo`;o00001?ooool?
o`000003ooooool0003o000000_o000000?oooooo`000?l000000_l00009ooooo`?o00001Oooool4
o`0000gooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo0_l00009ooooo`;o00002_ooool3
o`0000Sooooo1ol000000ooooooo0000o`000003o`00013ooooo0_l000000ooooooo0000o`000004
ooooo`?o00002oooool2o`0000Cooooo1?l0000looooo`007?ooool00ol0003oooooooooo`0/oooo
o`;o00004_ooool2o`0000gooooo0ol00005oooooaoo00002oooool3o`0000Kooooo1Ol00003oooo
o`;o00003_ooool2o`0000;ooooo0_l00005ooooo`Co00003oooool2o`0000Kooooo0_l000000ooo
oooo0000o`000002oooooa7o00003oooool2o`0000?ooooo1?l0000?ooooo`Co0000?_ooool001co
oooo00?o0000ooooooooool0;?ooool2o`0001;ooooo0_l0000:ooooo`;o000000?oooooo`000?l0
00001_ooool9o`000003ooooool0003o0000017o00006Oooool2o`0000?ooooo0_l0000:ooooo`;o
00000_ooool2o`000003ooooool0003o000000Sooooo0_l00007ooooo`;o00001_ooool2o`0000Ko
oooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000ko00004oooool4o`00
00Cooooo0_l00002ooooo`;o00001Oooool4o`0003kooooo000Looooo`03o`000?oooooooooo03So
oooo0_l00002ooooo`;o00001oooool5o`0000;ooooo0ol000000ooooooo0000o`000003ooooo`;o
00000oooool@o`0000;ooooo1?l000000ooooooo0000o`000002o`0000_ooooo0_l00005ooooo`;o
00001?ooool2o`0000gooooo1?l00005ooooo`;o00004Oooool2o`000004ooooool0003o0000o`00
00_ooooo0_l000000ooooooo0000o`00000Do`000003ooooool0003o000001Cooooo0_l000000ooo
oooo0000o`000002ooooo`;o00000_ooool3o`0000?ooooo0_l0000mooooo`007?ooool00ol0003o
ooooooooo`0hooooo`;o00000_ooool2o`000003ooooool0003o000000Cooooo1Ol00002ooooo`?o
000000?oooooo`000?l000000oooool4o`0000;ooooo2_l000000ooooooo0000o`000007o`0000Co
oooo0_l00003ooooo`;o00001_ooool4o`0000;ooooo0ol00004ooooo`;o00002_ooool2o`000003
ooooool0003o000000Oooooo0_l00004ooooo`;o00003_ooool3o`0000?ooooo0_l00006ooooo`;o
000000?oooooo`000?l000005?l000000ooooooo0000o`000008ooooo`;o00002?ooool4o`0000Go
oooo0_l00002ooooo`?o00000oooool4o`0001_ooooo0_l0000Nooooo`007?ooool00ol0003ooooo
ooooo`0hooooo`;o00001Oooool2o`0000;ooooo0_l00007ooooo`;o000000?oooooo`000?l00000
1?ooool4o`0000?ooooo2Ol000000ooooooo0000o`000007o`0000Wooooo0_l00005ooooo`[o0000
0_ooool4o`000003ooooool0003o000000;o00001?ooool5o`0000kooooo0ol0000Cooooo`Co0000
2?ooool7o`000003ooooool0003o000000[o00000oooool2o`0000Oooooo0_l00005ooooo`Go0000
4oooool2o`0001_ooooo0_l0000Nooooo`007?ooool00ol0003oooooooooo`0Tooooo`;o00007Ooo
ool2o`0000[ooooo0_l00006ooooo`;o00001Oooool6o`0000;ooooo2?l00003ooooo`;o00003?oo
ool4o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000?ooooo1?l00004ooooo`;o0000
00?oooooo`000?l000000_ooool6o`0000Oooooo0_l0000Eooooo`;o00001ooooolFo`0000;ooooo
0_l000000ooooooo0000o`000008ooooo`;o000000?oooooo`000?l000000ol0001@ooooo`007?oo
ool2o`0002Gooooo0_l0000Mooooo`;o00001_ooool3o`0000Sooooo0ol00004ooooo`So000000?o
ooooo`000?l000001_l00002ooooo`?o000000?oooooo`000?l000000_ooool2o`0000oooooo0_l0
0005ooooo`Go00002_ooool6o`0000_ooooo0_l00005ooooo`;o000000?oooooo`000?l000004?oo
oolJo`000003ooooool0003o000000?ooooo0_l00003ooooo`;o00002Oooool2o`0000gooooo0_l0
000looooo`007?ooool00ol0003oooooooooo`0mooooo`;o00000_ooool2o`0000Sooooo0ol00000
0ooooooo0000o`000005ooooo`;o00001Oooool2o`000003ooooool0003o000000?o00000_ooool3
o`000003ooooool0003o000000;o000000?oooooo`000?l000001?l00002ooooo`?o000000?ooooo
o`000?l000002oooool2o`0000Sooooo0_l00006ooooo`;o00001?ooool2o`0000Oooooo0_l00004
ooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o0000013ooooo6_l00006
ooooo`;o00003Oooool3o`0000[ooooo0_l000001?oooooo0000o`000?ooool2o`0003Wooooo000L
ooooo`03o`000?oooooooooo03gooooo0_l00002ooooo`;o00002Oooool2o`000003ooooool0003o
000000cooooo0_l00002ooooo`;o00001Oooool2o`000003ooooool0003o000000;o00001?ooool2
o`000004ooooool0003o0000ooooo`;o000000Coooooo`000?l0003o00000oooool2o`0000Wooooo
0_l0000<ooooo`;o00001?ooool3o`0000Kooooo0_l00005ooooo`Co00000_ooool2o`0000Cooooo
0_l000000ooooooo0000o`00000:oooooaOo000000?oooooo`000?l000000_l00007ooooo`;o0000
2_ooool2o`0000_ooooo2?l0000iooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00002_oo
ool4o`0000Kooooo0_l00007ooooo`;o00001oooool2o`0000Gooooo0_l00007ooooo`;o00001?oo
ool3o`0000;ooooo0ol00009ooooo`;o00004_ooool3o`0000gooooo0_l0000:ooooo`;o000000?o
ooooo`000?l000002_oooolMo`0000Kooooo0_l00006ooooo`;o00004Oooool4o`0003_ooooo000L
ooooo`03o`000?oooooooooo03kooooo0_l0000:ooooo`Co00001_ooool4o`0000kooooo0_l0000;
ooooo`;o00001Oooool4o`0000?ooooo0_l0000@ooooo`;o00001oooool4o`0001?ooooo0_l0000;
ooooo`;o00002_ooool6o`000003ooooool0003o000000co000000Coooooo`000?l0003ooooo1?l0
000>ooooo`;o00003oooool2o`0000Cooooo0ol0000hooooo`007?ooool00ol0003oooooooooo`13
ooooo`;o00001Oooool2o`000003ooooool0003o000000Kooooo1?l0000Gooooo`;o000000Cooooo
o`000?l0003ooooo0_l00002ooooo`;o00002_ooool2o`0000Oooooo0_l00002ooooo`;o00001ooo
ool4o`0000[ooooo0ol00006ooooo`Co00001?ooool2o`0000?ooooo0_l0000:oooooaCo000000Co
ooooo`000?l0003o00001_ooool2o`0000?ooooo0_l0000?ooooo`;o00000oooool2o`000003oooo
ool0003o000000Cooooo0ol0000hooooo`007?ooool00ol0003oooooooooo`0jooooo`;o00001ooo
ool2o`000003ooooool0003o000000Gooooo0_l00008ooooo`;o00001oooool2o`0000Gooooo0_l0
0007ooooo`;o00000oooool6o`0000[ooooo0ol00002ooooo`;o00000oooool2o`0001Wooooo0ol0
0008ooooo`;o00000oooool3o`0000?ooooo1ol00005oooooa[o00001?ooool2o`0000?ooooo0_l0
000;ooooo`;o00000_ooool2o`0000?ooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`0j
ooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`;o00002Oooool2o`0000gooooo0_l0
0005ooooo`;o00002oooool3o`000004ooooool0003o0000o`0000[ooooo1ol00003ooooo`;o0000
4Oooool2o`0000kooooo1_l00002ooooo`;o00001Oooool6o`0000Gooooo6_l0000Fooooo`;o0000
Boooool001cooooo00?o0000ooooooooool08oooool2o`0001;ooooo0_l000000ooooooo0000o`00
0004ooooo`;o00000oooool2o`0000;ooooo0_l00006ooooo`;o00003Oooool2o`00013ooooo1_l0
000?ooooo`Co00001?ooool2o`0000kooooo0_l000000ooooooo0000o`00000>ooooo`Ko00000_oo
ool2o`0000Oooooo0ol000000ooooooo0000o`000004oooooaOo00002?ooool2o`0001Oooooo0_l0
0002ooooo`;o00000oooool2o`0000gooooo0_l0000Zooooo`007?ooool00ol0003oooooooooo`0S
ooooo`;o00004_ooool5o`0000Wooooo0_l00002ooooo`;o00000oooool2o`00013ooooo0_l00007
ooooo`;o00001_ooool4o`000003ooooool0003o000000_ooooo0_l00002ooooo`;o00003_ooool2
o`0000Kooooo0_l000000ooooooo0000o`00000?ooooo`;o00004_ooool2o`0000Gooooo5?l0000:
ooooo`;o00001?ooool2o`00017ooooo0_l000000ooooooo0000o`000007o`0000;ooooo0_l00008
ooooo`;o0000:_ooool001cooooo00?o0000ooooooooool09_ooool2o`0000oooooo1Ol00006oooo
o`;o000000?oooooo`000?l000001oooool2o`000003ooooool0003o000001Kooooo0_l00003oooo
o`Ko00003oooool2o`0001;ooooo0_l00009ooooo`;o00000_ooool2o`0000Sooooo1Ol0000=oooo
o`?o00001_ooool2o`0000;ooooo4Ol00007ooooo`Co00001Oooool4o`000003ooooool0003o0000
00kooooo0_l000001?oooooo0000o`000?ooool6o`0000;ooooo0ol0000cooooo`007?ooool00ol0
003oooooooooo`0Vooooo`;o00003oooool3o`0000Sooooo0_l000000ooooooo0000o`000009oooo
o`?o00004_ooool4o`0000Gooooo1?l00002ooooo`;o0000<?ooool2o`0000Sooooo0ol0000?oooo
o`?o00001_ooool2o`0000?ooooo4?l00003ooooo`;o00000_ooool4o`0000Gooooo0ol00002oooo
o`;o00002Oooool2o`0000_ooooo0_l000000ooooooo0000o`000002ooooo`;o0000<oooool001co
oooo00?o0000ooooooooool0>?ooool2o`0000gooooo0_l00007ooooo`;o00001Oooool2o`000003
ooooool0003o000000Cooooo0_l00003ooooo`Co00001oooool2o`0000;ooooo0_l0000;ooooo`;o
00000oooool2o`0000_ooooo0_l00003ooooo`Co00005Oooool3o`0000;ooooo1?l00003ooooo`;o
00001?ooool2o`0000Kooooo1?l000000ooooooo0000o`00000=o`0000;ooooo1?l000000ooooooo
0000o`000002o`0000Oooooo0ol0000<ooooo`;o00003_ooool2o`0003Oooooo000Looooo`03o`00
0?oooooooooo04;ooooo0_l00003ooooo`;o00000_ooool2o`0000[ooooo1Ol00004ooooo`;o0000
1?ooool2o`0000?ooooo0_l0000Aooooo`;o000000?oooooo`000?l000000oooool2o`0000Cooooo
0_l00005ooooo`;o00000_ooool5o`0000cooooo0_l00008ooooo`;o00000_ooool4o`0000?ooooo
0_l000000ooooooo0000o`000009ooooo`Wo000000?oooooo`000?l000002?l00002ooooo`;o0000
0_ooool3o`0000[ooooo0ol0000Kooooo`;o00001?ooool2o`00037ooooo000Looooo`03o`000?oo
oooooooo02?ooooo0_l0000Kooooo`Co00000_ooool4o`000003ooooool0003o000000Cooooo0_l0
0004ooooo`Co00001?ooool2o`0000Cooooo0_l00004ooooo`;o00004Oooool2o`0000[ooooo1?l0
0009ooooo`;o00000oooool2o`0000Gooooo0_l00003ooooo`;o00003_ooool2o`0000Kooooo0_l0
0005ooooo`;o00001?ooool6o`0000Oooooo1?l00007ooooo`;o00000_ooool2o`0000Sooooo0_l0
000Kooooo`;o00001?ooool2o`00037ooooo000Looooo`03o`000?oooooooooo02?ooooo0_l0000F
ooooo`;o00000oooool2o`0000Cooooo1?l000000ooooooo0000o`000004ooooo`;o00001?ooool2
o`0000Kooooo0_l000001?oooooo0000o`000?ooool2o`0000Kooooo1Ol0000>ooooo`;o00002?oo
ool2o`00013ooooo0_l00005ooooo`Co00004Oooool2o`0000Kooooo0_l00005ooooo`;o00000_oo
ool7o`0000Sooooo0_l00002ooooo`;o00001?ooool7o`0000Sooooo0ol00004ooooo`;o0000COoo
ool001cooooo0_l0000looooo`Oo00005Oooool2o`0000Sooooo0ol00002ooooo`;o00000_ooool2
o`000003ooooool0003o000000?o00001Oooool3o`0000Kooooo1?l00008ooooo`;o00001_ooool3
o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`?o00001?ooool2o`0001?ooooo0_l00009
ooooo`Co000000?oooooo`000?l000002?ooool2o`0000;ooooo0_l00004ooooo`Go000000?ooooo
o`000?l000001oooool3o`0000Cooooo0_l0000<ooooo`?o0000?_ooool001cooooo00?o0000oooo
ooooool0;Oooool2o`0000Oooooo0_l00005ooooo`?o00003oooool2o`0000oooooo0ol00003oooo
o`;o00000_ooool2o`0000_ooooo0ol00008ooooo`;o00002?ooool2o`0000Kooooo0ol00004oooo
o`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`00
00_ooooo0_l000000ooooooo0000o`00000Tooooo`Co000000?oooooo`000?l000000_l0000=oooo
o`;o00000_ooool4o`0000Oooooo1Ol000000ooooooo0000o`00000iooooo`007?ooool00ol0003o
ooooooooo`0]ooooo`;o00001oooool2o`0000Gooooo0_l0000=ooooo`;o000000?oooooo`000?l0
00003oooool2o`0000Cooooo1Ol0000<ooooo`;o00003oooool2o`000003ooooool0003o000000So
oooo0_l000001Ooooooo0000o`000?l0003ooooo00Co00002?ooool2o`000003ooooool0003o0000
00;o00002?ooool2o`000004ooooool0003o0000ooooo`;o00002Oooool2o`0000Sooooo0ol0000>
ooooo`;o00000oooool2o`0000cooooo0_l000000ooooooo0000o`000002ooooo`Co00001oooool2
o`000004ooooool0003o0000ooooo`;o0000>Oooool001cooooo00?o0000ooooooooool09oooool2
o`0001Cooooo0_l00003ooooo`;o00002?ooool2o`0001;ooooo0_l00004ooooo`Go00002Oooool5
o`0000oooooo0_l000000ooooooo0000o`000008ooooo`Ko000000?oooooo`000?l000003?ooool4
o`000003ooooool0003o000000Kooooo1?l00003ooooo`Ko00001?ooool4o`0000Kooooo0ol0000>
ooooo`?o00002oooool2o`0000?ooooo0ol0000Dooooo`;o0000>_ooool001cooooo00?o0000oooo
ooooool09oooool2o`0000oooooo0_l00007ooooo`?o00002oooool2o`0000Cooooo0_l00009oooo
o`;o000000Coooooo`000?l0003ooooo1?l0000:ooooo`?o00006Oooool2o`0000?ooooo0ol00007
ooooo`;o00002?ooool3o`000003ooooool0003o000000;o00002?ooool2o`0000;ooooo1ol00005
ooooo`?o00006?ooool2o`0000Kooooo0_l00003ooooo`;o00001?ooool2o`0001?ooooo0ol0000j
ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00001oooool2o`0000Cooooo0_l00006oooo
o`;o00001?ooool2o`0000cooooo0_l00003ooooo`Co00002?ooool2o`0000Oooooo0_l0000<oooo
o`;o00000oooool2o`0000?ooooo1?l00006ooooo`;o00002?ooool2o`0000;ooooo1?l00004oooo
o`;o00001Oooool5o`0000?ooooo0_l00003ooooo`;o00003oooool2o`0000Sooooo0_l00006oooo
o`?o00001?ooool2o`0000Cooooo0_l0000;ooooo`;o00001?ooool2o`0003_ooooo000Looooo`03
o`000?oooooooooo04Oooooo0_l00003ooooo`Co00005oooool5o`0000Sooooo0_l00006ooooo`?o
00003?ooool2o`0000;ooooo0_l00006ooooo`;o00004Oooool5o`0000Kooooo0_l00005ooooo`;o
000000?oooooo`000?l000000oooool2o`0000_ooooo0_l00007ooooo`;o00001Oooool2o`000003
ooooool0003o000000Oooooo0_l00004ooooo`;o00000_ooool4o`0000_ooooo0_l00004ooooo`Co
0000>Oooool001cooooo00?o0000ooooooooool0Boooool5o`0001Kooooo1?l0000;ooooo`Co0000
0oooool2o`0000Kooooo0_l00009ooooo`;o00005_ooool6o`0000;ooooo0_l0000Pooooo`;o0000
2oooool2o`000004ooooool0003o0000ooooo`;o00003oooool4o`0001?ooooo1?l0000iooooo`00
7?ooool00ol0003oooooooooo`0gooooo`;o00001Oooool4o`0000Wooooo0_l000000ooooooo0000
o`00000Fooooo`?o00000_ooool3o`0000Oooooo1_l00009ooooo`;o00003Oooool2o`0000Gooooo
0_l00004ooooo`;o00001Oooool4o`0000Cooooo1?l0000[ooooo`;o00001?ooool2o`0000oooooo
0_l00003ooooo`?o0000C?ooool001cooooo00?o0000ooooooooool0=oooool2o`0000Gooooo1?l0
0002ooooo`;o00002?ooool2o`0001Oooooo2?l00008ooooo`Co00004oooool2o`0000?ooooo0ol0
0004ooooo`;o00001?ooool2o`0000Cooooo1Ol00005ooooo`?o00008?ooool2o`0002;ooooo0_l0
00001?oooooo0000o`000?l0000:ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0A?oo
ool2o`000003ooooool0003o000000Kooooo0_l0000Hooooo`Ko00000_ooool2o`0000?ooooo0ol0
000Cooooo`Co00001?ooool2o`00013ooooo1?l00006ooooo`;o00006oooool2o`0000;ooooo1?l0
0002ooooo`Co00002_ooool4o`0000[ooooo0_l00002ooooo`;o00003_ooool3o`0003oooooo000L
ooooo`03o`000?oooooooooo03Oooooo0_l0000>ooooo`;o00001_ooool2o`0000?ooooo0_l0000C
ooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo0_l00002ooooo`;o00001?ooool2
o`0000[ooooo0_l0000>ooooo`;o00001?ooool3o`0000;ooooo0_l0000Nooooo`;o00001?ooool2
o`000003ooooool0003o000000?o00000_ooool4o`0000Gooooo0_l00003ooooo`Co00002_ooool2
o`0000Kooooo0_l0000;ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0=oooool2o`00
01_ooooo0_l0000Aooooo`;o00001Oooool2o`0000Cooooo0_l00004ooooo`?o00000_ooool3o`00
013ooooo0_l00008ooooo`;o00000_ooool5o`0000Kooooo0_l00009ooooo`?o00003_ooool2o`00
00Oooooo0_l000001?oooooo0000o`000?ooool4o`0000Kooooo0_l00004ooooo`;o00004oooool2
o`0004cooooo000Looooo`03o`000?oooooooooo03;ooooo0_l0000Eooooo`;o000000?oooooo`00
0?l000001_ooool3o`00013ooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l00000
0ooooooo0000o`000005ooooo`;o00000_ooool2o`0000Sooooo0_l00007ooooo`;o00002_ooool4
o`0000Sooooo0ol00009ooooo`?o00006Oooool8o`0001Gooooo0_l00002ooooo`;o00001Oooool2
o`0000_ooooo0_l00010ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?oo
ool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0<_ooool2o`0000Oooooo
0_l0000<ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l0000Booooo`Co0000
1?ooool2o`0000Wooooo0_l000000ooooooo0000o`000006ooooo`Co00000oooool2o`0000kooooo
0ol00009ooooo`;o00001Oooool2o`0000Cooooo0_l0000>ooooo`;o00002?ooool5o`0000_ooooo
0_l00009ooooo`;o000000?oooooo`000?l000000_ooool4o`0000?ooooo0ol0000:ooooo`;o0000
@?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMgMooo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo02oooooo0_l0000:ooooo`;o00000oooool2o`00
00Oooooo0_l00005ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Cooooo0ol000000ooo
oooo0000o`000004ooooo`;o00004Oooool2o`0000?ooooo0_l00003ooooo`Go00000oooool2o`00
0003ooooool0003o000001cooooo1Ol00003ooooo`Ko00000_ooool2o`0000Kooooo0_l00007oooo
o`?o00001oooool2o`000003ooooool0003o000000;ooooo0_l00009ooooo`Co000000?oooooo`00
0?l000001?l00004ooooo`;o00001_ooool2o`0004Cooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
02oooooo0_l00006ooooo`;o00001oooool2o`0000;ooooo0_l000000ooooooo0000o`000003o`00
00Oooooo0_l00004ooooo`;o00001?ooool3o`000003ooooool0003o000001[ooooo1?l00003oooo
o`;o00001_ooool2o`000004ooooool0003o0000ooooo`;o00006Oooool5o`0000Cooooo1_l00000
0ooooooo0000o`00000:ooooo`;o00000oooool2o`0000Sooooo0_l000001Ooooooo0000o`000?l0
003ooooo00;o00002oooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000000ooo
ool2o`0000?ooooo1Ol00014ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09
ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0003Oooooo0_l00002ooooo`;o00001ooo
ool8o`0000Gooooo0_l00007ooooo`;o00007oooool:o`0000Cooooo0_l00002ooooo`Ko000000Co
ooooo`000?l0003ooooo0_l00006ooooo`;o00000oooool2o`0000;ooooo0_l00005ooooo`Go0000
0_ooool:o`0000Sooooo0_l000000ooooooo0000o`000002ooooo`Co00002oooool2o`0000oooooo
1Ol00002ooooo`;o00000oooool2o`0000?ooooo0ol00016ooooo`0000?oooooo`000?ooool00_oo
ool00ol0003oooooooooo`09ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003ooooo
ooooo`0iooooo`Co00001Oooool2o`000005ooooool0003o0000o`000?ooool00_l00006ooooo`;o
00001oooool4o`0001Kooooo5ol00002ooooo`Co00001_ooool5o`0000?ooooo0_l00003ooooo`;o
00000_ooool2o`000003ooooool0003o000000;ooooo4Ol00003ooooo`;o00000oooool2o`0000Go
oooo1?l00006ooooo`;o00002Oooool2o`0000Wooooo0_l0000@ooooo`;o00002Oooool2o`0003_o
oooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qoooool0
2?ooool00ol0003oooooooooo`0eooooo`;o00000_ooool2o`0000Oooooo0_l0000Hooooo`;o0000
4Oooool3o`0000;ooooo5ol000000ooooooo0000o`000005ooooo`;o00000oooool4o`0000Gooooo
0_l00005ooooo`;o000000?oooooo`000?l000000_ooool8o`0000;ooooo1_l000000ooooooo0000
o`000003o`0000Gooooo0_l0000=ooooo`;o00002Oooool2o`0000;ooooo0_l0000<ooooo`Co0000
0oooool2o`0000Oooooo0_l00004ooooo`;o0000>oooool00006oooooomgMgOoV9RHoooooonHV9So
MgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo02Kooooo0_l0000=ooooo`;o
00001Oooool4o`000003ooooool0003o000000[ooooo0_l0000Poooooaco000000?oooooo`000?l0
00000ol00002ooooo`;o00000oooool2o`0000Gooooo1?l00005ooooo`;o000000Coooooo`000?l0
003ooooo2Ol000000ooooooo0000o`000005o`000003ooooool0003o000000?o00001?ooool3o`00
01cooooo0_l00005ooooo`;o00000_ooool2o`000003ooooool0003o000000Co000000?oooooo`00
0?l000001oooool2o`00047ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<
odA4A?l0003o410@1_ooool00ol0003oooooooooo`0Vooooo`;o00005?ooool4o`000003ooooool0
003o000000?ooooo0_l00005ooooo`;o00003?ooool2o`0000;ooooo0_l0000@oooooaco000000Co
ooooo`000?l0003o00000_ooool2o`0000[ooooo0ol00008oooooago00000_ooool2o`0000Kooooo
0_l0000Looooo`;o00000_ooool2o`0000Gooooo0_l0000<ooooo`;o0000?oooool001cooooo00?o
0000ooooooooool0>_ooool2o`0000[ooooo0_l00005ooooo`?o00001_ooool2o`0000?ooooo0_l0
0002ooooo`;o00002?ooool2o`0000Kooooo7Ol000001?oooooo0000o`000?ooool3o`0000;ooooo
0_l0000=ooooo`;o00000_ooool7o`000003ooooool0003o000001?o00000oooool2o`0000Gooooo
0_l0000;ooooo`;o00003Oooool2o`0000;ooooo0_l00004ooooo`;o00003oooool2o`0000oooooo
0_l0000^ooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o00003?ooool3o`0001;ooooo0_l0
0006ooooo`;o00000_ooool3o`0000Cooooo0_l00006ooooo`;o00001OoooolQo`000004ooooool0
003o0000o`0000;ooooo0_l00003ooooo`;o00001oooool<o`000003ooooool0003o000000Ko0000
00?oooooo`000?l000002Ol00004ooooo`;o00004_ooool2o`0000gooooo0_l00002ooooo`Co0000
00Coooooo`000?l0003o00004_ooool2o`0000cooooo0_l0000^ooooo`007?ooool00ol0003ooooo
ooooo`0[ooooo`;o00002?ooool2o`0000;ooooo0_l00006ooooo`;o00004?ooool2o`0000Gooooo
0ol00004ooooo`;o00003OoooolOo`0000?ooooo0ol00007ooooo`?o00001_ooool2o`000003oooo
ool0003o000000Oo000000?oooooo`000?l000004?l0000;ooooo`;o00007?ooool4o`0000;ooooo
0_l000000ooooooo0000o`00000Cooooo`;o0000??ooool001cooooo00?o0000ooooooooool0=Ooo
ool2o`0000[ooooo0_l0000?ooooo`Co00001Oooool2o`0001?ooooo3?l000000ooooooo0000o`00
000@o`0000kooooo0_l00007ooooo`;o00000_oooolJo`0000_ooooo0_l00006ooooo`;o00003ooo
ool2o`0000?ooooo1?l00006ooooo`;o00003oooool2o`0003oooooo000Looooo`03o`000?oooooo
oooo03[ooooo0_l00008ooooo`;o00003?ooool4o`0000Gooooo0_l0000Dooooo`ko000000?ooooo
o`000?l000003_l00002ooooo`;o00002oooool2o`0000Gooooo0_l00002oooooa?o000000?ooooo
o`000?l000001Ol0000Booooo`;o00003oooool2o`0000?ooooo0_l00008ooooo`;o00003oooool2
o`000003ooooool0003o000003cooooo000Looooo`03o`000?oooooooooo03Cooooo0_l00004oooo
o`;o00002?ooool2o`0001Gooooo0_l00009ooooo`;o00002Oooool<o`000003ooooool0003o0000
013o00000_ooool2o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0000Wooooo4ol000000ooo
oooo0000o`000007o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000002Oooool2o`00
02Oooooo0_l000001?oooooo0000o`000?ooool2o`0003cooooo000Looooo`03o`000?oooooooooo
03?ooooo0ol0000`ooooo`;o00001_oooolQo`0000Oooooo0_l00002ooooo`;o00003oooool<o`00
00;ooooo3_l000000ooooooo0000o`000002o`000005ooooool0003o0000o`000?ooool00_l00002
ooooo`;o00001Oooool2o`0000Sooooo0_l0000;ooooo`;o00001Oooool2o`0000Sooooo0ol00012
ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00003?ooool2o`0000Gooooo0_l00007oooo
o`;o00001?ooool2o`0000?ooooo0_l0000?oooooako000000Goooooo`000?l0003o0000ooooo`02
o`0000[ooooo0_l0000;oooooago00000_ooool2o`0000?ooooo0_l00006ooooo`;o00003oooool2
o`0000_ooooo0_l00005ooooo`;o00002?ooool2o`0004?ooooo000Looooo`03o`000?oooooooooo
03Sooooo0ol00006ooooo`;o00001Oooool2o`0000Oooooo0_l00004ooooo`;o00000_ooool3o`00
00oooooo9_l00009ooooo`;o00002_oooolOo`0000?ooooo0_l0000:ooooo`;o0000LOooool001co
oooo00?o0000ooooooooool0>?ooool3o`00023ooooo0_l0000>oooooaKo000000?oooooo`000?l0
00003ol00008ooooo`;o00002_oooolRo`000004ooooool0003o0000ooooo`;o00000_ooool2o`00
0003ooooool0003o000000;o000000?oooooo`000?l000009_ooool2o`0004Kooooo000Looooo`03
o`000?oooooooooo03Sooooo0_l0000Eooooo`Go00001_ooool2o`0000oooooo0_l00003oooooa_o
000000?oooooo`000?l000000_ooool2o`0000Wooooo0_l0000:ooooo`;o000000?oooooo`000?l0
00007Ol00002ooooo`Go000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00008_ooool2o`00
00;ooooo0_l00004ooooo`;o0000@?ooool001cooooo0_l0001@ooooo`Go00001_ooool3o`0000Ko
oooo0_l00004ooooo`;o00001_oooolJo`0000?ooooo0ol00008ooooo`;o00003ooooolKo`000003
ooooool0003o000000?ooooo0_l000000ooooooo0000o`00000]ooooo`;o00000oooool2o`0000?o
oooo1Ol0000mooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00003?ooool4o`0000Gooooo
0_l00006ooooo`;o00001?ooool2o`0000Oooooo5_l000001?oooooo0000o`000?ooool5o`0000So
oooo0_l0000?oooooa_o00002?ooool2o`00027ooooo0_l0000@ooooo`;o00001Oooool3o`0003go
oooo000Looooo`03o`000?oooooooooo04Cooooo0_l0000<ooooo`Co00005oooool3o`0000Cooooo
0ol00002oooooa;o000000?oooooo`000?l000000ol00005ooooo`;o00002Oooool2o`0000Oooooo
6ol00008ooooo`;o00000oooool2o`0001Gooooo0_l00005ooooo`Co00001_ooool2o`0000Cooooo
0_l00017ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00004?ooool2o`0000Kooooo0_l0
0004ooooo`;o00002oooool3o`0000Cooooo5_l00002ooooo`Go00001?ooool4o`0000Sooooo0_l0
0007oooooa[o00000oooool2o`0000Wooooo0_l0000Eooooo`;o00001oooool2o`0000Kooooo0_l0
0004ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0@?ooool4o`0001Kooooo0ol00003
ooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o00001_oooolAo`000003ooooool0003o
000000?ooooo0_l000001?oooooo0000o`000?l00003ooooo`Co000000?oooooo`000?l000000_l0
00000ooooooo0000o`000007ooooo`;o000000?oooooo`000?l000005ol00003ooooo`;o00002?oo
ool3o`0000Oooooo0_l00005ooooo`;o00001oooool2o`0000gooooo1?l0001;ooooo`007?ooool0
0ol0003oooooooooo`12ooooo`;o00005oooool2o`0000;ooooo0_l00002ooooo`?o00000_ooool2
o`0000?ooooo0_l0000:ooooo`co00002oooool2o`0000?ooooo0_l00003ooooo`Co000000?ooooo
o`000?l000000_l00005ooooo`;o00000_oooolGo`0000kooooo0ol00007ooooo`;o00001Oooool2
o`0000Oooooo0_l00003ooooo`Co00001_ooool4o`0000Gooooo0_l00002ooooo`;o0000@?ooool0
01cooooo00?o0000ooooooooool0>_ooool2o`0000Cooooo0_l0000:ooooo`Co00001Oooool2o`00
00;ooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0ol0000=ooooo`Co00000_ooool3
o`0000Cooooo1ol0000:ooooo`Oo00002Oooool2o`0000Wooooo5ol0000<ooooo`;o00005oooool2
o`000004ooooool0003o0000ooooo`Ko00001_ooool4o`0000Cooooo0ol00002ooooo`;o0000@?oo
ool001cooooo00?o0000ooooooooool0>_ooool2o`0000Cooooo0_l0000:ooooo`Co00000oooool5
o`000004ooooool0003o0000ooooo`;o00001_ooool2o`0000gooooo1?l00003ooooo`?o00000ooo
ool4o`000003ooooool0003o000000;o00001_ooool9o`0001Cooooo5_l00004ooooo`Co00001Ooo
ool2o`0000Wooooo0_l00002ooooo`;o00002?ooool2o`0000Cooooo0_l0000Booooo`Co0000@ooo
ool001cooooo00?o0000ooooooooool0>_ooool4o`0000[ooooo0ol00003ooooo`;o00000oooool5
o`0002?ooooo0_l00009ooooo`?o00001_ooool2o`0000Cooooo0_l0000Cooooo`Oo000000?ooooo
o`000?l000001Ol000000ooooooo0000o`000006o`0000Cooooo1?l0000>ooooo`Co00000_ooool2
o`0000kooooo0_l00005ooooo`;o00003Oooool2o`0004?ooooo000Looooo`03o`000?oooooooooo
03cooooo0_l0000:ooooo`?o00002Oooool4o`0000Wooooo0_l00005ooooo`;o00003?ooool2o`00
00;ooooo0_l000000ooooooo0000o`00000Gooooo`;o00001oooool2o`0000Wooooo1_l000000ooo
oooo0000o`00000?o`000003ooooool0003o000000?ooooo0_l00003ooooo`Co00001oooool2o`00
01Kooooo0_l000000ooooooo0000o`000002o`0005;ooooo000Looooo`03o`000?oooooooooo04?o
oooo0_l0000Aooooo`;o00002Oooool2o`0000Gooooo0_l0000<ooooo`?o000000Coooooo`000?l0
003ooooo0_l00006ooooo`;o00001Oooool2o`0000Kooooo2?l000000ooooooo0000o`000002o`00
00Cooooo0_l0000:ooooo`;o00000_ooool9o`000005ooooool0003o0000o`000?ooool00_l00008
ooooo`Co00006oooool2o`0000;ooooo0_l000000ooooooo0000o`00000@ooooo`Co0000@?ooool0
01cooooo00?o0000ooooooooool0@oooool2o`0000_ooooo0_l0000Kooooo`;o00002?ooool2o`00
00cooooo0_l00005ooooo`;o00001Oooool4o`000003ooooool0003o000000;o000000?oooooo`00
0?l000000_ooool2o`0000;ooooo0ol00004ooooo`;o00001_ooool=o`0000Sooooo0_l00002oooo
o`;o00000oooool2o`0001Sooooo0_l0000:ooooo`;o00002oooool4o`00043ooooo000Looooo`03
o`000?oooooooooo053ooooo0_l000000ooooooo0000o`000009ooooo`;o00003Oooool2o`0000_o
oooo0_l0000:ooooo`;o00001oooool2o`0000;ooooo0_l00008ooooo`;o00000_ooool2o`0000?o
oooo1?l00002ooooo`Ko00000_ooool2o`0000;ooooo0_l00002ooooo`Go00002?ooool2o`0000;o
oooo0ol00002ooooo`;o00001Oooool2o`0001Wooooo0_l000001?oooooo0000o`000?l0001?oooo
o`007?ooool00ol0003oooooooooo`1@ooooo`;o000000?oooooo`000?l000002Oooool2o`0000go
oooo0_l00003ooooo`;o00001_ooool2o`0000;ooooo0_l00006ooooo`;o00000_ooool2o`0000?o
oooo0_l0000<ooooo`;o00000oooool2o`0000Cooooo0_l00004ooooo`Go00002oooool3o`0000;o
oooo0_l00006ooooo`Go00002Oooool2o`0000Oooooo0_l0000@ooooo`;o000000?oooooo`000?l0
0000D?ooool001cooooo00?o0000ooooooooool0F_ooool2o`000003ooooool0003o000000kooooo
0_l00003ooooo`;o00001_ooool6o`0000;ooooo1?l000001?oooooo0000o`000?ooool4o`0000?o
oooo0_l0000:ooooo`;o00000oooool2o`0000gooooo1Ol0000=ooooo`;o000000?oooooo`000?l0
00000_ooool3o`000003ooooool0003o000000cooooo0_l00002ooooo`Co0000IOooool001cooooo
00?o0000ooooooooool0>oooool2o`0001gooooo0_l000000ooooooo0000o`00000Jooooo`;o0000
00?oooooo`000?l000001?ooool7o`0000;ooooo2_l0000@ooooo`;o00003?ooool3o`000003oooo
ool0003o000000Gooooo0_l00006ooooo`;o00000_ooool2o`000003ooooool0003o000000_ooooo
1?l00002ooooo`;o00002Oooool2o`0005cooooo000Looooo`;o0000??ooool2o`0001Cooooo0_l0
000?ooooo`;o00001_ooool2o`0000Sooooo1?l000000ooooooo0000o`00000:ooooo`;o00001?oo
ool6o`000004ooooool0003o0000o`00013ooooo0_l00005ooooo`;o00002Oooool2o`0000Gooooo
0_l0000=ooooo`;o00002oooool2o`0000Oooooo1Ol00003ooooo`;o00002?ooool2o`0005;ooooo
000Looooo`03o`000?oooooooooo04kooooo0_l000000ooooooo0000o`000002ooooo`;o00002_oo
ool3o`0000Kooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo1?l00005ooooo`;o0000
00?oooooo`000?l000000oooool2o`0000Oooooo0_l00002ooooo`Go00003Oooool2o`0000Kooooo
0_l00005ooooo`;o00001Oooool2o`0000_ooooo0_l00008ooooo`;o00004?ooool5o`000003oooo
ool0003o000000[ooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`1>ooooo`;o00001?oo
ool3o`0000[ooooo0ol00009ooooo`;o000000Coooooo`000?l0003ooooo0ol00007ooooo`;o0000
00?oooooo`000?l000004?ooool5o`0000Sooooo0_l00003ooooo`;o00001Oooool3o`0000Gooooo
1?l00003ooooo`;o00002oooool2o`0000Sooooo1?l00003ooooo`;o000000?oooooo`000?l00000
3?ooool2o`0005kooooo000Looooo`03o`000?oooooooooo04oooooo0_l00003ooooo`;o00003?oo
ool2o`0000oooooo1?l00007ooooo`;o00003Oooool2o`0000Gooooo0ol00006ooooo`Co00002_oo
ool2o`000003ooooool0003o000000?ooooo1?l00003ooooo`;o00003_ooool2o`0000Oooooo0_l0
0003ooooo`;o000000?oooooo`000?l000005Oooool2o`0005Gooooo000Looooo`03o`000?oooooo
oooo04oooooo0_l0000Dooooo`;o00003_ooool2o`0000Oooooo0_l0000=ooooo`Co00000oooool3
o`0000Kooooo0ol0000:ooooo`;o00000_ooool3o`0000;ooooo1?l0000Booooo`?o00006oooool3
o`0000Sooooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`1Jooooo`;o00002Oooool2o`00
0003ooooool0003o000000_ooooo0_l0000Cooooo`;o00000oooool2o`0000Cooooo0_l00004oooo
o`;o000000Coooooo`000?l0003ooooo0_l00007ooooo`;o00000oooool2o`0000Cooooo0_l00004
ooooo`;o00001oooool2o`0000?ooooo0_l00003ooooo`Go00002_ooool2o`0000Sooooo1?l0001N
ooooo`007?ooool00ol0003oooooooooo`1Jooooo`;o00003?ooool2o`0000?ooooo0_l00006oooo
o`;o00004oooool2o`0000Wooooo0_l00004ooooo`Go000000?oooooo`000?l000002_ooool2o`00
00Kooooo0_l00004ooooo`;o00001oooool2o`0000Gooooo0_l000000ooooooo0000o`000003o`00
00[ooooo1?l00006ooooo`Co00001Oooool2o`0005Oooooo000Looooo`03o`000?oooooooooo05Co
oooo0_l00003ooooo`;o00004_ooool2o`0000Gooooo0_l0000Qooooo`;o00000oooool3o`0000ko
oooo0_l000000ooooooo0000o`000002ooooo`Co00001?ooool2o`0000gooooo0_l00005ooooo`;o
00002Oooool5o`0000Gooooo0_l00007ooooo`;o0000Eoooool001cooooo00?o0000ooooooooool0
E?ooool2o`0000?ooooo0_l0000Cooooo`;o00001?ooool2o`0001Kooooo0_l00009ooooo`Co0000
0_ooool2o`0000;ooooo0ol0000<ooooo`;o000000?oooooo`000?l000000ol00004ooooo`?o0000
4oooool2o`0000Wooooo0_l000000ooooooo0000o`00000>ooooo`;o0000Eoooool001cooooo00?o
0000ooooooooool0AOooool2o`0001;ooooo0_l00002ooooo`;o000000?oooooo`000?l000003?oo
ool2o`0001cooooo0ol000000ooooooo0000o`000002ooooo`;o00000oooool2o`0000Kooooo1Ol0
00000ooooooo0000o`00000:ooooo`;o00000oooool2o`0000?ooooo0_l00003ooooo`;o00003Ooo
ool2o`0000[ooooo1?l00002ooooo`;o00000_ooool2o`00063ooooo000Looooo`03o`000?oooooo
oooo04Gooooo0_l0000>ooooo`?o00001Oooool2o`000003ooooool0003o000000Wooooo0_l00000
0ooooooo0000o`00000Mooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o
000000;ooooo0_l00007ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00007
ooooo`;o00000oooool2o`0000?ooooo1Ol0000:ooooo`;o00003?ooool2o`0000;ooooo0_l00000
1?oooooo0000o`000?l0001Pooooo`007?ooool00ol0003oooooooooo`1Eooooo`?o00002Oooool2
o`0000Sooooo0_l000000ooooooo0000o`00000Booooo`;o00001?ooool2o`0000gooooo0_l00002
ooooo`;o00003_ooool2o`0000;ooooo0_l0000<ooooo`;o00001Oooool3o`000003ooooool0003o
000000kooooo0_l0000<ooooo`;o0000HOooool001cooooo00?o0000ooooooooool0D?ooool2o`00
00oooooo0_l0000:ooooo`;o00004oooool2o`0000Cooooo0_l0000:ooooo`;o00000_ooool2o`00
00Oooooo0_l00004ooooo`;o00005Oooool2o`0000Sooooo0_l0000>ooooo`;o00003oooool2o`00
05kooooo000Looooo`03o`000?oooooooooo053ooooo0_l0000?ooooo`;o00002_ooool5o`0000;o
oooo0_l00004ooooo`;o00004?ooool2o`0000Kooooo0_l00002ooooo`?o00001_ooool2o`0000Co
oooo0_l0000Eooooo`;o00008Oooool2o`0000Kooooo0_l0001Nooooo`007?ooool00ol0003ooooo
ooooo`1Aooooo`;o00002_ooool2o`0000;ooooo0_l00004ooooo`?o00001?ooool4o`0000;ooooo
1?l00002ooooo`;o00003_ooool4o`0000;ooooo0_l00007ooooo`?o00002Oooool4o`0001Sooooo
0_l00003ooooo`Co00002Oooool2o`0000Wooooo0_l000001?oooooo0000o`000?ooool2o`0000?o
oooo0_l0001Nooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o00002_ooool2o`0000Sooooo
0ol00004ooooo`;o00000_ooool2o`0000;ooooo0_l0000=ooooo`;o00000oooool2o`0000Cooooo
1?l00006ooooo`;o00002Oooool4o`0000Sooooo1?l0000<ooooo`;o00000_ooool5o`0000?ooooo
0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l00004ooooo`;o00001?ooool2o`0006?o
oooo000Looooo`;o0000I_ooool3o`0000Oooooo0_l000000ooooooo0000o`00000Aooooo`;o0000
2oooool2o`0000Gooooo0_l0000;ooooo`;o00001Oooool;o`0000gooooo0_l00006ooooo`Go0000
0_ooool3o`000003ooooool0003o000000?ooooo1?l00002ooooo`;o0000I?ooool001cooooo00?o
0000ooooooooool0HOooool7o`0000Cooooo0_l000000ooooooo0000o`00000Jooooo`;o00001Ooo
ool2o`0000Gooooo0_l0000@ooooo`Ko00000_ooool5o`0000Gooooo0_l000000ooooooo0000o`00
0004o`0000;ooooo0ol00003ooooo`;o00001?ooool3o`0000Kooooo1?l000001?oooooo0000o`00
0?l0001Tooooo`007?ooool00ol0003oooooooooo`1Qooooo`Co00001Oooool4o`0000kooooo0_l0
000=ooooo`;o00001Oooool2o`0001Kooooo0ol00009ooooo`;o00001?ooool3o`000003ooooool0
003o000000Co00000_ooool3o`0000Sooooo0_l00007ooooo`;o00001?ooool2o`0006Gooooo000L
ooooo`03o`000?oooooooooo06[ooooo0_l00003ooooo`?o00002_ooool2o`000003ooooool0003o
000000Kooooo0_l00005ooooo`;o00001Oooool2o`0000?ooooo0_l000000ooooooo0000o`000009
ooooo`Co00004?ooool4o`0000Sooooo0_l00003ooooo`?o00000oooool2o`0000Oooooo1Ol0001X
ooooo`007?ooool00ol0003oooooooooo`1Tooooo`;o000000?oooooo`000?l000001_ooool3o`00
00;ooooo0_l00009ooooo`;o00001_ooool2o`0000Gooooo0ol000001?oooooo0000o`000?ooool2
o`0000?ooooo0_l000000ooooooo0000o`000009ooooo`;o00002oooool4o`0000Gooooo0_l0000=
ooooo`?o00001oooool2o`0000;ooooo1_l0001Xooooo`007?ooool00ol0003oooooooooo`1Toooo
o`;o000000?oooooo`000?l000002_ooool3o`0001?ooooo0_l00002ooooo`Co000000Coooooo`00
0?l0003ooooo0_l0000Nooooo`Go00001_ooool2o`0000Wooooo0_l00008ooooo`Co00000_ooool2
o`0001Gooooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`1cooooo`;o00005?ooool2o`00
00;ooooo0_l0000Iooooo`;o00001?ooool2o`0000Sooooo0_l00006ooooo`;o00002Oooool4o`00
00Kooooo0_l00005ooooo`;o00005?ooool2o`0005Gooooo000Looooo`03o`000?oooooooooo06Wo
oooo0_l00008ooooo`;o00003oooool2o`0001Gooooo0ol0000:ooooo`;o00001?ooool5o`0000Co
oooo0_l0000<ooooo`;o00000_ooool6o`0000gooooo0_l0001[ooooo`007?ooool00ol0003ooooo
ooooo`1Yooooo`;o00006Oooool2o`000003ooooool0003o000000Kooooo0ol00009ooooo`?o0000
0oooool2o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`Co000000?oooooo`000?l00000
0ol000000ooooooo0000o`000009ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000
o`000002ooooo`;o00001Oooool2o`0001Gooooo0_l0001Hooooo`007?ooool00ol0003ooooooooo
o`1Yooooo`Co00001_ooool2o`000003ooooool0003o000000Sooooo1?l00003ooooo`;o00001_oo
ool3o`0000oooooo0_l00002ooooo`?o000000?oooooo`000?l000002Oooool4o`0000;ooooo0_l0
0008ooooo`;o000000?oooooo`000?l000000ol00002ooooo`;o000000?oooooo`000?l000001Ooo
ool2o`0001Gooooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`1Rooooo`;o00001oooool2
o`0000Kooooo1Ol00004ooooo`;o00000_ooool4o`0000[ooooo0_l0000:ooooo`;o00002Oooool2
o`0000oooooo0_l00002ooooo`;o00002?ooool2o`000003ooooool0003o000000;ooooo1Ol0001i
ooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o00000oooool2o`0000[ooooo0_l00004oooo
o`?o00001Oooool4o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000003oooo
o`?o00002_ooool2o`0001Sooooo0_l00004ooooo`;o00000oooool2o`0000;ooooo0_l00006oooo
o`Co0000N_ooool001cooooo00?o0000ooooooooool0GOooool2o`0000Wooooo1?l00002ooooo`;o
00001?ooool3o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`000003
ooooool0003o000000?ooooo0_l0000@ooooo`;o000000?oooooo`000?l000004?ooool2o`0000Co
oooo0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o0000087ooooo000Looooo`03o`00
0?oooooooooo06Oooooo1Ol00003ooooo`;o00001?ooool3o`000003ooooool0003o000000;ooooo
0_l000000ooooooo0000o`00000;ooooo`;o00001Oooool2o`0000Wooooo0_l000000ooooooo0000
o`00000>ooooo`?o00000oooool4o`0000Cooooo1?l00002ooooo`;o00003_ooool2o`00077ooooo
00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q
8Oo<c<`01_ooool00ol0003oooooooooo`1Wooooo`;o00001_ooool5o`0000;ooooo0_l000001Ooo
oooo0000o`000?l0003ooooo00;o000000?oooooo`000?l000001_ooool2o`0000;ooooo0_l00006
ooooo`Co00000_ooool2o`0000;ooooo0_l0000Booooo`?o00000oooool3o`0000Gooooo1Ol0000A
ooooo`;o0000LOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go
8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo073ooooo1?l00003ooooo`Go0000
3?ooool2o`0000;ooooo0_l00007ooooo`?o000000Coooooo`000?l0003o00000_ooool2o`0001Co
oooo0_l00002ooooo`;o00002Oooool2o`0000_ooooo0_l00003ooooo`;o0000L_ooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool0Moooool2o`0000oooooo0_l00002ooooo`;o00002oooool2o`0000oo
oooo0_l00002ooooo`;o00001?ooool2o`0000Cooooo0ol0000<ooooo`;o00001Oooool2o`0000?o
oooo0_l0000=ooooo`;o0000Hoooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
2Oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0002Fooooo`;o00004_ooool2o`0000;o
oooo0_l0000:ooooo`Co00001oooool3o`000003ooooool0003o000001Wooooo0_l0001Sooooo`00
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<
c<`01_ooool00ol0003oooooooooo`1mooooo`;o00003Oooool2o`0000Gooooo0_l000000ooooooo
0000o`000008ooooo`;o00006_ooool2o`0000?ooooo0ol000001?oooooo0000o`000?l0000>oooo
o`;o0000LOooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol@413o
^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0M?ooool4o`0000Gooooo0_l000000ooo
oooo0000o`000003ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o000000?oooooo`00
0?l000001?l0000Hooooo`;o00000oooool3o`0000kooooo0_l00002ooooo`;o0000LOooool00006
oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o
0000ooooooooool0M?ooool4o`0000Sooooo0_l00003ooooo`;o00002?ooool2o`0000[ooooo0_l0
00000ooooooo0000o`000002ooooo`;o00006?ooool2o`0001Cooooo0_l00002ooooo`;o0000LOoo
ool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Ko
oooo00?o0000ooooooooool0N?ooool2o`0000Kooooo0_l00006ooooo`;o00001Oooool2o`0001Wo
oooo0ol0000@ooooo`;o00004?ooool2o`0000Gooooo0_l0001aooooo`007?ooool00ol0003ooooo
ooooo`1hooooo`Co00003?ooool2o`0000Kooooo0_l00007ooooo`;o00000_ooool2o`0000_ooooo
0ol00006ooooo`;o000000?oooooo`000?l000001Oooool2o`0000kooooo1?l0001hooooo`007?oo
ool00ol0003oooooooooo`1jooooo`;o00004_ooool4o`0000Oooooo0_l00002ooooo`;o00000_oo
ool2o`00013ooooo0_l000001?oooooo0000o`000?l00008ooooo`;o000000?oooooo`000?l00000
0oooool2o`0000;ooooo0_l0001jooooo`007?ooool00ol0003oooooooooo`2>ooooo`Go00003_oo
ool2o`0000;ooooo0_l00008ooooo`;o000000?oooooo`000?l000000oooool2o`000003ooooool0
003o000000Gooooo0_l000000ooooooo0000o`000003ooooo`;o0000O_ooool001cooooo00?o0000
ooooooooool0G_ooool2o`00023ooooo0_l0000>ooooo`?o00004_ooool2o`0000Gooooo0_l00000
1?oooooo0000o`000?ooool2o`0000Kooooo0_l00007ooooo`;o00000_ooool2o`00083ooooo000L
ooooo`03o`000?oooooooooo05kooooo0_l0000Pooooo`;o00003_ooool3o`0000gooooo0_l0000:
ooooo`;o00005Oooool2o`0000;ooooo0_l00020ooooo`007?ooool00ol0003oooooooooo`2:oooo
o`;o00003oooool2o`0000?ooooo0_l0000=ooooo`;o00002oooool2o`0000Wooooo0_l00020oooo
o`007?ooool00ol0003oooooooooo`2:ooooo`;o00002?ooool2o`0000Gooooo0_l0000@ooooo`Co
00002oooool2o`000003ooooool0003o000000;ooooo0_l00024ooooo`007?ooool00ol0003ooooo
ooooo`20ooooo`;o00001?ooool2o`0000cooooo0_l00004ooooo`;o00001?ooool2o`0000Cooooo
0_l00005ooooo`Co00002oooool2o`000003ooooool0003o000000;ooooo0_l00024ooooo`007?oo
ool00ol0003oooooooooo`20ooooo`?o00000oooool2o`0000kooooo0_l00002ooooo`;o00001?oo
ool2o`0000Cooooo0ol0000Aooooo`;o0000SOooool001cooooo00?o0000ooooooooool0POooool2
o`0001?ooooo0_l0000<ooooo`;o000000?oooooo`000?l000004Oooool2o`0000;ooooo0_l00004
ooooo`;o0000Poooool001cooooo00?o0000ooooooooool0K?ooool2o`0000oooooo0_l0000>oooo
o`;o00003Oooool2o`0000Kooooo0_l0000Hooooo`;o00001?ooool2o`0008?ooooo000Looooo`;o
0000KOooool2o`0000oooooo0_l0000>ooooo`?o00003?ooool2o`0000Sooooo0_l0002Qooooo`00
7?ooool00ol0003oooooooooo`23ooooo`;o00002?ooool3o`0001Kooooo0_l00004ooooo`;o0000
Voooool001cooooo00?o0000ooooooooool0Poooool2o`0000Cooooo0_l0000Qooooo`;o0000Vooo
ool001cooooo00?o0000ooooooooool0ROooool2o`0000gooooo0_l0000:ooooo`;o0000Xoooool0
01cooooo00?o0000ooooooooool0V?ooool2o`0000[ooooo0_l0002Sooooo`007?ooool00ol0003o
ooooooooo`2Jooooo`;o0000[Oooool001cooooo00?o0000ooooooooool0V_ooool2o`000:gooooo
000Looooo`03o`000?oooooooooo0;oooooo0_l00028ooooo`007?ooool00ol0003oooooooooo`2o
ooooo`;o0000R?ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001;ooooo1?l000000ol@413ooooo
ooooo`03ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo0ol0003o
oooood[ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000oooooooo
ool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oo
oooooooo0?ooooooD_ooool001;ooooo00?oEEEEofIVI_l00000oooooomDooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00XOooool01?l@413o0000o`000?ooool2o`000003oa0@
4?oooooooooo01Kooooo1?l000002?l@413ooooooooooonHV9So410@o`000?lb<S;oc<c<1?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o410@olc<c02<ooooo`00X_oo
ool01Ol0003ooooooooooooooooo000000Wooooo1_l0000<ooooo`03o`000?oooooooooo00;ooooo
00Go410@okZj^_ooooooMgMgoc8b<P07ooooo`09ogMgMolb<S;ooooooooooomEEEGoMgMgoooooonH
V9So8B4Q08cooooo002Rooooo`05o`000?ooooooooooooooool000006oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`2:ooooo`00X_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l0000<ooooo`03o`00
0?oooooooooo00Gooooo00?oZJVYoa0@4?ooool01_ooool02OmgMgOo<S8boooooooooooo0000oiRH
V?ooooooV9RHob4Q8@2<ooooo`00X_ooool01Ol0003oQhN7oooooonYZJWo000001_ooooo00?o0000
ooooooooool01?ooool00ol@413o0000okZj^P04ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_oo
ool01Ol0003oEEEEo`000?l@413oc<c<08cooooo002Qooooo`03oa0@4?l0003oMgMg00;o000000?o
V9RHooooooooool06Oooool00ol0003oooooooooo`05ooooo`03okZj^_lQ8B7ooooo00?ooooo00?o
0000ooooooooool01?ooool00omEEEGoQhN7ooooo`2>ooooo`00`_ooool00ol0003oooooooooo`02
ooooo`05oa0@4?nHV9SooooookZj^_l000001?ooool00ol0003oooooooooo`04ooooo`03omgMgOl@
413oV9RH08kooooo0030ooooo`03oeEEEOmVIVKo000000Cooooo00GoZJVYoa0@4?l0003o410@ojVY
Z@04ooooo`Co00001?ooool01?o<c<coA4A4o`000?l@412<ooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1362) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.33879 .46449 Mdot
.32995 .46011 Mdot
.53832 .64376 Mdot
.56352 .36836 Mdot
.75297 .65579 Mdot
.56915 .66177 Mdot
.35009 .59005 Mdot
.38176 .63715 Mdot
.53892 .63232 Mdot
.339 .547 Mdot
.40631 .62894 Mdot
.58694 .46493 Mdot
.3757 .60631 Mdot
.56702 .4057 Mdot
.86888 .48174 Mdot
.49598 .36397 Mdot
.34076 .46299 Mdot
.63045 .55971 Mdot
.49361 .41868 Mdot
.56217 .68342 Mdot
.37665 .44778 Mdot
.56287 .40069 Mdot
.3474 .4112 Mdot
.56707 .40629 Mdot
.53885 .37005 Mdot
.33246 .41038 Mdot
.348 .38693 Mdot
.51511 .38511 Mdot
.50993 .41754 Mdot
.39494 .63811 Mdot
.68299 .3957 Mdot
.8427 .54031 Mdot
.51225 .32698 Mdot
.78383 .41697 Mdot
.36096 .6227 Mdot
.40866 .33043 Mdot
.55963 .65633 Mdot
.39847 .61687 Mdot
.40175 .61287 Mdot
.36453 .6358 Mdot
.39177 .62712 Mdot
.34585 .42455 Mdot
.27521 .50227 Mdot
.52489 .71973 Mdot
.53625 .34022 Mdot
.61375 .77634 Mdot
.36606 .37278 Mdot
.57689 .42282 Mdot
.29669 .43042 Mdot
.65033 .61876 Mdot
.46923 .71059 Mdot
.35799 .59279 Mdot
.58117 .67336 Mdot
.15002 .36348 Mdot
.3736 .59636 Mdot
.60282 .42726 Mdot
.55102 .64731 Mdot
.54894 .40527 Mdot
.56554 .41044 Mdot
.44765 .2318 Mdot
.59043 .36294 Mdot
.68768 .52751 Mdot
.27672 .41565 Mdot
.48391 .57844 Mdot
.55438 .63717 Mdot
.40811 .61683 Mdot
.32411 .45325 Mdot
.36681 .60328 Mdot
.59891 .32424 Mdot
.59165 .63389 Mdot
.57993 .4213 Mdot
.40684 .62622 Mdot
.36865 .41225 Mdot
.51947 .41006 Mdot
.60777 .71644 Mdot
.57413 .81415 Mdot
.67581 .49919 Mdot
.40971 .30718 Mdot
.44031 .23008 Mdot
.6724 .65038 Mdot
.50939 .36849 Mdot
.71641 .46488 Mdot
.57991 .80306 Mdot
.30363 .40244 Mdot
.48073 .38367 Mdot
.63752 .57656 Mdot
.51914 .40526 Mdot
.67096 .77079 Mdot
.59453 .40626 Mdot
.60855 .53256 Mdot
.53047 .63282 Mdot
.31192 .42881 Mdot
.5602 .36501 Mdot
.52538 .42448 Mdot
.49548 .22066 Mdot
.54235 .44773 Mdot
.54993 .38809 Mdot
.29137 .42814 Mdot
.36022 .59263 Mdot
.60497 .41132 Mdot
.47781 .65753 Mdot
.52096 .66928 Mdot
.55925 .35093 Mdot
.53713 .61506 Mdot
.34894 .3977 Mdot
.52651 .42418 Mdot
.39664 .60522 Mdot
.57869 .36081 Mdot
.24577 .62553 Mdot
.34992 .45738 Mdot
.5071 .4002 Mdot
.64235 .53371 Mdot
.35449 .2682 Mdot
.30454 .42451 Mdot
.47203 .6562 Mdot
.49977 .42366 Mdot
.5399 .39263 Mdot
.31569 .45313 Mdot
.51509 .6406 Mdot
.64678 .78181 Mdot
.28755 .42492 Mdot
.39437 .64266 Mdot
.37913 .42884 Mdot
.56778 .46722 Mdot
.56276 .63402 Mdot
.50382 .70742 Mdot
.23775 .58378 Mdot
.70273 .39191 Mdot
.52201 .40466 Mdot
.29586 .5151 Mdot
.53553 .68514 Mdot
.31913 .43773 Mdot
.36788 .60727 Mdot
.47299 .38367 Mdot
.35437 .4429 Mdot
.41251 .62811 Mdot
.65302 .52139 Mdot
.40355 .71113 Mdot
.36195 .41382 Mdot
.49696 .50106 Mdot
.38842 .58608 Mdot
.34942 .61158 Mdot
.71225 .27393 Mdot
.32062 .44929 Mdot
.67929 .54464 Mdot
.36841 .61697 Mdot
.69812 .35361 Mdot
.54875 .33893 Mdot
.6852 .45249 Mdot
.19909 .44104 Mdot
.76787 .38805 Mdot
.4261 .73751 Mdot
.65611 .548 Mdot
.42208 .60548 Mdot
.54942 .37546 Mdot
.32215 .409 Mdot
.34066 .41033 Mdot
.58831 .36143 Mdot
.53694 .36258 Mdot
.58271 .42119 Mdot
.55632 .43794 Mdot
.62979 .33197 Mdot
.53272 .45359 Mdot
.34337 .35628 Mdot
.31332 .42399 Mdot
.55956 .3721 Mdot
.58701 .65099 Mdot
.59105 .34559 Mdot
.39897 .62815 Mdot
.55379 .40072 Mdot
.56077 .36708 Mdot
.56829 .34457 Mdot
.35381 .59738 Mdot
.83446 .58001 Mdot
.31361 .29928 Mdot
.81772 .57745 Mdot
.58779 .5173 Mdot
.58107 .6313 Mdot
.52059 .39504 Mdot
.6793 .52711 Mdot
.4687 .29682 Mdot
.57749 .37443 Mdot
.1776 .67608 Mdot
.55714 .39186 Mdot
.77516 .63769 Mdot
.61539 .36072 Mdot
.81335 .51956 Mdot
.70772 .44625 Mdot
.5359 .37701 Mdot
.34395 .52199 Mdot
.37017 .57376 Mdot
.55016 .70452 Mdot
.38837 .62369 Mdot
.5858 .65703 Mdot
.54256 .64493 Mdot
.47129 .60261 Mdot
.57631 .47272 Mdot
.57024 .32915 Mdot
.58293 .42938 Mdot
.56556 .60682 Mdot
.29037 .40334 Mdot
.64369 .52256 Mdot
.30962 .46014 Mdot
.79293 .69596 Mdot
.56988 .7563 Mdot
.3484 .63076 Mdot
.67077 .51055 Mdot
.52282 .65405 Mdot
.53567 .62501 Mdot
.64583 .53722 Mdot
.54621 .42498 Mdot
.32652 .44741 Mdot
.7428 .31389 Mdot
.27271 .66543 Mdot
.64976 .18714 Mdot
.29359 .42481 Mdot
.31826 .54028 Mdot
.38966 .6362 Mdot
.54906 .66479 Mdot
.54237 .39095 Mdot
.53876 .41898 Mdot
.36207 .46514 Mdot
.57759 .42599 Mdot
.25172 .40301 Mdot
.53693 .38476 Mdot
.4106 .67851 Mdot
.65016 .50392 Mdot
.47223 .60358 Mdot
.72563 .39691 Mdot
.31386 .40158 Mdot
.57423 .23146 Mdot
.54646 .61703 Mdot
.46837 .29158 Mdot
.4109 .61395 Mdot
.66813 .51616 Mdot
.5591 .62394 Mdot
.64103 .52897 Mdot
.51712 .4468 Mdot
.57287 .673 Mdot
.65363 .55427 Mdot
.6295 .46816 Mdot
.55228 .33301 Mdot
.19741 .59405 Mdot
.36603 .63471 Mdot
.31475 .4654 Mdot
.59464 .37497 Mdot
.56038 .61374 Mdot
.47199 .37523 Mdot
.45333 .77633 Mdot
.43929 .67321 Mdot
.53057 .68391 Mdot
.51132 .59509 Mdot
.68285 .52018 Mdot
.48616 .74498 Mdot
.30341 .52718 Mdot
.3256 .462 Mdot
.54269 .44981 Mdot
.82276 .49309 Mdot
.36795 .61604 Mdot
.58908 .3724 Mdot
.74457 .56936 Mdot
.3587 .60827 Mdot
.54662 .40568 Mdot
.4171 .6289 Mdot
.34176 .41078 Mdot
.39734 .22797 Mdot
.30782 .45155 Mdot
.5711 .43493 Mdot
.38899 .59895 Mdot
.52996 .61151 Mdot
.33233 .41525 Mdot
.55622 .42666 Mdot
.51654 .3866 Mdot
.54647 .56337 Mdot
.56023 .37968 Mdot
.81166 .60491 Mdot
.53597 .38072 Mdot
.53998 .65819 Mdot
.52095 .35504 Mdot
.26613 .29815 Mdot
.46646 .60055 Mdot
.32371 .45164 Mdot
.52175 .67899 Mdot
.54456 .63605 Mdot
.6038 .73947 Mdot
.42316 .64449 Mdot
.49689 .41324 Mdot
.56839 .61921 Mdot
.6457 .30419 Mdot
.40715 .59828 Mdot
.60462 .38326 Mdot
.45756 .48881 Mdot
.63955 .61451 Mdot
.57627 .67761 Mdot
.46179 .40918 Mdot
.35496 .40377 Mdot
.55425 .36204 Mdot
.53073 .62612 Mdot
.52993 .47314 Mdot
.50155 .40066 Mdot
.22245 .42676 Mdot
.54707 .56842 Mdot
.37492 .58461 Mdot
.61474 .37442 Mdot
.58808 .39189 Mdot
.57592 .66695 Mdot
.31489 .40324 Mdot
.40474 .59528 Mdot
.34188 .42007 Mdot
.80629 .50122 Mdot
.20615 .60025 Mdot
.6474 .40742 Mdot
.63851 .52218 Mdot
.65697 .59432 Mdot
.81132 .50269 Mdot
.5127 .19247 Mdot
.62001 .25229 Mdot
.79341 .40245 Mdot
.52716 .6234 Mdot
.71408 .58808 Mdot
.54741 .64097 Mdot
.52404 .3663 Mdot
.5633 .63632 Mdot
.82401 .48218 Mdot
.53979 .38513 Mdot
.56782 .64507 Mdot
.54391 .22497 Mdot
.55305 .36493 Mdot
.32403 .46023 Mdot
.78847 .67748 Mdot
.3634 .21046 Mdot
.43669 .66948 Mdot
.53993 .67523 Mdot
.65736 .2771 Mdot
.55107 .38639 Mdot
.51998 .35655 Mdot
.31369 .41365 Mdot
.48863 .34817 Mdot
.69237 .54329 Mdot
.67942 .51248 Mdot
.35968 .5588 Mdot
.69103 .49977 Mdot
.61634 .37863 Mdot
.32872 .41537 Mdot
.62787 .3366 Mdot
.62386 .69498 Mdot
.65755 .61312 Mdot
.33556 .59111 Mdot
.78821 .67601 Mdot
.28975 .38317 Mdot
.34688 .66219 Mdot
.61178 .6371 Mdot
.30389 .43871 Mdot
.84552 .55956 Mdot
.39028 .62019 Mdot
.20571 .62532 Mdot
.3651 .50121 Mdot
.54669 .42261 Mdot
.39738 .59476 Mdot
.47527 .42498 Mdot
.3845 .20008 Mdot
.26053 .70062 Mdot
.43292 .41343 Mdot
.59761 .39712 Mdot
.6172 .68479 Mdot
.54902 .39705 Mdot
.53004 .77849 Mdot
.53015 .38006 Mdot
.33851 .42272 Mdot
.33278 .55568 Mdot
.43221 .58839 Mdot
.2646 .34358 Mdot
.49725 .75683 Mdot
.65816 .55071 Mdot
.53558 .388 Mdot
.54942 .42271 Mdot
.6868 .55371 Mdot
.35024 .40914 Mdot
.57656 .43052 Mdot
.57269 .2253 Mdot
.5319 .428 Mdot
.39809 .62434 Mdot
.31044 .48869 Mdot
.31488 .36849 Mdot
.53569 .43793 Mdot
.33493 .39139 Mdot
.34041 .6151 Mdot
.38796 .60072 Mdot
.61802 .37331 Mdot
.37577 .64325 Mdot
.56493 .39033 Mdot
.28845 .7294 Mdot
.36521 .42258 Mdot
.2159 .47819 Mdot
.34624 .44109 Mdot
.40023 .30165 Mdot
.35634 .60089 Mdot
.42819 .69424 Mdot
.49691 .45005 Mdot
.38748 .61597 Mdot
.38854 .44079 Mdot
.50832 .35323 Mdot
.52428 .33765 Mdot
.71732 .30278 Mdot
.5326 .66008 Mdot
.53419 .57035 Mdot
.39436 .6387 Mdot
.57321 .4182 Mdot
.52373 .44018 Mdot
.34345 .62098 Mdot
.28211 .7028 Mdot
.42027 .20045 Mdot
.53719 .38269 Mdot
.32948 .42771 Mdot
.32347 .43773 Mdot
.5839 .34818 Mdot
.55302 .35212 Mdot
.5707 .63288 Mdot
.51799 .62422 Mdot
.59184 .64664 Mdot
.5294 .57524 Mdot
.42578 .69039 Mdot
.69185 .72666 Mdot
.36408 .63547 Mdot
.29349 .56064 Mdot
.61196 .52884 Mdot
.58469 .43171 Mdot
.53461 .67592 Mdot
.58657 .39112 Mdot
.57087 .38229 Mdot
.4045 .65234 Mdot
.7582 .60915 Mdot
.36331 .38484 Mdot
.32421 .39744 Mdot
.39057 .58459 Mdot
.62243 .39485 Mdot
.34576 .64597 Mdot
.666 .51965 Mdot
.73939 .34706 Mdot
.41069 .61977 Mdot
.31858 .45753 Mdot
.36757 .63156 Mdot
.53401 .42099 Mdot
.54648 .46038 Mdot
.30776 .44129 Mdot
.69722 .54545 Mdot
.49153 .34851 Mdot
.54386 .40341 Mdot
.18713 .45364 Mdot
.7274 .35733 Mdot
.37821 .68143 Mdot
.53762 .37831 Mdot
.51761 .42815 Mdot
.68444 .56592 Mdot
.53255 .42712 Mdot
.59198 .40142 Mdot
.36299 .26957 Mdot
.2535 .59296 Mdot
.67076 .50689 Mdot
.29493 .72693 Mdot
.29321 .42778 Mdot
.8308 .51704 Mdot
.55442 .67321 Mdot
.38738 .55566 Mdot
.37407 .2207 Mdot
.58498 .66923 Mdot
.42501 .7419 Mdot
.83379 .5349 Mdot
.46624 .63042 Mdot
.50909 .68176 Mdot
.34797 .38376 Mdot
.56709 .43462 Mdot
.54012 .39603 Mdot
.68456 .53049 Mdot
.33161 .44364 Mdot
.52308 .5538 Mdot
.46078 .82912 Mdot
.56066 .39856 Mdot
.22721 .44708 Mdot
.36139 .76398 Mdot
.6382 .6216 Mdot
.66772 .5326 Mdot
.69098 .51946 Mdot
.53473 .39029 Mdot
.3269 .28382 Mdot
.3311 .41058 Mdot
.55763 .42605 Mdot
.53877 .45419 Mdot
.53697 .66886 Mdot
.35906 .44831 Mdot
.51469 .64406 Mdot
.45512 .71309 Mdot
.80759 .59355 Mdot
.16477 .5823 Mdot
.36746 .59495 Mdot
.50119 .79877 Mdot
.41981 .6153 Mdot
.72196 .46545 Mdot
.55278 .69388 Mdot
.55605 .35822 Mdot
.31966 .40175 Mdot
.57733 .41183 Mdot
.55166 .35349 Mdot
.54829 .42454 Mdot
.53712 .44064 Mdot
.14453 .5268 Mdot
.65215 .54849 Mdot
.48764 .421 Mdot
.53815 .65296 Mdot
.59508 .78897 Mdot
.55274 .8055 Mdot
.55296 .42035 Mdot
.52357 .38527 Mdot
.3617 .42852 Mdot
.58971 .3651 Mdot
.41779 .60859 Mdot
.28964 .44696 Mdot
.518 .41466 Mdot
.74968 .71454 Mdot
.50649 .41337 Mdot
.82018 .54122 Mdot
.37039 .63192 Mdot
.24992 .64297 Mdot
.52009 .45843 Mdot
.44626 .65867 Mdot
.5348 .57002 Mdot
.56416 .6266 Mdot
.41971 .63254 Mdot
.56131 .65414 Mdot
.42721 .82122 Mdot
.57039 .46013 Mdot
.54722 .37336 Mdot
.58014 .43704 Mdot
.58154 .63152 Mdot
.69766 .7518 Mdot
.51686 .75015 Mdot
.54237 .46685 Mdot
.582 .6416 Mdot
.30937 .39351 Mdot
.70693 .3155 Mdot
.34936 .43163 Mdot
.63403 .54674 Mdot
.39195 .63325 Mdot
.69642 .5417 Mdot
.77277 .52815 Mdot
.34127 .46058 Mdot
.34422 .46854 Mdot
.55552 .67078 Mdot
.37774 .50469 Mdot
.38696 .15866 Mdot
.36258 .5028 Mdot
.7128 .42412 Mdot
.31997 .4156 Mdot
.51541 .42174 Mdot
.74295 .49747 Mdot
.36056 .51479 Mdot
.56138 .65099 Mdot
.57841 .38367 Mdot
.39842 .2246 Mdot
.57053 .63254 Mdot
.58614 .43445 Mdot
.53422 .6533 Mdot
.38508 .62753 Mdot
.52913 .66984 Mdot
.32354 .47586 Mdot
.51354 .4012 Mdot
.43688 .13053 Mdot
.712 .57582 Mdot
.54934 .38272 Mdot
.37974 .58051 Mdot
.35437 .72282 Mdot
.57607 .3652 Mdot
.64247 .54596 Mdot
.57494 .64756 Mdot
.40216 .47731 Mdot
.53434 .38159 Mdot
.58342 .64362 Mdot
.34714 .46324 Mdot
.42536 .60671 Mdot
.48626 .22227 Mdot
.43698 .6617 Mdot
.31164 .41332 Mdot
.54659 .51366 Mdot
.40757 .64329 Mdot
.51913 .42922 Mdot
.53956 .44834 Mdot
.32913 .43091 Mdot
.64923 .45849 Mdot
.54492 .34647 Mdot
.51311 .36518 Mdot
.54177 .66725 Mdot
.56538 .65446 Mdot
.58602 .25566 Mdot
.51873 .63015 Mdot
.54242 .45979 Mdot
.33195 .43059 Mdot
.56305 .36583 Mdot
.36405 .43236 Mdot
.58849 .36435 Mdot
.61516 .45331 Mdot
.34895 .40816 Mdot
.4141 .65766 Mdot
.57523 .38173 Mdot
.52892 .31997 Mdot
.58232 .36414 Mdot
.56333 .43457 Mdot
.56343 .63051 Mdot
.67084 .52653 Mdot
.56079 .45117 Mdot
.71198 .54398 Mdot
.64486 .52448 Mdot
.42851 .59141 Mdot
.53512 .66668 Mdot
.67584 .55147 Mdot
.37514 .77783 Mdot
.58104 .6673 Mdot
.68937 .53787 Mdot
.55446 .80518 Mdot
.35857 .61978 Mdot
.35926 .40649 Mdot
.54983 .36397 Mdot
.79245 .49534 Mdot
.34419 .36591 Mdot
.5079 .66399 Mdot
.53946 .38109 Mdot
.58784 .37396 Mdot
.29 .4154 Mdot
.46542 .84675 Mdot
.59155 .63412 Mdot
.50132 .41165 Mdot
.33375 .45795 Mdot
.46208 .86293 Mdot
.54278 .65262 Mdot
.6884 .53327 Mdot
.35551 .62195 Mdot
.38423 .39835 Mdot
.23557 .58364 Mdot
.35796 .58543 Mdot
.60323 .6813 Mdot
.4596 .70683 Mdot
.50243 .42979 Mdot
.53563 .67977 Mdot
.67111 .21956 Mdot
.59887 .30825 Mdot
.49193 .58605 Mdot
.66409 .28259 Mdot
.30346 .43249 Mdot
.41912 .61303 Mdot
.65382 .54715 Mdot
.2969 .4185 Mdot
.34493 .46175 Mdot
.34969 .62844 Mdot
.33322 .29519 Mdot
.45178 .48666 Mdot
.40229 .61832 Mdot
.76208 .40894 Mdot
.70384 .69749 Mdot
.5366 .67826 Mdot
.69181 .5444 Mdot
.76744 .54489 Mdot
.34547 .42209 Mdot
.81028 .65454 Mdot
.72102 .30098 Mdot
.5502 .38813 Mdot
.67112 .54927 Mdot
.70286 .73746 Mdot
.5157 .838 Mdot
.35856 .60365 Mdot
.41025 .57254 Mdot
.69281 .53113 Mdot
.59432 .37661 Mdot
.7027 .32658 Mdot
.5203 .36201 Mdot
.38648 .63441 Mdot
.51361 .2328 Mdot
.33965 .46217 Mdot
.3489 .62146 Mdot
.73678 .3399 Mdot
.56533 .39206 Mdot
.57607 .37997 Mdot
.74372 .41712 Mdot
.30081 .40999 Mdot
.56439 .62635 Mdot
.51716 .44405 Mdot
.54758 .40206 Mdot
.57488 .44897 Mdot
.61301 .37955 Mdot
.36808 .25339 Mdot
.52413 .37107 Mdot
.56837 .76538 Mdot
.59915 .39229 Mdot
.57461 .39307 Mdot
.33983 .39236 Mdot
.16273 .59759 Mdot
.47789 .72296 Mdot
.55135 .40067 Mdot
.50958 .42288 Mdot
.35123 .62343 Mdot
.40667 .49505 Mdot
.39259 .49627 Mdot
.40953 .46916 Mdot
.63909 .26303 Mdot
.55909 .33227 Mdot
.33027 .45132 Mdot
.65423 .55619 Mdot
.50013 .41743 Mdot
.33074 .45414 Mdot
.55698 .34117 Mdot
.57264 .6327 Mdot
.58253 .66538 Mdot
.6176 .32953 Mdot
.6723 .55416 Mdot
.24875 .4394 Mdot
.28992 .55939 Mdot
.57849 .66636 Mdot
.54497 .37154 Mdot
.43973 .63329 Mdot
.53284 .62503 Mdot
.47105 .63404 Mdot
.65929 .47971 Mdot
.32266 .40668 Mdot
.31109 .42568 Mdot
.68269 .45441 Mdot
.42912 .728 Mdot
.214 .39091 Mdot
.38534 .62894 Mdot
.4961 .43317 Mdot
.32393 .52595 Mdot
.30852 .4236 Mdot
.73719 .47996 Mdot
.67076 .55136 Mdot
.35898 .61083 Mdot
.5929 .7118 Mdot
.35823 .43636 Mdot
.36631 .44897 Mdot
.59984 .37045 Mdot
.54356 .41099 Mdot
.61281 .24931 Mdot
.7122 .55554 Mdot
.35222 .58769 Mdot
.69226 .53943 Mdot
.55149 .69357 Mdot
.51298 .37888 Mdot
.34554 .40799 Mdot
.68358 .71735 Mdot
.50283 .42362 Mdot
.54567 .62697 Mdot
.30645 .43152 Mdot
.68369 .52001 Mdot
.64552 .55163 Mdot
.55369 .43681 Mdot
.54418 .25235 Mdot
.39441 .61388 Mdot
.30432 .44449 Mdot
.35195 .65247 Mdot
.52815 .35426 Mdot
.53595 .40706 Mdot
.59459 .33118 Mdot
.35309 .58693 Mdot
.295 .62953 Mdot
.63956 .52445 Mdot
.32542 .44417 Mdot
.5236 .37559 Mdot
.68735 .54852 Mdot
.30486 .56143 Mdot
.53567 .6886 Mdot
.52663 .66527 Mdot
.65155 .55738 Mdot
.66712 .54031 Mdot
.63958 .53613 Mdot
.81176 .65328 Mdot
.28317 .4236 Mdot
.29497 .38116 Mdot
.50379 .36545 Mdot
.70754 .43784 Mdot
.4806 .41208 Mdot
.39435 .5887 Mdot
.53108 .65538 Mdot
.567 .35786 Mdot
.53706 .43613 Mdot
.61935 .3667 Mdot
.21821 .45688 Mdot
.36833 .3808 Mdot
.35638 .45341 Mdot
.53847 .46118 Mdot
.54319 .67473 Mdot
.80474 .68978 Mdot
.75486 .30978 Mdot
.52323 .45961 Mdot
.4508 .48215 Mdot
.34057 .40372 Mdot
.3608 .63446 Mdot
.7633 .46293 Mdot
.35935 .62365 Mdot
.32126 .44326 Mdot
.52071 .37228 Mdot
.28816 .57788 Mdot
.68137 .56761 Mdot
.57156 .42375 Mdot
.38055 .63396 Mdot
.58054 .41897 Mdot
.35343 .58763 Mdot
.79896 .51757 Mdot
.6449 .22536 Mdot
.55591 .39158 Mdot
.48266 .39276 Mdot
.63078 .24262 Mdot
.55834 .42018 Mdot
.66142 .57189 Mdot
.34048 .40341 Mdot
.52228 .22801 Mdot
.50956 .3465 Mdot
.56199 .28055 Mdot
.5223 .35754 Mdot
.4984 .21402 Mdot
.53601 .41025 Mdot
.6336 .62781 Mdot
.50894 .39957 Mdot
.59008 .41135 Mdot
.37727 .59426 Mdot
.34858 .62001 Mdot
.36279 .40224 Mdot
.54904 .61222 Mdot
.82053 .55725 Mdot
.54044 .40416 Mdot
.44613 .67655 Mdot
.27258 .61783 Mdot
.66685 .53785 Mdot
.32717 .44159 Mdot
.51578 .85717 Mdot
.39796 .63927 Mdot
.69431 .26975 Mdot
.59764 .26072 Mdot
.23946 .54022 Mdot
.74538 .54753 Mdot
.36071 .74094 Mdot
.6752 .51597 Mdot
.56763 .34493 Mdot
.72035 .65529 Mdot
.62893 .63496 Mdot
.64671 .47591 Mdot
.41726 .63868 Mdot
.4993 .27938 Mdot
.74972 .62476 Mdot
.64417 .55732 Mdot
.69202 .52469 Mdot
.35706 .59091 Mdot
.49863 .66317 Mdot
.57553 .4712 Mdot
.66476 .54801 Mdot
.58637 .63596 Mdot
.57323 .67602 Mdot
.59448 .64697 Mdot
.33439 .40912 Mdot
.73103 .29743 Mdot
.34686 .63688 Mdot
.38007 .58562 Mdot
.5134 .60724 Mdot
.44543 .37155 Mdot
.28996 .4555 Mdot
.55459 .6641 Mdot
.51829 .6498 Mdot
.34473 .40289 Mdot
.61058 .41576 Mdot
.59939 .44357 Mdot
.55642 .39923 Mdot
.67659 .5271 Mdot
.53969 .41463 Mdot
.58028 .64169 Mdot
.36324 .60021 Mdot
.52032 .65027 Mdot
.38366 .58007 Mdot
.66545 .74378 Mdot
.55369 .43055 Mdot
.51209 .39837 Mdot
.17725 .50081 Mdot
.37486 .4401 Mdot
.61462 .769 Mdot
.40051 .67164 Mdot
.54567 .64251 Mdot
.59213 .39837 Mdot
.29169 .45021 Mdot
.70848 .55706 Mdot
.1752 .59266 Mdot
.55199 .34983 Mdot
.35225 .42043 Mdot
.51443 .37959 Mdot
.62583 .3176 Mdot
.23777 .32569 Mdot
.34104 .42804 Mdot
.20964 .42653 Mdot
.50904 .4194 Mdot
.41181 .7853 Mdot
.60341 .38942 Mdot
.66152 .37834 Mdot
.54473 .34654 Mdot
.29279 .42741 Mdot
.55608 .40256 Mdot
.29597 .45273 Mdot
.56836 .6729 Mdot
.35771 .62979 Mdot
.31152 .41624 Mdot
.54055 .44505 Mdot
.43034 .08487 Mdot
.37837 .62681 Mdot
.53899 .38973 Mdot
.35346 .60111 Mdot
.33605 .4436 Mdot
.29779 .4275 Mdot
.5111 .8295 Mdot
.45575 .71562 Mdot
.38451 .6259 Mdot
.51329 .37927 Mdot
.4532 .78811 Mdot
.54184 .35964 Mdot
.65561 .30724 Mdot
.60148 .42823 Mdot
.5161 .35659 Mdot
.55987 .81063 Mdot
.37489 .5842 Mdot
.21308 .3862 Mdot
.54402 .82514 Mdot
.59246 .79082 Mdot
.37363 .45375 Mdot
.65015 .56121 Mdot
.84243 .56714 Mdot
.42393 .69104 Mdot
.58261 .63965 Mdot
.57555 .36208 Mdot
.33016 .48278 Mdot
.3958 .61066 Mdot
.66431 .52281 Mdot
.55466 .39155 Mdot
.52134 .66116 Mdot
.47477 .19357 Mdot
.41665 .59965 Mdot
.34526 .42871 Mdot
.30067 .40117 Mdot
.30388 .76678 Mdot
.53274 .37675 Mdot
.51365 .40561 Mdot
.39111 .63391 Mdot
.32649 .71965 Mdot
.65732 .51457 Mdot
.54263 .22232 Mdot
.38329 .62414 Mdot
.48559 .53948 Mdot
.32415 .45593 Mdot
.58875 .37764 Mdot
.76139 .68677 Mdot
.58408 .72572 Mdot
.18742 .48644 Mdot
.67978 .52813 Mdot
.65899 .31035 Mdot
.29277 .42967 Mdot
.36797 .61096 Mdot
.39442 .72126 Mdot
.55889 .32988 Mdot
.58455 .39442 Mdot
.66494 .32941 Mdot
.43239 .59099 Mdot
.42042 .437 Mdot
.54376 .35045 Mdot
.52493 .57543 Mdot
.56373 .3517 Mdot
.50959 .34058 Mdot
.58528 .44642 Mdot
.52667 .40453 Mdot
.34884 .41238 Mdot
.49468 .31951 Mdot
.56819 .62285 Mdot
.27718 .39792 Mdot
.48347 .54584 Mdot
.54435 .38323 Mdot
.50779 .37521 Mdot
.41851 .40463 Mdot
.41687 .75235 Mdot
.31285 .41839 Mdot
.34267 .47102 Mdot
.3827 .64384 Mdot
.60729 .43012 Mdot
.5431 .6135 Mdot
.47806 .37177 Mdot
.55648 .6291 Mdot
.34587 .40956 Mdot
.54459 .64619 Mdot
.35215 .61687 Mdot
.54411 .68179 Mdot
.42685 .69073 Mdot
.36904 .62242 Mdot
.31784 .40825 Mdot
.52146 .41384 Mdot
.38294 .58105 Mdot
.70775 .38159 Mdot
.67823 .52859 Mdot
.60178 .83186 Mdot
.51717 .41454 Mdot
.24746 .59299 Mdot
.54575 .48046 Mdot
.51917 .64921 Mdot
.23156 .33425 Mdot
.32884 .39808 Mdot
.68375 .51127 Mdot
.30697 .4028 Mdot
.72211 .33251 Mdot
.67496 .53778 Mdot
.59988 .81408 Mdot
.57791 .56493 Mdot
.72216 .351 Mdot
.61502 .40903 Mdot
.73582 .39248 Mdot
.56702 .68454 Mdot
.39398 .60834 Mdot
.40703 .72876 Mdot
.59037 .40622 Mdot
.54788 .18698 Mdot
.32018 .39354 Mdot
.55402 .61325 Mdot
.36822 .60458 Mdot
.40358 .59382 Mdot
.49543 .39689 Mdot
.68207 .62619 Mdot
.58615 .39878 Mdot
.43087 .71798 Mdot
.64731 .27479 Mdot
.27262 .38269 Mdot
.53719 .38518 Mdot
.57461 .66819 Mdot
.5146 .37934 Mdot
.64064 .5171 Mdot
.71168 .26436 Mdot
.50241 .33896 Mdot
.37437 .67627 Mdot
.69509 .5815 Mdot
.31144 .4497 Mdot
.57883 .48626 Mdot
.39965 .68346 Mdot
.53131 .37488 Mdot
.11855 .50494 Mdot
.68918 .54251 Mdot
.72118 .65057 Mdot
.52214 .43553 Mdot
.49621 .41413 Mdot
.46324 .573 Mdot
.2266 .56833 Mdot
.59908 .7181 Mdot
.56651 .41464 Mdot
.68029 .3608 Mdot
.3648 .58628 Mdot
.58928 .36817 Mdot
.53865 .39429 Mdot
.34075 .3224 Mdot
.40477 .5921 Mdot
.53944 .63775 Mdot
.58385 .67198 Mdot
.50879 .66216 Mdot
.64776 .51033 Mdot
.32174 .60209 Mdot
.72955 .45636 Mdot
.41567 .19258 Mdot
.70002 .53158 Mdot
.53699 .43452 Mdot
.72281 .56111 Mdot
.51878 .36971 Mdot
.65975 .52859 Mdot
.40729 .59343 Mdot
.30785 .41884 Mdot
.32837 .5339 Mdot
.58604 .66395 Mdot
.56933 .32996 Mdot
.65676 .51298 Mdot
.32287 .4085 Mdot
.76499 .5043 Mdot
.31538 .44991 Mdot
.38329 .61579 Mdot
.3225 .61657 Mdot
.66081 .52429 Mdot
.3411 .44406 Mdot
.35666 .66707 Mdot
.49395 .83905 Mdot
.57677 .45514 Mdot
.31137 .61017 Mdot
.29826 .44553 Mdot
.32789 .47221 Mdot
.29137 .44284 Mdot
.57534 .42664 Mdot
.45267 .48308 Mdot
.5314 .34304 Mdot
.37167 .5842 Mdot
.53418 .64927 Mdot
.60111 .22234 Mdot
.51926 .72685 Mdot
.50081 .4927 Mdot
.5108 .44835 Mdot
.56644 .39334 Mdot
.53509 .39043 Mdot
.50527 .3479 Mdot
.39781 .70138 Mdot
.58115 .40569 Mdot
.37852 .594 Mdot
.57626 .64455 Mdot
.56665 .34412 Mdot
.57607 .60174 Mdot
.58529 .78486 Mdot
.69861 .54727 Mdot
.35061 .57176 Mdot
.759 .29586 Mdot
.32038 .41057 Mdot
.52119 .67759 Mdot
.58224 .65371 Mdot
.65674 .51992 Mdot
.39801 .6189 Mdot
.31866 .45056 Mdot
.64971 .30742 Mdot
.64436 .52612 Mdot
.55282 .40251 Mdot
.44304 .4687 Mdot
.58451 .19523 Mdot
.57012 .34751 Mdot
.57038 .36485 Mdot
.59676 .6552 Mdot
.7292 .63329 Mdot
.51582 .13464 Mdot
.74335 .45637 Mdot
.66707 .5246 Mdot
.67452 .56228 Mdot
.35663 .40929 Mdot
.50772 .35218 Mdot
.36244 .58407 Mdot
.36472 .49313 Mdot
.3155 .65225 Mdot
.26447 .46972 Mdot
.19357 .52525 Mdot
.56273 .35342 Mdot
.30186 .71949 Mdot
.5668 .38884 Mdot
.28356 .42339 Mdot
.34514 .41261 Mdot
.3281 .42058 Mdot
.39321 .60865 Mdot
.42368 .31544 Mdot
.39056 .59881 Mdot
.74162 .25719 Mdot
.2962 .43524 Mdot
.57032 .56693 Mdot
.54886 .67038 Mdot
.54953 .46649 Mdot
.68875 .52608 Mdot
.31926 .62231 Mdot
.601 .32582 Mdot
.29239 .30306 Mdot
.56274 .61632 Mdot
.31493 .40912 Mdot
.34227 .72578 Mdot
.80795 .40688 Mdot
.40352 .48214 Mdot
.62177 .36302 Mdot
.76523 .4656 Mdot
.66417 .53509 Mdot
.18652 .48891 Mdot
.69268 .53429 Mdot
.37945 .63393 Mdot
.51477 .39335 Mdot
.51954 .40476 Mdot
.56551 .35183 Mdot
.55328 .42627 Mdot
.38981 .64753 Mdot
.54677 .45091 Mdot
.26632 .29805 Mdot
.58805 .65661 Mdot
.63507 .45583 Mdot
.69019 .53275 Mdot
.4263 .62592 Mdot
.57718 .6444 Mdot
.41531 .74887 Mdot
.72403 .40015 Mdot
.53548 .38249 Mdot
.56948 .35874 Mdot
.67993 .25329 Mdot
.54183 .35096 Mdot
.5344 .47027 Mdot
.58314 .64158 Mdot
.50354 .48439 Mdot
.69844 .54445 Mdot
.682 .56143 Mdot
.36701 .6227 Mdot
.34797 .41289 Mdot
.68548 .54344 Mdot
.54539 .66997 Mdot
.5136 .44993 Mdot
.53626 .45032 Mdot
.2974 .44404 Mdot
.69218 .25437 Mdot
.63734 .52955 Mdot
.43848 .78671 Mdot
.32254 .40294 Mdot
.37106 .40372 Mdot
.58478 .39318 Mdot
.20004 .47544 Mdot
.34854 .47474 Mdot
.68325 .50768 Mdot
.42466 .62867 Mdot
.75644 .44078 Mdot
.41043 .62911 Mdot
.3471 .42994 Mdot
.50075 .40358 Mdot
.33565 .40624 Mdot
.53568 .37855 Mdot
.83024 .42294 Mdot
.52435 .4073 Mdot
.39639 .19803 Mdot
.67176 .44311 Mdot
.56772 .66456 Mdot
.39958 .75194 Mdot
.55486 .67266 Mdot
.31261 .40425 Mdot
.50022 .42309 Mdot
.67365 .51204 Mdot
.55083 .79308 Mdot
.3557 .48615 Mdot
.53172 .63014 Mdot
.55731 .60798 Mdot
.4126 .63048 Mdot
.54953 .34543 Mdot
.5835 .39823 Mdot
.56782 .64757 Mdot
.25394 .39492 Mdot
.35363 .44082 Mdot
.52082 .38482 Mdot
.56997 .39538 Mdot
.56418 .66651 Mdot
.47544 .83769 Mdot
.51971 .30424 Mdot
.51952 .39529 Mdot
.57082 .7444 Mdot
.39285 .5887 Mdot
.56248 .46351 Mdot
.48252 .4022 Mdot
.66576 .5426 Mdot
.4171 .23943 Mdot
.74318 .32843 Mdot
.41142 .59611 Mdot
.58475 .65379 Mdot
.52823 .37615 Mdot
.57701 .66613 Mdot
.54053 .45133 Mdot
.22461 .55669 Mdot
.53572 .68638 Mdot
.51011 .36704 Mdot
.61377 .39901 Mdot
.29953 .41074 Mdot
.56515 .35542 Mdot
.42251 .38254 Mdot
.5464 .62153 Mdot
.49601 .40036 Mdot
.53429 .24715 Mdot
.40577 .61956 Mdot
.6172 .40067 Mdot
.64461 .53791 Mdot
.64534 .29943 Mdot
.27309 .5617 Mdot
.76133 .59309 Mdot
.68184 .56277 Mdot
.58057 .41721 Mdot
.55867 .60983 Mdot
.34954 .59171 Mdot
.36091 .21376 Mdot
.59349 .37862 Mdot
.38422 .6338 Mdot
.36253 .60167 Mdot
.66742 .52014 Mdot
.17001 .61611 Mdot
.53048 .43758 Mdot
.55084 .41968 Mdot
.38075 .34549 Mdot
.36207 .4556 Mdot
.53159 .41387 Mdot
.524 .42612 Mdot
.37502 .59271 Mdot
.6091 .44615 Mdot
.49537 .295 Mdot
.52202 .21685 Mdot
.33813 .60675 Mdot
.31479 .50489 Mdot
.55052 .6863 Mdot
.68144 .5554 Mdot
.30991 .43897 Mdot
.66196 .5116 Mdot
.534 .67073 Mdot
.52356 .42394 Mdot
.37477 .63877 Mdot
.40191 .37972 Mdot
.35615 .5916 Mdot
.74779 .58324 Mdot
.31589 .45977 Mdot
.37528 .53679 Mdot
.12647 .53754 Mdot
.49334 .7675 Mdot
.4498 .61603 Mdot
.66708 .53825 Mdot
.51629 .70481 Mdot
.56934 .3939 Mdot
.18297 .4971 Mdot
.53863 .43355 Mdot
.52462 .24215 Mdot
.58896 .64957 Mdot
.59192 .6454 Mdot
.51702 .39334 Mdot
.64565 .27697 Mdot
.34776 .59351 Mdot
.40529 .5975 Mdot
.50377 .37364 Mdot
.3875 .61661 Mdot
.54782 .41257 Mdot
.575 .63709 Mdot
.18542 .41507 Mdot
.55399 .39578 Mdot
.49628 .35266 Mdot
.23246 .55849 Mdot
.55967 .81626 Mdot
.68603 .59079 Mdot
.35869 .80279 Mdot
.79677 .37681 Mdot
.38701 .61483 Mdot
.51584 .35148 Mdot
.307 .50184 Mdot
.59746 .64708 Mdot
.34542 .66375 Mdot
.52813 .42131 Mdot
.53505 .42946 Mdot
.59159 .4092 Mdot
.57412 .37552 Mdot
.18414 .58329 Mdot
.35346 .49001 Mdot
.41943 .26897 Mdot
.55548 .35344 Mdot
.72067 .37847 Mdot
.37142 .63049 Mdot
.3883 .41087 Mdot
.69774 .52166 Mdot
.56391 .35406 Mdot
.28919 .39472 Mdot
.36305 .63914 Mdot
.73452 .24538 Mdot
.38103 .63638 Mdot
.5455 .6362 Mdot
.34802 .61152 Mdot
.55878 .3798 Mdot
.32352 .43732 Mdot
.42172 .5265 Mdot
.48797 .74249 Mdot
.58222 .63742 Mdot
.54877 .38268 Mdot
.54977 .57553 Mdot
.5685 .62182 Mdot
.60372 .78573 Mdot
.31578 .43582 Mdot
.68057 .37004 Mdot
.34028 .40799 Mdot
.49968 .38437 Mdot
.49972 .38701 Mdot
.34535 .63099 Mdot
.35077 .61689 Mdot
.34223 .40902 Mdot
.18099 .6528 Mdot
.63846 .53319 Mdot
.332 .42051 Mdot
.55651 .32735 Mdot
.44159 .49725 Mdot
.324 .43324 Mdot
.62632 .55033 Mdot
.36702 .59642 Mdot
.3706 .42111 Mdot
.59879 .39737 Mdot
.76058 .39954 Mdot
.65757 .5597 Mdot
.56507 .69046 Mdot
.74982 .50341 Mdot
.53919 .62158 Mdot
.42039 .63249 Mdot
.55699 .67231 Mdot
.37168 .58683 Mdot
.27158 .58741 Mdot
.26999 .39932 Mdot
.45107 .59817 Mdot
.40514 .64214 Mdot
.55568 .67033 Mdot
.51385 .38824 Mdot
.71122 .57663 Mdot
.49399 .3801 Mdot
.56351 .44132 Mdot
.3889 .59078 Mdot
.29833 .41735 Mdot
.35009 .47226 Mdot
.70563 .3371 Mdot
.35504 .41837 Mdot
.54276 .62708 Mdot
.29784 .28756 Mdot
.46085 .67737 Mdot
.41222 .62302 Mdot
.3543 .62626 Mdot
.52393 .36146 Mdot
.5613 .65328 Mdot
.5853 .63906 Mdot
.40856 .63232 Mdot
.2228 .48009 Mdot
.48693 .37694 Mdot
.31848 .47205 Mdot
.36711 .44963 Mdot
.3374 .42908 Mdot
.29362 .447 Mdot
.51402 .29861 Mdot
.35715 .6127 Mdot
.30237 .41218 Mdot
.52547 .35927 Mdot
.53178 .42606 Mdot
.35125 .50481 Mdot
.66408 .55836 Mdot
.56534 .34193 Mdot
.58923 .44313 Mdot
.58796 .3786 Mdot
.52838 .67093 Mdot
.4541 .40366 Mdot
.52696 .67715 Mdot
.57478 .61902 Mdot
.58354 .62602 Mdot
.42377 .6902 Mdot
.67569 .26637 Mdot
.79895 .43909 Mdot
.50159 .41479 Mdot
.33689 .74436 Mdot
.55059 .65476 Mdot
.26684 .31452 Mdot
.2956 .63488 Mdot
.59192 .39392 Mdot
.60686 .72185 Mdot
.56866 .6521 Mdot
.33931 .40089 Mdot
.52577 .41604 Mdot
.51049 .65485 Mdot
.64457 .5422 Mdot
.4944 .39145 Mdot
.53876 .6896 Mdot
.33779 .4459 Mdot
.6747 .50335 Mdot
.37463 .43086 Mdot
.58491 .62719 Mdot
.61699 .37575 Mdot
.27757 .23254 Mdot
.52304 .61086 Mdot
.42266 .80279 Mdot
.62727 .43947 Mdot
.51784 .38566 Mdot
.51463 .65883 Mdot
.38019 .41829 Mdot
.42146 .62988 Mdot
.54893 .53812 Mdot
.368 .43328 Mdot
.59201 .64552 Mdot
.52595 .63322 Mdot
.58265 .63788 Mdot
.35748 .45408 Mdot
.56836 .33851 Mdot
.36316 .43885 Mdot
.34755 .60663 Mdot
.54972 .36182 Mdot
.80988 .50564 Mdot
.31797 .71353 Mdot
.32862 .40237 Mdot
.5332 .63978 Mdot
.68239 .56673 Mdot
.56137 .38957 Mdot
.31989 .7216 Mdot
.51449 .38421 Mdot
.38255 .58706 Mdot
.37322 .26173 Mdot
.40042 .39856 Mdot
.51457 .3566 Mdot
.5276 .36071 Mdot
.40514 .59836 Mdot
.54928 .38697 Mdot
.54596 .34621 Mdot
.4232 .69344 Mdot
.35548 .4504 Mdot
.56008 .40173 Mdot
.5363 .65749 Mdot
.46496 .70165 Mdot
.48971 .36745 Mdot
.48508 .67618 Mdot
.67489 .36638 Mdot
.36292 .27527 Mdot
.53702 .43293 Mdot
.43506 .44789 Mdot
.57975 .38428 Mdot
.56591 .42658 Mdot
.52534 .36516 Mdot
.21712 .64744 Mdot
.54011 .68892 Mdot
.57906 .6583 Mdot
.66822 .56275 Mdot
.67574 .36814 Mdot
.66788 .54755 Mdot
.36348 .59697 Mdot
.69257 .6354 Mdot
.5282 .67878 Mdot
.34664 .43641 Mdot
.57565 .41907 Mdot
.52358 .61085 Mdot
.58884 .38298 Mdot
.5569 .37854 Mdot
.53718 .61511 Mdot
.55002 .68842 Mdot
.74383 .62686 Mdot
.65567 .55522 Mdot
.32287 .41956 Mdot
.54397 .34268 Mdot
.64762 .51855 Mdot
.53207 .43447 Mdot
.70817 .44036 Mdot
.32512 .42227 Mdot
.35809 .44687 Mdot
.34712 .4738 Mdot
.52111 .42105 Mdot
.55909 .38418 Mdot
.39124 .59838 Mdot
.31965 .40011 Mdot
.40416 .62257 Mdot
.53452 .55259 Mdot
.6317 .7312 Mdot
.5283 .42162 Mdot
.32345 .5768 Mdot
.66151 .55137 Mdot
.52936 .63478 Mdot
.59894 .20415 Mdot
.66752 .56278 Mdot
.53267 .37916 Mdot
.5631 .61409 Mdot
.65442 .53255 Mdot
.64501 .33183 Mdot
.72298 .25565 Mdot
.69349 .56166 Mdot
.52618 .35894 Mdot
.61655 .42781 Mdot
.3449 .79348 Mdot
.68972 .5611 Mdot
.3578 .62492 Mdot
.52009 .41962 Mdot
.28277 .45509 Mdot
.65978 .51135 Mdot
.55677 .76445 Mdot
.57381 .64918 Mdot
.75543 .37987 Mdot
.55662 .31336 Mdot
.24821 .39066 Mdot
.67776 .55998 Mdot
.31926 .44713 Mdot
.52509 .47121 Mdot
.58403 .39037 Mdot
.68325 .56356 Mdot
.42316 .64627 Mdot
.56572 .63606 Mdot
.47031 .71992 Mdot
.35855 .45369 Mdot
.41548 .65325 Mdot
.52847 .64624 Mdot
.44973 .78983 Mdot
.45288 .2085 Mdot
.59429 .44885 Mdot
.32053 .76444 Mdot
.33075 .67814 Mdot
.59918 .37392 Mdot
.70679 .55496 Mdot
.389 .58258 Mdot
.37948 .64172 Mdot
.38154 .61853 Mdot
.27242 .60731 Mdot
.41106 .46839 Mdot
.53015 .68828 Mdot
.33109 .62973 Mdot
.67981 .55537 Mdot
.75142 .42642 Mdot
.55824 .4444 Mdot
.56444 .39479 Mdot
.53189 .34809 Mdot
.56975 .35551 Mdot
.57815 .39477 Mdot
.39437 .62289 Mdot
.26163 .58431 Mdot
.38884 .49244 Mdot
.32559 .42783 Mdot
.72875 .6206 Mdot
.54644 .66613 Mdot
.54264 .6986 Mdot
.64937 .53486 Mdot
.51469 .77423 Mdot
.57428 .60045 Mdot
.54396 .64452 Mdot
.59164 .35995 Mdot
.35812 .43809 Mdot
.53896 .46812 Mdot
.52685 .35991 Mdot
.54735 .62795 Mdot
.47859 .57096 Mdot
.46254 .33049 Mdot
.6751 .48995 Mdot
.68702 .5034 Mdot
.42546 .47776 Mdot
.66764 .5651 Mdot
.5073 .43454 Mdot
.23757 .33219 Mdot
.53383 .67139 Mdot
.55558 .64143 Mdot
.6654 .55656 Mdot
.19877 .46942 Mdot
.30482 .43567 Mdot
.34426 .55547 Mdot
.35812 .59445 Mdot
.50013 .39751 Mdot
.5003 .19584 Mdot
.61451 .47216 Mdot
.6707 .63118 Mdot
.38097 .62449 Mdot
.56652 .67347 Mdot
.49181 .42356 Mdot
.53746 .35705 Mdot
.65741 .54782 Mdot
.75916 .63819 Mdot
.55798 .46187 Mdot
.68386 .77235 Mdot
.64499 .22487 Mdot
.72512 .32119 Mdot
.58419 .3953 Mdot
.35725 .45048 Mdot
.57275 .68424 Mdot
.69117 .54673 Mdot
.56573 .33002 Mdot
.75607 .32457 Mdot
.29952 .44432 Mdot
.37082 .62008 Mdot
.46212 .54297 Mdot
.75373 .44925 Mdot
.56646 .43529 Mdot
.53055 .42789 Mdot
.56412 .43057 Mdot
.64214 .17237 Mdot
.52904 .67624 Mdot
.33534 .40195 Mdot
.66474 .52076 Mdot
.35495 .42405 Mdot
.5696 .66687 Mdot
.45987 .59829 Mdot
.50951 .394 Mdot
.30355 .44991 Mdot
.31745 .44631 Mdot
.38971 .63825 Mdot
.42564 .61253 Mdot
.49045 .55072 Mdot
.5258 .40736 Mdot
.53885 .60609 Mdot
.30107 .41141 Mdot
.43782 .46507 Mdot
.6742 .53968 Mdot
.36861 .59452 Mdot
.5609 .3547 Mdot
.53601 .68204 Mdot
.60006 .42161 Mdot
.31166 .4231 Mdot
.54459 .64502 Mdot
.67807 .71979 Mdot
.69599 .55313 Mdot
.53883 .425 Mdot
.6541 .57568 Mdot
.58477 .64945 Mdot
.57118 .39197 Mdot
.47155 .80277 Mdot
.62647 .55006 Mdot
.52358 .7507 Mdot
.57924 .62555 Mdot
.44033 .66691 Mdot
.36032 .41298 Mdot
.27146 .63911 Mdot
.55158 .63775 Mdot
.41152 .77569 Mdot
.71433 .69207 Mdot
.50414 .44386 Mdot
.34416 .42146 Mdot
.33682 .68318 Mdot
.8353 .50361 Mdot
.41902 .8132 Mdot
.53878 .39075 Mdot
.51899 .63021 Mdot
.65414 .53999 Mdot
.41305 .61773 Mdot
.54831 .73409 Mdot
.6471 .50014 Mdot
.58599 .62052 Mdot
.52546 .36561 Mdot
.32819 .44717 Mdot
.37913 .59847 Mdot
.27515 .56749 Mdot
.54176 .66632 Mdot
.53242 .64842 Mdot
.49006 .40842 Mdot
.67102 .55196 Mdot
.29413 .68385 Mdot
.57783 .63738 Mdot
.66166 .2404 Mdot
.5163 .6911 Mdot
.64306 .52452 Mdot
.57869 .37464 Mdot
.70709 .33016 Mdot
.51279 .34686 Mdot
.5037 .81502 Mdot
.55016 .66748 Mdot
.31748 .42278 Mdot
.58132 .42343 Mdot
.5631 .23735 Mdot
.54115 .62807 Mdot
.44266 .47893 Mdot
.63484 .60737 Mdot
.35713 .60325 Mdot
.59434 .20266 Mdot
.53882 .4172 Mdot
.34941 .59216 Mdot
.65819 .54676 Mdot
.52246 .39957 Mdot
.5615 .3825 Mdot
.29034 .41664 Mdot
.39468 .63703 Mdot
.74137 .64007 Mdot
.35169 .62558 Mdot
.369 .63229 Mdot
.28797 .44817 Mdot
.55998 .41087 Mdot
.54354 .63624 Mdot
.56742 .65118 Mdot
.60111 .39712 Mdot
.17013 .41498 Mdot
.3041 .43957 Mdot
.58257 .67669 Mdot
.62229 .15926 Mdot
.60717 .38692 Mdot
.57969 .203 Mdot
.75347 .64642 Mdot
.36771 .58285 Mdot
.5264 .35816 Mdot
.33806 .4441 Mdot
.61635 .67379 Mdot
.53347 .6448 Mdot
.59347 .41059 Mdot
.37899 .59993 Mdot
.64938 .55146 Mdot
.55886 .62098 Mdot
.68047 .62803 Mdot
.55462 .42909 Mdot
.61363 .71602 Mdot
.52191 .63049 Mdot
.83146 .58749 Mdot
.40405 .74105 Mdot
.34171 .4192 Mdot
.55776 .3758 Mdot
.33289 .39861 Mdot
.65997 .52179 Mdot
.4657 .54405 Mdot
.36994 .59806 Mdot
.44497 .37747 Mdot
.25818 .29434 Mdot
.58313 .63843 Mdot
.33248 .40052 Mdot
.50825 .36111 Mdot
.21983 .54858 Mdot
.54496 .41634 Mdot
.6251 .40121 Mdot
.73635 .54475 Mdot
.40351 .6011 Mdot
.36257 .58743 Mdot
.57148 .38085 Mdot
.6575 .51731 Mdot
.54526 .66826 Mdot
.55692 .63186 Mdot
.78937 .69283 Mdot
.37358 .5321 Mdot
.61169 .25079 Mdot
.53675 .42949 Mdot
.58062 .6165 Mdot
.49373 .70758 Mdot
.38993 .6337 Mdot
.60377 .36468 Mdot
.54522 .6136 Mdot
.62532 .56094 Mdot
.65107 .32518 Mdot
.58197 .38826 Mdot
.52206 .33711 Mdot
.35343 .60007 Mdot
.42252 .44479 Mdot
.57275 .67299 Mdot
.58978 .43609 Mdot
.44006 .5766 Mdot
.65014 .33928 Mdot
.67514 .2241 Mdot
.32312 .41935 Mdot
.677 .61478 Mdot
.39528 .62269 Mdot
.4977 .34946 Mdot
.67896 .51926 Mdot
.59883 .64359 Mdot
.53696 .68474 Mdot
.53032 .37125 Mdot
.50872 .44047 Mdot
.62589 .23147 Mdot
.35317 .43451 Mdot
.369 .6275 Mdot
.51571 .40706 Mdot
.33202 .54369 Mdot
.5621 .35063 Mdot
.39811 .60315 Mdot
.25673 .24979 Mdot
.49877 .3706 Mdot
.54932 .4178 Mdot
.30381 .69032 Mdot
.36941 .43951 Mdot
.31314 .39888 Mdot
.51996 .18473 Mdot
.53684 .42922 Mdot
.62737 .21987 Mdot
.31829 .41692 Mdot
.30414 .4303 Mdot
.43244 .70494 Mdot
.56112 .39229 Mdot
.50021 .32478 Mdot
.3726 .58481 Mdot
.3664 .63194 Mdot
.36359 .44348 Mdot
.56019 .46318 Mdot
.42056 .60703 Mdot
.23226 .64405 Mdot
.56047 .6549 Mdot
.21802 .35096 Mdot
.3023 .44042 Mdot
.39513 .56897 Mdot
.38463 .63092 Mdot
.74908 .27307 Mdot
.61138 .65784 Mdot
.51215 .39199 Mdot
.54277 .42929 Mdot
.67038 .5566 Mdot
.52797 .3477 Mdot
.59172 .64535 Mdot
.3876 .61738 Mdot
.58452 .26857 Mdot
.32855 .42015 Mdot
.5343 .40878 Mdot
.54919 .78389 Mdot
.63492 .76998 Mdot
.69039 .60427 Mdot
.31078 .44831 Mdot
.33756 .41099 Mdot
.55131 .6794 Mdot
.52039 .62859 Mdot
.57187 .40777 Mdot
.41332 .606 Mdot
.32133 .40027 Mdot
.39771 .59914 Mdot
.53265 .66953 Mdot
.54345 .63894 Mdot
.55056 .69129 Mdot
.55223 .44687 Mdot
.53899 .64859 Mdot
.64872 .73107 Mdot
.37473 .655 Mdot
.28932 .45412 Mdot
.59048 .17937 Mdot
.27976 .57133 Mdot
.37039 .46884 Mdot
.65188 .51301 Mdot
.5847 .64252 Mdot
.34603 .60508 Mdot
.56183 .36408 Mdot
.58164 .36496 Mdot
.45437 .65969 Mdot
.34201 .60767 Mdot
.66223 .52234 Mdot
.35317 .591 Mdot
.66682 .51995 Mdot
.62995 .66758 Mdot
.55839 .34576 Mdot
.53793 .45239 Mdot
.38993 .62421 Mdot
.5415 .64713 Mdot
.57745 .65336 Mdot
.69779 .55698 Mdot
.49251 .5838 Mdot
.56644 .62006 Mdot
.30152 .42765 Mdot
.48792 .31341 Mdot
.52155 .63826 Mdot
.52749 .41529 Mdot
.72884 .46108 Mdot
.17955 .50148 Mdot
.50557 .34763 Mdot
.42789 .7001 Mdot
.36912 .36614 Mdot
.58707 .409 Mdot
.17789 .49177 Mdot
.42754 .6659 Mdot
.36183 .41861 Mdot
.58711 .6565 Mdot
.52833 .59695 Mdot
.46337 .38859 Mdot
.6872 .50633 Mdot
.59327 .34799 Mdot
.30873 .4514 Mdot
.30982 .3942 Mdot
.73051 .35141 Mdot
.45144 .81416 Mdot
.65511 .53561 Mdot
.65068 .53961 Mdot
.55142 .6358 Mdot
.59775 .83746 Mdot
.62097 .37019 Mdot
.66395 .52341 Mdot
.25348 .4143 Mdot
.5274 .36696 Mdot
.66484 .39311 Mdot
.56724 .51042 Mdot
.3616 .44773 Mdot
.71983 .37024 Mdot
.54051 .6319 Mdot
.3559 .41796 Mdot
.32144 .53548 Mdot
.56088 .33805 Mdot
.32658 .4224 Mdot
.39412 .59778 Mdot
.43549 .75044 Mdot
.29896 .42398 Mdot
.72025 .44943 Mdot
.41823 .62185 Mdot
.43606 .4667 Mdot
.69489 .33796 Mdot
.32295 .83538 Mdot
.39214 .61963 Mdot
.526 .63417 Mdot
.56782 .64996 Mdot
.55574 .63189 Mdot
.35588 .42689 Mdot
.58552 .64134 Mdot
.35199 .4332 Mdot
.35001 .77994 Mdot
.19289 .51619 Mdot
.66552 .52466 Mdot
.47085 .72227 Mdot
.33648 .43922 Mdot
.2634 .3114 Mdot
.14056 .43353 Mdot
.52408 .35856 Mdot
.36841 .64193 Mdot
.66366 .52709 Mdot
.66784 .78017 Mdot
.66325 .54029 Mdot
.70637 .29499 Mdot
.32054 .29128 Mdot
.54243 .4084 Mdot
.45801 .30241 Mdot
.69557 .52891 Mdot
.32504 .45697 Mdot
.57006 .39123 Mdot
.58681 .54655 Mdot
.66141 .5442 Mdot
.64164 .53492 Mdot
.56711 .40533 Mdot
.31489 .40898 Mdot
.53359 .6356 Mdot
.36018 .63155 Mdot
.67196 .509 Mdot
.59779 .46439 Mdot
.5271 .3385 Mdot
.51144 .38494 Mdot
.36544 .50738 Mdot
.70009 .56567 Mdot
.38715 .61402 Mdot
.19161 .63548 Mdot
.54695 .61013 Mdot
.5957 .56113 Mdot
.66496 .23268 Mdot
.40619 .68455 Mdot
.55146 .66623 Mdot
.57545 .66663 Mdot
.57875 .39655 Mdot
.56899 .49692 Mdot
.29844 .30554 Mdot
.4927 .59768 Mdot
.5549 .69364 Mdot
.56164 .63334 Mdot
.32974 .39542 Mdot
.72195 .32488 Mdot
.55367 .32524 Mdot
.41042 .595 Mdot
.54074 .68697 Mdot
.21289 .57152 Mdot
.67535 .55371 Mdot
.32609 .27963 Mdot
.56136 .34548 Mdot
.51213 .3966 Mdot
.37352 .6039 Mdot
.38884 .59832 Mdot
.61944 .63252 Mdot
.71697 .31313 Mdot
.37597 .37196 Mdot
.25519 .5638 Mdot
.36201 .28552 Mdot
.31694 .39471 Mdot
.32814 .40238 Mdot
.49891 .75346 Mdot
.35649 .63233 Mdot
.58566 .4146 Mdot
.3462 .41105 Mdot
.59962 .57474 Mdot
.45722 .35167 Mdot
.65239 .29793 Mdot
.59521 .2158 Mdot
.53888 .37946 Mdot
.35052 .44933 Mdot
.36914 .44218 Mdot
.34214 .4664 Mdot
.4439 .65466 Mdot
.56591 .41511 Mdot
.53914 .3846 Mdot
.5846 .40636 Mdot
.2083 .50732 Mdot
.56774 .42096 Mdot
.26712 .62937 Mdot
.47039 .53626 Mdot
.43612 .22973 Mdot
.58908 .43828 Mdot
.36087 .58108 Mdot
.55284 .43844 Mdot
.65802 .51776 Mdot
.5149 .36774 Mdot
.64993 .29633 Mdot
.37722 .62897 Mdot
.50837 .30748 Mdot
.27541 .58507 Mdot
.59638 .39209 Mdot
.6785 .50644 Mdot
.31606 .66008 Mdot
.81844 .48626 Mdot
.70873 .57524 Mdot
.30112 .42978 Mdot
.55651 .6592 Mdot
.3453 .60488 Mdot
.5486 .64091 Mdot
.5558 .45225 Mdot
.49148 .75803 Mdot
.68463 .75299 Mdot
.53776 .55924 Mdot
.57025 .35656 Mdot
.57455 .32458 Mdot
.30553 .42445 Mdot
.54989 .61107 Mdot
.35357 .47667 Mdot
.57395 .42866 Mdot
.67661 .52627 Mdot
.66079 .54826 Mdot
.5511 .54081 Mdot
.78918 .62894 Mdot
.21875 .6098 Mdot
.37738 .60494 Mdot
.57332 .63389 Mdot
.69115 .52866 Mdot
.38163 .76563 Mdot
.42554 .60555 Mdot
.39569 .59166 Mdot
.37354 .62782 Mdot
.51273 .41994 Mdot
.53794 .68821 Mdot
.44245 .22802 Mdot
.58989 .63114 Mdot
.55086 .3851 Mdot
.52682 .67002 Mdot
.5538 .61391 Mdot
.69104 .53793 Mdot
.37206 .62927 Mdot
.53731 .67238 Mdot
.49827 .39008 Mdot
.3192 .41273 Mdot
.4431 .60134 Mdot
.65946 .44481 Mdot
.46394 .81455 Mdot
.64247 .37177 Mdot
.3537 .4597 Mdot
.82836 .51228 Mdot
.3867 .58618 Mdot
.21936 .48791 Mdot
.74461 .6221 Mdot
.5021 .4234 Mdot
.17317 .39558 Mdot
.54562 .69997 Mdot
.54639 .61537 Mdot
.57847 .37622 Mdot
.50533 .6804 Mdot
.53873 .41106 Mdot
.52768 .65736 Mdot
.49877 .69974 Mdot
.28127 .40442 Mdot
.54241 .65224 Mdot
.58654 .4371 Mdot
.56614 .38295 Mdot
.35989 .44696 Mdot
.51491 .64672 Mdot
.5675 .32921 Mdot
.80721 .67397 Mdot
.39507 .60388 Mdot
.35452 .68156 Mdot
.72893 .47442 Mdot
.39693 .62274 Mdot
.33411 .42198 Mdot
.55984 .44271 Mdot
.65691 .54574 Mdot
.33715 .44023 Mdot
.63087 .28758 Mdot
.69419 .55239 Mdot
.21243 .3444 Mdot
.36553 .44767 Mdot
.53435 .62585 Mdot
.66951 .51526 Mdot
.52379 .347 Mdot
.59846 .64824 Mdot
.41047 .75475 Mdot
.54993 .66465 Mdot
.582 .40132 Mdot
.51048 .7338 Mdot
.3677 .62773 Mdot
.53555 .39195 Mdot
.54778 .61692 Mdot
.4322 .69791 Mdot
.50913 .4207 Mdot
.5757 .38378 Mdot
.67984 .23755 Mdot
.34411 .24403 Mdot
.66944 .53969 Mdot
.37672 .44064 Mdot
.52463 .35948 Mdot
.6436 .53322 Mdot
.66209 .69395 Mdot
.51116 .4118 Mdot
.29826 .44356 Mdot
.60946 .37182 Mdot
.51631 .63994 Mdot
.40319 .61825 Mdot
.52578 .57732 Mdot
.64451 .54175 Mdot
.38872 .84317 Mdot
.55206 .68416 Mdot
.52912 .44773 Mdot
.55623 .35018 Mdot
.7612 .53189 Mdot
.36146 .41993 Mdot
.27886 .35407 Mdot
.53908 .42534 Mdot
.21001 .49537 Mdot
.52588 .39958 Mdot
.55495 .69995 Mdot
.30424 .43464 Mdot
.55425 .42031 Mdot
.39788 .55148 Mdot
.4923 .35893 Mdot
.66377 .56042 Mdot
.31098 .70611 Mdot
.5601 .33545 Mdot
.22655 .29754 Mdot
.60161 .53035 Mdot
.54083 .65345 Mdot
.59835 .76939 Mdot
.7962 .70594 Mdot
.27529 .60632 Mdot
.35324 .42417 Mdot
.73693 .68552 Mdot
.54308 .63655 Mdot
.58637 .75897 Mdot
.83137 .50251 Mdot
.56517 .37593 Mdot
.56801 .43474 Mdot
.76893 .47897 Mdot
.58049 .62242 Mdot
.55332 .60488 Mdot
.5244 .45324 Mdot
.50323 .34467 Mdot
.53878 .64282 Mdot
.49609 .41064 Mdot
.55711 .45914 Mdot
.37059 .64212 Mdot
.30093 .4437 Mdot
.40615 .60272 Mdot
.41905 .60721 Mdot
.26503 .68746 Mdot
.60688 .5314 Mdot
.39997 .60626 Mdot
.38151 .58165 Mdot
.66498 .3869 Mdot
.66588 .28523 Mdot
.66326 .5111 Mdot
.80359 .63497 Mdot
.56291 .63575 Mdot
.56019 .41493 Mdot
.36716 .44837 Mdot
.3886 .38216 Mdot
.68542 .69234 Mdot
.24361 .34051 Mdot
.58104 .42197 Mdot
.53907 .62923 Mdot
.4381 .65849 Mdot
.53861 .46904 Mdot
.50871 .6433 Mdot
.51789 .41162 Mdot
.59307 .64703 Mdot
.54482 .27281 Mdot
.41165 .77504 Mdot
.50423 .63015 Mdot
.31336 .47023 Mdot
.51522 .40119 Mdot
.31107 .45292 Mdot
.39166 .63179 Mdot
.66303 .513 Mdot
.67151 .54253 Mdot
.57008 .39712 Mdot
.61462 .34986 Mdot
.62862 .69105 Mdot
.56228 .38843 Mdot
.53093 .36475 Mdot
.42968 .66511 Mdot
.52738 .36324 Mdot
.57966 .35858 Mdot
.58973 .38892 Mdot
.58544 .42545 Mdot
.36751 .63182 Mdot
.52006 .77458 Mdot
.46671 .39856 Mdot
.47148 .38354 Mdot
.42026 .6297 Mdot
.7519 .63724 Mdot
.40997 .59685 Mdot
.82425 .48117 Mdot
.36395 .58518 Mdot
.67568 .53504 Mdot
.74963 .56693 Mdot
.56797 .31266 Mdot
.29115 .42447 Mdot
.41149 .58809 Mdot
.65802 .52122 Mdot
.38413 .61794 Mdot
.52505 .65042 Mdot
.6872 .23473 Mdot
.33239 .38577 Mdot
.35289 .49525 Mdot
.32774 .65953 Mdot
.47332 .77255 Mdot
.54784 .6812 Mdot
.32238 .45911 Mdot
.46548 .32032 Mdot
.5712 .35512 Mdot
.64376 .53105 Mdot
.57187 .40531 Mdot
.38118 .63791 Mdot
.54464 .63114 Mdot
.39186 .79841 Mdot
.65783 .54826 Mdot
.62042 .19315 Mdot
.57449 .65409 Mdot
.59088 .3692 Mdot
.41923 .60538 Mdot
.52212 .16438 Mdot
.40128 .5982 Mdot
.29881 .3317 Mdot
.34782 .40385 Mdot
.37806 .81482 Mdot
.343 .4321 Mdot
.42098 .76427 Mdot
.47642 .13296 Mdot
.53579 .78328 Mdot
.31755 .40975 Mdot
.46554 .60769 Mdot
.53134 .37681 Mdot
.51087 .38622 Mdot
.39985 .78185 Mdot
.37147 .44798 Mdot
.54606 .35304 Mdot
.47249 .6791 Mdot
.41724 .6545 Mdot
.54864 .20185 Mdot
.55925 .67438 Mdot
.53637 .41425 Mdot
.33595 .5981 Mdot
.34192 .60163 Mdot
.57756 .67212 Mdot
.39423 .59021 Mdot
.54118 .38583 Mdot
.33754 .43813 Mdot
.51668 .71056 Mdot
.68189 .54195 Mdot
.62225 .81284 Mdot
.6402 .54764 Mdot
.55204 .66651 Mdot
.49415 .37905 Mdot
.54364 .63965 Mdot
.86579 .63679 Mdot
.53143 .38437 Mdot
.31752 .41798 Mdot
.53489 .35946 Mdot
.51665 .39729 Mdot
.58432 .42376 Mdot
.53185 .64162 Mdot
.70595 .50157 Mdot
.4969 .39876 Mdot
.36789 .59805 Mdot
.39456 .26255 Mdot
.57576 .34495 Mdot
.50857 .60944 Mdot
.67015 .30751 Mdot
.33919 .65076 Mdot
.36847 .41736 Mdot
.54435 .65751 Mdot
.32862 .41677 Mdot
.2085 .45336 Mdot
.33398 .4223 Mdot
.36616 .31133 Mdot
.48303 .30328 Mdot
.57129 .24922 Mdot
.54724 .25202 Mdot
.43842 .54688 Mdot
.37481 .44377 Mdot
.71322 .55442 Mdot
.31612 .40332 Mdot
.36685 .43819 Mdot
.19782 .26979 Mdot
.28752 .43512 Mdot
.53071 .42005 Mdot
.58069 .35052 Mdot
.46692 .78483 Mdot
.69649 .41853 Mdot
.54946 .36054 Mdot
.55259 .35693 Mdot
.68599 .52307 Mdot
.21206 .46488 Mdot
.52511 .75516 Mdot
.32601 .2566 Mdot
.64791 .75792 Mdot
.56979 .40481 Mdot
.51954 .3611 Mdot
.48814 .43728 Mdot
.39685 .18209 Mdot
.27122 .70384 Mdot
.26941 .44039 Mdot
.48506 .42656 Mdot
.52801 .79474 Mdot
.5776 .4293 Mdot
.52488 .4267 Mdot
.53599 .37861 Mdot
.54291 .63603 Mdot
.37288 .425 Mdot
.58663 .42779 Mdot
.75267 .53624 Mdot
.52447 .42307 Mdot
.41119 .68737 Mdot
.49478 .85117 Mdot
.53927 .41779 Mdot
.35557 .39553 Mdot
.51242 .38187 Mdot
.36336 .42925 Mdot
.3409 .45833 Mdot
.49483 .43664 Mdot
.35786 .28821 Mdot
.34659 .39604 Mdot
.55159 .38479 Mdot
.52486 .64171 Mdot
.82685 .58949 Mdot
.58084 .40387 Mdot
.65981 .5125 Mdot
.54082 .42876 Mdot
.66791 .50398 Mdot
.53741 .36431 Mdot
.55678 .68427 Mdot
.34487 .36754 Mdot
.55571 .63988 Mdot
.30701 .75261 Mdot
.54952 .68952 Mdot
.65564 .20201 Mdot
.34582 .46343 Mdot
.48698 .72523 Mdot
.22301 .39737 Mdot
.36085 .69104 Mdot
.47754 .4865 Mdot
.42257 .51121 Mdot
.41196 .60416 Mdot
.35188 .40955 Mdot
.24089 .46569 Mdot
.72041 .64614 Mdot
.72477 .60026 Mdot
.56633 .62226 Mdot
.16986 .62141 Mdot
.20616 .38318 Mdot
.50254 .43053 Mdot
.43251 .32494 Mdot
.42527 .2849 Mdot
.57806 .42987 Mdot
.57809 .43503 Mdot
.55404 .58406 Mdot
.49491 .39925 Mdot
.33139 .54688 Mdot
.55591 .66843 Mdot
.65464 .52213 Mdot
.30931 .41984 Mdot
.64896 .55136 Mdot
.73629 .62853 Mdot
.41604 .50797 Mdot
.52844 .66212 Mdot
.53931 .33117 Mdot
.55913 .36051 Mdot
.3616 .43806 Mdot
.32762 .4837 Mdot
.30428 .4076 Mdot
.66016 .53144 Mdot
.56193 .66595 Mdot
.17839 .5319 Mdot
.56216 .35927 Mdot
.31699 .4448 Mdot
.49581 .49575 Mdot
.52757 .35854 Mdot
.39096 .62841 Mdot
.52684 .37908 Mdot
.31223 .41155 Mdot
.52769 .36316 Mdot
.34479 .43099 Mdot
.5576 .65679 Mdot
.59433 .38448 Mdot
.58169 .37988 Mdot
.57242 .17904 Mdot
.67068 .5248 Mdot
.31175 .45756 Mdot
.58705 .56751 Mdot
.535 .35004 Mdot
.44547 .71915 Mdot
.521 .41433 Mdot
.38528 .39604 Mdot
.51233 .4347 Mdot
.36298 .68288 Mdot
.48404 .35606 Mdot
.57635 .40999 Mdot
.56205 .52293 Mdot
.41289 .29522 Mdot
.55562 .30445 Mdot
.37642 .57893 Mdot
.29871 .45282 Mdot
.5559 .20751 Mdot
.54966 .71295 Mdot
.52472 .61834 Mdot
.73606 .40466 Mdot
.59435 .40923 Mdot
.54485 .40963 Mdot
.32271 .61342 Mdot
.65314 .54916 Mdot
.31316 .4506 Mdot
.66705 .52005 Mdot
.61512 .20537 Mdot
.67697 .56142 Mdot
.55078 .7011 Mdot
.61334 .71763 Mdot
.18401 .5727 Mdot
.68822 .52583 Mdot
.31284 .40918 Mdot
.59562 .7353 Mdot
.60099 .37822 Mdot
.59717 .52589 Mdot
.68185 .53071 Mdot
.23721 .71954 Mdot
.58127 .35997 Mdot
.47423 .48243 Mdot
.40511 .61052 Mdot
.68101 .52017 Mdot
.41423 .62628 Mdot
.56492 .36777 Mdot
.52871 .75343 Mdot
.35201 .42318 Mdot
.40922 .63554 Mdot
.61576 .40545 Mdot
.66216 .52602 Mdot
.53775 .68642 Mdot
.33038 .59374 Mdot
.40039 .58808 Mdot
.76993 .62896 Mdot
.37562 .79936 Mdot
.56467 .66398 Mdot
.4554 .20541 Mdot
.3545 .58741 Mdot
.60013 .37457 Mdot
.21998 .45706 Mdot
.51147 .39335 Mdot
.25564 .64084 Mdot
.54495 .66426 Mdot
.48779 .77418 Mdot
.52331 .36094 Mdot
.57776 .41931 Mdot
.33127 .38771 Mdot
.56357 .64323 Mdot
.3256 .43567 Mdot
.30694 .45966 Mdot
.55929 .65652 Mdot
.34288 .42306 Mdot
.69744 .5356 Mdot
.29933 .51189 Mdot
.35768 .59381 Mdot
.36039 .60593 Mdot
.55762 .63173 Mdot
.53871 .6564 Mdot
.54482 .64374 Mdot
.52617 .37915 Mdot
.30736 .44455 Mdot
.55393 .37161 Mdot
.53532 .43325 Mdot
.39712 .25218 Mdot
.37255 .43264 Mdot
.54479 .37582 Mdot
.59551 .55261 Mdot
.57908 .50253 Mdot
.52239 .64637 Mdot
.40223 .60884 Mdot
.47791 .69703 Mdot
.39278 .74609 Mdot
.53283 .41285 Mdot
.61795 .53515 Mdot
.3133 .40709 Mdot
.65744 .54275 Mdot
.65107 .56208 Mdot
.66542 .5396 Mdot
.37753 .67034 Mdot
.34659 .46452 Mdot
.31977 .2644 Mdot
.53993 .4132 Mdot
.37787 .50508 Mdot
.26034 .41237 Mdot
.62687 .65881 Mdot
.40002 .60815 Mdot
.53713 .35743 Mdot
.52999 .573 Mdot
.43781 .36838 Mdot
.5144 .3902 Mdot
.58838 .35425 Mdot
.65749 .73152 Mdot
.60424 .35615 Mdot
.30602 .39864 Mdot
.52673 .1687 Mdot
.51846 .35331 Mdot
.20894 .56836 Mdot
.63978 .81445 Mdot
.52485 .40982 Mdot
.57038 .4275 Mdot
.57751 .36533 Mdot
.51314 .3705 Mdot
.35387 .39676 Mdot
.69466 .37483 Mdot
.35855 .58423 Mdot
.37946 .50154 Mdot
.36871 .63724 Mdot
.58335 .67347 Mdot
.49622 .77442 Mdot
.34715 .40495 Mdot
.66958 .5564 Mdot
.6125 .78902 Mdot
.43807 .18618 Mdot
.57416 .67173 Mdot
.23204 .63973 Mdot
.67846 .53001 Mdot
.59842 .36851 Mdot
.68987 .51694 Mdot
.52397 .6717 Mdot
.35782 .60386 Mdot
.57391 .33924 Mdot
.32287 .40368 Mdot
.29801 .42808 Mdot
.53631 .35561 Mdot
.544 .79563 Mdot
.39835 .62729 Mdot
.39639 .58457 Mdot
.50966 .41576 Mdot
.52622 .34622 Mdot
.32893 .43305 Mdot
.5758 .63975 Mdot
.58789 .24455 Mdot
.64796 .53683 Mdot
.55703 .44542 Mdot
.52357 .36599 Mdot
.67101 .23653 Mdot
.36762 .59571 Mdot
.51159 .64096 Mdot
.50502 .42632 Mdot
.24614 .55937 Mdot
.50336 .42384 Mdot
.49966 .4485 Mdot
.52448 .64083 Mdot
.47051 .42632 Mdot
.53016 .45158 Mdot
.33851 .3824 Mdot
.41493 .61353 Mdot
.32215 .42199 Mdot
.36411 .38713 Mdot
.29171 .49086 Mdot
.38795 .62754 Mdot
.53638 .37437 Mdot
.39656 .61 Mdot
.51084 .4105 Mdot
.50561 .37032 Mdot
.39866 .60358 Mdot
.32686 .43553 Mdot
.7293 .69234 Mdot
.5335 .7784 Mdot
.50823 .37598 Mdot
.50839 .44646 Mdot
.69101 .39464 Mdot
.7057 .50565 Mdot
.57261 .43059 Mdot
.30759 .41419 Mdot
.571 .36661 Mdot
.39891 .63429 Mdot
.69502 .52899 Mdot
.31775 .412 Mdot
.57884 .6565 Mdot
.56429 .67852 Mdot
.27613 .59091 Mdot
.56862 .61879 Mdot
.5629 .43796 Mdot
.38707 .43918 Mdot
.36786 .39697 Mdot
.5783 .8155 Mdot
.56255 .65479 Mdot
.66176 .51034 Mdot
.57498 .38626 Mdot
.76105 .4 Mdot
.33507 .60379 Mdot
.16034 .36727 Mdot
.26211 .31007 Mdot
.70404 .53759 Mdot
.25663 .33475 Mdot
.55814 .68684 Mdot
.54648 .4537 Mdot
.65535 .51502 Mdot
.55208 .67919 Mdot
.50294 .39583 Mdot
.49351 .43657 Mdot
.28603 .34868 Mdot
.39581 .5259 Mdot
.39431 .60683 Mdot
.58509 .63521 Mdot
.70525 .53289 Mdot
.53914 .69675 Mdot
.3372 .46317 Mdot
.56754 .41704 Mdot
.49069 .39049 Mdot
.57961 .64404 Mdot
.5308 .61092 Mdot
.54734 .38087 Mdot
.33501 .39897 Mdot
.55649 .582 Mdot
.56498 .40305 Mdot
.37685 .53104 Mdot
.3655 .45897 Mdot
.56052 .67137 Mdot
.5758 .41758 Mdot
.7062 .51545 Mdot
.57603 .64939 Mdot
.52167 .64957 Mdot
.52112 .35933 Mdot
.69785 .54069 Mdot
.49331 .42822 Mdot
.36678 .58672 Mdot
.19929 .65521 Mdot
.39711 .6356 Mdot
.49927 .69559 Mdot
.61866 .37678 Mdot
.23668 .52116 Mdot
.366 .41799 Mdot
.7216 .35077 Mdot
.47434 .68297 Mdot
.55256 .46082 Mdot
.81693 .58209 Mdot
.39219 .56677 Mdot
.57871 .80243 Mdot
.79357 .46586 Mdot
.68791 .5352 Mdot
.38228 .61902 Mdot
.56999 .42806 Mdot
.36978 .64248 Mdot
.6501 .51732 Mdot
.30802 .7509 Mdot
.58174 .40788 Mdot
.3047 .43084 Mdot
.5421 .38216 Mdot
.30131 .43658 Mdot
.51617 .36175 Mdot
.47846 .39576 Mdot
.43846 .67398 Mdot
.65293 .33188 Mdot
.51059 .42885 Mdot
.62201 .16513 Mdot
.52171 .49304 Mdot
.64911 .52773 Mdot
.56097 .37592 Mdot
.50609 .65594 Mdot
.3417 .61303 Mdot
.3081 .67008 Mdot
.54143 .63613 Mdot
.39529 .58654 Mdot
.3372 .42696 Mdot
.54857 .66066 Mdot
.57895 .66897 Mdot
.47063 .42821 Mdot
.70045 .53454 Mdot
.36732 .61815 Mdot
.55474 .42171 Mdot
.58083 .40845 Mdot
.4558 .20172 Mdot
.69796 .66649 Mdot
.34402 .48525 Mdot
.32273 .22491 Mdot
.30729 .46462 Mdot
.65639 .52473 Mdot
.53402 .63654 Mdot
.54543 .43609 Mdot
.53974 .39243 Mdot
.45829 .71427 Mdot
.31446 .40019 Mdot
.47425 .55008 Mdot
.24581 .39625 Mdot
.59443 .57531 Mdot
.672 .34493 Mdot
.30882 .4175 Mdot
.67154 .348 Mdot
.69093 .56749 Mdot
.77015 .68762 Mdot
.66172 .3574 Mdot
.40469 .61321 Mdot
.67276 .35864 Mdot
.32013 .45046 Mdot
.4984 .39947 Mdot
.52882 .62984 Mdot
.55482 .61364 Mdot
.32218 .42868 Mdot
.51914 .68015 Mdot
.6896 .54495 Mdot
.56077 .42869 Mdot
.33867 .24265 Mdot
.29232 .56074 Mdot
.55985 .62933 Mdot
.52368 .46695 Mdot
.37437 .62873 Mdot
.53554 .35534 Mdot
.69192 .53354 Mdot
.39415 .61632 Mdot
.7127 .30353 Mdot
.40817 .65368 Mdot
.5726 .38924 Mdot
.67661 .23514 Mdot
.38845 .62295 Mdot
.50411 .48055 Mdot
.56333 .40956 Mdot
.37445 .58514 Mdot
.45932 .42847 Mdot
.43427 .75369 Mdot
.53098 .559 Mdot
.83224 .50281 Mdot
.51089 .54802 Mdot
.54296 .62408 Mdot
.45416 .76563 Mdot
.33632 .68705 Mdot
.34713 .60894 Mdot
.51643 .6266 Mdot
.61737 .4953 Mdot
.4159 .62345 Mdot
.59535 .36654 Mdot
.52059 .41057 Mdot
.28471 .71667 Mdot
.35396 .57186 Mdot
.41699 .7666 Mdot
.2944 .61518 Mdot
.53878 .34859 Mdot
.4909 .42172 Mdot
.54232 .39629 Mdot
.32272 .39252 Mdot
.38376 .59964 Mdot
.57913 .16271 Mdot
.39306 .63004 Mdot
.35184 .26433 Mdot
.55909 .63392 Mdot
.5565 .67592 Mdot
.53537 .41616 Mdot
.45733 .46727 Mdot
.69105 .30699 Mdot
.54474 .38634 Mdot
.63665 .50222 Mdot
.32259 .72974 Mdot
.52747 .34719 Mdot
.35344 .4044 Mdot
.50396 .45688 Mdot
.5858 .47364 Mdot
.35698 .59416 Mdot
.67887 .55144 Mdot
.71636 .33369 Mdot
.35799 .61245 Mdot
.5448 .4083 Mdot
.24483 .52756 Mdot
.52099 .39274 Mdot
.5066 .38128 Mdot
.28614 .30465 Mdot
.66052 .56461 Mdot
.55147 .64802 Mdot
.66651 .53714 Mdot
.3647 .42498 Mdot
.14356 .35563 Mdot
.67256 .56235 Mdot
.69342 .30178 Mdot
.27318 .71869 Mdot
.67187 .36954 Mdot
.30656 .44974 Mdot
.69571 .51993 Mdot
.40362 .62227 Mdot
.82583 .59532 Mdot
.29012 .35983 Mdot
.37952 .55687 Mdot
.56002 .40319 Mdot
.28039 .42997 Mdot
.29626 .42237 Mdot
.41112 .63548 Mdot
.33617 .45913 Mdot
.48744 .33816 Mdot
.50135 .38967 Mdot
.35557 .62876 Mdot
.25817 .55395 Mdot
.36994 .57809 Mdot
.45416 .58415 Mdot
.5604 .38109 Mdot
.31505 .41539 Mdot
.55864 .44731 Mdot
.38043 .44189 Mdot
.51258 .66097 Mdot
.51466 .34335 Mdot
.68865 .54787 Mdot
.23246 .53785 Mdot
.56709 .66339 Mdot
.61394 .57341 Mdot
.363 .43651 Mdot
.37416 .66392 Mdot
.35788 .44859 Mdot
.38195 .42059 Mdot
.41424 .60034 Mdot
.33987 .44607 Mdot
.56856 .42752 Mdot
.57066 .54547 Mdot
.35867 .43018 Mdot
.37207 .61004 Mdot
.67606 .55003 Mdot
.34026 .43069 Mdot
.50141 .67307 Mdot
.57748 .39079 Mdot
.53212 .64783 Mdot
.74047 .57191 Mdot
.28327 .43134 Mdot
.67067 .5667 Mdot
.53029 .61295 Mdot
.64154 .53374 Mdot
.52074 .82706 Mdot
.41368 .64329 Mdot
.32941 .28754 Mdot
.65312 .49298 Mdot
.29279 .42014 Mdot
.74428 .57323 Mdot
.53665 .432 Mdot
.57689 .38826 Mdot
.66157 .50595 Mdot
.29636 .422 Mdot
.70405 .76154 Mdot
.62799 .40815 Mdot
.43715 .55942 Mdot
.42794 .60508 Mdot
.65309 .19662 Mdot
.44531 .57357 Mdot
.59733 .84209 Mdot
.58033 .45552 Mdot
.55655 .60524 Mdot
.53347 .40598 Mdot
.45965 .68446 Mdot
.66497 .52731 Mdot
.47943 .6471 Mdot
.48788 .38067 Mdot
.55227 .65399 Mdot
.58635 .38045 Mdot
.55862 .52888 Mdot
.52505 .48098 Mdot
.6553 .51133 Mdot
.57396 .76564 Mdot
.28972 .44249 Mdot
.68251 .53852 Mdot
.54006 .67936 Mdot
.68418 .33394 Mdot
.50262 .39299 Mdot
.60522 .37907 Mdot
.59485 .57582 Mdot
.30623 .44565 Mdot
.53817 .62121 Mdot
.3638 .58958 Mdot
.6685 .55416 Mdot
.55766 .36132 Mdot
.52851 .43284 Mdot
.43753 .71466 Mdot
.37547 .6315 Mdot
.56197 .61174 Mdot
.40971 .61019 Mdot
.57494 .67756 Mdot
.49771 .38264 Mdot
.56795 .67275 Mdot
.5848 .43498 Mdot
.43119 .6747 Mdot
.31163 .29039 Mdot
.41303 .30895 Mdot
.54681 .6672 Mdot
.64709 .27774 Mdot
.37915 .63074 Mdot
.39623 .59386 Mdot
.21793 .64926 Mdot
.29277 .33506 Mdot
.43409 .19618 Mdot
.79418 .56552 Mdot
.3619 .63079 Mdot
.37226 .62197 Mdot
.53267 .65073 Mdot
.34215 .44654 Mdot
.31375 .46511 Mdot
.57768 .67472 Mdot
.73031 .46769 Mdot
.3131 .45041 Mdot
.79651 .62575 Mdot
.51973 .19967 Mdot
.59402 .4236 Mdot
.54608 .70322 Mdot
.6619 .54646 Mdot
.72481 .45059 Mdot
.56602 .53028 Mdot
.5796 .4193 Mdot
.74407 .38314 Mdot
.56636 .63375 Mdot
.43318 .44783 Mdot
.82143 .48715 Mdot
.59088 .38263 Mdot
.56191 .414 Mdot
.54056 .4022 Mdot
.70228 .5497 Mdot
.30583 .34934 Mdot
.56929 .42239 Mdot
.72997 .46995 Mdot
.5361 .35179 Mdot
.49481 .47307 Mdot
.67003 .54115 Mdot
.64953 .35147 Mdot
.72855 .64117 Mdot
.52745 .17321 Mdot
.56458 .48877 Mdot
.36263 .58882 Mdot
.72685 .56737 Mdot
.40562 .5999 Mdot
.37725 .31041 Mdot
.66192 .38303 Mdot
.29779 .4617 Mdot
.57799 .42205 Mdot
.55234 .66729 Mdot
.29617 .42354 Mdot
.44699 .74251 Mdot
.16862 .31331 Mdot
.35812 .5891 Mdot
.68988 .81774 Mdot
.37764 .58636 Mdot
.58047 .66785 Mdot
.3293 .43208 Mdot
.49598 .29602 Mdot
.35248 .5085 Mdot
.34257 .42857 Mdot
.70064 .73848 Mdot
.27072 .44369 Mdot
.66834 .31215 Mdot
.29277 .40898 Mdot
.37391 .61598 Mdot
.35208 .67024 Mdot
.52048 .30963 Mdot
.53299 .42676 Mdot
.42794 .5107 Mdot
.67996 .30249 Mdot
.53839 .43233 Mdot
.55795 .66724 Mdot
.30988 .30092 Mdot
.73636 .38852 Mdot
.33324 .44749 Mdot
.41483 .65044 Mdot
.56876 .41245 Mdot
.51737 .3743 Mdot
.50058 .39819 Mdot
.27719 .2826 Mdot
.76744 .69115 Mdot
.49709 .39598 Mdot
.52364 .35403 Mdot
.5506 .65811 Mdot
.68045 .49676 Mdot
.58032 .74838 Mdot
.43442 .221 Mdot
.59152 .39863 Mdot
.6788 .53988 Mdot
.71007 .54684 Mdot
.50079 .41761 Mdot
.60273 .54151 Mdot
.24546 .51895 Mdot
.55624 .42183 Mdot
.31128 .30308 Mdot
.61221 .60993 Mdot
.58084 .62247 Mdot
.57893 .65073 Mdot
.31231 .45627 Mdot
.58391 .65003 Mdot
.54981 .68621 Mdot
.49181 .30574 Mdot
.49268 .54687 Mdot
.44504 .62323 Mdot
.65852 .53256 Mdot
.5343 .39129 Mdot
.57936 .30756 Mdot
.2429 .54789 Mdot
.41716 .6101 Mdot
.32506 .40731 Mdot
.34004 .61089 Mdot
.70035 .57817 Mdot
.29014 .48103 Mdot
.56568 .62669 Mdot
.35692 .62187 Mdot
.34817 .63907 Mdot
.67714 .54196 Mdot
.40065 .63687 Mdot
.33567 .63135 Mdot
.53726 .33571 Mdot
.42159 .34296 Mdot
.55142 .38711 Mdot
.61481 .79391 Mdot
.36877 .62555 Mdot
.3832 .67938 Mdot
.54947 .41462 Mdot
.57465 .6504 Mdot
.48847 .32253 Mdot
.52759 .42597 Mdot
.5818 .64411 Mdot
.50097 .4279 Mdot
.6402 .54522 Mdot
.37542 .44789 Mdot
.35984 .50498 Mdot
.15851 .60735 Mdot
.70015 .53165 Mdot
.4493 .73782 Mdot
.57803 .42641 Mdot
.42908 .81851 Mdot
.33873 .43328 Mdot
.5323 .44219 Mdot
.71751 .36909 Mdot
.35426 .43538 Mdot
.33196 .41457 Mdot
.52769 .37226 Mdot
.4069 .61283 Mdot
.56549 .66637 Mdot
.67249 .54427 Mdot
.58702 .83132 Mdot
.56351 .39626 Mdot
.579 .3748 Mdot
.68103 .53385 Mdot
.38102 .63424 Mdot
.5055 .42479 Mdot
.77152 .51697 Mdot
.72946 .74745 Mdot
.38828 .58781 Mdot
.59653 .37404 Mdot
.37073 .33599 Mdot
.61442 .45404 Mdot
.37851 .82807 Mdot
.60114 .52857 Mdot
.54681 .65123 Mdot
.6007 .34035 Mdot
.2133 .29628 Mdot
.67551 .55207 Mdot
.43584 .18884 Mdot
.51855 .37142 Mdot
.56083 .35723 Mdot
.30649 .40696 Mdot
.55199 .37449 Mdot
.34021 .40302 Mdot
.15785 .56194 Mdot
.66588 .22807 Mdot
.32771 .46118 Mdot
.28947 .42384 Mdot
.70479 .32418 Mdot
.50675 .71214 Mdot
.32497 .42812 Mdot
.50873 .36544 Mdot
.63418 .45146 Mdot
.41738 .42914 Mdot
.68351 .5107 Mdot
.74503 .59908 Mdot
.62304 .35401 Mdot
.63112 .56437 Mdot
.7503 .64905 Mdot
.62046 .34023 Mdot
.47634 .60083 Mdot
.37513 .58993 Mdot
.59113 .38406 Mdot
.55687 .61339 Mdot
.568 .61742 Mdot
.5657 .45146 Mdot
.5274 .3882 Mdot
.36463 .42878 Mdot
.65673 .54953 Mdot
.3481 .59716 Mdot
.55615 .35781 Mdot
.71485 .34654 Mdot
.65631 .55382 Mdot
.33938 .45453 Mdot
.37955 .26334 Mdot
.63523 .53223 Mdot
.47652 .38739 Mdot
.54512 .42426 Mdot
.53891 .37941 Mdot
.53289 .30465 Mdot
.38455 .59708 Mdot
.75034 .58102 Mdot
.56377 .34327 Mdot
.60883 .20123 Mdot
.44024 .60381 Mdot
.51984 .33447 Mdot
.34435 .4598 Mdot
.43022 .64399 Mdot
.54196 .69274 Mdot
.26697 .47488 Mdot
.57057 .38974 Mdot
.55167 .78711 Mdot
.29874 .7257 Mdot
.51255 .65054 Mdot
.379 .43628 Mdot
.66028 .53915 Mdot
.54213 .38671 Mdot
.35483 .29234 Mdot
.52317 .41257 Mdot
.63089 .55624 Mdot
.51979 .64976 Mdot
.37832 .59001 Mdot
.59066 .80085 Mdot
.58095 .62822 Mdot
.32948 .41642 Mdot
.7627 .30422 Mdot
.34148 .40262 Mdot
.316 .46452 Mdot
.39418 .25991 Mdot
.38609 .59657 Mdot
.18482 .32774 Mdot
.17094 .57152 Mdot
.51405 .34722 Mdot
.38221 .63222 Mdot
.31552 .42793 Mdot
.55229 .3512 Mdot
.31149 .47373 Mdot
.35847 .45891 Mdot
.50296 .37079 Mdot
.57705 .36242 Mdot
.44084 .78645 Mdot
.82133 .51047 Mdot
.65988 .53766 Mdot
.36821 .43063 Mdot
.34866 .52249 Mdot
.55504 .35043 Mdot
.54082 .41372 Mdot
.33661 .69291 Mdot
.69574 .52721 Mdot
.31809 .55088 Mdot
.51788 .37302 Mdot
.69247 .26187 Mdot
.47316 .42368 Mdot
.35019 .39741 Mdot
.40529 .59746 Mdot
.53951 .17771 Mdot
.32724 .59651 Mdot
.33876 .40354 Mdot
.66995 .55826 Mdot
.35403 .38984 Mdot
.69117 .29694 Mdot
.37561 .63742 Mdot
.31214 .41156 Mdot
.52143 .57955 Mdot
.38478 .60539 Mdot
.36264 .62341 Mdot
.40752 .2494 Mdot
.50966 .64134 Mdot
.70361 .55037 Mdot
.36924 .62057 Mdot
.2175 .49537 Mdot
.37666 .61082 Mdot
.17873 .58935 Mdot
.59485 .38097 Mdot
.74468 .44316 Mdot
.48395 .67195 Mdot
.58384 .32372 Mdot
.368 .62903 Mdot
.68538 .52151 Mdot
.50386 .39618 Mdot
.32292 .45368 Mdot
.64494 .53608 Mdot
.3568 .55266 Mdot
.53938 .64106 Mdot
.35582 .44813 Mdot
.35841 .57577 Mdot
.29935 .43082 Mdot
.24237 .46804 Mdot
.24946 .70683 Mdot
.74977 .35409 Mdot
.34452 .51098 Mdot
.50292 .39047 Mdot
.77298 .60682 Mdot
.60203 .38643 Mdot
.52275 .38637 Mdot
.55856 .67059 Mdot
.74296 .41863 Mdot
.32615 .43529 Mdot
.65901 .78409 Mdot
.35431 .59959 Mdot
.5384 .17293 Mdot
.58851 .4818 Mdot
.52552 .44732 Mdot
.35879 .42658 Mdot
.32348 .3981 Mdot
.40869 .28625 Mdot
.55318 .69603 Mdot
.56909 .43863 Mdot
.59927 .36132 Mdot
.54292 .45782 Mdot
.35639 .60219 Mdot
.61237 .55761 Mdot
.54597 .62441 Mdot
.30975 .76588 Mdot
.51901 .64586 Mdot
.62625 .55232 Mdot
.33612 .44892 Mdot
.67268 .56216 Mdot
.54222 .41542 Mdot
.30657 .47853 Mdot
.3136 .39983 Mdot
.65482 .509 Mdot
.67299 .51597 Mdot
.40116 .732 Mdot
.3983 .6039 Mdot
.51935 .42598 Mdot
.57441 .41927 Mdot
.55182 .3687 Mdot
.52726 .38061 Mdot
.35532 .5933 Mdot
.50349 .40516 Mdot
.33431 .59348 Mdot
.23698 .43118 Mdot
.77044 .47501 Mdot
.51328 .54542 Mdot
.24785 .64497 Mdot
.3265 .45017 Mdot
.22301 .50273 Mdot
.61767 .42986 Mdot
.22577 .34091 Mdot
.35424 .76978 Mdot
.5493 .33868 Mdot
.562 .67813 Mdot
.44889 .40923 Mdot
.56284 .6198 Mdot
.59061 .8549 Mdot
.41263 .7004 Mdot
.82716 .53641 Mdot
.58108 .40704 Mdot
.56529 .54708 Mdot
.20256 .50927 Mdot
.60338 .38212 Mdot
.41584 .71596 Mdot
.25177 .63827 Mdot
.56264 .77037 Mdot
.69316 .53186 Mdot
.57346 .39916 Mdot
.5642 .30524 Mdot
.56586 .42757 Mdot
.53546 .41 Mdot
.50176 .40154 Mdot
.36214 .57876 Mdot
.54219 .44176 Mdot
.50826 .3952 Mdot
.6306 .69573 Mdot
.66556 .3405 Mdot
.54151 .60971 Mdot
.23744 .67414 Mdot
.67273 .56271 Mdot
.36175 .43127 Mdot
.76398 .68453 Mdot
.40414 .61273 Mdot
.41529 .28421 Mdot
.53232 .37997 Mdot
.47705 .78621 Mdot
.3653 .64821 Mdot
.67674 .55626 Mdot
.52421 .67367 Mdot
.83643 .55592 Mdot
.55683 .66388 Mdot
.4194 .66494 Mdot
.57266 .65262 Mdot
.62367 .41196 Mdot
.36524 .42879 Mdot
.51045 .42341 Mdot
.36572 .61464 Mdot
.5799 .66049 Mdot
.69607 .40766 Mdot
.5403 .39698 Mdot
.55927 .65558 Mdot
.51061 .42303 Mdot
.3424 .49534 Mdot
.48496 .21268 Mdot
.54889 .68479 Mdot
.36254 .64598 Mdot
.36967 .60036 Mdot
.69711 .545 Mdot
.35803 .44037 Mdot
.33027 .40528 Mdot
.39254 .61574 Mdot
.25777 .35927 Mdot
.59154 .40321 Mdot
.56349 .3539 Mdot
.56495 .18507 Mdot
.56325 .43286 Mdot
.67822 .33014 Mdot
.54109 .56697 Mdot
.33112 .45522 Mdot
.51921 .44662 Mdot
.52664 .3687 Mdot
.57379 .38885 Mdot
.24956 .42813 Mdot
.57557 .6377 Mdot
.59247 .38207 Mdot
.66759 .51526 Mdot
.6128 .69023 Mdot
.53478 .35542 Mdot
.4621 .39525 Mdot
.3279 .40533 Mdot
.32097 .23117 Mdot
.38017 .58744 Mdot
.54176 .679 Mdot
.54546 .66748 Mdot
.75099 .60583 Mdot
.22471 .56912 Mdot
.54287 .56541 Mdot
.34156 .79366 Mdot
.43903 .67304 Mdot
.66369 .52153 Mdot
.5991 .67641 Mdot
.34578 .67261 Mdot
.5352 .66405 Mdot
.35537 .59038 Mdot
.59445 .37267 Mdot
.59219 .39582 Mdot
.19069 .36901 Mdot
.50041 .41989 Mdot
.66251 .54235 Mdot
.36875 .57722 Mdot
.31955 .44953 Mdot
.67327 .55648 Mdot
.41052 .60989 Mdot
.3185 .45711 Mdot
.56034 .33916 Mdot
.56751 .34281 Mdot
.32805 .40777 Mdot
.30426 .41312 Mdot
.54648 .42169 Mdot
.55168 .73715 Mdot
.29004 .42781 Mdot
.30906 .41545 Mdot
.56213 .62642 Mdot
.56277 .61569 Mdot
.47211 .37479 Mdot
.38034 .62823 Mdot
.50687 .39695 Mdot
.54996 .6628 Mdot
.67615 .56124 Mdot
.32628 .43801 Mdot
.51025 .37408 Mdot
.53827 .35828 Mdot
.67715 .54343 Mdot
.69025 .5526 Mdot
.68924 .52972 Mdot
.34734 .5819 Mdot
.56025 .37044 Mdot
.33229 .42769 Mdot
.39426 .59917 Mdot
.70895 .54812 Mdot
.68321 .51265 Mdot
.58475 .69327 Mdot
.55457 .43705 Mdot
.5235 .71309 Mdot
.23037 .27124 Mdot
.62049 .22108 Mdot
.52227 .67808 Mdot
.53975 .69391 Mdot
.67045 .42041 Mdot
.43301 .4619 Mdot
.39401 .62564 Mdot
.67991 .4955 Mdot
.71502 .32548 Mdot
.55654 .33399 Mdot
.523 .35135 Mdot
.48157 .405 Mdot
.68486 .52499 Mdot
.75363 .4242 Mdot
.34918 .40641 Mdot
.61414 .31115 Mdot
.65181 .5511 Mdot
.53389 .61016 Mdot
.57914 .70221 Mdot
.51851 .65106 Mdot
.58739 .35833 Mdot
.42374 .30744 Mdot
.22044 .53342 Mdot
.78345 .55214 Mdot
.37226 .63104 Mdot
.5809 .30851 Mdot
.42591 .81451 Mdot
.33163 .41088 Mdot
.58434 .673 Mdot
.6633 .51993 Mdot
.30286 .41585 Mdot
.34382 .62219 Mdot
.37068 .6196 Mdot
.55715 .62887 Mdot
.55126 .63006 Mdot
.52643 .65171 Mdot
.35765 .46081 Mdot
.33835 .44759 Mdot
.5692 .38756 Mdot
.32674 .4418 Mdot
.24901 .31464 Mdot
.66427 .50196 Mdot
.52693 .60214 Mdot
.38226 .6222 Mdot
.31045 .45214 Mdot
.54246 .39499 Mdot
.42408 .44792 Mdot
.28062 .63424 Mdot
.6493 .52368 Mdot
.46906 .20581 Mdot
.57033 .85352 Mdot
.52284 .42856 Mdot
.37551 .59562 Mdot
.34279 .23694 Mdot
.54329 .40136 Mdot
.53204 .6351 Mdot
.62597 .74445 Mdot
.6076 .67183 Mdot
.52523 .42468 Mdot
.55184 .33171 Mdot
.37153 .58369 Mdot
.32513 .77222 Mdot
.56583 .39082 Mdot
.31624 .53618 Mdot
.38331 .64871 Mdot
.53854 .62538 Mdot
.82085 .65327 Mdot
.69607 .58819 Mdot
.72923 .45819 Mdot
.55344 .62613 Mdot
.51615 .3988 Mdot
.56879 .62495 Mdot
.65858 .51826 Mdot
.53465 .68035 Mdot
.34345 .40168 Mdot
.51776 .63679 Mdot
.57925 .37413 Mdot
.32305 .42665 Mdot
.38842 .62425 Mdot
.50704 .1791 Mdot
.65086 .71647 Mdot
.57447 .64805 Mdot
.55994 .68279 Mdot
.51203 .44117 Mdot
.32435 .55792 Mdot
.57693 .44273 Mdot
.58426 .36262 Mdot
.36582 .63454 Mdot
.35621 .43593 Mdot
.39588 .58933 Mdot
.51802 .32555 Mdot
.78339 .48343 Mdot
.40766 .6068 Mdot
.54106 .77916 Mdot
.67698 .52848 Mdot
.48341 .50692 Mdot
.5389 .39096 Mdot
.40923 .63177 Mdot
.56155 .37251 Mdot
.35585 .41141 Mdot
.51543 .53113 Mdot
.53505 .75896 Mdot
.36018 .61133 Mdot
.56829 .7936 Mdot
.76196 .50089 Mdot
.47618 .35906 Mdot
.39775 .59394 Mdot
.72534 .38118 Mdot
.58162 .66636 Mdot
.64726 .53765 Mdot
.6379 .53232 Mdot
.64615 .54666 Mdot
.58127 .44662 Mdot
.57502 .4869 Mdot
.66866 .5674 Mdot
.34419 .61853 Mdot
.65533 .51151 Mdot
.19822 .56386 Mdot
.66382 .77919 Mdot
.66802 .52825 Mdot
.56271 .40696 Mdot
.56542 .47446 Mdot
.66588 .38456 Mdot
.42682 .75433 Mdot
.82381 .55292 Mdot
.31997 .70615 Mdot
.53004 .42367 Mdot
.35311 .46664 Mdot
.36914 .44518 Mdot
.36172 .21463 Mdot
.66714 .29091 Mdot
.64824 .23172 Mdot
.28922 .44565 Mdot
.49796 .72849 Mdot
.34504 .45295 Mdot
.49912 .40958 Mdot
.55937 .35266 Mdot
.28785 .44573 Mdot
.77279 .45331 Mdot
.48715 .73522 Mdot
.58951 .8152 Mdot
.30033 .42324 Mdot
.41455 .61217 Mdot
.42355 .6214 Mdot
.36358 .62569 Mdot
.49524 .19514 Mdot
.35462 .42267 Mdot
.54792 .36267 Mdot
.54821 .66864 Mdot
.59002 .39524 Mdot
.3884 .60529 Mdot
.6713 .77997 Mdot
.34753 .42922 Mdot
.57087 .41545 Mdot
.4755 .34407 Mdot
.5452 .6336 Mdot
.67709 .53513 Mdot
.37362 .48904 Mdot
.64837 .23622 Mdot
.35325 .60847 Mdot
.28395 .43482 Mdot
.40159 .68192 Mdot
.61212 .78551 Mdot
.57565 .45924 Mdot
.59552 .35329 Mdot
.58389 .83576 Mdot
.70072 .27846 Mdot
.57149 .43444 Mdot
.54973 .68146 Mdot
.45143 .71007 Mdot
.52714 .3604 Mdot
.37059 .43821 Mdot
.63567 .53389 Mdot
.64235 .53303 Mdot
.47135 .37464 Mdot
.38872 .49854 Mdot
.54792 .53788 Mdot
.53419 .37458 Mdot
.47718 .38994 Mdot
.54258 .62534 Mdot
.45009 .67606 Mdot
.61643 .20551 Mdot
.67696 .55933 Mdot
.50885 .42346 Mdot
.69542 .72768 Mdot
.30442 .40572 Mdot
.51343 .6561 Mdot
.39003 .64006 Mdot
.26089 .4152 Mdot
.52575 .67571 Mdot
.51014 .36849 Mdot
.50248 .42083 Mdot
.4201 .6105 Mdot
.34879 .39754 Mdot
.68326 .52504 Mdot
.55426 .67466 Mdot
.69154 .54789 Mdot
.35426 .43298 Mdot
.33306 .44271 Mdot
.47438 .34893 Mdot
.59093 .454 Mdot
.57826 .65597 Mdot
.58716 .43378 Mdot
.60619 .68464 Mdot
.42337 .84567 Mdot
.41238 .5887 Mdot
.54128 .43862 Mdot
.30461 .39701 Mdot
.35705 .60824 Mdot
.56691 .35857 Mdot
.61431 .83268 Mdot
.54833 .34929 Mdot
.43656 .61938 Mdot
.73866 .31988 Mdot
.69179 .53867 Mdot
.62485 .32833 Mdot
.41036 .78423 Mdot
.5575 .43314 Mdot
.53866 .66065 Mdot
.52372 .46588 Mdot
.40709 .61967 Mdot
.33404 .44791 Mdot
.4085 .8485 Mdot
.37411 .6076 Mdot
.55903 .42697 Mdot
.67008 .55512 Mdot
.30185 .40173 Mdot
.61055 .50761 Mdot
.60366 .54619 Mdot
.47689 .44792 Mdot
.56046 .44474 Mdot
.52101 .37827 Mdot
.77905 .52164 Mdot
.53918 .6766 Mdot
.3097 .42225 Mdot
.37149 .59504 Mdot
.39431 .61902 Mdot
.56382 .63125 Mdot
.45316 .6093 Mdot
.48243 .50731 Mdot
.32491 .19529 Mdot
.58088 .63517 Mdot
.66198 .56236 Mdot
.32612 .54527 Mdot
.54713 .67442 Mdot
.56173 .65196 Mdot
.56068 .62503 Mdot
.4929 .59544 Mdot
.31044 .45017 Mdot
.51159 .36626 Mdot
.36796 .41669 Mdot
.51437 .39806 Mdot
.43636 .62194 Mdot
.36296 .61519 Mdot
.34751 .43395 Mdot
.55315 .82891 Mdot
.40383 .35955 Mdot
.55111 .40608 Mdot
.42977 .81798 Mdot
.4899 .38318 Mdot
.67557 .38866 Mdot
.48642 .40668 Mdot
.56841 .63949 Mdot
.60938 .38836 Mdot
.55296 .45918 Mdot
.3988 .19523 Mdot
.38275 .62543 Mdot
.58561 .62609 Mdot
.49442 .36019 Mdot
.47694 .3997 Mdot
.34851 .46554 Mdot
.30415 .41589 Mdot
.63859 .53514 Mdot
.64671 .31515 Mdot
.38917 .6271 Mdot
.17247 .52129 Mdot
.53518 .42668 Mdot
.63698 .58013 Mdot
.53996 .24805 Mdot
.571 .3607 Mdot
.43285 .79946 Mdot
.42102 .30176 Mdot
.54106 .38795 Mdot
.43909 .54115 Mdot
.37762 .63089 Mdot
.78608 .45008 Mdot
.52959 .35441 Mdot
.53958 .63456 Mdot
.34097 .44989 Mdot
.31564 .39746 Mdot
.64433 .55088 Mdot
.2071 .37646 Mdot
.39875 .58996 Mdot
.34161 .4422 Mdot
.5341 .39781 Mdot
.37798 .59413 Mdot
.58429 .64048 Mdot
.52551 .44554 Mdot
.65474 .27572 Mdot
.32094 .44427 Mdot
.4969 .42409 Mdot
.2945 .52434 Mdot
.69227 .44961 Mdot
.77232 .34977 Mdot
.36762 .59488 Mdot
.69664 .54101 Mdot
.49785 .44956 Mdot
.28001 .34656 Mdot
.49588 .43509 Mdot
.74668 .46385 Mdot
.20167 .57639 Mdot
.69591 .53141 Mdot
.55378 .41335 Mdot
.55456 .3609 Mdot
.48103 .48004 Mdot
.67186 .5597 Mdot
.57999 .41148 Mdot
.26859 .3875 Mdot
.30375 .43816 Mdot
.58174 .67377 Mdot
.3151 .44825 Mdot
.55965 .40379 Mdot
.58366 .45926 Mdot
.30632 .40838 Mdot
.44563 .83855 Mdot
.67065 .49797 Mdot
.38978 .59192 Mdot
.50297 .36268 Mdot
.56283 .34598 Mdot
.56409 .14512 Mdot
.51308 .64273 Mdot
.554 .74317 Mdot
.63505 .62488 Mdot
.73003 .68293 Mdot
.70103 .58653 Mdot
.82479 .44054 Mdot
.70568 .28274 Mdot
.54014 .44201 Mdot
.63204 .43369 Mdot
.24963 .49638 Mdot
.37411 .63417 Mdot
.19981 .45297 Mdot
.53292 .42698 Mdot
.53366 .40814 Mdot
.52498 .68235 Mdot
.50971 .768 Mdot
.64653 .22937 Mdot
.4192 .45882 Mdot
.68416 .52712 Mdot
.36742 .43523 Mdot
.50933 .36693 Mdot
.46714 .55311 Mdot
.53058 .61176 Mdot
.69835 .5827 Mdot
.56767 .41663 Mdot
.26218 .318 Mdot
.27046 .61564 Mdot
.39254 .60154 Mdot
.54372 .66671 Mdot
.66312 .24265 Mdot
.54667 .43682 Mdot
.39951 .63871 Mdot
.55904 .39467 Mdot
.53375 .58784 Mdot
.52677 .32176 Mdot
.66003 .52566 Mdot
.51408 .37475 Mdot
.71586 .57438 Mdot
.68987 .19802 Mdot
.66433 .56981 Mdot
.29478 .46277 Mdot
.53741 .60109 Mdot
.57793 .6402 Mdot
.30676 .41274 Mdot
.57846 .64506 Mdot
.4268 .26552 Mdot
.53171 .27916 Mdot
.67939 .52774 Mdot
.47105 .39766 Mdot
.66917 .53259 Mdot
.51278 .65892 Mdot
.52845 .42474 Mdot
.49087 .86176 Mdot
.573 .66527 Mdot
.71263 .27432 Mdot
.37956 .61137 Mdot
.52973 .61132 Mdot
.53535 .35236 Mdot
.3793 .68496 Mdot
.57947 .62706 Mdot
.51125 .75204 Mdot
.57321 .38859 Mdot
.32577 .447 Mdot
.53152 .36048 Mdot
.5125 .34976 Mdot
.55193 .60597 Mdot
.50971 .40509 Mdot
.41097 .61111 Mdot
.29975 .45389 Mdot
.81231 .6086 Mdot
.23865 .6156 Mdot
.57759 .41974 Mdot
.53653 .39891 Mdot
.3715 .40191 Mdot
.58502 .35878 Mdot
.35589 .59282 Mdot
.11881 .59183 Mdot
.67704 .52893 Mdot
.58349 .61851 Mdot
.71152 .58324 Mdot
.55169 .33721 Mdot
.50346 .40016 Mdot
.64387 .82296 Mdot
.77927 .48462 Mdot
.40449 .59954 Mdot
.54109 .45836 Mdot
.58424 .63647 Mdot
.66409 .55128 Mdot
.34447 .61144 Mdot
.5409 .37954 Mdot
.54562 .41486 Mdot
.69443 .55064 Mdot
.63356 .46127 Mdot
.54368 .20045 Mdot
.41669 .62791 Mdot
.6142 .36817 Mdot
.49772 .64866 Mdot
.58982 .41336 Mdot
.46528 .19649 Mdot
.31484 .41228 Mdot
.35353 .61368 Mdot
.75181 .63053 Mdot
.54588 .43848 Mdot
.41038 .60138 Mdot
.38804 .62748 Mdot
.51784 .44877 Mdot
.29037 .40348 Mdot
.31093 .45826 Mdot
.30008 .43565 Mdot
.15854 .40941 Mdot
.71898 .43551 Mdot
.52641 .65151 Mdot
.37841 .63194 Mdot
.55851 .68528 Mdot
.62851 .55358 Mdot
.529 .56262 Mdot
.55562 .68455 Mdot
.3005 .44307 Mdot
.56025 .60159 Mdot
.56786 .36993 Mdot
.39003 .62478 Mdot
.53262 .65969 Mdot
.51975 .34426 Mdot
.33801 .5492 Mdot
.37075 .74257 Mdot
.68049 .51347 Mdot
.6355 .54033 Mdot
.54789 .35254 Mdot
.55978 .69257 Mdot
.54397 .4204 Mdot
.37625 .64306 Mdot
.33669 .54492 Mdot
.50524 .36116 Mdot
.57473 .64533 Mdot
.36394 .3949 Mdot
.65553 .24071 Mdot
.60132 .42435 Mdot
.56162 .40785 Mdot
.51279 .40265 Mdot
.55924 .39415 Mdot
.61271 .77739 Mdot
.4275 .62291 Mdot
.24751 .64178 Mdot
.74707 .57558 Mdot
.34564 .4243 Mdot
.37189 .41834 Mdot
.60671 .21053 Mdot
.25183 .50728 Mdot
.37961 .62883 Mdot
.52434 .38417 Mdot
.24855 .57034 Mdot
.72912 .74656 Mdot
.56143 .84343 Mdot
.48605 .47596 Mdot
.51378 .63428 Mdot
.28508 .43695 Mdot
.58086 .66361 Mdot
.51815 .40415 Mdot
.48128 .41123 Mdot
.8185 .40111 Mdot
.35384 .63239 Mdot
.67548 .52391 Mdot
.51279 .39635 Mdot
.71941 .44133 Mdot
.54914 .65898 Mdot
.5328 .60827 Mdot
.59115 .37339 Mdot
.34514 .39246 Mdot
.66618 .19413 Mdot
.38335 .59691 Mdot
.31523 .69288 Mdot
.20068 .51397 Mdot
.29362 .6338 Mdot
.38766 .60286 Mdot
.52815 .49757 Mdot
.5172 .66814 Mdot
.53192 .23902 Mdot
.34552 .41893 Mdot
.64558 .53323 Mdot
.5275 .33096 Mdot
.31716 .40405 Mdot
.52302 .63698 Mdot
.33047 .44765 Mdot
.50222 .39858 Mdot
.40845 .64612 Mdot
.54472 .65086 Mdot
.44611 .62011 Mdot
.30979 .39381 Mdot
.67221 .55844 Mdot
.42335 .48313 Mdot
.41673 .40296 Mdot
.42072 .2986 Mdot
.59331 .37851 Mdot
.47088 .55997 Mdot
.54856 .36416 Mdot
.37914 .42512 Mdot
.54763 .39536 Mdot
.39207 .42152 Mdot
.53917 .65959 Mdot
.52421 .35408 Mdot
.53057 .37589 Mdot
.19596 .61285 Mdot
.57834 .40456 Mdot
.58088 .43652 Mdot
.53798 .38595 Mdot
.34484 .48198 Mdot
.47112 .40519 Mdot
.34811 .459 Mdot
.61072 .70922 Mdot
.56248 .64883 Mdot
.64212 .52262 Mdot
.69867 .54693 Mdot
.73992 .42905 Mdot
.72472 .62719 Mdot
.48535 .77486 Mdot
.31102 .44167 Mdot
.40946 .62446 Mdot
.55219 .39399 Mdot
.81854 .48738 Mdot
.60366 .58537 Mdot
.52918 .61532 Mdot
.24087 .61772 Mdot
.60633 .34248 Mdot
.79263 .43555 Mdot
.54364 .45673 Mdot
.1795 .39069 Mdot
.61491 .41584 Mdot
.55509 .32356 Mdot
.59118 .65432 Mdot
.66804 .58047 Mdot
.57554 .35363 Mdot
.3368 .46788 Mdot
.65104 .53321 Mdot
.60065 .47281 Mdot
.52225 .70763 Mdot
.59795 .71862 Mdot
.39204 .45166 Mdot
.56545 .37979 Mdot
.54521 .6496 Mdot
.35772 .44607 Mdot
.62555 .21187 Mdot
.39289 .59759 Mdot
.44454 .59483 Mdot
.29329 .5029 Mdot
.45633 .83444 Mdot
.65748 .55511 Mdot
.49296 .22506 Mdot
.57685 .37215 Mdot
.61341 .7392 Mdot
.5014 .36713 Mdot
.68267 .77563 Mdot
.67571 .5644 Mdot
.29874 .44398 Mdot
.41515 .6161 Mdot
.37017 .43432 Mdot
.40834 .3032 Mdot
.55047 .70523 Mdot
.48024 .53263 Mdot
.55816 .66167 Mdot
.57641 .53215 Mdot
.31724 .42401 Mdot
.50888 .42058 Mdot
.32033 .19694 Mdot
.31087 .41407 Mdot
.29636 .40722 Mdot
.28348 .72907 Mdot
.45553 .85769 Mdot
.61013 .37091 Mdot
.28907 .42686 Mdot
.56322 .65886 Mdot
.65721 .53816 Mdot
.52037 .3643 Mdot
.56954 .37828 Mdot
.31929 .40458 Mdot
.56372 .60853 Mdot
.34066 .33063 Mdot
.55635 .63198 Mdot
.30819 .44872 Mdot
.55536 .64003 Mdot
.39541 .67796 Mdot
.54783 .67838 Mdot
.56431 .34622 Mdot
.54881 .39492 Mdot
.6965 .61436 Mdot
.33202 .44315 Mdot
.53582 .37373 Mdot
.51239 .44078 Mdot
.32929 .429 Mdot
.57741 .51125 Mdot
.35099 .32722 Mdot
.58134 .42126 Mdot
.57721 .39524 Mdot
.69617 .53533 Mdot
.49947 .57017 Mdot
.47751 .21537 Mdot
.5046 .39396 Mdot
.70145 .55012 Mdot
.33162 .46737 Mdot
.55433 .42257 Mdot
.74176 .71321 Mdot
.45525 .71212 Mdot
.52709 .42889 Mdot
.58111 .66667 Mdot
.54968 .45882 Mdot
.7616 .33311 Mdot
.58284 .3611 Mdot
.32027 .43187 Mdot
.34875 .44185 Mdot
.17214 .54417 Mdot
.32713 .41704 Mdot
.55551 .61369 Mdot
.38664 .60557 Mdot
.60524 .79477 Mdot
.58465 .64522 Mdot
.60322 .43357 Mdot
.17438 .61609 Mdot
.51765 .43632 Mdot
.53967 .34116 Mdot
.71508 .25682 Mdot
.5776 .6649 Mdot
.3591 .42044 Mdot
.44269 .47561 Mdot
.59929 .45068 Mdot
.35591 .6178 Mdot
.50543 .34102 Mdot
.59593 .3735 Mdot
.73379 .30518 Mdot
.62128 .76543 Mdot
.3913 .6429 Mdot
.58352 .43197 Mdot
.50397 .39612 Mdot
.5065 .65813 Mdot
.53739 .39483 Mdot
.65768 .53437 Mdot
.3562 .42565 Mdot
.55375 .67853 Mdot
.6789 .54486 Mdot
.5462 .43392 Mdot
.68745 .52801 Mdot
.5318 .64772 Mdot
.38258 .64058 Mdot
.52109 .41384 Mdot
.68139 .50945 Mdot
.68674 .52848 Mdot
.54656 .36603 Mdot
.33329 .45009 Mdot
.61837 .35715 Mdot
.57796 .40871 Mdot
.50931 .37622 Mdot
.33263 .40534 Mdot
.80277 .70589 Mdot
.56394 .35331 Mdot
.75554 .46989 Mdot
.32123 .39915 Mdot
.57858 .52436 Mdot
.58736 .65576 Mdot
.59482 .36917 Mdot
.38138 .64091 Mdot
.39215 .63784 Mdot
.51786 .64656 Mdot
.28256 .42554 Mdot
.64018 .6155 Mdot
.28193 .40415 Mdot
.53414 .46441 Mdot
.59099 .41683 Mdot
.2904 .36398 Mdot
.83209 .52834 Mdot
.36193 .41322 Mdot
.49068 .67774 Mdot
.40007 .48441 Mdot
.40659 .63207 Mdot
.54256 .60908 Mdot
.28517 .44265 Mdot
.34487 .40605 Mdot
.32802 .45519 Mdot
.64547 .52918 Mdot
.7002 .61535 Mdot
.33742 .39573 Mdot
.35617 .39574 Mdot
.57395 .38338 Mdot
.50615 .39118 Mdot
.66682 .25942 Mdot
.62102 .25554 Mdot
.68022 .51714 Mdot
.52901 .63301 Mdot
.14615 .40568 Mdot
.36912 .64003 Mdot
.22749 .63896 Mdot
.52771 .3466 Mdot
.17128 .31943 Mdot
.52813 .3565 Mdot
.53262 .39562 Mdot
.30012 .45459 Mdot
.67764 .50923 Mdot
.67247 .53087 Mdot
.31011 .42011 Mdot
.36671 .4062 Mdot
.65868 .53317 Mdot
.39749 .7864 Mdot
.75555 .7091 Mdot
.61046 .65124 Mdot
.33447 .43129 Mdot
.43865 .36733 Mdot
.42053 .62062 Mdot
.57119 .47748 Mdot
.38636 .6472 Mdot
.55512 .65589 Mdot
.52573 .67785 Mdot
.35504 .61003 Mdot
.57187 .39041 Mdot
.52855 .6603 Mdot
.53407 .43898 Mdot
.3195 .71872 Mdot
.40974 .33232 Mdot
.67 .60284 Mdot
.48723 .46001 Mdot
.56552 .51335 Mdot
.448 .62306 Mdot
.55039 .42944 Mdot
.73743 .69161 Mdot
.68003 .52546 Mdot
.51249 .46336 Mdot
.35413 .61946 Mdot
.74005 .27365 Mdot
.52303 .41992 Mdot
.32078 .43482 Mdot
.38529 .63 Mdot
.26142 .46545 Mdot
.32237 .5355 Mdot
.5133 .40023 Mdot
.23923 .26813 Mdot
.32043 .47875 Mdot
.54403 .67278 Mdot
.246 .35573 Mdot
.35624 .40314 Mdot
.72163 .54476 Mdot
.75607 .5908 Mdot
.51969 .83515 Mdot
.36239 .4311 Mdot
.50989 .65031 Mdot
.3356 .4628 Mdot
.66783 .55726 Mdot
.31347 .46986 Mdot
.54405 .65878 Mdot
.56492 .41566 Mdot
.56849 .63542 Mdot
.64769 .52194 Mdot
.54891 .20577 Mdot
.39242 .64249 Mdot
.58733 .63037 Mdot
.36389 .60821 Mdot
.67599 .45649 Mdot
.77138 .53137 Mdot
.37986 .58968 Mdot
.34896 .28471 Mdot
.59465 .40559 Mdot
.35256 .3989 Mdot
.56837 .63093 Mdot
.70692 .68431 Mdot
.42125 .47951 Mdot
.34115 .41586 Mdot
.52355 .64361 Mdot
.3377 .51998 Mdot
.27615 .32743 Mdot
.58033 .43857 Mdot
.65852 .39818 Mdot
.33489 .42818 Mdot
.51356 .66835 Mdot
.55489 .18105 Mdot
.33704 .46362 Mdot
.57846 .63178 Mdot
.41532 .61095 Mdot
.39628 .61626 Mdot
.58795 .39592 Mdot
.42715 .64287 Mdot
.52304 .66196 Mdot
.38059 .55118 Mdot
.2878 .42692 Mdot
.2494 .44335 Mdot
.67573 .50504 Mdot
.5643 .64271 Mdot
.50168 .42459 Mdot
.378 .45114 Mdot
.43227 .69454 Mdot
.35103 .34189 Mdot
.32049 .22475 Mdot
.56367 .63137 Mdot
.35244 .41824 Mdot
.3217 .4374 Mdot
.59913 .4289 Mdot
.34422 .50958 Mdot
.64368 .61974 Mdot
.43866 .44082 Mdot
.43124 .43656 Mdot
.58236 .67398 Mdot
.58699 .70613 Mdot
.49522 .3577 Mdot
.56252 .38429 Mdot
.40948 .62957 Mdot
.56694 .41252 Mdot
.29279 .44427 Mdot
.59226 .37742 Mdot
.37206 .59601 Mdot
.55735 .66625 Mdot
.52403 .41719 Mdot
.69175 .53465 Mdot
.42255 .60943 Mdot
.33964 .61453 Mdot
.57012 .64524 Mdot
.32024 .40365 Mdot
.59824 .51808 Mdot
.54945 .62956 Mdot
.56591 .38078 Mdot
.49718 .58209 Mdot
.50078 .39741 Mdot
.62844 .34372 Mdot
.34416 .4629 Mdot
.55634 .67729 Mdot
.29371 .45261 Mdot
.36939 .60999 Mdot
.74808 .57848 Mdot
.55471 .40151 Mdot
.58158 .63614 Mdot
.4676 .67158 Mdot
.64253 .36681 Mdot
.34466 .38827 Mdot
.41528 .77158 Mdot
.37455 .42285 Mdot
.53296 .62707 Mdot
.21481 .64914 Mdot
.64801 .54476 Mdot
.52847 .61532 Mdot
.82536 .57971 Mdot
.57479 .65986 Mdot
.58689 .38538 Mdot
.5516 .35334 Mdot
.55008 .67803 Mdot
.6976 .54339 Mdot
.65707 .22452 Mdot
.59457 .62398 Mdot
.36008 .4241 Mdot
.32664 .73943 Mdot
.42269 .17009 Mdot
.40843 .58024 Mdot
.40908 .62818 Mdot
.61903 .40763 Mdot
.60299 .39406 Mdot
.35318 .6237 Mdot
.36096 .64345 Mdot
.64034 .53944 Mdot
.5637 .62323 Mdot
.374 .46043 Mdot
.34207 .59007 Mdot
.37381 .48321 Mdot
.71924 .62339 Mdot
.60178 .42205 Mdot
.20361 .53001 Mdot
.52157 .35176 Mdot
.74292 .51704 Mdot
.36987 .59551 Mdot
.49569 .40567 Mdot
.5681 .45029 Mdot
.36916 .63608 Mdot
.65556 .53773 Mdot
.45924 .61877 Mdot
.55138 .64206 Mdot
.81107 .67472 Mdot
.53673 .44523 Mdot
.58802 .37642 Mdot
.37017 .62911 Mdot
.63885 .67923 Mdot
.34912 .42602 Mdot
.37378 .43694 Mdot
.53991 .67674 Mdot
.4043 .49845 Mdot
.5936 .39131 Mdot
.55762 .42537 Mdot
.5441 .64404 Mdot
.55953 .61181 Mdot
.4561 .76547 Mdot
.55969 .36017 Mdot
.38009 .62239 Mdot
.62629 .55415 Mdot
.36551 .5963 Mdot
.49986 .40411 Mdot
.58536 .37273 Mdot
.56539 .34623 Mdot
.50073 .42104 Mdot
.36895 .64806 Mdot
.49903 .38422 Mdot
.47958 .41728 Mdot
.34859 .41651 Mdot
.5101 .39285 Mdot
.43272 .44034 Mdot
.56848 .40562 Mdot
.65793 .53644 Mdot
.43865 .21862 Mdot
.52285 .41929 Mdot
.59501 .37659 Mdot
.57796 .61124 Mdot
.54865 .41024 Mdot
.37396 .64252 Mdot
.33715 .43706 Mdot
.37656 .63019 Mdot
.39179 .63864 Mdot
.54191 .69038 Mdot
.65943 .56386 Mdot
.55291 .33635 Mdot
.65623 .52047 Mdot
.59285 .44698 Mdot
.54624 .43883 Mdot
.73824 .5942 Mdot
.17256 .40411 Mdot
.50884 .19503 Mdot
.55663 .40086 Mdot
.57498 .66593 Mdot
.58011 .66531 Mdot
.62111 .46216 Mdot
.57185 .44261 Mdot
.34987 .59594 Mdot
.40162 .63535 Mdot
.65992 .28624 Mdot
.76105 .37997 Mdot
.65728 .53658 Mdot
.49445 .55879 Mdot
.56705 .43882 Mdot
.4975 .41112 Mdot
.52684 .44418 Mdot
.55037 .68568 Mdot
.47665 .46369 Mdot
.53533 .61145 Mdot
.27126 .63096 Mdot
.35922 .61587 Mdot
.51639 .41037 Mdot
.21401 .57036 Mdot
.29877 .42199 Mdot
.33617 .43783 Mdot
.33868 .60503 Mdot
.51239 .68653 Mdot
.6386 .24042 Mdot
.55826 .85 Mdot
.29219 .46321 Mdot
.66326 .5099 Mdot
.55781 .43022 Mdot
.5648 .66401 Mdot
.30697 .44981 Mdot
.66206 .51078 Mdot
.51326 .42099 Mdot
.70201 .61501 Mdot
.56224 .39785 Mdot
.23337 .50515 Mdot
.34154 .45306 Mdot
.70506 .76306 Mdot
.28309 .42117 Mdot
.42227 .60629 Mdot
.35199 .60347 Mdot
.56714 .35935 Mdot
.26324 .3664 Mdot
.36599 .41124 Mdot
.47491 .6159 Mdot
.66174 .562 Mdot
.40807 .68791 Mdot
.65817 .55064 Mdot
.54167 .66809 Mdot
.64896 .5389 Mdot
.54183 .65833 Mdot
.6131 .23911 Mdot
.34425 .48444 Mdot
.6817 .53708 Mdot
.46158 .65701 Mdot
.60525 .39222 Mdot
.68321 .51787 Mdot
.485 .41695 Mdot
.6332 .36085 Mdot
.5445 .64116 Mdot
.66512 .56061 Mdot
.5079 .42232 Mdot
.81469 .42692 Mdot
.39641 .59397 Mdot
.35003 .59826 Mdot
.48709 .41961 Mdot
.57189 .68362 Mdot
.31577 .46555 Mdot
.66371 .77168 Mdot
.36291 .5763 Mdot
.5641 .35499 Mdot
.57958 .35552 Mdot
.37044 .41471 Mdot
.19854 .58129 Mdot
.57637 .36606 Mdot
.50957 .31951 Mdot
.55921 .35862 Mdot
.37716 .58476 Mdot
.3693 .43462 Mdot
.32743 .43826 Mdot
.52365 .64718 Mdot
.29846 .41505 Mdot
.63696 .44387 Mdot
.23349 .58378 Mdot
.55957 .31545 Mdot
.37208 .60593 Mdot
.26191 .60728 Mdot
.26928 .63294 Mdot
.82033 .55695 Mdot
.31317 .39158 Mdot
.50429 .36428 Mdot
.30215 .4068 Mdot
.66087 .54896 Mdot
.32368 .44616 Mdot
.28533 .43756 Mdot
.54333 .42321 Mdot
.51632 .39844 Mdot
.55168 .67021 Mdot
.35602 .50767 Mdot
.32144 .40108 Mdot
.52733 .35772 Mdot
.6044 .37555 Mdot
.52454 .43683 Mdot
.49141 .60404 Mdot
.36554 .41955 Mdot
.33431 .77681 Mdot
.70615 .35362 Mdot
.32174 .40144 Mdot
.6813 .20749 Mdot
.46114 .67622 Mdot
.56432 .70256 Mdot
.45065 .59634 Mdot
.55367 .35795 Mdot
.58431 .62999 Mdot
.51841 .40501 Mdot
.20474 .53071 Mdot
.54112 .41235 Mdot
.65664 .53329 Mdot
.53981 .44205 Mdot
.51874 .66518 Mdot
.55737 .63116 Mdot
.57511 .35912 Mdot
.52456 .41479 Mdot
.57266 .21006 Mdot
.26972 .43883 Mdot
.33992 .44055 Mdot
.63296 .613 Mdot
.68552 .54285 Mdot
.35423 .61457 Mdot
.54148 .39035 Mdot
.54442 .68946 Mdot
.56036 .63171 Mdot
.36321 .4116 Mdot
.53485 .63415 Mdot
.38481 .59793 Mdot
.55043 .4003 Mdot
.35032 .6177 Mdot
.64339 .53219 Mdot
.36814 .42929 Mdot
.51111 .39597 Mdot
.57413 .38381 Mdot
.34904 .44178 Mdot
.51589 .34376 Mdot
.69613 .54044 Mdot
.57737 .65478 Mdot
.36324 .43468 Mdot
.3899 .60858 Mdot
.5417 .666 Mdot
.50757 .37559 Mdot
.20541 .33058 Mdot
.58448 .39017 Mdot
.53942 .35888 Mdot
.84173 .55645 Mdot
.56008 .44181 Mdot
.56494 .63036 Mdot
.30177 .44733 Mdot
.46873 .428 Mdot
.72675 .40915 Mdot
.73623 .78447 Mdot
.53161 .61427 Mdot
.56392 .42759 Mdot
.81616 .50366 Mdot
.56738 .42267 Mdot
.36968 .369 Mdot
.59975 .6548 Mdot
.5244 .5166 Mdot
.48851 .40382 Mdot
.40408 .61398 Mdot
.55503 .6729 Mdot
.53829 .6556 Mdot
.30283 .72041 Mdot
.54811 .4249 Mdot
.45899 .5692 Mdot
.50628 .41265 Mdot
.39356 .60893 Mdot
.68167 .31241 Mdot
.55771 .6299 Mdot
.35956 .21212 Mdot
.55111 .36344 Mdot
.34761 .40532 Mdot
.55488 .60063 Mdot
.3675 .67601 Mdot
.51166 .37277 Mdot
.6694 .51785 Mdot
.33254 .5948 Mdot
.51226 .33183 Mdot
.37484 .60334 Mdot
.50776 .37983 Mdot
.45168 .39325 Mdot
.22771 .37005 Mdot
.33014 .45281 Mdot
.41546 .61804 Mdot
.51769 .5759 Mdot
.49866 .37969 Mdot
.36237 .43301 Mdot
.34462 .41745 Mdot
.64438 .52747 Mdot
.52206 .54229 Mdot
.29191 .51685 Mdot
.42355 .35543 Mdot
.31583 .72994 Mdot
.56028 .60299 Mdot
.53403 .75452 Mdot
.53107 .36598 Mdot
.62189 .56126 Mdot
.38 .64279 Mdot
.58479 .394 Mdot
.48665 .23126 Mdot
.30328 .42139 Mdot
.58102 .38713 Mdot
.66758 .53243 Mdot
.61653 .58283 Mdot
.62261 .54971 Mdot
.77159 .5805 Mdot
.55767 .66019 Mdot
.48334 .42428 Mdot
.45719 .38605 Mdot
.58724 .66067 Mdot
.59162 .35944 Mdot
.57932 .63712 Mdot
.42336 .80948 Mdot
.67932 .51355 Mdot
.36224 .41778 Mdot
.4414 .65897 Mdot
.56864 .34159 Mdot
.5999 .38858 Mdot
.64875 .55985 Mdot
.55952 .38084 Mdot
.21418 .3648 Mdot
.49681 .60177 Mdot
.53327 .66384 Mdot
.3283 .45465 Mdot
.58709 .35779 Mdot
.5407 .55639 Mdot
.57378 .41428 Mdot
.49973 .28173 Mdot
.59469 .3747 Mdot
.31793 .52588 Mdot
.33971 .45012 Mdot
.36935 .60301 Mdot
.49375 .39419 Mdot
.53654 .40672 Mdot
.75932 .42565 Mdot
.6086 .43122 Mdot
.49526 .39682 Mdot
.36476 .38893 Mdot
.31181 .45456 Mdot
.34003 .46113 Mdot
.51965 .63531 Mdot
.74445 .3387 Mdot
.37561 .6175 Mdot
.48292 .45052 Mdot
.35499 .58303 Mdot
.31499 .34423 Mdot
.66623 .5104 Mdot
.79721 .5469 Mdot
.53355 .38037 Mdot
.30726 .44167 Mdot
.6705 .74297 Mdot
.35964 .45941 Mdot
.47768 .55129 Mdot
.38933 .62679 Mdot
.31106 .41655 Mdot
.53268 .40015 Mdot
.41032 .47969 Mdot
.81047 .47555 Mdot
.37021 .61981 Mdot
.6045 .43059 Mdot
.51569 .63671 Mdot
.69301 .59463 Mdot
.25639 .29294 Mdot
.3944 .59242 Mdot
.43666 .61666 Mdot
.54944 .42636 Mdot
.29586 .42623 Mdot
.40062 .61004 Mdot
.37216 .58601 Mdot
.5325 .63638 Mdot
.51576 .39472 Mdot
.51659 .3893 Mdot
.53122 .62696 Mdot
.37476 .62989 Mdot
.49201 .43193 Mdot
.52386 .32259 Mdot
.80227 .35423 Mdot
.31179 .50766 Mdot
.81543 .67567 Mdot
.62165 .4673 Mdot
.43995 .23428 Mdot
.66326 .77637 Mdot
.33392 .40065 Mdot
.53503 .4321 Mdot
.55222 .32529 Mdot
.52253 .66115 Mdot
.5577 .4097 Mdot
.5889 .68398 Mdot
.39057 .63349 Mdot
.73519 .27304 Mdot
.27583 .57875 Mdot
.47474 .82665 Mdot
.55656 .41139 Mdot
.39147 .41197 Mdot
.6675 .54724 Mdot
.42478 .59709 Mdot
.36309 .44912 Mdot
.50661 .42997 Mdot
.56831 .2085 Mdot
.53118 .61312 Mdot
.32776 .40995 Mdot
.62637 .21452 Mdot
.53973 .50524 Mdot
.50104 .39934 Mdot
.52713 .62305 Mdot
.71093 .72203 Mdot
.26743 .45421 Mdot
.3782 .57695 Mdot
.65448 .53711 Mdot
.55817 .67461 Mdot
.40407 .63523 Mdot
.38539 .4431 Mdot
.32007 .41595 Mdot
.32426 .4691 Mdot
.49229 .20361 Mdot
.58874 .62734 Mdot
.6714 .54633 Mdot
.78174 .42783 Mdot
.76255 .40056 Mdot
.65944 .53085 Mdot
.52417 .67658 Mdot
.31034 .45325 Mdot
.30715 .42482 Mdot
.33735 .43649 Mdot
.44635 .18768 Mdot
.30551 .39982 Mdot
.249 .67498 Mdot
.51682 .43241 Mdot
.53445 .31455 Mdot
.56266 .42685 Mdot
.34747 .60352 Mdot
.35201 .44487 Mdot
.43487 .48247 Mdot
.57846 .45354 Mdot
.78738 .51851 Mdot
.58785 .39088 Mdot
.42313 .63429 Mdot
.57785 .37886 Mdot
.18616 .49481 Mdot
.30645 .40388 Mdot
.55711 .40419 Mdot
.4098 .64025 Mdot
.68594 .54763 Mdot
.34923 .38851 Mdot
.51277 .40213 Mdot
.46411 .78825 Mdot
.55125 .44328 Mdot
.47766 .82006 Mdot
.24417 .45659 Mdot
.66424 .50991 Mdot
.2141 .48081 Mdot
.51331 .62504 Mdot
.51292 .32084 Mdot
.5828 .46288 Mdot
.36616 .61325 Mdot
.42549 .6782 Mdot
.5633 .65101 Mdot
.48556 .47427 Mdot
.47891 .3665 Mdot
.64432 .52316 Mdot
.28215 .46542 Mdot
.35436 .62702 Mdot
.59649 .36479 Mdot
.5806 .44151 Mdot
.2866 .67815 Mdot
.47511 .39207 Mdot
.58852 .36342 Mdot
.63874 .554 Mdot
.24441 .65845 Mdot
.56986 .40125 Mdot
.48669 .55362 Mdot
.30736 .46864 Mdot
.54128 .4651 Mdot
.23729 .66123 Mdot
.54848 .35275 Mdot
.31944 .41009 Mdot
.55774 .3049 Mdot
.27265 .50536 Mdot
.66225 .56436 Mdot
.5955 .37608 Mdot
.17317 .55614 Mdot
.55817 .36813 Mdot
.37991 .61806 Mdot
.57628 .43926 Mdot
.54663 .65841 Mdot
.50955 .19003 Mdot
.52448 .65651 Mdot
.58812 .4089 Mdot
.33786 .43375 Mdot
.3654 .62508 Mdot
.39022 .20967 Mdot
.66984 .628 Mdot
.23379 .63878 Mdot
.57794 .83108 Mdot
.67134 .56167 Mdot
.70955 .54996 Mdot
.36146 .63615 Mdot
.55906 .40369 Mdot
.24619 .69662 Mdot
.61673 .41111 Mdot
.57767 .39305 Mdot
.53967 .41258 Mdot
.76679 .53077 Mdot
.39316 .63574 Mdot
.54706 .63563 Mdot
.58098 .36922 Mdot
.49736 .38888 Mdot
.33696 .40198 Mdot
.68866 .53731 Mdot
.5868 .65687 Mdot
.67742 .52734 Mdot
.55963 .67015 Mdot
.70427 .23554 Mdot
.53023 .45432 Mdot
.68132 .55185 Mdot
.33495 .59529 Mdot
.32528 .40486 Mdot
.23497 .57902 Mdot
.53861 .66151 Mdot
.51966 .64453 Mdot
.5839 .36389 Mdot
.31554 .4098 Mdot
.29763 .45397 Mdot
.66458 .55308 Mdot
.38105 .59204 Mdot
.52373 .41994 Mdot
.55706 .43906 Mdot
.5086 .3065 Mdot
.55798 .68986 Mdot
.22678 .50743 Mdot
.53161 .76587 Mdot
.55896 .40127 Mdot
.28792 .42873 Mdot
.53041 .41634 Mdot
.58134 .78938 Mdot
.29739 .42031 Mdot
.54162 .3528 Mdot
.63425 .18898 Mdot
.52529 .70217 Mdot
.26006 .52827 Mdot
.56708 .34969 Mdot
.64278 .80906 Mdot
.5319 .37139 Mdot
.75165 .27795 Mdot
.66456 .72112 Mdot
.59111 .41128 Mdot
.51439 .36627 Mdot
.3825 .33452 Mdot
.56083 .43321 Mdot
.52746 .63148 Mdot
.69564 .27232 Mdot
.33906 .4682 Mdot
.31512 .67453 Mdot
.45188 .21898 Mdot
.67368 .56405 Mdot
.54026 .67681 Mdot
.58758 .70272 Mdot
.66632 .52592 Mdot
.33136 .43147 Mdot
.5591 .39397 Mdot
.43079 .50868 Mdot
.57058 .6819 Mdot
.59592 .48458 Mdot
.38215 .61856 Mdot
.43753 .72325 Mdot
.58993 .57214 Mdot
.37851 .60103 Mdot
.51063 .38922 Mdot
.36806 .33263 Mdot
.57347 .24221 Mdot
.78157 .68315 Mdot
.40878 .63366 Mdot
.36868 .62055 Mdot
.47853 .18442 Mdot
.65551 .50634 Mdot
.3029 .6885 Mdot
.32206 .53053 Mdot
.35892 .62189 Mdot
.25747 .43302 Mdot
.54303 .61446 Mdot
.4003 .65475 Mdot
.48987 .44437 Mdot
.53453 .43638 Mdot
.53408 .40208 Mdot
.37252 .59116 Mdot
.643 .38699 Mdot
.243 .35134 Mdot
.36233 .60772 Mdot
.61716 .43381 Mdot
.5004 .51944 Mdot
.52917 .72867 Mdot
.54292 .62574 Mdot
.65491 .55989 Mdot
.69407 .50968 Mdot
.35152 .41074 Mdot
.65709 .56201 Mdot
.61732 .57733 Mdot
.55293 .3833 Mdot
.36028 .60117 Mdot
.42384 .69084 Mdot
.39225 .61424 Mdot
.66958 .52734 Mdot
.64048 .52169 Mdot
.34883 .41723 Mdot
.33425 .44379 Mdot
.41091 .26028 Mdot
.67588 .36967 Mdot
.58026 .40832 Mdot
.73425 .64644 Mdot
.28696 .44219 Mdot
.60076 .48531 Mdot
.65325 .55997 Mdot
.68682 .54377 Mdot
.7616 .44369 Mdot
.5317 .38464 Mdot
.302 .36619 Mdot
.53521 .38722 Mdot
.68182 .32513 Mdot
.53074 .34706 Mdot
.53303 .63552 Mdot
.5253 .38253 Mdot
.7697 .45577 Mdot
.55208 .33238 Mdot
.60303 .4019 Mdot
.54822 .68739 Mdot
.49911 .34109 Mdot
.54752 .65647 Mdot
.58514 .41014 Mdot
.6953 .51909 Mdot
.53379 .67546 Mdot
.72414 .42861 Mdot
.76268 .46532 Mdot
.52179 .67541 Mdot
.65323 .51904 Mdot
.69681 .55442 Mdot
.72949 .46738 Mdot
.36358 .44874 Mdot
.6012 .4578 Mdot
.55988 .40626 Mdot
.55055 .60887 Mdot
.40253 .63253 Mdot
.51373 .36365 Mdot
.6035 .37926 Mdot
.54617 .34672 Mdot
.35181 .41 Mdot
.64821 .61869 Mdot
.67519 .55562 Mdot
.5331 .6228 Mdot
.5978 .5224 Mdot
.57819 .67944 Mdot
.58785 .43385 Mdot
.54934 .32632 Mdot
.4703 .22493 Mdot
.50292 .71617 Mdot
.44468 .18164 Mdot
.32194 .41503 Mdot
.57971 .66766 Mdot
.68259 .50717 Mdot
.56747 .32799 Mdot
.3048 .44139 Mdot
.54445 .65832 Mdot
.56137 .39784 Mdot
.6122 .41662 Mdot
.25275 .6222 Mdot
.64366 .44213 Mdot
.74808 .45276 Mdot
.51731 .64869 Mdot
.51438 .6304 Mdot
.7705 .49392 Mdot
.68174 .57608 Mdot
.42383 .48039 Mdot
.55715 .42062 Mdot
.66933 .51861 Mdot
.30557 .44826 Mdot
.51185 .21217 Mdot
.35951 .59233 Mdot
.34905 .50852 Mdot
.55549 .41007 Mdot
.55251 .51873 Mdot
.34015 .43245 Mdot
.66484 .5333 Mdot
.36969 .59139 Mdot
.71234 .53818 Mdot
.56424 .68137 Mdot
.48972 .84619 Mdot
.5605 .37286 Mdot
.58913 .36881 Mdot
.42333 .62323 Mdot
.3 .42983 Mdot
.66582 .5677 Mdot
.33597 .74674 Mdot
.5335 .64971 Mdot
.23045 .67685 Mdot
.28935 .43047 Mdot
.43525 .38153 Mdot
.54379 .61937 Mdot
.3423 .59619 Mdot
.72014 .44908 Mdot
.37835 .59705 Mdot
.59051 .39905 Mdot
.31458 .44031 Mdot
.4131 .61874 Mdot
.31883 .50052 Mdot
.82317 .48602 Mdot
.43455 .37792 Mdot
.54984 .38765 Mdot
.7999 .38277 Mdot
.45873 .80458 Mdot
.27256 .44697 Mdot
.38883 .64197 Mdot
.58591 .39438 Mdot
.59902 .38257 Mdot
.56081 .36852 Mdot
.40519 .62607 Mdot
.73845 .62955 Mdot
.54182 .64244 Mdot
.55514 .42785 Mdot
.64028 .53769 Mdot
.55371 .65349 Mdot
.42838 .6658 Mdot
.54586 .62709 Mdot
.30012 .3957 Mdot
.59465 .4272 Mdot
.33852 .67194 Mdot
.65787 .17037 Mdot
.37385 .62594 Mdot
.53578 .6887 Mdot
.53087 .45215 Mdot
.45765 .70376 Mdot
.32811 .46036 Mdot
.53183 .64942 Mdot
.58831 .37799 Mdot
.45674 .6467 Mdot
.53515 .20265 Mdot
.55032 .62774 Mdot
.30338 .44158 Mdot
.78542 .67066 Mdot
.56314 .4121 Mdot
.54041 .37055 Mdot
.31379 .41979 Mdot
.31515 .30424 Mdot
.57317 .18854 Mdot
.52655 .41517 Mdot
.36848 .60208 Mdot
.38376 .82978 Mdot
.60481 .38226 Mdot
.70405 .33105 Mdot
.5526 .6723 Mdot
.37778 .65915 Mdot
.25186 .49384 Mdot
.57393 .33139 Mdot
.31718 .71282 Mdot
.44058 .61389 Mdot
.79489 .40802 Mdot
.58666 .68415 Mdot
.59966 .73222 Mdot
.76865 .34797 Mdot
.40789 .64328 Mdot
.40948 .44041 Mdot
.33178 .72599 Mdot
.32245 .26202 Mdot
.74608 .70224 Mdot
.62777 .7135 Mdot
.56852 .20696 Mdot
.44706 .50567 Mdot
.57049 .66636 Mdot
.58456 .50101 Mdot
.51653 .40533 Mdot
.46692 .80643 Mdot
.23039 .40544 Mdot
.2331 .38775 Mdot
.80219 .3854 Mdot
.39003 .37447 Mdot
.81384 .49594 Mdot
.82726 .55731 Mdot
.61168 .28696 Mdot
.55836 .74806 Mdot
.2321 .68397 Mdot
.68095 .24164 Mdot
.34179 .76897 Mdot
.54776 .31178 Mdot
.46769 .55347 Mdot
.53172 .8223 Mdot
.38602 .45367 Mdot
.26666 .33942 Mdot
.5254 .648 Mdot
.3509 .4614 Mdot
.3202 .70098 Mdot
.3747 .41959 Mdot
.2677 .50088 Mdot
.79719 .66269 Mdot
.82471 .49507 Mdot
.18454 .56304 Mdot
.6623 .78762 Mdot
.47378 .23443 Mdot
.15479 .61272 Mdot
.59446 .65561 Mdot
.35464 .4042 Mdot
.75106 .51748 Mdot
.7759 .44797 Mdot
.28532 .62701 Mdot
.37526 .76421 Mdot
.72017 .59704 Mdot
.67515 .43557 Mdot
.32269 .43501 Mdot
.2219 .4803 Mdot
.416 .6598 Mdot
.27466 .58765 Mdot
.67983 .25486 Mdot
.78722 .62787 Mdot
.42393 .51345 Mdot
.38679 .75652 Mdot
.4699 .73201 Mdot
.27675 .28102 Mdot
.71333 .37395 Mdot
.60147 .48957 Mdot
.30969 .51149 Mdot
.63861 .78523 Mdot
.33615 .26866 Mdot
.66907 .32001 Mdot
.77483 .43303 Mdot
.67731 .22258 Mdot
.54625 .79634 Mdot
.50041 .13883 Mdot
.37744 .44385 Mdot
.58133 .35602 Mdot
.34439 .2946 Mdot
.17589 .57728 Mdot
.63549 .52698 Mdot
.76739 .59888 Mdot
.65458 .55606 Mdot
.28461 .41086 Mdot
.54147 .19261 Mdot
.23741 .6562 Mdot
.17608 .60476 Mdot
.70452 .53148 Mdot
.47443 .44163 Mdot
.57721 .87879 Mdot
.79728 .47506 Mdot
.25999 .55623 Mdot
.78958 .33712 Mdot
.49919 .50259 Mdot
.25265 .45049 Mdot
.41208 .62257 Mdot
.76328 .3294 Mdot
.30935 .43035 Mdot
.5129 .12665 Mdot
.74589 .27011 Mdot
.51029 .22387 Mdot
.92607 .5058 Mdot
.76715 .51273 Mdot
.52946 .51696 Mdot
.37969 .55833 Mdot
.70409 .39942 Mdot
.25437 .32864 Mdot
.70657 .49941 Mdot
.46105 .71115 Mdot
.62143 .82917 Mdot
.79113 .38121 Mdot
.19274 .63351 Mdot
.43722 .82984 Mdot
.30856 .27958 Mdot
.53358 .55847 Mdot
.52965 .47353 Mdot
.59243 .58186 Mdot
.76534 .64225 Mdot
.68277 .21803 Mdot
.70915 .35507 Mdot
.72689 .79362 Mdot
.65551 .56891 Mdot
.70467 .63881 Mdot
.82425 .63156 Mdot
.68819 .44502 Mdot
.23656 .46959 Mdot
.71871 .32379 Mdot
.50442 .4746 Mdot
.60763 .52971 Mdot
.76967 .61588 Mdot
.23431 .53559 Mdot
.713 .28912 Mdot
.69889 .74367 Mdot
.284 .67507 Mdot
.42106 .33119 Mdot
.74813 .36936 Mdot
.3819 .41938 Mdot
.66688 .39669 Mdot
.25076 .48443 Mdot
.83209 .47404 Mdot
.41866 .64473 Mdot
.84787 .47598 Mdot
.5787 .19292 Mdot
.51392 .44963 Mdot
.62047 .40947 Mdot
.34992 .37661 Mdot
.67342 .39843 Mdot
.48895 .34791 Mdot
.26314 .63889 Mdot
.83577 .52016 Mdot
.55139 .25286 Mdot
.44962 .63422 Mdot
.42992 .6749 Mdot
.81979 .64528 Mdot
.3696 .29451 Mdot
.69053 .57546 Mdot
.66826 .27072 Mdot
.27142 .29426 Mdot
.56011 .6457 Mdot
.19835 .63556 Mdot
.34975 .57871 Mdot
.52764 .20831 Mdot
.42052 .35982 Mdot
.39755 .23214 Mdot
.8363 .52061 Mdot
.60811 .71371 Mdot
.56259 .19525 Mdot
.6848 .46582 Mdot
.2917 .74049 Mdot
.52389 .72567 Mdot
.51106 .33801 Mdot
.39777 .77077 Mdot
.69816 .54101 Mdot
.40591 .29511 Mdot
.35185 .79921 Mdot
.65549 .67654 Mdot
.48199 .38048 Mdot
.50969 .22043 Mdot
.53488 .71092 Mdot
.40558 .4843 Mdot
.37653 .1809 Mdot
.6063 .40717 Mdot
.77752 .41299 Mdot
.52555 .79443 Mdot
.69207 .37875 Mdot
.73622 .73367 Mdot
.60573 .78248 Mdot
.53969 .14134 Mdot
.78461 .34442 Mdot
.65836 .62926 Mdot
.76521 .35036 Mdot
.82203 .42371 Mdot
.5349 .1464 Mdot
.60817 .44293 Mdot
.42416 .60757 Mdot
.19559 .32733 Mdot
.54513 .62391 Mdot
.78665 .46366 Mdot
.3153 .72974 Mdot
.56774 .57614 Mdot
.37956 .39055 Mdot
.53376 .48822 Mdot
.4476 .51174 Mdot
.27178 .44 Mdot
.48574 .35239 Mdot
.44604 .16645 Mdot
.59294 .15854 Mdot
.48443 .14936 Mdot
.58894 .81414 Mdot
.74915 .3162 Mdot
.55217 .52813 Mdot
.189 .58234 Mdot
.61067 .46995 Mdot
.51308 .42624 Mdot
.71773 .55634 Mdot
.76539 .51737 Mdot
.48218 .21276 Mdot
.29496 .58339 Mdot
.30443 .47869 Mdot
.76802 .60773 Mdot
.27956 .80878 Mdot
.43326 .25512 Mdot
.26027 .69532 Mdot
.69135 .58393 Mdot
.67916 .37405 Mdot
.75349 .64718 Mdot
.43954 .21521 Mdot
.83593 .55892 Mdot
.27386 .44299 Mdot
.33703 .76019 Mdot
.65099 .7046 Mdot
.4079 .45771 Mdot
.65415 .6166 Mdot
.81432 .51949 Mdot
.32283 .67511 Mdot
.41087 .21127 Mdot
.32365 .54749 Mdot
.34482 .28389 Mdot
.48497 .62126 Mdot
.44593 .73276 Mdot
.32888 .77539 Mdot
.59311 .76892 Mdot
.69009 .32408 Mdot
.49152 .52141 Mdot
.20563 .4879 Mdot
.44293 .60451 Mdot
.6921 .3325 Mdot
.43594 .4451 Mdot
.7621 .36464 Mdot
.5494 .09188 Mdot
.37193 .19827 Mdot
.79205 .6897 Mdot
.73974 .64912 Mdot
.49064 .35922 Mdot
.83205 .58513 Mdot
.46166 .14297 Mdot
.69712 .20437 Mdot
.42394 .74327 Mdot
.58484 .68069 Mdot
.34957 .58826 Mdot
.48027 .16764 Mdot
.73581 .62578 Mdot
.81097 .60616 Mdot
.72933 .35871 Mdot
.338 .61403 Mdot
.16385 .41905 Mdot
.6775 .22725 Mdot
.43086 .36413 Mdot
.64476 .43716 Mdot
.4988 .36132 Mdot
.20859 .43767 Mdot
.37319 .42025 Mdot
.51718 .74922 Mdot
.67346 .35858 Mdot
.56436 .63936 Mdot
.74274 .53122 Mdot
.39022 .77281 Mdot
.53932 .44177 Mdot
.52256 .56969 Mdot
.3399 .38954 Mdot
.51247 .72432 Mdot
.25171 .59205 Mdot
.66114 .18887 Mdot
.68586 .5888 Mdot
.48897 .40872 Mdot
.69471 .37216 Mdot
.65179 .61129 Mdot
.5551 .18074 Mdot
.36093 .63721 Mdot
.80958 .41479 Mdot
.43781 .53305 Mdot
.66806 .38921 Mdot
.24334 .39606 Mdot
.6335 .37691 Mdot
.59777 .40059 Mdot
.637 .77086 Mdot
.50781 .26962 Mdot
.37465 .50528 Mdot
.48595 .44386 Mdot
.61488 .45785 Mdot
.82842 .59508 Mdot
.61519 .58107 Mdot
.44994 .72384 Mdot
.81851 .44217 Mdot
.40036 .62332 Mdot
.30076 .40841 Mdot
.63736 .4926 Mdot
.36505 .77636 Mdot
.54337 .27685 Mdot
.53336 .20235 Mdot
.57592 .56956 Mdot
.66602 .66478 Mdot
.82208 .45905 Mdot
.80617 .42125 Mdot
.18723 .45633 Mdot
.27168 .45054 Mdot
.63217 .31479 Mdot
.35692 .77757 Mdot
.31318 .45777 Mdot
.26358 .66446 Mdot
.25524 .64842 Mdot
.71544 .25387 Mdot
.50578 .58084 Mdot
.63206 .82352 Mdot
.74382 .44765 Mdot
.75811 .60066 Mdot
.38726 .2095 Mdot
.31392 .75851 Mdot
.80137 .5185 Mdot
.26187 .4276 Mdot
.38398 .34819 Mdot
.55253 .31464 Mdot
.19907 .54143 Mdot
.19172 .35262 Mdot
.63634 .49779 Mdot
.41648 .41881 Mdot
.70437 .74117 Mdot
.56361 .38658 Mdot
.33821 .21227 Mdot
.36883 .76846 Mdot
.46725 .1841 Mdot
.33704 .60104 Mdot
.50476 .39579 Mdot
.57313 .34195 Mdot
.69747 .29711 Mdot
.26747 .50654 Mdot
.75239 .35067 Mdot
.39744 .82983 Mdot
.73002 .70424 Mdot
.24571 .39261 Mdot
.78199 .45241 Mdot
.78836 .63237 Mdot
.47813 .80696 Mdot
.50751 .54111 Mdot
.74273 .55706 Mdot
.70028 .44406 Mdot
.64791 .79388 Mdot
.43397 .4529 Mdot
.42023 .56391 Mdot
.28551 .64762 Mdot
.54234 .77141 Mdot
.4594 .20085 Mdot
.51376 .37588 Mdot
.62681 .21485 Mdot
.81932 .5771 Mdot
.19863 .44109 Mdot
.23558 .3342 Mdot
.38155 .19155 Mdot
.47088 .29775 Mdot
.56725 .77606 Mdot
.44173 .79703 Mdot
.30309 .769 Mdot
.43421 .5349 Mdot
.78188 .53693 Mdot
.69341 .45622 Mdot
.82093 .45277 Mdot
.42509 .62036 Mdot
.31456 .53891 Mdot
.4332 .67534 Mdot
.76112 .35179 Mdot
.36844 .30716 Mdot
.82249 .53195 Mdot
.47968 .49746 Mdot
.5467 .1393 Mdot
.60993 .76586 Mdot
.45881 .50342 Mdot
.56444 .67907 Mdot
.61809 .70111 Mdot
.78682 .58356 Mdot
.62405 .75047 Mdot
.30072 .7409 Mdot
.54909 .7024 Mdot
.61471 .49447 Mdot
.41218 .3934 Mdot
.659 .4066 Mdot
.63326 .77451 Mdot
.69458 .37286 Mdot
.82857 .5093 Mdot
.70839 .29734 Mdot
.6223 .21438 Mdot
.77169 .51138 Mdot
.56227 .84051 Mdot
.25907 .55146 Mdot
.61675 .53518 Mdot
.37669 .76992 Mdot
.70491 .65514 Mdot
.26113 .41834 Mdot
.23997 .21943 Mdot
.4966 .84196 Mdot
.59298 .75954 Mdot
.68383 .21982 Mdot
.6033 .7901 Mdot
.50222 .71753 Mdot
.291 .30796 Mdot
.32987 .51472 Mdot
.61042 .22808 Mdot
.53978 .41153 Mdot
.43901 .16146 Mdot
.66578 .36769 Mdot
.63653 .17033 Mdot
.81003 .61731 Mdot
.38187 .38921 Mdot
.59387 .42682 Mdot
.53028 .62313 Mdot
.44958 .56471 Mdot
.64363 .29487 Mdot
.33854 .32261 Mdot
.2345 .446 Mdot
.4634 .64209 Mdot
.59231 .6467 Mdot
.64005 .60657 Mdot
.28949 .46042 Mdot
.7447 .61434 Mdot
.53977 .76782 Mdot
.51305 .61342 Mdot
.41229 .51572 Mdot
.68844 .34703 Mdot
.2443 .49182 Mdot
.43578 .35998 Mdot
.44561 .21256 Mdot
.33283 .67311 Mdot
.53343 .62925 Mdot
.43392 .34767 Mdot
.52854 .82673 Mdot
.70693 .728 Mdot
.67519 .21724 Mdot
.60216 .54075 Mdot
.34345 .34197 Mdot
.69389 .32173 Mdot
.24244 .34031 Mdot
.27376 .35527 Mdot
.49682 .7035 Mdot
.21079 .44434 Mdot
.2809 .33186 Mdot
.33645 .72182 Mdot
.7358 .27238 Mdot
.34044 .76671 Mdot
.35475 .77773 Mdot
.53665 .58716 Mdot
.52979 .29722 Mdot
.39685 .41035 Mdot
.73025 .43502 Mdot
.415 .48308 Mdot
.14697 .56963 Mdot
.51145 .46304 Mdot
.11433 .52397 Mdot
.38423 .58672 Mdot
.27852 .30008 Mdot
.70404 .45253 Mdot
.50278 .52464 Mdot
.47009 .48443 Mdot
.59611 .77276 Mdot
.31185 .52554 Mdot
.5325 .8011 Mdot
.2388 .37523 Mdot
.59518 .65746 Mdot
.41875 .8431 Mdot
.57294 .84301 Mdot
.40119 .34169 Mdot
.54436 .44791 Mdot
.52151 .84026 Mdot
.588 .67331 Mdot
.46955 .21057 Mdot
.74411 .72534 Mdot
.68638 .72651 Mdot
.4239 .4159 Mdot
.67603 .38082 Mdot
.78455 .53398 Mdot
.80957 .38823 Mdot
.18837 .39214 Mdot
.7668 .61994 Mdot
.42459 .61803 Mdot
.48855 .50664 Mdot
.80913 .55726 Mdot
.26605 .47211 Mdot
.4191 .65104 Mdot
.23932 .45838 Mdot
.13478 .59894 Mdot
.78897 .46315 Mdot
.75556 .3595 Mdot
.24421 .44888 Mdot
.28341 .42229 Mdot
.28993 .50702 Mdot
.23656 .47183 Mdot
.66472 .73972 Mdot
.49048 .82405 Mdot
.24212 .47821 Mdot
.23562 .71473 Mdot
.63383 .36102 Mdot
.58126 .71846 Mdot
.38512 .38837 Mdot
.59229 .27692 Mdot
.33903 .61984 Mdot
.65207 .24192 Mdot
.73869 .70473 Mdot
.40575 .58982 Mdot
.64907 .76937 Mdot
.39329 .76042 Mdot
.44975 .36201 Mdot
.52583 .28293 Mdot
.72419 .69953 Mdot
.36182 .32491 Mdot
.18799 .51519 Mdot
.53012 .21836 Mdot
.55098 .6967 Mdot
.76315 .68478 Mdot
.53549 .66348 Mdot
.58663 .48974 Mdot
.33811 .5064 Mdot
.7007 .49448 Mdot
.45717 .17907 Mdot
.68192 .56203 Mdot
.36976 .42158 Mdot
.19135 .36313 Mdot
.29434 .44279 Mdot
.46082 .16174 Mdot
.40483 .22821 Mdot
.21634 .42458 Mdot
.65647 .63663 Mdot
.64249 .67142 Mdot
.17424 .64985 Mdot
.4118 .66646 Mdot
.58652 .58247 Mdot
.21322 .5851 Mdot
.3596 .40699 Mdot
.70328 .58591 Mdot
.54075 .68499 Mdot
.4025 .53231 Mdot
.33583 .69841 Mdot
.62184 .33979 Mdot
.37959 .45492 Mdot
.4053 .52518 Mdot
.64089 .25735 Mdot
.73812 .29285 Mdot
.58162 .64071 Mdot
.12646 .50922 Mdot
.59643 .41674 Mdot
.41934 .3239 Mdot
.83977 .55354 Mdot
.16274 .42523 Mdot
.61273 .62317 Mdot
.58576 .84553 Mdot
.49878 .37062 Mdot
.74142 .66452 Mdot
.31632 .43114 Mdot
.34356 .76513 Mdot
.65328 .55075 Mdot
.69427 .38707 Mdot
.37102 .58263 Mdot
.40644 .21225 Mdot
.61607 .64435 Mdot
.31903 .46744 Mdot
.71434 .6894 Mdot
.60879 .28638 Mdot
.36929 .53913 Mdot
.63444 .63637 Mdot
.40407 .34575 Mdot
.537 .2817 Mdot
.34177 .48349 Mdot
.76626 .37912 Mdot
.36675 .79324 Mdot
.66833 .1893 Mdot
.35307 .38269 Mdot
.55115 .51023 Mdot
.27615 .65722 Mdot
.67341 .75089 Mdot
.21037 .5463 Mdot
.84119 .5327 Mdot
.66937 .33437 Mdot
.5715 .30056 Mdot
.68345 .33069 Mdot
.60786 .33926 Mdot
.47225 .53266 Mdot
.4805 .74081 Mdot
.22299 .39447 Mdot
.23263 .50666 Mdot
.31371 .28555 Mdot
.19634 .51586 Mdot
.75308 .3667 Mdot
.2197 .43035 Mdot
.50443 .66378 Mdot
.46918 .33264 Mdot
.39976 .57724 Mdot
.74656 .29598 Mdot
.84104 .53917 Mdot
.43281 .61186 Mdot
.69043 .59959 Mdot
.6887 .76762 Mdot
.61535 .38361 Mdot
.57844 .52917 Mdot
.59272 .37425 Mdot
.64054 .42681 Mdot
.15072 .45523 Mdot
.67143 .74185 Mdot
.4802 .40672 Mdot
.79247 .39272 Mdot
.77839 .36005 Mdot
.58493 .14692 Mdot
.25351 .70769 Mdot
.35371 .42054 Mdot
.53545 .15409 Mdot
.23194 .44635 Mdot
.81762 .4022 Mdot
.53556 .73449 Mdot
.8574 .55584 Mdot
.3832 .3441 Mdot
.66878 .76701 Mdot
.27931 .32021 Mdot
.32479 .52216 Mdot
.53257 .78742 Mdot
.55642 .53649 Mdot
.43075 .70856 Mdot
.57958 .79538 Mdot
.37087 .8359 Mdot
.54833 .32015 Mdot
.43592 .78303 Mdot
.30321 .64471 Mdot
.77229 .6748 Mdot
.62361 .73831 Mdot
.56675 .44239 Mdot
.4193 .68478 Mdot
.44648 .19159 Mdot
.69537 .34888 Mdot
.59737 .49956 Mdot
.61619 .74009 Mdot
.57956 .22896 Mdot
.6764 .31233 Mdot
.34609 .77455 Mdot
.39704 .34792 Mdot
.45012 .55476 Mdot
.49973 .37698 Mdot
.3601 .47146 Mdot
.6925 .56351 Mdot
.55352 .54281 Mdot
.58366 .40975 Mdot
.53024 .60944 Mdot
.3659 .53654 Mdot
.4233 .1777 Mdot
.23997 .53523 Mdot
.41192 .79468 Mdot
.38912 .42547 Mdot
.30713 .62511 Mdot
.21696 .56663 Mdot
.35032 .21848 Mdot
.67192 .7018 Mdot
.70929 .35562 Mdot
.80195 .46982 Mdot
.71765 .30014 Mdot
.38736 .46494 Mdot
.62421 .18362 Mdot
.38245 .64283 Mdot
.44357 .37555 Mdot
.30754 .59158 Mdot
.63397 .59337 Mdot
.47921 .42563 Mdot
.66837 .76644 Mdot
.58715 .57631 Mdot
.77344 .45438 Mdot
.54626 .79892 Mdot
.63706 .33721 Mdot
.4083 .37787 Mdot
.80384 .40748 Mdot
.53282 .6139 Mdot
.40021 .80415 Mdot
.37107 .5482 Mdot
.6229 .72814 Mdot
.7341 .30607 Mdot
.6938 .22823 Mdot
.44932 .486 Mdot
.69565 .42972 Mdot
.54377 .36571 Mdot
.33317 .77545 Mdot
.66554 .74942 Mdot
.47861 .45707 Mdot
.41758 .73205 Mdot
.2968 .41412 Mdot
.45872 .75416 Mdot
.464 .55576 Mdot
.60361 .23278 Mdot
.35522 .39367 Mdot
.21023 .42919 Mdot
.69986 .52809 Mdot
.52275 .50654 Mdot
.46326 .39513 Mdot
.70191 .41664 Mdot
.19305 .644 Mdot
.47647 .43494 Mdot
.77058 .6246 Mdot
.41841 .35264 Mdot
.33666 .74895 Mdot
.72193 .69741 Mdot
.48066 .68958 Mdot
.31189 .52338 Mdot
.49107 .30926 Mdot
.3342 .68197 Mdot
.55811 .34844 Mdot
.51835 .69224 Mdot
.32669 .46612 Mdot
.76207 .69358 Mdot
.48858 .28706 Mdot
.72262 .43004 Mdot
.49137 .6039 Mdot
.60608 .48804 Mdot
.37275 .56201 Mdot
.85302 .55372 Mdot
.31157 .51804 Mdot
.67332 .34764 Mdot
.50692 .57992 Mdot
.70617 .4483 Mdot
.38592 .24216 Mdot
.73962 .26021 Mdot
.28046 .31612 Mdot
.41856 .50395 Mdot
.2715 .30944 Mdot
.58073 .76801 Mdot
.72764 .74422 Mdot
.67323 .32309 Mdot
.49348 .49194 Mdot
.63547 .55531 Mdot
.24595 .61626 Mdot
.4788 .61644 Mdot
.60214 .50571 Mdot
.4095 .5364 Mdot
.37694 .71944 Mdot
.33703 .64531 Mdot
.46798 .44039 Mdot
.77922 .50002 Mdot
.80266 .44479 Mdot
.32295 .7373 Mdot
.44167 .60053 Mdot
.57697 .73294 Mdot
.60943 .24342 Mdot
.86327 .56468 Mdot
.22079 .31798 Mdot
.5466 .36591 Mdot
.40788 .57422 Mdot
.68459 .4234 Mdot
.5178 .66008 Mdot
.23132 .4883 Mdot
.22332 .56488 Mdot
.41154 .60314 Mdot
.62125 .49534 Mdot
.7679 .42081 Mdot
.5545 .76667 Mdot
.65568 .42906 Mdot
.43603 .66362 Mdot
.40484 .18162 Mdot
.56296 .82339 Mdot
.67685 .74656 Mdot
.88054 .49605 Mdot
.39782 .55453 Mdot
.61578 .44672 Mdot
.38154 .27336 Mdot
.74053 .30367 Mdot
.7013 .37472 Mdot
.5096 .2066 Mdot
.46005 .68159 Mdot
.6695 .32344 Mdot
.26382 .40502 Mdot
.78007 .47734 Mdot
.45077 .75228 Mdot
.46927 .52049 Mdot
.64376 .67657 Mdot
.63862 .18324 Mdot
.39521 .38434 Mdot
.80847 .48173 Mdot
.41332 .19787 Mdot
.28721 .76065 Mdot
.75584 .31346 Mdot
.76122 .46663 Mdot
.65508 .72268 Mdot
.34885 .29386 Mdot
.43257 .44219 Mdot
.25754 .4392 Mdot
.47579 .21073 Mdot
.54654 .26918 Mdot
.69979 .61633 Mdot
.33486 .25913 Mdot
.69044 .32458 Mdot
.56526 .26121 Mdot
.48835 .48914 Mdot
.44146 .34841 Mdot
.68225 .60135 Mdot
.25063 .46116 Mdot
.42119 .45215 Mdot
.72873 .40539 Mdot
.42676 .34853 Mdot
.28806 .67156 Mdot
.59868 .78527 Mdot
.27348 .76177 Mdot
.72562 .65268 Mdot
.33936 .23013 Mdot
.51836 .43408 Mdot
.59361 .13406 Mdot
.5501 .78232 Mdot
.58241 .74825 Mdot
.50823 .81451 Mdot
.53625 .71508 Mdot
.62851 .40844 Mdot
.55739 .34828 Mdot
.78235 .58575 Mdot
.41964 .41176 Mdot
.47507 .22976 Mdot
.38704 .21669 Mdot
.68499 .38186 Mdot
.72878 .363 Mdot
.73623 .44156 Mdot
.54557 .30446 Mdot
.29352 .43436 Mdot
.49385 .14861 Mdot
.42983 .48934 Mdot
.48867 .46367 Mdot
.46734 .36067 Mdot
.34102 .28597 Mdot
.64396 .82697 Mdot
.36175 .38246 Mdot
.72865 .33433 Mdot
.3872 .36626 Mdot
.39445 .46685 Mdot
.20618 .52579 Mdot
.90128 .41678 Mdot
.63861 .14377 Mdot
.33284 .46902 Mdot
.247 .68107 Mdot
.3888 .37086 Mdot
.75898 .35548 Mdot
.65718 .70117 Mdot
.38751 .73155 Mdot
.4488 .42445 Mdot
.37579 .49272 Mdot
.46874 .38227 Mdot
.51333 .80099 Mdot
.7538 .29368 Mdot
.36077 .23113 Mdot
.79383 .39583 Mdot
.61599 .34453 Mdot
.46722 .40314 Mdot
.8856 .54506 Mdot
.81186 .54665 Mdot
.60117 .42572 Mdot
.25917 .33993 Mdot
.5211 .46993 Mdot
.52039 .40475 Mdot
.75124 .58192 Mdot
.41868 .84204 Mdot
.6917 .31909 Mdot
.76103 .35225 Mdot
.36862 .4083 Mdot
.56613 .7129 Mdot
.38323 .58589 Mdot
.45524 .48403 Mdot
.59291 .44241 Mdot
.41091 .61836 Mdot
.64966 .34466 Mdot
.69561 .75413 Mdot
.47046 .60132 Mdot
.40737 .82441 Mdot
.85584 .48275 Mdot
.47405 .30126 Mdot
.24489 .60786 Mdot
.60606 .36693 Mdot
.5835 .27231 Mdot
.62082 .26572 Mdot
.63067 .44619 Mdot
.62678 .79144 Mdot
.34619 .14809 Mdot
.40494 .69826 Mdot
.63007 .23511 Mdot
.27879 .42969 Mdot
.42902 .54661 Mdot
.42309 .38742 Mdot
.54214 .72613 Mdot
.58451 .65477 Mdot
.60664 .33146 Mdot
.3561 .38922 Mdot
.33679 .58993 Mdot
.12356 .47522 Mdot
.53605 .44848 Mdot
.21992 .50785 Mdot
.81806 .40947 Mdot
.52922 .21782 Mdot
.39687 .31526 Mdot
.53688 .34269 Mdot
.27354 .59682 Mdot
.49796 .49437 Mdot
.76429 .66244 Mdot
.63089 .22077 Mdot
.79461 .43114 Mdot
.49435 .28378 Mdot
.40414 .37626 Mdot
.49761 .38663 Mdot
.64645 .51101 Mdot
.3809 .65866 Mdot
.76699 .5871 Mdot
.5589 .46806 Mdot
.79785 .35834 Mdot
.61443 .68038 Mdot
.57236 .5519 Mdot
.31777 .37577 Mdot
.57524 .14793 Mdot
.35505 .26405 Mdot
.40239 .42867 Mdot
.36337 .2084 Mdot
.62683 .60951 Mdot
.65872 .41306 Mdot
.53197 .61911 Mdot
.59641 .45398 Mdot
.37748 .40904 Mdot
.35252 .19974 Mdot
.75963 .56705 Mdot
.43303 .7018 Mdot
.44201 .73055 Mdot
.28435 .70894 Mdot
.36523 .5417 Mdot
.87588 .47576 Mdot
.6317 .64999 Mdot
.37116 .19369 Mdot
.37503 .79667 Mdot
.38177 .40989 Mdot
.61286 .77845 Mdot
.50895 .45972 Mdot
.57354 .63633 Mdot
.79124 .40379 Mdot
.56287 .48687 Mdot
.54503 .19564 Mdot
.518 .34207 Mdot
.49888 .18204 Mdot
.62568 .54071 Mdot
.70683 .59041 Mdot
.58373 .76109 Mdot
.34558 .28023 Mdot
.81281 .6394 Mdot
.2472 .62134 Mdot
.83506 .59515 Mdot
.79909 .6582 Mdot
.80836 .40703 Mdot
.50726 .19713 Mdot
.17831 .41855 Mdot
.59408 .7529 Mdot
.71582 .70927 Mdot
.5058 .75065 Mdot
.32334 .30093 Mdot
.61545 .70787 Mdot
.32235 .3726 Mdot
.26818 .50933 Mdot
.42477 .59463 Mdot
.11798 .38255 Mdot
.74573 .39322 Mdot
.36923 .39094 Mdot
.62717 .68065 Mdot
.79045 .36838 Mdot
.35204 .28609 Mdot
.57099 .79903 Mdot
.46655 .55158 Mdot
.51646 .3348 Mdot
.52694 .2768 Mdot
.30964 .73228 Mdot
.62039 .67133 Mdot
.20388 .7042 Mdot
.53972 .8224 Mdot
.40869 .71695 Mdot
.46001 .53089 Mdot
.35359 .46093 Mdot
.19294 .54314 Mdot
.64951 .66098 Mdot
.61354 .79748 Mdot
.67965 .76261 Mdot
.8103 .55435 Mdot
.17383 .6471 Mdot
.34433 .76074 Mdot
.73889 .29716 Mdot
.63025 .76531 Mdot
.31502 .4683 Mdot
.75615 .47818 Mdot
.57191 .68725 Mdot
.45861 .71436 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo08Sooooo0_l0002oooooo`00
7?ooool00ol0003oooooooooo`28ooooo`;o0000_oooool001cooooo00?o0000ooooooooool0[ooo
ool2o`0009Sooooo000Looooo`03o`000?oooooooooo0:oooooo0_l0002Hooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0Xoooool2o`000:Cooooo000Looooo`03o`000?oooooooooo08[o
oooo0_l0000Gooooo`;o0000Y?ooool001cooooo00?o0000ooooooooool0R_ooool2o`0000_ooooo
0_l0000;ooooo`;o00005oooool2o`0008[ooooo000Looooo`03o`000?oooooooooo09Oooooo0_l0
000;ooooo`;o00005oooool2o`0008[ooooo000Looooo`03o`000?oooooooooo09oooooo0_l0000;
ooooo`Co0000VOooool001cooooo00?o0000ooooooooool0T_ooool2o`0000_ooooo0_l0000;oooo
o`Co00007?ooool2o`0007_ooooo000Looooo`03o`000?oooooooooo09;ooooo0_l0000Fooooo`;o
00001oooool2o`0000Gooooo0_l0000@ooooo`;o0000Noooool001cooooo00?o0000ooooooooool0
KOooool2o`0002_ooooo0_l000000ooooooo0000o`00000;ooooo`;o00001oooool2o`0000;ooooo
0_l000000ooooooo0000o`00002=ooooo`007?ooool2o`0006kooooo0_l0000[ooooo`;o000000?o
ooooo`000?l000006?ooool2o`00093ooooo000Looooo`03o`000?oooooooooo0:[ooooo0_l0002M
ooooo`007?ooool00ol0003oooooooooo`1jooooo`;o0000;_ooool2o`00017ooooo0_l00007oooo
o`;o0000POooool001cooooo00?o0000ooooooooool0N_ooool2o`0000oooooo0_l00005ooooo`;o
00009?ooool2o`0000?ooooo0_l00007ooooo`;o0000POooool001cooooo00?o0000ooooooooool0
Roooool2o`0000Gooooo0_l0000Booooo`;o00004?ooool2o`0000cooooo0_l00021ooooo`007?oo
ool00ol0003oooooooooo`2=ooooo`;o00002Oooool2o`0000cooooo0ol0000Mooooo`;o0000POoo
ool001cooooo00?o0000ooooooooool0Q_ooool2o`0000Gooooo0_l00009ooooo`;o00003Oooool2
o`0002;ooooo0_l00005ooooo`;o0000MOooool001cooooo00?o0000ooooooooool0Q_ooool2o`00
023ooooo0_l000000ooooooo0000o`00000Nooooo`Co00000oooool2o`0007Gooooo000Looooo`03
o`000?oooooooooo08Kooooo0_l0000Pooooo`;o000000?oooooo`000?l000008?ooool2o`0007[o
oooo000Looooo`03o`000?oooooooooo07Oooooo0_l0000=ooooo`;o00002Oooool2o`0000kooooo
0_l00008ooooo`;o00000oooool3o`0000?ooooo0_l00004ooooo`;o0000Roooool001cooooo00?o
0000ooooooooool0Moooool2o`0000Cooooo0_l000000ooooooo0000o`00000;ooooo`;o00000_oo
ool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o000000?oooooo`000?l000003Ooo
ool3o`0000?ooooo0_l00004ooooo`;o00002Oooool2o`0000?ooooo0_l0001kooooo`007?ooool0
0ol0003oooooooooo`1mooooo`;o000000?oooooo`000?l000002Oooool4o`0000Gooooo0_l00002
ooooo`;o00001?ooool2o`0000Gooooo0_l00007ooooo`;o00001?ooool2o`00017ooooo0_l00003
ooooo`;o000000?oooooo`000?l00000N?ooool001cooooo00?o0000ooooooooool0R_ooool5o`00
01?ooooo0_l000000ooooooo0000o`000007ooooo`;o00001?ooool4o`0001;ooooo0_l00003oooo
o`;o00000_ooool4o`0007;ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44
ooooo`Go00001_ooool00ol0003oooooooooo`1eooooo`;o000000?oooooo`000?l000002Oooool2
o`0000Gooooo0_l000000ooooooo0000o`000007ooooo`;o00002_ooool3o`0000Oooooo0_l00008
ooooo`Co00003?ooool2o`0000;ooooo0_l00007ooooo`Co0000L_ooool00006oooooomgMgOoV9RH
oooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`00
0?oooooooooo06Cooooo1?l0000=ooooo`;o000000?oooooo`000?l000001?ooool2o`0000?ooooo
0_l00004ooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`000005ooooo`Co0000
00Coooooo`000?l0003o00001oooool3o`0000Cooooo0_l00003ooooo`Co00002_ooool2o`0000So
oooo0_l00003ooooo`;o0000L_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool0
2_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo06Cooooo1?l00007ooooo`;o0000
1?ooool2o`0000Kooooo0ol00003ooooo`;o00001?ooool2o`0000Sooooo0_l00008ooooo`Oo0000
00?oooooo`000?l000001_ooool2o`0000Cooooo0_l00005ooooo`;o00005?ooool2o`0000?ooooo
0_l00005ooooo`;o0000Joooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02ooo
ool00onHV9So8B4Qonk^kP06ooooo`?o0000Koooool2o`0000Cooooo0_l00002ooooo`;o00000_oo
ool2o`0000Cooooo1?l00009ooooo`?o00003_ooool2o`0000;ooooo0_l00002ooooo`?o000000Co
ooooo`000?l0003o00002Oooool2o`0000;ooooo0_l00003ooooo`;o00003Oooool2o`0000Wooooo
0_l0001[ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomV
IVKooooo00Gooooo00?o0000ooooooooool0NOooool2o`0000[ooooo0_l00009ooooo`?o00000_oo
ool2o`0000Gooooo0_l0000;ooooo`?o000000?oooooo`000?l000000_l00008ooooo`;o00000_oo
ool4o`000003ooooool0003o000000;o00002oooool2o`0000cooooo0_l0001Xooooo`0000?ooooo
oa0@4?ooool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0L_ooool2o`0001_ooooo0ol00003ooooo`;o00001Oooool2o`0000Cooooo0_l00004
ooooo`;o00001Oooool4o`0000;ooooo0_l00008ooooo`;o00000oooool2o`0001Cooooo0_l00003
ooooo`;o0000J?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooo
oonHV9So410@00Kooooo00?o0000ooooooooool0J_ooool2o`0000Gooooo0ol00006ooooo`?o0000
0oooool4o`0000_ooooo0_l00004ooooo`Co00002Oooool3o`0000?ooooo0_l00007ooooo`;o0000
0_ooool3o`0000Wooooo0_l00004ooooo`;o00004Oooool2o`0006gooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo
06[ooooo0_l00005ooooo`?o00001_ooool3o`0000?ooooo1?l00007ooooo`Co00001_ooool7o`00
00;ooooo0_l00003ooooo`;o00004Oooool2o`0000Wooooo0_l00003ooooo`Co0000Ooooool001co
oooo00?o0000ooooooooool0K_ooool2o`0000;ooooo0_l00006ooooo`;o00003oooool4o`0000So
oooo1Ol00002ooooo`;o00001_ooool4o`0001Cooooo0_l00006ooooo`Co00003_ooool4o`0006go
oooo000Looooo`03o`000?oooooooooo04[ooooo0_l0000Rooooo`;o00001_ooool2o`0000;ooooo
0_l0000=ooooo`Co00000_ooool2o`0000cooooo0_l00003ooooo`;o00000_ooool4o`0001Cooooo
0_l00006ooooo`Go00002oooool6o`0006gooooo000Looooo`03o`000?oooooooooo04[ooooo0_l0
000Zooooo`;o00001_ooool2o`0000Wooooo1?l00002ooooo`;o00002Oooool2o`000003ooooool0
003o000000?ooooo0_l00008ooooo`;o00004Oooool2o`0000Gooooo1Ol00007ooooo`;o00000_oo
ool6o`0006gooooo000Looooo`03o`000?oooooooooo06Cooooo0ol0000Gooooo`;o00005Oooool2
o`0000?ooooo1?l00004ooooo`;o00002?ooool3o`0000Oooooo0_l00007ooooo`;o00003Oooool2
o`0000;ooooo0_l00004ooooo`;o0000Koooool001cooooo00?o0000ooooooooool0I?ooool3o`00
00Cooooo0_l0000@ooooo`;o000000?oooooo`000?l000002?ooool4o`0000Oooooo1?l00003oooo
o`;o00002?ooool2o`0000Gooooo0_l00007ooooo`Co00002Oooool2o`0000Wooooo0_l00005oooo
o`;o000000?oooooo`000?l000001?ooool2o`0006Wooooo000Looooo`03o`000?oooooooooo05Ko
oooo0_l0000=ooooo`;o00001?ooool2o`0000Cooooo0_l0000:ooooo`;o000000?oooooo`000?l0
00002?ooool6o`0000Oooooo0_l000000ooooooo0000o`000007ooooo`;o000000?oooooo`000?l0
00003oooool3o`0000Kooooo0_l000000ooooooo0000o`000003ooooo`;o00001?ooool3o`0000?o
oooo0ol00007ooooo`;o0000JOooool001cooooo00?o0000ooooooooool0E_ooool2o`0000gooooo
0_l00005ooooo`;o00000oooool2o`0000[ooooo0_l0000<ooooo`;o000000?oooooo`000?l00000
1_ooool2o`0000;ooooo0_l00007ooooo`;o00004_ooool2o`0000Oooooo0_l00006ooooo`?o0000
1?ooool2o`0000?ooooo1_l000000ooooooo0000o`000004ooooo`;o0000I_ooool001cooooo00?o
0000ooooooooool0K?ooool2o`0001Kooooo0_l00005ooooo`;o00002Oooool2o`00017ooooo0_l0
0008ooooo`;o00003_ooool2o`0000Cooooo0_l00004ooooo`;o00001Oooool7o`0000Cooooo0_l0
001Vooooo`007?ooool00ol0003oooooooooo`1Zooooo`;o00003_ooool2o`0000Sooooo0_l0000Q
ooooo`Co00002?ooool2o`0000;ooooo0_l0000:ooooo`;o00001?ooool2o`000003ooooool0003o
000000;ooooo1_l00003ooooo`;o0000K_ooool001cooooo00?o0000ooooooooool0J_ooool4o`00
00cooooo0_l0000[ooooo`;o00003_ooool2o`0000;ooooo0_l00005ooooo`;o00001Oooool2o`00
0003ooooool0003o000000;ooooo1_l00003ooooo`;o00004?ooool2o`0005cooooo000Looooo`03
o`000?oooooooooo06cooooo0_l0000looooo`Co00002?ooool2o`0000?ooooo0_l00005ooooo`?o
00009_ooool2o`0005cooooo000Looooo`;o0000DOooool2o`0002_ooooo0_l00002ooooo`;o0000
9oooool6o`0000Kooooo0_l0000;ooooo`;o000000?oooooo`000?l00000POooool001cooooo00?o
0000ooooooooool0D?ooool2o`0002;ooooo0_l00007ooooo`;o00000_ooool2o`0000Kooooo0_l0
000Rooooo`Co00004_ooool2o`000003ooooool0003o0000017ooooo0_l00002ooooo`;o00001_oo
ool2o`0006;ooooo000Looooo`03o`000?oooooooooo06Kooooo0_l0000<ooooo`;o00004oooool2
o`0002Cooooo0_l0000:ooooo`;o00002Oooool2o`0000Cooooo0_l0000;ooooo`;o00000_ooool2
o`0000Gooooo1Ol00004ooooo`;o0000F_ooool001cooooo00?o0000ooooooooool0I_ooool2o`00
0003ooooool0003o0000017ooooo0_l00004ooooo`;o0000<?ooool2o`0000Gooooo0_l000000ooo
oooo0000o`000006ooooo`;o00001?ooool2o`0000Oooooo0_l0000=ooooo`;o000000?oooooo`00
0?l000000oooool3o`0005[ooooo000Looooo`03o`000?oooooooooo06Cooooo0ol00002ooooo`;o
00001?ooool3o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o00001?ooool2o`00033o
oooo0_l00008ooooo`;o00003?ooool2o`0000Oooooo0_l00006ooooo`;o00001?ooool2o`0000Oo
oooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`1Tooooo`?o00002?ooool3o`0000?ooooo
0_l000000ooooooo0000o`000002ooooo`;o00002Oooool2o`0003gooooo0_l00004ooooo`;o0000
2_ooool2o`0000?ooooo0_l00004ooooo`;o0000I?ooool001cooooo00?o0000ooooooooool0?Ooo
ool2o`0000_ooooo0_l0000Mooooo`;o00001?ooool2o`000003ooooool0003o0000017ooooo1?l0
000Hooooo`;o00002oooool2o`0000[ooooo0_l0000:ooooo`;o00003Oooool2o`000003ooooool0
003o000000Cooooo0_l0000>ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0?Oooool2
o`0000Sooooo0_l000000ooooooo0000o`00000Mooooo`;o00001?ooool2o`000003ooooool0003o
000000Cooooo0_l0000;ooooo`;o00006_ooool2o`0000[ooooo0ol0000:ooooo`;o00006Oooool2
o`0000Oooooo0_l00004ooooo`;o00001Oooool7o`0005Oooooo000Looooo`03o`000?oooooooooo
04Oooooo0_l0000Yooooo`;o00001?ooool2o`0002gooooo0_l00004ooooo`;o00002oooool2o`00
0003ooooool0003o000000oooooo0_l000000ooooooo0000o`00000;ooooo`;o00001?ooool2o`00
00Gooooo1?l000000ooooooo0000o`00001Gooooo`007?ooool00ol0003oooooooooo`1Qooooo`;o
00000oooool2o`0000[ooooo0_l0000Zooooo`;o00001oooool4o`0000;ooooo0_l0000>ooooo`;o
00003oooool2o`000004ooooool0003o0000o`0000cooooo0_l00002ooooo`;o00002_ooool2o`00
05Oooooo000Looooo`03o`000?oooooooooo05Kooooo0_l00009ooooo`;o00000oooool2o`0000Go
oooo0_l0000_ooooo`?o00001_ooool6o`0000Kooooo0_l0000Iooooo`;o00000_ooool4o`0000[o
oooo0ol0000=ooooo`;o0000Eoooool001cooooo00?o0000ooooooooool0E_ooool2o`0000[ooooo
0_l00002ooooo`;o00000oooool6o`000003ooooool0003o000000gooooo1?l000000ooooooo0000
o`00000Eooooo`Co00001_ooool2o`0000;ooooo0_l00006ooooo`;o00007_ooool4o`0000[ooooo
0_l0001Vooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o00000oooool2o`0000;ooooo0ol0
0002ooooo`Wo00003Oooool4o`000003ooooool0003o000001?ooooo1?l0000Sooooo`?o00001?oo
ool2o`0000Sooooo1?l0000=ooooo`;o0000Hoooool001cooooo00?o0000ooooooooool0GOooool2
o`0000?ooooo1?l000000ooooooo0000o`000007ooooo`?o00008Oooool2o`0000Gooooo0_l0000U
ooooo`?o00001?ooool2o`0000[ooooo0_l0000=ooooo`;o0000Hoooool001cooooo00?o0000oooo
ooooool0D?ooool2o`0000;ooooo0_l0000<ooooo`Co00000oooool2o`000003ooooool0003o0000
00Co00000_ooool2o`0000[ooooo1?l0000@ooooo`;o00001oooool2o`0002kooooo0_l00006oooo
o`;o00002oooool2o`0000Sooooo0_l00003ooooo`;o0000E_ooool001cooooo00?o0000oooooooo
ool0@_ooool2o`0000;ooooo0_l00008ooooo`;o000000Coooooo`000?l0003o00004oooool2o`00
0003ooooool0003o000000;o00001?ooool2o`0000[ooooo1?l000000ooooooo0000o`00000=oooo
o`?o00001_ooool2o`0000Cooooo0_l00003ooooo`;o00008oooool5o`0000_ooooo1?l000000ooo
oooo0000o`000006ooooo`Co000000?oooooo`000?l000001?l0001Dooooo`007?ooool2o`0004?o
oooo0_l00002ooooo`;o00002oooool2o`0000;ooooo0_l00008ooooo`?o000000?oooooo`000?l0
00005oooool2o`0000Gooooo0_l0000=ooooo`Co00001Oooool2o`0000Cooooo0_l00003ooooo`;o
00003?ooool2o`0001Kooooo1?l0000;ooooo`Co000000Coooooo`000?l0003ooooo0ol00002oooo
o`Co000000?oooooo`000?l000000_ooool2o`0005Cooooo000Looooo`03o`000?oooooooooo05Oo
oooo1_l00004ooooo`Ko00005oooool2o`000003ooooool0003o000000;ooooo0_l0000:ooooo`;o
00000oooool2o`000003ooooool0003o000000[ooooo0_l00002ooooo`;o00000_ooool2o`0000;o
oooo0_l00003ooooo`;o00005_ooool2o`0000Wooooo0_l00002ooooo`;o00001Oooool4o`0000Go
oooo0_l00005ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0FOooool6o`0000;ooooo
1?l0000?ooooo`;o00002oooool2o`0000;ooooo0ol00009ooooo`;o00001_ooool2o`000003oooo
ool0003o000000?ooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo0_l00002ooooo`Co0000
0oooool2o`0001Cooooo1Ol00003ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Gooooo
0ol00004ooooo`Co00001Oooool2o`0005?ooooo000Looooo`03o`000?oooooooooo057ooooo0_l0
00000ooooooo0000o`000005ooooo`Co00005Oooool2o`000003ooooool0003o000000Sooooo0ol0
0002ooooo`;o00005?ooool2o`0000?ooooo0_l00002ooooo`;o00002_ooool4o`0000?ooooo0ol0
0004ooooo`;o00003_ooool5o`0000;ooooo0_l00005ooooo`;o00003?ooool2o`0000Cooooo0_l0
001Fooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00007?ooool5o`0000Gooooo0_l0000F
ooooo`;o00000_ooool2o`0000Wooooo0_l0000Gooooo`?o00001oooool2o`0000Oooooo0_l00000
0ooooooo0000o`000002ooooo`;o00000_ooool2o`0000Cooooo0_l00003ooooo`;o00003?ooool2
o`000004ooooool0003o0000ooooo`Co00002Oooool2o`0000Kooooo0_l00002ooooo`?o0000EOoo
ool001cooooo00?o0000ooooooooool0<oooool2o`0001Sooooo0_l00003ooooo`?o00000_ooool2
o`0001[ooooo0_l00008ooooo`;o00001oooool2o`0001?ooooo0_l0000=ooooo`;o00000_ooool6
o`000003ooooool0003o000000gooooo0_l00004ooooo`;o00000_ooool2o`0000Gooooo0_l00000
0ooooooo0000o`000002o`0000Kooooo0_l000000ooooooo0000o`000006ooooo`;o000000?ooooo
o`000?l000000_l0001Eooooo`007?ooool00ol0003oooooooooo`0dooooo`;o00003_ooool2o`00
00Oooooo0_l00002ooooo`Co00000_ooool2o`0002Cooooo0_l00007ooooo`;o00005Oooool2o`00
00?ooooo0_l00004ooooo`Co00000_ooool6o`0001Cooooo1?l00002ooooo`;o00001_ooool2o`00
00Gooooo0_l00003ooooo`;o00002?ooool2o`0000;ooooo0_l0001Gooooo`007?ooool00ol0003o
ooooooooo`0dooooo`;o00003_ooool2o`0000_ooooo0_l00004ooooo`;o00004Oooool3o`0002Ko
oooo0_l00006ooooo`Co00000oooool3o`000003ooooool0003o000000;o00001?ooool2o`0001So
oooo0_l0000<ooooo`?o00001?ooool3o`0000Sooooo0_l00002ooooo`;o0000Foooool001cooooo
00?o0000ooooooooool0B_ooool2o`0000_ooooo0_l0000Aooooo`?o00001Oooool2o`00013ooooo
0_l00003ooooo`;o00002?ooool2o`0000Kooooo0_l00002ooooo`;o00000_ooool6o`0000Kooooo
1?l00004ooooo`;o000000?oooooo`000?l000000oooool2o`0000oooooo0_l00004ooooo`?o0000
00?oooooo`000?l000001?l000001?oooooo0000o`000?ooool6o`0000Sooooo0_l0001Eooooo`00
7?ooool00ol0003oooooooooo`0hooooo`;o00000_ooool2o`0000cooooo0_l00003ooooo`;o0000
1Oooool2o`0001Kooooo0_l00002ooooo`;o00004?ooool2o`0000?ooooo0_l0000Dooooo`;o0000
0_ooool4o`0000Sooooo1?l00002ooooo`Co000000?oooooo`000?l000000oooool2o`0000Kooooo
0_l00007ooooo`;o00000_ooool4o`0000;ooooo1?l00002ooooo`?o000000?oooooo`000?l00000
0ol00005ooooo`;o00000_ooool4o`0005?ooooo000Looooo`03o`000?oooooooooo03Sooooo0_l0
0002ooooo`;o000000?oooooo`000?l000002?ooool2o`0000Cooooo0_l00005ooooo`Co00000ooo
ool2o`0000cooooo0_l000000ooooooo0000o`00000Aooooo`;o00000_ooool2o`0000_ooooo0_l0
000?ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo2_l00004ooooo`;o00000_oo
ool2o`0000;ooooo1_l00003ooooo`Co00000_ooool2o`0000?ooooo0ol000001?oooooo0000o`00
0?ooool4o`0000[ooooo0_l00004ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0?ooo
ool2o`0000Oooooo0ol00005ooooo`;o00001_ooool2o`000003ooooool0003o000000;o00003?oo
ool2o`0000Oooooo0_l00003ooooo`;o00001_ooool2o`0000;ooooo0_l0000;ooooo`;o000000?o
ooooo`000?l000003?ooool4o`000004ooooool0003o0000ooooo`;o00000_ooool:o`0000Cooooo
0_l00002ooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`Co00001?ooool2o`000005oooo
ool0003o0000o`000?ooool00_l00002ooooo`?o000000?oooooo`000?l000001?l00009ooooo`;o
0000Doooool001cooooo00?o0000ooooooooool0B?ooool3o`0000Gooooo0_l00009ooooo`;o0000
5oooool3o`0000;ooooo0_l0000Jooooo`;o00001?ooool2o`0000Gooooo1ol00002ooooo`;o0000
0_ooool5o`000003ooooool0003o0000017ooooo0_l000000ooooooo0000o`000009ooooo`;o0000
0_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`Ko00002Oooool2o`0000Oooooo
0_l0001:ooooo`007?ooool00ol0003oooooooooo`16ooooo`;o00000oooool2o`0000?ooooo0_l0
00000ooooooo0000o`00000Pooooo`;o00002?ooool2o`0001[ooooo0_l000000ooooooo0000o`00
0004o`0000;ooooo0ol000000ooooooo0000o`000008o`000003ooooool0003o000000;o00001_oo
ool2o`000003ooooool0003o000000;ooooo1?l000000ooooooo0000o`000002ooooo`;o00000ooo
ool2o`0000Sooooo0_l000000ooooooo0000o`000009ooooo`Co00003Oooool2o`0004[ooooo000L
ooooo`03o`000?oooooooooo047ooooo0_l00003ooooo`;o00000oooool2o`0000?ooooo1Ol0000>
ooooo`;o00001oooool4o`0000Wooooo0_l00004ooooo`;o00001?ooool2o`00013ooooo0_l00005
ooooo`Wo00000_ooool@o`0000Kooooo2ol00005ooooo`;o00000oooool2o`0001Kooooo1?l0000;
ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0@Oooool2o`0000oooooo0_l00003oooo
o`;o00002_ooool2o`0000Oooooo1?l00008ooooo`?o00001Oooool2o`0000?ooooo0_l00002oooo
o`;o00003?ooool2o`0000;ooooo0_l00003oooooa7o000000?oooooo`000?l000001Ol00003oooo
o`;o00000oooool2o`000003ooooool0003o000000;ooooo0_l00005ooooo`;o00001Oooool3o`00
00?ooooo0_l00006ooooo`;o00001_ooool2o`0000gooooo0_l0001<ooooo`007?ooool2o`0004Co
oooo0_l0000Booooo`Co00001Oooool2o`0001Kooooo0ol00002ooooo`;o000000?oooooo`000?l0
00001Oooool4o`000003ooooool0003o000000Sooooo0_l00003ooooo`[o000000?oooooo`000?l0
00005ol00005ooooo`;o00004?ooool3o`0000?ooooo1?l00004ooooo`;o000000?oooooo`000?l0
00000oooool2o`0000?ooooo0_l00002ooooo`Co0000D?ooool001cooooo00?o0000ooooooooool0
>oooool2o`0000Kooooo0_l00006ooooo`;o00002_ooool4o`0000Gooooo0_l0000Gooooo`;o0000
0_ooool2o`0000Gooooo0_l000000ooooooo0000o`000003ooooo`;o00000oooool2o`0000?ooooo
0_l00002ooooo`Ko000000?oooooo`000?l000001Ol000000ooooooo0000o`00000;o`000003oooo
ool0003o000000?o000000Coooooo`000?l0003o00001?ooool2o`000003ooooool0003o000000Ko
oooo0_l00005ooooo`;o00001_ooool3o`000003ooooool0003o000000?ooooo1?l00006ooooo`So
0000D?ooool001cooooo00?o0000ooooooooool0:oooool2o`0000kooooo0_l0000>ooooo`?o0000
1oooool4o`0001?ooooo0_l0000Fooooo`Co00002Oooool2o`0000Kooooo0ol000000ooooooo0000
o`000002oooooaco000000?oooooo`000?l000000_l00003ooooo`Co00001_ooool2o`0000kooooo
0_l000001?oooooo0000o`000?l00002ooooo`Co00001Oooool2o`000003ooooool0003o000000co
oooo0_l00016ooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o00007oooool2o`0000;ooooo
0_l00003ooooo`;o00001?ooool2o`0000oooooo0_l0000Aooooo`;o00001?ooool3o`0000;ooooo
0_l0000;ooooo`Co000000Coooooo`000?l0003o00001?ooool;o`0000;ooooo3_l00002ooooo`;o
00000oooool2o`0000cooooo0_l00002ooooo`;o00002_ooool2o`0000?ooooo0ol00005ooooo`Go
00001?ooool2o`0000Cooooo1?l00016ooooo`007?ooool00ol0003oooooooooo`0jooooo`;o0000
5?ooool2o`0000Wooooo0_l0000Rooooo`;o00001?ooool2o`0000?ooooo0_l00002ooooo`;o0000
1?ooool2o`000003ooooool0003o000000?ooooo1ol000000ooooooo0000o`00000Ho`000003oooo
ool0003o000000?ooooo1?l00002ooooo`;o00001oooool2o`0000;ooooo1?l0000=ooooo`?o0000
1oooool2o`0000Gooooo0_l00004ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0;Ooo
ool2o`0000_ooooo0_l00006ooooo`;o00005oooool2o`000003ooooool0003o000000cooooo0_l0
0006ooooo`;o00001?ooool2o`0000cooooo0_l00004ooooo`;o00001?ooool2o`0000Oooooo6?l0
00000ooooooo0000o`00000:o`0000;ooooo1?l00002ooooo`;o00002oooool4o`0000kooooo0_l0
0009ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0;Oooool2o`000003ooooool0003o
000000Sooooo0_l00006ooooo`;o00003_ooool2o`0000Oooooo0_l000000ooooooo0000o`000003
ooooo`;o00001oooool2o`0000Kooooo0_l00004ooooo`;o00003?ooool5o`0000_ooooo0_l00000
0ooooooo0000o`00000Vo`000004ooooool0003o0000o`0000Kooooo0_l00005ooooo`;o000000Co
ooooo`000?l0003o00002oooool2o`0000Sooooo1?l000000ooooooo0000o`000007ooooo`;o0000
B_ooool001cooooo00?o0000ooooooooool0<?ooool2o`0000Sooooo0_l0000:ooooo`;o00002_oo
ool2o`0000oooooo0_l00007ooooo`;o00001_ooool4o`0000?ooooo0_l0000=ooooo`Go00002Ooo
ool2o`000004ooooool0003o0000oooooago000000?oooooo`000?l000002_l00005ooooo`;o0000
1Oooool7o`0000?ooooo0_l00005ooooo`?o00001oooool4o`0000[ooooo0_l0001:ooooo`007?oo
ool00ol0003oooooooooo`16ooooo`;o00000_ooool2o`0001Wooooo0_l0000<ooooo`;o000000?o
ooooo`000?l000000oooool2o`0000oooooo0ol00006ooooo`Go00001?oooolZo`0000Gooooo0_l0
0007ooooo`Go00000oooool4o`0000;ooooo1?l0001Qooooo`007?ooool00ol0003oooooooooo`10
ooooo`;o00002?ooool2o`0001Oooooo1?l00007ooooo`;o00000oooool2o`0000Kooooo0_l00003
ooooo`?o00001_ooool2o`000004ooooool0003o0000o`0000Kooooo0ol00002ooooo`;o00000ooo
oolTo`000004ooooool0003o0000o`0000?ooooo0_l00007ooooo`;o00001?ooool2o`0000?ooooo
1?l00002ooooo`Co00005oooool2o`0004Sooooo000Looooo`03o`000?oooooooooo043ooooo0_l0
000Jooooo`;o00001Oooool2o`0000Wooooo0_l00004ooooo`;o00002Oooool4o`0000Kooooo0ol0
00000ooooooo0000o`00000:oooooaOo000000?oooooo`000?l000005?l00003ooooo`;o00001ooo
ool2o`0000?ooooo0_l00003ooooo`;o00000oooool2o`0000;ooooo1?l00008ooooo`Go00001_oo
ool4o`0004Sooooo000Looooo`03o`000?oooooooooo02?ooooo0_l0000Jooooo`;o00005?ooool2
o`0000?ooooo1?l0000<ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000002
o`0000Cooooo0_l000000ooooooo0000o`000002o`0000Gooooo0_l00002ooooo`;o00002Ooooola
o`0000gooooo1?l000001?oooooo0000o`000?ooool4o`0000?ooooo0_l00004ooooo`;o00001?oo
ool2o`0000;ooooo1Ol00006ooooo`;o000000?oooooo`000?l00000Aoooool001cooooo00?o0000
ooooooooool08oooool2o`0001[ooooo0_l000000ooooooo0000o`000004ooooo`;o00002_ooool3
o`0000?ooooo0_l0000<ooooo`Co000000?oooooo`000?l000000_l000001?oooooo0000o`000?l0
0005ooooo`;o000000?oooooo`000?l000001oooool2o`0000Wooooo0_l00002ooooo`Go000000Co
ooooo`000?l0003ooooo0ol000000ooooooo0000o`00000Oo`000003ooooool0003o000000Oooooo
0_l00004ooooo`Co00001?ooool2o`000003ooooool0003o000000kooooo0_l0000@ooooo`?o0000
A_ooool001cooooo00?o0000ooooooooool0=oooool2o`0000Wooooo0_l00004ooooo`;o00000ooo
ool2o`0000Gooooo0_l0000Booooo`;o000000?oooooo`000?l000001Ol000001?oooooo0000o`00
0?l00002ooooo`?o00002oooool2o`0000Wooooo1?l00002ooooo`;o00000ooooolEo`0000;ooooo
2ol000000ooooooo0000o`000003o`0000Wooooo0_l00005ooooo`?o000000?oooooo`000?l00000
1?ooool2o`0000_ooooo0_l00009ooooo`;o00002Oooool4o`0004Cooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003o
ooooooooo`0gooooo`Co00001oooool2o`0000Sooooo0ol0000Booooo`Ko00000_ooool9o`000004
ooooool0003o0000o`0000;ooooo0ol00007ooooo`;o00002oooool2o`0000;ooooo0_l00002oooo
o`Co000000?oooooo`000?l000002Ol000000ooooooo0000o`000004o`000003ooooool0003o0000
01?o00004?ooool3o`000003ooooool0003o000000Kooooo0_l00009ooooo`;o000000?oooooo`00
0?l000001_ooool2o`0000Kooooo0_l00003ooooo`;o0000A?ooool00006oooooomgMgOoV9RHoooo
oonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0e
ooooo`;o00000_ooool2o`0000[ooooo0_l00004ooooo`?o000000?oooooo`000?l000002Oooool2
o`0000;ooooo6?l00003ooooo`;o00001oooool2o`0000_ooooo0_l000001?oooooo0000o`000?l0
0002ooooo`Co00000_ooool:o`0000;ooooo6_l00003ooooo`;o00003?ooool3o`0000?ooooo0_l0
00001?oooooo0000o`000?ooool2o`0000Kooooo0_l000001?oooooo0000o`000?ooool2o`0000ko
oooo0_l00019ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`Go0000
1_ooool00ol0003oooooooooo`0eooooo`;o00003_ooool2o`0000Cooooo0ol000000ooooooo0000
o`000003ooooo`Co00000_ooool2o`0000;ooooo3_l000000ooooooo0000o`000007o`0000?ooooo
0_l00003ooooo`;o00004_ooool8o`0000?ooooo9?l00003ooooo`Co00002_ooool2o`000003oooo
ool0003o000000;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00001?ooool3o`0000Wo
oooo0_l00009ooooo`;o0000BOooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
2Oooool01?m4A4CogMgMooooool00007ooooo`?o0000AOooool2o`0000Oooooo0_l00004ooooo`Co
00000oooool2o`000003ooooool0003o000001Co000000?oooooo`000?l000000_ooool2o`0000?o
oooo0_l00004ooooo`;o00003_ooool7o`0000;ooooo9Ol00002ooooo`Go00002Oooool2o`0000?o
oooo0_l00008ooooo`;o00001?ooool2o`0000[ooooo0ol00008ooooo`;o00001_ooool2o`00047o
oooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`0/ooooo`;o00001_ooool2o`00017ooooo0_l00005ooooo`;o
00000_ooool2o`0000Cooooo0_l000001?oooooo0000o`000?oooolIo`0000gooooo0_l0000:oooo
o`;o00000_ooool3o`0000;ooooo4?l000000ooooooo0000o`00000Fo`0000;ooooo1Ol0000Poooo
o`Co00001oooool2o`0000Oooooo0ol00006ooooo`;o0000@Oooool00003ooooool@413ooooo00;o
oooo00?o410@ooooooooool02_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo02co
oooo0_l00002ooooo`;o00000_ooool2o`00017ooooo0_l00009ooooo`;o00001?ooool2o`000003
ooooool0003o000001co00002oooool2o`0000Sooooo1_l000001?oooooo0000o`000?oooolAo`00
0003ooooool0003o000001?o00000_ooool2o`000003ooooool0003o000000Co00001Oooool2o`00
0003ooooool0003o000000[ooooo0_l00008ooooo`Go00001oooool2o`0000Oooooo0ol000000ooo
oooo0000o`000002o`000003ooooool0003o0000047ooooo00001_ooooooMgMgoiRHV?ooooooV9RH
ogMgM`cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0`ooooo`;o00007oooool2
o`0000Kooooo7Ol000000ooooooo0000o`000006o`0000Kooooo0_l00007ooooo`;o00000_ooool2
o`0000Cooooo2Ol000000ooooooo0000o`000005o`000003ooooool0003o000000Co000000?ooooo
o`000?l000003?l00002ooooo`;o000000?oooooo`000?l000001?l00005ooooo`;o000000?ooooo
o`000?l000002_ooool2o`0000Sooooo0_l0000:ooooo`;o00002?ooool2o`000003ooooool0003o
000000;o000000?oooooo`000?l00000@Oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Ooo
ool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo03Cooooo0_l00003ooooo`;o00005?oo
ool4o`0000?ooooo0_l000001Ooooooo0000o`000?l0003ooooo01[o000000?oooooo`000?l00000
1Ol00006ooooo`;o00000_ooool2o`0000gooooo0ol00002ooooob;o00000_ooool2o`0000;ooooo
1?l00009ooooo`;o00009Oooool2o`0000Sooooo0_l00014ooooo`007?ooool00ol0003ooooooooo
o`0dooooo`Co000000?oooooo`000?l000005?ooool4o`0000?ooooo0_l00002oooooa3o000000?o
ooooo`000?l000002_l000000ooooooo0000o`00000<ooooo`;o000000?oooooo`000?l000003Ooo
ool4o`000003ooooool0003o0000027o00000oooool3o`0000cooooo0_l0000:ooooo`Co00003?oo
ool2o`0000Wooooo1?l00006ooooo`;o00007?ooool2o`0002Kooooo000Looooo`03o`000?oooooo
oooo03;ooooo0_l00002ooooo`;o00006Oooool2o`0000Gooooo0_l000000ooooooo0000o`00000=
o`000003ooooool0003o000000go00000_ooool2o`0000Kooooo1?l0000@ooooo`Wo000000?ooooo
o`000?l000004?l000000ooooooo0000o`00000:o`0000;ooooo0ol0000@ooooo`;o00001_ooool4
o`0000cooooo0_l00006ooooo`;o00000oooool2o`0000Gooooo0_l0000Mooooo`;o00009_ooool0
01cooooo00?o0000ooooooooool0<_ooool2o`0000oooooo0_l0000Cooooob;o00000_ooool2o`00
00Kooooo0_l00008ooooo`;o00001_ooool2o`000003ooooool0003o000001Wo000000?oooooo`00
0?l000001Ol000000ooooooo0000o`000003o`0001Cooooo0_l00003ooooo`;o00001oooool2o`00
00_ooooo0_l00003ooooo`;o00002_ooool2o`0000?ooooo0_l000000ooooooo0000o`00000moooo
o`007?ooool00ol0003oooooooooo`0aooooo`;o00003Oooool2o`000003ooooool0003o000000;o
00002_ooool2o`0000Gooooo8Ol00002ooooo`;o00004Oooool2o`0000Gooooo;Ol00002ooooo`;o
00001_ooool2o`0000gooooo0_l00007ooooo`;o00002_ooool5o`0000Gooooo0_l00009ooooo`Co
000000?oooooo`000?l00000?Oooool001cooooo00?o0000ooooooooool0<Oooool2o`0000gooooo
0ol000001?oooooo0000o`000?l00006ooooo`;o00000_ooool2o`0000Cooooo8_l00002ooooo`;o
00000_ooool2o`0000?ooooo0_l0000;ooooo`;o00000_ooool9o`000003ooooool0003o000002;o
000000Coooooo`000?l0003o00001Oooool2o`0000?ooooo0_l0000;ooooo`;o00001oooool2o`00
00Cooooo0_l000001?oooooo0000o`000?ooool2o`0000Gooooo0_l00009ooooo`;o0000@_ooool0
01cooooo00?o0000ooooooooool0:_ooool2o`0001Gooooo0_l000000ooooooo0000o`000003oooo
o`;o00000_ooool2o`000003ooooool0003o000000Gooooo8_l00006ooooo`;o00000oooool2o`00
00_ooooo0_l00002ooooo`;o00001OoooolQo`0000;ooooo1Ol000000ooooooo0000o`000003oooo
o`;o00001Oooool2o`0000_ooooo0_l00007ooooo`;o00001?ooool2o`0000Wooooo0_l00004oooo
o`;o0000BOooool001cooooo00?o0000ooooooooool0:_ooool2o`0001gooooo0_l00005ooooo`;o
00001_ooool:o`000003ooooool0003o000001Co00003?ooool2o`000003ooooool0003o000000go
oooo0_l00003ooooo`?o00000_oooolMo`0000;ooooo1?l000000ooooooo0000o`000003ooooo`;o
00000_ooool2o`0000Sooooo0_l0000<ooooo`;o000000?oooooo`000?l000003Oooool2o`0000Co
oooo0_l00019ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00002oooool2o`000003oooo
ool0003o000000;ooooo0ol00002oooooa?o000000?oooooo`000?l000002_l000000ooooooo0000
o`000009ooooo`;o000000?oooooo`000?l000003Oooool2o`0000;ooooo1?l00002oooooago0000
2_ooool2o`0000Cooooo0_l00008ooooo`;o00002?ooool2o`0000;ooooo0_l000000ooooooo0000
o`00000Cooooo`Co0000Aoooool001cooooo00?o0000ooooooooool0?Oooool2o`000003ooooool0
003o000000_ooooo0_l000000ooooooo0000o`000002ooooo`?o00000_oooolSo`0000Gooooo0_l0
0006ooooo`Co00001oooool4o`0000?ooooo0_l00004ooooo`Co000000Coooooo`000?l0003ooooo
4_l000001?oooooo0000o`000?l00003ooooo`;o00001?ooool2o`0000?ooooo0_l00007ooooo`;o
00002_ooool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`0000co
oooo0_l00004ooooo`Co0000?oooool001cooooo00?o0000ooooooooool0?Oooool2o`0000;ooooo
0_l00005ooooo`;o00000oooool2o`0000Gooooo0ol00002ooooob?o00001Oooool2o`0000?ooooo
0_l000000ooooooo0000o`000002o`0000Oooooo1?l00002ooooo`?o00000oooool6o`000003oooo
ool0003o000000Go000000?oooooo`000?l000004?l000000ooooooo0000o`000005ooooo`Ko0000
0oooool2o`0000;ooooo0_l00004ooooo`;o00000_ooool4o`0000;ooooo0_l00003ooooo`;o0000
00?oooooo`000?l000000_ooool4o`0000_ooooo0_l00003ooooo`Co0000?oooool001cooooo00?o
0000ooooooooool0@Oooool2o`0000?ooooo1?l00002ooooo`;o00001_ooool3o`0000?ooooo4ol0
00000ooooooo0000o`000009o`0000gooooo0_l000001?oooooo0000o`000?l0000;ooooo`;o0000
00Goooooo`000?l0003o0000ooooo`0Ao`000003ooooool0003o000000;o00000oooool5o`000003
ooooool0003o000000;o000000?oooooo`000?l000000_l00003ooooo`Co00001Oooool2o`0000So
oooo0_l00002ooooo`Co00000_ooool2o`0000Kooooo0_l000001?oooooo0000o`000?ooool2o`00
00;ooooo0_l00007ooooo`;o0000A_ooool001cooooo0_l00017ooooo`;o00001?ooool4o`0000Go
oooo0_l00003oooooa?o000000?oooooo`000?l000002Ol00003ooooo`;o00001oooool3o`000004
ooooool0003o0000o`0000_ooooo1?l00003ooooo`?o000000?oooooo`000?l000005ol00002oooo
o`Co00000oooool2o`0000Cooooo0_l0000?ooooo`Co00000_ooool3o`0000;ooooo1?l00004oooo
o`;o000000?oooooo`000?l000001Oooool6o`0004_ooooo000Looooo`03o`000?oooooooooo02go
oooo0_l0000:ooooo`;o00000_ooool2o`000003ooooool0003o000000cooooo0_l00003ooooo`Co
000000?oooooo`000?l000005?l00002ooooo`ko00001oooool2o`0000;ooooo0_l0000>ooooo`;o
00000oooool2o`0000?ooooo0_l00002ooooo`Wo000000?oooooo`000?l000001?l000001Ooooooo
0000o`000?l0003ooooo00Go00000oooool2o`0000Cooooo0_l0000>ooooo`Go00000_ooool2o`00
00Gooooo0_l00005ooooo`;o00001_ooool2o`000003ooooool0003o000000;o00002Oooool2o`00
043ooooo000Looooo`03o`000?oooooooooo02gooooo0_l0000:ooooo`;o00000_ooool2o`000004
ooooool0003o0000ooooo`?o00001?ooool4o`0000Gooooo0_l00003ooooo`So000000?oooooo`00
0?l000004Ol00002ooooo`Ko00001Oooool2o`0000Kooooo0_l0000=ooooo`;o00001_ooool2o`00
00?ooooo2ol00008ooooo`?o000000?oooooo`000?l000001?l00002ooooo`;o00001Oooool2o`00
00;ooooo0_l00007ooooo`Co000000?oooooo`000?l000002_ooool2o`0000?ooooo0ol00005oooo
o`?o00003_ooool2o`00043ooooo000Looooo`03o`000?oooooooooo03Wooooo0_l00008ooooo`?o
00001?ooool6o`0000[ooooo0_l000001?oooooo0000o`000?oooolEo`000003ooooool0003o0000
00Wooooo0_l000000ooooooo0000o`00000Booooo`;o000000?oooooo`000?l000000oooool4o`00
0004ooooool0003o0000o`0000?ooooo2?l00003ooooo`?o000000?oooooo`000?l000001?ooool2
o`0000;ooooo0_l00004ooooo`?o00000_ooool2o`0000Oooooo0_l00003ooooo`;o00002_ooool2
o`0000?ooooo0_l00006ooooo`;o00003oooool2o`00043ooooo000Looooo`03o`000?oooooooooo
047ooooo0_l0000;ooooo`;o00002_ooool5o`000003ooooool0003o000001?o000000?oooooo`00
0?l000000_ooool2o`0000Sooooo0_l00003ooooo`;o00003?ooool2o`0000;ooooo0_l00005oooo
o`?o000000?oooooo`000?l000000_ooool;o`000005ooooool0003o0000o`000?ooool00ol00000
0ooooooo0000o`000006ooooo`;o00000_ooool2o`0001Wooooo0_l00002ooooo`;o00001?ooool2
o`0000?ooooo0_l00006ooooo`;o00002Oooool2o`00043ooooo000Looooo`03o`000?oooooooooo
047ooooo0_l00008ooooo`;o00001?ooool2o`0000Gooooo0_l000001?oooooo0000o`000?l00002
oooooa7o000000?oooooo`000?l000001_ooool4o`0000_ooooo0ol00005ooooo`;o00001?ooool2
o`0000;ooooo0_l00005ooooo`?o000000?oooooo`000?l000000_ooool4o`000004ooooool0003o
0000ooooo`Go00000oooool3o`000003ooooool0003o000000Kooooo0_l0000Cooooo`;o00002?oo
ool6o`0000Cooooo0_l00002ooooo`Co00001Oooool4o`0004Wooooo000Looooo`03o`000?oooooo
oooo03gooooo0_l0000:ooooo`Co00001?ooool3o`0000Cooooo0_l00006oooooa7o000000Cooooo
o`000?l0003ooooo0_l00005ooooo`;o00000oooool3o`0000Kooooo1?l00003ooooo`;o00004ooo
ool2o`0000;ooooo1?l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000cooooo
0_l000001?oooooo0000o`000?ooool2o`00013ooooo0_l0000:ooooo`Co00001oooool5o`0000Oo
oooo0_l000000ooooooo0000o`000016ooooo`007?ooool00ol0003oooooooooo`0mooooo`;o0000
2_ooool2o`0000Oooooo0ol0000;oooooa3o000000?oooooo`000?l000000_ooool2o`0000[ooooo
0ol00008ooooo`;o00003oooool2o`0000Oooooo1ol00005ooooo`;o00000oooool2o`0000;ooooo
0_l00002ooooo`;o00000_ooool3o`0000?ooooo0_l0000Nooooo`;o00001oooool2o`0000gooooo
0_l00007ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool09?ooool2o`0001Oooooo0_l0
000:ooooo`;o00002?ooool2o`0000cooooo0_l000000ooooooo0000o`000003o`0000Cooooo1_l0
000Iooooo`;o00003?ooool2o`000004ooooool0003o0000ooooo`;o00001Oooool3o`0000[ooooo
0_l000000ooooooo0000o`000002ooooo`;o00000_ooool2o`0000?ooooo0_l00008ooooo`;o0000
6Oooool2o`0000_ooooo0_l00007ooooo`;o00000_ooool2o`0000Gooooo0_l00004ooooo`;o0000
1oooool2o`0002kooooo000Looooo`03o`000?oooooooooo02Cooooo0_l0000Gooooo`;o00000ooo
ool5o`0000Cooooo0_l00006ooooo`;o00002_ooool3o`0000;ooooo0ol00006ooooo`Co00003_oo
ool2o`000004ooooool0003o0000ooooo`?o00001?ooool2o`0000[ooooo1?l00004ooooo`;o0000
4_ooool4o`0001Kooooo0_l00002ooooo`;o00005Oooool2o`000003ooooool0003o000000Cooooo
0_l00002ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00002oooool2o`0000Oooooo
0_l0000^ooooo`007?ooool00ol0003oooooooooo`12ooooo`Go00001?ooool2o`0000kooooo0_l0
0002ooooo`?o00000_ooool2o`0000;ooooo0_l00002ooooo`;o00002?ooool2o`0000Oooooo0_l0
00000ooooooo0000o`000004o`0000;ooooo1?l000000ooooooo0000o`000005ooooo`Co00001_oo
ool2o`0000Gooooo0_l00005ooooo`;o00001_ooool2o`0000?ooooo0_l0000Eooooo`;o00006?oo
ool2o`0000Cooooo0_l00002ooooo`;o00000_ooool3o`0000Kooooo0_l00003ooooo`;o00002?oo
ool2o`0000;ooooo0_l0000aooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00001oooool2
o`0000[ooooo0_l0000;ooooo`;o00002_ooool3o`000004ooooool0003o0000o`0000;ooooo0_l0
0004ooooo`;o00001_ooool4o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000;ooooo
1?l00003ooooo`Co00001oooool2o`0000Gooooo0_l00005ooooo`;o00002?ooool2o`000004oooo
ool0003o0000ooooo`?o0000>?ooool4o`0000Kooooo0_l000000ooooooo0000o`000002o`0000So
oooo0_l00002ooooo`;o0000<Oooool001cooooo00?o0000ooooooooool0>Oooool2o`0000Cooooo
0_l00003ooooo`;o000000?oooooo`000?l000001Oooool2o`00017ooooo0_l00004ooooo`;o0000
0_ooool3o`0000;ooooo0_l00004ooooo`;o00001_ooool4o`0000Kooooo0_l00004ooooo`Go0000
0_ooool4o`0000;ooooo0_l00003ooooo`;o00002?ooool2o`0000Oooooo0ol000001?oooooo0000
o`000?l00004ooooo`Go0000=_ooool2o`0000_ooooo1?l0000oooooo`007?ooool00ol0003ooooo
ooooo`0fooooo`;o000000?oooooo`000?l000001?ooool2o`0000?ooooo0_l000000ooooooo0000
o`000003ooooo`;o00003Oooool2o`0000Cooooo0_l0000<ooooo`;o00001Oooool2o`0000?ooooo
0_l0000;ooooo`;o00001Oooool4o`0000Sooooo1?l0000;ooooo`;o00001oooool3o`000003oooo
ool0003o000000;ooooo0_l00003ooooo`?o00002?ooool2o`0000[ooooo0_l0000]ooooo`?o0000
@?ooool001cooooo00?o0000ooooooooool0=_ooool2o`000003ooooool0003o000000Kooooo1?l0
0007ooooo`Co00002oooool2o`0000kooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0
003o000000?ooooo0_l00003ooooo`;o00006oooool4o`0000Gooooo0_l0000Cooooo`;o00001ooo
ool4o`0000?ooooo0_l00003ooooo`;o00001Oooool4o`0000Gooooo0_l0000Dooooo`;o00001_oo
ool2o`0000Oooooo0ol0000oooooo`007?ooool00ol0003oooooooooo`0hooooo`?o00001_ooool4
o`0000Sooooo0ol0000Kooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000003
ooooo`?o00000_ooool2o`0000[ooooo0_l0000:ooooo`;o00000oooool4o`0000Gooooo1?l0000;
ooooo`;o00003Oooool4o`0000?ooooo0_l00003ooooo`;o00001?ooool2o`000003ooooool0003o
000000Gooooo0_l0000<ooooo`;o00001_ooool2o`0000Kooooo0_l00005ooooo`Go00004?ooool2
o`0002gooooo000Looooo`;o0000=oooool4o`0001?ooooo0_l00004ooooo`;o00002oooool2o`00
00;ooooo0_l0000=ooooo`;o00000oooool2o`000004ooooool0003o0000o`0000;ooooo0_l0000:
ooooo`;o00002_ooool2o`0000Cooooo0_l00008ooooo`;o00002oooool2o`0000?ooooo0_l00002
ooooo`;o00002oooool2o`000003ooooool0003o000000Kooooo1Ol00002ooooo`;o00000oooool2
o`0000[ooooo0_l00004ooooo`;o00000oooool2o`0000Oooooo0_l000000ooooooo0000o`00000C
ooooo`;o0000;Oooool001cooooo00?o0000ooooooooool08oooool2o`00017ooooo0ol0000<oooo
o`;o00003?ooool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o000000Coooooo`00
0?l0003o00002?ooool2o`000003ooooool0003o000000;o00000_ooool3o`0000[ooooo0_l0000;
ooooo`;o00002oooool2o`0001Sooooo1?l00002ooooo`;o00002oooool2o`000004ooooool0003o
0000o`0000?ooooo1_l000000ooooooo0000o`000002o`0000?ooooo0_l0000<ooooo`;o00000_oo
ool3o`0000;ooooo0_l00007ooooo`Go00000oooool4o`0003_ooooo000Looooo`03o`000?oooooo
oooo02?ooooo0_l0000Kooooo`;o00000_ooool6o`0000Cooooo0_l00003ooooo`Go00000_ooool4
o`0000Cooooo0ol00005ooooo`;o00000_ooool7o`000004ooooool0003o0000o`0000[ooooo0ol0
0007ooooo`;o00000_ooool2o`0000Kooooo1?l000000ooooooo0000o`000006ooooo`;o00001?oo
ool2o`0000[ooooo0_l00006ooooo`;o000000?oooooo`000?l000001_ooool2o`0000;ooooo3_l0
0004ooooo`;o00003Oooool2o`0000?ooooo0_l0000<ooooo`Co00000oooool4o`0001_ooooo0_l0
000Nooooo`007?ooool00ol0003oooooooooo`0Uooooo`;o00005oooool4o`0000;ooooo1_l00004
ooooo`;o00000oooool4o`0000?ooooo0_l00006ooooo`;o00001_ooool8o`000004ooooool0003o
0000ooooo`?o00002_ooool2o`0000;ooooo0ol00003ooooo`;o00002_ooool4o`0000Wooooo0_l0
0004ooooo`;o000000?oooooo`000?l000000oooool2o`0000[ooooo0_l000000ooooooo0000o`00
0009ooooo`oo000000Coooooo`000?l0003ooooo0_l0000Pooooo`;o00000_ooool4o`0001kooooo
0_l0000Nooooo`007?ooool00ol0003oooooooooo`0Uooooo`;o00005_ooool3o`0001?ooooo0_l0
0009ooooo`;o000000?oooooo`000?l000002Oooool5o`0001Gooooo1?l00004ooooo`;o00007_oo
ool3o`0000?ooooo0_l00002ooooo`;o00005?ooool>o`0000;ooooo0_l0000Eooooo`Co00003_oo
ool4o`0003kooooo000Looooo`03o`000?oooooooooo03Wooooo1_l0000Looooo`Go000000?ooooo
o`000?l000001?ooool2o`0000Sooooo0_l0000?ooooo`;o00000_ooool2o`0000Kooooo0_l0000G
ooooo`?o00001?ooool2o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l000003oooool2
o`000003ooooool0003o000000go00001?ooool2o`0000[ooooo0_l00005ooooo`Co00004?ooool3
o`0003gooooo000Looooo`03o`000?oooooooooo03Wooooo1Ol0000>ooooo`;o00003Oooool3o`00
00?ooooo0_l00004ooooo`;o000000?oooooo`000?l000001Oooool2o`0000oooooo0_l0000Koooo
o`;o00001_ooool3o`0000Kooooo0_l00009ooooo`;o00000_ooool2o`0000_ooooo0_l000000ooo
oooo0000o`00000?o`0000;ooooo0_l0000:ooooo`Co00000oooool4o`0000?ooooo0_l00002oooo
o`;o00000_ooool3o`0000?ooooo1?l0000kooooo`007?ooool00ol0003oooooooooo`0dooooo`;o
00004oooool2o`000003ooooool0003o000001?ooooo0ol00002ooooo`;o00000_ooool6o`0002Go
oooo0_l00005ooooo`;o000000?oooooo`000?l000003oooool2o`000003ooooool0003o000000Wo
oooo0ol0000;ooooo`co000000?oooooo`000?l000001_l0000?ooooo`;o00000oooool2o`0000;o
oooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool3o`0000Gooooo0_l0000kooooo`00
7?ooool00ol0003oooooooooo`0Qooooo`;o00004Oooool2o`0000Gooooo0_l00002ooooo`;o0000
2?ooool2o`00017ooooo0_l00004ooooo`Ko00001?ooool4o`0000gooooo0_l000000ooooooo0000
o`000003ooooo`;o00003_ooool2o`0000Gooooo0_l00002ooooo`;o00004Oooool2o`0000?ooooo
0_l00004ooooo`;o00003?oooolEo`0001Sooooo0_l0000Aooooo`;o0000>oooool001cooooo00?o
0000ooooooooool08Oooool2o`0000Sooooo0_l0000>ooooo`;o00000_ooool2o`0000_ooooo0_l0
0003ooooo`;o00002Oooool2o`000004ooooool0003o0000ooooo`Go00005_ooool2o`000003oooo
ool0003o000000?ooooo0_l0000Iooooo`;o00003_ooool4o`0000Cooooo0_l00004ooooo`?o0000
0_ooool2o`0000Kooooo5ol0000Eooooo`;o00004Oooool2o`0003gooooo000Looooo`03o`000?oo
oooooooo02_ooooo0_l00009ooooo`;o00001_ooool3o`0000_ooooo0_l00003ooooo`;o00003?oo
ool2o`0000Cooooo0_l0000?ooooo`?o00001_ooool2o`00017ooooo0_l00002ooooo`Co00002_oo
ool2o`0000[ooooo1_l000001?oooooo0000o`000?l00005ooooo`Ko00001_oooolHo`0000[ooooo
0_l00004ooooo`Ko00003_ooool2o`000004ooooool0003o0000ooooo`;o0000>_ooool001cooooo
00?o0000ooooooooool0=_ooool2o`0000Kooooo0ol00003ooooo`;o00000_ooool4o`0001Wooooo
1?l0000=ooooo`?o00001_ooool2o`0000Sooooo0ol00006ooooo`;o00000_ooool4o`0000[ooooo
0_l0000>ooooo`;o000000?oooooo`000?l000001oooool4o`000003ooooool0003o000000Cooooo
6?l0000:ooooo`;o00001?ooool6o`0000;ooooo0_l0000:ooooo`;o00000_ooool4o`0003[ooooo
000Looooo`03o`000?oooooooooo02Gooooo0_l0000Mooooo`;o00000_ooool4o`0001Oooooo1_l0
000:ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Kooooo0ol00009ooooo`;o00005ooo
ool5o`0001;ooooo0_l00004oooooaSo000000?oooooo`000?l000002oooool2o`0000Oooooo0ol0
000<ooooo`Co0000??ooool001cooooo00?o0000ooooooooool09Oooool2o`0001Kooooo0_l00009
ooooo`Co00005_ooool4o`0000gooooo1Ol00009ooooo`;o00002?ooool2o`0000Sooooo0_l00003
ooooo`;o00001Oooool2o`0000_ooooo1Ol0000=ooooo`;o00001Oooool2o`0000;ooooo6?l00000
0ooooooo0000o`00000;ooooo`;o00001oooool2o`0000_ooooo1?l00002ooooo`?o0000>Oooool0
01cooooo00?o0000ooooooooool0=?ooool2o`0000Gooooo1?l0000;ooooo`;o00005_ooool4o`00
00;ooooo1?l00007ooooo`?o00005Oooool2o`0000Gooooo1?l00004ooooo`;o00001Oooool2o`00
00?ooooo0_l00007ooooo`?o00003_ooool2o`0000Gooooo0_l00002oooooaKo00000_ooool2o`00
00;ooooo0_l00002ooooo`;o00002?ooool2o`00013ooooo0_l00004ooooo`?o0000>Oooool001co
oooo00?o0000ooooooooool0=?ooool2o`0000Gooooo0_l00004ooooo`;o00002?ooool2o`0001So
oooo1ol0000Looooo`;o000000?oooooo`000?l000001Oooool4o`0000?ooooo0_l000000ooooooo
0000o`000004ooooo`?o000000?oooooo`000?l000002?ooool2o`0000;ooooo1?l00003ooooo`;o
00000oooool2o`0000Sooooo5ol000001?oooooo0000o`000?l00002ooooo`;o00000_ooool2o`00
0003ooooool0003o000000Gooooo0_l00008ooooo`;o00000oooool2o`0001Kooooo0_l0000[oooo
o`007?ooool2o`0004;ooooo0_l000000ooooooo0000o`000005ooooo`;o00005oooool8o`0000Wo
oooo0_l000000ooooooo0000o`00000>ooooo`;o000000?oooooo`000?l000002Oooool2o`000004
ooooool0003o0000ooooo`;o00001?ooool3o`0000oooooo1?l00003ooooo`;o00000oooool2o`00
00Cooooo5?l000000ooooooo0000o`000008o`0000Wooooo0_l0000?ooooo`;o00000oooool2o`00
01Kooooo0_l0000[ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00002_ooool2o`0001;o
oooo0_l00004ooooo`;o00001?ooool2o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`;o
00005?ooool5o`000003ooooool0003o000000;o00002?ooool2o`0000;ooooo0_l0000:ooooo`;o
00001_ooool2o`0000Kooooo1?l00002oooooaWo00005_ooool2o`0000_ooooo0_l00003ooooo`;o
00000_ooool2o`0003Kooooo000Looooo`03o`000?oooooooooo03Gooooo0_l0000>ooooo`;o0000
2Oooool3o`0001Gooooo0_l00002ooooo`;o00000_ooool2o`0000Kooooo1?l000001?oooooo0000
o`000?l0000>ooooo`;o00000oooool3o`000004ooooool0003o0000ooooo`;o00002_ooool2o`00
00;ooooo1?l00008ooooo`;o00001_ooool2o`0000Sooooo6Ol000000ooooooo0000o`000003o`00
00Kooooo0_l0000<ooooo`;o00001_ooool2o`0000;ooooo1?l000000ooooooo0000o`000002o`00
0003ooooool0003o000000;o0000=?ooool001cooooo00?o0000ooooooooool0=Oooool2o`0000ko
oooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool2o`0000Oooooo0_l0000:ooooo`Co
00000_ooool2o`0000?ooooo0_l00005ooooo`Co000000?oooooo`000?l000002oooool2o`0000;o
oooo0_l00003ooooo`Co00001_ooool2o`0000[ooooo1Ol0000Eooooo`;o00001?oooolCo`0000?o
oooo0_l000000ooooooo0000o`000003o`0000Kooooo0_l0000Dooooo`;o00000_ooool4o`000003
ooooool0003o000000?o00000_ooool2o`0003Cooooo000Looooo`03o`000?oooooooooo033ooooo
0_l00006ooooo`;o00003_ooool2o`0000;ooooo0_l00007ooooo`;o00000oooool4o`000003oooo
ool0003o000000Gooooo0_l00009ooooo`;o00000_ooool2o`000003ooooool0003o0000013ooooo
0_l00009ooooo`;o00001_ooool2o`0000Wooooo1Ol000000ooooooo0000o`00000>ooooo`;o0000
0oooool2o`000003ooooool0003o000000?o00001?ooool@o`0000Sooooo0_l0000Sooooo`;o0000
00?oooooo`000?l00000>?ooool001cooooo00?o0000ooooooooool0<?ooool2o`0000Kooooo0_l0
0003ooooo`;o00001_ooool2o`0000Sooooo0_l00004ooooo`;o00001?ooool3o`000003ooooool0
003o000001Cooooo0_l0000>ooooo`;o00001oooool2o`0001Sooooo0_l00003ooooo`?o00002?oo
ool2o`0000Cooooo0_l00006ooooo`Go00001?ooool@o`000003ooooool0003o000000Gooooo0_l0
000Eooooo`;o00005Oooool2o`0003;ooooo000Looooo`03o`000?oooooooooo02cooooo0_l0000?
ooooo`;o000000Coooooo`000?l0003ooooo1Ol00007ooooo`;o00001Oooool2o`0002Cooooo0ol0
0006ooooo`;o00001oooool2o`000003ooooool0003o000001?ooooo0_l00004ooooo`Co00001Ooo
ool5o`000003ooooool0003o000000cooooo0_l00006ooooo`ko000000?oooooo`000?l000001_oo
ool2o`0000Cooooo1?l000000ooooooo0000o`000009ooooo`;o00003_ooool2o`0000Gooooo0_l0
000booooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00001_ooool2o`0000;ooooo0_l00006
ooooo`So00001Oooool2o`0000Oooooo0ol0000Eooooo`?o00002oooool3o`0000?ooooo0_l0000=
ooooo`;o00001Oooool2o`0000Cooooo0_l00006ooooo`;o00000_ooool6o`0000Gooooo1?l00002
ooooo`?o00004oooool7o`0000;ooooo0_l000000ooooooo0000o`000009ooooo`;o00000oooool5
o`000003ooooool0003o000001Wooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`0doooo
o`;o00000_ooool2o`0000Oooooo0ol00009ooooo`;o00002?ooool2o`0001Gooooo1Ol00002oooo
o`;o00002_ooool3o`0000Wooooo0_l00004ooooo`;o00000oooool2o`0000Cooooo0_l00007oooo
o`Go00000oooool2o`0000_ooooo1Ol00003ooooo`;o00002oooool5o`0000Oooooo0_l00003oooo
o`Go00001_ooool4o`0005Sooooo000Looooo`03o`000?oooooooooo03Gooooo0_l00007ooooo`;o
00005_ooool2o`0000;ooooo0_l00009ooooo`;o00001oooool2o`000003ooooool0003o000000Ko
00001Oooool2o`000003ooooool0003o000000Sooooo1?l00004ooooo`;o00001?ooool2o`0000Wo
oooo0_l000001?oooooo0000o`000?l00005ooooo`;o00001?ooool2o`0000Cooooo1_l00003oooo
o`?o00001?ooool2o`0000Cooooo0_l00007ooooo`;o000000Coooooo`000?l0003ooooo1ol00007
ooooo`?o00005Oooool2o`00047ooooo000Looooo`03o`000?oooooooooo03Gooooo0_l00006oooo
o`?o00002Oooool2o`0000_ooooo0_l00002ooooo`;o00002Oooool2o`0000Kooooo0ol000000ooo
oooo0000o`000003o`000003ooooool0003o000000;o00000oooool2o`000003ooooool0003o0000
00Sooooo0_l0000<ooooo`;o00001_ooool2o`000003ooooool0003o000000?o00002?ooool2o`00
00;ooooo0_l00004ooooo`Co00001Oooool3o`0000Cooooo0_l00008ooooo`;o00000oooool2o`00
00;ooooo1?l000000ooooooo0000o`00000:ooooo`?o00001Oooool2o`0000gooooo1?l000000ooo
oooo0000o`00000looooo`007?ooool00ol0003oooooooooo`0booooo`;o00001?ooool4o`000003
ooooool0003o000000?ooooo0_l00004ooooo`Co00001Oooool2o`0000?ooooo0_l00004ooooo`;o
00003oooool2o`000003ooooool0003o000000go00000_ooool2o`0000gooooo0_l0000:ooooo`Co
000000?oooooo`000?l000000oooool2o`0000Sooooo0ol00008ooooo`Co00001Oooool2o`0000Go
oooo0_l00008ooooo`;o00001_ooool4o`0000;ooooo0_l0000:ooooo`?o00001Oooool2o`0000?o
oooo0_l00008ooooo`Co000000?oooooo`000?l00000??ooool001cooooo00?o0000ooooooooool0
<_ooool2o`0000Cooooo1?l00006ooooo`;o00001?ooool4o`0000Gooooo0_l00002ooooo`?o0000
1?ooool2o`00017ooooo4Ol00002ooooo`;o00003?ooool2o`0000[ooooo1?l0000:ooooo`?o0000
0oooool2o`0000Wooooo0_l00003ooooo`;o00000_ooool2o`0001Oooooo2Ol00009ooooo`;o0000
1?ooool2o`0000?ooooo1?l00008ooooo`;o00000_ooool2o`0003gooooo000Looooo`03o`000?oo
oooooooo03Kooooo0_l0000Mooooo`?o00004Oooool4o`000003ooooool0003o000001Co00001Ooo
ool2o`00017ooooo0_l0000<ooooo`?o00004oooool2o`0001Wooooo0_l000000ooooooo0000o`00
0006o`0000cooooo0_l000000ooooooo0000o`000003ooooo`;o00003Oooool3o`0003gooooo0000
1_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<
c<`01_ooool00ol0003oooooooooo`0Sooooo`;o00004?ooool3o`0000Cooooo0_l0000?ooooo`Co
00001Oooool2o`0000Sooooo0_l00006oooooa;o000000?oooooo`000?l000001ol00003ooooo`Co
0000?oooool2o`0000Kooooo0_l00007ooooo`;o000000?oooooo`000?l000000_ooool2o`0000So
oooo0_l00004ooooo`?o00003_ooool2o`0000Cooooo0_l0000nooooo`0000KoooooogMgMonHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000
ooooooooool08oooool2o`00013ooooo0_l00005ooooo`;o00003oooool4o`0000Cooooo0_l00009
ooooo`;o00001OoooolMo`0000;ooooo0ol00004ooooo`Co00002oooool2o`0000Cooooo0_l00004
ooooo`;o00008?ooool2o`0000Kooooo0_l00009ooooo`;o00001oooool2o`0000Cooooo0_l00005
ooooo`;o00003_ooool2o`0000?ooooo1Ol0000looooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0X
ooooo`;o00001oooool2o`0000cooooo0_l0000Dooooo`;o00004?oooolQo`0000Gooooo1?l00000
0ooooooo0000o`000008ooooo`;o00001?ooool2o`0000Cooooo0_l0000=ooooo`;o00008oooool3
o`0000Oooooo1?l00004ooooo`;o00001Oooool2o`00017ooooo1Ol0000looooo`0000?oooooo`00
0?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3
o`0002Sooooo0_l00007ooooo`;o00003?ooool2o`0002Cooooo0_l00002oooooago00001_ooool2
o`000004ooooool0003o0000ooooo`Oo00000oooool4o`0000Oooooo0_l00002ooooo`;o00000ooo
ool4o`0000?ooooo0_l0000Mooooo`;o00000_ooool4o`0000[ooooo0_l00004ooooo`;o00000_oo
ool2o`000003ooooool0003o000005;ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo03Kooooo0_l0
000Nooooo`;o00003Oooool2o`0000;ooooo8?l00002ooooo`?o00001_ooool5o`0000?ooooo1?l0
0007ooooo`;o00000_ooool2o`0000?ooooo1?l00003ooooo`;o00004oooool2o`0000Sooooo0_l0
0002ooooo`Co00004_ooool4o`00013ooooo0_l00013ooooo`0000?ooooooa0@4?ooool00_ooool0
0ol@413oooooooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0<?ooool2
o`0000Cooooo0_l0000Dooooo`;o00000oooool2o`0000;ooooo0ol0000Aooooob3o00000_ooool3
o`000003ooooool0003o000000;ooooo0_l00007ooooo`;o00000oooool4o`0000?ooooo1_l00000
0ooooooo0000o`000005o`0001;ooooo1_l0000>ooooo`;o00004_ooool4o`0000;ooooo0ol0000;
ooooo`;o0000@oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@oiRH
V008ooooo`03o`000?oooooooooo02oooooo0ol0000Aooooo`;o00001oooool2o`0000?ooooo0_l0
0002ooooo`;o00002_ooool2o`0000Oooooo4?l000000ooooooo0000o`00000>o`0000Cooooo0_l0
0002ooooo`;o00003?ooool4o`000003ooooool0003o000000ko00000_ooool2o`0000Wooooo0_l0
0003ooooo`Co00001?ooool2o`00023ooooo0_l00002ooooo`?o00002oooool2o`0004?ooooo0000
1_ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003o
ooooooooo`0_ooooo`;o00002oooool2o`0000Gooooo0_l00005ooooo`;o00002?ooool2o`0000Ko
oooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo8ol0000:ooooo`;o00002_ooool2o`000003
ooooool0003o000000go00000oooool2o`0000Wooooo0_l00005ooooo`Co00000_ooool4o`0000Co
oooo0_l00004ooooo`Co00003?ooool2o`0000Kooooo0_l0001Aooooo`007?ooool00ol0003ooooo
ooooo`0dooooo`?o00001Oooool2o`0000cooooo1?l00006ooooo`?o00001Oooool2o`0000Oooooo
0_l00003oooooako00000_ooool3o`000004ooooool0003o0000ooooo`;o00001?ooool3o`0000Wo
oooo0_l00002oooooa3o00000_ooool3o`0000kooooo1?l000000ooooooo0000o`000003o`0000Co
oooo0_l00004ooooo`Co00003?ooool2o`0000Kooooo0_l0000;ooooo`;o0000A?ooool001cooooo
00?o0000ooooooooool0<oooool4o`0001Cooooo1?l00006ooooo`;o00003_ooool2o`0000?ooooo
2Ol000000ooooooo0000o`00000Bo`0000;ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o
00001Oooool4o`0000_ooooo2Ol00002ooooo`_o00003oooool7o`0000gooooo0_l00007ooooo`;o
00002_ooool2o`0000cooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o0000
6?ooool3o`00013ooooo0_l00002ooooo`;o00001?ooool=o`000003ooooool0003o000000oo0000
00Coooooo`000?l0003ooooo0ol0000:ooooo`;o00001oooool3o`000003ooooool0003o000000Oo
00000_ooool=o`0000Cooooo0_l00005ooooo`Go00005oooool2o`000003ooooool0003o000000?o
oooo1?l00003ooooo`?o0000DOooool001cooooo00?o0000ooooooooool0?oooool2o`0000_ooooo
1?l00009ooooo`;o00001Oooool2o`0000;ooooo0_l00006oooooago00001?ooool3o`0001?ooooo
0ol000000ooooooo0000o`00000>o`000003ooooool0003o000000Go00001?ooool2o`0000Gooooo
0_l0000:ooooo`;o000000Coooooo`000?l0003o00002_ooool4o`000004ooooool0003o0000oooo
o`Co00001?ooool2o`0000Cooooo0_l000000ooooooo0000o`000018ooooo`007?ooool00ol0003o
ooooooooo`0oooooo`;o00002oooool2o`0000Gooooo0ol00003ooooo`;o000000?oooooo`000?l0
00002_ooool2o`0000;ooooo7Ol0000;ooooo`;o00002_ooool2o`000003ooooool0003o000001;o
000000?oooooo`000?l000001?l0000<ooooo`;o00001_ooool2o`0000;ooooo0_l000001?oooooo
0000o`000?l0000<ooooo`;o000000?oooooo`000?l000001Ol00004ooooo`;o00001?ooool5o`00
04Sooooo000Looooo`03o`000?oooooooooo03_ooooo0_l0000Fooooo`?o000000?oooooo`000?l0
00000oooool2o`0000[ooooo0ol000000ooooooo0000o`00000Jo`0000?ooooo0_l000000ooooooo
0000o`000004ooooo`?o00002Oooool2o`000003ooooool0003o000001Wo00001oooool2o`0000_o
oooo0_l00002ooooo`;o00004Oooool5o`0000;ooooo0_l00004ooooo`;o00001?ooool3o`0000Wo
oooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0kooooo`Co00005Oooool2o`000003oooo
ool0003o000000?ooooo0_l0000;ooooo`;o00000_oooolGo`000004ooooool0003o0000o`0000?o
oooo0_l000000ooooooo0000o`000005ooooo`;o00003?oooolKo`0000Gooooo1?l00002ooooo`?o
00001Oooool2o`0000[ooooo0_l0000:ooooo`;o00001Oooool2o`0000[ooooo0_l00003ooooo`;o
00001Oooool2o`0000_ooooo0_l0000booooo`007?ooool00ol0003oooooooooo`0kooooo`Co0000
1oooool4o`0000Cooooo0_l00002ooooo`Co00001_ooool2o`0000oooooo0_l00002oooooaGo0000
7_oooolIo`0000Kooooo0_l00004ooooo`?o00001Oooool2o`0000[ooooo0_l00002ooooo`;o0000
2_ooool2o`000004ooooool0003o0000ooooo`;o00000oooool2o`0000Oooooo0_l000000ooooooo
0000o`00000?ooooo`;o0000<_ooool001cooooo00?o0000ooooooooool0A_ooool4o`0000?ooooo
1?l000000ooooooo0000o`000002o`0001Oooooo0_l00003oooooaCo000000?oooooo`000?l00000
2_ooool2o`0000cooooo6ol00003ooooo`;o00008?ooool2o`0000Kooooo0_l00002ooooo`;o0000
1?ooool4o`000003ooooool0003o000000[ooooo0_l00013ooooo`007?ooool00ol0003ooooooooo
o`0kooooo`;o00002oooool2o`0000?ooooo1?l0000>ooooo`;o00002Oooool2o`000003ooooool0
003o000000?ooooo3?l00002ooooo`[o00001oooool4o`0000cooooo8?l00003ooooo`;o00008?oo
ool2o`000003ooooool0003o000000;o00001?ooool2o`0000;ooooo0_l0000?ooooo`;o0000@Ooo
ool001cooooo00?o0000ooooooooool0=Oooool2o`0000Cooooo0_l00005ooooo`?o00000oooool2
o`0000?ooooo1?l00008ooooo`;o00001?ooool2o`0000Wooooo0_l000000ooooooo0000o`000003
ooooo`Co00000oooool4o`0000Cooooo0_l000000ooooooo0000o`000004o`0000Oooooo0_l00005
ooooo`;o00001?ooool2o`0000?ooooo3_l000000ooooooo0000o`00000=o`0000?ooooo0_l0000P
ooooo`;o00000oooool3o`0000;ooooo0ol0000Cooooo`;o0000@Oooool001cooooo0_l0000foooo
o`Co00002Oooool3o`0000[ooooo0_l00008ooooo`;o00002?ooool2o`0000Gooooo0_l00003oooo
o`;o00000_ooool3o`0000?ooooo1?l00003ooooo`;o000000Coooooo`000?l0003o00004_ooool2
o`0000Cooooo0_l00002ooooo`oo00000_ooool>o`0000;ooooo0_l00004ooooo`;o00003?ooool2
o`0000gooooo1?l00002ooooo`;o00000_ooool3o`0005Kooooo000Looooo`03o`000?oooooooooo
03Gooooo1?l00004ooooo`;o00009?ooool2o`0000Gooooo0_l00003ooooo`;o00001Oooool2o`00
00Kooooo2?l00006ooooo`;o00004ooooolPo`0000;ooooo0_l00004ooooo`;o00003?ooool2o`00
00Sooooo0_l00003ooooo`Co00001oooool2o`00013ooooo0ol000000ooooooo0000o`000010oooo
o`007?ooool00ol0003oooooooooo`0mooooo`;o00002_ooool2o`000003ooooool0003o000000So
oooo0_l0000Nooooo`Co00001?ooool2o`000003ooooool0003o000000?o00001Oooool4o`0000?o
oooo0_l00002ooooo`?o00002?ooool4o`000003ooooool0003o000000ko000000?oooooo`000?l0
00002?l00002ooooo`;o00000oooool2o`0001Oooooo0_l00003ooooo`;o00002Oooool2o`0000go
oooo0_l000001Ooooooo0000o`000?l0003ooooo00;o0000@?ooool001cooooo00?o0000oooooooo
ool0BOooool2o`000003ooooool0003o000000Sooooo0_l0000;ooooo`;o00000_ooool2o`0000ko
oooo0ol00009ooooo`;o00001Oooool5o`000003ooooool0003o000000;o00000_ooool3o`0000So
oooo7?l000000ooooooo0000o`000003ooooo`;o00000oooool2o`0000Gooooo0_l0000_ooooo`;o
0000Aoooool001cooooo00?o0000ooooooooool0BOooool2o`0000Oooooo0_l0000?ooooo`;o0000
0_ooool2o`0000?ooooo0ol00007ooooo`?o00002_ooool3o`0000;ooooo1?l00004ooooo`;o0000
3?oooolOo`0001;ooooo0_l00004ooooo`;o00005_ooool2o`0000Gooooo0_l00009ooooo`;o0000
B?ooool001cooooo00?o0000ooooooooool0D_ooool2o`000003ooooool0003o000001Gooooo0ol0
00000ooooooo0000o`000004ooooo`;o00002_ooool4o`000003ooooool0003o000000Co00004Ooo
oolOo`0000cooooo0_l0000:ooooo`;o00002?ooool2o`0000cooooo0_l00005ooooo`;o00002Ooo
ool2o`0004Sooooo000Looooo`03o`000?oooooooooo05Gooooo0_l00009ooooo`;o00003Oooool3
o`0000Gooooo0_l00009ooooo`;o00000oooool2o`000004ooooool0003o0000o`0001Kooooo6Ol0
000:ooooo`;o000000?oooooo`000?l000005?ooool2o`0001[ooooo0_l0001<ooooo`007?ooool0
0ol0003oooooooooo`19ooooo`;o00003oooool2o`0000Cooooo0_l00006ooooo`Co000000?ooooo
o`000?l000000_l00006ooooo`;o00001Oooool2o`0000[ooooo0ol00007ooooo`;o00000oooool2
o`0000Cooooo0_l00002oooooa[o00001Oooool6o`0000Gooooo0_l0000/ooooo`;o00001Oooool2
o`0004Gooooo000Looooo`03o`000?oooooooooo03Kooooo0_l0000?ooooo`Co00000_ooool2o`00
00[ooooo0ol00007ooooo`Co000000?oooooo`000?l000000_l000000ooooooo0000o`000005oooo
o`Co00001_ooool2o`0000Sooooo2?l00002ooooo`Co00000oooool3o`0000?ooooo0_l00005oooo
oaOo00000_ooool2o`000003ooooool0003o000000;o00001oooool2o`0000;ooooo0_l0000Toooo
o`;o00000oooool2o`0000Cooooo1Ol00012ooooo`007?ooool00ol0003oooooooooo`0fooooo`;o
00003oooool2o`0000Cooooo0_l0000:ooooo`;o00002?ooool4o`000003ooooool0003o000000[o
oooo1?l000000ooooooo0000o`000002ooooo`;o00000oooool2o`0000;ooooo1Ol00002ooooo`?o
00000_ooool2o`0000;ooooo0_l00002ooooo`Co00000_ooool2o`0000?ooooo5_l00004ooooo`;o
00000oooool2o`0000Kooooo0ol00002ooooo`;o00009?ooool2o`0000?ooooo0_l00006ooooo`?o
0000@_ooool001cooooo00?o0000ooooooooool0COooool2o`0000[ooooo0_l0000=ooooo`Co0000
0oooool2o`000003ooooool0003o000000?ooooo1?l00002ooooo`Co000000?oooooo`000?l00000
0_ooool2o`0000[ooooo0_l00002ooooo`;o00001?ooool2o`0000;ooooo1?l000000ooooooo0000
o`00000Eo`0000Cooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo0_l0000Kooooo`;o0000
3oooool2o`0004gooooo000Looooo`03o`000?oooooooooo04Sooooo0_l00003ooooo`;o00003Ooo
ool2o`0000_ooooo0ol00003ooooo`;o000000?oooooo`000?l000000oooool2o`0000Gooooo1?l0
0002ooooo`;o00003?ooool2o`0000;ooooo0_l0000:ooooo`?o00000_oooolAo`0000;ooooo1?l0
0002ooooo`?o00000_ooool2o`000003ooooool0003o000001Sooooo0_l00005ooooo`;o000000?o
ooooo`000?l000001_ooool2o`0000Cooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`18
ooooo`;o00002?ooool2o`0000Sooooo0_l000000ooooooo0000o`000009ooooo`;o00002oooool2
o`0000Oooooo1_l0000<ooooo`;o00001?ooool2o`0000Wooooo0_l00003oooooa3o00000oooool3
o`0000?ooooo0_l00002ooooo`;o00006oooool4o`0000Kooooo0_l00006ooooo`Co00001Oooool2
o`0000?ooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`1Booooo`;o00002oooool2o`00
00;ooooo0_l00005ooooo`;o00001Oooool2o`0000kooooo0ol00002ooooo`?o00003oooool2o`00
00[ooooo0ol000000ooooooo0000o`00000>o`0000_ooooo0_l00003ooooo`;o00004Oooool2o`00
00Oooooo0_l00003ooooo`;o000000?oooooo`000?l000001_ooool4o`0000Gooooo0_l00003oooo
o`;o0000AOooool001cooooo00?o0000ooooooooool0DOooool2o`0000cooooo0_l00002ooooo`;o
00001Oooool2o`0000Gooooo0_l0000Cooooo`Go00004oooool2o`0000Cooooo0ol00005ooooo`;o
000000?oooooo`000?l000001Ol00004ooooo`;o00001oooool2o`0000;ooooo1?l00008ooooo`;o
00001_ooool2o`0000Oooooo0_l00003ooooo`;o000000?oooooo`000?l000001_ooool3o`0000Ko
oooo0ol00019ooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00000oooool2o`0001Kooooo
0_l0000Eooooo`;o00001?ooool5o`0000cooooo0_l00005ooooo`;o00002oooool3o`000004oooo
ool0003o0000o`0000Sooooo0_l0000;ooooo`Co00002?ooool2o`0000cooooo0_l00004ooooo`;o
00002oooool2o`0000Sooooo0_l00019ooooo`007?ooool2o`0004gooooo0_l00003ooooo`;o0000
4Oooool2o`0000?ooooo0_l0000Booooo`;o000000?oooooo`000?l000000_l00003ooooo`Co0000
2?ooool2o`0000;ooooo0_l00005ooooo`;o00002oooool7o`0001?ooooo0_l0000;ooooo`;o0000
0_ooool2o`0000Wooooo0_l00004ooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0?ooo
ool2o`00013ooooo0_l000000ooooooo0000o`000002ooooo`;o00002_ooool2o`0001Oooooo0_l0
0003ooooo`;o00000oooool4o`0000Kooooo1?l00009ooooo`;o00001?ooool2o`000003ooooool0
003o000000Cooooo1Ol00002ooooo`;o00000_ooool2o`000003ooooool0003o000000Sooooo0_l0
0009ooooo`Co00000_ooool2o`0000oooooo1?l000001?oooooo0000o`000?ooool2o`0005Sooooo
000Looooo`03o`000?oooooooooo03oooooo0_l0000<ooooo`Co00000oooool2o`0000;ooooo0_l0
0007ooooo`;o000000?oooooo`000?l000008oooool2o`0000Kooooo0ol00009ooooo`Go00000_oo
ool5o`0000Gooooo0ol00003ooooo`;o00000_ooool2o`000003ooooool0003o000000Oooooo0_l0
000:ooooo`;o00005oooool2o`000004ooooool0003o0000ooooo`;o00003_ooool4o`0004Kooooo
000Looooo`03o`000?oooooooooo04gooooo1?l00008ooooo`;o00001_ooool2o`000003ooooool0
003o000001Wooooo0_l00007ooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`;o0000
1_ooool2o`000003ooooool0003o000000;ooooo1?l00002ooooo`;o00003oooool2o`0000Kooooo
0ol0000Oooooo`;o00002oooool2o`0000_ooooo1?l00016ooooo`007?ooool00ol0003ooooooooo
o`1Iooooo`;o00002?ooool3o`0001Wooooo0_l00007ooooo`;o00001Oooool5o`000003ooooool0
003o000000[ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00003ooooo`;o00000ooo
ool2o`0000Oooooo0_l00003ooooo`?o00000oooool2o`0001_ooooo0_l00006ooooo`;o00000ooo
ool2o`0005Gooooo000Looooo`03o`000?oooooooooo04Wooooo0_l0000>ooooo`;o00002?ooool3
o`0001_ooooo1?l00005ooooo`;o00001?ooool3o`0000cooooo1?l00003ooooo`;o00000_ooool2
o`0000?ooooo0_l00003ooooo`;o00001oooool2o`0000?ooooo1?l00002ooooo`;o00001_ooool2
o`0000Sooooo0_l0000Aooooo`;o000000?oooooo`000?l00000Eoooool001cooooo00?o0000oooo
ooooool0BOooool2o`0000[ooooo0_l00002ooooo`;o00000oooool3o`0000?ooooo1?l0000?oooo
o`;o00002?ooool4o`0000?ooooo1?l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l00008
ooooo`?o00001Oooool2o`000003ooooool0003o000000gooooo0_l00003ooooo`?o000000?ooooo
o`000?l000000_l0000:ooooo`;o00001_ooool4o`0001Cooooo0_l0001Gooooo`007?ooool00ol0
003oooooooooo`19ooooo`;o00002_ooool2o`0000Oooooo0ol00003ooooo`Co00000_ooool2o`00
00?ooooo0_l00006ooooo`;o00000oooool2o`0000[ooooo1?l000000ooooooo0000o`000006oooo
o`Co00003_ooool2o`00013ooooo0_l00003ooooo`Oo00003?ooool2o`000003ooooool0003o0000
00;ooooo0_l00009ooooo`;o0000I?ooool001cooooo00?o0000ooooooooool0GOooool2o`0000Go
oooo0_l00002ooooo`Go00000_ooool2o`0000_ooooo0_l0000<ooooo`;o00000_ooool2o`0000Go
oooo1?l000000ooooooo0000o`000007ooooo`;o000000?oooooo`000?l000001?ooool2o`0000co
oooo0_l00005ooooo`;o00003_ooool2o`000003ooooool0003o000000Gooooo1?l00004ooooo`;o
00002Oooool2o`0005Wooooo000Looooo`03o`000?oooooooooo05Sooooo1ol00004ooooo`Co0000
00Coooooo`000?l0003ooooo0_l0000Cooooo`;o00001_ooool2o`0000Cooooo0_l0000:ooooo`;o
00000_ooool2o`0000?ooooo1ol00002ooooo`;o00003?ooool2o`0000_ooooo0_l0000Booooo`Go
00000_ooool2o`0000[ooooo0_l0001Iooooo`007?ooool00ol0003oooooooooo`1Hooooo`Ko0000
0oooool6o`0001?ooooo0_l00003ooooo`?o00000_ooool2o`0000;ooooo0_l00002ooooo`?o0000
1_ooool2o`0000Oooooo0_l00005ooooo`;o000000?oooooo`000?l000003_ooool2o`0000Gooooo
0_l00006ooooo`Co00001?ooool2o`000003ooooool0003o000000[ooooo0_l00002ooooo`;o0000
IOooool001cooooo00?o0000ooooooooool0HOooool4o`0001Gooooo0_l00003ooooo`;o00000ooo
ool2o`0000Kooooo0ol00006ooooo`;o00000oooool2o`0000Kooooo0_l00006ooooo`;o00000_oo
ool2o`0000Sooooo0_l00004ooooo`?o00002?ooool2o`0000Cooooo0_l000000ooooooo0000o`00
000Gooooo`;o0000G?ooool001cooooo00?o0000ooooooooool0IOooool2o`00023ooooo0_l00005
ooooo`;o00002_ooool2o`0000Kooooo0_l00006ooooo`;o00000_ooool3o`0000gooooo0_l00007
ooooo`;o00005oooool3o`0000Sooooo0_l0001Looooo`007?ooool00ol0003oooooooooo`1Koooo
o`;o000000?oooooo`000?l000001Oooool3o`0000Wooooo0_l0000=ooooo`;o00001?ooool3o`00
00Gooooo0_l00008ooooo`;o00005Oooool2o`0000oooooo0_l000001Ooooooo0000o`000?l0003o
oooo00;o00002oooool4o`0000Sooooo0ol0001Vooooo`007?ooool00ol0003oooooooooo`1Koooo
o`;o000000?oooooo`000?l000001_ooool2o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`00
00Wooooo0_l00004ooooo`;o00001Oooool2o`0000Wooooo1Ol0000Cooooo`;o00001?ooool2o`00
00Sooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00002_ooool4o`0000Oooooo1?l00006
ooooo`;o0000G_ooool001cooooo00?o0000ooooooooool0JOooool3o`0000Wooooo0_l00005oooo
o`;o00002?ooool2o`0000Gooooo0_l0000;ooooo`?o00004oooool4o`0000;ooooo0_l000000ooo
oooo0000o`00000=ooooo`;o00002_ooool6o`0000Gooooo0_l00008ooooo`;o0000G_ooool001co
oooo0_l0001Qooooo`;o00001oooool3o`00013ooooo0_l00005ooooo`;o00001Oooool2o`0001Go
oooo0_l000000ooooooo0000o`000002o`0000[ooooo0_l00005ooooo`;o00003?ooool2o`0000_o
oooo0_l000001?oooooo0000o`000?l0000?ooooo`;o0000G_ooool001cooooo00?o0000oooooooo
ool0H?ooool2o`0000Sooooo0_l0000Booooo`;o00000oooool3o`000003ooooool0003o000000?o
00000oooool4o`0000_ooooo0_l000000ooooooo0000o`000009o`0000gooooo0_l00002ooooo`;o
00002?ooool2o`0000_ooooo0_l000000ooooooo0000o`000002ooooo`;o000000Coooooo`000?l0
003o0000J?ooool001cooooo00?o0000ooooooooool0H?ooool2o`0001Sooooo0_l00002ooooo`;o
00000_ooool4o`000003ooooool0003o000000;o00001?ooool4o`0000_ooooo0_l00002ooooo`;o
00000oooool5o`0000Wooooo0_l00006ooooo`;o00007?ooool2o`000004ooooool0003o0000o`00
06Sooooo000Looooo`03o`000?oooooooooo05[ooooo0_l00006ooooo`;o00001_ooool2o`0000ko
oooo1?l00004ooooo`;o00006?ooool4o`0000Oooooo0_l000000ooooooo0000o`000009ooooo`;o
00001?ooool4o`00013ooooo0_l0001hooooo`007?ooool00ol0003oooooooooo`1Eooooo`;o0000
0oooool2o`0000Kooooo0_l00006ooooo`Co00003_ooool2o`0001kooooo0_l0000<ooooo`;o0000
3_ooool5o`00013ooooo0_l00008ooooo`;o00001_ooool2o`0006Kooooo000Looooo`03o`000?oo
oooooooo05Gooooo0_l00008ooooo`Co000000?oooooo`000?l000001Oooool3o`0000Cooooo0_l0
0002ooooo`Co00002_ooool3o`0000Wooooo0_l0000Gooooo`;o00001Oooool3o`0000;ooooo1?l0
00000ooooooo0000o`000006ooooo`;o00000_ooool2o`000003ooooool0003o000000[ooooo0_l0
0002ooooo`;o00001_ooool2o`0006Kooooo000Looooo`03o`000?oooooooooo05oooooo1?l00000
0ooooooo0000o`000005ooooo`?o000000Coooooo`000?l0003ooooo2?l0000:ooooo`?o00002Ooo
ool2o`0000[ooooo0_l00004ooooo`;o00001Oooool2o`000003ooooool0003o000000;ooooo0ol0
0002ooooo`Ko00000_ooool4o`000003ooooool0003o000000Co000000?oooooo`000?l000001?oo
ool2o`0000Cooooo0_l00005ooooo`;o0000Joooool001cooooo00?o0000ooooooooool0Goooool2
o`0000Gooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000002
ooooo`Co00001?ooool2o`00017ooooo0_l00004ooooo`;o00001?ooool2o`0000Sooooo0_l00005
ooooo`;o00001?ooool2o`0000;ooooo1?l00003ooooo`;o00001?ooool3o`0000;ooooo0_l00003
ooooo`Co00000_ooool4o`0006_ooooo000Looooo`03o`000?oooooooooo06Kooooo1?l00003oooo
o`;o00003?ooool4o`0000?ooooo0ol0000Aooooo`;o00000_ooool5o`0000Cooooo1?l00005oooo
o`;o00001Oooool3o`0000Sooooo0_l0000:ooooo`?o00001oooool4o`0000;ooooo0_l0001]oooo
o`007?ooool00ol0003oooooooooo`1Wooooo`Co00000_ooool2o`000004ooooool0003o0000oooo
o`;o000000?oooooo`000?l000002_ooool2o`0000cooooo0_l00008ooooo`Go00001?ooool4o`00
0003ooooool0003o000000Co00001_ooool2o`0000gooooo0ol00004ooooo`;o00002?ooool2o`00
00Cooooo0_l0001]ooooo`007?ooool00ol0003oooooooooo`1Yooooo`;o00000oooool4o`000004
ooooool0003o0000ooooo`;o00001_ooool2o`00013ooooo0_l0000Fooooo`Ko00005Oooool3o`00
00Sooooo0_l00004ooooo`Co0000LOooool001cooooo00?o0000ooooooooool0K_ooool2o`0000ko
oooo0_l00002ooooo`;o00001_ooool2o`0000Sooooo0_l0000Dooooo`;o00000oooool2o`0000Wo
oooo0_l00003ooooo`Co00002Oooool4o`0000;ooooo1_l0000Cooooo`;o0000G?ooool001cooooo
00?o0000ooooooooool0OOooool2o`0000?ooooo0_l00006ooooo`?o00000_ooool2o`0000;ooooo
0ol000000ooooooo0000o`00000@ooooo`?o00000oooool2o`0000Wooooo0_l00003ooooo`Ko0000
1oooool2o`0000Cooooo0ol0000Fooooo`;o0000G?ooool001cooooo00?o0000ooooooooool0OOoo
ool2o`0000cooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00000_ooool2o`00013ooooo
0_l00004ooooo`;o00002?ooool2o`0000;ooooo1Ol000000ooooooo0000o`000003ooooo`;o0000
2Oooool2o`0007Cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1[ooooo`?o00001Oooool2o`00
01Wooooo0_l0000Gooooo`;o00001_ooool2o`0000Cooooo0_l00002ooooo`;o00000_ooool5o`00
0004ooooool0003o0000o`0000;ooooo0_l00005ooooo`;o00005oooool2o`0005oooooo00001_oo
ooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40
1_ooool00ol0003oooooooooo`1[ooooo`?o00001Oooool2o`000003ooooool0003o000000[ooooo
0_l00008ooooo`;o00006Oooool3o`0000?ooooo1?l00004ooooo`;o000000?oooooo`000?l00000
1oooool2o`000003ooooool0003o000000Wooooo0_l0000Gooooo`;o0000Goooool00003ooooool@
413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0Koooool2o`0000Gooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo
0_l000000ooooooo0000o`00000Aooooo`;o00001oooool2o`0000?ooooo0ol00006ooooo`Co0000
1oooool2o`000003ooooool0003o000008?ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oo
oooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000Koooool4o`0000?ooooo
0_l00004ooooo`;o00002?ooool2o`000003ooooool0003o000000[ooooo0_l00008ooooo`;o0000
0_ooool2o`0000Cooooo0_l00003ooooo`;o00001_ooool5o`000003ooooool0003o000008_ooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Goc<c<o`000?l0003o0000
olc<c006ooooo`03o`000?oooooooooo077ooooo0_l0000;ooooo`;o00001_ooool2o`0000Wooooo
0_l000001?oooooo0000o`000?l0000<ooooo`;o00001?ooool2o`0000Gooooo0_l00006ooooo`?o
000000?oooooo`000?l00000Roooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool0
2Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0Eoooool2o`0002Go
oooo0_l00006ooooo`;o00002Oooool2o`000003ooooool0003o000000;ooooo0_l0000Fooooo`;o
00006oooool2o`0007[ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj
^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo05Oooooo0_l0000]ooooo`;o00004?ooool2
o`0001Sooooo0_l0000Booooo`;o00001Oooool2o`0007[ooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo07Oooooo
0_l0000;ooooo`;o000000?oooooo`000?l000001_ooool2o`0000;ooooo0_l0000;ooooo`?o0000
3oooool2o`0000?ooooo0ol00002ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Cooooo
0_l0001kooooo`007?ooool00ol0003oooooooooo`1gooooo`;o00002oooool2o`000004ooooool0
003o0000o`0000Gooooo0_l00002ooooo`;o00002oooool3o`0000oooooo0_l00003ooooo`?o0000
0_ooool2o`000003ooooool0003o000000_ooooo0_l0000>ooooo`;o0000Joooool001cooooo00?o
0000ooooooooool0Qoooool3o`0000gooooo0_l0000Iooooo`;o0000:?ooool2o`0006_ooooo000L
ooooo`03o`000?oooooooooo087ooooo0_l00004ooooo`;o00003_ooool2o`0000?ooooo0_l0000;
ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`0001Gooooo0_l000000ooooooo0000o`00
001jooooo`007?ooool00ol0003oooooooooo`1gooooo`;o00002?ooool2o`0001?ooooo0_l00004
ooooo`;o00001oooool2o`000005ooooool0003o0000o`000?ooool00ol00004ooooo`;o00005Ooo
ool2o`000003ooooool0003o000007[ooooo000Looooo`03o`000?oooooooooo07Oooooo1?l00002
ooooo`;o00002oooool2o`0000Kooooo0_l00002ooooo`;o00002_ooool2o`000004ooooool0003o
0000ooooo`;o00001_ooool2o`0000Kooooo0_l000000ooooooo0000o`000009ooooo`;o00001Ooo
ool2o`0007[ooooo000Looooo`03o`000?oooooooooo07Wooooo0_l00002ooooo`;o00002oooool2
o`0000Cooooo1?l0000>ooooo`;o00003?ooool2o`0000Kooooo0_l000000ooooooo0000o`000003
ooooo`;o00000_ooool4o`00087ooooo000Looooo`03o`000?oooooooooo06Gooooo0_l0000>oooo
o`;o00006Oooool2o`0000Gooooo0_l0000<ooooo`;o00004oooool2o`0000;ooooo1?l00002oooo
o`;o0000Poooool001cooooo00?o0000ooooooooool0IOooool2o`0000kooooo0_l0000Fooooo`;o
00002?ooool2o`0000Cooooo0_l00005ooooo`Co00002oooool2o`0000Gooooo0_l00002ooooo`;o
0000ROooool001cooooo00?o0000ooooooooool0Noooool2o`0000Oooooo0_l00007ooooo`;o0000
3_ooool3o`0000Cooooo1?l0000;ooooo`;o000000?oooooo`000?l000001_ooool2o`0008Wooooo
000Looooo`03o`000?oooooooooo07_ooooo0_l00007ooooo`Co00002oooool2o`0000Kooooo0_l0
00000ooooooo0000o`00000Cooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l0
0029ooooo`007?ooool00ol0003oooooooooo`21ooooo`;o00000oooool2o`0000_ooooo0_l00006
ooooo`;o00005Oooool2o`0000Kooooo0_l0002=ooooo`007?ooool2o`0008;ooooo0_l0000Joooo
o`;o00004oooool2o`0009Gooooo000Looooo`03o`000?oooooooooo09gooooo0_l0000Fooooo`;o
00001Oooool2o`0008_ooooo000Looooo`03o`000?oooooooooo093ooooo0_l0000Booooo`;o0000
3oooool2o`0000Gooooo0_l0002;ooooo`007?ooool00ol0003oooooooooo`2@ooooo`;o00002_oo
ool2o`0000Kooooo0_l0002Sooooo`007?ooool00ol0003oooooooooo`2Booooo`;o00002?ooool2
o`000:_ooooo000Looooo`03o`000?oooooooooo09;ooooo0_l0002eooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2hooooo`;o0000Soooool0
01cooooo00?o0000ooooooooool0^?ooool2o`0008oooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001;o
oooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oo
oooooooo00Gooooo0ol0003ooooood[ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool0
01Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;o
oooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001;ooooo00?oEEEEofIVI_l00000oooo
oomDooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00XOooool01?l@413o0000
o`000?ooool2o`000003oa0@4?oooooooooo01Kooooo1?l000002?l@413ooooooooooonHV9So410@
o`000?lb<S;oc<c<0oooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo1Ol0002<ooooo`00X_oo
ool01Ol0003ooooooooooooooooo000000Wooooo1_l0000<ooooo`03o`000?oooooooooo00;ooooo
00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OnH
V9So8B4Qonk^k_ooooooA4A408cooooo002Rooooo`05o`000?ooooooooooooooool000006oooool0
0ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`02ooooo`03oiRHV?lQ8B7ok^k^08gooooo002Rooooo`05o`000?ooooooooooooooool000002Ooo
ool6o`0000cooooo00?o0000ooooooooool01Oooool00onYZJWo410@ooooo`02ooooo`05o`000?nH
V9SooooooiRHV?lQ8B401Oooool00onHV9So8B4Qonk^kP2<ooooo`00X_ooool01Ol0003oQhN7oooo
oonYZJWo000001_ooooo00?o0000ooooooooool01?ooool00ol@413o0000okZj^P03ooooo`05o`00
0?mEEEGo0000oa0@4?o<c<`01_ooool00omgMgOoIVIVooooo`2;ooooo`00XOooool00ol@413o0000
ogMgM`02o`000003oiRHV?oooooooooo01Wooooo00?o0000ooooooooool01Oooool00onj^[[o8B4Q
ooooo`02ooooo`03oeEEEOn7QhOooooo00Wooooo00?o0000ooooooooool0R_ooool00<;ooooo00?o
0000ooooooooool00_ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00?ogMgMoa0@4?nHV9P0
1Oooool01Ol0003o^[ZjoooooonHV9So410@08cooooo0030ooooo`03oeEEEOmVIVKo000000Cooooo
00GoZJVYoa0@4?l0003o410@ojVYZ@04ooooo`04olc<c?m4A4Co0000oa0@40?ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c02<ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1368) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.32639 .43558 Mdot
.32077 .4258 Mdot
.52395 .64208 Mdot
.59537 .39783 Mdot
.73084 .68323 Mdot
.53001 .6783 Mdot
.35412 .55527 Mdot
.34674 .60568 Mdot
.53152 .63502 Mdot
.33711 .51699 Mdot
.37258 .61763 Mdot
.56949 .48254 Mdot
.36719 .5836 Mdot
.56908 .42598 Mdot
.87037 .50524 Mdot
.54618 .34589 Mdot
.32865 .43556 Mdot
.61465 .56759 Mdot
.50928 .38838 Mdot
.513 .68939 Mdot
.37287 .44285 Mdot
.5703 .41954 Mdot
.37219 .40369 Mdot
.56866 .42641 Mdot
.5784 .38102 Mdot
.36262 .3946 Mdot
.38845 .37839 Mdot
.55223 .37254 Mdot
.52281 .39338 Mdot
.35638 .61549 Mdot
.69477 .43298 Mdot
.83726 .56811 Mdot
.56848 .3256 Mdot
.79266 .44837 Mdot
.34273 .5817 Mdot
.44442 .31631 Mdot
.52759 .6672 Mdot
.37489 .60558 Mdot
.38117 .60543 Mdot
.33551 .59364 Mdot
.36123 .60636 Mdot
.35936 .41201 Mdot
.2702 .46359 Mdot
.48068 .71318 Mdot
.59292 .35418 Mdot
.58218 .7904 Mdot
.40372 .36252 Mdot
.56484 .44471 Mdot
.31955 .38495 Mdot
.62403 .64651 Mdot
.43279 .69845 Mdot
.36155 .56214 Mdot
.53433 .69459 Mdot
.16353 .34058 Mdot
.37296 .57654 Mdot
.59291 .46281 Mdot
.5291 .65455 Mdot
.55777 .41184 Mdot
.56444 .42792 Mdot
.47836 .22486 Mdot
.61886 .40786 Mdot
.68117 .57217 Mdot
.30574 .36912 Mdot
.4781 .57353 Mdot
.53874 .65086 Mdot
.38318 .61143 Mdot
.32067 .41662 Mdot
.36291 .57497 Mdot
.63974 .35809 Mdot
.56857 .66939 Mdot
.56829 .44605 Mdot
.3747 .61634 Mdot
.38787 .41237 Mdot
.53551 .39331 Mdot
.56987 .73585 Mdot
.54291 .82048 Mdot
.68787 .539 Mdot
.44537 .29421 Mdot
.47069 .22249 Mdot
.64415 .67861 Mdot
.55868 .35667 Mdot
.72166 .50122 Mdot
.54797 .81054 Mdot
.34526 .3702 Mdot
.51962 .35679 Mdot
.61495 .59122 Mdot
.53923 .38975 Mdot
.6434 .78979 Mdot
.59071 .44481 Mdot
.60193 .54141 Mdot
.52461 .62859 Mdot
.33249 .39259 Mdot
.59553 .39311 Mdot
.52772 .40747 Mdot
.52705 .21913 Mdot
.5256 .43996 Mdot
.57184 .40151 Mdot
.31615 .38122 Mdot
.36385 .56359 Mdot
.60055 .45244 Mdot
.45217 .64387 Mdot
.49248 .6498 Mdot
.6042 .38084 Mdot
.53874 .62029 Mdot
.38319 .39198 Mdot
.52868 .40805 Mdot
.38404 .5978 Mdot
.61141 .40123 Mdot
.23158 .59271 Mdot
.33971 .43685 Mdot
.53534 .37843 Mdot
.64234 .54533 Mdot
.38612 .25319 Mdot
.33094 .38525 Mdot
.44582 .64419 Mdot
.51063 .39434 Mdot
.56192 .39672 Mdot
.31454 .41187 Mdot
.50506 .62554 Mdot
.61794 .79846 Mdot
.31444 .3777 Mdot
.35349 .61844 Mdot
.38633 .4289 Mdot
.54702 .47533 Mdot
.54645 .65519 Mdot
.46409 .69445 Mdot
.22817 .55054 Mdot
.71508 .42777 Mdot
.54152 .39137 Mdot
.28854 .47791 Mdot
.49326 .67165 Mdot
.32937 .40285 Mdot
.36066 .57791 Mdot
.50966 .35671 Mdot
.35132 .42914 Mdot
.37991 .62059 Mdot
.66014 .5448 Mdot
.36723 .69103 Mdot
.381 .41215 Mdot
.48786 .49339 Mdot
.39145 .57946 Mdot
.34131 .56795 Mdot
.73723 .29964 Mdot
.32091 .41148 Mdot
.66062 .57789 Mdot
.35308 .58341 Mdot
.71648 .38744 Mdot
.60279 .36135 Mdot
.6932 .48792 Mdot
.20821 .4061 Mdot
.77976 .41983 Mdot
.39104 .72235 Mdot
.64198 .56371 Mdot
.40669 .60818 Mdot
.58107 .39293 Mdot
.35651 .38678 Mdot
.3683 .39956 Mdot
.61828 .40566 Mdot
.58267 .37429 Mdot
.57105 .44798 Mdot
.5396 .43978 Mdot
.66138 .36703 Mdot
.51683 .44094 Mdot
.38386 .33988 Mdot
.33767 .39046 Mdot
.59005 .39789 Mdot
.55209 .68235 Mdot
.62916 .38817 Mdot
.36613 .61218 Mdot
.56445 .41259 Mdot
.59444 .39503 Mdot
.61357 .37937 Mdot
.35461 .56229 Mdot
.8237 .60721 Mdot
.34521 .2793 Mdot
.80678 .60575 Mdot
.57883 .52753 Mdot
.56155 .66376 Mdot
.54828 .38358 Mdot
.67458 .56794 Mdot
.51006 .28727 Mdot
.60045 .41152 Mdot
.16266 .65371 Mdot
.57361 .40942 Mdot
.7563 .66651 Mdot
.64027 .40759 Mdot
.80947 .5496 Mdot
.71537 .48171 Mdot
.57126 .38353 Mdot
.33784 .4954 Mdot
.37948 .55628 Mdot
.4995 .70367 Mdot
.36147 .60197 Mdot
.54691 .68598 Mdot
.52578 .64625 Mdot
.46111 .59778 Mdot
.55762 .48438 Mdot
.61969 .36013 Mdot
.56776 .45345 Mdot
.56238 .62948 Mdot
.32924 .36415 Mdot
.64938 .53953 Mdot
.30535 .41482 Mdot
.77303 .71941 Mdot
.53248 .76368 Mdot
.32666 .58368 Mdot
.68033 .5491 Mdot
.50483 .63829 Mdot
.53335 .62731 Mdot
.64286 .54988 Mdot
.54107 .42281 Mdot
.32656 .41416 Mdot
.76278 .3439 Mdot
.25189 .63396 Mdot
.67627 .20257 Mdot
.32119 .37962 Mdot
.31214 .50594 Mdot
.35316 .61043 Mdot
.51501 .66427 Mdot
.56476 .39754 Mdot
.54053 .41305 Mdot
.35009 .45007 Mdot
.56396 .44731 Mdot
.275 .36229 Mdot
.56601 .3894 Mdot
.37091 .65949 Mdot
.66274 .53004 Mdot
.46191 .59852 Mdot
.73736 .43127 Mdot
.35549 .37602 Mdot
.60799 .24157 Mdot
.54562 .62908 Mdot
.50908 .2826 Mdot
.38849 .61105 Mdot
.67524 .55201 Mdot
.55067 .64489 Mdot
.64352 .54166 Mdot
.50831 .42618 Mdot
.52636 .68885 Mdot
.63548 .56703 Mdot
.62971 .49665 Mdot
.60672 .35646 Mdot
.18762 .56491 Mdot
.33734 .59344 Mdot
.30659 .42287 Mdot
.61292 .42052 Mdot
.55689 .63636 Mdot
.51159 .35021 Mdot
.41995 .76644 Mdot
.40426 .66166 Mdot
.49063 .66814 Mdot
.50947 .59058 Mdot
.68294 .56438 Mdot
.44857 .73603 Mdot
.296 .49073 Mdot
.31637 .42473 Mdot
.52525 .4425 Mdot
.82313 .52281 Mdot
.35353 .58258 Mdot
.61055 .41594 Mdot
.72968 .60711 Mdot
.35233 .57193 Mdot
.556 .41032 Mdot
.38487 .62333 Mdot
.36865 .40045 Mdot
.42649 .21707 Mdot
.31005 .40637 Mdot
.55383 .44863 Mdot
.38294 .58892 Mdot
.53145 .61196 Mdot
.35827 .39756 Mdot
.5467 .43157 Mdot
.55211 .37468 Mdot
.54245 .56878 Mdot
.58492 .40376 Mdot
.79804 .63291 Mdot
.56847 .38606 Mdot
.51442 .65254 Mdot
.57471 .3557 Mdot
.29454 .27476 Mdot
.45624 .5966 Mdot
.32145 .41516 Mdot
.48708 .6599 Mdot
.53331 .64223 Mdot
.56769 .75505 Mdot
.38587 .63587 Mdot
.51667 .38415 Mdot
.56004 .64595 Mdot
.67694 .33141 Mdot
.39856 .59845 Mdot
.61582 .43072 Mdot
.45414 .47766 Mdot
.61518 .64142 Mdot
.52784 .69463 Mdot
.48294 .38221 Mdot
.38377 .40122 Mdot
.59382 .38672 Mdot
.52864 .62425 Mdot
.51251 .46487 Mdot
.53085 .37571 Mdot
.23571 .38849 Mdot
.54375 .57445 Mdot
.3807 .56994 Mdot
.63161 .42343 Mdot
.59443 .43086 Mdot
.53213 .68675 Mdot
.35538 .3779 Mdot
.39844 .59501 Mdot
.36056 .40667 Mdot
.80503 .53179 Mdot
.19544 .5705 Mdot
.65564 .44869 Mdot
.64367 .5363 Mdot
.62909 .61769 Mdot
.80993 .53297 Mdot
.54308 .19343 Mdot
.65208 .26978 Mdot
.80352 .43275 Mdot
.52702 .61967 Mdot
.68871 .6235 Mdot
.53164 .64773 Mdot
.57158 .36651 Mdot
.54515 .65716 Mdot
.826 .51182 Mdot
.56755 .39184 Mdot
.54155 .6662 Mdot
.5774 .23061 Mdot
.59103 .38806 Mdot
.31614 .42224 Mdot
.76913 .70236 Mdot
.39045 .19726 Mdot
.40146 .65799 Mdot
.50219 .66519 Mdot
.68725 .30086 Mdot
.57388 .40131 Mdot
.57329 .3561 Mdot
.34659 .38414 Mdot
.53936 .3322 Mdot
.67317 .58535 Mdot
.68544 .55568 Mdot
.36689 .53515 Mdot
.69891 .54389 Mdot
.63062 .42775 Mdot
.35568 .39527 Mdot
.65893 .37335 Mdot
.58888 .72039 Mdot
.63052 .64026 Mdot
.33506 .54953 Mdot
.76894 .701 Mdot
.33028 .35014 Mdot
.31469 .62519 Mdot
.58587 .67258 Mdot
.31793 .39444 Mdot
.8375 .58658 Mdot
.36581 .60153 Mdot
.19299 .59657 Mdot
.3577 .48234 Mdot
.54302 .42152 Mdot
.39258 .59111 Mdot
.48809 .39594 Mdot
.41158 .18891 Mdot
.23881 .67292 Mdot
.45115 .39745 Mdot
.59877 .43999 Mdot
.58098 .71198 Mdot
.56433 .40653 Mdot
.49407 .77751 Mdot
.56535 .38102 Mdot
.35581 .40619 Mdot
.33091 .52275 Mdot
.42598 .58958 Mdot
.2936 .31521 Mdot
.45983 .74996 Mdot
.6413 .5669 Mdot
.56271 .39043 Mdot
.54479 .42369 Mdot
.66093 .58876 Mdot
.37595 .40353 Mdot
.56092 .44957 Mdot
.60578 .23492 Mdot
.52945 .41483 Mdot
.36818 .60938 Mdot
.29979 .4497 Mdot
.35882 .34584 Mdot
.52558 .42575 Mdot
.3771 .37888 Mdot
.32938 .568 Mdot
.38086 .58949 Mdot
.63553 .42194 Mdot
.33876 .60728 Mdot
.57981 .41429 Mdot
.26379 .70313 Mdot
.37667 .42049 Mdot
.21893 .44195 Mdot
.34617 .42296 Mdot
.43521 .28838 Mdot
.35517 .56611 Mdot
.39099 .67873 Mdot
.49277 .42685 Mdot
.36745 .59738 Mdot
.39035 .43867 Mdot
.56307 .34534 Mdot
.58291 .34332 Mdot
.74056 .33144 Mdot
.50803 .64855 Mdot
.53156 .57309 Mdot
.35549 .61546 Mdot
.5646 .43886 Mdot
.51611 .42063 Mdot
.32867 .57338 Mdot
.25875 .67447 Mdot
.44839 .19191 Mdot
.56775 .38827 Mdot
.3451 .40341 Mdot
.33231 .40576 Mdot
.62291 .39023 Mdot
.59944 .37766 Mdot
.55286 .65967 Mdot
.51645 .61487 Mdot
.56012 .68056 Mdot
.52733 .57677 Mdot
.38833 .6746 Mdot
.66606 .74941 Mdot
.33542 .5931 Mdot
.28667 .52391 Mdot
.60655 .53827 Mdot
.56887 .45619 Mdot
.4983 .66244 Mdot
.59389 .42938 Mdot
.58991 .41293 Mdot
.36196 .63317 Mdot
.74003 .64101 Mdot
.39981 .3783 Mdot
.36601 .37927 Mdot
.39406 .57951 Mdot
.62945 .44168 Mdot
.31714 .60173 Mdot
.6715 .55305 Mdot
.75626 .3791 Mdot
.38295 .6146 Mdot
.31375 .41709 Mdot
.34068 .59186 Mdot
.53593 .41108 Mdot
.52531 .45664 Mdot
.31839 .39844 Mdot
.67713 .58892 Mdot
.54327 .33328 Mdot
.55608 .40674 Mdot
.19381 .42043 Mdot
.74349 .39027 Mdot
.33946 .65496 Mdot
.57136 .38576 Mdot
.51981 .40609 Mdot
.65404 .59655 Mdot
.5305 .4146 Mdot
.59125 .43992 Mdot
.39483 .25538 Mdot
.24294 .55855 Mdot
.68181 .54542 Mdot
.26979 .70056 Mdot
.31837 .38162 Mdot
.82783 .5461 Mdot
.51202 .67446 Mdot
.39357 .54379 Mdot
.40196 .20815 Mdot
.54017 .69377 Mdot
.39028 .72692 Mdot
.82871 .5633 Mdot
.4465 .62351 Mdot
.47509 .66201 Mdot
.38914 .3742 Mdot
.55024 .4454 Mdot
.55948 .39908 Mdot
.676 .57308 Mdot
.33309 .41511 Mdot
.51835 .55321 Mdot
.43169 .82211 Mdot
.57058 .41646 Mdot
.23613 .40767 Mdot
.3323 .74502 Mdot
.61321 .64998 Mdot
.66263 .56233 Mdot
.68994 .56675 Mdot
.56045 .39124 Mdot
.35828 .26542 Mdot
.36151 .39384 Mdot
.54807 .4322 Mdot
.52109 .44513 Mdot
.5047 .65814 Mdot
.35231 .4358 Mdot
.50278 .62779 Mdot
.41885 .70034 Mdot
.79481 .62217 Mdot
.15762 .55564 Mdot
.36875 .57074 Mdot
.468 .79457 Mdot
.39628 .61565 Mdot
.72679 .50165 Mdot
.50219 .69302 Mdot
.59761 .38506 Mdot
.36003 .3799 Mdot
.57198 .43794 Mdot
.59777 .37793 Mdot
.54277 .4241 Mdot
.52486 .42904 Mdot
.14288 .50179 Mdot
.63876 .56148 Mdot
.50205 .39039 Mdot
.5171 .64771 Mdot
.56278 .7994 Mdot
.51987 .80858 Mdot
.54873 .42475 Mdot
.55747 .37927 Mdot
.36891 .42321 Mdot
.61668 .4096 Mdot
.39998 .60965 Mdot
.29879 .39647 Mdot
.53077 .39552 Mdot
.72655 .73807 Mdot
.52388 .38829 Mdot
.81376 .57013 Mdot
.34245 .59398 Mdot
.23299 .61128 Mdot
.50675 .44202 Mdot
.41457 .65015 Mdot
.53213 .57292 Mdot
.55252 .65067 Mdot
.3862 .62679 Mdot
.53031 .66713 Mdot
.39829 .81067 Mdot
.54888 .46985 Mdot
.58124 .38981 Mdot
.56214 .45678 Mdot
.56175 .66418 Mdot
.67186 .77333 Mdot
.47758 .74594 Mdot
.5222 .46222 Mdot
.5547 .67297 Mdot
.35383 .36678 Mdot
.72995 .34549 Mdot
.35603 .41878 Mdot
.62444 .55446 Mdot
.35689 .61012 Mdot
.67864 .58609 Mdot
.76682 .56302 Mdot
.33002 .43388 Mdot
.33076 .44272 Mdot
.51444 .67364 Mdot
.37304 .48884 Mdot
.4099 .14901 Mdot
.35508 .483 Mdot
.72258 .45928 Mdot
.34946 .38958 Mdot
.52318 .39937 Mdot
.74272 .53501 Mdot
.3552 .49366 Mdot
.53273 .66517 Mdot
.59386 .41892 Mdot
.42737 .21387 Mdot
.55298 .6593 Mdot
.56957 .45896 Mdot
.51425 .64498 Mdot
.35597 .60162 Mdot
.49855 .65393 Mdot
.31061 .43837 Mdot
.53892 .3831 Mdot
.45739 .12497 Mdot
.68659 .61373 Mdot
.57554 .39763 Mdot
.38624 .56923 Mdot
.32346 .70008 Mdot
.60629 .4035 Mdot
.63311 .55517 Mdot
.54474 .67275 Mdot
.4002 .46739 Mdot
.56679 .38535 Mdot
.5543 .67522 Mdot
.33475 .4398 Mdot
.40923 .60959 Mdot
.51764 .21953 Mdot
.40252 .65169 Mdot
.34532 .38257 Mdot
.53533 .51576 Mdot
.36677 .62744 Mdot
.52008 .40766 Mdot
.52333 .43885 Mdot
.34203 .40522 Mdot
.6549 .49173 Mdot
.59711 .36654 Mdot
.56372 .35705 Mdot
.50892 .66035 Mdot
.53274 .67053 Mdot
.62219 .26955 Mdot
.51496 .61941 Mdot
.52219 .45368 Mdot
.34423 .40689 Mdot
.59685 .39564 Mdot
.36824 .4269 Mdot
.6163 .40846 Mdot
.60846 .48333 Mdot
.37587 .40216 Mdot
.37329 .64204 Mdot
.59325 .41544 Mdot
.58537 .32751 Mdot
.6117 .40579 Mdot
.54689 .44248 Mdot
.54936 .65317 Mdot
.66947 .56111 Mdot
.5395 .45568 Mdot
.69642 .5912 Mdot
.64972 .54141 Mdot
.42135 .59376 Mdot
.505 .6552 Mdot
.65305 .57967 Mdot
.3454 .76067 Mdot
.53677 .69029 Mdot
.6743 .58035 Mdot
.52163 .80854 Mdot
.34314 .57841 Mdot
.38475 .40488 Mdot
.58971 .38498 Mdot
.79183 .52712 Mdot
.38622 .35092 Mdot
.48324 .64339 Mdot
.57041 .389 Mdot
.60835 .4167 Mdot
.32359 .37178 Mdot
.43821 .84065 Mdot
.56834 .6696 Mdot
.52155 .3845 Mdot
.3252 .42676 Mdot
.4371 .8571 Mdot
.52023 .65121 Mdot
.67716 .57685 Mdot
.3389 .57803 Mdot
.41 .39556 Mdot
.22599 .55058 Mdot
.36513 .55726 Mdot
.5621 .70818 Mdot
.42363 .69428 Mdot
.50804 .4016 Mdot
.49641 .6663 Mdot
.69843 .23921 Mdot
.64008 .33587 Mdot
.48659 .58078 Mdot
.69331 .30751 Mdot
.32323 .3899 Mdot
.39755 .61361 Mdot
.64103 .56166 Mdot
.32929 .37679 Mdot
.33305 .4372 Mdot
.32926 .58161 Mdot
.36525 .27727 Mdot
.44898 .47552 Mdot
.37663 .60889 Mdot
.77219 .44157 Mdot
.67845 .72167 Mdot
.49803 .66564 Mdot
.67176 .58579 Mdot
.75849 .5806 Mdot
.36129 .41021 Mdot
.79363 .68004 Mdot
.74407 .32951 Mdot
.57198 .40175 Mdot
.65134 .57475 Mdot
.67757 .7599 Mdot
.48653 .83686 Mdot
.35555 .56919 Mdot
.41231 .57037 Mdot
.68298 .577 Mdot
.61132 .42184 Mdot
.72466 .35774 Mdot
.57157 .36043 Mdot
.35196 .60697 Mdot
.54742 .23345 Mdot
.32788 .43413 Mdot
.33354 .575 Mdot
.75461 .37173 Mdot
.57872 .41574 Mdot
.5952 .41469 Mdot
.75347 .45091 Mdot
.33858 .37351 Mdot
.55284 .65061 Mdot
.50958 .42284 Mdot
.55947 .40871 Mdot
.55379 .46258 Mdot
.62663 .42881 Mdot
.39878 .2398 Mdot
.56813 .36989 Mdot
.53207 .77219 Mdot
.60372 .43658 Mdot
.58389 .42327 Mdot
.37996 .38211 Mdot
.15405 .57206 Mdot
.44034 .71186 Mdot
.56294 .41068 Mdot
.51822 .39787 Mdot
.33415 .57742 Mdot
.40407 .48366 Mdot
.38882 .48352 Mdot
.40929 .45988 Mdot
.67008 .2836 Mdot
.61174 .35937 Mdot
.32669 .41949 Mdot
.63464 .56918 Mdot
.51588 .3889 Mdot
.32517 .42184 Mdot
.60781 .36933 Mdot
.55439 .66066 Mdot
.53922 .6898 Mdot
.65259 .36478 Mdot
.64862 .57902 Mdot
.26063 .39485 Mdot
.28309 .52283 Mdot
.53474 .68805 Mdot
.58117 .38681 Mdot
.41235 .63084 Mdot
.53102 .62512 Mdot
.4513 .62522 Mdot
.67068 .51202 Mdot
.35866 .3855 Mdot
.33467 .39009 Mdot
.69079 .48979 Mdot
.39333 .71256 Mdot
.23168 .3572 Mdot
.35507 .60264 Mdot
.50073 .40461 Mdot
.31713 .49346 Mdot
.33464 .38713 Mdot
.73931 .5165 Mdot
.64953 .57592 Mdot
.35068 .57354 Mdot
.55035 .72857 Mdot
.35932 .42723 Mdot
.35996 .43988 Mdot
.6208 .41814 Mdot
.54989 .41145 Mdot
.64539 .26564 Mdot
.69159 .59939 Mdot
.3576 .55507 Mdot
.67593 .58284 Mdot
.50136 .69182 Mdot
.55501 .36654 Mdot
.37365 .40039 Mdot
.65721 .74058 Mdot
.51288 .39559 Mdot
.53958 .63662 Mdot
.32628 .39096 Mdot
.68373 .56454 Mdot
.63141 .56104 Mdot
.53805 .43678 Mdot
.58245 .25873 Mdot
.37447 .6012 Mdot
.31318 .39889 Mdot
.31949 .6116 Mdot
.58106 .36076 Mdot
.5483 .40313 Mdot
.63585 .36793 Mdot
.35895 .55511 Mdot
.27772 .59152 Mdot
.64391 .53817 Mdot
.32829 .41123 Mdot
.56449 .37258 Mdot
.66458 .58577 Mdot
.29835 .52429 Mdot
.49178 .67583 Mdot
.49982 .64873 Mdot
.63199 .56912 Mdot
.65585 .56624 Mdot
.63788 .54597 Mdot
.79527 .67878 Mdot
.31004 .37569 Mdot
.33726 .35024 Mdot
.55444 .35097 Mdot
.71606 .47317 Mdot
.50176 .38127 Mdot
.39429 .58473 Mdot
.51047 .64419 Mdot
.60509 .39212 Mdot
.52763 .42514 Mdot
.64049 .41432 Mdot
.22494 .41923 Mdot
.40423 .37317 Mdot
.34768 .43786 Mdot
.51905 .45325 Mdot
.5045 .66713 Mdot
.78607 .71327 Mdot
.77436 .33923 Mdot
.50862 .44454 Mdot
.44866 .47067 Mdot
.37346 .39439 Mdot
.3338 .59065 Mdot
.76707 .49703 Mdot
.3407 .58134 Mdot
.32612 .4078 Mdot
.56501 .36789 Mdot
.27977 .54076 Mdot
.65056 .59624 Mdot
.55976 .44121 Mdot
.34805 .60247 Mdot
.57006 .44502 Mdot
.35911 .5558 Mdot
.79512 .54885 Mdot
.67403 .24289 Mdot
.57303 .4083 Mdot
.51681 .36424 Mdot
.6613 .26013 Mdot
.55244 .4287 Mdot
.63235 .58999 Mdot
.37361 .39406 Mdot
.55576 .23015 Mdot
.56672 .34123 Mdot
.60566 .2941 Mdot
.57494 .3587 Mdot
.52977 .21299 Mdot
.5458 .40525 Mdot
.60825 .65773 Mdot
.53715 .37903 Mdot
.5837 .44582 Mdot
.37731 .5783 Mdot
.33434 .57365 Mdot
.39063 .40138 Mdot
.54909 .62605 Mdot
.81214 .58571 Mdot
.55337 .40462 Mdot
.41186 .66526 Mdot
.25828 .58245 Mdot
.65771 .56462 Mdot
.3316 .41073 Mdot
.48915 .85649 Mdot
.35857 .61846 Mdot
.72061 .29465 Mdot
.6332 .27687 Mdot
.23428 .50617 Mdot
.73514 .58738 Mdot
.33066 .72015 Mdot
.6803 .55719 Mdot
.61296 .37948 Mdot
.6954 .68215 Mdot
.6027 .66678 Mdot
.65436 .50575 Mdot
.3801 .62945 Mdot
.54215 .27656 Mdot
.72928 .65506 Mdot
.62658 .5664 Mdot
.68714 .57166 Mdot
.36158 .56031 Mdot
.47373 .64336 Mdot
.55636 .48266 Mdot
.648 .56936 Mdot
.56259 .66999 Mdot
.52543 .69132 Mdot
.56265 .68157 Mdot
.36503 .39503 Mdot
.75339 .32581 Mdot
.3218 .59007 Mdot
.38466 .57428 Mdot
.51238 .60111 Mdot
.47924 .35104 Mdot
.29298 .40552 Mdot
.5188 .66829 Mdot
.50331 .63322 Mdot
.37701 .39573 Mdot
.60668 .45671 Mdot
.58584 .47214 Mdot
.56734 .41364 Mdot
.67281 .56589 Mdot
.5446 .41086 Mdot
.55325 .67213 Mdot
.36218 .57049 Mdot
.50512 .63436 Mdot
.38962 .57087 Mdot
.63761 .76413 Mdot
.54233 .43237 Mdot
.54024 .3801 Mdot
.17812 .46962 Mdot
.37351 .43691 Mdot
.58277 .78367 Mdot
.35906 .64985 Mdot
.52946 .64727 Mdot
.59324 .43787 Mdot
.29817 .40003 Mdot
.68586 .59991 Mdot
.16648 .56556 Mdot
.60008 .37481 Mdot
.3676 .41303 Mdot
.5556 .36808 Mdot
.66035 .34828 Mdot
.26297 .2986 Mdot
.35285 .41118 Mdot
.22192 .39053 Mdot
.52064 .39455 Mdot
.38052 .77159 Mdot
.61038 .43532 Mdot
.67736 .41729 Mdot
.59694 .36648 Mdot
.31823 .38121 Mdot
.56443 .41553 Mdot
.29993 .403 Mdot
.5223 .68545 Mdot
.33478 .58524 Mdot
.34291 .38438 Mdot
.52512 .43579 Mdot
.44302 .07977 Mdot
.35192 .59622 Mdot
.56355 .39418 Mdot
.35214 .56436 Mdot
.33642 .41811 Mdot
.32305 .38339 Mdot
.48114 .82751 Mdot
.41936 .70297 Mdot
.3569 .60028 Mdot
.55498 .36703 Mdot
.42074 .7788 Mdot
.58784 .37593 Mdot
.68512 .33521 Mdot
.59087 .46293 Mdot
.56974 .35318 Mdot
.52777 .81477 Mdot
.38086 .56959 Mdot
.23117 .35315 Mdot
.51298 .82695 Mdot
.56013 .8007 Mdot
.36727 .44595 Mdot
.62895 .57298 Mdot
.83335 .5942 Mdot
.38635 .6748 Mdot
.5567 .67173 Mdot
.60819 .40068 Mdot
.31607 .44912 Mdot
.37846 .60036 Mdot
.668 .55385 Mdot
.57225 .40732 Mdot
.49834 .64284 Mdot
.5044 .1904 Mdot
.40601 .60215 Mdot
.35533 .41431 Mdot
.34267 .36755 Mdot
.2782 .74431 Mdot
.56945 .38082 Mdot
.53536 .38637 Mdot
.35576 .60992 Mdot
.29836 .69472 Mdot
.66766 .54284 Mdot
.57573 .22776 Mdot
.35749 .5984 Mdot
.48005 .53466 Mdot
.31893 .41872 Mdot
.60601 .42028 Mdot
.73946 .71156 Mdot
.5423 .7383 Mdot
.19007 .45365 Mdot
.67408 .56887 Mdot
.68784 .33886 Mdot
.31633 .38284 Mdot
.35776 .5799 Mdot
.35979 .70087 Mdot
.61193 .35604 Mdot
.58994 .43051 Mdot
.69071 .36113 Mdot
.4251 .59263 Mdot
.4299 .42754 Mdot
.59441 .36951 Mdot
.52275 .5756 Mdot
.60674 .38451 Mdot
.56687 .33634 Mdot
.56637 .467 Mdot
.54455 .3946 Mdot
.37219 .40528 Mdot
.54494 .31161 Mdot
.55779 .64958 Mdot
.31153 .35762 Mdot
.47812 .54116 Mdot
.57192 .39411 Mdot
.55344 .36032 Mdot
.43986 .39263 Mdot
.38333 .73717 Mdot
.34214 .38663 Mdot
.32885 .44409 Mdot
.34336 .61201 Mdot
.5986 .46597 Mdot
.54427 .62308 Mdot
.52073 .34757 Mdot
.54566 .6468 Mdot
.37253 .40172 Mdot
.52608 .64866 Mdot
.34004 .57275 Mdot
.50043 .67362 Mdot
.38948 .67514 Mdot
.349 .58684 Mdot
.35396 .38335 Mdot
.53369 .39731 Mdot
.38873 .5715 Mdot
.72137 .41692 Mdot
.6727 .56797 Mdot
.57384 .84165 Mdot
.5303 .39493 Mdot
.23694 .55901 Mdot
.52655 .47968 Mdot
.50462 .63314 Mdot
.25562 .30627 Mdot
.36886 .3825 Mdot
.68924 .55573 Mdot
.34853 .37253 Mdot
.74171 .36421 Mdot
.66305 .57066 Mdot
.56975 .8244 Mdot
.57029 .57575 Mdot
.73931 .38379 Mdot
.61473 .4528 Mdot
.74787 .4262 Mdot
.517 .69397 Mdot
.37914 .59789 Mdot
.37235 .71039 Mdot
.58693 .44237 Mdot
.57784 .19251 Mdot
.36433 .37323 Mdot
.55243 .63093 Mdot
.36305 .57679 Mdot
.39842 .59337 Mdot
.52825 .37005 Mdot
.65374 .65491 Mdot
.58814 .43459 Mdot
.3945 .70241 Mdot
.6782 .29744 Mdot
.30575 .34667 Mdot
.56586 .38987 Mdot
.53028 .68669 Mdot
.55588 .36804 Mdot
.64834 .5343 Mdot
.73677 .28926 Mdot
.55758 .33062 Mdot
.33546 .64811 Mdot
.6647 .61419 Mdot
.31407 .40685 Mdot
.56372 .49774 Mdot
.36008 .66156 Mdot
.56993 .37837 Mdot
.11895 .484 Mdot
.67058 .58315 Mdot
.69635 .67778 Mdot
.51782 .41505 Mdot
.51535 .38475 Mdot
.45748 .56869 Mdot
.21888 .53568 Mdot
.55931 .7354 Mdot
.56204 .43135 Mdot
.69899 .39622 Mdot
.37093 .56292 Mdot
.61401 .41225 Mdot
.55988 .39684 Mdot
.37575 .30451 Mdot
.40048 .59195 Mdot
.5287 .63913 Mdot
.53786 .69508 Mdot
.48528 .64163 Mdot
.65865 .53365 Mdot
.31343 .55689 Mdot
.7351 .49182 Mdot
.4432 .18388 Mdot
.68962 .58022 Mdot
.52861 .42375 Mdot
.70429 .60318 Mdot
.56556 .36454 Mdot
.66072 .55406 Mdot
.40174 .59375 Mdot
.33812 .38369 Mdot
.32269 .50222 Mdot
.54355 .69079 Mdot
.61898 .36089 Mdot
.66773 .5412 Mdot
.35741 .38692 Mdot
.76314 .53934 Mdot
.31674 .40916 Mdot
.36463 .59417 Mdot
.30889 .57011 Mdot
.66456 .5522 Mdot
.3399 .42179 Mdot
.32122 .63316 Mdot
.46535 .83551 Mdot
.55577 .46891 Mdot
.29899 .56674 Mdot
.30767 .39664 Mdot
.31472 .43632 Mdot
.30374 .3926 Mdot
.56155 .44602 Mdot
.45027 .47159 Mdot
.58809 .35357 Mdot
.37797 .5669 Mdot
.51725 .64221 Mdot
.63267 .2349 Mdot
.47675 .72038 Mdot
.49078 .48379 Mdot
.50331 .42621 Mdot
.57842 .41743 Mdot
.56057 .39161 Mdot
.56129 .33948 Mdot
.3606 .67978 Mdot
.57927 .43651 Mdot
.37843 .57914 Mdot
.54801 .67158 Mdot
.61269 .37803 Mdot
.57013 .62557 Mdot
.55215 .79377 Mdot
.67773 .59066 Mdot
.35733 .54214 Mdot
.77906 .32392 Mdot
.35398 .38663 Mdot
.48749 .65827 Mdot
.54572 .68175 Mdot
.66458 .54638 Mdot
.3727 .60634 Mdot
.31856 .41141 Mdot
.68012 .33531 Mdot
.64839 .54208 Mdot
.56239 .413 Mdot
.44368 .45677 Mdot
.61456 .20526 Mdot
.61335 .38366 Mdot
.60254 .3998 Mdot
.56041 .68867 Mdot
.70579 .66218 Mdot
.53875 .13579 Mdot
.74847 .49133 Mdot
.66851 .55708 Mdot
.6459 .58718 Mdot
.38052 .40638 Mdot
.56276 .34419 Mdot
.36974 .55952 Mdot
.35583 .4749 Mdot
.29183 .61397 Mdot
.2654 .42613 Mdot
.19106 .49342 Mdot
.60505 .38553 Mdot
.27632 .69264 Mdot
.58218 .41469 Mdot
.31067 .3756 Mdot
.3694 .40353 Mdot
.3506 .39809 Mdot
.37826 .59757 Mdot
.46049 .30264 Mdot
.38427 .58978 Mdot
.76427 .28166 Mdot
.31489 .38812 Mdot
.56403 .57726 Mdot
.51087 .6681 Mdot
.52851 .46532 Mdot
.68325 .57149 Mdot
.30327 .57705 Mdot
.64104 .36033 Mdot
.32324 .28121 Mdot
.55748 .64038 Mdot
.35115 .38199 Mdot
.31278 .70276 Mdot
.81732 .43652 Mdot
.40117 .47154 Mdot
.6446 .40949 Mdot
.76857 .49963 Mdot
.65831 .56108 Mdot
.18886 .45631 Mdot
.68041 .5793 Mdot
.34731 .60167 Mdot
.54598 .37818 Mdot
.5399 .38968 Mdot
.60787 .38568 Mdot
.54496 .42908 Mdot
.34804 .62013 Mdot
.52805 .44629 Mdot
.29474 .27468 Mdot
.54953 .68677 Mdot
.63654 .48827 Mdot
.67925 .57719 Mdot
.39773 .62461 Mdot
.54879 .67208 Mdot
.38166 .73319 Mdot
.73549 .43464 Mdot
.56682 .38681 Mdot
.60621 .39437 Mdot
.70673 .27624 Mdot
.59285 .36853 Mdot
.51591 .46288 Mdot
.55566 .67349 Mdot
.4927 .47391 Mdot
.67913 .58872 Mdot
.65282 .59138 Mdot
.34731 .58561 Mdot
.37114 .40522 Mdot
.66648 .58147 Mdot
.50915 .6651 Mdot
.50466 .42909 Mdot
.52033 .43911 Mdot
.3082 .39514 Mdot
.71837 .27806 Mdot
.63877 .5408 Mdot
.40646 .7758 Mdot
.36128 .38267 Mdot
.39605 .40361 Mdot
.59102 .42977 Mdot
.20389 .4407 Mdot
.33461 .45089 Mdot
.69056 .55145 Mdot
.39432 .6262 Mdot
.76349 .47473 Mdot
.37701 .62013 Mdot
.35565 .41628 Mdot
.52793 .3775 Mdot
.36818 .39368 Mdot
.56994 .3844 Mdot
.83749 .45098 Mdot
.54085 .39487 Mdot
.42377 .18786 Mdot
.67968 .47883 Mdot
.527 .67914 Mdot
.3672 .73468 Mdot
.51266 .67442 Mdot
.3529 .37714 Mdot
.51142 .39395 Mdot
.68161 .55249 Mdot
.51675 .79601 Mdot
.34379 .46485 Mdot
.52713 .62777 Mdot
.55642 .6273 Mdot
.3788 .62207 Mdot
.60072 .36877 Mdot
.58643 .4326 Mdot
.53964 .66784 Mdot
.27934 .35591 Mdot
.35221 .42729 Mdot
.55612 .37673 Mdot
.57906 .42148 Mdot
.52311 .67771 Mdot
.44701 .83229 Mdot
.57106 .30682 Mdot
.54743 .38295 Mdot
.53123 .75246 Mdot
.39311 .58386 Mdot
.54088 .46894 Mdot
.51074 .37193 Mdot
.65308 .56662 Mdot
.44784 .22984 Mdot
.76187 .35947 Mdot
.4036 .59735 Mdot
.54788 .68322 Mdot
.56702 .37677 Mdot
.53356 .6869 Mdot
.52319 .44288 Mdot
.21833 .5238 Mdot
.49278 .67319 Mdot
.56005 .3562 Mdot
.61685 .44532 Mdot
.33685 .37324 Mdot
.60543 .38888 Mdot
.45097 .36679 Mdot
.54326 .63293 Mdot
.52637 .37289 Mdot
.57144 .2514 Mdot
.37851 .61172 Mdot
.62037 .44699 Mdot
.64137 .54949 Mdot
.67682 .32572 Mdot
.26603 .52602 Mdot
.74528 .62658 Mdot
.65223 .59237 Mdot
.57108 .44392 Mdot
.55696 .63058 Mdot
.35275 .556 Mdot
.38809 .20029 Mdot
.60898 .42326 Mdot
.35075 .60494 Mdot
.36065 .57072 Mdot
.67211 .55446 Mdot
.15927 .59074 Mdot
.52227 .42194 Mdot
.54777 .42269 Mdot
.41694 .33132 Mdot
.35272 .44281 Mdot
.54011 .40448 Mdot
.52561 .40773 Mdot
.37651 .57559 Mdot
.59977 .47713 Mdot
.54082 .29027 Mdot
.55417 .21912 Mdot
.3318 .56116 Mdot
.30549 .46978 Mdot
.50306 .68327 Mdot
.65488 .58641 Mdot
.32199 .39799 Mdot
.67275 .54365 Mdot
.50139 .65771 Mdot
.52695 .40578 Mdot
.34075 .60243 Mdot
.43197 .36836 Mdot
.36023 .56017 Mdot
.73114 .61865 Mdot
.3103 .41769 Mdot
.37718 .5192 Mdot
.12378 .51574 Mdot
.45709 .76088 Mdot
.43165 .61522 Mdot
.65754 .56502 Mdot
.47409 .69186 Mdot
.57984 .42002 Mdot
.18428 .46513 Mdot
.53033 .42405 Mdot
.56034 .24452 Mdot
.55503 .68205 Mdot
.56106 .67958 Mdot
.54742 .37976 Mdot
.67683 .29977 Mdot
.34997 .55601 Mdot
.39745 .59721 Mdot
.5508 .35667 Mdot
.36691 .59771 Mdot
.55127 .41573 Mdot
.55287 .6655 Mdot
.19718 .38377 Mdot
.56854 .40952 Mdot
.54926 .33796 Mdot
.22582 .52525 Mdot
.52808 .82027 Mdot
.6551 .62004 Mdot
.33101 .78587 Mdot
.80946 .40635 Mdot
.36811 .59646 Mdot
.57134 .34918 Mdot
.29804 .46461 Mdot
.56581 .68235 Mdot
.3135 .6273 Mdot
.53193 .40712 Mdot
.53057 .41825 Mdot
.58633 .44519 Mdot
.59732 .41015 Mdot
.17605 .55478 Mdot
.34185 .46747 Mdot
.45324 .25883 Mdot
.60025 .3806 Mdot
.73435 .41287 Mdot
.34422 .59361 Mdot
.40721 .4098 Mdot
.6942 .57129 Mdot
.60546 .38691 Mdot
.32932 .35808 Mdot
.33236 .59628 Mdot
.75764 .26872 Mdot
.34676 .60461 Mdot
.53382 .64311 Mdot
.34004 .56703 Mdot
.58389 .40281 Mdot
.3327 .40553 Mdot
.42 .51692 Mdot
.45012 .73354 Mdot
.55806 .6697 Mdot
.5752 .39716 Mdot
.54728 .583 Mdot
.55862 .64869 Mdot
.57177 .7978 Mdot
.32884 .39948 Mdot
.69742 .40633 Mdot
.37002 .3977 Mdot
.54064 .36256 Mdot
.53894 .36459 Mdot
.32395 .58343 Mdot
.33878 .57203 Mdot
.3705 .39947 Mdot
.1669 .62823 Mdot
.63838 .54357 Mdot
.35333 .40062 Mdot
.61036 .35137 Mdot
.43861 .48713 Mdot
.33657 .40327 Mdot
.61524 .55695 Mdot
.36754 .57128 Mdot
.38274 .42146 Mdot
.59989 .44053 Mdot
.77155 .43207 Mdot
.63485 .57441 Mdot
.51326 .69788 Mdot
.7485 .54049 Mdot
.53836 .62764 Mdot
.38707 .62705 Mdot
.51419 .67589 Mdot
.37679 .56889 Mdot
.2617 .55156 Mdot
.30083 .35818 Mdot
.44072 .59732 Mdot
.36453 .62517 Mdot
.51487 .67346 Mdot
.54912 .37392 Mdot
.68547 .61424 Mdot
.53752 .35684 Mdot
.54475 .44838 Mdot
.38862 .58313 Mdot
.33148 .37682 Mdot
.33641 .44948 Mdot
.72583 .36927 Mdot
.37153 .41287 Mdot
.53755 .63444 Mdot
.32838 .26677 Mdot
.42834 .66567 Mdot
.38224 .6174 Mdot
.33462 .58098 Mdot
.5748 .36304 Mdot
.53095 .66656 Mdot
.55942 .67229 Mdot
.37324 .62101 Mdot
.22519 .44334 Mdot
.53044 .35255 Mdot
.30705 .4319 Mdot
.3607 .44067 Mdot
.34935 .40951 Mdot
.30233 .3969 Mdot
.5631 .2992 Mdot
.34764 .57348 Mdot
.33866 .37588 Mdot
.577 .36266 Mdot
.53074 .41324 Mdot
.34242 .48081 Mdot
.64013 .57685 Mdot
.61288 .37484 Mdot
.5717 .46684 Mdot
.60461 .42072 Mdot
.49727 .65438 Mdot
.47716 .37894 Mdot
.4922 .65954 Mdot
.56449 .64834 Mdot
.5668 .65937 Mdot
.38616 .67396 Mdot
.70323 .29015 Mdot
.80513 .4703 Mdot
.51913 .3873 Mdot
.30864 .72242 Mdot
.5233 .65884 Mdot
.29556 .28969 Mdot
.27718 .59739 Mdot
.59598 .43462 Mdot
.56929 .74024 Mdot
.53677 .67142 Mdot
.37445 .39102 Mdot
.53466 .40185 Mdot
.49183 .63507 Mdot
.63795 .55265 Mdot
.53087 .36563 Mdot
.49354 .67876 Mdot
.33608 .42084 Mdot
.68597 .54353 Mdot
.37991 .43023 Mdot
.56717 .66097 Mdot
.63303 .42469 Mdot
.30168 .2149 Mdot
.52406 .60714 Mdot
.3924 .79089 Mdot
.626 .47544 Mdot
.55363 .37499 Mdot
.49353 .63916 Mdot
.39432 .4194 Mdot
.38969 .62584 Mdot
.54162 .54182 Mdot
.37147 .4292 Mdot
.56108 .6797 Mdot
.52077 .62535 Mdot
.55806 .67028 Mdot
.34854 .43902 Mdot
.6163 .37213 Mdot
.36212 .43117 Mdot
.34275 .56381 Mdot
.59114 .38331 Mdot
.808 .536 Mdot
.29079 .68709 Mdot
.36603 .38621 Mdot
.52287 .63537 Mdot
.65181 .59607 Mdot
.5781 .41112 Mdot
.29246 .69634 Mdot
.55243 .37146 Mdot
.38604 .57688 Mdot
.40466 .24848 Mdot
.42441 .39142 Mdot
.5683 .35206 Mdot
.57787 .36554 Mdot
.39675 .59791 Mdot
.57227 .4003 Mdot
.59793 .36701 Mdot
.38565 .67691 Mdot
.34807 .43511 Mdot
.56767 .41807 Mdot
.51252 .64937 Mdot
.42938 .68917 Mdot
.53729 .3463 Mdot
.45427 .66043 Mdot
.69288 .40271 Mdot
.39501 .26103 Mdot
.52966 .42246 Mdot
.44129 .4357 Mdot
.59429 .42022 Mdot
.55356 .43874 Mdot
.57327 .3668 Mdot
.20164 .6186 Mdot
.4947 .67877 Mdot
.53983 .68292 Mdot
.64063 .58355 Mdot
.6933 .40458 Mdot
.65046 .57127 Mdot
.36428 .56878 Mdot
.66498 .66386 Mdot
.49206 .66173 Mdot
.35017 .42016 Mdot
.56591 .44133 Mdot
.52464 .60745 Mdot
.60168 .42477 Mdot
.5836 .40058 Mdot
.53879 .62037 Mdot
.50198 .6852 Mdot
.72258 .65684 Mdot
.63628 .56904 Mdot
.34796 .39399 Mdot
.59792 .36202 Mdot
.65578 .53941 Mdot
.52531 .42033 Mdot
.71643 .47571 Mdot
.34704 .39715 Mdot
.3521 .43417 Mdot
.33316 .44925 Mdot
.52763 .40194 Mdot
.58077 .40592 Mdot
.38511 .58989 Mdot
.36115 .37866 Mdot
.37454 .61255 Mdot
.52949 .55446 Mdot
.59927 .75146 Mdot
.53179 .40746 Mdot
.31984 .5375 Mdot
.64315 .56952 Mdot
.52265 .62902 Mdot
.62934 .21574 Mdot
.64008 .58315 Mdot
.56759 .38243 Mdot
.55864 .63796 Mdot
.6533 .55282 Mdot
.67351 .36543 Mdot
.74721 .27999 Mdot
.66517 .59802 Mdot
.57768 .36298 Mdot
.61231 .46619 Mdot
.31726 .77497 Mdot
.66098 .59568 Mdot
.33845 .58131 Mdot
.52812 .40024 Mdot
.2873 .40453 Mdot
.67105 .54192 Mdot
.51981 .76898 Mdot
.54267 .67311 Mdot
.76818 .41236 Mdot
.60935 .3329 Mdot
.27256 .35314 Mdot
.64943 .58733 Mdot
.32163 .40913 Mdot
.50873 .46073 Mdot
.59258 .42727 Mdot
.6534 .59389 Mdot
.38564 .63714 Mdot
.547 .65875 Mdot
.43326 .70833 Mdot
.34975 .43937 Mdot
.37512 .63915 Mdot
.51532 .63593 Mdot
.4175 .78023 Mdot
.48244 .20256 Mdot
.5784 .47352 Mdot
.29353 .74242 Mdot
.30158 .64553 Mdot
.61761 .42113 Mdot
.68443 .59819 Mdot
.39351 .57664 Mdot
.34217 .60798 Mdot
.36103 .5942 Mdot
.25976 .57152 Mdot
.41108 .45907 Mdot
.48825 .67307 Mdot
.31176 .58259 Mdot
.65347 .58527 Mdot
.76016 .46017 Mdot
.53932 .4474 Mdot
.57599 .41687 Mdot
.58656 .35843 Mdot
.60851 .39167 Mdot
.58497 .42687 Mdot
.36652 .60591 Mdot
.25208 .54929 Mdot
.38436 .47957 Mdot
.34237 .40092 Mdot
.70593 .65101 Mdot
.51251 .66314 Mdot
.49334 .69215 Mdot
.64749 .55081 Mdot
.4783 .77068 Mdot
.56906 .62315 Mdot
.52694 .64713 Mdot
.62192 .40542 Mdot
.35788 .42826 Mdot
.51945 .46216 Mdot
.57775 .36431 Mdot
.54012 .63866 Mdot
.47287 .56636 Mdot
.5052 .31555 Mdot
.68797 .52757 Mdot
.69503 .54745 Mdot
.42499 .46723 Mdot
.63924 .58554 Mdot
.50822 .40862 Mdot
.26254 .30435 Mdot
.50083 .65814 Mdot
.5363 .65455 Mdot
.64219 .57617 Mdot
.20346 .43462 Mdot
.32138 .39284 Mdot
.34587 .52582 Mdot
.36074 .56328 Mdot
.5321 .3726 Mdot
.53076 .19528 Mdot
.60878 .49678 Mdot
.64252 .65977 Mdot
.35559 .59684 Mdot
.52041 .68444 Mdot
.50388 .39313 Mdot
.58669 .37053 Mdot
.64305 .56442 Mdot
.7386 .66736 Mdot
.53605 .46468 Mdot
.65717 .79215 Mdot
.6741 .24239 Mdot
.74578 .35188 Mdot
.58903 .43092 Mdot
.34966 .43626 Mdot
.52259 .69755 Mdot
.66962 .58688 Mdot
.61658 .35945 Mdot
.77445 .35497 Mdot
.30977 .39614 Mdot
.3522 .5868 Mdot
.45815 .5365 Mdot
.75968 .48355 Mdot
.5494 .44544 Mdot
.52862 .41378 Mdot
.54957 .44011 Mdot
.66764 .18616 Mdot
.49425 .65962 Mdot
.37099 .38987 Mdot
.66984 .55286 Mdot
.36645 .41706 Mdot
.52679 .68213 Mdot
.44976 .59559 Mdot
.54186 .37531 Mdot
.30819 .40267 Mdot
.32098 .40751 Mdot
.35191 .61191 Mdot
.40512 .61455 Mdot
.48501 .54668 Mdot
.54172 .39594 Mdot
.54144 .61277 Mdot
.33798 .37458 Mdot
.43946 .45354 Mdot
.661 .57117 Mdot
.36997 .57141 Mdot
.60303 .38542 Mdot
.49524 .66863 Mdot
.5907 .458 Mdot
.33729 .38883 Mdot
.52695 .64794 Mdot
.65128 .74275 Mdot
.67137 .59338 Mdot
.53614 .41744 Mdot
.62656 .59261 Mdot
.5511 .68011 Mdot
.58254 .42006 Mdot
.43968 .79603 Mdot
.6155 .55669 Mdot
.48407 .74785 Mdot
.56387 .6572 Mdot
.40612 .65636 Mdot
.38034 .41086 Mdot
.25372 .60548 Mdot
.53655 .64907 Mdot
.37965 .76152 Mdot
.68946 .71654 Mdot
.50051 .41847 Mdot
.36093 .40897 Mdot
.30619 .65212 Mdot
.83435 .53265 Mdot
.38973 .80143 Mdot
.56264 .39467 Mdot
.51526 .61954 Mdot
.64706 .55723 Mdot
.38716 .61451 Mdot
.50479 .73629 Mdot
.6592 .52564 Mdot
.57176 .65367 Mdot
.57301 .36721 Mdot
.32799 .41515 Mdot
.37569 .58214 Mdot
.26761 .53163 Mdot
.50958 .65965 Mdot
.51671 .64028 Mdot
.51416 .37831 Mdot
.64928 .57653 Mdot
.27032 .65286 Mdot
.55473 .66743 Mdot
.68969 .26072 Mdot
.47724 .67346 Mdot
.64775 .54032 Mdot
.6011 .41245 Mdot
.72816 .36171 Mdot
.57009 .3436 Mdot
.47234 .81171 Mdot
.51369 .66704 Mdot
.34149 .39243 Mdot
.56863 .44844 Mdot
.59813 .24626 Mdot
.53582 .63385 Mdot
.44159 .46772 Mdot
.61197 .63267 Mdot
.3544 .56803 Mdot
.62476 .21377 Mdot
.542 .41189 Mdot
.3524 .5562 Mdot
.64447 .56421 Mdot
.54586 .38813 Mdot
.58362 .40656 Mdot
.32336 .37269 Mdot
.35675 .61456 Mdot
.71884 .66868 Mdot
.33295 .57947 Mdot
.34118 .59336 Mdot
.29638 .39752 Mdot
.56027 .42391 Mdot
.53253 .64151 Mdot
.53662 .6699 Mdot
.60273 .44091 Mdot
.18062 .38602 Mdot
.3173 .39515 Mdot
.53478 .69775 Mdot
.64707 .17069 Mdot
.61603 .43435 Mdot
.61047 .21271 Mdot
.73182 .67477 Mdot
.37489 .5626 Mdot
.57815 .36252 Mdot
.33757 .41981 Mdot
.58083 .70363 Mdot
.52003 .63876 Mdot
.58753 .44716 Mdot
.37455 .58288 Mdot
.63445 .56241 Mdot
.55224 .64228 Mdot
.65217 .65669 Mdot
.54396 .43205 Mdot
.57696 .7365 Mdot
.51857 .62084 Mdot
.81988 .61465 Mdot
.3706 .7233 Mdot
.36121 .40601 Mdot
.58618 .39929 Mdot
.37138 .3853 Mdot
.66582 .54998 Mdot
.46147 .53794 Mdot
.36894 .5746 Mdot
.47689 .35641 Mdot
.28558 .27089 Mdot
.55805 .67093 Mdot
.36994 .38689 Mdot
.56054 .35089 Mdot
.21454 .51572 Mdot
.5465 .41598 Mdot
.63029 .44668 Mdot
.72566 .58713 Mdot
.39336 .59949 Mdot
.36844 .562 Mdot
.59142 .41231 Mdot
.66669 .54505 Mdot
.51029 .66376 Mdot
.54411 .64916 Mdot
.7693 .71663 Mdot
.37397 .5139 Mdot
.64452 .26718 Mdot
.53171 .41948 Mdot
.56975 .64776 Mdot
.4556 .69475 Mdot
.35498 .60893 Mdot
.62824 .41255 Mdot
.54585 .62471 Mdot
.61012 .56937 Mdot
.6795 .3567 Mdot
.59269 .42452 Mdot
.58063 .34127 Mdot
.35278 .56372 Mdot
.42938 .43502 Mdot
.52625 .68875 Mdot
.5735 .46226 Mdot
.436 .57463 Mdot
.67636 .37415 Mdot
.70219 .24458 Mdot
.34832 .39402 Mdot
.64843 .64325 Mdot
.36737 .60644 Mdot
.55149 .33635 Mdot
.68063 .56215 Mdot
.56939 .67968 Mdot
.49437 .67199 Mdot
.572 .37506 Mdot
.50546 .41574 Mdot
.65634 .2474 Mdot
.35677 .42297 Mdot
.34487 .58998 Mdot
.53553 .3887 Mdot
.32807 .51225 Mdot
.60626 .38244 Mdot
.38705 .59754 Mdot
.28073 .23076 Mdot
.54711 .3518 Mdot
.54809 .42026 Mdot
.27868 .65994 Mdot
.36813 .43424 Mdot
.35612 .37348 Mdot
.5498 .18659 Mdot
.53195 .41932 Mdot
.65737 .23533 Mdot
.34717 .3893 Mdot
.32569 .38878 Mdot
.39563 .6896 Mdot
.57582 .4127 Mdot
.55312 .31802 Mdot
.37853 .56813 Mdot
.33957 .5914 Mdot
.35924 .43473 Mdot
.53846 .46734 Mdot
.40395 .60914 Mdot
.21638 .61358 Mdot
.52918 .66695 Mdot
.23954 .32166 Mdot
.31523 .39475 Mdot
.40119 .56329 Mdot
.3531 .60333 Mdot
.77086 .29904 Mdot
.57796 .69182 Mdot
.54524 .37546 Mdot
.53588 .42348 Mdot
.64566 .57959 Mdot
.58343 .35512 Mdot
.5609 .67948 Mdot
.36631 .59817 Mdot
.62288 .2842 Mdot
.35129 .39812 Mdot
.54592 .40303 Mdot
.51427 .78669 Mdot
.60484 .78666 Mdot
.66125 .63416 Mdot
.31466 .40537 Mdot
.36563 .39819 Mdot
.50606 .67669 Mdot
.51792 .6188 Mdot
.57088 .43107 Mdot
.3979 .60643 Mdot
.36225 .37983 Mdot
.38981 .59458 Mdot
.5013 .65584 Mdot
.53072 .64325 Mdot
.50142 .6887 Mdot
.53357 .44559 Mdot
.52084 .64563 Mdot
.61867 .75209 Mdot
.33462 .62102 Mdot
.29338 .40396 Mdot
.61884 .18937 Mdot
.27188 .53511 Mdot
.36004 .45626 Mdot
.66281 .5381 Mdot
.5563 .67484 Mdot
.34213 .56193 Mdot
.59727 .39351 Mdot
.61056 .4062 Mdot
.42412 .65043 Mdot
.33606 .56228 Mdot
.66696 .55201 Mdot
.35719 .55785 Mdot
.67185 .55388 Mdot
.59827 .69791 Mdot
.60649 .37516 Mdot
.52098 .44254 Mdot
.36217 .60341 Mdot
.5235 .64675 Mdot
.5422 .67841 Mdot
.67189 .59674 Mdot
.48739 .57878 Mdot
.55827 .64609 Mdot
.32603 .3855 Mdot
.53519 .3047 Mdot
.51364 .62637 Mdot
.53637 .40256 Mdot
.7338 .49676 Mdot
.18032 .46997 Mdot
.56169 .33948 Mdot
.39076 .68422 Mdot
.40673 .35429 Mdot
.58223 .44243 Mdot
.17997 .46027 Mdot
.39034 .65315 Mdot
.37689 .41603 Mdot
.5486 .68624 Mdot
.53013 .59804 Mdot
.49508 .36221 Mdot
.69401 .55108 Mdot
.62971 .39158 Mdot
.31082 .40674 Mdot
.35415 .36762 Mdot
.74721 .38393 Mdot
.42111 .80578 Mdot
.65139 .55516 Mdot
.64477 .55469 Mdot
.53783 .64763 Mdot
.57028 .84652 Mdot
.64016 .4181 Mdot
.6673 .55397 Mdot
.27448 .37086 Mdot
.57327 .36973 Mdot
.67705 .43217 Mdot
.55564 .51725 Mdot
.35501 .43687 Mdot
.73455 .40435 Mdot
.533 .63602 Mdot
.37255 .41297 Mdot
.3152 .50196 Mdot
.61168 .36793 Mdot
.34792 .3982 Mdot
.38783 .59127 Mdot
.40069 .73743 Mdot
.327 .38155 Mdot
.72708 .48487 Mdot
.38962 .61956 Mdot
.43734 .45539 Mdot
.71588 .37031 Mdot
.30144 .81985 Mdot
.36764 .6026 Mdot
.5203 .626 Mdot
.53781 .66939 Mdot
.54331 .64825 Mdot
.3649 .41951 Mdot
.55792 .67423 Mdot
.35686 .42141 Mdot
.32166 .76099 Mdot
.19148 .48405 Mdot
.66744 .55594 Mdot
.43366 .71084 Mdot
.34007 .41554 Mdot
.2917 .28659 Mdot
.14758 .40877 Mdot
.57609 .36094 Mdot
.33444 .60182 Mdot
.6644 .55606 Mdot
.64017 .79841 Mdot
.65336 .56343 Mdot
.73119 .32254 Mdot
.35202 .27209 Mdot
.55124 .40891 Mdot
.49831 .29145 Mdot
.6872 .57637 Mdot
.31889 .42008 Mdot
.58241 .41873 Mdot
.57808 .55551 Mdot
.64886 .56462 Mdot
.64097 .5456 Mdot
.56943 .4258 Mdot
.35122 .38187 Mdot
.5255 .63292 Mdot
.33539 .58776 Mdot
.682 .54841 Mdot
.58433 .48643 Mdot
.58556 .34617 Mdot
.54974 .36987 Mdot
.35927 .48815 Mdot
.67213 .60369 Mdot
.36892 .59615 Mdot
.17843 .6087 Mdot
.54786 .62222 Mdot
.58521 .57168 Mdot
.69273 .25275 Mdot
.36692 .66418 Mdot
.51536 .66721 Mdot
.5319 .68621 Mdot
.58403 .42853 Mdot
.55486 .50448 Mdot
.32977 .28407 Mdot
.48661 .59112 Mdot
.50383 .69415 Mdot
.54617 .65388 Mdot
.37102 .38046 Mdot
.74245 .35592 Mdot
.60826 .34714 Mdot
.40341 .596 Mdot
.49579 .67686 Mdot
.20512 .53992 Mdot
.65111 .58085 Mdot
.3573 .26126 Mdot
.60855 .37663 Mdot
.5417 .37881 Mdot
.3675 .58066 Mdot
.38325 .58838 Mdot
.59461 .66579 Mdot
.73925 .34294 Mdot
.41153 .36182 Mdot
.24785 .52928 Mdot
.3945 .27105 Mdot
.36097 .37231 Mdot
.36569 .38591 Mdot
.4611 .74656 Mdot
.33207 .58725 Mdot
.57744 .44558 Mdot
.37149 .40298 Mdot
.58724 .58914 Mdot
.49778 .33288 Mdot
.68284 .32429 Mdot
.62654 .22736 Mdot
.57128 .3875 Mdot
.3442 .43127 Mdot
.36607 .43606 Mdot
.32909 .43948 Mdot
.41236 .64695 Mdot
.56127 .43119 Mdot
.56754 .391 Mdot
.58177 .43905 Mdot
.20748 .47361 Mdot
.55861 .43639 Mdot
.25119 .59528 Mdot
.46577 .52992 Mdot
.4664 .22177 Mdot
.57211 .46335 Mdot
.36927 .55611 Mdot
.53658 .43752 Mdot
.66692 .54575 Mdot
.56406 .36012 Mdot
.68078 .32231 Mdot
.34943 .59671 Mdot
.55896 .30571 Mdot
.26586 .5489 Mdot
.60101 .43554 Mdot
.68778 .54866 Mdot
.29123 .62354 Mdot
.81983 .51629 Mdot
.68223 .61279 Mdot
.3239 .38672 Mdot
.52353 .66653 Mdot
.34151 .56134 Mdot
.5324 .64865 Mdot
.53492 .45344 Mdot
.45453 .75054 Mdot
.6581 .77388 Mdot
.53352 .5623 Mdot
.60818 .39291 Mdot
.62299 .35516 Mdot
.33172 .38581 Mdot
.55 .62539 Mdot
.34022 .45531 Mdot
.55926 .44632 Mdot
.67347 .56539 Mdot
.64508 .56686 Mdot
.54397 .54514 Mdot
.77244 .65762 Mdot
.20696 .57892 Mdot
.36953 .58423 Mdot
.55402 .66202 Mdot
.68332 .57443 Mdot
.35115 .74809 Mdot
.41028 .60861 Mdot
.39335 .58774 Mdot
.34776 .59334 Mdot
.52278 .39663 Mdot
.49342 .67653 Mdot
.47271 .22065 Mdot
.56879 .66627 Mdot
.57472 .40032 Mdot
.49673 .65269 Mdot
.55202 .63146 Mdot
.67586 .58125 Mdot
.34561 .59324 Mdot
.50246 .66122 Mdot
.53559 .36618 Mdot
.35134 .38724 Mdot
.43115 .60245 Mdot
.66634 .48047 Mdot
.43335 .80741 Mdot
.66058 .41443 Mdot
.34257 .44092 Mdot
.82595 .54154 Mdot
.38997 .57856 Mdot
.22072 .45204 Mdot
.72383 .65258 Mdot
.51253 .39506 Mdot
.18621 .36727 Mdot
.49506 .69549 Mdot
.54619 .62739 Mdot
.59973 .41348 Mdot
.4724 .66075 Mdot
.54685 .40782 Mdot
.5064 .64344 Mdot
.4611 .68508 Mdot
.31614 .3625 Mdot
.52028 .65067 Mdot
.56929 .46103 Mdot
.58629 .41014 Mdot
.35369 .43534 Mdot
.50155 .62974 Mdot
.61785 .35905 Mdot
.78938 .69846 Mdot
.384 .59599 Mdot
.32008 .65161 Mdot
.73234 .51102 Mdot
.36857 .60765 Mdot
.35344 .4029 Mdot
.54117 .44699 Mdot
.6444 .56272 Mdot
.33978 .41664 Mdot
.6644 .31102 Mdot
.66958 .59203 Mdot
.23355 .3162 Mdot
.35949 .43863 Mdot
.53177 .62688 Mdot
.6768 .55235 Mdot
.58021 .35146 Mdot
.56621 .68359 Mdot
.3775 .73897 Mdot
.51562 .66488 Mdot
.58303 .4339 Mdot
.46994 .72674 Mdot
.34376 .58928 Mdot
.5597 .39295 Mdot
.54658 .62997 Mdot
.39531 .68291 Mdot
.51964 .39572 Mdot
.59195 .41724 Mdot
.70647 .25953 Mdot
.37332 .22856 Mdot
.65784 .5676 Mdot
.37524 .43804 Mdot
.57623 .36213 Mdot
.64375 .54587 Mdot
.63331 .7195 Mdot
.52847 .38944 Mdot
.30936 .39507 Mdot
.62833 .42065 Mdot
.50679 .62556 Mdot
.37744 .60941 Mdot
.52386 .5778 Mdot
.63825 .55225 Mdot
.36375 .83058 Mdot
.5049 .68217 Mdot
.5161 .43185 Mdot
.60266 .37809 Mdot
.75439 .56852 Mdot
.37545 .41696 Mdot
.31168 .32518 Mdot
.53606 .41787 Mdot
.2107 .46081 Mdot
.54796 .39067 Mdot
.50292 .70101 Mdot
.32187 .39181 Mdot
.54961 .42571 Mdot
.40201 .54213 Mdot
.54284 .34098 Mdot
.63866 .57853 Mdot
.28469 .67824 Mdot
.61188 .36417 Mdot
.25004 .27395 Mdot
.5941 .5399 Mdot
.51843 .65015 Mdot
.5651 .78147 Mdot
.7764 .72841 Mdot
.26276 .57013 Mdot
.36503 .41623 Mdot
.71345 .71056 Mdot
.53202 .64134 Mdot
.55077 .76965 Mdot
.83047 .53175 Mdot
.59097 .40451 Mdot
.55102 .44617 Mdot
.77035 .51291 Mdot
.56666 .65455 Mdot
.55363 .62054 Mdot
.51099 .43663 Mdot
.55895 .3357 Mdot
.52494 .64188 Mdot
.51812 .38161 Mdot
.53488 .46129 Mdot
.3358 .60312 Mdot
.31138 .3964 Mdot
.39422 .60168 Mdot
.40234 .60888 Mdot
.24361 .65845 Mdot
.60006 .5406 Mdot
.38571 .60055 Mdot
.38736 .57134 Mdot
.67857 .4258 Mdot
.69491 .31059 Mdot
.67402 .54413 Mdot
.78758 .66222 Mdot
.5453 .65648 Mdot
.55733 .42666 Mdot
.3612 .43976 Mdot
.4198 .3736 Mdot
.6588 .71732 Mdot
.26918 .3117 Mdot
.56903 .44729 Mdot
.5335 .63299 Mdot
.40437 .64942 Mdot
.51923 .46315 Mdot
.49637 .62535 Mdot
.53319 .39332 Mdot
.56111 .68126 Mdot
.58756 .28102 Mdot
.37973 .76085 Mdot
.4963 .61521 Mdot
.30378 .42772 Mdot
.54002 .3842 Mdot
.31138 .40924 Mdot
.3577 .60902 Mdot
.67312 .5456 Mdot
.65689 .57081 Mdot
.57776 .42272 Mdot
.64459 .39329 Mdot
.59476 .71742 Mdot
.57957 .41105 Mdot
.57722 .37106 Mdot
.39303 .65303 Mdot
.57602 .36716 Mdot
.61363 .3997 Mdot
.59782 .42974 Mdot
.57211 .45255 Mdot
.34045 .59201 Mdot
.48362 .77184 Mdot
.49429 .37037 Mdot
.50776 .35669 Mdot
.38826 .6253 Mdot
.73066 .66642 Mdot
.4019 .59774 Mdot
.82637 .51078 Mdot
.37067 .5615 Mdot
.66578 .56968 Mdot
.73599 .60438 Mdot
.61798 .33612 Mdot
.31885 .37849 Mdot
.40828 .58908 Mdot
.66473 .54816 Mdot
.36335 .59587 Mdot
.50946 .63682 Mdot
.71337 .25706 Mdot
.37669 .3713 Mdot
.34227 .47224 Mdot
.30078 .62181 Mdot
.43873 .76431 Mdot
.50304 .67576 Mdot
.31557 .42037 Mdot
.50836 .3072 Mdot
.60976 .39217 Mdot
.64518 .54465 Mdot
.5727 .42946 Mdot
.34578 .60585 Mdot
.53636 .63886 Mdot
.36236 .78354 Mdot
.64299 .56498 Mdot
.64923 .20629 Mdot
.53947 .67687 Mdot
.61446 .41381 Mdot
.40395 .60744 Mdot
.54959 .16632 Mdot
.39346 .59612 Mdot
.33263 .30855 Mdot
.37857 .39819 Mdot
.35068 .79984 Mdot
.35081 .41508 Mdot
.38789 .75051 Mdot
.49847 .13052 Mdot
.50046 .78347 Mdot
.3526 .38418 Mdot
.45304 .60344 Mdot
.56851 .37974 Mdot
.54846 .37039 Mdot
.36886 .76682 Mdot
.36653 .4411 Mdot
.59449 .37355 Mdot
.44038 .66587 Mdot
.37739 .64088 Mdot
.57973 .20777 Mdot
.51403 .67916 Mdot
.54283 .40815 Mdot
.33336 .55445 Mdot
.33956 .55774 Mdot
.53114 .69148 Mdot
.39318 .58579 Mdot
.5679 .39335 Mdot
.34173 .41555 Mdot
.47406 .69941 Mdot
.66457 .57818 Mdot
.59354 .82566 Mdot
.62978 .55618 Mdot
.51549 .66787 Mdot
.53821 .35613 Mdot
.53034 .64387 Mdot
.8537 .65722 Mdot
.56288 .38486 Mdot
.34572 .38946 Mdot
.58357 .37045 Mdot
.54407 .38232 Mdot
.57154 .45073 Mdot
.52082 .63546 Mdot
.70994 .54625 Mdot
.52836 .37202 Mdot
.36732 .57296 Mdot
.42647 .25077 Mdot
.61852 .3834 Mdot
.50577 .60154 Mdot
.69794 .33586 Mdot
.31102 .60878 Mdot
.38368 .41743 Mdot
.51757 .65554 Mdot
.35437 .39607 Mdot
.21576 .41699 Mdot
.35306 .40301 Mdot
.40057 .29615 Mdot
.5277 .29503 Mdot
.60773 .26035 Mdot
.58542 .25901 Mdot
.43631 .5399 Mdot
.37189 .43945 Mdot
.69343 .59867 Mdot
.35626 .37875 Mdot
.36648 .43224 Mdot
.21712 .25039 Mdot
.30633 .38544 Mdot
.53457 .40808 Mdot
.61929 .39181 Mdot
.43372 .77682 Mdot
.70644 .45442 Mdot
.59187 .38217 Mdot
.59623 .38155 Mdot
.68328 .56804 Mdot
.21733 .42833 Mdot
.48623 .75289 Mdot
.35564 .23901 Mdot
.61867 .77625 Mdot
.57165 .42753 Mdot
.57127 .35917 Mdot
.49195 .41017 Mdot
.42312 .1723 Mdot
.24861 .67598 Mdot
.2826 .3902 Mdot
.49594 .39686 Mdot
.49374 .79363 Mdot
.56248 .44952 Mdot
.52575 .40881 Mdot
.57009 .38468 Mdot
.53223 .64085 Mdot
.38227 .42511 Mdot
.57251 .45483 Mdot
.74498 .57468 Mdot
.52821 .40579 Mdot
.37247 .66815 Mdot
.46764 .84811 Mdot
.54182 .41261 Mdot
.38911 .39148 Mdot
.55256 .36832 Mdot
.36997 .4244 Mdot
.33092 .43189 Mdot
.49754 .40908 Mdot
.39034 .27326 Mdot
.38248 .38903 Mdot
.57542 .40068 Mdot
.51502 .6305 Mdot
.8149 .6169 Mdot
.58029 .43503 Mdot
.67064 .54289 Mdot
.53493 .42173 Mdot
.68021 .5405 Mdot
.58171 .37587 Mdot
.50838 .68604 Mdot
.38703 .35297 Mdot
.53757 .65367 Mdot
.28076 .72907 Mdot
.50124 .68603 Mdot
.68306 .21898 Mdot
.3334 .43916 Mdot
.44874 .71471 Mdot
.24118 .36164 Mdot
.32586 .6638 Mdot
.47177 .47484 Mdot
.42014 .50088 Mdot
.39819 .60463 Mdot
.37678 .40457 Mdot
.24499 .42545 Mdot
.69559 .67366 Mdot
.70185 .63376 Mdot
.55685 .64816 Mdot
.15866 .59628 Mdot
.22364 .3513 Mdot
.50759 .40243 Mdot
.47035 .31136 Mdot
.46087 .27439 Mdot
.56267 .45024 Mdot
.56069 .45385 Mdot
.55284 .59455 Mdot
.5261 .37167 Mdot
.32776 .51491 Mdot
.51641 .67234 Mdot
.66116 .54639 Mdot
.33839 .38526 Mdot
.63421 .56214 Mdot
.71404 .65815 Mdot
.41359 .49696 Mdot
.50345 .64738 Mdot
.59649 .34598 Mdot
.59802 .38898 Mdot
.36117 .42994 Mdot
.31379 .44907 Mdot
.34334 .37412 Mdot
.65872 .55606 Mdot
.52203 .67553 Mdot
.17568 .50171 Mdot
.60087 .39008 Mdot
.32189 .40614 Mdot
.48675 .48693 Mdot
.57889 .36379 Mdot
.35961 .60651 Mdot
.564 .37764 Mdot
.34722 .38182 Mdot
.57627 .36736 Mdot
.35307 .4155 Mdot
.52599 .66584 Mdot
.60491 .42857 Mdot
.59909 .41818 Mdot
.60129 .18733 Mdot
.67072 .55993 Mdot
.30861 .41358 Mdot
.57781 .57954 Mdot
.5883 .36256 Mdot
.40915 .70554 Mdot
.533 .39732 Mdot
.41187 .39223 Mdot
.51161 .41066 Mdot
.32686 .65427 Mdot
.53237 .33677 Mdot
.5725 .43598 Mdot
.55227 .52868 Mdot
.44829 .28316 Mdot
.60647 .3211 Mdot
.38389 .56569 Mdot
.30216 .40328 Mdot
.58738 .21452 Mdot
.50056 .71344 Mdot
.52522 .61405 Mdot
.74702 .43854 Mdot
.58909 .44673 Mdot
.55176 .41155 Mdot
.31037 .567 Mdot
.63893 .56258 Mdot
.31462 .40851 Mdot
.67193 .55412 Mdot
.64504 .21866 Mdot
.64829 .58805 Mdot
.49944 .69992 Mdot
.57673 .7378 Mdot
.17722 .54363 Mdot
.68298 .5711 Mdot
.34948 .38065 Mdot
.55769 .74961 Mdot
.61589 .42554 Mdot
.58947 .53592 Mdot
.67354 .57171 Mdot
.21686 .69491 Mdot
.61394 .40168 Mdot
.46936 .47005 Mdot
.38622 .60603 Mdot
.6815 .56372 Mdot
.38281 .62038 Mdot
.59674 .39834 Mdot
.48949 .75182 Mdot
.36497 .41486 Mdot
.37229 .62334 Mdot
.61688 .4504 Mdot
.66421 .55429 Mdot
.49408 .67434 Mdot
.32715 .55067 Mdot
.3995 .58734 Mdot
.75119 .65875 Mdot
.34695 .7834 Mdot
.52529 .67638 Mdot
.48492 .19981 Mdot
.36044 .55633 Mdot
.61791 .42204 Mdot
.22665 .41917 Mdot
.54377 .37602 Mdot
.23863 .6086 Mdot
.51299 .66062 Mdot
.45246 .76745 Mdot
.57456 .36214 Mdot
.56747 .44312 Mdot
.37539 .37307 Mdot
.54008 .66188 Mdot
.33553 .40589 Mdot
.30359 .41293 Mdot
.52724 .66705 Mdot
.3586 .40918 Mdot
.68415 .58217 Mdot
.29166 .47477 Mdot
.36062 .56258 Mdot
.35564 .57168 Mdot
.54465 .64962 Mdot
.51491 .65041 Mdot
.52804 .64734 Mdot
.56353 .37714 Mdot
.31531 .40063 Mdot
.58678 .39357 Mdot
.5283 .42156 Mdot
.42824 .24079 Mdot
.37654 .43064 Mdot
.57784 .38963 Mdot
.58577 .56163 Mdot
.56718 .51259 Mdot
.5097 .63254 Mdot
.38524 .60341 Mdot
.44261 .68379 Mdot
.36053 .72767 Mdot
.54172 .40466 Mdot
.61266 .54273 Mdot
.35144 .37955 Mdot
.64724 .56117 Mdot
.62917 .57437 Mdot
.65534 .56457 Mdot
.33725 .64168 Mdot
.3339 .44057 Mdot
.34985 .24596 Mdot
.54588 .41012 Mdot
.37326 .48923 Mdot
.28394 .36813 Mdot
.59606 .69075 Mdot
.38404 .60166 Mdot
.58625 .37057 Mdot
.52763 .57462 Mdot
.47112 .34958 Mdot
.54809 .3757 Mdot
.62298 .39831 Mdot
.62858 .75275 Mdot
.63381 .40232 Mdot
.34919 .36891 Mdot
.55477 .17127 Mdot
.57311 .35249 Mdot
.20168 .53689 Mdot
.61261 .8287 Mdot
.53911 .39696 Mdot
.55659 .44276 Mdot
.60723 .40441 Mdot
.56093 .36067 Mdot
.38723 .39262 Mdot
.70983 .41068 Mdot
.36615 .55681 Mdot
.37461 .48639 Mdot
.33751 .59729 Mdot
.53674 .69585 Mdot
.46048 .76857 Mdot
.37727 .39881 Mdot
.64523 .57887 Mdot
.58125 .80222 Mdot
.46594 .17946 Mdot
.52809 .68887 Mdot
.21671 .60895 Mdot
.6717 .56894 Mdot
.62107 .41585 Mdot
.69064 .56384 Mdot
.49337 .65312 Mdot
.35467 .56884 Mdot
.6197 .37554 Mdot
.36101 .38345 Mdot
.32275 .38391 Mdot
.5867 .36843 Mdot
.50993 .7973 Mdot
.36623 .61124 Mdot
.39864 .58272 Mdot
.52411 .39175 Mdot
.58253 .35257 Mdot
.34003 .40644 Mdot
.55141 .66797 Mdot
.62246 .25744 Mdot
.64485 .55108 Mdot
.53798 .44749 Mdot
.5715 .3659 Mdot
.6983 .25758 Mdot
.36845 .57133 Mdot
.50088 .62443 Mdot
.51239 .39918 Mdot
.23917 .52541 Mdot
.51308 .39603 Mdot
.49534 .42461 Mdot
.51518 .62967 Mdot
.4827 .39895 Mdot
.51551 .43709 Mdot
.38209 .36961 Mdot
.39286 .61252 Mdot
.3453 .39501 Mdot
.39941 .38148 Mdot
.28476 .45024 Mdot
.35807 .60378 Mdot
.57357 .38209 Mdot
.37965 .60047 Mdot
.52935 .38828 Mdot
.55423 .35547 Mdot
.3871 .59815 Mdot
.33651 .40665 Mdot
.70531 .71695 Mdot
.49761 .77811 Mdot
.55328 .36118 Mdot
.50237 .42303 Mdot
.703 .43137 Mdot
.70859 .55163 Mdot
.55709 .44661 Mdot
.34149 .38052 Mdot
.6017 .40152 Mdot
.36215 .61586 Mdot
.68663 .57621 Mdot
.35091 .38579 Mdot
.54095 .68152 Mdot
.51635 .68666 Mdot
.26582 .5546 Mdot
.56041 .64559 Mdot
.54522 .44496 Mdot
.38936 .43738 Mdot
.39737 .39507 Mdot
.54736 .82248 Mdot
.53062 .66853 Mdot
.67302 .54242 Mdot
.58951 .41858 Mdot
.77198 .43251 Mdot
.32953 .55857 Mdot
.17453 .3427 Mdot
.29025 .28529 Mdot
.69011 .58577 Mdot
.28419 .30704 Mdot
.50858 .68961 Mdot
.52701 .44917 Mdot
.66563 .54185 Mdot
.50667 .67713 Mdot
.53551 .37291 Mdot
.49656 .40905 Mdot
.31997 .32173 Mdot
.3955 .51281 Mdot
.38077 .59723 Mdot
.56204 .66892 Mdot
.69459 .5822 Mdot
.49153 .68797 Mdot
.32536 .43333 Mdot
.5611 .43369 Mdot
.52762 .36363 Mdot
.5509 .67338 Mdot
.53241 .612 Mdot
.57565 .3949 Mdot
.37263 .3868 Mdot
.5546 .59286 Mdot
.56978 .42268 Mdot
.37733 .51383 Mdot
.35543 .44692 Mdot
.51706 .6781 Mdot
.567 .44048 Mdot
.70536 .56388 Mdot
.54415 .67471 Mdot
.50688 .63449 Mdot
.5733 .35913 Mdot
.68093 .58596 Mdot
.5018 .39858 Mdot
.37248 .5648 Mdot
.18396 .62883 Mdot
.35976 .61539 Mdot
.46239 .67983 Mdot
.63415 .42558 Mdot
.2331 .48641 Mdot
.38101 .41722 Mdot
.73881 .38356 Mdot
.44141 .66942 Mdot
.53072 .46053 Mdot
.80547 .61034 Mdot
.39917 .55925 Mdot
.54666 .80973 Mdot
.79691 .49792 Mdot
.67513 .57787 Mdot
.36113 .59501 Mdot
.55595 .44285 Mdot
.33505 .60309 Mdot
.65915 .54014 Mdot
.28167 .72727 Mdot
.57822 .43844 Mdot
.32561 .38947 Mdot
.57129 .39171 Mdot
.31795 .39153 Mdot
.568 .35699 Mdot
.51011 .36631 Mdot
.4032 .66221 Mdot
.68005 .36481 Mdot
.51445 .40399 Mdot
.64755 .17681 Mdot
.50798 .4877 Mdot
.6522 .5462 Mdot
.58819 .40164 Mdot
.48622 .63589 Mdot
.3322 .5665 Mdot
.28345 .63621 Mdot
.53112 .63968 Mdot
.39648 .58362 Mdot
.35109 .40802 Mdot
.51775 .66102 Mdot
.5339 .69016 Mdot
.48181 .4013 Mdot
.68802 .58259 Mdot
.3513 .58323 Mdot
.54902 .42705 Mdot
.57702 .43828 Mdot
.48518 .19628 Mdot
.67156 .69283 Mdot
.33025 .45858 Mdot
.34916 .20846 Mdot
.30131 .41843 Mdot
.66093 .5493 Mdot
.5253 .6339 Mdot
.53313 .43057 Mdot
.56198 .39647 Mdot
.42192 .7018 Mdot
.35675 .37536 Mdot
.4693 .54492 Mdot
.26867 .35774 Mdot
.58326 .58969 Mdot
.69436 .37888 Mdot
.33988 .38344 Mdot
.69342 .38244 Mdot
.66084 .60114 Mdot
.74881 .71219 Mdot
.68272 .39407 Mdot
.3834 .60736 Mdot
.69253 .39435 Mdot
.31966 .4121 Mdot
.52917 .37323 Mdot
.52494 .62531 Mdot
.55287 .63196 Mdot
.33936 .39919 Mdot
.48433 .66058 Mdot
.66916 .58489 Mdot
.54842 .43634 Mdot
.36755 .2267 Mdot
.28548 .52405 Mdot
.54773 .64963 Mdot
.50773 .45454 Mdot
.34764 .59452 Mdot
.58632 .36761 Mdot
.68027 .57845 Mdot
.37209 .60231 Mdot
.73631 .33218 Mdot
.36603 .63613 Mdot
.58561 .41912 Mdot
.70349 .25667 Mdot
.36214 .60163 Mdot
.49321 .46891 Mdot
.56358 .42565 Mdot
.38005 .56995 Mdot
.471 .40533 Mdot
.39978 .74073 Mdot
.52676 .56037 Mdot
.83132 .532 Mdot
.50532 .54585 Mdot
.53949 .63236 Mdot
.41987 .75527 Mdot
.3058 .6569 Mdot
.3409 .56492 Mdot
.5136 .61609 Mdot
.61505 .51415 Mdot
.38616 .61943 Mdot
.62005 .41299 Mdot
.53581 .39445 Mdot
.26066 .68935 Mdot
.36185 .54401 Mdot
.38428 .75254 Mdot
.28023 .57608 Mdot
.5918 .36404 Mdot
.50445 .39114 Mdot
.56068 .40094 Mdot
.36691 .37382 Mdot
.37838 .58621 Mdot
.60576 .17092 Mdot
.36007 .609 Mdot
.38315 .24911 Mdot
.54409 .65231 Mdot
.51128 .67804 Mdot
.54066 .40872 Mdot
.45729 .45338 Mdot
.71662 .33567 Mdot
.5698 .3964 Mdot
.64466 .52264 Mdot
.2949 .7055 Mdot
.58321 .3543 Mdot
.38217 .40114 Mdot
.49582 .43619 Mdot
.56953 .48929 Mdot
.35968 .56234 Mdot
.65524 .58185 Mdot
.73622 .36555 Mdot
.34858 .57385 Mdot
.55279 .41064 Mdot
.24039 .4927 Mdot
.55029 .3823 Mdot
.54853 .36401 Mdot
.31658 .28223 Mdot
.63416 .58104 Mdot
.52884 .65536 Mdot
.6581 .56396 Mdot
.37445 .42196 Mdot
.157 .33414 Mdot
.64423 .58596 Mdot
.71915 .32985 Mdot
.2499 .69185 Mdot
.68937 .40644 Mdot
.31049 .40418 Mdot
.69358 .56901 Mdot
.3743 .61201 Mdot
.81329 .62264 Mdot
.32679 .33171 Mdot
.38695 .54254 Mdot
.56645 .41897 Mdot
.30229 .38018 Mdot
.32583 .37901 Mdot
.37445 .62438 Mdot
.32648 .42931 Mdot
.53759 .32441 Mdot
.53857 .36745 Mdot
.33382 .58363 Mdot
.25163 .51918 Mdot
.3784 .56021 Mdot
.44767 .58156 Mdot
.58398 .40485 Mdot
.34618 .38617 Mdot
.53879 .45049 Mdot
.37923 .44001 Mdot
.48998 .64078 Mdot
.57296 .34211 Mdot
.66629 .58616 Mdot
.22772 .50405 Mdot
.52739 .67786 Mdot
.59818 .58722 Mdot
.36388 .42942 Mdot
.33386 .63268 Mdot
.35112 .43527 Mdot
.39475 .42148 Mdot
.40335 .60212 Mdot
.33751 .42235 Mdot
.55502 .44139 Mdot
.56279 .55326 Mdot
.36473 .42313 Mdot
.36149 .58264 Mdot
.65423 .57886 Mdot
.34999 .41241 Mdot
.472 .65305 Mdot
.58761 .42355 Mdot
.51695 .63964 Mdot
.72428 .60973 Mdot
.3046 .38164 Mdot
.64116 .589 Mdot
.53167 .61341 Mdot
.64159 .54481 Mdot
.49027 .82609 Mdot
.3739 .63073 Mdot
.36099 .26934 Mdot
.66642 .52225 Mdot
.32389 .37599 Mdot
.72861 .61044 Mdot
.53001 .42144 Mdot
.58921 .42132 Mdot
.67406 .5383 Mdot
.32623 .37879 Mdot
.67866 .78264 Mdot
.63206 .45196 Mdot
.43506 .55423 Mdot
.4132 .60826 Mdot
.68024 .213 Mdot
.44097 .57054 Mdot
.57047 .85092 Mdot
.56007 .47131 Mdot
.55631 .62329 Mdot
.54763 .40059 Mdot
.42589 .6723 Mdot
.66506 .55716 Mdot
.45761 .63382 Mdot
.53003 .35549 Mdot
.52487 .65972 Mdot
.6019 .42138 Mdot
.54965 .53409 Mdot
.50905 .47376 Mdot
.66684 .53892 Mdot
.53809 .77351 Mdot
.30247 .39208 Mdot
.66773 .57662 Mdot
.49947 .66866 Mdot
.7069 .36589 Mdot
.5373 .37064 Mdot
.61928 .42744 Mdot
.58356 .59039 Mdot
.31358 .40082 Mdot
.53775 .62656 Mdot
.36853 .56442 Mdot
.64597 .57637 Mdot
.5965 .38859 Mdot
.52386 .41638 Mdot
.40114 .69997 Mdot
.34633 .59721 Mdot
.55871 .63468 Mdot
.39077 .60808 Mdot
.52654 .69371 Mdot
.53981 .36034 Mdot
.52201 .68503 Mdot
.56786 .45847 Mdot
.39456 .66158 Mdot
.34282 .27043 Mdot
.44893 .29609 Mdot
.51196 .66419 Mdot
.67814 .30077 Mdot
.34944 .59928 Mdot
.39227 .58971 Mdot
.20221 .62046 Mdot
.32625 .31082 Mdot
.46244 .18877 Mdot
.78368 .59661 Mdot
.33716 .58789 Mdot
.35165 .58892 Mdot
.51513 .64205 Mdot
.33896 .42414 Mdot
.30599 .42209 Mdot
.53021 .69341 Mdot
.73435 .50368 Mdot
.31472 .40832 Mdot
.7806 .65412 Mdot
.55073 .20157 Mdot
.58279 .45617 Mdot
.49565 .69985 Mdot
.64732 .56639 Mdot
.73134 .48597 Mdot
.55699 .53685 Mdot
.56905 .44452 Mdot
.75681 .41629 Mdot
.54913 .65757 Mdot
.43938 .43602 Mdot
.8227 .51697 Mdot
.60354 .42552 Mdot
.5592 .42739 Mdot
.55499 .40343 Mdot
.68082 .59357 Mdot
.34373 .32565 Mdot
.55887 .43854 Mdot
.73377 .5061 Mdot
.58844 .36498 Mdot
.48655 .45822 Mdot
.65702 .56889 Mdot
.67313 .38907 Mdot
.70467 .66926 Mdot
.55608 .17593 Mdot
.54809 .49518 Mdot
.36785 .56299 Mdot
.70812 .60753 Mdot
.39614 .59946 Mdot
.41196 .29593 Mdot
.67653 .42219 Mdot
.29546 .41308 Mdot
.5662 .44505 Mdot
.5151 .66864 Mdot
.32483 .37981 Mdot
.41111 .7303 Mdot
.18562 .29213 Mdot
.36357 .55982 Mdot
.66731 .8338 Mdot
.38227 .5734 Mdot
.53591 .69034 Mdot
.34112 .40607 Mdot
.54173 .29135 Mdot
.34464 .48488 Mdot
.35349 .4125 Mdot
.67522 .76082 Mdot
.28218 .39332 Mdot
.69594 .34109 Mdot
.33024 .36872 Mdot
.35783 .58705 Mdot
.31797 .63677 Mdot
.57352 .31254 Mdot
.53103 .41464 Mdot
.42525 .50064 Mdot
.70711 .33044 Mdot
.53096 .42289 Mdot
.51853 .67319 Mdot
.34143 .28057 Mdot
.74878 .42215 Mdot
.33154 .41884 Mdot
.37429 .63665 Mdot
.56524 .43169 Mdot
.56126 .36664 Mdot
.53198 .37334 Mdot
.30608 .26117 Mdot
.74575 .71557 Mdot
.53045 .37006 Mdot
.57742 .35702 Mdot
.52081 .66097 Mdot
.69169 .53731 Mdot
.5425 .75843 Mdot
.46409 .213 Mdot
.59257 .43769 Mdot
.66397 .5747 Mdot
.69258 .59315 Mdot
.51621 .38934 Mdot
.59392 .55012 Mdot
.24165 .48353 Mdot
.54996 .42826 Mdot
.343 .2828 Mdot
.59397 .63758 Mdot
.56689 .65474 Mdot
.54527 .67759 Mdot
.30987 .41273 Mdot
.54992 .68007 Mdot
.50256 .68264 Mdot
.53859 .29914 Mdot
.48712 .54296 Mdot
.42273 .6226 Mdot
.65653 .55562 Mdot
.55942 .39156 Mdot
.62569 .33243 Mdot
.23699 .51389 Mdot
.3981 .6107 Mdot
.35987 .38755 Mdot
.33171 .56455 Mdot
.67111 .61314 Mdot
.28412 .43779 Mdot
.55354 .65168 Mdot
.34012 .57879 Mdot
.32166 .59282 Mdot
.66117 .57467 Mdot
.36249 .61874 Mdot
.31518 .58373 Mdot
.59454 .34992 Mdot
.45746 .32799 Mdot
.57356 .40204 Mdot
.58397 .80715 Mdot
.34626 .58852 Mdot
.34357 .6536 Mdot
.55065 .41831 Mdot
.54235 .6745 Mdot
.53748 .3125 Mdot
.52806 .41018 Mdot
.5526 .6747 Mdot
.50836 .39902 Mdot
.63155 .55401 Mdot
.37134 .44249 Mdot
.35235 .4841 Mdot
.14901 .58288 Mdot
.68971 .58032 Mdot
.41314 .72554 Mdot
.56416 .44792 Mdot
.39986 .80803 Mdot
.34666 .41313 Mdot
.52076 .42744 Mdot
.73246 .40326 Mdot
.35695 .42419 Mdot
.35862 .39691 Mdot
.56954 .37363 Mdot
.38574 .60836 Mdot
.52409 .67866 Mdot
.65614 .57259 Mdot
.55819 .83913 Mdot
.57423 .41713 Mdot
.60118 .41277 Mdot
.67033 .57298 Mdot
.34819 .603 Mdot
.51387 .39788 Mdot
.7676 .55171 Mdot
.70578 .76939 Mdot
.39018 .58065 Mdot
.61526 .42034 Mdot
.407 .32117 Mdot
.60737 .48367 Mdot
.35244 .81387 Mdot
.5937 .53841 Mdot
.52368 .65359 Mdot
.63783 .38104 Mdot
.23512 .2734 Mdot
.65239 .57984 Mdot
.46379 .18182 Mdot
.56416 .36554 Mdot
.60137 .38754 Mdot
.34584 .37507 Mdot
.58343 .39418 Mdot
.37369 .39357 Mdot
.15291 .53553 Mdot
.69361 .24789 Mdot
.3184 .42523 Mdot
.31743 .37747 Mdot
.72689 .35511 Mdot
.46623 .70037 Mdot
.3417 .4007 Mdot
.5594 .35417 Mdot
.63521 .48486 Mdot
.42955 .42032 Mdot
.68934 .555 Mdot
.72602 .63232 Mdot
.6497 .39749 Mdot
.61352 .57392 Mdot
.72817 .67709 Mdot
.6523 .37917 Mdot
.46718 .59537 Mdot
.37826 .57397 Mdot
.60255 .42683 Mdot
.55445 .63328 Mdot
.56062 .64377 Mdot
.54386 .45909 Mdot
.55757 .38421 Mdot
.37156 .42461 Mdot
.64121 .56517 Mdot
.34859 .55848 Mdot
.59795 .3848 Mdot
.73302 .37926 Mdot
.63768 .56813 Mdot
.33178 .42802 Mdot
.41117 .25055 Mdot
.63489 .5423 Mdot
.51231 .35954 Mdot
.54083 .42146 Mdot
.57134 .38749 Mdot
.58491 .31243 Mdot
.38078 .58496 Mdot
.73443 .61658 Mdot
.6112 .37551 Mdot
.63873 .21369 Mdot
.42692 .60542 Mdot
.57795 .33716 Mdot
.33317 .43524 Mdot
.39564 .63758 Mdot
.49476 .68462 Mdot
.26631 .43204 Mdot
.5839 .41806 Mdot
.51711 .79031 Mdot
.27332 .69931 Mdot
.49679 .63172 Mdot
.38085 .43542 Mdot
.65228 .56074 Mdot
.56783 .39464 Mdot
.3874 .27693 Mdot
.53581 .39767 Mdot
.61644 .5632 Mdot
.50491 .63376 Mdot
.38092 .57662 Mdot
.55898 .81013 Mdot
.56348 .66072 Mdot
.35527 .39642 Mdot
.78201 .33285 Mdot
.37488 .39388 Mdot
.30797 .42253 Mdot
.42586 .24816 Mdot
.38234 .58552 Mdot
.20322 .30368 Mdot
.16473 .54377 Mdot
.57118 .34472 Mdot
.35044 .60242 Mdot
.33566 .39435 Mdot
.59952 .37632 Mdot
.30134 .43113 Mdot
.3478 .44316 Mdot
.5514 .3542 Mdot
.60905 .40175 Mdot
.40871 .77577 Mdot
.81891 .54009 Mdot
.65325 .55958 Mdot
.37367 .42742 Mdot
.34329 .49733 Mdot
.60174 .37754 Mdot
.54602 .41113 Mdot
.30615 .6641 Mdot
.68858 .5751 Mdot
.31256 .51568 Mdot
.56253 .36614 Mdot
.71877 .28607 Mdot
.48677 .39491 Mdot
.38425 .39215 Mdot
.39749 .59718 Mdot
.56876 .18203 Mdot
.32209 .55223 Mdot
.37231 .39323 Mdot
.64431 .58064 Mdot
.39111 .38373 Mdot
.71743 .32439 Mdot
.34225 .60184 Mdot
.34715 .38177 Mdot
.51961 .5787 Mdot
.3747 .59009 Mdot
.34345 .5832 Mdot
.43883 .2389 Mdot
.49846 .62403 Mdot
.68223 .59437 Mdot
.35067 .58593 Mdot
.2178 .46021 Mdot
.36416 .58661 Mdot
.1702 .56171 Mdot
.60819 .42585 Mdot
.75168 .47771 Mdot
.45439 .65621 Mdot
.62932 .35618 Mdot
.34295 .59037 Mdot
.68395 .56648 Mdot
.53599 .37366 Mdot
.31951 .41622 Mdot
.64299 .54855 Mdot
.36158 .5281 Mdot
.52662 .64127 Mdot
.34946 .43368 Mdot
.36723 .54996 Mdot
.32157 .38649 Mdot
.24581 .42785 Mdot
.22832 .68018 Mdot
.76549 .38604 Mdot
.33615 .48457 Mdot
.53929 .36891 Mdot
.75669 .6384 Mdot
.61096 .4326 Mdot
.55617 .37936 Mdot
.51642 .67598 Mdot
.7526 .45249 Mdot
.33623 .40602 Mdot
.6309 .80146 Mdot
.35397 .564 Mdot
.56702 .17702 Mdot
.57459 .49717 Mdot
.51382 .42965 Mdot
.36769 .42065 Mdot
.36509 .37938 Mdot
.44337 .27437 Mdot
.50177 .69559 Mdot
.55065 .45008 Mdot
.6269 .4085 Mdot
.52311 .4517 Mdot
.35437 .56692 Mdot
.59987 .5663 Mdot
.54129 .63487 Mdot
.28356 .7435 Mdot
.50653 .6307 Mdot
.61428 .55894 Mdot
.33275 .42179 Mdot
.6444 .58587 Mdot
.54553 .4133 Mdot
.29678 .43565 Mdot
.35618 .37454 Mdot
.66698 .53673 Mdot
.6788 .55559 Mdot
.36716 .71321 Mdot
.38654 .5981 Mdot
.5226 .40476 Mdot
.56481 .44048 Mdot
.58756 .38992 Mdot
.56314 .37904 Mdot
.35837 .56072 Mdot
.52864 .3802 Mdot
.33268 .551 Mdot
.25048 .38975 Mdot
.77238 .5088 Mdot
.5075 .54354 Mdot
.2308 .61357 Mdot
.32457 .41606 Mdot
.22196 .46768 Mdot
.61362 .46782 Mdot
.24877 .31232 Mdot
.32562 .75061 Mdot
.60328 .36146 Mdot
.51454 .68449 Mdot
.469 .3868 Mdot
.55586 .64407 Mdot
.56515 .86245 Mdot
.37506 .68139 Mdot
.82161 .56505 Mdot
.57825 .43744 Mdot
.55783 .5545 Mdot
.20181 .47605 Mdot
.61536 .42948 Mdot
.37957 .69803 Mdot
.23538 .60605 Mdot
.5267 .77597 Mdot
.68276 .5777 Mdot
.57839 .42666 Mdot
.61385 .32502 Mdot
.55285 .43937 Mdot
.54565 .40469 Mdot
.53034 .37648 Mdot
.37091 .55512 Mdot
.52766 .43338 Mdot
.54006 .37543 Mdot
.59694 .72132 Mdot
.68945 .37417 Mdot
.54335 .61807 Mdot
.21853 .64559 Mdot
.64423 .58641 Mdot
.36683 .42516 Mdot
.74231 .7094 Mdot
.38335 .60677 Mdot
.45025 .27297 Mdot
.56676 .38271 Mdot
.44346 .77926 Mdot
.32956 .60826 Mdot
.65048 .58371 Mdot
.49229 .65509 Mdot
.82861 .58361 Mdot
.52032 .66997 Mdot
.38008 .6499 Mdot
.53924 .67461 Mdot
.62535 .45524 Mdot
.37214 .42487 Mdot
.51841 .39872 Mdot
.35304 .58021 Mdot
.53916 .68494 Mdot
.70678 .44385 Mdot
.55888 .39984 Mdot
.52793 .66642 Mdot
.51882 .39845 Mdot
.33052 .46811 Mdot
.5159 .21005 Mdot
.50237 .6804 Mdot
.32852 .60439 Mdot
.36723 .5757 Mdot
.67726 .58858 Mdot
.35604 .42966 Mdot
.36513 .38958 Mdot
.37139 .60088 Mdot
.28575 .32781 Mdot
.58981 .44092 Mdot
.60527 .38648 Mdot
.59451 .19269 Mdot
.54762 .44111 Mdot
.70222 .36164 Mdot
.53804 .57146 Mdot
.3248 .42291 Mdot
.50982 .42654 Mdot
.57149 .37031 Mdot
.5867 .41967 Mdot
.26533 .38369 Mdot
.55282 .66631 Mdot
.60527 .4258 Mdot
.6754 .55088 Mdot
.57507 .71582 Mdot
.58574 .36706 Mdot
.49039 .36841 Mdot
.3634 .38806 Mdot
.34787 .21431 Mdot
.38388 .57584 Mdot
.50074 .66948 Mdot
.51097 .66334 Mdot
.73223 .63813 Mdot
.21691 .53661 Mdot
.53948 .57021 Mdot
.31413 .77495 Mdot
.40397 .66147 Mdot
.66855 .55257 Mdot
.55653 .70407 Mdot
.31333 .63917 Mdot
.50695 .65323 Mdot
.35997 .55886 Mdot
.61463 .41839 Mdot
.59497 .43611 Mdot
.20765 .34036 Mdot
.51408 .39111 Mdot
.65115 .56419 Mdot
.37754 .55852 Mdot
.31997 .4111 Mdot
.6478 .58147 Mdot
.39181 .60824 Mdot
.31398 .41669 Mdot
.61088 .36897 Mdot
.61387 .37694 Mdot
.36166 .38993 Mdot
.33961 .3777 Mdot
.54351 .42073 Mdot
.50921 .74048 Mdot
.315 .38053 Mdot
.34166 .38227 Mdot
.55121 .64917 Mdot
.55777 .63967 Mdot
.5119 .34987 Mdot
.35215 .5985 Mdot
.53771 .37589 Mdot
.51699 .66364 Mdot
.64764 .58733 Mdot
.33397 .40782 Mdot
.55616 .36115 Mdot
.58648 .37216 Mdot
.66003 .57555 Mdot
.66513 .59008 Mdot
.68077 .57452 Mdot
.35279 .54811 Mdot
.59169 .39715 Mdot
.34704 .40525 Mdot
.38699 .59237 Mdot
.69046 .59389 Mdot
.6881 .55705 Mdot
.53616 .7111 Mdot
.53856 .43764 Mdot
.47924 .7041 Mdot
.25319 .2504 Mdot
.65092 .23578 Mdot
.48804 .65908 Mdot
.49283 .68465 Mdot
.67914 .45788 Mdot
.43539 .45076 Mdot
.36405 .60717 Mdot
.69149 .53561 Mdot
.73603 .35659 Mdot
.60967 .36021 Mdot
.5779 .35441 Mdot
.50783 .37431 Mdot
.68083 .56916 Mdot
.76253 .45777 Mdot
.37749 .40094 Mdot
.65165 .34009 Mdot
.63648 .5633 Mdot
.5358 .61338 Mdot
.53034 .71615 Mdot
.50275 .6342 Mdot
.61968 .40229 Mdot
.46043 .29531 Mdot
.21644 .50011 Mdot
.77403 .58517 Mdot
.34442 .59462 Mdot
.62692 .33408 Mdot
.39648 .80351 Mdot
.36162 .39437 Mdot
.53805 .69604 Mdot
.66945 .55123 Mdot
.33644 .3786 Mdot
.3282 .57454 Mdot
.35251 .58645 Mdot
.54625 .64716 Mdot
.54154 .64337 Mdot
.5097 .63854 Mdot
.34625 .44411 Mdot
.33534 .42238 Mdot
.58472 .41553 Mdot
.33113 .41058 Mdot
.27568 .28885 Mdot
.6774 .53619 Mdot
.52906 .60226 Mdot
.3584 .5966 Mdot
.31151 .40828 Mdot
.56174 .4002 Mdot
.43004 .43785 Mdot
.26317 .59907 Mdot
.65488 .54378 Mdot
.49915 .20171 Mdot
.5438 .85847 Mdot
.52306 .40879 Mdot
.37499 .57765 Mdot
.37128 .22153 Mdot
.55735 .40496 Mdot
.52458 .63135 Mdot
.59364 .7627 Mdot
.56952 .7021 Mdot
.52747 .40752 Mdot
.60657 .35453 Mdot
.37804 .56636 Mdot
.29801 .75094 Mdot
.58001 .4153 Mdot
.30975 .50172 Mdot
.34229 .61761 Mdot
.53544 .62985 Mdot
.80495 .6782 Mdot
.66633 .62038 Mdot
.73455 .49372 Mdot
.54542 .64206 Mdot
.54254 .3831 Mdot
.5569 .65187 Mdot
.66705 .54651 Mdot
.49541 .66622 Mdot
.37689 .3939 Mdot
.51007 .62391 Mdot
.60188 .41243 Mdot
.34174 .3985 Mdot
.36104 .60231 Mdot
.53631 .1794 Mdot
.62076 .73934 Mdot
.54401 .67278 Mdot
.5113 .68709 Mdot
.50744 .41773 Mdot
.32028 .52266 Mdot
.55727 .45887 Mdot
.6143 .40522 Mdot
.33731 .59316 Mdot
.35805 .42573 Mdot
.39508 .58609 Mdot
.57478 .32736 Mdot
.78423 .5162 Mdot
.39193 .60497 Mdot
.50549 .7804 Mdot
.67197 .56698 Mdot
.47633 .49856 Mdot
.56256 .39489 Mdot
.37428 .62107 Mdot
.59107 .39956 Mdot
.37814 .40778 Mdot
.50795 .52894 Mdot
.49683 .75899 Mdot
.35137 .57456 Mdot
.535 .79947 Mdot
.76066 .53611 Mdot
.52141 .33799 Mdot
.39345 .59072 Mdot
.73864 .41534 Mdot
.53782 .68996 Mdot
.64368 .55112 Mdot
.63816 .54283 Mdot
.63566 .55704 Mdot
.56141 .46473 Mdot
.55939 .49697 Mdot
.63923 .58851 Mdot
.33113 .57135 Mdot
.66682 .53909 Mdot
.19187 .53304 Mdot
.63588 .79719 Mdot
.6663 .56002 Mdot
.56521 .42349 Mdot
.54548 .48126 Mdot
.68004 .42319 Mdot
.39276 .74052 Mdot
.81606 .58126 Mdot
.29255 .67879 Mdot
.53135 .4102 Mdot
.34023 .44625 Mdot
.36468 .43823 Mdot
.38897 .20121 Mdot
.69601 .31704 Mdot
.67723 .24997 Mdot
.29943 .39511 Mdot
.45857 .7191 Mdot
.33736 .4305 Mdot
.52159 .38176 Mdot
.60327 .38255 Mdot
.29812 .39504 Mdot
.77791 .48675 Mdot
.44911 .72558 Mdot
.55902 .82395 Mdot
.32876 .38185 Mdot
.3937 .61142 Mdot
.39627 .6211 Mdot
.34235 .58521 Mdot
.52557 .19401 Mdot
.36739 .4159 Mdot
.58943 .3826 Mdot
.51173 .66634 Mdot
.59361 .4344 Mdot
.37755 .59254 Mdot
.64385 .79847 Mdot
.35657 .41608 Mdot
.56465 .43525 Mdot
.5218 .32676 Mdot
.53525 .64107 Mdot
.66664 .57079 Mdot
.36597 .47362 Mdot
.67739 .25485 Mdot
.3471 .56856 Mdot
.30274 .38461 Mdot
.36184 .66047 Mdot
.58073 .79885 Mdot
.55479 .47189 Mdot
.62881 .3985 Mdot
.55542 .84297 Mdot
.72656 .3043 Mdot
.5544 .44856 Mdot
.50414 .6775 Mdot
.4153 .69699 Mdot
.57772 .36493 Mdot
.37039 .4338 Mdot
.63459 .5436 Mdot
.64275 .54491 Mdot
.51095 .34979 Mdot
.38467 .48516 Mdot
.54064 .54137 Mdot
.57201 .38048 Mdot
.51179 .36158 Mdot
.53849 .63302 Mdot
.41645 .66493 Mdot
.6463 .21895 Mdot
.64911 .58628 Mdot
.51725 .39808 Mdot
.66984 .75045 Mdot
.34452 .37295 Mdot
.49422 .63654 Mdot
.35096 .61343 Mdot
.28385 .37013 Mdot
.49219 .65766 Mdot
.55938 .35719 Mdot
.51482 .39289 Mdot
.40067 .61185 Mdot
.38317 .39171 Mdot
.67947 .5686 Mdot
.5109 .67538 Mdot
.66935 .58781 Mdot
.35881 .42267 Mdot
.33488 .4155 Mdot
.52009 .33034 Mdot
.5737 .47571 Mdot
.54088 .68076 Mdot
.571 .45915 Mdot
.56628 .71101 Mdot
.39703 .83597 Mdot
.40866 .58988 Mdot
.52882 .42992 Mdot
.34815 .36683 Mdot
.35082 .57088 Mdot
.60456 .39269 Mdot
.58729 .84374 Mdot
.59799 .3717 Mdot
.41361 .62073 Mdot
.7584 .35041 Mdot
.67604 .58211 Mdot
.65823 .3626 Mdot
.37904 .77033 Mdot
.54318 .437 Mdot
.51174 .65319 Mdot
.50786 .45312 Mdot
.37961 .61256 Mdot
.33184 .41967 Mdot
.38319 .83768 Mdot
.36498 .58301 Mdot
.5484 .43387 Mdot
.6464 .57819 Mdot
.34369 .36863 Mdot
.60653 .52225 Mdot
.59409 .5548 Mdot
.47842 .42555 Mdot
.54112 .44936 Mdot
.5609 .37229 Mdot
.77431 .55556 Mdot
.50078 .66585 Mdot
.33662 .38703 Mdot
.37209 .57406 Mdot
.3698 .60381 Mdot
.54912 .65399 Mdot
.43858 .60784 Mdot
.47548 .49892 Mdot
.3487 .18067 Mdot
.55869 .66718 Mdot
.63634 .57941 Mdot
.32123 .51206 Mdot
.50701 .66972 Mdot
.53222 .66606 Mdot
.55108 .647 Mdot
.48703 .58913 Mdot
.31299 .40668 Mdot
.56182 .3567 Mdot
.38376 .41665 Mdot
.54198 .38136 Mdot
.41237 .6226 Mdot
.35044 .57859 Mdot
.35278 .41912 Mdot
.52279 .8319 Mdot
.43757 .34552 Mdot
.55848 .41402 Mdot
.40048 .80755 Mdot
.53111 .35791 Mdot
.68859 .42635 Mdot
.51181 .37619 Mdot
.5463 .66299 Mdot
.61749 .43609 Mdot
.53094 .45894 Mdot
.42608 .1853 Mdot
.35605 .5987 Mdot
.56837 .65995 Mdot
.54527 .34261 Mdot
.50598 .36956 Mdot
.33557 .44259 Mdot
.33744 .37944 Mdot
.63735 .54506 Mdot
.67714 .34456 Mdot
.3593 .60444 Mdot
.17095 .49151 Mdot
.53254 .41613 Mdot
.61426 .59639 Mdot
.57738 .25343 Mdot
.60591 .39693 Mdot
.40197 .78851 Mdot
.45727 .28988 Mdot
.56622 .39462 Mdot
.43685 .53357 Mdot
.34828 .59829 Mdot
.79142 .48257 Mdot
.58221 .36205 Mdot
.53069 .63709 Mdot
.33583 .42573 Mdot
.35887 .37388 Mdot
.631 .56005 Mdot
.22536 .34523 Mdot
.39695 .58829 Mdot
.34168 .42084 Mdot
.55436 .39566 Mdot
.37794 .57879 Mdot
.5575 .67307 Mdot
.51458 .42751 Mdot
.68487 .2991 Mdot
.32508 .40824 Mdot
.50791 .39418 Mdot
.28739 .48745 Mdot
.70015 .48511 Mdot
.78785 .38049 Mdot
.36893 .57083 Mdot
.67938 .5857 Mdot
.49363 .42615 Mdot
.31234 .31913 Mdot
.49933 .40706 Mdot
.75059 .49888 Mdot
.19369 .54592 Mdot
.68572 .57845 Mdot
.55435 .42078 Mdot
.59483 .38609 Mdot
.47535 .46687 Mdot
.6448 .5831 Mdot
.57424 .43977 Mdot
.30006 .35001 Mdot
.31833 .39398 Mdot
.5348 .6952 Mdot
.31781 .40771 Mdot
.56573 .41907 Mdot
.56454 .47624 Mdot
.34478 .3759 Mdot
.41788 .83049 Mdot
.68388 .53547 Mdot
.3885 .58445 Mdot
.55453 .34855 Mdot
.60926 .37803 Mdot
.58857 .15127 Mdot
.5017 .62622 Mdot
.51293 .74718 Mdot
.61001 .65411 Mdot
.70611 .70808 Mdot
.67217 .62028 Mdot
.83051 .46958 Mdot
.73101 .30909 Mdot
.52615 .4323 Mdot
.63301 .47142 Mdot
.24769 .45882 Mdot
.34349 .59829 Mdot
.20699 .4178 Mdot
.53083 .41476 Mdot
.54603 .40214 Mdot
.48756 .66436 Mdot
.47276 .76351 Mdot
.67561 .24729 Mdot
.42226 .44931 Mdot
.67849 .57053 Mdot
.3694 .43035 Mdot
.55936 .35559 Mdot
.46243 .54769 Mdot
.5321 .61258 Mdot
.66869 .61627 Mdot
.56148 .43352 Mdot
.29039 .29248 Mdot
.25656 .58041 Mdot
.38389 .59292 Mdot
.51049 .66143 Mdot
.69105 .26331 Mdot
.53346 .43198 Mdot
.36036 .61916 Mdot
.57263 .41268 Mdot
.53433 .5912 Mdot
.58344 .32827 Mdot
.66306 .55246 Mdot
.55863 .3644 Mdot
.69197 .61302 Mdot
.71458 .21693 Mdot
.635 .58874 Mdot
.29261 .41427 Mdot
.54057 .60702 Mdot
.55265 .6696 Mdot
.34193 .37904 Mdot
.54922 .67335 Mdot
.46054 .25612 Mdot
.57628 .2844 Mdot
.67414 .56836 Mdot
.50002 .36869 Mdot
.66357 .56342 Mdot
.49159 .6389 Mdot
.52953 .40986 Mdot
.46516 .85866 Mdot
.53057 .68354 Mdot
.73757 .30007 Mdot
.3658 .58914 Mdot
.53123 .61165 Mdot
.58763 .3649 Mdot
.34092 .65914 Mdot
.5631 .65883 Mdot
.47251 .74694 Mdot
.58652 .41908 Mdot
.32632 .41337 Mdot
.58073 .36856 Mdot
.56875 .34556 Mdot
.55237 .62091 Mdot
.53312 .38361 Mdot
.39114 .60924 Mdot
.3022 .40446 Mdot
.79843 .63646 Mdot
.22589 .5829 Mdot
.56708 .44327 Mdot
.55504 .39822 Mdot
.39761 .40166 Mdot
.61757 .40194 Mdot
.35926 .56078 Mdot
.1119 .57274 Mdot
.67165 .56728 Mdot
.57092 .65088 Mdot
.68552 .61942 Mdot
.60547 .36133 Mdot
.53274 .37632 Mdot
.6179 .83697 Mdot
.77987 .5178 Mdot
.39537 .59871 Mdot
.5216 .4513 Mdot
.56043 .66969 Mdot
.645 .57117 Mdot
.3364 .56575 Mdot
.57252 .38912 Mdot
.54808 .41553 Mdot
.67089 .59104 Mdot
.63477 .49215 Mdot
.57471 .20566 Mdot
.38488 .62253 Mdot
.63493 .41652 Mdot
.47983 .63026 Mdot
.58235 .44705 Mdot
.49474 .19226 Mdot
.34858 .38402 Mdot
.34363 .57178 Mdot
.7311 .66032 Mdot
.53188 .43276 Mdot
.39912 .60202 Mdot
.35817 .60381 Mdot
.50801 .42883 Mdot
.3292 .36424 Mdot
.30753 .41377 Mdot
.31784 .39021 Mdot
.16896 .38237 Mdot
.72762 .47063 Mdot
.50984 .63838 Mdot
.34805 .59958 Mdot
.50939 .68837 Mdot
.61569 .56019 Mdot
.52527 .56362 Mdot
.50741 .68542 Mdot
.3116 .3957 Mdot
.55955 .62078 Mdot
.59716 .40191 Mdot
.36177 .60379 Mdot
.50834 .64829 Mdot
.57774 .34638 Mdot
.33635 .5186 Mdot
.34002 .72239 Mdot
.68561 .55707 Mdot
.63027 .54885 Mdot
.59594 .37441 Mdot
.50799 .69638 Mdot
.54273 .41789 Mdot
.3392 .60738 Mdot
.33387 .51461 Mdot
.55745 .3489 Mdot
.54629 .6711 Mdot
.39548 .39199 Mdot
.68406 .26042 Mdot
.59162 .46032 Mdot
.56377 .42322 Mdot
.53723 .38369 Mdot
.57316 .41249 Mdot
.5811 .79124 Mdot
.40062 .62277 Mdot
.23091 .61013 Mdot
.7315 .61216 Mdot
.35943 .41172 Mdot
.38601 .41914 Mdot
.63727 .22311 Mdot
.24855 .47054 Mdot
.35118 .59834 Mdot
.55874 .37913 Mdot
.24051 .53632 Mdot
.70539 .76857 Mdot
.53316 .8473 Mdot
.47979 .46166 Mdot
.50666 .62065 Mdot
.30228 .38656 Mdot
.53843 .68764 Mdot
.53951 .38828 Mdot
.50305 .38038 Mdot
.82832 .42981 Mdot
.32999 .58662 Mdot
.67461 .56307 Mdot
.54233 .37905 Mdot
.72734 .47657 Mdot
.51931 .66034 Mdot
.53482 .61095 Mdot
.61139 .4177 Mdot
.38358 .38427 Mdot
.6924 .21136 Mdot
.37998 .58415 Mdot
.28849 .66303 Mdot
.19941 .48111 Mdot
.27554 .59655 Mdot
.37899 .59065 Mdot
.51439 .49442 Mdot
.48981 .64806 Mdot
.56727 .2427 Mdot
.36412 .40814 Mdot
.64548 .54721 Mdot
.58536 .33841 Mdot
.35655 .37996 Mdot
.51591 .62615 Mdot
.32935 .41705 Mdot
.53297 .3745 Mdot
.36714 .63009 Mdot
.52271 .65167 Mdot
.42511 .61997 Mdot
.35421 .36728 Mdot
.64581 .58231 Mdot
.42214 .47256 Mdot
.43869 .39131 Mdot
.4568 .28691 Mdot
.60892 .42309 Mdot
.46575 .55516 Mdot
.58878 .38418 Mdot
.38882 .42565 Mdot
.56475 .40438 Mdot
.40511 .42111 Mdot
.51287 .65285 Mdot
.57788 .35751 Mdot
.56871 .37848 Mdot
.18458 .58469 Mdot
.5778 .43395 Mdot
.56308 .45692 Mdot
.56577 .39098 Mdot
.33068 .45575 Mdot
.49584 .37563 Mdot
.33721 .43696 Mdot
.57295 .73043 Mdot
.53507 .66466 Mdot
.64762 .53861 Mdot
.678 .59046 Mdot
.74867 .46337 Mdot
.701 .65671 Mdot
.45023 .76793 Mdot
.32038 .40054 Mdot
.37844 .6168 Mdot
.56877 .40699 Mdot
.81976 .51739 Mdot
.58962 .60376 Mdot
.53025 .61467 Mdot
.22782 .5849 Mdot
.64115 .38372 Mdot
.79932 .46708 Mdot
.52396 .45086 Mdot
.19355 .36178 Mdot
.61259 .45762 Mdot
.60935 .34562 Mdot
.55425 .68646 Mdot
.63646 .60314 Mdot
.61377 .39288 Mdot
.32371 .4374 Mdot
.65008 .55092 Mdot
.58943 .49386 Mdot
.47814 .69661 Mdot
.55795 .73557 Mdot
.39179 .44678 Mdot
.58825 .40746 Mdot
.52393 .65128 Mdot
.35222 .43337 Mdot
.65531 .2267 Mdot
.38697 .59036 Mdot
.4351 .59499 Mdot
.28609 .46451 Mdot
.42791 .82718 Mdot
.63763 .56994 Mdot
.52491 .22308 Mdot
.6017 .40943 Mdot
.57873 .75642 Mdot
.55131 .35072 Mdot
.65595 .79516 Mdot
.64624 .58991 Mdot
.3094 .39558 Mdot
.39076 .61441 Mdot
.37289 .43085 Mdot
.4438 .29036 Mdot
.49991 .70469 Mdot
.47475 .52675 Mdot
.52275 .66956 Mdot
.56761 .53999 Mdot
.34023 .39304 Mdot
.51956 .39549 Mdot
.34397 .18206 Mdot
.34414 .38255 Mdot
.33541 .36925 Mdot
.25922 .70278 Mdot
.42999 .8511 Mdot
.62954 .41967 Mdot
.31466 .37956 Mdot
.52802 .67175 Mdot
.65086 .55813 Mdot
.57055 .36208 Mdot
.59211 .40915 Mdot
.3578 .38176 Mdot
.56077 .63115 Mdot
.37687 .31264 Mdot
.54365 .6488 Mdot
.31248 .40427 Mdot
.53724 .6535 Mdot
.35494 .65491 Mdot
.50467 .67325 Mdot
.61011 .37911 Mdot
.56585 .405 Mdot
.66852 .64441 Mdot
.33377 .41507 Mdot
.57369 .38119 Mdot
.5079 .41739 Mdot
.34383 .40411 Mdot
.56678 .52025 Mdot
.38676 .31047 Mdot
.56964 .44706 Mdot
.58394 .4266 Mdot
.68307 .58146 Mdot
.49486 .56622 Mdot
.50828 .21182 Mdot
.53817 .37243 Mdot
.67955 .59359 Mdot
.31892 .43346 Mdot
.54818 .42733 Mdot
.71819 .73684 Mdot
.41901 .69935 Mdot
.52563 .41211 Mdot
.53714 .6899 Mdot
.52808 .45666 Mdot
.77913 .36368 Mdot
.61433 .40331 Mdot
.33528 .39993 Mdot
.34757 .425 Mdot
.16853 .51533 Mdot
.35311 .39525 Mdot
.55334 .63255 Mdot
.37596 .5915 Mdot
.57378 .80667 Mdot
.55418 .67694 Mdot
.5922 .46711 Mdot
.16348 .59028 Mdot
.51427 .41429 Mdot
.59525 .35745 Mdot
.73992 .28118 Mdot
.53476 .68645 Mdot
.37299 .41638 Mdot
.44218 .46418 Mdot
.58555 .477 Mdot
.34249 .57569 Mdot
.56163 .33411 Mdot
.61519 .41966 Mdot
.75528 .33436 Mdot
.58977 .78127 Mdot
.35074 .61666 Mdot
.56747 .45559 Mdot
.53613 .37368 Mdot
.48533 .63788 Mdot
.55867 .39622 Mdot
.65437 .55614 Mdot
.36615 .41881 Mdot
.50805 .67792 Mdot
.66018 .57772 Mdot
.53505 .42939 Mdot
.68057 .57247 Mdot
.51682 .63931 Mdot
.34506 .60893 Mdot
.53346 .39705 Mdot
.68839 .55294 Mdot
.67958 .57257 Mdot
.5862 .38407 Mdot
.32981 .4207 Mdot
.64447 .40257 Mdot
.57457 .43639 Mdot
.55397 .36209 Mdot
.36673 .39111 Mdot
.7836 .72808 Mdot
.60593 .38621 Mdot
.75833 .50459 Mdot
.36286 .37886 Mdot
.56928 .53281 Mdot
.5493 .68586 Mdot
.61762 .4153 Mdot
.34399 .60844 Mdot
.35409 .61327 Mdot
.50484 .63077 Mdot
.30801 .377 Mdot
.61561 .64262 Mdot
.31718 .36247 Mdot
.51552 .45524 Mdot
.58194 .45005 Mdot
.32787 .33519 Mdot
.82776 .55702 Mdot
.38148 .41164 Mdot
.45941 .66076 Mdot
.39718 .4734 Mdot
.37122 .61966 Mdot
.54428 .6181 Mdot
.29798 .39174 Mdot
.3748 .39861 Mdot
.32238 .42074 Mdot
.64787 .54465 Mdot
.67261 .64561 Mdot
.37621 .38463 Mdot
.38942 .39191 Mdot
.5911 .41579 Mdot
.54138 .37123 Mdot
.69494 .28186 Mdot
.65325 .27356 Mdot
.68301 .5606 Mdot
.52334 .62758 Mdot
.15617 .38076 Mdot
.33596 .60007 Mdot
.2125 .6085 Mdot
.58363 .35398 Mdot
.18842 .29743 Mdot
.58019 .36259 Mdot
.55511 .3931 Mdot
.30196 .40519 Mdot
.68584 .55145 Mdot
.66711 .56494 Mdot
.33874 .38595 Mdot
.3908 .40587 Mdot
.65614 .5561 Mdot
.36686 .7714 Mdot
.73278 .73286 Mdot
.57898 .68647 Mdot
.34535 .409 Mdot
.47236 .34849 Mdot
.39293 .61972 Mdot
.55262 .48659 Mdot
.34515 .61773 Mdot
.52514 .66322 Mdot
.49085 .6598 Mdot
.34764 .57062 Mdot
.58421 .41945 Mdot
.50487 .64608 Mdot
.52384 .42559 Mdot
.29212 .69308 Mdot
.44548 .31813 Mdot
.64099 .62963 Mdot
.48305 .44062 Mdot
.55441 .51974 Mdot
.42647 .62189 Mdot
.54083 .42911 Mdot
.71394 .71632 Mdot
.67645 .56747 Mdot
.50048 .44677 Mdot
.33969 .57557 Mdot
.76265 .29977 Mdot
.52977 .40253 Mdot
.33304 .40212 Mdot
.35424 .60325 Mdot
.26393 .42152 Mdot
.31621 .50216 Mdot
.53955 .38224 Mdot
.26283 .24745 Mdot
.30775 .44053 Mdot
.50635 .66624 Mdot
.27163 .32475 Mdot
.38518 .40098 Mdot
.70825 .59071 Mdot
.73959 .62476 Mdot
.49013 .83436 Mdot
.36759 .42531 Mdot
.49393 .6311 Mdot
.32418 .43196 Mdot
.64345 .57839 Mdot
.30397 .42734 Mdot
.51646 .6561 Mdot
.56014 .43077 Mdot
.54942 .66019 Mdot
.65408 .54165 Mdot
.58031 .21181 Mdot
.35189 .61704 Mdot
.56715 .66497 Mdot
.35693 .57535 Mdot
.6844 .49168 Mdot
.76481 .56648 Mdot
.38237 .57735 Mdot
.38101 .26884 Mdot
.59119 .4444 Mdot
.38513 .39492 Mdot
.55257 .65674 Mdot
.68154 .70929 Mdot
.42059 .46909 Mdot
.36378 .40351 Mdot
.51259 .63115 Mdot
.33079 .49155 Mdot
.30643 .30216 Mdot
.56188 .45802 Mdot
.6696 .43804 Mdot
.3484 .40728 Mdot
.48623 .64795 Mdot
.58433 .18735 Mdot
.32501 .43361 Mdot
.55926 .66288 Mdot
.39554 .61085 Mdot
.37377 .60374 Mdot
.59153 .43365 Mdot
.39158 .63607 Mdot
.49922 .64428 Mdot
.38661 .5363 Mdot
.31316 .37925 Mdot
.25992 .39885 Mdot
.68624 .54594 Mdot
.54097 .66209 Mdot
.51131 .396 Mdot
.37349 .44561 Mdot
.39538 .67977 Mdot
.38871 .32548 Mdot
.34676 .20819 Mdot
.54893 .65397 Mdot
.36967 .41148 Mdot
.33139 .40436 Mdot
.58762 .46226 Mdot
.33553 .48306 Mdot
.61814 .64762 Mdot
.44703 .42696 Mdot
.44119 .42421 Mdot
.53539 .6957 Mdot
.54142 .72219 Mdot
.54683 .34113 Mdot
.58292 .40849 Mdot
.37571 .61988 Mdot
.56387 .43033 Mdot
.30385 .39417 Mdot
.60897 .4217 Mdot
.37194 .5751 Mdot
.5189 .67202 Mdot
.53262 .40141 Mdot
.67923 .57919 Mdot
.40412 .61151 Mdot
.32887 .56747 Mdot
.54305 .66793 Mdot
.35915 .38171 Mdot
.59101 .52938 Mdot
.5406 .64155 Mdot
.5878 .40847 Mdot
.49264 .57736 Mdot
.53271 .37286 Mdot
.6575 .3828 Mdot
.33191 .43767 Mdot
.5104 .67901 Mdot
.29813 .40269 Mdot
.35959 .5805 Mdot
.7322 .61456 Mdot
.5644 .4138 Mdot
.55851 .66832 Mdot
.43684 .65941 Mdot
.66232 .40873 Mdot
.38561 .37915 Mdot
.38296 .75762 Mdot
.38544 .42357 Mdot
.52991 .62663 Mdot
.19925 .62065 Mdot
.63862 .55643 Mdot
.52949 .61418 Mdot
.81437 .60746 Mdot
.53549 .68103 Mdot
.59839 .42544 Mdot
.59782 .37775 Mdot
.50619 .67463 Mdot
.67882 .5877 Mdot
.68541 .24312 Mdot
.57651 .65847 Mdot
.37077 .4195 Mdot
.29876 .71633 Mdot
.44852 .16245 Mdot
.41003 .58032 Mdot
.376 .61882 Mdot
.62046 .45222 Mdot
.60691 .4389 Mdot
.33561 .57839 Mdot
.32871 .60072 Mdot
.63623 .54884 Mdot
.55435 .64757 Mdot
.36549 .45084 Mdot
.34426 .5504 Mdot
.36546 .46866 Mdot
.69477 .65333 Mdot
.59281 .459 Mdot
.20033 .49761 Mdot
.57651 .35364 Mdot
.73938 .55637 Mdot
.37044 .57303 Mdot
.52188 .3772 Mdot
.54647 .45953 Mdot
.33865 .59661 Mdot
.64999 .55677 Mdot
.44178 .61535 Mdot
.53323 .6516 Mdot
.79347 .69896 Mdot
.52238 .43356 Mdot
.60646 .41889 Mdot
.34443 .59182 Mdot
.60729 .70741 Mdot
.36041 .41504 Mdot
.37469 .4342 Mdot
.50115 .66641 Mdot
.40159 .48678 Mdot
.59903 .43377 Mdot
.54852 .43172 Mdot
.52737 .64694 Mdot
.55698 .6336 Mdot
.42172 .75526 Mdot
.59863 .3891 Mdot
.35671 .59506 Mdot
.6135 .56079 Mdot
.36635 .56999 Mdot
.52683 .37742 Mdot
.60743 .41452 Mdot
.61084 .37973 Mdot
.5134 .3923 Mdot
.33203 .60951 Mdot
.54011 .36215 Mdot
.49718 .3867 Mdot
.36841 .40819 Mdot
.54314 .37482 Mdot
.44135 .42801 Mdot
.57014 .42705 Mdot
.65284 .55756 Mdot
.46829 .21104 Mdot
.53017 .40198 Mdot
.6119 .42211 Mdot
.56963 .63978 Mdot
.55364 .41484 Mdot
.33788 .60542 Mdot
.34235 .41459 Mdot
.34806 .59704 Mdot
.35326 .61357 Mdot
.4955 .68175 Mdot
.63387 .57975 Mdot
.60657 .36105 Mdot
.66377 .54639 Mdot
.57641 .47152 Mdot
.53189 .43328 Mdot
.71852 .62838 Mdot
.18462 .37539 Mdot
.53937 .19551 Mdot
.56616 .41486 Mdot
.53189 .68539 Mdot
.53678 .68838 Mdot
.61738 .49093 Mdot
.5522 .45535 Mdot
.3511 .55885 Mdot
.3643 .61843 Mdot
.68961 .31139 Mdot
.77371 .41208 Mdot
.65224 .55721 Mdot
.48929 .55507 Mdot
.54869 .44877 Mdot
.51895 .38249 Mdot
.51608 .42653 Mdot
.50315 .68249 Mdot
.47411 .44645 Mdot
.53721 .61556 Mdot
.25485 .59661 Mdot
.34684 .57655 Mdot
.53323 .39149 Mdot
.20635 .53862 Mdot
.32843 .38013 Mdot
.34101 .41443 Mdot
.33348 .55988 Mdot
.47585 .66762 Mdot
.66843 .25851 Mdot
.53088 .85347 Mdot
.29041 .41471 Mdot
.67443 .54305 Mdot
.54537 .4352 Mdot
.52535 .67651 Mdot
.31074 .40447 Mdot
.67314 .54301 Mdot
.5223 .39778 Mdot
.67462 .64542 Mdot
.57216 .4172 Mdot
.2315 .46956 Mdot
.33439 .42838 Mdot
.67978 .78405 Mdot
.31158 .37387 Mdot
.40627 .60888 Mdot
.34914 .56479 Mdot
.6042 .39349 Mdot
.29276 .33381 Mdot
.38642 .41082 Mdot
.46153 .60876 Mdot
.63638 .57891 Mdot
.36927 .66794 Mdot
.64136 .56685 Mdot
.50826 .66091 Mdot
.64401 .55307 Mdot
.51544 .65407 Mdot
.64491 .2543 Mdot
.33036 .45788 Mdot
.66827 .57525 Mdot
.43335 .64727 Mdot
.61059 .43803 Mdot
.68483 .56234 Mdot
.50257 .38617 Mdot
.65578 .40403 Mdot
.52975 .64549 Mdot
.63949 .57956 Mdot
.51749 .39663 Mdot
.82172 .45669 Mdot
.39234 .58991 Mdot
.35015 .56039 Mdot
.50256 .38889 Mdot
.52193 .69647 Mdot
.30728 .42348 Mdot
.63571 .79009 Mdot
.37187 .55348 Mdot
.60499 .38785 Mdot
.61556 .39669 Mdot
.38755 .41515 Mdot
.1901 .55138 Mdot
.60588 .40437 Mdot
.56378 .31747 Mdot
.59938 .38756 Mdot
.38256 .57172 Mdot
.37178 .4307 Mdot
.33454 .40876 Mdot
.51041 .63373 Mdot
.33329 .37535 Mdot
.63921 .47939 Mdot
.22388 .55089 Mdot
.61209 .33689 Mdot
.36483 .58056 Mdot
.24945 .57252 Mdot
.25266 .59896 Mdot
.81197 .58544 Mdot
.35823 .3673 Mdot
.55543 .35046 Mdot
.34179 .37225 Mdot
.64457 .56738 Mdot
.3255 .41137 Mdot
.30206 .38713 Mdot
.54036 .41934 Mdot
.54294 .38294 Mdot
.51261 .67018 Mdot
.34852 .48532 Mdot
.36178 .38053 Mdot
.57907 .36292 Mdot
.62108 .42404 Mdot
.51865 .41748 Mdot
.48438 .5967 Mdot
.37932 .41834 Mdot
.30675 .75644 Mdot
.72389 .38713 Mdot
.36174 .381 Mdot
.70747 .22689 Mdot
.42887 .6646 Mdot
.51303 .70928 Mdot
.44083 .59539 Mdot
.59626 .38315 Mdot
.56496 .66375 Mdot
.53897 .38907 Mdot
.20136 .49826 Mdot
.54729 .41047 Mdot
.65447 .55478 Mdot
.5259 .43213 Mdot
.49321 .64547 Mdot
.54487 .649 Mdot
.60994 .39787 Mdot
.5349 .40015 Mdot
.60415 .21915 Mdot
.28382 .3886 Mdot
.34162 .41869 Mdot
.60995 .63977 Mdot
.66696 .58115 Mdot
.34362 .57272 Mdot
.56465 .39648 Mdot
.49757 .68233 Mdot
.54646 .65175 Mdot
.38384 .41056 Mdot
.5273 .63296 Mdot
.38039 .58569 Mdot
.56265 .40974 Mdot
.33776 .57242 Mdot
.64421 .5451 Mdot
.37459 .42643 Mdot
.5415 .37772 Mdot
.59089 .41622 Mdot
.34786 .42513 Mdot
.57418 .34332 Mdot
.67925 .5851 Mdot
.54107 .67933 Mdot
.36559 .42821 Mdot
.37579 .59532 Mdot
.50978 .65936 Mdot
.55301 .36045 Mdot
.22617 .30444 Mdot
.59306 .4274 Mdot
.58684 .37353 Mdot
.83397 .58387 Mdot
.54161 .44632 Mdot
.55053 .65411 Mdot
.30894 .39961 Mdot
.48011 .40166 Mdot
.73747 .44356 Mdot
.71501 .8032 Mdot
.53295 .61547 Mdot
.5514 .43793 Mdot
.81471 .53365 Mdot
.55723 .43725 Mdot
.40702 .35785 Mdot
.56429 .68907 Mdot
.51436 .5147 Mdot
.51611 .37399 Mdot
.38215 .60746 Mdot
.51259 .67472 Mdot
.51524 .64957 Mdot
.27717 .6937 Mdot
.54241 .42421 Mdot
.45382 .56483 Mdot
.52434 .38758 Mdot
.37828 .59795 Mdot
.70776 .3416 Mdot
.54593 .64836 Mdot
.38661 .19857 Mdot
.59087 .38554 Mdot
.37731 .39935 Mdot
.55527 .61629 Mdot
.32985 .64647 Mdot
.55818 .3612 Mdot
.67504 .55428 Mdot
.32991 .55168 Mdot
.56907 .33002 Mdot
.3689 .58141 Mdot
.55043 .36367 Mdot
.47893 .36932 Mdot
.24955 .33773 Mdot
.32559 .42048 Mdot
.38931 .61584 Mdot
.51508 .57434 Mdot
.54264 .35849 Mdot
.36606 .42666 Mdot
.36479 .40659 Mdot
.64777 .54289 Mdot
.516 .54143 Mdot
.28489 .47952 Mdot
.45804 .33951 Mdot
.28874 .70515 Mdot
.55949 .62271 Mdot
.49497 .75412 Mdot
.5764 .37202 Mdot
.60719 .57007 Mdot
.34196 .60932 Mdot
.59043 .43036 Mdot
.51903 .2283 Mdot
.33258 .38247 Mdot
.59291 .42311 Mdot
.66268 .56212 Mdot
.59923 .60016 Mdot
.61201 .55647 Mdot
.75818 .61433 Mdot
.52353 .66815 Mdot
.49594 .39421 Mdot
.48852 .36124 Mdot
.54643 .68915 Mdot
.62225 .40488 Mdot
.55602 .66803 Mdot
.39361 .79797 Mdot
.68473 .55676 Mdot
.37796 .41551 Mdot
.4085 .65016 Mdot
.6152 .37605 Mdot
.60715 .43381 Mdot
.62861 .57081 Mdot
.58359 .40405 Mdot
.23441 .33426 Mdot
.49137 .59462 Mdot
.50575 .65179 Mdot
.32296 .42054 Mdot
.61979 .40164 Mdot
.53605 .55996 Mdot
.56764 .43676 Mdot
.54315 .27892 Mdot
.61318 .42029 Mdot
.31087 .49213 Mdot
.3347 .42506 Mdot
.36508 .57686 Mdot
.5284 .36744 Mdot
.54893 .40335 Mdot
.76796 .45896 Mdot
.60031 .46697 Mdot
.52813 .36994 Mdot
.39901 .38395 Mdot
.3107 .411 Mdot
.3287 .43352 Mdot
.51315 .62348 Mdot
.76208 .37025 Mdot
.35774 .58912 Mdot
.48242 .42792 Mdot
.36241 .55356 Mdot
.35288 .32246 Mdot
.67681 .54563 Mdot
.78917 .57807 Mdot
.56722 .38395 Mdot
.3177 .39843 Mdot
.6431 .76366 Mdot
.34878 .44424 Mdot
.47253 .5464 Mdot
.35966 .60439 Mdot
.34232 .38427 Mdot
.55172 .39615 Mdot
.40878 .46936 Mdot
.8131 .5062 Mdot
.352 .58621 Mdot
.59454 .46557 Mdot
.50768 .62307 Mdot
.66333 .62546 Mdot
.28352 .26959 Mdot
.39179 .58753 Mdot
.41538 .61835 Mdot
.5423 .42624 Mdot
.32226 .38161 Mdot
.38281 .6031 Mdot
.37759 .56868 Mdot
.52422 .63257 Mdot
.54554 .37984 Mdot
.55019 .37664 Mdot
.52855 .6252 Mdot
.34702 .59555 Mdot
.49825 .40322 Mdot
.58061 .32758 Mdot
.8164 .38236 Mdot
.30301 .47214 Mdot
.79811 .69957 Mdot
.61851 .49475 Mdot
.47066 .22661 Mdot
.63525 .79448 Mdot
.37086 .38786 Mdot
.52884 .42039 Mdot
.60713 .34642 Mdot
.49937 .64342 Mdot
.55971 .42142 Mdot
.54155 .70589 Mdot
.35563 .60927 Mdot
.75823 .29906 Mdot
.26706 .54265 Mdot
.44516 .82092 Mdot
.55766 .42164 Mdot
.40971 .41026 Mdot
.65045 .57079 Mdot
.41515 .60097 Mdot
.35613 .43862 Mdot
.51086 .40351 Mdot
.59973 .21706 Mdot
.53261 .61418 Mdot
.35968 .39118 Mdot
.65622 .22959 Mdot
.52679 .50544 Mdot
.53147 .37445 Mdot
.5271 .6194 Mdot
.686 .74524 Mdot
.27343 .40635 Mdot
.38582 .56462 Mdot
.64969 .55566 Mdot
.51319 .67844 Mdot
.36688 .61999 Mdot
.38543 .44061 Mdot
.34922 .38987 Mdot
.3124 .43114 Mdot
.52308 .20204 Mdot
.57011 .66194 Mdot
.6538 .57306 Mdot
.78959 .4598 Mdot
.77341 .43296 Mdot
.65864 .55521 Mdot
.49043 .65799 Mdot
.3106 .40912 Mdot
.33261 .38706 Mdot
.34298 .41435 Mdot
.47464 .18175 Mdot
.34831 .3695 Mdot
.22928 .64584 Mdot
.51627 .40996 Mdot
.58951 .32412 Mdot
.55098 .43648 Mdot
.34453 .56191 Mdot
.34811 .42905 Mdot
.43348 .47167 Mdot
.55774 .46855 Mdot
.78325 .55131 Mdot
.59501 .42999 Mdot
.3897 .62921 Mdot
.59727 .41502 Mdot
.18772 .46245 Mdot
.34747 .37295 Mdot
.56378 .41738 Mdot
.37046 .62657 Mdot
.6638 .58433 Mdot
.3886 .38075 Mdot
.53764 .3833 Mdot
.4313 .78011 Mdot
.53383 .44119 Mdot
.44737 .81444 Mdot
.25044 .41462 Mdot
.67529 .54376 Mdot
.21677 .44492 Mdot
.50996 .61398 Mdot
.56831 .3203 Mdot
.56395 .47889 Mdot
.35452 .57978 Mdot
.38785 .66337 Mdot
.53395 .66669 Mdot
.47958 .45944 Mdot
.52339 .34362 Mdot
.64978 .54028 Mdot
.28184 .41712 Mdot
.3341 .58165 Mdot
.6223 .41167 Mdot
.56139 .4604 Mdot
.26385 .64689 Mdot
.50804 .36335 Mdot
.61701 .40761 Mdot
.62424 .56178 Mdot
.22611 .62831 Mdot
.5744 .42526 Mdot
.4813 .54936 Mdot
.29966 .42314 Mdot
.52114 .45956 Mdot
.21922 .63174 Mdot
.59619 .37501 Mdot
.35372 .38569 Mdot
.60845 .32244 Mdot
.2677 .46716 Mdot
.63543 .58159 Mdot
.61273 .42184 Mdot
.16847 .52759 Mdot
.59201 .39401 Mdot
.36029 .59273 Mdot
.55748 .4557 Mdot
.51826 .65794 Mdot
.53971 .1906 Mdot
.50445 .64095 Mdot
.58325 .44297 Mdot
.34563 .41287 Mdot
.34419 .58596 Mdot
.41805 .19875 Mdot
.6417 .65655 Mdot
.21848 .60781 Mdot
.54868 .83754 Mdot
.64354 .58454 Mdot
.69035 .59524 Mdot
.33313 .59255 Mdot
.56543 .41856 Mdot
.22569 .66928 Mdot
.61637 .45463 Mdot
.58595 .42531 Mdot
.54622 .40952 Mdot
.76025 .5665 Mdot
.3563 .61262 Mdot
.53518 .64401 Mdot
.60689 .40944 Mdot
.53553 .36486 Mdot
.3721 .39078 Mdot
.67408 .57962 Mdot
.54806 .68635 Mdot
.67317 .56668 Mdot
.5174 .67655 Mdot
.7294 .25851 Mdot
.51485 .44058 Mdot
.65685 .58389 Mdot
.33309 .55233 Mdot
.36189 .38595 Mdot
.22592 .54598 Mdot
.51108 .65376 Mdot
.50803 .63001 Mdot
.61309 .4062 Mdot
.35108 .38286 Mdot
.30038 .40443 Mdot
.64401 .57284 Mdot
.38174 .57962 Mdot
.5302 .40304 Mdot
.53985 .4414 Mdot
.55897 .30488 Mdot
.50746 .69247 Mdot
.22496 .47245 Mdot
.4942 .76519 Mdot
.56732 .41691 Mdot
.31191 .38062 Mdot
.53737 .40533 Mdot
.54833 .79746 Mdot
.32845 .37825 Mdot
.59176 .37004 Mdot
.66184 .20313 Mdot
.48082 .69009 Mdot
.25477 .49263 Mdot
.61013 .38436 Mdot
.61532 .82388 Mdot
.57292 .37644 Mdot
.77309 .30437 Mdot
.63641 .74366 Mdot
.58478 .44634 Mdot
.56439 .35874 Mdot
.4184 .3201 Mdot
.54544 .43952 Mdot
.52294 .62536 Mdot
.72187 .29748 Mdot
.32578 .43917 Mdot
.2891 .64114 Mdot
.48178 .2127 Mdot
.64459 .58828 Mdot
.50131 .66669 Mdot
.54152 .71965 Mdot
.66702 .55733 Mdot
.34304 .40706 Mdot
.57321 .41227 Mdot
.42789 .49867 Mdot
.52109 .69417 Mdot
.58491 .50167 Mdot
.36143 .59468 Mdot
.40132 .70871 Mdot
.57993 .58538 Mdot
.37337 .58308 Mdot
.54619 .37243 Mdot
.40418 .31753 Mdot
.60873 .25303 Mdot
.76137 .7078 Mdot
.37279 .62194 Mdot
.35029 .58551 Mdot
.50765 .18181 Mdot
.6683 .53493 Mdot
.27793 .65785 Mdot
.31553 .49743 Mdot
.34174 .57996 Mdot
.27263 .38624 Mdot
.54399 .624 Mdot
.3572 .63317 Mdot
.48975 .41946 Mdot
.52577 .42366 Mdot
.5511 .39848 Mdot
.37531 .57256 Mdot
.65597 .43039 Mdot
.2682 .32103 Mdot
.356 .57398 Mdot
.61232 .47043 Mdot
.49246 .51445 Mdot
.48552 .72482 Mdot
.53847 .63359 Mdot
.63293 .57338 Mdot
.69767 .55731 Mdot
.37551 .40534 Mdot
.6333 .57672 Mdot
.60024 .59253 Mdot
.57742 .40073 Mdot
.35893 .56885 Mdot
.38625 .67458 Mdot
.3725 .59991 Mdot
.66803 .56065 Mdot
.64622 .53708 Mdot
.36794 .40884 Mdot
.33494 .41701 Mdot
.44345 .24978 Mdot
.6931 .40623 Mdot
.57663 .43782 Mdot
.71069 .67427 Mdot
.30006 .3915 Mdot
.5914 .50359 Mdot
.63174 .57274 Mdot
.66743 .58251 Mdot
.76817 .47744 Mdot
.56284 .38524 Mdot
.34313 .33986 Mdot
.56307 .38964 Mdot
.70619 .35593 Mdot
.58601 .35666 Mdot
.52511 .63242 Mdot
.56054 .37877 Mdot
.7745 .48941 Mdot
.60667 .35554 Mdot
.60228 .44504 Mdot
.50099 .68273 Mdot
.55345 .33069 Mdot
.52022 .65745 Mdot
.57972 .44211 Mdot
.69374 .56805 Mdot
.49806 .66153 Mdot
.73334 .46345 Mdot
.76608 .49949 Mdot
.48927 .65612 Mdot
.66172 .54337 Mdot
.67181 .5946 Mdot
.73363 .50339 Mdot
.35681 .43859 Mdot
.58846 .4828 Mdot
.56389 .42085 Mdot
.55098 .62338 Mdot
.36672 .61729 Mdot
.56496 .35646 Mdot
.6175 .42714 Mdot
.59783 .36765 Mdot
.37635 .40488 Mdot
.62218 .6464 Mdot
.64974 .58215 Mdot
.53256 .62376 Mdot
.59032 .533 Mdot
.5292 .69724 Mdot
.5718 .45961 Mdot
.60479 .3461 Mdot
.50123 .22033 Mdot
.46292 .70509 Mdot
.47247 .17572 Mdot
.3513 .39053 Mdot
.53525 .68974 Mdot
.69032 .55067 Mdot
.61797 .35732 Mdot
.31619 .39686 Mdot
.51703 .65613 Mdot
.57161 .41653 Mdot
.60866 .45764 Mdot
.23866 .5887 Mdot
.64755 .47816 Mdot
.75365 .48741 Mdot
.50298 .63206 Mdot
.50936 .61811 Mdot
.77001 .52801 Mdot
.64935 .60414 Mdot
.42298 .46987 Mdot
.55135 .42811 Mdot
.67447 .5548 Mdot
.31095 .40246 Mdot
.54346 .21295 Mdot
.36335 .5629 Mdot
.3407 .48368 Mdot
.55803 .41996 Mdot
.54231 .52232 Mdot
.3484 .4135 Mdot
.66022 .56057 Mdot
.37271 .57034 Mdot
.69979 .58636 Mdot
.51538 .6891 Mdot
.46204 .84244 Mdot
.59012 .3991 Mdot
.61339 .41278 Mdot
.39516 .62228 Mdot
.32298 .38612 Mdot
.63683 .58719 Mdot
.30785 .72488 Mdot
.51647 .64198 Mdot
.21187 .64896 Mdot
.31207 .38234 Mdot
.46443 .36256 Mdot
.54277 .62927 Mdot
.34266 .55424 Mdot
.72702 .48452 Mdot
.3761 .58071 Mdot
.59145 .43739 Mdot
.32405 .40161 Mdot
.38628 .61519 Mdot
.30852 .46581 Mdot
.82461 .51573 Mdot
.46475 .3592 Mdot
.57211 .40117 Mdot
.81198 .41222 Mdot
.42735 .79659 Mdot
.28225 .39649 Mdot
.34897 .61419 Mdot
.59099 .43132 Mdot
.6107 .42866 Mdot
.59344 .39613 Mdot
.37313 .61523 Mdot
.71638 .65911 Mdot
.52716 .6441 Mdot
.54516 .43157 Mdot
.63753 .54734 Mdot
.52609 .66057 Mdot
.39139 .65327 Mdot
.53963 .63686 Mdot
.34335 .36331 Mdot
.5824 .45887 Mdot
.30788 .6379 Mdot
.6823 .18528 Mdot
.34949 .59237 Mdot
.49181 .67601 Mdot
.51587 .43818 Mdot
.42189 .69113 Mdot
.31916 .42477 Mdot
.51555 .64052 Mdot
.60539 .42037 Mdot
.42995 .63914 Mdot
.56642 .20673 Mdot
.54228 .64083 Mdot
.31499 .3962 Mdot
.76619 .69609 Mdot
.56151 .42713 Mdot
.57903 .38261 Mdot
.34161 .38814 Mdot
.34709 .28428 Mdot
.60286 .19722 Mdot
.53586 .40181 Mdot
.36508 .57566 Mdot
.35761 .81603 Mdot
.61669 .42997 Mdot
.72526 .36267 Mdot
.51165 .67239 Mdot
.33659 .6277 Mdot
.25004 .45581 Mdot
.6219 .3648 Mdot
.29009 .68624 Mdot
.42172 .61517 Mdot
.80434 .43838 Mdot
.53852 .70508 Mdot
.56196 .74773 Mdot
.78448 .37883 Mdot
.36714 .62761 Mdot
.4165 .43411 Mdot
.30325 .7022 Mdot
.35244 .24391 Mdot
.7229 .72644 Mdot
.59384 .73609 Mdot
.59981 .21552 Mdot
.44328 .49609 Mdot
.52784 .68245 Mdot
.57318 .51257 Mdot
.53749 .38802 Mdot
.43551 .79934 Mdot
.24848 .36754 Mdot
.25429 .35223 Mdot
.81397 .41476 Mdot
.42262 .36399 Mdot
.81358 .52613 Mdot
.81906 .58537 Mdot
.64832 .30929 Mdot
.51857 .75311 Mdot
.21311 .65651 Mdot
.70752 .26397 Mdot
.31378 .74873 Mdot
.60129 .32694 Mdot
.46294 .5481 Mdot
.50046 .8225 Mdot
.38313 .44843 Mdot
.29591 .31181 Mdot
.51147 .63528 Mdot
.33911 .44056 Mdot
.29274 .67278 Mdot
.38779 .42075 Mdot
.26363 .46243 Mdot
.77923 .68824 Mdot
.8248 .52469 Mdot
.17884 .53345 Mdot
.63446 .80504 Mdot
.50585 .22991 Mdot
.14494 .58898 Mdot
.55742 .68834 Mdot
.38319 .40147 Mdot
.74726 .55536 Mdot
.78169 .48109 Mdot
.26895 .5905 Mdot
.3452 .74615 Mdot
.6962 .6311 Mdot
.68345 .47169 Mdot
.33414 .40352 Mdot
.22431 .44364 Mdot
.37568 .64446 Mdot
.26477 .55152 Mdot
.70668 .2779 Mdot
.77038 .65677 Mdot
.42153 .5033 Mdot
.35558 .73855 Mdot
.43271 .72104 Mdot
.3055 .2597 Mdot
.72777 .40865 Mdot
.5929 .5071 Mdot
.30137 .47578 Mdot
.60929 .80117 Mdot
.36716 .25162 Mdot
.6957 .35008 Mdot
.78242 .46567 Mdot
.70419 .24313 Mdot
.51229 .79839 Mdot
.52378 .13855 Mdot
.37501 .44049 Mdot
.61654 .39784 Mdot
.37676 .27794 Mdot
.16885 .54926 Mdot
.63745 .53873 Mdot
.75138 .63152 Mdot
.63497 .56924 Mdot
.31864 .36741 Mdot
.57192 .1974 Mdot
.21984 .62632 Mdot
.1661 .57826 Mdot
.69466 .58096 Mdot
.47871 .41777 Mdot
.5554 .88419 Mdot
.79951 .50666 Mdot
.25328 .52136 Mdot
.8055 .36562 Mdot
.48984 .49544 Mdot
.26067 .40587 Mdot
.38236 .61705 Mdot
.781 .35968 Mdot
.32937 .39195 Mdot
.53453 .1275 Mdot
.76802 .29582 Mdot
.54279 .22428 Mdot
.92541 .51915 Mdot
.76398 .54786 Mdot
.51928 .51596 Mdot
.38743 .54432 Mdot
.71563 .43519 Mdot
.28164 .30157 Mdot
.71088 .54329 Mdot
.4248 .69875 Mdot
.59447 .84106 Mdot
.8035 .41128 Mdot
.1797 .60652 Mdot
.40877 .82068 Mdot
.3392 .25977 Mdot
.52927 .56044 Mdot
.51232 .4653 Mdot
.58161 .59851 Mdot
.74519 .67098 Mdot
.70915 .2386 Mdot
.72647 .38859 Mdot
.70546 .81168 Mdot
.62896 .58412 Mdot
.67821 .66692 Mdot
.80962 .6575 Mdot
.69636 .48054 Mdot
.24006 .43041 Mdot
.7396 .35474 Mdot
.49364 .4608 Mdot
.60116 .53919 Mdot
.7521 .64682 Mdot
.22967 .50162 Mdot
.73747 .31626 Mdot
.6733 .76568 Mdot
.26168 .64365 Mdot
.45754 .31711 Mdot
.76214 .40193 Mdot
.39542 .42038 Mdot
.6784 .43548 Mdot
.25033 .4454 Mdot
.83497 .50288 Mdot
.37987 .6342 Mdot
.85029 .50278 Mdot
.60867 .20233 Mdot
.50499 .42879 Mdot
.62179 .45355 Mdot
.39115 .36536 Mdot
.68471 .43642 Mdot
.53982 .3321 Mdot
.24594 .60597 Mdot
.83263 .54891 Mdot
.5896 .26073 Mdot
.42474 .63034 Mdot
.39305 .66148 Mdot
.80424 .67077 Mdot
.4029 .28031 Mdot
.6592 .60738 Mdot
.69672 .29448 Mdot
.30026 .27157 Mdot
.53592 .66083 Mdot
.18488 .60806 Mdot
.3563 .54716 Mdot
.55929 .21138 Mdot
.45409 .344 Mdot
.42704 .22117 Mdot
.83313 .54933 Mdot
.57005 .73365 Mdot
.593 .20286 Mdot
.69339 .50173 Mdot
.26664 .71533 Mdot
.48049 .72008 Mdot
.56838 .33492 Mdot
.3664 .75495 Mdot
.68103 .5863 Mdot
.44088 .28255 Mdot
.32424 .7816 Mdot
.62607 .70426 Mdot
.52272 .35444 Mdot
.54171 .22085 Mdot
.48773 .70474 Mdot
.40322 .47349 Mdot
.40185 .16962 Mdot
.60402 .44966 Mdot
.78695 .44467 Mdot
.49126 .79294 Mdot
.70666 .41495 Mdot
.71259 .75632 Mdot
.5738 .79503 Mdot
.56389 .14499 Mdot
.80023 .37387 Mdot
.63063 .65793 Mdot
.78089 .38149 Mdot
.82929 .45267 Mdot
.55984 .14963 Mdot
.59847 .47476 Mdot
.40729 .61022 Mdot
.21527 .30237 Mdot
.54102 .63385 Mdot
.79026 .49627 Mdot
.28826 .70488 Mdot
.56281 .58794 Mdot
.40935 .38608 Mdot
.51748 .48482 Mdot
.44391 .50257 Mdot
.2855 .38932 Mdot
.53508 .33451 Mdot
.47233 .16097 Mdot
.61855 .16777 Mdot
.50913 .14758 Mdot
.55832 .82284 Mdot
.76853 .3463 Mdot
.54331 .53203 Mdot
.18083 .55334 Mdot
.60312 .49431 Mdot
.51809 .40247 Mdot
.69886 .59999 Mdot
.7614 .55288 Mdot
.51303 .20982 Mdot
.28637 .54514 Mdot
.29511 .43547 Mdot
.75111 .6395 Mdot
.25901 .79098 Mdot
.46597 .24653 Mdot
.23882 .66721 Mdot
.66044 .61516 Mdot
.69524 .41072 Mdot
.7318 .67546 Mdot
.46905 .20778 Mdot
.82771 .58654 Mdot
.28604 .3919 Mdot
.30918 .73914 Mdot
.62074 .72901 Mdot
.40973 .45005 Mdot
.62752 .64416 Mdot
.81048 .54945 Mdot
.29548 .64163 Mdot
.43939 .20182 Mdot
.3185 .51343 Mdot
.37671 .26754 Mdot
.47248 .611 Mdot
.40973 .7198 Mdot
.30161 .75456 Mdot
.55929 .7801 Mdot
.7137 .35482 Mdot
.48456 .51565 Mdot
.20758 .45324 Mdot
.42941 .60558 Mdot
.71421 .36426 Mdot
.44301 .43248 Mdot
.7763 .39636 Mdot
.56494 .0954 Mdot
.39847 .1861 Mdot
.77236 .71365 Mdot
.71656 .67689 Mdot
.54063 .34069 Mdot
.82072 .61232 Mdot
.48501 .13915 Mdot
.72154 .22422 Mdot
.38936 .72827 Mdot
.53644 .70176 Mdot
.35413 .55377 Mdot
.50745 .16542 Mdot
.71368 .65569 Mdot
.79723 .63418 Mdot
.74517 .39164 Mdot
.32728 .56697 Mdot
.17345 .39081 Mdot
.70437 .24825 Mdot
.46435 .34675 Mdot
.64906 .47415 Mdot
.55031 .34524 Mdot
.21876 .4014 Mdot
.38584 .4212 Mdot
.47776 .74501 Mdot
.69318 .39422 Mdot
.5436 .65998 Mdot
.73603 .5716 Mdot
.35939 .75645 Mdot
.52571 .43154 Mdot
.51966 .56911 Mdot
.38162 .37895 Mdot
.47082 .71619 Mdot
.24127 .55776 Mdot
.68717 .20535 Mdot
.65466 .61805 Mdot
.51282 .37842 Mdot
.71034 .40783 Mdot
.62562 .63786 Mdot
.58452 .18706 Mdot
.33208 .59343 Mdot
.81799 .44455 Mdot
.43541 .52488 Mdot
.6811 .42772 Mdot
.2656 .35787 Mdot
.64954 .42265 Mdot
.59682 .44266 Mdot
.60712 .78762 Mdot
.54909 .26878 Mdot
.36957 .48858 Mdot
.48704 .41894 Mdot
.60816 .48646 Mdot
.816 .62223 Mdot
.59836 .59778 Mdot
.41345 .71084 Mdot
.82416 .47195 Mdot
.37074 .6104 Mdot
.33948 .37246 Mdot
.6448 .51617 Mdot
.3359 .75845 Mdot
.58714 .2851 Mdot
.56461 .20618 Mdot
.56881 .58099 Mdot
.63755 .69273 Mdot
.82649 .48869 Mdot
.81393 .45139 Mdot
.19357 .4231 Mdot
.2794 .40088 Mdot
.66546 .34444 Mdot
.32822 .75907 Mdot
.30955 .41453 Mdot
.24346 .63359 Mdot
.23727 .61687 Mdot
.74023 .27802 Mdot
.50222 .57701 Mdot
.60526 .83659 Mdot
.75021 .48236 Mdot
.74076 .63342 Mdot
.41497 .19835 Mdot
.28726 .73577 Mdot
.79742 .54949 Mdot
.28024 .38013 Mdot
.41997 .33419 Mdot
.60617 .3328 Mdot
.19481 .50972 Mdot
.20986 .32542 Mdot
.64402 .51954 Mdot
.43249 .40941 Mdot
.67911 .76345 Mdot
.58188 .41082 Mdot
.36449 .19719 Mdot
.33932 .75031 Mdot
.49605 .18045 Mdot
.3335 .55672 Mdot
.53697 .37387 Mdot
.61803 .37858 Mdot
.72306 .32468 Mdot
.26295 .46871 Mdot
.76842 .38239 Mdot
.37064 .81705 Mdot
.70591 .72823 Mdot
.26912 .3549 Mdot
.78712 .48527 Mdot
.77128 .66083 Mdot
.44649 .80101 Mdot
.50135 .53856 Mdot
.73008 .59674 Mdot
.70835 .47951 Mdot
.6196 .80994 Mdot
.43877 .44123 Mdot
.42085 .55999 Mdot
.26561 .61316 Mdot
.50583 .77294 Mdot
.48887 .19584 Mdot
.55762 .36496 Mdot
.65665 .22998 Mdot
.80846 .60529 Mdot
.20771 .40622 Mdot
.2602 .30615 Mdot
.408 .18032 Mdot
.51269 .28832 Mdot
.53225 .78236 Mdot
.41031 .78691 Mdot
.27755 .74671 Mdot
.43216 .52668 Mdot
.77459 .57057 Mdot
.70103 .49195 Mdot
.82582 .48246 Mdot
.39868 .62067 Mdot
.30813 .50404 Mdot
.39689 .6625 Mdot
.77677 .38317 Mdot
.4026 .29228 Mdot
.8173 .56095 Mdot
.47313 .48751 Mdot
.57052 .14362 Mdot
.57746 .78012 Mdot
.4543 .49366 Mdot
.51628 .68724 Mdot
.58175 .72483 Mdot
.77398 .61517 Mdot
.5919 .7679 Mdot
.27488 .71601 Mdot
.49814 .70051 Mdot
.61136 .51315 Mdot
.43755 .38177 Mdot
.66854 .44608 Mdot
.60316 .79076 Mdot
.7101 .40858 Mdot
.82659 .53859 Mdot
.73289 .32519 Mdot
.65236 .22896 Mdot
.7687 .54594 Mdot
.5336 .84451 Mdot
.25272 .51664 Mdot
.61122 .54286 Mdot
.34667 .75239 Mdot
.67874 .68203 Mdot
.28315 .3725 Mdot
.25991 .20289 Mdot
.46826 .83877 Mdot
.55815 .77143 Mdot
.71015 .24064 Mdot
.57149 .80188 Mdot
.46229 .7067 Mdot
.32196 .28575 Mdot
.32173 .48383 Mdot
.64179 .24202 Mdot
.54712 .40893 Mdot
.46448 .1554 Mdot
.6841 .40509 Mdot
.66208 .1835 Mdot
.79547 .64506 Mdot
.41183 .38387 Mdot
.58155 .45821 Mdot
.53 .62184 Mdot
.44569 .56017 Mdot
.67541 .32028 Mdot
.37351 .30446 Mdot
.24392 .40525 Mdot
.43948 .63389 Mdot
.56055 .68075 Mdot
.61617 .63166 Mdot
.28961 .41111 Mdot
.72452 .64565 Mdot
.50274 .76883 Mdot
.51127 .60553 Mdot
.41039 .50459 Mdot
.70866 .3805 Mdot
.24337 .4543 Mdot
.47076 .34232 Mdot
.47514 .20578 Mdot
.30345 .63925 Mdot
.52902 .6285 Mdot
.47068 .33157 Mdot
.49786 .82667 Mdot
.68188 .75095 Mdot
.70219 .23709 Mdot
.59346 .54936 Mdot
.3814 .32458 Mdot
.71744 .35225 Mdot
.26784 .31151 Mdot
.3054 .32557 Mdot
.45875 .68981 Mdot
.21979 .4076 Mdot
.31217 .30657 Mdot
.30732 .69796 Mdot
.7588 .29836 Mdot
.31249 .74625 Mdot
.32615 .75905 Mdot
.53738 .5917 Mdot
.57945 .30322 Mdot
.41589 .40671 Mdot
.73863 .46986 Mdot
.41344 .4725 Mdot
.14142 .54506 Mdot
.49982 .44607 Mdot
.1129 .50398 Mdot
.38762 .57757 Mdot
.3082 .27741 Mdot
.71125 .48816 Mdot
.49515 .5204 Mdot
.46564 .4725 Mdot
.56293 .78419 Mdot
.30456 .49057 Mdot
.49886 .80083 Mdot
.26229 .34133 Mdot
.55736 .68989 Mdot
.3923 .83286 Mdot
.545 .84847 Mdot
.43655 .32736 Mdot
.52708 .44146 Mdot
.49249 .83986 Mdot
.54227 .69806 Mdot
.49982 .20636 Mdot
.72076 .74831 Mdot
.66025 .74914 Mdot
.44117 .40352 Mdot
.69075 .41814 Mdot
.77782 .56728 Mdot
.82094 .41719 Mdot
.203 .36189 Mdot
.74853 .65062 Mdot
.39939 .61891 Mdot
.48082 .4988 Mdot
.80032 .58668 Mdot
.26619 .42878 Mdot
.37991 .63907 Mdot
.24536 .4176 Mdot
.12684 .57747 Mdot
.79265 .49559 Mdot
.77049 .3914 Mdot
.25283 .40609 Mdot
.31123 .37476 Mdot
.28313 .46888 Mdot
.23959 .43289 Mdot
.63677 .76039 Mdot
.46043 .81979 Mdot
.24352 .43939 Mdot
.21548 .68974 Mdot
.65628 .40407 Mdot
.53699 .73093 Mdot
.41489 .38217 Mdot
.63091 .2952 Mdot
.32484 .57187 Mdot
.68089 .26142 Mdot
.71506 .72879 Mdot
.40268 .58988 Mdot
.62013 .78694 Mdot
.36179 .74337 Mdot
.48682 .34214 Mdot
.5714 .28674 Mdot
.69981 .72367 Mdot
.39734 .30926 Mdot
.18681 .48339 Mdot
.56256 .2219 Mdot
.49995 .69495 Mdot
.74141 .70966 Mdot
.50756 .65299 Mdot
.57381 .50329 Mdot
.32855 .47787 Mdot
.70708 .53739 Mdot
.48518 .17452 Mdot
.65255 .59182 Mdot
.38162 .42161 Mdot
.20882 .33496 Mdot
.30655 .39323 Mdot
.48691 .15777 Mdot
.43424 .21787 Mdot
.22949 .38755 Mdot
.62842 .66574 Mdot
.61196 .70036 Mdot
.16074 .6258 Mdot
.37092 .64859 Mdot
.5773 .59909 Mdot
.20378 .55404 Mdot
.38462 .40544 Mdot
.67491 .62029 Mdot
.49669 .67464 Mdot
.403 .52095 Mdot
.3057 .67074 Mdot
.65348 .37838 Mdot
.37431 .4487 Mdot
.40458 .51357 Mdot
.67131 .27746 Mdot
.7601 .32089 Mdot
.55509 .6721 Mdot
.12649 .48699 Mdot
.58806 .4529 Mdot
.45582 .31031 Mdot
.83235 .58115 Mdot
.17153 .39692 Mdot
.59148 .65538 Mdot
.55873 .85275 Mdot
.54712 .35181 Mdot
.7181 .69104 Mdot
.33333 .39688 Mdot
.31546 .74483 Mdot
.6378 .56383 Mdot
.70739 .42344 Mdot
.37795 .56505 Mdot
.4349 .20247 Mdot
.58774 .67911 Mdot
.309 .42698 Mdot
.68946 .71403 Mdot
.64588 .30839 Mdot
.37124 .51955 Mdot
.60754 .66747 Mdot
.4392 .33132 Mdot
.58225 .28865 Mdot
.32759 .45573 Mdot
.77892 .41088 Mdot
.338 .77635 Mdot
.69398 .20632 Mdot
.39306 .374 Mdot
.53917 .51323 Mdot
.25583 .62475 Mdot
.64622 .77119 Mdot
.20543 .51395 Mdot
.8367 .56083 Mdot
.69381 .36678 Mdot
.61858 .32104 Mdot
.70677 .36222 Mdot
.64324 .37901 Mdot
.4674 .52618 Mdot
.44304 .73108 Mdot
.24153 .35913 Mdot
.23062 .47123 Mdot
.3448 .26588 Mdot
.19491 .48343 Mdot
.76726 .39894 Mdot
.23201 .39245 Mdot
.47973 .64322 Mdot
.5135 .31755 Mdot
.40373 .57541 Mdot
.76764 .32436 Mdot
.83569 .56713 Mdot
.414 .6142 Mdot
.66091 .62963 Mdot
.6623 .78793 Mdot
.62672 .43254 Mdot
.56946 .53738 Mdot
.61196 .41909 Mdot
.64482 .46597 Mdot
.15599 .42841 Mdot
.6441 .76268 Mdot
.50518 .37582 Mdot
.80367 .42287 Mdot
.79275 .39072 Mdot
.60919 .15499 Mdot
.23203 .68091 Mdot
.36859 .41389 Mdot
.56153 .1575 Mdot
.2412 .40609 Mdot
.82735 .43103 Mdot
.49249 .73312 Mdot
.85053 .5816 Mdot
.41924 .32989 Mdot
.64111 .78605 Mdot
.30966 .29603 Mdot
.31762 .48993 Mdot
.49758 .78702 Mdot
.54849 .54152 Mdot
.39397 .69288 Mdot
.54698 .80297 Mdot
.34609 .82179 Mdot
.60338 .33778 Mdot
.40371 .77172 Mdot
.28229 .60713 Mdot
.7517 .70022 Mdot
.59044 .75702 Mdot
.54742 .45166 Mdot
.38105 .66776 Mdot
.475 .18552 Mdot
.71466 .38234 Mdot
.58884 .51412 Mdot
.58204 .75763 Mdot
.6128 .23958 Mdot
.70309 .34143 Mdot
.31789 .75496 Mdot
.43224 .33377 Mdot
.44667 .54903 Mdot
.54524 .35689 Mdot
.34762 .45427 Mdot
.66358 .59891 Mdot
.54645 .54778 Mdot
.57865 .44095 Mdot
.53196 .61036 Mdot
.3667 .51588 Mdot
.44991 .16992 Mdot
.23516 .50097 Mdot
.38131 .78137 Mdot
.39994 .42521 Mdot
.29041 .58369 Mdot
.20968 .53455 Mdot
.3775 .2041 Mdot
.64429 .72636 Mdot
.72653 .38918 Mdot
.80497 .50117 Mdot
.74108 .32851 Mdot
.38224 .45673 Mdot
.65183 .1965 Mdot
.34373 .61092 Mdot
.47583 .35498 Mdot
.29903 .55061 Mdot
.61177 .61458 Mdot
.49147 .39597 Mdot
.64068 .78548 Mdot
.57772 .59072 Mdot
.7784 .48781 Mdot
.51253 .80094 Mdot
.66597 .37311 Mdot
.43835 .36494 Mdot
.8132 .43734 Mdot
.53428 .61601 Mdot
.37077 .79018 Mdot
.37598 .52944 Mdot
.58886 .74808 Mdot
.75548 .33534 Mdot
.71944 .25046 Mdot
.44676 .47491 Mdot
.70486 .46534 Mdot
.58469 .38174 Mdot
.30565 .75492 Mdot
.63774 .76932 Mdot
.47717 .43733 Mdot
.38262 .71532 Mdot
.33213 .37386 Mdot
.42325 .74358 Mdot
.4593 .55036 Mdot
.63575 .24633 Mdot
.38988 .38899 Mdot
.22208 .39297 Mdot
.69182 .5774 Mdot
.51108 .50347 Mdot
.49184 .36805 Mdot
.71208 .45231 Mdot
.179 .6175 Mdot
.48374 .40826 Mdot
.75229 .65474 Mdot
.45299 .33732 Mdot
.30858 .72727 Mdot
.69745 .72163 Mdot
.44646 .6754 Mdot
.30446 .48842 Mdot
.53834 .30195 Mdot
.30415 .65049 Mdot
.60488 .37769 Mdot
.47841 .67512 Mdot
.31535 .42929 Mdot
.73995 .71801 Mdot
.53163 .28157 Mdot
.73172 .46495 Mdot
.48435 .59659 Mdot
.59886 .50692 Mdot
.3815 .54546 Mdot
.84619 .58004 Mdot
.30373 .48294 Mdot
.69507 .3819 Mdot
.50345 .57634 Mdot
.71365 .48381 Mdot
.41595 .23006 Mdot
.76246 .28502 Mdot
.31079 .29239 Mdot
.41605 .49312 Mdot
.30068 .28545 Mdot
.54567 .77703 Mdot
.70375 .7664 Mdot
.69891 .35362 Mdot
.48476 .48217 Mdot
.6207 .5627 Mdot
.23289 .58296 Mdot
.46607 .60837 Mdot
.5953 .51995 Mdot
.40986 .52632 Mdot
.34346 .69738 Mdot
.3108 .60146 Mdot
.47363 .41793 Mdot
.7778 .5334 Mdot
.80827 .4759 Mdot
.29528 .71372 Mdot
.43006 .60195 Mdot
.53572 .74305 Mdot
.64191 .25868 Mdot
.85568 .58937 Mdot
.24377 .2923 Mdot
.58632 .38402 Mdot
.41031 .57231 Mdot
.69383 .45976 Mdot
.49583 .64078 Mdot
.23183 .45152 Mdot
.21609 .53233 Mdot
.39868 .60371 Mdot
.6205 .51479 Mdot
.77682 .45342 Mdot
.51776 .77072 Mdot
.66246 .46682 Mdot
.40111 .65302 Mdot
.43132 .17241 Mdot
.53228 .82777 Mdot
.64993 .76736 Mdot
.88042 .51777 Mdot
.40245 .54588 Mdot
.6095 .47893 Mdot
.41389 .26053 Mdot
.76156 .33278 Mdot
.71618 .41018 Mdot
.54086 .20712 Mdot
.42673 .6696 Mdot
.69557 .35405 Mdot
.29079 .36238 Mdot
.78166 .51044 Mdot
.41544 .74097 Mdot
.46434 .51277 Mdot
.61304 .70489 Mdot
.66539 .19742 Mdot
.42476 .37527 Mdot
.81019 .51242 Mdot
.44111 .18891 Mdot
.26292 .73749 Mdot
.77501 .34317 Mdot
.76443 .50091 Mdot
.62569 .74484 Mdot
.38131 .27773 Mdot
.44055 .43009 Mdot
.27016 .39219 Mdot
.50633 .20717 Mdot
.58839 .27745 Mdot
.67219 .64646 Mdot
.36509 .24226 Mdot
.71393 .35538 Mdot
.60426 .27261 Mdot
.48062 .47838 Mdot
.47928 .33158 Mdot
.65245 .62988 Mdot
.2552 .41854 Mdot
.42599 .44254 Mdot
.73973 .43965 Mdot
.46259 .33285 Mdot
.26559 .63944 Mdot
.5664 .7965 Mdot
.25062 .73909 Mdot
.70112 .67981 Mdot
.36713 .21461 Mdot
.51621 .4122 Mdot
.61573 .14233 Mdot
.51508 .78533 Mdot
.54481 .75877 Mdot
.47669 .81164 Mdot
.48926 .71059 Mdot
.63265 .45216 Mdot
.60448 .37704 Mdot
.76903 .61787 Mdot
.43839 .40033 Mdot
.50673 .2255 Mdot
.41514 .2053 Mdot
.69923 .41863 Mdot
.74411 .39619 Mdot
.74364 .47643 Mdot
.59722 .31725 Mdot
.31313 .38648 Mdot
.51859 .1477 Mdot
.42784 .47873 Mdot
.48337 .44555 Mdot
.50941 .33918 Mdot
.37287 .26912 Mdot
.61843 .84073 Mdot
.39927 .37494 Mdot
.74759 .36606 Mdot
.42173 .35427 Mdot
.39151 .45837 Mdot
.20326 .4931 Mdot
.90736 .43256 Mdot
.66053 .15551 Mdot
.31969 .4359 Mdot
.22712 .6525 Mdot
.42235 .35971 Mdot
.77428 .38709 Mdot
.6278 .72597 Mdot
.35446 .71139 Mdot
.46257 .40428 Mdot
.36913 .47743 Mdot
.50478 .356 Mdot
.48007 .79812 Mdot
.7744 .3217 Mdot
.38912 .21736 Mdot
.80468 .42596 Mdot
.64757 .38574 Mdot
.49244 .37455 Mdot
.88095 .56603 Mdot
.80446 .57616 Mdot
.59105 .46116 Mdot
.28714 .31171 Mdot
.50576 .45785 Mdot
.54043 .39027 Mdot
.73533 .61729 Mdot
.39211 .83174 Mdot
.71587 .34927 Mdot
.77663 .38366 Mdot
.39082 .40826 Mdot
.51746 .72049 Mdot
.38719 .5763 Mdot
.45253 .47251 Mdot
.5767 .46829 Mdot
.38445 .61386 Mdot
.6748 .3808 Mdot
.66966 .77546 Mdot
.4605 .5967 Mdot
.37957 .81212 Mdot
.85734 .5085 Mdot
.51682 .29182 Mdot
.23279 .57434 Mdot
.62863 .41511 Mdot
.62264 .28843 Mdot
.65398 .28508 Mdot
.63047 .48057 Mdot
.59675 .80617 Mdot
.36534 .1369 Mdot
.3672 .67771 Mdot
.66035 .25179 Mdot
.30056 .37983 Mdot
.42798 .53932 Mdot
.45017 .37191 Mdot
.49651 .72571 Mdot
.54696 .68379 Mdot
.64424 .36811 Mdot
.39285 .3833 Mdot
.33714 .54888 Mdot
.12662 .45326 Mdot
.52069 .4368 Mdot
.21839 .47337 Mdot
.82694 .43849 Mdot
.5616 .22123 Mdot
.43225 .30133 Mdot
.5925 .357 Mdot
.2624 .56075 Mdot
.4885 .4855 Mdot
.74327 .68915 Mdot
.66073 .23668 Mdot
.80165 .46236 Mdot
.53757 .27972 Mdot
.43483 .36394 Mdot
.5372 .36331 Mdot
.65688 .53341 Mdot
.33905 .6283 Mdot
.75239 .62086 Mdot
.53776 .47172 Mdot
.81192 .38719 Mdot
.57756 .70856 Mdot
.56478 .5603 Mdot
.36364 .35413 Mdot
.59991 .15516 Mdot
.38642 .24917 Mdot
.41329 .42486 Mdot
.39031 .19524 Mdot
.60539 .63562 Mdot
.66731 .45219 Mdot
.53286 .61997 Mdot
.58146 .47812 Mdot
.39802 .4094 Mdot
.37846 .18609 Mdot
.74701 .60324 Mdot
.39621 .68669 Mdot
.40588 .71697 Mdot
.2606 .68104 Mdot
.36753 .52071 Mdot
.87796 .49788 Mdot
.60268 .68188 Mdot
.39739 .18158 Mdot
.34618 .78053 Mdot
.4015 .40997 Mdot
.5813 .79226 Mdot
.49874 .44089 Mdot
.55238 .66407 Mdot
.80125 .43426 Mdot
.54576 .49269 Mdot
.57568 .20095 Mdot
.57665 .34334 Mdot
.52831 .18143 Mdot
.61932 .54749 Mdot
.6795 .62456 Mdot
.54812 .7711 Mdot
.37738 .26403 Mdot
.79715 .66575 Mdot
.23348 .58818 Mdot
.82296 .62179 Mdot
.78148 .68396 Mdot
.8177 .43665 Mdot
.53792 .19742 Mdot
.18895 .38817 Mdot
.55857 .76551 Mdot
.69099 .73292 Mdot
.46727 .74455 Mdot
.35537 .28186 Mdot
.57873 .73001 Mdot
.3676 .35252 Mdot
.26339 .47172 Mdot
.41636 .59813 Mdot
.12805 .3634 Mdot
.75752 .42649 Mdot
.40127 .38699 Mdot
.59361 .70891 Mdot
.80395 .39826 Mdot
.38423 .27056 Mdot
.53831 .80517 Mdot
.46194 .54602 Mdot
.57417 .33532 Mdot
.57087 .2806 Mdot
.2831 .70718 Mdot
.58639 .70161 Mdot
.18658 .68113 Mdot
.50833 .82361 Mdot
.37275 .69798 Mdot
.4561 .52345 Mdot
.34202 .44181 Mdot
.18874 .51202 Mdot
.62021 .6903 Mdot
.58283 .81035 Mdot
.65269 .78268 Mdot
.80188 .58376 Mdot
.16053 .62289 Mdot
.31617 .74029 Mdot
.76055 .32565 Mdot
.59956 .78201 Mdot
.30566 .42621 Mdot
.75782 .51307 Mdot
.52093 .69949 Mdot
.42223 .70192 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0S?ooool2o`000;_ooooo000Loooo
o`03o`000?oooooooooo08cooooo0_l0002kooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0;Cooooo0_l0002Cooooo`007?ooool2o`000;Gooooo0_l0002Cooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo097ooooo0_l0002f
ooooo`007?ooool00ol0003oooooooooo`2Aooooo`;o00005oooool2o`0009gooooo000Looooo`03
o`000?oooooooooo09kooooo0_l0000:ooooo`;o0000WOooool001cooooo00?o0000ooooooooool0
W_ooool2o`000:Wooooo000Looooo`03o`000?oooooooooo07?ooooo0_l0000fooooo`;o0000W?oo
ool001cooooo00?o0000ooooooooool0Loooool2o`0002Gooooo0_l0000:ooooo`;o00000oooool2
o`0009cooooo000Looooo`03o`000?oooooooooo09[ooooo0_l0000:ooooo`;o00003_ooool2o`00
00cooooo0_l00023ooooo`007?ooool00ol0003oooooooooo`2Rooooo`;o00003oooool2o`000003
ooooool0003o000000cooooo0_l00023ooooo`007?ooool00ol0003oooooooooo`21ooooo`;o0000
7oooool2o`000003ooooool0003o000000_ooooo0ol0002Dooooo`007?ooool2o`0008;ooooo0_l0
000Rooooo`;o00002oooool2o`0000Oooooo0_l0002<ooooo`007?ooool00ol0003oooooooooo`2C
ooooo`;o00009_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000?ooooo`;o0000M?ooool0
01cooooo00?o0000ooooooooool0Toooool2o`0000Gooooo0_l0000Gooooo`;o00002_ooool2o`00
0003ooooool0003o000000oooooo0_l0001dooooo`007?ooool00ol0003oooooooooo`2>ooooo`;o
00001_ooool2o`0000;ooooo0_l0000Gooooo`;o0000U?ooool001cooooo00?o0000ooooooooool0
S_ooool2o`0000Kooooo0_l00009ooooo`;o0000Y_ooool001cooooo00?o0000ooooooooool0XOoo
ool2o`0000cooooo0_l0000Dooooo`;o0000P_ooool001cooooo00?o0000ooooooooool0Ooooool2
o`0000Gooooo0_l00006ooooo`;o00007oooool3o`0000oooooo0_l00002ooooo`;o00001oooool2
o`0007Wooooo000Looooo`03o`000?oooooooooo07oooooo0_l00005ooooo`Co00001?ooool2o`00
00[ooooo0_l0000Dooooo`;o00003oooool2o`0000_ooooo0_l0001iooooo`007?ooool00ol0003o
ooooooooo`28ooooo`;o00003?ooool2o`0000;ooooo0_l0000Eooooo`;o000000?oooooo`000?l0
00006Oooool2o`0007Sooooo000Looooo`03o`000?oooooooooo06kooooo0_l0000Aooooo`;o0000
4Oooool4o`0000Gooooo0_l00009ooooo`Co00001Oooool2o`000003ooooool0003o000001Wooooo
0_l0001hooooo`007?ooool00ol0003oooooooooo`1/ooooo`Co00003Oooool2o`0000;ooooo0_l0
0009ooooo`;o00001Oooool5o`0000Gooooo0_l00002ooooo`;o00001Oooool4o`0000Wooooo0_l0
000Looooo`;o0000M?ooool001cooooo00?o0000ooooooooool0K?ooool2o`0000Wooooo0_l00004
ooooo`?o00001oooool2o`0000?ooooo0_l00005ooooo`;o000000Coooooo`000?l0003o00002?oo
ool2o`0000cooooo0_l00004ooooo`;o00000oooool2o`0000Cooooo0_l0000Aooooo`Co00000ooo
ool2o`0006gooooo000Looooo`03o`000?oooooooooo07Oooooo0_l00005ooooo`;o00000_ooool2
o`0000;ooooo0ol00003ooooo`;o00001?ooool2o`0000?ooooo0_l00007ooooo`;o00002_ooool2
o`000003ooooool0003o000000Wooooo0_l00004ooooo`;o00000oooool2o`0000kooooo0_l00003
ooooo`;o0000KOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol0
0006ooooo`03o`000?oooooooooo08;ooooo0_l00002ooooo`;o00001?ooool4o`0000;ooooo0_l0
0009ooooo`;o000000?oooooo`000?l000002_ooool3o`0000Wooooo0_l00003ooooo`;o00001_oo
ool2o`0008;ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1kooooo`;o00004Oooool2o`0000[o
oooo1Ol00008ooooo`So00002Oooool2o`0000?ooooo0_l0000Aooooo`;o0000Moooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`00
0?oooooooooo07?ooooo0_l00005ooooo`?o00001_ooool3o`0001Cooooo0ol0000:ooooo`Ko0000
2Oooool2o`0000Sooooo0_l0000>ooooo`;o00000_ooool2o`0007?ooooo00000ooooooo0000oooo
o`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`00057ooooo0_l0
000Pooooo`;o00001Oooool3o`0000Kooooo0ol00004ooooo`?o00003?ooool3o`0000;ooooo0_l0
0006ooooo`;o00000oooool2o`0000;ooooo0_l00005ooooo`?o00001?ooool2o`000003ooooool0
003o000000;o00003oooool3o`0000;ooooo0_l0001_ooooo`0000?oooooo`000?ooool00_ooool0
0ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0DOooool2
o`0002Cooooo0_l000001?oooooo0000o`000?l00006ooooo`;o00001Oooool3o`0000[ooooo1?l0
0003ooooo`;o00001_ooool2o`0000Oooooo0_l00003ooooo`;o000000?oooooo`000?l000001?oo
ool2o`0000?ooooo1?l0000=ooooo`;o00000oooool2o`000003ooooool0003o000006cooooo0000
0ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1]ooooo`?o00001oooool2o`0000Kooooo0_l00002ooooo`;o00004?ooool4
o`0000Kooooo1?l00009ooooo`;o00001_ooool2o`000003ooooool0003o000000;o00002Oooool2
o`0000Wooooo0_l0000:ooooo`;o000000?oooooo`000?l00000JOooool00006oooooomgMgOoV9RH
oooooonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
KOooool3o`0000oooooo0_l0000Cooooo`?o00002?ooool7o`0000Kooooo0_l00004ooooo`Co0000
0oooool2o`0001Cooooo0_l0000<ooooo`?o0000JOooool00006ooooooo^k^ko<S8bo`000?lb<S;o
k^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0G_ooool2o`00
00gooooo0_l00005ooooo`;o00004Oooool2o`0000[ooooo0ol00003ooooo`;o00001_ooool5o`00
00;ooooo0_l00003ooooo`;o00000oooool2o`0000Gooooo1?l00006ooooo`;o00000_ooool2o`00
00?ooooo0_l0000;ooooo`;o00000_ooool2o`0006[ooooo000Looooo`03o`000?oooooooooo05ko
oooo0_l0000=ooooo`;o00001Oooool2o`0000Gooooo0_l0000:ooooo`Co00002?ooool2o`0000Co
oooo0_l0000=ooooo`;o00000oooool2o`0000cooooo0_l00002ooooo`;o00000_ooool2o`0000;o
oooo1?l000000ooooooo0000o`00000;ooooo`;o00002Oooool2o`0006?ooooo000Looooo`03o`00
0?oooooooooo07Gooooo0_l00004ooooo`;o00002_ooool4o`0000_ooooo0_l00007ooooo`;o0000
0oooool2o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o000000?oooooo`000?l00000
2_ooool3o`0000Oooooo0_l00003ooooo`;o00002_ooool2o`0000Sooooo0_l0001Sooooo`007?oo
ool00ol0003oooooooooo`1eooooo`;o00004?ooool2o`0000_ooooo1?l00007ooooo`;o00000ooo
ool2o`000003ooooool0003o000000?ooooo0ol000001?oooooo0000o`000?ooool2o`0000_ooooo
0_l00009ooooo`;o000000?oooooo`000?l000002_ooool2o`0000_ooooo0_l0001Pooooo`007?oo
ool00ol0003oooooooooo`1dooooo`;o00007_ooool3o`000003ooooool0003o000000Oooooo0_l0
0004ooooo`;o00001?ooool2o`0000Cooooo0_l00002ooooo`;o00003oooool2o`000003ooooool0
003o000000Cooooo0_l0000?ooooo`;o00000oooool2o`00063ooooo000Looooo`03o`000?oooooo
oooo05Oooooo0_l0000Kooooo`Co00002oooool2o`0000Wooooo0_l00005ooooo`;o000000?ooooo
o`000?l000001oooool2o`0000;ooooo0_l0000:ooooo`;o00001?ooool3o`0000kooooo0_l00006
ooooo`Co00003_ooool2o`0006Gooooo000Looooo`03o`000?oooooooooo05Oooooo0_l0000Moooo
o`;o00002oooool2o`0000Wooooo0_l0000Aooooo`;o00000_ooool2o`0000Oooooo0_l000000ooo
oooo0000o`000005ooooo`;o00005_ooool4o`0007Gooooo000Looooo`03o`000?oooooooooo0:ko
oooo0_l0000Aooooo`;o00001oooool2o`0000Cooooo1Ol0001dooooo`007?ooool00ol0003ooooo
ooooo`1`ooooo`;o00003?ooool2o`0000_ooooo0_l0000dooooo`Co00001Oooool2o`0000Cooooo
1Ol0000:ooooo`?o000000?oooooo`000?l00000I?ooool001cooooo00?o0000ooooooooool0L?oo
ool2o`000003ooooool0003o000000Wooooo0_l00007ooooo`;o00000_ooool2o`0002Oooooo0_l0
000<ooooo`?o00002?ooool2o`0000Sooooo0_l00002ooooo`;o00000_ooool6o`0006Cooooo000L
ooooo`03o`000?oooooooooo06kooooo0ol00002ooooo`;o00004_ooool2o`0002Wooooo1?l0000<
ooooo`;o00002Oooool2o`0000Sooooo0_l00002ooooo`;o00000oooool5o`0006Cooooo000Loooo
o`03o`000?oooooooooo05;ooooo0_l0000Jooooo`?o00002?ooool3o`0000Cooooo0_l00005oooo
o`;o00002oooool2o`0001cooooo0_l0000;ooooo`;o00002_ooool2o`0000Cooooo0_l00005oooo
o`;o00001?ooool5o`0006Kooooo000Looooo`;o0000A?ooool2o`0000[ooooo0_l000000ooooooo
0000o`00000Pooooo`;o00000oooool3o`0000Cooooo1?l00003ooooo`;o00000oooool2o`0000Ko
oooo0_l0000Pooooo`;o00001oooool2o`0000[ooooo0_l00004ooooo`Co00000oooool2o`0000Co
oooo0_l000000ooooooo0000o`000003ooooo`;o0000HOooool001cooooo00?o0000ooooooooool0
@oooool2o`0000[ooooo0_l0000Sooooo`;o00001?ooool2o`000003ooooool0003o000000?ooooo
0_l00003ooooo`;o00000oooool2o`0002Sooooo1?l00008ooooo`;o00002_ooool2o`0000?ooooo
0_l00003ooooo`;o00000oooool2o`0000Oooooo0_l0001Qooooo`007?ooool00ol0003ooooooooo
o`1jooooo`;o000000?oooooo`000?l000004oooool2o`0002Cooooo0_l00008ooooo`;o00000_oo
ool2o`0000Kooooo0_l00005ooooo`;o000000?oooooo`000?l000000oooool6o`000003ooooool0
003o000000?ooooo0_l0001Nooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o00002?ooool2
o`0000Cooooo0_l0000;ooooo`;o00001?ooool2o`0000[ooooo0_l000000ooooooo0000o`00000U
ooooo`Go00001?ooool2o`0000;ooooo0_l00005ooooo`;o00001?ooool4o`0000;ooooo1Ol00000
0ooooooo0000o`000005o`0000?ooooo0_l0001Nooooo`007?ooool00ol0003oooooooooo`1Poooo
o`;o00002?ooool2o`0000Cooooo0_l00005ooooo`;o00001?ooool2o`0000Cooooo0_l0000:oooo
o`;o0000:?ooool5o`0000Cooooo0_l00009ooooo`;o00001?ooool2o`0000Cooooo1_l00003oooo
o`;o0000IOooool001cooooo00?o0000ooooooooool0Ioooool2o`0000?ooooo0_l00003ooooo`;o
00001?ooool2o`0005Gooooo0_l0000=ooooo`;o00000oooool2o`0006Gooooo000Looooo`03o`00
0?oooooooooo05Sooooo0ol0000<ooooo`;o00000oooool2o`0000?ooooo0ol000000ooooooo0000
o`000004o`0003Cooooo0_l0000Eooooo`;o00001_ooool4o`00023ooooo0_l0001Eooooo`007?oo
ool00ol0003oooooooooo`19ooooo`;o00000oooool2o`0000Sooooo0ol00003ooooo`;o00003?oo
ool2o`000004ooooool0003o0000ooooo`;o000000Coooooo`000?l0003ooooo1_l0000Aooooo`;o
00007_ooool2o`00013ooooo0_l00003ooooo`;o00002?ooool2o`00023ooooo0_l0001Eooooo`00
7?ooool00ol0003oooooooooo`19ooooo`;o00000oooool2o`0000cooooo1?l0000?ooooo`;o0000
2Oooool4o`0000kooooo0_l000001?oooooo0000o`000?ooool2o`0001Sooooo0_l0000Cooooo`;o
00001oooool2o`0000Cooooo0_l0000@ooooo`;o0000IOooool001cooooo00?o0000ooooooooool0
G?ooool2o`0000;ooooo0_l0000:ooooo`;o00001Oooool2o`0000;ooooo1Ol0000@ooooo`;o0000
1?ooool2o`0001Oooooo1?l0000<ooooo`;o00003Oooool2o`0000[ooooo0_l0000:ooooo`;o0000
0_ooool2o`0000Gooooo1?l0001Hooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o000000?o
ooooo`000?l000000_l00004ooooo`?o00000_ooool2o`000003ooooool0003o000000;ooooo0ol0
0005ooooo`;o00002_ooool2o`000003ooooool0003o000001;ooooo0_l00005ooooo`Ko00001ooo
ool2o`0000?ooooo0_l0000Iooooo`;o00001_ooool2o`0000;ooooo0_l00002ooooo`;o00001Ooo
ool4o`0000?ooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`1Kooooo`;o000000?ooooo
o`000?l000000oooool6o`0000;ooooo1?l000000ooooooo0000o`00000=ooooo`;o00002_ooool2
o`000003ooooool0003o000001;ooooo0_l00005ooooo`;o00002oooool3o`0000;ooooo0_l0000:
ooooo`;o00002?ooool2o`0000?ooooo0_l00006ooooo`;o00001_ooool2o`0000Gooooo0_l00005
ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0E_ooool2o`0000?ooooo0_l000000ooo
oooo0000o`000005ooooo`Co00001?ooool2o`0001_ooooo0_l00005ooooo`;o00003oooool3o`00
017ooooo1ol00009ooooo`?o00002?ooool2o`0000?ooooo0_l0000>ooooo`;o00001?ooool2o`00
00Kooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00004?ooool2o`0000Wo
oooo0_l00003ooooo`?o00000oooool2o`0001cooooo0_l00009ooooo`Co00000oooool2o`0000_o
oooo0_l00002ooooo`Co00001_ooool2o`0000Sooooo0_l000000ooooooo0000o`00000;ooooo`;o
00006Oooool2o`0000Wooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`0iooooo`;o0000
4?ooool2o`0000kooooo0ol00003ooooo`;o00007?ooool2o`0000_ooooo0ol00002ooooo`?o0000
2_ooool2o`0000Cooooo0_l00002ooooo`;o00000_ooool2o`0001?ooooo0_l00006ooooo`;o0000
5?ooool4o`0000?ooooo0_l0001Qooooo`007?ooool00ol0003oooooooooo`0jooooo`;o00005_oo
ool2o`0000Oooooo0_l00004ooooo`;o00006oooool2o`0000;ooooo0_l00009ooooo`?o00000_oo
ool2o`0001Cooooo0_l0000Gooooo`;o00001_ooool2o`0000kooooo0_l00004ooooo`;o00001Ooo
ool3o`0000[ooooo0_l000000ooooooo0000o`00001Aooooo`007?ooool2o`0003_ooooo0_l0000F
ooooo`;o00001?ooool2o`0000Oooooo0_l0000Kooooo`;o00000_ooool2o`0000Gooooo0_l00003
ooooo`;o00006oooool2o`0000Kooooo0_l0000Sooooo`Go00002_ooool2o`0000?ooooo0_l00004
ooooo`Oo0000D?ooool001cooooo00?o0000ooooooooool0?_ooool2o`0000;ooooo0_l00002oooo
o`;o00002_ooool2o`0000Cooooo0_l00006ooooo`;o00005?ooool2o`00017ooooo0_l00007oooo
o`;o00005_ooool3o`0000Kooooo0_l00003ooooo`;o00007_ooool2o`000003ooooool0003o0000
00_ooooo0_l00002ooooo`;o00001?ooool4o`000003ooooool0003o0000053ooooo000Looooo`03
o`000?oooooooooo03kooooo0_l00002ooooo`;o00000_ooool2o`0000Oooooo1Ol00005ooooo`;o
00001Oooool4o`0001;ooooo0_l0000Jooooo`;o00003Oooool2o`0000Oooooo0ol00005ooooo`;o
00000_ooool4o`0002?ooooo0_l00009ooooo`;o00003Oooool2o`00053ooooo000Looooo`03o`00
0?oooooooooo04oooooo1?l00006ooooo`;o00001oooool2o`0000;ooooo1?l0000@ooooo`;o0000
00?oooooo`000?l000004Oooool2o`0000oooooo0_l0000?ooooo`;o00000_ooool2o`0001Kooooo
0ol0000<ooooo`?o00002_ooool2o`0005gooooo000Looooo`03o`000?oooooooooo04gooooo0_l0
0004ooooo`?o00001?ooool4o`0000Sooooo1?l0000=ooooo`;o000000Coooooo`000?l0003ooooo
0_l0000Aooooo`;o00000oooool2o`0001Cooooo1?l00008ooooo`;o000000?oooooo`000?l00000
4_ooool3o`0000?ooooo0_l00006ooooo`Co00002_ooool2o`0005gooooo000Looooo`03o`000?oo
oooooooo04Sooooo0_l00003ooooo`;o00001?ooool3o`0000Cooooo1?l0000Iooooo`;o00005?oo
ool2o`0000Kooooo0_l00009ooooo`;o00002Oooool4o`0000Sooooo0_l000000ooooooo0000o`00
000Hooooo`;o00001_ooool4o`0000cooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`18
ooooo`;o00004_ooool2o`0000Cooooo0_l0000Looooo`;o00000_ooool2o`0000Oooooo0_l00002
ooooo`;o00003Oooool2o`000003ooooool0003o000000_ooooo0_l000000ooooooo0000o`000009
ooooo`;o00007_ooool2o`0000cooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`1:oooo
o`;o00001oooool2o`0000gooooo1?l00009ooooo`;o00003oooool2o`0000;ooooo0_l00007oooo
o`;o00000_ooool2o`00013ooooo0_l0000;ooooo`;o000000?oooooo`000?l000000_l00007oooo
o`;o000000Goooooo`000?l0003o0000ooooo`02o`00017ooooo0ol0000?ooooo`;o00001oooool2
o`0000?ooooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00002?ooool2o`00
00Oooooo1?l00008ooooo`;o000000?oooooo`000?l000000_l00006ooooo`;o000000?oooooo`00
0?l000001oooool2o`000003ooooool0003o000000?ooooo0_l0000Yooooo`;o00002?ooool2o`00
00Gooooo0_l00003ooooo`Ko00004Oooool4o`0000Wooooo1?l000000ooooooo0000o`000005oooo
o`Co000000?oooooo`000?l000000ol0001>ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o
00004oooool2o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l000002?ooool2o`0000[o
oooo0_l000000ooooooo0000o`00000=ooooo`;o00001Oooool2o`0001?ooooo0_l00003ooooo`;o
00002?ooool9o`0000;ooooo0_l00002ooooo`;o00004_ooool4o`0000Wooooo1?l000001?oooooo
0000o`000?ooool2o`0000;ooooo1?l000001?oooooo0000o`000?ooool2o`0004kooooo000Loooo
o`03o`000?oooooooooo05Wooooo0_l0000;ooooo`;o00007?ooool2o`0000Cooooo0ol00004oooo
o`;o00000_ooool2o`000003ooooool0003o000000_ooooo0ol00003ooooo`?o00000_ooool3o`00
00;ooooo1ol00004ooooo`;o00001Oooool2o`0000oooooo0_l00008ooooo`;o00000_ooool2o`00
00?ooooo1Ol0001Iooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00003oooool2o`0000Ko
oooo0_l0000Aooooo`;o00002Oooool3o`0001_ooooo0ol00002ooooo`Co00001_ooool4o`000003
ooooool0003o000000Cooooo0_l00005ooooo`;o00000oooool5o`000003ooooool0003o000000Oo
00002?ooool3o`0000?ooooo0ol0000>ooooo`Go00001Oooool2o`0000;ooooo0_l00003ooooo`Go
00000_ooool4o`0000Cooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o0000
3oooool2o`0000Kooooo0_l00003ooooo`;o00003?ooool2o`0000[ooooo0_l0000Looooo`;o0000
0_ooool2o`0000Cooooo0_l00002ooooo`;o00002Oooool2o`0000Kooooo0_l000001Ooooooo0000
o`000?l0003ooooo00Co000000?oooooo`000?l000002?l00004ooooo`Oo000000?oooooo`000?l0
00000_ooool2o`0000_ooooo1?l00002ooooo`;o00001?ooool2o`0000_ooooo1?l00004ooooo`;o
0000COooool001cooooo00?o0000ooooooooool0<Oooool2o`0000gooooo0_l0000;ooooo`;o0000
0_ooool2o`0001Wooooo0_l0000;ooooo`;o00005?ooool4o`0000oooooo0_l00002ooooo`;o0000
00Coooooo`000?l0003ooooo1Ol000000ooooooo0000o`000002o`0000;ooooo1?l00004ooooo`;o
000000?oooooo`000?l000000_l00005ooooo`;o00000_ooool2o`0000[ooooo2?l000000ooooooo
0000o`00000Aooooo`;o0000Coooool001cooooo00?o0000ooooooooool0<Oooool2o`0000;ooooo
0_l00009ooooo`;o00003oooool2o`0001Wooooo0_l0000;ooooo`;o00005Oooool3o`0000;ooooo
0_l00003ooooo`;o00001_ooool2o`0000;ooooo0_l00004ooooo`Co00000oooool9o`0001Cooooo
0_l00002ooooo`;o00000_ooool2o`0000;ooooo1?l000001?oooooo0000o`000?l00008ooooo`;o
00001_ooool2o`0000;ooooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`0eooooo`;o0000
3_ooool2o`0001Wooooo0_l0000?ooooo`;o00005oooool2o`0000Cooooo0_l000000ooooooo0000
o`000002o`0000?ooooo0_l00009ooooo`?o00000oooool6o`0000;ooooo2Ol00002ooooo`;o0000
00Coooooo`000?l0003o00004?ooool2o`0000;ooooo0_l0000?ooooo`;o000000?oooooo`000?l0
00001_ooool6o`0004oooooo000Looooo`;o0000A_ooool2o`0001Oooooo1?l00006ooooo`Co0000
1Oooool2o`0000Oooooo0_l0000>ooooo`;o00001oooool5o`0000[ooooo1Ol00004ooooo`;o0000
00?oooooo`000?l000003?l000001Ooooooo0000o`000?l0003ooooo00?o00003oooool2o`0000Wo
oooo0_l00005ooooo`;o00000_ooool2o`0000Sooooo0_l000000ooooooo0000o`00001Aooooo`00
7?ooool00ol0003oooooooooo`15ooooo`Co00001_ooool2o`0000Cooooo0_l00007ooooo`;o0000
2?ooool4o`0000Sooooo0_l00004ooooo`;o00006Oooool5o`0000Sooooo0ol00004ooooo`;o0000
0oooool6o`000003ooooool0003o000000So00000oooool2o`0000oooooo0_l00009ooooo`?o0000
1?ooool2o`0000Oooooo0_l00003ooooo`;o0000E?ooool001cooooo00?o0000ooooooooool0AOoo
ool4o`0000Kooooo0_l00003ooooo`Go00006Oooool4o`0000Cooooo0_l00004ooooo`;o00000ooo
ool2o`00013ooooo0ol00006ooooo`Co000000?oooooo`000?l000006?l00002ooooo`Co00000_oo
ool4o`0000kooooo0_l00003ooooo`?o000000?oooooo`000?l000000ol000001?oooooo0000o`00
0?ooool5o`0000Sooooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`18ooooo`;o000000?o
ooooo`000?l000001_ooool3o`000003ooooool0003o000000Gooooo0_l000000ooooooo0000o`00
0004ooooo`;o00002Oooool2o`0000cooooo0_l00003ooooo`;o00003?ooool2o`0000;ooooo0_l0
0007ooooob3o000000?oooooo`000?l000002?l000000ooooooo0000o`00000;ooooo`;o00001ooo
ool4o`0000;ooooo0_l000000ooooooo0000o`000002o`0000Gooooo0_l00002ooooo`Co0000COoo
ool001cooooo00?o0000ooooooooool0>oooool2o`000003ooooool0003o000000Sooooo0_l00000
0ooooooo0000o`000006ooooo`Go00000oooool2o`000004ooooool0003o0000ooooo`Co00000_oo
ool2o`0000?ooooo0_l0000Aooooo`Go000000?oooooo`000?l000003?ooool2o`0000Kooooo1?l0
0003ooooo`?o00001?ooool5o`0000;ooooo3Ol000000ooooooo0000o`000008o`0000Cooooo0_l0
0004ooooo`;o00002Oooool2o`000003ooooool0003o000000;o00001?ooool3o`0000Wooooo0_l0
0004ooooo`;o0000COooool001cooooo00?o0000ooooooooool09_ooool2o`0001?ooooo0_l00000
0ooooooo0000o`00000;ooooo`;o00002Oooool2o`0000?ooooo0_l00006ooooo`;o00000_ooool2
o`0000?ooooo0_l0000=ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo0_l00000
0ooooooo0000o`000002o`0000Kooooo0_l00006ooooo`Co00000_ooool5o`0000;ooooo8?l00004
ooooo`;o00000_ooool4o`0000?ooooo1?l00002ooooo`;o000000?oooooo`000?l000001?l00002
ooooo`Wo00002?ooool2o`0000Oooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`0Voooo
o`;o00004Oooool2o`0001;ooooo0_l0000:ooooo`;o00001Oooool2o`0000;ooooo0_l000000ooo
oooo0000o`000002o`000003ooooool0003o000000Go00002?ooool2o`0000Wooooo0_l000000ooo
oooo0000o`000002o`0000;ooooo0_l00007ooooo`;o00000_ooool2o`000003ooooool0003o0000
00Go00000_ooool5o`000003ooooool0003o0000017o000000Goooooo`000?l0003o0000ooooo`02
o`0000?ooooo1?l000001?oooooo0000o`000?ooool2o`0000;ooooo1?l00003ooooo`;o00000_oo
ool4o`0000;ooooo0_l000000ooooooo0000o`000004o`0000Sooooo0_l00007ooooo`;o0000AOoo
ool001cooooo00?o0000ooooooooool0>Oooool2o`0001;ooooo0_l00006ooooo`;o000000Cooooo
o`000?l0003o00001Oooool2o`0000;ooooo0ol000000ooooooo0000o`00000:o`0000?ooooo0ol0
000?ooooo`;o00000oooool3o`0000Oooooo0_l00002ooooo`So00000ooooolJo`000003ooooool0
003o000000;o00001Oooool4o`0000Cooooo0_l00009ooooo`;o00001Oooool2o`000003ooooool0
003o000000Oooooo0_l000000ooooooo0000o`00001Cooooo`007?ooool00ol0003oooooooooo`0h
ooooo`;o00006oooool2o`000003ooooool0003o000000Oooooo0_l00002ooooo`;o000000?ooooo
o`000?l000001Ol000000ooooooo0000o`000003o`000003ooooool0003o000000;o000000?ooooo
o`000?l000001Ol00003ooooo`?o00001_ooool2o`0000cooooo0ol00002ooooo`Go000000?ooooo
o`000?l000007ol0000:ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00001ooo
ool2o`0000[ooooo0_l000000ooooooo0000o`00000:ooooo`;o0000Aoooool001cooooo00?o0000
ooooooooool0>?ooool2o`0002Kooooo5Ol000000ooooooo0000o`000002ooooo`So00000oooool3
o`0001Cooooo0ol000000ooooooo0000o`00000Fo`000003ooooool0003o000000go00002?ooool4
o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0002;ooooo0_l00017ooooo`007?ooool0
0ol0003oooooooooo`0_ooooo`;o00009_ooool2o`0000Gooooo7_l00002ooooo`;o00002_ooool2
o`0000_ooooo0_l00006oooooako000000?oooooo`000?l000001ol00004ooooo`Co000000?ooooo
o`000?l000001Oooool2o`0000Gooooo0_l00002ooooo`;o00001_ooool2o`0000Kooooo0_l00006
ooooo`Co0000Boooool001cooooo00?o0000ooooooooool0;oooool2o`0000;ooooo0_l00007oooo
o`;o00005?ooool2o`0000?ooooo0_l00005ooooo`?o000000?oooooo`000?l000007?l00002oooo
o`?o00001Oooool2o`0000_ooooo1?l00004ooooo`?o00000_oooolSo`0000Cooooo1?l000000ooo
oooo0000o`000002o`0000?ooooo0_l00004ooooo`?o00000_ooool4o`0000Cooooo1?l000001?oo
oooo0000o`000?ooool2o`0000;ooooo2?l00007ooooo`;o0000@_ooool001cooooo00?o0000oooo
ooooool0<oooool2o`0000;ooooo0_l00003ooooo`;o00002Oooool2o`0000Wooooo0_l000000ooo
oooo0000o`000007ooooobOo00004?ooool2o`0000;ooooo0_l00003ooooo`?o00000ooooolSo`00
00Gooooo0_l000001?oooooo0000o`000?ooool2o`0000Wooooo0ol00004ooooo`Go00000oooool2
o`000003ooooool0003o000000Cooooo1_l00009ooooo`?o0000@_ooool001cooooo00?o0000oooo
ooooool0=Oooool4o`000003ooooool0003o000000Sooooo0_l000000ooooooo0000o`000002o`00
00?ooooo0_l00005ooooo`;o000000Coooooo`000?l0003o00000ooooolJo`000003ooooool0003o
000000;o00000_ooool4o`0001;ooooo0_l00007ooooo`?o000000?oooooo`000?l000003?l00003
oooooa7o00000oooool4o`0000Cooooo0_l00006ooooo`;o00003?ooool5o`0000Cooooo0_l00005
ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Cooooo0_l00013ooooo`0000Koooooonk^
k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool0=Oooool2o`0000?ooooo0_l00008ooooo`;o00000_ooool3o`0000?ooooo0_l0
0004ooooo`;o00000_ooool3o`0000;ooooo1Ol000000ooooooo0000o`00000;o`000003ooooool0
003o000000co00000oooool2o`0000;ooooo0_l00003ooooo`;o00004_oooolAo`000003ooooool0
003o000001So00000oooool2o`0000Oooooo0_l000000ooooooo0000o`00000<ooooo`;o00001?oo
ool2o`0000Kooooo0_l00006ooooo`;o0000BOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0dooooo`;o0000
3_ooool2o`0000;ooooo0_l00007ooooo`;o000000?oooooo`000?l000000_ooool3o`0000;ooooo
8_l00002ooooo`?o00000_ooool2o`0000?ooooo0_l0000=ooooo`Go000000?oooooo`000?l00000
9Ol00002ooooo`;o00000oooool2o`0000[ooooo0_l000000ooooooo0000o`000002o`0000gooooo
0_l00006ooooo`Co0000Coooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Ooo
ool5o`0000Kooooo00?o0000ooooooooool0=?ooool2o`0001_ooooo0_l00005ooooo`;o00000ooo
oolNo`0000;ooooo0_l00002ooooo`;o00003?ooool2o`0000Sooooo8?l000000ooooooo0000o`00
000:o`000004ooooool0003o0000o`0000Gooooo0_l0000<ooooo`Co00003Oooool2o`0000Gooooo
0_l000000ooooooo0000o`000007ooooo`;o0000A_ooool00003ooooool0003ooooo00;ooooo00?o
0000ooooooooool02Oooool01?m4A4CogMgMooooool00007ooooo`?o0000@oooool2o`0000cooooo
0_l00004ooooo`;o00001?oooolRo`0000cooooo0_l00002ooooo`;o00001oooool3o`0000?ooooo
3_l00002oooooako00000_ooool3o`0000cooooo0_l0000;ooooo`;o00002?ooool3o`0000[ooooo
0_l00016ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmE
EEGoooooo`0000Oooooo00?o0000ooooooooool0@?ooool2o`000003ooooool0003o000000Kooooo
1Ol000000ooooooo0000o`000002ooooo`Co000000?oooooo`000?l000008ol0000<ooooo`?o0000
1Oooool4o`000004ooooool0003o0000o`0000?ooooo:_l00002ooooo`;o00000_ooool2o`000003
ooooool0003o000000Oooooo0_l000000ooooooo0000o`000002o`0000Wooooo0ol00007ooooo`;o
00003Oooool2o`0004Cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo
00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0/ooooo`;o00004_ooool2o`0000;ooooo
0_l00003ooooo`Oo000000?oooooo`000?l000000_ooool2o`0000?ooooo1_l000000ooooooo0000
o`00000Mo`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l000001Oooool4o`0000;ooooo
0_l00003ooooob7o000000?oooooo`000?l000002?l00002ooooo`Co000000?oooooo`000?l00000
0_l00005ooooo`Oo00000_ooool2o`0000Cooooo1?l0000Fooooo`;o0000A?ooool00006oooooomg
MgOoV9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo02co
oooo0_l0000Fooooo`;o00000oooool2o`0000oooooo0_l00005oooooaGo000000?oooooo`000?l0
00001?l000000ooooooo0000o`000005o`0000Cooooo0_l0000>ooooo`;o000000?oooooo`000?l0
00000_l000000ooooooo0000o`00000Po`000003ooooool0003o000000Co00000_ooool4o`0000?o
oooo0_l00007ooooo`Co00000oooool4o`0000;ooooo0_l0000;ooooo`Go00001_ooool2o`000003
ooooool0003o000004?ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`00
0?ooool01_ooool00ol0003oooooooooo`1>ooooo`;o00002_ooool4o`000003ooooool0003o0000
01_o00000oooool4o`0001Wooooo0_l00004ooooo`Co000000?oooooo`000?l000008Ol00002oooo
o`;o00001Oooool2o`0000Wooooo0_l00002ooooo`Go00001?ooool3o`0000Sooooo1Ol00006oooo
o`;o000000Coooooo`000?l0003o0000@_ooool001cooooo00?o0000ooooooooool0@?ooool4o`00
00Sooooo1Ol00007ooooo`;o000000?oooooo`000?l000007ol0000Jooooo`Co00001Oooool_o`00
00Gooooo0_l00003ooooo`;o00000oooool4o`000003ooooool0003o000000?ooooo0_l00002oooo
o`?o00001?ooool2o`00017ooooo1?l00010ooooo`007?ooool00ol0003oooooooooo`0kooooo`;o
00000oooool4o`000004ooooool0003o0000o`0000Cooooo0_l000001?oooooo0000o`000?ooool2
o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l000002_l000000ooooooo0000o`000002
o`000003ooooool0003o000000[o000000?oooooo`000?l000001_ooool2o`0000cooooo1ol00002
ooooo`Co000000?oooooo`000?l00000:?l0000:ooooo`;o00000oooool4o`0000Kooooo0_l00009
ooooo`;o00001Oooool2o`0000cooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0koooo
o`;o00002?ooool3o`0000[ooooo0_l0000:ooooo`Co000000?oooooo`000?l000006_l000001?oo
oooo0000o`000?ooool2o`0000?ooooo0_l00002ooooo`;o00003?ooool7o`000003ooooool0003o
000001?o000000?oooooo`000?l000001Ol000000ooooooo0000o`00000;o`0000;ooooo0_l00007
ooooo`?o00001oooool2o`0000_ooooo0_l00008ooooo`;o00001_ooool2o`0004Kooooo000Loooo
o`03o`000?oooooooooo03_ooooo0_l0000?ooooo`;o00001?ooool2o`0000[ooooo2_l000001Ooo
oooo0000o`000?l0003ooooo013o000000?oooooo`000?l000000oooool2o`0000?ooooo0_l00002
ooooo`?o00002Oooool3o`000003ooooool0003o000002[o000000?oooooo`000?l000000_l00002
ooooo`;o00001oooool3o`000003ooooool0003o000000Cooooo1?l00009ooooo`;o000000?ooooo
o`000?l000003Oooool3o`0004Gooooo000Looooo`03o`000?oooooooooo02oooooo0_l0000Boooo
o`;o00001Oooool4o`0000Cooooo0ol0000:ooooo`go000000?oooooo`000?l000003_l000000ooo
oooo0000o`000008ooooo`;o000000?oooooo`000?l000000_l00009ooooo`?o000000Goooooo`00
0?l0003o0000ooooo`0Wo`000003ooooool0003o000000;o00001Oooool2o`0000Kooooo0_l00000
0ooooooo0000o`000006ooooo`;o00002Oooool2o`000003ooooool0003o000000kooooo0_l00005
ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0;oooool2o`0001;ooooo0_l00005oooo
o`;o00001oooool2o`0000Wooooo7_l00008ooooo`;o00001Oooool3o`0001;ooooo9ol000000ooo
oooo0000o`000007ooooo`;o00001Oooool2o`0000Cooooo0_l000000ooooooo0000o`000009oooo
o`;o00002Oooool2o`0000Sooooo0_l00006ooooo`;o00006?ooool2o`0002Cooooo000Looooo`03
o`000?oooooooooo03kooooo0_l0000:ooooo`;o00001oooool2o`0000Oooooo7_l0000:ooooo`;o
00000_ooool2o`000004ooooool0003o0000o`0000oooooo0_l00003ooooo`oo000000?oooooo`00
0?l000004ol000000ooooooo0000o`00000>ooooo`Go000000Coooooo`000?l0003ooooo0_l00002
ooooo`;o00001?ooool3o`0000Wooooo0_l00007ooooo`?o00000oooool2o`0001_ooooo0_l0000T
ooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00002oooool2o`0000cooooo0_l000001?oo
oooo0000o`000?l00002oooooaWo000000?oooooo`000?l000002oooool2o`000004ooooool0003o
0000o`0000Wooooo0_l00004ooooo`;o00000oooool7o`0000;ooooo7?l0000?ooooo`;o000000?o
ooooo`000?l000000_l00008ooooo`;o00001?ooool3o`000003ooooool0003o000000oooooo0ol0
00000ooooooo0000o`000002o`000003ooooool0003o000003kooooo000Looooo`03o`000?oooooo
oooo03oooooo0_l00002ooooo`Co00001?ooool2o`0000cooooo0_l00005ooooo`?o00000_oooolH
o`0000[ooooo0ol000000ooooooo0000o`00000:ooooo`Co00000oooool2o`000003ooooool0003o
000000Ko000000?oooooo`000?l000006Ol00004ooooo`;o00002oooool2o`0001Cooooo0_l00000
0ooooooo0000o`000006ooooo`;o00002?ooool2o`000003ooooool0003o000000?ooooo0_l0000n
ooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00000_ooool4o`0000Oooooo0_l0000@oooo
o`;o00001OoooolAo`000003ooooool0003o000000cooooo0_l00002ooooo`;o00002Oooool2o`00
0003ooooool0003o000000?ooooo9?l00003ooooo`;o00000_ooool2o`0000[ooooo0_l0000;oooo
o`;o00002?ooool2o`0000Wooooo0_l00003ooooo`;o00002?ooool2o`00047ooooo000Looooo`03
o`000?oooooooooo04?ooooo1?l00007ooooo`;o00004_ooool3o`0000;ooooo2ol00002ooooo`Co
000000Coooooo`000?l0003ooooo0_l00007ooooo`;o00003oooool2o`000003ooooool0003o0000
00Cooooo1?l00003oooooaSo00000_ooool2o`0000?ooooo0ol000000ooooooo0000o`000006oooo
o`;o00000_ooool2o`0000_ooooo0_l00008ooooo`;o00003_ooool4o`0000Kooooo0_l00011oooo
o`007?ooool2o`0004Gooooo0_l00002ooooo`;o00003oooool2o`0000?ooooo0_l00002ooooo`?o
00000oooool4o`0000;ooooo1?l000001?oooooo0000o`000?ooool2o`000004ooooool0003o0000
ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00004oooool2o`0000Gooooo0ol00002
ooooo`go000000?oooooo`000?l000000ol000001?oooooo0000o`000?l00003ooooo`?o000000Co
ooooo`000?l0003o00001Oooool2o`0000;ooooo0_l0000=ooooo`;o00002oooool2o`0000_ooooo
0_l00005ooooo`;o00001Oooool2o`0003_ooooo000Looooo`03o`000?oooooooooo02Gooooo0_l0
000Cooooo`;o00001?ooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000003?oo
ool2o`0000?ooooo0_l00009ooooo`Oo00000oooool2o`0000cooooo0_l00007ooooo`?o00001?oo
ool2o`0000kooooo0_l000000ooooooo0000o`000002o`0000;ooooo0ol000000ooooooo0000o`00
0008o`000003ooooool0003o000000;o00000_ooool3o`0000;ooooo1Ol000000ooooooo0000o`00
0009ooooo`;o00002oooool4o`0000_ooooo0_l00006ooooo`;o00002_ooool2o`0000?ooooo1?l0
000kooooo`007?ooool00ol0003oooooooooo`0Uooooo`;o00004oooool2o`0000Cooooo0_l00009
ooooo`;o000000?oooooo`000?l000005oooool3o`000003ooooool0003o000000;o00000_ooool2
o`0000Gooooo0_l000000ooooooo0000o`00000=ooooo`Co00000oooool2o`0000Oooooo0_l00005
ooooo`;o000000?oooooo`000?l000001ol00003ooooo`So000000?oooooo`000?l000000ol00003
ooooo`So00004?ooool2o`0000Oooooo0_l0000@ooooo`;o00000oooool2o`0000cooooo0_l00000
0ooooooo0000o`00000mooooo`007?ooool00ol0003oooooooooo`0gooooo`;o000000?oooooo`00
0?l000001Oooool4o`0000Sooooo0ol0000Gooooo`?o00001oooool2o`0000Gooooo0_l000000ooo
oooo0000o`000004ooooo`?o00002?ooool2o`0000[ooooo1?l000000ooooooo0000o`000002oooo
o`;o00000oooool6o`000005ooooool0003o0000o`000?ooool01ol000000ooooooo0000o`000004
o`0000;ooooo1?l0000Dooooo`;o00000oooool2o`0000Oooooo0_l0000:ooooo`Go00001Oooool2
o`0000Sooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0gooooo`Co00001_ooool4o`00
00Sooooo0_l00003ooooo`Co00000oooool2o`0000;ooooo0_l0000=ooooo`;o00004oooool3o`00
00Sooooo0_l0000:ooooo`;o00000oooool2o`0000;ooooo1ol000001Ooooooo0000o`000?l0003o
oooo01;o00007oooool2o`0000Oooooo0_l000000ooooooo0000o`000003ooooo`;o00000_ooool2
o`000003ooooool0003o000000Gooooo0_l00002ooooo`;o0000A_ooool001cooooo00?o0000oooo
ooooool0>?ooool3o`0000Wooooo0_l0000<ooooo`Co00000oooool2o`0000;ooooo0_l000000ooo
oooo0000o`000009ooooo`?o00004?ooool2o`0000Kooooo0_l00004ooooo`;o00002Oooool2o`00
00[ooooo2_l00003ooooo`;o000000?oooooo`000?l000001?l00002ooooo`Ko00000_ooool3o`00
00Sooooo0_l00003ooooo`;o00003?ooool2o`0000Oooooo0_l00003ooooo`;o00002Oooool2o`00
00Cooooo0ol00016ooooo`007?ooool00ol0003oooooooooo`0fooooo`Co00002_ooool2o`000003
ooooool0003o000000Cooooo0_l00003ooooo`?o00000oooool2o`0000Kooooo0_l00006ooooo`;o
000000?oooooo`000?l000001_ooool2o`0000Wooooo0_l000000ooooooo0000o`000002ooooo`?o
00001?ooool4o`0000Gooooo1?l00003ooooo`;o00001Oooool2o`0000?ooooo0_l000001Ooooooo
0000o`000?l0003ooooo00Co000000?oooooo`000?l000001?l00003ooooo`Co00000_ooool3o`00
00Sooooo0_l00003ooooo`;o00003?ooool2o`0000Kooooo0_l000000ooooooo0000o`00000<oooo
o`;o00001?ooool4o`0000Kooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0fooooo`?o
00001oooool2o`000003ooooool0003o000000Co00001?ooool2o`0000?ooooo0_l00004ooooo`;o
00001Oooool3o`0000Kooooo0_l000000ooooooo0000o`000006ooooo`;o00002?ooool;o`000003
ooooool0003o000000?ooooo0ol00003ooooo`?o00001Oooool2o`0000Cooooo0_l00007ooooo`?o
000000?oooooo`000?l000000ol00003ooooo`?o000000?oooooo`000?l000001_ooool2o`0000Go
oooo0_l00003ooooo`;o00002Oooool2o`0000Wooooo0_l00002ooooo`;o000000?oooooo`000?l0
00005?ooool2o`0000Cooooo1?l0000mooooo`007?ooool00ol0003oooooooooo`0nooooo`Co0000
00?oooooo`000?l000001?l00009ooooo`;o00001oooool2o`000004ooooool0003o0000o`0000[o
oooo0_l00003ooooo`;o000000?oooooo`000?l000002?ooool4o`0000;ooooo1?l00002ooooo`;o
00000_ooool4o`0000?ooooo0ol00005ooooo`;o00001?ooool2o`0000Oooooo0_l000000ooooooo
0000o`000006o`000003ooooool0003o000000Co00000_ooool2o`0000Oooooo1?l00003ooooo`;o
00002Oooool2o`0000Wooooo0_l000000ooooooo0000o`000004ooooo`;o00001?ooool2o`0000go
oooo0_l00003ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0?_ooool2o`0001Wooooo
1?l000000ooooooo0000o`000007ooooo`;o00001oooool2o`0000;ooooo0_l00003ooooo`;o0000
3?ooool2o`0000Cooooo1Ol00003ooooo`;o000000?oooooo`000?l000003Oooool2o`0000Gooooo
0_l00003ooooo`?o000000?oooooo`000?l000000ol00003ooooo`;o000000?oooooo`000?l00000
1?ooool2o`0000;ooooo0_l000000ooooooo0000o`000008ooooo`;o00001oooool2o`000004oooo
ool0003o0000ooooo`;o00001?ooool4o`0000;ooooo1?l0000;ooooo`;o0000A?ooool001cooooo
00?o0000ooooooooool0>Oooool2o`000004ooooool0003o0000o`0001[ooooo0ol00003ooooo`;o
00001_ooool4o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o00000oooool2o`0000co
oooo0_l00007ooooo`;o00001_ooool4o`0000_ooooo0_l00004ooooo`;o00000_ooool6o`0000;o
oooo1?l00005ooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`;o00001?ooool2o`00
00;ooooo0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o000000Wooooo0_l00004oooo
o`;o00000_ooool2o`000003ooooool0003o000000Wooooo0_l0000oooooo`007?ooool00ol0003o
ooooooooo`0Sooooo`;o00005?ooool6o`0000Wooooo0_l000000ooooooo0000o`00000Booooo`;o
00001?ooool2o`0000;ooooo2Ol00004ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o
00006?ooool4o`0000Kooooo0_l00007ooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`?o
00001Oooool2o`0000Gooooo1?l00008ooooo`;o00001oooool4o`0000;ooooo0ol000000ooooooo
0000o`000002o`0000Cooooo0_l000000ooooooo0000o`000005ooooo`Go00002Oooool2o`0003oo
oooo000Looooo`03o`000?oooooooooo02?ooooo1?l0000Dooooo`;o00002oooool2o`000003oooo
ool0003o000000gooooo0_l00003ooooo`;o00001?ooool2o`0000;ooooo2_l000000ooooooo0000
o`000002o`000003ooooool0003o000000;o00000_ooool3o`0000Wooooo0_l00009ooooo`;o0000
0_ooool4o`0000?ooooo0_l000000ooooooo0000o`00000:ooooo`?o00000_ooool2o`0000?ooooo
0_l00006ooooo`;o00001oooool2o`00013ooooo0_l000001?oooooo0000o`000?ooool3o`0000;o
oooo1?l00005ooooo`Co00000oooool3o`000003ooooool0003o000000_ooooo0_l0000nooooo`00
7?ooool00ol0003oooooooooo`0Uooooo`;o00003Oooool2o`0001Wooooo0_l00009ooooo`Co0000
00?oooooo`000?l000001?l00003ooooo`;o00001oooool2o`000003ooooool0003o000000;o0000
1oooool2o`0000[ooooo0_l00009ooooo`;o00000_ooool2o`0000Gooooo0_l0000;ooooo`Co0000
0oooool2o`0000kooooo0_l00003ooooo`?o00001?ooool2o`0000Sooooo1?l000001?oooooo0000
o`000?ooool2o`0000Kooooo0_l00002ooooo`Co00001Oooool3o`0000kooooo0_l0000nooooo`00
7?ooool00ol0003oooooooooo`0dooooo`;o00001?ooool2o`0000;ooooo0_l0000:ooooo`;o0000
0oooool2o`0000_ooooo0_l000000ooooooo0000o`000004o`0000?ooooo1?l00004ooooo`;o0000
4Oooool2o`0000_ooooo0_l00009ooooo`;o00001_ooool2o`0000Wooooo0_l0000<ooooo`;o0000
0_ooool2o`0000?ooooo0_l00003ooooo`;o00001Oooool2o`0000Sooooo1?l000000ooooooo0000
o`000009ooooo`;o00000_ooool2o`0000gooooo0_l00019ooooo`007?ooool00ol0003ooooooooo
o`0jooooo`;o000000Coooooo`000?l0003o00002_ooool2o`0001Oooooo0_l00005ooooo`Co0000
0_ooool2o`00017ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00005ooooo`?o0000
00?oooooo`000?l000001_ooool2o`0000Wooooo0_l00002ooooo`?o00000_ooool2o`0000?ooooo
0_l00002ooooo`Co000000?oooooo`000?l000000_ooool2o`00023ooooo0_l00008ooooo`;o0000
1_ooool4o`0001Sooooo0_l0000^ooooo`007?ooool2o`0002cooooo0_l00008ooooo`;o00001_oo
ool3o`0000?ooooo0_l00002ooooo`Co00005_ooool4o`0000Oooooo0_l0000Eooooo`Ko00000ooo
ool2o`0000Wooooo0ol0000Hooooo`?o00000_ooool2o`000003ooooool0003o000000Kooooo0_l0
0005ooooo`;o00004_ooool2o`0000Sooooo0ol000000ooooooo0000o`000003ooooo`;o00000_oo
ool4o`0000Gooooo1?l000000ooooooo0000o`00000Eooooo`;o0000;_ooool001cooooo00?o0000
ooooooooool08Oooool2o`0000Sooooo0_l00008ooooo`;o00003?ooool2o`000003ooooool0003o
000000?o00005Oooool7o`0001_ooooo0_l000001?oooooo0000o`000?l00004ooooo`;o00002Ooo
ool2o`0000Wooooo0_l0000<ooooo`;o00001Oooool2o`000003ooooool0003o000000;o00007ooo
ool2o`0000Sooooo1_l00003ooooo`;o000000?oooooo`000?l000000ol0000:ooooo`;o00001ooo
ool2o`0000?ooooo0_l0000gooooo`007?ooool00ol0003oooooooooo`0Qooooo`;o00008oooool4
o`0001Kooooo1ol0000Kooooo`;o000000?oooooo`000?l000001Oooool2o`0001Cooooo0_l00003
ooooo`;o00001oooool2o`0000Gooooo0_l00003ooooo`Go00004?ooool2o`0001Oooooo0ol00006
ooooo`;o00002oooool2o`0000;ooooo0_l00005ooooo`;o00000oooool2o`0000Gooooo0_l0000`
ooooo`007?ooool00ol0003oooooooooo`0looooo`;o00002_ooool2o`0001Sooooo0_l00013oooo
o`;o00005?ooool4o`00013ooooo0_l0000Gooooo`?o00002_ooool2o`000003ooooool0003o0000
00Cooooo0_l00002ooooo`;o00000oooool2o`0000Sooooo0_l00002ooooo`;o0000<?ooool001co
oooo00?o0000ooooooooool0>_ooool4o`000003ooooool0003o000000Sooooo0_l0000Iooooo`Go
00003Oooool3o`0000Cooooo0_l000000ooooooo0000o`00000Aooooo`;o00005_ooool2o`0000Oo
oooo1?l00003ooooo`;o00001_ooool3o`00013ooooo0_l0000Booooo`;o00001_ooool2o`0000;o
oooo0ol000000ooooooo0000o`000007ooooo`;o00000oooool3o`0000Sooooo0_l0000dooooo`00
7?ooool00ol0003oooooooooo`0Uooooo`;o00003?ooool2o`0000Gooooo0_l00003ooooo`;o0000
00?oooooo`000?l000001Oooool2o`0000?ooooo0_l0000Booooo`[o00001oooool2o`000004oooo
ool0003o0000o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`;o00003?ooool2o`0000Go
oooo1?l00005ooooo`Co00000oooool3o`0000Cooooo0_l000000ooooooo0000o`000002o`0000?o
oooo0_l00006ooooo`Go00001_ooool2o`0000Kooooo0_l0000Dooooo`;o00001?ooool2o`0000;o
oooo0_l00003ooooo`;o00001_ooool2o`000003ooooool0003o000000;o0000?oooool001cooooo
00?o0000ooooooooool09Oooool2o`0000cooooo0_l0000=ooooo`;o00002_ooool2o`0001;ooooo
0_l00003ooooo`Go00001oooool6o`0000cooooo0_l0000Cooooo`Go00001?ooool4o`0000?ooooo
0_l00004ooooo`?o000000?oooooo`000?l000002?ooool2o`0000Kooooo0_l00005ooooo`?o0000
7?ooool2o`0000cooooo0ol00009ooooo`Co00004?ooool2o`0000gooooo0_l0000Nooooo`007?oo
ool00ol0003oooooooooo`1>ooooo`?o00001oooool2o`0000[ooooo0_l00002ooooo`Co00002?oo
ool5o`0000Kooooo0_l0000?ooooo`;o00002oooool2o`0000gooooo0_l00002ooooo`;o00000_oo
ool2o`0000Sooooo0_l000000ooooooo0000o`00000:ooooo`?o00001Oooool2o`0002?ooooo0_l0
000:ooooo`Co00004?ooool2o`0000gooooo0_l0000Nooooo`007?ooool00ol0003oooooooooo`13
ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool3
o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`0000?ooooo0_l00005ooooo`;o00002Oooool4
o`0000Oooooo0_l00004ooooo`;o00000_ooool2o`0001Kooooo0_l0000Cooooo`;o00002oooool2
o`0000;ooooo0_l000000ooooooo0000o`00000]ooooo`;o00000_ooool2o`0003oooooo000Loooo
o`03o`000?oooooooooo03?ooooo0_l0000>ooooo`;o000000?oooooo`000?l000000_ooool2o`00
0003ooooool0003o000000Cooooo0_l00004ooooo`;o00000_ooool2o`0000kooooo0_l00003oooo
o`;o00000_ooool2o`0000Wooooo0_l00006ooooo`?o00002?ooool4o`0000Wooooo0_l0000=oooo
o`;o00001_ooool2o`0000;ooooo0_l0000Dooooo`;o00002?ooool2o`0001Sooooo0_l00005oooo
o`;o00001Oooool2o`0000;ooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0cooooo`;o
00003Oooool2o`0000Wooooo0_l00004ooooo`;o00007Oooool2o`0000;ooooo0_l0000Aooooo`;o
00002Oooool4o`0000Wooooo0_l0000:ooooo`;o000000?oooooo`000?l000001_ooool2o`0000;o
oooo0_l0000Eooooo`;o00001oooool2o`0001Sooooo0_l00005ooooo`;o00000oooool2o`0000Ko
oooo0ol0000looooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00001_ooool2o`0000?ooooo
0_l00003ooooo`Go00003_ooool4o`0001cooooo0_l0000Eooooo`;o00002?ooool2o`0000;ooooo
0_l0000Cooooo`Co00001?ooool2o`0000Gooooo0_l0000Aooooo`;o000000?oooooo`000?l00000
0ol00003ooooo`;o000000?oooooo`000?l000003_ooool2o`0000[ooooo0_l00007ooooo`Go0000
0oooool3o`0003cooooo000Looooo`03o`000?oooooooooo02kooooo0_l00006ooooo`;o00000ooo
ool2o`000003ooooool0003o000000;o000000?oooooo`000?l000001Oooool2o`0000Wooooo0_l0
000=ooooo`;o00003Oooool2o`0000Gooooo0_l0000>ooooo`;o00001Oooool3o`0000Cooooo0_l0
0005ooooo`;o00003_ooool4o`0000;ooooo0_l00005ooooo`?o00000_ooool2o`0000Sooooo1_l0
00000ooooooo0000o`000008o`000003ooooool0003o000000?ooooo0_l00009ooooo`;o00001?oo
ool2o`0000Cooooo0_l00008ooooo`Co00000_ooool2o`0003kooooo000Looooo`03o`000?oooooo
oooo03kooooo0ol00002ooooo`;o00001Oooool2o`0000_ooooo0_l0000;ooooo`;o00005?ooool2
o`0000_ooooo0_l000000ooooooo0000o`000005ooooo`?o00001?ooool2o`0000Gooooo0_l00003
ooooo`;o00001_ooool4o`000003ooooool0003o000000;ooooo0_l00005ooooo`Oo00002?ooool@
o`000004ooooool0003o0000o`0000?ooooo0_l0000;ooooo`;o00000_ooool3o`0000gooooo0_l0
00000ooooooo0000o`000003o`0003kooooo000Looooo`03o`000?oooooooooo03;ooooo0_l00002
ooooo`;o00001oooool2o`0001;ooooo0_l00002ooooo`;o00005oooool4o`0000Kooooo1?l00000
0ooooooo0000o`000006ooooo`;o000000?oooooo`000?l000002Oooool2o`000003ooooool0003o
000000;o00001Oooool2o`000003ooooool0003o000000Kooooo1?l00005ooooo`;o00001_ooool5
o`000003ooooool0003o000000Gooooo5?l000000ooooooo0000o`000002ooooo`;o00002_ooool2
o`0000?ooooo0_l0000@ooooo`Co0000?oooool001cooooo00?o0000ooooooooool0:_ooool2o`00
00Kooooo0_l00002ooooo`;o00000oooool2o`0000Wooooo0_l0000;ooooo`;o00001?ooool2o`00
01Cooooo1Ol00004ooooo`Ko000000?oooooo`000?l000004Oooool6o`0000;ooooo0_l00004oooo
o`?o00002_ooool3o`0001?ooooo1?l00003oooooa?o000000Coooooo`000?l0003o00000_ooool2
o`0000oooooo1?l0000Aooooo`;o0000?_ooool001cooooo0_l0000[ooooo`;o00001oooool2o`00
00Kooooo0_l00008ooooo`?o00001_ooool2o`0000?ooooo0_l00004ooooo`;o00000_ooool2o`00
00Sooooo1ol000001?oooooo0000o`000?l00002ooooo`;o00000_ooool2o`0000Gooooo0_l0000<
ooooo`;o00000_ooool4o`000004ooooool0003o0000ooooo`?o00001?ooool2o`0000_ooooo0ol0
000=ooooo`;o00001_ooool2o`0000;ooooo2Ol000000ooooooo0000o`00000;o`0000?ooooo0_l0
000?ooooo`Co00001_ooool3o`0000;ooooo0_l00004ooooo`Co0000??ooool001cooooo00?o0000
ooooooooool0<oooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00001Oooool3
o`0000Kooooo0_l000000ooooooo0000o`000002o`0000Sooooo0_l00006ooooo`Wo000000Cooooo
o`000?l0003ooooo1Ol0000Cooooo`;o000000?oooooo`000?l000000_ooool2o`0000Kooooo0_l0
000:ooooo`;o00003?ooool2o`0000Sooooo0_l0000:ooooo`Wo000000?oooooo`000?l000002ol0
0002ooooo`;o00004?ooool4o`0000?ooooo0_l000001?oooooo0000o`000?l00002ooooo`;o0000
1_ooool2o`0003cooooo000Looooo`03o`000?oooooooooo033ooooo0_l00003ooooo`Co000000?o
ooooo`000?l000000_ooool2o`00017ooooo1?l0000=ooooo`;o000000?oooooo`000?l000001?l0
00000ooooooo0000o`000009o`000003ooooool0003o0000013ooooo0_l00008ooooo`;o00001Ooo
ool2o`0000Sooooo0_l000000ooooooo0000o`000007ooooo`Co00000oooool2o`0000?ooooo0_l0
0004ooooo`?o000000?oooooo`000?l000006?l000000ooooooo0000o`000008ooooo`;o000000?o
ooooo`000?l000000oooool6o`000003ooooool0003o000000cooooo0_l0000nooooo`007?ooool0
0ol0003oooooooooo`0`ooooo`;o00000oooool2o`0001;ooooo1?l00006ooooo`;o00003Oooool2
o`0000?ooooo1_l000000ooooooo0000o`00000:o`0000Cooooo0_l00005ooooo`;o00001_ooool2
o`0000Gooooo0_l00005ooooo`;o00002_ooool5o`0000Gooooo0_l000000ooooooo0000o`000002
ooooo`;o00000oooool2o`0000Cooooo0ol000000ooooooo0000o`00000Eo`000003ooooool0003o
000000_ooooo0_l000000ooooooo0000o`000007ooooo`;o00003oooool2o`0003kooooo000Loooo
o`03o`000?oooooooooo03Cooooo0_l0000Cooooo`Co00001Oooool2o`0001?ooooo4_l00005oooo
o`?o00001?ooool2o`0000Kooooo0_l0000Hooooo`Go00002?ooool2o`0000Cooooo0_l00008oooo
oaWo00006?ooool2o`0000oooooo0_l000001?oooooo0000o`000?ooool2o`0003_ooooo000Loooo
o`03o`000?oooooooooo03;ooooo1?l00003ooooo`;o00005oooool2o`0001Cooooo5?l00003oooo
o`;o00003oooool2o`0000Cooooo0_l00005ooooo`;o00002?ooool2o`000003ooooool0003o0000
00kooooo0_l00003ooooo`;o00000ooooolKo`0000;ooooo0_l0000@ooooo`Co00003oooool5o`00
0003ooooool0003o000000cooooo0_l0000]ooooo`007?ooool00ol0003oooooooooo`0booooo`;o
00001Oooool2o`0002;ooooo0_l00002ooooo`;o00001?oooolEo`0001Cooooo0ol00003ooooo`;o
00001Oooool2o`0000Kooooo1?l00003ooooo`;o00004Oooool2o`000003ooooool0003o000000;o
00000_oooolHo`000003ooooool0003o000000kooooo1_l00002ooooo`;o00003?ooool2o`0000?o
oooo0_l0000<ooooo`;o0000;Oooool001cooooo00?o0000ooooooooool08Oooool2o`0000_ooooo
0_l0000<ooooo`;o00003oooool2o`0000;ooooo0ol00009ooooo`;o00000_ooool2o`0000?ooooo
5ol00005ooooo`;o00001oooool2o`0000Cooooo0_l0000Booooo`;o00001?ooool3o`0000cooooo
0_l00005ooooo`Go00000_oooolHo`0000_ooooo0_l00004ooooo`;o00001Oooool3o`0000[ooooo
0_l00005ooooo`;o0000>oooool001cooooo00?o0000ooooooooool08Oooool2o`0000_ooooo0_l0
000<ooooo`;o00002_ooool2o`0000?ooooo0_l00002ooooo`?o00003Oooool2o`0000?ooooo5ol0
0002ooooo`;o000000?oooooo`000?l000001_ooool3o`0000_ooooo0_l0000:ooooo`_o00001_oo
ool2o`0000?ooooo0_l00005ooooo`;o000000?oooooo`000?l000000_oooolHo`0000_ooooo0_l0
00000ooooooo0000o`000008ooooo`;o00002oooool2o`0004;ooooo000Looooo`03o`000?oooooo
oooo02Kooooo0_l0000:ooooo`;o00003?ooool2o`0000Kooooo0_l0000=ooooo`;o00001_ooool2
o`0000Kooooo5ol000000ooooooo0000o`000009ooooo`;o00003?ooool2o`000005ooooool0003o
0000o`000?ooool00ol00002ooooo`Oo00000_ooool2o`0000Cooooo1?l0000=ooooo`;o00000ooo
oolFo`0000oooooo0_l0000=ooooo`;o00000_ooool2o`0004Kooooo000Looooo`03o`000?oooooo
oooo02Kooooo0_l0000:ooooo`;o00003?ooool2o`0000kooooo0_l00005ooooo`;o00001_ooool2
o`0000Kooooo5ol00003ooooo`;o00002oooool2o`0000[ooooo1?l000001?oooooo0000o`000?l0
0003ooooo`Go00002Oooool4o`000003ooooool0003o0000013ooooo5_l0000Cooooo`;o00002?oo
ool2o`0000;ooooo0_l00002ooooo`;o00001?ooool2o`0000;ooooo0ol0000gooooo`007?ooool0
0ol0003oooooooooo`0]ooooo`;o00002Oooool2o`0000cooooo1?l00006ooooo`;o00002Oooool2
o`0000Gooooo0ol000000ooooooo0000o`00000Ho`000003ooooool0003o000000_ooooo0_l0000:
ooooo`;o00004_ooool2o`0000Gooooo0_l000000ooooooo0000o`00000?oooooaOo00004oooool2
o`0000cooooo0_l00002ooooo`;o00000_ooool4o`0000;ooooo0ol0000gooooo`007?ooool00ol0
003oooooooooo`0]ooooo`;o00002Oooool2o`0000cooooo1?l00006ooooo`;o00002Oooool2o`00
00Gooooo0ol000000ooooooo0000o`00000Ho`0002kooooo0_l00003ooooo`;o00001?ooool2o`00
00Cooooo0_l00008oooooaWo00001_ooool2o`000003ooooool0003o000000_ooooo0_l00006oooo
o`?o000000?oooooo`000?l000000_l000000ooooooo0000o`000003o`0003_ooooo000Looooo`03
o`000?oooooooooo02_ooooo0_l00003ooooo`?o00005Oooool4o`0000Sooooo0_l0000?oooooa3o
000000?oooooo`000?l000002ol00004ooooo`;o00004Oooool2o`0000Kooooo0_l00006ooooo`;o
00001oooool2o`0000?ooooo1Ol00002ooooo`;o00000oooool2o`0000Cooooo4Ol000000ooooooo
0000o`000006o`0000Cooooo0_l000000ooooooo0000o`00000;ooooo`;o00001_ooool2o`0000;o
oooo1?l000001?oooooo0000o`000?ooool2o`0000Cooooo0_l0000eooooo`0000Koooooonk^k_lb
<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o
0000ooooooooool0:oooool2o`0000?ooooo0ol0000Eooooo`Co00002?ooool4o`0000gooooo0_l0
00000ooooooo0000o`00000;o`000003ooooool0003o000000_o00000_ooool4o`00017ooooo0_l0
0006ooooo`;o00001_ooool3o`0000?ooooo0_l00006ooooo`Go00000_ooool2o`0000?ooooo0_l0
0002ooooo`[o000000?oooooo`000?l000001_l000000ooooooo0000o`000002o`0000;ooooo0_l0
000Wooooo`;o00001Oooool2o`0003Gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo
0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0`ooooo`;o
00002Oooool2o`0000_ooooo0_l00004ooooo`?o00001Oooool2o`0000gooooo0_l000000ooooooo
0000o`00000Go`0000Cooooo0ol00002ooooo`?o000000?oooooo`000?l000001_l00004ooooo`Co
00003Oooool2o`0000?ooooo0_l0000=ooooo`;o00000oooool2o`0000;ooooo0_l00006ooooo`Go
000000Coooooo`000?l0003ooooo1_l0000:ooooo`;o00004?ooool2o`0000kooooo0_l0000loooo
o`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooooooo`0`ooooo`;o00002Oooool2o`00017ooooo0ol000000ooo
oooo0000o`000002ooooo`;o00004?oooolIo`0000?ooooo0_l00004ooooo`?o000000?oooooo`00
0?l000001_l00004ooooo`Co00002_ooool2o`0000Kooooo0_l00006ooooo`?o00001?ooool2o`00
00?ooooo0_l0000:ooooo`So00000_ooool7o`0000Sooooo0_l0000@ooooo`;o0000C?ooool00003
ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q
00Kooooo0ol0001>ooooo`;o00000_ooool2o`0000gooooo1?l00002oooooa_o000000Coooooo`00
0?l0003o00000_ooool2o`0000Gooooo0_l000000ooooooo0000o`00000=ooooo`Co00000oooool2
o`0000kooooo0ol00004ooooo`;o00002_ooool2o`0000Kooooo0ol00005ooooo`So00003?ooool2
o`0005Sooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oeEE
EOl0003o410@olc<c006ooooo`03o`000?oooooooooo03Oooooo0_l0000@ooooo`;o000000Cooooo
o`000?l0003ooooo0_l0000@ooooo`Co00000_oooolKo`000003ooooool0003o000000;ooooo0ol0
0005ooooo`;o00004?ooool4o`0000?ooooo0_l0000Booooo`;o00003Oooool2o`0000;ooooo0_l0
0002ooooo`;o00000_ooool2o`0000Sooooo0_l00008ooooo`;o00000_ooool2o`00017ooooo0ol0
0014ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`03oeEEEOn7QhOo
oooo00Sooooo00?o0000ooooooooool0=_ooool4o`0000Oooooo1?l00004ooooo`Go000000?ooooo
o`000?l000001oooool2o`0000Oooooo0_l00004oooooago00000oooool3o`000003ooooool0003o
000000Gooooo1?l0000<ooooo`;o00000_ooool3o`0000?ooooo0_l0000>ooooo`;o00004Oooool2
o`000003ooooool0003o000000?ooooo0_l00009ooooo`;o00000oooool6o`0001Gooooo1Ol00000
0ooooooo0000o`00000oooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@
413oV9RH00Sooooo00?o0000ooooooooool0=_ooool4o`0000Oooooo1?l00002ooooo`Go00003?oo
ool2o`0000Oooooo0_l000001?oooooo0000o`000?ooool7o`000003ooooool0003o000001?o0000
1oooool2o`0000Gooooo1_l0000>ooooo`So00009?ooool2o`0000Kooooo0_l00006ooooo`;o0000
0oooool5o`0001Kooooo0_l000000ooooooo0000o`000003o`0003oooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`13oooo
o`;o00000_ooool3o`0000Wooooo0_l00006ooooo`;o00001oooool2o`0000Kooooo6ol000000ooo
oooo0000o`000002ooooo`;o00002?ooool2o`0000Gooooo0_l00003ooooo`Co000000?oooooo`00
0?l000001Ol0000Eooooo`;o00003_ooool5o`0000;ooooo1Ol0000:ooooo`?o00001_ooool2o`00
00Cooooo0_l00008ooooo`;o00000_ooool3o`00043ooooo000Looooo`03o`000?oooooooooo03Ko
oooo0_l00006ooooo`;o00000oooool2o`0000;ooooo1?l00008ooooo`;o00001_ooool2o`0000ko
oooo5ol000000ooooooo0000o`000002o`000003ooooool0003o000000;ooooo0_l0000?ooooo`;o
00000oooool4o`000003ooooool0003o000000Ko00000_ooool2o`00013ooooo0_l00004ooooo`;o
00001_ooool7o`0000?ooooo1?l0000;ooooo`?o00001Oooool2o`0000;ooooo1?l0000;ooooo`?o
0000@Oooool001cooooo00?o0000ooooooooool0=_ooool2o`0000Gooooo0ol00009ooooo`;o0000
4oooool2o`0000Wooooo5ol00003ooooo`;o000000Coooooo`000?l0003o00006?ooool>o`000003
ooooool0003o000000;o00005Oooool2o`0000Kooooo0_l00002ooooo`Co00000_ooool2o`0000go
oooo0ol00004ooooo`;o00000oooool2o`0000gooooo1?l00010ooooo`007?ooool00ol0003ooooo
ooooo`0`ooooo`;o00002oooool3o`0000oooooo0_l0000:ooooo`;o000000?oooooo`000?l00000
2Oooool2o`0000;ooooo0_l00002ooooo`oo00000_ooool3o`000004ooooool0003o0000o`0000Co
oooo0_l0000?oooooaKo000000?oooooo`000?l000006_ooool2o`0000;ooooo2Ol0000>ooooo`;o
00000oooool2o`0000_ooooo0_l00004ooooo`Go0000@?ooool001cooooo00?o0000ooooooooool0
<?ooool3o`00017ooooo0_l00009ooooo`;o00002_ooool2o`0000Gooooo0_l00006ooooo`;o0000
1oooool=o`0000;ooooo0_l00002ooooo`;o00001Oooool4o`0000cooooo5ol000000ooooooo0000
o`00000Mooooo`;o00000oooool2o`000003ooooool0003o000000kooooo1?l0000>ooooo`;o0000
1?ooool3o`0004;ooooo000Looooo`03o`000?oooooooooo037ooooo1?l00003ooooo`;o00002_oo
ool4o`0001[ooooo0_l00006ooooo`;o00001oooool;o`0000Cooooo0_l00002ooooo`;o00001ooo
ool2o`0000Oooooo0_l00003oooooa[o00005Oooool2o`0000;ooooo0_l000001?oooooo0000o`00
0?l00008ooooo`;o00001_ooool2o`0000Kooooo0_l0001Iooooo`007?ooool00ol0003ooooooooo
o`0cooooo`;o00000oooool2o`0000[ooooo1?l00003ooooo`;o000000?oooooo`000?l000005Ooo
ool2o`0000;ooooo0ol00004ooooo`[o000000?oooooo`000?l000001Oooool2o`0000;ooooo0_l0
0003ooooo`;o00001?ooool2o`0000Gooooo0_l00003oooooaSo00003_ooool3o`0000Kooooo0_l0
0002ooooo`;o000000?oooooo`000?l000002Oooool4o`0000Cooooo1?l00003ooooo`;o000000?o
ooooo`000?l000003Oooool2o`0004Sooooo000Looooo`03o`000?oooooooooo04Cooooo0_l00005
ooooo`;o000000?oooooo`000?l000002?ooool2o`0000[ooooo0ol00002ooooo`;o00001Oooool5
o`000003ooooool0003o000000Go00003_ooool2o`0000Cooooo0_l00007oooooaGo000000?ooooo
o`000?l000000_l0000=ooooo`Go00003Oooool2o`0000_ooooo0_l00006ooooo`;o00000oooool2
o`000003ooooool0003o000000gooooo0ol00017ooooo`007?ooool00ol0003oooooooooo`1Coooo
o`;o00000oooool2o`0000Gooooo1ol0000=ooooo`;o000000?oooooo`000?l000001ol00009oooo
o`;o00004?ooool5o`000003ooooool0003o000000co00000oooool3o`000003ooooool0003o0000
00Kooooo0_l00002ooooo`?o00000oooool4o`0001oooooo0_l00004ooooo`Co00003?ooool2o`00
04Oooooo000Looooo`03o`000?oooooooooo05?ooooo0_l00005ooooo`Co000000?oooooo`000?l0
00000ol00006ooooo`;o00002_ooool4o`0000?ooooo0_l00009ooooo`;o00003?oooolIo`000003
ooooool0003o000000;o000000?oooooo`000?l000001_ooool2o`0000?ooooo1?l000000ooooooo
0000o`000002o`0000Cooooo0_l0000Iooooo`;o000000Coooooo`000?l0003ooooo1?l0001Eoooo
o`007?ooool00ol0003oooooooooo`13ooooo`;o00000_ooool2o`0000Sooooo0_l00007ooooo`Ko
00001oooool2o`000003ooooool0003o000000[ooooo0ol0000Dooooo`Co00001OoooolNo`00013o
oooo1_l00005ooooo`;o00001?ooool4o`0000oooooo0_l00003ooooo`;o00004?ooool2o`0004So
oooo000Looooo`03o`000?oooooooooo047ooooo1?l00002ooooo`;o00002?ooool3o`0000[ooooo
0_l00007ooooo`Co00002_ooool3o`0000Sooooo1?l00005ooooo`;o00000_ooool4o`0000Wooooo
7Ol0000>ooooo`Go00002oooool4o`0000oooooo0_l00006ooooo`;o00003Oooool2o`0004Sooooo
000Looooo`;o0000@_ooool2o`0000?ooooo0_l0000:ooooo`Co00002Oooool3o`0000;ooooo0_l0
0003ooooo`;o00001_ooool2o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`Ko000000Co
ooooo`000?l0003ooooo0_l0000?oooooako00002oooool4o`0001_ooooo0_l00003ooooo`;o0000
1_ooool3o`0005Oooooo000Looooo`03o`000?oooooooooo037ooooo0_l0000Cooooo`;o00003?oo
ool2o`0000Wooooo0ol00002ooooo`Co00000oooool3o`0000;ooooo0ol00005ooooo`;o000000Go
ooooo`000?l0003o0000ooooo`06o`000003ooooool0003o000000kooooo0_l00004oooooaOo0000
00?oooooo`000?l000000_l00004ooooo`;o00001?ooool3o`0000cooooo0_l0000;ooooo`;o0000
0_ooool4o`000003ooooool0003o000000;o00001?ooool4o`0000Oooooo0_l0001=ooooo`007?oo
ool00ol0003oooooooooo`0aooooo`;o00003oooool2o`0000Oooooo0_l0000:ooooo`;o00001ooo
ool2o`0000Cooooo0_l00003ooooo`?o00000_ooool2o`0000Wooooo0ol000001?oooooo0000o`00
0?l0000>ooooo`;o00001?ooool2o`0000?ooooo5ol000000ooooooo0000o`000004o`0000?ooooo
0_l00004ooooo`;o00001Oooool2o`0000;ooooo0_l000001?oooooo0000o`000?l0000;ooooo`Co
00000_ooool2o`000003ooooool0003o000000;o00001Oooool3o`0000?ooooo0ol000000ooooooo
0000o`000007ooooo`;o00003?ooool2o`0003Kooooo000Looooo`03o`000?oooooooooo04;ooooo
0_l00007ooooo`;o00002_ooool2o`0000Oooooo0_l00009ooooo`;o00001?ooool3o`000003oooo
ool0003o000000Gooooo0_l000001?oooooo0000o`000?l00008ooooo`;o00001?ooool3o`0000?o
oooo0ol000000ooooooo0000o`00000=o`000003ooooool0003o000000Ko000000?oooooo`000?l0
00001?l00009ooooo`;o00001Oooool2o`0000;ooooo0_l000000ooooooo0000o`00000>ooooo`;o
00000_ooool5o`000003ooooool0003o000000Cooooo0_l00004ooooo`?o00002_ooool2o`0000co
oooo0_l0000fooooo`007?ooool00ol0003oooooooooo`1Gooooo`;o000000?oooooo`000?l00000
1?ooool2o`0000Cooooo0_l00003ooooo`;o00001?ooool6o`0000?ooooo2?l00002ooooo`;o0000
0_ooool4o`0000Cooooo0ol00003ooooo`?o000000?oooooo`000?l000006ol0000Fooooo`;o0000
1Oooool2o`0000_ooooo0_l00002ooooo`;o00000oooool2o`0000_ooooo0_l00003ooooo`;o0000
Boooool001cooooo00?o0000ooooooooool0B_ooool2o`0000kooooo0_l00004ooooo`;o00001?oo
ool2o`0000_ooooo1?l000000ooooooo0000o`000002o`000003ooooool0003o000000;o000000?o
ooooo`000?l000000_l000001Ooooooo0000o`000?l0003ooooo00;o00002_ooool2o`0000;ooooo
7?l00006ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o00002_ooool2o`0000?ooooo
0_l00006ooooo`;o00001oooool4o`0000Cooooo0_l00008ooooo`;o000000?oooooo`000?l00000
B?ooool001cooooo00?o0000ooooooooool0A_ooool2o`0000;ooooo0_l0000Dooooo`;o00004_oo
ool3o`000003ooooool0003o000000Sooooo0_l00003ooooo`;o00000_ooool3o`0000Wooooo0_l0
0003oooooa_o00001_ooool2o`000003ooooool0003o000000;o00001?ooool2o`0000oooooo0_l0
0006ooooo`;o00000oooool2o`0000;ooooo1_l00002ooooo`;o00002oooool4o`0004Kooooo000L
ooooo`03o`000?oooooooooo04Kooooo0_l00002ooooo`;o00003oooool2o`0000?ooooo0_l0000H
ooooo`;o00002oooool2o`0000?ooooo0_l00009ooooo`;o00000_oooolLo`0000Cooooo0_l0000Q
ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000006ooooo`;o00004Oooool2
o`0004Kooooo000Looooo`03o`000?oooooooooo04[ooooo0_l000001?oooooo0000o`000?ooool2
o`0000Wooooo0_l0000Mooooo`?o00002_ooool2o`0000Cooooo0_l00008ooooo`?o000000?ooooo
o`000?l000003Ol000000ooooooo0000o`000007o`0000Oooooo0_l0000Qooooo`;o00000oooool4
o`0000;ooooo0ol0001Mooooo`007?ooool00ol0003oooooooooo`16ooooo`;o00001Oooool2o`00
0003ooooool0003o000000Oooooo1?l0000Dooooo`;o000000?oooooo`000?l000001?ooool5o`00
00kooooo0_l00003ooooo`;o00001?ooool2o`0000;ooooo3_l000000ooooooo0000o`000007o`00
0003ooooool0003o000000Cooooo0_l0000@ooooo`;o00003oooool4o`0000?ooooo0_l00002oooo
o`?o00004_ooool3o`000003ooooool0003o000004Gooooo000Looooo`03o`000?oooooooooo03Wo
oooo0_l0000;ooooo`Co00001oooool2o`0000Kooooo1?l0000Dooooo`;o000000?oooooo`000?l0
00000_l00003ooooo`Co00004oooool2o`0000Wooooo6_l00004ooooo`;o00000oooool2o`0000_o
oooo0_l0000:ooooo`;o00000oooool4o`0000Sooooo0_l0000Booooo`?o000000?oooooo`000?l0
0000AOooool001cooooo00?o0000ooooooooool0>Oooool2o`0000gooooo0_l00007ooooo`;o0000
2?ooool2o`0001Wooooo0_l00003ooooo`Co00003Oooool2o`0000Cooooo0_l00008oooooa[o0000
0_ooool2o`0000Kooooo0_l0000Gooooo`;o00000oooool2o`0000[ooooo0_l0000>ooooo`;o0000
COooool001cooooo00?o0000ooooooooool0@_ooool2o`0000gooooo0_l00008ooooo`;o00007_oo
ool4o`0000Wooooo0_l00002ooooo`;o00000oooool3o`0000Sooooo4Ol000000ooooooo0000o`00
0006o`0000;ooooo0_l0000dooooo`;o00002Oooool3o`0004gooooo000Looooo`03o`000?oooooo
oooo04;ooooo0_l00009ooooo`;o00000_ooool2o`0000?ooooo0_l00003ooooo`;o00005oooool2
o`0000Kooooo0ol00006ooooo`;o000000?oooooo`000?l000001oooool2o`0000?ooooo1?l00002
ooooo`;o000000?oooooo`000?l000001Ol000000ooooooo0000o`00000=o`0000;ooooo0_l00004
ooooo`;o00001_ooool2o`0000?ooooo0_l00009ooooo`;o00003Oooool2o`0000Oooooo0_l00009
ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0@oooool2o`0000Sooooo0_l00007oooo
o`;o00000oooool4o`0001Gooooo0_l00006ooooo`;o00001oooool3o`0000Sooooo0_l000001?oo
oooo0000o`000?ooool4o`0000;ooooo1ol000000ooooooo0000o`000009o`0000;ooooo0_l00005
ooooo`;o00001?ooool2o`0000Kooooo0_l00003ooooo`;o00002Oooool2o`0000gooooo0_l0001R
ooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00004Oooool2o`0000?ooooo1?l000000ooo
oooo0000o`00000:ooooo`;o00001oooool2o`000003ooooool0003o000000Wooooo0_l000001?oo
oooo0000o`000?ooool2o`0000Gooooo0_l000000ooooooo0000o`000003ooooo`;o00000ooooolA
o`00017ooooo0_l0000dooooo`;o00001_ooool3o`0004Wooooo000Looooo`;o0000EOooool3o`00
00Cooooo0_l00003ooooo`;o00000oooool2o`0000Gooooo0_l00003ooooo`;o00000_ooool2o`00
0003ooooool0003o000000Gooooo0_l00002ooooo`Go000000?oooooo`000?l000002Oooool6o`00
00?ooooo4Ol00007ooooo`;o00001?ooool2o`0000;ooooo0_l00002ooooo`;o0000:oooool2o`00
00?ooooo0ol00005ooooo`Co0000B?ooool001cooooo00?o0000ooooooooool0D?ooool7o`0000?o
oooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l0000:ooooo`;o00002Oooool2o`00
0003ooooool0003o000000?ooooo0ol0000<ooooo`Oo000000?oooooo`000?l000001Ol00003oooo
o`;o00000oooool3o`0000Cooooo0_l00002ooooo`;o00000_ooool4o`0000Kooooo0_l00003oooo
o`;o00009_ooool2o`0000Cooooo0_l00007ooooo`;o0000B?ooool001cooooo00?o0000oooooooo
ool0D?ooool4o`0000Cooooo1_l000001?oooooo0000o`000?ooool2o`0001Sooooo0_l00003oooo
o`;o000000?oooooo`000?l000003?ooool3o`0000?ooooo0_l000001?oooooo0000o`000?ooool3
o`0000[ooooo0ol00003ooooo`Co00001?ooool2o`0000Kooooo1?l00003ooooo`;o00006?ooool2
o`00013ooooo1?l0001Aooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o00000_ooool2o`00
017ooooo0_l00004ooooo`;o00002?ooool6o`0000Cooooo0_l00007ooooo`;o00001oooool2o`00
00Kooooo0_l00005ooooo`Co00001Oooool3o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`00
01Oooooo0_l00006ooooo`Co00001oooool2o`0000Gooooo0_l0001Cooooo`007?ooool00ol0003o
ooooooooo`1Looooo`;o00004Oooool2o`0000?ooooo0ol00005ooooo`;o000000?oooooo`000?l0
00000_ooool2o`0000Cooooo1?l0000;ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;o
oooo0_l00005ooooo`;o00002?ooool2o`0000;ooooo0ol00002ooooo`;o00006oooool4o`0000Ko
oooo0_l00006ooooo`Go00001_ooool2o`0000?ooooo0_l0001;ooooo`007?ooool00ol0003ooooo
ooooo`1Cooooo`;o000000?oooooo`000?l000001?ooool3o`0001Gooooo0_l00003ooooo`;o0000
00?oooooo`000?l000000_ooool2o`0000Wooooo0_l000000ooooooo0000o`000005ooooo`;o0000
00?oooooo`000?l000001Oooool2o`0000Sooooo0_l0000<ooooo`Co00000_ooool2o`0001?ooooo
0_l00008ooooo`;o00000oooool2o`000003ooooool0003o000000Kooooo1Ol00005ooooo`?o0000
0oooool2o`0004_ooooo000Looooo`03o`000?oooooooooo05?ooooo0_l000000ooooooo0000o`00
0005ooooo`;o00002Oooool2o`0000oooooo0_l00005ooooo`?o00002oooool2o`000003ooooool0
003o000000;ooooo1Ol0000:ooooo`;o00000oooool2o`000003ooooool0003o000000Wooooo0_l0
0003ooooo`?o00002oooool2o`0000Kooooo0_l00008ooooo`;o00000oooool2o`000003ooooool0
003o000000Oooooo0ol00006ooooo`?o0000D?ooool001cooooo00?o0000ooooooooool0HOooool2
o`0000Gooooo0_l000000ooooooo0000o`000008ooooo`;o00001?ooool2o`0000Cooooo0_l00006
ooooo`;o00001_ooool2o`0000Cooooo0ol0000:ooooo`;o00001_ooool2o`0000kooooo1?l0000:
ooooo`;o00003Oooool2o`0000Cooooo0ol0000;ooooo`;o00002?ooool2o`00053ooooo000Loooo
o`03o`000?oooooooooo063ooooo0ol00008ooooo`;o00002?ooool2o`0000Cooooo0_l00005oooo
o`;o00001Oooool2o`0000?ooooo0_l00005ooooo`;o00000oooool2o`0000;ooooo0_l0000<oooo
o`;o00002oooool2o`0000?ooooo0_l00008ooooo`;o00000oooool2o`0000[ooooo0_l00004oooo
o`?o00001Oooool2o`00063ooooo000Looooo`03o`000?oooooooooo05Oooooo0ol00006ooooo`?o
00003_ooool2o`0000Sooooo0_l00005ooooo`;o00002_ooool2o`0000Gooooo0_l00003ooooo`;o
00000_ooool2o`0000oooooo0_l00008ooooo`;o00002oooool4o`0000?ooooo0_l0000Cooooo`Co
000000?oooooo`000?l000003oooool2o`000003ooooool0003o000004cooooo000Looooo`03o`00
0?oooooooooo05Oooooo0ol00007ooooo`;o00003_ooool2o`0000Sooooo0_l00005ooooo`;o0000
2?ooool2o`0001gooooo0_l00002ooooo`;o00001Oooool4o`0000cooooo0_l0000Eooooo`;o0000
0oooool4o`0000Cooooo0_l0000<ooooo`;o000000?oooooo`000?l00000C?ooool001cooooo00?o
0000ooooooooool0F_ooool2o`0001Sooooo0_l00002ooooo`;o00002?ooool2o`0000Sooooo1?l0
000<ooooo`;o00003Oooool2o`0000Cooooo0ol000000ooooooo0000o`000003o`0002?ooooo0_l0
000;ooooo`;o0000GOooool001cooooo00?o0000ooooooooool0C_ooool2o`0000;ooooo0_l00006
ooooo`;o00005?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l0000>
ooooo`;o00003?ooool2o`0000;ooooo0_l0000:ooooo`;o00000oooool3o`000004ooooool0003o
0000ooooo`;o00000oooool2o`0002Kooooo0_l000000ooooooo0000o`00001Oooooo`007?ooool0
0ol0003oooooooooo`1>ooooo`;o00000_ooool2o`0000gooooo1?l0000;ooooo`;o00001Oooool4
o`000003ooooool0003o000000;o00000oooool2o`0001_ooooo1?l00008ooooo`;o00001oooool2
o`000003ooooool0003o000000?ooooo0_l00007ooooo`;o00002_ooool2o`00017ooooo0_l00000
0ooooooo0000o`00001Oooooo`007?ooool00ol0003oooooooooo`1Gooooo`?o00000_ooool2o`00
00?ooooo1?l00003ooooo`;o00002?ooool2o`0000Sooooo1?l00003ooooo`;o000000?oooooo`00
0?l000003?ooool2o`000003ooooool0003o000000Wooooo0_l00006ooooo`;o00002Oooool2o`00
00oooooo0ol00002ooooo`;o00000oooool4o`0000Oooooo0_l0001/ooooo`007?ooool00ol0003o
ooooooooo`1Fooooo`Co00000_ooool2o`0000Cooooo0ol00003ooooo`;o00000_ooool4o`0000;o
oooo0_l0000Booooo`;o00002_ooool9o`0000Sooooo0_l00005ooooo`;o00001oooool2o`0000Oo
oooo0_l00009ooooo`;o00000_ooool2o`0000?ooooo0_l00009ooooo`;o00002Oooool2o`00067o
oooo000Looooo`;o0000Eoooool2o`0000Gooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo
1_l0000:ooooo`;o00005?ooool4o`0000;ooooo1Ol00008ooooo`;o00003?ooool4o`0000Oooooo
0_l0000Eooooo`Go00000_ooool2o`0000[ooooo0_l0001Qooooo`007?ooool00ol0003ooooooooo
o`1Mooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000002_oo
ool3o`0001Cooooo1?l00006ooooo`Go00001_ooool2o`0000;ooooo0_l00006ooooo`;o00003?oo
ool2o`0000Cooooo0_l000000ooooooo0000o`000009ooooo`Go00000_ooool2o`0006gooooo000L
ooooo`03o`000?oooooooooo05kooooo1?l00002ooooo`;o00001oooool2o`0000;ooooo1?l00004
ooooo`;o00002_ooool2o`0001?ooooo1Ol00006ooooo`;o00000_ooool2o`0000[ooooo0_l00000
0ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o
000001[ooooo0_l0001Sooooo`007?ooool00ol0003oooooooooo`1Nooooo`Co00000_ooool7o`00
0003ooooool0003o000000?ooooo1?l00004ooooo`;o00002_ooool2o`0001Oooooo0_l0000<oooo
o`?o00001_ooool2o`000005ooooool0003o0000o`000?ooool00_l0000=ooooo`;o00002oooool2
o`0000[ooooo0_l0001Sooooo`007?ooool00ol0003oooooooooo`1Uooooo`Ko000000?oooooo`00
0?l000002_ooool3o`0001Kooooo0_l00003ooooo`;o00001_ooool2o`0000Wooooo0_l000001?oo
oooo0000o`000?l0000:ooooo`;o00000_ooool2o`0000cooooo1?l00009ooooo`?o0000K_ooool0
01cooooo00?o0000ooooooooool0IOooool2o`0000gooooo0_l00002ooooo`;o00002oooool2o`00
00Cooooo0_l00004ooooo`;o00000oooool2o`0000Gooooo0_l0000:ooooo`;o00001oooool2o`00
00Wooooo0_l0000<ooooo`Co00002?ooool4o`0000Kooooo0_l0001Vooooo`007?ooool00ol0003o
ooooooooo`1dooooo`;o00003oooool2o`0000Cooooo0_l000001Ooooooo0000o`000?l0003ooooo
00;o00002Oooool2o`000003ooooool0003o000000?ooooo0_l00008ooooo`;o000000?oooooo`00
0?l000002?ooool2o`0000gooooo0_l00002ooooo`;o00001_ooool2o`0000Sooooo0_l0001Voooo
o`007?ooool00ol0003oooooooooo`1cooooo`;o00000_ooool3o`0000Gooooo0_l0000=ooooo`?o
000000?oooooo`000?l000001?ooool3o`0000Gooooo0ol000001?oooooo0000o`000?l00002oooo
o`;o00000oooool3o`000003ooooool0003o000000Sooooo0_l0000=ooooo`;o000000Coooooo`00
0?l0003o00004?ooool2o`0006Kooooo000Looooo`03o`000?oooooooooo06;ooooo0ol0000>oooo
o`;o00000_ooool3o`0000Gooooo1?l0000Eooooo`?o00001_ooool2o`000004ooooool0003o0000
ooooo`Ko000000?oooooo`000?l000000_ooool2o`0001[ooooo0_l00002ooooo`;o00000_ooool2
o`00077ooooo000Looooo`03o`000?oooooooooo06;ooooo0ol00005ooooo`;o00005?ooool3o`00
00;ooooo0_l00002ooooo`;o00004_ooool3o`0000Oooooo0_l00002ooooo`Co00005_ooool2o`00
00_ooooo0_l00002ooooo`;o0000LOooool001cooooo00?o0000ooooooooool0I_ooool2o`0000;o
oooo0_l000000ooooooo0000o`000009ooooo`;o00002_ooool3o`000005ooooool0003o0000o`00
0?ooool00_l0000?ooooo`Go00002oooool2o`0000?ooooo1?l00002ooooo`;o00000_ooool2o`00
0003ooooool0003o000000Cooooo0_l00022ooooo`007?ooool00ol0003oooooooooo`1Vooooo`;o
00001Oooool2o`0000?ooooo0_l00004ooooo`;o00002_ooool2o`0000;ooooo0_l00002ooooo`;o
00004Oooool3o`0000;ooooo0_l00003ooooo`;o00001oooool4o`0000;ooooo1_l000000ooooooo
0000o`00000?ooooo`;o00001oooool2o`0006kooooo000Looooo`03o`000?oooooooooo06Sooooo
0_l00003ooooo`;o00000oooool2o`0000kooooo0_l0000Jooooo`?o00000_ooool3o`0000?ooooo
0_l00008ooooo`;o00001Oooool2o`0000Gooooo0_l00003ooooo`;o00001?ooool2o`0000;ooooo
0_l000000ooooooo0000o`000004ooooo`;o0000K_ooool001cooooo00?o0000ooooooooool0D?oo
ool2o`0001Kooooo0_l0000;ooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`;o0000
6_ooool2o`0000?ooooo0ol0000Cooooo`;o00001Oooool3o`0000?ooooo0_l00003ooooo`Co0000
1?ooool2o`0007Cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1@ooooo`;o00008oooool2o`00
00Gooooo0_l000000ooooooo0000o`00000Cooooo`;o00001_ooool3o`0000Gooooo0_l0000:oooo
o`;o00001oooool2o`0000Gooooo0_l00009ooooo`Co00000oooool2o`0007Gooooo00001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_oo
ool00ol0003oooooooooo`27ooooo`;o00000_ooool2o`0000Oooooo0_l00006ooooo`?o00000ooo
ool4o`0000Sooooo1?l00002ooooo`;o000000?oooooo`000?l000000_l0000@ooooo`;o00001?oo
ool3o`0007Gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo06kooooo0_l0000<ooooo`;o00002Ooo
ool2o`000004ooooool0003o0000o`0000_ooooo0_l00008ooooo`Co00001?ooool2o`0000;ooooo
0_l00002ooooo`Wo00002_ooool2o`0000Cooooo1?l00002ooooo`;o0000M_ooool00003ooooool0
003ooooo00;ooooo00?o0000ooooooooool02Oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo
0ol0001^ooooo`;o00002oooool4o`0000_ooooo0_l000000ooooooo0000o`000009ooooo`;o0000
1?ooool2o`0000?ooooo0_l00005ooooo`;o00000_ooool2o`0000;ooooo0ol000001?oooooo0000
o`000?ooool2o`0000Oooooo0_l000000ooooooo0000o`000002ooooo`;o000000Coooooo`000?l0
003o00005Oooool2o`0006?ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wo
oooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo07_ooooo1?l00006oooo
o`;o00001_ooool2o`0000oooooo0_l00003ooooo`;o00001_ooool2o`000003ooooool0003o0000
00Kooooo1Ol00003ooooo`;o00000_ooool2o`0000Gooooo0ol0000Hooooo`;o0000Hoooool00003
ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol@413o^[Zjoooooonj^[[o410@
00Kooooo00?o0000ooooooooool0O_ooool2o`0000Gooooo0_l00002ooooo`;o00006_ooool3o`00
00?ooooo0_l000000ooooooo0000o`000007ooooo`;o000000?oooooo`000?l000000_ooool2o`00
00Gooooo0_l00003ooooo`;o0000OOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool0
1Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0N?ooool2o`0000Cooooo0_l0
0009ooooo`;o00002oooool3o`0000cooooo0ol00006ooooo`;o00000_ooool2o`0000Kooooo0_l0
0009ooooo`;o00006_ooool2o`0006Kooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo
00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo06oooooo0ol00006ooooo`;o
00001?ooool2o`0000kooooo0_l00006ooooo`?o00003oooool2o`0000Cooooo0_l00002ooooo`;o
00001_ooool2o`0002Gooooo0_l0001Vooooo`007?ooool00ol0003oooooooooo`1_ooooo`?o0000
0oooool2o`0001Oooooo0_l0000Hooooo`;o0000Woooool001cooooo00?o0000ooooooooool0G_oo
ool2o`0000gooooo0_l00006ooooo`;o00002_ooool2o`0000Gooooo0_l00003ooooo`;o00000ooo
ool2o`0001Cooooo0_l00003ooooo`;o0000V_ooool001cooooo00?o0000ooooooooool0G_ooool2
o`0000gooooo0_l0000Booooo`;o00001Oooool2o`0000?ooooo0_l00003ooooo`;o00002oooool4
o`0000Gooooo0_l00003ooooo`?o00000_ooool2o`000003ooooool0003o000000gooooo0_l00023
ooooo`007?ooool00ol0003oooooooooo`27ooooo`;o00004?ooool4o`000003ooooool0003o0000
00Go00001?ooool2o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000001_ooool2o`00
00Gooooo0_l00023ooooo`007?ooool00ol0003oooooooooo`1booooo`;o00004?ooool2o`000003
ooooool0003o0000013ooooo1?l000000ooooooo0000o`000003ooooo`;o00001?ooool2o`0001;o
oooo0_l00004ooooo`;o0000Q?ooool001cooooo00?o0000ooooooooool0L_ooool2o`0000Sooooo
0_l00006ooooo`;o00001oooool2o`0000cooooo0_l00009ooooo`;o00006oooool2o`00013ooooo
0_l0001booooo`007?ooool00ol0003oooooooooo`1iooooo`;o000000Coooooo`000?l0003o0000
3_ooool2o`0000Cooooo0_l00005ooooo`?o00002Oooool2o`0000Kooooo0_l0000Aooooo`;o0000
0_ooool2o`0000kooooo0_l0001booooo`007?ooool00ol0003oooooooooo`1iooooo`;o00000_oo
ool2o`0000cooooo0_l00006ooooo`?o00001?ooool4o`00013ooooo0_l00002ooooo`;o00003Ooo
ool2o`0000;ooooo0_l00022ooooo`007?ooool00ol0003oooooooooo`2;ooooo`;o00001Oooool4
o`0000Kooooo0_l0000Cooooo`?o00000oooool2o`0000;ooooo1?l00006ooooo`;o0000P_ooool0
01cooooo00?o0000ooooooooool0T_ooool2o`0001Kooooo0_l00005ooooo`;o00000_ooool4o`00
00;ooooo1?l0002:ooooo`007?ooool00ol0003oooooooooo`2Dooooo`;o00004oooool3o`000003
ooooool0003o000000Kooooo0_l0002Booooo`007?ooool2o`0008Wooooo0_l0000:ooooo`;o0000
4oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`00097ooooo000Looooo`03o`000?oo
oooooooo08Sooooo0_l0000Oooooo`;o00001oooool2o`0000;ooooo0_l0002Aooooo`007?ooool0
0ol0003oooooooooo`2:ooooo`;o00001oooool2o`0000Kooooo0_l0000<ooooo`;o00000_ooool2
o`0009[ooooo000Looooo`03o`000?oooooooooo08[ooooo0_l00007ooooo`;o00001_ooool2o`00
013ooooo0_l0002Jooooo`007?ooool00ol0003oooooooooo`2dooooo`;o0000Toooool001cooooo
00?o0000ooooooooool0]?ooool2o`0009?ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`2aooooo`;o0000U_ooool001cooooo00?o0000
ooooooooool0/Oooool2o`0009Kooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`004_ooool4o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool3o`00
0?ooooooB_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003ooooo
ooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000
ooooooooool0oooooomBooooo`004_ooool00omEEEGoIVIVo`00003ooooooeCooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo002Qooooo`04oa0@4?l0003o0000ooooo`;o000000?o
410@ooooooooool05_ooool4o`000008oa0@4?oooooooooooiRHV?l@413o0000oc8b<_o<c<`3oooo
o`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<08cooooo002R
ooooo`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo00?o0000ooooooooool00_oo
ool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoEEEEogMgMoooooooV9RHob4Q8@03ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40S?ooool00:;ooooo00Go0000ooooooooooooooooo`00000Koooo
o`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`2:ooooo`00X_ooool01Ol0003ooooooooooooo
oooo000000Wooooo1_l0000<ooooo`03o`000?oooooooooo00Gooooo00?oZJVYoa0@4?ooool00_oo
ool01Ol0003oV9RHoooooonHV9So8B4Q00?ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P2<ooooo`00
X_ooool01Ol0003oQhN7oooooonYZJWo000001_ooooo00?o0000ooooooooool01?ooool00ol@413o
0000okZj^P03ooooo`05o`000?mEEEGo0000oa0@4?o<c<`00oooool01Oo<c<co0000o`000?l0003o
c<c<08cooooo002Qooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool06Oooool00ol0
003oooooooooo`05ooooo`03okZj^_lQ8B7ooooo00;ooooo00?oEEEEohN7Qoooool01Oooool01Ol@
413o^[Zjoooooonj^[[o410@08cooooo0032ooooo`03o`000?oooooooooo00;ooooo00Go410@oiRH
V?oooooo^[Zjo`000003ooooo`03omgMgOl@413oV9RH00Gooooo00Go0000okZj^_oooooo^[Zjo`00
002<ooooo`00`?ooool00omEEEGoIVIVo`000004ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01?oo
ool01?o<c<coA4A4o`000?l@4103ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0S?ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1374) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.32593 .39309 Mdot
.32748 .38098 Mdot
.51117 .64725 Mdot
.6051 .43376 Mdot
.70548 .70892 Mdot
.4876 .67537 Mdot
.36595 .53513 Mdot
.32779 .56167 Mdot
.52044 .64789 Mdot
.34055 .48803 Mdot
.33992 .58783 Mdot
.54856 .48566 Mdot
.35983 .56543 Mdot
.56604 .43235 Mdot
.86942 .52858 Mdot
.60259 .35582 Mdot
.32779 .39432 Mdot
.60358 .57311 Mdot
.55021 .36803 Mdot
.46926 .67378 Mdot
.36389 .42686 Mdot
.57163 .4292 Mdot
.38411 .39943 Mdot
.56546 .4323 Mdot
.60608 .40986 Mdot
.38488 .38784 Mdot
.41894 .38133 Mdot
.59676 .38408 Mdot
.56111 .37789 Mdot
.3281 .5754 Mdot
.69897 .47171 Mdot
.82862 .59577 Mdot
.62175 .346 Mdot
.7971 .48015 Mdot
.34363 .54371 Mdot
.48185 .30807 Mdot
.49435 .66667 Mdot
.34933 .58229 Mdot
.35462 .58706 Mdot
.32788 .54746 Mdot
.33757 .57184 Mdot
.36767 .3959 Mdot
.27336 .4243 Mdot
.43999 .69583 Mdot
.63412 .39533 Mdot
.55019 .80051 Mdot
.43877 .35857 Mdot
.5509 .44306 Mdot
.35973 .35417 Mdot
.59374 .67022 Mdot
.39877 .68002 Mdot
.36933 .54663 Mdot
.48355 .69239 Mdot
.17869 .31747 Mdot
.36947 .56559 Mdot
.57108 .4792 Mdot
.50469 .66023 Mdot
.56976 .41469 Mdot
.56167 .43 Mdot
.50889 .22239 Mdot
.61814 .45457 Mdot
.65742 .61167 Mdot
.34946 .3364 Mdot
.47348 .56812 Mdot
.51359 .66564 Mdot
.35273 .59193 Mdot
.33446 .37407 Mdot
.36282 .55708 Mdot
.66684 .40296 Mdot
.52838 .69637 Mdot
.55277 .44672 Mdot
.34251 .58858 Mdot
.39363 .41183 Mdot
.57051 .38617 Mdot
.52987 .74744 Mdot
.51145 .82306 Mdot
.68607 .585 Mdot
.48226 .28724 Mdot
.501 .21923 Mdot
.61191 .70214 Mdot
.61031 .37577 Mdot
.71974 .53762 Mdot
.51572 .81403 Mdot
.39081 .3599 Mdot
.57339 .34999 Mdot
.59446 .59961 Mdot
.57578 .38652 Mdot
.61525 .80555 Mdot
.57115 .46229 Mdot
.59415 .55131 Mdot
.51974 .63677 Mdot
.36449 .367 Mdot
.6087 .43055 Mdot
.55343 .39026 Mdot
.55795 .22179 Mdot
.52683 .41665 Mdot
.58651 .41906 Mdot
.35828 .34977 Mdot
.37051 .54964 Mdot
.58017 .47502 Mdot
.43106 .62766 Mdot
.48198 .63096 Mdot
.62438 .42667 Mdot
.53295 .639 Mdot
.40406 .39503 Mdot
.55366 .39124 Mdot
.36259 .58532 Mdot
.61552 .44621 Mdot
.22187 .55894 Mdot
.33598 .40117 Mdot
.58102 .37596 Mdot
.64627 .5671 Mdot
.41889 .24258 Mdot
.36936 .36167 Mdot
.42273 .62917 Mdot
.5481 .37247 Mdot
.58412 .40838 Mdot
.33337 .36776 Mdot
.50605 .61976 Mdot
.58883 .81157 Mdot
.35786 .34645 Mdot
.32432 .57662 Mdot
.38316 .42318 Mdot
.52888 .4671 Mdot
.51598 .67418 Mdot
.4297 .6729 Mdot
.22363 .51668 Mdot
.72096 .46513 Mdot
.57587 .38926 Mdot
.28879 .43901 Mdot
.46765 .64807 Mdot
.35296 .37096 Mdot
.35906 .55715 Mdot
.56089 .34619 Mdot
.34946 .40203 Mdot
.34486 .59543 Mdot
.66196 .57972 Mdot
.33398 .66482 Mdot
.38615 .40932 Mdot
.48202 .48315 Mdot
.38342 .57862 Mdot
.35009 .53438 Mdot
.75962 .32735 Mdot
.33896 .37095 Mdot
.63651 .60004 Mdot
.34983 .5535 Mdot
.72918 .42382 Mdot
.63683 .40708 Mdot
.69411 .52393 Mdot
.22146 .37245 Mdot
.7872 .45245 Mdot
.3581 .70186 Mdot
.63455 .57839 Mdot
.38094 .60384 Mdot
.59891 .42009 Mdot
.3875 .37944 Mdot
.3846 .3944 Mdot
.61901 .45273 Mdot
.61397 .408 Mdot
.55384 .45042 Mdot
.53636 .42239 Mdot
.68279 .40875 Mdot
.5196 .41571 Mdot
.42383 .33214 Mdot
.37033 .36913 Mdot
.60124 .43008 Mdot
.50437 .69558 Mdot
.64175 .43982 Mdot
.33766 .57931 Mdot
.5733 .42037 Mdot
.60648 .43118 Mdot
.63279 .42896 Mdot
.36386 .54163 Mdot
.81017 .63439 Mdot
.37924 .26365 Mdot
.79285 .63369 Mdot
.56759 .53556 Mdot
.52337 .68943 Mdot
.58628 .38913 Mdot
.65491 .60482 Mdot
.55194 .28622 Mdot
.59904 .44628 Mdot
.14964 .63158 Mdot
.58141 .42551 Mdot
.73435 .69417 Mdot
.64405 .45695 Mdot
.80202 .57912 Mdot
.7161 .5176 Mdot
.59986 .40638 Mdot
.33614 .46646 Mdot
.38562 .55233 Mdot
.45484 .68601 Mdot
.34112 .56964 Mdot
.49803 .69444 Mdot
.50907 .65168 Mdot
.45282 .59033 Mdot
.53805 .48245 Mdot
.64969 .40831 Mdot
.54875 .45304 Mdot
.54438 .65849 Mdot
.37739 .34477 Mdot
.65543 .56806 Mdot
.32242 .36663 Mdot
.75133 .74205 Mdot
.49423 .76491 Mdot
.32531 .53634 Mdot
.67393 .59517 Mdot
.50022 .62924 Mdot
.52597 .64214 Mdot
.64472 .57049 Mdot
.55007 .40924 Mdot
.34103 .37607 Mdot
.77958 .37546 Mdot
.23537 .60095 Mdot
.70228 .22026 Mdot
.3643 .35179 Mdot
.31147 .47057 Mdot
.32894 .56927 Mdot
.48885 .65525 Mdot
.58524 .41109 Mdot
.55768 .40246 Mdot
.34109 .42059 Mdot
.54897 .44481 Mdot
.30613 .32603 Mdot
.5923 .40655 Mdot
.33441 .63102 Mdot
.66976 .56655 Mdot
.45367 .5909 Mdot
.74335 .46695 Mdot
.39446 .3702 Mdot
.64073 .25581 Mdot
.53283 .65251 Mdot
.5501 .28172 Mdot
.35799 .59562 Mdot
.66814 .59452 Mdot
.52631 .66943 Mdot
.64889 .56541 Mdot
.52244 .39891 Mdot
.4795 .68176 Mdot
.62591 .57741 Mdot
.62503 .52257 Mdot
.64222 .40227 Mdot
.18156 .53554 Mdot
.32975 .54818 Mdot
.31768 .37423 Mdot
.60487 .45958 Mdot
.53651 .66481 Mdot
.56377 .3419 Mdot
.38739 .75166 Mdot
.36956 .64339 Mdot
.46782 .6442 Mdot
.50919 .58926 Mdot
.6647 .60788 Mdot
.41233 .72053 Mdot
.29524 .45279 Mdot
.32465 .37827 Mdot
.5249 .41919 Mdot
.81992 .55245 Mdot
.35074 .55345 Mdot
.60527 .45522 Mdot
.70909 .64265 Mdot
.35682 .54632 Mdot
.56982 .41237 Mdot
.34868 .60115 Mdot
.38405 .3952 Mdot
.45611 .21007 Mdot
.33385 .36211 Mdot
.54081 .4392 Mdot
.36848 .58019 Mdot
.53087 .62378 Mdot
.37899 .38676 Mdot
.54709 .41977 Mdot
.59525 .38565 Mdot
.53665 .57409 Mdot
.59334 .43017 Mdot
.7816 .66054 Mdot
.5963 .40607 Mdot
.49766 .64668 Mdot
.62144 .3868 Mdot
.32569 .25387 Mdot
.4473 .58988 Mdot
.33626 .37359 Mdot
.47003 .63648 Mdot
.51652 .65508 Mdot
.53042 .76459 Mdot
.34744 .61295 Mdot
.56106 .3684 Mdot
.53308 .67512 Mdot
.70341 .36349 Mdot
.37632 .59474 Mdot
.60314 .4679 Mdot
.45336 .46653 Mdot
.58661 .66524 Mdot
.47831 .68821 Mdot
.51833 .36139 Mdot
.39706 .4026 Mdot
.61221 .42482 Mdot
.52446 .63558 Mdot
.50498 .44695 Mdot
.57884 .37093 Mdot
.25408 .35214 Mdot
.53826 .58079 Mdot
.38016 .56654 Mdot
.62603 .46859 Mdot
.5813 .45453 Mdot
.48513 .68399 Mdot
.39318 .37189 Mdot
.37892 .5923 Mdot
.37277 .39349 Mdot
.79981 .56185 Mdot
.18867 .54034 Mdot
.6535 .48796 Mdot
.65037 .56145 Mdot
.60044 .63535 Mdot
.8047 .56285 Mdot
.57287 .19809 Mdot
.68222 .2914 Mdot
.80968 .4635 Mdot
.5257 .62995 Mdot
.65515 .65373 Mdot
.51143 .65764 Mdot
.61257 .39404 Mdot
.51358 .67457 Mdot
.82433 .54137 Mdot
.59136 .40936 Mdot
.50445 .67714 Mdot
.61001 .24036 Mdot
.60919 .42387 Mdot
.32626 .37595 Mdot
.74762 .72638 Mdot
.41793 .18712 Mdot
.36625 .63944 Mdot
.4799 .64682 Mdot
.71419 .32833 Mdot
.58794 .42045 Mdot
.62029 .38618 Mdot
.38227 .37132 Mdot
.59484 .33787 Mdot
.64264 .61447 Mdot
.67353 .60257 Mdot
.37709 .51983 Mdot
.69249 .59159 Mdot
.62325 .47137 Mdot
.37919 .38378 Mdot
.67839 .41679 Mdot
.55094 .73823 Mdot
.60025 .66313 Mdot
.34598 .51658 Mdot
.74745 .72512 Mdot
.37809 .33154 Mdot
.29332 .58166 Mdot
.54941 .70087 Mdot
.35118 .35887 Mdot
.82665 .61354 Mdot
.3448 .57298 Mdot
.18371 .56742 Mdot
.35347 .45943 Mdot
.5524 .40981 Mdot
.37585 .58715 Mdot
.51916 .3717 Mdot
.43895 .18092 Mdot
.2201 .64401 Mdot
.47411 .38432 Mdot
.58063 .46406 Mdot
.54052 .72981 Mdot
.57796 .41649 Mdot
.45791 .77118 Mdot
.59832 .40027 Mdot
.36968 .39001 Mdot
.33473 .49154 Mdot
.41451 .58894 Mdot
.32717 .29024 Mdot
.42316 .7368 Mdot
.63142 .58007 Mdot
.5895 .40476 Mdot
.55183 .41262 Mdot
.63024 .60856 Mdot
.38767 .40124 Mdot
.54563 .44487 Mdot
.63792 .24838 Mdot
.54866 .39631 Mdot
.3412 .57918 Mdot
.3013 .40487 Mdot
.40409 .33622 Mdot
.53709 .40319 Mdot
.40945 .38164 Mdot
.33585 .52724 Mdot
.36625 .57898 Mdot
.63192 .46829 Mdot
.32068 .55916 Mdot
.58164 .4332 Mdot
.24168 .67508 Mdot
.37545 .41289 Mdot
.22718 .40679 Mdot
.34916 .39407 Mdot
.47132 .28082 Mdot
.3624 .54501 Mdot
.35586 .65644 Mdot
.50683 .40066 Mdot
.34929 .57232 Mdot
.38568 .43121 Mdot
.61726 .36714 Mdot
.63161 .37701 Mdot
.76055 .36219 Mdot
.497 .6389 Mdot
.52739 .57635 Mdot
.32747 .57489 Mdot
.55369 .43766 Mdot
.53376 .39466 Mdot
.33276 .53049 Mdot
.23868 .64442 Mdot
.47652 .18696 Mdot
.59419 .40707 Mdot
.36423 .38135 Mdot
.35256 .37453 Mdot
.63429 .44079 Mdot
.62319 .42162 Mdot
.51788 .68146 Mdot
.5186 .61777 Mdot
.51312 .69983 Mdot
.52398 .57936 Mdot
.35293 .65167 Mdot
.63875 .76884 Mdot
.32819 .54706 Mdot
.28619 .48664 Mdot
.60041 .54947 Mdot
.54824 .45631 Mdot
.47899 .64261 Mdot
.5817 .45311 Mdot
.58994 .4397 Mdot
.3259 .59704 Mdot
.71763 .67142 Mdot
.42875 .37983 Mdot
.4005 .37847 Mdot
.38586 .57977 Mdot
.61828 .48081 Mdot
.30473 .5519 Mdot
.66471 .593 Mdot
.76892 .41269 Mdot
.35078 .59371 Mdot
.32828 .37098 Mdot
.33409 .54871 Mdot
.55627 .39791 Mdot
.51699 .4365 Mdot
.34822 .36151 Mdot
.64468 .61973 Mdot
.59935 .34106 Mdot
.57266 .4102 Mdot
.20431 .38811 Mdot
.75482 .42498 Mdot
.30788 .62035 Mdot
.59824 .408 Mdot
.5484 .3847 Mdot
.62167 .61264 Mdot
.54959 .39678 Mdot
.57354 .45881 Mdot
.42775 .24579 Mdot
.23773 .52324 Mdot
.67771 .59202 Mdot
.24736 .67229 Mdot
.36042 .35135 Mdot
.82139 .57499 Mdot
.47902 .65994 Mdot
.39849 .53932 Mdot
.43038 .19903 Mdot
.48866 .69566 Mdot
.35757 .70677 Mdot
.82022 .59156 Mdot
.42863 .61331 Mdot
.4542 .63758 Mdot
.42155 .37575 Mdot
.53983 .43348 Mdot
.58074 .40803 Mdot
.65221 .60873 Mdot
.34523 .38067 Mdot
.51323 .55198 Mdot
.40252 .81165 Mdot
.57412 .42751 Mdot
.2508 .3702 Mdot
.30497 .72273 Mdot
.58323 .67492 Mdot
.65079 .59307 Mdot
.67022 .61237 Mdot
.58749 .40359 Mdot
.39146 .25127 Mdot
.38474 .38672 Mdot
.54756 .42123 Mdot
.52024 .42101 Mdot
.48717 .64352 Mdot
.34683 .40806 Mdot
.50314 .6199 Mdot
.38477 .6815 Mdot
.779 .6504 Mdot
.15346 .52919 Mdot
.37032 .5588 Mdot
.43473 .78583 Mdot
.36428 .60358 Mdot
.72467 .5378 Mdot
.46031 .67301 Mdot
.61624 .42612 Mdot
.39545 .37637 Mdot
.55948 .44257 Mdot
.62179 .42089 Mdot
.55017 .4114 Mdot
.53412 .40584 Mdot
.14403 .47701 Mdot
.63332 .57534 Mdot
.53999 .36765 Mdot
.5029 .64557 Mdot
.53023 .80562 Mdot
.48668 .80755 Mdot
.55363 .41629 Mdot
.59509 .39317 Mdot
.36733 .4095 Mdot
.61484 .45476 Mdot
.3715 .60221 Mdot
.32917 .35119 Mdot
.56548 .38435 Mdot
.7016 .75981 Mdot
.56561 .37522 Mdot
.80396 .59886 Mdot
.33392 .55101 Mdot
.22034 .57853 Mdot
.51078 .41679 Mdot
.38196 .63529 Mdot
.52788 .5763 Mdot
.52387 .67493 Mdot
.34907 .60494 Mdot
.49617 .66875 Mdot
.3696 .7968 Mdot
.5305 .46082 Mdot
.60133 .41807 Mdot
.54308 .45256 Mdot
.52333 .68982 Mdot
.64507 .79196 Mdot
.4389 .73477 Mdot
.51263 .44376 Mdot
.51115 .6912 Mdot
.39909 .36072 Mdot
.74912 .37797 Mdot
.36006 .39784 Mdot
.62176 .56361 Mdot
.33177 .57132 Mdot
.64736 .61879 Mdot
.75588 .59687 Mdot
.32973 .39344 Mdot
.32652 .40277 Mdot
.48117 .66108 Mdot
.37122 .47076 Mdot
.43261 .14167 Mdot
.35096 .45918 Mdot
.72579 .49518 Mdot
.37986 .37648 Mdot
.55655 .38212 Mdot
.73605 .57161 Mdot
.35358 .47034 Mdot
.49922 .66952 Mdot
.58854 .44632 Mdot
.45675 .207 Mdot
.51824 .68129 Mdot
.54805 .45956 Mdot
.50333 .64137 Mdot
.33739 .56501 Mdot
.48544 .63689 Mdot
.31241 .39192 Mdot
.58094 .38189 Mdot
.47748 .1215 Mdot
.65159 .64479 Mdot
.59184 .41922 Mdot
.385 .56757 Mdot
.29594 .67352 Mdot
.60969 .44454 Mdot
.6317 .56833 Mdot
.50237 .68351 Mdot
.3982 .45607 Mdot
.59584 .40433 Mdot
.50957 .69234 Mdot
.33073 .40158 Mdot
.3837 .60533 Mdot
.54845 .22103 Mdot
.3672 .63416 Mdot
.38252 .36944 Mdot
.52429 .51353 Mdot
.33069 .59258 Mdot
.54737 .38594 Mdot
.52606 .41455 Mdot
.36034 .38045 Mdot
.65578 .52444 Mdot
.62953 .41031 Mdot
.6135 .37998 Mdot
.48825 .64798 Mdot
.49527 .67265 Mdot
.65638 .28867 Mdot
.51707 .6215 Mdot
.51617 .43211 Mdot
.36056 .38284 Mdot
.60782 .43321 Mdot
.36471 .41166 Mdot
.61515 .4538 Mdot
.59369 .50477 Mdot
.38862 .40027 Mdot
.33491 .61249 Mdot
.59053 .44373 Mdot
.63495 .3561 Mdot
.61275 .44935 Mdot
.5393 .42852 Mdot
.51965 .67476 Mdot
.65681 .59736 Mdot
.52742 .43982 Mdot
.66698 .63086 Mdot
.65493 .56975 Mdot
.40718 .59367 Mdot
.48968 .64163 Mdot
.63002 .59616 Mdot
.31698 .74019 Mdot
.48739 .6904 Mdot
.6461 .61186 Mdot
.48847 .80779 Mdot
.346 .54223 Mdot
.39554 .40547 Mdot
.6106 .42073 Mdot
.78671 .55846 Mdot
.42564 .3457 Mdot
.47403 .62348 Mdot
.59524 .40954 Mdot
.60271 .45441 Mdot
.36958 .34768 Mdot
.41071 .83146 Mdot
.528 .69643 Mdot
.56585 .37125 Mdot
.33023 .38436 Mdot
.41182 .84866 Mdot
.50207 .65049 Mdot
.65077 .61176 Mdot
.34258 .53873 Mdot
.42927 .39653 Mdot
.22141 .51691 Mdot
.37401 .5445 Mdot
.51434 .72115 Mdot
.38995 .67572 Mdot
.54014 .37704 Mdot
.47446 .64463 Mdot
.72461 .26133 Mdot
.67287 .37306 Mdot
.4829 .57555 Mdot
.71938 .33604 Mdot
.35931 .35949 Mdot
.36673 .60313 Mdot
.6354 .57656 Mdot
.37332 .35508 Mdot
.33053 .39819 Mdot
.32944 .53622 Mdot
.39924 .26408 Mdot
.44864 .46464 Mdot
.34862 .58547 Mdot
.77737 .47485 Mdot
.65065 .74259 Mdot
.47634 .64482 Mdot
.64116 .61378 Mdot
.74453 .6152 Mdot
.37054 .39611 Mdot
.7748 .70508 Mdot
.76393 .36005 Mdot
.58641 .41932 Mdot
.63251 .59141 Mdot
.65092 .7794 Mdot
.45703 .83238 Mdot
.36098 .54749 Mdot
.4076 .57166 Mdot
.65623 .61576 Mdot
.60255 .45952 Mdot
.74227 .39154 Mdot
.61663 .38897 Mdot
.3305 .56576 Mdot
.58035 .23869 Mdot
.32786 .39251 Mdot
.33831 .53387 Mdot
.76836 .4052 Mdot
.57975 .43331 Mdot
.59257 .44466 Mdot
.75775 .48541 Mdot
.38343 .35866 Mdot
.52417 .67507 Mdot
.52608 .39549 Mdot
.57324 .41407 Mdot
.535 .45401 Mdot
.61729 .47137 Mdot
.43049 .23039 Mdot
.60819 .39418 Mdot
.49511 .77343 Mdot
.5871 .46492 Mdot
.57762 .44188 Mdot
.40933 .38533 Mdot
.14815 .54675 Mdot
.40501 .69403 Mdot
.57385 .41801 Mdot
.55364 .37817 Mdot
.33755 .53583 Mdot
.40288 .47176 Mdot
.38689 .46918 Mdot
.40867 .45017 Mdot
.69868 .30817 Mdot
.64424 .4069 Mdot
.33674 .37966 Mdot
.62363 .57844 Mdot
.55745 .37113 Mdot
.3338 .3805 Mdot
.63521 .41703 Mdot
.51849 .68311 Mdot
.48962 .69173 Mdot
.67566 .40822 Mdot
.62741 .59291 Mdot
.2809 .35322 Mdot
.28257 .48562 Mdot
.48672 .68705 Mdot
.6035 .41592 Mdot
.38063 .62022 Mdot
.52555 .63817 Mdot
.43455 .61374 Mdot
.67575 .54827 Mdot
.39017 .3799 Mdot
.36836 .36696 Mdot
.69178 .52578 Mdot
.35986 .69148 Mdot
.25327 .32489 Mdot
.33597 .56494 Mdot
.52977 .37818 Mdot
.3156 .4586 Mdot
.37078 .36519 Mdot
.73493 .55254 Mdot
.63036 .59105 Mdot
.35457 .54584 Mdot
.50504 .7348 Mdot
.35698 .40589 Mdot
.35159 .41652 Mdot
.61429 .46236 Mdot
.56502 .40837 Mdot
.67621 .28612 Mdot
.65856 .63496 Mdot
.369 .53735 Mdot
.64632 .61466 Mdot
.46031 .67126 Mdot
.6023 .38145 Mdot
.38809 .39797 Mdot
.62912 .76008 Mdot
.54978 .37422 Mdot
.52416 .65558 Mdot
.36095 .36208 Mdot
.66532 .60839 Mdot
.62612 .57143 Mdot
.53747 .419 Mdot
.61936 .27085 Mdot
.35207 .57974 Mdot
.34313 .35888 Mdot
.30224 .56289 Mdot
.62247 .39587 Mdot
.57057 .40196 Mdot
.65917 .41618 Mdot
.37012 .53829 Mdot
.26753 .55164 Mdot
.65031 .56309 Mdot
.34478 .37524 Mdot
.60416 .39355 Mdot
.63475 .60852 Mdot
.2981 .48686 Mdot
.46341 .65137 Mdot
.49013 .63391 Mdot
.6212 .57715 Mdot
.64269 .58981 Mdot
.64157 .56451 Mdot
.77661 .70385 Mdot
.35325 .34279 Mdot
.38551 .33454 Mdot
.6092 .3669 Mdot
.71781 .50903 Mdot
.54435 .36118 Mdot
.3824 .58354 Mdot
.50151 .63781 Mdot
.61687 .43586 Mdot
.53901 .40362 Mdot
.6414 .46275 Mdot
.23686 .38313 Mdot
.43499 .37205 Mdot
.34196 .40669 Mdot
.51411 .43139 Mdot
.48002 .64963 Mdot
.76566 .73619 Mdot
.79093 .37001 Mdot
.51085 .41995 Mdot
.44904 .45962 Mdot
.39349 .39351 Mdot
.32841 .5446 Mdot
.76547 .53094 Mdot
.34231 .54189 Mdot
.3461 .37182 Mdot
.60776 .39031 Mdot
.27786 .50306 Mdot
.61895 .61065 Mdot
.54898 .43626 Mdot
.33123 .56001 Mdot
.55458 .44709 Mdot
.36996 .53903 Mdot
.78729 .57961 Mdot
.70195 .26337 Mdot
.58192 .42436 Mdot
.56942 .35441 Mdot
.69015 .2811 Mdot
.55315 .42185 Mdot
.60844 .59812 Mdot
.39392 .39333 Mdot
.58842 .23661 Mdot
.62082 .36484 Mdot
.6457 .31636 Mdot
.61983 .38983 Mdot
.56045 .21604 Mdot
.56732 .4014 Mdot
.57698 .6838 Mdot
.5821 .37767 Mdot
.56457 .4581 Mdot
.3717 .57007 Mdot
.33991 .53335 Mdot
.40391 .40471 Mdot
.53686 .65062 Mdot
.80054 .61401 Mdot
.57261 .40677 Mdot
.37834 .64786 Mdot
.24962 .54564 Mdot
.64538 .59043 Mdot
.34773 .37704 Mdot
.46223 .85302 Mdot
.32803 .57917 Mdot
.74439 .32198 Mdot
.66641 .29824 Mdot
.23477 .47193 Mdot
.71853 .62529 Mdot
.30311 .69568 Mdot
.66793 .60159 Mdot
.63223 .42886 Mdot
.66673 .70611 Mdot
.56983 .69351 Mdot
.65866 .53762 Mdot
.34247 .60329 Mdot
.58402 .28207 Mdot
.70473 .68359 Mdot
.6176 .57295 Mdot
.66396 .61455 Mdot
.37016 .54503 Mdot
.46057 .62342 Mdot
.53663 .47985 Mdot
.63459 .58562 Mdot
.52099 .6941 Mdot
.47772 .68345 Mdot
.5158 .7019 Mdot
.38629 .38953 Mdot
.77277 .35596 Mdot
.3162 .54007 Mdot
.38062 .5715 Mdot
.51432 .6013 Mdot
.52069 .3382 Mdot
.31579 .35699 Mdot
.48801 .66068 Mdot
.5012 .62437 Mdot
.39527 .39607 Mdot
.58725 .48202 Mdot
.56376 .4837 Mdot
.57426 .42327 Mdot
.65525 .60241 Mdot
.56207 .40406 Mdot
.5102 .68962 Mdot
.36529 .55359 Mdot
.50215 .62652 Mdot
.38683 .57012 Mdot
.60881 .78076 Mdot
.54348 .41714 Mdot
.58382 .3807 Mdot
.18291 .43885 Mdot
.36619 .42258 Mdot
.55043 .79426 Mdot
.32318 .61687 Mdot
.51045 .65549 Mdot
.57634 .45868 Mdot
.32609 .35329 Mdot
.651 .63302 Mdot
.16098 .53843 Mdot
.62577 .4195 Mdot
.37351 .40218 Mdot
.60178 .38317 Mdot
.68695 .38585 Mdot
.29123 .27328 Mdot
.36348 .391 Mdot
.23861 .356 Mdot
.55835 .37736 Mdot
.35015 .75404 Mdot
.59504 .46807 Mdot
.68394 .45824 Mdot
.62946 .41017 Mdot
.36049 .351 Mdot
.57099 .42218 Mdot
.32599 .3559 Mdot
.47774 .67562 Mdot
.33315 .54144 Mdot
.37933 .36899 Mdot
.52944 .41236 Mdot
.45506 .0758 Mdot
.33898 .55881 Mdot
.58711 .40792 Mdot
.36093 .54118 Mdot
.34532 .38461 Mdot
.36394 .35542 Mdot
.45085 .82191 Mdot
.38515 .6842 Mdot
.33911 .56501 Mdot
.60198 .38183 Mdot
.38885 .765 Mdot
.61624 .41284 Mdot
.71015 .36755 Mdot
.56886 .4781 Mdot
.61924 .38054 Mdot
.49534 .81499 Mdot
.3805 .56629 Mdot
.25301 .32143 Mdot
.48171 .8252 Mdot
.52755 .80641 Mdot
.35748 .42643 Mdot
.61596 .57878 Mdot
.82147 .62116 Mdot
.35093 .65137 Mdot
.51378 .69175 Mdot
.61326 .44383 Mdot
.31356 .40597 Mdot
.35593 .58242 Mdot
.66165 .59146 Mdot
.58221 .42315 Mdot
.49182 .62899 Mdot
.53363 .19101 Mdot
.38306 .59989 Mdot
.36289 .39456 Mdot
.38973 .35599 Mdot
.25429 .71992 Mdot
.60085 .40318 Mdot
.57605 .38155 Mdot
.33112 .57047 Mdot
.27356 .66693 Mdot
.66865 .58212 Mdot
.60804 .2372 Mdot
.34107 .56457 Mdot
.47545 .52907 Mdot
.33135 .37447 Mdot
.59819 .45537 Mdot
.71506 .73492 Mdot
.49897 .74164 Mdot
.19689 .42155 Mdot
.65376 .60501 Mdot
.71206 .37162 Mdot
.35766 .3509 Mdot
.35564 .55573 Mdot
.3281 .67515 Mdot
.64604 .40259 Mdot
.57757 .45104 Mdot
.71062 .39687 Mdot
.4122 .59199 Mdot
.43945 .42076 Mdot
.62562 .41177 Mdot
.51979 .57692 Mdot
.62367 .43093 Mdot
.62133 .35895 Mdot
.54496 .46648 Mdot
.57509 .39364 Mdot
.38291 .40047 Mdot
.59554 .31911 Mdot
.52889 .67701 Mdot
.35723 .33021 Mdot
.47362 .53596 Mdot
.59229 .41415 Mdot
.60496 .37512 Mdot
.46335 .38343 Mdot
.35156 .7173 Mdot
.37694 .36985 Mdot
.32454 .40339 Mdot
.32093 .56555 Mdot
.57795 .48527 Mdot
.53522 .64531 Mdot
.57527 .34318 Mdot
.52127 .6678 Mdot
.38598 .39828 Mdot
.50741 .65361 Mdot
.34675 .53629 Mdot
.47208 .65225 Mdot
.35413 .65251 Mdot
.34447 .55174 Mdot
.3884 .37563 Mdot
.56602 .38749 Mdot
.38573 .57041 Mdot
.729 .45401 Mdot
.65341 .60352 Mdot
.54611 .84849 Mdot
.56564 .38365 Mdot
.23156 .52425 Mdot
.51303 .46791 Mdot
.50229 .62525 Mdot
.28285 .27984 Mdot
.4004 .38266 Mdot
.67704 .60345 Mdot
.39164 .3635 Mdot
.75711 .39796 Mdot
.64396 .59777 Mdot
.53964 .83123 Mdot
.56053 .5848 Mdot
.75172 .4185 Mdot
.59761 .48301 Mdot
.75459 .46119 Mdot
.47018 .68092 Mdot
.35838 .58174 Mdot
.34018 .6868 Mdot
.56879 .45767 Mdot
.60742 .20137 Mdot
.40282 .37136 Mdot
.53646 .65734 Mdot
.36163 .5583 Mdot
.38016 .59115 Mdot
.5797 .36509 Mdot
.62117 .67909 Mdot
.57365 .45261 Mdot
.36053 .68087 Mdot
.70624 .32412 Mdot
.34763 .31921 Mdot
.59185 .40675 Mdot
.48363 .6826 Mdot
.60199 .38336 Mdot
.65561 .56286 Mdot
.75956 .31611 Mdot
.61308 .34629 Mdot
.305 .61158 Mdot
.62883 .63698 Mdot
.3372 .36428 Mdot
.54646 .50052 Mdot
.325 .63088 Mdot
.60299 .40182 Mdot
.12139 .46315 Mdot
.64134 .61105 Mdot
.6676 .70209 Mdot
.53959 .39065 Mdot
.55929 .36814 Mdot
.45201 .56353 Mdot
.21617 .50258 Mdot
.51744 .74405 Mdot
.55758 .43052 Mdot
.71083 .43458 Mdot
.37666 .55466 Mdot
.61075 .45489 Mdot
.58276 .40688 Mdot
.41265 .29276 Mdot
.38343 .59105 Mdot
.51607 .64908 Mdot
.4862 .6952 Mdot
.47746 .62246 Mdot
.66573 .56864 Mdot
.31626 .5151 Mdot
.73417 .52731 Mdot
.47078 .17862 Mdot
.662 .6212 Mdot
.54078 .40287 Mdot
.67615 .64069 Mdot
.6103 .38797 Mdot
.65636 .58696 Mdot
.38353 .59278 Mdot
.3762 .36538 Mdot
.3219 .46896 Mdot
.49287 .69558 Mdot
.64873 .40928 Mdot
.66968 .58069 Mdot
.38801 .38007 Mdot
.75597 .57355 Mdot
.33759 .3671 Mdot
.34963 .56849 Mdot
.30804 .5252 Mdot
.66048 .58812 Mdot
.34512 .38916 Mdot
.29648 .59161 Mdot
.43649 .82862 Mdot
.53604 .46276 Mdot
.29638 .5235 Mdot
.33937 .35481 Mdot
.3165 .39018 Mdot
.33753 .35067 Mdot
.54782 .44196 Mdot
.4505 .46044 Mdot
.63121 .39236 Mdot
.38004 .56306 Mdot
.50717 .64188 Mdot
.66318 .25092 Mdot
.43669 .70468 Mdot
.48503 .4719 Mdot
.51772 .39893 Mdot
.57829 .43413 Mdot
.58728 .40394 Mdot
.61677 .35931 Mdot
.32706 .6514 Mdot
.56561 .44727 Mdot
.37204 .57151 Mdot
.50583 .68536 Mdot
.633 .42737 Mdot
.55211 .65381 Mdot
.5186 .79825 Mdot
.64453 .6214 Mdot
.36981 .52355 Mdot
.79653 .35306 Mdot
.38577 .37781 Mdot
.47153 .63531 Mdot
.49877 .69041 Mdot
.66427 .58347 Mdot
.34699 .581 Mdot
.33718 .36952 Mdot
.70571 .36788 Mdot
.65334 .56924 Mdot
.5717 .41902 Mdot
.44678 .44608 Mdot
.64402 .21844 Mdot
.62971 .43278 Mdot
.60927 .43969 Mdot
.51119 .70558 Mdot
.67803 .68844 Mdot
.56146 .13929 Mdot
.74759 .52623 Mdot
.65946 .59406 Mdot
.61984 .59892 Mdot
.39002 .40509 Mdot
.61733 .36564 Mdot
.37698 .55031 Mdot
.3498 .45088 Mdot
.27618 .57258 Mdot
.27619 .38341 Mdot
.193 .46182 Mdot
.6216 .43094 Mdot
.25383 .66379 Mdot
.58301 .43517 Mdot
.35403 .34305 Mdot
.38193 .39762 Mdot
.37299 .38195 Mdot
.35791 .58091 Mdot
.49903 .29644 Mdot
.369 .58153 Mdot
.78508 .30736 Mdot
.35311 .35329 Mdot
.55521 .58656 Mdot
.48335 .6547 Mdot
.51616 .44886 Mdot
.65993 .61247 Mdot
.29898 .53138 Mdot
.66713 .40557 Mdot
.357 .26305 Mdot
.53451 .66906 Mdot
.38732 .37285 Mdot
.28644 .67637 Mdot
.82291 .46642 Mdot
.39945 .46005 Mdot
.64848 .45768 Mdot
.76661 .53341 Mdot
.64885 .58903 Mdot
.19537 .42438 Mdot
.65226 .61554 Mdot
.33133 .55898 Mdot
.58893 .38359 Mdot
.57626 .38695 Mdot
.62373 .43244 Mdot
.54776 .41664 Mdot
.31947 .57587 Mdot
.52438 .42454 Mdot
.32591 .25382 Mdot
.50013 .69693 Mdot
.63251 .51757 Mdot
.65247 .61347 Mdot
.36229 .61032 Mdot
.50624 .68626 Mdot
.34989 .71276 Mdot
.74109 .47038 Mdot
.59475 .40537 Mdot
.61615 .43816 Mdot
.73161 .30173 Mdot
.62524 .41009 Mdot
.50799 .44438 Mdot
.5118 .69222 Mdot
.48807 .45943 Mdot
.64665 .62093 Mdot
.62258 .60644 Mdot
.34421 .54967 Mdot
.38204 .39981 Mdot
.63863 .6068 Mdot
.48465 .65142 Mdot
.51706 .40205 Mdot
.52374 .41376 Mdot
.34113 .35412 Mdot
.74253 .30403 Mdot
.64419 .56157 Mdot
.37525 .76059 Mdot
.39451 .37939 Mdot
.40846 .40673 Mdot
.57898 .45132 Mdot
.2123 .40694 Mdot
.32774 .41401 Mdot
.68115 .59919 Mdot
.35801 .6095 Mdot
.76517 .50887 Mdot
.34243 .59291 Mdot
.36162 .39599 Mdot
.57533 .37036 Mdot
.38993 .39039 Mdot
.59843 .40602 Mdot
.84142 .47919 Mdot
.57262 .39103 Mdot
.45134 .18099 Mdot
.68074 .51474 Mdot
.48492 .67371 Mdot
.3367 .71307 Mdot
.47946 .66035 Mdot
.39181 .3699 Mdot
.54925 .37255 Mdot
.67258 .59861 Mdot
.48232 .79435 Mdot
.33587 .43454 Mdot
.52174 .63785 Mdot
.54119 .65425 Mdot
.34322 .59575 Mdot
.63051 .41408 Mdot
.5734 .44993 Mdot
.50191 .67657 Mdot
.31236 .32156 Mdot
.35123 .4012 Mdot
.59623 .39029 Mdot
.57567 .43714 Mdot
.48346 .66997 Mdot
.41837 .82355 Mdot
.61965 .32366 Mdot
.58627 .38807 Mdot
.49074 .75312 Mdot
.38189 .58248 Mdot
.52436 .45685 Mdot
.55983 .35752 Mdot
.64042 .58785 Mdot
.47887 .22459 Mdot
.77695 .39212 Mdot
.38305 .59595 Mdot
.5001 .69314 Mdot
.60252 .39852 Mdot
.48625 .6852 Mdot
.52325 .41871 Mdot
.21714 .49056 Mdot
.4661 .64931 Mdot
.61147 .37635 Mdot
.60099 .47851 Mdot
.38204 .35735 Mdot
.61946 .43371 Mdot
.48345 .35468 Mdot
.5289 .655 Mdot
.57639 .36602 Mdot
.60745 .26102 Mdot
.34848 .58858 Mdot
.60541 .48138 Mdot
.64362 .56915 Mdot
.70384 .35684 Mdot
.2652 .48966 Mdot
.72498 .65877 Mdot
.62168 .60717 Mdot
.55587 .44688 Mdot
.53985 .65831 Mdot
.36456 .53481 Mdot
.41574 .18988 Mdot
.59942 .4591 Mdot
.33119 .56351 Mdot
.36396 .55259 Mdot
.66406 .59444 Mdot
.15127 .56548 Mdot
.53768 .39825 Mdot
.5546 .41413 Mdot
.45373 .32288 Mdot
.34434 .41456 Mdot
.56437 .39663 Mdot
.55164 .38914 Mdot
.37296 .56772 Mdot
.58132 .49564 Mdot
.58566 .29575 Mdot
.5856 .2253 Mdot
.34096 .52362 Mdot
.30413 .43061 Mdot
.46655 .66236 Mdot
.62679 .60289 Mdot
.35155 .36347 Mdot
.67198 .58582 Mdot
.48503 .64115 Mdot
.55424 .38867 Mdot
.32581 .55599 Mdot
.46307 .36038 Mdot
.36919 .54396 Mdot
.70937 .6521 Mdot
.32471 .37023 Mdot
.38262 .50462 Mdot
.12331 .49414 Mdot
.42129 .74859 Mdot
.41167 .60936 Mdot
.64491 .5905 Mdot
.4394 .66869 Mdot
.57725 .43681 Mdot
.1897 .43374 Mdot
.54174 .40395 Mdot
.59523 .25197 Mdot
.50729 .69749 Mdot
.51461 .6997 Mdot
.58877 .38589 Mdot
.70503 .32674 Mdot
.36187 .53263 Mdot
.3761 .59339 Mdot
.60464 .36976 Mdot
.34861 .57203 Mdot
.56249 .41211 Mdot
.51391 .68522 Mdot
.21219 .35322 Mdot
.57821 .42166 Mdot
.60614 .34976 Mdot
.22446 .49155 Mdot
.4962 .82052 Mdot
.62076 .64109 Mdot
.30421 .76629 Mdot
.81862 .43645 Mdot
.35053 .57243 Mdot
.62194 .37734 Mdot
.29812 .42389 Mdot
.51978 .70393 Mdot
.29179 .58464 Mdot
.55675 .39269 Mdot
.54664 .39945 Mdot
.56704 .4595 Mdot
.59748 .44336 Mdot
.17156 .52623 Mdot
.33459 .43685 Mdot
.48765 .254 Mdot
.62158 .42452 Mdot
.74258 .44893 Mdot
.33568 .55181 Mdot
.41871 .41042 Mdot
.67227 .61686 Mdot
.62092 .43223 Mdot
.37805 .33902 Mdot
.32307 .54769 Mdot
.77913 .29337 Mdot
.32863 .56087 Mdot
.51618 .65613 Mdot
.34929 .53279 Mdot
.59335 .42879 Mdot
.35305 .37465 Mdot
.41961 .50836 Mdot
.41366 .71789 Mdot
.51629 .69132 Mdot
.59199 .41866 Mdot
.54202 .59156 Mdot
.53017 .6767 Mdot
.53959 .80574 Mdot
.35555 .36868 Mdot
.70697 .4451 Mdot
.38766 .39414 Mdot
.59463 .36743 Mdot
.59209 .36785 Mdot
.32235 .53485 Mdot
.34591 .5349 Mdot
.38639 .39562 Mdot
.15513 .60375 Mdot
.64293 .56318 Mdot
.37269 .38516 Mdot
.64709 .39617 Mdot
.43723 .47708 Mdot
.35795 .3758 Mdot
.60906 .564 Mdot
.36901 .55823 Mdot
.38102 .41672 Mdot
.58159 .46525 Mdot
.77771 .46535 Mdot
.62031 .58209 Mdot
.46614 .68351 Mdot
.74105 .57652 Mdot
.52895 .64637 Mdot
.34992 .60574 Mdot
.47926 .66247 Mdot
.37781 .56362 Mdot
.25782 .51487 Mdot
.34272 .32681 Mdot
.42892 .59293 Mdot
.32961 .58893 Mdot
.48158 .66126 Mdot
.59379 .38275 Mdot
.65026 .64487 Mdot
.5932 .36021 Mdot
.53443 .43352 Mdot
.37819 .58026 Mdot
.37533 .35653 Mdot
.32934 .41309 Mdot
.74125 .40391 Mdot
.37681 .40477 Mdot
.52438 .6521 Mdot
.36125 .24947 Mdot
.39748 .64899 Mdot
.34863 .59496 Mdot
.3359 .53848 Mdot
.6169 .39349 Mdot
.49701 .66892 Mdot
.51626 .69389 Mdot
.3387 .59081 Mdot
.23312 .40767 Mdot
.58615 .35214 Mdot
.31278 .38397 Mdot
.35206 .4177 Mdot
.36221 .3877 Mdot
.33318 .35272 Mdot
.61031 .31203 Mdot
.35227 .54317 Mdot
.38197 .36042 Mdot
.61853 .39473 Mdot
.55089 .39599 Mdot
.33776 .45213 Mdot
.6228 .58647 Mdot
.63533 .42426 Mdot
.54972 .46959 Mdot
.59658 .45479 Mdot
.48392 .63655 Mdot
.51174 .3597 Mdot
.47567 .63767 Mdot
.53564 .67866 Mdot
.53146 .68866 Mdot
.35069 .65047 Mdot
.72844 .31681 Mdot
.80722 .50159 Mdot
.56182 .37177 Mdot
.2828 .69754 Mdot
.49791 .65826 Mdot
.32756 .26765 Mdot
.26564 .55788 Mdot
.58051 .45823 Mdot
.52989 .75129 Mdot
.49733 .67637 Mdot
.39734 .39144 Mdot
.56293 .39112 Mdot
.48756 .62039 Mdot
.63859 .56907 Mdot
.58469 .36334 Mdot
.46275 .65461 Mdot
.34288 .38615 Mdot
.68224 .59025 Mdot
.3748 .42165 Mdot
.53103 .68994 Mdot
.62756 .46973 Mdot
.32684 .19894 Mdot
.52518 .61346 Mdot
.36273 .77529 Mdot
.61569 .50462 Mdot
.596 .38706 Mdot
.48802 .62407 Mdot
.39625 .41899 Mdot
.35294 .60641 Mdot
.53349 .54356 Mdot
.3666 .41554 Mdot
.51457 .69978 Mdot
.51897 .63111 Mdot
.51595 .6917 Mdot
.34212 .40824 Mdot
.63983 .42233 Mdot
.35713 .41075 Mdot
.3529 .53282 Mdot
.61289 .42052 Mdot
.80228 .56586 Mdot
.2671 .65808 Mdot
.39502 .38407 Mdot
.515 .64124 Mdot
.62 .61101 Mdot
.58295 .42994 Mdot
.26822 .66845 Mdot
.59758 .38338 Mdot
.38014 .57422 Mdot
.43708 .23972 Mdot
.44712 .38736 Mdot
.61874 .37827 Mdot
.61714 .39775 Mdot
.37479 .59348 Mdot
.58772 .41859 Mdot
.62978 .41116 Mdot
.35036 .65335 Mdot
.34364 .40465 Mdot
.57108 .42626 Mdot
.499 .64298 Mdot
.39622 .6707 Mdot
.59391 .35054 Mdot
.42907 .64077 Mdot
.70332 .44185 Mdot
.42827 .25156 Mdot
.54254 .40226 Mdot
.44978 .42584 Mdot
.58796 .44743 Mdot
.54644 .43001 Mdot
.61341 .39548 Mdot
.18943 .58938 Mdot
.46368 .65494 Mdot
.49319 .68667 Mdot
.61851 .59304 Mdot
.70328 .44371 Mdot
.63471 .58851 Mdot
.36803 .55402 Mdot
.63286 .68815 Mdot
.47391 .63933 Mdot
.35434 .39484 Mdot
.55336 .44079 Mdot
.52564 .61415 Mdot
.59139 .45556 Mdot
.59484 .42714 Mdot
.53294 .63913 Mdot
.46454 .66391 Mdot
.69716 .68484 Mdot
.62524 .57913 Mdot
.37481 .37792 Mdot
.63305 .40615 Mdot
.6615 .57271 Mdot
.54116 .39835 Mdot
.71788 .51156 Mdot
.37128 .37907 Mdot
.34743 .40657 Mdot
.32681 .41142 Mdot
.5579 .38654 Mdot
.58883 .42854 Mdot
.36967 .58213 Mdot
.39707 .37566 Mdot
.34461 .58604 Mdot
.52373 .55526 Mdot
.5657 .76658 Mdot
.55637 .39282 Mdot
.32371 .50084 Mdot
.63091 .58272 Mdot
.51826 .63571 Mdot
.65902 .23049 Mdot
.61838 .59238 Mdot
.59854 .40291 Mdot
.53689 .66703 Mdot
.65151 .58032 Mdot
.69417 .40438 Mdot
.76948 .30598 Mdot
.63046 .61979 Mdot
.61875 .39546 Mdot
.59559 .49234 Mdot
.29077 .75395 Mdot
.62757 .61515 Mdot
.33995 .54066 Mdot
.55963 .38575 Mdot
.30925 .35631 Mdot
.67172 .5832 Mdot
.48231 .76758 Mdot
.50044 .68206 Mdot
.77641 .44584 Mdot
.65128 .36947 Mdot
.3034 .31919 Mdot
.62223 .60073 Mdot
.34153 .36991 Mdot
.50362 .44112 Mdot
.58193 .45077 Mdot
.62203 .6094 Mdot
.34713 .61402 Mdot
.51384 .6769 Mdot
.39839 .69028 Mdot
.34301 .40938 Mdot
.33669 .61025 Mdot
.50924 .63553 Mdot
.38589 .76624 Mdot
.51185 .20055 Mdot
.55588 .4807 Mdot
.2685 .71814 Mdot
.2787 .60884 Mdot
.60932 .46267 Mdot
.64956 .63098 Mdot
.38699 .57687 Mdot
.32278 .56125 Mdot
.34697 .56549 Mdot
.25291 .53455 Mdot
.41085 .44956 Mdot
.46211 .64801 Mdot
.30765 .53495 Mdot
.6265 .60109 Mdot
.76353 .49437 Mdot
.53131 .43015 Mdot
.57718 .43192 Mdot
.62759 .39692 Mdot
.6199 .43767 Mdot
.5759 .44497 Mdot
.34215 .57587 Mdot
.24824 .51343 Mdot
.38144 .46456 Mdot
.36442 .37814 Mdot
.6782 .6787 Mdot
.48826 .65258 Mdot
.45466 .66953 Mdot
.64809 .57455 Mdot
.44187 .76165 Mdot
.55222 .65072 Mdot
.50908 .65327 Mdot
.62338 .45326 Mdot
.35524 .40572 Mdot
.51072 .4435 Mdot
.6179 .39663 Mdot
.5231 .65767 Mdot
.46793 .5612 Mdot
.55136 .31143 Mdot
.68965 .57029 Mdot
.68739 .59524 Mdot
.42548 .45712 Mdot
.61613 .59453 Mdot
.53513 .38272 Mdot
.29081 .27832 Mdot
.48426 .6411 Mdot
.50929 .6661 Mdot
.62487 .58697 Mdot
.21262 .40091 Mdot
.35544 .36007 Mdot
.3532 .5 Mdot
.36819 .54704 Mdot
.58171 .36942 Mdot
.56068 .19851 Mdot
.59711 .51625 Mdot
.61018 .68381 Mdot
.34099 .56222 Mdot
.47695 .67334 Mdot
.5407 .36998 Mdot
.61952 .40785 Mdot
.63487 .57944 Mdot
.71453 .695 Mdot
.52169 .44999 Mdot
.62991 .809 Mdot
.70202 .26284 Mdot
.7627 .38464 Mdot
.57654 .45066 Mdot
.34442 .40668 Mdot
.47301 .68784 Mdot
.63868 .61304 Mdot
.6477 .40739 Mdot
.78952 .38671 Mdot
.34198 .35549 Mdot
.34672 .55446 Mdot
.45487 .52989 Mdot
.76007 .51791 Mdot
.53922 .43297 Mdot
.54892 .39509 Mdot
.54274 .42828 Mdot
.69285 .20196 Mdot
.47755 .63858 Mdot
.39558 .38907 Mdot
.66367 .59182 Mdot
.36966 .40389 Mdot
.48289 .67596 Mdot
.43992 .58976 Mdot
.58783 .37826 Mdot
.3351 .35889 Mdot
.34244 .3685 Mdot
.32704 .56977 Mdot
.37558 .60741 Mdot
.48027 .5421 Mdot
.57229 .39238 Mdot
.53758 .63116 Mdot
.38229 .35908 Mdot
.44316 .44349 Mdot
.64209 .59645 Mdot
.37078 .56012 Mdot
.62011 .42974 Mdot
.47166 .64612 Mdot
.56875 .4735 Mdot
.37145 .36794 Mdot
.50846 .65384 Mdot
.62287 .76186 Mdot
.6375 .61932 Mdot
.55117 .40227 Mdot
.60286 .6008 Mdot
.50428 .69328 Mdot
.5791 .43884 Mdot
.40798 .78506 Mdot
.60948 .56382 Mdot
.44496 .73799 Mdot
.52963 .68595 Mdot
.3716 .63919 Mdot
.38642 .40819 Mdot
.24104 .57027 Mdot
.5135 .66267 Mdot
.34892 .74334 Mdot
.66199 .73808 Mdot
.5202 .39097 Mdot
.37121 .39512 Mdot
.28168 .6167 Mdot
.8299 .56155 Mdot
.36085 .78621 Mdot
.58617 .40756 Mdot
.51734 .62186 Mdot
.6436 .57814 Mdot
.35489 .59675 Mdot
.46177 .72896 Mdot
.66683 .56025 Mdot
.53993 .68466 Mdot
.61296 .39563 Mdot
.3413 .37757 Mdot
.36769 .5712 Mdot
.26631 .49506 Mdot
.48921 .64797 Mdot
.5081 .64005 Mdot
.5612 .36324 Mdot
.62971 .59134 Mdot
.2507 .6197 Mdot
.51441 .68765 Mdot
.71599 .28396 Mdot
.45075 .64779 Mdot
.65355 .56748 Mdot
.59896 .44728 Mdot
.74482 .39575 Mdot
.62277 .36995 Mdot
.44077 .80438 Mdot
.48589 .65609 Mdot
.37147 .37275 Mdot
.55184 .4491 Mdot
.63212 .25974 Mdot
.52371 .65021 Mdot
.44245 .45721 Mdot
.58531 .65527 Mdot
.36074 .54569 Mdot
.65449 .22807 Mdot
.55957 .4028 Mdot
.3642 .53472 Mdot
.63616 .58018 Mdot
.58113 .39038 Mdot
.59029 .43104 Mdot
.36902 .34823 Mdot
.32893 .57483 Mdot
.69244 .6952 Mdot
.33495 .53662 Mdot
.33332 .54994 Mdot
.32542 .35123 Mdot
.56206 .42419 Mdot
.51657 .65393 Mdot
.49835 .67536 Mdot
.58457 .46741 Mdot
.1939 .35747 Mdot
.35004 .35892 Mdot
.48257 .69551 Mdot
.67169 .18417 Mdot
.60205 .47043 Mdot
.64056 .22575 Mdot
.70667 .70139 Mdot
.38022 .55768 Mdot
.61937 .39539 Mdot
.34483 .38639 Mdot
.53981 .72326 Mdot
.51122 .64159 Mdot
.56731 .46197 Mdot
.36622 .57072 Mdot
.62825 .57385 Mdot
.52923 .66821 Mdot
.61966 .68081 Mdot
.54485 .41811 Mdot
.53832 .74978 Mdot
.51981 .62559 Mdot
.80554 .64174 Mdot
.33935 .7008 Mdot
.3738 .39354 Mdot
.59756 .42818 Mdot
.39992 .3858 Mdot
.66296 .58717 Mdot
.45793 .53145 Mdot
.36772 .56134 Mdot
.51673 .34228 Mdot
.31549 .24961 Mdot
.51557 .69211 Mdot
.3974 .38641 Mdot
.61383 .37134 Mdot
.2142 .48267 Mdot
.55917 .40876 Mdot
.61915 .48447 Mdot
.70751 .6267 Mdot
.37003 .59245 Mdot
.37496 .55178 Mdot
.59152 .44041 Mdot
.6666 .58353 Mdot
.48642 .65134 Mdot
.5185 .66844 Mdot
.74732 .73956 Mdot
.37823 .49742 Mdot
.67552 .28783 Mdot
.54642 .401 Mdot
.54109 .67878 Mdot
.42159 .67441 Mdot
.33126 .56923 Mdot
.62679 .45997 Mdot
.53541 .64783 Mdot
.5978 .57473 Mdot
.70155 .39302 Mdot
.58381 .44904 Mdot
.63074 .37328 Mdot
.36176 .54127 Mdot
.43662 .42758 Mdot
.47945 .6816 Mdot
.55153 .46585 Mdot
.42967 .57197 Mdot
.69446 .41398 Mdot
.72796 .26747 Mdot
.37504 .37818 Mdot
.61596 .66676 Mdot
.3425 .57685 Mdot
.60819 .34935 Mdot
.66434 .60518 Mdot
.52524 .70367 Mdot
.46837 .64871 Mdot
.60669 .40094 Mdot
.52714 .38849 Mdot
.68549 .26666 Mdot
.35765 .40113 Mdot
.33915 .54994 Mdot
.57428 .3832 Mdot
.32906 .48057 Mdot
.62481 .42895 Mdot
.3655 .58731 Mdot
.30603 .21309 Mdot
.60277 .36226 Mdot
.55676 .41272 Mdot
.25765 .62714 Mdot
.36143 .41715 Mdot
.39656 .36814 Mdot
.57904 .19197 Mdot
.54672 .40101 Mdot
.68628 .25388 Mdot
.37842 .37477 Mdot
.36221 .36041 Mdot
.36109 .6681 Mdot
.58023 .42924 Mdot
.60593 .32956 Mdot
.37966 .56432 Mdot
.33345 .54785 Mdot
.35306 .41174 Mdot
.52283 .45408 Mdot
.37677 .60365 Mdot
.20423 .58253 Mdot
.49557 .66776 Mdot
.26425 .29355 Mdot
.34852 .35746 Mdot
.40011 .5654 Mdot
.33406 .56397 Mdot
.79044 .32621 Mdot
.53573 .71422 Mdot
.59013 .38093 Mdot
.54602 .40636 Mdot
.6249 .59171 Mdot
.62741 .39178 Mdot
.51447 .69953 Mdot
.34778 .57175 Mdot
.65846 .30615 Mdot
.37346 .38243 Mdot
.56915 .40008 Mdot
.47895 .7845 Mdot
.57431 .79963 Mdot
.62727 .65817 Mdot
.339 .36365 Mdot
.38385 .39188 Mdot
.47352 .65776 Mdot
.51996 .62308 Mdot
.56335 .43697 Mdot
.3706 .59915 Mdot
.39722 .37734 Mdot
.3704 .58757 Mdot
.48639 .63977 Mdot
.51421 .6537 Mdot
.46201 .66757 Mdot
.52853 .42597 Mdot
.5067 .64715 Mdot
.58735 .76851 Mdot
.30968 .5743 Mdot
.31731 .35577 Mdot
.64684 .20223 Mdot
.27031 .49817 Mdot
.35039 .43289 Mdot
.66741 .57509 Mdot
.51171 .69354 Mdot
.35286 .53099 Mdot
.60971 .43199 Mdot
.61149 .44894 Mdot
.39398 .63634 Mdot
.3462 .52672 Mdot
.66227 .58941 Mdot
.36774 .53967 Mdot
.66434 .59386 Mdot
.56171 .72052 Mdot
.63025 .42237 Mdot
.52185 .41777 Mdot
.34053 .57097 Mdot
.50738 .65012 Mdot
.49718 .68517 Mdot
.63682 .62249 Mdot
.48368 .57373 Mdot
.53154 .67432 Mdot
.36513 .35866 Mdot
.58309 .3087 Mdot
.51278 .62657 Mdot
.5635 .39274 Mdot
.73215 .53238 Mdot
.18509 .43898 Mdot
.6171 .35958 Mdot
.35587 .66186 Mdot
.44251 .34854 Mdot
.56495 .45424 Mdot
.18594 .42931 Mdot
.35326 .63129 Mdot
.37887 .4103 Mdot
.49948 .69588 Mdot
.53001 .60516 Mdot
.54077 .34696 Mdot
.68445 .59905 Mdot
.64041 .44318 Mdot
.33428 .36267 Mdot
.3988 .36166 Mdot
.75938 .41818 Mdot
.39098 .7937 Mdot
.64838 .58025 Mdot
.64358 .57492 Mdot
.51536 .66271 Mdot
.54304 .85277 Mdot
.63949 .46592 Mdot
.66108 .59112 Mdot
.30426 .33225 Mdot
.61135 .39783 Mdot
.6804 .47219 Mdot
.5432 .51968 Mdot
.34861 .41075 Mdot
.74399 .44019 Mdot
.52066 .64991 Mdot
.37756 .40552 Mdot
.31431 .46708 Mdot
.63896 .41663 Mdot
.37096 .38023 Mdot
.37111 .58457 Mdot
.36755 .71929 Mdot
.3687 .35682 Mdot
.72727 .52056 Mdot
.35505 .60169 Mdot
.44052 .44552 Mdot
.73169 .40544 Mdot
.28011 .80283 Mdot
.34543 .575 Mdot
.5183 .63133 Mdot
.49953 .67602 Mdot
.51856 .66724 Mdot
.3666 .40435 Mdot
.5137 .6942 Mdot
.3588 .40013 Mdot
.29474 .73917 Mdot
.19451 .45228 Mdot
.65964 .59262 Mdot
.39862 .69291 Mdot
.35023 .3854 Mdot
.32313 .26439 Mdot
.15677 .38414 Mdot
.61913 .39266 Mdot
.32105 .55275 Mdot
.65742 .59078 Mdot
.61208 .81347 Mdot
.64333 .58637 Mdot
.75281 .35248 Mdot
.38557 .25718 Mdot
.5679 .40781 Mdot
.53962 .28865 Mdot
.66122 .61761 Mdot
.33022 .37541 Mdot
.58004 .43789 Mdot
.5682 .5625 Mdot
.63911 .58349 Mdot
.64489 .5663 Mdot
.56639 .4325 Mdot
.38745 .3728 Mdot
.51806 .64135 Mdot
.33205 .54344 Mdot
.67577 .59504 Mdot
.56507 .49707 Mdot
.63252 .38197 Mdot
.59667 .38004 Mdot
.35646 .466 Mdot
.63602 .62918 Mdot
.3514 .57294 Mdot
.16811 .58176 Mdot
.53802 .6456 Mdot
.57372 .57979 Mdot
.71902 .27558 Mdot
.33127 .63517 Mdot
.48677 .65743 Mdot
.48518 .68335 Mdot
.57404 .44535 Mdot
.53975 .50519 Mdot
.36399 .26657 Mdot
.48352 .58485 Mdot
.46089 .67503 Mdot
.5167 .67312 Mdot
.40377 .3819 Mdot
.75905 .38913 Mdot
.64733 .3901 Mdot
.38383 .59492 Mdot
.46597 .65351 Mdot
.20187 .50788 Mdot
.62785 .59595 Mdot
.39022 .247 Mdot
.63074 .42462 Mdot
.5856 .38081 Mdot
.36228 .56399 Mdot
.36918 .58014 Mdot
.56127 .69394 Mdot
.75796 .37495 Mdot
.44556 .35665 Mdot
.24626 .49408 Mdot
.42834 .26151 Mdot
.40086 .36913 Mdot
.39502 .3837 Mdot
.42412 .73319 Mdot
.32895 .54142 Mdot
.55983 .45316 Mdot
.38405 .39854 Mdot
.57273 .60083 Mdot
.54473 .32505 Mdot
.70921 .35506 Mdot
.65699 .24236 Mdot
.59689 .40915 Mdot
.3424 .3989 Mdot
.35871 .41723 Mdot
.32628 .3984 Mdot
.37924 .63237 Mdot
.5572 .42987 Mdot
.592 .40877 Mdot
.56617 .45118 Mdot
.21162 .44043 Mdot
.55155 .43175 Mdot
.24041 .55977 Mdot
.46228 .52315 Mdot
.49668 .21809 Mdot
.55023 .46608 Mdot
.37769 .54623 Mdot
.53597 .41907 Mdot
.66635 .58426 Mdot
.6121 .38308 Mdot
.70756 .3528 Mdot
.33689 .5572 Mdot
.60824 .31802 Mdot
.2625 .5119 Mdot
.58469 .4624 Mdot
.6805 .59604 Mdot
.27355 .58374 Mdot
.81755 .5462 Mdot
.6465 .64247 Mdot
.36242 .35803 Mdot
.49229 .66315 Mdot
.35236 .53007 Mdot
.5112 .65894 Mdot
.52515 .43554 Mdot
.41838 .73694 Mdot
.63065 .79162 Mdot
.5281 .56476 Mdot
.61875 .43838 Mdot
.65457 .40141 Mdot
.36953 .36251 Mdot
.53781 .65009 Mdot
.33228 .42174 Mdot
.54598 .44067 Mdot
.65618 .60258 Mdot
.63452 .58217 Mdot
.53592 .54769 Mdot
.75281 .68549 Mdot
.19926 .54744 Mdot
.36119 .56758 Mdot
.51727 .68374 Mdot
.65816 .61435 Mdot
.32229 .72693 Mdot
.38562 .60493 Mdot
.37923 .58524 Mdot
.33857 .554 Mdot
.55847 .38003 Mdot
.46425 .65255 Mdot
.50287 .21758 Mdot
.5302 .69424 Mdot
.58924 .42043 Mdot
.48451 .63513 Mdot
.53587 .65781 Mdot
.64704 .61356 Mdot
.33707 .55245 Mdot
.48316 .64424 Mdot
.58848 .3668 Mdot
.3833 .37643 Mdot
.41566 .59959 Mdot
.66673 .51557 Mdot
.40288 .79648 Mdot
.66579 .45878 Mdot
.33644 .40644 Mdot
.82001 .57067 Mdot
.38261 .57721 Mdot
.22744 .41705 Mdot
.69876 .68113 Mdot
.54974 .37373 Mdot
.20183 .33932 Mdot
.45439 .67411 Mdot
.53418 .65098 Mdot
.59701 .4471 Mdot
.45149 .63689 Mdot
.56595 .4038 Mdot
.49904 .63412 Mdot
.42934 .66297 Mdot
.36336 .33629 Mdot
.50251 .65017 Mdot
.54771 .46164 Mdot
.58944 .43529 Mdot
.34818 .40858 Mdot
.50126 .62052 Mdot
.64886 .40688 Mdot
.76958 .7224 Mdot
.36395 .5844 Mdot
.29285 .61579 Mdot
.72892 .54736 Mdot
.34267 .57847 Mdot
.37076 .38652 Mdot
.53279 .43043 Mdot
.63729 .57925 Mdot
.34911 .38587 Mdot
.69414 .33976 Mdot
.63638 .61703 Mdot
.25752 .28904 Mdot
.3516 .41515 Mdot
.52516 .64048 Mdot
.66902 .59576 Mdot
.62711 .38588 Mdot
.52002 .70493 Mdot
.34627 .71873 Mdot
.48874 .65611 Mdot
.56994 .4483 Mdot
.43104 .7117 Mdot
.33886 .54877 Mdot
.58569 .40417 Mdot
.53296 .65389 Mdot
.3605 .66146 Mdot
.55658 .37753 Mdot
.58824 .44391 Mdot
.7315 .28393 Mdot
.4035 .21656 Mdot
.64291 .59209 Mdot
.36768 .42446 Mdot
.61842 .39375 Mdot
.64739 .5685 Mdot
.60207 .74002 Mdot
.56875 .37884 Mdot
.34243 .35462 Mdot
.62271 .46601 Mdot
.50753 .62098 Mdot
.34895 .58638 Mdot
.52099 .5796 Mdot
.63915 .56896 Mdot
.33879 .81565 Mdot
.46855 .66206 Mdot
.52539 .40549 Mdot
.62525 .42356 Mdot
.74213 .60403 Mdot
.37702 .4099 Mdot
.35026 .30219 Mdot
.55077 .4025 Mdot
.21638 .42697 Mdot
.58036 .39362 Mdot
.45788 .68344 Mdot
.35667 .35977 Mdot
.55349 .41763 Mdot
.40501 .53786 Mdot
.59999 .34889 Mdot
.62041 .58727 Mdot
.26206 .64793 Mdot
.6415 .41255 Mdot
.27556 .25149 Mdot
.58534 .54919 Mdot
.50182 .64831 Mdot
.53128 .78904 Mdot
.75502 .7502 Mdot
.25617 .53286 Mdot
.36911 .4024 Mdot
.68725 .73344 Mdot
.51639 .65339 Mdot
.51433 .77489 Mdot
.82604 .56087 Mdot
.59702 .43512 Mdot
.53996 .43479 Mdot
.76648 .54639 Mdot
.53402 .68483 Mdot
.54258 .64506 Mdot
.51767 .41057 Mdot
.61485 .35325 Mdot
.51188 .64794 Mdot
.56398 .36739 Mdot
.5219 .44526 Mdot
.32125 .55443 Mdot
.34344 .35641 Mdot
.3693 .59419 Mdot
.37479 .60293 Mdot
.2256 .6281 Mdot
.59206 .55047 Mdot
.36197 .58788 Mdot
.38468 .56981 Mdot
.68327 .46613 Mdot
.72071 .33954 Mdot
.67267 .58704 Mdot
.76908 .68889 Mdot
.51418 .67425 Mdot
.558 .42393 Mdot
.35277 .41722 Mdot
.4492 .36904 Mdot
.62964 .73829 Mdot
.29858 .285 Mdot
.55269 .44835 Mdot
.52287 .64763 Mdot
.36932 .63274 Mdot
.51025 .44486 Mdot
.49633 .61497 Mdot
.56894 .38457 Mdot
.51404 .70087 Mdot
.62806 .29718 Mdot
.34897 .74264 Mdot
.49676 .60702 Mdot
.31232 .37875 Mdot
.5808 .38342 Mdot
.33272 .36458 Mdot
.33311 .57104 Mdot
.67107 .58784 Mdot
.63953 .59308 Mdot
.57394 .43693 Mdot
.65567 .44234 Mdot
.55777 .73645 Mdot
.584 .43098 Mdot
.61284 .40168 Mdot
.35627 .63216 Mdot
.61487 .39775 Mdot
.61843 .44654 Mdot
.58496 .45616 Mdot
.55239 .45522 Mdot
.33376 .54869 Mdot
.44709 .7636 Mdot
.53794 .3526 Mdot
.55844 .3456 Mdot
.35158 .60504 Mdot
.70572 .69384 Mdot
.3807 .59565 Mdot
.82483 .54031 Mdot
.37704 .55309 Mdot
.64675 .59936 Mdot
.71695 .63995 Mdot
.65676 .37466 Mdot
.36236 .34955 Mdot
.39443 .59066 Mdot
.66336 .58508 Mdot
.34734 .56822 Mdot
.50441 .63164 Mdot
.73798 .28167 Mdot
.41315 .37195 Mdot
.33587 .44245 Mdot
.28249 .57982 Mdot
.40475 .75077 Mdot
.47222 .65536 Mdot
.32721 .37418 Mdot
.55348 .30447 Mdot
.62056 .43872 Mdot
.64921 .5687 Mdot
.56571 .43734 Mdot
.32698 .56126 Mdot
.52071 .65487 Mdot
.33364 .76539 Mdot
.63437 .57976 Mdot
.67734 .22215 Mdot
.49566 .68188 Mdot
.61026 .45615 Mdot
.37765 .60259 Mdot
.57673 .17126 Mdot
.37279 .5906 Mdot
.37029 .29096 Mdot
.3944 .39858 Mdot
.32383 .78207 Mdot
.35884 .39207 Mdot
.35621 .73227 Mdot
.52023 .13037 Mdot
.46487 .77849 Mdot
.38676 .37534 Mdot
.44215 .59632 Mdot
.60113 .40173 Mdot
.59546 .37948 Mdot
.33899 .7481 Mdot
.35755 .42164 Mdot
.62276 .41541 Mdot
.41131 .64819 Mdot
.33874 .6133 Mdot
.61019 .21724 Mdot
.47658 .66467 Mdot
.56312 .40101 Mdot
.34365 .51947 Mdot
.35096 .52584 Mdot
.48231 .6875 Mdot
.38053 .58383 Mdot
.59042 .41065 Mdot
.3515 .38648 Mdot
.43709 .67804 Mdot
.63917 .60322 Mdot
.56498 .83534 Mdot
.62739 .56735 Mdot
.48633 .65796 Mdot
.59395 .36002 Mdot
.51353 .65384 Mdot
.84 .67807 Mdot
.59392 .40108 Mdot
.37722 .37389 Mdot
.61746 .40566 Mdot
.58476 .38516 Mdot
.55286 .45321 Mdot
.51354 .6396 Mdot
.70194 .59216 Mdot
.5787 .36661 Mdot
.36765 .55912 Mdot
.45908 .24379 Mdot
.6344 .43395 Mdot
.5074 .59906 Mdot
.72157 .36792 Mdot
.29569 .56134 Mdot
.38506 .41406 Mdot
.49717 .65129 Mdot
.37753 .38335 Mdot
.22779 .38204 Mdot
.37039 .38633 Mdot
.43641 .28676 Mdot
.57267 .29715 Mdot
.64264 .27656 Mdot
.62218 .27168 Mdot
.43434 .53369 Mdot
.36367 .42353 Mdot
.66124 .63508 Mdot
.3933 .37316 Mdot
.3606 .4145 Mdot
.23748 .23121 Mdot
.34492 .34729 Mdot
.5578 .39505 Mdot
.62962 .44157 Mdot
.40092 .76399 Mdot
.70941 .49118 Mdot
.61428 .4202 Mdot
.6179 .42265 Mdot
.66244 .61031 Mdot
.22763 .39312 Mdot
.4475 .74384 Mdot
.38664 .22484 Mdot
.58875 .79067 Mdot
.56649 .4353 Mdot
.61725 .38765 Mdot
.51598 .38386 Mdot
.44934 .16554 Mdot
.22911 .64667 Mdot
.31006 .34563 Mdot
.52869 .37164 Mdot
.4593 .7879 Mdot
.5468 .44586 Mdot
.55087 .38996 Mdot
.5983 .40632 Mdot
.51688 .6532 Mdot
.37901 .41925 Mdot
.55158 .45754 Mdot
.73132 .61161 Mdot
.55517 .38944 Mdot
.33683 .64079 Mdot
.44011 .84204 Mdot
.55886 .40314 Mdot
.40993 .39518 Mdot
.59956 .38097 Mdot
.36754 .41105 Mdot
.33146 .39206 Mdot
.52318 .38207 Mdot
.42428 .26321 Mdot
.40588 .39221 Mdot
.58941 .42119 Mdot
.51176 .63097 Mdot
.80019 .6441 Mdot
.5672 .44699 Mdot
.67085 .58387 Mdot
.5468 .4045 Mdot
.67948 .58637 Mdot
.61213 .40852 Mdot
.46817 .66764 Mdot
.42614 .34828 Mdot
.51077 .66655 Mdot
.25669 .70345 Mdot
.46351 .66448 Mdot
.7097 .23842 Mdot
.32992 .40027 Mdot
.41273 .69706 Mdot
.26388 .32776 Mdot
.29684 .6309 Mdot
.47024 .46209 Mdot
.41941 .49087 Mdot
.37184 .59827 Mdot
.38767 .40235 Mdot
.25593 .3867 Mdot
.66667 .69827 Mdot
.67276 .66394 Mdot
.52904 .67535 Mdot
.15013 .57127 Mdot
.24454 .32049 Mdot
.53904 .37757 Mdot
.51054 .30489 Mdot
.4972 .2699 Mdot
.54659 .44666 Mdot
.54342 .44881 Mdot
.54683 .60708 Mdot
.57682 .36495 Mdot
.32923 .48304 Mdot
.48341 .66159 Mdot
.66176 .58157 Mdot
.37519 .36653 Mdot
.62821 .57355 Mdot
.68746 .68544 Mdot
.41306 .48615 Mdot
.49434 .63498 Mdot
.63983 .38605 Mdot
.61362 .42922 Mdot
.35697 .40917 Mdot
.31187 .40562 Mdot
.38682 .36201 Mdot
.65331 .58656 Mdot
.48445 .66774 Mdot
.17689 .47176 Mdot
.615 .43181 Mdot
.34433 .3682 Mdot
.48142 .47559 Mdot
.61898 .39697 Mdot
.33626 .57068 Mdot
.60012 .3969 Mdot
.38451 .37021 Mdot
.61489 .39809 Mdot
.36026 .39381 Mdot
.49434 .66462 Mdot
.5923 .46018 Mdot
.59324 .44959 Mdot
.62974 .19862 Mdot
.65869 .59741 Mdot
.32651 .36656 Mdot
.56652 .58926 Mdot
.62618 .40193 Mdot
.37502 .68587 Mdot
.56553 .38703 Mdot
.43317 .3923 Mdot
.53709 .38517 Mdot
.29802 .61913 Mdot
.5881 .33897 Mdot
.56098 .44151 Mdot
.54168 .53125 Mdot
.48476 .27704 Mdot
.64963 .35226 Mdot
.38521 .56374 Mdot
.32821 .35694 Mdot
.61811 .22513 Mdot
.45487 .69932 Mdot
.52607 .62237 Mdot
.75242 .47349 Mdot
.56896 .46272 Mdot
.56615 .40986 Mdot
.31072 .52268 Mdot
.63262 .57614 Mdot
.3363 .3656 Mdot
.6642 .59408 Mdot
.67413 .23497 Mdot
.62094 .60086 Mdot
.45582 .681 Mdot
.53821 .75089 Mdot
.17414 .51449 Mdot
.65994 .61207 Mdot
.38704 .3708 Mdot
.51843 .75711 Mdot
.60532 .46455 Mdot
.58002 .54512 Mdot
.65114 .60624 Mdot
.19864 .66958 Mdot
.61737 .44805 Mdot
.46892 .4569 Mdot
.35871 .59111 Mdot
.66384 .60672 Mdot
.34777 .59741 Mdot
.60574 .43502 Mdot
.45042 .74328 Mdot
.37006 .40152 Mdot
.33676 .59202 Mdot
.60062 .48223 Mdot
.6587 .58947 Mdot
.46638 .65073 Mdot
.33511 .51403 Mdot
.38573 .58742 Mdot
.72897 .6873 Mdot
.31909 .76442 Mdot
.48591 .67067 Mdot
.51424 .19814 Mdot
.37076 .54041 Mdot
.60918 .46342 Mdot
.23863 .38286 Mdot
.58875 .38025 Mdot
.22609 .57518 Mdot
.49052 .65121 Mdot
.41752 .75537 Mdot
.61737 .39257 Mdot
.55363 .44352 Mdot
.41124 .37409 Mdot
.50652 .67346 Mdot
.35486 .37668 Mdot
.32222 .36467 Mdot
.49424 .66631 Mdot
.3693 .39366 Mdot
.65468 .61976 Mdot
.29181 .43561 Mdot
.36842 .54634 Mdot
.35951 .54911 Mdot
.51857 .66915 Mdot
.49958 .64563 Mdot
.50956 .65434 Mdot
.60023 .3962 Mdot
.34368 .36107 Mdot
.60216 .42473 Mdot
.54231 .40085 Mdot
.45996 .23399 Mdot
.3712 .41986 Mdot
.59931 .41544 Mdot
.57514 .56894 Mdot
.5532 .5177 Mdot
.50659 .62853 Mdot
.3595 .589 Mdot
.41055 .66466 Mdot
.3304 .70485 Mdot
.56523 .39795 Mdot
.6081 .55359 Mdot
.38922 .37111 Mdot
.64068 .58044 Mdot
.61536 .57993 Mdot
.64377 .58854 Mdot
.30683 .60315 Mdot
.32976 .40197 Mdot
.38147 .23106 Mdot
.5635 .40453 Mdot
.37153 .47121 Mdot
.31817 .33063 Mdot
.55937 .71471 Mdot
.35966 .58724 Mdot
.61919 .40759 Mdot
.52404 .57706 Mdot
.51049 .33718 Mdot
.59196 .38333 Mdot
.62916 .44776 Mdot
.59839 .76968 Mdot
.63903 .45311 Mdot
.39446 .36074 Mdot
.58246 .17695 Mdot
.62183 .38225 Mdot
.19884 .50504 Mdot
.58558 .84002 Mdot
.56983 .39111 Mdot
.54585 .43548 Mdot
.60982 .44575 Mdot
.60975 .38115 Mdot
.40723 .3962 Mdot
.71847 .44863 Mdot
.37496 .54474 Mdot
.37234 .46874 Mdot
.32701 .55079 Mdot
.48494 .69511 Mdot
.42494 .75735 Mdot
.39268 .39851 Mdot
.6251 .59085 Mdot
.54986 .81162 Mdot
.4936 .17624 Mdot
.4809 .683 Mdot
.20519 .57755 Mdot
.65185 .60337 Mdot
.61584 .46091 Mdot
.67285 .61052 Mdot
.48101 .63365 Mdot
.3605 .54648 Mdot
.64039 .42669 Mdot
.39369 .37981 Mdot
.36335 .35556 Mdot
.62105 .40612 Mdot
.47558 .79443 Mdot
.33835 .57879 Mdot
.38808 .58383 Mdot
.56343 .37763 Mdot
.62813 .38846 Mdot
.35777 .3799 Mdot
.51102 .68574 Mdot
.65548 .27483 Mdot
.64579 .57275 Mdot
.53036 .42976 Mdot
.61294 .39349 Mdot
.72397 .28128 Mdot
.36968 .55895 Mdot
.50216 .6161 Mdot
.54673 .37643 Mdot
.23777 .49084 Mdot
.54971 .37459 Mdot
.51085 .39772 Mdot
.51231 .63041 Mdot
.51095 .37532 Mdot
.52118 .41118 Mdot
.41814 .36999 Mdot
.36197 .59953 Mdot
.37194 .37672 Mdot
.42669 .38368 Mdot
.2885 .40734 Mdot
.33717 .56785 Mdot
.60232 .40709 Mdot
.3568 .58338 Mdot
.57024 .37869 Mdot
.60765 .37125 Mdot
.36506 .58766 Mdot
.35495 .37777 Mdot
.67874 .73917 Mdot
.46146 .77243 Mdot
.60433 .37571 Mdot
.51898 .39555 Mdot
.70784 .46955 Mdot
.69842 .59861 Mdot
.54422 .43947 Mdot
.38111 .36552 Mdot
.60734 .44035 Mdot
.33224 .57913 Mdot
.66067 .61723 Mdot
.3842 .37528 Mdot
.49473 .68648 Mdot
.47287 .67275 Mdot
.26168 .5174 Mdot
.53362 .67496 Mdot
.53668 .4301 Mdot
.38472 .43004 Mdot
.41546 .39876 Mdot
.51625 .82575 Mdot
.49534 .66982 Mdot
.67291 .58482 Mdot
.58538 .44299 Mdot
.77808 .46575 Mdot
.33813 .52077 Mdot
.19063 .31813 Mdot
.32146 .26305 Mdot
.66015 .625 Mdot
.31567 .28207 Mdot
.46622 .67166 Mdot
.52197 .42744 Mdot
.66774 .58013 Mdot
.47357 .65846 Mdot
.58437 .37192 Mdot
.52207 .38214 Mdot
.35916 .30094 Mdot
.39762 .50115 Mdot
.36023 .58265 Mdot
.52097 .69311 Mdot
.66742 .6244 Mdot
.45544 .66409 Mdot
.32631 .39036 Mdot
.55522 .43152 Mdot
.58202 .35982 Mdot
.50738 .68866 Mdot
.53155 .62445 Mdot
.59399 .41745 Mdot
.3996 .38746 Mdot
.54808 .60504 Mdot
.56896 .4308 Mdot
.38145 .49846 Mdot
.34619 .42047 Mdot
.4793 .666 Mdot
.55455 .44082 Mdot
.68929 .61143 Mdot
.50074 .68426 Mdot
.50348 .62792 Mdot
.61854 .38905 Mdot
.64962 .62021 Mdot
.53489 .37355 Mdot
.37707 .55755 Mdot
.17127 .60234 Mdot
.3307 .57727 Mdot
.43229 .65712 Mdot
.62884 .47054 Mdot
.23531 .45184 Mdot
.38212 .413 Mdot
.75126 .41829 Mdot
.41184 .65121 Mdot
.51924 .44295 Mdot
.79105 .6382 Mdot
.3999 .56104 Mdot
.5143 .813 Mdot
.79592 .52982 Mdot
.64831 .61093 Mdot
.3464 .56595 Mdot
.54534 .43511 Mdot
.32066 .55408 Mdot
.66379 .57521 Mdot
.25754 .70153 Mdot
.56383 .44793 Mdot
.3616 .36077 Mdot
.59373 .41204 Mdot
.35354 .35714 Mdot
.61632 .38314 Mdot
.56051 .35336 Mdot
.36837 .64365 Mdot
.7002 .40253 Mdot
.54511 .38076 Mdot
.67288 .19066 Mdot
.49866 .47706 Mdot
.65466 .57506 Mdot
.59719 .43121 Mdot
.48061 .61865 Mdot
.34014 .52752 Mdot
.26442 .5995 Mdot
.51708 .65145 Mdot
.38533 .58362 Mdot
.36475 .38795 Mdot
.49299 .6552 Mdot
.48511 .68824 Mdot
.50871 .37766 Mdot
.65899 .62203 Mdot
.34872 .55187 Mdot
.55206 .41816 Mdot
.56303 .44686 Mdot
.51432 .19473 Mdot
.64168 .71545 Mdot
.32398 .42187 Mdot
.37633 .19458 Mdot
.31596 .3689 Mdot
.65991 .5838 Mdot
.5174 .64202 Mdot
.53865 .41108 Mdot
.58435 .40825 Mdot
.38774 .68319 Mdot
.39582 .37023 Mdot
.46507 .53931 Mdot
.29812 .32271 Mdot
.56952 .6018 Mdot
.71016 .41654 Mdot
.37775 .36639 Mdot
.70853 .42052 Mdot
.62603 .62089 Mdot
.72516 .73553 Mdot
.69531 .43442 Mdot
.3553 .58977 Mdot
.70498 .4333 Mdot
.33747 .37059 Mdot
.57875 .36802 Mdot
.52161 .63397 Mdot
.53617 .65866 Mdot
.36373 .3752 Mdot
.4664 .63655 Mdot
.63917 .61123 Mdot
.54473 .42459 Mdot
.39742 .21406 Mdot
.28496 .4868 Mdot
.52086 .67121 Mdot
.50525 .43271 Mdot
.33749 .5546 Mdot
.62136 .40518 Mdot
.65265 .61494 Mdot
.3493 .57842 Mdot
.75661 .36306 Mdot
.32891 .60231 Mdot
.58208 .44048 Mdot
.72879 .28067 Mdot
.34189 .57002 Mdot
.48943 .45298 Mdot
.56284 .42788 Mdot
.37963 .56638 Mdot
.49385 .38489 Mdot
.36683 .72278 Mdot
.52186 .56116 Mdot
.82688 .56107 Mdot
.49996 .54281 Mdot
.52685 .65176 Mdot
.38665 .73971 Mdot
.28093 .62254 Mdot
.35079 .53208 Mdot
.51564 .6171 Mdot
.60927 .53257 Mdot
.35153 .59921 Mdot
.61631 .45861 Mdot
.56977 .38712 Mdot
.23958 .66037 Mdot
.37385 .52817 Mdot
.35292 .73415 Mdot
.27342 .53584 Mdot
.62754 .4053 Mdot
.54257 .36869 Mdot
.58004 .41013 Mdot
.40443 .37296 Mdot
.36677 .57547 Mdot
.63223 .1817 Mdot
.33481 .57264 Mdot
.41568 .23811 Mdot
.51626 .67061 Mdot
.47575 .66205 Mdot
.56128 .39976 Mdot
.46159 .44055 Mdot
.73851 .36727 Mdot
.58923 .41413 Mdot
.65125 .54996 Mdot
.27014 .67865 Mdot
.62768 .39075 Mdot
.3955 .40202 Mdot
.50463 .41051 Mdot
.55014 .49327 Mdot
.3678 .54545 Mdot
.63004 .59933 Mdot
.75171 .39957 Mdot
.35277 .5442 Mdot
.56752 .41008 Mdot
.24195 .45781 Mdot
.5885 .3898 Mdot
.59932 .37444 Mdot
.35008 .2633 Mdot
.61523 .58809 Mdot
.50391 .66057 Mdot
.64621 .59038 Mdot
.3727 .41238 Mdot
.17185 .3123 Mdot
.61948 .59697 Mdot
.74136 .36072 Mdot
.22934 .66356 Mdot
.69886 .44608 Mdot
.33612 .3609 Mdot
.67285 .61503 Mdot
.34472 .58551 Mdot
.79807 .6497 Mdot
.36936 .31203 Mdot
.39378 .53627 Mdot
.56965 .42587 Mdot
.3422 .34227 Mdot
.36906 .35441 Mdot
.33835 .59452 Mdot
.32963 .38734 Mdot
.59101 .32927 Mdot
.59009 .36983 Mdot
.33326 .53986 Mdot
.25108 .48382 Mdot
.38379 .55694 Mdot
.44057 .57719 Mdot
.59186 .43018 Mdot
.38035 .3723 Mdot
.52927 .43344 Mdot
.37129 .42814 Mdot
.48337 .6236 Mdot
.6252 .37001 Mdot
.63602 .61005 Mdot
.22846 .47017 Mdot
.48617 .67315 Mdot
.58199 .59698 Mdot
.35956 .41056 Mdot
.30566 .59063 Mdot
.34609 .40683 Mdot
.39613 .42053 Mdot
.37955 .59909 Mdot
.34283 .38804 Mdot
.54559 .43315 Mdot
.55365 .55944 Mdot
.36395 .40661 Mdot
.35624 .56031 Mdot
.63142 .59632 Mdot
.36034 .38989 Mdot
.45438 .63076 Mdot
.58031 .44476 Mdot
.50858 .63975 Mdot
.70209 .64503 Mdot
.34456 .34416 Mdot
.61526 .59881 Mdot
.53076 .62577 Mdot
.64578 .56621 Mdot
.45947 .82148 Mdot
.33644 .60048 Mdot
.39442 .25553 Mdot
.67302 .55901 Mdot
.36842 .351 Mdot
.70731 .64541 Mdot
.54361 .40156 Mdot
.58318 .44449 Mdot
.67586 .58124 Mdot
.36954 .35451 Mdot
.65248 .80105 Mdot
.62168 .48858 Mdot
.43193 .54989 Mdot
.38978 .60517 Mdot
.70669 .23178 Mdot
.43529 .56673 Mdot
.54382 .85707 Mdot
.53944 .46787 Mdot
.54305 .64928 Mdot
.57215 .39984 Mdot
.3941 .65492 Mdot
.65699 .59193 Mdot
.44087 .61901 Mdot
.58547 .35444 Mdot
.49816 .66012 Mdot
.59363 .45349 Mdot
.53996 .53655 Mdot
.50068 .45883 Mdot
.67009 .57796 Mdot
.50152 .77602 Mdot
.33632 .34983 Mdot
.64279 .60471 Mdot
.47521 .64781 Mdot
.72428 .40103 Mdot
.58718 .37141 Mdot
.6084 .46762 Mdot
.56964 .60269 Mdot
.34191 .36028 Mdot
.52916 .64482 Mdot
.37394 .55402 Mdot
.6275 .58922 Mdot
.61277 .42795 Mdot
.54329 .39448 Mdot
.36703 .67923 Mdot
.33429 .55537 Mdot
.53885 .66356 Mdot
.36195 .5955 Mdot
.47765 .68649 Mdot
.59493 .36496 Mdot
.47776 .67503 Mdot
.54661 .45785 Mdot
.35874 .64065 Mdot
.37622 .25446 Mdot
.4861 .28932 Mdot
.48709 .65289 Mdot
.70618 .32793 Mdot
.33476 .55874 Mdot
.37662 .58615 Mdot
.18975 .59129 Mdot
.36388 .292 Mdot
.49063 .18504 Mdot
.76945 .627 Mdot
.33376 .54443 Mdot
.34471 .55503 Mdot
.506 .64005 Mdot
.34265 .39015 Mdot
.31767 .37333 Mdot
.48074 .68864 Mdot
.73176 .53951 Mdot
.33655 .36552 Mdot
.76194 .68181 Mdot
.58105 .20723 Mdot
.5607 .46641 Mdot
.45325 .68002 Mdot
.63655 .58335 Mdot
.73133 .52153 Mdot
.54715 .54097 Mdot
.55409 .44592 Mdot
.76466 .45063 Mdot
.51633 .67762 Mdot
.44766 .42658 Mdot
.82037 .54671 Mdot
.59272 .45727 Mdot
.5587 .42577 Mdot
.57455 .40729 Mdot
.64648 .62545 Mdot
.3856 .3102 Mdot
.55013 .43349 Mdot
.73089 .54207 Mdot
.62465 .40424 Mdot
.48703 .44005 Mdot
.64124 .59215 Mdot
.6871 .43082 Mdot
.67668 .69474 Mdot
.58431 .1819 Mdot
.53186 .49222 Mdot
.37406 .55224 Mdot
.68108 .64385 Mdot
.37294 .59406 Mdot
.44793 .28719 Mdot
.68191 .463 Mdot
.31366 .36348 Mdot
.55174 .44433 Mdot
.48549 .65819 Mdot
.36776 .35431 Mdot
.37698 .71245 Mdot
.2039 .27083 Mdot
.37191 .54601 Mdot
.64493 .84789 Mdot
.37919 .56995 Mdot
.48667 .68983 Mdot
.35892 .38037 Mdot
.58684 .2971 Mdot
.34082 .45738 Mdot
.36291 .39222 Mdot
.64848 .78017 Mdot
.30812 .34795 Mdot
.719 .37383 Mdot
.37736 .34939 Mdot
.35035 .55938 Mdot
.29329 .59673 Mdot
.62326 .33166 Mdot
.54995 .39713 Mdot
.42423 .49086 Mdot
.73045 .36163 Mdot
.5431 .40325 Mdot
.48405 .66364 Mdot
.37554 .26447 Mdot
.75595 .45709 Mdot
.34097 .38211 Mdot
.33613 .60711 Mdot
.55934 .43305 Mdot
.60634 .38645 Mdot
.58117 .36989 Mdot
.33724 .24239 Mdot
.7218 .73869 Mdot
.5817 .36646 Mdot
.62243 .38993 Mdot
.49482 .65762 Mdot
.68967 .58315 Mdot
.50379 .76196 Mdot
.49384 .2091 Mdot
.57584 .45808 Mdot
.64134 .60069 Mdot
.66108 .6309 Mdot
.55752 .3716 Mdot
.58452 .55788 Mdot
.24396 .44819 Mdot
.55179 .41972 Mdot
.3773 .26691 Mdot
.56843 .66435 Mdot
.53416 .68503 Mdot
.5002 .68708 Mdot
.32842 .36637 Mdot
.50319 .69238 Mdot
.46666 .66149 Mdot
.58528 .30417 Mdot
.48224 .53849 Mdot
.39678 .61557 Mdot
.65206 .58458 Mdot
.58661 .40302 Mdot
.66271 .36935 Mdot
.23673 .4795 Mdot
.36875 .60176 Mdot
.3892 .3819 Mdot
.33996 .52594 Mdot
.63487 .63827 Mdot
.29064 .39239 Mdot
.52401 .67627 Mdot
.34339 .53997 Mdot
.3145 .54254 Mdot
.63937 .59853 Mdot
.33088 .58167 Mdot
.31142 .53548 Mdot
.63712 .39063 Mdot
.49604 .31913 Mdot
.58717 .42069 Mdot
.55303 .8167 Mdot
.3413 .55023 Mdot
.31112 .61895 Mdot
.56002 .41333 Mdot
.49937 .68267 Mdot
.58774 .31724 Mdot
.55147 .39228 Mdot
.50825 .69077 Mdot
.54228 .37522 Mdot
.63048 .56678 Mdot
.3623 .42567 Mdot
.34845 .45935 Mdot
.1421 .55863 Mdot
.66206 .6213 Mdot
.37876 .70746 Mdot
.54882 .44552 Mdot
.3709 .79414 Mdot
.35721 .38818 Mdot
.53241 .40242 Mdot
.74209 .43924 Mdot
.35699 .40211 Mdot
.37985 .38663 Mdot
.60632 .39809 Mdot
.35685 .59206 Mdot
.48337 .67131 Mdot
.63752 .59348 Mdot
.5294 .84384 Mdot
.57589 .43074 Mdot
.59881 .44754 Mdot
.6475 .6046 Mdot
.33091 .56048 Mdot
.54923 .37615 Mdot
.75859 .58556 Mdot
.68096 .78914 Mdot
.38149 .57913 Mdot
.60731 .46082 Mdot
.44417 .31231 Mdot
.59236 .50464 Mdot
.32668 .79715 Mdot
.58494 .54788 Mdot
.50222 .65499 Mdot
.65443 .43112 Mdot
.2587 .25123 Mdot
.62943 .59585 Mdot
.49158 .17836 Mdot
.6088 .38774 Mdot
.61726 .43027 Mdot
.38801 .36418 Mdot
.5995 .42269 Mdot
.39442 .39301 Mdot
.15097 .50928 Mdot
.71999 .27038 Mdot
.32598 .37941 Mdot
.36124 .34803 Mdot
.74479 .38864 Mdot
.43023 .67973 Mdot
.36412 .37758 Mdot
.61187 .37387 Mdot
.63005 .51444 Mdot
.44149 .41426 Mdot
.67765 .60271 Mdot
.70221 .66353 Mdot
.65948 .44532 Mdot
.59976 .57875 Mdot
.70253 .70331 Mdot
.66981 .42524 Mdot
.46035 .58781 Mdot
.37549 .56803 Mdot
.59098 .45748 Mdot
.53652 .66062 Mdot
.53494 .6734 Mdot
.52909 .44548 Mdot
.5913 .39662 Mdot
.36878 .41226 Mdot
.6327 .57892 Mdot
.36009 .53365 Mdot
.61668 .42614 Mdot
.74636 .41413 Mdot
.62718 .57918 Mdot
.33456 .38921 Mdot
.44367 .2424 Mdot
.63873 .56052 Mdot
.56423 .34915 Mdot
.55102 .40814 Mdot
.59693 .40919 Mdot
.63258 .33541 Mdot
.3697 .5767 Mdot
.7135 .65032 Mdot
.63357 .42441 Mdot
.6679 .22915 Mdot
.40918 .60262 Mdot
.62978 .36644 Mdot
.33162 .39642 Mdot
.35856 .61955 Mdot
.45979 .66103 Mdot
.27552 .38966 Mdot
.58164 .43856 Mdot
.48214 .7887 Mdot
.25069 .67098 Mdot
.49485 .61996 Mdot
.37436 .42579 Mdot
.64484 .58409 Mdot
.58938 .41147 Mdot
.42155 .26647 Mdot
.56716 .38918 Mdot
.60773 .56928 Mdot
.50224 .62592 Mdot
.37585 .57171 Mdot
.52707 .81553 Mdot
.52714 .68835 Mdot
.37786 .38414 Mdot
.79862 .36258 Mdot
.39512 .39378 Mdot
.31909 .37417 Mdot
.45822 .24116 Mdot
.37059 .5781 Mdot
.22343 .27987 Mdot
.16187 .51604 Mdot
.62329 .37204 Mdot
.33295 .56153 Mdot
.36537 .37005 Mdot
.62425 .42053 Mdot
.30859 .38212 Mdot
.33999 .41168 Mdot
.60592 .36783 Mdot
.61322 .44509 Mdot
.37737 .76074 Mdot
.81292 .56952 Mdot
.6465 .58423 Mdot
.36939 .4157 Mdot
.34208 .47024 Mdot
.62497 .42267 Mdot
.56277 .40528 Mdot
.28074 .63131 Mdot
.66355 .61742 Mdot
.31272 .48022 Mdot
.60744 .38701 Mdot
.74283 .31266 Mdot
.51797 .37105 Mdot
.40488 .39537 Mdot
.37617 .59338 Mdot
.5975 .18962 Mdot
.32793 .51314 Mdot
.39361 .39213 Mdot
.6232 .59193 Mdot
.41766 .38705 Mdot
.74023 .3547 Mdot
.32743 .55629 Mdot
.38449 .37012 Mdot
.51715 .57951 Mdot
.36078 .57459 Mdot
.34312 .54511 Mdot
.47056 .23299 Mdot
.49931 .6147 Mdot
.64782 .62688 Mdot
.34631 .55272 Mdot
.22338 .42577 Mdot
.35518 .56453 Mdot
.16502 .53404 Mdot
.59714 .46038 Mdot
.75291 .51246 Mdot
.43046 .63715 Mdot
.65908 .40209 Mdot
.33729 .54898 Mdot
.6642 .6097 Mdot
.58431 .37282 Mdot
.33387 .37308 Mdot
.64547 .56973 Mdot
.3707 .50917 Mdot
.5133 .64891 Mdot
.34547 .40438 Mdot
.37813 .53829 Mdot
.36071 .3564 Mdot
.25623 .38908 Mdot
.20982 .65253 Mdot
.77706 .41931 Mdot
.33259 .45433 Mdot
.58979 .37147 Mdot
.73669 .66896 Mdot
.59672 .46654 Mdot
.59427 .39225 Mdot
.48056 .66409 Mdot
.75672 .48704 Mdot
.35528 .37721 Mdot
.60257 .81553 Mdot
.36256 .54246 Mdot
.5953 .18431 Mdot
.55718 .50391 Mdot
.52497 .40291 Mdot
.36803 .40698 Mdot
.39972 .37817 Mdot
.47885 .26808 Mdot
.4589 .67608 Mdot
.53776 .43856 Mdot
.62742 .45658 Mdot
.51787 .42964 Mdot
.36133 .54492 Mdot
.58825 .57274 Mdot
.52637 .65539 Mdot
.25921 .71905 Mdot
.50492 .62478 Mdot
.60709 .56552 Mdot
.33964 .3849 Mdot
.61967 .59695 Mdot
.56071 .40632 Mdot
.30261 .38744 Mdot
.39593 .36917 Mdot
.67113 .57577 Mdot
.66803 .59944 Mdot
.33562 .68938 Mdot
.36458 .58725 Mdot
.55172 .38538 Mdot
.55296 .43921 Mdot
.60539 .42274 Mdot
.59856 .39726 Mdot
.36752 .54312 Mdot
.57456 .37276 Mdot
.34289 .51655 Mdot
.27047 .35078 Mdot
.76911 .54221 Mdot
.50188 .54066 Mdot
.21792 .58119 Mdot
.33794 .3761 Mdot
.22642 .43322 Mdot
.59761 .49419 Mdot
.27496 .28516 Mdot
.29865 .72837 Mdot
.6371 .40734 Mdot
.47301 .66953 Mdot
.4989 .36821 Mdot
.53088 .67146 Mdot
.54 .86763 Mdot
.34047 .65562 Mdot
.81262 .59357 Mdot
.56438 .44718 Mdot
.54925 .56013 Mdot
.20581 .44334 Mdot
.60311 .46683 Mdot
.3459 .67426 Mdot
.2234 .57272 Mdot
.49021 .77616 Mdot
.65557 .61607 Mdot
.57138 .4399 Mdot
.65485 .35866 Mdot
.54549 .42999 Mdot
.56767 .40093 Mdot
.57797 .37116 Mdot
.37936 .54634 Mdot
.53288 .41119 Mdot
.58645 .37702 Mdot
.56057 .74 Mdot
.70665 .41194 Mdot
.53696 .63885 Mdot
.20281 .61631 Mdot
.61918 .5974 Mdot
.36445 .40946 Mdot
.71816 .73292 Mdot
.35562 .58941 Mdot
.48596 .26742 Mdot
.59785 .40248 Mdot
.41016 .76749 Mdot
.31274 .55814 Mdot
.6255 .59811 Mdot
.47877 .63441 Mdot
.81768 .61122 Mdot
.48765 .66287 Mdot
.34204 .62401 Mdot
.49675 .6802 Mdot
.61219 .48926 Mdot
.36917 .41285 Mdot
.55312 .37886 Mdot
.3521 .5518 Mdot
.49171 .68773 Mdot
.71053 .48115 Mdot
.57978 .40804 Mdot
.49515 .66647 Mdot
.55371 .37889 Mdot
.32488 .43384 Mdot
.54636 .21149 Mdot
.46817 .65921 Mdot
.31427 .55371 Mdot
.3656 .56074 Mdot
.64493 .61957 Mdot
.35296 .40556 Mdot
.39131 .386 Mdot
.34977 .57716 Mdot
.31905 .30003 Mdot
.57186 .45858 Mdot
.62109 .43179 Mdot
.62369 .20354 Mdot
.5407 .42772 Mdot
.72089 .39655 Mdot
.53301 .57613 Mdot
.33272 .3811 Mdot
.52359 .39931 Mdot
.60987 .39699 Mdot
.58246 .44162 Mdot
.28948 .3428 Mdot
.51335 .68571 Mdot
.59424 .45856 Mdot
.66906 .59369 Mdot
.53317 .73155 Mdot
.62134 .40434 Mdot
.53293 .35094 Mdot
.39138 .38408 Mdot
.37565 .20013 Mdot
.37894 .57256 Mdot
.47554 .64907 Mdot
.48716 .65157 Mdot
.70898 .66868 Mdot
.21408 .50366 Mdot
.53417 .57507 Mdot
.28788 .75381 Mdot
.36922 .64316 Mdot
.66297 .5908 Mdot
.50667 .71536 Mdot
.28919 .60021 Mdot
.4926 .64152 Mdot
.36949 .54254 Mdot
.60774 .45919 Mdot
.57883 .4586 Mdot
.22722 .31225 Mdot
.5541 .37175 Mdot
.64111 .58505 Mdot
.38357 .55446 Mdot
.33858 .37014 Mdot
.62513 .59458 Mdot
.36291 .59631 Mdot
.3288 .37078 Mdot
.6377 .41753 Mdot
.63469 .42667 Mdot
.38839 .38438 Mdot
.38154 .36232 Mdot
.55337 .40964 Mdot
.46676 .73493 Mdot
.35739 .34865 Mdot
.37996 .3668 Mdot
.52385 .67304 Mdot
.53517 .66851 Mdot
.56419 .34172 Mdot
.33726 .56024 Mdot
.58435 .3757 Mdot
.49052 .65635 Mdot
.62098 .59989 Mdot
.35203 .37683 Mdot
.6063 .37792 Mdot
.61816 .40898 Mdot
.63784 .59814 Mdot
.63319 .61242 Mdot
.65553 .61289 Mdot
.36562 .52723 Mdot
.60294 .43076 Mdot
.36407 .38368 Mdot
.36946 .58463 Mdot
.65803 .63061 Mdot
.67501 .60442 Mdot
.48491 .71088 Mdot
.5372 .42001 Mdot
.44019 .684 Mdot
.27749 .23048 Mdot
.68026 .25371 Mdot
.47164 .63605 Mdot
.45833 .66057 Mdot
.6801 .49538 Mdot
.43939 .44122 Mdot
.33923 .57458 Mdot
.69009 .58094 Mdot
.75299 .39004 Mdot
.64232 .40751 Mdot
.6242 .38762 Mdot
.55522 .35816 Mdot
.65932 .60961 Mdot
.76614 .4918 Mdot
.39107 .40015 Mdot
.68134 .37686 Mdot
.62961 .57543 Mdot
.53362 .62851 Mdot
.48001 .71366 Mdot
.50033 .62468 Mdot
.62288 .45042 Mdot
.49847 .28963 Mdot
.2176 .46687 Mdot
.76037 .61738 Mdot
.33502 .55255 Mdot
.66337 .37159 Mdot
.3674 .78904 Mdot
.38434 .38711 Mdot
.48593 .69614 Mdot
.66457 .5903 Mdot
.37845 .36093 Mdot
.33172 .53103 Mdot
.3472 .55455 Mdot
.52145 .66846 Mdot
.52075 .66237 Mdot
.5038 .63312 Mdot
.33838 .41167 Mdot
.34114 .38679 Mdot
.58417 .43755 Mdot
.3475 .37664 Mdot
.30536 .26505 Mdot
.67931 .58057 Mdot
.52918 .61003 Mdot
.34317 .56445 Mdot
.33365 .36398 Mdot
.58129 .41049 Mdot
.43658 .42998 Mdot
.25133 .56225 Mdot
.6583 .57541 Mdot
.52886 .20162 Mdot
.51716 .86077 Mdot
.54879 .38844 Mdot
.37029 .56785 Mdot
.40067 .20935 Mdot
.57483 .41008 Mdot
.51829 .63924 Mdot
.56047 .77617 Mdot
.52385 .71922 Mdot
.55321 .39014 Mdot
.64308 .39984 Mdot
.38042 .56265 Mdot
.27262 .72733 Mdot
.58099 .43398 Mdot
.30881 .46583 Mdot
.31666 .57088 Mdot
.5259 .64624 Mdot
.78701 .70286 Mdot
.6307 .64436 Mdot
.73334 .52926 Mdot
.52433 .66412 Mdot
.58321 .38454 Mdot
.52664 .6783 Mdot
.66602 .58501 Mdot
.47362 .64421 Mdot
.39681 .39462 Mdot
.51109 .62198 Mdot
.59966 .44773 Mdot
.36614 .37635 Mdot
.34053 .56947 Mdot
.56518 .18307 Mdot
.58896 .75721 Mdot
.50175 .68294 Mdot
.46941 .67039 Mdot
.52771 .39049 Mdot
.32194 .48803 Mdot
.53862 .45169 Mdot
.61542 .45054 Mdot
.32993 .54799 Mdot
.35686 .40394 Mdot
.38218 .58479 Mdot
.6271 .35151 Mdot
.7802 .54853 Mdot
.36486 .59454 Mdot
.46955 .77632 Mdot
.65368 .60245 Mdot
.47177 .4889 Mdot
.58595 .40764 Mdot
.33958 .59163 Mdot
.60073 .43196 Mdot
.38653 .40517 Mdot
.50115 .52486 Mdot
.45837 .75244 Mdot
.35447 .54707 Mdot
.50131 .80089 Mdot
.75391 .57055 Mdot
.57514 .33528 Mdot
.37703 .58731 Mdot
.74655 .45108 Mdot
.4884 .69087 Mdot
.64481 .5719 Mdot
.64287 .56256 Mdot
.63344 .57085 Mdot
.5408 .46086 Mdot
.54226 .49813 Mdot
.61423 .59775 Mdot
.33675 .5303 Mdot
.67 .57812 Mdot
.18973 .50204 Mdot
.60756 .81191 Mdot
.65545 .59454 Mdot
.56548 .42777 Mdot
.52756 .47424 Mdot
.68538 .46355 Mdot
.36034 .72189 Mdot
.80504 .60953 Mdot
.26892 .64867 Mdot
.55383 .39432 Mdot
.33303 .41102 Mdot
.35663 .41812 Mdot
.41669 .19088 Mdot
.72141 .34679 Mdot
.70482 .27122 Mdot
.33077 .35054 Mdot
.42134 .70205 Mdot
.3373 .39429 Mdot
.56741 .36939 Mdot
.6224 .42765 Mdot
.32912 .3501 Mdot
.77804 .52011 Mdot
.41266 .70908 Mdot
.52844 .82913 Mdot
.37002 .35815 Mdot
.36341 .59944 Mdot
.36168 .60696 Mdot
.34088 .5453 Mdot
.55539 .19665 Mdot
.37126 .40381 Mdot
.61221 .41883 Mdot
.48526 .65416 Mdot
.57849 .45641 Mdot
.36119 .57795 Mdot
.61596 .81387 Mdot
.36248 .39649 Mdot
.55632 .43509 Mdot
.5733 .32542 Mdot
.5185 .65572 Mdot
.64649 .60061 Mdot
.35992 .45335 Mdot
.70487 .27653 Mdot
.35463 .53963 Mdot
.3408 .34524 Mdot
.32643 .62999 Mdot
.54911 .80832 Mdot
.53515 .46595 Mdot
.63547 .44903 Mdot
.52703 .84718 Mdot
.74961 .3325 Mdot
.54127 .43951 Mdot
.47162 .65742 Mdot
.38135 .67784 Mdot
.61746 .39713 Mdot
.3639 .41828 Mdot
.63796 .56126 Mdot
.64682 .56711 Mdot
.56298 .3414 Mdot
.38276 .47002 Mdot
.53256 .54289 Mdot
.60259 .40484 Mdot
.56338 .35049 Mdot
.52583 .65156 Mdot
.38371 .64804 Mdot
.67533 .2354 Mdot
.62274 .59961 Mdot
.55255 .37782 Mdot
.64273 .77 Mdot
.38847 .36175 Mdot
.48977 .62248 Mdot
.32538 .57055 Mdot
.31773 .33199 Mdot
.47702 .63623 Mdot
.61058 .37682 Mdot
.55377 .37324 Mdot
.37126 .60386 Mdot
.40426 .39478 Mdot
.6585 .60841 Mdot
.47759 .65984 Mdot
.63799 .61354 Mdot
.35945 .40226 Mdot
.34628 .38203 Mdot
.57198 .328 Mdot
.55137 .48031 Mdot
.49499 .68584 Mdot
.54931 .46074 Mdot
.5206 .72493 Mdot
.37065 .82353 Mdot
.39437 .59132 Mdot
.5362 .40849 Mdot
.39464 .35822 Mdot
.3563 .54436 Mdot
.61604 .43594 Mdot
.56056 .85202 Mdot
.62655 .41565 Mdot
.38438 .61337 Mdot
.77469 .38263 Mdot
.64676 .61424 Mdot
.68138 .40412 Mdot
.3487 .7526 Mdot
.54069 .42149 Mdot
.49561 .64503 Mdot
.50597 .43085 Mdot
.3489 .58992 Mdot
.34055 .38285 Mdot
.35779 .8244 Mdot
.35856 .5634 Mdot
.54655 .42272 Mdot
.62644 .59093 Mdot
.39025 .35762 Mdot
.59922 .53692 Mdot
.58441 .56191 Mdot
.49267 .40331 Mdot
.53144 .43303 Mdot
.60226 .39059 Mdot
.76488 .58867 Mdot
.47838 .64639 Mdot
.3724 .36644 Mdot
.37054 .56337 Mdot
.34634 .57737 Mdot
.51888 .67517 Mdot
.42312 .60236 Mdot
.47099 .4893 Mdot
.37275 .16815 Mdot
.51836 .69009 Mdot
.61799 .5871 Mdot
.32151 .47826 Mdot
.47963 .65312 Mdot
.49822 .66963 Mdot
.52521 .67132 Mdot
.48387 .58314 Mdot
.33636 .36365 Mdot
.61244 .37821 Mdot
.38577 .41352 Mdot
.58421 .38293 Mdot
.38201 .61437 Mdot
.35128 .54862 Mdot
.35721 .3959 Mdot
.49216 .83145 Mdot
.47315 .33595 Mdot
.5685 .4166 Mdot
.37146 .79369 Mdot
.58653 .35711 Mdot
.69358 .46584 Mdot
.55939 .36082 Mdot
.51026 .67894 Mdot
.60337 .47236 Mdot
.52004 .44099 Mdot
.45354 .17865 Mdot
.3398 .56352 Mdot
.53289 .68964 Mdot
.60211 .35201 Mdot
.55434 .35432 Mdot
.33037 .40492 Mdot
.37871 .36217 Mdot
.64127 .5636 Mdot
.70175 .37896 Mdot
.33756 .56917 Mdot
.1732 .46203 Mdot
.54977 .39911 Mdot
.59243 .60684 Mdot
.61359 .26419 Mdot
.61408 .43978 Mdot
.37173 .77363 Mdot
.49471 .2843 Mdot
.58841 .41023 Mdot
.43503 .52675 Mdot
.33477 .55735 Mdot
.79224 .51501 Mdot
.62237 .39773 Mdot
.51863 .64902 Mdot
.33914 .38958 Mdot
.39835 .36987 Mdot
.62641 .57055 Mdot
.24695 .31502 Mdot
.38244 .58704 Mdot
.34723 .38971 Mdot
.58026 .40183 Mdot
.37188 .57089 Mdot
.51389 .69316 Mdot
.52723 .40079 Mdot
.71212 .32624 Mdot
.34492 .37143 Mdot
.54495 .37166 Mdot
.28723 .44916 Mdot
.70094 .52121 Mdot
.79982 .41217 Mdot
.3704 .55899 Mdot
.64821 .61903 Mdot
.50813 .39973 Mdot
.3498 .29694 Mdot
.52654 .38014 Mdot
.74854 .5337 Mdot
.18989 .51515 Mdot
.65832 .61817 Mdot
.56049 .41767 Mdot
.6134 .42506 Mdot
.47507 .45243 Mdot
.62189 .59453 Mdot
.56018 .44582 Mdot
.34047 .32032 Mdot
.35192 .35884 Mdot
.48366 .69325 Mdot
.33973 .36676 Mdot
.56911 .42537 Mdot
.54304 .47599 Mdot
.38667 .36423 Mdot
.39002 .8193 Mdot
.68443 .58026 Mdot
.37707 .58109 Mdot
.60985 .36446 Mdot
.6303 .42622 Mdot
.61304 .15967 Mdot
.50262 .618 Mdot
.47162 .7431 Mdot
.57941 .67973 Mdot
.67934 .73085 Mdot
.63642 .64607 Mdot
.83262 .49859 Mdot
.75349 .33772 Mdot
.53262 .40948 Mdot
.62483 .50326 Mdot
.25265 .42164 Mdot
.33125 .55438 Mdot
.21849 .38391 Mdot
.5497 .39709 Mdot
.56992 .39961 Mdot
.46741 .64026 Mdot
.43592 .75331 Mdot
.70337 .26821 Mdot
.42514 .44091 Mdot
.65624 .60895 Mdot
.36416 .41501 Mdot
.61124 .37523 Mdot
.45827 .54178 Mdot
.53123 .625 Mdot
.63266 .64066 Mdot
.55558 .43166 Mdot
.32193 .26963 Mdot
.24827 .54377 Mdot
.36623 .58282 Mdot
.48837 .64988 Mdot
.71721 .28689 Mdot
.53783 .41251 Mdot
.32902 .58079 Mdot
.57827 .42677 Mdot
.5326 .59835 Mdot
.63363 .35646 Mdot
.65927 .58744 Mdot
.60603 .38255 Mdot
.65852 .64566 Mdot
.73862 .23752 Mdot
.61107 .59715 Mdot
.30964 .36458 Mdot
.53815 .62279 Mdot
.51112 .68763 Mdot
.38245 .36476 Mdot
.50588 .68739 Mdot
.49474 .25204 Mdot
.61876 .29861 Mdot
.65422 .60475 Mdot
.54645 .35219 Mdot
.65052 .59437 Mdot
.48589 .62302 Mdot
.55279 .39297 Mdot
.43911 .85284 Mdot
.48524 .68004 Mdot
.75992 .32782 Mdot
.35445 .56712 Mdot
.53075 .62324 Mdot
.62415 .40369 Mdot
.30906 .62559 Mdot
.52787 .68682 Mdot
.43443 .73508 Mdot
.58277 .44112 Mdot
.3415 .3754 Mdot
.61688 .40218 Mdot
.6213 .37132 Mdot
.54159 .64518 Mdot
.57629 .37813 Mdot
.36167 .59642 Mdot
.32736 .35777 Mdot
.78178 .66393 Mdot
.21766 .54932 Mdot
.55327 .44337 Mdot
.57865 .40403 Mdot
.41141 .40499 Mdot
.62081 .44965 Mdot
.36817 .5438 Mdot
.10666 .5541 Mdot
.65318 .60239 Mdot
.54058 .68191 Mdot
.65078 .64942 Mdot
.6387 .40782 Mdot
.58012 .37262 Mdot
.59214 .84837 Mdot
.77548 .55047 Mdot
.37272 .59318 Mdot
.517 .42894 Mdot
.51874 .69277 Mdot
.63097 .58489 Mdot
.34577 .52931 Mdot
.59642 .41117 Mdot
.56057 .40964 Mdot
.63798 .61711 Mdot
.63091 .52028 Mdot
.60515 .21445 Mdot
.34895 .60051 Mdot
.63337 .46426 Mdot
.47324 .614 Mdot
.56289 .45811 Mdot
.52385 .1919 Mdot
.38387 .37259 Mdot
.35014 .53871 Mdot
.70649 .68838 Mdot
.53619 .41252 Mdot
.37436 .5973 Mdot
.33722 .56795 Mdot
.52029 .40179 Mdot
.37734 .34484 Mdot
.32533 .36634 Mdot
.35449 .35629 Mdot
.18172 .35555 Mdot
.72972 .50623 Mdot
.50397 .63311 Mdot
.33354 .55801 Mdot
.46743 .67068 Mdot
.60831 .56664 Mdot
.52084 .5644 Mdot
.46794 .66649 Mdot
.34425 .35609 Mdot
.54634 .64699 Mdot
.60344 .43776 Mdot
.33994 .57085 Mdot
.4974 .63894 Mdot
.62729 .37821 Mdot
.34012 .48935 Mdot
.31168 .69825 Mdot
.67266 .60378 Mdot
.63083 .56273 Mdot
.62314 .41694 Mdot
.46296 .67941 Mdot
.55517 .40722 Mdot
.32096 .55941 Mdot
.33613 .48469 Mdot
.61207 .36693 Mdot
.50462 .68374 Mdot
.41577 .39564 Mdot
.71086 .28317 Mdot
.56964 .47615 Mdot
.56478 .42648 Mdot
.57934 .38109 Mdot
.57874 .42707 Mdot
.5491 .80114 Mdot
.36623 .61055 Mdot
.21853 .57748 Mdot
.71057 .64671 Mdot
.36795 .39577 Mdot
.38647 .41609 Mdot
.66696 .2389 Mdot
.25192 .4339 Mdot
.33673 .55943 Mdot
.59594 .39404 Mdot
.23791 .50159 Mdot
.6805 .78837 Mdot
.50475 .84823 Mdot
.48052 .44541 Mdot
.50847 .61682 Mdot
.33928 .34629 Mdot
.48991 .68939 Mdot
.57715 .38575 Mdot
.54649 .36086 Mdot
.8347 .45859 Mdot
.32716 .53996 Mdot
.65896 .60186 Mdot
.58592 .38148 Mdot
.72869 .51218 Mdot
.49443 .65599 Mdot
.53345 .62467 Mdot
.60498 .45686 Mdot
.41068 .38763 Mdot
.71794 .23067 Mdot
.36965 .57567 Mdot
.266 .63032 Mdot
.20283 .44869 Mdot
.26417 .55734 Mdot
.36382 .57813 Mdot
.50397 .48562 Mdot
.48006 .62847 Mdot
.60178 .25126 Mdot
.37431 .3968 Mdot
.64829 .57067 Mdot
.63448 .37148 Mdot
.39277 .37446 Mdot
.51473 .62809 Mdot
.34076 .37963 Mdot
.58135 .37141 Mdot
.33048 .59576 Mdot
.50315 .65287 Mdot
.40095 .61359 Mdot
.39905 .36135 Mdot
.62315 .59431 Mdot
.42215 .46234 Mdot
.46255 .38249 Mdot
.49402 .28148 Mdot
.59945 .45895 Mdot
.46107 .54969 Mdot
.61056 .4195 Mdot
.38736 .42162 Mdot
.5799 .41547 Mdot
.40996 .42019 Mdot
.49653 .64567 Mdot
.62243 .39071 Mdot
.6022 .40099 Mdot
.17663 .55633 Mdot
.56602 .44424 Mdot
.54369 .45327 Mdot
.59094 .40744 Mdot
.32437 .41845 Mdot
.53845 .35644 Mdot
.33393 .40004 Mdot
.53269 .74344 Mdot
.50115 .67108 Mdot
.65406 .56604 Mdot
.64487 .62143 Mdot
.75165 .49817 Mdot
.67256 .6833 Mdot
.41552 .7557 Mdot
.34808 .36397 Mdot
.34555 .59175 Mdot
.58034 .42024 Mdot
.81731 .54729 Mdot
.57195 .62053 Mdot
.52949 .62639 Mdot
.21932 .55118 Mdot
.6565 .43327 Mdot
.80177 .49875 Mdot
.51892 .42867 Mdot
.21033 .33338 Mdot
.59489 .4857 Mdot
.64858 .38808 Mdot
.5048 .70005 Mdot
.60713 .61604 Mdot
.62357 .44097 Mdot
.32287 .39345 Mdot
.65014 .5766 Mdot
.57263 .50642 Mdot
.4413 .67421 Mdot
.51591 .7438 Mdot
.38668 .43759 Mdot
.59287 .435 Mdot
.50415 .65361 Mdot
.34792 .40599 Mdot
.68413 .24454 Mdot
.37101 .58357 Mdot
.42307 .59201 Mdot
.28771 .42412 Mdot
.39934 .81662 Mdot
.62584 .58034 Mdot
.55621 .22544 Mdot
.60162 .44568 Mdot
.54301 .76813 Mdot
.60674 .36429 Mdot
.62873 .81174 Mdot
.61829 .60171 Mdot
.34205 .35496 Mdot
.35876 .59927 Mdot
.36738 .41769 Mdot
.48041 .28344 Mdot
.45492 .68745 Mdot
.4706 .52024 Mdot
.4895 .66443 Mdot
.55745 .54605 Mdot
.36998 .37227 Mdot
.55668 .37735 Mdot
.36789 .16923 Mdot
.38164 .36863 Mdot
.38234 .35311 Mdot
.23746 .6748 Mdot
.40414 .84179 Mdot
.62478 .46554 Mdot
.35745 .34782 Mdot
.49123 .66978 Mdot
.64579 .58155 Mdot
.61489 .38961 Mdot
.59437 .43892 Mdot
.3925 .3767 Mdot
.54231 .66016 Mdot
.41481 .30139 Mdot
.51842 .66787 Mdot
.33793 .3619 Mdot
.51067 .66618 Mdot
.32024 .62218 Mdot
.47529 .65418 Mdot
.6302 .42758 Mdot
.5801 .41671 Mdot
.6352 .66964 Mdot
.34578 .38107 Mdot
.60306 .40655 Mdot
.52842 .39023 Mdot
.36266 .38093 Mdot
.55426 .52564 Mdot
.42403 .30011 Mdot
.55326 .44859 Mdot
.57529 .44403 Mdot
.65385 .61865 Mdot
.49087 .56234 Mdot
.53863 .21245 Mdot
.58679 .37339 Mdot
.64513 .62469 Mdot
.32122 .38765 Mdot
.55128 .41774 Mdot
.69273 .75846 Mdot
.38499 .68053 Mdot
.54806 .39222 Mdot
.48786 .69033 Mdot
.51894 .43714 Mdot
.79318 .39544 Mdot
.61666 .44933 Mdot
.36002 .37303 Mdot
.34893 .39644 Mdot
.16858 .48665 Mdot
.37736 .38205 Mdot
.53616 .65946 Mdot
.3607 .57623 Mdot
.54226 .81467 Mdot
.50862 .6934 Mdot
.57044 .48267 Mdot
.15543 .56449 Mdot
.53694 .38886 Mdot
.63391 .40001 Mdot
.76272 .30739 Mdot
.48743 .68571 Mdot
.37544 .40789 Mdot
.44365 .45362 Mdot
.56425 .48824 Mdot
.34705 .54009 Mdot
.61708 .35299 Mdot
.6076 .46033 Mdot
.7737 .36528 Mdot
.55781 .79296 Mdot
.32329 .57347 Mdot
.5475 .45483 Mdot
.58441 .37292 Mdot
.47884 .61978 Mdot
.58249 .40554 Mdot
.65 .58317 Mdot
.36813 .40477 Mdot
.47383 .65996 Mdot
.63632 .5996 Mdot
.54082 .41089 Mdot
.65662 .61149 Mdot
.50865 .63939 Mdot
.32422 .56343 Mdot
.56608 .38716 Mdot
.67821 .60057 Mdot
.65564 .61093 Mdot
.60885 .41761 Mdot
.33822 .3824 Mdot
.65129 .45143 Mdot
.56225 .44347 Mdot
.60426 .37699 Mdot
.39115 .38787 Mdot
.76291 .74973 Mdot
.62179 .43193 Mdot
.75547 .53898 Mdot
.39827 .37661 Mdot
.55842 .539 Mdot
.5003 .6961 Mdot
.61244 .45895 Mdot
.3238 .56249 Mdot
.3277 .57219 Mdot
.50352 .62362 Mdot
.35043 .34266 Mdot
.58677 .66655 Mdot
.36465 .33678 Mdot
.51062 .43394 Mdot
.56116 .46028 Mdot
.37151 .3157 Mdot
.81998 .58555 Mdot
.38707 .40911 Mdot
.43528 .63981 Mdot
.39502 .4611 Mdot
.33754 .58823 Mdot
.53754 .63921 Mdot
.33084 .348 Mdot
.39073 .39723 Mdot
.33245 .37795 Mdot
.65166 .57069 Mdot
.63962 .67125 Mdot
.40431 .387 Mdot
.40989 .39564 Mdot
.58866 .44237 Mdot
.58994 .37478 Mdot
.72085 .30735 Mdot
.6834 .29583 Mdot
.66761 .60545 Mdot
.51946 .63494 Mdot
.16815 .35581 Mdot
.32361 .55204 Mdot
.20123 .5775 Mdot
.62811 .3906 Mdot
.20698 .27539 Mdot
.62064 .39684 Mdot
.58277 .40072 Mdot
.32654 .35821 Mdot
.67696 .59883 Mdot
.6518 .59783 Mdot
.3749 .36718 Mdot
.40122 .40825 Mdot
.65139 .58454 Mdot
.33726 .7528 Mdot
.70806 .75499 Mdot
.53769 .7107 Mdot
.35961 .38482 Mdot
.5122 .33628 Mdot
.35858 .60398 Mdot
.53417 .48319 Mdot
.31863 .57203 Mdot
.49575 .66239 Mdot
.47416 .63737 Mdot
.35396 .54143 Mdot
.58079 .43967 Mdot
.49634 .63494 Mdot
.53599 .40222 Mdot
.26804 .66483 Mdot
.48299 .30982 Mdot
.60946 .65065 Mdot
.4904 .41919 Mdot
.54248 .5221 Mdot
.40217 .61486 Mdot
.54494 .4136 Mdot
.68792 .7389 Mdot
.65676 .60578 Mdot
.50331 .42256 Mdot
.34487 .53773 Mdot
.78292 .32729 Mdot
.55896 .3883 Mdot
.35637 .37288 Mdot
.33492 .56472 Mdot
.27606 .3788 Mdot
.31534 .46748 Mdot
.58199 .38173 Mdot
.28795 .2279 Mdot
.30949 .39412 Mdot
.48195 .65026 Mdot
.3018 .29631 Mdot
.39862 .40294 Mdot
.68384 .63189 Mdot
.71864 .65724 Mdot
.46024 .83016 Mdot
.365 .41007 Mdot
.49164 .61833 Mdot
.3262 .38844 Mdot
.62416 .58945 Mdot
.3127 .37838 Mdot
.49608 .65079 Mdot
.55677 .42879 Mdot
.51469 .67953 Mdot
.65882 .57325 Mdot
.61099 .22145 Mdot
.32393 .57445 Mdot
.5289 .69275 Mdot
.35808 .55242 Mdot
.68582 .52756 Mdot
.75322 .60053 Mdot
.37661 .57305 Mdot
.41459 .25769 Mdot
.57173 .46229 Mdot
.40334 .39809 Mdot
.51971 .67928 Mdot
.65329 .73101 Mdot
.4208 .45897 Mdot
.37779 .3938 Mdot
.50953 .62963 Mdot
.3286 .46021 Mdot
.34065 .28058 Mdot
.54231 .4536 Mdot
.67092 .47825 Mdot
.36335 .38575 Mdot
.47592 .62726 Mdot
.6133 .19682 Mdot
.32589 .39043 Mdot
.52156 .68759 Mdot
.36576 .60025 Mdot
.34967 .58046 Mdot
.57708 .45439 Mdot
.35365 .61626 Mdot
.49203 .63044 Mdot
.39312 .52805 Mdot
.35593 .34678 Mdot
.27893 .35706 Mdot
.68096 .59295 Mdot
.50701 .67429 Mdot
.54778 .37383 Mdot
.36426 .42957 Mdot
.36046 .65841 Mdot
.42714 .31607 Mdot
.37377 .19417 Mdot
.51875 .67504 Mdot
.3763 .40265 Mdot
.35311 .37313 Mdot
.56539 .47546 Mdot
.33175 .45247 Mdot
.5882 .67185 Mdot
.45866 .4157 Mdot
.45327 .41465 Mdot
.48393 .69408 Mdot
.49263 .72498 Mdot
.60376 .35157 Mdot
.58833 .43177 Mdot
.34142 .59177 Mdot
.5595 .43113 Mdot
.33668 .35168 Mdot
.60028 .45806 Mdot
.36969 .56391 Mdot
.48519 .66315 Mdot
.56191 .38944 Mdot
.65122 .61466 Mdot
.37578 .60521 Mdot
.33534 .52665 Mdot
.50427 .67933 Mdot
.39356 .37744 Mdot
.58126 .53963 Mdot
.52141 .66028 Mdot
.59179 .43532 Mdot
.48931 .57295 Mdot
.58209 .37 Mdot
.67348 .4279 Mdot
.32939 .39805 Mdot
.47444 .66224 Mdot
.32408 .35532 Mdot
.35648 .55762 Mdot
.7111 .64869 Mdot
.57232 .42109 Mdot
.51752 .69073 Mdot
.40832 .643 Mdot
.66951 .4531 Mdot
.41616 .38229 Mdot
.35188 .73947 Mdot
.38356 .41913 Mdot
.52409 .63883 Mdot
.18686 .59183 Mdot
.63704 .57193 Mdot
.52909 .62529 Mdot
.80053 .63501 Mdot
.4904 .68175 Mdot
.58806 .45371 Mdot
.62197 .42079 Mdot
.47521 .6561 Mdot
.64677 .62 Mdot
.71253 .26453 Mdot
.54289 .68919 Mdot
.37137 .40832 Mdot
.27352 .69055 Mdot
.47426 .15781 Mdot
.40149 .58291 Mdot
.34227 .59125 Mdot
.60532 .48519 Mdot
.58985 .46855 Mdot
.33864 .53722 Mdot
.31679 .54994 Mdot
.63835 .56563 Mdot
.52741 .67355 Mdot
.35548 .43017 Mdot
.35645 .52323 Mdot
.3581 .44806 Mdot
.66519 .68002 Mdot
.57098 .47571 Mdot
.20175 .46534 Mdot
.62362 .38582 Mdot
.72903 .59466 Mdot
.37 .56148 Mdot
.56996 .36637 Mdot
.53073 .44703 Mdot
.32854 .55083 Mdot
.64618 .58012 Mdot
.42483 .60772 Mdot
.50949 .6617 Mdot
.77396 .72274 Mdot
.52913 .40896 Mdot
.59952 .45472 Mdot
.3373 .5508 Mdot
.57223 .72881 Mdot
.36626 .39849 Mdot
.36824 .42128 Mdot
.47822 .64701 Mdot
.40052 .47459 Mdot
.58375 .45977 Mdot
.54822 .42121 Mdot
.50947 .6535 Mdot
.53818 .66176 Mdot
.38838 .73981 Mdot
.61399 .4297 Mdot
.34323 .5623 Mdot
.60526 .5671 Mdot
.36892 .55647 Mdot
.5744 .36961 Mdot
.60323 .45244 Mdot
.63033 .42841 Mdot
.55257 .37226 Mdot
.314 .55982 Mdot
.59449 .36672 Mdot
.53559 .36424 Mdot
.37766 .39979 Mdot
.58903 .37885 Mdot
.45219 .41831 Mdot
.5659 .43384 Mdot
.64774 .58278 Mdot
.49795 .20754 Mdot
.5597 .38821 Mdot
.60299 .46003 Mdot
.54526 .67074 Mdot
.56476 .41334 Mdot
.3213 .55723 Mdot
.35274 .38629 Mdot
.33566 .55642 Mdot
.32694 .57199 Mdot
.46221 .65815 Mdot
.61582 .58654 Mdot
.63964 .40778 Mdot
.66367 .58302 Mdot
.55397 .47746 Mdot
.53582 .41301 Mdot
.69351 .66014 Mdot
.19932 .34706 Mdot
.56931 .19974 Mdot
.57258 .42311 Mdot
.48553 .68264 Mdot
.48824 .6888 Mdot
.60722 .51422 Mdot
.53656 .4451 Mdot
.36238 .53606 Mdot
.3325 .58258 Mdot
.71599 .34036 Mdot
.78193 .44517 Mdot
.64755 .58211 Mdot
.48466 .55086 Mdot
.53695 .43601 Mdot
.5644 .36841 Mdot
.52927 .40013 Mdot
.46716 .6616 Mdot
.47981 .42855 Mdot
.53391 .63229 Mdot
.24372 .56071 Mdot
.34988 .54432 Mdot
.57046 .38341 Mdot
.20327 .50647 Mdot
.37086 .35684 Mdot
.35184 .38532 Mdot
.34353 .52356 Mdot
.45221 .64245 Mdot
.69662 .27984 Mdot
.50335 .85412 Mdot
.30689 .36517 Mdot
.67361 .58626 Mdot
.54349 .42154 Mdot
.48586 .67081 Mdot
.33611 .36119 Mdot
.67265 .58545 Mdot
.55715 .38051 Mdot
.64175 .6713 Mdot
.57454 .42918 Mdot
.23555 .43443 Mdot
.33632 .39094 Mdot
.65373 .80241 Mdot
.35562 .34233 Mdot
.38003 .60415 Mdot
.35827 .53889 Mdot
.61518 .43628 Mdot
.32843 .30587 Mdot
.39313 .41024 Mdot
.45151 .59944 Mdot
.61836 .58664 Mdot
.3338 .63978 Mdot
.6315 .58006 Mdot
.4874 .64789 Mdot
.64395 .57336 Mdot
.49707 .64857 Mdot
.67529 .27324 Mdot
.32407 .42103 Mdot
.64417 .60431 Mdot
.40609 .63327 Mdot
.59444 .47007 Mdot
.66798 .60745 Mdot
.54297 .36475 Mdot
.66373 .45015 Mdot
.51197 .65449 Mdot
.62035 .58857 Mdot
.55386 .37699 Mdot
.8249 .48647 Mdot
.37654 .58631 Mdot
.36105 .53653 Mdot
.54151 .36666 Mdot
.47291 .68633 Mdot
.31786 .37498 Mdot
.60719 .80511 Mdot
.38067 .5452 Mdot
.61987 .43268 Mdot
.62249 .44477 Mdot
.39126 .41371 Mdot
.18568 .52121 Mdot
.60873 .44488 Mdot
.61593 .33372 Mdot
.6157 .42907 Mdot
.38051 .56861 Mdot
.36629 .41686 Mdot
.35164 .37776 Mdot
.50658 .62999 Mdot
.3777 .35662 Mdot
.6345 .51102 Mdot
.21921 .51741 Mdot
.65256 .37555 Mdot
.36028 .5619 Mdot
.24242 .53655 Mdot
.24117 .56346 Mdot
.8004 .61375 Mdot
.40189 .36295 Mdot
.61009 .36709 Mdot
.38692 .35969 Mdot
.63372 .58218 Mdot
.34254 .37361 Mdot
.33873 .34656 Mdot
.55244 .4064 Mdot
.58358 .38473 Mdot
.48276 .65738 Mdot
.34483 .45926 Mdot
.3964 .3778 Mdot
.61968 .39636 Mdot
.61172 .46634 Mdot
.53841 .39289 Mdot
.48115 .58943 Mdot
.37925 .41324 Mdot
.28075 .73353 Mdot
.73633 .42297 Mdot
.39606 .37822 Mdot
.73267 .24829 Mdot
.3982 .64803 Mdot
.46415 .69763 Mdot
.4296 .59111 Mdot
.61671 .42385 Mdot
.52702 .69111 Mdot
.57617 .38589 Mdot
.20271 .46594 Mdot
.56413 .4058 Mdot
.65105 .58244 Mdot
.53258 .40921 Mdot
.48494 .62837 Mdot
.51917 .66885 Mdot
.61665 .44297 Mdot
.5645 .39017 Mdot
.63491 .23177 Mdot
.31246 .34446 Mdot
.34887 .38831 Mdot
.58227 .66392 Mdot
.63922 .60694 Mdot
.34963 .53929 Mdot
.586 .4103 Mdot
.46337 .65933 Mdot
.51843 .67186 Mdot
.39049 .40914 Mdot
.51917 .64279 Mdot
.36879 .57677 Mdot
.57441 .41719 Mdot
.34461 .53444 Mdot
.64812 .56829 Mdot
.37064 .4156 Mdot
.58611 .37983 Mdot
.58818 .44249 Mdot
.34908 .39673 Mdot
.62577 .37224 Mdot
.64835 .61854 Mdot
.49578 .68492 Mdot
.3617 .41083 Mdot
.35762 .57796 Mdot
.48955 .64792 Mdot
.60459 .3749 Mdot
.24927 .27906 Mdot
.58225 .45121 Mdot
.61738 .41029 Mdot
.82327 .61115 Mdot
.53346 .42987 Mdot
.51991 .67615 Mdot
.33833 .35727 Mdot
.50645 .37841 Mdot
.74227 .47902 Mdot
.69342 .82032 Mdot
.53108 .62919 Mdot
.54558 .4279 Mdot
.80952 .56337 Mdot
.55 .43144 Mdot
.44229 .35263 Mdot
.5164 .70776 Mdot
.50558 .50947 Mdot
.56544 .36112 Mdot
.35415 .58888 Mdot
.47918 .66051 Mdot
.50041 .64532 Mdot
.25454 .66496 Mdot
.54983 .41121 Mdot
.44871 .55993 Mdot
.56647 .37503 Mdot
.35763 .58111 Mdot
.72964 .37407 Mdot
.5204 .66911 Mdot
.41413 .18805 Mdot
.61099 .42195 Mdot
.39221 .39893 Mdot
.54521 .63964 Mdot
.30088 .60933 Mdot
.60763 .37952 Mdot
.66629 .59612 Mdot
.33901 .5159 Mdot
.62279 .35205 Mdot
.36282 .5655 Mdot
.60087 .37558 Mdot
.51689 .35198 Mdot
.27542 .30706 Mdot
.33513 .37971 Mdot
.35653 .59915 Mdot
.51217 .57381 Mdot
.59772 .36531 Mdot
.36292 .40999 Mdot
.37602 .39632 Mdot
.65238 .56936 Mdot
.50983 .5393 Mdot
.28534 .44069 Mdot
.49587 .3291 Mdot
.26451 .67792 Mdot
.54546 .64945 Mdot
.45586 .74681 Mdot
.61163 .40185 Mdot
.59456 .57564 Mdot
.3217 .56238 Mdot
.57808 .45129 Mdot
.55081 .22991 Mdot
.37271 .36099 Mdot
.58493 .44829 Mdot
.65101 .593 Mdot
.58004 .61424 Mdot
.60499 .56347 Mdot
.74059 .64704 Mdot
.49106 .66414 Mdot
.53011 .36964 Mdot
.53176 .34575 Mdot
.49619 .69645 Mdot
.62412 .45289 Mdot
.51528 .6889 Mdot
.36433 .78289 Mdot
.67209 .60323 Mdot
.38018 .41061 Mdot
.37433 .63438 Mdot
.63635 .42616 Mdot
.59193 .46512 Mdot
.61695 .57698 Mdot
.5922 .42938 Mdot
.25795 .30482 Mdot
.48951 .58875 Mdot
.49295 .63963 Mdot
.33305 .37816 Mdot
.62344 .44993 Mdot
.53014 .56268 Mdot
.55708 .43826 Mdot
.58556 .28474 Mdot
.60524 .45959 Mdot
.30945 .45609 Mdot
.33874 .38843 Mdot
.36312 .55984 Mdot
.58132 .36322 Mdot
.57079 .40257 Mdot
.77143 .49268 Mdot
.58021 .4871 Mdot
.57965 .36493 Mdot
.42479 .3865 Mdot
.33063 .36549 Mdot
.32882 .39236 Mdot
.51388 .62384 Mdot
.77584 .40328 Mdot
.34867 .56031 Mdot
.49561 .40473 Mdot
.37329 .53899 Mdot
.39382 .30861 Mdot
.67374 .5901 Mdot
.7773 .60868 Mdot
.59717 .40369 Mdot
.34764 .36109 Mdot
.61474 .78075 Mdot
.34048 .41339 Mdot
.46813 .54103 Mdot
.33787 .56943 Mdot
.37897 .36854 Mdot
.57825 .4001 Mdot
.40781 .45851 Mdot
.81179 .5367 Mdot
.34702 .554 Mdot
.57302 .48262 Mdot
.50926 .61961 Mdot
.62841 .64912 Mdot
.31308 .2483 Mdot
.37786 .58448 Mdot
.388 .61207 Mdot
.54815 .41258 Mdot
.3643 .35379 Mdot
.35758 .58707 Mdot
.37858 .56408 Mdot
.5174 .64001 Mdot
.58755 .38452 Mdot
.5927 .38567 Mdot
.52394 .63644 Mdot
.33618 .55481 Mdot
.5278 .37679 Mdot
.63154 .35441 Mdot
.82758 .41098 Mdot
.30203 .43302 Mdot
.77895 .72309 Mdot
.60956 .51773 Mdot
.50137 .22341 Mdot
.60681 .80926 Mdot
.39727 .38751 Mdot
.54364 .40012 Mdot
.64683 .38901 Mdot
.49266 .62988 Mdot
.56359 .42217 Mdot
.48974 .70842 Mdot
.33149 .5699 Mdot
.7789 .3266 Mdot
.26454 .50576 Mdot
.41545 .81157 Mdot
.56205 .42072 Mdot
.42164 .41042 Mdot
.63509 .5882 Mdot
.39577 .60046 Mdot
.34878 .41297 Mdot
.54176 .37928 Mdot
.63043 .22917 Mdot
.53122 .62735 Mdot
.38579 .38402 Mdot
.68508 .24769 Mdot
.51529 .50013 Mdot
.58009 .37039 Mdot
.52587 .62973 Mdot
.65932 .76561 Mdot
.29171 .36074 Mdot
.38729 .56328 Mdot
.64673 .57924 Mdot
.47663 .66361 Mdot
.33367 .58543 Mdot
.37842 .43137 Mdot
.37943 .37649 Mdot
.31741 .38404 Mdot
.55335 .20438 Mdot
.53387 .69153 Mdot
.63553 .59203 Mdot
.79284 .49206 Mdot
.77946 .4661 Mdot
.65395 .58602 Mdot
.47497 .63586 Mdot
.33208 .36418 Mdot
.36923 .36383 Mdot
.35342 .38654 Mdot
.50277 .1794 Mdot
.39345 .3608 Mdot
.21298 .61569 Mdot
.54216 .38604 Mdot
.63768 .35267 Mdot
.54636 .42652 Mdot
.35521 .53293 Mdot
.34688 .3998 Mdot
.43371 .46141 Mdot
.53763 .46332 Mdot
.77468 .58347 Mdot
.58232 .45434 Mdot
.3523 .60924 Mdot
.59395 .44634 Mdot
.19349 .4307 Mdot
.39059 .36329 Mdot
.56917 .42281 Mdot
.33404 .59385 Mdot
.63486 .60688 Mdot
.41758 .38401 Mdot
.5799 .38111 Mdot
.39887 .76736 Mdot
.53155 .42145 Mdot
.41702 .80503 Mdot
.26416 .3747 Mdot
.67384 .58747 Mdot
.22461 .41003 Mdot
.51185 .61269 Mdot
.62054 .33922 Mdot
.54251 .47875 Mdot
.35344 .55285 Mdot
.35164 .6403 Mdot
.49892 .67137 Mdot
.48095 .44273 Mdot
.57864 .34113 Mdot
.65551 .56895 Mdot
.29632 .36938 Mdot
.33489 .53867 Mdot
.61987 .45813 Mdot
.54111 .45577 Mdot
.24529 .61365 Mdot
.55833 .35056 Mdot
.61634 .45366 Mdot
.61792 .56866 Mdot
.21157 .59734 Mdot
.56992 .43597 Mdot
.47664 .54455 Mdot
.31144 .3731 Mdot
.51286 .44002 Mdot
.20471 .60157 Mdot
.62287 .41758 Mdot
.38637 .37705 Mdot
.65104 .35442 Mdot
.27054 .42844 Mdot
.61587 .58916 Mdot
.60398 .46033 Mdot
.16735 .4991 Mdot
.60547 .42879 Mdot
.34761 .56417 Mdot
.54023 .44863 Mdot
.4957 .6535 Mdot
.56933 .19481 Mdot
.49878 .63093 Mdot
.56552 .45545 Mdot
.35663 .38736 Mdot
.34177 .54719 Mdot
.44613 .19124 Mdot
.60947 .68052 Mdot
.20705 .57614 Mdot
.51931 .84077 Mdot
.61997 .59531 Mdot
.6576 .63154 Mdot
.3264 .54556 Mdot
.56932 .42482 Mdot
.20804 .641 Mdot
.59981 .48512 Mdot
.57775 .44469 Mdot
.5642 .4044 Mdot
.74851 .60117 Mdot
.32969 .57289 Mdot
.51635 .65789 Mdot
.60612 .44883 Mdot
.58922 .36572 Mdot
.39565 .39023 Mdot
.64631 .61124 Mdot
.49892 .69557 Mdot
.65486 .60311 Mdot
.48073 .66516 Mdot
.75299 .2834 Mdot
.51823 .41522 Mdot
.62979 .60197 Mdot
.34341 .51776 Mdot
.39213 .38191 Mdot
.2219 .51236 Mdot
.49476 .64494 Mdot
.50646 .62534 Mdot
.61371 .45045 Mdot
.38664 .37345 Mdot
.32545 .35708 Mdot
.62888 .58547 Mdot
.37449 .57429 Mdot
.55886 .38892 Mdot
.53541 .42405 Mdot
.60801 .31709 Mdot
.46408 .67447 Mdot
.22879 .43795 Mdot
.45664 .75851 Mdot
.57174 .42527 Mdot
.35389 .347 Mdot
.56191 .39522 Mdot
.51495 .80111 Mdot
.37183 .35557 Mdot
.62343 .41077 Mdot
.6889 .21975 Mdot
.44596 .66591 Mdot
.25589 .45663 Mdot
.62651 .43227 Mdot
.58795 .83566 Mdot
.6062 .40261 Mdot
.79222 .33195 Mdot
.60669 .76193 Mdot
.5652 .45931 Mdot
.61308 .3821 Mdot
.45534 .31141 Mdot
.54038 .42496 Mdot
.52033 .63262 Mdot
.74551 .32507 Mdot
.32374 .39637 Mdot
.26871 .6046 Mdot
.51161 .21059 Mdot
.61817 .59936 Mdot
.47812 .64731 Mdot
.49185 .72236 Mdot
.65822 .59331 Mdot
.35951 .38219 Mdot
.57895 .42697 Mdot
.42676 .4889 Mdot
.47314 .68344 Mdot
.56935 .51227 Mdot
.34688 .56605 Mdot
.36739 .6883 Mdot
.5675 .59654 Mdot
.36512 .56992 Mdot
.59263 .37932 Mdot
.44131 .30854 Mdot
.64267 .26847 Mdot
.73895 .73147 Mdot
.33785 .59122 Mdot
.34636 .55217 Mdot
.53638 .18283 Mdot
.67289 .57454 Mdot
.25715 .6248 Mdot
.31432 .46247 Mdot
.34406 .54194 Mdot
.29805 .3437 Mdot
.53455 .64622 Mdot
.32221 .59528 Mdot
.50793 .39348 Mdot
.53885 .40142 Mdot
.57599 .40114 Mdot
.37412 .56487 Mdot
.65624 .47322 Mdot
.29761 .293 Mdot
.3583 .5508 Mdot
.59625 .49573 Mdot
.48621 .50755 Mdot
.44383 .71135 Mdot
.52547 .65206 Mdot
.61935 .58045 Mdot
.68418 .60559 Mdot
.38587 .40229 Mdot
.61741 .58327 Mdot
.58241 .6036 Mdot
.59064 .42271 Mdot
.36376 .54996 Mdot
.35082 .65112 Mdot
.3514 .57756 Mdot
.65616 .59609 Mdot
.65299 .56381 Mdot
.37681 .39986 Mdot
.34506 .38299 Mdot
.47644 .2442 Mdot
.70268 .44541 Mdot
.56298 .44619 Mdot
.68328 .69969 Mdot
.33375 .34848 Mdot
.57729 .51635 Mdot
.61868 .57947 Mdot
.63891 .60827 Mdot
.76952 .51133 Mdot
.59361 .40131 Mdot
.3888 .32529 Mdot
.59033 .40449 Mdot
.72565 .38997 Mdot
.62826 .39478 Mdot
.51807 .64059 Mdot
.59726 .39514 Mdot
.7742 .52295 Mdot
.64265 .40112 Mdot
.58322 .47028 Mdot
.46555 .66088 Mdot
.60927 .34402 Mdot
.49722 .65474 Mdot
.56316 .45206 Mdot
.67362 .61436 Mdot
.47946 .64186 Mdot
.73624 .49891 Mdot
.76409 .53343 Mdot
.47491 .63413 Mdot
.66397 .57936 Mdot
.63742 .62059 Mdot
.73109 .53924 Mdot
.34937 .41338 Mdot
.5689 .49543 Mdot
.56663 .42506 Mdot
.53946 .64789 Mdot
.33508 .58327 Mdot
.6146 .38037 Mdot
.60648 .46647 Mdot
.62927 .41173 Mdot
.38701 .40236 Mdot
.59207 .67021 Mdot
.62602 .59629 Mdot
.52721 .63796 Mdot
.58084 .5427 Mdot
.47834 .69155 Mdot
.55 .46179 Mdot
.64537 .38835 Mdot
.53169 .2201 Mdot
.42642 .68564 Mdot
.49998 .17321 Mdot
.38035 .37825 Mdot
.48639 .68884 Mdot
.68143 .59835 Mdot
.6498 .40457 Mdot
.34765 .35925 Mdot
.4964 .65127 Mdot
.57471 .42835 Mdot
.58975 .48379 Mdot
.22936 .55412 Mdot
.64475 .51142 Mdot
.75341 .52206 Mdot
.50144 .62326 Mdot
.51124 .61626 Mdot
.7643 .56144 Mdot
.61626 .61992 Mdot
.42319 .45971 Mdot
.55285 .42063 Mdot
.66548 .59614 Mdot
.33803 .36002 Mdot
.57429 .21771 Mdot
.37043 .54865 Mdot
.3367 .45474 Mdot
.56359 .41992 Mdot
.53164 .52219 Mdot
.35825 .38953 Mdot
.65062 .59026 Mdot
.37364 .56149 Mdot
.67305 .62863 Mdot
.47097 .67473 Mdot
.43398 .83552 Mdot
.60041 .43096 Mdot
.60985 .45486 Mdot
.36004 .60708 Mdot
.36215 .35708 Mdot
.61334 .59572 Mdot
.28207 .70013 Mdot
.50689 .64109 Mdot
.19628 .62047 Mdot
.35323 .34817 Mdot
.49994 .34837 Mdot
.53081 .65116 Mdot
.35441 .52531 Mdot
.72726 .5202 Mdot
.36906 .57067 Mdot
.57501 .45706 Mdot
.34997 .3669 Mdot
.35366 .59654 Mdot
.30661 .42632 Mdot
.82245 .54536 Mdot
.50096 .34549 Mdot
.58695 .41904 Mdot
.82059 .44218 Mdot
.39628 .78457 Mdot
.30685 .35029 Mdot
.3235 .57025 Mdot
.57798 .45237 Mdot
.59827 .46372 Mdot
.60494 .43127 Mdot
.34182 .58669 Mdot
.69007 .68645 Mdot
.51148 .65135 Mdot
.54602 .41864 Mdot
.64059 .56525 Mdot
.4983 .66159 Mdot
.35443 .63179 Mdot
.52403 .65582 Mdot
.39129 .35197 Mdot
.5601 .46868 Mdot
.28506 .59894 Mdot
.70646 .20192 Mdot
.34052 .55487 Mdot
.46331 .65155 Mdot
.52071 .41245 Mdot
.38839 .67254 Mdot
.32693 .37932 Mdot
.50714 .63929 Mdot
.59754 .45505 Mdot
.40317 .62729 Mdot
.59701 .21446 Mdot
.52301 .66102 Mdot
.3471 .35818 Mdot
.7446 .72063 Mdot
.56042 .42723 Mdot
.60528 .41143 Mdot
.37529 .37039 Mdot
.38153 .2689 Mdot
.63213 .20912 Mdot
.56377 .39191 Mdot
.36398 .55912 Mdot
.33172 .79972 Mdot
.60445 .46787 Mdot
.74193 .39685 Mdot
.48042 .6582 Mdot
.30875 .58364 Mdot
.25537 .4182 Mdot
.64882 .41409 Mdot
.26651 .65711 Mdot
.39833 .61033 Mdot
.80981 .46913 Mdot
.48654 .70577 Mdot
.52283 .75641 Mdot
.79671 .4107 Mdot
.33094 .59298 Mdot
.42169 .42887 Mdot
.27782 .67546 Mdot
.3839 .22932 Mdot
.69757 .74875 Mdot
.55803 .75242 Mdot
.63038 .2276 Mdot
.44142 .4866 Mdot
.48352 .67702 Mdot
.55939 .51944 Mdot
.57607 .38414 Mdot
.40428 .78819 Mdot
.27187 .33194 Mdot
.28032 .31886 Mdot
.82234 .44458 Mdot
.45522 .35741 Mdot
.8095 .55606 Mdot
.80766 .61338 Mdot
.68081 .33798 Mdot
.47829 .75076 Mdot
.19699 .6284 Mdot
.73241 .28872 Mdot
.28753 .72572 Mdot
.64604 .35984 Mdot
.45873 .54222 Mdot
.46886 .81897 Mdot
.37521 .43666 Mdot
.32953 .2876 Mdot
.50665 .632 Mdot
.33387 .40444 Mdot
.26924 .64167 Mdot
.38755 .41786 Mdot
.26735 .42374 Mdot
.759 .71311 Mdot
.82131 .5542 Mdot
.17694 .5038 Mdot
.60645 .81927 Mdot
.53748 .23008 Mdot
.1375 .56546 Mdot
.50771 .70348 Mdot
.3963 .40257 Mdot
.73726 .59194 Mdot
.78264 .5142 Mdot
.25878 .55238 Mdot
.31684 .72454 Mdot
.66545 .66124 Mdot
.68451 .50797 Mdot
.35593 .3744 Mdot
.23221 .40806 Mdot
.33726 .61633 Mdot
.26102 .51454 Mdot
.73157 .30351 Mdot
.75057 .68483 Mdot
.42074 .49351 Mdot
.32625 .71664 Mdot
.39731 .7037 Mdot
.33649 .24097 Mdot
.73665 .44517 Mdot
.57996 .52012 Mdot
.30057 .43686 Mdot
.57979 .81357 Mdot
.39961 .23868 Mdot
.71726 .38391 Mdot
.78514 .49855 Mdot
.72982 .26602 Mdot
.47805 .79596 Mdot
.54689 .14071 Mdot
.36666 .42615 Mdot
.62262 .44604 Mdot
.41087 .2662 Mdot
.16523 .52126 Mdot
.64313 .55933 Mdot
.73138 .66299 Mdot
.62389 .57864 Mdot
.36549 .34143 Mdot
.60193 .20565 Mdot
.20586 .59578 Mdot
.15922 .55175 Mdot
.66802 .62362 Mdot
.4968 .39486 Mdot
.5338 .88784 Mdot
.79748 .53798 Mdot
.25259 .48587 Mdot
.81847 .39475 Mdot
.48362 .4856 Mdot
.27761 .3636 Mdot
.34892 .59482 Mdot
.7954 .39113 Mdot
.3626 .36463 Mdot
.55596 .13049 Mdot
.78799 .32279 Mdot
.57457 .22891 Mdot
.9237 .53262 Mdot
.75552 .58208 Mdot
.51004 .51136 Mdot
.39409 .53876 Mdot
.72064 .47226 Mdot
.31252 .27699 Mdot
.70396 .58849 Mdot
.3908 .68026 Mdot
.5678 .85012 Mdot
.81214 .44194 Mdot
.1696 .57935 Mdot
.38033 .80826 Mdot
.37181 .24355 Mdot
.52411 .56177 Mdot
.50472 .44752 Mdot
.56686 .61389 Mdot
.72175 .69834 Mdot
.73437 .26134 Mdot
.73858 .42434 Mdot
.68383 .82807 Mdot
.6092 .59048 Mdot
.64727 .69139 Mdot
.79269 .68319 Mdot
.69747 .51655 Mdot
.25002 .39261 Mdot
.75658 .38795 Mdot
.49197 .44232 Mdot
.59345 .54947 Mdot
.73083 .67661 Mdot
.2306 .4676 Mdot
.75901 .34554 Mdot
.64651 .78473 Mdot
.24359 .61032 Mdot
.49619 .30937 Mdot
.77164 .43572 Mdot
.39727 .42 Mdot
.68131 .47511 Mdot
.2573 .4071 Mdot
.83424 .5316 Mdot
.34157 .6078 Mdot
.84953 .52938 Mdot
.63811 .21491 Mdot
.51755 .40173 Mdot
.60715 .4867 Mdot
.42724 .36383 Mdot
.68788 .47558 Mdot
.59533 .33799 Mdot
.23349 .5717 Mdot
.82607 .57748 Mdot
.62636 .27434 Mdot
.39791 .62108 Mdot
.35706 .6401 Mdot
.78652 .69598 Mdot
.43752 .27129 Mdot
.62395 .62732 Mdot
.72259 .32146 Mdot
.33177 .25152 Mdot
.50448 .66954 Mdot
.17446 .58034 Mdot
.36902 .52851 Mdot
.59021 .21822 Mdot
.49094 .33319 Mdot
.457 .21416 Mdot
.82654 .57786 Mdot
.52973 .74551 Mdot
.6229 .21385 Mdot
.69427 .53877 Mdot
.24392 .6884 Mdot
.43971 .70468 Mdot
.62255 .35806 Mdot
.33641 .73524 Mdot
.64957 .6205 Mdot
.47691 .27569 Mdot
.29759 .76138 Mdot
.59348 .7263 Mdot
.57722 .3496 Mdot
.57307 .22536 Mdot
.4464 .68549 Mdot
.40174 .46205 Mdot
.42721 .16107 Mdot
.58452 .47492 Mdot
.7918 .47684 Mdot
.45681 .78676 Mdot
.71443 .45315 Mdot
.68751 .77687 Mdot
.54158 .80345 Mdot
.58799 .15098 Mdot
.81266 .40412 Mdot
.59867 .68215 Mdot
.79285 .41369 Mdot
.83298 .48168 Mdot
.58467 .15531 Mdot
.5792 .49288 Mdot
.38074 .60528 Mdot
.23698 .27788 Mdot
.52687 .6543 Mdot
.7893 .5287 Mdot
.26408 .67761 Mdot
.55403 .59983 Mdot
.43381 .38627 Mdot
.50598 .47397 Mdot
.44183 .49352 Mdot
.31453 .34495 Mdot
.59064 .33808 Mdot
.49841 .15857 Mdot
.64408 .17938 Mdot
.53352 .14852 Mdot
.52759 .82792 Mdot
.78472 .37784 Mdot
.53385 .53306 Mdot
.17639 .52424 Mdot
.58936 .51216 Mdot
.54978 .38128 Mdot
.66865 .63759 Mdot
.75207 .58746 Mdot
.54343 .21095 Mdot
.28468 .50664 Mdot
.30119 .3875 Mdot
.73031 .67009 Mdot
.23902 .77214 Mdot
.49887 .24305 Mdot
.2205 .63787 Mdot
.62506 .63671 Mdot
.70377 .44975 Mdot
.70664 .702 Mdot
.49854 .20435 Mdot
.81642 .61412 Mdot
.31412 .34679 Mdot
.28334 .71538 Mdot
.58841 .74806 Mdot
.40994 .44203 Mdot
.59718 .66752 Mdot
.80306 .57893 Mdot
.27413 .60459 Mdot
.46803 .19613 Mdot
.31877 .47899 Mdot
.41019 .25583 Mdot
.46549 .60049 Mdot
.37549 .70103 Mdot
.27594 .73129 Mdot
.52493 .78664 Mdot
.73273 .38855 Mdot
.47922 .50844 Mdot
.21435 .4194 Mdot
.41233 .60233 Mdot
.73134 .39889 Mdot
.45259 .42227 Mdot
.78638 .42916 Mdot
.58069 .10017 Mdot
.42537 .17686 Mdot
.75074 .73679 Mdot
.68969 .70246 Mdot
.59787 .34726 Mdot
.80662 .63946 Mdot
.50804 .13782 Mdot
.7452 .24569 Mdot
.35678 .70815 Mdot
.48405 .70084 Mdot
.36624 .53372 Mdot
.53427 .16642 Mdot
.68713 .68324 Mdot
.78069 .66181 Mdot
.75626 .42629 Mdot
.33329 .52559 Mdot
.18565 .36292 Mdot
.72985 .27162 Mdot
.5026 .33509 Mdot
.64611 .50828 Mdot
.60652 .35802 Mdot
.2335 .36658 Mdot
.38495 .41755 Mdot
.43899 .73376 Mdot
.70565 .43309 Mdot
.51041 .67509 Mdot
.72233 .6106 Mdot
.32993 .73638 Mdot
.53288 .40856 Mdot
.51618 .56917 Mdot
.413 .38213 Mdot
.43196 .69903 Mdot
.23612 .52261 Mdot
.71263 .2239 Mdot
.62029 .6386 Mdot
.55961 .36273 Mdot
.71952 .44571 Mdot
.59626 .6604 Mdot
.61346 .19653 Mdot
.32478 .54564 Mdot
.82257 .47451 Mdot
.43395 .51727 Mdot
.68553 .46773 Mdot
.29412 .32286 Mdot
.64987 .46794 Mdot
.57785 .46477 Mdot
.57681 .80067 Mdot
.58923 .27534 Mdot
.36745 .46951 Mdot
.50524 .39362 Mdot
.594 .50731 Mdot
.80093 .64918 Mdot
.57982 .61106 Mdot
.37911 .6918 Mdot
.82604 .50164 Mdot
.34271 .5818 Mdot
.38482 .35842 Mdot
.65033 .54411 Mdot
.30813 .73732 Mdot
.6285 .30192 Mdot
.59519 .21366 Mdot
.55896 .59125 Mdot
.6055 .71562 Mdot
.82714 .51819 Mdot
.81773 .48173 Mdot
.20377 .39073 Mdot
.30124 .35427 Mdot
.69191 .38028 Mdot
.30092 .73753 Mdot
.3266 .36758 Mdot
.22743 .60141 Mdot
.22357 .58417 Mdot
.76308 .30398 Mdot
.49963 .57379 Mdot
.57867 .84687 Mdot
.75075 .51718 Mdot
.71909 .66473 Mdot
.44296 .19056 Mdot
.26268 .71084 Mdot
.7896 .57998 Mdot
.31029 .33856 Mdot
.45653 .32576 Mdot
.64914 .36897 Mdot
.19504 .47804 Mdot
.23037 .29871 Mdot
.65011 .54687 Mdot
.44901 .40289 Mdot
.65258 .78285 Mdot
.58579 .43249 Mdot
.39127 .18483 Mdot
.31141 .72879 Mdot
.52457 .18047 Mdot
.34373 .52123 Mdot
.58498 .37365 Mdot
.63706 .42935 Mdot
.74528 .35494 Mdot
.26588 .43055 Mdot
.78045 .4154 Mdot
.34403 .80151 Mdot
.67958 .74987 Mdot
.29883 .32052 Mdot
.78755 .518 Mdot
.75135 .68845 Mdot
.41493 .79089 Mdot
.49565 .53483 Mdot
.71113 .63409 Mdot
.70942 .51545 Mdot
.59122 .82267 Mdot
.44545 .43169 Mdot
.41817 .55851 Mdot
.25119 .57685 Mdot
.46897 .76872 Mdot
.51805 .19473 Mdot
.60501 .38221 Mdot
.68549 .24815 Mdot
.79464 .63316 Mdot
.22091 .37263 Mdot
.28813 .27982 Mdot
.43463 .1721 Mdot
.555 .2876 Mdot
.49668 .78365 Mdot
.37951 .77271 Mdot
.25372 .72254 Mdot
.43093 .51925 Mdot
.76284 .6033 Mdot
.70135 .52826 Mdot
.82693 .51202 Mdot
.36461 .60808 Mdot
.30729 .4679 Mdot
.36136 .64222 Mdot
.78858 .4157 Mdot
.43816 .28304 Mdot
.80867 .58982 Mdot
.4695 .47641 Mdot
.5943 .1502 Mdot
.54451 .79002 Mdot
.45197 .48364 Mdot
.4725 .6733 Mdot
.54271 .7407 Mdot
.75749 .64599 Mdot
.5591 .78074 Mdot
.25147 .68918 Mdot
.45475 .68147 Mdot
.60419 .53077 Mdot
.46463 .37309 Mdot
.66882 .48527 Mdot
.57269 .80335 Mdot
.71913 .4465 Mdot
.82107 .56777 Mdot
.75414 .35538 Mdot
.68143 .24662 Mdot
.7606 .57963 Mdot
.50479 .84548 Mdot
.25238 .48122 Mdot
.60613 .55351 Mdot
.31817 .73137 Mdot
.64872 .70539 Mdot
.31634 .33356 Mdot
.28047 .18708 Mdot
.43962 .83233 Mdot
.52257 .77815 Mdot
.73528 .26366 Mdot
.53956 .80965 Mdot
.42563 .68756 Mdot
.35603 .2673 Mdot
.31915 .44916 Mdot
.67198 .2595 Mdot
.56524 .4047 Mdot
.48958 .15224 Mdot
.69386 .44542 Mdot
.68736 .19872 Mdot
.77828 .67233 Mdot
.4374 .38319 Mdot
.5593 .46744 Mdot
.52651 .63417 Mdot
.44129 .55545 Mdot
.70309 .35051 Mdot
.41045 .29245 Mdot
.25966 .36654 Mdot
.41683 .62239 Mdot
.51356 .70021 Mdot
.58903 .65364 Mdot
.30816 .36194 Mdot
.69983 .67504 Mdot
.46542 .76388 Mdot
.51318 .60519 Mdot
.41038 .49381 Mdot
.72305 .41696 Mdot
.24917 .41736 Mdot
.5109 .33129 Mdot
.5046 .20295 Mdot
.2812 .60098 Mdot
.52258 .63996 Mdot
.51135 .32241 Mdot
.46683 .82301 Mdot
.65524 .771 Mdot
.72805 .25925 Mdot
.58405 .55721 Mdot
.42042 .31457 Mdot
.73662 .38566 Mdot
.29702 .28477 Mdot
.34277 .30122 Mdot
.42574 .66849 Mdot
.23355 .37237 Mdot
.34767 .28553 Mdot
.28152 .67088 Mdot
.77945 .32582 Mdot
.28635 .72304 Mdot
.29898 .73738 Mdot
.53527 .60006 Mdot
.62604 .32206 Mdot
.43069 .40566 Mdot
.74086 .50517 Mdot
.41285 .46183 Mdot
.1385 .5206 Mdot
.50309 .42177 Mdot
.11339 .48416 Mdot
.38109 .57542 Mdot
.34075 .2578 Mdot
.71137 .52419 Mdot
.48897 .51447 Mdot
.46511 .46005 Mdot
.52918 .79119 Mdot
.30333 .45334 Mdot
.465 .79618 Mdot
.29069 .30981 Mdot
.50731 .70454 Mdot
.36582 .81989 Mdot
.517 .85101 Mdot
.47348 .3185 Mdot
.52683 .41887 Mdot
.46313 .8362 Mdot
.48957 .70086 Mdot
.52973 .20626 Mdot
.6958 .7694 Mdot
.63262 .76828 Mdot
.46083 .39397 Mdot
.69752 .45765 Mdot
.76674 .59971 Mdot
.82892 .44638 Mdot
.22066 .33233 Mdot
.72652 .68004 Mdot
.36627 .60739 Mdot
.47574 .4892 Mdot
.78814 .61575 Mdot
.27623 .38609 Mdot
.34119 .6127 Mdot
.25814 .37859 Mdot
.12094 .5564 Mdot
.79185 .52786 Mdot
.78127 .4245 Mdot
.26903 .36567 Mdot
.35494 .34276 Mdot
.28466 .42909 Mdot
.24908 .39529 Mdot
.60776 .77724 Mdot
.43018 .81176 Mdot
.25172 .40161 Mdot
.19755 .66406 Mdot
.66427 .45007 Mdot
.49082 .7324 Mdot
.4412 .38052 Mdot
.66607 .3202 Mdot
.32834 .52774 Mdot
.70795 .28401 Mdot
.68929 .75073 Mdot
.38739 .59032 Mdot
.59071 .80082 Mdot
.33197 .7223 Mdot
.53135 .33153 Mdot
.61486 .30011 Mdot
.67307 .74529 Mdot
.43422 .29973 Mdot
.18991 .45197 Mdot
.59432 .22931 Mdot
.45793 .67467 Mdot
.71718 .73315 Mdot
.49318 .64178 Mdot
.55782 .51001 Mdot
.32456 .4445 Mdot
.70233 .5822 Mdot
.51284 .17337 Mdot
.62217 .60675 Mdot
.37957 .41646 Mdot
.22879 .30732 Mdot
.34047 .35222 Mdot
.51269 .15679 Mdot
.46404 .21154 Mdot
.24735 .35219 Mdot
.596 .69008 Mdot
.57754 .72282 Mdot
.14948 .60193 Mdot
.33318 .61893 Mdot
.56365 .61493 Mdot
.1987 .5225 Mdot
.39501 .40582 Mdot
.63926 .64697 Mdot
.46836 .65173 Mdot
.40512 .5116 Mdot
.2802 .63929 Mdot
.67128 .42401 Mdot
.36511 .43272 Mdot
.4058 .5033 Mdot
.69956 .3013 Mdot
.77933 .3505 Mdot
.51197 .69092 Mdot
.12878 .46489 Mdot
.5665 .46723 Mdot
.49411 .30309 Mdot
.82188 .60862 Mdot
.18296 .36898 Mdot
.56054 .68468 Mdot
.53179 .85728 Mdot
.60277 .36228 Mdot
.69157 .71544 Mdot
.36132 .37003 Mdot
.2892 .7217 Mdot
.63051 .57642 Mdot
.71366 .4615 Mdot
.38118 .56154 Mdot
.46353 .19643 Mdot
.55035 .70591 Mdot
.31708 .37896 Mdot
.66189 .73572 Mdot
.67884 .3369 Mdot
.37715 .50296 Mdot
.57479 .69351 Mdot
.47595 .32223 Mdot
.62499 .30504 Mdot
.32181 .41715 Mdot
.7873 .44355 Mdot
.31028 .75647 Mdot
.71904 .22528 Mdot
.42487 .37521 Mdot
.52728 .51132 Mdot
.24015 .59062 Mdot
.61817 .78805 Mdot
.20521 .48149 Mdot
.82894 .58878 Mdot
.71221 .40306 Mdot
.6583 .35341 Mdot
.72491 .39695 Mdot
.66093 .42757 Mdot
.4639 .51923 Mdot
.40706 .71485 Mdot
.26453 .32559 Mdot
.23449 .43623 Mdot
.37793 .25016 Mdot
.19802 .45139 Mdot
.77708 .43236 Mdot
.24932 .35636 Mdot
.46917 .62324 Mdot
.56156 .31488 Mdot
.39737 .57868 Mdot
.78597 .35413 Mdot
.82709 .5949 Mdot
.38804 .60916 Mdot
.62658 .6532 Mdot
.63523 .80538 Mdot
.61617 .4739 Mdot
.55912 .54364 Mdot
.6047 .4581 Mdot
.64026 .50134 Mdot
.16393 .40186 Mdot
.6158 .77991 Mdot
.55123 .35836 Mdot
.81103 .45357 Mdot
.80347 .42227 Mdot
.63348 .16525 Mdot
.21322 .65303 Mdot
.37369 .40339 Mdot
.58744 .16352 Mdot
.25654 .36782 Mdot
.83359 .45993 Mdot
.45053 .72255 Mdot
.841 .60751 Mdot
.45602 .32134 Mdot
.61281 .80175 Mdot
.34368 .27541 Mdot
.31581 .45498 Mdot
.46237 .78164 Mdot
.53972 .54446 Mdot
.35956 .67111 Mdot
.51403 .80633 Mdot
.32147 .80543 Mdot
.64652 .37597 Mdot
.3724 .75606 Mdot
.26854 .56719 Mdot
.72857 .72448 Mdot
.55631 .77058 Mdot
.53472 .43849 Mdot
.3451 .6427 Mdot
.50336 .18312 Mdot
.72832 .41849 Mdot
.57669 .52539 Mdot
.54691 .76984 Mdot
.645 .25415 Mdot
.72542 .37398 Mdot
.29128 .73254 Mdot
.46866 .32482 Mdot
.44324 .5433 Mdot
.6002 .36575 Mdot
.33871 .4239 Mdot
.62885 .61982 Mdot
.53839 .55106 Mdot
.5629 .45027 Mdot
.53141 .62204 Mdot
.37175 .49724 Mdot
.47636 .16532 Mdot
.23609 .46661 Mdot
.35146 .76436 Mdot
.402 .42393 Mdot
.28273 .54075 Mdot
.20712 .50208 Mdot
.40533 .19263 Mdot
.61455 .74653 Mdot
.73854 .42495 Mdot
.8039 .53237 Mdot
.7613 .35897 Mdot
.37511 .44328 Mdot
.67898 .21184 Mdot
.32191 .56465 Mdot
.51558 .34124 Mdot
.29852 .51023 Mdot
.58751 .63235 Mdot
.52346 .37121 Mdot
.61236 .80117 Mdot
.56512 .60332 Mdot
.77838 .52114 Mdot
.47853 .79858 Mdot
.68508 .41484 Mdot
.47048 .35551 Mdot
.81871 .46753 Mdot
.5318 .63078 Mdot
.34202 .77292 Mdot
.38396 .51652 Mdot
.55352 .76234 Mdot
.77378 .36634 Mdot
.74369 .27478 Mdot
.44655 .46417 Mdot
.70706 .50163 Mdot
.60962 .41487 Mdot
.27973 .73185 Mdot
.6091 .78559 Mdot
.48624 .41698 Mdot
.34995 .69325 Mdot
.37728 .35473 Mdot
.3891 .72742 Mdot
.4551 .54457 Mdot
.66664 .26362 Mdot
.41262 .39262 Mdot
.2384 .35824 Mdot
.66609 .62028 Mdot
.50173 .4963 Mdot
.53507 .35076 Mdot
.71549 .4889 Mdot
.16767 .59091 Mdot
.50738 .3838 Mdot
.73044 .68368 Mdot
.49028 .32731 Mdot
.28278 .70272 Mdot
.67055 .74325 Mdot
.41628 .65602 Mdot
.30323 .45106 Mdot
.58577 .30691 Mdot
.28019 .61477 Mdot
.62721 .42418 Mdot
.45114 .64926 Mdot
.32081 .38256 Mdot
.71555 .74099 Mdot
.57417 .28483 Mdot
.73445 .50046 Mdot
.48111 .58932 Mdot
.5871 .52185 Mdot
.38978 .53906 Mdot
.83657 .6066 Mdot
.30256 .4451 Mdot
.71018 .41975 Mdot
.50079 .57338 Mdot
.71418 .51975 Mdot
.4466 .22207 Mdot
.78332 .31113 Mdot
.34462 .27219 Mdot
.41534 .48241 Mdot
.333 .26438 Mdot
.51002 .78104 Mdot
.67865 .78632 Mdot
.7195 .38772 Mdot
.48039 .46995 Mdot
.61319 .56892 Mdot
.22453 .54874 Mdot
.45738 .59869 Mdot
.58524 .53233 Mdot
.41129 .51834 Mdot
.31341 .67043 Mdot
.29839 .55289 Mdot
.4911 .39676 Mdot
.77147 .56609 Mdot
.80985 .50702 Mdot
.27031 .68755 Mdot
.41447 .59941 Mdot
.49311 .74458 Mdot
.67281 .27791 Mdot
.84568 .6142 Mdot
.26913 .2677 Mdot
.60898 .41765 Mdot
.40502 .57419 Mdot
.6958 .49668 Mdot
.48996 .6263 Mdot
.23837 .41561 Mdot
.21383 .49937 Mdot
.37289 .59802 Mdot
.61667 .5345 Mdot
.7808 .48654 Mdot
.48051 .76893 Mdot
.66166 .50328 Mdot
.36562 .63491 Mdot
.45772 .16631 Mdot
.50137 .82863 Mdot
.62205 .78474 Mdot
.8782 .5395 Mdot
.4049 .54281 Mdot
.59409 .5015 Mdot
.44715 .2527 Mdot
.77963 .36347 Mdot
.7249 .44766 Mdot
.57138 .21156 Mdot
.39528 .6525 Mdot
.71641 .3884 Mdot
.32855 .32746 Mdot
.77834 .54315 Mdot
.38158 .72419 Mdot
.46102 .50444 Mdot
.5788 .72675 Mdot
.69176 .21387 Mdot
.45359 .36965 Mdot
.80794 .54289 Mdot
.46898 .18345 Mdot
.24041 .71274 Mdot
.79117 .37416 Mdot
.76219 .53494 Mdot
.59477 .76238 Mdot
.41544 .26655 Mdot
.4507 .42056 Mdot
.29299 .34892 Mdot
.53646 .20768 Mdot
.62809 .29314 Mdot
.63925 .67203 Mdot
.39666 .22916 Mdot
.73283 .38916 Mdot
.64117 .29017 Mdot
.47757 .46551 Mdot
.52175 .32266 Mdot
.61915 .65214 Mdot
.26801 .37777 Mdot
.43062 .43459 Mdot
.74492 .47504 Mdot
.50164 .32335 Mdot
.24767 .60528 Mdot
.53384 .80349 Mdot
.22933 .71509 Mdot
.67283 .7042 Mdot
.39573 .20206 Mdot
.54035 .38778 Mdot
.63802 .15242 Mdot
.47963 .78328 Mdot
.50627 .76284 Mdot
.44491 .80472 Mdot
.44663 .6935 Mdot
.62255 .48884 Mdot
.62739 .42341 Mdot
.75198 .64914 Mdot
.45895 .39173 Mdot
.5379 .22579 Mdot
.44358 .19744 Mdot
.7061 .45737 Mdot
.75459 .43107 Mdot
.74504 .51155 Mdot
.64275 .34518 Mdot
.35228 .35133 Mdot
.543 .14949 Mdot
.42736 .46841 Mdot
.48868 .42504 Mdot
.56033 .33252 Mdot
.4064 .2569 Mdot
.5932 .85196 Mdot
.42977 .37547 Mdot
.7624 .39965 Mdot
.45614 .34689 Mdot
.38701 .44682 Mdot
.20518 .46061 Mdot
.9121 .44787 Mdot
.68258 .16877 Mdot
.32046 .39042 Mdot
.21048 .62298 Mdot
.45583 .35271 Mdot
.7856 .41987 Mdot
.59624 .74564 Mdot
.32406 .68656 Mdot
.48449 .38688 Mdot
.36436 .4582 Mdot
.55456 .34427 Mdot
.44663 .79075 Mdot
.7924 .35092 Mdot
.4183 .20701 Mdot
.81167 .45659 Mdot
.66228 .43375 Mdot
.53406 .35538 Mdot
.87446 .58728 Mdot
.79368 .60522 Mdot
.56903 .47657 Mdot
.31934 .28645 Mdot
.50251 .43705 Mdot
.57611 .38773 Mdot
.71448 .65091 Mdot
.36552 .81869 Mdot
.73571 .38239 Mdot
.78838 .41621 Mdot
.39969 .40996 Mdot
.46916 .71367 Mdot
.38152 .57415 Mdot
.45259 .46122 Mdot
.55435 .47431 Mdot
.35256 .59437 Mdot
.69112 .42166 Mdot
.64278 .79388 Mdot
.45225 .58944 Mdot
.35202 .79679 Mdot
.85594 .5341 Mdot
.56016 .29164 Mdot
.22549 .54 Mdot
.62589 .46199 Mdot
.65872 .31127 Mdot
.68458 .30918 Mdot
.62274 .50978 Mdot
.56668 .81722 Mdot
.38412 .12726 Mdot
.33281 .65003 Mdot
.68921 .2718 Mdot
.33997 .3414 Mdot
.4268 .53356 Mdot
.48125 .35975 Mdot
.45278 .71447 Mdot
.49904 .69287 Mdot
.66678 .41443 Mdot
.41953 .38648 Mdot
.34851 .51719 Mdot
.13174 .43132 Mdot
.52568 .41141 Mdot
.22223 .43941 Mdot
.83227 .46758 Mdot
.59329 .22849 Mdot
.46894 .29319 Mdot
.63232 .39839 Mdot
.25724 .52374 Mdot
.48299 .47393 Mdot
.71936 .7145 Mdot
.68946 .25564 Mdot
.80453 .49377 Mdot
.58001 .28431 Mdot
.46711 .35515 Mdot
.59147 .36565 Mdot
.66434 .56754 Mdot
.31027 .58456 Mdot
.7336 .65346 Mdot
.52191 .45965 Mdot
.82285 .41659 Mdot
.53571 .72634 Mdot
.55573 .56727 Mdot
.40808 .34802 Mdot
.62458 .16467 Mdot
.41898 .23854 Mdot
.41995 .42197 Mdot
.41765 .18511 Mdot
.57909 .65964 Mdot
.66705 .4906 Mdot
.52928 .63432 Mdot
.55994 .48714 Mdot
.40728 .41146 Mdot
.4048 .17508 Mdot
.72958 .63801 Mdot
.36156 .66533 Mdot
.37185 .69763 Mdot
.24003 .65146 Mdot
.37398 .50296 Mdot
.87783 .51982 Mdot
.56779 .70712 Mdot
.42388 .17232 Mdot
.3182 .76132 Mdot
.41135 .41145 Mdot
.54936 .80214 Mdot
.50475 .41548 Mdot
.51443 .68399 Mdot
.80724 .46517 Mdot
.52942 .4885 Mdot
.60585 .20974 Mdot
.62747 .37377 Mdot
.55728 .18431 Mdot
.61634 .55765 Mdot
.64462 .6525 Mdot
.51172 .77574 Mdot
.41068 .2524 Mdot
.77916 .69168 Mdot
.22441 .55405 Mdot
.80823 .6484 Mdot
.76157 .70909 Mdot
.82327 .46653 Mdot
.56799 .2015 Mdot
.2027 .35839 Mdot
.52208 .77255 Mdot
.66409 .75381 Mdot
.42957 .73169 Mdot
.38962 .26746 Mdot
.53961 .7445 Mdot
.41111 .3465 Mdot
.26592 .43373 Mdot
.39878 .59813 Mdot
.13934 .34376 Mdot
.76429 .46079 Mdot
.42511 .38939 Mdot
.55609 .72923 Mdot
.81388 .42881 Mdot
.41794 .2598 Mdot
.50526 .8071 Mdot
.45791 .54002 Mdot
.62703 .36197 Mdot
.61293 .29299 Mdot
.25928 .67984 Mdot
.54704 .72261 Mdot
.17116 .65789 Mdot
.47668 .82117 Mdot
.3396 .67328 Mdot
.45345 .51593 Mdot
.33568 .40707 Mdot
.18884 .48091 Mdot
.58682 .71376 Mdot
.552 .81958 Mdot
.62501 .79958 Mdot
.79012 .61278 Mdot
.14951 .59885 Mdot
.28996 .71693 Mdot
.77934 .3557 Mdot
.5684 .79478 Mdot
.31478 .3775 Mdot
.75379 .54748 Mdot
.47104 .68897 Mdot
.38803 .68333 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo093ooooo0_l0002gooooo`007?ooool00ol0003oooooooooo`2@ooooo`;o0000]oooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo0_l0002jooooo`;o0000S_ooool001cooooo00?o0000ooooooooool0
^Oooool2o`0008kooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`2Gooooo`;o0000/?ooool001cooooo00?o0000ooooooooool0Uoooool2
o`000;3ooooo000Looooo`03o`000?oooooooooo07Wooooo0_l0003>ooooo`007?ooool00ol0003o
ooooooooo`1iooooo`;o0000:_ooool2o`0000[ooooo0_l0002Fooooo`007?ooool00ol0003ooooo
ooooo`2Uooooo`;o00002_ooool2o`0009Kooooo000Looooo`03o`000?oooooooooo0:7ooooo0_l0
002Vooooo`007?ooool00ol0003oooooooooo`2Qooooo`;o00002oooool2o`0000?ooooo0_l0002D
ooooo`007?ooool00ol0003oooooooooo`29ooooo`;o00008oooool2o`0000?ooooo0_l0002Doooo
o`007?ooool00ol0003oooooooooo`29ooooo`;o0000__ooool001cooooo00?o0000ooooooooool0
Z_ooool2o`000003ooooool0003o000000kooooo0_l0002:ooooo`007?ooool2o`0009cooooo0_l0
000=ooooo`;o000000?oooooo`000?l000003?ooool4o`0000cooooo0_l0001looooo`007?ooool0
0ol0003oooooooooo`2Kooooo`;o00001_ooool2o`0001Gooooo0ol0000>ooooo`;o0000O?ooool0
01cooooo00?o0000ooooooooool0U_ooool2o`0000Kooooo0_l00003ooooo`;o00005Oooool2o`00
00Oooooo0_l00024ooooo`007?ooool00ol0003oooooooooo`27ooooo`;o00003Oooool2o`0000Ko
oooo0_l0000Sooooo`;o0000Q?ooool001cooooo00?o0000ooooooooool0Qoooool2o`0000Gooooo
0_l00007ooooo`;o00008_ooool2o`0000[ooooo0_l000000ooooooo0000o`00001mooooo`007?oo
ool00ol0003oooooooooo`1dooooo`?o00005oooool2o`000003ooooool0003o000000Cooooo0_l0
000Aooooo`;o00003oooool2o`0000[ooooo0_l000000ooooooo0000o`00000>ooooo`;o0000KOoo
ool001cooooo00?o0000ooooooooool0M?ooool3o`0000oooooo0_l000000ooooooo0000o`000006
ooooo`;o00005oooool2o`0000cooooo0_l0000Pooooo`;o0000KOooool001cooooo00?o0000oooo
ooooool0P?ooool2o`0000Cooooo0_l000000ooooooo0000o`00000Dooooo`;o00000_ooool2o`00
01?ooooo0_l0002?ooooo`007?ooool00ol0003oooooooooo`20ooooo`;o00001?ooool2o`0001Co
oooo1Ol00002ooooo`;o00005?ooool2o`0008kooooo000Looooo`03o`000?oooooooooo08Kooooo
0_l00003ooooo`;o00000_ooool3o`0000?ooooo0_l00005ooooo`?o000000?oooooo`000?l00000
1Oooool2o`00013ooooo0_l0000Booooo`;o0000N_ooool001cooooo00?o0000ooooooooool0Rooo
ool2o`0000;ooooo0ol00003ooooo`;o00002Oooool2o`0000Gooooo0_l000000ooooooo0000o`00
0005ooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo0_l0000:ooooo`;o000000?o
ooooo`000?l000001oooool2o`00077ooooo000Looooo`03o`000?oooooooooo05Oooooo0_l0000R
ooooo`;o00001oooool2o`0000oooooo1?l00003ooooo`;o00000_ooool2o`0000Sooooo0_l00005
ooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo0_l0000:ooooo`;o00002_ooool2
o`00077ooooo000Looooo`03o`000?oooooooooo05Oooooo0_l0000Rooooo`;o00001_ooool3o`00
00Kooooo0_l00009ooooo`;o00000oooool2o`00023ooooo0_l0000Gooooo`;o0000L?ooool00006
ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooo
oooo083ooooo0_l000001?oooooo0000o`000?l00006ooooo`?o00005oooool2o`0000;ooooo0_l0
000<ooooo`;o00001?ooool2o`0001Oooooo0_l0001`ooooo`0000KoooooogMgMonHV9SooooooiRH
V?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000oooooooo
ool0M_ooool3o`0000Oooooo0_l00002ooooo`;o00001oooool2o`0000Cooooo0ol0000=ooooo`Go
00000_ooool2o`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l000002Oooool2o`0008Co
oooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h0
1oooool00ol0003oooooooooo`1Vooooo`;o00003_ooool3o`0000oooooo0_l00002ooooo`;o0000
1Oooool3o`0000gooooo1?l0000:ooooo`?o000000Coooooo`000?l0003o00002oooool2o`0000Co
oooo0_l0000@ooooo`;o0000K?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
2oooool00onHV9So8B4Qonk^kP06ooooo`?o0000I_ooool2o`0000kooooo0_l00005ooooo`;o0000
2Oooool2o`0000;ooooo0_l0000Booooo`;o000000?oooooo`000?l000000oooool2o`0000Sooooo
0_l000001?oooooo0000o`000?l0000:ooooo`;o00001Oooool2o`0000?ooooo0_l0000;ooooo`Co
00000oooool2o`0006Gooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo
00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`1fooooo`;o00001Oooool2o`0001oooooo
1?l000000ooooooo0000o`000003ooooo`;o00001_ooool2o`0000?ooooo0_l00009ooooo`Co0000
0oooool2o`0000Gooooo0_l0000=ooooo`;o00000oooool2o`0006Gooooo00000ooooooo410@oooo
o`02ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`24ooooo`;o00002oooool2o`0000[ooooo0ol00008ooooo`Co00001?ooool2o`0000Oooooo0_l0
0005ooooo`;o00001Oooool2o`000003ooooool0003o000007gooooo00001_ooooooMgMgoiRHV?oo
ooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo07ko
oooo0_l00004ooooo`;o00002_ooool5o`0000Sooooo0ol00002ooooo`;o00001?ooool4o`000004
ooooool0003o0000o`0000Kooooo0_l000000ooooooo0000o`000006ooooo`;o00001oooool2o`00
00gooooo0_l0001^ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Pooooo`;o00006oooool3o`00013ooooo1Ol0
000=ooooo`;o00001oooool5o`0000Kooooo0_l00006ooooo`;o000000?oooooo`000?l000001?oo
ool2o`0000;ooooo0_l0000<ooooo`;o00000_ooool2o`0006[ooooo000Looooo`03o`000?oooooo
oooo063ooooo0_l0000Kooooo`Co00004?ooool2o`0000_ooooo1?l00009ooooo`;o00001Oooool2
o`0000?ooooo0_l00003ooooo`Co000000Coooooo`000?l0003o00000oooool2o`0000;ooooo1?l0
000>ooooo`;o0000J_ooool001cooooo00?o0000ooooooooool0Ooooool2o`0001gooooo1?l00007
ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000oooool2o`0000Cooooo0ol00008
ooooo`;o00003Oooool2o`0000;ooooo0_l0001Wooooo`007?ooool00ol0003oooooooooo`2=oooo
o`;o00002Oooool2o`0000Gooooo0_l000000ooooooo0000o`000005ooooo`;o00000oooool2o`00
0003ooooool0003o0000013ooooo0_l0000Cooooo`;o00000_ooool2o`0000;ooooo0_l00002oooo
o`;o0000Hoooool001cooooo00?o0000ooooooooool0N_ooool2o`00017ooooo0_l00009ooooo`;o
00001Oooool2o`000003ooooool0003o000000Oooooo0_l00004ooooo`;o00000oooool2o`0000;o
oooo0_l00009ooooo`;o00000_ooool2o`000003ooooool0003o000000[ooooo0_l0000:ooooo`Co
0000HOooool001cooooo00?o0000ooooooooool0E_ooool2o`0000;ooooo0_l0000Mooooo`?o0000
00?oooooo`000?l000002Oooool2o`00027ooooo0_l00002ooooo`Co00000oooool3o`000004oooo
ool0003o0000ooooo`;o00001_ooool2o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`?o
000000?oooooo`000?l000003_ooool3o`00067ooooo000Looooo`03o`000?oooooooooo04Wooooo
0_l0000;ooooo`;o00000_ooool2o`0001cooooo0ol00002ooooo`;o00002Oooool2o`0000_ooooo
0_l0000Dooooo`;o00000_ooool2o`0000Kooooo0_l00004ooooo`;o00002_ooool3o`0000Gooooo
0ol000000ooooooo0000o`00000;ooooo`;o000000?oooooo`000?l00000H_ooool001cooooo00?o
0000ooooooooool0BOooool2o`0002gooooo0_l0000Hooooo`;o000000?oooooo`000?l000009?oo
ool2o`0000gooooo0_l0000;ooooo`?o00002?ooool2o`0006Gooooo000Looooo`03o`000?oooooo
oooo07kooooo0_l00003ooooo`?o00001?ooool2o`0000Kooooo0_l0000Uooooo`Co00001Oooool2
o`00017ooooo1Ol00009ooooo`;o00001oooool2o`0005_ooooo000Looooo`03o`000?oooooooooo
06[ooooo0_l0000Booooo`;o00000oooool3o`0000Cooooo1?l00003ooooo`;o00002oooool2o`00
01Wooooo0_l00007ooooo`;o00003_ooool2o`000003ooooool0003o000000cooooo0_l00007oooo
o`;o0000Foooool001cooooo00?o0000ooooooooool0J_ooool2o`0000Wooooo0_l0000=ooooo`;o
000000?oooooo`000?l000000oooool2o`0000?ooooo0_l00004ooooo`;o00001Oooool2o`0002;o
oooo0_l0000>ooooo`;o00001_ooool2o`0001;ooooo0_l0001Iooooo`007?ooool00ol0003ooooo
ooooo`1Rooooo`;o00004Oooool2o`0000Cooooo0_l0000:ooooo`;o00002?ooool2o`0000Cooooo
0_l0000booooo`;o00003Oooool3o`0000gooooo0_l00002ooooo`;o0000FOooool001cooooo0_l0
001Aooooo`;o00001?ooool2o`0000[ooooo0ol00003ooooo`;o00002?ooool2o`0000?ooooo0_l0
0002ooooo`;o00001Oooool2o`0000?ooooo0_l0000Dooooo`;o00007oooool4o`0000Wooooo0_l0
0007ooooo`;o00001?ooool3o`0000gooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1@
ooooo`;o00001?ooool2o`0000_ooooo0_l000000ooooooo0000o`000002o`0000Sooooo0_l00002
ooooo`?o00000_ooool2o`0000Gooooo0_l00003ooooo`;o00001?ooool2o`0000cooooo1?l0000O
ooooo`Co00003?ooool2o`0000Cooooo0_l00003ooooo`Co0000K?ooool001cooooo00?o0000oooo
ooooool0I_ooool2o`0000?ooooo0_l00009ooooo`;o00000_ooool4o`0000;ooooo1Ol00008oooo
o`;o00003?ooool2o`0002oooooo1?l00009ooooo`Go0000Joooool001cooooo00?o0000oooooooo
ool0Joooool2o`0000gooooo1?l00002ooooo`Ko000000?oooooo`000?l00000>Oooool2o`0000Ko
oooo1?l00008ooooo`;o00001?ooool2o`0000[ooooo1Ol0001Looooo`007?ooool00ol0003ooooo
ooooo`1Uooooo`;o000000?oooooo`000?l000001?ooool4o`0000Cooooo0ol00005ooooo`;o0000
1?ooool5o`0003Wooooo1?l00004ooooo`;o00002Oooool3o`0000Sooooo0_l00002ooooo`;o0000
0_ooool5o`0005cooooo000Looooo`03o`000?oooooooooo05Cooooo0_l00009ooooo`;o00001?oo
ool5o`0000Cooooo1?l000001?oooooo0000o`000?ooool3o`0000;ooooo0_l000000ooooooo0000
o`000002ooooo`Ko00004_ooool2o`0002Sooooo0_l0000?ooooo`;o00001?ooool2o`0000?ooooo
0_l00002ooooo`;o00000oooool4o`0005cooooo000Looooo`03o`000?oooooooooo03oooooo0_l0
000Cooooo`;o00002Oooool2o`0000Cooooo1?l00007ooooo`;o000000?oooooo`000?l000000_oo
ool3o`000003ooooool0003o000000Gooooo1Ol0000Aooooo`Co00000_ooool2o`0002Gooooo0_l0
0006ooooo`;o00003?ooool2o`0000Cooooo0_l00003ooooo`;o000000?oooooo`000?l00000G_oo
ool001cooooo00?o0000ooooooooool0?oooool2o`0001[ooooo0_l00008ooooo`;o00001Oooool2
o`0000[ooooo0_l0000@ooooo`;o00003?ooool2o`0000Cooooo0_l0000Uooooo`?o00001Oooool2
o`0000Wooooo0_l00002ooooo`;o00000oooool2o`0000?ooooo0_l000000ooooooo0000o`00001N
ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00006Oooool2o`0000Gooooo0_l00008oooo
o`;o00007?ooool2o`0000_ooooo0_l000000ooooooo0000o`00000Pooooo`;o00002?ooool4o`00
00?ooooo0_l00002ooooo`;o00001Oooool2o`0000;ooooo0_l00003ooooo`;o00000oooool2o`00
0003ooooool0003o000000?ooooo0_l0001Iooooo`007?ooool00ol0003oooooooooo`10ooooo`;o
00000oooool2o`0000;ooooo0_l00002ooooo`;o00002Oooool5o`0000Gooooo0_l00008ooooo`;o
0000:Oooool2o`000003ooooool0003o0000023ooooo0_l0000:ooooo`;o00000oooool2o`0000;o
oooo0_l00004ooooo`;o00001Oooool2o`000003ooooool0003o000000?ooooo0_l00006ooooo`;o
0000FOooool001cooooo00?o0000ooooooooool0AOooool2o`0000;ooooo0_l00002ooooo`;o0000
2Oooool5o`0000Kooooo0_l00006ooooo`;o00007_ooool2o`0000Sooooo0_l00006ooooo`;o0000
4?ooool2o`0000Wooooo0_l0000Kooooo`;o00000oooool4o`0000?ooooo0_l00002ooooo`Co0000
00?oooooo`000?l00000Foooool001cooooo00?o0000ooooooooool0E_ooool2o`0000Gooooo0_l0
0004ooooo`;o00001_ooool4o`0001cooooo0_l00008ooooo`;o000000?oooooo`000?l000000ooo
ool2o`00013ooooo0ol00005ooooo`Go00007?ooool2o`0000;ooooo0_l00004ooooo`co00000ooo
ool2o`0005Kooooo000Looooo`03o`000?oooooooooo053ooooo0_l00004ooooo`;o00001Oooool2
o`0000Gooooo0_l000000ooooooo0000o`000004ooooo`;o00006oooool2o`0000;ooooo0_l00008
ooooo`Co000000?oooooo`000?l000003Oooool2o`0000;ooooo0ol00004ooooo`Go00005Oooool2
o`0000Gooooo0_l00008ooooo`;o000000?oooooo`000?l000000oooool2o`0000Gooooo0_l0001F
ooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00004_ooool2o`000003ooooool0003o0000
00Wooooo0_l000000ooooooo0000o`00000;ooooo`;o00001_ooool2o`0000;ooooo0_l00009oooo
o`?o00000_ooool2o`0000cooooo0_l00003ooooo`?o00006?ooool2o`0000?ooooo0_l00005oooo
o`Co00002Oooool2o`0000?ooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1Booooo`;o
00002Oooool2o`0000Sooooo0_l00009ooooo`;o000000?oooooo`000?l000002oooool2o`00017o
oooo0_l00007ooooo`;o00004_ooool2o`0000oooooo0_l00003ooooo`;o00000_ooool2o`0000co
oooo0_l0000Mooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0D_ooool2o`0000Wooooo
0ol0000>ooooo`;o00004_ooool2o`00017ooooo0_l00007ooooo`;o00005_ooool2o`0000;ooooo
0ol00006ooooo`Co000000?oooooo`000?l000002oooool2o`0000?ooooo0_l0000Mooooo`;o0000
C_ooool001cooooo0_l00018ooooo`;o00005Oooool2o`0000Cooooo0_l00006ooooo`Co000000?o
ooooo`000?l000004?ooool2o`000004ooooool0003o0000ooooo`;o00004oooool2o`0001Kooooo
0_l00002ooooo`?o00001oooool3o`000003ooooool0003o000000_ooooo0_l00003ooooo`;o0000
0oooool2o`0006Sooooo000Looooo`03o`000?oooooooooo04Oooooo0_l0000Kooooo`;o00001_oo
ool4o`000003ooooool0003o0000013ooooo0_l000001?oooooo0000o`000?ooool2o`0001;ooooo
0_l0000Aooooo`;o00002?ooool2o`0000Sooooo0_l00002ooooo`;o00005Oooool2o`0000Wooooo
0_l000000ooooooo0000o`000005ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0Aooo
ool2o`0000Oooooo0_l00004ooooo`;o00003oooool2o`0000Gooooo0_l0000]ooooo`;o00000ooo
ool2o`0000cooooo0_l00008ooooo`;o00002oooool3o`0000Sooooo0_l0000Booooo`;o00000_oo
ool2o`000003ooooool0003o000000Gooooo1?l00003ooooo`;o0000C?ooool001cooooo00?o0000
ooooooooool0Aoooool2o`0000Oooooo0_l00004ooooo`;o00000oooool2o`0000[ooooo0_l0000A
ooooo`Co00003_ooool2o`0000_ooooo0_l00002ooooo`;o00000oooool2o`0001Kooooo0_l0000;
ooooo`;o00002Oooool2o`0000Oooooo0_l00002ooooo`;o00001Oooool2o`0000cooooo1?l00003
ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0=?ooool2o`00013ooooo0_l0000Coooo
o`;o00005oooool2o`0000Cooooo1?l0000>ooooo`?o000000?oooooo`000?l000001oooool2o`00
00;ooooo0_l0000@ooooo`;o00002Oooool2o`0000Kooooo0_l0000>ooooo`;o00001oooool2o`00
00;ooooo0_l0000<ooooo`;o00003?ooool2o`0004cooooo000Looooo`03o`000?oooooooooo03Co
oooo0_l0000@ooooo`;o00001Oooool2o`0002Gooooo0ol0000>ooooo`Co00001?ooool2o`000003
ooooool0003o000001gooooo0_l00002ooooo`;o00003Oooool2o`0000[ooooo0_l00002ooooo`;o
00005Oooool2o`0000;ooooo0_l00004ooooo`;o00001_ooool2o`0004cooooo000Looooo`03o`00
0?oooooooooo03Kooooo0_l00002ooooo`;o00004Oooool2o`0000Sooooo0_l00006ooooo`;o0000
3?ooool2o`0000Kooooo0_l0000>ooooo`Co00003Oooool2o`0000Gooooo0_l0000Dooooo`;o0000
1_ooool2o`000003ooooool0003o000000;ooooo0_l0000:ooooo`;o00006Oooool2o`0000Sooooo
0_l0001Dooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00000_ooool2o`00013ooooo1?l0
0007ooooo`;o00000oooool5o`000003ooooool0003o000000Oooooo1?l0000Qooooo`;o00001?oo
ool3o`0000Cooooo0_l00003ooooo`;o00000_ooool2o`0001?ooooo0_l000000ooooooo0000o`00
0002ooooo`;o00001?ooool2o`0000_ooooo0_l0000@ooooo`;o00001Oooool2o`0000cooooo0_l0
001;ooooo`007?ooool00ol0003oooooooooo`1<ooooo`Go000000?oooooo`000?l000002?ooool3
o`000003ooooool0003o000000;o00001oooool2o`0000kooooo0_l0000Cooooo`?o000000Cooooo
o`000?l0003ooooo0_l00006ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Gooooo0_l0
0007ooooo`;o00003Oooool2o`000003ooooool0003o000000_ooooo0_l0000;ooooo`Co000000?o
ooooo`000?l000001Oooool2o`0000Wooooo0_l000001?oooooo0000o`000?l0001:ooooo`007?oo
ool00ol0003oooooooooo`1?ooooo`;o000000?oooooo`000?l000003?ooool2o`0000Gooooo0_l0
0003ooooo`;o00003Oooool2o`0001Cooooo0_l000000ooooooo0000o`000006ooooo`Go00003?oo
ool2o`0000Oooooo0_l00004ooooo`;o00001oooool2o`0001[ooooo1Ol00008ooooo`;o00000ooo
ool2o`0000Cooooo1_l0001:ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00003?ooool2
o`000003ooooool0003o000000Sooooo0_l00002ooooo`?o000000?oooooo`000?l000000oooool2
o`0000;ooooo0_l00005ooooo`;o00003Oooool2o`0001Cooooo0ol00003ooooo`;o00001Oooool2
o`0000_ooooo0_l00004ooooo`;o00000oooool2o`0000Cooooo0_l0000Hooooo`Go00002_ooool2
o`000003ooooool0003o000000Cooooo1?l000000ooooooo0000o`000019ooooo`007?ooool00ol0
003oooooooooo`11ooooo`;o000000?oooooo`000?l000003oooool2o`0000Sooooo0_l00002oooo
o`?o00002_ooool2o`0000Gooooo1?l0000;ooooo`;o00005?ooool2o`000004ooooool0003o0000
ooooo`;o00001Oooool2o`0000Oooooo0_l00003ooooo`;o00002?ooool2o`000004ooooool0003o
0000ooooo`;o000000?oooooo`000?l000009?ooool2o`0000cooooo0_l00019ooooo`007?ooool0
0ol0003oooooooooo`11ooooo`;o00007_ooool4o`0000Wooooo0_l00002ooooo`?o00001?ooool2
o`0000Gooooo0_l0000Dooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`Go00002ooo
ool2o`0000?ooooo0_l00003ooooo`Co00001?ooool2o`0000Cooooo0_l0000=ooooo`;o00002ooo
ool2o`0000Wooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00008Oooool2
o`0000Sooooo0_l000000ooooooo0000o`000002ooooo`?o00000_ooool2o`0000Oooooo0_l0000D
ooooo`;o00002_ooool5o`0000cooooo0_l00003ooooo`;o000000?oooooo`000?l000001?l00005
ooooo`;o00004Oooool2o`0000?ooooo0_l00005ooooo`?o00002Oooool2o`0005Kooooo000Loooo
o`03o`000?oooooooooo02[ooooo0_l0000Booooo`;o00006_ooool2o`000003ooooool0003o0000
00?ooooo0_l00007ooooo`Oo000000?oooooo`000?l000000_ooool2o`0002_ooooo0_l0000:oooo
o`;o000000?oooooo`000?l000000_ooool3o`000003ooooool0003o000000;ooooo0_l000000ooo
oooo0000o`000002ooooo`;o00005_ooool2o`0000Gooooo0ol0001Qooooo`007?ooool00ol0003o
ooooooooo`0Zooooo`;o00004Oooool2o`0001_ooooo0_l000000ooooooo0000o`000002ooooo`?o
00001_ooool9o`000004ooooool0003o0000ooooo`;o00002Oooool2o`0000?ooooo0_l00007oooo
o`;o00003Oooool2o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool5o`00
00;ooooo0_l00005ooooo`;o00000_ooool3o`000003ooooool0003o000000Gooooo0_l0000Hoooo
o`;o00002_ooool2o`0005Cooooo000Looooo`;o0000?_ooool2o`0001Gooooo0_l00005ooooo`;o
00000oooool4o`0000?ooooo1ol000000ooooooo0000o`000005o`000003ooooool0003o000000So
oooo0ol00003ooooo`;o00000oooool2o`0000;ooooo0_l0000=ooooo`;o00002?ooool5o`0000Co
oooo2?l00003ooooo`So000000?oooooo`000?l000001Oooool2o`0001;ooooo0_l00004ooooo`;o
00002_ooool2o`0000Cooooo0_l00003ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0
@Oooool2o`0000[ooooo1?l00003ooooo`;o00000_ooool2o`000003ooooool0003o000000?ooooo
0_l00004ooooo`Oo00000_ooool7o`000005ooooool0003o0000o`000?ooool00_l00004ooooo`;o
00001?ooool2o`0000?ooooo0_l00002ooooo`;o00003Oooool2o`0000?ooooo0_l00003ooooo`Co
000000?oooooo`000?l000000_ooool8o`000003ooooool0003o000000go000000?oooooo`000?l0
00000_ooool2o`000003ooooool0003o000000gooooo0ol0000=ooooo`;o00001_ooool2o`0000?o
oooo0ol00018ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00000_ooool2o`0000Sooooo
0_l00007ooooo`;o000000?oooooo`000?l000000_l00006ooooo`?o00001?ooool2o`000003oooo
ool0003o000000;o000000?oooooo`000?l000001_l000000ooooooo0000o`000009o`000003oooo
ool0003o000000oooooo0ol000000ooooooo0000o`000002ooooo`?o00000_ooool2o`0000Wooooo
0_l00004ooooo`?o000000?oooooo`000?l000001?l000000ooooooo0000o`000003ooooo`?o0000
0oooool2o`0000;ooooo2Ol00002ooooo`Go00003Oooool4o`0000Sooooo0ol000000ooooooo0000
o`000004ooooo`Ko00000_ooool2o`0004Sooooo000Looooo`03o`000?oooooooooo03?ooooo0_l0
0002ooooo`;o00000_ooool2o`000003ooooool0003o000000[ooooo0_l000000ooooooo0000o`00
0008ooooo`;o00001Oooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000005_l0
000=ooooo`Co000000?oooooo`000?l000000_ooool3o`0000;ooooo0_l00007ooooo`;o00001_oo
ool3o`0000;ooooo1Ol000000ooooooo0000o`000002ooooo`Ko000000Coooooo`000?l0003o0000
0_ooool3o`000004ooooool0003o0000o`0000;ooooo1Ol0000>ooooo`Co00002?ooool3o`000003
ooooool0003o000000?o000000?oooooo`000?l000001?l0001<ooooo`007?ooool00ol0003ooooo
ooooo`0iooooo`Co000000?oooooo`000?l000002_ooool2o`0000oooooo0_l00003ooooo`;o0000
1?oooolKo`0000[ooooo0_l00003ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Oooooo
0_l000000ooooooo0000o`000006ooooo`Wo00000oooool2o`0000;ooooo0_l000001?oooooo0000
o`000?l00002ooooo`Go00001?ooool2o`000003ooooool0003o000001Kooooo0_l00002ooooo`;o
00000oooool4o`0000[ooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`0iooooo`;o0000
6Oooool4o`0000?ooooo0_l00003ooooo`Co000000?oooooo`000?l000002Ol00002ooooo`oo0000
1_ooool2o`0000[ooooo0_l0000@ooooo`;o00000oooool2o`000004ooooool0003o0000o`0000;o
oooo4_l000000ooooooo0000o`000003o`0001Oooooo0_l00006ooooo`;o00000_ooool2o`0000?o
oooo0ol00003ooooo`?o00001Oooool2o`0004Oooooo000Looooo`03o`000?oooooooooo03Sooooo
0_l0000>ooooo`;o00001_ooool3o`000003ooooool0003o000000;o00001Oooool2o`000003oooo
ool0003o000001ko00001oooool2o`0000Gooooo0_l0000>ooooo`;o00002_ooool7o`000003oooo
ool0003o000001Co000000?oooooo`000?l000001?ooool3o`000003ooooool0003o000000cooooo
1?l00002ooooo`;o00000oooool2o`0000[ooooo0ol0001>ooooo`007?ooool00ol0003ooooooooo
o`0hooooo`;o00002_ooool2o`0000;ooooo0_l00004ooooo`Go00002_ooool2o`0000Cooooo7_l0
00000ooooooo0000o`000002o`0000Cooooo0_l00002ooooo`Co00003?ooool2o`0000Cooooo1_l0
0002oooooa?o00000_ooool;o`0000?ooooo0ol000001?oooooo0000o`000?l0000;ooooo`Co0000
0_ooool2o`0000?ooooo0_l0000?ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0A?oo
ool2o`0000;ooooo0_l00004ooooo`;o00000_ooool2o`0000gooooo:ol00004ooooo`;o000000?o
ooooo`000?l000003OoooolDo`000003ooooool0003o000000Go000000?oooooo`000?l000002ol0
0004ooooo`Ko000000?oooooo`000?l000002_ooool2o`000003ooooool0003o000000?o00001ooo
ool2o`0000Gooooo0_l00002ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0A?ooool2
o`0000[ooooo1Ol0000<ooooob?o000000?oooooo`000?l000000ol00009ooooo`;o00003?ooool3
o`0000Cooooo5_l000000ooooooo0000o`00000:o`0000?ooooo1_l00003ooooo`;o000000?ooooo
o`000?l000002_ooool5o`0000Gooooo1?l00005ooooo`Ko0000B_ooool001cooooo00?o0000oooo
ooooool0D?ooool2o`000004ooooool0003o0000ooooo`;o00002_ooool3o`000003ooooool0003o
000001So000000Coooooo`000?l0003ooooo0ol000000ooooooo0000o`000002ooooo`;o00004ooo
ool2o`0000Cooooo0ol000000ooooooo0000o`00000No`0000?ooooo0_l0000:ooooo`;o000000Co
ooooo`000?l0003ooooo0_l0000>ooooo`;o00002Oooool2o`0004cooooo000Looooo`03o`000?oo
oooooooo02oooooo0_l0000Booooo`;o000000Coooooo`000?l0003ooooo0ol0000:ooooo`;o0000
2Oooool>o`000003ooooool0003o000000Oo000000?oooooo`000?l000002_l000000ooooooo0000
o`000005o`0000Cooooo0ol000000ooooooo0000o`000009ooooo`;o000000?oooooo`000?l00000
0ol000000ooooooo0000o`00000Lo`0000;ooooo0_l0000Aooooo`;o000000?oooooo`000?l00000
0oooool2o`0000Cooooo0_l00007ooooo`;o00000_ooool2o`0004oooooo000Looooo`03o`000?oo
oooooooo02oooooo0_l0000Booooo`;o000000Coooooo`000?l0003ooooo0ol00003ooooo`;o0000
1Oooool2o`0000Kooooo;_l000000ooooooo0000o`000003ooooo`?o000000?oooooo`000?l00000
0_ooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000002o`0000;ooooo
9?l0000=ooooo`;o00002?ooool3o`0000?ooooo0_l00005ooooo`Co00000_ooool2o`0000?ooooo
0_l0001:ooooo`007?ooool00ol0003oooooooooo`0nooooo`?o00003_ooool3o`0000Cooooo0_l0
0006ooooo`?o00000_oooolUo`000003ooooool0003o000000;ooooo0_l0000;ooooo`;o000000?o
ooooo`000?l000001_ooool5o`000003ooooool0003o000001go000000?oooooo`000?l000001?l0
000:ooooo`;o00002?ooool8o`000004ooooool0003o0000ooooo`Co00002?ooool2o`0004[ooooo
00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@oooooooo
ool01?ooool00ol0003oooooooooo`0nooooo`?o00001Oooool2o`0000Kooooo1?l00004ooooo`;o
00000oooool2o`0000Gooooo7Ol000000ooooooo0000o`000002o`0000;ooooo0_l000000ooooooo
0000o`000006ooooo`?o00003?ooool3o`0000;ooooo1Ol000000ooooooo0000o`00000Po`000004
ooooool0003o0000o`0000oooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l000001Ooo
oooo0000o`000?l0003ooooo00Co00001?ooool2o`0000Cooooo0_l00018ooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo04Kooooo0_l00005ooooo`?o00002oooool2o`0000Cooooo0ol000000ooooooo0000o`00
0005o`0000;ooooo4Ol000000ooooooo0000o`000003o`0000?ooooo0ol00006ooooo`?o00002?oo
ool7o`0000;ooooo1?l000000ooooooo0000o`00000?o`000003ooooool0003o000000ko00000_oo
ool2o`00013ooooo0_l000001?oooooo0000o`000?ooool4o`0000?ooooo0ol00009ooooo`;o0000
0oooool3o`0000Gooooo0_l00011ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`09ooooo`Go00001_ooool00ol0003oooooooooo`1=ooooo`;o00004_ooool2o`0000;ooooo8?l0
0003ooooo`;o00004_ooool4o`000003ooooool0003o000001Oo00000_ooool@o`000004ooooool0
003o0000o`0001?ooooo0_l000000ooooooo0000o`000004o`000003ooooool0003o000000Oo0000
2?ooool2o`0000Kooooo0_l00011ooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooooooo
o`09ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0000booooo`;o00003Oooool2o`0000_ooooo
0_l0000Foooooa_o00000_ooool2o`0000Wooooo0_l0000<ooooo`;o00000oooool[o`000005oooo
ool0003o0000o`000?ooool00ol000000ooooooo0000o`000009ooooo`;o00000_ooool2o`000004
ooooool0003o0000ooooo`;o00001?ooool6o`0000;ooooo0_l0001?ooooo`0000?oooooo`000?oo
ool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000oooo
ooooool0<_ooool2o`0000gooooo0_l0000;ooooo`;o00003_ooool2o`0000;ooooo0_l00002oooo
o`Go000000?oooooo`000?l000004ol000000ooooooo0000o`000004ooooo`;o00001?ooool2o`00
00cooooo0ol00002ooooo`;o000000?oooooo`000?l000009_l000000ooooooo0000o`000005o`00
0003ooooool0003o000000?ooooo0_l00002ooooo`Co00000_ooool2o`000004ooooool0003o0000
ooooo`;o000000?oooooo`000?l000001oooool4o`0000[ooooo0_l00013ooooo`0000?ooooooa0@
4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0@Oooool2o`0000?ooooo1?l00006ooooo`;o00002?ooool2o`0000;ooooo0_l00002oooo
o`;o00000_oooolCo`000003ooooool0003o000000So00001?ooool2o`0001?ooooo0_l00008oooo
oa_o000000?oooooo`000?l000003?l00004ooooo`;o000000?oooooo`000?l000000_l00002oooo
o`;o00002_ooool2o`000003ooooool0003o000000Oooooo0_l0000<ooooo`;o0000@oooool00006
oooooomgMgOoV9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooo
oooo047ooooo0_l00002ooooo`Go00001_ooool2o`0000Sooooo0_l0000:ooooob7o00006Oooool2
o`0000;ooooo;Ol00007ooooo`Co00001_ooool2o`0001_ooooo0ol00007ooooo`;o0000?_ooool0
0006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oo
oooooooo04Gooooo0_l00003ooooo`;o00006_oooolJo`000003ooooool0003o000000Co00001Ooo
ool2o`000003ooooool0003o000000oooooo0_l00002ooooobOo00000_ooool4o`0000Cooooo0_l0
0004ooooo`;o000000?oooooo`000?l000000_ooool2o`0000_ooooo0_l00005ooooo`;o00000_oo
ool2o`0000;ooooo1?l00007ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0A_ooool2
o`0000;ooooo0_l000000ooooooo0000o`000002o`0001Cooooo1?l00002oooooa;o00003oooool2
o`000003ooooool0003o000000;o00001oooool2o`0000Cooooo1?l000000ooooooo0000o`000002
o`000004ooooool0003o0000oooooaWo000000?oooooo`000?l000001Ol000001?oooooo0000o`00
0?ooool2o`000003ooooool0003o000000;ooooo1?l000000ooooooo0000o`000003ooooo`;o0000
0_ooool4o`0000Cooooo0ol000001?oooooo0000o`000?ooool2o`0000;ooooo1_l00007ooooo`;o
0000@?ooool001cooooo00?o0000ooooooooool0??ooool2o`0000Cooooo0_l00002ooooo`;o0000
1Oooool4o`0001Cooooo1Ol000000ooooooo0000o`00000?o`000003ooooool0003o000000;ooooo
0_l00008ooooo`;o00000_ooool4o`0000Oooooo1?l00002ooooo`Co000000?oooooo`000?l00000
8_l00002ooooo`?o00001?ooool2o`0000Gooooo0_l00002ooooo`;o00000oooool3o`0000;ooooo
1?l00005ooooo`;o000000?oooooo`000?l000001?ooool5o`0000Wooooo0_l00010ooooo`007?oo
ool00ol0003oooooooooo`0looooo`;o00001?ooool2o`0000[ooooo0_l00003ooooo`Co00000ooo
ool2o`000003ooooool0003o000000Oooooo2Ol000000ooooooo0000o`00000:o`000003ooooool0
003o000000Co00000_ooool2o`0000Cooooo0_l00002ooooo`;o00002oooool2o`0000;ooooo1?l0
00000ooooooo0000o`00000Go`000003ooooool0003o000000go00002?ooool2o`0000Gooooo0_l0
0003ooooo`?o00001?ooool5o`0000_ooooo1?l00004ooooo`;o0000A_ooool001cooooo00?o0000
ooooooooool0??ooool2o`0000Gooooo1?l0000<ooooo`Co00000oooool2o`000004ooooool0003o
0000ooooo`;o00001?ooool2o`0000;ooooo0_l00004ooooo`So000000?oooooo`000?l000001?oo
ool2o`0000Cooooo0_l00003ooooo`;o00000_ooool3o`0000[ooooo0_l00003ooooo`;o00001?oo
oolEo`000003ooooool0003o0000013o00001Oooool2o`000004ooooool0003o0000o`00013ooooo
1Ol00003ooooo`?o00001_ooool2o`0000Gooooo0_l00016ooooo`007?ooool00ol0003ooooooooo
o`0iooooo`Co00001_ooool4o`0000cooooo0ol00003ooooo`;o00001?ooool3o`0000kooooo2?l0
00000ooooooo0000o`00000:ooooo`;o00000oooool2o`0000;ooooo0_l00008ooooo`;o000000?o
ooooo`000?l000001?ooool2o`000003ooooool0003o000000[o000000?oooooo`000?l000006ol0
0005ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0000oooooo0_l00003ooooo`?o0000
2?ooool2o`0000Oooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`0Wooooo`;o00004?oo
ool4o`0000Wooooo0_l00006ooooo`;o00000oooool3o`0000?ooooo0_l00003ooooo`?o00001Ooo
ool2o`0000Kooooo1?l000000ooooooo0000o`000007o`0000Wooooo0_l00003ooooo`;o000000?o
ooooo`000?l000002Oooool2o`0000Kooooo1ol000000ooooooo0000o`00000So`0000Cooooo1?l0
0006ooooo`;o00001?ooool2o`0000kooooo0_l00006ooooo`;o000000?oooooo`000?l000001ooo
ool2o`0004;ooooo000Looooo`03o`000?oooooooooo02Oooooo0_l0000Aooooo`;o00002_ooool5
o`0000?ooooo0_l00003ooooo`;o00001_ooool2o`000003ooooool0003o000000Kooooo0_l00000
0ooooooo0000o`000003ooooo`;o00000oooool2o`000005ooooool0003o0000o`000?ooool00_l0
000<ooooo`;o00000oooool2o`00013ooooo;Ol00005ooooo`Co00002Oooool2o`000003ooooool0
003o000000;o00004_ooool4o`0000_ooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0h
ooooo`;o00002_ooool2o`000003ooooool0003o000000;o00003oooool3o`000003ooooool0003o
000000Wooooo0_l0000;ooooo`;o00000_ooool2o`0000cooooo0_l0000@ooooo`;o00000oooool2
o`0000;ooooo9Ol00005ooooo`;o00003oooool2o`0000?ooooo0_l00008ooooo`?o00001oooool2
o`0000gooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00001Oooool4o`00
0004ooooool0003o0000ooooo`;o00004?ooool3o`0000gooooo0_l0000;ooooo`;o00000_ooool2
o`0000Gooooo0_l00003ooooo`;o00000oooool2o`0000Gooooo0_l00004ooooo`Ko00000_ooool2
o`000003ooooool0003o000000;o000000?oooooo`000?l000009Ol00002ooooo`;o00003_ooool2
o`0000[ooooo0ol0000Dooooo`;o000000?oooooo`000?l00000@?ooool001cooooo00?o0000oooo
ooooool0?oooool4o`0001Kooooo0_l00004ooooo`;o00001Oooool2o`000003ooooool0003o0000
00_ooooo0_l00009ooooo`;o00000oooool2o`0000?ooooo1?l00003ooooo`;o00001?ooool2o`00
00;ooooo0_l00002ooooo`[o000000?oooooo`000?l000002Ol000000ooooooo0000o`00000Eo`00
00?ooooo0ol0000:ooooo`Ko00000_ooool2o`0000?ooooo0_l0000;ooooo`Ko00001_ooool2o`00
0003ooooool0003o000000;o0000?_ooool001cooooo00?o0000ooooooooool0?_ooool2o`0000co
oooo0_l0000<ooooo`;o00000oooool2o`0000?ooooo1?l00009ooooo`;o00001oooool2o`0000Ko
oooo0_l00007ooooo`Co00002Oooool2o`0000Kooooo:?l000000ooooooo0000o`000002o`0000Go
oooo0_l0000:ooooo`Ko00000_ooool4o`000003ooooool0003o000000;o00002Oooool6o`0000Wo
oooo1?l0000Iooooo`;o00008oooool001cooooo0_l0000kooooo`Ko00002Oooool2o`000003oooo
ool0003o000000cooooo0_l00003ooooo`;o00000oooool2o`0000;ooooo1?l00002ooooo`;o0000
00?oooooo`000?l000001oooool2o`0000Gooooo0ol0000Cooooo`;o00001oooool2o`0000;ooooo
1?l000000ooooooo0000o`00000Ro`0000?ooooo0_l00002ooooo`;o00002oooool2o`0000?ooooo
1?l00003ooooo`Co00001?ooool2o`0000Gooooo0_l0000Vooooo`;o00008oooool001cooooo00?o
0000ooooooooool0>_ooool5o`0000[ooooo0_l0000Aooooo`;o000000?oooooo`000?l000000_oo
ool2o`0000?ooooo1?l00002ooooo`;o000000?oooooo`000?l000003_ooool2o`0000Wooooo0_l0
0009ooooo`;o00000_ooool2o`0000Wooooo0_l00002oooooaoo00000oooool2o`0000;ooooo0_l0
0002ooooo`Co00002Oooool2o`000003ooooool0003o000000?ooooo0_l00004ooooo`;o00001?oo
ool2o`0000Gooooo0_l00006ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0Boooool2
o`0000;ooooo0_l0000;ooooo`;o000000?oooooo`000?l000001?l00003ooooo`Go00001?ooool4
o`0000Wooooo0_l000000ooooooo0000o`000003ooooo`;o00001?ooool2o`0000Oooooo0_l00004
ooooo`;o00002Oooool3o`000003ooooool0003o000001ko00000_ooool5o`0000?ooooo1?l00002
ooooo`;o00000oooool2o`000003ooooool0003o000000;o00000oooool2o`0000Oooooo0_l0000@
ooooo`;o00001Oooool2o`0003cooooo000Looooo`03o`000?oooooooooo03_ooooo0_l00002oooo
o`;o00002_ooool2o`0000;ooooo0_l0000@ooooo`Co00000_ooool2o`0000;ooooo1_l00002oooo
o`;o00002?ooool3o`000005ooooool0003o0000o`000?ooool00ol000001?oooooo0000o`000?oo
ool5o`0000;ooooo1?l00004ooooo`;o00000_ooool2o`0000Gooooo1Ol000000ooooooo0000o`00
0003o`0000;ooooo5ol00003ooooo`Co00000oooool2o`0000Cooooo0_l00003ooooo`;o000000?o
ooooo`000?l000000_l0000;ooooo`Go00003_ooool2o`0000Gooooo0_l0000looooo`007?ooool0
0ol0003oooooooooo`0Tooooo`Co00003Oooool2o`0000Cooooo0_l00002ooooo`;o00008Oooool2
o`0000?ooooo0_l00003ooooo`Go00001oooool2o`0000?ooooo1?l000001?oooooo0000o`000?oo
ool3o`000003ooooool0003o000000;ooooo1?l00002ooooo`Co00001?ooool2o`0000;ooooo0_l0
0005ooooo`;o000000?oooooo`000?l000001_l00002oooooa?o00000_ooool4o`000003ooooool0
003o000000_ooooo0ol00007ooooo`;o00002oooool2o`000003ooooool0003o000000gooooo0_l0
0006ooooo`;o0000??ooool001cooooo00?o0000ooooooooool09?ooool4o`0000gooooo0_l00007
ooooo`;o00000oooool2o`0000;ooooo1?l0000Eooooo`Go00001?ooool2o`0000Gooooo0_l00006
ooooo`;o00001Oooool2o`0000Cooooo0_l00006ooooo`Go00000oooool4o`0000[ooooo0_l00003
ooooo`Wo000000?oooooo`000?l000007Ol00009ooooo`Go00001oooool2o`0000Kooooo0_l00009
ooooo`;o00001oooool3o`000003ooooool0003o000000;o000000?oooooo`000?l00000??ooool0
01cooooo00?o0000ooooooooool0?_ooool2o`0000?ooooo0_l00002ooooo`Co00005Oooool7o`00
00;ooooo1?l00002ooooo`?o00000_ooool3o`0000;ooooo0ol0000;ooooo`;o00001oooool2o`00
00Gooooo0ol00009ooooo`;o00000oooool9o`000003ooooool0003o000000;o00000oooool<o`00
0003ooooool0003o000000?o000000Coooooo`000?l0003ooooo0_l00009ooooo`Go00000oooool2
o`0000;ooooo0_l00005ooooo`?o00002Oooool2o`0000Oooooo0ol000000ooooooo0000o`000002
o`000003ooooool0003o000003cooooo000Looooo`03o`000?oooooooooo03Kooooo0_l0000?oooo
o`Co00005_ooool2o`0000;ooooo0_l00004ooooo`;o00000_ooool2o`0000?ooooo0ol00002oooo
o`?o00000oooool2o`0000Kooooo0_l0000?ooooo`Co00001Oooool2o`0000cooooo0_l000001?oo
oooo0000o`000?ooool2o`0000?ooooo2?l00002ooooo`Oo00001_ooool2o`0000Kooooo0_l00004
ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Gooooo0_l00002ooooo`;o00004?ooool2
o`0004Cooooo000Looooo`03o`000?oooooooooo02_ooooo0_l00009ooooo`;o00004Oooool2o`00
02[ooooo0_l00007ooooo`?o00002Oooool2o`0000Wooooo0_l00002ooooo`?o00000_ooool2o`00
0003ooooool0003o000000Gooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool4o`00
0004ooooool0003o0000o`0000Cooooo0_l00002ooooo`Go00002?ooool2o`0000Kooooo1Ol00000
0ooooooo0000o`000005ooooo`;o00001_ooool2o`000003ooooool0003o000000Kooooo0_l00002
ooooo`;o00002?ooool2o`00043ooooo000Looooo`03o`000?oooooooooo02_ooooo0_l0000?oooo
o`;o00002oooool2o`0001Oooooo1Ol0000Gooooo`;o00002_ooool2o`0000Wooooo0_l00002oooo
o`;o00000oooool2o`0000Sooooo0_l000000ooooooo0000o`000005o`0000;ooooo1?l000001?oo
oooo0000o`000?l00003ooooo`;o00005Oooool2o`0000;ooooo1?l0000?ooooo`?o00002Oooool2
o`0000;ooooo1?l00006ooooo`;o00001?ooool2o`0003[ooooo000Looooo`03o`000?oooooooooo
03[ooooo1?l000001?oooooo0000o`000?ooool2o`0000Gooooo0_l00003ooooo`;o00004_ooool7
o`0001[ooooo0_l0000Dooooo`;o00003oooool4o`000003ooooool0003o000000;o00000_ooool3
o`0000?ooooo0_l000000ooooooo0000o`000003o`0000;ooooo0_l0000?ooooo`;o00002oooool2
o`0000Sooooo0_l0000@ooooo`;o00001Oooool2o`0000?ooooo1?l0000jooooo`007?ooool00ol0
003oooooooooo`0Qooooo`;o00005oooool2o`0000?ooooo0_l000000ooooooo0000o`00000:oooo
o`;o00002?ooool2o`0000gooooo1?l0000Gooooo`?o00002_ooool2o`0000Sooooo0_l00005oooo
o`;o00002?ooool3o`000004ooooool0003o0000ooooo`Co000000?oooooo`000?l000000_l00000
0ooooooo0000o`000006o`0000;ooooo0_l0000>ooooo`;o00003?ooool2o`0000gooooo0_l0000B
ooooo`Co000000?oooooo`000?l00000??ooool001cooooo00?o0000ooooooooool08Oooool2o`00
013ooooo0_l0000Iooooo`;o00002?ooool3o`0000;ooooo0_l00006ooooo`;o00000_ooool4o`00
01Gooooo0_l00003ooooo`;o00000oooool2o`000003ooooool0003o000000Cooooo1_l00005oooo
o`;o00001_ooool2o`0000Cooooo0_l00002ooooo`Co00000_ooool3o`000003ooooool0003o0000
00[o00002?ooool2o`0000?ooooo0_l0000>ooooo`;o00002oooool2o`0000Kooooo0_l0000<oooo
o`;o0000?oooool001cooooo00?o0000ooooooooool0<oooool2o`0000kooooo1?l00003ooooo`;o
00001_ooool2o`0000Gooooo0_l00002ooooo`;o00001_ooool2o`0000;ooooo1?l0000Gooooo`Go
00000oooool2o`0000Oooooo1?l0000?ooooo`?o00001oooool4o`0000?ooooo0_l00003ooooo`;o
000000?oooooo`000?l000000_l000000ooooooo0000o`000008ooooo`;o00000oooool2o`0000co
oooo1?l0000;ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000002ooooo`;o
0000BOooool001cooooo00?o0000ooooooooool09?ooool2o`0001gooooo1?l00003ooooo`Co0000
1?ooool3o`0001Cooooo0_l0000Gooooo`Ko00001?ooool2o`0001_ooooo0_l00004ooooo`;o0000
1?ooool2o`000004ooooool0003o0000o`0000?ooooo0_l0000Eooooo`;o00000_ooool2o`0000So
oooo0_l00003ooooo`;o00002_ooool5o`0000Gooooo0_l00002ooooo`;o0000AOooool001cooooo
00?o0000ooooooooool09?ooool2o`0002Kooooo0_l00005ooooo`?o00007oooool5o`0000Sooooo
0_l000000ooooooo0000o`000005ooooo`;o00004Oooool2o`0000_ooooo0_l000000ooooooo0000
o`000003ooooo`?o000000Coooooo`000?l0003o00000oooool2o`0001Wooooo0_l00003ooooo`;o
00002?ooool2o`0000Kooooo0_l00002ooooo`;o00001Oooool2o`0000Cooooo0ol00007ooooo`;o
0000??ooool001cooooo0_l0000dooooo`;o00003Oooool2o`0000Kooooo0_l00008ooooo`;o0000
3oooool2o`0000Sooooo0_l00004ooooo`Go00000oooool2o`00023ooooo0_l00003ooooo`;o0000
1_ooool4o`0000Cooooo0_l00007ooooo`;o00003Oooool2o`00013ooooo0_l00002ooooo`;o0000
1oooool2o`0000?ooooo0_l00009ooooo`;o00001?ooool3o`0000Cooooo0_l000000ooooooo0000
o`00000looooo`007?ooool00ol0003oooooooooo`0cooooo`;o000000?oooooo`000?l000000_oo
ool2o`0000Cooooo1Ol00005ooooo`;o00002oooool2o`0000cooooo0_l00008ooooo`;o00001Ooo
ool5o`0000;ooooo0_l000000ooooooo0000o`00000@ooooo`;o00004?ooool2o`0000Sooooo0_l0
00000ooooooo0000o`00000:ooooo`;o00001Oooool2o`000003ooooool0003o000000?ooooo0_l0
0005ooooo`;o00003Oooool2o`0000Oooooo0_l0000Eooooo`;o00001?ooool2o`0003oooooo000L
ooooo`03o`000?oooooooooo03Kooooo0_l00002ooooo`;o000000?oooooo`000?l000001_l0000=
ooooo`;o00000oooool4o`0001_ooooo1Ol00005ooooo`;o00004?ooool2o`0000Kooooo0_l0000@
ooooo`;o00000oooool2o`0000?ooooo0_l00005ooooo`;o00001Oooool2o`000003ooooool0003o
000000[ooooo0_l00006ooooo`;o00003?ooool2o`0000;ooooo0_l0000Dooooo`;o0000A?ooool0
01cooooo00?o0000ooooooooool0;Oooool2o`0000kooooo0ol0000Booooo`;o00001Oooool2o`00
00;ooooo0_l0000Fooooo`;o00003_ooool2o`00017ooooo1?l00004ooooo`;o00002_ooool2o`00
00?ooooo0_l00003ooooo`;o00001Oooool2o`0000Sooooo0_l000000ooooooo0000o`000002oooo
o`;o00002oooool2o`0000Sooooo0_l00002ooooo`;o00000_ooool2o`0000Kooooo0_l0000<oooo
o`;o0000A?ooool001cooooo00?o0000ooooooooool0;Oooool2o`0001Gooooo0_l00007ooooo`;o
00000oooool2o`0000Wooooo0_l00008ooooo`Co00002_ooool2o`0000Wooooo0_l00003ooooo`;o
00004Oooool2o`0000Kooooo1?l00003ooooo`?o00001oooool2o`0000;ooooo0_l00005ooooo`;o
00000oooool2o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o00005Oooool2o`0000;o
oooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool3o`0000;ooooo0_l0000=ooooo`;o
0000?_ooool001cooooo00?o0000ooooooooool0<Oooool2o`0000;ooooo0_l00003ooooo`;o0000
2?ooool3o`0000Kooooo0_l000000ooooooo0000o`000002o`0000oooooo0_l00002ooooo`So0000
2_ooool2o`0000Gooooo0_l00007ooooo`;o00001Oooool2o`0000Wooooo0_l00005ooooo`;o0000
0oooool3o`0000_ooooo0_l000000ooooooo0000o`000002ooooo`Co000000?oooooo`000?l00000
1_ooool2o`0000?ooooo0_l00005ooooo`;o00000_ooool2o`0000Cooooo0_l00002ooooo`Co0000
0_ooool2o`0000?ooooo1Ol00003ooooo`;o00000_ooool2o`0000;ooooo0_l00009ooooo`;o0000
?_ooool001cooooo00?o0000ooooooooool0<Oooool2o`0000;ooooo0_l00003ooooo`;o00002?oo
ool3o`0000Wooooo0ol0000@ooooo`;o00001Oooool5o`0000Sooooo1?l00007ooooo`;o00001?oo
ool3o`0000Gooooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l0000@ooooo`;o000000?o
ooooo`000?l000000_l00004ooooo`?o00000oooool2o`0000;ooooo0_l00005ooooo`?o00002Ooo
ool2o`0000;ooooo0_l00004ooooo`;o00000_ooool4o`000003ooooool0003o000000Kooooo0_l0
00000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000000_l00009ooooo`;o00003_oo
ool2o`0002kooooo000Looooo`03o`000?oooooooooo02Wooooo0_l00007ooooo`;o00001Oooool2
o`0000;ooooo0_l00005ooooo`;o00000oooool3o`0000Gooooo0_l0000>ooooo`;o00001oooool4
o`0000;ooooo0_l00005ooooo`;o00002Oooool2o`0000Cooooo0_l00008ooooo`Go00004_ooool2
o`000005ooooool0003o0000o`000?ooool01?l00005ooooo`Co00001Oooool2o`0000?ooooo1Ol0
000Dooooo`;o00000_ooool3o`000003ooooool0003o000000;o00001Oooool4o`0000?ooooo0ol0
00000ooooooo0000o`00000;ooooo`;o00003_ooool2o`0002kooooo000Looooo`03o`000?oooooo
oooo02Wooooo0_l00007ooooo`Ko000000?oooooo`000?l000000_ooool2o`0000Wooooo1?l00004
ooooo`;o00002oooool2o`000004ooooool0003o0000o`0000Kooooo2Ol00002ooooo`;o00007?oo
ool2o`0000_ooooo0_l00008ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Kooooo0_l0
00000ooooooo0000o`00000:ooooo`;o00002?ooool2o`0000[ooooo1Ol000000ooooooo0000o`00
0003ooooo`Co00000oooool4o`0000Gooooo0ol0001>ooooo`007?ooool00ol0003oooooooooo`0^
ooooo`;o00001?ooool4o`00013ooooo0_l00006ooooo`;o00002oooool2o`000003ooooool0003o
000000Gooooo2_l00002ooooo`Go00001?ooool2o`0000cooooo0_l0000;ooooo`;o00001_ooool2
o`0000oooooo0_l00006ooooo`;o00005oooool2o`0000Sooooo1ol000000ooooooo0000o`000005
ooooo`?o00000_ooool2o`0000cooooo0_l0000Aooooo`;o00001Oooool2o`00033ooooo000Loooo
o`03o`000?oooooooooo02kooooo0_l0000]ooooo`;o00002?ooool:o`000003ooooool0003o0000
00Co00001?ooool2o`0000cooooo0_l00004ooooo`?o00001?ooool2o`0001?ooooo0_l0000<oooo
o`;o00001?ooool4o`0001Oooooo0_l00003ooooo`;o00002?ooool3o`0000Sooooo0_l00006oooo
o`Ko00002?ooool2o`0000?ooooo0_l00005ooooo`;o00003oooool2o`0001oooooo000Looooo`03
o`000?oooooooooo03;ooooo0_l00003ooooo`;o00005Oooool4o`0000_ooooo0_l000001?oooooo
0000o`000?l00002ooooo`;o000000?oooooo`000?l000002ol0000Booooo`Co00001Oooool3o`00
00[ooooo0_l0000;ooooo`Co00001oooool2o`0000?ooooo0_l00004ooooo`Co000000?oooooo`00
0?l000008oooool2o`0000?ooooo0_l00003ooooo`?o00002?ooool4o`0000Sooooo0_l00005oooo
o`;o00005?ooool2o`0001oooooo000Looooo`03o`000?oooooooooo037ooooo0ol00003ooooo`;o
00004_ooool2o`000003ooooool0003o000000;o00000oooool2o`0000Wooooo0ol00002oooooa7o
000000?oooooo`000?l000000oooool2o`0000;ooooo0_l00005ooooo`Co00002oooool2o`000003
ooooool0003o000000;ooooo0_l0000;ooooo`Co00001oooool2o`0000Sooooo0_l00004ooooo`;o
00002oooool2o`0000[ooooo0_l00006ooooo`Co00001Oooool2o`0000?ooooo0ol00008ooooo`;o
00000oooool2o`0000cooooo0_l0000eooooo`007?ooool00ol0003oooooooooo`0aooooo`;o0000
1oooool2o`0000[ooooo0_l00003ooooo`;o00002?ooool2o`000003ooooool0003o000000Wooooo
0_l000000ooooooo0000o`00000Ao`0000;ooooo1ol0000?ooooo`Oo000000?oooooo`000?l00000
1?ooool2o`000003ooooool0003o000000Sooooo1?l00002ooooo`;o00001Oooool2o`0000Cooooo
0_l0000Aooooo`;o00002_ooool2o`0000Kooooo1_l00006ooooo`;o00002oooool2o`0000?ooooo
0_l00002ooooo`;o00003oooool2o`0002kooooo000Looooo`03o`000?oooooooooo03[ooooo0_l0
000:ooooo`;o00001Oooool2o`0000Wooooo0_l00008ooooo`?o00000_oooolAo`0000?ooooo0_l0
00000ooooooo0000o`000002o`0000[ooooo0_l00002ooooo`Ko000000Coooooo`000?l0003o0000
1Oooool2o`000003ooooool0003o000000Gooooo1ol00002ooooo`;o00001Oooool2o`0001Cooooo
0_l0000Iooooo`;o00001_ooool2o`0000;ooooo0_l000000ooooooo0000o`000008ooooo`;o0000
0oooool2o`0000oooooo0_l0000^ooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00003ooo
ool2o`0000kooooo0_l0000Cooooo`;o000000?oooooo`000?l000004ol00006ooooo`;o00002_oo
ool2o`0000;ooooo0ol00004ooooo`?o00001Oooool2o`0000Sooooo1Ol00003ooooo`?o00001Ooo
ool3o`0001?ooooo0_l0000Hooooo`?o00001Oooool2o`0000;ooooo0ol000000ooooooo0000o`00
0008ooooo`;o000000Coooooo`000?l0003o0000@?ooool001cooooo0_l0000]ooooo`;o00003ooo
ool2o`0000Cooooo1?l00006ooooo`;o00005?oooolGo`0000oooooo0_l00007ooooo`;o00001_oo
ool2o`0000kooooo0ol00004ooooo`;o00001_ooool3o`000003ooooool0003o000000;o00003_oo
ool3o`0000Kooooo0_l0000?ooooo`;o00001_ooool2o`0000;ooooo0_l000000ooooooo0000o`00
0002o`0000[ooooo0ol00010ooooo`007?ooool00ol0003oooooooooo`0Oooooo`;o00003oooool2
o`00017ooooo1_l00007ooooo`;o000000?oooooo`000?l000002?ooool4o`000003ooooool0003o
000001Go000000?oooooo`000?l000003Oooool2o`0000Oooooo0_l00006ooooo`;o00001oooool2
o`0000Kooooo0_l0000=ooooo`;o000000?oooooo`000?l000001Ol0000<ooooo`;o00001_ooool2
o`00017ooooo0_l0000;ooooo`Co00002oooool2o`00043ooooo000Looooo`03o`000?oooooooooo
01oooooo0_l00003ooooo`;o00002_ooool2o`0000Cooooo0_l0000=ooooo`Co00001oooool5o`00
00Sooooo1?l000000ooooooo0000o`00000Ho`00013ooooo0_l0000Eooooo`;o000000?oooooo`00
0?l000004_ooool2o`000003ooooool0003o000000;ooooo0ol0000Wooooo`;o00005_ooool2o`00
00;ooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0Tooooo`;o00001?ooool2o`0000[o
oooo0_l0000<ooooo`;o00001?ooool2o`0000Kooooo0ol0000=oooooaWo00002Oooool2o`0000Ko
oooo1?l0000Fooooo`;o00001oooool3o`0000Sooooo0_l00008ooooo`;o00001oooool2o`0000Ko
oooo1?l0000Sooooo`;o00001Oooool2o`0004Cooooo000Looooo`03o`000?oooooooooo02[ooooo
0_l0000Hooooo`;o00001?ooool3o`000003ooooool0003o000000?ooooo0_l00007ooooo`Co0000
0_oooolJo`0000;ooooo0_l00004ooooo`;o00002?ooool3o`0000?ooooo0_l00006ooooo`;o0000
2?ooool4o`0000Gooooo0ol00003ooooo`;o00000oooool2o`0000Gooooo0_l000000ooooooo0000
o`000003ooooo`[o00000_ooool4o`0001_ooooo0_l00006ooooo`;o00000_ooool5o`0000?ooooo
1?l0000mooooo`007?ooool00ol0003oooooooooo`0Yooooo`;o00000_ooool4o`0001[ooooo0_l0
00000ooooooo0000o`00000<ooooo`Co00001Oooool:o`000003ooooool0003o000000[o00000_oo
ool2o`0000oooooo0_l00003ooooo`;o00001_ooool2o`0000Oooooo1Ol0000;ooooo`;o00000ooo
ool2o`0000Gooooo0ol00002ooooo`;o000000?oooooo`000?l000002?l00003ooooo`;o00007?oo
ool2o`000003ooooool0003o000000Oooooo1Ol00003ooooo`Co0000?Oooool001cooooo00?o0000
ooooooooool0:Oooool2o`0000;ooooo1?l00007ooooo`;o00006_ooool2o`0000oooooo5_l00003
ooooo`;o00002_ooool2o`0000[ooooo0_l0000<ooooo`?o000000?oooooo`000?l000001oooool2
o`0000Cooooo0_l00008ooooo`[o000000?oooooo`000?l000001Ol000000ooooooo0000o`000002
o`0001oooooo0_l00008ooooo`;o000000Coooooo`000?l0003ooooo0_l00010ooooo`007?ooool0
0ol0003oooooooooo`0]ooooo`;o00002Oooool2o`0000_ooooo0_l000001?oooooo0000o`000?oo
ool2o`0000Oooooo1?l0000;ooooo`ko000000?oooooo`000?l000002?l00005ooooo`;o00001Ooo
ool4o`0000[ooooo0_l0000<ooooo`;o00002oooool2o`0000Cooooo0_l00002ooooo`;o00001?oo
ool6o`000003ooooool0003o000000co00001_ooool2o`0000gooooo0_l00004ooooo`;o00004Ooo
ool2o`000003ooooool0003o0000043ooooo000Looooo`03o`000?oooooooooo02gooooo0_l0000F
ooooo`Go000000?oooooo`000?l000002Oooool2o`0000Wooooo3ol000000ooooooo0000o`000009
o`0000Cooooo0ol00005ooooo`;o00003oooool4o`0000;ooooo0_l00002ooooo`;o00001Oooool3
o`0000kooooo1ol00003ooooo`;o000000?oooooo`000?l000003ol00003ooooo`;o00003Oooool2
o`0000Cooooo0ol0000Cooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0?_ooool4o`00
0003ooooool0003o000000?o00001_ooool2o`00017ooooo0_l000000ooooooo0000o`00000Fo`00
0004ooooool0003o0000ooooo`;o00002Oooool2o`0000cooooo1?l00002ooooo`;o00000_ooool:
o`00013ooooo1Ol00002oooooaGo00005?ooool2o`0000?ooooo0_l0000=ooooo`;o00001?ooool4
o`0003kooooo000Looooo`03o`000?oooooooooo03?ooooo1?l00007ooooo`Co000000Coooooo`00
0?l0003o00002?ooool2o`0000Sooooo0_l00002ooooo`;o00001_oooolHo`000003ooooool0003o
000000cooooo0_l0000Gooooo`Wo00002_ooool2o`0000Kooooo0_l00003ooooo`ko000000?ooooo
o`000?l000002Ol0000?ooooo`;o00001?ooool2o`0000Oooooo0ol00002ooooo`;o00001_ooool2
o`0003kooooo000Looooo`03o`000?oooooooooo03?ooooo1?l00008ooooo`;o00000_ooool4o`00
00kooooo0_l000001?oooooo0000o`000?ooool3o`0000?ooooo0_l00004oooooaGo00000oooool2
o`0001Sooooo0_l00009ooooo`Co00000oooool2o`0000Gooooo0_l00003ooooo`;o00002oooool>
o`000003ooooool0003o000000Wo00000_ooool2o`00013ooooo0ol00003ooooo`;o00000_ooool3
o`0000;ooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00001?ooool2o`00
00kooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo5?l00003ooooo`;o00004Oooool2o`00
00Gooooo0_l0000Fooooo`?o00004?oooolJo`0000;ooooo0_l0000>ooooo`Go00000oooool2o`00
00gooooo0_l0000?ooooo`;o0000;oooool001cooooo00?o0000ooooooooool0<oooool2o`0000Go
oooo0_l0000>ooooo`;o00005?ooool2o`0000Gooooo5ol00005ooooo`;o00000oooool2o`000004
ooooool0003o0000ooooo`Ko00001Oooool4o`0000Gooooo0_l0000=ooooo`Go00003?oooolJo`00
00Gooooo0_l0000=ooooo`;o000000?oooooo`000?l000000_l0000<ooooo`;o00000_ooool4o`00
00gooooo0_l0000_ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool0
1Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0<oooool2o`0000Cooooo0ol0
000>ooooo`;o00004Oooool2o`000003ooooool0003o000000Gooooo3?l000000ooooooo0000o`00
0008o`0000?ooooo1?l000000ooooooo0000o`000002o`000004ooooool0003o0000ooooo`Co0000
1oooool4o`0000Gooooo0_l00008ooooo`;o00001?ooool4o`0000cooooo6_l000001?oooooo0000
o`000?ooool3o`0000Wooooo0_l00007ooooo`;o00003?ooool3o`000003ooooool0003o000000;o
0000?_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMg
MoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo03Wooooo0ol00003ooooo`Co00006Oooool3
o`0000Kooooo5_l000000ooooooo0000o`000003ooooo`?o00000_ooool4o`0000;ooooo0_l0000N
ooooo`;o00001oooool2o`0000;ooooo0_l00008ooooo`co000000?oooooo`000?l000003Ol00000
0ooooooo0000o`000007ooooo`;o000000?oooooo`000?l000001?ooool2o`00013ooooo0_l00000
0ooooooo0000o`000002o`0003kooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo
00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo02gooooo0_l0000@
ooooo`Co00003oooool2o`0000Gooooo1Ol00007oooooaKo00000_ooool3o`0000?ooooo0_l00007
ooooo`;o000000?oooooo`000?l000001?l0000<ooooo`;o00001_ooool3o`0000Cooooo0_l00003
ooooo`;o00000_ooool2o`0000;ooooo0_l00003oooooa_o00000_ooool2o`0000Sooooo0_l00007
ooooo`;o000000?oooooo`000?l000002_ooool2o`0000Kooooo0_l0000nooooo`0000?oooooo`00
0?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3
o`0002gooooo0_l00005ooooo`;o00002Oooool2o`0000Gooooo0_l000000ooooooo0000o`000007
ooooo`;o00001?ooool4o`0000Cooooo0_l00005ooooo`;o000000?oooooo`000?l000003ol00002
ooooo`?o000000?oooooo`000?l000000_l000000ooooooo0000o`000007ooooo`Ko00003?ooool4
o`0000Cooooo0ol00004ooooo`;o00000_ooool4o`0000Gooooo0_l000000ooooooo0000o`00000B
o`000003ooooool0003o000000Ko00000_ooool2o`0000kooooo1?l000001?oooooo0000o`000?l0
000:ooooo`;o0000A_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool0
1Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0;Oooool4o`0000?ooooo0_l0
0009ooooo`;o00001Oooool2o`000003ooooool0003o000000;ooooo0_l00005ooooo`?o000000?o
ooooo`000?l000001_ooool2o`0000Gooooo0_l00003oooooa7o00001?ooool3o`0000;ooooo0_l0
000Kooooo`;o00000oooool2o`0000Cooooo0_l00004ooooo`Co000000?oooooo`000?l000001Ooo
ool2o`0000?ooooo1_l000000ooooooo0000o`00000>o`00017ooooo1_l000000ooooooo0000o`00
0008ooooo`;o00003?ooool2o`0003_ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooo
oooo00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`0_ooooo`;o00007?ooool2
o`0000Gooooo1Ol00005ooooo`;o00002Oooool4o`000003ooooool0003o000000go00001Oooool2
o`0000;ooooo0_l0000Fooooo`;o00000oooool2o`0000?ooooo0_l00004ooooo`;o00002Oooool2
o`0000;ooooo0_l00007ooooo`;o000000?oooooo`000?l000003_l000000ooooooo0000o`00000A
ooooo`;o00002_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000?ooooo0ol0000j
ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o
0000ooooooooool0Boooool2o`0000[ooooo0_l00005ooooo`?o00002?ooool4o`0000;ooooo1_l0
00000ooooooo0000o`000002ooooo`;o00000_ooool2o`0000;ooooo0_l00002ooooo`;o00005_oo
ool2o`0000?ooooo0_l00003ooooo`;o00001?ooool2o`0000Wooooo0_l00002ooooo`;o00001_oo
ool3o`000003ooooool0003o000000ko00000oooool2o`0000Wooooo0_l000000ooooooo0000o`00
000=ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`Co00000oooool2o`0003[ooooo0000
1_ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003o
ooooooooo`11ooooo`;o00002?ooool3o`0000Wooooo0_l00002ooooo`;o00000_ooool2o`0000So
oooo1_l00003ooooo`?o00000oooool4o`000003ooooool0003o000000;o00001_ooool4o`0000_o
oooo0_l00005ooooo`?o00000oooool2o`0000;ooooo0ol00009ooooo`?o00000oooool2o`0000[o
oooo5?l00003ooooo`;o00002Oooool2o`000003ooooool0003o000000;ooooo0_l0000<ooooo`?o
000000Coooooo`000?l0003ooooo2?l00004ooooo`;o0000>?ooool001cooooo00?o0000oooooooo
ool0?_ooool2o`000003ooooool0003o000000Wooooo0_l00009ooooo`?o000000?oooooo`000?l0
00001?ooool2o`0000;ooooo0_l00002ooooo`?o000000?oooooo`000?l000000_l00007ooooo`?o
00000_ooool4o`0000Kooooo1?l0000;ooooo`Co00000_ooool=o`0000[ooooo0ol00003ooooo`;o
00001_ooool2o`0000Gooooo0_l000000ooooooo0000o`000009o`000003ooooool0003o000001Go
oooo0_l00003ooooo`;o00001oooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000;o
oooo0_l00004ooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0??ooool4o`0000kooooo
0_l00008ooooo`;o00000oooool2o`000004ooooool0003o0000o`0000;ooooo0_l00002ooooo`?o
00000oooool4o`0000Gooooo0_l00004ooooo`;o00002oooool2o`0000_ooooo0_l000000ooooooo
0000o`00000:o`0000;ooooo0_l0000;ooooo`;o00002Oooool2o`000003ooooool0003o000000;o
oooo1Ol000000ooooooo0000o`000009o`0001[ooooo0_l0000Booooo`;o0000@?ooool001cooooo
00?o0000ooooooooool0??ooool2o`0000?ooooo0_l0000;ooooo`Co00001_ooool2o`0000?ooooo
0_l000000ooooooo0000o`000002ooooo`;o00001Oooool2o`0000Cooooo0_l00005ooooo`;o0000
1?ooool2o`0000Cooooo0_l00005ooooo`;o00001Oooool2o`000003ooooool0003o000001Ko0000
2Oooool2o`0000cooooo0_l00002ooooo`Go000000?oooooo`000?l000001ol0000`ooooo`;o0000
@?ooool001cooooo00?o0000ooooooooool0@Oooool2o`0000?ooooo0_l00008ooooo`;o00001_oo
ool2o`0000Oooooo0_l000000ooooooo0000o`000005ooooo`;o00004_ooool2o`0000?ooooo0_l0
0002ooooo`;o00002?ooool2o`000003ooooool0003o000000Ko00000_ooool>o`0001[ooooo0_l0
0002ooooo`;o000000Coooooo`000?l0003o00000_ooool4o`0000_ooooo0_l00002ooooo`;o0000
3_ooool2o`00057ooooo000Looooo`03o`000?oooooooooo03cooooo0_l00008ooooo`;o00002?oo
ool2o`000003ooooool0003o000000Sooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0
003o000000Cooooo0_l0000>ooooo`;o00001Oooool4o`0000Kooooo0_l00005oooooaKo00006_oo
ool2o`0000;ooooo0_l000001Ooooooo0000o`000?l0003ooooo00Oo00002Oooool2o`0000;ooooo
0_l0000>ooooo`;o0000DOooool001cooooo00?o0000ooooooooool0;Oooool2o`0000gooooo0_l0
000Eooooo`;o00000_ooool2o`0000Cooooo0_l00007ooooo`;o000000?oooooo`000?l000001?oo
ool3o`0000;ooooo1Ol00007ooooo`;o00001?ooool2o`0000Sooooo0_l00005oooooaKo00003_oo
ool2o`0000kooooo0_l00002ooooo`[o000000?oooooo`000?l000001oooool2o`0001Wooooo0_l0
0019ooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o0000:?ooool2o`0000oooooo0_l00005
ooooo`?o000000?oooooo`000?l000001Ol00002ooooo`;o00000_ooool2o`0000Kooooo0_l00005
ooooo`;o00000oooool@o`000003ooooool0003o000000Go00003oooool2o`0000;ooooo0_l00006
ooooo`?o00001_ooool5o`0000Gooooo0_l00007ooooo`;o00006Oooool4o`000003ooooool0003o
000004Cooooo000Looooo`03o`000?oooooooooo04Cooooo0_l0000Aooooo`;o00003oooool3o`00
00?ooooo1?l000000ooooooo0000o`000002o`000003ooooool0003o000000;ooooo0_l0000:oooo
o`Co00000oooool3o`0000;ooooo6ol0000@ooooo`;o00001Oooool6o`0000Kooooo1Ol0000>oooo
o`;o00000_ooool2o`0001;ooooo0_l000000ooooooo0000o`000003o`0004Cooooo000Looooo`03
o`000?oooooooooo043ooooo0_l00002ooooo`;o00003_ooool2o`000003ooooool0003o0000013o
oooo3_l0000:ooooo`;o00001Oooool4o`0000?ooooo0ol00002oooooa_o00005oooool2o`0000;o
oooo0_l00002ooooo`;o00001Oooool2o`000003ooooool0003o000000Wooooo1?l00002ooooo`;o
00004_ooool2o`0000?ooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o0000
0_ooool2o`000004ooooool0003o0000ooooo`;o00002?ooool2o`0001Cooooo1?l00003ooooo`Go
00002oooool2o`0000Gooooo0_l00005ooooo`;o00000ooooolJo`0001Sooooo0_l000000ooooooo
0000o`000002o`000003ooooool0003o000000Co00001?ooool3o`0000Gooooo1Ol0000=ooooo`;o
00003?ooool4o`0004Gooooo000Looooo`03o`000?oooooooooo04Cooooo0_l000001?oooooo0000
o`000?ooool2o`0000Gooooo0_l000000ooooooo0000o`00000Nooooo`;o000000?oooooo`000?l0
00000_l00002ooooo`?o00000_ooool2o`0000_ooooo0_l000000ooooooo0000o`00000Lo`0001So
oooo1_l000000ooooooo0000o`000003o`0000Gooooo0_l00005ooooo`Go00002?ooool2o`000003
ooooool0003o000000;o00002oooool3o`000003ooooool0003o000004Cooooo000Looooo`;o0000
@Oooool2o`0000Sooooo0_l00005ooooo`;o000000?oooooo`000?l000004Oooool3o`0000Cooooo
0ol00006ooooo`Co00000_ooool3o`0000;ooooo0_l0000;ooooo`;o000000?oooooo`000?l00000
7_l0000@ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`Ko00004Oooool3o`0000Oo
oooo0_l000000ooooooo0000o`000007ooooo`;o00001?ooool3o`000003ooooool0003o000004Co
oooo000Looooo`03o`000?oooooooooo043ooooo1?l00006ooooo`;o00006oooool3o`000004oooo
ool0003o0000ooooo`?o00002oooool3o`0000?ooooo0_l0000?oooooa_o00000_ooool2o`0000So
oooo1?l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o000000?oooooo`00
0?l000004?ooool3o`0000Cooooo0_l0000=ooooo`;o0000C_ooool001cooooo00?o0000oooooooo
ool0=?ooool2o`0000cooooo0_l0000?ooooo`;o00005_ooool2o`000003ooooool0003o000000?o
00002Oooool2o`0000Gooooo0_l00004ooooo`;o00001ooooolMo`000003ooooool0003o000000So
oooo1?l0000:ooooo`;o00001oooool2o`0001?ooooo1_l0001Mooooo`007?ooool00ol0003ooooo
ooooo`0dooooo`;o00005?ooool2o`0000Oooooo0_l0000Kooooo`?o00004?ooool2o`0000Cooooo
0_l00006oooooaOo00000_ooool5o`0000Wooooo0_l00004ooooo`;o00002?ooool2o`0000[ooooo
0_l00007ooooo`;o00001oooool4o`00013ooooo0_l0001=ooooo`007?ooool00ol0003ooooooooo
o`0looooo`;o00002Oooool2o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o00005?oo
ool2o`0000Gooooo0ol0000?ooooo`;o00001?ooool2o`0000Kooooo6Ol000000ooooooo0000o`00
0002o`0000Oooooo0_l000001?oooooo0000o`000?l00003ooooo`?o00004oooool2o`000003oooo
ool0003o000000Cooooo0_l000000ooooooo0000o`000004ooooo`;o00000_ooool2o`0000kooooo
0_l0001=ooooo`007?ooool00ol0003oooooooooo`0looooo`;o00002Oooool2o`0000Kooooo0_l0
0002ooooo`Co00004_ooool2o`0000Oooooo0_l0000>ooooo`;o00001?ooool2o`0000?ooooo0_l0
00000ooooooo0000o`00000=o`0000?ooooo2?l000000ooooooo0000o`000008ooooo`;o00000_oo
ool4o`000004ooooool0003o0000o`0000?ooooo0_l0000Aooooo`;o00001oooool2o`0000Cooooo
0_l00002ooooo`;o00003_ooool2o`0004gooooo000Looooo`03o`000?oooooooooo03gooooo0_l0
000?ooooo`;o00000oooool4o`000003ooooool0003o000000Sooooo0_l0000=ooooo`?o00002Ooo
ool2o`0000Sooooo0_l00002ooooo`Co000000?oooooo`000?l000007Ol0000<ooooo`Go00001?oo
ool2o`0000Gooooo1?l0000Cooooo`;o00001Oooool4o`0005cooooo000Looooo`03o`000?oooooo
oooo03gooooo0_l0000>ooooo`?o00000oooool2o`0000?ooooo0_l00002ooooo`;o00001?ooool2
o`0000Oooooo1?l00002ooooo`;o00001oooool2o`000003ooooool0003o000000Kooooo1Ol00000
1?oooooo0000o`000?l00002oooooaco000000?oooooo`000?l000003?ooool4o`0000cooooo1?l0
000Cooooo`;o000000?oooooo`000?l000000_ooool4o`0000cooooo0_l0001>ooooo`007?ooool0
0ol0003oooooooooo`19ooooo`Ko00002?ooool4o`000003ooooool0003o000000Wooooo0_l00002
ooooo`Co00002oooool3o`0000Sooooo0_l000000ooooooo0000o`000002ooooo`;o00000_oooolL
o`0000kooooo0ol0000?ooooo`;o00004_ooool2o`0000?ooooo0_l00003ooooo`;o00003Oooool2
o`0004kooooo000Looooo`03o`000?oooooooooo04Wooooo1?l00004ooooo`Go000000?oooooo`00
0?l000000_l0000<ooooo`;o00002_ooool2o`0000?ooooo1Ol000000ooooooo0000o`000008oooo
o`Co00000oooool>o`000003ooooool0003o000000ko00002_ooool4o`0000Kooooo0_l00002oooo
o`;o00003?ooool2o`0000?ooooo0_l00005ooooo`;o00001_ooool4o`00027ooooo0_l0000joooo
o`007?ooool00ol0003oooooooooo`1Aooooo`Go00006oooool4o`0000?ooooo1Ol000000ooooooo
0000o`000008ooooo`Co00000ooooolJo`000003ooooool0003o000000;o00002_ooool2o`0000Go
oooo0_l000000ooooooo0000o`000002ooooo`;o00003?ooool2o`000003ooooool0003o000000Co
00000_ooool4o`0000Gooooo0_l0000:ooooo`;o00002?ooool2o`0000gooooo0_l0000jooooo`00
7?ooool00ol0003oooooooooo`1Vooooo`;o00002Oooool2o`0000?ooooo0_l000001?oooooo0000
o`000?l0000;ooooo`;o00000_ooool4o`000005ooooool0003o0000o`000?ooool04ol000000ooo
oooo0000o`000004o`0000Cooooo0_l00004ooooo`;o00001Oooool2o`000003ooooool0003o0000
00;ooooo0_l0000?ooooo`;o00000_ooool3o`000003ooooool0003o000000;o00001_ooool2o`00
00Gooooo0ol000000ooooooo0000o`000008ooooo`;o0000BOooool001cooooo00?o0000oooooooo
ool0C?ooool4o`0000Cooooo0_l0000@ooooo`;o000000?oooooo`000?l000000_l00007ooooo`Co
000000?oooooo`000?l000003?ooool2o`0000;ooooo1?l000000ooooooo0000o`000003oooooa[o
00000oooool2o`0000Cooooo0_l00008ooooo`;o00001_ooool2o`0000cooooo0_l00002ooooo`;o
000000Coooooo`000?l0003ooooo0_l00005ooooo`;o00001Oooool3o`0000?ooooo0_l0001Aoooo
o`007?ooool00ol0003oooooooooo`1<ooooo`Co00001?ooool3o`0001;ooooo1?l00004ooooo`;o
000000Coooooo`000?l0003ooooo0_l00005ooooo`;o00001oooool2o`0000Oooooo0_l00003oooo
oaOo000000?oooooo`000?l000003oooool2o`0000[ooooo0_l00002ooooo`;o00002?ooool2o`00
00Sooooo0_l00005ooooo`;o00001Oooool2o`0000Cooooo0_l000000ooooooo0000o`00001>oooo
o`007?ooool00ol0003oooooooooo`1Eooooo`;o00002?ooool2o`0000gooooo0_l000000ooooooo
0000o`000004ooooo`;o00001Oooool4o`0000Wooooo1?l00009oooooaCo00001oooool6o`0000Go
oooo0_l0000>ooooo`;o00002?ooool2o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l0
00001Oooool2o`0000cooooo0_l000000ooooooo0000o`00001;ooooo`007?ooool00ol0003ooooo
ooooo`1Hooooo`;o00001Oooool2o`000003ooooool0003o000000[ooooo0_l00005ooooo`;o0000
2Oooool4o`0000Gooooo1_l00004ooooo`;o00001?ooool>o`000003ooooool0003o000000Wooooo
1_l0000Looooo`;o000000?oooooo`000?l000000oooool2o`0000;ooooo0_l000001?oooooo0000
o`000?ooool2o`0000;ooooo0_l0000?ooooo`;o0000Boooool001cooooo0_l0001Aooooo`;o0000
1_ooool2o`0000Sooooo0_l00007ooooo`;o00001?ooool2o`0000;ooooo0ol0000:ooooo`;o0000
00?oooooo`000?l000000_ooool2o`0000Gooooo0_l000000ooooooo0000o`000004ooooo`go0000
0_ooool2o`0000Gooooo0_l0000Booooo`;o00004?ooool2o`0000?ooooo0_l00006ooooo`;o0000
0oooool2o`00063ooooo000Looooo`03o`000?oooooooooo053ooooo0_l00006ooooo`;o00003_oo
ool2o`000003ooooool0003o000000Cooooo0_l00003ooooo`;o00001Oooool2o`0000Kooooo0_l0
0003ooooo`?o00000oooool2o`0000Oooooo1?l00003ooooo`Wo00001_ooool2o`0001;ooooo0_l0
000@ooooo`Co000000?oooooo`000?l000000_l00002ooooo`Co00005?ooool2o`0000;ooooo0_l0
001;ooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00001_ooool2o`0000kooooo0_l00006
ooooo`;o00001Oooool2o`0000Cooooo0_l0000;ooooo`?o00003Oooool2o`0000Gooooo2?l00006
ooooo`;o00001?ooool2o`0001Sooooo0_l00004ooooo`Co00000oooool2o`0000;ooooo0_l0000F
ooooo`;o00000_ooool2o`0004_ooooo000Looooo`03o`000?oooooooooo05;ooooo0_l0000Loooo
o`;o00001Oooool2o`0000Wooooo0_l00008ooooo`;o00003?ooool3o`0000Gooooo1?l00005oooo
o`;o00000_ooool2o`0000Cooooo0_l0000Hooooo`;o00001?ooool2o`0000[ooooo0_l0000Aoooo
o`;o0000Doooool001cooooo00?o0000ooooooooool0B_ooool2o`0000Kooooo0_l0000Fooooo`;o
00000_ooool2o`0000Oooooo0_l00009ooooo`;o00001?ooool2o`0000;ooooo0_l000000ooooooo
0000o`000004ooooo`;o000000?oooooo`000?l000000ol0000=ooooo`?o00003_ooool2o`0002Co
oooo0_l0000@ooooo`?o0000Doooool001cooooo00?o0000ooooooooool0Aoooool2o`000003oooo
ool0003o000000cooooo1?l0000:ooooo`;o00000_ooool2o`0000;ooooo0_l00007ooooo`;o0000
1oooool2o`0000Kooooo0_l00005ooooo`;o00001?ooool2o`000003ooooool0003o000000Oooooo
0_l00007ooooo`;o00001_ooool2o`0000Oooooo0_l00004ooooo`;o00002_ooool2o`0000kooooo
0_l00007ooooo`;o00002oooool2o`0005Cooooo000Looooo`03o`000?oooooooooo04Oooooo0_l0
0006ooooo`?o00000_ooool2o`0000;ooooo1?l0000:ooooo`;o00001Oooool3o`0000Cooooo0_l0
000:ooooo`Go00007?ooool2o`0000?ooooo0_l0000:ooooo`?o00003?ooool2o`0000[ooooo0_l0
000>ooooo`;o00001oooool2o`0000Kooooo0_l0001Iooooo`007?ooool00ol0003oooooooooo`1?
ooooo`?o00000_ooool2o`0000?ooooo0ol00003ooooo`;o00001oooool2o`0000?ooooo0_l00002
ooooo`Go00003?ooool3o`0000[ooooo0_l0000;ooooo`;o00001Oooool2o`000003ooooool0003o
000000Cooooo1?l00003ooooo`;o00000oooool2o`0003Cooooo0_l00006ooooo`Go0000C_ooool0
01cooooo00?o0000ooooooooool0Coooool2o`0000Sooooo0ol00003ooooo`;o00000_ooool2o`00
00?ooooo0_l00007ooooo`Co00000oooool2o`0001Gooooo0_l0000;ooooo`;o00001Oooool4o`00
00?ooooo1_l00008ooooo`;o00000oooool2o`0002[ooooo0_l00004ooooo`;o00001Oooool5o`00
04kooooo000Looooo`03o`000?oooooooooo05Gooooo0_l00003ooooo`;o000000?oooooo`000?l0
00000_ooool6o`00017ooooo0_l000000ooooooo0000o`00000Eooooo`;o00002?ooool2o`0000Oo
oooo0_l00003ooooo`Co00000oooool2o`0000?ooooo1?l00003ooooo`;o0000:_ooool2o`0000Co
oooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`1Eooooo`Co00000_ooool4o`0000;ooooo
0_l000001?oooooo0000o`000?l00009ooooo`;o00002Oooool2o`0000_ooooo0_l00008ooooo`;o
00002?ooool2o`0000_ooooo0_l000000ooooooo0000o`000003ooooo`;o00000oooool2o`0001So
oooo0_l00007ooooo`;o00002_ooool2o`0000Gooooo0_l0001Kooooo`007?ooool00ol0003ooooo
ooooo`1Fooooo`?o00000_ooool2o`0000Oooooo0_l00004ooooo`;o00000oooool3o`0001Cooooo
1ol00007ooooo`;o00001_ooool2o`0000;ooooo0_l00007ooooo`;o00009Oooool2o`000003oooo
ool0003o000000Cooooo1?l00007ooooo`?o000000?oooooo`000?l000000_ooool2o`0005_ooooo
000Looooo`03o`000?oooooooooo05Oooooo0_l00004ooooo`Go00001Oooool2o`000003ooooool0
003o000000?ooooo0_l0000Cooooo`Co000000?oooooo`000?l000001?l00005ooooo`;o00002_oo
ool2o`0000gooooo1?l0000Fooooo`;o00002?ooool2o`0000Kooooo0ol00006ooooo`Ko00001_oo
ool2o`0000?ooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`1Looooo`Ko000000?ooooo
o`000?l000000_ooool2o`0000Kooooo0_l00009ooooo`;o00002?ooool4o`0000Gooooo0_l0000?
ooooo`;o00003Oooool7o`0000cooooo0_l00007ooooo`;o00002?ooool2o`0000Cooooo0_l00000
0ooooooo0000o`000007ooooo`Co00001_ooool3o`0000?ooooo0_l0001Booooo`007?ooool00ol0
003oooooooooo`1Looooo`;o00001Oooool2o`0000Wooooo0ol00009ooooo`;o00004_ooool3o`00
00Cooooo0_l00005ooooo`Co00001?ooool2o`0000?ooooo0_l000001?oooooo0000o`000?l00003
ooooo`;o00003?ooool2o`0000kooooo0_l00004ooooo`;o000000?oooooo`000?l000002_ooool2
o`0000Sooooo0ol0001Gooooo`007?ooool00ol0003oooooooooo`1Zooooo`;o00000_ooool2o`00
01kooooo1?l00003ooooo`;o00001Oooool2o`0000Kooooo0_l00002ooooo`?o000000?oooooo`00
0?l000003Oooool2o`000003ooooool0003o000000Cooooo0_l0000:ooooo`;o00001?ooool3o`00
073ooooo000Looooo`;o0000Joooool2o`0001Cooooo0_l00003ooooo`;o00002Oooool2o`0000Ko
oooo0_l0000>ooooo`;o000000?oooooo`000?l000003_ooool2o`000003ooooool0003o000000Co
oooo0_l0000Aooooo`Co000000Coooooo`000?l0003ooooo0_l0000@ooooo`;o000000?oooooo`00
0?l00000Doooool001cooooo00?o0000ooooooooool0F_ooool3o`0000gooooo0_l00002ooooo`;o
00002_ooool2o`0000Cooooo0_l00003ooooo`;o00000oooool2o`0000Gooooo0_l00005ooooo`;o
00000_ooool2o`0000[ooooo0_l000000ooooooo0000o`000004ooooo`;o00008Oooool2o`0000?o
oooo0_l000001?oooooo0000o`000?ooool2o`00013ooooo0_l000000ooooooo0000o`00001Coooo
o`007?ooool00ol0003oooooooooo`1Jooooo`?o00001?ooool2o`0000Oooooo0_l00002ooooo`;o
00001Oooool2o`0000?ooooo0_l00007ooooo`Go00000_ooool2o`0000Gooooo0_l00009ooooo`;o
00001oooool3o`0000Wooooo0_l00009ooooo`;o00005_ooool2o`0000cooooo0_l0001Uooooo`00
7?ooool00ol0003oooooooooo`1Qooooo`;o00004_ooool3o`0000_ooooo1Ol00009ooooo`;o0000
4_ooool3o`0001Cooooo0_l0000;ooooo`;o00004_ooool2o`000003ooooool0003o000000;o0000
IOooool001cooooo00?o0000ooooooooool0GOooool2o`0000Gooooo0_l0000@ooooo`?o00004ooo
ool3o`0000;ooooo0_l0000=ooooo`?o00003Oooool2o`0000_ooooo0_l00002ooooo`;o00001?oo
ool4o`0001;ooooo0_l000000ooooooo0000o`00001Wooooo`007?ooool00ol0003oooooooooo`1M
ooooo`Co00000oooool2o`0000?ooooo0_l00003ooooo`;o00001oooool2o`000005ooooool0003o
0000o`000?ooool00_l0000<ooooo`?o00001?ooool2o`0000Sooooo0_l000001?oooooo0000o`00
0?l00006ooooo`;o00001Oooool2o`0000;ooooo0_l00007ooooo`;o00000_ooool2o`0000Cooooo
0_l00009ooooo`;o0000MOooool001cooooo00?o0000ooooooooool0Goooool2o`0000?ooooo0_l0
0003ooooo`;o00000oooool2o`0000[ooooo0ol000001?oooooo0000o`000?ooool2o`00013ooooo
1?l000001?oooooo0000o`000?l00002ooooo`;o00002_ooool2o`0000;ooooo0ol00004ooooo`;o
00001Oooool2o`0000;ooooo0_l00009ooooo`Co00001?ooool2o`0000[ooooo0_l0001Yooooo`00
7?ooool00ol0003oooooooooo`1:ooooo`;o00007oooool2o`0000_ooooo0_l00004ooooo`;o0000
00?oooooo`000?l000003_ooool3o`000004ooooool0003o0000ooooo`?o00002oooool2o`0000Go
oooo0ol000000ooooooo0000o`000008ooooo`;o00000_ooool2o`0000Wooooo1Ol00002ooooo`;o
00002oooool2o`0006Wooooo000Looooo`03o`000?oooooooooo04[ooooo0_l0000Oooooo`;o0000
1Oooool2o`000004ooooool0003o0000ooooo`;o00005oooool3o`0000Wooooo1?l000001Ooooooo
0000o`000?l0003ooooo00;o00002Oooool2o`0001[ooooo0_l00002ooooo`;o0000M_ooool001co
oooo00?o0000ooooooooool0L_ooool2o`000003ooooool0003o000001cooooo1?l00004ooooo`Ko
000000Goooooo`000?l0003o0000ooooo`02o`0000[ooooo0_l0000>ooooo`;o00006?ooool2o`00
06_ooooo000Looooo`03o`000?oooooooooo06Gooooo0_l0000[ooooo`Go00001?ooool2o`0000Go
oooo0_l00002ooooo`;o00002_ooool2o`0000kooooo1?l00009ooooo`?o00002_ooool2o`0006_o
oooo000Looooo`03o`000?oooooooooo06Gooooo0_l0000<ooooo`;o00002?ooool2o`0000;ooooo
0_l0000?ooooo`;o00001?ooool2o`0000Cooooo0_l00002ooooo`;o00003_ooool2o`0000kooooo
1_l00006ooooo`Co0000Moooool001cooooo00?o0000ooooooooool0LOooool4o`0000Sooooo0_l0
00001?oooooo0000o`000?l00006ooooo`;o00001_ooool2o`0000Gooooo0_l00004ooooo`;o0000
1oooool2o`0001Wooooo0_l000001?oooooo0000o`000?l00006ooooo`Co00001oooool2o`0006ko
oooo000Looooo`03o`000?oooooooooo077ooooo0_l000000ooooooo0000o`00000:ooooo`;o0000
00?oooooo`000?l000001?ooool2o`0000;ooooo0_l00002ooooo`;o00001_ooool2o`0000cooooo
1?l00002ooooo`;o00003?ooool2o`0000Gooooo0_l000000ooooooo0000o`00000Booooo`;o0000
K_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0
003o8B4Qolc<c006ooooo`03o`000?oooooooooo07Cooooo0ol00004ooooo`;o00001_ooool2o`00
00Sooooo0_l00008ooooo`Co00003Oooool3o`0000;ooooo1_l00008ooooo`;o00003?ooool2o`00
00;ooooo0ol00009ooooo`;o0000K_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo06Kooooo0_l0
0007ooooo`;o00000oooool3o`0000Cooooo0_l00002ooooo`;o00004_ooool2o`0000;ooooo1?l0
000Dooooo`Co00000_ooool2o`0001;ooooo0_l00002ooooo`?o0000NOooool00003ooooool@413o
oooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool0I_ooool4o`0000Gooooo0_l00003ooooo`;o00002Oooool2o`0001;ooooo0_l0
0003ooooo`;o00002oooool2o`0000Sooooo0_l00004ooooo`Go00003Oooool2o`00083ooooo0000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`?o0000Eoooool2o`0000oooooo0_l00002ooooo`;o0000:_ooool2o`0000Gooooo0_l0
0003ooooo`?o00000oooool4o`000003ooooool0003o000000Gooooo1?l00002ooooo`;o00001Ooo
ool2o`0000;ooooo0_l00007ooooo`?o0000M_ooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool02Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0Eooo
ool2o`0000cooooo0_l00005ooooo`;o00005_ooool2o`0000Gooooo1?l0000@ooooo`;o00000_oo
ool3o`0000;ooooo1_l000000ooooooo0000o`000005ooooo`;o00001?ooool2o`0000?ooooo1Ol0
0005ooooo`;o00000oooool3o`0007Kooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooo
oooo00Wooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo06Gooooo0_l0
000Aooooo`;o00002_ooool2o`0000Gooooo1?l0000;ooooo`?o00000oooool2o`000003ooooool0
003o000000?ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00004?ooool2o`000003oooo
ool0003o000000?ooooo1?l0001looooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05
o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`1hooooo`;o00001Oooool2o`00
00;ooooo0_l00003ooooo`;o00004?ooool3o`0000?ooooo0_l000000ooooooo0000o`000006oooo
o`;o00000_ooool2o`0000[ooooo0_l00004ooooo`?o00001?ooool3o`0007kooooo00001_oooooo
k^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oo
oooooooo06[ooooo0_l0000Cooooo`;o00000_ooool2o`0000?ooooo0_l0000Cooooo`;o00001?oo
ool3o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000008ooooo`Co00000ooo
ool6o`0000;ooooo0_l0001oooooo`007?ooool00ol0003oooooooooo`1Zooooo`;o00001oooool2
o`0000Wooooo0_l0000Eooooo`;o00001_ooool2o`0000Gooooo0_l000000ooooooo0000o`000003
ooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o00001Oooool2o`000004ooooool0003o
0000o`0008?ooooo000Looooo`03o`000?oooooooooo07?ooooo0_l00006ooooo`;o000000?ooooo
o`000?l000003oooool4o`0000;ooooo1?l00004ooooo`;o00004Oooool2o`0000;ooooo0_l0000;
ooooo`;o00006_ooool2o`0006[ooooo000Looooo`03o`000?oooooooooo073ooooo0_l000000ooo
oooo0000o`000002o`0000Cooooo0_l00007ooooo`;o00002Oooool4o`000004ooooool0003o0000
ooooo`Co00000_ooool2o`0000?ooooo0_l0000<ooooo`;o00002_ooool2o`0000?ooooo0_l0000J
ooooo`;o0000J_ooool001cooooo00?o0000ooooooooool0L?ooool2o`0000?ooooo0_l0000=oooo
o`;o00003_ooool2o`0000?ooooo0_l00007ooooo`Co00000_ooool2o`0001;ooooo0_l0000Loooo
o`;o0000KOooool001cooooo00?o0000ooooooooool0P_ooool2o`0000Kooooo0_l00006ooooo`;o
00002?ooool2o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o00000_ooool2o`0002co
oooo0_l0001]ooooo`007?ooool00ol0003oooooooooo`22ooooo`;o00001_ooool3o`0000Cooooo
0ol00008ooooo`;o000000?oooooo`000?l000001oooool2o`0000;ooooo0_l0002Kooooo`007?oo
ool00ol0003oooooooooo`29ooooo`Co00001?ooool4o`0001oooooo0_l00005ooooo`;o0000S?oo
ool001cooooo00?o0000ooooooooool0ROooool2o`0000Sooooo0_l0000@ooooo`;o00003Oooool2
o`0000Cooooo0ol0002<ooooo`007?ooool00ol0003oooooooooo`20ooooo`;o00002Oooool2o`00
01Sooooo0_l000000ooooooo0000o`00000@ooooo`;o0000SOooool001cooooo00?o0000oooooooo
ool0P?ooool2o`0000Wooooo0_l0000Cooooo`;o00001_ooool2o`0000kooooo0_l0002?ooooo`00
7?ooool00ol0003oooooooooo`22ooooo`;o00007?ooool2o`0000Gooooo0_l00005ooooo`;o0000
2?ooool2o`0000?ooooo0_l0000?ooooo`;o0000NOooool001cooooo0_l00023ooooo`;o00001ooo
ool2o`0000Gooooo0_l0000<ooooo`;o00000_ooool2o`000003ooooool0003o000000Cooooo0ol0
0002ooooo`;o000000?oooooo`000?l000001_ooool2o`0000oooooo0_l0001iooooo`007?ooool0
0ol0003oooooooooo`2;ooooo`;o00001Oooool2o`0000cooooo0_l00002ooooo`;o00001oooool2
o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`;o0000R_ooool001cooooo00?o0000oooo
ooooool0X?ooool2o`0000Oooooo0_l00002ooooo`;o0000V_ooool001cooooo00?o0000oooooooo
ool0Y?ooool2o`0000?ooooo0_l00002ooooo`;o0000V_ooool001cooooo00?o0000ooooooooool0
Y?ooool2o`000:?ooooo000Looooo`03o`000?oooooooooo0:cooooo0_l0002Kooooo`007?ooool0
0ol0003oooooooooo`2/ooooo`;o0000Voooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0:[ooooo0_l0002Mooooo`007?ooool00ol0003o
ooooooooo`2Zooooo`;o0000WOooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`00
0?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom:
ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool001Co
oooo00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o0000ooooooooool0
oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooo
oooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`004_ooool00omEEEGo
IVIVo`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Qoooo
o`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05_ooool4o`000008oa0@4?oooooo
oooooiRHV?l@413o0000oc8b<_o<c<`5ooooo`03o`000?o^k^kooooo00Gooooo0_l000000ol@413o
ooooooooo`2:ooooo`00X_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l0000<ooooo`03
o`000?oooooooooo00;ooooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`03oeEEEOnYZJWooooo
00Kooooo00?o0000ooooooooool0Roooool00:;ooooo00Go0000ooooooooooooooooo`00000Koooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00onYZJWoEEEEooooo`03oooo
o`Go0000S?ooool00:;ooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00003?ooool00ol0
003oooooooooo`05ooooo`03ojVYZOl@413ooooo00Gooooo00?o8B4Qooooooooool00_ooool01?m4
A4CogMgMooooool0002=ooooo`00X_ooool01Ol0003oQhN7oooooonYZJWo000001_ooooo00?o0000
ooooooooool01?ooool00ol@413o0000okZj^P06ooooo`03oeEEEOo<c<cooooo00;ooooo00CogMgM
oeEEEOoooooo0000SOooool00:7ooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0I
ooooo`03o`000?oooooooooo00Gooooo00?o^[Zjob4Q8Oooool01Oooool00onYZJWoMgMgooooo`03
ooooo`03ogMgMoo<c<co000008gooooo0032ooooo`03o`000?oooooooooo00;ooooo00Go410@oiRH
V?oooooo^[Zjo`000003ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00oo^k^koA4A4o`00
002=ooooo`00`?ooool00omEEEGoIVIVo`000004ooooo`05ojVYZOl@413o0000oa0@4?nYZJT00ooo
ool5o`0000Gooooo00?oMgMgo`000?ooool0S?ooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1380) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.34524 .34745 Mdot
.35528 .33883 Mdot
.49141 .65695 Mdot
.59727 .45896 Mdot
.67732 .73224 Mdot
.45524 .6571 Mdot
.37383 .52848 Mdot
.3299 .51784 Mdot
.49625 .66414 Mdot
.34842 .46058 Mdot
.32118 .54424 Mdot
.53284 .47495 Mdot
.35053 .54711 Mdot
.5717 .42804 Mdot
.86599 .55196 Mdot
.64895 .39274 Mdot
.34614 .34902 Mdot
.59614 .57987 Mdot
.60366 .37269 Mdot
.44235 .64647 Mdot
.3589 .39675 Mdot
.57773 .43022 Mdot
.38802 .38708 Mdot
.57137 .42756 Mdot
.61466 .44362 Mdot
.39766 .38074 Mdot
.43805 .3879 Mdot
.62886 .41886 Mdot
.60992 .3882 Mdot
.32057 .52689 Mdot
.69523 .51015 Mdot
.81679 .62335 Mdot
.66334 .38471 Mdot
.79712 .51218 Mdot
.354 .51981 Mdot
.5201 .30622 Mdot
.46633 .65649 Mdot
.33144 .54674 Mdot
.33239 .55433 Mdot
.33874 .50923 Mdot
.33015 .53139 Mdot
.37825 .37321 Mdot
.28418 .38586 Mdot
.4055 .66962 Mdot
.64669 .44802 Mdot
.51832 .80652 Mdot
.47083 .35907 Mdot
.55306 .42663 Mdot
.40358 .34456 Mdot
.55959 .68906 Mdot
.36803 .65638 Mdot
.37059 .54155 Mdot
.44142 .66952 Mdot
.19535 .2945 Mdot
.35809 .55519 Mdot
.54991 .47463 Mdot
.47764 .66071 Mdot
.58811 .41923 Mdot
.57082 .42314 Mdot
.53922 .22435 Mdot
.59728 .48368 Mdot
.6233 .63783 Mdot
.39951 .32233 Mdot
.47 .5626 Mdot
.47938 .67165 Mdot
.3283 .55655 Mdot
.36745 .33828 Mdot
.35867 .54512 Mdot
.67717 .45266 Mdot
.47761 .70494 Mdot
.55165 .43078 Mdot
.32267 .54658 Mdot
.39047 .40223 Mdot
.6107 .40122 Mdot
.4891 .75143 Mdot
.47994 .82184 Mdot
.66853 .63156 Mdot
.51956 .28654 Mdot
.53119 .22031 Mdot
.57667 .72003 Mdot
.64356 .42052 Mdot
.71101 .57323 Mdot
.48341 .81353 Mdot
.42619 .36612 Mdot
.628 .37021 Mdot
.57735 .60314 Mdot
.61398 .40546 Mdot
.58694 .81791 Mdot
.55455 .45493 Mdot
.58513 .5615 Mdot
.50413 .65423 Mdot
.39919 .35575 Mdot
.60197 .45948 Mdot
.59585 .39109 Mdot
.58821 .22851 Mdot
.55375 .39523 Mdot
.59501 .43508 Mdot
.40512 .34071 Mdot
.36956 .54452 Mdot
.55783 .4743 Mdot
.41459 .60992 Mdot
.48233 .6226 Mdot
.61665 .46799 Mdot
.51127 .6626 Mdot
.4099 .39574 Mdot
.59531 .39191 Mdot
.33958 .56021 Mdot
.59861 .47559 Mdot
.21691 .52448 Mdot
.34879 .35745 Mdot
.62493 .40163 Mdot
.64528 .60005 Mdot
.45273 .23678 Mdot
.40741 .3561 Mdot
.40277 .61174 Mdot
.60012 .37465 Mdot
.60187 .4262 Mdot
.37109 .33421 Mdot
.50536 .62737 Mdot
.55976 .82101 Mdot
.40628 .33781 Mdot
.31651 .52655 Mdot
.3764 .40524 Mdot
.52242 .44761 Mdot
.47485 .67946 Mdot
.40187 .6462 Mdot
.22431 .4825 Mdot
.71985 .503 Mdot
.61196 .40743 Mdot
.29688 .39987 Mdot
.45962 .62648 Mdot
.38613 .34961 Mdot
.35578 .54204 Mdot
.61603 .35868 Mdot
.35937 .3654 Mdot
.32064 .55409 Mdot
.6498 .62105 Mdot
.3052 .63365 Mdot
.38385 .39554 Mdot
.47978 .47188 Mdot
.36247 .5725 Mdot
.3632 .5183 Mdot
.77904 .35663 Mdot
.37407 .33964 Mdot
.61569 .61405 Mdot
.35189 .53151 Mdot
.73551 .46184 Mdot
.64077 .45902 Mdot
.68786 .55958 Mdot
.23848 .34044 Mdot
.79006 .48561 Mdot
.32818 .67673 Mdot
.62994 .60041 Mdot
.34859 .58679 Mdot
.60203 .44522 Mdot
.40655 .37772 Mdot
.39233 .38438 Mdot
.59875 .48298 Mdot
.62137 .4481 Mdot
.54983 .43471 Mdot
.55846 .40288 Mdot
.69229 .45418 Mdot
.54661 .39288 Mdot
.46163 .33188 Mdot
.40238 .36093 Mdot
.59678 .45361 Mdot
.45555 .68569 Mdot
.62944 .48513 Mdot
.32497 .53629 Mdot
.58588 .42563 Mdot
.59994 .45824 Mdot
.62377 .4738 Mdot
.36938 .53417 Mdot
.7939 .6612 Mdot
.41508 .25307 Mdot
.77599 .661 Mdot
.55499 .54044 Mdot
.47386 .69617 Mdot
.61853 .41496 Mdot
.62567 .6311 Mdot
.59293 .29329 Mdot
.58469 .46262 Mdot
.1386 .60983 Mdot
.58681 .43537 Mdot
.70969 .72016 Mdot
.6294 .49765 Mdot
.79099 .60797 Mdot
.71004 .55296 Mdot
.61326 .43662 Mdot
.33946 .43554 Mdot
.38065 .55349 Mdot
.4218 .65671 Mdot
.33427 .53254 Mdot
.45115 .67998 Mdot
.48677 .65849 Mdot
.44764 .58156 Mdot
.52553 .46891 Mdot
.6548 .46068 Mdot
.54452 .43465 Mdot
.50906 .68379 Mdot
.4231 .34561 Mdot
.6523 .60714 Mdot
.35923 .32758 Mdot
.72817 .76355 Mdot
.45583 .75986 Mdot
.33988 .49965 Mdot
.64894 .63727 Mdot
.49689 .63389 Mdot
.50405 .66258 Mdot
.64275 .60223 Mdot
.57962 .40141 Mdot
.37184 .34371 Mdot
.79267 .40812 Mdot
.22344 .56688 Mdot
.72742 .23983 Mdot
.40892 .34566 Mdot
.31661 .43441 Mdot
.3255 .52346 Mdot
.47192 .64513 Mdot
.60044 .42882 Mdot
.59003 .40242 Mdot
.34325 .37877 Mdot
.55038 .42714 Mdot
.34421 .29615 Mdot
.60832 .43109 Mdot
.30491 .59441 Mdot
.66391 .61028 Mdot
.44868 .58206 Mdot
.74328 .50322 Mdot
.42052 .37544 Mdot
.67191 .27369 Mdot
.50192 .67469 Mdot
.59018 .28849 Mdot
.33039 .56354 Mdot
.6437 .63404 Mdot
.48553 .68422 Mdot
.64797 .60006 Mdot
.56026 .38089 Mdot
.4447 .65736 Mdot
.62282 .59317 Mdot
.61655 .54603 Mdot
.65015 .45517 Mdot
.17929 .506 Mdot
.34015 .51103 Mdot
.34887 .33048 Mdot
.58338 .47714 Mdot
.4976 .68636 Mdot
.61823 .35556 Mdot
.3563 .73224 Mdot
.33704 .61798 Mdot
.46179 .62417 Mdot
.50736 .59086 Mdot
.63149 .64071 Mdot
.3785 .69892 Mdot
.30162 .41413 Mdot
.35428 .33579 Mdot
.54986 .39673 Mdot
.81305 .58198 Mdot
.35255 .53233 Mdot
.58547 .47412 Mdot
.68322 .67497 Mdot
.36159 .53381 Mdot
.58996 .41782 Mdot
.32076 .56201 Mdot
.39128 .38447 Mdot
.48605 .20715 Mdot
.37527 .33145 Mdot
.54887 .41818 Mdot
.34758 .56252 Mdot
.51931 .64363 Mdot
.39403 .37592 Mdot
.56902 .40654 Mdot
.62674 .41897 Mdot
.52919 .57847 Mdot
.59103 .44762 Mdot
.76262 .68731 Mdot
.61121 .43374 Mdot
.48402 .64629 Mdot
.64274 .43616 Mdot
.35913 .2362 Mdot
.44094 .58105 Mdot
.36954 .33919 Mdot
.46735 .6202 Mdot
.4886 .66665 Mdot
.49279 .76824 Mdot
.31624 .57488 Mdot
.61363 .3805 Mdot
.48923 .69248 Mdot
.72415 .39947 Mdot
.34695 .57764 Mdot
.57931 .48267 Mdot
.45455 .45623 Mdot
.55355 .68453 Mdot
.43976 .66302 Mdot
.56513 .35343 Mdot
.39648 .3979 Mdot
.60823 .45822 Mdot
.50787 .65572 Mdot
.51096 .42569 Mdot
.62643 .39575 Mdot
.27689 .31845 Mdot
.53062 .58649 Mdot
.3668 .56286 Mdot
.60465 .49944 Mdot
.56602 .45482 Mdot
.44733 .66228 Mdot
.41797 .37598 Mdot
.35062 .57808 Mdot
.384 .37529 Mdot
.79076 .59141 Mdot
.18586 .5099 Mdot
.64291 .52258 Mdot
.65055 .59696 Mdot
.57155 .64769 Mdot
.79577 .59213 Mdot
.60207 .20634 Mdot
.70982 .31661 Mdot
.81172 .4946 Mdot
.51245 .65019 Mdot
.6159 .67639 Mdot
.48365 .66446 Mdot
.63103 .43697 Mdot
.47308 .67769 Mdot
.81908 .57093 Mdot
.60553 .4323 Mdot
.46536 .67156 Mdot
.64137 .25392 Mdot
.60668 .45532 Mdot
.3577 .33499 Mdot
.72425 .74916 Mdot
.44586 .18017 Mdot
.33333 .61297 Mdot
.47199 .6334 Mdot
.73751 .35886 Mdot
.59481 .4371 Mdot
.64239 .43515 Mdot
.40973 .36978 Mdot
.64457 .36494 Mdot
.61046 .62863 Mdot
.64366 .64214 Mdot
.38624 .51412 Mdot
.67246 .63698 Mdot
.60113 .50006 Mdot
.39666 .37446 Mdot
.68462 .46309 Mdot
.5117 .74829 Mdot
.56687 .68108 Mdot
.36227 .49534 Mdot
.72409 .74799 Mdot
.42497 .32949 Mdot
.28401 .53473 Mdot
.50594 .71695 Mdot
.39337 .34189 Mdot
.81282 .64043 Mdot
.3345 .53736 Mdot
.17793 .53805 Mdot
.35371 .43282 Mdot
.58075 .40334 Mdot
.34994 .5726 Mdot
.56512 .36097 Mdot
.4665 .17628 Mdot
.20468 .6143 Mdot
.50219 .37491 Mdot
.56133 .463 Mdot
.49814 .73821 Mdot
.59184 .42678 Mdot
.42202 .75929 Mdot
.61703 .43129 Mdot
.38444 .37108 Mdot
.34358 .46227 Mdot
.4 .58341 Mdot
.36477 .27014 Mdot
.38833 .71741 Mdot
.62616 .59896 Mdot
.608 .42782 Mdot
.57811 .40481 Mdot
.60476 .61685 Mdot
.38943 .39067 Mdot
.54799 .42547 Mdot
.66872 .26536 Mdot
.58792 .3918 Mdot
.32764 .53856 Mdot
.31565 .35973 Mdot
.44503 .33823 Mdot
.57369 .38931 Mdot
.4265 .38831 Mdot
.35285 .49945 Mdot
.34651 .55994 Mdot
.6124 .50202 Mdot
.32536 .51115 Mdot
.58078 .4406 Mdot
.22261 .64582 Mdot
.37318 .39109 Mdot
.24019 .373 Mdot
.3648 .35963 Mdot
.50782 .27927 Mdot
.36642 .53627 Mdot
.32449 .62791 Mdot
.53915 .38101 Mdot
.33809 .54077 Mdot
.37863 .41441 Mdot
.65327 .41333 Mdot
.65741 .42865 Mdot
.77671 .39453 Mdot
.48933 .64018 Mdot
.52136 .57953 Mdot
.32045 .5261 Mdot
.55928 .42369 Mdot
.57581 .38169 Mdot
.34929 .50005 Mdot
.2223 .6133 Mdot
.50464 .18564 Mdot
.60909 .43285 Mdot
.38715 .36268 Mdot
.38295 .3511 Mdot
.62 .48314 Mdot
.6188 .46353 Mdot
.47263 .68608 Mdot
.51418 .63202 Mdot
.46079 .6961 Mdot
.51858 .58246 Mdot
.32162 .62205 Mdot
.61036 .78466 Mdot
.33927 .50919 Mdot
.29217 .44962 Mdot
.5925 .56155 Mdot
.54215 .43767 Mdot
.47373 .62989 Mdot
.56722 .45408 Mdot
.58202 .45114 Mdot
.30601 .54912 Mdot
.69151 .69961 Mdot
.45073 .38462 Mdot
.41911 .38383 Mdot
.36447 .57457 Mdot
.59559 .5051 Mdot
.30856 .50399 Mdot
.64171 .63109 Mdot
.77698 .44743 Mdot
.32595 .55661 Mdot
.36333 .33304 Mdot
.34393 .51464 Mdot
.59236 .39834 Mdot
.52923 .41195 Mdot
.38912 .34134 Mdot
.60949 .63505 Mdot
.64816 .37103 Mdot
.59344 .41865 Mdot
.21838 .357 Mdot
.76079 .46085 Mdot
.28526 .57983 Mdot
.61094 .43651 Mdot
.59595 .38371 Mdot
.59527 .61742 Mdot
.5883 .39278 Mdot
.55791 .45288 Mdot
.46155 .24113 Mdot
.23813 .48764 Mdot
.65503 .63644 Mdot
.22814 .64264 Mdot
.40596 .3431 Mdot
.81152 .60377 Mdot
.46126 .64108 Mdot
.39797 .54066 Mdot
.45925 .19352 Mdot
.44359 .67546 Mdot
.32773 .68211 Mdot
.80846 .61961 Mdot
.41372 .59999 Mdot
.4463 .61617 Mdot
.44458 .38267 Mdot
.5526 .41314 Mdot
.60009 .42344 Mdot
.62112 .63153 Mdot
.37174 .34905 Mdot
.50771 .54988 Mdot
.37348 .79779 Mdot
.58066 .431 Mdot
.27053 .33525 Mdot
.27993 .69771 Mdot
.54828 .6945 Mdot
.63125 .62112 Mdot
.63468 .64721 Mdot
.6077 .42555 Mdot
.4261 .24202 Mdot
.39842 .38 Mdot
.56817 .40785 Mdot
.54363 .39742 Mdot
.47986 .6363 Mdot
.35355 .369 Mdot
.50349 .62599 Mdot
.3538 .65741 Mdot
.7604 .67773 Mdot
.15223 .50278 Mdot
.36336 .55116 Mdot
.40174 .77247 Mdot
.33187 .57481 Mdot
.71579 .57313 Mdot
.43465 .64322 Mdot
.61029 .46212 Mdot
.41594 .38021 Mdot
.55938 .43059 Mdot
.61806 .46222 Mdot
.57795 .4029 Mdot
.56902 .38967 Mdot
.14796 .45224 Mdot
.63055 .59745 Mdot
.59298 .36597 Mdot
.48799 .64952 Mdot
.49771 .80781 Mdot
.45335 .8024 Mdot
.5764 .40841 Mdot
.62065 .4241 Mdot
.36874 .38254 Mdot
.59413 .48134 Mdot
.33916 .57908 Mdot
.37456 .32198 Mdot
.60864 .39613 Mdot
.67517 .77946 Mdot
.61454 .38954 Mdot
.79091 .62696 Mdot
.34232 .51591 Mdot
.21218 .54521 Mdot
.53547 .39381 Mdot
.34949 .61375 Mdot
.52178 .57955 Mdot
.48061 .68623 Mdot
.31953 .56624 Mdot
.46598 .65928 Mdot
.34146 .77974 Mdot
.52619 .4398 Mdot
.60521 .44564 Mdot
.54079 .43151 Mdot
.47366 .69642 Mdot
.61757 .80753 Mdot
.40211 .71639 Mdot
.52004 .42038 Mdot
.4629 .68764 Mdot
.43218 .36851 Mdot
.76386 .41235 Mdot
.37089 .3691 Mdot
.62201 .58071 Mdot
.32621 .52688 Mdot
.61191 .63594 Mdot
.74044 .62932 Mdot
.34856 .3489 Mdot
.33971 .3567 Mdot
.46193 .64327 Mdot
.37294 .45098 Mdot
.45526 .13664 Mdot
.35146 .43172 Mdot
.72234 .531 Mdot
.40337 .37121 Mdot
.60409 .38785 Mdot
.72351 .60674 Mdot
.3562 .44522 Mdot
.46744 .66225 Mdot
.57659 .45436 Mdot
.4864 .20409 Mdot
.47299 .68626 Mdot
.54011 .44094 Mdot
.49152 .64692 Mdot
.33491 .52708 Mdot
.48201 .6298 Mdot
.33241 .34465 Mdot
.62077 .40604 Mdot
.4974 .12012 Mdot
.61104 .66613 Mdot
.59817 .4393 Mdot
.37107 .56599 Mdot
.27232 .64385 Mdot
.59453 .46991 Mdot
.63192 .59102 Mdot
.45974 .6742 Mdot
.39693 .44277 Mdot
.61229 .43222 Mdot
.46112 .68725 Mdot
.34401 .35621 Mdot
.35159 .58944 Mdot
.57867 .2267 Mdot
.33366 .60779 Mdot
.41157 .36881 Mdot
.51495 .50692 Mdot
.31179 .54499 Mdot
.59421 .38385 Mdot
.55445 .39342 Mdot
.3847 .35949 Mdot
.6518 .55682 Mdot
.63199 .45835 Mdot
.64257 .42636 Mdot
.47743 .64012 Mdot
.4625 .66113 Mdot
.6878 .31237 Mdot
.51146 .63574 Mdot
.53138 .40765 Mdot
.38295 .36089 Mdot
.59963 .46062 Mdot
.36552 .38243 Mdot
.59478 .48086 Mdot
.57428 .51594 Mdot
.39088 .39069 Mdot
.30724 .57044 Mdot
.57981 .45421 Mdot
.66976 .40086 Mdot
.5947 .47575 Mdot
.55606 .40897 Mdot
.47719 .6829 Mdot
.63222 .62807 Mdot
.53665 .41609 Mdot
.62702 .65959 Mdot
.65098 .60832 Mdot
.38858 .58749 Mdot
.48272 .63677 Mdot
.61363 .6071 Mdot
.29036 .71678 Mdot
.44521 .66946 Mdot
.61453 .62885 Mdot
.45516 .80293 Mdot
.35645 .52096 Mdot
.39416 .39889 Mdot
.60981 .45425 Mdot
.77725 .58914 Mdot
.4614 .34735 Mdot
.4757 .61244 Mdot
.60781 .43532 Mdot
.58361 .47144 Mdot
.41549 .34505 Mdot
.38312 .81927 Mdot
.47711 .70474 Mdot
.61657 .38648 Mdot
.35551 .34238 Mdot
.38616 .83763 Mdot
.48364 .65222 Mdot
.61813 .63251 Mdot
.35576 .51527 Mdot
.44255 .39883 Mdot
.22197 .48291 Mdot
.37545 .54263 Mdot
.46388 .71917 Mdot
.35933 .65196 Mdot
.59051 .37279 Mdot
.46812 .62844 Mdot
.74918 .28546 Mdot
.69463 .41708 Mdot
.4805 .57078 Mdot
.74166 .36744 Mdot
.39994 .34784 Mdot
.3342 .57617 Mdot
.63179 .59993 Mdot
.41455 .35328 Mdot
.346 .35309 Mdot
.34459 .50231 Mdot
.4345 .25628 Mdot
.44996 .45459 Mdot
.32894 .54838 Mdot
.7775 .50854 Mdot
.62091 .75987 Mdot
.46983 .62976 Mdot
.6097 .62703 Mdot
.72604 .6481 Mdot
.38026 .37532 Mdot
.7541 .72929 Mdot
.78012 .39209 Mdot
.59474 .43518 Mdot
.61926 .60601 Mdot
.62329 .79577 Mdot
.42729 .8245 Mdot
.36382 .53736 Mdot
.39633 .57085 Mdot
.62014 .63999 Mdot
.58137 .47523 Mdot
.75488 .42725 Mdot
.6377 .43546 Mdot
.32915 .5224 Mdot
.61211 .2482 Mdot
.34748 .34757 Mdot
.35375 .50732 Mdot
.77767 .43989 Mdot
.57948 .43921 Mdot
.58072 .45641 Mdot
.7564 .52012 Mdot
.4212 .36195 Mdot
.4808 .68655 Mdot
.56657 .37937 Mdot
.59079 .42153 Mdot
.53342 .43216 Mdot
.59398 .49626 Mdot
.46287 .2255 Mdot
.62804 .43421 Mdot
.45788 .76901 Mdot
.56641 .46835 Mdot
.57188 .4433 Mdot
.42369 .39106 Mdot
.14504 .52151 Mdot
.37298 .6705 Mdot
.58811 .42451 Mdot
.60371 .38281 Mdot
.35265 .50838 Mdot
.40361 .45933 Mdot
.38769 .45335 Mdot
.40789 .43901 Mdot
.72423 .33614 Mdot
.64936 .45924 Mdot
.3652 .34277 Mdot
.62026 .59215 Mdot
.60952 .38015 Mdot
.36182 .34164 Mdot
.63257 .46632 Mdot
.47241 .68778 Mdot
.44611 .67203 Mdot
.68478 .45548 Mdot
.61394 .60335 Mdot
.30801 .31611 Mdot
.28855 .44865 Mdot
.44658 .6659 Mdot
.6083 .44579 Mdot
.34679 .59968 Mdot
.50671 .65876 Mdot
.4218 .59991 Mdot
.67195 .58772 Mdot
.40824 .37964 Mdot
.40261 .35848 Mdot
.68562 .56155 Mdot
.32963 .6655 Mdot
.27822 .29474 Mdot
.3339 .52597 Mdot
.5778 .36866 Mdot
.32043 .42197 Mdot
.40613 .35923 Mdot
.72439 .58749 Mdot
.61783 .60416 Mdot
.36033 .53155 Mdot
.45907 .73019 Mdot
.36278 .37255 Mdot
.35305 .37962 Mdot
.59151 .48672 Mdot
.59004 .41165 Mdot
.7046 .31024 Mdot
.61757 .65901 Mdot
.37512 .5326 Mdot
.61314 .63138 Mdot
.43584 .64157 Mdot
.63432 .42061 Mdot
.39225 .38894 Mdot
.59981 .77556 Mdot
.60125 .37709 Mdot
.49314 .67263 Mdot
.39967 .35055 Mdot
.63178 .64149 Mdot
.62542 .58927 Mdot
.56223 .40072 Mdot
.65419 .2881 Mdot
.33506 .54737 Mdot
.3864 .33622 Mdot
.30111 .51241 Mdot
.63664 .44403 Mdot
.59859 .41184 Mdot
.66185 .46703 Mdot
.37557 .5343 Mdot
.26493 .51118 Mdot
.64998 .59865 Mdot
.37572 .34596 Mdot
.62596 .43094 Mdot
.60821 .61911 Mdot
.30417 .44979 Mdot
.45272 .62713 Mdot
.48693 .63066 Mdot
.61859 .58972 Mdot
.62816 .61315 Mdot
.64247 .59477 Mdot
.75608 .72812 Mdot
.40263 .33121 Mdot
.43089 .33504 Mdot
.64838 .41003 Mdot
.71276 .54451 Mdot
.59963 .36367 Mdot
.35846 .57505 Mdot
.49304 .64279 Mdot
.60495 .46928 Mdot
.57514 .39067 Mdot
.62549 .50116 Mdot
.2535 .34899 Mdot
.46151 .37457 Mdot
.35038 .36504 Mdot
.52966 .40707 Mdot
.47012 .6353 Mdot
.7438 .7582 Mdot
.80412 .4017 Mdot
.5336 .39652 Mdot
.45114 .4497 Mdot
.39987 .39 Mdot
.34058 .50768 Mdot
.75859 .56426 Mdot
.35413 .5174 Mdot
.37958 .34517 Mdot
.63082 .43099 Mdot
.28275 .46559 Mdot
.59426 .61495 Mdot
.55708 .42012 Mdot
.33381 .51941 Mdot
.55265 .43204 Mdot
.37515 .53506 Mdot
.77553 .60956 Mdot
.7282 .28635 Mdot
.58804 .43502 Mdot
.62441 .37292 Mdot
.71688 .30508 Mdot
.57164 .41173 Mdot
.59197 .6003 Mdot
.40033 .39019 Mdot
.61981 .24715 Mdot
.65678 .41132 Mdot
.68056 .34599 Mdot
.63926 .43796 Mdot
.59031 .22301 Mdot
.59697 .40902 Mdot
.54031 .70331 Mdot
.62455 .4038 Mdot
.55243 .44726 Mdot
.35699 .55951 Mdot
.35528 .50825 Mdot
.40431 .4023 Mdot
.50659 .67464 Mdot
.78589 .64179 Mdot
.59609 .41646 Mdot
.34664 .62447 Mdot
.24715 .50814 Mdot
.62959 .61558 Mdot
.3768 .34893 Mdot
.43498 .84677 Mdot
.31784 .53008 Mdot
.76519 .35123 Mdot
.69651 .3242 Mdot
.24071 .4379 Mdot
.69634 .66042 Mdot
.27863 .66819 Mdot
.6385 .63856 Mdot
.62323 .47347 Mdot
.63491 .72634 Mdot
.53153 .71228 Mdot
.65741 .57206 Mdot
.31536 .56094 Mdot
.62372 .295 Mdot
.67654 .70952 Mdot
.61542 .58528 Mdot
.62719 .64483 Mdot
.37222 .54081 Mdot
.45843 .60732 Mdot
.52494 .46529 Mdot
.62513 .60455 Mdot
.46958 .69774 Mdot
.44218 .65816 Mdot
.46347 .70043 Mdot
.39743 .38272 Mdot
.7888 .38742 Mdot
.32816 .49709 Mdot
.36417 .56628 Mdot
.51274 .60719 Mdot
.56759 .33641 Mdot
.35464 .31914 Mdot
.46696 .6479 Mdot
.50009 .62969 Mdot
.39925 .39266 Mdot
.5638 .48653 Mdot
.54413 .47729 Mdot
.58416 .42829 Mdot
.62753 .62985 Mdot
.59155 .4067 Mdot
.46287 .68565 Mdot
.36296 .54423 Mdot
.4996 .63247 Mdot
.37159 .56843 Mdot
.57942 .79344 Mdot
.5685 .4026 Mdot
.6235 .40731 Mdot
.19146 .40861 Mdot
.36167 .39345 Mdot
.51815 .80056 Mdot
.29792 .57474 Mdot
.48465 .6622 Mdot
.55991 .4546 Mdot
.36994 .32153 Mdot
.61074 .65297 Mdot
.15859 .51128 Mdot
.62251 .46326 Mdot
.37796 .3814 Mdot
.63266 .4216 Mdot
.70395 .42816 Mdot
.3221 .25034 Mdot
.37881 .36739 Mdot
.25919 .32349 Mdot
.60803 .38573 Mdot
.32134 .73297 Mdot
.57208 .47678 Mdot
.68048 .49869 Mdot
.63203 .45821 Mdot
.40624 .3429 Mdot
.58298 .42502 Mdot
.36885 .32303 Mdot
.44793 .65158 Mdot
.34674 .50909 Mdot
.40951 .36673 Mdot
.55963 .3927 Mdot
.46669 .0729 Mdot
.34069 .52456 Mdot
.60405 .42815 Mdot
.36742 .53206 Mdot
.36871 .3513 Mdot
.40645 .34813 Mdot
.42036 .81264 Mdot
.35403 .66017 Mdot
.3362 .52832 Mdot
.63383 .4207 Mdot
.35805 .74685 Mdot
.61937 .45307 Mdot
.72957 .40332 Mdot
.54854 .47234 Mdot
.64595 .42949 Mdot
.46278 .81132 Mdot
.36728 .56291 Mdot
.27808 .29177 Mdot
.45024 .81992 Mdot
.49497 .80807 Mdot
.35401 .39326 Mdot
.61115 .58857 Mdot
.80672 .64798 Mdot
.31977 .62118 Mdot
.46472 .69021 Mdot
.59785 .47216 Mdot
.32676 .35904 Mdot
.33618 .55238 Mdot
.64039 .62817 Mdot
.58918 .43444 Mdot
.49071 .62757 Mdot
.56249 .19532 Mdot
.35227 .58537 Mdot
.37559 .3691 Mdot
.42774 .36176 Mdot
.23254 .69397 Mdot
.61639 .43517 Mdot
.61776 .40217 Mdot
.32633 .52584 Mdot
.25257 .63697 Mdot
.6536 .6258 Mdot
.63908 .25036 Mdot
.33793 .52951 Mdot
.47204 .52288 Mdot
.3641 .33669 Mdot
.5792 .46839 Mdot
.68863 .75641 Mdot
.45538 .73588 Mdot
.20779 .39017 Mdot
.6247 .6303 Mdot
.7306 .40767 Mdot
.40389 .34109 Mdot
.35437 .53812 Mdot
.30043 .64507 Mdot
.65419 .45559 Mdot
.56577 .44975 Mdot
.72349 .43548 Mdot
.39607 .58594 Mdot
.44791 .41586 Mdot
.6277 .45736 Mdot
.51491 .57881 Mdot
.61347 .47066 Mdot
.65978 .40331 Mdot
.5345 .44847 Mdot
.60804 .40983 Mdot
.38627 .38689 Mdot
.64175 .34066 Mdot
.48422 .69125 Mdot
.40738 .31987 Mdot
.47006 .53014 Mdot
.60236 .43626 Mdot
.64064 .41685 Mdot
.48939 .37731 Mdot
.32233 .69331 Mdot
.40693 .36572 Mdot
.3377 .35702 Mdot
.32139 .51576 Mdot
.55591 .48539 Mdot
.50867 .66934 Mdot
.6291 .36301 Mdot
.48274 .67937 Mdot
.39038 .38768 Mdot
.48431 .65851 Mdot
.35988 .51702 Mdot
.4612 .63178 Mdot
.32276 .62326 Mdot
.34946 .52551 Mdot
.41069 .37594 Mdot
.6067 .39869 Mdot
.37019 .56821 Mdot
.72993 .49194 Mdot
.62543 .62908 Mdot
.51867 .85243 Mdot
.60925 .39577 Mdot
.23159 .48914 Mdot
.50947 .45002 Mdot
.50032 .63122 Mdot
.31272 .25567 Mdot
.41574 .3864 Mdot
.64704 .64425 Mdot
.42391 .36934 Mdot
.76788 .43325 Mdot
.62285 .61828 Mdot
.50972 .83465 Mdot
.54936 .59193 Mdot
.75875 .45452 Mdot
.57365 .49405 Mdot
.75564 .4968 Mdot
.4379 .653 Mdot
.33846 .55421 Mdot
.31148 .65874 Mdot
.5555 .44911 Mdot
.63631 .2134 Mdot
.42725 .37882 Mdot
.50191 .68027 Mdot
.35686 .54497 Mdot
.35243 .57827 Mdot
.62991 .39076 Mdot
.58526 .69772 Mdot
.56205 .44816 Mdot
.32997 .65418 Mdot
.73067 .3542 Mdot
.39526 .30385 Mdot
.60788 .4309 Mdot
.44715 .66025 Mdot
.63265 .42188 Mdot
.65436 .60177 Mdot
.77962 .34445 Mdot
.65752 .38297 Mdot
.28484 .56888 Mdot
.59298 .6494 Mdot
.37731 .33494 Mdot
.53178 .49417 Mdot
.29752 .59298 Mdot
.61882 .43585 Mdot
.12591 .44217 Mdot
.61142 .62483 Mdot
.63555 .72264 Mdot
.58428 .38196 Mdot
.61216 .37901 Mdot
.44736 .55758 Mdot
.21848 .46928 Mdot
.4747 .7442 Mdot
.56775 .42056 Mdot
.7148 .47461 Mdot
.3712 .55222 Mdot
.59043 .47823 Mdot
.60222 .4242 Mdot
.4503 .2879 Mdot
.35633 .58024 Mdot
.49278 .66191 Mdot
.44203 .67377 Mdot
.48014 .61309 Mdot
.65983 .61208 Mdot
.32795 .47825 Mdot
.72689 .56216 Mdot
.49832 .17682 Mdot
.62308 .64862 Mdot
.57715 .39122 Mdot
.63908 .67068 Mdot
.63428 .43085 Mdot
.63999 .62174 Mdot
.35572 .58135 Mdot
.41026 .36278 Mdot
.32643 .43452 Mdot
.4468 .67785 Mdot
.65309 .46148 Mdot
.6556 .625 Mdot
.40639 .37843 Mdot
.74372 .60648 Mdot
.37578 .3367 Mdot
.34102 .53911 Mdot
.31831 .48472 Mdot
.64205 .62537 Mdot
.36505 .35389 Mdot
.28354 .54551 Mdot
.40738 .81831 Mdot
.52952 .44273 Mdot
.30292 .4824 Mdot
.38472 .33091 Mdot
.33776 .34315 Mdot
.38447 .3269 Mdot
.55173 .42411 Mdot
.45253 .45041 Mdot
.64629 .44459 Mdot
.36878 .56061 Mdot
.49331 .65009 Mdot
.69223 .27008 Mdot
.40101 .68059 Mdot
.48444 .45897 Mdot
.5544 .37993 Mdot
.57792 .43862 Mdot
.60729 .42563 Mdot
.65672 .40271 Mdot
.29896 .61744 Mdot
.56004 .43817 Mdot
.35634 .56058 Mdot
.46138 .67866 Mdot
.62481 .47274 Mdot
.52021 .67954 Mdot
.48493 .79838 Mdot
.60872 .63672 Mdot
.38076 .51702 Mdot
.81112 .38302 Mdot
.40669 .37568 Mdot
.46946 .62016 Mdot
.45343 .67679 Mdot
.64875 .62479 Mdot
.33061 .54403 Mdot
.37355 .33767 Mdot
.72546 .40418 Mdot
.65011 .60683 Mdot
.58596 .42348 Mdot
.45102 .43693 Mdot
.67261 .23448 Mdot
.61855 .47524 Mdot
.59681 .46616 Mdot
.45918 .70074 Mdot
.64638 .71118 Mdot
.5841 .14515 Mdot
.74079 .56055 Mdot
.63666 .6282 Mdot
.60254 .60397 Mdot
.38917 .39497 Mdot
.65411 .41143 Mdot
.37419 .54902 Mdot
.34901 .42141 Mdot
.26929 .52973 Mdot
.29535 .3438 Mdot
.19918 .43051 Mdot
.61158 .46935 Mdot
.23486 .63344 Mdot
.5802 .4429 Mdot
.40337 .332 Mdot
.38775 .38445 Mdot
.39358 .36914 Mdot
.33864 .55331 Mdot
.53832 .29713 Mdot
.34716 .5637 Mdot
.80364 .3339 Mdot
.39848 .33969 Mdot
.54465 .59394 Mdot
.4687 .64078 Mdot
.52044 .42558 Mdot
.62478 .64038 Mdot
.3055 .4885 Mdot
.67631 .45515 Mdot
.39312 .24932 Mdot
.49343 .68876 Mdot
.41232 .37357 Mdot
.26374 .64731 Mdot
.82472 .49648 Mdot
.39876 .44694 Mdot
.63537 .49882 Mdot
.75939 .5666 Mdot
.6331 .61753 Mdot
.20595 .39311 Mdot
.61717 .63667 Mdot
.33459 .51886 Mdot
.62448 .41305 Mdot
.61396 .40612 Mdot
.61265 .47177 Mdot
.57205 .40484 Mdot
.31251 .52518 Mdot
.54523 .40113 Mdot
.35936 .23618 Mdot
.45168 .68369 Mdot
.62402 .54384 Mdot
.61849 .63521 Mdot
.32881 .58019 Mdot
.46128 .67971 Mdot
.3208 .68817 Mdot
.74053 .50666 Mdot
.61079 .43211 Mdot
.60314 .47034 Mdot
.75395 .32936 Mdot
.62857 .4559 Mdot
.51517 .4221 Mdot
.46295 .68895 Mdot
.49028 .44428 Mdot
.61046 .63757 Mdot
.59993 .6118 Mdot
.3507 .5241 Mdot
.38611 .38586 Mdot
.61232 .62 Mdot
.4723 .63965 Mdot
.55186 .38213 Mdot
.55248 .39222 Mdot
.3868 .33172 Mdot
.76414 .33186 Mdot
.64552 .59346 Mdot
.34529 .74123 Mdot
.41252 .38171 Mdot
.40994 .40507 Mdot
.56654 .45092 Mdot
.22495 .37431 Mdot
.33538 .36916 Mdot
.65422 .64281 Mdot
.32525 .57665 Mdot
.76149 .54276 Mdot
.32014 .55027 Mdot
.37352 .36909 Mdot
.62418 .39271 Mdot
.39955 .38578 Mdot
.61261 .43529 Mdot
.84196 .50753 Mdot
.6085 .40618 Mdot
.47904 .17752 Mdot
.67493 .54992 Mdot
.45464 .65417 Mdot
.30889 .68775 Mdot
.46127 .64163 Mdot
.41858 .37394 Mdot
.60124 .37547 Mdot
.64509 .63902 Mdot
.44772 .78812 Mdot
.33703 .39614 Mdot
.50453 .65648 Mdot
.50822 .67938 Mdot
.31925 .55341 Mdot
.63028 .46167 Mdot
.56365 .44598 Mdot
.4641 .66904 Mdot
.3523 .294 Mdot
.36134 .36575 Mdot
.62363 .42297 Mdot
.57386 .4386 Mdot
.45652 .65055 Mdot
.38963 .81146 Mdot
.66149 .35286 Mdot
.61935 .41423 Mdot
.45019 .74629 Mdot
.35845 .57408 Mdot
.52333 .43436 Mdot
.61563 .37005 Mdot
.62802 .61036 Mdot
.50999 .22373 Mdot
.78803 .42593 Mdot
.35386 .58299 Mdot
.45328 .68023 Mdot
.62104 .43325 Mdot
.44734 .66394 Mdot
.54846 .39601 Mdot
.22099 .45726 Mdot
.45719 .62659 Mdot
.64387 .42169 Mdot
.57646 .49132 Mdot
.42072 .35999 Mdot
.60818 .46975 Mdot
.5201 .34772 Mdot
.49707 .67488 Mdot
.62709 .38948 Mdot
.64176 .27558 Mdot
.327 .55068 Mdot
.58124 .49746 Mdot
.64241 .6003 Mdot
.72562 .39183 Mdot
.27063 .4534 Mdot
.7008 .68888 Mdot
.59869 .61215 Mdot
.5537 .43252 Mdot
.50441 .6825 Mdot
.37297 .5274 Mdot
.44389 .18272 Mdot
.57878 .47235 Mdot
.33129 .52152 Mdot
.36262 .54272 Mdot
.64009 .63157 Mdot
.14601 .54036 Mdot
.57739 .38626 Mdot
.57878 .40766 Mdot
.49084 .32008 Mdot
.34825 .37393 Mdot
.59882 .40364 Mdot
.5953 .38904 Mdot
.35962 .55887 Mdot
.56005 .49985 Mdot
.62791 .31052 Mdot
.61611 .23525 Mdot
.35793 .49975 Mdot
.3121 .38961 Mdot
.44869 .63601 Mdot
.60595 .61049 Mdot
.39058 .34477 Mdot
.65385 .6298 Mdot
.47968 .63292 Mdot
.59759 .3906 Mdot
.33195 .51294 Mdot
.4959 .35596 Mdot
.37217 .53944 Mdot
.68295 .68263 Mdot
.35977 .33082 Mdot
.3899 .49403 Mdot
.12506 .47252 Mdot
.38688 .73059 Mdot
.39092 .59817 Mdot
.62921 .61525 Mdot
.41425 .64033 Mdot
.5751 .43959 Mdot
.19905 .40293 Mdot
.5772 .39256 Mdot
.62869 .2641 Mdot
.45697 .68955 Mdot
.46215 .69719 Mdot
.62259 .41453 Mdot
.72948 .35723 Mdot
.37205 .52376 Mdot
.34725 .57663 Mdot
.64393 .41124 Mdot
.33781 .54001 Mdot
.58552 .4121 Mdot
.46782 .68547 Mdot
.23019 .32379 Mdot
.58791 .43036 Mdot
.65255 .38563 Mdot
.22831 .45777 Mdot
.4642 .81706 Mdot
.58649 .65384 Mdot
.27866 .74437 Mdot
.82419 .46699 Mdot
.33889 .54194 Mdot
.65011 .42696 Mdot
.30809 .38213 Mdot
.46784 .70549 Mdot
.2815 .53858 Mdot
.59648 .39519 Mdot
.58416 .39264 Mdot
.5532 .44982 Mdot
.5853 .45944 Mdot
.17057 .49762 Mdot
.33599 .39907 Mdot
.52201 .25455 Mdot
.61541 .46479 Mdot
.74478 .48592 Mdot
.3432 .51779 Mdot
.42299 .40983 Mdot
.63556 .65138 Mdot
.61021 .46978 Mdot
.42521 .33934 Mdot
.3336 .50601 Mdot
.79865 .31896 Mdot
.33112 .51798 Mdot
.48764 .66713 Mdot
.36321 .51614 Mdot
.59202 .44675 Mdot
.38327 .3515 Mdot
.42018 .5012 Mdot
.37976 .69601 Mdot
.46689 .69195 Mdot
.59869 .43905 Mdot
.53349 .59961 Mdot
.48564 .69181 Mdot
.5075 .80973 Mdot
.39015 .35031 Mdot
.70838 .48497 Mdot
.39489 .38637 Mdot
.63876 .40263 Mdot
.63687 .40148 Mdot
.33671 .49673 Mdot
.35973 .51504 Mdot
.39276 .38636 Mdot
.14571 .57957 Mdot
.64398 .5943 Mdot
.3907 .37057 Mdot
.65929 .4499 Mdot
.43737 .46759 Mdot
.38649 .3555 Mdot
.60451 .57546 Mdot
.3627 .54989 Mdot
.37624 .39821 Mdot
.56177 .4649 Mdot
.77887 .49917 Mdot
.61433 .59262 Mdot
.43289 .65442 Mdot
.72803 .61094 Mdot
.50312 .66766 Mdot
.31991 .56763 Mdot
.45943 .64282 Mdot
.36645 .5595 Mdot
.26023 .47799 Mdot
.39191 .30947 Mdot
.41785 .58459 Mdot
.31293 .54064 Mdot
.46208 .64366 Mdot
.62808 .41582 Mdot
.60982 .66576 Mdot
.64127 .39368 Mdot
.5479 .4113 Mdot
.35607 .57025 Mdot
.41545 .35562 Mdot
.33705 .36831 Mdot
.75128 .44024 Mdot
.37864 .38559 Mdot
.49578 .66999 Mdot
.39609 .23634 Mdot
.36848 .62771 Mdot
.32371 .55621 Mdot
.35039 .50914 Mdot
.63441 .43917 Mdot
.46642 .66007 Mdot
.46569 .69383 Mdot
.3186 .54618 Mdot
.24612 .37342 Mdot
.63812 .37972 Mdot
.3372 .33743 Mdot
.35289 .38106 Mdot
.38041 .36464 Mdot
.37876 .32537 Mdot
.65257 .3356 Mdot
.36031 .52752 Mdot
.41894 .36283 Mdot
.63461 .44105 Mdot
.58982 .39317 Mdot
.33926 .41917 Mdot
.61395 .59668 Mdot
.62875 .47158 Mdot
.5367 .45375 Mdot
.57804 .4666 Mdot
.48105 .62845 Mdot
.55613 .35125 Mdot
.47279 .6242 Mdot
.49067 .69649 Mdot
.48266 .70127 Mdot
.31951 .62013 Mdot
.75073 .34578 Mdot
.80514 .53287 Mdot
.61319 .38388 Mdot
.25989 .67029 Mdot
.47509 .65399 Mdot
.36237 .2493 Mdot
.2615 .51764 Mdot
.56308 .45702 Mdot
.48987 .75518 Mdot
.46118 .66517 Mdot
.40512 .3908 Mdot
.60194 .3988 Mdot
.49037 .61691 Mdot
.63837 .59694 Mdot
.63415 .39213 Mdot
.44989 .62923 Mdot
.36544 .35056 Mdot
.66104 .6359 Mdot
.36936 .39848 Mdot
.48182 .70189 Mdot
.60664 .50109 Mdot
.35281 .18485 Mdot
.51981 .62794 Mdot
.3341 .75615 Mdot
.59933 .52586 Mdot
.62607 .42051 Mdot
.49032 .62065 Mdot
.39118 .40894 Mdot
.32201 .5702 Mdot
.52513 .54323 Mdot
.36503 .38713 Mdot
.4621 .69724 Mdot
.50753 .64805 Mdot
.46645 .69196 Mdot
.34965 .36657 Mdot
.63431 .47217 Mdot
.3601 .3768 Mdot
.36589 .51895 Mdot
.61157 .4558 Mdot
.79286 .59513 Mdot
.24737 .62712 Mdot
.40914 .3849 Mdot
.49817 .65497 Mdot
.59491 .61544 Mdot
.58424 .43948 Mdot
.24763 .63859 Mdot
.62991 .4189 Mdot
.36195 .56771 Mdot
.47015 .23582 Mdot
.469 .38591 Mdot
.64725 .42692 Mdot
.63131 .44256 Mdot
.34588 .57568 Mdot
.59612 .4357 Mdot
.63163 .45911 Mdot
.31932 .62323 Mdot
.353 .36426 Mdot
.57975 .42783 Mdot
.48772 .64479 Mdot
.36612 .64725 Mdot
.64397 .38156 Mdot
.40938 .61952 Mdot
.70523 .4822 Mdot
.46234 .24717 Mdot
.57901 .39191 Mdot
.45907 .41864 Mdot
.57542 .45468 Mdot
.56024 .41381 Mdot
.63048 .43858 Mdot
.18064 .55997 Mdot
.45077 .62972 Mdot
.45135 .66964 Mdot
.60505 .59923 Mdot
.70477 .48393 Mdot
.62314 .60622 Mdot
.36478 .54623 Mdot
.59725 .7072 Mdot
.47027 .62441 Mdot
.36851 .36344 Mdot
.55654 .426 Mdot
.5199 .629 Mdot
.57317 .46301 Mdot
.59423 .44681 Mdot
.51117 .66273 Mdot
.4455 .63646 Mdot
.66798 .70996 Mdot
.62128 .59373 Mdot
.39833 .36842 Mdot
.63772 .45716 Mdot
.65429 .61521 Mdot
.58047 .38835 Mdot
.71257 .54698 Mdot
.39465 .3665 Mdot
.35488 .36798 Mdot
.33575 .36609 Mdot
.60182 .39188 Mdot
.58913 .44313 Mdot
.34734 .56461 Mdot
.41807 .38045 Mdot
.32568 .54586 Mdot
.51752 .55491 Mdot
.53179 .77653 Mdot
.59612 .395 Mdot
.33382 .46801 Mdot
.62392 .60006 Mdot
.50405 .65222 Mdot
.68761 .24804 Mdot
.60531 .59875 Mdot
.61512 .43327 Mdot
.49686 .68827 Mdot
.64174 .61434 Mdot
.70557 .44673 Mdot
.78933 .3332 Mdot
.59872 .62792 Mdot
.63421 .44173 Mdot
.57293 .50327 Mdot
.26581 .73076 Mdot
.59841 .62158 Mdot
.353 .51436 Mdot
.60365 .39264 Mdot
.3454 .31716 Mdot
.65555 .62774 Mdot
.44476 .76011 Mdot
.45925 .67147 Mdot
.7798 .48008 Mdot
.67705 .41779 Mdot
.34008 .29044 Mdot
.6035 .60655 Mdot
.37715 .34093 Mdot
.51271 .41932 Mdot
.56892 .45258 Mdot
.59756 .61433 Mdot
.31586 .57606 Mdot
.47168 .67948 Mdot
.36676 .66674 Mdot
.34977 .36815 Mdot
.30907 .56784 Mdot
.49912 .64618 Mdot
.35535 .748 Mdot
.54105 .20254 Mdot
.53863 .47055 Mdot
.2458 .69196 Mdot
.26286 .56926 Mdot
.58646 .48314 Mdot
.6098 .65 Mdot
.36767 .57312 Mdot
.32602 .51386 Mdot
.34127 .53512 Mdot
.25239 .49707 Mdot
.41034 .43876 Mdot
.45311 .62445 Mdot
.31725 .49192 Mdot
.60699 .60883 Mdot
.76145 .52857 Mdot
.54766 .40757 Mdot
.57901 .4363 Mdot
.63973 .44751 Mdot
.60644 .47283 Mdot
.56865 .44419 Mdot
.33064 .53713 Mdot
.25036 .47736 Mdot
.38125 .44716 Mdot
.38994 .36121 Mdot
.64612 .70258 Mdot
.47372 .64302 Mdot
.43096 .63973 Mdot
.64324 .60788 Mdot
.40616 .7469 Mdot
.52184 .67654 Mdot
.48554 .65959 Mdot
.6031 .4864 Mdot
.36152 .37144 Mdot
.51833 .4205 Mdot
.6327 .44214 Mdot
.49098 .67343 Mdot
.4639 .55555 Mdot
.5978 .31877 Mdot
.67901 .61522 Mdot
.66431 .64028 Mdot
.42656 .4474 Mdot
.60164 .59939 Mdot
.58317 .37414 Mdot
.32189 .25476 Mdot
.47915 .63233 Mdot
.47637 .66842 Mdot
.61568 .59812 Mdot
.22593 .3684 Mdot
.39625 .34554 Mdot
.36487 .47908 Mdot
.36947 .54119 Mdot
.62919 .39631 Mdot
.59008 .20538 Mdot
.58128 .52946 Mdot
.57455 .70226 Mdot
.33963 .52807 Mdot
.44905 .64942 Mdot
.5931 .36808 Mdot
.62554 .4513 Mdot
.62958 .60131 Mdot
.68736 .7204 Mdot
.5249 .42623 Mdot
.60237 .82274 Mdot
.72828 .28579 Mdot
.77546 .41885 Mdot
.56532 .44875 Mdot
.35237 .3664 Mdot
.43592 .66074 Mdot
.60821 .6249 Mdot
.65305 .45981 Mdot
.8009 .41933 Mdot
.38698 .33323 Mdot
.34908 .52912 Mdot
.45253 .52329 Mdot
.75502 .55184 Mdot
.5525 .41247 Mdot
.58897 .39116 Mdot
.55887 .41054 Mdot
.7175 .21954 Mdot
.47431 .626 Mdot
.40543 .3884 Mdot
.64176 .6297 Mdot
.37392 .37988 Mdot
.4515 .65456 Mdot
.43193 .58119 Mdot
.62779 .4083 Mdot
.37828 .33048 Mdot
.37903 .34086 Mdot
.3237 .52239 Mdot
.34214 .58613 Mdot
.47634 .53701 Mdot
.60726 .40684 Mdot
.51977 .65453 Mdot
.42002 .36179 Mdot
.44749 .43487 Mdot
.62254 .61611 Mdot
.36285 .55244 Mdot
.61098 .46751 Mdot
.46455 .62768 Mdot
.54959 .46675 Mdot
.40432 .36113 Mdot
.48473 .6595 Mdot
.59335 .77683 Mdot
.6043 .63049 Mdot
.58565 .39758 Mdot
.58519 .60328 Mdot
.45651 .68368 Mdot
.57489 .44233 Mdot
.37676 .76992 Mdot
.6051 .5755 Mdot
.40751 .72074 Mdot
.48162 .6981 Mdot
.33873 .61439 Mdot
.38458 .39485 Mdot
.23383 .53416 Mdot
.48139 .66955 Mdot
.31999 .72153 Mdot
.63237 .75622 Mdot
.56141 .37469 Mdot
.38154 .37517 Mdot
.26395 .57809 Mdot
.82209 .59039 Mdot
.33276 .76774 Mdot
.60376 .4272 Mdot
.51146 .63633 Mdot
.63769 .6075 Mdot
.32747 .56212 Mdot
.42099 .71197 Mdot
.66389 .60218 Mdot
.49406 .70285 Mdot
.63007 .43841 Mdot
.37087 .34468 Mdot
.35281 .55702 Mdot
.27132 .45855 Mdot
.47802 .64083 Mdot
.49526 .64939 Mdot
.61545 .37623 Mdot
.61708 .60386 Mdot
.2357 .58509 Mdot
.4671 .68768 Mdot
.74013 .3096 Mdot
.43764 .62234 Mdot
.65098 .60523 Mdot
.58403 .46324 Mdot
.75645 .43158 Mdot
.65531 .41829 Mdot
.40916 .79301 Mdot
.46929 .64348 Mdot
.40015 .36352 Mdot
.54933 .43247 Mdot
.66442 .27723 Mdot
.49666 .66808 Mdot
.44459 .4478 Mdot
.55452 .67421 Mdot
.36477 .53587 Mdot
.68318 .24518 Mdot
.59096 .40403 Mdot
.37275 .52712 Mdot
.63026 .6028 Mdot
.61438 .41208 Mdot
.58828 .44585 Mdot
.41476 .34526 Mdot
.3216 .52711 Mdot
.66266 .71876 Mdot
.35005 .50687 Mdot
.34251 .51478 Mdot
.36981 .31989 Mdot
.5757 .41955 Mdot
.48947 .66586 Mdot
.4626 .66532 Mdot
.56357 .46911 Mdot
.20975 .32965 Mdot
.39237 .34112 Mdot
.43926 .6724 Mdot
.69596 .19949 Mdot
.5778 .48408 Mdot
.66969 .24178 Mdot
.67852 .72558 Mdot
.37223 .55696 Mdot
.6347 .44203 Mdot
.36691 .35201 Mdot
.49594 .7323 Mdot
.4958 .65273 Mdot
.55204 .45247 Mdot
.35193 .55554 Mdot
.62659 .59253 Mdot
.48881 .68521 Mdot
.58382 .69942 Mdot
.56872 .40408 Mdot
.49898 .756 Mdot
.51123 .6424 Mdot
.78853 .66839 Mdot
.31117 .67421 Mdot
.38473 .37606 Mdot
.59539 .44956 Mdot
.41269 .3882 Mdot
.64475 .6264 Mdot
.45536 .52491 Mdot
.35955 .55126 Mdot
.56282 .33905 Mdot
.34751 .23101 Mdot
.46596 .69195 Mdot
.40952 .38753 Mdot
.64868 .41735 Mdot
.21884 .44964 Mdot
.58604 .40749 Mdot
.59764 .50893 Mdot
.68265 .66244 Mdot
.34189 .57118 Mdot
.37167 .5489 Mdot
.58272 .45283 Mdot
.6507 .62598 Mdot
.47354 .64089 Mdot
.48046 .67764 Mdot
.72378 .76126 Mdot
.38525 .4842 Mdot
.70402 .3122 Mdot
.58293 .39355 Mdot
.49704 .69889 Mdot
.39268 .64903 Mdot
.32731 .52514 Mdot
.60586 .49334 Mdot
.50717 .67165 Mdot
.58883 .58052 Mdot
.71586 .43287 Mdot
.57138 .45272 Mdot
.65899 .42393 Mdot
.36799 .53259 Mdot
.44291 .4218 Mdot
.44477 .65719 Mdot
.53937 .44966 Mdot
.42238 .56691 Mdot
.70314 .45664 Mdot
.75197 .29237 Mdot
.39829 .36871 Mdot
.58063 .68475 Mdot
.3302 .53799 Mdot
.65396 .38579 Mdot
.63286 .63869 Mdot
.4741 .70898 Mdot
.45994 .6273 Mdot
.62187 .43802 Mdot
.57132 .37479 Mdot
.71292 .28882 Mdot
.36654 .36953 Mdot
.3471 .51961 Mdot
.61539 .40201 Mdot
.33476 .44898 Mdot
.61572 .46989 Mdot
.34077 .56402 Mdot
.33233 .19705 Mdot
.64659 .40136 Mdot
.58134 .40826 Mdot
.24122 .59264 Mdot
.36019 .38497 Mdot
.42412 .37468 Mdot
.60776 .20079 Mdot
.58315 .39376 Mdot
.71372 .27514 Mdot
.40378 .36935 Mdot
.4019 .3504 Mdot
.32992 .64111 Mdot
.58308 .43691 Mdot
.6519 .35746 Mdot
.36768 .56114 Mdot
.34386 .5136 Mdot
.35644 .37565 Mdot
.52354 .43097 Mdot
.34415 .58395 Mdot
.19613 .55102 Mdot
.46631 .65815 Mdot
.29161 .26736 Mdot
.39199 .33918 Mdot
.38941 .56631 Mdot
.33316 .52396 Mdot
.8075 .35416 Mdot
.48866 .72298 Mdot
.62725 .41196 Mdot
.5789 .39686 Mdot
.61248 .60113 Mdot
.64354 .44288 Mdot
.46204 .69692 Mdot
.33741 .53913 Mdot
.69021 .33364 Mdot
.39354 .36971 Mdot
.59916 .40957 Mdot
.44345 .77733 Mdot
.54381 .80858 Mdot
.59073 .67552 Mdot
.37951 .33588 Mdot
.39371 .38236 Mdot
.45864 .63606 Mdot
.51254 .63946 Mdot
.56634 .42906 Mdot
.33936 .57614 Mdot
.41677 .38167 Mdot
.34478 .56843 Mdot
.48135 .63284 Mdot
.48822 .66388 Mdot
.44015 .63875 Mdot
.54825 .40329 Mdot
.48894 .65353 Mdot
.55545 .7802 Mdot
.30365 .52328 Mdot
.35719 .31898 Mdot
.6742 .21763 Mdot
.27522 .46134 Mdot
.34817 .39852 Mdot
.65751 .61921 Mdot
.46228 .6899 Mdot
.36658 .5171 Mdot
.60179 .46121 Mdot
.59379 .47446 Mdot
.36424 .61685 Mdot
.36214 .5073 Mdot
.64246 .62735 Mdot
.37321 .53446 Mdot
.64074 .63138 Mdot
.52246 .73458 Mdot
.62477 .46776 Mdot
.54763 .39499 Mdot
.33291 .53291 Mdot
.48701 .65611 Mdot
.45504 .67122 Mdot
.60264 .63392 Mdot
.48112 .56908 Mdot
.48802 .69098 Mdot
.40554 .35121 Mdot
.62839 .3245 Mdot
.50626 .63897 Mdot
.60114 .40034 Mdot
.72408 .56727 Mdot
.19369 .40854 Mdot
.65684 .40318 Mdot
.3247 .63368 Mdot
.47677 .34758 Mdot
.5551 .4439 Mdot
.19562 .39896 Mdot
.32054 .59958 Mdot
.37707 .39135 Mdot
.45163 .68228 Mdot
.52397 .61652 Mdot
.59396 .34944 Mdot
.65846 .64313 Mdot
.62672 .48711 Mdot
.37541 .33206 Mdot
.43123 .36936 Mdot
.76646 .45364 Mdot
.36132 .77795 Mdot
.63962 .61221 Mdot
.63974 .6052 Mdot
.48253 .67109 Mdot
.51605 .85623 Mdot
.62282 .50286 Mdot
.6402 .62757 Mdot
.34157 .30032 Mdot
.62729 .43903 Mdot
.67463 .51084 Mdot
.53127 .51714 Mdot
.35344 .37238 Mdot
.74751 .47711 Mdot
.4949 .66592 Mdot
.37873 .38669 Mdot
.31925 .43104 Mdot
.63647 .46763 Mdot
.39344 .36685 Mdot
.34709 .56724 Mdot
.33688 .69654 Mdot
.40964 .352 Mdot
.72093 .5557 Mdot
.32527 .56664 Mdot
.44422 .43691 Mdot
.74164 .44248 Mdot
.2592 .78446 Mdot
.33356 .53908 Mdot
.507 .64783 Mdot
.46293 .66669 Mdot
.48135 .67684 Mdot
.37129 .37803 Mdot
.46352 .69198 Mdot
.36819 .36962 Mdot
.26963 .71492 Mdot
.2018 .4209 Mdot
.63792 .62747 Mdot
.36677 .66943 Mdot
.37227 .35507 Mdot
.35723 .24559 Mdot
.16813 .35971 Mdot
.63661 .43981 Mdot
.32904 .5077 Mdot
.6377 .62474 Mdot
.58391 .82524 Mdot
.6313 .6119 Mdot
.77074 .38418 Mdot
.42074 .24729 Mdot
.5923 .41349 Mdot
.58063 .29387 Mdot
.62346 .64521 Mdot
.36222 .33667 Mdot
.57618 .44241 Mdot
.55741 .56806 Mdot
.6303 .60702 Mdot
.6445 .59845 Mdot
.5718 .42841 Mdot
.41247 .37361 Mdot
.4998 .65709 Mdot
.34483 .5096 Mdot
.65096 .63792 Mdot
.54629 .49497 Mdot
.65492 .43434 Mdot
.63193 .41578 Mdot
.35784 .44124 Mdot
.59968 .64153 Mdot
.33917 .54302 Mdot
.1607 .55476 Mdot
.51079 .67051 Mdot
.56211 .58557 Mdot
.74332 .30066 Mdot
.3024 .59884 Mdot
.46879 .64496 Mdot
.44778 .66174 Mdot
.56713 .4431 Mdot
.52678 .49886 Mdot
.40048 .25387 Mdot
.48213 .58012 Mdot
.43384 .64524 Mdot
.47605 .67935 Mdot
.41999 .38713 Mdot
.77128 .42389 Mdot
.66315 .44364 Mdot
.35521 .58283 Mdot
.45435 .62945 Mdot
.20316 .47556 Mdot
.61199 .60563 Mdot
.4246 .23747 Mdot
.624 .46964 Mdot
.62454 .4087 Mdot
.35338 .54862 Mdot
.34819 .56309 Mdot
.52129 .71268 Mdot
.77252 .40859 Mdot
.47813 .35554 Mdot
.25046 .45882 Mdot
.46292 .25749 Mdot
.42715 .37658 Mdot
.40945 .38467 Mdot
.38915 .71341 Mdot
.34254 .50586 Mdot
.55229 .44025 Mdot
.38868 .3865 Mdot
.55715 .60931 Mdot
.59408 .33059 Mdot
.73068 .38935 Mdot
.68617 .26041 Mdot
.60917 .43628 Mdot
.35573 .35896 Mdot
.35813 .38375 Mdot
.34208 .35228 Mdot
.34615 .61023 Mdot
.56802 .41985 Mdot
.60638 .43238 Mdot
.55788 .44187 Mdot
.22042 .40798 Mdot
.56255 .41786 Mdot
.23513 .52344 Mdot
.46009 .51619 Mdot
.52691 .21871 Mdot
.53836 .44945 Mdot
.37723 .54621 Mdot
.56083 .40014 Mdot
.6499 .62639 Mdot
.63927 .4281 Mdot
.7295 .38692 Mdot
.34027 .52198 Mdot
.65189 .34274 Mdot
.2656 .47482 Mdot
.56516 .46416 Mdot
.65539 .64028 Mdot
.26377 .54203 Mdot
.81143 .57595 Mdot
.60628 .66163 Mdot
.40353 .34892 Mdot
.46772 .65267 Mdot
.36648 .51576 Mdot
.48257 .66517 Mdot
.53777 .41165 Mdot
.38407 .71731 Mdot
.60261 .80597 Mdot
.52169 .56641 Mdot
.60513 .47246 Mdot
.6642 .45426 Mdot
.407 .35677 Mdot
.50771 .67459 Mdot
.33627 .37904 Mdot
.55143 .42208 Mdot
.62809 .6307 Mdot
.62747 .6026 Mdot
.52748 .5483 Mdot
.73069 .712 Mdot
.19579 .51553 Mdot
.35008 .54946 Mdot
.47114 .68722 Mdot
.62233 .64038 Mdot
.29564 .70263 Mdot
.35402 .59016 Mdot
.35418 .57404 Mdot
.34387 .52143 Mdot
.60689 .38785 Mdot
.453 .62821 Mdot
.53294 .21882 Mdot
.48006 .70447 Mdot
.59563 .43809 Mdot
.48218 .6277 Mdot
.50107 .68042 Mdot
.61427 .63095 Mdot
.34386 .51929 Mdot
.47648 .63384 Mdot
.63502 .3981 Mdot
.40603 .37336 Mdot
.39868 .59112 Mdot
.66115 .54961 Mdot
.37274 .78174 Mdot
.65826 .50008 Mdot
.34599 .36239 Mdot
.81064 .59962 Mdot
.3625 .57114 Mdot
.23912 .38321 Mdot
.66984 .70682 Mdot
.60136 .3767 Mdot
.21985 .31213 Mdot
.42788 .64422 Mdot
.50408 .67391 Mdot
.58253 .46152 Mdot
.44244 .61535 Mdot
.59421 .40948 Mdot
.49336 .63752 Mdot
.40435 .63705 Mdot
.41256 .3298 Mdot
.48415 .65236 Mdot
.53872 .4432 Mdot
.58467 .44791 Mdot
.35432 .3702 Mdot
.50203 .62568 Mdot
.6547 .45942 Mdot
.74813 .74545 Mdot
.34123 .5609 Mdot
.27369 .57567 Mdot
.71888 .5827 Mdot
.32919 .53914 Mdot
.38812 .36992 Mdot
.54882 .40819 Mdot
.63184 .60316 Mdot
.37095 .35458 Mdot
.71914 .37284 Mdot
.6044 .62749 Mdot
.28383 .26351 Mdot
.35372 .37828 Mdot
.50476 .66072 Mdot
.64364 .63532 Mdot
.64778 .43712 Mdot
.46817 .7066 Mdot
.31755 .69456 Mdot
.47115 .64559 Mdot
.56235 .44221 Mdot
.39559 .68905 Mdot
.34766 .51866 Mdot
.60614 .42461 Mdot
.50112 .67589 Mdot
.32905 .63419 Mdot
.60649 .38452 Mdot
.57799 .45254 Mdot
.7544 .31034 Mdot
.43451 .20836 Mdot
.62654 .61449 Mdot
.36255 .39653 Mdot
.63528 .44023 Mdot
.64564 .6021 Mdot
.56923 .75511 Mdot
.61473 .39476 Mdot
.38783 .333 Mdot
.60058 .49553 Mdot
.5057 .62955 Mdot
.32864 .54933 Mdot
.51608 .58216 Mdot
.63895 .5973 Mdot
.31406 .79844 Mdot
.45087 .63658 Mdot
.55981 .38642 Mdot
.61933 .46612 Mdot
.72498 .6378 Mdot
.37588 .38974 Mdot
.39311 .28721 Mdot
.58519 .39746 Mdot
.22673 .39404 Mdot
.61133 .41372 Mdot
.42579 .65368 Mdot
.39749 .34619 Mdot
.57524 .40919 Mdot
.40424 .53768 Mdot
.64841 .38207 Mdot
.61085 .59611 Mdot
.24357 .61584 Mdot
.64227 .46419 Mdot
.30266 .23061 Mdot
.5744 .55735 Mdot
.48521 .65056 Mdot
.49722 .79198 Mdot
.73234 .77096 Mdot
.25606 .49515 Mdot
.37452 .37843 Mdot
.65877 .75371 Mdot
.48975 .66534 Mdot
.47751 .7747 Mdot
.8182 .58999 Mdot
.59033 .45367 Mdot
.55169 .41423 Mdot
.75745 .57911 Mdot
.48687 .70003 Mdot
.5151 .67118 Mdot
.54765 .38859 Mdot
.65748 .39351 Mdot
.49128 .65798 Mdot
.61648 .38178 Mdot
.52797 .42112 Mdot
.3284 .50881 Mdot
.38797 .33491 Mdot
.34039 .57173 Mdot
.34233 .582 Mdot
.21132 .59692 Mdot
.58247 .56019 Mdot
.33755 .56121 Mdot
.3694 .56735 Mdot
.6786 .50555 Mdot
.74258 .37131 Mdot
.65357 .63093 Mdot
.7484 .7145 Mdot
.47368 .67798 Mdot
.57327 .41636 Mdot
.35363 .3809 Mdot
.47814 .36734 Mdot
.59858 .7548 Mdot
.33128 .26121 Mdot
.55045 .43222 Mdot
.49796 .66548 Mdot
.33563 .60708 Mdot
.51709 .42216 Mdot
.49867 .6165 Mdot
.6108 .39892 Mdot
.46158 .69794 Mdot
.66493 .32019 Mdot
.32004 .72079 Mdot
.49892 .6077 Mdot
.33965 .333 Mdot
.61952 .40702 Mdot
.37249 .33208 Mdot
.32741 .52767 Mdot
.65143 .63094 Mdot
.62329 .61236 Mdot
.57295 .43713 Mdot
.6477 .48776 Mdot
.51936 .74795 Mdot
.58408 .44099 Mdot
.62535 .44283 Mdot
.32327 .60164 Mdot
.62972 .44121 Mdot
.60095 .47801 Mdot
.56751 .45853 Mdot
.54576 .43864 Mdot
.34365 .51436 Mdot
.41116 .74961 Mdot
.59099 .35295 Mdot
.61348 .35673 Mdot
.32137 .56779 Mdot
.67747 .71875 Mdot
.35125 .58133 Mdot
.81971 .56984 Mdot
.3725 .55124 Mdot
.62358 .62131 Mdot
.69297 .67279 Mdot
.67962 .42329 Mdot
.40866 .34293 Mdot
.37128 .58446 Mdot
.64672 .62534 Mdot
.33958 .53684 Mdot
.49844 .63913 Mdot
.76053 .30813 Mdot
.43754 .37981 Mdot
.33703 .40668 Mdot
.27387 .53572 Mdot
.37218 .73211 Mdot
.45925 .63376 Mdot
.36001 .33435 Mdot
.59836 .31213 Mdot
.60644 .47406 Mdot
.64702 .60351 Mdot
.56751 .4311 Mdot
.3295 .51699 Mdot
.49135 .66967 Mdot
.30617 .74426 Mdot
.62895 .60111 Mdot
.70446 .24038 Mdot
.45604 .6675 Mdot
.5895 .47881 Mdot
.34536 .58376 Mdot
.6036 .17913 Mdot
.34532 .57228 Mdot
.41049 .28036 Mdot
.39665 .39355 Mdot
.29789 .76176 Mdot
.37431 .36484 Mdot
.32662 .71002 Mdot
.54193 .13252 Mdot
.42927 .76824 Mdot
.40965 .37483 Mdot
.43404 .58634 Mdot
.61768 .4344 Mdot
.63162 .41451 Mdot
.31078 .72609 Mdot
.35541 .38777 Mdot
.62275 .45856 Mdot
.3852 .627 Mdot
.30972 .57228 Mdot
.63977 .23005 Mdot
.45563 .64267 Mdot
.59461 .40558 Mdot
.36051 .49718 Mdot
.36625 .51 Mdot
.44313 .66402 Mdot
.35625 .5741 Mdot
.60395 .43247 Mdot
.37252 .35657 Mdot
.40812 .64996 Mdot
.61535 .61794 Mdot
.53671 .84176 Mdot
.62781 .58715 Mdot
.46806 .64497 Mdot
.64186 .39389 Mdot
.48772 .66345 Mdot
.82475 .69912 Mdot
.61364 .42859 Mdot
.40364 .36809 Mdot
.62559 .44855 Mdot
.6207 .41113 Mdot
.54731 .43687 Mdot
.49861 .65265 Mdot
.68329 .63564 Mdot
.62853 .39162 Mdot
.36102 .54965 Mdot
.49197 .24189 Mdot
.6231 .47817 Mdot
.50738 .60192 Mdot
.74008 .40281 Mdot
.29415 .51286 Mdot
.38105 .39857 Mdot
.48012 .64896 Mdot
.39581 .37305 Mdot
.24409 .34882 Mdot
.38799 .36956 Mdot
.47284 .28347 Mdot
.61588 .30897 Mdot
.67529 .29721 Mdot
.65684 .2894 Mdot
.43239 .52813 Mdot
.35931 .39274 Mdot
.62031 .66047 Mdot
.41696 .37692 Mdot
.3608 .38197 Mdot
.25858 .21257 Mdot
.39322 .32947 Mdot
.59552 .39757 Mdot
.61424 .48171 Mdot
.36915 .74656 Mdot
.70524 .52766 Mdot
.61277 .45661 Mdot
.61375 .46101 Mdot
.62813 .64074 Mdot
.24244 .35954 Mdot
.41006 .72782 Mdot
.41867 .21456 Mdot
.5586 .80116 Mdot
.56963 .43035 Mdot
.63915 .43475 Mdot
.55816 .36902 Mdot
.47568 .16183 Mdot
.21305 .61641 Mdot
.34915 .31054 Mdot
.57789 .36369 Mdot
.42487 .77737 Mdot
.54809 .42695 Mdot
.5941 .38905 Mdot
.6123 .43541 Mdot
.49019 .66556 Mdot
.37368 .39905 Mdot
.54381 .44058 Mdot
.71237 .64659 Mdot
.59771 .39182 Mdot
.30702 .60619 Mdot
.41219 .83295 Mdot
.59025 .40371 Mdot
.41702 .39795 Mdot
.63298 .41845 Mdot
.36803 .38394 Mdot
.35112 .34851 Mdot
.56837 .3691 Mdot
.45899 .25873 Mdot
.41443 .39453 Mdot
.59515 .43873 Mdot
.50338 .64318 Mdot
.7828 .67079 Mdot
.56132 .43916 Mdot
.65425 .62794 Mdot
.58081 .39615 Mdot
.66067 .63212 Mdot
.61973 .44721 Mdot
.44606 .64089 Mdot
.46122 .35029 Mdot
.47698 .66996 Mdot
.23525 .67622 Mdot
.444 .63662 Mdot
.73514 .25987 Mdot
.34411 .35476 Mdot
.38013 .6733 Mdot
.29043 .29659 Mdot
.27457 .59372 Mdot
.47239 .45016 Mdot
.42012 .48159 Mdot
.341 .57652 Mdot
.3887 .39142 Mdot
.27292 .35036 Mdot
.63426 .71901 Mdot
.63803 .68925 Mdot
.4851 .69015 Mdot
.14423 .54641 Mdot
.2684 .29141 Mdot
.58916 .37251 Mdot
.55198 .30615 Mdot
.53363 .27146 Mdot
.54736 .42756 Mdot
.54359 .42789 Mdot
.53519 .62072 Mdot
.62789 .38876 Mdot
.33541 .45165 Mdot
.46311 .64515 Mdot
.64822 .62215 Mdot
.40848 .36279 Mdot
.62668 .59229 Mdot
.657 .70951 Mdot
.41425 .47573 Mdot
.48947 .63469 Mdot
.65846 .43957 Mdot
.60641 .46226 Mdot
.36082 .37528 Mdot
.32533 .35881 Mdot
.42134 .36618 Mdot
.63814 .61939 Mdot
.45896 .64978 Mdot
.18198 .4419 Mdot
.60582 .46508 Mdot
.38088 .34208 Mdot
.48058 .46356 Mdot
.63322 .44302 Mdot
.33 .52975 Mdot
.62079 .43036 Mdot
.41245 .37039 Mdot
.62947 .44148 Mdot
.37411 .36683 Mdot
.4679 .65517 Mdot
.57221 .46762 Mdot
.57789 .46013 Mdot
.65762 .21269 Mdot
.63355 .62957 Mdot
.36427 .32955 Mdot
.55403 .59659 Mdot
.63509 .45046 Mdot
.34407 .66098 Mdot
.60671 .39801 Mdot
.44988 .39432 Mdot
.58458 .3768 Mdot
.27736 .5792 Mdot
.63933 .36362 Mdot
.56122 .43049 Mdot
.53109 .53034 Mdot
.52146 .277 Mdot
.68154 .39469 Mdot
.37352 .56343 Mdot
.37121 .32492 Mdot
.64791 .23906 Mdot
.41698 .67286 Mdot
.51683 .64074 Mdot
.75203 .50887 Mdot
.55283 .45418 Mdot
.5896 .41344 Mdot
.32183 .48308 Mdot
.62951 .59744 Mdot
.37557 .33501 Mdot
.64046 .63143 Mdot
.70202 .25392 Mdot
.60223 .60613 Mdot
.42521 .65117 Mdot
.49904 .75702 Mdot
.17468 .48532 Mdot
.62502 .64012 Mdot
.41392 .3721 Mdot
.47876 .75776 Mdot
.5822 .48157 Mdot
.56839 .55254 Mdot
.62193 .62898 Mdot
.18274 .6439 Mdot
.59934 .47831 Mdot
.47235 .44493 Mdot
.33324 .56063 Mdot
.63147 .63932 Mdot
.32181 .55781 Mdot
.59694 .46029 Mdot
.41261 .72756 Mdot
.37586 .37849 Mdot
.31654 .5465 Mdot
.57645 .49512 Mdot
.63967 .62489 Mdot
.4566 .62769 Mdot
.35086 .48583 Mdot
.36074 .57919 Mdot
.70375 .71403 Mdot
.29252 .74273 Mdot
.45767 .65272 Mdot
.54334 .20042 Mdot
.37521 .53709 Mdot
.58616 .48365 Mdot
.2554 .34855 Mdot
.62691 .41049 Mdot
.21829 .54104 Mdot
.47623 .64385 Mdot
.38375 .73797 Mdot
.63544 .43873 Mdot
.55461 .42842 Mdot
.43389 .38204 Mdot
.46936 .67094 Mdot
.38318 .35377 Mdot
.36 .32632 Mdot
.46654 .65617 Mdot
.38123 .37295 Mdot
.617 .64211 Mdot
.30028 .39596 Mdot
.37009 .5408 Mdot
.36168 .53767 Mdot
.48001 .6782 Mdot
.48599 .64703 Mdot
.48497 .6607 Mdot
.62141 .42996 Mdot
.38557 .33788 Mdot
.60106 .45072 Mdot
.57977 .39079 Mdot
.492 .23191 Mdot
.36672 .39424 Mdot
.60581 .44238 Mdot
.56415 .57477 Mdot
.53956 .51694 Mdot
.50137 .63724 Mdot
.33499 .5598 Mdot
.38222 .64109 Mdot
.3032 .67836 Mdot
.59835 .4052 Mdot
.60329 .56749 Mdot
.41538 .37349 Mdot
.63386 .60662 Mdot
.60972 .5891 Mdot
.62994 .61336 Mdot
.28876 .55776 Mdot
.34294 .3564 Mdot
.41424 .22015 Mdot
.59209 .40808 Mdot
.37335 .45158 Mdot
.36117 .30248 Mdot
.51927 .72932 Mdot
.33609 .55872 Mdot
.62548 .45092 Mdot
.51853 .57979 Mdot
.55446 .33391 Mdot
.62652 .41496 Mdot
.61139 .48595 Mdot
.56752 .78213 Mdot
.62294 .49359 Mdot
.42837 .36782 Mdot
.60981 .18562 Mdot
.64651 .43201 Mdot
.20047 .47295 Mdot
.5588 .84838 Mdot
.60663 .40408 Mdot
.55546 .41784 Mdot
.59403 .47087 Mdot
.63925 .42505 Mdot
.41284 .39767 Mdot
.71991 .48757 Mdot
.37603 .54338 Mdot
.37352 .44908 Mdot
.33595 .51068 Mdot
.44116 .67307 Mdot
.39048 .74067 Mdot
.39538 .39236 Mdot
.61326 .60069 Mdot
.51855 .81713 Mdot
.52112 .17653 Mdot
.44488 .65911 Mdot
.19781 .54569 Mdot
.62437 .62772 Mdot
.59334 .48673 Mdot
.63868 .64719 Mdot
.4803 .62413 Mdot
.36411 .53633 Mdot
.63296 .47546 Mdot
.41141 .38155 Mdot
.40585 .34783 Mdot
.62801 .45084 Mdot
.44116 .78702 Mdot
.32584 .53639 Mdot
.36519 .57813 Mdot
.61175 .38976 Mdot
.64665 .4399 Mdot
.38301 .35741 Mdot
.46532 .68339 Mdot
.68635 .29615 Mdot
.64251 .60486 Mdot
.54706 .40702 Mdot
.6317 .43679 Mdot
.74755 .30713 Mdot
.36275 .55084 Mdot
.50358 .62094 Mdot
.59756 .37664 Mdot
.24191 .45622 Mdot
.60106 .37732 Mdot
.54594 .37854 Mdot
.50403 .64295 Mdot
.55305 .36251 Mdot
.55136 .38967 Mdot
.44427 .37726 Mdot
.33155 .5696 Mdot
.39714 .36581 Mdot
.44631 .38849 Mdot
.30244 .36519 Mdot
.33269 .52865 Mdot
.61431 .43893 Mdot
.33621 .55374 Mdot
.61584 .39576 Mdot
.64487 .41436 Mdot
.34022 .56386 Mdot
.38237 .35437 Mdot
.65005 .75855 Mdot
.42548 .7612 Mdot
.63982 .41699 Mdot
.55773 .37775 Mdot
.7051 .5078 Mdot
.67676 .64207 Mdot
.55111 .42018 Mdot
.41392 .36568 Mdot
.59492 .46513 Mdot
.32109 .53243 Mdot
.62309 .64452 Mdot
.40773 .37324 Mdot
.45255 .67047 Mdot
.44619 .64712 Mdot
.26404 .48006 Mdot
.48986 .69268 Mdot
.55259 .40916 Mdot
.37752 .41278 Mdot
.4219 .40188 Mdot
.48511 .8253 Mdot
.46464 .65933 Mdot
.65547 .62938 Mdot
.57653 .44978 Mdot
.77921 .49955 Mdot
.35537 .49476 Mdot
.20846 .29393 Mdot
.35529 .2441 Mdot
.62043 .6507 Mdot
.35058 .26074 Mdot
.44122 .64352 Mdot
.54063 .40355 Mdot
.65433 .62389 Mdot
.45817 .63655 Mdot
.62957 .40043 Mdot
.56687 .36889 Mdot
.40196 .28836 Mdot
.40136 .49191 Mdot
.33933 .55647 Mdot
.47001 .697 Mdot
.62828 .65455 Mdot
.4353 .6347 Mdot
.34748 .34531 Mdot
.56533 .41978 Mdot
.63382 .38678 Mdot
.46108 .68256 Mdot
.51941 .64466 Mdot
.60086 .43978 Mdot
.41097 .38914 Mdot
.53642 .61774 Mdot
.57477 .42923 Mdot
.38807 .48607 Mdot
.34729 .38118 Mdot
.45667 .64517 Mdot
.55734 .42664 Mdot
.65997 .65228 Mdot
.45814 .6734 Mdot
.49973 .63471 Mdot
.63895 .43662 Mdot
.61293 .63883 Mdot
.58528 .36757 Mdot
.36968 .55473 Mdot
.16133 .57592 Mdot
.32122 .53005 Mdot
.40961 .63159 Mdot
.60832 .50234 Mdot
.24307 .41786 Mdot
.3785 .39578 Mdot
.75834 .45433 Mdot
.38549 .62943 Mdot
.52706 .4185 Mdot
.77374 .66537 Mdot
.39089 .56272 Mdot
.48187 .81227 Mdot
.79066 .56132 Mdot
.61677 .62992 Mdot
.34053 .53482 Mdot
.55539 .41728 Mdot
.32799 .50819 Mdot
.65445 .61826 Mdot
.2361 .67415 Mdot
.55841 .4376 Mdot
.40112 .3502 Mdot
.60489 .43591 Mdot
.39642 .3424 Mdot
.64203 .43056 Mdot
.61638 .36614 Mdot
.33585 .61791 Mdot
.71203 .44351 Mdot
.5947 .37867 Mdot
.69774 .20645 Mdot
.49559 .46334 Mdot
.64768 .61272 Mdot
.59307 .45125 Mdot
.48348 .61127 Mdot
.35673 .50304 Mdot
.25165 .56092 Mdot
.4916 .66442 Mdot
.36185 .5767 Mdot
.38222 .36652 Mdot
.47455 .64824 Mdot
.44473 .66619 Mdot
.5495 .36402 Mdot
.61996 .64727 Mdot
.35226 .52956 Mdot
.57385 .40858 Mdot
.55862 .43621 Mdot
.54325 .19706 Mdot
.609 .73356 Mdot
.32996 .37833 Mdot
.40414 .18346 Mdot
.34971 .3265 Mdot
.64504 .62235 Mdot
.49892 .65721 Mdot
.56956 .39556 Mdot
.60211 .42629 Mdot
.35667 .65927 Mdot
.4217 .37602 Mdot
.46165 .53326 Mdot
.33318 .29242 Mdot
.55411 .61113 Mdot
.71827 .45662 Mdot
.41058 .36427 Mdot
.71569 .46096 Mdot
.59494 .62769 Mdot
.69958 .75723 Mdot
.69839 .47617 Mdot
.33138 .55687 Mdot
.70898 .47399 Mdot
.37299 .33843 Mdot
.62786 .39299 Mdot
.50721 .65267 Mdot
.50079 .68127 Mdot
.39181 .35928 Mdot
.46344 .61837 Mdot
.60967 .62362 Mdot
.56335 .4087 Mdot
.42815 .20505 Mdot
.29093 .44979 Mdot
.48016 .68144 Mdot
.51921 .40991 Mdot
.34262 .52088 Mdot
.62894 .45032 Mdot
.6178 .63649 Mdot
.33395 .54424 Mdot
.77297 .3956 Mdot
.30607 .55604 Mdot
.57582 .44564 Mdot
.75203 .30673 Mdot
.33454 .53334 Mdot
.49364 .43643 Mdot
.57324 .42261 Mdot
.36642 .56241 Mdot
.52757 .37046 Mdot
.33626 .7003 Mdot
.51622 .56127 Mdot
.81904 .59014 Mdot
.49492 .53881 Mdot
.49778 .67111 Mdot
.35525 .71932 Mdot
.2623 .58511 Mdot
.36463 .51667 Mdot
.51253 .62942 Mdot
.60019 .5496 Mdot
.32375 .56192 Mdot
.59433 .48533 Mdot
.60951 .4013 Mdot
.22181 .6302 Mdot
.38228 .52441 Mdot
.32362 .71186 Mdot
.27441 .49551 Mdot
.63381 .45363 Mdot
.59556 .36825 Mdot
.59802 .42427 Mdot
.42757 .38047 Mdot
.34924 .55852 Mdot
.65837 .1949 Mdot
.32755 .52995 Mdot
.44911 .23183 Mdot
.47754 .67727 Mdot
.45706 .64035 Mdot
.59442 .40338 Mdot
.46874 .42993 Mdot
.75583 .40111 Mdot
.6005 .43391 Mdot
.65258 .58405 Mdot
.24869 .64974 Mdot
.64454 .44201 Mdot
.39532 .39646 Mdot
.53137 .38914 Mdot
.53429 .48544 Mdot
.3702 .53978 Mdot
.61121 .60935 Mdot
.76234 .43522 Mdot
.36005 .52872 Mdot
.59029 .41463 Mdot
.24921 .42341 Mdot
.61935 .41702 Mdot
.63758 .4127 Mdot
.38608 .24861 Mdot
.60441 .59464 Mdot
.47692 .66028 Mdot
.63021 .6162 Mdot
.37133 .38874 Mdot
.18801 .29044 Mdot
.60358 .60231 Mdot
.75933 .39371 Mdot
.21179 .63426 Mdot
.69951 .48642 Mdot
.37835 .33236 Mdot
.6368 .65033 Mdot
.32609 .54555 Mdot
.78025 .67621 Mdot
.41464 .30321 Mdot
.39494 .53658 Mdot
.57916 .42646 Mdot
.39174 .32352 Mdot
.41134 .35031 Mdot
.31634 .54965 Mdot
.35274 .34422 Mdot
.64003 .35215 Mdot
.63449 .40222 Mdot
.34748 .50805 Mdot
.2565 .44856 Mdot
.37605 .55775 Mdot
.43405 .57038 Mdot
.58999 .4465 Mdot
.4074 .36924 Mdot
.5432 .41013 Mdot
.36531 .40307 Mdot
.48617 .61732 Mdot
.65692 .41884 Mdot
.60807 .62095 Mdot
.23449 .43653 Mdot
.45595 .65454 Mdot
.56651 .60279 Mdot
.36208 .3779 Mdot
.29232 .54209 Mdot
.35365 .36748 Mdot
.3906 .41003 Mdot
.34858 .5827 Mdot
.36397 .35173 Mdot
.55712 .41585 Mdot
.54388 .56376 Mdot
.36783 .37783 Mdot
.35154 .54113 Mdot
.61463 .60812 Mdot
.3772 .36461 Mdot
.44818 .6117 Mdot
.57179 .44725 Mdot
.49575 .64949 Mdot
.67436 .6767 Mdot
.39375 .32669 Mdot
.59816 .60224 Mdot
.51821 .64631 Mdot
.64523 .59891 Mdot
.42849 .81321 Mdot
.31216 .55549 Mdot
.42926 .24681 Mdot
.66878 .60137 Mdot
.41274 .34723 Mdot
.68086 .67715 Mdot
.58035 .39211 Mdot
.57396 .44915 Mdot
.66071 .62688 Mdot
.41168 .35067 Mdot
.62581 .81661 Mdot
.60204 .51392 Mdot
.42808 .54546 Mdot
.35972 .59202 Mdot
.73207 .25254 Mdot
.42934 .56156 Mdot
.51747 .86053 Mdot
.52994 .44946 Mdot
.51304 .67534 Mdot
.60125 .41169 Mdot
.36451 .63266 Mdot
.63646 .62512 Mdot
.42986 .6032 Mdot
.63741 .38227 Mdot
.47375 .65536 Mdot
.57606 .4632 Mdot
.53012 .53622 Mdot
.50209 .44086 Mdot
.65788 .62259 Mdot
.46461 .77306 Mdot
.38341 .3255 Mdot
.61683 .62139 Mdot
.46692 .63101 Mdot
.73553 .43848 Mdot
.6317 .40185 Mdot
.58463 .48654 Mdot
.55398 .61225 Mdot
.38448 .33615 Mdot
.50435 .66644 Mdot
.36942 .54996 Mdot
.61663 .60111 Mdot
.60659 .46076 Mdot
.58484 .38701 Mdot
.3362 .65323 Mdot
.33951 .51889 Mdot
.50059 .68634 Mdot
.33351 .56653 Mdot
.44024 .66105 Mdot
.6402 .40012 Mdot
.44839 .65112 Mdot
.54009 .43849 Mdot
.32631 .6118 Mdot
.41142 .24323 Mdot
.52375 .28895 Mdot
.47271 .64235 Mdot
.73044 .35856 Mdot
.33749 .52131 Mdot
.35119 .57259 Mdot
.18069 .56193 Mdot
.40448 .28015 Mdot
.51876 .18499 Mdot
.7517 .65633 Mdot
.34599 .51164 Mdot
.34733 .52756 Mdot
.49407 .64791 Mdot
.36224 .35301 Mdot
.34938 .3299 Mdot
.44134 .66439 Mdot
.7227 .57446 Mdot
.37587 .33515 Mdot
.74088 .70828 Mdot
.61055 .21646 Mdot
.54555 .45433 Mdot
.4233 .65025 Mdot
.62836 .60489 Mdot
.72491 .55654 Mdot
.53678 .54249 Mdot
.55315 .43074 Mdot
.76721 .48569 Mdot
.47318 .68207 Mdot
.45634 .41957 Mdot
.81432 .57639 Mdot
.5736 .46543 Mdot
.57228 .41808 Mdot
.59689 .41827 Mdot
.60858 .6422 Mdot
.42856 .30453 Mdot
.56012 .4185 Mdot
.7215 .57713 Mdot
.63224 .45132 Mdot
.49622 .42271 Mdot
.62529 .61322 Mdot
.69002 .47423 Mdot
.64512 .71674 Mdot
.61207 .19095 Mdot
.52042 .48109 Mdot
.37066 .54868 Mdot
.6462 .67419 Mdot
.34385 .5746 Mdot
.4844 .28444 Mdot
.67749 .50289 Mdot
.34911 .3225 Mdot
.55268 .42814 Mdot
.4673 .64451 Mdot
.4103 .34948 Mdot
.34554 .68959 Mdot
.22323 .2498 Mdot
.37293 .54258 Mdot
.6229 .85997 Mdot
.3638 .56436 Mdot
.44498 .66854 Mdot
.38358 .35846 Mdot
.62928 .3123 Mdot
.34246 .4263 Mdot
.37741 .36772 Mdot
.6208 .79636 Mdot
.34585 .31163 Mdot
.73664 .4095 Mdot
.42085 .35014 Mdot
.34806 .53516 Mdot
.279 .55241 Mdot
.66488 .36449 Mdot
.58832 .39327 Mdot
.42465 .48171 Mdot
.74922 .3953 Mdot
.57878 .39294 Mdot
.46192 .64689 Mdot
.41158 .2534 Mdot
.75752 .4927 Mdot
.36697 .34694 Mdot
.30956 .56362 Mdot
.56691 .42346 Mdot
.63293 .4271 Mdot
.62858 .3964 Mdot
.37038 .22684 Mdot
.69596 .76011 Mdot
.63067 .39343 Mdot
.64109 .43933 Mdot
.47372 .65117 Mdot
.67347 .62958 Mdot
.46476 .75898 Mdot
.52355 .20928 Mdot
.55996 .4538 Mdot
.61876 .61792 Mdot
.62051 .65654 Mdot
.60943 .38057 Mdot
.57406 .56509 Mdot
.252 .41354 Mdot
.57241 .40944 Mdot
.41352 .25618 Mdot
.53483 .68678 Mdot
.48695 .70026 Mdot
.4562 .67518 Mdot
.36664 .3304 Mdot
.45606 .68207 Mdot
.44945 .6354 Mdot
.62938 .31993 Mdot
.47828 .53326 Mdot
.36867 .60137 Mdot
.63883 .61735 Mdot
.60761 .42453 Mdot
.68678 .41515 Mdot
.24199 .4452 Mdot
.33661 .57663 Mdot
.40577 .38026 Mdot
.35683 .50135 Mdot
.59738 .65262 Mdot
.30875 .34904 Mdot
.48009 .68725 Mdot
.35589 .51701 Mdot
.32523 .49817 Mdot
.61896 .61518 Mdot
.31836 .53367 Mdot
.32251 .49264 Mdot
.65291 .44394 Mdot
.53638 .31739 Mdot
.59415 .43666 Mdot
.52219 .82245 Mdot
.34837 .52173 Mdot
.28814 .57782 Mdot
.58298 .41101 Mdot
.45812 .67106 Mdot
.63454 .33595 Mdot
.59289 .39106 Mdot
.46079 .68493 Mdot
.59331 .37283 Mdot
.63117 .58891 Mdot
.35776 .39448 Mdot
.3493 .43111 Mdot
.13774 .53454 Mdot
.62312 .64875 Mdot
.34717 .68428 Mdot
.54976 .42769 Mdot
.34252 .77698 Mdot
.376 .36149 Mdot
.56951 .38654 Mdot
.74573 .47632 Mdot
.36533 .36979 Mdot
.39476 .37646 Mdot
.62382 .43573 Mdot
.33133 .55985 Mdot
.4554 .65146 Mdot
.62148 .61105 Mdot
.50068 .84546 Mdot
.57916 .43451 Mdot
.58376 .46328 Mdot
.62035 .625 Mdot
.33323 .51945 Mdot
.60011 .37816 Mdot
.74487 .61805 Mdot
.65528 .80648 Mdot
.36008 .57169 Mdot
.5851 .48007 Mdot
.48143 .30971 Mdot
.57288 .51518 Mdot
.30153 .77807 Mdot
.57384 .55607 Mdot
.48021 .65531 Mdot
.64957 .47934 Mdot
.28364 .23018 Mdot
.61339 .60651 Mdot
.51925 .17845 Mdot
.63349 .42974 Mdot
.60846 .46574 Mdot
.42043 .36821 Mdot
.60057 .44742 Mdot
.401 .39031 Mdot
.15201 .48305 Mdot
.74452 .29508 Mdot
.35486 .33712 Mdot
.40866 .3412 Mdot
.75785 .42407 Mdot
.40044 .6529 Mdot
.39016 .36073 Mdot
.64583 .41932 Mdot
.62012 .54017 Mdot
.45235 .41042 Mdot
.64814 .64403 Mdot
.67402 .69177 Mdot
.6523 .48998 Mdot
.5905 .58362 Mdot
.67392 .72698 Mdot
.6713 .47257 Mdot
.45665 .57963 Mdot
.36165 .56073 Mdot
.57202 .46425 Mdot
.49986 .68308 Mdot
.4919 .69229 Mdot
.53405 .42218 Mdot
.61558 .42365 Mdot
.36835 .38585 Mdot
.62799 .59927 Mdot
.37035 .524 Mdot
.61059 .46247 Mdot
.75422 .45045 Mdot
.62296 .5952 Mdot
.35596 .34778 Mdot
.47676 .23921 Mdot
.64143 .58947 Mdot
.61964 .3638 Mdot
.58114 .40133 Mdot
.60916 .43634 Mdot
.67154 .37098 Mdot
.3509 .56164 Mdot
.68801 .68134 Mdot
.62691 .47085 Mdot
.69594 .24725 Mdot
.38875 .59359 Mdot
.66192 .41495 Mdot
.34818 .35193 Mdot
.32464 .58825 Mdot
.44233 .63298 Mdot
.29308 .35001 Mdot
.57682 .44405 Mdot
.44698 .78228 Mdot
.23134 .64119 Mdot
.4974 .62117 Mdot
.36823 .40244 Mdot
.63414 .61188 Mdot
.60267 .43224 Mdot
.45654 .26169 Mdot
.60624 .40072 Mdot
.60221 .57858 Mdot
.49996 .6319 Mdot
.35962 .56326 Mdot
.49517 .81696 Mdot
.47804 .69815 Mdot
.39539 .3737 Mdot
.8122 .3931 Mdot
.40095 .39121 Mdot
.35066 .33088 Mdot
.49087 .23916 Mdot
.35074 .56314 Mdot
.24514 .25677 Mdot
.16227 .48831 Mdot
.65444 .421 Mdot
.33408 .52163 Mdot
.39748 .3579 Mdot
.62048 .46325 Mdot
.33319 .33591 Mdot
.34615 .36871 Mdot
.64588 .4097 Mdot
.5972 .47303 Mdot
.34727 .74152 Mdot
.80345 .59851 Mdot
.63521 .61321 Mdot
.36713 .38923 Mdot
.34557 .4415 Mdot
.61968 .46528 Mdot
.59104 .408 Mdot
.26103 .59552 Mdot
.62574 .64668 Mdot
.3184 .44474 Mdot
.63319 .42827 Mdot
.76413 .34112 Mdot
.56361 .36032 Mdot
.41062 .39627 Mdot
.34732 .57667 Mdot
.62578 .20032 Mdot
.34227 .48131 Mdot
.40105 .38927 Mdot
.61065 .60042 Mdot
.43277 .39261 Mdot
.75901 .38713 Mdot
.3332 .5143 Mdot
.41251 .37033 Mdot
.51275 .5812 Mdot
.34503 .55266 Mdot
.35286 .5203 Mdot
.5025 .23174 Mdot
.50139 .61787 Mdot
.60923 .64456 Mdot
.35002 .52778 Mdot
.2339 .39231 Mdot
.3478 .5423 Mdot
.16312 .5063 Mdot
.57631 .47151 Mdot
.74839 .54685 Mdot
.41198 .61674 Mdot
.66884 .45391 Mdot
.34637 .51743 Mdot
.63001 .6416 Mdot
.62902 .40122 Mdot
.36766 .33737 Mdot
.64365 .60202 Mdot
.38122 .49735 Mdot
.49133 .65975 Mdot
.35465 .36506 Mdot
.38182 .53844 Mdot
.40301 .34667 Mdot
.2728 .35266 Mdot
.19421 .62425 Mdot
.78412 .45355 Mdot
.33505 .42062 Mdot
.63339 .40366 Mdot
.71341 .69779 Mdot
.57401 .47662 Mdot
.62089 .42287 Mdot
.45911 .64473 Mdot
.75517 .52176 Mdot
.3831 .35433 Mdot
.57418 .82618 Mdot
.36798 .53418 Mdot
.62307 .19459 Mdot
.54075 .50115 Mdot
.56092 .38442 Mdot
.37073 .38103 Mdot
.41855 .38332 Mdot
.51453 .26754 Mdot
.43122 .64614 Mdot
.54687 .41657 Mdot
.60718 .49125 Mdot
.53489 .40524 Mdot
.36568 .53557 Mdot
.5774 .57831 Mdot
.49489 .6738 Mdot
.23709 .69292 Mdot
.50219 .63223 Mdot
.60163 .57572 Mdot
.36365 .34773 Mdot
.60378 .60236 Mdot
.58893 .40709 Mdot
.32367 .34142 Mdot
.4227 .37529 Mdot
.66015 .62055 Mdot
.63998 .63719 Mdot
.30751 .66138 Mdot
.34004 .56317 Mdot
.59808 .38654 Mdot
.55752 .42454 Mdot
.60473 .45176 Mdot
.61954 .42944 Mdot
.37138 .53773 Mdot
.62236 .39424 Mdot
.3593 .49326 Mdot
.29595 .31541 Mdot
.76075 .57492 Mdot
.49663 .53661 Mdot
.20944 .54825 Mdot
.36907 .34163 Mdot
.23607 .39964 Mdot
.57539 .50636 Mdot
.30375 .26003 Mdot
.2738 .70357 Mdot
.64088 .45929 Mdot
.44882 .64457 Mdot
.53801 .35733 Mdot
.48868 .68855 Mdot
.51518 .87045 Mdot
.31054 .62375 Mdot
.8004 .62162 Mdot
.55928 .43729 Mdot
.53987 .56418 Mdot
.21427 .41126 Mdot
.57951 .48173 Mdot
.31606 .64542 Mdot
.2161 .53872 Mdot
.45344 .77084 Mdot
.61949 .63972 Mdot
.569 .43715 Mdot
.68378 .40287 Mdot
.55956 .41331 Mdot
.59756 .40899 Mdot
.62567 .39533 Mdot
.37851 .54711 Mdot
.56407 .39297 Mdot
.62784 .40638 Mdot
.52296 .7516 Mdot
.71588 .45242 Mdot
.51438 .66369 Mdot
.19052 .58668 Mdot
.60297 .60252 Mdot
.36653 .38043 Mdot
.69194 .75464 Mdot
.33182 .55685 Mdot
.5218 .26769 Mdot
.61502 .43245 Mdot
.37771 .75101 Mdot
.31621 .50917 Mdot
.60829 .6059 Mdot
.47759 .62347 Mdot
.80375 .63854 Mdot
.46495 .64902 Mdot
.31102 .58721 Mdot
.45797 .6672 Mdot
.59025 .50952 Mdot
.36836 .38663 Mdot
.60302 .38295 Mdot
.35464 .5327 Mdot
.44972 .66963 Mdot
.70699 .51837 Mdot
.59949 .42273 Mdot
.467 .65698 Mdot
.60352 .38341 Mdot
.32871 .39386 Mdot
.57616 .21691 Mdot
.45264 .63434 Mdot
.3204 .50594 Mdot
.35829 .54946 Mdot
.60976 .63506 Mdot
.35984 .37011 Mdot
.40418 .38407 Mdot
.33513 .54391 Mdot
.35703 .27732 Mdot
.55695 .45166 Mdot
.61061 .4696 Mdot
.65213 .2173 Mdot
.55778 .40905 Mdot
.73334 .43396 Mdot
.52613 .5802 Mdot
.36035 .34144 Mdot
.56142 .38145 Mdot
.62697 .4374 Mdot
.57535 .44669 Mdot
.32056 .30708 Mdot
.46716 .68535 Mdot
.57446 .46772 Mdot
.64515 .634 Mdot
.48953 .73739 Mdot
.62952 .44971 Mdot
.58442 .3497 Mdot
.40582 .38293 Mdot
.40413 .18881 Mdot
.36191 .56584 Mdot
.46642 .63204 Mdot
.47384 .64157 Mdot
.68172 .69667 Mdot
.2162 .47049 Mdot
.5271 .57918 Mdot
.26315 .73056 Mdot
.33667 .61765 Mdot
.64197 .62864 Mdot
.45559 .70864 Mdot
.27432 .55745 Mdot
.48482 .63892 Mdot
.37321 .53842 Mdot
.58607 .47912 Mdot
.56168 .45618 Mdot
.24903 .28528 Mdot
.60625 .37822 Mdot
.63069 .60944 Mdot
.37738 .55542 Mdot
.37435 .33895 Mdot
.61065 .60317 Mdot
.33387 .56789 Mdot
.36405 .33318 Mdot
.63457 .46794 Mdot
.62689 .47302 Mdot
.40309 .38123 Mdot
.41702 .36389 Mdot
.58153 .40391 Mdot
.42573 .72005 Mdot
.40496 .33935 Mdot
.41191 .36581 Mdot
.48154 .68492 Mdot
.49438 .68862 Mdot
.6186 .35558 Mdot
.33832 .52411 Mdot
.62731 .40379 Mdot
.47208 .64708 Mdot
.60292 .60527 Mdot
.38065 .35186 Mdot
.63945 .42016 Mdot
.62367 .45136 Mdot
.61812 .61382 Mdot
.60436 .62147 Mdot
.62116 .63722 Mdot
.37696 .51969 Mdot
.59759 .45533 Mdot
.38513 .36376 Mdot
.34564 .56587 Mdot
.61748 .65452 Mdot
.6442 .64404 Mdot
.43724 .69237 Mdot
.56116 .40137 Mdot
.40913 .65575 Mdot
.3029 .21184 Mdot
.70811 .27447 Mdot
.46925 .62076 Mdot
.44086 .63236 Mdot
.67355 .53147 Mdot
.44367 .43319 Mdot
.32943 .53424 Mdot
.67503 .62733 Mdot
.76535 .4252 Mdot
.64672 .45973 Mdot
.64419 .4379 Mdot
.61121 .36774 Mdot
.62596 .63787 Mdot
.76437 .52589 Mdot
.39286 .39226 Mdot
.70125 .41931 Mdot
.62715 .59465 Mdot
.51858 .65043 Mdot
.43363 .69462 Mdot
.49939 .62954 Mdot
.60344 .48407 Mdot
.53705 .29068 Mdot
.2238 .43391 Mdot
.7427 .64831 Mdot
.34216 .51771 Mdot
.68661 .41778 Mdot
.339 .77125 Mdot
.39781 .37993 Mdot
.44142 .67464 Mdot
.64369 .62932 Mdot
.41577 .36136 Mdot
.34812 .49977 Mdot
.34934 .52962 Mdot
.4824 .67998 Mdot
.48615 .67513 Mdot
.49725 .64019 Mdot
.34485 .36819 Mdot
.36349 .34986 Mdot
.5793 .4453 Mdot
.37692 .34858 Mdot
.33758 .24407 Mdot
.66427 .62698 Mdot
.52308 .62349 Mdot
.33946 .53111 Mdot
.37389 .33235 Mdot
.59849 .42543 Mdot
.44241 .42384 Mdot
.24574 .52439 Mdot
.65007 .61545 Mdot
.55824 .20543 Mdot
.49052 .86044 Mdot
.59356 .38656 Mdot
.35725 .55717 Mdot
.4308 .20066 Mdot
.59488 .42026 Mdot
.50152 .65546 Mdot
.52727 .78483 Mdot
.47411 .72189 Mdot
.59576 .39084 Mdot
.65274 .45303 Mdot
.36938 .56059 Mdot
.24933 .70176 Mdot
.57973 .44061 Mdot
.31399 .42903 Mdot
.31295 .52048 Mdot
.50101 .66606 Mdot
.76726 .72688 Mdot
.5938 .65926 Mdot
.72575 .56412 Mdot
.4874 .67903 Mdot
.62019 .40957 Mdot
.48154 .69062 Mdot
.64901 .62676 Mdot
.46754 .62764 Mdot
.40177 .39268 Mdot
.50744 .63271 Mdot
.58437 .46413 Mdot
.39282 .36154 Mdot
.33399 .53201 Mdot
.59346 .19013 Mdot
.55622 .7699 Mdot
.45963 .67323 Mdot
.44505 .64365 Mdot
.57118 .37635 Mdot
.32876 .45465 Mdot
.53785 .42993 Mdot
.59649 .47868 Mdot
.34044 .51104 Mdot
.36396 .371 Mdot
.35756 .57569 Mdot
.66582 .39352 Mdot
.77155 .58021 Mdot
.33631 .56819 Mdot
.43354 .7668 Mdot
.62634 .62862 Mdot
.46967 .47869 Mdot
.60356 .42708 Mdot
.31879 .54741 Mdot
.59517 .45446 Mdot
.38615 .39266 Mdot
.49546 .51899 Mdot
.42053 .73902 Mdot
.35948 .53222 Mdot
.46743 .798 Mdot
.74193 .60369 Mdot
.62764 .35334 Mdot
.35096 .57361 Mdot
.74857 .48766 Mdot
.44567 .67047 Mdot
.64216 .60349 Mdot
.64415 .59367 Mdot
.63272 .59429 Mdot
.5341 .44078 Mdot
.5284 .49018 Mdot
.59783 .60095 Mdot
.3532 .50294 Mdot
.6577 .62273 Mdot
.19179 .47088 Mdot
.57915 .82322 Mdot
.63335 .62544 Mdot
.57501 .42455 Mdot
.51943 .45685 Mdot
.68128 .50324 Mdot
.3303 .69895 Mdot
.79096 .63725 Mdot
.24961 .61644 Mdot
.5932 .39413 Mdot
.34087 .36646 Mdot
.35617 .38368 Mdot
.44492 .18384 Mdot
.74258 .37935 Mdot
.73054 .29499 Mdot
.37675 .32249 Mdot
.38772 .67828 Mdot
.35468 .35271 Mdot
.6186 .38604 Mdot
.61425 .46753 Mdot
.37485 .32125 Mdot
.7732 .55313 Mdot
.37915 .68631 Mdot
.49795 .83071 Mdot
.41002 .35385 Mdot
.33278 .57065 Mdot
.32884 .5763 Mdot
.35124 .51839 Mdot
.58476 .20294 Mdot
.37518 .38097 Mdot
.61227 .45417 Mdot
.47045 .64181 Mdot
.56286 .4543 Mdot
.34313 .55479 Mdot
.58796 .82605 Mdot
.3738 .36997 Mdot
.5632 .42306 Mdot
.62356 .34077 Mdot
.48935 .66865 Mdot
.62245 .6218 Mdot
.35801 .42775 Mdot
.73033 .30078 Mdot
.3638 .5266 Mdot
.38972 .3251 Mdot
.29871 .59204 Mdot
.51759 .81385 Mdot
.5275 .44668 Mdot
.619 .48952 Mdot
.4987 .84839 Mdot
.76948 .36258 Mdot
.54895 .41867 Mdot
.45723 .63474 Mdot
.35051 .65349 Mdot
.63201 .44227 Mdot
.36153 .3876 Mdot
.64053 .58971 Mdot
.64571 .60041 Mdot
.61742 .35462 Mdot
.38382 .45332 Mdot
.52429 .54233 Mdot
.61624 .43761 Mdot
.61896 .36479 Mdot
.4972 .67037 Mdot
.35255 .62563 Mdot
.70316 .25448 Mdot
.60472 .60578 Mdot
.60281 .38175 Mdot
.61453 .7861 Mdot
.42286 .36669 Mdot
.49236 .62034 Mdot
.32187 .52169 Mdot
.36062 .30334 Mdot
.47483 .62388 Mdot
.64298 .42166 Mdot
.60544 .37914 Mdot
.33845 .58022 Mdot
.41035 .39565 Mdot
.62606 .63639 Mdot
.46024 .64008 Mdot
.6074 .62495 Mdot
.3672 .37151 Mdot
.37155 .35052 Mdot
.62301 .34324 Mdot
.53546 .46855 Mdot
.45309 .67008 Mdot
.54033 .4428 Mdot
.47211 .7261 Mdot
.34437 .80846 Mdot
.37096 .58485 Mdot
.56925 .39247 Mdot
.43034 .36547 Mdot
.3624 .5319 Mdot
.60424 .46871 Mdot
.53421 .85757 Mdot
.62581 .46076 Mdot
.35147 .59581 Mdot
.78708 .41603 Mdot
.61369 .63134 Mdot
.69241 .44982 Mdot
.31993 .73136 Mdot
.5628 .40421 Mdot
.4841 .64364 Mdot
.5211 .40783 Mdot
.32653 .55202 Mdot
.36603 .34706 Mdot
.33243 .80869 Mdot
.35103 .54489 Mdot
.56622 .40831 Mdot
.61448 .60151 Mdot
.42726 .36368 Mdot
.58906 .5502 Mdot
.57376 .56865 Mdot
.51932 .38556 Mdot
.54554 .41015 Mdot
.62709 .42748 Mdot
.75098 .62052 Mdot
.47083 .63214 Mdot
.40639 .36096 Mdot
.36046 .55448 Mdot
.33255 .5412 Mdot
.47638 .68254 Mdot
.40826 .59248 Mdot
.46894 .47916 Mdot
.39695 .15786 Mdot
.46915 .69273 Mdot
.60818 .59507 Mdot
.3269 .44437 Mdot
.46717 .63723 Mdot
.4667 .66152 Mdot
.48356 .68476 Mdot
.48219 .5785 Mdot
.37687 .33402 Mdot
.64318 .42409 Mdot
.38194 .3986 Mdot
.62204 .40916 Mdot
.3485 .5955 Mdot
.35622 .5301 Mdot
.37008 .366 Mdot
.46139 .8276 Mdot
.51014 .33188 Mdot
.58582 .41947 Mdot
.34302 .77653 Mdot
.63779 .38618 Mdot
.69 .50497 Mdot
.61462 .37293 Mdot
.46792 .67772 Mdot
.57891 .48691 Mdot
.52916 .4164 Mdot
.48106 .17537 Mdot
.3378 .52794 Mdot
.48417 .70279 Mdot
.6496 .38728 Mdot
.6104 .36336 Mdot
.34181 .35953 Mdot
.41497 .36231 Mdot
.64251 .59375 Mdot
.71951 .41722 Mdot
.33203 .52973 Mdot
.17914 .43268 Mdot
.58683 .39447 Mdot
.57276 .61262 Mdot
.64798 .27993 Mdot
.60059 .4699 Mdot
.34245 .75499 Mdot
.53254 .28522 Mdot
.60304 .43067 Mdot
.43376 .52064 Mdot
.33848 .52047 Mdot
.78854 .54728 Mdot
.63518 .44539 Mdot
.49432 .66377 Mdot
.35971 .35049 Mdot
.42424 .37663 Mdot
.62596 .58884 Mdot
.27135 .28652 Mdot
.35679 .57725 Mdot
.36641 .35561 Mdot
.6047 .41906 Mdot
.35661 .5601 Mdot
.46415 .69135 Mdot
.56481 .38352 Mdot
.73578 .35652 Mdot
.37889 .34414 Mdot
.59721 .37193 Mdot
.29425 .4107 Mdot
.69453 .55674 Mdot
.8079 .44458 Mdot
.3633 .55135 Mdot
.61243 .63676 Mdot
.54134 .3802 Mdot
.39131 .28181 Mdot
.57325 .36887 Mdot
.7406 .5678 Mdot
.19024 .4842 Mdot
.62062 .64352 Mdot
.57985 .41414 Mdot
.60894 .45927 Mdot
.47995 .43914 Mdot
.60761 .60157 Mdot
.55744 .43374 Mdot
.38777 .30214 Mdot
.39402 .34239 Mdot
.44107 .67046 Mdot
.37802 .33804 Mdot
.57922 .42572 Mdot
.53033 .4607 Mdot
.41934 .36759 Mdot
.36228 .80509 Mdot
.66948 .62717 Mdot
.35452 .5699 Mdot
.65002 .40727 Mdot
.6227 .47061 Mdot
.63742 .17032 Mdot
.50371 .62347 Mdot
.43113 .73078 Mdot
.54347 .6994 Mdot
.6502 .75071 Mdot
.59814 .66285 Mdot
.83109 .52766 Mdot
.77272 .36813 Mdot
.56502 .39162 Mdot
.61036 .5283 Mdot
.26378 .38569 Mdot
.33772 .51599 Mdot
.23397 .3515 Mdot
.58817 .39307 Mdot
.60003 .40986 Mdot
.46315 .62139 Mdot
.40015 .73714 Mdot
.72934 .29164 Mdot
.42695 .4327 Mdot
.62401 .63494 Mdot
.36337 .38491 Mdot
.6445 .42043 Mdot
.45488 .53568 Mdot
.51892 .64535 Mdot
.59553 .655 Mdot
.56547 .42011 Mdot
.35635 .25027 Mdot
.24606 .50647 Mdot
.34406 .56202 Mdot
.47597 .64141 Mdot
.74111 .31287 Mdot
.5678 .39609 Mdot
.31751 .53199 Mdot
.58385 .43375 Mdot
.52623 .60701 Mdot
.66873 .40135 Mdot
.6417 .62409 Mdot
.6358 .42386 Mdot
.61815 .66955 Mdot
.76161 .25946 Mdot
.59503 .59979 Mdot
.34301 .32263 Mdot
.52449 .64344 Mdot
.46452 .68489 Mdot
.41561 .3659 Mdot
.46047 .68028 Mdot
.52887 .25333 Mdot
.65747 .32055 Mdot
.62521 .63051 Mdot
.60121 .35678 Mdot
.63005 .62159 Mdot
.48863 .61836 Mdot
.5934 .39247 Mdot
.41271 .84431 Mdot
.45011 .65899 Mdot
.77929 .35713 Mdot
.34546 .54293 Mdot
.51947 .64283 Mdot
.63223 .45066 Mdot
.28535 .58637 Mdot
.47943 .69755 Mdot
.39822 .71635 Mdot
.5759 .44659 Mdot
.37277 .3437 Mdot
.62778 .44568 Mdot
.65351 .41971 Mdot
.51412 .6712 Mdot
.62033 .39988 Mdot
.33284 .567 Mdot
.36988 .3249 Mdot
.76269 .69053 Mdot
.2141 .51522 Mdot
.55448 .42811 Mdot
.60197 .41928 Mdot
.41447 .4048 Mdot
.60174 .48206 Mdot
.37149 .53871 Mdot
.10303 .53579 Mdot
.62601 .62818 Mdot
.4955 .70107 Mdot
.61082 .67074 Mdot
.6423 .45987 Mdot
.62636 .39816 Mdot
.56673 .85708 Mdot
.76636 .58239 Mdot
.34405 .57387 Mdot
.53446 .40456 Mdot
.46825 .69499 Mdot
.62256 .60129 Mdot
.36129 .50964 Mdot
.60727 .43732 Mdot
.58624 .40908 Mdot
.60559 .62838 Mdot
.62291 .54584 Mdot
.63473 .22659 Mdot
.32123 .56151 Mdot
.61435 .49965 Mdot
.47438 .60436 Mdot
.55129 .44643 Mdot
.55268 .19527 Mdot
.40985 .37146 Mdot
.36119 .5221 Mdot
.67842 .71393 Mdot
.56632 .39526 Mdot
.34393 .57781 Mdot
.33266 .52874 Mdot
.55604 .38247 Mdot
.42303 .34566 Mdot
.36296 .32884 Mdot
.39774 .34248 Mdot
.19668 .32923 Mdot
.72531 .54156 Mdot
.49738 .64029 Mdot
.33704 .51994 Mdot
.44304 .64315 Mdot
.60324 .57698 Mdot
.51542 .56479 Mdot
.44675 .63987 Mdot
.38889 .33528 Mdot
.51764 .67322 Mdot
.59345 .46039 Mdot
.33258 .5324 Mdot
.48959 .64053 Mdot
.65339 .42919 Mdot
.34841 .46186 Mdot
.28637 .6709 Mdot
.642 .64254 Mdot
.63245 .58589 Mdot
.62198 .45991 Mdot
.43275 .64978 Mdot
.58465 .40361 Mdot
.3255 .51145 Mdot
.34295 .4555 Mdot
.65013 .41137 Mdot
.46125 .67635 Mdot
.4242 .39955 Mdot
.73549 .30845 Mdot
.5496 .47035 Mdot
.57559 .42315 Mdot
.6203 .4043 Mdot
.58391 .43431 Mdot
.5172 .80694 Mdot
.33229 .58289 Mdot
.21062 .54427 Mdot
.68475 .67829 Mdot
.37857 .37332 Mdot
.38182 .40111 Mdot
.6954 .25754 Mdot
.26138 .39823 Mdot
.33853 .52323 Mdot
.62046 .42531 Mdot
.24092 .46672 Mdot
.65474 .80574 Mdot
.47619 .84612 Mdot
.48764 .4303 Mdot
.50791 .62509 Mdot
.38782 .32491 Mdot
.44753 .66995 Mdot
.61544 .40595 Mdot
.60199 .36475 Mdot
.83768 .48767 Mdot
.34121 .50361 Mdot
.63062 .63249 Mdot
.62422 .40939 Mdot
.72356 .5474 Mdot
.47478 .64984 Mdot
.52054 .64526 Mdot
.58457 .47514 Mdot
.4236 .39298 Mdot
.74242 .25171 Mdot
.35153 .56104 Mdot
.24843 .59551 Mdot
.21065 .41678 Mdot
.26001 .51746 Mdot
.34509 .55731 Mdot
.4988 .4732 Mdot
.48201 .61934 Mdot
.63487 .26428 Mdot
.38259 .37844 Mdot
.64545 .60472 Mdot
.6627 .42222 Mdot
.41535 .37753 Mdot
.50675 .64196 Mdot
.36875 .34539 Mdot
.62787 .39793 Mdot
.31002 .54849 Mdot
.48241 .65465 Mdot
.37495 .60078 Mdot
.43168 .3691 Mdot
.60899 .60197 Mdot
.42291 .45217 Mdot
.48874 .37669 Mdot
.53158 .28249 Mdot
.57886 .47225 Mdot
.45722 .54367 Mdot
.61064 .45339 Mdot
.38096 .40618 Mdot
.5938 .42762 Mdot
.40805 .41455 Mdot
.48414 .64476 Mdot
.6405 .43998 Mdot
.61895 .43469 Mdot
.17213 .52771 Mdot
.56243 .43616 Mdot
.54077 .43245 Mdot
.60679 .43069 Mdot
.33117 .37407 Mdot
.59196 .35635 Mdot
.34776 .35574 Mdot
.4915 .7484 Mdot
.46759 .66486 Mdot
.65189 .60407 Mdot
.60896 .63697 Mdot
.74882 .53289 Mdot
.63986 .70604 Mdot
.38198 .73822 Mdot
.38729 .34259 Mdot
.32305 .55123 Mdot
.59033 .43111 Mdot
.81103 .57701 Mdot
.55107 .63528 Mdot
.51705 .64694 Mdot
.21551 .5169 Mdot
.65158 .48096 Mdot
.79992 .53044 Mdot
.53669 .40435 Mdot
.22953 .30591 Mdot
.57136 .49539 Mdot
.6655 .44123 Mdot
.45391 .68983 Mdot
.58187 .62134 Mdot
.60815 .47773 Mdot
.34212 .34712 Mdot
.64338 .61079 Mdot
.55446 .50898 Mdot
.4141 .64539 Mdot
.47298 .74344 Mdot
.38074 .42111 Mdot
.58736 .45039 Mdot
.48242 .65594 Mdot
.3556 .36773 Mdot
.71159 .26496 Mdot
.3476 .56658 Mdot
.41054 .58452 Mdot
.29822 .3838 Mdot
.37089 .80283 Mdot
.62106 .59487 Mdot
.58678 .23199 Mdot
.5872 .46431 Mdot
.50714 .77441 Mdot
.64813 .40566 Mdot
.60126 .82526 Mdot
.59921 .60597 Mdot
.3873 .33294 Mdot
.32914 .56701 Mdot
.36462 .38958 Mdot
.5174 .28269 Mdot
.42123 .65838 Mdot
.46781 .51322 Mdot
.46493 .65135 Mdot
.54648 .54974 Mdot
.39938 .36224 Mdot
.60665 .38446 Mdot
.39196 .15856 Mdot
.4116 .36783 Mdot
.42304 .3559 Mdot
.21867 .64573 Mdot
.378 .82976 Mdot
.60316 .49639 Mdot
.40538 .33873 Mdot
.46192 .65608 Mdot
.63681 .61122 Mdot
.636 .43499 Mdot
.58584 .45409 Mdot
.41309 .3789 Mdot
.50596 .68477 Mdot
.45323 .2973 Mdot
.48082 .67717 Mdot
.37957 .33417 Mdot
.47718 .66963 Mdot
.29482 .58167 Mdot
.46267 .63507 Mdot
.62186 .47157 Mdot
.59295 .4286 Mdot
.59825 .68899 Mdot
.37189 .34965 Mdot
.61522 .43913 Mdot
.57215 .37645 Mdot
.38621 .36137 Mdot
.54147 .52641 Mdot
.46174 .29653 Mdot
.55067 .43273 Mdot
.56886 .44308 Mdot
.6169 .64054 Mdot
.48717 .5584 Mdot
.56844 .21709 Mdot
.63031 .40344 Mdot
.60788 .6406 Mdot
.34424 .3416 Mdot
.57365 .40779 Mdot
.66573 .77775 Mdot
.35407 .65645 Mdot
.59032 .38862 Mdot
.44558 .66964 Mdot
.53076 .41254 Mdot
.80348 .42806 Mdot
.59814 .47872 Mdot
.3905 .3556 Mdot
.36285 .36103 Mdot
.17221 .45801 Mdot
.39677 .37227 Mdot
.50025 .68196 Mdot
.34388 .55344 Mdot
.51077 .81886 Mdot
.45988 .68731 Mdot
.54935 .47869 Mdot
.15022 .53882 Mdot
.58269 .37927 Mdot
.64305 .45225 Mdot
.78299 .33496 Mdot
.44788 .66503 Mdot
.37577 .38703 Mdot
.44639 .44431 Mdot
.54486 .48333 Mdot
.35837 .5204 Mdot
.65898 .39378 Mdot
.58551 .4799 Mdot
.78848 .39746 Mdot
.52584 .80046 Mdot
.31791 .52337 Mdot
.5425 .43577 Mdot
.62903 .40139 Mdot
.48176 .61139 Mdot
.6031 .42313 Mdot
.6385 .6151 Mdot
.3722 .37944 Mdot
.4572 .63774 Mdot
.61588 .61363 Mdot
.57153 .39666 Mdot
.62278 .63706 Mdot
.49607 .64925 Mdot
.32579 .51626 Mdot
.60698 .39852 Mdot
.65 .64276 Mdot
.62236 .63586 Mdot
.61078 .45087 Mdot
.36436 .34534 Mdot
.63993 .49441 Mdot
.56055 .43285 Mdot
.63885 .41807 Mdot
.4025 .38512 Mdot
.74099 .7705 Mdot
.61116 .47017 Mdot
.74703 .5726 Mdot
.41838 .38164 Mdot
.54684 .54235 Mdot
.45215 .68303 Mdot
.5904 .48263 Mdot
.32605 .51537 Mdot
.32255 .52447 Mdot
.5019 .63019 Mdot
.39984 .32921 Mdot
.55344 .68586 Mdot
.41367 .33097 Mdot
.52421 .41007 Mdot
.54879 .44771 Mdot
.41747 .30806 Mdot
.80886 .61388 Mdot
.38478 .396 Mdot
.41816 .618 Mdot
.39439 .44689 Mdot
.3192 .54322 Mdot
.51458 .66428 Mdot
.37764 .32087 Mdot
.39486 .3903 Mdot
.36249 .33937 Mdot
.64806 .607 Mdot
.6026 .6911 Mdot
.4167 .39055 Mdot
.41661 .39823 Mdot
.57932 .45187 Mdot
.63153 .40685 Mdot
.74403 .33536 Mdot
.71085 .3218 Mdot
.63576 .64094 Mdot
.50527 .65229 Mdot
.18205 .33115 Mdot
.33193 .50905 Mdot
.19395 .54609 Mdot
.64501 .44199 Mdot
.22668 .2537 Mdot
.63453 .44384 Mdot
.60712 .42017 Mdot
.36869 .3247 Mdot
.64967 .64105 Mdot
.62826 .62442 Mdot
.40769 .36297 Mdot
.39955 .40394 Mdot
.6384 .61688 Mdot
.30921 .73101 Mdot
.68179 .77513 Mdot
.49086 .721 Mdot
.38061 .3613 Mdot
.55657 .33341 Mdot
.3271 .57123 Mdot
.52263 .46951 Mdot
.31428 .52157 Mdot
.4705 .65488 Mdot
.47134 .62311 Mdot
.36241 .52764 Mdot
.57547 .44414 Mdot
.49095 .63616 Mdot
.57328 .38806 Mdot
.24773 .63462 Mdot
.52138 .30792 Mdot
.5765 .66607 Mdot
.50937 .40049 Mdot
.53091 .51988 Mdot
.37653 .60179 Mdot
.57248 .40101 Mdot
.65978 .75891 Mdot
.62645 .63324 Mdot
.52302 .40015 Mdot
.35789 .51653 Mdot
.80051 .35576 Mdot
.60128 .39387 Mdot
.38752 .35296 Mdot
.33327 .52505 Mdot
.29639 .33946 Mdot
.32024 .43159 Mdot
.62154 .40669 Mdot
.31424 .20985 Mdot
.32812 .34696 Mdot
.47125 .63702 Mdot
.33596 .27137 Mdot
.39789 .39914 Mdot
.64936 .66579 Mdot
.69356 .68739 Mdot
.43011 .82252 Mdot
.36662 .38133 Mdot
.49421 .61731 Mdot
.34868 .34374 Mdot
.61327 .5993 Mdot
.34034 .33271 Mdot
.47987 .6478 Mdot
.56859 .41883 Mdot
.47099 .68201 Mdot
.65191 .61415 Mdot
.64078 .23447 Mdot
.31777 .52443 Mdot
.47864 .70253 Mdot
.35842 .53863 Mdot
.68007 .56347 Mdot
.73712 .6331 Mdot
.35943 .5646 Mdot
.44919 .25182 Mdot
.55495 .45527 Mdot
.40637 .39757 Mdot
.47504 .68605 Mdot
.62269 .74895 Mdot
.42156 .44894 Mdot
.38751 .37917 Mdot
.50268 .64028 Mdot
.33198 .42652 Mdot
.37822 .2638 Mdot
.53952 .4325 Mdot
.66314 .51587 Mdot
.38287 .36436 Mdot
.47751 .61632 Mdot
.64175 .20928 Mdot
.34702 .34524 Mdot
.47302 .69345 Mdot
.33433 .57305 Mdot
.33286 .5458 Mdot
.56323 .45187 Mdot
.32089 .58207 Mdot
.49012 .629 Mdot
.39653 .52599 Mdot
.40428 .33679 Mdot
.30487 .31958 Mdot
.65791 .63791 Mdot
.46907 .67189 Mdot
.59938 .37544 Mdot
.35898 .40024 Mdot
.32888 .63102 Mdot
.46513 .31373 Mdot
.4014 .18287 Mdot
.47636 .68234 Mdot
.37967 .3837 Mdot
.38454 .35079 Mdot
.54663 .46761 Mdot
.3342 .41825 Mdot
.55388 .69105 Mdot
.47282 .40783 Mdot
.46673 .40837 Mdot
.44088 .67147 Mdot
.4449 .71414 Mdot
.65076 .38729 Mdot
.58639 .44482 Mdot
.32005 .54865 Mdot
.56855 .42227 Mdot
.3831 .32699 Mdot
.57994 .47223 Mdot
.3594 .55426 Mdot
.46309 .64739 Mdot
.60249 .39689 Mdot
.61685 .63513 Mdot
.34274 .58446 Mdot
.35247 .49854 Mdot
.46365 .6728 Mdot
.41333 .37995 Mdot
.56921 .5476 Mdot
.48802 .67414 Mdot
.58635 .44975 Mdot
.48659 .56907 Mdot
.62915 .39713 Mdot
.67499 .47409 Mdot
.34508 .35263 Mdot
.45587 .63971 Mdot
.3666 .32168 Mdot
.35362 .53991 Mdot
.68525 .67991 Mdot
.58469 .42533 Mdot
.46817 .69252 Mdot
.38198 .62294 Mdot
.66372 .49537 Mdot
.43401 .38893 Mdot
.32271 .71755 Mdot
.37784 .40185 Mdot
.50528 .65867 Mdot
.1778 .56284 Mdot
.63566 .59796 Mdot
.51738 .64539 Mdot
.78383 .66206 Mdot
.4525 .66366 Mdot
.57131 .459 Mdot
.61829 .46223 Mdot
.46122 .63619 Mdot
.61092 .63669 Mdot
.73795 .28825 Mdot
.49731 .70699 Mdot
.37248 .38448 Mdot
.25132 .66263 Mdot
.49987 .15623 Mdot
.38395 .58026 Mdot
.32097 .54873 Mdot
.58159 .50141 Mdot
.56758 .47374 Mdot
.35315 .51046 Mdot
.32542 .50383 Mdot
.63946 .59385 Mdot
.48436 .68784 Mdot
.35212 .3971 Mdot
.37093 .51035 Mdot
.35536 .42077 Mdot
.63112 .70233 Mdot
.5507 .47043 Mdot
.2077 .43337 Mdot
.64513 .43603 Mdot
.71265 .63105 Mdot
.3613 .55287 Mdot
.62194 .38524 Mdot
.53438 .42401 Mdot
.33741 .51181 Mdot
.63819 .61066 Mdot
.40953 .59627 Mdot
.47959 .66565 Mdot
.75285 .74569 Mdot
.56167 .39008 Mdot
.58066 .46902 Mdot
.34516 .51851 Mdot
.53516 .74298 Mdot
.37518 .37382 Mdot
.3638 .39358 Mdot
.47027 .63244 Mdot
.40153 .46203 Mdot
.56509 .46081 Mdot
.56867 .40823 Mdot
.48558 .66006 Mdot
.50087 .68465 Mdot
.35686 .71946 Mdot
.60637 .46287 Mdot
.34108 .53004 Mdot
.59894 .57608 Mdot
.36383 .54856 Mdot
.62389 .39139 Mdot
.58498 .47042 Mdot
.62153 .47225 Mdot
.60463 .37754 Mdot
.3169 .51054 Mdot
.63903 .40178 Mdot
.58866 .3612 Mdot
.38275 .38274 Mdot
.62811 .40959 Mdot
.46425 .4118 Mdot
.57042 .42892 Mdot
.63722 .61331 Mdot
.52754 .2081 Mdot
.60189 .39436 Mdot
.58156 .47599 Mdot
.5048 .69384 Mdot
.58599 .41458 Mdot
.32703 .51045 Mdot
.37373 .35733 Mdot
.33986 .52057 Mdot
.3221 .52378 Mdot
.44699 .63155 Mdot
.60602 .59382 Mdot
.64338 .45992 Mdot
.64861 .62417 Mdot
.53792 .46561 Mdot
.56559 .39548 Mdot
.66348 .68823 Mdot
.21653 .31947 Mdot
.59862 .20761 Mdot
.58324 .42687 Mdot
.44849 .66131 Mdot
.44666 .66838 Mdot
.59213 .53148 Mdot
.54073 .42263 Mdot
.37083 .52758 Mdot
.31897 .53535 Mdot
.73829 .37241 Mdot
.78551 .47893 Mdot
.63761 .6128 Mdot
.48077 .54618 Mdot
.5482 .41416 Mdot
.61651 .38297 Mdot
.56761 .38361 Mdot
.44987 .63566 Mdot
.49309 .41315 Mdot
.51651 .65533 Mdot
.23827 .52401 Mdot
.35796 .52606 Mdot
.61267 .39928 Mdot
.20478 .47404 Mdot
.41148 .35333 Mdot
.37371 .35615 Mdot
.36018 .50167 Mdot
.44181 .61903 Mdot
.7227 .30397 Mdot
.47566 .85191 Mdot
.33891 .32294 Mdot
.65506 .63069 Mdot
.56491 .40571 Mdot
.45753 .65277 Mdot
.37817 .33252 Mdot
.65476 .62977 Mdot
.60562 .38719 Mdot
.60471 .69139 Mdot
.57957 .43244 Mdot
.24509 .4002 Mdot
.35626 .34988 Mdot
.62724 .81795 Mdot
.40505 .33233 Mdot
.34749 .58646 Mdot
.36663 .52831 Mdot
.60338 .4683 Mdot
.36948 .28463 Mdot
.39041 .40075 Mdot
.44591 .58904 Mdot
.60891 .5949 Mdot
.30449 .60462 Mdot
.62624 .59903 Mdot
.47698 .63944 Mdot
.64079 .60416 Mdot
.48219 .6471 Mdot
.7037 .29546 Mdot
.33022 .37727 Mdot
.61812 .62218 Mdot
.37995 .61536 Mdot
.57092 .4782 Mdot
.63489 .64253 Mdot
.59722 .36557 Mdot
.65695 .49349 Mdot
.4863 .66271 Mdot
.60991 .59694 Mdot
.6043 .38207 Mdot
.82435 .51635 Mdot
.35103 .57263 Mdot
.36967 .52741 Mdot
.59499 .36614 Mdot
.4367 .65918 Mdot
.34867 .33102 Mdot
.57857 .81661 Mdot
.38032 .54609 Mdot
.60907 .46934 Mdot
.6054 .47972 Mdot
.38749 .40219 Mdot
.18524 .49089 Mdot
.59356 .46939 Mdot
.6598 .36585 Mdot
.60802 .46373 Mdot
.36587 .56438 Mdot
.36415 .38806 Mdot
.37957 .35205 Mdot
.50063 .63879 Mdot
.41743 .35705 Mdot
.62459 .53846 Mdot
.21964 .48358 Mdot
.67557 .4254 Mdot
.35331 .54574 Mdot
.24113 .50011 Mdot
.23521 .52712 Mdot
.78576 .64154 Mdot
.43296 .37086 Mdot
.64882 .41066 Mdot
.42332 .36453 Mdot
.62676 .60196 Mdot
.3751 .34355 Mdot
.38713 .32475 Mdot
.5835 .40116 Mdot
.62028 .40997 Mdot
.46606 .64206 Mdot
.34615 .42986 Mdot
.4156 .38161 Mdot
.63418 .44295 Mdot
.58827 .48801 Mdot
.58158 .38292 Mdot
.48058 .5841 Mdot
.37603 .39404 Mdot
.25671 .70847 Mdot
.7427 .46026 Mdot
.41493 .38173 Mdot
.75655 .27133 Mdot
.36935 .62695 Mdot
.42477 .67075 Mdot
.41904 .5831 Mdot
.6121 .46093 Mdot
.47679 .70005 Mdot
.61471 .40531 Mdot
.20862 .4339 Mdot
.59149 .40936 Mdot
.6398 .61536 Mdot
.56516 .3914 Mdot
.48582 .62237 Mdot
.4806 .67846 Mdot
.6011 .47412 Mdot
.6037 .39936 Mdot
.66459 .24756 Mdot
.35286 .31041 Mdot
.36886 .35585 Mdot
.54951 .68379 Mdot
.61264 .62045 Mdot
.36055 .52211 Mdot
.60152 .42889 Mdot
.44752 .6327 Mdot
.47801 .67995 Mdot
.38807 .39828 Mdot
.49934 .65905 Mdot
.35008 .56094 Mdot
.5891 .42443 Mdot
.35882 .51342 Mdot
.64629 .60239 Mdot
.36816 .39004 Mdot
.6256 .40835 Mdot
.57889 .45157 Mdot
.36276 .36131 Mdot
.65604 .42175 Mdot
.61276 .63639 Mdot
.45418 .6699 Mdot
.36362 .37957 Mdot
.34039 .55145 Mdot
.47828 .64105 Mdot
.64057 .41642 Mdot
.27428 .25496 Mdot
.56886 .45311 Mdot
.6221 .45188 Mdot
.8095 .63831 Mdot
.54988 .40793 Mdot
.47668 .68406 Mdot
.38248 .33173 Mdot
.54626 .36451 Mdot
.74092 .51483 Mdot
.67167 .83574 Mdot
.51649 .65088 Mdot
.5613 .41171 Mdot
.80073 .59258 Mdot
.56169 .4168 Mdot
.47567 .35194 Mdot
.46453 .70678 Mdot
.49904 .50137 Mdot
.61975 .37724 Mdot
.331 .55526 Mdot
.46092 .64154 Mdot
.48672 .64745 Mdot
.23541 .6347 Mdot
.57788 .40255 Mdot
.44418 .55412 Mdot
.61527 .39006 Mdot
.3383 .55317 Mdot
.74655 .40907 Mdot
.48122 .67963 Mdot
.44212 .18068 Mdot
.60925 .45536 Mdot
.39469 .3923 Mdot
.52077 .66559 Mdot
.28199 .5666 Mdot
.63913 .42239 Mdot
.64081 .63402 Mdot
.35537 .49008 Mdot
.66288 .39367 Mdot
.35276 .54988 Mdot
.63777 .41475 Mdot
.5631 .34628 Mdot
.30464 .27887 Mdot
.36367 .3419 Mdot
.32752 .56531 Mdot
.50809 .57378 Mdot
.64186 .40216 Mdot
.36504 .37976 Mdot
.38423 .37941 Mdot
.64929 .60629 Mdot
.50383 .53569 Mdot
.29334 .40188 Mdot
.53626 .32587 Mdot
.24355 .64883 Mdot
.51535 .67567 Mdot
.41771 .73238 Mdot
.62441 .44213 Mdot
.58482 .58105 Mdot
.32436 .51376 Mdot
.56596 .45029 Mdot
.58176 .2359 Mdot
.41077 .35784 Mdot
.57267 .45302 Mdot
.63146 .62125 Mdot
.5596 .625 Mdot
.59888 .57348 Mdot
.71925 .678 Mdot
.46616 .65236 Mdot
.58022 .36282 Mdot
.58256 .34528 Mdot
.44895 .6807 Mdot
.60401 .48661 Mdot
.4672 .68933 Mdot
.33588 .76441 Mdot
.64173 .64188 Mdot
.37791 .39251 Mdot
.34108 .6105 Mdot
.62886 .47342 Mdot
.57041 .47193 Mdot
.61325 .58776 Mdot
.5908 .44625 Mdot
.28432 .27727 Mdot
.48893 .58536 Mdot
.48609 .63765 Mdot
.3629 .33982 Mdot
.60422 .4841 Mdot
.52338 .56437 Mdot
.56115 .42591 Mdot
.62569 .29826 Mdot
.58371 .47745 Mdot
.31471 .41859 Mdot
.36021 .34948 Mdot
.35694 .54706 Mdot
.63186 .38989 Mdot
.59825 .4124 Mdot
.76968 .52646 Mdot
.55808 .4888 Mdot
.62995 .39057 Mdot
.4424 .3913 Mdot
.36964 .33125 Mdot
.34849 .34775 Mdot
.5083 .63653 Mdot
.78537 .43745 Mdot
.34623 .53408 Mdot
.52254 .38597 Mdot
.37774 .53703 Mdot
.43539 .30375 Mdot
.65232 .63359 Mdot
.76182 .63837 Mdot
.61364 .43277 Mdot
.38893 .3407 Mdot
.58571 .79399 Mdot
.34568 .37064 Mdot
.46453 .53523 Mdot
.33207 .53011 Mdot
.40963 .36625 Mdot
.60485 .41642 Mdot
.40757 .44678 Mdot
.80661 .56696 Mdot
.34962 .52915 Mdot
.55147 .47977 Mdot
.50745 .62896 Mdot
.59174 .66493 Mdot
.34469 .22958 Mdot
.35326 .57253 Mdot
.35635 .59629 Mdot
.57561 .40235 Mdot
.40773 .34716 Mdot
.33462 .55683 Mdot
.36686 .56028 Mdot
.50045 .65555 Mdot
.6229 .4127 Mdot
.62517 .41719 Mdot
.50692 .65634 Mdot
.34145 .51997 Mdot
.57555 .36699 Mdot
.66799 .39819 Mdot
.83562 .43993 Mdot
.30993 .3925 Mdot
.75825 .74589 Mdot
.59603 .53574 Mdot
.53195 .22465 Mdot
.57829 .82057 Mdot
.40845 .38819 Mdot
.58135 .39114 Mdot
.66329 .44248 Mdot
.49088 .62895 Mdot
.57828 .41935 Mdot
.44099 .69108 Mdot
.32701 .52574 Mdot
.79685 .35521 Mdot
.26845 .46888 Mdot
.38582 .79864 Mdot
.57844 .41725 Mdot
.42701 .40966 Mdot
.62367 .60636 Mdot
.3696 .59087 Mdot
.35249 .37463 Mdot
.59167 .37542 Mdot
.66009 .24446 Mdot
.51765 .64851 Mdot
.40134 .37923 Mdot
.71253 .26842 Mdot
.50711 .49046 Mdot
.62759 .39615 Mdot
.51269 .64999 Mdot
.63126 .78287 Mdot
.31996 .32051 Mdot
.376 .56367 Mdot
.63918 .61041 Mdot
.45652 .64194 Mdot
.31806 .53863 Mdot
.37161 .41083 Mdot
.40305 .37092 Mdot
.34252 .33778 Mdot
.58296 .21051 Mdot
.48508 .70475 Mdot
.62111 .60873 Mdot
.79153 .52441 Mdot
.78059 .49978 Mdot
.63902 .61951 Mdot
.47287 .62244 Mdot
.37205 .33145 Mdot
.40583 .35741 Mdot
.3741 .35794 Mdot
.53073 .18066 Mdot
.42751 .36766 Mdot
.20035 .58498 Mdot
.58962 .38032 Mdot
.67274 .39596 Mdot
.56299 .41105 Mdot
.36738 .52056 Mdot
.35878 .36221 Mdot
.43492 .45173 Mdot
.53048 .44356 Mdot
.76189 .61451 Mdot
.56684 .45537 Mdot
.32067 .57297 Mdot
.58064 .45859 Mdot
.20334 .39954 Mdot
.42324 .36872 Mdot
.58132 .42404 Mdot
.3136 .54741 Mdot
.60947 .61794 Mdot
.43466 .39018 Mdot
.62066 .40473 Mdot
.36739 .75013 Mdot
.55479 .40036 Mdot
.38678 .79182 Mdot
.2842 .33775 Mdot
.65438 .63166 Mdot
.23716 .37641 Mdot
.51092 .62148 Mdot
.66307 .37469 Mdot
.52941 .46438 Mdot
.35486 .53454 Mdot
.31982 .60915 Mdot
.4659 .66321 Mdot
.48901 .42734 Mdot
.63176 .36213 Mdot
.65186 .608 Mdot
.32324 .32667 Mdot
.34939 .50845 Mdot
.59809 .48758 Mdot
.53723 .43478 Mdot
.23138 .57914 Mdot
.61402 .36186 Mdot
.5959 .48167 Mdot
.6166 .5824 Mdot
.20102 .56584 Mdot
.57123 .43342 Mdot
.47277 .53933 Mdot
.34147 .32876 Mdot
.5226 .41607 Mdot
.19387 .57101 Mdot
.62129 .46025 Mdot
.40783 .3756 Mdot
.68204 .39753 Mdot
.28069 .39048 Mdot
.60449 .59562 Mdot
.58232 .47703 Mdot
.16975 .47057 Mdot
.60074 .45588 Mdot
.34268 .53506 Mdot
.54127 .42674 Mdot
.47753 .64925 Mdot
.5984 .2026 Mdot
.49489 .63438 Mdot
.55472 .4453 Mdot
.37616 .36063 Mdot
.35064 .52035 Mdot
.47452 .18728 Mdot
.57398 .69899 Mdot
.19981 .54401 Mdot
.4899 .84081 Mdot
.60519 .60128 Mdot
.61698 .65516 Mdot
.33803 .50691 Mdot
.5798 .4255 Mdot
.19344 .61213 Mdot
.57597 .49778 Mdot
.5701 .44535 Mdot
.59263 .40853 Mdot
.73209 .63424 Mdot
.32355 .5264 Mdot
.48648 .66851 Mdot
.5893 .47015 Mdot
.63603 .39742 Mdot
.40449 .3892 Mdot
.61505 .62852 Mdot
.45135 .68162 Mdot
.62677 .62998 Mdot
.45838 .64552 Mdot
.77455 .3098 Mdot
.54535 .39234 Mdot
.60909 .6113 Mdot
.36001 .49501 Mdot
.40829 .38201 Mdot
.22308 .47844 Mdot
.48368 .64294 Mdot
.50288 .63373 Mdot
.59503 .4773 Mdot
.41125 .37358 Mdot
.36773 .32343 Mdot
.62035 .59998 Mdot
.35668 .56399 Mdot
.60076 .39421 Mdot
.55628 .4038 Mdot
.65155 .34148 Mdot
.43722 .64526 Mdot
.23791 .40428 Mdot
.41958 .74542 Mdot
.58096 .42766 Mdot
.4022 .33554 Mdot
.59824 .40079 Mdot
.48145 .80054 Mdot
.41304 .35289 Mdot
.62659 .45544 Mdot
.71504 .23852 Mdot
.42319 .63681 Mdot
.26324 .42121 Mdot
.61547 .47327 Mdot
.56075 .84439 Mdot
.62027 .43881 Mdot
.80877 .36028 Mdot
.57601 .77566 Mdot
.5521 .44871 Mdot
.64067 .4279 Mdot
.49262 .30875 Mdot
.55974 .40673 Mdot
.50734 .65053 Mdot
.76607 .35458 Mdot
.34105 .34994 Mdot
.2547 .5659 Mdot
.54123 .21265 Mdot
.60062 .60377 Mdot
.46997 .63258 Mdot
.44376 .7105 Mdot
.63632 .62683 Mdot
.38262 .35983 Mdot
.58411 .43441 Mdot
.42702 .47963 Mdot
.43861 .65639 Mdot
.55268 .51482 Mdot
.3408 .53532 Mdot
.3367 .66277 Mdot
.55372 .60477 Mdot
.35158 .55417 Mdot
.63 .41248 Mdot
.47858 .30591 Mdot
.67469 .28799 Mdot
.71467 .75376 Mdot
.31775 .54616 Mdot
.35043 .52751 Mdot
.5647 .1874 Mdot
.66235 .61959 Mdot
.24102 .59006 Mdot
.31922 .42606 Mdot
.35529 .51899 Mdot
.33192 .3077 Mdot
.50755 .66988 Mdot
.30399 .54664 Mdot
.54382 .37553 Mdot
.57643 .38908 Mdot
.60263 .41542 Mdot
.36246 .55785 Mdot
.64522 .51089 Mdot
.3307 .26805 Mdot
.35971 .53799 Mdot
.57442 .50732 Mdot
.48193 .49914 Mdot
.40642 .68851 Mdot
.49658 .67058 Mdot
.61436 .59113 Mdot
.6549 .64792 Mdot
.38731 .39015 Mdot
.61 .59225 Mdot
.56487 .6109 Mdot
.59476 .44069 Mdot
.36425 .54073 Mdot
.31965 .62089 Mdot
.33603 .54554 Mdot
.6327 .62685 Mdot
.65187 .60107 Mdot
.38208 .38216 Mdot
.36975 .3502 Mdot
.5095 .24369 Mdot
.70374 .48555 Mdot
.55905 .43559 Mdot
.65259 .72189 Mdot
.38091 .32292 Mdot
.56101 .52232 Mdot
.61418 .5902 Mdot
.61146 .62116 Mdot
.76564 .54495 Mdot
.61326 .42851 Mdot
.43318 .32326 Mdot
.60872 .42825 Mdot
.73939 .42649 Mdot
.64191 .44593 Mdot
.50038 .65647 Mdot
.6204 .42704 Mdot
.76884 .55607 Mdot
.65141 .45416 Mdot
.56162 .47115 Mdot
.44876 .63455 Mdot
.65506 .37854 Mdot
.47745 .65122 Mdot
.55528 .44095 Mdot
.63796 .6502 Mdot
.47461 .62963 Mdot
.73282 .53425 Mdot
.75677 .56675 Mdot
.47363 .6211 Mdot
.6517 .62179 Mdot
.60376 .63191 Mdot
.72206 .57423 Mdot
.35278 .37536 Mdot
.54931 .49426 Mdot
.5779 .42361 Mdot
.51054 .67315 Mdot
.32046 .53762 Mdot
.64301 .42725 Mdot
.5829 .48408 Mdot
.63081 .45926 Mdot
.38816 .39098 Mdot
.55796 .68914 Mdot
.61015 .60483 Mdot
.50797 .65935 Mdot
.56903 .55041 Mdot
.43802 .66646 Mdot
.54023 .44425 Mdot
.66229 .4419 Mdot
.56177 .22408 Mdot
.39518 .65977 Mdot
.52731 .17414 Mdot
.40222 .37244 Mdot
.4453 .66743 Mdot
.65508 .64222 Mdot
.65714 .45751 Mdot
.39015 .33966 Mdot
.47968 .64835 Mdot
.58035 .43201 Mdot
.56634 .49013 Mdot
.22511 .51884 Mdot
.63696 .54187 Mdot
.74749 .55619 Mdot
.50078 .62867 Mdot
.50991 .62587 Mdot
.75349 .59386 Mdot
.58776 .62571 Mdot
.42405 .44972 Mdot
.57241 .41072 Mdot
.64008 .63353 Mdot
.38085 .33321 Mdot
.60425 .22623 Mdot
.37013 .54372 Mdot
.33861 .42206 Mdot
.58007 .41788 Mdot
.52174 .5183 Mdot
.37579 .36296 Mdot
.63336 .61953 Mdot
.36427 .55532 Mdot
.63467 .66042 Mdot
.44312 .64793 Mdot
.40569 .82543 Mdot
.59558 .45355 Mdot
.58965 .47751 Mdot
.3274 .57536 Mdot
.40385 .34808 Mdot
.59803 .59914 Mdot
.25917 .67307 Mdot
.49376 .64931 Mdot
.18385 .59175 Mdot
.40113 .33605 Mdot
.54088 .34185 Mdot
.50123 .67259 Mdot
.3691 .51171 Mdot
.72097 .55534 Mdot
.35432 .55785 Mdot
.56005 .45248 Mdot
.38672 .34545 Mdot
.32666 .56108 Mdot
.3149 .38435 Mdot
.81666 .57498 Mdot
.54235 .33966 Mdot
.59529 .4354 Mdot
.8255 .47248 Mdot
.36576 .76859 Mdot
.3435 .31305 Mdot
.32046 .5205 Mdot
.56518 .451 Mdot
.57624 .4753 Mdot
.59875 .45716 Mdot
.32326 .54453 Mdot
.65998 .71069 Mdot
.48841 .66012 Mdot
.56917 .40514 Mdot
.64147 .5949 Mdot
.4727 .65638 Mdot
.32161 .60057 Mdot
.49288 .67273 Mdot
.43068 .35749 Mdot
.54434 .45681 Mdot
.27095 .55668 Mdot
.73009 .22005 Mdot
.34465 .52361 Mdot
.45249 .62722 Mdot
.55003 .39055 Mdot
.35786 .64879 Mdot
.35592 .33748 Mdot
.49531 .64813 Mdot
.57877 .4676 Mdot
.3765 .61074 Mdot
.62678 .22563 Mdot
.48861 .67582 Mdot
.39035 .33864 Mdot
.72102 .74385 Mdot
.57223 .42033 Mdot
.61292 .44409 Mdot
.4052 .36497 Mdot
.41783 .25885 Mdot
.66062 .22392 Mdot
.60193 .39998 Mdot
.35814 .54725 Mdot
.30638 .78097 Mdot
.58062 .48369 Mdot
.75345 .43285 Mdot
.4637 .64094 Mdot
.29806 .53306 Mdot
.26704 .38193 Mdot
.65025 .46565 Mdot
.24691 .62602 Mdot
.3715 .59802 Mdot
.81116 .5002 Mdot
.43897 .68627 Mdot
.48327 .75826 Mdot
.80496 .44338 Mdot
.31178 .5455 Mdot
.42345 .42303 Mdot
.25594 .64637 Mdot
.41648 .21871 Mdot
.67046 .76878 Mdot
.52155 .76245 Mdot
.65995 .24283 Mdot
.4409 .47753 Mdot
.45114 .65572 Mdot
.54515 .52056 Mdot
.61592 .40402 Mdot
.3735 .77303 Mdot
.29964 .29958 Mdot
.31052 .28862 Mdot
.82696 .4747 Mdot
.48792 .35446 Mdot
.80167 .58556 Mdot
.79327 .64091 Mdot
.70794 .37193 Mdot
.43829 .74084 Mdot
.18391 .6 Mdot
.75506 .31547 Mdot
.26344 .70039 Mdot
.67667 .40557 Mdot
.45529 .53614 Mdot
.43717 .81175 Mdot
.36902 .4149 Mdot
.36701 .26818 Mdot
.49967 .64095 Mdot
.34502 .35979 Mdot
.25035 .60841 Mdot
.38236 .40319 Mdot
.27823 .38605 Mdot
.73688 .7369 Mdot
.81426 .58367 Mdot
.17885 .47403 Mdot
.57844 .83024 Mdot
.56848 .23473 Mdot
.13241 .54225 Mdot
.45569 .6957 Mdot
.39581 .39738 Mdot
.72176 .6269 Mdot
.77872 .54711 Mdot
.25538 .51351 Mdot
.29074 .6999 Mdot
.62871 .68576 Mdot
.67853 .54346 Mdot
.38592 .35339 Mdot
.24515 .37388 Mdot
.30822 .57603 Mdot
.26368 .47742 Mdot
.75388 .33129 Mdot
.72823 .7115 Mdot
.42137 .48458 Mdot
.29945 .69138 Mdot
.3648 .68069 Mdot
.36939 .2254 Mdot
.73928 .48272 Mdot
.56434 .52726 Mdot
.30817 .3969 Mdot
.55039 .82218 Mdot
.43314 .2303 Mdot
.73283 .42061 Mdot
.78305 .53142 Mdot
.75372 .29087 Mdot
.44372 .78903 Mdot
.56991 .14534 Mdot
.36141 .39775 Mdot
.60495 .48072 Mdot
.44601 .26007 Mdot
.16495 .49322 Mdot
.64529 .59064 Mdot
.70781 .6926 Mdot
.62037 .59245 Mdot
.41437 .33703 Mdot
.63117 .21721 Mdot
.19576 .5648 Mdot
.15537 .52525 Mdot
.62908 .65425 Mdot
.52818 .37776 Mdot
.51243 .88977 Mdot
.79133 .56895 Mdot
.25791 .45045 Mdot
.82837 .42442 Mdot
.48087 .4745 Mdot
.30195 .3254 Mdot
.324 .55627 Mdot
.80616 .42341 Mdot
.39932 .35315 Mdot
.57736 .13564 Mdot
.80546 .3506 Mdot
.60538 .23753 Mdot
.92089 .54635 Mdot
.74218 .61492 Mdot
.50283 .50372 Mdot
.39453 .53978 Mdot
.71865 .50968 Mdot
.34652 .2557 Mdot
.68684 .63158 Mdot
.35993 .65645 Mdot
.54153 .85644 Mdot
.81689 .47304 Mdot
.16246 .5521 Mdot
.35223 .79271 Mdot
.40606 .23158 Mdot
.51821 .56233 Mdot
.51043 .42641 Mdot
.54873 .6275 Mdot
.69545 .72376 Mdot
.75803 .28587 Mdot
.74469 .46147 Mdot
.66215 .8427 Mdot
.59629 .59419 Mdot
.61257 .7111 Mdot
.77365 .70824 Mdot
.69145 .55199 Mdot
.26571 .35693 Mdot
.76912 .42277 Mdot
.50035 .4237 Mdot
.58404 .55967 Mdot
.70626 .70455 Mdot
.23689 .43389 Mdot
.77713 .37644 Mdot
.61887 .80064 Mdot
.23017 .57575 Mdot
.53603 .30862 Mdot
.77623 .47042 Mdot
.39196 .4102 Mdot
.67543 .5134 Mdot
.27078 .37053 Mdot
.82998 .56025 Mdot
.31316 .56601 Mdot
.8456 .556 Mdot
.66672 .23042 Mdot
.55266 .38196 Mdot
.58384 .50406 Mdot
.45721 .36793 Mdot
.68267 .51379 Mdot
.64497 .36528 Mdot
.22616 .5365 Mdot
.81611 .60603 Mdot
.66087 .29294 Mdot
.36971 .60552 Mdot
.32473 .61066 Mdot
.76687 .72051 Mdot
.4728 .26809 Mdot
.59148 .63579 Mdot
.74531 .351 Mdot
.36553 .23482 Mdot
.47086 .66665 Mdot
.16714 .55247 Mdot
.37877 .52269 Mdot
.62024 .22862 Mdot
.53036 .3291 Mdot
.48732 .21135 Mdot
.81656 .60637 Mdot
.48857 .74951 Mdot
.65194 .22797 Mdot
.6874 .57586 Mdot
.22393 .66014 Mdot
.40362 .68042 Mdot
.66086 .40226 Mdot
.30842 .71219 Mdot
.61278 .6391 Mdot
.51316 .27478 Mdot
.2723 .73894 Mdot
.55871 .74209 Mdot
.6312 .37182 Mdot
.6036 .23378 Mdot
.41445 .65665 Mdot
.40141 .4493 Mdot
.45272 .15526 Mdot
.56132 .47671 Mdot
.79206 .50932 Mdot
.42242 .77579 Mdot
.71473 .49212 Mdot
.66132 .79507 Mdot
.50944 .80788 Mdot
.61202 .15923 Mdot
.82175 .43496 Mdot
.5631 .70072 Mdot
.80069 .44674 Mdot
.83309 .51087 Mdot
.60938 .16338 Mdot
.55787 .49543 Mdot
.34807 .58773 Mdot
.26035 .25435 Mdot
.49602 .67319 Mdot
.78379 .56072 Mdot
.24318 .64848 Mdot
.54203 .60999 Mdot
.4536 .38887 Mdot
.50231 .45869 Mdot
.4412 .48488 Mdot
.35584 .31132 Mdot
.64127 .36354 Mdot
.52432 .15926 Mdot
.66936 .19317 Mdot
.55778 .15219 Mdot
.49694 .82936 Mdot
.79729 .41034 Mdot
.52458 .53122 Mdot
.17561 .49507 Mdot
.57184 .52214 Mdot
.59909 .38232 Mdot
.62891 .66593 Mdot
.73784 .6205 Mdot
.57321 .21607 Mdot
.29004 .46872 Mdot
.32208 .34174 Mdot
.70609 .69882 Mdot
.21984 .75247 Mdot
.53166 .24464 Mdot
.2056 .60777 Mdot
.59021 .64843 Mdot
.70398 .48954 Mdot
.67849 .72612 Mdot
.52794 .20491 Mdot
.80217 .64137 Mdot
.35496 .31234 Mdot
.25994 .68933 Mdot
.55485 .76151 Mdot
.40869 .43191 Mdot
.56332 .68604 Mdot
.7921 .60774 Mdot
.25964 .56506 Mdot
.49679 .19413 Mdot
.32427 .44441 Mdot
.44478 .24931 Mdot
.46385 .59125 Mdot
.34419 .67712 Mdot
.2523 .70602 Mdot
.49019 .78841 Mdot
.74643 .42449 Mdot
.47569 .50016 Mdot
.2256 .38656 Mdot
.39331 .59331 Mdot
.74278 .43558 Mdot
.46348 .41512 Mdot
.79204 .46271 Mdot
.59678 .10626 Mdot
.45245 .17076 Mdot
.72754 .75874 Mdot
.65974 .72506 Mdot
.64703 .37894 Mdot
.78981 .66618 Mdot
.53096 .13901 Mdot
.76772 .26845 Mdot
.32701 .68357 Mdot
.43834 .67909 Mdot
.37465 .52711 Mdot
.56084 .17059 Mdot
.6566 .70753 Mdot
.76161 .68857 Mdot
.76203 .46207 Mdot
.35062 .49614 Mdot
.20036 .33565 Mdot
.75348 .29699 Mdot
.54446 .33131 Mdot
.63779 .53929 Mdot
.65069 .39731 Mdot
.25232 .33368 Mdot
.37977 .40136 Mdot
.40216 .71522 Mdot
.70973 .47372 Mdot
.47068 .67532 Mdot
.7026 .64718 Mdot
.30243 .71313 Mdot
.56592 .39104 Mdot
.5114 .56935 Mdot
.43032 .38888 Mdot
.39766 .67418 Mdot
.23654 .48717 Mdot
.73718 .24419 Mdot
.58641 .65057 Mdot
.6142 .37471 Mdot
.72157 .48466 Mdot
.56364 .67844 Mdot
.64189 .209 Mdot
.33625 .50584 Mdot
.82331 .50459 Mdot
.43328 .51049 Mdot
.68089 .50688 Mdot
.32791 .29215 Mdot
.63693 .50642 Mdot
.55889 .46189 Mdot
.54653 .80977 Mdot
.62732 .28851 Mdot
.36906 .4485 Mdot
.5401 .37582 Mdot
.57531 .51884 Mdot
.78325 .67562 Mdot
.56034 .62094 Mdot
.34785 .66756 Mdot
.82414 .53136 Mdot
.32701 .54147 Mdot
.42247 .36241 Mdot
.6509 .57672 Mdot
.28223 .71343 Mdot
.66583 .32611 Mdot
.62494 .2246 Mdot
.54736 .59921 Mdot
.57085 .73267 Mdot
.82407 .5476 Mdot
.81759 .51222 Mdot
.21757 .35956 Mdot
.33446 .31527 Mdot
.71012 .42065 Mdot
.27551 .7134 Mdot
.36372 .3302 Mdot
.21567 .56839 Mdot
.21437 .55083 Mdot
.78348 .33129 Mdot
.49681 .57142 Mdot
.55246 .85433 Mdot
.74549 .55156 Mdot
.69358 .69388 Mdot
.47127 .1863 Mdot
.2406 .68414 Mdot
.77791 .60972 Mdot
.35015 .30588 Mdot
.49347 .32287 Mdot
.67548 .41755 Mdot
.19966 .44643 Mdot
.25289 .27307 Mdot
.65112 .57988 Mdot
.46533 .39933 Mdot
.6251 .7992 Mdot
.58411 .44334 Mdot
.41852 .17517 Mdot
.2856 .7044 Mdot
.55276 .18399 Mdot
.36051 .49923 Mdot
.62898 .40244 Mdot
.62813 .47599 Mdot
.76359 .38715 Mdot
.27571 .3932 Mdot
.78811 .44937 Mdot
.31792 .78335 Mdot
.65144 .76878 Mdot
.33409 .29084 Mdot
.78333 .55052 Mdot
.72897 .71471 Mdot
.38369 .77662 Mdot
.4907 .52985 Mdot
.68642 .66808 Mdot
.70351 .55087 Mdot
.56301 .83201 Mdot
.45255 .42434 Mdot
.41219 .55663 Mdot
.24277 .53936 Mdot
.43226 .75861 Mdot
.54699 .19747 Mdot
.63542 .42295 Mdot
.71292 .26895 Mdot
.7779 .66044 Mdot
.23787 .34066 Mdot
.31885 .25592 Mdot
.46136 .167 Mdot
.59632 .29521 Mdot
.46081 .77993 Mdot
.34963 .75454 Mdot
.23195 .69683 Mdot
.43037 .51281 Mdot
.74692 .63477 Mdot
.69437 .56408 Mdot
.82432 .54151 Mdot
.33119 .57936 Mdot
.31256 .43106 Mdot
.3289 .61432 Mdot
.79615 .44907 Mdot
.47436 .27976 Mdot
.79673 .61807 Mdot
.46907 .46537 Mdot
.61806 .15897 Mdot
.51147 .7955 Mdot
.45127 .47394 Mdot
.44547 .64741 Mdot
.50254 .7486 Mdot
.73767 .67542 Mdot
.5262 .78898 Mdot
.23088 .66084 Mdot
.42396 .65173 Mdot
.59349 .54614 Mdot
.49414 .36737 Mdot
.66082 .52183 Mdot
.54229 .81197 Mdot
.72101 .48545 Mdot
.81212 .59682 Mdot
.77165 .38728 Mdot
.7091 .26698 Mdot
.74775 .61206 Mdot
.47583 .84334 Mdot
.25807 .44595 Mdot
.60058 .56668 Mdot
.29173 .70735 Mdot
.6155 .72434 Mdot
.3587 .30404 Mdot
.30138 .17215 Mdot
.41073 .82255 Mdot
.48667 .77976 Mdot
.75878 .28847 Mdot
.50768 .81352 Mdot
.39399 .66195 Mdot
.39262 .25342 Mdot
.32368 .41183 Mdot
.70055 .28008 Mdot
.59306 .40952 Mdot
.51453 .15198 Mdot
.69402 .48639 Mdot
.71212 .21576 Mdot
.75872 .69869 Mdot
.45927 .38509 Mdot
.5442 .45496 Mdot
.5102 .65517 Mdot
.437 .54981 Mdot
.7258 .38466 Mdot
.44821 .28738 Mdot
.28093 .3308 Mdot
.39575 .6072 Mdot
.46117 .69685 Mdot
.5583 .67184 Mdot
.34202 .32076 Mdot
.67112 .70154 Mdot
.42839 .75274 Mdot
.51189 .61203 Mdot
.4121 .4842 Mdot
.73084 .45541 Mdot
.26093 .38172 Mdot
.55468 .32914 Mdot
.53392 .20414 Mdot
.2669 .55974 Mdot
.5035 .65885 Mdot
.55477 .32193 Mdot
.43564 .81575 Mdot
.62738 .78789 Mdot
.75237 .28334 Mdot
.57355 .56443 Mdot
.45897 .31213 Mdot
.75073 .42121 Mdot
.32945 .26087 Mdot
.38477 .28415 Mdot
.39865 .64274 Mdot
.25157 .33911 Mdot
.38658 .27005 Mdot
.25953 .64131 Mdot
.79741 .35433 Mdot
.26246 .69751 Mdot
.27369 .71317 Mdot
.52801 .6098 Mdot
.66606 .35179 Mdot
.44099 .40563 Mdot
.73688 .54023 Mdot
.41316 .45063 Mdot
.13815 .49618 Mdot
.52323 .39943 Mdot
.11582 .46428 Mdot
.36213 .56906 Mdot
.3757 .24199 Mdot
.70452 .55967 Mdot
.48443 .507 Mdot
.46769 .44872 Mdot
.49523 .79361 Mdot
.30914 .41507 Mdot
.43114 .78709 Mdot
.32319 .28157 Mdot
.45527 .69659 Mdot
.33952 .80427 Mdot
.48897 .85068 Mdot
.51131 .31566 Mdot
.55211 .39693 Mdot
.43351 .82925 Mdot
.44238 .68164 Mdot
.55926 .21013 Mdot
.66958 .78829 Mdot
.60395 .78365 Mdot
.48278 .38759 Mdot
.69564 .49731 Mdot
.7515 .63098 Mdot
.83334 .47586 Mdot
.24099 .30395 Mdot
.7012 .70753 Mdot
.33281 .5798 Mdot
.47332 .47885 Mdot
.77275 .64411 Mdot
.29472 .34636 Mdot
.31157 .57211 Mdot
.27684 .34226 Mdot
.11699 .53558 Mdot
.78659 .55974 Mdot
.78757 .45846 Mdot
.29163 .32868 Mdot
.40432 .33234 Mdot
.29441 .38956 Mdot
.2643 .35969 Mdot
.57813 .79 Mdot
.39984 .79998 Mdot
.26597 .3657 Mdot
.18202 .63805 Mdot
.65766 .49341 Mdot
.44523 .72257 Mdot
.4648 .38153 Mdot
.69664 .35096 Mdot
.34496 .49473 Mdot
.73281 .30923 Mdot
.66175 .77021 Mdot
.36173 .58172 Mdot
.56122 .81094 Mdot
.30455 .69785 Mdot
.57992 .33308 Mdot
.65445 .3217 Mdot
.6444 .76393 Mdot
.47147 .29669 Mdot
.19715 .42098 Mdot
.62499 .24046 Mdot
.43116 .64472 Mdot
.69088 .75483 Mdot
.48508 .63958 Mdot
.54225 .50876 Mdot
.32809 .4073 Mdot
.68718 .62574 Mdot
.54031 .17565 Mdot
.59938 .61194 Mdot
.37506 .397 Mdot
.25093 .28079 Mdot
.38695 .32997 Mdot
.5383 .15881 Mdot
.49408 .20931 Mdot
.26932 .31917 Mdot
.55989 .70847 Mdot
.54076 .73805 Mdot
.14047 .5784 Mdot
.30488 .57882 Mdot
.54589 .62957 Mdot
.198 .49068 Mdot
.39353 .39879 Mdot
.60039 .66461 Mdot
.4581 .62923 Mdot
.40778 .50506 Mdot
.25993 .60502 Mdot
.67354 .47122 Mdot
.35958 .40459 Mdot
.40849 .49496 Mdot
.72499 .32838 Mdot
.79543 .38126 Mdot
.46368 .68809 Mdot
.13335 .44273 Mdot
.54945 .45807 Mdot
.53336 .30273 Mdot
.80832 .63593 Mdot
.19697 .34166 Mdot
.52117 .7052 Mdot
.50501 .85905 Mdot
.64659 .40139 Mdot
.66233 .73714 Mdot
.39404 .35504 Mdot
.26522 .69618 Mdot
.62746 .59599 Mdot
.71248 .50001 Mdot
.37074 .5603 Mdot
.49233 .19405 Mdot
.50744 .72085 Mdot
.34536 .33354 Mdot
.63211 .75397 Mdot
.70639 .37079 Mdot
.38533 .49095 Mdot
.53711 .71216 Mdot
.51396 .31923 Mdot
.66337 .3295 Mdot
.32958 .37215 Mdot
.79117 .47685 Mdot
.28402 .73396 Mdot
.74316 .24588 Mdot
.44872 .38119 Mdot
.51729 .50458 Mdot
.22958 .55547 Mdot
.58958 .80129 Mdot
.20972 .44908 Mdot
.81789 .61667 Mdot
.72349 .44197 Mdot
.68787 .39522 Mdot
.73708 .43405 Mdot
.65941 .47625 Mdot
.46168 .512 Mdot
.37374 .69267 Mdot
.29133 .29474 Mdot
.24383 .40213 Mdot
.41276 .23905 Mdot
.20548 .41976 Mdot
.78221 .46668 Mdot
.27101 .32272 Mdot
.46959 .61023 Mdot
.60927 .32505 Mdot
.37994 .57698 Mdot
.80123 .38493 Mdot
.81526 .6226 Mdot
.3567 .59417 Mdot
.59019 .66962 Mdot
.60781 .81968 Mdot
.59263 .49764 Mdot
.54782 .54741 Mdot
.58382 .47586 Mdot
.62928 .53152 Mdot
.17456 .37562 Mdot
.5868 .7933 Mdot
.60726 .36542 Mdot
.81434 .48463 Mdot
.8103 .45438 Mdot
.65767 .17758 Mdot
.19738 .62447 Mdot
.37727 .38239 Mdot
.61309 .17217 Mdot
.27725 .33237 Mdot
.83639 .48912 Mdot
.41164 .70276 Mdot
.82888 .63356 Mdot
.49324 .3185 Mdot
.58432 .81396 Mdot
.38075 .25938 Mdot
.32065 .41799 Mdot
.42719 .77116 Mdot
.53053 .54524 Mdot
.3286 .64397 Mdot
.48098 .80558 Mdot
.29729 .78695 Mdot
.67016 .42713 Mdot
.34246 .73625 Mdot
.2625 .52615 Mdot
.70328 .74717 Mdot
.52208 .77898 Mdot
.54426 .41576 Mdot
.31414 .60996 Mdot
.53157 .18439 Mdot
.73568 .45645 Mdot
.56216 .53185 Mdot
.5117 .77678 Mdot
.6757 .2722 Mdot
.74263 .40923 Mdot
.26666 .70774 Mdot
.50608 .32162 Mdot
.44012 .53736 Mdot
.64325 .40414 Mdot
.34057 .38246 Mdot
.59746 .62735 Mdot
.52982 .55252 Mdot
.55625 .43917 Mdot
.52044 .64124 Mdot
.37985 .48213 Mdot
.5028 .16396 Mdot
.24253 .4326 Mdot
.32292 .74393 Mdot
.39686 .41548 Mdot
.28419 .49826 Mdot
.20929 .46939 Mdot
.4337 .18433 Mdot
.58331 .76188 Mdot
.74455 .4621 Mdot
.79882 .5632 Mdot
.77782 .39098 Mdot
.37001 .42207 Mdot
.70534 .22938 Mdot
.32303 .5154 Mdot
.56127 .33802 Mdot
.30563 .47163 Mdot
.56133 .64666 Mdot
.57106 .36168 Mdot
.58384 .81335 Mdot
.55005 .61378 Mdot
.77341 .55411 Mdot
.44445 .79183 Mdot
.69271 .4597 Mdot
.5049 .35013 Mdot
.82031 .49792 Mdot
.516 .65302 Mdot
.31436 .75256 Mdot
.39126 .51025 Mdot
.51786 .77089 Mdot
.78841 .3986 Mdot
.76608 .30078 Mdot
.44787 .45424 Mdot
.70217 .53752 Mdot
.61329 .44961 Mdot
.25582 .70666 Mdot
.57994 .79806 Mdot
.50531 .39982 Mdot
.32057 .66659 Mdot
.41806 .35509 Mdot
.35712 .70612 Mdot
.45159 .53857 Mdot
.69581 .28424 Mdot
.42231 .39699 Mdot
.25872 .32554 Mdot
.62744 .65052 Mdot
.4961 .48593 Mdot
.5872 .3503 Mdot
.71189 .52538 Mdot
.15914 .56436 Mdot
.54633 .36838 Mdot
.70553 .71082 Mdot
.52973 .32406 Mdot
.2598 .67585 Mdot
.64165 .76179 Mdot
.39017 .63309 Mdot
.30917 .41261 Mdot
.63042 .32316 Mdot
.26301 .57599 Mdot
.62081 .46757 Mdot
.43756 .62338 Mdot
.34722 .33735 Mdot
.68929 .76211 Mdot
.61486 .29605 Mdot
.73081 .53582 Mdot
.48052 .58399 Mdot
.57187 .53139 Mdot
.39095 .53999 Mdot
.82418 .63306 Mdot
.30901 .40611 Mdot
.71754 .45993 Mdot
.49789 .57116 Mdot
.70784 .55512 Mdot
.47782 .21841 Mdot
.80183 .33813 Mdot
.38131 .25641 Mdot
.41624 .47193 Mdot
.36801 .24708 Mdot
.47398 .77999 Mdot
.65263 .80374 Mdot
.73407 .42454 Mdot
.4807 .45742 Mdot
.6099 .58058 Mdot
.2211 .51389 Mdot
.45352 .58868 Mdot
.57228 .54151 Mdot
.41277 .51294 Mdot
.2876 .63963 Mdot
.30005 .50488 Mdot
.51981 .38062 Mdot
.76044 .59781 Mdot
.80735 .53806 Mdot
.24842 .65935 Mdot
.39709 .5911 Mdot
.45061 .73751 Mdot
.70158 .3006 Mdot
.83332 .63934 Mdot
.29642 .24476 Mdot
.61084 .45099 Mdot
.39212 .57333 Mdot
.69044 .53291 Mdot
.49068 .62391 Mdot
.25035 .38092 Mdot
.2165 .46625 Mdot
.34217 .57717 Mdot
.61001 .5541 Mdot
.77982 .51983 Mdot
.44321 .76116 Mdot
.65432 .53739 Mdot
.3322 .60802 Mdot
.48421 .16335 Mdot
.47033 .82592 Mdot
.59352 .79851 Mdot
.87384 .56137 Mdot
.40282 .54337 Mdot
.57378 .51254 Mdot
.48092 .25005 Mdot
.79427 .39529 Mdot
.72674 .48613 Mdot
.60106 .21972 Mdot
.36587 .63061 Mdot
.73099 .42555 Mdot
.37483 .30384 Mdot
.77027 .57524 Mdot
.35003 .70248 Mdot
.45932 .49592 Mdot
.54244 .74165 Mdot
.71733 .23233 Mdot
.4827 .36683 Mdot
.80181 .57302 Mdot
.4969 .18151 Mdot
.22005 .68677 Mdot
.80387 .40608 Mdot
.75457 .56832 Mdot
.56303 .77511 Mdot
.45052 .26101 Mdot
.46173 .41401 Mdot
.32418 .31147 Mdot
.56612 .21216 Mdot
.6645 .31527 Mdot
.60232 .69184 Mdot
.4292 .22026 Mdot
.7464 .42514 Mdot
.67512 .31313 Mdot
.47892 .45291 Mdot
.56716 .32361 Mdot
.58418 .66785 Mdot
.28772 .34002 Mdot
.43422 .42769 Mdot
.74405 .51085 Mdot
.54315 .32157 Mdot
.23477 .56979 Mdot
.50134 .80642 Mdot
.20993 .69013 Mdot
.64139 .72508 Mdot
.42503 .19271 Mdot
.58693 .38038 Mdot
.66041 .1643 Mdot
.44399 .77619 Mdot
.46736 .76048 Mdot
.41307 .79376 Mdot
.41191 .66612 Mdot
.60323 .51457 Mdot
.62144 .46709 Mdot
.73155 .67891 Mdot
.48131 .38618 Mdot
.56852 .23042 Mdot
.47238 .19322 Mdot
.70502 .49655 Mdot
.75961 .46702 Mdot
.74039 .54632 Mdot
.6779 .3852 Mdot
.39885 .33782 Mdot
.56727 .15401 Mdot
.42807 .45832 Mdot
.50463 .40666 Mdot
.61298 .3436 Mdot
.4411 .24989 Mdot
.56832 .86063 Mdot
.4541 .37998 Mdot
.77275 .43466 Mdot
.49087 .3439 Mdot
.38298 .43035 Mdot
.21171 .42848 Mdot
.91556 .46285 Mdot
.70453 .18344 Mdot
.34174 .34389 Mdot
.19731 .59292 Mdot
.48947 .34969 Mdot
.79258 .45348 Mdot
.5633 .75986 Mdot
.29718 .65783 Mdot
.51466 .37424 Mdot
.36331 .43494 Mdot
.60938 .35342 Mdot
.41328 .7788 Mdot
.80746 .38103 Mdot
.44798 .20037 Mdot
.81461 .48758 Mdot
.65904 .48099 Mdot
.58622 .35359 Mdot
.86607 .60888 Mdot
.77958 .63373 Mdot
.54904 .47058 Mdot
.35527 .26528 Mdot
.51386 .4151 Mdot
.61327 .40654 Mdot
.68913 .68186 Mdot
.33914 .80296 Mdot
.75056 .41776 Mdot
.79588 .4496 Mdot
.39719 .40448 Mdot
.42582 .69271 Mdot
.36337 .56851 Mdot
.45458 .45104 Mdot
.53887 .46162 Mdot
.32694 .55847 Mdot
.69725 .46497 Mdot
.61524 .80923 Mdot
.44696 .58081 Mdot
.32507 .77864 Mdot
.85164 .55971 Mdot
.60234 .3003 Mdot
.22326 .5051 Mdot
.60463 .49434 Mdot
.69058 .33997 Mdot
.71197 .3374 Mdot
.60973 .53342 Mdot
.53674 .8246 Mdot
.40256 .11916 Mdot
.30383 .61639 Mdot
.71623 .29467 Mdot
.38967 .32143 Mdot
.42512 .52885 Mdot
.51687 .35238 Mdot
.41348 .69256 Mdot
.45257 .67919 Mdot
.6719 .46367 Mdot
.43554 .39199 Mdot
.36467 .49773 Mdot
.13896 .40929 Mdot
.55624 .39092 Mdot
.23116 .40623 Mdot
.83407 .49688 Mdot
.62393 .23949 Mdot
.50604 .2912 Mdot
.64275 .45041 Mdot
.25848 .48644 Mdot
.48226 .46152 Mdot
.69297 .73797 Mdot
.71668 .27725 Mdot
.80316 .52526 Mdot
.62037 .29667 Mdot
.50124 .35031 Mdot
.63757 .39875 Mdot
.65932 .61065 Mdot
.29898 .53399 Mdot
.71103 .68416 Mdot
.51996 .43772 Mdot
.83044 .44644 Mdot
.49138 .73363 Mdot
.54587 .5725 Mdot
.44549 .35306 Mdot
.64912 .17637 Mdot
.45242 .23266 Mdot
.42159 .41767 Mdot
.44542 .17811 Mdot
.54732 .68004 Mdot
.65904 .52638 Mdot
.51195 .65637 Mdot
.54141 .48038 Mdot
.40691 .40792 Mdot
.43133 .16691 Mdot
.70772 .67064 Mdot
.33025 .63836 Mdot
.34086 .67319 Mdot
.223 .62072 Mdot
.38279 .49013 Mdot
.87546 .54178 Mdot
.52899 .72371 Mdot
.45053 .16609 Mdot
.29156 .73939 Mdot
.41252 .40902 Mdot
.51753 .80794 Mdot
.52885 .3934 Mdot
.46879 .68502 Mdot
.80906 .49645 Mdot
.51869 .47597 Mdot
.63519 .22184 Mdot
.65633 .42397 Mdot
.58574 .19061 Mdot
.61515 .57389 Mdot
.60542 .67231 Mdot
.47493 .775 Mdot
.44512 .24585 Mdot
.75911 .71677 Mdot
.22018 .51925 Mdot
.79096 .67461 Mdot
.73973 .73317 Mdot
.82507 .49655 Mdot
.59737 .20922 Mdot
.2193 .32954 Mdot
.48523 .77411 Mdot
.6355 .77154 Mdot
.39394 .71206 Mdot
.42547 .25847 Mdot
.49958 .75137 Mdot
.44845 .35075 Mdot
.2753 .39649 Mdot
.37489 .59015 Mdot
.15185 .32386 Mdot
.76567 .49567 Mdot
.44112 .39359 Mdot
.51666 .74127 Mdot
.82021 .45988 Mdot
.45257 .25444 Mdot
.47207 .80488 Mdot
.45467 .53386 Mdot
.66226 .40851 Mdot
.65173 .31283 Mdot
.23859 .6508 Mdot
.50496 .73374 Mdot
.15771 .63475 Mdot
.44491 .81509 Mdot
.3104 .64366 Mdot
.45186 .50849 Mdot
.345 .36276 Mdot
.19316 .44987 Mdot
.55056 .73037 Mdot
.52137 .82509 Mdot
.59695 .81315 Mdot
.77513 .64116 Mdot
.14076 .57515 Mdot
.26614 .69114 Mdot
.79493 .38693 Mdot
.53723 .8035 Mdot
.3434 .33221 Mdot
.74423 .581 Mdot
.43381 .66147 Mdot
.35696 .65943 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Dooooo`;o0000/oooool001cooooo00?o
0000ooooooooool0U?ooool2o`000;?ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0__ooool2o`0008Wooooo000Looooo`03o`000?oooooo
oooo0;kooooo0_l00029ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0Ooooool2o`000<Sooooo
000Looooo`03o`000?oooooooooo07oooooo0_l0000Mooooo`;o0000ZOooool001cooooo00?o0000
ooooooooool0W_ooool2o`000:Wooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2/ooooo`;o0000
Voooool001cooooo00?o0000ooooooooool0T?ooool2o`0001[ooooo0_l0000:ooooo`;o0000Sooo
ool001cooooo00?o0000ooooooooool0T?ooool2o`0001Oooooo0_l0000=ooooo`;o0000Soooool0
01cooooo00?o0000ooooooooool0ZOooool2o`0009kooooo000Looooo`03o`000?oooooooooo0;Go
oooo0_l00003ooooo`;o0000SOooool001cooooo00?o0000ooooooooool0]Oooool2o`0000?ooooo
0_l0002=ooooo`007?ooool2o`000:Cooooo0_l0000<ooooo`;o0000U_ooool001cooooo00?o0000
ooooooooool0Soooool2o`0000kooooo0_l00002ooooo`;o00003?ooool2o`000003ooooool0003o
000009?ooooo000Looooo`03o`000?oooooooooo07cooooo0ol0000@ooooo`;o00003_ooool2o`00
00Kooooo0_l00002ooooo`;o00001oooool2o`0000gooooo1?l00022ooooo`007?ooool00ol0003o
ooooooooo`1looooo`?o00006?ooool2o`0000kooooo0_l00002ooooo`;o00005_ooool4o`0008;o
oooo000Looooo`03o`000?oooooooooo08oooooo0_l00006ooooo`;o000000?oooooo`000?l00000
1?ooool2o`00023ooooo0_l0000?ooooo`;o0000M?ooool001cooooo00?o0000ooooooooool0R?oo
ool2o`0000Gooooo0_l000000ooooooo0000o`000006ooooo`;o00001?ooool2o`00023ooooo0_l0
000?ooooo`;o0000M?ooool001cooooo00?o0000ooooooooool0G_ooool2o`0002Sooooo0_l00005
ooooo`;o000000?oooooo`000?l000007_ooool2o`0000oooooo0_l00006ooooo`;o0000O?ooool0
01cooooo00?o0000ooooooooool0G_ooool2o`0002Cooooo0_l00009ooooo`;o00002?ooool2o`00
00gooooo0_l00008ooooo`;o00003oooool2o`0000Kooooo0_l0001looooo`007?ooool00ol0003o
ooooooooo`24ooooo`;o00001oooool2o`0000Gooooo0_l00002ooooo`?o00000oooool2o`0000Go
oooo1Ol00002ooooo`;o00008Oooool2o`000003ooooool0003o000007Gooooo000Looooo`03o`00
0?oooooooooo08cooooo0ol00005ooooo`;o00000_ooool2o`0000Cooooo0_l00005ooooo`?o0000
00Coooooo`000?l0003ooooo0_l0000Booooo`;o00003Oooool2o`000003ooooool0003o000007Go
oooo000Looooo`03o`000?oooooooooo07oooooo0ol00007ooooo`;o000000Coooooo`000?l0003o
00003oooool2o`0000Wooooo0_l00005ooooo`;o00003_ooool2o`0001oooooo0_l0001Vooooo`00
7?ooool00ol0003oooooooooo`1_ooooo`;o00003_ooool3o`0000Oooooo0_l000001?oooooo0000
o`000?l00006ooooo`?o00002?ooool2o`0000?ooooo0_l00002ooooo`;o00001Oooool2o`0000;o
oooo0_l0000<ooooo`;o00007Oooool2o`0006Kooooo000Looooo`03o`000?oooooooooo06oooooo
0_l0000?ooooo`;o00004oooool3o`0000Sooooo0_l00003ooooo`;o00003Oooool2o`0000Cooooo
0_l000000ooooooo0000o`000003ooooo`;o0000QOooool00006ooooooo^k^ko<S8bo`000?lb<S;o
k^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo083ooooo0_l00004ooooo`;o
00002Oooool2o`0000?ooooo0_l0000Rooooo`;o000000?oooooo`000?l000001?ooool2o`00017o
oooo0_l0001aooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnH
V9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0Q_ooool2o`0000Wooooo0_l00003
ooooo`;o00001?ooool4o`00013ooooo0_l000000ooooooo0000o`00000>ooooo`;o00000_ooool2
o`0000Wooooo0_l00002ooooo`;o0000LOooool00003ooooool@413ooooo00;ooooo00?o410@oooo
ooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo06Sooooo0_l0000boooo
o`Co00003Oooool5o`000003ooooool0003o000001;ooooo0_l00009ooooo`;o00002_ooool2o`00
06Wooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^
k^h01_ooool3o`0006Sooooo0_l0000Nooooo`;o00001?ooool2o`0001cooooo1?l0000:ooooo`;o
00000oooool2o`000003ooooool0003o000000?ooooo0_l0000Eooooo`;o0000JOooool00003oooo
ool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`00
0?oooooooooo08Oooooo0ol00004ooooo`;o00002_ooool2o`0000cooooo1ol00003ooooo`;o0000
1_ooool4o`000004ooooool0003o0000ooooo`;o00000oooool2o`00083ooooo00000ooooooo410@
ooooo`02ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`27ooooo`Co00003oooool2o`0000[ooooo1_l00006ooooo`;o00002?ooool6o`0000_ooooo
0_l0000@ooooo`;o0000J?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o
^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0Goooool2o`000003ooooool0003o0000
02Gooooo0_l0000?ooooo`Go00001oooool4o`0000Sooooo1?l00004ooooo`;o00000_ooool4o`00
00_ooooo0_l0000@ooooo`;o0000J?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0D?ooool2o`0000gooooo0_l0
00000ooooooo0000o`00000Pooooo`;o00005Oooool4o`0000gooooo0_l00004ooooo`Co00001?oo
ool2o`0000oooooo0_l00005ooooo`;o0000MOooool001cooooo00?o0000ooooooooool0D?ooool2
o`0003;ooooo0_l0000Aooooo`;o00004oooool2o`0000Oooooo1?l0000:ooooo`;o00001?ooool4
o`0000?ooooo1?l00003ooooo`;o00002oooool2o`0006?ooooo000Looooo`03o`000?oooooooooo
08?ooooo0ol00002ooooo`;o00003Oooool2o`0000kooooo1?l0000:ooooo`Co00001_ooool2o`00
00;ooooo0_l00004ooooo`;o00001Oooool2o`0000Gooooo0_l0000;ooooo`?o00000_ooool2o`00
05kooooo000Looooo`03o`000?oooooooooo08?ooooo0ol00002ooooo`;o00006?ooool2o`0000?o
oooo1_l00006ooooo`;o00001oooool2o`000003ooooool0003o000000Kooooo0_l00002ooooo`;o
00001_ooool2o`00013ooooo0_l00002ooooo`;o0000G_ooool001cooooo00?o0000ooooooooool0
M?ooool3o`0001cooooo0_l0000=ooooo`;o00001Oooool4o`0000Kooooo0_l00003ooooo`;o0000
0_ooool2o`0000;ooooo0_l00005ooooo`Ko00001_ooool2o`0007Cooooo000Looooo`03o`000?oo
oooooooo05Sooooo0_l00005ooooo`;o00002oooool2o`0000Kooooo0ol0000Booooo`;o00002?oo
ool2o`00023ooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l00004ooooo`So0000
0_ooool2o`0000?ooooo0_l0000:ooooo`;o0000I_ooool001cooooo00?o0000ooooooooool0F?oo
ool2o`0000Gooooo0_l0000;ooooo`?o00004Oooool2o`0000Oooooo0_l00003ooooo`?o00002ooo
ool2o`000003ooooool0003o000001Cooooo0_l00004ooooo`;o00000oooool2o`0000Cooooo0_l0
0004ooooo`;o00000_ooool2o`0000?ooooo0_l0000:ooooo`;o00000_ooool2o`0006;ooooo000L
ooooo`03o`000?oooooooooo06gooooo0_l00002ooooo`Co00002?ooool2o`000003ooooool0003o
000000cooooo0ol00004ooooo`;o00001Oooool2o`000003ooooool0003o000001Cooooo0_l00002
ooooo`Co00000oooool2o`0000;ooooo0_l00006ooooo`;o00002Oooool2o`0000cooooo0_l0001R
ooooo`007?ooool00ol0003oooooooooo`1aooooo`Co00002?ooool2o`0000?ooooo0_l00002oooo
o`;o00001oooool2o`0000Cooooo1?l00003ooooo`;o00005oooool2o`0000;ooooo0_l00006oooo
o`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o000000?oooooo`000?l000001_ooool2
o`0000_ooooo0_l00002ooooo`;o0000Goooool001cooooo00?o0000ooooooooool0M_ooool2o`00
00[ooooo0_l00002ooooo`?o00002Oooool2o`0000?ooooo0_l00003ooooo`;o00008oooool2o`00
00Cooooo0_l00006ooooo`;o00000_ooool2o`000003ooooool0003o000000Wooooo0_l000000ooo
oooo0000o`000002ooooo`;o0000Goooool001cooooo00?o0000ooooooooool0GOooool2o`0000_o
oooo0_l00004ooooo`;o00001?ooool2o`0000[ooooo0_l00003ooooo`;o00001?ooool2o`0000?o
oooo0_l00008ooooo`;o00001?ooool2o`0000Gooooo0_l0000Looooo`;o00002_ooool2o`000003
ooooool0003o000000;ooooo0_l00005ooooo`;o00002Oooool4o`0005Wooooo000Looooo`03o`00
0?oooooooooo05gooooo0_l0000;ooooo`;o00001?ooool6o`0000Cooooo1?l00004ooooo`;o0000
00Coooooo`000?l0003ooooo0_l00003ooooo`;o00000oooool2o`0000kooooo0_l00005ooooo`;o
00006?ooool2o`000003ooooool0003o000000_ooooo0ol00004ooooo`Ko00003?ooool4o`0005Wo
oooo000Looooo`;o0000A_ooool2o`0001kooooo0_l00009ooooo`Ko00001?ooool4o`0000Oooooo
0_l000000ooooooo0000o`000002ooooo`Co00000_ooool2o`0000Cooooo0_l0000Yooooo`;o0000
00?oooooo`000?l000001?ooool2o`0000Kooooo0_l00006ooooo`Co00003Oooool2o`0005[ooooo
000Looooo`03o`000?oooooooooo04Gooooo0ol00009ooooo`;o00000_ooool2o`0000kooooo0_l0
0009ooooo`;o00002_ooool4o`0000;ooooo0ol00007ooooo`Go00001oooool2o`0000cooooo1?l0
000Rooooo`?o00004Oooool3o`0000Oooooo0_l000000ooooooo0000o`00001Jooooo`007?ooool0
0ol0003oooooooooo`16ooooo`;o00001?ooool2o`0000?ooooo0_l00002ooooo`;o00002oooool5
o`0000Kooooo0_l00009ooooo`;o00000_ooool4o`0000;ooooo0ol000001?oooooo0000o`000?oo
ool2o`0000Cooooo0_l00002ooooo`;o00004Oooool4o`0002?ooooo0_l0000?ooooo`Go00001ooo
ool2o`0005gooooo000Looooo`03o`000?oooooooooo04cooooo0_l0000Aooooo`;o000000?ooooo
o`000?l000000_l000001?oooooo0000o`000?l00003ooooo`?o00002?ooool2o`0000Wooooo1Ol0
00000ooooooo0000o`000002ooooo`So0000A_ooool2o`000003ooooool0003o000000_ooooo0_l0
0007ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0F?ooool2o`0000Gooooo0_l00006
ooooo`?o00001?ooool2o`0000Oooooo0ol0000:ooooo`;o00001oooool6o`0003Gooooo1?l0000?
ooooo`;o00003_ooool2o`0000Oooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`1Hoooo
o`;o000000?oooooo`000?l000004oooool2o`0000Gooooo0_l0000Hooooo`;o00004?ooool2o`00
0003ooooool0003o0000023ooooo1?l00009ooooo`;o00003?ooool2o`0006Cooooo000Looooo`03
o`000?oooooooooo05_ooooo0_l0000;ooooo`;o00001_ooool2o`000003ooooool0003o000000Go
oooo0_l0000Jooooo`;o00002oooool2o`000003ooooool0003o000002gooooo0_l00006ooooo`;o
00001?ooool3o`00013ooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o0000
6?ooool3o`0000Sooooo0_l00005ooooo`;o00006_ooool2o`0001;ooooo0_l0000Zooooo`Co0000
0oooool2o`0000Gooooo0_l0000<ooooo`;o00000_ooool2o`00057ooooo000Looooo`03o`000?oo
oooooooo04kooooo0_l0000Iooooo`;o0000>?ooool2o`000003ooooool0003o000000;ooooo0_l0
000Qooooo`;o00001oooool4o`0000Sooooo1?l0000<ooooo`;o0000EOooool001cooooo00?o0000
ooooooooool0FOooool2o`0000Cooooo0_l0000?ooooo`;o00009?ooool2o`0000Wooooo1?l00000
0ooooooo0000o`00000Uooooo`Co00000oooool2o`0000[ooooo1ol0001Rooooo`007?ooool00ol0
003oooooooooo`1>ooooo`;o00002Oooool2o`0000Cooooo0_l00004ooooo`;o00002Oooool2o`00
00Wooooo0_l00003ooooo`Co00004_ooool2o`0000Wooooo0_l000000ooooooo0000o`000003oooo
o`;o00009?ooool2o`0000?ooooo0_l0000:ooooo`;o00000oooool2o`0006;ooooo000Looooo`03
o`000?oooooooooo04gooooo0ol0000Eooooo`;o00003Oooool2o`0000?ooooo1?l00003ooooo`Co
00004_ooool2o`0000;ooooo0_l00008ooooo`;o00000oooool2o`0003?ooooo0_l00009ooooo`;o
00001Oooool4o`0005Gooooo000Looooo`03o`000?oooooooooo04gooooo0_l00005ooooo`;o0000
2oooool2o`00017ooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l0000=ooooo`?o
00001Oooool2o`0000;ooooo0_l00009ooooo`?o000000?oooooo`000?l000004Oooool2o`0000[o
oooo0_l00007ooooo`;o00001?ooool2o`0000Gooooo0_l00004ooooo`;o00000oooool2o`000003
ooooool0003o000000;ooooo1Ol0001Dooooo`007?ooool00ol0003oooooooooo`0iooooo`;o0000
6?ooool3o`000003ooooool0003o000000Sooooo0_l00004ooooo`Ko00003oooool2o`000003oooo
ool0003o000000gooooo0ol0000@ooooo`;o00000_ooool3o`0000?ooooo0_l0000?ooooo`;o0000
2_ooool2o`0000Oooooo0ol00003ooooo`;o00002oooool2o`0000?ooooo0_l000000ooooooo0000
o`000002ooooo`Go0000E?ooool001cooooo00?o0000ooooooooool0>Oooool2o`000003ooooool0
003o000000;ooooo0_l0000Aooooo`;o00000_ooool2o`0000;ooooo0_l0000:ooooo`Ko00000_oo
ool2o`00033ooooo0_l00008ooooo`;o00003?ooool2o`0000;ooooo0ol00007ooooo`;o00002Ooo
ool3o`0000cooooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo1Ol0001Fooooo`007?ooool0
0ol0003oooooooooo`0looooo`;o00000_ooool2o`0001Gooooo0_l00002ooooo`;o00003oooool2
o`000003ooooool0003o000001kooooo0_l000001?oooooo0000o`000?ooool2o`0001Cooooo0_l0
000<ooooo`;o00000_ooool3o`0000Cooooo1Ol0000:ooooo`;o00000oooool2o`000003ooooool0
003o000000Cooooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`00
001Fooooo`007?ooool2o`0005cooooo0_l000000ooooooo0000o`00000;ooooo`?o00008Oooool2
o`000004ooooool0003o0000ooooo`;o00005?ooool2o`0001?ooooo0_l00002ooooo`Go00003ooo
ool2o`000003ooooool0003o000000?ooooo0_l00007ooooo`;o00000oooool2o`000003ooooool0
003o000000;ooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`1;ooooo`;o00004Oooool2
o`0000_ooooo0_l00004ooooo`?o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000004
ooooo`;o00000_ooool2o`000003ooooool0003o000001gooooo0_l0000Eooooo`;o00007_ooool2
o`0000Gooooo1?l00003ooooo`;o00001Oooool2o`0005;ooooo000Looooo`03o`000?oooooooooo
04Oooooo0_l00002ooooo`;o00005oooool2o`0000;ooooo0_l00004ooooo`;o000000Coooooo`00
0?l0003o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`;o00000_ooool2
o`000003ooooool0003o000000cooooo0_l0000;ooooo`;o00000_ooool2o`0000Gooooo0_l0000c
ooooo`Co00001_ooool3o`0005Oooooo000Looooo`03o`000?oooooooooo04Oooooo0_l0000Koooo
o`;o00000_ooool2o`0000Cooooo0ol0000;ooooo`;o00001_ooool2o`0001;ooooo0ol000000ooo
oooo0000o`000007ooooo`?o00000_ooool2o`0000Cooooo0_l0000Booooo`;o00000_ooool2o`00
01Oooooo0_l00002ooooo`;o00000oooool;o`0000?ooooo0_l0001?ooooo`007?ooool00ol0003o
ooooooooo`14ooooo`;o00008?ooool2o`0000Cooooo1_l0000:ooooo`;o00001_ooool2o`0000_o
oooo1?l00004ooooo`;o000000?oooooo`000?l000002?ooool2o`0000;ooooo0_l0000Cooooo`;o
00000oooool2o`0000;ooooo0ol00005ooooo`;o00001_ooool2o`0000;ooooo0_l00003ooooo`;o
00001oooool5o`0000;ooooo1?l00003ooooo`;o0000Coooool001cooooo00?o0000ooooooooool0
A?ooool2o`0001Kooooo0_l00002ooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`?o
000000?oooooo`000?l000007oooool4o`0000gooooo0_l0000Kooooo`;o00002?ooool2o`0000Go
oooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`Co00002?ooool2o`0000;o
oooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00003oooool4o`0000Cooooo
0_l000001?oooooo0000o`000?l00007ooooo`;o000000Coooooo`000?l0003ooooo0ol00002oooo
o`;o00002oooool2o`0001Wooooo0_l00004ooooo`?o00001Oooool2o`0001;ooooo0_l00009oooo
o`;o00002Oooool2o`0000gooooo0_l0000<ooooo`;o00003Oooool2o`0004Oooooo000Looooo`03
o`000?oooooooooo04?ooooo0_l0000?ooooo`Co00001oooool2o`0000?ooooo0_l00004ooooo`So
000000?oooooo`000?l000001Ol000001?oooooo0000o`000?ooool2o`000003ooooool0003o0000
00Kooooo0_l0000Aooooo`?o00000_ooool4o`0000Gooooo0_l000001?oooooo0000o`000?ooool2
o`0000cooooo0_l00009ooooo`;o00001_ooool5o`0000gooooo0_l0000Kooooo`;o0000Aoooool0
01cooooo00?o0000ooooooooool0;_ooool2o`0001Oooooo0_l00007ooooo`;o00000_ooool2o`00
00Sooooo0_l00004ooooo`;o00001?ooool6o`000003ooooool0003o000000go00002Oooool2o`00
01;ooooo0_l00002ooooo`;o00001Oooool4o`000004ooooool0003o0000ooooo`;o00000_ooool2
o`0000cooooo0_l00004ooooo`?o00001_ooool5o`0000Sooooo0_l00003ooooo`;o0000I?ooool0
01cooooo00?o0000ooooooooool0;_ooool2o`0000cooooo0_l00009ooooo`;o00001oooool2o`00
00Wooooo0_l000000ooooooo0000o`000005ooooo`;o00001?ooool2o`000004ooooool0003o0000
ooooo`oo0000:?ooool4o`0000Cooooo0_l00002ooooo`;o00003?ooool2o`0000Cooooo0_l0000:
ooooo`;o00002?ooool2o`0000Sooooo0_l00007ooooo`;o0000E_ooool001cooooo00?o0000oooo
ooooool0=oooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`00013ooooo1?l000000ooo
oooo0000o`000008ooooo`;o00001?ooool5o`000003ooooool0003o000001;o000000?oooooo`00
0?l000002_ooool2o`0000kooooo0_l00005ooooo`;o00000_ooool2o`000003ooooool0003o0000
00_ooooo0_l0000Eooooo`;o00004_ooool2o`0000Oooooo0_l000000ooooooo0000o`000005oooo
o`;o0000C?ooool001cooooo00?o0000ooooooooool0=oooool2o`0000Oooooo0_l00002ooooo`;o
00002?ooool2o`0000Cooooo1_l0000Aoooooa?o000000?oooooo`000?l000001?l000000ooooooo
0000o`000002o`0000Sooooo0_l0000>ooooo`;o00002Oooool2o`000004ooooool0003o0000o`00
00Kooooo0_l00002ooooo`;o00005Oooool2o`0000Kooooo0_l0000@ooooo`;o000000Coooooo`00
0?l0003ooooo0_l00005ooooo`Co00000_ooool2o`0004Kooooo000Looooo`03o`000?oooooooooo
03gooooo0_l0000?ooooo`;o00001?ooool2o`0000?ooooo0_l0000>oooooaCo000000?oooooo`00
0?l000000_l000000ooooooo0000o`000003ooooo`;o00000oooool2o`00027ooooo1ol00002oooo
o`;o00003oooool2o`0000Cooooo0_l0000:ooooo`;o00001Oooool2o`0000;ooooo0_l00005oooo
o`;o00002oooool4o`0000;ooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`0looooo`?o
00002oooool2o`0000;ooooo0_l00009ooooo`?o000000?oooooo`000?l000001_ooool2o`0000;o
oooo7?l000000ooooooo0000o`000005ooooo`;o00007Oooool2o`0000Gooooo1?l0000@ooooo`;o
000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00000;ooooo`;o00001?ooool2o`00
00;ooooo0_l0000;ooooo`;o00002oooool2o`0004Kooooo000Looooo`03o`000?oooooooooo03co
oooo0_l0000<ooooo`;o00000_ooool2o`0000Kooooo0_l00002ooooo`Go00001_ooool2o`000003
ooooool0003o000001Wo00000oooool2o`0001Cooooo0_l0000>ooooo`;o00001Oooool2o`0000ko
oooo0_l00002ooooo`;o00001?ooool2o`000003ooooool0003o000000_ooooo0_l0000Eooooo`;o
00000oooool2o`0004kooooo000Looooo`03o`000?oooooooooo05Kooooo0_l00004ooooo`;o0000
2OoooolNo`000003ooooool0003o000000[ooooo0_l00003ooooo`;o00000oooool2o`0000Oooooo
0_l00005ooooo`;o00001Oooool2o`0000Cooooo0_l00008ooooo`;o00000_ooool2o`0000Oooooo
0_l00007ooooo`;o00005Oooool2o`0000Oooooo0_l0001>ooooo`007?ooool2o`0004gooooo0_l0
00000ooooooo0000o`000004ooooo`;o00001?ooool3o`0000?ooooo0_l00004ooooo`;o00000_oo
oolMo`0000Kooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`?o00000ooo
ool2o`0000cooooo0_l00004ooooo`Ko00006_ooool2o`0000?ooooo0_l0000@ooooo`;o00004?oo
ool2o`0004Gooooo000Looooo`03o`000?oooooooooo04Sooooo0_l00002ooooo`;o000000?ooooo
o`000?l000001?ooool2o`0000Cooooo0_l00004ooooo`;o00002?oooolBo`000003ooooool0003o
000000Oo00001_ooool3o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo0ol00002
ooooo`;o00002oooool2o`000003ooooool0003o000000Cooooo1Ol00003ooooo`;o00001?ooool2
o`0000;ooooo0_l00005ooooo`Co00001oooool2o`0000kooooo0_l00005ooooo`;o00002oooool2
o`0004Gooooo000Looooo`03o`000?oooooooooo04?ooooo0_l00003ooooo`;o00002Oooool4o`00
01?ooooo1ol000000ooooooo0000o`00000Do`0000Gooooo0_l00008ooooo`?o000000?oooooo`00
0?l000000_l00005ooooo`;o00002oooool2o`000003ooooool0003o000000Gooooo1?l000000ooo
oooo0000o`000005o`000003ooooool0003o000000;ooooo0_l00005ooooo`Co00004oooool3o`00
0003ooooool0003o000000Gooooo0_l00002ooooo`;o00001?ooool5o`0004Gooooo000Looooo`03
o`000?oooooooooo03?ooooo0_l0000>ooooo`;o00001_ooool2o`0000Gooooo0ol0000>ooooo`;o
000000?oooooo`000?l000000_ooool8o`000003ooooool0003o000001Go00002oooool2o`000004
ooooool0003o0000ooooo`Co00003?ooool2o`00013ooooo0_l000001?oooooo0000o`000?ooool4
o`0000Wooooo0_l0000Gooooo`Go00001oooool2o`0000;ooooo0_l00004ooooo`Go0000AOooool0
01cooooo00?o0000ooooooooool0<oooool2o`0000kooooo0_l00006ooooo`;o00001Oooool2o`00
00oooooo0_l000000ooooooo0000o`000003ooooo`[o000000?oooooo`000?l000004_l0000;oooo
o`;o00005?ooool2o`0000?ooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o0000
00;o00001oooool2o`0000?ooooo0_l00005ooooo`;o00005oooool2o`000003ooooool0003o0000
00Sooooo0_l0000;ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0Doooool2o`0000[o
oooo0_l00008ooooo`;o000000?oooooo`000?l000007?l0000Tooooo`Co000000?oooooo`000?l0
00004_l00002ooooo`;o000000?oooooo`000?l000000_l00003ooooo`?o00008?ooool2o`0000_o
oooo0_l00014ooooo`007?ooool00ol0003oooooooooo`16ooooo`;o00002oooool2o`0000[ooooo
0_l00008oooooa;o000000?oooooo`000?l000003Ol00006ooooo`;o00001Oooool3o`0000;ooooo
0_l0000?ooooo`?o000000?oooooo`000?l000002?l000000ooooooo0000o`000008o`0000Gooooo
1?l00003ooooo`?o00005oooool2o`0000Sooooo0_l0001@ooooo`007?ooool00ol0003ooooooooo
o`16ooooo`;o00003?ooool2o`00017ooooo9?l00006ooooo`;o00001Oooool3o`0000;ooooo0_l0
0009ooooo`;o00001?ooool2o`0000;ooooo3_l00003ooooo`?o00000_ooool3o`0000Cooooo0_l0
0005ooooo`;o00002_ooool2o`0000Sooooo0ol00008ooooo`;o0000D?ooool001cooooo00?o0000
ooooooooool0=Oooool2o`0000kooooo0_l00003ooooo`Co00001_ooool2o`00017ooooo0ol00003
oooooa_o000000?oooooo`000?l000001oooool2o`0000_ooooo0_l00002ooooo`;o00000oooool2
o`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l000000_ooool8o`0000;ooooo0_l00000
0ooooooo0000o`000002o`0000Cooooo0_l00003ooooo`Co00002_ooool2o`0000;ooooo0_l00004
ooooo`?o0000F_ooool001cooooo00?o0000ooooooooool0=Oooool2o`0000kooooo0_l00002oooo
o`Go00006Oooool3o`0000?ooooo3_l000001Ooooooo0000o`000?l0003ooooo00Wo00001?ooool2
o`0000?ooooo0_l00007ooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool4
o`000003ooooool0003o000000;o000000?oooooo`000?l000000_ooool9o`000003ooooool0003o
000000?o00002?ooool2o`000003ooooool0003o0000013ooooo0_l0000Aooooo`;o0000C_ooool0
01cooooo00?o0000ooooooooool0BOooool2o`0000?ooooo0_l000000ooooooo0000o`00000Doooo
ob;o000000Coooooo`000?l0003ooooo1Ol000000ooooooo0000o`000006ooooo`;o00002?ooool2
o`000004ooooool0003o0000oooooago00000oooool5o`000003ooooool0003o000001[ooooo0_l0
000:ooooo`;o00001?ooool2o`000003ooooool0003o000004Gooooo000Looooo`03o`000?oooooo
oooo04[ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l00008ooooo`;o000000Cooooo
o`000?l0003ooooo0_l00005oooooaco000000?oooooo`000?l000000ol000000ooooooo0000o`00
0003o`000003ooooool0003o0000013ooooo0_l00004ooooo`?o000000?oooooo`000?l000005Ol0
0005ooooo`Ko000000?oooooo`000?l000000_l0000Booooo`;o00000oooool2o`0000Sooooo0_l0
0006ooooo`;o000000?oooooo`000?l000000_l00013ooooo`007?ooool00ol0003oooooooooo`16
ooooo`;o00000_ooool2o`0000Kooooo0ol00002ooooo`Co00000_ooool2o`000004ooooool0003o
0000ooooo`;o00001_ooool2o`0000?ooooo5ol00002ooooo`[o00000_ooool2o`0000;ooooo0_l0
000:ooooo`?o00001oooool8o`000003ooooool0003o000000;o000000?oooooo`000?l000002Ol0
0002ooooo`?o00000_ooool7o`0000;ooooo0_l0000>ooooo`?o00002?ooool3o`000003ooooool0
003o000000?ooooo1_l00002ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0@?ooool2
o`0000Cooooo0_l0000:ooooo`;o00000oooool4o`000003ooooool0003o000000Cooooo0_l0000<
ooooo`Wo000000?oooooo`000?l000004ol000001?oooooo0000o`000?l00002ooooo`;o00000_oo
ool2o`0000[ooooo0ol000000ooooooo0000o`000003oooooaoo00000_ooool4o`0000Gooooo0_l0
000?ooooo`?o00001oooool3o`000003ooooool0003o000000;o000000?oooooo`000?l000001?l0
0017ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool2o`000003oa0@
4?oooooooooo00Cooooo00?o0000ooooooooool0?oooool3o`0000Cooooo1?l0000<ooooo`?o0000
0oooool2o`0000?ooooo0ol00003ooooo`;o00001_ooool:o`000003ooooool0003o000001?o0000
00?oooooo`000?l000005_ooool4o`000003ooooool0003o000001Oo000000?oooooo`000?l00000
0ol000000ooooooo0000o`000002o`000003ooooool0003o000000;o00004_ooool4o`0000Oooooo
0_l00004ooooo`?o00002?ooool2o`0004?ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0?oooool2o`0000Go
oooo1?l0000<ooooo`;o00001_ooool5o`0000Cooooo0_l000000ooooooo0000o`000003oooooaWo
000000?oooooo`000?l000001Ol0000Hooooo`Co000000?oooooo`000?l000007Ol000000ooooooo
0000o`000002o`000003ooooool0003o000000;o000000Coooooo`000?l0003ooooo1?l0000:oooo
o`;o00001_ooool2o`000003ooooool0003o000000;ooooo1Ol00002ooooo`;o00001?ooool2o`00
04?ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006ooooo`03
o`000?oooooooooo03cooooo1?l00009ooooo`;o000000?oooooo`000?l000000oooool2o`0000?o
oooo0_l00005ooooo`Go00001oooool3o`000003ooooool0003o000001Wo00001?ooool4o`0000?o
oooo0_l0000;ooooo`;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000Oo`0000;o
oooo0_l00003ooooo`Co000000?oooooo`000?l000000_l00009ooooo`;o00001oooool2o`0000Go
oooo0ol00002ooooo`Co0000BOooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
2Oooool01?m4A4CogMgMooooool00007ooooo`?o0000??ooool4o`0000Wooooo1Ol00003ooooo`;o
00002Oooool3o`0000[ooooo0_l00002ooooo`;o00000_oooolGo`0000Cooooo0_l00005ooooo`;o
00002oooool4o`0000;ooooo0_l00005ooooob_o00000_ooool2o`0000_ooooo1?l00002ooooo`;o
00000oooool2o`0000Sooooo0_l00003ooooo`;o0000A_ooool00003ooooool0003ooooo00;ooooo
00?o0000ooooooooool02Oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo03go
oooo0_l00008ooooo`;o000000Coooooo`000?l0003o00003oooool2o`0000?ooooo0_l0000>oooo
o`Go000000?oooooo`000?l000003_l00004ooooo`;o00005Oooool2o`0000Kooooo9ol000000ooo
oooo0000o`000008o`0000cooooo0ol00002ooooo`;o00000oooool2o`0000gooooo0_l00016oooo
o`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oo
oooo00?o0000ooooooooool0:Oooool2o`0000oooooo0ol00007ooooo`;o000000Coooooo`000?l0
003ooooo0_l0000Eooooo`;o00001?ooool2o`000003ooooool0003o000000Gooooo0_l00004oooo
o`?o000000?oooooo`000?l000002?l00006ooooo`;o00001oooool4o`0000Sooooo0_l00004oooo
obKo000000?oooooo`000?l000000_l00002ooooo`;o00000oooool2o`0000kooooo2Ol00006oooo
o`;o00001Oooool2o`000003ooooool0003o000004Kooooo00001_ooooooMgMgoiRHV?ooooooV9RH
ogMgM`cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0Yooooo`;o00003oooool3
o`0000Gooooo1?l0000Fooooo`;o00001oooool4o`000003ooooool0003o000000Wooooo0_l00004
ooooo`?o00000_ooool4o`0000;ooooo0ol00006ooooo`;o00000_ooool5o`0000Sooooo0_l00003
ooooobKo00000_ooool8o`0001Gooooo1ol00003ooooo`;o000000?oooooo`000?l000001Oooool3
o`0004Sooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_oo
ool00ol0003oooooooooo`12ooooo`;o00002_ooool2o`0000cooooo1?l000000ooooooo0000o`00
0002ooooo`;o00003Oooool5o`0000;ooooo1?l00002ooooo`;o00000oooool3o`0000Kooooo0_l0
00001?oooooo0000o`000?l00007ooooo`;o00001OoooolBo`000004ooooool0003o0000oooooaco
00001_ooool2o`0001Oooooo0_l00009ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0
@Oooool2o`0000Sooooo0_l000000ooooooo0000o`00000>ooooo`;o000000?oooooo`000?l00000
0ol00003ooooo`;o00002Oooool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o0000
0_ooool2o`0000Oooooo0_l000000ooooooo0000o`000002o`0000Oooooo0_l00005ooooo`;o0000
00?oooooo`000?l000000_l000000ooooooo0000o`000008o`000003ooooool0003o000001go0000
0oooool2o`000004ooooool0003o0000ooooo`;o00001_ooool2o`0000Sooooo0_l0000:ooooo`;o
0000Boooool001cooooo00?o0000ooooooooool0??ooool7o`0000Sooooo0_l00005ooooo`;o0000
3oooool3o`0000?ooooo0ol00002ooooo`Co00001_ooool2o`0000_ooooo0_l00005ooooo`Oo0000
4?ooool7o`000003ooooool0003o000001Ko00000_ooool?o`0000Cooooo0_l000001?oooooo0000
o`000?ooool4o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000Cooooo0_l00006oooo
o`;o00000_ooool2o`0000;ooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`0looooo`Go
00003?ooool2o`0000?ooooo0_l0000@ooooo`;o00000oooool3o`0000;ooooo1?l00002ooooo`;o
00000_ooool2o`0000cooooo0_l00004ooooo`;o000000Coooooo`000?l0003o00002oooool4o`00
00;ooooo1?l000000ooooooo0000o`000004o`000003ooooool0003o000002Co00001?ooool2o`00
00Gooooo0_l000000ooooooo0000o`000005ooooo`?o00000_ooool5o`0000;ooooo1?l00006oooo
o`Co00001Oooool2o`0003kooooo000Looooo`03o`000?oooooooooo04gooooo0_l0000Eooooo`;o
00000_ooool6o`0000?ooooo0_l000000ooooooo0000o`00000@ooooo`;o000000Coooooo`000?l0
003ooooo0_l000000ooooooo0000o`00000:ooooo`Ko000000?oooooo`000?l000001Ol000000ooo
oooo0000o`00000Yo`000003ooooool0003o000000?o00003oooool4o`000003ooooool0003o0000
00?o000000?oooooo`000?l000000_l00003ooooo`;o00001?ooool2o`0000Gooooo0_l0000noooo
o`007?ooool00ol0003oooooooooo`0mooooo`;o00000_ooool2o`0001oooooo1?l00002ooooo`;o
00000_ooool3o`0000;ooooo0_l00006ooooo`;o00003_ooool2o`0000[ooooo0_l00004ooooo`;o
00001Oooool2o`000003ooooool0003o000000;o00000_oooolYo`0000;ooooo1?l00007ooooo`;o
00001oooool4o`000003ooooool0003o000000;o00000_ooool2o`0000Gooooo0_l00003ooooo`;o
0000A_ooool001cooooo00?o0000ooooooooool0=_ooool2o`0000Gooooo0_l000001?oooooo0000
o`000?l00002ooooo`;o00000_ooool4o`0001Gooooo1?l00007ooooo`Co00002?ooool2o`0000Ko
oooo0_l00004ooooo`;o00000oooool2o`0000Oooooo0_l00004ooooo`;o00002Oooool2o`0000;o
oooo1?l000000ooooooo0000o`00000So`0000gooooo0_l00002ooooo`;o00000oooool4o`0000?o
oooo0ol00002ooooo`;o00002Oooool2o`0004Kooooo000Looooo`03o`000?oooooooooo03Kooooo
0_l00008ooooo`;o00000oooool2o`000003ooooool0003o000000?o00005_ooool5o`0000?ooooo
0_l000001Ooooooo0000o`000?l0003ooooo00;o00003Oooool2o`0000Cooooo0_l00003ooooo`Go
00003?ooool2o`0000Oooooo0_l00002ooooobWo00004_ooool4o`000003ooooool0003o000000?o
00000_ooool8o`0000kooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`18ooooo`Co0000
5oooool2o`000003ooooool0003o000000?ooooo0_l00005ooooo`;o00003Oooool3o`0000Wooooo
1?l00007ooooo`;o00000oooool2o`0000Kooooo1?l00002ooooobWo00004oooool2o`0000;ooooo
1?l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000001?l0000:ooooo`;o0000
0oooool2o`0003_ooooo000Looooo`03o`000?oooooooooo02Gooooo0_l000000ooooooo0000o`00
000=ooooo`;o00004Oooool2o`00027ooooo0_l00002ooooo`;o00002_ooool2o`0000;ooooo0ol0
000Dooooo`;o00001Oooool2o`0000Cooooo7_l000000ooooooo0000o`00000:o`0000;ooooo1?l0
000Aooooo`;o00000_ooool4o`000003ooooool0003o000000Oooooo1?l00005ooooo`;o00002?oo
ool2o`0003_ooooo000Looooo`03o`000?oooooooooo02Gooooo0_l000000ooooooo0000o`00000=
ooooo`;o00001?ooool2o`0000cooooo0_l00003ooooo`;o00004_ooool4o`0000Gooooo0_l00000
1?oooooo0000o`000?l0000:ooooo`;o00003_ooool2o`0000Oooooo0_l00004ooooo`;o000000?o
ooooo`000?l000001ooooolGo`000003ooooool0003o000000Co000000?oooooo`000?l000002Ol0
00001?oooooo0000o`000?l0000=ooooo`;o00000_ooool2o`0000Cooooo0_l0000Cooooo`?o0000
1Oooool2o`0003gooooo000Looooo`03o`000?oooooooooo03gooooo0_l000000ooooooo0000o`00
0009ooooo`;o00000oooool2o`0000Sooooo0_l00008ooooo`Co000000?oooooo`000?l000001Ooo
ool2o`0000;ooooo1_l00002ooooo`Oo00000_ooool4o`0000Cooooo0_l00005ooooo`Co00001?oo
ool2o`0000Sooooo;?l00002ooooo`;o00002oooool4o`0001Cooooo0_l000001?oooooo0000o`00
0?ooool3o`000003ooooool0003o000000Gooooo0_l0000mooooo`007?ooool2o`0002gooooo0_l0
000=ooooo`;o00000oooool2o`000003ooooool0003o000000_ooooo0_l00008ooooo`?o00000_oo
ool2o`0000Sooooo0_l00009ooooo`Ko00000_ooool8o`000003ooooool0003o000000;o000000Co
ooooo`000?l0003ooooo1Ol00002ooooo`Co00002_ooool2o`0000;ooooo1ol000000ooooooo0000
o`00000Eo`000003ooooool0003o000000So00000_ooool2o`0000Wooooo0_l00002ooooo`;o0000
0_ooool2o`0000[ooooo0_l00006ooooo`;o000000Coooooo`000?l0003ooooo0ol00017ooooo`00
7?ooool00ol0003oooooooooo`0/ooooo`;o00003Oooool2o`0000Kooooo0_l0000;ooooo`;o0000
0_ooool2o`0000Gooooo0_l00002ooooo`;o00001_ooool4o`000003ooooool0003o000000Oooooo
0ol000001?oooooo0000o`000?l00006ooooo`;o00000_ooool2o`0000;ooooo0_l00002ooooo`Co
00001?ooool4o`0000Sooooo0_l00007ooooo`Co000000?oooooo`000?l000009Ol000001?oooooo
0000o`000?ooool4o`0000Kooooo0_l00003ooooo`;o00001Oooool6o`0000Cooooo0_l000001?oo
oooo0000o`000?l00002ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0=?ooool2o`00
00kooooo1?l00003ooooo`;o00001oooool2o`00017ooooo0_l00003ooooo`;o00002oooool3o`00
00_ooooo0_l00005ooooo`Co00001_ooool2o`0000Gooooo0_l00004ooooo`;o00001?oooolRo`00
00;ooooo2?l000001?oooooo0000o`000?ooool4o`0000;ooooo0_l00003ooooo`;o00000_ooool3
o`0000Kooooo1?l00004ooooo`Go00000oooool2o`0004Cooooo000Looooo`03o`000?oooooooooo
03Cooooo0_l0000>ooooo`Co00000oooool2o`000003ooooool0003o000000Cooooo1?l0000Eoooo
o`;o00004?ooool2o`0000Kooooo0_l00007ooooo`;o00001_ooool4o`0000?ooooo0_l00004oooo
o`;o00000_ooool8o`0000;ooooo2Ol000000ooooooo0000o`00000Eo`0000Wooooo0_l00002oooo
o`;o00000_ooool3o`0000?ooooo1Ol00003ooooo`;o00001oooool2o`0000Wooooo0_l00010oooo
o`007?ooool00ol0003oooooooooo`0Rooooo`;o0000:_ooool2o`0000Kooooo0_l0000Dooooo`?o
00004?ooool2o`0001Oooooo1?l000000ooooooo0000o`000009ooooo`Go00001OoooolIo`000003
ooooool0003o000000Go00000oooool2o`0000?ooooo1?l00006ooooo`;o00001?ooool5o`0000?o
oooo0ol00007ooooo`;o00002?ooool2o`0001gooooo0_l0000Qooooo`007?ooool00ol0003ooooo
ooooo`0Rooooo`;o00007oooool2o`0000Kooooo0_l0000;ooooo`;o00003oooool2o`000003oooo
ool0003o0000017ooooo0_l00009ooooo`;o00002Oooool2o`000003ooooool0003o000000?ooooo
0_l00008ooooo`?o000000Coooooo`000?l0003ooooo0ol000000ooooooo0000o`00000<o`000003
ooooool0003o000000Ko000000?oooooo`000?l000001Ol00002ooooo`;o000000?oooooo`000?l0
00000oooool2o`0000;ooooo0_l0000=ooooo`;o00000oooool3o`0000Cooooo0_l000000ooooooo
0000o`000009ooooo`;o00007?ooool2o`00027ooooo000Looooo`03o`000?oooooooooo03?ooooo
0_l00006ooooo`;o00000oooool2o`000003ooooool0003o000000Kooooo0_l00006ooooo`;o0000
0oooool4o`0000gooooo0_l0000Oooooo`;o00002Oooool2o`0000oooooo0ol000001Ooooooo0000
o`000?l0003ooooo00?o00000_oooolJo`0000;ooooo0_l00002ooooo`;o00002_ooool2o`0001;o
oooo0_l00003ooooo`Co00003?ooool2o`0003oooooo000Looooo`03o`000?oooooooooo02Gooooo
0_l0000<ooooo`;o000000?oooooo`000?l000000oooool7o`000003ooooool0003o000000kooooo
0_l00005ooooo`;o00001?ooool2o`00027ooooo0_l0000:ooooo`;o00001oooool2o`0000Cooooo
0_l00006ooooo`?o000000Goooooo`000?l0003o0000ooooo`03o`0000;ooooo6Ol0000:ooooo`?o
00002Oooool3o`0001?ooooo0_l0000<ooooo`Co0000?oooool001cooooo00?o0000ooooooooool0
9Oooool2o`0000oooooo0_l00005ooooo`Co00004_ooool2o`0000_ooooo0_l0000Qooooo`;o0000
2_ooool2o`0000Oooooo0_l00004ooooo`;o00001Oooool2o`0000;ooooo0_l00003ooooo`ko0000
00?oooooo`000?l000003Ol00006ooooo`;o00000_ooool3o`0000?ooooo0_l000001?oooooo0000
o`000?ooool4o`0000Sooooo0ol0000<ooooo`;o00001oooool7o`0003cooooo000Looooo`03o`00
0?oooooooooo03kooooo0_l00005ooooo`;o00001oooool2o`000003ooooool0003o000000;o0000
4_ooool2o`0000[ooooo0_l0000>ooooo`;o00000_ooool2o`0000;ooooo0_l00008ooooo`Go0000
2oooool2o`0000;ooooo0_l00002ooooo`So000000?oooooo`000?l000003?l000000ooooooo0000
o`000005o`0000?ooooo0_l000000ooooooo0000o`000008ooooo`;o000000?oooooo`000?l00000
0oooool2o`0000Sooooo0ol00008ooooo`Ko00002_ooool4o`0003cooooo000Looooo`03o`000?oo
oooooooo02kooooo0_l0000Dooooo`?o00001oooool2o`000004ooooool0003o0000o`0000_ooooo
0_l00004ooooo`Co00000_ooool2o`0000Kooooo0_l00003ooooo`;o00002oooool4o`0000;ooooo
0_l00008ooooo`?o00003Oooool2o`0000Gooooo1Ol00005oooooa?o00001_ooool5o`0000gooooo
0_l00009ooooo`;o00002oooool4o`0004cooooo000Looooo`03o`000?oooooooooo02kooooo0_l0
0005ooooo`;o00000oooool2o`0000Sooooo0ol00009ooooo`;o00003Oooool2o`0000?ooooo0ol0
0004ooooo`;o000000?oooooo`000?l000002?ooool4o`0000Kooooo0_l000001?oooooo0000o`00
0?l00004ooooo`;o00003oooool2o`0000Kooooo0_l00003ooooo`Go00000_ooool2o`0000Gooooo
4?l000000ooooooo0000o`000005ooooo`Co00002_ooool6o`0000;ooooo1?l00002ooooo`Co0000
1Oooool2o`0000Kooooo0_l00006ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0<Ooo
ool2o`0000;ooooo0_l00003ooooo`;o00002?ooool2o`0000;ooooo1?l00004ooooo`;o00003_oo
ool2o`0000;ooooo0_l00008ooooo`;o00002Oooool3o`0000Kooooo0_l000000ooooooo0000o`00
0005ooooo`;o00003oooool2o`0000_ooooo0_l00005ooooo`Co00000oooool:o`000003ooooool0
003o000000;o000000Coooooo`000?l0003o00001?ooool2o`0000gooooo1_l00002ooooo`Co0000
1?ooool3o`0000Cooooo0_l00006ooooo`;o00001_ooool2o`0000Gooooo0_l0000kooooo`007?oo
ool00ol0003oooooooooo`0aooooo`;o00001Oooool2o`0000?ooooo0_l00009ooooo`Co00005?oo
ool2o`000003ooooool0003o000000;o00002Oooool2o`0000Oooooo0_l00004ooooo`;o00008?oo
ool2o`0000Gooooo0_l00008ooooo`Co000000?oooooo`000?l000002_l00002ooooo`;o000000?o
ooooo`000?l000001Oooool3o`0000oooooo0_l000000ooooooo0000o`000002o`000003ooooool0
003o000000Cooooo0_l0000Dooooo`;o00001Oooool2o`0003_ooooo000Looooo`03o`000?oooooo
oooo03;ooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l0000@ooooo`;o00001?oo
ool2o`0000cooooo1?l00005ooooo`;o00000_ooool4o`0000Gooooo1?l00002ooooo`Co00007_oo
ool2o`0000Gooooo0ol00003ooooo`Go000000?oooooo`000?l000000ol00006ooooo`Co00001?oo
ool2o`0000?ooooo0_l00002ooooo`Ko00003_ooool2o`0000?ooooo0_l00007ooooo`;o000000?o
ooooo`000?l000003Oooool2o`0004?ooooo000Looooo`03o`000?oooooooooo02Wooooo0_l00007
ooooo`Go00005oooool3o`0000Cooooo0_l00002ooooo`;o00002oooool3o`000003ooooool0003o
000000Wo00000oooool2o`000003ooooool0003o000000Cooooo0_l0000>ooooo`;o00005_ooool2
o`0000?ooooo1Ol00003ooooo`Go00000_ooool6o`0000Cooooo1ol00004ooooo`Co00000oooool2
o`0000?ooooo0_l000000ooooooo0000o`00000?ooooo`;o000000?oooooo`000?l000003?ooool3
o`000005ooooool0003o0000o`000?ooool00_l0000looooo`007?ooool2o`0002[ooooo0_l00009
ooooo`;o00005Oooool2o`000003ooooool0003o000000Wooooo0_l0000;ooooo`?o000000?ooooo
o`000?l000002Ol00003ooooo`;o00002oooool2o`0000[ooooo0_l00004ooooo`Co00000oooool2
o`0000Oooooo0_l00003ooooo`;o00001?ooool2o`0000?ooooo1?l00002ooooo`Ko000000Cooooo
o`000?l0003ooooo1_l00005ooooo`;o00001Oooool2o`0000?ooooo0_l000001?oooooo0000o`00
0?ooool2o`0000cooooo0_l00005ooooo`?o00001oooool3o`000005ooooool0003o0000o`000?oo
ool00_l0000looooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00006oooool2o`00017ooooo
0_l000000ooooooo0000o`000003ooooo`;o00000oooool8o`0001;ooooo0_l0000@ooooo`Co0000
0oooool4o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o00001?ooool2o`0000;ooooo
0_l000001?oooooo0000o`000?l00003ooooo`Oo000000?oooooo`000?l000002Oooool2o`0000Co
oooo1_l00006ooooo`Co00001_ooool2o`0000Wooooo0ol00008ooooo`;o00000_ooool2o`0003oo
oooo000Looooo`03o`000?oooooooooo02kooooo0_l000000ooooooo0000o`000004ooooo`;o0000
3?ooool2o`0000Gooooo0_l0000@ooooo`;o000000Coooooo`000?l0003ooooo4?l0000=ooooo`;o
00005oooool2o`0000Cooooo0_l00002ooooo`;o00004?ooool3o`000003ooooool0003o000000;o
oooo0_l00002ooooo`?o00000_ooool2o`0000;ooooo0_l0000;ooooo`Ko00000oooool2o`0000?o
oooo0_l00005ooooo`?o00006?ooool2o`0000Cooooo0_l0000iooooo`007?ooool00ol0003ooooo
ooooo`0aooooo`;o00001?ooool4o`0000[ooooo0_l00005ooooo`?o00005?oooolDo`0000Cooooo
0_l00004ooooo`;o00001_ooool2o`0000Cooooo0_l00009ooooo`;o00002?ooool2o`0000Kooooo
0_l00002ooooo`;o00001Oooool2o`0000?ooooo1?l0000;ooooo`;o000000?oooooo`000?l00000
1oooool4o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`;o00001Oooool5o`0000Oooooo
0_l00002ooooo`;o00003?ooool2o`000003ooooool0003o000003Wooooo000Looooo`03o`000?oo
oooooooo033ooooo0_l00007ooooo`;o00002Oooool2o`0000Oooooo1?l000000ooooooo0000o`00
0008ooooo`Co00000oooool2o`000003ooooool0003o000000oo00000oooool3o`0000Gooooo0_l0
0004ooooo`?o00001?ooool2o`000003ooooool0003o000000;o00005_ooool2o`0000;ooooo0_l0
0005ooooo`;o00000oooool6o`0000cooooo0_l00007ooooo`Go00000_ooool2o`0000Kooooo0_l0
0006ooooo`Co00001oooool2o`0000;ooooo1?l00005ooooo`;o00000oooool2o`0003cooooo000L
ooooo`03o`000?oooooooooo033ooooo0_l0000:ooooo`;o00001?ooool4o`0000Wooooo0_l00000
0ooooooo0000o`000008ooooo`Co00001OoooolAo`0000;ooooo1?l00006ooooo`;o00001?ooool2
o`0000Sooooo1?l0000Cooooo`Co00000oooool2o`0000Cooooo0ol00007ooooo`;o00004_ooool2
o`0000;ooooo1?l0000Aooooo`;o00004?ooool2o`0000Gooooo1?l0000oooooo`007?ooool00ol0
003oooooooooo`0looooo`;o00001?ooool5o`0000[ooooo0_l0000Boooooa3o00000_ooool3o`00
01Sooooo0_l00009ooooo`;o00001oooool2o`000003ooooool0003o000000;o00000oooool2o`00
00Cooooo0ol00007ooooo`;o00004_ooool2o`0000cooooo0_l00009ooooo`;o00000oooool2o`00
00Gooooo0_l0000=ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0:oooool2o`0001Oo
oooo0ol00002ooooo`;o00001_ooool2o`0000cooooo0_l000000ooooooo0000o`00000Bo`000003
ooooool0003o0000013ooooo0_l00004ooooo`;o00001Oooool2o`0000Gooooo0_l00007ooooo`;o
000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l00002ooooo`?o00005?ooool2o`0000Co
oooo0_l0000=ooooo`;o00003Oooool3o`0000Gooooo0_l0001>ooooo`007?ooool00ol0003ooooo
ooooo`0[ooooo`;o00000_ooool2o`0001;ooooo0_l00004ooooo`Go00001?ooool2o`0000_ooooo
0_l000000ooooooo0000o`00000Fo`0000?ooooo0_l0000:ooooo`;o00001?ooool3o`0000Cooooo
0_l0000Dooooo`?o00000oooool2o`0000;ooooo0_l00007ooooo`;o00003?ooool2o`0000?ooooo
0ol0000>ooooo`;o00003?ooool2o`000003ooooool0003o000000;o00001Oooool2o`0000;ooooo
0_l00016ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00000oooool2o`0000gooooo0_l0
0004ooooo`Go00001?ooool2o`0000kooooo6?l00003ooooo`;o00001oooool2o`000003ooooool0
003o000000Gooooo0_l0000Jooooo`;o00001_ooool2o`0000?ooooo0_l00004ooooo`;o000000?o
ooooo`000?l000003_ooool2o`0000gooooo1?l0000?ooooo`Co00001Oooool2o`0000;ooooo0_l0
0007ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0=?ooool2o`0001?ooooo0_l00009
ooooo`;o00003OoooolEo`0000kooooo0_l000000ooooooo0000o`00000:ooooo`;o00001Oooool2
o`0000Wooooo1?l00008ooooo`Go000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l00005
ooooo`;o00003?ooool2o`0000Sooooo0_l00004ooooo`;o00002oooool2o`0000Gooooo0_l00003
ooooo`;o00001_ooool4o`0003gooooo000Looooo`03o`000?oooooooooo01kooooo0_l00002oooo
o`;o00001Oooool2o`0001gooooo0_l0000:ooooo`?o00000_ooool2o`0000;ooooo0_l00004oooo
oaGo00006?ooool7o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o00001Oooool4o`00
00Sooooo0_l000000ooooooo0000o`000005ooooo`?o00000_ooool2o`0000Gooooo0_l0000<oooo
o`;o00000oooool2o`0000Wooooo0_l000000ooooooo0000o`000003ooooo`;o00002_ooool2o`00
00?ooooo1?l00004ooooo`;o0000?oooool001cooooo00?o0000ooooooooool07_ooool2o`0000;o
oooo0_l00005ooooo`;o00000_ooool2o`0000Oooooo0_l0000:ooooo`;o00000_ooool4o`0000_o
oooo0_l000001?oooooo0000o`000?l00002ooooo`;o00001OoooolFo`0000?ooooo0_l000000ooo
oooo0000o`000009ooooo`;o00000_ooool6o`0000;ooooo0ol00003ooooo`Go00001_ooool2o`00
01Cooooo0_l00002ooooo`;o00000oooool2o`0000Sooooo0_l00009ooooo`;o00000_ooool2o`00
00Sooooo0_l00003ooooo`;o00004Oooool2o`0004Gooooo000Looooo`03o`000?oooooooooo02co
oooo0ol00007ooooo`;o00002_ooool3o`000003ooooool0003o000000?ooooo0_l0000;ooooo`;o
00002?ooool;o`000003ooooool0003o000000[o000000?oooooo`000?l000001Ol00009ooooo`;o
00000_ooool3o`0000Cooooo0ol00004ooooo`?o00002?ooool2o`0000Oooooo0_l00003ooooo`;o
00003_ooool3o`0000;ooooo0_l00004ooooo`;o00003Oooool2o`0000Kooooo1_l0000Dooooo`;o
00001?ooool2o`0000oooooo0_l0000^ooooo`007?ooool00ol0003oooooooooo`0Wooooo`;o0000
0oooool2o`0000oooooo0_l00002ooooo`Co00001_ooool2o`0000Gooooo0_l00007ooooo`;o0000
1OoooolFo`0000?ooooo1_l0000@ooooo`;o00000oooool2o`0000oooooo0_l00002ooooo`;o0000
00Coooooo`000?l0003ooooo0_l00003ooooo`;o00003_ooool3o`0000;ooooo0_l0000<ooooo`;o
00002Oooool2o`0000;ooooo0_l00002ooooo`;o00001_ooool3o`00017ooooo0_l0000?ooooo`;o
0000;_ooool001cooooo00?o0000ooooooooool09oooool2o`0000;ooooo0_l0000>ooooo`Co0000
0_ooool2o`0000oooooo0_l00004ooooo`;o000000?oooooo`000?l000000_ooool2o`000003oooo
ool0003o000001Ko00001Oooool2o`0000Kooooo0_l00008ooooo`;o00001Oooool2o`0000gooooo
1_l000000ooooooo0000o`000005ooooo`;o00001_ooool2o`0000Gooooo0_l000000ooooooo0000
o`00000@ooooo`;o00002Oooool2o`000003ooooool0003o000000Cooooo1?l00003ooooo`?o0000
0_ooool2o`000003ooooool0003o000000[ooooo0_l0000Mooooo`;o00008?ooool001cooooo0_l0
000/ooooo`;o00003_ooool4o`000003ooooool0003o000000;o00005?ooool2o`0000Gooooo3?l0
0003ooooo`co00003Oooool2o`000003ooooool0003o000000cooooo0_l00007ooooo`;o00001Ooo
ool3o`0000?ooooo0_l00005ooooo`;o00001Oooool5o`0000?ooooo0_l000000ooooooo0000o`00
000:ooooo`;o00000_ooool2o`0000Sooooo0_l000001?oooooo0000o`000?ooool2o`0000Cooooo
1?l00008ooooo`Go00002_ooool2o`0001gooooo0_l0000Pooooo`007?ooool00ol0003ooooooooo
o`0aooooo`Co00001oooool2o`0000;ooooo1?l0000Cooooo`;o00001ooooolJo`00013ooooo0_l0
00000ooooooo0000o`00000Booooo`;o00001Oooool2o`0000Cooooo0_l00005ooooo`;o00001Ooo
ool2o`000004ooooool0003o0000ooooo`;o00003oooool2o`0000;ooooo0_l00004ooooo`;o0000
0_ooool4o`0000Wooooo0_l000000ooooooo0000o`000004ooooo`;o00000_ooool2o`0001Sooooo
0_l0000booooo`007?ooool00ol0003oooooooooo`0aooooo`Co00004_ooool2o`0000_ooooo0_l0
00000ooooooo0000o`000007oooooa[o00002?ooool2o`0000Wooooo0_l00004ooooo`;o00003ooo
ool2o`0000;ooooo0_l0000;ooooo`Co00002Oooool2o`0000cooooo0_l0000;ooooo`?o00000_oo
ool3o`000003ooooool0003o000000;o00001?ooool5o`0000?ooooo0ol0000Fooooo`;o00001?oo
ool2o`0003;ooooo000Looooo`03o`000?oooooooooo037ooooo0_l00004ooooo`;o00003_ooool2
o`0000[ooooo1?l00003ooooo`;o00001?ooool4o`000003ooooool0003o000001;o00002Oooool2
o`0000[ooooo0_l00003ooooo`;o00001Oooool2o`0000Sooooo0_l0000Aooooo`Go00005?ooool2
o`0000[ooooo1?l000001?oooooo0000o`000?l00002ooooo`Co00001Oooool2o`0000Gooooo0_l0
0004ooooo`;o00003?ooool2o`0000?ooooo1?l0000fooooo`007?ooool00ol0003oooooooooo`0f
ooooo`?o00005Oooool2o`0000?ooooo1?l00003ooooo`;o00001ooooolEo`0000?ooooo0_l0000;
ooooo`;o00001?ooool2o`0000Gooooo0_l00003ooooo`;o00002?ooool3o`0001;ooooo0ol00000
0ooooooo0000o`00000Jooooo`Go00000oooool2o`0000Gooooo0_l00003ooooo`;o00003?ooool4
o`000003ooooool0003o000000Sooooo0_l00005ooooo`;o00001Oooool2o`0002oooooo000Loooo
o`03o`000?oooooooooo033ooooo0_l00004ooooo`?o00000oooool4o`0000kooooo1Ol00005oooo
o`;o00001ooooolGo`0000?ooooo0_l0000;ooooo`;o00002oooool2o`0000gooooo1?l00004oooo
o`?o00002?ooool2o`000004ooooool0003o0000ooooo`;o00006_ooool4o`000003ooooool0003o
000000Sooooo0_l00003ooooo`;o00001?ooool2o`0000Kooooo1?l000000ooooooo0000o`00000F
ooooo`;o0000;oooool001cooooo00?o0000ooooooooool0<?ooool2o`0000[ooooo1?l00002oooo
o`;o000000?oooooo`000?l000002?ooool5o`0000Cooooo0ol00006ooooo`ko000000?oooooo`00
0?l000001_l00003ooooo`;o00002?ooool2o`0001;ooooo0ol00006ooooo`Ko00001?ooool3o`00
00;ooooo0_l00004ooooo`;o00001_ooool3o`0001cooooo0_l00007ooooo`?o00000oooool2o`00
00;ooooo1?l00008ooooo`;o00000oooool2o`0004Gooooo000Looooo`03o`000?oooooooooo03_o
oooo0_l00005ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Oooooo0_l00005ooooo`;o
00001Oooool3o`000003ooooool0003o0000017o00001_ooool2o`0000Kooooo0_l00002ooooo`;o
00003Oooool4o`0000;ooooo0_l00002ooooo`;o00002_ooool2o`000003ooooool0003o000000Co
oooo0_l00006ooooo`?o00004?ooool2o`0001?ooooo0_l00004ooooo`Oo00002Oooool2o`0000?o
oooo0_l00002ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0:_ooool2o`0000oooooo
0_l0000:ooooo`Co00002_ooool2o`0000Kooooo0_l000000ooooooo0000o`00000Do`0000Kooooo
0ol0000:ooooo`;o00003Oooool2o`0000Cooooo0_l000000ooooooo0000o`00000;ooooo`;o0000
0oooool2o`0000[ooooo1?l000000ooooooo0000o`00000<ooooo`;o00001oooool2o`0000Kooooo
1_l00006ooooo`;o00000_ooool2o`000003ooooool0003o000000Wooooo0_l00002ooooo`?o0000
@Oooool001cooooo00?o0000ooooooooool0:_ooool2o`0000Gooooo0_l0000Dooooo`;o00002Ooo
ool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000003o`000003ooooool0
003o0000017o00000_ooool2o`0000;ooooo0_l0000Kooooo`;o00001_ooool4o`0000?ooooo0_l0
0009ooooo`;o00000oooool2o`0000Gooooo1?l000000ooooooo0000o`00000:ooooo`;o00002Ooo
ool2o`0000Kooooo1_l0000:ooooo`;o000000?oooooo`000?l000002Oooool2o`000004ooooool0
003o0000o`0004;ooooo000Looooo`03o`000?oooooooooo02[ooooo1?l00003ooooo`;o00005?oo
ool2o`0000Wooooo0_l00002ooooo`;o000000?oooooo`000?l000000ol000001Ooooooo0000o`00
0?l0003ooooo00;o000000?oooooo`000?l000003Ol00003ooooo`?o00003_ooool7o`000003oooo
ool0003o000000Kooooo0_l00008ooooo`Oo00003_ooool5o`000003ooooool0003o000000Co0000
0_ooool2o`0000Sooooo0_l0000Eooooo`;o00001Oooool2o`0000;ooooo0_l00003ooooo`;o0000
2oooool3o`0004;ooooo000Looooo`03o`000?oooooooooo02cooooo0_l0000?ooooo`;o00002?oo
ool4o`0000_ooooo0_l000001?oooooo0000o`000?ooool2o`0000Oooooo3ol000000ooooooo0000
o`000002ooooo`;o00000oooool2o`0000;ooooo1?l00003ooooo`Oo000000?oooooo`000?l00000
1Oooool3o`0000Sooooo1_l0000Aooooo`Ko00000_ooool2o`000004ooooool0003o0000o`0000So
oooo0_l0000Dooooo`;o00001_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000_o
oooo0ol00012ooooo`007?ooool00ol0003oooooooooo`0jooooo`;o000000?oooooo`000?l00000
2_ooool2o`0000Kooooo0_l00006ooooo`;o00001_ooool2o`0000;ooooo0_l000001?oooooo0000
o`000?ooool7o`0000?ooooo0_l00003ooooo`;o000000Coooooo`000?l0003o00000_ooool4o`00
00?ooooo0_l00003ooooo`;o00002?ooool2o`000003ooooool0003o000000Oooooo0ol00002oooo
o`;o00002?ooool2o`0000Oooooo0_l00005ooooo`Co000000?oooooo`000?l000000_l00004oooo
o`;o00001?ooool2o`0000kooooo0ol0000<ooooo`;o00002_ooool2o`0000;ooooo0_l00012oooo
o`007?ooool00ol0003oooooooooo`0jooooo`;o00003oooool2o`0000Cooooo0_l00006ooooo`;o
00001_ooool2o`0000?ooooo0_l00003ooooo`Ko00000oooool4o`0000;ooooo0_l000001?oooooo
0000o`000?l00009ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o00001_ooool2
o`0000Cooooo0_l00006ooooo`;o00002?ooool2o`0000gooooo3_l00006ooooo`;o00003oooool2
o`00013ooooo0_l00006ooooo`;o00000oooool3o`00043ooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003ooooo
ooooo`0hooooo`;o00000_ooool2o`0000gooooo0_l00008ooooo`;o00001_ooool2o`0000Oooooo
0_l00006ooooo`Go000000?oooooo`000?l000000_l00003ooooo`Go000000?oooooo`000?l00000
2_ooool2o`000004ooooool0003o0000ooooo`;o00003?ooool2o`0000[ooooo1?l0000=ooooo`;o
000000?oooooo`000?l000003Ol0000Qooooo`;o00001_ooool2o`0000;ooooo1Ol00004ooooo`?o
0000@?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMg
MoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo03Sooooo0_l00002ooooo`;o00000oooool2
o`0000Sooooo1?l00002ooooo`;o00000_ooool2o`0000Kooooo1?l0000<ooooo`Ko00002?ooool3
o`0000?ooooo0_l0000Zooooo`Go00003?ooool2o`000003ooooool0003o000000oo00007oooool2
o`0000[ooooo1Ol00002ooooo`;o0000@oooool00003ooooool@413ooooo00;ooooo00?o410@oooo
ooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0>?ooool2
o`0000Oooooo0_l0000:ooooo`;o00000_ooool2o`0000cooooo0_l00003ooooo`;o00001oooool5
o`0000?ooooo0_l00004ooooo`;o00001?ooool6o`0002?ooooo0_l00002ooooo`Co00002ooooolE
o`00027ooooo0_l00009ooooo`;o000000?oooooo`000?l000000ol00013ooooo`0000?oooooo`00
0?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3
o`0003Sooooo0_l0000Uooooo`;o00000oooool3o`0000Kooooo0_l00005ooooo`Go00000_ooool2
o`0000Kooooo1?l000000ooooooo0000o`00000Gooooo`;o00001oooool2o`0000;ooooo0_l00004
ooooo`;o00000_ooool4o`000003ooooool0003o000001Co000000Coooooo`000?l0003o00007?oo
ool2o`0000cooooo1?l00014ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09
ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`1Aooooo`;o00003?oo
ool3o`0000?ooooo0_l0000=ooooo`Go00003oooool2o`0000cooooo0_l00009ooooo`;o00003Ooo
ool2o`0000;ooooo0_l00002ooooo`Co00000_oooolEo`000004ooooool0003o0000o`0001Kooooo
0ol0000Dooooo`?o0000@_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Ooo
ool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo03oooooo0_l0000=ooooo`;o000000?o
ooooo`000?l000003?ooool3o`0000;ooooo0_l00002ooooo`?o00002Oooool2o`0000Oooooo0_l0
000Booooo`;o00000oooool2o`0000Kooooo0_l00003ooooo`;o00000_ooool2o`0000Oooooo0ol0
000<oooooa?o00005Oooool2o`0000Cooooo0ol00008ooooo`?o00000_ooool2o`0000Gooooo0ol0
000>ooooo`;o0000<_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@
oiRHV008ooooo`03o`000?oooooooooo02Wooooo0_l0000@ooooo`;o00000_ooool2o`0000gooooo
0_l0000Booooo`go00002?ooool2o`0000Cooooo1?l00002ooooo`;o00002Oooool2o`000003oooo
ool0003o000000;ooooo1_l00003ooooo`;o00000oooool2o`0000;ooooo0ol00002ooooo`;o0000
0_ooool3o`000003ooooool0003o000000;o00001ooooolGo`00017ooooo1?l00004ooooo`;o0000
1oooool3o`0000;ooooo0_l0000Fooooo`;o0000<_ooool00006ooooooo^k^ko<S8bo`000?lb<S;o
k^k^3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo02Wooooo0_l0000@oooo
o`;o00000_ooool2o`0000Cooooo0_l00004ooooo`;o00005Oooool2o`0000;ooooo2_l00007oooo
o`?o00001Oooool2o`0000;ooooo0_l00007ooooo`Co00001Oooool6o`0000Sooooo0_l00003oooo
o`;o00000_ooool2o`000004ooooool0003o0000o`0000;ooooo1?l00005oooooaWo00000oooool2
o`0000kooooo0_l00002ooooo`Co00000oooool2o`0000gooooo0_l00014ooooo`007?ooool00ol0
003oooooooooo`0oooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`Co00003_ooool4
o`0000Kooooo1Ol00002ooooo`;o00000oooool2o`0000?ooooo0_l00008ooooo`Co00001_ooool3
o`0000Cooooo0_l00002ooooo`[o00001Oooool2o`0000;ooooo0_l00003ooooo`;o00003?ooool3
o`000003ooooool0003o0000013o00001_ooool2o`0001;ooooo0ol00004ooooo`;o00002Oooool2
o`0000;ooooo0_l000000ooooooo0000o`000011ooooo`007?ooool00ol0003oooooooooo`12oooo
o`;o000000?oooooo`000?l000001_ooool2o`0000kooooo1?l00003ooooo`?o00000_ooool3o`00
00Oooooo0_l0000<ooooo`Go00001_ooool3o`0000Cooooo4Ol00002ooooo`;o00000_ooool2o`00
00Kooooo0_l00005ooooo`;o00000oooool@o`000003ooooool0003o000000Co00005oooool6o`00
00gooooo0ol000001?oooooo0000o`000?ooool2o`00047ooooo000Looooo`03o`000?oooooooooo
03_ooooo0ol00007ooooo`;o00006_ooool2o`000004ooooool0003o0000o`0000Kooooo0_l00009
ooooo`;o00001oooool2o`0000Oooooo1?l000001?oooooo0000o`000?oooolBo`0000;ooooo0_l0
0002ooooo`;o00001_ooool2o`0000Gooooo0_l00004oooooaKo00005oooool2o`0000;ooooo0_l0
000>ooooo`;o000000?oooooo`000?l000000_l00012ooooo`007?ooool00ol0003oooooooooo`0k
ooooo`?o00003_ooool3o`0001;ooooo0_l000000ooooooo0000o`000002o`0000Gooooo1?l00003
ooooo`;o00000_ooool3o`0000oooooo0_l00003ooooo`oo000000?oooooo`000?l000000ol00000
1?oooooo0000o`000?l00006ooooo`;o00000_ooool2o`0000Oooooo7_l00002ooooo`;o00002_oo
ool2o`0001Cooooo0_l00006ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0A?ooool2
o`0000Kooooo0ol0000Gooooo`?o00001_ooool2o`0000;ooooo0ol00003ooooo`;o00004oooool:
o`000003ooooool0003o000000co00001oooool2o`0000_ooooo7_l00002ooooo`;o00001oooool2
o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`00000;ooooo`;o0000B_ooool0
01cooooo00?o0000ooooooooool0@Oooool2o`000003ooooool0003o000000?ooooo0_l0000Doooo
o`;o00001Oooool3o`0000[ooooo0_l00004ooooo`Co00001?ooool2o`0000Sooooo7?l00007oooo
o`;o00004?oooolIo`0000;ooooo0_l00007ooooo`;o00001?ooool5o`000003ooooool0003o0000
00Oooooo0_l0000=ooooo`?o0000?_ooool001cooooo00?o0000ooooooooool0<?ooool2o`0000oo
oooo0_l00006ooooo`;o00000_ooool3o`0000oooooo0_l00005ooooo`?o00002_ooool2o`0000Ko
oooo0_l00003ooooo`?o00000oooool2o`0000;ooooo6ol0000:ooooo`;o00002oooool2o`0000;o
oooo2ol000000ooooooo0000o`00000;o`000004ooooool0003o0000o`0000gooooo1?l000000ooo
oooo0000o`000008ooooo`;o00000_ooool2o`0000Cooooo0_l00003ooooo`?o0000?_ooool001co
oooo00?o0000ooooooooool0<?ooool2o`0000Gooooo0_l0000@ooooo`;o00000_ooool3o`0000[o
oooo0_l0000<ooooo`;o00005_ooool2o`000004ooooool0003o0000oooooaoo00002_ooool2o`00
00_ooooo0_l00004oooooaCo000000Coooooo`000?l0003ooooo0_l0000<ooooo`;o00001Oooool2
o`0000?ooooo0_l00007ooooo`;o00000_ooool5o`0000Gooooo0_l0000looooo`007?ooool00ol0
003oooooooooo`0gooooo`;o00003Oooool3o`0000Cooooo0_l00002ooooo`;o00001oooool2o`00
00_ooooo0ol0000>ooooo`;o00001?ooool2o`0000?ooooo0_l00003ooooo`Oo000000?oooooo`00
0?l000005ol0000Fooooo`;o000000?oooooo`000?l000004_l00002ooooo`;o00003_ooool2o`00
00[ooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000003
o`0000Gooooo0_l0000looooo`007?ooool00ol0003oooooooooo`0hooooo`;o00002Oooool6o`00
00Kooooo1?l00002ooooo`;o00001oooool2o`000003ooooool0003o000000;o00000_ooool2o`00
00oooooo0_l00004ooooo`?o00000_ooool2o`0000;ooooo8_l0000:ooooo`;o00002_ooool2o`00
0004ooooool0003o0000ooooo`oo00001?ooool2o`0000[ooooo0_l0000Aooooo`?o000000Cooooo
o`000?l0003ooooo0_l000000ooooooo0000o`000016ooooo`007?ooool00ol0003oooooooooo`0h
ooooo`;o00002Oooool4o`0000Cooooo1_l000001?oooooo0000o`000?ooool2o`0000Oooooo0_l0
00000ooooooo0000o`000002o`0000;ooooo0_l00008ooooo`Co00001oooool2o`000003ooooool0
003o000000;ooooo0_l00002ooooo`Wo000000?oooooo`000?l000003Ol000001?oooooo0000o`00
0?ooool3o`0000cooooo0_l000000ooooooo0000o`000004ooooo`?o00000oooool2o`0000;ooooo
3Ol0000=ooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o00002?ooool2o`0000Wooooo
0_l00015ooooo`007?ooool2o`0004_ooooo1Ol00003ooooo`;o00007Oooool4o`0000Oooooo0_l0
0003ooooo`;o00000oooool2o`000004ooooool0003o0000oooooa_o00003oooool2o`0000?ooooo
1Ol00002ooooo`;o00000_ooool8o`0000?ooooo1?l0000;ooooo`;o00001_ooool2o`0000?ooooo
0_l0000Cooooo`;o0000AOooool001cooooo00?o0000ooooooooool0B_ooool2o`0001_ooooo1?l0
0003ooooo`;o000000?oooooo`000?l000002oooool2o`000003ooooool0003o000000?ooooo1_l0
0002oooooaWo00005?ooool2o`000003ooooool0003o000000;ooooo2ol00006ooooo`;o0000M?oo
ool001cooooo00?o0000ooooooooool0GOooool2o`0000;ooooo0_l00004ooooo`Co00000oooool5
o`000003ooooool0003o000000Sooooo0_l000000ooooooo0000o`00000To`0001Cooooo0_l00000
0ooooooo0000o`000003ooooo`So00009Oooool2o`0005Oooooo000Looooo`03o`000?oooooooooo
04Gooooo1?l00004ooooo`;o00003_ooool2o`000004ooooool0003o0000o`0000Wooooo0_l00000
0ooooooo0000o`000002o`000003ooooool0003o000000Kooooo0ol00004ooooo`Co00000_ooool@
o`000003ooooool0003o000000Wo00006?ooool2o`0000;ooooo0_l00002ooooo`Oo00004_ooool2
o`00013ooooo0_l00006ooooo`Go000000?oooooo`000?l00000BOooool001cooooo00?o0000oooo
ooooool0AOooool4o`0000Cooooo0ol0000@ooooo`;o00002?ooool4o`000004ooooool0003o0000
o`0000[ooooo0ol0000:ooooo`So000000?oooooo`000?l000000_l000000ooooooo0000o`00000<
o`0001Oooooo1ol00003ooooo`Ko00003_ooool2o`0000;ooooo0_l0000Hooooo`Go000000?ooooo
o`000?l00000BOooool001cooooo00?o0000ooooooooool0C_ooool2o`0000Oooooo0_l0000;oooo
o`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000004ooooo`;o00003Oooool2
o`0000Oooooo3?l000000ooooooo0000o`00000=o`00013ooooo0_l000000ooooooo0000o`000002
o`000004ooooool0003o0000ooooo`?o00001?ooool2o`0000Cooooo0_l00009ooooo`?o00006ooo
ool2o`0000?ooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o00001?ooool4
o`0000Wooooo0_l000000ooooooo0000o`000004ooooo`;o00001?ooool4o`0000Wooooo1?l00002
ooooo`;o00000ooooolLo`00013ooooo0_l000000ooooooo0000o`000002o`0000Cooooo1Ol00002
ooooo`;o000000Coooooo`000?l0003ooooo0_l0000:ooooo`;o00001Oooool2o`0001Cooooo1ol0
001:ooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00001Oooool3o`0000Kooooo0_l00006
ooooo`;o00002?ooool2o`0000Kooooo1?l000000ooooooo0000o`000003ooooo`;o000000?ooooo
o`000?l000000_ooool4o`0000?ooooo6ol0000:ooooo`Co00002?ooool2o`0000?ooooo1_l00005
ooooo`Co00003Oooool2o`0000?ooooo0_l0000Fooooo`Co0000Boooool001cooooo00?o0000oooo
ooooool0BOooool2o`0000Gooooo0ol0000>ooooo`;o00001?ooool2o`0000;ooooo0ol0000:oooo
o`;o00000oooool2o`0000Gooooo0_l00005ooooo`Co000000?oooooo`000?l000005_l00008oooo
o`Co00002?ooool2o`0000?ooooo0_l000000ooooooo0000o`000008ooooo`;o00001oooool5o`00
0003ooooool0003o000000gooooo0_l0000<ooooo`Go0000B_ooool001cooooo00?o0000oooooooo
ool0BOooool2o`0000Kooooo0_l0000<ooooo`;o00001_ooool2o`0000?ooooo0_l0000<ooooo`;o
00000oooool2o`0000[ooooo4_l000000ooooooo0000o`000008o`0000Kooooo0_l00003ooooo`;o
00001oooool2o`0000Kooooo0_l0000Aooooo`Ko00002Oooool2o`0000;ooooo1?l00005ooooo`;o
00001Oooool5o`0004[ooooo000Looooo`03o`000?oooooooooo05oooooo0_l00005ooooo`?o0000
2_ooool2o`0000Gooooo0_l00003ooooo`;o00002_oooolBo`0000;ooooo1?l00002ooooo`;o0000
1oooool2o`0000?ooooo0ol0000Tooooo`Co00002?ooool2o`0000;ooooo0_l00007ooooo`;o0000
E?ooool001cooooo00?o0000ooooooooool0B_ooool2o`0001[ooooo0ol00004ooooo`;o00001?oo
ool2o`0000;ooooo0_l0000Boooooa;o000000?oooooo`000?l000001?l0000;ooooo`?o000000Co
ooooo`000?l0003o00000oooool2o`0000gooooo0_l0000@ooooo`Co00001Oooool2o`0006Cooooo
000Looooo`03o`000?oooooooooo04Cooooo0_l00004ooooo`;o00001Oooool2o`0000kooooo0_l0
00000ooooooo0000o`000007ooooo`;o00002?ooool2o`0000Cooooo0_l000000ooooooo0000o`00
0009ooooo`;o00000_oooolEo`0000Kooooo0_l00003ooooo`Ko00001?ooool2o`0000Cooooo0_l0
0007ooooo`;o000000?oooooo`000?l000001oooool2o`0000Oooooo0_l000001?oooooo0000o`00
0?ooool2o`0000oooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00000_oo
ool2o`0000Kooooo0_l00003ooooo`Co00002Oooool2o`000004ooooool0003o0000ooooo`;o0000
1oooool2o`0000Oooooo0_l00005ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o
000000Coooooo`000?l0003o00000oooool@o`0000[ooooo0_l00004ooooo`Co00002oooool4o`00
00Sooooo0_l00007ooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o0000
00;o00004?ooool2o`0005?ooooo000Looooo`03o`000?oooooooooo043ooooo0_l00006ooooo`?o
000000?oooooo`000?l000001Oooool2o`0000Wooooo0_l00003ooooo`Co00003oooool2o`0000_o
oooo0_l00002ooooo`Ko00000oooool8o`000003ooooool0003o000000?o00000_ooool2o`0000co
oooo1?l0000>ooooo`?o00005?ooool2o`0000Cooooo0_l00003ooooo`;o00004?ooool2o`0005?o
oooo000Looooo`03o`000?oooooooooo04Sooooo0ol00007ooooo`;o00000oooool2o`0000Kooooo
0_l00002ooooo`Co000000?oooooo`000?l000000_l0000;ooooo`?o00003oooool2o`0000Gooooo
2ol000000ooooooo0000o`000004o`0000cooooo0_l00007ooooo`;o000000?oooooo`000?l00000
7_ooool2o`000003ooooool0003o000000?ooooo1?l0000=ooooo`;o0000E?ooool001cooooo0_l0
0019ooooo`;o00000oooool2o`0000?ooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo0_l0
0007ooooo`Co00002oooool3o`0001Kooooo4?l0000=ooooo`;o00001?ooool2o`0000;ooooo0_l0
00000ooooooo0000o`00000Jooooo`;o00000_ooool2o`000003ooooool0003o000000?ooooo1?l0
000=ooooo`;o00004oooool2o`0003oooooo000Looooo`03o`000?oooooooooo04gooooo0_l00003
ooooo`;o000000?oooooo`000?l000000_ooool5o`0000cooooo0_l00002ooooo`;o00004_ooool2
o`0000gooooo1?l00002ooooo`Go000000?oooooo`000?l000001oooool2o`0000Cooooo0ol00004
ooooo`;o00000_ooool2o`000003ooooool0003o000000gooooo0_l00003ooooo`;o00001_ooool2
o`0000Gooooo0_l00003ooooo`;o00009?ooool2o`0003oooooo000Looooo`03o`000?oooooooooo
04kooooo0ol00002ooooo`Co00000_ooool5o`00013ooooo1?l0000@ooooo`;o00003oooool3o`00
0003ooooool0003o000000?o000000Coooooo`000?l0003o00001_ooool2o`0000Cooooo0_l00009
ooooo`;o00001Oooool2o`0000Wooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o
000000?ooooo0_l00008ooooo`Co00002Oooool2o`0000Sooooo0_l0001@ooooo`007?ooool00ol0
003oooooooooo`1>ooooo`Co000000?oooooo`000?l000001_ooool2o`0000Wooooo0_l00008oooo
o`;o00006_ooool2o`0000;ooooo0_l000000ooooooo0000o`000003o`0000Kooooo0_l0000Boooo
o`;o00002_ooool2o`0000?ooooo0_l00007ooooo`Co000000?oooooo`000?l000001ol00006oooo
o`?o00002_ooool2o`0000Sooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o
00000oooool5o`0000Gooooo0ol00003ooooo`?o00004oooool3o`0000Oooooo0_l00005ooooo`?o
000000?oooooo`000?l000001?ooool2o`0000kooooo0_l000000ooooooo0000o`000002o`0000Go
oooo0_l0000?ooooo`;o00002Oooool2o`0000;ooooo1Ol000001?oooooo0000o`000?l00006oooo
o`;o00001_ooool3o`0005gooooo000Looooo`03o`000?oooooooooo05Cooooo1_l000000ooooooo
0000o`000002ooooo`?o00000oooool2o`0001;ooooo2?l00004ooooo`;o00001_ooool2o`0001;o
oooo0_l00003ooooo`;o000000?oooooo`000?l000000_l0000Qooooo`;o00002Oooool2o`0000Ko
oooo0_l00006ooooo`?o00000oooool2o`0000;ooooo0_l0001Dooooo`007?ooool00ol0003ooooo
ooooo`1Dooooo`;o00001Oooool2o`0000Sooooo0_l00009ooooo`;o00001oooool3o`0000;ooooo
0ol00006ooooo`;o00002_ooool2o`0000cooooo0_l0000Eooooo`;o00004?ooool2o`0000;ooooo
0_l00003ooooo`;o00000oooool2o`000003ooooool0003o000000Kooooo0_l00004ooooo`;o0000
1?ooool2o`0000;ooooo1?l0001Booooo`007?ooool00ol0003oooooooooo`1Tooooo`;o00002_oo
ool2o`0000oooooo0_l00004ooooo`;o00001?ooool2o`0000Cooooo0_l000000ooooooo0000o`00
0003ooooo`?o00000oooool2o`0000Gooooo0_l0000>ooooo`;o00004?ooool3o`0000?ooooo0_l0
00000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000001_ooool2o`00013ooooo0_l0
001Booooo`007?ooool00ol0003oooooooooo`1Qooooo`;o000000?oooooo`000?l000006oooool2
o`0000[ooooo0_l00007ooooo`;o00000oooool3o`0000?ooooo0_l00005ooooo`;o00006_ooool2
o`0000Cooooo1Ol000001?oooooo0000o`000?ooool2o`0000Cooooo0_l00003ooooo`;o0000JOoo
ool001cooooo00?o0000ooooooooool0HOooool2o`0001kooooo0ol0000Booooo`;o00003Oooool2
o`0001gooooo0_l00004ooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo1?l00003
ooooo`;o00004Oooool3o`000003ooooool0003o000005;ooooo000Looooo`03o`000?oooooooooo
05;ooooo0ol0000<ooooo`;o000000?oooooo`000?l000002_ooool2o`0000?ooooo0_l00003oooo
o`;o00001Oooool5o`0000;ooooo0_l00007ooooo`;o00002_ooool2o`0000Kooooo0_l00008oooo
o`;o00001Oooool2o`0001oooooo0ol0000Gooooo`?o000000?oooooo`000?l00000D_ooool001co
oooo00?o0000ooooooooool0D_ooool3o`0000Cooooo0_l00006ooooo`;o000000Coooooo`000?l0
003o00002Oooool2o`0000?ooooo0_l00003ooooo`;o00002?ooool2o`0000;ooooo0_l00006oooo
o`?o00002Oooool3o`000003ooooool0003o000000Cooooo0_l00007ooooo`;o00001Oooool2o`00
00[ooooo0_l0000Dooooo`;o00004_ooool2o`0005_ooooo000Looooo`03o`000?oooooooooo05Go
oooo0_l00002ooooo`;o00002_ooool2o`0000Gooooo0_l0000:ooooo`?o00000oooool2o`0000Go
oooo0_l00008ooooo`?o00002Oooool7o`0000Cooooo0_l00004ooooo`;o00005?ooool2o`0000oo
oooo0_l00008ooooo`;o00003Oooool2o`0005_ooooo000Looooo`03o`000?oooooooooo05Gooooo
0_l00004ooooo`;o00003oooool3o`0000Wooooo1Ol000000ooooooo0000o`000005ooooo`;o0000
1?ooool2o`0000;ooooo0_l0000:ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Kooooo
0_l00004ooooo`;o00007oooool2o`0000Sooooo0_l0000=ooooo`;o0000Foooool001cooooo00?o
0000ooooooooool0Eoooool2o`0000;ooooo0_l00003ooooo`;o00000oooool2o`0000Gooooo0ol0
000<ooooo`;o00003_ooool2o`0000Wooooo0_l0000<ooooo`;o00001?ooool4o`0000Cooooo0_l0
000booooo`;o0000HOooool001cooooo00?o0000ooooooooool0Eoooool2o`0000;ooooo0_l00003
ooooo`;o00000oooool2o`0000Wooooo0ol000000ooooooo0000o`00000:ooooo`;o00000oooool2
o`0000Oooooo0_l00006ooooo`;o00002_ooool2o`000003ooooool0003o000000?ooooo0_l0000e
ooooo`;o00000oooool3o`0000Kooooo1Ol0001Eooooo`007?ooool2o`00077ooooo0ol000001?oo
oooo0000o`000?ooool2o`0000Oooooo1?l000000ooooooo0000o`000007ooooo`;o00002oooool3
o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000007oooool2o`0000Oooooo0_l0
000@ooooo`;o00001?ooool2o`0000Kooooo1Ol0001Eooooo`007?ooool00ol0003oooooooooo`14
ooooo`;o00007?ooool2o`00013ooooo0_l000000ooooooo0000o`000009ooooo`;o00000oooool2
o`0001;ooooo0ol000000ooooooo0000o`000005ooooo`;o00007_ooool2o`0000;ooooo0_l00003
ooooo`;o000000?oooooo`000?l000004?ooool2o`000003ooooool0003o0000063ooooo000Loooo
o`03o`000?oooooooooo04Cooooo0_l0000Looooo`;o00001Oooool2o`000003ooooool0003o0000
00;o00005oooool2o`0001;ooooo0_l000000ooooooo0000o`000006ooooo`;o00003Oooool2o`00
00Sooooo0_l00009ooooo`;o00001_ooool2o`0000Sooooo1Ol00003ooooo`;o0000Hoooool001co
oooo00?o0000ooooooooool0JOooool2o`000003ooooool0003o000000;o00005Oooool2o`0000;o
oooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0ol00002ooooo`Go000000?oooooo`00
0?l000004oooool4o`0000Sooooo0_l00005ooooo`;o00000_ooool2o`0000?ooooo0_l00002oooo
o`;o00001oooool5o`0000Sooooo0_l00003ooooo`;o0000FOooool001cooooo00?o0000oooooooo
ool0GOooool2o`0002Kooooo0ol000001?oooooo0000o`000?ooool3o`000004ooooool0003o0000
ooooo`?o00000_ooool3o`0000_ooooo0_l00008ooooo`;o000000?oooooo`000?l000001Oooool2
o`0000[ooooo0_l00005ooooo`Co00000_ooool2o`0000Oooooo1?l00007ooooo`Co00000oooool2
o`0005Wooooo000Looooo`03o`000?oooooooooo05gooooo0_l0000:ooooo`;o00006oooool2o`00
0004ooooool0003o0000ooooo`;o00006?ooool2o`0000Sooooo0_l00008ooooo`;o00004Oooool3
o`0000cooooo0_l00009ooooo`Co0000G_ooool001cooooo00?o0000ooooooooool0J?ooool3o`00
00Sooooo0_l00002ooooo`;o00003oooool3o`0000Kooooo0_l00009ooooo`;o00004oooool2o`00
01_ooooo1?l00004ooooo`;o0000LOooool001cooooo00?o0000ooooooooool0J?ooool4o`0000Oo
oooo0_l00002ooooo`;o00001_ooool2o`0000Kooooo0ol00006ooooo`?o00002Oooool2o`0000Ko
oooo0_l0000;ooooo`;o00006?ooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`00
01;ooooo0_l000000ooooooo0000o`00001Jooooo`007?ooool00ol0003oooooooooo`1Zooooo`;o
00002_ooool2o`0000Oooooo0_l00004ooooo`Co00001oooool2o`000003ooooool0003o000000;o
oooo0_l000000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l000003Oooool2o`0000;o
oooo0_l00006ooooo`;o00002_ooool2o`0000Kooooo0_l00005ooooo`;o00003_ooool2o`000003
ooooool0003o000005[ooooo000Looooo`03o`000?oooooooooo05kooooo0_l00006ooooo`;o0000
1?ooool2o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l000002?ooool5o`0000Cooooo
0_l00005ooooo`;o00000_ooool2o`000003ooooool0003o000000Gooooo0ol00002ooooo`;o0000
00?oooooo`000?l000002?ooool2o`0000;ooooo0_l00004ooooo`Co00004oooool2o`0000Cooooo
0_l0001]ooooo`007?ooool00ol0003oooooooooo`1Nooooo`Co00001?ooool2o`0000?ooooo0ol0
0004ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Sooooo0_l000000ooooooo0000o`00
0004ooooo`;o00001?ooool2o`0000;ooooo0_l00002ooooo`;o00001_ooool2o`0000;ooooo0_l0
00000ooooooo0000o`000006ooooo`;o00000_ooool2o`0000Kooooo0_l0000Eooooo`;o00000_oo
ool2o`0006oooooo000Looooo`03o`000?oooooooooo053ooooo0_l0000>ooooo`;o00000_ooool2
o`0000Gooooo0_l00008ooooo`;o00005_ooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool2
o`0000cooooo0_l00007ooooo`;o00000_ooool2o`0000Wooooo1?l00005ooooo`;o00003Oooool2
o`0006oooooo000Looooo`03o`000?oooooooooo053ooooo0_l0000;ooooo`;o00001Oooool2o`00
02;ooooo0_l00002ooooo`Co00002oooool2o`0000_ooooo0_l0000Fooooo`Ko00000_ooool3o`00
00_ooooo0_l0001aooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o0000:Oooool2o`0000;o
oooo1?l0000;ooooo`;o00002_ooool2o`0000oooooo0_l0000:ooooo`;o00000_ooool2o`0000co
oooo0_l0001aooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<
c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0Koooool2o`0000Wooooo0_l00005
ooooo`?o00002?ooool3o`0000kooooo0ol00007ooooo`;o00003oooool5o`0008cooooo00001_oo
ooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40
1_ooool00ol0003oooooooooo`1_ooooo`;o00002Oooool2o`0000Gooooo0ol00009ooooo`;o0000
3_ooool3o`0000;ooooo0_l0000Dooooo`Go00002Oooool3o`0000[ooooo0_l0001dooooo`0000?o
oooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`1Rooooo`;o00004_ooool2o`0000;ooooo0_l00002ooooo`;o0000
5?ooool2o`0000?ooooo0ol00006ooooo`;o000000?oooooo`000?l000000_l0000@ooooo`;o0000
0_ooool2o`0000Kooooo1?l0000:ooooo`;o0000M?ooool00003ooooool0003ooooo00;ooooo00?o
0000ooooooooool02Oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0001Rooooo`;o0000
1_ooool2o`0000Wooooo0ol00002ooooo`;o00000_ooool2o`00013ooooo0_l00002ooooo`;o0000
0oooool3o`0000Wooooo1?l00002ooooo`;o00001Oooool2o`0000Gooooo0_l000001?oooooo0000
o`000?l00006ooooo`Co00001oooool2o`0007Oooooo00000ooooooo0000ooooo`02ooooo`03o`00
0?oooooooooo00Wooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo06[o
oooo0ol00005ooooo`;o000000?oooooo`000?l000006Oooool2o`0000Cooooo1?l00005ooooo`;o
00001?ooool2o`0000Cooooo0_l00005ooooo`;o00002?ooool2o`0000;ooooo0_l0000>ooooo`?o
0000M_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol@413o^[Zj
oooooonj^[[o410@00Kooooo00?o0000ooooooooool0J?ooool2o`000004ooooool0003o0000o`00
00Cooooo0_l0000Rooooo`Co00000oooool:o`0000Kooooo0ol0000@ooooo`;o00000_ooool3o`00
00[ooooo0_l0001fooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooookZj^_l000001_ooool00ol0003oooooooooo`1Xooooo`;o00000_ooool2o`0000gooooo0_l0
0008ooooo`;o00000oooool2o`0000Oooooo0_l00004ooooo`;o00000_ooool3o`000003ooooool0
003o000000?o00001_ooool4o`0000?ooooo0_l0000?ooooo`?o0000P_ooool00006ooooooo^k^ko
<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000oooooooo
ool0Noooool2o`0000Sooooo1?l000001?oooooo0000o`000?ooool2o`0000Cooooo0_l00004oooo
o`;o00001_ooool2o`000003ooooool0003o000000Kooooo0_l00005ooooo`;o00001Oooool2o`00
00;ooooo0_l00029ooooo`007?ooool00ol0003oooooooooo`21ooooo`;o00001?ooool2o`000004
ooooool0003o0000ooooo`;o00001?ooool2o`0000Cooooo0_l00002ooooo`;o00000_ooool6o`00
017ooooo1Ol000000ooooooo0000o`000007ooooo`?o0000Ooooool001cooooo00?o0000oooooooo
ool0NOooool2o`0000Kooooo0_l0000<ooooo`;o00000_ooool2o`0000?ooooo0_l00003ooooo`;o
00000oooool2o`000003ooooool0003o000000Sooooo0_l000000ooooooo0000o`000004ooooo`;o
000000?oooooo`000?l000001Oooool2o`0000?ooooo0ol0001oooooo`007?ooool00ol0003ooooo
ooooo`1iooooo`;o00001oooool2o`0000?ooooo0ol00005ooooo`;o00001oooool4o`0000[ooooo
0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o000000Cooooo1?l00004ooooo`Co0000
QOooool001cooooo00?o0000ooooooooool0P?ooool4o`0000?ooooo0ol00008ooooo`;o000000?o
ooooo`000?l000000oooool2o`0000[ooooo0_l00003ooooo`;o00002_ooool6o`0000?ooooo0_l0
0027ooooo`007?ooool00ol0003oooooooooo`1gooooo`;o00001oooool2o`0000Oooooo0_l00007
ooooo`;o000000?oooooo`000?l000001oooool2o`0001Oooooo0ol000000ooooooo0000o`00002<
ooooo`007?ooool00ol0003oooooooooo`1gooooo`;o00002Oooool2o`0000Gooooo0_l0000Coooo
o`;o00004oooool2o`0000?ooooo0_l0002?ooooo`007?ooool00ol0003oooooooooo`1jooooo`;o
00001_ooool2o`0001kooooo0_l0000?ooooo`;o00008Oooool2o`00077ooooo000Looooo`03o`00
0?oooooooooo07[ooooo0_l0000Vooooo`;o0000<_ooool2o`00077ooooo000Looooo`03o`000?oo
oooooooo09Oooooo0_l00002ooooo`;o00003_ooool2o`0002Kooooo0_l0001dooooo`007?ooool0
0ol0003oooooooooo`22ooooo`;o00001_ooool2o`0000_ooooo0_l00002ooooo`;o00000_ooool2
o`0000[ooooo0_l00005ooooo`;o00007oooool2o`0007Cooooo000Looooo`03o`000?oooooooooo
08;ooooo0_l00006ooooo`;o00002oooool2o`0000Gooooo0ol0000Aooooo`;o0000UOooool001co
oooo0_l0002Hooooo`;o00000_ooool2o`000003ooooool0003o000000Gooooo0_l0000;ooooo`;o
0000UOooool001cooooo00?o0000ooooooooool0Uoooool2o`0000;ooooo0_l00008ooooo`;o0000
2Oooool2o`0009Oooooo000Looooo`03o`000?oooooooooo0:3ooooo0_l00002ooooo`;o00001?oo
ool4o`0000;ooooo0_l00002ooooo`;o0000Toooool001cooooo00?o0000ooooooooool0W?ooool2
o`0000;ooooo0_l00002ooooo`;o00001?ooool4o`0000Kooooo0ol0000@ooooo`;o0000P?ooool0
01cooooo00?o0000ooooooooool0W?ooool2o`0000Kooooo0_l0000?ooooo`;o00004?ooool2o`00
083ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
Y?ooool2o`000:?ooooo000Looooo`03o`000?oooooooooo0:Cooooo0_l0002Sooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0:?ooooo0_l0002Tooooo`007?ooool00ol0003oooooooooo`2S
ooooo`;o0000Y?ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBooo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
4_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom:ooooo`005?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000
ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o0000ooooooooool0oooooomBoooo
o`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?oooooo
D_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`004_ooool00omEEEGoIVIVo`00003o
oooooeCooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Qooooo`04oa0@4?l0
003o0000ooooo`;o000000?o410@ooooooooool05_ooool4o`000008oa0@4?oooooooooooiRHV?l@
413o0000oc8b<_o<c<`3ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^08cooooo002Rooooo`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo
00?o0000ooooooooool00_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00Go8B4QoiRHV?oo
ooooV9RHob4Q8@03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0S?ooool00:;ooooo00Go0000oooo
ooooooooooooo`00000Kooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`2:ooooo`00X_oo
ool01Ol0003ooooooooooooooooo000000Wooooo1_l0000<ooooo`03o`000?oooooooooo00Gooooo
00?oZJVYoa0@4?ooool00_ooool01Olb<S;oV9RHoooooonHV9So<S8b00?ooooo00Go0000oooooooo
ooooooooo`00002<ooooo`00X_ooool01Ol0003oQhN7oooooonYZJWo000001_ooooo00?o0000oooo
ooooool01?ooool00ol@413o0000okZj^P03ooooo`05olc<c?l0003o0000o`000?o<c<`00oooool0
1Ol0003ooooooooooooooooo000008cooooo002Qooooo`03oa0@4?l0003oMgMg00;o000000?oV9RH
ooooooooool06Oooool00ol0003oooooooooo`05ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@
okZj^_oooooo^[Zjoa0@4003ooooo`05oa0@4?ooooooooooooooool@4100S?ooool00<;ooooo00?o
0000ooooooooool00_ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00Go0000okZj^_oooooo
^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0S?ooool00<3ooooo00?oEEEEofIVI_l0
00001?ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0S?ooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1386) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.38329 .31108 Mdot
.39921 .31129 Mdot
.46094 .66221 Mdot
.58645 .46555 Mdot
.6469 .75261 Mdot
.43825 .63489 Mdot
.37078 .52732 Mdot
.34676 .48573 Mdot
.45887 .67107 Mdot
.35995 .4347 Mdot
.3247 .4973 Mdot
.52943 .45603 Mdot
.3413 .52378 Mdot
.59265 .42592 Mdot
.86007 .57559 Mdot
.67157 .44625 Mdot
.38355 .31247 Mdot
.59021 .59101 Mdot
.65115 .40614 Mdot
.43383 .62049 Mdot
.36759 .35619 Mdot
.59478 .43158 Mdot
.39486 .36344 Mdot
.59283 .4254 Mdot
.60833 .46792 Mdot
.40652 .36624 Mdot
.44755 .39286 Mdot
.63627 .46204 Mdot
.64706 .42651 Mdot
.33425 .48486 Mdot
.68356 .54664 Mdot
.80201 .65057 Mdot
.68753 .43535 Mdot
.79255 .54433 Mdot
.36108 .50965 Mdot
.55836 .31111 Mdot
.4464 .64267 Mdot
.32956 .50736 Mdot
.32528 .5138 Mdot
.35744 .4867 Mdot
.33892 .49526 Mdot
.39725 .34784 Mdot
.30174 .3495 Mdot
.37872 .638 Mdot
.63094 .49282 Mdot
.48671 .80842 Mdot
.50109 .36246 Mdot
.57952 .41327 Mdot
.43914 .35091 Mdot
.52206 .70149 Mdot
.34123 .62859 Mdot
.35943 .53625 Mdot
.41715 .63666 Mdot
.21339 .27199 Mdot
.34115 .53606 Mdot
.54334 .45568 Mdot
.44984 .6541 Mdot
.61008 .43231 Mdot
.59611 .42228 Mdot
.56928 .23063 Mdot
.57379 .4877 Mdot
.58879 .64907 Mdot
.44645 .32835 Mdot
.4674 .55717 Mdot
.44289 .66337 Mdot
.32127 .51221 Mdot
.41213 .32018 Mdot
.34782 .52998 Mdot
.66984 .50028 Mdot
.42628 .69222 Mdot
.57502 .41535 Mdot
.32415 .50021 Mdot
.38871 .37799 Mdot
.63828 .43703 Mdot
.44871 .74799 Mdot
.44849 .81688 Mdot
.63716 .67123 Mdot
.55643 .29214 Mdot
.56117 .22567 Mdot
.53934 .73157 Mdot
.64628 .47114 Mdot
.69584 .60712 Mdot
.45128 .80912 Mdot
.44459 .37637 Mdot
.66766 .41392 Mdot
.56409 .60568 Mdot
.63714 .44223 Mdot
.55847 .82678 Mdot
.55823 .43545 Mdot
.57398 .57054 Mdot
.47166 .66902 Mdot
.42749 .355 Mdot
.5892 .46971 Mdot
.6362 .41857 Mdot
.61752 .23908 Mdot
.59954 .39237 Mdot
.60171 .44755 Mdot
.44309 .34907 Mdot
.35653 .53801 Mdot
.54951 .4568 Mdot
.40317 .59126 Mdot
.48055 .6287 Mdot
.59418 .48834 Mdot
.47222 .67899 Mdot
.40872 .38518 Mdot
.63533 .41881 Mdot
.32611 .52369 Mdot
.57737 .48013 Mdot
.21695 .48967 Mdot
.38174 .31926 Mdot
.64752 .44678 Mdot
.63161 .64025 Mdot
.48706 .23628 Mdot
.43431 .36083 Mdot
.38616 .59206 Mdot
.64817 .40627 Mdot
.61303 .44699 Mdot
.41761 .32055 Mdot
.49289 .6438 Mdot
.53091 .82674 Mdot
.44588 .3472 Mdot
.33043 .48205 Mdot
.3768 .37339 Mdot
.53232 .42626 Mdot
.43486 .66528 Mdot
.38052 .61744 Mdot
.23024 .4483 Mdot
.71146 .54024 Mdot
.63431 .44205 Mdot
.3125 .362 Mdot
.46223 .6178 Mdot
.42091 .34167 Mdot
.34794 .52538 Mdot
.66218 .39351 Mdot
.38735 .32992 Mdot
.31726 .50611 Mdot
.62042 .65752 Mdot
.28205 .5985 Mdot
.38662 .36724 Mdot
.48099 .46111 Mdot
.33537 .55218 Mdot
.36826 .51343 Mdot
.79506 .38697 Mdot
.41715 .32628 Mdot
.60038 .62702 Mdot
.35225 .51528 Mdot
.73482 .50058 Mdot
.61939 .49736 Mdot
.67476 .59381 Mdot
.25887 .31039 Mdot
.78811 .51908 Mdot
.30218 .64778 Mdot
.6202 .63021 Mdot
.31927 .55439 Mdot
.599 .45939 Mdot
.4159 .37148 Mdot
.39985 .36458 Mdot
.57504 .48808 Mdot
.6094 .47628 Mdot
.57017 .41725 Mdot
.60143 .40035 Mdot
.68887 .49933 Mdot
.59225 .38729 Mdot
.49688 .33746 Mdot
.42646 .36019 Mdot
.58966 .46113 Mdot
.41821 .65695 Mdot
.60247 .51178 Mdot
.33228 .49454 Mdot
.60356 .43476 Mdot
.58867 .46712 Mdot
.5977 .49858 Mdot
.36337 .52972 Mdot
.77507 .68731 Mdot
.45228 .24839 Mdot
.75643 .68731 Mdot
.54207 .54186 Mdot
.42573 .67988 Mdot
.63269 .45192 Mdot
.59474 .64543 Mdot
.63169 .30762 Mdot
.5757 .45886 Mdot
.12949 .58856 Mdot
.59619 .44152 Mdot
.68282 .74392 Mdot
.604 .523 Mdot
.77652 .63615 Mdot
.69738 .58689 Mdot
.61256 .46219 Mdot
.34814 .40301 Mdot
.36375 .54952 Mdot
.40212 .62398 Mdot
.3408 .49944 Mdot
.41844 .64956 Mdot
.45686 .65973 Mdot
.44573 .57291 Mdot
.52546 .44952 Mdot
.63646 .5043 Mdot
.56506 .41525 Mdot
.46136 .69356 Mdot
.45541 .35842 Mdot
.63268 .64886 Mdot
.40785 .30692 Mdot
.70391 .78354 Mdot
.41788 .74859 Mdot
.36137 .47796 Mdot
.60947 .66717 Mdot
.48289 .64768 Mdot
.46573 .67523 Mdot
.62814 .64065 Mdot
.6189 .41392 Mdot
.41278 .32684 Mdot
.80177 .44161 Mdot
.21631 .53226 Mdot
.75136 .26091 Mdot
.44292 .35454 Mdot
.32778 .39814 Mdot
.34017 .4862 Mdot
.45888 .63986 Mdot
.61004 .44763 Mdot
.62454 .4224 Mdot
.36337 .33457 Mdot
.57661 .41233 Mdot
.38782 .27419 Mdot
.6135 .45495 Mdot
.28555 .55106 Mdot
.64197 .65423 Mdot
.44693 .57351 Mdot
.73696 .53937 Mdot
.43031 .37954 Mdot
.70101 .29467 Mdot
.45604 .68294 Mdot
.6282 .30211 Mdot
.31797 .51949 Mdot
.60583 .66157 Mdot
.43887 .67823 Mdot
.63375 .64131 Mdot
.61218 .38563 Mdot
.42888 .62909 Mdot
.61813 .61961 Mdot
.60529 .56684 Mdot
.63205 .49905 Mdot
.18078 .47629 Mdot
.35762 .48958 Mdot
.39414 .3022 Mdot
.56666 .4707 Mdot
.44857 .68924 Mdot
.66391 .38987 Mdot
.32737 .70853 Mdot
.30923 .58579 Mdot
.4648 .61727 Mdot
.50255 .59425 Mdot
.5926 .65733 Mdot
.34841 .67182 Mdot
.31513 .37626 Mdot
.39919 .30877 Mdot
.59462 .39146 Mdot
.80258 .61119 Mdot
.35212 .51641 Mdot
.5697 .46933 Mdot
.65284 .70321 Mdot
.35708 .52536 Mdot
.61233 .43275 Mdot
.31197 .51378 Mdot
.39902 .36393 Mdot
.51624 .2084 Mdot
.4228 .32206 Mdot
.58157 .40561 Mdot
.32981 .53192 Mdot
.49226 .66438 Mdot
.4075 .36106 Mdot
.60748 .40984 Mdot
.63483 .46056 Mdot
.52046 .58181 Mdot
.59012 .45274 Mdot
.7414 .71275 Mdot
.61339 .45881 Mdot
.46517 .64991 Mdot
.6337 .48288 Mdot
.3944 .2223 Mdot
.43812 .57153 Mdot
.41348 .3224 Mdot
.4703 .61708 Mdot
.45202 .66716 Mdot
.45542 .76598 Mdot
.30096 .52659 Mdot
.65399 .42113 Mdot
.4392 .68834 Mdot
.73838 .43824 Mdot
.32132 .54402 Mdot
.5613 .47393 Mdot
.4571 .44733 Mdot
.51638 .69764 Mdot
.41989 .6311 Mdot
.61658 .36357 Mdot
.39535 .37779 Mdot
.59405 .47367 Mdot
.47371 .67207 Mdot
.53038 .40803 Mdot
.65298 .44257 Mdot
.30336 .28808 Mdot
.52122 .59102 Mdot
.34342 .54851 Mdot
.57776 .51065 Mdot
.56737 .4404 Mdot
.42781 .63385 Mdot
.42696 .37849 Mdot
.32379 .54725 Mdot
.40019 .35332 Mdot
.7779 .62045 Mdot
.18705 .47927 Mdot
.62642 .55124 Mdot
.63753 .63883 Mdot
.54269 .65509 Mdot
.78314 .62106 Mdot
.63044 .21793 Mdot
.73429 .34476 Mdot
.80954 .52594 Mdot
.48163 .66898 Mdot
.57411 .69016 Mdot
.45057 .66159 Mdot
.62406 .47564 Mdot
.43507 .66252 Mdot
.81004 .60034 Mdot
.61074 .45363 Mdot
.4347 .65196 Mdot
.67108 .27087 Mdot
.59496 .47018 Mdot
.40352 .31062 Mdot
.69947 .77027 Mdot
.47423 .17656 Mdot
.30598 .57896 Mdot
.46678 .63138 Mdot
.7566 .39168 Mdot
.60009 .44867 Mdot
.63404 .48199 Mdot
.42497 .36992 Mdot
.68024 .40878 Mdot
.58596 .63399 Mdot
.60208 .66719 Mdot
.38885 .51458 Mdot
.64101 .67512 Mdot
.57456 .50912 Mdot
.41074 .36235 Mdot
.6771 .5076 Mdot
.47238 .75088 Mdot
.53073 .69329 Mdot
.37696 .48577 Mdot
.69928 .7692 Mdot
.46402 .34062 Mdot
.28743 .48825 Mdot
.45957 .71952 Mdot
.43248 .34308 Mdot
.79622 .66692 Mdot
.33764 .50302 Mdot
.17573 .5085 Mdot
.35967 .40293 Mdot
.61812 .41609 Mdot
.32589 .54198 Mdot
.6176 .37072 Mdot
.49436 .17503 Mdot
.19276 .58418 Mdot
.53561 .37033 Mdot
.55817 .44521 Mdot
.45578 .73732 Mdot
.60624 .43995 Mdot
.38698 .74182 Mdot
.61905 .46163 Mdot
.40365 .35129 Mdot
.35599 .43515 Mdot
.38447 .57201 Mdot
.40558 .25613 Mdot
.35652 .6921 Mdot
.61833 .62652 Mdot
.61581 .45261 Mdot
.61524 .41516 Mdot
.58919 .62161 Mdot
.39365 .36708 Mdot
.57548 .41017 Mdot
.69765 .28532 Mdot
.63079 .41308 Mdot
.33252 .49832 Mdot
.34156 .31866 Mdot
.47952 .34779 Mdot
.62146 .40055 Mdot
.4312 .38968 Mdot
.37015 .4871 Mdot
.33071 .52908 Mdot
.58608 .5184 Mdot
.34546 .47715 Mdot
.58827 .44012 Mdot
.20682 .61573 Mdot
.38114 .357 Mdot
.25748 .34098 Mdot
.39607 .3302 Mdot
.54392 .28386 Mdot
.35937 .52991 Mdot
.29852 .5941 Mdot
.58583 .37607 Mdot
.33754 .50835 Mdot
.37737 .38626 Mdot
.66009 .46889 Mdot
.65421 .48269 Mdot
.78873 .42793 Mdot
.4734 .6494 Mdot
.51367 .58224 Mdot
.33453 .48425 Mdot
.58719 .41479 Mdot
.62678 .39597 Mdot
.36769 .48557 Mdot
.20994 .58147 Mdot
.53286 .18805 Mdot
.61267 .45665 Mdot
.41221 .349 Mdot
.41717 .33981 Mdot
.59208 .50422 Mdot
.5979 .48628 Mdot
.4294 .66903 Mdot
.4963 .65077 Mdot
.41657 .67069 Mdot
.51131 .58535 Mdot
.29626 .58671 Mdot
.58112 .79676 Mdot
.35784 .48716 Mdot
.30441 .41356 Mdot
.58269 .57316 Mdot
.5603 .41699 Mdot
.47019 .62983 Mdot
.56879 .44063 Mdot
.5817 .44825 Mdot
.30662 .49829 Mdot
.66221 .7248 Mdot
.46713 .38994 Mdot
.42347 .38364 Mdot
.33653 .55525 Mdot
.57071 .51213 Mdot
.32592 .46326 Mdot
.60611 .65828 Mdot
.78005 .48298 Mdot
.31967 .5106 Mdot
.41056 .31366 Mdot
.35826 .4962 Mdot
.62905 .42136 Mdot
.56216 .39565 Mdot
.42917 .33955 Mdot
.58102 .63874 Mdot
.68122 .41748 Mdot
.61376 .43585 Mdot
.2357 .3273 Mdot
.761 .49744 Mdot
.27266 .5354 Mdot
.61114 .46038 Mdot
.64086 .41244 Mdot
.57903 .61874 Mdot
.63042 .41415 Mdot
.56251 .43435 Mdot
.49579 .24185 Mdot
.24431 .45215 Mdot
.61705 .66994 Mdot
.21239 .61206 Mdot
.44216 .35119 Mdot
.79838 .63209 Mdot
.45436 .62909 Mdot
.39054 .54073 Mdot
.48865 .19182 Mdot
.41517 .64251 Mdot
.30164 .6537 Mdot
.79356 .64717 Mdot
.40247 .58424 Mdot
.44776 .60176 Mdot
.45929 .38928 Mdot
.5889 .40393 Mdot
.61405 .44389 Mdot
.5915 .64242 Mdot
.4092 .32967 Mdot
.50212 .54659 Mdot
.34491 .78065 Mdot
.59596 .43422 Mdot
.29441 .3034 Mdot
.25768 .67049 Mdot
.50916 .7067 Mdot
.60596 .64403 Mdot
.59205 .66532 Mdot
.61737 .45091 Mdot
.46179 .23823 Mdot
.40769 .36643 Mdot
.60583 .41015 Mdot
.58706 .38916 Mdot
.47036 .63984 Mdot
.37938 .32945 Mdot
.49239 .64165 Mdot
.32686 .62892 Mdot
.73931 .70368 Mdot
.15396 .47631 Mdot
.34734 .53804 Mdot
.36949 .75455 Mdot
.31217 .53137 Mdot
.7007 .6068 Mdot
.4259 .61582 Mdot
.59288 .47845 Mdot
.42155 .37967 Mdot
.58183 .41932 Mdot
.59801 .48462 Mdot
.61661 .41372 Mdot
.61702 .39769 Mdot
.15467 .42729 Mdot
.62229 .6283 Mdot
.64489 .39131 Mdot
.4649 .65485 Mdot
.46551 .806 Mdot
.42019 .79317 Mdot
.61132 .41638 Mdot
.62691 .45958 Mdot
.3832 .34744 Mdot
.57221 .48254 Mdot
.31508 .53983 Mdot
.42552 .31409 Mdot
.64076 .43202 Mdot
.64766 .79671 Mdot
.6492 .43068 Mdot
.77472 .65432 Mdot
.35652 .49563 Mdot
.20879 .51141 Mdot
.57774 .38414 Mdot
.32014 .58465 Mdot
.51401 .58231 Mdot
.43441 .67579 Mdot
.3083 .51778 Mdot
.44403 .64417 Mdot
.31423 .75967 Mdot
.54095 .41789 Mdot
.60077 .46202 Mdot
.56358 .41184 Mdot
.42548 .67998 Mdot
.5896 .81992 Mdot
.36865 .69103 Mdot
.54499 .40195 Mdot
.42229 .66322 Mdot
.45 .37923 Mdot
.77372 .44807 Mdot
.39441 .34011 Mdot
.62023 .60754 Mdot
.33892 .48909 Mdot
.58221 .64062 Mdot
.7208 .65972 Mdot
.38653 .31334 Mdot
.37185 .31546 Mdot
.45339 .63099 Mdot
.37876 .43005 Mdot
.47797 .13391 Mdot
.35774 .40108 Mdot
.71236 .56591 Mdot
.41873 .3659 Mdot
.6435 .42213 Mdot
.70543 .63945 Mdot
.36342 .41865 Mdot
.44267 .64719 Mdot
.57549 .44708 Mdot
.51629 .20528 Mdot
.42953 .66949 Mdot
.55574 .4191 Mdot
.46917 .65554 Mdot
.345 .49632 Mdot
.47599 .63577 Mdot
.36782 .30541 Mdot
.64119 .44748 Mdot
.51741 .12082 Mdot
.57018 .67686 Mdot
.6007 .45262 Mdot
.34643 .55364 Mdot
.25307 .61205 Mdot
.57799 .47215 Mdot
.62612 .62339 Mdot
.42909 .65002 Mdot
.39822 .42678 Mdot
.61525 .45865 Mdot
.4213 .66165 Mdot
.3771 .31659 Mdot
.32146 .55922 Mdot
.60815 .2363 Mdot
.30616 .5729 Mdot
.42737 .37064 Mdot
.50863 .49697 Mdot
.31489 .4956 Mdot
.63964 .41122 Mdot
.60098 .39148 Mdot
.41251 .34543 Mdot
.64239 .58882 Mdot
.61118 .49158 Mdot
.64082 .47539 Mdot
.4662 .64093 Mdot
.44038 .64272 Mdot
.71573 .33982 Mdot
.49161 .65474 Mdot
.56726 .39271 Mdot
.41003 .34473 Mdot
.58696 .46877 Mdot
.38077 .34569 Mdot
.5728 .48249 Mdot
.55487 .51647 Mdot
.39473 .36808 Mdot
.29622 .52036 Mdot
.57795 .44904 Mdot
.68485 .45441 Mdot
.57471 .47709 Mdot
.59519 .40303 Mdot
.43398 .66996 Mdot
.60132 .64891 Mdot
.56946 .39964 Mdot
.58313 .67426 Mdot
.63068 .6493 Mdot
.36733 .57385 Mdot
.47199 .64245 Mdot
.6027 .62114 Mdot
.2661 .69093 Mdot
.42072 .63823 Mdot
.58884 .63643 Mdot
.42201 .79399 Mdot
.36188 .51256 Mdot
.393 .37715 Mdot
.5977 .47181 Mdot
.76362 .619 Mdot
.49356 .35324 Mdot
.47802 .61346 Mdot
.60997 .45727 Mdot
.5699 .46579 Mdot
.44894 .35661 Mdot
.35555 .80406 Mdot
.42589 .69164 Mdot
.65252 .42892 Mdot
.39789 .31355 Mdot
.36029 .82401 Mdot
.46012 .65341 Mdot
.58882 .64127 Mdot
.36493 .50672 Mdot
.44936 .39982 Mdot
.2277 .44886 Mdot
.3635 .53949 Mdot
.41642 .70247 Mdot
.33254 .62392 Mdot
.6416 .39748 Mdot
.46725 .62477 Mdot
.77169 .31116 Mdot
.70342 .4647 Mdot
.47851 .56692 Mdot
.75948 .40098 Mdot
.43376 .35094 Mdot
.31309 .5341 Mdot
.62182 .63118 Mdot
.44261 .36326 Mdot
.38124 .31512 Mdot
.36394 .48479 Mdot
.47064 .25449 Mdot
.45242 .44581 Mdot
.32696 .50658 Mdot
.77249 .54229 Mdot
.5897 .77311 Mdot
.4676 .62698 Mdot
.58647 .63229 Mdot
.70369 .67862 Mdot
.39728 .35055 Mdot
.73187 .75224 Mdot
.79229 .42517 Mdot
.60146 .44741 Mdot
.60843 .6252 Mdot
.59497 .80891 Mdot
.39747 .81335 Mdot
.35646 .52925 Mdot
.38082 .56339 Mdot
.58545 .64913 Mdot
.5663 .46781 Mdot
.76196 .46432 Mdot
.62982 .47938 Mdot
.34375 .48829 Mdot
.64244 .26163 Mdot
.38595 .31204 Mdot
.36827 .49771 Mdot
.78211 .47548 Mdot
.58854 .43826 Mdot
.57704 .4513 Mdot
.7493 .55456 Mdot
.44242 .37205 Mdot
.4344 .67624 Mdot
.61896 .38819 Mdot
.60984 .43578 Mdot
.55466 .41109 Mdot
.56793 .49992 Mdot
.49577 .22541 Mdot
.62402 .47162 Mdot
.42102 .75897 Mdot
.55885 .45264 Mdot
.58011 .4356 Mdot
.42602 .39009 Mdot
.14472 .49623 Mdot
.34517 .64239 Mdot
.60582 .43572 Mdot
.64633 .41729 Mdot
.36709 .49814 Mdot
.4068 .44667 Mdot
.39198 .43657 Mdot
.40816 .4255 Mdot
.74619 .36685 Mdot
.62961 .50151 Mdot
.40752 .321 Mdot
.61617 .61686 Mdot
.65152 .41841 Mdot
.40506 .31769 Mdot
.60868 .4981 Mdot
.42835 .67042 Mdot
.41973 .64069 Mdot
.67913 .50163 Mdot
.6049 .61917 Mdot
.3405 .28454 Mdot
.3008 .41268 Mdot
.42448 .63618 Mdot
.60267 .46449 Mdot
.31658 .568 Mdot
.47061 .67381 Mdot
.4138 .58453 Mdot
.65817 .62861 Mdot
.41563 .37368 Mdot
.42845 .35899 Mdot
.67253 .59599 Mdot
.30373 .63551 Mdot
.30587 .26745 Mdot
.34507 .4947 Mdot
.63131 .38487 Mdot
.332 .38471 Mdot
.4309 .36191 Mdot
.70799 .62056 Mdot
.60821 .62289 Mdot
.35761 .52303 Mdot
.41471 .715 Mdot
.38536 .3368 Mdot
.37201 .3375 Mdot
.56875 .48691 Mdot
.61734 .42868 Mdot
.73002 .33734 Mdot
.57568 .66975 Mdot
.3694 .53129 Mdot
.58609 .63762 Mdot
.42822 .61511 Mdot
.63837 .46719 Mdot
.39679 .36768 Mdot
.56967 .78687 Mdot
.64789 .40979 Mdot
.45055 .67514 Mdot
.43161 .35237 Mdot
.5924 .65822 Mdot
.62137 .61767 Mdot
.60605 .40123 Mdot
.68622 .30976 Mdot
.3314 .51073 Mdot
.42947 .33358 Mdot
.31472 .46833 Mdot
.62324 .48442 Mdot
.62236 .43509 Mdot
.64528 .51027 Mdot
.36875 .5329 Mdot
.27033 .47123 Mdot
.63618 .64054 Mdot
.41464 .33122 Mdot
.6251 .46794 Mdot
.59087 .62511 Mdot
.31613 .41404 Mdot
.45415 .61378 Mdot
.47871 .63931 Mdot
.6152 .61347 Mdot
.6101 .63686 Mdot
.63253 .63406 Mdot
.734 .75115 Mdot
.44571 .3389 Mdot
.46742 .34697 Mdot
.65841 .46442 Mdot
.70106 .5787 Mdot
.6503 .3924 Mdot
.33103 .55096 Mdot
.47351 .65354 Mdot
.585 .48004 Mdot
.62213 .40263 Mdot
.60025 .52453 Mdot
.27422 .31732 Mdot
.48486 .37906 Mdot
.37869 .3253 Mdot
.56516 .39215 Mdot
.46431 .63148 Mdot
.72086 .77896 Mdot
.81373 .43392 Mdot
.57436 .38556 Mdot
.45415 .44116 Mdot
.40193 .37365 Mdot
.35935 .48694 Mdot
.74665 .59663 Mdot
.36263 .50755 Mdot
.41844 .33398 Mdot
.62825 .4715 Mdot
.29434 .42941 Mdot
.57891 .61653 Mdot
.58798 .41111 Mdot
.34896 .49026 Mdot
.57493 .41667 Mdot
.3679 .53331 Mdot
.75998 .6385 Mdot
.75231 .3113 Mdot
.59724 .44223 Mdot
.66446 .41681 Mdot
.74095 .3315 Mdot
.60544 .41522 Mdot
.5823 .60458 Mdot
.40224 .37414 Mdot
.6498 .26138 Mdot
.665 .46701 Mdot
.70881 .38174 Mdot
.62927 .48212 Mdot
.61941 .23373 Mdot
.62359 .43201 Mdot
.49993 .71434 Mdot
.64555 .44821 Mdot
.56216 .42781 Mdot
.3378 .53797 Mdot
.36875 .49964 Mdot
.40034 .38656 Mdot
.46083 .68557 Mdot
.76828 .6687 Mdot
.61714 .43634 Mdot
.31856 .59513 Mdot
.25112 .47054 Mdot
.60919 .63946 Mdot
.41354 .33367 Mdot
.40746 .83774 Mdot
.33011 .48518 Mdot
.78255 .38185 Mdot
.72272 .354 Mdot
.25197 .40459 Mdot
.66951 .69199 Mdot
.25766 .63842 Mdot
.59891 .66085 Mdot
.59734 .49792 Mdot
.60057 .74203 Mdot
.48994 .72135 Mdot
.6486 .60818 Mdot
.30817 .51153 Mdot
.66027 .31428 Mdot
.64522 .73204 Mdot
.61269 .60707 Mdot
.58747 .65834 Mdot
.36144 .5365 Mdot
.46278 .59961 Mdot
.52636 .44539 Mdot
.61406 .62927 Mdot
.42208 .67838 Mdot
.42569 .62861 Mdot
.41676 .67734 Mdot
.40484 .36715 Mdot
.8011 .41978 Mdot
.35009 .46701 Mdot
.33947 .54892 Mdot
.5056 .61642 Mdot
.61569 .34809 Mdot
.40391 .29784 Mdot
.45354 .63772 Mdot
.4878 .64483 Mdot
.39992 .37515 Mdot
.54913 .47244 Mdot
.53786 .45812 Mdot
.60033 .43516 Mdot
.59687 .64614 Mdot
.62215 .42646 Mdot
.42343 .66134 Mdot
.35128 .53319 Mdot
.48559 .64761 Mdot
.34627 .55562 Mdot
.54985 .80206 Mdot
.61009 .40678 Mdot
.64203 .45019 Mdot
.20363 .37885 Mdot
.37127 .35383 Mdot
.48619 .80261 Mdot
.28589 .52689 Mdot
.45282 .66074 Mdot
.56288 .4365 Mdot
.4208 .31014 Mdot
.57218 .6599 Mdot
.15937 .48405 Mdot
.60084 .48889 Mdot
.39112 .35245 Mdot
.63652 .46667 Mdot
.70985 .47298 Mdot
.35489 .23047 Mdot
.4019 .34496 Mdot
.28312 .29348 Mdot
.64735 .42293 Mdot
.29459 .70872 Mdot
.55888 .46406 Mdot
.66734 .53594 Mdot
.61128 .4915 Mdot
.44253 .35121 Mdot
.60228 .43223 Mdot
.41945 .31067 Mdot
.43616 .62662 Mdot
.36299 .49408 Mdot
.4274 .36818 Mdot
.60676 .39388 Mdot
.47813 .07105 Mdot
.35022 .50014 Mdot
.61295 .44988 Mdot
.36308 .52707 Mdot
.40511 .3285 Mdot
.4391 .35493 Mdot
.3899 .79988 Mdot
.32699 .63171 Mdot
.34495 .49827 Mdot
.63797 .46692 Mdot
.32892 .72462 Mdot
.60463 .47842 Mdot
.74275 .44147 Mdot
.54328 .45272 Mdot
.64185 .47913 Mdot
.43035 .80375 Mdot
.34382 .54891 Mdot
.30573 .26489 Mdot
.41886 .8111 Mdot
.4627 .80575 Mdot
.36529 .35108 Mdot
.60756 .60657 Mdot
.78926 .67431 Mdot
.29476 .58536 Mdot
.42207 .667 Mdot
.57876 .47662 Mdot
.35499 .31657 Mdot
.32891 .51533 Mdot
.60701 .65552 Mdot
.59842 .44275 Mdot
.48299 .63775 Mdot
.59107 .20332 Mdot
.32264 .55546 Mdot
.39812 .34352 Mdot
.44969 .37333 Mdot
.21329 .66692 Mdot
.61568 .46362 Mdot
.64222 .44277 Mdot
.33959 .48846 Mdot
.23573 .60546 Mdot
.62111 .66251 Mdot
.66858 .26689 Mdot
.3452 .5006 Mdot
.46967 .51631 Mdot
.4098 .31654 Mdot
.56842 .46037 Mdot
.6606 .77566 Mdot
.41296 .72089 Mdot
.22236 .35977 Mdot
.59469 .64415 Mdot
.74278 .44599 Mdot
.44179 .3487 Mdot
.34954 .52164 Mdot
.27768 .61173 Mdot
.63724 .50065 Mdot
.57082 .43626 Mdot
.72852 .47595 Mdot
.37845 .57357 Mdot
.45421 .41236 Mdot
.60795 .48795 Mdot
.50837 .5805 Mdot
.59054 .48813 Mdot
.67372 .45841 Mdot
.54451 .42543 Mdot
.62991 .44074 Mdot
.39367 .36208 Mdot
.68007 .37364 Mdot
.43539 .68334 Mdot
.45305 .32725 Mdot
.46746 .52391 Mdot
.60568 .45379 Mdot
.64657 .46712 Mdot
.51846 .37444 Mdot
.29646 .6659 Mdot
.42614 .36586 Mdot
.36924 .31526 Mdot
.33985 .47779 Mdot
.54378 .4697 Mdot
.46545 .68278 Mdot
.67009 .40386 Mdot
.4394 .67182 Mdot
.39623 .36551 Mdot
.4554 .65789 Mdot
.36658 .51072 Mdot
.4605 .62271 Mdot
.29717 .58838 Mdot
.35472 .50925 Mdot
.42052 .37373 Mdot
.63761 .43239 Mdot
.34477 .55457 Mdot
.72384 .52973 Mdot
.59606 .64392 Mdot
.4916 .85341 Mdot
.64143 .4322 Mdot
.23715 .45405 Mdot
.51732 .43195 Mdot
.48692 .64662 Mdot
.34451 .23441 Mdot
.41855 .38315 Mdot
.60501 .67096 Mdot
.43946 .37762 Mdot
.77356 .46955 Mdot
.60263 .63534 Mdot
.48011 .83465 Mdot
.53755 .59712 Mdot
.75998 .49136 Mdot
.55441 .4861 Mdot
.7508 .53254 Mdot
.42431 .62353 Mdot
.3292 .51844 Mdot
.28724 .62728 Mdot
.56335 .43027 Mdot
.66434 .22829 Mdot
.4366 .38471 Mdot
.45422 .68714 Mdot
.34675 .52824 Mdot
.32507 .54883 Mdot
.65889 .43943 Mdot
.54709 .7101 Mdot
.56933 .43263 Mdot
.30396 .62344 Mdot
.75088 .38686 Mdot
.44342 .30299 Mdot
.61336 .4545 Mdot
.42914 .63228 Mdot
.63629 .46685 Mdot
.63793 .64463 Mdot
.7966 .37382 Mdot
.68365 .43374 Mdot
.27601 .52269 Mdot
.56092 .65323 Mdot
.42252 .32587 Mdot
.52372 .48043 Mdot
.27978 .54978 Mdot
.61674 .46592 Mdot
.13252 .42091 Mdot
.58936 .6315 Mdot
.60085 .73859 Mdot
.6336 .40212 Mdot
.65379 .41867 Mdot
.44424 .55073 Mdot
.22576 .43601 Mdot
.43272 .73601 Mdot
.59597 .41847 Mdot
.7103 .5147 Mdot
.35378 .54423 Mdot
.57067 .47619 Mdot
.61484 .44595 Mdot
.48772 .29026 Mdot
.32733 .55356 Mdot
.45819 .66682 Mdot
.41487 .64055 Mdot
.48171 .61654 Mdot
.63665 .65531 Mdot
.34581 .44776 Mdot
.71361 .59568 Mdot
.526 .17855 Mdot
.5826 .65994 Mdot
.62362 .4045 Mdot
.5958 .6908 Mdot
.6307 .4739 Mdot
.6114 .65149 Mdot
.32647 .55409 Mdot
.43143 .36655 Mdot
.33667 .3996 Mdot
.41636 .64563 Mdot
.6339 .50435 Mdot
.62386 .66295 Mdot
.4152 .3717 Mdot
.72671 .63765 Mdot
.42021 .32577 Mdot
.34042 .50955 Mdot
.33645 .4506 Mdot
.61036 .65514 Mdot
.40019 .32716 Mdot
.28327 .49837 Mdot
.37824 .80474 Mdot
.54282 .42024 Mdot
.31751 .44517 Mdot
.43085 .3284 Mdot
.37555 .30555 Mdot
.43267 .32511 Mdot
.58015 .41095 Mdot
.45557 .44184 Mdot
.63225 .49037 Mdot
.34649 .54836 Mdot
.46762 .65893 Mdot
.71936 .29184 Mdot
.37167 .65018 Mdot
.48828 .44722 Mdot
.60559 .38163 Mdot
.58802 .43676 Mdot
.61705 .45066 Mdot
.67129 .4579 Mdot
.27773 .57909 Mdot
.57595 .42463 Mdot
.33671 .53814 Mdot
.42705 .65446 Mdot
.59907 .49838 Mdot
.47586 .69427 Mdot
.45142 .79431 Mdot
.57941 .63981 Mdot
.38286 .51874 Mdot
.8225 .41339 Mdot
.41767 .37059 Mdot
.47217 .61842 Mdot
.42247 .64833 Mdot
.61675 .65927 Mdot
.33081 .5047 Mdot
.41779 .32462 Mdot
.73858 .44312 Mdot
.63095 .6478 Mdot
.60535 .43345 Mdot
.45536 .4297 Mdot
.69992 .25301 Mdot
.59274 .49605 Mdot
.58172 .47099 Mdot
.41361 .67519 Mdot
.61145 .72932 Mdot
.60676 .1533 Mdot
.72835 .5938 Mdot
.60431 .65259 Mdot
.59317 .61143 Mdot
.39098 .37037 Mdot
.66233 .46705 Mdot
.35875 .54351 Mdot
.35548 .3875 Mdot
.27165 .48697 Mdot
.32116 .30863 Mdot
.20948 .39954 Mdot
.58972 .4855 Mdot
.21974 .60211 Mdot
.58626 .44122 Mdot
.44606 .34007 Mdot
.39642 .36147 Mdot
.41256 .35732 Mdot
.32989 .51791 Mdot
.57729 .30484 Mdot
.32882 .53244 Mdot
.81978 .36091 Mdot
.43824 .34491 Mdot
.53304 .59946 Mdot
.45988 .63449 Mdot
.54258 .40614 Mdot
.58828 .65243 Mdot
.32128 .45064 Mdot
.66793 .50222 Mdot
.43105 .2409 Mdot
.4441 .68825 Mdot
.42384 .37368 Mdot
.24505 .61639 Mdot
.82267 .5268 Mdot
.40061 .43189 Mdot
.61152 .52661 Mdot
.74717 .59882 Mdot
.60997 .64352 Mdot
.22019 .36279 Mdot
.58542 .64414 Mdot
.34981 .49057 Mdot
.63811 .45488 Mdot
.63662 .44265 Mdot
.58943 .48845 Mdot
.611 .4108 Mdot
.32643 .47935 Mdot
.58773 .39235 Mdot
.39465 .22232 Mdot
.41644 .65305 Mdot
.61249 .56739 Mdot
.58724 .64366 Mdot
.30744 .53599 Mdot
.42623 .65517 Mdot
.29523 .66013 Mdot
.73364 .5427 Mdot
.61434 .45745 Mdot
.58319 .47944 Mdot
.77333 .35859 Mdot
.60946 .48744 Mdot
.53765 .40413 Mdot
.42157 .66451 Mdot
.49855 .43141 Mdot
.58016 .64139 Mdot
.5865 .61598 Mdot
.35638 .50953 Mdot
.39424 .36126 Mdot
.59356 .62834 Mdot
.46303 .63645 Mdot
.60231 .3821 Mdot
.59928 .3896 Mdot
.43212 .33037 Mdot
.78283 .361 Mdot
.63553 .6339 Mdot
.31723 .71809 Mdot
.41764 .37805 Mdot
.40553 .39256 Mdot
.57051 .43767 Mdot
.24143 .34317 Mdot
.36039 .32508 Mdot
.61392 .67382 Mdot
.30662 .53066 Mdot
.75247 .57601 Mdot
.31953 .5023 Mdot
.39649 .34199 Mdot
.65357 .43871 Mdot
.40434 .37058 Mdot
.61313 .46085 Mdot
.83908 .53615 Mdot
.63303 .43867 Mdot
.50696 .17753 Mdot
.66272 .58341 Mdot
.4399 .63263 Mdot
.28451 .65937 Mdot
.45399 .62945 Mdot
.42949 .37766 Mdot
.64861 .40796 Mdot
.60459 .66586 Mdot
.4133 .77738 Mdot
.35073 .35349 Mdot
.47034 .67095 Mdot
.46121 .68987 Mdot
.31652 .50513 Mdot
.60814 .49302 Mdot
.57217 .43211 Mdot
.43569 .64923 Mdot
.39746 .27521 Mdot
.38886 .33144 Mdot
.62971 .46098 Mdot
.58534 .43386 Mdot
.44393 .63174 Mdot
.36103 .79616 Mdot
.69391 .39183 Mdot
.63381 .45204 Mdot
.41064 .73211 Mdot
.33139 .55018 Mdot
.54101 .41333 Mdot
.6597 .40933 Mdot
.61207 .63511 Mdot
.54096 .22742 Mdot
.79475 .46049 Mdot
.32446 .55424 Mdot
.41995 .65087 Mdot
.62015 .46586 Mdot
.42662 .63506 Mdot
.59327 .3903 Mdot
.22975 .42424 Mdot
.45957 .6163 Mdot
.64566 .4722 Mdot
.55693 .48362 Mdot
.44351 .3706 Mdot
.58702 .48309 Mdot
.56033 .34802 Mdot
.4516 .67982 Mdot
.65777 .43695 Mdot
.67384 .29434 Mdot
.32427 .50677 Mdot
.55877 .49413 Mdot
.62921 .63901 Mdot
.74133 .4296 Mdot
.28226 .418 Mdot
.67343 .71627 Mdot
.58496 .61586 Mdot
.57548 .41749 Mdot
.4564 .6903 Mdot
.37069 .52603 Mdot
.47254 .17891 Mdot
.56598 .46371 Mdot
.34591 .48948 Mdot
.35203 .53194 Mdot
.60447 .65735 Mdot
.14343 .51522 Mdot
.62609 .40075 Mdot
.61348 .41761 Mdot
.52783 .32318 Mdot
.37101 .33138 Mdot
.62888 .42981 Mdot
.63719 .4165 Mdot
.33997 .53992 Mdot
.54393 .49018 Mdot
.66603 .33297 Mdot
.64536 .24867 Mdot
.37338 .49034 Mdot
.32976 .34936 Mdot
.44601 .61719 Mdot
.59355 .61773 Mdot
.42813 .34267 Mdot
.61886 .66516 Mdot
.4724 .63685 Mdot
.6376 .41952 Mdot
.35057 .48375 Mdot
.53065 .35578 Mdot
.36232 .53536 Mdot
.65244 .70945 Mdot
.40747 .30948 Mdot
.39654 .48871 Mdot
.12901 .45069 Mdot
.35479 .70709 Mdot
.37021 .58159 Mdot
.60919 .63895 Mdot
.39812 .61192 Mdot
.58536 .43532 Mdot
.21217 .37278 Mdot
.62292 .40557 Mdot
.66032 .2804 Mdot
.41709 .66155 Mdot
.41704 .67276 Mdot
.63569 .45455 Mdot
.74954 .39036 Mdot
.37207 .52266 Mdot
.32204 .54335 Mdot
.65384 .46368 Mdot
.33788 .50757 Mdot
.61428 .42563 Mdot
.42679 .66471 Mdot
.25091 .29592 Mdot
.60093 .43928 Mdot
.67849 .43736 Mdot
.23732 .42433 Mdot
.43229 .80983 Mdot
.55397 .65932 Mdot
.25481 .72049 Mdot
.82597 .49789 Mdot
.33726 .50983 Mdot
.64782 .47873 Mdot
.3274 .34215 Mdot
.4188 .68641 Mdot
.2833 .49231 Mdot
.63381 .42221 Mdot
.62786 .41086 Mdot
.56084 .4303 Mdot
.57807 .45664 Mdot
.17309 .46888 Mdot
.34906 .35722 Mdot
.55592 .26043 Mdot
.59481 .48469 Mdot
.74066 .52305 Mdot
.356 .49792 Mdot
.42054 .40315 Mdot
.59171 .66985 Mdot
.58849 .48478 Mdot
.46074 .35207 Mdot
.35468 .47933 Mdot
.81595 .34511 Mdot
.34765 .48687 Mdot
.45107 .66676 Mdot
.3695 .51123 Mdot
.59139 .45291 Mdot
.41714 .34027 Mdot
.42124 .49568 Mdot
.34979 .66862 Mdot
.42261 .67028 Mdot
.60122 .45285 Mdot
.52253 .60619 Mdot
.43636 .68499 Mdot
.47573 .80968 Mdot
.42378 .34526 Mdot
.70123 .52426 Mdot
.40039 .36764 Mdot
.6566 .45446 Mdot
.65612 .45265 Mdot
.35858 .47228 Mdot
.36765 .50866 Mdot
.39883 .3662 Mdot
.13865 .5557 Mdot
.63393 .63424 Mdot
.40907 .35579 Mdot
.64629 .49814 Mdot
.43882 .45869 Mdot
.41691 .34488 Mdot
.60058 .5913 Mdot
.34757 .53667 Mdot
.37954 .36538 Mdot
.55733 .44732 Mdot
.77491 .53317 Mdot
.60995 .6123 Mdot
.41745 .62299 Mdot
.70979 .64303 Mdot
.46141 .67843 Mdot
.30776 .51928 Mdot
.45169 .62893 Mdot
.34497 .54593 Mdot
.26915 .44169 Mdot
.44094 .30911 Mdot
.40891 .5731 Mdot
.31883 .49175 Mdot
.45322 .63135 Mdot
.63821 .4594 Mdot
.56929 .6761 Mdot
.6651 .44648 Mdot
.58549 .40039 Mdot
.33137 .54515 Mdot
.44178 .36534 Mdot
.36262 .32435 Mdot
.75538 .47774 Mdot
.38873 .3557 Mdot
.45424 .67514 Mdot
.43231 .22793 Mdot
.34196 .60188 Mdot
.31827 .50917 Mdot
.36531 .49723 Mdot
.62488 .47954 Mdot
.44369 .645 Mdot
.42091 .67139 Mdot
.32094 .49809 Mdot
.26359 .34104 Mdot
.67112 .42885 Mdot
.37667 .30163 Mdot
.37097 .33871 Mdot
.40518 .34467 Mdot
.42894 .32042 Mdot
.68789 .3679 Mdot
.36029 .52009 Mdot
.43943 .3715 Mdot
.62374 .48096 Mdot
.6311 .4156 Mdot
.34826 .3831 Mdot
.60818 .61498 Mdot
.60321 .49998 Mdot
.54342 .43068 Mdot
.56853 .45807 Mdot
.47619 .63394 Mdot
.60567 .35803 Mdot
.47309 .62441 Mdot
.43918 .69287 Mdot
.43079 .69164 Mdot
.2946 .58407 Mdot
.76952 .37653 Mdot
.7989 .56402 Mdot
.65177 .4244 Mdot
.2402 .64126 Mdot
.45364 .64791 Mdot
.39947 .23541 Mdot
.26519 .47755 Mdot
.56363 .44018 Mdot
.4502 .75206 Mdot
.43655 .64441 Mdot
.40634 .37827 Mdot
.63454 .42892 Mdot
.48853 .62524 Mdot
.62825 .63342 Mdot
.66099 .44269 Mdot
.45017 .61348 Mdot
.40276 .3256 Mdot
.62515 .67232 Mdot
.37455 .36276 Mdot
.43 .69173 Mdot
.58007 .51388 Mdot
.37931 .17278 Mdot
.5029 .64579 Mdot
.30689 .73377 Mdot
.5799 .53856 Mdot
.63319 .46111 Mdot
.48673 .62977 Mdot
.38795 .38593 Mdot
.30784 .52261 Mdot
.51708 .54057 Mdot
.37739 .34942 Mdot
.41698 .67279 Mdot
.47897 .6655 Mdot
.42232 .66997 Mdot
.37698 .32612 Mdot
.60868 .50374 Mdot
.38017 .33838 Mdot
.36992 .51537 Mdot
.59777 .47438 Mdot
.77973 .62392 Mdot
.23201 .59485 Mdot
.41298 .3774 Mdot
.46682 .66573 Mdot
.57943 .61712 Mdot
.59137 .44207 Mdot
.23102 .60738 Mdot
.63691 .46283 Mdot
.33694 .54819 Mdot
.50351 .23709 Mdot
.49031 .38663 Mdot
.645 .47761 Mdot
.62029 .47968 Mdot
.32149 .54141 Mdot
.60197 .44878 Mdot
.61049 .49191 Mdot
.29429 .58771 Mdot
.38191 .3258 Mdot
.598 .4316 Mdot
.46863 .65154 Mdot
.33971 .61968 Mdot
.67429 .43174 Mdot
.3949 .59765 Mdot
.69822 .52193 Mdot
.49678 .24829 Mdot
.62466 .4064 Mdot
.4682 .41429 Mdot
.57441 .44656 Mdot
.5952 .40889 Mdot
.6225 .47633 Mdot
.17534 .53058 Mdot
.45099 .61437 Mdot
.42588 .6416 Mdot
.5983 .60965 Mdot
.69739 .52345 Mdot
.61147 .62859 Mdot
.35139 .53592 Mdot
.55922 .72011 Mdot
.47122 .62293 Mdot
.39653 .33506 Mdot
.58314 .41468 Mdot
.50237 .64719 Mdot
.56701 .4518 Mdot
.5928 .45462 Mdot
.47205 .67905 Mdot
.4425 .61545 Mdot
.63563 .73138 Mdot
.61658 .61893 Mdot
.41697 .3607 Mdot
.61712 .49426 Mdot
.62904 .65581 Mdot
.62777 .40466 Mdot
.70062 .58108 Mdot
.41555 .35688 Mdot
.38134 .32932 Mdot
.36229 .32238 Mdot
.63942 .42375 Mdot
.59205 .44829 Mdot
.32838 .53329 Mdot
.42386 .38108 Mdot
.32653 .50209 Mdot
.51078 .55331 Mdot
.49809 .78119 Mdot
.63372 .42179 Mdot
.34858 .43856 Mdot
.616 .62557 Mdot
.47307 .66747 Mdot
.71467 .26794 Mdot
.59879 .60952 Mdot
.6163 .46145 Mdot
.44734 .6903 Mdot
.61845 .64835 Mdot
.70637 .49024 Mdot
.80654 .36124 Mdot
.57649 .62873 Mdot
.62298 .48115 Mdot
.55263 .4986 Mdot
.24278 .70581 Mdot
.58004 .62307 Mdot
.36383 .50397 Mdot
.64007 .42574 Mdot
.39158 .29128 Mdot
.62204 .6647 Mdot
.40776 .74657 Mdot
.43068 .64768 Mdot
.77811 .51469 Mdot
.68321 .47082 Mdot
.38138 .26815 Mdot
.59292 .61371 Mdot
.419 .32955 Mdot
.5358 .40235 Mdot
.57111 .44059 Mdot
.58277 .61713 Mdot
.3001 .52789 Mdot
.433 .66274 Mdot
.33918 .63879 Mdot
.37613 .32733 Mdot
.29907 .51731 Mdot
.47443 .6599 Mdot
.32645 .72577 Mdot
.57006 .20844 Mdot
.53606 .45004 Mdot
.22583 .66437 Mdot
.25464 .52784 Mdot
.56616 .47897 Mdot
.57305 .65589 Mdot
.34046 .55637 Mdot
.34506 .47969 Mdot
.34332 .50727 Mdot
.25844 .45984 Mdot
.41058 .42587 Mdot
.45535 .612 Mdot
.33644 .45661 Mdot
.59543 .6172 Mdot
.7539 .56243 Mdot
.58764 .39771 Mdot
.59061 .43619 Mdot
.62387 .48877 Mdot
.5843 .48434 Mdot
.57713 .43411 Mdot
.33538 .49973 Mdot
.25861 .44168 Mdot
.38509 .42768 Mdot
.41566 .35051 Mdot
.61021 .72147 Mdot
.46165 .63991 Mdot
.42232 .61248 Mdot
.62449 .64506 Mdot
.3719 .72653 Mdot
.47859 .69232 Mdot
.45527 .65953 Mdot
.57718 .49514 Mdot
.38509 .33525 Mdot
.54266 .4023 Mdot
.62159 .48037 Mdot
.44861 .67405 Mdot
.4611 .54956 Mdot
.64114 .33671 Mdot
.65691 .65736 Mdot
.62826 .67617 Mdot
.42817 .43746 Mdot
.59447 .60775 Mdot
.63545 .3939 Mdot
.35503 .23437 Mdot
.47241 .63593 Mdot
.44341 .65849 Mdot
.60928 .61739 Mdot
.24297 .33744 Mdot
.4323 .34711 Mdot
.37852 .46364 Mdot
.35866 .53539 Mdot
.65452 .44446 Mdot
.61871 .21577 Mdot
.56349 .53564 Mdot
.53655 .71428 Mdot
.34722 .5013 Mdot
.43864 .62584 Mdot
.64463 .39385 Mdot
.60999 .48182 Mdot
.61939 .6306 Mdot
.6576 .74291 Mdot
.54788 .4063 Mdot
.57477 .83328 Mdot
.75241 .3107 Mdot
.78359 .45412 Mdot
.57123 .43521 Mdot
.37989 .32706 Mdot
.41714 .62831 Mdot
.58677 .62977 Mdot
.6343 .5032 Mdot
.80829 .45256 Mdot
.43151 .33167 Mdot
.3521 .51114 Mdot
.45103 .51674 Mdot
.74456 .58494 Mdot
.58929 .40343 Mdot
.63186 .41338 Mdot
.59647 .40582 Mdot
.74128 .23857 Mdot
.47303 .62699 Mdot
.40778 .37683 Mdot
.60705 .65747 Mdot
.38909 .34874 Mdot
.43715 .63074 Mdot
.427 .57099 Mdot
.64413 .45364 Mdot
.42588 .32369 Mdot
.42066 .33106 Mdot
.3392 .48412 Mdot
.31454 .54945 Mdot
.47321 .53133 Mdot
.63171 .43818 Mdot
.48582 .67468 Mdot
.44134 .37146 Mdot
.45146 .42782 Mdot
.60406 .63381 Mdot
.34619 .53844 Mdot
.5902 .48346 Mdot
.4653 .62184 Mdot
.54681 .44658 Mdot
.42788 .36166 Mdot
.45485 .65884 Mdot
.56312 .78753 Mdot
.57984 .6327 Mdot
.62555 .41572 Mdot
.57298 .60534 Mdot
.42012 .65561 Mdot
.58298 .43692 Mdot
.34649 .75074 Mdot
.60124 .59167 Mdot
.37306 .69633 Mdot
.43084 .68768 Mdot
.31045 .58217 Mdot
.38756 .36716 Mdot
.23246 .49734 Mdot
.44557 .66349 Mdot
.29348 .69655 Mdot
.60111 .77061 Mdot
.61375 .38095 Mdot
.39838 .35142 Mdot
.25344 .53741 Mdot
.81089 .61916 Mdot
.30585 .74626 Mdot
.6135 .44904 Mdot
.49117 .6554 Mdot
.62071 .64078 Mdot
.31691 .5165 Mdot
.38465 .68545 Mdot
.64613 .64658 Mdot
.44248 .70126 Mdot
.62234 .47591 Mdot
.41133 .3266 Mdot
.33658 .53254 Mdot
.28265 .42293 Mdot
.466 .64187 Mdot
.46939 .65977 Mdot
.65725 .41718 Mdot
.60764 .62209 Mdot
.22558 .54958 Mdot
.42502 .66623 Mdot
.76162 .33713 Mdot
.43614 .60289 Mdot
.63282 .64688 Mdot
.57487 .45894 Mdot
.76254 .46863 Mdot
.65862 .47381 Mdot
.37777 .77765 Mdot
.45844 .63677 Mdot
.42249 .35978 Mdot
.57149 .4155 Mdot
.69447 .29815 Mdot
.45626 .67434 Mdot
.44721 .43929 Mdot
.51926 .68799 Mdot
.35824 .52876 Mdot
.71039 .2647 Mdot
.62388 .42421 Mdot
.37068 .5257 Mdot
.61886 .6321 Mdot
.63226 .44694 Mdot
.58956 .44946 Mdot
.44817 .35658 Mdot
.33502 .48577 Mdot
.63007 .73861 Mdot
.36609 .49451 Mdot
.35726 .49494 Mdot
.42086 .30855 Mdot
.60226 .42344 Mdot
.45313 .66728 Mdot
.43738 .64556 Mdot
.55634 .45238 Mdot
.22797 .30287 Mdot
.43219 .34196 Mdot
.41315 .63858 Mdot
.71962 .21648 Mdot
.55973 .47479 Mdot
.6974 .26044 Mdot
.64792 .7467 Mdot
.35209 .54811 Mdot
.62313 .4817 Mdot
.40307 .32752 Mdot
.45173 .7308 Mdot
.46701 .66246 Mdot
.5579 .43246 Mdot
.33693 .53073 Mdot
.62136 .62142 Mdot
.44121 .68174 Mdot
.54571 .71174 Mdot
.60913 .40795 Mdot
.45991 .75532 Mdot
.48631 .66151 Mdot
.76907 .69422 Mdot
.28687 .64437 Mdot
.40018 .35429 Mdot
.5916 .45733 Mdot
.41483 .38211 Mdot
.61186 .65771 Mdot
.45367 .51837 Mdot
.34453 .53481 Mdot
.61103 .34915 Mdot
.38114 .21568 Mdot
.422 .66962 Mdot
.4121 .37938 Mdot
.65321 .47064 Mdot
.22827 .41697 Mdot
.6182 .42288 Mdot
.57322 .51809 Mdot
.65231 .69346 Mdot
.32096 .53429 Mdot
.35612 .54224 Mdot
.58098 .44996 Mdot
.61791 .66108 Mdot
.46307 .63834 Mdot
.4393 .66867 Mdot
.69906 .78135 Mdot
.39396 .47499 Mdot
.72946 .33963 Mdot
.62649 .41063 Mdot
.44505 .69941 Mdot
.36891 .6207 Mdot
.34075 .48874 Mdot
.57821 .50451 Mdot
.46269 .68372 Mdot
.58051 .58846 Mdot
.72144 .47458 Mdot
.57283 .44236 Mdot
.65886 .47903 Mdot
.36321 .52777 Mdot
.4469 .41648 Mdot
.42908 .62901 Mdot
.54877 .42666 Mdot
.41587 .559 Mdot
.70134 .49971 Mdot
.77381 .31882 Mdot
.4167 .3608 Mdot
.54332 .69646 Mdot
.33453 .49999 Mdot
.67947 .4376 Mdot
.59472 .65665 Mdot
.42345 .6948 Mdot
.46219 .61863 Mdot
.61711 .46963 Mdot
.62446 .38693 Mdot
.73811 .31331 Mdot
.39061 .33732 Mdot
.35714 .50296 Mdot
.64077 .44097 Mdot
.34521 .41745 Mdot
.5926 .48923 Mdot
.32448 .52754 Mdot
.35925 .18289 Mdot
.66365 .45568 Mdot
.61467 .41991 Mdot
.22984 .55706 Mdot
.37491 .345 Mdot
.4353 .38088 Mdot
.63575 .21277 Mdot
.62651 .41095 Mdot
.7392 .2986 Mdot
.42058 .36531 Mdot
.43362 .35374 Mdot
.3036 .60956 Mdot
.59263 .43961 Mdot
.6865 .39832 Mdot
.34514 .54795 Mdot
.35879 .4953 Mdot
.37773 .33571 Mdot
.54329 .4103 Mdot
.31663 .54818 Mdot
.192 .51935 Mdot
.4451 .64371 Mdot
.32091 .24377 Mdot
.43287 .34013 Mdot
.37143 .56024 Mdot
.34582 .49274 Mdot
.82174 .38259 Mdot
.44082 .71839 Mdot
.64079 .4561 Mdot
.62168 .4101 Mdot
.60465 .61665 Mdot
.63012 .48792 Mdot
.41708 .67238 Mdot
.33823 .50663 Mdot
.71723 .36564 Mdot
.41206 .35758 Mdot
.6245 .434 Mdot
.40825 .76509 Mdot
.51345 .81353 Mdot
.55299 .6862 Mdot
.42385 .32818 Mdot
.40228 .36424 Mdot
.45531 .62391 Mdot
.48967 .65891 Mdot
.58811 .42287 Mdot
.31664 .53698 Mdot
.42176 .38105 Mdot
.32448 .53424 Mdot
.47362 .63805 Mdot
.45379 .66483 Mdot
.43528 .61447 Mdot
.59039 .39513 Mdot
.46217 .65814 Mdot
.5233 .78712 Mdot
.31569 .4765 Mdot
.40707 .29928 Mdot
.70061 .23534 Mdot
.28657 .42548 Mdot
.35865 .35691 Mdot
.62966 .66 Mdot
.42059 .66497 Mdot
.37145 .51378 Mdot
.588 .47098 Mdot
.57488 .47534 Mdot
.33609 .59152 Mdot
.37351 .50168 Mdot
.60927 .6566 Mdot
.36654 .53186 Mdot
.60512 .65773 Mdot
.48222 .74007 Mdot
.60086 .49421 Mdot
.59268 .38921 Mdot
.33968 .49859 Mdot
.45893 .65838 Mdot
.42769 .64496 Mdot
.57639 .63507 Mdot
.47895 .56517 Mdot
.43864 .68612 Mdot
.43616 .35645 Mdot
.66842 .35003 Mdot
.48523 .65677 Mdot
.63288 .42935 Mdot
.70996 .60072 Mdot
.20599 .37858 Mdot
.67106 .4584 Mdot
.29871 .60062 Mdot
.51014 .35047 Mdot
.56719 .426 Mdot
.20894 .36923 Mdot
.29686 .55881 Mdot
.38389 .35921 Mdot
.41731 .6518 Mdot
.51123 .62959 Mdot
.64491 .37188 Mdot
.6195 .67599 Mdot
.59947 .51203 Mdot
.42256 .32255 Mdot
.44817 .37979 Mdot
.7681 .48991 Mdot
.33257 .75876 Mdot
.61852 .64546 Mdot
.62377 .64072 Mdot
.44514 .66555 Mdot
.48941 .85679 Mdot
.59763 .52495 Mdot
.60729 .65504 Mdot
.38509 .27683 Mdot
.61998 .47432 Mdot
.66039 .54593 Mdot
.52176 .5097 Mdot
.37708 .33195 Mdot
.74474 .51439 Mdot
.45667 .67139 Mdot
.38808 .35656 Mdot
.33027 .39468 Mdot
.61226 .5014 Mdot
.41427 .35609 Mdot
.32672 .53518 Mdot
.30956 .6699 Mdot
.43915 .3595 Mdot
.70835 .58951 Mdot
.31237 .51996 Mdot
.44748 .42948 Mdot
.74513 .4807 Mdot
.23896 .7649 Mdot
.3359 .50347 Mdot
.47871 .66511 Mdot
.43661 .64672 Mdot
.44037 .66882 Mdot
.38836 .34587 Mdot
.42036 .66796 Mdot
.39187 .33853 Mdot
.24681 .68873 Mdot
.21315 .39006 Mdot
.60573 .65317 Mdot
.33897 .64149 Mdot
.40549 .33329 Mdot
.39349 .23091 Mdot
.18165 .33555 Mdot
.62605 .48152 Mdot
.35015 .47718 Mdot
.60755 .65142 Mdot
.55578 .83362 Mdot
.61314 .63876 Mdot
.78455 .41714 Mdot
.4571 .24304 Mdot
.61722 .43159 Mdot
.61992 .30652 Mdot
.58477 .65659 Mdot
.40791 .31505 Mdot
.58381 .43789 Mdot
.54603 .57233 Mdot
.61604 .63495 Mdot
.63194 .63841 Mdot
.59241 .42622 Mdot
.42392 .3738 Mdot
.46634 .66844 Mdot
.36147 .49277 Mdot
.6114 .66882 Mdot
.53473 .48139 Mdot
.6481 .48611 Mdot
.64077 .46199 Mdot
.3641 .4143 Mdot
.56993 .6427 Mdot
.33673 .51082 Mdot
.15618 .52787 Mdot
.46716 .68459 Mdot
.55017 .59021 Mdot
.76527 .3275 Mdot
.28267 .55674 Mdot
.45701 .63731 Mdot
.42862 .63368 Mdot
.57692 .43236 Mdot
.51927 .48658 Mdot
.4387 .24693 Mdot
.48067 .57721 Mdot
.42384 .61692 Mdot
.43561 .66622 Mdot
.42293 .38607 Mdot
.77868 .4597 Mdot
.65377 .49459 Mdot
.32565 .55506 Mdot
.45513 .6165 Mdot
.20905 .44321 Mdot
.60188 .61894 Mdot
.45993 .23325 Mdot
.59945 .49524 Mdot
.64161 .45188 Mdot
.34219 .52741 Mdot
.32985 .53287 Mdot
.47776 .72012 Mdot
.78251 .44336 Mdot
.51014 .3577 Mdot
.26053 .42408 Mdot
.49776 .25922 Mdot
.43778 .38344 Mdot
.41338 .3775 Mdot
.35742 .68758 Mdot
.36139 .48693 Mdot
.56775 .42218 Mdot
.39572 .36349 Mdot
.54148 .61502 Mdot
.64063 .34952 Mdot
.74651 .42616 Mdot
.71361 .28101 Mdot
.61015 .4589 Mdot
.38818 .32358 Mdot
.37396 .34299 Mdot
.37698 .31314 Mdot
.31657 .57978 Mdot
.59668 .41819 Mdot
.61124 .45432 Mdot
.57117 .42582 Mdot
.23366 .37646 Mdot
.59401 .41315 Mdot
.23574 .48658 Mdot
.45888 .50912 Mdot
.55691 .22358 Mdot
.5479 .42638 Mdot
.36358 .54283 Mdot
.605 .39992 Mdot
.61677 .66091 Mdot
.63634 .47541 Mdot
.7458 .42363 Mdot
.35168 .49805 Mdot
.68739 .3776 Mdot
.27525 .43848 Mdot
.56033 .44776 Mdot
.61611 .67265 Mdot
.26248 .49967 Mdot
.80166 .60542 Mdot
.56714 .66999 Mdot
.43604 .35378 Mdot
.45025 .64132 Mdot
.37209 .51232 Mdot
.4494 .66123 Mdot
.57363 .39687 Mdot
.35273 .69197 Mdot
.57419 .81695 Mdot
.51434 .56709 Mdot
.58351 .48292 Mdot
.65148 .50194 Mdot
.43347 .36099 Mdot
.46207 .6861 Mdot
.35658 .33437 Mdot
.58135 .40943 Mdot
.59664 .64714 Mdot
.61706 .62994 Mdot
.51917 .54676 Mdot
.70656 .73666 Mdot
.19662 .48341 Mdot
.33953 .52491 Mdot
.42785 .66888 Mdot
.58667 .65092 Mdot
.2718 .67582 Mdot
.32359 .56153 Mdot
.32828 .54665 Mdot
.35409 .50113 Mdot
.64532 .42416 Mdot
.45412 .61475 Mdot
.56275 .22428 Mdot
.42833 .69341 Mdot
.59991 .44992 Mdot
.47741 .6339 Mdot
.45333 .68676 Mdot
.58719 .63788 Mdot
.35545 .49964 Mdot
.46959 .63513 Mdot
.65738 .44886 Mdot
.41904 .36896 Mdot
.38182 .57727 Mdot
.64973 .58216 Mdot
.34335 .76336 Mdot
.64014 .53442 Mdot
.37566 .32174 Mdot
.7979 .62814 Mdot
.33593 .55118 Mdot
.25528 .35092 Mdot
.63761 .7288 Mdot
.64815 .40943 Mdot
.23999 .28613 Mdot
.41632 .61475 Mdot
.45856 .68362 Mdot
.57483 .45648 Mdot
.44308 .59944 Mdot
.62155 .43029 Mdot
.478 .64944 Mdot
.38545 .6102 Mdot
.45413 .3401 Mdot
.46031 .65387 Mdot
.55264 .42073 Mdot
.58572 .44808 Mdot
.37934 .33068 Mdot
.49155 .64084 Mdot
.63668 .50341 Mdot
.72539 .76721 Mdot
.32673 .5255 Mdot
.26315 .53278 Mdot
.7028 .61623 Mdot
.33313 .49998 Mdot
.40748 .35348 Mdot
.58858 .39864 Mdot
.6197 .63347 Mdot
.40474 .332 Mdot
.73848 .40919 Mdot
.58183 .63018 Mdot
.3119 .24029 Mdot
.37349 .33667 Mdot
.46758 .67424 Mdot
.60503 .66236 Mdot
.6384 .48574 Mdot
.41889 .68805 Mdot
.29209 .66714 Mdot
.45804 .63955 Mdot
.57424 .42869 Mdot
.36524 .65998 Mdot
.35805 .50276 Mdot
.61709 .44914 Mdot
.4548 .68332 Mdot
.30262 .60192 Mdot
.64709 .42078 Mdot
.5778 .44661 Mdot
.77474 .33827 Mdot
.46611 .20423 Mdot
.608 .63624 Mdot
.37047 .35756 Mdot
.62478 .48087 Mdot
.63049 .64207 Mdot
.53544 .76459 Mdot
.64574 .43523 Mdot
.43233 .33207 Mdot
.57348 .50336 Mdot
.49173 .64652 Mdot
.32616 .50706 Mdot
.5093 .58467 Mdot
.62845 .63414 Mdot
.28984 .7791 Mdot
.44785 .61898 Mdot
.60953 .38945 Mdot
.59706 .48885 Mdot
.70349 .6691 Mdot
.38394 .35715 Mdot
.43795 .28219 Mdot
.62535 .41529 Mdot
.24142 .36232 Mdot
.629 .44577 Mdot
.40876 .62168 Mdot
.43287 .34831 Mdot
.60993 .41606 Mdot
.39888 .53708 Mdot
.67724 .4326 Mdot
.60531 .61207 Mdot
.22959 .58258 Mdot
.61945 .50193 Mdot
.3308 .21177 Mdot
.56218 .56409 Mdot
.4624 .65351 Mdot
.46343 .79035 Mdot
.70871 .79038 Mdot
.26266 .45779 Mdot
.39059 .34826 Mdot
.6285 .7709 Mdot
.45368 .66712 Mdot
.44084 .76913 Mdot
.80691 .61883 Mdot
.5854 .45632 Mdot
.58726 .40416 Mdot
.74353 .61075 Mdot
.4346 .69339 Mdot
.47177 .68683 Mdot
.59505 .38478 Mdot
.67802 .44731 Mdot
.46009 .66283 Mdot
.6552 .42411 Mdot
.55503 .40233 Mdot
.34916 .47759 Mdot
.43148 .33368 Mdot
.31962 .5336 Mdot
.31604 .5449 Mdot
.20093 .56532 Mdot
.5709 .56865 Mdot
.32415 .52294 Mdot
.34417 .55346 Mdot
.66496 .54169 Mdot
.75992 .40521 Mdot
.61793 .66573 Mdot
.72591 .7386 Mdot
.43522 .66323 Mdot
.60308 .41953 Mdot
.37175 .33879 Mdot
.50719 .36822 Mdot
.56618 .76648 Mdot
.36653 .24112 Mdot
.57274 .41581 Mdot
.45904 .67335 Mdot
.30768 .57265 Mdot
.54013 .40383 Mdot
.49418 .628 Mdot
.64009 .43555 Mdot
.41634 .67326 Mdot
.69712 .34881 Mdot
.29354 .69576 Mdot
.49594 .61581 Mdot
.38125 .29953 Mdot
.6396 .44727 Mdot
.42007 .32033 Mdot
.33933 .49057 Mdot
.61538 .66464 Mdot
.60736 .63229 Mdot
.58594 .43233 Mdot
.62535 .52189 Mdot
.48074 .75215 Mdot
.59021 .44295 Mdot
.61587 .47553 Mdot
.29867 .56211 Mdot
.62009 .47759 Mdot
.57816 .48458 Mdot
.56587 .44438 Mdot
.56304 .41875 Mdot
.35825 .49572 Mdot
.37652 .72996 Mdot
.64283 .37478 Mdot
.66063 .38973 Mdot
.30877 .51985 Mdot
.6465 .74044 Mdot
.32296 .55073 Mdot
.81081 .59924 Mdot
.35566 .54431 Mdot
.6008 .63774 Mdot
.66487 .70216 Mdot
.68366 .4754 Mdot
.44456 .35237 Mdot
.34263 .56648 Mdot
.61442 .65838 Mdot
.3411 .50678 Mdot
.47981 .65351 Mdot
.78062 .33595 Mdot
.45035 .38774 Mdot
.3482 .36686 Mdot
.27539 .49142 Mdot
.34174 .70855 Mdot
.45743 .62275 Mdot
.40642 .3119 Mdot
.64023 .32924 Mdot
.58378 .48546 Mdot
.63064 .6438 Mdot
.58722 .42493 Mdot
.3468 .48476 Mdot
.45155 .67156 Mdot
.28046 .72049 Mdot
.61906 .63001 Mdot
.73022 .2606 Mdot
.43115 .64275 Mdot
.56978 .4761 Mdot
.3176 .54881 Mdot
.6301 .18978 Mdot
.32281 .53797 Mdot
.4518 .27802 Mdot
.39748 .37419 Mdot
.27328 .73917 Mdot
.40017 .34014 Mdot
.29989 .68432 Mdot
.5638 .13699 Mdot
.3943 .75272 Mdot
.42064 .37241 Mdot
.42976 .57537 Mdot
.6171 .4641 Mdot
.64163 .4608 Mdot
.28481 .70117 Mdot
.36925 .34564 Mdot
.6034 .48529 Mdot
.3618 .60277 Mdot
.29732 .5226 Mdot
.66813 .24589 Mdot
.44855 .62617 Mdot
.62485 .42797 Mdot
.37549 .4878 Mdot
.37489 .50616 Mdot
.42258 .63319 Mdot
.32978 .54839 Mdot
.60956 .45255 Mdot
.40465 .33428 Mdot
.38731 .6198 Mdot
.59736 .62909 Mdot
.50892 .84493 Mdot
.62384 .61698 Mdot
.45651 .63675 Mdot
.6654 .44681 Mdot
.45379 .66411 Mdot
.80802 .72013 Mdot
.61892 .45734 Mdot
.42151 .36461 Mdot
.61194 .47981 Mdot
.63714 .4509 Mdot
.566 .41786 Mdot
.46887 .66438 Mdot
.65623 .67375 Mdot
.65735 .43969 Mdot
.34651 .53508 Mdot
.52483 .24521 Mdot
.59577 .50188 Mdot
.50238 .60863 Mdot
.75294 .43972 Mdot
.30538 .46842 Mdot
.38272 .36793 Mdot
.46069 .64867 Mdot
.41119 .361 Mdot
.26414 .31777 Mdot
.40766 .35319 Mdot
.50911 .28658 Mdot
.65539 .32906 Mdot
.70497 .32155 Mdot
.68864 .31146 Mdot
.43053 .52268 Mdot
.36979 .35195 Mdot
.57761 .67252 Mdot
.42504 .37843 Mdot
.37731 .34282 Mdot
.28007 .1948 Mdot
.43848 .33239 Mdot
.63153 .42321 Mdot
.5873 .49875 Mdot
.33897 .7247 Mdot
.69401 .56279 Mdot
.59801 .47598 Mdot
.59579 .48026 Mdot
.59032 .65507 Mdot
.26125 .328 Mdot
.37505 .70485 Mdot
.45159 .20846 Mdot
.52837 .80744 Mdot
.58932 .4259 Mdot
.63137 .47992 Mdot
.60985 .37439 Mdot
.50233 .16127 Mdot
.20066 .5856 Mdot
.39632 .28808 Mdot
.63127 .37989 Mdot
.39091 .76206 Mdot
.57449 .41121 Mdot
.63643 .4156 Mdot
.61284 .46069 Mdot
.4538 .66762 Mdot
.37733 .3652 Mdot
.55958 .4198 Mdot
.68901 .67872 Mdot
.63687 .42057 Mdot
.28544 .56584 Mdot
.38415 .82091 Mdot
.62368 .42346 Mdot
.41471 .39109 Mdot
.63924 .46472 Mdot
.38171 .3482 Mdot
.38972 .31446 Mdot
.62138 .37989 Mdot
.49402 .2601 Mdot
.41368 .38731 Mdot
.59913 .44997 Mdot
.47973 .6595 Mdot
.76294 .69657 Mdot
.57603 .42607 Mdot
.62045 .66419 Mdot
.62343 .411 Mdot
.62613 .6698 Mdot
.60897 .47438 Mdot
.44107 .61855 Mdot
.49261 .3562 Mdot
.44268 .66013 Mdot
.21674 .64787 Mdot
.44087 .61461 Mdot
.75897 .28293 Mdot
.37807 .31558 Mdot
.35216 .64486 Mdot
.32003 .26893 Mdot
.25963 .5537 Mdot
.47746 .44037 Mdot
.42242 .47349 Mdot
.31757 .53844 Mdot
.39265 .36716 Mdot
.29495 .31709 Mdot
.59906 .73496 Mdot
.59883 .70799 Mdot
.43649 .68308 Mdot
.14089 .52158 Mdot
.29466 .26477 Mdot
.64059 .39625 Mdot
.59319 .31532 Mdot
.56946 .27901 Mdot
.5733 .41133 Mdot
.56919 .41011 Mdot
.51852 .63341 Mdot
.65878 .43653 Mdot
.34628 .4206 Mdot
.45293 .63306 Mdot
.61808 .65734 Mdot
.4299 .3654 Mdot
.62151 .62126 Mdot
.62325 .7294 Mdot
.41724 .46658 Mdot
.47775 .64476 Mdot
.64946 .49101 Mdot
.59031 .47551 Mdot
.38181 .33768 Mdot
.35336 .31651 Mdot
.43918 .37459 Mdot
.6119 .64867 Mdot
.44641 .63296 Mdot
.19083 .41226 Mdot
.58818 .47735 Mdot
.42152 .33331 Mdot
.48326 .45245 Mdot
.62136 .48135 Mdot
.33989 .49401 Mdot
.62218 .46378 Mdot
.42674 .37206 Mdot
.61972 .4776 Mdot
.39858 .34113 Mdot
.4484 .64304 Mdot
.56359 .45537 Mdot
.57237 .45239 Mdot
.68463 .22933 Mdot
.60117 .65091 Mdot
.41287 .31208 Mdot
.54156 .60163 Mdot
.61809 .48784 Mdot
.31733 .63175 Mdot
.63813 .43192 Mdot
.46215 .39694 Mdot
.63589 .39757 Mdot
.26557 .53616 Mdot
.67689 .40657 Mdot
.58326 .42043 Mdot
.52172 .52588 Mdot
.55765 .28306 Mdot
.69918 .44411 Mdot
.35012 .55335 Mdot
.42156 .31411 Mdot
.67634 .25599 Mdot
.38977 .63911 Mdot
.49223 .66097 Mdot
.7457 .54413 Mdot
.55734 .43429 Mdot
.61564 .42956 Mdot
.34024 .45039 Mdot
.62154 .62757 Mdot
.42099 .32454 Mdot
.60486 .65755 Mdot
.72829 .27503 Mdot
.59175 .6128 Mdot
.40927 .61973 Mdot
.46015 .75635 Mdot
.17889 .45604 Mdot
.58858 .65233 Mdot
.42654 .37393 Mdot
.43941 .75176 Mdot
.56373 .47434 Mdot
.55546 .55759 Mdot
.59386 .64124 Mdot
.16929 .61814 Mdot
.57686 .48349 Mdot
.47854 .43545 Mdot
.32171 .51916 Mdot
.59335 .65612 Mdot
.31564 .51 Mdot
.5854 .46634 Mdot
.37722 .70468 Mdot
.39158 .34921 Mdot
.31866 .498 Mdot
.55609 .48877 Mdot
.6088 .65308 Mdot
.45845 .61673 Mdot
.36934 .46752 Mdot
.33147 .55602 Mdot
.67606 .73836 Mdot
.2677 .71873 Mdot
.44328 .63388 Mdot
.57225 .20653 Mdot
.36666 .535 Mdot
.5658 .47939 Mdot
.27632 .31678 Mdot
.64175 .45478 Mdot
.2155 .50643 Mdot
.46249 .6424 Mdot
.35191 .71543 Mdot
.62593 .47996 Mdot
.57958 .41523 Mdot
.44415 .3889 Mdot
.43755 .65461 Mdot
.4154 .34133 Mdot
.4091 .30659 Mdot
.44677 .64262 Mdot
.39976 .34992 Mdot
.58218 .64976 Mdot
.31665 .35765 Mdot
.35949 .5354 Mdot
.35461 .52795 Mdot
.43864 .66871 Mdot
.46575 .65181 Mdot
.45411 .6599 Mdot
.62288 .46398 Mdot
.42789 .33426 Mdot
.59447 .46238 Mdot
.62588 .40608 Mdot
.52409 .23477 Mdot
.37473 .35714 Mdot
.60351 .46034 Mdot
.55266 .57968 Mdot
.52827 .51007 Mdot
.48316 .65329 Mdot
.32338 .51989 Mdot
.35755 .61436 Mdot
.27966 .64887 Mdot
.62739 .4305 Mdot
.59761 .58321 Mdot
.42664 .37558 Mdot
.61871 .63734 Mdot
.60591 .60591 Mdot
.61112 .63847 Mdot
.28419 .50945 Mdot
.37575 .31635 Mdot
.44808 .21365 Mdot
.62138 .42779 Mdot
.37923 .43088 Mdot
.4103 .28704 Mdot
.47783 .73466 Mdot
.32478 .51994 Mdot
.61021 .48149 Mdot
.51134 .58216 Mdot
.60043 .34193 Mdot
.63789 .45767 Mdot
.58388 .50081 Mdot
.53626 .79004 Mdot
.59574 .51589 Mdot
.44583 .37815 Mdot
.63664 .19717 Mdot
.64057 .48133 Mdot
.20659 .44084 Mdot
.53243 .85372 Mdot
.63343 .4359 Mdot
.58818 .40865 Mdot
.57711 .47256 Mdot
.63874 .47312 Mdot
.41073 .38841 Mdot
.71357 .52627 Mdot
.36372 .54028 Mdot
.37884 .42792 Mdot
.35475 .48544 Mdot
.41453 .63967 Mdot
.35784 .71872 Mdot
.39714 .37239 Mdot
.60565 .61702 Mdot
.48756 .81874 Mdot
.54857 .18033 Mdot
.42781 .63039 Mdot
.19454 .5136 Mdot
.59639 .64223 Mdot
.57006 .48823 Mdot
.59564 .66798 Mdot
.47836 .62944 Mdot
.35738 .5287 Mdot
.6067 .50559 Mdot
.41677 .37711 Mdot
.43879 .35439 Mdot
.61206 .4833 Mdot
.40694 .77509 Mdot
.33278 .49532 Mdot
.33638 .55834 Mdot
.64724 .42915 Mdot
.63527 .48739 Mdot
.41262 .34302 Mdot
.42648 .66108 Mdot
.71447 .32069 Mdot
.62608 .6424 Mdot
.58723 .39709 Mdot
.62465 .47599 Mdot
.76862 .33468 Mdot
.34704 .53734 Mdot
.49526 .63513 Mdot
.64569 .40674 Mdot
.2517 .42209 Mdot
.64766 .40991 Mdot
.59482 .37666 Mdot
.48038 .65956 Mdot
.60352 .36679 Mdot
.59899 .38726 Mdot
.46122 .38563 Mdot
.31492 .52593 Mdot
.41815 .35852 Mdot
.45935 .3931 Mdot
.32509 .32649 Mdot
.34247 .4954 Mdot
.61153 .46449 Mdot
.32807 .51637 Mdot
.64575 .43671 Mdot
.65215 .46665 Mdot
.32422 .52697 Mdot
.4143 .34097 Mdot
.61968 .77467 Mdot
.39029 .74439 Mdot
.64576 .46692 Mdot
.60954 .38156 Mdot
.69464 .54478 Mdot
.64601 .6787 Mdot
.58242 .40799 Mdot
.4322 .37037 Mdot
.58111 .46865 Mdot
.3317 .48896 Mdot
.58491 .65566 Mdot
.42047 .3702 Mdot
.42625 .64294 Mdot
.43752 .62267 Mdot
.2731 .44342 Mdot
.43971 .68897 Mdot
.59178 .40123 Mdot
.37662 .38371 Mdot
.41861 .39634 Mdot
.45408 .82116 Mdot
.44314 .64317 Mdot
.621 .66572 Mdot
.57871 .44355 Mdot
.77523 .53351 Mdot
.37269 .48196 Mdot
.22785 .27048 Mdot
.39122 .22916 Mdot
.5797 .66082 Mdot
.38831 .24396 Mdot
.43428 .61804 Mdot
.58117 .39226 Mdot
.62318 .66166 Mdot
.45457 .62392 Mdot
.6517 .44834 Mdot
.61972 .37884 Mdot
.44595 .28585 Mdot
.40573 .48583 Mdot
.32833 .52074 Mdot
.42264 .67789 Mdot
.58476 .66912 Mdot
.42987 .61052 Mdot
.38708 .31056 Mdot
.59472 .4163 Mdot
.66415 .4367 Mdot
.42419 .65737 Mdot
.49166 .66542 Mdot
.60213 .45495 Mdot
.41276 .38148 Mdot
.52072 .62913 Mdot
.59369 .42884 Mdot
.39607 .47778 Mdot
.36579 .33748 Mdot
.44777 .62849 Mdot
.58335 .41555 Mdot
.62007 .68279 Mdot
.42849 .64844 Mdot
.48404 .65 Mdot
.62994 .48102 Mdot
.58118 .64404 Mdot
.63818 .3883 Mdot
.35084 .54497 Mdot
.15415 .54968 Mdot
.33317 .48745 Mdot
.39349 .60602 Mdot
.58202 .51638 Mdot
.25592 .38501 Mdot
.38242 .36395 Mdot
.75959 .49121 Mdot
.36208 .60473 Mdot
.55542 .40037 Mdot
.75382 .69151 Mdot
.37419 .55803 Mdot
.4496 .80761 Mdot
.78118 .59239 Mdot
.58968 .63857 Mdot
.34308 .50637 Mdot
.58852 .40824 Mdot
.34901 .47678 Mdot
.62709 .65799 Mdot
.21762 .64563 Mdot
.57517 .42331 Mdot
.43309 .35311 Mdot
.60762 .45546 Mdot
.43465 .34533 Mdot
.63708 .47849 Mdot
.66111 .40422 Mdot
.30822 .58538 Mdot
.7143 .48592 Mdot
.64282 .40679 Mdot
.72186 .22397 Mdot
.49855 .44968 Mdot
.62458 .65095 Mdot
.5889 .45673 Mdot
.48427 .61535 Mdot
.37179 .49426 Mdot
.24552 .52116 Mdot
.45556 .66783 Mdot
.33332 .55493 Mdot
.40528 .34711 Mdot
.45795 .64388 Mdot
.42261 .63548 Mdot
.59913 .36669 Mdot
.58126 .65681 Mdot
.35375 .51445 Mdot
.60942 .41465 Mdot
.57651 .42251 Mdot
.57204 .20312 Mdot
.57429 .74653 Mdot
.35058 .33412 Mdot
.43244 .17525 Mdot
.39631 .30008 Mdot
.615 .65551 Mdot
.46566 .66788 Mdot
.61497 .40243 Mdot
.61312 .44723 Mdot
.32961 .63099 Mdot
.43123 .38044 Mdot
.45924 .52692 Mdot
.37273 .26813 Mdot
.5381 .61762 Mdot
.71798 .49747 Mdot
.43043 .36756 Mdot
.71417 .50198 Mdot
.57306 .62819 Mdot
.6725 .77694 Mdot
.69142 .51703 Mdot
.323 .51488 Mdot
.70399 .51453 Mdot
.4169 .32466 Mdot
.65595 .44075 Mdot
.47532 .66927 Mdot
.45286 .68727 Mdot
.41868 .35107 Mdot
.46687 .61276 Mdot
.58883 .62957 Mdot
.60145 .40749 Mdot
.45947 .19987 Mdot
.30317 .41377 Mdot
.43659 .67131 Mdot
.54938 .39408 Mdot
.35372 .49957 Mdot
.61308 .48359 Mdot
.58596 .64436 Mdot
.33273 .50754 Mdot
.78505 .42929 Mdot
.30292 .50468 Mdot
.58116 .43995 Mdot
.7728 .33437 Mdot
.34041 .50023 Mdot
.50501 .42306 Mdot
.59816 .42365 Mdot
.34331 .5479 Mdot
.57029 .36628 Mdot
.30892 .67399 Mdot
.50976 .56047 Mdot
.80776 .61896 Mdot
.49046 .53364 Mdot
.45478 .67747 Mdot
.32644 .69448 Mdot
.25035 .54566 Mdot
.37024 .51242 Mdot
.49676 .64739 Mdot
.58854 .56429 Mdot
.31435 .51465 Mdot
.57119 .48733 Mdot
.63744 .43621 Mdot
.20772 .59933 Mdot
.38076 .52642 Mdot
.29708 .68625 Mdot
.28317 .45648 Mdot
.6151 .48929 Mdot
.6465 .39563 Mdot
.61208 .44291 Mdot
.43624 .38576 Mdot
.33335 .53042 Mdot
.68398 .21035 Mdot
.33801 .49223 Mdot
.48313 .23063 Mdot
.4379 .66595 Mdot
.45126 .62568 Mdot
.62645 .42636 Mdot
.47768 .42252 Mdot
.7682 .43654 Mdot
.60619 .4509 Mdot
.64386 .62349 Mdot
.23092 .61941 Mdot
.63171 .48784 Mdot
.39498 .37574 Mdot
.57368 .38012 Mdot
.52733 .46909 Mdot
.3603 .53463 Mdot
.59927 .62049 Mdot
.76762 .47191 Mdot
.35928 .52089 Mdot
.6151 .43087 Mdot
.26185 .39013 Mdot
.6316 .4539 Mdot
.64755 .46238 Mdot
.42399 .23902 Mdot
.59913 .60603 Mdot
.44976 .65325 Mdot
.60911 .64033 Mdot
.38114 .35395 Mdot
.20537 .26889 Mdot
.59516 .61079 Mdot
.77265 .42821 Mdot
.19759 .60439 Mdot
.69087 .52569 Mdot
.42487 .32498 Mdot
.59308 .6696 Mdot
.32699 .50219 Mdot
.76001 .70178 Mdot
.45857 .30623 Mdot
.38849 .53723 Mdot
.59875 .43032 Mdot
.43989 .32618 Mdot
.44182 .35926 Mdot
.31633 .50098 Mdot
.39382 .31284 Mdot
.6788 .38986 Mdot
.65379 .45226 Mdot
.36393 .49368 Mdot
.26776 .41403 Mdot
.35585 .55077 Mdot
.42956 .56198 Mdot
.59023 .4512 Mdot
.42354 .36798 Mdot
.58101 .3977 Mdot
.36981 .36634 Mdot
.48558 .62415 Mdot
.65991 .47439 Mdot
.58943 .62651 Mdot
.2456 .40358 Mdot
.44063 .6338 Mdot
.55233 .60667 Mdot
.38105 .34031 Mdot
.29473 .49286 Mdot
.38048 .32838 Mdot
.38733 .38686 Mdot
.32043 .5501 Mdot
.40068 .32513 Mdot
.59107 .40831 Mdot
.5335 .56654 Mdot
.38576 .34354 Mdot
.34578 .52087 Mdot
.60312 .62256 Mdot
.40263 .34219 Mdot
.45027 .59911 Mdot
.57703 .43842 Mdot
.46961 .66018 Mdot
.64156 .70353 Mdot
.44013 .3301 Mdot
.58893 .60845 Mdot
.48948 .66682 Mdot
.63224 .63914 Mdot
.39755 .80137 Mdot
.30873 .50556 Mdot
.46513 .24376 Mdot
.65126 .6454 Mdot
.44514 .3576 Mdot
.64988 .7047 Mdot
.62557 .40756 Mdot
.57727 .44135 Mdot
.62874 .66645 Mdot
.44187 .35972 Mdot
.59875 .8293 Mdot
.57869 .52628 Mdot
.42409 .54008 Mdot
.32877 .56678 Mdot
.75597 .27487 Mdot
.42431 .55442 Mdot
.49148 .86122 Mdot
.53914 .42703 Mdot
.4679 .689 Mdot
.62414 .43695 Mdot
.3378 .60592 Mdot
.60643 .65063 Mdot
.42515 .58791 Mdot
.66926 .43199 Mdot
.45176 .64772 Mdot
.56904 .45382 Mdot
.52107 .53286 Mdot
.51292 .42485 Mdot
.62794 .66247 Mdot
.42791 .76466 Mdot
.43255 .32341 Mdot
.59592 .63254 Mdot
.46484 .62595 Mdot
.73991 .47723 Mdot
.65209 .45056 Mdot
.56389 .48198 Mdot
.53769 .61891 Mdot
.42789 .33218 Mdot
.46328 .67829 Mdot
.3533 .54162 Mdot
.60869 .62008 Mdot
.59136 .47441 Mdot
.63157 .40684 Mdot
.30983 .62301 Mdot
.35312 .49521 Mdot
.45141 .69122 Mdot
.31808 .52418 Mdot
.42172 .62985 Mdot
.65963 .45287 Mdot
.43689 .62657 Mdot
.55762 .41708 Mdot
.30039 .57567 Mdot
.44787 .23733 Mdot
.561 .29501 Mdot
.4615 .63868 Mdot
.75028 .3918 Mdot
.35039 .49495 Mdot
.32676 .543 Mdot
.17511 .5326 Mdot
.44648 .27668 Mdot
.5468 .18861 Mdot
.73075 .68409 Mdot
.36126 .49574 Mdot
.35208 .50848 Mdot
.4699 .65794 Mdot
.39827 .32455 Mdot
.39496 .3021 Mdot
.42055 .63272 Mdot
.70757 .60781 Mdot
.42117 .32486 Mdot
.71785 .73302 Mdot
.63919 .22906 Mdot
.55111 .43257 Mdot
.40714 .61898 Mdot
.61612 .63206 Mdot
.71236 .59028 Mdot
.52675 .54126 Mdot
.57641 .41605 Mdot
.76423 .52105 Mdot
.43215 .666 Mdot
.46453 .41525 Mdot
.80457 .60577 Mdot
.56588 .45424 Mdot
.60108 .41999 Mdot
.61618 .43813 Mdot
.57627 .64582 Mdot
.46966 .30887 Mdot
.59169 .41193 Mdot
.70603 .6105 Mdot
.61511 .48659 Mdot
.51322 .4095 Mdot
.60814 .63445 Mdot
.68159 .51592 Mdot
.61057 .73426 Mdot
.63929 .20299 Mdot
.51726 .46481 Mdot
.35525 .54149 Mdot
.6048 .69618 Mdot
.32059 .53886 Mdot
.52064 .28794 Mdot
.66367 .53931 Mdot
.39637 .29708 Mdot
.578 .4141 Mdot
.45634 .63587 Mdot
.44148 .35807 Mdot
.31767 .66251 Mdot
.24333 .22944 Mdot
.36099 .53824 Mdot
.60127 .87006 Mdot
.34006 .54726 Mdot
.42117 .63742 Mdot
.41233 .34401 Mdot
.66742 .33528 Mdot
.35033 .39257 Mdot
.40055 .34408 Mdot
.59245 .80928 Mdot
.39197 .28735 Mdot
.74823 .44718 Mdot
.45054 .3626 Mdot
.34745 .51387 Mdot
.27593 .50634 Mdot
.69488 .40766 Mdot
.63011 .41453 Mdot
.42661 .47366 Mdot
.76295 .43078 Mdot
.62392 .40703 Mdot
.45078 .63328 Mdot
.44904 .24821 Mdot
.75324 .52851 Mdot
.40649 .32475 Mdot
.30177 .51286 Mdot
.59315 .41977 Mdot
.63257 .47046 Mdot
.65403 .44426 Mdot
.40507 .21503 Mdot
.66869 .77946 Mdot
.65763 .44243 Mdot
.62991 .48418 Mdot
.45508 .64507 Mdot
.64477 .66986 Mdot
.42604 .74957 Mdot
.55311 .21359 Mdot
.56351 .43583 Mdot
.59997 .63181 Mdot
.57819 .66782 Mdot
.65123 .41877 Mdot
.56243 .57149 Mdot
.26542 .38022 Mdot
.60774 .41421 Mdot
.45112 .25148 Mdot
.49407 .70047 Mdot
.43465 .6937 Mdot
.42576 .64864 Mdot
.41508 .31458 Mdot
.42084 .65397 Mdot
.44707 .61729 Mdot
.66857 .34447 Mdot
.4752 .52743 Mdot
.33956 .579 Mdot
.61397 .64805 Mdot
.61812 .45018 Mdot
.69548 .46519 Mdot
.25273 .41152 Mdot
.31451 .53583 Mdot
.41325 .37213 Mdot
.37231 .49205 Mdot
.56299 .65729 Mdot
.33611 .31085 Mdot
.43357 .67626 Mdot
.36394 .50844 Mdot
.34698 .46625 Mdot
.60214 .63035 Mdot
.32867 .48797 Mdot
.34301 .45963 Mdot
.64059 .4923 Mdot
.57731 .32357 Mdot
.59998 .4479 Mdot
.49181 .82449 Mdot
.35652 .50567 Mdot
.27592 .53244 Mdot
.61359 .42301 Mdot
.43014 .64667 Mdot
.67458 .36599 Mdot
.63441 .41631 Mdot
.42248 .65928 Mdot
.64377 .39947 Mdot
.62611 .62078 Mdot
.36771 .35328 Mdot
.35594 .39986 Mdot
.13586 .5105 Mdot
.58256 .66009 Mdot
.31931 .65678 Mdot
.57559 .41242 Mdot
.31512 .75672 Mdot
.40393 .33956 Mdot
.61884 .39564 Mdot
.74301 .51378 Mdot
.38942 .33666 Mdot
.40765 .36189 Mdot
.6201 .46953 Mdot
.321 .51706 Mdot
.44241 .6315 Mdot
.60698 .63001 Mdot
.47213 .84401 Mdot
.59217 .43524 Mdot
.57464 .4588 Mdot
.59576 .63744 Mdot
.34851 .48976 Mdot
.64666 .41019 Mdot
.7268 .6487 Mdot
.62902 .82129 Mdot
.33368 .54966 Mdot
.5663 .47444 Mdot
.51816 .31327 Mdot
.5537 .51491 Mdot
.27734 .75679 Mdot
.56145 .56266 Mdot
.45561 .65276 Mdot
.62714 .51599 Mdot
.30946 .21074 Mdot
.60277 .6206 Mdot
.54685 .1821 Mdot
.63096 .4726 Mdot
.58946 .47998 Mdot
.4365 .37534 Mdot
.59649 .45977 Mdot
.40276 .37474 Mdot
.15601 .45669 Mdot
.7668 .32149 Mdot
.39937 .30998 Mdot
.4457 .35097 Mdot
.76558 .46082 Mdot
.37725 .62329 Mdot
.41621 .35045 Mdot
.64922 .47109 Mdot
.60716 .56202 Mdot
.46124 .40854 Mdot
.60633 .67144 Mdot
.64187 .71606 Mdot
.63145 .52495 Mdot
.58244 .59147 Mdot
.64289 .74746 Mdot
.65746 .51516 Mdot
.45558 .57242 Mdot
.34033 .54292 Mdot
.56539 .45217 Mdot
.45152 .68815 Mdot
.44166 .6901 Mdot
.56222 .40355 Mdot
.62399 .45557 Mdot
.38072 .34995 Mdot
.61945 .62799 Mdot
.37055 .52206 Mdot
.59286 .47898 Mdot
.75615 .48769 Mdot
.61747 .62134 Mdot
.3955 .31698 Mdot
.51003 .2413 Mdot
.6342 .62802 Mdot
.66371 .40228 Mdot
.61994 .41499 Mdot
.6101 .45894 Mdot
.69858 .41566 Mdot
.33247 .53412 Mdot
.65859 .70887 Mdot
.60168 .49822 Mdot
.72249 .26755 Mdot
.3673 .57808 Mdot
.668 .4702 Mdot
.38443 .31521 Mdot
.30182 .54474 Mdot
.44025 .61138 Mdot
.31742 .31441 Mdot
.58304 .43949 Mdot
.41204 .77106 Mdot
.21557 .61042 Mdot
.49099 .63339 Mdot
.37209 .36678 Mdot
.61505 .64103 Mdot
.60889 .45146 Mdot
.49181 .26293 Mdot
.63579 .43341 Mdot
.59814 .59268 Mdot
.48621 .64719 Mdot
.33738 .54298 Mdot
.46357 .81454 Mdot
.42807 .68505 Mdot
.41033 .36099 Mdot
.82247 .42414 Mdot
.4022 .37534 Mdot
.39634 .30345 Mdot
.52356 .24233 Mdot
.33147 .53508 Mdot
.26796 .23485 Mdot
.16593 .4605 Mdot
.65593 .4758 Mdot
.34791 .49202 Mdot
.4245 .35488 Mdot
.59928 .48735 Mdot
.37154 .29963 Mdot
.37204 .3266 Mdot
.65663 .46311 Mdot
.57783 .47678 Mdot
.31905 .71845 Mdot
.79051 .62706 Mdot
.61474 .6427 Mdot
.37772 .35238 Mdot
.35368 .4115 Mdot
.59768 .48842 Mdot
.62082 .42695 Mdot
.24739 .55778 Mdot
.58545 .65934 Mdot
.32946 .40974 Mdot
.63187 .47141 Mdot
.7823 .37093 Mdot
.61589 .36942 Mdot
.40918 .38602 Mdot
.32207 .54344 Mdot
.65332 .21388 Mdot
.3609 .4575 Mdot
.40342 .37405 Mdot
.60325 .61474 Mdot
.43782 .3947 Mdot
.77324 .42112 Mdot
.35095 .48589 Mdot
.42686 .37206 Mdot
.5066 .58307 Mdot
.33434 .5226 Mdot
.3601 .509 Mdot
.5343 .23534 Mdot
.49539 .6307 Mdot
.57548 .64893 Mdot
.35356 .51122 Mdot
.24893 .36021 Mdot
.34261 .51811 Mdot
.16451 .47846 Mdot
.56462 .46153 Mdot
.73819 .58043 Mdot
.39889 .59581 Mdot
.65799 .50184 Mdot
.35806 .50061 Mdot
.59114 .65715 Mdot
.65069 .4487 Mdot
.41281 .3198 Mdot
.62898 .64099 Mdot
.38961 .49354 Mdot
.45881 .66414 Mdot
.38305 .32713 Mdot
.3722 .53926 Mdot
.43718 .35201 Mdot
.2945 .31925 Mdot
.1817 .59569 Mdot
.78631 .48846 Mdot
.3448 .38444 Mdot
.65186 .45291 Mdot
.68742 .72428 Mdot
.56035 .46499 Mdot
.62801 .45893 Mdot
.45011 .62991 Mdot
.74786 .55617 Mdot
.41494 .34154 Mdot
.54597 .8334 Mdot
.36214 .52903 Mdot
.65026 .20774 Mdot
.52969 .4896 Mdot
.61147 .38866 Mdot
.3858 .3475 Mdot
.42302 .38305 Mdot
.54973 .27275 Mdot
.41996 .61671 Mdot
.58063 .40363 Mdot
.57945 .5032 Mdot
.57304 .39175 Mdot
.35922 .52898 Mdot
.56694 .58434 Mdot
.45084 .67736 Mdot
.21758 .66559 Mdot
.48746 .64852 Mdot
.59728 .59 Mdot
.40299 .32262 Mdot
.59534 .61095 Mdot
.62027 .42477 Mdot
.35707 .3029 Mdot
.43306 .38052 Mdot
.63177 .66199 Mdot
.60086 .66098 Mdot
.2837 .63011 Mdot
.32453 .5263 Mdot
.6405 .4165 Mdot
.58511 .41426 Mdot
.59615 .46597 Mdot
.62207 .46228 Mdot
.36275 .53358 Mdot
.65124 .43924 Mdot
.3755 .48165 Mdot
.32576 .28458 Mdot
.74749 .60664 Mdot
.49202 .53123 Mdot
.20559 .51485 Mdot
.41163 .32343 Mdot
.25037 .36738 Mdot
.55472 .50376 Mdot
.33448 .23774 Mdot
.25152 .67671 Mdot
.6194 .49761 Mdot
.44149 .62267 Mdot
.58381 .35792 Mdot
.44002 .68451 Mdot
.49068 .87085 Mdot
.28697 .58719 Mdot
.78499 .64912 Mdot
.57611 .42361 Mdot
.52999 .56659 Mdot
.22707 .38001 Mdot
.5618 .47296 Mdot
.29117 .6128 Mdot
.21373 .50428 Mdot
.41705 .76005 Mdot
.58516 .64848 Mdot
.58319 .42968 Mdot
.69786 .45295 Mdot
.59501 .40811 Mdot
.62397 .43243 Mdot
.65276 .44181 Mdot
.36451 .54402 Mdot
.61097 .39687 Mdot
.64573 .45215 Mdot
.48519 .75622 Mdot
.71631 .49381 Mdot
.4748 .68078 Mdot
.1817 .55696 Mdot
.59438 .61063 Mdot
.38291 .34462 Mdot
.66411 .77418 Mdot
.32328 .51521 Mdot
.55709 .27372 Mdot
.61685 .46085 Mdot
.34669 .72994 Mdot
.33551 .46991 Mdot
.59819 .61617 Mdot
.47689 .62704 Mdot
.78687 .66534 Mdot
.45135 .63688 Mdot
.29222 .54164 Mdot
.43282 .64371 Mdot
.56684 .51489 Mdot
.38024 .35064 Mdot
.64582 .41695 Mdot
.3532 .5186 Mdot
.42452 .64068 Mdot
.69616 .55435 Mdot
.61425 .44298 Mdot
.44644 .6435 Mdot
.64586 .41773 Mdot
.34417 .35157 Mdot
.60537 .22612 Mdot
.45084 .61869 Mdot
.34119 .46984 Mdot
.34483 .53245 Mdot
.58121 .63886 Mdot
.38457 .33332 Mdot
.40928 .37308 Mdot
.33367 .50825 Mdot
.39882 .26107 Mdot
.56262 .43297 Mdot
.58887 .48494 Mdot
.67963 .23378 Mdot
.59663 .40414 Mdot
.73883 .47293 Mdot
.51767 .58352 Mdot
.40369 .31643 Mdot
.61323 .38676 Mdot
.62097 .47298 Mdot
.58006 .44042 Mdot
.35703 .27774 Mdot
.42644 .66411 Mdot
.56522 .45688 Mdot
.60711 .66258 Mdot
.44613 .73365 Mdot
.61395 .48356 Mdot
.63609 .36805 Mdot
.41136 .37365 Mdot
.43321 .18055 Mdot
.33781 .54678 Mdot
.46386 .62638 Mdot
.4628 .63906 Mdot
.65092 .72125 Mdot
.22321 .43732 Mdot
.51856 .58243 Mdot
.24033 .70562 Mdot
.30891 .58532 Mdot
.60792 .65699 Mdot
.40984 .68467 Mdot
.26941 .5126 Mdot
.47169 .64562 Mdot
.36396 .53506 Mdot
.56738 .47412 Mdot
.56315 .43865 Mdot
.27271 .26002 Mdot
.65046 .41422 Mdot
.61454 .63676 Mdot
.35881 .54957 Mdot
.41776 .32607 Mdot
.60183 .61639 Mdot
.31749 .52569 Mdot
.41125 .31432 Mdot
.61019 .50057 Mdot
.60091 .49998 Mdot
.41042 .37062 Mdot
.43666 .37111 Mdot
.61818 .41706 Mdot
.38804 .69606 Mdot
.44387 .34799 Mdot
.43026 .36924 Mdot
.43567 .67545 Mdot
.44499 .68883 Mdot
.66415 .39003 Mdot
.34913 .49757 Mdot
.64745 .4498 Mdot
.45741 .64123 Mdot
.59292 .61253 Mdot
.41471 .33831 Mdot
.64289 .46933 Mdot
.60865 .48046 Mdot
.60244 .62888 Mdot
.58582 .6251 Mdot
.58776 .64712 Mdot
.37834 .52159 Mdot
.58903 .46302 Mdot
.40971 .34794 Mdot
.32654 .53288 Mdot
.57636 .66418 Mdot
.60211 .66903 Mdot
.40101 .65932 Mdot
.60476 .40098 Mdot
.38679 .62451 Mdot
.329 .19483 Mdot
.734 .29756 Mdot
.47192 .6189 Mdot
.43853 .61047 Mdot
.66026 .56497 Mdot
.44709 .42623 Mdot
.33655 .4967 Mdot
.64764 .66808 Mdot
.77266 .46147 Mdot
.62607 .50077 Mdot
.63398 .48484 Mdot
.65737 .40397 Mdot
.59052 .65095 Mdot
.75721 .55974 Mdot
.39529 .37064 Mdot
.70978 .46499 Mdot
.62106 .62366 Mdot
.48716 .67077 Mdot
.39743 .66205 Mdot
.48745 .64428 Mdot
.57819 .49296 Mdot
.57518 .29841 Mdot
.23476 .40156 Mdot
.7215 .67736 Mdot
.35541 .49686 Mdot
.69413 .46792 Mdot
.3117 .75033 Mdot
.40727 .36594 Mdot
.41374 .64112 Mdot
.60892 .65866 Mdot
.43758 .36902 Mdot
.36698 .48436 Mdot
.35193 .5117 Mdot
.43879 .672 Mdot
.44439 .6715 Mdot
.47823 .65383 Mdot
.37099 .32578 Mdot
.40148 .3237 Mdot
.58394 .44217 Mdot
.41389 .33359 Mdot
.37177 .22642 Mdot
.63333 .66761 Mdot
.50755 .63952 Mdot
.34502 .50303 Mdot
.4211 .32157 Mdot
.61146 .44401 Mdot
.44613 .41808 Mdot
.24673 .4861 Mdot
.62475 .65404 Mdot
.58714 .21314 Mdot
.46391 .85749 Mdot
.63763 .41308 Mdot
.3394 .53662 Mdot
.4615 .19569 Mdot
.61335 .43796 Mdot
.4688 .66834 Mdot
.49419 .78868 Mdot
.42572 .7105 Mdot
.63631 .41832 Mdot
.63629 .49851 Mdot
.34707 .54876 Mdot
.22853 .67466 Mdot
.58758 .43931 Mdot
.32558 .39203 Mdot
.32882 .47623 Mdot
.46087 .67587 Mdot
.74601 .74985 Mdot
.55816 .66606 Mdot
.71214 .5976 Mdot
.44238 .6754 Mdot
.63804 .44948 Mdot
.43347 .68057 Mdot
.61561 .66064 Mdot
.46736 .62375 Mdot
.40218 .37705 Mdot
.49081 .65055 Mdot
.57458 .45993 Mdot
.41788 .353 Mdot
.34099 .49883 Mdot
.62126 .20036 Mdot
.52308 .77739 Mdot
.4297 .64923 Mdot
.43855 .61973 Mdot
.6241 .38829 Mdot
.34053 .42245 Mdot
.56149 .40994 Mdot
.57471 .48148 Mdot
.35781 .48986 Mdot
.38743 .33655 Mdot
.3301 .55076 Mdot
.68527 .44635 Mdot
.75839 .61103 Mdot
.31895 .52762 Mdot
.39813 .75189 Mdot
.597 .6444 Mdot
.47007 .46894 Mdot
.61346 .44882 Mdot
.32026 .4993 Mdot
.588 .4605 Mdot
.39 .36641 Mdot
.49121 .51161 Mdot
.38427 .71879 Mdot
.35658 .5228 Mdot
.43364 .79089 Mdot
.72508 .63507 Mdot
.6703 .38928 Mdot
.32612 .54368 Mdot
.74441 .52441 Mdot
.42043 .63924 Mdot
.62679 .6412 Mdot
.63439 .63367 Mdot
.62551 .62708 Mdot
.54933 .41823 Mdot
.5217 .47541 Mdot
.58914 .60739 Mdot
.36952 .49202 Mdot
.62765 .66247 Mdot
.19799 .43964 Mdot
.55081 .83106 Mdot
.60405 .64829 Mdot
.5977 .42612 Mdot
.52489 .4366 Mdot
.66816 .5399 Mdot
.30351 .67236 Mdot
.77387 .66423 Mdot
.23501 .58281 Mdot
.63256 .41892 Mdot
.36773 .32336 Mdot
.37231 .34216 Mdot
.47365 .18018 Mdot
.75896 .41402 Mdot
.75397 .32074 Mdot
.42764 .31627 Mdot
.3591 .64926 Mdot
.39112 .31914 Mdot
.65413 .42962 Mdot
.59256 .48607 Mdot
.42589 .31358 Mdot
.76357 .58545 Mdot
.34989 .65826 Mdot
.4677 .8288 Mdot
.43819 .36102 Mdot
.31513 .52767 Mdot
.30929 .53159 Mdot
.36033 .50595 Mdot
.61345 .21278 Mdot
.3893 .35028 Mdot
.59934 .47369 Mdot
.46037 .63655 Mdot
.56537 .43783 Mdot
.33181 .52254 Mdot
.56002 .83489 Mdot
.39608 .34271 Mdot
.59069 .41699 Mdot
.66691 .37044 Mdot
.45104 .66923 Mdot
.59965 .63714 Mdot
.36263 .39751 Mdot
.75336 .32706 Mdot
.36367 .52102 Mdot
.43761 .32654 Mdot
.28101 .54847 Mdot
.48638 .81541 Mdot
.5382 .42454 Mdot
.5911 .50954 Mdot
.47051 .84662 Mdot
.78565 .39394 Mdot
.58131 .40598 Mdot
.4549 .62205 Mdot
.32373 .62469 Mdot
.621 .47997 Mdot
.37438 .34806 Mdot
.63342 .62784 Mdot
.63172 .64073 Mdot
.66341 .38822 Mdot
.38861 .43563 Mdot
.51634 .53942 Mdot
.61376 .4651 Mdot
.66306 .40341 Mdot
.45493 .67647 Mdot
.32464 .59744 Mdot
.72935 .2757 Mdot
.59461 .61382 Mdot
.64641 .41566 Mdot
.58547 .79856 Mdot
.44042 .37559 Mdot
.48822 .63025 Mdot
.33796 .48229 Mdot
.40987 .28761 Mdot
.47471 .62551 Mdot
.64487 .47184 Mdot
.64951 .41474 Mdot
.31409 .54062 Mdot
.4092 .38541 Mdot
.59148 .64975 Mdot
.45421 .62771 Mdot
.58605 .62944 Mdot
.38974 .33901 Mdot
.40805 .3303 Mdot
.66673 .37379 Mdot
.5342 .44799 Mdot
.42696 .64296 Mdot
.55456 .42073 Mdot
.42499 .71471 Mdot
.31841 .79082 Mdot
.34218 .56662 Mdot
.61602 .39993 Mdot
.45 .37659 Mdot
.35901 .52447 Mdot
.5849 .47901 Mdot
.50828 .86026 Mdot
.60468 .48924 Mdot
.32094 .56607 Mdot
.79526 .45029 Mdot
.58651 .63788 Mdot
.69016 .49558 Mdot
.29328 .70699 Mdot
.60444 .40403 Mdot
.4674 .64827 Mdot
.55293 .39248 Mdot
.3231 .50741 Mdot
.40556 .3241 Mdot
.30741 .79065 Mdot
.34304 .5228 Mdot
.60396 .40916 Mdot
.60639 .61852 Mdot
.44771 .37476 Mdot
.57626 .56086 Mdot
.56237 .57485 Mdot
.55758 .3768 Mdot
.58368 .39863 Mdot
.62844 .46649 Mdot
.73297 .65069 Mdot
.46679 .62955 Mdot
.4297 .36303 Mdot
.34321 .53774 Mdot
.33386 .50419 Mdot
.43372 .66897 Mdot
.3954 .57869 Mdot
.46931 .46948 Mdot
.42129 .1498 Mdot
.42376 .67272 Mdot
.60293 .60922 Mdot
.33735 .41078 Mdot
.46109 .63077 Mdot
.44277 .64615 Mdot
.43714 .67703 Mdot
.48061 .57547 Mdot
.42268 .32494 Mdot
.64316 .47383 Mdot
.38341 .36858 Mdot
.63958 .45049 Mdot
.31831 .56411 Mdot
.35587 .5185 Mdot
.39598 .33769 Mdot
.4306 .8203 Mdot
.54843 .33414 Mdot
.60851 .43078 Mdot
.31556 .75626 Mdot
.6673 .43692 Mdot
.67805 .54186 Mdot
.65802 .4126 Mdot
.43197 .65849 Mdot
.55969 .47899 Mdot
.5595 .3989 Mdot
.50879 .17553 Mdot
.34621 .49949 Mdot
.43199 .69439 Mdot
.6753 .43942 Mdot
.65766 .39755 Mdot
.37268 .3182 Mdot
.43603 .36912 Mdot
.63312 .6331 Mdot
.72944 .45801 Mdot
.34128 .49563 Mdot
.18869 .40353 Mdot
.62839 .41431 Mdot
.55613 .61538 Mdot
.67993 .29984 Mdot
.58185 .47703 Mdot
.31467 .73285 Mdot
.56987 .29252 Mdot
.61034 .45073 Mdot
.4327 .51496 Mdot
.35155 .49534 Mdot
.78041 .57913 Mdot
.62121 .48436 Mdot
.45786 .66935 Mdot
.39756 .32122 Mdot
.43402 .38202 Mdot
.62192 .61757 Mdot
.29804 .26045 Mdot
.32891 .55142 Mdot
.40021 .32914 Mdot
.62051 .44441 Mdot
.33717 .53804 Mdot
.4211 .66776 Mdot
.6157 .39036 Mdot
.75525 .38916 Mdot
.41851 .33284 Mdot
.6469 .4011 Mdot
.30824 .37315 Mdot
.68144 .59072 Mdot
.81205 .47746 Mdot
.34719 .5381 Mdot
.58206 .64165 Mdot
.58884 .37614 Mdot
.43497 .27547 Mdot
.62671 .38243 Mdot
.72715 .60075 Mdot
.19478 .4531 Mdot
.58383 .65318 Mdot
.60922 .42281 Mdot
.59381 .47506 Mdot
.4886 .42895 Mdot
.59968 .61302 Mdot
.57764 .42024 Mdot
.43709 .29833 Mdot
.43267 .34379 Mdot
.41618 .63735 Mdot
.42138 .32843 Mdot
.5994 .4299 Mdot
.53331 .43937 Mdot
.43587 .37444 Mdot
.33486 .78795 Mdot
.64027 .6681 Mdot
.33045 .54357 Mdot
.6619 .46228 Mdot
.59794 .49513 Mdot
.66162 .1831 Mdot
.49394 .63845 Mdot
.3927 .71009 Mdot
.50348 .71099 Mdot
.61919 .76717 Mdot
.56087 .67065 Mdot
.82588 .5568 Mdot
.7882 .39976 Mdot
.61244 .3965 Mdot
.59242 .54576 Mdot
.28035 .35156 Mdot
.35351 .49132 Mdot
.25299 .32098 Mdot
.63015 .41427 Mdot
.6248 .43483 Mdot
.46648 .61559 Mdot
.36633 .71511 Mdot
.75308 .31704 Mdot
.42756 .42362 Mdot
.59107 .6471 Mdot
.37746 .34661 Mdot
.6472 .47145 Mdot
.45238 .52934 Mdot
.49076 .66602 Mdot
.56056 .66047 Mdot
.59459 .41661 Mdot
.39312 .2352 Mdot
.25022 .46909 Mdot
.32786 .52861 Mdot
.4643 .64064 Mdot
.76227 .34073 Mdot
.61312 .40163 Mdot
.32878 .48633 Mdot
.59567 .43829 Mdot
.51517 .61638 Mdot
.68358 .45515 Mdot
.61098 .65414 Mdot
.63687 .47041 Mdot
.57549 .68294 Mdot
.78317 .2824 Mdot
.58627 .60542 Mdot
.38808 .29401 Mdot
.49732 .66429 Mdot
.425 .66184 Mdot
.43358 .37149 Mdot
.42529 .65505 Mdot
.56251 .25988 Mdot
.69121 .34883 Mdot
.59486 .64467 Mdot
.65197 .38442 Mdot
.60481 .64329 Mdot
.48684 .62638 Mdot
.63379 .41779 Mdot
.38592 .83317 Mdot
.43273 .63295 Mdot
.79526 .38749 Mdot
.34069 .5163 Mdot
.49293 .66364 Mdot
.6155 .48612 Mdot
.27087 .54327 Mdot
.42933 .68551 Mdot
.36527 .69096 Mdot
.58054 .44071 Mdot
.41359 .32759 Mdot
.6155 .47935 Mdot
.65594 .47442 Mdot
.47064 .68645 Mdot
.64571 .44279 Mdot
.31735 .52417 Mdot
.42015 .31303 Mdot
.74141 .71582 Mdot
.21542 .48085 Mdot
.5797 .41496 Mdot
.61857 .44254 Mdot
.4103 .39488 Mdot
.57748 .48947 Mdot
.3622 .53442 Mdot
.10092 .5177 Mdot
.59711 .64385 Mdot
.44373 .70047 Mdot
.56959 .68263 Mdot
.62075 .4988 Mdot
.65118 .44466 Mdot
.54162 .86319 Mdot
.75261 .61337 Mdot
.32111 .53836 Mdot
.57275 .3912 Mdot
.42211 .6744 Mdot
.61414 .6252 Mdot
.37173 .50379 Mdot
.60814 .45815 Mdot
.61709 .42412 Mdot
.58224 .63146 Mdot
.612 .56915 Mdot
.66317 .24179 Mdot
.31267 .51342 Mdot
.58756 .51692 Mdot
.47723 .60314 Mdot
.56181 .42677 Mdot
.58129 .20237 Mdot
.42363 .37087 Mdot
.36451 .5162 Mdot
.64742 .73622 Mdot
.6121 .40003 Mdot
.31905 .54185 Mdot
.34238 .49544 Mdot
.60712 .38449 Mdot
.45531 .35847 Mdot
.4117 .31058 Mdot
.43569 .34622 Mdot
.21373 .30364 Mdot
.71461 .57589 Mdot
.47822 .65398 Mdot
.35094 .49362 Mdot
.43666 .61847 Mdot
.59929 .59191 Mdot
.50901 .56443 Mdot
.44228 .61837 Mdot
.43208 .33463 Mdot
.47411 .68905 Mdot
.58301 .46365 Mdot
.33982 .49796 Mdot
.47327 .64981 Mdot
.64968 .48165 Mdot
.3603 .43623 Mdot
.26464 .64106 Mdot
.60028 .66637 Mdot
.62791 .61837 Mdot
.60204 .48576 Mdot
.41996 .61965 Mdot
.62033 .41919 Mdot
.34549 .47749 Mdot
.35382 .42705 Mdot
.65881 .4663 Mdot
.42861 .65265 Mdot
.42246 .39555 Mdot
.75748 .33573 Mdot
.54502 .45065 Mdot
.59922 .42567 Mdot
.64224 .44596 Mdot
.59525 .43867 Mdot
.48557 .80864 Mdot
.30886 .54076 Mdot
.20741 .51061 Mdot
.6547 .70607 Mdot
.39741 .34814 Mdot
.38211 .37099 Mdot
.72216 .27851 Mdot
.27632 .36417 Mdot
.34985 .49719 Mdot
.62585 .46024 Mdot
.24965 .43221 Mdot
.62838 .82056 Mdot
.44757 .84104 Mdot
.50011 .41883 Mdot
.496 .64125 Mdot
.43622 .32538 Mdot
.42241 .63979 Mdot
.63772 .44362 Mdot
.65179 .39507 Mdot
.83713 .51705 Mdot
.36122 .48339 Mdot
.59708 .65036 Mdot
.64085 .45218 Mdot
.71212 .58149 Mdot
.4568 .64508 Mdot
.4923 .66619 Mdot
.56853 .46965 Mdot
.42495 .39122 Mdot
.76548 .27412 Mdot
.33324 .53423 Mdot
.23615 .55939 Mdot
.22277 .3856 Mdot
.26349 .47764 Mdot
.33147 .52599 Mdot
.49945 .45967 Mdot
.48213 .62503 Mdot
.66613 .28128 Mdot
.39679 .35406 Mdot
.62851 .644 Mdot
.66433 .47701 Mdot
.42293 .37779 Mdot
.48318 .65973 Mdot
.40904 .3253 Mdot
.65241 .44527 Mdot
.31093 .49853 Mdot
.45743 .65401 Mdot
.34778 .58041 Mdot
.44893 .37964 Mdot
.60083 .61435 Mdot
.42456 .44191 Mdot
.51779 .37406 Mdot
.5686 .28975 Mdot
.5661 .46367 Mdot
.45419 .53747 Mdot
.59882 .47182 Mdot
.37984 .37636 Mdot
.60676 .44196 Mdot
.40393 .40064 Mdot
.4665 .64901 Mdot
.62891 .48427 Mdot
.61769 .46526 Mdot
.1711 .49891 Mdot
.57934 .42486 Mdot
.56286 .41256 Mdot
.6128 .45354 Mdot
.35363 .32978 Mdot
.64416 .37935 Mdot
.38164 .31766 Mdot
.45066 .74557 Mdot
.44084 .64903 Mdot
.63439 .64617 Mdot
.57943 .64012 Mdot
.74016 .56704 Mdot
.60365 .72364 Mdot
.35035 .71567 Mdot
.42681 .33894 Mdot
.32136 .50419 Mdot
.6018 .44158 Mdot
.80112 .60644 Mdot
.52711 .64747 Mdot
.48801 .66717 Mdot
.21665 .48233 Mdot
.62989 .51782 Mdot
.79374 .562 Mdot
.57578 .39161 Mdot
.25091 .27982 Mdot
.55256 .48707 Mdot
.6579 .49284 Mdot
.41472 .66023 Mdot
.56305 .62232 Mdot
.58369 .4903 Mdot
.37962 .30961 Mdot
.62243 .64712 Mdot
.53955 .50166 Mdot
.39643 .61561 Mdot
.43088 .73469 Mdot
.37905 .39579 Mdot
.58575 .45182 Mdot
.45639 .65482 Mdot
.38221 .32947 Mdot
.73727 .28751 Mdot
.32744 .53507 Mdot
.39916 .57303 Mdot
.31687 .34555 Mdot
.34279 .78594 Mdot
.61593 .61962 Mdot
.61624 .24245 Mdot
.57646 .46205 Mdot
.47159 .77515 Mdot
.66157 .46033 Mdot
.57381 .8356 Mdot
.58839 .61151 Mdot
.43192 .33166 Mdot
.31486 .52205 Mdot
.37562 .35147 Mdot
.55392 .28815 Mdot
.4006 .62531 Mdot
.46625 .50584 Mdot
.44953 .63833 Mdot
.53528 .55094 Mdot
.42291 .35858 Mdot
.64723 .42082 Mdot
.41617 .15008 Mdot
.42825 .37013 Mdot
.44891 .36798 Mdot
.20307 .61594 Mdot
.35176 .81504 Mdot
.57587 .50607 Mdot
.44462 .34769 Mdot
.44385 .63907 Mdot
.61736 .64267 Mdot
.62895 .47787 Mdot
.58216 .45321 Mdot
.4199 .37693 Mdot
.4576 .69286 Mdot
.49096 .30062 Mdot
.43983 .66862 Mdot
.42488 .32711 Mdot
.44303 .66006 Mdot
.28055 .53604 Mdot
.45942 .62604 Mdot
.59685 .49533 Mdot
.60545 .44196 Mdot
.55912 .70165 Mdot
.40892 .33011 Mdot
.61198 .46531 Mdot
.62505 .38899 Mdot
.41239 .34759 Mdot
.52995 .52225 Mdot
.49889 .29992 Mdot
.57254 .41626 Mdot
.57815 .43346 Mdot
.58296 .64795 Mdot
.48381 .55433 Mdot
.59768 .22564 Mdot
.64983 .45119 Mdot
.57661 .64356 Mdot
.38459 .30686 Mdot
.60988 .41397 Mdot
.63759 .79441 Mdot
.32715 .62798 Mdot
.6343 .41235 Mdot
.42093 .63854 Mdot
.56395 .39616 Mdot
.80979 .46123 Mdot
.57587 .48291 Mdot
.42023 .34818 Mdot
.39342 .32962 Mdot
.17939 .42929 Mdot
.41258 .36136 Mdot
.45216 .68749 Mdot
.33313 .52219 Mdot
.47965 .81914 Mdot
.4204 .66092 Mdot
.54132 .46043 Mdot
.14783 .51311 Mdot
.63356 .39861 Mdot
.62473 .49387 Mdot
.80048 .36349 Mdot
.42629 .63617 Mdot
.38559 .35493 Mdot
.44942 .43605 Mdot
.53625 .46585 Mdot
.36349 .51331 Mdot
.67912 .44759 Mdot
.56664 .47453 Mdot
.79941 .43056 Mdot
.49416 .80372 Mdot
.33341 .48067 Mdot
.56212 .41561 Mdot
.65057 .44884 Mdot
.48299 .61492 Mdot
.61626 .44591 Mdot
.61551 .64648 Mdot
.38807 .34735 Mdot
.45297 .62404 Mdot
.60082 .62692 Mdot
.61614 .4046 Mdot
.58892 .64803 Mdot
.47 .66021 Mdot
.34388 .48127 Mdot
.63792 .43248 Mdot
.60882 .67158 Mdot
.5894 .64669 Mdot
.60066 .47004 Mdot
.40518 .32183 Mdot
.61629 .52459 Mdot
.58078 .42153 Mdot
.64407 .46739 Mdot
.40722 .37244 Mdot
.71818 .79011 Mdot
.58902 .48588 Mdot
.73328 .60507 Mdot
.42366 .38196 Mdot
.53519 .54255 Mdot
.41723 .65273 Mdot
.56917 .4812 Mdot
.34448 .48082 Mdot
.33713 .48469 Mdot
.48867 .64615 Mdot
.44412 .33559 Mdot
.51603 .69884 Mdot
.45467 .34168 Mdot
.55619 .39415 Mdot
.55862 .42726 Mdot
.46093 .31299 Mdot
.79455 .64171 Mdot
.38707 .36828 Mdot
.40784 .5969 Mdot
.39673 .43074 Mdot
.32364 .49554 Mdot
.47465 .68131 Mdot
.42866 .31524 Mdot
.39793 .37046 Mdot
.40694 .31689 Mdot
.62908 .64705 Mdot
.56321 .70427 Mdot
.41765 .38627 Mdot
.41418 .39104 Mdot
.57926 .44696 Mdot
.64791 .45459 Mdot
.76398 .36529 Mdot
.73497 .35081 Mdot
.59556 .66064 Mdot
.47401 .66813 Mdot
.1978 .30698 Mdot
.35214 .48059 Mdot
.19064 .51452 Mdot
.63224 .48805 Mdot
.24727 .23279 Mdot
.62177 .48283 Mdot
.6212 .44694 Mdot
.41894 .31194 Mdot
.6089 .67017 Mdot
.60146 .64346 Mdot
.42908 .36497 Mdot
.39568 .38533 Mdot
.61405 .64743 Mdot
.28328 .70639 Mdot
.65433 .79302 Mdot
.44272 .71728 Mdot
.4078 .34306 Mdot
.6028 .34201 Mdot
.31091 .52544 Mdot
.52275 .45053 Mdot
.33003 .47752 Mdot
.45021 .64488 Mdot
.47277 .62254 Mdot
.36189 .52116 Mdot
.582 .4386 Mdot
.47757 .64695 Mdot
.62165 .3993 Mdot
.23155 .60305 Mdot
.55986 .31286 Mdot
.54233 .67581 Mdot
.53925 .3883 Mdot
.52144 .5131 Mdot
.34996 .58163 Mdot
.6143 .40845 Mdot
.62997 .77595 Mdot
.59377 .64758 Mdot
.55858 .38701 Mdot
.36552 .50922 Mdot
.81509 .38486 Mdot
.63771 .42488 Mdot
.41963 .34445 Mdot
.34521 .49355 Mdot
.32314 .30477 Mdot
.33114 .39542 Mdot
.6412 .44846 Mdot
.34126 .19362 Mdot
.36136 .30692 Mdot
.46398 .63364 Mdot
.37322 .25084 Mdot
.39596 .37977 Mdot
.60686 .6898 Mdot
.66499 .71448 Mdot
.39994 .81155 Mdot
.38236 .34539 Mdot
.49091 .62725 Mdot
.38925 .3102 Mdot
.60637 .61617 Mdot
.38228 .29957 Mdot
.46148 .64775 Mdot
.59785 .41791 Mdot
.43089 .66421 Mdot
.62745 .65401 Mdot
.66926 .25056 Mdot
.33275 .4813 Mdot
.42733 .69015 Mdot
.35182 .5257 Mdot
.6674 .59825 Mdot
.71686 .66355 Mdot
.33651 .54378 Mdot
.48438 .25168 Mdot
.55832 .43588 Mdot
.40441 .38412 Mdot
.43092 .67095 Mdot
.59033 .76262 Mdot
.42303 .43846 Mdot
.40001 .35805 Mdot
.48162 .65666 Mdot
.3418 .39116 Mdot
.41833 .25301 Mdot
.56149 .41228 Mdot
.64767 .54901 Mdot
.4074 .34648 Mdot
.47943 .61934 Mdot
.66937 .22446 Mdot
.38655 .31033 Mdot
.42607 .67642 Mdot
.31479 .53092 Mdot
.33105 .50781 Mdot
.56741 .43618 Mdot
.30115 .53595 Mdot
.48176 .63905 Mdot
.39433 .52652 Mdot
.44477 .34537 Mdot
.33634 .28747 Mdot
.62023 .6723 Mdot
.43672 .65505 Mdot
.6474 .4067 Mdot
.36619 .36026 Mdot
.30241 .59842 Mdot
.50189 .31795 Mdot
.42953 .17442 Mdot
.43382 .66878 Mdot
.39081 .35513 Mdot
.41872 .34096 Mdot
.54405 .44687 Mdot
.34432 .38145 Mdot
.51568 .70353 Mdot
.48845 .40355 Mdot
.48048 .4052 Mdot
.41532 .63817 Mdot
.40223 .68978 Mdot
.67618 .43946 Mdot
.58904 .44731 Mdot
.32061 .50071 Mdot
.59527 .42014 Mdot
.43157 .32438 Mdot
.56689 .46426 Mdot
.34259 .53665 Mdot
.45127 .63446 Mdot
.63632 .42801 Mdot
.58617 .64259 Mdot
.31546 .54787 Mdot
.37007 .4856 Mdot
.43272 .65165 Mdot
.41929 .37763 Mdot
.55558 .55247 Mdot
.44624 .67226 Mdot
.58553 .45062 Mdot
.48385 .5658 Mdot
.6539 .4452 Mdot
.66225 .51625 Mdot
.38042 .31444 Mdot
.45062 .62444 Mdot
.41728 .30783 Mdot
.34792 .52205 Mdot
.65529 .70743 Mdot
.60308 .43369 Mdot
.4232 .67176 Mdot
.35783 .59932 Mdot
.64669 .5316 Mdot
.4412 .39309 Mdot
.2961 .69235 Mdot
.37899 .36996 Mdot
.46943 .67299 Mdot
.17209 .53391 Mdot
.62571 .63233 Mdot
.48935 .66576 Mdot
.76453 .68824 Mdot
.43123 .63771 Mdot
.56834 .44726 Mdot
.59816 .48481 Mdot
.45753 .62577 Mdot
.58104 .64075 Mdot
.76124 .31378 Mdot
.44708 .70713 Mdot
.38477 .35104 Mdot
.23243 .63318 Mdot
.52563 .15774 Mdot
.36103 .56827 Mdot
.32137 .50104 Mdot
.55871 .49961 Mdot
.55704 .45882 Mdot
.36624 .50049 Mdot
.34718 .47137 Mdot
.63074 .63143 Mdot
.4367 .68042 Mdot
.36219 .35535 Mdot
.37796 .50853 Mdot
.36032 .38772 Mdot
.59347 .71891 Mdot
.54584 .45098 Mdot
.21811 .40185 Mdot
.63625 .48392 Mdot
.69108 .66444 Mdot
.34477 .53741 Mdot
.65685 .43036 Mdot
.56143 .40494 Mdot
.35532 .48769 Mdot
.61873 .64332 Mdot
.39688 .58142 Mdot
.44728 .65914 Mdot
.73048 .76744 Mdot
.60986 .39325 Mdot
.56915 .46182 Mdot
.35669 .50029 Mdot
.49728 .74986 Mdot
.39441 .34597 Mdot
.37285 .35502 Mdot
.46621 .62939 Mdot
.40518 .44938 Mdot
.56247 .44461 Mdot
.60593 .41075 Mdot
.45495 .65991 Mdot
.45214 .69002 Mdot
.32793 .69461 Mdot
.58991 .47598 Mdot
.34672 .50395 Mdot
.59382 .58914 Mdot
.34923 .53674 Mdot
.65428 .43733 Mdot
.57142 .46578 Mdot
.59631 .49568 Mdot
.64976 .41243 Mdot
.3361 .47123 Mdot
.65747 .45384 Mdot
.6414 .38323 Mdot
.39384 .35678 Mdot
.64329 .45483 Mdot
.47641 .40827 Mdot
.59104 .42557 Mdot
.61603 .64437 Mdot
.55696 .21275 Mdot
.63776 .42571 Mdot
.56602 .46861 Mdot
.45411 .69946 Mdot
.61257 .42767 Mdot
.34731 .47785 Mdot
.40508 .33561 Mdot
.35235 .49673 Mdot
.33709 .48389 Mdot
.44602 .61324 Mdot
.60102 .60666 Mdot
.62199 .49937 Mdot
.61705 .65881 Mdot
.53774 .44415 Mdot
.61135 .39969 Mdot
.62893 .71158 Mdot
.23599 .29304 Mdot
.62711 .2189 Mdot
.60092 .43358 Mdot
.4296 .63371 Mdot
.42277 .63813 Mdot
.57445 .54201 Mdot
.56989 .40541 Mdot
.36879 .52515 Mdot
.32832 .48947 Mdot
.75588 .40677 Mdot
.78418 .51306 Mdot
.6167 .64432 Mdot
.4775 .54115 Mdot
.58373 .40254 Mdot
.65452 .42534 Mdot
.61832 .39219 Mdot
.44739 .61773 Mdot
.5127 .40235 Mdot
.48209 .67452 Mdot
.23885 .48679 Mdot
.35957 .51766 Mdot
.64104 .43717 Mdot
.21092 .44159 Mdot
.43985 .36152 Mdot
.40591 .33497 Mdot
.37441 .49408 Mdot
.44222 .60181 Mdot
.74621 .33037 Mdot
.44791 .84694 Mdot
.38225 .29262 Mdot
.61983 .66633 Mdot
.60493 .40649 Mdot
.44314 .63381 Mdot
.42464 .32495 Mdot
.61996 .6656 Mdot
.64491 .42269 Mdot
.5652 .70478 Mdot
.59411 .43429 Mdot
.25952 .36741 Mdot
.39451 .31843 Mdot
.60038 .83066 Mdot
.44733 .34105 Mdot
.31841 .55327 Mdot
.36485 .52372 Mdot
.5846 .47799 Mdot
.4143 .27209 Mdot
.38914 .37643 Mdot
.44466 .57918 Mdot
.60373 .60967 Mdot
.28358 .56381 Mdot
.61835 .62663 Mdot
.46634 .64002 Mdot
.62528 .64077 Mdot
.46343 .64907 Mdot
.72963 .32033 Mdot
.35129 .33298 Mdot
.59628 .63399 Mdot
.35513 .59307 Mdot
.5574 .46496 Mdot
.59407 .6613 Mdot
.64821 .39339 Mdot
.6378 .52881 Mdot
.45346 .66244 Mdot
.60406 .6119 Mdot
.64713 .41696 Mdot
.81988 .5464 Mdot
.32663 .5429 Mdot
.36793 .52445 Mdot
.64642 .39273 Mdot
.41901 .62738 Mdot
.39374 .30243 Mdot
.54984 .82446 Mdot
.36701 .54412 Mdot
.58787 .48347 Mdot
.58091 .49002 Mdot
.38623 .37596 Mdot
.18884 .4604 Mdot
.57767 .47099 Mdot
.69082 .41003 Mdot
.59043 .47799 Mdot
.34188 .54887 Mdot
.37615 .34983 Mdot
.41368 .33753 Mdot
.48146 .65436 Mdot
.44257 .3673 Mdot
.61134 .56185 Mdot
.22513 .44967 Mdot
.678 .47831 Mdot
.34398 .52546 Mdot
.24585 .46358 Mdot
.23516 .49019 Mdot
.76817 .66847 Mdot
.44926 .38119 Mdot
.65829 .46515 Mdot
.44265 .37442 Mdot
.61693 .62898 Mdot
.41567 .3294 Mdot
.43577 .32489 Mdot
.62152 .41664 Mdot
.63778 .44981 Mdot
.45724 .63334 Mdot
.35332 .39767 Mdot
.42055 .38027 Mdot
.62212 .48198 Mdot
.56608 .48621 Mdot
.63107 .40097 Mdot
.4799 .58147 Mdot
.38157 .36112 Mdot
.23506 .68176 Mdot
.74252 .49833 Mdot
.41984 .37986 Mdot
.77872 .29559 Mdot
.34289 .60132 Mdot
.39894 .63598 Mdot
.41058 .57196 Mdot
.59479 .4789 Mdot
.42646 .68604 Mdot
.63773 .44267 Mdot
.21902 .40232 Mdot
.62002 .42821 Mdot
.61621 .64761 Mdot
.61267 .39644 Mdot
.48288 .62986 Mdot
.4388 .66939 Mdot
.57982 .48096 Mdot
.63522 .43061 Mdot
.69277 .26613 Mdot
.40119 .28984 Mdot
.40212 .3311 Mdot
.5121 .69726 Mdot
.59347 .62891 Mdot
.36401 .51594 Mdot
.61071 .44847 Mdot
.44618 .61432 Mdot
.43629 .6683 Mdot
.38841 .37255 Mdot
.46462 .66953 Mdot
.33237 .53289 Mdot
.60648 .43639 Mdot
.36798 .5066 Mdot
.63083 .64258 Mdot
.378 .35361 Mdot
.6426 .45232 Mdot
.57915 .44646 Mdot
.39315 .32972 Mdot
.65697 .47697 Mdot
.58252 .64149 Mdot
.42796 .64346 Mdot
.38117 .3424 Mdot
.33216 .51789 Mdot
.46598 .64221 Mdot
.64685 .46674 Mdot
.30067 .23271 Mdot
.57069 .44097 Mdot
.60723 .47966 Mdot
.79288 .66501 Mdot
.58985 .39899 Mdot
.433 .67051 Mdot
.42863 .32753 Mdot
.59504 .36594 Mdot
.73329 .55025 Mdot
.64993 .84942 Mdot
.48493 .6706 Mdot
.59759 .40818 Mdot
.78835 .62142 Mdot
.59413 .41186 Mdot
.50807 .35473 Mdot
.41624 .68614 Mdot
.49541 .4913 Mdot
.65959 .42046 Mdot
.32381 .51339 Mdot
.45377 .62915 Mdot
.46585 .6526 Mdot
.22011 .60345 Mdot
.61684 .41343 Mdot
.44102 .54726 Mdot
.64933 .43154 Mdot
.32976 .51755 Mdot
.7579 .4459 Mdot
.43834 .67076 Mdot
.4706 .17661 Mdot
.59658 .47222 Mdot
.39664 .37188 Mdot
.48094 .68392 Mdot
.27405 .52077 Mdot
.6408 .47096 Mdot
.60345 .65944 Mdot
.37325 .4754 Mdot
.68258 .44705 Mdot
.341 .52767 Mdot
.64599 .46416 Mdot
.61281 .35598 Mdot
.33649 .25413 Mdot
.40664 .3193 Mdot
.31484 .51961 Mdot
.50273 .57381 Mdot
.65933 .45525 Mdot
.38218 .34331 Mdot
.39734 .35581 Mdot
.63063 .64704 Mdot
.49853 .53033 Mdot
.30857 .36437 Mdot
.57804 .33102 Mdot
.22621 .61846 Mdot
.47057 .69015 Mdot
.38159 .71073 Mdot
.61574 .47433 Mdot
.57529 .58755 Mdot
.34357 .4784 Mdot
.57056 .43679 Mdot
.61157 .24597 Mdot
.43594 .36409 Mdot
.57357 .44345 Mdot
.60599 .64427 Mdot
.5389 .63226 Mdot
.59337 .58684 Mdot
.69477 .70654 Mdot
.44953 .63991 Mdot
.63356 .38026 Mdot
.63334 .36239 Mdot
.4162 .64904 Mdot
.57781 .49606 Mdot
.42418 .66789 Mdot
.30867 .74278 Mdot
.60022 .66566 Mdot
.38382 .36068 Mdot
.31217 .57843 Mdot
.60269 .50155 Mdot
.55998 .45835 Mdot
.60998 .60753 Mdot
.59094 .45165 Mdot
.31285 .25236 Mdot
.48719 .58443 Mdot
.47345 .64544 Mdot
.40715 .31748 Mdot
.57876 .4936 Mdot
.51584 .56493 Mdot
.58697 .41744 Mdot
.66245 .31831 Mdot
.56672 .47117 Mdot
.32721 .38071 Mdot
.39868 .321 Mdot
.34547 .52965 Mdot
.66084 .43938 Mdot
.62171 .43521 Mdot
.76269 .56 Mdot
.5444 .47443 Mdot
.65905 .43925 Mdot
.45242 .39498 Mdot
.4178 .31756 Mdot
.38707 .31255 Mdot
.48863 .6549 Mdot
.7903 .47241 Mdot
.34705 .51145 Mdot
.56207 .37711 Mdot
.36904 .53623 Mdot
.47532 .30799 Mdot
.61496 .66678 Mdot
.74293 .6667 Mdot
.61572 .46001 Mdot
.42935 .33893 Mdot
.55646 .80329 Mdot
.37041 .32799 Mdot
.46188 .52903 Mdot
.34105 .49593 Mdot
.42792 .36801 Mdot
.62269 .44277 Mdot
.40913 .43362 Mdot
.79766 .597 Mdot
.35241 .51168 Mdot
.54248 .46208 Mdot
.49337 .64619 Mdot
.55554 .67315 Mdot
.37783 .214 Mdot
.32827 .54463 Mdot
.32545 .56915 Mdot
.61545 .41163 Mdot
.44087 .35501 Mdot
.32507 .5174 Mdot
.34486 .54677 Mdot
.46793 .66775 Mdot
.63735 .45353 Mdot
.63525 .4582 Mdot
.47246 .67209 Mdot
.35365 .49785 Mdot
.62904 .38192 Mdot
.68468 .45163 Mdot
.84047 .46916 Mdot
.32701 .35279 Mdot
.73633 .7676 Mdot
.57975 .54812 Mdot
.56226 .23028 Mdot
.54977 .82834 Mdot
.41076 .37901 Mdot
.62684 .40755 Mdot
.65442 .4938 Mdot
.48228 .63936 Mdot
.60405 .42518 Mdot
.40446 .65793 Mdot
.34019 .48891 Mdot
.81173 .38452 Mdot
.27881 .43283 Mdot
.35654 .7822 Mdot
.60586 .42388 Mdot
.42619 .40429 Mdot
.61178 .62912 Mdot
.34021 .57075 Mdot
.37471 .33328 Mdot
.64179 .40117 Mdot
.68831 .26262 Mdot
.48752 .66878 Mdot
.41062 .36827 Mdot
.73814 .2913 Mdot
.50373 .4779 Mdot
.65351 .44352 Mdot
.48199 .66889 Mdot
.60222 .79678 Mdot
.35572 .28769 Mdot
.353 .55484 Mdot
.61959 .64392 Mdot
.44976 .62633 Mdot
.32551 .49136 Mdot
.37257 .37894 Mdot
.41871 .36551 Mdot
.38373 .30369 Mdot
.6119 .22031 Mdot
.43295 .69721 Mdot
.60824 .62835 Mdot
.78557 .5567 Mdot
.77663 .53364 Mdot
.61241 .64944 Mdot
.47424 .62296 Mdot
.42004 .3196 Mdot
.43199 .36061 Mdot
.40495 .33621 Mdot
.55855 .18546 Mdot
.44492 .37783 Mdot
.19149 .55406 Mdot
.63836 .40462 Mdot
.6903 .44799 Mdot
.59941 .40885 Mdot
.3702 .51777 Mdot
.38894 .32756 Mdot
.4368 .44266 Mdot
.54335 .42091 Mdot
.74509 .64426 Mdot
.56759 .4414 Mdot
.30532 .52528 Mdot
.57544 .45292 Mdot
.21693 .36922 Mdot
.4392 .37695 Mdot
.60207 .43039 Mdot
.31513 .49826 Mdot
.59277 .62494 Mdot
.44157 .39397 Mdot
.64215 .44649 Mdot
.33741 .72861 Mdot
.59875 .3965 Mdot
.35699 .77491 Mdot
.30933 .30456 Mdot
.61851 .66659 Mdot
.25398 .34443 Mdot
.49999 .63642 Mdot
.69108 .42182 Mdot
.53072 .44378 Mdot
.35215 .51991 Mdot
.29547 .57088 Mdot
.44102 .64664 Mdot
.50273 .41576 Mdot
.67203 .40321 Mdot
.63169 .6494 Mdot
.35959 .29227 Mdot
.365 .49574 Mdot
.57316 .49267 Mdot
.55728 .4136 Mdot
.22228 .54385 Mdot
.66034 .39716 Mdot
.57338 .48431 Mdot
.61438 .60541 Mdot
.19446 .53411 Mdot
.58786 .42888 Mdot
.46966 .53362 Mdot
.38483 .29747 Mdot
.55085 .39859 Mdot
.18681 .54034 Mdot
.60135 .48551 Mdot
.4186 .37141 Mdot
.69848 .44739 Mdot
.29732 .35442 Mdot
.59898 .60679 Mdot
.566 .46999 Mdot
.1756 .44198 Mdot
.59074 .46594 Mdot
.34422 .50861 Mdot
.56758 .40848 Mdot
.45891 .64684 Mdot
.62673 .21372 Mdot
.4813 .64717 Mdot
.56571 .42694 Mdot
.40468 .33922 Mdot
.35875 .50689 Mdot
.50323 .187 Mdot
.53599 .71111 Mdot
.19681 .5116 Mdot
.46057 .83764 Mdot
.5974 .61108 Mdot
.57584 .66478 Mdot
.35778 .48391 Mdot
.59993 .43019 Mdot
.1821 .58307 Mdot
.55521 .49221 Mdot
.57725 .43589 Mdot
.62135 .42849 Mdot
.71139 .66505 Mdot
.33701 .48675 Mdot
.44936 .66686 Mdot
.57447 .46847 Mdot
.65862 .44863 Mdot
.4065 .37665 Mdot
.58944 .63652 Mdot
.41752 .65109 Mdot
.59628 .6456 Mdot
.44896 .62991 Mdot
.79377 .33729 Mdot
.59092 .38637 Mdot
.59628 .62016 Mdot
.3756 .48448 Mdot
.41394 .37499 Mdot
.22944 .44452 Mdot
.46771 .64751 Mdot
.48684 .65036 Mdot
.57415 .47877 Mdot
.42294 .37295 Mdot
.4182 .31017 Mdot
.61294 .62256 Mdot
.33499 .5409 Mdot
.63714 .42475 Mdot
.59877 .39969 Mdot
.68715 .37584 Mdot
.42818 .618 Mdot
.25178 .37189 Mdot
.38382 .72605 Mdot
.59888 .43239 Mdot
.44361 .34312 Mdot
.63076 .42748 Mdot
.44812 .79583 Mdot
.44154 .36214 Mdot
.60814 .48569 Mdot
.7399 .25904 Mdot
.41195 .60947 Mdot
.27634 .38692 Mdot
.59103 .49197 Mdot
.53398 .84995 Mdot
.61547 .46896 Mdot
.82241 .38908 Mdot
.54482 .78476 Mdot
.56075 .42902 Mdot
.63778 .47591 Mdot
.5297 .31224 Mdot
.60008 .40376 Mdot
.47698 .66753 Mdot
.78312 .38544 Mdot
.37689 .31117 Mdot
.24746 .52578 Mdot
.57054 .21876 Mdot
.59109 .61044 Mdot
.46593 .62928 Mdot
.40162 .68437 Mdot
.60505 .65151 Mdot
.41054 .34392 Mdot
.5953 .43889 Mdot
.42885 .47138 Mdot
.42299 .62608 Mdot
.53839 .50914 Mdot
.3429 .50694 Mdot
.31033 .63305 Mdot
.53935 .61057 Mdot
.33756 .52946 Mdot
.64221 .45825 Mdot
.51532 .30955 Mdot
.70411 .31094 Mdot
.68896 .77425 Mdot
.32011 .49791 Mdot
.35399 .51144 Mdot
.59267 .19543 Mdot
.63495 .66191 Mdot
.22998 .55425 Mdot
.33056 .38914 Mdot
.36236 .50993 Mdot
.37247 .27975 Mdot
.46397 .68266 Mdot
.30591 .49563 Mdot
.592 .37353 Mdot
.62399 .4023 Mdot
.62207 .44046 Mdot
.34268 .54166 Mdot
.62636 .54081 Mdot
.3666 .24708 Mdot
.35306 .52649 Mdot
.5541 .5047 Mdot
.48008 .49002 Mdot
.37535 .65815 Mdot
.45435 .67618 Mdot
.61043 .61117 Mdot
.61382 .67774 Mdot
.39238 .36522 Mdot
.60557 .60857 Mdot
.54853 .61529 Mdot
.59748 .45095 Mdot
.35456 .53184 Mdot
.29469 .58499 Mdot
.33317 .51015 Mdot
.60256 .64858 Mdot
.63629 .64346 Mdot
.39373 .35592 Mdot
.40675 .32871 Mdot
.54226 .24825 Mdot
.69593 .52488 Mdot
.57735 .42237 Mdot
.6192 .7401 Mdot
.43147 .3196 Mdot
.54512 .52087 Mdot
.61044 .61026 Mdot
.59203 .62868 Mdot
.75657 .57795 Mdot
.61873 .45701 Mdot
.47206 .33211 Mdot
.61595 .45342 Mdot
.74676 .4646 Mdot
.6268 .48904 Mdot
.4672 .66839 Mdot
.62447 .46134 Mdot
.7586 .58843 Mdot
.63411 .49881 Mdot
.55384 .45405 Mdot
.44674 .6163 Mdot
.68373 .42791 Mdot
.45727 .64803 Mdot
.56977 .42395 Mdot
.59423 .67023 Mdot
.47097 .63025 Mdot
.72319 .5688 Mdot
.74438 .59908 Mdot
.47555 .62226 Mdot
.62182 .659 Mdot
.57851 .63372 Mdot
.70695 .60761 Mdot
.37451 .33397 Mdot
.53707 .48065 Mdot
.6003 .42762 Mdot
.46577 .68638 Mdot
.32832 .49193 Mdot
.64058 .47624 Mdot
.56331 .47774 Mdot
.60968 .49149 Mdot
.3925 .36644 Mdot
.52032 .70163 Mdot
.60052 .61698 Mdot
.47131 .6749 Mdot
.55579 .55545 Mdot
.41575 .63323 Mdot
.55339 .42194 Mdot
.65331 .49333 Mdot
.59138 .23223 Mdot
.36985 .63006 Mdot
.55457 .17851 Mdot
.4168 .36562 Mdot
.42226 .6367 Mdot
.61518 .67382 Mdot
.64071 .5027 Mdot
.43099 .33911 Mdot
.46091 .64795 Mdot
.59495 .43461 Mdot
.55002 .47795 Mdot
.22621 .48316 Mdot
.62505 .56928 Mdot
.73603 .58942 Mdot
.48892 .64397 Mdot
.497 .64255 Mdot
.73796 .62495 Mdot
.56709 .62616 Mdot
.42564 .43953 Mdot
.60676 .41508 Mdot
.60318 .65858 Mdot
.4265 .32744 Mdot
.63325 .23833 Mdot
.35756 .53772 Mdot
.34755 .38664 Mdot
.60635 .42551 Mdot
.51404 .51056 Mdot
.40269 .34021 Mdot
.60858 .64486 Mdot
.34564 .54145 Mdot
.58998 .67869 Mdot
.43376 .62181 Mdot
.37728 .81222 Mdot
.58891 .46018 Mdot
.57056 .47503 Mdot
.3088 .53 Mdot
.43691 .35341 Mdot
.59021 .60615 Mdot
.23944 .64425 Mdot
.46854 .6587 Mdot
.17468 .56297 Mdot
.44244 .34307 Mdot
.58542 .34564 Mdot
.45641 .68098 Mdot
.37603 .5092 Mdot
.70844 .58916 Mdot
.33704 .53445 Mdot
.56458 .43473 Mdot
.42443 .3401 Mdot
.31705 .5151 Mdot
.33377 .34318 Mdot
.80713 .60436 Mdot
.58693 .34411 Mdot
.60165 .44796 Mdot
.82666 .50313 Mdot
.33631 .74884 Mdot
.38885 .28734 Mdot
.33718 .48044 Mdot
.56947 .43681 Mdot
.56262 .46502 Mdot
.58858 .46533 Mdot
.32586 .49916 Mdot
.62668 .73092 Mdot
.45668 .66217 Mdot
.60865 .40898 Mdot
.63171 .63372 Mdot
.45034 .64754 Mdot
.29755 .56035 Mdot
.45032 .67501 Mdot
.45597 .37015 Mdot
.54847 .43472 Mdot
.26619 .5126 Mdot
.7529 .23941 Mdot
.35313 .50335 Mdot
.45384 .6137 Mdot
.59713 .38722 Mdot
.33117 .62066 Mdot
.40048 .31092 Mdot
.47047 .6589 Mdot
.56853 .45941 Mdot
.35051 .58875 Mdot
.65543 .23997 Mdot
.4454 .67397 Mdot
.43165 .33841 Mdot
.69587 .76535 Mdot
.59935 .42148 Mdot
.60688 .4669 Mdot
.42537 .36423 Mdot
.45534 .25497 Mdot
.68801 .24135 Mdot
.63364 .42972 Mdot
.34612 .53087 Mdot
.28193 .75998 Mdot
.56184 .47587 Mdot
.75926 .47014 Mdot
.45631 .63081 Mdot
.30505 .48374 Mdot
.28425 .34764 Mdot
.62918 .5063 Mdot
.2317 .59367 Mdot
.34302 .57721 Mdot
.80828 .53148 Mdot
.40487 .6521 Mdot
.44403 .75348 Mdot
.80922 .47655 Mdot
.31454 .49608 Mdot
.4223 .41403 Mdot
.23794 .61565 Mdot
.45005 .21247 Mdot
.64198 .7862 Mdot
.48524 .76632 Mdot
.68809 .26092 Mdot
.44189 .46927 Mdot
.43602 .63131 Mdot
.53268 .51543 Mdot
.63954 .44268 Mdot
.34364 .75399 Mdot
.33094 .27138 Mdot
.34388 .26249 Mdot
.82788 .50517 Mdot
.52154 .35532 Mdot
.79024 .61473 Mdot
.77594 .66773 Mdot
.72861 .40984 Mdot
.39961 .72335 Mdot
.17398 .57149 Mdot
.77502 .34375 Mdot
.24197 .6732 Mdot
.68912 .45807 Mdot
.45276 .52981 Mdot
.40556 .80086 Mdot
.37043 .38356 Mdot
.40756 .25476 Mdot
.47909 .65578 Mdot
.37614 .31949 Mdot
.23638 .57368 Mdot
.38164 .37353 Mdot
.29543 .35039 Mdot
.71323 .75917 Mdot
.80361 .61279 Mdot
.18452 .44424 Mdot
.55053 .83792 Mdot
.59853 .24361 Mdot
.12961 .51917 Mdot
.41324 .66759 Mdot
.39501 .37688 Mdot
.70136 .65912 Mdot
.77008 .57946 Mdot
.25912 .47463 Mdot
.26748 .67285 Mdot
.5879 .70278 Mdot
.66598 .57705 Mdot
.41798 .34337 Mdot
.26252 .34154 Mdot
.29425 .52719 Mdot
.27294 .44098 Mdot
.77318 .36065 Mdot
.70383 .73626 Mdot
.42351 .47689 Mdot
.27585 .66335 Mdot
.33615 .65301 Mdot
.40383 .21348 Mdot
.73527 .52045 Mdot
.54841 .52776 Mdot
.32437 .35777 Mdot
.52128 .82714 Mdot
.46748 .22699 Mdot
.74176 .45923 Mdot
.77619 .56408 Mdot
.77551 .31722 Mdot
.40956 .77766 Mdot
.59299 .15244 Mdot
.36905 .35835 Mdot
.58027 .49069 Mdot
.48166 .25996 Mdot
.168 .46511 Mdot
.63655 .6306 Mdot
.68131 .71969 Mdot
.61619 .61721 Mdot
.45281 .34869 Mdot
.65949 .23175 Mdot
.18947 .53369 Mdot
.15458 .49867 Mdot
.58548 .66919 Mdot
.57081 .37161 Mdot
.49131 .88994 Mdot
.78105 .59946 Mdot
.2691 .41576 Mdot
.83496 .45429 Mdot
.48165 .46371 Mdot
.3321 .29242 Mdot
.31845 .50935 Mdot
.81302 .45619 Mdot
.42946 .35365 Mdot
.59896 .14296 Mdot
.82015 .3789 Mdot
.63492 .24991 Mdot
.91695 .56049 Mdot
.72431 .64585 Mdot
.49858 .49376 Mdot
.38668 .54037 Mdot
.7095 .54631 Mdot
.38309 .23852 Mdot
.66153 .66992 Mdot
.33295 .62842 Mdot
.51565 .85992 Mdot
.81776 .50452 Mdot
.15831 .52493 Mdot
.32476 .77417 Mdot
.44147 .2244 Mdot
.51146 .56195 Mdot
.52936 .40877 Mdot
.52776 .63866 Mdot
.66682 .74652 Mdot
.7797 .31175 Mdot
.74435 .49936 Mdot
.6406 .85556 Mdot
.58918 .60182 Mdot
.57517 .72506 Mdot
.7528 .73229 Mdot
.67871 .58588 Mdot
.28631 .32391 Mdot
.7768 .45868 Mdot
.51796 .40914 Mdot
.57256 .56859 Mdot
.67909 .73008 Mdot
.24829 .40092 Mdot
.7915 .40849 Mdot
.59067 .81329 Mdot
.22161 .54047 Mdot
.576 .31533 Mdot
.77563 .50562 Mdot
.38848 .38784 Mdot
.66135 .54829 Mdot
.28986 .33636 Mdot
.82219 .5888 Mdot
.30335 .51622 Mdot
.83854 .5827 Mdot
.69411 .24848 Mdot
.60331 .38236 Mdot
.56076 .50432 Mdot
.48217 .3742 Mdot
.66952 .5493 Mdot
.68043 .40929 Mdot
.2242 .50074 Mdot
.80297 .63417 Mdot
.69239 .31583 Mdot
.34133 .58284 Mdot
.29918 .57387 Mdot
.74559 .74396 Mdot
.5081 .27095 Mdot
.56568 .6364 Mdot
.76426 .38249 Mdot
.40101 .22203 Mdot
.44149 .65279 Mdot
.16293 .52468 Mdot
.37826 .52489 Mdot
.64914 .24234 Mdot
.57146 .33303 Mdot
.51788 .21286 Mdot
.80341 .63448 Mdot
.4478 .74585 Mdot
.67982 .24489 Mdot
.67306 .61193 Mdot
.20695 .63105 Mdot
.37421 .6496 Mdot
.67549 .45717 Mdot
.28307 .68626 Mdot
.58093 .64424 Mdot
.54898 .27987 Mdot
.24883 .71465 Mdot
.52272 .75143 Mdot
.66934 .41699 Mdot
.6329 .2459 Mdot
.39287 .62451 Mdot
.40351 .43509 Mdot
.47839 .15226 Mdot
.55111 .4602 Mdot
.78758 .54194 Mdot
.38853 .76001 Mdot
.70711 .5305 Mdot
.6343 .81074 Mdot
.47762 .80822 Mdot
.63599 .16974 Mdot
.82724 .46608 Mdot
.52479 .71257 Mdot
.80434 .48033 Mdot
.82953 .54022 Mdot
.63392 .17386 Mdot
.54307 .48362 Mdot
.31869 .55506 Mdot
.28493 .2323 Mdot
.45202 .67777 Mdot
.77387 .59216 Mdot
.22589 .61809 Mdot
.52754 .61842 Mdot
.46939 .39252 Mdot
.50673 .44328 Mdot
.44194 .47703 Mdot
.4052 .29224 Mdot
.67824 .40659 Mdot
.55022 .16302 Mdot
.69415 .20897 Mdot
.58208 .1586 Mdot
.46653 .82726 Mdot
.80592 .44359 Mdot
.51641 .52622 Mdot
.17851 .46575 Mdot
.55382 .52359 Mdot
.6437 .4135 Mdot
.58472 .68232 Mdot
.71912 .65148 Mdot
.60241 .22501 Mdot
.30214 .43223 Mdot
.35485 .30321 Mdot
.67907 .72506 Mdot
.20167 .7322 Mdot
.56404 .25113 Mdot
.19432 .57729 Mdot
.5591 .65207 Mdot
.69554 .52838 Mdot
.6479 .74719 Mdot
.5572 .20952 Mdot
.78502 .66809 Mdot
.40412 .29259 Mdot
.23944 .66156 Mdot
.52071 .76931 Mdot
.40767 .41834 Mdot
.52642 .69843 Mdot
.77771 .63591 Mdot
.25254 .52395 Mdot
.52571 .19603 Mdot
.33491 .41038 Mdot
.48009 .24847 Mdot
.46525 .58529 Mdot
.31682 .64899 Mdot
.23107 .67917 Mdot
.45566 .78547 Mdot
.75424 .46205 Mdot
.47424 .49141 Mdot
.24101 .35499 Mdot
.3739 .57843 Mdot
.74792 .47365 Mdot
.47461 .41098 Mdot
.79306 .49674 Mdot
.61333 .11375 Mdot
.4799 .16784 Mdot
.70313 .77913 Mdot
.62722 .74398 Mdot
.67774 .4284 Mdot
.77053 .6921 Mdot
.55402 .14273 Mdot
.78871 .29214 Mdot
.30096 .65528 Mdot
.40807 .64466 Mdot
.37229 .5266 Mdot
.5873 .17795 Mdot
.62265 .72755 Mdot
.74032 .71398 Mdot
.76209 .49854 Mdot
.36931 .48117 Mdot
.21737 .30924 Mdot
.77487 .32391 Mdot
.58835 .3372 Mdot
.62519 .56678 Mdot
.66989 .45174 Mdot
.2746 .30322 Mdot
.3805 .37016 Mdot
.36876 .68967 Mdot
.70487 .51424 Mdot
.43529 .65882 Mdot
.67804 .68041 Mdot
.27749 .68715 Mdot
.61353 .39667 Mdot
.50553 .56916 Mdot
.43613 .39163 Mdot
.36964 .64396 Mdot
.24266 .45182 Mdot
.76047 .26587 Mdot
.55515 .65514 Mdot
.65711 .41468 Mdot
.71592 .52355 Mdot
.52794 .69093 Mdot
.66948 .22418 Mdot
.35685 .48138 Mdot
.82019 .53489 Mdot
.43307 .50447 Mdot
.66762 .54303 Mdot
.36586 .26693 Mdot
.61546 .53416 Mdot
.55698 .44346 Mdot
.51636 .81488 Mdot
.66256 .30734 Mdot
.37495 .42603 Mdot
.58709 .37247 Mdot
.55607 .52071 Mdot
.76317 .70117 Mdot
.54108 .62731 Mdot
.3207 .63893 Mdot
.8184 .56116 Mdot
.33024 .49991 Mdot
.44341 .37272 Mdot
.64369 .61346 Mdot
.25873 .68732 Mdot
.69791 .35634 Mdot
.65362 .23872 Mdot
.53475 .60503 Mdot
.53457 .74343 Mdot
.81717 .577 Mdot
.81343 .54285 Mdot
.23466 .32974 Mdot
.37615 .28585 Mdot
.71885 .46378 Mdot
.25243 .68719 Mdot
.41204 .31209 Mdot
.20844 .53485 Mdot
.21001 .51694 Mdot
.80116 .35954 Mdot
.49301 .56965 Mdot
.52661 .85897 Mdot
.73454 .58505 Mdot
.66477 .72002 Mdot
.49993 .18568 Mdot
.22139 .6562 Mdot
.76251 .63849 Mdot
.39714 .28478 Mdot
.53046 .32578 Mdot
.68156 .47099 Mdot
.20856 .41501 Mdot
.27698 .24905 Mdot
.64358 .6177 Mdot
.48115 .39828 Mdot
.597 .81242 Mdot
.58857 .44456 Mdot
.44618 .1685 Mdot
.26246 .67772 Mdot
.58062 .191 Mdot
.37514 .49076 Mdot
.6497 .44966 Mdot
.60132 .50324 Mdot
.77751 .42082 Mdot
.2917 .35767 Mdot
.79107 .484 Mdot
.29266 .76273 Mdot
.62191 .78462 Mdot
.37369 .26703 Mdot
.77456 .58253 Mdot
.70463 .73912 Mdot
.35326 .75831 Mdot
.48668 .52381 Mdot
.65701 .69804 Mdot
.69087 .58482 Mdot
.53507 .83789 Mdot
.45883 .41898 Mdot
.4044 .55165 Mdot
.24066 .50123 Mdot
.39623 .74259 Mdot
.57576 .20397 Mdot
.63732 .46954 Mdot
.7385 .29189 Mdot
.75846 .68675 Mdot
.25817 .31065 Mdot
.35162 .2351 Mdot
.48845 .16504 Mdot
.63523 .31019 Mdot
.42508 .77118 Mdot
.32125 .73269 Mdot
.2126 .67001 Mdot
.43002 .50717 Mdot
.7271 .66442 Mdot
.68064 .59844 Mdot
.81785 .57104 Mdot
.30946 .53607 Mdot
.32412 .39417 Mdot
.30241 .57933 Mdot
.79933 .48306 Mdot
.51046 .28281 Mdot
.78155 .64574 Mdot
.47104 .45525 Mdot
.64178 .16993 Mdot
.47879 .79651 Mdot
.45232 .46506 Mdot
.4366 .6225 Mdot
.46247 .74891 Mdot
.71495 .70293 Mdot
.49349 .79259 Mdot
.2134 .63149 Mdot
.40731 .62012 Mdot
.58002 .55819 Mdot
.52663 .36546 Mdot
.64579 .55422 Mdot
.51209 .81665 Mdot
.71516 .5243 Mdot
.79976 .62544 Mdot
.78499 .42042 Mdot
.73495 .28953 Mdot
.73042 .64279 Mdot
.44679 .83814 Mdot
.26959 .41147 Mdot
.59397 .58121 Mdot
.26792 .6809 Mdot
.5799 .73812 Mdot
.40773 .28733 Mdot
.32231 .1582 Mdot
.38175 .80958 Mdot
.45091 .7762 Mdot
.78024 .31464 Mdot
.47616 .81341 Mdot
.36816 .63228 Mdot
.4311 .24511 Mdot
.33605 .37331 Mdot
.727 .30321 Mdot
.62083 .42947 Mdot
.53957 .15465 Mdot
.68442 .52573 Mdot
.73603 .23434 Mdot
.73712 .72367 Mdot
.47822 .38843 Mdot
.54955 .43284 Mdot
.47616 .6725 Mdot
.43346 .54338 Mdot
.74274 .42161 Mdot
.48576 .2896 Mdot
.30664 .2987 Mdot
.37656 .58845 Mdot
.41651 .67178 Mdot
.52374 .685 Mdot
.38689 .29233 Mdot
.63889 .72424 Mdot
.39224 .73545 Mdot
.5044 .62319 Mdot
.41546 .47632 Mdot
.73125 .4948 Mdot
.27792 .34799 Mdot
.59988 .33755 Mdot
.56307 .20931 Mdot
.26117 .51678 Mdot
.46787 .67209 Mdot
.59879 .3309 Mdot
.4045 .80494 Mdot
.59865 .80147 Mdot
.7747 .30889 Mdot
.56185 .57075 Mdot
.49604 .31665 Mdot
.75926 .45836 Mdot
.36437 .24059 Mdot
.42943 .27628 Mdot
.37719 .61491 Mdot
.27324 .30824 Mdot
.42793 .26146 Mdot
.24167 .60998 Mdot
.81233 .38354 Mdot
.24125 .67017 Mdot
.25074 .68692 Mdot
.5161 .61994 Mdot
.69738 .39013 Mdot
.4461 .40467 Mdot
.72687 .57441 Mdot
.41495 .43882 Mdot
.14036 .4717 Mdot
.55908 .38652 Mdot
.12018 .44412 Mdot
.3365 .54933 Mdot
.41257 .23071 Mdot
.69099 .59359 Mdot
.48186 .49853 Mdot
.4725 .43943 Mdot
.46155 .79157 Mdot
.32236 .37698 Mdot
.3975 .77357 Mdot
.35891 .25772 Mdot
.41257 .66848 Mdot
.31361 .7861 Mdot
.46099 .84745 Mdot
.54946 .31941 Mdot
.59709 .39269 Mdot
.40386 .81909 Mdot
.41017 .64783 Mdot
.58828 .21793 Mdot
.64243 .80476 Mdot
.57449 .79516 Mdot
.50719 .3844 Mdot
.68497 .53522 Mdot
.73242 .66053 Mdot
.83423 .50569 Mdot
.26363 .27727 Mdot
.67324 .7325 Mdot
.31037 .53726 Mdot
.47362 .46885 Mdot
.75427 .6714 Mdot
.31996 .31094 Mdot
.29885 .52257 Mdot
.3004 .30926 Mdot
.11494 .51493 Mdot
.77699 .5911 Mdot
.78909 .49299 Mdot
.31929 .29607 Mdot
.44674 .34082 Mdot
.31185 .35187 Mdot
.28444 .32665 Mdot
.54822 .79864 Mdot
.36973 .78454 Mdot
.28542 .33222 Mdot
.16902 .61195 Mdot
.63872 .52888 Mdot
.40286 .70163 Mdot
.48646 .3842 Mdot
.72146 .38635 Mdot
.36547 .47564 Mdot
.75499 .33651 Mdot
.63287 .78689 Mdot
.33186 .55877 Mdot
.53172 .81708 Mdot
.28018 .67058 Mdot
.62781 .34837 Mdot
.68887 .35005 Mdot
.61418 .7793 Mdot
.50827 .30024 Mdot
.20831 .39038 Mdot
.65432 .25503 Mdot
.42062 .61573 Mdot
.66297 .77431 Mdot
.47131 .64627 Mdot
.53035 .49966 Mdot
.34063 .36789 Mdot
.66331 .66493 Mdot
.56773 .18136 Mdot
.58582 .61592 Mdot
.37933 .36366 Mdot
.27483 .25594 Mdot
.43311 .32907 Mdot
.56392 .16379 Mdot
.52427 .21134 Mdot
.29476 .28909 Mdot
.52126 .71978 Mdot
.50279 .74593 Mdot
.13369 .55524 Mdot
.29026 .53089 Mdot
.52437 .64226 Mdot
.2018 .45868 Mdot
.39252 .37664 Mdot
.5623 .67304 Mdot
.45936 .61885 Mdot
.40981 .50141 Mdot
.24518 .56882 Mdot
.6607 .51413 Mdot
.36523 .36593 Mdot
.41156 .48927 Mdot
.74712 .35803 Mdot
.80805 .41278 Mdot
.42255 .66421 Mdot
.14019 .42033 Mdot
.55189 .43727 Mdot
.5725 .30944 Mdot
.79185 .66276 Mdot
.21336 .31515 Mdot
.47667 .71401 Mdot
.47841 .85807 Mdot
.66362 .45571 Mdot
.63088 .75555 Mdot
.42364 .35073 Mdot
.24396 .66878 Mdot
.62081 .62505 Mdot
.70356 .53766 Mdot
.34858 .54948 Mdot
.52131 .19555 Mdot
.46226 .72366 Mdot
.38869 .30224 Mdot
.60062 .7684 Mdot
.72742 .40877 Mdot
.39353 .4844 Mdot
.49637 .72184 Mdot
.55246 .3229 Mdot
.69602 .36057 Mdot
.35276 .32811 Mdot
.79029 .51052 Mdot
.2597 .70925 Mdot
.76601 .26775 Mdot
.46573 .38782 Mdot
.51078 .49406 Mdot
.22435 .51957 Mdot
.5607 .81084 Mdot
.21881 .41696 Mdot
.80382 .64422 Mdot
.72684 .48242 Mdot
.70496 .44289 Mdot
.74256 .47253 Mdot
.64077 .51629 Mdot
.46064 .50462 Mdot
.34422 .66529 Mdot
.3211 .26736 Mdot
.25803 .36941 Mdot
.44872 .23315 Mdot
.21709 .38877 Mdot
.78238 .50148 Mdot
.29639 .29213 Mdot
.47268 .60755 Mdot
.65269 .34674 Mdot
.35558 .56519 Mdot
.81304 .41631 Mdot
.80046 .6499 Mdot
.32582 .5672 Mdot
.55337 .67903 Mdot
.5802 .83085 Mdot
.56691 .50081 Mdot
.53631 .54848 Mdot
.56764 .46983 Mdot
.61413 .55621 Mdot
.18775 .34968 Mdot
.55754 .80274 Mdot
.65523 .39875 Mdot
.81355 .51602 Mdot
.8132 .48699 Mdot
.68162 .19187 Mdot
.18471 .59557 Mdot
.3899 .35261 Mdot
.63852 .18332 Mdot
.30225 .30036 Mdot
.83562 .5186 Mdot
.37779 .67433 Mdot
.81413 .65954 Mdot
.53038 .32165 Mdot
.55561 .82257 Mdot
.42021 .24906 Mdot
.33262 .38026 Mdot
.39259 .7556 Mdot
.52163 .5436 Mdot
.30244 .61245 Mdot
.44812 .80078 Mdot
.27386 .76653 Mdot
.67066 .48046 Mdot
.31459 .7127 Mdot
.26465 .48508 Mdot
.67625 .76786 Mdot
.48816 .78221 Mdot
.57839 .40203 Mdot
.29087 .57109 Mdot
.55962 .18925 Mdot
.73602 .49526 Mdot
.5472 .53288 Mdot
.47684 .77829 Mdot
.70436 .29324 Mdot
.75409 .44639 Mdot
.24449 .68103 Mdot
.54399 .32474 Mdot
.43757 .53105 Mdot
.65888 .45746 Mdot
.35905 .33803 Mdot
.57564 .62806 Mdot
.52125 .55198 Mdot
.57208 .42319 Mdot
.49491 .66209 Mdot
.3898 .47165 Mdot
.52935 .16587 Mdot
.25427 .39939 Mdot
.29612 .72037 Mdot
.39273 .39638 Mdot
.29464 .45796 Mdot
.21618 .43673 Mdot
.46264 .17927 Mdot
.55113 .77226 Mdot
.74409 .49999 Mdot
.78977 .59378 Mdot
.79028 .42407 Mdot
.37113 .39366 Mdot
.73054 .24878 Mdot
.34159 .47868 Mdot
.60908 .34769 Mdot
.31945 .43579 Mdot
.53329 .65699 Mdot
.62412 .37431 Mdot
.5551 .82192 Mdot
.53368 .62148 Mdot
.76368 .58638 Mdot
.41053 .78073 Mdot
.688 .50389 Mdot
.54193 .35013 Mdot
.81796 .52856 Mdot
.48306 .67238 Mdot
.28828 .72941 Mdot
.39435 .50941 Mdot
.48253 .77375 Mdot
.79917 .43178 Mdot
.78624 .32804 Mdot
.45024 .44548 Mdot
.69038 .57191 Mdot
.60316 .47109 Mdot
.23434 .67983 Mdot
.55064 .80657 Mdot
.53378 .38854 Mdot
.2954 .63621 Mdot
.44458 .36608 Mdot
.32824 .68021 Mdot
.44891 .53224 Mdot
.7227 .30759 Mdot
.42111 .39319 Mdot
.28245 .29535 Mdot
.58497 .66425 Mdot
.49444 .47403 Mdot
.63881 .36993 Mdot
.70129 .56073 Mdot
.15337 .53792 Mdot
.59518 .36896 Mdot
.67812 .73557 Mdot
.57034 .32857 Mdot
.23995 .64723 Mdot
.61117 .77696 Mdot
.36772 .6077 Mdot
.32269 .37437 Mdot
.66988 .3487 Mdot
.25308 .53522 Mdot
.59759 .49119 Mdot
.4359 .60357 Mdot
.38995 .30553 Mdot
.66159 .78105 Mdot
.65251 .31414 Mdot
.72094 .57033 Mdot
.47983 .58133 Mdot
.5555 .5349 Mdot
.38232 .54087 Mdot
.80905 .65943 Mdot
.32351 .3675 Mdot
.71642 .50077 Mdot
.49396 .56949 Mdot
.69487 .58901 Mdot
.50939 .21934 Mdot
.81783 .36567 Mdot
.42034 .24615 Mdot
.41894 .46238 Mdot
.40519 .23434 Mdot
.43809 .77388 Mdot
.62596 .81854 Mdot
.74197 .46312 Mdot
.4848 .44638 Mdot
.60683 .59906 Mdot
.2228 .47875 Mdot
.45345 .58039 Mdot
.55764 .5467 Mdot
.41309 .50953 Mdot
.26679 .60602 Mdot
.31419 .46267 Mdot
.55901 .37322 Mdot
.74488 .6283 Mdot
.80075 .56895 Mdot
.2299 .62969 Mdot
.37952 .57716 Mdot
.40934 .72177 Mdot
.72766 .32611 Mdot
.81856 .66445 Mdot
.32503 .22402 Mdot
.60062 .47018 Mdot
.37432 .56501 Mdot
.67807 .5673 Mdot
.4851 .63362 Mdot
.26708 .34802 Mdot
.22407 .4332 Mdot
.31808 .53993 Mdot
.601 .57275 Mdot
.77382 .55305 Mdot
.40647 .74745 Mdot
.64134 .56846 Mdot
.30503 .57274 Mdot
.51093 .16361 Mdot
.43928 .81969 Mdot
.56466 .80857 Mdot
.86732 .58355 Mdot
.39576 .54232 Mdot
.55413 .51161 Mdot
.51475 .25295 Mdot
.80521 .42796 Mdot
.72127 .52458 Mdot
.62987 .23147 Mdot
.33918 .60419 Mdot
.73864 .46465 Mdot
.42569 .29515 Mdot
.75759 .60646 Mdot
.32163 .67642 Mdot
.45918 .48767 Mdot
.50505 .74948 Mdot
.74177 .25243 Mdot
.51281 .36691 Mdot
.79194 .60287 Mdot
.52495 .1832 Mdot
.20211 .66 Mdot
.81292 .43852 Mdot
.74182 .60067 Mdot
.53085 .78296 Mdot
.48599 .26152 Mdot
.47265 .41035 Mdot
.36187 .28132 Mdot
.59522 .2205 Mdot
.69663 .34269 Mdot
.563 .70502 Mdot
.46263 .21594 Mdot
.75405 .46272 Mdot
.70519 .34056 Mdot
.48402 .44227 Mdot
.61248 .33516 Mdot
.5487 .67706 Mdot
.31299 .30622 Mdot
.43594 .4204 Mdot
.737 .5464 Mdot
.58557 .32836 Mdot
.2271 .53344 Mdot
.46916 .80532 Mdot
.19268 .66454 Mdot
.60734 .74161 Mdot
.45494 .18678 Mdot
.63631 .40268 Mdot
.68275 .17786 Mdot
.40867 .76397 Mdot
.4288 .75183 Mdot
.38143 .77879 Mdot
.38664 .63329 Mdot
.58009 .5276 Mdot
.59832 .49126 Mdot
.70822 .70659 Mdot
.50571 .38364 Mdot
.59834 .23921 Mdot
.50158 .1928 Mdot
.69569 .53464 Mdot
.75879 .50356 Mdot
.72983 .58017 Mdot
.69956 .43321 Mdot
.43959 .34349 Mdot
.59152 .16123 Mdot
.42992 .44862 Mdot
.53052 .39388 Mdot
.65937 .37139 Mdot
.4766 .24861 Mdot
.54381 .8668 Mdot
.47333 .38575 Mdot
.77814 .47063 Mdot
.52631 .34552 Mdot
.38288 .40826 Mdot
.22271 .39691 Mdot
.91782 .47764 Mdot
.72616 .19939 Mdot
.38046 .30734 Mdot
.18772 .56269 Mdot
.52397 .35084 Mdot
.79498 .48769 Mdot
.52961 .76855 Mdot
.27458 .6262 Mdot
.55246 .36868 Mdot
.36764 .40807 Mdot
.65774 .38345 Mdot
.38043 .7624 Mdot
.81929 .41155 Mdot
.47821 .19758 Mdot
.81345 .51887 Mdot
.64006 .51967 Mdot
.63847 .37328 Mdot
.85574 .63081 Mdot
.76234 .66123 Mdot
.54449 .4508 Mdot
.39424 .2492 Mdot
.53947 .39876 Mdot
.63584 .44243 Mdot
.65991 .70942 Mdot
.31318 .78467 Mdot
.75988 .45477 Mdot
.79897 .4836 Mdot
.39364 .38451 Mdot
.39165 .66012 Mdot
.33782 .54992 Mdot
.45771 .44245 Mdot
.54073 .43923 Mdot
.31908 .51283 Mdot
.69245 .50771 Mdot
.58726 .82137 Mdot
.44491 .57213 Mdot
.29906 .75779 Mdot
.84446 .58544 Mdot
.64175 .31677 Mdot
.22627 .46998 Mdot
.57708 .50476 Mdot
.71722 .3734 Mdot
.73535 .36893 Mdot
.59355 .55089 Mdot
.50726 .82828 Mdot
.42073 .11254 Mdot
.28187 .57791 Mdot
.74086 .31982 Mdot
.43915 .32319 Mdot
.42297 .52421 Mdot
.55647 .35181 Mdot
.38096 .66178 Mdot
.42012 .64967 Mdot
.65975 .50868 Mdot
.44202 .39521 Mdot
.37805 .49018 Mdot
.14834 .38706 Mdot
.6039 .39069 Mdot
.24472 .37418 Mdot
.83222 .52647 Mdot
.65322 .2539 Mdot
.54287 .29553 Mdot
.62528 .49247 Mdot
.26638 .44964 Mdot
.48542 .45014 Mdot
.66455 .75904 Mdot
.74192 .30104 Mdot
.79752 .55672 Mdot
.65754 .31571 Mdot
.53753 .35047 Mdot
.65874 .45051 Mdot
.63698 .65394 Mdot
.30586 .48442 Mdot
.68534 .7123 Mdot
.5351 .4169 Mdot
.83459 .47654 Mdot
.44705 .73047 Mdot
.53539 .57645 Mdot
.4747 .36366 Mdot
.6734 .19014 Mdot
.4864 .2319 Mdot
.41934 .40912 Mdot
.47361 .17443 Mdot
.51026 .69422 Mdot
.64451 .55833 Mdot
.47699 .67407 Mdot
.53454 .46214 Mdot
.40213 .39351 Mdot
.4583 .16161 Mdot
.68222 .70048 Mdot
.30383 .60664 Mdot
.3139 .64458 Mdot
.20989 .58927 Mdot
.39177 .48317 Mdot
.87081 .56398 Mdot
.48818 .73125 Mdot
.47758 .16289 Mdot
.26676 .71513 Mdot
.40821 .39763 Mdot
.48597 .80967 Mdot
.56882 .38264 Mdot
.42767 .66502 Mdot
.80658 .52795 Mdot
.51713 .45891 Mdot
.66351 .23693 Mdot
.6559 .47878 Mdot
.61376 .20024 Mdot
.61229 .59607 Mdot
.56519 .68352 Mdot
.43832 .76888 Mdot
.48028 .24488 Mdot
.73734 .7406 Mdot
.22107 .48409 Mdot
.77137 .70005 Mdot
.71636 .75576 Mdot
.82303 .52684 Mdot
.62594 .22044 Mdot
.23848 .30199 Mdot
.44855 .77019 Mdot
.60566 .78589 Mdot
.36173 .68603 Mdot
.46235 .2556 Mdot
.45975 .75087 Mdot
.47876 .36031 Mdot
.2908 .36095 Mdot
.34732 .57225 Mdot
.16562 .30386 Mdot
.7615 .53075 Mdot
.44955 .39647 Mdot
.47675 .7452 Mdot
.82278 .49141 Mdot
.4877 .25484 Mdot
.43905 .79861 Mdot
.45231 .52749 Mdot
.67269 .46358 Mdot
.68613 .33879 Mdot
.2214 .6206 Mdot
.46233 .73511 Mdot
.14627 .61188 Mdot
.41322 .80536 Mdot
.28627 .61044 Mdot
.45134 .50128 Mdot
.37435 .3217 Mdot
.20155 .41888 Mdot
.51266 .73976 Mdot
.49121 .82696 Mdot
.56858 .82334 Mdot
.75704 .66849 Mdot
.13428 .55179 Mdot
.2452 .66345 Mdot
.80691 .41894 Mdot
.50624 .808 Mdot
.38654 .30052 Mdot
.72942 .61319 Mdot
.41425 .62848 Mdot
.32988 .63117 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Hooooo`;o0000[oooool001cooooo00?o
0000ooooooooool0V?ooool2o`000:oooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo08Gooooo0_l0000looooo`;o0000Q?ooool001co
oooo00?o0000ooooooooool0QOooool2o`0003cooooo0_l00024ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0:Cooooo0_l0002Sooooo`007?ooool0
0ol0003oooooooooo`2Tooooo`;o0000Xoooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo09Sooooo
0_l0002_ooooo`007?ooool00ol0003oooooooooo`2Hooooo`;o00006Oooool2o`0009Cooooo000L
ooooo`03o`000?oooooooooo0;?ooooo0_l0002Dooooo`007?ooool00ol0003oooooooooo`2`oooo
o`;o00003Oooool2o`0008Sooooo000Looooo`03o`000?oooooooooo0;3ooooo0_l0000=ooooo`;o
0000R?ooool001cooooo00?o0000ooooooooool0Poooool4o`000<;ooooo000Looooo`;o0000Q?oo
ool4o`00017ooooo0_l0000Sooooo`;o00000_ooool2o`0008Kooooo000Looooo`03o`000?oooooo
oooo09Sooooo0_l0000Booooo`;o00003oooool2o`0000;ooooo0_l00026ooooo`007?ooool00ol0
003oooooooooo`1Uooooo`;o0000@?ooool2o`0000?ooooo0_l0000;ooooo`;o0000S_ooool001co
oooo00?o0000ooooooooool0IOooool2o`0002[ooooo0_l00004ooooo`;o00001_ooool2o`0000Ko
oooo0_l00006ooooo`;o00002?ooool2o`000003ooooool0003o000008_ooooo000Looooo`03o`00
0?oooooooooo097ooooo0_l00004ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000
o`000004ooooo`;o00001Oooool2o`0000;ooooo0_l00007ooooo`;o0000Roooool001cooooo00?o
0000ooooooooool0SOooool2o`0000Wooooo0_l000000ooooooo0000o`000005ooooo`;o00001?oo
ool2o`0000Wooooo0_l0002Dooooo`007?ooool00ol0003oooooooooo`2=ooooo`;o00002Oooool2
o`00037ooooo1?l0001jooooo`007?ooool00ol0003oooooooooo`1gooooo`;o00003oooool3o`00
00_ooooo0_l00005ooooo`;o0000:oooool5o`0007[ooooo000Looooo`03o`000?oooooooooo07Oo
oooo0_l0000?ooooo`?o00002_ooool3o`0000Gooooo0_l00002ooooo`?o00005oooool2o`0000go
oooo0_l0000>ooooo`;o0000KOooool001cooooo00?o0000ooooooooool0ROooool2o`0000Sooooo
1Ol00009ooooo`?o00000oooool2o`0000Gooooo1?l00003ooooo`;o00001?ooool2o`0001gooooo
0_l0001]ooooo`007?ooool00ol0003oooooooooo`1aooooo`;o00005_ooool2o`0000Sooooo0_l0
00000ooooooo0000o`00000?ooooo`;o00001Oooool4o`0000?ooooo0_l0000Eooooo`;o00001Ooo
ool2o`0007Cooooo000Looooo`03o`000?oooooooooo077ooooo0_l0000Mooooo`;o00003Oooool3
o`0000Gooooo0_l00005ooooo`;o00000_ooool2o`0001Sooooo0_l00005ooooo`;o0000M?ooool0
01cooooo00?o0000ooooooooool0T?ooool2o`0000gooooo0ol00007ooooo`;o00000oooool2o`00
00;ooooo0_l0000Eooooo`;o00003?ooool2o`00073ooooo00001_ooooook^k^oc8b<_l0003o<S8b
onk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`1[ooooo`;o0000;_ooool2
o`0000;ooooo0_l00008ooooo`;o00000oooool2o`0000;ooooo0_l00005ooooo`;o00003_ooool2
o`0000cooooo0_l000000ooooooo0000o`00001]ooooo`0000KoooooogMgMonHV9SooooooiRHV?mg
MgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0
Eoooool2o`0000kooooo0_l00002ooooo`;o00009Oooool2o`0000Oooooo0_l00002ooooo`;o0000
1Oooool3o`00013ooooo0_l00002ooooo`;o00006oooool2o`0006gooooo00000ooooooo410@oooo
o`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003ooooooooo
o`1Gooooo`;o00003_ooool2o`0002Sooooo0ol00004ooooo`;o00003?ooool3o`0001Cooooo0_l0
000<ooooo`;o00006oooool2o`0005oooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`00097ooooo0_l00005ooooo`;o00007?ooool2
o`000003ooooool0003o000000Wooooo1?l00003ooooo`?o00006_ooool2o`0005oooooo00000ooo
oooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0
003oooooooooo`2Dooooo`;o00003_ooool2o`00013ooooo1Ol000000ooooooo0000o`000006oooo
o`Co00001?ooool2o`0007_ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2?ooooo`;o00000oooool2o`0000ko
oooo0_l0000?ooooo`Co00000oooool2o`00017ooooo0_l0000=ooooo`;o0000JOooool00006oooo
oomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000
ooooooooool0HOooool2o`0000Gooooo0_l0000Uooooo`;o00004oooool2o`000003ooooool0003o
000000Sooooo1ol0000Gooooo`;o00002Oooool2o`0000;ooooo0_l0001Yooooo`0000Koooooonk^
k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`1Qooooo`;o00001Oooool2o`0000gooooo0_l00006ooooo`?o00003?ooool2o`0001Cooooo
0_l000000ooooooo0000o`000007ooooo`Go00001_ooool2o`0000Kooooo0_l00003ooooo`;o0000
00?oooooo`000?l000000oooool2o`0000Sooooo0_l0001]ooooo`007?ooool00ol0003ooooooooo
o`1gooooo`?o00001Oooool3o`0000cooooo0_l00003ooooo`;o00003oooool2o`0000[ooooo0ol0
0008ooooo`;o00001_ooool4o`000003ooooool0003o000000?o00000oooool2o`0001Cooooo0_l0
001Qooooo`007?ooool00ol0003oooooooooo`1hooooo`;o00006Oooool2o`0000gooooo0_l0000B
ooooo`;o00000oooool2o`000003ooooool0003o000000?ooooo1?l000001?oooooo0000o`000?l0
000Kooooo`;o0000HOooool001cooooo00?o0000ooooooooool0I_ooool2o`0001Cooooo0_l00000
0ooooooo0000o`00000;ooooo`;o00005?ooool2o`0000gooooo1?l000000ooooooo0000o`000006
ooooo`;o00000oooool2o`0000?ooooo0_l0000<ooooo`;o00003oooool2o`00063ooooo000Loooo
o`03o`000?oooooooooo06Kooooo0_l0000=ooooo`;o00001Oooool2o`000003ooooool0003o0000
00_ooooo0_l00006ooooo`;o00001oooool2o`0000gooooo0_l00003ooooo`Co00002Oooool5o`00
01?ooooo0_l0000?ooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0Boooool2o`0002?o
oooo0_l00003ooooo`;o00001?ooool2o`0000Gooooo0_l00005ooooo`;o00002Oooool2o`0000?o
oooo0_l00002ooooo`;o00003Oooool2o`0000Gooooo1?l00007ooooo`Go00002Oooool2o`0000Ko
oooo0_l00005ooooo`;o0000K?ooool001cooooo00?o0000ooooooooool0Boooool4o`0000[ooooo
0_l00003ooooo`;o00004?ooool2o`0000Wooooo0ol00004ooooo`;o00001Oooool2o`0000?ooooo
0_l00002ooooo`;o00001Oooool3o`0001Oooooo1?l00005ooooo`;o00001oooool2o`0000;ooooo
0_l000000ooooooo0000o`000004ooooo`Co00000oooool4o`0006cooooo000Looooo`03o`000?oo
oooooooo04gooooo0_l00004ooooo`;o00001?ooool2o`0000?ooooo0_l0000<ooooo`Ko00002_oo
ool6o`0000cooooo0_l00002ooooo`;o00001_ooool2o`0000[ooooo0_l00002ooooo`;o00004?oo
ool2o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o00001oooool4o`0000?ooooo0_l0
0005ooooo`;o00002Oooool2o`0005cooooo000Looooo`03o`000?oooooooooo05?ooooo0_l0000D
ooooo`;o000000?oooooo`000?l000001?l00007ooooo`;o000000?oooooo`000?l000001?l00004
ooooo`;o00001_ooool2o`0000;ooooo0_l00006ooooo`;o00001?ooool2o`0000Cooooo0_l00002
ooooo`;o00004oooool2o`000004ooooool0003o0000ooooo`;o00000oooool2o`0000Gooooo0_l0
00000ooooooo0000o`00000:ooooo`;o00002Oooool4o`0000;ooooo0_l0001Fooooo`007?ooool0
0ol0003oooooooooo`1Rooooo`;o00001Oooool2o`0000Sooooo0_l00004ooooo`;o00002oooool4
o`0000Cooooo0_l000001?oooooo0000o`000?l00009ooooo`;o000000?oooooo`000?l000000_l0
0002ooooo`;o00005oooool2o`0000?ooooo0ol00003ooooo`;o00000oooool4o`000003ooooool0
003o000000Kooooo0_l0000?ooooo`;o00000_ooool2o`0005Kooooo000Looooo`03o`000?oooooo
oooo06;ooooo0_l000000ooooooo0000o`00000<ooooo`;o00001Oooool2o`0000Wooooo0_l00000
0ooooooo0000o`000007ooooo`Co00000oooool2o`0000?ooooo0_l00003ooooo`;o00000_ooool3
o`0001Kooooo0_l00002ooooo`?o00001?ooool2o`0000?ooooo0_l00003ooooo`?o00000_ooool2
o`000003ooooool0003o000006_ooooo000Looooo`03o`000?oooooooooo05Kooooo0_l0000=oooo
o`;o00003?ooool2o`0000Gooooo1?l00007ooooo`;o000000Coooooo`000?l0003ooooo0_l00000
1?oooooo0000o`000?l00002ooooo`;o00000_ooool3o`0000Cooooo0_l00007ooooo`;o00000ooo
ool2o`00017ooooo0_l00002ooooo`;o00001Oooool2o`0000;ooooo0_l00005ooooo`;o00000_oo
ool2o`0000?ooooo0_l00009ooooo`;o0000G_ooool001cooooo0_l0001Gooooo`;o00002_ooool2
o`0000oooooo1?l00005ooooo`;o00001oooool2o`0000Cooooo0_l000001?oooooo0000o`000?l0
0006ooooo`Go00000_ooool2o`0000cooooo0_l00005ooooo`;o00005Oooool2o`0000;ooooo0_l0
0006ooooo`;o00001_ooool2o`0000Wooooo0_l0001Nooooo`007?ooool00ol0003oooooooooo`1R
ooooo`;o00001_ooool2o`0000Wooooo0_l0000:ooooo`;o000000?oooooo`000?l000002Oooool3
o`0000?ooooo0_l00003ooooo`?o00001_ooool2o`0000kooooo0_l0000Eooooo`;o00001?ooool3
o`0000?ooooo0_l00008ooooo`;o00002oooool2o`0005[ooooo000Looooo`03o`000?oooooooooo
05Kooooo0_l0000Booooo`;o00001Oooool2o`0000gooooo0ol000000ooooooo0000o`00000:oooo
o`Co000000?oooooo`000?l000001?ooool2o`0000Kooooo0_l0000[ooooo`?o00001Oooool2o`00
00Kooooo0_l0000;ooooo`;o0000F_ooool001cooooo00?o0000ooooooooool0EOooool3o`0000Go
oooo0_l0000Booooo`;o00002oooool4o`0000Gooooo0_l00009ooooo`;o00001Oooool3o`000004
ooooool0003o0000o`00017ooooo1?l0000Hooooo`Co00001oooool2o`0000;ooooo0_l000000ooo
oooo0000o`000008ooooo`;o00000_ooool2o`000003ooooool0003o000005Oooooo000Looooo`03
o`000?oooooooooo05Gooooo0_l00006ooooo`;o00003Oooool2o`00013ooooo0_l00007ooooo`;o
00004?ooool7o`00017ooooo1?l0000Hooooo`Co00002oooool2o`000003ooooool0003o000000;o
oooo0_l00004ooooo`;o00000_ooool2o`000003ooooool0003o000005Oooooo000Looooo`03o`00
0?oooooooooo05cooooo0_l00002ooooo`;o00000oooool2o`0000Gooooo0_l00005ooooo`;o0000
00?oooooo`000?l000009?ooool2o`0003Oooooo0_l00005ooooo`?o00001?ooool2o`0000;ooooo
0_l0000:ooooo`Co0000D_ooool001cooooo00?o0000ooooooooool0?oooool2o`0000Gooooo0_l0
000Dooooo`;o00000_ooool2o`0000;ooooo0ol0000<ooooo`Oo0000Foooool3o`0000Gooooo0_l0
0005ooooo`;o000000?oooooo`000?l000002_ooool4o`0005;ooooo000Looooo`03o`000?oooooo
oooo03oooooo0_l000000ooooooo0000o`000002ooooo`;o00007?ooool2o`0000;ooooo0_l0000;
ooooo`;o000000?oooooo`000?l000002Oooool2o`0001cooooo0_l0000<ooooo`Co00008oooool2
o`0000cooooo0_l0001Sooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00009?ooool2o`00
00oooooo0ol000000ooooooo0000o`000004ooooo`;o00000oooool4o`000003ooooool0003o0000
01;ooooo0_l0000<ooooo`Co0000=_ooool2o`0000Oooooo0_l000000ooooooo0000o`00001Boooo
o`007?ooool00ol0003oooooooooo`1>ooooo`;o00000_ooool2o`0001cooooo0_l00003ooooo`;o
00000_ooool3o`000003ooooool0003o000000Wooooo1?l000000ooooooo0000o`000002o`0001ko
oooo0_l00004ooooo`;o0000<?ooool4o`0000Oooooo0_l000000ooooooo0000o`00001Booooo`00
7?ooool00ol0003oooooooooo`1>ooooo`;o00000_ooool2o`0001cooooo1?l000000ooooooo0000
o`00000Dooooo`;o00000_ooool2o`00017ooooo0_l0000;ooooo`Co00000_ooool2o`0001cooooo
1?l0000=ooooo`;o000000?oooooo`000?l000002_ooool2o`0000Kooooo0_l0001<ooooo`007?oo
ool00ol0003oooooooooo`1:ooooo`;o00006_ooool2o`0000?ooooo0_l00005ooooo`;o00000_oo
ool2o`0000Gooooo0_l0000<ooooo`Co00004oooool2o`0000Wooooo0_l00002ooooo`;o00008?oo
ool4o`0000Sooooo0_l00003ooooo`;o00003Oooool2o`0000Kooooo0_l0001<ooooo`007?ooool0
0ol0003oooooooooo`1:ooooo`;o00004?ooool2o`000003ooooool0003o000000Gooooo0_l00002
ooooo`?o00000oooool2o`0000Cooooo0_l00003ooooo`Co00000_ooool3o`0000Wooooo0_l0000C
ooooo`;o000000?oooooo`000?l000001_ooool2o`000003ooooool0003o000002gooooo0_l0000;
ooooo`;o0000Foooool001cooooo00?o0000ooooooooool0G?ooool5o`0000Oooooo1?l00004oooo
o`?o00001oooool:o`0001Kooooo0ol00005ooooo`;o000000?oooooo`000?l000002Oooool3o`00
00;ooooo0_l0000_ooooo`;o00000oooool3o`0000kooooo0_l0001;ooooo`007?ooool00ol0003o
ooooooooo`19ooooo`;o00003Oooool2o`0000?ooooo0_l00009ooooo`;o00001oooool2o`0000Go
oooo1Ol00002ooooo`?o00001Oooool2o`00017ooooo0ol0000@ooooo`;o00000_ooool3o`000003
ooooool0003o0000023ooooo0_l00007ooooo`?o00000oooool2o`0000?ooooo0ol0000>ooooo`;o
0000Boooool001cooooo00?o0000ooooooooool0BOooool2o`0000?ooooo0_l00008ooooo`;o0000
2_ooool2o`0001;ooooo1?l000000ooooooo0000o`000003o`0000Gooooo0_l000000ooooooo0000
o`00000Qooooo`;o00000oooool2o`000003ooooool0003o000000;o00007_ooool2o`0000Gooooo
1Ol00008ooooo`?o00002oooool2o`0004kooooo000Looooo`;o0000Coooool2o`0000kooooo1?l0
0002ooooo`;o00003oooool7o`000003ooooool0003o000000?o00002?ooool2o`00013ooooo1?l0
00000ooooooo0000o`00000Dooooo`;o00008?ooool2o`0000?ooooo0_l0000;ooooo`Co00002_oo
ool2o`0004kooooo000Looooo`03o`000?oooooooooo03;ooooo0_l0000>ooooo`;o00000_ooool2
o`0000;ooooo0_l00009ooooo`;o00001Oooool7o`0000;ooooo0_l00009ooooo`;o00000oooool:
o`000003ooooool0003o000000[ooooo0_l0000>ooooo`Co000000?oooooo`000?l000009Oooool2
o`0000oooooo0_l0000=ooooo`;o00000oooool2o`0005[ooooo000Looooo`03o`000?oooooooooo
03;ooooo0_l00009ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`;o00002Oooool2o`00
00Gooooo0_l00003ooooo`?o000000?oooooo`000?l000002Oooool?o`0000;ooooo0_l000000ooo
oooo0000o`000006ooooo`;o00000oooool2o`0002Gooooo0_l0000<ooooo`Go00002?ooool2o`00
01;ooooo0ol0001Oooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00001?ooool2o`0000_o
oooo0_l00003ooooo`;o00001oooool2o`0000;ooooo1Ol00002ooooo`;o00001oooool;o`000003
ooooool0003o000000Oo00001?ooool2o`0000Cooooo0_l00002ooooo`Co00002oooool2o`00013o
oooo1?l0000<ooooo`;o000000?oooooo`000?l000000_l00006ooooo`;o00001_ooool2o`0000Co
oooo0_l00004ooooo`;o00002?ooool2o`0000Gooooo0_l0001?ooooo`007?ooool00ol0003ooooo
ooooo`13ooooo`;o00002oooool2o`0000?ooooo0_l00007ooooo`;o00001?ooool3o`0000;ooooo
0_l0000<oooooa;o00000_ooool2o`0000Gooooo0_l000000ooooooo0000o`000002o`0000_ooooo
0ol000000ooooooo0000o`000008ooooo`;o00000_ooool2o`0001?ooooo0_l0000>ooooo`?o0000
0oooool2o`0000Wooooo0_l00003ooooo`Co00000_ooool4o`0004kooooo000Looooo`03o`000?oo
oooooooo04;ooooo0_l0000Booooo`;o00001?ooool2o`0000Gooooo0_l0000:ooooo`?o00000_oo
oolEo`0000Wooooo0_l00009ooooo`;o00001_ooool2o`000003ooooool0003o000000Sooooo0_l0
0003ooooo`;o00001?ooool2o`0000kooooo0_l000000ooooooo0000o`000003o`0000Oooooo0ol0
000=ooooo`;o00000oooool4o`0000;ooooo1Ol0001=ooooo`007?ooool00ol0003oooooooooo`12
ooooo`;o00003_ooool2o`000004ooooool0003o0000o`0000Cooooo0_l00005ooooo`;o00001_oo
ool2o`0000;ooooo0ol00002oooooaKo00004oooool4o`0000kooooo0_l00006ooooo`;o00001?oo
ool2o`0000kooooo0_l000000ooooooo0000o`000003o`0000Sooooo0_l0000>ooooo`;o00000_oo
ool2o`0000Gooooo1?l0001=ooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o00000_ooool2
o`000003ooooool0003o000000Gooooo0_l0000=ooooo`;o00001Oooool2o`000003ooooool0003o
000000?o000000?oooooo`000?l000003Ol000000ooooooo0000o`00000Booooo`;o00001oooool3
o`0000Cooooo0ol0000Qooooo`;o00003?ooool2o`000003ooooool0003o000000?ooooo0_l00002
ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`00001?ooooo`007?ooool00ol0
003oooooooooo`1>ooooo`;o00002Oooool2o`0001Kooooo2ol000000ooooooo0000o`00000>o`00
01_ooooo0ol00002ooooo`;o000000?oooooo`000?l000001_ooool2o`0002Oooooo0_l000000ooo
oooo0000o`000003ooooo`;o00001_ooool2o`0000;ooooo0_l000000ooooooo0000o`00001?oooo
o`007?ooool00ol0003oooooooooo`19ooooo`;o00001_ooool2o`0000Kooooo0_l0000;ooooo`;o
00001oooool>o`000003ooooool0003o0000017o00006?ooool2o`0000;ooooo0_l00006ooooo`;o
000000?oooooo`000?l000000_l0000@ooooo`;o00000oooool2o`0001Kooooo0_l00006ooooo`;o
00000_ooool2o`000003ooooool0003o000000;ooooo0_l0001;ooooo`007?ooool00ol0003ooooo
ooooo`19ooooo`;o00001_ooool2o`0000Kooooo0_l0000;ooooo`;o00001oooool2o`0000Cooooo
7?l00005ooooo`;o00007Oooool2o`000003ooooool0003o000000;o00000oooool2o`0000_ooooo
0_l00003ooooo`;o00006_ooool6o`0000;ooooo0_l00005ooooo`;o0000Boooool001cooooo00?o
0000ooooooooool0=oooool2o`00013ooooo0_l0000>ooooo`;o00004oooool6o`000003ooooool0
003o000001Ko00002Oooool2o`0001Kooooo0_l00006ooooo`Co00001Oooool2o`0000;ooooo0_l0
000@ooooo`;o00005_ooool4o`0000Gooooo0ol0001@ooooo`007?ooool00ol0003oooooooooo`0g
ooooo`;o00004_ooool2o`0000gooooo0_l0000Boooooa7o000000Coooooo`000?l0003ooooo2?l0
0002ooooo`;o00003oooool2o`0000kooooo0_l00006ooooo`;o00000oooool2o`0000;ooooo0_l0
0002ooooo`;o00001oooool2o`0000Oooooo0_l0000Booooo`;o00001_ooool;o`0000;ooooo0_l0
0019ooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o00000oooool4o`0000Kooooo0_l0000E
oooooa7o000000?oooooo`000?l000001_l00002ooooo`Go000000?oooooo`000?l000002Oooool2
o`0001_ooooo0_l00002ooooo`;o00002oooool2o`0000gooooo0_l00004ooooo`;o00000_ooool2
o`0000;ooooo0_l00006ooooo`Go00000_ooool4o`0000;ooooo0_l00019ooooo`007?ooool00ol0
003oooooooooo`1;ooooo`;o00000_ooool5o`0001?ooooo1?l0000:oooooago000000?oooooo`00
0?l000009_ooool2o`0000;ooooo0ol0000Cooooo`;o00001?ooool2o`000004ooooool0003o0000
ooooo`;o00000_ooool2o`0000;ooooo1?l00007ooooo`;o00000_ooool2o`0004oooooo000Loooo
o`03o`000?oooooooooo04_ooooo0_l00002ooooo`;o00002?ooool2o`0000Sooooo0_l00002oooo
o`Co00002OoooolKo`0000Gooooo0_l00002ooooo`;o00003Oooool2o`00017ooooo0ol00002oooo
o`Go00003?ooool2o`0000?ooooo0_l00007ooooo`;o00002oooool2o`0000_ooooo0_l0000;oooo
o`;o0000@_ooool001cooooo0_l0000jooooo`;o00005?ooool2o`0000;ooooo0_l00002ooooo`Co
000000?oooooo`000?l000000_l00003ooooo`;o00000_ooool2o`0000_ooooo5?l000000ooooooo
0000o`000006o`0000?ooooo0_l00002ooooo`;o00002?ooool2o`0000;ooooo0ol00002ooooo`?o
00001?ooool2o`0000Kooooo0_l00006ooooo`Co00000_ooool2o`0000;ooooo0_l00002ooooo`;o
00000oooool3o`0000Cooooo1Ol0000:ooooo`;o00006?ooool2o`0004;ooooo000Looooo`03o`00
0?oooooooooo03Wooooo0_l0000Dooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`Co0000
0_ooool2o`0000;ooooo0ol00003ooooo`Co00000ooooolNo`000003ooooool0003o000000Wooooo
0_l00003ooooo`;o00000_ooool2o`0000?ooooo0ol00003ooooo`?o00003oooool3o`0000;ooooo
0_l00002ooooo`;o00001oooool3o`0000Cooooo1Ol00006ooooo`;o00000_ooool2o`0005cooooo
000Looooo`03o`000?oooooooooo04_ooooo0_l0000:ooooo`;o00001?ooool2o`0000?ooooo0_l0
0002ooooo`;o00001?ooool4o`000003ooooool0003o000001go00000_ooool2o`0000Sooooo0ol0
0002ooooo`;o00000oooool2o`000003ooooool0003o000000Kooooo0_l0000@ooooo`;o00006_oo
ool2o`0000Kooooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00001?ooool4
o`0000cooooo1?l00004ooooo`;o000000?oooooo`000?l000001_ooool2o`000003ooooool0003o
000000go000000?oooooo`000?l000001_l000000ooooooo0000o`000006o`0000[ooooo0_l00003
ooooo`?o00000_ooool2o`000003ooooool0003o000000oooooo0_l00005ooooo`Co00006_ooool2
o`0000kooooo0_l00006ooooo`;o00001oooool2o`0004Oooooo000Looooo`03o`000?oooooooooo
04Cooooo0ol00004ooooo`Co00003?ooool2o`0000Gooooo0ol000000ooooooo0000o`000006oooo
o`;o00000oooool8o`000003ooooool0003o000000;o000000?oooooo`000?l000003ol00006oooo
o`;o00001Oooool2o`000003ooooool0003o000001Kooooo0_l00005ooooo`;o00001oooool2o`00
01;ooooo0_l0000?ooooo`;o00001_ooool2o`000003ooooool0003o000000Cooooo1?l00002oooo
o`;o0000@Oooool001cooooo00?o0000ooooooooool0A?ooool2o`0000Gooooo0_l00009ooooo`;o
00000oooool2o`0000Cooooo0ol0000?ooooo`So000000?oooooo`000?l000004ol00005ooooo`Co
00001Oooool2o`0000Kooooo0_l0000<ooooo`;o00001oooool2o`0000Gooooo0_l00003ooooo`;o
00002oooool2o`0000Gooooo0_l00005ooooo`;o00003Oooool2o`000004ooooool0003o0000oooo
o`;o00001?ooool4o`0000;ooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o
000000?oooooo`000?l000002Oooool5o`0000?ooooo0_l00009ooooo`;o00000_ooool2o`0000Co
oooo1?l00004oooooago00001_ooool2o`0000Wooooo1?l00002ooooo`;o00001oooool2o`0000?o
oooo0_l00007ooooo`Co00000_ooool3o`0000Cooooo0_l0000:ooooo`;o00000oooool2o`0000Oo
oooo0_l00004ooooo`;o00000_ooool2o`0000?ooooo0_l0000:ooooo`;o00001?ooool2o`00047o
oooo000Looooo`03o`000?oooooooooo043ooooo0_l000000ooooooo0000o`000009ooooo`Go0000
4_ooool2o`0000Cooooo1?l00006oooooago00003oooool4o`0000Gooooo0_l00004ooooo`;o0000
1?ooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0ol00004ooooo`Go0000
0_ooool2o`000003ooooool0003o000000Gooooo0_l0000=ooooo`;o00000_ooool2o`0000Wooooo
0_l0001=ooooo`007?ooool00ol0003oooooooooo`11ooooo`;o00002Oooool4o`00013ooooo0_l0
0003ooooo`;o00000_ooool2o`0000cooooo6ol00007ooooo`;o00002Oooool3o`0000?ooooo0_l0
0006ooooo`;o00000_ooool2o`0000?ooooo1?l00003ooooo`;o000000?oooooo`000?l000000_l0
0003ooooo`Co00000_ooool2o`000003ooooool0003o000000;ooooo0_l0000:ooooo`;o00004ooo
ool2o`0000?ooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`0oooooo`Co00001Oooool2
o`0000;ooooo0_l0000Booooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00003?oooolI
o`0000Wooooo0_l00009ooooo`?o00002_ooool4o`0000Kooooo1?l00003ooooo`;o00000oooool2
o`0000?ooooo0ol00006ooooo`;o00000_ooool4o`0000Sooooo0_l0000?ooooo`;o00001oooool2
o`0004Sooooo000Looooo`03o`000?oooooooooo03kooooo0ol00005ooooo`Co00002Oooool2o`00
00kooooo1ol00002ooooo`;o00001oooool2o`000003ooooool0003o000001Ko00002_ooool2o`00
01Gooooo1?l00002ooooo`;o00000_ooool4o`0000;ooooo1ol000001Ooooooo0000o`000?l0003o
oooo00;o00003?ooool2o`0000Gooooo0_l0000Booooo`;o00003oooool2o`00043ooooo000Loooo
o`03o`000?oooooooooo03kooooo0_l00006ooooo`;o00002oooool2o`0001;ooooo0ol00002oooo
o`?o00001_ooool4o`0000?ooooo0ol000000ooooooo0000o`00000:o`0000;ooooo0_l0000:oooo
o`;o00001Oooool2o`0001;ooooo1Ol00004ooooo`ko000000Coooooo`000?l0003ooooo1?l0000>
ooooo`;o00004?ooool2o`0000Cooooo0_l00008ooooo`Go0000@?ooool001cooooo00?o0000oooo
ooooool0;?ooool2o`0001Oooooo0_l00008ooooo`;o00001Oooool2o`00013ooooo0_l00002oooo
o`?o000000Coooooo`000?l0003o00000_ooool4o`000003ooooool0003o000000co000000Cooooo
o`000?l0003o00000oooool2o`000003ooooool0003o000000Co00000_ooool4o`0000?ooooo0_l0
000?ooooo`;o000000?oooooo`000?l000000ol00002ooooo`Wo00000_ooool4o`0000;ooooo0_l0
00000ooooooo0000o`000002o`0001?ooooo0_l00007ooooo`;o00000_ooool2o`0000Cooooo0ol0
00001?oooooo0000o`000?l00003ooooo`Go0000@?ooool001cooooo00?o0000ooooooooool0;?oo
ool2o`0001;ooooo1ol00008ooooo`Co00000oooool2o`00013ooooo0_l00003ooooo`;o000000Co
ooooo`000?l0003o00001?ooool2o`000004ooooool0003o0000ooooo`?o000000?oooooo`000?l0
00002Ol000000ooooooo0000o`00000;o`0000;ooooo0_l0000<ooooo`?o00001Oooool2o`0000?o
oooo0_l00002ooooo`ko00000oooool2o`0000Gooooo1Ol000000ooooooo0000o`000004ooooo`;o
00001_ooool2o`0000Oooooo1?l00007ooooo`;o000000Coooooo`000?l0003o00001_ooool2o`00
043ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool01?ooool00ol0003oooooooooo`10ooooo`Go00003?ooool2o`0001?ooooo1?l00000
1?oooooo0000o`000?ooool2o`0000Gooooo0_l00008oooooa7o000000Coooooo`000?l0003ooooo
0ol000000ooooooo0000o`00000?ooooo`Co00000_ooool3o`0000;ooooo5Ol00002ooooo`Ko0000
0_ooool5o`000003ooooool0003o000000?ooooo0ol0000?ooooo`Co00001oooool2o`0000[ooooo
0_l00010ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo04Gooooo0_l0000Oooooo`Co000000Coooooo`000?l0
003ooooo0_l00005ooooo`Co00000oooool2o`000003ooooool0003o000000Oo00000_ooool:o`00
0003ooooool0003o000001;ooooo0_l00004oooooaSo000000Coooooo`000?l0003ooooo1ol00000
0ooooooo0000o`000009ooooo`;o00004?ooool4o`0000Oooooo0_l0001<ooooo`0000?ooooooa0@
4?ooool00_ooool00ol@413oooooooooo`09ooooo`Go00001_ooool00ol0003oooooooooo`10oooo
o`;o00000oooool2o`0000Sooooo0_l0000Eooooo`Ko00000oooool5o`0000?ooooo0_l00003oooo
o`;o00000oooool6o`0000?ooooo1ol000000ooooooo0000o`000005ooooo`;o00004?ooool2o`00
00;ooooo3ol000000ooooooo0000o`00000Do`0000Kooooo0_l0000Oooooo`;o0000Boooool00003
ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?m4A4CogMgMooooool00007oooo
o`?o0000@?ooool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`Co00005_ooool2o`00
0004ooooool0003o0000ooooo`Oo00002oooool4o`0000;ooooo0_l00007ooooo`;o00002Oooool2
o`0000Sooooo0_l00005ooooo`[o000000Coooooo`000?l0003ooooo6?l000000ooooooo0000o`00
0003o`000003ooooool0003o000000;ooooo0_l0000Fooooo`;o00001oooool2o`0004_ooooo0000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo00001ooo
ool00ol0003oooooooooo`0jooooo`;o00001oooool2o`0000Cooooo0_l000000ooooooo0000o`00
0002o`0001gooooo0_l000001?oooooo0000o`000?l0000<ooooo`;o00001?ooool4o`0000Cooooo
0_l00009ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Gooooo1_l000000ooooooo0000
o`000004o`000003ooooool0003o000001oo00006_ooool2o`0005Cooooo00000ooooooo410@oooo
o`02ooooo`03oa0@4?oooooooooo00[ooooo00?oMgMgolc<c?l000001oooool00ol0003ooooooooo
o`0jooooo`;o00004?ooool4o`0002Cooooo0_l00003ooooo`;o00002Oooool2o`000003ooooool0
003o000000Cooooo0_l00003ooooo`;o00000oooool3o`000003ooooool0003o000000Kooooo0ol0
0002ooooo`So00000oooool4o`0000;ooooo3Ol000000ooooooo0000o`000002o`000003ooooool0
003o000000go00000oooool2o`0000Sooooo0_l00002ooooo`;o00001?ooool3o`0000Sooooo0_l0
001:ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo
00?o0000ooooooooool0>_ooool2o`0001;ooooo0_l00004ooooo`;o00004Oooool5o`0000?ooooo
0_l00003ooooo`;o00000oooool2o`0000Wooooo0_l0000:ooooo`Co00000_ooool3o`0000[ooooo
0ol00002ooooo`?o00000_ooool2o`000004ooooool0003o0000oooooako000000?oooooo`000?l0
00001?ooool3o`0000;ooooo0ol00008ooooo`?o000000?oooooo`000?l000001?ooool2o`0000Wo
oooo0_l00007ooooo`;o0000@Oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omg
MgOo0000ooooo`06ooooo`03o`000?oooooooooo03[ooooo0_l00004ooooo`;o00003?ooool2o`00
00?ooooo0ol00008ooooo`?o00000_ooool2o`0000;ooooo1Ol00003ooooo`;o00000_ooool2o`00
013ooooo0_l00009ooooo`;o000000?oooooo`000?l000000ol0000Dooooo`?o000000?oooooo`00
0?l000003Ol00002oooooa3o000000Coooooo`000?l0003ooooo0_l00006ooooo`Co00002?ooool2
o`0000Sooooo0_l0000>ooooo`;o000000Coooooo`000?l0003o0000@?ooool001cooooo00?o0000
ooooooooool0@?ooool2o`000004ooooool0003o0000ooooo`;o00002oooool3o`0000;ooooo0_l0
0004ooooo`?o00000_ooool2o`0000Oooooo0_l00004ooooo`?o00003?ooool2o`0000;ooooo0_l0
0006ooooo`;o00001?ooool3o`0000[ooooo0_l00008ooooo`Co000000?oooooo`000?l000003ol0
00000ooooooo0000o`00000Eo`000003ooooool0003o000000Cooooo0_l0000Booooo`;o00001_oo
ool2o`0000Kooooo0ol000000ooooooo0000o`000010ooooo`007?ooool00ol0003oooooooooo`0W
ooooo`;o000000?oooooo`000?l000004_ooool2o`0000?ooooo0_l000000ooooooo0000o`00000<
ooooo`;o00000_ooool2o`0001;ooooo0ol00003ooooo`;o00003Oooool2o`0000Oooooo0_l00000
0ooooooo0000o`000002ooooo`;o00003?ooool3o`0000Sooooo;_l000000ooooooo0000o`000002
ooooo`;o00003_ooool2o`0000Sooooo1_l00003ooooo`Ko0000@oooool001cooooo00?o0000oooo
ooooool09oooool2o`000003ooooool0003o000001;ooooo0_l00007ooooo`Co00000oooool2o`00
0003ooooool0003o000000Gooooo0_l0000Aooooo`Co00006?ooool2o`000003ooooool0003o0000
00Gooooo0_l00004ooooo`;o00001_ooool3o`000003ooooool0003o000000Kooooo1?l000000ooo
oooo0000o`000002o`000003ooooool0003o000001go00002Oooool2o`0000kooooo0ol00007oooo
o`So000000?oooooo`000?l000000_l00003ooooo`;o0000@?ooool001cooooo00?o0000oooooooo
ool0;oooool2o`0001Kooooo1?l00003ooooo`;o000000?oooooo`000?l000001Oooool3o`00013o
oooo0_l00002ooooo`;o00001Oooool5o`0000?ooooo0_l000001?oooooo0000o`000?l00003oooo
o`;o00001?ooool4o`0000Kooooo0_l00007ooooo`;o000000?oooooo`000?l000001?oooolAo`00
0003ooooool0003o000001Ko00001oooool2o`0001;ooooo0ol0000;ooooo`Co00000_ooool2o`00
00?ooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00001_ooool2o`00023o
oooo0_l000000ooooooo0000o`00000Aooooo`;o00001Oooool5o`0000;ooooo0ol000001?oooooo
0000o`000?l00009ooooo`Go00002Oooool2o`0000cooooo1ol00002ooooo`Oo000000?oooooo`00
0?l000006?l00002ooooo`Ko00004Oooool4o`0000?ooooo0_l000000ooooooo0000o`000002oooo
o`Wo0000AOooool001cooooo00?o0000ooooooooool0=oooool2o`0000cooooo0_l00006ooooo`;o
00002?ooool2o`0000?ooooo1?l0000Gooooo`;o00001?ooool3o`000003ooooool0003o000000_o
oooo1?l00009ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Oooooo9ol00002ooooo`Ko
00000oooool2o`0000cooooo0_l00005ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?o
oooo0_l00003ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0@oooool5o`0000Gooooo
0_l00008ooooo`;o00001Oooool2o`0000Cooooo0_l0000:ooooo`?o00001oooool9o`0000_ooooo
0_l00008ooooo`;o00001?ooool2o`0000Cooooo0_l000000ooooooo0000o`000005oooooa_o0000
00?oooooo`000?l000001Ol000000ooooooo0000o`00000:o`000003ooooool0003o000001Gooooo
0_l00008ooooo`;o00000oooool2o`0004;ooooo000Looooo`03o`000?oooooooooo03gooooo0_l0
0004ooooo`Go00003_ooool2o`0000cooooo0_l00008ooooo`Go00001oooool4o`000003ooooool0
003o000000;ooooo0_l000001?oooooo0000o`000?l00005ooooo`;o00001_ooool4o`0000gooooo
1?l000000ooooooo0000o`00000Yo`000005ooooool0003o0000o`000?ooool00_l0000>ooooo`;o
00000oooool2o`0000?ooooo0_l0000<ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0
=Oooool2o`0000Kooooo1_l00002ooooo`;o00002Oooool2o`0000;ooooo1?l0000Fooooo`;o0000
4oooool2o`000005ooooool0003o0000o`000?ooool00_l00002ooooo`Go00000oooool5o`0000Ko
oooo0_l00006ooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000001?o
000000?oooooo`000?l000002_l00003ooooo`?o00001_ooool2o`0000Wooooo0ol00002ooooo`;o
00001oooool2o`0000Gooooo0_l000000ooooooo0000o`000013ooooo`007?ooool00ol0003ooooo
ooooo`0Sooooo`;o00004?ooool2o`000003ooooool0003o000000Gooooo1?l00004ooooo`;o0000
1oooool2o`0000;ooooo0ol0000<ooooo`;o00008Oooool2o`0000;ooooo0_l00003ooooo`Co0000
1?ooool5o`0000Gooooo0_l00004ooooo`Ko00001?oooolGo`000003ooooool0003o000000go0000
0oooool2o`0000;ooooo1?l00009ooooo`?o00000_ooool3o`0000Kooooo0_l00005ooooo`?o0000
AOooool001cooooo00?o0000ooooooooool08oooool2o`0001?ooooo0_l0000<ooooo`?o00003?oo
ool2o`0000cooooo0_l00008ooooo`;o00004Oooool2o`0000Kooooo0_l00005ooooo`Co00001ooo
ool3o`0000[ooooo2Ol000000ooooooo0000o`00000Eo`000003ooooool0003o000001?o000000?o
ooooo`000?l000003?ooool7o`0000Cooooo0_l00008ooooo`;o0000AOooool001cooooo0_l0000W
ooooo`;o00007Oooool4o`0000;ooooo0ol00005ooooo`;o00004?ooool2o`0000?ooooo1Ol0000A
ooooo`;o00001_ooool2o`0000Oooooo0_l00006ooooo`Co000000?oooooo`000?l000001_ooool3
o`000004ooooool0003o0000ooooo`?o000000?oooooo`000?l000005Ol00002oooooaCo000000?o
ooooo`000?l000003_ooool2o`0000Oooooo0_l00005ooooo`;o00000_ooool2o`0004Cooooo000L
ooooo`03o`000?oooooooooo02Kooooo0_l0000Dooooo`;o00001oooool2o`0000;ooooo1Ol00005
ooooo`;o00004?ooool2o`0000?ooooo0ol0000Xooooo`;o00000_ooool3o`0000;ooooo0_l00006
ooooo`;o00000_ooool2o`000003ooooool0003o000002Wo00000_ooool3o`0000;ooooo0_l0000B
ooooo`;o00001_ooool2o`0000;ooooo0_l00002ooooo`;o00001_ooool2o`0003cooooo000Loooo
o`03o`000?oooooooooo02oooooo0_l00005ooooo`;o00001?ooool4o`0000Wooooo0_l00007oooo
o`;o00001?ooool2o`0000;ooooo0_l0000<ooooo`;o00001Oooool2o`0001Sooooo0_l00008oooo
o`;o00004Oooool2o`000003ooooool0003o000001;o000000?oooooo`000?l000007?l000000ooo
oooo0000o`000008ooooo`;o00002?ooool2o`0000Cooooo1?l00007ooooo`;o00001Oooool2o`00
03cooooo000Looooo`03o`000?oooooooooo02oooooo0_l000000ooooooo0000o`000002ooooo`;o
00000_ooool2o`0000;ooooo0_l0000@ooooo`Co00001?ooool2o`0000;ooooo0_l0000<ooooo`Co
00000oooool2o`0001Sooooo0_l0000;ooooo`;o00001?ooool2o`0000Cooooo0_l00002ooooo`;o
000000Goooooo`000?l0003o0000ooooo`0Po`0000?ooooo0ol000000ooooooo0000o`000002o`00
00;ooooo0_l0000;ooooo`;o00000_ooool2o`0000Cooooo2?l00003ooooo`;o00000oooool3o`00
04?ooooo000Looooo`03o`000?oooooooooo03;ooooo0_l00006ooooo`;o00004?ooool2o`0000;o
oooo0_l0000@ooooo`;o00000_ooool2o`0000Cooooo0_l00009ooooo`;o00002oooool2o`0001;o
oooo0ol00003ooooo`;o00001?ooool2o`0000Cooooo1?l000000ooooooo0000o`000008o`000003
ooooool0003o000001Wo00000_ooool2o`0000Sooooo0_l00003ooooo`;o00001?ooool7o`000003
ooooool0003o000000Go00000oooool2o`0000?ooooo0_l00014ooooo`007?ooool00ol0003ooooo
ooooo`0cooooo`;o000000?oooooo`000?l000005?ooool2o`0001Cooooo0_l00002ooooo`;o0000
1Oooool3o`0000Cooooo0_l000000ooooooo0000o`00000;ooooo`;o00002Oooool2o`0000Sooooo
0_l00009ooooo`;o00001?ooool4o`0000?ooooo2?l000000ooooooo0000o`00000>o`000003oooo
ool0003o000000Wo000000?oooooo`000?l000001Oooool2o`000003ooooool0003o000000;o0000
00?oooooo`000?l000001?ooool7o`000003ooooool0003o000001?ooooo0_l0000nooooo`007?oo
ool00ol0003oooooooooo`0cooooo`Go00003_ooool2o`0000Kooooo0_l0000?ooooo`;o00000_oo
ool2o`0000Cooooo1ol00004ooooo`;o00003_ooool2o`0000Kooooo0_l000000ooooooo0000o`00
0004ooooo`?o00004?ooool4o`000003ooooool0003o000000?ooooo9Ol00003ooooo`;o00000_oo
ool2o`0000?ooooo0_l0000>ooooo`?o000000?oooooo`000?l000000_l0000>ooooo`;o00000_oo
ool2o`0003[ooooo000Looooo`03o`000?oooooooooo02[ooooo0_l00009ooooo`;o00003oooool2
o`0000Kooooo0_l00004ooooo`;o00002Oooool2o`0000;ooooo0_l00004ooooo`Ko00000_ooool2
o`0000Sooooo0_l00008ooooo`Go00000_ooool2o`0000Oooooo0ol00005ooooo`;o00002Oooool2
o`0000?ooooo1?l00002ooooo`oo00000_oooolCo`0000?ooooo0_l00007ooooo`;o00001oooool5
o`0000;ooooo2?l00002ooooo`;o00003_ooool2o`0003[ooooo000Looooo`03o`000?oooooooooo
02[ooooo0_l00002ooooo`;o00001oooool2o`0001Oooooo0_l00002ooooo`;o00003Oooool2o`00
00;ooooo1?l000000ooooooo0000o`000002o`000003ooooool0003o000000;o000000?oooooo`00
0?l000000oooool3o`0000Gooooo1ol00002ooooo`;o00003oooool2o`0000Oooooo0_l00005oooo
o`Co000000?oooooo`000?l000001ol000000ooooooo0000o`000003o`000003ooooool0003o0000
00co000000?oooooo`000?l000000ol00004ooooo`;o00001oooool2o`0000;ooooo1?l000000ooo
oooo0000o`000003o`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l000001?ooool2o`00
00Kooooo0_l0000looooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00000_ooool2o`0000?o
oooo1?l0000:ooooo`;o00002Oooool4o`0000oooooo0_l000001?oooooo0000o`000?l00002oooo
o`Ko000000Goooooo`000?l0003o0000ooooo`02o`0000Cooooo0ol00004ooooo`;o000000?ooooo
o`000?l000001?ooool2o`0001;ooooo0_l00004ooooo`;o00001Oooool4o`000003ooooool0003o
000000co000000?oooooo`000?l000004ol00002ooooo`Co00002oooool4o`0000;ooooo0_l00003
ooooo`;o00001_ooool2o`0000Gooooo1Ol00005ooooo`;o00006Oooool2o`00027ooooo000Loooo
o`03o`000?oooooooooo03;ooooo0_l00005ooooo`;o000000?oooooo`000?l000001?ooool6o`00
00[ooooo0_l0000Boooooa;o00001?ooool3o`00027ooooo0_l00004ooooo`;o00000_ooool3o`00
00;ooooo0_l000000ooooooo0000o`00000<o`000003ooooool0003o0000017o00000_ooool4o`00
00kooooo0_l00004ooooo`;o00000_ooool2o`0000Kooooo0_l00004ooooo`?o000000?oooooo`00
0?l000008?ooool2o`00027ooooo000Looooo`03o`000?oooooooooo033ooooo0_l0000:ooooo`;o
00001?ooool6o`0000Cooooo0_l00004ooooo`;o00002oooool3o`0000Gooooo4_l00003ooooo`;o
00000_ooool2o`0002Cooooo0_l00002ooooo`Go000000?oooooo`000?l000007?l000000ooooooo
0000o`000002o`0000?ooooo0_l0000<ooooo`;o00000_ooool2o`0000Cooooo0_l0000:ooooo`;o
000000Coooooo`000?l0003ooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o
00004_ooool2o`0000?ooooo1Ol00004ooooo`;o000000?oooooo`000?l000000oooool2o`0000?o
oooo0ol00005oooooa;o00000oooool3o`000003ooooool0003o000000;o00003Oooool2o`0001;o
oooo0_l000000ooooooo0000o`000003ooooo`;o000000Goooooo`000?l0003o0000ooooo`0Jo`00
0003ooooool0003o000001?ooooo0_l0000<ooooo`;o00002?ooool6o`0000;ooooo0_l00013oooo
o`007?ooool00ol0003oooooooooo`13ooooo`;o00001?ooool3o`0000Wooooo1ol00008oooooaGo
00001?ooool2o`0000?ooooo0_l0000=ooooo`;o00000oooool4o`0000?ooooo0_l00006ooooo`;o
000000?oooooo`000?l000000oooool2o`000004ooooool0003o0000o`0000;ooooo6Ol000000ooo
oooo0000o`00000Aooooo`;o00003_ooool3o`000003ooooool0003o000000Cooooo1?l00004oooo
o`;o000000?oooooo`000?l00000@?ooool001cooooo00?o0000ooooooooool0@oooool2o`0000Co
oooo0_l0000;ooooo`Co00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000Do`0000;o
oooo0_l00008ooooo`;o00003oooool4o`0000?ooooo0ol00002ooooo`;o00002Oooool2o`0000;o
oooo0ol00002ooooo`_o000000?oooooo`000?l000002_l000000ooooooo0000o`000003o`0000So
oooo0_l00004ooooo`;o000000?oooooo`000?l000000oooool3o`0000Kooooo0_l000000ooooooo
0000o`000005ooooo`;o00002?ooool2o`00043ooooo000Looooo`03o`000?oooooooooo02_ooooo
0_l00002ooooo`;o00005oooool2o`0000kooooo0_l00002ooooo`;o00000_oooolHo`0000?ooooo
0_l00008ooooo`;o00004_ooool2o`0000?ooooo0_l000001?oooooo0000o`000?l0000<ooooo`Co
00001?ooool2o`000003ooooool0003o000000Oo000000?oooooo`000?l000001_l000000ooooooo
0000o`000004o`0000Sooooo0_l00007ooooo`;o00000oooool5o`0000Cooooo0ol00007ooooo`?o
00002?ooool2o`0003oooooo000Looooo`;o0000;?ooool2o`0000;ooooo0_l00003ooooo`;o0000
3oooool2o`000003ooooool0003o000000;o00001_ooool2o`0000Cooooo0_l00006oooooaSo0000
2Oooool2o`0000cooooo0_l00008ooooo`;o00001_ooool2o`0000Kooooo1?l00003ooooo`Oo0000
00?oooooo`000?l000004ol000000ooooooo0000o`000002ooooo`;o00000_ooool2o`000004oooo
ool0003o0000ooooo`;o00000_ooool2o`0000?ooooo0_l00004ooooo`Go00000oooool3o`0000Co
oooo0_l00002ooooo`;o00002?ooool2o`0003oooooo000Looooo`03o`000?oooooooooo03Cooooo
0_l0000<ooooo`;o000000?oooooo`000?l000000oooool2o`0000Kooooo0_l0000;ooooo`;o0000
0_oooolEo`0000Wooooo0_l00006ooooo`;o00001?ooool2o`000003ooooool0003o000001Gooooo
1?l00003ooooo`co000000?oooooo`000?l000003ol00002ooooo`Co000000Goooooo`000?l0003o
0000ooooo`02o`000003ooooool0003o000000;ooooo0_l00002ooooo`?o00001?ooool2o`000003
ooooool0003o000000?ooooo0_l00005ooooo`;o00002_ooool2o`000003ooooool0003o000003ko
oooo000Looooo`03o`000?oooooooooo04;ooooo0_l0000Booooo`;o00001ooooolIo`00013ooooo
0ol00007ooooo`Co00006_ooool4o`0000?ooooo0ol00003ooooo`;o000000?oooooo`000?l00000
0_l00005ooooo`Go00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`?o0000
1Oooool2o`0000gooooo0_l00003ooooo`;o00003?ooool2o`000003ooooool0003o000000;o0000
??ooool001cooooo00?o0000ooooooooool0:?ooool2o`0000_ooooo0_l00009ooooo`Co00004_oo
ool2o`000003ooooool0003o000000Kooooo3Ol000000ooooooo0000o`000008o`0000?ooooo0_l0
0004ooooo`;o00001?ooool2o`0000Oooooo0_l000000ooooooo0000o`00000=ooooo`;o000000?o
ooooo`000?l000000_l000000ooooooo0000o`00000:ooooo`?o00000_ooool2o`0000?ooooo0_l0
0006ooooo`;o00000oooool2o`0000?ooooo0_l00003ooooo`;o00000oooool2o`0001Wooooo0_l0
0003ooooo`;o00002_ooool4o`0003cooooo000Looooo`03o`000?oooooooooo02Sooooo0_l00002
ooooo`;o00001oooool2o`0000Cooooo0ol00002ooooo`;o00004Oooool3o`0000?ooooo0_l00003
oooooa_o00000oooool2o`0000Cooooo0_l0000=ooooo`;o00002Oooool2o`0000Gooooo0_l00000
0ooooooo0000o`000002o`000003ooooool0003o000000?ooooo0_l00004ooooo`Go000000Cooooo
o`000?l0003ooooo0ol0000<ooooo`;o00000oooool2o`0000cooooo0_l0000;ooooo`;o00002ooo
ool4o`0004[ooooo000Looooo`03o`000?oooooooooo02;ooooo0_l00007ooooo`?o00003?ooool4
o`000003ooooool0003o000000;o00003_ooool5o`0000Oooooo3?l00002ooooo`Ko000000?ooooo
o`000?l000000ol00004ooooo`;o00003?ooool2o`0000Cooooo0_l00004ooooo`;o00001Oooool2
o`0000Sooooo0_l000000ooooooo0000o`000005ooooo`;o00000_ooool4o`000003ooooool0003o
000000;o000000?oooooo`000?l000000_l00006ooooo`;o00000_ooool2o`0000Cooooo0ol00005
ooooo`;o000000?oooooo`000?l000000_ooool4o`0000Wooooo0_l00009ooooo`Co00001oooool2
o`0000Kooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0Mooooo`;o00000oooool2o`00
00;ooooo0_l00003ooooo`;o00003Oooool3o`0000;ooooo1?l00002ooooo`;o00002_ooool2o`00
00[ooooo3Ol000001Ooooooo0000o`000?l0003ooooo00So00000_ooool4o`0000cooooo0_l00004
ooooo`?o00000oooool2o`0001;ooooo0_l00005ooooo`;o00000_ooool4o`000003ooooool0003o
000000;o000000?oooooo`000?l000002?ooool3o`000003ooooool0003o000000Cooooo0ol00005
ooooo`;o000000?oooooo`000?l000000_ooool4o`0000Wooooo0_l00009ooooo`;o000000?ooooo
o`000?l000001_ooool2o`0000Kooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0Moooo
o`;o00001oooool2o`0000;ooooo0_l0000?ooooo`;o00002?ooool2o`0000Gooooo0_l00007oooo
o`?o00001Oooool2o`000003ooooool0003o000000Wo000000?oooooo`000?l000001_l000000ooo
oooo0000o`000004o`0000gooooo0_l00006ooooo`;o00005_ooool2o`0000?ooooo0_l00002oooo
o`;o00000oooool2o`0000?ooooo0_l00003ooooo`;o00001Oooool4o`000003ooooool0003o0000
017ooooo0_l0000:ooooo`Co00001Oooool2o`0000Kooooo0_l00006ooooo`;o00001_ooool2o`00
03_ooooo000Looooo`03o`000?oooooooooo02[ooooo0_l00004ooooo`?o00006Oooool4o`0000Go
oooo0ol00005oooooago00000_ooool2o`0000Sooooo1?l0000:ooooo`;o00001?ooool2o`0000So
oooo1_l00003ooooo`;o000000Coooooo`000?l0003o00001Oooool2o`0000Cooooo1?l00002oooo
o`;o000000?oooooo`000?l000000_l0000@ooooo`Oo00000_ooool4o`0000?ooooo1Ol00004oooo
o`;o00003Oooool2o`0000Kooooo0_l0000looooo`007?ooool00ol0003oooooooooo`0_ooooo`Co
00006_ooool4o`0000Sooooo0_l000000ooooooo0000o`00000Lo`0000;ooooo0_l00008ooooo`;o
00001oooool7o`000004ooooool0003o0000ooooo`;o00002?ooool4o`0000Kooooo1?l00006oooo
o`?o00000oooool3o`0000;ooooo0ol00003ooooo`Go00003Oooool7o`0000;ooooo1?l00006oooo
o`;o000000?oooooo`000?l000003oooool3o`000003ooooool0003o000000;o000000?oooooo`00
0?l00000??ooool001cooooo00?o0000ooooooooool0;oooool2o`0000Cooooo0_l0000<ooooo`;o
00002_ooool2o`0000Gooooo0_l000000ooooooo0000o`00000Lo`0001?ooooo0_l00002ooooo`Ko
00000_ooool3o`0000?ooooo1?l0000>ooooo`;o00002Oooool2o`0000Sooooo0_l00006ooooo`Go
00003_ooool2o`0000;ooooo0_l00003ooooo`;o00001oooool3o`000003ooooool0003o000000co
oooo0ol000000ooooooo0000o`000002o`0003oooooo000Looooo`03o`000?oooooooooo03Cooooo
0ol00003ooooo`?o00000oooool2o`000004ooooool0003o0000ooooo`;o00001_ooool2o`0000;o
oooo0_l000001?oooooo0000o`000?l00003ooooo`;o00000ooooolFo`0001Cooooo0_l00002oooo
o`?o00001?ooool3o`0000Cooooo1?l00005ooooo`;o00001oooool2o`000003ooooool0003o0000
00;o00003oooool2o`0000Kooooo1?l0000;ooooo`;o000000?oooooo`000?l000000_ooool2o`00
00?ooooo0_l00007ooooo`;o00000_ooool2o`0000;ooooo0_l00009ooooo`;o00000_ooool2o`00
043ooooo000Looooo`03o`000?oooooooooo02kooooo0_l00004ooooo`;o00001?ooool3o`0000?o
oooo0_l00004ooooo`;o00001_ooool3o`000003ooooool0003o000000Go00001OoooolHo`0000Co
oooo0_l00002ooooo`;o00004?ooool2o`0000?ooooo0_l00005ooooo`;o00001oooool2o`0000Oo
oooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l00009ooooo`;o00001_ooool2o`0000Oo
oooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Eooooo`;o00003Oooool2o`00
00Cooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00002Oooool2o`0000Wo
oooo0_l00009ooooo`;o00000_ooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l0
00001ol00002ooooo`ko000000?oooooo`000?l000000ol000000ooooooo0000o`000006ooooo`;o
00002?ooool2o`0000Gooooo0_l0000;ooooo`;o000000?oooooo`000?l000000oooool2o`0000_o
oooo0_l0000=ooooo`;o00002_ooool3o`000003ooooool0003o000000Oooooo1?l00007ooooo`;o
00003_ooool2o`0000cooooo0_l000000ooooooo0000o`00000jooooo`007?ooool00ol0003ooooo
ooooo`0iooooo`;o00002Oooool2o`0000kooooo0_l00005ooooo`;o000000Coooooo`000?l0003o
oooo5_l000000ooooooo0000o`000005o`0000Oooooo0_l000000ooooooo0000o`00000<ooooo`;o
00002oooool5o`000003ooooool0003o000000;o00002Oooool2o`0000oooooo0_l0000:ooooo`?o
000000?oooooo`000?l000001?ooool2o`0000?ooooo0_l00006ooooo`Go00001oooool2o`0000?o
oooo1?l00004ooooo`;o00001?ooool2o`0003gooooo000Looooo`03o`000?oooooooooo04Cooooo
0_l00008ooooo`;o00001?ooool2o`0000Sooooo0_l00003oooooa;o00002?ooool2o`0000[ooooo
0_l000000ooooooo0000o`00000Aooooo`;o00001?ooool3o`0000;ooooo0_l00005ooooo`;o0000
1?ooool4o`0000;ooooo0_l0000Dooooo`Co00000oooool2o`0000;ooooo0_l00003ooooo`;o0000
1_ooool5o`0000Oooooo0_l00005ooooo`;o00001?ooool4o`00047ooooo000Looooo`;o0000;ooo
ool2o`0001Kooooo0_l00006ooooo`;o00001oooool4o`0000Oooooo4_l0000Hooooo`?o00000ooo
ool2o`0000_ooooo0_l00004ooooo`;o00000oooool2o`0000Gooooo0_l00006ooooo`;o00000_oo
ool2o`00013ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Oooooo0_l0
0005ooooo`Co00006?ooool2o`00047ooooo000Looooo`03o`000?oooooooooo02Sooooo0_l00004
ooooo`;o00002oooool2o`0000Wooooo0ol00008ooooo`;o00001?ooool4o`0000Oooooo4_l0000<
ooooo`;o00002oooool2o`0000?ooooo0_l0000>ooooo`;o00000_ooool2o`0000;ooooo0_l00005
ooooo`;o00002_ooool2o`0000Wooooo0_l00004ooooo`?o00000_ooool2o`000003ooooool0003o
000001;ooooo0_l0000<ooooo`;o0000Coooool001cooooo00?o0000ooooooooool0:?ooool3o`00
00cooooo0_l00002ooooo`;o00002_ooool2o`0000Sooooo0_l00005ooooo`;o00002_ooool=o`00
00oooooo0_l00004ooooo`;o00003?ooool2o`0000?ooooo0_l00007ooooo`;o00000_ooool2o`00
00Wooooo0_l0000Aooooo`;o00000_ooool2o`0000Cooooo0_l0000>ooooo`;o00003oooool3o`00
00Kooooo0_l000000ooooooo0000o`000002ooooo`;o00001oooool2o`0003oooooo000Looooo`03
o`000?oooooooooo02Sooooo0ol0000<ooooo`;o00003_ooool4o`0000;ooooo0_l00009ooooo`;o
00000oooool2o`0000Gooooo3Ol00004ooooo`?o00002oooool2o`000003ooooool0003o000000co
oooo0_l00003ooooo`;o00005_ooool2o`0000Kooooo0_l00009ooooo`;o00002?ooool2o`0000ko
oooo0_l0000?ooooo`Oo00001Oooool2o`0000;ooooo0_l00007ooooo`;o0000?oooool001cooooo
00?o0000ooooooooool0=Oooool2o`0000;ooooo0_l0000>ooooo`;o00000_ooool2o`0000kooooo
0_l00006ooooo`;o000000?oooooo`000?l000000_l00009ooooo`Go00002Oooool2o`0000?ooooo
0_l0000Hooooo`;o00003Oooool4o`0000;ooooo1?l00006ooooo`Co00002Oooool2o`0000kooooo
1?l0000?ooooo`Go00002?ooool2o`0000Kooooo0_l0000Nooooo`;o00008Oooool001cooooo00?o
0000ooooooooool0=Oooool2o`0000;ooooo0_l00003ooooo`;o00006?ooool3o`0000;ooooo0_l0
0005ooooo`?o00001?ooool3o`0000;ooooo0_l00004ooooo`Co00003_ooool2o`0000kooooo0ol0
0007ooooo`Co00000_ooool4o`0000Oooooo0_l00002ooooo`;o00000_ooool2o`0000Cooooo1?l0
000>ooooo`;o00002Oooool4o`0000;ooooo0_l0000;ooooo`;o00001Oooool2o`0000Cooooo1?l0
0004ooooo`;o00003oooool2o`0000gooooo0_l0000Qooooo`007?ooool00ol0003oooooooooo`0n
ooooo`;o00003?ooool2o`0000[ooooo0ol00008ooooo`Ko00000_ooool3o`0000;ooooo1?l00002
ooooo`;o00008?ooool3o`000005ooooool0003o0000o`000?ooool01_l00002ooooo`Co00001ooo
ool2o`000003ooooool0003o000000?ooooo0_l00004ooooo`Co00000_ooool2o`0000Cooooo0_l0
0004ooooo`;o00000oooool2o`0000[ooooo0_l000000ooooooo0000o`000004ooooo`;o00002Ooo
ool2o`0000Kooooo0_l0000Eooooo`;o0000<?ooool001cooooo00?o0000ooooooooool0=Oooool2
o`0001Gooooo0_l0000=ooooo`?o000000Goooooo`000?l0003o0000ooooo`02o`000004ooooool0
003o0000o`0000;ooooo1?l00003ooooo`;o00001Oooool2o`0000Oooooo0_l00003ooooo`;o0000
0_ooool4o`000003ooooool0003o000000Kooooo0_l00002ooooo`?o000000Coooooo`000?l0003o
oooo0_l00009ooooo`;o00000oooool2o`000004ooooool0003o0000o`0000Kooooo1_l00002oooo
o`;o00001?ooool2o`0000Wooooo0_l00002ooooo`;o00002?ooool3o`0000Cooooo0_l0000Aoooo
o`;o00001?ooool2o`00047ooooo000Looooo`03o`000?oooooooooo03Gooooo0_l0000Booooo`;o
00004?ooool7o`0000Wooooo1?l00005ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o
000000Coooooo`000?l0003o00000oooool3o`000003ooooool0003o000000;o000000?oooooo`00
0?l000001_ooool2o`0000Kooooo0_l0000<ooooo`;o00000oooool2o`0000;ooooo1?l00004oooo
o`;o00006oooool2o`0000Sooooo1?l0000Looooo`;o00003?ooool2o`0003?ooooo000Looooo`03
o`000?oooooooooo03_ooooo0_l0000<ooooo`;o00003Oooool2o`0000?ooooo1ol00008ooooo`;o
00001_ooool6o`0000?ooooo0ol000000ooooooo0000o`000005ooooo`;o00000oooool2o`0000Wo
oooo0_l00006ooooo`;o00002?ooool2o`0000Oooooo0_l00004ooooo`;o00006_ooool2o`0000Wo
oooo0_l00002ooooo`;o00000_ooool2o`0000Oooooo0ol0000Booooo`;o00003?ooool2o`0003?o
oooo000Looooo`03o`000?oooooooooo03_ooooo0_l00003ooooo`;o00005Oooool3o`0000Gooooo
1_l00006ooooo`Go00001?ooool6o`0000?ooooo0_l0000>ooooo`;o000000?oooooo`000?l00000
1_ooool2o`0000Oooooo0_l00002ooooo`;o00000oooool2o`0000Cooooo0_l0000;ooooo`;o0000
5_ooool2o`0000Wooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000000?ooooo
0ol00002ooooo`;o00000_ooool2o`0000[ooooo0_l00011ooooo`007?ooool00ol0003ooooooooo
o`0gooooo`;o00000_ooool2o`0000?ooooo0_l00005ooooo`Co00003?ooool2o`0000?ooooo0_l0
00000ooooooo0000o`000005o`0000Gooooo1Ol00005ooooo`;o00001_ooool4o`0000;ooooo0_l0
0008ooooo`;o000000?oooooo`000?l000001_ooool4o`0000Gooooo1_l00009ooooo`;o00000_oo
ool2o`0000Oooooo0ol0000?ooooo`;o00000_ooool2o`0000Sooooo0_l000000ooooooo0000o`00
0002ooooo`;o00000oooool7o`0000Kooooo1_l0000Aooooo`;o00001oooool2o`00037ooooo000L
ooooo`03o`000?oooooooooo03Oooooo0_l00002ooooo`Co00002?ooool4o`0000kooooo0_l00000
1Ooooooo0000o`000?l0003ooooo00?o000000?oooooo`000?l000001Oooool2o`0001;ooooo0_l0
0002ooooo`;o000000?oooooo`000?l000002oooool2o`0000Gooooo0_l00005ooooo`Ko00003Ooo
ool2o`000003ooooool0003o000000Cooooo0ol0000?ooooo`;o00000_ooool2o`0000Cooooo0_l0
0002ooooo`Co00002_ooool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o00004ooo
ool3o`0000Kooooo0_l0000aooooo`007?ooool00ol0003oooooooooo`0Vooooo`;o00005Oooool2
o`000003ooooool0003o000001Oooooo0_l000001Ooooooo0000o`000?l0003ooooo00?o00002ooo
ool2o`0000Oooooo0_l00006ooooo`;o00001Oooool2o`0000_ooooo0_l0000=ooooo`;o00000_oo
ool2o`0000Oooooo0_l00006ooooo`Co000000?oooooo`000?l000000_l0000=ooooo`;o00002_oo
ool3o`0000;ooooo0ol000000ooooooo0000o`000002o`0000Gooooo0_l00006ooooo`?o00000ooo
ool2o`0000cooooo0_l00005ooooo`;o0000>Oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^
1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo02Ko
oooo0_l0000Hooooo`;o00001_ooool2o`0001?ooooo0_l0000:ooooo`;o00000oooool4o`0000Go
oooo0_l000000ooooooo0000o`000003ooooo`;o00007_ooool2o`0000Gooooo0_l00007ooooo`;o
00002?ooool2o`000003ooooool0003o000000Co00002oooool2o`0000Sooooo0_l000001?oooooo
0000o`000?ooool3o`0000;ooooo1?l00003ooooo`Co00001_ooool2o`0000?ooooo1?l000000ooo
oooo0000o`000008ooooo`;o0000@?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo03Oooooo0ol0
000>ooooo`;o00004oooool2o`0000Gooooo0_l00003ooooo`;o00001Oooool2o`0000Sooooo0_l0
0002ooooo`;o000000?oooooo`000?l000007?ooool2o`0000[ooooo0_l0000<ooooo`;o00001?oo
ool3o`000003ooooool0003o000001;ooooo0_l00004ooooo`;o00001Oooool2o`0000?ooooo0_l0
0004ooooo`;o00001oooool4o`000003ooooool0003o000000;o0000B?ooool00003ooooool@413o
oooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool0=oooool3o`0000Kooooo0_l00006ooooo`;o00003_ooool2o`0000Gooooo0_l0
0003ooooo`Co00002Oooool2o`0000[ooooo0ol000000ooooooo0000o`000009ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0001Cooooo1?l0000Dooooo`Co00004?ooool6o`0000Wooooo0_l0
0008ooooo`?o00002Oooool2o`0000?ooooo0_l00002ooooo`?o0000@oooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0
0010ooooo`;o00000_ooool2o`0000;ooooo0_l0000>ooooo`;o00000oooool4o`0000Gooooo0_l0
0003ooooo`?o00000oooool3o`0000Wooooo0_l0000;ooooo`Oo00000_ooool2o`0000;ooooo0_l0
000@ooooo`;o000000?oooooo`000?l000003_ooool2o`0000?ooooo0_l0000Booooo`;o00000_oo
ool2o`0000Sooooo0ol00002ooooo`;o00000oooool4o`0000Wooooo0_l000000ooooooo0000o`00
0004ooooo`?o0000@oooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool0
1Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0??ooool2o`0000Kooooo0_l0
0002ooooo`?o00002?ooool2o`0000Sooooo1?l00009ooooo`Co00001?ooool2o`0000Sooooo0_l0
000<ooooo`Ko00001oooool2o`0000gooooo0_l00002ooooo`Co00001Oooool2o`000004ooooool0
003o0000ooooo`Go000000?oooooo`000?l000001Ol0000Mooooo`;o00000oooool4o`000003oooo
ool0003o000000;o000000?oooooo`000?l000002Oooool2o`000003ooooool0003o000000;o0000
AOooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7oooo
o`08ooooo`03o`000?oooooooooo03cooooo0_l00009ooooo`Co00002?ooool2o`0000[ooooo0_l0
0009ooooo`;o00001_ooool4o`0000Kooooo0_l00004ooooo`;o00004_ooool2o`0000Oooooo0_l0
0005ooooo`;o00000_ooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`000003oooo
ool0003o000000go00001oooool2o`0000gooooo1_l00006ooooo`;o00000oooool2o`000003oooo
ool0003o000000cooooo1?l00015ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03
omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0;?ooool2o`0000Gooooo0_l0000<ooooo`?o
00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l0
00000_l00002ooooo`;o00004oooool2o`0000?ooooo0_l00003ooooo`;o00000_ooool2o`000004
ooooool0003o0000ooooo`;o000000?oooooo`000?l000000oooool2o`0000;ooooo1?l00007oooo
o`;o00002_ooool2o`0000?ooooo0_l00009ooooo`[o000000?oooooo`000?l000001oooool2o`00
00Kooooo0_l00005ooooo`Ko00002_ooool2o`0000?ooooo0_l0000<ooooo`;o0000A_ooool00006
ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oo
oooooooo02cooooo0_l00005ooooo`;o00002_ooool5o`0000Kooooo0ol000000ooooooo0000o`00
0006ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00003oooool2o`0000Gooooo1?l0
0002ooooo`?o00000oooool?o`0000;ooooo0_l00002ooooo`Co000000?oooooo`000?l000003?oo
ool5o`000003ooooool0003o000000Oooooo3?l00007ooooo`;o00002?ooool2o`0000Wooooo0_l0
0005ooooo`;o00000oooool2o`000003ooooool0003o000000;o00002?ooool2o`0000;ooooo0_l0
0016ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00002Oooool3o`0000Gooooo0_l00002
ooooo`Co00008_ooool2o`0000Gooooo0ol00003ooooo`;o00000_oooolKo`000004ooooool0003o
0000ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000003o`000003ooooool0
003o000000Gooooo4_l00003ooooo`;o00004Oooool2o`0000Oooooo0_l00006ooooo`;o00002_oo
ool2o`0000?ooooo0ol00014ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00002Oooool2
o`0000Cooooo1Ol00003ooooo`;o00006_ooool2o`000003ooooool0003o000000Oooooo0_l00002
ooooo`Co00001Oooool2o`0000;ooooo5_l00005ooooo`;o00000_ooool2o`0000;ooooo1Ol0000;
oooooa;o00000oooool2o`00017ooooo1?l0000@ooooo`;o00000oooool5o`0000Cooooo1?l00013
ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o000000?oooooo`000?l000005_ooool4o`00
00;ooooo0_l000001?oooooo0000o`000?ooool2o`0000Oooooo0_l000001?oooooo0000o`000?oo
ool4o`000003ooooool0003o000000;o000000?oooooo`000?l000000_l000000ooooooo0000o`00
0003o`000003ooooool0003o000000_o00001?ooool2o`0000;ooooo0_l00004ooooo`;o00001ooo
ool2o`0000Cooooo4Ol00003ooooo`;o00004oooool2o`0000Sooooo0_l00006ooooo`;o00000ooo
ool5o`0000Kooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`1Eooooo`;o00000oooool2
o`0000?ooooo1?l00002ooooo`Go00003Oooool2o`000003ooooool0003o000000Go00000oooool4
o`0000;ooooo5Ol000000ooooooo0000o`00000:ooooo`;o00001OoooolIo`000003ooooool0003o
000001gooooo0_l0000;ooooo`;o00000_ooool5o`0004Oooooo000Looooo`03o`000?oooooooooo
043ooooo0_l00005ooooo`;o00003?ooool2o`000003ooooool0003o000000;o00002_ooool4o`00
0003ooooool0003o000000Oooooo0_l00008ooooo`;o00000oooool:o`000003ooooool0003o0000
00oo00000oooool2o`000003ooooool0003o000000Gooooo0_l00006oooooaGo000000Coooooo`00
0?l0003o00001Oooool2o`0001[ooooo0_l0000=ooooo`Go00004?ooool2o`0003Gooooo000Loooo
o`03o`000?oooooooooo043ooooo1?l00003ooooo`?o00003_ooool2o`0000Oooooo1?l000000ooo
oooo0000o`000002o`000003ooooool0003o000000Oooooo0_l00004ooooo`;o00001ooooolLo`00
00?ooooo0_l000000ooooooo0000o`000004ooooo`;o00002_oooolFo`0000Gooooo0_l0000Joooo
o`;o00004?ooool3o`0000oooooo0_l0000eooooo`007?ooool00ol0003oooooooooo`12ooooo`;o
00001?ooool2o`0001;ooooo0_l000000ooooooo0000o`000004o`000003ooooool0003o000000co
oooo0_l00004ooooo`;o00000_ooool2o`0000?ooooo5_l000000ooooooo0000o`000005o`0000Co
oooo0_l00004ooooo`;o00001oooool2o`000003ooooool0003o000001Co00006oooool2o`0000ko
oooo0ol00005ooooo`?o0000A_ooool001cooooo00?o0000ooooooooool0D?ooool2o`0000[ooooo
0_l000000ooooooo0000o`000003ooooo`;o00001?ooool2o`0000_ooooo0_l00002ooooo`;o0000
00?oooooo`000?l000000_ooool8o`000003ooooool0003o000000ko00000_ooool6o`0000Gooooo
0_l0000:ooooo`;o000000?oooooo`000?l000003_l00002ooooo`Co00005?ooool2o`0000Gooooo
0_l00009ooooo`?o00000_ooool3o`0000Kooooo0_l00016ooooo`007?ooool00ol0003ooooooooo
o`1:ooooo`;o00001?ooool4o`00013ooooo0_l00004ooooo`Co00002Oooool2o`0000;ooooo0_l0
0005ooooo`So000000?oooooo`000?l000003_l000000ooooooo0000o`000002o`000003ooooool0
003o000000Cooooo0ol0000;ooooo`;o000000?oooooo`000?l000004ol0000Dooooo`Co00000ooo
ool3o`0000Sooooo0ol00008ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0@oooool2
o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Oooooo0_l00006ooooo`Co000000?ooooo
o`000?l000000oooool2o`0000_ooooo6?l000000ooooooo0000o`000006o`0000Gooooo0_l0000<
oooooaSo000000?oooooo`000?l000000_l0000Aooooo`;o00000_ooool4o`0000?ooooo0_l0000:
ooooo`;o00000_ooool2o`000003ooooool0003o000004Kooooo000Looooo`03o`000?oooooooooo
04?ooooo0_l00005ooooo`;o00002oooool4o`0000?ooooo0_l00002ooooo`?o00002_ooool4o`00
0003ooooool0003o000000;o00002OoooolQo`0000Gooooo0_l0000>oooooaKo000000?oooooo`00
0?l000000_l0000Eooooo`?o00001?ooool2o`0000[ooooo0ol000001?oooooo0000o`000?ooool2
o`0004Kooooo000Looooo`;o0000A?ooool2o`0000Gooooo0_l0000;ooooo`;o00001Oooool2o`00
00?ooooo0_l0000<ooooo`;o00000_ooool3o`0000Sooooo3_l000000ooooooo0000o`00000@o`00
00Kooooo0_l00009ooooo`;o00000ooooolEo`0001[ooooo1_l0000?ooooo`;o000000?oooooo`00
0?l000000ol00016ooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o00002Oooool2o`0000[o
oooo0_l00009ooooo`;o00000_oooolKo`0000kooooo0_l00002ooooo`?o00000_ooool2o`0000;o
oooo3?l000000ooooooo0000o`000006o`0001Oooooo0_l00002ooooo`;o00003?ooool2o`0000Ko
oooo0ol00016ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00006?ooool2o`0000Cooooo
0_l00003ooooo`;o00000oooool2o`0000Kooooo0_l00008ooooo`;o00000_oooolJo`0000_ooooo
0_l00002ooooo`;o00000_ooool4o`000004ooooool0003o0000ooooo`Ko000000?oooooo`000?l0
00003Ol00003ooooo`;o00009?ooool2o`0004oooooo000Looooo`03o`000?oooooooooo03kooooo
0_l00004ooooo`;o00001?ooool2o`0000gooooo0_l000000ooooooo0000o`000006ooooo`;o0000
2?ooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000Go0000
00?oooooo`000?l000006_l0000:ooooo`;o00001Oooool5o`000004ooooool0003o0000oooooa?o
00001_ooool2o`0000cooooo0_l00004ooooo`;o00000_ooool2o`0000Sooooo0_l0000=ooooo`Co
0000@_ooool001cooooo00?o0000ooooooooool0>oooool2o`000003ooooool0003o000000Kooooo
0_l00002ooooo`Co00002?ooool2o`000004ooooool0003o0000ooooo`;o00001Oooool2o`0000ko
oooo0_l00003ooooo`;o000000?oooooo`000?l000001?l00002oooooago00004?ooool4o`0000;o
oooo1_l000000ooooooo0000o`000004o`000003ooooool0003o000000Ko00002?ooool2o`0000Oo
oooo0_l000001?oooooo0000o`000?ooool9o`0000Sooooo0_l00002ooooo`;o00000oooool3o`00
00?ooooo1Ol00011ooooo`007?ooool00ol0003oooooooooo`0kooooo`;o00001Oooool3o`000003
ooooool0003o000000Cooooo0_l00008ooooo`;o00000oooool4o`0000Cooooo0_l00007ooooo`;o
00005?ooool2o`000003ooooool0003o000001?o000000?oooooo`000?l000000ol0000Booooo`;o
00000oooool5o`000003ooooool0003o000000oo000000?oooooo`000?l000000oooool2o`0000Oo
oooo0_l00004ooooo`Co000000?oooooo`000?l000001?ooool2o`0000Sooooo0_l000000ooooooo
0000o`000004o`0000Gooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`11ooooo`Co0000
1_ooool3o`0000;ooooo0_l00005ooooo`;o00000_ooool4o`0000;ooooo0_l00009ooooo`Co0000
4_oooolLo`0001Cooooo1?l000000ooooooo0000o`00000Ho`0000;ooooo0_l0000<ooooo`;o0000
2oooool2o`0000;ooooo0_l00002ooooo`Co000000Goooooo`000?l0003o0000ooooo`02o`0004So
oooo000Looooo`03o`000?oooooooooo047ooooo0_l00008ooooo`?o00000_ooool2o`000003oooo
ool0003o000000;ooooo0_l00006ooooo`Co00002_ooool3o`0000Oooooo0_l00009oooooa_o0000
5?ooool5o`000003ooooool0003o000000Ko000000?oooooo`000?l000002?l000001?oooooo0000
o`000?ooool2o`000003ooooool0003o000000;o00003?ooool2o`0000kooooo0ol00002ooooo`;o
00001Oooool2o`0004[ooooo000Looooo`03o`000?oooooooooo04Oooooo0_l00002ooooo`;o0000
00?oooooo`000?l000000oooool4o`0000Sooooo1?l00002ooooo`;o00001_ooool2o`0000Sooooo
0_l0000:oooooaWo00004?ooool4o`000003ooooool0003o000000Co000000?oooooo`000?l00000
0_l00005ooooo`Wo00000_ooool2o`0000?ooooo0_l0000Dooooo`;o00002?ooool2o`0000[ooooo
0_l0001:ooooo`007?ooool00ol0003oooooooooo`17ooooo`?o00001?ooool2o`0000;ooooo0_l0
00000ooooooo0000o`00000>ooooo`Co00006_ooool;o`000003ooooool0003o000000Oo000000Co
ooooo`000?l0003o00004?ooool6o`0000?ooooo0_l00005ooooo`;o00001_ooool3o`000003oooo
ool0003o000000;ooooo1?l00008ooooo`;o00000_ooool2o`0000?ooooo0_l00004ooooo`;o0000
H?ooool001cooooo00?o0000ooooooooool0Aoooool4o`000003ooooool0003o000000Cooooo0ol0
000Booooo`;o00007?ooool9o`000003ooooool0003o000000Co000000?oooooo`000?l000006?oo
ool2o`0000;ooooo1Ol000000ooooooo0000o`000002o`0000Kooooo1?l00006ooooo`;o00002?oo
ool2o`0000;ooooo0_l00003ooooo`;o0000I_ooool001cooooo00?o0000ooooooooool0BOooool2
o`000003ooooool0003o000000Gooooo0_l00003ooooo`;o00000oooool3o`0001;ooooo0_l00005
ooooo`;o00001?ooool7o`000003ooooool0003o000000Go00000_ooool:o`0000cooooo0_l00008
ooooo`;o00000_ooool5o`000003ooooool0003o000000[ooooo0_l0000Rooooo`;o00001oooool2
o`0005Cooooo000Looooo`03o`000?oooooooooo04cooooo1_l00004ooooo`Co00000oooool3o`00
013ooooo1_l00003ooooo`;o00001?ooool7o`000003ooooool0003o0000017o00002oooool3o`00
00Sooooo0_l0000?ooooo`;o00009oooool2o`0000Kooooo1Ol000000ooooooo0000o`00001?oooo
o`007?ooool00ol0003oooooooooo`1<ooooo`Ko000000Coooooo`000?l0003ooooo0_l00004oooo
o`;o00004Oooool3o`000004ooooool0003o0000o`0000Wooooo0_l00003ooooo`;o000000Gooooo
o`000?l0003o0000ooooo`0?o`0000_ooooo0_l000000ooooooo0000o`00000=ooooo`;o00001Ooo
ool2o`000003ooooool0003o000001?ooooo0_l0000Iooooo`?o000000?oooooo`000?l000000ol0
001?ooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00001oooool2o`0000Sooooo0ol00006
ooooo`?o000000Coooooo`000?l0003o00004?ooool>o`000003ooooool0003o000000?o00002?oo
ool2o`0000Cooooo0ol0000<ooooo`;o00001Oooool2o`00013ooooo0_l00004ooooo`;o00006Ooo
ool2o`0000?ooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`1Looooo`;o00002?ooool3
o`0000cooooo0_l00003ooooo`;o00002_ooool5o`0000Oooooo0_l00003ooooo`;o00002Oooool4
o`000003ooooool0003o000000;o00000_ooool2o`0001;ooooo0_l0000=ooooo`Co00008?ooool4
o`00057ooooo000Looooo`;o0000F_ooool2o`000003ooooool0003o000001Oooooo0_l00003oooo
o`;o00000oooool2o`0000Sooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00002oooool2
o`0000Cooooo1_l00004ooooo`;o00000oooool2o`0000gooooo0_l0000?ooooo`;o00001_ooool2
o`0001Oooooo0ol000000ooooooo0000o`00001@ooooo`007?ooool00ol0003oooooooooo`1Ioooo
o`;o00006oooool3o`0000Kooooo0_l00003ooooo`;o00001_ooool3o`000003ooooool0003o0000
00_ooooo0_l00005ooooo`Co00002_ooool4o`0000Gooooo0_l0000@ooooo`Go00000_ooool2o`00
00Cooooo0_l00008ooooo`;o00001_ooool2o`0000Gooooo0ol000000ooooooo0000o`00001@oooo
o`007?ooool00ol0003oooooooooo`1:ooooo`?o00002oooool2o`0000;ooooo0_l0000Booooo`;o
00001?ooool3o`0000_ooooo0_l00007ooooo`;o00004oooool4o`0000gooooo0ol00005ooooo`;o
00000_ooool2o`0000cooooo1_l000000ooooooo0000o`000008ooooo`;o00000_ooool4o`0000Ko
oooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`1:ooooo`?o00001?ooool2o`0000Gooooo
0_l00002ooooo`;o00002Oooool2o`0000;ooooo0_l00003ooooo`;o00001_ooool2o`0000;ooooo
0_l00009ooooo`;o00001?ooool2o`00017ooooo1?l00006ooooo`;o00000_ooool2o`0000oooooo
0_l0000?ooooo`Go00002Oooool2o`0000;ooooo0_l0001Uooooo`007?ooool00ol0003ooooooooo
o`1Aooooo`;o00002Oooool2o`0000Cooooo0_l00003ooooo`;o00000_ooool2o`0000_ooooo0_l0
0002ooooo`;o00002Oooool2o`0000kooooo0_l00006ooooo`?o00001Oooool2o`000003ooooool0
003o000000Co00006Oooool2o`0000Gooooo1_l00005ooooo`;o00004?ooool2o`0005[ooooo000L
ooooo`03o`000?oooooooooo04gooooo0_l00004ooooo`;o00003Oooool2o`0000[ooooo0ol00002
ooooo`;o00003_ooool2o`000003ooooool0003o000000Cooooo0_l00009ooooo`;o00001_ooool2
o`0000Kooooo0_l00002ooooo`Co00006_ooool2o`0000;ooooo0_l00005ooooo`;o000000?ooooo
o`000?l000000_ooool2o`00013ooooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`1=oooo
o`Co00000_ooool2o`0000;ooooo0_l00003ooooo`;o00001Oooool3o`0000Sooooo1ol00004oooo
o`;o00002?ooool2o`000003ooooool0003o000000?ooooo0ol00004ooooo`;o00000oooool2o`00
00gooooo0_l0000:ooooo`;o00002Oooool2o`0000kooooo0_l00005ooooo`;o000000Coooooo`00
0?l0003ooooo0_l0000Aooooo`;o00005?ooool2o`0004Cooooo000Looooo`03o`000?oooooooooo
04oooooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo0_l00005ooooo`?o00002oooool2o`00
00Kooooo0_l00003ooooo`;o000000Coooooo`000?l0003o00001oooool2o`0000Gooooo0_l00003
ooooo`;o00000_ooool4o`0000Oooooo0_l0000:ooooo`;o00002Oooool2o`000003ooooool0003o
000000;o00003?ooool2o`0000;ooooo0_l00004ooooo`;o00004?ooool2o`0001Gooooo0_l00014
ooooo`007?ooool00ol0003oooooooooo`1Vooooo`?o000000?oooooo`000?l000002Oooool2o`00
00;ooooo0_l00003ooooo`;o000000Coooooo`000?l0003o00003_ooool2o`0000Oooooo1?l0000H
ooooo`;o00001oooool4o`0000Sooooo0_l00002ooooo`;o000000?oooooo`000?l000001?ooool4
o`0000oooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`1Jooooo`;o00002_ooool3o`00
0003ooooool0003o000000Wooooo0_l00002ooooo`;o0000??ooool2o`0000[ooooo0_l000001?oo
oooo0000o`000?l00002ooooo`?o00001Oooool2o`0000Cooooo1?l0001/ooooo`007?ooool00ol0
003oooooooooo`0nooooo`;o00006_ooool2o`0000Kooooo0_l000000ooooooo0000o`000003oooo
o`;o000000?oooooo`000?l000002?ooool2o`0000Wooooo0_l00009ooooo`Co00002_ooool2o`00
00kooooo0_l0000Fooooo`;o000000?oooooo`000?l000000_l000001?oooooo0000o`000?ooool2
o`0000Oooooo1?l0000Fooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0?_ooool2o`00
023ooooo1?l000000ooooooo0000o`000006ooooo`;o00002?ooool2o`0000?ooooo0_l00004oooo
o`;o00001?ooool3o`0000;ooooo1?l000000ooooooo0000o`000003ooooo`;o00000_ooool2o`00
00kooooo0_l0000Booooo`;o00000_ooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool2
o`0000Oooooo1?l0000:ooooo`;o00002_ooool2o`0005Kooooo000Looooo`03o`000?oooooooooo
063ooooo0_l0000Jooooo`;o00002_ooool3o`0000;ooooo0_l000000ooooooo0000o`000002o`00
00?ooooo0_l0000Pooooo`;o00001?ooool2o`0000;ooooo0_l00004ooooo`;o00001?ooool2o`00
00Oooooo0_l00007ooooo`?o000000Coooooo`000?l0003ooooo0_l0001Oooooo`007?ooool00ol0
003oooooooooo`1Eooooo`;o00008oooool2o`0001Cooooo0_l00007ooooo`;o00002?ooool2o`00
01Cooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00000oooool3
o`0000Oooooo0_l00007ooooo`?o00001?ooool2o`0000;ooooo0_l0001Kooooo`007?ooool00ol0
003oooooooooo`1Eooooo`;o00002_ooool2o`0001Oooooo1Ol0000Hooooo`Co00002?ooool2o`00
00Gooooo0_l0000Cooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000004
ooooo`;o00000_ooool2o`0000Kooooo0_l0000@ooooo`Co0000FOooool001cooooo00?o0000oooo
ooooool0H?ooool3o`0001Sooooo1?l000001?oooooo0000o`000?l0000;ooooo`?o00001_ooool2
o`0000Oooooo0_l00008ooooo`;o00002oooool2o`0000oooooo0_l00003ooooo`Co000000Cooooo
o`000?l0003ooooo0_l00003ooooo`;o00004_ooool2o`0005Wooooo000Looooo`;o0000HOooool4
o`0000Kooooo0_l000000ooooooo0000o`00000Aooooo`?o000000Coooooo`000?l0003ooooo0_l0
0005ooooo`?o000000?oooooo`000?l000000_ooool2o`0000Kooooo1?l00004ooooo`;o00003ooo
ool2o`0001Cooooo1?l00004ooooo`;o00005?ooool2o`0000;ooooo0_l0001Hooooo`007?ooool0
0ol0003oooooooooo`1Rooooo`;o00001_ooool5o`0000gooooo1?l00004ooooo`;o000000Gooooo
o`000?l0003o0000ooooo`05o`0000;ooooo0_l00002ooooo`Co00001?ooool4o`0000Cooooo0_l0
000Vooooo`;o00006_ooool3o`0000;ooooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`1F
ooooo`;o00002oooool2o`0000Oooooo0_l00006ooooo`;o00001_ooool4o`0000Sooooo0_l00000
0ooooooo0000o`000003o`0000;ooooo0_l00004ooooo`Co0000;Oooool2o`0000?ooooo0_l0000E
ooooo`;o00000oooool2o`0005gooooo000Looooo`03o`000?oooooooooo05Kooooo1?l00003oooo
o`;o00000oooool3o`0000?ooooo0_l00005ooooo`;o00000oooool2o`0000Cooooo1?l00006oooo
o`?o00002oooool2o`0000Kooooo0_l0000]ooooo`;o00002Oooool2o`0000kooooo0ol0001Roooo
o`007?ooool00ol0003oooooooooo`1Hooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o
00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000007ooooo`Go00001oooool3o`0003Go
oooo0_l0000Fooooo`;o00003_ooool2o`0006?ooooo000Looooo`03o`000?oooooooooo04[ooooo
0_l00009ooooo`;o00001?ooool2o`0000oooooo0_l0000:ooooo`;o000000?oooooo`000?l00000
1?ooool2o`0000Cooooo0_l00007ooooo`;o00002?ooool2o`0000kooooo0_l00008ooooo`;o0000
1_ooool2o`00023ooooo0_l0001Yooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o00002Ooo
ool2o`0002[ooooo0_l00004ooooo`;o00000_ooool2o`0000?ooooo0_l00008ooooo`;o00002Ooo
ool2o`000003ooooool0003o000000;o00002?ooool2o`0000Wooooo0_l00004ooooo`;o00004Ooo
ool2o`0000Cooooo0ol00007ooooo`Go0000G?ooool001cooooo00?o0000ooooooooool0P_ooool2
o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000005Oooool2o`000003ooooool0003o
000000Gooooo0_l0000>ooooo`;o00001?ooool2o`000003ooooool0003o000000kooooo0_l00005
ooooo`;o00001oooool5o`0005cooooo000Looooo`03o`000?oooooooooo06Kooooo0_l00008oooo
o`;o00002oooool2o`000003ooooool0003o000000;o00000_ooool2o`0000?ooooo0_l000000ooo
oooo0000o`000005ooooo`;o00000_ooool2o`0001Cooooo0_l0000;ooooo`;o000000?oooooo`00
0?l000001Oooool5o`0000Sooooo0ol00006ooooo`;o000000?oooooo`000?l00000J?ooool001co
oooo00?o0000ooooooooool0F_ooool2o`0000[ooooo0_l00008ooooo`;o00001Oooool3o`0000?o
oooo0_l000000ooooooo0000o`000003o`0000Kooooo0_l00002ooooo`;o00001?ooool6o`0000_o
oooo0_l0000Dooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`;o00002?ooool3o`00
0003ooooool0003o000000?ooooo0_l00003ooooo`;o00000oooool2o`00067ooooo000Looooo`03
o`000?oooooooooo05[ooooo0_l0000@ooooo`;o00000_ooool2o`0000Gooooo0ol00007ooooo`Co
00002_ooool2o`0000Kooooo0_l00002ooooo`;o000000?oooooo`000?l000001_ooool2o`0001_o
oooo0ol0000=ooooo`Ko00001_ooool4o`0000?ooooo0_l0001Qooooo`007?ooool00ol0003ooooo
ooooo`1Rooooo`;o00002?ooool2o`0000;ooooo0_l00002ooooo`;o00003?ooool2o`0001Oooooo
0_l000000ooooooo0000o`000009ooooo`;o00000_ooool2o`0001Gooooo1?l0000;ooooo`Co0000
2?ooool4o`0006Kooooo000Looooo`03o`000?oooooooooo06;ooooo0_l00005ooooo`;o000000?o
ooooo`000?l000001_ooool2o`0001[ooooo0_l0000Dooooo`;o000000?oooooo`000?l000000_oo
ool2o`0000Cooooo1?l0000:ooooo`;o00000oooool2o`0000;ooooo0_l000000ooooooo0000o`00
000Booooo`;o0000I_ooool001cooooo00?o0000ooooooooool0H?ooool6o`0000?ooooo0_l00000
0ooooooo0000o`00000Kooooo`;o00001Oooool2o`000003ooooool0003o000000Sooooo0_l00007
ooooo`;o00000_ooool2o`0000Oooooo1?l0000:ooooo`;o00001oooool2o`000003ooooool0003o
000001?ooooo0_l000000ooooooo0000o`00001Rooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^
k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0
H?ooool2o`0000;ooooo0_l0000Oooooo`;o00000_ooool2o`0000Cooooo0_l000001?oooooo0000
o`000?l00008ooooo`;o00002oooool2o`0001oooooo0_l00004ooooo`;o00003oooool2o`000003
ooooool0003o000006;ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44oooo
o`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1booooo`;o00004Oooool2
o`0000Oooooo0ol000000ooooooo0000o`000004ooooo`;o00000oooool2o`0001Sooooo1?l00005
ooooo`;o00002Oooool2o`0000;ooooo1?l0001fooooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`1b
ooooo`;o00001oooool2o`0000kooooo0_l000000ooooooo0000o`000008ooooo`;o00005?ooool2
o`0000Oooooo1Ol00004ooooo`;o00003Oooool2o`0007Sooooo00000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000Noooool4
o`000003ooooool0003o000000Kooooo0_l000001?oooooo0000o`000?ooool2o`0000[ooooo0_l0
00000ooooooo0000o`00000?ooooo`Go00001oooool2o`0000?ooooo0_l00028ooooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_oo
ool00ol0003oooooooooo`1`ooooo`;o00001Oooool2o`0000Cooooo0_l000000ooooooo0000o`00
0002o`0000Cooooo0_l00004ooooo`;o00000oooool4o`0000?ooooo0_l000000ooooooo0000o`00
000@ooooo`Co00003?ooool2o`0000cooooo0_l0001jooooo`0000?ooooooa0@4?ooool00_ooool0
0ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooooooo
o`1`ooooo`;o00001Oooool3o`0000Kooooo1?l00005ooooo`;o00000oooool3o`0000;ooooo1_l0
00000ooooooo0000o`000005ooooo`;o00001Oooool2o`0000Gooooo0_l00003ooooo`;o00001ooo
ool2o`0000kooooo0_l0001jooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`00
0?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`1gooooo`?o00001?ooool2o`0000Co
oooo0_l00003ooooo`;o00000oooool3o`0000Kooooo0_l000000ooooooo0000o`000005ooooo`;o
00001Oooool2o`0000Sooooo1?l00007ooooo`?o00002_ooool2o`0007gooooo00001_ooooook^k^
oc8b<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooo
oooo06oooooo0_l00006ooooo`;o00001?ooool3o`0000Cooooo0_l0000=ooooo`;o00000_ooool2
o`000003ooooool0003o000000Oooooo0ol0000<ooooo`;o00002?ooool4o`0000[ooooo0_l0001m
ooooo`007?ooool00ol0003oooooooooo`1_ooooo`;o00003?ooool4o`0000gooooo0_l00003oooo
o`;o00000_ooool6o`0000Kooooo0ol00003ooooo`;o00003?ooool2o`0000?ooooo0_l0000:oooo
o`;o0000Ooooool001cooooo00?o0000ooooooooool0NOooool2o`0000Cooooo0_l00007ooooo`;o
000000Coooooo`000?l0003ooooo1?l00006ooooo`;o000000?oooooo`000?l000001_ooool2o`00
00Cooooo0_l00006ooooo`;o00001?ooool2o`0000;ooooo0ol0000:ooooo`?o0000O_ooool001co
oooo00?o0000ooooooooool0LOooool2o`0000Kooooo0_l0000=ooooo`;o000000?oooooo`000?l0
00000oooool2o`0000[ooooo0_l0000Aooooo`Co00000_ooool2o`0000Cooooo0ol0000:ooooo`?o
0000O_ooool001cooooo00?o0000ooooooooool0LOooool2o`00027ooooo0_l00006ooooo`;o0000
0oooool2o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`Go000000?oooooo`000?l00000
T_ooool001cooooo00?o0000ooooooooool0U?ooool2o`0000Kooooo0_l00003ooooo`;o00000ooo
ool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000005ooooo`;o00001?oo
ool2o`0008Sooooo000Looooo`03o`000?oooooooooo07[ooooo0_l0000Hooooo`;o00006?ooool5
o`0000Cooooo1?l00004ooooo`;o0000R?ooool001cooooo00?o0000ooooooooool0N_ooool2o`00
01Kooooo0_l00004ooooo`;o00005?ooool2o`000004ooooool0003o0000o`0000?ooooo0_l0002@
ooooo`007?ooool00ol0003oooooooooo`21ooooo`;o00002_ooool2o`0000?ooooo0_l00004oooo
o`;o00004?ooool2o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`;o0000T?ooool001co
oooo00?o0000ooooooooool0POooool2o`0000[ooooo0ol0000Jooooo`;o00000oooool2o`0009So
oooo000Looooo`03o`000?oooooooooo08kooooo0_l00005ooooo`?o00002_ooool2o`000:Gooooo
000Looooo`03o`000?oooooooooo08kooooo0_l00002ooooo`;o000000Coooooo`000?l0003o0000
2_ooool2o`0000Kooooo0_l0000Sooooo`;o0000N?ooool001cooooo0_l0002?ooooo`;o00000_oo
ool2o`0001Kooooo0_l0000Sooooo`;o0000N?ooool001cooooo00?o0000ooooooooool0W?ooool2
o`0000_ooooo0_l0000Qooooo`;o0000Noooool001cooooo00?o0000ooooooooool0Toooool2o`00
00?ooooo0_l000001?oooooo0000o`000?l00009ooooo`Co00008Oooool2o`0007_ooooo000Loooo
o`03o`000?oooooooooo09?ooooo0_l00003ooooo`;o000000Coooooo`000?l0003o00000oooool2
o`000004ooooool0003o0000ooooo`;o0000X?ooool001cooooo00?o0000ooooooooool0W?ooool2
o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`;o0000Voooool001cooooo00?o0000oooo
ooooool0[?ooool3o`0009[ooooo000Looooo`03o`000?oooooooooo09cooooo0_l0000?ooooo`;o
00004Oooool2o`0008Oooooo000Looooo`03o`000?oooooooooo09cooooo0_l0000Rooooo`;o0000
Qoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Looooo`;o0000Zoooool001cooooo00?o
0000ooooooooool0W?ooool2o`000:_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001;ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oo
ooooB_ooool001Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood[ooooo
000Dooooo`03o`000?oooooooooo00Gooooo0ol0003ooooood[ooooo000Dooooo`03o`000?oooooo
oooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003o
ooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001;ooooo00?o
EEEEofIVI_l00000oooooomDooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
XOooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo01Kooooo1?l000002?l@413o
oooooooooonHV9So410@o`000?lb<S;oc<c<0oooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o410@olc<c02<ooooo`00X_ooool01Ol0003ooooooooooooooooo000000Wo
oooo1_l0000<ooooo`03o`000?oooooooooo00;ooooo00Go410@okZj^_ooooooMgMgoc8b<P03oooo
o`05ob4Q8OnHV9SooooooiRHV?lQ8B400oooool01OmEEEGoMgMgoooooonHV9So8B4Q08cooooo002R
ooooo`05o`000?ooooooooooooooool000006oooool00ol0003oooooooooo`06ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool0R_ooool00:;ooooo00Go0000ooooooooooooooooo`000009ooooo`Ko00003?ooool00ol0003o
ooooooooo`05ooooo`03ojVYZOl@413ooooo00;ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P03oooo
o`05o`000?nHV9SooooooiRHV?lQ8B40S?ooool00:;ooooo00Go0000ohN7QoooooooZJVYo`00000K
ooooo`03o`000?oooooooooo00Cooooo00?o410@o`000?nj^[X00oooool01Oo<c<co0000o`000?l0
003oc<c<00?ooooo00Go0000oeEEEOl0003o410@olc<c02<ooooo`00XOooool00ol@413o0000ogMg
M`02o`000003oiRHV?oooooooooo01Wooooo00?o0000ooooooooool01Oooool00onj^[[o8B4Qoooo
o`02ooooo`05oa0@4?nj^[[ooooookZj^_l@41000oooool00omEEEGoQhN7ooooo`2>ooooo`00`_oo
ool00ol0003oooooooooo`02ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01Ol0003o^[Zj
oooooonj^[[o000000?ooooo00?ogMgMoa0@4?nHV9P0S_ooool00<3ooooo00?oEEEEofIVI_l00000
1?ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@04oooo
o`04olc<c?m4A4Co0000oa0@48cooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1392) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.43241 .293 Mdot
.44852 .30554 Mdot
.42451 .65521 Mdot
.58792 .46057 Mdot
.61472 .76957 Mdot
.43195 .62041 Mdot
.35542 .52076 Mdot
.36619 .47029 Mdot
.41733 .66015 Mdot
.37491 .41016 Mdot
.34508 .46169 Mdot
.54085 .43715 Mdot
.33694 .49576 Mdot
.62218 .43844 Mdot
.85162 .59958 Mdot
.66585 .50036 Mdot
.43239 .29423 Mdot
.58316 .60505 Mdot
.67482 .459 Mdot
.43549 .60716 Mdot
.39451 .31602 Mdot
.61913 .44345 Mdot
.41397 .33417 Mdot
.62272 .43825 Mdot
.59964 .47801 Mdot
.42117 .34472 Mdot
.44957 .39206 Mdot
.62162 .49466 Mdot
.65638 .4772 Mdot
.35853 .45874 Mdot
.66473 .57978 Mdot
.78425 .67726 Mdot
.69098 .48964 Mdot
.78337 .57642 Mdot
.35709 .50176 Mdot
.59569 .32287 Mdot
.43206 .63149 Mdot
.3425 .47301 Mdot
.33551 .47533 Mdot
.37177 .47926 Mdot
.35599 .47138 Mdot
.42714 .32711 Mdot
.32501 .31644 Mdot
.35965 .60463 Mdot
.60108 .51439 Mdot
.45556 .80625 Mdot
.53057 .36836 Mdot
.62121 .42065 Mdot
.45836 .36235 Mdot
.4822 .70649 Mdot
.31914 .59747 Mdot
.34019 .5199 Mdot
.41097 .60787 Mdot
.23263 .25025 Mdot
.32799 .50532 Mdot
.55737 .43551 Mdot
.42479 .64152 Mdot
.62849 .45536 Mdot
.62741 .43873 Mdot
.5987 .24111 Mdot
.56349 .4728 Mdot
.56183 .6517 Mdot
.47995 .34658 Mdot
.46533 .55208 Mdot
.41309 .6424 Mdot
.33401 .47128 Mdot
.45689 .32295 Mdot
.33595 .50608 Mdot
.64699 .53907 Mdot
.38465 .66066 Mdot
.61594 .41893 Mdot
.34324 .4636 Mdot
.39986 .34296 Mdot
.64194 .47947 Mdot
.4097 .7375 Mdot
.4174 .80827 Mdot
.59555 .69928 Mdot
.59214 .30389 Mdot
.59073 .2353 Mdot
.50103 .73632 Mdot
.62342 .50831 Mdot
.675 .63855 Mdot
.41958 .80088 Mdot
.44879 .37987 Mdot
.68256 .47051 Mdot
.55327 .60884 Mdot
.63697 .48234 Mdot
.53013 .83214 Mdot
.58656 .42193 Mdot
.56116 .57811 Mdot
.42806 .66795 Mdot
.44515 .35634 Mdot
.58649 .46572 Mdot
.65558 .46467 Mdot
.64561 .25328 Mdot
.64736 .41745 Mdot
.61093 .45863 Mdot
.46363 .36321 Mdot
.33696 .51906 Mdot
.56367 .43666 Mdot
.39715 .57244 Mdot
.46501 .64178 Mdot
.57644 .48469 Mdot
.42255 .67577 Mdot
.41167 .36047 Mdot
.65485 .4643 Mdot
.32895 .48403 Mdot
.57104 .4673 Mdot
.22209 .45466 Mdot
.42867 .29763 Mdot
.64114 .49194 Mdot
.60107 .67642 Mdot
.52168 .24139 Mdot
.44707 .36485 Mdot
.37282 .57031 Mdot
.67272 .45827 Mdot
.61864 .46689 Mdot
.46086 .32737 Mdot
.46436 .65873 Mdot
.50226 .82882 Mdot
.46789 .36272 Mdot
.35617 .45332 Mdot
.39325 .3341 Mdot
.55804 .41191 Mdot
.40658 .63798 Mdot
.36466 .58838 Mdot
.24145 .41446 Mdot
.69586 .57564 Mdot
.63542 .48006 Mdot
.33487 .32706 Mdot
.4605 .62338 Mdot
.44946 .34353 Mdot
.33924 .50257 Mdot
.68992 .44411 Mdot
.4294 .30865 Mdot
.33453 .46401 Mdot
.57914 .68029 Mdot
.26534 .56084 Mdot
.40457 .332 Mdot
.4847 .45186 Mdot
.3146 .51512 Mdot
.36079 .50858 Mdot
.80749 .41797 Mdot
.45683 .33086 Mdot
.58555 .64527 Mdot
.3485 .49855 Mdot
.72667 .53904 Mdot
.58976 .51039 Mdot
.65554 .62572 Mdot
.2821 .28274 Mdot
.78122 .55264 Mdot
.28092 .61588 Mdot
.59758 .66324 Mdot
.30336 .50919 Mdot
.60015 .46446 Mdot
.42478 .35507 Mdot
.41718 .33855 Mdot
.56409 .47382 Mdot
.59411 .48506 Mdot
.61014 .41699 Mdot
.64572 .42644 Mdot
.67272 .54028 Mdot
.64234 .40746 Mdot
.52985 .3473 Mdot
.44066 .35825 Mdot
.59314 .45933 Mdot
.40015 .62187 Mdot
.57408 .51656 Mdot
.3521 .46515 Mdot
.6223 .45201 Mdot
.5881 .46334 Mdot
.57242 .49674 Mdot
.34663 .51812 Mdot
.75394 .71231 Mdot
.49014 .25029 Mdot
.73446 .71215 Mdot
.52998 .53962 Mdot
.39005 .64518 Mdot
.62684 .48517 Mdot
.56888 .65284 Mdot
.66709 .32812 Mdot
.58557 .44834 Mdot
.12231 .56778 Mdot
.61208 .45064 Mdot
.65439 .76499 Mdot
.57695 .53155 Mdot
.75869 .66334 Mdot
.67871 .61853 Mdot
.60669 .47696 Mdot
.36273 .36968 Mdot
.33973 .5325 Mdot
.39439 .59423 Mdot
.35431 .47628 Mdot
.40531 .61687 Mdot
.42413 .65047 Mdot
.44629 .56578 Mdot
.53902 .43213 Mdot
.60532 .52838 Mdot
.60559 .41271 Mdot
.41079 .68238 Mdot
.47289 .37295 Mdot
.59678 .68271 Mdot
.45757 .30787 Mdot
.67897 .8017 Mdot
.38142 .73122 Mdot
.37822 .47073 Mdot
.56529 .67949 Mdot
.45157 .65955 Mdot
.41962 .66839 Mdot
.59726 .67514 Mdot
.64869 .44934 Mdot
.45318 .32786 Mdot
.80666 .47545 Mdot
.21419 .49729 Mdot
.77373 .28313 Mdot
.45996 .36659 Mdot
.34502 .36286 Mdot
.36199 .46497 Mdot
.44198 .63885 Mdot
.61623 .46502 Mdot
.64546 .45952 Mdot
.40073 .29826 Mdot
.61894 .41798 Mdot
.4349 .26212 Mdot
.61283 .47253 Mdot
.27825 .50365 Mdot
.6061 .68976 Mdot
.44755 .5666 Mdot
.72429 .5745 Mdot
.43204 .3718 Mdot
.72747 .31815 Mdot
.40835 .66772 Mdot
.66319 .32165 Mdot
.32692 .47507 Mdot
.56554 .67233 Mdot
.39967 .65112 Mdot
.60266 .67807 Mdot
.65882 .4178 Mdot
.42719 .60988 Mdot
.60281 .65318 Mdot
.59165 .58466 Mdot
.60067 .5207 Mdot
.18608 .44632 Mdot
.36984 .48205 Mdot
.44552 .29408 Mdot
.5702 .45372 Mdot
.40085 .66903 Mdot
.69267 .43887 Mdot
.30129 .68103 Mdot
.28893 .54802 Mdot
.46242 .62366 Mdot
.49455 .59828 Mdot
.55821 .66004 Mdot
.3231 .64025 Mdot
.33539 .34054 Mdot
.4494 .30358 Mdot
.64354 .4132 Mdot
.78867 .64008 Mdot
.34767 .49927 Mdot
.57346 .45409 Mdot
.61889 .72667 Mdot
.34443 .51011 Mdot
.62954 .45733 Mdot
.32504 .46775 Mdot
.41699 .33751 Mdot
.54668 .214 Mdot
.46382 .33194 Mdot
.62694 .41658 Mdot
.32505 .49317 Mdot
.45112 .67529 Mdot
.42566 .34255 Mdot
.64404 .43831 Mdot
.62176 .49254 Mdot
.51089 .58425 Mdot
.59954 .45359 Mdot
.71826 .7364 Mdot
.60982 .47514 Mdot
.43724 .65009 Mdot
.60698 .50815 Mdot
.43103 .21272 Mdot
.43838 .5631 Mdot
.4566 .32552 Mdot
.46609 .62539 Mdot
.41565 .65197 Mdot
.41882 .75808 Mdot
.30591 .47552 Mdot
.66577 .47579 Mdot
.3945 .66179 Mdot
.74537 .47837 Mdot
.31106 .4985 Mdot
.56391 .45386 Mdot
.46026 .43983 Mdot
.47589 .7027 Mdot
.41708 .60554 Mdot
.66299 .39209 Mdot
.40488 .34512 Mdot
.58649 .47215 Mdot
.42791 .6716 Mdot
.56165 .39907 Mdot
.64867 .49221 Mdot
.33261 .26159 Mdot
.5108 .59446 Mdot
.32174 .51759 Mdot
.55683 .50368 Mdot
.59197 .42984 Mdot
.4238 .61218 Mdot
.42981 .36849 Mdot
.31046 .50285 Mdot
.42568 .33249 Mdot
.76142 .6486 Mdot
.19226 .44838 Mdot
.6065 .57349 Mdot
.60827 .67756 Mdot
.51419 .65779 Mdot
.76701 .64909 Mdot
.65791 .23271 Mdot
.75506 .37512 Mdot
.8031 .55748 Mdot
.43691 .67426 Mdot
.53281 .69456 Mdot
.41903 .64698 Mdot
.60398 .49528 Mdot
.40886 .63608 Mdot
.79758 .62953 Mdot
.61207 .46951 Mdot
.41682 .62871 Mdot
.6987 .29073 Mdot
.58966 .47008 Mdot
.4526 .30812 Mdot
.67373 .78935 Mdot
.50314 .17639 Mdot
.28719 .53896 Mdot
.45353 .63797 Mdot
.77101 .42621 Mdot
.60901 .45811 Mdot
.60763 .5077 Mdot
.43336 .36205 Mdot
.69679 .46254 Mdot
.57045 .63879 Mdot
.55974 .67499 Mdot
.38263 .51504 Mdot
.60084 .70316 Mdot
.55486 .50037 Mdot
.42717 .34586 Mdot
.65688 .54564 Mdot
.43376 .74633 Mdot
.49228 .69896 Mdot
.38464 .48626 Mdot
.67351 .78836 Mdot
.49231 .35769 Mdot
.3032 .44535 Mdot
.41388 .7098 Mdot
.45793 .35316 Mdot
.77703 .69268 Mdot
.35022 .47609 Mdot
.17705 .47877 Mdot
.37216 .37063 Mdot
.64656 .45043 Mdot
.31545 .49863 Mdot
.66445 .40175 Mdot
.52268 .17733 Mdot
.18443 .55392 Mdot
.57398 .3728 Mdot
.58015 .42904 Mdot
.41459 .7279 Mdot
.61983 .45727 Mdot
.35371 .71905 Mdot
.6112 .48141 Mdot
.42986 .3343 Mdot
.37184 .40978 Mdot
.36935 .55554 Mdot
.44877 .24946 Mdot
.32883 .66152 Mdot
.59861 .65901 Mdot
.61609 .4727 Mdot
.64546 .44772 Mdot
.57946 .63205 Mdot
.4104 .33575 Mdot
.61895 .41574 Mdot
.72419 .30771 Mdot
.65666 .45666 Mdot
.35016 .46826 Mdot
.37617 .28538 Mdot
.50788 .36034 Mdot
.6594 .43962 Mdot
.43009 .38036 Mdot
.37921 .4857 Mdot
.32755 .4917 Mdot
.56161 .51814 Mdot
.36903 .45975 Mdot
.60796 .44363 Mdot
.19453 .58529 Mdot
.40696 .32134 Mdot
.27847 .31115 Mdot
.43749 .3159 Mdot
.57893 .2944 Mdot
.34327 .51535 Mdot
.27954 .55639 Mdot
.63661 .39261 Mdot
.34632 .4801 Mdot
.38811 .34953 Mdot
.63927 .51407 Mdot
.6277 .52109 Mdot
.79631 .46211 Mdot
.44298 .65528 Mdot
.50499 .58436 Mdot
.359 .45841 Mdot
.62666 .42733 Mdot
.66554 .43783 Mdot
.37862 .48303 Mdot
.20167 .54945 Mdot
.5612 .1942 Mdot
.61101 .47307 Mdot
.43785 .3402 Mdot
.44789 .33939 Mdot
.56748 .501 Mdot
.58014 .4853 Mdot
.40016 .63723 Mdot
.46294 .66533 Mdot
.38942 .63273 Mdot
.50268 .58783 Mdot
.27848 .54734 Mdot
.55136 .80504 Mdot
.37169 .47991 Mdot
.3224 .37947 Mdot
.57073 .58343 Mdot
.59935 .41125 Mdot
.45704 .63841 Mdot
.59306 .43077 Mdot
.59744 .44435 Mdot
.32646 .45392 Mdot
.63058 .74648 Mdot
.47849 .39458 Mdot
.42399 .369 Mdot
.31408 .51929 Mdot
.5519 .50369 Mdot
.35111 .43255 Mdot
.56754 .66975 Mdot
.77784 .51894 Mdot
.33394 .46893 Mdot
.45771 .31582 Mdot
.36525 .48857 Mdot
.64901 .46197 Mdot
.60916 .39776 Mdot
.45764 .3487 Mdot
.56344 .63967 Mdot
.69342 .47252 Mdot
.62792 .46038 Mdot
.25592 .29929 Mdot
.75515 .53421 Mdot
.27092 .48922 Mdot
.60718 .47455 Mdot
.66336 .46215 Mdot
.57093 .62377 Mdot
.65561 .45731 Mdot
.59167 .42333 Mdot
.52995 .24826 Mdot
.25638 .41726 Mdot
.571 .68686 Mdot
.20031 .58113 Mdot
.46123 .36422 Mdot
.78201 .65981 Mdot
.44725 .62789 Mdot
.37833 .53482 Mdot
.51857 .19405 Mdot
.40581 .6106 Mdot
.28008 .62238 Mdot
.77563 .67398 Mdot
.39575 .5672 Mdot
.45271 .59767 Mdot
.46708 .39366 Mdot
.63391 .4204 Mdot
.62173 .46567 Mdot
.56902 .64854 Mdot
.44859 .32667 Mdot
.49687 .5421 Mdot
.31708 .76043 Mdot
.61778 .44594 Mdot
.32164 .27516 Mdot
.23866 .64162 Mdot
.46756 .71028 Mdot
.57746 .6604 Mdot
.5534 .66793 Mdot
.61839 .47276 Mdot
.49816 .24042 Mdot
.42193 .34572 Mdot
.64272 .43736 Mdot
.63733 .40609 Mdot
.44913 .64671 Mdot
.42175 .30255 Mdot
.46555 .6567 Mdot
.30494 .5969 Mdot
.71608 .72773 Mdot
.15861 .44965 Mdot
.33025 .51192 Mdot
.33863 .7324 Mdot
.313 .4835 Mdot
.68002 .63806 Mdot
.4286 .59855 Mdot
.58219 .47503 Mdot
.4244 .36461 Mdot
.61973 .4265 Mdot
.58131 .48392 Mdot
.6474 .44762 Mdot
.65805 .43418 Mdot
.16416 .40208 Mdot
.60057 .66303 Mdot
.67936 .43861 Mdot
.43283 .6532 Mdot
.4338 .80011 Mdot
.38754 .78007 Mdot
.64202 .44581 Mdot
.61755 .48579 Mdot
.4153 .31637 Mdot
.56582 .46685 Mdot
.30939 .49211 Mdot
.4699 .32603 Mdot
.6477 .47743 Mdot
.61945 .81133 Mdot
.65468 .48155 Mdot
.75548 .68061 Mdot
.3647 .48694 Mdot
.21016 .47726 Mdot
.6282 .39609 Mdot
.29762 .54881 Mdot
.50528 .58445 Mdot
.39852 .6461 Mdot
.3187 .47011 Mdot
.42933 .63067 Mdot
.28832 .73687 Mdot
.57325 .40605 Mdot
.59929 .46779 Mdot
.60558 .40971 Mdot
.38982 .6452 Mdot
.56137 .82904 Mdot
.3399 .65943 Mdot
.58488 .39631 Mdot
.39928 .62849 Mdot
.45544 .38459 Mdot
.77837 .48464 Mdot
.42993 .32037 Mdot
.60905 .64162 Mdot
.35966 .46639 Mdot
.56335 .64168 Mdot
.69748 .68753 Mdot
.43538 .2972 Mdot
.41788 .2887 Mdot
.4452 .62858 Mdot
.38888 .40842 Mdot
.50097 .13347 Mdot
.37081 .36811 Mdot
.69596 .59896 Mdot
.43072 .35443 Mdot
.65742 .47184 Mdot
.68257 .66921 Mdot
.37542 .39084 Mdot
.42604 .63158 Mdot
.59395 .43909 Mdot
.54646 .21072 Mdot
.3999 .63767 Mdot
.59286 .41043 Mdot
.43488 .65669 Mdot
.35857 .4778 Mdot
.45639 .64661 Mdot
.41399 .27967 Mdot
.6356 .48859 Mdot
.53778 .1236 Mdot
.5315 .67814 Mdot
.60632 .46108 Mdot
.32211 .52468 Mdot
.23853 .57889 Mdot
.57742 .46076 Mdot
.6069 .66074 Mdot
.41432 .62341 Mdot
.4036 .40845 Mdot
.61112 .47645 Mdot
.39959 .62679 Mdot
.42409 .29261 Mdot
.30251 .51614 Mdot
.63648 .24964 Mdot
.28836 .53105 Mdot
.43496 .36448 Mdot
.50665 .48479 Mdot
.33705 .45467 Mdot
.66353 .46035 Mdot
.64874 .41746 Mdot
.44058 .33859 Mdot
.62706 .6207 Mdot
.58529 .49881 Mdot
.61628 .50771 Mdot
.4455 .64478 Mdot
.42792 .62702 Mdot
.73955 .37007 Mdot
.45525 .66789 Mdot
.61561 .39797 Mdot
.4392 .33613 Mdot
.58583 .46344 Mdot
.41419 .31357 Mdot
.56625 .46711 Mdot
.54052 .50733 Mdot
.41059 .33715 Mdot
.30398 .46992 Mdot
.59431 .44221 Mdot
.67805 .50712 Mdot
.57144 .46334 Mdot
.63944 .42413 Mdot
.40247 .641 Mdot
.57067 .65968 Mdot
.61772 .40468 Mdot
.54245 .6759 Mdot
.59418 .68215 Mdot
.34512 .55272 Mdot
.448 .64951 Mdot
.59058 .64316 Mdot
.2447 .66324 Mdot
.41455 .61056 Mdot
.57162 .64247 Mdot
.38935 .78118 Mdot
.35576 .50446 Mdot
.40345 .34357 Mdot
.59012 .47326 Mdot
.74604 .64771 Mdot
.52325 .36192 Mdot
.47281 .62367 Mdot
.60882 .47142 Mdot
.57611 .45118 Mdot
.46561 .37047 Mdot
.32828 .78602 Mdot
.38457 .65974 Mdot
.65836 .48226 Mdot
.44643 .30619 Mdot
.33437 .80789 Mdot
.43127 .64875 Mdot
.56805 .64596 Mdot
.36225 .50138 Mdot
.45087 .39735 Mdot
.23867 .41512 Mdot
.34236 .52497 Mdot
.37592 .67259 Mdot
.31066 .59227 Mdot
.67427 .44581 Mdot
.45891 .63226 Mdot
.79186 .33793 Mdot
.69834 .51214 Mdot
.47586 .56366 Mdot
.77246 .43607 Mdot
.45335 .3588 Mdot
.31182 .48625 Mdot
.59821 .66498 Mdot
.45447 .37127 Mdot
.42921 .29439 Mdot
.37685 .48051 Mdot
.50692 .25926 Mdot
.45554 .43806 Mdot
.34137 .47059 Mdot
.76237 .57575 Mdot
.55747 .78202 Mdot
.45749 .63456 Mdot
.57175 .63787 Mdot
.67807 .70602 Mdot
.42528 .32861 Mdot
.7085 .77352 Mdot
.80016 .45892 Mdot
.61088 .45836 Mdot
.59226 .65087 Mdot
.56608 .81867 Mdot
.36786 .79901 Mdot
.34167 .51256 Mdot
.36344 .54863 Mdot
.5593 .6499 Mdot
.57191 .45111 Mdot
.76306 .502 Mdot
.60545 .50248 Mdot
.36306 .47014 Mdot
.67096 .27859 Mdot
.43509 .29579 Mdot
.37093 .49514 Mdot
.7814 .51154 Mdot
.6096 .4427 Mdot
.592 .44329 Mdot
.73655 .58812 Mdot
.44881 .37612 Mdot
.3982 .64647 Mdot
.66326 .42465 Mdot
.62551 .45737 Mdot
.59507 .40506 Mdot
.55316 .48557 Mdot
.52892 .2304 Mdot
.6068 .49227 Mdot
.3852 .74338 Mdot
.57609 .4351 Mdot
.60586 .4349 Mdot
.42444 .37669 Mdot
.1471 .47079 Mdot
.32235 .61081 Mdot
.62298 .4543 Mdot
.66311 .46929 Mdot
.36978 .49494 Mdot
.41287 .43443 Mdot
.3999 .41948 Mdot
.41164 .40943 Mdot
.76401 .39959 Mdot
.59795 .52143 Mdot
.45253 .31972 Mdot
.60277 .64929 Mdot
.66595 .47241 Mdot
.45146 .31499 Mdot
.58093 .50361 Mdot
.39842 .6377 Mdot
.41215 .61163 Mdot
.65963 .54138 Mdot
.59332 .64357 Mdot
.37677 .25926 Mdot
.31883 .37865 Mdot
.4196 .61131 Mdot
.59864 .47112 Mdot
.29669 .52653 Mdot
.4243 .67078 Mdot
.41121 .56959 Mdot
.6347 .66731 Mdot
.42313 .35614 Mdot
.44306 .35935 Mdot
.65324 .62819 Mdot
.2829 .60251 Mdot
.33554 .24364 Mdot
.35972 .47663 Mdot
.67273 .42588 Mdot
.35084 .34829 Mdot
.4433 .36287 Mdot
.68641 .65111 Mdot
.59355 .64906 Mdot
.34622 .50877 Mdot
.37478 .68979 Mdot
.42373 .31139 Mdot
.40971 .30335 Mdot
.56055 .46939 Mdot
.63596 .45843 Mdot
.7519 .36659 Mdot
.53901 .66943 Mdot
.35232 .52274 Mdot
.56868 .64156 Mdot
.43118 .59938 Mdot
.61944 .49991 Mdot
.41255 .33824 Mdot
.53889 .79383 Mdot
.66996 .46208 Mdot
.40927 .65695 Mdot
.45043 .3581 Mdot
.55748 .6607 Mdot
.60629 .6534 Mdot
.64843 .43034 Mdot
.71477 .33483 Mdot
.34122 .47717 Mdot
.46194 .3449 Mdot
.33881 .43295 Mdot
.59784 .50149 Mdot
.63379 .46642 Mdot
.61622 .5387 Mdot
.35094 .52348 Mdot
.28375 .43291 Mdot
.6058 .67835 Mdot
.45168 .33208 Mdot
.61019 .49039 Mdot
.57909 .63588 Mdot
.33371 .37993 Mdot
.45536 .61407 Mdot
.45541 .65098 Mdot
.60355 .64524 Mdot
.58553 .65978 Mdot
.60601 .67218 Mdot
.71076 .77254 Mdot
.47334 .35599 Mdot
.49363 .3628 Mdot
.63942 .51021 Mdot
.68328 .61068 Mdot
.68237 .4413 Mdot
.31248 .51088 Mdot
.43949 .65821 Mdot
.57615 .47122 Mdot
.65857 .44196 Mdot
.57411 .53188 Mdot
.29839 .28855 Mdot
.50577 .38483 Mdot
.423 .29946 Mdot
.61309 .39648 Mdot
.45182 .63659 Mdot
.69722 .79813 Mdot
.81947 .46658 Mdot
.62432 .39559 Mdot
.45748 .43383 Mdot
.41264 .34616 Mdot
.37269 .4805 Mdot
.72986 .62759 Mdot
.35977 .50093 Mdot
.45275 .33684 Mdot
.60965 .49536 Mdot
.3121 .39539 Mdot
.57117 .62191 Mdot
.62943 .42522 Mdot
.3648 .47648 Mdot
.61522 .41974 Mdot
.3498 .52331 Mdot
.74084 .66604 Mdot
.77394 .33765 Mdot
.6122 .4519 Mdot
.67799 .47327 Mdot
.76189 .35965 Mdot
.63893 .44074 Mdot
.57558 .61325 Mdot
.41258 .34675 Mdot
.67791 .27893 Mdot
.64608 .51453 Mdot
.72952 .42195 Mdot
.60362 .50421 Mdot
.64731 .24796 Mdot
.63704 .46533 Mdot
.45751 .71594 Mdot
.63845 .49179 Mdot
.59588 .41888 Mdot
.32481 .50412 Mdot
.36988 .49729 Mdot
.40436 .35609 Mdot
.411 .67382 Mdot
.74792 .69442 Mdot
.62962 .46325 Mdot
.29656 .5604 Mdot
.26172 .43346 Mdot
.58303 .66053 Mdot
.44922 .33267 Mdot
.37997 .82598 Mdot
.35508 .45581 Mdot
.79617 .41337 Mdot
.74445 .38673 Mdot
.26826 .37256 Mdot
.63931 .71925 Mdot
.24075 .60709 Mdot
.56082 .66707 Mdot
.57249 .49581 Mdot
.56424 .75246 Mdot
.44732 .72058 Mdot
.63085 .64512 Mdot
.32225 .46476 Mdot
.69278 .33862 Mdot
.61149 .75056 Mdot
.60336 .63648 Mdot
.55384 .65833 Mdot
.34183 .52149 Mdot
.46552 .60096 Mdot
.54189 .42829 Mdot
.59364 .65812 Mdot
.38855 .64227 Mdot
.42439 .6074 Mdot
.38528 .63962 Mdot
.41924 .34401 Mdot
.80944 .45261 Mdot
.37367 .45 Mdot
.31876 .51482 Mdot
.49244 .62664 Mdot
.65965 .37262 Mdot
.45526 .2962 Mdot
.44028 .63344 Mdot
.45849 .6588 Mdot
.41011 .34573 Mdot
.55334 .45146 Mdot
.54972 .43766 Mdot
.61988 .44982 Mdot
.56979 .65478 Mdot
.64072 .46057 Mdot
.40152 .62775 Mdot
.33586 .51141 Mdot
.45405 .66062 Mdot
.32137 .52646 Mdot
.52001 .80658 Mdot
.64781 .4377 Mdot
.63415 .49095 Mdot
.21923 .34979 Mdot
.39969 .31493 Mdot
.45473 .8005 Mdot
.28865 .47775 Mdot
.42102 .64811 Mdot
.59053 .42496 Mdot
.4675 .31936 Mdot
.54101 .65707 Mdot
.16324 .45662 Mdot
.58034 .48957 Mdot
.41878 .32502 Mdot
.61853 .49814 Mdot
.70388 .51768 Mdot
.38888 .21422 Mdot
.43283 .32941 Mdot
.30965 .26656 Mdot
.65936 .47475 Mdot
.27053 .68182 Mdot
.56841 .44463 Mdot
.6463 .56785 Mdot
.5854 .49881 Mdot
.46161 .36443 Mdot
.62354 .44947 Mdot
.46625 .31912 Mdot
.43532 .61338 Mdot
.36992 .48894 Mdot
.43648 .36319 Mdot
.65241 .42379 Mdot
.48959 .07015 Mdot
.35822 .48551 Mdot
.61636 .4687 Mdot
.34759 .51609 Mdot
.44624 .32259 Mdot
.45565 .36467 Mdot
.35982 .78368 Mdot
.30491 .59977 Mdot
.35714 .47924 Mdot
.61934 .49941 Mdot
.30203 .69869 Mdot
.58959 .4833 Mdot
.74903 .48107 Mdot
.55899 .4329 Mdot
.61552 .51118 Mdot
.39833 .7925 Mdot
.32187 .51828 Mdot
.33531 .24141 Mdot
.38784 .79881 Mdot
.43092 .79937 Mdot
.39491 .31134 Mdot
.59961 .633 Mdot
.7693 .69981 Mdot
.27747 .54552 Mdot
.39642 .63135 Mdot
.57459 .46498 Mdot
.39455 .28386 Mdot
.33647 .47926 Mdot
.56991 .66841 Mdot
.61256 .45312 Mdot
.46003 .65133 Mdot
.61915 .21478 Mdot
.30492 .51177 Mdot
.43077 .32542 Mdot
.45723 .381 Mdot
.1968 .63916 Mdot
.60755 .48033 Mdot
.64011 .48596 Mdot
.36042 .46645 Mdot
.22325 .57302 Mdot
.57742 .68414 Mdot
.69607 .28629 Mdot
.35557 .48124 Mdot
.46843 .50942 Mdot
.45608 .31781 Mdot
.57876 .44587 Mdot
.63149 .79235 Mdot
.37397 .6973 Mdot
.24038 .3306 Mdot
.56984 .65195 Mdot
.74798 .48561 Mdot
.4625 .36247 Mdot
.34272 .50102 Mdot
.26056 .57637 Mdot
.60588 .52547 Mdot
.59797 .42924 Mdot
.72493 .51701 Mdot
.36069 .5554 Mdot
.4578 .40901 Mdot
.58555 .49356 Mdot
.50055 .58202 Mdot
.57426 .48225 Mdot
.66141 .51 Mdot
.57501 .41158 Mdot
.63382 .47585 Mdot
.41398 .33252 Mdot
.70833 .41503 Mdot
.39401 .65364 Mdot
.48657 .34595 Mdot
.46569 .51742 Mdot
.60868 .4657 Mdot
.62593 .50567 Mdot
.55074 .37595 Mdot
.27462 .63577 Mdot
.43685 .3609 Mdot
.4145 .28723 Mdot
.36519 .45631 Mdot
.54965 .44848 Mdot
.41555 .67443 Mdot
.6906 .45788 Mdot
.40457 .64612 Mdot
.41361 .33642 Mdot
.42484 .64818 Mdot
.36105 .50551 Mdot
.45613 .62743 Mdot
.27901 .54944 Mdot
.35378 .49627 Mdot
.42719 .36029 Mdot
.64528 .47575 Mdot
.32044 .52439 Mdot
.71068 .56624 Mdot
.57096 .65275 Mdot
.46488 .85137 Mdot
.64802 .47796 Mdot
.2483 .41936 Mdot
.53563 .41907 Mdot
.45616 .66013 Mdot
.3775 .21671 Mdot
.42005 .36481 Mdot
.55989 .6802 Mdot
.4413 .37766 Mdot
.77377 .50639 Mdot
.58167 .65257 Mdot
.45083 .83123 Mdot
.52581 .60088 Mdot
.75509 .52847 Mdot
.55005 .4663 Mdot
.73997 .56769 Mdot
.42495 .60314 Mdot
.3344 .48208 Mdot
.26822 .59336 Mdot
.59539 .42113 Mdot
.69114 .24582 Mdot
.43648 .38046 Mdot
.40558 .67067 Mdot
.33659 .50382 Mdot
.31024 .50522 Mdot
.65594 .49318 Mdot
.50778 .71547 Mdot
.59934 .42607 Mdot
.28348 .5895 Mdot
.76632 .42145 Mdot
.48574 .3167 Mdot
.61309 .47211 Mdot
.42586 .61212 Mdot
.61825 .49809 Mdot
.60544 .68189 Mdot
.81021 .40377 Mdot
.68734 .48895 Mdot
.27918 .47563 Mdot
.53429 .65067 Mdot
.46122 .33447 Mdot
.52489 .46334 Mdot
.27317 .50331 Mdot
.60644 .48278 Mdot
.14124 .39917 Mdot
.57466 .63926 Mdot
.56405 .74908 Mdot
.66644 .44803 Mdot
.66751 .47332 Mdot
.44257 .54364 Mdot
.23797 .40315 Mdot
.3927 .71992 Mdot
.63028 .43619 Mdot
.69716 .5532 Mdot
.33169 .5218 Mdot
.56925 .46048 Mdot
.62061 .46759 Mdot
.52392 .29979 Mdot
.30883 .51168 Mdot
.4196 .65646 Mdot
.40641 .60921 Mdot
.47391 .62864 Mdot
.59844 .68866 Mdot
.36638 .42279 Mdot
.69471 .6271 Mdot
.55393 .18386 Mdot
.54925 .65833 Mdot
.65831 .44455 Mdot
.55073 .69905 Mdot
.60958 .499 Mdot
.57584 .66924 Mdot
.30802 .51188 Mdot
.44088 .36572 Mdot
.35301 .36478 Mdot
.40552 .61322 Mdot
.60254 .52687 Mdot
.58022 .6864 Mdot
.42409 .35463 Mdot
.70542 .66657 Mdot
.45949 .33283 Mdot
.34687 .4836 Mdot
.35875 .42289 Mdot
.57263 .67075 Mdot
.44298 .31758 Mdot
.29588 .45359 Mdot
.34938 .78796 Mdot
.57495 .40786 Mdot
.33798 .41208 Mdot
.46632 .34176 Mdot
.42413 .28362 Mdot
.46969 .3399 Mdot
.62296 .41946 Mdot
.45895 .43457 Mdot
.60303 .51322 Mdot
.32413 .51986 Mdot
.43104 .65785 Mdot
.7441 .31559 Mdot
.34947 .61619 Mdot
.49549 .43814 Mdot
.65448 .40939 Mdot
.61044 .44142 Mdot
.61838 .47235 Mdot
.65846 .50941 Mdot
.26413 .53805 Mdot
.6112 .4255 Mdot
.32411 .50339 Mdot
.40942 .62512 Mdot
.5734 .49732 Mdot
.4258 .69128 Mdot
.41838 .78601 Mdot
.56137 .63971 Mdot
.3732 .51895 Mdot
.83062 .44391 Mdot
.42675 .35604 Mdot
.46653 .6276 Mdot
.41007 .61815 Mdot
.57511 .67859 Mdot
.34506 .47183 Mdot
.45839 .33027 Mdot
.74442 .48324 Mdot
.59542 .68125 Mdot
.62453 .45253 Mdot
.45914 .42372 Mdot
.72556 .27363 Mdot
.57083 .49143 Mdot
.58093 .46169 Mdot
.3841 .63677 Mdot
.5739 .74192 Mdot
.62958 .16384 Mdot
.71055 .62525 Mdot
.56993 .6643 Mdot
.58633 .62692 Mdot
.40603 .33675 Mdot
.64271 .51369 Mdot
.33615 .5248 Mdot
.37123 .35084 Mdot
.28334 .44581 Mdot
.35193 .27892 Mdot
.22375 .36914 Mdot
.57538 .47917 Mdot
.20864 .57033 Mdot
.60577 .44281 Mdot
.47295 .35703 Mdot
.41669 .33411 Mdot
.43215 .34478 Mdot
.33516 .48215 Mdot
.61482 .31929 Mdot
.32415 .4928 Mdot
.83328 .3881 Mdot
.46178 .35806 Mdot
.5211 .60335 Mdot
.44668 .6358 Mdot
.58023 .39862 Mdot
.55884 .65399 Mdot
.34315 .41823 Mdot
.64451 .54014 Mdot
.47006 .23842 Mdot
.39795 .66484 Mdot
.43008 .36314 Mdot
.23068 .58431 Mdot
.81674 .55741 Mdot
.40622 .4154 Mdot
.58474 .53945 Mdot
.73016 .62963 Mdot
.58057 .66348 Mdot
.23796 .33359 Mdot
.56318 .64608 Mdot
.36505 .47745 Mdot
.62797 .4912 Mdot
.63633 .48221 Mdot
.57335 .4819 Mdot
.64576 .4415 Mdot
.35263 .44818 Mdot
.63735 .40956 Mdot
.43129 .21278 Mdot
.40103 .61832 Mdot
.59838 .58782 Mdot
.56496 .64675 Mdot
.30584 .48591 Mdot
.40826 .62511 Mdot
.27388 .62943 Mdot
.72041 .57762 Mdot
.61147 .47491 Mdot
.57544 .46969 Mdot
.7893 .38889 Mdot
.58686 .49417 Mdot
.5735 .39657 Mdot
.3978 .62905 Mdot
.51157 .42292 Mdot
.56098 .64125 Mdot
.57947 .62558 Mdot
.35441 .49794 Mdot
.41505 .3324 Mdot
.57964 .64039 Mdot
.44716 .63947 Mdot
.65178 .40803 Mdot
.64788 .41438 Mdot
.46618 .34412 Mdot
.79817 .39096 Mdot
.6091 .67305 Mdot
.29157 .69156 Mdot
.42214 .36046 Mdot
.40693 .36658 Mdot
.59669 .42992 Mdot
.26135 .31374 Mdot
.40027 .2907 Mdot
.56717 .68824 Mdot
.3086 .48095 Mdot
.73828 .60816 Mdot
.33853 .46232 Mdot
.43043 .32318 Mdot
.65192 .48992 Mdot
.41651 .34586 Mdot
.60808 .47642 Mdot
.83277 .56498 Mdot
.63733 .4769 Mdot
.53527 .18115 Mdot
.64457 .61482 Mdot
.43492 .62015 Mdot
.26421 .62864 Mdot
.44674 .6279 Mdot
.43248 .37009 Mdot
.67177 .4603 Mdot
.56234 .67534 Mdot
.37964 .76217 Mdot
.37791 .31315 Mdot
.42584 .66846 Mdot
.41077 .67847 Mdot
.33436 .46285 Mdot
.58238 .498 Mdot
.60226 .42748 Mdot
.4196 .62769 Mdot
.44556 .26736 Mdot
.43004 .31076 Mdot
.61822 .48891 Mdot
.61086 .43774 Mdot
.43852 .62254 Mdot
.33286 .77778 Mdot
.71497 .43777 Mdot
.62744 .48609 Mdot
.37334 .71076 Mdot
.31316 .51029 Mdot
.57512 .40309 Mdot
.67884 .46463 Mdot
.58815 .66037 Mdot
.57157 .23574 Mdot
.79691 .49557 Mdot
.30672 .51107 Mdot
.40596 .61852 Mdot
.60862 .48524 Mdot
.42209 .6121 Mdot
.64267 .41115 Mdot
.24339 .39184 Mdot
.45926 .62068 Mdot
.62222 .50866 Mdot
.55356 .46357 Mdot
.45108 .37591 Mdot
.57525 .47519 Mdot
.6026 .35767 Mdot
.40706 .66158 Mdot
.65664 .49091 Mdot
.70311 .31658 Mdot
.33947 .46892 Mdot
.54936 .47641 Mdot
.59946 .67448 Mdot
.75023 .46906 Mdot
.29977 .38447 Mdot
.64363 .74016 Mdot
.57809 .62431 Mdot
.61533 .42067 Mdot
.4065 .67563 Mdot
.35578 .51987 Mdot
.50171 .17856 Mdot
.57449 .44751 Mdot
.3636 .47311 Mdot
.33715 .51105 Mdot
.56688 .66785 Mdot
.14347 .49003 Mdot
.66241 .44258 Mdot
.64245 .44822 Mdot
.56423 .33211 Mdot
.41155 .29888 Mdot
.64202 .46789 Mdot
.65785 .4636 Mdot
.32457 .50737 Mdot
.53979 .4708 Mdot
.6987 .36138 Mdot
.67303 .26527 Mdot
.37936 .49047 Mdot
.35606 .31291 Mdot
.44744 .61217 Mdot
.58479 .63274 Mdot
.45455 .34975 Mdot
.57426 .68442 Mdot
.45301 .64565 Mdot
.65568 .46632 Mdot
.36944 .47129 Mdot
.56769 .36134 Mdot
.34316 .52129 Mdot
.61872 .73183 Mdot
.45642 .30991 Mdot
.40012 .48826 Mdot
.13517 .42845 Mdot
.32598 .67859 Mdot
.34999 .55959 Mdot
.5834 .66023 Mdot
.38978 .58592 Mdot
.60973 .4386 Mdot
.22882 .34355 Mdot
.65715 .44508 Mdot
.68953 .30022 Mdot
.39601 .62485 Mdot
.38846 .63489 Mdot
.62672 .48915 Mdot
.76467 .42547 Mdot
.35874 .51806 Mdot
.31201 .49811 Mdot
.63487 .50754 Mdot
.34706 .47978 Mdot
.63653 .45415 Mdot
.40158 .63219 Mdot
.27386 .27002 Mdot
.61693 .45285 Mdot
.67932 .49353 Mdot
.25142 .39164 Mdot
.40076 .79902 Mdot
.52429 .65879 Mdot
.23301 .69503 Mdot
.82392 .52915 Mdot
.3451 .48104 Mdot
.62161 .51471 Mdot
.35479 .30666 Mdot
.38178 .65067 Mdot
.29711 .44888 Mdot
.65118 .46586 Mdot
.65655 .45287 Mdot
.5929 .4197 Mdot
.5889 .44803 Mdot
.1791 .43998 Mdot
.37476 .31708 Mdot
.58875 .27148 Mdot
.57918 .48175 Mdot
.72995 .55944 Mdot
.36263 .48864 Mdot
.41802 .38648 Mdot
.55082 .67291 Mdot
.57505 .47769 Mdot
.48304 .36853 Mdot
.37376 .4689 Mdot
.8308 .37154 Mdot
.36612 .47219 Mdot
.41537 .65096 Mdot
.36341 .50731 Mdot
.60022 .4546 Mdot
.44757 .33964 Mdot
.42224 .49158 Mdot
.32473 .63679 Mdot
.3945 .63446 Mdot
.60649 .46163 Mdot
.50974 .61137 Mdot
.39393 .65611 Mdot
.44445 .80561 Mdot
.44919 .34782 Mdot
.68556 .56119 Mdot
.41544 .34088 Mdot
.64351 .5024 Mdot
.6443 .50088 Mdot
.37864 .46168 Mdot
.36336 .5043 Mdot
.41522 .33878 Mdot
.13391 .53217 Mdot
.6073 .67278 Mdot
.43068 .3411 Mdot
.61619 .52874 Mdot
.44135 .45073 Mdot
.4442 .34199 Mdot
.59405 .61154 Mdot
.33129 .51106 Mdot
.40007 .32725 Mdot
.57795 .4304 Mdot
.76575 .56699 Mdot
.59993 .64067 Mdot
.41698 .5991 Mdot
.68699 .67229 Mdot
.41444 .6677 Mdot
.31722 .47124 Mdot
.44564 .62591 Mdot
.3241 .51651 Mdot
.28449 .40685 Mdot
.48289 .32467 Mdot
.40353 .55969 Mdot
.34232 .45366 Mdot
.44482 .62872 Mdot
.62475 .4943 Mdot
.53113 .67717 Mdot
.65789 .49984 Mdot
.63288 .41527 Mdot
.31628 .50508 Mdot
.45223 .37197 Mdot
.40353 .2908 Mdot
.75309 .5157 Mdot
.41445 .32527 Mdot
.41171 .65975 Mdot
.46968 .22488 Mdot
.31932 .57143 Mdot
.33375 .46694 Mdot
.36919 .49314 Mdot
.60192 .49887 Mdot
.42846 .63094 Mdot
.39246 .63473 Mdot
.3417 .4599 Mdot
.28488 .31101 Mdot
.67648 .48556 Mdot
.42582 .28119 Mdot
.40796 .30359 Mdot
.43557 .33203 Mdot
.46941 .33387 Mdot
.71496 .40664 Mdot
.34969 .50878 Mdot
.44547 .37412 Mdot
.60025 .49912 Mdot
.65487 .45892 Mdot
.36613 .34586 Mdot
.59768 .64235 Mdot
.57615 .50195 Mdot
.57102 .41509 Mdot
.58049 .444 Mdot
.458 .645 Mdot
.65274 .38125 Mdot
.46297 .63419 Mdot
.39305 .6673 Mdot
.38781 .66168 Mdot
.27754 .54393 Mdot
.78447 .40851 Mdot
.7885 .59496 Mdot
.66139 .47808 Mdot
.22419 .61104 Mdot
.43224 .64029 Mdot
.43833 .22665 Mdot
.27698 .43858 Mdot
.58871 .42776 Mdot
.41169 .74223 Mdot
.42386 .62526 Mdot
.41321 .35277 Mdot
.64616 .47122 Mdot
.47377 .63943 Mdot
.60234 .66997 Mdot
.65577 .4962 Mdot
.45205 .61116 Mdot
.44613 .31885 Mdot
.57955 .69404 Mdot
.39732 .32329 Mdot
.38725 .66142 Mdot
.55801 .50922 Mdot
.40611 .16285 Mdot
.47347 .6611 Mdot
.28164 .7085 Mdot
.56037 .54292 Mdot
.62032 .49167 Mdot
.4692 .64444 Mdot
.39572 .35168 Mdot
.31511 .47419 Mdot
.50965 .53583 Mdot
.4086 .31398 Mdot
.3884 .63491 Mdot
.43633 .67021 Mdot
.39451 .63405 Mdot
.42076 .29891 Mdot
.58012 .51029 Mdot
.41791 .30863 Mdot
.3611 .51099 Mdot
.58824 .4753 Mdot
.76309 .65181 Mdot
.22111 .56178 Mdot
.41888 .35681 Mdot
.42626 .66215 Mdot
.57173 .62257 Mdot
.60849 .4473 Mdot
.21864 .57537 Mdot
.62149 .4957 Mdot
.31752 .51211 Mdot
.53692 .24378 Mdot
.51123 .38952 Mdot
.61922 .51215 Mdot
.59879 .49554 Mdot
.31302 .49594 Mdot
.61014 .45961 Mdot
.58462 .49862 Mdot
.27676 .54834 Mdot
.42609 .30203 Mdot
.62126 .44588 Mdot
.43798 .65359 Mdot
.3178 .58865 Mdot
.67795 .48862 Mdot
.38548 .57565 Mdot
.68225 .55899 Mdot
.53099 .2553 Mdot
.65776 .44692 Mdot
.47611 .41207 Mdot
.59349 .43803 Mdot
.63613 .42876 Mdot
.60249 .49464 Mdot
.17352 .50126 Mdot
.45249 .61261 Mdot
.41776 .61564 Mdot
.5913 .62948 Mdot
.68114 .56024 Mdot
.59222 .65568 Mdot
.33425 .51359 Mdot
.5199 .72623 Mdot
.46281 .63195 Mdot
.43494 .31916 Mdot
.62355 .42426 Mdot
.47194 .66247 Mdot
.58377 .43792 Mdot
.59983 .45677 Mdot
.42238 .6757 Mdot
.44499 .60836 Mdot
.60076 .74836 Mdot
.60204 .65155 Mdot
.43304 .35025 Mdot
.58877 .50564 Mdot
.58876 .68523 Mdot
.66094 .44725 Mdot
.68262 .61295 Mdot
.43469 .34709 Mdot
.42382 .30383 Mdot
.40359 .28933 Mdot
.65343 .47064 Mdot
.60412 .45189 Mdot
.32332 .49311 Mdot
.42557 .36746 Mdot
.34383 .46667 Mdot
.50404 .55048 Mdot
.46479 .78074 Mdot
.65146 .46549 Mdot
.36638 .41215 Mdot
.59751 .65673 Mdot
.43011 .6678 Mdot
.7398 .28975 Mdot
.59177 .62976 Mdot
.60962 .47923 Mdot
.39964 .66941 Mdot
.58339 .67317 Mdot
.6961 .53251 Mdot
.82081 .38969 Mdot
.56331 .63049 Mdot
.59963 .4987 Mdot
.54309 .4822 Mdot
.22201 .67954 Mdot
.57012 .6275 Mdot
.36314 .49856 Mdot
.65226 .47248 Mdot
.44244 .28117 Mdot
.57772 .68637 Mdot
.37228 .72718 Mdot
.41722 .62297 Mdot
.77107 .54929 Mdot
.66967 .51945 Mdot
.42597 .25391 Mdot
.5856 .62879 Mdot
.45611 .33444 Mdot
.57117 .39521 Mdot
.59508 .43207 Mdot
.5756 .624 Mdot
.30422 .47652 Mdot
.40734 .63481 Mdot
.31642 .60736 Mdot
.41925 .29915 Mdot
.30897 .46746 Mdot
.43563 .6632 Mdot
.29977 .69996 Mdot
.5987 .21825 Mdot
.55179 .43075 Mdot
.2089 .63585 Mdot
.25432 .48567 Mdot
.56408 .46056 Mdot
.54414 .65315 Mdot
.3164 .52313 Mdot
.3679 .46245 Mdot
.34986 .48454 Mdot
.27124 .42355 Mdot
.41371 .41049 Mdot
.45689 .61294 Mdot
.36048 .4299 Mdot
.58654 .63387 Mdot
.74093 .59536 Mdot
.63579 .41446 Mdot
.61264 .44305 Mdot
.59624 .50559 Mdot
.57266 .47481 Mdot
.60477 .43194 Mdot
.35114 .47168 Mdot
.27297 .40707 Mdot
.39349 .40673 Mdot
.4393 .34388 Mdot
.57125 .73422 Mdot
.44361 .64094 Mdot
.42517 .5941 Mdot
.59074 .67579 Mdot
.3401 .7009 Mdot
.42892 .69098 Mdot
.42341 .64915 Mdot
.56157 .48283 Mdot
.42434 .31025 Mdot
.58136 .39607 Mdot
.59919 .49705 Mdot
.40872 .6546 Mdot
.45903 .54378 Mdot
.67882 .36349 Mdot
.6258 .69265 Mdot
.58298 .69873 Mdot
.43097 .42713 Mdot
.58813 .6245 Mdot
.67218 .43914 Mdot
.38951 .21774 Mdot
.45376 .6449 Mdot
.41732 .63952 Mdot
.59755 .64544 Mdot
.26332 .30831 Mdot
.45487 .35546 Mdot
.39286 .45475 Mdot
.33998 .51873 Mdot
.64859 .49439 Mdot
.64658 .22946 Mdot
.54678 .53491 Mdot
.49705 .71918 Mdot
.35599 .48363 Mdot
.43808 .61465 Mdot
.67803 .44194 Mdot
.59083 .48987 Mdot
.59669 .66298 Mdot
.62599 .76207 Mdot
.58797 .39981 Mdot
.54705 .84064 Mdot
.77407 .33701 Mdot
.78693 .49008 Mdot
.5991 .42884 Mdot
.42345 .30136 Mdot
.41459 .60248 Mdot
.5733 .63619 Mdot
.60287 .52602 Mdot
.81157 .48611 Mdot
.46487 .34486 Mdot
.35122 .49537 Mdot
.45029 .51016 Mdot
.72894 .61668 Mdot
.63448 .42027 Mdot
.65709 .45761 Mdot
.63887 .42728 Mdot
.76385 .25875 Mdot
.46107 .63678 Mdot
.41521 .35277 Mdot
.56871 .66984 Mdot
.41961 .32135 Mdot
.43394 .61691 Mdot
.42569 .5606 Mdot
.6332 .49466 Mdot
.4652 .33515 Mdot
.45641 .33673 Mdot
.36238 .46219 Mdot
.30292 .50192 Mdot
.47083 .52522 Mdot
.63694 .47558 Mdot
.43842 .68044 Mdot
.44783 .37517 Mdot
.4548 .42142 Mdot
.58367 .65285 Mdot
.32925 .5113 Mdot
.57701 .47751 Mdot
.45983 .62866 Mdot
.56661 .42775 Mdot
.44089 .36024 Mdot
.42375 .64839 Mdot
.53235 .7938 Mdot
.56511 .6347 Mdot
.6514 .45528 Mdot
.56418 .61072 Mdot
.40282 .62189 Mdot
.60684 .4378 Mdot
.31778 .72783 Mdot
.59476 .61238 Mdot
.3431 .6653 Mdot
.38918 .65659 Mdot
.29023 .54378 Mdot
.4054 .33243 Mdot
.23707 .4603 Mdot
.4146 .6445 Mdot
.27001 .66893 Mdot
.56865 .78083 Mdot
.66101 .41305 Mdot
.42556 .32999 Mdot
.25053 .49576 Mdot
.79644 .64758 Mdot
.28057 .72207 Mdot
.61735 .46858 Mdot
.45437 .66835 Mdot
.59048 .6706 Mdot
.3281 .47204 Mdot
.355 .65086 Mdot
.61471 .68512 Mdot
.39439 .67998 Mdot
.60266 .49421 Mdot
.45224 .32654 Mdot
.32809 .49896 Mdot
.29998 .3892 Mdot
.44459 .64529 Mdot
.43173 .65972 Mdot
.67144 .47263 Mdot
.59364 .64801 Mdot
.22052 .51373 Mdot
.39919 .63229 Mdot
.78005 .36599 Mdot
.44145 .59348 Mdot
.59816 .68141 Mdot
.58487 .44794 Mdot
.76263 .50624 Mdot
.63558 .51689 Mdot
.34708 .75846 Mdot
.44404 .63635 Mdot
.43789 .35455 Mdot
.61234 .41671 Mdot
.7217 .32184 Mdot
.41353 .66064 Mdot
.45015 .43145 Mdot
.48036 .6946 Mdot
.34312 .5136 Mdot
.73573 .28618 Mdot
.64359 .46031 Mdot
.35588 .51964 Mdot
.59522 .66376 Mdot
.6304 .48162 Mdot
.60163 .45089 Mdot
.4647 .37021 Mdot
.35869 .46018 Mdot
.59526 .75406 Mdot
.37168 .49092 Mdot
.36565 .48678 Mdot
.46795 .31758 Mdot
.63058 .44394 Mdot
.41623 .6529 Mdot
.4236 .62661 Mdot
.57376 .43413 Mdot
.2483 .27746 Mdot
.45848 .35227 Mdot
.40517 .60714 Mdot
.74239 .23488 Mdot
.56191 .45435 Mdot
.72328 .28128 Mdot
.6154 .76427 Mdot
.32875 .52379 Mdot
.59939 .49925 Mdot
.44528 .32028 Mdot
.40923 .71953 Mdot
.42839 .65992 Mdot
.5882 .41973 Mdot
.32959 .49782 Mdot
.60423 .65685 Mdot
.39892 .65591 Mdot
.50639 .71707 Mdot
.64642 .438 Mdot
.42175 .74803 Mdot
.44578 .67114 Mdot
.74739 .71884 Mdot
.26718 .61211 Mdot
.42498 .333 Mdot
.5971 .45787 Mdot
.41773 .36162 Mdot
.57219 .67369 Mdot
.45276 .51176 Mdot
.33075 .50711 Mdot
.65577 .37256 Mdot
.4158 .204 Mdot
.39452 .63359 Mdot
.41705 .35764 Mdot
.6307 .51201 Mdot
.24238 .38499 Mdot
.64121 .45523 Mdot
.55291 .51326 Mdot
.61768 .71881 Mdot
.31808 .4892 Mdot
.33448 .52192 Mdot
.5957 .44506 Mdot
.57508 .68075 Mdot
.44572 .64086 Mdot
.40684 .64363 Mdot
.6736 .79951 Mdot
.40168 .4714 Mdot
.75125 .36931 Mdot
.65587 .45177 Mdot
.3965 .679 Mdot
.34995 .59069 Mdot
.36101 .46775 Mdot
.55802 .49489 Mdot
.41299 .67332 Mdot
.57175 .59793 Mdot
.71749 .51683 Mdot
.59523 .43422 Mdot
.63415 .52068 Mdot
.34735 .51668 Mdot
.44883 .41058 Mdot
.42742 .60996 Mdot
.58012 .41313 Mdot
.4114 .54908 Mdot
.68859 .54057 Mdot
.79321 .34632 Mdot
.43276 .35007 Mdot
.50452 .70172 Mdot
.35045 .47117 Mdot
.68034 .49358 Mdot
.56021 .6608 Mdot
.38208 .66325 Mdot
.46007 .62431 Mdot
.60385 .48573 Mdot
.66753 .42583 Mdot
.76062 .33948 Mdot
.42832 .31564 Mdot
.3593 .49387 Mdot
.64048 .4838 Mdot
.36024 .38636 Mdot
.57488 .48458 Mdot
.32536 .48582 Mdot
.38641 .17084 Mdot
.65005 .50636 Mdot
.64141 .45065 Mdot
.22351 .52101 Mdot
.40879 .3097 Mdot
.43582 .37661 Mdot
.6629 .22782 Mdot
.65563 .45205 Mdot
.76233 .3237 Mdot
.43257 .35573 Mdot
.45117 .36039 Mdot
.28327 .57454 Mdot
.61124 .44669 Mdot
.70681 .44801 Mdot
.32327 .51843 Mdot
.36628 .48803 Mdot
.41683 .30542 Mdot
.57964 .40147 Mdot
.30509 .50125 Mdot
.19189 .48751 Mdot
.4304 .63118 Mdot
.35153 .22341 Mdot
.46037 .35165 Mdot
.34943 .54372 Mdot
.36147 .4758 Mdot
.83301 .41115 Mdot
.39578 .70136 Mdot
.62884 .49402 Mdot
.6533 .44823 Mdot
.59427 .64124 Mdot
.60197 .50961 Mdot
.38874 .63452 Mdot
.34792 .47936 Mdot
.73874 .40113 Mdot
.4316 .3445 Mdot
.63597 .46733 Mdot
.37401 .74793 Mdot
.48335 .81441 Mdot
.51514 .68996 Mdot
.4608 .33703 Mdot
.41933 .34027 Mdot
.45179 .62474 Mdot
.45079 .67051 Mdot
.62147 .43325 Mdot
.31262 .49011 Mdot
.42376 .36566 Mdot
.32055 .49089 Mdot
.45286 .64727 Mdot
.4184 .65166 Mdot
.43862 .60319 Mdot
.63893 .41393 Mdot
.42845 .65337 Mdot
.49113 .7893 Mdot
.34059 .44007 Mdot
.45846 .29985 Mdot
.72574 .25503 Mdot
.30402 .39161 Mdot
.38496 .31559 Mdot
.58771 .68818 Mdot
.3967 .62895 Mdot
.36365 .51034 Mdot
.58482 .46588 Mdot
.57284 .46192 Mdot
.31233 .55996 Mdot
.37239 .50146 Mdot
.57089 .67092 Mdot
.34892 .52155 Mdot
.56714 .66862 Mdot
.44226 .73755 Mdot
.57689 .49428 Mdot
.64241 .40967 Mdot
.3543 .4746 Mdot
.4264 .65112 Mdot
.41695 .61907 Mdot
.56034 .63511 Mdot
.47623 .56171 Mdot
.39499 .65886 Mdot
.45169 .3637 Mdot
.70122 .38293 Mdot
.44719 .66729 Mdot
.64479 .4704 Mdot
.69031 .63195 Mdot
.22178 .34938 Mdot
.65789 .50977 Mdot
.27925 .56403 Mdot
.54334 .35719 Mdot
.60235 .42059 Mdot
.22563 .34037 Mdot
.2851 .51186 Mdot
.4078 .32449 Mdot
.40272 .61787 Mdot
.49147 .64168 Mdot
.68413 .41115 Mdot
.5725 .69357 Mdot
.57182 .51535 Mdot
.46334 .33213 Mdot
.4527 .38395 Mdot
.76393 .5265 Mdot
.30518 .73633 Mdot
.58544 .67157 Mdot
.59309 .67276 Mdot
.41275 .64562 Mdot
.46308 .85446 Mdot
.57203 .53133 Mdot
.57043 .66829 Mdot
.43253 .26353 Mdot
.60225 .49127 Mdot
.63961 .57617 Mdot
.51624 .4981 Mdot
.41807 .30267 Mdot
.73543 .55119 Mdot
.41568 .65869 Mdot
.41327 .32537 Mdot
.34775 .35909 Mdot
.58329 .50988 Mdot
.43431 .34559 Mdot
.32108 .49324 Mdot
.28636 .64007 Mdot
.45284 .36726 Mdot
.6899 .62119 Mdot
.32147 .47316 Mdot
.45031 .42233 Mdot
.74174 .51938 Mdot
.21963 .74435 Mdot
.34894 .47494 Mdot
.43633 .66976 Mdot
.42218 .62677 Mdot
.4074 .64451 Mdot
.42092 .31908 Mdot
.39442 .63141 Mdot
.42874 .31737 Mdot
.22666 .66107 Mdot
.22841 .35994 Mdot
.57055 .66578 Mdot
.31604 .61001 Mdot
.44333 .32573 Mdot
.43138 .22097 Mdot
.19724 .31174 Mdot
.60147 .50129 Mdot
.37182 .46309 Mdot
.57307 .66607 Mdot
.52775 .83861 Mdot
.58627 .66343 Mdot
.79405 .45097 Mdot
.49414 .24504 Mdot
.63352 .46025 Mdot
.65629 .32569 Mdot
.55317 .65583 Mdot
.45492 .31507 Mdot
.60667 .43896 Mdot
.53434 .57512 Mdot
.59112 .66347 Mdot
.60263 .67523 Mdot
.62178 .43844 Mdot
.43008 .36329 Mdot
.42426 .66378 Mdot
.36986 .48698 Mdot
.56609 .68216 Mdot
.53502 .46193 Mdot
.61985 .52037 Mdot
.62463 .49804 Mdot
.37568 .38553 Mdot
.54995 .63965 Mdot
.3441 .48139 Mdot
.1546 .50107 Mdot
.4168 .67738 Mdot
.53852 .59399 Mdot
.78443 .35558 Mdot
.2737 .51081 Mdot
.44274 .63568 Mdot
.42463 .61264 Mdot
.60597 .43074 Mdot
.51888 .47111 Mdot
.47783 .24652 Mdot
.4778 .57569 Mdot
.42623 .59817 Mdot
.40635 .63919 Mdot
.42252 .37053 Mdot
.78103 .49623 Mdot
.62553 .52967 Mdot
.30703 .51266 Mdot
.45543 .61771 Mdot
.2195 .41094 Mdot
.59103 .64077 Mdot
.49597 .2348 Mdot
.57539 .49442 Mdot
.63253 .49178 Mdot
.33476 .49939 Mdot
.32438 .49393 Mdot
.43355 .71646 Mdot
.78775 .47891 Mdot
.54254 .36343 Mdot
.27623 .39062 Mdot
.5322 .26709 Mdot
.4379 .38041 Mdot
.41914 .35715 Mdot
.33012 .6564 Mdot
.3739 .48143 Mdot
.60522 .41859 Mdot
.41465 .33479 Mdot
.52673 .61834 Mdot
.68004 .37971 Mdot
.75603 .46468 Mdot
.73886 .30362 Mdot
.60768 .47272 Mdot
.43324 .30539 Mdot
.4089 .30791 Mdot
.42472 .29009 Mdot
.29506 .54207 Mdot
.63096 .43651 Mdot
.61186 .47036 Mdot
.60624 .42294 Mdot
.25096 .34624 Mdot
.63261 .43108 Mdot
.24237 .44974 Mdot
.45879 .50219 Mdot
.58657 .23276 Mdot
.57911 .41276 Mdot
.34109 .52745 Mdot
.64847 .42852 Mdot
.57424 .67975 Mdot
.6127 .50441 Mdot
.75581 .46212 Mdot
.36042 .4852 Mdot
.71314 .41975 Mdot
.29133 .40384 Mdot
.5806 .43183 Mdot
.56947 .68854 Mdot
.27003 .45779 Mdot
.78836 .63459 Mdot
.53209 .66949 Mdot
.45336 .36211 Mdot
.43558 .63349 Mdot
.36519 .50942 Mdot
.41864 .64586 Mdot
.62277 .40477 Mdot
.32539 .66159 Mdot
.54556 .82435 Mdot
.5065 .56688 Mdot
.57312 .473 Mdot
.62284 .53444 Mdot
.44619 .36432 Mdot
.41192 .67523 Mdot
.39207 .29681 Mdot
.62478 .41922 Mdot
.56885 .65529 Mdot
.5954 .66089 Mdot
.51122 .54331 Mdot
.68097 .75896 Mdot
.20179 .45107 Mdot
.33519 .49528 Mdot
.39923 .63612 Mdot
.55883 .65195 Mdot
.2513 .64704 Mdot
.30307 .52006 Mdot
.31354 .50461 Mdot
.35925 .48978 Mdot
.65705 .47442 Mdot
.45505 .6151 Mdot
.59219 .23398 Mdot
.38564 .66299 Mdot
.60791 .45877 Mdot
.45889 .6455 Mdot
.40505 .66961 Mdot
.56943 .64242 Mdot
.361 .48978 Mdot
.45247 .64269 Mdot
.64803 .49894 Mdot
.42892 .35634 Mdot
.36588 .55882 Mdot
.63282 .61303 Mdot
.31519 .7416 Mdot
.61571 .55972 Mdot
.42097 .29523 Mdot
.78189 .65606 Mdot
.31539 .51443 Mdot
.27534 .32071 Mdot
.60277 .74635 Mdot
.67039 .46178 Mdot
.26197 .26166 Mdot
.41686 .59303 Mdot
.40984 .67023 Mdot
.58662 .44594 Mdot
.44799 .59298 Mdot
.63721 .46267 Mdot
.44619 .65818 Mdot
.37167 .58334 Mdot
.48146 .35833 Mdot
.43099 .6492 Mdot
.58813 .41025 Mdot
.60019 .44716 Mdot
.42111 .30331 Mdot
.46535 .65588 Mdot
.60549 .52769 Mdot
.70176 .78735 Mdot
.32801 .48592 Mdot
.26179 .48886 Mdot
.68127 .6472 Mdot
.34958 .47001 Mdot
.43118 .3386 Mdot
.6362 .41591 Mdot
.59488 .66538 Mdot
.4436 .32433 Mdot
.75148 .44778 Mdot
.56839 .63372 Mdot
.34111 .21991 Mdot
.41179 .30356 Mdot
.42162 .66898 Mdot
.56455 .6725 Mdot
.61015 .51383 Mdot
.38111 .65278 Mdot
.27058 .63716 Mdot
.4417 .63801 Mdot
.60664 .42672 Mdot
.34117 .6264 Mdot
.35992 .49444 Mdot
.61957 .47138 Mdot
.40734 .66718 Mdot
.28256 .5659 Mdot
.66087 .47285 Mdot
.59601 .4403 Mdot
.79212 .36726 Mdot
.49835 .2044 Mdot
.58456 .65765 Mdot
.39658 .31781 Mdot
.60101 .49983 Mdot
.59873 .67717 Mdot
.50118 .76846 Mdot
.64867 .48273 Mdot
.46531 .34564 Mdot
.55536 .49174 Mdot
.46103 .66104 Mdot
.34053 .47044 Mdot
.50099 .58696 Mdot
.60204 .67062 Mdot
.2664 .75786 Mdot
.44853 .61515 Mdot
.65585 .42067 Mdot
.57792 .487 Mdot
.67838 .69718 Mdot
.4093 .32312 Mdot
.48167 .28869 Mdot
.65163 .45481 Mdot
.25999 .33222 Mdot
.62935 .47838 Mdot
.40475 .59465 Mdot
.45449 .35659 Mdot
.64131 .44458 Mdot
.39054 .53189 Mdot
.68064 .48922 Mdot
.59648 .63745 Mdot
.22027 .54869 Mdot
.589 .51523 Mdot
.35948 .19539 Mdot
.54884 .56837 Mdot
.43251 .65049 Mdot
.43023 .78416 Mdot
.68452 .80816 Mdot
.2762 .42157 Mdot
.42125 .32215 Mdot
.59688 .78468 Mdot
.41667 .6532 Mdot
.40484 .75831 Mdot
.7923 .64737 Mdot
.59394 .45286 Mdot
.63242 .41943 Mdot
.72499 .64078 Mdot
.38984 .66573 Mdot
.42155 .68243 Mdot
.64524 .40663 Mdot
.67305 .50187 Mdot
.42354 .65501 Mdot
.66443 .47888 Mdot
.59907 .39965 Mdot
.3711 .46294 Mdot
.46356 .34637 Mdot
.31758 .48808 Mdot
.30671 .49757 Mdot
.19463 .53363 Mdot
.55776 .57521 Mdot
.3284 .48199 Mdot
.3203 .52287 Mdot
.64413 .57283 Mdot
.77226 .44058 Mdot
.57314 .68415 Mdot
.70203 .76075 Mdot
.4084 .63669 Mdot
.63418 .442 Mdot
.40879 .30404 Mdot
.53712 .37219 Mdot
.53289 .77313 Mdot
.40346 .22544 Mdot
.61348 .41772 Mdot
.416 .66201 Mdot
.28952 .53095 Mdot
.57727 .39669 Mdot
.47681 .64271 Mdot
.64438 .47955 Mdot
.38756 .63526 Mdot
.72371 .38171 Mdot
.27011 .66808 Mdot
.48507 .62705 Mdot
.43136 .28223 Mdot
.63458 .4874 Mdot
.46284 .32892 Mdot
.35907 .46799 Mdot
.57126 .68151 Mdot
.58689 .6547 Mdot
.61247 .4373 Mdot
.59663 .54035 Mdot
.44263 .74931 Mdot
.60704 .44698 Mdot
.59879 .48917 Mdot
.28554 .51607 Mdot
.60006 .49381 Mdot
.56845 .47182 Mdot
.58788 .43177 Mdot
.60171 .41378 Mdot
.36562 .48812 Mdot
.34418 .70492 Mdot
.68247 .41492 Mdot
.69043 .43872 Mdot
.31791 .472 Mdot
.6134 .75837 Mdot
.30779 .50635 Mdot
.79846 .62842 Mdot
.33323 .52322 Mdot
.57878 .65248 Mdot
.63368 .72745 Mdot
.66902 .52272 Mdot
.46308 .36602 Mdot
.31592 .53544 Mdot
.57377 .67614 Mdot
.34918 .48211 Mdot
.44421 .66221 Mdot
.79788 .3647 Mdot
.45441 .39002 Mdot
.37067 .3272 Mdot
.28712 .44902 Mdot
.31434 .68063 Mdot
.45407 .62536 Mdot
.45468 .31126 Mdot
.67719 .35425 Mdot
.57157 .4756 Mdot
.59776 .6784 Mdot
.61921 .43385 Mdot
.36671 .46933 Mdot
.41227 .65488 Mdot
.25695 .69449 Mdot
.59685 .6623 Mdot
.75424 .28236 Mdot
.42109 .62015 Mdot
.56868 .45994 Mdot
.30538 .50224 Mdot
.65617 .20316 Mdot
.31655 .49329 Mdot
.49231 .28505 Mdot
.40876 .34333 Mdot
.25037 .71463 Mdot
.43465 .32521 Mdot
.27659 .6558 Mdot
.58605 .1438 Mdot
.36068 .7322 Mdot
.42811 .35965 Mdot
.42953 .56506 Mdot
.60806 .48174 Mdot
.62607 .49783 Mdot
.26164 .67388 Mdot
.40225 .30802 Mdot
.58435 .48819 Mdot
.34136 .57534 Mdot
.30413 .4718 Mdot
.69496 .26439 Mdot
.44563 .62176 Mdot
.64111 .46363 Mdot
.38236 .48842 Mdot
.3713 .50567 Mdot
.41927 .60825 Mdot
.31332 .50738 Mdot
.61213 .46788 Mdot
.44201 .32558 Mdot
.37352 .5903 Mdot
.58215 .64417 Mdot
.48151 .84479 Mdot
.60858 .65381 Mdot
.44285 .63492 Mdot
.65803 .50013 Mdot
.41894 .65115 Mdot
.78991 .74083 Mdot
.61444 .4783 Mdot
.43379 .35618 Mdot
.59336 .48963 Mdot
.63033 .48788 Mdot
.6054 .41489 Mdot
.42865 .66264 Mdot
.62282 .70447 Mdot
.65427 .49278 Mdot
.33171 .50895 Mdot
.5573 .25382 Mdot
.57044 .49988 Mdot
.49196 .61698 Mdot
.75969 .47795 Mdot
.32726 .43096 Mdot
.40107 .33096 Mdot
.43562 .64606 Mdot
.42849 .34553 Mdot
.28742 .28929 Mdot
.43152 .33859 Mdot
.54439 .29604 Mdot
.68971 .35579 Mdot
.73105 .34872 Mdot
.7169 .33687 Mdot
.42869 .51684 Mdot
.39926 .31305 Mdot
.53918 .67302 Mdot
.4282 .36687 Mdot
.41252 .30962 Mdot
.30161 .17821 Mdot
.47046 .34863 Mdot
.64898 .46505 Mdot
.56597 .49152 Mdot
.31111 .69884 Mdot
.67618 .59543 Mdot
.58719 .47669 Mdot
.5827 .47853 Mdot
.5583 .6571 Mdot
.28354 .29886 Mdot
.3438 .67538 Mdot
.48521 .20684 Mdot
.49818 .80965 Mdot
.61991 .43597 Mdot
.60634 .50407 Mdot
.65838 .40291 Mdot
.52934 .16395 Mdot
.19212 .5546 Mdot
.44717 .28076 Mdot
.6738 .41912 Mdot
.35806 .74221 Mdot
.61748 .41579 Mdot
.65811 .46236 Mdot
.60802 .47607 Mdot
.41639 .65365 Mdot
.3983 .32629 Mdot
.59726 .41262 Mdot
.66211 .70714 Mdot
.65437 .46666 Mdot
.27368 .52144 Mdot
.35611 .80598 Mdot
.64409 .45965 Mdot
.41442 .37026 Mdot
.62172 .49881 Mdot
.41348 .31581 Mdot
.43822 .30044 Mdot
.6669 .41545 Mdot
.52868 .26771 Mdot
.41474 .36574 Mdot
.60738 .45821 Mdot
.44035 .66634 Mdot
.74087 .72102 Mdot
.61014 .42641 Mdot
.57614 .68487 Mdot
.6537 .45008 Mdot
.58111 .69275 Mdot
.59519 .48332 Mdot
.44295 .61032 Mdot
.5215 .3647 Mdot
.41555 .64004 Mdot
.20146 .61883 Mdot
.44386 .60664 Mdot
.78081 .30712 Mdot
.42548 .29252 Mdot
.32942 .61291 Mdot
.35184 .24539 Mdot
.25253 .512 Mdot
.4841 .43349 Mdot
.42585 .46724 Mdot
.3123 .49174 Mdot
.40953 .33523 Mdot
.32105 .28753 Mdot
.5617 .74523 Mdot
.55663 .71852 Mdot
.39492 .65409 Mdot
.14008 .49677 Mdot
.32273 .24108 Mdot
.67426 .44396 Mdot
.63249 .3321 Mdot
.60402 .29218 Mdot
.61627 .41509 Mdot
.61259 .41176 Mdot
.49694 .64391 Mdot
.65798 .49084 Mdot
.36137 .39021 Mdot
.44336 .62973 Mdot
.5773 .67836 Mdot
.4403 .36386 Mdot
.60444 .6568 Mdot
.5868 .74426 Mdot
.42178 .45924 Mdot
.45007 .65457 Mdot
.62048 .52482 Mdot
.58283 .47098 Mdot
.41989 .30933 Mdot
.3923 .28366 Mdot
.44308 .37574 Mdot
.57819 .66799 Mdot
.43927 .6251 Mdot
.20334 .38275 Mdot
.58015 .47093 Mdot
.45561 .33886 Mdot
.48874 .44361 Mdot
.59844 .49765 Mdot
.35735 .47128 Mdot
.61148 .48524 Mdot
.43355 .36472 Mdot
.59982 .49355 Mdot
.43272 .32443 Mdot
.43307 .63323 Mdot
.57835 .4394 Mdot
.58768 .44125 Mdot
.71043 .24815 Mdot
.56902 .66086 Mdot
.46024 .31606 Mdot
.52913 .60524 Mdot
.59221 .50049 Mdot
.29572 .59914 Mdot
.646 .47574 Mdot
.46962 .39869 Mdot
.67056 .44381 Mdot
.26324 .49174 Mdot
.6949 .46043 Mdot
.61999 .42826 Mdot
.51436 .5181 Mdot
.59262 .29489 Mdot
.70068 .49521 Mdot
.32537 .52699 Mdot
.46696 .32415 Mdot
.70301 .27549 Mdot
.37317 .60443 Mdot
.45266 .67283 Mdot
.73345 .57858 Mdot
.58638 .42072 Mdot
.6342 .45774 Mdot
.36225 .42403 Mdot
.60043 .66198 Mdot
.46088 .3325 Mdot
.56705 .66829 Mdot
.75254 .29782 Mdot
.58477 .62701 Mdot
.40585 .59361 Mdot
.42215 .74916 Mdot
.18674 .42665 Mdot
.55914 .65407 Mdot
.43223 .36557 Mdot
.40135 .73927 Mdot
.5655 .45533 Mdot
.54224 .56017 Mdot
.57156 .64939 Mdot
.1584 .59256 Mdot
.56832 .47013 Mdot
.48615 .42924 Mdot
.32967 .4772 Mdot
.55963 .65958 Mdot
.33091 .46621 Mdot
.58669 .46047 Mdot
.34569 .6751 Mdot
.42146 .32345 Mdot
.33978 .45846 Mdot
.54997 .46957 Mdot
.57283 .66814 Mdot
.45822 .62042 Mdot
.38657 .45891 Mdot
.31039 .51703 Mdot
.64662 .75968 Mdot
.24505 .69282 Mdot
.43646 .62347 Mdot
.60079 .21651 Mdot
.34775 .52375 Mdot
.56353 .46073 Mdot
.30071 .28798 Mdot
.63051 .49382 Mdot
.21779 .47144 Mdot
.44201 .64319 Mdot
.32293 .68822 Mdot
.60234 .49998 Mdot
.62026 .42205 Mdot
.44546 .38785 Mdot
.41669 .63257 Mdot
.44554 .33879 Mdot
.45874 .30837 Mdot
.43234 .63175 Mdot
.42773 .33031 Mdot
.55621 .64888 Mdot
.34015 .32255 Mdot
.34064 .51934 Mdot
.3413 .51009 Mdot
.4064 .64319 Mdot
.43596 .65177 Mdot
.42244 .64852 Mdot
.61177 .48589 Mdot
.46018 .34428 Mdot
.59516 .46366 Mdot
.65877 .44742 Mdot
.55598 .24267 Mdot
.40098 .31866 Mdot
.60232 .4686 Mdot
.54091 .58376 Mdot
.52144 .49819 Mdot
.44739 .66383 Mdot
.33012 .47899 Mdot
.3367 .58493 Mdot
.2604 .61723 Mdot
.64057 .46724 Mdot
.58897 .60038 Mdot
.43131 .36658 Mdot
.59138 .66702 Mdot
.59852 .63135 Mdot
.58507 .66158 Mdot
.29369 .46242 Mdot
.42252 .29161 Mdot
.48264 .21192 Mdot
.63916 .46088 Mdot
.38936 .40959 Mdot
.45997 .28673 Mdot
.43663 .73116 Mdot
.33087 .48006 Mdot
.59118 .48976 Mdot
.50297 .58413 Mdot
.64447 .36145 Mdot
.62581 .4929 Mdot
.56284 .4923 Mdot
.50485 .79339 Mdot
.56868 .51875 Mdot
.4498 .38164 Mdot
.66293 .21145 Mdot
.61347 .51195 Mdot
.2172 .40887 Mdot
.50624 .85608 Mdot
.63979 .47541 Mdot
.63093 .42353 Mdot
.57648 .46066 Mdot
.61577 .50451 Mdot
.41211 .36508 Mdot
.69946 .56328 Mdot
.34222 .52568 Mdot
.38866 .4057 Mdot
.37101 .47623 Mdot
.40641 .60849 Mdot
.32794 .6919 Mdot
.40965 .3418 Mdot
.59488 .64236 Mdot
.45699 .81646 Mdot
.57606 .1876 Mdot
.42557 .60999 Mdot
.19537 .48133 Mdot
.5725 .65185 Mdot
.56062 .47146 Mdot
.55459 .67238 Mdot
.46292 .64157 Mdot
.3426 .51287 Mdot
.57825 .51127 Mdot
.42201 .35922 Mdot
.45569 .36417 Mdot
.59124 .49255 Mdot
.37353 .7587 Mdot
.35204 .46616 Mdot
.31279 .5227 Mdot
.65449 .47922 Mdot
.60679 .5129 Mdot
.44231 .33739 Mdot
.40405 .62935 Mdot
.73928 .34765 Mdot
.59403 .67522 Mdot
.63565 .41363 Mdot
.60414 .496 Mdot
.78675 .3634 Mdot
.33053 .51113 Mdot
.47308 .65057 Mdot
.67075 .45797 Mdot
.26684 .38899 Mdot
.66971 .46214 Mdot
.64543 .39791 Mdot
.44091 .66675 Mdot
.65232 .39072 Mdot
.64819 .41171 Mdot
.47071 .39147 Mdot
.31939 .47953 Mdot
.43548 .35015 Mdot
.46637 .39606 Mdot
.35462 .29333 Mdot
.35787 .47478 Mdot
.60427 .47787 Mdot
.33526 .47952 Mdot
.64752 .48379 Mdot
.63164 .50866 Mdot
.32561 .48519 Mdot
.44494 .33766 Mdot
.5881 .78727 Mdot
.35673 .72231 Mdot
.6253 .50502 Mdot
.65761 .41149 Mdot
.6769 .57893 Mdot
.60824 .70688 Mdot
.62645 .41892 Mdot
.4392 .36833 Mdot
.58233 .45939 Mdot
.35463 .4602 Mdot
.55394 .65504 Mdot
.42933 .35826 Mdot
.41721 .61675 Mdot
.43841 .61145 Mdot
.28872 .4084 Mdot
.39462 .66285 Mdot
.63762 .42024 Mdot
.38845 .34613 Mdot
.41668 .37802 Mdot
.42335 .81338 Mdot
.4295 .62936 Mdot
.57628 .68638 Mdot
.5989 .43879 Mdot
.76605 .56728 Mdot
.38386 .48116 Mdot
.24854 .24811 Mdot
.42871 .2188 Mdot
.54658 .65869 Mdot
.42798 .23254 Mdot
.4366 .60548 Mdot
.63131 .40528 Mdot
.5799 .68503 Mdot
.45129 .62424 Mdot
.64344 .49544 Mdot
.66585 .41336 Mdot
.4881 .29442 Mdot
.4094 .48364 Mdot
.33227 .48332 Mdot
.38927 .64196 Mdot
.54616 .66993 Mdot
.43393 .59675 Mdot
.43666 .29559 Mdot
.63099 .43382 Mdot
.66375 .49159 Mdot
.40502 .62537 Mdot
.44992 .67584 Mdot
.60548 .4637 Mdot
.41646 .35976 Mdot
.50099 .63819 Mdot
.62058 .44098 Mdot
.40277 .47517 Mdot
.40238 .30106 Mdot
.44341 .62289 Mdot
.6232 .42502 Mdot
.57317 .70021 Mdot
.41504 .62194 Mdot
.45062 .66187 Mdot
.60469 .50385 Mdot
.55978 .64384 Mdot
.67624 .43281 Mdot
.32899 .52024 Mdot
.1498 .52362 Mdot
.35649 .4601 Mdot
.38336 .58129 Mdot
.55905 .51364 Mdot
.27354 .35375 Mdot
.40336 .32733 Mdot
.7547 .52836 Mdot
.34178 .57704 Mdot
.59988 .39843 Mdot
.73154 .71611 Mdot
.35345 .54313 Mdot
.41777 .7991 Mdot
.76767 .62263 Mdot
.57079 .64458 Mdot
.35041 .48363 Mdot
.63141 .42345 Mdot
.3713 .46183 Mdot
.58553 .68537 Mdot
.20244 .61642 Mdot
.61162 .42416 Mdot
.45117 .35963 Mdot
.60867 .46833 Mdot
.45821 .35605 Mdot
.61169 .50724 Mdot
.68325 .45865 Mdot
.28817 .54735 Mdot
.70625 .52791 Mdot
.66885 .45706 Mdot
.74494 .24294 Mdot
.50683 .43873 Mdot
.58692 .67936 Mdot
.59585 .45559 Mdot
.4764 .6273 Mdot
.37578 .49357 Mdot
.24631 .48096 Mdot
.41731 .65517 Mdot
.3121 .51689 Mdot
.43399 .33344 Mdot
.43813 .64083 Mdot
.4181 .60977 Mdot
.64836 .38868 Mdot
.55038 .65501 Mdot
.34984 .49923 Mdot
.642 .44321 Mdot
.61333 .42463 Mdot
.60049 .213 Mdot
.53818 .75381 Mdot
.38439 .29651 Mdot
.46132 .17014 Mdot
.44784 .29361 Mdot
.57593 .67468 Mdot
.4241 .66287 Mdot
.65382 .43726 Mdot
.61852 .46711 Mdot
.30748 .59921 Mdot
.43233 .37308 Mdot
.45763 .52046 Mdot
.41551 .25116 Mdot
.52275 .62142 Mdot
.70845 .53762 Mdot
.43942 .36541 Mdot
.70335 .54189 Mdot
.55976 .62871 Mdot
.64444 .79434 Mdot
.67457 .55444 Mdot
.33341 .47459 Mdot
.68989 .55299 Mdot
.4577 .32961 Mdot
.65238 .4927 Mdot
.43093 .67064 Mdot
.40456 .66982 Mdot
.44116 .34674 Mdot
.46527 .6188 Mdot
.5752 .63748 Mdot
.64145 .43218 Mdot
.49148 .19877 Mdot
.32117 .37971 Mdot
.40315 .64383 Mdot
.59202 .39199 Mdot
.36023 .48826 Mdot
.59173 .49352 Mdot
.56341 .64655 Mdot
.34431 .47552 Mdot
.79258 .46381 Mdot
.31937 .45821 Mdot
.60328 .43824 Mdot
.79066 .36309 Mdot
.35359 .4765 Mdot
.52219 .41459 Mdot
.6277 .44108 Mdot
.32195 .51695 Mdot
.61765 .3766 Mdot
.28553 .64449 Mdot
.50301 .55882 Mdot
.79318 .64748 Mdot
.48679 .5276 Mdot
.4106 .66203 Mdot
.30103 .66582 Mdot
.24545 .5052 Mdot
.36335 .50865 Mdot
.46567 .66241 Mdot
.57449 .57566 Mdot
.32689 .46938 Mdot
.56195 .47108 Mdot
.64204 .47836 Mdot
.19737 .56811 Mdot
.36836 .52368 Mdot
.2739 .65791 Mdot
.29972 .41992 Mdot
.58934 .49958 Mdot
.67835 .44478 Mdot
.62123 .46353 Mdot
.43596 .38097 Mdot
.32796 .49477 Mdot
.70878 .2278 Mdot
.35726 .46816 Mdot
.51754 .23487 Mdot
.40801 .64059 Mdot
.44778 .62326 Mdot
.64338 .4637 Mdot
.48716 .41843 Mdot
.77518 .47301 Mdot
.61121 .46419 Mdot
.62232 .66399 Mdot
.21705 .58824 Mdot
.60342 .5107 Mdot
.40582 .34321 Mdot
.62381 .39062 Mdot
.53267 .45032 Mdot
.34169 .51938 Mdot
.58818 .6397 Mdot
.76712 .50911 Mdot
.34858 .50854 Mdot
.6328 .45819 Mdot
.27947 .35847 Mdot
.6247 .48561 Mdot
.62978 .50294 Mdot
.4632 .23518 Mdot
.59277 .62659 Mdot
.42545 .6409 Mdot
.58233 .66096 Mdot
.40906 .31927 Mdot
.22379 .24795 Mdot
.58824 .62796 Mdot
.7809 .46367 Mdot
.18683 .57427 Mdot
.67336 .56169 Mdot
.46362 .33545 Mdot
.55192 .67308 Mdot
.3441 .46708 Mdot
.73766 .72594 Mdot
.49733 .32045 Mdot
.37621 .53229 Mdot
.62279 .44566 Mdot
.47517 .34348 Mdot
.45592 .36865 Mdot
.33627 .45952 Mdot
.44282 .30248 Mdot
.7035 .43794 Mdot
.64247 .49934 Mdot
.37082 .48902 Mdot
.2846 .38104 Mdot
.33131 .52857 Mdot
.42745 .55291 Mdot
.60076 .45258 Mdot
.43333 .35976 Mdot
.63005 .41002 Mdot
.39099 .32567 Mdot
.47208 .63794 Mdot
.63691 .51785 Mdot
.57724 .63572 Mdot
.2616 .37179 Mdot
.4346 .62145 Mdot
.53981 .60955 Mdot
.41769 .31044 Mdot
.312 .4486 Mdot
.42341 .30261 Mdot
.39497 .35269 Mdot
.30653 .50458 Mdot
.44451 .31674 Mdot
.63341 .42535 Mdot
.52305 .5677 Mdot
.42013 .31575 Mdot
.34131 .49723 Mdot
.5901 .64454 Mdot
.43525 .32848 Mdot
.45475 .59579 Mdot
.60145 .43447 Mdot
.43165 .66016 Mdot
.6047 .72483 Mdot
.47326 .34716 Mdot
.58259 .62086 Mdot
.44666 .67612 Mdot
.60246 .6759 Mdot
.36699 .78608 Mdot
.32596 .46009 Mdot
.50156 .24691 Mdot
.62168 .68392 Mdot
.46059 .36958 Mdot
.6153 .72743 Mdot
.65757 .44855 Mdot
.59945 .43639 Mdot
.58502 .69197 Mdot
.4557 .36894 Mdot
.57156 .83903 Mdot
.55734 .5262 Mdot
.42084 .53306 Mdot
.30512 .52924 Mdot
.77804 .29833 Mdot
.42133 .54567 Mdot
.46578 .85911 Mdot
.56703 .41209 Mdot
.41741 .68204 Mdot
.63337 .46898 Mdot
.31548 .57477 Mdot
.57284 .66469 Mdot
.4263 .5751 Mdot
.67247 .48819 Mdot
.4313 .63875 Mdot
.58398 .4406 Mdot
.51342 .52662 Mdot
.53216 .41428 Mdot
.58497 .68879 Mdot
.39207 .75095 Mdot
.47053 .33833 Mdot
.57909 .64527 Mdot
.45645 .63233 Mdot
.73708 .51651 Mdot
.64219 .49721 Mdot
.56036 .46233 Mdot
.52195 .62276 Mdot
.46154 .3428 Mdot
.41588 .66896 Mdot
.33248 .51938 Mdot
.59565 .64731 Mdot
.58429 .47086 Mdot
.66187 .45163 Mdot
.28896 .58941 Mdot
.36325 .48405 Mdot
.4025 .67321 Mdot
.32358 .47912 Mdot
.41996 .60561 Mdot
.64737 .50289 Mdot
.43604 .61389 Mdot
.59605 .41004 Mdot
.28348 .53397 Mdot
.48517 .23741 Mdot
.59705 .30733 Mdot
.44449 .63997 Mdot
.76515 .42698 Mdot
.36214 .48159 Mdot
.31522 .50015 Mdot
.17301 .50335 Mdot
.4879 .28284 Mdot
.57488 .1959 Mdot
.70704 .70974 Mdot
.36753 .48969 Mdot
.35306 .49339 Mdot
.43328 .65884 Mdot
.44252 .31429 Mdot
.4464 .29462 Mdot
.41713 .60692 Mdot
.68706 .63884 Mdot
.46081 .33284 Mdot
.69329 .75557 Mdot
.66662 .24477 Mdot
.57996 .41772 Mdot
.40275 .59232 Mdot
.59323 .66161 Mdot
.69402 .62195 Mdot
.51763 .5373 Mdot
.6169 .42037 Mdot
.75554 .55629 Mdot
.40428 .63664 Mdot
.4712 .41255 Mdot
.79135 .63492 Mdot
.58105 .43949 Mdot
.63251 .44087 Mdot
.6276 .46365 Mdot
.55396 .64371 Mdot
.5066 .32213 Mdot
.63173 .42852 Mdot
.68517 .64149 Mdot
.59111 .49738 Mdot
.53683 .40244 Mdot
.58591 .65668 Mdot
.66259 .55267 Mdot
.57367 .74648 Mdot
.6658 .2178 Mdot
.52352 .44847 Mdot
.33411 .52072 Mdot
.5597 .70772 Mdot
.31429 .49315 Mdot
.55593 .29762 Mdot
.64249 .57035 Mdot
.44765 .29036 Mdot
.61937 .42016 Mdot
.44341 .63417 Mdot
.45625 .36781 Mdot
.29425 .63201 Mdot
.26396 .21011 Mdot
.34058 .52242 Mdot
.58006 .87819 Mdot
.31999 .51374 Mdot
.41548 .61026 Mdot
.44142 .33769 Mdot
.69995 .36429 Mdot
.36598 .35717 Mdot
.43236 .32777 Mdot
.56357 .81878 Mdot
.44258 .27749 Mdot
.75323 .48617 Mdot
.46428 .37489 Mdot
.34708 .49331 Mdot
.28428 .46113 Mdot
.71067 .45749 Mdot
.65512 .45742 Mdot
.4297 .46725 Mdot
.77115 .46745 Mdot
.65685 .44702 Mdot
.44183 .62836 Mdot
.48722 .24963 Mdot
.74299 .56384 Mdot
.44977 .32146 Mdot
.31422 .46448 Mdot
.62739 .43501 Mdot
.61324 .49789 Mdot
.64832 .49397 Mdot
.44083 .20735 Mdot
.64044 .79648 Mdot
.65258 .49479 Mdot
.60326 .50636 Mdot
.43548 .63949 Mdot
.60691 .70064 Mdot
.38883 .73388 Mdot
.58246 .22193 Mdot
.59161 .42482 Mdot
.58233 .64813 Mdot
.54189 .66716 Mdot
.66545 .47265 Mdot
.54973 .57637 Mdot
.28369 .34878 Mdot
.64119 .44168 Mdot
.48934 .25357 Mdot
.44849 .70242 Mdot
.3898 .66616 Mdot
.41272 .62031 Mdot
.46137 .32008 Mdot
.40458 .62116 Mdot
.44832 .61296 Mdot
.70119 .37585 Mdot
.4729 .52115 Mdot
.31404 .54777 Mdot
.58018 .66934 Mdot
.61943 .47284 Mdot
.68788 .51388 Mdot
.26863 .37905 Mdot
.31174 .48829 Mdot
.42228 .35337 Mdot
.37756 .49164 Mdot
.53428 .6546 Mdot
.37006 .27982 Mdot
.39765 .64595 Mdot
.36027 .50232 Mdot
.37124 .44727 Mdot
.58471 .64902 Mdot
.35275 .45707 Mdot
.36727 .43665 Mdot
.61041 .52058 Mdot
.61731 .33771 Mdot
.60954 .45754 Mdot
.46185 .82274 Mdot
.35709 .49528 Mdot
.27548 .48537 Mdot
.63822 .45191 Mdot
.41756 .62192 Mdot
.70522 .40464 Mdot
.65631 .46169 Mdot
.40222 .62573 Mdot
.67454 .44894 Mdot
.60848 .65841 Mdot
.39633 .31357 Mdot
.36952 .36645 Mdot
.13644 .48641 Mdot
.54913 .65848 Mdot
.29608 .62585 Mdot
.61793 .41735 Mdot
.28911 .73366 Mdot
.43799 .32807 Mdot
.66035 .43313 Mdot
.73363 .55072 Mdot
.42765 .31431 Mdot
.42516 .34311 Mdot
.60581 .48785 Mdot
.33071 .47497 Mdot
.43763 .62128 Mdot
.58816 .65294 Mdot
.44377 .83945 Mdot
.61444 .44367 Mdot
.5848 .4477 Mdot
.5757 .64832 Mdot
.36488 .47565 Mdot
.66884 .46208 Mdot
.70472 .67699 Mdot
.60242 .83352 Mdot
.31479 .51125 Mdot
.56734 .45671 Mdot
.55386 .32274 Mdot
.53993 .50497 Mdot
.25446 .73361 Mdot
.54804 .5667 Mdot
.42927 .64496 Mdot
.597 .53474 Mdot
.3357 .19328 Mdot
.59092 .64283 Mdot
.57449 .18926 Mdot
.61067 .49824 Mdot
.57895 .47387 Mdot
.43983 .37436 Mdot
.59833 .46301 Mdot
.41261 .34758 Mdot
.16295 .43007 Mdot
.78653 .3491 Mdot
.44913 .30464 Mdot
.46523 .36546 Mdot
.76756 .49828 Mdot
.36004 .59278 Mdot
.43975 .34432 Mdot
.62629 .51009 Mdot
.5919 .57968 Mdot
.46724 .40717 Mdot
.56074 .68139 Mdot
.60657 .73565 Mdot
.6039 .54655 Mdot
.57474 .60157 Mdot
.60992 .76426 Mdot
.63199 .5476 Mdot
.45572 .56703 Mdot
.32281 .51017 Mdot
.58212 .43751 Mdot
.40333 .66985 Mdot
.39559 .66543 Mdot
.60807 .4036 Mdot
.61886 .48088 Mdot
.41141 .31628 Mdot
.59851 .66099 Mdot
.35727 .51698 Mdot
.58177 .47542 Mdot
.75175 .52523 Mdot
.6013 .65423 Mdot
.44288 .30676 Mdot
.54313 .24883 Mdot
.61125 .66757 Mdot
.68646 .4561 Mdot
.64853 .45087 Mdot
.60763 .47271 Mdot
.71128 .46575 Mdot
.32481 .49693 Mdot
.62613 .7323 Mdot
.5753 .4988 Mdot
.74714 .2896 Mdot
.3457 .55608 Mdot
.6488 .51751 Mdot
.43264 .29687 Mdot
.29583 .49383 Mdot
.44427 .60338 Mdot
.34689 .28396 Mdot
.60492 .43932 Mdot
.37792 .7551 Mdot
.20355 .57927 Mdot
.47037 .64862 Mdot
.39279 .32641 Mdot
.58602 .66627 Mdot
.61254 .46663 Mdot
.52672 .27053 Mdot
.64327 .47529 Mdot
.59173 .6116 Mdot
.455 .66043 Mdot
.32109 .50783 Mdot
.43242 .80825 Mdot
.38854 .65197 Mdot
.42785 .34482 Mdot
.82932 .45529 Mdot
.4118 .3476 Mdot
.44783 .29701 Mdot
.55591 .25071 Mdot
.32359 .49688 Mdot
.29151 .21453 Mdot
.17279 .43256 Mdot
.63172 .51702 Mdot
.36307 .47708 Mdot
.44292 .35374 Mdot
.58034 .48717 Mdot
.41926 .27702 Mdot
.41499 .29626 Mdot
.63812 .50849 Mdot
.57383 .46466 Mdot
.29324 .69194 Mdot
.77427 .65485 Mdot
.58457 .66696 Mdot
.407 .31618 Mdot
.36723 .38051 Mdot
.57861 .48704 Mdot
.6395 .4599 Mdot
.24017 .519 Mdot
.55171 .6585 Mdot
.34595 .37579 Mdot
.61211 .49805 Mdot
.79691 .40161 Mdot
.663 .39935 Mdot
.4117 .36161 Mdot
.31196 .49822 Mdot
.67999 .23018 Mdot
.38028 .44133 Mdot
.41355 .34757 Mdot
.59391 .63839 Mdot
.4365 .38873 Mdot
.78262 .45608 Mdot
.36857 .47389 Mdot
.43365 .36482 Mdot
.49879 .58495 Mdot
.33416 .48937 Mdot
.35679 .50067 Mdot
.56571 .24382 Mdot
.47614 .64581 Mdot
.55094 .64657 Mdot
.35188 .49671 Mdot
.26794 .32991 Mdot
.34173 .49228 Mdot
.16915 .45043 Mdot
.57489 .44503 Mdot
.72261 .61255 Mdot
.39117 .57497 Mdot
.63118 .53705 Mdot
.36165 .49256 Mdot
.5573 .65911 Mdot
.64233 .49512 Mdot
.45759 .32315 Mdot
.59786 .67578 Mdot
.39189 .49437 Mdot
.42183 .65498 Mdot
.42657 .30369 Mdot
.35261 .5295 Mdot
.4557 .36178 Mdot
.32036 .28951 Mdot
.17228 .56703 Mdot
.78344 .5237 Mdot
.36272 .3476 Mdot
.64029 .49874 Mdot
.65951 .74783 Mdot
.56913 .44588 Mdot
.61871 .4862 Mdot
.44388 .62551 Mdot
.73488 .58965 Mdot
.44504 .33852 Mdot
.51792 .83708 Mdot
.34581 .51683 Mdot
.67667 .22356 Mdot
.52744 .47259 Mdot
.65755 .42094 Mdot
.41758 .31819 Mdot
.42384 .36815 Mdot
.58387 .28364 Mdot
.42201 .59586 Mdot
.62714 .41447 Mdot
.55919 .49355 Mdot
.62252 .40014 Mdot
.34366 .51455 Mdot
.55559 .59014 Mdot
.40809 .65898 Mdot
.20097 .63752 Mdot
.45508 .66192 Mdot
.59035 .60799 Mdot
.44781 .31708 Mdot
.58837 .62826 Mdot
.64096 .45803 Mdot
.39902 .27468 Mdot
.4339 .37459 Mdot
.58981 .69071 Mdot
.56218 .6684 Mdot
.26493 .59654 Mdot
.32625 .48491 Mdot
.65991 .46566 Mdot
.62535 .42541 Mdot
.59352 .46764 Mdot
.61257 .4841 Mdot
.34437 .52035 Mdot
.6497 .48892 Mdot
.3859 .48132 Mdot
.35882 .25884 Mdot
.72967 .63687 Mdot
.48831 .52492 Mdot
.20634 .48114 Mdot
.45454 .32479 Mdot
.26889 .33685 Mdot
.54273 .48935 Mdot
.36641 .21884 Mdot
.23223 .64833 Mdot
.58972 .51066 Mdot
.44204 .61419 Mdot
.63102 .37312 Mdot
.39669 .65798 Mdot
.46645 .86879 Mdot
.27078 .54727 Mdot
.76654 .67569 Mdot
.61214 .42501 Mdot
.51996 .5675 Mdot
.24385 .34991 Mdot
.56499 .4532 Mdot
.27223 .57741 Mdot
.21636 .46951 Mdot
.38168 .74386 Mdot
.55958 .64925 Mdot
.61262 .43372 Mdot
.69546 .50344 Mdot
.63645 .42802 Mdot
.63693 .4659 Mdot
.64905 .49157 Mdot
.34182 .52887 Mdot
.65424 .4296 Mdot
.63559 .49466 Mdot
.4479 .75416 Mdot
.70714 .53455 Mdot
.42484 .6791 Mdot
.17649 .52732 Mdot
.58758 .62717 Mdot
.41684 .31441 Mdot
.63518 .79124 Mdot
.33335 .47507 Mdot
.59125 .28534 Mdot
.61043 .47922 Mdot
.31788 .70471 Mdot
.36178 .44463 Mdot
.58921 .63535 Mdot
.46364 .63844 Mdot
.76729 .69124 Mdot
.43954 .63128 Mdot
.28819 .49184 Mdot
.42167 .62202 Mdot
.54893 .50682 Mdot
.41051 .31644 Mdot
.66303 .46874 Mdot
.34676 .50181 Mdot
.41711 .61422 Mdot
.6785 .58773 Mdot
.62257 .46525 Mdot
.43144 .63205 Mdot
.66244 .4695 Mdot
.37133 .31248 Mdot
.63367 .23897 Mdot
.45114 .61694 Mdot
.36679 .44821 Mdot
.33255 .50551 Mdot
.56357 .63985 Mdot
.42489 .30868 Mdot
.41866 .35117 Mdot
.34432 .47684 Mdot
.44318 .25268 Mdot
.59275 .42247 Mdot
.57518 .47808 Mdot
.70582 .25263 Mdot
.63998 .42608 Mdot
.73696 .51253 Mdot
.50834 .58601 Mdot
.45068 .31289 Mdot
.65939 .41975 Mdot
.60385 .49101 Mdot
.60217 .43773 Mdot
.39732 .2556 Mdot
.40177 .63153 Mdot
.57865 .44143 Mdot
.56596 .67405 Mdot
.40448 .72096 Mdot
.59231 .4941 Mdot
.67809 .40394 Mdot
.41989 .35304 Mdot
.46288 .17548 Mdot
.3189 .51151 Mdot
.45548 .63222 Mdot
.44499 .64118 Mdot
.61747 .74179 Mdot
.23511 .4045 Mdot
.50921 .58484 Mdot
.21975 .67943 Mdot
.28871 .54739 Mdot
.56965 .67016 Mdot
.37616 .64707 Mdot
.2749 .46786 Mdot
.44507 .65156 Mdot
.3449 .52215 Mdot
.56836 .45699 Mdot
.5893 .42651 Mdot
.29781 .23692 Mdot
.66837 .46787 Mdot
.58872 .66339 Mdot
.3344 .52956 Mdot
.45743 .3312 Mdot
.59213 .63865 Mdot
.32191 .48019 Mdot
.45811 .31695 Mdot
.5817 .50749 Mdot
.57441 .50048 Mdot
.42114 .35036 Mdot
.44271 .37214 Mdot
.64583 .45117 Mdot
.35593 .6637 Mdot
.46518 .36274 Mdot
.43825 .36615 Mdot
.39957 .64664 Mdot
.39836 .66609 Mdot
.69279 .43909 Mdot
.3596 .48252 Mdot
.63879 .49404 Mdot
.44003 .63867 Mdot
.58587 .62773 Mdot
.44702 .33642 Mdot
.62138 .5048 Mdot
.59083 .48781 Mdot
.58584 .6483 Mdot
.57486 .63208 Mdot
.56259 .64966 Mdot
.36667 .5196 Mdot
.59136 .46038 Mdot
.43676 .33758 Mdot
.32263 .49139 Mdot
.54223 .66249 Mdot
.55876 .67672 Mdot
.38029 .61998 Mdot
.64768 .42927 Mdot
.37222 .59369 Mdot
.35531 .17975 Mdot
.75752 .32238 Mdot
.46607 .62806 Mdot
.44304 .60167 Mdot
.64133 .59526 Mdot
.44981 .41922 Mdot
.35369 .47038 Mdot
.6113 .69995 Mdot
.77459 .49844 Mdot
.59477 .51835 Mdot
.60648 .50991 Mdot
.68066 .45787 Mdot
.56163 .65407 Mdot
.74469 .59276 Mdot
.40931 .33933 Mdot
.70602 .51091 Mdot
.60258 .65851 Mdot
.44185 .67818 Mdot
.37493 .6226 Mdot
.45862 .65823 Mdot
.5634 .48078 Mdot
.61192 .31261 Mdot
.25033 .37021 Mdot
.69716 .70396 Mdot
.36314 .48726 Mdot
.68526 .5162 Mdot
.28593 .72663 Mdot
.42196 .3451 Mdot
.4048 .60902 Mdot
.56943 .67219 Mdot
.44506 .37157 Mdot
.37893 .48152 Mdot
.35075 .49563 Mdot
.40405 .64584 Mdot
.40789 .64949 Mdot
.4427 .66145 Mdot
.41398 .29519 Mdot
.44593 .3165 Mdot
.60349 .44168 Mdot
.44954 .33291 Mdot
.40725 .21267 Mdot
.59073 .69523 Mdot
.48245 .65372 Mdot
.35373 .4829 Mdot
.46284 .33047 Mdot
.61997 .46376 Mdot
.44805 .41177 Mdot
.25455 .44797 Mdot
.5851 .68134 Mdot
.61558 .22451 Mdot
.43739 .85192 Mdot
.66086 .46099 Mdot
.32664 .50435 Mdot
.49293 .19466 Mdot
.62597 .4614 Mdot
.4262 .66547 Mdot
.46159 .78773 Mdot
.38238 .68612 Mdot
.65586 .46453 Mdot
.60498 .52297 Mdot
.32442 .52067 Mdot
.21055 .64653 Mdot
.60814 .4426 Mdot
.34361 .3562 Mdot
.35519 .44678 Mdot
.41567 .66532 Mdot
.72358 .77141 Mdot
.52573 .66575 Mdot
.69295 .62895 Mdot
.40388 .65115 Mdot
.63194 .48765 Mdot
.39454 .64976 Mdot
.57343 .67865 Mdot
.45974 .6313 Mdot
.41071 .34882 Mdot
.45707 .66434 Mdot
.58394 .44857 Mdot
.43919 .34707 Mdot
.35482 .476 Mdot
.64847 .21363 Mdot
.4899 .77973 Mdot
.41536 .62331 Mdot
.44046 .60981 Mdot
.66695 .42743 Mdot
.35652 .3914 Mdot
.60409 .4074 Mdot
.56826 .46714 Mdot
.36975 .48241 Mdot
.42584 .31274 Mdot
.31206 .51013 Mdot
.68268 .5002 Mdot
.74102 .64059 Mdot
.32168 .48247 Mdot
.36407 .73175 Mdot
.57123 .65371 Mdot
.4723 .46022 Mdot
.6175 .4684 Mdot
.34062 .46041 Mdot
.59258 .45771 Mdot
.40788 .33311 Mdot
.48892 .50318 Mdot
.35089 .69211 Mdot
.34578 .50776 Mdot
.40036 .77967 Mdot
.70385 .66418 Mdot
.69745 .43781 Mdot
.31436 .50042 Mdot
.73389 .56049 Mdot
.41372 .61105 Mdot
.59556 .6748 Mdot
.6081 .67249 Mdot
.60406 .66372 Mdot
.58477 .40776 Mdot
.52462 .4583 Mdot
.58283 .62008 Mdot
.37569 .49022 Mdot
.58461 .68862 Mdot
.20837 .40842 Mdot
.52264 .83539 Mdot
.57295 .66139 Mdot
.62545 .44229 Mdot
.54374 .42127 Mdot
.6475 .57163 Mdot
.28065 .64279 Mdot
.75396 .69011 Mdot
.22522 .54832 Mdot
.65308 .46254 Mdot
.41067 .29197 Mdot
.40759 .30653 Mdot
.50291 .18001 Mdot
.77005 .4501 Mdot
.77473 .34789 Mdot
.47054 .32927 Mdot
.33623 .6167 Mdot
.43792 .30477 Mdot
.6591 .48354 Mdot
.57684 .48151 Mdot
.47034 .32562 Mdot
.74921 .61676 Mdot
.3258 .62619 Mdot
.43774 .82327 Mdot
.45087 .3675 Mdot
.31826 .48119 Mdot
.31034 .48269 Mdot
.35898 .49848 Mdot
.64144 .22593 Mdot
.41874 .32242 Mdot
.58972 .47585 Mdot
.44541 .63763 Mdot
.59196 .42712 Mdot
.33286 .48739 Mdot
.53206 .84044 Mdot
.42962 .32326 Mdot
.62772 .43139 Mdot
.69939 .41082 Mdot
.41357 .65272 Mdot
.57847 .65118 Mdot
.37497 .36389 Mdot
.77351 .35481 Mdot
.35144 .51203 Mdot
.47303 .34304 Mdot
.27482 .50156 Mdot
.4556 .81303 Mdot
.5668 .41028 Mdot
.56615 .50787 Mdot
.4425 .84183 Mdot
.79795 .42623 Mdot
.62653 .41668 Mdot
.45293 .62306 Mdot
.30211 .5923 Mdot
.59905 .49629 Mdot
.40641 .31153 Mdot
.61064 .66724 Mdot
.60087 .67681 Mdot
.69296 .43652 Mdot
.39722 .41763 Mdot
.50909 .53442 Mdot
.60521 .47998 Mdot
.68528 .45762 Mdot
.41131 .66134 Mdot
.30217 .56399 Mdot
.75353 .29857 Mdot
.58701 .63029 Mdot
.66445 .46776 Mdot
.55586 .80733 Mdot
.44391 .37704 Mdot
.47015 .64509 Mdot
.36233 .45941 Mdot
.45965 .28721 Mdot
.46326 .63596 Mdot
.62171 .50788 Mdot
.66731 .46804 Mdot
.30809 .49252 Mdot
.41195 .36102 Mdot
.56324 .65379 Mdot
.4482 .62678 Mdot
.57283 .63548 Mdot
.42654 .31595 Mdot
.4473 .32611 Mdot
.69887 .41557 Mdot
.5505 .42919 Mdot
.41776 .61725 Mdot
.59061 .41096 Mdot
.38228 .69167 Mdot
.2931 .77082 Mdot
.31552 .53537 Mdot
.65612 .43573 Mdot
.45622 .38303 Mdot
.34613 .51101 Mdot
.57686 .47029 Mdot
.48268 .86008 Mdot
.58259 .49245 Mdot
.29995 .5252 Mdot
.79895 .48505 Mdot
.56889 .642 Mdot
.67475 .53746 Mdot
.26936 .68 Mdot
.64568 .43162 Mdot
.44001 .65053 Mdot
.5971 .39189 Mdot
.33828 .46866 Mdot
.44941 .32027 Mdot
.28302 .77049 Mdot
.33855 .4964 Mdot
.6421 .43526 Mdot
.59478 .64424 Mdot
.45386 .38071 Mdot
.56175 .56829 Mdot
.54998 .57997 Mdot
.60386 .38163 Mdot
.63212 .41258 Mdot
.61338 .49184 Mdot
.71116 .67869 Mdot
.45496 .63644 Mdot
.44158 .36248 Mdot
.32793 .5083 Mdot
.34727 .47381 Mdot
.40303 .64003 Mdot
.38534 .56204 Mdot
.47147 .46081 Mdot
.44572 .144 Mdot
.3936 .6373 Mdot
.59545 .63288 Mdot
.35307 .37759 Mdot
.4503 .63395 Mdot
.42694 .63099 Mdot
.39939 .64894 Mdot
.47774 .57368 Mdot
.46193 .33391 Mdot
.61911 .50819 Mdot
.40122 .33183 Mdot
.63213 .48946 Mdot
.29887 .52166 Mdot
.34828 .50397 Mdot
.4328 .32023 Mdot
.40003 .80962 Mdot
.5872 .34351 Mdot
.62874 .45322 Mdot
.28951 .73317 Mdot
.66708 .49218 Mdot
.65853 .57477 Mdot
.67531 .46806 Mdot
.40992 .63112 Mdot
.55897 .45862 Mdot
.60552 .399 Mdot
.5369 .17926 Mdot
.35684 .48133 Mdot
.38787 .66591 Mdot
.67445 .4953 Mdot
.68477 .44963 Mdot
.41836 .29104 Mdot
.44341 .3706 Mdot
.60719 .67161 Mdot
.7307 .5 Mdot
.35709 .47384 Mdot
.20169 .37459 Mdot
.65425 .45612 Mdot
.54317 .61711 Mdot
.70887 .32314 Mdot
.57637 .46692 Mdot
.28882 .70759 Mdot
.60587 .30602 Mdot
.61402 .46727 Mdot
.43179 .50929 Mdot
.36239 .48289 Mdot
.76795 .61033 Mdot
.59646 .49992 Mdot
.41775 .65807 Mdot
.4433 .31147 Mdot
.43426 .37643 Mdot
.60677 .65356 Mdot
.32645 .23733 Mdot
.31097 .51015 Mdot
.44186 .31879 Mdot
.62533 .471 Mdot
.32442 .50368 Mdot
.39513 .63157 Mdot
.66026 .42543 Mdot
.77008 .42356 Mdot
.45357 .33617 Mdot
.67545 .4518 Mdot
.32863 .33808 Mdot
.66223 .62234 Mdot
.81207 .51072 Mdot
.33011 .51185 Mdot
.56241 .6424 Mdot
.63959 .39423 Mdot
.47855 .2796 Mdot
.67012 .42086 Mdot
.7085 .63179 Mdot
.20348 .42196 Mdot
.55494 .65248 Mdot
.63559 .44858 Mdot
.5853 .47307 Mdot
.49969 .42254 Mdot
.5916 .63382 Mdot
.61582 .42405 Mdot
.48179 .3097 Mdot
.45759 .35372 Mdot
.40945 .60783 Mdot
.45869 .33546 Mdot
.62356 .44589 Mdot
.55352 .42214 Mdot
.43984 .37339 Mdot
.30811 .76808 Mdot
.60047 .6983 Mdot
.31689 .50302 Mdot
.64432 .51028 Mdot
.57454 .49344 Mdot
.68546 .19795 Mdot
.46947 .65386 Mdot
.35809 .68153 Mdot
.46124 .71344 Mdot
.58677 .77985 Mdot
.52636 .67086 Mdot
.8169 .58609 Mdot
.79975 .43225 Mdot
.65546 .43015 Mdot
.57308 .55553 Mdot
.30153 .32014 Mdot
.36637 .48095 Mdot
.27511 .29266 Mdot
.65535 .45723 Mdot
.63547 .46812 Mdot
.46423 .62225 Mdot
.33555 .68764 Mdot
.77425 .34385 Mdot
.42884 .41236 Mdot
.56501 .65161 Mdot
.41041 .31216 Mdot
.62413 .5091 Mdot
.45075 .52281 Mdot
.44857 .67597 Mdot
.53046 .65832 Mdot
.63069 .43394 Mdot
.43167 .22508 Mdot
.26091 .43222 Mdot
.32639 .48917 Mdot
.44458 .6433 Mdot
.78033 .36992 Mdot
.65308 .4354 Mdot
.35358 .4558 Mdot
.6143 .44822 Mdot
.50095 .62452 Mdot
.67604 .50789 Mdot
.57373 .67054 Mdot
.61621 .50113 Mdot
.5346 .68583 Mdot
.80298 .30592 Mdot
.57993 .61629 Mdot
.43874 .28162 Mdot
.45741 .67614 Mdot
.4024 .62899 Mdot
.43969 .37003 Mdot
.4076 .62445 Mdot
.59507 .27148 Mdot
.71902 .38182 Mdot
.56956 .65242 Mdot
.68656 .43035 Mdot
.57726 .65902 Mdot
.47162 .64064 Mdot
.65474 .46247 Mdot
.35907 .81945 Mdot
.42872 .61512 Mdot
.80762 .41851 Mdot
.34212 .48912 Mdot
.45229 .67493 Mdot
.59166 .49727 Mdot
.26639 .49809 Mdot
.3891 .65315 Mdot
.33689 .65964 Mdot
.60228 .43825 Mdot
.45329 .32897 Mdot
.59596 .49182 Mdot
.63225 .51605 Mdot
.42036 .68139 Mdot
.64276 .48808 Mdot
.32295 .47879 Mdot
.46618 .32213 Mdot
.71828 .73933 Mdot
.22179 .44633 Mdot
.62051 .42195 Mdot
.6256 .46831 Mdot
.41025 .37208 Mdot
.56487 .47652 Mdot
.34348 .52055 Mdot
.10031 .49973 Mdot
.57173 .65342 Mdot
.3954 .67962 Mdot
.5299 .6852 Mdot
.59058 .51279 Mdot
.64571 .4926 Mdot
.51674 .86662 Mdot
.73453 .64294 Mdot
.31505 .49291 Mdot
.62221 .39952 Mdot
.39127 .63822 Mdot
.59639 .65523 Mdot
.36978 .50229 Mdot
.60697 .47063 Mdot
.63951 .45523 Mdot
.56817 .63488 Mdot
.59845 .58974 Mdot
.69016 .25973 Mdot
.32596 .46771 Mdot
.5628 .51663 Mdot
.47474 .60907 Mdot
.59616 .41804 Mdot
.6095 .21309 Mdot
.43162 .36141 Mdot
.35541 .50891 Mdot
.61417 .75468 Mdot
.65337 .43337 Mdot
.31097 .49545 Mdot
.3578 .47473 Mdot
.65518 .41356 Mdot
.47274 .37298 Mdot
.45971 .31384 Mdot
.4585 .35727 Mdot
.23265 .27909 Mdot
.69787 .60831 Mdot
.44258 .66155 Mdot
.36339 .48097 Mdot
.43889 .60743 Mdot
.59281 .61145 Mdot
.50215 .56336 Mdot
.44401 .61092 Mdot
.46345 .34746 Mdot
.42399 .68582 Mdot
.58719 .45672 Mdot
.3548 .47425 Mdot
.44255 .65548 Mdot
.62277 .51793 Mdot
.37546 .41219 Mdot
.24707 .60949 Mdot
.55885 .67316 Mdot
.61116 .65653 Mdot
.58316 .48767 Mdot
.4216 .59791 Mdot
.64551 .45422 Mdot
.36893 .46016 Mdot
.36864 .39928 Mdot
.63898 .5117 Mdot
.41196 .62489 Mdot
.42008 .37926 Mdot
.77639 .36441 Mdot
.5622 .43109 Mdot
.62683 .44313 Mdot
.63759 .48823 Mdot
.61371 .44813 Mdot
.45442 .80629 Mdot
.30397 .49075 Mdot
.2089 .47663 Mdot
.62132 .72934 Mdot
.42707 .32741 Mdot
.39876 .33353 Mdot
.74681 .30131 Mdot
.29603 .33248 Mdot
.36021 .48287 Mdot
.61642 .48545 Mdot
.26394 .39855 Mdot
.60166 .83277 Mdot
.41903 .83289 Mdot
.51683 .41236 Mdot
.46942 .65666 Mdot
.47248 .34145 Mdot
.4156 .61243 Mdot
.63622 .48367 Mdot
.68207 .4453 Mdot
.83305 .54665 Mdot
.37597 .47773 Mdot
.56665 .65773 Mdot
.63174 .49145 Mdot
.69472 .61358 Mdot
.43646 .64078 Mdot
.45029 .67661 Mdot
.57235 .45377 Mdot
.42316 .37689 Mdot
.78678 .29745 Mdot
.32513 .49762 Mdot
.2292 .52256 Mdot
.23891 .3554 Mdot
.27497 .43879 Mdot
.33018 .48988 Mdot
.5053 .44784 Mdot
.46876 .63835 Mdot
.69498 .30161 Mdot
.42239 .33019 Mdot
.59538 .67753 Mdot
.64175 .52123 Mdot
.42677 .36471 Mdot
.44352 .66836 Mdot
.45135 .32387 Mdot
.64626 .49373 Mdot
.33153 .45536 Mdot
.42924 .64715 Mdot
.3226 .55196 Mdot
.45381 .38427 Mdot
.59212 .63601 Mdot
.42797 .43131 Mdot
.5499 .3757 Mdot
.60429 .30305 Mdot
.5746 .44752 Mdot
.45216 .53105 Mdot
.5908 .47404 Mdot
.39414 .33819 Mdot
.61858 .45893 Mdot
.40461 .37589 Mdot
.43883 .65041 Mdot
.60239 .50569 Mdot
.60755 .48301 Mdot
.17351 .46986 Mdot
.61366 .42805 Mdot
.6044 .40979 Mdot
.61346 .47103 Mdot
.38969 .29319 Mdot
.68265 .42174 Mdot
.42901 .29647 Mdot
.41122 .7354 Mdot
.42335 .63139 Mdot
.6004 .68162 Mdot
.56125 .63994 Mdot
.72585 .59994 Mdot
.56466 .73503 Mdot
.32155 .68852 Mdot
.45612 .34654 Mdot
.33883 .465 Mdot
.61568 .45495 Mdot
.78767 .63556 Mdot
.50005 .65562 Mdot
.44476 .67589 Mdot
.22287 .4476 Mdot
.60032 .53817 Mdot
.78322 .59332 Mdot
.62567 .40153 Mdot
.2741 .25551 Mdot
.54805 .46737 Mdot
.63087 .53015 Mdot
.39465 .623 Mdot
.55017 .62255 Mdot
.56853 .48057 Mdot
.42858 .28921 Mdot
.5875 .67553 Mdot
.53221 .48644 Mdot
.38702 .58819 Mdot
.39085 .71795 Mdot
.38732 .36287 Mdot
.59745 .44986 Mdot
.42797 .64691 Mdot
.4246 .30456 Mdot
.76076 .31166 Mdot
.32153 .49372 Mdot
.39036 .55838 Mdot
.34244 .31124 Mdot
.31534 .76611 Mdot
.60119 .65177 Mdot
.64452 .25666 Mdot
.58384 .45134 Mdot
.43672 .77051 Mdot
.64492 .50883 Mdot
.54623 .84283 Mdot
.58191 .62318 Mdot
.46522 .34508 Mdot
.32231 .47591 Mdot
.40558 .31453 Mdot
.58928 .29959 Mdot
.39191 .59495 Mdot
.46611 .49848 Mdot
.43733 .63098 Mdot
.52456 .54969 Mdot
.43906 .35429 Mdot
.66094 .47295 Mdot
.44047 .1438 Mdot
.43601 .36495 Mdot
.45925 .37752 Mdot
.1909 .58582 Mdot
.32566 .79778 Mdot
.55617 .49634 Mdot
.4662 .36272 Mdot
.43303 .62727 Mdot
.58654 .66906 Mdot
.60579 .50068 Mdot
.59411 .4483 Mdot
.42468 .3616 Mdot
.40741 .67923 Mdot
.52686 .31081 Mdot
.40721 .64397 Mdot
.46229 .33699 Mdot
.41582 .64025 Mdot
.27901 .48795 Mdot
.45286 .62925 Mdot
.57376 .49299 Mdot
.61774 .45793 Mdot
.51917 .70704 Mdot
.44809 .32671 Mdot
.60392 .47881 Mdot
.6674 .42872 Mdot
.43898 .33961 Mdot
.52122 .51376 Mdot
.53455 .30982 Mdot
.61305 .41788 Mdot
.60605 .43226 Mdot
.55822 .64778 Mdot
.48048 .5501 Mdot
.62618 .2379 Mdot
.63977 .49639 Mdot
.55595 .64174 Mdot
.43459 .29073 Mdot
.6428 .44306 Mdot
.60869 .80822 Mdot
.30527 .59597 Mdot
.65938 .45832 Mdot
.41464 .61086 Mdot
.61136 .39901 Mdot
.81194 .49474 Mdot
.56805 .46908 Mdot
.44437 .34653 Mdot
.43537 .31332 Mdot
.19008 .40055 Mdot
.42927 .34687 Mdot
.40399 .66958 Mdot
.33381 .48811 Mdot
.44895 .8156 Mdot
.39937 .62575 Mdot
.5523 .43969 Mdot
.1482 .48733 Mdot
.66852 .44412 Mdot
.59514 .5108 Mdot
.81483 .39253 Mdot
.42122 .61254 Mdot
.41227 .32272 Mdot
.4525 .42869 Mdot
.54373 .44504 Mdot
.35653 .50605 Mdot
.67424 .50219 Mdot
.56753 .45696 Mdot
.80611 .46412 Mdot
.46291 .80272 Mdot
.35922 .45427 Mdot
.60212 .41132 Mdot
.64213 .49514 Mdot
.47565 .62672 Mdot
.62155 .46867 Mdot
.58244 .66971 Mdot
.41966 .31976 Mdot
.45014 .62323 Mdot
.58591 .64558 Mdot
.65327 .43991 Mdot
.56274 .65099 Mdot
.43193 .66046 Mdot
.36653 .46324 Mdot
.64541 .476 Mdot
.56287 .683 Mdot
.56416 .65025 Mdot
.59326 .47396 Mdot
.45012 .31836 Mdot
.58862 .53918 Mdot
.61735 .42712 Mdot
.62354 .50422 Mdot
.41751 .34925 Mdot
.69485 .80825 Mdot
.57469 .47909 Mdot
.71461 .63574 Mdot
.42494 .36791 Mdot
.52442 .53972 Mdot
.40202 .61848 Mdot
.56464 .46406 Mdot
.36708 .46325 Mdot
.3607 .46096 Mdot
.45824 .66015 Mdot
.47382 .35288 Mdot
.47543 .70376 Mdot
.48115 .35973 Mdot
.60137 .39422 Mdot
.59228 .4167 Mdot
.49826 .3285 Mdot
.77712 .66884 Mdot
.40425 .33307 Mdot
.40417 .57759 Mdot
.40292 .4131 Mdot
.34508 .4596 Mdot
.42469 .67946 Mdot
.47174 .32865 Mdot
.41156 .34094 Mdot
.4534 .31583 Mdot
.59389 .67984 Mdot
.52297 .70995 Mdot
.41811 .36707 Mdot
.41403 .3699 Mdot
.59676 .4416 Mdot
.6356 .49771 Mdot
.78024 .39663 Mdot
.75521 .38215 Mdot
.55847 .66494 Mdot
.43049 .66892 Mdot
.21527 .28347 Mdot
.37177 .46879 Mdot
.19129 .48279 Mdot
.60381 .51127 Mdot
.26845 .21304 Mdot
.59779 .49913 Mdot
.62378 .47315 Mdot
.46545 .32012 Mdot
.56338 .68174 Mdot
.57492 .65641 Mdot
.43987 .36295 Mdot
.40128 .35289 Mdot
.58068 .66905 Mdot
.25998 .67944 Mdot
.62612 .80835 Mdot
.39716 .70071 Mdot
.43864 .33334 Mdot
.64677 .36218 Mdot
.31607 .47772 Mdot
.53532 .43365 Mdot
.35634 .44882 Mdot
.43274 .63575 Mdot
.46409 .63214 Mdot
.35002 .51083 Mdot
.60488 .43804 Mdot
.44804 .65611 Mdot
.66027 .43851 Mdot
.21968 .57069 Mdot
.59743 .32475 Mdot
.50697 .67976 Mdot
.57825 .38611 Mdot
.51555 .50235 Mdot
.32517 .55384 Mdot
.64954 .44192 Mdot
.59894 .78972 Mdot
.56654 .65368 Mdot
.60509 .38981 Mdot
.36111 .50374 Mdot
.8265 .41429 Mdot
.65143 .47038 Mdot
.44653 .34401 Mdot
.3606 .47587 Mdot
.35469 .27566 Mdot
.34847 .35992 Mdot
.63486 .48925 Mdot
.36858 .17947 Mdot
.40482 .27839 Mdot
.44994 .63802 Mdot
.41261 .23559 Mdot
.40415 .34711 Mdot
.56046 .70159 Mdot
.63379 .73789 Mdot
.37 .79731 Mdot
.41586 .3145 Mdot
.47448 .64188 Mdot
.43907 .29702 Mdot
.59581 .64216 Mdot
.43252 .28294 Mdot
.43687 .64601 Mdot
.63195 .43716 Mdot
.40482 .6344 Mdot
.58785 .68313 Mdot
.6961 .26931 Mdot
.35848 .45435 Mdot
.38598 .65821 Mdot
.34114 .50607 Mdot
.64829 .63103 Mdot
.69301 .69127 Mdot
.32007 .50781 Mdot
.51951 .25773 Mdot
.58637 .42226 Mdot
.4086 .3564 Mdot
.39975 .63978 Mdot
.55664 .77164 Mdot
.42619 .42737 Mdot
.42209 .33492 Mdot
.44379 .66539 Mdot
.35872 .35534 Mdot
.46025 .24931 Mdot
.60297 .40888 Mdot
.62679 .5767 Mdot
.43604 .33488 Mdot
.47066 .63133 Mdot
.6958 .24215 Mdot
.43615 .295 Mdot
.39264 .64189 Mdot
.31557 .48402 Mdot
.34312 .47444 Mdot
.595 .42719 Mdot
.30035 .48425 Mdot
.45796 .65204 Mdot
.38624 .52419 Mdot
.46797 .36096 Mdot
.37157 .26142 Mdot
.57378 .69091 Mdot
.41578 .63225 Mdot
.6719 .45849 Mdot
.39084 .31935 Mdot
.28253 .56187 Mdot
.53683 .32794 Mdot
.45823 .16902 Mdot
.40324 .63995 Mdot
.41662 .32638 Mdot
.44829 .34137 Mdot
.56315 .42784 Mdot
.36298 .34421 Mdot
.47499 .70801 Mdot
.50482 .4027 Mdot
.49386 .40492 Mdot
.40802 .60793 Mdot
.36856 .65375 Mdot
.67543 .49544 Mdot
.60292 .44901 Mdot
.34023 .46174 Mdot
.62854 .43677 Mdot
.46921 .33866 Mdot
.57483 .4484 Mdot
.32837 .50695 Mdot
.44128 .62954 Mdot
.64801 .47175 Mdot
.565 .64533 Mdot
.30446 .50049 Mdot
.38007 .48419 Mdot
.41568 .62705 Mdot
.42373 .36149 Mdot
.54188 .55412 Mdot
.40848 .6514 Mdot
.59819 .44884 Mdot
.48053 .56286 Mdot
.64754 .49454 Mdot
.6382 .54985 Mdot
.42848 .2933 Mdot
.44829 .6219 Mdot
.46523 .31472 Mdot
.34158 .49996 Mdot
.62209 .73058 Mdot
.62286 .45098 Mdot
.39387 .63612 Mdot
.33636 .57178 Mdot
.62228 .55907 Mdot
.4406 .38938 Mdot
.27267 .66444 Mdot
.3969 .33132 Mdot
.42385 .66935 Mdot
.16977 .50508 Mdot
.60076 .66796 Mdot
.44707 .6753 Mdot
.74289 .7131 Mdot
.42456 .61702 Mdot
.58805 .43508 Mdot
.58128 .48418 Mdot
.45183 .6277 Mdot
.56224 .64119 Mdot
.78208 .34059 Mdot
.39867 .68999 Mdot
.41426 .31972 Mdot
.21727 .60277 Mdot
.55171 .16231 Mdot
.33601 .54589 Mdot
.34064 .4625 Mdot
.547 .48388 Mdot
.57021 .43967 Mdot
.36743 .49679 Mdot
.37142 .45393 Mdot
.60597 .66942 Mdot
.39674 .65164 Mdot
.38941 .31445 Mdot
.37296 .50897 Mdot
.37498 .35102 Mdot
.55347 .72859 Mdot
.56297 .4314 Mdot
.23266 .37099 Mdot
.60881 .51083 Mdot
.6653 .69403 Mdot
.32907 .50932 Mdot
.66092 .485 Mdot
.60643 .40414 Mdot
.36994 .4789 Mdot
.58711 .67053 Mdot
.38761 .56426 Mdot
.41911 .64288 Mdot
.70724 .78765 Mdot
.65496 .42511 Mdot
.57831 .44745 Mdot
.36113 .49132 Mdot
.45951 .74977 Mdot
.42605 .32375 Mdot
.40052 .31634 Mdot
.4547 .636 Mdot
.41171 .4376 Mdot
.58465 .4303 Mdot
.64237 .43787 Mdot
.42291 .64915 Mdot
.40329 .67234 Mdot
.30241 .66588 Mdot
.58223 .47107 Mdot
.35384 .48516 Mdot
.58655 .60503 Mdot
.33231 .51246 Mdot
.65345 .48939 Mdot
.57728 .45193 Mdot
.57322 .49303 Mdot
.66926 .4657 Mdot
.36235 .44645 Mdot
.64472 .50243 Mdot
.67996 .42666 Mdot
.41798 .3295 Mdot
.63165 .49492 Mdot
.4879 .40766 Mdot
.62136 .43705 Mdot
.58435 .66893 Mdot
.58614 .22138 Mdot
.65079 .47101 Mdot
.57116 .45164 Mdot
.40412 .68433 Mdot
.63383 .45422 Mdot
.36989 .46192 Mdot
.44148 .32674 Mdot
.36172 .48471 Mdot
.36102 .46018 Mdot
.4486 .60837 Mdot
.59442 .62877 Mdot
.5915 .51422 Mdot
.57562 .67852 Mdot
.55687 .42563 Mdot
.65303 .43255 Mdot
.5905 .72903 Mdot
.25741 .2681 Mdot
.65471 .23341 Mdot
.62155 .44929 Mdot
.42549 .61335 Mdot
.41685 .61156 Mdot
.55655 .5456 Mdot
.61566 .40901 Mdot
.35393 .51835 Mdot
.35174 .45805 Mdot
.76821 .44268 Mdot
.77773 .54728 Mdot
.58488 .66944 Mdot
.47453 .53564 Mdot
.63034 .41573 Mdot
.66289 .4798 Mdot
.66152 .42901 Mdot
.44846 .6136 Mdot
.53799 .39713 Mdot
.43416 .67861 Mdot
.2457 .44959 Mdot
.3509 .50641 Mdot
.64375 .48127 Mdot
.22162 .40923 Mdot
.45233 .36878 Mdot
.44254 .32706 Mdot
.37775 .49472 Mdot
.44747 .59516 Mdot
.76669 .35837 Mdot
.42017 .83907 Mdot
.43229 .27678 Mdot
.57484 .68599 Mdot
.64448 .43391 Mdot
.43641 .62332 Mdot
.46345 .33527 Mdot
.57521 .68555 Mdot
.65792 .47308 Mdot
.52482 .71058 Mdot
.6165 .44458 Mdot
.27836 .33657 Mdot
.44143 .30699 Mdot
.57339 .84048 Mdot
.47361 .35808 Mdot
.30342 .50761 Mdot
.3508 .51489 Mdot
.57744 .46926 Mdot
.4606 .2702 Mdot
.40102 .34152 Mdot
.44626 .5719 Mdot
.59596 .63391 Mdot
.27254 .51918 Mdot
.59856 .65911 Mdot
.44637 .64427 Mdot
.59443 .67371 Mdot
.43689 .6483 Mdot
.75261 .34714 Mdot
.38565 .29558 Mdot
.57842 .64652 Mdot
.3326 .56572 Mdot
.56638 .44504 Mdot
.55703 .66475 Mdot
.68056 .44217 Mdot
.61176 .5532 Mdot
.42003 .64975 Mdot
.59554 .63635 Mdot
.66391 .46934 Mdot
.81158 .57655 Mdot
.31522 .49997 Mdot
.35334 .51737 Mdot
.67971 .4409 Mdot
.41752 .60271 Mdot
.44507 .29398 Mdot
.52132 .82871 Mdot
.34465 .53035 Mdot
.57552 .47606 Mdot
.56687 .47882 Mdot
.39915 .34009 Mdot
.19645 .42983 Mdot
.57808 .4596 Mdot
.70603 .46145 Mdot
.58104 .47297 Mdot
.32047 .5167 Mdot
.40714 .31357 Mdot
.44676 .3351 Mdot
.44509 .66371 Mdot
.45198 .3735 Mdot
.59571 .5809 Mdot
.23583 .41602 Mdot
.66033 .52453 Mdot
.3371 .4993 Mdot
.25679 .42754 Mdot
.24116 .45322 Mdot
.74782 .69419 Mdot
.45403 .3854 Mdot
.63894 .51066 Mdot
.44756 .37762 Mdot
.59595 .66005 Mdot
.45367 .33173 Mdot
.47236 .34083 Mdot
.64823 .45319 Mdot
.63153 .48767 Mdot
.44588 .63303 Mdot
.3677 .36355 Mdot
.42316 .36411 Mdot
.59855 .49872 Mdot
.55915 .4676 Mdot
.66555 .44554 Mdot
.47721 .58062 Mdot
.40452 .3246 Mdot
.2161 .65382 Mdot
.73546 .53629 Mdot
.42279 .36325 Mdot
.79888 .32062 Mdot
.32024 .57104 Mdot
.3867 .60206 Mdot
.40556 .55902 Mdot
.58301 .47669 Mdot
.38701 .65258 Mdot
.63698 .48306 Mdot
.23359 .3714 Mdot
.638 .46013 Mdot
.58216 .67093 Mdot
.65565 .43023 Mdot
.46597 .64373 Mdot
.40598 .64382 Mdot
.5721 .46923 Mdot
.64521 .47289 Mdot
.719 .28702 Mdot
.45197 .28541 Mdot
.44213 .32157 Mdot
.47085 .7021 Mdot
.5793 .6407 Mdot
.35518 .5084 Mdot
.61601 .46607 Mdot
.44842 .60951 Mdot
.4052 .64125 Mdot
.4027 .33752 Mdot
.42235 .66332 Mdot
.32566 .49591 Mdot
.62285 .45523 Mdot
.36493 .50277 Mdot
.59875 .67766 Mdot
.40645 .31719 Mdot
.63297 .49275 Mdot
.59706 .44116 Mdot
.43505 .31316 Mdot
.6325 .51834 Mdot
.56292 .64251 Mdot
.4182 .61827 Mdot
.41657 .31182 Mdot
.33642 .48383 Mdot
.44428 .6455 Mdot
.6264 .5056 Mdot
.32794 .21279 Mdot
.59446 .43205 Mdot
.59043 .48614 Mdot
.7736 .69091 Mdot
.63712 .41708 Mdot
.40143 .64077 Mdot
.46504 .33981 Mdot
.64432 .38601 Mdot
.71952 .58446 Mdot
.62842 .86139 Mdot
.4395 .67704 Mdot
.63829 .42994 Mdot
.77254 .64946 Mdot
.63352 .43021 Mdot
.54042 .36114 Mdot
.38013 .6499 Mdot
.49512 .48037 Mdot
.67106 .47638 Mdot
.33492 .47393 Mdot
.44683 .62753 Mdot
.43534 .65238 Mdot
.20882 .57172 Mdot
.64776 .44756 Mdot
.43918 .54004 Mdot
.65411 .48226 Mdot
.33535 .48175 Mdot
.76329 .48374 Mdot
.40468 .64455 Mdot
.49961 .17596 Mdot
.58913 .4728 Mdot
.40959 .34111 Mdot
.4317 .68533 Mdot
.27767 .47426 Mdot
.61868 .50448 Mdot
.56492 .66884 Mdot
.38653 .47167 Mdot
.67895 .50134 Mdot
.33394 .49863 Mdot
.62723 .5032 Mdot
.65867 .3813 Mdot
.37013 .23348 Mdot
.45235 .3176 Mdot
.3241 .47372 Mdot
.49621 .57378 Mdot
.64559 .50436 Mdot
.41696 .31308 Mdot
.42158 .3316 Mdot
.59557 .68058 Mdot
.49426 .5237 Mdot
.33024 .32966 Mdot
.61919 .34507 Mdot
.21272 .58738 Mdot
.42019 .68471 Mdot
.34898 .68233 Mdot
.59955 .48818 Mdot
.56549 .59551 Mdot
.36746 .45982 Mdot
.59736 .42941 Mdot
.6402 .25995 Mdot
.44659 .36774 Mdot
.59504 .43539 Mdot
.5773 .66057 Mdot
.51872 .63587 Mdot
.58553 .60225 Mdot
.66786 .73198 Mdot
.43617 .63203 Mdot
.67531 .42034 Mdot
.67581 .39551 Mdot
.40336 .61541 Mdot
.56149 .48417 Mdot
.39738 .63312 Mdot
.28318 .71832 Mdot
.55919 .67244 Mdot
.40672 .3255 Mdot
.2919 .53942 Mdot
.5756 .50363 Mdot
.57328 .44024 Mdot
.60123 .63545 Mdot
.60088 .4534 Mdot
.34289 .23065 Mdot
.48307 .5852 Mdot
.44645 .65251 Mdot
.45338 .31649 Mdot
.56343 .48177 Mdot
.50788 .5645 Mdot
.62476 .42901 Mdot
.69491 .34352 Mdot
.56993 .45414 Mdot
.34689 .3443 Mdot
.44447 .31226 Mdot
.33489 .50386 Mdot
.65805 .49357 Mdot
.6333 .466 Mdot
.75055 .59287 Mdot
.54768 .45317 Mdot
.65622 .49309 Mdot
.45601 .39541 Mdot
.46255 .32495 Mdot
.43616 .29707 Mdot
.45189 .66725 Mdot
.7904 .50786 Mdot
.3486 .4911 Mdot
.60965 .38332 Mdot
.34992 .52591 Mdot
.51175 .32033 Mdot
.57002 .68288 Mdot
.72095 .69318 Mdot
.61037 .47777 Mdot
.45822 .34845 Mdot
.52686 .8086 Mdot
.41239 .29635 Mdot
.4601 .52268 Mdot
.35677 .47386 Mdot
.43703 .36354 Mdot
.62791 .47162 Mdot
.41354 .41934 Mdot
.78499 .62662 Mdot
.351 .49603 Mdot
.5526 .44126 Mdot
.46297 .661 Mdot
.52044 .67469 Mdot
.41194 .20192 Mdot
.31493 .50262 Mdot
.30238 .531 Mdot
.64816 .44523 Mdot
.45746 .36575 Mdot
.33282 .47818 Mdot
.32362 .51716 Mdot
.42588 .66443 Mdot
.62849 .48973 Mdot
.62375 .49125 Mdot
.42687 .67075 Mdot
.36149 .48675 Mdot
.67185 .42109 Mdot
.6792 .50486 Mdot
.84201 .49861 Mdot
.35233 .3166 Mdot
.71355 .78785 Mdot
.5623 .55445 Mdot
.59198 .24025 Mdot
.52145 .83255 Mdot
.4162 .35643 Mdot
.65838 .44936 Mdot
.62637 .52936 Mdot
.45813 .65251 Mdot
.63037 .44636 Mdot
.38502 .619 Mdot
.36057 .46739 Mdot
.82337 .41421 Mdot
.29547 .39857 Mdot
.32794 .7625 Mdot
.63257 .44684 Mdot
.42373 .39075 Mdot
.59208 .65628 Mdot
.31391 .53901 Mdot
.41488 .30202 Mdot
.67218 .45038 Mdot
.71464 .28312 Mdot
.44333 .67688 Mdot
.42286 .34903 Mdot
.76151 .31579 Mdot
.50566 .46495 Mdot
.64842 .49317 Mdot
.43733 .67436 Mdot
.57245 .80729 Mdot
.39662 .26319 Mdot
.32756 .5302 Mdot
.58734 .67157 Mdot
.44631 .6227 Mdot
.34857 .45758 Mdot
.38723 .33978 Mdot
.43097 .35422 Mdot
.43399 .28749 Mdot
.64001 .23356 Mdot
.38789 .67011 Mdot
.59012 .65292 Mdot
.77502 .58871 Mdot
.76753 .56732 Mdot
.57803 .66887 Mdot
.46476 .63314 Mdot
.46325 .32835 Mdot
.44508 .36303 Mdot
.44097 .32697 Mdot
.58627 .19369 Mdot
.44862 .38094 Mdot
.18653 .52312 Mdot
.66763 .4529 Mdot
.68814 .50061 Mdot
.63916 .43177 Mdot
.35974 .51317 Mdot
.43213 .30848 Mdot
.43949 .43366 Mdot
.57539 .40839 Mdot
.7245 .67218 Mdot
.59147 .43062 Mdot
.31092 .47575 Mdot
.58965 .4435 Mdot
.23413 .33991 Mdot
.44146 .37712 Mdot
.6249 .44817 Mdot
.33623 .45684 Mdot
.58069 .63735 Mdot
.44098 .39017 Mdot
.63711 .48853 Mdot
.3096 .70321 Mdot
.64531 .421 Mdot
.32804 .75454 Mdot
.33845 .27589 Mdot
.57343 .68523 Mdot
.27453 .31452 Mdot
.47662 .65185 Mdot
.70135 .47487 Mdot
.54812 .42612 Mdot
.3453 .5019 Mdot
.28067 .52755 Mdot
.42536 .62999 Mdot
.52103 .40943 Mdot
.69255 .45684 Mdot
.5953 .68265 Mdot
.40215 .26731 Mdot
.37007 .49154 Mdot
.56016 .47802 Mdot
.59721 .40775 Mdot
.21819 .50828 Mdot
.68685 .44931 Mdot
.56541 .46915 Mdot
.60499 .63553 Mdot
.19204 .50225 Mdot
.61652 .43667 Mdot
.46733 .52755 Mdot
.4353 .28271 Mdot
.59367 .39556 Mdot
.18359 .50968 Mdot
.58288 .48698 Mdot
.42698 .3573 Mdot
.69853 .4984 Mdot
.31946 .3214 Mdot
.59252 .62724 Mdot
.57019 .4528 Mdot
.185 .41323 Mdot
.59024 .46384 Mdot
.34932 .48638 Mdot
.61166 .40973 Mdot
.43616 .64352 Mdot
.65425 .22803 Mdot
.45069 .65837 Mdot
.60021 .4203 Mdot
.43879 .32851 Mdot
.35733 .4981 Mdot
.53235 .19053 Mdot
.4966 .71609 Mdot
.198 .479 Mdot
.4315 .8312 Mdot
.59018 .63011 Mdot
.54152 .66322 Mdot
.37363 .47649 Mdot
.62368 .44647 Mdot
.17401 .5539 Mdot
.54759 .47381 Mdot
.60351 .4331 Mdot
.63857 .46133 Mdot
.68709 .69292 Mdot
.3596 .46268 Mdot
.41427 .64972 Mdot
.57765 .45578 Mdot
.64928 .49947 Mdot
.41433 .35171 Mdot
.57204 .64294 Mdot
.40339 .61747 Mdot
.56981 .65402 Mdot
.44314 .62471 Mdot
.8103 .3655 Mdot
.6413 .40572 Mdot
.58592 .63691 Mdot
.38439 .4846 Mdot
.42099 .35574 Mdot
.24101 .41098 Mdot
.44085 .65023 Mdot
.45304 .66326 Mdot
.56983 .46451 Mdot
.42976 .36196 Mdot
.46534 .31777 Mdot
.5972 .6523 Mdot
.32121 .50419 Mdot
.65118 .46991 Mdot
.64397 .42394 Mdot
.71326 .41737 Mdot
.43043 .60157 Mdot
.27005 .34119 Mdot
.3505 .70069 Mdot
.62119 .44703 Mdot
.46833 .35888 Mdot
.64503 .46759 Mdot
.41519 .78699 Mdot
.45389 .37006 Mdot
.58715 .4918 Mdot
.76314 .2809 Mdot
.41066 .58777 Mdot
.2947 .35466 Mdot
.57221 .48636 Mdot
.5074 .85241 Mdot
.60333 .48406 Mdot
.83301 .41799 Mdot
.51326 .78916 Mdot
.59363 .41884 Mdot
.61357 .50585 Mdot
.56598 .32182 Mdot
.64272 .42823 Mdot
.43339 .67045 Mdot
.79637 .41722 Mdot
.42498 .28859 Mdot
.24729 .48513 Mdot
.59945 .22889 Mdot
.58458 .62434 Mdot
.4546 .63575 Mdot
.36986 .64665 Mdot
.57124 .66417 Mdot
.44013 .33612 Mdot
.61357 .4483 Mdot
.43189 .46458 Mdot
.42273 .60399 Mdot
.52952 .49643 Mdot
.34991 .4839 Mdot
.28911 .60011 Mdot
.52535 .61418 Mdot
.33084 .49733 Mdot
.62829 .49649 Mdot
.5509 .31911 Mdot
.73034 .33655 Mdot
.66229 .79265 Mdot
.34112 .45923 Mdot
.35193 .49725 Mdot
.62038 .20682 Mdot
.594 .69221 Mdot
.22408 .51799 Mdot
.34873 .35305 Mdot
.3579 .50274 Mdot
.41776 .26123 Mdot
.41435 .67325 Mdot
.3263 .45178 Mdot
.64249 .393 Mdot
.66002 .4428 Mdot
.62933 .46966 Mdot
.32501 .51102 Mdot
.60348 .56175 Mdot
.40439 .23088 Mdot
.34133 .50769 Mdot
.54204 .4906 Mdot
.48042 .48091 Mdot
.35189 .62311 Mdot
.41113 .66067 Mdot
.60064 .63976 Mdot
.56672 .69195 Mdot
.41066 .33368 Mdot
.59771 .63404 Mdot
.53428 .61763 Mdot
.60555 .4576 Mdot
.33886 .51301 Mdot
.27746 .54507 Mdot
.34265 .47801 Mdot
.57174 .66042 Mdot
.60424 .68043 Mdot
.41851 .32893 Mdot
.44736 .32408 Mdot
.57428 .25785 Mdot
.67932 .56137 Mdot
.61409 .42515 Mdot
.58365 .75361 Mdot
.47178 .33439 Mdot
.53296 .51249 Mdot
.60088 .63875 Mdot
.57827 .63933 Mdot
.74248 .6099 Mdot
.61458 .47793 Mdot
.50405 .34738 Mdot
.61556 .47336 Mdot
.74735 .50362 Mdot
.59863 .50807 Mdot
.42493 .66437 Mdot
.61475 .48519 Mdot
.74357 .61966 Mdot
.6027 .52183 Mdot
.5701 .43492 Mdot
.44833 .61178 Mdot
.69058 .483 Mdot
.43421 .64308 Mdot
.60636 .42088 Mdot
.5524 .67415 Mdot
.45723 .63915 Mdot
.70753 .60174 Mdot
.72713 .62992 Mdot
.4661 .63294 Mdot
.57959 .68228 Mdot
.5632 .63494 Mdot
.68643 .63866 Mdot
.4143 .30235 Mdot
.53758 .46054 Mdot
.62599 .44515 Mdot
.41533 .67812 Mdot
.35057 .46006 Mdot
.61566 .50817 Mdot
.56288 .45804 Mdot
.58438 .49772 Mdot
.40991 .33461 Mdot
.48029 .70655 Mdot
.59084 .63802 Mdot
.4242 .67206 Mdot
.54233 .55768 Mdot
.41068 .60502 Mdot
.58854 .41126 Mdot
.62498 .5285 Mdot
.62013 .2442 Mdot
.3503 .59855 Mdot
.58184 .18626 Mdot
.42942 .35263 Mdot
.41707 .61037 Mdot
.56838 .68901 Mdot
.60987 .52948 Mdot
.45949 .3497 Mdot
.43637 .64574 Mdot
.6168 .4454 Mdot
.55093 .45709 Mdot
.23284 .44745 Mdot
.60981 .59413 Mdot
.71929 .62103 Mdot
.4603 .65824 Mdot
.46948 .65791 Mdot
.71801 .65423 Mdot
.55364 .62577 Mdot
.42877 .42891 Mdot
.6399 .4416 Mdot
.56522 .66794 Mdot
.46337 .33836 Mdot
.66093 .25373 Mdot
.33794 .5196 Mdot
.36468 .35008 Mdot
.63159 .44825 Mdot
.5094 .49988 Mdot
.4366 .3274 Mdot
.57862 .66308 Mdot
.32696 .51326 Mdot
.54606 .68273 Mdot
.43497 .60813 Mdot
.34904 .796 Mdot
.59337 .45808 Mdot
.57001 .45941 Mdot
.31098 .4811 Mdot
.45446 .36243 Mdot
.58394 .61974 Mdot
.22331 .61424 Mdot
.43182 .65837 Mdot
.16881 .53437 Mdot
.46716 .35852 Mdot
.62994 .36116 Mdot
.40952 .66615 Mdot
.37076 .50864 Mdot
.69004 .62086 Mdot
.32694 .50079 Mdot
.59339 .4247 Mdot
.45335 .34544 Mdot
.32909 .471 Mdot
.36182 .30657 Mdot
.79416 .63352 Mdot
.6312 .36004 Mdot
.61057 .45885 Mdot
.82397 .53414 Mdot
.30845 .7256 Mdot
.43914 .27571 Mdot
.36253 .457 Mdot
.5964 .42877 Mdot
.57092 .44699 Mdot
.58937 .46187 Mdot
.34507 .46393 Mdot
.59076 .74632 Mdot
.42206 .65198 Mdot
.64542 .43849 Mdot
.60543 .67164 Mdot
.43061 .63758 Mdot
.28517 .51383 Mdot
.40919 .65667 Mdot
.46763 .38106 Mdot
.5754 .41875 Mdot
.27122 .46855 Mdot
.77456 .25968 Mdot
.3572 .49056 Mdot
.45512 .61378 Mdot
.64664 .4105 Mdot
.30937 .58886 Mdot
.44979 .30615 Mdot
.43305 .65989 Mdot
.57953 .44512 Mdot
.32684 .56068 Mdot
.68269 .2572 Mdot
.40676 .65217 Mdot
.46055 .34972 Mdot
.66965 .78473 Mdot
.63021 .44057 Mdot
.5995 .47614 Mdot
.43719 .35938 Mdot
.49331 .25799 Mdot
.71396 .261 Mdot
.64496 .47119 Mdot
.33438 .50535 Mdot
.25872 .737 Mdot
.56302 .45578 Mdot
.75888 .50795 Mdot
.44721 .63053 Mdot
.32701 .44283 Mdot
.30614 .31618 Mdot
.59767 .52588 Mdot
.22098 .56053 Mdot
.31721 .54708 Mdot
.80115 .56287 Mdot
.38864 .61423 Mdot
.40594 .74225 Mdot
.80926 .51013 Mdot
.33649 .45488 Mdot
.42139 .4 Mdot
.22411 .58389 Mdot
.48433 .21094 Mdot
.61257 .80073 Mdot
.4495 .76417 Mdot
.71439 .28134 Mdot
.44409 .46192 Mdot
.4326 .61645 Mdot
.52418 .50498 Mdot
.6382 .48428 Mdot
.31525 .73137 Mdot
.3647 .24793 Mdot
.37951 .24128 Mdot
.82498 .53598 Mdot
.55659 .36088 Mdot
.77524 .64319 Mdot
.75588 .69349 Mdot
.74196 .45046 Mdot
.36361 .69864 Mdot
.16724 .54314 Mdot
.79195 .37306 Mdot
.2235 .64474 Mdot
.68203 .50932 Mdot
.4511 .52329 Mdot
.37438 .78642 Mdot
.38386 .34556 Mdot
.45038 .24852 Mdot
.44203 .66334 Mdot
.42228 .29403 Mdot
.22748 .53809 Mdot
.39701 .33593 Mdot
.31794 .31783 Mdot
.68853 .77953 Mdot
.78955 .64162 Mdot
.19398 .41438 Mdot
.52275 .84219 Mdot
.62762 .25657 Mdot
.12905 .49613 Mdot
.38846 .62908 Mdot
.40515 .34418 Mdot
.67682 .68799 Mdot
.75682 .61099 Mdot
.27023 .43653 Mdot
.24757 .64393 Mdot
.54526 .7108 Mdot
.6476 .60811 Mdot
.44605 .34206 Mdot
.28372 .31152 Mdot
.29796 .47661 Mdot
.28868 .40616 Mdot
.78903 .39111 Mdot
.67795 .75862 Mdot
.42661 .47112 Mdot
.25607 .63326 Mdot
.31241 .62161 Mdot
.43932 .20558 Mdot
.72433 .55735 Mdot
.53505 .52201 Mdot
.34846 .32175 Mdot
.49246 .82834 Mdot
.50249 .2291 Mdot
.74358 .49883 Mdot
.76459 .59621 Mdot
.79491 .34457 Mdot
.37618 .7619 Mdot
.61625 .16202 Mdot
.39471 .31814 Mdot
.56606 .47921 Mdot
.51716 .26643 Mdot
.17436 .43685 Mdot
.61202 .67041 Mdot
.65264 .74363 Mdot
.60262 .64964 Mdot
.47491 .36535 Mdot
.68655 .24906 Mdot
.18717 .50251 Mdot
.15679 .4719 Mdot
.54666 .67015 Mdot
.61932 .38164 Mdot
.47037 .88826 Mdot
.76688 .62914 Mdot
.28595 .38264 Mdot
.83819 .48442 Mdot
.48502 .4542 Mdot
.36622 .26535 Mdot
.3338 .46718 Mdot
.81584 .4893 Mdot
.44771 .35719 Mdot
.6208 .15248 Mdot
.83187 .40739 Mdot
.66294 .26568 Mdot
.91182 .57521 Mdot
.70229 .67437 Mdot
.49784 .48267 Mdot
.37287 .53429 Mdot
.69341 .58102 Mdot
.42145 .22614 Mdot
.6303 .70174 Mdot
.31089 .59683 Mdot
.49006 .86052 Mdot
.81451 .53634 Mdot
.15714 .49781 Mdot
.29829 .75283 Mdot
.47789 .22248 Mdot
.50436 .56068 Mdot
.55994 .39967 Mdot
.50436 .6464 Mdot
.63655 .7663 Mdot
.79909 .33851 Mdot
.73725 .53713 Mdot
.61932 .86668 Mdot
.58297 .61509 Mdot
.53617 .73239 Mdot
.73043 .75492 Mdot
.65985 .61742 Mdot
.31096 .29417 Mdot
.77934 .49534 Mdot
.5435 .40124 Mdot
.55941 .57561 Mdot
.65001 .7526 Mdot
.2646 .36919 Mdot
.80185 .44126 Mdot
.56203 .82261 Mdot
.2181 .5049 Mdot
.61479 .3295 Mdot
.76957 .54092 Mdot
.39545 .35421 Mdot
.64089 .57862 Mdot
.31354 .30538 Mdot
.81083 .61737 Mdot
.31426 .46755 Mdot
.82836 .60946 Mdot
.71993 .2687 Mdot
.65254 .4089 Mdot
.5467 .49049 Mdot
.50353 .38157 Mdot
.64963 .58076 Mdot
.69672 .46313 Mdot
.22778 .46464 Mdot
.78662 .66188 Mdot
.72023 .34202 Mdot
.31623 .55235 Mdot
.28289 .53156 Mdot
.72302 .76591 Mdot
.54272 .2799 Mdot
.54799 .63405 Mdot
.77909 .41545 Mdot
.43785 .21371 Mdot
.42075 .63433 Mdot
.16184 .49694 Mdot
.36561 .5218 Mdot
.67659 .2591 Mdot
.61241 .34576 Mdot
.5486 .21883 Mdot
.78706 .66218 Mdot
.40849 .73495 Mdot
.70617 .26426 Mdot
.65204 .64578 Mdot
.19327 .60152 Mdot
.35235 .61531 Mdot
.66438 .50921 Mdot
.26093 .65809 Mdot
.55941 .64388 Mdot
.5837 .29079 Mdot
.22751 .68891 Mdot
.48629 .75433 Mdot
.68221 .47382 Mdot
.66083 .26143 Mdot
.38073 .59388 Mdot
.409 .41994 Mdot
.50446 .15211 Mdot
.56312 .43986 Mdot
.77837 .57448 Mdot
.35583 .73966 Mdot
.6917 .5669 Mdot
.60677 .82378 Mdot
.44629 .80451 Mdot
.65984 .18245 Mdot
.829 .49744 Mdot
.48479 .7169 Mdot
.80363 .51431 Mdot
.82229 .56977 Mdot
.6583 .18663 Mdot
.54187 .46293 Mdot
.30263 .50983 Mdot
.31029 .2122 Mdot
.40862 .66021 Mdot
.75971 .62266 Mdot
.21246 .58699 Mdot
.51175 .6242 Mdot
.4812 .39642 Mdot
.51837 .43104 Mdot
.44385 .47016 Mdot
.45593 .29039 Mdot
.69608 .46022 Mdot
.57616 .16984 Mdot
.71818 .22658 Mdot
.60652 .16768 Mdot
.43642 .82151 Mdot
.81045 .47714 Mdot
.50984 .51863 Mdot
.18508 .43627 Mdot
.53901 .51719 Mdot
.66435 .46445 Mdot
.54184 .68616 Mdot
.69632 .67983 Mdot
.6308 .23761 Mdot
.32037 .39826 Mdot
.39589 .27454 Mdot
.65002 .7482 Mdot
.18472 .71159 Mdot
.59554 .26238 Mdot
.18677 .54669 Mdot
.53299 .64983 Mdot
.67859 .56435 Mdot
.61542 .76472 Mdot
.58624 .2181 Mdot
.76521 .69387 Mdot
.45496 .2902 Mdot
.22219 .63258 Mdot
.48648 .77159 Mdot
.40994 .40048 Mdot
.48712 .7038 Mdot
.75996 .66311 Mdot
.25312 .48225 Mdot
.55482 .20184 Mdot
.35089 .37689 Mdot
.51548 .25382 Mdot
.46578 .58323 Mdot
.29423 .61745 Mdot
.21255 .65119 Mdot
.4218 .77787 Mdot
.7557 .5004 Mdot
.47469 .48282 Mdot
.2601 .32511 Mdot
.35467 .55802 Mdot
.74629 .51236 Mdot
.48507 .40981 Mdot
.78927 .53107 Mdot
.63045 .12268 Mdot
.50788 .16819 Mdot
.67797 .79762 Mdot
.59269 .75861 Mdot
.68369 .48488 Mdot
.749 .71685 Mdot
.57734 .14902 Mdot
.8079 .31633 Mdot
.27936 .62411 Mdot
.39631 .60899 Mdot
.3575 .52092 Mdot
.61363 .18839 Mdot
.5859 .74243 Mdot
.71714 .73758 Mdot
.75614 .53518 Mdot
.38203 .47897 Mdot
.23647 .28398 Mdot
.79368 .35183 Mdot
.63124 .35345 Mdot
.60934 .59118 Mdot
.66022 .50456 Mdot
.29982 .27559 Mdot
.39799 .3321 Mdot
.34018 .65784 Mdot
.69095 .55276 Mdot
.41187 .63372 Mdot
.64965 .70934 Mdot
.25567 .65911 Mdot
.65613 .43098 Mdot
.4989 .5686 Mdot
.43511 .38536 Mdot
.34825 .61073 Mdot
.25461 .41705 Mdot
.78215 .28854 Mdot
.52735 .65413 Mdot
.67311 .47009 Mdot
.70241 .56085 Mdot
.48965 .69682 Mdot
.6959 .24186 Mdot
.37425 .4729 Mdot
.81311 .5654 Mdot
.43323 .49917 Mdot
.64714 .57452 Mdot
.40683 .24833 Mdot
.59078 .55002 Mdot
.58002 .42732 Mdot
.48643 .81596 Mdot
.69423 .3307 Mdot
.3854 .40245 Mdot
.63743 .38947 Mdot
.54079 .51356 Mdot
.74098 .72539 Mdot
.52274 .63033 Mdot
.29847 .60688 Mdot
.80881 .5909 Mdot
.34772 .4677 Mdot
.44962 .37708 Mdot
.62567 .65227 Mdot
.23805 .6595 Mdot
.72382 .39111 Mdot
.68091 .25576 Mdot
.52175 .60899 Mdot
.49746 .7476 Mdot
.80656 .60621 Mdot
.80527 .57355 Mdot
.25469 .3016 Mdot
.42378 .26789 Mdot
.71743 .50761 Mdot
.2321 .6594 Mdot
.45952 .31549 Mdot
.20584 .50105 Mdot
.21045 .48267 Mdot
.81583 .38829 Mdot
.48827 .56809 Mdot
.50096 .86077 Mdot
.7182 .61695 Mdot
.63351 .74262 Mdot
.52902 .18887 Mdot
.2053 .62742 Mdot
.74357 .66591 Mdot
.4476 .27771 Mdot
.56712 .33458 Mdot
.66732 .51955 Mdot
.22164 .38399 Mdot
.30222 .2271 Mdot
.62426 .65735 Mdot
.49613 .39963 Mdot
.56838 .82237 Mdot
.60472 .44681 Mdot
.47431 .16481 Mdot
.24243 .64927 Mdot
.60832 .20138 Mdot
.38031 .4917 Mdot
.64079 .49523 Mdot
.57438 .50497 Mdot
.78675 .45539 Mdot
.31293 .32493 Mdot
.78919 .51901 Mdot
.26859 .73996 Mdot
.59134 .79726 Mdot
.41644 .25046 Mdot
.76136 .61371 Mdot
.67887 .76117 Mdot
.32412 .73623 Mdot
.48379 .51706 Mdot
.62391 .72307 Mdot
.67215 .61641 Mdot
.50728 .84023 Mdot
.46363 .41506 Mdot
.39714 .54284 Mdot
.24511 .46287 Mdot
.36186 .72098 Mdot
.60414 .21424 Mdot
.61712 .50083 Mdot
.76184 .31644 Mdot
.73663 .71163 Mdot
.28133 .283 Mdot
.3857 .21801 Mdot
.51603 .16634 Mdot
.67059 .33139 Mdot
.39005 .75746 Mdot
.29486 .70751 Mdot
.19591 .6425 Mdot
.42979 .50209 Mdot
.70391 .69169 Mdot
.66078 .63037 Mdot
.80763 .60042 Mdot
.30746 .48669 Mdot
.342 .35854 Mdot
.2844 .53891 Mdot
.79797 .51743 Mdot
.54558 .29219 Mdot
.76323 .67244 Mdot
.47478 .4471 Mdot
.66538 .18298 Mdot
.44663 .79314 Mdot
.45449 .45717 Mdot
.43756 .61066 Mdot
.42338 .742 Mdot
.68985 .72789 Mdot
.46127 .79156 Mdot
.19935 .60162 Mdot
.40289 .5931 Mdot
.5648 .56641 Mdot
.56235 .36887 Mdot
.62583 .58175 Mdot
.48217 .81734 Mdot
.70148 .56153 Mdot
.78412 .65356 Mdot
.79397 .45441 Mdot
.75858 .31375 Mdot
.709 .67132 Mdot
.41794 .8298 Mdot
.28669 .37859 Mdot
.58465 .59639 Mdot
.24723 .6526 Mdot
.54263 .74585 Mdot
.45771 .28586 Mdot
.34295 .14539 Mdot
.35299 .79344 Mdot
.41573 .76758 Mdot
.7994 .34169 Mdot
.4451 .80935 Mdot
.34808 .60057 Mdot
.4707 .24311 Mdot
.35717 .33592 Mdot
.7509 .32827 Mdot
.63746 .46158 Mdot
.56489 .16027 Mdot
.66579 .56113 Mdot
.75878 .25414 Mdot
.71381 .7468 Mdot
.49455 .39287 Mdot
.57784 .41758 Mdot
.42973 .67357 Mdot
.43088 .53614 Mdot
.75324 .46045 Mdot
.52211 .2991 Mdot
.33579 .27084 Mdot
.35928 .56615 Mdot
.38868 .63373 Mdot
.48589 .69169 Mdot
.4375 .27929 Mdot
.60385 .74243 Mdot
.35802 .71228 Mdot
.48822 .63539 Mdot
.41942 .47106 Mdot
.72378 .53401 Mdot
.29934 .31693 Mdot
.64302 .35662 Mdot
.59194 .21844 Mdot
.26443 .4735 Mdot
.42318 .66758 Mdot
.64067 .3493 Mdot
.37373 .79069 Mdot
.56924 .81162 Mdot
.79473 .33542 Mdot
.5491 .57548 Mdot
.53093 .32716 Mdot
.76175 .49625 Mdot
.40092 .22463 Mdot
.4742 .27948 Mdot
.36049 .58634 Mdot
.29799 .28023 Mdot
.47022 .2609 Mdot
.22824 .57758 Mdot
.82403 .41311 Mdot
.22312 .64158 Mdot
.23053 .65912 Mdot
.50046 .62853 Mdot
.71827 .43482 Mdot
.44649 .4001 Mdot
.71108 .607 Mdot
.41895 .42643 Mdot
.1451 .44703 Mdot
.60578 .38962 Mdot
.12649 .42351 Mdot
.3166 .51291 Mdot
.45093 .2246 Mdot
.67153 .62511 Mdot
.48141 .48982 Mdot
.47844 .4328 Mdot
.42842 .78504 Mdot
.34267 .34079 Mdot
.36472 .75577 Mdot
.3969 .239 Mdot
.38729 .62977 Mdot
.28846 .76559 Mdot
.4331 .84131 Mdot
.58709 .32986 Mdot
.64526 .41611 Mdot
.37429 .8058 Mdot
.39737 .61186 Mdot
.61681 .22945 Mdot
.61472 .81866 Mdot
.54458 .80268 Mdot
.53407 .38484 Mdot
.66621 .56946 Mdot
.70988 .6879 Mdot
.83145 .53582 Mdot
.28813 .25271 Mdot
.64333 .75431 Mdot
.30741 .48809 Mdot
.47597 .45991 Mdot
.73299 .69718 Mdot
.35026 .28091 Mdot
.30595 .47177 Mdot
.32783 .28025 Mdot
.11475 .49433 Mdot
.76321 .62158 Mdot
.78563 .52782 Mdot
.35065 .26848 Mdot
.47315 .35777 Mdot
.33587 .31764 Mdot
.30865 .29677 Mdot
.5181 .80302 Mdot
.3402 .76565 Mdot
.30914 .30185 Mdot
.15866 .58602 Mdot
.61277 .55364 Mdot
.36656 .67026 Mdot
.50668 .3884 Mdot
.73972 .42518 Mdot
.38153 .46936 Mdot
.77406 .36525 Mdot
.60303 .80054 Mdot
.30951 .52055 Mdot
.50238 .81942 Mdot
.25947 .6411 Mdot
.66979 .37591 Mdot
.71712 .38335 Mdot
.58292 .79112 Mdot
.54384 .30999 Mdot
.22328 .36046 Mdot
.68187 .27266 Mdot
.42291 .59552 Mdot
.63396 .79127 Mdot
.44426 .65176 Mdot
.52522 .48498 Mdot
.363 .32958 Mdot
.63311 .69787 Mdot
.59498 .19036 Mdot
.57888 .62498 Mdot
.40098 .3257 Mdot
.30005 .23325 Mdot
.46778 .34359 Mdot
.58956 .17175 Mdot
.55459 .21768 Mdot
.32281 .26248 Mdot
.48106 .72342 Mdot
.46467 .7467 Mdot
.12911 .53249 Mdot
.29155 .48099 Mdot
.49922 .6513 Mdot
.21014 .42668 Mdot
.40339 .3429 Mdot
.52662 .67365 Mdot
.4581 .62343 Mdot
.4096 .49974 Mdot
.2363 .5315 Mdot
.63595 .54774 Mdot
.38704 .32484 Mdot
.41403 .4864 Mdot
.76542 .38962 Mdot
.81697 .44469 Mdot
.39877 .62937 Mdot
.14936 .3975 Mdot
.57807 .42137 Mdot
.61039 .32319 Mdot
.77264 .68878 Mdot
.23192 .2897 Mdot
.43063 .71026 Mdot
.45204 .85436 Mdot
.64999 .50637 Mdot
.59774 .77011 Mdot
.44519 .35075 Mdot
.22586 .64008 Mdot
.60147 .65946 Mdot
.68713 .57306 Mdot
.32534 .52243 Mdot
.55054 .20098 Mdot
.41793 .71524 Mdot
.43952 .28991 Mdot
.56785 .77858 Mdot
.74104 .44958 Mdot
.39903 .48369 Mdot
.45447 .7223 Mdot
.59058 .33343 Mdot
.72195 .39658 Mdot
.38901 .29192 Mdot
.78452 .54436 Mdot
.23772 .6828 Mdot
.78724 .29049 Mdot
.4769 .39311 Mdot
.50917 .48114 Mdot
.22459 .48325 Mdot
.5316 .81658 Mdot
.2323 .38534 Mdot
.78667 .67131 Mdot
.72154 .52316 Mdot
.70786 .49225 Mdot
.74101 .51172 Mdot
.61194 .54207 Mdot
.46092 .49746 Mdot
.31951 .63377 Mdot
.35303 .24409 Mdot
.27669 .33856 Mdot
.48554 .23303 Mdot
.23267 .35858 Mdot
.7773 .53651 Mdot
.3245 .26515 Mdot
.47058 .61382 Mdot
.68897 .37762 Mdot
.32937 .54071 Mdot
.82125 .44811 Mdot
.78265 .67663 Mdot
.30299 .52856 Mdot
.51654 .68176 Mdot
.55247 .83884 Mdot
.55209 .48653 Mdot
.52539 .54687 Mdot
.57155 .45347 Mdot
.59657 .57524 Mdot
.20343 .32416 Mdot
.52794 .80819 Mdot
.68241 .45092 Mdot
.80854 .54768 Mdot
.81197 .51991 Mdot
.70508 .20798 Mdot
.1752 .56652 Mdot
.41762 .32423 Mdot
.66359 .19691 Mdot
.33067 .27233 Mdot
.83129 .5483 Mdot
.35108 .6393 Mdot
.79684 .68518 Mdot
.56694 .33075 Mdot
.52705 .82758 Mdot
.46128 .24536 Mdot
.35228 .34357 Mdot
.35929 .73522 Mdot
.51335 .5397 Mdot
.28221 .5776 Mdot
.41568 .79198 Mdot
.25148 .7444 Mdot
.64948 .52516 Mdot
.28929 .6858 Mdot
.27527 .44501 Mdot
.64805 .78618 Mdot
.4548 .78039 Mdot
.62589 .41182 Mdot
.27701 .52765 Mdot
.5876 .19764 Mdot
.72892 .53399 Mdot
.53412 .52862 Mdot
.44264 .7746 Mdot
.73047 .31665 Mdot
.75936 .48465 Mdot
.22512 .65292 Mdot
.58165 .33438 Mdot
.43579 .52437 Mdot
.64373 .50566 Mdot
.3938 .29983 Mdot
.56267 .62964 Mdot
.51284 .54966 Mdot
.60903 .42196 Mdot
.45543 .67407 Mdot
.39931 .46677 Mdot
.55609 .17104 Mdot
.27099 .36758 Mdot
.27167 .69413 Mdot
.39683 .36661 Mdot
.31328 .42129 Mdot
.22767 .40425 Mdot
.49213 .1776 Mdot
.51838 .77756 Mdot
.73686 .53774 Mdot
.77687 .62371 Mdot
.79843 .4579 Mdot
.38196 .35917 Mdot
.75426 .26964 Mdot
.36618 .45861 Mdot
.65372 .37029 Mdot
.33856 .40295 Mdot
.50314 .66306 Mdot
.66943 .40903 Mdot
.5265 .82686 Mdot
.51688 .62611 Mdot
.74923 .61762 Mdot
.37734 .76538 Mdot
.67128 .54374 Mdot
.5811 .35712 Mdot
.81158 .55943 Mdot
.43646 .67749 Mdot
.26425 .70387 Mdot
.391 .50962 Mdot
.44783 .77109 Mdot
.80568 .46542 Mdot
.80385 .35608 Mdot
.45329 .43759 Mdot
.67231 .60385 Mdot
.59402 .47657 Mdot
.21559 .6518 Mdot
.5211 .81112 Mdot
.57035 .38582 Mdot
.27528 .60312 Mdot
.45511 .37397 Mdot
.30331 .65043 Mdot
.44719 .52563 Mdot
.74687 .33298 Mdot
.41892 .37588 Mdot
.30883 .26825 Mdot
.5488 .66407 Mdot
.49691 .46264 Mdot
.68009 .4072 Mdot
.68408 .59383 Mdot
.15043 .51166 Mdot
.64496 .38946 Mdot
.64891 .75735 Mdot
.61054 .34131 Mdot
.22363 .61738 Mdot
.57962 .78842 Mdot
.34866 .58006 Mdot
.34349 .33817 Mdot
.70231 .38129 Mdot
.25074 .49354 Mdot
.57677 .4895 Mdot
.44122 .59402 Mdot
.44065 .29379 Mdot
.63291 .79752 Mdot
.68612 .33776 Mdot
.70502 .60316 Mdot
.47715 .58042 Mdot
.54055 .53254 Mdot
.36643 .53386 Mdot
.79125 .68536 Mdot
.34561 .33129 Mdot
.70612 .54066 Mdot
.48908 .56798 Mdot
.67591 .62058 Mdot
.54113 .225 Mdot
.83102 .39344 Mdot
.46088 .24217 Mdot
.42337 .45424 Mdot
.44403 .2268 Mdot
.40277 .76273 Mdot
.5989 .83067 Mdot
.7428 .50262 Mdot
.49164 .43784 Mdot
.60019 .62411 Mdot
.22986 .44358 Mdot
.45478 .57507 Mdot
.5431 .54762 Mdot
.41166 .50668 Mdot
.25147 .57063 Mdot
.33739 .42785 Mdot
.60515 .37908 Mdot
.72514 .65714 Mdot
.79015 .59961 Mdot
.21511 .59917 Mdot
.36256 .55828 Mdot
.37123 .69786 Mdot
.75055 .35371 Mdot
.80153 .6893 Mdot
.35442 .20603 Mdot
.59313 .47403 Mdot
.35381 .5481 Mdot
.65944 .5989 Mdot
.46501 .64805 Mdot
.28791 .3175 Mdot
.23646 .40056 Mdot
.31161 .49326 Mdot
.58937 .58994 Mdot
.76289 .58585 Mdot
.37121 .72797 Mdot
.62397 .59659 Mdot
.28757 .53067 Mdot
.53795 .16713 Mdot
.40848 .80993 Mdot
.5355 .81484 Mdot
.85856 .60616 Mdot
.38544 .53586 Mdot
.54067 .5003 Mdot
.5481 .26161 Mdot
.81211 .46097 Mdot
.70835 .56169 Mdot
.65749 .2465 Mdot
.31671 .57325 Mdot
.73893 .50447 Mdot
.47374 .30303 Mdot
.74061 .63641 Mdot
.29727 .64676 Mdot
.4604 .48001 Mdot
.46754 .75047 Mdot
.76475 .27378 Mdot
.54446 .37048 Mdot
.77832 .63213 Mdot
.55323 .18856 Mdot
.18684 .63272 Mdot
.81804 .47136 Mdot
.72421 .63145 Mdot
.49853 .78596 Mdot
.52124 .26853 Mdot
.48254 .40937 Mdot
.40412 .25943 Mdot
.62371 .23251 Mdot
.72361 .37414 Mdot
.5228 .71074 Mdot
.49672 .21653 Mdot
.75533 .50109 Mdot
.73074 .3713 Mdot
.4915 .43434 Mdot
.65436 .35683 Mdot
.51274 .68007 Mdot
.34252 .27723 Mdot
.43668 .41135 Mdot
.72382 .58089 Mdot
.62677 .34397 Mdot
.22486 .49676 Mdot
.43748 .8001 Mdot
.17774 .63862 Mdot
.57122 .75309 Mdot
.48553 .18438 Mdot
.66774 .4499 Mdot
.70485 .19302 Mdot
.37431 .74676 Mdot
.39159 .73699 Mdot
.35047 .75996 Mdot
.37038 .60028 Mdot
.55859 .52841 Mdot
.57718 .49 Mdot
.68259 .73157 Mdot
.53226 .38451 Mdot
.62716 .25191 Mdot
.5312 .19634 Mdot
.67837 .56986 Mdot
.75192 .54016 Mdot
.7137 .61241 Mdot
.70549 .48437 Mdot
.46405 .3578 Mdot
.61586 .17114 Mdot
.43326 .43925 Mdot
.56481 .38934 Mdot
.69408 .41203 Mdot
.51225 .25358 Mdot
.51957 .8704 Mdot
.48845 .39159 Mdot
.77827 .50713 Mdot
.56259 .35236 Mdot
.38962 .38089 Mdot
.23793 .36616 Mdot
.91894 .49235 Mdot
.74723 .21646 Mdot
.42987 .28806 Mdot
.18182 .53245 Mdot
.55971 .35697 Mdot
.79268 .52224 Mdot
.49562 .77175 Mdot
.25693 .59263 Mdot
.59608 .37379 Mdot
.37817 .37816 Mdot
.69073 .42948 Mdot
.34869 .74164 Mdot
.82774 .44238 Mdot
.50902 .19892 Mdot
.80807 .55042 Mdot
.61184 .545 Mdot
.67961 .41187 Mdot
.84343 .65305 Mdot
.74211 .68738 Mdot
.56149 .43122 Mdot
.43538 .23914 Mdot
.57717 .39319 Mdot
.63604 .48147 Mdot
.62774 .73295 Mdot
.288 .76403 Mdot
.76324 .49259 Mdot
.79751 .51797 Mdot
.40021 .35143 Mdot
.36915 .62178 Mdot
.31715 .51446 Mdot
.46119 .43529 Mdot
.56314 .42151 Mdot
.33213 .47032 Mdot
.67662 .54693 Mdot
.5591 .83023 Mdot
.44537 .56485 Mdot
.27439 .73458 Mdot
.83437 .61134 Mdot
.67708 .33964 Mdot
.23469 .43497 Mdot
.55724 .49486 Mdot
.73787 .41048 Mdot
.75412 .40301 Mdot
.57562 .56214 Mdot
.47819 .82828 Mdot
.43868 .10732 Mdot
.26795 .53624 Mdot
.76272 .3466 Mdot
.47604 .3403 Mdot
.42049 .51877 Mdot
.59868 .36046 Mdot
.35702 .62559 Mdot
.40692 .61778 Mdot
.63415 .5431 Mdot
.44142 .39126 Mdot
.38291 .49154 Mdot
.15989 .36456 Mdot
.65122 .4185 Mdot
.26257 .34364 Mdot
.82675 .55625 Mdot
.68078 .27139 Mdot
.5787 .30603 Mdot
.59608 .50995 Mdot
.28096 .41417 Mdot
.49162 .44119 Mdot
.63477 .77739 Mdot
.76477 .3264 Mdot
.78754 .58801 Mdot
.69056 .34007 Mdot
.57586 .35707 Mdot
.64811 .50081 Mdot
.59944 .68792 Mdot
.328 .44349 Mdot
.65733 .73724 Mdot
.56531 .40501 Mdot
.83521 .50694 Mdot
.40468 .71768 Mdot
.52468 .57905 Mdot
.49688 .37491 Mdot
.6972 .20586 Mdot
.52071 .23657 Mdot
.41772 .3931 Mdot
.50232 .17413 Mdot
.46881 .69948 Mdot
.62529 .5859 Mdot
.42952 .67527 Mdot
.54369 .44181 Mdot
.40402 .36568 Mdot
.48571 .15918 Mdot
.65398 .72678 Mdot
.28351 .57133 Mdot
.29181 .61263 Mdot
.20073 .55757 Mdot
.39803 .48242 Mdot
.86388 .58662 Mdot
.44704 .73 Mdot
.50514 .16283 Mdot
.24423 .68898 Mdot
.40825 .37427 Mdot
.45488 .80736 Mdot
.61801 .39058 Mdot
.40197 .63297 Mdot
.79977 .5596 Mdot
.52546 .44281 Mdot
.69046 .25473 Mdot
.63068 .51912 Mdot
.64124 .21298 Mdot
.60437 .62307 Mdot
.52618 .68622 Mdot
.40238 .75755 Mdot
.5156 .24996 Mdot
.71419 .76275 Mdot
.22728 .44884 Mdot
.74965 .72437 Mdot
.69188 .77645 Mdot
.8171 .55743 Mdot
.65359 .23489 Mdot
.25991 .27609 Mdot
.41253 .76096 Mdot
.57488 .79669 Mdot
.33427 .65434 Mdot
.49955 .25952 Mdot
.42093 .74336 Mdot
.50325 .37132 Mdot
.31157 .3281 Mdot
.32102 .54371 Mdot
.18063 .28392 Mdot
.75166 .56553 Mdot
.45173 .39524 Mdot
.4374 .74155 Mdot
.82143 .52323 Mdot
.52262 .26148 Mdot
.40641 .7884 Mdot
.45076 .52094 Mdot
.65763 .5137 Mdot
.71521 .3693 Mdot
.20789 .58979 Mdot
.42064 .72747 Mdot
.13687 .58941 Mdot
.38199 .79214 Mdot
.26808 .57469 Mdot
.45191 .49455 Mdot
.41944 .29438 Mdot
.21405 .38817 Mdot
.47412 .7419 Mdot
.46148 .82512 Mdot
.54021 .83001 Mdot
.73611 .69438 Mdot
.13002 .52882 Mdot
.22755 .63444 Mdot
.81508 .45132 Mdot
.47556 .80839 Mdot
.43724 .28676 Mdot
.70976 .64344 Mdot
.41059 .60128 Mdot
.30774 .5994 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0Voooool2o`000:cooooo000Looooo`03o`000?oooooooooo09_ooooo0_l0002/ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0Roooool2o`000;cooooo000Looooo`03o`000?oooooo
oooo08_ooooo0_l0002looooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`39ooooo`;o0000O_ooool001cooooo00?o0000ooooooooool0Zoooool2
o`0001cooooo0_l0001nooooo`007?ooool00ol0003oooooooooo`2[ooooo`;o0000W?ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Oooooo`;o0000
Z?ooool001cooooo00?o0000ooooooooool0Woooool2o`000:Sooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0Roooool4o`0002cooooo0_l0002<oooo
o`007?ooool00ol0003oooooooooo`1/ooooo`;o00007Oooool4o`0002cooooo0_l0002<ooooo`00
7?ooool00ol0003oooooooooo`1/ooooo`;o0000B_ooool2o`0008oooooo000Looooo`;o0000XOoo
ool2o`0001Kooooo0_l0000<ooooo`;o0000POooool001cooooo00?o0000ooooooooool0X?ooool2
o`0002Cooooo0_l00021ooooo`007?ooool00ol0003oooooooooo`2Jooooo`;o0000[Oooool001co
oooo00?o0000ooooooooool0P?ooool2o`0001Sooooo0_l00004ooooo`;o00003Oooool2o`0000?o
oooo0_l0000>ooooo`;o0000Poooool001cooooo00?o0000ooooooooool0P?ooool2o`0001Cooooo
0_l00008ooooo`;o00001_ooool2o`0000Gooooo0_l00003ooooo`;o00003_ooool2o`0000?ooooo
0_l0001nooooo`007?ooool00ol0003oooooooooo`2Aooooo`;o00000oooool2o`0000Wooooo0_l0
00000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000005?ooool2o`0000Kooooo0_l0
001nooooo`007?ooool00ol0003oooooooooo`1jooooo`;o00005Oooool3o`0000gooooo0_l00000
0ooooooo0000o`000005ooooo`;o00001?ooool2o`0000Cooooo0_l00003ooooo`;o00000oooool2
o`000003ooooool0003o000008?ooooo000Looooo`03o`000?oooooooooo07[ooooo0_l0000Foooo
o`;o00002oooool2o`00013ooooo0_l00004ooooo`;o00000oooool2o`0000Kooooo0_l00023oooo
o`007?ooool00ol0003oooooooooo`1Nooooo`;o0000<oooool2o`0000Oooooo0_l000001?oooooo
0000o`000?l00004ooooo`;o0000XOooool001cooooo00?o0000ooooooooool0G_ooool2o`00013o
oooo0_l00002ooooo`;o00007Oooool2o`0000Oooooo0_l000001?oooooo0000o`000?l00004oooo
o`;o00000_ooool3o`0009cooooo000Looooo`03o`000?oooooooooo073ooooo0_l00002ooooo`;o
00009?ooool2o`0000?ooooo0ol00008ooooo`?o00000oooool2o`00027ooooo0ol0001cooooo`00
7?ooool00ol0003oooooooooo`2Jooooo`;o00005?ooool2o`0000Gooooo1?l0000Gooooo`Co0000
Loooool001cooooo00?o0000ooooooooool0Z?ooool3o`0000Gooooo0_l00005ooooo`Co00000_oo
ool2o`0000Gooooo0_l0000<ooooo`;o0000MOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^
1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo06Wooooo0_l0000mooooo`?o0000
1Oooool2o`0000Gooooo0_l00002ooooo`Co00001Oooool2o`0001_ooooo0_l0001Vooooo`0000Ko
ooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A4
00Kooooo00?o0000ooooooooool0JOooool2o`0000Kooooo0_l0000Yooooo`;o00001oooool2o`00
00;ooooo0_l00008ooooo`;o00000_ooool2o`0000;ooooo0_l0000Gooooo`;o00002oooool2o`00
06Kooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^
k^h01oooool00ol0003oooooooooo`1aooooo`;o0000:Oooool2o`0000Cooooo0_l000000ooooooo
0000o`000002ooooo`;o00002?ooool2o`0000;ooooo0_l00002ooooo`;o00005oooool2o`0000Go
oooo0_l0001/ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRH
V?lQ8B7ok^k^00Kooooo0ol00022ooooo`;o00006?ooool2o`0000Cooooo0_l0000;ooooo`?o0000
2Oooool2o`0000Gooooo0_l0000Gooooo`;o0000K?ooool00003ooooool0003ooooo00;ooooo00?o
0000ooooooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo06oooooo0_l0
000Aooooo`?o00001_ooool2o`00017ooooo0_l0000?ooooo`?o00004?ooool2o`0000gooooo0_l0
000<ooooo`;o0000J?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool03Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo06oooooo0_l0000Booooo`;o00001_ooool2
o`0000gooooo0_l00002ooooo`;o00009_ooool2o`0000Wooooo0_l0000<ooooo`Co0000I_ooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo
00?o0000ooooooooool0D_ooool2o`0000gooooo0_l0000Xooooo`;o00003?ooool3o`0001;ooooo
0_l0000Fooooo`;o00003?ooool2o`0000_ooooo0_l0001Vooooo`0000Koooooonk^k_lb<S;o0000
oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Boooo
o`?o00001_ooool2o`0000Cooooo0_l00004ooooo`;o00004_ooool2o`0000Cooooo0_l00005oooo
o`Co00003Oooool3o`0001;ooooo0_l0000?ooooo`Go000000?oooooo`000?l000001_ooool4o`00
00?ooooo0_l0001cooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00001_ooool2o`0000[o
oooo0_l0000>ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`0000Gooooo1?l0000Boooo
o`;o00003_ooool4o`0000Wooooo2Ol000000ooooooo0000o`000006ooooo`Co00000oooool2o`00
01Wooooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`1[ooooo`;o00001_ooool2o`0000;o
oooo0_l000001?oooooo0000o`000?l0000;ooooo`;o00005?ooool2o`0000kooooo1?l00009oooo
o`Ko00004oooool2o`0001Wooooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`1[ooooo`;o
000000?oooooo`000?l000000oooool2o`0000Wooooo0_l00008ooooo`;o00001Oooool2o`0000Ko
oooo0_l0000Eooooo`;o00002Oooool4o`0000Oooooo0_l0000Booooo`;o0000Koooool001cooooo
00?o0000ooooooooool0G_ooool2o`0000kooooo0_l0000>ooooo`?o00001?ooool2o`000004oooo
ool0003o0000ooooo`?o000000?oooooo`000?l000001?ooool4o`0001?ooooo0_l0000;ooooo`;o
00002Oooool2o`0000Oooooo0_l00009ooooo`;o00002oooool2o`0006;ooooo000Looooo`03o`00
0?oooooooooo05kooooo0_l0000<ooooo`;o00004Oooool2o`0000Cooooo0_l000001?oooooo0000
o`000?ooool3o`0000Oooooo0_l00008ooooo`;o00001oooool2o`0000;ooooo0_l0000Aooooo`;o
00001?ooool2o`0000Kooooo0ol000001?oooooo0000o`000?ooool2o`0000?ooooo0_l00007oooo
o`;o000000?oooooo`000?l00000H_ooool001cooooo00?o0000ooooooooool0G_ooool2o`0000co
oooo0_l00006ooooo`;o00002_ooool2o`0000Gooooo0_l0000Aooooo`;o00000oooool2o`0000Oo
oooo0_l0000Aooooo`;o00000_ooool2o`0000Cooooo1?l00003ooooo`Co000000?oooooo`000?l0
00000ol00003ooooo`;o00001oooool2o`0006Gooooo000Looooo`03o`000?oooooooooo05gooooo
0ol0000Dooooo`;o00002_ooool4o`0000?ooooo0_l0000:ooooo`;o00001Oooool2o`000003oooo
ool0003o000000Gooooo0ol0000?ooooo`;o00000oooool4o`0000Sooooo0_l00003ooooo`;o0000
0oooool3o`0001Wooooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o00001ooo
ool2o`0001Gooooo0_l00003ooooo`;o00001_ooool2o`0000Oooooo1?l00003ooooo`;o000000?o
ooooo`000?l000001Oooool3o`0000oooooo0_l00004ooooo`?o00002Oooool4o`0000Gooooo0_l0
000Jooooo`;o0000F_ooool001cooooo00?o0000ooooooooool0IOooool3o`000003ooooool0003o
000000gooooo0_l00003ooooo`;o00002oooool2o`0000Kooooo0_l000000ooooooo0000o`000003
ooooo`;o00000_ooool2o`0000Kooooo0_l00009ooooo`;o00002_ooool4o`0000Oooooo1?l0000B
ooooo`;o00003_ooool2o`0005Wooooo000Looooo`03o`000?oooooooooo06Gooooo0_l00002oooo
o`;o00001?ooool2o`0000Oooooo0_l0000Hooooo`;o000000?oooooo`000?l000001_ooool3o`00
00Kooooo0_l00003ooooo`;o00001?ooool2o`000003ooooool0003o000000Oooooo1?l00005oooo
o`;o00003Oooool2o`0000Kooooo0ol0000>ooooo`;o0000FOooool001cooooo00?o0000oooooooo
ool0AOooool2o`0000Kooooo0_l0000Jooooo`;o00001?ooool2o`0000;ooooo0_l0000;ooooo`;o
00003Oooool2o`000003ooooool0003o000000?ooooo0_l00004ooooo`Co00001oooool2o`000003
ooooool0003o000000;o00001Oooool2o`00013ooooo0_l00006ooooo`;o00000_ooool2o`000003
ooooool0003o000000Cooooo1?l00004ooooo`;o0000I?ooool001cooooo0_l00016ooooo`;o0000
00?oooooo`000?l000000oooool2o`0002Cooooo0_l0000;ooooo`;o000000Coooooo`000?l0003o
00002?ooool3o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o00000_ooool2o`0000?o
oooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l0000Eooooo`;o000000Coooooo`000?l0
003ooooo0_l00002ooooo`;o00001oooool2o`0000Kooooo0_l0001Tooooo`007?ooool00ol0003o
ooooooooo`18ooooo`;o00004?ooool2o`0002Oooooo0ol000000ooooooo0000o`000003ooooo`Co
00002oooool2o`0000Kooooo0ol00003ooooo`;o00001_ooool2o`0001Gooooo0_l000001?oooooo
0000o`000?ooool2o`0000?ooooo0_l00007ooooo`;o00000oooool2o`0000Gooooo0_l00009oooo
o`;o0000E?ooool001cooooo00?o0000ooooooooool0EOooool2o`0000?ooooo0_l0000Qooooo`;o
00002?ooool2o`0000?ooooo0_l0000=ooooo`?o00001Oooool4o`0000;ooooo0_l00006ooooo`;o
00001?ooool2o`0000oooooo0_l00004ooooo`;o00000oooool2o`0000Cooooo1Ol00003ooooo`;o
00001Oooool2o`0000Wooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`1Eooooo`;o0000
4Oooool2o`0000Oooooo0_l00002ooooo`Co00001?ooool2o`000003ooooool0003o000000;ooooo
0_l0000?ooooo`;o00001Oooool2o`000003ooooool0003o000000;o00000_ooool3o`0000Kooooo
0_l00007ooooo`;o00003oooool2o`0000;ooooo1?l00003ooooo`;o00000oooool6o`0000Kooooo
0_l0000>ooooo`;o00000_ooool2o`0004oooooo000Looooo`03o`000?oooooooooo057ooooo0_l0
000Booooo`;o000000?oooooo`000?l000001oooool2o`0000;ooooo1?l00004ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0000?ooooo0ol00009ooooo`;o00002?ooool4o`0000?ooooo0_l0
0006ooooo`;o00003_ooool2o`0000cooooo0_l00005ooooo`;o00000oooool2o`0000;ooooo1?l0
0002ooooo`Co00003_ooool2o`0000;ooooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`1A
ooooo`;o00003_ooool2o`0000;ooooo0ol0000;ooooo`;o00002?ooool4o`0000Sooooo0ol00000
0ooooooo0000o`00000Eooooo`;o00000_ooool3o`0001?ooooo0_l0000Dooooo`;o000000?ooooo
o`000?l000001Oooool2o`0000;ooooo0_l0001Uooooo`007?ooool00ol0003oooooooooo`1@oooo
o`;o00000oooool2o`0000[ooooo0_l00003ooooo`;o000000?oooooo`000?l000000oooool2o`00
00?ooooo0_l0000:ooooo`;o00001Oooool2o`0000Gooooo0_l00003ooooo`;o00004?ooool7o`00
02Wooooo0_l000000ooooooo0000o`000005ooooo`;o00001_ooool2o`0000Wooooo0_l0001Foooo
o`007?ooool00ol0003oooooooooo`1@ooooo`;o00000oooool2o`0000[ooooo0_l00005ooooo`?o
00000oooool2o`0001Kooooo0_l0000:ooooo`;o00004_ooool3o`0001;ooooo0_l000000ooooooo
0000o`00000Iooooo`?o00000_ooool2o`0000Kooooo1?l00007ooooo`;o00000_ooool2o`0005;o
oooo000Looooo`03o`000?oooooooooo057ooooo0_l0000;ooooo`;o00001Oooool2o`000003oooo
ool0003o000000;o00000oooool2o`0000cooooo0ol00004ooooo`;o00000oooool4o`0002kooooo
0_l000000ooooooo0000o`00000Iooooo`?o00001Oooool2o`0000Gooooo0_l0000;ooooo`;o0000
D_ooool001cooooo00?o0000ooooooooool0B?ooool2o`0000?ooooo0_l00002ooooo`;o00002ooo
ool2o`0000Gooooo0_l00003ooooo`Co000000?oooooo`000?l000000oooool2o`0000Oooooo1Ol0
00001?oooooo0000o`000?l00003ooooo`Oo00001_ooool4o`0001?ooooo0_l0000Wooooo`Co0000
1oooool2o`0006Kooooo000Looooo`03o`000?oooooooooo04Sooooo0_l00003ooooo`;o00002Ooo
ool2o`0000?ooooo0_l00008ooooo`;o00000oooool5o`0000?ooooo0_l0000:ooooo`;o000000?o
ooooo`000?l000000_ooool9o`0000Kooooo1?l000000ooooooo0000o`00000@ooooo`;o00009ooo
ool4o`0000[ooooo0_l000000ooooooo0000o`000008ooooo`;o000000?oooooo`000?l000000_oo
ool2o`0004oooooo000Looooo`03o`000?oooooooooo03Oooooo0_l00009ooooo`;o00001Oooool2
o`0000gooooo0_l00003ooooo`;o00002?ooool2o`0000Cooooo0ol00006ooooo`;o00001?ooool2
o`0000Sooooo3Ol00008ooooo`?o00007?ooool4o`00023ooooo0_l00004ooooo`;o000000?ooooo
o`000?l000000_ooool2o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o0000Coooool0
01cooooo00?o0000ooooooooool0=oooool2o`0000Wooooo0_l00005ooooo`;o00003oooool2o`00
0004ooooool0003o0000o`0000Gooooo0_l00006ooooo`;o00001oooool2o`0000Cooooo0_l00000
0ooooooo0000o`000002ooooo`Wo00000oooool5o`0000Gooooo0_l000000ooooooo0000o`00000L
ooooo`Co00008?ooool2o`0000Kooooo0_l00003ooooo`;o00003Oooool2o`0004gooooo000Loooo
o`03o`000?oooooooooo04Sooooo0_l0000@ooooo`;o000000Coooooo`000?l0003o00001?ooool3
o`0001Cooooo0_l000001Ooooooo0000o`000?l0003ooooo00_o000000?oooooo`000?l000001?l0
0005ooooo`;o00004_ooool2o`0000_ooooo0_l00004ooooo`;o00007Oooool2o`0000Gooooo0_l0
0005ooooo`Co00002Oooool4o`0004_ooooo000Looooo`03o`000?oooooooooo04Sooooo0_l0000<
ooooo`;o00002Oooool2o`000003ooooool0003o000000Wooooo0_l0000:ooooo`;o000000Gooooo
o`000?l0003o0000ooooo`0@o`0000Wooooo0_l0000@ooooo`;o00002Oooool4o`000004ooooool0
003o0000ooooo`;o00007Oooool2o`0000cooooo1?l0000;ooooo`;o0000Boooool001cooooo00?o
0000ooooooooool0E_ooool2o`0000Wooooo0_l0000<ooooo`;o00002?ooool7o`0000;ooooo4?l0
0009ooooo`;o00004?ooool2o`0000;ooooo0_l00005ooooo`;o00000oooool2o`0003;ooooo0_l0
0006ooooo`;o000000?oooooo`000?l00000Boooool001cooooo0_l0001@ooooo`;o00001oooool2
o`0000Oooooo0_l0000Fooooo`So000000?oooooo`000?l000002Ol000000ooooooo0000o`000003
o`0001?ooooo0_l00005ooooo`;o00000_ooool2o`0000Wooooo0_l0000Nooooo`Co00003oooool4
o`0000Kooooo0_l000000ooooooo0000o`00001;ooooo`007?ooool00ol0003oooooooooo`1?oooo
o`;o00001oooool2o`0000Oooooo0_l0000Iooooo`;o000000?oooooo`000?l000002?l00002oooo
o`Go000000?oooooo`000?l000000oooool2o`0000kooooo0_l0000Dooooo`?o00000_ooool2o`00
01Wooooo1?l0000<ooooo`;o000000?oooooo`000?l00000F?ooool001cooooo00?o0000oooooooo
ool0HOooool3o`0000cooooo1?l0000=ooooo`oo00001_ooool2o`00023ooooo0_l00003ooooo`?o
000000?oooooo`000?l000009?ooool2o`0000?ooooo0_l0000<ooooo`;o00001Oooool2o`0004Ko
oooo000Looooo`03o`000?oooooooooo05;ooooo0_l0000>ooooo`;o00003?ooool4o`0000_ooooo
3?l000000ooooooo0000o`000005o`0000Kooooo0_l0000<ooooo`;o000000Coooooo`000?l0003o
oooo0_l00009ooooo`;o00001?ooool2o`000003ooooool0003o000002Cooooo0_l0000Aooooo`;o
00001Oooool2o`0004Kooooo000Looooo`03o`000?oooooooooo03cooooo0_l0000Cooooo`?o0000
0oooool4o`00017ooooo0_l00002ooooo`;o00000oooool4o`0000Cooooo5ol00005ooooo`;o0000
3?ooool2o`000004ooooool0003o0000ooooo`;o00005?ooool2o`0002kooooo0_l0001Dooooo`00
7?ooool00ol0003oooooooooo`0looooo`;o00004oooool2o`0000;ooooo1_l00003ooooo`Co0000
1?ooool2o`0000Cooooo0_l000001?oooooo0000o`000?l00003oooooaCo000000?oooooo`000?l0
00002Ol00005ooooo`;o00009oooool2o`0001cooooo0_l00006ooooo`;o00000oooool2o`0000?o
oooo0ol0000=ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0EOooool2o`0000?ooooo
0_l00002ooooo`Co00000_ooool4o`000003ooooool0003o000000Cooooo0_l00005ooooo`;o0000
00?oooooo`000?l000006ol00004ooooo`;o00004oooool2o`0001?ooooo0_l0000Kooooo`;o0000
1Oooool3o`0000?ooooo0_l00004ooooo`;o00003Oooool2o`0004Cooooo000Looooo`03o`000?oo
oooooooo05Kooooo0_l00002ooooo`;o00000_ooool2o`0000Cooooo0_l00003ooooo`Ko00003?oo
ool<o`000003ooooool0003o000000co00002?ooool2o`000004ooooool0003o0000o`0000_ooooo
0ol00002ooooo`;o00002?ooool2o`0000;ooooo1?l0000>ooooo`;o00003?ooool2o`0000?ooooo
0ol00008ooooo`;o00003?ooool2o`0004Oooooo000Looooo`03o`000?oooooooooo03kooooo0_l0
000Aooooo`;o00000oooool2o`0000[ooooo1?l00005ooooo`Co00002ooooolAo`000003ooooool0
003o000000Wo00000_ooool2o`0000?ooooo0_l000001?oooooo0000o`000?l0000<ooooo`;o0000
0_ooool2o`0000Sooooo0_l00002ooooo`;o00003Oooool2o`000003ooooool0003o000000cooooo
0_l00003ooooo`;o00002Oooool4o`0000[ooooo0_l00017ooooo`007?ooool00ol0003ooooooooo
o`0nooooo`;o00004Oooool2o`0000kooooo0ol00005ooooo`;o00002_ooool2o`0000?ooooo7Ol0
0002ooooo`;o00000oooool2o`0000Wooooo1?l0000Aooooo`;o00004Oooool2o`0000;ooooo0_l0
000Iooooo`;o00000_ooool3o`0005;ooooo000Looooo`03o`000?oooooooooo04[ooooo0_l00005
ooooo`Co00001oooool2o`0000?ooooo0_l00005ooooo`?o00000_ooool2o`0000?ooooo0_l00000
0ooooooo0000o`000005ooooo`Ko000000?oooooo`000?l000004_l00007ooooo`;o00002Oooool4
o`0000Oooooo0_l00005ooooo`;o00001oooool2o`0000Cooooo0_l00009ooooo`?o00001_ooool2
o`00013ooooo0_l00003ooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0B_ooool2o`00
00Gooooo1?l00007ooooo`;o00002_ooool2o`0000?ooooo0_l00003ooooo`;o00002?oooolKo`00
01gooooo0_l00003ooooo`Go00001_ooool2o`0000Cooooo0_l0000:ooooo`;o00001_ooool2o`00
00Cooooo0_l00009ooooo`;o00003Oooool2o`0004Wooooo000Looooo`03o`000?oooooooooo04[o
oooo0_l00008ooooo`Go00003_ooool2o`0000?ooooo0_l00002ooooo`;o00002_oooolKo`0001go
oooo0_l00003ooooo`;o000000?oooooo`000?l000001oooool2o`0001Cooooo1?l00005ooooo`?o
00000_ooool2o`0000Cooooo0_l00007ooooo`;o00000oooool5o`0004Oooooo000Looooo`03o`00
0?oooooooooo04Kooooo1?l0000:ooooo`Go00003_ooool4o`000003ooooool0003o000000;ooooo
0_l00008ooooo`co00000_oooolAo`0002[ooooo1?l0000Aooooo`;o000000?oooooo`000?l00000
0_l00006ooooo`;o00000_ooool2o`0000Sooooo0_l00003ooooo`Co000000Coooooo`000?l0003o
oooo0_l00017ooooo`007?ooool00ol0003oooooooooo`16ooooo`Co00002?ooool4o`0001?ooooo
0_l000000ooooooo0000o`000003o`000003ooooool0003o000000Kooooo0_l00002oooooa_o0000
8_ooool2o`0000Kooooo0_l00003ooooo`;o00003_ooool2o`0000?ooooo0ol00006ooooo`;o0000
2oooool2o`0000?ooooo1?l00002ooooo`Co0000Aoooool001cooooo00?o0000ooooooooool0Aooo
ool2o`0000Gooooo0_l00002ooooo`;o00006Oooool4o`000004ooooool0003o0000o`0000Cooooo
0ol00002oooooako00001?ooool2o`0000Kooooo0_l0000Aooooo`;o00001_ooool4o`000003oooo
ool0003o000001Cooooo0_l00006ooooo`;o00001?ooool2o`0000?ooooo0_l000000ooooooo0000
o`000002ooooo`;o00001?ooool2o`0004Wooooo000Looooo`;o0000AOooool2o`0000Kooooo1?l0
0008ooooo`;o00005?ooool2o`0000;ooooo1Ol00002ooooo`?o00001?oooolLo`0000Cooooo0_l0
0006ooooo`;o00006Oooool4o`0000Gooooo0_l0000Looooo`Co00000oooool2o`000003ooooool0
003o000000;ooooo0_l00002ooooo`Co0000BOooool001cooooo00?o0000ooooooooool0A?ooool2
o`0000Kooooo0_l00007ooooo`;o000000?oooooo`000?l000005?ooool2o`0000?ooooo1Ol00002
ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`00000;o`000003ooooool0003o
000000;o000000Coooooo`000?l0003o00006oooool2o`0001Cooooo0_l000000ooooooo0000o`00
000Looooo`;o00001?ooool2o`0000[ooooo1?l00019ooooo`007?ooool00ol0003oooooooooo`1:
ooooo`;o00002Oooool2o`0000Gooooo0_l0000>ooooo`Co000000?oooooo`000?l000000oooool2
o`0000Gooooo4_l000000ooooooo0000o`000002o`0000;ooooo0_l0000Jooooo`?o00000_ooool4
o`0000kooooo0_l00002ooooo`;o00000_ooool2o`0000Gooooo0_l00002ooooo`;o00004_ooool2
o`0000Gooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l00016ooooo`007?ooool0
0ol0003oooooooooo`16ooooo`Ko00002oooool2o`0000?ooooo0_l0000=ooooo`Co00000_ooool4
o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000005_l000001?oooooo0000o`000?oo
ool2o`0000oooooo0_l00003ooooo`;o00000oooool4o`0000Gooooo0_l00007ooooo`;o00000_oo
ool2o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`0001Kooooo1Ol00002ooooo`;o00001?oo
ool2o`0004Kooooo000Looooo`03o`000?oooooooooo04Gooooo1Ol0000=ooooo`;o00004_ooool4
o`0000Cooooo0_l00003ooooo`Co00001_oooolFo`000004ooooool0003o0000ooooo`?o00000_oo
ool2o`0000?ooooo0_l00004ooooo`?o00000_ooool2o`0000;ooooo0_l00008ooooo`?o00001ooo
ool2o`0000?ooooo0_l0000?ooooo`;o00004oooool3o`0000Kooooo0_l0001:ooooo`007?ooool0
0ol0003oooooooooo`0`ooooo`;o00004oooool2o`0000?ooooo0_l0000Pooooo`;o000000?ooooo
o`000?l000000oooool4o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000004_l00000
0ooooooo0000o`000004ooooo`;o00000_ooool2o`0000?ooooo0_l00004ooooo`;o00000oooool2
o`0000;ooooo0_l00008ooooo`;o00002?ooool2o`0000?ooooo0_l00009ooooo`;o00001?ooool3
o`0001Kooooo2Ol00002ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0<?ooool2o`00
01?ooooo0_l00003ooooo`;o00001_ooool4o`0001Wooooo0_l00003ooooo`Co00001OoooolHo`00
00;ooooo1?l0000;ooooo`;o000000Coooooo`000?l0003ooooo0_l00005ooooo`;o00009?ooool2
o`0000Gooooo0_l00003ooooo`;o00002Oooool2o`0000Kooooo2Ol00002ooooo`;o0000A?ooool0
01cooooo00?o0000ooooooooool0AOooool2o`000003ooooool0003o000000Cooooo0_l000000ooo
oooo0000o`000003o`0001cooooo1Ol00006ooooo`;o000000?oooooo`000?l000004ol00004oooo
o`;o00001Oooool2o`0000Oooooo1_l00004ooooo`;o00007?ooool2o`0001;ooooo0_l00003oooo
o`Co00000_ooool2o`0000Sooooo0_l000000ooooooo0000o`00000;ooooo`;o0000?Oooool001co
oooo00?o0000ooooooooool0?_ooool2o`0000Sooooo0_l00004ooooo`;o000000?oooooo`000?l0
00000_l0000Mooooo`;o000000?oooooo`000?l000002_ooool4o`000004ooooool0003o0000oooo
o`co000000?oooooo`000?l000001_ooool4o`0000Wooooo1?l00008ooooo`;o00001Oooool2o`00
00Wooooo0_l00006ooooo`?o00004oooool2o`000003ooooool0003o000000;o00000oooool2o`00
00Oooooo0_l000000ooooooo0000o`00000;ooooo`;o0000?Oooool001cooooo00?o0000oooooooo
ool0?_ooool2o`0001?ooooo0_l00004ooooo`;o00002Oooool2o`0000Oooooo1?l00006ooooo`;o
00001oooool3o`000003ooooool0003o000000;o000000?oooooo`000?l000002_l000000ooooooo
0000o`000006ooooo`;o00003oooool2o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000;o
oooo0_l00006ooooo`?o00000_ooool2o`0000Cooooo0_l00002ooooo`;o00001Oooool2o`0000So
oooo0_l0000:ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0E?ooool2o`0000?ooooo
0_l00009ooooo`?o00000_ooool2o`0000;ooooo1?l00003ooooo`;o000000?oooooo`000?l00000
0_ooool2o`0000?ooooo0_l00002ooooo`oo000000?oooooo`000?l000002_ooool2o`0000gooooo
0_l0000?ooooo`?o00000_ooool2o`0000Wooooo1?l00002ooooo`;o000000Coooooo`000?l0003o
oooo0_l00002ooooo`;o00001Oooool2o`00063ooooo000Looooo`03o`000?oooooooooo03kooooo
0_l00004ooooo`;o00003_ooool2o`0000?ooooo0_l00003ooooo`;o00001Oooool2o`0000;ooooo
0_l00009ooooo`;o00001Oooool2o`0000Sooooo0_l000000ooooooo0000o`000002o`0000;ooooo
1Ol000000ooooooo0000o`00000:ooooo`?o00001_ooool3o`0001Cooooo1?l000000ooooooo0000
o`000009ooooo`Co00001Oooool2o`0000Gooooo0_l00003ooooo`Co00002Oooool2o`0005Gooooo
000Looooo`03o`000?oooooooooo03kooooo0_l00004ooooo`;o00000_ooool2o`000003ooooool0
003o000000cooooo0_l00003ooooo`;o00004Oooool2o`0000?ooooo0_l0000<ooooo`;o00001?oo
ool2o`000003ooooool0003o000000?o00003oooool2o`0000Kooooo0ol00009ooooo`;o000000?o
ooooo`000?l000002?ooool2o`0000[ooooo0_l0000@ooooo`;o00000oooool3o`0000Kooooo0_l0
0002ooooo`;o0000EOooool001cooooo00?o0000ooooooooool0@_ooool2o`0000Cooooo0_l00000
0ooooooo0000o`000006ooooo`;o000000?oooooo`000?l000001_ooool2o`00017ooooo0ol00002
ooooo`;o00003?ooool4o`0000;ooooo1Ol000000ooooooo0000o`00000?ooooo`?o00004?ooool3
o`000003ooooool0003o000000Oooooo0_l00002ooooo`Co00000_ooool2o`000003ooooool0003o
000000;o00007?ooool2o`0000Gooooo0_l00006ooooo`Co00001?ooool4o`0000;ooooo0_l0000l
ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo00Cooooo00?o0000ooooooooool0@_ooool2o`0000Oooooo0_l000000ooooooo0000o`00
0003ooooo`;o000000?oooooo`000?l000001_ooool3o`0000oooooo1?l00002ooooo`;o00003?oo
ool4o`0000;ooooo2?l00002ooooo`Go00000_ooool4o`0000;ooooo0ol0000@ooooo`;o00000_oo
ool2o`0000?ooooo0ol000000ooooooo0000o`000002ooooo`Co00000_ooool7o`0000;ooooo0_l0
000Aooooo`;o00003?ooool2o`0000Gooooo1Ol00004ooooo`Co000000Coooooo`000?l0003o0000
??ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`1;ooooo`;o000000?oooooo`000?l000003oooool2o`000003
ooooool0003o000000cooooo0_l0000Booooo`;o00001_ooool6o`0000;ooooo2ol0000<ooooo`;o
00002Oooool6o`000003ooooool0003o000000?o000000?oooooo`000?l000000_ooool3o`000003
ooooool0003o000000;o00001Oooool2o`0000;ooooo0_l0000=ooooo`;o00004Oooool4o`0000Oo
oooo0_l00003ooooo`;o0000?Oooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool0
2Oooool5o`0000Kooooo00?o0000ooooooooool0:_ooool2o`000003ooooool0003o000002?ooooo
0_l00008ooooo`;o00001?ooool4o`0000kooooo0_l0000?ooooo`;o00001_ooool5o`0000;ooooo
0ol000001?oooooo0000o`000?l00002ooooo`;o00003?ooool2o`0000Gooooo0ol000000ooooooo
0000o`00000Bo`0000;ooooo1?l00004ooooo`;o00000_ooool2o`0000gooooo0_l0000;ooooo`;o
00001?ooool2o`0004gooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo
00CoA4A4omgMgOoooooo00001oooool3o`0002[ooooo0_l000000ooooooo0000o`000003ooooo`;o
00001_ooool2o`0000gooooo0ol00006ooooo`;o00002?ooool2o`0000Kooooo0_l00004ooooo`;o
00002?ooool2o`0000?ooooo0_l00006ooooo`;o00000_ooool2o`0000Kooooo1?l00004ooooo`;o
00001_ooool2o`000003ooooool0003o000000Wooooo1?l00003ooooo`?o00000_ooool6o`0000;o
oooo2_l00005ooooo`;o00000_ooool4o`0001Kooooo0_l00003ooooo`;o000000?oooooo`000?l0
00002Oooool2o`0004Sooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo
00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`0booooo`;o00001_ooool2o`0000[o
oooo0_l000001?oooooo0000o`000?l0000>ooooo`?o00003Oooool2o`0000gooooo1?l00004oooo
o`;o00006_ooool2o`000003ooooool0003o000000Wooooo1?l00005ooooo`Oo00000oooool2o`00
0005ooooool0003o0000o`000?ooool02_l00003ooooo`Co00000_ooool2o`0000Oooooo0_l00009
ooooo`;o00000oooool2o`0000cooooo0_l00002ooooo`;o0000A?ooool00003ooooool@413ooooo
00;ooooo00?o410@ooooooooool02_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo
043ooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000[ooooo0_l00002oooo
o`Co00007_ooool3o`000004ooooool0003o0000ooooo`;o00003Oooool2o`000003ooooool0003o
000000?ooooo1_l00006ooooo`;o00003Oooool5o`000003ooooool0003o000000;ooooo5Ol00003
ooooo`Go00001_ooool2o`000003ooooool0003o000001Gooooo0_l00006ooooo`;o00001Oooool2
o`0003gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l000001ooo
ool00ol0003oooooooooo`10ooooo`;o000000Coooooo`000?l0003o00001Oooool2o`0000Sooooo
0_l00002ooooo`?o00003_ooool2o`0000Oooooo1Ol00003ooooo`?o000000Coooooo`000?l0003o
oooo0ol00003ooooo`Co00000_ooool2o`000004ooooool0003o0000ooooo`Wo00001oooool3o`00
00[ooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000[o00000_ooool<
o`0000;ooooo0_l000001?oooooo0000o`000?l00002ooooo`?o00000oooool2o`0000Kooooo0_l0
000=ooooo`;o00003Oooool3o`0003cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPgooooo
00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`0hooooo`;o000000?oooooo`000?l00000
1oooool2o`0000Cooooo0ol0000;ooooo`;o00004?ooool2o`0000Oooooo1Ol00003ooooo`;o0000
0_ooool3o`000003ooooool0003o000000?ooooo1?l00002ooooo`;o00000oooool6o`000003oooo
ool0003o000000Sooooo1?l000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l00000
4?l00002ooooo`oo00000_ooool3o`0000;ooooo0ol000000ooooooo0000o`000008ooooo`;o0000
2oooool2o`0000Cooooo0_l00007ooooo`Go0000??ooool001cooooo00?o0000ooooooooool0>?oo
ool2o`000003ooooool0003o000000cooooo1?l00002ooooo`?o00001_ooool2o`0001;ooooo0_l0
000?ooooo`Go00004Oooool2o`0000Gooooo0_l0000:ooooo`;o000000?oooooo`000?l000002ooo
ool5o`0000;ooooo2_l000000ooooooo0000o`00000=o`0000?ooooo0_l00003ooooo`;o000000?o
ooooo`000?l000000_l0000Cooooo`;o00001?ooool2o`000004ooooool0003o0000o`0000?ooooo
1Ol0000looooo`007?ooool00ol0003oooooooooo`19ooooo`;o00000_ooool5o`0000Cooooo0_l0
0006ooooo`;o00000_ooool2o`0000Sooooo0_l0000?ooooo`?o000000?oooooo`000?l000000_l0
0009ooooo`Co00002?ooool2o`0000kooooo0_l000000ooooooo0000o`000004ooooo`;o00000_oo
oolFo`000003ooooool0003o000000Co00000_ooool6o`0000Sooooo0_l0000?ooooo`;o00002?oo
ool2o`000004ooooool0003o0000o`0000Kooooo0_l0000looooo`007?ooool00ol0003ooooooooo
o`0Uooooo`;o00005oooool2o`0000gooooo0_l00005ooooo`Co00001_ooool2o`0000;ooooo0_l0
000=ooooo`Co00002Oooool2o`000003ooooool0003o000000;o00002Oooool5o`0000cooooo0_l0
00000ooooooo0000o`000006ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000
o`000003ooooo`;o000000?oooooo`000?l000007ol00008ooooo`;o00000oooool2o`0000[ooooo
0ol0001Aooooo`007?ooool00ol0003oooooooooo`0Uooooo`;o00004_ooool2o`0000?ooooo0_l0
00000ooooooo0000o`00000=ooooo`;o00000_ooool2o`0001Cooooo0_l00005ooooo`Co00003ooo
ool2o`000004ooooool0003o0000o`0000Gooooo1?l0000<ooooo`;o000000?oooooo`000?l00000
2_ooool8o`0000?ooooo8_l0000>ooooo`;o000000?oooooo`000?l000001oooool4o`0000Kooooo
0_l00018ooooo`007?ooool00ol0003oooooooooo`0Xooooo`;o00001oooool2o`0000Kooooo0_l0
00000ooooooo0000o`000003ooooo`;o00003Oooool2o`0001Gooooo0_l000000ooooooo0000o`00
0005ooooo`;o00004Oooool2o`000004ooooool0003o0000o`0000Gooooo0_l00009ooooo`;o0000
2Oooool2o`0000Gooooo2_l00002ooooobOo00003Oooool2o`0000Oooooo1?l00006ooooo`;o0000
B?ooool001cooooo00?o0000ooooooooool0:?ooool2o`0000Oooooo0_l000000ooooooo0000o`00
0006ooooo`;o00004oooool2o`0000Gooooo0_l0000=ooooo`;o000000?oooooo`000?l000000_oo
ool2o`000003ooooool0003o000001Cooooo0ol000001?oooooo0000o`000?ooool5o`0000Gooooo
1?l00009ooooo`;o00000oooool4o`000004ooooool0003o0000ooooo`?o00000_oooolPo`000004
ooooool0003o0000ooooo`Co00008Oooool2o`0004Oooooo000Looooo`03o`000?oooooooooo03Co
oooo0ol000000ooooooo0000o`00000?ooooo`;o00001_ooool2o`000003ooooool0003o000000;o
oooo0_l0000@ooooo`;o00000_ooool2o`0000Cooooo0_l0000<ooooo`;o00000oooool2o`0000;o
oooo0_l000001?oooooo0000o`000?ooool3o`0000Cooooo0ol000000ooooooo0000o`00000<oooo
o`Co00000ooooolJo`000003ooooool0003o000000Oo00000oooool2o`0000?ooooo0_l00007oooo
o`;o00003oooool2o`0000Oooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`0eooooo`Go
00003oooool2o`0000Wooooo1?l0000Cooooo`;o00001oooool2o`0000cooooo0_l00005ooooo`;o
00001?ooool5o`0000Sooooo0ol00002ooooo`;o00002Oooool2o`000003ooooool0003o000001[o
00000_ooool9o`000003ooooool0003o000000;o000000?oooooo`000?l000001Ol000000ooooooo
0000o`000002o`0000oooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`0fooooo`;o0000
7_ooool2o`0000kooooo0_l00003ooooo`;o00002oooool2o`0000Sooooo0_l00005ooooo`;o0000
1?ooool5o`0000Sooooo0ol00002ooooo`;o00001?ooool2o`0000Cooooo1Ol000000ooooooo0000
o`00000@o`000003ooooool0003o000000ko000000?oooooo`000?l000002_l000000ooooooo0000
o`00000@ooooo`?o00002?ooool2o`0000Kooooo0_l0000nooooo`007?ooool00ol0003ooooooooo
o`0iooooo`;o00002Oooool2o`000003ooooool0003o000000gooooo1?l00005ooooo`;o00001Ooo
ool3o`0000Wooooo0_l00004ooooo`;o00008Oooool3o`0000Wooooo0_l00004ooooo`;o000000?o
ooooo`000?l000000_oooolMo`000003ooooool0003o000000[o00006?ooool3o`0000Sooooo0_l0
0003ooooo`;o000000Coooooo`000?l0003o0000?Oooool001cooooo00?o0000ooooooooool0:ooo
ool2o`0000cooooo1?l00007ooooo`Ko00001Oooool2o`0000Gooooo1_l000000ooooooo0000o`00
0002o`000003ooooool0003o000000?ooooo0_l00006ooooo`So00007oooool2o`0000?ooooo0_l0
0003ooooo`;o00001?ooool2o`0000Gooooo1?l00003ooooob[o00001?ooool2o`0000cooooo0_l0
000Dooooo`?o000000?oooooo`000?l00000?Oooool001cooooo0_l0000/ooooo`;o00000oooool2
o`000003ooooool0003o000000Kooooo0_l000000ooooooo0000o`000005ooooo`Go000000Gooooo
o`000?l0003o0000ooooo`02o`0000Wooooo0_l000000ooooooo0000o`000003ooooo`;o00000_oo
ool2o`0000Oooooo0ol000000ooooooo0000o`000003o`0001Cooooo0_l00008ooooo`;o00000_oo
ool2o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l000001?ooool3o`0000Cooooo9ol0
0005ooooo`;o00002Oooool2o`000003ooooool0003o000000Cooooo0_l00006ooooo`;o00000ooo
ool6o`00043ooooo000Looooo`03o`000?oooooooooo033ooooo0_l000000ooooooo0000o`000009
ooooo`;o00001?ooool2o`0000Gooooo0ol0000>ooooo`;o00002?ooool7o`0000?ooooo0ol00002
ooooo`?o00001?ooool2o`0000Sooooo0_l00004ooooo`;o00003?ooool2o`0000gooooo0_l00003
ooooo`Co000000?oooooo`000?l000001ol000000ooooooo0000o`000003o`000003ooooool0003o
000001So00004?ooool2o`0000Oooooo0_l00004ooooo`Co00000oooool4o`0000?ooooo0_l0000m
ooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00004Oooool2o`0000Gooooo0_l00007oooo
o`;o00001_ooool2o`0000Kooooo4ol00005ooooo`;o00002?ooool2o`0000Sooooo0_l00008oooo
o`;o00002oooool2o`0000Gooooo0ol000000ooooooo0000o`000006o`000003ooooool0003o0000
01Oo000000?oooooo`000?l000002?l00004ooooo`;o00005Oooool8o`0000Sooooo0_l0000moooo
o`007?ooool00ol0003oooooooooo`0aooooo`;o00005_ooool2o`0000Wooooo0_l00003ooooo`;o
00002Oooool4o`000003ooooool0003o000000ko000000?oooooo`000?l000002Oooool2o`0000Wo
oooo0_l00003ooooo`Co00003_ooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l0
00007?l000000ooooooo0000o`00000=o`0000;ooooo0ol0000<ooooo`;o00001oooool2o`0000Co
oooo0_l00002ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0A_ooool2o`000004oooo
ool0003o0000ooooo`;o00002oooool2o`000003ooooool0003o000000Cooooo0_l000001Ooooooo
0000o`000?l0003ooooo013o000000?oooooo`000?l000002Oooool2o`0000;ooooo0_l00002oooo
o`;o00001_ooool4o`0000Gooooo1?l00005ooooo`;o000000?oooooo`000?l000000_l00002oooo
ob_o00000oooool3o`000003ooooool0003o000000gooooo0ol00006ooooo`;o00000_ooool8o`00
04?ooooo000Looooo`03o`000?oooooooooo04Kooooo0_l00004ooooo`;o00002?ooool2o`0000Co
oooo0_l00003ooooo`?o000000?oooooo`000?l000004?l00007ooooo`;o00001oooool4o`0000;o
oooo0_l0000?ooooo`Co00001Oooool2o`000003ooooool0003o000000go000000?oooooo`000?l0
00007?l000000ooooooo0000o`000004ooooo`;o00000_ooool2o`0000gooooo0_l00003ooooo`;o
000000?oooooo`000?l000000_ooool3o`000003ooooool0003o000000;ooooo0_l00011ooooo`00
7?ooool00ol0003oooooooooo`0/ooooo`;o00001oooool2o`0000cooooo0_l0000?ooooo`Co0000
1ooooolKo`0000Cooooo0_l00004ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0001Oo
oooo0_l00005ooooo`Go000000?oooooo`000?l00000:?l00007ooooo`;o00002oooool2o`0000Go
oooo0_l00009ooooo`;o00000_ooool2o`00047ooooo000Looooo`03o`000?oooooooooo02cooooo
0_l000000ooooooo0000o`000004ooooo`;o00003?ooool2o`0000gooooo1?l00009ooooo`?o0000
00?oooooo`000?l000005ol00003ooooo`;o00000oooool2o`000003ooooool0003o000000?ooooo
0_l0000Gooooo`;o000000?oooooo`000?l000000_ooool5o`000003ooooool0003o000001Wo0000
00?oooooo`000?l000003?l000000ooooooo0000o`00000Aooooo`;o00001_ooool2o`0000cooooo
0_l00011ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00003oooool5o`0000gooooo0_l0
0002ooooo`?o00001?oooolKo`0000;ooooo0_l00003ooooo`;o00009oooool2o`0000Cooooo0ol0
00000ooooooo0000o`00000Xo`000004ooooool0003o0000ooooo`;o00005_ooool2o`0000Sooooo
0ol000000ooooooo0000o`000011ooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00001Ooo
ool2o`000004ooooool0003o0000o`0001?ooooo0ol000001?oooooo0000o`000?oooolMo`0000Go
oooo0_l0000Aooooo`;o00006oooool2o`000003ooooool0003o000001;o00000oooool?o`0000So
oooo0_l0000<ooooo`;o00000oooool2o`0000Oooooo0_l00004ooooo`?o0000A?ooool001cooooo
00?o0000ooooooooool0=_ooool2o`0000;ooooo2Ol00002ooooo`;o00001Oooool2o`000003oooo
ool0003o000000Wooooo0ol00004oooooa_o00000_ooool2o`0001;ooooo0_l00002ooooo`Co0000
0oooool3o`0000;ooooo0_l00009ooooo`;o00000ooooolEo`0000;ooooo3Ol00007ooooo`;o0000
3oooool3o`0000;ooooo0_l00007ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0:Ooo
ool2o`0000oooooo1?l000000ooooooo0000o`000002o`0000;ooooo0_l00005ooooo`Go00001Ooo
ool2o`0000?ooooo0_l000000ooooooo0000o`00000Lo`0000;ooooo0_l000000ooooooo0000o`00
0002o`00017ooooo1?l00003ooooo`?o000000Coooooo`000?l0003o00000oooool4o`0000;ooooo
1Ol000000ooooooo0000o`000006o`000003ooooool0003o000001Oo00000oooool4o`000003oooo
ool0003o000000;ooooo0_l0000;ooooo`So00000oooool2o`0000Gooooo0_l00002ooooo`;o0000
1_ooool2o`0003_ooooo000Looooo`03o`000?oooooooooo02Wooooo0_l000000ooooooo0000o`00
000=ooooo`;o00004?ooool6o`000003ooooool0003o000000?o00001OoooolMo`0000?ooooo0_l0
00000ooooooo0000o`000002o`0001cooooo0_l00004ooooo`Co00000_ooool5o`000004ooooool0
003o0000oooooaoo00000_ooool6o`0000Cooooo0_l0000<ooooo`Oo00000oooool2o`0000Gooooo
0_l00002ooooo`?o00001Oooool2o`0003_ooooo000Looooo`03o`000?oooooooooo02_ooooo0ol0
000=ooooo`;o00005?ooool5o`000004ooooool0003o0000ooooo`;o00000oooool>o`000003oooo
ool0003o000000_o00000oooool2o`0000Gooooo0_l0000Booooo`;o00004Ooooolco`0000?ooooo
0_l0000@ooooo`;o00001_ooool2o`0000Oooooo0_l0000Pooooo`;o00008?ooool001cooooo00?o
0000ooooooooool08_ooool2o`0000Oooooo0_l0000Qooooo`;o00000_ooool2o`0000Kooooo1?l0
00000ooooooo0000o`00000Jo`000003ooooool0003o000000Oooooo0_l00008ooooo`;o00002?oo
ool2o`00017ooooo1?l000000ooooooo0000o`00000Bo`000003ooooool0003o000001?o00000_oo
ool2o`000003ooooool0003o000000;o00004?ooool2o`0000?ooooo0_l000001?oooooo0000o`00
0?ooool2o`0000?ooooo0_l0000Qooooo`;o00008?ooool001cooooo00?o0000ooooooooool08_oo
ool2o`0000;ooooo0_l00002ooooo`;o00000oooool4o`0000oooooo0_l000000ooooooo0000o`00
0007ooooo`;o00000oooool2o`0000Oooooo0_l00002oooooaWo00000oooool2o`00017ooooo0_l0
00000ooooooo0000o`000002o`0000kooooo1_l00007ooooo`?o00000_oooolNo`0000?ooooo1?l0
0004ooooo`?o00003?ooool2o`0000Cooooo2?l00003ooooo`;o00000oooool2o`0000?ooooo0_l0
0003ooooo`;o0000>Oooool001cooooo0_l0000Nooooo`;o00001oooool2o`0000;ooooo0_l00003
ooooo`Co00000_ooool2o`0000Sooooo0_l000001?oooooo0000o`000?ooool2o`0000cooooo0_l0
00000ooooooo0000o`000007oooooaSo00002_ooool2o`0000Kooooo0_l00007ooooo`Co00003?oo
ool8o`0000;ooooo0_l00002ooooo`?o00000_oooolEo`000003ooooool0003o000000Wo000000?o
ooooo`000?l000001Ol000000ooooooo0000o`000009ooooo`;o00000_ooool2o`0000;ooooo2_l0
000=ooooo`;o00000oooool2o`0003Wooooo000Looooo`03o`000?oooooooooo01gooooo0_l0000@
ooooo`;o00001?ooool2o`0000;ooooo1?l00002ooooo`;o00000_ooool2o`00013ooooo1?l00006
oooooaSo00002_ooool2o`0000Gooooo0ol00006ooooo`;o00002?ooool2o`0000Gooooo1?l00000
0ooooooo0000o`000003ooooo`;o00000_ooool3o`0000;ooooo1_l000000ooooooo0000o`00000=
o`0000;ooooo1?l000000ooooooo0000o`000002o`000003ooooool0003o000000Oo00002_ooool7
o`000003ooooool0003o000000;o0000Doooool001cooooo00?o0000ooooooooool0<oooool4o`00
00;ooooo1?l00006ooooo`;o00001oooool2o`0000Oooooo1?l00006oooooaSo00002oooool2o`00
00Cooooo0_l00007ooooo`;o00002?ooool2o`0000Oooooo0_l000000ooooooo0000o`000003oooo
o`;o000000?oooooo`000?l000000_l000001?oooooo0000o`000?ooool6o`000003ooooool0003o
000000co000000?oooooo`000?l000000_l00002ooooo`;o00000_ooool4o`0000?ooooo0_l00005
ooooo`;o00001Oooool5o`0000;ooooo0ol00002ooooo`?o00000_ooool2o`0000cooooo0_l0000l
ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00000oooool2o`0000Wooooo0_l00007oooo
o`;o00001oooool2o`0000Sooooo6?l00004ooooo`;o00001Oooool2o`0000Gooooo0_l00004oooo
o`;o00000oooool2o`0001Kooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o0000
00?ooooo6?l000000ooooooo0000o`000002o`0000;ooooo1?l00006ooooo`;o000000?oooooo`00
0?l000003?ooool4o`000004ooooool0003o0000o`0000;ooooo0_l00004ooooo`?o00001Oooool2
o`0003cooooo000Looooo`03o`000?oooooooooo02gooooo0_l00009ooooo`;o00002Oooool3o`00
00Sooooo0_l00005ooooo`;o00000_ooool2o`0000Cooooo6?l00004ooooo`;o00003?ooool2o`00
00Cooooo0_l00003ooooo`;o00004?ooool2o`000004ooooool0003o0000ooooo`;o00000_ooool4
o`0000Cooooo6?l00002ooooo`Co00001?ooool4o`000004ooooool0003o0000ooooo`;o00002?oo
ool5o`0000Cooooo0_l00003ooooo`;o00001oooool3o`0004?ooooo000Looooo`03o`000?oooooo
oooo02gooooo0_l0000Eooooo`;o00002?ooool2o`0000Wooooo0_l00004oooooaCo00001_ooool2
o`0000gooooo0_l00005ooooo`;o00002?ooool2o`0000_ooooo0_l000000ooooooo0000o`000003
o`0000;ooooo1Ol000000ooooooo0000o`000002o`0000;ooooo0_l000000ooooooo0000o`000007
o`000003ooooool0003o000000Go00000_ooool2o`0000Oooooo0ol000000ooooooo0000o`000004
ooooo`;o000000?oooooo`000?l000000_ooool7o`0000Oooooo0_l00005ooooo`;o0000A_ooool0
01cooooo00?o0000ooooooooool0AOooool2o`0000?ooooo0_l00009ooooo`;o00000_ooool2o`00
00Cooooo6?l00002ooooo`;o00002_ooool2o`000003ooooool0003o000000[ooooo0_l00003oooo
o`;o00001oooool3o`0000Kooooo0_l00006ooooo`Ko00000oooool5o`0000Gooooo1ol000001?oo
oooo0000o`000?l00004ooooo`?o00000oooool2o`0000Cooooo0_l00002ooooo`;o000000?ooooo
o`000?l000000_ooool3o`0000;ooooo0_l00006ooooo`;o00000_ooool6o`000003ooooool0003o
000004?ooooo000Looooo`03o`000?oooooooooo03Wooooo0_l0000:ooooo`Co000000?oooooo`00
0?l000002Oooool2o`0000Kooooo6_l0000>ooooo`;o00002?ooool9o`0000[ooooo0ol00005oooo
o`;o00001oooool4o`0000Kooooo1ol00002ooooo`_o00001?ooool3o`0000Wooooo0_l00004oooo
o`;o00001?ooool2o`0000[ooooo0_l00002ooooo`Co00000oooool2o`000003ooooool0003o0000
043ooooo000Looooo`03o`000?oooooooooo02gooooo0_l0000:ooooo`;o00002_ooool4o`0000co
oooo0_l00006ooooo`?o000000?oooooo`000?l000003ol000001?oooooo0000o`000?l00004oooo
o`;o00003_ooool2o`0000;ooooo1_l000001?oooooo0000o`000?l00003ooooo`Co00002oooool2
o`0000Gooooo0_l0000;ooooo`Ko00000_ooool6o`000003ooooool0003o000000;o00000_ooool2
o`000003ooooool0003o000000oooooo0_l00007ooooo`;o00000_ooool2o`0000Gooooo0_l00000
0ooooooo0000o`000007ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool09oooool2o`00
00Cooooo0_l00007ooooo`;o00007_ooool3o`0000Cooooo1?l00003ooooo`go00000oooool2o`00
00Cooooo0_l0000>ooooo`;o00000_ooool2o`0000Cooooo0ol00003ooooo`Go00001?ooool2o`00
00Gooooo0_l00005ooooo`?o00002_ooool<o`0000Gooooo0_l00002ooooo`;o00003Oooool2o`00
00cooooo0ol000000ooooooo0000o`000005ooooo`;o00002oooool2o`0003oooooo000Looooo`03
o`000?oooooooooo02Kooooo1?l0000<ooooo`?o00004?ooool2o`0000_ooooo1_l00003ooooo`;o
00001Oooool8o`000003ooooool0003o000000Gooooo0_l00003ooooo`;o00004_ooool2o`0000?o
oooo0_l00004ooooo`;o00001oooool2o`0000Gooooo1?l00004ooooo`;o00000_ooool4o`0000Ko
oooo1_l000000ooooooo0000o`000002o`0001?ooooo0_l00002ooooo`;o00003Oooool2o`0000So
oooo1?l00009ooooo`;o0000?oooool001cooooo00?o0000ooooooooool09_ooool4o`0000Wooooo
0_l00002ooooo`;o00000oooool2o`0000_ooooo0_l0000=ooooo`Co00000oooool2o`0000;ooooo
0_l00002ooooo`;o00000_ooool3o`0000Gooooo1_l00002ooooo`;o00002?ooool2o`0000Sooooo
0_l00005ooooo`;o00002_ooool2o`0000Sooooo1?l00006ooooo`Co00001?ooool2o`0000Oooooo
1?l0000Cooooo`;o00000_ooool2o`0000?ooooo1?l00006ooooo`?o00002Oooool2o`0000Wooooo
0_l0000oooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00001oooool2o`0000Sooooo0_l0
000:ooooo`?o00000oooool2o`0000Wooooo0_l0000>ooooo`So00002_ooool2o`000003ooooool0
003o000000cooooo0_l0000:ooooo`Co00002?ooool2o`0000kooooo0ol00003ooooo`;o000000?o
ooooo`000?l000000_l0000<ooooo`;o00002Oooool2o`0000?ooooo1ol00003ooooo`?o00001Ooo
ool2o`0000[ooooo0_l000000ooooooo0000o`000002o`0003gooooo000Looooo`03o`000?oooooo
oooo04Kooooo0_l0000:ooooo`?o00001?ooool4o`0000Gooooo0_l00003ooooo`;o00004?ooool2
o`0000gooooo0_l000000ooooooo0000o`00000Eooooo`Co000000Coooooo`000?l0003o00004?oo
ool3o`000004ooooool0003o0000o`0000?ooooo0_l00003ooooo`;o00000oooool2o`0000;ooooo
0_l00003ooooo`;o00000oooool2o`0000?ooooo0ol00004ooooo`;o000000Coooooo`000?l0003o
00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`00000:ooooo`;o000000?oooooo`000?l0
00000_l0000mooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00008Oooool2o`000003oooo
ool0003o000000?o00001?ooool2o`000003ooooool0003o000000;o00001Oooool3o`0000cooooo
0_l0000<ooooo`?o00000oooool2o`0000_ooooo0_l00002ooooo`?o00000_ooool3o`0000Sooooo
0_l00006ooooo`?o000000?oooooo`000?l000000oooool2o`0000Gooooo0_l00002ooooo`;o0000
0_ooool2o`0000;ooooo0ol00003ooooo`;o00000oooool3o`0000Cooooo0_l00006ooooo`;o0000
1?ooool2o`0000?ooooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00001?oo
ool2o`0001Wooooo1Ol000000ooooooo0000o`000002o`0000Cooooo1Ol00002ooooo`;o00000ooo
ool3o`0000cooooo0_l00006ooooo`;o00001Oooool2o`0000?ooooo0_l0000;ooooo`;o00000_oo
ool2o`0000?ooooo0_l00004ooooo`;o00000_ooool3o`0000cooooo0_l000000ooooooo0000o`00
0005ooooo`?o00001Oooool2o`0000;ooooo1?l0000Oooooo`Co00001_ooool2o`0000Kooooo0_l0
000looooo`007?ooool2o`0003[ooooo0_l00003ooooo`;o00001?ooool3o`0000gooooo1Ol00000
1?oooooo0000o`000?ooool2o`0000?ooooo0ol00004ooooo`;o00001?ooool2o`000003ooooool0
003o000000kooooo0_l000000ooooooo0000o`00000Aooooo`;o00001_ooool2o`000003ooooool0
003o000000;ooooo0_l00004ooooo`;o00000_ooool2o`0000Wooooo0_l00002ooooo`;o00002?oo
ool4o`0000Cooooo0_l00004ooooo`;o00004?ooool3o`0000[ooooo1?l00008ooooo`;o00001Ooo
ool3o`0003cooooo000Looooo`03o`000?oooooooooo03Gooooo0_l000000ooooooo0000o`000004
ooooo`;o00001?ooool3o`0000oooooo0ol00004ooooo`;o00001?ooool5o`0000Cooooo0_l00004
ooooo`;o00003_ooool2o`0000?ooooo0_l0000:ooooo`;o00000oooool2o`0000Kooooo0_l00000
0ooooooo0000o`000002ooooo`;o00000oooool2o`0000kooooo0_l00005ooooo`;o00001oooool2
o`0000Gooooo0_l00007ooooo`Go00002Oooool3o`0000[ooooo0_l000000ooooooo0000o`000007
ooooo`;o00001Oooool2o`0003gooooo000Looooo`03o`000?oooooooooo03Gooooo0_l000001?oo
oooo0000o`000?ooool2o`0001[ooooo0_l0000:ooooo`Go00001?ooool3o`0000;ooooo0_l00000
0ooooooo0000o`00000Aooooo`;o00002_ooool2o`0001Oooooo0_l00005ooooo`;o000000?ooooo
o`000?l000002oooool2o`0000kooooo0_l00002ooooo`;o00000oooool5o`0000Kooooo0_l00009
ooooo`;o00001_ooool2o`0000gooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0koooo
o`;o000000?oooooo`000?l000005oooool2o`0000Cooooo0_l00003ooooo`;o00002Oooool9o`00
00Gooooo0_l00002ooooo`?o00007_ooool2o`0000[ooooo0_l00005ooooo`;o000000?oooooo`00
0?l000003?ooool4o`0000oooooo1Ol0000;ooooo`Co00001oooool2o`0000cooooo0ol000000ooo
oooo0000o`000002o`000003ooooool0003o000003kooooo000Looooo`03o`000?oooooooooo03ko
oooo0_l00004ooooo`;o00003?ooool2o`0000Cooooo0_l00003ooooo`;o00000oooool2o`0000;o
oooo0_l00006ooooo`?o000000Coooooo`000?l0003o00001?ooool4o`0000;ooooo0ol00005oooo
o`;o00000_ooool2o`0000[ooooo0ol00005ooooo`?o00002_ooool2o`0000Wooooo0_l00007oooo
o`;o00000_ooool4o`0000cooooo0_l000000ooooooo0000o`000004o`0000;ooooo1Ol00005oooo
o`Co00004oooool3o`000003ooooool0003o000000;o0000@Oooool001cooooo00?o0000oooooooo
ool0=Oooool2o`0000gooooo0_l0000<ooooo`;o00000oooool3o`0000Cooooo0_l00006ooooo`Co
00001oooool2o`0000Kooooo0ol0000;ooooo`?o000000?oooooo`000?l000000ol00007ooooo`?o
00001Oooool4o`00017ooooo0_l000000ooooooo0000o`000007ooooo`;o00004_ooool2o`000003
ooooool0003o000000Co00000_ooool6o`0000Kooooo0_l000000ooooooo0000o`000002o`0000ko
oooo0_l00002ooooo`;o00001Oooool2o`0003cooooo000Looooo`03o`000?oooooooooo02Cooooo
0_l0000>ooooo`?o00001Oooool2o`0001Wooooo0ol00004ooooo`;o00002?ooool2o`0000Oooooo
0_l00007ooooo`;o000000?oooooo`000?l000000oooool2o`0000Cooooo0_l00003ooooo`Go0000
1Oooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0ol00006ooooo`?o
00000_ooool3o`0001Sooooo0_l00005ooooo`;o00000_ooool2o`0000;ooooo0_l00004ooooo`;o
00002?ooool5o`0000?ooooo0ol0000<ooooo`;o00001Oooool2o`0003cooooo000Looooo`03o`00
0?oooooooooo02Cooooo0_l0000>ooooo`;o00001_ooool2o`0000;ooooo0_l00002ooooo`;o0000
2?ooool2o`0000Sooooo0_l0000:ooooo`;o00001?ooool2o`0000Wooooo0_l00006ooooo`;o0000
0oooool2o`0000Wooooo0_l000000ooooooo0000o`000009ooooo`;o000000Coooooo`000?l0003o
oooo0_l00002ooooo`?o00001_ooool3o`0000;ooooo0_l0000Hooooo`Co00001?ooool2o`0000;o
oooo0_l00002ooooo`;o00003_ooool2o`0000Kooooo0ol0000?ooooo`;o0000@?ooool001cooooo
00?o0000ooooooooool0>Oooool2o`0000Gooooo0_l000000ooooooo0000o`000002o`0000Oooooo
0_l00003ooooo`;o00000oooool2o`0000Wooooo0ol00004ooooo`?o00002?ooool2o`0000;ooooo
1_l00008ooooo`;o00001?ooool2o`000003ooooool0003o000000Gooooo0_l00004ooooo`;o0000
2oooool2o`0000?ooooo1Ol00003ooooo`;o00001Oooool2o`000003ooooool0003o000000[ooooo
1?l000000ooooooo0000o`000005ooooo`Co000000?oooooo`000?l000001oooool2o`0000_ooooo
0_l00003ooooo`;o00001oooool2o`0000?ooooo0_l0000Kooooo`;o00008oooool001cooooo00?o
0000ooooooooool0>Oooool2o`0000Sooooo1Ol00002ooooo`;o00001Oooool6o`000003ooooool0
003o000000Wooooo0_l00006ooooo`;o00003?ooool4o`0000?ooooo0_l00005ooooo`;o00001ooo
ool2o`0000Gooooo0_l00004ooooo`;o00002oooool2o`0000?ooooo1_l00002ooooo`;o00001Ooo
ool2o`000003ooooool0003o000000Gooooo0_l00002ooooo`Co00000_ooool2o`0000Cooooo0_l0
00001?oooooo0000o`000?ooool2o`0000Kooooo0ol000000ooooooo0000o`000008ooooo`;o0000
0oooool4o`0000Gooooo1?l0000Nooooo`;o00008oooool001cooooo00?o0000ooooooooool0?Ooo
ool3o`0000Kooooo0_l00002ooooo`;o00001Oooool2o`0000;ooooo0_l000000ooooooo0000o`00
000Aooooo`;o000000?oooooo`000?l000002Oooool2o`0000Gooooo0_l0000Eooooo`;o00001_oo
ool2o`0000Kooooo0_l00006ooooo`;o00000_ooool2o`0000Oooooo1?l00008ooooo`;o00000_oo
ool2o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o00000oooool2o`0000Oooooo0ol0
00000ooooooo0000o`00000?ooooo`;o00001oooool2o`0004?ooooo000Looooo`03o`000?oooooo
oooo03gooooo0ol00005ooooo`Co00008Oooool2o`0000;ooooo0_l00005ooooo`;o00000_ooool2
o`0001Wooooo0_l000000ooooooo0000o`000005ooooo`Ko00000oooool2o`0000?ooooo0_l00000
0ooooooo0000o`000005ooooo`;o00001?ooool4o`0000Sooooo0_l00005ooooo`;o00000oooool2
o`0000Oooooo0_l00007ooooo`?o0000H?ooool001cooooo00?o0000ooooooooool0<?ooool2o`00
00Sooooo0ol00004ooooo`;o00000_ooool4o`00027ooooo0_l00005ooooo`;o00000_ooool2o`00
00Cooooo0_l00005ooooo`;o00004?ooool2o`0000?ooooo0_l00003ooooo`Ko00002?ooool2o`00
00Sooooo0_l00004ooooo`;o000000?oooooo`000?l000001_ooool2o`00013ooooo0_l0000;oooo
o`;o00000oooool2o`0000Oooooo0_l00006ooooo`;o00002?ooool2o`0000gooooo0_l0000boooo
o`007?ooool00ol0003oooooooooo`0Yooooo`;o00001Oooool2o`0000Sooooo0ol00003ooooo`Go
00004oooool4o`0000Gooooo0_l000000ooooooo0000o`000008ooooo`;o000000?oooooo`000?l0
00000_l000000ooooooo0000o`000002ooooo`?o00001Oooool2o`0001Gooooo0_l00004ooooo`Co
00003_ooool2o`0000Wooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l0000@oooo
o`;o00004?ooool2o`0000Oooooo0_l00002ooooo`;o00000_ooool2o`0000Gooooo0_l000000ooo
oooo0000o`00000=ooooo`;o0000<_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2
ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo02Wooooo0_l0
0005ooooo`;o00003_ooool2o`000003ooooool0003o000000_ooooo0_l000000ooooooo0000o`00
0003ooooo`Co00000_ooool2o`000004ooooool0003o0000ooooo`;o00002?ooool2o`000003oooo
ool0003o000000_o000000Coooooo`000?l0003o00000_ooool4o`0000Cooooo1?l0000Kooooo`;o
00001?ooool2o`0000Wooooo0_l000001?oooooo0000o`000?ooool2o`0001Kooooo0_l0000?oooo
o`;o000000?oooooo`000?l000000_l00006ooooo`;o000000?oooooo`000?l000001_ooool2o`00
04Cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOo
oooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0`ooooo`;o00007_ooool5o`0000Wooooo1Ol0
000>ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo0_l000001?oooooo0000o`00
0?l00002ooooo`Co000000Coooooo`000?l0003ooooo1_l0000@ooooo`;o00001oooool2o`0000Oo
oooo0_l00004ooooo`;o00001_ooool2o`0000?ooooo0_l00004ooooo`;o00002Oooool4o`00017o
oooo1Ol00003ooooo`;o00001?ooool3o`0004_ooooo00000ooooooo410@ooooo`02ooooo`03oa0@
4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo04;o
oooo0_l0000>ooooo`;o00001_ooool4o`000003ooooool0003o000000;o000000?oooooo`000?l0
00002?ooool2o`0000Gooooo0_l00005ooooo`;o00000_ooool2o`0000;ooooo1ol00003ooooo`Co
00002oooool2o`0000?ooooo0_l0000@ooooo`Co00000_ooool4o`0000Wooooo0_l00004ooooo`;o
00000oooool2o`0000Cooooo0_l00004ooooo`;o00002?ooool2o`0000?ooooo0_l00006ooooo`;o
00001Oooool3o`0000Cooooo0_l0000<ooooo`;o0000=_ooool00003ooooool0003ooooo00;ooooo
00?o0000ooooooooool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0000kooooo`Co
00000oooool3o`00017ooooo2?l000001?oooooo0000o`000?l00002ooooo`;o00001oooool3o`00
00Gooooo0_l00003ooooo`;o00001_ooool8o`000003ooooool0003o000000Co00000_ooool2o`00
00Sooooo0_l00007ooooo`?o00003Oooool3o`000003ooooool0003o000000;o00005?ooool2o`00
00[ooooo0_l000001?oooooo0000o`000?l00004ooooo`;o00004oooool2o`0000Cooooo0_l0000<
ooooo`;o0000=_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0
003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0>oooool4o`0000Cooooo0_l0000A
ooooo`Co00004oooool2o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0000Kooooo3Ol00004
ooooo`;o00004Oooool4o`0000gooooo0_l000001?oooooo0000o`000?l0000Jooooo`;o00002?oo
ool3o`0001kooooo0_l0000?ooooo`;o0000=?ooool00003ooooool@413ooooo00;ooooo00?o410@
ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo04[ooooo0_l00000
0ooooooo0000o`00000>ooooo`;o00001?ooool2o`0000cooooo0_l00002ooooo`;o00001_ooool2
o`000003ooooool0003o000000Ko00000_ooool6o`0000Kooooo0_l0000>ooooo`Co00000_ooool2
o`0000;ooooo0_l00008ooooo`Co00004Oooool2o`0000Kooooo0_l00006ooooo`;o00000_ooool2
o`0000Oooooo0_l0000Dooooo`;o00001Oooool2o`0000Sooooo0_l0000dooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0AOoo
ool2o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`;o00001_ooool4o`0000Cooooo1?l0
0006ooooo`;o00003_ooool2o`000003ooooool0003o000000Oo000000?oooooo`000?l000001Ol0
0005ooooo`;o00002_ooool2o`0000;ooooo0_l00004ooooo`;o00000_ooool2o`000003ooooool0
003o000000Oooooo0ol0000@ooooo`;o00002Oooool2o`0000?ooooo0_l00002ooooo`?o000000?o
ooooo`000?l000000oooool3o`0000?ooooo0_l00002ooooo`;o00004Oooool4o`0003cooooo0000
1_ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003o
ooooooooo`15ooooo`;o00003?ooool2o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`Ko
00001?ooool4o`0000[ooooo6?l00002ooooo`;o00002oooool2o`0000?ooooo0_l0000:ooooo`;o
00000_ooool2o`000003ooooool0003o000000?o00002oooool2o`0000;ooooo0_l0000:ooooo`;o
00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`;o00000oooool6o`0001?o
oooo0_l0000looooo`007?ooool00ol0003oooooooooo`0nooooo`;o00001Oooool2o`0000[ooooo
0_l00005ooooo`;o00000_ooool2o`0000Wooooo1?l00003ooooo`?o00002_ooool2o`0000;ooooo
1?l000000ooooooo0000o`00000Ao`0000Gooooo0_l00009ooooo`;o000000Coooooo`000?l0003o
oooo0_l00008ooooo`Go00003_ooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool5o`0000;o
oooo0_l00005ooooo`;o00000_ooool2o`0000Gooooo0_l00002ooooo`;o00003_ooool2o`0004?o
oooo000Looooo`03o`000?oooooooooo03kooooo0_l00005ooooo`;o00002_ooool2o`0000Wooooo
0_l00004ooooo`;o00001Oooool2o`0000?ooooo0_l00004ooooo`;o00000_ooool3o`0000?ooooo
2_l000001Ooooooo0000o`000?l0003ooooo00So00001oooool2o`0000Sooooo0ol000001?oooooo
0000o`000?ooool2o`0000Oooooo0_l000001?oooooo0000o`000?l0000<ooooo`;o00002Oooool2
o`0000;ooooo1?l000000ooooooo0000o`000002o`0000Gooooo0ol000000ooooooo0000o`000003
ooooo`Co00000_ooool2o`0000kooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`1Goooo
o`;o00002Oooool2o`0000_ooooo0_l00003ooooo`Oo000000?oooooo`000?l000002Ol00002oooo
o`co000000?oooooo`000?l000001oooool2o`000003ooooool0003o000000;ooooo0_l00007oooo
o`;o00001Oooool7o`0000;ooooo1?l00005ooooo`;o00002Oooool2o`000003ooooool0003o0000
00;o00000_ooool4o`0000Kooooo0_l00006ooooo`;o00000oooool5o`000003ooooool0003o0000
04kooooo000Looooo`03o`000?oooooooooo03oooooo0_l0000Fooooo`;o00000oooool2o`0000So
oooo0_l00003ooooo`;o00000_ooool3o`0000Cooooo0_l00004oooooago000000?oooooo`000?l0
00000_l000001?oooooo0000o`000?ooool6o`0000Oooooo0ol00003ooooo`ko00003Oooool5o`00
0003ooooool0003o000000Kooooo0_l00003ooooo`;o00001?ooool2o`0000Sooooo0_l000001?oo
oooo0000o`000?ooool4o`0004cooooo000Looooo`03o`000?oooooooooo03oooooo0_l0000Aoooo
o`;o000000?oooooo`000?l000001Oooool2o`0000Sooooo0_l00003ooooo`;o00000oooool2o`00
00Sooooo0_l000000ooooooo0000o`00000Jo`000003ooooool0003o000000;o000000?oooooo`00
0?l000000oooool4o`0000Sooooo1ol000000ooooooo0000o`000005o`00013ooooo1_l00008oooo
o`?o00000oooool2o`0000?ooooo0ol0000:ooooo`;o00001?ooool2o`0000;ooooo0ol00017oooo
o`007?ooool00ol0003oooooooooo`0iooooo`;o00002Oooool2o`0000Wooooo0_l000001?oooooo
0000o`000?ooool2o`0000Gooooo0_l00006ooooo`;o00005?oooolNo`0000Oooooo0_l00005oooo
o`;o00001_ooool2o`0000;ooooo3ol0000>ooooo`;o00000_ooool2o`0000Oooooo0ol00003oooo
o`;o00000oooool4o`0000[ooooo0_l00002ooooo`;o00000oooool4o`0004Oooooo000Looooo`03
o`000?oooooooooo03Wooooo0_l00005ooooo`;o00000_ooool4o`0000Oooooo0_l00003ooooo`?o
00001Oooool2o`0000Kooooo1?l0000Aoooooako00001?ooool2o`0000Sooooo0_l00007ooooo`;o
00000_oooolAo`0001Wooooo0_l00004ooooo`Co000000?oooooo`000?l000000_l00002ooooo`;o
00002_ooool2o`000003ooooool0003o000000;o0000BOooool001cooooo00?o0000ooooooooool0
=_ooool2o`0000Cooooo1_l00004ooooo`;o00003?ooool3o`0000;ooooo0_l0000:ooooo`?o0000
1_ooool2o`0000Wooooo3Ol00002oooooa3o00000oooool2o`0000;ooooo0_l00004ooooo`;o0000
2?ooool2o`000003ooooool0003o000000oo00005?ooool6o`0000Oooooo0_l00003ooooo`;o0000
0_ooool2o`0000gooooo0ol0001:ooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00001?oo
ool4o`0000Gooooo0ol00002ooooo`;o00001Oooool2o`0000Cooooo1?l0000:ooooo`;o00001ooo
ool2o`0000Wooooo8?l00003ooooo`;o000000?oooooo`000?l000003_oooolBo`000003ooooool0
003o000001?ooooo1_l00006ooooo`;o00000oooool2o`000003ooooool0003o000000;o00002Ooo
ool2o`0000;ooooo0ol0001:ooooo`007?ooool00ol0003oooooooooo`0looooo`;o00000oooool2
o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Cooooo1?l0000I
ooooo`;o00001?oooolOo`0000?ooooo1_l0000=oooooaGo00001Oooool2o`0000Gooooo0_l00009
ooooo`;o00001_ooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`0000Wooooo0_l00003
ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0@Oooool2o`0000;ooooo0_l000001?oo
oooo0000o`000?ooool5o`0000Wooooo0_l00002ooooo`;o00005Oooool4o`0000?ooooo4Ol00000
0ooooooo0000o`00000:o`0000Gooooo1?l0000=oooooa?o00001oooool2o`0000Gooooo0_l00008
ooooo`;o00004oooool2o`0000?ooooo1Ol00005ooooo`?o0000B?ooool001cooooo0_l00012oooo
o`?o00001?ooool2o`000003ooooool0003o000000?o00003Oooool4o`0000oooooo0_l00004oooo
ob?o00001Oooool2o`0000Wooooo0ol00004oooooa;o00001Oooool2o`00017ooooo0ol0000Boooo
o`;o00000oooool5o`0000Gooooo0ol00018ooooo`007?ooool00ol0003oooooooooo`11ooooo`?o
000000?oooooo`000?l000001_ooool2o`0000Oooooo0_l00007ooooo`;o00002?ooool2o`0000Go
oooo0_l00002ooooo`;o00000_oooolSo`0000?ooooo0ol00007ooooo`Co000000?oooooo`000?l0
00005Ol00003ooooo`;o00004_ooool2o`0000Sooooo0_l0000=ooooo`;o00000_ooool2o`000003
ooooool0003o0000017ooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`12ooooo`;o0000
00?oooooo`000?l000002_ooool2o`0000;ooooo0ol0000@ooooo`Go00001oooool2o`0000Cooooo
1_l000000ooooooo0000o`00000Do`0000;ooooo0_l00004ooooo`;o00000_ooool2o`0000;ooooo
7_l00002ooooo`;o00007?ooool2o`000003ooooool0003o000000kooooo1Ol0000Aooooo`;o0000
>Oooool001cooooo00?o0000ooooooooool0A_ooool6o`0000?ooooo1?l00002ooooo`;o00003ooo
ool7o`0000cooooo1_l000000ooooooo0000o`00000Fo`0000_ooooo0_l00002ooooo`Co000000?o
ooooo`000?l000005ol00002ooooo`;o00007oooool2o`00013ooooo1?l0001;ooooo`007?ooool0
0ol0003oooooooooo`16ooooo`So000000?oooooo`000?l000001?ooool2o`0000oooooo0ol00000
1?oooooo0000o`000?l00003ooooo`;o00001_oooolPo`0000Sooooo0_l0000:ooooo`Co000000Go
ooooo`000?l0003o0000ooooo`0>o`0000?ooooo0_l0000Iooooo`;o00004?ooool2o`0000Gooooo
1?l0001;ooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00001_ooool3o`0000Oooooo0ol0
000;ooooo`;o00000_ooool2o`0000Kooooo2?l000000ooooooo0000o`00000Eo`0000Sooooo0_l0
0005ooooo`;o00000ooooolFo`000004ooooool0003o0000ooooo`;o00000_ooool2o`0001Gooooo
0_l0000:ooooo`?o00000oooool2o`0000Oooooo0_l0001;ooooo`007?ooool00ol0003ooooooooo
o`1Dooooo`;o00002?ooool3o`0000_ooooo0_l00005ooooo`;o00001OoooolHo`000003ooooool0
003o000001;ooooo7_l00005ooooo`;o00003_ooool2o`0000Gooooo1?l00008ooooo`?o00002Ooo
ool2o`000003ooooool0003o000004_ooooo000Looooo`03o`000?oooooooooo057ooooo0_l00000
0ooooooo0000o`00000Mooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo5?l0000E
ooooo`Ko000000?oooooo`000?l000003ol000000ooooooo0000o`000003o`0001Gooooo0ol00003
ooooo`;o000000?oooooo`000?l000000oooool2o`0000[ooooo0_l00002ooooo`?o000000?ooooo
o`000?l00000Boooool001cooooo00?o0000ooooooooool0DOooool2o`0001Wooooo0ol00007oooo
o`;o00001ooooolDo`0001;ooooo2Ol000000ooooooo0000o`000008o`000003ooooool0003o0000
00So00005oooool2o`0000?ooooo0ol00005ooooo`;o00002_ooool3o`000003ooooool0003o0000
00?o0000C?ooool001cooooo00?o0000ooooooooool0A?ooool2o`0000_ooooo0_l000000ooooooo
0000o`00000@ooooo`;o00001?ooool3o`0000gooooo0ol000000ooooooo0000o`00000Ao`0000ko
oooo1_l00002ooooo`;o000000?oooooo`000?l000001?ooool8o`000003ooooool0003o000000Oo
00006_ooool2o`000003ooooool0003o000000;o00004?ooool2o`0000?ooooo0ol0001<ooooo`00
7?ooool00ol0003oooooooooo`14ooooo`;o00001?ooool2o`0000Gooooo0_l000000ooooooo0000
o`000008ooooo`;o00000_ooool2o`0000;ooooo0_l00006ooooo`;o000000?oooooo`000?l00000
2Oooool3o`0000;ooooo1ol000000ooooooo0000o`000003o`0001?ooooo1Ol00003ooooo`;o0000
0oooool2o`0000;ooooo4_l0000Jooooo`;o00000oooool2o`0000gooooo0_l0001Eooooo`007?oo
ool00ol0003oooooooooo`1:ooooo`;o00002?ooool2o`0000Cooooo0_l00002ooooo`;o00000_oo
ool2o`0000[ooooo0_l000000ooooooo0000o`000005ooooo`;o00001_ooool:o`0001[ooooo0_l0
00000ooooooo0000o`000007o`0000;ooooo4Ol000000ooooooo0000o`000002o`0002[ooooo0_l0
0009ooooo`Co0000B?ooool001cooooo00?o0000ooooooooool0A_ooool2o`0000Cooooo0_l0000<
ooooo`;o00002Oooool2o`0000;ooooo0_l0000;ooooo`Co00001_ooool2o`0000?ooooo1Ol0000M
ooooo`Oo00001_ooool9o`0000;ooooo1?l000000ooooooo0000o`000002o`00013ooooo0_l00005
ooooo`;o00000_ooool2o`0000Sooooo0_l00008ooooo`;o00001?ooool6o`0004Kooooo000Loooo
o`03o`000?oooooooooo04Kooooo0_l00004ooooo`;o00003Oooool3o`0000Oooooo1_l00003oooo
o`;o00001_ooool4o`0000Cooooo0_l00007ooooo`?o00004?ooool2o`0000Sooooo0_l0000>oooo
o`oo00001?ooool2o`0000oooooo0_l00003ooooo`So00002?ooool2o`0000;ooooo0_l00002oooo
o`Ko00001_ooool2o`0004Kooooo000Looooo`03o`000?oooooooooo04Sooooo0_l00002ooooo`;o
00000_ooool2o`0000?ooooo0_l00004ooooo`?o00002Oooool2o`0000Gooooo0_l00008ooooo`;o
00001?ooool2o`0000Oooooo0ol0000>ooooo`Co00002?ooool2o`0000?ooooo0_l00009ooooo`_o
00002?ooool2o`0000_ooooo0_l00005ooooo`Co00000_ooool2o`0000?ooooo0_l00003ooooo`;o
00000_ooool5o`000003ooooool0003o000000Co0000C_ooool001cooooo00?o0000ooooooooool0
B?ooool2o`0000Kooooo0_l00003ooooo`;o00001oooool2o`000003ooooool0003o000000oooooo
0_l000001?oooooo0000o`000?l0000Pooooo`;o000000Coooooo`000?l0003o00002oooool2o`00
00Cooooo0_l00005ooooo`So000000?oooooo`000?l000002Oooool2o`0000Sooooo0_l00003oooo
o`Co00002Oooool2o`0000;ooooo0ol00002ooooo`;o000000Coooooo`000?l0003ooooo0_l0001B
ooooo`007?ooool2o`0005oooooo0_l000000ooooooo0000o`000008ooooo`;o000000?oooooo`00
0?l000000_ooool2o`000004ooooool0003o0000o`0000Gooooo0_l0000Fooooo`;o00001?ooool3
o`0000;ooooo0_l0000=ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00002
ooooo`Oo00001?ooool3o`0000gooooo0_l0000?ooooo`;o00002_ooool2o`00057ooooo000Loooo
o`03o`000?oooooooooo05;ooooo0_l0000:ooooo`;o000000Coooooo`000?l0003ooooo0_l00005
ooooo`Go00003Oooool2o`0000oooooo0_l00005ooooo`Co000000?oooooo`000?l000001?ooool2
o`00013ooooo0_l00002ooooo`;o00001_ooool7o`0000;ooooo1?l0000Dooooo`;o00005Oooool2
o`00057ooooo000Looooo`03o`000?oooooooooo05;ooooo0_l00006ooooo`Co00000oooool2o`00
0003ooooool0003o000000Kooooo0_l0000Pooooo`;o00001oooool5o`0000Wooooo0_l0000;oooo
o`;o00002oooool2o`000003ooooool0003o000000?ooooo0_l0000:ooooo`;o00000oooool2o`00
00Gooooo0_l0001Xooooo`007?ooool00ol0003oooooooooo`1Hooooo`Ko00006?ooool2o`0000_o
oooo0_l00003ooooo`;o00002_ooool2o`000003ooooool0003o000000;o00002_ooool4o`0000Co
oooo0_l00003ooooo`;o00003_ooool2o`0000_ooooo0_l00002ooooo`;o00000oooool2o`0000So
oooo0_l0001Uooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00007_ooool2o`0001Oooooo
0_l00003ooooo`;o00002oooool2o`0000?ooooo0_l00008ooooo`Co00004?ooool3o`0000Cooooo
0_l0000Pooooo`;o00004Oooool2o`0000Oooooo0_l000001?oooooo0000o`000?ooool2o`0005Ko
oooo000Looooo`03o`000?oooooooooo03Sooooo0_l0000Dooooo`;o00008Oooool2o`00017ooooo
0_l00003ooooo`;o00001_ooool3o`0000Kooooo0_l00002ooooo`;o000000?oooooo`000?l00000
Aoooool3o`000003ooooool0003o000000?o0000E_ooool001cooooo00?o0000ooooooooool0C_oo
ool2o`0000Sooooo0_l0000Eooooo`;o00002_ooool3o`0000;ooooo0ol000000ooooooo0000o`00
0003ooooo`;o00000oooool2o`000003ooooool0003o000000Oooooo0_l00002ooooo`;o000000?o
ooooo`000?l000003_ooool2o`0001;ooooo0_l00005ooooo`;o00007?ooool2o`0000?ooooo0_l0
001Hooooo`007?ooool00ol0003oooooooooo`1Gooooo`?o00005Oooool5o`0000Oooooo0ol00002
ooooo`?o00002oooool4o`0000Oooooo0_l00003ooooo`;o00004Oooool2o`0001;ooooo1?l00003
ooooo`;o00007oooool4o`0005Sooooo000Looooo`03o`000?oooooooooo05Oooooo1?l00005oooo
o`;o00003_ooool4o`0000cooooo0_l0000>ooooo`;o00001oooool2o`0000[ooooo0_l0000Joooo
o`;o00000_ooool4o`0000Sooooo0_l0000Iooooo`?o000000?oooooo`000?l00000Eoooool001co
oooo00?o0000ooooooooool0FOooool2o`0000Gooooo0_l00002ooooo`;o00003oooool2o`0000co
oooo1?l0000Nooooo`;o00002Oooool2o`0000[ooooo0_l00003ooooo`;o000000?oooooo`000?l0
00000_l00002ooooo`;o00001Oooool2o`0000Wooooo0_l00007ooooo`;o00001Oooool3o`000003
ooooool0003o000005Oooooo000Looooo`03o`000?oooooooooo06?ooooo0ol00004ooooo`;o0000
1Oooool6o`000003ooooool0003o000000Wooooo1?l00003ooooo`;o000000?oooooo`000?l00000
6oooool2o`0000Cooooo0_l0000:ooooo`;o00001_ooool8o`0000Wooooo0_l00003ooooo`Co0000
1oooool2o`0006;ooooo000Looooo`03o`000?oooooooooo04oooooo0_l00004ooooo`;o00000ooo
ool2o`0000Oooooo0_l00005ooooo`;o00001Oooool4o`0000?ooooo0_l000000ooooooo0000o`00
0004ooooo`?o00001_ooool2o`000003ooooool0003o000001_ooooo0_l00008ooooo`Co00002Ooo
ool2o`0000;ooooo1Ol0000;ooooo`;o00000oooool2o`0006gooooo000Looooo`03o`000?oooooo
oooo04oooooo0ol00003ooooo`;o00000oooool2o`0000?ooooo0_l00005ooooo`;o00002Oooool2
o`0000Sooooo0_l00004ooooo`?o00002?ooool2o`00017ooooo0_l0000Cooooo`Co00002Oooool2
o`0000Oooooo0_l00006ooooo`;o00004Oooool3o`00067ooooo000Looooo`03o`000?oooooooooo
053ooooo0_l00002ooooo`;o00001?ooool2o`0000?ooooo0_l00002ooooo`;o000000?oooooo`00
0?l000001_ooool4o`0000Wooooo0_l00002ooooo`Co00000oooool2o`0000;ooooo1?l00008oooo
o`;o00001oooool2o`0001Kooooo0_l0000<ooooo`;o00000oooool2o`000003ooooool0003o0000
00?ooooo0_l0000Aooooo`?o00005Oooool2o`0004[ooooo000Looooo`03o`000?oooooooooo04Co
oooo0_l00008ooooo`;o00001?ooool2o`0000gooooo0_l00009ooooo`Go00001Oooool3o`0000Co
oooo1Ol000001?oooooo0000o`000?l00002ooooo`;o00002_ooool2o`0001_ooooo0_l00002oooo
o`;o00000_ooool2o`0000?ooooo0_l00003ooooo`;o00000oooool2o`000004ooooool0003o0000
ooooo`;o00005?ooool2o`0001Gooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`14oooo
o`;o00002?ooool2o`00027ooooo0_l00003ooooo`Go00001Oooool4o`000003ooooool0003o0000
00;ooooo0_l00008ooooo`;o00002Oooool2o`0000cooooo0_l00005ooooo`;o00000_ooool2o`00
00;ooooo0ol000001?oooooo0000o`000?l00007ooooo`?o00000oooool5o`00013ooooo0_l0001S
ooooo`007?ooool2o`0007Oooooo0_l00004ooooo`;o00001oooool2o`0000;ooooo0_l000000ooo
oooo0000o`000004ooooo`Co00002?ooool2o`0000cooooo0_l00005ooooo`;o00000_ooool2o`00
00?ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00001?ooool2o`0000Cooooo0_l00000
0ooooooo0000o`00000@ooooo`;o0000Hoooool001cooooo00?o0000ooooooooool0GOooool2o`00
01gooooo0_l00007ooooo`;o00001Oooool4o`0000;ooooo1?l00004ooooo`;o00003oooool2o`00
00Kooooo1Ol00002ooooo`;o00000_ooool2o`0000?ooooo0_l00008ooooo`Co0000N?ooool001co
oooo00?o0000ooooooooool0GOooool2o`0000Sooooo0_l0000:ooooo`;o00000_ooool2o`0000;o
oooo0_l00002ooooo`;o00003Oooool2o`0000[ooooo0_l0000?ooooo`;o00001oooool4o`0000;o
oooo0_l00002ooooo`;o00001?ooool2o`0000Oooooo1?l0000<ooooo`;o00002_ooool2o`0005ko
oooo000Looooo`03o`000?oooooooooo05?ooooo0_l0000>ooooo`;o00000_ooool2o`0000Cooooo
0ol00003ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0000;ooooo0ol00002ooooo`;o
0000=oooool2o`0000Cooooo0ol00008ooooo`?o00001oooool3o`0000;ooooo0_l0000:ooooo`;o
0000G_ooool001cooooo00?o0000ooooooooool0Doooool2o`0000kooooo0_l00002ooooo`;o0000
1?ooool3o`0000Kooooo1?l00005ooooo`Oo0000=oooool2o`0000Cooooo0_l00003ooooo`;o0000
1?ooool2o`0000Sooooo0ol00005ooooo`;o00000_ooool2o`0006?ooooo000Looooo`03o`000?oo
oooooooo05[ooooo0_l00007ooooo`;o00000_ooool2o`0000;ooooo0_l00009ooooo`Co00001Ooo
ool2o`000003ooooool0003o000000[ooooo0_l0000booooo`Co00000_ooool2o`000003ooooool0
003o000000Cooooo0_l00006ooooo`;o00001Oooool2o`0000;ooooo0_l000000ooooooo0000o`00
001Pooooo`007?ooool00ol0003oooooooooo`1Jooooo`;o00001?ooool2o`000003ooooool0003o
000000Kooooo0_l0000:ooooo`;o00002_ooool2o`0000Wooooo0_l0000?ooooo`;o00008Oooool4
o`0000Gooooo0_l00004ooooo`;o00005?ooool2o`00063ooooo000Looooo`03o`000?oooooooooo
05Sooooo0_l000000ooooooo0000o`000003ooooo`;o00008Oooool2o`0000Gooooo0_l00002oooo
o`;o00002_ooool2o`000003ooooool0003o000000;o00004?ooool2o`0000_ooooo0_l00004oooo
o`;o00007Oooool2o`0000;ooooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o
000000?oooooo`000?l00000;Oooool6o`0000[ooooo0_l000000ooooooo0000o`00000:ooooo`;o
00001_ooool2o`0000_ooooo0_l0000Rooooo`?o00000_ooool2o`00063ooooo000Looooo`03o`00
0?oooooooooo06Sooooo0_l0000Kooooo`;o00001Oooool2o`0001Oooooo0_l00002ooooo`;o0000
2_ooool2o`0001?ooooo0_l0000Aooooo`;o00000oooool2o`0006Gooooo000Looooo`03o`000?oo
oooooooo06Sooooo0_l0000@ooooo`?o000000?oooooo`000?l000001Oooool2o`0000Wooooo0_l0
00000ooooooo0000o`000006ooooo`;o00002?ooool2o`0000[ooooo0_l00002ooooo`;o00001?oo
ool2o`0000gooooo0_l0000@ooooo`?o0000J_ooool001cooooo00?o0000ooooooooool0LOooool2
o`0000Oooooo0ol000000ooooooo0000o`000007ooooo`?o00001_ooool2o`000003ooooool0003o
000000Kooooo0_l0000Dooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`00000F
ooooo`;o00001?ooool2o`0006_ooooo000Looooo`03o`000?oooooooooo06Oooooo0_l00005oooo
o`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000008ooooo`;o000000Goooooo`00
0?l0003o0000ooooo`03o`0000Sooooo0_l0000:ooooo`;o00006oooool2o`000003ooooool0003o
000000oooooo0_l00005ooooo`?o00001oooool6o`0006?ooooo000Looooo`03o`000?oooooooooo
06Oooooo0_l00005ooooo`;o00000oooool2o`000003ooooool0003o000000Sooooo0_l000001?oo
oooo0000o`000?l0000<ooooo`;o00002?ooool4o`0000?ooooo0_l0000Dooooo`Co00000_ooool2
o`0000Wooooo0ol00002ooooo`;o00001_ooool2o`0000Oooooo1_l0001Sooooo`0000Koooooonk^
k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo
00?o0000ooooooooool0Koooool2o`0000Gooooo1?l00004ooooo`;o00000oooool2o`0000Sooooo
0_l00003ooooo`;o00002?ooool2o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`Co0000
3?ooool3o`0000?ooooo0_l00008ooooo`Co000000?oooooo`000?l000000oooool2o`0000;ooooo
0_l0001`ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7o
V9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0K_ooool3o`0000?ooooo0_l00002oooo
o`;o00001?ooool2o`0000?ooooo0_l00008ooooo`;o00000oooool2o`0000cooooo0_l00007oooo
o`Co00002_ooool2o`0000?ooooo0_l0000;ooooo`Oo00000oooool2o`0000?ooooo0_l0001_oooo
o`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooooooo`1Vooooo`;o00001_ooool2o`0000Cooooo0_l00004oooo
o`;o00000_ooool2o`0000Cooooo0_l00002ooooo`Co00001?ooool2o`0002Gooooo0_l00003oooo
o`;o00000_ooool2o`000003ooooool0003o000000Gooooo1?l00009ooooo`?o00001Oooool2o`00
06Sooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P06ooooo`?o0000I_ooool2o`0000cooooo0_l00004ooooo`;o00000_ooool2o`00
00Cooooo0ol000000ooooooo0000o`000002o`0000Cooooo0_l000000ooooooo0000o`00000@oooo
o`;o00001_ooool2o`00017ooooo0_l000000ooooooo0000o`00000Booooo`Co00001?ooool2o`00
06Sooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Goc<c<o`000?l0
003o0000olc<c006ooooo`03o`000?oooooooooo073ooooo0_l00004ooooo`;o00003Oooool2o`00
00Kooooo0_l000001?oooooo0000o`000?ooool2o`00013ooooo0_l00006ooooo`Co0000:?ooool2
o`0006kooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go410@okZj
^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo06Wooooo0_l00005ooooo`;o00001?ooool2
o`0000Kooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l00002ooooo`;o000000?o
ooooo`000?l000001Oooool2o`0000Gooooo0_l00005ooooo`Go00001Oooool4o`0000?ooooo0_l0
000:ooooo`;o00001?ooool2o`00017ooooo0_l000000ooooooo0000o`00001Yooooo`0000Kooooo
ogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003o
ooooooooo`1Yooooo`;o00004oooool2o`000004ooooool0003o0000ooooo`;o00000oooool2o`00
00;ooooo0_l000000ooooooo0000o`000005ooooo`;o00001Oooool2o`0000Kooooo1?l00007oooo
o`;o00000_ooool3o`0000[ooooo0_l000001?oooooo0000o`000?ooool2o`00017ooooo0_l00000
0ooooooo0000o`00001Yooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@
413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`26ooooo`;o00001_ooool4o`0000Oooooo
0ol0000:ooooo`;o00000_ooool2o`0000Wooooo0_l0000>ooooo`;o0000P_ooool001cooooo00?o
0000ooooooooool0Q_ooool2o`0000Kooooo0_l000000ooooooo0000o`000006ooooo`?o00003Ooo
ool3o`0000Oooooo0ol0000>ooooo`;o0000Poooool001cooooo00?o0000ooooooooool0LOooool2
o`0001Oooooo0_l00005ooooo`;o00001_ooool2o`0000Cooooo0_l00008ooooo`;o00002?ooool3
o`0000kooooo0_l00023ooooo`007?ooool00ol0003oooooooooo`1aooooo`;o00005oooool2o`00
00Kooooo0_l0000;ooooo`;o00003?ooool2o`0000Cooooo1?l0000:ooooo`;o0000Q_ooool001co
oooo00?o0000ooooooooool0N?ooool2o`00013ooooo0_l00006ooooo`;o00001?ooool2o`0000;o
oooo0_l00009ooooo`;o00001?ooool2o`0000Cooooo1?l0000:ooooo`;o0000Q_ooool001cooooo
00?o0000ooooooooool0N?ooool2o`0000[ooooo0_l00002ooooo`;o00001Oooool2o`0000Oooooo
0_l00002ooooo`;o000000?oooooo`000?l000001Oooool3o`0000?ooooo0_l00004ooooo`?o0000
2_ooool2o`0008Sooooo000Looooo`03o`000?oooooooooo08Cooooo0_l00002ooooo`;o00001Ooo
ool2o`0000kooooo0_l00005ooooo`Co00000_ooool2o`0000Cooooo0ol0000:ooooo`?o0000Qooo
ool001cooooo00?o0000ooooooooool0Q?ooool2o`0001kooooo1_l0000Fooooo`;o0000Qoooool0
01cooooo00?o0000ooooooooool0QOooool2o`0000Gooooo0_l0000Cooooo`;o000000?oooooo`00
0?l000001Ol00003ooooo`Co00001?ooool2o`00097ooooo000Looooo`03o`000?oooooooooo08Go
oooo0_l00002ooooo`;o000000?oooooo`000?l000004oooool2o`0000?ooooo1Ol00003ooooo`Co
00001?ooool2o`00097ooooo000Looooo`03o`000?oooooooooo08Wooooo0_l000000ooooooo0000
o`00000;ooooo`;o00002oooool2o`0000Kooooo0_l0002Iooooo`007?ooool00ol0003ooooooooo
o`2Iooooo`;o0000[_ooool001cooooo0_l0002;ooooo`;o00001oooool2o`0000cooooo0_l0002V
ooooo`007?ooool00ol0003oooooooooo`2:ooooo`;o00000oooool2o`0000;ooooo0_l0000<oooo
o`;o0000Y_ooool001cooooo00?o0000ooooooooool0Soooool2o`0000;ooooo0ol0000;ooooo`;o
0000Y_ooool001cooooo00?o0000ooooooooool0U?ooool2o`0000?ooooo1?l00002ooooo`;o0000
9oooool2o`0007oooooo000Looooo`03o`000?oooooooooo09Wooooo1?l00002ooooo`;o00009ooo
ool2o`0007oooooo000Looooo`03o`000?oooooooooo0:Cooooo0_l0000Oooooo`;o0000P_ooool0
01cooooo00?o0000ooooooooool0U?ooool2o`0000kooooo0ol0000Nooooo`;o0000P_ooool001co
oooo00?o0000ooooooooool0U?ooool2o`0000oooooo0_l0002Rooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0;Wooooo0_l0002>ooooo`007?ooool0
0ol0003oooooooooo`2iooooo`;o0000S_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`2Eooooo`;o0000/_ooool001cooooo00?o0000ooooooooool0
UOooool2o`000;;ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01;ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB_ooool001Co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`00
0?oooooooooo00Gooooo0ol0003ooooood[ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_oo
ool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooo
oe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001;ooooo00?oEEEEofIVI_l00000
oooooomDooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00XOooool01?l@413o
0000o`000?ooool2o`000003oa0@4?oooooooooo01Kooooo1?l000002?l@413ooooooooooonHV9So
410@o`000?lb<S;oc<c<0oooool01?l@413o0000odA4A?o<c<`4ooooo`Go0000S?ooool00:;ooooo
00Go0000ooooooooooooooooo`000009ooooo`Ko00003?ooool00ol0003oooooooooo`02ooooo`05
oa0@4?nj^[[oooooogMgMolb<S801Oooool00onHV9So410@omgMg@03ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@0S?ooool00:;ooooo00Go0000ooooooooooooooooo`00000Kooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01?ooool00on7QhOoEEEEooooo`03ooooo`03oiRHV?lQ8B7o
k^k^08gooooo002Rooooo`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo00?o0000
ooooooooool01Oooool00onYZJWo410@ooooo`02ooooo`05olc<c?lQ8B7o0000oeEEEOl000001Ooo
ool00onHV9So8B4Qonk^kP2<ooooo`00X_ooool01Ol0003oQhN7oooooonYZJWo000001_ooooo00?o
0000ooooooooool01?ooool00ol@413o0000okZj^P03ooooo`05ob4Q8On7QhOooooooiRHV?l00000
1_ooool00omgMgOoIVIVooooo`2;ooooo`00XOooool00ol@413o0000ogMgM`02o`000003oiRHV?oo
oooooooo01Wooooo00?o0000ooooooooool01Oooool00onj^[[o8B4Qooooo`02ooooo`05o`000?oo
ooooooooooooool000001oooool00ol0003oooooooooo`2:ooooo`00`_ooool00ol0003ooooooooo
o`02ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OlQ8B7oV9RHoooooomgMgOoEEEE00?o
oooo00Go0000okZj^_ooooooV9RHoa0@402<ooooo`00`?ooool00omEEEGoIVIVo`000004ooooo`05
ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo<c<co410@o`000?lb<S;ok^k^00?ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c02<ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1398) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.48207 .29592 Mdot
.49122 .31945 Mdot
.39224 .63305 Mdot
.60636 .45979 Mdot
.58149 .7828 Mdot
.42508 .61659 Mdot
.3358 .49894 Mdot
.37693 .46588 Mdot
.38372 .63139 Mdot
.39288 .38651 Mdot
.37066 .44348 Mdot
.56594 .42625 Mdot
.34081 .46562 Mdot
.64575 .46904 Mdot
.84062 .62396 Mdot
.63655 .54048 Mdot
.48182 .29725 Mdot
.57296 .62149 Mdot
.66811 .51428 Mdot
.43545 .60783 Mdot
.43756 .2867 Mdot
.63999 .47001 Mdot
.44848 .31086 Mdot
.64623 .46932 Mdot
.6006 .47954 Mdot
.44756 .32301 Mdot
.44927 .3833 Mdot
.60086 .50645 Mdot
.63737 .51915 Mdot
.38007 .44969 Mdot
.64008 .60824 Mdot
.76377 .70308 Mdot
.67372 .53876 Mdot
.76969 .60813 Mdot
.34632 .48502 Mdot
.63108 .34103 Mdot
.41644 .624 Mdot
.36229 .45174 Mdot
.35638 .44826 Mdot
.37301 .47693 Mdot
.37058 .46052 Mdot
.4631 .31834 Mdot
.3528 .28772 Mdot
.34747 .57142 Mdot
.57555 .51019 Mdot
.42493 .80001 Mdot
.56036 .37752 Mdot
.65777 .45488 Mdot
.46482 .36587 Mdot
.44125 .7033 Mdot
.30266 .56362 Mdot
.32371 .4875 Mdot
.41489 .59185 Mdot
.25285 .22957 Mdot
.3275 .46685 Mdot
.59041 .42708 Mdot
.40358 .62474 Mdot
.63636 .48487 Mdot
.64881 .47312 Mdot
.62718 .25566 Mdot
.57671 .45518 Mdot
.54364 .65344 Mdot
.49768 .3665 Mdot
.46322 .54755 Mdot
.39515 .61663 Mdot
.35792 .44388 Mdot
.48882 .33981 Mdot
.33123 .47317 Mdot
.61494 .56435 Mdot
.35942 .61766 Mdot
.65521 .44972 Mdot
.36856 .44399 Mdot
.42997 .30826 Mdot
.62529 .51084 Mdot
.37274 .7205 Mdot
.38678 .79602 Mdot
.54752 .71318 Mdot
.62584 .32136 Mdot
.61944 .24906 Mdot
.46261 .73408 Mdot
.59377 .51855 Mdot
.64916 .66661 Mdot
.38844 .78881 Mdot
.44928 .37055 Mdot
.66986 .52468 Mdot
.54371 .6139 Mdot
.61992 .50913 Mdot
.50173 .83401 Mdot
.62946 .43073 Mdot
.54692 .58344 Mdot
.38556 .64546 Mdot
.45743 .3507 Mdot
.60131 .46243 Mdot
.6461 .50995 Mdot
.67216 .27075 Mdot
.67695 .46602 Mdot
.62296 .47372 Mdot
.47039 .36994 Mdot
.32221 .48443 Mdot
.5981 .42988 Mdot
.39661 .55516 Mdot
.4333 .65047 Mdot
.57819 .46984 Mdot
.3779 .64942 Mdot
.42964 .32759 Mdot
.64587 .50923 Mdot
.34601 .45077 Mdot
.58805 .45434 Mdot
.23238 .41977 Mdot
.47795 .29777 Mdot
.61592 .51916 Mdot
.55765 .69955 Mdot
.55595 .25246 Mdot
.45373 .35772 Mdot
.36276 .54688 Mdot
.66655 .51302 Mdot
.62101 .4849 Mdot
.48917 .34542 Mdot
.42121 .66188 Mdot
.47374 .82715 Mdot
.47545 .37237 Mdot
.3812 .44139 Mdot
.42791 .29917 Mdot
.59593 .41106 Mdot
.39396 .60923 Mdot
.3536 .55923 Mdot
.25787 .38137 Mdot
.6736 .60775 Mdot
.62064 .50636 Mdot
.36292 .29662 Mdot
.44362 .63377 Mdot
.46933 .3472 Mdot
.33601 .47281 Mdot
.69464 .50061 Mdot
.47445 .30778 Mdot
.36242 .43796 Mdot
.53621 .68518 Mdot
.25563 .52172 Mdot
.44122 .30298 Mdot
.49027 .44476 Mdot
.31081 .46857 Mdot
.34486 .49307 Mdot
.81611 .44939 Mdot
.48354 .34548 Mdot
.56432 .66774 Mdot
.34407 .47631 Mdot
.711 .57604 Mdot
.56987 .50022 Mdot
.63089 .65457 Mdot
.30764 .25782 Mdot
.76927 .5859 Mdot
.26495 .58188 Mdot
.56129 .68889 Mdot
.3069 .45889 Mdot
.61152 .47048 Mdot
.4434 .33225 Mdot
.44842 .31608 Mdot
.5765 .4562 Mdot
.59081 .48057 Mdot
.65201 .44393 Mdot
.66991 .47465 Mdot
.64599 .57329 Mdot
.67865 .45202 Mdot
.56101 .36045 Mdot
.45292 .34775 Mdot
.61096 .46225 Mdot
.3994 .59415 Mdot
.55668 .50364 Mdot
.37302 .45235 Mdot
.63523 .47794 Mdot
.60436 .46184 Mdot
.56611 .47933 Mdot
.32952 .49071 Mdot
.7307 .73584 Mdot
.52781 .25932 Mdot
.71036 .73505 Mdot
.52019 .53393 Mdot
.37462 .60462 Mdot
.61126 .50356 Mdot
.5485 .6592 Mdot
.69821 .35344 Mdot
.61356 .44929 Mdot
.11701 .54749 Mdot
.63005 .46922 Mdot
.62513 .78295 Mdot
.55584 .52539 Mdot
.73778 .68913 Mdot
.65486 .64703 Mdot
.60578 .48367 Mdot
.38408 .33684 Mdot
.31889 .49975 Mdot
.39651 .5715 Mdot
.36557 .46321 Mdot
.40631 .59433 Mdot
.39581 .62965 Mdot
.447 .56102 Mdot
.56465 .42286 Mdot
.5757 .53026 Mdot
.65015 .4368 Mdot
.36747 .65109 Mdot
.47829 .38172 Mdot
.55071 .70076 Mdot
.49752 .32656 Mdot
.65377 .81776 Mdot
.34744 .70818 Mdot
.38436 .47202 Mdot
.52606 .67597 Mdot
.40741 .6554 Mdot
.37967 .64005 Mdot
.55433 .69595 Mdot
.65409 .49518 Mdot
.4827 .34078 Mdot
.80716 .50954 Mdot
.21701 .4623 Mdot
.79421 .30605 Mdot
.46484 .3698 Mdot
.3683 .32991 Mdot
.37874 .45896 Mdot
.41682 .63551 Mdot
.62105 .4819 Mdot
.64357 .49973 Mdot
.45 .27714 Mdot
.65785 .45101 Mdot
.4835 .26129 Mdot
.61298 .4848 Mdot
.28379 .45528 Mdot
.5609 .71156 Mdot
.44816 .56214 Mdot
.70551 .60765 Mdot
.43875 .35056 Mdot
.75092 .34339 Mdot
.37255 .63247 Mdot
.69428 .3459 Mdot
.35033 .44234 Mdot
.53162 .67029 Mdot
.37864 .61352 Mdot
.55876 .70162 Mdot
.68461 .47018 Mdot
.42762 .60473 Mdot
.57206 .68551 Mdot
.5755 .59913 Mdot
.57267 .51728 Mdot
.19518 .41615 Mdot
.36951 .478 Mdot
.49258 .30602 Mdot
.59679 .44445 Mdot
.36677 .63063 Mdot
.70049 .49476 Mdot
.27879 .65038 Mdot
.27754 .50653 Mdot
.44502 .63457 Mdot
.48425 .60194 Mdot
.53526 .65719 Mdot
.3035 .60534 Mdot
.36155 .30861 Mdot
.49266 .3181 Mdot
.67675 .45955 Mdot
.7715 .66829 Mdot
.34307 .47629 Mdot
.59963 .44636 Mdot
.58252 .74482 Mdot
.33314 .48262 Mdot
.63542 .48693 Mdot
.35275 .43523 Mdot
.44891 .31531 Mdot
.57715 .22395 Mdot
.4887 .35025 Mdot
.6641 .45497 Mdot
.33637 .45552 Mdot
.40268 .6676 Mdot
.45243 .3257 Mdot
.65996 .48434 Mdot
.60243 .50502 Mdot
.5008 .58559 Mdot
.6197 .4623 Mdot
.69355 .75784 Mdot
.60909 .48455 Mdot
.40456 .63918 Mdot
.58292 .50753 Mdot
.46847 .20779 Mdot
.43967 .55692 Mdot
.48693 .34152 Mdot
.44703 .63685 Mdot
.38908 .62453 Mdot
.38352 .74468 Mdot
.33005 .4326 Mdot
.64683 .52349 Mdot
.36672 .6211 Mdot
.74458 .51921 Mdot
.32179 .45211 Mdot
.59023 .4417 Mdot
.46378 .43344 Mdot
.43384 .69883 Mdot
.42166 .59458 Mdot
.6966 .43491 Mdot
.43342 .31239 Mdot
.59605 .46675 Mdot
.38358 .64877 Mdot
.60172 .40276 Mdot
.62156 .5248 Mdot
.36376 .23941 Mdot
.49961 .59668 Mdot
.31374 .47354 Mdot
.54955 .48554 Mdot
.63036 .44009 Mdot
.42374 .60442 Mdot
.43884 .34609 Mdot
.31762 .45572 Mdot
.45872 .32007 Mdot
.74156 .67548 Mdot
.20144 .41739 Mdot
.58515 .58955 Mdot
.56589 .70456 Mdot
.48646 .65632 Mdot
.74759 .67599 Mdot
.68419 .25041 Mdot
.77177 .40702 Mdot
.79238 .58901 Mdot
.38938 .65762 Mdot
.49359 .69042 Mdot
.39537 .62376 Mdot
.58912 .49436 Mdot
.39708 .60967 Mdot
.78164 .65818 Mdot
.61491 .48215 Mdot
.4081 .6111 Mdot
.72379 .31296 Mdot
.59997 .46743 Mdot
.49353 .32442 Mdot
.64751 .80609 Mdot
.53274 .17973 Mdot
.2784 .4951 Mdot
.42579 .64232 Mdot
.78046 .46177 Mdot
.62218 .47201 Mdot
.58362 .50753 Mdot
.44505 .34357 Mdot
.69196 .5173 Mdot
.55846 .65023 Mdot
.52523 .67 Mdot
.36972 .50791 Mdot
.55456 .71941 Mdot
.54972 .48156 Mdot
.45144 .32887 Mdot
.6278 .57392 Mdot
.39656 .7352 Mdot
.45242 .69716 Mdot
.38102 .48718 Mdot
.64722 .80517 Mdot
.51128 .37437 Mdot
.32981 .40934 Mdot
.37182 .68904 Mdot
.46894 .35973 Mdot
.7554 .71743 Mdot
.36386 .46006 Mdot
.18191 .44885 Mdot
.39244 .33741 Mdot
.6518 .49446 Mdot
.32548 .45397 Mdot
.69564 .4489 Mdot
.55165 .18321 Mdot
.17973 .52369 Mdot
.61529 .38522 Mdot
.61963 .43194 Mdot
.37604 .71081 Mdot
.62954 .47941 Mdot
.32322 .69154 Mdot
.60487 .48985 Mdot
.46079 .32482 Mdot
.39052 .38558 Mdot
.35544 .53433 Mdot
.49282 .25106 Mdot
.30644 .62667 Mdot
.56475 .68699 Mdot
.61481 .48718 Mdot
.6533 .49188 Mdot
.56751 .65136 Mdot
.44441 .3092 Mdot
.65911 .44897 Mdot
.74794 .33191 Mdot
.6532 .50546 Mdot
.36994 .45374 Mdot
.41634 .26132 Mdot
.53204 .37393 Mdot
.66982 .49293 Mdot
.43404 .35798 Mdot
.3752 .48586 Mdot
.33907 .45599 Mdot
.5474 .50496 Mdot
.3858 .45681 Mdot
.63283 .46151 Mdot
.18585 .55487 Mdot
.44974 .29731 Mdot
.30256 .28408 Mdot
.47756 .32006 Mdot
.61212 .3105 Mdot
.32887 .48598 Mdot
.26834 .5163 Mdot
.67838 .4302 Mdot
.35868 .4602 Mdot
.41463 .31255 Mdot
.60498 .5356 Mdot
.59383 .53481 Mdot
.79923 .49667 Mdot
.40428 .64674 Mdot
.49535 .58558 Mdot
.38049 .44957 Mdot
.6568 .46401 Mdot
.67603 .49319 Mdot
.37601 .48372 Mdot
.19765 .5174 Mdot
.58974 .2041 Mdot
.61146 .48392 Mdot
.46325 .33528 Mdot
.47111 .34348 Mdot
.55957 .48214 Mdot
.5806 .47173 Mdot
.38927 .60454 Mdot
.41814 .66604 Mdot
.38171 .59523 Mdot
.49283 .58944 Mdot
.26904 .50554 Mdot
.52107 .80939 Mdot
.37242 .47744 Mdot
.34557 .34827 Mdot
.55669 .59147 Mdot
.64538 .43107 Mdot
.4283 .64456 Mdot
.63083 .44151 Mdot
.62523 .45419 Mdot
.357 .4239 Mdot
.59744 .76412 Mdot
.48504 .39808 Mdot
.43443 .34247 Mdot
.30738 .47259 Mdot
.54557 .48589 Mdot
.37796 .41089 Mdot
.53501 .66944 Mdot
.77014 .55483 Mdot
.35924 .44184 Mdot
.49386 .33436 Mdot
.36151 .48022 Mdot
.64383 .50375 Mdot
.65666 .42422 Mdot
.47185 .35681 Mdot
.55307 .64565 Mdot
.68303 .52581 Mdot
.63197 .48764 Mdot
.27863 .27332 Mdot
.74307 .57042 Mdot
.28039 .44375 Mdot
.60798 .48231 Mdot
.65424 .51278 Mdot
.56275 .6363 Mdot
.65197 .50518 Mdot
.63354 .4352 Mdot
.56348 .26062 Mdot
.27426 .38358 Mdot
.52729 .68666 Mdot
.19205 .55007 Mdot
.46726 .36904 Mdot
.76262 .68668 Mdot
.42979 .63177 Mdot
.36436 .52084 Mdot
.54897 .20034 Mdot
.40894 .59015 Mdot
.26363 .58895 Mdot
.75489 .69972 Mdot
.39367 .55042 Mdot
.45187 .60285 Mdot
.46959 .39366 Mdot
.66632 .46282 Mdot
.62389 .48642 Mdot
.55139 .65625 Mdot
.47994 .33636 Mdot
.49216 .53656 Mdot
.29053 .73744 Mdot
.63723 .47057 Mdot
.35131 .25109 Mdot
.2233 .61166 Mdot
.42515 .70456 Mdot
.54866 .67102 Mdot
.525 .66206 Mdot
.61614 .48881 Mdot
.53466 .2491 Mdot
.44748 .32424 Mdot
.6598 .48274 Mdot
.67591 .44837 Mdot
.41559 .64535 Mdot
.471 .2965 Mdot
.42329 .661 Mdot
.28888 .56224 Mdot
.69104 .7495 Mdot
.16619 .42272 Mdot
.32323 .47355 Mdot
.30994 .70636 Mdot
.334 .44132 Mdot
.65439 .666 Mdot
.43303 .59473 Mdot
.59066 .46582 Mdot
.43709 .33888 Mdot
.65289 .45853 Mdot
.58262 .47115 Mdot
.65466 .49313 Mdot
.67296 .48741 Mdot
.17639 .37655 Mdot
.56414 .69084 Mdot
.68749 .49589 Mdot
.3992 .6379 Mdot
.40267 .79022 Mdot
.35586 .76319 Mdot
.6526 .48829 Mdot
.60511 .49732 Mdot
.45954 .30081 Mdot
.58338 .45165 Mdot
.32489 .4464 Mdot
.49816 .34816 Mdot
.63077 .51351 Mdot
.5909 .82323 Mdot
.63308 .5212 Mdot
.73349 .70541 Mdot
.36222 .47862 Mdot
.21634 .44303 Mdot
.67198 .4317 Mdot
.2843 .50822 Mdot
.4956 .58569 Mdot
.38142 .60943 Mdot
.34602 .43358 Mdot
.41528 .62155 Mdot
.2642 .71174 Mdot
.61677 .41158 Mdot
.60837 .47224 Mdot
.6511 .43401 Mdot
.37439 .60457 Mdot
.53288 .83495 Mdot
.31734 .62308 Mdot
.63186 .40942 Mdot
.39446 .59821 Mdot
.45501 .38002 Mdot
.77758 .52168 Mdot
.46909 .3166 Mdot
.58441 .6769 Mdot
.37644 .45885 Mdot
.55163 .64712 Mdot
.67103 .71219 Mdot
.48377 .30297 Mdot
.47056 .28055 Mdot
.42775 .63103 Mdot
.4032 .3861 Mdot
.52438 .13528 Mdot
.39174 .33456 Mdot
.67383 .62913 Mdot
.4483 .33678 Mdot
.64203 .51599 Mdot
.65567 .69525 Mdot
.3929 .36197 Mdot
.41233 .61972 Mdot
.62667 .44802 Mdot
.57673 .22043 Mdot
.38873 .60467 Mdot
.63935 .42586 Mdot
.39779 .64175 Mdot
.36633 .46734 Mdot
.42157 .64961 Mdot
.46564 .26954 Mdot
.61444 .51256 Mdot
.55874 .12844 Mdot
.49722 .67205 Mdot
.61811 .47228 Mdot
.30932 .48148 Mdot
.22894 .54509 Mdot
.59836 .45336 Mdot
.57194 .69288 Mdot
.40986 .60573 Mdot
.41386 .38829 Mdot
.60883 .48636 Mdot
.39596 .59722 Mdot
.47518 .28893 Mdot
.30144 .46527 Mdot
.66343 .26639 Mdot
.28196 .48491 Mdot
.44469 .34652 Mdot
.50922 .47247 Mdot
.36711 .43055 Mdot
.65586 .51156 Mdot
.67789 .46656 Mdot
.46631 .33674 Mdot
.60555 .65192 Mdot
.57385 .4857 Mdot
.58944 .51326 Mdot
.41442 .64172 Mdot
.41729 .61831 Mdot
.75882 .40232 Mdot
.40878 .66414 Mdot
.66213 .428 Mdot
.46679 .33413 Mdot
.60271 .46047 Mdot
.46004 .29802 Mdot
.58362 .45202 Mdot
.53483 .49146 Mdot
.44369 .31024 Mdot
.32912 .42805 Mdot
.62463 .4505 Mdot
.652 .54912 Mdot
.5913 .45183 Mdot
.6674 .46941 Mdot
.38844 .60844 Mdot
.54488 .66515 Mdot
.66226 .4367 Mdot
.5093 .66819 Mdot
.54846 .69843 Mdot
.325 .52355 Mdot
.41252 .64644 Mdot
.56904 .66982 Mdot
.2265 .63414 Mdot
.41733 .59671 Mdot
.557 .65395 Mdot
.35765 .76461 Mdot
.34372 .48624 Mdot
.43307 .31051 Mdot
.59769 .46988 Mdot
.72481 .67482 Mdot
.55164 .37304 Mdot
.4549 .63532 Mdot
.61142 .48125 Mdot
.60407 .44566 Mdot
.47005 .37592 Mdot
.3017 .7654 Mdot
.3599 .6167 Mdot
.63561 .52408 Mdot
.48929 .31882 Mdot
.30874 .78949 Mdot
.40179 .63388 Mdot
.55237 .65362 Mdot
.34969 .48838 Mdot
.45094 .3894 Mdot
.25474 .38204 Mdot
.32278 .49378 Mdot
.34631 .63215 Mdot
.2946 .55782 Mdot
.67725 .50328 Mdot
.43476 .64114 Mdot
.80937 .36523 Mdot
.6794 .55495 Mdot
.47247 .56073 Mdot
.78032 .47208 Mdot
.46163 .35943 Mdot
.33116 .4429 Mdot
.56081 .6904 Mdot
.45768 .36881 Mdot
.47909 .29484 Mdot
.37576 .48105 Mdot
.54251 .2711 Mdot
.45895 .43138 Mdot
.3633 .44882 Mdot
.74716 .60836 Mdot
.52432 .78646 Mdot
.4317 .64209 Mdot
.55977 .65051 Mdot
.64993 .72968 Mdot
.46077 .31752 Mdot
.68437 .79278 Mdot
.80358 .49305 Mdot
.62316 .4735 Mdot
.56518 .67691 Mdot
.53687 .82513 Mdot
.33882 .78161 Mdot
.32969 .48254 Mdot
.34614 .52669 Mdot
.54253 .65068 Mdot
.60029 .4434 Mdot
.75782 .53977 Mdot
.5851 .50118 Mdot
.37531 .46386 Mdot
.69717 .29854 Mdot
.48382 .30117 Mdot
.36185 .48854 Mdot
.77538 .54765 Mdot
.63459 .46216 Mdot
.62213 .44973 Mdot
.71842 .62007 Mdot
.45078 .36766 Mdot
.38087 .6095 Mdot
.68351 .47904 Mdot
.63292 .48387 Mdot
.64249 .42273 Mdot
.55711 .46483 Mdot
.56208 .24078 Mdot
.59338 .4942 Mdot
.35132 .72255 Mdot
.61284 .43407 Mdot
.63789 .45407 Mdot
.43131 .35053 Mdot
.15215 .44512 Mdot
.30521 .57668 Mdot
.63383 .47994 Mdot
.64866 .51761 Mdot
.3609 .48779 Mdot
.42129 .4237 Mdot
.41142 .40263 Mdot
.41969 .39093 Mdot
.77735 .43368 Mdot
.57074 .51711 Mdot
.48751 .33467 Mdot
.57443 .68234 Mdot
.64927 .52117 Mdot
.48943 .33011 Mdot
.56751 .48884 Mdot
.38735 .60384 Mdot
.41465 .59567 Mdot
.63019 .57088 Mdot
.57069 .672 Mdot
.41538 .2406 Mdot
.3421 .34752 Mdot
.42117 .60109 Mdot
.60535 .47412 Mdot
.29038 .47876 Mdot
.38149 .64551 Mdot
.4132 .55691 Mdot
.60327 .69988 Mdot
.44147 .33172 Mdot
.45388 .35051 Mdot
.6284 .65739 Mdot
.26787 .56736 Mdot
.36652 .22365 Mdot
.36798 .46713 Mdot
.69008 .48129 Mdot
.37682 .31506 Mdot
.45181 .35289 Mdot
.66037 .67832 Mdot
.56733 .67643 Mdot
.33518 .48285 Mdot
.34128 .65566 Mdot
.46876 .30483 Mdot
.45927 .28709 Mdot
.57625 .45152 Mdot
.63843 .49247 Mdot
.76985 .39734 Mdot
.50969 .66175 Mdot
.33228 .49855 Mdot
.55562 .65091 Mdot
.43527 .5974 Mdot
.59603 .50883 Mdot
.44473 .31231 Mdot
.50763 .79643 Mdot
.6609 .5151 Mdot
.38088 .6237 Mdot
.45992 .3564 Mdot
.53418 .65736 Mdot
.57532 .68712 Mdot
.66894 .47968 Mdot
.73934 .36241 Mdot
.35855 .45403 Mdot
.4782 .35761 Mdot
.36747 .40694 Mdot
.58028 .49496 Mdot
.63064 .49596 Mdot
.58493 .54952 Mdot
.3308 .49828 Mdot
.30506 .39744 Mdot
.56244 .70374 Mdot
.47879 .34222 Mdot
.597 .49526 Mdot
.56552 .65478 Mdot
.35636 .34846 Mdot
.44655 .62294 Mdot
.41735 .65195 Mdot
.57754 .67891 Mdot
.55432 .67743 Mdot
.56518 .69997 Mdot
.68673 .79193 Mdot
.48422 .37123 Mdot
.51196 .37769 Mdot
.6061 .5322 Mdot
.66004 .6396 Mdot
.68869 .4985 Mdot
.31265 .46378 Mdot
.39954 .64618 Mdot
.58933 .45966 Mdot
.6673 .49468 Mdot
.55386 .52543 Mdot
.32521 .2631 Mdot
.52513 .39204 Mdot
.47282 .29477 Mdot
.66016 .42491 Mdot
.42553 .64042 Mdot
.67324 .8154 Mdot
.8213 .49947 Mdot
.66922 .4294 Mdot
.46077 .42749 Mdot
.43967 .31755 Mdot
.37259 .47858 Mdot
.70858 .65649 Mdot
.34841 .48627 Mdot
.47636 .34596 Mdot
.59261 .49827 Mdot
.33537 .36448 Mdot
.56317 .63459 Mdot
.66009 .46418 Mdot
.37107 .47015 Mdot
.65423 .44991 Mdot
.32979 .49737 Mdot
.71842 .69177 Mdot
.79273 .36483 Mdot
.62914 .47014 Mdot
.66267 .52575 Mdot
.77939 .3889 Mdot
.65462 .4827 Mdot
.56737 .62767 Mdot
.43922 .31792 Mdot
.7037 .29928 Mdot
.61126 .54053 Mdot
.74195 .465 Mdot
.58279 .50153 Mdot
.67381 .26537 Mdot
.63349 .49767 Mdot
.41514 .70806 Mdot
.61415 .51701 Mdot
.63961 .43493 Mdot
.32681 .46373 Mdot
.35926 .48975 Mdot
.42621 .32113 Mdot
.37105 .64068 Mdot
.72508 .71849 Mdot
.63068 .49079 Mdot
.28231 .52197 Mdot
.27905 .39771 Mdot
.55214 .67573 Mdot
.47653 .34058 Mdot
.35264 .81156 Mdot
.37938 .44382 Mdot
.80585 .44541 Mdot
.7612 .42144 Mdot
.28926 .34242 Mdot
.60688 .74163 Mdot
.22817 .57481 Mdot
.53218 .66383 Mdot
.5668 .47844 Mdot
.52652 .75699 Mdot
.40563 .71059 Mdot
.60399 .67978 Mdot
.3512 .4312 Mdot
.72059 .36665 Mdot
.57608 .76455 Mdot
.58217 .67027 Mdot
.53211 .6542 Mdot
.32408 .49016 Mdot
.45997 .60843 Mdot
.57001 .42034 Mdot
.56125 .68285 Mdot
.37509 .60176 Mdot
.42699 .60093 Mdot
.37324 .59872 Mdot
.44653 .32095 Mdot
.81367 .48586 Mdot
.39272 .44412 Mdot
.31393 .46973 Mdot
.4736 .63435 Mdot
.69496 .40746 Mdot
.49958 .3129 Mdot
.42025 .63094 Mdot
.41433 .65917 Mdot
.43778 .31571 Mdot
.57864 .43686 Mdot
.57886 .42713 Mdot
.63548 .47468 Mdot
.54792 .66126 Mdot
.63966 .4972 Mdot
.39721 .59906 Mdot
.327 .47732 Mdot
.40918 .65784 Mdot
.3078 .48328 Mdot
.49003 .80699 Mdot
.66296 .4861 Mdot
.6118 .51315 Mdot
.23807 .3216 Mdot
.44449 .2883 Mdot
.42377 .79411 Mdot
.30644 .43195 Mdot
.39575 .62591 Mdot
.63161 .4356 Mdot
.49993 .34155 Mdot
.51882 .65047 Mdot
.17022 .42898 Mdot
.57732 .47543 Mdot
.45776 .30943 Mdot
.59655 .50678 Mdot
.68606 .55907 Mdot
.42344 .20201 Mdot
.46607 .3247 Mdot
.33816 .24316 Mdot
.64146 .51926 Mdot
.24959 .65279 Mdot
.60074 .43715 Mdot
.62026 .59303 Mdot
.57393 .48575 Mdot
.46762 .36941 Mdot
.63799 .47728 Mdot
.49899 .34087 Mdot
.4318 .61311 Mdot
.36516 .48317 Mdot
.44661 .34694 Mdot
.67631 .47486 Mdot
.50118 .07012 Mdot
.3592 .47324 Mdot
.61816 .48456 Mdot
.33137 .48972 Mdot
.48077 .33189 Mdot
.46129 .3653 Mdot
.33055 .76428 Mdot
.28866 .5652 Mdot
.36433 .46753 Mdot
.59627 .50837 Mdot
.27808 .66969 Mdot
.58905 .47623 Mdot
.74787 .52125 Mdot
.59343 .42577 Mdot
.58693 .51581 Mdot
.36705 .77763 Mdot
.31332 .4743 Mdot
.36614 .22165 Mdot
.35745 .78317 Mdot
.39971 .789 Mdot
.43953 .2837 Mdot
.58097 .66498 Mdot
.74701 .72412 Mdot
.26859 .50339 Mdot
.38964 .59847 Mdot
.59292 .45463 Mdot
.44134 .26383 Mdot
.35431 .45209 Mdot
.53767 .67018 Mdot
.62839 .4712 Mdot
.42111 .65482 Mdot
.64667 .2297 Mdot
.3063 .46189 Mdot
.46694 .32062 Mdot
.45681 .37809 Mdot
.18329 .611 Mdot
.60357 .48659 Mdot
.61934 .5141 Mdot
.37681 .45936 Mdot
.21529 .54033 Mdot
.53328 .68749 Mdot
.72115 .3081 Mdot
.3618 .46801 Mdot
.46837 .50258 Mdot
.49145 .33525 Mdot
.61017 .44323 Mdot
.60186 .80616 Mdot
.34019 .6658 Mdot
.26152 .30299 Mdot
.54978 .65932 Mdot
.74568 .52563 Mdot
.46938 .36871 Mdot
.3392 .47407 Mdot
.24958 .53986 Mdot
.57628 .5266 Mdot
.63584 .44401 Mdot
.71247 .55696 Mdot
.34408 .53151 Mdot
.4591 .40371 Mdot
.57797 .48119 Mdot
.49172 .5829 Mdot
.57844 .46696 Mdot
.62943 .54542 Mdot
.61847 .41644 Mdot
.623 .50227 Mdot
.44948 .30987 Mdot
.72492 .46178 Mdot
.37224 .61327 Mdot
.50711 .36637 Mdot
.4649 .51092 Mdot
.61588 .47716 Mdot
.59705 .51817 Mdot
.58603 .38395 Mdot
.2574 .60361 Mdot
.44837 .34583 Mdot
.46713 .27691 Mdot
.38499 .45007 Mdot
.57487 .43433 Mdot
.37373 .64368 Mdot
.68698 .51391 Mdot
.38614 .61309 Mdot
.4468 .31192 Mdot
.39817 .62877 Mdot
.34648 .49084 Mdot
.43684 .63574 Mdot
.26909 .50804 Mdot
.3486 .47836 Mdot
.44172 .33759 Mdot
.63036 .51062 Mdot
.30843 .48052 Mdot
.69057 .60014 Mdot
.55007 .66077 Mdot
.43839 .84632 Mdot
.6306 .5141 Mdot
.26503 .38559 Mdot
.56258 .41405 Mdot
.41144 .6588 Mdot
.4111 .20297 Mdot
.43371 .33568 Mdot
.52159 .67457 Mdot
.44336 .3623 Mdot
.76827 .54326 Mdot
.55698 .66969 Mdot
.42185 .82429 Mdot
.51398 .60339 Mdot
.74387 .56512 Mdot
.56592 .44724 Mdot
.72323 .60147 Mdot
.4292 .59742 Mdot
.35094 .45285 Mdot
.25503 .55789 Mdot
.63804 .43626 Mdot
.71641 .26566 Mdot
.4386 .36172 Mdot
.36901 .63433 Mdot
.33349 .47186 Mdot
.31547 .45776 Mdot
.62776 .53021 Mdot
.46821 .71351 Mdot
.63871 .44276 Mdot
.26928 .55348 Mdot
.77671 .4573 Mdot
.51812 .33985 Mdot
.61347 .48468 Mdot
.42531 .6057 Mdot
.59639 .50654 Mdot
.56107 .70581 Mdot
.82032 .43406 Mdot
.6689 .53811 Mdot
.29454 .43118 Mdot
.51373 .64565 Mdot
.48463 .35071 Mdot
.53573 .44844 Mdot
.27821 .45612 Mdot
.60094 .48748 Mdot
.15211 .37688 Mdot
.56086 .65403 Mdot
.5258 .75352 Mdot
.66876 .50247 Mdot
.65031 .52251 Mdot
.44184 .53702 Mdot
.25499 .37111 Mdot
.35611 .69667 Mdot
.65259 .47338 Mdot
.67564 .58804 Mdot
.31704 .48319 Mdot
.59124 .44875 Mdot
.62165 .48684 Mdot
.55763 .31583 Mdot
.30933 .4632 Mdot
.3881 .63036 Mdot
.40996 .58954 Mdot
.4525 .64043 Mdot
.55106 .70623 Mdot
.38781 .40197 Mdot
.67087 .65564 Mdot
.58214 .19278 Mdot
.52738 .65275 Mdot
.66492 .49681 Mdot
.50767 .69556 Mdot
.59 .50099 Mdot
.54096 .67507 Mdot
.30857 .46311 Mdot
.44839 .35258 Mdot
.37577 .33173 Mdot
.40781 .59187 Mdot
.57376 .52686 Mdot
.53458 .69152 Mdot
.44318 .33145 Mdot
.68036 .69266 Mdot
.4843 .34856 Mdot
.35594 .4633 Mdot
.38216 .40039 Mdot
.5377 .6736 Mdot
.48131 .32595 Mdot
.32025 .41474 Mdot
.32121 .76826 Mdot
.61877 .41368 Mdot
.36252 .38328 Mdot
.48431 .35847 Mdot
.47694 .27997 Mdot
.48906 .35878 Mdot
.65971 .45502 Mdot
.4623 .42837 Mdot
.57743 .51002 Mdot
.31358 .47689 Mdot
.39437 .63965 Mdot
.76609 .34075 Mdot
.33416 .58077 Mdot
.50457 .43254 Mdot
.68586 .45834 Mdot
.6361 .46197 Mdot
.61647 .48851 Mdot
.62592 .54349 Mdot
.2587 .49533 Mdot
.64785 .45148 Mdot
.32706 .46269 Mdot
.40514 .60313 Mdot
.56644 .48025 Mdot
.3781 .66993 Mdot
.38624 .77368 Mdot
.55122 .64439 Mdot
.35625 .50747 Mdot
.83529 .47442 Mdot
.44423 .33444 Mdot
.4457 .63902 Mdot
.40974 .59883 Mdot
.53372 .68057 Mdot
.3646 .45278 Mdot
.48518 .34608 Mdot
.74242 .52386 Mdot
.54994 .69871 Mdot
.63618 .48 Mdot
.46235 .41806 Mdot
.74914 .29589 Mdot
.56866 .47363 Mdot
.60042 .45615 Mdot
.37343 .59626 Mdot
.53451 .74818 Mdot
.65253 .17666 Mdot
.68794 .65415 Mdot
.54086 .66753 Mdot
.57415 .65089 Mdot
.43972 .30708 Mdot
.60819 .53759 Mdot
.3183 .48918 Mdot
.39719 .31564 Mdot
.30422 .40794 Mdot
.38608 .25522 Mdot
.24184 .33958 Mdot
.58194 .46497 Mdot
.2017 .53836 Mdot
.63201 .45931 Mdot
.48326 .37177 Mdot
.45075 .31307 Mdot
.45599 .33271 Mdot
.35135 .45343 Mdot
.64974 .33995 Mdot
.33616 .45464 Mdot
.84404 .41523 Mdot
.47019 .36541 Mdot
.5089 .60575 Mdot
.42254 .63671 Mdot
.62633 .40908 Mdot
.53955 .65326 Mdot
.36824 .39104 Mdot
.61245 .56442 Mdot
.50965 .24267 Mdot
.36729 .6251 Mdot
.44201 .34183 Mdot
.22081 .55171 Mdot
.80677 .58821 Mdot
.41595 .39809 Mdot
.56094 .53852 Mdot
.70873 .65837 Mdot
.54839 .67536 Mdot
.25889 .3059 Mdot
.54852 .65025 Mdot
.37039 .47111 Mdot
.60747 .50868 Mdot
.6196 .50856 Mdot
.57799 .46632 Mdot
.65858 .48782 Mdot
.3802 .43265 Mdot
.67444 .45262 Mdot
.46874 .20791 Mdot
.40193 .59222 Mdot
.58166 .6051 Mdot
.54952 .65195 Mdot
.32502 .44037 Mdot
.40429 .60223 Mdot
.25731 .59673 Mdot
.70106 .61039 Mdot
.61026 .48552 Mdot
.59001 .45824 Mdot
.80178 .41981 Mdot
.5784 .48237 Mdot
.61754 .40454 Mdot
.39253 .59774 Mdot
.52789 .41908 Mdot
.54983 .64534 Mdot
.56964 .64446 Mdot
.3477 .48011 Mdot
.45046 .31066 Mdot
.56346 .65911 Mdot
.41976 .63939 Mdot
.68462 .45586 Mdot
.67899 .46258 Mdot
.48256 .35997 Mdot
.81006 .4214 Mdot
.56864 .70202 Mdot
.26896 .66227 Mdot
.4379 .33391 Mdot
.42258 .33211 Mdot
.63439 .44353 Mdot
.28421 .28656 Mdot
.44956 .27124 Mdot
.52384 .68631 Mdot
.3308 .43758 Mdot
.7192 .63855 Mdot
.36618 .43921 Mdot
.46799 .31894 Mdot
.62569 .52538 Mdot
.44311 .31999 Mdot
.60704 .48425 Mdot
.82302 .59399 Mdot
.62433 .50561 Mdot
.56404 .18842 Mdot
.6214 .64352 Mdot
.42757 .61855 Mdot
.24847 .59623 Mdot
.42942 .63149 Mdot
.43988 .34928 Mdot
.66406 .51432 Mdot
.52695 .67133 Mdot
.34727 .74268 Mdot
.41615 .28186 Mdot
.38379 .64439 Mdot
.36883 .6461 Mdot
.36285 .43681 Mdot
.57245 .4838 Mdot
.6402 .44602 Mdot
.41083 .61255 Mdot
.49341 .27209 Mdot
.47392 .30985 Mdot
.60298 .49994 Mdot
.63914 .45987 Mdot
.42835 .62276 Mdot
.30552 .7566 Mdot
.72319 .48727 Mdot
.61093 .50466 Mdot
.33967 .6829 Mdot
.31362 .46347 Mdot
.61945 .41022 Mdot
.66876 .5197 Mdot
.55569 .67994 Mdot
.60153 .24854 Mdot
.79439 .53088 Mdot
.30817 .46187 Mdot
.4062 .59598 Mdot
.60025 .49066 Mdot
.42252 .60327 Mdot
.6772 .45673 Mdot
.26168 .36054 Mdot
.44483 .63088 Mdot
.59277 .51804 Mdot
.57193 .44548 Mdot
.45288 .36939 Mdot
.58522 .46197 Mdot
.64359 .37758 Mdot
.37586 .62584 Mdot
.6295 .52906 Mdot
.7291 .34141 Mdot
.36318 .44589 Mdot
.55906 .45603 Mdot
.55681 .69719 Mdot
.75188 .50953 Mdot
.3227 .35365 Mdot
.61239 .76014 Mdot
.56874 .64199 Mdot
.65374 .45075 Mdot
.36724 .64071 Mdot
.33641 .49845 Mdot
.5316 .18178 Mdot
.60529 .44204 Mdot
.37319 .46662 Mdot
.32804 .47799 Mdot
.53604 .6677 Mdot
.14615 .46474 Mdot
.66985 .49651 Mdot
.65093 .4902 Mdot
.59955 .3469 Mdot
.46219 .28489 Mdot
.63446 .50292 Mdot
.6485 .51075 Mdot
.32389 .46598 Mdot
.55109 .45185 Mdot
.72519 .39419 Mdot
.69881 .28467 Mdot
.37285 .48926 Mdot
.38902 .28307 Mdot
.44167 .61813 Mdot
.57084 .65626 Mdot
.46866 .35505 Mdot
.53073 .68587 Mdot
.41951 .647 Mdot
.64491 .51111 Mdot
.37801 .46868 Mdot
.60602 .37398 Mdot
.32515 .49094 Mdot
.58281 .74922 Mdot
.49576 .32806 Mdot
.39885 .48892 Mdot
.14349 .40571 Mdot
.30152 .64587 Mdot
.33186 .53177 Mdot
.55259 .67588 Mdot
.38874 .56352 Mdot
.63777 .45957 Mdot
.24878 .31549 Mdot
.66357 .49682 Mdot
.71586 .32286 Mdot
.39304 .59385 Mdot
.37948 .59614 Mdot
.60814 .50628 Mdot
.77453 .46189 Mdot
.33985 .499 Mdot
.32297 .4521 Mdot
.60312 .52644 Mdot
.3593 .46051 Mdot
.64227 .4901 Mdot
.39412 .60212 Mdot
.29865 .24644 Mdot
.63129 .47434 Mdot
.65631 .54013 Mdot
.2704 .36026 Mdot
.36981 .78464 Mdot
.49826 .65438 Mdot
.21359 .66842 Mdot
.81799 .56074 Mdot
.35733 .45999 Mdot
.58981 .52338 Mdot
.38818 .27791 Mdot
.3628 .60762 Mdot
.32196 .41126 Mdot
.64213 .5078 Mdot
.65629 .50288 Mdot
.63661 .43341 Mdot
.61627 .45119 Mdot
.18861 .41083 Mdot
.41125 .28483 Mdot
.61999 .28743 Mdot
.5828 .46855 Mdot
.71268 .59417 Mdot
.35935 .47871 Mdot
.42408 .35925 Mdot
.51904 .66589 Mdot
.58293 .46369 Mdot
.49458 .38117 Mdot
.38246 .46884 Mdot
.84309 .39792 Mdot
.37538 .46741 Mdot
.38972 .62368 Mdot
.34756 .49386 Mdot
.61937 .46349 Mdot
.4707 .34336 Mdot
.42277 .48823 Mdot
.30551 .60175 Mdot
.38571 .5994 Mdot
.61777 .47279 Mdot
.49601 .61434 Mdot
.3703 .61548 Mdot
.41374 .79752 Mdot
.46615 .34944 Mdot
.66221 .5937 Mdot
.44554 .31605 Mdot
.61225 .52866 Mdot
.6135 .52805 Mdot
.39116 .4621 Mdot
.34883 .49148 Mdot
.44669 .31458 Mdot
.13151 .50893 Mdot
.5665 .70098 Mdot
.45722 .32938 Mdot
.58403 .53694 Mdot
.4453 .44379 Mdot
.46672 .3418 Mdot
.58181 .63469 Mdot
.32452 .47364 Mdot
.43943 .29693 Mdot
.61672 .43172 Mdot
.75141 .60014 Mdot
.57732 .67324 Mdot
.42282 .58842 Mdot
.66035 .69799 Mdot
.3766 .63595 Mdot
.34413 .43374 Mdot
.43037 .6295 Mdot
.31605 .47354 Mdot
.306 .37442 Mdot
.51198 .3486 Mdot
.40233 .54609 Mdot
.37155 .43288 Mdot
.42736 .63089 Mdot
.60319 .50851 Mdot
.4973 .67113 Mdot
.62733 .53607 Mdot
.66872 .45706 Mdot
.32037 .45985 Mdot
.45544 .36746 Mdot
.4538 .27309 Mdot
.7441 .55337 Mdot
.45415 .3058 Mdot
.38032 .6273 Mdot
.50772 .22765 Mdot
.30253 .53683 Mdot
.36025 .44001 Mdot
.36164 .48604 Mdot
.58489 .49547 Mdot
.41447 .62109 Mdot
.38355 .59835 Mdot
.36948 .43917 Mdot
.30936 .2839 Mdot
.65498 .53407 Mdot
.47829 .2785 Mdot
.45736 .28596 Mdot
.46657 .3286 Mdot
.49277 .35421 Mdot
.7327 .44978 Mdot
.33728 .48534 Mdot
.44856 .3632 Mdot
.5836 .49455 Mdot
.65015 .50573 Mdot
.39343 .3113 Mdot
.57464 .67359 Mdot
.56522 .48573 Mdot
.61308 .4173 Mdot
.61296 .44286 Mdot
.42419 .64943 Mdot
.69001 .41829 Mdot
.43685 .64416 Mdot
.36218 .62663 Mdot
.36147 .61935 Mdot
.26902 .50147 Mdot
.7954 .44124 Mdot
.77401 .62544 Mdot
.64095 .52285 Mdot
.21204 .58017 Mdot
.40938 .62945 Mdot
.47822 .22365 Mdot
.29672 .40196 Mdot
.62849 .43637 Mdot
.37506 .7262 Mdot
.41563 .61424 Mdot
.43579 .32253 Mdot
.63448 .50807 Mdot
.44495 .64993 Mdot
.56217 .69627 Mdot
.62646 .53222 Mdot
.44555 .61852 Mdot
.4831 .32941 Mdot
.53091 .69831 Mdot
.43821 .29288 Mdot
.36116 .61896 Mdot
.54785 .49263 Mdot
.43285 .15523 Mdot
.43236 .66631 Mdot
.25883 .68082 Mdot
.54361 .53951 Mdot
.60213 .50334 Mdot
.43613 .65332 Mdot
.42101 .31493 Mdot
.34088 .43509 Mdot
.5038 .52931 Mdot
.45453 .29377 Mdot
.3794 .59612 Mdot
.39028 .65346 Mdot
.38597 .59913 Mdot
.47099 .2923 Mdot
.56324 .49652 Mdot
.46552 .29785 Mdot
.3442 .49516 Mdot
.59469 .46999 Mdot
.74317 .67845 Mdot
.21485 .52852 Mdot
.43778 .32893 Mdot
.38804 .63924 Mdot
.56357 .63562 Mdot
.6304 .46433 Mdot
.21054 .5431 Mdot
.60007 .50711 Mdot
.31529 .46679 Mdot
.56977 .2561 Mdot
.53208 .39494 Mdot
.58877 .51905 Mdot
.58549 .49109 Mdot
.32556 .45081 Mdot
.62169 .47384 Mdot
.57354 .48525 Mdot
.26738 .50678 Mdot
.47484 .29994 Mdot
.6394 .47321 Mdot
.40224 .64202 Mdot
.3016 .55466 Mdot
.65595 .53647 Mdot
.38104 .55417 Mdot
.65843 .59124 Mdot
.56442 .2684 Mdot
.66244 .4986 Mdot
.48177 .41111 Mdot
.62702 .44695 Mdot
.66198 .47163 Mdot
.58868 .49292 Mdot
.17516 .47201 Mdot
.44519 .6203 Mdot
.41707 .60288 Mdot
.57661 .65674 Mdot
.65717 .59219 Mdot
.56188 .68019 Mdot
.32443 .47788 Mdot
.4804 .72496 Mdot
.43848 .64225 Mdot
.47383 .32025 Mdot
.65688 .45939 Mdot
.43014 .6669 Mdot
.61898 .44053 Mdot
.61741 .46479 Mdot
.3778 .64923 Mdot
.44181 .61328 Mdot
.56403 .7603 Mdot
.57239 .68381 Mdot
.45292 .33646 Mdot
.57157 .49414 Mdot
.54237 .69673 Mdot
.66472 .50001 Mdot
.65926 .64176 Mdot
.45633 .33621 Mdot
.47238 .29944 Mdot
.45382 .27196 Mdot
.63997 .51257 Mdot
.62404 .46426 Mdot
.33541 .45434 Mdot
.43636 .34217 Mdot
.3672 .44736 Mdot
.49791 .54641 Mdot
.43219 .77536 Mdot
.64261 .50775 Mdot
.38653 .38781 Mdot
.56526 .68472 Mdot
.38701 .64676 Mdot
.76264 .31295 Mdot
.57682 .65731 Mdot
.60569 .48726 Mdot
.36572 .63061 Mdot
.54333 .68339 Mdot
.67498 .57047 Mdot
.83197 .41826 Mdot
.55516 .63755 Mdot
.58352 .49385 Mdot
.54885 .46228 Mdot
.20385 .65235 Mdot
.56161 .63943 Mdot
.3524 .48679 Mdot
.63772 .51309 Mdot
.49204 .28858 Mdot
.53259 .68981 Mdot
.33937 .70236 Mdot
.41228 .60766 Mdot
.75868 .58345 Mdot
.64005 .55573 Mdot
.47225 .24878 Mdot
.57301 .65259 Mdot
.48053 .34716 Mdot
.61437 .40262 Mdot
.6319 .44386 Mdot
.56667 .6398 Mdot
.32762 .43285 Mdot
.39692 .60777 Mdot
.29941 .57329 Mdot
.46962 .29127 Mdot
.33603 .42766 Mdot
.39337 .6469 Mdot
.27593 .67114 Mdot
.6269 .23175 Mdot
.58403 .4228 Mdot
.19524 .60669 Mdot
.26213 .44374 Mdot
.586 .44643 Mdot
.52461 .64768 Mdot
.30652 .47778 Mdot
.38375 .45988 Mdot
.35644 .46628 Mdot
.29076 .38909 Mdot
.42124 .39269 Mdot
.44831 .62222 Mdot
.38469 .41037 Mdot
.57149 .65865 Mdot
.72286 .62674 Mdot
.67105 .45762 Mdot
.63628 .46472 Mdot
.57667 .49801 Mdot
.58338 .46045 Mdot
.63916 .45116 Mdot
.36798 .45734 Mdot
.29331 .37434 Mdot
.40656 .38442 Mdot
.46192 .33857 Mdot
.53035 .73978 Mdot
.41613 .63796 Mdot
.43043 .58763 Mdot
.54807 .69122 Mdot
.31184 .6706 Mdot
.38069 .67111 Mdot
.39643 .6283 Mdot
.56742 .46235 Mdot
.4698 .30456 Mdot
.62763 .40747 Mdot
.58455 .49241 Mdot
.38235 .62165 Mdot
.45722 .5383 Mdot
.7093 .39684 Mdot
.58919 .71955 Mdot
.53384 .70518 Mdot
.43594 .41654 Mdot
.57618 .64909 Mdot
.68046 .4964 Mdot
.42463 .20532 Mdot
.4207 .64695 Mdot
.40026 .61803 Mdot
.57261 .67609 Mdot
.28649 .28149 Mdot
.46488 .35873 Mdot
.4042 .45278 Mdot
.32439 .48636 Mdot
.62034 .52629 Mdot
.67337 .24624 Mdot
.53391 .528 Mdot
.45723 .71658 Mdot
.35988 .47015 Mdot
.43324 .61616 Mdot
.6838 .49958 Mdot
.58457 .48172 Mdot
.56065 .6881 Mdot
.5932 .77751 Mdot
.63538 .41412 Mdot
.51931 .84487 Mdot
.79291 .36415 Mdot
.78521 .52637 Mdot
.63699 .44457 Mdot
.47277 .29694 Mdot
.41995 .59002 Mdot
.56159 .6503 Mdot
.57403 .52582 Mdot
.81059 .51983 Mdot
.48085 .35961 Mdot
.34796 .47579 Mdot
.4504 .50382 Mdot
.70854 .64639 Mdot
.66677 .46303 Mdot
.65268 .50637 Mdot
.66481 .47201 Mdot
.7849 .27974 Mdot
.43306 .64546 Mdot
.43746 .32373 Mdot
.53574 .67028 Mdot
.46044 .30783 Mdot
.42867 .61512 Mdot
.42702 .55177 Mdot
.60863 .5151 Mdot
.48779 .35325 Mdot
.47919 .34876 Mdot
.38063 .45631 Mdot
.31173 .45227 Mdot
.46912 .51892 Mdot
.62513 .5044 Mdot
.38908 .66453 Mdot
.45027 .3661 Mdot
.45774 .41495 Mdot
.55802 .67155 Mdot
.32316 .47233 Mdot
.58468 .46448 Mdot
.43866 .63831 Mdot
.60486 .4247 Mdot
.45172 .34907 Mdot
.39728 .62808 Mdot
.50117 .79561 Mdot
.5563 .6425 Mdot
.65092 .50098 Mdot
.55635 .61897 Mdot
.40199 .59593 Mdot
.63648 .4568 Mdot
.29125 .70162 Mdot
.58234 .63612 Mdot
.31924 .62899 Mdot
.366 .61453 Mdot
.27951 .50134 Mdot
.44175 .3038 Mdot
.24763 .42343 Mdot
.39446 .61901 Mdot
.25007 .63927 Mdot
.53523 .78675 Mdot
.68864 .46436 Mdot
.46017 .31857 Mdot
.25543 .45399 Mdot
.77897 .67539 Mdot
.2574 .6956 Mdot
.61887 .48516 Mdot
.40774 .66396 Mdot
.55068 .68779 Mdot
.35303 .44061 Mdot
.3341 .6111 Mdot
.57357 .71219 Mdot
.35731 .64284 Mdot
.58915 .49273 Mdot
.48284 .33918 Mdot
.3331 .46205 Mdot
.32285 .35822 Mdot
.41335 .64142 Mdot
.39337 .64144 Mdot
.65517 .52353 Mdot
.56808 .67569 Mdot
.2206 .47789 Mdot
.39179 .60073 Mdot
.79522 .39562 Mdot
.44415 .59482 Mdot
.55253 .70083 Mdot
.61333 .44856 Mdot
.75638 .54383 Mdot
.60125 .53575 Mdot
.31772 .73579 Mdot
.42029 .63532 Mdot
.4535 .34321 Mdot
.65385 .44527 Mdot
.7457 .34754 Mdot
.38085 .6292 Mdot
.45366 .42415 Mdot
.43882 .69259 Mdot
.3299 .48446 Mdot
.75881 .30913 Mdot
.64172 .49898 Mdot
.3366 .49833 Mdot
.55894 .68743 Mdot
.61628 .5037 Mdot
.62317 .46181 Mdot
.46905 .37519 Mdot
.37952 .4516 Mdot
.55884 .76457 Mdot
.36542 .48564 Mdot
.36308 .47907 Mdot
.5013 .34001 Mdot
.64671 .479 Mdot
.38872 .62556 Mdot
.41448 .6149 Mdot
.61075 .43222 Mdot
.2704 .25374 Mdot
.47004 .35959 Mdot
.40921 .58709 Mdot
.76402 .25446 Mdot
.58769 .44123 Mdot
.74693 .30383 Mdot
.5817 .77796 Mdot
.314 .48354 Mdot
.58292 .49408 Mdot
.48152 .32968 Mdot
.36991 .6997 Mdot
.39107 .63913 Mdot
.63213 .43023 Mdot
.33493 .46219 Mdot
.57127 .68891 Mdot
.3744 .61702 Mdot
.4668 .71506 Mdot
.66179 .48558 Mdot
.38516 .73459 Mdot
.39835 .6609 Mdot
.72372 .74187 Mdot
.25261 .57817 Mdot
.45788 .31973 Mdot
.61475 .46376 Mdot
.43381 .33159 Mdot
.53512 .67517 Mdot
.45274 .50536 Mdot
.3275 .47019 Mdot
.69205 .40689 Mdot
.45114 .19632 Mdot
.38628 .59883 Mdot
.43578 .32827 Mdot
.59807 .52736 Mdot
.26099 .35417 Mdot
.64438 .49403 Mdot
.54251 .49839 Mdot
.58006 .73794 Mdot
.33484 .44821 Mdot
.31872 .48516 Mdot
.62346 .4535 Mdot
.5328 .68261 Mdot
.41766 .63932 Mdot
.38977 .61298 Mdot
.64784 .81548 Mdot
.40621 .47222 Mdot
.76902 .40054 Mdot
.65676 .50168 Mdot
.3591 .64196 Mdot
.33551 .55921 Mdot
.3761 .46076 Mdot
.55577 .47474 Mdot
.37258 .64112 Mdot
.56072 .60818 Mdot
.70337 .55752 Mdot
.63071 .44549 Mdot
.59943 .53868 Mdot
.33088 .49004 Mdot
.45032 .40231 Mdot
.42774 .60494 Mdot
.62469 .4201 Mdot
.40969 .53826 Mdot
.66566 .57633 Mdot
.80975 .37433 Mdot
.45284 .33611 Mdot
.46528 .69982 Mdot
.36803 .45642 Mdot
.65772 .54037 Mdot
.5366 .65866 Mdot
.35573 .62032 Mdot
.44251 .63448 Mdot
.59692 .48771 Mdot
.68597 .4809 Mdot
.7801 .36672 Mdot
.47016 .31183 Mdot
.35336 .48049 Mdot
.62112 .51284 Mdot
.38018 .35595 Mdot
.57705 .46913 Mdot
.34231 .44994 Mdot
.4135 .16109 Mdot
.6173 .53625 Mdot
.64826 .49114 Mdot
.22238 .48483 Mdot
.45638 .29099 Mdot
.43942 .3575 Mdot
.68896 .24561 Mdot
.65636 .50173 Mdot
.78269 .34984 Mdot
.44879 .33914 Mdot
.4591 .35845 Mdot
.26989 .53721 Mdot
.6326 .46602 Mdot
.71064 .50073 Mdot
.31409 .47505 Mdot
.36272 .4804 Mdot
.46572 .2945 Mdot
.62539 .41103 Mdot
.3142 .45242 Mdot
.19583 .45554 Mdot
.41558 .62263 Mdot
.38286 .2067 Mdot
.47213 .36058 Mdot
.32796 .51639 Mdot
.36971 .46752 Mdot
.84121 .43973 Mdot
.35631 .67358 Mdot
.60612 .51136 Mdot
.65802 .49755 Mdot
.57286 .67064 Mdot
.57863 .50572 Mdot
.37999 .59601 Mdot
.36003 .46084 Mdot
.75426 .43892 Mdot
.45576 .33208 Mdot
.63122 .49817 Mdot
.34148 .72615 Mdot
.45348 .81129 Mdot
.47759 .68717 Mdot
.4825 .35219 Mdot
.44903 .31888 Mdot
.43586 .63173 Mdot
.4035 .66353 Mdot
.64922 .46486 Mdot
.32946 .44617 Mdot
.43603 .3393 Mdot
.3353 .45095 Mdot
.41813 .64798 Mdot
.39115 .62627 Mdot
.43998 .60614 Mdot
.67337 .45853 Mdot
.39622 .63473 Mdot
.45915 .78681 Mdot
.37056 .4161 Mdot
.501 .31825 Mdot
.74921 .27633 Mdot
.32703 .36062 Mdot
.42498 .28405 Mdot
.5402 .69837 Mdot
.39145 .59701 Mdot
.34671 .49635 Mdot
.60002 .46147 Mdot
.59359 .45158 Mdot
.29588 .5232 Mdot
.35893 .4944 Mdot
.53639 .67249 Mdot
.32957 .49524 Mdot
.53562 .66839 Mdot
.40358 .72756 Mdot
.57119 .47851 Mdot
.6777 .4548 Mdot
.36702 .46189 Mdot
.39674 .63175 Mdot
.41447 .60474 Mdot
.55135 .63991 Mdot
.47292 .55847 Mdot
.36913 .6183 Mdot
.45822 .36118 Mdot
.72562 .42108 Mdot
.40068 .65865 Mdot
.63421 .50655 Mdot
.66578 .66018 Mdot
.24086 .32114 Mdot
.62518 .54345 Mdot
.26716 .52527 Mdot
.57676 .3684 Mdot
.64415 .44105 Mdot
.24548 .31262 Mdot
.28742 .46248 Mdot
.4488 .29998 Mdot
.40363 .59313 Mdot
.46525 .6494 Mdot
.70659 .46145 Mdot
.52587 .69455 Mdot
.55555 .50159 Mdot
.48812 .35016 Mdot
.45216 .37741 Mdot
.7538 .56277 Mdot
.27966 .7111 Mdot
.54592 .68412 Mdot
.55169 .69123 Mdot
.39231 .61838 Mdot
.43697 .84922 Mdot
.55242 .52436 Mdot
.53811 .67046 Mdot
.48153 .26194 Mdot
.59128 .49043 Mdot
.61485 .60054 Mdot
.51582 .48473 Mdot
.46771 .29338 Mdot
.71945 .58664 Mdot
.38376 .62921 Mdot
.45307 .3049 Mdot
.37158 .32596 Mdot
.56561 .497 Mdot
.45707 .33506 Mdot
.3339 .45303 Mdot
.26789 .60782 Mdot
.45782 .36465 Mdot
.66633 .64991 Mdot
.34714 .43755 Mdot
.45342 .41488 Mdot
.73103 .55756 Mdot
.20142 .72307 Mdot
.36426 .45821 Mdot
.39047 .65304 Mdot
.41333 .61393 Mdot
.38949 .61392 Mdot
.46266 .30753 Mdot
.38758 .59731 Mdot
.46963 .31341 Mdot
.20947 .63238 Mdot
.24734 .33086 Mdot
.54013 .66892 Mdot
.29881 .57589 Mdot
.4765 .33147 Mdot
.47015 .21623 Mdot
.21477 .28843 Mdot
.58294 .49725 Mdot
.3856 .46213 Mdot
.54156 .67102 Mdot
.49965 .84018 Mdot
.55221 .68016 Mdot
.79897 .48533 Mdot
.53115 .25383 Mdot
.63549 .49179 Mdot
.6886 .35017 Mdot
.53295 .65202 Mdot
.49208 .33221 Mdot
.63551 .45745 Mdot
.52261 .57647 Mdot
.55572 .68417 Mdot
.55993 .69977 Mdot
.64551 .46874 Mdot
.44192 .34194 Mdot
.38564 .63915 Mdot
.36637 .48167 Mdot
.52527 .67903 Mdot
.54896 .44511 Mdot
.58748 .52871 Mdot
.60067 .51121 Mdot
.39329 .35535 Mdot
.5388 .63836 Mdot
.35656 .45951 Mdot
.15593 .47427 Mdot
.37322 .6477 Mdot
.52674 .59711 Mdot
.80049 .38433 Mdot
.27604 .46351 Mdot
.41999 .63403 Mdot
.42408 .60532 Mdot
.64078 .45125 Mdot
.52617 .45682 Mdot
.51711 .25344 Mdot
.47315 .57488 Mdot
.43097 .59282 Mdot
.39288 .60983 Mdot
.43262 .34289 Mdot
.77808 .53304 Mdot
.59162 .54348 Mdot
.30727 .46347 Mdot
.44428 .62674 Mdot
.23441 .37898 Mdot
.57088 .66821 Mdot
.53244 .24257 Mdot
.56997 .47811 Mdot
.61013 .51253 Mdot
.33636 .46703 Mdot
.33534 .45567 Mdot
.39102 .70267 Mdot
.78791 .51489 Mdot
.57566 .37343 Mdot
.29735 .35918 Mdot
.56548 .28118 Mdot
.43962 .36243 Mdot
.43776 .32935 Mdot
.30841 .62111 Mdot
.37291 .48 Mdot
.64748 .44167 Mdot
.44867 .31177 Mdot
.51339 .61993 Mdot
.70977 .41804 Mdot
.75899 .5041 Mdot
.76153 .3277 Mdot
.60971 .48138 Mdot
.47897 .30848 Mdot
.45713 .28982 Mdot
.47625 .28692 Mdot
.28358 .49952 Mdot
.65278 .4741 Mdot
.61411 .48261 Mdot
.64592 .44583 Mdot
.27201 .31771 Mdot
.65797 .47111 Mdot
.2552 .41331 Mdot
.45974 .49566 Mdot
.61547 .24611 Mdot
.62349 .41928 Mdot
.32105 .49535 Mdot
.67029 .47795 Mdot
.53253 .68109 Mdot
.58898 .50794 Mdot
.75929 .50155 Mdot
.36069 .4745 Mdot
.72768 .46655 Mdot
.31347 .37189 Mdot
.6188 .43423 Mdot
.52548 .68768 Mdot
.28639 .41775 Mdot
.77168 .6631 Mdot
.5021 .66304 Mdot
.4603 .3616 Mdot
.41711 .6277 Mdot
.34849 .49662 Mdot
.39602 .6228 Mdot
.66611 .43979 Mdot
.30317 .62711 Mdot
.51675 .82827 Mdot
.49865 .56573 Mdot
.58531 .45936 Mdot
.58985 .54763 Mdot
.45327 .35653 Mdot
.37103 .64281 Mdot
.43821 .27254 Mdot
.66105 .45602 Mdot
.54692 .66086 Mdot
.56086 .68588 Mdot
.5044 .53805 Mdot
.65441 .77845 Mdot
.21123 .41876 Mdot
.34027 .464 Mdot
.38917 .60328 Mdot
.5408 .65185 Mdot
.23463 .61689 Mdot
.29921 .46992 Mdot
.31864 .45841 Mdot
.35623 .47735 Mdot
.63989 .51758 Mdot
.44573 .62394 Mdot
.62078 .24774 Mdot
.35891 .62033 Mdot
.62097 .47172 Mdot
.42458 .65026 Mdot
.36922 .6329 Mdot
.55558 .65215 Mdot
.35729 .47856 Mdot
.42136 .64475 Mdot
.61772 .52921 Mdot
.44564 .3364 Mdot
.35149 .53598 Mdot
.61101 .64206 Mdot
.2888 .7168 Mdot
.58961 .57542 Mdot
.47192 .28897 Mdot
.76282 .68314 Mdot
.3119 .4682 Mdot
.29876 .29307 Mdot
.56598 .75886 Mdot
.66157 .51502 Mdot
.28543 .23907 Mdot
.42334 .58227 Mdot
.3721 .63598 Mdot
.61614 .44817 Mdot
.44895 .59546 Mdot
.63576 .49608 Mdot
.40424 .65092 Mdot
.36281 .55672 Mdot
.49508 .3745 Mdot
.40125 .63395 Mdot
.63433 .42266 Mdot
.62501 .45813 Mdot
.47023 .29657 Mdot
.4234 .66036 Mdot
.57587 .5294 Mdot
.67762 .80553 Mdot
.34398 .45167 Mdot
.26986 .44522 Mdot
.6551 .67472 Mdot
.3684 .45479 Mdot
.45916 .32843 Mdot
.67048 .45937 Mdot
.55767 .68813 Mdot
.4776 .33083 Mdot
.75774 .4878 Mdot
.55917 .64409 Mdot
.37094 .20274 Mdot
.46139 .28885 Mdot
.38067 .64193 Mdot
.53076 .66994 Mdot
.58189 .51491 Mdot
.36089 .60948 Mdot
.25355 .60526 Mdot
.41734 .63479 Mdot
.64385 .4489 Mdot
.3239 .59031 Mdot
.35329 .48137 Mdot
.61797 .48865 Mdot
.37224 .63138 Mdot
.2698 .52746 Mdot
.64402 .51886 Mdot
.62729 .45033 Mdot
.80635 .39677 Mdot
.53118 .20914 Mdot
.5552 .67534 Mdot
.43955 .28883 Mdot
.58356 .49559 Mdot
.55486 .69838 Mdot
.46689 .76671 Mdot
.62768 .51799 Mdot
.48072 .3604 Mdot
.55531 .47136 Mdot
.41668 .66212 Mdot
.36289 .44802 Mdot
.49145 .58849 Mdot
.56152 .69648 Mdot
.24412 .73502 Mdot
.44095 .62171 Mdot
.68077 .47275 Mdot
.5775 .47235 Mdot
.65035 .72144 Mdot
.45086 .30028 Mdot
.52077 .30684 Mdot
.65146 .50083 Mdot
.28205 .30414 Mdot
.61824 .50067 Mdot
.40999 .57671 Mdot
.46381 .3591 Mdot
.65313 .48698 Mdot
.38115 .52145 Mdot
.65948 .53744 Mdot
.5766 .66827 Mdot
.21566 .51461 Mdot
.56722 .50587 Mdot
.38826 .18177 Mdot
.53538 .56993 Mdot
.40116 .63591 Mdot
.39794 .77368 Mdot
.66015 .82403 Mdot
.29651 .38745 Mdot
.46129 .30983 Mdot
.56434 .79479 Mdot
.38877 .62608 Mdot
.37021 .74241 Mdot
.77462 .67523 Mdot
.61634 .45801 Mdot
.66595 .46101 Mdot
.70223 .66861 Mdot
.36063 .62414 Mdot
.37493 .65637 Mdot
.68088 .45199 Mdot
.64574 .54409 Mdot
.39177 .6322 Mdot
.64341 .52506 Mdot
.64727 .42039 Mdot
.38527 .46172 Mdot
.47868 .35959 Mdot
.33525 .4471 Mdot
.31832 .44994 Mdot
.19231 .50199 Mdot
.54353 .57947 Mdot
.34708 .4488 Mdot
.30924 .47868 Mdot
.61876 .59783 Mdot
.77938 .47683 Mdot
.52999 .68499 Mdot
.67718 .78057 Mdot
.39629 .60972 Mdot
.65054 .48027 Mdot
.45814 .28692 Mdot
.56851 .38035 Mdot
.49903 .77449 Mdot
.4413 .21465 Mdot
.6542 .44697 Mdot
.38146 .63197 Mdot
.28288 .48477 Mdot
.62246 .40616 Mdot
.44652 .65253 Mdot
.62686 .51268 Mdot
.3783 .59604 Mdot
.74413 .4176 Mdot
.25023 .63838 Mdot
.46531 .63698 Mdot
.48328 .28334 Mdot
.61463 .51093 Mdot
.48984 .34753 Mdot
.3749 .45981 Mdot
.5296 .68118 Mdot
.55882 .67537 Mdot
.6405 .46084 Mdot
.56965 .54331 Mdot
.40568 .73993 Mdot
.6297 .46304 Mdot
.59068 .48665 Mdot
.28587 .46689 Mdot
.58775 .49072 Mdot
.58213 .45641 Mdot
.6257 .43869 Mdot
.64665 .435 Mdot
.36213 .48008 Mdot
.3152 .67513 Mdot
.70384 .46689 Mdot
.69838 .49487 Mdot
.34456 .43467 Mdot
.57892 .77212 Mdot
.31258 .45789 Mdot
.78263 .6571 Mdot
.31713 .4856 Mdot
.55526 .66723 Mdot
.60041 .74803 Mdot
.63946 .55811 Mdot
.46871 .37141 Mdot
.30058 .49335 Mdot
.53431 .6778 Mdot
.35824 .4639 Mdot
.40006 .65242 Mdot
.81209 .39386 Mdot
.45419 .38436 Mdot
.40387 .29338 Mdot
.30886 .4106 Mdot
.29078 .64904 Mdot
.43704 .63315 Mdot
.49379 .32851 Mdot
.70792 .38517 Mdot
.58176 .46064 Mdot
.55335 .69848 Mdot
.64735 .46363 Mdot
.37798 .46539 Mdot
.38452 .62421 Mdot
.23608 .66672 Mdot
.5612 .6878 Mdot
.7762 .30524 Mdot
.41694 .60869 Mdot
.59106 .4481 Mdot
.3137 .45339 Mdot
.68162 .21908 Mdot
.33057 .45047 Mdot
.52963 .30177 Mdot
.4381 .31323 Mdot
.22954 .68854 Mdot
.47009 .32385 Mdot
.25739 .62509 Mdot
.6087 .15296 Mdot
.32937 .70697 Mdot
.4428 .33782 Mdot
.43149 .55708 Mdot
.60275 .4879 Mdot
.60178 .51212 Mdot
.24173 .64477 Mdot
.44975 .28508 Mdot
.58131 .47608 Mdot
.32467 .54437 Mdot
.32877 .42945 Mdot
.71986 .2852 Mdot
.43398 .62656 Mdot
.63738 .49948 Mdot
.37717 .48878 Mdot
.35615 .49718 Mdot
.4226 .59843 Mdot
.3161 .46083 Mdot
.61625 .48106 Mdot
.47557 .33031 Mdot
.36594 .56236 Mdot
.56284 .66412 Mdot
.45431 .84131 Mdot
.57743 .68816 Mdot
.4207 .63362 Mdot
.62739 .53637 Mdot
.39191 .62632 Mdot
.77055 .76099 Mdot
.60931 .48995 Mdot
.44939 .34046 Mdot
.58654 .48327 Mdot
.61145 .50808 Mdot
.64922 .43863 Mdot
.38926 .64137 Mdot
.58545 .72773 Mdot
.62631 .52888 Mdot
.32649 .47231 Mdot
.5888 .26784 Mdot
.56248 .48179 Mdot
.47726 .62416 Mdot
.75998 .51674 Mdot
.35549 .40137 Mdot
.43832 .30014 Mdot
.40679 .63542 Mdot
.45269 .32985 Mdot
.31323 .26379 Mdot
.45943 .32872 Mdot
.5779 .31144 Mdot
.71803 .38734 Mdot
.75303 .37788 Mdot
.74114 .36475 Mdot
.42738 .51045 Mdot
.44457 .2868 Mdot
.50775 .66549 Mdot
.43855 .34353 Mdot
.46016 .29391 Mdot
.32293 .16303 Mdot
.4842 .36522 Mdot
.64126 .50577 Mdot
.56481 .47192 Mdot
.28626 .66955 Mdot
.65275 .62452 Mdot
.5928 .47022 Mdot
.58811 .46843 Mdot
.53718 .65508 Mdot
.3086 .27262 Mdot
.31804 .64049 Mdot
.51941 .20999 Mdot
.46808 .80774 Mdot
.64623 .46565 Mdot
.5848 .50327 Mdot
.69107 .45007 Mdot
.55679 .16984 Mdot
.18741 .52362 Mdot
.49558 .29019 Mdot
.69498 .47295 Mdot
.32714 .71812 Mdot
.65806 .44803 Mdot
.64963 .51012 Mdot
.60728 .48396 Mdot
.38822 .62619 Mdot
.43796 .29538 Mdot
.64308 .43078 Mdot
.63268 .73115 Mdot
.64373 .51048 Mdot
.27222 .47503 Mdot
.32844 .78837 Mdot
.64258 .49888 Mdot
.42663 .33808 Mdot
.59824 .50964 Mdot
.45836 .29888 Mdot
.48508 .30839 Mdot
.69173 .46798 Mdot
.56219 .28171 Mdot
.42907 .33357 Mdot
.62108 .47096 Mdot
.39498 .65298 Mdot
.71685 .74372 Mdot
.64653 .45137 Mdot
.53198 .68739 Mdot
.65674 .49908 Mdot
.53266 .69794 Mdot
.59301 .48011 Mdot
.43936 .61478 Mdot
.5491 .37535 Mdot
.39868 .61702 Mdot
.18963 .58943 Mdot
.44187 .61113 Mdot
.80038 .33197 Mdot
.47637 .28994 Mdot
.31246 .57855 Mdot
.38509 .22638 Mdot
.25344 .46977 Mdot
.4912 .42898 Mdot
.43 .46314 Mdot
.32798 .44728 Mdot
.44394 .3083 Mdot
.35022 .26219 Mdot
.52285 .74917 Mdot
.5134 .72 Mdot
.37263 .614 Mdot
.1418 .47192 Mdot
.35202 .22073 Mdot
.67864 .50159 Mdot
.66811 .35558 Mdot
.63646 .3105 Mdot
.65751 .44652 Mdot
.65602 .44077 Mdot
.471 .64966 Mdot
.63083 .52981 Mdot
.38117 .36053 Mdot
.42548 .63063 Mdot
.53559 .68212 Mdot
.44901 .35078 Mdot
.57151 .689 Mdot
.54828 .75335 Mdot
.42731 .45449 Mdot
.4101 .65111 Mdot
.5877 .53465 Mdot
.59445 .46358 Mdot
.46692 .30008 Mdot
.43823 .26297 Mdot
.44575 .36234 Mdot
.54346 .67608 Mdot
.42666 .62493 Mdot
.2194 .3536 Mdot
.59262 .46181 Mdot
.47709 .34944 Mdot
.49588 .43728 Mdot
.58356 .49234 Mdot
.37133 .46136 Mdot
.60195 .49266 Mdot
.44353 .3456 Mdot
.5878 .49037 Mdot
.46907 .32173 Mdot
.41568 .62578 Mdot
.61337 .43835 Mdot
.62045 .44541 Mdot
.7347 .26888 Mdot
.54291 .66465 Mdot
.49573 .33588 Mdot
.51709 .60758 Mdot
.57719 .49053 Mdot
.28005 .56407 Mdot
.63087 .51111 Mdot
.47299 .39836 Mdot
.6756 .50029 Mdot
.27069 .44757 Mdot
.6907 .51573 Mdot
.65184 .46007 Mdot
.50999 .50813 Mdot
.62562 .3122 Mdot
.68563 .54242 Mdot
.3101 .48553 Mdot
.49659 .34543 Mdot
.72753 .29713 Mdot
.36595 .57257 Mdot
.40489 .66647 Mdot
.71543 .61138 Mdot
.6299 .42974 Mdot
.63792 .49071 Mdot
.38497 .40275 Mdot
.56461 .69011 Mdot
.48569 .34917 Mdot
.53581 .66811 Mdot
.77444 .32176 Mdot
.57305 .64999 Mdot
.41124 .57646 Mdot
.38567 .73588 Mdot
.19822 .39714 Mdot
.53978 .65348 Mdot
.44207 .34525 Mdot
.36539 .72078 Mdot
.59096 .4434 Mdot
.52955 .55974 Mdot
.55262 .65892 Mdot
.1501 .56726 Mdot
.58334 .45508 Mdot
.49404 .42547 Mdot
.35114 .44578 Mdot
.53686 .65748 Mdot
.35849 .43751 Mdot
.60555 .45892 Mdot
.31977 .63992 Mdot
.46076 .31085 Mdot
.36864 .43628 Mdot
.56391 .44983 Mdot
.53982 .67212 Mdot
.44426 .63028 Mdot
.39845 .45878 Mdot
.30647 .46896 Mdot
.61625 .77766 Mdot
.22494 .66545 Mdot
.42615 .62194 Mdot
.6289 .23013 Mdot
.32781 .49637 Mdot
.58532 .44631 Mdot
.32778 .26259 Mdot
.60738 .51247 Mdot
.22525 .43636 Mdot
.41325 .63826 Mdot
.29776 .65698 Mdot
.58436 .49664 Mdot
.6562 .45538 Mdot
.44479 .37588 Mdot
.4052 .61338 Mdot
.46985 .34112 Mdot
.49825 .32762 Mdot
.41641 .62436 Mdot
.46162 .32069 Mdot
.54019 .64832 Mdot
.36954 .29237 Mdot
.32441 .48736 Mdot
.33125 .4803 Mdot
.38979 .61241 Mdot
.40238 .63932 Mdot
.39633 .6272 Mdot
.60159 .49331 Mdot
.47704 .35602 Mdot
.6089 .46661 Mdot
.66281 .49939 Mdot
.58723 .25565 Mdot
.4446 .29158 Mdot
.60963 .47486 Mdot
.52867 .58639 Mdot
.52085 .4839 Mdot
.40192 .65598 Mdot
.3503 .44752 Mdot
.32057 .55274 Mdot
.24591 .58409 Mdot
.63409 .50148 Mdot
.57676 .61799 Mdot
.44089 .34546 Mdot
.55361 .68646 Mdot
.58084 .66244 Mdot
.55272 .67807 Mdot
.31654 .42099 Mdot
.47406 .28673 Mdot
.5178 .21525 Mdot
.63841 .49635 Mdot
.40357 .38775 Mdot
.50458 .30256 Mdot
.39712 .71958 Mdot
.35011 .44887 Mdot
.5849 .48188 Mdot
.49357 .58531 Mdot
.68224 .39098 Mdot
.60485 .50829 Mdot
.56178 .47158 Mdot
.47337 .79215 Mdot
.5522 .50609 Mdot
.44967 .37292 Mdot
.68848 .22827 Mdot
.58515 .51523 Mdot
.23214 .37715 Mdot
.4801 .8554 Mdot
.62705 .50642 Mdot
.66227 .46378 Mdot
.59764 .45274 Mdot
.59099 .51014 Mdot
.42736 .3319 Mdot
.67793 .59706 Mdot
.32247 .49437 Mdot
.40302 .38239 Mdot
.37503 .47386 Mdot
.41017 .589 Mdot
.30186 .66087 Mdot
.43989 .31275 Mdot
.5726 .67194 Mdot
.42688 .81034 Mdot
.6036 .19838 Mdot
.42634 .60378 Mdot
.20035 .4489 Mdot
.5517 .66145 Mdot
.57488 .45307 Mdot
.52276 .66636 Mdot
.43133 .64951 Mdot
.33004 .48348 Mdot
.56153 .49734 Mdot
.4386 .33293 Mdot
.46153 .36499 Mdot
.5827 .48392 Mdot
.34151 .73812 Mdot
.37238 .45328 Mdot
.30435 .47601 Mdot
.63446 .5194 Mdot
.58016 .51198 Mdot
.46834 .33754 Mdot
.39833 .60185 Mdot
.76029 .37629 Mdot
.55126 .69352 Mdot
.6714 .45662 Mdot
.58864 .49496 Mdot
.80173 .39276 Mdot
.32401 .47313 Mdot
.43657 .65844 Mdot
.66483 .51214 Mdot
.2872 .35765 Mdot
.66061 .51507 Mdot
.68364 .44026 Mdot
.39528 .65376 Mdot
.68941 .43161 Mdot
.68056 .45943 Mdot
.47441 .3935 Mdot
.3421 .44147 Mdot
.4548 .33859 Mdot
.46868 .39522 Mdot
.38886 .26703 Mdot
.36861 .46448 Mdot
.6036 .48264 Mdot
.35338 .45142 Mdot
.62611 .51795 Mdot
.59999 .52497 Mdot
.34295 .44959 Mdot
.47013 .33994 Mdot
.55561 .79609 Mdot
.32584 .69543 Mdot
.59701 .5172 Mdot
.687 .46179 Mdot
.65284 .60888 Mdot
.56518 .7255 Mdot
.66234 .45684 Mdot
.44566 .35288 Mdot
.6031 .45539 Mdot
.37715 .44888 Mdot
.53422 .65171 Mdot
.44464 .33792 Mdot
.41599 .60326 Mdot
.43531 .61359 Mdot
.31064 .37601 Mdot
.36611 .62223 Mdot
.66885 .4647 Mdot
.41657 .3092 Mdot
.42518 .34774 Mdot
.39308 .802 Mdot
.41647 .62087 Mdot
.53148 .68898 Mdot
.63043 .45139 Mdot
.75172 .6004 Mdot
.38262 .48302 Mdot
.27027 .22712 Mdot
.46708 .21344 Mdot
.52429 .65247 Mdot
.46891 .22718 Mdot
.43723 .60707 Mdot
.67199 .4447 Mdot
.5349 .69005 Mdot
.43594 .6311 Mdot
.6154 .52341 Mdot
.69197 .4651 Mdot
.52537 .31341 Mdot
.4103 .48335 Mdot
.34866 .45238 Mdot
.37603 .60174 Mdot
.51671 .66216 Mdot
.43787 .59595 Mdot
.48519 .30217 Mdot
.65486 .47211 Mdot
.63661 .5335 Mdot
.40172 .59993 Mdot
.4013 .66737 Mdot
.61548 .47356 Mdot
.43394 .32936 Mdot
.4783 .64343 Mdot
.64279 .46953 Mdot
.40589 .47625 Mdot
.45157 .28021 Mdot
.43143 .62616 Mdot
.65615 .45978 Mdot
.52518 .70224 Mdot
.4113 .60528 Mdot
.4056 .65657 Mdot
.58376 .50191 Mdot
.54694 .64658 Mdot
.68853 .48961 Mdot
.31632 .4799 Mdot
.14822 .49775 Mdot
.37829 .45005 Mdot
.37893 .55785 Mdot
.54697 .49862 Mdot
.29544 .32472 Mdot
.44277 .29898 Mdot
.74347 .56503 Mdot
.32531 .54603 Mdot
.64816 .41968 Mdot
.70721 .73871 Mdot
.33245 .51763 Mdot
.38652 .78679 Mdot
.75027 .6518 Mdot
.55514 .65482 Mdot
.35747 .46599 Mdot
.66264 .46404 Mdot
.38618 .46065 Mdot
.5395 .69448 Mdot
.19073 .58683 Mdot
.64897 .45078 Mdot
.45945 .35795 Mdot
.61377 .479 Mdot
.4674 .3617 Mdot
.58665 .50979 Mdot
.67767 .51546 Mdot
.27706 .50566 Mdot
.68797 .56704 Mdot
.66368 .51079 Mdot
.76673 .26308 Mdot
.51886 .43178 Mdot
.54305 .69062 Mdot
.61565 .46127 Mdot
.45605 .63889 Mdot
.36758 .48976 Mdot
.25423 .4409 Mdot
.38763 .62787 Mdot
.30776 .46943 Mdot
.46448 .32803 Mdot
.4127 .63402 Mdot
.42089 .59888 Mdot
.68688 .42788 Mdot
.53053 .65046 Mdot
.34424 .47782 Mdot
.65468 .48649 Mdot
.64986 .45242 Mdot
.62857 .22647 Mdot
.5013 .7549 Mdot
.42743 .27038 Mdot
.49074 .16818 Mdot
.49447 .30665 Mdot
.53687 .67848 Mdot
.38614 .63828 Mdot
.66751 .48863 Mdot
.62075 .48496 Mdot
.29116 .56476 Mdot
.43836 .35193 Mdot
.45675 .51404 Mdot
.46009 .24233 Mdot
.50826 .62285 Mdot
.68979 .57512 Mdot
.44744 .35101 Mdot
.68343 .57863 Mdot
.55154 .63418 Mdot
.61586 .80916 Mdot
.64945 .58584 Mdot
.35538 .44617 Mdot
.66725 .58707 Mdot
.48508 .34517 Mdot
.62458 .52762 Mdot
.38615 .64994 Mdot
.36877 .63294 Mdot
.46126 .34179 Mdot
.45129 .6304 Mdot
.56217 .65298 Mdot
.66291 .47779 Mdot
.52404 .20194 Mdot
.34437 .34855 Mdot
.38683 .6107 Mdot
.63965 .409 Mdot
.35794 .47686 Mdot
.58227 .48494 Mdot
.5484 .65075 Mdot
.36143 .45513 Mdot
.79526 .4988 Mdot
.34949 .42428 Mdot
.63379 .45435 Mdot
.80542 .39238 Mdot
.36504 .46287 Mdot
.54395 .41188 Mdot
.64715 .47495 Mdot
.31436 .47299 Mdot
.66213 .40292 Mdot
.26673 .61257 Mdot
.49646 .55624 Mdot
.77553 .67534 Mdot
.48408 .52105 Mdot
.37789 .62844 Mdot
.27974 .63404 Mdot
.24772 .4645 Mdot
.34704 .49485 Mdot
.42208 .66502 Mdot
.55855 .58362 Mdot
.3535 .43766 Mdot
.57646 .4533 Mdot
.62621 .51013 Mdot
.19096 .5369 Mdot
.34947 .50882 Mdot
.25468 .62746 Mdot
.32334 .38712 Mdot
.57597 .48823 Mdot
.682 .5025 Mdot
.62533 .48463 Mdot
.43809 .36198 Mdot
.33666 .4587 Mdot
.73249 .24702 Mdot
.37384 .4588 Mdot
.55209 .24491 Mdot
.39303 .61188 Mdot
.43422 .62872 Mdot
.63877 .50108 Mdot
.49614 .41679 Mdot
.77654 .51012 Mdot
.61865 .47784 Mdot
.58906 .69854 Mdot
.20728 .55669 Mdot
.57904 .50773 Mdot
.4355 .31149 Mdot
.6689 .42282 Mdot
.55027 .43644 Mdot
.32512 .48816 Mdot
.56958 .66538 Mdot
.76054 .54627 Mdot
.33676 .48435 Mdot
.6367 .48994 Mdot
.30161 .32919 Mdot
.60956 .50229 Mdot
.60128 .51883 Mdot
.50317 .23785 Mdot
.57863 .65392 Mdot
.4045 .62486 Mdot
.55137 .67539 Mdot
.45272 .29761 Mdot
.24308 .22786 Mdot
.57511 .65326 Mdot
.78385 .49977 Mdot
.17962 .54413 Mdot
.64841 .59221 Mdot
.4861 .3527 Mdot
.51992 .66628 Mdot
.36712 .44793 Mdot
.71351 .74832 Mdot
.52864 .34157 Mdot
.36092 .51828 Mdot
.64051 .47426 Mdot
.49305 .36328 Mdot
.45997 .3682 Mdot
.3656 .43498 Mdot
.48789 .31329 Mdot
.71179 .49084 Mdot
.61258 .52553 Mdot
.36589 .48374 Mdot
.30666 .35036 Mdot
.31336 .49036 Mdot
.42774 .54449 Mdot
.62129 .46241 Mdot
.44657 .34212 Mdot
.66944 .4497 Mdot
.4294 .29227 Mdot
.44396 .64869 Mdot
.60223 .53764 Mdot
.56437 .65309 Mdot
.28216 .34173 Mdot
.42649 .61931 Mdot
.52855 .61222 Mdot
.46455 .29892 Mdot
.34103 .41376 Mdot
.47241 .29803 Mdot
.41976 .31584 Mdot
.31292 .45584 Mdot
.483 .32656 Mdot
.66264 .46699 Mdot
.51285 .56732 Mdot
.46375 .30459 Mdot
.34176 .46997 Mdot
.56781 .67059 Mdot
.46852 .32626 Mdot
.45364 .60075 Mdot
.63518 .45034 Mdot
.39298 .64169 Mdot
.56463 .73964 Mdot
.48847 .36528 Mdot
.57299 .64131 Mdot
.39792 .6657 Mdot
.55945 .70009 Mdot
.33727 .7675 Mdot
.35592 .42925 Mdot
.53778 .25671 Mdot
.58387 .71295 Mdot
.46438 .37221 Mdot
.5782 .74463 Mdot
.66087 .49988 Mdot
.63249 .45014 Mdot
.53628 .69972 Mdot
.45966 .36821 Mdot
.54424 .84583 Mdot
.54235 .51629 Mdot
.41909 .52497 Mdot
.2956 .48246 Mdot
.79798 .32246 Mdot
.42053 .53663 Mdot
.44027 .85418 Mdot
.60817 .41363 Mdot
.3719 .65361 Mdot
.62831 .49733 Mdot
.29919 .53989 Mdot
.54246 .66998 Mdot
.43042 .56713 Mdot
.64878 .53463 Mdot
.41001 .62786 Mdot
.61791 .44257 Mdot
.50792 .51834 Mdot
.55818 .41093 Mdot
.53757 .69696 Mdot
.35787 .73212 Mdot
.49102 .358 Mdot
.56019 .66235 Mdot
.43279 .63989 Mdot
.7264 .55537 Mdot
.61347 .52376 Mdot
.58079 .44632 Mdot
.50706 .62408 Mdot
.47926 .35609 Mdot
.37683 .63815 Mdot
.31907 .48137 Mdot
.57 .6765 Mdot
.59557 .46446 Mdot
.66176 .50401 Mdot
.27437 .55348 Mdot
.36353 .47538 Mdot
.3657 .6362 Mdot
.34553 .44357 Mdot
.4242 .59655 Mdot
.61563 .53176 Mdot
.43207 .61405 Mdot
.6426 .42772 Mdot
.27703 .48875 Mdot
.52292 .24401 Mdot
.63098 .32542 Mdot
.41752 .63793 Mdot
.77476 .46345 Mdot
.36502 .47267 Mdot
.32396 .45511 Mdot
.17434 .47418 Mdot
.52609 .2992 Mdot
.60295 .20694 Mdot
.68098 .73271 Mdot
.36261 .48241 Mdot
.35043 .47559 Mdot
.39507 .64199 Mdot
.48261 .32305 Mdot
.49314 .3071 Mdot
.42123 .59581 Mdot
.66176 .66671 Mdot
.4854 .34936 Mdot
.66765 .77553 Mdot
.69262 .26331 Mdot
.62393 .42346 Mdot
.4075 .57377 Mdot
.55864 .68467 Mdot
.6706 .65075 Mdot
.51034 .53096 Mdot
.65502 .45163 Mdot
.74109 .59068 Mdot
.39318 .60681 Mdot
.47576 .41044 Mdot
.77478 .66344 Mdot
.61587 .43999 Mdot
.65037 .4783 Mdot
.62912 .48954 Mdot
.54116 .64338 Mdot
.53799 .34119 Mdot
.65931 .46849 Mdot
.65957 .66924 Mdot
.5788 .48737 Mdot
.56641 .40264 Mdot
.55678 .67584 Mdot
.63547 .58178 Mdot
.53503 .75271 Mdot
.69145 .23518 Mdot
.53856 .43665 Mdot
.31924 .48379 Mdot
.51498 .70729 Mdot
.32875 .44926 Mdot
.58949 .31303 Mdot
.61681 .59486 Mdot
.49486 .30259 Mdot
.65687 .45324 Mdot
.42171 .63352 Mdot
.46058 .3679 Mdot
.27598 .5989 Mdot
.28487 .19209 Mdot
.32268 .4901 Mdot
.55928 .88445 Mdot
.31567 .4691 Mdot
.41831 .59722 Mdot
.4675 .33695 Mdot
.72608 .39774 Mdot
.39 .32298 Mdot
.46672 .32335 Mdot
.53438 .82495 Mdot
.49236 .28399 Mdot
.75116 .52555 Mdot
.46674 .37807 Mdot
.34772 .47109 Mdot
.30405 .41969 Mdot
.71085 .50916 Mdot
.65156 .50491 Mdot
.43357 .46274 Mdot
.77355 .50488 Mdot
.66165 .49832 Mdot
.4256 .62876 Mdot
.52527 .25824 Mdot
.7268 .59793 Mdot
.48426 .33395 Mdot
.3428 .42721 Mdot
.65167 .47044 Mdot
.59318 .50273 Mdot
.62031 .52581 Mdot
.47741 .20415 Mdot
.61173 .81088 Mdot
.62382 .52924 Mdot
.58132 .50336 Mdot
.41211 .63131 Mdot
.56226 .72002 Mdot
.35401 .71236 Mdot
.61133 .2344 Mdot
.63269 .43624 Mdot
.56041 .66719 Mdot
.51416 .6592 Mdot
.64857 .52112 Mdot
.53641 .57939 Mdot
.30628 .31992 Mdot
.65537 .48489 Mdot
.52723 .26297 Mdot
.40237 .69186 Mdot
.36034 .6246 Mdot
.41057 .60239 Mdot
.49431 .33991 Mdot
.40385 .59677 Mdot
.44192 .61927 Mdot
.72633 .41203 Mdot
.47144 .51466 Mdot
.29732 .50909 Mdot
.54375 .67847 Mdot
.6167 .48958 Mdot
.665 .55559 Mdot
.28946 .34844 Mdot
.32981 .44442 Mdot
.44265 .32925 Mdot
.37047 .48921 Mdot
.51189 .64892 Mdot
.40835 .25667 Mdot
.38081 .60884 Mdot
.34777 .48774 Mdot
.39235 .43938 Mdot
.56131 .66978 Mdot
.37743 .4438 Mdot
.39002 .42205 Mdot
.58002 .52274 Mdot
.65447 .35953 Mdot
.62298 .47199 Mdot
.43218 .81723 Mdot
.35114 .47998 Mdot
.28704 .43962 Mdot
.64517 .48981 Mdot
.41319 .6072 Mdot
.72518 .449 Mdot
.6489 .50849 Mdot
.39929 .59812 Mdot
.67511 .50608 Mdot
.5749 .69179 Mdot
.44064 .28584 Mdot
.39093 .33278 Mdot
.13945 .46213 Mdot
.52717 .65284 Mdot
.27818 .59232 Mdot
.65751 .44976 Mdot
.26496 .70823 Mdot
.47089 .32839 Mdot
.67544 .4872 Mdot
.71751 .58627 Mdot
.47031 .3103 Mdot
.45169 .32558 Mdot
.5964 .4905 Mdot
.35322 .44467 Mdot
.42883 .62134 Mdot
.56089 .67525 Mdot
.41562 .83171 Mdot
.63692 .46651 Mdot
.61346 .44834 Mdot
.55609 .6617 Mdot
.37181 .46952 Mdot
.65976 .51474 Mdot
.67924 .7024 Mdot
.57566 .84313 Mdot
.31404 .46498 Mdot
.59189 .44522 Mdot
.58805 .33763 Mdot
.53519 .48859 Mdot
.23322 .7089 Mdot
.53464 .56789 Mdot
.40367 .63008 Mdot
.56952 .53563 Mdot
.36198 .17807 Mdot
.5695 .6698 Mdot
.60219 .19999 Mdot
.59122 .50115 Mdot
.5893 .46301 Mdot
.44335 .35818 Mdot
.6115 .46823 Mdot
.4387 .31852 Mdot
.17276 .40325 Mdot
.80323 .37735 Mdot
.49205 .31897 Mdot
.47142 .37243 Mdot
.76346 .53592 Mdot
.3479 .56208 Mdot
.46195 .33921 Mdot
.595 .52214 Mdot
.57455 .5931 Mdot
.47047 .4048 Mdot
.52155 .67602 Mdot
.5689 .74981 Mdot
.57641 .55432 Mdot
.56438 .6135 Mdot
.57573 .77708 Mdot
.60153 .56731 Mdot
.45515 .56367 Mdot
.32052 .46701 Mdot
.61768 .43923 Mdot
.36794 .6325 Mdot
.36516 .62514 Mdot
.65473 .42969 Mdot
.60986 .49482 Mdot
.45629 .29749 Mdot
.56344 .68818 Mdot
.33883 .49718 Mdot
.59005 .4658 Mdot
.74083 .56231 Mdot
.57006 .68546 Mdot
.48622 .31711 Mdot
.57555 .26195 Mdot
.57369 .69932 Mdot
.68317 .51275 Mdot
.65272 .4961 Mdot
.60969 .48133 Mdot
.70842 .51655 Mdot
.33301 .45828 Mdot
.59165 .75109 Mdot
.5668 .48232 Mdot
.76953 .3129 Mdot
.32631 .52707 Mdot
.61379 .5448 Mdot
.48151 .30032 Mdot
.30896 .44433 Mdot
.44374 .6077 Mdot
.38 .25929 Mdot
.63409 .45634 Mdot
.3453 .73463 Mdot
.19548 .54792 Mdot
.43452 .6567 Mdot
.43131 .29331 Mdot
.54996 .68157 Mdot
.6175 .48047 Mdot
.56035 .28468 Mdot
.62937 .50886 Mdot
.58015 .63381 Mdot
.41018 .6583 Mdot
.3215 .46409 Mdot
.40179 .79815 Mdot
.36859 .61007 Mdot
.45266 .3289 Mdot
.83267 .48655 Mdot
.43799 .31804 Mdot
.49368 .31057 Mdot
.58741 .26444 Mdot
.33236 .45743 Mdot
.31547 .19611 Mdot
.18288 .40438 Mdot
.59784 .53317 Mdot
.36954 .46955 Mdot
.45765 .34724 Mdot
.57923 .47337 Mdot
.47093 .26992 Mdot
.46616 .28522 Mdot
.60554 .52973 Mdot
.5925 .454 Mdot
.27048 .66261 Mdot
.75489 .68163 Mdot
.54846 .68073 Mdot
.45206 .29401 Mdot
.38658 .34927 Mdot
.578 .47263 Mdot
.63944 .49594 Mdot
.23932 .47991 Mdot
.52985 .65359 Mdot
.36793 .34384 Mdot
.59232 .50204 Mdot
.80785 .43278 Mdot
.69527 .44538 Mdot
.42899 .32859 Mdot
.32285 .45217 Mdot
.70547 .24892 Mdot
.39852 .43207 Mdot
.4395 .3191 Mdot
.57427 .66781 Mdot
.43708 .37127 Mdot
.78686 .49171 Mdot
.37543 .47035 Mdot
.44353 .34574 Mdot
.48982 .58622 Mdot
.34488 .45849 Mdot
.34695 .48394 Mdot
.59634 .25717 Mdot
.44372 .65492 Mdot
.53633 .64401 Mdot
.34726 .47733 Mdot
.29052 .3019 Mdot
.34619 .46629 Mdot
.177 .42218 Mdot
.60741 .44041 Mdot
.70203 .64248 Mdot
.38881 .55538 Mdot
.59813 .55502 Mdot
.35574 .48114 Mdot
.53499 .65613 Mdot
.61472 .52235 Mdot
.48925 .34036 Mdot
.55462 .69682 Mdot
.38619 .4938 Mdot
.3907 .63092 Mdot
.47467 .30179 Mdot
.33135 .50471 Mdot
.46249 .36342 Mdot
.34936 .26397 Mdot
.16614 .53853 Mdot
.77537 .55892 Mdot
.38938 .31347 Mdot
.61114 .52346 Mdot
.63034 .76792 Mdot
.60091 .43833 Mdot
.60547 .49842 Mdot
.42948 .6282 Mdot
.71652 .62146 Mdot
.46966 .34053 Mdot
.48986 .83727 Mdot
.32965 .48903 Mdot
.70202 .24182 Mdot
.53561 .4561 Mdot
.68178 .47359 Mdot
.46046 .30399 Mdot
.43474 .34155 Mdot
.61621 .2998 Mdot
.42754 .58786 Mdot
.66536 .45296 Mdot
.5577 .47306 Mdot
.66721 .43427 Mdot
.32965 .48562 Mdot
.54326 .5954 Mdot
.3785 .62442 Mdot
.18743 .60892 Mdot
.40997 .65948 Mdot
.57895 .6284 Mdot
.48546 .3294 Mdot
.5751 .65369 Mdot
.64191 .4957 Mdot
.44598 .25802 Mdot
.43881 .35436 Mdot
.54129 .70188 Mdot
.53217 .66557 Mdot
.25175 .56149 Mdot
.34359 .44975 Mdot
.64841 .51344 Mdot
.65728 .46156 Mdot
.60464 .4683 Mdot
.60352 .49265 Mdot
.32653 .49097 Mdot
.6244 .52317 Mdot
.38486 .48319 Mdot
.39392 .23864 Mdot
.70758 .66504 Mdot
.48569 .51806 Mdot
.21173 .44732 Mdot
.48578 .33966 Mdot
.29119 .30859 Mdot
.54482 .46972 Mdot
.39897 .20383 Mdot
.21633 .61891 Mdot
.56972 .50053 Mdot
.43661 .61828 Mdot
.67279 .40264 Mdot
.3711 .61804 Mdot
.44234 .86416 Mdot
.26252 .50565 Mdot
.74529 .70099 Mdot
.64881 .45182 Mdot
.51018 .56697 Mdot
.26437 .32128 Mdot
.59184 .44168 Mdot
.25994 .54042 Mdot
.22406 .43466 Mdot
.34821 .72258 Mdot
.54322 .65037 Mdot
.64321 .45852 Mdot
.67676 .54866 Mdot
.66274 .47123 Mdot
.63296 .49796 Mdot
.62225 .5246 Mdot
.32131 .49727 Mdot
.67351 .48147 Mdot
.61027 .51689 Mdot
.4116 .74579 Mdot
.68847 .57249 Mdot
.3782 .65444 Mdot
.17475 .49789 Mdot
.57492 .65195 Mdot
.46182 .30083 Mdot
.6057 .80547 Mdot
.35504 .44652 Mdot
.62354 .30216 Mdot
.60619 .48781 Mdot
.29196 .67588 Mdot
.38674 .43214 Mdot
.57262 .66195 Mdot
.43428 .6477 Mdot
.74523 .71592 Mdot
.42158 .62905 Mdot
.30045 .44314 Mdot
.41619 .61042 Mdot
.54183 .49005 Mdot
.45536 .29689 Mdot
.64899 .5172 Mdot
.34064 .47764 Mdot
.41744 .60137 Mdot
.65489 .61738 Mdot
.62475 .48677 Mdot
.41556 .6239 Mdot
.64787 .51741 Mdot
.40774 .28149 Mdot
.66085 .25518 Mdot
.44172 .62448 Mdot
.38945 .43928 Mdot
.32983 .47026 Mdot
.55307 .64588 Mdot
.471 .30393 Mdot
.4413 .32501 Mdot
.36041 .45616 Mdot
.48865 .25326 Mdot
.635 .43533 Mdot
.58271 .46405 Mdot
.73037 .27349 Mdot
.66637 .47154 Mdot
.72711 .55178 Mdot
.49823 .58744 Mdot
.48988 .32775 Mdot
.68382 .47266 Mdot
.59254 .49133 Mdot
.63342 .45315 Mdot
.43999 .24109 Mdot
.39479 .6018 Mdot
.6128 .43993 Mdot
.53062 .67183 Mdot
.36609 .7003 Mdot
.58221 .48575 Mdot
.70452 .45209 Mdot
.44104 .32714 Mdot
.49316 .17377 Mdot
.31677 .46669 Mdot
.43212 .63931 Mdot
.41689 .63904 Mdot
.58212 .75777 Mdot
.25176 .3724 Mdot
.49917 .58619 Mdot
.20176 .65237 Mdot
.27748 .50575 Mdot
.53613 .67114 Mdot
.35856 .60392 Mdot
.29078 .42544 Mdot
.40871 .6458 Mdot
.32602 .49295 Mdot
.59271 .44589 Mdot
.62967 .43588 Mdot
.32388 .21638 Mdot
.65509 .51893 Mdot
.55396 .68222 Mdot
.31508 .4932 Mdot
.48378 .3461 Mdot
.57289 .667 Mdot
.34368 .44344 Mdot
.49354 .33559 Mdot
.56575 .49357 Mdot
.56496 .48369 Mdot
.44378 .32637 Mdot
.44687 .35912 Mdot
.65072 .49447 Mdot
.33157 .62484 Mdot
.47233 .37065 Mdot
.44613 .35046 Mdot
.38188 .61038 Mdot
.36678 .62653 Mdot
.70048 .49499 Mdot
.36265 .4718 Mdot
.61285 .51888 Mdot
.41569 .63407 Mdot
.57356 .65153 Mdot
.47246 .34098 Mdot
.59451 .51425 Mdot
.58623 .48025 Mdot
.56252 .67018 Mdot
.56429 .64765 Mdot
.54564 .65247 Mdot
.34789 .50491 Mdot
.60895 .46186 Mdot
.46404 .33283 Mdot
.33628 .45262 Mdot
.51737 .65486 Mdot
.52316 .67121 Mdot
.37463 .58383 Mdot
.66921 .4783 Mdot
.36428 .56461 Mdot
.38152 .16688 Mdot
.77827 .34837 Mdot
.44489 .6394 Mdot
.44373 .60556 Mdot
.61817 .62188 Mdot
.45253 .41159 Mdot
.37029 .45816 Mdot
.56838 .7212 Mdot
.77085 .53562 Mdot
.56962 .51193 Mdot
.58159 .50889 Mdot
.67506 .51487 Mdot
.54196 .65496 Mdot
.7271 .62437 Mdot
.44115 .31087 Mdot
.68981 .55383 Mdot
.56868 .68917 Mdot
.39273 .66452 Mdot
.36628 .58517 Mdot
.41464 .65883 Mdot
.57052 .46139 Mdot
.64618 .33267 Mdot
.2702 .34035 Mdot
.67029 .7275 Mdot
.3608 .47792 Mdot
.66126 .55693 Mdot
.26218 .70055 Mdot
.44791 .32391 Mdot
.4084 .58826 Mdot
.53441 .67237 Mdot
.44921 .36086 Mdot
.377 .48288 Mdot
.34752 .47566 Mdot
.38597 .61257 Mdot
.38584 .61754 Mdot
.39937 .65075 Mdot
.46536 .28353 Mdot
.48428 .32754 Mdot
.63136 .45684 Mdot
.47661 .34099 Mdot
.4434 .20322 Mdot
.54185 .70648 Mdot
.44706 .66119 Mdot
.35954 .46791 Mdot
.48881 .34869 Mdot
.62436 .48381 Mdot
.44971 .40331 Mdot
.26922 .41071 Mdot
.54074 .69078 Mdot
.64323 .23946 Mdot
.41098 .84373 Mdot
.65285 .51082 Mdot
.32761 .46517 Mdot
.52492 .19774 Mdot
.62995 .48683 Mdot
.38578 .64194 Mdot
.42968 .78212 Mdot
.34736 .65041 Mdot
.6464 .51005 Mdot
.57572 .52264 Mdot
.31322 .4779 Mdot
.19565 .61772 Mdot
.63372 .46098 Mdot
.3679 .3232 Mdot
.38221 .43223 Mdot
.37892 .63455 Mdot
.7003 .79123 Mdot
.4969 .66053 Mdot
.66883 .65736 Mdot
.38169 .61608 Mdot
.61268 .50913 Mdot
.37543 .6102 Mdot
.5324 .67956 Mdot
.43628 .64064 Mdot
.43625 .31825 Mdot
.41153 .66249 Mdot
.61217 .44845 Mdot
.45963 .34022 Mdot
.36606 .46334 Mdot
.67492 .22979 Mdot
.45695 .77701 Mdot
.4107 .60647 Mdot
.43782 .61341 Mdot
.68443 .48268 Mdot
.37704 .36164 Mdot
.65055 .43083 Mdot
.58555 .45291 Mdot
.36918 .47822 Mdot
.46969 .30761 Mdot
.31293 .46293 Mdot
.65942 .5453 Mdot
.7197 .66843 Mdot
.34197 .44512 Mdot
.33233 .70674 Mdot
.54964 .66167 Mdot
.47597 .45303 Mdot
.6191 .48514 Mdot
.36854 .43887 Mdot
.61178 .46069 Mdot
.4437 .30583 Mdot
.48867 .49432 Mdot
.3219 .65975 Mdot
.33561 .48172 Mdot
.36798 .76445 Mdot
.67876 .69042 Mdot
.70576 .49245 Mdot
.32303 .45495 Mdot
.71698 .59506 Mdot
.41634 .59644 Mdot
.55289 .69445 Mdot
.56763 .70118 Mdot
.56727 .69342 Mdot
.63081 .41863 Mdot
.53696 .44436 Mdot
.5733 .64052 Mdot
.36952 .48723 Mdot
.53734 .69656 Mdot
.22283 .3774 Mdot
.49443 .83622 Mdot
.54505 .66801 Mdot
.64479 .47408 Mdot
.5743 .41568 Mdot
.62195 .59721 Mdot
.26233 .61099 Mdot
.73149 .71449 Mdot
.22038 .51355 Mdot
.64602 .50689 Mdot
.46245 .27848 Mdot
.45613 .28784 Mdot
.53288 .18348 Mdot
.77559 .48707 Mdot
.79241 .37588 Mdot
.49682 .35104 Mdot
.31948 .5818 Mdot
.48298 .31171 Mdot
.6354 .52548 Mdot
.58113 .4674 Mdot
.49883 .34796 Mdot
.73044 .64653 Mdot
.30762 .59126 Mdot
.40803 .81423 Mdot
.456 .36309 Mdot
.34022 .44216 Mdot
.33179 .43956 Mdot
.34983 .48379 Mdot
.66846 .24223 Mdot
.45916 .30776 Mdot
.59528 .47135 Mdot
.42012 .63705 Mdot
.63179 .43814 Mdot
.34585 .456 Mdot
.50414 .84267 Mdot
.46729 .31825 Mdot
.6546 .46795 Mdot
.71877 .45832 Mdot
.38709 .6236 Mdot
.55597 .66608 Mdot
.39661 .32935 Mdot
.79047 .38339 Mdot
.33645 .4892 Mdot
.49073 .3623 Mdot
.28071 .45405 Mdot
.42531 .80673 Mdot
.60801 .41226 Mdot
.55462 .49068 Mdot
.41462 .83398 Mdot
.80612 .45905 Mdot
.66376 .4548 Mdot
.43815 .63072 Mdot
.2865 .55728 Mdot
.58506 .49179 Mdot
.45322 .29045 Mdot
.57309 .6989 Mdot
.55724 .69966 Mdot
.70204 .49203 Mdot
.40941 .39978 Mdot
.50348 .52768 Mdot
.60247 .48474 Mdot
.6808 .51427 Mdot
.37887 .62832 Mdot
.28706 .52659 Mdot
.77535 .32258 Mdot
.57337 .65513 Mdot
.6511 .5172 Mdot
.52573 .81229 Mdot
.44599 .36414 Mdot
.4368 .65393 Mdot
.38197 .45286 Mdot
.50431 .3031 Mdot
.43577 .64567 Mdot
.59289 .51704 Mdot
.65385 .51863 Mdot
.32329 .44626 Mdot
.42954 .32819 Mdot
.5435 .65579 Mdot
.43144 .6315 Mdot
.56158 .64926 Mdot
.46861 .31048 Mdot
.47931 .33495 Mdot
.71684 .46469 Mdot
.58261 .4216 Mdot
.41612 .60404 Mdot
.63694 .42482 Mdot
.34664 .65824 Mdot
.26879 .74878 Mdot
.30032 .49314 Mdot
.67035 .48817 Mdot
.45576 .37916 Mdot
.33356 .48457 Mdot
.59067 .45943 Mdot
.45724 .85696 Mdot
.57674 .47886 Mdot
.29371 .47672 Mdot
.79799 .52004 Mdot
.55549 .6514 Mdot
.64824 .57138 Mdot
.24859 .65092 Mdot
.66615 .47954 Mdot
.40602 .64152 Mdot
.64509 .41148 Mdot
.36251 .44476 Mdot
.48476 .33291 Mdot
.25959 .74849 Mdot
.34111 .46727 Mdot
.66101 .48073 Mdot
.57132 .67345 Mdot
.45363 .37526 Mdot
.54645 .5719 Mdot
.53687 .58346 Mdot
.65039 .40362 Mdot
.66958 .45368 Mdot
.59772 .4985 Mdot
.68608 .70401 Mdot
.42812 .64209 Mdot
.45077 .35106 Mdot
.32496 .46909 Mdot
.36432 .45607 Mdot
.38964 .60816 Mdot
.37872 .54357 Mdot
.47506 .45362 Mdot
.47031 .14045 Mdot
.38308 .60072 Mdot
.57807 .66274 Mdot
.37431 .34582 Mdot
.42669 .63772 Mdot
.41341 .62002 Mdot
.38002 .61186 Mdot
.47327 .57253 Mdot
.48563 .35074 Mdot
.591 .51554 Mdot
.43796 .30084 Mdot
.61149 .51056 Mdot
.29473 .47211 Mdot
.33982 .48046 Mdot
.47151 .31911 Mdot
.36989 .79556 Mdot
.62501 .36041 Mdot
.63822 .4837 Mdot
.26533 .7077 Mdot
.64046 .53536 Mdot
.63336 .60235 Mdot
.66271 .52118 Mdot
.40145 .60736 Mdot
.58158 .44321 Mdot
.65333 .42348 Mdot
.56548 .18659 Mdot
.36231 .46899 Mdot
.35899 .62395 Mdot
.6491 .54006 Mdot
.68543 .50678 Mdot
.47049 .28305 Mdot
.44812 .35856 Mdot
.56692 .70016 Mdot
.72271 .54149 Mdot
.36903 .46321 Mdot
.21805 .34607 Mdot
.65207 .50347 Mdot
.53285 .61955 Mdot
.73433 .34894 Mdot
.59297 .45692 Mdot
.2655 .67971 Mdot
.63957 .32511 Mdot
.61789 .48194 Mdot
.43119 .50356 Mdot
.36401 .47388 Mdot
.75134 .64051 Mdot
.58042 .49267 Mdot
.38561 .63016 Mdot
.48456 .32138 Mdot
.43835 .35637 Mdot
.57572 .6874 Mdot
.35595 .21756 Mdot
.3121 .46255 Mdot
.47973 .32591 Mdot
.62178 .49266 Mdot
.32699 .46313 Mdot
.3882 .59784 Mdot
.68076 .47933 Mdot
.77996 .45904 Mdot
.47742 .34622 Mdot
.67378 .50885 Mdot
.35445 .30682 Mdot
.63777 .65072 Mdot
.80785 .54422 Mdot
.3232 .47338 Mdot
.55035 .64704 Mdot
.68034 .43341 Mdot
.51889 .29512 Mdot
.69113 .4751 Mdot
.68517 .66021 Mdot
.21637 .39087 Mdot
.53678 .65021 Mdot
.64619 .48576 Mdot
.59446 .46658 Mdot
.51209 .41978 Mdot
.57498 .66177 Mdot
.65191 .45377 Mdot
.51663 .33253 Mdot
.46824 .35981 Mdot
.4134 .59069 Mdot
.48185 .34972 Mdot
.64081 .47499 Mdot
.58873 .41727 Mdot
.44375 .35739 Mdot
.28246 .74578 Mdot
.55334 .71507 Mdot
.32274 .45823 Mdot
.61056 .53572 Mdot
.57004 .47686 Mdot
.70878 .2147 Mdot
.42961 .66028 Mdot
.32943 .64611 Mdot
.4187 .70636 Mdot
.55335 .7885 Mdot
.49525 .6656 Mdot
.80431 .61535 Mdot
.80716 .4653 Mdot
.67399 .48249 Mdot
.55427 .55815 Mdot
.32647 .29203 Mdot
.36818 .47488 Mdot
.29971 .26696 Mdot
.65187 .50495 Mdot
.63029 .49832 Mdot
.44774 .63361 Mdot
.30897 .65549 Mdot
.7924 .37151 Mdot
.43285 .3986 Mdot
.54636 .65547 Mdot
.45711 .29395 Mdot
.59377 .51968 Mdot
.44979 .5162 Mdot
.39987 .66671 Mdot
.50571 .65267 Mdot
.65457 .47199 Mdot
.47118 .22048 Mdot
.27822 .39666 Mdot
.34041 .45324 Mdot
.41493 .64014 Mdot
.79506 .3999 Mdot
.66842 .4866 Mdot
.37848 .44281 Mdot
.63331 .46934 Mdot
.48357 .62962 Mdot
.64915 .54914 Mdot
.53858 .6743 Mdot
.59322 .50754 Mdot
.49731 .67995 Mdot
.82079 .32962 Mdot
.57123 .63399 Mdot
.4892 .2872 Mdot
.40924 .67164 Mdot
.39715 .60048 Mdot
.44518 .3546 Mdot
.40422 .60129 Mdot
.62604 .28782 Mdot
.74021 .41818 Mdot
.54927 .65944 Mdot
.69947 .48577 Mdot
.54955 .67002 Mdot
.44164 .65069 Mdot
.64722 .50795 Mdot
.33239 .80326 Mdot
.42569 .61002 Mdot
.81617 .44996 Mdot
.34908 .46406 Mdot
.40398 .66795 Mdot
.57926 .48762 Mdot
.27235 .45271 Mdot
.36833 .61126 Mdot
.31442 .6237 Mdot
.63312 .45359 Mdot
.48207 .34158 Mdot
.58656 .48659 Mdot
.59846 .53253 Mdot
.37418 .65437 Mdot
.61966 .51761 Mdot
.34524 .44293 Mdot
.49714 .34347 Mdot
.69365 .76066 Mdot
.2332 .41198 Mdot
.65643 .45546 Mdot
.62413 .49108 Mdot
.42278 .33912 Mdot
.57513 .45862 Mdot
.32576 .4905 Mdot
.10117 .48178 Mdot
.55016 .66189 Mdot
.35812 .64256 Mdot
.49308 .67989 Mdot
.56935 .50352 Mdot
.61885 .52299 Mdot
.49196 .86736 Mdot
.71246 .67062 Mdot
.3296 .44942 Mdot
.66709 .43336 Mdot
.38033 .59993 Mdot
.56535 .68291 Mdot
.35573 .49379 Mdot
.61092 .47943 Mdot
.64328 .49289 Mdot
.55867 .64499 Mdot
.5821 .60756 Mdot
.71533 .28006 Mdot
.35362 .43573 Mdot
.54875 .5028 Mdot
.46441 .61799 Mdot
.64022 .43447 Mdot
.63727 .22731 Mdot
.44422 .34178 Mdot
.34091 .48953 Mdot
.57942 .76883 Mdot
.67016 .48481 Mdot
.32405 .44959 Mdot
.36862 .46439 Mdot
.68435 .46397 Mdot
.47809 .38165 Mdot
.49649 .33356 Mdot
.46707 .36267 Mdot
.25321 .25582 Mdot
.67556 .63799 Mdot
.39922 .65074 Mdot
.36633 .47297 Mdot
.43793 .61036 Mdot
.58091 .63405 Mdot
.4953 .5615 Mdot
.43982 .61572 Mdot
.47785 .36017 Mdot
.37649 .66201 Mdot
.60863 .4565 Mdot
.36756 .46197 Mdot
.40383 .64656 Mdot
.59015 .52782 Mdot
.39342 .38929 Mdot
.23401 .57683 Mdot
.52586 .66816 Mdot
.57881 .69095 Mdot
.58089 .47502 Mdot
.42699 .58983 Mdot
.64799 .49627 Mdot
.38555 .45735 Mdot
.38741 .37194 Mdot
.60534 .53322 Mdot
.40717 .60491 Mdot
.42713 .3505 Mdot
.79201 .39393 Mdot
.59816 .42556 Mdot
.64499 .47567 Mdot
.61603 .5138 Mdot
.63302 .46883 Mdot
.42378 .79987 Mdot
.31998 .4437 Mdot
.21513 .44257 Mdot
.58571 .74762 Mdot
.46287 .31845 Mdot
.43438 .30074 Mdot
.76901 .32538 Mdot
.31982 .30391 Mdot
.36268 .47248 Mdot
.60471 .49628 Mdot
.28369 .36651 Mdot
.57477 .84234 Mdot
.3907 .82171 Mdot
.53673 .41087 Mdot
.4282 .6622 Mdot
.49113 .36098 Mdot
.41734 .59894 Mdot
.61844 .50952 Mdot
.68556 .50265 Mdot
.82538 .57649 Mdot
.37699 .47831 Mdot
.54367 .66089 Mdot
.60982 .51169 Mdot
.67196 .64283 Mdot
.41168 .63279 Mdot
.4015 .66821 Mdot
.5988 .44557 Mdot
.43029 .3499 Mdot
.80605 .32128 Mdot
.3326 .45902 Mdot
.22775 .48547 Mdot
.25882 .32652 Mdot
.29429 .40211 Mdot
.34216 .45623 Mdot
.51531 .4393 Mdot
.43991 .64862 Mdot
.72093 .32461 Mdot
.4576 .3158 Mdot
.55143 .69611 Mdot
.60638 .5441 Mdot
.43875 .34072 Mdot
.39689 .65699 Mdot
.48391 .33676 Mdot
.61867 .5242 Mdot
.36196 .42795 Mdot
.40184 .63139 Mdot
.30396 .51589 Mdot
.45328 .37854 Mdot
.57434 .66444 Mdot
.43357 .4211 Mdot
.58493 .3837 Mdot
.63774 .32185 Mdot
.60538 .44211 Mdot
.45095 .52467 Mdot
.59753 .47086 Mdot
.42668 .30253 Mdot
.62744 .47953 Mdot
.41735 .34315 Mdot
.40534 .64057 Mdot
.58108 .50212 Mdot
.60142 .4884 Mdot
.1793 .4406 Mdot
.64782 .45524 Mdot
.65013 .43328 Mdot
.61455 .48418 Mdot
.43494 .26927 Mdot
.70077 .47573 Mdot
.47849 .29684 Mdot
.37391 .7185 Mdot
.41069 .61763 Mdot
.55483 .70254 Mdot
.55098 .64451 Mdot
.70625 .63081 Mdot
.52398 .7392 Mdot
.2965 .65741 Mdot
.47214 .35436 Mdot
.36505 .44194 Mdot
.62886 .47473 Mdot
.77088 .664 Mdot
.46969 .65876 Mdot
.39611 .66432 Mdot
.2342 .41307 Mdot
.57199 .5416 Mdot
.7685 .62408 Mdot
.66907 .43739 Mdot
.29867 .23333 Mdot
.56283 .44811 Mdot
.59662 .54707 Mdot
.39231 .59187 Mdot
.54112 .62555 Mdot
.57507 .4633 Mdot
.4796 .28888 Mdot
.54536 .68836 Mdot
.5354 .46866 Mdot
.38507 .56424 Mdot
.35436 .69392 Mdot
.40799 .32681 Mdot
.62106 .45816 Mdot
.40122 .6303 Mdot
.47278 .30074 Mdot
.78171 .33686 Mdot
.33385 .45367 Mdot
.38486 .54189 Mdot
.37331 .28241 Mdot
.28905 .74366 Mdot
.57151 .6835 Mdot
.67117 .27419 Mdot
.61006 .45043 Mdot
.40275 .76075 Mdot
.61149 .53489 Mdot
.51873 .84694 Mdot
.57209 .64355 Mdot
.48101 .35999 Mdot
.34631 .44026 Mdot
.45122 .29186 Mdot
.62269 .31669 Mdot
.39295 .57106 Mdot
.46711 .49146 Mdot
.42037 .62732 Mdot
.51508 .54605 Mdot
.45451 .34411 Mdot
.644 .51897 Mdot
.46487 .13971 Mdot
.44518 .34772 Mdot
.45949 .37686 Mdot
.18224 .55572 Mdot
.30004 .77817 Mdot
.55322 .47658 Mdot
.4735 .37129 Mdot
.4206 .622 Mdot
.54842 .68358 Mdot
.58635 .49973 Mdot
.61986 .45479 Mdot
.43908 .33669 Mdot
.36628 .64555 Mdot
.56005 .32696 Mdot
.38977 .61345 Mdot
.48385 .35302 Mdot
.39869 .61735 Mdot
.29056 .44122 Mdot
.43273 .63572 Mdot
.56977 .47616 Mdot
.62773 .47824 Mdot
.47952 .70487 Mdot
.47953 .33598 Mdot
.60265 .48305 Mdot
.68391 .48423 Mdot
.46447 .33594 Mdot
.51686 .50208 Mdot
.56787 .32547 Mdot
.65381 .44682 Mdot
.63983 .45239 Mdot
.54284 .64861 Mdot
.47704 .54561 Mdot
.65359 .25368 Mdot
.61208 .52135 Mdot
.54441 .64303 Mdot
.48433 .29509 Mdot
.65535 .48692 Mdot
.57937 .81909 Mdot
.28925 .56129 Mdot
.65375 .50827 Mdot
.41728 .59702 Mdot
.65849 .42683 Mdot
.80983 .52844 Mdot
.58391 .45418 Mdot
.46367 .3445 Mdot
.477 .31626 Mdot
.20419 .37179 Mdot
.45239 .33127 Mdot
.36855 .63246 Mdot
.34576 .45724 Mdot
.41876 .80826 Mdot
.39644 .59638 Mdot
.58205 .42878 Mdot
.15132 .46141 Mdot
.67366 .49987 Mdot
.57335 .50326 Mdot
.82598 .42182 Mdot
.42162 .60308 Mdot
.45369 .30241 Mdot
.45588 .42174 Mdot
.56774 .43164 Mdot
.34326 .48805 Mdot
.6473 .54467 Mdot
.59191 .44549 Mdot
.80851 .49799 Mdot
.43213 .79762 Mdot
.38253 .44439 Mdot
.64777 .4331 Mdot
.61455 .52221 Mdot
.45567 .63836 Mdot
.62136 .48827 Mdot
.54498 .68055 Mdot
.46133 .30685 Mdot
.43597 .62978 Mdot
.56435 .66826 Mdot
.66502 .49076 Mdot
.5449 .6535 Mdot
.39293 .64212 Mdot
.38246 .46003 Mdot
.63026 .51089 Mdot
.52241 .6786 Mdot
.54656 .65392 Mdot
.59934 .47245 Mdot
.48649 .33198 Mdot
.56365 .5392 Mdot
.6509 .45727 Mdot
.59628 .51529 Mdot
.44165 .32291 Mdot
.67133 .82464 Mdot
.58143 .46463 Mdot
.69142 .66391 Mdot
.43567 .34213 Mdot
.5157 .53395 Mdot
.40279 .59304 Mdot
.58419 .44915 Mdot
.38278 .46033 Mdot
.38029 .45385 Mdot
.41369 .66001 Mdot
.48622 .36934 Mdot
.43339 .69977 Mdot
.49416 .37536 Mdot
.64954 .41614 Mdot
.63716 .43063 Mdot
.52748 .34941 Mdot
.75682 .69494 Mdot
.44027 .30351 Mdot
.40667 .56184 Mdot
.41347 .39451 Mdot
.37167 .44133 Mdot
.37798 .65473 Mdot
.4984 .35093 Mdot
.44215 .31336 Mdot
.4905 .33212 Mdot
.54904 .69651 Mdot
.48303 .70791 Mdot
.43101 .33647 Mdot
.42649 .33754 Mdot
.62683 .45179 Mdot
.60839 .51915 Mdot
.79265 .42879 Mdot
.77117 .41506 Mdot
.53192 .66112 Mdot
.38671 .64805 Mdot
.23429 .26086 Mdot
.3813 .46787 Mdot
.19594 .45091 Mdot
.57901 .50853 Mdot
.28999 .19472 Mdot
.58195 .49296 Mdot
.61909 .49295 Mdot
.49775 .34148 Mdot
.52337 .67744 Mdot
.55001 .66652 Mdot
.44922 .3498 Mdot
.42545 .31718 Mdot
.5443 .67871 Mdot
.23971 .65068 Mdot
.59758 .821 Mdot
.35725 .67295 Mdot
.4681 .33203 Mdot
.6842 .3923 Mdot
.34009 .43832 Mdot
.55886 .42416 Mdot
.38279 .43564 Mdot
.41339 .62708 Mdot
.4396 .64271 Mdot
.33619 .48723 Mdot
.635 .45545 Mdot
.40729 .65079 Mdot
.67135 .49222 Mdot
.21222 .53809 Mdot
.63301 .34318 Mdot
.47074 .67793 Mdot
.6225 .39768 Mdot
.5141 .48948 Mdot
.30628 .51859 Mdot
.66075 .49056 Mdot
.56708 .80002 Mdot
.54621 .658 Mdot
.65269 .41321 Mdot
.34748 .48947 Mdot
.83463 .4437 Mdot
.63875 .51107 Mdot
.46693 .34497 Mdot
.36914 .46706 Mdot
.38937 .2526 Mdot
.37215 .32678 Mdot
.61346 .51246 Mdot
.39582 .16773 Mdot
.4541 .26352 Mdot
.42296 .64022 Mdot
.4533 .22626 Mdot
.43153 .31352 Mdot
.51504 .69989 Mdot
.6009 .75704 Mdot
.34069 .77996 Mdot
.46098 .30006 Mdot
.44422 .65183 Mdot
.48685 .30561 Mdot
.57339 .67233 Mdot
.48408 .28489 Mdot
.40762 .63631 Mdot
.65291 .47526 Mdot
.39528 .60572 Mdot
.5424 .69437 Mdot
.72091 .29036 Mdot
.38206 .44405 Mdot
.36213 .61541 Mdot
.33421 .47699 Mdot
.62331 .66103 Mdot
.66611 .71569 Mdot
.32081 .46365 Mdot
.55384 .27031 Mdot
.62911 .43085 Mdot
.42961 .32295 Mdot
.38707 .60595 Mdot
.522 .77565 Mdot
.43197 .41617 Mdot
.45451 .31824 Mdot
.39824 .65469 Mdot
.38334 .3217 Mdot
.50263 .25368 Mdot
.64919 .43146 Mdot
.60319 .59851 Mdot
.46517 .33066 Mdot
.44704 .64298 Mdot
.72082 .26202 Mdot
.48486 .30109 Mdot
.37925 .6032 Mdot
.3361 .44295 Mdot
.36158 .45337 Mdot
.63443 .44034 Mdot
.3194 .43773 Mdot
.41866 .65419 Mdot
.37436 .51515 Mdot
.47608 .37133 Mdot
.40924 .24186 Mdot
.52783 .69233 Mdot
.40479 .6125 Mdot
.66557 .51293 Mdot
.43166 .28779 Mdot
.27017 .52278 Mdot
.56974 .34277 Mdot
.48748 .16671 Mdot
.38987 .60823 Mdot
.45527 .30837 Mdot
.47001 .34496 Mdot
.60051 .4236 Mdot
.39057 .31012 Mdot
.43321 .70373 Mdot
.52138 .40492 Mdot
.50607 .40694 Mdot
.41195 .58973 Mdot
.34739 .61124 Mdot
.65039 .54044 Mdot
.62544 .46142 Mdot
.36762 .43987 Mdot
.65104 .47254 Mdot
.4894 .35768 Mdot
.60494 .44289 Mdot
.32632 .46836 Mdot
.42422 .62914 Mdot
.6353 .50971 Mdot
.5505 .65093 Mdot
.31415 .45158 Mdot
.37678 .48518 Mdot
.40845 .60918 Mdot
.43843 .33588 Mdot
.52931 .55224 Mdot
.38472 .61925 Mdot
.62234 .45794 Mdot
.47659 .55993 Mdot
.61934 .52568 Mdot
.60835 .57207 Mdot
.47869 .2931 Mdot
.43576 .62791 Mdot
.5005 .33634 Mdot
.33953 .47239 Mdot
.58673 .74884 Mdot
.63639 .47772 Mdot
.38406 .60011 Mdot
.31904 .54 Mdot
.59524 .57684 Mdot
.43996 .37389 Mdot
.25294 .63443 Mdot
.4336 .2983 Mdot
.38195 .64383 Mdot
.1708 .47633 Mdot
.56158 .69399 Mdot
.39853 .66525 Mdot
.71915 .73624 Mdot
.4214 .60875 Mdot
.62418 .44118 Mdot
.58238 .47134 Mdot
.43331 .63403 Mdot
.55103 .64603 Mdot
.80009 .36809 Mdot
.35814 .65792 Mdot
.457 .30213 Mdot
.20596 .57184 Mdot
.57815 .16999 Mdot
.31492 .51293 Mdot
.3675 .44092 Mdot
.55193 .46362 Mdot
.60483 .43446 Mdot
.35731 .48805 Mdot
.38977 .44924 Mdot
.56645 .69814 Mdot
.37591 .61257 Mdot
.43124 .28405 Mdot
.3576 .50026 Mdot
.40093 .31529 Mdot
.51219 .73028 Mdot
.59903 .42602 Mdot
.25126 .34118 Mdot
.58266 .51124 Mdot
.63633 .71913 Mdot
.32472 .47069 Mdot
.63647 .52752 Mdot
.65324 .42918 Mdot
.37215 .47544 Mdot
.54791 .68491 Mdot
.38215 .54587 Mdot
.39876 .62135 Mdot
.68348 .80601 Mdot
.67718 .4772 Mdot
.60864 .44414 Mdot
.35627 .47983 Mdot
.42253 .7431 Mdot
.46417 .31528 Mdot
.44496 .28972 Mdot
.42827 .64165 Mdot
.42044 .42784 Mdot
.62338 .43563 Mdot
.65917 .4829 Mdot
.39611 .62793 Mdot
.36665 .63545 Mdot
.28104 .63398 Mdot
.59396 .46325 Mdot
.35763 .46972 Mdot
.57574 .62294 Mdot
.32408 .47552 Mdot
.62735 .52599 Mdot
.60454 .44687 Mdot
.56933 .47602 Mdot
.65758 .51763 Mdot
.387 .43503 Mdot
.61329 .52956 Mdot
.69566 .48205 Mdot
.45456 .31144 Mdot
.6074 .51412 Mdot
.49771 .40867 Mdot
.64631 .46747 Mdot
.54687 .68167 Mdot
.61485 .23407 Mdot
.6378 .51108 Mdot
.59918 .44342 Mdot
.3625 .65127 Mdot
.64053 .4882 Mdot
.38528 .46017 Mdot
.47443 .33055 Mdot
.36197 .47493 Mdot
.38087 .4531 Mdot
.44438 .61432 Mdot
.57897 .65735 Mdot
.56933 .50565 Mdot
.53416 .68092 Mdot
.59288 .42034 Mdot
.67053 .48388 Mdot
.54909 .7395 Mdot
.28045 .24498 Mdot
.68112 .25092 Mdot
.63691 .47563 Mdot
.4243 .60645 Mdot
.41886 .59927 Mdot
.54085 .54272 Mdot
.65937 .44006 Mdot
.33528 .49602 Mdot
.3764 .4443 Mdot
.7751 .47963 Mdot
.76605 .58118 Mdot
.5469 .6824 Mdot
.47209 .52988 Mdot
.66681 .45609 Mdot
.64125 .52492 Mdot
.67922 .48335 Mdot
.4417 .62002 Mdot
.56849 .39888 Mdot
.38596 .65998 Mdot
.25897 .41288 Mdot
.33957 .48431 Mdot
.62515 .51345 Mdot
.23684 .37727 Mdot
.45678 .36527 Mdot
.47504 .33163 Mdot
.36884 .49157 Mdot
.44842 .59834 Mdot
.78384 .38735 Mdot
.39254 .82831 Mdot
.48356 .27747 Mdot
.53054 .68777 Mdot
.66363 .48098 Mdot
.42624 .62181 Mdot
.48607 .35248 Mdot
.53099 .68752 Mdot
.64154 .51718 Mdot
.48476 .70858 Mdot
.63749 .4687 Mdot
.30112 .3083 Mdot
.4849 .31621 Mdot
.54635 .8474 Mdot
.48377 .37269 Mdot
.30807 .45745 Mdot
.3344 .49105 Mdot
.592 .45907 Mdot
.50542 .28061 Mdot
.43196 .30767 Mdot
.44758 .5682 Mdot
.578 .6642 Mdot
.27185 .47269 Mdot
.56464 .68702 Mdot
.41546 .64196 Mdot
.55242 .69289 Mdot
.40576 .63777 Mdot
.7722 .37524 Mdot
.42922 .26998 Mdot
.559 .66272 Mdot
.31454 .53314 Mdot
.59828 .43658 Mdot
.53079 .66045 Mdot
.68618 .49964 Mdot
.58448 .56602 Mdot
.39377 .62621 Mdot
.57654 .66669 Mdot
.6494 .51806 Mdot
.79937 .60667 Mdot
.32411 .45496 Mdot
.33515 .49484 Mdot
.68622 .4984 Mdot
.4228 .59228 Mdot
.49225 .30568 Mdot
.49281 .82934 Mdot
.32361 .50062 Mdot
.5847 .46273 Mdot
.57504 .46124 Mdot
.43093 .30573 Mdot
.20805 .39916 Mdot
.59972 .45293 Mdot
.70373 .51425 Mdot
.59155 .46373 Mdot
.31358 .47213 Mdot
.45323 .29238 Mdot
.47312 .33997 Mdot
.40002 .65425 Mdot
.45462 .36835 Mdot
.57798 .5957 Mdot
.25156 .38295 Mdot
.62837 .55656 Mdot
.33771 .46863 Mdot
.27389 .39265 Mdot
.25334 .41656 Mdot
.72499 .71827 Mdot
.45356 .37977 Mdot
.60557 .53225 Mdot
.44906 .36776 Mdot
.56184 .68577 Mdot
.48052 .34361 Mdot
.4914 .3605 Mdot
.6506 .49745 Mdot
.6124 .50883 Mdot
.42437 .6344 Mdot
.38994 .3297 Mdot
.43644 .33751 Mdot
.58279 .49316 Mdot
.576 .44969 Mdot
.67004 .50005 Mdot
.47227 .58072 Mdot
.44551 .29786 Mdot
.20019 .62516 Mdot
.7212 .57324 Mdot
.43668 .33654 Mdot
.81671 .34595 Mdot
.30333 .53654 Mdot
.38582 .57406 Mdot
.40458 .54595 Mdot
.58986 .46745 Mdot
.36676 .61029 Mdot
.61939 .50966 Mdot
.25223 .34155 Mdot
.6383 .49504 Mdot
.5439 .68103 Mdot
.67407 .48264 Mdot
.43295 .65212 Mdot
.38899 .61254 Mdot
.58751 .4562 Mdot
.63253 .50856 Mdot
.74286 .30975 Mdot
.4987 .29815 Mdot
.47823 .32794 Mdot
.42791 .69732 Mdot
.56303 .65906 Mdot
.34103 .48896 Mdot
.62006 .48248 Mdot
.4437 .61553 Mdot
.39042 .61037 Mdot
.43602 .30572 Mdot
.38468 .63739 Mdot
.33437 .45805 Mdot
.63301 .48043 Mdot
.35093 .49129 Mdot
.55468 .69872 Mdot
.45111 .29426 Mdot
.60977 .51355 Mdot
.62738 .4517 Mdot
.47681 .31587 Mdot
.59831 .5351 Mdot
.55071 .64746 Mdot
.41587 .60512 Mdot
.46294 .29888 Mdot
.3508 .45564 Mdot
.41297 .64134 Mdot
.59742 .51845 Mdot
.35563 .19555 Mdot
.63138 .4434 Mdot
.58731 .47878 Mdot
.75184 .71571 Mdot
.67039 .46108 Mdot
.38776 .60764 Mdot
.48443 .35646 Mdot
.68401 .42325 Mdot
.69987 .61655 Mdot
.60733 .87166 Mdot
.39088 .66198 Mdot
.66251 .47399 Mdot
.75349 .67649 Mdot
.6592 .47105 Mdot
.57312 .37154 Mdot
.36154 .60668 Mdot
.49789 .47014 Mdot
.65244 .52608 Mdot
.35685 .4467 Mdot
.4298 .63128 Mdot
.4015 .63925 Mdot
.20167 .53979 Mdot
.65495 .49334 Mdot
.43842 .53308 Mdot
.63215 .52134 Mdot
.35178 .45324 Mdot
.76233 .5221 Mdot
.38744 .61214 Mdot
.5293 .17879 Mdot
.59737 .46891 Mdot
.44027 .31224 Mdot
.3829 .66579 Mdot
.2929 .43026 Mdot
.59291 .51211 Mdot
.53387 .6673 Mdot
.39156 .47329 Mdot
.65393 .54537 Mdot
.33659 .46585 Mdot
.59938 .51716 Mdot
.69428 .41917 Mdot
.40485 .21739 Mdot
.48866 .3329 Mdot
.34893 .43955 Mdot
.48897 .57327 Mdot
.61349 .53171 Mdot
.46262 .30006 Mdot
.45613 .31589 Mdot
.55031 .69834 Mdot
.49132 .5163 Mdot
.3573 .29916 Mdot
.6574 .36764 Mdot
.20322 .55596 Mdot
.37362 .65849 Mdot
.32142 .64812 Mdot
.59201 .48648 Mdot
.55402 .60336 Mdot
.38481 .45617 Mdot
.63523 .44367 Mdot
.66716 .27742 Mdot
.45212 .35938 Mdot
.62987 .44618 Mdot
.54843 .67099 Mdot
.50004 .63615 Mdot
.57435 .619 Mdot
.63928 .75376 Mdot
.41872 .62719 Mdot
.69551 .47449 Mdot
.70493 .44018 Mdot
.405 .59186 Mdot
.56638 .46348 Mdot
.3894 .60023 Mdot
.2599 .6915 Mdot
.52668 .66766 Mdot
.44719 .29989 Mdot
.28184 .49591 Mdot
.56375 .4874 Mdot
.60794 .43628 Mdot
.58104 .66841 Mdot
.62073 .46308 Mdot
.37387 .21256 Mdot
.47626 .58659 Mdot
.40897 .64736 Mdot
.4901 .33266 Mdot
.5698 .46222 Mdot
.50007 .56305 Mdot
.6544 .46402 Mdot
.72237 .37256 Mdot
.59624 .44462 Mdot
.37339 .31147 Mdot
.48523 .32299 Mdot
.33253 .47066 Mdot
.62975 .53176 Mdot
.63068 .49533 Mdot
.73349 .62446 Mdot
.56987 .43746 Mdot
.62808 .53033 Mdot
.45608 .39021 Mdot
.49221 .34436 Mdot
.48444 .30341 Mdot
.40544 .6616 Mdot
.78557 .54345 Mdot
.35027 .47047 Mdot
.65606 .40787 Mdot
.32929 .49977 Mdot
.54369 .33832 Mdot
.52808 .68187 Mdot
.69625 .71731 Mdot
.60732 .48677 Mdot
.47252 .35708 Mdot
.49708 .80987 Mdot
.4635 .28334 Mdot
.45899 .51635 Mdot
.36886 .46301 Mdot
.44679 .34764 Mdot
.62285 .49501 Mdot
.42148 .40422 Mdot
.76875 .65557 Mdot
.34731 .47616 Mdot
.58196 .42986 Mdot
.41903 .66291 Mdot
.48722 .67071 Mdot
.44665 .19369 Mdot
.32153 .45713 Mdot
.29278 .48468 Mdot
.65713 .49204 Mdot
.46255 .36747 Mdot
.35268 .44867 Mdot
.31526 .47395 Mdot
.38626 .64085 Mdot
.60888 .50803 Mdot
.60466 .50557 Mdot
.38328 .64726 Mdot
.36004 .47645 Mdot
.69235 .47541 Mdot
.65378 .54784 Mdot
.84016 .52829 Mdot
.38422 .28646 Mdot
.69025 .80637 Mdot
.54576 .55488 Mdot
.62079 .2544 Mdot
.49312 .83321 Mdot
.43588 .3269 Mdot
.66081 .50087 Mdot
.59235 .54359 Mdot
.41843 .65461 Mdot
.64465 .48046 Mdot
.38149 .58434 Mdot
.37616 .46021 Mdot
.83165 .44394 Mdot
.31796 .36709 Mdot
.30052 .73982 Mdot
.64565 .4824 Mdot
.42779 .36784 Mdot
.56137 .68047 Mdot
.29831 .49766 Mdot
.46485 .29012 Mdot
.6719 .50651 Mdot
.73869 .30554 Mdot
.39449 .66429 Mdot
.44599 .32698 Mdot
.78228 .34134 Mdot
.51234 .45382 Mdot
.6208 .52531 Mdot
.38972 .65801 Mdot
.54215 .81427 Mdot
.44076 .24762 Mdot
.31017 .49042 Mdot
.54747 .68572 Mdot
.43365 .62759 Mdot
.37469 .44154 Mdot
.41828 .30335 Mdot
.44863 .33687 Mdot
.48443 .291 Mdot
.66704 .25001 Mdot
.35682 .62888 Mdot
.56227 .67672 Mdot
.76 .62002 Mdot
.75332 .60036 Mdot
.5427 .67647 Mdot
.43948 .6437 Mdot
.49059 .3473 Mdot
.45306 .35462 Mdot
.47389 .33026 Mdot
.61394 .20553 Mdot
.44876 .37131 Mdot
.18536 .49235 Mdot
.6658 .50704 Mdot
.66704 .54628 Mdot
.66173 .47609 Mdot
.34219 .49594 Mdot
.47666 .30991 Mdot
.44345 .42495 Mdot
.61928 .41427 Mdot
.70059 .69786 Mdot
.62951 .44029 Mdot
.3358 .43452 Mdot
.62023 .44834 Mdot
.25462 .31196 Mdot
.44373 .362 Mdot
.63985 .4775 Mdot
.36609 .43226 Mdot
.56585 .65745 Mdot
.44026 .37506 Mdot
.61549 .51365 Mdot
.28462 .67447 Mdot
.67343 .46906 Mdot
.3005 .73101 Mdot
.37026 .25216 Mdot
.52978 .68626 Mdot
.29821 .28725 Mdot
.44028 .65973 Mdot
.69251 .52676 Mdot
.57996 .41932 Mdot
.3398 .47665 Mdot
.27687 .48099 Mdot
.41316 .61827 Mdot
.54305 .40836 Mdot
.68989 .51275 Mdot
.54932 .69964 Mdot
.44857 .25289 Mdot
.36355 .48525 Mdot
.56976 .45786 Mdot
.64424 .4265 Mdot
.21915 .47272 Mdot
.68797 .50623 Mdot
.58128 .4532 Mdot
.58389 .66972 Mdot
.1936 .47042 Mdot
.64355 .46357 Mdot
.46565 .52139 Mdot
.48633 .28643 Mdot
.64171 .41334 Mdot
.18416 .47916 Mdot
.58125 .47432 Mdot
.44354 .3354 Mdot
.68195 .54489 Mdot
.346 .29235 Mdot
.57826 .65461 Mdot
.59742 .44378 Mdot
.19775 .38447 Mdot
.60542 .46356 Mdot
.35461 .46729 Mdot
.65602 .43817 Mdot
.40923 .63424 Mdot
.68069 .24528 Mdot
.40756 .65402 Mdot
.64261 .4392 Mdot
.47124 .32933 Mdot
.34919 .48233 Mdot
.56186 .19792 Mdot
.4568 .71359 Mdot
.20342 .44625 Mdot
.40266 .82149 Mdot
.57559 .65681 Mdot
.51617 .65541 Mdot
.37646 .47574 Mdot
.64044 .47546 Mdot
.16931 .52495 Mdot
.55863 .45378 Mdot
.63753 .45098 Mdot
.63767 .49622 Mdot
.65976 .71727 Mdot
.37875 .45513 Mdot
.38999 .62209 Mdot
.60207 .44992 Mdot
.61868 .53044 Mdot
.43742 .32243 Mdot
.55698 .65465 Mdot
.40437 .59334 Mdot
.54842 .66074 Mdot
.42966 .62723 Mdot
.82396 .39396 Mdot
.67866 .44944 Mdot
.56958 .66119 Mdot
.38154 .48583 Mdot
.44012 .32983 Mdot
.25767 .37823 Mdot
.40683 .64194 Mdot
.40757 .65921 Mdot
.58898 .45181 Mdot
.44251 .34072 Mdot
.49898 .3393 Mdot
.56793 .68137 Mdot
.32479 .4613 Mdot
.63894 .51058 Mdot
.67051 .47142 Mdot
.72848 .46359 Mdot
.43437 .59946 Mdot
.2922 .31275 Mdot
.32089 .67007 Mdot
.63847 .4739 Mdot
.47717 .37029 Mdot
.63661 .50479 Mdot
.38315 .7742 Mdot
.45765 .36749 Mdot
.58043 .4806 Mdot
.78445 .30369 Mdot
.41652 .57392 Mdot
.31775 .32519 Mdot
.57353 .46962 Mdot
.48088 .85172 Mdot
.59799 .48621 Mdot
.84042 .44693 Mdot
.48147 .7888 Mdot
.63763 .43327 Mdot
.58872 .50979 Mdot
.60078 .33718 Mdot
.66664 .47491 Mdot
.38801 .65154 Mdot
.80561 .44954 Mdot
.47679 .28561 Mdot
.25441 .44458 Mdot
.62763 .24287 Mdot
.57374 .64676 Mdot
.42838 .64143 Mdot
.35164 .60401 Mdot
.54182 .66842 Mdot
.46751 .33493 Mdot
.6328 .46883 Mdot
.43589 .45968 Mdot
.42707 .59681 Mdot
.52894 .48032 Mdot
.35702 .46582 Mdot
.2738 .56484 Mdot
.51224 .61603 Mdot
.33605 .46266 Mdot
.60412 .51277 Mdot
.58483 .3342 Mdot
.75293 .36407 Mdot
.63519 .80863 Mdot
.3694 .43805 Mdot
.34689 .47778 Mdot
.64757 .22149 Mdot
.54561 .70601 Mdot
.22344 .48163 Mdot
.37368 .31987 Mdot
.34614 .48638 Mdot
.46567 .2533 Mdot
.37349 .6417 Mdot
.35702 .42185 Mdot
.68245 .43253 Mdot
.66774 .49596 Mdot
.62531 .49477 Mdot
.32105 .46909 Mdot
.5797 .57398 Mdot
.4433 .21993 Mdot
.33305 .47842 Mdot
.54357 .47112 Mdot
.48263 .47244 Mdot
.33623 .58639 Mdot
.37923 .62764 Mdot
.57839 .67266 Mdot
.52215 .69036 Mdot
.44592 .30802 Mdot
.57918 .66521 Mdot
.5223 .61943 Mdot
.62041 .46929 Mdot
.32765 .48082 Mdot
.26869 .50284 Mdot
.35864 .45578 Mdot
.545 .66645 Mdot
.55986 .70413 Mdot
.45531 .31157 Mdot
.48067 .33374 Mdot
.60503 .27249 Mdot
.65511 .59293 Mdot
.65003 .45338 Mdot
.54651 .76178 Mdot
.49492 .35548 Mdot
.5269 .49911 Mdot
.57911 .67174 Mdot
.56315 .6571 Mdot
.72363 .64018 Mdot
.6097 .48979 Mdot
.52966 .36455 Mdot
.61396 .48727 Mdot
.7407 .54247 Mdot
.57709 .50206 Mdot
.38569 .64013 Mdot
.60393 .49493 Mdot
.72409 .6492 Mdot
.57408 .51989 Mdot
.60641 .43108 Mdot
.44251 .61799 Mdot
.67517 .53404 Mdot
.40836 .63256 Mdot
.64714 .44433 Mdot
.5196 .66738 Mdot
.4279 .64516 Mdot
.68627 .63215 Mdot
.70542 .65862 Mdot
.44101 .64382 Mdot
.53581 .68734 Mdot
.55446 .64141 Mdot
.6611 .66655 Mdot
.46419 .28991 Mdot
.55286 .44361 Mdot
.64289 .47637 Mdot
.37193 .64783 Mdot
.37483 .44583 Mdot
.58876 .51324 Mdot
.58636 .44419 Mdot
.57403 .48434 Mdot
.44468 .30812 Mdot
.43912 .70314 Mdot
.57236 .66564 Mdot
.38079 .64672 Mdot
.52966 .55669 Mdot
.41536 .58932 Mdot
.63468 .42373 Mdot
.59106 .54179 Mdot
.64777 .2599 Mdot
.33609 .5659 Mdot
.60912 .19742 Mdot
.44857 .33463 Mdot
.41968 .59854 Mdot
.52447 .6877 Mdot
.57912 .5343 Mdot
.47271 .35877 Mdot
.40753 .63577 Mdot
.63704 .46946 Mdot
.5722 .44054 Mdot
.24493 .41202 Mdot
.59171 .61638 Mdot
.69776 .65032 Mdot
.41648 .65976 Mdot
.42786 .66308 Mdot
.6941 .6811 Mdot
.54478 .6293 Mdot
.43418 .41835 Mdot
.65458 .48397 Mdot
.5348 .66676 Mdot
.48389 .35455 Mdot
.68698 .2721 Mdot
.32246 .48561 Mdot
.39072 .31572 Mdot
.64392 .48264 Mdot
.50878 .48782 Mdot
.47024 .32681 Mdot
.54742 .67354 Mdot
.32027 .4722 Mdot
.50879 .67522 Mdot
.43451 .60833 Mdot
.32135 .777 Mdot
.61207 .46149 Mdot
.59269 .44839 Mdot
.33333 .4386 Mdot
.46113 .36279 Mdot
.5742 .6408 Mdot
.21101 .58356 Mdot
.39448 .64058 Mdot
.16621 .50593 Mdot
.47599 .36931 Mdot
.66991 .38778 Mdot
.37431 .63151 Mdot
.35493 .49906 Mdot
.66651 .64959 Mdot
.33087 .46267 Mdot
.63438 .43738 Mdot
.4708 .35153 Mdot
.35437 .44037 Mdot
.39675 .27744 Mdot
.77781 .66209 Mdot
.67083 .38673 Mdot
.62256 .47362 Mdot
.81742 .5655 Mdot
.28277 .69933 Mdot
.48942 .28006 Mdot
.38315 .44975 Mdot
.63477 .4425 Mdot
.60224 .43989 Mdot
.60641 .46165 Mdot
.36952 .44573 Mdot
.55284 .7562 Mdot
.39326 .62913 Mdot
.66075 .48537 Mdot
.56477 .69927 Mdot
.41051 .62665 Mdot
.28657 .46453 Mdot
.38105 .62344 Mdot
.47019 .38438 Mdot
.61828 .4219 Mdot
.28606 .42636 Mdot
.79479 .28055 Mdot
.35464 .47643 Mdot
.44654 .62254 Mdot
.68012 .45741 Mdot
.29355 .55421 Mdot
.49202 .32085 Mdot
.39407 .64252 Mdot
.61137 .44312 Mdot
.30848 .52656 Mdot
.70819 .27696 Mdot
.38292 .61866 Mdot
.47363 .35953 Mdot
.64287 .80165 Mdot
.64913 .47643 Mdot
.602 .47816 Mdot
.44965 .34526 Mdot
.53068 .26854 Mdot
.73813 .28255 Mdot
.6337 .50721 Mdot
.33096 .47146 Mdot
.23711 .71241 Mdot
.58796 .44269 Mdot
.75198 .5457 Mdot
.42747 .63354 Mdot
.35752 .41347 Mdot
.33179 .28823 Mdot
.57031 .5233 Mdot
.21488 .5272 Mdot
.29974 .50889 Mdot
.78972 .59424 Mdot
.38711 .58301 Mdot
.36978 .72502 Mdot
.80498 .54392 Mdot
.36661 .43042 Mdot
.42619 .37995 Mdot
.21458 .55181 Mdot
.51921 .21441 Mdot
.58264 .81224 Mdot
.41465 .75631 Mdot
.73843 .30367 Mdot
.44749 .45592 Mdot
.4279 .61379 Mdot
.5214 .4911 Mdot
.61928 .51144 Mdot
.28891 .70557 Mdot
.40006 .2297 Mdot
.41647 .22537 Mdot
.81824 .56715 Mdot
.5927 .37218 Mdot
.75693 .67071 Mdot
.73333 .7178 Mdot
.74738 .49268 Mdot
.33205 .66738 Mdot
.1637 .51494 Mdot
.80562 .40291 Mdot
.20837 .61541 Mdot
.65732 .55151 Mdot
.45011 .51669 Mdot
.34408 .76859 Mdot
.41206 .30882 Mdot
.49403 .25039 Mdot
.39778 .65176 Mdot
.47332 .28888 Mdot
.22377 .50216 Mdot
.43108 .30179 Mdot
.34464 .28925 Mdot
.66322 .7976 Mdot
.77228 .66975 Mdot
.20711 .38456 Mdot
.495 .84313 Mdot
.65518 .27324 Mdot
.1307 .47306 Mdot
.38237 .59238 Mdot
.43426 .31185 Mdot
.64893 .71296 Mdot
.73916 .64119 Mdot
.28878 .40019 Mdot
.23148 .61374 Mdot
.50311 .70926 Mdot
.62433 .63614 Mdot
.46796 .34344 Mdot
.30809 .28439 Mdot
.31939 .43161 Mdot
.31058 .37395 Mdot
.80135 .4222 Mdot
.65108 .77809 Mdot
.43015 .46723 Mdot
.24051 .60172 Mdot
.29423 .58743 Mdot
.47563 .20206 Mdot
.70654 .59236 Mdot
.52635 .51128 Mdot
.37915 .29115 Mdot
.46381 .82583 Mdot
.53787 .237 Mdot
.7378 .53834 Mdot
.74846 .62734 Mdot
.8115 .3724 Mdot
.34411 .74196 Mdot
.63972 .17404 Mdot
.4371 .28822 Mdot
.57404 .46122 Mdot
.55155 .2798 Mdot
.18402 .40834 Mdot
.57344 .70155 Mdot
.62261 .7638 Mdot
.57408 .68259 Mdot
.48328 .37779 Mdot
.71201 .26878 Mdot
.18871 .47139 Mdot
.16195 .44487 Mdot
.51703 .66248 Mdot
.66437 .40966 Mdot
.44941 .88463 Mdot
.74893 .65768 Mdot
.30808 .35187 Mdot
.83794 .51478 Mdot
.49038 .44683 Mdot
.40304 .2447 Mdot
.36015 .44026 Mdot
.81449 .52259 Mdot
.45864 .35346 Mdot
.64299 .16417 Mdot
.84057 .43588 Mdot
.68908 .2845 Mdot
.90549 .59064 Mdot
.67674 .69994 Mdot
.50035 .47202 Mdot
.3564 .51873 Mdot
.6709 .61244 Mdot
.46083 .21911 Mdot
.59518 .72662 Mdot
.29458 .56251 Mdot
.4646 .8582 Mdot
.80708 .56835 Mdot
.15897 .47067 Mdot
.27327 .7291 Mdot
.51489 .22626 Mdot
.49748 .55849 Mdot
.59937 .40279 Mdot
.47901 .64948 Mdot
.60536 .78262 Mdot
.81591 .36566 Mdot
.72306 .57392 Mdot
.59848 .87612 Mdot
.57375 .63432 Mdot
.49653 .73237 Mdot
.70687 .77579 Mdot
.63582 .64572 Mdot
.33872 .26823 Mdot
.7765 .5323 Mdot
.57612 .40199 Mdot
.54504 .58024 Mdot
.61981 .77159 Mdot
.28546 .3393 Mdot
.80801 .47456 Mdot
.53311 .82859 Mdot
.21965 .46934 Mdot
.65093 .35058 Mdot
.75795 .57583 Mdot
.41942 .31744 Mdot
.61637 .60345 Mdot
.34084 .2783 Mdot
.79611 .64566 Mdot
.34223 .42962 Mdot
.81509 .63637 Mdot
.7438 .29071 Mdot
.68476 .45723 Mdot
.54797 .47065 Mdot
.52245 .3899 Mdot
.62501 .60715 Mdot
.6916 .5178 Mdot
.2369 .42853 Mdot
.76733 .68877 Mdot
.74386 .37063 Mdot
.29891 .51508 Mdot
.2774 .48574 Mdot
.69949 .78605 Mdot
.57578 .29491 Mdot
.53711 .63348 Mdot
.78956 .44922 Mdot
.47549 .21016 Mdot
.40665 .61747 Mdot
.16387 .46918 Mdot
.34624 .50601 Mdot
.70229 .27852 Mdot
.65095 .36714 Mdot
.57924 .22929 Mdot
.76777 .68906 Mdot
.3714 .7174 Mdot
.73063 .28566 Mdot
.62511 .676 Mdot
.18299 .57201 Mdot
.33764 .57988 Mdot
.63329 .54622 Mdot
.24247 .62821 Mdot
.54654 .64642 Mdot
.61655 .30718 Mdot
.20863 .66213 Mdot
.45008 .75094 Mdot
.66769 .52705 Mdot
.68695 .27999 Mdot
.37647 .56636 Mdot
.41816 .40442 Mdot
.53107 .15481 Mdot
.59642 .43185 Mdot
.76446 .60653 Mdot
.32515 .71513 Mdot
.66908 .59956 Mdot
.57907 .83404 Mdot
.41553 .79674 Mdot
.68342 .19729 Mdot
.82696 .529 Mdot
.44435 .71338 Mdot
.79845 .54853 Mdot
.8113 .59957 Mdot
.68235 .20164 Mdot
.55734 .44506 Mdot
.30586 .45924 Mdot
.33602 .19436 Mdot
.37791 .62569 Mdot
.74151 .65187 Mdot
.20302 .55557 Mdot
.49529 .62675 Mdot
.48886 .39963 Mdot
.5356 .42434 Mdot
.44674 .46447 Mdot
.50117 .30606 Mdot
.69224 .5154 Mdot
.60237 .17978 Mdot
.74117 .24576 Mdot
.6311 .17948 Mdot
.4066 .81223 Mdot
.8107 .51092 Mdot
.50596 .50922 Mdot
.19533 .40659 Mdot
.5307 .50461 Mdot
.65342 .51486 Mdot
.50382 .67949 Mdot
.67012 .70499 Mdot
.65808 .25362 Mdot
.34384 .36757 Mdot
.44184 .2569 Mdot
.61974 .7677 Mdot
.16912 .69088 Mdot
.62563 .27815 Mdot
.18295 .51617 Mdot
.51251 .64515 Mdot
.65435 .59554 Mdot
.58177 .77838 Mdot
.61488 .23062 Mdot
.74295 .7184 Mdot
.50046 .30544 Mdot
.20847 .60281 Mdot
.45253 .76843 Mdot
.41814 .37813 Mdot
.44669 .70131 Mdot
.73915 .68893 Mdot
.26159 .44085 Mdot
.58408 .21165 Mdot
.37237 .34503 Mdot
.55026 .2657 Mdot
.46304 .58418 Mdot
.27712 .58344 Mdot
.19707 .62253 Mdot
.38878 .76584 Mdot
.75035 .53882 Mdot
.47672 .47482 Mdot
.28247 .29731 Mdot
.33707 .53179 Mdot
.73754 .55069 Mdot
.49377 .4101 Mdot
.78051 .56538 Mdot
.6482 .13311 Mdot
.53647 .17187 Mdot
.65246 .81394 Mdot
.55671 .76847 Mdot
.66508 .53496 Mdot
.72544 .74002 Mdot
.60108 .1579 Mdot
.82502 .34064 Mdot
.26282 .59084 Mdot
.39868 .58307 Mdot
.33775 .50042 Mdot
.63984 .20185 Mdot
.54701 .75135 Mdot
.6924 .75895 Mdot
.74402 .57126 Mdot
.38169 .48117 Mdot
.25739 .26012 Mdot
.80954 .38029 Mdot
.66984 .37913 Mdot
.59091 .61248 Mdot
.62882 .54083 Mdot
.3272 .25128 Mdot
.43438 .29933 Mdot
.31791 .62132 Mdot
.66849 .58701 Mdot
.40097 .61045 Mdot
.61872 .73343 Mdot
.23738 .62948 Mdot
.67388 .48357 Mdot
.49189 .5674 Mdot
.4365 .36652 Mdot
.33325 .5762 Mdot
.27228 .38341 Mdot
.80193 .31175 Mdot
.50378 .64978 Mdot
.65884 .52207 Mdot
.68137 .5951 Mdot
.4496 .69514 Mdot
.72091 .26172 Mdot
.37966 .47302 Mdot
.80209 .59598 Mdot
.43354 .49416 Mdot
.62194 .60017 Mdot
.44955 .23699 Mdot
.56694 .55474 Mdot
.62029 .43061 Mdot
.45671 .81308 Mdot
.7217 .35744 Mdot
.40053 .37764 Mdot
.67916 .42616 Mdot
.53311 .49956 Mdot
.71696 .7479 Mdot
.5062 .63049 Mdot
.28201 .57231 Mdot
.79546 .62055 Mdot
.36891 .45134 Mdot
.45112 .36907 Mdot
.59656 .68819 Mdot
.22053 .63041 Mdot
.74291 .42902 Mdot
.70651 .27537 Mdot
.50892 .61118 Mdot
.46038 .74519 Mdot
.79227 .63527 Mdot
.793 .60419 Mdot
.27726 .27546 Mdot
.47382 .26278 Mdot
.705 .54996 Mdot
.21485 .63046 Mdot
.49548 .33503 Mdot
.20775 .46723 Mdot
.21575 .44831 Mdot
.82734 .41727 Mdot
.48274 .56634 Mdot
.47539 .85964 Mdot
.69694 .64652 Mdot
.60072 .76112 Mdot
.55857 .1959 Mdot
.19263 .59813 Mdot
.72139 .6916 Mdot
.49609 .28641 Mdot
.60283 .34943 Mdot
.63692 .55508 Mdot
.23879 .35362 Mdot
.3282 .20762 Mdot
.59344 .69307 Mdot
.50973 .40301 Mdot
.53947 .82906 Mdot
.62831 .46121 Mdot
.5029 .1642 Mdot
.22596 .6196 Mdot
.63568 .2151 Mdot
.37313 .49059 Mdot
.61353 .52127 Mdot
.56208 .48858 Mdot
.79104 .4906 Mdot
.33846 .29587 Mdot
.78234 .5541 Mdot
.24609 .71537 Mdot
.5601 .80645 Mdot
.46093 .24194 Mdot
.74395 .64368 Mdot
.65219 .78042 Mdot
.29696 .71079 Mdot
.48227 .50993 Mdot
.58838 .74283 Mdot
.64828 .64479 Mdot
.47957 .83905 Mdot
.46675 .41091 Mdot
.39143 .53082 Mdot
.25633 .42476 Mdot
.3303 .69418 Mdot
.63211 .22806 Mdot
.59399 .50794 Mdot
.78256 .34206 Mdot
.71265 .73462 Mdot
.30678 .25807 Mdot
.42042 .20511 Mdot
.54416 .17098 Mdot
.70145 .35737 Mdot
.35647 .73898 Mdot
.27103 .67955 Mdot
.18212 .61459 Mdot
.42952 .49717 Mdot
.67777 .71608 Mdot
.6355 .65899 Mdot
.79368 .62968 Mdot
.32634 .44153 Mdot
.36593 .3256 Mdot
.27617 .49501 Mdot
.79196 .55194 Mdot
.57899 .30753 Mdot
.74205 .6978 Mdot
.4795 .44077 Mdot
.6887 .19807 Mdot
.41513 .78538 Mdot
.45767 .45061 Mdot
.43509 .61231 Mdot
.38599 .72843 Mdot
.66296 .74981 Mdot
.42965 .78599 Mdot
.18883 .5716 Mdot
.40774 .57447 Mdot
.54886 .57019 Mdot
.60035 .37962 Mdot
.60316 .60424 Mdot
.45251 .81409 Mdot
.68028 .59564 Mdot
.7654 .68088 Mdot
.79831 .48891 Mdot
.77961 .33909 Mdot
.68403 .69712 Mdot
.38926 .81835 Mdot
.30895 .34807 Mdot
.57236 .61131 Mdot
.23013 .62293 Mdot
.50444 .74708 Mdot
.50296 .30073 Mdot
.36303 .13388 Mdot
.32483 .77446 Mdot
.38164 .75417 Mdot
.81592 .36912 Mdot
.41458 .80139 Mdot
.33349 .56751 Mdot
.51069 .24828 Mdot
.38633 .30308 Mdot
.77182 .35464 Mdot
.63679 .49557 Mdot
.59057 .16885 Mdot
.63998 .59029 Mdot
.78007 .27485 Mdot
.68918 .7677 Mdot
.50831 .39828 Mdot
.6214 .42224 Mdot
.38402 .65195 Mdot
.42976 .52854 Mdot
.75694 .5004 Mdot
.55588 .31523 Mdot
.3673 .24767 Mdot
.34437 .54019 Mdot
.38038 .59545 Mdot
.44545 .69055 Mdot
.48845 .2837 Mdot
.56668 .75545 Mdot
.327 .6838 Mdot
.46438 .6448 Mdot
.42332 .46802 Mdot
.70831 .57171 Mdot
.32434 .28915 Mdot
.68047 .38486 Mdot
.62039 .2314 Mdot
.27689 .43136 Mdot
.38252 .64172 Mdot
.6776 .37594 Mdot
.34374 .77315 Mdot
.5394 .81833 Mdot
.81218 .36243 Mdot
.53582 .57825 Mdot
.56338 .34245 Mdot
.7578 .53435 Mdot
.43837 .21343 Mdot
.51558 .29476 Mdot
.34821 .557 Mdot
.32511 .2555 Mdot
.51197 .26976 Mdot
.21938 .54476 Mdot
.8324 .44271 Mdot
.20838 .61214 Mdot
.21337 .63021 Mdot
.48155 .63387 Mdot
.72749 .48291 Mdot
.44663 .38999 Mdot
.68987 .63715 Mdot
.42593 .41399 Mdot
.15233 .42209 Mdot
.6533 .41333 Mdot
.13476 .40234 Mdot
.31399 .46722 Mdot
.4902 .22417 Mdot
.64689 .65339 Mdot
.48278 .48135 Mdot
.48435 .42842 Mdot
.39621 .77427 Mdot
.36947 .30844 Mdot
.3334 .73387 Mdot
.43628 .22602 Mdot
.38074 .59217 Mdot
.26442 .74306 Mdot
.40534 .83221 Mdot
.62313 .34696 Mdot
.6763 .4636 Mdot
.34522 .78948 Mdot
.39939 .58562 Mdot
.64443 .24458 Mdot
.58677 .82986 Mdot
.51416 .80617 Mdot
.56378 .38993 Mdot
.641 .59837 Mdot
.68436 .71255 Mdot
.82503 .56626 Mdot
.314 .23066 Mdot
.61234 .77257 Mdot
.32548 .44258 Mdot
.47985 .4526 Mdot
.70922 .72094 Mdot
.38406 .25683 Mdot
.33107 .42993 Mdot
.35809 .25574 Mdot
.11641 .47368 Mdot
.74544 .65087 Mdot
.77707 .56263 Mdot
.38458 .24636 Mdot
.48325 .37232 Mdot
.36515 .2883 Mdot
.33603 .2706 Mdot
.48781 .8032 Mdot
.31178 .74353 Mdot
.33624 .2752 Mdot
.15094 .56036 Mdot
.58546 .56693 Mdot
.33932 .63058 Mdot
.52591 .39453 Mdot
.75081 .46627 Mdot
.3884 .47064 Mdot
.78977 .39489 Mdot
.57261 .81103 Mdot
.30345 .47232 Mdot
.47313 .81783 Mdot
.2429 .61007 Mdot
.70238 .41264 Mdot
.73844 .42025 Mdot
.55083 .79921 Mdot
.57739 .32543 Mdot
.24182 .33144 Mdot
.70731 .29292 Mdot
.42835 .58797 Mdot
.6044 .80537 Mdot
.40798 .64537 Mdot
.52866 .46879 Mdot
.39437 .29658 Mdot
.59863 .72372 Mdot
.62219 .20272 Mdot
.56932 .64335 Mdot
.44129 .29635 Mdot
.32615 .21311 Mdot
.48452 .36049 Mdot
.61542 .18269 Mdot
.58474 .22845 Mdot
.35279 .2398 Mdot
.4408 .71924 Mdot
.42723 .7407 Mdot
.12673 .51003 Mdot
.30928 .43434 Mdot
.47056 .65531 Mdot
.22292 .39471 Mdot
.43341 .30998 Mdot
.49428 .66837 Mdot
.44173 .63291 Mdot
.4067 .4972 Mdot
.2332 .4936 Mdot
.60553 .56898 Mdot
.42477 .291 Mdot
.41474 .48488 Mdot
.77963 .42248 Mdot
.82206 .47691 Mdot
.39333 .59851 Mdot
.16083 .37421 Mdot
.62091 .42519 Mdot
.64583 .34344 Mdot
.75093 .71367 Mdot
.2524 .26558 Mdot
.38667 .69478 Mdot
.42586 .84789 Mdot
.61724 .53623 Mdot
.56347 .78062 Mdot
.46132 .3476 Mdot
.2112 .6105 Mdot
.56703 .68921 Mdot
.66391 .60461 Mdot
.31271 .48031 Mdot
.57997 .21041 Mdot
.37652 .69686 Mdot
.48852 .29761 Mdot
.53411 .78433 Mdot
.74664 .49198 Mdot
.39901 .48528 Mdot
.41321 .71388 Mdot
.62711 .35097 Mdot
.74049 .43597 Mdot
.434 .26818 Mdot
.77368 .57805 Mdot
.21841 .65506 Mdot
.80659 .31369 Mdot
.48278 .39682 Mdot
.51268 .4684 Mdot
.23037 .44682 Mdot
.50243 .81853 Mdot
.25011 .35461 Mdot
.76672 .69758 Mdot
.70731 .56248 Mdot
.69594 .53935 Mdot
.73188 .55056 Mdot
.58206 .55185 Mdot
.46214 .49075 Mdot
.30047 .5992 Mdot
.38636 .22533 Mdot
.29927 .31023 Mdot
.52287 .23917 Mdot
.25199 .32954 Mdot
.76679 .57128 Mdot
.35465 .24224 Mdot
.459 .62464 Mdot
.71664 .41491 Mdot
.30938 .50424 Mdot
.82574 .48004 Mdot
.7621 .70246 Mdot
.29436 .48135 Mdot
.48055 .67827 Mdot
.5246 .84372 Mdot
.55544 .46593 Mdot
.51593 .54267 Mdot
.59825 .44495 Mdot
.57738 .58895 Mdot
.22144 .29927 Mdot
.49812 .8096 Mdot
.68184 .50839 Mdot
.79931 .57946 Mdot
.80651 .55306 Mdot
.72781 .22575 Mdot
.16907 .53761 Mdot
.45727 .30792 Mdot
.68819 .21278 Mdot
.36147 .2488 Mdot
.82331 .57828 Mdot
.3326 .60072 Mdot
.77722 .71022 Mdot
.60235 .34579 Mdot
.49846 .82899 Mdot
.50291 .24919 Mdot
.37935 .31049 Mdot
.32816 .7103 Mdot
.50651 .53383 Mdot
.26879 .5406 Mdot
.384 .77934 Mdot
.23046 .72089 Mdot
.6152 .55217 Mdot
.2672 .65619 Mdot
.29421 .40722 Mdot
.61925 .80182 Mdot
.42222 .77368 Mdot
.66586 .44947 Mdot
.27332 .48174 Mdot
.61546 .2097 Mdot
.71422 .57148 Mdot
.52461 .51984 Mdot
.40922 .76593 Mdot
.75365 .34174 Mdot
.75807 .52335 Mdot
.20893 .62389 Mdot
.61806 .35072 Mdot
.43464 .51734 Mdot
.61139 .53145 Mdot
.4405 .27529 Mdot
.55462 .63643 Mdot
.50533 .54567 Mdot
.64849 .44715 Mdot
.40752 .66902 Mdot
.4057 .46745 Mdot
.58323 .17955 Mdot
.29233 .33778 Mdot
.25001 .66573 Mdot
.41468 .3307 Mdot
.33866 .3895 Mdot
.24374 .37234 Mdot
.52224 .17945 Mdot
.48534 .77768 Mdot
.72256 .57449 Mdot
.76021 .65281 Mdot
.80207 .49213 Mdot
.40455 .32322 Mdot
.77619 .29159 Mdot
.38455 .4538 Mdot
.69038 .40366 Mdot
.36181 .37342 Mdot
.47105 .66428 Mdot
.69642 .45936 Mdot
.49788 .82819 Mdot
.50053 .62769 Mdot
.7304 .64732 Mdot
.34539 .74595 Mdot
.6446 .57592 Mdot
.62065 .37251 Mdot
.80112 .5904 Mdot
.38816 .6604 Mdot
.24264 .67637 Mdot
.38161 .50531 Mdot
.41394 .76315 Mdot
.80786 .49936 Mdot
.81863 .38444 Mdot
.4568 .4307 Mdot
.64878 .63246 Mdot
.59774 .47473 Mdot
.19991 .62305 Mdot
.49149 .81168 Mdot
.61236 .39496 Mdot
.2608 .56816 Mdot
.4572 .37123 Mdot
.28318 .61759 Mdot
.4462 .5189 Mdot
.7679 .35979 Mdot
.42764 .34611 Mdot
.33725 .24467 Mdot
.52344 .65731 Mdot
.50258 .45329 Mdot
.70489 .45655 Mdot
.66105 .6236 Mdot
.1503 .48552 Mdot
.68448 .42824 Mdot
.61871 .77574 Mdot
.64838 .36216 Mdot
.21113 .58684 Mdot
.54719 .79603 Mdot
.33334 .54987 Mdot
.37081 .30603 Mdot
.72668 .41888 Mdot
.25621 .45182 Mdot
.57467 .47409 Mdot
.44395 .5955 Mdot
.48884 .30298 Mdot
.60379 .8112 Mdot
.71496 .36543 Mdot
.68348 .63341 Mdot
.47224 .58046 Mdot
.5293 .52477 Mdot
.34752 .51587 Mdot
.77103 .71057 Mdot
.37439 .29977 Mdot
.68679 .57765 Mdot
.48345 .56625 Mdot
.65183 .64896 Mdot
.57277 .2356 Mdot
.84137 .42118 Mdot
.50209 .2453 Mdot
.42913 .44839 Mdot
.48388 .22507 Mdot
.36868 .74683 Mdot
.57165 .84004 Mdot
.73602 .54193 Mdot
.49992 .43246 Mdot
.58442 .65427 Mdot
.24221 .4087 Mdot
.45468 .57309 Mdot
.53038 .54426 Mdot
.40849 .50265 Mdot
.24194 .53451 Mdot
.36502 .40067 Mdot
.65113 .40133 Mdot
.7016 .68375 Mdot
.77554 .62978 Mdot
.20421 .56818 Mdot
.34708 .53455 Mdot
.33809 .66647 Mdot
.76985 .3826 Mdot
.78235 .7137 Mdot
.38411 .19114 Mdot
.59919 .47241 Mdot
.33382 .52238 Mdot
.63571 .62681 Mdot
.42871 .6548 Mdot
.31216 .28993 Mdot
.25354 .36874 Mdot
.32621 .44817 Mdot
.57484 .60492 Mdot
.74716 .61771 Mdot
.33848 .70314 Mdot
.60327 .62187 Mdot
.28148 .48443 Mdot
.56541 .17396 Mdot
.37813 .79671 Mdot
.50616 .81729 Mdot
.84755 .62923 Mdot
.37465 .52359 Mdot
.53779 .48272 Mdot
.58042 .27589 Mdot
.81493 .49433 Mdot
.68811 .59607 Mdot
.68365 .26455 Mdot
.30025 .53842 Mdot
.73118 .54417 Mdot
.51178 .32482 Mdot
.71952 .66463 Mdot
.27767 .61424 Mdot
.46267 .47314 Mdot
.43066 .7449 Mdot
.78593 .29599 Mdot
.57794 .37919 Mdot
.76119 .66057 Mdot
.58178 .19761 Mdot
.1744 .6052 Mdot
.81914 .50446 Mdot
.70213 .66001 Mdot
.46625 .78412 Mdot
.55526 .2823 Mdot
.49037 .40958 Mdot
.44916 .24647 Mdot
.6512 .24803 Mdot
.74494 .40843 Mdot
.48286 .70876 Mdot
.53133 .22237 Mdot
.7498 .53949 Mdot
.75121 .40447 Mdot
.50012 .42962 Mdot
.68986 .38674 Mdot
.47696 .67728 Mdot
.37499 .25347 Mdot
.43888 .39925 Mdot
.70472 .61338 Mdot
.66438 .36779 Mdot
.22813 .46006 Mdot
.40638 .79083 Mdot
.16526 .61265 Mdot
.53363 .75886 Mdot
.51667 .1857 Mdot
.66836 .50454 Mdot
.72652 .20969 Mdot
.34172 .72487 Mdot
.35661 .71639 Mdot
.3208 .73762 Mdot
.36195 .56915 Mdot
.54303 .51935 Mdot
.57459 .47469 Mdot
.65529 .75332 Mdot
.56136 .38975 Mdot
.65459 .26827 Mdot
.56117 .20389 Mdot
.6542 .60059 Mdot
.73877 .57605 Mdot
.69239 .64224 Mdot
.69489 .53358 Mdot
.4728 .36679 Mdot
.64029 .18371 Mdot
.43822 .43072 Mdot
.60537 .39622 Mdot
.71413 .46098 Mdot
.54734 .26516 Mdot
.49544 .87146 Mdot
.49968 .39716 Mdot
.77292 .54368 Mdot
.59912 .36544 Mdot
.40497 .34911 Mdot
.25715 .33663 Mdot
.91894 .5071 Mdot
.76753 .23446 Mdot
.48091 .28862 Mdot
.17958 .50239 Mdot
.59614 .36921 Mdot
.78556 .55685 Mdot
.46171 .7695 Mdot
.24466 .55799 Mdot
.64072 .39247 Mdot
.39625 .34614 Mdot
.70368 .48409 Mdot
.31888 .71699 Mdot
.8327 .47316 Mdot
.54042 .20446 Mdot
.79848 .58207 Mdot
.58262 .5556 Mdot
.70283 .46308 Mdot
.82915 .67551 Mdot
.71924 .71173 Mdot
.5972 .42542 Mdot
.47769 .23585 Mdot
.62204 .40323 Mdot
.61997 .50782 Mdot
.59359 .75193 Mdot
.26396 .74135 Mdot
.76025 .53073 Mdot
.79139 .55249 Mdot
.42535 .31545 Mdot
.35817 .58413 Mdot
.31309 .46886 Mdot
.46478 .42924 Mdot
.60222 .41917 Mdot
.3571 .44177 Mdot
.65134 .57976 Mdot
.53066 .83588 Mdot
.44611 .55982 Mdot
.25147 .70937 Mdot
.8214 .6374 Mdot
.7074 .36734 Mdot
.24845 .40039 Mdot
.55508 .47477 Mdot
.75193 .44995 Mdot
.76782 .43874 Mdot
.55722 .56712 Mdot
.44938 .82455 Mdot
.45641 .10341 Mdot
.26251 .49293 Mdot
.78143 .37445 Mdot
.49608 .36125 Mdot
.41837 .51224 Mdot
.64025 .37953 Mdot
.34209 .58791 Mdot
.40733 .59618 Mdot
.60249 .56321 Mdot
.44067 .37669 Mdot
.37619 .49122 Mdot
.1736 .34179 Mdot
.67896 .4687 Mdot
.28427 .31512 Mdot
.81747 .58643 Mdot
.70625 .29152 Mdot
.61266 .32228 Mdot
.5744 .50273 Mdot
.30204 .38094 Mdot
.49955 .43517 Mdot
.60421 .79257 Mdot
.78484 .35275 Mdot
.77338 .6189 Mdot
.71873 .36831 Mdot
.61478 .37153 Mdot
.61704 .53066 Mdot
.55235 .70634 Mdot
.35866 .41451 Mdot
.62776 .75833 Mdot
.60643 .40803 Mdot
.83222 .53756 Mdot
.36571 .69639 Mdot
.51384 .58044 Mdot
.51405 .38571 Mdot
.72032 .22338 Mdot
.55503 .24705 Mdot
.42345 .36868 Mdot
.53172 .17728 Mdot
.42518 .69464 Mdot
.60324 .60912 Mdot
.38318 .65351 Mdot
.56878 .42943 Mdot
.42076 .33062 Mdot
.51354 .15982 Mdot
.62388 .74887 Mdot
.27026 .53366 Mdot
.27528 .57828 Mdot
.19573 .52581 Mdot
.39827 .48426 Mdot
.85468 .60982 Mdot
.40709 .7205 Mdot
.53326 .16596 Mdot
.22431 .66139 Mdot
.42052 .34157 Mdot
.4243 .801 Mdot
.66416 .42024 Mdot
.3939 .60289 Mdot
.78858 .59122 Mdot
.54269 .43191 Mdot
.71569 .27489 Mdot
.5966 .53465 Mdot
.66803 .22875 Mdot
.58764 .65433 Mdot
.4893 .68158 Mdot
.36784 .74114 Mdot
.55042 .26144 Mdot
.69006 .78284 Mdot
.23876 .41382 Mdot
.72611 .74715 Mdot
.66673 .79486 Mdot
.80715 .5882 Mdot
.68003 .25238 Mdot
.28322 .25217 Mdot
.3778 .74662 Mdot
.54351 .80374 Mdot
.31276 .61845 Mdot
.53605 .27085 Mdot
.38383 .72939 Mdot
.52376 .3826 Mdot
.3367 .29886 Mdot
.30276 .50549 Mdot
.19683 .2642 Mdot
.73619 .59928 Mdot
.45169 .38778 Mdot
.39943 .73086 Mdot
.81613 .55536 Mdot
.55664 .27463 Mdot
.37458 .77438 Mdot
.44993 .51436 Mdot
.62444 .54635 Mdot
.73838 .40316 Mdot
.1983 .55868 Mdot
.38145 .71179 Mdot
.1295 .56746 Mdot
.35149 .77551 Mdot
.25649 .53744 Mdot
.45323 .48837 Mdot
.47075 .28697 Mdot
.23045 .35787 Mdot
.436 .73702 Mdot
.43202 .81957 Mdot
.5117 .83329 Mdot
.71264 .71832 Mdot
.12799 .50613 Mdot
.21345 .60455 Mdot
.81933 .4841 Mdot
.4452 .80463 Mdot
.4872 .29239 Mdot
.68579 .67107 Mdot
.41595 .58608 Mdot
.29139 .56497 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0Woooool2o`000:Sooooo000Looooo`03o`000?oooooooooo09oooooo0_l0002Xooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo097ooooo
0_l0002fooooo`007?ooool00ol0003oooooooooo`2Aooooo`;o0000]_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0/_ooool2o`0009Gooooo000Looooo`03o`000?oooooooooo0;;o
oooo0_l0002Eooooo`007?ooool00ol0003oooooooooo`1booooo`;o0000<oooool2o`0002Kooooo
0_l0001hooooo`007?ooool00ol0003oooooooooo`1booooo`;o0000<oooool2o`0002Kooooo0_l0
001hooooo`007?ooool00ol0003oooooooooo`2Cooooo`Co0000/_ooool001cooooo00?o0000oooo
ooooool0Toooool4o`000;;ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000<?ooooo0_l00025ooooo`007?ooool0
0ol0003oooooooooo`29ooooo`;o00007_ooool2o`0001Oooooo0_l00025ooooo`007?ooool00ol0
003oooooooooo`29ooooo`;o00006?ooool2o`0000Cooooo0_l0000Dooooo`;o0000R?ooool001co
oooo00?o0000ooooooooool0IOooool2o`0001cooooo0_l0000Nooooo`;o00006_ooool2o`0008So
oooo000Looooo`03o`000?oooooooooo06Gooooo0_l0000Looooo`;o00006oooool2o`0000Oooooo
0_l0000Rooooo`;o0000N_ooool001cooooo00?o0000ooooooooool0N?ooool2o`0000?ooooo0_l0
000Looooo`?o00000_ooool2o`0000Oooooo0_l0000Aooooo`;o00003oooool2o`0007[ooooo000L
ooooo`03o`000?oooooooooo07Sooooo0_l00003ooooo`;o00007?ooool3o`0000cooooo0_l00000
0ooooooo0000o`000002ooooo`;o00001Oooool2o`0000;ooooo0_l0002;ooooo`007?ooool00ol0
003oooooooooo`2Looooo`;o00003?ooool2o`000003ooooool0003o000000;ooooo0_l000000ooo
oooo0000o`000002ooooo`;o00004_ooool2o`0007_ooooo000Looooo`03o`000?oooooooooo07;o
oooo0_l0000Xooooo`;o00002oooool2o`0000Wooooo0_l0000Fooooo`;o00000_ooool2o`0007Oo
oooo000Looooo`03o`000?oooooooooo07;ooooo0_l0000booooo`Go00003oooool2o`0000Cooooo
0_l00007ooooo`;o00001Oooool2o`0007Oooooo000Looooo`03o`000?oooooooooo07[ooooo0_l0
000Zooooo`Go00001?ooool2o`0000Wooooo0_l00004ooooo`;o00000_ooool2o`0000?ooooo0_l0
00000ooooooo0000o`00001kooooo`007?ooool00ol0003oooooooooo`1jooooo`;o0000:?ooool2
o`0000?ooooo0_l00004ooooo`;o00000oooool2o`0000kooooo0_l00006ooooo`;o0000Noooool0
01cooooo00?o0000ooooooooool0Y?ooool2o`0000gooooo0ol0002Cooooo`0000Koooooonk^k_lb
<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0FOooool2
o`0001kooooo0_l0000Booooo`;o00009?ooool2o`0000Cooooo0_l0002>ooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo
00?o0000ooooooooool0FOooool3o`0000Oooooo0_l00004ooooo`;o00001Oooool2o`0000Oooooo
0_l0000Booooo`Co00008Oooool2o`0000Gooooo0_l0002>ooooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0F_oo
ool2o`0000Oooooo0_l00004ooooo`;o00001Oooool2o`0001gooooo0_l0000Fooooo`;o00002Ooo
ool3o`0000Cooooo0_l00005ooooo`Co00005_ooool4o`0006_ooooo00000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0007Gooooo0_l0000;
ooooo`;o00000_ooool2o`0000oooooo0_l0000=ooooo`?o00001_ooool2o`0000;ooooo0_l00004
ooooo`;o00001Oooool4o`0000;ooooo0_l00004ooooo`;o00003?ooool4o`0006_ooooo00000ooo
oooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0
003oooooooooo`1eooooo`;o00001oooool2o`0000;ooooo0_l000001?oooooo0000o`000?l00004
ooooo`;o00002Oooool2o`0000gooooo0_l00004ooooo`;o000000?oooooo`000?l000000_ooool2
o`0000Oooooo0_l00006ooooo`Co00001?ooool2o`0000cooooo0_l0001]ooooo`0000?ooooooa0@
4?ooool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0Ioooool2o`00013ooooo0_l00003ooooo`;o00001Oooool3o`0000Cooooo0_l00006oooo
o`Go00004?ooool2o`000003ooooool0003o000000Gooooo0_l00007ooooo`;o00000_ooool2o`00
00;ooooo0_l00023ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`1Wooooo`;o00004?ooool2o`0001Wooooo1Ol0
000<ooooo`;o00000_ooool2o`0000kooooo0ol00004ooooo`;o00000_ooool2o`0002;ooooo0_l0
001Oooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`01_ooool00ol0003oooooooooo`1Vooooo`;o00003_ooool2o`0001?ooooo0ol00006ooooo`;o
000000?oooooo`000?l000002oooool3o`0001;ooooo0ol00008ooooo`;o00001Oooool2o`0000oo
oooo0_l00004ooooo`;o00001?ooool2o`0005oooooo000Looooo`03o`000?oooooooooo06Gooooo
0ol00008ooooo`;o00001?ooool2o`0000Sooooo0_l00009ooooo`?o00001_ooool3o`0000gooooo
0ol0000Tooooo`;o00003oooool2o`0000Cooooo0_l0001Uooooo`007?ooool00ol0003ooooooooo
o`1Uooooo`;o00002?ooool3o`0000kooooo0_l0000:ooooo`;o00001?ooool2o`000003ooooool0
003o0000027ooooo0_l0000Eooooo`;o00002Oooool2o`0006gooooo000Looooo`03o`000?oooooo
oooo06oooooo0_l00002ooooo`;o00005oooool2o`0000Cooooo0_l000001?oooooo0000o`000?oo
ool2o`000003ooooool0003o000000cooooo0_l0000=ooooo`;o00005Oooool2o`0000Wooooo0_l0
000:ooooo`;o0000HOooool001cooooo00?o0000ooooooooool0E?ooool2o`0001gooooo0_l00004
ooooo`?o00002?ooool2o`0000Cooooo0_l00003ooooo`;o00001?ooool2o`000003ooooool0003o
000000?o00001?ooool4o`0000Cooooo0_l0000=ooooo`;o00003_ooool2o`000003ooooool0003o
000001Wooooo0_l000000ooooooo0000o`00001Nooooo`007?ooool00ol0003oooooooooo`1;oooo
o`;o000000?oooooo`000?l000001?ooool2o`0000cooooo0_l0000Eooooo`?o00000_ooool2o`00
00Cooooo0_l00004ooooo`;o00000oooool2o`0000Cooooo0_l00002ooooo`;o00001_ooool4o`00
01?ooooo1?l00008ooooo`;o00000_ooool5o`000003ooooool0003o000000Gooooo1?l00003oooo
o`;o00002oooool2o`0005kooooo000Looooo`03o`000?oooooooooo04_ooooo0_l000000ooooooo
0000o`00000=ooooo`;o00000oooool2o`0001[ooooo0_l0000hooooo`Co00002?ooool8o`0000;o
oooo0_l00005ooooo`Co00000oooool2o`0006_ooooo000Looooo`03o`000?oooooooooo05gooooo
0_l0000_ooooo`;o00001oooool2o`0001;ooooo0_l00009ooooo`;o00002oooool7o`0001?ooooo
0_l0000Gooooo`;o0000DOooool001cooooo00?o0000ooooooooool0FOooool2o`0001Cooooo0_l0
00000ooooooo0000o`000008ooooo`;o00004?ooool2o`0000Oooooo0_l00007ooooo`;o00001?oo
ool2o`0000?ooooo0_l00009ooooo`;o00002oooool3o`0000Oooooo0_l0000>ooooo`;o00005ooo
ool2o`00057ooooo000Looooo`03o`000?oooooooooo05Wooooo0_l0000?ooooo`;o00000oooool2
o`000003ooooool0003o000000Sooooo0_l00003ooooo`Co00001_ooool2o`0000Gooooo0_l0000<
ooooo`Co00000_ooool2o`000003ooooool0003o000000Sooooo0_l0000Cooooo`;o00000oooool2
o`0000Kooooo0_l00009ooooo`;o0000Ioooool001cooooo00?o0000ooooooooool0Eoooool2o`00
017ooooo0_l00003ooooo`;o00003_ooool6o`0000Kooooo0_l00005ooooo`;o00002oooool2o`00
0003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000005ooooo`;o000000?oooooo`00
0?l000003oooool2o`0000;ooooo0_l00004ooooo`;o00001Oooool6o`000003ooooool0003o0000
00;ooooo0_l0000;ooooo`;o0000F_ooool001cooooo00?o0000ooooooooool0Eoooool2o`0000Co
oooo0_l0000;ooooo`;o00001_ooool4o`0000?ooooo0_l00004ooooo`;o00002_ooool2o`000003
ooooool0003o000000Kooooo0_l00007ooooo`Go00000_ooool2o`0000;ooooo0_l00004ooooo`?o
00003Oooool2o`0000;ooooo1?l00006ooooo`Co00001Oooool4o`000003ooooool0003o000000?o
oooo0_l00007ooooo`;o000000?oooooo`000?l00000F_ooool001cooooo0_l0001Iooooo`;o0000
0oooool2o`0000Sooooo0_l00005ooooo`;o00000_ooool5o`0000;ooooo0_l0000@ooooo`;o0000
00?oooooo`000?l000001_ooool2o`0000Cooooo0ol000000ooooooo0000o`000002o`0000Kooooo
0_l00005ooooo`;o00003Oooool2o`0000?ooooo0ol00008ooooo`;o00000oooool2o`0000;ooooo
0ol00005ooooo`;o00001oooool2o`0005gooooo000Looooo`03o`000?oooooooooo05Cooooo0_l0
0002ooooo`;o00003Oooool2o`0000Gooooo0_l00005ooooo`?o00000_ooool3o`00017ooooo0_l0
0004ooooo`;o00001Oooool4o`000003ooooool0003o000000;ooooo0_l00003ooooo`;o00001_oo
ool2o`0001?ooooo0_l00009ooooo`Ko00000_ooool3o`0001Sooooo0_l0001Cooooo`007?ooool0
0ol0003oooooooooo`1?ooooo`;o00000oooool2o`0000[ooooo0_l00004ooooo`;o00002Oooool2
o`0000?ooooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l00009ooooo`Co00001?ooool2
o`0000Gooooo0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o000000Co00001?ooool2
o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l000001_ooool4o`0000Oooooo1?l0000O
ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0B?ooool2o`0000Gooooo0ol0000>oooo
o`;o00001?ooool2o`0000Wooooo0_l00005ooooo`?o00001_ooool4o`0000Oooooo0ol0000:oooo
o`;o00003?ooool3o`000003ooooool0003o000000;ooooo0_l00002ooooo`Co00001?ooool2o`00
0003ooooool0003o000000Sooooo0_l00005ooooo`;o0000N?ooool001cooooo00?o0000oooooooo
ool0??ooool2o`0000[ooooo0_l00006ooooo`;o00004?ooool2o`0000;ooooo0ol00005ooooo`;o
00002?ooool2o`0000Wooooo0_l00006ooooo`?o00000_ooool2o`0000Cooooo0_l000000ooooooo
0000o`00000<ooooo`?o00001Oooool2o`0000;ooooo0_l00002ooooo`;o00000_ooool2o`0001;o
oooo0_l00009ooooo`;o000000?oooooo`000?l000001oooool2o`0000gooooo0_l0001Booooo`00
7?ooool00ol0003oooooooooo`0looooo`;o00004?ooool2o`0000kooooo0_l00002ooooo`;o0000
0_ooool3o`0000Gooooo0_l0000;ooooo`;o00003_ooool3o`0000;ooooo0_l00004ooooo`;o0000
00?oooooo`000?l000003?ooool2o`0000Gooooo0ol00006ooooo`;o00000_ooool2o`0001Oooooo
0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000Kooooo0ol0000=ooooo`;o
0000D_ooool001cooooo00?o0000ooooooooool0C_ooool2o`0000kooooo0_l00009ooooo`?o0000
3oooool2o`0000[ooooo1Ol00008ooooo`?o00003?ooool2o`0000Cooooo0ol00002ooooo`Co0000
0_ooool2o`0000Gooooo0_l0000Dooooo`;o000000Coooooo`000?l0003ooooo0_l0000:ooooo`Co
00001?ooool2o`0005cooooo000Looooo`03o`000?oooooooooo05Oooooo0_l00008ooooo`;o0000
1_ooool3o`0001_ooooo1_l000000ooooooo0000o`000002o`0000;ooooo0ol00006ooooo`;o0000
1?ooool2o`0000Cooooo1Ol00002ooooo`;o00000_ooool2o`0000Gooooo0_l00004ooooo`;o0000
3_ooool2o`0000Cooooo0_l00002ooooo`;o00001_ooool2o`0000Cooooo1?l0001Looooo`007?oo
ool00ol0003oooooooooo`1Fooooo`?o00002?ooool2o`0000Kooooo0_l0000Pooooo`;o000000?o
ooooo`000?l000000_l00002ooooo`;o00001oooool2o`0000gooooo0_l00003ooooo`;o00001_oo
ool2o`0000Kooooo0_l0000>ooooo`;o00000oooool2o`0000?ooooo0_l00005ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0000Gooooo0_l00008ooooo`;o0000COooool001cooooo00?o0000
ooooooooool0E_ooool2o`00017ooooo1?l0000=ooooo`;o000000?oooooo`000?l000003?ooool2
o`000003ooooool0003o000000;ooooo1?l000000ooooooo0000o`000004o`0001;ooooo1?l00006
ooooo`;o00003?ooool2o`0000cooooo0ol00003ooooo`;o00000oooool4o`000003ooooool0003o
000000Wooooo0_l00008ooooo`?o0000C?ooool001cooooo00?o0000ooooooooool0FOooool2o`00
013ooooo0_l00009ooooo`;o00000_ooool5o`0000;ooooo1?l00009ooooo`?o000000Coooooo`00
0?l0003ooooo2?l00003ooooo`;o00003Oooool7o`00017ooooo0_l0000<ooooo`;o00001?ooool2
o`0000?ooooo0_l00003ooooo`;o00001Oooool2o`0000gooooo0_l000000ooooooo0000o`000019
ooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o00001?ooool4o`0001?ooooo0_l00003oooo
o`;o00001?ooool4o`000003ooooool0003o000000;o000000Coooooo`000?l0003ooooo4?l00002
ooooo`;o00003oooool5o`0002Kooooo0_l000000ooooooo0000o`000005ooooo`;o00000_ooool4
o`00013ooooo0_l00019ooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00005Oooool2o`00
00;ooooo1_l00003ooooo`Co00000_ooool2o`000003ooooool0003o000000;ooooo0_l00004oooo
o`;o00001oooool2o`0000;ooooo6Ol0000Cooooo`;o00004_ooool4o`0001;ooooo0_l000000ooo
oooo0000o`000005ooooo`;o00000_ooool2o`0005gooooo000Looooo`03o`000?oooooooooo04;o
oooo0_l0000Eooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`Co00000_ooool5o`0000;o
oooo0ol000000ooooooo0000o`000002o`0000_ooooo6Ol0000Wooooo`Co00006?ooool2o`0000;o
oooo0_l00006ooooo`;o00002?ooool2o`0004oooooo000Looooo`03o`000?oooooooooo05gooooo
0_l00003ooooo`;o00000_ooool2o`0000Gooooo0_l00005ooooo`;o000000?oooooo`000?l00000
1_ooool2o`0000Gooooo1?l000000ooooooo0000o`00000Bo`0000Gooooo0ol0000@ooooo`;o0000
:Oooool2o`0000;ooooo0_l00006ooooo`;o00002?ooool2o`0004oooooo000Looooo`03o`000?oo
oooooooo05Sooooo0_l00003ooooo`;o00002oooool2o`0000Kooooo0_l00008ooooo`;o000000?o
ooooo`000?l000001ooooolEo`000003ooooool0003o000000Cooooo0ol0000@ooooo`;o00009_oo
ool2o`000003ooooool0003o000000Gooooo0_l00005ooooo`;o00002Oooool2o`0004cooooo000L
ooooo`;o0000AOooool2o`0001;ooooo0_l0000@ooooo`;o00001?ooool4o`0000;ooooo0_l00004
ooooo`;o00002OoooolFo`000003ooooool0003o000000;o00001Oooool2o`0001_ooooo0_l0000I
ooooo`Co00001_ooool2o`0000Gooooo0_l00009ooooo`;o0000C?ooool001cooooo00?o0000oooo
ooooool0A?ooool2o`0000_ooooo0_l00005ooooo`;o000000?oooooo`000?l000001oooool2o`00
00Cooooo0_l00004ooooo`;o00001?ooool2o`0000;ooooo0_l00008ooooo`;o000000?oooooo`00
0?l000003ol000000ooooooo0000o`000004o`000003ooooool0003o000000Gooooo0ol0000Joooo
o`;o000000?oooooo`000?l000006?ooool2o`0000Wooooo0_l000000ooooooo0000o`00000:oooo
o`;o0000C?ooool001cooooo00?o0000ooooooooool0D?ooool3o`0000Gooooo0_l000000ooooooo
0000o`000007ooooo`;o00002Oooool2o`0000Cooooo0_l00003ooooo`;o00002?ooool2o`000003
ooooool0003o000000Go000000?oooooo`000?l000001ol000000ooooooo0000o`000007o`0000?o
oooo0_l000000ooooooo0000o`00000>ooooo`;o00002_ooool2o`000003ooooool0003o000002?o
oooo0_l000000ooooooo0000o`000007ooooo`;o000000Coooooo`000?l0003ooooo0_l00019oooo
o`007?ooool00ol0003oooooooooo`1@ooooo`;o00002Oooool5o`0000oooooo0_l000000ooooooo
0000o`000005o`0000;ooooo0_l00005ooooo`Co00000_oooolIo`0000Cooooo0_l0000Aooooo`;o
00002Oooool3o`0000Gooooo0_l0000Iooooo`;o00001?ooool3o`0000Cooooo0_l00003ooooo`;o
00001?ooool2o`0004Wooooo000Looooo`03o`000?oooooooooo04cooooo0_l000000ooooooo0000
o`00000:ooooo`Go00004_ooool7o`0000;ooooo0ol00004ooooo`Co00000_oooolIo`0000Kooooo
0_l0000?ooooo`;o00000_ooool2o`0000Gooooo0_l00002ooooo`;o00000_ooool2o`0001Wooooo
0ol00004ooooo`;o00001?ooool5o`0000Wooooo0ol00015ooooo`007?ooool00ol0003ooooooooo
o`1<ooooo`Go00002?ooool4o`0001Wooooo0ol00002ooooo`Go00000ooooolJo`0000;ooooo0_l0
0006ooooo`;o00002?ooool2o`0000Gooooo0_l00002ooooo`;o00002?ooool3o`0001kooooo0_l0
000;ooooo`Co00002Oooool3o`0004Gooooo000Looooo`03o`000?oooooooooo04gooooo0_l00006
ooooo`;o00000_ooool2o`0000Gooooo0_l0000Dooooo`?o00000_ooool5o`0000Cooooo1?l00002
ooooo`oo000000?oooooo`000?l000000_l000000ooooooo0000o`00000@ooooo`;o00004oooool2
o`00087ooooo000Looooo`03o`000?oooooooooo04[ooooo0ol00005ooooo`;o000000?oooooo`00
0?l000002Oooool2o`0001;ooooo1?l000000ooooooo0000o`000002o`0000?ooooo0_l00002oooo
oa[o000000?oooooo`000?l000008_ooool2o`0000?ooooo0_l000000ooooooo0000o`00000Hoooo
o`;o00004Oooool2o`0000Gooooo0_l000000ooooooo0000o`000015ooooo`007?ooool00ol0003o
ooooooooo`1:ooooo`?o00001Oooool2o`0000Sooooo0_l00005ooooo`;o00003_ooool4o`0000;o
oooo1?l00003ooooo`;o00001Oooool:o`000003ooooool0003o000000_o00000oooool2o`00017o
oooo0_l000000ooooooo0000o`000009ooooo`;o00000oooool6o`0001Oooooo0ol0000>ooooo`Co
00001Oooool2o`000003ooooool0003o000004Gooooo000Looooo`03o`000?oooooooooo053ooooo
0_l0000:ooooo`Co00000oooool2o`0000kooooo1?l00006ooooo`;o00000_ooool2o`0000Gooooo
3ol000000ooooooo0000o`000006o`0000;ooooo0_l0000>ooooo`;o000000Coooooo`000?l0003o
oooo0_l0000?ooooo`;o000000?oooooo`000?l000006?ooool2o`0000cooooo1?l0001Aooooo`00
7?ooool00ol0003oooooooooo`1;ooooo`Oo00003?ooool2o`0001Cooooo1?l00003ooooo`Co0000
0_oooolOo`0001;ooooo0_l0000kooooo`;o00000oooool2o`0000[ooooo0_l00005ooooo`;o0000
@?ooool001cooooo00?o0000ooooooooool0Boooool5o`0002Cooooo1?l00003ooooo`?o00001Ooo
oolMo`0000Cooooo0_l0000Dooooo`;o00004_ooool2o`0001oooooo0_l0000?ooooo`;o00001Ooo
ool2o`00043ooooo000Looooo`03o`000?oooooooooo053ooooo0_l00009ooooo`;o00007?ooool5
o`0000Wooooo3ol00002ooooo`Wo00000oooool2o`0000Oooooo0_l0000;ooooo`?o00000_ooool2
o`0000gooooo0_l0000Zooooo`;o0000COooool001cooooo00?o0000ooooooooool0Boooool2o`00
0003ooooool0003o000000;o00000_ooool2o`0000;ooooo1Ol0000Looooo`;o000000?oooooo`00
0?l000001ooooolLo`0000Cooooo0_l000001?oooooo0000o`000?ooool4o`0000cooooo0_l00002
ooooo`;o00002?ooool2o`0000Cooooo0_l0000Hooooo`;o00001_ooool2o`0000;ooooo0_l00002
ooooo`?o00003?ooool2o`0003oooooo000Looooo`03o`000?oooooooooo03Gooooo0_l0000Doooo
o`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo1?l0000Hooooo`;o00003_ooool4o`00
0003ooooool0003o000001Ko00001?ooool2o`000004ooooool0003o0000ooooo`;o00001_ooool4
o`0001;ooooo0ol00002ooooo`?o00006?ooool2o`0000Gooooo0ol00002ooooo`;o00000_ooool3
o`0000cooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0eooooo`;o00003?ooool2o`00
01Gooooo0_l0000?ooooo`;o00001oooool4o`0000Gooooo0_l00005oooooaco00004oooool4o`00
00Sooooo0ol00005ooooo`;o000000?oooooo`000?l000000_ooool2o`0000kooooo0_l0000>oooo
o`Co00002?ooool2o`0000Wooooo0_l00012ooooo`007?ooool2o`0004Cooooo0_l0000Eooooo`;o
00001?ooool3o`0000Sooooo1?l000000ooooooo0000o`000003ooooo`?o00000_ooool2o`000004
ooooool0003o0000ooooo`;o00001?ooool4o`000003ooooool0003o000001?o00000oooool2o`00
00?ooooo0_l0000Eooooo`?o00000oooool5o`0000Kooooo0_l0000:ooooo`Co00002oooool2o`00
0003ooooool0003o000000Wooooo0ol00009ooooo`;o0000@_ooool001cooooo00?o0000oooooooo
ool0A?ooool2o`0000Cooooo0_l0000>ooooo`;o00001?ooool3o`0000;ooooo0_l00005ooooo`?o
000000?oooooo`000?l000002?ooool2o`0000Cooooo0_l00005ooooo`?o000000?oooooo`000?l0
00001_l000000ooooooo0000o`000007o`000003ooooool0003o000000?ooooo0_l00003ooooo`;o
00005_ooool2o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`;o00002_ooool2o`000003
ooooool0003o000000[ooooo0_l0000<ooooo`Co0000C?ooool001cooooo00?o0000ooooooooool0
A?ooool2o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l000003Oooool2o`0000?ooooo
0_l0000Aooooo`;o00000_ooool2o`0000gooooo5Ol0000eooooo`;o00002?ooool2o`0001Kooooo
0_l00002ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0Aoooool2o`0000Gooooo0_l0
00000ooooooo0000o`000007ooooo`;o000000?oooooo`000?l000001_ooool2o`00017ooooo0_l0
0002ooooo`;o00002?ooool2o`000003ooooool0003o000001Co0000<_ooool2o`0000;ooooo0_l0
0009ooooo`;o00001Oooool2o`0000gooooo0ol0001@ooooo`007?ooool00ol0003oooooooooo`17
ooooo`;o00002?ooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000006
ooooo`Co00003_ooool3o`0000;ooooo0_l00008ooooo`;o000000?oooooo`000?l000005?l0000C
ooooo`;o00004oooool2o`0000Kooooo1?l0000=ooooo`;o00001Oooool2o`0000?ooooo0_l00008
ooooo`;o00003?ooool2o`0004?ooooo000Looooo`03o`000?oooooooooo057ooooo0_l000000ooo
oooo0000o`00000Aooooo`Co00003?ooool3o`0000;ooooo0_l0000=oooooaCo00000_ooool2o`00
00Gooooo0_l00008ooooo`;o00002oooool2o`0000Kooooo0_l00006ooooo`;o00004oooool2o`00
00Kooooo0ol00002ooooo`;o00002oooool2o`0000?ooooo1?l00012ooooo`007?ooool00ol0003o
ooooooooo`1?ooooo`;o00001oooool2o`0000[ooooo0_l00003ooooo`;o000000?oooooo`000?l0
00006?ooool3o`000004ooooool0003o0000ooooo`co000000Goooooo`000?l0003o0000ooooo`02
o`000003ooooool0003o000000Gooooo0_l0000>ooooo`;o00001?ooool3o`0000oooooo1_l0000<
ooooo`Ko00001Oooool2o`0000;ooooo0_l00007ooooo`;o00000_ooool4o`000003ooooool0003o
000000;o0000@_ooool001cooooo00?o0000ooooooooool0?oooool2o`0000[ooooo0_l000001?oo
oooo0000o`000?l00007ooooo`;o00002?ooool4o`0000Kooooo0_l0000<ooooo`;o00002_ooool3
o`000003ooooool0003o000000;ooooo3_l00002ooooo`;o00005_ooool4o`0000?ooooo0ol00004
ooooo`Co00002?ooool6o`0000cooooo0_l00002ooooo`;o00001_ooool2o`0000[ooooo0_l00002
ooooo`Co00000_ooool3o`0004;ooooo000Looooo`03o`000?oooooooooo037ooooo0_l0000<oooo
o`;o00002_ooool2o`000004ooooool0003o0000o`0000_ooooo0_l00002ooooo`Co00003_ooool2
o`0000Kooooo0_l0000>ooooo`?o000000?oooooo`000?l000003?l000000ooooooo0000o`000003
ooooo`;o00001Oooool2o`0000Cooooo0_l00005ooooo`?o00001?ooool2o`0000;ooooo0_l00000
0ooooooo0000o`000002o`0001oooooo0_l00005ooooo`;o00001oooool2o`000003ooooool0003o
000000;ooooo0_l00003ooooo`?o0000@oooool001cooooo00?o0000ooooooooool0;_ooool2o`00
0003ooooool0003o000000?ooooo0_l0000=ooooo`;o000000Coooooo`000?l0003o00001Oooool2
o`0000[ooooo0_l00002ooooo`?o00003oooool2o`0000[ooooo0_l00004ooooo`;o00001Oooool<
o`0000;ooooo0_l00002ooooo`;o00000oooool3o`0000Cooooo0_l00004ooooo`;o000000?ooooo
o`000?l000000oooool2o`0000Sooooo0_l0000:ooooo`;o00002Oooool2o`0000gooooo0_l00008
ooooo`Co00000_ooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000002
o`0004Cooooo000Looooo`03o`000?oooooooooo02kooooo0_l00006ooooo`;o00003Oooool2o`00
0004ooooool0003o0000o`0000Gooooo0_l0000<ooooo`;o000000?oooooo`000?l000006oooool2
o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`co000000Coooooo`000?l0003o00000_oo
ool2o`0000Cooooo0_l0000=ooooo`;o000000Coooooo`000?l0003ooooo0_l00005ooooo`;o0000
2oooool3o`0000Oooooo1?l0000Gooooo`Co00002Oooool2o`000003ooooool0003o000000;o0000
A?ooool001cooooo00?o0000ooooooooool0?Oooool2o`000003ooooool0003o000000Kooooo0_l0
0004ooooo`Co00000oooool2o`0000Oooooo0_l0000Booooo`;o00002oooool3o`0000Gooooo0_l0
0005ooooo`Co00000oooool2o`000003ooooool0003o000000?ooooo0_l00007ooooo`;o00003Ooo
ool2o`000003ooooool0003o000000?o00000_ooool2o`0000_ooooo0_l00008ooooo`;o000000?o
ooooo`000?l000006oooool2o`0000Gooooo0_l000001?oooooo0000o`000?ooool2o`000003oooo
ool0003o0000047ooooo000Looooo`03o`000?oooooooooo03gooooo0_l000000ooooooo0000o`00
000<ooooo`?o000000Coooooo`000?l0003ooooo0_l00006ooooo`;o00001_ooool2o`0000_ooooo
0_l00006ooooo`Co000000Coooooo`000?l0003o00003?ooool4o`0000?ooooo0_l0000<ooooo`;o
000000?oooooo`000?l000004_ooool3o`0000Oooooo0_l0000@ooooo`;o000000Coooooo`000?l0
003ooooo0_l00004ooooo`;o000000?oooooo`000?l000003oooool2o`0000?ooooo1?l000000ooo
oooo0000o`000004ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0@oooool2o`0000go
oooo0_l00007ooooo`Co00001_ooool2o`0000?ooooo0_l0000>ooooo`Co000000?oooooo`000?l0
00000_ooool4o`0000Kooooo1Ol0000Aooooo`;o000000?oooooo`000?l000002oooool2o`0000oo
oooo0_l0000@ooooo`;o00000_ooool4o`0000Cooooo0_l000000ooooooo0000o`00000Booooo`Co
0000C?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@
413oooooooooo`04ooooo`03o`000?oooooooooo04?ooooo0_l0000@ooooo`;o00001?ooool2o`00
00gooooo0_l00008ooooo`;o00001_ooool2o`0000Gooooo1?l00006ooooo`Go00000oooool3o`00
00kooooo0ol0000:ooooo`;o00005oooool2o`0000cooooo0_l0000Mooooo`;o00000_ooool2o`00
00;ooooo1Ol00002ooooo`;o0000?oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0mooooo`;o00001_ooool2
o`0000kooooo1?l0000Kooooo`;o00003Oooool4o`0000gooooo1?l000000ooooooo0000o`000004
ooooo`;o00001_ooool4o`0001Kooooo1?l00007ooooo`;o00003?ooool2o`0000Oooooo0_l00003
ooooo`;o00004oooool3o`000003ooooool0003o000000?o00000_ooool2o`0003oooooo00000ooo
oooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006ooooo`03o`000?oooooooooo
03gooooo0_l000000ooooooo0000o`000003ooooo`;o00004?ooool2o`000003ooooool0003o0000
00?ooooo0_l0000Pooooo`Co00001?ooool4o`0000Oooooo1?l000000ooooooo0000o`000002o`00
00;ooooo1?l00004ooooo`Co00002_ooool2o`0000[ooooo1?l000000ooooooo0000o`00000Koooo
o`;o00000oooool2o`0000cooooo0_l00005ooooo`?o00000_ooool2o`0000[ooooo0_l0000ioooo
o`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`00
00Oooooo0ol0000Xooooo`;o00002_ooool2o`0000[ooooo0_l0000;ooooo`;o00002?ooool2o`00
0003ooooool0003o000000Go00003oooool2o`000003ooooool0003o000000?ooooo1?l00005oooo
o`Co00001?ooool4o`000004ooooool0003o0000o`0000Gooooo0_l00002ooooo`?o00001?ooool3
o`00013ooooo1Ol00006ooooo`?o00000_ooool4o`0000Sooooo0_l000000ooooooo0000o`000002
ooooo`;o00003oooool2o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l000001_ooool2
o`0000;ooooo0_l0000:ooooo`;o0000>Oooool00003ooooool0003ooooo00;ooooo00?o0000oooo
ooooool02Oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo02Sooooo0_l00000
0ooooooo0000o`000007ooooo`;o00000_ooool2o`0001?ooooo0_l0000=ooooo`?o00004Oooool2
o`000003ooooool0003o000000?ooooo1?l00006ooooo`Go00001oooool5o`0000;ooooo0_l0000;
ooooo`;o00000_ooool2o`0000cooooo0_l000000ooooooo0000o`000006ooooo`?o00000_ooool4
o`0000Oooooo0ol000000ooooooo0000o`000002ooooo`;o00000oooool2o`0000kooooo0_l00002
ooooo`;o000000Coooooo`000?l0003ooooo0_l0000:ooooo`;o0000AOooool00003ooooool@413o
oooo00;ooooo00?o410@ooooooooool02_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooo
oooo02_ooooo0_l0000;ooooo`;o00000_ooool2o`0000gooooo0_l0000?ooooo`;o000000?ooooo
o`000?l000001_ooool2o`0000_ooooo0_l0000>ooooo`?o00002_ooool2o`0000;ooooo0_l00007
ooooo`;o000000?oooooo`000?l000000oooool2o`0000Gooooo0_l0000Booooo`;o00000_ooool6
o`000004ooooool0003o0000ooooo`Co00002Oooool4o`0000kooooo1?l00005ooooo`;o0000D?oo
ool00006oooooomgMgOoV9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`00
0?oooooooooo03Sooooo1_l0000:ooooo`;o000000Coooooo`000?l0003o00001_ooool2o`0000Ko
oooo0_l000000ooooooo0000o`000002o`0000;ooooo1?l0000;ooooo`;o000000?oooooo`000?l0
00000_l0000Dooooo`;o00000oooool2o`000003ooooool0003o000000;o000000?oooooo`000?l0
00000_l000000ooooooo0000o`000008ooooo`Co00000oooool2o`0000[ooooo0_l000001Ooooooo
0000o`000?l0003ooooo00Ko000000?oooooo`000?l000000_l000001?oooooo0000o`000?ooool2
o`0000Oooooo0ol00008ooooo`;o00001?ooool2o`0000Oooooo0_l0001@ooooo`0000Koooooonk^
k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0>_oo
ool2o`0000cooooo1_l000001?oooooo0000o`000?l00002ooooo`;o00002oooool2o`000004oooo
ool0003o0000o`0000Cooooo0_l00003ooooo`?o00001?ooool4o`0000cooooo0_l00006ooooo`Co
000000Coooooo`000?l0003ooooo1?l000001?oooooo0000o`000?l0000<ooooo`Co00000oooool3
o`0000Wooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l00002ooooo`Oo00000_ooool2
o`0000[ooooo0_l00003ooooo`;o000000?oooooo`000?l000003Oooool2o`0001Gooooo0_l0000i
ooooo`007?ooool00ol0003oooooooooo`0looooo`Co00002?ooool4o`0000?ooooo0ol00007oooo
o`;o00002Oooool2o`0000Gooooo0_l00003ooooo`?o00000_ooool2o`00013ooooo1Ol00004oooo
o`Co00002Oooool2o`0001Cooooo0_l00002ooooo`;o00000_ooool2o`0000Gooooo1Ol00002oooo
o`Wo00002_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000Kooooo0ol00007oooo
o`;o00004?ooool3o`0000;ooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`0looooo`Co
000000?oooooo`000?l000001Oooool2o`0000Gooooo0_l00008ooooo`;o00001?ooool2o`0000;o
oooo0_l0000@ooooo`;o00004_ooool3o`0000Cooooo1?l00009ooooo`;o00001?ooool2o`0000?o
oooo0_l0000;ooooo`[o000000Coooooo`000?l0003ooooo2?l00003ooooo`?o00000oooool2o`00
00Kooooo1?l00003ooooo`;o00000oooool2o`0000;ooooo1?l00003ooooo`;o00003?ooool4o`00
00?ooooo1?l000000ooooooo0000o`00000jooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o
00000_ooool2o`0000;ooooo0_l00009ooooo`;o00001Oooool2o`0000?ooooo0_l000000ooooooo
0000o`00000=ooooo`;o00000_ooool2o`0000Wooooo1?l00009ooooo`;o00002?ooool2o`0000;o
oooo0_l00005ooooo`;o00004Oooool2o`0000?ooooo1?l00006ooooo`Go00000_ooool3o`000003
ooooool0003o000000Co00000_ooool4o`000003ooooool0003o000000_o00000oooool2o`0000;o
oooo0_l00008ooooo`;o00000_ooool2o`0000Gooooo0_l00004ooooo`;o00001Oooool5o`0000?o
oooo0_l00003ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0;_ooool2o`0000;ooooo
0_l00002ooooo`;o00005Oooool2o`000003ooooool0003o000000Oooooo1?l0000<ooooo`;o0000
00?oooooo`000?l000001_l00007ooooo`;o00002?ooool2o`0000Gooooo0_l00002ooooo`Co0000
2Oooool2o`0000_ooooo0_l00006ooooo`Co00000_ooool;o`0000;ooooo1?l000000ooooooo0000
o`000003o`000003ooooool0003o000000Go00000_ooool4o`0001cooooo0_l00005ooooo`;o0000
Aoooool001cooooo00?o0000ooooooooool0=?ooool2o`0001?ooooo0_l0000>ooooo`Co00002_oo
ool7o`0000;ooooo1_l0000?ooooo`;o00001?ooool3o`0000?ooooo1?l00005ooooo`Oo00004ooo
ool3o`000005ooooool0003o0000o`000?ooool01ol00003ooooo`;o000000?oooooo`000?l00000
2_l000001?oooooo0000o`000?ooool4o`00017ooooo0_l0000>ooooo`;o0000BOooool001cooooo
00?o0000ooooooooool0=?ooool2o`0001?ooooo0_l0000;ooooo`;o00000oooool3o`0000;ooooo
0_l00002ooooo`;o000000Goooooo`000?l0003o0000ooooo`07o`000003ooooool0003o000000;o
000000?oooooo`000?l000000_l00002ooooo`;o00002oooool2o`0000Cooooo1?l00005ooooo`Co
000000Coooooo`000?l0003o00000oooool2o`0000Kooooo0_l00006ooooo`;o00000_ooool2o`00
00?ooooo2_l000000ooooooo0000o`000008o`0000;ooooo0ol000000ooooooo0000o`000003o`00
013ooooo0_l00009ooooo`;o00000oooool2o`0000?ooooo0_l00002ooooo`;o0000@?ooool001co
oooo00?o0000ooooooooool0AOooool2o`0000oooooo0_l00004ooooo`;o00000_ooool3o`000004
ooooool0003o0000ooooo`[o000000?oooooo`000?l000000ol000000ooooooo0000o`000002o`00
00;ooooo0_l0000Aooooo`Co00002_ooool3o`0000?ooooo0_l00004ooooo`Ko00001?ooool5o`00
00Cooooo5?l000000ooooooo0000o`000003o`000003ooooool0003o000000Go00003Oooool2o`00
00[ooooo0_l00008ooooo`;o00000_ooool2o`0000Cooooo0_l0000jooooo`007?ooool00ol0003o
ooooooooo`15ooooo`;o00004oooool2o`0000Gooooo0_l000000ooooooo0000o`000002ooooo`ko
00000oooool5o`0001oooooo1?l00003ooooo`;o00001Oooool2o`0000;ooooo0_l00004ooooo`Go
00001OoooolIo`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000002_ooool2o`0000;o
oooo0_l00003ooooo`;o00005Oooool2o`0003[ooooo000Looooo`03o`000?oooooooooo03Oooooo
0_l00009ooooo`?o00002_ooool4o`0000Oooooo0ol000000ooooooo0000o`000004oooooaKo0000
00Coooooo`000?l0003o00006_ooool2o`0000?ooooo0_l00005ooooo`;o00003oooool3o`000003
ooooool0003o000000?o000000?oooooo`000?l000004ol000001?oooooo0000o`000?l00002oooo
o`;o00001Oooool2o`0000kooooo0_l00003ooooo`;o00001oooool2o`0000[ooooo1?l0000joooo
o`007?ooool00ol0003oooooooooo`0^ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Go
oooo0_l00002ooooo`?o00002_ooool4o`000004ooooool0003o0000ooooo`;o00000_ooool2o`00
0004ooooool0003o0000ooooo`;o000000?oooooo`000?l000005Ol000000ooooooo0000o`00000?
ooooo`;o00002Oooool2o`000003ooooool0003o000000kooooo0_l00002ooooo`Co00000oooool2
o`000003ooooool0003o000001So00000oooool2o`0000Kooooo0_l0000Oooooo`;o000000?ooooo
o`000?l000001_ooool3o`0003cooooo000Looooo`03o`000?oooooooooo02kooooo0_l000000ooo
oooo0000o`000004ooooo`;o00001?ooool3o`000004ooooool0003o0000o`0000?ooooo0_l00006
ooooo`Co000000Coooooo`000?l0003ooooo0_l00008ooooo`;o000000?oooooo`000?l000006?l0
000:ooooo`;o00000oooool2o`0000cooooo0ol0000<ooooo`?o00000_ooool9o`000003ooooool0
003o0000023o00000oooool2o`0000Sooooo0_l0000Cooooo`;o00000oooool2o`000003ooooool0
003o000000?ooooo1Ol0000jooooo`007?ooool2o`0003Sooooo0_l00003ooooo`?o00000_ooool3
o`0000?ooooo0_l00007ooooo`;o00000_ooool2o`0000cooooo6ol0000;ooooo`;o00001oooool2
o`0000Gooooo0_l00002ooooo`;o00003?ooool2o`0000?ooooo0_l00002ooooo`?o000000Cooooo
o`000?l0003ooooo1Ol000000ooooooo0000o`00000Io`0000;ooooo0ol000000ooooooo0000o`00
0005ooooo`Co00001?ooool2o`0000_ooooo0_l00003ooooo`;o000000?oooooo`000?l000001_oo
ool2o`0003[ooooo000Looooo`03o`000?oooooooooo03cooooo0_l0000Aooooo`?o00000oooool5
o`0000Sooooo6Ol00005ooooo`;o00001Oooool2o`0000Sooooo0_l00004ooooo`?o00001Oooool2
o`0000;ooooo0_l0000:ooooo`;o000000Coooooo`000?l0003o00000_oooolTo`0000;ooooo0_l0
0002ooooo`;o00001oooool2o`0000Cooooo0_l0000Cooooo`;o0000@_ooool001cooooo00?o0000
ooooooooool0??ooool2o`00017ooooo0_l00004ooooo`Go00001_oooolLo`0000;ooooo1?l00005
ooooo`;o00001Oooool2o`0000Oooooo0_l00006ooooo`;o00000_ooool2o`0000;ooooo0_l00000
0ooooooo0000o`000006ooooo`;o000000?oooooo`000?l000009_l00004ooooo`;o00000oooool2
o`00013ooooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o00005oooool2o`00
00oooooo0_l00007ooooo`oo000000?oooooo`000?l000002_l00002ooooo`;o00002_ooool2o`00
00;ooooo0_l0000Gooooo`;o000000?oooooo`000?l000001_ooool2o`000003ooooool0003o0000
01So000000?oooooo`000?l000002ol000001?oooooo0000o`000?ooool9o`0000kooooo1?l00006
ooooo`;o0000AOooool001cooooo00?o0000ooooooooool0:_ooool5o`0001Cooooo0_l000000ooo
oooo0000o`000005ooooo`;o00001oooool2o`000004ooooool0003o0000o`0000Cooooo3Ol00000
0ooooooo0000o`00000=o`0000_ooooo1?l000000ooooooo0000o`00000Pooooo`Co000000?ooooo
o`000?l00000:_l000000ooooooo0000o`000004o`000004ooooool0003o0000o`0000gooooo1?l0
0006ooooo`;o0000AOooool001cooooo00?o0000ooooooooool0:_ooool4o`0001;ooooo0_l00000
0ooooooo0000o`000008ooooo`;o00001oooool2o`000004ooooool0003o0000o`0000;ooooo7ol0
0003ooooo`;o00001?ooool5o`0000;ooooo0_l0000Pooooo`Co000000?oooooo`000?l000008Ol0
00000ooooooo0000o`000005o`0000;ooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo0_l0
00000ooooooo0000o`000006ooooo`;o00002?ooool2o`0004Gooooo000Looooo`03o`000?oooooo
oooo033ooooo1?l00007ooooo`;o00000oooool2o`0000;ooooo0_l00009ooooo`;o00002?ooool2
o`0000;ooooo7ol00004ooooo`;o00001?ooool4o`0001Cooooo0_l00003ooooo`;o00000oooool4
o`000005ooooool0003o0000o`000?ooool00_l00004ooooo`ko000000Coooooo`000?l0003ooooo
5_l00002ooooo`;o00001_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000@ooooo`;o0000
AOooool001cooooo00?o0000ooooooooool08_ooool2o`0000?ooooo0_l000000ooooooo0000o`00
0004ooooo`Co000000?oooooo`000?l000000oooool3o`0000Kooooo0ol00009ooooo`;o00001?oo
ool2o`0000Gooooo8Ol00003ooooo`;o00004Oooool2o`0000Cooooo0_l00003ooooo`?o000000Co
ooooo`000?l0003o00000oooool4o`000005ooooool0003o0000o`000?ooool0;?l000000ooooooo
0000o`00000Jooooo`;o00003oooool2o`0003cooooo000Looooo`03o`000?oooooooooo02;ooooo
0_l00003ooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo0ol00003ooooo`;o0000
1oooool2o`00013ooooo0_l00005ooooo`;o000000?oooooo`000?l000007?l00003ooooo`;o0000
4Oooool2o`0000;ooooo1?l00004ooooo`;o000000?oooooo`000?l000003?ooool;o`000003oooo
ool0003o000001ko000000?oooooo`000?l000000ol0000Gooooo`?o00001oooool2o`0000;ooooo
0_l00002ooooo`?o0000>oooool001cooooo00?o0000ooooooooool0;oooool2o`0000?ooooo0_l0
0002ooooo`;o00002_ooool2o`0000Cooooo0_l00009ooooo`;o00001?ooool3o`000003ooooool0
003o000000Co000000?oooooo`000?l000004Ol00007ooooo`;o00005Oooool2o`0000oooooo0_l0
0006ooooo`?o000000?oooooo`000?l000004Ol000000ooooooo0000o`000008o`000003ooooool0
003o000000Oo000000?oooooo`000?l000000ol0000Fooooo`?o00002?ooool2o`0000;ooooo0ol0
0002ooooo`;o0000>oooool001cooooo00?o0000ooooooooool07Oooool2o`0001Wooooo0_l0000:
ooooo`?o00000oooool2o`0000Wooooo0ol00003ooooo`?o00000_oooolKo`0000Oooooo0_l0000E
ooooo`;o00003Oooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`00000/
o`0000Wooooo0_l0000=ooooo`;o00003_ooool2o`0003oooooo000Looooo`03o`000?oooooooooo
01gooooo0_l0000>ooooo`;o00005_ooool3o`0000gooooo1Ol000001?oooooo0000o`000?l00002
oooooaGo000000?oooooo`000?l000000ol00003ooooo`;o00000_ooool3o`0001Cooooo0_l00009
ooooo`?o00001?ooool6o`000003ooooool0003o000001Go000000?oooooo`000?l000001?l00000
0ooooooo0000o`00000@o`0000Kooooo0_l0000Eooooo`;o00000_ooool4o`00047ooooo000Loooo
o`03o`000?oooooooooo02gooooo0_l0000Fooooo`?o00003_ooool4o`000003ooooool0003o0000
00Cooooo6Ol00004ooooo`;o00000oooool2o`000003ooooool0003o000000Oooooo0_l0000Aoooo
o`Go00000oooool2o`000003ooooool0003o000000;o00000_oooolYo`0000?ooooo1?l00004oooo
o`;o00002Oooool2o`0000Cooooo0_l00005ooooo`?o00000_ooool4o`0000?ooooo0_l0000loooo
o`007?ooool00ol0003oooooooooo`0iooooo`;o00006oooool2o`0000Wooooo6Ol00004ooooo`;o
00001_ooool2o`0000Oooooo0_l000000ooooooo0000o`000002o`0000cooooo0ol000000ooooooo
0000o`000002ooooo`So000000?oooooo`000?l000009Ol00002ooooo`;o00000_ooool5o`0000;o
oooo0_l00006ooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo1ol00008ooooo`;o
0000??ooool001cooooo00?o0000ooooooooool0>Oooool2o`0000gooooo0_l00006ooooo`Co0000
0_ooool3o`0000Gooooo0_l000000ooooooo0000o`000008o`000003ooooool0003o000000Go0000
00?oooooo`000?l000000_l00002ooooo`;o00003Oooool2o`0000Oooooo1?l00005ooooo`;o0000
2Oooool2o`0000;ooooo2?l00002oooooa3o000000?oooooo`000?l000004ol00002ooooo`;o0000
00?oooooo`000?l000001?l0000:ooooo`;o00002oooool3o`0000;ooooo0_l00002ooooo`;o0000
@_ooool001cooooo00?o0000ooooooooool0;?ooool2o`0000Oooooo0_l0000Aooooo`;o00001_oo
ool4o`0000;ooooo1?l00003ooooo`?o00000oooool<o`000004ooooool0003o0000o`0000Oooooo
0_l00004ooooo`;o00001_ooool3o`0000Oooooo0_l00007ooooo`;o00003oooool4o`0000?ooooo
4Ol000000ooooooo0000o`00000Go`000004ooooool0003o0000o`0001gooooo2?l00012ooooo`00
7?ooool2o`0002gooooo0_l00007ooooo`;o00007Oooool2o`000004ooooool0003o0000o`0000?o
oooo0_l00005ooooo`_o000000?oooooo`000?l000003_ooool2o`0000Kooooo0_l0000Mooooo`Co
000000?oooooo`000?l000000_l000000ooooooo0000o`000004o`000003ooooool0003o000000Wo
00000_ooool2o`000003ooooool0003o000001Ko00000oooool2o`0000gooooo0ol00006ooooo`;o
00000_ooool3o`000003ooooool0003o000000;ooooo0_l00010ooooo`007?ooool00ol0003ooooo
ooooo`0gooooo`;o00000_ooool2o`0000Sooooo0_l0000=ooooo`;o000000Coooooo`000?l0003o
00001oooool2o`000003ooooool0003o000000Wo000000?oooooo`000?l000003oooool2o`0000Go
oooo0_l00005ooooo`;o00000oooool2o`0000kooooo0_l000000ooooooo0000o`000002o`0000?o
oooo0_l000000ooooooo0000o`000002ooooo`[o000000?oooooo`000?l000001ol000000ooooooo
0000o`000003o`000003ooooool0003o000000_o000000?oooooo`000?l000000oooool2o`0000go
oooo0ol00002ooooo`;o00000_ooool2o`0000Kooooo0_l000001?oooooo0000o`000?l00010oooo
o`007?ooool00ol0003oooooooooo`0Vooooo`;o00002_ooool2o`0000?ooooo0_l00002ooooo`;o
00002?ooool2o`0000_ooooo1_l00007ooooo`Co00001Oooool2o`0000?ooooo0_l000000ooooooo
0000o`000002ooooo`;o00000_ooool2o`0000Oooooo0_l00005ooooo`;o00001Oooool2o`0000?o
oooo0_l0000>ooooo`;o00000oooool2o`0000?ooooo1Ol000000ooooooo0000o`00000Xo`0001Go
oooo0_l00002ooooo`;o00003Oooool2o`0001oooooo0_l0000Pooooo`007?ooool00ol0003ooooo
ooooo`0Uooooo`Co00002Oooool2o`0001kooooo1_l000000ooooooo0000o`000002ooooo`Co0000
3?ooool5o`0000;ooooo0_l00002ooooo`;o00003Oooool2o`0000Kooooo0_l00002ooooo`;o0000
1?ooool2o`0000Kooooo0ol0000<ooooo`;o00000_oooolOo`000003ooooool0003o000000So0000
1Oooool2o`0000_ooooo0_l00006ooooo`;o00002?ooool4o`00027ooooo0_l0000Pooooo`007?oo
ool00ol0003oooooooooo`0Uooooo`Co00006oooool2o`0001?ooooo0_l00002ooooo`?o00000ooo
ool2o`0000Wooooo0_l0000Dooooo`;o000000?oooooo`000?l000002?ooool4o`0000Cooooo0_l0
0006ooooo`?o00000oooool2o`0000cooooo7_l000000ooooooo0000o`000003o`000003ooooool0
003o000000;o00000oooool4o`0000_ooooo0_l00006ooooo`;o00002?ooool4o`0004?ooooo000L
ooooo`03o`000?oooooooooo037ooooo0_l00005ooooo`;o00002?ooool4o`0000gooooo0_l00008
ooooo`Co00000_ooool2o`0000;ooooo0_l00004ooooo`;o00001oooool2o`0000cooooo0_l00008
ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Gooooo0_l00009ooooo`;o00000oooool2
o`0000Oooooo0ol000000ooooooo0000o`00000To`0000;ooooo0ol0000?ooooo`;o00001oooool2
o`0000kooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00001Oooool2o`00
00?ooooo0_l00003ooooo`;o00003oooool2o`0000Sooooo1Ol00005ooooo`?o00000oooool2o`00
0003ooooool0003o000000;o00000_ooool2o`00017ooooo0_l00002ooooo`?o000000?oooooo`00
0?l000000_ooool2o`0000?ooooo1?l00003ooooo`;o00001?ooool2o`0000?ooooo0ol00007oooo
obGo00000_ooool2o`0000?ooooo0_l0000:ooooo`;o00000oooool2o`0000Oooooo0_l000000ooo
oooo0000o`000002ooooo`;o00001oooool2o`0003_ooooo000Looooo`03o`000?oooooooooo03go
oooo0_l0000@ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`;o00000_ooool2o`0000Ko
oooo0ol00005ooooo`Go00000oooool2o`0000oooooo0_l00002ooooo`;o00001Oooool3o`0000;o
oooo0ol00005ooooo`;o00001?ooool2o`0000Cooooo0_l00006ooooob;o00001_ooool2o`0000oo
oooo0ol000000ooooooo0000o`000002o`0000?ooooo0_l00004ooooo`;o00000_ooool4o`0004;o
oooo000Looooo`03o`000?oooooooooo03?ooooo0_l00002ooooo`Co000000?oooooo`000?l00000
4Oooool2o`0000;ooooo0ol00002ooooo`;o00000_ooool2o`0000;ooooo0_l00004ooooo`;o0000
00?oooooo`000?l000002?ooool2o`000003ooooool0003o000000;o00002_ooool2o`0000Wooooo
0_l00003ooooo`;o00000oooool2o`0000gooooo0_l00006ooooo`?o00000_ooool6o`000003oooo
ool0003o000000Co000000?oooooo`000?l000004?l000000ooooooo0000o`000002ooooo`;o0000
4Oooool9o`0000?ooooo1?l00008ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0<ooo
ool2o`0000;ooooo1?l000000ooooooo0000o`000004ooooo`;o00003oooool3o`0000Cooooo0_l0
0004ooooo`;o00001?ooool2o`0000Gooooo0_l00007ooooo`;o00003?ooool2o`0000;ooooo0_l0
0005ooooo`;o00003oooool2o`0000Kooooo1?l00004ooooo`?o00001?ooool2o`0000;ooooo1ol0
00000ooooooo0000o`00000:o`000003ooooool0003o000000Ko00000_ooool2o`000003ooooool0
003o000000kooooo1Ol00009ooooo`;o00001_ooool2o`0000Cooooo0_l00002ooooo`;o0000>_oo
ool001cooooo00?o0000ooooooooool0@_ooool2o`00013ooooo0_l00004ooooo`;o00002_ooool9
o`0000cooooo0_l0000;ooooo`;o00003?ooool2o`0000Sooooo1?l00006ooooo`;o00002oooool2
o`0000;ooooo4_l00008ooooo`;o00001_ooool2o`0001Cooooo0_l00003ooooo`;o00001?ooool2
o`0000?ooooo0_l00004ooooo`;o00000_ooool2o`0003[ooooo000Looooo`03o`000?oooooooooo
04_ooooo0_l00007ooooo`;o00003?ooool2o`0000Cooooo1ol000000ooooooo0000o`000009oooo
o`;o00003_ooool2o`0000Wooooo0_l00009ooooo`Ko00003_ooool5o`000003ooooool0003o0000
00[o000000?oooooo`000?l000001?l000000ooooooo0000o`000002o`000003ooooool0003o0000
00;ooooo0_l00004ooooo`;o00004_ooool3o`0000;ooooo1?l00003ooooo`;o0000BOooool001co
oooo00?o0000ooooooooool0<_ooool3o`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l0
00002?ooool2o`0000?ooooo0_l00002ooooo`;o00002?ooool3o`000003ooooool0003o000000Wo
oooo1Ol0000?ooooo`;o00000_ooool2o`0000Cooooo0ol00003ooooo`;o00002Oooool2o`0000;o
oooo0ol000001?oooooo0000o`000?l0000;ooooo`;o000000Coooooo`000?l0003ooooo3ol00000
1?oooooo0000o`000?ooool3o`000003ooooool0003o000000Wo00001?ooool2o`0000cooooo0_l0
0002ooooo`Ko000000?oooooo`000?l000000_l0000@ooooo`;o0000??ooool001cooooo00?o0000
ooooooooool0<_ooool3o`0000Gooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00002Ooo
ool2o`000005ooooool0003o0000o`000?ooool00_l00007ooooo`Co00000oooool2o`0000Kooooo
1?l00009ooooo`;o00001_ooool2o`0000;ooooo0_l00005ooooo`;o00000oooool2o`0000Wooooo
0_l00002ooooo`;o00002oooool2o`0000?ooooo0ol000000ooooooo0000o`000002ooooo`Co0000
00?oooooo`000?l000001_l000001?oooooo0000o`000?ooool2o`0000;ooooo1Ol000000ooooooo
0000o`000002o`0000Gooooo0_l00007ooooo`;o00000_ooool3o`0000;ooooo1_l0000Eooooo`;o
0000??ooool001cooooo00?o0000ooooooooool0=oooool2o`0000Gooooo0_l000000ooooooo0000
o`000003o`0000Oooooo0_l00002ooooo`;o000000?oooooo`000?l000001oooool2o`0000Gooooo
1?l00004ooooo`;o00002Oooool4o`0000cooooo0_l0000Kooooo`;o00000oooool2o`000004oooo
ool0003o0000o`0000Cooooo1Ol00004ooooo`?o00000_ooool5o`000005ooooool0003o0000o`00
0?ooool00_l000000ooooooo0000o`000004o`0000Kooooo0ol000000ooooooo0000o`000007oooo
o`;o000000?oooooo`000?l000000ol000000ooooooo0000o`000002o`0000;ooooo0ol00002oooo
o`;o00001Oooool3o`0004Cooooo000Looooo`03o`000?oooooooooo02;ooooo0_l0000Cooooo`;o
00000oooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0001gooooo0_l0000:oooo
o`;o00000oooool3o`0000Gooooo0ol00005ooooo`;o00002_ooool2o`0000;ooooo0_l00005oooo
o`Co00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000007ooooo`;o00001Oooool4o`00
0004ooooool0003o0000ooooo`;o000000?oooooo`000?l000000ol00002ooooo`;o000000Gooooo
o`000?l0003o0000ooooo`02o`0000?ooooo0ol0000=ooooo`;o000000Coooooo`000?l0003ooooo
1Ol000000ooooooo0000o`000002o`000003ooooool0003o000000Gooooo0ol00014ooooo`007?oo
ool2o`0002?ooooo0_l0000Gooooo`?o00002Oooool2o`0001gooooo0_l000000ooooooo0000o`00
0007ooooo`;o00001?ooool2o`0000;ooooo0_l000001?oooooo0000o`000?l0000Aooooo`;o0000
0_ooool2o`0000Gooooo1?l00002ooooo`;o00005?ooool6o`0000Oooooo1Ol00003ooooo`Go0000
00Coooooo`000?l0003ooooo0_l00007ooooo`;o00001oooool4o`0000;ooooo0_l000000ooooooo
0000o`000003ooooo`;o00001_ooool2o`0004Oooooo000Looooo`03o`000?oooooooooo03_ooooo
0_l00005ooooo`Co00003_ooool3o`0000Gooooo0_l00006ooooo`;o00000oooool2o`0000gooooo
0_l00002ooooo`;o00002Oooool2o`0001oooooo0_l0000?ooooo`?o00002?ooool2o`0000Wooooo
1Ol00004ooooo`;o00000_ooool2o`0000?ooooo0_l00005ooooo`So00002_ooool2o`000004oooo
ool0003o0000ooooo`Co0000AOooool001cooooo00?o0000ooooooooool0>?ooool3o`0000?ooooo
2?l0000>ooooo`?o00000_ooool2o`000003ooooool0003o000000;o00001?ooool2o`0000Oooooo
0_l00003ooooo`;o00001?ooool2o`000003ooooool0003o000000;o00000oooool2o`0000?ooooo
0ol000000ooooooo0000o`00000Aooooo`;o00002?ooool2o`0000Cooooo0_l00004ooooo`;o0000
00?oooooo`000?l000000_l00004ooooo`;o00000oooool2o`0000;ooooo0_l000001?oooooo0000
o`000?l00004ooooo`Co00000oooool2o`000003ooooool0003o000000Kooooo0_l00002ooooo`;o
00001?ooool2o`0000Kooooo0_l00002ooooo`Go00000oooool2o`000003ooooool0003o000004;o
oooo000Looooo`03o`000?oooooooooo02gooooo0_l00009ooooo`?o00000_ooool5o`0000[ooooo
0_l000000ooooooo0000o`000008ooooo`;o000000?oooooo`000?l000000_l00009ooooo`;o0000
0_ooool4o`000003ooooool0003o000000?ooooo0_l00002ooooo`Co00000oooool2o`0000Cooooo
0_l000000ooooooo0000o`000002o`0000Oooooo0ol00005ooooo`;o00002?ooool2o`0000Cooooo
1?l00002ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o00001oooool2o`000004oooo
ool0003o0000o`0000Gooooo0ol00003ooooo`Co00001?ooool2o`000003ooooool0003o000000;o
oooo1?l0000:ooooo`Co000000?oooooo`000?l000002?ooool2o`0004;ooooo000Looooo`03o`00
0?oooooooooo02gooooo0_l0000>ooooo`;o00003Oooool5o`0000Wooooo1?l0000;ooooo`;o0000
0_ooool4o`0000;ooooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo0_l0000;ooooo`?o0000
1_ooool3o`0000Cooooo1?l00007ooooo`;o00001_ooool2o`0000kooooo0_l0000:ooooo`;o0000
3Oooool2o`0000Cooooo0ol00006ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Gooooo
0ol0000;ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0C_ooool2o`0000Gooooo1?l0
00000ooooooo0000o`000002o`000003ooooool0003o000000Sooooo0_l00002ooooo`;o00001?oo
ool2o`0000;ooooo1_l00003ooooo`;o00002oooool5o`0000Cooooo0_l000000ooooooo0000o`00
0002ooooo`Co00006Oooool2o`0000Cooooo0_l000001?oooooo0000o`000?l0000Looooo`;o0000
2Oooool3o`000003ooooool0003o000000Kooooo0ol0000:ooooo`Co0000?oooool001cooooo00?o
0000ooooooooool09_ooool2o`0000Gooooo0_l0000@ooooo`;o00004?ooool8o`000004ooooool0
003o0000o`0000;ooooo0_l00008ooooo`;o00001oooool3o`0000;ooooo1?l0000=ooooo`;o0000
1?ooool4o`0000Oooooo0_l000000ooooooo0000o`000002o`0000;ooooo0ol00005ooooo`;o0000
1Oooool2o`0000Oooooo0_l00004ooooo`Ko00005_ooool2o`00013ooooo0_l0000:ooooo`;o0000
1_ooool2o`0000;ooooo1?l0000oooooo`007?ooool00ol0003oooooooooo`0Vooooo`;o00001Ooo
ool2o`0000Wooooo1?l00003ooooo`;o00004?ooool4o`0000?ooooo0_l0000?ooooo`;o00000_oo
ool2o`0000?ooooo0ol00007ooooo`?o00002Oooool2o`0000Cooooo0_l00006ooooo`;o00001?oo
ool2o`0000Cooooo0ol00005ooooo`;o00000_ooool5o`0000Oooooo0_l00004ooooo`Co00001Ooo
ool2o`0000Cooooo0_l00006ooooo`;o00000oooool2o`0000Cooooo1?l00008ooooo`;o00001Ooo
ool2o`0000_ooooo0_l00002ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0>?ooool4
o`0000?ooooo0_l00005ooooo`;o00004?ooool2o`0000Cooooo0_l0000=ooooo`;o00001?ooool2
o`0000Gooooo1Ol00002ooooo`;o000000?oooooo`000?l000002_ooool2o`0000Cooooo0_l00003
ooooo`;o00003Oooool2o`0000;ooooo0ol00008ooooo`;o000000?oooooo`000?l000001?ooool2
o`0000Cooooo0ol00003ooooo`?o00001_ooool2o`0000?ooooo0_l00004ooooo`Oo00001Oooool2
o`0000;ooooo0_l000000ooooooo0000o`00001Booooo`007?ooool00ol0003oooooooooo`16oooo
o`Co00001?ooool2o`0000Kooooo0_l00005ooooo`Co000000?oooooo`000?l000001Oooool2o`00
00oooooo0_l00005ooooo`Go00002_ooool2o`0000Cooooo0_l00003ooooo`;o00002Oooool2o`00
00;ooooo0_l0000=ooooo`;o000000?oooooo`000?l000000_l00008ooooo`;o00001?ooool2o`00
00Cooooo0_l00004ooooo`Co00001Oooool2o`000004ooooool0003o0000o`0000?ooooo0_l00004
ooooo`;o00001?ooool2o`0000kooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`11oooo
o`;o00001Oooool2o`0000Cooooo0_l00002ooooo`;o00000_ooool2o`0000Gooooo1?l000000ooo
oooo0000o`000002o`0000?ooooo0ol0000Eooooo`?o00004_ooool2o`0000_ooooo0_l000000ooo
oooo0000o`000002ooooo`;o000000?oooooo`000?l000003oooool2o`0000_ooooo0_l000000ooo
oooo0000o`000002o`0000;ooooo0_l00004ooooo`?o00001_ooool2o`0000Oooooo0_l00007oooo
o`;o000000?oooooo`000?l000001_ooool2o`0000Kooooo0_l0000oooooo`007?ooool00ol0003o
ooooooooo`11ooooo`;o00002Oooool2o`0000Cooooo0_l00002ooooo`;o00003?ooool2o`0000?o
oooo0ol00005ooooo`;o00000oooool6o`0000;ooooo0_l00006ooooo`;o00002oooool2o`000003
ooooool0003o000000Cooooo0_l00005ooooo`;o00001Oooool6o`0000;ooooo0_l0000Gooooo`;o
00000oooool2o`00027ooooo1?l00009ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0
>_ooool2o`0000Gooooo0_l00009ooooo`;o00002?ooool2o`0000Cooooo0_l0000;ooooo`Co0000
1?ooool4o`000003ooooool0003o000000Co00000_ooool2o`000003ooooool0003o000000;o0000
00?oooooo`000?l000000_l00009ooooo`;o00000_ooool2o`0000;ooooo1_l00007ooooo`;o0000
00Coooooo`000?l0003ooooo0_l00002ooooo`;o00006oooool2o`0000Cooooo0_l000000ooooooo
0000o`00000;ooooo`?o00002oooool2o`000003ooooool0003o000000Sooooo0_l00004ooooo`;o
0000@Oooool001cooooo00?o0000ooooooooool0>_ooool2o`0000Gooooo0_l0000?ooooo`;o0000
2?ooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool4o`0000Kooooo0_l00009ooooo`;o0000
00?oooooo`000?l000001ol0000=ooooo`;o00000_ooool6o`0000Oooooo0_l0000>ooooo`Co0000
4?ooool2o`000004ooooool0003o0000ooooo`;o000000Coooooo`000?l0003ooooo0_l0000;oooo
o`?o00001Oooool2o`0000Oooooo0_l00004ooooo`So00000_ooool2o`0001[ooooo0_l0000Uoooo
o`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0>_ooool2o`0001Kooooo0_l00003ooooo`;o00001ooo
ool2o`0000?ooooo0_l0000Aooooo`;o00000_ooool>o`0001;ooooo0_l0000Cooooo`;o00001?oo
ool5o`0000[ooooo0_l00004ooooo`;o000000?oooooo`000?l000001?l0000=ooooo`Co00001ooo
ool2o`0000gooooo2?l00004ooooo`;o00006?ooool2o`0002Gooooo00001_ooooooMgMgoiRHV?oo
ooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003o
ooooooooo`1=ooooo`;o000000?oooooo`000?l000001Oooool2o`0001gooooo6_l0000?ooooo`;o
00001_ooool2o`0000Cooooo0_l00002ooooo`;o00001?ooool3o`0000_ooooo0ol00007ooooo`Ko
00000oooool6o`0000Cooooo1Ol0000Fooooo`;o00000_ooool2o`0000Gooooo0_l0000oooooo`00
00?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`0kooooo`;o00004?ooool2o`000003ooooool0003o000000Co
oooo0_l00006ooooo`;o00005_oooolJo`0000oooooo0_l00006ooooo`;o00001?ooool2o`0000So
oooo0ol00006ooooo`;o00000oooool3o`0000Cooooo0_l00003ooooo`;o00000oooool9o`0000Ko
oooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0ol0000>ooooo`;o000000?oooooo`00
0?l00000@oooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003o
V9RHoooooonHV9So8B4Q00Kooooo0ol0000kooooo`;o00000oooool2o`0000Sooooo0_l0000:oooo
o`;o00001_ooool4o`0000Kooooo0_l0000<oooooaGo00000oooool4o`0000Sooooo0_l00007oooo
o`;o00002oooool2o`0000Gooooo0_l00007ooooo`;o00000_ooool4o`0000;ooooo1?l00003oooo
o`;o00000oooool2o`0000Gooooo0_l00008ooooo`?o000000?oooooo`000?l000000oooool3o`00
017ooooo0_l00013ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05
o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0eooooo`;o00002Oooool4o`00
00Kooooo0_l00003ooooo`?o00003Oooool3o`0000Kooooo0_l00004ooooo`;o000000?oooooo`00
0?l000000ooooolCo`0000;ooooo0ol000001?oooooo0000o`000?l00008ooooo`;o00001_ooool3
o`0000_ooooo0_l00005ooooo`Co00001Oooool2o`0000;ooooo0_l00004ooooo`;o00001Oooool2
o`000003ooooool0003o0000017ooooo0_l0000<ooooo`;o00001oooool2o`0004Wooooo00000ooo
oooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0
003oooooooooo`0eooooo`;o00000_ooool2o`000003ooooool0003o000000Cooooo0_l0000;oooo
o`?o000000?oooooo`000?l000002_ooool2o`0000gooooo0_l000001?oooooo0000o`000?l00002
oooooaSo00001?ooool2o`0000kooooo1?l0000<ooooo`;o00000oooool4o`0000Gooooo0_l00005
ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000002?ooool2
o`0000cooooo0_l00004ooooo`?o00001_ooool4o`0004Oooooo00001_ooooooMgMgoiRHV?oooooo
V9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0booooo`;o00001?oo
ool3o`000003ooooool0003o000000;ooooo0ol00002ooooo`;o00001?ooool2o`0000Gooooo0ol0
000Dooooo`;o00000_ooool2o`0000;ooooo7Ol00004ooooo`;o00003_ooool4o`0000;ooooo0_l0
0008ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000Gooooo
0_l00003ooooo`;o00000_ooool2o`0000Cooooo0ol00007ooooo`?o00000_ooool2o`0000Sooooo
0_l00005ooooo`;o00002?ooool2o`00013ooooo0_l0000eooooo`0000Koooooonk^k_lb<S;o0000
oc8b<_o^k^h<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0<_ooool2o`00
00?ooooo0ol00006ooooo`?o00000_ooool4o`0000;ooooo0_l00005ooooo`?o000000?oooooo`00
0?l000004Oooool2o`0000;ooooo0_l00003ooooo`co000000?oooooo`000?l000001?l00002oooo
o`So00003_ooool2o`0000?ooooo0_l00004ooooo`;o00000oooool2o`0000Gooooo1?l00004oooo
o`;o00006?ooool2o`0000Sooooo0ol00002ooooo`;o00006_ooool2o`0000oooooo0_l0000eoooo
o`007?ooool00ol0003oooooooooo`0gooooo`;o00000oooool2o`0000;ooooo0_l000000ooooooo
0000o`000002ooooo`Co00002oooool4o`0000Sooooo0_l0000=oooooako00001?ooool2o`0000So
oooo0_l00004ooooo`;o00002?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o
00000_ooool2o`0001?ooooo0_l0000=ooooo`?o00003?ooool2o`0000Kooooo0_l00008ooooo`;o
0000A_ooool001cooooo00?o0000ooooooooool0??ooool2o`0000Gooooo0_l000001?oooooo0000
o`000?ooool2o`0000gooooo0_l00006ooooo`Ko00002_oooolOo`0000Cooooo0_l0000>ooooo`;o
000000Coooooo`000?l0003ooooo0_l00006ooooo`;o00000oooool4o`0000;ooooo0_l00002oooo
o`;o00000oooool2o`0000[ooooo0_l0000=ooooo`;o00000oooool3o`0000Oooooo0_l00002oooo
o`;o00000_ooool2o`0000Kooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`0looooo`?o
000000?oooooo`000?l000001?ooool3o`0000Oooooo0_l0000>ooooo`Ko00000_ooool2o`0000Ko
oooo1_l000000ooooooo0000o`00000Ao`000003ooooool0003o000000?o000000?oooooo`000?l0
00001?ooool2o`0000Sooooo1?l000001?oooooo0000o`000?ooool2o`0000_ooooo0ol00007oooo
o`;o00000oooool2o`0000Wooooo0_l000000ooooooo0000o`00000@ooooo`Oo00001oooool2o`00
0003ooooool0003o000000Oooooo0_l0000<ooooo`;o0000>_ooool001cooooo00?o0000oooooooo
ool0??ooool3o`000003ooooool0003o000000Gooooo0_l00002ooooo`;o00000_ooool3o`0000go
oooo1_l00003ooooo`;o00001ooooolOo`000003ooooool0003o000000Cooooo0_l00004ooooo`Ko
00002Oooool2o`0000Oooooo1?l0000Booooo`;o00000oooool2o`000003ooooool0003o000001;o
oooo1Ol00003ooooo`;o00001Oooool4o`0001?ooooo0_l0000jooooo`007?ooool00ol0003ooooo
ooooo`0mooooo`;o00000oooool4o`0000?ooooo1?l00002ooooo`;o00003_ooool3o`0000;ooooo
0_l00004ooooo`;o00001?ooool5o`000003ooooool0003o000001Wo00002?ooool2o`0000;ooooo
1_l00009ooooo`?o00001_ooool2o`000003ooooool0003o0000017ooooo0_l0000:ooooo`;o0000
2Oooool2o`0000?ooooo0_l00006ooooo`;o00001oooool2o`0000Cooooo0_l0000?ooooo`;o0000
>?ooool001cooooo00?o0000ooooooooool0@?ooool8o`000003ooooool0003o000000cooooo0ol0
000:ooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l00000
7?l00005ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Sooooo1_l00005ooooo`Go0000
5?ooool2o`0000Kooooo0_l000001?oooooo0000o`000?l00005ooooo`;o00005?ooool2o`0000Co
oooo0_l0000?ooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0@?ooool2o`0000Cooooo
0_l00006ooooo`;o00001oooool3o`0001?ooooo0_l00004ooooo`So000000?oooooo`000?l00000
5?l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000Cooooo0_l0000:ooooo`;o
00000_ooool3o`000004ooooool0003o0000ooooo`Go00003?ooool2o`0000Kooooo0_l00009oooo
o`Co00008?ooool2o`0000Gooooo1?l00010ooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o
00005?ooool2o`0000gooooo7ol000000ooooooo0000o`00000:ooooo`;o00002_ooool2o`0000;o
oooo2Ol000000ooooooo0000o`00000<ooooo`;o00002_ooool2o`0000?ooooo0_l00002ooooo`;o
00002?ooool3o`0000Oooooo0_l0000<ooooo`;o00001Oooool4o`00043ooooo000Looooo`03o`00
0?oooooooooo04kooooo0_l0000Dooooo`;o00002_ooool3o`000003ooooool0003o000001co0000
1_ooool2o`00017ooooo3_l0000:ooooo`;o000000?oooooo`000?l000002_ooool3o`000003oooo
ool0003o000000;o00000oooool2o`000003ooooool0003o000000Cooooo0ol00003ooooo`;o0000
0_ooool2o`0005Oooooo000Looooo`03o`000?oooooooooo04_ooooo0_l0000Aooooo`;o00001ooo
ool2o`0000Oooooo7ol00004ooooo`;o00000oooool2o`0000Wooooo0_l00005ooooo`[o000000?o
ooooo`000?l000000_l0000:ooooo`;o000000?oooooo`000?l000000oooool2o`0000;ooooo0_l0
00000ooooooo0000o`000002ooooo`;o00001Oooool7o`0000Gooooo0_l000000ooooooo0000o`00
0002o`0000oooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o00003_ooool2
o`000003ooooool0003o000000Gooooo1?l0000:oooooa_o00001Oooool4o`000003ooooool0003o
000000Kooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000003Ol0000B
ooooo`;o00000_ooool4o`0000;ooooo0_l00008ooooo`;o000000?oooooo`000?l000000oooool4
o`0000?ooooo0_l0000?ooooo`;o0000B?ooool001cooooo0_l0000oooooo`?o00002Oooool2o`00
0003ooooool0003o000000Sooooo0_l00002ooooo`;o00002?ooool2o`0000Kooooo0_l00003oooo
oa7o000000?oooooo`000?l000002Ol00004ooooo`Co000000?oooooo`000?l000001_oooolIo`00
00Sooooo0_l00008ooooo`;o00000oooool3o`0000;ooooo0ol00007ooooo`;o00001_ooool4o`00
00;ooooo1Ol000000ooooooo0000o`00001Dooooo`007?ooool00ol0003oooooooooo`0nooooo`?o
00000_ooool2o`0000Gooooo0_l000000ooooooo0000o`000008ooooo`;o00002?ooool2o`0000So
oooo1?l00003oooooa7o000000?oooooo`000?l000002Ol00006ooooo`;o00001oooool2o`000004
ooooool0003o0000oooooaWo00001?ooool2o`0000Kooooo1?l000000ooooooo0000o`000005oooo
o`?o00001?ooool2o`000003ooooool0003o000000cooooo1Ol000001?oooooo0000o`000?ooool2
o`00057ooooo000Looooo`03o`000?oooooooooo04?ooooo0_l0000>ooooo`;o00002?ooool2o`00
00;ooooo0_l00008ooooo`Co00000_ooool2o`0000;ooooo4_l000000ooooooo0000o`000004o`00
00Oooooo0_l00003ooooo`;o00000_ooool2o`0000Cooooo6Ol0000;ooooo`Go000000?oooooo`00
0?l000001Oooool3o`0000Cooooo0_l00003ooooo`?o00002oooool2o`0000Gooooo0_l00002oooo
o`;o0000COooool001cooooo00?o0000ooooooooool0AOooool2o`0000cooooo0_l00008ooooo`?o
00001Oooool2o`0000Kooooo0_l00002ooooo`;o00000oooool3o`000003ooooool0003o000001?o
00001_ooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool3o`000003ooooool0003o000001;o
00003Oooool3o`000003ooooool0003o000000Oooooo0ol00004ooooo`;o00000oooool4o`0000_o
oooo0_l00002ooooo`;o00001?ooool3o`0004gooooo000Looooo`03o`000?oooooooooo043ooooo
0_l00003ooooo`;o00003Oooool2o`0000Sooooo0_l00005ooooo`;o00004?ooool2o`000003oooo
ool0003o000000ko000000?oooooo`000?l000000_l00006ooooo`;o00001oooool3o`000003oooo
ool0003o000000;o000000?oooooo`000?l000000_l00002ooooo`ko00003?ooool2o`0000_ooooo
0_l00005ooooo`Co000000?oooooo`000?l000000_l00002ooooo`;o00002oooool2o`0000;ooooo
1?l0001>ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00000oooool2o`0000;ooooo0_l0
0003ooooo`;o00001?ooool2o`0001;ooooo1Ol0000<oooooa;o00002_ooool2o`0000Kooooo7_l0
000Dooooo`Ko00002?ooool2o`0000?ooooo0_l00002ooooo`;o00003oooool3o`0004oooooo000L
ooooo`03o`000?oooooooooo04;ooooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool2
o`0000Kooooo1Ol00007ooooo`;o000000Coooooo`000?l0003ooooo1Ol0000:ooooo`Co00000ooo
ool5o`000003ooooool0003o000000;ooooo0ol0000@ooooo`Go000000Goooooo`000?l0003o0000
ooooo`0Go`0001?ooooo1_l00006ooooo`;o00000oooool2o`0000;ooooo1?l0000:ooooo`;o0000
0oooool2o`00053ooooo000Looooo`03o`000?oooooooooo04;ooooo0_l0000Booooo`Go00001ooo
ool2o`000003ooooool0003o000000Wooooo0_l00005ooooo`?o00001oooool2o`0001Sooooo1Ol0
0006oooooaKo00005_ooool2o`0000Oooooo0_l00003ooooo`;o00000_ooool4o`0000[ooooo0_l0
0003ooooo`;o0000D?ooool001cooooo00?o0000ooooooooool0Boooool2o`0000cooooo1?l00006
ooooo`;o00002oooool2o`0000oooooo0_l0000Dooooo`;o00001Oooool2o`0000;ooooo0_l00002
oooooaKo00002oooool2o`0000Sooooo0_l0000Eooooo`;o00000oooool6o`0000Gooooo0ol0000?
ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0Boooool2o`0000Kooooo0ol00003oooo
o`Co00001_ooool2o`00033ooooo1Ol00002ooooo`So00000_oooolFo`0000Cooooo0_l00005oooo
o`;o00002?ooool4o`0001?ooooo0_l00003ooooo`Ko00001Oooool3o`0000oooooo0_l0000moooo
o`007?ooool00ol0003oooooooooo`1@ooooo`;o000000Coooooo`000?l0003o00005Oooool2o`00
02Sooooo0_l000001?oooooo0000o`000?ooool7o`0000Cooooo5?l00006ooooo`;o00004Oooool2
o`0000Wooooo0_l0000>ooooo`;o000000Coooooo`000?l0003ooooo0ol0001Booooo`007?ooool0
0ol0003oooooooooo`1@ooooo`;o00005?ooool2o`0000?ooooo0_l0000^ooooo`;o00002Oooool6
o`000003ooooool0003o000000[o00009Oooool4o`0000oooooo0_l000001?oooooo0000o`000?l0
001Booooo`007?ooool00ol0003oooooooooo`17ooooo`;o00007Oooool2o`0000gooooo0_l0000P
ooooo`;o00003Oooool6o`000003ooooool0003o000000_o00001?ooool2o`00023ooooo0_l0000:
ooooo`;o00001_ooool4o`00057ooooo000Looooo`03o`000?oooooooooo03?ooooo0_l0000Boooo
o`;o00002?ooool2o`0001;ooooo0_l0000>ooooo`;o00002?ooool2o`0000[ooooo1?l00008oooo
o`;o00001?ooool2o`0000Oooooo5?l00004ooooo`;o00006Oooool2o`0000_ooooo0ol00003oooo
o`;o00001oooool3o`00057ooooo000Looooo`03o`000?oooooooooo03?ooooo0_l0000Kooooo`?o
00004_ooool5o`0000Gooooo0_l00009ooooo`;o00000oooool2o`0000Gooooo0_l00003ooooo`Go
00003Oooool2o`0000;ooooo0_l00003oooooaCo00000oooool2o`0001;ooooo0_l00006ooooo`;o
00002oooool3o`0000Wooooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o0000
5?ooool4o`0000Gooooo0ol000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l00000
2_ooool5o`0000?ooooo0ol0000@ooooo`;o00001?oooolAo`0000Cooooo0ol0000Booooo`Co0000
1Oooool2o`0000Cooooo0_l0000;ooooo`;o00000oooool2o`000003ooooool0003o000005;ooooo
000Looooo`;o0000D_ooool2o`0000Gooooo0_l000000ooooooo0000o`00000Cooooo`;o000000Go
ooooo`000?l0003o0000ooooo`02o`0000kooooo1?l00002ooooo`Co00000_ooool2o`0000oooooo
0_l00003oooooa3o00000oooool2o`0000;ooooo0_l0000Aooooo`;o00000oooool4o`0000Cooooo
0_l0000;ooooo`?o000000?oooooo`000?l000000_ooool2o`0005;ooooo000Looooo`03o`000?oo
oooooooo057ooooo0_l00005ooooo`;o000000?oooooo`000?l000003Oooool3o`0000Kooooo0ol0
0005ooooo`;o00002Oooool2o`000003ooooool0003o000000Co00001?ooool2o`0000?ooooo0_l0
000:ooooo`;o000000Coooooo`000?l0003ooooo1?l000000ooooooo0000o`000008o`0000Oooooo
0_l0000Dooooo`Oo00004Oooool2o`000004ooooool0003o0000ooooo`;o0000Doooool001cooooo
00?o0000ooooooooool0D_ooool2o`0000Kooooo0_l00005ooooo`;o00001?ooool8o`0000cooooo
0_l00006ooooo`Go000000?oooooo`000?l000000ol0000:ooooo`?o00002Oooool2o`000004oooo
ool0003o0000ooooo`co00008?ooool2o`000003ooooool0003o000000;o00003Oooool2o`0000So
oooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`18ooooo`;o00001?ooool2o`0000;ooooo
0_l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00001?ooool3o`0000?o
oooo0_l00007ooooo`;o00002?ooool2o`000004ooooool0003o0000o`0001?ooooo0ol00004oooo
o`;o00000_ooool2o`0000Kooooo2?l0000fooooo`;o00002oooool4o`0004kooooo000Looooo`03
o`000?oooooooooo04Sooooo0ol00003ooooo`;o00000_ooool2o`0000?ooooo0_l00004ooooo`;o
00002?ooool2o`0000Kooooo0_l00005ooooo`Co00001_ooool4o`0000Wooooo0_l00002ooooo`;o
000000?oooooo`000?l000000oooool3o`0000Cooooo0_l0000<ooooo`;o00000_ooool2o`0000?o
oooo0_l000000ooooooo0000o`00000Cooooo`;o00001Oooool2o`0000?ooooo0_l00009ooooo`;o
00002?ooool2o`0000Gooooo1Ol0001=ooooo`007?ooool00ol0003oooooooooo`19ooooo`;o0000
00?oooooo`000?l000001?ooool2o`0000Kooooo0_l00008ooooo`Co00001oooool3o`0000?ooooo
0_l000000ooooooo0000o`000008ooooo`;o00002Oooool2o`0000;ooooo0_l000000ooooooo0000
o`00000Hooooo`Ko00000oooool2o`000003ooooool0003o000001?ooooo0_l00002ooooo`Oo0000
00Coooooo`000?l0003ooooo0_l00006ooooo`;o00000_ooool2o`0000;ooooo1_l00006ooooo`;o
0000COooool001cooooo00?o0000ooooooooool0C?ooool2o`0000cooooo0_l00008ooooo`Go0000
1oooool2o`0000?ooooo0ol00005ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Cooooo
0_l000000ooooooo0000o`00000=ooooo`;o00002oooool2o`000003ooooool0003o000000Oooooo
0_l0000=ooooo`;o00001_ooool4o`000003ooooool0003o000000Cooooo0_l00004ooooo`;o0000
0_ooool4o`0000;ooooo1_l0001Eooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00001ooo
ool2o`0001kooooo0_l00004ooooo`?o00000oooool5o`0000Gooooo0_l000000ooooooo0000o`00
0009ooooo`;o00005_ooool2o`0000_ooooo0_l000000ooooooo0000o`000002o`0000Gooooo0_l0
00000ooooooo0000o`00000:ooooo`;o00000_ooool2o`0001;ooooo0ol00002ooooo`Co00000_oo
ool2o`0005Wooooo000Looooo`03o`000?oooooooooo03kooooo0_l00007ooooo`;o00008_ooool5
o`0000?ooooo1Ol0000Pooooo`;o00006_ooool3o`0000Oooooo0ol0000>ooooo`;o00004_ooool2
o`0000[ooooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`1Eooooo`;o00005?ooool2o`00
00Oooooo1?l000001?oooooo0000o`000?l00003ooooo`;o00005oooool2o`0001[ooooo0_l00004
ooooo`;o00000_ooool2o`0000oooooo0_l00005ooooo`;o00005oooool2o`0005Sooooo000Loooo
o`03o`000?oooooooooo05Gooooo0_l00007ooooo`;o00004Oooool2o`0000Kooooo0ol00002oooo
o`?o00007Oooool2o`0000?ooooo0_l0000Eooooo`;o00003_ooool2o`0000?ooooo0_l00005oooo
o`;o000000?oooooo`000?l00000K_ooool001cooooo00?o0000ooooooooool0C?ooool2o`00013o
oooo0_l00003ooooo`;o00001?ooool2o`000003ooooool0003o000000?ooooo0_l00006ooooo`?o
000000Coooooo`000?l0003o00004oooool2o`0000Wooooo0_l00003ooooo`;o00008?ooool2o`00
00?ooooo0_l0000=ooooo`;o00002?ooool3o`0000Cooooo0_l0001Mooooo`007?ooool00ol0003o
ooooooooo`1<ooooo`;o00003Oooool2o`0000Kooooo0ol00003ooooo`Go00000_ooool2o`0000Oo
oooo0ol000000ooooooo0000o`00000;ooooo`;o00001oooool2o`0002Cooooo0_l0000:ooooo`;o
00006oooool6o`0000;ooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1Booooo`;o0000
1oooool2o`000003ooooool0003o000000Cooooo0_l00005ooooo`?o00000_ooool2o`0000;ooooo
0_l0000:ooooo`;o00001Oooool2o`000003ooooool0003o000001[ooooo0_l000000ooooooo0000
o`000004ooooo`;o00000oooool2o`0000?ooooo0_l00006ooooo`;o00007oooool2o`0000;ooooo
1?l0001Oooooo`007?ooool00ol0003oooooooooo`1Booooo`;o00001_ooool2o`0000;ooooo0_l0
0002ooooo`;o00002?ooool3o`0000Gooooo0ol00002ooooo`;o00001Oooool2o`0000Cooooo1?l0
0008ooooo`;o00004_ooool2o`000003ooooool0003o000000Cooooo0_l00003ooooo`;o00000_oo
ool5o`0000Cooooo0_l0000Rooooo`Go0000Goooool001cooooo00?o0000ooooooooool0D_ooool2
o`0000Cooooo1?l00006ooooo`;o00002?ooool3o`0000Gooooo1ol00007ooooo`;o00000_ooool4
o`0000Sooooo0_l0000<ooooo`;o00002?ooool2o`0000cooooo1Ol00002ooooo`;o00008oooool3
o`000003ooooool0003o000005oooooo000Looooo`;o0000D_ooool2o`000003ooooool0003o0000
00;ooooo0_l0000Booooo`;o00001_ooool2o`000003ooooool0003o000000Wooooo0_l0000:oooo
o`;o00004?ooool2o`0000Cooooo0_l00002ooooo`;o00000_ooool2o`0000Gooooo0_l00003oooo
o`Co000000?oooooo`000?l000001_ooool2o`0000_ooooo0_l00007ooooo`;o00001Oooool3o`00
0003ooooool0003o000005oooooo000Looooo`03o`000?oooooooooo057ooooo0_l000000ooooooo
0000o`00000Rooooo`;o00005?ooool2o`0001Kooooo0ol000000ooooooo0000o`000002ooooo`;o
00001Oooool2o`0000?ooooo1Ol00008ooooo`;o00000oooool2o`0000?ooooo0_l000000ooooooo
0000o`000007ooooo`;o0000J_ooool001cooooo00?o0000ooooooooool0H?ooool2o`0001Kooooo
0_l00009ooooo`;o00006_ooool2o`0000Kooooo0_l000000ooooooo0000o`000002ooooo`Co0000
0_ooool2o`0000Oooooo1?l0000;ooooo`;o00000oooool2o`0007Kooooo000Looooo`03o`000?oo
oooooooo063ooooo0_l0000Qooooo`;o00006_ooool2o`0000Kooooo0_l000000ooooooo0000o`00
0004ooooo`;o000000Coooooo`000?l0003o00000oooool2o`0000Cooooo0_l00002ooooo`;o0000
0oooool2o`0001?ooooo0ol0001Yooooo`007?ooool00ol0003oooooooooo`1`ooooo`;o00003Ooo
ool2o`0000;ooooo0_l0000Uooooo`;o00000_ooool2o`0000?ooooo0ol00003ooooo`;o00001?oo
ool2o`0000;ooooo0_l00003ooooo`;o00004oooool3o`0001Kooooo0_l0001Aooooo`007?ooool0
0ol0003oooooooooo`1Nooooo`;o00002?ooool2o`0000Kooooo0_l00002ooooo`;o00001Oooool2
o`0000;ooooo1_l0000?ooooo`;o00006?ooool2o`0000;ooooo0_l00003ooooo`;o00001Oooool3
o`0000Gooooo0_l0000^ooooo`;o0000DOooool001cooooo00?o0000ooooooooool0G_ooool2o`00
00Gooooo0_l000000ooooooo0000o`000004o`0000;ooooo0_l00002ooooo`;o00001Oooool2o`00
00Cooooo0_l0000<ooooo`;o000000?oooooo`000?l000000_l0000Kooooo`?o00000oooool3o`00
00Cooooo0_l00006ooooo`;o000000?oooooo`000?l000004Oooool2o`0006_ooooo000Looooo`03
o`000?oooooooooo06Gooooo0_l00003ooooo`Co00008Oooool2o`000003ooooool0003o000001go
oooo0_l00005ooooo`;o00002Oooool2o`000004ooooool0003o0000ooooo`;o00004Oooool2o`00
06_ooooo000Looooo`03o`000?oooooooooo06Kooooo0_l00004ooooo`Co00001_ooool2o`000005
ooooool0003o0000o`000?ooool00ol00005ooooo`;o00000_ooool2o`0001?ooooo0_l00006oooo
o`;o00004?ooool2o`0000Wooooo1Ol0000=ooooo`;o00002oooool2o`0006Gooooo000Looooo`03
o`000?oooooooooo05kooooo0_l00005ooooo`?o00001?ooool4o`0000?ooooo0_l000001?oooooo
0000o`000?ooool3o`000004ooooool0003o0000o`0000Gooooo0_l00002ooooo`;o00001_ooool2
o`0000Oooooo0_l00002ooooo`;o00001_ooool2o`0000oooooo1?l00002ooooo`;o00001Oooool3
o`0000Wooooo0ol00002ooooo`;o00002oooool2o`0006Gooooo000Looooo`03o`000?oooooooooo
05kooooo0_l00005ooooo`;o00000oooool3o`0000Kooooo0_l00004ooooo`;o00003Oooool2o`00
00Oooooo0_l00007ooooo`;o00005oooool2o`0000;ooooo1?l00002ooooo`;o00001Oooool2o`00
00[ooooo0ol00005ooooo`;o0000Koooool001cooooo00?o0000ooooooooool0J_ooool3o`0000?o
oooo0_l00002ooooo`;o00000oooool2o`0000gooooo0_l0000:ooooo`;o00005?ooool2o`0000Oo
oooo0_l00004ooooo`;o00001_ooool2o`0000Cooooo0_l00007ooooo`;o00001_ooool2o`0000;o
oooo0_l0001[ooooo`007?ooool00ol0003oooooooooo`1Wooooo`;o00001oooool2o`0000;ooooo
0_l00004ooooo`;o00001oooool2o`0000?ooooo0_l00007ooooo`;o000000?oooooo`000?l00000
4Oooool2o`000003ooooool0003o000000gooooo0_l00006ooooo`;o00001?ooool2o`0001?ooooo
0_l000000ooooooo0000o`00001Xooooo`007?ooool00ol0003oooooooooo`1Qooooo`;o00001?oo
ool2o`0000?ooooo0_l0000<ooooo`;o00000_ooool4o`000003ooooool0003o000000?ooooo0_l0
0007ooooo`;o00001_ooool2o`0000cooooo0_l000000ooooooo0000o`000004ooooo`;o0000;Ooo
ool3o`0006Oooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<
c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Qooooo`;o00002Oooool2o`0000co
oooo0_l00002ooooo`Co00001?ooool2o`0000kooooo0_l000000ooooooo0000o`00000Eooooo`;o
00003_ooool2o`0001Wooooo0_l00003ooooo`;o0000Ioooool00006oooooomgMgOoV9RHoooooonH
V9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooo
oooo07Cooooo0_l000001?oooooo0000o`000?ooool2o`0000Oooooo0_l000001?oooooo0000o`00
0?ooool2o`0000_ooooo0_l00007ooooo`Co00002oooool2o`000004ooooool0003o0000ooooo`;o
00002_ooool2o`0001;ooooo0ol00004ooooo`;o0000K?ooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool0M?ooool2o`000004ooooool0003o0000ooooo`;o00000oooool2o`0000;ooooo0_l000001?oo
oooo0000o`000?ooool2o`0001Cooooo1?l0000;ooooo`Go000000?oooooo`000?l000007_ooool3
o`0007;ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRH
V?ooooooV9RHoc8b<P06ooooo`?o0000J?ooool2o`0001;ooooo0_l000000ooooooo0000o`000002
ooooo`;o000000?oooooo`000?l000004oooool2o`00013ooooo1?l00003ooooo`;o00003oooool2
o`0000Kooooo0_l0001jooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09oooo
o`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`1Xooooo`;o00004_ooool2
o`0000Gooooo0_l000000ooooooo0000o`000005ooooo`;o00003?ooool2o`0000Kooooo0_l00008
ooooo`;o00000oooool2o`0000cooooo0ol00002ooooo`;o00001_ooool4o`0000Oooooo1_l0001[
ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooo
okZj^_l@41001_ooool00ol0003oooooooooo`24ooooo`Co00001Oooool2o`0000Gooooo0_l00005
ooooo`;o000000?oooooo`000?l000000oooool4o`0000_ooooo0_l0000<ooooo`?o000000?ooooo
o`000?l000001Oooool2o`000004ooooool0003o0000o`0000Oooooo1_l0001[ooooo`0000Kooooo
ogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003o
ooooooooo`1_ooooo`;o00003oooool2o`0000;ooooo0_l000000ooooooo0000o`000007ooooo`;o
00000_ooool2o`0000Gooooo1Ol00005ooooo`Co00003Oooool2o`000003ooooool0003o000000Go
oooo0_l000001?oooooo0000o`000?l00005ooooo`;o0000O?ooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0Kooo
ool2o`0000oooooo0ol00004ooooo`;o00001_ooool4o`0000Wooooo0_l00009ooooo`;o00000ooo
ool2o`0000Sooooo0_l000000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l000002_oo
ool3o`0000Gooooo0_l0001`ooooo`007?ooool00ol0003oooooooooo`1kooooo`;o00001?ooool2
o`0000Kooooo0_l00004ooooo`Co00000oooool2o`0000Oooooo1?l00008ooooo`?o00002_ooool2
o`0001Gooooo1?l00004ooooo`;o0000L?ooool001cooooo00?o0000ooooooooool0Noooool2o`00
00;ooooo0_l00008ooooo`;o00002oooool2o`0000Oooooo1?l00008ooooo`;o00002oooool2o`00
00Cooooo0_l0000Aooooo`;o0000M_ooool001cooooo00?o0000ooooooooool0Noooool2o`0000;o
oooo0_l00004ooooo`;o00000_ooool2o`0000?ooooo0_l0000Jooooo`?o00003oooool4o`0001?o
oooo0_l000000ooooooo0000o`00001aooooo`007?ooool00ol0003oooooooooo`1looooo`;o0000
1oooool2o`0000Oooooo0_l00003ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Cooooo
0_l00004ooooo`?o00003oooool2o`0001Gooooo0_l000000ooooooo0000o`00001aooooo`007?oo
ool00ol0003oooooooooo`1looooo`;o00005Oooool2o`000003ooooool0003o000000Cooooo1?l0
0004ooooo`;o00000oooool4o`0000kooooo0_l0002<ooooo`007?ooool00ol0003oooooooooo`20
ooooo`;o000000?oooooo`000?l000005oooool5o`000003ooooool0003o000000Gooooo1?l0000;
ooooo`;o000000?oooooo`000?l00000S?ooool001cooooo00?o0000ooooooooool0P?ooool2o`00
0003ooooool0003o000001Kooooo1_l000000ooooooo0000o`000005ooooo`;o00003Oooool2o`00
08oooooo000Looooo`03o`000?oooooooooo09Sooooo0_l000000ooooooo0000o`000004o`0000So
oooo0_l0000;ooooo`;o0000TOooool001cooooo00?o0000ooooooooool0P_ooool2o`0000cooooo
0_l00006ooooo`;o00000oooool5o`0000Gooooo0_l0000=ooooo`?o0000T?ooool001cooooo00?o
0000ooooooooool0P_ooool2o`0000Oooooo0_l00003ooooo`;o00002oooool2o`000003ooooool0
003o000000?ooooo1?l00004ooooo`;o00002?ooool2o`00093ooooo000Looooo`03o`000?oooooo
oooo08Oooooo0_l000001?oooooo0000o`000?l0000Hooooo`;o00001_ooool3o`0009Wooooo000L
ooooo`;o0000R?ooool2o`000003ooooool0003o000000cooooo0_l0000;ooooo`;o00001oooool2
o`0009Wooooo000Looooo`03o`000?oooooooooo08_ooooo0_l0000;ooooo`;o0000[oooool001co
oooo00?o0000ooooooooool0Roooool2o`0000Cooooo1?l00003ooooo`;o0000[oooool001cooooo
00?o0000ooooooooool0TOooool4o`0000;ooooo0_l0002`ooooo`007?ooool00ol0003ooooooooo
o`2<ooooo`;o00002Oooool2o`000;3ooooo000Looooo`03o`000?oooooooooo08cooooo0_l0000>
ooooo`;o0000Zoooool001cooooo00?o0000ooooooooool0W?ooool3o`000:[ooooo000Looooo`03
o`000?oooooooooo09gooooo0_l0000Rooooo`;o0000Q_ooool001cooooo00?o0000ooooooooool0
_oooool4o`0008Kooooo000Looooo`03o`000?oooooooooo0;oooooo0_l00028ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo08kooooo0_l0000Roooo
o`;o0000UOooool001cooooo00?o0000ooooooooool0S_ooool2o`0002;ooooo0_l0002Eooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001;ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood[o
oooo000Dooooo`03o`000?oooooooooo00Gooooo0ol0003ooooood[ooooo000Dooooo`03o`000?oo
oooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0
003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001;ooooo
00?oEEEEofIVI_l00000oooooomDooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00XOooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo01Kooooo1?l000002?l@
413ooooooooooonHV9So410@o`000?lb<S;oc<c<0oooool01?l@413o0000odA4A?o<c<`4ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0S?ooool00:;ooooo00Go0000ooooooooooooooooo`000009oooo
o`Ko00003?ooool00ol0003oooooooooo`02ooooo`05oa0@4?nj^[[oooooogMgMolb<S801Oooool0
0onHV9So410@omgMg@03ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40S?ooool00:;ooooo00Go0000
ooooooooooooooooo`00000Kooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?oo
ool00on7QhOoEEEEooooo`02ooooo`05o`000?ooooooooooooooool00000S?ooool00:;ooooo00Go
0000ooooooooooooooooo`000009ooooo`Ko00003?ooool00ol0003oooooooooo`05ooooo`03ojVY
ZOl@413ooooo00;ooooo00Goc<c<ob4Q8Ol0003oEEEEo`000003ooooo`05oc8b<_nHV9SooooooiRH
V?lb<S80S?ooool00:;ooooo00Go0000ohN7QoooooooZJVYo`00000Kooooo`03o`000?oooooooooo
00Cooooo00?o410@o`000?nj^[X00oooool01OlQ8B7oQhN7oooooonHV9So000000?ooooo00Goc<c<
o`000?l0003o0000olc<c02<ooooo`00XOooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooo
oooo01Wooooo00?o0000ooooooooool01Oooool00onj^[[o8B4Qooooo`02ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol@413o^[Zjoooooonj^[[o410@08cooooo0032ooooo`03o`000?oo
oooooooo00;ooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ob4Q8OnHV9SoooooogMgMomE
EED00oooool01Ol0003o^[Zjoooooonj^[[o000008cooooo0030ooooo`03oeEEEOmVIVKo000000Co
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05olc<c?l@413o0000oc8b<_o^k^h00oooool0
1OnYZJWo410@o`000?l@413oZJVY08cooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1404) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.52242 .31706 Mdot
.51826 .34363 Mdot
.37161 .60236 Mdot
.6326 .47576 Mdot
.5477 .79211 Mdot
.40763 .61646 Mdot
.32332 .46126 Mdot
.37509 .46236 Mdot
.367 .59542 Mdot
.41417 .36327 Mdot
.38956 .44021 Mdot
.60186 .4288 Mdot
.3527 .43808 Mdot
.65064 .50892 Mdot
.82712 .64873 Mdot
.5986 .55642 Mdot
.5216 .3183 Mdot
.55773 .63905 Mdot
.63654 .55406 Mdot
.42264 .61426 Mdot
.49009 .27575 Mdot
.64635 .50565 Mdot
.49184 .303 Mdot
.6507 .50945 Mdot
.6127 .48418 Mdot
.48395 .31093 Mdot
.45407 .3658 Mdot
.59162 .50207 Mdot
.60615 .53711 Mdot
.39064 .44977 Mdot
.61146 .63124 Mdot
.74089 .72765 Mdot
.63994 .57448 Mdot
.75156 .63901 Mdot
.33869 .45452 Mdot
.66315 .36511 Mdot
.39558 .6152 Mdot
.37784 .44246 Mdot
.37736 .43607 Mdot
.36457 .46693 Mdot
.37467 .45458 Mdot
.49695 .32234 Mdot
.38382 .26407 Mdot
.3413 .53874 Mdot
.56978 .49237 Mdot
.39483 .78976 Mdot
.59099 .39109 Mdot
.67009 .50547 Mdot
.47033 .35529 Mdot
.40062 .69174 Mdot
.2925 .52783 Mdot
.32216 .4426 Mdot
.41686 .59008 Mdot
.27382 .21017 Mdot
.34293 .43048 Mdot
.6334 .43999 Mdot
.38599 .60596 Mdot
.63188 .51307 Mdot
.64917 .51388 Mdot
.65423 .2741 Mdot
.60987 .45293 Mdot
.52957 .6607 Mdot
.50321 .37988 Mdot
.46095 .54342 Mdot
.38672 .59471 Mdot
.38138 .43327 Mdot
.50447 .35789 Mdot
.33966 .43692 Mdot
.58241 .57481 Mdot
.35285 .5744 Mdot
.67231 .49973 Mdot
.38796 .43973 Mdot
.47636 .28682 Mdot
.60375 .5219 Mdot
.3388 .69779 Mdot
.35689 .78036 Mdot
.49917 .71135 Mdot
.6566 .34395 Mdot
.64695 .26685 Mdot
.42505 .72492 Mdot
.57763 .50682 Mdot
.61933 .69039 Mdot
.35813 .7732 Mdot
.45769 .34925 Mdot
.6357 .56228 Mdot
.53318 .62003 Mdot
.60183 .5169 Mdot
.47315 .83239 Mdot
.6675 .46649 Mdot
.53195 .58578 Mdot
.35744 .60645 Mdot
.47402 .33761 Mdot
.62671 .47409 Mdot
.61845 .5367 Mdot
.69682 .29117 Mdot
.67639 .52292 Mdot
.63295 .49603 Mdot
.47353 .36402 Mdot
.32378 .43921 Mdot
.6411 .44673 Mdot
.40069 .54151 Mdot
.39097 .64299 Mdot
.60307 .46312 Mdot
.34928 .60701 Mdot
.46718 .30015 Mdot
.61877 .53602 Mdot
.36868 .43107 Mdot
.62137 .45964 Mdot
.24766 .38525 Mdot
.51863 .31673 Mdot
.59191 .52134 Mdot
.50953 .70388 Mdot
.58928 .26963 Mdot
.46714 .33935 Mdot
.35612 .52187 Mdot
.63522 .55238 Mdot
.62253 .50184 Mdot
.50115 .3618 Mdot
.37449 .64431 Mdot
.44517 .82184 Mdot
.477 .37011 Mdot
.39769 .44167 Mdot
.47642 .27937 Mdot
.63926 .42817 Mdot
.39124 .58923 Mdot
.34745 .53001 Mdot
.27927 .34974 Mdot
.64583 .63527 Mdot
.6045 .51561 Mdot
.39509 .27179 Mdot
.41086 .63748 Mdot
.48435 .34625 Mdot
.34301 .4396 Mdot
.67562 .55238 Mdot
.51093 .32345 Mdot
.38738 .42944 Mdot
.50122 .67731 Mdot
.25288 .48247 Mdot
.48983 .29091 Mdot
.49648 .43981 Mdot
.32796 .42268 Mdot
.333 .46064 Mdot
.82093 .48091 Mdot
.4964 .35727 Mdot
.53255 .68762 Mdot
.34471 .44703 Mdot
.68789 .60986 Mdot
.57191 .4817 Mdot
.60174 .67957 Mdot
.33489 .23604 Mdot
.75238 .61852 Mdot
.25474 .54653 Mdot
.51704 .69902 Mdot
.33062 .41429 Mdot
.62798 .48595 Mdot
.47565 .31337 Mdot
.48866 .30673 Mdot
.60918 .45346 Mdot
.60468 .47821 Mdot
.67453 .49276 Mdot
.66353 .5268 Mdot
.61316 .59588 Mdot
.68881 .50919 Mdot
.59114 .37721 Mdot
.47276 .33166 Mdot
.63411 .48034 Mdot
.40399 .58223 Mdot
.55688 .48351 Mdot
.38339 .44965 Mdot
.63695 .50775 Mdot
.62947 .47574 Mdot
.58352 .46397 Mdot
.32357 .4491 Mdot
.70569 .7575 Mdot
.5642 .27607 Mdot
.6845 .7556 Mdot
.51368 .52541 Mdot
.37666 .5723 Mdot
.60087 .50715 Mdot
.52934 .66915 Mdot
.72433 .38222 Mdot
.64551 .47289 Mdot
.11359 .5276 Mdot
.6411 .49811 Mdot
.59548 .79757 Mdot
.5455 .50962 Mdot
.71411 .71312 Mdot
.62672 .67154 Mdot
.6131 .49044 Mdot
.41253 .30741 Mdot
.31073 .45526 Mdot
.40437 .55796 Mdot
.36948 .45296 Mdot
.40907 .58671 Mdot
.37673 .60292 Mdot
.44657 .55829 Mdot
.60007 .42614 Mdot
.5588 .51541 Mdot
.67805 .48455 Mdot
.34034 .60647 Mdot
.47757 .38042 Mdot
.50312 .69948 Mdot
.52047 .35236 Mdot
.62861 .83149 Mdot
.31697 .68019 Mdot
.37848 .46999 Mdot
.49908 .66545 Mdot
.36616 .62918 Mdot
.35726 .59882 Mdot
.50766 .698 Mdot
.63503 .53248 Mdot
.49873 .35385 Mdot
.80322 .54374 Mdot
.22461 .42757 Mdot
.81256 .3293 Mdot
.46896 .35915 Mdot
.39728 .30136 Mdot
.38109 .45863 Mdot
.38655 .622 Mdot
.62501 .49996 Mdot
.62418 .52795 Mdot
.50306 .27556 Mdot
.67319 .50212 Mdot
.53002 .2728 Mdot
.61722 .49615 Mdot
.30214 .40983 Mdot
.51114 .71768 Mdot
.4475 .55968 Mdot
.68108 .63762 Mdot
.461 .32314 Mdot
.771 .36977 Mdot
.35726 .58969 Mdot
.72075 .37362 Mdot
.3772 .42678 Mdot
.50871 .66423 Mdot
.37592 .58072 Mdot
.51035 .70679 Mdot
.6811 .52721 Mdot
.41872 .60876 Mdot
.52859 .70526 Mdot
.5572 .61003 Mdot
.56311 .49912 Mdot
.20792 .38598 Mdot
.36086 .46542 Mdot
.52571 .33166 Mdot
.63454 .45825 Mdot
.35328 .58615 Mdot
.6859 .54784 Mdot
.26052 .61735 Mdot
.27558 .46335 Mdot
.41181 .63858 Mdot
.47184 .60408 Mdot
.5206 .65757 Mdot
.2903 .56828 Mdot
.39242 .28208 Mdot
.52019 .34316 Mdot
.68144 .51685 Mdot
.75127 .69544 Mdot
.34413 .44635 Mdot
.63599 .46158 Mdot
.54479 .75724 Mdot
.33231 .44457 Mdot
.62961 .5137 Mdot
.38252 .42101 Mdot
.48944 .30664 Mdot
.60739 .23846 Mdot
.49802 .36423 Mdot
.67477 .50833 Mdot
.35842 .42821 Mdot
.35805 .6391 Mdot
.4855 .31738 Mdot
.6474 .52914 Mdot
.59386 .50212 Mdot
.49042 .58572 Mdot
.6403 .48616 Mdot
.66763 .77672 Mdot
.61472 .4933 Mdot
.37505 .615 Mdot
.5776 .4917 Mdot
.50637 .20782 Mdot
.44032 .55344 Mdot
.50171 .35768 Mdot
.41265 .64081 Mdot
.37632 .59483 Mdot
.35008 .72631 Mdot
.36457 .40517 Mdot
.61157 .54732 Mdot
.3596 .57857 Mdot
.73579 .55952 Mdot
.34965 .41651 Mdot
.63011 .45199 Mdot
.46804 .42805 Mdot
.39201 .68589 Mdot
.4206 .59664 Mdot
.71339 .48649 Mdot
.47861 .29177 Mdot
.61935 .47318 Mdot
.35378 .60856 Mdot
.64422 .4225 Mdot
.59221 .5307 Mdot
.39607 .22184 Mdot
.48805 .59762 Mdot
.32662 .42742 Mdot
.55954 .46714 Mdot
.66328 .47632 Mdot
.416 .60697 Mdot
.46382 .31938 Mdot
.34384 .41675 Mdot
.49293 .31952 Mdot
.71865 .7006 Mdot
.21451 .38645 Mdot
.56335 .59977 Mdot
.51734 .71491 Mdot
.45972 .65103 Mdot
.72516 .70128 Mdot
.70899 .2707 Mdot
.78417 .43972 Mdot
.77732 .6203 Mdot
.35247 .6205 Mdot
.45733 .67926 Mdot
.38121 .59913 Mdot
.59261 .48604 Mdot
.39331 .59195 Mdot
.76258 .68607 Mdot
.62076 .49578 Mdot
.40008 .60104 Mdot
.74593 .33698 Mdot
.62178 .47628 Mdot
.51774 .34889 Mdot
.6212 .82017 Mdot
.56291 .18667 Mdot
.28006 .44973 Mdot
.3878 .63245 Mdot
.78482 .49802 Mdot
.63388 .49435 Mdot
.57814 .49196 Mdot
.4699 .32218 Mdot
.66676 .56372 Mdot
.54084 .66904 Mdot
.50284 .66085 Mdot
.35381 .48937 Mdot
.50532 .722 Mdot
.5619 .46371 Mdot
.48302 .31848 Mdot
.59577 .59076 Mdot
.36139 .71812 Mdot
.41221 .68754 Mdot
.36813 .47895 Mdot
.62085 .81929 Mdot
.52347 .38831 Mdot
.36342 .38216 Mdot
.33578 .65902 Mdot
.47617 .35378 Mdot
.73162 .74077 Mdot
.37134 .44958 Mdot
.19014 .41888 Mdot
.42115 .30724 Mdot
.63392 .53042 Mdot
.35134 .42014 Mdot
.70594 .50451 Mdot
.5811 .19275 Mdot
.17876 .49364 Mdot
.65484 .40913 Mdot
.65933 .4616 Mdot
.34105 .68706 Mdot
.63229 .50452 Mdot
.29668 .65988 Mdot
.6075 .49381 Mdot
.49164 .32456 Mdot
.41242 .36199 Mdot
.3441 .50826 Mdot
.53606 .26172 Mdot
.29031 .5889 Mdot
.52092 .7007 Mdot
.61652 .49895 Mdot
.63697 .52974 Mdot
.54574 .67588 Mdot
.48997 .29806 Mdot
.67564 .50086 Mdot
.76855 .35728 Mdot
.627 .5387 Mdot
.38036 .44901 Mdot
.45958 .24654 Mdot
.55371 .38823 Mdot
.6499 .54043 Mdot
.45317 .32783 Mdot
.36171 .47461 Mdot
.35992 .43033 Mdot
.54676 .48661 Mdot
.38974 .45836 Mdot
.64914 .49466 Mdot
.18093 .5245 Mdot
.49885 .29379 Mdot
.32918 .26021 Mdot
.50676 .33581 Mdot
.64267 .33166 Mdot
.32672 .44452 Mdot
.26529 .47521 Mdot
.70103 .48229 Mdot
.36835 .44621 Mdot
.45536 .28461 Mdot
.5757 .53173 Mdot
.56913 .52603 Mdot
.79753 .53148 Mdot
.36938 .61991 Mdot
.48528 .58578 Mdot
.39108 .44974 Mdot
.66178 .51249 Mdot
.65619 .54326 Mdot
.36321 .47352 Mdot
.19782 .48566 Mdot
.61821 .21781 Mdot
.61689 .49452 Mdot
.48744 .33342 Mdot
.48805 .34564 Mdot
.57395 .46442 Mdot
.60363 .46586 Mdot
.39055 .5825 Mdot
.37098 .64653 Mdot
.3874 .57011 Mdot
.48234 .59001 Mdot
.26828 .46283 Mdot
.49036 .80984 Mdot
.3637 .4669 Mdot
.37333 .32082 Mdot
.54082 .59673 Mdot
.67802 .47562 Mdot
.38862 .63569 Mdot
.66265 .47784 Mdot
.65023 .48421 Mdot
.38866 .40924 Mdot
.56371 .77739 Mdot
.48793 .39851 Mdot
.46251 .314 Mdot
.32122 .42486 Mdot
.5546 .46803 Mdot
.40307 .39602 Mdot
.51224 .66569 Mdot
.75681 .59022 Mdot
.38346 .43212 Mdot
.51264 .35683 Mdot
.35272 .46164 Mdot
.62128 .53083 Mdot
.68837 .47147 Mdot
.47988 .35435 Mdot
.53963 .66044 Mdot
.65289 .56801 Mdot
.62692 .51164 Mdot
.30339 .24975 Mdot
.72471 .60521 Mdot
.30083 .40142 Mdot
.61576 .49108 Mdot
.6231 .54441 Mdot
.54956 .6558 Mdot
.62625 .53765 Mdot
.66824 .47365 Mdot
.59569 .27896 Mdot
.29775 .35199 Mdot
.49281 .67427 Mdot
.18768 .5192 Mdot
.47121 .36052 Mdot
.74055 .71222 Mdot
.39941 .62873 Mdot
.35057 .49897 Mdot
.57979 .21077 Mdot
.41318 .58457 Mdot
.25272 .55415 Mdot
.73164 .72402 Mdot
.39587 .53567 Mdot
.44051 .61134 Mdot
.47064 .38805 Mdot
.67022 .51581 Mdot
.62304 .50491 Mdot
.53306 .66926 Mdot
.49931 .34901 Mdot
.4884 .53025 Mdot
.2658 .71212 Mdot
.64425 .50414 Mdot
.38257 .23149 Mdot
.21182 .58095 Mdot
.38416 .68969 Mdot
.52046 .6768 Mdot
.50803 .65521 Mdot
.61608 .50092 Mdot
.57047 .26463 Mdot
.48316 .31171 Mdot
.64849 .52797 Mdot
.68897 .50489 Mdot
.3782 .62708 Mdot
.51463 .31084 Mdot
.37666 .64481 Mdot
.27941 .52576 Mdot
.6646 .76858 Mdot
.17658 .39561 Mdot
.33411 .43229 Mdot
.28425 .67707 Mdot
.36587 .41543 Mdot
.62487 .68983 Mdot
.42906 .60059 Mdot
.616 .4689 Mdot
.46698 .31268 Mdot
.66368 .50598 Mdot
.60567 .46679 Mdot
.63696 .5315 Mdot
.65694 .53778 Mdot
.19126 .35078 Mdot
.51846 .70271 Mdot
.6683 .54827 Mdot
.37247 .61034 Mdot
.37232 .7765 Mdot
.32566 .74287 Mdot
.63932 .52683 Mdot
.60182 .49879 Mdot
.5051 .30566 Mdot
.61834 .45472 Mdot
.35554 .41406 Mdot
.50984 .36827 Mdot
.60539 .52792 Mdot
.56243 .8322 Mdot
.60202 .53569 Mdot
.70909 .72833 Mdot
.35457 .46102 Mdot
.22721 .409 Mdot
.6958 .48402 Mdot
.28101 .46493 Mdot
.4855 .5859 Mdot
.38142 .57966 Mdot
.37825 .41531 Mdot
.39675 .61288 Mdot
.24232 .68472 Mdot
.66027 .43842 Mdot
.62426 .48493 Mdot
.68026 .48187 Mdot
.3764 .57213 Mdot
.50414 .83767 Mdot
.30206 .58372 Mdot
.6735 .44284 Mdot
.39803 .58195 Mdot
.45849 .3639 Mdot
.77111 .55874 Mdot
.50226 .32637 Mdot
.54561 .70525 Mdot
.37948 .45747 Mdot
.5381 .66098 Mdot
.64206 .73318 Mdot
.52019 .32475 Mdot
.52027 .2929 Mdot
.39834 .62701 Mdot
.42203 .3629 Mdot
.54829 .1393 Mdot
.42113 .30464 Mdot
.64683 .65544 Mdot
.47628 .32056 Mdot
.61139 .53806 Mdot
.6256 .71705 Mdot
.4168 .33313 Mdot
.39615 .60959 Mdot
.65553 .48042 Mdot
.60684 .23458 Mdot
.39005 .58216 Mdot
.67626 .4665 Mdot
.36858 .61183 Mdot
.36645 .45626 Mdot
.38007 .63456 Mdot
.51673 .27639 Mdot
.59577 .5153 Mdot
.58045 .13532 Mdot
.46759 .66155 Mdot
.63107 .49164 Mdot
.31586 .43309 Mdot
.22444 .51117 Mdot
.6309 .46603 Mdot
.52592 .71017 Mdot
.40541 .59873 Mdot
.42954 .36616 Mdot
.61305 .49429 Mdot
.39972 .58234 Mdot
.5208 .30559 Mdot
.32005 .41769 Mdot
.68862 .28627 Mdot
.28761 .43741 Mdot
.46779 .32404 Mdot
.51573 .46243 Mdot
.39376 .42214 Mdot
.62528 .54468 Mdot
.67683 .5236 Mdot
.48883 .33718 Mdot
.57731 .68112 Mdot
.58714 .47135 Mdot
.57828 .49982 Mdot
.38 .62384 Mdot
.4007 .6122 Mdot
.77326 .43574 Mdot
.36355 .6387 Mdot
.69051 .47782 Mdot
.49069 .33598 Mdot
.62931 .4738 Mdot
.50675 .30366 Mdot
.61839 .45512 Mdot
.53966 .47508 Mdot
.48889 .29815 Mdot
.36435 .40043 Mdot
.65248 .48101 Mdot
.61471 .57378 Mdot
.62569 .46012 Mdot
.66567 .52152 Mdot
.38752 .58442 Mdot
.52264 .67007 Mdot
.6864 .4892 Mdot
.48469 .65678 Mdot
.50209 .69554 Mdot
.31175 .48697 Mdot
.37527 .62557 Mdot
.53471 .69228 Mdot
.21184 .60411 Mdot
.41626 .5966 Mdot
.53773 .67153 Mdot
.32738 .74459 Mdot
.33613 .45382 Mdot
.47897 .29025 Mdot
.61814 .47623 Mdot
.70032 .69975 Mdot
.5797 .38719 Mdot
.42419 .64072 Mdot
.61907 .49278 Mdot
.64015 .46395 Mdot
.47147 .36944 Mdot
.27628 .74251 Mdot
.354 .57369 Mdot
.60213 .53989 Mdot
.51693 .34211 Mdot
.28376 .76899 Mdot
.37738 .60985 Mdot
.5353 .6678 Mdot
.33899 .45957 Mdot
.45451 .37475 Mdot
.27576 .3503 Mdot
.31689 .44884 Mdot
.33037 .58674 Mdot
.28518 .52142 Mdot
.65199 .55074 Mdot
.39657 .63752 Mdot
.82395 .39265 Mdot
.64878 .58906 Mdot
.46854 .55804 Mdot
.78288 .50866 Mdot
.47152 .3472 Mdot
.36269 .415 Mdot
.51572 .69958 Mdot
.4638 .35192 Mdot
.52084 .31439 Mdot
.36408 .47143 Mdot
.57611 .29018 Mdot
.46314 .42552 Mdot
.38098 .4409 Mdot
.72703 .63946 Mdot
.49053 .78624 Mdot
.39302 .63633 Mdot
.54147 .67029 Mdot
.61992 .74915 Mdot
.49585 .31955 Mdot
.65977 .80974 Mdot
.80255 .52747 Mdot
.63325 .49602 Mdot
.52721 .69448 Mdot
.50732 .8282 Mdot
.31074 .76145 Mdot
.33019 .4424 Mdot
.33176 .49728 Mdot
.52979 .6575 Mdot
.63815 .45969 Mdot
.74607 .57705 Mdot
.58424 .48767 Mdot
.37509 .46009 Mdot
.72068 .32099 Mdot
.52112 .3231 Mdot
.34811 .46821 Mdot
.76384 .58337 Mdot
.64964 .49633 Mdot
.65134 .47876 Mdot
.6952 .64953 Mdot
.45985 .34673 Mdot
.38088 .57933 Mdot
.67353 .53487 Mdot
.63063 .5099 Mdot
.67943 .46413 Mdot
.58087 .4516 Mdot
.59465 .25664 Mdot
.59582 .4888 Mdot
.3202 .69713 Mdot
.65297 .45949 Mdot
.65812 .49272 Mdot
.45504 .31969 Mdot
.15984 .41917 Mdot
.29432 .54071 Mdot
.63443 .50803 Mdot
.61564 .54399 Mdot
.34768 .46695 Mdot
.43193 .41536 Mdot
.42619 .38627 Mdot
.43323 .37025 Mdot
.78601 .46853 Mdot
.56172 .4985 Mdot
.50654 .35347 Mdot
.53231 .70473 Mdot
.6146 .54712 Mdot
.51095 .35126 Mdot
.57814 .47169 Mdot
.38939 .58052 Mdot
.41473 .59363 Mdot
.5973 .58804 Mdot
.53465 .69493 Mdot
.45513 .22869 Mdot
.36995 .32019 Mdot
.41662 .60325 Mdot
.62052 .48405 Mdot
.29913 .42925 Mdot
.35455 .60445 Mdot
.41769 .54854 Mdot
.56643 .72394 Mdot
.47464 .31131 Mdot
.47168 .33433 Mdot
.59889 .68268 Mdot
.25904 .5309 Mdot
.39821 .20782 Mdot
.36769 .45727 Mdot
.67983 .53708 Mdot
.40883 .28768 Mdot
.46877 .33427 Mdot
.63066 .70144 Mdot
.52921 .69575 Mdot
.33338 .44597 Mdot
.31687 .61448 Mdot
.50871 .31652 Mdot
.51003 .29249 Mdot
.61104 .45029 Mdot
.62684 .51948 Mdot
.78365 .42881 Mdot
.48834 .65184 Mdot
.32081 .45874 Mdot
.53877 .66766 Mdot
.42946 .60446 Mdot
.58632 .50058 Mdot
.48845 .30057 Mdot
.47601 .79456 Mdot
.62834 .5505 Mdot
.37074 .58871 Mdot
.47222 .34364 Mdot
.51955 .65693 Mdot
.53145 .70851 Mdot
.65874 .53032 Mdot
.75969 .39157 Mdot
.37373 .44173 Mdot
.48393 .36029 Mdot
.39561 .38845 Mdot
.5857 .48063 Mdot
.61915 .51603 Mdot
.55988 .54441 Mdot
.31983 .45755 Mdot
.33352 .36645 Mdot
.51375 .71164 Mdot
.49462 .35152 Mdot
.59762 .49193 Mdot
.54229 .67805 Mdot
.38383 .32055 Mdot
.42248 .63021 Mdot
.37541 .63328 Mdot
.53703 .70395 Mdot
.5193 .68558 Mdot
.51699 .71043 Mdot
.66221 .80907 Mdot
.48609 .37521 Mdot
.52435 .39057 Mdot
.57811 .52843 Mdot
.63245 .66454 Mdot
.66863 .55031 Mdot
.3335 .42002 Mdot
.36654 .61621 Mdot
.61963 .46414 Mdot
.64618 .54041 Mdot
.54386 .50997 Mdot
.35399 .24136 Mdot
.54331 .4011 Mdot
.51666 .31036 Mdot
.69043 .47326 Mdot
.38894 .63106 Mdot
.6492 .83054 Mdot
.81911 .53255 Mdot
.69478 .48066 Mdot
.465 .42174 Mdot
.48179 .29995 Mdot
.363 .46777 Mdot
.68333 .68266 Mdot
.33937 .45698 Mdot
.49022 .3517 Mdot
.59202 .49091 Mdot
.3633 .33754 Mdot
.55027 .65373 Mdot
.66412 .5142 Mdot
.36782 .46126 Mdot
.67151 .49937 Mdot
.31959 .45596 Mdot
.69316 .7152 Mdot
.80843 .39239 Mdot
.63977 .49807 Mdot
.62701 .55937 Mdot
.79325 .41872 Mdot
.64508 .52444 Mdot
.554 .6459 Mdot
.48121 .29986 Mdot
.72681 .32193 Mdot
.57826 .54137 Mdot
.7456 .50944 Mdot
.58225 .48647 Mdot
.69853 .28568 Mdot
.61948 .51923 Mdot
.37511 .69127 Mdot
.59216 .51818 Mdot
.67235 .47696 Mdot
.34508 .42794 Mdot
.34554 .46741 Mdot
.46695 .29389 Mdot
.34991 .59619 Mdot
.70011 .74048 Mdot
.6235 .51272 Mdot
.27659 .48124 Mdot
.30294 .36433 Mdot
.51904 .68263 Mdot
.49397 .34869 Mdot
.32579 .79459 Mdot
.39472 .44369 Mdot
.81155 .47776 Mdot
.77271 .45742 Mdot
.31452 .31491 Mdot
.57321 .75878 Mdot
.22022 .5421 Mdot
.5145 .66003 Mdot
.58497 .46351 Mdot
.48795 .75509 Mdot
.36673 .69222 Mdot
.56923 .70812 Mdot
.38307 .41567 Mdot
.74324 .3972 Mdot
.5399 .77376 Mdot
.54626 .6992 Mdot
.51877 .65329 Mdot
.32035 .44534 Mdot
.44547 .61629 Mdot
.60783 .42588 Mdot
.52076 .6951 Mdot
.37831 .5706 Mdot
.42101 .6052 Mdot
.37679 .56746 Mdot
.48449 .30854 Mdot
.81373 .51929 Mdot
.40427 .44656 Mdot
.33005 .42477 Mdot
.45044 .63715 Mdot
.71929 .44927 Mdot
.52885 .34038 Mdot
.39267 .62191 Mdot
.36961 .63729 Mdot
.4812 .29717 Mdot
.61912 .44144 Mdot
.61963 .43424 Mdot
.63983 .50578 Mdot
.52743 .67003 Mdot
.62365 .52345 Mdot
.39986 .58475 Mdot
.33313 .43706 Mdot
.36621 .63258 Mdot
.31315 .43455 Mdot
.45982 .80323 Mdot
.64849 .5321 Mdot
.59368 .51394 Mdot
.25989 .29463 Mdot
.49724 .28207 Mdot
.39345 .78359 Mdot
.33778 .39509 Mdot
.37972 .60067 Mdot
.66672 .47285 Mdot
.51536 .36459 Mdot
.50463 .6454 Mdot
.18015 .40114 Mdot
.59802 .46631 Mdot
.49879 .31062 Mdot
.58825 .49941 Mdot
.65749 .59367 Mdot
.45813 .19415 Mdot
.49552 .32924 Mdot
.368 .22354 Mdot
.60892 .54012 Mdot
.23222 .62218 Mdot
.64157 .45484 Mdot
.59226 .61104 Mdot
.58718 .47142 Mdot
.47139 .3612 Mdot
.63916 .50934 Mdot
.51455 .3638 Mdot
.41566 .61759 Mdot
.35352 .46628 Mdot
.46888 .32581 Mdot
.66906 .52963 Mdot
.51299 .0709 Mdot
.35685 .4553 Mdot
.62097 .49959 Mdot
.32552 .44934 Mdot
.50268 .34684 Mdot
.46802 .35157 Mdot
.30262 .74203 Mdot
.2789 .52883 Mdot
.36503 .45501 Mdot
.58684 .5004 Mdot
.25771 .63828 Mdot
.6067 .4743 Mdot
.73906 .56098 Mdot
.63678 .44046 Mdot
.57474 .50114 Mdot
.33688 .75938 Mdot
.32555 .42784 Mdot
.39762 .20596 Mdot
.32809 .76442 Mdot
.36931 .77486 Mdot
.4924 .27456 Mdot
.54785 .69436 Mdot
.72273 .74687 Mdot
.26843 .46042 Mdot
.39397 .57845 Mdot
.62564 .46323 Mdot
.49153 .25719 Mdot
.37302 .4376 Mdot
.5138 .66784 Mdot
.63841 .49825 Mdot
.37721 .63829 Mdot
.67329 .24778 Mdot
.32798 .41626 Mdot
.49843 .32733 Mdot
.46019 .36228 Mdot
.17287 .58262 Mdot
.60918 .49081 Mdot
.59753 .51971 Mdot
.37922 .45814 Mdot
.2119 .50757 Mdot
.49736 .67757 Mdot
.74337 .33176 Mdot
.36308 .45357 Mdot
.46931 .49607 Mdot
.50975 .35626 Mdot
.64658 .46596 Mdot
.57215 .81697 Mdot
.31349 .62763 Mdot
.28545 .27734 Mdot
.52997 .67026 Mdot
.73565 .56503 Mdot
.47307 .36203 Mdot
.34382 .4424 Mdot
.24489 .50312 Mdot
.56077 .5107 Mdot
.66423 .48331 Mdot
.6908 .59378 Mdot
.3307 .50153 Mdot
.46182 .39515 Mdot
.59432 .47043 Mdot
.48224 .58292 Mdot
.60554 .46133 Mdot
.59215 .55778 Mdot
.66194 .44467 Mdot
.60927 .5146 Mdot
.4931 .30321 Mdot
.72914 .51104 Mdot
.36967 .57668 Mdot
.51778 .38232 Mdot
.465 .50467 Mdot
.62558 .49322 Mdot
.58016 .50835 Mdot
.62287 .40045 Mdot
.2452 .57006 Mdot
.4708 .3265 Mdot
.51854 .28643 Mdot
.39436 .45129 Mdot
.61428 .4377 Mdot
.34997 .59998 Mdot
.66074 .56064 Mdot
.38267 .5856 Mdot
.49009 .3022 Mdot
.37903 .60417 Mdot
.33536 .4596 Mdot
.4024 .63533 Mdot
.2677 .46568 Mdot
.34564 .45142 Mdot
.47127 .31539 Mdot
.60718 .52554 Mdot
.31586 .43194 Mdot
.66425 .62997 Mdot
.52906 .67146 Mdot
.41196 .83822 Mdot
.60487 .52823 Mdot
.28713 .35357 Mdot
.59665 .41932 Mdot
.36743 .63497 Mdot
.44489 .19344 Mdot
.4661 .30837 Mdot
.49551 .66286 Mdot
.45756 .33673 Mdot
.75688 .57976 Mdot
.52641 .68303 Mdot
.39305 .81401 Mdot
.50216 .60465 Mdot
.72627 .60045 Mdot
.59972 .44295 Mdot
.7008 .63285 Mdot
.4249 .60244 Mdot
.3703 .43593 Mdot
.2479 .52173 Mdot
.67056 .47739 Mdot
.73985 .28743 Mdot
.45458 .33329 Mdot
.35275 .58992 Mdot
.3423 .43744 Mdot
.34045 .41713 Mdot
.59304 .53988 Mdot
.42942 .70423 Mdot
.6669 .48409 Mdot
.2618 .51629 Mdot
.7819 .49384 Mdot
.53964 .36482 Mdot
.61765 .49642 Mdot
.41621 .60867 Mdot
.58832 .49912 Mdot
.51207 .71248 Mdot
.82682 .46431 Mdot
.63356 .57215 Mdot
.32148 .39232 Mdot
.49963 .64107 Mdot
.49394 .36129 Mdot
.5547 .44044 Mdot
.29488 .41125 Mdot
.60661 .48958 Mdot
.16503 .35405 Mdot
.53992 .67438 Mdot
.4867 .75122 Mdot
.64267 .54646 Mdot
.61511 .54891 Mdot
.44176 .53129 Mdot
.27659 .34046 Mdot
.32405 .66711 Mdot
.65131 .51664 Mdot
.6472 .6173 Mdot
.32087 .43642 Mdot
.62729 .45786 Mdot
.62132 .50354 Mdot
.5879 .33713 Mdot
.33048 .41826 Mdot
.37092 .59773 Mdot
.41425 .58463 Mdot
.4184 .64405 Mdot
.50291 .70575 Mdot
.40969 .3841 Mdot
.64287 .68046 Mdot
.61052 .20534 Mdot
.51442 .64971 Mdot
.6425 .54056 Mdot
.47022 .68257 Mdot
.58795 .49088 Mdot
.51238 .67321 Mdot
.32973 .4179 Mdot
.46659 .33139 Mdot
.40481 .30291 Mdot
.41146 .58545 Mdot
.55886 .51063 Mdot
.496 .68176 Mdot
.47598 .31264 Mdot
.65222 .71534 Mdot
.49504 .35973 Mdot
.36399 .44647 Mdot
.40577 .38142 Mdot
.51109 .67011 Mdot
.50652 .34299 Mdot
.35376 .3847 Mdot
.29425 .7459 Mdot
.66221 .44174 Mdot
.38976 .35824 Mdot
.48989 .36589 Mdot
.52491 .29571 Mdot
.49485 .3697 Mdot
.67138 .50653 Mdot
.46655 .4228 Mdot
.57143 .49264 Mdot
.32353 .42989 Mdot
.36787 .60805 Mdot
.78505 .36674 Mdot
.32571 .54509 Mdot
.51418 .43001 Mdot
.69115 .51575 Mdot
.6507 .49724 Mdot
.61655 .50096 Mdot
.58932 .55355 Mdot
.2614 .4526 Mdot
.66613 .4972 Mdot
.3461 .42739 Mdot
.40365 .59349 Mdot
.58324 .46474 Mdot
.34033 .63264 Mdot
.35517 .75741 Mdot
.53885 .65783 Mdot
.33905 .48168 Mdot
.83648 .50493 Mdot
.47491 .31552 Mdot
.40988 .64172 Mdot
.40939 .59312 Mdot
.50238 .67247 Mdot
.37821 .44473 Mdot
.49738 .35897 Mdot
.73229 .56384 Mdot
.50297 .6968 Mdot
.6358 .5098 Mdot
.46621 .41206 Mdot
.77036 .31938 Mdot
.59057 .46085 Mdot
.63073 .4694 Mdot
.37748 .56583 Mdot
.49393 .74726 Mdot
.67558 .1918 Mdot
.66116 .67971 Mdot
.51822 .66841 Mdot
.55054 .67844 Mdot
.48699 .29262 Mdot
.57669 .53577 Mdot
.31697 .44282 Mdot
.43228 .28753 Mdot
.3334 .37541 Mdot
.4223 .23781 Mdot
.2634 .31123 Mdot
.60994 .4624 Mdot
.19904 .50659 Mdot
.65046 .49253 Mdot
.48483 .37499 Mdot
.49201 .30674 Mdot
.48383 .32507 Mdot
.37007 .43661 Mdot
.68073 .36591 Mdot
.3589 .42741 Mdot
.852 .44204 Mdot
.47472 .35967 Mdot
.49694 .60658 Mdot
.38969 .62682 Mdot
.66877 .44003 Mdot
.52609 .65753 Mdot
.39501 .36783 Mdot
.58039 .57404 Mdot
.5489 .25445 Mdot
.35755 .58183 Mdot
.46883 .31854 Mdot
.21562 .51901 Mdot
.79293 .61892 Mdot
.42982 .38012 Mdot
.54549 .52681 Mdot
.68338 .68439 Mdot
.51698 .67922 Mdot
.28265 .28009 Mdot
.53464 .66173 Mdot
.36664 .46143 Mdot
.59439 .508 Mdot
.60209 .5163 Mdot
.60565 .46063 Mdot
.64382 .53053 Mdot
.4009 .42926 Mdot
.68475 .5095 Mdot
.50666 .208 Mdot
.40685 .58212 Mdot
.5627 .61909 Mdot
.5345 .66408 Mdot
.35801 .40931 Mdot
.40354 .5922 Mdot
.2459 .56275 Mdot
.67618 .63982 Mdot
.61474 .49474 Mdot
.62103 .46366 Mdot
.8105 .45102 Mdot
.59383 .47143 Mdot
.66044 .43093 Mdot
.39667 .5801 Mdot
.54641 .42021 Mdot
.53754 .65789 Mdot
.55094 .66941 Mdot
.34352 .45195 Mdot
.49327 .3047 Mdot
.53803 .68054 Mdot
.38552 .62637 Mdot
.69167 .51316 Mdot
.68116 .51996 Mdot
.48752 .36555 Mdot
.81831 .45197 Mdot
.52061 .71473 Mdot
.24993 .63085 Mdot
.47065 .30993 Mdot
.45703 .30131 Mdot
.66366 .48198 Mdot
.30955 .26203 Mdot
.50164 .26901 Mdot
.48988 .67302 Mdot
.36426 .41017 Mdot
.69565 .66651 Mdot
.38912 .43291 Mdot
.50013 .32712 Mdot
.59454 .53405 Mdot
.48278 .30473 Mdot
.61352 .49168 Mdot
.8098 .62324 Mdot
.60736 .51776 Mdot
.59313 .19936 Mdot
.59378 .66899 Mdot
.40801 .61939 Mdot
.23765 .56269 Mdot
.39933 .62833 Mdot
.46262 .32269 Mdot
.63195 .5519 Mdot
.50351 .66259 Mdot
.31685 .71933 Mdot
.4614 .26261 Mdot
.35698 .60458 Mdot
.34436 .60116 Mdot
.38818 .42823 Mdot
.58715 .46944 Mdot
.66557 .48789 Mdot
.40077 .60389 Mdot
.53745 .29023 Mdot
.50945 .32484 Mdot
.59829 .49904 Mdot
.65422 .49784 Mdot
.4054 .62244 Mdot
.27957 .73297 Mdot
.71781 .53675 Mdot
.59978 .50763 Mdot
.31109 .64935 Mdot
.33469 .42026 Mdot
.6627 .43818 Mdot
.63545 .55817 Mdot
.51861 .68838 Mdot
.63044 .26584 Mdot
.78706 .56615 Mdot
.33012 .41688 Mdot
.40813 .58812 Mdot
.60362 .49116 Mdot
.41596 .60552 Mdot
.68404 .514 Mdot
.2844 .33096 Mdot
.41451 .63592 Mdot
.5773 .50584 Mdot
.60859 .44414 Mdot
.46043 .3498 Mdot
.6148 .46277 Mdot
.67928 .40695 Mdot
.36485 .58708 Mdot
.59489 .53996 Mdot
.75135 .36803 Mdot
.38335 .43847 Mdot
.58687 .44635 Mdot
.50922 .70104 Mdot
.74598 .55 Mdot
.35033 .3265 Mdot
.58045 .7757 Mdot
.55153 .66606 Mdot
.67053 .49985 Mdot
.34662 .59525 Mdot
.32402 .4611 Mdot
.56202 .18871 Mdot
.64309 .46182 Mdot
.37178 .46042 Mdot
.33318 .43814 Mdot
.51448 .66517 Mdot
.15141 .43932 Mdot
.64755 .54293 Mdot
.63668 .52699 Mdot
.63279 .36748 Mdot
.51295 .29237 Mdot
.61576 .52341 Mdot
.61973 .53898 Mdot
.34113 .4277 Mdot
.57646 .44267 Mdot
.74524 .42976 Mdot
.72231 .3064 Mdot
.35835 .47582 Mdot
.4265 .26121 Mdot
.42077 .6255 Mdot
.5449 .68232 Mdot
.4789 .35052 Mdot
.49625 .67495 Mdot
.37993 .63113 Mdot
.61675 .53664 Mdot
.37422 .46478 Mdot
.64308 .39541 Mdot
.32049 .44662 Mdot
.54574 .76122 Mdot
.51798 .35286 Mdot
.39264 .48522 Mdot
.15397 .38248 Mdot
.28244 .60986 Mdot
.31882 .49811 Mdot
.51923 .68312 Mdot
.39363 .54632 Mdot
.65366 .49667 Mdot
.27169 .28903 Mdot
.64125 .53978 Mdot
.73889 .34764 Mdot
.39885 .57751 Mdot
.38497 .56922 Mdot
.59671 .5068 Mdot
.77895 .49902 Mdot
.32634 .46361 Mdot
.3506 .41722 Mdot
.57912 .5201 Mdot
.36841 .44683 Mdot
.63118 .52078 Mdot
.39575 .58458 Mdot
.3248 .22554 Mdot
.63757 .50247 Mdot
.61842 .56756 Mdot
.29398 .3309 Mdot
.33987 .76697 Mdot
.47576 .64727 Mdot
.19682 .64104 Mdot
.80813 .59246 Mdot
.36778 .44516 Mdot
.57185 .51002 Mdot
.42554 .25695 Mdot
.36143 .56774 Mdot
.35511 .38198 Mdot
.61709 .53232 Mdot
.63118 .53911 Mdot
.67116 .47355 Mdot
.64626 .47608 Mdot
.2015 .38162 Mdot
.45477 .26403 Mdot
.64897 .30788 Mdot
.60782 .46526 Mdot
.68919 .62591 Mdot
.35245 .45911 Mdot
.44466 .32705 Mdot
.49862 .65577 Mdot
.61171 .46227 Mdot
.49803 .38859 Mdot
.37834 .46713 Mdot
.85276 .42405 Mdot
.37294 .46232 Mdot
.37744 .59479 Mdot
.33459 .46303 Mdot
.63909 .48674 Mdot
.48784 .34521 Mdot
.42259 .48461 Mdot
.29275 .56465 Mdot
.39017 .57615 Mdot
.63044 .49173 Mdot
.48231 .61506 Mdot
.36637 .57698 Mdot
.38366 .78552 Mdot
.48075 .34477 Mdot
.63295 .62022 Mdot
.48674 .30405 Mdot
.58399 .5284 Mdot
.58514 .52857 Mdot
.39198 .46414 Mdot
.33672 .46167 Mdot
.48841 .30403 Mdot
.13144 .48586 Mdot
.51833 .71231 Mdot
.48659 .32415 Mdot
.56197 .52599 Mdot
.45041 .43865 Mdot
.48607 .34067 Mdot
.5625 .6603 Mdot
.33492 .43312 Mdot
.48992 .28494 Mdot
.65699 .45959 Mdot
.73196 .63196 Mdot
.53983 .69948 Mdot
.42426 .58985 Mdot
.63063 .71956 Mdot
.35801 .59423 Mdot
.37669 .41435 Mdot
.40175 .6277 Mdot
.32869 .42835 Mdot
.33317 .34544 Mdot
.52898 .37166 Mdot
.40453 .5342 Mdot
.39541 .42696 Mdot
.39813 .62668 Mdot
.59165 .50505 Mdot
.46807 .66073 Mdot
.59108 .54575 Mdot
.67672 .51214 Mdot
.3434 .42131 Mdot
.46289 .34907 Mdot
.50638 .27373 Mdot
.72827 .58989 Mdot
.49865 .30452 Mdot
.36754 .59065 Mdot
.54587 .23664 Mdot
.29316 .49891 Mdot
.38508 .43072 Mdot
.34915 .46609 Mdot
.58867 .48392 Mdot
.39655 .61201 Mdot
.38852 .57377 Mdot
.39122 .43449 Mdot
.33637 .26019 Mdot
.61715 .56149 Mdot
.52624 .29451 Mdot
.50896 .28999 Mdot
.49368 .33223 Mdot
.50034 .36958 Mdot
.74063 .4952 Mdot
.33267 .44917 Mdot
.46055 .34072 Mdot
.58847 .48247 Mdot
.62448 .53673 Mdot
.42873 .28418 Mdot
.53721 .69826 Mdot
.57792 .46863 Mdot
.65689 .44279 Mdot
.64898 .46737 Mdot
.38239 .63629 Mdot
.7135 .46461 Mdot
.39746 .64076 Mdot
.35104 .58187 Mdot
.35456 .57593 Mdot
.26932 .45817 Mdot
.80205 .47442 Mdot
.75563 .65506 Mdot
.60671 .54265 Mdot
.204 .54891 Mdot
.38618 .61306 Mdot
.5185 .22686 Mdot
.32396 .36927 Mdot
.66416 .47164 Mdot
.34113 .70462 Mdot
.40272 .60836 Mdot
.47577 .30047 Mdot
.61175 .52686 Mdot
.40465 .64829 Mdot
.51459 .70493 Mdot
.59127 .54103 Mdot
.42452 .62666 Mdot
.50599 .34676 Mdot
.48932 .68705 Mdot
.48982 .28099 Mdot
.3544 .57559 Mdot
.55373 .47391 Mdot
.45941 .15001 Mdot
.38526 .6547 Mdot
.23894 .65132 Mdot
.53207 .52973 Mdot
.59497 .50076 Mdot
.39278 .64658 Mdot
.46308 .28754 Mdot
.37367 .41375 Mdot
.50003 .52147 Mdot
.504 .29491 Mdot
.38489 .56916 Mdot
.35545 .61657 Mdot
.3905 .57615 Mdot
.51655 .30653 Mdot
.56834 .47673 Mdot
.51043 .30798 Mdot
.33147 .46223 Mdot
.61579 .47424 Mdot
.72028 .70337 Mdot
.21322 .49529 Mdot
.47361 .30641 Mdot
.36387 .60347 Mdot
.55027 .65532 Mdot
.64536 .49495 Mdot
.20689 .5108 Mdot
.59055 .502 Mdot
.33367 .42335 Mdot
.60149 .27408 Mdot
.5531 .40332 Mdot
.57387 .50506 Mdot
.59258 .48151 Mdot
.35351 .41783 Mdot
.63206 .49519 Mdot
.58717 .47091 Mdot
.26649 .46437 Mdot
.51541 .31671 Mdot
.64336 .5075 Mdot
.37135 .61512 Mdot
.29186 .51842 Mdot
.61801 .56415 Mdot
.3818 .53452 Mdot
.62876 .61709 Mdot
.59618 .28757 Mdot
.63903 .54031 Mdot
.4855 .40936 Mdot
.6565 .47981 Mdot
.65932 .52093 Mdot
.59343 .48482 Mdot
.18026 .44289 Mdot
.42288 .62797 Mdot
.41245 .60183 Mdot
.54888 .68532 Mdot
.62752 .61775 Mdot
.52278 .69389 Mdot
.33098 .43584 Mdot
.44152 .71626 Mdot
.40002 .64045 Mdot
.50379 .33307 Mdot
.66575 .50883 Mdot
.38283 .65415 Mdot
.65494 .46922 Mdot
.63671 .48627 Mdot
.34933 .60678 Mdot
.42425 .62153 Mdot
.52628 .76687 Mdot
.52962 .70438 Mdot
.47959 .32454 Mdot
.57826 .4771 Mdot
.4988 .69031 Mdot
.64016 .54261 Mdot
.63155 .6666 Mdot
.48204 .32755 Mdot
.51403 .31464 Mdot
.50622 .27249 Mdot
.61219 .53406 Mdot
.64149 .49048 Mdot
.35857 .4267 Mdot
.46433 .31472 Mdot
.38439 .44204 Mdot
.49244 .54108 Mdot
.4003 .76524 Mdot
.61747 .53263 Mdot
.40922 .36478 Mdot
.5227 .69966 Mdot
.35754 .60848 Mdot
.78287 .33708 Mdot
.54871 .68593 Mdot
.61014 .49271 Mdot
.35224 .58589 Mdot
.5079 .68057 Mdot
.64512 .60124 Mdot
.84002 .44673 Mdot
.544 .65276 Mdot
.58898 .48197 Mdot
.56995 .44931 Mdot
.18853 .62462 Mdot
.54785 .65919 Mdot
.34192 .46021 Mdot
.61031 .53278 Mdot
.53268 .3124 Mdot
.49539 .67928 Mdot
.31019 .67277 Mdot
.40557 .60168 Mdot
.74093 .61664 Mdot
.60336 .57482 Mdot
.51838 .25364 Mdot
.54874 .67968 Mdot
.49273 .35586 Mdot
.65713 .42747 Mdot
.66179 .48055 Mdot
.55109 .66241 Mdot
.36208 .40414 Mdot
.3945 .59063 Mdot
.2887 .53736 Mdot
.51605 .30444 Mdot
.371 .4034 Mdot
.36181 .61267 Mdot
.25559 .64 Mdot
.6543 .2489 Mdot
.62624 .43329 Mdot
.1851 .5773 Mdot
.27809 .40323 Mdot
.62356 .4528 Mdot
.51309 .64499 Mdot
.31624 .42911 Mdot
.38529 .46074 Mdot
.36152 .44877 Mdot
.31664 .3576 Mdot
.43405 .37292 Mdot
.425 .62988 Mdot
.40746 .396 Mdot
.54383 .68477 Mdot
.69996 .65581 Mdot
.6781 .51364 Mdot
.64853 .49931 Mdot
.5799 .48176 Mdot
.61404 .46056 Mdot
.66112 .49139 Mdot
.37605 .45039 Mdot
.31925 .34446 Mdot
.42479 .36061 Mdot
.48458 .33422 Mdot
.48864 .73729 Mdot
.38412 .6229 Mdot
.42999 .59094 Mdot
.50629 .68978 Mdot
.28827 .63649 Mdot
.34193 .63481 Mdot
.37824 .60258 Mdot
.59582 .45304 Mdot
.50955 .31712 Mdot
.66979 .43867 Mdot
.59086 .48174 Mdot
.3735 .58834 Mdot
.45584 .53321 Mdot
.73187 .4344 Mdot
.54919 .73744 Mdot
.48877 .69537 Mdot
.44362 .40609 Mdot
.55297 .67715 Mdot
.65923 .5471 Mdot
.45996 .19746 Mdot
.38087 .63196 Mdot
.38916 .59946 Mdot
.53385 .69912 Mdot
.31201 .25735 Mdot
.47412 .34962 Mdot
.41034 .4551 Mdot
.32353 .44207 Mdot
.59052 .53129 Mdot
.69877 .26582 Mdot
.52647 .51631 Mdot
.41833 .70668 Mdot
.36 .45367 Mdot
.41449 .62075 Mdot
.66175 .55022 Mdot
.59914 .47488 Mdot
.51705 .69797 Mdot
.55992 .78889 Mdot
.67615 .45015 Mdot
.49152 .84594 Mdot
.80866 .39166 Mdot
.77828 .56261 Mdot
.66456 .48453 Mdot
.51557 .31251 Mdot
.42152 .59095 Mdot
.54268 .67132 Mdot
.55954 .50937 Mdot
.80522 .55362 Mdot
.48582 .36392 Mdot
.34756 .44931 Mdot
.45115 .49776 Mdot
.68381 .67333 Mdot
.67041 .51618 Mdot
.62597 .53896 Mdot
.66135 .52248 Mdot
.80421 .30125 Mdot
.3928 .63943 Mdot
.47641 .30261 Mdot
.51217 .6667 Mdot
.50151 .31186 Mdot
.41156 .61755 Mdot
.42931 .54571 Mdot
.59019 .51323 Mdot
.49565 .36529 Mdot
.49055 .35572 Mdot
.38535 .45653 Mdot
.33951 .41154 Mdot
.46826 .51264 Mdot
.60883 .51754 Mdot
.34913 .62847 Mdot
.46023 .34472 Mdot
.46153 .40764 Mdot
.52574 .68511 Mdot
.33512 .43146 Mdot
.61245 .46396 Mdot
.40199 .63803 Mdot
.6484 .44579 Mdot
.4711 .33148 Mdot
.37898 .6031 Mdot
.46966 .79289 Mdot
.543 .6592 Mdot
.6284 .53409 Mdot
.54499 .63003 Mdot
.405 .58536 Mdot
.65513 .49377 Mdot
.26758 .67267 Mdot
.56257 .66246 Mdot
.3028 .58932 Mdot
.36251 .57382 Mdot
.27887 .45701 Mdot
.49004 .29195 Mdot
.26427 .3873 Mdot
.3844 .59562 Mdot
.23407 .60811 Mdot
.50119 .78815 Mdot
.68975 .52172 Mdot
.4948 .31977 Mdot
.26792 .41301 Mdot
.75862 .70233 Mdot
.23679 .66735 Mdot
.62094 .50047 Mdot
.36275 .63786 Mdot
.51029 .68941 Mdot
.38001 .42684 Mdot
.32283 .57 Mdot
.52638 .72583 Mdot
.33617 .59641 Mdot
.59392 .48501 Mdot
.49987 .35302 Mdot
.3509 .43077 Mdot
.35052 .33095 Mdot
.37949 .62287 Mdot
.36583 .60859 Mdot
.61967 .55298 Mdot
.53027 .69579 Mdot
.22563 .44229 Mdot
.39463 .58177 Mdot
.80687 .42555 Mdot
.43777 .60328 Mdot
.50473 .70097 Mdot
.6458 .47218 Mdot
.74367 .58079 Mdot
.57335 .53014 Mdot
.29036 .70999 Mdot
.38915 .62443 Mdot
.47596 .32926 Mdot
.67476 .49499 Mdot
.76611 .37452 Mdot
.36651 .5922 Mdot
.4585 .41742 Mdot
.39646 .68097 Mdot
.32868 .44398 Mdot
.77932 .33309 Mdot
.62355 .52611 Mdot
.32421 .46107 Mdot
.51623 .69607 Mdot
.60393 .51078 Mdot
.64296 .4882 Mdot
.47085 .36798 Mdot
.3886 .45153 Mdot
.5214 .76985 Mdot
.35242 .46834 Mdot
.35484 .46192 Mdot
.51782 .36401 Mdot
.64307 .5165 Mdot
.37526 .59519 Mdot
.40142 .60799 Mdot
.65181 .45647 Mdot
.29394 .23198 Mdot
.47697 .35462 Mdot
.41492 .58185 Mdot
.78427 .27493 Mdot
.62802 .45009 Mdot
.76804 .32763 Mdot
.54733 .78748 Mdot
.3181 .43613 Mdot
.58836 .48172 Mdot
.50458 .34583 Mdot
.33523 .67259 Mdot
.36604 .60543 Mdot
.66968 .46756 Mdot
.35201 .43202 Mdot
.52642 .70697 Mdot
.36947 .58046 Mdot
.42803 .70574 Mdot
.64791 .53108 Mdot
.35078 .71559 Mdot
.35687 .62877 Mdot
.69841 .76291 Mdot
.24348 .54332 Mdot
.49259 .31846 Mdot
.63568 .48381 Mdot
.46866 .3055 Mdot
.50778 .66958 Mdot
.45341 .49927 Mdot
.33995 .4327 Mdot
.7172 .44871 Mdot
.48663 .19283 Mdot
.39088 .57616 Mdot
.47237 .30449 Mdot
.57521 .51828 Mdot
.2838 .32507 Mdot
.62926 .52485 Mdot
.54492 .48061 Mdot
.54076 .75044 Mdot
.36253 .42162 Mdot
.32052 .43875 Mdot
.64958 .48252 Mdot
.50018 .67344 Mdot
.3841 .6248 Mdot
.38549 .58833 Mdot
.62211 .82897 Mdot
.40552 .47279 Mdot
.78252 .43256 Mdot
.63235 .53864 Mdot
.33836 .59537 Mdot
.32615 .5263 Mdot
.37761 .45868 Mdot
.5738 .45837 Mdot
.35086 .59708 Mdot
.5469 .61788 Mdot
.67934 .59412 Mdot
.65992 .4811 Mdot
.57093 .53306 Mdot
.32496 .44932 Mdot
.45478 .39128 Mdot
.41865 .60899 Mdot
.66685 .45211 Mdot
.41057 .52815 Mdot
.63511 .60446 Mdot
.82332 .40247 Mdot
.47973 .32425 Mdot
.42635 .69076 Mdot
.3769 .44974 Mdot
.62005 .56855 Mdot
.52128 .65961 Mdot
.34675 .57618 Mdot
.40907 .63748 Mdot
.60352 .48697 Mdot
.67513 .53665 Mdot
.79635 .39456 Mdot
.50572 .32354 Mdot
.34689 .45615 Mdot
.5996 .52018 Mdot
.40584 .32749 Mdot
.6026 .46196 Mdot
.36677 .42795 Mdot
.44029 .15386 Mdot
.5832 .53955 Mdot
.63414 .52575 Mdot
.22631 .44889 Mdot
.50644 .29395 Mdot
.45746 .3297 Mdot
.71362 .26587 Mdot
.63201 .53839 Mdot
.80008 .37652 Mdot
.4752 .32247 Mdot
.47042 .34429 Mdot
.26394 .4988 Mdot
.64528 .49767 Mdot
.69722 .55126 Mdot
.32561 .42866 Mdot
.3535 .4626 Mdot
.51207 .30487 Mdot
.66807 .44194 Mdot
.34221 .41271 Mdot
.2036 .42358 Mdot
.39609 .61376 Mdot
.41445 .19385 Mdot
.47788 .35716 Mdot
.31391 .479 Mdot
.36861 .4587 Mdot
.8463 .46814 Mdot
.32475 .63656 Mdot
.59142 .50897 Mdot
.63618 .53673 Mdot
.53737 .69504 Mdot
.57548 .48886 Mdot
.38554 .56948 Mdot
.36853 .44755 Mdot
.76333 .47797 Mdot
.48404 .32446 Mdot
.61767 .5179 Mdot
.31153 .70019 Mdot
.42383 .80418 Mdot
.44061 .67815 Mdot
.4911 .36043 Mdot
.48738 .30935 Mdot
.40479 .63223 Mdot
.35949 .6347 Mdot
.65615 .50837 Mdot
.35969 .41663 Mdot
.46587 .3123 Mdot
.36103 .42407 Mdot
.3783 .63083 Mdot
.37633 .59741 Mdot
.42754 .61434 Mdot
.67927 .51528 Mdot
.37297 .60628 Mdot
.42748 .77964 Mdot
.3981 .40234 Mdot
.52785 .34589 Mdot
.77075 .29888 Mdot
.35481 .33344 Mdot
.47367 .26691 Mdot
.49624 .69047 Mdot
.39612 .57872 Mdot
.33287 .46489 Mdot
.6265 .47263 Mdot
.62788 .46149 Mdot
.28809 .48292 Mdot
.34348 .47109 Mdot
.51093 .66858 Mdot
.32062 .45356 Mdot
.5136 .66534 Mdot
.36708 .71097 Mdot
.58973 .46528 Mdot
.68595 .51204 Mdot
.37146 .45306 Mdot
.37567 .60485 Mdot
.40928 .60127 Mdot
.54065 .65316 Mdot
.46911 .55547 Mdot
.36356 .57811 Mdot
.46814 .34542 Mdot
.74127 .46257 Mdot
.35962 .62783 Mdot
.61274 .52565 Mdot
.6372 .68456 Mdot
.26296 .29417 Mdot
.58872 .55309 Mdot
.2628 .4855 Mdot
.61015 .38509 Mdot
.67151 .48575 Mdot
.26815 .28637 Mdot
.30397 .415 Mdot
.49728 .29518 Mdot
.40766 .58395 Mdot
.43323 .65013 Mdot
.71027 .51609 Mdot
.48721 .6818 Mdot
.55692 .48157 Mdot
.49751 .36373 Mdot
.45731 .35926 Mdot
.7376 .5981 Mdot
.25657 .68357 Mdot
.50932 .68301 Mdot
.50881 .69262 Mdot
.38337 .59359 Mdot
.41091 .84106 Mdot
.54305 .50882 Mdot
.51392 .66833 Mdot
.5286 .27314 Mdot
.59729 .48495 Mdot
.58839 .61907 Mdot
.52069 .47234 Mdot
.51388 .30527 Mdot
.6971 .61947 Mdot
.36877 .59403 Mdot
.4985 .30286 Mdot
.40129 .29749 Mdot
.57031 .47781 Mdot
.48321 .32753 Mdot
.35842 .42473 Mdot
.25463 .57384 Mdot
.46592 .34798 Mdot
.63844 .6748 Mdot
.3775 .42007 Mdot
.45792 .40684 Mdot
.71283 .59397 Mdot
.18449 .70137 Mdot
.37318 .44851 Mdot
.35582 .61629 Mdot
.40139 .60654 Mdot
.38463 .5887 Mdot
.50314 .3136 Mdot
.39256 .576 Mdot
.50444 .32437 Mdot
.19557 .60307 Mdot
.26966 .30323 Mdot
.51667 .66869 Mdot
.28791 .53989 Mdot
.49961 .34299 Mdot
.5094 .21702 Mdot
.23404 .26581 Mdot
.58585 .48375 Mdot
.38596 .46285 Mdot
.516 .67108 Mdot
.47142 .83839 Mdot
.51614 .68545 Mdot
.79937 .52001 Mdot
.5673 .26983 Mdot
.6256 .51689 Mdot
.71598 .37852 Mdot
.52034 .65225 Mdot
.51216 .35434 Mdot
.65404 .49358 Mdot
.51099 .57591 Mdot
.51604 .69115 Mdot
.5116 .70594 Mdot
.65073 .50854 Mdot
.46869 .31855 Mdot
.36226 .60181 Mdot
.35543 .46596 Mdot
.49608 .66725 Mdot
.57521 .43815 Mdot
.5675 .51575 Mdot
.58784 .50534 Mdot
.41823 .32569 Mdot
.53115 .64429 Mdot
.36777 .44432 Mdot
.16018 .44747 Mdot
.34682 .60393 Mdot
.5145 .59919 Mdot
.81336 .41328 Mdot
.28978 .41774 Mdot
.38997 .62348 Mdot
.41557 .60783 Mdot
.66201 .49257 Mdot
.53981 .44736 Mdot
.55549 .26825 Mdot
.46692 .57452 Mdot
.42829 .59753 Mdot
.39001 .58877 Mdot
.46069 .31345 Mdot
.76955 .56965 Mdot
.56478 .53715 Mdot
.32803 .41771 Mdot
.41711 .63263 Mdot
.25367 .34776 Mdot
.53723 .69208 Mdot
.56842 .25694 Mdot
.58874 .46447 Mdot
.59311 .51241 Mdot
.34864 .43614 Mdot
.35756 .42765 Mdot
.35262 .68006 Mdot
.78287 .551 Mdot
.60937 .38936 Mdot
.32342 .33066 Mdot
.59658 .30139 Mdot
.45493 .33454 Mdot
.47333 .30668 Mdot
.2932 .58307 Mdot
.36219 .46894 Mdot
.67323 .48821 Mdot
.49141 .30383 Mdot
.50154 .62054 Mdot
.72877 .46146 Mdot
.755 .54383 Mdot
.78134 .3527 Mdot
.61775 .49167 Mdot
.51385 .32713 Mdot
.50744 .29349 Mdot
.52232 .30393 Mdot
.28305 .4544 Mdot
.65084 .51726 Mdot
.61982 .49552 Mdot
.66921 .49113 Mdot
.29636 .29138 Mdot
.65656 .51864 Mdot
.27411 .37804 Mdot
.46134 .48964 Mdot
.64328 .26354 Mdot
.66599 .45054 Mdot
.31465 .45022 Mdot
.66131 .52954 Mdot
.50104 .67217 Mdot
.58181 .49511 Mdot
.75587 .54134 Mdot
.35677 .45717 Mdot
.73027 .51524 Mdot
.34109 .34365 Mdot
.65783 .46334 Mdot
.49058 .67468 Mdot
.3114 .38131 Mdot
.75185 .69058 Mdot
.4777 .65316 Mdot
.46931 .34755 Mdot
.39304 .61782 Mdot
.33412 .46621 Mdot
.38244 .59906 Mdot
.68723 .49364 Mdot
.287 .58978 Mdot
.48768 .82872 Mdot
.49091 .56353 Mdot
.61634 .46114 Mdot
.56328 .54282 Mdot
.46753 .3381 Mdot
.34839 .59829 Mdot
.4894 .26361 Mdot
.6716 .50795 Mdot
.52716 .66897 Mdot
.5186 .69672 Mdot
.49927 .53128 Mdot
.62727 .79482 Mdot
.22494 .38661 Mdot
.35389 .43668 Mdot
.39114 .58153 Mdot
.52779 .65726 Mdot
.222 .58577 Mdot
.31442 .421 Mdot
.34291 .41928 Mdot
.35141 .45602 Mdot
.60885 .53772 Mdot
.42085 .63081 Mdot
.64822 .26548 Mdot
.35082 .57642 Mdot
.63336 .49329 Mdot
.3824 .63719 Mdot
.35398 .58881 Mdot
.53805 .66883 Mdot
.35116 .45758 Mdot
.38278 .6309 Mdot
.58714 .53246 Mdot
.47471 .318 Mdot
.33991 .50845 Mdot
.58438 .66888 Mdot
.26474 .68946 Mdot
.56467 .58241 Mdot
.51855 .30354 Mdot
.741 .70891 Mdot
.32932 .42285 Mdot
.32498 .26859 Mdot
.52816 .76594 Mdot
.62907 .55085 Mdot
.30999 .21865 Mdot
.42727 .58267 Mdot
.35431 .59232 Mdot
.64814 .47366 Mdot
.44154 .60341 Mdot
.62219 .51986 Mdot
.36662 .62321 Mdot
.35852 .53027 Mdot
.49835 .38397 Mdot
.37695 .60949 Mdot
.67363 .46007 Mdot
.6471 .48691 Mdot
.51409 .31035 Mdot
.37699 .64433 Mdot
.55925 .51429 Mdot
.65326 .82148 Mdot
.36664 .43041 Mdot
.28724 .40355 Mdot
.62516 .69807 Mdot
.37856 .44877 Mdot
.48846 .32535 Mdot
.67629 .51487 Mdot
.5149 .69541 Mdot
.50083 .3435 Mdot
.75697 .5283 Mdot
.54439 .66305 Mdot
.40095 .18904 Mdot
.51101 .29583 Mdot
.35658 .60094 Mdot
.50822 .66351 Mdot
.57165 .49858 Mdot
.35817 .5686 Mdot
.24139 .57203 Mdot
.3875 .62197 Mdot
.66564 .49258 Mdot
.31349 .55314 Mdot
.34618 .45674 Mdot
.61744 .50209 Mdot
.35779 .58871 Mdot
.26486 .48791 Mdot
.61106 .54163 Mdot
.65434 .48265 Mdot
.81726 .42642 Mdot
.56444 .21869 Mdot
.52129 .68505 Mdot
.49222 .27883 Mdot
.58761 .48311 Mdot
.50717 .70045 Mdot
.43298 .75937 Mdot
.60036 .52909 Mdot
.48545 .36441 Mdot
.57511 .45589 Mdot
.37047 .64161 Mdot
.38146 .44004 Mdot
.48116 .589 Mdot
.51388 .70452 Mdot
.22337 .71093 Mdot
.4174 .62795 Mdot
.67487 .5294 Mdot
.60053 .46438 Mdot
.62016 .74139 Mdot
.49888 .29726 Mdot
.55159 .33354 Mdot
.6289 .53437 Mdot
.3071 .27861 Mdot
.60761 .51015 Mdot
.41688 .57045 Mdot
.47319 .34893 Mdot
.64069 .52631 Mdot
.37251 .50599 Mdot
.62201 .56698 Mdot
.54206 .69508 Mdot
.21574 .48066 Mdot
.56561 .48607 Mdot
.4169 .17116 Mdot
.52231 .56867 Mdot
.37535 .61058 Mdot
.36662 .75902 Mdot
.63596 .8378 Mdot
.32319 .35661 Mdot
.50087 .31416 Mdot
.5313 .8012 Mdot
.37486 .59555 Mdot
.33757 .72188 Mdot
.75402 .70209 Mdot
.64137 .48107 Mdot
.6714 .51419 Mdot
.67585 .69355 Mdot
.35078 .57963 Mdot
.34306 .61417 Mdot
.69082 .5092 Mdot
.60732 .56555 Mdot
.37197 .6015 Mdot
.60799 .54625 Mdot
.6834 .46318 Mdot
.38583 .46247 Mdot
.4836 .36214 Mdot
.3636 .42099 Mdot
.34774 .41294 Mdot
.19405 .47068 Mdot
.52883 .58082 Mdot
.37084 .43025 Mdot
.31804 .43048 Mdot
.59145 .61644 Mdot
.78104 .51357 Mdot
.49618 .67387 Mdot
.65165 .79774 Mdot
.39268 .59136 Mdot
.64443 .52 Mdot
.50923 .29149 Mdot
.60141 .39426 Mdot
.46479 .77038 Mdot
.47957 .20905 Mdot
.67372 .49671 Mdot
.36486 .59436 Mdot
.28857 .43709 Mdot
.66516 .43493 Mdot
.40561 .65053 Mdot
.60342 .52437 Mdot
.38366 .5684 Mdot
.75807 .45546 Mdot
.23432 .60718 Mdot
.43788 .64143 Mdot
.52835 .30299 Mdot
.59714 .51434 Mdot
.50055 .36356 Mdot
.37774 .45712 Mdot
.49844 .67074 Mdot
.52366 .68822 Mdot
.65424 .49947 Mdot
.5504 .53343 Mdot
.37049 .72459 Mdot
.64601 .49356 Mdot
.59983 .48209 Mdot
.3001 .41898 Mdot
.5945 .48278 Mdot
.61479 .45708 Mdot
.66086 .47197 Mdot
.67679 .48077 Mdot
.35329 .46196 Mdot
.29081 .6414 Mdot
.7044 .52254 Mdot
.68306 .54795 Mdot
.37676 .41559 Mdot
.54372 .78142 Mdot
.33748 .41585 Mdot
.76367 .68503 Mdot
.3189 .43888 Mdot
.5272 .67996 Mdot
.56614 .76359 Mdot
.60328 .57718 Mdot
.4717 .36405 Mdot
.30084 .44439 Mdot
.50502 .67094 Mdot
.36474 .44841 Mdot
.36281 .62165 Mdot
.82304 .42316 Mdot
.45712 .36926 Mdot
.44458 .2699 Mdot
.3394 .37846 Mdot
.27197 .61461 Mdot
.40472 .6338 Mdot
.51585 .35231 Mdot
.73169 .42002 Mdot
.61247 .45957 Mdot
.50578 .69925 Mdot
.65602 .5062 Mdot
.37619 .46272 Mdot
.37324 .5914 Mdot
.2182 .63768 Mdot
.51765 .69825 Mdot
.79584 .32881 Mdot
.40793 .60562 Mdot
.62747 .45727 Mdot
.34124 .41316 Mdot
.70623 .23735 Mdot
.35771 .42066 Mdot
.56127 .32662 Mdot
.48274 .29568 Mdot
.21109 .66131 Mdot
.49896 .33226 Mdot
.24266 .59283 Mdot
.63192 .16449 Mdot
.30136 .67771 Mdot
.47189 .31646 Mdot
.43359 .55235 Mdot
.60755 .49109 Mdot
.58791 .50671 Mdot
.22539 .61429 Mdot
.50291 .28339 Mdot
.60086 .46919 Mdot
.31341 .50998 Mdot
.36382 .40158 Mdot
.74247 .30788 Mdot
.40719 .62797 Mdot
.62037 .52326 Mdot
.36341 .47793 Mdot
.34024 .47165 Mdot
.41944 .60132 Mdot
.33898 .41964 Mdot
.62258 .49601 Mdot
.49955 .34142 Mdot
.364 .53614 Mdot
.53406 .68398 Mdot
.42714 .83453 Mdot
.53358 .71041 Mdot
.39083 .62376 Mdot
.59108 .54612 Mdot
.3768 .59801 Mdot
.75013 .78035 Mdot
.6105 .49694 Mdot
.4748 .32383 Mdot
.59944 .47716 Mdot
.59741 .51026 Mdot
.67636 .4861 Mdot
.36308 .60577 Mdot
.54578 .74318 Mdot
.59284 .5377 Mdot
.33741 .43347 Mdot
.61871 .28705 Mdot
.57757 .4649 Mdot
.45881 .62736 Mdot
.75346 .55569 Mdot
.38583 .379 Mdot
.48799 .28656 Mdot
.37959 .61449 Mdot
.48327 .32025 Mdot
.34096 .24163 Mdot
.48847 .32578 Mdot
.60874 .33213 Mdot
.73984 .42208 Mdot
.77069 .40818 Mdot
.76112 .39414 Mdot
.42679 .50383 Mdot
.4978 .28092 Mdot
.48406 .65469 Mdot
.46523 .3171 Mdot
.50836 .29988 Mdot
.34383 .14943 Mdot
.48784 .37069 Mdot
.618 .53031 Mdot
.58728 .45823 Mdot
.26523 .63755 Mdot
.62479 .64925 Mdot
.61419 .47309 Mdot
.61202 .46877 Mdot
.52314 .65734 Mdot
.33584 .24968 Mdot
.29905 .60159 Mdot
.554 .21814 Mdot
.43803 .80174 Mdot
.65369 .50686 Mdot
.58236 .48888 Mdot
.70116 .50676 Mdot
.58484 .17909 Mdot
.18661 .49287 Mdot
.53474 .31504 Mdot
.6908 .52984 Mdot
.299 .69029 Mdot
.6756 .49951 Mdot
.62105 .53935 Mdot
.61392 .49166 Mdot
.3744 .59522 Mdot
.48886 .2827 Mdot
.67666 .47411 Mdot
.60153 .75037 Mdot
.61631 .53533 Mdot
.28134 .42907 Mdot
.30156 .76828 Mdot
.62419 .52668 Mdot
.45792 .30725 Mdot
.5873 .50263 Mdot
.50519 .30289 Mdot
.5186 .33045 Mdot
.69049 .5252 Mdot
.59342 .30195 Mdot
.46298 .30467 Mdot
.63405 .49287 Mdot
.35899 .61901 Mdot
.69128 .76429 Mdot
.6654 .49631 Mdot
.49635 .67684 Mdot
.6341 .5369 Mdot
.49086 .68717 Mdot
.60666 .47939 Mdot
.42093 .62201 Mdot
.57643 .38898 Mdot
.3889 .59765 Mdot
.18137 .55989 Mdot
.42582 .61955 Mdot
.81742 .35702 Mdot
.5212 .30751 Mdot
.3018 .54255 Mdot
.41911 .21215 Mdot
.26214 .42794 Mdot
.49781 .42636 Mdot
.43365 .46097 Mdot
.35776 .41659 Mdot
.49004 .29702 Mdot
.38145 .24148 Mdot
.48329 .74602 Mdot
.47157 .71149 Mdot
.36961 .5774 Mdot
.14604 .44702 Mdot
.38197 .20398 Mdot
.65438 .55017 Mdot
.6985 .3843 Mdot
.66606 .33339 Mdot
.67636 .49788 Mdot
.6795 .49165 Mdot
.44117 .64934 Mdot
.59564 .54161 Mdot
.40628 .33241 Mdot
.39686 .62531 Mdot
.5028 .67461 Mdot
.46814 .33049 Mdot
.52665 .7072 Mdot
.50833 .75605 Mdot
.43251 .45228 Mdot
.37059 .62742 Mdot
.56523 .52382 Mdot
.62063 .47014 Mdot
.51016 .31107 Mdot
.48773 .25492 Mdot
.45914 .33822 Mdot
.51329 .6757 Mdot
.40233 .6227 Mdot
.23875 .32504 Mdot
.62063 .4678 Mdot
.48842 .35437 Mdot
.50311 .43364 Mdot
.5902 .48103 Mdot
.37436 .45571 Mdot
.60325 .49362 Mdot
.46754 .32247 Mdot
.59481 .48259 Mdot
.49938 .32995 Mdot
.39359 .61568 Mdot
.65172 .46377 Mdot
.65302 .47422 Mdot
.75711 .29117 Mdot
.52178 .6682 Mdot
.51366 .35889 Mdot
.50541 .60896 Mdot
.58658 .47619 Mdot
.27086 .52745 Mdot
.60715 .52627 Mdot
.47453 .39446 Mdot
.65146 .5481 Mdot
.28777 .40536 Mdot
.66539 .56248 Mdot
.66171 .50661 Mdot
.50937 .49715 Mdot
.6558 .33436 Mdot
.65598 .58066 Mdot
.31336 .43734 Mdot
.50919 .36589 Mdot
.74951 .32043 Mdot
.36619 .54447 Mdot
.35997 .63902 Mdot
.69201 .64149 Mdot
.66815 .46566 Mdot
.62799 .51797 Mdot
.40771 .38496 Mdot
.51923 .70262 Mdot
.49582 .36123 Mdot
.51397 .66529 Mdot
.7937 .34638 Mdot
.55027 .67701 Mdot
.418 .57084 Mdot
.35135 .71708 Mdot
.21319 .36768 Mdot
.52622 .65786 Mdot
.46673 .32107 Mdot
.33239 .69696 Mdot
.62988 .45373 Mdot
.51812 .55633 Mdot
.53186 .67224 Mdot
.14447 .54232 Mdot
.61658 .457 Mdot
.50116 .42368 Mdot
.37564 .43046 Mdot
.52195 .65893 Mdot
.38517 .4268 Mdot
.63266 .47466 Mdot
.30087 .60066 Mdot
.4999 .31447 Mdot
.39202 .43028 Mdot
.59589 .44396 Mdot
.51391 .67053 Mdot
.41431 .63534 Mdot
.40121 .46303 Mdot
.32309 .42166 Mdot
.58549 .7919 Mdot
.20771 .63706 Mdot
.40428 .62062 Mdot
.65622 .24734 Mdot
.3187 .45377 Mdot
.62295 .45228 Mdot
.35681 .24097 Mdot
.59139 .51057 Mdot
.23765 .40149 Mdot
.38188 .62095 Mdot
.2773 .62259 Mdot
.58735 .4843 Mdot
.66855 .50514 Mdot
.45291 .3536 Mdot
.3963 .60043 Mdot
.48872 .34312 Mdot
.52067 .35351 Mdot
.39527 .61539 Mdot
.49454 .32266 Mdot
.52868 .65389 Mdot
.40311 .26829 Mdot
.32272 .4429 Mdot
.33312 .44168 Mdot
.3859 .58799 Mdot
.3735 .61352 Mdot
.37906 .60186 Mdot
.6025 .4938 Mdot
.48389 .35828 Mdot
.62914 .48175 Mdot
.63882 .54106 Mdot
.61734 .27368 Mdot
.49629 .28481 Mdot
.62307 .48743 Mdot
.51617 .58742 Mdot
.52657 .47068 Mdot
.36203 .62612 Mdot
.37391 .43138 Mdot
.30998 .51801 Mdot
.23653 .55001 Mdot
.61668 .52218 Mdot
.56025 .63515 Mdot
.46575 .32024 Mdot
.51315 .69081 Mdot
.54915 .69212 Mdot
.51781 .68458 Mdot
.35034 .3892 Mdot
.5208 .30232 Mdot
.55325 .22387 Mdot
.6236 .52198 Mdot
.42209 .36518 Mdot
.53761 .32994 Mdot
.3603 .70092 Mdot
.37282 .43234 Mdot
.59928 .4752 Mdot
.48364 .58551 Mdot
.71115 .42779 Mdot
.59295 .50599 Mdot
.5837 .45714 Mdot
.44192 .78633 Mdot
.55099 .48696 Mdot
.45702 .3523 Mdot
.713 .2474 Mdot
.57384 .49992 Mdot
.25132 .34615 Mdot
.45387 .85165 Mdot
.60833 .52026 Mdot
.66619 .5148 Mdot
.63069 .4651 Mdot
.58164 .49816 Mdot
.46222 .30271 Mdot
.65008 .62594 Mdot
.31627 .44942 Mdot
.42239 .35783 Mdot
.36842 .46618 Mdot
.41469 .58425 Mdot
.28048 .62649 Mdot
.48461 .29669 Mdot
.53636 .6959 Mdot
.39723 .80049 Mdot
.63108 .21264 Mdot
.41845 .60749 Mdot
.20935 .41653 Mdot
.52947 .67321 Mdot
.60878 .45055 Mdot
.50286 .65731 Mdot
.38936 .64112 Mdot
.3296 .44332 Mdot
.56609 .47693 Mdot
.4718 .30977 Mdot
.46834 .35152 Mdot
.59608 .4751 Mdot
.31158 .71369 Mdot
.38216 .45014 Mdot
.31551 .4271 Mdot
.60402 .5352 Mdot
.57228 .49513 Mdot
.48988 .33958 Mdot
.39927 .58771 Mdot
.77735 .40585 Mdot
.50708 .6939 Mdot
.67915 .51293 Mdot
.59178 .4861 Mdot
.81337 .42229 Mdot
.33501 .43249 Mdot
.3911 .6504 Mdot
.63361 .55085 Mdot
.31234 .32888 Mdot
.62805 .5503 Mdot
.70044 .49529 Mdot
.35872 .6199 Mdot
.70886 .48322 Mdot
.68516 .51691 Mdot
.47529 .39011 Mdot
.37197 .42064 Mdot
.47961 .3276 Mdot
.46996 .38932 Mdot
.42612 .248 Mdot
.37017 .45594 Mdot
.61237 .48826 Mdot
.373 .4365 Mdot
.59934 .52787 Mdot
.57773 .51643 Mdot
.36747 .4281 Mdot
.48971 .34269 Mdot
.52272 .80109 Mdot
.29877 .66435 Mdot
.58084 .50757 Mdot
.68988 .51926 Mdot
.62414 .63359 Mdot
.51898 .73372 Mdot
.67193 .50919 Mdot
.46452 .32962 Mdot
.63333 .47064 Mdot
.38915 .44809 Mdot
.52165 .6528 Mdot
.47309 .31811 Mdot
.41143 .60133 Mdot
.41826 .61941 Mdot
.33823 .34734 Mdot
.35826 .5792 Mdot
.67071 .51843 Mdot
.45895 .28248 Mdot
.45121 .31521 Mdot
.36344 .78717 Mdot
.39812 .61329 Mdot
.49495 .67798 Mdot
.65565 .48558 Mdot
.73229 .63219 Mdot
.37044 .47683 Mdot
.29275 .20777 Mdot
.50595 .21341 Mdot
.51087 .6483 Mdot
.5103 .22843 Mdot
.42464 .6142 Mdot
.68841 .5003 Mdot
.49713 .68066 Mdot
.40536 .63187 Mdot
.58908 .52513 Mdot
.6927 .52247 Mdot
.5548 .33942 Mdot
.40779 .48137 Mdot
.36921 .43406 Mdot
.37949 .57112 Mdot
.49757 .65267 Mdot
.4322 .60371 Mdot
.52164 .32474 Mdot
.65375 .51729 Mdot
.59963 .5493 Mdot
.40288 .5886 Mdot
.35701 .63804 Mdot
.62827 .49063 Mdot
.47011 .30402 Mdot
.45334 .6432 Mdot
.64844 .50724 Mdot
.40378 .47613 Mdot
.50531 .28008 Mdot
.40527 .62633 Mdot
.6649 .50879 Mdot
.48303 .69009 Mdot
.40675 .59943 Mdot
.36427 .62907 Mdot
.58268 .48726 Mdot
.53496 .65705 Mdot
.67304 .54367 Mdot
.32323 .43316 Mdot
.14948 .47198 Mdot
.389 .4496 Mdot
.3802 .53702 Mdot
.54954 .48004 Mdot
.32111 .29855 Mdot
.49247 .28919 Mdot
.72584 .60038 Mdot
.31417 .5118 Mdot
.68419 .46259 Mdot
.68123 .75891 Mdot
.31773 .48204 Mdot
.35614 .7709 Mdot
.72932 .67935 Mdot
.53614 .67097 Mdot
.36239 .44926 Mdot
.66627 .51516 Mdot
.38739 .46189 Mdot
.49804 .68681 Mdot
.18267 .55715 Mdot
.66738 .49726 Mdot
.47096 .34426 Mdot
.6226 .49295 Mdot
.47407 .35395 Mdot
.57873 .49528 Mdot
.64785 .55905 Mdot
.27539 .46236 Mdot
.66034 .60055 Mdot
.63306 .54928 Mdot
.78699 .28408 Mdot
.53295 .42948 Mdot
.50306 .68588 Mdot
.63831 .48279 Mdot
.42399 .64331 Mdot
.35277 .47298 Mdot
.26914 .40176 Mdot
.37261 .59584 Mdot
.32411 .42232 Mdot
.49248 .32996 Mdot
.38483 .61811 Mdot
.41791 .60113 Mdot
.70824 .47842 Mdot
.51861 .64966 Mdot
.34342 .4481 Mdot
.64213 .52703 Mdot
.66667 .49918 Mdot
.65592 .24349 Mdot
.46418 .74946 Mdot
.47549 .25705 Mdot
.52068 .1694 Mdot
.52702 .33287 Mdot
.50659 .67279 Mdot
.36329 .60156 Mdot
.65072 .53626 Mdot
.62232 .50169 Mdot
.28136 .52849 Mdot
.45989 .32411 Mdot
.45666 .50796 Mdot
.50512 .24224 Mdot
.49542 .62243 Mdot
.66284 .60761 Mdot
.46691 .32948 Mdot
.65554 .60997 Mdot
.5422 .64655 Mdot
.58727 .82116 Mdot
.61882 .6097 Mdot
.37822 .43367 Mdot
.63791 .6149 Mdot
.49788 .35834 Mdot
.59246 .53539 Mdot
.35477 .61087 Mdot
.35353 .58871 Mdot
.48222 .33559 Mdot
.42284 .63659 Mdot
.54138 .67432 Mdot
.65492 .52618 Mdot
.55714 .20966 Mdot
.37216 .32116 Mdot
.38483 .58463 Mdot
.67971 .44536 Mdot
.35299 .45687 Mdot
.59498 .47547 Mdot
.53434 .6621 Mdot
.37435 .44439 Mdot
.79311 .53404 Mdot
.38286 .40636 Mdot
.65546 .49011 Mdot
.81691 .4218 Mdot
.36948 .45236 Mdot
.56984 .41552 Mdot
.64666 .51401 Mdot
.32766 .42727 Mdot
.69599 .44248 Mdot
.25297 .57891 Mdot
.49011 .5526 Mdot
.75498 .70222 Mdot
.48252 .51413 Mdot
.36465 .58996 Mdot
.26326 .59995 Mdot
.25706 .42418 Mdot
.33377 .46364 Mdot
.37472 .64788 Mdot
.5416 .58755 Mdot
.38182 .42405 Mdot
.61044 .45157 Mdot
.60487 .5221 Mdot
.18842 .50588 Mdot
.33243 .47943 Mdot
.23982 .59553 Mdot
.3527 .35922 Mdot
.58725 .47406 Mdot
.65814 .5518 Mdot
.6254 .50481 Mdot
.45408 .33335 Mdot
.35611 .4307 Mdot
.75482 .26774 Mdot
.37804 .45558 Mdot
.58589 .26091 Mdot
.38871 .59018 Mdot
.4057 .62945 Mdot
.61998 .52533 Mdot
.50356 .41682 Mdot
.77208 .54747 Mdot
.62686 .49561 Mdot
.5474 .7218 Mdot
.20176 .52509 Mdot
.57435 .4908 Mdot
.48104 .2926 Mdot
.69713 .47149 Mdot
.57814 .43253 Mdot
.32254 .44403 Mdot
.53801 .68916 Mdot
.74777 .58285 Mdot
.33313 .44808 Mdot
.62789 .51659 Mdot
.3277 .30293 Mdot
.60079 .50513 Mdot
.58259 .51135 Mdot
.54311 .24766 Mdot
.55208 .68332 Mdot
.38653 .60673 Mdot
.5188 .68177 Mdot
.50122 .29665 Mdot
.26303 .20884 Mdot
.54984 .68127 Mdot
.78137 .53618 Mdot
.17606 .51408 Mdot
.61845 .61593 Mdot
.49424 .36363 Mdot
.49952 .65628 Mdot
.38386 .44248 Mdot
.6879 .76852 Mdot
.55275 .36447 Mdot
.34589 .49507 Mdot
.64317 .509 Mdot
.49815 .37542 Mdot
.46571 .35312 Mdot
.39075 .42724 Mdot
.51851 .33645 Mdot
.70233 .54281 Mdot
.58599 .52536 Mdot
.35376 .46719 Mdot
.33339 .32291 Mdot
.31241 .44317 Mdot
.42912 .53768 Mdot
.64125 .48732 Mdot
.47184 .3225 Mdot
.68284 .5054 Mdot
.47933 .2752 Mdot
.40391 .6471 Mdot
.57308 .53294 Mdot
.54266 .67579 Mdot
.30689 .31407 Mdot
.40658 .61923 Mdot
.51773 .61502 Mdot
.50929 .30823 Mdot
.37519 .39009 Mdot
.51478 .31333 Mdot
.46114 .2879 Mdot
.33918 .41453 Mdot
.50754 .34455 Mdot
.66379 .5175 Mdot
.50315 .5653 Mdot
.5056 .31229 Mdot
.3492 .44148 Mdot
.53325 .69208 Mdot
.49644 .33246 Mdot
.44319 .60879 Mdot
.65937 .48803 Mdot
.36537 .6085 Mdot
.52258 .74715 Mdot
.49255 .37372 Mdot
.55461 .66689 Mdot
.35478 .63407 Mdot
.51111 .70586 Mdot
.30884 .74598 Mdot
.38712 .41578 Mdot
.57294 .27354 Mdot
.5409 .73086 Mdot
.46784 .3612 Mdot
.53961 .75593 Mdot
.63681 .54019 Mdot
.65785 .48603 Mdot
.49259 .68992 Mdot
.46549 .35286 Mdot
.51695 .84971 Mdot
.53735 .50056 Mdot
.41864 .51662 Mdot
.30243 .43217 Mdot
.81556 .34683 Mdot
.42154 .52864 Mdot
.41479 .84647 Mdot
.65211 .43645 Mdot
.34232 .61021 Mdot
.61658 .5152 Mdot
.29015 .5022 Mdot
.51739 .67114 Mdot
.43313 .5644 Mdot
.61069 .55825 Mdot
.38791 .61263 Mdot
.6529 .47025 Mdot
.50551 .50878 Mdot
.59017 .41618 Mdot
.49511 .68798 Mdot
.32603 .70875 Mdot
.49719 .37062 Mdot
.53369 .68068 Mdot
.39536 .63551 Mdot
.70778 .59216 Mdot
.5876 .52415 Mdot
.61848 .44946 Mdot
.49388 .62337 Mdot
.48567 .36018 Mdot
.35651 .59606 Mdot
.32416 .43531 Mdot
.53135 .69773 Mdot
.62079 .47145 Mdot
.63484 .54358 Mdot
.26658 .51629 Mdot
.35818 .4597 Mdot
.34834 .59072 Mdot
.37318 .42476 Mdot
.42157 .59973 Mdot
.58438 .53375 Mdot
.41516 .61847 Mdot
.67776 .47028 Mdot
.28121 .44264 Mdot
.5602 .25769 Mdot
.66185 .34869 Mdot
.38512 .62389 Mdot
.7789 .5006 Mdot
.36143 .45888 Mdot
.34939 .42005 Mdot
.17912 .44516 Mdot
.5584 .32447 Mdot
.63083 .22162 Mdot
.65306 .75257 Mdot
.35198 .46398 Mdot
.34925 .45085 Mdot
.36656 .61013 Mdot
.50914 .34159 Mdot
.52569 .33295 Mdot
.4197 .59789 Mdot
.63259 .69061 Mdot
.49545 .36111 Mdot
.64129 .79255 Mdot
.71684 .2843 Mdot
.66536 .45535 Mdot
.41451 .56559 Mdot
.51775 .69403 Mdot
.64288 .6758 Mdot
.50553 .52276 Mdot
.67072 .50131 Mdot
.72097 .62344 Mdot
.39222 .58705 Mdot
.47868 .40731 Mdot
.75508 .69099 Mdot
.65293 .46682 Mdot
.64592 .51852 Mdot
.6236 .51076 Mdot
.53162 .6502 Mdot
.56427 .36261 Mdot
.65983 .51726 Mdot
.63014 .69294 Mdot
.59046 .47489 Mdot
.60091 .41166 Mdot
.52198 .68675 Mdot
.60449 .60182 Mdot
.49526 .75221 Mdot
.71593 .2549 Mdot
.56054 .43223 Mdot
.32213 .43747 Mdot
.47364 .69555 Mdot
.35707 .41859 Mdot
.62051 .33366 Mdot
.58953 .61257 Mdot
.5291 .32882 Mdot
.67076 .50363 Mdot
.39166 .62441 Mdot
.4663 .35339 Mdot
.26339 .56395 Mdot
.30584 .17556 Mdot
.31944 .44478 Mdot
.5389 .8889 Mdot
.33216 .42513 Mdot
.41677 .59784 Mdot
.4896 .33841 Mdot
.74559 .43396 Mdot
.42212 .2942 Mdot
.49675 .32893 Mdot
.50485 .8277 Mdot
.53445 .30664 Mdot
.74178 .56454 Mdot
.46806 .36913 Mdot
.35174 .4461 Mdot
.33425 .38504 Mdot
.69511 .55765 Mdot
.62612 .53718 Mdot
.43727 .46001 Mdot
.76997 .54262 Mdot
.63854 .53963 Mdot
.39846 .62428 Mdot
.56215 .27465 Mdot
.70484 .62976 Mdot
.50425 .35075 Mdot
.37697 .40643 Mdot
.65311 .51395 Mdot
.58891 .49423 Mdot
.59079 .5308 Mdot
.51441 .2057 Mdot
.58302 .82242 Mdot
.591 .53642 Mdot
.57956 .48747 Mdot
.38657 .61615 Mdot
.51358 .72665 Mdot
.32251 .68576 Mdot
.63953 .25082 Mdot
.6671 .47415 Mdot
.53033 .68423 Mdot
.49535 .65029 Mdot
.61396 .5466 Mdot
.52274 .58016 Mdot
.33259 .29429 Mdot
.64382 .52643 Mdot
.56352 .28043 Mdot
.35979 .66967 Mdot
.35016 .57997 Mdot
.40813 .5968 Mdot
.50978 .36111 Mdot
.40596 .58727 Mdot
.4202 .62644 Mdot
.74364 .45134 Mdot
.471 .50822 Mdot
.29166 .46545 Mdot
.51161 .67741 Mdot
.61582 .50181 Mdot
.63088 .58539 Mdot
.31476 .32047 Mdot
.36082 .41543 Mdot
.47694 .3107 Mdot
.35583 .47434 Mdot
.49598 .643 Mdot
.44893 .24148 Mdot
.38124 .57885 Mdot
.33799 .45773 Mdot
.40647 .44092 Mdot
.52911 .68669 Mdot
.39343 .44311 Mdot
.41031 .41416 Mdot
.56541 .50653 Mdot
.68672 .38781 Mdot
.63439 .4949 Mdot
.40294 .80809 Mdot
.34579 .45423 Mdot
.31041 .39811 Mdot
.63324 .52268 Mdot
.40653 .60201 Mdot
.7338 .49646 Mdot
.62159 .53771 Mdot
.40193 .58548 Mdot
.64821 .55175 Mdot
.52955 .71142 Mdot
.49369 .27718 Mdot
.42071 .30306 Mdot
.14486 .43762 Mdot
.51414 .64968 Mdot
.26613 .55701 Mdot
.67391 .50083 Mdot
.24315 .68086 Mdot
.49702 .33599 Mdot
.65962 .53855 Mdot
.69493 .61908 Mdot
.50667 .32238 Mdot
.4851 .31658 Mdot
.60095 .48843 Mdot
.37775 .43086 Mdot
.40688 .62189 Mdot
.52516 .6899 Mdot
.3877 .82086 Mdot
.64742 .50104 Mdot
.64604 .47208 Mdot
.53178 .67693 Mdot
.36882 .46134 Mdot
.62731 .54952 Mdot
.65095 .72438 Mdot
.54902 .85005 Mdot
.33391 .42151 Mdot
.62976 .45567 Mdot
.62007 .35773 Mdot
.54122 .47223 Mdot
.21398 .68301 Mdot
.5218 .56619 Mdot
.38172 .60909 Mdot
.55259 .52251 Mdot
.388 .16535 Mdot
.53508 .69255 Mdot
.62981 .21425 Mdot
.58871 .49182 Mdot
.61716 .46623 Mdot
.45981 .33279 Mdot
.62977 .4845 Mdot
.48043 .29989 Mdot
.18541 .37613 Mdot
.81688 .40576 Mdot
.51923 .34363 Mdot
.47365 .36716 Mdot
.75311 .57327 Mdot
.34075 .53102 Mdot
.48423 .33465 Mdot
.57607 .51083 Mdot
.55562 .60217 Mdot
.47286 .40022 Mdot
.49443 .664 Mdot
.52974 .75811 Mdot
.55382 .55025 Mdot
.55076 .62564 Mdot
.54087 .78552 Mdot
.57233 .57438 Mdot
.45313 .56171 Mdot
.33785 .42637 Mdot
.65472 .46729 Mdot
.35307 .58808 Mdot
.35529 .58125 Mdot
.68482 .47814 Mdot
.607 .50045 Mdot
.50411 .29977 Mdot
.51916 .70037 Mdot
.32645 .46114 Mdot
.61555 .46846 Mdot
.72323 .59799 Mdot
.52661 .70381 Mdot
.51524 .33887 Mdot
.60657 .28065 Mdot
.52675 .71599 Mdot
.6559 .55907 Mdot
.63336 .53214 Mdot
.61777 .49162 Mdot
.68993 .56341 Mdot
.35387 .42805 Mdot
.55618 .7648 Mdot
.58214 .46642 Mdot
.78939 .33699 Mdot
.31316 .49139 Mdot
.57997 .5486 Mdot
.51985 .32114 Mdot
.33919 .40489 Mdot
.42991 .61665 Mdot
.41539 .24073 Mdot
.65407 .49179 Mdot
.31492 .71009 Mdot
.19139 .51678 Mdot
.38962 .64808 Mdot
.48168 .277 Mdot
.51376 .68448 Mdot
.62392 .4965 Mdot
.59153 .30513 Mdot
.60785 .5236 Mdot
.56155 .65867 Mdot
.36671 .63366 Mdot
.34088 .42497 Mdot
.37184 .78434 Mdot
.36727 .57247 Mdot
.4838 .31963 Mdot
.8324 .51777 Mdot
.48012 .29899 Mdot
.5246 .33663 Mdot
.61744 .28337 Mdot
.35407 .42702 Mdot
.33953 .17981 Mdot
.19609 .37609 Mdot
.57239 .52545 Mdot
.36708 .45987 Mdot
.47634 .33559 Mdot
.60123 .46609 Mdot
.52118 .27952 Mdot
.51567 .29543 Mdot
.57902 .52531 Mdot
.62561 .46248 Mdot
.25134 .63111 Mdot
.73269 .70695 Mdot
.51325 .68267 Mdot
.50191 .29298 Mdot
.41277 .31981 Mdot
.60075 .46486 Mdot
.62457 .52247 Mdot
.24478 .44105 Mdot
.51677 .65154 Mdot
.39527 .31524 Mdot
.58881 .49317 Mdot
.81499 .46416 Mdot
.7075 .5002 Mdot
.46589 .30068 Mdot
.35046 .4172 Mdot
.72944 .26977 Mdot
.41346 .42945 Mdot
.48074 .30094 Mdot
.54031 .69356 Mdot
.44944 .34391 Mdot
.78588 .52772 Mdot
.3711 .46419 Mdot
.46746 .32258 Mdot
.47995 .58655 Mdot
.36171 .43594 Mdot
.33985 .4541 Mdot
.62569 .27531 Mdot
.40112 .65105 Mdot
.52664 .64799 Mdot
.34571 .44982 Mdot
.31609 .27672 Mdot
.35533 .442 Mdot
.188 .39376 Mdot
.64574 .46186 Mdot
.67697 .66944 Mdot
.39144 .53856 Mdot
.56833 .55638 Mdot
.34807 .45829 Mdot
.52074 .65659 Mdot
.58925 .52359 Mdot
.5045 .35855 Mdot
.5074 .69888 Mdot
.37459 .48587 Mdot
.37225 .59993 Mdot
.51431 .31824 Mdot
.31771 .46558 Mdot
.46982 .35102 Mdot
.38049 .24305 Mdot
.16321 .51014 Mdot
.76196 .59368 Mdot
.4235 .28615 Mdot
.58623 .52224 Mdot
.60052 .7842 Mdot
.64124 .45595 Mdot
.60121 .49974 Mdot
.40204 .62638 Mdot
.6931 .65071 Mdot
.48898 .34261 Mdot
.46172 .83401 Mdot
.32489 .44767 Mdot
.72603 .26225 Mdot
.55274 .44583 Mdot
.67541 .53018 Mdot
.50381 .30891 Mdot
.46334 .31342 Mdot
.64607 .32076 Mdot
.42784 .59044 Mdot
.6773 .50712 Mdot
.57741 .45737 Mdot
.69119 .48691 Mdot
.32752 .44471 Mdot
.52952 .59917 Mdot
.36817 .58773 Mdot
.17715 .58007 Mdot
.36591 .63458 Mdot
.56162 .65052 Mdot
.50795 .34825 Mdot
.54958 .6817 Mdot
.62631 .52413 Mdot
.49511 .2535 Mdot
.45881 .32653 Mdot
.49528 .69438 Mdot
.51306 .66124 Mdot
.2444 .52578 Mdot
.36778 .42866 Mdot
.61782 .54078 Mdot
.66422 .51077 Mdot
.62461 .47997 Mdot
.60436 .49469 Mdot
.32139 .44749 Mdot
.59502 .53115 Mdot
.37315 .47797 Mdot
.43015 .22411 Mdot
.68181 .69046 Mdot
.48445 .51087 Mdot
.22165 .4137 Mdot
.50194 .35565 Mdot
.31671 .28312 Mdot
.56141 .4548 Mdot
.43176 .19286 Mdot
.20398 .58882 Mdot
.57154 .48193 Mdot
.41591 .62384 Mdot
.70352 .44312 Mdot
.36564 .57913 Mdot
.41807 .85692 Mdot
.26245 .46344 Mdot
.72157 .72465 Mdot
.66647 .49805 Mdot
.50086 .5649 Mdot
.28822 .29468 Mdot
.63161 .45299 Mdot
.25445 .50275 Mdot
.23664 .40004 Mdot
.31749 .6968 Mdot
.53049 .65775 Mdot
.65773 .49966 Mdot
.6448 .58329 Mdot
.66029 .52093 Mdot
.61892 .51903 Mdot
.59279 .53099 Mdot
.31366 .45258 Mdot
.66166 .53353 Mdot
.58985 .51556 Mdot
.37689 .73163 Mdot
.66119 .6052 Mdot
.34646 .61253 Mdot
.17661 .46869 Mdot
.55047 .67984 Mdot
.50655 .30767 Mdot
.57616 .81673 Mdot
.37775 .43373 Mdot
.65321 .32365 Mdot
.61004 .4934 Mdot
.26982 .64415 Mdot
.40531 .42944 Mdot
.54257 .68808 Mdot
.39317 .64165 Mdot
.72097 .73896 Mdot
.39518 .62179 Mdot
.3282 .40167 Mdot
.40608 .60624 Mdot
.5482 .47243 Mdot
.50359 .2984 Mdot
.61614 .54391 Mdot
.3414 .44559 Mdot
.41384 .60107 Mdot
.62668 .64235 Mdot
.62326 .50577 Mdot
.39504 .6145 Mdot
.61506 .54328 Mdot
.45008 .26115 Mdot
.68653 .27448 Mdot
.41608 .63025 Mdot
.40444 .44058 Mdot
.34146 .43417 Mdot
.53954 .66067 Mdot
.51069 .31752 Mdot
.47855 .30665 Mdot
.37287 .44447 Mdot
.53303 .26349 Mdot
.66915 .47467 Mdot
.61126 .46234 Mdot
.75293 .29601 Mdot
.66306 .52278 Mdot
.70912 .58907 Mdot
.48778 .58775 Mdot
.51267 .3497 Mdot
.67835 .5295 Mdot
.59749 .48637 Mdot
.65615 .48895 Mdot
.48383 .2344 Mdot
.39645 .58488 Mdot
.6505 .46482 Mdot
.50657 .66475 Mdot
.33222 .67278 Mdot
.59433 .47595 Mdot
.71287 .50603 Mdot
.47709 .30787 Mdot
.52397 .17545 Mdot
.33508 .42403 Mdot
.39522 .63475 Mdot
.38379 .62407 Mdot
.54591 .76881 Mdot
.27296 .34157 Mdot
.48882 .58638 Mdot
.18657 .62482 Mdot
.27575 .46243 Mdot
.5118 .66752 Mdot
.35646 .56446 Mdot
.31679 .38767 Mdot
.37305 .62237 Mdot
.31961 .44911 Mdot
.63015 .45671 Mdot
.66525 .47192 Mdot
.35053 .19865 Mdot
.62105 .54939 Mdot
.51607 .68833 Mdot
.31182 .44674 Mdot
.49619 .35783 Mdot
.53964 .6922 Mdot
.37195 .42342 Mdot
.5116 .35759 Mdot
.5729 .475 Mdot
.57908 .46698 Mdot
.47945 .30976 Mdot
.46161 .33577 Mdot
.63317 .52967 Mdot
.31666 .58282 Mdot
.47493 .36622 Mdot
.46635 .32808 Mdot
.38121 .58062 Mdot
.35607 .5828 Mdot
.68578 .54801 Mdot
.36037 .4567 Mdot
.59005 .51882 Mdot
.38692 .62035 Mdot
.54976 .67886 Mdot
.49069 .34538 Mdot
.5812 .50372 Mdot
.60151 .475 Mdot
.52965 .6879 Mdot
.54585 .67027 Mdot
.53156 .66144 Mdot
.33098 .47437 Mdot
.63291 .47877 Mdot
.48943 .33261 Mdot
.36051 .42596 Mdot
.50113 .64805 Mdot
.49969 .66091 Mdot
.38026 .55723 Mdot
.66005 .52936 Mdot
.36228 .5374 Mdot
.40741 .15638 Mdot
.796 .37496 Mdot
.40868 .64166 Mdot
.43128 .61457 Mdot
.59197 .64481 Mdot
.45704 .40288 Mdot
.3766 .4526 Mdot
.52151 .73107 Mdot
.76122 .57257 Mdot
.56385 .49265 Mdot
.57556 .49256 Mdot
.64478 .55759 Mdot
.52755 .66066 Mdot
.70468 .65378 Mdot
.48654 .29643 Mdot
.66198 .59 Mdot
.52361 .70527 Mdot
.35159 .63011 Mdot
.36861 .55442 Mdot
.37001 .6372 Mdot
.60006 .45376 Mdot
.67679 .35774 Mdot
.29404 .31253 Mdot
.64144 .7475 Mdot
.35411 .45957 Mdot
.62667 .58521 Mdot
.24093 .67256 Mdot
.48364 .31188 Mdot
.41372 .58246 Mdot
.50941 .66729 Mdot
.46221 .33881 Mdot
.36448 .4735 Mdot
.34742 .44893 Mdot
.38289 .58514 Mdot
.37933 .58813 Mdot
.36339 .61979 Mdot
.51566 .29306 Mdot
.50804 .34612 Mdot
.65204 .49028 Mdot
.49375 .349 Mdot
.4798 .19841 Mdot
.49491 .70013 Mdot
.40331 .65643 Mdot
.36181 .45195 Mdot
.49895 .36341 Mdot
.62549 .50357 Mdot
.45438 .3924 Mdot
.29074 .37533 Mdot
.50125 .68443 Mdot
.66982 .25777 Mdot
.38457 .83278 Mdot
.62315 .54211 Mdot
.34446 .42942 Mdot
.55741 .20505 Mdot
.62637 .50963 Mdot
.36023 .60392 Mdot
.39858 .77202 Mdot
.32384 .60678 Mdot
.61861 .53698 Mdot
.56233 .50578 Mdot
.32232 .43065 Mdot
.18403 .58862 Mdot
.65012 .49489 Mdot
.39774 .29498 Mdot
.40235 .42899 Mdot
.36091 .59454 Mdot
.67647 .80907 Mdot
.47184 .65204 Mdot
.64061 .682 Mdot
.37704 .58429 Mdot
.59736 .5118 Mdot
.37479 .57653 Mdot
.50207 .67104 Mdot
.39831 .63813 Mdot
.47857 .29779 Mdot
.36616 .63862 Mdot
.645 .47136 Mdot
.482 .33311 Mdot
.36964 .45339 Mdot
.70032 .24859 Mdot
.42439 .76928 Mdot
.40543 .5998 Mdot
.42056 .6202 Mdot
.67219 .53786 Mdot
.40245 .33383 Mdot
.68154 .47783 Mdot
.61977 .45699 Mdot
.36041 .46536 Mdot
.50777 .31962 Mdot
.33443 .41955 Mdot
.62269 .57391 Mdot
.6949 .6939 Mdot
.36978 .42377 Mdot
.30395 .67756 Mdot
.52812 .67168 Mdot
.48032 .44733 Mdot
.62112 .50062 Mdot
.39076 .43365 Mdot
.63595 .47988 Mdot
.49093 .29506 Mdot
.49043 .48598 Mdot
.29882 .62279 Mdot
.33463 .4454 Mdot
.33702 .74552 Mdot
.65052 .71319 Mdot
.69388 .54549 Mdot
.34877 .41938 Mdot
.69398 .62687 Mdot
.41564 .59561 Mdot
.50763 .69583 Mdot
.51953 .71333 Mdot
.52062 .70709 Mdot
.67202 .45357 Mdot
.55735 .43754 Mdot
.55516 .66602 Mdot
.35549 .47221 Mdot
.49517 .68752 Mdot
.24124 .34694 Mdot
.46613 .83359 Mdot
.52056 .67197 Mdot
.64592 .5118 Mdot
.61334 .42373 Mdot
.59413 .61625 Mdot
.24897 .57756 Mdot
.70681 .73694 Mdot
.22046 .47896 Mdot
.62057 .53455 Mdot
.51493 .28559 Mdot
.50734 .29084 Mdot
.56339 .19071 Mdot
.77529 .52448 Mdot
.80696 .40422 Mdot
.50672 .36964 Mdot
.3091 .54557 Mdot
.51533 .33236 Mdot
.60125 .54093 Mdot
.60741 .46341 Mdot
.51083 .36838 Mdot
.70762 .67415 Mdot
.29589 .55455 Mdot
.37888 .80172 Mdot
.46552 .34526 Mdot
.37027 .42005 Mdot
.36464 .41255 Mdot
.342 .45605 Mdot
.69417 .26141 Mdot
.50072 .31065 Mdot
.61517 .47548 Mdot
.38764 .62529 Mdot
.66542 .47543 Mdot
.36443 .43482 Mdot
.47609 .84161 Mdot
.50001 .32601 Mdot
.65693 .51421 Mdot
.72417 .50913 Mdot
.37562 .59282 Mdot
.52847 .6798 Mdot
.4279 .29933 Mdot
.80414 .41236 Mdot
.32925 .45195 Mdot
.4958 .37322 Mdot
.2986 .4093 Mdot
.39547 .79663 Mdot
.65187 .43494 Mdot
.56259 .47099 Mdot
.38697 .82308 Mdot
.81013 .49221 Mdot
.67465 .50805 Mdot
.40767 .63288 Mdot
.27762 .52044 Mdot
.59172 .48168 Mdot
.50407 .29085 Mdot
.5261 .71528 Mdot
.50913 .70365 Mdot
.68916 .5456 Mdot
.425 .38218 Mdot
.49998 .51966 Mdot
.60987 .48884 Mdot
.65227 .5594 Mdot
.36556 .59044 Mdot
.28016 .48665 Mdot
.79452 .34726 Mdot
.54745 .68238 Mdot
.61803 .54539 Mdot
.49522 .8135 Mdot
.4584 .34021 Mdot
.39327 .64735 Mdot
.38962 .45336 Mdot
.53717 .3305 Mdot
.39566 .64113 Mdot
.57807 .50503 Mdot
.61997 .54833 Mdot
.35414 .41302 Mdot
.46672 .30057 Mdot
.52839 .66255 Mdot
.40105 .62955 Mdot
.54328 .67027 Mdot
.50542 .32116 Mdot
.49969 .3476 Mdot
.71949 .51661 Mdot
.62452 .43169 Mdot
.41093 .60195 Mdot
.67487 .46396 Mdot
.32058 .61687 Mdot
.24587 .72503 Mdot
.30073 .44415 Mdot
.65381 .53726 Mdot
.45922 .36315 Mdot
.33088 .44629 Mdot
.62085 .46493 Mdot
.43179 .85091 Mdot
.59496 .46822 Mdot
.30388 .42669 Mdot
.79229 .5551 Mdot
.53841 .66804 Mdot
.61512 .59464 Mdot
.23143 .62029 Mdot
.6563 .52907 Mdot
.37431 .61755 Mdot
.68352 .45052 Mdot
.38374 .43704 Mdot
.50529 .35037 Mdot
.2375 .725 Mdot
.35133 .43934 Mdot
.65097 .52731 Mdot
.53431 .69639 Mdot
.45881 .3572 Mdot
.53142 .57164 Mdot
.52328 .58483 Mdot
.68755 .44137 Mdot
.67998 .50961 Mdot
.59558 .49453 Mdot
.65826 .72613 Mdot
.38991 .6339 Mdot
.46919 .33212 Mdot
.33919 .43042 Mdot
.37512 .44698 Mdot
.38863 .58517 Mdot
.37583 .52435 Mdot
.47936 .44791 Mdot
.495 .13914 Mdot
.38728 .57511 Mdot
.54655 .69123 Mdot
.40129 .31703 Mdot
.39205 .63028 Mdot
.39667 .61057 Mdot
.3785 .58041 Mdot
.46741 .57176 Mdot
.49485 .3621 Mdot
.57779 .50269 Mdot
.4874 .28681 Mdot
.59549 .51197 Mdot
.30779 .42256 Mdot
.33834 .44701 Mdot
.50267 .33027 Mdot
.34057 .7784 Mdot
.65959 .38477 Mdot
.63398 .51368 Mdot
.24352 .68026 Mdot
.60269 .55369 Mdot
.60484 .62396 Mdot
.62811 .55595 Mdot
.39822 .59391 Mdot
.6209 .44777 Mdot
.68648 .46952 Mdot
.59439 .19755 Mdot
.36253 .45458 Mdot
.34891 .57933 Mdot
.61048 .56345 Mdot
.661 .55549 Mdot
.51943 .29575 Mdot
.46277 .33604 Mdot
.51883 .71193 Mdot
.70523 .58075 Mdot
.37146 .45537 Mdot
.23752 .31816 Mdot
.62752 .53657 Mdot
.52307 .6235 Mdot
.7559 .37643 Mdot
.62429 .46485 Mdot
.24522 .64984 Mdot
.67003 .34916 Mdot
.62296 .49772 Mdot
.43092 .49754 Mdot
.35974 .45901 Mdot
.73086 .66914 Mdot
.58768 .47918 Mdot
.36933 .5959 Mdot
.51162 .34153 Mdot
.45733 .3281 Mdot
.53179 .70896 Mdot
.38602 .20135 Mdot
.33386 .41891 Mdot
.50527 .3418 Mdot
.61649 .50742 Mdot
.34569 .42764 Mdot
.39296 .57688 Mdot
.67022 .5346 Mdot
.78479 .49523 Mdot
.49086 .35275 Mdot
.64546 .553 Mdot
.38451 .2806 Mdot
.60904 .67517 Mdot
.79935 .57774 Mdot
.33424 .43216 Mdot
.53724 .65998 Mdot
.70118 .48666 Mdot
.55262 .32097 Mdot
.68508 .53169 Mdot
.65788 .68526 Mdot
.23323 .36007 Mdot
.52464 .65329 Mdot
.63722 .52073 Mdot
.61829 .47198 Mdot
.52449 .42054 Mdot
.54458 .68901 Mdot
.66692 .5015 Mdot
.53987 .35889 Mdot
.47566 .35324 Mdot
.4163 .58795 Mdot
.49217 .35844 Mdot
.64274 .50971 Mdot
.63181 .43081 Mdot
.46054 .33234 Mdot
.25835 .72144 Mdot
.50393 .71668 Mdot
.34631 .42159 Mdot
.5791 .53498 Mdot
.58971 .46366 Mdot
.73134 .23317 Mdot
.38309 .648 Mdot
.30865 .60556 Mdot
.37819 .69018 Mdot
.5194 .79291 Mdot
.46776 .6564 Mdot
.78804 .64442 Mdot
.81036 .49862 Mdot
.66139 .53449 Mdot
.53786 .55429 Mdot
.35435 .26793 Mdot
.36216 .46245 Mdot
.32632 .24425 Mdot
.62634 .53742 Mdot
.61697 .5173 Mdot
.4159 .6386 Mdot
.2878 .61962 Mdot
.80744 .39952 Mdot
.4418 .38233 Mdot
.53051 .66458 Mdot
.50598 .29729 Mdot
.57686 .50781 Mdot
.44963 .50997 Mdot
.35605 .63642 Mdot
.48629 .6455 Mdot
.65366 .51702 Mdot
.51113 .22175 Mdot
.30198 .36341 Mdot
.36302 .42919 Mdot
.38156 .62326 Mdot
.80621 .4302 Mdot
.65305 .53525 Mdot
.39487 .44243 Mdot
.64296 .50051 Mdot
.46467 .63046 Mdot
.61161 .57239 Mdot
.51123 .67112 Mdot
.58523 .49769 Mdot
.46454 .66842 Mdot
.83643 .35317 Mdot
.55564 .65625 Mdot
.53116 .3098 Mdot
.36297 .64766 Mdot
.39909 .58579 Mdot
.46316 .33077 Mdot
.404 .5914 Mdot
.65468 .30849 Mdot
.75449 .45673 Mdot
.52961 .66993 Mdot
.68896 .54068 Mdot
.52176 .67693 Mdot
.40025 .64745 Mdot
.62066 .53613 Mdot
.30623 .7848 Mdot
.41319 .61215 Mdot
.82093 .48152 Mdot
.35918 .44244 Mdot
.35903 .64027 Mdot
.59065 .4753 Mdot
.28852 .40934 Mdot
.36646 .57308 Mdot
.2989 .58478 Mdot
.65563 .48908 Mdot
.49769 .3538 Mdot
.59691 .47932 Mdot
.57307 .52489 Mdot
.34357 .61162 Mdot
.59532 .52272 Mdot
.37334 .424 Mdot
.51095 .36479 Mdot
.66787 .77945 Mdot
.24948 .3781 Mdot
.66865 .50533 Mdot
.61927 .5081 Mdot
.45345 .307 Mdot
.60666 .45421 Mdot
.32122 .44658 Mdot
.10354 .46374 Mdot
.52826 .67225 Mdot
.33709 .59603 Mdot
.45971 .66924 Mdot
.56906 .48447 Mdot
.59155 .52711 Mdot
.4671 .86546 Mdot
.68689 .6957 Mdot
.35764 .41924 Mdot
.69155 .48568 Mdot
.38505 .57255 Mdot
.52383 .69856 Mdot
.34107 .46838 Mdot
.62022 .49125 Mdot
.62949 .52332 Mdot
.54369 .6637 Mdot
.56333 .62237 Mdot
.73831 .30236 Mdot
.38285 .42205 Mdot
.5492 .48405 Mdot
.446 .62531 Mdot
.67301 .47684 Mdot
.66422 .24492 Mdot
.47043 .32027 Mdot
.33209 .45494 Mdot
.54395 .77846 Mdot
.65601 .53476 Mdot
.35306 .41599 Mdot
.37025 .45589 Mdot
.6856 .52129 Mdot
.47737 .38024 Mdot
.51579 .35743 Mdot
.47337 .35446 Mdot
.27512 .23409 Mdot
.64871 .66398 Mdot
.3633 .61969 Mdot
.36218 .45996 Mdot
.42289 .61745 Mdot
.56202 .65918 Mdot
.48854 .55871 Mdot
.42068 .62298 Mdot
.48263 .36185 Mdot
.34162 .62156 Mdot
.63679 .47502 Mdot
.3717 .45349 Mdot
.3692 .61947 Mdot
.56971 .5155 Mdot
.41436 .36698 Mdot
.22572 .54357 Mdot
.50494 .65982 Mdot
.53448 .71308 Mdot
.60133 .46823 Mdot
.42661 .59267 Mdot
.62989 .52891 Mdot
.38905 .45884 Mdot
.41092 .34515 Mdot
.57709 .52914 Mdot
.40403 .59625 Mdot
.45148 .31842 Mdot
.80412 .42381 Mdot
.64175 .44283 Mdot
.64474 .51303 Mdot
.59577 .51722 Mdot
.64321 .49995 Mdot
.39369 .78944 Mdot
.35206 .40915 Mdot
.22599 .40872 Mdot
.54892 .7605 Mdot
.49672 .32221 Mdot
.48363 .28427 Mdot
.78846 .35025 Mdot
.34692 .27912 Mdot
.35985 .45717 Mdot
.60235 .49785 Mdot
.30852 .33692 Mdot
.548 .84919 Mdot
.36269 .80754 Mdot
.55939 .41458 Mdot
.38114 .64885 Mdot
.49652 .37261 Mdot
.41513 .5988 Mdot
.60061 .5161 Mdot
.66271 .55271 Mdot
.81416 .60663 Mdot
.36702 .47031 Mdot
.52516 .66642 Mdot
.59356 .51162 Mdot
.64474 .66835 Mdot
.38509 .61666 Mdot
.35706 .63922 Mdot
.63569 .46042 Mdot
.45455 .31872 Mdot
.82309 .34521 Mdot
.35299 .42832 Mdot
.23172 .44859 Mdot
.28217 .29947 Mdot
.32105 .36915 Mdot
.36181 .43256 Mdot
.52771 .4352 Mdot
.39898 .64535 Mdot
.74358 .34956 Mdot
.49482 .31524 Mdot
.50558 .69588 Mdot
.5746 .54372 Mdot
.46714 .31516 Mdot
.35798 .62399 Mdot
.50224 .35238 Mdot
.59071 .52814 Mdot
.39156 .41673 Mdot
.37942 .60845 Mdot
.29575 .47416 Mdot
.45776 .36124 Mdot
.5424 .69091 Mdot
.44162 .4117 Mdot
.62155 .39998 Mdot
.66807 .34556 Mdot
.64313 .46195 Mdot
.45025 .51849 Mdot
.61725 .47673 Mdot
.47406 .28111 Mdot
.6309 .50307 Mdot
.44588 .30948 Mdot
.37455 .61644 Mdot
.58037 .48632 Mdot
.60622 .4905 Mdot
.18839 .41118 Mdot
.66312 .50027 Mdot
.68002 .48056 Mdot
.61882 .49684 Mdot
.48497 .25917 Mdot
.69592 .53207 Mdot
.51946 .3161 Mdot
.33972 .69568 Mdot
.39667 .60707 Mdot
.50668 .70463 Mdot
.53864 .6578 Mdot
.68183 .6588 Mdot
.48277 .73527 Mdot
.27609 .6232 Mdot
.4816 .35305 Mdot
.38703 .43558 Mdot
.63575 .50096 Mdot
.75093 .6914 Mdot
.43614 .65597 Mdot
.35388 .63135 Mdot
.25045 .37902 Mdot
.55243 .53109 Mdot
.74976 .65387 Mdot
.69083 .49118 Mdot
.32424 .2136 Mdot
.59503 .44251 Mdot
.56781 .54411 Mdot
.39884 .57533 Mdot
.53251 .63189 Mdot
.60442 .45715 Mdot
.52385 .30815 Mdot
.50618 .68574 Mdot
.54916 .45508 Mdot
.38945 .54534 Mdot
.32259 .66355 Mdot
.44216 .29573 Mdot
.64453 .48427 Mdot
.37988 .60736 Mdot
.51359 .31606 Mdot
.79986 .36262 Mdot
.3579 .42517 Mdot
.38303 .52485 Mdot
.40791 .25996 Mdot
.26439 .719 Mdot
.5289 .70355 Mdot
.69584 .29472 Mdot
.64206 .47151 Mdot
.37012 .74621 Mdot
.58011 .53459 Mdot
.49117 .84793 Mdot
.55298 .66936 Mdot
.48587 .36433 Mdot
.3756 .42223 Mdot
.50193 .29043 Mdot
.65325 .3388 Mdot
.4004 .5557 Mdot
.46904 .48505 Mdot
.39569 .61996 Mdot
.50734 .54006 Mdot
.47611 .33076 Mdot
.61098 .54171 Mdot
.48931 .13781 Mdot
.46739 .3253 Mdot
.46236 .36215 Mdot
.17727 .52565 Mdot
.27527 .75644 Mdot
.56924 .45965 Mdot
.4757 .3677 Mdot
.4001 .61696 Mdot
.51141 .68464 Mdot
.58631 .48759 Mdot
.64625 .48109 Mdot
.46987 .31269 Mdot
.3426 .60007 Mdot
.59003 .34759 Mdot
.38517 .58863 Mdot
.49187 .36202 Mdot
.38864 .59786 Mdot
.31487 .39934 Mdot
.39874 .6329 Mdot
.58994 .46307 Mdot
.63214 .50244 Mdot
.44084 .69543 Mdot
.49923 .34843 Mdot
.61136 .48787 Mdot
.67065 .53894 Mdot
.48794 .33496 Mdot
.51735 .48955 Mdot
.59837 .34595 Mdot
.67357 .49637 Mdot
.66057 .4928 Mdot
.53089 .65593 Mdot
.47382 .5408 Mdot
.67958 .27266 Mdot
.58808 .52072 Mdot
.5345 .65193 Mdot
.52441 .31733 Mdot
.64225 .52776 Mdot
.54999 .82681 Mdot
.27985 .52478 Mdot
.62557 .54099 Mdot
.41607 .59686 Mdot
.68853 .47546 Mdot
.80337 .56219 Mdot
.61757 .45677 Mdot
.48221 .33947 Mdot
.50834 .33244 Mdot
.22155 .34329 Mdot
.48225 .32085 Mdot
.35367 .58823 Mdot
.36334 .43564 Mdot
.38907 .79719 Mdot
.40052 .58205 Mdot
.6236 .43703 Mdot
.15714 .43534 Mdot
.64945 .54703 Mdot
.57277 .48531 Mdot
.83374 .45099 Mdot
.41544 .60493 Mdot
.50033 .30155 Mdot
.46036 .415 Mdot
.60435 .43302 Mdot
.33467 .45508 Mdot
.60903 .56699 Mdot
.62963 .45589 Mdot
.80657 .53208 Mdot
.40182 .78825 Mdot
.39657 .44494 Mdot
.67857 .4792 Mdot
.58922 .52333 Mdot
.42369 .64293 Mdot
.61995 .50425 Mdot
.51095 .67973 Mdot
.50268 .31189 Mdot
.40644 .63106 Mdot
.53222 .688 Mdot
.64685 .53646 Mdot
.53057 .66175 Mdot
.36502 .60877 Mdot
.38386 .46054 Mdot
.60691 .52566 Mdot
.49351 .66622 Mdot
.53151 .66344 Mdot
.61736 .47893 Mdot
.5073 .35085 Mdot
.54728 .52761 Mdot
.66341 .50379 Mdot
.58171 .50565 Mdot
.48006 .30548 Mdot
.64795 .83905 Mdot
.60981 .46184 Mdot
.66445 .68887 Mdot
.46378 .31434 Mdot
.50974 .52579 Mdot
.40708 .58335 Mdot
.62039 .45353 Mdot
.38401 .46084 Mdot
.38727 .45399 Mdot
.36873 .6376 Mdot
.48891 .37512 Mdot
.39171 .68669 Mdot
.49714 .38407 Mdot
.6859 .45825 Mdot
.67286 .47081 Mdot
.55 .37079 Mdot
.73393 .71962 Mdot
.48883 .2905 Mdot
.41241 .5517 Mdot
.42841 .37495 Mdot
.39158 .43836 Mdot
.34614 .61283 Mdot
.50889 .37015 Mdot
.48603 .29903 Mdot
.51074 .3534 Mdot
.50367 .69448 Mdot
.44419 .6984 Mdot
.46313 .30768 Mdot
.45809 .30678 Mdot
.65302 .48348 Mdot
.58699 .516 Mdot
.80091 .46145 Mdot
.78262 .44892 Mdot
.516 .65806 Mdot
.35643 .60939 Mdot
.25465 .23935 Mdot
.37768 .46604 Mdot
.20442 .41902 Mdot
.57375 .49154 Mdot
.31164 .17803 Mdot
.58855 .48036 Mdot
.61456 .5057 Mdot
.51274 .36372 Mdot
.49532 .66554 Mdot
.52468 .67511 Mdot
.46891 .32996 Mdot
.46777 .29071 Mdot
.51179 .67798 Mdot
.22289 .62057 Mdot
.56913 .83078 Mdot
.32551 .63563 Mdot
.49287 .33583 Mdot
.7126 .42953 Mdot
.37204 .41645 Mdot
.59158 .4256 Mdot
.40136 .43405 Mdot
.39091 .61473 Mdot
.40107 .64133 Mdot
.33054 .4501 Mdot
.65533 .49176 Mdot
.36879 .62517 Mdot
.65194 .54062 Mdot
.20926 .50548 Mdot
.66521 .36761 Mdot
.43395 .67082 Mdot
.66426 .42521 Mdot
.51768 .47717 Mdot
.29726 .47778 Mdot
.64335 .53382 Mdot
.53476 .80683 Mdot
.52885 .66646 Mdot
.68861 .45517 Mdot
.33681 .45902 Mdot
.8394 .4731 Mdot
.6124 .53209 Mdot
.48416 .34274 Mdot
.36851 .45803 Mdot
.42599 .23588 Mdot
.40178 .29826 Mdot
.59524 .51458 Mdot
.42278 .15852 Mdot
.50511 .26331 Mdot
.38718 .62913 Mdot
.49458 .22321 Mdot
.47614 .29135 Mdot
.47547 .68691 Mdot
.56725 .7716 Mdot
.3124 .75977 Mdot
.50645 .30632 Mdot
.40299 .64922 Mdot
.52129 .32878 Mdot
.53683 .69662 Mdot
.52844 .30532 Mdot
.37945 .61562 Mdot
.64999 .51815 Mdot
.39454 .58798 Mdot
.50026 .68839 Mdot
.74331 .31324 Mdot
.39646 .44451 Mdot
.35751 .57301 Mdot
.33798 .44124 Mdot
.59325 .68702 Mdot
.63682 .73629 Mdot
.34073 .42425 Mdot
.58636 .28945 Mdot
.6672 .46641 Mdot
.46978 .29677 Mdot
.38796 .58172 Mdot
.48666 .77443 Mdot
.44057 .40546 Mdot
.49131 .31411 Mdot
.36021 .62261 Mdot
.41493 .29334 Mdot
.54394 .26675 Mdot
.68033 .47794 Mdot
.57861 .61469 Mdot
.49148 .33227 Mdot
.41008 .64459 Mdot
.74413 .28372 Mdot
.52193 .32357 Mdot
.38267 .57404 Mdot
.36676 .41812 Mdot
.376 .44321 Mdot
.66577 .47916 Mdot
.353 .40417 Mdot
.37529 .63603 Mdot
.36159 .49794 Mdot
.47782 .36966 Mdot
.44815 .22894 Mdot
.49002 .67998 Mdot
.39673 .59959 Mdot
.63414 .5518 Mdot
.48264 .27304 Mdot
.26582 .48256 Mdot
.60059 .36192 Mdot
.5172 .1675 Mdot
.38876 .5854 Mdot
.49782 .30749 Mdot
.4863 .34553 Mdot
.64429 .44231 Mdot
.42557 .28331 Mdot
.39217 .6906 Mdot
.53759 .41004 Mdot
.51629 .41034 Mdot
.41567 .58608 Mdot
.339 .5686 Mdot
.61185 .56454 Mdot
.64472 .4895 Mdot
.38973 .43452 Mdot
.65101 .51499 Mdot
.49555 .36924 Mdot
.64235 .46229 Mdot
.34077 .43077 Mdot
.39708 .62361 Mdot
.61109 .5286 Mdot
.53566 .6639 Mdot
.34255 .41209 Mdot
.36357 .47505 Mdot
.40182 .60003 Mdot
.46986 .31167 Mdot
.51872 .54706 Mdot
.3772 .5884 Mdot
.64555 .48497 Mdot
.47229 .55705 Mdot
.59025 .53004 Mdot
.57866 .58278 Mdot
.52138 .31232 Mdot
.40773 .62977 Mdot
.51872 .36109 Mdot
.3456 .44155 Mdot
.55025 .7618 Mdot
.63783 .50846 Mdot
.38843 .57543 Mdot
.30786 .5045 Mdot
.56923 .58557 Mdot
.45043 .34844 Mdot
.23738 .60291 Mdot
.48337 .28199 Mdot
.3561 .60321 Mdot
.1752 .44772 Mdot
.51471 .7027 Mdot
.35532 .63386 Mdot
.69366 .75725 Mdot
.41095 .60876 Mdot
.65832 .47317 Mdot
.60534 .46676 Mdot
.40063 .63222 Mdot
.53811 .65943 Mdot
.815 .39585 Mdot
.32986 .61486 Mdot
.50269 .30441 Mdot
.19874 .54078 Mdot
.60509 .18084 Mdot
.30427 .47193 Mdot
.38912 .43574 Mdot
.57391 .45032 Mdot
.64602 .455 Mdot
.34489 .46467 Mdot
.39885 .45166 Mdot
.51865 .70996 Mdot
.37385 .57843 Mdot
.48205 .26988 Mdot
.34056 .47538 Mdot
.43696 .28696 Mdot
.47119 .72332 Mdot
.6426 .44373 Mdot
.27354 .31286 Mdot
.57472 .49511 Mdot
.60506 .73929 Mdot
.33762 .43133 Mdot
.60122 .54351 Mdot
.68406 .47698 Mdot
.36494 .4654 Mdot
.5102 .68516 Mdot
.38083 .52753 Mdot
.38546 .60029 Mdot
.65948 .82225 Mdot
.66821 .53174 Mdot
.64483 .46573 Mdot
.34941 .45773 Mdot
.38706 .73028 Mdot
.49952 .32098 Mdot
.49721 .2836 Mdot
.39031 .63371 Mdot
.43079 .42093 Mdot
.66087 .46762 Mdot
.64794 .52765 Mdot
.37832 .60213 Mdot
.34976 .59026 Mdot
.26453 .59972 Mdot
.62051 .4696 Mdot
.35902 .45185 Mdot
.55973 .64182 Mdot
.33292 .43407 Mdot
.59528 .53575 Mdot
.63988 .46522 Mdot
.58957 .46277 Mdot
.62403 .55011 Mdot
.40438 .43383 Mdot
.58415 .53 Mdot
.68616 .5377 Mdot
.4955 .30912 Mdot
.59014 .51174 Mdot
.50502 .41059 Mdot
.65225 .50821 Mdot
.51157 .68203 Mdot
.64285 .25062 Mdot
.61176 .53139 Mdot
.63718 .45899 Mdot
.33628 .60609 Mdot
.63167 .51827 Mdot
.3867 .46133 Mdot
.49852 .34056 Mdot
.35737 .45834 Mdot
.38844 .45336 Mdot
.4261 .623 Mdot
.55039 .68684 Mdot
.56758 .48643 Mdot
.50249 .67296 Mdot
.63654 .43544 Mdot
.65705 .53419 Mdot
.50602 .74206 Mdot
.30474 .22398 Mdot
.70602 .2711 Mdot
.63989 .50746 Mdot
.41487 .60878 Mdot
.41614 .6003 Mdot
.52921 .53416 Mdot
.68229 .49238 Mdot
.32443 .45788 Mdot
.39237 .44331 Mdot
.77621 .51709 Mdot
.7492 .61436 Mdot
.51111 .68257 Mdot
.47023 .52401 Mdot
.67598 .51048 Mdot
.60618 .54462 Mdot
.66594 .53712 Mdot
.41944 .62694 Mdot
.6033 .40921 Mdot
.34891 .62162 Mdot
.27852 .37751 Mdot
.33497 .44975 Mdot
.60176 .52364 Mdot
.25641 .34609 Mdot
.46488 .3478 Mdot
.49838 .34184 Mdot
.35354 .47521 Mdot
.43981 .60689 Mdot
.79751 .41688 Mdot
.36512 .81472 Mdot
.53003 .2952 Mdot
.49489 .67645 Mdot
.65297 .52888 Mdot
.40445 .6206 Mdot
.49432 .36348 Mdot
.49543 .67646 Mdot
.61029 .5386 Mdot
.44587 .69903 Mdot
.64595 .503 Mdot
.32718 .28315 Mdot
.51463 .33737 Mdot
.51934 .85145 Mdot
.48513 .37603 Mdot
.33283 .4137 Mdot
.32653 .45234 Mdot
.62214 .46562 Mdot
.54483 .30363 Mdot
.47879 .2876 Mdot
.44649 .56744 Mdot
.54564 .6924 Mdot
.28172 .42693 Mdot
.52082 .70063 Mdot
.38054 .62476 Mdot
.50828 .69436 Mdot
.377 .61508 Mdot
.78825 .40398 Mdot
.47776 .2574 Mdot
.53271 .67998 Mdot
.30353 .49623 Mdot
.63957 .45281 Mdot
.51518 .65694 Mdot
.66481 .55073 Mdot
.55967 .56836 Mdot
.37813 .59934 Mdot
.54292 .69375 Mdot
.61606 .54484 Mdot
.78337 .63653 Mdot
.34961 .42004 Mdot
.325 .4566 Mdot
.66546 .54986 Mdot
.42251 .59434 Mdot
.52559 .3312 Mdot
.46416 .82636 Mdot
.31361 .45738 Mdot
.61383 .46289 Mdot
.60542 .45583 Mdot
.47827 .28563 Mdot
.2235 .36863 Mdot
.63228 .46663 Mdot
.68396 .56207 Mdot
.61832 .46823 Mdot
.32771 .42635 Mdot
.50341 .29256 Mdot
.49184 .34538 Mdot
.36169 .62328 Mdot
.46195 .34953 Mdot
.55865 .60618 Mdot
.27218 .3511 Mdot
.59223 .57026 Mdot
.34799 .43801 Mdot
.29704 .35985 Mdot
.27166 .38095 Mdot
.70002 .74026 Mdot
.45761 .36294 Mdot
.57773 .52817 Mdot
.45871 .34591 Mdot
.51942 .69748 Mdot
.49508 .35376 Mdot
.49692 .37248 Mdot
.63083 .53154 Mdot
.59741 .51141 Mdot
.39293 .62678 Mdot
.4204 .30026 Mdot
.46732 .31129 Mdot
.58899 .48105 Mdot
.6116 .44896 Mdot
.64541 .54548 Mdot
.46516 .58144 Mdot
.49515 .2906 Mdot
.18746 .59603 Mdot
.69988 .60767 Mdot
.46809 .31082 Mdot
.832 .37125 Mdot
.29387 .49864 Mdot
.39262 .55473 Mdot
.40679 .53459 Mdot
.61413 .46935 Mdot
.36506 .57158 Mdot
.60108 .51686 Mdot
.27459 .31323 Mdot
.62462 .52104 Mdot
.50987 .67923 Mdot
.66137 .53463 Mdot
.38993 .64392 Mdot
.3852 .58745 Mdot
.61991 .46053 Mdot
.61011 .52574 Mdot
.76402 .33379 Mdot
.53415 .32484 Mdot
.50299 .34209 Mdot
.38553 .68292 Mdot
.5378 .68021 Mdot
.33253 .4545 Mdot
.62392 .49961 Mdot
.42461 .62388 Mdot
.38777 .5872 Mdot
.48381 .28894 Mdot
.36296 .6 Mdot
.35501 .42875 Mdot
.63353 .50775 Mdot
.33836 .4629 Mdot
.50694 .70062 Mdot
.50102 .29239 Mdot
.59209 .51289 Mdot
.65344 .48377 Mdot
.50841 .33199 Mdot
.57182 .52809 Mdot
.53733 .66067 Mdot
.40994 .60249 Mdot
.50828 .3069 Mdot
.36786 .43782 Mdot
.37929 .62255 Mdot
.58022 .50879 Mdot
.38337 .18116 Mdot
.66175 .47981 Mdot
.60344 .47476 Mdot
.72789 .73903 Mdot
.67487 .51624 Mdot
.38747 .58337 Mdot
.49079 .36464 Mdot
.70769 .4722 Mdot
.67491 .64531 Mdot
.58683 .88023 Mdot
.35131 .62616 Mdot
.65776 .52305 Mdot
.7315 .70206 Mdot
.65754 .51925 Mdot
.60621 .38739 Mdot
.36002 .5667 Mdot
.50292 .46182 Mdot
.61624 .55324 Mdot
.37879 .43509 Mdot
.39983 .62844 Mdot
.37297 .61283 Mdot
.19879 .50805 Mdot
.63702 .53183 Mdot
.43845 .52686 Mdot
.60131 .53514 Mdot
.37049 .43676 Mdot
.75488 .5605 Mdot
.3843 .586 Mdot
.55955 .18518 Mdot
.61866 .47541 Mdot
.48517 .29666 Mdot
.34458 .62803 Mdot
.31931 .39148 Mdot
.58161 .501 Mdot
.51305 .6635 Mdot
.3867 .47249 Mdot
.61636 .57117 Mdot
.3499 .43553 Mdot
.58252 .50894 Mdot
.71647 .46535 Mdot
.44 .20611 Mdot
.50862 .35291 Mdot
.37778 .42318 Mdot
.48122 .57211 Mdot
.58308 .53239 Mdot
.50749 .30772 Mdot
.49381 .31392 Mdot
.50344 .69676 Mdot
.49014 .50846 Mdot
.38837 .27392 Mdot
.69004 .39736 Mdot
.19789 .52461 Mdot
.34107 .61651 Mdot
.30065 .60942 Mdot
.60093 .48286 Mdot
.5403 .61039 Mdot
.38935 .45744 Mdot
.66409 .48263 Mdot
.69207 .298 Mdot
.46502 .33942 Mdot
.65891 .48109 Mdot
.52035 .67659 Mdot
.48359 .63345 Mdot
.55859 .63594 Mdot
.60963 .77156 Mdot
.39461 .6187 Mdot
.6905 .53118 Mdot
.71851 .49128 Mdot
.40934 .58368 Mdot
.59398 .45336 Mdot
.39296 .57958 Mdot
.23933 .66282 Mdot
.50619 .65982 Mdot
.49598 .29371 Mdot
.2829 .45023 Mdot
.57514 .46953 Mdot
.64802 .45855 Mdot
.54608 .69725 Mdot
.64033 .4874 Mdot
.40524 .19836 Mdot
.46746 .58803 Mdot
.37219 .62371 Mdot
.51007 .35358 Mdot
.59883 .45397 Mdot
.49249 .56047 Mdot
.66008 .51119 Mdot
.74446 .40404 Mdot
.63397 .45803 Mdot
.40551 .28458 Mdot
.5113 .3432 Mdot
.34281 .43608 Mdot
.59408 .54276 Mdot
.61971 .51564 Mdot
.71171 .65405 Mdot
.60732 .43777 Mdot
.59324 .54021 Mdot
.45809 .37758 Mdot
.50479 .36304 Mdot
.52048 .32551 Mdot
.3616 .63383 Mdot
.77573 .57888 Mdot
.35386 .44739 Mdot
.69157 .44844 Mdot
.318 .45846 Mdot
.57124 .35945 Mdot
.49662 .67052 Mdot
.66929 .73861 Mdot
.61168 .49351 Mdot
.48014 .35509 Mdot
.46703 .80708 Mdot
.5144 .29163 Mdot
.45864 .51031 Mdot
.37154 .45511 Mdot
.46857 .32646 Mdot
.61517 .50972 Mdot
.43333 .38912 Mdot
.74923 .68342 Mdot
.34683 .44911 Mdot
.62346 .43782 Mdot
.37226 .64389 Mdot
.45585 .66249 Mdot
.48141 .18952 Mdot
.34614 .42004 Mdot
.29831 .43519 Mdot
.63957 .53241 Mdot
.46796 .35477 Mdot
.37468 .43392 Mdot
.32762 .42832 Mdot
.3614 .60342 Mdot
.59582 .50849 Mdot
.59496 .50399 Mdot
.35459 .60696 Mdot
.35474 .45805 Mdot
.6863 .53197 Mdot
.61657 .57345 Mdot
.83491 .55815 Mdot
.42068 .2638 Mdot
.6667 .8229 Mdot
.53175 .54981 Mdot
.64821 .27262 Mdot
.46468 .83034 Mdot
.47327 .3036 Mdot
.6361 .54083 Mdot
.56523 .53754 Mdot
.37492 .63621 Mdot
.6406 .5161 Mdot
.38859 .56141 Mdot
.37809 .45833 Mdot
.83651 .47363 Mdot
.34566 .33935 Mdot
.2749 .71458 Mdot
.63964 .5181 Mdot
.44413 .33779 Mdot
.52224 .69365 Mdot
.29651 .4503 Mdot
.51308 .29971 Mdot
.64426 .55063 Mdot
.76008 .32938 Mdot
.35282 .63058 Mdot
.48055 .3122 Mdot
.80017 .36743 Mdot
.52227 .44664 Mdot
.59141 .53066 Mdot
.35249 .6211 Mdot
.51148 .81778 Mdot
.48639 .24096 Mdot
.30997 .44262 Mdot
.50937 .68536 Mdot
.40609 .62843 Mdot
.3934 .43992 Mdot
.46279 .27854 Mdot
.47645 .32091 Mdot
.52631 .31291 Mdot
.69263 .26943 Mdot
.34352 .58329 Mdot
.52519 .69199 Mdot
.74066 .65015 Mdot
.73405 .63214 Mdot
.51247 .67538 Mdot
.40054 .64191 Mdot
.5014 .36395 Mdot
.46854 .33651 Mdot
.49826 .33989 Mdot
.64133 .22077 Mdot
.45706 .34989 Mdot
.18807 .46187 Mdot
.63724 .54794 Mdot
.63204 .57814 Mdot
.65535 .5243 Mdot
.3296 .46181 Mdot
.51141 .32682 Mdot
.4497 .4172 Mdot
.66268 .44266 Mdot
.67383 .72075 Mdot
.66257 .47592 Mdot
.36954 .41018 Mdot
.65099 .47643 Mdot
.27803 .28577 Mdot
.45796 .33664 Mdot
.64009 .51078 Mdot
.39235 .42399 Mdot
.54072 .68062 Mdot
.45024 .35015 Mdot
.59556 .51675 Mdot
.26327 .64312 Mdot
.67099 .52387 Mdot
.27501 .70478 Mdot
.40386 .23374 Mdot
.49519 .6748 Mdot
.32452 .26308 Mdot
.39481 .65302 Mdot
.66603 .57035 Mdot
.62124 .42874 Mdot
.34179 .44442 Mdot
.28413 .4341 Mdot
.39787 .60925 Mdot
.56853 .41302 Mdot
.66509 .56034 Mdot
.50212 .6972 Mdot
.49641 .24927 Mdot
.35106 .46679 Mdot
.60053 .45122 Mdot
.67931 .46959 Mdot
.22501 .43744 Mdot
.6646 .55557 Mdot
.61554 .45441 Mdot
.54836 .69927 Mdot
.19913 .4387 Mdot
.65381 .50352 Mdot
.46461 .51527 Mdot
.52944 .30793 Mdot
.68092 .45175 Mdot
.18845 .44883 Mdot
.60214 .468 Mdot
.47386 .31555 Mdot
.65126 .58175 Mdot
.37584 .26809 Mdot
.5514 .6839 Mdot
.63545 .45814 Mdot
.21387 .35577 Mdot
.62893 .47753 Mdot
.35947 .44821 Mdot
.68123 .48893 Mdot
.38221 .61564 Mdot
.70574 .26517 Mdot
.36706 .62807 Mdot
.67171 .48308 Mdot
.49675 .33691 Mdot
.34261 .45453 Mdot
.59164 .20928 Mdot
.41776 .70369 Mdot
.213 .41361 Mdot
.37415 .80857 Mdot
.54807 .68495 Mdot
.49935 .64814 Mdot
.36834 .4683 Mdot
.64213 .50978 Mdot
.168 .49613 Mdot
.58701 .44485 Mdot
.66028 .49013 Mdot
.62325 .52135 Mdot
.63007 .7376 Mdot
.38482 .45481 Mdot
.37887 .59404 Mdot
.63603 .46594 Mdot
.58702 .5343 Mdot
.47713 .30167 Mdot
.53728 .67216 Mdot
.40811 .5846 Mdot
.52812 .67011 Mdot
.40295 .6259 Mdot
.83458 .42231 Mdot
.69058 .50625 Mdot
.54078 .68586 Mdot
.36881 .47827 Mdot
.47484 .30888 Mdot
.27921 .34692 Mdot
.37455 .6184 Mdot
.36429 .63279 Mdot
.62357 .45852 Mdot
.46989 .31817 Mdot
.51539 .36269 Mdot
.52681 .69953 Mdot
.34558 .42502 Mdot
.61287 .53188 Mdot
.66662 .5245 Mdot
.73217 .51189 Mdot
.42755 .60627 Mdot
.31774 .28711 Mdot
.2964 .635 Mdot
.64224 .50734 Mdot
.47902 .36955 Mdot
.61567 .52624 Mdot
.35219 .75755 Mdot
.46438 .35055 Mdot
.5968 .47153 Mdot
.80354 .32701 Mdot
.42259 .57026 Mdot
.3448 .29936 Mdot
.59883 .46036 Mdot
.45426 .84788 Mdot
.60547 .48672 Mdot
.84464 .47575 Mdot
.44959 .78368 Mdot
.6719 .474 Mdot
.58023 .49635 Mdot
.63319 .35805 Mdot
.66049 .5256 Mdot
.35499 .61338 Mdot
.8108 .48219 Mdot
.5231 .30263 Mdot
.26866 .40492 Mdot
.65477 .26062 Mdot
.55251 .67369 Mdot
.39056 .63365 Mdot
.34667 .56377 Mdot
.51816 .6697 Mdot
.49076 .33715 Mdot
.64308 .49979 Mdot
.43997 .45644 Mdot
.42362 .60101 Mdot
.53702 .46594 Mdot
.36228 .44885 Mdot
.26489 .52824 Mdot
.50028 .6167 Mdot
.35234 .43305 Mdot
.58901 .50867 Mdot
.61647 .35433 Mdot
.77165 .39273 Mdot
.60806 .82187 Mdot
.39166 .43296 Mdot
.34506 .44986 Mdot
.67402 .23919 Mdot
.49815 .70184 Mdot
.22795 .44551 Mdot
.40453 .29187 Mdot
.33771 .45552 Mdot
.51358 .25665 Mdot
.35119 .59794 Mdot
.38877 .40644 Mdot
.70315 .4853 Mdot
.64575 .54151 Mdot
.61688 .51135 Mdot
.33649 .42807 Mdot
.55706 .57841 Mdot
.48265 .21454 Mdot
.33594 .44148 Mdot
.55915 .45603 Mdot
.48632 .4653 Mdot
.32811 .54987 Mdot
.36638 .59022 Mdot
.54119 .69952 Mdot
.48604 .67673 Mdot
.49173 .29858 Mdot
.54607 .69381 Mdot
.51164 .62117 Mdot
.63501 .4913 Mdot
.33037 .43984 Mdot
.26867 .45977 Mdot
.37222 .44305 Mdot
.52172 .67097 Mdot
.51109 .71003 Mdot
.49591 .30992 Mdot
.50149 .34795 Mdot
.63394 .29194 Mdot
.62543 .61805 Mdot
.66602 .50008 Mdot
.50823 .76427 Mdot
.50237 .37164 Mdot
.52834 .48452 Mdot
.5424 .69912 Mdot
.53923 .67866 Mdot
.70042 .66815 Mdot
.6109 .4971 Mdot
.55113 .38161 Mdot
.61587 .49842 Mdot
.72646 .58029 Mdot
.57696 .48526 Mdot
.36154 .60252 Mdot
.60287 .49644 Mdot
.70053 .67645 Mdot
.56265 .5023 Mdot
.64838 .45281 Mdot
.42171 .62562 Mdot
.64177 .57137 Mdot
.38296 .61404 Mdot
.67109 .49048 Mdot
.4984 .65694 Mdot
.38794 .63584 Mdot
.66017 .65909 Mdot
.67978 .68449 Mdot
.40228 .64272 Mdot
.49952 .67886 Mdot
.54216 .65676 Mdot
.6319 .69044 Mdot
.51268 .299 Mdot
.58146 .43749 Mdot
.64287 .51208 Mdot
.34575 .60371 Mdot
.39016 .44421 Mdot
.57781 .49947 Mdot
.62512 .45143 Mdot
.58833 .47051 Mdot
.49071 .29754 Mdot
.39833 .6912 Mdot
.54005 .69083 Mdot
.3532 .60521 Mdot
.51853 .55255 Mdot
.41849 .58789 Mdot
.67359 .46151 Mdot
.56477 .53453 Mdot
.67385 .27898 Mdot
.32738 .53242 Mdot
.63631 .21197 Mdot
.47774 .31945 Mdot
.41715 .6002 Mdot
.48966 .67444 Mdot
.55967 .52142 Mdot
.4792 .35633 Mdot
.37982 .61524 Mdot
.64505 .50322 Mdot
.61052 .44094 Mdot
.26254 .3774 Mdot
.5709 .63604 Mdot
.67197 .67653 Mdot
.3711 .63924 Mdot
.38066 .64946 Mdot
.66685 .70491 Mdot
.53661 .63748 Mdot
.44219 .40826 Mdot
.64403 .52527 Mdot
.51426 .66371 Mdot
.4911 .36299 Mdot
.71108 .29309 Mdot
.32293 .44029 Mdot
.42458 .28798 Mdot
.63836 .51707 Mdot
.51236 .47642 Mdot
.49741 .33436 Mdot
.51778 .6773 Mdot
.33325 .42964 Mdot
.4801 .66272 Mdot
.42151 .61437 Mdot
.29466 .75545 Mdot
.63553 .48058 Mdot
.62879 .45855 Mdot
.3663 .4126 Mdot
.46921 .34926 Mdot
.55562 .6667 Mdot
.20272 .55248 Mdot
.36723 .60875 Mdot
.16695 .47764 Mdot
.47834 .36785 Mdot
.70165 .42301 Mdot
.35943 .58987 Mdot
.33849 .47253 Mdot
.63864 .67451 Mdot
.34882 .42977 Mdot
.66756 .47631 Mdot
.48254 .35016 Mdot
.38105 .42748 Mdot
.43599 .25713 Mdot
.75835 .68977 Mdot
.70233 .42177 Mdot
.63279 .49568 Mdot
.80695 .59696 Mdot
.25993 .67058 Mdot
.53345 .30048 Mdot
.39311 .45048 Mdot
.66459 .48131 Mdot
.64166 .45811 Mdot
.63118 .47697 Mdot
.38707 .44179 Mdot
.51367 .76007 Mdot
.37543 .60069 Mdot
.64723 .5303 Mdot
.51666 .70953 Mdot
.38924 .61233 Mdot
.30203 .41682 Mdot
.37107 .58865 Mdot
.47005 .3783 Mdot
.66095 .45045 Mdot
.31063 .38811 Mdot
.81336 .30171 Mdot
.35117 .45431 Mdot
.42276 .6299 Mdot
.68624 .51484 Mdot
.28442 .51752 Mdot
.51825 .34521 Mdot
.36549 .60984 Mdot
.64759 .4666 Mdot
.29847 .4877 Mdot
.73158 .29884 Mdot
.37621 .58679 Mdot
.47939 .35763 Mdot
.61599 .81578 Mdot
.64668 .51639 Mdot
.61482 .48427 Mdot
.47204 .32719 Mdot
.56604 .28714 Mdot
.76015 .30559 Mdot
.6119 .52571 Mdot
.34108 .43564 Mdot
.21744 .68661 Mdot
.6275 .45134 Mdot
.73845 .58267 Mdot
.39608 .62833 Mdot
.38897 .39501 Mdot
.36026 .26445 Mdot
.55803 .50574 Mdot
.21343 .4939 Mdot
.29375 .46506 Mdot
.77398 .62525 Mdot
.39475 .56384 Mdot
.33638 .70245 Mdot
.79635 .57774 Mdot
.39352 .42178 Mdot
.43946 .3546 Mdot
.20955 .51954 Mdot
.55439 .2231 Mdot
.55262 .82051 Mdot
.38113 .74317 Mdot
.75986 .32743 Mdot
.45158 .45136 Mdot
.41198 .61613 Mdot
.52511 .47744 Mdot
.59959 .51794 Mdot
.26527 .67714 Mdot
.43618 .21682 Mdot
.45396 .21502 Mdot
.80762 .59845 Mdot
.62852 .39099 Mdot
.73557 .69689 Mdot
.70862 .74022 Mdot
.74456 .53526 Mdot
.30637 .63061 Mdot
.1634 .48686 Mdot
.81589 .43292 Mdot
.19675 .58554 Mdot
.62117 .57859 Mdot
.44991 .51046 Mdot
.31508 .74767 Mdot
.45296 .28167 Mdot
.53694 .26114 Mdot
.36168 .61967 Mdot
.51955 .30434 Mdot
.22516 .46638 Mdot
.4796 .28297 Mdot
.37446 .26536 Mdot
.63764 .81307 Mdot
.75198 .69686 Mdot
.22387 .35494 Mdot
.46715 .84076 Mdot
.68082 .29325 Mdot
.13457 .44988 Mdot
.38861 .56841 Mdot
.47966 .29198 Mdot
.61853 .73344 Mdot
.71746 .66952 Mdot
.31445 .36703 Mdot
.21942 .58264 Mdot
.46313 .69856 Mdot
.59718 .66071 Mdot
.48587 .34278 Mdot
.33502 .26063 Mdot
.35374 .39916 Mdot
.33809 .34538 Mdot
.80984 .45359 Mdot
.62366 .7944 Mdot
.43322 .46481 Mdot
.22952 .56913 Mdot
.28232 .55135 Mdot
.51238 .20317 Mdot
.68232 .62403 Mdot
.5241 .49784 Mdot
.41444 .26755 Mdot
.43519 .8196 Mdot
.57307 .25099 Mdot
.72386 .5769 Mdot
.72802 .65693 Mdot
.82517 .40034 Mdot
.31399 .71822 Mdot
.66336 .18851 Mdot
.48948 .27665 Mdot
.60428 .45531 Mdot
.58359 .29995 Mdot
.1969 .37973 Mdot
.52628 .71752 Mdot
.59193 .77992 Mdot
.53184 .70467 Mdot
.48306 .37974 Mdot
.73554 .29054 Mdot
.19406 .44038 Mdot
.17 .4176 Mdot
.49785 .65296 Mdot
.69702 .45219 Mdot
.42819 .87897 Mdot
.7276 .68462 Mdot
.33492 .32437 Mdot
.83418 .54528 Mdot
.49647 .44163 Mdot
.44126 .23063 Mdot
.38489 .43093 Mdot
.80889 .55595 Mdot
.47315 .34053 Mdot
.66545 .17807 Mdot
.84616 .4642 Mdot
.71295 .30594 Mdot
.89796 .60685 Mdot
.64828 .72197 Mdot
.5055 .46323 Mdot
.34101 .49339 Mdot
.64313 .63936 Mdot
.50072 .21778 Mdot
.55791 .74427 Mdot
.28483 .52632 Mdot
.43912 .85292 Mdot
.79553 .60039 Mdot
.16378 .44352 Mdot
.25015 .70338 Mdot
.55196 .23608 Mdot
.49076 .55521 Mdot
.64168 .42162 Mdot
.45219 .64753 Mdot
.57393 .79529 Mdot
.82995 .39281 Mdot
.70195 .60829 Mdot
.57824 .88385 Mdot
.55721 .65754 Mdot
.4573 .72467 Mdot
.68241 .79462 Mdot
.60755 .67022 Mdot
.36868 .2465 Mdot
.76798 .56906 Mdot
.61371 .4134 Mdot
.53015 .58186 Mdot
.58912 .78674 Mdot
.31044 .3119 Mdot
.80998 .50814 Mdot
.50388 .83124 Mdot
.22612 .43404 Mdot
.68272 .37756 Mdot
.74071 .60977 Mdot
.4601 .28903 Mdot
.58989 .6228 Mdot
.37069 .25564 Mdot
.77821 .67346 Mdot
.37613 .4088 Mdot
.7988 .66315 Mdot
.76536 .31404 Mdot
.69086 .51459 Mdot
.56529 .45525 Mdot
.53955 .39949 Mdot
.59752 .62823 Mdot
.66614 .56402 Mdot
.25142 .39283 Mdot
.7454 .71446 Mdot
.76312 .40065 Mdot
.29167 .47303 Mdot
.28277 .43919 Mdot
.6753 .80413 Mdot
.6064 .31556 Mdot
.52917 .63853 Mdot
.79546 .48367 Mdot
.51356 .21174 Mdot
.39399 .60398 Mdot
.16902 .44145 Mdot
.32945 .47469 Mdot
.72583 .30019 Mdot
.68435 .39602 Mdot
.60955 .24441 Mdot
.74585 .71475 Mdot
.33748 .69399 Mdot
.75284 .3087 Mdot
.5933 .70129 Mdot
.17635 .54243 Mdot
.32978 .54455 Mdot
.59543 .56078 Mdot
.22805 .59716 Mdot
.53473 .6566 Mdot
.64678 .32846 Mdot
.19248 .63466 Mdot
.41473 .7415 Mdot
.63264 .56303 Mdot
.71092 .30118 Mdot
.37932 .54354 Mdot
.43089 .38913 Mdot
.55836 .16039 Mdot
.6391 .44751 Mdot
.74597 .63765 Mdot
.29736 .68682 Mdot
.64062 .62698 Mdot
.55132 .84153 Mdot
.38541 .78501 Mdot
.70659 .21414 Mdot
.82106 .56076 Mdot
.40483 .70219 Mdot
.78874 .58263 Mdot
.79668 .6293 Mdot
.70589 .21874 Mdot
.58802 .43908 Mdot
.3292 .41419 Mdot
.36179 .179 Mdot
.36674 .58819 Mdot
.71964 .67923 Mdot
.19775 .52421 Mdot
.47946 .62605 Mdot
.49297 .40102 Mdot
.55722 .42388 Mdot
.45021 .46023 Mdot
.53316 .33348 Mdot
.66761 .56245 Mdot
.62875 .19281 Mdot
.76283 .26624 Mdot
.65577 .19393 Mdot
.37735 .79942 Mdot
.8066 .5448 Mdot
.50534 .49898 Mdot
.20912 .37691 Mdot
.53029 .48952 Mdot
.62132 .54531 Mdot
.47219 .66682 Mdot
.64113 .7264 Mdot
.68392 .27274 Mdot
.37168 .3408 Mdot
.49022 .25052 Mdot
.58891 .78321 Mdot
.155 .67029 Mdot
.65365 .2981 Mdot
.18294 .48588 Mdot
.49819 .64049 Mdot
.62485 .62049 Mdot
.54745 .78789 Mdot
.64288 .24697 Mdot
.71854 .74126 Mdot
.53276 .33277 Mdot
.19855 .57256 Mdot
.4192 .75993 Mdot
.4344 .3516 Mdot
.40625 .6907 Mdot
.71558 .71297 Mdot
.27802 .40086 Mdot
.61326 .22548 Mdot
.39948 .31629 Mdot
.58346 .28424 Mdot
.45628 .58664 Mdot
.266 .5478 Mdot
.18477 .59351 Mdot
.35707 .74958 Mdot
.73806 .5765 Mdot
.47995 .46809 Mdot
.30761 .27212 Mdot
.32385 .49971 Mdot
.72132 .58773 Mdot
.50004 .41104 Mdot
.76677 .59929 Mdot
.6666 .14506 Mdot
.56568 .17889 Mdot
.62695 .82781 Mdot
.5198 .77326 Mdot
.6287 .56785 Mdot
.7002 .76123 Mdot
.62533 .16933 Mdot
.83987 .3647 Mdot
.25175 .55619 Mdot
.40682 .57147 Mdot
.32412 .46399 Mdot
.6657 .21826 Mdot
.50658 .75367 Mdot
.66649 .77775 Mdot
.72568 .60596 Mdot
.36979 .47504 Mdot
.27981 .23795 Mdot
.82238 .40886 Mdot
.70128 .41216 Mdot
.5702 .63066 Mdot
.59183 .55208 Mdot
.35617 .23058 Mdot
.48401 .28325 Mdot
.30299 .58191 Mdot
.63926 .61508 Mdot
.39563 .59547 Mdot
.58627 .7522 Mdot
.22297 .59876 Mdot
.66052 .53526 Mdot
.48472 .56542 Mdot
.45087 .33782 Mdot
.32455 .54111 Mdot
.2955 .35179 Mdot
.81958 .33513 Mdot
.48472 .64353 Mdot
.62376 .55424 Mdot
.65379 .6246 Mdot
.40891 .68531 Mdot
.74421 .2834 Mdot
.37285 .46852 Mdot
.78712 .62639 Mdot
.434 .48915 Mdot
.59438 .61971 Mdot
.49314 .23316 Mdot
.54724 .54992 Mdot
.66031 .46066 Mdot
.42716 .80622 Mdot
.74461 .38645 Mdot
.42112 .3516 Mdot
.70312 .47672 Mdot
.53456 .48369 Mdot
.69147 .76831 Mdot
.49214 .62858 Mdot
.27179 .53608 Mdot
.7784 .64977 Mdot
.3819 .44642 Mdot
.45944 .34848 Mdot
.55865 .71508 Mdot
.20651 .60054 Mdot
.75483 .46895 Mdot
.73001 .29713 Mdot
.49677 .61177 Mdot
.42406 .73636 Mdot
.77455 .66375 Mdot
.77676 .63446 Mdot
.30193 .2517 Mdot
.52259 .27144 Mdot
.68173 .58815 Mdot
.20099 .60083 Mdot
.51389 .35812 Mdot
.21412 .4336 Mdot
.22574 .41417 Mdot
.83558 .44612 Mdot
.47681 .56425 Mdot
.44974 .85558 Mdot
.67127 .67298 Mdot
.56727 .77521 Mdot
.58841 .20684 Mdot
.1835 .56866 Mdot
.6964 .71507 Mdot
.53641 .31044 Mdot
.63638 .37033 Mdot
.60014 .57258 Mdot
.25967 .32425 Mdot
.35452 .19081 Mdot
.55389 .71863 Mdot
.52123 .40788 Mdot
.51023 .83251 Mdot
.64668 .49133 Mdot
.53197 .16671 Mdot
.21326 .58915 Mdot
.66252 .23205 Mdot
.3584 .477 Mdot
.58909 .52166 Mdot
.57251 .47 Mdot
.79033 .52618 Mdot
.36718 .27128 Mdot
.77039 .58888 Mdot
.22559 .68937 Mdot
.52842 .81222 Mdot
.50583 .24209 Mdot
.72264 .67188 Mdot
.62497 .79657 Mdot
.27241 .6825 Mdot
.48217 .50279 Mdot
.5515 .75686 Mdot
.6201 .66915 Mdot
.45181 .8345 Mdot
.46987 .40547 Mdot
.38818 .51687 Mdot
.27425 .38783 Mdot
.30267 .6629 Mdot
.65929 .24539 Mdot
.5855 .49851 Mdot
.8004 .36819 Mdot
.6869 .75532 Mdot
.33396 .23624 Mdot
.45535 .19664 Mdot
.57293 .17891 Mdot
.72715 .38671 Mdot
.32496 .71625 Mdot
.25035 .64943 Mdot
.1713 .58648 Mdot
.42941 .49194 Mdot
.64925 .73707 Mdot
.60589 .68362 Mdot
.77621 .65842 Mdot
.35887 .41101 Mdot
.39532 .29727 Mdot
.27799 .44993 Mdot
.78124 .58628 Mdot
.60978 .32822 Mdot
.71831 .72144 Mdot
.48451 .43592 Mdot
.71159 .21508 Mdot
.3845 .77347 Mdot
.46153 .44527 Mdot
.41904 .61817 Mdot
.35108 .70893 Mdot
.63474 .76826 Mdot
.39884 .77604 Mdot
.18207 .54158 Mdot
.41475 .56654 Mdot
.53339 .56965 Mdot
.63813 .39966 Mdot
.57909 .62191 Mdot
.42306 .80691 Mdot
.65261 .62496 Mdot
.74387 .70694 Mdot
.79804 .52371 Mdot
.79778 .36501 Mdot
.65613 .71965 Mdot
.36101 .80385 Mdot
.33581 .32084 Mdot
.55648 .62496 Mdot
.21682 .5924 Mdot
.46606 .74126 Mdot
.53684 .32797 Mdot
.3824 .12376 Mdot
.29775 .75281 Mdot
.34914 .73622 Mdot
.82961 .39657 Mdot
.38466 .78955 Mdot
.32455 .53355 Mdot
.5501 .26129 Mdot
.42182 .27755 Mdot
.78958 .38174 Mdot
.62325 .52028 Mdot
.61664 .18044 Mdot
.60989 .61211 Mdot
.79966 .29617 Mdot
.66358 .78604 Mdot
.5192 .40413 Mdot
.66358 .45258 Mdot
.35198 .61186 Mdot
.42975 .52123 Mdot
.7535 .54067 Mdot
.58613 .33666 Mdot
.40035 .22953 Mdot
.33289 .51034 Mdot
.38604 .56934 Mdot
.40375 .68037 Mdot
.53183 .30509 Mdot
.52838 .76283 Mdot
.30038 .65078 Mdot
.43366 .6471 Mdot
.42609 .46655 Mdot
.68492 .60604 Mdot
.35218 .26527 Mdot
.70987 .41998 Mdot
.64812 .2481 Mdot
.29844 .39205 Mdot
.35808 .60177 Mdot
.7075 .40877 Mdot
.31495 .7526 Mdot
.50921 .82163 Mdot
.82681 .3895 Mdot
.52228 .57875 Mdot
.5935 .36169 Mdot
.74721 .57211 Mdot
.47619 .20734 Mdot
.54978 .32097 Mdot
.34032 .52667 Mdot
.35392 .23438 Mdot
.55097 .2888 Mdot
.2152 .51189 Mdot
.83738 .47227 Mdot
.19723 .58217 Mdot
.19959 .60063 Mdot
.46087 .63463 Mdot
.7243 .53153 Mdot
.45153 .374 Mdot
.66404 .66395 Mdot
.43609 .40249 Mdot
.16207 .39681 Mdot
.68901 .4555 Mdot
.14494 .38054 Mdot
.33213 .42304 Mdot
.52976 .22986 Mdot
.61803 .67759 Mdot
.48578 .47376 Mdot
.48988 .42523 Mdot
.36495 .75939 Mdot
.40147 .28194 Mdot
.30431 .70837 Mdot
.47618 .21899 Mdot
.38694 .56712 Mdot
.24188 .71887 Mdot
.37777 .82016 Mdot
.65614 .37034 Mdot
.67775 .52067 Mdot
.31698 .77037 Mdot
.40718 .5745 Mdot
.67088 .26306 Mdot
.55884 .83825 Mdot
.48335 .80556 Mdot
.59619 .40136 Mdot
.61167 .62091 Mdot
.65635 .73401 Mdot
.81499 .59701 Mdot
.34079 .21144 Mdot
.58093 .78685 Mdot
.3577 .41137 Mdot
.48449 .44687 Mdot
.68334 .74223 Mdot
.42002 .23898 Mdot
.36607 .40319 Mdot
.39014 .23607 Mdot
.11993 .45289 Mdot
.72402 .6784 Mdot
.76331 .59697 Mdot
.42006 .22997 Mdot
.48465 .37542 Mdot
.39818 .26475 Mdot
.36564 .24856 Mdot
.45731 .7991 Mdot
.28507 .71864 Mdot
.36571 .25274 Mdot
.14594 .53504 Mdot
.56048 .56984 Mdot
.32342 .58664 Mdot
.54433 .40287 Mdot
.75435 .5084 Mdot
.38428 .46983 Mdot
.80193 .42494 Mdot
.54192 .81826 Mdot
.31736 .42382 Mdot
.44384 .81236 Mdot
.23079 .5779 Mdot
.72405 .45538 Mdot
.75254 .45945 Mdot
.51838 .80349 Mdot
.60838 .3458 Mdot
.26367 .30369 Mdot
.73024 .31535 Mdot
.42836 .59079 Mdot
.57477 .81651 Mdot
.37287 .62155 Mdot
.54041 .45619 Mdot
.43226 .2723 Mdot
.56191 .74242 Mdot
.64907 .2183 Mdot
.55126 .66796 Mdot
.49182 .28594 Mdot
.35275 .19574 Mdot
.48948 .36746 Mdot
.64131 .19659 Mdot
.61456 .24365 Mdot
.38392 .22135 Mdot
.40172 .70761 Mdot
.39125 .72835 Mdot
.12655 .48775 Mdot
.34133 .39766 Mdot
.43857 .65342 Mdot
.23997 .3631 Mdot
.47954 .29011 Mdot
.46542 .65896 Mdot
.40949 .63608 Mdot
.40244 .49194 Mdot
.23589 .45583 Mdot
.57574 .57782 Mdot
.47326 .27197 Mdot
.41324 .48231 Mdot
.78947 .4561 Mdot
.8233 .5091 Mdot
.39697 .58131 Mdot
.17454 .35048 Mdot
.6624 .45542 Mdot
.67735 .36929 Mdot
.72698 .73706 Mdot
.27451 .24305 Mdot
.34763 .66933 Mdot
.39969 .83856 Mdot
.58316 .53948 Mdot
.52852 .78669 Mdot
.47864 .33922 Mdot
.20021 .58035 Mdot
.52193 .70403 Mdot
.63535 .63101 Mdot
.31977 .43269 Mdot
.60937 .22391 Mdot
.34008 .67006 Mdot
.52634 .32162 Mdot
.49972 .78545 Mdot
.74389 .53476 Mdot
.39308 .48268 Mdot
.37422 .69737 Mdot
.6604 .37508 Mdot
.75119 .47742 Mdot
.48358 .25781 Mdot
.75779 .61119 Mdot
.20215 .62645 Mdot
.82385 .337 Mdot
.48489 .39663 Mdot
.52063 .45841 Mdot
.24145 .41069 Mdot
.473 .81668 Mdot
.2719 .32525 Mdot
.74427 .72265 Mdot
.6841 .59828 Mdot
.66987 .57974 Mdot
.71488 .58784 Mdot
.55781 .54735 Mdot
.46414 .48464 Mdot
.28776 .56258 Mdot
.42042 .21132 Mdot
.32521 .28493 Mdot
.55999 .25202 Mdot
.27472 .30211 Mdot
.75089 .60537 Mdot
.38605 .22368 Mdot
.43623 .63201 Mdot
.735 .45637 Mdot
.30248 .45957 Mdot
.82647 .51192 Mdot
.73913 .72699 Mdot
.30181 .43117 Mdot
.44568 .66998 Mdot
.4967 .84546 Mdot
.57801 .45215 Mdot
.50851 .53601 Mdot
.63555 .45959 Mdot
.55726 .59744 Mdot
.24151 .2752 Mdot
.46804 .80694 Mdot
.65566 .55575 Mdot
.7858 .61113 Mdot
.7968 .58627 Mdot
.74959 .24498 Mdot
.16627 .50885 Mdot
.49939 .30903 Mdot
.71205 .23076 Mdot
.3938 .23008 Mdot
.81172 .60851 Mdot
.32272 .5615 Mdot
.75548 .73435 Mdot
.63553 .36667 Mdot
.46969 .8268 Mdot
.54388 .26126 Mdot
.41247 .28376 Mdot
.30018 .68147 Mdot
.50173 .52636 Mdot
.26261 .50254 Mdot
.35329 .76296 Mdot
.21111 .69637 Mdot
.58056 .55905 Mdot
.24888 .62454 Mdot
.32109 .37342 Mdot
.5903 .81455 Mdot
.39047 .76237 Mdot
.68028 .5041 Mdot
.28011 .43562 Mdot
.643 .22524 Mdot
.69193 .60601 Mdot
.52033 .50821 Mdot
.37697 .75258 Mdot
.77355 .3679 Mdot
.74991 .56201 Mdot
.19608 .59425 Mdot
.65169 .37358 Mdot
.43441 .51056 Mdot
.58189 .5308 Mdot
.49243 .26742 Mdot
.54392 .65106 Mdot
.49902 .53997 Mdot
.66984 .4938 Mdot
.36173 .6436 Mdot
.40646 .46892 Mdot
.61071 .19139 Mdot
.31781 .31069 Mdot
.23153 .63572 Mdot
.44862 .29871 Mdot
.36872 .36325 Mdot
.26419 .34146 Mdot
.55288 .18488 Mdot
.45213 .77251 Mdot
.70133 .60878 Mdot
.74017 .68057 Mdot
.80121 .52665 Mdot
.43917 .29309 Mdot
.79605 .31425 Mdot
.39109 .45495 Mdot
.71636 .44445 Mdot
.38868 .34715 Mdot
.43661 .65987 Mdot
.70081 .51658 Mdot
.46908 .8259 Mdot
.48556 .62646 Mdot
.70753 .67488 Mdot
.31529 .72277 Mdot
.61227 .59817 Mdot
.65752 .39691 Mdot
.78663 .62122 Mdot
.3502 .623 Mdot
.2239 .64744 Mdot
.36882 .49254 Mdot
.38127 .75031 Mdot
.80568 .53351 Mdot
.83046 .41281 Mdot
.46114 .42464 Mdot
.62097 .65689 Mdot
.61438 .47925 Mdot
.18746 .59385 Mdot
.46164 .80819 Mdot
.6539 .41856 Mdot
.25228 .53207 Mdot
.46247 .35421 Mdot
.26845 .58248 Mdot
.44594 .51254 Mdot
.78559 .38738 Mdot
.45433 .3144 Mdot
.36704 .22488 Mdot
.50803 .65136 Mdot
.51027 .44684 Mdot
.71102 .51111 Mdot
.63325 .64907 Mdot
.153 .45944 Mdot
.7063 .47917 Mdot
.5881 .79041 Mdot
.6815 .39005 Mdot
.20259 .55586 Mdot
.51438 .79963 Mdot
.3228 .51716 Mdot
.40333 .27988 Mdot
.74261 .45968 Mdot
.26929 .41097 Mdot
.59654 .46397 Mdot
.4373 .6041 Mdot
.52407 .32718 Mdot
.57463 .82199 Mdot
.7385 .39593 Mdot
.65717 .66013 Mdot
.4652 .58113 Mdot
.52325 .51318 Mdot
.33126 .48625 Mdot
.74861 .73471 Mdot
.40824 .27464 Mdot
.65941 .6095 Mdot
.47745 .56415 Mdot
.62346 .67334 Mdot
.60396 .25119 Mdot
.84878 .44866 Mdot
.54288 .25645 Mdot
.43525 .44527 Mdot
.52407 .22964 Mdot
.33645 .72652 Mdot
.54445 .84665 Mdot
.72113 .58015 Mdot
.50825 .42982 Mdot
.55664 .6852 Mdot
.25985 .37459 Mdot
.45166 .57338 Mdot
.52045 .53708 Mdot
.40444 .49611 Mdot
.23847 .49808 Mdot
.39322 .37965 Mdot
.68805 .43843 Mdot
.67481 .70756 Mdot
.75717 .65911 Mdot
.19736 .53713 Mdot
.33456 .50556 Mdot
.31163 .62876 Mdot
.78533 .41222 Mdot
.76124 .73732 Mdot
.41376 .17953 Mdot
.61728 .47881 Mdot
.31935 .48821 Mdot
.60809 .65059 Mdot
.38445 .64331 Mdot
.33917 .26591 Mdot
.27511 .33827 Mdot
.35577 .4162 Mdot
.55749 .61729 Mdot
.72679 .64802 Mdot
.3094 .67366 Mdot
.5796 .64454 Mdot
.28736 .43695 Mdot
.59346 .18418 Mdot
.34854 .78024 Mdot
.47657 .81594 Mdot
.83431 .65278 Mdot
.36456 .50544 Mdot
.54669 .46641 Mdot
.61083 .29579 Mdot
.81358 .52791 Mdot
.66138 .62614 Mdot
.70804 .28526 Mdot
.29112 .50059 Mdot
.71512 .5824 Mdot
.53666 .35231 Mdot
.69485 .69045 Mdot
.26342 .57963 Mdot
.46578 .4674 Mdot
.39512 .73318 Mdot
.80507 .31871 Mdot
.61271 .39469 Mdot
.74085 .68774 Mdot
.61044 .21043 Mdot
.16494 .57772 Mdot
.81618 .53769 Mdot
.67613 .68563 Mdot
.43417 .77746 Mdot
.58685 .30263 Mdot
.49584 .40989 Mdot
.49517 .2428 Mdot
.6774 .26678 Mdot
.7603 .44455 Mdot
.444 .69929 Mdot
.56603 .23373 Mdot
.73731 .57714 Mdot
.7663 .43912 Mdot
.5086 .42753 Mdot
.71723 .42245 Mdot
.44159 .66961 Mdot
.40935 .23528 Mdot
.44604 .38419 Mdot
.68023 .64272 Mdot
.69606 .39816 Mdot
.23678 .42367 Mdot
.37606 .77765 Mdot
.15534 .58671 Mdot
.49507 .75845 Mdot
.54836 .1909 Mdot
.64121 .54762 Mdot
.74755 .22771 Mdot
.31175 .69876 Mdot
.32474 .69071 Mdot
.29311 .71207 Mdot
.36002 .54019 Mdot
.53687 .50415 Mdot
.59602 .46434 Mdot
.62677 .77146 Mdot
.59302 .40089 Mdot
.68025 .28795 Mdot
.59141 .21567 Mdot
.62505 .62549 Mdot
.71936 .61031 Mdot
.66659 .66882 Mdot
.66872 .57545 Mdot
.47646 .36313 Mdot
.66469 .19891 Mdot
.44487 .4235 Mdot
.64692 .41742 Mdot
.71832 .51341 Mdot
.58089 .28355 Mdot
.47129 .87002 Mdot
.50697 .40191 Mdot
.7619 .57987 Mdot
.63443 .3856 Mdot
.43086 .31711 Mdot
.28006 .30879 Mdot
.91784 .52199 Mdot
.78683 .25321 Mdot
.52487 .30852 Mdot
.18106 .4726 Mdot
.6318 .38876 Mdot
.77352 .59121 Mdot
.42824 .76184 Mdot
.23807 .52274 Mdot
.67926 .42448 Mdot
.4229 .31539 Mdot
.6951 .53888 Mdot
.29176 .68885 Mdot
.83411 .50394 Mdot
.5723 .21449 Mdot
.78462 .61359 Mdot
.55792 .55314 Mdot
.70541 .5189 Mdot
.81296 .69802 Mdot
.69406 .73384 Mdot
.64075 .44217 Mdot
.52033 .24017 Mdot
.66451 .43137 Mdot
.60291 .51608 Mdot
.55849 .76587 Mdot
.24146 .71701 Mdot
.7507 .56866 Mdot
.78054 .58683 Mdot
.46834 .28941 Mdot
.35709 .5508 Mdot
.32995 .42381 Mdot
.46906 .42396 Mdot
.64636 .43906 Mdot
.38208 .43065 Mdot
.62002 .60402 Mdot
.50199 .83835 Mdot
.44582 .55689 Mdot
.23073 .68256 Mdot
.80561 .66349 Mdot
.73204 .39836 Mdot
.26755 .36684 Mdot
.57285 .45835 Mdot
.75899 .49059 Mdot
.77628 .47547 Mdot
.53982 .56632 Mdot
.42074 .81712 Mdot
.4739 .10078 Mdot
.2657 .44949 Mdot
.79686 .40285 Mdot
.50218 .37586 Mdot
.41701 .50503 Mdot
.67674 .40867 Mdot
.33506 .55122 Mdot
.40889 .58905 Mdot
.57233 .5691 Mdot
.45 .35258 Mdot
.36206 .4792 Mdot
.18937 .31884 Mdot
.67614 .52566 Mdot
.30934 .28913 Mdot
.80458 .61658 Mdot
.72927 .31385 Mdot
.64387 .34378 Mdot
.57408 .48511 Mdot
.3291 .3512 Mdot
.50769 .43201 Mdot
.57348 .80437 Mdot
.80193 .3796 Mdot
.75511 .64895 Mdot
.74158 .3992 Mdot
.6516 .39471 Mdot
.58587 .53348 Mdot
.50402 .70675 Mdot
.38991 .39678 Mdot
.59738 .77528 Mdot
.64992 .42979 Mdot
.82561 .56835 Mdot
.33166 .66775 Mdot
.50283 .58033 Mdot
.52747 .39618 Mdot
.7425 .24251 Mdot
.58853 .26349 Mdot
.44067 .33876 Mdot
.56171 .18392 Mdot
.38219 .67943 Mdot
.57944 .62812 Mdot
.3505 .61321 Mdot
.60591 .4318 Mdot
.45581 .29954 Mdot
.54182 .16347 Mdot
.59281 .76644 Mdot
.26461 .49485 Mdot
.26482 .54242 Mdot
.19483 .49433 Mdot
.39208 .48181 Mdot
.84319 .63358 Mdot
.36947 .70371 Mdot
.56193 .17229 Mdot
.20735 .63279 Mdot
.44992 .30851 Mdot
.39424 .79067 Mdot
.69479 .46728 Mdot
.39515 .58496 Mdot
.773 .6225 Mdot
.56709 .42908 Mdot
.73886 .29702 Mdot
.57095 .52686 Mdot
.69379 .24729 Mdot
.55954 .68547 Mdot
.45489 .67148 Mdot
.33532 .72015 Mdot
.58389 .27948 Mdot
.66526 .80058 Mdot
.25542 .37937 Mdot
.70103 .76805 Mdot
.64125 .81068 Mdot
.79333 .6189 Mdot
.70494 .27257 Mdot
.30801 .23055 Mdot
.34489 .72757 Mdot
.51168 .80705 Mdot
.29812 .57987 Mdot
.57045 .28987 Mdot
.3492 .70963 Mdot
.54168 .39446 Mdot
.36511 .274 Mdot
.29724 .46048 Mdot
.21408 .24482 Mdot
.71521 .63117 Mdot
.45511 .37285 Mdot
.3636 .71391 Mdot
.80678 .58756 Mdot
.58862 .29424 Mdot
.34393 .75677 Mdot
.4499 .50815 Mdot
.58796 .55618 Mdot
.75537 .43911 Mdot
.19269 .5277 Mdot
.34571 .68911 Mdot
.12418 .54597 Mdot
.3222 .75579 Mdot
.25159 .49983 Mdot
.45517 .48281 Mdot
.51836 .30043 Mdot
.25053 .32837 Mdot
.39921 .72551 Mdot
.40292 .81041 Mdot
.48296 .83312 Mdot
.68701 .73987 Mdot
.1282 .48361 Mdot
.2032 .57407 Mdot
.81956 .51697 Mdot
.41517 .7969 Mdot
.52768 .31535 Mdot
.65822 .69536 Mdot
.42054 .58495 Mdot
.28156 .52872 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Sooooo`;o0000Y?ooool001cooooo00?o
0000ooooooooool0Xoooool2o`000:Cooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo0_l0002Gooooo`;o0000/Oooool001cooooo00?o0000ooooooooool0
U_ooool2o`000;7ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo07Sooooo0_l0003?
ooooo`007?ooool00ol0003oooooooooo`1hooooo`;o0000coooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2iooooo`;o0000S_ooool001cooooo00?o
0000ooooooooool0Voooool2o`0001cooooo0_l0002>ooooo`007?ooool00ol0003oooooooooo`2K
ooooo`Co00003oooool2o`0009Wooooo000Looooo`03o`000?oooooooooo09gooooo0_l0000?oooo
o`;o0000VOooool001cooooo00?o0000ooooooooool0eOooool2o`0007;ooooo000Looooo`03o`00
0?oooooooooo06cooooo0_l0000Sooooo`;o0000@_ooool2o`0007;ooooo000Looooo`;o0000KOoo
ool2o`0002?ooooo0_l0002fooooo`007?ooool00ol0003oooooooooo`21ooooo`;o00002?ooool2
o`000;cooooo000Looooo`03o`000?oooooooooo087ooooo0_l00003ooooo`;o00000oooool2o`00
0;cooooo000Looooo`03o`000?oooooooooo08Kooooo0_l0000Zooooo`;o0000UOooool001cooooo
00?o0000ooooooooool0N_ooool2o`00033ooooo0_l00004ooooo`;o00005Oooool2o`0007kooooo
000Looooo`03o`000?oooooooooo07[ooooo0_l0000Xooooo`;o00000oooool2o`000003ooooool0
003o000001_ooooo0_l0001nooooo`007?ooool00ol0003oooooooooo`24ooooo`;o00007_ooool3
o`0000;ooooo0_l00008ooooo`;o00004_ooool2o`00083ooooo000Looooo`03o`000?oooooooooo
08Cooooo0_l0000Oooooo`;o00003?ooool2o`0001;ooooo0_l00020ooooo`007?ooool00ol0003o
ooooooooo`1Pooooo`Co0000@_ooool2o`0002cooooo0_l0001cooooo`007?ooool00ol0003ooooo
ooooo`1Pooooo`Co00001oooool2o`0000Gooooo0_l00005ooooo`;o00002?ooool2o`00027ooooo
0_l0000<ooooo`Co00000_ooool2o`0000Gooooo0_l00002ooooo`;o00003Oooool2o`0007?ooooo
000Looooo`03o`000?oooooooooo06_ooooo0_l00005ooooo`;o00001Oooool2o`0000Sooooo0_l0
000^ooooo`Go00000_ooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o0000P_oo
ool001cooooo00?o0000ooooooooool0/?ooool5o`0000Sooooo0_l0002:ooooo`007?ooool00ol0
003oooooooooo`1oooooo`;o00006?ooool2o`0001Gooooo1Ol0000Oooooo`;o0000Loooool00006
ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooo
oooo06oooooo0_l0000>ooooo`;o00000_ooool2o`0000Cooooo0_l00002ooooo`;o00002_ooool3
o`0001;ooooo0_l00003ooooo`;o00001?ooool2o`0000Sooooo0_l00003ooooo`;o00002_ooool2
o`0000;ooooo0_l0001_ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0Koooool2o`0001;ooooo
0_l00004ooooo`;o00000_ooool2o`000004ooooool0003o0000o`0000Oooooo0_l0000Booooo`;o
00002Oooool2o`0000Sooooo0_l00003ooooo`;o00000oooool2o`0000;ooooo0_l00005ooooo`;o
0000Koooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00onHV9So8B4Q
onk^kP07ooooo`03o`000?oooooooooo06kooooo0ol0000?ooooo`;o00003_ooool4o`0000Cooooo
0_l0000Sooooo`;o00003_ooool2o`0000;ooooo0_l000000ooooooo0000o`00001cooooo`0000?o
ooooo`000?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0
001^ooooo`;o00002_ooool2o`0000Cooooo0_l0000@ooooo`;o00001?ooool2o`0002?ooooo0_l0
000Eooooo`;o0000Loooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool0
0omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo07Sooooo1?l000000ooooooo0000o`00000<
ooooo`;o00005_ooool2o`0000cooooo0_l0000@ooooo`;o0000Q?ooool00003ooooool@413ooooo
00;ooooo00?o410@ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
05;ooooo0_l00007ooooo`;o00006oooool2o`0000?ooooo0ol0000;ooooo`;o00002_ooool3o`00
00Oooooo1?l0000<ooooo`;o00002?ooool3o`0000Gooooo0_l00024ooooo`0000KoooooogMgMonH
V9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003ooooooooo
o`1Booooo`;o000000?oooooo`000?l000001?ooool2o`0000kooooo0_l0000Aooooo`;o00001?oo
ool3o`00013ooooo0ol00007ooooo`Co00003?ooool2o`0000Kooooo1Ol00005ooooo`;o00001_oo
ool2o`0007cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c006ooooo`03o`000?oooooooooo05Gooooo0_l0000?ooooo`;o00000oooool2o`0001Oo
oooo0ol00009ooooo`;o00001oooool2o`0000Kooooo1?l0000<ooooo`;o00000oooool2o`000003
ooooool0003o000000Sooooo0_l00004ooooo`Co00005Oooool3o`0006Cooooo000Looooo`03o`00
0?oooooooooo06Kooooo0_l0000Rooooo`;o00001?ooool2o`0000Oooooo0_l00004ooooo`Go0000
3?ooool2o`0000Cooooo0_l00004ooooo`;o00001oooool2o`0000;ooooo0_l00004ooooo`;o0000
0oooool2o`0000cooooo0ol0001Tooooo`007?ooool00ol0003oooooooooo`1Qooooo`;o00005_oo
ool2o`0000oooooo0_l0000;ooooo`;o00001_ooool2o`000003ooooool0003o000000cooooo0_l0
0002ooooo`;o00001_ooool2o`0000Oooooo0_l00006ooooo`Co00000oooool2o`0000_ooooo0_l0
001Vooooo`007?ooool00ol0003oooooooooo`1Oooooo`Co00004Oooool2o`0000?ooooo0ol00000
0ooooooo0000o`000009ooooo`;o00003Oooool2o`0000Cooooo0_l00003ooooo`;o00003?ooool2
o`0000;ooooo0_l0000<ooooo`;o00001Oooool2o`0000;ooooo0_l0000Booooo`;o0000I_ooool0
01cooooo00?o0000ooooooooool0Goooool2o`0000Gooooo0_l0000;ooooo`?o00001?ooool2o`00
0003ooooool0003o000000Wooooo0_l0000Cooooo`;o00000oooool2o`000003ooooool0003o0000
00Wooooo0_l0000@ooooo`?o00001?ooool2o`0000;ooooo0_l0000Pooooo`;o0000F?ooool001co
oooo00?o0000ooooooooool0H?ooool2o`0000Cooooo0_l00008ooooo`;o000000?oooooo`000?l0
00001oooool4o`0000Gooooo0_l00005ooooo`Ko00004?ooool2o`000003ooooool0003o000000?o
00006Oooool2o`0000Sooooo0_l0000Dooooo`;o00002_ooool2o`0005Sooooo000Looooo`03o`00
0?oooooooooo05cooooo0_l00002ooooo`;o00003_ooool2o`0000Oooooo0_l000000ooooooo0000
o`000003o`0000Cooooo0_l00005ooooo`Ko00002_ooool2o`0000Cooooo0_l00002ooooo`Co0000
2_ooool2o`0001gooooo0_l0000>ooooo`;o00001Oooool2o`0005gooooo000Looooo`03o`000?oo
oooooooo05Kooooo0_l00004ooooo`;o00002oooool2o`0000Cooooo0_l00008ooooo`Co00000_oo
ool4o`0000Cooooo0_l0000@ooooo`;o000000?oooooo`000?l000004?ooool4o`0000;ooooo0_l0
000;ooooo`;o00004?ooool2o`0001Gooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1?
ooooo`;o00001Oooool3o`00013ooooo0_l00004ooooo`;o00002_ooool2o`0000Cooooo0_l00002
ooooo`Co00004?ooool2o`0001?ooooo1?l0000?ooooo`?o00004oooool2o`0000Wooooo0_l0001U
ooooo`007?ooool00ol0003oooooooooo`1?ooooo`;o00001?ooool4o`0001;ooooo0_l00002oooo
o`?o00001_ooool2o`0000Wooooo1?l00007ooooo`;o00002_ooool2o`000004ooooool0003o0000
ooooo`?o00000_ooool2o`0001_ooooo0_l0000Cooooo`;o00002Oooool2o`0000Wooooo0_l0001J
ooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00004Oooool2o`0000oooooo0_l00003oooo
o`;o00000_ooool3o`0000Kooooo0_l00009ooooo`;o00002Oooool2o`0000[ooooo0_l000001?oo
oooo0000o`000?ooool3o`0000;ooooo0_l0000Kooooo`Co00002oooool5o`0001Oooooo0_l00000
0ooooooo0000o`00001Gooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00008_ooool2o`00
00_ooooo0ol0000Aooooo`;o00002Oooool2o`0000Wooooo0_l0000>ooooo`;o00004oooool4o`00
00Oooooo2Ol000000ooooooo0000o`000005ooooo`Co00000_ooool2o`0000[ooooo0_l0001Goooo
o`007?ooool2o`0005oooooo0ol00008ooooo`;o00002?ooool3o`00017ooooo0_l00009ooooo`;o
00001oooool4o`0000kooooo0_l00003ooooo`;o00000_ooool2o`0000Sooooo0_l0000:ooooo`Oo
00001?ooool2o`0000Gooooo1?l00002ooooo`;o0000Hoooool001cooooo00?o0000ooooooooool0
G_ooool3o`0000Sooooo0_l00008ooooo`;o00009_ooool4o`0000Kooooo0_l00008ooooo`;o0000
00?oooooo`000?l000000_ooool2o`0000Sooooo0_l0000:ooooo`?o00005_ooool2o`0001Gooooo
0_l0001;ooooo`007?ooool00ol0003oooooooooo`1Rooooo`;o00003oooool4o`0000oooooo0_l0
0002ooooo`;o00002oooool8o`0000Cooooo1?l00006ooooo`Co000000Coooooo`000?l0003ooooo
0_l00006ooooo`;o00005oooool2o`0000gooooo0_l0000Eooooo`;o0000Boooool001cooooo00?o
0000ooooooooool0H_ooool2o`0000?ooooo1Ol00009ooooo`;o00002_ooool2o`0000?ooooo0ol0
00000ooooooo0000o`000002ooooo`;o00001oooool7o`0000Gooooo0_l00006ooooo`Ko000000Co
ooooo`000?l0003ooooo0_l00004ooooo`Co00004_ooool2o`0000?ooooo0_l00006ooooo`;o0000
JOooool001cooooo00?o0000ooooooooool0HOooool2o`0000?ooooo1_l00005ooooo`;o00001_oo
ool2o`0000Kooooo0_l00002ooooo`Co00001Oooool6o`0000Kooooo0ol00003ooooo`;o00001ooo
ool8o`0000Gooooo0_l00003ooooo`;o00004?ooool2o`0000;ooooo0_l00003ooooo`;o00001_oo
ool2o`0000Sooooo0_l0001Oooooo`007?ooool00ol0003oooooooooo`18ooooo`;o00005oooool2
o`0000?ooooo0_l00002ooooo`;o00000oooool4o`0000?ooooo0_l000000ooooooo0000o`000003
ooooo`;o00000oooool4o`0000Wooooo1?l00002ooooo`;o00000oooool3o`0000;ooooo0_l00007
ooooo`?o000000?oooooo`000?l000001oooool2o`0000?ooooo0_l0000<ooooo`;o00000_ooool4
o`0000Gooooo1?l00005ooooo`Co000000?oooooo`000?l000000_ooool2o`0000Oooooo0_l00000
0ooooooo0000o`00001Cooooo`007?ooool00ol0003oooooooooo`18ooooo`;o00007?ooool2o`00
00;ooooo0_l00003ooooo`;o00001Oooool2o`0000Kooooo0ol00002ooooo`;o00002?ooool2o`00
00Oooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000cooooo0_l00002
ooooo`;o00000_ooool2o`0000Gooooo0_l0000;ooooo`;o00000oooool3o`0000Oooooo0_l00003
ooooo`Wo00000oooool2o`0000Kooooo0_l000000ooooooo0000o`00001Cooooo`007?ooool00ol0
003oooooooooo`1Pooooo`;o00001?ooool2o`0000Oooooo0_l00003ooooo`Co00000_ooool2o`00
0003ooooool0003o000000;o00002?ooool2o`0000;ooooo0_l00007ooooo`;o000000?oooooo`00
0?l000001?ooool4o`0000?ooooo1?l00007ooooo`;o00000_ooool3o`0000Cooooo0_l00007oooo
o`;o00002?ooool2o`0000Sooooo0ol000000ooooooo0000o`000002ooooo`Co00001?ooool2o`00
05kooooo000Looooo`03o`000?oooooooooo04_ooooo0_l0000Cooooo`;o000000?oooooo`000?l0
00003_ooool3o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o00001_ooool2o`0000_o
oooo2?l00002ooooo`?o000000?oooooo`000?l000001?l00009ooooo`;o000000?oooooo`000?l0
00002?ooool2o`0000?ooooo1?l00006ooooo`Co00001_ooool4o`0000Cooooo0ol0000Gooooo`;o
0000C?ooool001cooooo00?o0000ooooooooool0Boooool2o`0000_ooooo0ol00005ooooo`;o0000
00?oooooo`000?l000002?ooool2o`0000Cooooo0_l0000:ooooo`Co00000_ooool2o`0000cooooo
0_l00002ooooo`So000000?oooooo`000?l000000_ooool4o`0000_ooooo0_l00005ooooo`;o0000
0_ooool4o`0000Gooooo0_l00008ooooo`;o00001?ooool2o`0000;ooooo0_l0000Nooooo`;o0000
C?ooool001cooooo00?o0000ooooooooool0F?ooool3o`0000Gooooo0_l000000ooooooo0000o`00
0002ooooo`;o00001?ooool2o`0000[ooooo0_l000001?oooooo0000o`000?ooool2o`0000Cooooo
0_l00008ooooo`Ko000000?oooooo`000?l000002_l00004ooooo`;o00002oooool2o`0000Gooooo
0_l00002ooooo`;o000000?oooooo`000?l000005?ooool2o`00073ooooo000Looooo`03o`000?oo
oooooooo05Oooooo0_l0000:ooooo`;o000000Coooooo`000?l0003o00004?ooool2o`000004oooo
ool0003o0000ooooo`Go00000_ooool4o`0000Gooooo1?l00003ooooo`co00000_ooool2o`0000go
oooo0_l00004ooooo`?o00001Oooool2o`0000;ooooo0_l0000Eooooo`;o000000Coooooo`000?l0
003ooooo0_l000000ooooooo0000o`000007ooooo`;o00003?ooool2o`0004_ooooo000Looooo`03
o`000?oooooooooo05?ooooo1_l00008ooooo`Co000000?oooooo`000?l000006?ooool4o`0000;o
oooo1_l00004ooooo`Go00000_ooool;o`0000;ooooo0ol00008ooooo`;o00000oooool2o`0000?o
oooo0ol00002ooooo`;o00001Oooool2o`0001;ooooo0_l000001?oooooo0000o`000?ooool2o`00
0004ooooool0003o0000ooooo`;o00001_ooool3o`0000cooooo0_l0001;ooooo`007?ooool00ol0
003oooooooooo`1Cooooo`Co00001_ooool2o`0000;ooooo1?l0000Kooooo`?o00000oooool2o`00
0004ooooool0003o0000o`0000Kooooo1?l000000ooooooo0000o`00000>o`0000Cooooo0_l00002
ooooo`;o00000oooool5o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`;o00000oooool2
o`0000gooooo0_l00004ooooo`;o00002_ooool4o`0000?ooooo0_l0001Eooooo`007?ooool00ol0
003oooooooooo`1Aooooo`?o00001_ooool2o`000003ooooool0003o000000Wooooo0_l0000Coooo
o`;o000000Coooooo`000?l0003ooooo1?l00004ooooo`;o00001oooool2o`000003ooooool0003o
0000017o000000?oooooo`000?l000002Oooool3o`0000;ooooo0_l0000=ooooo`;o00003Oooool2
o`0000?ooooo0ol00002ooooo`;o00001_ooool2o`0000Gooooo0_l0001Eooooo`007?ooool00ol0
003oooooooooo`1Aooooo`?o00001_ooool2o`0000Wooooo0_l000000ooooooo0000o`00000Coooo
o`Co00000_ooool4o`0000Cooooo0ol00006ooooo`?o000000?oooooo`000?l000004?l0000Aoooo
o`;o00001_ooool2o`0000cooooo0_l00006ooooo`;o00000_ooool3o`0000?ooooo0_l00004oooo
o`;o000000?oooooo`000?l000000oooool2o`0000gooooo0_l00017ooooo`007?ooool2o`0005Wo
oooo0_l0000;ooooo`;o00001Oooool2o`0000oooooo1?l00004ooooo`Co00000oooool7o`000003
ooooool0003o000001?o000000?oooooo`000?l000003_ooool2o`0000;ooooo0_l00003ooooo`;o
00003?ooool2o`0000[ooooo0_l00004ooooo`;o00000oooool6o`0000?ooooo0_l00004ooooo`;o
00001oooool3o`0004Kooooo000Looooo`03o`000?oooooooooo05;ooooo2?l0000=ooooo`;o0000
0oooool2o`0000oooooo0_l000000ooooooo0000o`000003ooooo`Co00001OoooolNo`000003oooo
ool0003o000000_ooooo1_l0000Sooooo`;o00000oooool6o`0000Wooooo0_l00008ooooo`;o0000
00?oooooo`000?l00000@oooool001cooooo00?o0000ooooooooool0D_ooool6o`0000oooooo0_l0
000Gooooo`Co000000?oooooo`000?l000002OoooolLo`000003ooooool0003o000000cooooo1?l0
000Uooooo`;o000000?oooooo`000?l000000oooool2o`0000Gooooo0_l0000?ooooo`;o0000@ooo
ool001cooooo00?o0000ooooooooool0Eoooool2o`0000_ooooo0_l0000Looooo`;o000000?ooooo
o`000?l000001_oooolOo`00013ooooo0_l0000Aooooo`Co00004Oooool2o`000003ooooool0003o
000000Cooooo0_l00002ooooo`Co0000E?ooool001cooooo00?o0000ooooooooool0D_ooool2o`00
0003ooooool0003o000000;o00000oooool2o`0000?ooooo0_l000000ooooooo0000o`00000Woooo
o`?o00000_oooolJo`0002?ooooo1?l0000Fooooo`;o00000_ooool3o`000003ooooool0003o0000
05Kooooo000Looooo`03o`000?oooooooooo05;ooooo0_l000000ooooooo0000o`000005ooooo`;o
00000_ooool4o`0001Wooooo1?l00005ooooo`;o00001ooooolMo`0001Gooooo0_l0000Vooooo`;o
00000oooool2o`0000Gooooo0_l00008ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0
>_ooool2o`0000gooooo0_l0000Eooooo`Co00006Oooool4o`000003ooooool0003o000000;ooooo
1?l00005ooooo`?o000000?oooooo`000?l000005ol0000Eooooo`;o00009_ooool2o`0000[ooooo
0ol00007ooooo`;o000000?oooooo`000?l00000AOooool001cooooo00?o0000ooooooooool0>_oo
ool2o`0000gooooo0_l0000Hooooo`;o00001?ooool2o`0000Wooooo1?l000000ooooooo0000o`00
0007ooooo`;o00001?ooool2o`0000Gooooo6_l00006ooooo`?o00007?ooool2o`0001Kooooo1?l0
0006ooooo`;o00001?ooool2o`0000[ooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`1:
ooooo`;o00001Oooool2o`0000;ooooo0_l000000ooooooo0000o`000009ooooo`;o00001?ooool2
o`0000Wooooo1?l000000ooooooo0000o`000009ooooo`;o00003?oooolBo`000003ooooool0003o
000000;o000000?oooooo`000?l000000oooool5o`0001[ooooo1?l0000Dooooo`Co00001_ooool2
o`0005Oooooo000Looooo`03o`000?oooooooooo04[ooooo0_l00002ooooo`;o000000?oooooo`00
0?l000000_ooool2o`000003ooooool0003o000000Sooooo0_l00005ooooo`;o00000oooool2o`00
013ooooo0_l00002ooooo`;o00001ooooolPo`0000Gooooo0ol0000=ooooo`;o00002_ooool4o`00
027ooooo0_l000000ooooooo0000o`000007ooooo`Co000000?oooooo`000?l00000@oooool001co
oooo00?o0000ooooooooool0C_ooool2o`0000Wooooo0_l000000ooooooo0000o`000004ooooo`;o
000000?oooooo`000?l000001oooool2o`00013ooooo0_l0000;ooooo`ko000000?oooooo`000?l0
00003?l000000ooooooo0000o`000006ooooo`;o00003Oooool2o`0000Wooooo0ol0000Nooooo`;o
00000oooool2o`000003ooooool0003o000000Oooooo1?l000000ooooooo0000o`000013ooooo`00
7?ooool00ol0003oooooooooo`1Iooooo`;o000000?oooooo`000?l000001oooool2o`0000Oooooo
1?l0000=ooooo`?o00000_ooool2o`0000[ooooo4ol000000ooooooo0000o`000007o`0000;ooooo
0_l0000Aooooo`;o00000_ooool2o`0000Gooooo0_l00002ooooo`;o00000_ooool2o`0001Oooooo
0_l00004ooooo`;o00000oooool2o`0000_ooooo0_l00011ooooo`007?ooool00ol0003ooooooooo
o`1Fooooo`;o00002?ooool2o`0000kooooo1?l0000;ooooo`;o00000oooool2o`0000Oooooo7_l0
0004ooooo`;o00002_ooool2o`0000Wooooo0_l00009ooooo`;o00000_ooool2o`0001Oooooo0_l0
0004ooooo`;o00000oooool3o`000003ooooool0003o000000Oooooo1?l0000oooooo`007?ooool0
0ol0003oooooooooo`1Booooo`;o000000Coooooo`000?l0003o00002?ooool2o`0000_ooooo0_l0
0003ooooo`;o000000?oooooo`000?l000005?oooolOo`0000Kooooo0_l00009ooooo`;o00004ooo
ool2o`0001cooooo0_l0000:ooooo`;o000000?oooooo`000?l000002Oooool2o`0003oooooo000L
ooooo`03o`000?oooooooooo04Cooooo0_l0000<ooooo`;o000000Coooooo`000?l0003o00003?oo
ool2o`0000Gooooo1?l00006ooooo`;o00005?ooool2o`000004ooooool0003o0000ooooo`co0000
00?oooooo`000?l000001ol000000ooooooo0000o`000006ooooo`;o00006oooool2o`000004oooo
ool0003o0000o`0007Kooooo000Looooo`03o`000?oooooooooo04Cooooo0_l00005ooooo`;o0000
00?oooooo`000?l000000_l00005ooooo`;o00002oooool2o`0000;ooooo1Ol0000>ooooo`;o0000
1Oooool2o`0000[ooooo0_l000000ooooooo0000o`00000Do`000003ooooool0003o000001;ooooo
0_l000001?oooooo0000o`000?ooool2o`0000Wooooo0_l00002ooooo`;o00000_ooool2o`0001Go
oooo0_l0000@ooooo`;o00001Oooool2o`000003ooooool0003o000003oooooo000Looooo`;o0000
=_ooool2o`0000?ooooo0_l0000?ooooo`;o000000?oooooo`000?l000000_l00004ooooo`?o0000
3oooool4o`0000oooooo0_l00005ooooo`;o00002ooooolHo`000003ooooool0003o000001;ooooo
0_l000001?oooooo0000o`000?ooool2o`0000oooooo1Ol0000Dooooo`Co00003?ooool4o`0000Go
oooo0_l000000ooooooo0000o`00000oooooo`007?ooool00ol0003oooooooooo`0booooo`;o0000
00?oooooo`000?l000000oooool2o`0001Wooooo1?l000000ooooooo0000o`000003o`0000Sooooo
0_l0000Looooo`;o00000_ooool2o`0000?ooooo6Ol00004ooooo`;o00009_ooool2o`000003oooo
ool0003o000001Kooooo0_l0000:ooooo`Co00003_ooool2o`0003_ooooo000Looooo`03o`000?oo
oooooooo03;ooooo0_l0000>ooooo`;o000000?oooooo`000?l000003_ooool2o`0000?ooooo1Ol0
0006ooooo`Co00007?ooool2o`0000;ooooo1?l000000ooooooo0000o`00000Go`0000Cooooo0_l0
000Gooooo`;o0000=?ooool2o`0000[ooooo0_l00004ooooo`;o0000>oooool001cooooo00?o0000
ooooooooool0@_ooool2o`000004ooooool0003o0000ooooo`;o00004oooool2o`0000Cooooo1?l0
0008ooooo`;o00002_ooool2o`0000Sooooo0_l00004ooooo`;o00001?oooolEo`0000Kooooo0_l0
0008ooooo`;o00003?ooool4o`0000;ooooo0_l0000<ooooo`;o00007?ooool2o`0000kooooo0_l0
0011ooooo`007?ooool00ol0003oooooooooo`18ooooo`Co00004Oooool2o`0000Cooooo0_l0000:
ooooo`;o00000oooool2o`0000Gooooo0_l00005ooooo`Ko00002OoooolFo`0000Gooooo0_l00006
ooooo`Co00001Oooool4o`0000Gooooo0_l00002ooooo`;o00003?ooool2o`0001cooooo0_l00008
ooooo`;o0000Aoooool001cooooo00?o0000ooooooooool0B_ooool2o`0001;ooooo0ol0000Coooo
o`;o00002oooool9o`0000Kooooo5ol00005ooooo`;o00000_ooool2o`0000;ooooo0_l00007oooo
o`Co00004oooool2o`0000?ooooo0_l0000Tooooo`?o00002oooool2o`0003[ooooo000Looooo`03
o`000?oooooooooo04;ooooo0_l000000ooooooo0000o`00000<ooooo`;o00002Oooool3o`000004
ooooool0003o0000ooooo`?o000000?oooooo`000?l000004_ooool2o`0000;ooooo1_l000000ooo
oooo0000o`000006ooooo`?o000000?oooooo`000?l000002ol000000ooooooo0000o`000002o`00
00Kooooo0_l00002ooooo`;o00006?ooool3o`0000Oooooo0_l00002ooooo`?o00005Oooool2o`00
00Gooooo0_l00002ooooo`;o00000_ooool3o`0000_ooooo0_l0000jooooo`007?ooool00ol0003o
ooooooooo`12ooooo`;o000000?oooooo`000?l000003?ooool2o`0000gooooo0_l000001Ooooooo
0000o`000?l0003ooooo00;o00004_ooool2o`0000Cooooo0_l00004ooooo`;o00001_ooool2o`00
0003ooooool0003o000000Co000000?oooooo`000?l000001ol00004ooooo`;o00001Oooool2o`00
01Wooooo0ol00004ooooo`;o000000?oooooo`000?l000000_ooool2o`0001Kooooo0_l00005oooo
o`;o00000_ooool2o`0000?ooooo0_l00008ooooo`;o0000?Oooool001cooooo00?o0000oooooooo
ool0DOooool2o`0000Sooooo0_l00008ooooo`;o00000_ooool2o`0001cooooo1?l00004ooooo`?o
00001Oooool=o`0000Cooooo0_l00005ooooo`;o00006_ooool2o`0000?ooooo1Ol0000Aooooo`;o
00003Oooool4o`0000Kooooo0_l00009ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0
>Oooool2o`000003ooooool0003o000000;ooooo0_l0000;ooooo`;o00000_ooool3o`000003oooo
ool0003o000000;o00000_ooool2o`0000Sooooo0_l00002ooooo`Co00006_ooool4o`0000Cooooo
1?l00002ooooo`;o00000oooool7o`0001_ooooo0_l0000Booooo`;o000000?oooooo`000?l00000
1Oooool2o`0000Wooooo0ol0000:ooooo`;o000000?oooooo`000?l000002?ooool3o`0004Oooooo
000Looooo`03o`000?oooooooooo02_ooooo0_l0000<ooooo`;o000000?oooooo`000?l000001?l0
000;ooooo`Co000000Coooooo`000?l0003ooooo1?l00008ooooo`;o00002?ooool2o`0000gooooo
1?l00002ooooo`;o00001_ooool2o`0000Oooooo0_l00002ooooo`Oo00000oooool3o`0000gooooo
0_l0000;ooooo`;o00007?ooool2o`0000Wooooo0_l0000;ooooo`;o00002Oooool2o`000004oooo
ool0003o0000o`0004Kooooo000Looooo`03o`000?oooooooooo02_ooooo0_l000000ooooooo0000
o`00000<ooooo`Co00003_ooool3o`0000Cooooo0_l0000:ooooo`;o00003?ooool5o`0000Kooooo
1?l00002ooooo`?o00000oooool4o`0000;ooooo0ol00008ooooo`Co00000oooool4o`0000;ooooo
0_l00009ooooo`;o00008Oooool2o`0000_ooooo0_l00006ooooo`;o00005?ooool2o`0000;ooooo
0_l00016ooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00004?ooool4o`000003ooooool0
003o000000Kooooo0_l00003ooooo`;o000000?oooooo`000?l000003?ooool2o`0000Cooooo0_l0
0004ooooo`Go00003Oooool2o`0000?ooooo0ol00003ooooo`?o00003oooool2o`0000Cooooo0_l0
000Cooooo`;o00001_ooool3o`0000Kooooo0_l00006ooooo`;o00001oooool2o`0000;ooooo0_l0
0006ooooo`?o00001?ooool2o`0000_ooooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`10
ooooo`Co000000?oooooo`000?l000001_ooool2o`0000?ooooo0_l000000ooooooo0000o`00000:
ooooo`Co00001?ooool2o`0000?ooooo0_l00006ooooo`;o00001Oooool2o`0000;ooooo0_l00004
ooooo`Co00002_ooool4o`0000Gooooo0_l00006ooooo`?o00001oooool2o`0000Gooooo1?l00006
ooooo`?o00001?ooool4o`0000kooooo0ol0000;ooooo`;o00001?ooool2o`0000_ooooo0_l0000<
ooooo`;o0000?_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l0
00000ol@413oooooooooo`04ooooo`03o`000?oooooooooo03Wooooo0_l0000Cooooo`;o00003Ooo
ool2o`0000;ooooo0_l000001?oooooo0000o`000?l00007ooooo`;o00001_ooool2o`0000Gooooo
0_l00009ooooo`?o00001Oooool2o`0000?ooooo1?l00005ooooo`;o00001_ooool3o`0000Oooooo
0_l00005ooooo`;o00000oooool2o`0000Cooooo0_l00004ooooo`?o00003oooool2o`0001Oooooo
0_l00002ooooo`;o00002_ooool2o`0000?ooooo1?l0000mooooo`0000KoooooogMgMonHV9Sooooo
oiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo037o
oooo0_l00003ooooo`;o000000?oooooo`000?l000004oooool2o`0000gooooo0_l00005ooooo`?o
00000oooool2o`0000oooooo0_l00002ooooo`Co00003Oooool4o`0000;ooooo0_l00002ooooo`;o
00003?ooool2o`0000;ooooo0_l0000>ooooo`;o00000_ooool2o`000003ooooool0003o000000So
oooo0_l000000ooooooo0000o`000002o`0000Oooooo0_l0000?ooooo`;o00001Oooool2o`0000;o
oooo0_l00006ooooo`;o00000_ooool4o`000003ooooool0003o000000;o0000?Oooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo00?o0000ooooooooool0
<Oooool2o`0000?ooooo0_l0000Aooooo`;o00005_ooool4o`0000Gooooo0ol00002ooooo`;o0000
2_ooool2o`0000;ooooo1?l0000?ooooo`;o00000_ooool2o`0000;ooooo0ol0000;ooooo`;o0000
00Coooooo`000?l0003o00004_ooool2o`000004ooooool0003o0000ooooo`;o00000oooool4o`00
0003ooooool0003o000000;o00001oooool5o`0000[ooooo1_l00003ooooo`;o00002_ooool2o`00
0004ooooool0003o0000ooooo`;o00000oooool2o`0003gooooo00000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`0003Oooooo0_l0000@
ooooo`;o00002Oooool2o`000003ooooool0003o000000Gooooo0_l000000ooooooo0000o`000002
o`0000;ooooo0_l00002ooooo`;o00000_ooool2o`000004ooooool0003o0000o`0000Wooooo0_l0
000:ooooo`;o00001Oooool2o`0000?ooooo0_l00003ooooo`?o00000oooool2o`0000Sooooo1?l0
00000ooooooo0000o`00000;ooooo`?o00001_ooool3o`0000;ooooo0_l0000?ooooo`Co00002_oo
ool2o`000004ooooool0003o0000o`0000Cooooo0_l00009ooooo`;o000000?oooooo`000?l00000
1?ooool2o`0003oooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Co
gMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`0gooooo`;o00004?ooool2o`0000Wooooo
0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00007ooooo`;o000000?oooooo`000?l0
00000oooool2o`000003ooooool0003o000000Oo00000oooool2o`0000[ooooo1?l00003ooooo`;o
00000_ooool2o`0000Gooooo0_l00003ooooo`;o00000_ooool2o`0000Kooooo0_l000000ooooooo
0000o`00000;ooooo`?o00001oooool2o`0002Gooooo0_l00004ooooo`;o00000oooool2o`000004
ooooool0003o0000ooooo`;o000000?oooooo`000?l000000_ooool4o`0003oooooo00000ooooooo
410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oMgMgolc<c?l000001oooool00ol0003o
ooooooooo`16ooooo`;o00003?ooool2o`0000Cooooo0_l000000ooooooo0000o`00000;ooooo`;o
00000oooool>o`0000kooooo0ol00003ooooo`?o000000Coooooo`000?l0003ooooo1?l00009oooo
o`?o00006?ooool2o`0000oooooo0_l00005ooooo`?o00001oooool2o`0000[ooooo0_l00007oooo
o`Co000000?oooooo`000?l000001?ooool2o`0000;ooooo0ol00010ooooo`0000KoooooogMgMonH
V9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0>Oooool2
o`0000_ooooo0_l00003ooooo`;o00001oooool2o`0000Cooooo1_l0000;ooooo`?o000000?ooooo
o`000?l000001ol00003ooooo`;o00003oooool2o`0000?ooooo1Ol00002ooooo`Co000000?ooooo
o`000?l000000ol00002ooooo`Co00000oooool2o`0001;ooooo0ol0000?ooooo`;o00001Oooool3
o`0000Gooooo1?l0000Cooooo`;o00000_ooool2o`0000Cooooo0_l00004ooooo`;o0000@?ooool0
0006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oo
oooooooo03Wooooo0_l00006ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o00001_oo
ool3o`0000Kooooo1Ol00006oooooaCo00001oooool2o`0000Gooooo0_l000000ooooooo0000o`00
0004ooooo`Co00001oooool5o`0000;ooooo0_l00005ooooo`;o00001Oooool2o`000003ooooool0
003o000000Sooooo0_l00003ooooo`;o00006_ooool2o`0001Wooooo0_l00004ooooo`;o000000?o
ooooo`000?l000001?ooool2o`0003gooooo000Looooo`03o`000?oooooooooo03Cooooo0_l0000:
ooooo`?o000000?oooooo`000?l000000_l0000;ooooo`;o00001Oooool2o`0000;ooooo0ol00003
ooooo`;o000000?oooooo`000?l000005?l00005ooooo`;o00001Oooool2o`0000?ooooo0_l00000
1?oooooo0000o`000?l0000<ooooo`;o00004?ooool2o`000003ooooool0003o000000Gooooo0_l0
0006ooooo`;o00002?ooool2o`000003ooooool0003o000002_ooooo0ol00003ooooo`;o00001?oo
ool2o`0003gooooo000Looooo`03o`000?oooooooooo033ooooo0_l00002ooooo`;o00001?ooool2
o`0000?ooooo0ol0000Hooooo`;o00000_ooool2o`0000;ooooo7?l0000:ooooo`;o00001?ooool2
o`000003ooooool0003o000000;o00002oooool2o`0000Gooooo0_l00005ooooo`;o00003?ooool4
o`0000gooooo0ol000000ooooooo0000o`00000=ooooo`;o000000?oooooo`000?l000001Oooool2
o`0001;ooooo0ol00005ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0<?ooool2o`00
00Sooooo0_l00002ooooo`?o00002?ooool2o`0000Gooooo0_l0000<oooooago000000?oooooo`00
0?l000002_ooool2o`0000?ooooo0_l00003ooooo`Go00002?ooool2o`0000Kooooo0_l00005oooo
o`;o000000?oooooo`000?l000002oooool2o`0000?ooooo0_l00008ooooo`;o00002_ooool2o`00
00Gooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l000000ooooooo0000o`00000Boooo
o`;o000000?oooooo`000?l000001?l000000ooooooo0000o`000004ooooo`;o0000=_ooool001co
oooo00?o0000ooooooooool0?_ooool2o`0000Gooooo0_l00002ooooo`;o00001Oooool3o`0000Go
oooo0_l00005ooooo`?o000000?oooooo`000?l000006_l0000>ooooo`;o00000oooool5o`0000Co
oooo0_l000000ooooooo0000o`000003o`0000kooooo0_l00009ooooo`;o000000Coooooo`000?l0
003ooooo0ol00008ooooo`;o00000oooool4o`0000?ooooo0_l00005ooooo`;o000000?oooooo`00
0?l000000_l00006ooooo`;o00004_ooool9o`000003ooooool0003o000000Cooooo0_l0000foooo
o`007?ooool00ol0003oooooooooo`15ooooo`;o00002_ooool2o`0000Gooooo0_l00003ooooo`Co
00000_oooolOo`000003ooooool0003o000000kooooo0ol00005ooooo`;o000000Coooooo`000?l0
003ooooo1?l00004ooooo`;o00002Oooool2o`0000Kooooo0_l000000ooooooo0000o`000003o`00
00;ooooo0_l000001?oooooo0000o`000?ooool2o`000004ooooool0003o0000ooooo`Co00003Ooo
ool3o`0000Sooooo0_l0000;ooooo`;o00001?ooool3o`0000;ooooo0_l00011ooooo`007?ooool0
0ol0003oooooooooo`12ooooo`;o00000_ooool2o`00013ooooo0ol00002ooooo`Co00000_oooolO
o`000003ooooool0003o000000oooooo0_l0000:ooooo`Go00001?ooool2o`0000Oooooo1?l00002
ooooo`;o00001_ooool3o`0000?ooooo1Ol000001?oooooo0000o`000?ooool2o`0000;ooooo0ol0
000>ooooo`;o00002?ooool2o`0000[ooooo0ol00005ooooo`;o000000?oooooo`000?l00000@_oo
ool001cooooo00?o0000ooooooooool0;oooool2o`00017ooooo0_l00002ooooo`;o00003oooool5
o`000003ooooool0003o000000;o000000?oooooo`000?l000003Ol000000ooooooo0000o`000009
o`0000;ooooo0ol0000Hooooo`;o00001?ooool3o`0000Gooooo0_l00008ooooo`;o00001?ooool2
o`0000Oooooo0_l00002ooooo`Go000000?oooooo`000?l000000oooool2o`0000;ooooo0_l0000D
ooooo`;o00000_ooool2o`0000Oooooo0_l000000ooooooo0000o`000009ooooo`;o0000@_ooool0
01cooooo00?o0000ooooooooool0:oooool6o`0000cooooo0_l00006ooooo`;o00004?ooool5o`00
0003ooooool0003o000000?ooooo3ol000000ooooooo0000o`00000:o`00017ooooo0_l00009oooo
o`;o00000_ooool2o`0000Sooooo0_l00007ooooo`;o00001?ooool6o`0000Cooooo0_l000000ooo
oooo0000o`000003o`000005ooooool0003o0000o`000?ooool01?l000000ooooooo0000o`000003
o`0000Cooooo0_l0000<ooooo`;o00001_ooool2o`000003ooooool0003o000000;o00000_ooool2
o`0004cooooo000Looooo`03o`000?oooooooooo02_ooooo1?l00004ooooo`;o00000_ooool2o`00
00;ooooo1?l00006ooooo`?o00001?ooool2o`0000[ooooo1?l00005oooooa;o000000?oooooo`00
0?l000002Ol000000ooooooo0000o`00000=ooooo`;o00003Oooool2o`00013ooooo0ol00004oooo
o`Ko000000?oooooo`000?l000002Ol000000ooooooo0000o`000004o`0000;ooooo1ol00003oooo
o`Co000000?oooooo`000?l000003oooool2o`000003ooooool0003o000000Cooooo0_l0000Doooo
o`;o0000=_ooool001cooooo00?o0000ooooooooool0<_ooool3o`000004ooooool0003o0000o`00
00;ooooo0_l00009ooooo`;o00001?ooool2o`0000[ooooo0_l00004ooooo`;o000000?oooooo`00
0?l000007?l000000ooooooo0000o`000008ooooo`;o00001_ooool2o`0000[ooooo0_l0000@oooo
o`;o00001Oooool2o`0000;ooooo0_l000001Ooooooo0000o`000?l0003ooooo00Go00001?ooool6
o`000003ooooool0003o000000Oo000000?oooooo`000?l000000_l000000ooooooo0000o`000002
ooooo`;o00003?ooool2o`0001Oooooo0_l00003ooooo`;o0000=_ooool001cooooo00?o0000oooo
ooooool0;?ooool2o`0000;ooooo1?l000001?oooooo0000o`000?l00002ooooo`;o00002_ooool4
o`0000Wooooo0_l00009ooooo`;o00000_oooolHo`000003ooooool0003o000000;o000000?ooooo
o`000?l000002?ooool2o`0000Kooooo0_l00004ooooo`Co00001_ooool2o`0000;ooooo0_l00004
ooooo`;o00000_ooool2o`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l000000_ooool6
o`0000Cooooo1Ol00002ooooo`;o00001?ooool2o`0000;ooooo0_l00006ooooo`?o00002oooool2
o`0000Gooooo0_l0000@ooooo`?o000000?oooooo`000?l00000=oooool001cooooo0_l0000Yoooo
o`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o00000oooool2o`0000[ooooo1?l00007oooo
o`Co00000_ooool3o`0000?ooooo0_l00003ooooob3o00001oooool2o`0000Cooooo0_l00007oooo
o`Co00001_ooool2o`0000;ooooo0_l00004ooooo`;o00001oooool6o`0000Cooooo0_l000000ooo
oooo0000o`000007o`000003ooooool0003o000000Gooooo1?l000000ooooooo0000o`000002o`00
0003ooooool0003o000000;o00001?ooool3o`0000Kooooo0_l0000:ooooo`;o00001oooool2o`00
0003ooooool0003o000000?ooooo1?l000000ooooooo0000o`00000gooooo`007?ooool00ol0003o
ooooooooo`0Sooooo`;o00000oooool2o`0002Oooooo0_l00004ooooo`?o00000oooool2o`0000;o
oooo7ol00002ooooo`;o00001Oooool2o`0000Cooooo0_l0000Nooooo`;o00000_ooool3o`000003
ooooool0003o000000;o00000_ooool>o`000003ooooool0003o000000?o00000_ooool;o`000003
ooooool0003o000000Kooooo0_l00005ooooo`;o00000_ooool2o`0000oooooo0_l000000ooooooo
0000o`000003ooooo`;o0000??ooool001cooooo00?o0000ooooooooool08oooool2o`0002Cooooo
0_l00009ooooo`;o000000Coooooo`000?l0003o00001ooooolLo`0000Gooooo0_l00007ooooo`;o
00006?ooool2o`0000Gooooo0_l000001?oooooo0000o`000?oooolPo`000003ooooool0003o0000
00?o00000oooool3o`0000Wooooo0_l00002ooooo`;o00001?ooool3o`0000?ooooo0_l00004oooo
o`;o00001?ooool2o`0004Cooooo000Looooo`03o`000?oooooooooo02kooooo0_l00009ooooo`;o
00003_ooool2o`0000Sooooo0ol000000ooooooo0000o`000004ooooo`Co000000?oooooo`000?l0
00006Ol0000<ooooo`Co000000?oooooo`000?l000004?ooool2o`0000?ooooo0_l00005ooooo`;o
00001?ooool2o`000003ooooool0003o000000Oo000000?oooooo`000?l000005?l00002ooooo`;o
00000_ooool2o`0000cooooo1_l00002ooooo`;o00001?ooool2o`0000Cooooo0_l000000ooooooo
0000o`000017ooooo`007?ooool00ol0003oooooooooo`0Nooooo`;o00003_ooool2o`0000Wooooo
0_l0000Gooooo`So00000oooool4o`0000Cooooo2Ol000000ooooooo0000o`000007o`000003oooo
ool0003o000000?o000000?oooooo`000?l000002?ooool3o`0000;ooooo0_l0000@ooooo`;o0000
0_ooool2o`0000gooooo5ol000000ooooooo0000o`000008o`0000;ooooo1Ol00008ooooo`;o0000
0oooool2o`0000;ooooo0_l00002ooooo`;o00003Oooool2o`0000?ooooo0_l00002ooooo`;o0000
1?ooool2o`0003Sooooo000Looooo`03o`000?oooooooooo01kooooo0_l0000Uooooo`;o00002ooo
ool3o`000003ooooool0003o000000;o000000Coooooo`000?l0003o00001Oooool2o`000003oooo
ool0003o0000017o000000?oooooo`000?l000000_l000000ooooooo0000o`000006ooooo`Co0000
2Oooool2o`0000Cooooo0_l00004ooooo`;o00000_ooool2o`0000Gooooo0_l000000ooooooo0000
o`000005o`0000;ooooo9Ol00002ooooo`;o00001?ooool3o`0000Kooooo0_l0000Fooooo`;o0000
0_ooool2o`0000Cooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00000ooo
ool2o`0000Sooooo0_l0000<ooooo`;o00001_ooool3o`0000Gooooo0_l00004oooooa;o00001Ooo
ool2o`0000Gooooo0_l0000;ooooo`;o00000_ooool4o`0000_ooooo0_l00002ooooo`;o000000?o
ooooo`000?l000001Ol000000ooooooo0000o`00000@o`000003ooooool0003o000001;o000000?o
ooooo`000?l000001Oooool2o`0000[ooooo0_l00009ooooo`;o00004Oooool2o`0003Sooooo000L
ooooo`03o`000?oooooooooo02gooooo0_l00007ooooo`?o00000_ooool2o`0001kooooo0ol00000
0ooooooo0000o`000009oooooa;o00001?ooool2o`0001Kooooo1?l00009ooooo`Co00000oooool6
o`000004ooooool0003o0000ooooo`Co000000?oooooo`000?l000001Ol000000ooooooo0000o`00
0007o`000003ooooool0003o000000oo000000Coooooo`000?l0003ooooo0_l0000=ooooo`;o0000
2Oooool2o`0000kooooo1Ol0000hooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o00002?oo
ool2o`0001Wooooo0_l00007ooooo`?o000000?oooooo`000?l000001_ooool6o`0000;ooooo2?l0
0003ooooo`;o00000oooool3o`0001Sooooo0_l00007ooooo`Co00001Oooool6o`0000;ooooo1_l0
00000ooooooo0000o`000006o`000003ooooool0003o000001So000000?oooooo`000?l000000ol0
000Dooooo`;o00001oooool2o`0000Wooooo1Ol0000hooooo`007?ooool00ol0003oooooooooo`0c
ooooo`;o00003oooool2o`0000cooooo0_l00009ooooo`;o00000oooool2o`0000?ooooo0ol00000
0ooooooo0000o`000002ooooo`So00002?ooool2o`0002;ooooo0ol000000ooooooo0000o`000003
ooooo`;o000000?oooooo`000?l000000oooool6o`000003ooooool0003o000000Ko000000?ooooo
o`000?l000001ol000000ooooooo0000o`00000?o`0000;ooooo0ol0000<ooooo`;o00000_ooool2
o`0000;ooooo0_l00007ooooo`;o000000?oooooo`000?l000002Oooool2o`0003Sooooo000Loooo
o`03o`000?oooooooooo03?ooooo0_l0000=ooooo`Co00002?ooool2o`0000?ooooo0_l000000ooo
oooo0000o`000002ooooo`;o000000?oooooo`000?l000000oooool3o`0000?ooooo1?l00006oooo
o`Go00001Oooool2o`0000?ooooo0ol0000<ooooo`;o00005Oooool2o`0000Cooooo1_l00002oooo
o`?o000000?oooooo`000?l000002?l000000ooooooo0000o`00000No`0000cooooo0_l00002oooo
o`;o00003_ooool2o`000003ooooool0003o0000043ooooo000Looooo`03o`000?oooooooooo02Ko
oooo0ol0000?ooooo`;o00000oooool2o`0000?ooooo0_l0000:ooooo`;o00000_ooool3o`000003
ooooool0003o000000;ooooo0_l00007ooooo`;o00000oooool4o`0000[ooooo0_l00004ooooo`;o
00000oooool3o`0000;ooooo0_l00008ooooo`;o000000?oooooo`000?l000000_l00005ooooo`;o
00002_ooool4o`000003ooooool0003o000000Co000000?oooooo`000?l000002ol00002oooooaSo
00000_ooool9o`0001Wooooo0_l00003ooooo`;o000000?oooooo`000?l00000@?ooool001cooooo
00?o0000ooooooooool09Oooool4o`0000Sooooo0_l00005ooooo`;o00000oooool2o`0001?ooooo
0_l00003ooooo`;o00001?ooool2o`0000?ooooo1?l00002ooooo`;o00001Oooool2o`0000Gooooo
0_l00004ooooo`;o00002?ooool2o`000003ooooool0003o000000Sooooo1?l00005ooooo`;o0000
1_ooool2o`0000;ooooo1?l00002ooooo`Go000000?oooooo`000?l00000;Ol000000ooooooo0000
o`00000Iooooo`;o0000B?ooool001cooooo00?o0000ooooooooool09Oooool2o`0000[ooooo0_l0
000Oooooo`;o00000oooool2o`0000Cooooo0_l00003ooooo`Co00002Oooool2o`0000?ooooo0_l0
0009ooooo`;o00001oooool3o`0000Oooooo0_l0000@ooooo`;o00000_ooool2o`0000Cooooo0ol0
0002ooooobco000000?oooooo`000?l000001?ooool2o`0000_ooooo0_l0000>ooooo`;o0000A?oo
ool001cooooo00?o0000ooooooooool0=_ooool2o`000004ooooool0003o0000ooooo`;o00001?oo
ool2o`0000kooooo0_l0000>ooooo`;o00001oooool4o`0000Gooooo0_l00009ooooo`;o00001ooo
ool2o`0000Sooooo0_l0000OoooooaWo000000?oooooo`000?l000004?l000000ooooooo0000o`00
0004ooooo`;o00001Oooool2o`0000Cooooo0_l00005ooooo`?o00001_ooool2o`0004Cooooo000L
ooooo`03o`000?oooooooooo03?ooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0
003o000000Cooooo0_l00006ooooo`;o00001_ooool2o`0000Sooooo0_l000000ooooooo0000o`00
0003ooooo`;o00000_ooool2o`000003ooooool0003o000000;o00000oooool2o`0000cooooo0_l0
0006ooooo`;o00001Oooool2o`0000Cooooo0_l0000;ooooo`;o00000_ooool2o`0000_ooooo0_l0
00000ooooooo0000o`00000Ro`000003ooooool0003o000000?ooooo0_l00009ooooo`Co00002ooo
ool3o`0000Kooooo0_l00014ooooo`007?ooool2o`0003Cooooo0_l0000Eooooo`;o00000_ooool2
o`0000;ooooo0_l00007ooooo`?o000000?oooooo`000?l000000oooool3o`000003ooooool0003o
000000Cooooo0_l00002ooooo`;o00003?ooool2o`0000Kooooo0_l00005ooooo`?o00000oooool2
o`0000Wooooo1?l00002ooooo`;o00000oooool2o`0000Kooooo0_l000000ooooooo0000o`00000A
o`000003ooooool0003o000000ko00000_ooool2o`0000Cooooo0_l00007ooooo`;o00003?ooool4
o`0000Kooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`1<ooooo`Go000000?oooooo`00
0?l000001oooool3o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000001?ooool2o`00
01Oooooo0_l00007ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Gooooo0_l00009oooo
o`;o00001_ooool2o`0000;ooooo3?l000000ooooooo0000o`00000Eo`000003ooooool0003o0000
00Cooooo0_l0000Eooooo`;o00004?ooool3o`0003_ooooo000Looooo`03o`000?oooooooooo03[o
oooo0_l000001?oooooo0000o`000?ooool3o`0000Wooooo0_l000001?oooooo0000o`000?ooool2
o`0000Oooooo0_l00003ooooo`;o00001oooool2o`0000Sooooo1?l0000=ooooo`;o000000?ooooo
o`000?l000002?ooool4o`0000Cooooo0_l0000@ooooo`;o00001?ooool5o`000003ooooool0003o
000000So00000ooooolKo`000003ooooool0003o000000Co00009Oooool3o`0003_ooooo000Loooo
o`03o`000?oooooooooo037ooooo0ol00006ooooo`;o000000Coooooo`000?l0003ooooo0ol00002
ooooo`;o00006oooool2o`0000Cooooo1_l00005ooooo`Co00003Oooool2o`0000?ooooo0_l00003
ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo0ol00003ooooo`;o00000oooool2
o`0000Kooooo0_l00002ooooobko000000Coooooo`000?l0003ooooo0ol000000ooooooo0000o`00
0002o`0000?ooooo0_l000000ooooooo0000o`000007ooooo`;o00001oooool2o`0000?ooooo0_l0
000oooooo`007?ooool00ol0003oooooooooo`0aooooo`?o000000?oooooo`000?l000002Oooool4
o`000003ooooool0003o000001_ooooo0_l00004ooooo`;o000000Coooooo`000?l0003o00006ooo
ool2o`0000;ooooo0ol000001?oooooo0000o`000?ooool3o`0000;ooooo1?l00003ooooo`;o0000
0oooool3o`0000Gooooo0_l00003ooooo`;o00000_ooool5o`000003ooooool0003o0000027o0000
1?ooool2o`000003ooooool0003o000000Co00000_ooool2o`000003ooooool0003o000000Oooooo
0_l00007ooooo`;o00000oooool3o`0003kooooo000Looooo`03o`000?oooooooooo03Gooooo0_l0
0003ooooo`;o00001_ooool2o`0000gooooo1?l0000=ooooo`;o000000?oooooo`000?l000004ooo
ool2o`0000Sooooo0_l00007ooooo`;o00001?ooool3o`0000?ooooo0_l0000;ooooo`?o00002Ooo
ool2o`000004ooooool0003o0000ooooo`co000000?oooooo`000?l000006?l000001?oooooo0000
o`000?ooool2o`000004ooooool0003o0000ooooo`?o00003?ooool4o`0000[ooooo0_l000000ooo
oooo0000o`00000nooooo`007?ooool00ol0003oooooooooo`0iooooo`?o00001?ooool4o`0000go
oooo1?l00004ooooo`Co00001?ooool2o`0000;ooooo0_l0000Cooooo`;o00002?ooool2o`0000Wo
oooo0_l00002ooooo`;o00002_ooool2o`0000Kooooo0_l00009ooooo`;o000000?oooooo`000?l0
00000ol000000ooooooo0000o`000007o`000003ooooool0003o000000Co000000?oooooo`000?l0
00004Ol000000ooooooo0000o`000003o`000004ooooool0003o0000ooooo`;o00003Oooool2o`00
00Kooooo0_l00003ooooo`?o00000oooool2o`0003cooooo000Looooo`03o`000?oooooooooo03Wo
oooo0_l00005ooooo`Co00001_ooool2o`000003ooooool0003o000000Oooooo0_l000000ooooooo
0000o`000002o`0000Cooooo0_l0000=ooooo`;o00005_ooool2o`0000Gooooo0_l0000>ooooo`?o
00003_ooool4o`0000?ooooo0ol000000ooooooo0000o`00000Ro`0000;ooooo0_l0000Mooooo`;o
00000oooool2o`0000Cooooo0_l0000Iooooo`;o00008Oooool001cooooo00?o0000ooooooooool0
=_ooool3o`0000Cooooo0ol0000:ooooo`Go00001oooool5o`0000_ooooo0_l00008ooooo`;o0000
1?ooool2o`000003ooooool0003o000000gooooo0_l0000;ooooo`;o00002?ooool6o`0000_ooooo
2_l000000ooooooo0000o`00000Co`000003ooooool0003o000000Oo000000?oooooo`000?l00000
0_l00002ooooo`;o00005Oooool2o`0000?ooooo1?l0000Uooooo`;o00008Oooool001cooooo00?o
0000ooooooooool08Oooool2o`0001?ooooo0ol00002ooooo`Go00003?ooool2o`0000Cooooo1?l0
00000ooooooo0000o`000004o`0000Wooooo0_l00003ooooo`;o00002Oooool5o`0000Oooooo0_l0
00000ooooooo0000o`000004ooooo`;o00002?ooool2o`0000Sooooo0_l000001?oooooo0000o`00
0?l00008ooooo`?o00000oooool;o`000003ooooool0003o000001[o000000?oooooo`000?l00000
5?ooool2o`0000Cooooo0_l000000ooooooo0000o`000006o`000003ooooool0003o000004?ooooo
000Looooo`03o`000?oooooooooo027ooooo0_l0000Hooooo`;o00004Oooool8o`000005ooooool0
003o0000o`000?ooool00_l0000:ooooo`;o00000_ooool4o`0000;ooooo0_l00005ooooo`;o0000
2?ooool2o`000003ooooool0003o000000Cooooo0ol0000=ooooo`;o000000?oooooo`000?l00000
2Oooool2o`0000;ooooo1Ol00004ooooob[o00001oooool2o`0000Wooooo0_l00007ooooo`;o0000
0_ooool9o`00047ooooo000Looooo`03o`000?oooooooooo02cooooo0_l0000Pooooo`Co00005?oo
ool3o`0000;ooooo1?l00002ooooo`;o00001Oooool2o`0000?ooooo0_l000000ooooooo0000o`00
000:ooooo`;o00000_ooool2o`0000Wooooo0_l000000ooooooo0000o`000008ooooo`?o00001?oo
ool3o`0000;ooooo9_l000000ooooooo0000o`000003o`0000Oooooo0_l00005ooooo`;o00003_oo
ool3o`000003ooooool0003o000000;ooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0/
ooooo`;o00003_ooool2o`0001Oooooo0_l00003ooooo`;o00002_ooool2o`0000?ooooo0_l00005
ooooo`?o00000oooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000001_ooool2
o`0000Kooooo0_l0000?ooooo`;o00000_ooool2o`000003ooooool0003o000000Gooooo0_l00003
ooooobWo000000?oooooo`000?l000001Oooool2o`0000Oooooo0_l0000:ooooo`;o00000_ooool2
o`0000;ooooo0_l000000ooooooo0000o`000012ooooo`007?ooool00ol0003oooooooooo`0goooo
o`;o00000oooool3o`0001Kooooo0_l00003ooooo`Co00002?ooool2o`0000?ooooo0_l00004oooo
o`Co00000oooool2o`000004ooooool0003o0000ooooo`;o00002?ooool2o`0000cooooo0_l00004
ooooo`Co000000?oooooo`000?l000000_ooool2o`0000gooooo0_l00002oooooaco000000?ooooo
o`000?l000002Ol00005ooooo`;o00002_ooool3o`0000Kooooo0_l00009ooooo`;o0000@_ooool0
01cooooo00?o0000ooooooooool0:oooool2o`0000Wooooo0ol00004ooooo`;o00001Oooool4o`00
00?ooooo0_l00005ooooo`;o00001_ooool6o`0000Kooooo0ol00008ooooo`Co00000_ooool2o`00
00Gooooo0_l0000Booooo`;o00000_ooool2o`0000Cooooo1?l000000ooooooo0000o`00000?oooo
ob7o00000oooool3o`0000?ooooo0_l00002ooooo`;o00003oooool3o`0000;ooooo0_l00009oooo
o`?o0000AOooool001cooooo00?o0000ooooooooool09Oooool2o`0000Cooooo0_l00009ooooo`;o
00003?ooool4o`0000?ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00002Oooool2o`00
0003ooooool0003o000000?ooooo0ol0000:ooooo`;o00000_ooool2o`0000;ooooo0ol0000:oooo
o`;o00002?ooool2o`00017ooooo0_l0000:ooooo`So00000oooool3o`000003ooooool0003o0000
00Oo000000?oooooo`000?l000002?l00003ooooo`;o000000?oooooo`000?l000001_l0000?oooo
o`;o00000oooool3o`0000Sooooo0ol00007ooooo`;o0000??ooool001cooooo0_l0000Vooooo`;o
00006?ooool2o`0000Sooooo0_l00004ooooo`;o00000_ooool2o`0000cooooo0_l00003ooooo`?o
00001oooool2o`0000Wooooo0ol00006ooooo`;o00000_ooool2o`0001_ooooo0_l00002ooooo`;o
00000oooool5o`0000Kooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o0000
01?o00000oooool6o`0000oooooo0_l00006ooooo`;o000000?oooooo`000?l000003oooool2o`00
03cooooo000Looooo`03o`000?oooooooooo03kooooo0ol00008ooooo`;o00000oooool2o`0000So
oooo0_l00008ooooo`;o00000oooool4o`0000Gooooo0_l0000@ooooo`Co00000oooool4o`0000ko
oooo0_l00008ooooo`;o00000_ooool4o`000003ooooool0003o000000?o00001_ooool5o`000004
ooooool0003o0000o`0000;ooooo4ol000000ooooooo0000o`000005ooooo`;o00003_ooool2o`00
00Wooooo0_l00006ooooo`;o0000AOooool001cooooo00?o0000ooooooooool0>?ooool2o`0000Co
oooo0_l0000>ooooo`;o00000oooool2o`0000?ooooo0_l00002ooooo`;o00001?ooool2o`0000Go
oooo0_l00009ooooo`;o00000_ooool2o`0000;ooooo1?l00002ooooo`;o00001Oooool6o`0000Ko
oooo0ol00003ooooo`?o00001oooool2o`0000Cooooo0_l00004ooooo`;o00000_ooool2o`0000Co
oooo0ol000001?oooooo0000o`000?l00002ooooo`Wo000000?oooooo`000?l000001_l00002oooo
o`;o00001Oooool2o`00013ooooo0_l0000;ooooo`;o00000_ooool3o`0004Cooooo000Looooo`03
o`000?oooooooooo03Oooooo0ol00004ooooo`;o00003_ooool2o`0000?ooooo0_l00007ooooo`;o
00005_ooool2o`0000;ooooo0_l00002ooooo`Ko00002oooool3o`0000Cooooo1?l00003ooooo`?o
00001oooool2o`0000kooooo0_l00002ooooo`So00000_ooool2o`0000?ooooo0_l000001?oooooo
0000o`000?ooool8o`0000Sooooo0_l0000;ooooo`;o00001?ooool2o`0000Cooooo0_l00005oooo
o`;o00000oooool2o`0000Kooooo0_l0000looooo`007?ooool00ol0003oooooooooo`0gooooo`;o
00004?ooool2o`000003ooooool0003o000000cooooo0_l00009ooooo`;o00004oooool2o`0000Co
oooo0_l0000;ooooo`Co00000oooool2o`0000Gooooo0ol0000Kooooo`;o00000_ooool3o`0000?o
oooo1?l000000ooooooo0000o`000003o`000003ooooool0003o000000Oo00000oooool6o`0000_o
oooo0ol00002ooooo`?o00001?ooool4o`0000Kooooo0_l00004ooooo`;o00000_ooool2o`0003co
oooo000Looooo`03o`000?oooooooooo04Wooooo0_l000000ooooooo0000o`000004ooooo`;o0000
1_ooool3o`0000Sooooo0_l00006ooooo`;o000000?oooooo`000?l000001Oooool2o`000003oooo
ool0003o000000;o00001Oooool2o`0000Cooooo0_l00004ooooo`;o00001_ooool2o`000003oooo
ool0003o000000;o000000Coooooo`000?l0003o00001?ooool2o`0000Cooooo0_l0000@ooooo`;o
000000?oooooo`000?l000001?l00003ooooo`?o00001_ooool4o`0000?ooooo1?l0000<ooooo`Go
000000Coooooo`000?l0003o00001_ooool2o`000003ooooool0003o000000?ooooo0_l00004oooo
o`;o0000@?ooool001cooooo00?o0000ooooooooool0>?ooool2o`0000gooooo0_l00009ooooo`;o
00001oooool2o`0000gooooo0_l000001?oooooo0000o`000?ooool4o`0000?ooooo1ol00005oooo
o`;o00001?ooool2o`0000;ooooo0_l00008ooooo`;o000000?oooooo`000?l000000oooool3o`00
00Cooooo0_l000001?oooooo0000o`000?ooool2o`0000Cooooo0_l00002ooooo`;o00002Oooool9
o`0000Kooooo0_l00003ooooo`;o00004oooool5o`000003ooooool0003o000000Cooooo0_l00004
ooooo`;o00002_ooool2o`0003oooooo000Looooo`03o`000?oooooooooo03Sooooo0_l00003oooo
o`;o00002?ooool2o`0000;ooooo0ol0000=ooooo`;o00002?ooool2o`0000?ooooo0_l00005oooo
o`Go000000?oooooo`000?l000000ol00004ooooo`;o00000_ooool4o`0000Gooooo0_l00005oooo
o`;o00000oooool2o`0000_ooooo0_l000000ooooooo0000o`000007ooooo`;o00000_ooool2o`00
00Gooooo1?l000000ooooooo0000o`000008o`000004ooooool0003o0000ooooo`;o00000oooool2
o`0001Sooooo0ol000001?oooooo0000o`000?ooool2o`00013ooooo0_l0000oooooo`007?ooool0
0ol0003oooooooooo`0mooooo`?o00002oooool3o`000003ooooool0003o000001Cooooo0_l00008
ooooo`Oo000000?oooooo`000?l000000ol00002ooooo`Go000000?oooooo`000?l000000_l00007
ooooo`;o00000oooool2o`0000?ooooo0_l0000>ooooo`;o00001oooool2o`0000;ooooo0_l00000
0ooooooo0000o`000002ooooo`Go000000?oooooo`000?l000000ol00002ooooo`Go00001_ooool2
o`0001Sooooo1_l0001Dooooo`007?ooool00ol0003oooooooooo`0booooo`;o00001?ooool2o`00
00Cooooo0_l00007ooooo`;o00001?ooool4o`0001cooooo4ol000000ooooooo0000o`00000<oooo
o`;o00000oooool2o`0000cooooo0_l00002ooooo`;o00002Oooool2o`0000?ooooo1Ol00005oooo
o`;o00000_ooool4o`0000;ooooo1?l00007ooooo`;o00004?ooool2o`0000?ooooo0_l000000ooo
oooo0000o`000002o`0000Gooooo0_l00005ooooo`?o0000Aoooool001cooooo00?o0000oooooooo
ool0<_ooool2o`0000;ooooo1?l00003ooooo`;o00000_ooool2o`0000Cooooo0_l00004ooooo`?o
00000_ooool2o`0000Wooooo1?l0000<oooooa?o00000oooool2o`0000kooooo0_l0000;ooooo`Co
00000_ooool4o`0000Oooooo0_l00004ooooo`;o00001oooool2o`0000Cooooo0_l00002ooooo`;o
00001?ooool3o`0000?ooooo0_l00009ooooo`;o00000oooool4o`0000;ooooo1Ol000000ooooooo
0000o`000002o`0000;ooooo0_l00005ooooo`?o0000Aoooool001cooooo00?o0000ooooooooool0
=?ooool4o`0000Cooooo0ol00002ooooo`;o000000?oooooo`000?l000003?ooool3o`0000Oooooo
1Ol00002ooooo`;o00001ooooolMo`0000[ooooo0_l00004ooooo`;o00001Oooool2o`0000Cooooo
1?l0000:ooooo`;o00000_ooool2o`0001Cooooo1Ol00003ooooo`;o00002Oooool2o`000003oooo
ool0003o000000Co00000_ooool5o`000003ooooool0003o000000;o00001_ooool2o`0004_ooooo
000Looooo`03o`000?oooooooooo02oooooo0_l00003ooooo`;o00001_ooool2o`0000Kooooo0_l0
000=ooooo`;o00001oooool4o`0000?ooooo1?l000000ooooooo0000o`000002ooooo`;o000000Go
ooooo`000?l0003o0000ooooo`0Fo`0000Oooooo0_l00002ooooo`;o00000_ooool6o`0000Kooooo
1?l000001?oooooo0000o`000?ooool2o`0000Kooooo0ol000000ooooooo0000o`000004ooooo`;o
00002?ooool3o`0000?ooooo0_l0000:ooooo`;o00002?ooool2o`000003ooooool0003o000000?o
oooo0_l000000ooooooo0000o`000003ooooo`;o00001?ooool4o`000004ooooool0003o0000oooo
o`;o0000AOooool001cooooo00?o0000ooooooooool0;oooool2o`0000?ooooo0_l00002ooooo`;o
00000_ooool2o`000004ooooool0003o0000ooooo`Co00005?ooool3o`0000;ooooo0_l00004oooo
o`;o000000?oooooo`000?l000000ooooolMo`0000Kooooo0_l00002ooooo`;o00000_ooool6o`00
00Kooooo0_l00003ooooo`;o000000?oooooo`000?l000001oooool2o`0000Oooooo0_l00008oooo
o`?o00001?ooool2o`0000;ooooo0_l00005ooooo`;o00001oooool3o`000003ooooool0003o0000
00;o00001oooool2o`0000;ooooo0ol000000ooooooo0000o`000003ooooo`;o000000?oooooo`00
0?l00000AOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo03Sooooo0ol000001?oooooo0000o`00
0?ooool2o`000004ooooool0003o0000o`0000Kooooo0_l0000=ooooo`?o00000_ooool2o`0000co
oooo7Ol0000?ooooo`;o00008oooool2o`0000oooooo0_l000001?oooooo0000o`000?l00004oooo
o`;o00000_ooool2o`0000?ooooo1?l00003ooooo`;o00001oooool7o`0000[ooooo0_l00014oooo
o`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonH
V9So8B4Q00Kooooo00?o0000ooooooooool0>?ooool3o`000003ooooool0003o000000Gooooo0_l0
00000ooooooo0000o`000002ooooo`?o00007?ooool3o`000003ooooool0003o000001[o00008ooo
ool2o`0001Gooooo0ol0000<ooooo`;o00001Oooool2o`0000;ooooo0_l00003ooooo`Co00003_oo
ool2o`0000cooooo1Ol00012ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0iooooo`;o00002_oo
ool3o`0000;ooooo0_l00006ooooo`;o00005OoooolPo`0001;ooooo0_l00006ooooo`;o00000ooo
ool2o`0000;ooooo0_l00003ooooo`Co00003_ooool3o`0001Cooooo0_l0000;ooooo`?o00000_oo
ool2o`0000Kooooo0ol00008ooooo`;o000000?oooooo`000?l000000ol00012ooooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_oo
ool3o`0003cooooo1Ol00004ooooo`;o00000_ooool2o`0000Oooooo0_l00009ooooo`?o00003?oo
ool8o`000003ooooool0003o000001Oo00003Oooool2o`0000Kooooo0_l00003ooooo`;o00001ooo
ool4o`0000cooooo1?l00009ooooo`;o00000oooool2o`0000Gooooo0_l0000;ooooo`?o00000_oo
ool2o`0000Oooooo0_l00008ooooo`;o00000_ooool2o`0004Cooooo00000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oo
oooooooo03cooooo1ol00006ooooo`;o00004_ooool3o`000003ooooool0003o000000Oooooo9?l0
0008ooooo`;o00001_ooool3o`00013ooooo0ol0000=ooooo`;o00000oooool2o`0000?ooooo0_l0
00000ooooooo0000o`000003ooooo`;o00001_ooool4o`0000Wooooo0_l00006ooooo`;o00004ooo
ool2o`0004;ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEE
ohN7Qoooool02?ooool00ol0003oooooooooo`11ooooo`;o00001Oooool2o`0001Cooooo0_l00000
0ooooooo0000o`000002ooooo`;o00000ooooolTo`0000Sooooo0_l00006ooooo`Co00004?ooool2
o`00017ooooo0ol00003ooooo`;o00001Oooool4o`0000Gooooo1?l000000ooooooo0000o`000006
ooooo`;o00001_ooool2o`0001;ooooo0ol0000Iooooo`;o00009oooool00006oooooomgMgOoV9RH
oooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo04Sooooo0_l0
000>ooooo`;o00001?ooool2o`0000Gooooo0_l00004oooooaKo000000?oooooo`000?l000000_l0
0005ooooo`?o00004?ooool4o`0000[ooooo0_l00003ooooo`;o00002Oooool3o`0000?ooooo0_l0
00000ooooooo0000o`00000:ooooo`Go00001_ooool2o`0000;ooooo0_l00004ooooo`;o00001Ooo
ool2o`0000?ooooo0_l00007ooooo`;o00001oooool2o`0001[ooooo0_l0000Wooooo`0000Kooooo
onk^k_lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000oooooooo
ool0A_ooool2o`0000gooooo0_l000000ooooooo0000o`000009ooooo`;o00000_ooool2o`0000;o
oooo5Ol00002ooooo`;o000000?oooooo`000?l000000ol000000ooooooo0000o`00000<ooooo`;o
00000oooool2o`0000Cooooo0_l00006ooooo`;o00000oooool2o`0000Gooooo0_l00002ooooo`?o
00000oooool2o`0000Oooooo0ol00003ooooo`;o00002Oooool2o`0000Sooooo0_l00005ooooo`;o
000000?oooooo`000?l000000_l00007ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0
A_ooool2o`0000Wooooo0_l00002ooooo`;o00003?ooool3o`000003ooooool0003o000000;ooooo
1ol000000ooooooo0000o`00000;o`000003ooooool0003o000000Oo00000oooool2o`0000[ooooo
0_l00004ooooo`;o00000oooool2o`0000Sooooo0_l000000ooooooo0000o`000005ooooo`;o0000
0_ooool3o`0000Kooooo1Ol000000ooooooo0000o`000003o`0001gooooo0_l000001?oooooo0000
o`000?l00008ooooo`;o000000?oooooo`000?l000000_ooool2o`0004Gooooo000Looooo`03o`00
0?oooooooooo04Gooooo1?l00008ooooo`;o00001oooool2o`0000Sooooo0_l00005ooooo`;o0000
00?oooooo`000?l000006_l00003ooooo`;o00004?ooool2o`000003ooooool0003o000000Gooooo
0_l00003ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o000000?oooooo`000?l00000
0_l00004ooooo`Wo00000_ooool2o`0000kooooo0ol0000<ooooo`;o00000_ooool2o`0000Kooooo
0_l000000ooooooo0000o`000002o`0000;ooooo0_l00015ooooo`007?ooool00ol0003ooooooooo
o`0iooooo`?o00002Oooool5o`0000?ooooo0_l00007ooooo`;o00000_ooool2o`000003ooooool0
003o000000cooooo0_l000000ooooooo0000o`00000Io`0001Cooooo1?l000000ooooooo0000o`00
0002ooooo`;o000000?oooooo`000?l000001_ooool4o`0000?ooooo0_l000000ooooooo0000o`00
0002o`0000;ooooo1?l00002ooooo`;o000000?oooooo`000?l000001?ooool3o`0000Oooooo0_l0
0002ooooo`?o00001Oooool2o`0000oooooo1?l000000ooooooo0000o`000005ooooo`;o0000A?oo
ool001cooooo00?o0000ooooooooool0>Oooool3o`0000;ooooo0_l00008ooooo`;o00000oooool2
o`0000Oooooo0ol00004ooooo`;o00000oooool2o`0000Sooooo1?l000000ooooooo0000o`00000F
o`0000Cooooo0_l00002ooooo`;o00001Oooool4o`000003ooooool0003o000000Oooooo0_l00007
ooooo`Ko00000oooool2o`0000;ooooo0_l00003ooooo`;o00001?ooool2o`0000?ooooo0_l00000
0ooooooo0000o`000004o`0000Gooooo1_l00006ooooo`;o00003oooool3o`0000;ooooo0_l00005
ooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0?_ooool2o`0000gooooo0ol00007oooo
o`;o00001oooool4o`0000Sooooo7?l00005ooooo`;o00000_ooool4o`0000?ooooo1_l0000?oooo
o`Co00001?ooool2o`000003ooooool0003o000000Cooooo0_l00003ooooo`;o00000_ooool2o`00
00;ooooo0ol000000ooooooo0000o`000002ooooo`?o00001_ooool4o`000003ooooool0003o0000
00;ooooo0_l0000Aooooo`;o00000_ooool2o`000003ooooool0003o000004Sooooo000Looooo`03
o`000?oooooooooo043ooooo0_l0000;ooooo`?o00004?ooool4o`0000Oooooo0_l000000ooooooo
0000o`000005o`000003ooooool0003o0000013o00000_ooool2o`0000Oooooo0_l00004ooooo`;o
000000?oooooo`000?l000002oooool2o`0000;ooooo0_l00006ooooo`;o00001oooool2o`0000?o
oooo0_l00002ooooo`;o00000_ooool2o`0000Oooooo0_l0000:ooooo`?o00000_ooool2o`0000?o
oooo0ol0000Booooo`;o00003Oooool2o`0003Wooooo000Looooo`03o`000?oooooooooo03_ooooo
0_l00003ooooo`;o00001_ooool2o`00013ooooo0_l000000ooooooo0000o`000007ooooo`;o0000
0oooool2o`0000;ooooo6Ol00002ooooo`;o00000oooool2o`000003ooooool0003o000000Gooooo
0_l0000>ooooo`;o00001oooool2o`0000;ooooo0_l0000?ooooo`;o00001Oooool2o`00013ooooo
0_l00008ooooo`?o00003?ooool4o`00017ooooo0_l0000iooooo`007?ooool00ol0003ooooooooo
o`0kooooo`;o00000oooool2o`000003ooooool0003o000000?ooooo0_l00005ooooo`Go00001_oo
ool2o`000003ooooool0003o000000Oooooo0_l00003ooooo`;o00000ooooolEo`000003ooooool0
003o000000Oooooo0_l000000ooooooo0000o`00000:ooooo`;o00002?ooool2o`000003ooooool0
003o000000Cooooo0ol00002ooooo`;o00005Oooool3o`0000Sooooo0ol0000=ooooo`;o00001Ooo
ool3o`0000Oooooo1?l0001<ooooo`007?ooool00ol0003oooooooooo`0looooo`;o00001Oooool2
o`0000[ooooo1Ol00007ooooo`;o00004ooooolEo`000003ooooool0003o000000;ooooo0_l00004
ooooo`;o00002?ooool2o`000003ooooool0003o000000;o00001oooool2o`000003ooooool0003o
000000Cooooo0ol0000Dooooo`;o00000oooool2o`0000Wooooo0ol00002ooooo`;o00002Oooool2
o`0000Gooooo0ol0001Gooooo`007?ooool00ol0003oooooooooo`0looooo`;o00005?ooool4o`00
00Gooooo0_l0000Eooooo`;o000000?oooooo`000?l000004Ol00002ooooo`;o00001?ooool2o`00
00Sooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000Cooooo0_l000000ooo
oooo0000o`000002ooooo`Co00001?ooool2o`0000?ooooo0_l00009ooooo`;o00003Oooool4o`00
00;ooooo0_l0000Mooooo`;o0000Boooool001cooooo00?o0000ooooooooool0AOooool2o`0000Oo
oooo0_l00004ooooo`;o00002oooool2o`0000oooooo0_l000000ooooooo0000o`00000<o`000003
ooooool0003o000000?ooooo0_l000001?oooooo0000o`000?ooool2o`0000Kooooo0_l000000ooo
oooo0000o`000002ooooo`go000000?oooooo`000?l000000_ooool2o`0000Kooooo0_l00003oooo
o`;o00002?ooool2o`000003ooooool0003o000000_ooooo0_l00005ooooo`;o00002?ooool2o`00
00Oooooo0_l00006ooooo`;o000000?oooooo`000?l000002oooool2o`0003kooooo000Looooo`;o
0000A_ooool2o`0000?ooooo1_l0000>ooooo`;o000000?oooooo`000?l000003oooool2o`0000;o
oooo3?l00007ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000002oooo
o`?o00000_oooolAo`000003ooooool0003o000000Cooooo0_l0000=ooooo`;o00000oooool2o`00
0003ooooool0003o0000017ooooo0ol00008ooooo`;o00000oooool2o`0000;ooooo0_l00006oooo
o`;o00003_ooool4o`0003cooooo000Looooo`03o`000?oooooooooo04[ooooo1?l0000@ooooo`;o
00006Oooool9o`0000Oooooo1?l00005ooooo`;o00000_ooool:o`000004ooooool0003o0000oooo
o`go00000_ooool2o`0000gooooo0_l0000:ooooo`;o00003Oooool2o`000003ooooool0003o0000
00?o00002?ooool2o`000003ooooool0003o000000;o00005oooool2o`0003cooooo000Looooo`03
o`000?oooooooooo06Wooooo0_l0000>ooooo`;o00000_ooool4o`0000Wooooo0ol00006ooooo`?o
000000?oooooo`000?l000000ol00002ooooo`Go000000?oooooo`000?l000002?l000000ooooooo
0000o`000004o`00017ooooo0_l00006ooooo`;o00002_ooool2o`0000Cooooo1Ol00004ooooo`;o
00001Oooool4o`0000Cooooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`11ooooo`;o0000
6_ooool2o`0000[ooooo0_l0000Dooooo`;o00002Oooool2o`0000Oooooo0ol00004ooooo`;o0000
0_oooolBo`000003ooooool0003o000000;o00002Oooool2o`0000Kooooo0_l0000:ooooo`?o0000
1Oooool2o`0000gooooo0_l00007ooooo`;o00001?ooool2o`0004oooooo000Looooo`03o`000?oo
oooooooo047ooooo0_l00007ooooo`;o00004Oooool4o`0000Cooooo0_l0000Sooooo`;o00001?oo
ool2o`0000;ooooo0_l00002ooooo`;o00000oooool8o`000003ooooool0003o000000Wo00000_oo
ool2o`0000Wooooo0_l0000:ooooo`;o00000oooool2o`000003ooooool0003o000000;o00007?oo
ool2o`0000Cooooo0_l00006ooooo`Co0000AOooool001cooooo00?o0000ooooooooool0BOooool3
o`00017ooooo1?l00004ooooo`Go00009_ooool2o`0000Cooooo1?l00003ooooo`So000000?ooooo
o`000?l000003Ol0000Dooooo`?o00000oooool2o`0000?ooooo0_l00008ooooo`Co00005_ooool2
o`0000Kooooo1?l00015ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00006?ooool2o`00
00Kooooo0_l0000Cooooo`Co000000?oooooo`000?l000000_l00002ooooo`;o00005_ooool2o`00
0004ooooool0003o0000o`0000?ooooo0ol000000ooooooo0000o`000005oooooaKo00001oooool2
o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000000oooool2
o`0000Gooooo0_l000000ooooooo0000o`000004ooooo`Co00000oooool2o`0000?ooooo0_l0001M
ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00006_ooool2o`0000Cooooo1?l0000<oooo
o`;o00001Oooool7o`0000;ooooo0_l0000Fooooo`;o000000Goooooo`000?l0003o0000ooooo`05
o`0000Kooooo5ol00008ooooo`;o000000?oooooo`000?l000000oooool2o`0000;ooooo1?l00004
ooooo`;o00001Oooool7o`0000Kooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o
000000gooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o00001Oooool3o`00
00Cooooo0_l00006ooooo`;o00001Oooool3o`0002Gooooo0_l00008oooooaSo00004?ooool2o`00
00?ooooo0ol00002ooooo`?o00001oooool2o`0000;ooooo0_l00004ooooo`Co00000oooool2o`00
013ooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o00001Oooool2o`0000Go
oooo0_l00003ooooo`?o00000_ooool2o`0000[ooooo0_l00007ooooo`;o00001Oooool2o`0000[o
oooo0_l00004ooooo`;o00001ooooolHo`0000kooooo1?l000000ooooooo0000o`000005ooooo`?o
00001?ooool2o`000003ooooool0003o000000Sooooo1?l00002ooooo`Go00000_ooool2o`0005[o
oooo000Looooo`03o`000?oooooooooo04;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo
0_l00003ooooo`;o00001oooool3o`0000;ooooo0_l0000:ooooo`;o00001oooool3o`0000;ooooo
1?l0000:ooooo`;o00001?ooool2o`0000;ooooo0_l00004oooooaOo00001_ooool2o`0000Gooooo
1?l00002ooooo`;o00001Oooool3o`0000Cooooo0_l00005ooooo`;o00002_ooool5o`0000;ooooo
0_l000000ooooooo0000o`00001Gooooo`007?ooool00ol0003oooooooooo`12ooooo`?o00000_oo
ool2o`0000;ooooo0_l00003ooooo`;o00000oooool2o`0000Oooooo0_l00005ooooo`;o00004_oo
ool2o`000004ooooool0003o0000o`0000;ooooo0_l0000Booooo`;o00001?oooolIo`0000Cooooo
0_l00005ooooo`Co00002?ooool3o`0000Cooooo0_l00004ooooo`Co00003Oooool2o`0000Gooooo
0_l00002ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0@oooool2o`000003ooooool0
003o000000?ooooo0_l00005ooooo`;o00001oooool4o`0000Kooooo0_l00004ooooo`Co00002_oo
ool2o`000003ooooool0003o000000?ooooo0ol0000Cooooo`;o00000_oooolIo`0000Wooooo0_l0
0008ooooo`;o00000_ooool2o`0000Gooooo1?l00002ooooo`Co00003Oooool2o`0000;ooooo0_l0
0004ooooo`?o0000Doooool001cooooo00?o0000ooooooooool0A_ooool2o`0000[ooooo0_l00007
ooooo`Co00001oooool2o`0000?ooooo1?l00004ooooo`;o000000?oooooo`000?l000000ol00000
0ooooooo0000o`000006o`0000?ooooo0_l0000>oooooa[o00003?ooool2o`0000Kooooo1ol00008
ooooo`;o00001?ooool2o`0000;ooooo0_l0000=ooooo`;o000000?oooooo`000?l000000ol0001D
ooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o00001oooool2o`0000;ooooo0ol00006oooo
o`;o000000Coooooo`000?l0003o00000oooool6o`0000Gooooo0_l00002ooooo`;o00002Oooool2
o`000003ooooool0003o000001Ko00005?ooool2o`0000;ooooo0ol00006ooooo`;o00001?ooool5
o`000003ooooool0003o0000013ooooo0ol0001Fooooo`007?ooool00ol0003oooooooooo`11oooo
o`;o00007oooool4o`0000;ooooo1Ol00009ooooo`;o00004oooool4o`0000Cooooo0_l000000ooo
oooo0000o`000003oooooaGo00005oooool4o`0000Oooooo0_l00004ooooo`;o000000Coooooo`00
0?l0003ooooo0_l0000;ooooo`;o00000oooool2o`0001;ooooo0_l00013ooooo`007?ooool2o`00
03Wooooo0_l00007ooooo`;o00007_ooool5o`0000;ooooo1?l00005ooooo`;o00000oooool2o`00
01Cooooo0ol00004ooooo`;o00002?oooolCo`0000gooooo0_l00008ooooo`Co00005Oooool2o`00
00Cooooo1ol00003ooooo`?o00004Oooool2o`0004?ooooo000Looooo`03o`000?oooooooooo03So
oooo0_l0000Dooooo`;o00001_ooool2o`0000Wooooo0_l00007ooooo`?o00001?ooool2o`000003
ooooool0003o000000[ooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo0_l0000?oooooa?o
00003Oooool2o`0000[ooooo0_l0000:ooooo`;o00002Oooool2o`0000Cooooo1_l00005ooooo`Co
0000E?ooool001cooooo00?o0000ooooooooool0C_ooool2o`0000Kooooo0_l0000Booooo`?o0000
1oooool2o`0000Wooooo0ol00002ooooo`;o000000Coooooo`000?l0003o00005_ooool?o`0000Ko
oooo0_l0000Nooooo`Co00003Oooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l0
00000_l0001Dooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00005?ooool2o`0000;ooooo
0_l00002ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Cooooo0_l00009ooooo`;o0000
0oooool2o`000003ooooool0003o000001Gooooo3_l000000ooooooo0000o`000006ooooo`;o0000
8?ooool2o`00017ooooo0_l000001?oooooo0000o`000?l0001Iooooo`007?ooool00ol0003ooooo
ooooo`15ooooo`;o00003?ooool2o`0000Kooooo0_l00002ooooo`Ko000000?oooooo`000?l00000
1_ooool2o`0000;ooooo1?l0000Oooooo`;o00001oooool2o`0000;ooooo2_l0000Tooooo`;o0000
4_ooool3o`0000Kooooo0ol0001Iooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o00001_oo
ool2o`000003ooooool0003o000000?ooooo0_l00004ooooo`;o00000oooool2o`0000Kooooo0_l0
0002ooooo`;o00006?ooool2o`0000Oooooo0_l00009ooooo`;o000000?oooooo`000?l000001ol0
0006ooooo`;o00004oooool2o`0000Oooooo0_l0000;ooooo`?o00001?ooool3o`0000Kooooo0ol0
001Iooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o00001Oooool2o`0000;ooooo0_l00000
0ooooooo0000o`000007ooooo`?o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00000_oo
ool2o`0001Sooooo0_l0000Booooo`Wo00001oooool4o`0001?ooooo1?l00005ooooo`?o00002_oo
ool3o`0000_ooooo0_l000000ooooooo0000o`00001Iooooo`007?ooool00ol0003oooooooooo`1;
ooooo`;o00000oooool4o`0000Gooooo0_l00007ooooo`?o00001?ooool3o`0000Kooooo0_l0000Q
ooooo`;o00002Oooool4o`0000[ooooo1?l0000Gooooo`;o00001?ooool4o`0000Cooooo0_l0000=
ooooo`;o00000oooool2o`000003ooooool0003o000005Wooooo000Looooo`03o`000?oooooooooo
04Wooooo0_l000000ooooooo0000o`000002ooooo`;o00004Oooool2o`0000Gooooo0_l00002oooo
o`;o00001Oooool2o`0000Oooooo0_l00006ooooo`;o00002Oooool2o`0000;ooooo0_l00009oooo
o`;o000000?oooooo`000?l000000_ooool2o`0000Gooooo0_l00004ooooo`;o00005_ooool2o`00
0003ooooool0003o000000?o00000oooool2o`0000gooooo0ol000000ooooooo0000o`000002oooo
o`;o0000FOooool001cooooo00?o0000ooooooooool0BOooool2o`000003ooooool0003o000001co
oooo1_l00005ooooo`;o00001?ooool2o`000003ooooool0003o000000Kooooo0_l00009ooooo`;o
00004?ooool2o`0000;ooooo0_l0000;ooooo`;o00005_ooool2o`0000;ooooo1?l0000?ooooo`;o
00000_ooool2o`000003ooooool0003o000000?o0000F_ooool001cooooo00?o0000ooooooooool0
K?ooool2o`0000Wooooo0_l000001?oooooo0000o`000?l0000Yooooo`;o00001?ooool2o`0003Go
oooo0_l00007ooooo`?o0000F_ooool001cooooo00?o0000ooooooooool0Eoooool2o`0001kooooo
0_l000001?oooooo0000o`000?ooool2o`0001[ooooo0_l0000:ooooo`?o00001?ooool2o`0001Oo
oooo0_l00006ooooo`;o00000_ooool2o`0000_ooooo0_l0000?ooooo`;o000000?oooooo`000?l0
0000EOooool001cooooo00?o0000ooooooooool0Eoooool2o`0001Gooooo0_l0000=ooooo`;o0000
1oooool2o`00017ooooo1?l00008ooooo`;o00002?ooool2o`0001Cooooo0_l00002ooooo`[o0000
0oooool2o`0000Kooooo0_l00002ooooo`;o00000_ooool5o`0000Cooooo0_l000001?oooooo0000
o`000?l0001Dooooo`007?ooool00ol0003oooooooooo`1Oooooo`;o00003Oooool2o`0001?ooooo
0_l000000ooooooo0000o`00000<ooooo`;o00001Oooool2o`0000Cooooo0_l0000<ooooo`;o0000
4?ooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00005ooooo`;o0000
0oooool2o`0000?ooooo1?l00002ooooo`Ko00001oooool2o`0005Cooooo000Looooo`03o`000?oo
oooooooo05Kooooo0_l00007ooooo`;o00001Oooool3o`0000oooooo0_l00009ooooo`;o00003ooo
ool2o`0000_ooooo0_l0000;ooooo`;o000000?oooooo`000?l000000_l0000<ooooo`;o00000ooo
ool2o`0001;ooooo0ol00003ooooo`Co00000_ooool2o`0000;ooooo0_l0001Mooooo`007?ooool0
0ol0003oooooooooo`1Fooooo`;o00001?ooool2o`0000?ooooo1?l000001Ooooooo0000o`000?l0
003ooooo00;o00002?ooool2o`0000;ooooo0_l0000Oooooo`;o00000_ooool2o`0000Oooooo0_l0
0006ooooo`;o000000?oooooo`000?l000000_l0000Hooooo`;o00002oooool2o`0000_ooooo0_l0
001Pooooo`007?ooool2o`0005gooooo0_l00003ooooo`Co00001Oooool2o`0000Cooooo0_l00002
ooooo`;o00000_ooool2o`0001Wooooo0_l00004ooooo`?o000000?oooooo`000?l000001oooool2
o`0000Cooooo0_l0000Booooo`;o00001?ooool2o`0000Gooooo0_l0000Hooooo`;o0000H?ooool0
01cooooo00?o0000ooooooooool0GOooool2o`0000Cooooo0_l0000;ooooo`;o00001Oooool3o`00
01Wooooo0_l00005ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Wooooo0_l0000=oooo
o`;o00000oooool2o`0000Cooooo0_l00008ooooo`;o0000Moooool001cooooo00?o0000oooooooo
ool0E_ooool2o`0000Cooooo0ol00004ooooo`Co00001Oooool2o`000004ooooool0003o0000o`00
00Gooooo0_l0000Rooooo`Co00000_ooool2o`0000Wooooo1Ol0000:ooooo`;o00004oooool2o`00
00Wooooo0_l000001?oooooo0000o`000?ooool2o`0006Kooooo000Looooo`03o`000?oooooooooo
05Kooooo0_l00004ooooo`;o00001?ooool2o`000003ooooool0003o000000?ooooo1?l000001Ooo
oooo0000o`000?l0003ooooo00;o00003oooool2o`0000?ooooo0_l0000@ooooo`Co00000_ooool4
o`0000?ooooo0_l00002ooooo`Go00001Oooool2o`00027ooooo1?l000001?oooooo0000o`000?oo
ool2o`0006Kooooo000Looooo`03o`000?oooooooooo067ooooo0ol00006ooooo`;o00000oooool2
o`0000;ooooo0_l00006ooooo`;o00001oooool2o`000003ooooool0003o000000;o00004_ooool2
o`0000Cooooo0_l00003ooooo`;o00001?ooool3o`0000?ooooo1?l0000Qooooo`;o00001?ooool3
o`0006Oooooo000Looooo`03o`000?oooooooooo067ooooo0_l00004ooooo`;o00001_ooool2o`00
00[ooooo0_l000000ooooooo0000o`000007ooooo`;o00006?ooool2o`0000Gooooo0_l00004oooo
o`So00001oooool2o`0001kooooo1Ol0001Wooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o
00001?ooool2o`0000Oooooo0_l00002ooooo`;o00004Oooool2o`0000Kooooo0_l0000Iooooo`;o
00000oooool4o`0000Cooooo0_l000001?oooooo0000o`000?l00009ooooo`;o00002oooool2o`00
00Sooooo0_l00006ooooo`?o000000?oooooo`000?l00000Ioooool001cooooo00?o0000oooooooo
ool0F?ooool2o`0000Cooooo0_l00003ooooo`;o00001_ooool2o`0000?ooooo0_l0000<ooooo`;o
00001_ooool2o`0000Oooooo0_l00002ooooo`;o00004Oooool3o`0000Gooooo0_l00004ooooo`;o
00003?ooool2o`0000Cooooo1?l00008ooooo`;o00001_ooool3o`000003ooooool0003o000006Oo
oooo000Looooo`03o`000?oooooooooo06?ooooo0_l0000;ooooo`?o000000?oooooo`000?l00000
0oooool2o`0000?ooooo0_l0000?ooooo`;o00000_ooool2o`0000Gooooo0_l00009ooooo`;o0000
1Oooool2o`0000Kooooo0_l00003ooooo`;o00000oooool2o`0000;ooooo0_l00004ooooo`;o0000
Ooooool001cooooo00?o0000ooooooooool0Joooool2o`0000Cooooo0_l000000ooooooo0000o`00
0002o`000003ooooool0003o000000?ooooo0_l00009ooooo`;o00003oooool2o`0000Wooooo0_l0
0005ooooo`?o00001?ooool3o`0000?ooooo0_l00003ooooo`;o00005Oooool2o`0007;ooooo000L
ooooo`03o`000?oooooooooo06_ooooo1?l000000ooooooo0000o`000003ooooo`?o00003oooool4
o`0002;ooooo0_l00004ooooo`;o00001oooool2o`0001Oooooo0_l0000Iooooo`;o0000Eoooool0
01cooooo00?o0000ooooooooool0H?ooool2o`0000_ooooo0_l000000ooooooo0000o`000003oooo
o`;o00000_ooool2o`000003ooooool0003o000000Wooooo0_l00005ooooo`;o00007Oooool2o`00
00gooooo0_l000000ooooooo0000o`00000Dooooo`;o00006Oooool2o`0005Oooooo000Looooo`03
o`000?oooooooooo063ooooo0_l0000@ooooo`;o000000?oooooo`000?l000000_ooool2o`000004
ooooool0003o0000ooooo`;o00002oooool4o`0000cooooo0_l000000ooooooo0000o`000007oooo
o`;o00000_ooool4o`0000Wooooo0_l000001?oooooo0000o`000?ooool2o`0001?ooooo0_l0001c
ooooo`007?ooool00ol0003oooooooooo`1booooo`;o00001Oooool2o`000003ooooool0003o0000
00?o00002oooool2o`0000kooooo0_l000000ooooooo0000o`000007ooooo`;o00000_ooool4o`00
00;ooooo0_l00005ooooo`Go00005_ooool2o`0007?ooooo00001_ooooook^k^oc8b<_l0003o<S8b
onk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003ooooooooo
o`1iooooo`;o000000Coooooo`000?l0003o00005_ooool4o`0000cooooo0_l00007ooooo`;o0000
0_ooool2o`0000Kooooo0ol0000:ooooo`;o00001?ooool2o`0007[ooooo00001_ooooooMgMgoiRH
V?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0
003oooooooooo`1Vooooo`;o00004oooool4o`0000Cooooo0_l0000@ooooo`Co00003?ooool2o`00
00Oooooo0_l00007ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Oooooo0ol00003oooo
o`;o00002oooool2o`0006gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wo
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo06Kooooo0_l0000?oooo
o`;o00000_ooool4o`0000Cooooo0_l0000<ooooo`;o00004?ooool2o`0001;ooooo0_l00005oooo
o`;o00001oooool3o`0000Kooooo0_l00002ooooo`;o00001?ooool2o`0006gooooo00000ooooooo
0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06oooo
o`?o0000Moooool2o`0000Cooooo0_l0000<ooooo`;o00001?ooool3o`0000oooooo1Ol000000ooo
oooo0000o`00000Uooooo`;o00000_ooool2o`0007?ooooo00000ooooooo0000ooooo`02ooooo`03
o`000?oooooooooo00Wooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo
07;ooooo0_l00003ooooo`;o00003Oooool3o`0000;ooooo0_l00005ooooo`;o00001Oooool2o`00
00[ooooo0ol000001?oooooo0000o`000?l0000;ooooo`;o00007oooool2o`0006oooooo00000ooo
oooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go410@okZj^_oooooo^[Zjoa0@4006
ooooo`03o`000?oooooooooo07;ooooo0_l00002ooooo`;o00001oooool2o`0000Gooooo0ol00009
ooooo`Co00000oooool2o`000003ooooool0003o000000Cooooo0_l00006ooooo`;o00002oooool2
o`0001[ooooo0_l00003ooooo`;o0000Koooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2ooo
ool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0L_ooool2o`0000;ooooo
0_l00007ooooo`;o00001Oooool2o`0000Cooooo0_l00004ooooo`Co00001_ooool2o`0000Cooooo
0_l00004ooooo`;o00008oooool2o`0000Cooooo0_l00003ooooo`;o0000Koooool00006ooooooo^
k^ko<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000oooo
ooooool0Loooool2o`0000Oooooo0_l000000ooooooo0000o`00000;ooooo`;o00002Oooool2o`00
00Cooooo0_l00009ooooo`;o00004_ooool2o`0000Kooooo0_l00005ooooo`Co0000N_ooool001co
oooo00?o0000ooooooooool0Loooool2o`0000Oooooo0_l00007ooooo`;o00003oooool3o`0000Co
oooo0_l00003ooooo`;o00002?ooool2o`0000Sooooo0ol00003ooooo`;o00001_ooool2o`0000Go
oooo0_l0001looooo`007?ooool00ol0003oooooooooo`1gooooo`;o000000?oooooo`000?l00000
2Oooool2o`0000?ooooo0_l000000ooooooo0000o`000007ooooo`;o00002_ooool2o`0000Sooooo
0_l00002ooooo`;o00001?ooool3o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`0000Sooooo
1?l0001eooooo`007?ooool00ol0003oooooooooo`1gooooo`;o000000?oooooo`000?l000003_oo
ool2o`000003ooooool0003o000001?ooooo0_l0000<ooooo`;o00001Oooool2o`000004ooooool0
003o0000o`0000Gooooo0_l00002ooooo`;o00002?ooool4o`000003ooooool0003o000007;ooooo
000Looooo`03o`000?oooooooooo07[ooooo0_l0000Gooooo`Co00002Oooool3o`0000cooooo0_l0
0009ooooo`;o00003?ooool2o`0000_ooooo0_l0001booooo`007?ooool00ol0003oooooooooo`2C
ooooo`Co00001?ooool2o`0000?ooooo0ol0000<ooooo`;o00001?ooool2o`0000oooooo1?l00005
ooooo`;o0000N?ooool001cooooo00?o0000ooooooooool0NOooool2o`0000cooooo0_l00006oooo
o`;o000000?oooooo`000?l000001?l000000ooooooo0000o`000002o`0000?ooooo1?l0000?oooo
o`Co00003oooool4o`0000Gooooo0_l0001hooooo`007?ooool00ol0003oooooooooo`1iooooo`;o
00003?ooool2o`0000Kooooo0_l000000ooooooo0000o`000004o`000003ooooool0003o000000Go
oooo1?l0000?ooooo`;o0000U?ooool001cooooo00?o0000ooooooooool0O_ooool2o`0000;ooooo
0_l0000@ooooo`?o00002?ooool3o`00013ooooo0_l0000Gooooo`;o00000_ooool2o`0007Sooooo
000Looooo`03o`000?oooooooooo07kooooo0_l00002ooooo`;o00004?ooool5o`0000Kooooo0_l0
000>ooooo`;o000000?oooooo`000?l000005oooool2o`0000;ooooo0_l0001hooooo`007?ooool0
0ol0003oooooooooo`22ooooo`?o00004_ooool2o`0000?ooooo1?l0000=ooooo`Co0000V?ooool0
01cooooo00?o0000ooooooooool0Poooool2o`0000_ooooo0_l0000:ooooo`Co00001?ooool2o`00
00Oooooo0ol0002Iooooo`007?ooool2o`0008[ooooo1?l00003ooooo`;o00002_ooool2o`0000Ko
oooo0ol00007ooooo`?o0000V?ooool001cooooo00?o0000ooooooooool0ROooool4o`000003oooo
ool0003o000000;o00004oooool2o`0000Sooooo0_l0002Hooooo`007?ooool00ol0003ooooooooo
o`24ooooo`;o00002?ooool2o`000;Wooooo000Looooo`03o`000?oooooooooo08Cooooo0_l00033
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo09Co
oooo0_l0002cooooo`007?ooool00ol0003oooooooooo`2Dooooo`?o0000/_ooool001cooooo00?o
0000ooooooooool0UOooool2o`000;;ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0Qoooool2o`0003;ooooo0_l0002<ooooo`007?ooool00ol0003o
ooooooooo`27ooooo`;o0000;oooool2o`000003ooooool0003o000008cooooo000Looooo`03o`00
0?oooooooooo0;Sooooo0_l0002?ooooo`007?ooool00ol0003oooooooooo`2[ooooo`;o0000W?oo
ool001cooooo00?o0000ooooooooool0Zoooool2o`0009cooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?oooooo
Boooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001;ooooo1?l000000ol@413oooooooooo`03ooooo`03o`00
0?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo0ol0003ooooood[ooooo000Doooo
o`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`00
5?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_oo
ool001;ooooo00?oEEEEofIVI_l00000oooooomDooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00XOooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo01Kooooo
1?l000000ol@413oooooooooo`02ooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2o`000003oa0@4?oooooooooo08[ooooo002Rooooo`05o`000?oooooooooo
ooooool000002Oooool6o`0000cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`2;ooooo`00X_ooool0
1Ol0003ooooooooooooooooo000001_ooooo00?o0000ooooooooool00_ooool5o`0000?ooooo00Go
410@oooooooooooooooooa0@4003ooooo`Go0000S?ooool00:;ooooo00Go0000oooooooooooooooo
o`000009ooooo`Ko00003?ooool00ol0003oooooooooo`02ooooo`04odA4A?oMgMgoooooo`0000Co
oooo00Go0000ooooooooooooooooo`000003ooooo`04odA4A?oMgMgoooooo`0008gooooo002Roooo
o`05o`000?n7QhOoooooojVYZOl000006oooool00ol0003oooooooooo`02ooooo`04omgMgOmEEEGo
ooooo`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`04omgMgOmEEEGoooooo`0008go
oooo002Qooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool06Oooool00ol0003ooooo
ooooo`03ooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@4004ooooo`03
ogMgMoo<c<co000008gooooo0032ooooo`03o`000?oooooooooo00?ooooo00?ok^k^odA4A?l00000
1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?ok^k^odA4A?l00000SOooool00<3ooooo
00?oEEEEofIVI_l000001_ooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool00omgMgOo0000ooooo`2<ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1410) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.54568 .34602 Mdot
.5285 .36559 Mdot
.36453 .57224 Mdot
.65025 .51002 Mdot
.51395 .79745 Mdot
.37903 .6082 Mdot
.32783 .41432 Mdot
.36649 .4465 Mdot
.36596 .56449 Mdot
.43989 .34064 Mdot
.39424 .44091 Mdot
.64202 .44907 Mdot
.36945 .41617 Mdot
.6352 .54342 Mdot
.81118 .67374 Mdot
.56868 .54929 Mdot
.54422 .34672 Mdot
.53739 .65676 Mdot
.59649 .56732 Mdot
.3945 .61545 Mdot
.54253 .28542 Mdot
.63515 .53852 Mdot
.53329 .31406 Mdot
.63479 .54379 Mdot
.62979 .50175 Mdot
.52362 .31293 Mdot
.47069 .3413 Mdot
.60094 .49681 Mdot
.58359 .53105 Mdot
.38954 .44785 Mdot
.58073 .64871 Mdot
.71592 .75055 Mdot
.59947 .59191 Mdot
.72923 .66841 Mdot
.34488 .41528 Mdot
.69064 .39414 Mdot
.37102 .59856 Mdot
.38273 .43647 Mdot
.38791 .43142 Mdot
.35575 .44173 Mdot
.37146 .44145 Mdot
.52404 .33298 Mdot
.41695 .24596 Mdot
.34054 .50678 Mdot
.58793 .47847 Mdot
.36543 .77566 Mdot
.62183 .41055 Mdot
.65296 .55344 Mdot
.48746 .33588 Mdot
.36222 .67232 Mdot
.28923 .49096 Mdot
.34171 .39901 Mdot
.4067 .59448 Mdot
.29529 .19224 Mdot
.36868 .40469 Mdot
.67079 .47698 Mdot
.37164 .58579 Mdot
.61925 .53305 Mdot
.63004 .5456 Mdot
.67939 .29613 Mdot
.64804 .4769 Mdot
.51028 .67449 Mdot
.50215 .38268 Mdot
.45861 .5394 Mdot
.3809 .57958 Mdot
.39324 .43117 Mdot
.50947 .3658 Mdot
.3609 .40615 Mdot
.55528 .57234 Mdot
.36013 .54094 Mdot
.65945 .5506 Mdot
.39312 .43977 Mdot
.52929 .28666 Mdot
.59396 .51865 Mdot
.30874 .67019 Mdot
.32809 .76149 Mdot
.45636 .69395 Mdot
.68351 .37091 Mdot
.67282 .28841 Mdot
.3891 .70923 Mdot
.58632 .49179 Mdot
.58645 .70917 Mdot
.32905 .75426 Mdot
.48259 .32362 Mdot
.5948 .5758 Mdot
.51959 .62631 Mdot
.59657 .51384 Mdot
.44438 .82738 Mdot
.68235 .52003 Mdot
.51692 .58497 Mdot
.35013 .56533 Mdot
.50094 .32402 Mdot
.64723 .50501 Mdot
.59186 .53865 Mdot
.71916 .31413 Mdot
.64736 .56807 Mdot
.63438 .52337 Mdot
.48436 .34586 Mdot
.34601 .39739 Mdot
.67427 .48863 Mdot
.4067 .53275 Mdot
.34956 .61436 Mdot
.63755 .48036 Mdot
.3421 .56128 Mdot
.5171 .29058 Mdot
.59256 .53838 Mdot
.38621 .42269 Mdot
.65355 .49058 Mdot
.26775 .35178 Mdot
.54252 .34407 Mdot
.58598 .51056 Mdot
.46685 .69022 Mdot
.62051 .29278 Mdot
.4955 .32017 Mdot
.35313 .49563 Mdot
.5957 .56464 Mdot
.62243 .51941 Mdot
.50502 .36595 Mdot
.33714 .6062 Mdot
.41644 .81281 Mdot
.48364 .3543 Mdot
.40114 .44538 Mdot
.53051 .27963 Mdot
.67636 .46415 Mdot
.3882 .57956 Mdot
.3457 .50063 Mdot
.30526 .32037 Mdot
.614 .6572 Mdot
.59945 .51478 Mdot
.43 .25326 Mdot
.37006 .62384 Mdot
.50206 .33989 Mdot
.36103 .41008 Mdot
.63799 .58867 Mdot
.53268 .34461 Mdot
.40082 .4307 Mdot
.47784 .66517 Mdot
.25703 .44361 Mdot
.53833 .30178 Mdot
.50237 .43662 Mdot
.36143 .38948 Mdot
.3357 .41749 Mdot
.82191 .51239 Mdot
.50268 .35819 Mdot
.49246 .696 Mdot
.35578 .41532 Mdot
.65815 .63872 Mdot
.5965 .4726 Mdot
.5689 .69955 Mdot
.3634 .21764 Mdot
.73059 .64969 Mdot
.25046 .51052 Mdot
.47465 .69087 Mdot
.36747 .38492 Mdot
.63894 .51371 Mdot
.51722 .30721 Mdot
.52902 .31406 Mdot
.64727 .47692 Mdot
.62901 .49211 Mdot
.66685 .54648 Mdot
.63214 .5637 Mdot
.57969 .60766 Mdot
.67011 .56315 Mdot
.62008 .39839 Mdot
.5039 .31827 Mdot
.64779 .51417 Mdot
.40232 .58284 Mdot
.57519 .46988 Mdot
.38237 .44423 Mdot
.62713 .53332 Mdot
.64798 .508 Mdot
.61867 .46789 Mdot
.33743 .40446 Mdot
.67928 .77693 Mdot
.59753 .30056 Mdot
.65733 .77339 Mdot
.51083 .515 Mdot
.38626 .55578 Mdot
.6036 .50648 Mdot
.50404 .68081 Mdot
.74509 .4132 Mdot
.66205 .51584 Mdot
.11207 .50793 Mdot
.63818 .53035 Mdot
.56592 .8085 Mdot
.54895 .49197 Mdot
.68808 .73478 Mdot
.59533 .69129 Mdot
.62518 .50582 Mdot
.44703 .28478 Mdot
.32061 .40679 Mdot
.41102 .55421 Mdot
.36864 .43651 Mdot
.40287 .58842 Mdot
.36772 .57666 Mdot
.444 .55716 Mdot
.63952 .44562 Mdot
.56127 .49515 Mdot
.67633 .54139 Mdot
.33284 .55878 Mdot
.481 .36793 Mdot
.46472 .68286 Mdot
.52803 .373 Mdot
.60363 .84265 Mdot
.29087 .64815 Mdot
.36666 .45481 Mdot
.48335 .65661 Mdot
.34019 .58686 Mdot
.35517 .56011 Mdot
.46914 .68387 Mdot
.60606 .54827 Mdot
.50646 .35794 Mdot
.79485 .57792 Mdot
.23688 .39338 Mdot
.82862 .35259 Mdot
.4842 .33875 Mdot
.43072 .27896 Mdot
.37357 .44868 Mdot
.35947 .59555 Mdot
.6257 .52006 Mdot
.60231 .53705 Mdot
.55224 .29331 Mdot
.65834 .5527 Mdot
.57116 .29686 Mdot
.62348 .51221 Mdot
.33251 .3712 Mdot
.46399 .70731 Mdot
.44468 .55869 Mdot
.65179 .66315 Mdot
.50093 .30296 Mdot
.78756 .3967 Mdot
.3608 .55402 Mdot
.74223 .40364 Mdot
.39545 .42401 Mdot
.49368 .66207 Mdot
.38218 .56213 Mdot
.4661 .69378 Mdot
.65085 .57309 Mdot
.3947 .60973 Mdot
.481 .70615 Mdot
.53751 .61709 Mdot
.57553 .48207 Mdot
.22413 .35609 Mdot
.3537 .43792 Mdot
.54154 .35928 Mdot
.66383 .49778 Mdot
.35788 .54952 Mdot
.65176 .58904 Mdot
.24705 .58262 Mdot
.28296 .42038 Mdot
.37052 .62517 Mdot
.45854 .60373 Mdot
.50657 .66579 Mdot
.28401 .53009 Mdot
.42655 .26184 Mdot
.53079 .36607 Mdot
.65643 .56638 Mdot
.72835 .7211 Mdot
.35594 .41454 Mdot
.66281 .50149 Mdot
.50671 .76357 Mdot
.3485 .40561 Mdot
.61722 .53182 Mdot
.40354 .42114 Mdot
.52953 .31467 Mdot
.63692 .25739 Mdot
.50128 .36528 Mdot
.65521 .55769 Mdot
.38157 .41418 Mdot
.32826 .59442 Mdot
.52027 .31892 Mdot
.6173 .55489 Mdot
.60255 .49824 Mdot
.47984 .58448 Mdot
.64757 .52206 Mdot
.64087 .79273 Mdot
.62403 .5087 Mdot
.35706 .58246 Mdot
.59706 .48151 Mdot
.54427 .21287 Mdot
.43895 .55195 Mdot
.50695 .36324 Mdot
.37042 .6272 Mdot
.37343 .57155 Mdot
.3191 .70361 Mdot
.39894 .39457 Mdot
.58133 .54436 Mdot
.36765 .548 Mdot
.71858 .5982 Mdot
.38313 .39911 Mdot
.66413 .48918 Mdot
.4732 .42361 Mdot
.35316 .66414 Mdot
.40532 .60172 Mdot
.71209 .54053 Mdot
.52957 .29288 Mdot
.64275 .49944 Mdot
.34531 .56479 Mdot
.67989 .45833 Mdot
.57887 .51806 Mdot
.4289 .20897 Mdot
.47627 .59677 Mdot
.35746 .39175 Mdot
.58496 .45971 Mdot
.67204 .52757 Mdot
.39353 .60706 Mdot
.50532 .30202 Mdot
.37851 .39545 Mdot
.52323 .32723 Mdot
.69307 .7234 Mdot
.23125 .35592 Mdot
.54171 .60468 Mdot
.46919 .70751 Mdot
.43391 .64196 Mdot
.70012 .72442 Mdot
.73195 .29324 Mdot
.79222 .47294 Mdot
.75803 .65087 Mdot
.33586 .57327 Mdot
.42402 .66358 Mdot
.37375 .57803 Mdot
.61405 .4878 Mdot
.38748 .58274 Mdot
.74064 .71271 Mdot
.62618 .51453 Mdot
.38507 .59331 Mdot
.7648 .36224 Mdot
.64209 .50323 Mdot
.52587 .36938 Mdot
.59501 .83138 Mdot
.59353 .19731 Mdot
.29207 .40516 Mdot
.35309 .60349 Mdot
.78401 .53458 Mdot
.6364 .52302 Mdot
.5974 .48198 Mdot
.50801 .3087 Mdot
.62729 .59415 Mdot
.51156 .68859 Mdot
.48967 .65574 Mdot
.342 .45865 Mdot
.45902 .71009 Mdot
.58948 .45815 Mdot
.51817 .31747 Mdot
.56544 .59689 Mdot
.32893 .69597 Mdot
.37336 .67003 Mdot
.35453 .45502 Mdot
.59458 .83053 Mdot
.53072 .39914 Mdot
.39875 .36403 Mdot
.30742 .62157 Mdot
.49221 .33845 Mdot
.70604 .76231 Mdot
.37253 .43603 Mdot
.20169 .38905 Mdot
.45713 .28462 Mdot
.60674 .546 Mdot
.38215 .4033 Mdot
.69418 .55933 Mdot
.61094 .20591 Mdot
.18152 .46379 Mdot
.68727 .44374 Mdot
.67985 .51223 Mdot
.31071 .65778 Mdot
.62679 .528 Mdot
.27505 .62492 Mdot
.61869 .50353 Mdot
.51952 .33002 Mdot
.43867 .33924 Mdot
.33686 .47706 Mdot
.57635 .28228 Mdot
.28128 .54946 Mdot
.47607 .69523 Mdot
.62075 .51335 Mdot
.60931 .54782 Mdot
.51046 .69675 Mdot
.53528 .30865 Mdot
.66153 .55293 Mdot
.78581 .38328 Mdot
.59653 .54675 Mdot
.3799 .4423 Mdot
.50388 .24094 Mdot
.57401 .40392 Mdot
.6127 .56487 Mdot
.49098 .3026 Mdot
.35033 .44672 Mdot
.38096 .41657 Mdot
.56003 .47222 Mdot
.38282 .45334 Mdot
.64654 .53344 Mdot
.17985 .49417 Mdot
.54322 .31199 Mdot
.35776 .23992 Mdot
.52277 .35169 Mdot
.66977 .35723 Mdot
.34399 .40247 Mdot
.27015 .43435 Mdot
.70072 .53956 Mdot
.37318 .43186 Mdot
.50554 .27209 Mdot
.5657 .5137 Mdot
.56419 .50644 Mdot
.7911 .56636 Mdot
.34932 .58155 Mdot
.47489 .58458 Mdot
.39001 .44804 Mdot
.64038 .55298 Mdot
.61785 .57129 Mdot
.35191 .44664 Mdot
.20218 .45427 Mdot
.64639 .23522 Mdot
.62454 .51101 Mdot
.51175 .33308 Mdot
.50473 .34278 Mdot
.60709 .46289 Mdot
.63644 .48277 Mdot
.39223 .57438 Mdot
.3339 .60747 Mdot
.39581 .5607 Mdot
.47144 .58902 Mdot
.27595 .42075 Mdot
.45934 .80646 Mdot
.35508 .44107 Mdot
.40503 .29817 Mdot
.52398 .59873 Mdot
.68359 .53232 Mdot
.35174 .60657 Mdot
.67039 .52861 Mdot
.65634 .52704 Mdot
.41322 .40617 Mdot
.52989 .78607 Mdot
.4901 .39547 Mdot
.50736 .29695 Mdot
.35328 .38701 Mdot
.57714 .45962 Mdot
.42615 .38642 Mdot
.49524 .6656 Mdot
.73785 .62441 Mdot
.39576 .43116 Mdot
.51781 .37174 Mdot
.34986 .42935 Mdot
.59821 .53675 Mdot
.69553 .52856 Mdot
.49426 .34191 Mdot
.5168 .68025 Mdot
.61185 .59142 Mdot
.61719 .52854 Mdot
.32977 .22892 Mdot
.70027 .63739 Mdot
.33159 .3649 Mdot
.62648 .50815 Mdot
.59077 .54899 Mdot
.52633 .67873 Mdot
.59664 .54533 Mdot
.67764 .52751 Mdot
.62552 .30307 Mdot
.32641 .3235 Mdot
.47074 .65937 Mdot
.18727 .48846 Mdot
.48485 .34121 Mdot
.7161 .73603 Mdot
.3641 .60985 Mdot
.34086 .46884 Mdot
.61074 .22551 Mdot
.40757 .58826 Mdot
.24762 .51853 Mdot
.70628 .7464 Mdot
.40108 .52486 Mdot
.41902 .61589 Mdot
.47537 .37653 Mdot
.64544 .56014 Mdot
.62021 .52162 Mdot
.5063 .68358 Mdot
.50992 .3551 Mdot
.48582 .52323 Mdot
.24337 .68494 Mdot
.63507 .53617 Mdot
.41476 .21655 Mdot
.20444 .54979 Mdot
.34666 .66674 Mdot
.49292 .67902 Mdot
.49654 .65481 Mdot
.61886 .51419 Mdot
.60428 .28714 Mdot
.52267 .31276 Mdot
.61895 .5548 Mdot
.67297 .56 Mdot
.34998 .59271 Mdot
.54321 .33697 Mdot
.33845 .6079 Mdot
.27685 .48849 Mdot
.63721 .78461 Mdot
.18968 .36843 Mdot
.36053 .39957 Mdot
.26231 .64515 Mdot
.39494 .40703 Mdot
.59232 .70872 Mdot
.41153 .60692 Mdot
.64354 .49403 Mdot
.51181 .29937 Mdot
.64704 .55013 Mdot
.63752 .48496 Mdot
.60805 .54902 Mdot
.62048 .56754 Mdot
.20858 .32502 Mdot
.47343 .69505 Mdot
.62964 .58221 Mdot
.35899 .57759 Mdot
.34305 .75915 Mdot
.29749 .7195 Mdot
.61301 .54756 Mdot
.61086 .502 Mdot
.53995 .32633 Mdot
.65404 .48427 Mdot
.38873 .40038 Mdot
.51198 .37777 Mdot
.59028 .52394 Mdot
.53415 .83822 Mdot
.58191 .52756 Mdot
.68269 .74886 Mdot
.3517 .43025 Mdot
.24245 .37558 Mdot
.69417 .54183 Mdot
.28769 .42136 Mdot
.47509 .5847 Mdot
.38688 .56518 Mdot
.40352 .41253 Mdot
.37361 .59808 Mdot
.22311 .65627 Mdot
.69043 .48358 Mdot
.63713 .51046 Mdot
.68058 .53908 Mdot
.38607 .55545 Mdot
.47521 .83724 Mdot
.29474 .54321 Mdot
.69862 .49136 Mdot
.39829 .5801 Mdot
.4747 .33977 Mdot
.75903 .5954 Mdot
.52507 .34052 Mdot
.49804 .71814 Mdot
.37311 .44679 Mdot
.51547 .67994 Mdot
.61123 .75012 Mdot
.53947 .35123 Mdot
.55837 .32232 Mdot
.36439 .6079 Mdot
.44656 .33926 Mdot
.57269 .1455 Mdot
.45752 .2825 Mdot
.61611 .67702 Mdot
.51299 .31291 Mdot
.58629 .53497 Mdot
.59315 .734 Mdot
.44802 .30769 Mdot
.37571 .59566 Mdot
.6633 .52734 Mdot
.63633 .25307 Mdot
.39203 .5737 Mdot
.68884 .5219 Mdot
.35514 .57561 Mdot
.36401 .43603 Mdot
.34636 .59982 Mdot
.56152 .29985 Mdot
.59352 .50879 Mdot
.60293 .1442 Mdot
.44206 .64849 Mdot
.63663 .51939 Mdot
.34232 .38986 Mdot
.22513 .47741 Mdot
.65605 .50174 Mdot
.47741 .70864 Mdot
.39074 .59548 Mdot
.45187 .34248 Mdot
.62212 .50804 Mdot
.39918 .58141 Mdot
.5515 .33529 Mdot
.35488 .38165 Mdot
.7116 .3089 Mdot
.30498 .3919 Mdot
.50543 .30849 Mdot
.52479 .45592 Mdot
.41074 .42443 Mdot
.5921 .55075 Mdot
.64755 .56874 Mdot
.51037 .33735 Mdot
.54216 .70485 Mdot
.61843 .47491 Mdot
.5919 .48722 Mdot
.35356 .59166 Mdot
.37694 .60066 Mdot
.78285 .46982 Mdot
.33233 .59529 Mdot
.69322 .53542 Mdot
.51224 .33816 Mdot
.64933 .5065 Mdot
.5424 .32595 Mdot
.65389 .48467 Mdot
.55363 .46441 Mdot
.53457 .30784 Mdot
.39959 .38811 Mdot
.66068 .52615 Mdot
.57786 .57967 Mdot
.65633 .49381 Mdot
.6374 .5613 Mdot
.38882 .57347 Mdot
.49915 .67638 Mdot
.68091 .54642 Mdot
.46748 .6455 Mdot
.46642 .67898 Mdot
.30892 .44546 Mdot
.34907 .58958 Mdot
.49057 .70085 Mdot
.20086 .57345 Mdot
.40143 .59965 Mdot
.50762 .68854 Mdot
.29912 .72152 Mdot
.34345 .41351 Mdot
.53034 .29181 Mdot
.63962 .50064 Mdot
.67305 .72187 Mdot
.60776 .40557 Mdot
.38411 .63288 Mdot
.62741 .51154 Mdot
.66429 .50575 Mdot
.48038 .35135 Mdot
.25251 .71777 Mdot
.36172 .54098 Mdot
.57877 .53083 Mdot
.52774 .36377 Mdot
.25984 .74673 Mdot
.36271 .58123 Mdot
.50881 .68398 Mdot
.34097 .41877 Mdot
.46743 .35357 Mdot
.3013 .3207 Mdot
.33161 .4016 Mdot
.32814 .54319 Mdot
.28283 .48405 Mdot
.6117 .57476 Mdot
.35668 .61378 Mdot
.83552 .41975 Mdot
.61139 .61112 Mdot
.46395 .55519 Mdot
.78011 .54538 Mdot
.49327 .32975 Mdot
.39302 .40502 Mdot
.47343 .69026 Mdot
.48523 .32916 Mdot
.54588 .34314 Mdot
.35335 .44526 Mdot
.60606 .31601 Mdot
.46872 .42076 Mdot
.38651 .43701 Mdot
.70233 .66816 Mdot
.45645 .78129 Mdot
.35458 .61019 Mdot
.51112 .68996 Mdot
.58864 .76413 Mdot
.52499 .32983 Mdot
.6349 .82423 Mdot
.79706 .56198 Mdot
.6346 .52359 Mdot
.48412 .69608 Mdot
.47758 .82795 Mdot
.28415 .73883 Mdot
.34874 .40305 Mdot
.32457 .46094 Mdot
.5126 .67184 Mdot
.66555 .50106 Mdot
.72771 .61288 Mdot
.60602 .48299 Mdot
.36787 .44501 Mdot
.74113 .34541 Mdot
.54116 .35039 Mdot
.34207 .43117 Mdot
.74687 .61822 Mdot
.64542 .53485 Mdot
.66173 .52373 Mdot
.66752 .67547 Mdot
.48584 .32196 Mdot
.38662 .56452 Mdot
.63905 .57481 Mdot
.62111 .53013 Mdot
.69296 .51945 Mdot
.61781 .45762 Mdot
.62583 .27798 Mdot
.61433 .49175 Mdot
.29268 .66778 Mdot
.67657 .50761 Mdot
.65426 .53816 Mdot
.49715 .29691 Mdot
.17016 .39305 Mdot
.29018 .50377 Mdot
.62523 .53169 Mdot
.58587 .54353 Mdot
.34249 .42978 Mdot
.4435 .4099 Mdot
.44435 .37076 Mdot
.45355 .34757 Mdot
.78982 .5039 Mdot
.57422 .48133 Mdot
.51318 .36446 Mdot
.48448 .70863 Mdot
.58355 .5461 Mdot
.51812 .36663 Mdot
.60873 .46956 Mdot
.39239 .57178 Mdot
.40235 .5965 Mdot
.56632 .5935 Mdot
.48922 .70264 Mdot
.49513 .22347 Mdot
.40165 .29764 Mdot
.39689 .60477 Mdot
.6352 .50728 Mdot
.3226 .38439 Mdot
.34875 .56241 Mdot
.42099 .54545 Mdot
.52691 .7392 Mdot
.51793 .30485 Mdot
.50158 .3195 Mdot
.5655 .70284 Mdot
.25656 .49388 Mdot
.43016 .19621 Mdot
.36425 .4376 Mdot
.64571 .57928 Mdot
.44509 .2678 Mdot
.49977 .31726 Mdot
.59826 .71979 Mdot
.48446 .69856 Mdot
.34811 .40708 Mdot
.30312 .56941 Mdot
.53532 .33742 Mdot
.55133 .31758 Mdot
.64996 .47527 Mdot
.61073 .53352 Mdot
.79319 .46076 Mdot
.47394 .64296 Mdot
.32757 .41096 Mdot
.51116 .68619 Mdot
.4095 .60989 Mdot
.59799 .49256 Mdot
.53293 .3094 Mdot
.444 .78826 Mdot
.59099 .55807 Mdot
.37328 .56337 Mdot
.49598 .32738 Mdot
.50613 .66445 Mdot
.48278 .71131 Mdot
.62582 .56322 Mdot
.77564 .42151 Mdot
.38051 .43333 Mdot
.49318 .34998 Mdot
.42228 .3753 Mdot
.61216 .47972 Mdot
.60867 .52571 Mdot
.54595 .52864 Mdot
.32763 .40959 Mdot
.36769 .34156 Mdot
.46727 .70158 Mdot
.50518 .35271 Mdot
.6132 .4949 Mdot
.50613 .69644 Mdot
.41551 .29752 Mdot
.38622 .62554 Mdot
.34393 .59593 Mdot
.48903 .71168 Mdot
.48574 .6837 Mdot
.47001 .70225 Mdot
.6374 .82377 Mdot
.48882 .36709 Mdot
.53232 .40099 Mdot
.56997 .51088 Mdot
.60143 .6848 Mdot
.62964 .58397 Mdot
.36824 .39115 Mdot
.35021 .57719 Mdot
.64934 .49295 Mdot
.60943 .56228 Mdot
.54689 .49259 Mdot
.38406 .22367 Mdot
.56047 .41206 Mdot
.5451 .33764 Mdot
.69615 .53067 Mdot
.35478 .60331 Mdot
.62529 .84339 Mdot
.81296 .56564 Mdot
.69533 .53862 Mdot
.47062 .41683 Mdot
.52935 .303 Mdot
.35412 .44133 Mdot
.65471 .70533 Mdot
.34336 .41713 Mdot
.50231 .34895 Mdot
.60978 .49026 Mdot
.39502 .31527 Mdot
.52785 .67633 Mdot
.64109 .55553 Mdot
.36152 .44008 Mdot
.65904 .54998 Mdot
.32861 .40815 Mdot
.66552 .73579 Mdot
.82095 .41997 Mdot
.63731 .52945 Mdot
.58772 .56685 Mdot
.80325 .44859 Mdot
.61888 .54998 Mdot
.53343 .66642 Mdot
.529 .30239 Mdot
.74687 .3464 Mdot
.56134 .52483 Mdot
.74033 .55376 Mdot
.60528 .48091 Mdot
.72106 .3085 Mdot
.6063 .52801 Mdot
.33909 .66696 Mdot
.58868 .50848 Mdot
.678 .53241 Mdot
.37218 .4046 Mdot
.34055 .42863 Mdot
.51839 .28556 Mdot
.34921 .55434 Mdot
.67342 .75996 Mdot
.61412 .52675 Mdot
.27943 .44005 Mdot
.33289 .33474 Mdot
.48774 .68156 Mdot
.50654 .35018 Mdot
.29971 .77528 Mdot
.39715 .44571 Mdot
.81321 .51016 Mdot
.77886 .49411 Mdot
.34346 .29074 Mdot
.53909 .77048 Mdot
.21695 .50921 Mdot
.5008 .66341 Mdot
.62044 .46849 Mdot
.44915 .74639 Mdot
.33213 .66679 Mdot
.5291 .72692 Mdot
.40658 .41428 Mdot
.76056 .42907 Mdot
.50348 .77793 Mdot
.49974 .71397 Mdot
.50673 .66036 Mdot
.33778 .40019 Mdot
.42329 .61941 Mdot
.64791 .44892 Mdot
.47974 .69113 Mdot
.3882 .55534 Mdot
.39967 .60812 Mdot
.38736 .55138 Mdot
.52549 .31172 Mdot
.80968 .55279 Mdot
.40622 .44929 Mdot
.36239 .39217 Mdot
.42408 .63331 Mdot
.73204 .495 Mdot
.54166 .36735 Mdot
.36389 .60028 Mdot
.33737 .59629 Mdot
.52985 .29998 Mdot
.65931 .47137 Mdot
.66051 .46357 Mdot
.63072 .53416 Mdot
.5022 .68003 Mdot
.60558 .53378 Mdot
.39742 .58314 Mdot
.35572 .40172 Mdot
.33789 .58988 Mdot
.33812 .39002 Mdot
.42947 .79537 Mdot
.61621 .55776 Mdot
.59311 .50646 Mdot
.28426 .26927 Mdot
.54666 .29812 Mdot
.36393 .76911 Mdot
.37721 .371 Mdot
.37152 .57775 Mdot
.67716 .52605 Mdot
.51888 .37902 Mdot
.4955 .64492 Mdot
.19297 .37328 Mdot
.63153 .47901 Mdot
.5325 .32539 Mdot
.60036 .493 Mdot
.62157 .61842 Mdot
.49261 .19069 Mdot
.51914 .3372 Mdot
.39859 .20801 Mdot
.58316 .53503 Mdot
.2187 .59047 Mdot
.6708 .498 Mdot
.56441 .62258 Mdot
.61843 .47498 Mdot
.48457 .34196 Mdot
.62721 .53588 Mdot
.51818 .37791 Mdot
.38509 .61398 Mdot
.34736 .43337 Mdot
.5051 .31067 Mdot
.63625 .56883 Mdot
.52506 .07246 Mdot
.35792 .42841 Mdot
.62324 .51696 Mdot
.33886 .40551 Mdot
.5137 .35643 Mdot
.48826 .3312 Mdot
.27661 .7173 Mdot
.27598 .49166 Mdot
.36396 .43423 Mdot
.59854 .49276 Mdot
.24143 .60512 Mdot
.63328 .49103 Mdot
.72228 .59923 Mdot
.67312 .47894 Mdot
.58744 .48653 Mdot
.30834 .73809 Mdot
.35612 .39138 Mdot
.42934 .1944 Mdot
.3002 .74286 Mdot
.34003 .75712 Mdot
.54442 .28559 Mdot
.5028 .71135 Mdot
.69677 .76767 Mdot
.27676 .41816 Mdot
.39685 .57341 Mdot
.65416 .49616 Mdot
.54128 .26381 Mdot
.38357 .43001 Mdot
.49478 .66815 Mdot
.63624 .52861 Mdot
.34212 .60144 Mdot
.69866 .26878 Mdot
.36412 .38492 Mdot
.52207 .33819 Mdot
.4767 .33847 Mdot
.16571 .55421 Mdot
.62222 .5031 Mdot
.59128 .51303 Mdot
.37244 .44699 Mdot
.2132 .475 Mdot
.47376 .6634 Mdot
.76244 .35675 Mdot
.36371 .43195 Mdot
.47108 .49011 Mdot
.51515 .36905 Mdot
.6677 .5107 Mdot
.5427 .82444 Mdot
.29558 .58479 Mdot
.3117 .25407 Mdot
.50363 .68208 Mdot
.71757 .60275 Mdot
.48518 .34359 Mdot
.35918 .41219 Mdot
.24648 .46646 Mdot
.56629 .49082 Mdot
.66701 .53391 Mdot
.66076 .62506 Mdot
.32401 .46586 Mdot
.46901 .384 Mdot
.62593 .47918 Mdot
.4723 .58173 Mdot
.64054 .48084 Mdot
.56396 .54952 Mdot
.68977 .49233 Mdot
.60342 .51763 Mdot
.53391 .31525 Mdot
.72067 .55946 Mdot
.37828 .55421 Mdot
.52148 .39313 Mdot
.46586 .4987 Mdot
.63155 .51643 Mdot
.58758 .49395 Mdot
.65752 .42692 Mdot
.2383 .53549 Mdot
.50592 .31267 Mdot
.5599 .31389 Mdot
.39249 .45065 Mdot
.65569 .46466 Mdot
.3471 .55687 Mdot
.61993 .58853 Mdot
.38452 .57063 Mdot
.5328 .31199 Mdot
.36831 .57925 Mdot
.33825 .41749 Mdot
.36283 .61657 Mdot
.27463 .42385 Mdot
.35271 .41833 Mdot
.51312 .30489 Mdot
.59337 .52346 Mdot
.34304 .38909 Mdot
.633 .65437 Mdot
.50217 .68226 Mdot
.38551 .82711 Mdot
.58968 .52383 Mdot
.31423 .3242 Mdot
.63408 .43776 Mdot
.33724 .59285 Mdot
.47852 .18826 Mdot
.51324 .29569 Mdot
.48017 .65304 Mdot
.49025 .31194 Mdot
.73956 .61516 Mdot
.49199 .68795 Mdot
.36471 .8004 Mdot
.49049 .6046 Mdot
.70233 .63324 Mdot
.64064 .46134 Mdot
.67327 .66067 Mdot
.40574 .60743 Mdot
.38318 .4271 Mdot
.24693 .48538 Mdot
.67638 .53194 Mdot
.76114 .31079 Mdot
.48952 .30767 Mdot
.35547 .55175 Mdot
.3624 .40834 Mdot
.37558 .39346 Mdot
.57269 .52693 Mdot
.39224 .68803 Mdot
.66828 .53585 Mdot
.2611 .47857 Mdot
.7818 .53074 Mdot
.55319 .38609 Mdot
.62356 .51268 Mdot
.39244 .60832 Mdot
.60062 .49287 Mdot
.46581 .70154 Mdot
.82977 .49449 Mdot
.59307 .58609 Mdot
.35815 .36243 Mdot
.49074 .63941 Mdot
.49916 .35935 Mdot
.58009 .44157 Mdot
.32226 .37151 Mdot
.62141 .50039 Mdot
.1799 .33087 Mdot
.50698 .69222 Mdot
.4475 .74178 Mdot
.60408 .5647 Mdot
.58302 .54828 Mdot
.44163 .52652 Mdot
.30235 .31197 Mdot
.29771 .63241 Mdot
.62936 .54883 Mdot
.61412 .63964 Mdot
.34568 .39397 Mdot
.65884 .49292 Mdot
.62019 .51957 Mdot
.61436 .3625 Mdot
.36607 .38791 Mdot
.36736 .56898 Mdot
.40837 .58875 Mdot
.37611 .63277 Mdot
.46118 .68887 Mdot
.43269 .36863 Mdot
.61164 .70078 Mdot
.63884 .22149 Mdot
.50361 .65396 Mdot
.60643 .55978 Mdot
.4386 .66447 Mdot
.60659 .48745 Mdot
.48992 .67044 Mdot
.36547 .38718 Mdot
.50012 .3134 Mdot
.43892 .28062 Mdot
.40563 .58832 Mdot
.56414 .49072 Mdot
.46956 .66577 Mdot
.51789 .30699 Mdot
.62167 .734 Mdot
.50046 .35887 Mdot
.37007 .42879 Mdot
.43027 .36506 Mdot
.49121 .66754 Mdot
.51868 .35693 Mdot
.39097 .36513 Mdot
.269 .72135 Mdot
.69097 .48847 Mdot
.41965 .33649 Mdot
.4946 .36028 Mdot
.56059 .32667 Mdot
.49712 .36784 Mdot
.6533 .5548 Mdot
.47198 .41811 Mdot
.58971 .47926 Mdot
.35271 .39148 Mdot
.35757 .57267 Mdot
.80081 .39312 Mdot
.32354 .50957 Mdot
.52313 .43019 Mdot
.66929 .56829 Mdot
.64533 .53614 Mdot
.61914 .51456 Mdot
.56344 .543 Mdot
.27173 .4112 Mdot
.65637 .54583 Mdot
.37333 .40496 Mdot
.39348 .591 Mdot
.61794 .46822 Mdot
.31804 .58513 Mdot
.3257 .7376 Mdot
.51798 .6771 Mdot
.33056 .44271 Mdot
.8342 .53537 Mdot
.5154 .30809 Mdot
.36719 .62619 Mdot
.39831 .59372 Mdot
.4822 .66296 Mdot
.38116 .43827 Mdot
.50255 .36032 Mdot
.71371 .6019 Mdot
.46632 .68049 Mdot
.62461 .53378 Mdot
.47194 .4059 Mdot
.78896 .34371 Mdot
.62775 .47018 Mdot
.65357 .50419 Mdot
.38813 .55018 Mdot
.45318 .73867 Mdot
.69856 .20915 Mdot
.63105 .70113 Mdot
.49743 .67189 Mdot
.51307 .70105 Mdot
.53565 .30103 Mdot
.56377 .51824 Mdot
.33652 .397 Mdot
.47367 .26975 Mdot
.36905 .35019 Mdot
.45964 .22665 Mdot
.28808 .28462 Mdot
.64346 .48485 Mdot
.2006 .47506 Mdot
.64929 .53292 Mdot
.48793 .3659 Mdot
.53094 .31696 Mdot
.51455 .32315 Mdot
.38245 .4274 Mdot
.70669 .39608 Mdot
.38252 .41397 Mdot
.85709 .46855 Mdot
.48767 .34233 Mdot
.4852 .6061 Mdot
.35822 .60103 Mdot
.69611 .48702 Mdot
.51026 .66957 Mdot
.42355 .34763 Mdot
.55393 .57099 Mdot
.58657 .27406 Mdot
.36449 .54892 Mdot
.50952 .30516 Mdot
.2152 .48632 Mdot
.7752 .64927 Mdot
.44833 .3618 Mdot
.54116 .50946 Mdot
.65473 .70694 Mdot
.48887 .67771 Mdot
.30883 .25657 Mdot
.51272 .67849 Mdot
.3605 .43925 Mdot
.59831 .50271 Mdot
.59722 .5136 Mdot
.64104 .48039 Mdot
.61362 .55339 Mdot
.41219 .43262 Mdot
.665 .56241 Mdot
.54458 .21312 Mdot
.4045 .58379 Mdot
.54191 .62956 Mdot
.51097 .68045 Mdot
.39286 .39674 Mdot
.39441 .59008 Mdot
.23995 .52785 Mdot
.64658 .66472 Mdot
.62291 .50956 Mdot
.65063 .4935 Mdot
.81553 .48219 Mdot
.62489 .4795 Mdot
.69187 .47334 Mdot
.39821 .5773 Mdot
.56648 .42624 Mdot
.51714 .67648 Mdot
.51932 .69309 Mdot
.35067 .41711 Mdot
.53302 .31651 Mdot
.50123 .6953 Mdot
.35555 .5975 Mdot
.67135 .56652 Mdot
.65425 .56838 Mdot
.4929 .35791 Mdot
.8229 .4824 Mdot
.47174 .70936 Mdot
.235 .59795 Mdot
.51622 .30039 Mdot
.50589 .28491 Mdot
.66773 .53255 Mdot
.33693 .2405 Mdot
.55147 .28374 Mdot
.46795 .65757 Mdot
.39684 .40058 Mdot
.6682 .69118 Mdot
.39949 .43456 Mdot
.52325 .33947 Mdot
.57798 .52218 Mdot
.52705 .30749 Mdot
.62448 .50687 Mdot
.79323 .65238 Mdot
.5997 .51829 Mdot
.62243 .21402 Mdot
.56218 .69036 Mdot
.37709 .61032 Mdot
.23194 .52849 Mdot
.36429 .60953 Mdot
.50247 .30372 Mdot
.59307 .56181 Mdot
.48978 .65738 Mdot
.28907 .69267 Mdot
.50997 .25601 Mdot
.35097 .56384 Mdot
.34062 .5547 Mdot
.40232 .42985 Mdot
.61947 .4737 Mdot
.66405 .53825 Mdot
.38333 .59556 Mdot
.57258 .32096 Mdot
.53083 .34469 Mdot
.60816 .49947 Mdot
.64715 .53888 Mdot
.37279 .61042 Mdot
.25551 .70734 Mdot
.69878 .58256 Mdot
.60246 .50601 Mdot
.28888 .61127 Mdot
.36923 .3921 Mdot
.69221 .48365 Mdot
.59488 .57093 Mdot
.48325 .68495 Mdot
.6577 .28745 Mdot
.77494 .601 Mdot
.36621 .38664 Mdot
.40111 .58919 Mdot
.61807 .49901 Mdot
.39458 .60606 Mdot
.6613 .56534 Mdot
.31109 .3038 Mdot
.37461 .62502 Mdot
.58671 .49094 Mdot
.64941 .46786 Mdot
.48427 .32532 Mdot
.64681 .48858 Mdot
.70655 .44357 Mdot
.36944 .55773 Mdot
.57388 .52772 Mdot
.76964 .3957 Mdot
.39046 .4363 Mdot
.62565 .45691 Mdot
.46822 .68733 Mdot
.73247 .58947 Mdot
.38193 .30392 Mdot
.54843 .7867 Mdot
.52188 .69009 Mdot
.6578 .54987 Mdot
.34604 .55198 Mdot
.32849 .41444 Mdot
.59289 .19939 Mdot
.66785 .50543 Mdot
.36511 .44266 Mdot
.35486 .40239 Mdot
.4972 .66693 Mdot
.15926 .41369 Mdot
.60968 .56524 Mdot
.61111 .54572 Mdot
.66256 .39373 Mdot
.5534 .31891 Mdot
.60064 .52802 Mdot
.59136 .54152 Mdot
.36953 .40164 Mdot
.61223 .44923 Mdot
.75874 .46687 Mdot
.74315 .33008 Mdot
.34727 .44577 Mdot
.46657 .24779 Mdot
.3861 .62184 Mdot
.50529 .70121 Mdot
.49598 .33816 Mdot
.47426 .66117 Mdot
.34843 .59695 Mdot
.59082 .53745 Mdot
.36458 .44753 Mdot
.6753 .42551 Mdot
.33683 .40122 Mdot
.50828 .76756 Mdot
.52479 .37239 Mdot
.38353 .47429 Mdot
.16653 .35884 Mdot
.26963 .57166 Mdot
.31394 .45956 Mdot
.4875 .68204 Mdot
.40137 .5361 Mdot
.6478 .53775 Mdot
.29717 .26454 Mdot
.60593 .55829 Mdot
.75829 .37388 Mdot
.40102 .57596 Mdot
.39427 .55831 Mdot
.60091 .50338 Mdot
.77787 .53637 Mdot
.32867 .41784 Mdot
.38339 .40033 Mdot
.57723 .50323 Mdot
.3727 .43225 Mdot
.61242 .53754 Mdot
.39479 .58005 Mdot
.35192 .20753 Mdot
.63207 .53054 Mdot
.58083 .57286 Mdot
.32169 .30431 Mdot
.31133 .74625 Mdot
.45756 .63836 Mdot
.1829 .61322 Mdot
.79443 .62407 Mdot
.37367 .43085 Mdot
.57817 .49274 Mdot
.46507 .24397 Mdot
.37096 .5408 Mdot
.39174 .36229 Mdot
.59443 .53477 Mdot
.59919 .55027 Mdot
.6798 .52871 Mdot
.66014 .51871 Mdot
.21762 .35259 Mdot
.5019 .25532 Mdot
.67495 .33235 Mdot
.64011 .48543 Mdot
.66022 .65326 Mdot
.35155 .42751 Mdot
.48169 .30008 Mdot
.48589 .64981 Mdot
.64491 .48605 Mdot
.49798 .38869 Mdot
.36725 .45247 Mdot
.85972 .44982 Mdot
.36482 .4448 Mdot
.37431 .57242 Mdot
.33532 .42029 Mdot
.64624 .52168 Mdot
.50487 .34229 Mdot
.42195 .47996 Mdot
.287 .52655 Mdot
.39502 .56828 Mdot
.63611 .51899 Mdot
.46931 .61309 Mdot
.37485 .55187 Mdot
.35447 .76981 Mdot
.50068 .33548 Mdot
.60034 .63983 Mdot
.52969 .31045 Mdot
.57464 .51238 Mdot
.57538 .51295 Mdot
.38325 .45847 Mdot
.33782 .41979 Mdot
.53065 .31188 Mdot
.13373 .4628 Mdot
.47058 .70525 Mdot
.51673 .32503 Mdot
.55789 .50559 Mdot
.45596 .43532 Mdot
.50655 .33743 Mdot
.5341 .68613 Mdot
.36045 .4006 Mdot
.54033 .29568 Mdot
.67949 .5093 Mdot
.70774 .66155 Mdot
.49258 .71018 Mdot
.41344 .59681 Mdot
.59864 .73657 Mdot
.35892 .55748 Mdot
.40295 .41072 Mdot
.36657 .61097 Mdot
.35879 .3936 Mdot
.36509 .32107 Mdot
.53736 .38886 Mdot
.40871 .52537 Mdot
.40887 .42997 Mdot
.36446 .60753 Mdot
.59867 .49883 Mdot
.44297 .64786 Mdot
.56774 .53298 Mdot
.65441 .56116 Mdot
.37567 .3988 Mdot
.48642 .32599 Mdot
.55473 .2923 Mdot
.7056 .62405 Mdot
.53644 .3207 Mdot
.36951 .56204 Mdot
.58336 .25226 Mdot
.29198 .45934 Mdot
.39809 .43073 Mdot
.34415 .43012 Mdot
.6126 .48373 Mdot
.37412 .59741 Mdot
.3949 .56486 Mdot
.39991 .437 Mdot
.36531 .24032 Mdot
.58018 .56398 Mdot
.56218 .32562 Mdot
.55184 .31425 Mdot
.51628 .33793 Mdot
.50149 .37165 Mdot
.73867 .54119 Mdot
.34474 .40869 Mdot
.49021 .31693 Mdot
.6136 .48272 Mdot
.59599 .54322 Mdot
.46938 .26682 Mdot
.4904 .70723 Mdot
.60998 .46755 Mdot
.68688 .48883 Mdot
.66848 .51308 Mdot
.34697 .60285 Mdot
.72181 .51566 Mdot
.35582 .61694 Mdot
.35645 .54542 Mdot
.36216 .54293 Mdot
.2783 .4157 Mdot
.80446 .50776 Mdot
.7336 .68327 Mdot
.58011 .53618 Mdot
.20009 .51755 Mdot
.36616 .59001 Mdot
.55859 .23657 Mdot
.35759 .34233 Mdot
.67624 .52377 Mdot
.31071 .6783 Mdot
.38133 .59974 Mdot
.52459 .2979 Mdot
.59533 .52745 Mdot
.36048 .62861 Mdot
.46982 .69454 Mdot
.57069 .52754 Mdot
.39019 .62418 Mdot
.51619 .35925 Mdot
.45913 .6678 Mdot
.5415 .29142 Mdot
.362 .54259 Mdot
.57389 .46336 Mdot
.4857 .1473 Mdot
.34297 .6245 Mdot
.22238 .62053 Mdot
.52719 .51604 Mdot
.60441 .49814 Mdot
.35008 .61924 Mdot
.51568 .27808 Mdot
.4012 .40874 Mdot
.49855 .51281 Mdot
.54604 .31676 Mdot
.39423 .5582 Mdot
.34117 .5713 Mdot
.39527 .56852 Mdot
.54753 .33429 Mdot
.59389 .46822 Mdot
.54209 .33188 Mdot
.33348 .4184 Mdot
.63952 .49764 Mdot
.6948 .72605 Mdot
.21626 .46236 Mdot
.52046 .30046 Mdot
.35799 .56696 Mdot
.52707 .67831 Mdot
.64374 .53113 Mdot
.20775 .47869 Mdot
.60018 .49611 Mdot
.36657 .3936 Mdot
.63113 .29752 Mdot
.5745 .41495 Mdot
.58379 .48911 Mdot
.61762 .48509 Mdot
.38512 .40274 Mdot
.63445 .52223 Mdot
.6187 .47465 Mdot
.2738 .42259 Mdot
.54004 .34211 Mdot
.63157 .53766 Mdot
.35444 .57977 Mdot
.28932 .48102 Mdot
.58072 .56806 Mdot
.3865 .51824 Mdot
.59609 .63567 Mdot
.62514 .31245 Mdot
.604 .55708 Mdot
.48897 .40628 Mdot
.66449 .52734 Mdot
.63231 .55695 Mdot
.61566 .48767 Mdot
.18869 .41397 Mdot
.38761 .62433 Mdot
.39416 .60169 Mdot
.50755 .70538 Mdot
.59495 .63613 Mdot
.48185 .69201 Mdot
.35499 .3996 Mdot
.40455 .70054 Mdot
.35818 .61855 Mdot
.52225 .34714 Mdot
.64649 .55313 Mdot
.34107 .62257 Mdot
.67148 .51753 Mdot
.6449 .51984 Mdot
.34229 .56115 Mdot
.39186 .62095 Mdot
.48807 .76784 Mdot
.48214 .70618 Mdot
.51237 .31877 Mdot
.60628 .47289 Mdot
.46694 .67319 Mdot
.6036 .55973 Mdot
.60047 .68675 Mdot
.51201 .32339 Mdot
.54032 .33958 Mdot
.55472 .29052 Mdot
.58993 .53266 Mdot
.64488 .52569 Mdot
.38282 .41326 Mdot
.50854 .29874 Mdot
.38848 .43958 Mdot
.48807 .53461 Mdot
.36964 .75057 Mdot
.59441 .53524 Mdot
.43549 .34295 Mdot
.47776 .69579 Mdot
.34881 .56674 Mdot
.80027 .36172 Mdot
.50708 .70574 Mdot
.62137 .50492 Mdot
.3567 .5488 Mdot
.48138 .6716 Mdot
.61009 .62268 Mdot
.84487 .47499 Mdot
.5241 .67343 Mdot
.6144 .48277 Mdot
.60265 .45126 Mdot
.17617 .59658 Mdot
.52323 .68217 Mdot
.34271 .42059 Mdot
.58971 .53055 Mdot
.5584 .34487 Mdot
.47047 .66383 Mdot
.28564 .63928 Mdot
.38856 .59747 Mdot
.71799 .64798 Mdot
.56974 .57685 Mdot
.56263 .26892 Mdot
.51059 .70118 Mdot
.50127 .35408 Mdot
.68985 .46802 Mdot
.66759 .5305 Mdot
.52373 .68641 Mdot
.39736 .39225 Mdot
.3893 .58281 Mdot
.2847 .50042 Mdot
.54851 .33221 Mdot
.40391 .3946 Mdot
.34939 .57188 Mdot
.23922 .60716 Mdot
.68049 .26945 Mdot
.66617 .46558 Mdot
.17853 .54759 Mdot
.30168 .36539 Mdot
.65889 .48587 Mdot
.50349 .64874 Mdot
.3454 .38728 Mdot
.3762 .45275 Mdot
.36652 .42823 Mdot
.34822 .33039 Mdot
.45339 .35117 Mdot
.38952 .62636 Mdot
.42918 .38607 Mdot
.50283 .70225 Mdot
.67284 .68163 Mdot
.6548 .56279 Mdot
.64207 .53602 Mdot
.60588 .47663 Mdot
.64773 .48636 Mdot
.65765 .53891 Mdot
.37545 .44009 Mdot
.35009 .31852 Mdot
.44953 .33592 Mdot
.50952 .33097 Mdot
.44746 .72556 Mdot
.35708 .59418 Mdot
.41838 .59816 Mdot
.47375 .67651 Mdot
.27036 .59959 Mdot
.31828 .58771 Mdot
.36901 .57768 Mdot
.63528 .4675 Mdot
.53552 .33851 Mdot
.69716 .48525 Mdot
.61608 .48398 Mdot
.37573 .56533 Mdot
.45456 .52848 Mdot
.7463 .47434 Mdot
.50773 .74655 Mdot
.45426 .67484 Mdot
.45432 .39732 Mdot
.51633 .70061 Mdot
.61995 .57628 Mdot
.49509 .19418 Mdot
.34855 .59827 Mdot
.37886 .58435 Mdot
.4871 .70512 Mdot
.33946 .23625 Mdot
.49343 .33362 Mdot
.40991 .45616 Mdot
.3434 .39924 Mdot
.57722 .51774 Mdot
.72244 .2879 Mdot
.52581 .50293 Mdot
.38126 .68978 Mdot
.36154 .42972 Mdot
.38168 .61538 Mdot
.62199 .58027 Mdot
.62741 .48569 Mdot
.47538 .69017 Mdot
.52682 .79622 Mdot
.69782 .5014 Mdot
.46358 .84391 Mdot
.82124 .41919 Mdot
.76608 .5984 Mdot
.6662 .53507 Mdot
.54283 .33887 Mdot
.41011 .5972 Mdot
.51127 .69147 Mdot
.56564 .4896 Mdot
.79545 .58736 Mdot
.49243 .35484 Mdot
.35595 .41855 Mdot
.45239 .49209 Mdot
.65541 .6967 Mdot
.64538 .56048 Mdot
.59566 .54615 Mdot
.63296 .55933 Mdot
.8216 .32298 Mdot
.35264 .61244 Mdot
.52435 .30017 Mdot
.49446 .6662 Mdot
.53343 .32845 Mdot
.38148 .61146 Mdot
.43064 .54243 Mdot
.59119 .50369 Mdot
.49913 .36436 Mdot
.50003 .35215 Mdot
.37932 .44995 Mdot
.37687 .38799 Mdot
.46823 .50657 Mdot
.60083 .51923 Mdot
.32765 .58082 Mdot
.48739 .32033 Mdot
.46826 .40012 Mdot
.49005 .68875 Mdot
.36199 .39976 Mdot
.64434 .48784 Mdot
.36118 .61819 Mdot
.67976 .49015 Mdot
.503 .31679 Mdot
.36911 .57858 Mdot
.43782 .78565 Mdot
.51982 .68052 Mdot
.60041 .54432 Mdot
.52954 .64171 Mdot
.40078 .58574 Mdot
.65133 .53684 Mdot
.2474 .64158 Mdot
.53319 .68843 Mdot
.29453 .54824 Mdot
.37139 .54649 Mdot
.28825 .413 Mdot
.53814 .30302 Mdot
.28663 .35279 Mdot
.37863 .57841 Mdot
.22231 .57595 Mdot
.46683 .78495 Mdot
.66447 .57211 Mdot
.52421 .3291 Mdot
.28774 .37406 Mdot
.73581 .72797 Mdot
.21921 .63781 Mdot
.6225 .51747 Mdot
.33224 .59408 Mdot
.47694 .67906 Mdot
.39737 .42533 Mdot
.3203 .53005 Mdot
.47748 .72541 Mdot
.33268 .55061 Mdot
.61588 .48813 Mdot
.50781 .35837 Mdot
.37418 .41056 Mdot
.38223 .30831 Mdot
.35394 .59066 Mdot
.35564 .5716 Mdot
.58402 .55512 Mdot
.48516 .69947 Mdot
.23553 .40729 Mdot
.39576 .5771 Mdot
.81505 .45542 Mdot
.41991 .60927 Mdot
.46503 .68495 Mdot
.66278 .51544 Mdot
.72436 .61618 Mdot
.5649 .51153 Mdot
.26568 .68167 Mdot
.35954 .59909 Mdot
.50734 .31909 Mdot
.66526 .54829 Mdot
.78283 .40209 Mdot
.36768 .56218 Mdot
.46507 .41126 Mdot
.35648 .65982 Mdot
.34609 .40318 Mdot
.79703 .35766 Mdot
.60339 .53541 Mdot
.32866 .4145 Mdot
.4762 .68824 Mdot
.60284 .51116 Mdot
.64781 .52512 Mdot
.48063 .34932 Mdot
.38631 .44806 Mdot
.48358 .76967 Mdot
.3454 .43437 Mdot
.35127 .43106 Mdot
.52191 .38004 Mdot
.62366 .54322 Mdot
.37239 .57091 Mdot
.38065 .59857 Mdot
.67736 .50391 Mdot
.31855 .21244 Mdot
.49222 .33974 Mdot
.41075 .58661 Mdot
.80295 .29602 Mdot
.66341 .48593 Mdot
.78633 .35226 Mdot
.51302 .79286 Mdot
.34301 .39262 Mdot
.61403 .48218 Mdot
.51568 .35734 Mdot
.30624 .63953 Mdot
.35823 .5697 Mdot
.68313 .5218 Mdot
.37397 .41212 Mdot
.47867 .70598 Mdot
.37687 .55693 Mdot
.39091 .68948 Mdot
.61642 .55663 Mdot
.3193 .69184 Mdot
.33363 .58264 Mdot
.67186 .78164 Mdot
.24001 .50795 Mdot
.52365 .32611 Mdot
.64615 .51753 Mdot
.51674 .29567 Mdot
.48902 .66479 Mdot
.45461 .49354 Mdot
.36471 .40388 Mdot
.7304 .49475 Mdot
.52192 .19365 Mdot
.39555 .56881 Mdot
.52035 .298 Mdot
.57518 .50076 Mdot
.3104 .29839 Mdot
.60796 .5388 Mdot
.55945 .46797 Mdot
.50066 .75604 Mdot
.38905 .41161 Mdot
.34341 .39547 Mdot
.65732 .52543 Mdot
.47944 .66216 Mdot
.35568 .59539 Mdot
.38479 .57464 Mdot
.59658 .83976 Mdot
.40067 .46922 Mdot
.79168 .46512 Mdot
.6003 .5508 Mdot
.33593 .54982 Mdot
.3223 .49181 Mdot
.37083 .4461 Mdot
.60796 .45885 Mdot
.34969 .55545 Mdot
.53008 .62579 Mdot
.64686 .62381 Mdot
.6658 .53009 Mdot
.56104 .51401 Mdot
.33841 .40525 Mdot
.46425 .37762 Mdot
.39446 .60985 Mdot
.69032 .50285 Mdot
.41321 .51979 Mdot
.60081 .62349 Mdot
.8338 .43026 Mdot
.51264 .31868 Mdot
.3886 .67476 Mdot
.37655 .44036 Mdot
.58196 .57497 Mdot
.50579 .66798 Mdot
.35193 .53928 Mdot
.36824 .6227 Mdot
.62132 .4965 Mdot
.64025 .57684 Mdot
.80919 .42248 Mdot
.52902 .34087 Mdot
.34974 .42184 Mdot
.5924 .51467 Mdot
.43731 .3033 Mdot
.63784 .47918 Mdot
.38754 .41932 Mdot
.46673 .14922 Mdot
.56609 .52372 Mdot
.61037 .54301 Mdot
.23521 .41357 Mdot
.54816 .31713 Mdot
.49418 .30603 Mdot
.73655 .28828 Mdot
.60021 .55035 Mdot
.81438 .40334 Mdot
.51115 .31335 Mdot
.49442 .32655 Mdot
.26532 .46014 Mdot
.64134 .53282 Mdot
.66755 .59347 Mdot
.35561 .39192 Mdot
.34978 .43058 Mdot
.5453 .33044 Mdot
.69505 .48954 Mdot
.37883 .39078 Mdot
.21521 .39199 Mdot
.37248 .5981 Mdot
.44597 .18501 Mdot
.49127 .34245 Mdot
.31209 .43528 Mdot
.36392 .43915 Mdot
.84837 .4963 Mdot
.3032 .59274 Mdot
.59543 .50146 Mdot
.60412 .55224 Mdot
.49158 .70495 Mdot
.59691 .47853 Mdot
.39465 .55891 Mdot
.3722 .43274 Mdot
.76586 .51775 Mdot
.51504 .32288 Mdot
.60622 .52583 Mdot
.28488 .67082 Mdot
.39435 .79316 Mdot
.40434 .66372 Mdot
.49755 .35615 Mdot
.52657 .31488 Mdot
.3665 .61622 Mdot
.3318 .58959 Mdot
.63949 .54673 Mdot
.39002 .40514 Mdot
.51114 .29823 Mdot
.38642 .41285 Mdot
.34749 .59563 Mdot
.37159 .5731 Mdot
.40024 .61697 Mdot
.65499 .56442 Mdot
.36253 .5756 Mdot
.39629 .76795 Mdot
.42173 .39631 Mdot
.53903 .37099 Mdot
.79011 .32235 Mdot
.38661 .31099 Mdot
.52539 .26528 Mdot
.46434 .67249 Mdot
.3984 .57543 Mdot
.33284 .42146 Mdot
.64816 .50382 Mdot
.65694 .49629 Mdot
.28955 .44113 Mdot
.33707 .4312 Mdot
.49219 .66645 Mdot
.33139 .40664 Mdot
.49645 .66639 Mdot
.33362 .68867 Mdot
.62444 .47264 Mdot
.6648 .56454 Mdot
.37008 .43811 Mdot
.36549 .57695 Mdot
.39184 .59953 Mdot
.52176 .67263 Mdot
.46479 .55229 Mdot
.37176 .5506 Mdot
.49223 .32595 Mdot
.74811 .50582 Mdot
.33637 .58246 Mdot
.59693 .52732 Mdot
.60554 .70434 Mdot
.28763 .26895 Mdot
.56319 .54222 Mdot
.26604 .44578 Mdot
.64214 .40846 Mdot
.67029 .53941 Mdot
.29328 .26198 Mdot
.33419 .37508 Mdot
.54143 .31209 Mdot
.4038 .5856 Mdot
.39594 .64169 Mdot
.69462 .56813 Mdot
.45959 .66325 Mdot
.57598 .4686 Mdot
.50104 .36444 Mdot
.47636 .33407 Mdot
.71532 .63147 Mdot
.23641 .65425 Mdot
.48078 .67412 Mdot
.47361 .68037 Mdot
.37949 .5764 Mdot
.38478 .82996 Mdot
.54643 .49164 Mdot
.49452 .66855 Mdot
.57013 .29719 Mdot
.61846 .49058 Mdot
.56142 .63223 Mdot
.52965 .46372 Mdot
.54634 .33182 Mdot
.66888 .6482 Mdot
.36824 .56505 Mdot
.53744 .31933 Mdot
.43554 .27568 Mdot
.5961 .46961 Mdot
.51272 .32447 Mdot
.38414 .41172 Mdot
.24703 .53863 Mdot
.48914 .32673 Mdot
.60725 .69511 Mdot
.40051 .41809 Mdot
.46543 .39864 Mdot
.68724 .62698 Mdot
.16902 .67952 Mdot
.37464 .43683 Mdot
.34169 .57129 Mdot
.38172 .59765 Mdot
.38393 .57424 Mdot
.53338 .33103 Mdot
.39692 .56991 Mdot
.52768 .34058 Mdot
.18504 .57338 Mdot
.29494 .27754 Mdot
.49616 .67091 Mdot
.28367 .50293 Mdot
.51377 .35113 Mdot
.54869 .22347 Mdot
.25477 .2441 Mdot
.61044 .48166 Mdot
.37609 .45462 Mdot
.49398 .67191 Mdot
.44305 .83332 Mdot
.48378 .68102 Mdot
.79517 .55484 Mdot
.60102 .29318 Mdot
.61205 .53093 Mdot
.73793 .40946 Mdot
.50841 .66042 Mdot
.51814 .36969 Mdot
.65077 .53599 Mdot
.49974 .57347 Mdot
.47957 .68477 Mdot
.46734 .6937 Mdot
.63558 .54324 Mdot
.50942 .30505 Mdot
.35787 .56486 Mdot
.34908 .4345 Mdot
.47887 .65609 Mdot
.61042 .44549 Mdot
.56991 .49666 Mdot
.59565 .49663 Mdot
.45073 .30062 Mdot
.51852 .65713 Mdot
.37437 .43037 Mdot
.16735 .42064 Mdot
.3416 .55784 Mdot
.50154 .5998 Mdot
.82281 .44214 Mdot
.31409 .37617 Mdot
.36081 .59913 Mdot
.39248 .60741 Mdot
.65727 .54025 Mdot
.55784 .44474 Mdot
.59108 .29137 Mdot
.4592 .57348 Mdot
.4126 .60443 Mdot
.3877 .57835 Mdot
.50592 .29539 Mdot
.75551 .60567 Mdot
.55366 .51858 Mdot
.36373 .38604 Mdot
.37893 .62438 Mdot
.27687 .31785 Mdot
.49276 .70273 Mdot
.60297 .27811 Mdot
.62388 .47146 Mdot
.59392 .50501 Mdot
.36814 .41215 Mdot
.38137 .41321 Mdot
.31985 .65033 Mdot
.77267 .58679 Mdot
.642 .4125 Mdot
.3538 .30604 Mdot
.62434 .32707 Mdot
.48918 .30885 Mdot
.52011 .30041 Mdot
.2853 .54359 Mdot
.35295 .44178 Mdot
.66957 .54221 Mdot
.5325 .31432 Mdot
.4908 .62061 Mdot
.73689 .50757 Mdot
.74384 .58317 Mdot
.79806 .37816 Mdot
.62738 .50994 Mdot
.53286 .34952 Mdot
.54907 .31719 Mdot
.5538 .33425 Mdot
.29337 .40946 Mdot
.62854 .54894 Mdot
.62575 .51371 Mdot
.66402 .54263 Mdot
.32353 .26774 Mdot
.63179 .5536 Mdot
.29884 .34491 Mdot
.46359 .48419 Mdot
.66955 .28481 Mdot
.69035 .50068 Mdot
.32824 .40227 Mdot
.62856 .56428 Mdot
.48112 .66192 Mdot
.59833 .48627 Mdot
.74525 .58084 Mdot
.35633 .42942 Mdot
.7207 .5629 Mdot
.37315 .32017 Mdot
.67761 .51333 Mdot
.46778 .65898 Mdot
.34434 .3505 Mdot
.72919 .71657 Mdot
.45863 .64234 Mdot
.49163 .32854 Mdot
.36724 .59815 Mdot
.33292 .42314 Mdot
.37463 .57896 Mdot
.6785 .55061 Mdot
.27763 .55074 Mdot
.45836 .82574 Mdot
.48361 .56016 Mdot
.64897 .48838 Mdot
.54939 .5261 Mdot
.49657 .31941 Mdot
.34641 .5549 Mdot
.54041 .27038 Mdot
.65246 .55582 Mdot
.50279 .67907 Mdot
.47724 .69053 Mdot
.49597 .52338 Mdot
.59987 .80786 Mdot
.24261 .35509 Mdot
.37145 .41619 Mdot
.3932 .57403 Mdot
.5115 .67039 Mdot
.21378 .55408 Mdot
.3469 .38141 Mdot
.37656 .39692 Mdot
.35329 .42501 Mdot
.5849 .53314 Mdot
.38399 .62515 Mdot
.67405 .28694 Mdot
.35723 .54143 Mdot
.63689 .52201 Mdot
.34643 .60361 Mdot
.35744 .55167 Mdot
.50982 .68668 Mdot
.35182 .42572 Mdot
.35057 .59873 Mdot
.57394 .51744 Mdot
.51369 .30967 Mdot
.33297 .47611 Mdot
.55265 .69184 Mdot
.24357 .66015 Mdot
.54242 .58167 Mdot
.551 .3325 Mdot
.71675 .73294 Mdot
.36274 .39044 Mdot
.35343 .24761 Mdot
.48989 .7674 Mdot
.59129 .55886 Mdot
.33531 .20065 Mdot
.4206 .58937 Mdot
.3561 .55417 Mdot
.6634 .51792 Mdot
.42423 .60915 Mdot
.60751 .53038 Mdot
.34485 .58229 Mdot
.35865 .5046 Mdot
.49755 .38403 Mdot
.36271 .58068 Mdot
.69111 .5139 Mdot
.65182 .52689 Mdot
.54312 .33625 Mdot
.33889 .60753 Mdot
.56248 .494 Mdot
.6289 .83502 Mdot
.38542 .42099 Mdot
.31335 .3656 Mdot
.5924 .71645 Mdot
.3785 .44106 Mdot
.51714 .32772 Mdot
.65214 .56272 Mdot
.4758 .68676 Mdot
.51432 .35251 Mdot
.74887 .56876 Mdot
.51828 .68492 Mdot
.4309 .17889 Mdot
.55022 .32162 Mdot
.35314 .56115 Mdot
.49383 .66126 Mdot
.58584 .48359 Mdot
.3673 .53938 Mdot
.23434 .53789 Mdot
.36017 .59627 Mdot
.66003 .54203 Mdot
.31017 .51576 Mdot
.34872 .42166 Mdot
.6188 .51589 Mdot
.36192 .55366 Mdot
.26757 .44826 Mdot
.58376 .53794 Mdot
.66058 .52847 Mdot
.82474 .45587 Mdot
.59765 .23309 Mdot
.48737 .685 Mdot
.54388 .29079 Mdot
.61239 .4825 Mdot
.46716 .68563 Mdot
.39983 .74658 Mdot
.58591 .52162 Mdot
.49195 .35499 Mdot
.60988 .45776 Mdot
.33562 .60128 Mdot
.38763 .43659 Mdot
.4704 .58803 Mdot
.46952 .69369 Mdot
.20445 .68601 Mdot
.38128 .62159 Mdot
.64271 .57164 Mdot
.63476 .47942 Mdot
.58848 .7567 Mdot
.54128 .31515 Mdot
.57296 .36299 Mdot
.60058 .54492 Mdot
.33466 .25608 Mdot
.6058 .51354 Mdot
.4173 .57405 Mdot
.49326 .33237 Mdot
.61435 .5482 Mdot
.36585 .48576 Mdot
.58354 .57391 Mdot
.49617 .70842 Mdot
.22063 .44719 Mdot
.58618 .47307 Mdot
.44524 .1636 Mdot
.51053 .56452 Mdot
.36076 .58004 Mdot
.33677 .74052 Mdot
.612 .84926 Mdot
.35533 .33042 Mdot
.53152 .32973 Mdot
.49821 .80371 Mdot
.37184 .57081 Mdot
.30759 .69732 Mdot
.73092 .7275 Mdot
.65256 .51923 Mdot
.64773 .55973 Mdot
.64648 .7149 Mdot
.35678 .54373 Mdot
.33123 .56577 Mdot
.6726 .56347 Mdot
.57294 .56493 Mdot
.36544 .57203 Mdot
.57926 .54096 Mdot
.69673 .51845 Mdot
.37607 .45427 Mdot
.49191 .35126 Mdot
.39018 .41164 Mdot
.38336 .39462 Mdot
.19978 .43981 Mdot
.51448 .57901 Mdot
.38832 .42338 Mdot
.34659 .38893 Mdot
.56387 .62925 Mdot
.77726 .55041 Mdot
.47489 .66042 Mdot
.62571 .81211 Mdot
.38751 .58192 Mdot
.62176 .54647 Mdot
.55128 .31604 Mdot
.63424 .4155 Mdot
.43041 .7607 Mdot
.51768 .20877 Mdot
.66305 .54906 Mdot
.36497 .56218 Mdot
.30622 .39148 Mdot
.6946 .47949 Mdot
.3612 .63128 Mdot
.59176 .52015 Mdot
.39336 .55665 Mdot
.76548 .49439 Mdot
.22268 .57498 Mdot
.40398 .63631 Mdot
.55952 .33491 Mdot
.59526 .509 Mdot
.50384 .36686 Mdot
.37202 .44527 Mdot
.47943 .65951 Mdot
.4865 .68904 Mdot
.64573 .53994 Mdot
.54287 .51619 Mdot
.33777 .70407 Mdot
.64537 .53066 Mdot
.6226 .49081 Mdot
.32766 .37718 Mdot
.61809 .48725 Mdot
.6502 .48398 Mdot
.67367 .52266 Mdot
.67837 .53757 Mdot
.35007 .42998 Mdot
.27194 .60474 Mdot
.68427 .57378 Mdot
.64795 .58824 Mdot
.40234 .41227 Mdot
.50847 .78621 Mdot
.3735 .39043 Mdot
.74181 .71172 Mdot
.34171 .39486 Mdot
.4947 .68659 Mdot
.53148 .77396 Mdot
.56964 .5802 Mdot
.48315 .34502 Mdot
.31716 .39663 Mdot
.4857 .66372 Mdot
.36896 .43039 Mdot
.34326 .57888 Mdot
.83078 .45211 Mdot
.47127 .34632 Mdot
.48953 .25787 Mdot
.37595 .35466 Mdot
.25856 .57823 Mdot
.3657 .61722 Mdot
.52254 .37095 Mdot
.74827 .45716 Mdot
.64709 .48446 Mdot
.46691 .68394 Mdot
.64116 .54532 Mdot
.36717 .44759 Mdot
.37349 .56702 Mdot
.20358 .60778 Mdot
.47557 .69082 Mdot
.81297 .35271 Mdot
.38747 .6015 Mdot
.65932 .49253 Mdot
.37782 .39055 Mdot
.72973 .25773 Mdot
.3863 .40784 Mdot
.58585 .35584 Mdot
.53148 .30003 Mdot
.19533 .63333 Mdot
.51954 .34256 Mdot
.23276 .55948 Mdot
.65558 .17835 Mdot
.27752 .64511 Mdot
.51285 .30619 Mdot
.43368 .55063 Mdot
.62087 .502 Mdot
.59467 .49761 Mdot
.21294 .58296 Mdot
.55035 .30333 Mdot
.6323 .48307 Mdot
.30922 .4729 Mdot
.39904 .38949 Mdot
.76249 .332 Mdot
.37098 .61518 Mdot
.60367 .53127 Mdot
.35071 .45105 Mdot
.33451 .4307 Mdot
.40096 .60465 Mdot
.37324 .39451 Mdot
.62726 .51596 Mdot
.51466 .34997 Mdot
.36702 .51245 Mdot
.49616 .69465 Mdot
.39993 .82449 Mdot
.48428 .71458 Mdot
.36123 .59997 Mdot
.56754 .53343 Mdot
.37148 .57383 Mdot
.72889 .7987 Mdot
.6183 .50762 Mdot
.51006 .31401 Mdot
.62609 .48744 Mdot
.59868 .50628 Mdot
.67369 .54202 Mdot
.35566 .56797 Mdot
.50487 .75081 Mdot
.57412 .52477 Mdot
.36211 .40252 Mdot
.64619 .3112 Mdot
.61142 .46503 Mdot
.43848 .62525 Mdot
.74002 .59389 Mdot
.41588 .36203 Mdot
.53836 .29578 Mdot
.36053 .58564 Mdot
.51716 .31897 Mdot
.37007 .22315 Mdot
.5169 .32806 Mdot
.63622 .35736 Mdot
.755 .45862 Mdot
.7839 .43898 Mdot
.77669 .42427 Mdot
.42697 .49697 Mdot
.54741 .29719 Mdot
.46717 .64402 Mdot
.50777 .30125 Mdot
.54602 .32393 Mdot
.36417 .1375 Mdot
.49154 .36354 Mdot
.59658 .53407 Mdot
.62516 .46622 Mdot
.24862 .60361 Mdot
.59366 .66894 Mdot
.63928 .49568 Mdot
.64085 .49106 Mdot
.50846 .6674 Mdot
.36471 .23038 Mdot
.28798 .56043 Mdot
.58847 .2314 Mdot
.40802 .79167 Mdot
.63902 .54416 Mdot
.60349 .48255 Mdot
.68693 .56178 Mdot
.61339 .19153 Mdot
.18971 .46238 Mdot
.55919 .34767 Mdot
.66274 .57776 Mdot
.27443 .65942 Mdot
.66253 .55195 Mdot
.59207 .54282 Mdot
.62477 .50715 Mdot
.37173 .57025 Mdot
.54024 .29248 Mdot
.68361 .53057 Mdot
.56943 .76456 Mdot
.59156 .53627 Mdot
.30039 .38578 Mdot
.2759 .74602 Mdot
.60333 .53625 Mdot
.50534 .28949 Mdot
.59725 .49449 Mdot
.54184 .32426 Mdot
.53516 .35498 Mdot
.66403 .57459 Mdot
.62123 .32778 Mdot
.51165 .2908 Mdot
.63771 .52226 Mdot
.34232 .57481 Mdot
.66453 .78239 Mdot
.65656 .5448 Mdot
.47311 .66252 Mdot
.60257 .55079 Mdot
.46074 .66826 Mdot
.62944 .49434 Mdot
.38768 .61981 Mdot
.60395 .40666 Mdot
.38008 .58302 Mdot
.17688 .5302 Mdot
.39461 .62028 Mdot
.83176 .38196 Mdot
.55064 .33717 Mdot
.29781 .50556 Mdot
.45338 .20275 Mdot
.27832 .38778 Mdot
.50334 .42477 Mdot
.43607 .45924 Mdot
.38873 .40402 Mdot
.53587 .30781 Mdot
.41393 .22566 Mdot
.44386 .73532 Mdot
.43331 .69345 Mdot
.37802 .55473 Mdot
.15281 .422 Mdot
.41218 .19097 Mdot
.61426 .57577 Mdot
.72267 .41681 Mdot
.69191 .36009 Mdot
.66445 .55111 Mdot
.6718 .54793 Mdot
.40773 .64189 Mdot
.57325 .52966 Mdot
.43725 .30804 Mdot
.36446 .60567 Mdot
.48112 .66453 Mdot
.5017 .31382 Mdot
.47881 .70638 Mdot
.46777 .75193 Mdot
.43647 .45131 Mdot
.34453 .58798 Mdot
.56229 .50342 Mdot
.64585 .49811 Mdot
.53986 .33412 Mdot
.5371 .25938 Mdot
.49066 .31401 Mdot
.4888 .67266 Mdot
.37026 .60828 Mdot
.26112 .29752 Mdot
.64751 .49639 Mdot
.49956 .34937 Mdot
.50994 .43187 Mdot
.61607 .48308 Mdot
.37043 .44187 Mdot
.61588 .50015 Mdot
.50623 .30709 Mdot
.61848 .48736 Mdot
.52113 .34108 Mdot
.36925 .59732 Mdot
.67291 .51115 Mdot
.66644 .52093 Mdot
.7774 .31465 Mdot
.49994 .67445 Mdot
.51831 .37391 Mdot
.49399 .60938 Mdot
.6153 .47758 Mdot
.2684 .49016 Mdot
.59278 .52394 Mdot
.47829 .38585 Mdot
.61183 .57217 Mdot
.31383 .36699 Mdot
.62549 .59245 Mdot
.64496 .54929 Mdot
.51256 .487 Mdot
.68235 .36069 Mdot
.61728 .60523 Mdot
.33659 .39197 Mdot
.51194 .37554 Mdot
.76865 .34499 Mdot
.37227 .52166 Mdot
.32966 .59467 Mdot
.66383 .66778 Mdot
.68342 .51933 Mdot
.61267 .53338 Mdot
.43115 .36993 Mdot
.474 .6956 Mdot
.50058 .36087 Mdot
.49676 .66663 Mdot
.81012 .3713 Mdot
.51376 .69974 Mdot
.41803 .57499 Mdot
.31986 .69357 Mdot
.2315 .33861 Mdot
.51013 .66994 Mdot
.5065 .30542 Mdot
.30323 .66861 Mdot
.66304 .49073 Mdot
.50869 .55005 Mdot
.50333 .6849 Mdot
.14155 .51762 Mdot
.65162 .48514 Mdot
.50718 .42295 Mdot
.39139 .42617 Mdot
.5067 .66793 Mdot
.40117 .42739 Mdot
.65112 .50927 Mdot
.29008 .5592 Mdot
.53069 .32922 Mdot
.40375 .43308 Mdot
.63632 .45996 Mdot
.49293 .66994 Mdot
.37466 .62452 Mdot
.3956 .46172 Mdot
.35682 .38598 Mdot
.55491 .80222 Mdot
.19356 .60801 Mdot
.37321 .60848 Mdot
.68236 .26787 Mdot
.32953 .4061 Mdot
.65867 .48498 Mdot
.3871 .22348 Mdot
.59414 .50258 Mdot
.25481 .36746 Mdot
.35703 .59123 Mdot
.26237 .58589 Mdot
.61123 .48304 Mdot
.65183 .55241 Mdot
.47623 .32687 Mdot
.38296 .59017 Mdot
.5067 .34163 Mdot
.52798 .37388 Mdot
.37066 .59844 Mdot
.52237 .33114 Mdot
.51396 .66758 Mdot
.43939 .25097 Mdot
.34195 .39949 Mdot
.35172 .4044 Mdot
.38533 .57473 Mdot
.35718 .58035 Mdot
.37014 .57792 Mdot
.61522 .49967 Mdot
.49438 .34842 Mdot
.64304 .51187 Mdot
.60345 .55753 Mdot
.64551 .29657 Mdot
.54513 .30055 Mdot
.63435 .51115 Mdot
.5034 .58655 Mdot
.5374 .46194 Mdot
.33936 .58202 Mdot
.38945 .42597 Mdot
.30618 .48145 Mdot
.23235 .51555 Mdot
.60219 .52789 Mdot
.53965 .65139 Mdot
.50627 .30409 Mdot
.47791 .68224 Mdot
.50497 .71041 Mdot
.48552 .68181 Mdot
.38853 .36933 Mdot
.55355 .33229 Mdot
.58839 .23803 Mdot
.60671 .53278 Mdot
.44602 .34217 Mdot
.55625 .36036 Mdot
.32724 .67629 Mdot
.3879 .42607 Mdot
.62731 .486 Mdot
.47332 .58435 Mdot
.73017 .46898 Mdot
.59887 .50034 Mdot
.62116 .46325 Mdot
.41064 .77599 Mdot
.56561 .47212 Mdot
.48022 .32655 Mdot
.7362 .26858 Mdot
.58734 .48531 Mdot
.27433 .31643 Mdot
.42736 .84493 Mdot
.59837 .52066 Mdot
.64246 .55717 Mdot
.65654 .5009 Mdot
.59598 .48813 Mdot
.51146 .28888 Mdot
.61776 .64868 Mdot
.33053 .40192 Mdot
.44819 .33295 Mdot
.35914 .444 Mdot
.40897 .58859 Mdot
.26473 .58966 Mdot
.53253 .30269 Mdot
.49035 .70475 Mdot
.36805 .78693 Mdot
.65826 .23029 Mdot
.39541 .6087 Mdot
.2222 .38459 Mdot
.50111 .6838 Mdot
.64794 .47401 Mdot
.49056 .65315 Mdot
.34922 .61155 Mdot
.34744 .40327 Mdot
.59071 .46758 Mdot
.5171 .30127 Mdot
.4885 .33133 Mdot
.62483 .48352 Mdot
.28446 .68609 Mdot
.38081 .44395 Mdot
.34557 .38573 Mdot
.58365 .52835 Mdot
.58893 .48136 Mdot
.5096 .34022 Mdot
.39475 .58452 Mdot
.79024 .4358 Mdot
.47147 .68024 Mdot
.6564 .56275 Mdot
.61336 .48724 Mdot
.82156 .4517 Mdot
.36107 .4003 Mdot
.34806 .62243 Mdot
.59475 .56195 Mdot
.34169 .30353 Mdot
.59091 .5577 Mdot
.69223 .55219 Mdot
.34143 .57533 Mdot
.70874 .53844 Mdot
.66093 .56768 Mdot
.47865 .38034 Mdot
.39626 .41597 Mdot
.51053 .32113 Mdot
.47485 .37806 Mdot
.465 .23629 Mdot
.36708 .43877 Mdot
.62639 .50399 Mdot
.3845 .42923 Mdot
.58614 .52011 Mdot
.57897 .49972 Mdot
.38787 .41985 Mdot
.50758 .34223 Mdot
.48968 .80214 Mdot
.27648 .62985 Mdot
.58869 .49379 Mdot
.66584 .57045 Mdot
.5925 .65251 Mdot
.47215 .73061 Mdot
.65186 .55679 Mdot
.49977 .31053 Mdot
.65462 .50678 Mdot
.3891 .44599 Mdot
.50943 .66194 Mdot
.5126 .30839 Mdot
.39364 .6008 Mdot
.38605 .61675 Mdot
.37049 .32352 Mdot
.36606 .54754 Mdot
.64417 .56213 Mdot
.51023 .27183 Mdot
.49436 .29229 Mdot
.33473 .76903 Mdot
.37426 .59938 Mdot
.47081 .66279 Mdot
.65894 .53151 Mdot
.7081 .66177 Mdot
.35721 .45463 Mdot
.31572 .19024 Mdot
.54483 .21879 Mdot
.50075 .6506 Mdot
.55153 .23649 Mdot
.39685 .61605 Mdot
.67518 .55645 Mdot
.47148 .66542 Mdot
.36719 .6164 Mdot
.58096 .5116 Mdot
.66817 .57317 Mdot
.57596 .3674 Mdot
.40315 .47561 Mdot
.38404 .42512 Mdot
.3891 .55658 Mdot
.48537 .64714 Mdot
.41316 .60967 Mdot
.54083 .35192 Mdot
.63067 .55087 Mdot
.57201 .54028 Mdot
.3967 .58732 Mdot
.32807 .59295 Mdot
.63547 .51678 Mdot
.51855 .29578 Mdot
.42672 .63715 Mdot
.63517 .5409 Mdot
.39818 .47138 Mdot
.55294 .30037 Mdot
.37023 .61275 Mdot
.6458 .55259 Mdot
.45074 .66963 Mdot
.39124 .59677 Mdot
.3389 .58575 Mdot
.60503 .48168 Mdot
.5161 .67432 Mdot
.63601 .58098 Mdot
.35025 .39329 Mdot
.15358 .44622 Mdot
.38798 .44694 Mdot
.38563 .52031 Mdot
.566 .46728 Mdot
.34996 .27588 Mdot
.54088 .30226 Mdot
.70184 .63317 Mdot
.30993 .475 Mdot
.69771 .51775 Mdot
.65401 .77634 Mdot
.31445 .43922 Mdot
.32705 .75171 Mdot
.70518 .70479 Mdot
.50701 .68698 Mdot
.36668 .42912 Mdot
.64226 .55745 Mdot
.37803 .45472 Mdot
.46845 .67021 Mdot
.1784 .52729 Mdot
.65733 .54648 Mdot
.49478 .32694 Mdot
.6297 .51414 Mdot
.49074 .3371 Mdot
.59554 .4845 Mdot
.60617 .57978 Mdot
.28308 .41933 Mdot
.62585 .62579 Mdot
.59488 .56009 Mdot
.80551 .30567 Mdot
.54798 .43152 Mdot
.47375 .67184 Mdot
.6489 .51851 Mdot
.38339 .63458 Mdot
.34375 .43915 Mdot
.29084 .36463 Mdot
.36995 .56919 Mdot
.35759 .38699 Mdot
.51687 .33505 Mdot
.36127 .59187 Mdot
.39966 .60381 Mdot
.71057 .53345 Mdot
.5074 .65657 Mdot
.35388 .41497 Mdot
.61486 .54974 Mdot
.65507 .54751 Mdot
.68218 .26382 Mdot
.42745 .73719 Mdot
.52514 .25618 Mdot
.55102 .17386 Mdot
.54242 .36075 Mdot
.48573 .66594 Mdot
.35893 .56534 Mdot
.61545 .5623 Mdot
.62241 .51918 Mdot
.27839 .49133 Mdot
.49945 .30302 Mdot
.45716 .50219 Mdot
.54967 .25113 Mdot
.48416 .62125 Mdot
.62946 .63308 Mdot
.5015 .31213 Mdot
.62198 .63394 Mdot
.52554 .66466 Mdot
.55891 .83013 Mdot
.58636 .62553 Mdot
.39056 .42999 Mdot
.60472 .63527 Mdot
.50321 .3603 Mdot
.57554 .52244 Mdot
.34461 .56695 Mdot
.35696 .55136 Mdot
.50725 .32978 Mdot
.38402 .62968 Mdot
.50811 .69309 Mdot
.6253 .55777 Mdot
.59038 .222 Mdot
.40385 .29854 Mdot
.38669 .57155 Mdot
.70219 .4952 Mdot
.35377 .42661 Mdot
.62365 .48296 Mdot
.51227 .67864 Mdot
.37867 .43535 Mdot
.78603 .56923 Mdot
.41075 .40147 Mdot
.65479 .5346 Mdot
.825 .45104 Mdot
.3691 .43618 Mdot
.59932 .42676 Mdot
.62817 .54401 Mdot
.35856 .3923 Mdot
.71517 .49028 Mdot
.24474 .54397 Mdot
.48442 .54781 Mdot
.73193 .72768 Mdot
.48229 .5072 Mdot
.36756 .55935 Mdot
.25215 .56431 Mdot
.27316 .3853 Mdot
.3343 .42057 Mdot
.33602 .61066 Mdot
.52477 .58741 Mdot
.40083 .42368 Mdot
.64904 .47607 Mdot
.59457 .51954 Mdot
.18989 .47507 Mdot
.32608 .43811 Mdot
.22964 .56254 Mdot
.38609 .33711 Mdot
.61709 .47669 Mdot
.61779 .57947 Mdot
.6219 .52324 Mdot
.48901 .30751 Mdot
.37795 .41418 Mdot
.77551 .28967 Mdot
.37333 .4446 Mdot
.61805 .28291 Mdot
.38576 .57826 Mdot
.36882 .61507 Mdot
.60177 .53231 Mdot
.50934 .41737 Mdot
.76188 .58461 Mdot
.63051 .51878 Mdot
.5014 .73238 Mdot
.2005 .49365 Mdot
.59433 .47925 Mdot
.53121 .29569 Mdot
.70321 .5284 Mdot
.61361 .44219 Mdot
.34081 .40024 Mdot
.49508 .70133 Mdot
.72871 .61798 Mdot
.34606 .40823 Mdot
.61374 .53241 Mdot
.35716 .28047 Mdot
.60513 .50512 Mdot
.58724 .49746 Mdot
.58183 .26521 Mdot
.51191 .70543 Mdot
.37139 .58666 Mdot
.48823 .6808 Mdot
.54318 .31634 Mdot
.28342 .19104 Mdot
.5106 .70294 Mdot
.77347 .57244 Mdot
.17622 .48427 Mdot
.58651 .6325 Mdot
.49861 .36173 Mdot
.48687 .6506 Mdot
.38772 .43961 Mdot
.6612 .78623 Mdot
.57165 .38636 Mdot
.33596 .46202 Mdot
.63015 .53846 Mdot
.49775 .37535 Mdot
.48575 .33134 Mdot
.40498 .42956 Mdot
.53206 .3599 Mdot
.67585 .58809 Mdot
.57852 .51024 Mdot
.34708 .43434 Mdot
.36417 .29962 Mdot
.33121 .39607 Mdot
.43049 .53302 Mdot
.64731 .52344 Mdot
.50905 .31055 Mdot
.6655 .55901 Mdot
.53276 .2772 Mdot
.35991 .62703 Mdot
.56282 .51437 Mdot
.50802 .69497 Mdot
.33525 .2895 Mdot
.37607 .60924 Mdot
.50581 .61768 Mdot
.54112 .33128 Mdot
.40823 .37628 Mdot
.54171 .33903 Mdot
.51326 .27728 Mdot
.37552 .39041 Mdot
.51857 .35898 Mdot
.63839 .55747 Mdot
.4942 .56163 Mdot
.53591 .33178 Mdot
.36401 .41556 Mdot
.48968 .6995 Mdot
.51784 .34057 Mdot
.42377 .61346 Mdot
.65937 .5354 Mdot
.35537 .57123 Mdot
.47952 .74674 Mdot
.49414 .37012 Mdot
.52399 .69165 Mdot
.32869 .588 Mdot
.46704 .69329 Mdot
.28228 .72189 Mdot
.40928 .41522 Mdot
.60552 .29737 Mdot
.49569 .73779 Mdot
.48227 .34039 Mdot
.50067 .76087 Mdot
.60249 .55534 Mdot
.66007 .53304 Mdot
.46099 .67098 Mdot
.48576 .33098 Mdot
.4897 .8507 Mdot
.54276 .48518 Mdot
.41956 .50916 Mdot
.32557 .38668 Mdot
.83055 .37115 Mdot
.4233 .52228 Mdot
.38914 .83589 Mdot
.685 .47903 Mdot
.33289 .56215 Mdot
.6077 .52333 Mdot
.28904 .46308 Mdot
.4949 .67303 Mdot
.43167 .56564 Mdot
.57585 .55617 Mdot
.36769 .59113 Mdot
.66928 .51747 Mdot
.50652 .499 Mdot
.62574 .43264 Mdot
.46472 .67016 Mdot
.29737 .68143 Mdot
.49856 .37033 Mdot
.49827 .69211 Mdot
.35688 .61139 Mdot
.68134 .62513 Mdot
.58068 .50989 Mdot
.65632 .47929 Mdot
.48248 .6218 Mdot
.49432 .35138 Mdot
.35616 .55787 Mdot
.34956 .39514 Mdot
.48531 .70186 Mdot
.64501 .49917 Mdot
.59932 .55664 Mdot
.26568 .47855 Mdot
.35538 .43193 Mdot
.34993 .54996 Mdot
.39434 .42044 Mdot
.40416 .60443 Mdot
.57098 .51784 Mdot
.38394 .61428 Mdot
.68736 .52645 Mdot
.29589 .39787 Mdot
.59587 .27872 Mdot
.68865 .37631 Mdot
.35704 .59557 Mdot
.77752 .53797 Mdot
.35841 .43369 Mdot
.38082 .40193 Mdot
.18726 .41635 Mdot
.58299 .35439 Mdot
.65823 .23987 Mdot
.62377 .76895 Mdot
.34767 .43049 Mdot
.35592 .42058 Mdot
.35502 .5731 Mdot
.52135 .35815 Mdot
.54097 .36031 Mdot
.40362 .60229 Mdot
.60046 .70979 Mdot
.50034 .36045 Mdot
.61453 .80646 Mdot
.73892 .30739 Mdot
.68776 .50672 Mdot
.4171 .56682 Mdot
.47861 .68806 Mdot
.61182 .69635 Mdot
.5036 .51339 Mdot
.65679 .551 Mdot
.69551 .65347 Mdot
.39052 .57895 Mdot
.48225 .4024 Mdot
.73257 .71713 Mdot
.67171 .51444 Mdot
.62399 .54651 Mdot
.61577 .52559 Mdot
.51748 .66489 Mdot
.58667 .38504 Mdot
.63529 .55481 Mdot
.59779 .71186 Mdot
.61977 .47938 Mdot
.63719 .43195 Mdot
.48655 .68669 Mdot
.57328 .61292 Mdot
.45514 .74456 Mdot
.73893 .27666 Mdot
.5881 .43691 Mdot
.34595 .39538 Mdot
.43853 .67592 Mdot
.38711 .40554 Mdot
.64822 .35887 Mdot
.56232 .62415 Mdot
.5465 .35801 Mdot
.65499 .5526 Mdot
.36136 .60104 Mdot
.48598 .33192 Mdot
.25683 .52789 Mdot
.3267 .16063 Mdot
.33742 .39937 Mdot
.51886 .8916 Mdot
.36413 .39379 Mdot
.40097 .60089 Mdot
.51011 .33905 Mdot
.75842 .47171 Mdot
.46018 .27423 Mdot
.52009 .33802 Mdot
.47511 .82711 Mdot
.56312 .33976 Mdot
.72491 .60213 Mdot
.47836 .3498 Mdot
.36184 .41979 Mdot
.37185 .35983 Mdot
.6643 .5977 Mdot
.59684 .54485 Mdot
.44029 .45789 Mdot
.76045 .58025 Mdot
.60404 .5562 Mdot
.36632 .60628 Mdot
.59592 .29896 Mdot
.67769 .65819 Mdot
.51256 .36061 Mdot
.40705 .40057 Mdot
.63279 .54825 Mdot
.60477 .49014 Mdot
.57778 .51743 Mdot
.55148 .21208 Mdot
.55454 .83098 Mdot
.57378 .52282 Mdot
.60212 .47987 Mdot
.36401 .59211 Mdot
.46564 .71968 Mdot
.29525 .65491 Mdot
.66652 .27104 Mdot
.67644 .52743 Mdot
.49353 .69195 Mdot
.48324 .64449 Mdot
.58338 .54515 Mdot
.5094 .57822 Mdot
.36199 .27261 Mdot
.61652 .55052 Mdot
.59628 .30578 Mdot
.32439 .6376 Mdot
.35592 .54366 Mdot
.3944 .59581 Mdot
.51379 .37249 Mdot
.40008 .58764 Mdot
.38504 .62214 Mdot
.75314 .49238 Mdot
.47149 .502 Mdot
.29764 .42032 Mdot
.48638 .67243 Mdot
.61796 .51452 Mdot
.5931 .6006 Mdot
.34394 .29591 Mdot
.3915 .40451 Mdot
.51973 .30647 Mdot
.34571 .44259 Mdot
.48585 .63959 Mdot
.49049 .2343 Mdot
.38711 .56436 Mdot
.34168 .41702 Mdot
.41122 .44464 Mdot
.49098 .69255 Mdot
.39622 .44471 Mdot
.42669 .41248 Mdot
.57371 .4884 Mdot
.71248 .42086 Mdot
.63631 .52372 Mdot
.37401 .79534 Mdot
.35052 .42001 Mdot
.3446 .36409 Mdot
.6122 .54031 Mdot
.38905 .59831 Mdot
.7308 .54452 Mdot
.59339 .54182 Mdot
.39841 .58466 Mdot
.60777 .57319 Mdot
.48032 .71257 Mdot
.54525 .28981 Mdot
.45725 .28122 Mdot
.15265 .41292 Mdot
.50336 .65376 Mdot
.26031 .52064 Mdot
.65999 .55212 Mdot
.22414 .65203 Mdot
.51617 .34386 Mdot
.62278 .56984 Mdot
.66643 .64764 Mdot
.53034 .34066 Mdot
.52057 .31799 Mdot
.61835 .49538 Mdot
.39255 .42754 Mdot
.37434 .61114 Mdot
.48618 .69138 Mdot
.36004 .80698 Mdot
.63985 .53637 Mdot
.66303 .5155 Mdot
.49978 .68811 Mdot
.36224 .44092 Mdot
.59083 .55651 Mdot
.6205 .74244 Mdot
.52265 .85425 Mdot
.36787 .39248 Mdot
.66191 .49254 Mdot
.64909 .38277 Mdot
.55655 .46225 Mdot
.197 .65631 Mdot
.51041 .56158 Mdot
.36625 .58422 Mdot
.55032 .50355 Mdot
.41364 .15522 Mdot
.49073 .70133 Mdot
.65712 .23196 Mdot
.60647 .48853 Mdot
.64618 .49284 Mdot
.49443 .30987 Mdot
.64133 .51407 Mdot
.52845 .3017 Mdot
.20071 .34903 Mdot
.82726 .43403 Mdot
.52955 .36602 Mdot
.48278 .34933 Mdot
.7364 .60949 Mdot
.3383 .49945 Mdot
.50905 .33097 Mdot
.58184 .4944 Mdot
.53593 .60695 Mdot
.47726 .39304 Mdot
.47843 .65316 Mdot
.49024 .76005 Mdot
.53918 .53753 Mdot
.53332 .63678 Mdot
.50598 .7897 Mdot
.54833 .5709 Mdot
.44937 .56054 Mdot
.3681 .39848 Mdot
.67266 .51568 Mdot
.35674 .5507 Mdot
.36201 .54719 Mdot
.68779 .53539 Mdot
.61312 .50702 Mdot
.54317 .32104 Mdot
.47509 .6935 Mdot
.33035 .41545 Mdot
.64353 .49339 Mdot
.69904 .63098 Mdot
.47965 .70316 Mdot
.52777 .36017 Mdot
.63533 .30467 Mdot
.47663 .71493 Mdot
.61446 .58445 Mdot
.60514 .54676 Mdot
.62743 .50993 Mdot
.65722 .60118 Mdot
.37842 .41091 Mdot
.52035 .77324 Mdot
.61585 .46863 Mdot
.80651 .36149 Mdot
.30958 .45098 Mdot
.55876 .53425 Mdot
.54103 .34822 Mdot
.3784 .38156 Mdot
.4016 .61922 Mdot
.45208 .22832 Mdot
.65237 .53482 Mdot
.28751 .68219 Mdot
.19133 .48582 Mdot
.34718 .61887 Mdot
.53536 .28081 Mdot
.48289 .67845 Mdot
.62778 .51721 Mdot
.61917 .33113 Mdot
.59538 .52258 Mdot
.534 .68426 Mdot
.33753 .59117 Mdot
.37139 .39967 Mdot
.34285 .76706 Mdot
.3767 .54893 Mdot
.51786 .319 Mdot
.8286 .54897 Mdot
.52849 .30062 Mdot
.53826 .36275 Mdot
.64517 .30726 Mdot
.37935 .41037 Mdot
.36348 .16574 Mdot
.21226 .34791 Mdot
.56735 .50666 Mdot
.36188 .43861 Mdot
.50365 .32436 Mdot
.63436 .48116 Mdot
.56401 .30539 Mdot
.55375 .32339 Mdot
.57305 .50802 Mdot
.65465 .49557 Mdot
.23632 .5981 Mdot
.70803 .73033 Mdot
.48385 .67689 Mdot
.54567 .31343 Mdot
.44557 .29573 Mdot
.63467 .47993 Mdot
.60693 .53381 Mdot
.25634 .40304 Mdot
.50531 .65723 Mdot
.42743 .292 Mdot
.60551 .48942 Mdot
.81829 .49548 Mdot
.69826 .55528 Mdot
.51571 .29002 Mdot
.38329 .40022 Mdot
.75161 .29243 Mdot
.42369 .43184 Mdot
.52824 .30288 Mdot
.4949 .70611 Mdot
.47877 .31601 Mdot
.77965 .56365 Mdot
.36232 .44466 Mdot
.5061 .30712 Mdot
.46955 .58558 Mdot
.37743 .42116 Mdot
.34612 .41571 Mdot
.65305 .29809 Mdot
.3567 .62916 Mdot
.51452 .65967 Mdot
.35412 .41752 Mdot
.34419 .2548 Mdot
.36798 .42019 Mdot
.20196 .36537 Mdot
.66978 .50672 Mdot
.64813 .69258 Mdot
.39739 .52634 Mdot
.54827 .54504 Mdot
.34891 .42392 Mdot
.50718 .66501 Mdot
.5823 .51052 Mdot
.50928 .36631 Mdot
.46838 .6844 Mdot
.36166 .46606 Mdot
.36681 .57135 Mdot
.53826 .34264 Mdot
.32056 .41798 Mdot
.48977 .33184 Mdot
.41293 .22703 Mdot
.16357 .4819 Mdot
.74321 .62739 Mdot
.46272 .26791 Mdot
.58122 .50756 Mdot
.57049 .79645 Mdot
.66994 .49896 Mdot
.6097 .50208 Mdot
.36762 .61035 Mdot
.66526 .67638 Mdot
.50718 .34151 Mdot
.43336 .82742 Mdot
.33972 .40396 Mdot
.74841 .28452 Mdot
.57682 .44481 Mdot
.643 .57243 Mdot
.53692 .3279 Mdot
.50842 .29706 Mdot
.67264 .34595 Mdot
.41656 .59771 Mdot
.65858 .55797 Mdot
.61302 .45992 Mdot
.68759 .54437 Mdot
.34448 .40301 Mdot
.51455 .6008 Mdot
.37178 .56072 Mdot
.17029 .55115 Mdot
.33638 .59161 Mdot
.53726 .67365 Mdot
.51687 .36206 Mdot
.51013 .70312 Mdot
.60669 .53616 Mdot
.54363 .26102 Mdot
.49711 .30431 Mdot
.46105 .67552 Mdot
.49898 .66323 Mdot
.24302 .48983 Mdot
.38762 .42043 Mdot
.58905 .54183 Mdot
.6437 .55343 Mdot
.64123 .50761 Mdot
.61582 .50161 Mdot
.33689 .40226 Mdot
.58052 .52006 Mdot
.35996 .4576 Mdot
.46692 .21536 Mdot
.65292 .71243 Mdot
.48471 .50374 Mdot
.23578 .38058 Mdot
.50804 .36199 Mdot
.34493 .26094 Mdot
.58943 .45225 Mdot
.46444 .1861 Mdot
.19547 .55837 Mdot
.59593 .47258 Mdot
.38146 .61819 Mdot
.72081 .49005 Mdot
.37365 .55298 Mdot
.39359 .84714 Mdot
.2701 .42211 Mdot
.69575 .74617 Mdot
.6559 .54661 Mdot
.49222 .56128 Mdot
.31492 .27052 Mdot
.66468 .49105 Mdot
.25575 .46509 Mdot
.25389 .36624 Mdot
.29032 .66726 Mdot
.51289 .6725 Mdot
.6479 .54239 Mdot
.60605 .60366 Mdot
.63308 .55758 Mdot
.6061 .52748 Mdot
.57905 .51861 Mdot
.32547 .40419 Mdot
.62685 .56737 Mdot
.58911 .50513 Mdot
.34439 .71237 Mdot
.62738 .63046 Mdot
.33582 .56469 Mdot
.18195 .43968 Mdot
.51209 .70217 Mdot
.5396 .32891 Mdot
.54684 .8247 Mdot
.39017 .42981 Mdot
.67952 .3492 Mdot
.62076 .50525 Mdot
.25205 .61029 Mdot
.41621 .43251 Mdot
.49977 .70375 Mdot
.35184 .61461 Mdot
.69487 .75996 Mdot
.36576 .60217 Mdot
.36748 .37326 Mdot
.3855 .6007 Mdot
.56632 .46214 Mdot
.54368 .31954 Mdot
.58626 .54379 Mdot
.35454 .41216 Mdot
.39595 .60194 Mdot
.59526 .66197 Mdot
.61965 .52229 Mdot
.37117 .59774 Mdot
.58582 .54242 Mdot
.49544 .25175 Mdot
.71025 .29658 Mdot
.37888 .62227 Mdot
.40911 .44442 Mdot
.36458 .40582 Mdot
.51659 .68043 Mdot
.53609 .33962 Mdot
.52338 .30502 Mdot
.37762 .43427 Mdot
.57404 .28439 Mdot
.67749 .52887 Mdot
.64453 .48577 Mdot
.77324 .31982 Mdot
.6342 .56061 Mdot
.68303 .62264 Mdot
.4771 .58658 Mdot
.52032 .36697 Mdot
.64665 .5734 Mdot
.61749 .49156 Mdot
.65629 .53426 Mdot
.52766 .23545 Mdot
.39504 .58075 Mdot
.67132 .51157 Mdot
.49156 .66089 Mdot
.30386 .63965 Mdot
.62279 .4828 Mdot
.70231 .55904 Mdot
.52168 .30459 Mdot
.55521 .18056 Mdot
.36742 .395 Mdot
.3572 .61072 Mdot
.35597 .59466 Mdot
.50935 .77469 Mdot
.2983 .31277 Mdot
.47825 .58516 Mdot
.1743 .597 Mdot
.2834 .41936 Mdot
.49359 .66644 Mdot
.36544 .53508 Mdot
.35169 .35708 Mdot
.34996 .5858 Mdot
.33404 .40272 Mdot
.66159 .49372 Mdot
.67681 .52452 Mdot
.37745 .18388 Mdot
.58675 .55241 Mdot
.48162 .68289 Mdot
.32783 .39887 Mdot
.50219 .3584 Mdot
.49486 .70466 Mdot
.39451 .41872 Mdot
.51656 .37144 Mdot
.60072 .46897 Mdot
.6122 .46716 Mdot
.52186 .30803 Mdot
.49402 .31351 Mdot
.60676 .54491 Mdot
.31162 .54069 Mdot
.48409 .34887 Mdot
.50195 .31063 Mdot
.38624 .56581 Mdot
.36244 .54871 Mdot
.65159 .58913 Mdot
.3594 .43167 Mdot
.58667 .50758 Mdot
.36097 .59483 Mdot
.51207 .70105 Mdot
.50653 .34498 Mdot
.59169 .49145 Mdot
.62911 .48758 Mdot
.49044 .69379 Mdot
.51447 .69221 Mdot
.51098 .67636 Mdot
.32661 .43131 Mdot
.64815 .51232 Mdot
.51345 .33432 Mdot
.38474 .414 Mdot
.49088 .64533 Mdot
.48595 .65395 Mdot
.39041 .54239 Mdot
.62751 .56338 Mdot
.36549 .51296 Mdot
.43284 .14836 Mdot
.8106 .40174 Mdot
.36596 .6254 Mdot
.40488 .6179 Mdot
.56327 .66416 Mdot
.46506 .39355 Mdot
.37433 .44178 Mdot
.47392 .72873 Mdot
.74573 .60868 Mdot
.58031 .47727 Mdot
.59435 .48102 Mdot
.60346 .57648 Mdot
.50904 .67315 Mdot
.67798 .6801 Mdot
.5339 .30421 Mdot
.6258 .6162 Mdot
.4767 .70197 Mdot
.32863 .58304 Mdot
.37779 .53283 Mdot
.33771 .59642 Mdot
.63923 .47088 Mdot
.70284 .38694 Mdot
.32138 .28741 Mdot
.61109 .76365 Mdot
.35241 .42895 Mdot
.58926 .59882 Mdot
.22269 .64317 Mdot
.52283 .31332 Mdot
.40942 .58668 Mdot
.49199 .66452 Mdot
.49259 .31637 Mdot
.35296 .44747 Mdot
.35617 .41824 Mdot
.38496 .57046 Mdot
.38047 .5699 Mdot
.34511 .57777 Mdot
.55497 .32078 Mdot
.51808 .36058 Mdot
.65231 .53244 Mdot
.50621 .35021 Mdot
.51598 .19823 Mdot
.45747 .68062 Mdot
.35874 .6358 Mdot
.36414 .43014 Mdot
.50236 .36538 Mdot
.62299 .52256 Mdot
.46388 .37911 Mdot
.31877 .34313 Mdot
.47313 .66984 Mdot
.69495 .27913 Mdot
.35826 .81919 Mdot
.59203 .5469 Mdot
.37062 .40513 Mdot
.59019 .21686 Mdot
.6185 .52689 Mdot
.35453 .56508 Mdot
.36841 .75758 Mdot
.31344 .56008 Mdot
.59178 .53898 Mdot
.57077 .48713 Mdot
.351 .39125 Mdot
.17584 .55923 Mdot
.64699 .53424 Mdot
.43176 .27329 Mdot
.41373 .43217 Mdot
.36168 .55928 Mdot
.65232 .82476 Mdot
.45068 .64161 Mdot
.60921 .70211 Mdot
.38112 .56555 Mdot
.59743 .50734 Mdot
.3832 .55804 Mdot
.4829 .66188 Mdot
.35781 .61554 Mdot
.52762 .29817 Mdot
.33417 .5961 Mdot
.66277 .51434 Mdot
.50862 .32765 Mdot
.36846 .43688 Mdot
.72436 .26975 Mdot
.39258 .75671 Mdot
.38993 .59619 Mdot
.38797 .61854 Mdot
.63644 .57629 Mdot
.43323 .30976 Mdot
.685 .53492 Mdot
.65403 .48732 Mdot
.35338 .43755 Mdot
.53276 .33922 Mdot
.3693 .39139 Mdot
.584 .58322 Mdot
.66711 .71632 Mdot
.39275 .41782 Mdot
.27981 .6449 Mdot
.50142 .68172 Mdot
.48507 .44288 Mdot
.62249 .51768 Mdot
.4002 .43602 Mdot
.64952 .51502 Mdot
.5374 .30679 Mdot
.49402 .47864 Mdot
.28291 .58257 Mdot
.3496 .40749 Mdot
.30802 .7233 Mdot
.61981 .73187 Mdot
.66324 .58901 Mdot
.38077 .40095 Mdot
.66557 .65461 Mdot
.40164 .59855 Mdot
.47055 .68213 Mdot
.47125 .70714 Mdot
.47373 .70132 Mdot
.6934 .5055 Mdot
.58384 .43999 Mdot
.52497 .69088 Mdot
.34625 .44026 Mdot
.46506 .66982 Mdot
.26324 .31747 Mdot
.43761 .8276 Mdot
.49646 .67605 Mdot
.62956 .5421 Mdot
.65316 .44903 Mdot
.56599 .6293 Mdot
.24097 .54297 Mdot
.68031 .757 Mdot
.2255 .44479 Mdot
.59483 .53866 Mdot
.55773 .31158 Mdot
.55034 .31431 Mdot
.59434 .20171 Mdot
.76919 .56197 Mdot
.81809 .43259 Mdot
.50822 .37656 Mdot
.30548 .50871 Mdot
.53126 .35476 Mdot
.57743 .53126 Mdot
.64086 .48375 Mdot
.51302 .37855 Mdot
.68121 .69893 Mdot
.29103 .51696 Mdot
.35028 .78592 Mdot
.49063 .32407 Mdot
.39542 .41446 Mdot
.39575 .40335 Mdot
.34613 .4183 Mdot
.71827 .28317 Mdot
.5337 .32694 Mdot
.63816 .49803 Mdot
.35784 .59845 Mdot
.67426 .52778 Mdot
.38021 .42236 Mdot
.44783 .83732 Mdot
.52382 .33847 Mdot
.63538 .55093 Mdot
.71533 .55898 Mdot
.37437 .56979 Mdot
.4956 .68748 Mdot
.46667 .27841 Mdot
.81428 .44136 Mdot
.33968 .40913 Mdot
.49671 .37182 Mdot
.32767 .37035 Mdot
.36624 .78277 Mdot
.68514 .47691 Mdot
.58803 .46292 Mdot
.35953 .80923 Mdot
.80995 .52548 Mdot
.65529 .55744 Mdot
.36898 .6187 Mdot
.27578 .4829 Mdot
.61681 .48457 Mdot
.54816 .3126 Mdot
.47623 .71377 Mdot
.46669 .68975 Mdot
.65646 .58824 Mdot
.44428 .36505 Mdot
.49885 .51098 Mdot
.62424 .50246 Mdot
.61055 .58269 Mdot
.36802 .56037 Mdot
.28182 .44584 Mdot
.81085 .37222 Mdot
.50764 .70258 Mdot
.58679 .54652 Mdot
.46441 .81099 Mdot
.48888 .31529 Mdot
.35033 .62039 Mdot
.38614 .44981 Mdot
.55549 .36078 Mdot
.35409 .6159 Mdot
.58804 .49067 Mdot
.58657 .55067 Mdot
.38837 .39863 Mdot
.51653 .29056 Mdot
.5082 .67517 Mdot
.36486 .61163 Mdot
.51247 .69097 Mdot
.53023 .33872 Mdot
.51105 .35446 Mdot
.70662 .56654 Mdot
.66462 .46288 Mdot
.39274 .60094 Mdot
.68956 .51876 Mdot
.30617 .57093 Mdot
.22473 .7 Mdot
.31716 .39642 Mdot
.61778 .56508 Mdot
.47559 .33913 Mdot
.34584 .40586 Mdot
.64964 .49435 Mdot
.40611 .84196 Mdot
.62775 .47814 Mdot
.33011 .3829 Mdot
.78186 .58991 Mdot
.51065 .68627 Mdot
.58114 .60669 Mdot
.21814 .58859 Mdot
.62459 .56072 Mdot
.35454 .58348 Mdot
.70307 .50208 Mdot
.39197 .43534 Mdot
.51359 .36126 Mdot
.21709 .70041 Mdot
.3674 .41591 Mdot
.62138 .55599 Mdot
.48835 .70341 Mdot
.47863 .33234 Mdot
.51775 .56773 Mdot
.50966 .58366 Mdot
.70922 .48944 Mdot
.65954 .56084 Mdot
.60966 .49491 Mdot
.62831 .74456 Mdot
.35373 .60613 Mdot
.50139 .31587 Mdot
.36599 .40197 Mdot
.37717 .43745 Mdot
.38918 .57488 Mdot
.37649 .50558 Mdot
.48403 .44341 Mdot
.51972 .14009 Mdot
.39332 .56525 Mdot
.50238 .70844 Mdot
.43359 .29356 Mdot
.35758 .60514 Mdot
.37531 .59664 Mdot
.38436 .56375 Mdot
.46025 .57042 Mdot
.49957 .36085 Mdot
.58942 .48892 Mdot
.53785 .29556 Mdot
.59596 .50624 Mdot
.33724 .38076 Mdot
.351 .41077 Mdot
.52307 .344 Mdot
.31237 .75831 Mdot
.68877 .41568 Mdot
.62011 .53495 Mdot
.22452 .65136 Mdot
.57242 .54714 Mdot
.57475 .63969 Mdot
.58905 .56352 Mdot
.38929 .58754 Mdot
.65887 .47912 Mdot
.69517 .52612 Mdot
.62352 .21215 Mdot
.36255 .43209 Mdot
.3544 .54258 Mdot
.57529 .5633 Mdot
.62033 .58422 Mdot
.55633 .32536 Mdot
.49465 .31454 Mdot
.47106 .70516 Mdot
.67835 .61566 Mdot
.36846 .43945 Mdot
.25979 .29129 Mdot
.59819 .54547 Mdot
.51186 .62854 Mdot
.77348 .40478 Mdot
.65211 .49655 Mdot
.22844 .61851 Mdot
.69627 .37728 Mdot
.62613 .51726 Mdot
.43125 .49148 Mdot
.35708 .4326 Mdot
.70688 .69558 Mdot
.61482 .48016 Mdot
.36745 .56663 Mdot
.52329 .36002 Mdot
.49493 .30469 Mdot
.48298 .71197 Mdot
.41629 .1889 Mdot
.36902 .39053 Mdot
.51845 .35499 Mdot
.61387 .51841 Mdot
.37285 .40483 Mdot
.3968 .57107 Mdot
.63539 .57297 Mdot
.78445 .53177 Mdot
.50205 .35025 Mdot
.60485 .57251 Mdot
.41754 .26029 Mdot
.57694 .6948 Mdot
.7866 .61102 Mdot
.36073 .39958 Mdot
.51562 .67852 Mdot
.69826 .54394 Mdot
.57714 .35219 Mdot
.65414 .57759 Mdot
.62745 .70612 Mdot
.25382 .33003 Mdot
.51151 .66447 Mdot
.61631 .54191 Mdot
.6429 .49784 Mdot
.53612 .42397 Mdot
.50128 .70567 Mdot
.65335 .54917 Mdot
.55363 .38211 Mdot
.49221 .33765 Mdot
.40773 .59242 Mdot
.49936 .35549 Mdot
.62925 .53861 Mdot
.67062 .46483 Mdot
.49525 .30999 Mdot
.23622 .69553 Mdot
.45887 .70261 Mdot
.37756 .40099 Mdot
.56616 .51781 Mdot
.62533 .47154 Mdot
.75292 .25316 Mdot
.34207 .615 Mdot
.29706 .56247 Mdot
.34156 .66619 Mdot
.48529 .79307 Mdot
.44372 .64491 Mdot
.76834 .67291 Mdot
.80934 .53207 Mdot
.62616 .56791 Mdot
.52564 .5452 Mdot
.38435 .24834 Mdot
.35644 .43657 Mdot
.35444 .22482 Mdot
.59684 .54521 Mdot
.60626 .52495 Mdot
.37489 .62758 Mdot
.27301 .58111 Mdot
.81919 .42755 Mdot
.45657 .36455 Mdot
.50808 .6782 Mdot
.54598 .32019 Mdot
.58485 .49224 Mdot
.45005 .50412 Mdot
.32826 .59087 Mdot
.47278 .63831 Mdot
.63082 .55064 Mdot
.55111 .22916 Mdot
.33173 .33383 Mdot
.38402 .41786 Mdot
.35506 .59247 Mdot
.81384 .46045 Mdot
.61805 .5631 Mdot
.39796 .44494 Mdot
.63734 .53308 Mdot
.44566 .62666 Mdot
.5757 .5764 Mdot
.49059 .66826 Mdot
.59923 .49004 Mdot
.43583 .65392 Mdot
.84979 .37634 Mdot
.53052 .68048 Mdot
.55834 .34212 Mdot
.32811 .60661 Mdot
.3961 .58323 Mdot
.49809 .31052 Mdot
.39538 .58981 Mdot
.68035 .333 Mdot
.76187 .49645 Mdot
.50364 .68157 Mdot
.65686 .58476 Mdot
.49365 .68015 Mdot
.35634 .62502 Mdot
.59375 .53985 Mdot
.28096 .7643 Mdot
.38704 .60894 Mdot
.82183 .51302 Mdot
.37027 .42317 Mdot
.32834 .59601 Mdot
.61972 .47978 Mdot
.31417 .36999 Mdot
.37573 .54882 Mdot
.29116 .54454 Mdot
.65582 .534 Mdot
.50576 .35699 Mdot
.62263 .48694 Mdot
.56832 .5063 Mdot
.33339 .5635 Mdot
.58732 .51379 Mdot
.39505 .41991 Mdot
.5141 .37603 Mdot
.6413 .79543 Mdot
.27045 .34531 Mdot
.65178 .55258 Mdot
.61514 .52084 Mdot
.49983 .28736 Mdot
.64487 .47587 Mdot
.33749 .40152 Mdot
.10745 .44549 Mdot
.50108 .68223 Mdot
.33402 .55032 Mdot
.42926 .65513 Mdot
.59152 .47316 Mdot
.58117 .51473 Mdot
.44195 .86097 Mdot
.65836 .71757 Mdot
.38711 .4065 Mdot
.68882 .54321 Mdot
.39289 .56141 Mdot
.47916 .69593 Mdot
.33681 .42752 Mdot
.6294 .51145 Mdot
.60933 .53797 Mdot
.51733 .68529 Mdot
.54234 .63408 Mdot
.75882 .32625 Mdot
.40303 .42224 Mdot
.56421 .47009 Mdot
.4211 .62574 Mdot
.67857 .53259 Mdot
.69004 .26559 Mdot
.50952 .30775 Mdot
.3394 .41257 Mdot
.50835 .78334 Mdot
.621 .56467 Mdot
.38587 .40079 Mdot
.36717 .4388 Mdot
.65918 .57075 Mdot
.48091 .36762 Mdot
.5209 .37448 Mdot
.48996 .33705 Mdot
.29809 .21413 Mdot
.61818 .68542 Mdot
.34512 .57764 Mdot
.35808 .43485 Mdot
.39231 .61779 Mdot
.53417 .68486 Mdot
.48221 .55484 Mdot
.387 .62027 Mdot
.49146 .35017 Mdot
.32518 .57285 Mdot
.65392 .51213 Mdot
.36996 .43854 Mdot
.34954 .58113 Mdot
.57221 .49695 Mdot
.43929 .34529 Mdot
.2223 .51012 Mdot
.49227 .65634 Mdot
.48449 .71755 Mdot
.63322 .48274 Mdot
.41391 .59987 Mdot
.60514 .5419 Mdot
.38169 .45335 Mdot
.4402 .32043 Mdot
.56863 .51138 Mdot
.39162 .593 Mdot
.49352 .29464 Mdot
.81269 .45367 Mdot
.67602 .48396 Mdot
.62772 .5421 Mdot
.592 .51014 Mdot
.63799 .5329 Mdot
.36431 .77518 Mdot
.38833 .39336 Mdot
.24117 .37544 Mdot
.51176 .76768 Mdot
.52398 .33268 Mdot
.53588 .28999 Mdot
.80496 .37548 Mdot
.37657 .25867 Mdot
.35864 .43159 Mdot
.61196 .50188 Mdot
.33788 .3107 Mdot
.52148 .85329 Mdot
.33518 .79042 Mdot
.58464 .42413 Mdot
.34039 .61496 Mdot
.49743 .37172 Mdot
.3988 .60087 Mdot
.59635 .51248 Mdot
.62252 .58281 Mdot
.79948 .63669 Mdot
.35618 .44633 Mdot
.50338 .67575 Mdot
.59486 .50475 Mdot
.61398 .68934 Mdot
.36258 .59123 Mdot
.32749 .59438 Mdot
.66334 .50035 Mdot
.49702 .29598 Mdot
.83772 .36893 Mdot
.37758 .41047 Mdot
.24091 .41248 Mdot
.30848 .27474 Mdot
.3543 .34163 Mdot
.38039 .4192 Mdot
.54118 .43535 Mdot
.35562 .62213 Mdot
.76263 .37583 Mdot
.52701 .3256 Mdot
.469 .68097 Mdot
.55735 .52728 Mdot
.5104 .30131 Mdot
.33783 .57834 Mdot
.51004 .35998 Mdot
.57976 .51503 Mdot
.41196 .41722 Mdot
.36519 .58202 Mdot
.2986 .43009 Mdot
.47559 .33642 Mdot
.49817 .70563 Mdot
.45193 .40439 Mdot
.65616 .4261 Mdot
.69431 .37329 Mdot
.6678 .50556 Mdot
.45007 .51281 Mdot
.63863 .50034 Mdot
.52831 .27974 Mdot
.62709 .52613 Mdot
.48909 .28685 Mdot
.35558 .58295 Mdot
.60369 .47964 Mdot
.62041 .50063 Mdot
.20066 .38189 Mdot
.65126 .54624 Mdot
.68142 .53775 Mdot
.62402 .51377 Mdot
.5356 .26291 Mdot
.66915 .58017 Mdot
.5436 .34396 Mdot
.30954 .66781 Mdot
.37802 .59451 Mdot
.46446 .68947 Mdot
.51788 .67695 Mdot
.65332 .68297 Mdot
.44242 .72226 Mdot
.26111 .58672 Mdot
.49614 .34247 Mdot
.39574 .43581 Mdot
.63216 .52833 Mdot
.72819 .71728 Mdot
.39967 .64604 Mdot
.32968 .58483 Mdot
.27147 .34607 Mdot
.5458 .51306 Mdot
.72728 .68209 Mdot
.68411 .54847 Mdot
.35044 .1965 Mdot
.63543 .45826 Mdot
.55221 .52759 Mdot
.40199 .5735 Mdot
.52065 .64118 Mdot
.64181 .47674 Mdot
.55256 .33862 Mdot
.47649 .67357 Mdot
.57083 .45052 Mdot
.39713 .53311 Mdot
.29683 .62796 Mdot
.48633 .27681 Mdot
.65218 .52343 Mdot
.36636 .58175 Mdot
.5391 .34042 Mdot
.81503 .3885 Mdot
.38346 .41171 Mdot
.38469 .50872 Mdot
.44477 .24428 Mdot
.24183 .69261 Mdot
.48171 .70485 Mdot
.71808 .31781 Mdot
.66048 .51278 Mdot
.33929 .72733 Mdot
.5672 .51758 Mdot
.46347 .84589 Mdot
.52114 .6936 Mdot
.49227 .35527 Mdot
.39788 .41951 Mdot
.54695 .31084 Mdot
.68011 .36524 Mdot
.40793 .55033 Mdot
.47189 .4794 Mdot
.36749 .60146 Mdot
.50179 .53214 Mdot
.50651 .32038 Mdot
.58366 .53796 Mdot
.51373 .13813 Mdot
.50437 .3092 Mdot
.47819 .33926 Mdot
.17603 .49578 Mdot
.25182 .733 Mdot
.60121 .45789 Mdot
.48386 .35088 Mdot
.37289 .60312 Mdot
.48118 .67669 Mdot
.60781 .48433 Mdot
.65612 .52231 Mdot
.51387 .30176 Mdot
.3392 .55353 Mdot
.61675 .37194 Mdot
.38436 .5746 Mdot
.49737 .35825 Mdot
.37975 .58295 Mdot
.35058 .36625 Mdot
.36103 .61212 Mdot
.62589 .47128 Mdot
.62846 .52664 Mdot
.40399 .67958 Mdot
.51022 .35463 Mdot
.62601 .503 Mdot
.63431 .57634 Mdot
.51114 .33477 Mdot
.52263 .47872 Mdot
.62577 .37045 Mdot
.66319 .54875 Mdot
.65597 .53966 Mdot
.51425 .67093 Mdot
.47095 .53568 Mdot
.70368 .29457 Mdot
.58376 .50763 Mdot
.51855 .66827 Mdot
.54746 .34691 Mdot
.61442 .55034 Mdot
.52069 .83143 Mdot
.27739 .48747 Mdot
.59425 .54762 Mdot
.40106 .59978 Mdot
.69303 .53283 Mdot
.79255 .5958 Mdot
.65249 .48561 Mdot
.50486 .33278 Mdot
.52576 .35016 Mdot
.24197 .31536 Mdot
.51621 .31848 Mdot
.35737 .55112 Mdot
.37878 .4221 Mdot
.36001 .78254 Mdot
.39995 .58146 Mdot
.6638 .46876 Mdot
.16567 .40909 Mdot
.61021 .56994 Mdot
.59579 .47514 Mdot
.83821 .48006 Mdot
.39454 .60539 Mdot
.53947 .31971 Mdot
.46684 .40858 Mdot
.64542 .45458 Mdot
.34127 .41374 Mdot
.57409 .56768 Mdot
.6617 .49265 Mdot
.80031 .56622 Mdot
.37217 .77496 Mdot
.3983 .44743 Mdot
.68123 .53616 Mdot
.58249 .51031 Mdot
.38304 .6342 Mdot
.6187 .51902 Mdot
.48428 .67333 Mdot
.53418 .32936 Mdot
.36862 .61664 Mdot
.49197 .69597 Mdot
.6122 .5598 Mdot
.51013 .67595 Mdot
.35489 .57119 Mdot
.37483 .45175 Mdot
.5931 .52336 Mdot
.47628 .65418 Mdot
.50952 .67794 Mdot
.63701 .50185 Mdot
.51505 .36331 Mdot
.54255 .51002 Mdot
.64855 .54862 Mdot
.59073 .49305 Mdot
.52504 .30556 Mdot
.62482 .85137 Mdot
.64368 .48432 Mdot
.63438 .70983 Mdot
.50831 .29803 Mdot
.50698 .51599 Mdot
.40379 .5849 Mdot
.65618 .48456 Mdot
.37482 .45204 Mdot
.38323 .44911 Mdot
.33655 .59613 Mdot
.49098 .36901 Mdot
.35301 .66496 Mdot
.49649 .38352 Mdot
.7014 .51232 Mdot
.68315 .5262 Mdot
.56797 .39087 Mdot
.70881 .74242 Mdot
.53771 .3005 Mdot
.41692 .54824 Mdot
.44849 .35456 Mdot
.3972 .44055 Mdot
.3353 .56488 Mdot
.51042 .37851 Mdot
.53239 .30604 Mdot
.51711 .36791 Mdot
.46841 .67883 Mdot
.40737 .68241 Mdot
.51074 .293 Mdot
.50568 .28925 Mdot
.65896 .52835 Mdot
.58673 .50359 Mdot
.80511 .49424 Mdot
.78949 .4833 Mdot
.50288 .66286 Mdot
.34714 .56681 Mdot
.27606 .21915 Mdot
.36702 .45115 Mdot
.21667 .38751 Mdot
.59314 .47946 Mdot
.3332 .16309 Mdot
.61503 .48147 Mdot
.61398 .51594 Mdot
.51627 .37657 Mdot
.47882 .65461 Mdot
.49678 .68135 Mdot
.50254 .31396 Mdot
.52003 .28365 Mdot
.48611 .67291 Mdot
.20972 .58956 Mdot
.54091 .83761 Mdot
.30414 .59139 Mdot
.51367 .34007 Mdot
.73104 .47103 Mdot
.39861 .41118 Mdot
.62948 .44152 Mdot
.40953 .43804 Mdot
.36812 .59469 Mdot
.35879 .62002 Mdot
.34226 .40829 Mdot
.65325 .53563 Mdot
.3449 .58509 Mdot
.61454 .56641 Mdot
.2109 .47309 Mdot
.69266 .39704 Mdot
.39626 .65711 Mdot
.69516 .46608 Mdot
.52514 .46795 Mdot
.29895 .43432 Mdot
.61109 .5554 Mdot
.50241 .80992 Mdot
.50567 .67846 Mdot
.705 .50815 Mdot
.33977 .41757 Mdot
.84084 .50241 Mdot
.59162 .53144 Mdot
.50409 .33715 Mdot
.36434 .43869 Mdot
.4636 .22545 Mdot
.43601 .27637 Mdot
.59372 .50793 Mdot
.44936 .15199 Mdot
.55347 .27766 Mdot
.35483 .60065 Mdot
.53579 .22656 Mdot
.52767 .29048 Mdot
.44337 .66747 Mdot
.53339 .78135 Mdot
.28564 .73708 Mdot
.54042 .32781 Mdot
.3587 .62847 Mdot
.53852 .35497 Mdot
.49052 .70567 Mdot
.55829 .33721 Mdot
.35955 .5862 Mdot
.62722 .54898 Mdot
.39138 .58123 Mdot
.46958 .67227 Mdot
.763 .33753 Mdot
.39842 .44709 Mdot
.36608 .54244 Mdot
.35585 .40737 Mdot
.55896 .7076 Mdot
.60577 .75272 Mdot
.37177 .39905 Mdot
.61574 .31476 Mdot
.68219 .51986 Mdot
.52032 .28994 Mdot
.39069 .57169 Mdot
.45098 .76778 Mdot
.45203 .39644 Mdot
.52565 .32174 Mdot
.3406 .57821 Mdot
.45163 .27306 Mdot
.58204 .28933 Mdot
.68379 .535 Mdot
.5539 .62558 Mdot
.51491 .33597 Mdot
.36664 .62861 Mdot
.76536 .3069 Mdot
.54167 .35114 Mdot
.39038 .56118 Mdot
.39402 .41041 Mdot
.38076 .43586 Mdot
.67156 .5312 Mdot
.39041 .38818 Mdot
.34215 .59829 Mdot
.35086 .47247 Mdot
.48438 .35421 Mdot
.48743 .22257 Mdot
.46395 .66255 Mdot
.3839 .58996 Mdot
.59493 .56328 Mdot
.53565 .27708 Mdot
.26929 .44235 Mdot
.62905 .38535 Mdot
.54731 .17146 Mdot
.38913 .57515 Mdot
.53397 .32227 Mdot
.50372 .34111 Mdot
.67801 .48422 Mdot
.46548 .26583 Mdot
.354 .6694 Mdot
.55313 .41784 Mdot
.52392 .41467 Mdot
.40851 .59056 Mdot
.34196 .53059 Mdot
.57623 .5655 Mdot
.64795 .52712 Mdot
.39871 .43626 Mdot
.63046 .54755 Mdot
.49779 .36791 Mdot
.667 .50548 Mdot
.3669 .40332 Mdot
.3658 .60478 Mdot
.59352 .52818 Mdot
.51183 .68101 Mdot
.37934 .39042 Mdot
.35168 .44833 Mdot
.38707 .59392 Mdot
.51452 .30101 Mdot
.51077 .53883 Mdot
.37864 .56836 Mdot
.65232 .52456 Mdot
.46757 .55387 Mdot
.57798 .51647 Mdot
.55248 .58321 Mdot
.54771 .34153 Mdot
.37048 .61672 Mdot
.52361 .37844 Mdot
.36126 .41302 Mdot
.51338 .76921 Mdot
.6271 .53439 Mdot
.39404 .56634 Mdot
.30442 .46617 Mdot
.54577 .58622 Mdot
.47706 .32089 Mdot
.22627 .57035 Mdot
.53643 .28756 Mdot
.35108 .56242 Mdot
.18292 .41931 Mdot
.47095 .69237 Mdot
.32924 .58783 Mdot
.66683 .77575 Mdot
.38765 .60539 Mdot
.67098 .52258 Mdot
.63729 .48469 Mdot
.36297 .6131 Mdot
.51651 .6784 Mdot
.82682 .42351 Mdot
.31662 .56685 Mdot
.53917 .32363 Mdot
.19561 .50968 Mdot
.63237 .19476 Mdot
.30667 .42663 Mdot
.39727 .43701 Mdot
.60839 .45344 Mdot
.67392 .5 Mdot
.34173 .42584 Mdot
.39711 .45301 Mdot
.47141 .70288 Mdot
.38161 .55885 Mdot
.5346 .2732 Mdot
.33335 .43518 Mdot
.47992 .26981 Mdot
.43225 .70749 Mdot
.67633 .4854 Mdot
.29914 .28662 Mdot
.59164 .48235 Mdot
.5724 .75424 Mdot
.36408 .40142 Mdot
.57581 .53397 Mdot
.68795 .53412 Mdot
.35684 .44078 Mdot
.47993 .67613 Mdot
.38322 .5107 Mdot
.37573 .58206 Mdot
.63547 .83621 Mdot
.63426 .56985 Mdot
.66657 .50962 Mdot
.35038 .42455 Mdot
.35373 .71199 Mdot
.52646 .33403 Mdot
.54618 .29986 Mdot
.35413 .60626 Mdot
.44147 .41748 Mdot
.67681 .51864 Mdot
.61875 .55421 Mdot
.36942 .57748 Mdot
.3518 .5504 Mdot
.25344 .56391 Mdot
.64616 .49764 Mdot
.36232 .42804 Mdot
.53828 .66116 Mdot
.35806 .39981 Mdot
.57722 .52401 Mdot
.66326 .50663 Mdot
.62569 .47085 Mdot
.58834 .55495 Mdot
.41276 .4376 Mdot
.57355 .514 Mdot
.65372 .58203 Mdot
.53143 .32161 Mdot
.59233 .5026 Mdot
.51004 .41216 Mdot
.63689 .54404 Mdot
.48312 .67519 Mdot
.66964 .2709 Mdot
.59175 .53053 Mdot
.66527 .49987 Mdot
.32819 .55858 Mdot
.61477 .53627 Mdot
.37749 .45395 Mdot
.51448 .3485 Mdot
.35584 .43053 Mdot
.3849 .44924 Mdot
.39363 .62253 Mdot
.50851 .70718 Mdot
.58862 .47386 Mdot
.48197 .66333 Mdot
.67398 .47247 Mdot
.62223 .56493 Mdot
.4626 .73588 Mdot
.32993 .20538 Mdot
.72909 .29359 Mdot
.62931 .53524 Mdot
.3911 .60769 Mdot
.39864 .60243 Mdot
.52322 .52199 Mdot
.67405 .5491 Mdot
.33111 .41173 Mdot
.3951 .44433 Mdot
.77153 .55467 Mdot
.72724 .64597 Mdot
.48243 .67518 Mdot
.46891 .51795 Mdot
.65484 .5597 Mdot
.57867 .53794 Mdot
.62982 .5725 Mdot
.38397 .62205 Mdot
.63929 .43036 Mdot
.33196 .57355 Mdot
.30406 .34452 Mdot
.34604 .41029 Mdot
.59119 .51856 Mdot
.27993 .3163 Mdot
.48857 .32597 Mdot
.51363 .34927 Mdot
.34356 .44196 Mdot
.42044 .61222 Mdot
.80744 .44637 Mdot
.33806 .79833 Mdot
.56487 .32712 Mdot
.47172 .66172 Mdot
.62195 .55844 Mdot
.37335 .6086 Mdot
.49872 .36166 Mdot
.47233 .66192 Mdot
.58516 .53464 Mdot
.40907 .68298 Mdot
.63718 .5366 Mdot
.35593 .26167 Mdot
.52801 .35854 Mdot
.4924 .85266 Mdot
.48785 .3673 Mdot
.36984 .38575 Mdot
.33719 .40827 Mdot
.65008 .49573 Mdot
.5744 .33613 Mdot
.53104 .28926 Mdot
.44197 .56821 Mdot
.50094 .7087 Mdot
.30145 .38394 Mdot
.47603 .69508 Mdot
.35324 .59268 Mdot
.47202 .68139 Mdot
.35832 .58398 Mdot
.80052 .43297 Mdot
.52777 .25754 Mdot
.49813 .69089 Mdot
.30129 .4562 Mdot
.67042 .49492 Mdot
.50265 .66124 Mdot
.62521 .58237 Mdot
.53986 .56225 Mdot
.37144 .57569 Mdot
.49755 .708 Mdot
.58573 .54467 Mdot
.76362 .66573 Mdot
.38099 .40207 Mdot
.33253 .41092 Mdot
.62611 .58203 Mdot
.40871 .60053 Mdot
.54162 .35885 Mdot
.43527 .81981 Mdot
.32192 .40883 Mdot
.64604 .488 Mdot
.64319 .47636 Mdot
.53123 .28705 Mdot
.2426 .33862 Mdot
.65664 .50306 Mdot
.64903 .59896 Mdot
.64561 .49513 Mdot
.35919 .39174 Mdot
.54688 .314 Mdot
.50726 .34601 Mdot
.34121 .57956 Mdot
.48549 .32586 Mdot
.53844 .61237 Mdot
.29728 .32124 Mdot
.56228 .56746 Mdot
.36609 .41277 Mdot
.32581 .3303 Mdot
.29582 .34736 Mdot
.67332 .75975 Mdot
.47459 .3384 Mdot
.56985 .51054 Mdot
.48551 .32066 Mdot
.47721 .69167 Mdot
.50406 .35464 Mdot
.49777 .37186 Mdot
.60385 .54441 Mdot
.59777 .5071 Mdot
.36061 .60353 Mdot
.45729 .27897 Mdot
.51286 .29866 Mdot
.61502 .48221 Mdot
.65085 .47438 Mdot
.60684 .56583 Mdot
.45601 .58126 Mdot
.54227 .30598 Mdot
.17811 .56662 Mdot
.67193 .63798 Mdot
.51373 .29894 Mdot
.84466 .39619 Mdot
.29263 .45902 Mdot
.40144 .5461 Mdot
.41077 .5263 Mdot
.64191 .493 Mdot
.37448 .54655 Mdot
.59607 .51332 Mdot
.30028 .28702 Mdot
.60809 .53292 Mdot
.48384 .67221 Mdot
.62607 .568 Mdot
.34843 .61459 Mdot
.38518 .57382 Mdot
.65194 .49033 Mdot
.59515 .52557 Mdot
.78219 .35868 Mdot
.5541 .35573 Mdot
.51666 .35326 Mdot
.34686 .65926 Mdot
.5013 .6949 Mdot
.3401 .41242 Mdot
.62524 .51907 Mdot
.39139 .62252 Mdot
.38722 .57563 Mdot
.53449 .29466 Mdot
.35981 .56411 Mdot
.3787 .41217 Mdot
.62487 .53087 Mdot
.33821 .42145 Mdot
.46689 .68568 Mdot
.5454 .31224 Mdot
.59281 .50469 Mdot
.65899 .52883 Mdot
.52605 .34984 Mdot
.56504 .50911 Mdot
.51519 .67919 Mdot
.39148 .60071 Mdot
.5413 .32954 Mdot
.37994 .42661 Mdot
.35405 .59031 Mdot
.5873 .49429 Mdot
.41092 .16983 Mdot
.66818 .52987 Mdot
.63065 .48888 Mdot
.70211 .76045 Mdot
.64978 .56291 Mdot
.38941 .57263 Mdot
.49568 .35982 Mdot
.71309 .5265 Mdot
.64547 .66973 Mdot
.567 .88702 Mdot
.33092 .57871 Mdot
.62967 .55741 Mdot
.70695 .72563 Mdot
.63208 .55464 Mdot
.63828 .40997 Mdot
.36951 .53901 Mdot
.5095 .4558 Mdot
.58169 .5535 Mdot
.38979 .43139 Mdot
.3646 .60998 Mdot
.35736 .57952 Mdot
.20013 .47655 Mdot
.60787 .54931 Mdot
.43866 .52152 Mdot
.58185 .52673 Mdot
.3826 .42778 Mdot
.74076 .5981 Mdot
.38548 .57215 Mdot
.59025 .19529 Mdot
.64059 .50046 Mdot
.53291 .30317 Mdot
.32405 .57989 Mdot
.35534 .36103 Mdot
.59394 .48992 Mdot
.4974 .66477 Mdot
.37571 .46208 Mdot
.57917 .57681 Mdot
.36955 .41269 Mdot
.58898 .49577 Mdot
.72422 .51577 Mdot
.47528 .19974 Mdot
.51532 .36583 Mdot
.39868 .42129 Mdot
.47328 .57005 Mdot
.571 .51605 Mdot
.5402 .32964 Mdot
.52725 .32376 Mdot
.46672 .68069 Mdot
.4909 .50071 Mdot
.42215 .25469 Mdot
.71531 .43211 Mdot
.19672 .49338 Mdot
.32768 .56787 Mdot
.28782 .56801 Mdot
.62276 .49211 Mdot
.52441 .61544 Mdot
.38304 .45251 Mdot
.66748 .53329 Mdot
.71444 .32126 Mdot
.49406 .3188 Mdot
.6651 .52958 Mdot
.49299 .6788 Mdot
.47006 .62854 Mdot
.53842 .65231 Mdot
.57937 .78513 Mdot
.36768 .59988 Mdot
.66178 .57859 Mdot
.71568 .54395 Mdot
.40525 .58602 Mdot
.63335 .46656 Mdot
.39557 .57373 Mdot
.22191 .63279 Mdot
.49358 .65721 Mdot
.54136 .30971 Mdot
.29483 .40511 Mdot
.60618 .46661 Mdot
.67345 .50459 Mdot
.49997 .71244 Mdot
.64659 .52291 Mdot
.43667 .18817 Mdot
.45688 .58799 Mdot
.34834 .58619 Mdot
.5164 .36748 Mdot
.63798 .47022 Mdot
.48546 .55665 Mdot
.64004 .55107 Mdot
.76096 .43689 Mdot
.66356 .49728 Mdot
.44152 .26491 Mdot
.52213 .36114 Mdot
.36397 .40793 Mdot
.57147 .53036 Mdot
.60934 .52587 Mdot
.68573 .68078 Mdot
.64888 .46098 Mdot
.57259 .52733 Mdot
.46898 .35818 Mdot
.50824 .36998 Mdot
.53936 .35198 Mdot
.33386 .58926 Mdot
.76082 .6137 Mdot
.3623 .42197 Mdot
.70987 .4988 Mdot
.32528 .4101 Mdot
.59526 .38243 Mdot
.47761 .65836 Mdot
.64058 .75666 Mdot
.6218 .50656 Mdot
.49398 .3427 Mdot
.43677 .80029 Mdot
.55478 .31864 Mdot
.45889 .50461 Mdot
.3687 .43935 Mdot
.50448 .31096 Mdot
.61116 .51886 Mdot
.4491 .37434 Mdot
.72668 .70973 Mdot
.35557 .41793 Mdot
.66355 .46961 Mdot
.33576 .6047 Mdot
.42573 .65039 Mdot
.51599 .18949 Mdot
.37849 .39972 Mdot
.3189 .38894 Mdot
.60926 .55164 Mdot
.48622 .33412 Mdot
.38784 .42831 Mdot
.35781 .39292 Mdot
.35593 .56542 Mdot
.59894 .50399 Mdot
.60188 .50023 Mdot
.34713 .56413 Mdot
.35411 .42851 Mdot
.65571 .57811 Mdot
.57922 .58 Mdot
.82628 .58816 Mdot
.45982 .24921 Mdot
.64315 .83729 Mdot
.5215 .54037 Mdot
.6738 .29462 Mdot
.43601 .82402 Mdot
.52143 .29813 Mdot
.60166 .55533 Mdot
.55381 .51905 Mdot
.34178 .59823 Mdot
.62237 .54124 Mdot
.39839 .55209 Mdot
.37144 .44625 Mdot
.83794 .50325 Mdot
.37754 .3163 Mdot
.2516 .68728 Mdot
.62006 .54188 Mdot
.47645 .30954 Mdot
.4817 .6914 Mdot
.30918 .40271 Mdot
.54938 .32655 Mdot
.60424 .56949 Mdot
.77854 .35418 Mdot
.32931 .58377 Mdot
.52089 .31074 Mdot
.81503 .39365 Mdot
.53399 .44371 Mdot
.57833 .51759 Mdot
.33544 .57385 Mdot
.48066 .8178 Mdot
.53184 .24323 Mdot
.32878 .39523 Mdot
.47916 .67565 Mdot
.36973 .61469 Mdot
.39791 .44258 Mdot
.51454 .27036 Mdot
.51287 .31331 Mdot
.55191 .34365 Mdot
.7164 .29148 Mdot
.34651 .54262 Mdot
.48469 .69277 Mdot
.71737 .67844 Mdot
.71005 .66179 Mdot
.48845 .67183 Mdot
.35806 .62012 Mdot
.50455 .36789 Mdot
.49822 .31889 Mdot
.51471 .3478 Mdot
.66813 .2394 Mdot
.48171 .32405 Mdot
.1945 .43176 Mdot
.59885 .56201 Mdot
.5927 .59246 Mdot
.62692 .55672 Mdot
.33231 .41729 Mdot
.53113 .34769 Mdot
.45775 .41102 Mdot
.69099 .48977 Mdot
.6448 .74026 Mdot
.67185 .52691 Mdot
.40034 .40281 Mdot
.66329 .52168 Mdot
.30401 .26175 Mdot
.49064 .31208 Mdot
.62658 .53745 Mdot
.40847 .42633 Mdot
.50311 .69725 Mdot
.47593 .32266 Mdot
.59222 .50968 Mdot
.24605 .60983 Mdot
.64106 .56591 Mdot
.25207 .67639 Mdot
.43843 .22069 Mdot
.47314 .66068 Mdot
.35289 .24234 Mdot
.35086 .62754 Mdot
.62712 .59964 Mdot
.66142 .45797 Mdot
.35587 .41182 Mdot
.30208 .38963 Mdot
.37716 .59674 Mdot
.59712 .42458 Mdot
.625 .59044 Mdot
.46539 .68044 Mdot
.54372 .25654 Mdot
.34519 .43206 Mdot
.64036 .46906 Mdot
.68911 .52581 Mdot
.23567 .40273 Mdot
.62446 .58618 Mdot
.65202 .48209 Mdot
.50218 .71514 Mdot
.20851 .40741 Mdot
.64196 .54217 Mdot
.4643 .50941 Mdot
.55775 .33994 Mdot
.70067 .50379 Mdot
.19636 .41886 Mdot
.63401 .48319 Mdot
.51474 .30717 Mdot
.61236 .60452 Mdot
.40783 .24911 Mdot
.51091 .70555 Mdot
.66454 .49816 Mdot
.23304 .3275 Mdot
.64621 .50888 Mdot
.36561 .42645 Mdot
.67574 .5459 Mdot
.36141 .58838 Mdot
.72909 .28739 Mdot
.34159 .58644 Mdot
.67263 .53737 Mdot
.51546 .34434 Mdot
.34788 .41792 Mdot
.62148 .22467 Mdot
.38048 .68671 Mdot
.22647 .38142 Mdot
.34611 .79261 Mdot
.50688 .70472 Mdot
.48872 .64463 Mdot
.35809 .44561 Mdot
.62879 .53824 Mdot
.1701 .46749 Mdot
.62589 .45582 Mdot
.65815 .53751 Mdot
.60699 .53212 Mdot
.5987 .75355 Mdot
.38005 .4485 Mdot
.37592 .57313 Mdot
.6599 .50489 Mdot
.57251 .51926 Mdot
.52528 .30011 Mdot
.50687 .68869 Mdot
.40367 .58631 Mdot
.50257 .6806 Mdot
.36863 .61074 Mdot
.84212 .45052 Mdot
.6741 .56123 Mdot
.49946 .70105 Mdot
.35533 .45483 Mdot
.51964 .3033 Mdot
.30522 .31789 Mdot
.35404 .5842 Mdot
.33638 .58917 Mdot
.65579 .49107 Mdot
.51045 .30577 Mdot
.5193 .37775 Mdot
.48084 .69935 Mdot
.37472 .40301 Mdot
.59208 .53161 Mdot
.63636 .5639 Mdot
.72403 .55946 Mdot
.40607 .61088 Mdot
.3461 .26482 Mdot
.27817 .59666 Mdot
.63097 .53679 Mdot
.48526 .35486 Mdot
.59833 .52977 Mdot
.32284 .73746 Mdot
.48647 .32821 Mdot
.62751 .48168 Mdot
.82026 .35053 Mdot
.4218 .57429 Mdot
.37512 .27783 Mdot
.63561 .47532 Mdot
.42732 .84099 Mdot
.62288 .49785 Mdot
.84573 .50439 Mdot
.41775 .77383 Mdot
.68 .52941 Mdot
.5961 .4861 Mdot
.6621 .38404 Mdot
.63018 .56096 Mdot
.34303 .56883 Mdot
.81191 .5149 Mdot
.55527 .33323 Mdot
.28984 .36726 Mdot
.68039 .28184 Mdot
.51804 .69742 Mdot
.35434 .60639 Mdot
.35218 .53007 Mdot
.49649 .67271 Mdot
.51159 .33914 Mdot
.63804 .53272 Mdot
.44372 .45414 Mdot
.40536 .60602 Mdot
.55223 .45784 Mdot
.36696 .42883 Mdot
.26256 .49092 Mdot
.4892 .61656 Mdot
.37337 .41298 Mdot
.59395 .49968 Mdot
.64517 .37919 Mdot
.78637 .42188 Mdot
.58117 .8322 Mdot
.40145 .43574 Mdot
.3536 .41707 Mdot
.69945 .25973 Mdot
.45935 .68316 Mdot
.23745 .41006 Mdot
.43975 .27102 Mdot
.34328 .4154 Mdot
.55924 .27157 Mdot
.34953 .55619 Mdot
.41445 .40218 Mdot
.70131 .54203 Mdot
.60859 .56285 Mdot
.61098 .52112 Mdot
.36577 .39861 Mdot
.53702 .57609 Mdot
.52188 .21482 Mdot
.35408 .40611 Mdot
.58587 .45248 Mdot
.49097 .45962 Mdot
.32673 .51421 Mdot
.36882 .56087 Mdot
.49401 .71113 Mdot
.46095 .65935 Mdot
.53606 .31056 Mdot
.50096 .70996 Mdot
.50094 .6233 Mdot
.63965 .52199 Mdot
.35115 .40162 Mdot
.27717 .41746 Mdot
.37838 .43295 Mdot
.49792 .67628 Mdot
.46561 .69798 Mdot
.53115 .32254 Mdot
.51215 .35622 Mdot
.66035 .31581 Mdot
.59301 .63607 Mdot
.65376 .54777 Mdot
.46946 .76076 Mdot
.50289 .37493 Mdot
.53686 .47276 Mdot
.49541 .71162 Mdot
.50341 .69482 Mdot
.67335 .69302 Mdot
.61844 .50802 Mdot
.57 .39882 Mdot
.62074 .51255 Mdot
.70461 .61571 Mdot
.60075 .4771 Mdot
.35672 .5649 Mdot
.61341 .50147 Mdot
.6734 .70067 Mdot
.57313 .48443 Mdot
.67675 .49857 Mdot
.38715 .62237 Mdot
.60078 .58936 Mdot
.36318 .58804 Mdot
.66602 .54301 Mdot
.48533 .65053 Mdot
.35116 .6062 Mdot
.63021 .6816 Mdot
.65086 .70678 Mdot
.35941 .62202 Mdot
.47517 .66521 Mdot
.52075 .67751 Mdot
.59973 .7096 Mdot
.54953 .32569 Mdot
.61882 .4475 Mdot
.6273 .54022 Mdot
.34068 .5571 Mdot
.39247 .44386 Mdot
.5917 .48675 Mdot
.66067 .48551 Mdot
.62008 .47515 Mdot
.53601 .30883 Mdot
.35994 .67131 Mdot
.49588 .70403 Mdot
.34696 .56218 Mdot
.50968 .54547 Mdot
.40956 .59331 Mdot
.69018 .51564 Mdot
.55517 .51525 Mdot
.69788 .30114 Mdot
.32419 .49805 Mdot
.66314 .22981 Mdot
.51454 .31341 Mdot
.39964 .60282 Mdot
.4668 .65853 Mdot
.55844 .50105 Mdot
.49263 .34286 Mdot
.3601 .58626 Mdot
.63639 .53614 Mdot
.65189 .46591 Mdot
.28538 .3443 Mdot
.54717 .65336 Mdot
.64267 .69885 Mdot
.33727 .59902 Mdot
.33992 .61548 Mdot
.63694 .725 Mdot
.52349 .64986 Mdot
.4529 .40006 Mdot
.61751 .54985 Mdot
.49806 .66579 Mdot
.49646 .35849 Mdot
.73284 .31627 Mdot
.34436 .39768 Mdot
.4639 .26945 Mdot
.6201 .54029 Mdot
.51903 .46779 Mdot
.51735 .34291 Mdot
.49078 .67718 Mdot
.3619 .39736 Mdot
.4593 .64873 Mdot
.39321 .615 Mdot
.26944 .73178 Mdot
.64865 .51523 Mdot
.65952 .4945 Mdot
.39683 .40413 Mdot
.49048 .32993 Mdot
.525 .69164 Mdot
.19854 .5213 Mdot
.35657 .57266 Mdot
.17102 .44951 Mdot
.48555 .3525 Mdot
.72326 .46372 Mdot
.36315 .55539 Mdot
.33282 .4312 Mdot
.60747 .69484 Mdot
.37346 .40845 Mdot
.67508 .52958 Mdot
.4985 .34114 Mdot
.39763 .42628 Mdot
.47747 .24571 Mdot
.73606 .71613 Mdot
.72395 .46205 Mdot
.63456 .52305 Mdot
.79266 .62834 Mdot
.24047 .6399 Mdot
.56523 .33339 Mdot
.39166 .44951 Mdot
.66894 .53244 Mdot
.66902 .50129 Mdot
.64827 .50995 Mdot
.39105 .44074 Mdot
.47396 .75762 Mdot
.3685 .57433 Mdot
.61641 .55561 Mdot
.46998 .70103 Mdot
.36883 .59199 Mdot
.33096 .37596 Mdot
.37358 .5636 Mdot
.47666 .36283 Mdot
.68683 .49971 Mdot
.34402 .35607 Mdot
.83012 .32292 Mdot
.35448 .42385 Mdot
.38667 .62547 Mdot
.6635 .56655 Mdot
.28253 .47986 Mdot
.52786 .3668 Mdot
.35443 .57219 Mdot
.668 .51175 Mdot
.298 .44616 Mdot
.75254 .32247 Mdot
.37888 .56653 Mdot
.49196 .34402 Mdot
.58916 .82693 Mdot
.62626 .5456 Mdot
.63115 .50336 Mdot
.50627 .31419 Mdot
.59742 .3135 Mdot
.77973 .32972 Mdot
.59635 .52678 Mdot
.36306 .40642 Mdot
.20002 .65996 Mdot
.66253 .48695 Mdot
.71815 .61784 Mdot
.36185 .60698 Mdot
.41693 .38496 Mdot
.39073 .24532 Mdot
.56582 .48656 Mdot
.21667 .46093 Mdot
.29978 .41952 Mdot
.75407 .65548 Mdot
.40379 .55862 Mdot
.30658 .67533 Mdot
.78338 .61125 Mdot
.41079 .42402 Mdot
.46443 .3268 Mdot
.20908 .48736 Mdot
.5893 .23724 Mdot
.52271 .82554 Mdot
.34943 .72529 Mdot
.77841 .35217 Mdot
.45596 .44811 Mdot
.38293 .61081 Mdot
.5343 .46743 Mdot
.59416 .5131 Mdot
.24493 .64666 Mdot
.47258 .20937 Mdot
.49154 .21028 Mdot
.79323 .62967 Mdot
.66128 .418 Mdot
.71154 .72118 Mdot
.68217 .76031 Mdot
.73347 .57705 Mdot
.28825 .58982 Mdot
.16639 .45894 Mdot
.82263 .46275 Mdot
.18886 .55538 Mdot
.58341 .58848 Mdot
.45029 .50462 Mdot
.28797 .72406 Mdot
.50196 .26904 Mdot
.57703 .28159 Mdot
.34391 .57673 Mdot
.55127 .33366 Mdot
.23161 .43117 Mdot
.53318 .28559 Mdot
.4063 .24665 Mdot
.61197 .8258 Mdot
.72903 .72247 Mdot
.24391 .32595 Mdot
.43903 .83517 Mdot
.70403 .31623 Mdot
.14068 .42648 Mdot
.39752 .55987 Mdot
.53035 .29395 Mdot
.58634 .74907 Mdot
.69212 .69524 Mdot
.34658 .33856 Mdot
.21169 .551 Mdot
.42697 .68076 Mdot
.56666 .68137 Mdot
.50515 .33878 Mdot
.36389 .24065 Mdot
.39171 .38242 Mdot
.37019 .32157 Mdot
.81462 .48497 Mdot
.59601 .80728 Mdot
.43525 .46265 Mdot
.22328 .53593 Mdot
.27688 .51427 Mdot
.54917 .20895 Mdot
.65251 .65084 Mdot
.52841 .48526 Mdot
.45258 .25159 Mdot
.40651 .80969 Mdot
.60707 .27125 Mdot
.70191 .61284 Mdot
.70367 .68422 Mdot
.83582 .42791 Mdot
.28653 .69128 Mdot
.68701 .20533 Mdot
.54199 .28608 Mdot
.64242 .47512 Mdot
.61185 .32619 Mdot
.21282 .35123 Mdot
.47581 .71611 Mdot
.5611 .79173 Mdot
.48406 .70821 Mdot
.48517 .37013 Mdot
.75684 .31399 Mdot
.2031 .40977 Mdot
.18087 .39029 Mdot
.48564 .64747 Mdot
.71277 .50319 Mdot
.40658 .87126 Mdot
.70318 .70943 Mdot
.36588 .30111 Mdot
.82696 .57591 Mdot
.5024 .43825 Mdot
.48002 .22302 Mdot
.39778 .43082 Mdot
.79901 .58926 Mdot
.49855 .32559 Mdot
.68813 .19408 Mdot
.84875 .49226 Mdot
.73415 .32954 Mdot
.88921 .62389 Mdot
.61762 .73999 Mdot
.51248 .45691 Mdot
.33168 .45833 Mdot
.61151 .66089 Mdot
.54063 .22226 Mdot
.51962 .75503 Mdot
.28198 .48918 Mdot
.4134 .84472 Mdot
.77991 .63213 Mdot
.17158 .41638 Mdot
.22936 .67613 Mdot
.58843 .25226 Mdot
.48464 .55075 Mdot
.67782 .45653 Mdot
.42403 .64024 Mdot
.54267 .80399 Mdot
.8411 .41965 Mdot
.67428 .63871 Mdot
.55865 .88988 Mdot
.53109 .68228 Mdot
.41967 .70931 Mdot
.65732 .81124 Mdot
.57592 .69003 Mdot
.40006 .22936 Mdot
.75389 .60522 Mdot
.65132 .43817 Mdot
.51554 .58025 Mdot
.55849 .7978 Mdot
.33899 .2877 Mdot
.80766 .54183 Mdot
.47444 .83061 Mdot
.23742 .39935 Mdot
.70881 .40909 Mdot
.71805 .64185 Mdot
.5119 .27755 Mdot
.56251 .63706 Mdot
.40223 .2378 Mdot
.7573 .7004 Mdot
.40538 .40347 Mdot
.77966 .68959 Mdot
.78436 .33833 Mdot
.66952 .56742 Mdot
.59535 .45367 Mdot
.55501 .41039 Mdot
.56861 .64424 Mdot
.62657 .59415 Mdot
.27113 .35824 Mdot
.72114 .73852 Mdot
.77785 .43137 Mdot
.29519 .42921 Mdot
.29884 .39434 Mdot
.6507 .81995 Mdot
.63364 .34108 Mdot
.51824 .64899 Mdot
.79678 .51836 Mdot
.55168 .21857 Mdot
.37862 .59066 Mdot
.17726 .41379 Mdot
.32535 .43127 Mdot
.74689 .32373 Mdot
.71052 .4304 Mdot
.63896 .26403 Mdot
.72161 .73882 Mdot
.30765 .66563 Mdot
.77249 .33298 Mdot
.55793 .72037 Mdot
.17334 .51303 Mdot
.32822 .50983 Mdot
.5652 .55441 Mdot
.21796 .56532 Mdot
.51622 .67372 Mdot
.67357 .35405 Mdot
.17922 .60686 Mdot
.38095 .72632 Mdot
.59218 .57483 Mdot
.73234 .32458 Mdot
.38672 .52689 Mdot
.4473 .37449 Mdot
.58609 .16882 Mdot
.67254 .4887 Mdot
.72313 .6671 Mdot
.27322 .65556 Mdot
.60825 .64818 Mdot
.52384 .84609 Mdot
.35615 .76952 Mdot
.72911 .23285 Mdot
.8113 .59265 Mdot
.36745 .6838 Mdot
.77459 .61632 Mdot
.77851 .65867 Mdot
.72869 .23777 Mdot
.62734 .45181 Mdot
.36606 .38402 Mdot
.3874 .16627 Mdot
.37033 .55989 Mdot
.69449 .70415 Mdot
.19664 .49299 Mdot
.46522 .62252 Mdot
.49515 .39989 Mdot
.58243 .43039 Mdot
.45381 .457 Mdot
.54933 .36275 Mdot
.62818 .59341 Mdot
.65525 .20885 Mdot
.78294 .28775 Mdot
.68037 .211 Mdot
.34873 .78334 Mdot
.7982 .57866 Mdot
.50805 .48934 Mdot
.22628 .34755 Mdot
.53795 .47674 Mdot
.58908 .54863 Mdot
.44674 .65183 Mdot
.61008 .74364 Mdot
.70785 .29472 Mdot
.40313 .31858 Mdot
.53828 .25543 Mdot
.55805 .79451 Mdot
.1424 .65 Mdot
.679 .32184 Mdot
.18674 .45584 Mdot
.4889 .6384 Mdot
.59261 .6386 Mdot
.5132 .79329 Mdot
.66976 .26703 Mdot
.69235 .76202 Mdot
.54911 .3621 Mdot
.19246 .54204 Mdot
.38692 .74633 Mdot
.46105 .32383 Mdot
.36766 .67226 Mdot
.68965 .73472 Mdot
.30189 .36353 Mdot
.64197 .24329 Mdot
.43174 .29291 Mdot
.6137 .30914 Mdot
.44616 .58875 Mdot
.26119 .51122 Mdot
.17585 .56421 Mdot
.32714 .72951 Mdot
.7186 .61244 Mdot
.48404 .46261 Mdot
.33508 .24994 Mdot
.31821 .46206 Mdot
.69776 .62202 Mdot
.50403 .41128 Mdot
.748 .63227 Mdot
.68562 .15852 Mdot
.59541 .18928 Mdot
.60161 .83903 Mdot
.48256 .77279 Mdot
.5887 .57852 Mdot
.67367 .78015 Mdot
.65003 .18331 Mdot
.85236 .38831 Mdot
.24644 .5207 Mdot
.40945 .57177 Mdot
.32673 .41739 Mdot
.69099 .23742 Mdot
.46557 .74888 Mdot
.63977 .79367 Mdot
.70133 .63808 Mdot
.35706 .45256 Mdot
.30342 .21768 Mdot
.83204 .4371 Mdot
.724 .45 Mdot
.54714 .64593 Mdot
.56566 .5416 Mdot
.38612 .21379 Mdot
.53649 .28929 Mdot
.29606 .54147 Mdot
.60605 .63575 Mdot
.38633 .5866 Mdot
.55312 .76558 Mdot
.2127 .56735 Mdot
.62497 .56794 Mdot
.47778 .56251 Mdot
.48347 .31046 Mdot
.32192 .50571 Mdot
.32383 .32318 Mdot
.83494 .3584 Mdot
.47098 .63663 Mdot
.58607 .5588 Mdot
.62153 .64792 Mdot
.36964 .66722 Mdot
.76545 .30657 Mdot
.36188 .44933 Mdot
.76833 .65628 Mdot
.43463 .48403 Mdot
.56617 .6336 Mdot
.53662 .23692 Mdot
.53418 .53799 Mdot
.68119 .51167 Mdot
.39773 .79548 Mdot
.76267 .41676 Mdot
.44859 .32599 Mdot
.7062 .53289 Mdot
.54472 .47135 Mdot
.66486 .78631 Mdot
.48074 .62595 Mdot
.26822 .49906 Mdot
.75784 .67817 Mdot
.38325 .44128 Mdot
.4844 .32354 Mdot
.51529 .73065 Mdot
.19609 .57013 Mdot
.75942 .50989 Mdot
.75112 .32067 Mdot
.4852 .61119 Mdot
.38925 .72136 Mdot
.75355 .69135 Mdot
.7566 .66394 Mdot
.32827 .23065 Mdot
.56611 .29416 Mdot
.64902 .61921 Mdot
.19064 .57074 Mdot
.51874 .37357 Mdot
.22476 .40044 Mdot
.24013 .3806 Mdot
.84058 .47487 Mdot
.47066 .56162 Mdot
.42386 .84862 Mdot
.642 .69549 Mdot
.53369 .78462 Mdot
.61841 .2218 Mdot
.17807 .53893 Mdot
.66904 .73578 Mdot
.56318 .34372 Mdot
.66628 .3971 Mdot
.56759 .57265 Mdot
.28394 .29647 Mdot
.38094 .17684 Mdot
.50929 .73206 Mdot
.53026 .41363 Mdot
.48083 .83273 Mdot
.64774 .52961 Mdot
.56144 .17237 Mdot
.2046 .55813 Mdot
.6885 .25197 Mdot
.34692 .44699 Mdot
.58372 .50896 Mdot
.60249 .46574 Mdot
.78459 .56176 Mdot
.39823 .25171 Mdot
.75342 .62292 Mdot
.2074 .66236 Mdot
.49664 .81445 Mdot
.55024 .25115 Mdot
.69784 .69767 Mdot
.59756 .80938 Mdot
.25111 .652 Mdot
.4835 .49597 Mdot
.51423 .76496 Mdot
.58869 .68877 Mdot
.42384 .82668 Mdot
.475 .39895 Mdot
.38775 .50235 Mdot
.29848 .35313 Mdot
.28005 .62796 Mdot
.68533 .26593 Mdot
.59885 .49073 Mdot
.81521 .39446 Mdot
.65981 .77331 Mdot
.3624 .21778 Mdot
.4901 .19273 Mdot
.60222 .19019 Mdot
.74731 .41817 Mdot
.2963 .68975 Mdot
.2333 .61771 Mdot
.16366 .55836 Mdot
.4296 .48645 Mdot
.61898 .75425 Mdot
.57279 .70306 Mdot
.75536 .68631 Mdot
.39278 .39907 Mdot
.42888 .27523 Mdot
.28985 .40576 Mdot
.7659 .62007 Mdot
.6372 .3535 Mdot
.69241 .74287 Mdot
.48953 .43226 Mdot
.73383 .23385 Mdot
.35492 .75756 Mdot
.4661 .4413 Mdot
.38772 .61639 Mdot
.31946 .68436 Mdot
.60562 .78304 Mdot
.36883 .76183 Mdot
.17911 .51149 Mdot
.41697 .56815 Mdot
.51956 .56517 Mdot
.67155 .42946 Mdot
.55411 .63503 Mdot
.39378 .79588 Mdot
.62032 .6481 Mdot
.7199 .73133 Mdot
.79309 .55864 Mdot
.81292 .3911 Mdot
.6259 .73832 Mdot
.33333 .78637 Mdot
.36666 .29783 Mdot
.53737 .6367 Mdot
.20761 .56123 Mdot
.42845 .72802 Mdot
.55606 .35867 Mdot
.40099 .11512 Mdot
.27224 .72895 Mdot
.31881 .71433 Mdot
.84041 .42371 Mdot
.35553 .77408 Mdot
.32127 .49854 Mdot
.5873 .28263 Mdot
.46114 .26081 Mdot
.804 .40908 Mdot
.60784 .53142 Mdot
.64303 .19497 Mdot
.57879 .62658 Mdot
.81739 .31782 Mdot
.63733 .80158 Mdot
.52692 .41027 Mdot
.68778 .50291 Mdot
.34144 .56615 Mdot
.43051 .51474 Mdot
.74269 .58053 Mdot
.61245 .36215 Mdot
.43417 .2165 Mdot
.32688 .47652 Mdot
.39511 .55911 Mdot
.36351 .66104 Mdot
.56148 .33771 Mdot
.48961 .76436 Mdot
.27934 .61418 Mdot
.39681 .63963 Mdot
.42709 .4648 Mdot
.65448 .63503 Mdot
.38206 .24579 Mdot
.73023 .45919 Mdot
.67467 .26839 Mdot
.32857 .35736 Mdot
.35401 .56252 Mdot
.72935 .44551 Mdot
.28791 .72942 Mdot
.47885 .82147 Mdot
.83849 .41623 Mdot
.50919 .57654 Mdot
.62123 .38473 Mdot
.72987 .60855 Mdot
.51384 .20648 Mdot
.5739 .35257 Mdot
.33698 .49523 Mdot
.38382 .21719 Mdot
.58403 .31744 Mdot
.21583 .47912 Mdot
.83898 .50176 Mdot
.18984 .55193 Mdot
.18929 .57062 Mdot
.43963 .63021 Mdot
.70872 .57746 Mdot
.46564 .35228 Mdot
.63436 .68651 Mdot
.44902 .39256 Mdot
.17417 .37133 Mdot
.70516 .50857 Mdot
.15698 .35825 Mdot
.36536 .39237 Mdot
.5689 .24204 Mdot
.58599 .69698 Mdot
.48992 .46756 Mdot
.49491 .42277 Mdot
.33519 .74071 Mdot
.43702 .26234 Mdot
.27813 .67981 Mdot
.51592 .21797 Mdot
.3965 .55748 Mdot
.22123 .69345 Mdot
.35046 .80526 Mdot
.68459 .39925 Mdot
.65004 .56724 Mdot
.29005 .74875 Mdot
.40854 .5756 Mdot
.69572 .28461 Mdot
.53113 .84374 Mdot
.45222 .80099 Mdot
.62973 .42086 Mdot
.58071 .63705 Mdot
.62648 .7518 Mdot
.80135 .62768 Mdot
.36817 .19525 Mdot
.54968 .79703 Mdot
.39177 .39888 Mdot
.48952 .44255 Mdot
.65583 .7606 Mdot
.45717 .22739 Mdot
.40042 .3925 Mdot
.42325 .22141 Mdot
.12533 .43188 Mdot
.69935 .70364 Mdot
.74435 .63028 Mdot
.45634 .21931 Mdot
.48767 .36625 Mdot
.43362 .24749 Mdot
.39675 .23106 Mdot
.42662 .79077 Mdot
.2607 .69148 Mdot
.3968 .23489 Mdot
.14372 .50995 Mdot
.54031 .56426 Mdot
.31887 .54301 Mdot
.56206 .41348 Mdot
.75009 .55057 Mdot
.37294 .45874 Mdot
.8105 .45497 Mdot
.51123 .82213 Mdot
.3493 .38445 Mdot
.41446 .80301 Mdot
.22338 .54503 Mdot
.73448 .50142 Mdot
.75945 .4999 Mdot
.48572 .80392 Mdot
.63629 .37058 Mdot
.28841 .27768 Mdot
.75032 .3395 Mdot
.41686 .5981 Mdot
.54537 .82432 Mdot
.35045 .58509 Mdot
.55808 .45091 Mdot
.47399 .25783 Mdot
.52409 .7542 Mdot
.67538 .23708 Mdot
.52049 .69184 Mdot
.54144 .29829 Mdot
.37955 .18131 Mdot
.49379 .36152 Mdot
.66717 .21338 Mdot
.64344 .26321 Mdot
.41567 .20728 Mdot
.36498 .6891 Mdot
.35742 .71033 Mdot
.12858 .4655 Mdot
.38104 .37519 Mdot
.40343 .6445 Mdot
.26101 .33239 Mdot
.53085 .29216 Mdot
.43976 .64692 Mdot
.36931 .62204 Mdot
.39792 .48349 Mdot
.24408 .41887 Mdot
.55044 .57607 Mdot
.52581 .27005 Mdot
.41023 .47704 Mdot
.79491 .49013 Mdot
.82064 .54132 Mdot
.39782 .57867 Mdot
.19034 .32649 Mdot
.68561 .5062 Mdot
.70375 .39971 Mdot
.70116 .7585 Mdot
.29792 .22234 Mdot
.3157 .63596 Mdot
.37358 .82646 Mdot
.5661 .52364 Mdot
.49347 .78836 Mdot
.50279 .32925 Mdot
.19307 .54992 Mdot
.47563 .69932 Mdot
.60328 .6514 Mdot
.34707 .39112 Mdot
.63837 .24144 Mdot
.31007 .63646 Mdot
.54705 .35116 Mdot
.465 .78184 Mdot
.73277 .57672 Mdot
.38371 .47235 Mdot
.33891 .67397 Mdot
.68877 .40486 Mdot
.7539 .51988 Mdot
.5339 .2607 Mdot
.73693 .64305 Mdot
.18905 .59731 Mdot
.83886 .36009 Mdot
.48707 .39208 Mdot
.53128 .45266 Mdot
.25775 .37545 Mdot
.44321 .8111 Mdot
.29732 .2979 Mdot
.71965 .7461 Mdot
.65298 .62813 Mdot
.63307 .6092 Mdot
.69005 .6219 Mdot
.54315 .53298 Mdot
.46692 .47922 Mdot
.28177 .52487 Mdot
.45473 .20214 Mdot
.35391 .26325 Mdot
.59584 .27192 Mdot
.30045 .27679 Mdot
.72966 .63796 Mdot
.41812 .20965 Mdot
.40462 .63006 Mdot
.74395 .49997 Mdot
.31028 .4119 Mdot
.82342 .5438 Mdot
.71407 .74982 Mdot
.32527 .38589 Mdot
.41118 .65676 Mdot
.46866 .84411 Mdot
.61399 .45656 Mdot
.50368 .52749 Mdot
.66375 .49954 Mdot
.53699 .60109 Mdot
.26333 .25223 Mdot
.43773 .80028 Mdot
.61449 .58136 Mdot
.76817 .64231 Mdot
.78289 .61911 Mdot
.77018 .26545 Mdot
.16685 .48024 Mdot
.53393 .32468 Mdot
.73493 .25065 Mdot
.42694 .2163 Mdot
.79661 .63867 Mdot
.32052 .52316 Mdot
.73193 .7572 Mdot
.66513 .39317 Mdot
.44067 .82109 Mdot
.58238 .28225 Mdot
.4497 .2649 Mdot
.27615 .64942 Mdot
.49924 .51777 Mdot
.2636 .46419 Mdot
.32409 .74323 Mdot
.19369 .67121 Mdot
.55587 .54932 Mdot
.23479 .59144 Mdot
.35488 .3455 Mdot
.56153 .82408 Mdot
.36003 .74663 Mdot
.6636 .55722 Mdot
.29703 .3916 Mdot
.66984 .24418 Mdot
.66267 .63575 Mdot
.52166 .49597 Mdot
.34628 .73492 Mdot
.79001 .39458 Mdot
.73483 .59967 Mdot
.18683 .56431 Mdot
.68077 .40232 Mdot
.43494 .50421 Mdot
.57124 .51413 Mdot
.54368 .27674 Mdot
.52486 .67125 Mdot
.49422 .53288 Mdot
.66224 .54503 Mdot
.32879 .60093 Mdot
.40217 .46652 Mdot
.63835 .20651 Mdot
.34685 .28704 Mdot
.21661 .60461 Mdot
.49511 .28019 Mdot
.40129 .34248 Mdot
.28861 .31225 Mdot
.58397 .19415 Mdot
.41897 .76203 Mdot
.67358 .63909 Mdot
.71705 .70657 Mdot
.79584 .56128 Mdot
.48241 .27454 Mdot
.81367 .3373 Mdot
.38667 .45162 Mdot
.73088 .48955 Mdot
.41908 .32449 Mdot
.39996 .64877 Mdot
.68174 .56951 Mdot
.44003 .82007 Mdot
.47279 .62309 Mdot
.68111 .69959 Mdot
.28769 .69645 Mdot
.57928 .61025 Mdot
.68809 .42943 Mdot
.76818 .65153 Mdot
.33215 .57519 Mdot
.20832 .61755 Mdot
.35673 .46992 Mdot
.35018 .73298 Mdot
.79915 .5677 Mdot
.83923 .44087 Mdot
.46691 .41972 Mdot
.58999 .67655 Mdot
.63475 .49991 Mdot
.17843 .56437 Mdot
.43162 .80072 Mdot
.68729 .45556 Mdot
.24987 .49565 Mdot
.48291 .33084 Mdot
.25968 .54594 Mdot
.44627 .50669 Mdot
.79978 .41525 Mdot
.49847 .29286 Mdot
.39764 .20918 Mdot
.49746 .65163 Mdot
.51875 .44347 Mdot
.69769 .56388 Mdot
.60207 .66951 Mdot
.1585 .43334 Mdot
.70816 .53479 Mdot
.5576 .8011 Mdot
.70801 .42334 Mdot
.19814 .52475 Mdot
.48141 .79924 Mdot
.31819 .48162 Mdot
.43931 .26077 Mdot
.75014 .50222 Mdot
.28971 .37223 Mdot
.63157 .47633 Mdot
.41893 .60999 Mdot
.54196 .35496 Mdot
.54576 .82964 Mdot
.75655 .42796 Mdot
.62707 .68237 Mdot
.45611 .58092 Mdot
.52339 .50044 Mdot
.32416 .44677 Mdot
.7243 .75741 Mdot
.44524 .25685 Mdot
.626 .63425 Mdot
.47129 .56147 Mdot
.59188 .69293 Mdot
.63406 .27167 Mdot
.85321 .47583 Mdot
.58173 .27605 Mdot
.44065 .44409 Mdot
.56391 .24082 Mdot
.30673 .70235 Mdot
.51748 .85038 Mdot
.69827 .61556 Mdot
.51594 .42927 Mdot
.5164 .7081 Mdot
.28246 .34186 Mdot
.44526 .57456 Mdot
.5145 .52712 Mdot
.40109 .48742 Mdot
.24092 .46187 Mdot
.42133 .36297 Mdot
.71035 .48537 Mdot
.64544 .72792 Mdot
.73527 .68707 Mdot
.19467 .50607 Mdot
.32774 .47156 Mdot
.29355 .58654 Mdot
.79684 .44212 Mdot
.73847 .75982 Mdot
.4432 .17131 Mdot
.63705 .50172 Mdot
.31485 .44725 Mdot
.57767 .66986 Mdot
.34463 .61058 Mdot
.36827 .24587 Mdot
.30072 .30991 Mdot
.38759 .40252 Mdot
.538 .62649 Mdot
.70221 .67598 Mdot
.28488 .64032 Mdot
.55277 .6647 Mdot
.30486 .39155 Mdot
.62184 .19765 Mdot
.32004 .76074 Mdot
.44659 .81086 Mdot
.81887 .67665 Mdot
.35644 .48181 Mdot
.56585 .45802 Mdot
.63838 .32081 Mdot
.80812 .56147 Mdot
.62963 .65044 Mdot
.73027 .30824 Mdot
.29003 .46127 Mdot
.69071 .61735 Mdot
.54966 .37737 Mdot
.66709 .71318 Mdot
.25497 .54368 Mdot
.4695 .46276 Mdot
.36156 .71589 Mdot
.82199 .34163 Mdot
.64642 .41853 Mdot
.71759 .71318 Mdot
.63896 .22694 Mdot
.1585 .55007 Mdot
.80919 .57092 Mdot
.64693 .70758 Mdot
.4025 .76605 Mdot
.61477 .32881 Mdot
.49923 .40919 Mdot
.54085 .2484 Mdot
.70188 .28849 Mdot
.76971 .48166 Mdot
.40713 .68329 Mdot
.60027 .25069 Mdot
.71764 .613 Mdot
.77609 .47461 Mdot
.51625 .42741 Mdot
.73591 .46165 Mdot
.40601 .65645 Mdot
.44475 .22268 Mdot
.45918 .36728 Mdot
.65108 .6678 Mdot
.72035 .43308 Mdot
.25065 .38814 Mdot
.34677 .76078 Mdot
.14803 .56094 Mdot
.45604 .75153 Mdot
.58043 .20009 Mdot
.60235 .56464 Mdot
.76775 .24691 Mdot
.28516 .66922 Mdot
.29691 .66076 Mdot
.26807 .68396 Mdot
.36384 .51469 Mdot
.54098 .48848 Mdot
.63089 .47622 Mdot
.59751 .7858 Mdot
.62598 .41966 Mdot
.70363 .31058 Mdot
.62155 .23166 Mdot
.59304 .64402 Mdot
.69394 .64166 Mdot
.63705 .69127 Mdot
.63102 .60508 Mdot
.48677 .34651 Mdot
.68892 .21663 Mdot
.45287 .41895 Mdot
.68166 .45253 Mdot
.70626 .56413 Mdot
.61141 .30844 Mdot
.44692 .86616 Mdot
.51095 .40503 Mdot
.74523 .61517 Mdot
.66614 .4132 Mdot
.46723 .29202 Mdot
.30623 .28324 Mdot
.91565 .53712 Mdot
.80499 .27249 Mdot
.55324 .33923 Mdot
.18616 .44304 Mdot
.66408 .4162 Mdot
.75662 .62488 Mdot
.3956 .74897 Mdot
.23716 .48742 Mdot
.7062 .46641 Mdot
.45789 .29127 Mdot
.66606 .58465 Mdot
.26811 .65798 Mdot
.83198 .53465 Mdot
.60427 .22904 Mdot
.76662 .64458 Mdot
.54154 .54108 Mdot
.687 .57098 Mdot
.79495 .72037 Mdot
.66698 .75326 Mdot
.67554 .48277 Mdot
.56226 .25262 Mdot
.69473 .4745 Mdot
.59797 .51401 Mdot
.52305 .77469 Mdot
.2209 .69143 Mdot
.73449 .60547 Mdot
.76505 .6206 Mdot
.52094 .28302 Mdot
.3635 .52334 Mdot
.36287 .39148 Mdot
.47427 .4195 Mdot
.68035 .48072 Mdot
.39588 .42934 Mdot
.58669 .61918 Mdot
.47314 .83765 Mdot
.44348 .55559 Mdot
.21253 .65458 Mdot
.78714 .68937 Mdot
.75073 .43128 Mdot
.29166 .33509 Mdot
.60662 .4584 Mdot
.75878 .53156 Mdot
.7793 .51275 Mdot
.5251 .56055 Mdot
.39222 .80612 Mdot
.49118 .09944 Mdot
.27705 .40742 Mdot
.8087 .43132 Mdot
.50118 .37832 Mdot
.41665 .49722 Mdot
.70459 .44557 Mdot
.33526 .51647 Mdot
.40101 .59025 Mdot
.54876 .56338 Mdot
.4744 .32523 Mdot
.34921 .45148 Mdot
.20706 .29591 Mdot
.64585 .56975 Mdot
.33725 .26624 Mdot
.78801 .64665 Mdot
.74946 .33792 Mdot
.67145 .36991 Mdot
.5975 .47559 Mdot
.36124 .32612 Mdot
.51537 .43103 Mdot
.54297 .81255 Mdot
.81591 .40657 Mdot
.73304 .67761 Mdot
.75893 .4315 Mdot
.68272 .42605 Mdot
.57226 .51805 Mdot
.46157 .69047 Mdot
.41729 .38771 Mdot
.56663 .78786 Mdot
.68433 .46946 Mdot
.81536 .59934 Mdot
.30365 .63327 Mdot
.4919 .57864 Mdot
.53751 .40583 Mdot
.76353 .26301 Mdot
.62024 .28584 Mdot
.4724 .31006 Mdot
.59215 .1942 Mdot
.34341 .6544 Mdot
.55414 .64318 Mdot
.3392 .56637 Mdot
.64695 .45415 Mdot
.50471 .28316 Mdot
.57047 .17014 Mdot
.56121 .77923 Mdot
.26643 .45582 Mdot
.26068 .50567 Mdot
.198 .46315 Mdot
.38228 .47128 Mdot
.82951 .65781 Mdot
.33529 .68068 Mdot
.59115 .18179 Mdot
.19355 .60355 Mdot
.4948 .28721 Mdot
.36488 .77652 Mdot
.70356 .52341 Mdot
.3941 .57984 Mdot
.75314 .65297 Mdot
.59737 .43621 Mdot
.75967 .32074 Mdot
.56516 .5077 Mdot
.71822 .26834 Mdot
.51974 .70902 Mdot
.42259 .65736 Mdot
.30553 .69516 Mdot
.61469 .30386 Mdot
.64001 .81581 Mdot
.27707 .34618 Mdot
.67477 .78677 Mdot
.61564 .82377 Mdot
.77565 .64923 Mdot
.72798 .2951 Mdot
.33389 .21149 Mdot
.31442 .70441 Mdot
.47964 .80659 Mdot
.29111 .54012 Mdot
.60093 .31619 Mdot
.3178 .68493 Mdot
.5576 .40703 Mdot
.39595 .25414 Mdot
.30496 .41352 Mdot
.2322 .22594 Mdot
.68917 .66012 Mdot
.4685 .35093 Mdot
.33069 .69154 Mdot
.7935 .61962 Mdot
.61732 .31986 Mdot
.31492 .73586 Mdot
.45044 .50227 Mdot
.56168 .5464 Mdot
.76625 .47615 Mdot
.19115 .49679 Mdot
.31459 .66065 Mdot
.12096 .52475 Mdot
.29458 .73327 Mdot
.25338 .4623 Mdot
.45771 .47782 Mdot
.55282 .32957 Mdot
.27392 .30021 Mdot
.36454 .70803 Mdot
.37413 .79772 Mdot
.45402 .82957 Mdot
.65965 .75859 Mdot
.13066 .46109 Mdot
.19685 .54332 Mdot
.81581 .54986 Mdot
.38548 .78502 Mdot
.55179 .34626 Mdot
.62772 .71557 Mdot
.41321 .59153 Mdot
.27855 .49157 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Wooooo`;o0000X?ooool001cooooo00?o
0000ooooooooool0Yoooool2o`000:3ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo0_l0002Mooooo`;o0000Zoooool001cooooo00?o0000ooooooooool0
W?ooool2o`000:_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo07oooooo0_l00038ooooo`007?ooool00ol0003oooooooooo`1oooooo`;o0000
b?ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo07?ooooo0_l0000^ooooo`;o0000Y?ooool001cooooo00?o0000ooooooooool0Loooool2
o`0002kooooo1?l0002Rooooo`007?ooool00ol0003oooooooooo`2Uooooo`;o00006Oooool2o`00
08Oooooo000Looooo`03o`000?oooooooooo09[ooooo0_l0000Jooooo`;o00002?ooool2o`0008Oo
oooo000Looooo`03o`000?oooooooooo08Wooooo0_l00009ooooo`;o00001?ooool2o`0001[ooooo
0_l0002Aooooo`007?ooool2o`0008[ooooo0_l00003ooooo`;o00001?ooool2o`000;?ooooo000L
ooooo`03o`000?oooooooooo08?ooooo0_l00009ooooo`;o0000^Oooool001cooooo00?o0000oooo
ooooool0Poooool2o`0005Kooooo0_l0001/ooooo`007?ooool00ol0003oooooooooo`1Vooooo`;o
0000Loooool2o`0006cooooo000Looooo`03o`000?oooooooooo06Kooooo0_l000000ooooooo0000
o`000007ooooo`;o00006Oooool2o`000;[ooooo000Looooo`03o`000?oooooooooo06Wooooo0_l0
0007ooooo`;o00001_ooool2o`00017ooooo0_l0000/ooooo`;o0000S?ooool001cooooo00?o0000
ooooooooool0N_ooool2o`0000Kooooo0_l00008ooooo`;o00008?ooool2o`0000Kooooo0_l00003
ooooo`;o0000S?ooool001cooooo00?o0000ooooooooool0P_ooool2o`0000Sooooo0_l0000Poooo
o`?o00000_ooool2o`000003ooooool0003o0000097ooooo000Looooo`03o`000?oooooooooo07So
oooo0_l0000eooooo`;o00000_ooool2o`0001cooooo0_l0001fooooo`007?ooool00ol0003ooooo
ooooo`1hooooo`;o00003_ooool2o`0002Oooooo0_l0000Nooooo`;o0000M_ooool001cooooo00?o
0000ooooooooool0Moooool3o`0000kooooo0_l0000Wooooo`;o00002Oooool2o`00017ooooo0_l0
001hooooo`007?ooool00ol0003oooooooooo`1gooooo`;o00005?ooool2o`0000Cooooo0_l0000W
ooooo`;o00004Oooool2o`0007Sooooo000Looooo`03o`000?oooooooooo06?ooooo0_l0000Noooo
o`;o00001Oooool2o`000003ooooool0003o000000Cooooo0_l00003ooooo`;o00000_ooool2o`00
00Kooooo0_l0000Hooooo`Co0000Qoooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2
ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo05Sooooo0_l00002ooooo`;o00001Oooool2
o`0001gooooo0ol00005ooooo`;o00003?ooool2o`000004ooooool0003o0000o`0000Kooooo1?l0
000Fooooo`Co000000?oooooo`000?l00000Q?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo05So
oooo0_l00002ooooo`;o00004?ooool2o`0000Cooooo0_l0000<ooooo`;o00001?ooool2o`00017o
oooo1?l00007ooooo`;o00004_ooool5o`0000Cooooo0_l00005ooooo`;o000000?oooooo`000?l0
00003Oooool2o`0006_ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo
00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`1^ooooo`;o00001?ooool2o`0001;ooooo
0_l0000=ooooo`;o00001?ooool2o`0000Gooooo0_l0000Dooooo`Go00001oooool2o`0000;ooooo
0_l000000ooooooo0000o`00000=ooooo`;o0000Joooool00003ooooool0003ooooo00;ooooo00?o
0000ooooooooool02oooool00onHV9So8B4Qonk^kP06ooooo`?o0000JOooool2o`0002Gooooo0_l0
0005ooooo`;o00002oooool2o`0001?ooooo0_l00002ooooo`;o00001oooool2o`00087ooooo0000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool0
0ol0003oooooooooo`1Wooooo`Co00009Oooool2o`0002Oooooo0_l00002ooooo`;o00001?ooool2
o`0001Kooooo0_l0001/ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0=oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Ioooool2o`0000Kooooo0_l0000<oooo
o`?o00000oooool2o`0000?ooooo0_l0000Iooooo`?o00002Oooool2o`0001;ooooo0_l00007oooo
o`;o00000oooool2o`0000Sooooo0_l00002ooooo`;o0000J?ooool00006oooooomgMgOoV9RHoooo
oonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0JOoo
ool2o`0000Cooooo0_l0000<ooooo`?o00000oooool3o`0000;ooooo0_l0000<ooooo`;o00001?oo
ool2o`0000Gooooo0ol00009ooooo`;o00005_ooool2o`0000?ooooo0_l00003ooooo`;o00001_oo
ool2o`0000Cooooo0_l0001Xooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Mooooo`;o00001Oooool2o`0000?o
oooo0_l0000?ooooo`;o00002?ooool2o`0000kooooo1?l00004ooooo`;o00002?ooool2o`0000Go
oooo1?l0000Eooooo`?o00003?ooool2o`0000;ooooo0_l0001^ooooo`007?ooool00ol0003ooooo
ooooo`1Mooooo`Co00000oooool2o`0000cooooo0_l00005ooooo`?o00001oooool2o`0000;ooooo
1?l00009ooooo`;o00003_ooool4o`0000Gooooo0_l0000=ooooo`;o00002?ooool2o`0000gooooo
0_l00005ooooo`;o0000Joooool001cooooo00?o0000ooooooooool0E_ooool2o`0000Oooooo0_l0
000Aooooo`;o00001Oooool2o`0000Sooooo0_l000000ooooooo0000o`000005o`0000?ooooo0_l0
000Booooo`;o00001oooool4o`0000_ooooo0_l0000>ooooo`;o00003_ooool2o`0006_ooooo000L
ooooo`03o`000?oooooooooo05Kooooo0_l00005ooooo`;o00005Oooool2o`0000?ooooo0ol0000:
ooooo`;o00000oooool4o`000003ooooool0003o000000Kooooo0_l000000ooooooo0000o`000002
o`0000gooooo1Ol0000;ooooo`;o00001oooool3o`0000Cooooo0_l0001kooooo`007?ooool00ol0
003oooooooooo`18ooooo`;o00004oooool2o`00013ooooo0_l00003ooooo`;o00000oooool3o`00
00Kooooo0ol00008ooooo`;o00000_ooool4o`0000?ooooo0_l000000ooooooo0000o`000002o`00
00_ooooo1_l0000<ooooo`;o00001Oooool5o`0000Cooooo0_l0001kooooo`007?ooool00ol0003o
ooooooooo`18ooooo`;o00007Oooool2o`0000Kooooo0_l00002ooooo`;o00002Oooool2o`0000;o
oooo0ol0000:ooooo`Ko00005Oooool2o`0000?ooooo0_l0000@ooooo`Co00001oooool2o`0000Co
oooo1?l0001cooooo`007?ooool00ol0003oooooooooo`1Wooooo`;o00002_ooool2o`0000Sooooo
0ol0000?ooooo`;o00007_ooool2o`0000[ooooo0_l000001?oooooo0000o`000?ooool2o`0000?o
oooo0_l0000:ooooo`Co00004oooool4o`0005cooooo000Looooo`03o`000?oooooooooo06_ooooo
0_l0000@ooooo`;o00005?ooool2o`0000Oooooo0_l0000:ooooo`;o000000?oooooo`000?l00000
0_ooool2o`000003ooooool0003o000000Oooooo0_l000000ooooooo0000o`000006ooooo`;o0000
1_ooool2o`0000;ooooo0_l0000Eooooo`Co0000G?ooool001cooooo00?o0000ooooooooool0Jooo
ool2o`0000?ooooo0_l0000;ooooo`Co00004_ooool2o`0000Oooooo0_l0000:ooooo`;o000000?o
ooooo`000?l000000_ooool2o`000003ooooool0003o000000Oooooo0ol0000@ooooo`;o00000_oo
ool2o`000004ooooool0003o0000ooooo`;o00000oooool2o`0000[ooooo0_l0001Nooooo`007?oo
ool00ol0003oooooooooo`1Zooooo`;o00000oooool6o`0000[ooooo0_l0000Oooooo`;o00004Ooo
ool4o`0000Cooooo0ol0000>ooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`;o0000
0oooool2o`0000[ooooo0_l0001Nooooo`007?ooool00ol0003oooooooooo`1?ooooo`;o00006Ooo
ool2o`0000?ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l000000ooooooo0000o`00
0007ooooo`;o00001oooool2o`0000Cooooo0_l00002ooooo`;o00001oooool2o`0000Oooooo0_l0
0008ooooo`Co00005Oooool3o`0000Oooooo0_l0001aooooo`007?ooool00ol0003oooooooooo`1?
ooooo`;o00007_ooool2o`0000?ooooo0_l00002ooooo`Go00000oooool3o`000003ooooool0003o
000000?ooooo0_l00002ooooo`;o00000oooool4o`000003ooooool0003o0000013ooooo0_l00000
0ooooooo0000o`00000Oooooo`;o00001oooool2o`0001kooooo0_l0001Aooooo`007?ooool2o`00
05?ooooo0_l0000Eooooo`;o00001?ooool2o`0000Sooooo0_l00003ooooo`Go00001_ooool4o`00
00;ooooo0_l000000ooooooo0000o`000002o`0000Oooooo0_l0000=ooooo`;o000000?oooooo`00
0?l000002Oooool3o`0000;ooooo0_l0000Kooooo`;o00003Oooool2o`0000Wooooo0_l0001Aoooo
o`007?ooool00ol0003oooooooooo`1Booooo`;o00003_ooool2o`0000Gooooo0_l000000ooooooo
0000o`00000?ooooo`?o00001Oooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`00
00cooooo1?l0000:ooooo`;o00000_ooool2o`0000;ooooo0_l00005ooooo`?o00000_ooool2o`00
00[ooooo0_l0000?ooooo`;o00003Oooool2o`0000Cooooo0_l0001Fooooo`007?ooool00ol0003o
ooooooooo`1Qooooo`?o00001Oooool2o`000003ooooool0003o000000oooooo0_l00006ooooo`;o
000000?oooooo`000?l000000oooool2o`0000Oooooo0_l00003ooooo`;o00000_ooool2o`000003
ooooool0003o000000?ooooo0ol000000ooooooo0000o`000002o`0000Cooooo0_l0000Fooooo`;o
00007?ooool2o`0000Kooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`1Qooooo`;o0000
1_ooool2o`000003ooooool0003o000000Wooooo0_l0000;ooooo`;o00001Oooool4o`0000?ooooo
0_l00002ooooo`;o00000oooool2o`0000Gooooo0_l00003ooooo`So00007?ooool2o`0001;ooooo
0_l00008ooooo`;o0000G_ooool001cooooo00?o0000ooooooooool0G?ooool5o`0000_ooooo0_l0
00001?oooooo0000o`000?l00005ooooo`;o00002oooool2o`000004ooooool0003o0000ooooo`?o
00001Oooool2o`0001Kooooo1Ol0000Mooooo`?o00002oooool2o`0000?ooooo0_l0000Cooooo`;o
0000Doooool001cooooo00?o0000ooooooooool0G?ooool5o`0000Cooooo0_l00003ooooo`;o0000
00?oooooo`000?l000000ol0000Eooooo`;o000000?oooooo`000?l000001?l00003ooooo`Co0000
4?ooool2o`000003ooooool0003o000000;o00002oooool2o`00017ooooo0ol00007ooooo`;o0000
0_ooool4o`0001Kooooo1?l0001Aooooo`007?ooool00ol0003oooooooooo`1Iooooo`?o00001ooo
ool4o`0000?ooooo0_l000000ooooooo0000o`00000Mooooo`Co00000oooool7o`0000Gooooo0_l0
0002ooooo`;o00000_ooool2o`0000?ooooo0_l00005ooooo`;o00001?ooool2o`0001_ooooo2?l0
00000ooooooo0000o`000004ooooo`Co00000_ooool2o`0000Wooooo0_l0001Aooooo`007?ooool0
0ol0003oooooooooo`1Iooooo`?o00001oooool2o`0000gooooo0_l0000Eooooo`Co00000_ooool2
o`0000;ooooo0_l000000ooooooo0000o`000002o`0000Gooooo1_l00002ooooo`;o000000?ooooo
o`000?l000000_l00004ooooo`?o00002Oooool2o`000003ooooool0003o000000Oooooo0_l00009
ooooo`Oo00000oooool2o`0000Cooooo1?l00002ooooo`;o00005Oooool2o`0004Gooooo000Loooo
o`03o`000?oooooooooo05kooooo1?l0000<ooooo`;o00000_ooool2o`0001Cooooo1Ol00002oooo
o`;o000000?oooooo`000?l000001Oooool3o`0000Cooooo1?l00006ooooo`;o000000?oooooo`00
0?l000000oooool2o`0000Gooooo1?l000001?oooooo0000o`000?ooool2o`0000Oooooo0_l00009
ooooo`?o00005?ooool2o`0001Cooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`1Joooo
o`So00003?ooool2o`0000Kooooo0_l0000@ooooo`Co00001Oooool5o`0000?ooooo0ol00007oooo
o`?o00000_ooool4o`000004ooooool0003o0000ooooo`;o00001oooool4o`000003ooooool0003o
000000;o00001_ooool2o`0001Cooooo0_l0000<ooooo`;o0000Foooool001cooooo00?o0000oooo
ooooool0F_ooool4o`0001;ooooo0_l00004ooooo`;o00004?ooool2o`000003ooooool0003o0000
00Cooooo0_l000000ooooooo0000o`000007ooooo`;o000000Coooooo`000?l0003ooooo1?l00000
0ooooooo0000o`000002o`0000Cooooo0_l00005ooooo`Ko000000?oooooo`000?l000000_l00003
ooooo`;o000000?oooooo`000?l000003oooool2o`0000?ooooo0_l00006ooooo`;o0000HOooool0
01cooooo00?o0000ooooooooool0F_ooool2o`0000Cooooo0_l0000>ooooo`;o00006Oooool4o`00
00;ooooo0_l0000:ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0000;ooooo2?l00006
ooooo`Ko00002?ooool3o`0000kooooo0_l000000ooooooo0000o`000003ooooo`;o00001_ooool2
o`0000Oooooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`1Jooooo`;o000000?oooooo`00
0?l000000ol00003ooooo`;o00000oooool2o`000003ooooool0003o000001kooooo0_l00002oooo
o`;o00002?ooool9o`000004ooooool0003o0000ooooo`Wo00001_ooool4o`0000Kooooo0_l00003
ooooo`;o00002_ooool2o`0000;ooooo0ol00005ooooo`Co00001Oooool6o`0000;ooooo0_l0000:
ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0DOooool2o`0000[ooooo0ol00005oooo
o`;o00000_ooool6o`0001Sooooo0_l00008ooooo`;o000000?oooooo`000?l000001Oooool<o`00
0003ooooool0003o000000Go000000?oooooo`000?l000001oooool2o`000003ooooool0003o0000
00?ooooo0_l0000?ooooo`;o00000oooool2o`0000Oooooo0_l00003ooooo`So00000oooool2o`00
00Kooooo0_l000000ooooooo0000o`00001<ooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o
00005_ooool2o`000003ooooool0003o000001Wooooo1?l00006ooooo`;o000000?oooooo`000?l0
00001oooool:o`000003ooooool0003o000000Go000000?oooooo`000?l000000_ooool2o`0000Ko
oooo0_l000000ooooooo0000o`000005ooooo`;o00003oooool2o`0000Sooooo0ol000000ooooooo
0000o`000002ooooo`?o00001?ooool2o`0000Kooooo0_l0001?ooooo`007?ooool00ol0003ooooo
ooooo`10ooooo`;o00003oooool2o`0000Kooooo0_l00002ooooo`;o00000_ooool2o`0000Wooooo
0_l00005ooooo`;o00002_ooool3o`000003ooooool0003o000000?ooooo0ol00002ooooo`;o0000
3_ooool3o`000003ooooool0003o000000oo00000_ooool4o`0000Oooooo1?l00003ooooo`;o0000
00?oooooo`000?l000000oooool4o`0000Gooooo1?l00006ooooo`Co00001?ooool3o`0001Gooooo
0_l00016ooooo`007?ooool2o`00047ooooo0_l0000?ooooo`;o00000_ooool2o`0000;ooooo0_l0
0002ooooo`;o00000_ooool2o`0000Wooooo0_l00005ooooo`;o00002_ooool3o`000003ooooool0
003o000000Sooooo1?l00008ooooo`;o00000oooool2o`000003ooooool0003o000000oo000000?o
ooooo`000?l000000ol00006ooooo`;o000000?oooooo`000?l000001_ooool2o`0000?ooooo1?l0
0007ooooo`;o00001?ooool2o`0000;ooooo0_l0000Looooo`;o0000A_ooool001cooooo00?o0000
ooooooooool0EOooool2o`0000[ooooo0_l00002ooooo`;o00001?ooool2o`0000Kooooo0_l00003
ooooo`;o00004?ooool2o`0000?ooooo0_l00008ooooo`;o000000?oooooo`000?l000005?l00000
0ooooooo0000o`000009ooooo`;o00001?ooool2o`000003ooooool0003o000000;ooooo0_l0000B
ooooo`;o0000J?ooool001cooooo00?o0000ooooooooool0HOooool2o`0000;ooooo0_l00004oooo
o`;o00000_ooool2o`0000Oooooo0_l0000@ooooo`;o00000_ooool2o`0000_ooooo4ol000000ooo
oooo0000o`000002ooooo`;o00002Oooool2o`0000Cooooo0_l000000ooooooo0000o`000002oooo
o`;o000000?oooooo`000?l000007?ooool2o`0000Oooooo0_l0000;ooooo`;o0000AOooool001co
oooo00?o0000ooooooooool0G_ooool2o`0000[ooooo0_l00003ooooo`;o00001oooool2o`0000oo
oooo0ol00002ooooo`;o00001_oooolJo`0000?ooooo0_l00009ooooo`;o00000oooool3o`0000So
oooo0_l0000Aooooo`Co000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000005oooo
o`Co00002oooool2o`0004Gooooo000Looooo`03o`000?oooooooooo05[ooooo0_l000001?oooooo
0000o`000?l0000:ooooo`;o00003?ooool4o`0000gooooo0ol0000:oooooa[o000000Coooooo`00
0?l0003o00002_ooool2o`0000?ooooo0ol000000ooooooo0000o`000005ooooo`;o00004Oooool4
o`000004ooooool0003o0000ooooo`;o00001oooool3o`0005Cooooo000Looooo`03o`000?oooooo
oooo04_ooooo0_l00008ooooo`Co000000Coooooo`000?l0003ooooo0ol0000Gooooo`;o000000Co
ooooo`000?l0003ooooo0_l0000Iooooo`;o000000?oooooo`000?l000002?l000000ooooooo0000
o`00000<o`0000[ooooo1Ol000001?oooooo0000o`000?ooool2o`0000Gooooo0_l00003ooooo`;o
00003?ooool2o`0000?ooooo0_l00002ooooo`;o00001_ooool2o`0000Gooooo0_l0001>ooooo`00
7?ooool00ol0003oooooooooo`1;ooooo`;o00001Oooool2o`000003ooooool0003o000000;o0000
1_ooool2o`0000gooooo0_l00005ooooo`Co00001?ooool4o`0001Oooooo0_l000000ooooooo0000
o`00000Eo`0000Sooooo0_l00003ooooo`Co000000Coooooo`000?l0003o00003?ooool2o`0000co
oooo0_l00002ooooo`?o00000_ooool2o`0000_ooooo1?l0000;ooooo`;o0000@Oooool001cooooo
00?o0000ooooooooool0D_ooool2o`0000;ooooo0_l00005ooooo`Co00001?ooool2o`0000Oooooo
0_l00003ooooo`Co00002?ooool2o`0000[ooooo0_l0000:ooooo`;o000000?oooooo`000?l00000
6?l00002ooooo`;o00000_ooool2o`0000Wooooo0_l00005ooooo`;o00002oooool2o`0000Wooooo
0ol00009ooooo`Go00000_ooool2o`0000Cooooo0_l00007ooooo`?o000000?oooooo`000?l00000
?Oooool001cooooo00?o0000ooooooooool0@?ooool2o`0000[ooooo0_l0000?ooooo`Co000000Co
ooooo`000?l0003ooooo0ol0000:ooooo`Go00003Oooool2o`0000Gooooo0_l000000ooooooo0000
o`000002ooooo`;o00000_oooolOo`000003ooooool0003o000000_ooooo0_l00007ooooo`;o0000
2oooool2o`0000Wooooo0_l00004ooooo`;o00000oooool6o`0000Sooooo0_l00008ooooo`;o0000
00?oooooo`000?l00000?Oooool001cooooo00?o0000ooooooooool0>_ooool2o`0000Cooooo0_l0
0006ooooo`;o00000_ooool2o`0001Cooooo0_l00002ooooo`;o00002_ooool2o`000003ooooool0
003o000000gooooo0_l00008ooooo`;o00000_ooool3o`000003ooooool0003o000001ko00003Ooo
ool6o`00027ooooo0_l00003ooooo`;o00000_ooool2o`0005Cooooo000Looooo`03o`000?oooooo
oooo03Oooooo0_l000000ooooooo0000o`00000<ooooo`;o00001Oooool4o`0001?ooooo0_l00005
ooooo`;o000000?oooooo`000?l000008Oooool2o`0000;ooooo2?l000000ooooooo0000o`00000D
o`0000kooooo1Ol0000>ooooo`;o00004_ooool2o`000003ooooool0003o000000Cooooo0_l00003
ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0=oooool2o`0001Kooooo1?l00008oooo
o`;o00002Oooool4o`0000?ooooo0_l000000ooooooo0000o`00000Looooo`;o00001ooooolOo`00
00oooooo0_l0000@ooooo`Co00004?ooool2o`000003ooooool0003o000000Cooooo0_l000000ooo
oooo0000o`000002o`0004kooooo000Looooo`03o`000?oooooooooo04Oooooo0_l00002ooooo`;o
00003_ooool2o`0000_ooooo0_l00003ooooo`;o00002oooool2o`0000Wooooo0_l00007ooooo`;o
00001_ooool3o`000003ooooool0003o000000go000000?oooooo`000?l000002_l000000ooooooo
0000o`00000Pooooo`;o00005Oooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o
00001oooool2o`0004?ooooo000Looooo`03o`000?oooooooooo04Oooooo0_l00002ooooo`;o0000
8?ooool4o`0000?ooooo0_l00004ooooo`;o00002Oooool2o`0000Cooooo1Ol00005ooooob3o0000
0_ooool2o`00017ooooo0_l0000Tooooo`;o00000_ooool2o`0000Gooooo0_l00007ooooo`;o0000
00?oooooo`000?l00000@?ooool001cooooo00?o0000ooooooooool0F?ooool3o`0000Cooooo0_l0
0003ooooo`;o00002Oooool3o`0000;ooooo0_l00009ooooo`;o00002Oooool7o`0000Cooooo8?l0
000Eooooo`;o00009?ooool2o`0000[ooooo0_l00009ooooo`;o0000@?ooool001cooooo00?o0000
ooooooooool0@Oooool2o`0000?ooooo0_l0000<ooooo`Oo000000?oooooo`000?l000000ol00003
ooooo`;o00002_ooool2o`0000gooooo0_l00005ooooo`;o00000_ooool8o`0000?ooooo0_l00002
ooooo`Ko000000?oooooo`000?l000001_l000000ooooooo0000o`00000:o`0002;ooooo0_l0000D
ooooo`Co00001Oooool2o`0000Cooooo0_l0001;ooooo`007?ooool2o`0003kooooo0_l00002oooo
o`;o00000oooool2o`0000cooooo1?l00004ooooo`?o00003Oooool2o`0000;ooooo0_l00002oooo
o`;o00004?ooool2o`0000?ooooo0_l00003ooooo`;o00000_ooool3o`000003ooooool0003o0000
00_o000000?oooooo`000?l000000ol000000ooooooo0000o`000003o`000003ooooool0003o0000
02?ooooo1?l0000Booooo`Co00001Oooool2o`0000oooooo0_l00010ooooo`007?ooool00ol0003o
ooooooooo`0mooooo`;o00000_ooool4o`0000kooooo0_l00004ooooo`;o00000_ooool2o`0000go
oooo0_l00006ooooo`;o00006_ooool2o`0000;ooooo0_l00002oooooaSo00001oooool3o`00017o
oooo0_l0000:ooooo`Co00007_ooool2o`000003ooooool0003o000000Kooooo0_l000000ooooooo
0000o`000002o`0003kooooo000Looooo`03o`000?oooooooooo047ooooo2?l00002ooooo`;o0000
1_ooool2o`0000Cooooo0_l00002ooooo`;o00003Oooool2o`000003ooooool0003o000000Gooooo
0_l0000Fooooo`Co00000_ooool2o`0000;ooooo4?l000000ooooooo0000o`000007o`0000Gooooo
1_l0000>ooooo`;o00002_ooool2o`0001_ooooo0_l00003ooooo`;o000000?oooooo`000?l00000
1_ooool2o`0000?ooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o000000?o
ooooo`000?l000004Oooool4o`0000;ooooo0_l00007ooooo`;o00004Oooool2o`0000?ooooo0_l0
00000ooooooo0000o`000004ooooo`?o00005_ooool2o`0000Gooooo0_l00002oooooa[o00001ooo
ool3o`0000kooooo0_l00002ooooo`;o00001Oooool2o`0000Gooooo0_l0000Eooooo`;o00000ooo
ool3o`0000?ooooo0_l0000:ooooo`Co0000>_ooool001cooooo00?o0000ooooooooool0;oooool2
o`000003ooooool0003o0000023ooooo0_l0000Aooooo`;o00001oooool3o`0000;ooooo0_l00005
ooooo`;o00001Oooool4o`0000Oooooo0_l00005ooooo`Co00000ooooolGo`0000?ooooo0_l0000;
ooooo`?o00001Oooool2o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`000003ooooool0003o
000001Kooooo0_l00003ooooo`;o00000oooool5o`0000Oooooo1?l0000jooooo`007?ooool00ol0
003oooooooooo`0nooooo`;o00003oooool2o`0000[ooooo0_l000000ooooooo0000o`000002oooo
o`;o00001?ooool2o`0000;ooooo1ol00008ooooo`Go00000oooool4o`000003ooooool0003o0000
00?ooooo0ol000000ooooooo0000o`000004ooooo`;o00000_oooolCo`000003ooooool0003o0000
00;o00000oooool2o`0000_ooooo0ol0000Cooooo`?o00006Oooool2o`0000Wooooo1?l00015oooo
o`007?ooool00ol0003oooooooooo`0jooooo`;o00000_ooool2o`0000oooooo0_l00009ooooo`?o
000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l00002ooooo`Co00002_ooool3o`000003
ooooool0003o000000Sooooo0ol00002ooooo`;o00000_ooool2o`0000Gooooo0_l000000ooooooo
0000o`00000>o`000003ooooool0003o000000Wooooo0_l0000Pooooo`;o0000<Oooool2o`0003_o
oooo000Looooo`03o`000?oooooooooo03Gooooo0_l00003ooooo`;o00004oooool2o`0000Wooooo
0_l00006ooooo`;o000000?oooooo`000?l000000ol0000=ooooo`;o000000?oooooo`000?l00000
3?ooool3o`0000;ooooo0_l00002ooooo`;o00001OoooolBo`000004ooooool0003o0000o`0000Wo
oooo0_l0000<ooooo`Co00000_ooool2o`0000Wooooo0_l00002ooooo`;o00009oooool3o`0000Co
oooo1?l0000kooooo`007?ooool00ol0003oooooooooo`0eooooo`;o00001?ooool2o`0000kooooo
0_l00003ooooo`;o00002?ooool2o`0000Kooooo0_l000000ooooooo0000o`000004o`0000Wooooo
0_l000001?oooooo0000o`000?l0000;ooooo`;o000000?oooooo`000?l000000oooool3o`0000[o
oooo0_l000000ooooooo0000o`00000;o`000003ooooool0003o000001Sooooo1?l00002ooooo`;o
00002Oooool2o`0000;ooooo0_l00002ooooo`;o00004oooool2o`0000gooooo1?l00004ooooo`;o
0000?Oooool001cooooo00?o0000ooooooooool0>oooool2o`0000kooooo0_l00003ooooo`;o0000
2?ooool2o`0000Kooooo0_l00003ooooo`Co00002Oooool2o`0000;ooooo0_l00007ooooo`;o0000
0_ooool2o`0000Oooooo0_l00003ooooo`;o000000Coooooo`000?l0003o00001Oooool<o`0000Go
oooo0_l0000[ooooo`Co00004oooool3o`0000Wooooo0_l000000ooooooo0000o`00000<ooooo`;o
0000=oooool001cooooo00?o0000ooooooooool0A_ooool2o`000004ooooool0003o0000o`0001Ko
oooo0_l00003ooooo`Go000000Coooooo`000?l0003ooooo0_l00005ooooo`;o00002?ooool2o`00
013ooooo0_l000000ooooooo0000o`000002o`0000Gooooo2Ol00007ooooo`;o00007Oooool2o`00
00cooooo1?l0000Dooooo`;o00002Oooool2o`0000oooooo0_l0000gooooo`007?ooool00ol0003o
ooooooooo`0mooooo`;o00001Oooool4o`000004ooooool0003o0000o`0001;ooooo0_l00005oooo
o`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000003o`000003ooooool0003o0000
00;ooooo0_l00003ooooo`;o00005Oooool4o`000003ooooool0003o000000Cooooo0ol00004oooo
o`?o00002?ooool2o`0000cooooo0_l00006ooooo`;o00001_ooool3o`0000;ooooo0_l0000Voooo
o`;o00003Oooool2o`0003gooooo000Looooo`03o`000?oooooooooo03gooooo0_l00004ooooo`?o
00003oooool4o`0000Gooooo0_l00005ooooo`Go00000_ooool:o`0000Kooooo0_l00006ooooo`;o
000000Coooooo`000?l0003o00002oooool2o`000003ooooool0003o000000Cooooo0ol0000?oooo
o`;o00001?ooool2o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`;o000000?oooooo`00
0?l000001?ooool2o`0000;ooooo0_l0000<ooooo`;o00006?ooool2o`0000gooooo0_l0000moooo
o`007?ooool00ol0003oooooooooo`0gooooo`;o00001Oooool2o`0000?ooooo0_l00009ooooo`;o
00001Oooool4o`0000Gooooo0_l00004ooooo`Co00000_ooool?o`0000;ooooo0_l000000ooooooo
0000o`000004ooooo`;o000000Coooooo`000?l0003o00003_ooool2o`0000Cooooo0_l0000;oooo
o`;o00000oooool2o`0000?ooooo0ol00003ooooo`;o00003?ooool2o`0001Kooooo0_l0000Roooo
o`;o00002_ooool2o`0003Kooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46
ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0dooooo`;o000000?ooooo
o`000?l000001Oooool2o`0000;ooooo0_l00005ooooo`;o00000oooool2o`0000gooooo1Ol00002
ooooo`;o00001?ooool?o`000003ooooool0003o000000Co00003_ooool2o`0000?ooooo0_l00002
ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Kooooo0_l00003ooooo`;o00002?ooool2
o`0001cooooo0ol0000Zooooo`;o00000_ooool3o`0000[ooooo0_l0000fooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo03Cooooo0_l0000<ooooo`;o00001Oooool2o`0001;ooooo1Ol000000ooooooo0000o`00
0002oooooa[o00001?ooool2o`0000Oooooo0ol00002ooooo`;o00000_ooool2o`000004ooooool0
003o0000o`0000Wooooo0_l0000[ooooo`Co00001_ooool2o`0000?ooooo0_l0000Booooo`;o0000
1?ooool3o`000003ooooool0003o000000;ooooo0ol00008ooooo`;o0000>?ooool00003ooooool@
413ooooo00;ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo00?o0000ooooooooool0BOoo
ool2o`00017ooooo0ol00004ooooo`;o00000_oooolJo`0000Cooooo0_l00008ooooo`?o000000Go
ooooo`000?l0003o0000ooooo`02o`0000;ooooo1?l0000:ooooo`;o00002_ooool2o`0000oooooo
0_l0000=ooooo`;o00001?ooool4o`0000;ooooo0ol0000Booooo`;o00001?ooool3o`0000Kooooo
0_l00008ooooo`;o0000>?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Ooo
ool01?m4A4CogMgMooooool00007ooooo`?o0000AOooool2o`0000;ooooo0_l00005ooooo`;o0000
2_ooool2o`0000?ooooo0_l00004oooooako00002_ooool3o`000005ooooool0003o0000o`000?oo
ool01?l00002ooooo`;o00002_ooool2o`0000[ooooo0_l0000?ooooo`;o00004Oooool4o`0000Co
oooo0_l0000Gooooo`;o00001oooool4o`0004;ooooo00000ooooooo0000ooooo`02ooooo`03o`00
0?oooooooooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`15ooooo`;o
00000_ooool2o`0000Gooooo0_l00008ooooo`Co00000oooool2o`0000?ooooo7ol0000:ooooo`;o
00001Oooool2o`000003ooooool0003o000000;o00001Oooool2o`0000Gooooo1?l0000:ooooo`;o
00002Oooool2o`0001Gooooo0_l000000ooooooo0000o`00000?ooooo`;o00002?ooool2o`000003
ooooool0003o000000Oooooo1?l00012ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooo
ooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0<_ooool2o`0000cooooo
0_l00007ooooo`;o00002oooool2o`0000;ooooo1?l00006oooooaCo00000_ooool:o`0000_ooooo
0_l00003ooooo`Co00000oooool2o`000003ooooool0003o000000;ooooo0_l00007ooooo`;o0000
1?ooool2o`0000Cooooo0_l00007ooooo`Co00002Oooool2o`0000gooooo0_l00004ooooo`;o0000
2?ooool3o`0000Sooooo0_l00008ooooo`;o00000_ooool2o`0004;ooooo00001_ooooooMgMgoiRH
V?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0booooo`;o
00002_ooool4o`0000Oooooo1?l00008ooooo`?o00001?ooool2o`0000?ooooo0_l000000ooooooo
0000o`00000Ko`0000Kooooo0_l00003ooooo`;o00000oooool5o`0000Sooooo1_l00003ooooo`;o
00002?ooool3o`0000cooooo0_l00004ooooo`;o00001?ooool3o`0001?ooooo0_l00008ooooo`;o
00004oooool2o`0000;ooooo0_l00012ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h=oooo
o`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0;_ooool4o`0000Cooooo0_l00002oooo
o`;o00000_ooool2o`0000Wooooo1?l00008ooooo`;o00000oooool2o`0000?ooooo1?l00003oooo
o`Co000000?oooooo`000?l000005_l00004ooooo`;o00000oooool2o`0000?ooooo1?l0000;oooo
o`Co00000_ooool4o`0000Oooooo1?l00002ooooo`;o00003Oooool2o`0000;ooooo1Ol00006oooo
o`;o00005oooool2o`00013ooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`0^ooooo`Co
00000_ooool4o`000004ooooool0003o0000o`0000gooooo0_l0000;ooooo`?o000000?oooooo`00
0?l000000oooool2o`0000?ooooo8?l00008ooooo`;o00001oooool3o`0000[ooooo0_l00002oooo
o`Co00001_ooool2o`000003ooooool0003o000000;ooooo0_l0000Aooooo`;o00000_ooool2o`00
00?ooooo1?l00005ooooo`;o00002Oooool2o`0000Gooooo0ol00003ooooo`;o00002_ooool2o`00
00_ooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`0cooooo`?o00000_ooool3o`000003
ooooool0003o000000kooooo0_l00008ooooo`Ko000000Coooooo`000?l0003o00001?oooolMo`00
0003ooooool0003o000000Sooooo0_l000000ooooooo0000o`000003ooooo`Co00002_ooool2o`00
00cooooo0_l0000Fooooo`?o00000oooool2o`0000?ooooo0ol00006ooooo`;o00001_ooool2o`00
0003ooooool0003o000000Kooooo0_l00003ooooo`;o00000_ooool2o`0000gooooo0_l00003oooo
o`?o0000>_ooool001cooooo00?o0000ooooooooool0;_ooool2o`0000?ooooo0_l00003ooooo`;o
00000_ooool2o`0000kooooo0_l00006ooooo`So000000Coooooo`000?l0003o00002?oooolIo`00
0003ooooool0003o000000_ooooo0_l00003ooooo`Co00001Oooool2o`000004ooooool0003o0000
o`0000Oooooo0_l0000>ooooo`;o00000_ooool2o`0000Sooooo0ol0000Gooooo`Co00004_ooool2
o`0000;ooooo0_l00005ooooo`;o00000_ooool4o`000004ooooool0003o0000o`0003[ooooo000L
ooooo`03o`000?oooooooooo02[ooooo0_l00002ooooo`;o00009?ooool3o`0000Wooooo0_l00006
ooooo`Go000000Goooooo`000?l0003o0000ooooo`0Bo`0001;ooooo0_l00005ooooo`;o000000Go
ooooo`000?l0003o0000ooooo`02o`0000Cooooo0_l00008ooooo`;o00001?ooool2o`0000;ooooo
0ol0000@ooooo`?o00001?ooool4o`0000Kooooo0_l0000>ooooo`;o00001?ooool2o`0000;ooooo
0_l00005ooooo`;o000000Coooooo`000?l0003ooooo0_l000001?oooooo0000o`000?l0000joooo
o`007?ooool00ol0003oooooooooo`0Zooooo`;o0000<?ooool3o`000003ooooool0003o000000Oo
oooo6_l0000Qooooo`Co00003?ooool2o`0000?ooooo0_l00004ooooo`;o00002oooool2o`0000?o
oooo0ol00002ooooo`So00001Oooool2o`0000gooooo0ol0000Aooooo`;o00000oooool3o`0003_o
oooo000Looooo`03o`000?oooooooooo02Gooooo0_l00009ooooo`;o00002Oooool2o`0000_ooooo
0_l0000Booooo`?o00001ooooolOo`000003ooooool0003o000001?ooooo0_l00005ooooo`Ko0000
1_ooool2o`0000Wooooo0_l0000<ooooo`;o00000_ooool3o`0000Sooooo0_l00004ooooo`;o0000
1Oooool5o`0000Sooooo0_l000000ooooooo0000o`000004ooooo`;o00001Oooool2o`000004oooo
ool0003o0000ooooo`;o000000?oooooo`000?l000000_l0000looooo`007?ooool00ol0003ooooo
ooooo`0Uooooo`;o00002Oooool2o`0000Wooooo0_l0000;ooooo`;o00002_ooool2o`0000Oooooo
0_l00003ooooo`;o00000_oooolKo`000005ooooool0003o0000o`000?ooool00_l00008ooooo`;o
00002Oooool2o`0000;ooooo0_l000000ooooooo0000o`000008ooooo`Co00002oooool2o`000003
ooooool0003o000000Oooooo0_l00002ooooo`;o00006?ooool3o`0000Sooooo0_l000000ooooooo
0000o`000004ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o000000Coooooo`00
0?l0003ooooo0ol0000mooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00001?ooool2o`00
01Gooooo0_l000000ooooooo0000o`000004ooooo`;o00000oooool2o`0000;ooooo0_l000001?oo
oooo0000o`000?oooolHo`0000cooooo0_l0000=ooooo`;o00002oooool2o`0000cooooo0ol00000
0ooooooo0000o`00000:ooooo`;o00001?ooool2o`00027ooooo0_l00006ooooo`Co00002oooool2
o`0003gooooo000Looooo`03o`000?oooooooooo03Oooooo1?l00002ooooo`;o00005Oooool2o`00
0004ooooool0003o0000ooooo`;o00001_ooool2o`0000;ooooo1?l00002oooooaCo000000Cooooo
o`000?l0003o00004?ooool2o`0000Cooooo0ol00002ooooo`;o00006?ooool3o`0000Sooooo0_l0
0003ooooo`?o00001?ooool2o`0002Wooooo0_l00002ooooo`;o00001?ooool4o`0000Cooooo0_l0
000jooooo`007?ooool00ol0003oooooooooo`0Oooooo`;o00003Oooool2o`0000Wooooo0_l0000;
ooooo`;o00002?ooool2o`000004ooooool0003o0000o`0000;ooooo1?l000000ooooooo0000o`00
0002ooooo`;o00001Oooool2o`0000;ooooo6?l00007ooooo`;o00001oooool2o`0000?ooooo1?l0
0008ooooo`;o00000oooool2o`0000Gooooo0_l00005ooooo`?o00002?ooool3o`0000?ooooo0_l0
00000ooooooo0000o`00000=ooooo`;o00001?ooool3o`0000Gooooo0_l0000Dooooo`;o000000Co
ooooo`000?l0003ooooo1?l00004ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool07ooo
ool2o`0000gooooo0_l00004ooooo`;o00003_ooool4o`0000Sooooo0_l000000ooooooo0000o`00
0003ooooo`;o00000oooool2o`0000;ooooo1?l000000ooooooo0000o`000005oooooaOo00001ooo
ool2o`0000?ooooo0_l00007ooooo`;o00002_ooool2o`0000?ooooo0_l00005ooooo`;o00001Ooo
ool2o`0000Wooooo1?l00005ooooo`Ko00002Oooool2o`0000Cooooo0ol00005ooooo`;o00005_oo
ool3o`0004Gooooo000Looooo`;o0000=Oooool2o`0000kooooo0_l0000=ooooo`;o00003?ooool4
o`000003ooooool0003o000000Gooooo5Ol00008ooooo`;o00001?ooool2o`00023ooooo0_l00002
ooooo`;o00000oooool3o`0000;ooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o
000000?ooooo1Ol00008ooooo`;o00002oooool2o`0001Sooooo0_l00004ooooo`Go00000_ooool2
o`0000?ooooo0_l0000dooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00008Oooool2o`00
00_ooooo1?l000000ooooooo0000o`00000:o`0000_ooooo1?l0000Kooooo`;o00001oooool2o`00
00;ooooo0_l00003ooooo`Wo00001?ooool2o`0000Cooooo0_l0000:ooooo`?o00002_ooool2o`00
01[ooooo2Ol00002ooooo`;o00000oooool2o`0003Cooooo000Looooo`03o`000?oooooooooo03Wo
oooo0_l00003ooooo`;o00004oooool2o`0000Wooooo0_l00008ooooo`;o000000?oooooo`000?l0
00000_ooool<o`0000;ooooo0_l00002ooooo`;o00002?ooool3o`0000;ooooo0_l0000@ooooo`?o
00000_ooool4o`0000Gooooo0_l00002ooooo`;o00001_ooool>o`000004ooooool0003o0000oooo
o`;o00000oooool2o`0000?ooooo1Ol0000Booooo`Co00004?ooool4o`000003ooooool0003o0000
03oooooo000Looooo`03o`000?oooooooooo02Oooooo0_l00009ooooo`;o00001Oooool2o`0000So
oooo0_l00006ooooo`;o00001Oooool3o`0000Gooooo0ol000000ooooooo0000o`000002ooooo`;o
00000_ooool4o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o00000_ooool2o`0000;o
oooo0_l00002ooooo`;o00001oooool3o`0000?ooooo0_l0000:ooooo`;o00001?ooool3o`0000;o
oooo0_l00007ooooo`;o00000_ooool2o`0000;ooooo1_l00002ooooo`[o000000Goooooo`000?l0
003o0000ooooo`02o`0000;ooooo0_l00003ooooo`?o00003_ooool4o`0000;ooooo1?l0000;oooo
o`;o00001Oooool2o`000003ooooool0003o000003oooooo000Looooo`03o`000?oooooooooo02Oo
oooo0ol00008ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`;o00001?ooool2o`00
00Kooooo0_l00002ooooo`;o000000?oooooo`000?l000001_ooool3o`0000Gooooo1_l000000ooo
oooo0000o`00000;ooooo`;o00001Oooool2o`0000Sooooo0_l000000ooooooo0000o`000009oooo
o`;o00000_ooool2o`000003ooooool0003o000000[ooooo0_l000000ooooooo0000o`000003oooo
o`?o000000Coooooo`000?l0003ooooo1_l00004ooooo`Co000000?oooooo`000?l000000oooool3
o`000003ooooool0003o000000Wo00003Oooool6o`00017ooooo0_l00005ooooo`Co0000@?ooool0
01cooooo00?o0000ooooooooool09_ooool4o`0000[ooooo0_l000001?oooooo0000o`000?ooool2
o`000003ooooool0003o000000Cooooo0_l00007ooooo`;o000000Coooooo`000?l0003ooooo0_l0
0006ooooo`;o00000oooool2o`0000?ooooo1?l000000ooooooo0000o`000007ooooo`;o00000_oo
ool2o`0000Oooooo0_l00006ooooo`;o000000?oooooo`000?l000002Oooool2o`0000;ooooo1?l0
0008ooooo`So00000oooool6o`000003ooooool0003o000000;ooooo0ol00002ooooo`Wo000000Co
ooooo`000?l0003o00000_ooool;o`0000;ooooo1?l00002ooooo`;o00000oooool2o`0000[ooooo
0_l00008ooooo`;o00002?ooool2o`00043ooooo000Looooo`03o`000?oooooooooo02Kooooo0_l0
000<ooooo`;o00005_ooool2o`000003ooooool0003o000000kooooo0_l00005ooooo`;o00000ooo
ool2o`0000?ooooo1?l0000:ooooo`?o00006_ooool2o`0000Sooooo1?l000000ooooooo0000o`00
0006ooooo`Co000000?oooooo`000?l000000ooooolBo`000004ooooool0003o0000o`0000;ooooo
0ol00003ooooo`Ko00000_ooool2o`0000Gooooo0ol00007ooooo`;o00001Oooool2o`000003oooo
ool0003o000001Cooooo0_l0000dooooo`007?ooool00ol0003oooooooooo`11ooooo`;o00007_oo
ool2o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l00006ooooo`?o00000ooo
ool2o`0002_ooooo1?l00003ooooo`Co000000?oooooo`000?l000000_ooool?o`000005ooooool0
003o0000o`000?ooool00_l000000ooooooo0000o`000002o`000004ooooool0003o0000ooooo`;o
000000?oooooo`000?l000002_ooool3o`0000Oooooo0_l00005ooooo`;o00000_ooool2o`0001?o
oooo0_l0000dooooo`007?ooool00ol0003oooooooooo`0jooooo`;o000000?oooooo`000?l00000
0_ooool3o`0001gooooo0_l00003ooooo`Ko00000_ooool2o`0000Sooooo0ol00003ooooo`?o0000
00?oooooo`000?l000009oooool4o`0000?ooooo1?l00003ooooo`[o00000_ooool?o`0000;ooooo
0ol00002ooooo`Go00003oooool2o`0000;ooooo1?l000000ooooooo0000o`000004ooooo`;o0000
3Oooool6o`0003Kooooo000Looooo`03o`000?oooooooooo03?ooooo0_l00005ooooo`;o000000Co
ooooo`000?l0003ooooo1?l000000ooooooo0000o`00000:ooooo`Co00000oooool2o`0000Oooooo
0_l00003ooooo`Ko00003Oooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0000[o
oooo0_l000000ooooooo0000o`000002o`0000Gooooo0_l00007ooooo`;o00000oooool2o`0000co
oooo6ol00002ooooo`?o00000_ooool2o`000003ooooool0003o000000oooooo0_l00004ooooo`;o
000000?oooooo`000?l000004_ooool7o`0003Kooooo000Looooo`03o`000?oooooooooo037ooooo
1?l0000;ooooo`Co000000?oooooo`000?l000002_ooool4o`000003ooooool0003o000000Co0000
1?ooool2o`0000;ooooo0_l0000:ooooo`;o00004oooool2o`0000[ooooo0_l000000ooooooo0000
o`000002o`0000Gooooo0_l00007ooooo`;o00003oooool2o`0000;ooooo4ol00002ooooo`Co0000
0oooool6o`000003ooooool0003o000001Kooooo0_l00005ooooo`;o00001_ooool4o`0000?ooooo
0_l0000kooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00000oooool2o`0000;ooooo0_l0
0006ooooo`;o00002Oooool2o`0000Oooooo1_l00004ooooo`;o00000_ooool2o`0000[ooooo0_l0
00000ooooooo0000o`000009ooooo`;o00002?ooool3o`0000Sooooo0_l0000Cooooo`;o00000ooo
ool2o`0000Oooooo0ol00002oooooa_o00000_ooool3o`000003ooooool0003o000000?o00000_oo
ool2o`00017ooooo0_l00005ooooo`;o00001_ooool4o`00043ooooo000Looooo`03o`000?oooooo
oooo03Kooooo0_l000001?oooooo0000o`000?l00004ooooo`Co00001Oooool2o`0000;ooooo0_l0
0007ooooo`Co00006Oooool2o`0000Wooooo0ol00007ooooo`?o00002?ooool2o`0000cooooo1?l0
0003ooooo`;o00000_ooool3o`0000Gooooo1Ol000000ooooooo0000o`00000Jo`000005ooooool0
003o0000o`000?ooool01_l00002ooooo`;o00001Oooool2o`0001Wooooo0_l00012ooooo`007?oo
ool00ol0003oooooooooo`0iooooo`;o00001Oooool2o`0000Oooooo1?l00005ooooo`?o000000?o
ooooo`000?l000001?l00009ooooo`;o00006?ooool2o`0000Oooooo0_l00005ooooo`;o00001?oo
ool2o`0000[ooooo1?l00007ooooo`Go00000_ooool6o`000003ooooool0003o000001[o000000?o
ooooo`000?l000002?l00002ooooo`Go00000_ooool2o`0000Gooooo0_l0000;ooooo`;o00004?oo
ool2o`0003Oooooo000Looooo`03o`000?oooooooooo03Oooooo0_l00003ooooo`?o00003?ooool4
o`000003ooooool0003o000000?o000000Goooooo`000?l0003o0000ooooo`02o`0000Wooooo0_l0
0003ooooo`;o00000oooool2o`0001Oooooo0_l00005ooooo`?o00000oooool2o`0001Oooooo0ol0
0002ooooo`?o00000_oooolPo`000004ooooool0003o0000ooooo`Ko00000oooool3o`000004oooo
ool0003o0000o`0000Gooooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o
00000_ooool2o`0000;ooooo0_l00004ooooo`;o0000=oooool001cooooo00?o0000ooooooooool0
=Oooool4o`000003ooooool0003o000000?o00003_ooool2o`000003ooooool0003o000001?ooooo
0ol00002ooooo`;o00000oooool2o`0001?ooooo0_l000000ooooooo0000o`000007ooooo`;o0000
0_ooool2o`0000?ooooo0_l0000;ooooo`;o00002ooooolHo`000003ooooool0003o000000co0000
1_ooool2o`000003ooooool0003o000000Cooooo0ol00008ooooo`?o00000_ooool2o`0000Oooooo
0_l00002ooooo`;o00000_ooool2o`0000Cooooo0_l0000gooooo`007?ooool2o`0003Kooooo0_l0
0003ooooo`;o00005oooool2o`0000Cooooo0_l0000:ooooo`?o00000_ooool2o`000003ooooool0
003o000001Gooooo0_l000000ooooooo0000o`00000;ooooo`;o00000oooool2o`000003ooooool0
003o000000?ooooo0_l00003ooooo`;o00002_ooool2o`000003ooooool0003o000000?o000000?o
ooooo`000?l000007Ol000001Ooooooo0000o`000?l0003ooooo00;o00000_ooool2o`0000Kooooo
0_l000000ooooooo0000o`000003ooooo`?o00005oooool2o`000003ooooool0003o000003Oooooo
000Looooo`03o`000?oooooooooo05?ooooo0_l00003ooooo`Go00003Oooool2o`000003ooooool0
003o000000;ooooo0_l00007ooooo`;o00003_ooool2o`0000;ooooo1Ol00002ooooo`;o00000ooo
ool4o`0000?ooooo0_l00003ooooo`?o00001_ooool2o`000004ooooool0003o0000o`0000;ooooo
0ol000000ooooooo0000o`00000Mo`000005ooooool0003o0000o`000?ooool01?l000000ooooooo
0000o`000005ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000008ooooo`;o
00003Oooool5o`0003Sooooo000Looooo`03o`000?oooooooooo027ooooo0_l0000Iooooo`;o0000
3?ooool2o`0000Gooooo0_l00005ooooo`;o000000?oooooo`000?l000000_l00006ooooo`;o0000
1?ooool2o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l000003_ooool2o`000003oooo
ool0003o000000Co000000Coooooo`000?l0003o00000_ooool3o`0000_ooooo0_l00006ooooob_o
000000?oooooo`000?l000000_l000001Ooooooo0000o`000?l0003ooooo00;o00001_ooool2o`00
0004ooooool0003o0000o`0000_ooooo0_l00002ooooo`;o00002Oooool5o`0003Sooooo000Loooo
o`03o`000?oooooooooo027ooooo0_l00008ooooo`;o00003oooool2o`0000Gooooo1?l00003oooo
o`;o00000_ooool2o`000003ooooool0003o000000[ooooo0_l000000ooooooo0000o`000003oooo
o`Co00000_ooool2o`0000[ooooo1?l0000:ooooo`;o00001_ooool2o`0000Cooooo0ol00003oooo
o`;o00000oooool2o`0000cooooo0_l00003ooooob;o000000?oooooo`000?l000002Ol00002oooo
o`;o00002Oooool2o`000003ooooool0003o000000;ooooo0_l0000<ooooo`;o000000?oooooo`00
0?l00000@oooool001cooooo00?o0000ooooooooool0:oooool2o`0000Sooooo0ol00004ooooo`;o
00001Oooool4o`0000Oooooo0_l000000ooooooo0000o`00000=ooooo`;o00000oooool4o`0000[o
oooo0_l00004ooooo`;o00002_ooool2o`0000Oooooo0_l00003ooooo`;o00002Oooool4o`0000[o
oooo1?l00002oooooa7o00000_oooolFo`0000;ooooo0_l000001?oooooo0000o`000?l0000@oooo
o`;o00001?ooool2o`0000Wooooo0_l000000ooooooo0000o`000010ooooo`007?ooool00ol0003o
ooooooooo`0eooooo`?o00004?ooool2o`0000Oooooo0_l00003ooooo`;o00000oooool2o`0000Co
oooo0_l00003ooooo`;o000000?oooooo`000?l000001oooool3o`0001?ooooo0_l00004ooooo`;o
00003_ooool6o`0000?ooooo0_l00004ooooo`?o000000?oooooo`000?l000004?l000000ooooooo
0000o`00000Eo`000005ooooool0003o0000o`000?ooool00_l00005ooooo`;o00004?ooool2o`00
00Wooooo0_l000000ooooooo0000o`000010ooooo`007?ooool00ol0003oooooooooo`0Zooooo`;o
00004Oooool2o`0000Wooooo0_l00003ooooo`;o00001oooool2o`0000?ooooo0_l00004ooooo`;o
00001_ooool2o`0000Oooooo0_l00006ooooo`;o00001_ooool2o`0000Cooooo0_l0000;ooooo`;o
00001oooool2o`000004ooooool0003o0000o`0000?ooooo0_l00004ooooo`;o000000?oooooo`00
0?l000004?l000000ooooooo0000o`000008o`000003ooooool0003o000000;o000000?oooooo`00
0?l000003?l00006ooooo`;o00002?ooool2o`0000;ooooo0_l00008ooooo`;o00000oooool2o`00
04?ooooo000Looooo`03o`000?oooooooooo02[ooooo0_l0000Aooooo`;o00003Oooool3o`0000;o
oooo0_l0000Aooooo`;o00003?ooool2o`000003ooooool0003o000000?ooooo0_l00006ooooo`;o
00000_ooool2o`0000?ooooo0_l00008ooooo`;o00000oooool2o`000004ooooool0003o0000o`00
00Kooooo0_l00008ooooo`;o000000?oooooo`000?l00000;_l0000>ooooo`;o00000_ooool2o`00
00Sooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`0Tooooo`;o00005oooool2o`0000go
oooo0_l00003ooooo`;o00001Oooool4o`0000Sooooo0_l0000<ooooo`;o000000?oooooo`000?l0
00001_ooool7o`0000;ooooo0_l00003ooooo`?o00003?ooool2o`000003ooooool0003o000000Oo
oooo0_l00007ooooo`;o00000_ooool3o`000005ooooool0003o0000o`000?ooool09Ol000001?oo
oooo0000o`000?ooool2o`0001gooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0Toooo
o`;o00004?ooool2o`0000Gooooo0_l00009ooooo`Co00001?ooool2o`0000Kooooo1?l0000Noooo
o`;o000000?oooooo`000?l000001Ol00008ooooo`;o00000_ooool2o`0000kooooo0_l000000ooo
oooo0000o`000009oooooaWo000000?oooooo`000?l000000ol000000ooooooo0000o`00000@o`00
0004ooooool0003o0000ooooo`;o00007Oooool2o`0004Cooooo000Looooo`03o`000?oooooooooo
03Kooooo0_l0000@ooooo`Co00001?ooool2o`0000Oooooo0_l00009ooooo`;o00001Oooool2o`00
00;ooooo0_l00009ooooo`;o00005?ooool2o`0000gooooo0ol000000ooooooo0000o`000009oooo
o`Go00000ooooolVo`0000;ooooo0_l000000ooooooo0000o`00000@ooooo`;o00001Oooool3o`00
00Kooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00004_ooool2o`0000go
oooo0_l00009ooooo`;o00001Oooool2o`0000;ooooo0_l00002ooooo`;o00000_ooool2o`0000Co
oooo0_l000000ooooooo0000o`000006ooooo`;o00002oooool2o`0000Cooooo1_l0000<ooooo`;o
00000oooool2o`000003ooooool0003o000002Wo00000_ooool3o`0000kooooo0_l00005ooooo`?o
00001_ooool2o`0000Gooooo0ol0000looooo`007?ooool00ol0003oooooooooo`15ooooo`;o0000
00?oooooo`000?l000000_l000000ooooooo0000o`00000Tooooo`;o00000_ooool2o`0000Cooooo
1Ol00006ooooo`;o00002oooool2o`0000Cooooo1?l00003ooooo`;o00001_ooool5o`0000?ooooo
0_l000000ooooooo0000o`00000Yo`0000;ooooo0ol0000Dooooo`Co00003Oooool3o`0001Wooooo
0_l0000Qooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00003Oooool2o`000003ooooool0
003o000000?ooooo0_l0000<ooooo`?o00001?ooool2o`0000_ooooo2?l00008ooooo`;o00004?oo
ool2o`0000oooooo0_l00002ooooo`;o00000_ooool4o`0000Kooooo:?l00002ooooo`So00001_oo
ool2o`0000_ooooo0_l00008ooooo`;o00000_ooool2o`0001gooooo0_l0000Qooooo`007?ooool0
0ol0003oooooooooo`0fooooo`;o00000oooool3o`0000Oooooo0_l00004ooooo`?o000000?ooooo
o`000?l000002?ooool5o`0000Cooooo1?l000000ooooooo0000o`000004ooooo`[o00001?ooool2
o`0000_ooooo0_l00007ooooo`;o00004oooool2o`0000Cooooo1?l00003ooooobSo000000?ooooo
o`000?l000001?l00002ooooo`?o00000oooool4o`0001Gooooo0_l00002ooooo`?o0000?oooool0
01cooooo00?o0000ooooooooool0=_ooool2o`0000?ooooo0ol00007ooooo`;o00001?ooool3o`00
0003ooooool0003o000000;o00001_ooool5o`0000Kooooo0_l000000ooooooo0000o`000004oooo
o`_o00000oooool2o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l000004?ooool2o`00
00Kooooo0_l00003ooooo`;o00001Oooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool<
o`000003ooooool0003o000001?o000000Coooooo`000?l0003ooooo0ol00003ooooo`;o00000ooo
ool2o`0000kooooo0_l0000<ooooo`;o0000?oooool001cooooo0_l0000aooooo`;o00000_ooool4
o`0000?ooooo0_l00002ooooo`Co00003_ooool2o`0000?ooooo1?l00002ooooo`;o00002_ooool3
o`0000?ooooo2ol000000ooooooo0000o`000003ooooo`Co000000Coooooo`000?l0003o00000_oo
ool2o`0000oooooo0_l00005ooooo`?o00000oooool2o`0000Sooooo1ol00002ooooob;o00005?oo
ool2o`0000Oooooo0ol00009ooooo`;o00000_ooool2o`0003kooooo000Looooo`03o`000?oooooo
oooo033ooooo1_l00004ooooo`?o00000_ooool5o`0001;ooooo1?l00002ooooo`;o00002_ooool4
o`000003ooooool0003o000000[o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o
000000?o00000oooool4o`0000Kooooo0ol00004ooooo`;o00001Oooool2o`0000kooooo1_l00002
ooooo`ko000000?oooooo`000?l000003?l000000ooooooo0000o`000003o`000003ooooool0003o
000000kooooo0_l000000ooooooo0000o`000007ooooo`;o00002?ooool4o`0000;ooooo0_l0000n
ooooo`007?ooool00ol0003oooooooooo`0booooo`;o00001_ooool2o`0000Kooooo0_l0000Voooo
o`[o00000_ooool3o`000003ooooool0003o000000Co00000_ooool2o`0000Oooooo0ol00005oooo
o`?o00000oooool3o`0001Sooooo0_l000000ooooooo0000o`000005o`000003ooooool0003o0000
01Go00000_ooool2o`0000?ooooo1?l0000<ooooo`;o00002?ooool2o`0000Gooooo0_l00003oooo
o`;o0000A?ooool001cooooo00?o0000ooooooooool0<Oooool2o`0000;ooooo0_l00003ooooo`Co
000000?oooooo`000?l000001oooool2o`00013ooooo0ol00005ooooo`;o00000oooool3o`000003
ooooool0003o000001Co00002oooool3o`0000Cooooo0_l00004ooooo`?o00006?ooool2o`000004
ooooool0003o0000oooooaco000000Coooooo`000?l0003o00001?ooool4o`0000?ooooo1?l0000>
ooooo`;o00001Oooool2o`0004Wooooo000Looooo`03o`000?oooooooooo02cooooo0_l00003oooo
o`;o00000_ooool2o`0000Gooooo0_l000001?oooooo0000o`000?l00005ooooo`?o00004?ooool5
o`0000?ooooo0_l00003oooooa[o00003?ooool3o`0000Gooooo1_l000001?oooooo0000o`000?l0
0003ooooo`;o00000oooool2o`0000?ooooo1?l00007ooooo`;o00000_oooolNo`0000;ooooo0_l0
00000ooooooo0000o`000002o`0000?ooooo1?l0000=ooooo`;o00000oooool2o`000004ooooool0
003o0000o`0000;ooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00001ooo
ool3o`000003ooooool0003o000000Gooooo0_l000000ooooooo0000o`000002ooooo`;o00001Ooo
ool3o`0000cooooo0_l00009oooooaOo00002Oooool2o`0000Cooooo0_l00005ooooo`Co00000ooo
ool3o`0000?ooooo0_l000000ooooooo0000o`000002o`0000?ooooo1?l00006ooooo`Go000000?o
ooooo`000?l000006ol00002ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo0_l0
000>ooooo`;o000000?oooooo`000?l000001ol000001?oooooo0000o`000?l00013ooooo`007?oo
ool00ol0003oooooooooo`0eooooo`?o000000?oooooo`000?l000001_ooool4o`0000Wooooo0ol0
0009ooooo`;o00000oooool2o`0000;ooooo0_l00002oooooaSo00001Oooool2o`0000;ooooo0_l0
0002ooooo`;o00005?ooool5o`0000Gooooo0_l00005ooooo`;o000000?oooooo`000?l000001Ol0
00000ooooooo0000o`00000Ho`0000;ooooo0_l00002ooooo`?o000000?oooooo`000?l000002ooo
ool2o`0000Sooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00000_ooool2o`0004?ooooo
000Looooo`03o`000?oooooooooo03[ooooo1?l00003ooooo`;o00000oooool2o`0000cooooo0_l0
0004ooooo`;o00000oooool3o`000003ooooool0003o000000;ooooo0_l00002oooooaCo00000_oo
ool2o`000003ooooool0003o000000Kooooo0_l00004ooooo`;o00000_ooool2o`0000cooooo0_l0
0008ooooob[o00000_ooool3o`000003ooooool0003o000000oooooo0_l00006ooooo`;o00000ooo
ool2o`0000;ooooo0_l000000ooooooo0000o`000014ooooo`007?ooool00ol0003oooooooooo`0h
ooooo`So00001Oooool3o`0000cooooo0_l0000:ooooo`;o00001?ooool7o`000003ooooool0003o
000001?o000000Coooooo`000?l0003o00001_ooool2o`0000;ooooo0ol00002ooooo`;o00001ooo
ool2o`0000gooooo1Ol00002ooooo`;o00000_ooool3o`000003ooooool0003o000000;ooooo5_l0
0003ooooo`?o00006_ooool2o`0000[ooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0h
ooooo`;o00001?ooool2o`0000Gooooo0_l00009ooooo`;o00005?oooolMo`000004ooooool0003o
0000o`0000Kooooo0_l00002ooooo`;o00002Oooool2o`000004ooooool0003o0000ooooo`;o0000
1oooool2o`0000;ooooo0_l00004ooooo`[o000000?oooooo`000?l000001_l00002ooooo`go0000
0oooool2o`0000Kooooo0_l00006ooooo`;o00004_ooool3o`0000Sooooo0_l0000nooooo`007?oo
ool00ol0003oooooooooo`15ooooo`;o00002Oooool2o`0000?ooooo0_l0000?oooooa_o00003ooo
ool2o`0000Cooooo0_l00004ooooo`;o00001?ooool4o`0000Gooooo0ol000000ooooooo0000o`00
0004ooooo`Go000000?oooooo`000?l000000oooool3o`000003ooooool0003o000000;o00000_oo
ool6o`000003ooooool0003o000000;o000000?oooooo`000?l000002_ooool2o`0000Kooooo0_l0
00001?oooooo0000o`000?l00003ooooo`;o00002Oooool3o`0000Sooooo0_l0000nooooo`007?oo
ool00ol0003oooooooooo`11ooooo`;o00002_ooool2o`0000Kooooo0_l000000ooooooo0000o`00
0002ooooo`;o00002?oooolLo`0000kooooo0_l00004ooooo`Co00002?ooool4o`0000Kooooo0_l0
0002ooooo`;o00000oooool2o`000003ooooool0003o000000;o00001Oooool<o`000004ooooool0
003o0000ooooo`?o000000Coooooo`000?l0003o00001oooool2o`0000cooooo0ol00003ooooo`?o
0000Doooool001cooooo00?o0000ooooooooool0@Oooool2o`0000[ooooo0_l00002ooooo`?o0000
1?ooool2o`0000;ooooo0_l00006ooooo`;o000000?oooooo`000?l000006ol0000=ooooo`;o0000
0_ooool5o`0000Kooooo1_l000000ooooooo0000o`000005ooooo`Co00002?ooool2o`000003oooo
ool0003o000000Cooooo2?l00006ooooo`?o000000Coooooo`000?l0003ooooo0_l00005ooooo`;o
00003Oooool2o`0000Cooooo0_l000000ooooooo0000o`000006ooooo`;o00002?ooool2o`0003ko
oooo000Looooo`03o`000?oooooooooo043ooooo0_l000000ooooooo0000o`00000<ooooo`?o0000
1_ooool4o`0000Kooooo0_l000000ooooooo0000o`00000Ko`000003ooooool0003o000000Kooooo
0_l00002ooooo`;o00000_ooool5o`0000Kooooo0_l00005ooooo`;o00001Oooool2o`0000[ooooo
0_l000000ooooooo0000o`000002o`0000Gooooo0ol00002ooooo`;o00000_ooool4o`000003oooo
ool0003o000000;ooooo0_l0000@ooooo`;o00002oooool2o`000003ooooool0003o000000?ooooo
0ol00007ooooo`;o0000?_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Co
oooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo043ooooo0_l000000ooo
oooo0000o`000004ooooo`;o00001oooool2o`0000Kooooo0_l00003ooooo`;o00001_ooool5o`00
00;ooooo2?l000000ooooooo0000o`00000;o`000003ooooool0003o000000Kooooo0_l00006oooo
o`;o00007Oooool2o`0000Cooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l000000ooo
oooo0000o`000002o`000003ooooool0003o000000;ooooo1?l000001?oooooo0000o`000?l0000C
ooooo`;o000000?oooooo`000?l000002oooool2o`0000Cooooo0_l00002ooooo`;o0000@oooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RH
ob4Q8@06ooooo`03o`000?oooooooooo03Gooooo0ol00002ooooo`;o00003Oooool2o`0000cooooo
0_l00006ooooo`;o00001_oooolNo`0001;ooooo0_l0000Kooooo`;o00001oooool4o`0000;ooooo
0_l00002ooooo`?o00002oooool2o`0001Kooooo0_l00004ooooo`;o00002Oooool2o`0000Cooooo
0_l00013ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`0eooooo`?o00000_ooool2o`0000gooooo
0_l00009ooooo`;o000000?oooooo`000?l000003_oooolGo`000003ooooool0003o000000Go0000
4Oooool2o`0000Kooooo0_l00005ooooo`;o00003?ooool2o`0000Kooooo0_l0000:ooooo`;o0000
1Oooool2o`0000?ooooo0_l0000@ooooo`?o00000_ooool4o`0000Cooooo1?l00007ooooo`;o0000
1Oooool2o`0004;ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go
0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000>oooool2o`0000cooooo0_l00009ooooo`;o0000
4OoooolOo`0001Wooooo0_l00002ooooo`;o000000?oooooo`000?l000000oooool2o`0000oooooo
0ol00009ooooo`;o00001Oooool2o`000003ooooool0003o000000;o00003_ooool6o`000003oooo
ool0003o000000;o00001_ooool2o`000003ooooool0003o000000_ooooo0_l00012ooooo`0000?o
ooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
1_ooool00ol0003oooooooooo`0kooooo`;o00001_ooool2o`0000Kooooo1?l00006ooooo`;o0000
4?oooolMo`0000gooooo0_l00007ooooo`Co00001Oooool2o`0000Kooooo0ol0000?ooooo`;o0000
0_ooool6o`0000;ooooo0_l00007ooooo`;o00004?ooool3o`000004ooooool0003o0000ooooo`;o
00001?ooool3o`0000Cooooo0_l0001?ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooo
ooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0=oooool2o`0000;ooooo
0_l000000ooooooo0000o`000003ooooo`;o00001Oooool5o`0000Kooooo0_l0000@ooooo`Go0000
00?oooooo`000?l000002_l000000ooooooo0000o`000008o`000004ooooool0003o0000o`0000Wo
oooo0_l00007ooooo`Go00002oooool4o`0000_ooooo0_l00006ooooo`Ko00000_ooool3o`0001go
oooo1?l000001?oooooo0000o`000?ooool3o`0005Gooooo00001_ooooooMgMgoiRHV?ooooooV9RH
ogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0gooooo`;o00000_ooool2
o`000003ooooool0003o000000[ooooo1_l0000:ooooo`;o00003OoooolOo`0001;ooooo0_l00000
0ooooooo0000o`00000;ooooo`?o00002oooool3o`0000Sooooo0_l00005ooooo`;o00006_ooool2
o`000003ooooool0003o000000;o000000?oooooo`000?l000002oooool3o`0004_ooooo00001_oo
ooook^k^oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003ooooo
ooooo`0hooooo`;o00004_ooool4o`0000Oooooo0_l000000ooooooo0000o`00000=oooooa;o0000
00?oooooo`000?l000000_ooool3o`000003ooooool0003o000000;o00003Oooool2o`0000?ooooo
0_l0000;ooooo`;o00000_ooool2o`0000Wooooo1?l00009ooooo`;o00005?ooool2o`0000Cooooo
1?l00002ooooo`?o000000Coooooo`000?l0003ooooo1?l00003ooooo`;o00001_ooool3o`0004_o
oooo000Looooo`03o`000?oooooooooo03Sooooo0_l00006ooooo`;o00001?ooool4o`0000gooooo
0_l0000Booooo`co000000?oooooo`000?l000002?l00002ooooo`Co00003Oooool2o`0000Cooooo
0_l00004ooooo`;o00001?ooool2o`0000;ooooo0_l00009ooooo`;o00003_ooool3o`00013ooooo
0_l00002ooooo`Ko00000_ooool6o`000003ooooool0003o000000?o00000_ooool2o`0000?ooooo
0_l0001?ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o00000oooool5o`0001Kooooo0_l0
000;ooooo`[o000000?oooooo`000?l000002?l00004ooooo`;o00004Oooool5o`0000?ooooo0_l0
0008ooooo`;o00003_ooool2o`0000Wooooo0ol00006ooooo`;o00002oooool5o`0000Cooooo1_l0
0004ooooo`;o00001?ooool2o`000003ooooool0003o000000;o00000_ooool2o`0004Wooooo000L
ooooo`03o`000?oooooooooo04Gooooo0_l0000?ooooo`;o00002?ooool2o`0000Wooooo2?l00000
0ooooooo0000o`000008o`000003ooooool0003o000000Gooooo0_l0000;ooooo`;o000000Cooooo
o`000?l0003ooooo1Ol000000ooooooo0000o`00000Booooo`?o00001Oooool2o`0000;ooooo0_l0
00000ooooooo0000o`00000:ooooo`?o00000_ooool2o`0000Gooooo1?l000000ooooooo0000o`00
0002o`0000Wooooo0_l00003ooooo`?o000000?oooooo`000?l000000oooool2o`0000;ooooo0_l0
000Mooooo`;o0000:_ooool001cooooo00?o0000ooooooooool0E_ooool3o`0000Cooooo0_l0000<
oooooa?o00001oooool2o`0000Cooooo1?l00004ooooo`;o000000?oooooo`000?l000000_l00005
ooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`;o00000oooool2o`000004ooooool0
003o0000o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l00000
1?ooool2o`0000Cooooo1?l000000ooooooo0000o`000005ooooo`?o00001?ooool2o`0000Wooooo
1?l000001?oooooo0000o`000?l0000:ooooo`Co00006oooool2o`0002[ooooo000Looooo`03o`00
0?oooooooooo05Kooooo0ol00004ooooo`;o00003oooool:o`000003ooooool0003o000000;o0000
0oooool2o`0000?ooooo0_l00004ooooo`Co00001_ooool2o`000003ooooool0003o000000Wooooo
1?l000001?oooooo0000o`000?ooool3o`0000;ooooo0_l000001?oooooo0000o`000?l00002oooo
o`;o000000?oooooo`000?l000002oooool2o`0000Kooooo0_l00009ooooo`;o00000_ooool2o`00
00gooooo0_l0000>ooooo`Co0000Aoooool001cooooo00?o0000ooooooooool0??ooool2o`0000Ko
oooo0_l0000@ooooo`;o00001Oooool4o`0000oooooo1Ol000001?oooooo0000o`000?ooool2o`00
00Gooooo0_l00004ooooo`;o00000oooool2o`0000Sooooo0_l0000<ooooo`;o00001oooool2o`00
00Gooooo0ol00005ooooo`;o00002Oooool5o`0001Cooooo0ol00003ooooo`;o00001oooool3o`00
00Wooooo0_l00002ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0??ooool2o`0000Ko
oooo0_l0000Gooooo`So00003?ooool2o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`;o
00001Oooool3o`0000cooooo0_l0000Booooo`Go00000_ooool2o`000004ooooool0003o0000o`00
00?ooooo1ol000000ooooooo0000o`000003ooooo`Go00001_ooool4o`0000_ooooo0_l00003oooo
o`;o00002?ooool2o`0000Wooooo0_l00004ooooo`;o0000Aoooool001cooooo00?o0000oooooooo
ool0A?ooool2o`0000Cooooo0_l0000=ooooo`;o00001?ooool6o`000003ooooool0003o000000Wo
oooo0_l00006ooooo`;o00000_ooool4o`0000Gooooo0ol00008ooooo`;o00000_ooool3o`0000;o
oooo1?l0000;ooooo`Co00000oooool2o`000003ooooool0003o000000;ooooo1?l00002ooooo`Ko
000000?oooooo`000?l000002oooool4o`000004ooooool0003o0000o`0000Oooooo0_l00007oooo
o`;o00005?ooool3o`0004Oooooo000Looooo`03o`000?oooooooooo04Cooooo0ol00003ooooo`;o
000000?oooooo`000?l000002_ooool2o`0000Cooooo0ol00004ooooo`;o00005Oooool2o`0000;o
oooo0_l00003ooooo`;o000000?oooooo`000?l000001?ooool4o`0000?ooooo0_l00002ooooo`Co
00001oooool2o`000003ooooool0003o000000Kooooo0_l00005ooooo`;o00001?ooool4o`0000?o
oooo0_l0000<ooooo`;o00000_ooool3o`0000Gooooo1?l00003ooooo`;o00000_ooool2o`000003
ooooool0003o000000Sooooo0_l00007ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0
AOooool2o`0000Gooooo0ol00002ooooo`;o00000oooool3o`0002Cooooo1_l00006ooooo`;o0000
00Coooooo`000?l0003ooooo1?l000000ooooooo0000o`000002o`000003ooooool0003o000000Co
00001_ooool2o`000003ooooool0003o000000Cooooo1?l00003ooooo`;o00001_ooool2o`0001oo
oooo0_l00005ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Oooooo0ol00004ooooo`;o
0000Boooool001cooooo00?o0000ooooooooool0C?ooool2o`0000?ooooo0_l00003ooooo`?o0000
0_ooool2o`00027ooooo0ol0000:ooooo`?o00000oooool2o`000003ooooool0003o000000?ooooo
1_l000000ooooooo0000o`000003ooooo`;o00001oooool2o`0000Gooooo0_l00002ooooo`;o0000
0_ooool2o`0000?ooooo0_l000001?oooooo0000o`000?l0000=ooooo`;o00003_ooool2o`000003
ooooool0003o000000;o00002Oooool2o`000003ooooool0003o000000;ooooo0_l0001;ooooo`00
7?ooool2o`0002cooooo0_l0000Hooooo`;o00001oooool2o`0000Kooooo0_l00003ooooo`;o0000
1oooool2o`0001Sooooo0_l00007ooooo`;o00000_ooool4o`0000;ooooo0_l00007ooooo`;o0000
0_ooool4o`0000?ooooo0ol00003ooooo`?o00002oooool2o`0000;ooooo0_l000000ooooooo0000
o`000002o`000005ooooool0003o0000o`000?ooool00_l00005ooooo`;o00000oooool2o`0000ko
oooo0_l00003ooooo`;o00001_ooool2o`0000;ooooo1?l00004ooooo`;o0000BOooool001cooooo
00?o0000ooooooooool0:oooool2o`0001Cooooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo
0_l00005ooooo`;o00001Oooool2o`0000Kooooo0_l00006ooooo`;o00006Oooool5o`000003oooo
ool0003o000000Sooooo2ol00004ooooo`;o00000oooool5o`0000gooooo0_l000000ooooooo0000
o`000007ooooo`?o00001?ooool2o`000004ooooool0003o0000o`0000Sooooo0_l0000Aooooo`?o
00000_ooool2o`0000Kooooo0_l00019ooooo`007?ooool00ol0003oooooooooo`0looooo`;o0000
0oooool2o`0000;ooooo0_l00002ooooo`;o00002?ooool4o`0000Gooooo0_l00003ooooo`;o0000
2Oooool2o`0000oooooo0_l000000ooooooo0000o`000002o`0000;ooooo1_l00008ooooo`;o0000
00?oooooo`000?l000002_l00002ooooo`;o00001?ooool2o`000003ooooool0003o000001Cooooo
0_l00004ooooo`;o00001oooool3o`0000;ooooo0_l00004ooooo`;o00004Oooool2o`0000?ooooo
0_l000000ooooooo0000o`00000?ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0??oo
ool3o`0000Kooooo0_l00004ooooo`;o00001_ooool4o`0000Kooooo0_l00002ooooo`?o00002Ooo
ool2o`000003ooooool0003o000000;o00002Oooool2o`000003ooooool0003o000000;o00000_oo
ool2o`0000[ooooo3Ol000000ooooooo0000o`000005o`0000Cooooo0_l0000Aooooo`;o00000ooo
ool3o`00017ooooo0ol00002ooooo`;o00001?ooool3o`00017ooooo0_l000000ooooooo0000o`00
000?ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0?Oooool2o`000003ooooool0003o
000000Wooooo0_l00008ooooo`;o00001_ooool2o`0000?ooooo0_l00009ooooo`Oo00003?ooool2
o`0000Cooooo0_l00003ooooo`;o00001OoooolDo`000003ooooool0003o000000;ooooo0_l00003
ooooo`;o000000?oooooo`000?l000002Oooool2o`0000?ooooo0_l00009ooooo`Co00001Oooool2
o`0000?ooooo0_l00004ooooo`?o00003Oooool2o`0005Gooooo000Looooo`03o`000?oooooooooo
043ooooo0_l0000Iooooo`;o00000oooool3o`0000Gooooo2Ol00003ooooo`;o00002_ooool2o`00
00Cooooo0_l00003ooooo`?o00000ooooolHo`000003ooooool0003o000000Cooooo0_l000000ooo
oooo0000o`00000Iooooo`Co00000_ooool2o`0000[ooooo0_l00005ooooo`;o00002Oooool4o`00
05?ooooo000Looooo`03o`000?oooooooooo03_ooooo0_l0000Looooo`Co00000_ooool4o`0000Go
oooo2ol000000ooooooo0000o`000002o`0001Cooooo0_l000000ooooooo0000o`000008o`000003
ooooool0003o000000Co000000?oooooo`000?l000001_l000000ooooooo0000o`00000<ooooo`;o
00000oooool2o`000003ooooool0003o000000cooooo1?l00002ooooo`;o00002_ooool2o`0000Go
oooo1?l00009ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0>oooool2o`0001cooooo
0_l00004ooooo`Co00001oooool2o`0000?ooooo2Ol0000Gooooo`;o000000?oooooo`000?l00000
3?l00002ooooo`Oo00000_ooool2o`0000_ooooo0_l00003ooooo`;o000000?oooooo`000?l00000
3?ooool2o`0001Wooooo0_l0000;ooooo`;o00003?ooool2o`0004?ooooo000Looooo`03o`000?oo
oooooooo04Oooooo0_l00005ooooo`;o00004?ooool2o`0000Gooooo0_l000000ooooooo0000o`00
0006ooooo`Co00001?ooool2o`0000oooooo0_l00003oooooa[o000000?oooooo`000?l000003ooo
ool2o`0000Kooooo0_l0000>ooooo`?o00002Oooool2o`0001Cooooo0_l0000<ooooo`Co0000@Ooo
ool001cooooo00?o0000ooooooooool0<oooool2o`0001;ooooo0_l00005ooooo`;o00001oooool2
o`0000Oooooo0ol00004ooooo`;o00004Oooool2o`0000?ooooo0_l0000:ooooo`;o00000ooooolK
o`00017ooooo0_l00006ooooo`;o00003_ooool3o`000003ooooool0003o000000Kooooo0_l00003
ooooo`;o00000oooool2o`0000Kooooo0_l0000Booooo`;o0000@Oooool001cooooo00?o0000oooo
ooooool0<oooool2o`0001kooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l00002
ooooo`;o00001_ooool2o`0001Cooooo1?l00004ooooo`;o00002?oooolJo`0000Wooooo0_l0000B
ooooo`?o00001Oooool2o`0000Gooooo0ol000000ooooooo0000o`000008ooooo`;o000000?ooooo
o`000?l000000_l00006ooooo`;o0000EOooool001cooooo00?o0000ooooooooool0?oooool2o`00
00[ooooo0_l00006ooooo`;o00001?ooool3o`000003ooooool0003o000000Gooooo0_l00003oooo
o`;o00002Oooool2o`0000;ooooo0_l00007ooooo`;o00001?ooool2o`0000Sooooo5ol000001?oo
oooo0000o`000?l00008ooooo`;o00002Oooool3o`0000?ooooo0_l000000ooooooo0000o`000002
o`0000Cooooo0_l00005ooooo`;o00000_ooool2o`0000Cooooo0_l00005ooooo`Co00001_ooool2
o`0005Gooooo000Looooo`03o`000?oooooooooo03oooooo0_l0000:ooooo`;o000000?oooooo`00
0?l000000oooool2o`0000Cooooo0_l00002ooooo`;o00001Oooool2o`0000?ooooo0_l00008oooo
o`?o00000_ooool2o`000004ooooool0003o0000o`0001Cooooo5_l000001?oooooo0000o`000?l0
000?ooooo`;o00000_ooool3o`0000;ooooo0ol00003ooooo`;o00005Oooool2o`0000Sooooo0_l0
0005ooooo`;o00001Oooool2o`000003ooooool0003o000004_ooooo000Looooo`03o`000?oooooo
oooo04Cooooo0_l00005ooooo`;o000000Coooooo`000?l0003ooooo0_l00006ooooo`?o000000?o
ooooo`000?l000001Oooool2o`0000;ooooo0ol00008ooooo`;o00000oooool2o`000004ooooool0
003o0000o`0001Cooooo6Ol00005ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo
0_l000000ooooooo0000o`000004ooooo`;o00001Oooool2o`0000;ooooo0_l00004ooooo`;o0000
5?ooool2o`0000Cooooo0_l00006ooooo`;o000000?oooooo`000?l00000Boooool001cooooo00?o
0000ooooooooool0A?ooool2o`0000?ooooo1?l00004ooooo`;o00001_ooool3o`0000Cooooo0_l0
0002ooooo`;o000000Coooooo`000?l0003o00007oooool2o`0000Gooooo6Ol00007ooooo`;o0000
00?oooooo`000?l000000_ooool3o`0000;ooooo1?l000001?oooooo0000o`000?l00007ooooo`Ko
00001?ooool4o`0000Cooooo0_l00003ooooo`;o00003Oooool2o`0005Kooooo000Looooo`03o`00
0?oooooooooo04Cooooo0_l00003ooooo`;o00003oooool2o`0000Cooooo0_l00002ooooo`;o0000
00?oooooo`000?l000008?ooool2o`0000Gooooo0_l000000ooooooo0000o`00000?o`000004oooo
ool0003o0000o`00013ooooo0_l000001?oooooo0000o`000?l00003ooooo`Co00002?ooool2o`00
00;ooooo0_l00004ooooo`Co00000_ooool4o`000003ooooool0003o000006Gooooo000Looooo`;o
0000A?ooool4o`0001?ooooo0_l00004ooooo`;o00007_ooool2o`00017ooooo5?l0000>ooooo`;o
00001?ooool2o`0000Gooooo0ol00004ooooo`;o00000_ooool2o`0000;ooooo0_l00004ooooo`Co
00001?ooool2o`00017ooooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`13ooooo`Co0000
6Oooool6o`0000Cooooo0_l0000Dooooo`;o00003oooool2o`000003ooooool0003o0000013o0000
1_ooool2o`0000Kooooo1?l00009ooooo`Co00001?ooool2o`0000cooooo1?l00003ooooo`Go0000
3oooool2o`0005Gooooo000Looooo`03o`000?oooooooooo04oooooo0_l0000?ooooo`Ko00001?oo
ool2o`0000Oooooo0_l0000Dooooo`;o00001_ooool6o`000003ooooool0003o000000co00001_oo
ool2o`0000Cooooo1_l00009ooooo`;o00001Oooool2o`0000Cooooo1Ol0000;ooooo`Go00000_oo
ool2o`0006;ooooo000Looooo`03o`000?oooooooooo04oooooo0_l0000Oooooo`;o000000?ooooo
o`000?l000001_ooool2o`0000Sooooo0_l00002ooooo`;o00001_oooolFo`0000_ooooo0_l00007
ooooo`Ko00001oooool4o`0000;ooooo1Ol0000>ooooo`;o00000_ooool2o`000003ooooool0003o
000005oooooo000Looooo`03o`000?oooooooooo06Cooooo0_l00006ooooo`;o000000Coooooo`00
0?l0003o00002Oooool2o`0000Sooooo0_l0000:ooooo`;o00000_ooool=o`0000?ooooo0_l0000D
ooooo`Ko00002Oooool2o`0000Cooooo0_l00003ooooo`;o00002_ooool2o`0000;ooooo0_l00000
0ooooooo0000o`000003ooooo`;o0000F_ooool001cooooo00?o0000ooooooooool0E_ooool2o`00
00cooooo0_l00006ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Sooooo`[o00007?ooool3
o`0000Sooooo0_l00004ooooo`Co00000oooool2o`0000kooooo0_l00002ooooo`Ko0000F_ooool0
01cooooo00?o0000ooooooooool0C_ooool2o`0000Kooooo0_l00005ooooo`;o00004oooool2o`00
023ooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0ol0000@ooooo`;o00002_ooool4
o`0000Oooooo0_l00004ooooo`;o00000_ooool2o`000003ooooool0003o000001;ooooo1?l0000A
ooooo`;o0000BOooool001cooooo00?o0000ooooooooool0C_ooool2o`0000Cooooo0_l00002oooo
o`;o00000oooool2o`000003ooooool0003o000001Wooooo0_l0000?ooooo`;o00001_ooool2o`00
00Sooooo0_l0000Aooooo`;o00003?ooool2o`00017ooooo0_l00003ooooo`;o00001?ooool2o`00
00Cooooo0_l00004ooooo`;o00004oooool2o`0004Wooooo000Looooo`03o`000?oooooooooo05Co
oooo0_l00002ooooo`Co000000Coooooo`000?l0003ooooo0_l0000<ooooo`;o00002?ooool2o`00
0003ooooool0003o000000oooooo1?l00007ooooo`;o0000<_ooool2o`0000[ooooo0_l00004oooo
o`So00001?ooool2o`0005kooooo000Looooo`03o`000?oooooooooo05Gooooo0_l00003ooooo`;o
00002oooool2o`000003ooooool0003o000000;ooooo0_l00008ooooo`;o00003Oooool2o`0000Go
oooo0_l00006ooooo`?o00003oooool2o`00027ooooo0_l000000ooooooo0000o`00000>ooooo`Ko
00001_ooool3o`0005cooooo000Looooo`03o`000?oooooooooo05Cooooo0ol00003ooooo`;o0000
2oooool2o`000003ooooool0003o000001_ooooo0_l0000=ooooo`;o00001oooool2o`000003oooo
ool0003o000000;o00000_ooool2o`0001cooooo0_l00006ooooo`;o00004_ooool2o`000004oooo
ool0003o0000o`0000;ooooo0ol0001Looooo`007?ooool00ol0003oooooooooo`1>ooooo`;o0000
1?ooool2o`0000Kooooo0_l00005ooooo`;o00002?ooool3o`0001cooooo0_l00005ooooo`;o0000
00?oooooo`000?l000001oooool2o`000003ooooool0003o000000;o00005oooool2o`0000Oooooo
0_l0000<ooooo`Co00001?ooool2o`0000Cooooo0_l000001?oooooo0000o`000?l0001Qooooo`00
7?ooool00ol0003oooooooooo`1>ooooo`;o00002Oooool2o`000003ooooool0003o000000;ooooo
0_l000000ooooooo0000o`000003o`0000Gooooo0ol0000Gooooo`;o00000oooool2o`000003oooo
ool0003o000000;ooooo0_l00008ooooo`;o00007_ooool4o`0000Gooooo1?l0000:ooooo`Co0000
1?ooool2o`0000Oooooo1?l0001Pooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o00001Ooo
ool2o`0000?ooooo0ol000001?oooooo0000o`000?l0000Kooooo`;o00001Oooool3o`0000cooooo
0_l00008ooooo`;o00005_ooool2o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`;o0000
5_ooool3o`00063ooooo000Looooo`03o`000?oooooooooo05kooooo0_l00006ooooo`;o000000Co
ooooo`000?l0003o00008_ooool4o`0001Gooooo0_l0000Iooooo`;o000000?oooooo`000?l00000
0ol00004ooooo`;o00003Oooool2o`0000?ooooo0_l0001Uooooo`007?ooool00ol0003ooooooooo
o`1Aooooo`;o00000oooool2o`0000Kooooo0_l000000ooooooo0000o`000003ooooo`;o00002Ooo
ool2o`0000Oooooo0_l00002ooooo`;o00003_ooool4o`0000Kooooo0_l00007ooooo`;o00007ooo
ool2o`0000;ooooo1?l0000Cooooo`?o00000_ooool2o`0000;ooooo0_l0001Qooooo`007?ooool2
o`0005;ooooo0_l00003ooooo`;o00000_ooool2o`0000Gooooo0_l0000>ooooo`;o000000?ooooo
o`000?l000001?ooool2o`000004ooooool0003o0000o`0000kooooo0_l00003ooooo`;o00000ooo
ool2o`0000Kooooo0ol0000Hooooo`;o00001_ooool2o`0001Gooooo0_l00002ooooo`;o00000_oo
ool6o`00067ooooo000Looooo`03o`000?oooooooooo05[ooooo0_l0000;ooooo`;o00002oooool2
o`0000Oooooo0_l0000Aooooo`;o000000Coooooo`000?l0003o00002_ooool2o`0000Cooooo0_l0
000>ooooo`;o00000oooool2o`0000;ooooo2?l000000ooooooo0000o`00000;ooooo`;o00000ooo
ool2o`0000Sooooo0ol0001Rooooo`007?ooool00ol0003oooooooooo`1Wooooo`;o00000_ooool2
o`0000?ooooo0_l00002ooooo`;o00001_ooool2o`0001;ooooo0_l00002ooooo`;o00002Oooool2
o`0000Cooooo0ol0000>ooooo`;o00000oooool2o`0000;ooooo1?l00002ooooo`;o000000?ooooo
o`000?l000000_ooool2o`0000Oooooo0_l00002ooooo`;o00003?ooool2o`000003ooooool0003o
000005gooooo000Looooo`03o`000?oooooooooo06;ooooo0_l00007ooooo`?o00000_ooool2o`00
00;ooooo0_l00006ooooo`;o00006?ooool2o`0000?ooooo0_l00002ooooo`;o00001?ooool2o`00
01Cooooo0_l0000?ooooo`;o00000oooool3o`0000?ooooo1Ol00002ooooo`Co00001Oooool2o`00
0003ooooool0003o000000;o0000Foooool001cooooo00?o0000ooooooooool0H_ooool4o`000003
ooooool0003o000000?ooooo0ol00005ooooo`;o00003_ooool2o`0000;ooooo0_l0000;ooooo`?o
00000oooool2o`0000;ooooo1?l0000Pooooo`;o00003?ooool3o`0000?ooooo0_l000001?oooooo
0000o`000?ooool7o`0000Sooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o
00002_ooool2o`000003ooooool0003o000000Cooooo0_l00005ooooo`;o00002Oooool2o`0000?o
oooo0_l00002ooooo`;o00002oooool2o`0000Cooooo0_l00002ooooo`Ko00002oooool2o`0000?o
oooo0_l00004ooooo`;o00001_ooool2o`0001Sooooo0_l00003ooooo`;o0000IOooool001cooooo
00?o0000ooooooooool0F?ooool2o`0000oooooo0_l000001?oooooo0000o`000?ooool5o`0000Wo
oooo1?l0000>ooooo`;o00002?ooool4o`0000Cooooo1?l0000;ooooo`;o00000oooool2o`0000Co
oooo0_l0000:ooooo`;o00005_ooool2o`0006Sooooo000Looooo`03o`000?oooooooooo06Wooooo
0_l000001?oooooo0000o`000?ooool5o`0000Wooooo0_l0000@ooooo`;o00002?ooool4o`0000Co
oooo1?l00006ooooo`;o00006_ooool2o`0001Kooooo0_l0001Xooooo`007?ooool00ol0003ooooo
ooooo`1Nooooo`;o00004?ooool2o`000003ooooool0003o000000;o00002oooool4o`0001?ooooo
0_l00007ooooo`;o000000Goooooo`000?l0003o0000ooooo`04o`0002Gooooo1Ol0001booooo`00
7?ooool00ol0003oooooooooo`1Nooooo`;o00004?ooool2o`000003ooooool0003o000000;o0000
2oooool4o`0001[ooooo1?l000001Ooooooo0000o`000?l0003ooooo00;o00009_ooool6o`0000;o
oooo0_l0001^ooooo`007?ooool00ol0003oooooooooo`1cooooo`;o00007?ooool4o`0000_ooooo
0_l00007ooooo`;o00002?ooool2o`0001cooooo0_l00003ooooo`Go0000K_ooool001cooooo00?o
0000ooooooooool0K_ooool2o`000003ooooool0003o000000;o00001?ooool2o`0001Kooooo1Ol0
000;ooooo`;o00001_ooool3o`0000Oooooo0_l00003ooooo`;o00001oooool2o`0000Sooooo0_l0
0007ooooo`Go0000L?ooool001cooooo00?o0000ooooooooool0JOooool2o`0000?ooooo0_l00000
0ooooooo0000o`000003o`0000?ooooo0_l0000?ooooo`Co00001_ooool2o`0000Oooooo0_l00002
ooooo`;o00001Oooool4o`0000;ooooo0_l00004ooooo`;o00000_ooool2o`0000Cooooo0_l00000
0ooooooo0000o`000008ooooo`;o00001_ooool3o`000003ooooool0003o0000073ooooo000Loooo
o`03o`000?oooooooooo06Wooooo0_l00003ooooo`;o00001?ooool2o`00017ooooo0_l000000ooo
oooo0000o`000002o`0000oooooo0_l00002ooooo`;o00001Oooool2o`0000Cooooo0_l00004oooo
o`;o00002?ooool2o`0001?ooooo0ol000000ooooooo0000o`00001`ooooo`0000Koooooonk^k_lb
<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o
0000ooooooooool0JOooool2o`0000;ooooo0_l0000=ooooo`;o00000oooool2o`0000Cooooo0_l0
000Aooooo`;o00001Oooool4o`0000gooooo0_l0000Hooooo`;o0000Noooool00006oooooomgMgOo
V9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03
o`000?oooooooooo06gooooo0_l00007ooooo`;o00001?ooool3o`0000;ooooo0_l00005ooooo`;o
00004?ooool2o`0000Oooooo0_l00002ooooo`;o00001_ooool2o`000003ooooool0003o000000;o
oooo0_l0000Dooooo`?o0000N_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool0
2Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0J_ooool2o`0000Oo
oooo0_l000000ooooooo0000o`000004ooooo`?o00002Oooool4o`0000gooooo0_l00008ooooo`;o
00000_ooool2o`0000Kooooo0_l000000ooooooo0000o`000002ooooo`;o00005Oooool2o`0001[o
oooo0_l0001Nooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05oc8b
<_nHV9SooooooiRHV?lb<S801_ooool3o`0006[ooooo0_l00007ooooo`;o000000?oooooo`000?l0
00002oooool2o`0000?ooooo1?l00003ooooo`;o00002?ooool4o`000003ooooool0003o0000013o
oooo1?l0000Gooooo`;o00007?ooool2o`0005kooooo00000ooooooo0000ooooo`02ooooo`03o`00
0?oooooooooo00Wooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo06ko
oooo0_l0000<ooooo`;o00001Oooool2o`0000[ooooo1?l00005ooooo`Go000000?oooooo`000?l0
00003Oooool2o`000004ooooool0003o0000o`00017ooooo0_l00005ooooo`;o0000O?ooool00003
ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol@413o^[Zjoooooonj^[[o410@
00Kooooo00?o0000ooooooooool0K_ooool2o`000003ooooool0003o000000Wooooo0_l00002oooo
o`;o00003oooool2o`0000Gooooo1?l00003ooooo`;o00003?ooool2o`0000Gooooo0_l00008oooo
o`?o00000oooool2o`0008?ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000
okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo077ooooo0_l0000=ooooo`;o00000_oo
ool2o`0000Kooooo0ol00004ooooo`;o00002_ooool2o`0000cooooo0_l00005ooooo`;o00002?oo
ool3o`0000Kooooo0_l00009ooooo`;o0000MOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^
2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0Q?ooool2o`0000Ko
oooo0ol00004ooooo`;o00002Oooool2o`0000gooooo0_l0000Hooooo`;o00000oooool2o`0000Co
oooo0_l0001eooooo`007?ooool00ol0003oooooooooo`1aooooo`;o00009Oooool2o`0000Cooooo
0_l0000/ooooo`;o0000Noooool001cooooo00?o0000ooooooooool0LOooool2o`0001Oooooo0ol0
000;ooooo`;o00002?ooool2o`0002cooooo0_l0001gooooo`007?ooool00ol0003oooooooooo`1n
ooooo`;o00002_ooool3o`0000_ooooo0_l00008ooooo`;o00002Oooool3o`0000?ooooo0_l0000?
ooooo`;o00001?ooool3o`0000?ooooo0_l0001gooooo`007?ooool00ol0003oooooooooo`1foooo
o`;o000000?oooooo`000?l000000oooool2o`0000Kooooo0_l000001Ooooooo0000o`000?l0003o
oooo00;o00000_ooool2o`0000Cooooo0_l0000=ooooo`;o00001Oooool3o`0000?ooooo0_l00007
ooooo`;o00001Oooool3o`0000Cooooo0ol00003ooooo`;o0000Moooool001cooooo00?o0000oooo
ooooool0M_ooool2o`000003ooooool0003o000000_ooooo0_l000001Ooooooo0000o`000?l0003o
oooo00;o000000Coooooo`000?l0003o00000oooool3o`0000cooooo0ol00006ooooo`Ko00002?oo
ool3o`0000Cooooo0_l00024ooooo`007?ooool00ol0003oooooooooo`1iooooo`;o00004Oooool2
o`0000;ooooo0_l00004ooooo`Co00002oooool2o`0000Oooooo1_l00005ooooo`;o00000_ooool2
o`0008[ooooo000Looooo`03o`000?oooooooooo07_ooooo0_l0000>ooooo`Go00001_ooool4o`00
01;ooooo0_l0000;ooooo`;o00003_ooool6o`0007[ooooo000Looooo`03o`000?oooooooooo07_o
oooo0_l0000>ooooo`;o000000?oooooo`000?l000001_ooool3o`00017ooooo1?l0000@ooooo`Co
00001oooool6o`0007[ooooo000Looooo`03o`000?oooooooooo083ooooo0_l00005ooooo`;o0000
8?ooool3o`0001;ooooo1?l00005ooooo`;o0000P?ooool001cooooo00?o0000ooooooooool0P?oo
ool2o`000003ooooool0003o000000;ooooo0_l0000:ooooo`?o00004?ooool2o`000003ooooool0
003o000001Gooooo0_l00005ooooo`;o0000P?ooool001cooooo00?o0000ooooooooool0O?ooool2
o`0000Gooooo0_l000001?oooooo0000o`000?l0000:ooooo`?o00004?ooool2o`0001_ooooo0_l0
0024ooooo`007?ooool2o`0007gooooo0_l00008ooooo`;o00004oooool3o`0000Kooooo0_l0000M
ooooo`;o00000_ooool2o`00083ooooo000Looooo`03o`000?oooooooooo09_ooooo0ol00006oooo
o`Co00007oooool2o`00083ooooo000Looooo`03o`000?oooooooooo0:Kooooo0_l0002Qooooo`00
7?ooool00ol0003oooooooooo`2<ooooo`;o0000^oooool001cooooo00?o0000ooooooooool0S?oo
ool2o`000;_ooooo000Looooo`03o`000?oooooooooo08gooooo0_l0002jooooo`007?ooool00ol0
003oooooooooo`20ooooo`;o00002oooool2o`000;[ooooo000Looooo`03o`000?oooooooooo083o
oooo0_l00037ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0;;ooooo1?l0002Cooooo`00
7?ooool00ol0003oooooooooo`2Uooooo`;o00002oooool4o`0009?ooooo000Looooo`03o`000?oo
oooooooo0:Gooooo0_l0002Rooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`004_ooool4o`000003oa0@4?oooooooooo
00?ooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool3o`000?oooooo
B_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3o
oooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000oooooooo
ool0oooooomBooooo`004_ooool00omEEEGoIVIVo`00003ooooooeCooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo002Qooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@oooo
ooooool05_ooool4o`000003oa0@4?oooooooooo00;ooooo0_l000000ol@413oooooooooo`02oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kXcooooo002Rooooo`05o`000?oo
ooooooooooooool000002Oooool6o`0000cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`2<ooooo`00
X_ooool01Ol0003ooooooooooooooooo000001_ooooo00?o0000ooooooooool00_ooool5o`0000Ko
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@08cooooo002Rooooo`05
o`000?ooooooooooooooool000002Oooool6o`0000cooooo00?o0000ooooooooool00_ooool01?m4
A4CogMgMooooool00007ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
002<ooooo`00X_ooool01Ol0003oQhN7oooooonYZJWo000001_ooooo00?o0000ooooooooool00_oo
ool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`00002<ooooo`00XOooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo01Wooooo
00?o0000ooooooooool00oooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@402<ooooo`00`_ooool00ol0003oooooooooo`03ooooo`03onk^
k_m4A4Co000000Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg08co
oooo0030ooooo`03oeEEEOmVIVKo000000Kooooo00?oMgMgo`000?ooool01?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0S?ooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1416) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.55358 .36974 Mdot
.53051 .37489 Mdot
.3647 .55046 Mdot
.64712 .55138 Mdot
.48052 .79867 Mdot
.3484 .58386 Mdot
.35234 .37025 Mdot
.36284 .41493 Mdot
.37084 .54666 Mdot
.47126 .32051 Mdot
.38893 .43284 Mdot
.67472 .48805 Mdot
.38665 .39932 Mdot
.60986 .56149 Mdot
.79292 .6987 Mdot
.55791 .52898 Mdot
.55176 .3694 Mdot
.5113 .67377 Mdot
.56737 .55721 Mdot
.35851 .59987 Mdot
.58573 .31413 Mdot
.61371 .55856 Mdot
.56336 .33809 Mdot
.60927 .56143 Mdot
.63916 .53182 Mdot
.55856 .32912 Mdot
.50281 .31809 Mdot
.62329 .50767 Mdot
.58416 .51706 Mdot
.38195 .43439 Mdot
.54885 .66086 Mdot
.68928 .77132 Mdot
.56338 .59131 Mdot
.7031 .69557 Mdot
.36947 .37941 Mdot
.71244 .42693 Mdot
.34936 .57139 Mdot
.38171 .42161 Mdot
.38936 .4224 Mdot
.3581 .40398 Mdot
.3696 .41544 Mdot
.54447 .34446 Mdot
.45117 .23364 Mdot
.34458 .47591 Mdot
.62169 .48599 Mdot
.33697 .75793 Mdot
.65074 .43726 Mdot
.61652 .58096 Mdot
.52153 .31929 Mdot
.32811 .64598 Mdot
.29295 .45383 Mdot
.37763 .368 Mdot
.38231 .59349 Mdot
.31701 .17587 Mdot
.39492 .3918 Mdot
.68735 .53071 Mdot
.3595 .5643 Mdot
.60695 .54369 Mdot
.60445 .5591 Mdot
.70204 .32137 Mdot
.67083 .52434 Mdot
.47998 .68796 Mdot
.50397 .37519 Mdot
.45613 .53531 Mdot
.37078 .56811 Mdot
.39407 .42614 Mdot
.51553 .36136 Mdot
.38852 .38692 Mdot
.53662 .56033 Mdot
.37392 .52105 Mdot
.62375 .58375 Mdot
.38856 .43128 Mdot
.57699 .30863 Mdot
.6015 .51648 Mdot
.28329 .63871 Mdot
.30074 .7397 Mdot
.42461 .66756 Mdot
.7057 .40133 Mdot
.69642 .31335 Mdot
.35583 .68766 Mdot
.61345 .49405 Mdot
.5515 .72221 Mdot
.30159 .73229 Mdot
.52455 .30672 Mdot
.563 .56789 Mdot
.50311 .63163 Mdot
.60715 .51524 Mdot
.41538 .81909 Mdot
.6672 .57443 Mdot
.5026 .5809 Mdot
.35816 .53447 Mdot
.53862 .31879 Mdot
.64889 .54596 Mdot
.58401 .52753 Mdot
.73874 .3392 Mdot
.60492 .58817 Mdot
.62533 .54922 Mdot
.51227 .32642 Mdot
.38247 .37013 Mdot
.6826 .54453 Mdot
.41109 .52959 Mdot
.32403 .56924 Mdot
.66111 .52233 Mdot
.35225 .52545 Mdot
.56785 .30433 Mdot
.58471 .52784 Mdot
.39366 .41587 Mdot
.66491 .53919 Mdot
.29213 .32018 Mdot
.5512 .36641 Mdot
.60165 .50603 Mdot
.43707 .66702 Mdot
.64834 .32152 Mdot
.53727 .31175 Mdot
.35401 .46792 Mdot
.56817 .55359 Mdot
.62022 .53809 Mdot
.51246 .35798 Mdot
.31977 .55652 Mdot
.38768 .80033 Mdot
.50621 .33411 Mdot
.39501 .44098 Mdot
.57952 .3003 Mdot
.6971 .51377 Mdot
.37637 .57339 Mdot
.34821 .4711 Mdot
.33534 .29427 Mdot
.57971 .67287 Mdot
.60847 .51789 Mdot
.46635 .24127 Mdot
.33293 .59004 Mdot
.52817 .33241 Mdot
.38566 .38927 Mdot
.59339 .60335 Mdot
.54239 .36037 Mdot
.40142 .43043 Mdot
.46305 .65792 Mdot
.26778 .40579 Mdot
.57487 .33115 Mdot
.50804 .4346 Mdot
.39973 .37536 Mdot
.35903 .37513 Mdot
.8192 .54384 Mdot
.51577 .3486 Mdot
.45161 .68847 Mdot
.37797 .38785 Mdot
.62333 .66081 Mdot
.63222 .48734 Mdot
.53339 .71363 Mdot
.39273 .20293 Mdot
.70428 .67859 Mdot
.25227 .4744 Mdot
.44311 .67201 Mdot
.40646 .37475 Mdot
.6362 .54656 Mdot
.55886 .31924 Mdot
.56081 .33456 Mdot
.67026 .52403 Mdot
.64613 .5249 Mdot
.63306 .58579 Mdot
.5945 .57389 Mdot
.54923 .60968 Mdot
.62944 .59923 Mdot
.64671 .42488 Mdot
.54384 .31663 Mdot
.64214 .55266 Mdot
.3861 .58398 Mdot
.60562 .47282 Mdot
.3767 .42629 Mdot
.61211 .54969 Mdot
.64708 .54852 Mdot
.65325 .49909 Mdot
.37013 .36827 Mdot
.65181 .79379 Mdot
.62551 .33191 Mdot
.62919 .78813 Mdot
.51195 .50477 Mdot
.3905 .5529 Mdot
.61773 .51587 Mdot
.47062 .68838 Mdot
.7604 .44536 Mdot
.65127 .56269 Mdot
.11244 .48826 Mdot
.62244 .55605 Mdot
.53647 .81581 Mdot
.56445 .48087 Mdot
.66015 .75361 Mdot
.56168 .70569 Mdot
.63282 .53128 Mdot
.48565 .27078 Mdot
.3478 .36333 Mdot
.4104 .55723 Mdot
.37088 .41 Mdot
.38264 .58775 Mdot
.36376 .55575 Mdot
.43913 .5562 Mdot
.67254 .48279 Mdot
.58127 .4848 Mdot
.64572 .58707 Mdot
.34235 .51835 Mdot
.49619 .34901 Mdot
.43969 .66065 Mdot
.52776 .38113 Mdot
.579 .8512 Mdot
.27001 .61296 Mdot
.3596 .42304 Mdot
.47135 .65553 Mdot
.33642 .54178 Mdot
.3651 .53482 Mdot
.44328 .66373 Mdot
.58627 .54404 Mdot
.51799 .35134 Mdot
.78207 .61173 Mdot
.25348 .36034 Mdot
.84231 .37571 Mdot
.51695 .32007 Mdot
.46718 .26386 Mdot
.36766 .42287 Mdot
.34423 .56059 Mdot
.62196 .54087 Mdot
.59254 .53366 Mdot
.58908 .32737 Mdot
.62152 .58435 Mdot
.60261 .3318 Mdot
.62666 .53427 Mdot
.37284 .34264 Mdot
.42512 .68259 Mdot
.4395 .5578 Mdot
.61872 .68317 Mdot
.55157 .30204 Mdot
.80052 .42375 Mdot
.37205 .53435 Mdot
.75848 .435 Mdot
.40033 .42334 Mdot
.47699 .66776 Mdot
.38459 .55734 Mdot
.43416 .66957 Mdot
.6068 .59504 Mdot
.36099 .59606 Mdot
.43776 .68859 Mdot
.51724 .62034 Mdot
.60572 .48116 Mdot
.24355 .32695 Mdot
.35914 .39978 Mdot
.54461 .37773 Mdot
.66728 .54951 Mdot
.37082 .52804 Mdot
.60693 .61096 Mdot
.23888 .54683 Mdot
.29897 .37944 Mdot
.33276 .59172 Mdot
.44523 .6004 Mdot
.4833 .67877 Mdot
.28486 .49173 Mdot
.46262 .24836 Mdot
.53245 .37685 Mdot
.614 .59315 Mdot
.70317 .74478 Mdot
.37869 .38757 Mdot
.66349 .55215 Mdot
.46865 .76392 Mdot
.37983 .37694 Mdot
.60662 .54146 Mdot
.41008 .42377 Mdot
.56068 .33543 Mdot
.66498 .28058 Mdot
.51051 .35425 Mdot
.61609 .58556 Mdot
.3968 .40705 Mdot
.31935 .5436 Mdot
.55238 .3307 Mdot
.58864 .55638 Mdot
.62339 .50987 Mdot
.4692 .58156 Mdot
.63583 .55771 Mdot
.61357 .80563 Mdot
.62979 .53237 Mdot
.3523 .55074 Mdot
.62941 .49448 Mdot
.58167 .22284 Mdot
.43537 .55121 Mdot
.51496 .35671 Mdot
.33209 .59387 Mdot
.37169 .55746 Mdot
.29127 .67736 Mdot
.42337 .39659 Mdot
.57164 .52686 Mdot
.37965 .53437 Mdot
.69318 .63348 Mdot
.40916 .39653 Mdot
.67409 .54205 Mdot
.47903 .42028 Mdot
.3199 .63513 Mdot
.37571 .59748 Mdot
.69336 .59125 Mdot
.5746 .31625 Mdot
.65017 .53911 Mdot
.35406 .53034 Mdot
.70128 .50577 Mdot
.59007 .50625 Mdot
.46194 .20088 Mdot
.46468 .59394 Mdot
.39533 .37445 Mdot
.61929 .47049 Mdot
.6511 .57579 Mdot
.36116 .59348 Mdot
.55515 .30501 Mdot
.4082 .39069 Mdot
.54804 .33944 Mdot
.66528 .7434 Mdot
.25136 .32632 Mdot
.52096 .6045 Mdot
.42892 .68438 Mdot
.40904 .62901 Mdot
.67288 .7449 Mdot
.75275 .3177 Mdot
.79589 .50614 Mdot
.7348 .68014 Mdot
.34043 .53002 Mdot
.39281 .64429 Mdot
.36696 .56147 Mdot
.63881 .51175 Mdot
.37332 .57489 Mdot
.71622 .73768 Mdot
.62669 .53772 Mdot
.36343 .57918 Mdot
.78023 .38834 Mdot
.64667 .54131 Mdot
.52686 .37648 Mdot
.569 .83964 Mdot
.62429 .21155 Mdot
.31335 .36402 Mdot
.33406 .56144 Mdot
.77809 .57102 Mdot
.62703 .55048 Mdot
.62944 .49506 Mdot
.55239 .31252 Mdot
.58442 .60468 Mdot
.47039 .6985 Mdot
.47718 .65937 Mdot
.34125 .41693 Mdot
.42031 .68497 Mdot
.62523 .47157 Mdot
.55229 .32784 Mdot
.53919 .59399 Mdot
.29998 .66963 Mdot
.33802 .64511 Mdot
.35103 .41746 Mdot
.56849 .83879 Mdot
.53417 .40637 Mdot
.43257 .35319 Mdot
.28841 .57845 Mdot
.52322 .32422 Mdot
.67904 .78163 Mdot
.37406 .41306 Mdot
.21635 .3597 Mdot
.49792 .27209 Mdot
.58847 .54284 Mdot
.40565 .39991 Mdot
.66197 .60405 Mdot
.64076 .22268 Mdot
.18801 .43414 Mdot
.70864 .48588 Mdot
.6704 .56775 Mdot
.28585 .62415 Mdot
.61624 .54642 Mdot
.2591 .58753 Mdot
.63015 .52524 Mdot
.54403 .33855 Mdot
.47041 .31924 Mdot
.33612 .4412 Mdot
.61115 .31271 Mdot
.27964 .5095 Mdot
.44117 .67611 Mdot
.6239 .53306 Mdot
.58877 .54594 Mdot
.4645 .70312 Mdot
.56839 .33523 Mdot
.6243 .58673 Mdot
.79957 .40959 Mdot
.58092 .53641 Mdot
.37569 .42304 Mdot
.54779 .24409 Mdot
.59315 .42195 Mdot
.57972 .56267 Mdot
.54164 .29483 Mdot
.35145 .40605 Mdot
.39449 .40817 Mdot
.58353 .46938 Mdot
.37391 .43403 Mdot
.6261 .56387 Mdot
.18258 .46401 Mdot
.57159 .34301 Mdot
.38785 .22358 Mdot
.53156 .35879 Mdot
.69259 .38646 Mdot
.3779 .37175 Mdot
.28238 .39484 Mdot
.67812 .59126 Mdot
.37744 .41121 Mdot
.55796 .27646 Mdot
.57848 .4982 Mdot
.58085 .49284 Mdot
.77994 .60092 Mdot
.34748 .54415 Mdot
.46429 .58173 Mdot
.38239 .4349 Mdot
.60688 .57143 Mdot
.58044 .5725 Mdot
.3526 .40675 Mdot
.21051 .42324 Mdot
.67378 .25622 Mdot
.62833 .53425 Mdot
.53793 .3347 Mdot
.52758 .33684 Mdot
.64458 .48661 Mdot
.65852 .5234 Mdot
.38352 .57209 Mdot
.31621 .55718 Mdot
.39579 .56335 Mdot
.46047 .58614 Mdot
.2915 .38059 Mdot
.42824 .79925 Mdot
.35805 .40307 Mdot
.4398 .28135 Mdot
.50717 .59722 Mdot
.6597 .58363 Mdot
.33082 .56313 Mdot
.64876 .57568 Mdot
.63833 .56653 Mdot
.42827 .41058 Mdot
.49645 .79024 Mdot
.49491 .38907 Mdot
.55842 .30231 Mdot
.39374 .36755 Mdot
.60857 .4667 Mdot
.44758 .38155 Mdot
.47559 .67144 Mdot
.71346 .65651 Mdot
.39625 .42795 Mdot
.51898 .37321 Mdot
.36244 .39131 Mdot
.58996 .53068 Mdot
.67708 .58281 Mdot
.52215 .32845 Mdot
.48104 .69571 Mdot
.57234 .59474 Mdot
.60927 .53953 Mdot
.35739 .21101 Mdot
.67019 .66547 Mdot
.37114 .33706 Mdot
.6319 .53375 Mdot
.57531 .5349 Mdot
.49112 .69821 Mdot
.58209 .53538 Mdot
.65671 .57815 Mdot
.65162 .33238 Mdot
.35954 .29935 Mdot
.45802 .64866 Mdot
.1908 .4579 Mdot
.51579 .32254 Mdot
.68969 .75761 Mdot
.33661 .57369 Mdot
.33905 .43095 Mdot
.6413 .24447 Mdot
.38784 .58975 Mdot
.2485 .48266 Mdot
.67916 .7664 Mdot
.40673 .51881 Mdot
.39012 .61094 Mdot
.48873 .36 Mdot
.60643 .58022 Mdot
.6169 .53775 Mdot
.47014 .69172 Mdot
.52178 .35155 Mdot
.48456 .5158 Mdot
.22369 .65639 Mdot
.61554 .55714 Mdot
.44733 .20634 Mdot
.20123 .51828 Mdot
.3147 .63723 Mdot
.46454 .6783 Mdot
.48279 .6626 Mdot
.62196 .53224 Mdot
.63437 .31629 Mdot
.55814 .32819 Mdot
.58977 .5574 Mdot
.63357 .59838 Mdot
.34019 .55152 Mdot
.55557 .36157 Mdot
.31977 .55847 Mdot
.28126 .45116 Mdot
.60912 .79739 Mdot
.20533 .34151 Mdot
.39289 .38242 Mdot
.24469 .6113 Mdot
.41236 .40878 Mdot
.55771 .72208 Mdot
.38214 .60328 Mdot
.65505 .53588 Mdot
.56077 .3084 Mdot
.61401 .57444 Mdot
.65768 .52563 Mdot
.58701 .54595 Mdot
.58409 .57019 Mdot
.22813 .29965 Mdot
.4393 .67442 Mdot
.58683 .59139 Mdot
.35702 .54926 Mdot
.31523 .73844 Mdot
.27194 .69366 Mdot
.59142 .5483 Mdot
.62611 .51858 Mdot
.55943 .35186 Mdot
.67011 .53391 Mdot
.41249 .40044 Mdot
.51261 .37563 Mdot
.59464 .51726 Mdot
.50625 .84106 Mdot
.58557 .51386 Mdot
.65471 .7666 Mdot
.36317 .393 Mdot
.26184 .34344 Mdot
.66803 .59231 Mdot
.30367 .37986 Mdot
.46448 .58185 Mdot
.38611 .56223 Mdot
.41571 .41614 Mdot
.35148 .57314 Mdot
.20693 .62684 Mdot
.69957 .53843 Mdot
.63748 .54304 Mdot
.65169 .58737 Mdot
.39049 .55245 Mdot
.44623 .83365 Mdot
.2957 .50307 Mdot
.70249 .54668 Mdot
.38429 .58005 Mdot
.50782 .31711 Mdot
.74137 .63096 Mdot
.54021 .35123 Mdot
.44801 .7131 Mdot
.36808 .42086 Mdot
.48014 .69477 Mdot
.57911 .76263 Mdot
.54484 .37018 Mdot
.57895 .35825 Mdot
.33817 .57249 Mdot
.47838 .31792 Mdot
.59753 .15388 Mdot
.49843 .27043 Mdot
.58279 .69313 Mdot
.5526 .31993 Mdot
.583 .52137 Mdot
.55919 .74577 Mdot
.48575 .28977 Mdot
.35475 .57335 Mdot
.64348 .57104 Mdot
.66451 .27576 Mdot
.38386 .57147 Mdot
.67322 .5771 Mdot
.35562 .54501 Mdot
.36793 .40574 Mdot
.332 .55455 Mdot
.59325 .33618 Mdot
.60886 .50992 Mdot
.62611 .15501 Mdot
.42024 .63362 Mdot
.6301 .54847 Mdot
.38217 .36235 Mdot
.23091 .44395 Mdot
.6577 .54943 Mdot
.43413 .68914 Mdot
.36643 .58447 Mdot
.48271 .32037 Mdot
.62899 .53058 Mdot
.38416 .58137 Mdot
.56421 .36549 Mdot
.39675 .36352 Mdot
.73191 .33385 Mdot
.33265 .3521 Mdot
.55097 .31017 Mdot
.53495 .45325 Mdot
.41593 .42827 Mdot
.57494 .53726 Mdot
.60487 .58888 Mdot
.53426 .33699 Mdot
.50181 .71974 Mdot
.65023 .50545 Mdot
.62138 .49467 Mdot
.34335 .55362 Mdot
.35192 .57731 Mdot
.78761 .50406 Mdot
.32271 .54562 Mdot
.67003 .58777 Mdot
.53465 .33914 Mdot
.6492 .54836 Mdot
.56163 .35326 Mdot
.66971 .53421 Mdot
.57433 .46287 Mdot
.5685 .33405 Mdot
.42714 .38783 Mdot
.64227 .56871 Mdot
.55048 .5701 Mdot
.66442 .54319 Mdot
.59967 .57549 Mdot
.38152 .56944 Mdot
.4706 .68191 Mdot
.64836 .59236 Mdot
.45753 .63674 Mdot
.44381 .65897 Mdot
.31777 .40183 Mdot
.34178 .5489 Mdot
.44702 .69041 Mdot
.19379 .54242 Mdot
.37266 .59396 Mdot
.46735 .69576 Mdot
.27342 .69596 Mdot
.36965 .37742 Mdot
.57556 .31555 Mdot
.64696 .53787 Mdot
.64356 .74062 Mdot
.6348 .42965 Mdot
.34363 .60824 Mdot
.62988 .53667 Mdot
.66132 .55616 Mdot
.50564 .32981 Mdot
.23085 .69163 Mdot
.37526 .52221 Mdot
.58004 .51481 Mdot
.5304 .37277 Mdot
.23741 .72304 Mdot
.35696 .55438 Mdot
.47173 .6937 Mdot
.3632 .37879 Mdot
.49296 .33087 Mdot
.33087 .29415 Mdot
.36501 .36342 Mdot
.33721 .50544 Mdot
.28758 .44655 Mdot
.57455 .57299 Mdot
.32919 .57235 Mdot
.84408 .44657 Mdot
.57366 .62055 Mdot
.459 .55165 Mdot
.77201 .5819 Mdot
.53005 .31771 Mdot
.41235 .40628 Mdot
.44257 .67084 Mdot
.52395 .31257 Mdot
.55498 .36776 Mdot
.35431 .40602 Mdot
.63064 .34733 Mdot
.47516 .41745 Mdot
.3846 .42474 Mdot
.67357 .6935 Mdot
.42243 .77161 Mdot
.33021 .56795 Mdot
.46901 .69907 Mdot
.55659 .77448 Mdot
.54717 .34284 Mdot
.60994 .83612 Mdot
.78697 .59631 Mdot
.62531 .54951 Mdot
.44623 .68217 Mdot
.44772 .82446 Mdot
.25946 .71417 Mdot
.38173 .37566 Mdot
.32742 .41948 Mdot
.48366 .6871 Mdot
.66619 .55293 Mdot
.70286 .64611 Mdot
.6359 .50236 Mdot
.36471 .41491 Mdot
.75825 .37138 Mdot
.54701 .37046 Mdot
.35485 .38817 Mdot
.72449 .65136 Mdot
.62415 .56391 Mdot
.64493 .56778 Mdot
.63612 .69693 Mdot
.52845 .30701 Mdot
.38639 .56161 Mdot
.59567 .58878 Mdot
.61057 .5434 Mdot
.67962 .57528 Mdot
.65509 .48794 Mdot
.65457 .30454 Mdot
.63621 .51456 Mdot
.26952 .63542 Mdot
.67087 .56273 Mdot
.62835 .5721 Mdot
.54895 .29423 Mdot
.18296 .36697 Mdot
.29291 .46667 Mdot
.61211 .54736 Mdot
.57585 .52766 Mdot
.35617 .38736 Mdot
.4547 .40801 Mdot
.46645 .35616 Mdot
.48251 .32553 Mdot
.7888 .53938 Mdot
.60395 .48012 Mdot
.51857 .36285 Mdot
.43911 .69351 Mdot
.57216 .52915 Mdot
.52113 .36854 Mdot
.64436 .49383 Mdot
.38555 .57022 Mdot
.37598 .59258 Mdot
.54018 .58927 Mdot
.44512 .69095 Mdot
.53481 .22485 Mdot
.43635 .28089 Mdot
.36546 .59424 Mdot
.63861 .53947 Mdot
.35885 .34914 Mdot
.35829 .53137 Mdot
.42053 .54608 Mdot
.48634 .74604 Mdot
.56085 .31803 Mdot
.54171 .31574 Mdot
.52943 .71677 Mdot
.26049 .45693 Mdot
.46198 .18893 Mdot
.36694 .40681 Mdot
.60086 .59767 Mdot
.48388 .25607 Mdot
.54192 .31254 Mdot
.564 .73283 Mdot
.4447 .68425 Mdot
.37843 .37744 Mdot
.3007 .52413 Mdot
.54876 .35653 Mdot
.57477 .35172 Mdot
.67315 .52341 Mdot
.60094 .53759 Mdot
.79844 .49251 Mdot
.46497 .63782 Mdot
.35423 .36791 Mdot
.47187 .69671 Mdot
.3782 .60438 Mdot
.62377 .50257 Mdot
.56641 .33415 Mdot
.41193 .77755 Mdot
.56918 .54435 Mdot
.37708 .55214 Mdot
.53343 .3177 Mdot
.48387 .67735 Mdot
.43693 .69536 Mdot
.59011 .56937 Mdot
.7872 .45171 Mdot
.38191 .41809 Mdot
.51581 .33466 Mdot
.44783 .36657 Mdot
.64278 .5048 Mdot
.60592 .53145 Mdot
.54609 .51039 Mdot
.35521 .36699 Mdot
.40528 .324 Mdot
.43042 .67713 Mdot
.5209 .34572 Mdot
.63312 .51581 Mdot
.46046 .69963 Mdot
.45055 .28058 Mdot
.34664 .60256 Mdot
.33305 .55031 Mdot
.44185 .70014 Mdot
.45639 .67502 Mdot
.43211 .679 Mdot
.61247 .8359 Mdot
.50169 .35012 Mdot
.53656 .4086 Mdot
.58573 .49751 Mdot
.56806 .69966 Mdot
.58671 .59351 Mdot
.40392 .38119 Mdot
.35099 .54214 Mdot
.66003 .53894 Mdot
.5785 .5578 Mdot
.56133 .48128 Mdot
.41501 .21022 Mdot
.57635 .42526 Mdot
.55685 .36332 Mdot
.67657 .58453 Mdot
.33533 .56238 Mdot
.60168 .85383 Mdot
.80297 .59845 Mdot
.6712 .59024 Mdot
.47742 .41293 Mdot
.56866 .326 Mdot
.35722 .40282 Mdot
.62342 .72378 Mdot
.36665 .37937 Mdot
.52196 .34018 Mdot
.63407 .51019 Mdot
.42977 .29856 Mdot
.49409 .69649 Mdot
.60578 .57372 Mdot
.36319 .40583 Mdot
.62383 .58304 Mdot
.35732 .36636 Mdot
.63603 .75299 Mdot
.83013 .44718 Mdot
.62254 .5549 Mdot
.56194 .55369 Mdot
.80951 .47839 Mdot
.5934 .554 Mdot
.50435 .68628 Mdot
.56886 .32522 Mdot
.76364 .37223 Mdot
.56592 .50505 Mdot
.72614 .59661 Mdot
.63653 .50034 Mdot
.74102 .33339 Mdot
.60249 .53103 Mdot
.30859 .63665 Mdot
.60543 .50646 Mdot
.65345 .58175 Mdot
.39746 .39429 Mdot
.35533 .38535 Mdot
.56982 .2997 Mdot
.3613 .52549 Mdot
.64537 .77657 Mdot
.60868 .53616 Mdot
.29042 .39968 Mdot
.36816 .31032 Mdot
.45928 .67543 Mdot
.52339 .34455 Mdot
.27478 .75386 Mdot
.39044 .43843 Mdot
.81093 .54257 Mdot
.77967 .53094 Mdot
.37545 .27075 Mdot
.50501 .7769 Mdot
.2184 .4763 Mdot
.48082 .67338 Mdot
.65446 .50083 Mdot
.41108 .73067 Mdot
.303 .6359 Mdot
.48649 .73585 Mdot
.4173 .41862 Mdot
.77254 .46153 Mdot
.4674 .77713 Mdot
.45037 .71014 Mdot
.48699 .67388 Mdot
.37303 .36603 Mdot
.39567 .61381 Mdot
.67905 .48938 Mdot
.4468 .67539 Mdot
.39216 .55339 Mdot
.3667 .59825 Mdot
.39311 .54859 Mdot
.56048 .32982 Mdot
.80155 .5862 Mdot
.40098 .4458 Mdot
.39903 .37825 Mdot
.3951 .62283 Mdot
.73345 .5421 Mdot
.54349 .38433 Mdot
.34343 .56691 Mdot
.32682 .54813 Mdot
.5709 .32382 Mdot
.68183 .52198 Mdot
.68583 .51194 Mdot
.61401 .55281 Mdot
.46994 .68652 Mdot
.59735 .53395 Mdot
.38135 .58139 Mdot
.38804 .38026 Mdot
.33192 .54337 Mdot
.3776 .35981 Mdot
.39894 .7834 Mdot
.5858 .55781 Mdot
.61038 .50816 Mdot
.31071 .24604 Mdot
.58273 .3314 Mdot
.33554 .75094 Mdot
.41632 .36046 Mdot
.36562 .5595 Mdot
.65731 .57694 Mdot
.51761 .38103 Mdot
.48404 .65031 Mdot
.20847 .34571 Mdot
.65754 .51739 Mdot
.55483 .34562 Mdot
.62538 .50467 Mdot
.58333 .63216 Mdot
.52681 .19168 Mdot
.53893 .3439 Mdot
.42963 .1966 Mdot
.58058 .51956 Mdot
.20927 .55807 Mdot
.67305 .5525 Mdot
.53753 .62829 Mdot
.6502 .50551 Mdot
.51505 .32307 Mdot
.61011 .55122 Mdot
.51701 .3795 Mdot
.35004 .59248 Mdot
.35754 .39283 Mdot
.54936 .3116 Mdot
.59498 .58102 Mdot
.5374 .07483 Mdot
.36928 .39637 Mdot
.62274 .53715 Mdot
.37106 .36978 Mdot
.52289 .35573 Mdot
.52534 .31577 Mdot
.25303 .69061 Mdot
.27997 .45442 Mdot
.36918 .40465 Mdot
.62411 .50311 Mdot
.22973 .57081 Mdot
.65004 .52704 Mdot
.69771 .63447 Mdot
.68798 .53328 Mdot
.61735 .49124 Mdot
.2819 .71414 Mdot
.39439 .37321 Mdot
.4609 .18709 Mdot
.27424 .71887 Mdot
.31226 .7361 Mdot
.58689 .31502 Mdot
.45379 .70981 Mdot
.66951 .78612 Mdot
.293 .37802 Mdot
.38795 .57409 Mdot
.66086 .54409 Mdot
.58729 .28336 Mdot
.38661 .41838 Mdot
.47349 .67289 Mdot
.62244 .55364 Mdot
.32736 .55396 Mdot
.72234 .29239 Mdot
.40371 .37264 Mdot
.53995 .34699 Mdot
.51057 .31655 Mdot
.16182 .52568 Mdot
.6329 .52741 Mdot
.60387 .51111 Mdot
.36744 .42047 Mdot
.21907 .44281 Mdot
.45987 .65364 Mdot
.77814 .38265 Mdot
.37068 .40317 Mdot
.47369 .48475 Mdot
.51815 .3688 Mdot
.66038 .56151 Mdot
.51365 .82859 Mdot
.28782 .53967 Mdot
.33981 .23357 Mdot
.46936 .68885 Mdot
.69161 .63713 Mdot
.51442 .3248 Mdot
.38279 .38896 Mdot
.25412 .43036 Mdot
.58997 .48339 Mdot
.64179 .57742 Mdot
.62427 .64854 Mdot
.32621 .42572 Mdot
.4817 .3712 Mdot
.65333 .51391 Mdot
.462 .57894 Mdot
.66298 .52453 Mdot
.55365 .52944 Mdot
.69385 .54858 Mdot
.60894 .52266 Mdot
.56288 .33947 Mdot
.69991 .60422 Mdot
.38524 .54751 Mdot
.52191 .39703 Mdot
.4674 .49315 Mdot
.6289 .54287 Mdot
.61358 .49629 Mdot
.6852 .46289 Mdot
.23689 .50047 Mdot
.54857 .31385 Mdot
.58487 .35134 Mdot
.38458 .43881 Mdot
.68207 .51246 Mdot
.35854 .52593 Mdot
.5786 .59436 Mdot
.38039 .56499 Mdot
.56452 .33613 Mdot
.36225 .55777 Mdot
.36165 .37638 Mdot
.33161 .57851 Mdot
.28933 .38379 Mdot
.37332 .38696 Mdot
.558 .31389 Mdot
.5973 .51907 Mdot
.38317 .36229 Mdot
.59845 .67236 Mdot
.4682 .68787 Mdot
.35905 .8131 Mdot
.59428 .51678 Mdot
.34574 .2986 Mdot
.66724 .47102 Mdot
.32917 .54545 Mdot
.51193 .1874 Mdot
.56332 .30623 Mdot
.46916 .65001 Mdot
.53756 .3016 Mdot
.7164 .64857 Mdot
.45726 .68291 Mdot
.33684 .78368 Mdot
.47856 .60294 Mdot
.67254 .66201 Mdot
.67239 .50363 Mdot
.64141 .6837 Mdot
.37402 .60126 Mdot
.38823 .41635 Mdot
.252 .44932 Mdot
.65214 .58072 Mdot
.78 .33541 Mdot
.53882 .29782 Mdot
.36804 .52815 Mdot
.3879 .38935 Mdot
.40745 .38727 Mdot
.57684 .51003 Mdot
.3578 .66563 Mdot
.64151 .57939 Mdot
.2671 .44123 Mdot
.77643 .56758 Mdot
.56082 .4032 Mdot
.62635 .53464 Mdot
.35954 .59359 Mdot
.62567 .50479 Mdot
.42928 .67658 Mdot
.82922 .52447 Mdot
.55937 .58161 Mdot
.39983 .34437 Mdot
.48145 .64194 Mdot
.51304 .34684 Mdot
.60953 .45369 Mdot
.3592 .33963 Mdot
.63444 .5251 Mdot
.19656 .3076 Mdot
.46403 .69761 Mdot
.40934 .72484 Mdot
.57356 .55738 Mdot
.57019 .5311 Mdot
.44114 .52265 Mdot
.33176 .28642 Mdot
.2781 .59364 Mdot
.60142 .56059 Mdot
.57897 .65448 Mdot
.38368 .36758 Mdot
.66707 .54348 Mdot
.61855 .53653 Mdot
.63687 .39087 Mdot
.40417 .37699 Mdot
.36902 .5508 Mdot
.3884 .59039 Mdot
.33613 .60351 Mdot
.43242 .66383 Mdot
.45772 .35542 Mdot
.57819 .71587 Mdot
.66673 .24117 Mdot
.48824 .6657 Mdot
.57785 .55329 Mdot
.41215 .64421 Mdot
.63363 .50586 Mdot
.46855 .67061 Mdot
.40399 .37586 Mdot
.54449 .30974 Mdot
.4764 .26619 Mdot
.38564 .58899 Mdot
.58698 .48267 Mdot
.45459 .65227 Mdot
.5594 .31965 Mdot
.58944 .74817 Mdot
.5141 .34744 Mdot
.37747 .40684 Mdot
.45668 .35109 Mdot
.47148 .66977 Mdot
.52544 .36021 Mdot
.42671 .3545 Mdot
.24601 .69502 Mdot
.6972 .54409 Mdot
.45261 .31881 Mdot
.50962 .34486 Mdot
.57908 .36236 Mdot
.50656 .35415 Mdot
.61596 .58214 Mdot
.47849 .41434 Mdot
.6235 .48772 Mdot
.39137 .37082 Mdot
.35935 .54508 Mdot
.81326 .41948 Mdot
.32729 .47471 Mdot
.53103 .43194 Mdot
.62732 .60259 Mdot
.62309 .56459 Mdot
.62185 .53267 Mdot
.55681 .52209 Mdot
.28923 .37208 Mdot
.62449 .5784 Mdot
.39801 .39535 Mdot
.37204 .58374 Mdot
.65255 .49894 Mdot
.31345 .53553 Mdot
.29835 .71466 Mdot
.48429 .69389 Mdot
.33794 .39652 Mdot
.82863 .56567 Mdot
.55721 .31832 Mdot
.32998 .59082 Mdot
.37425 .58846 Mdot
.4683 .65992 Mdot
.37921 .42151 Mdot
.51424 .35037 Mdot
.68686 .6362 Mdot
.44276 .6599 Mdot
.60998 .54809 Mdot
.47991 .40052 Mdot
.80479 .36857 Mdot
.65968 .50721 Mdot
.654 .54953 Mdot
.39415 .54759 Mdot
.41376 .72174 Mdot
.72123 .22854 Mdot
.5985 .71768 Mdot
.47265 .6775 Mdot
.46614 .70817 Mdot
.57367 .32875 Mdot
.573 .50092 Mdot
.37305 .3633 Mdot
.51831 .2632 Mdot
.40777 .33361 Mdot
.49739 .22169 Mdot
.31533 .26028 Mdot
.66217 .52928 Mdot
.20627 .44378 Mdot
.62857 .56548 Mdot
.50179 .3484 Mdot
.55988 .33828 Mdot
.54632 .32911 Mdot
.38745 .41599 Mdot
.72685 .42918 Mdot
.39767 .40756 Mdot
.85939 .49477 Mdot
.51721 .32491 Mdot
.47375 .60402 Mdot
.33925 .56313 Mdot
.70257 .5419 Mdot
.48346 .684 Mdot
.4547 .33055 Mdot
.53598 .55863 Mdot
.62099 .30172 Mdot
.37667 .53269 Mdot
.55565 .31104 Mdot
.21944 .45389 Mdot
.75387 .67876 Mdot
.47254 .34363 Mdot
.54846 .49406 Mdot
.62346 .7253 Mdot
.46275 .67412 Mdot
.33691 .23576 Mdot
.47895 .69224 Mdot
.36307 .40448 Mdot
.61706 .50949 Mdot
.60782 .51555 Mdot
.66366 .52443 Mdot
.58737 .55288 Mdot
.41351 .43506 Mdot
.62391 .59576 Mdot
.582 .22317 Mdot
.38763 .58558 Mdot
.51964 .63659 Mdot
.47607 .6927 Mdot
.41769 .39776 Mdot
.37354 .5838 Mdot
.23962 .4926 Mdot
.6134 .68401 Mdot
.62835 .53213 Mdot
.66049 .54012 Mdot
.8168 .51315 Mdot
.65236 .51348 Mdot
.70571 .5252 Mdot
.38625 .57794 Mdot
.58753 .43768 Mdot
.48402 .69299 Mdot
.47521 .70619 Mdot
.37275 .38473 Mdot
.56146 .33967 Mdot
.45766 .69509 Mdot
.34023 .55884 Mdot
.63007 .60236 Mdot
.61126 .59326 Mdot
.51019 .34178 Mdot
.82394 .5126 Mdot
.42993 .68758 Mdot
.22445 .56404 Mdot
.5628 .31306 Mdot
.55925 .28987 Mdot
.64342 .57691 Mdot
.36585 .22227 Mdot
.59216 .31419 Mdot
.45531 .64571 Mdot
.41836 .40335 Mdot
.63751 .7118 Mdot
.39744 .43271 Mdot
.53981 .34895 Mdot
.58609 .50841 Mdot
.56434 .32793 Mdot
.63152 .53148 Mdot
.7735 .68103 Mdot
.60592 .52025 Mdot
.65152 .23231 Mdot
.52711 .70599 Mdot
.34563 .58388 Mdot
.2315 .494 Mdot
.33696 .5736 Mdot
.55222 .30394 Mdot
.56809 .54924 Mdot
.4769 .66116 Mdot
.26458 .66343 Mdot
.55829 .26137 Mdot
.35962 .53411 Mdot
.35228 .51949 Mdot
.40367 .43018 Mdot
.65162 .50509 Mdot
.63605 .57862 Mdot
.36042 .57919 Mdot
.59495 .35789 Mdot
.54112 .35906 Mdot
.62627 .51495 Mdot
.62233 .56752 Mdot
.34243 .58071 Mdot
.23382 .68028 Mdot
.6671 .62069 Mdot
.61733 .51471 Mdot
.2743 .5701 Mdot
.40398 .38256 Mdot
.70104 .53836 Mdot
.56492 .56143 Mdot
.45378 .67384 Mdot
.68262 .31296 Mdot
.75817 .63506 Mdot
.40482 .37582 Mdot
.38032 .5873 Mdot
.63325 .52192 Mdot
.36263 .59353 Mdot
.61919 .59563 Mdot
.3412 .27989 Mdot
.33607 .59422 Mdot
.61428 .49373 Mdot
.67641 .51465 Mdot
.52523 .30895 Mdot
.66168 .53408 Mdot
.72387 .48451 Mdot
.37704 .54435 Mdot
.5775 .51099 Mdot
.78389 .42383 Mdot
.38845 .42722 Mdot
.66158 .49139 Mdot
.44015 .66565 Mdot
.71127 .6267 Mdot
.41663 .28675 Mdot
.51662 .79307 Mdot
.47956 .70522 Mdot
.62289 .58208 Mdot
.35861 .52123 Mdot
.35305 .37051 Mdot
.62385 .21379 Mdot
.66471 .55739 Mdot
.36407 .41076 Mdot
.38696 .38002 Mdot
.47599 .67383 Mdot
.16974 .38801 Mdot
.57732 .56121 Mdot
.59158 .5457 Mdot
.68732 .42492 Mdot
.57591 .35368 Mdot
.59871 .5269 Mdot
.58137 .52901 Mdot
.39771 .39033 Mdot
.64953 .47552 Mdot
.7657 .50463 Mdot
.76099 .3553 Mdot
.34979 .4036 Mdot
.50762 .24258 Mdot
.3475 .59927 Mdot
.45834 .70275 Mdot
.52595 .32638 Mdot
.46112 .65244 Mdot
.33585 .55349 Mdot
.58422 .52606 Mdot
.36074 .41411 Mdot
.6995 .46282 Mdot
.37137 .36604 Mdot
.47093 .76823 Mdot
.52477 .37847 Mdot
.37572 .45581 Mdot
.18107 .33506 Mdot
.26369 .5322 Mdot
.31889 .41801 Mdot
.45878 .67551 Mdot
.40695 .53352 Mdot
.6237 .56731 Mdot
.32479 .24244 Mdot
.57862 .55174 Mdot
.77387 .40108 Mdot
.38963 .57862 Mdot
.39579 .56005 Mdot
.61833 .51188 Mdot
.77122 .57363 Mdot
.351 .37289 Mdot
.40859 .39791 Mdot
.59875 .49602 Mdot
.37682 .41103 Mdot
.59879 .54122 Mdot
.38134 .57788 Mdot
.37972 .19266 Mdot
.61791 .55174 Mdot
.55495 .56046 Mdot
.35294 .28136 Mdot
.28472 .72291 Mdot
.44417 .62839 Mdot
.17196 .58517 Mdot
.77704 .6552 Mdot
.37852 .41106 Mdot
.60444 .4897 Mdot
.50557 .23886 Mdot
.3833 .52873 Mdot
.42736 .35086 Mdot
.5889 .52685 Mdot
.5801 .54098 Mdot
.65805 .57983 Mdot
.64753 .56353 Mdot
.23667 .3242 Mdot
.54954 .258 Mdot
.69726 .36024 Mdot
.65925 .52765 Mdot
.62685 .67491 Mdot
.36517 .39118 Mdot
.53085 .28833 Mdot
.47534 .65085 Mdot
.66228 .53102 Mdot
.50057 .38135 Mdot
.36089 .42113 Mdot
.86407 .47521 Mdot
.36247 .41204 Mdot
.37165 .55868 Mdot
.35647 .37682 Mdot
.63516 .55661 Mdot
.528 .33655 Mdot
.42167 .47419 Mdot
.28839 .48842 Mdot
.39009 .56901 Mdot
.63006 .54784 Mdot
.45776 .60891 Mdot
.38385 .54331 Mdot
.32645 .75062 Mdot
.53053 .32776 Mdot
.56651 .65251 Mdot
.56379 .33242 Mdot
.59008 .50044 Mdot
.59044 .50116 Mdot
.37353 .43896 Mdot
.35938 .37764 Mdot
.56333 .33428 Mdot
.13839 .43961 Mdot
.43095 .68242 Mdot
.54612 .33238 Mdot
.57264 .49077 Mdot
.46143 .43314 Mdot
.53225 .33398 Mdot
.4959 .70521 Mdot
.39214 .38308 Mdot
.5798 .32611 Mdot
.67229 .56523 Mdot
.67919 .68789 Mdot
.44511 .70113 Mdot
.38902 .59768 Mdot
.56513 .74856 Mdot
.36927 .53572 Mdot
.41646 .41431 Mdot
.33761 .57641 Mdot
.39542 .37686 Mdot
.40066 .30235 Mdot
.54018 .40009 Mdot
.41288 .52039 Mdot
.41103 .43207 Mdot
.33848 .57228 Mdot
.62026 .50728 Mdot
.42173 .63324 Mdot
.56742 .51338 Mdot
.61379 .58754 Mdot
.40406 .39231 Mdot
.52685 .31056 Mdot
.59133 .3265 Mdot
.67648 .65424 Mdot
.56069 .34539 Mdot
.37491 .54789 Mdot
.61907 .27477 Mdot
.29911 .41926 Mdot
.39853 .42937 Mdot
.3573 .38858 Mdot
.64052 .50793 Mdot
.35234 .57314 Mdot
.39235 .56624 Mdot
.39633 .43452 Mdot
.39575 .22457 Mdot
.55839 .54806 Mdot
.58144 .36192 Mdot
.57725 .34909 Mdot
.5369 .3422 Mdot
.50771 .36152 Mdot
.72674 .58608 Mdot
.37444 .37574 Mdot
.53479 .30562 Mdot
.64193 .50798 Mdot
.58326 .5334 Mdot
.51272 .25996 Mdot
.44399 .69634 Mdot
.64607 .49292 Mdot
.69341 .54464 Mdot
.65916 .56373 Mdot
.33017 .55739 Mdot
.71489 .56711 Mdot
.32672 .57495 Mdot
.37025 .52305 Mdot
.37552 .52467 Mdot
.2953 .3755 Mdot
.80266 .54115 Mdot
.70831 .70949 Mdot
.57698 .51947 Mdot
.20044 .48612 Mdot
.35266 .5624 Mdot
.59765 .25269 Mdot
.39565 .32271 Mdot
.6581 .57495 Mdot
.28444 .64821 Mdot
.3558 .58012 Mdot
.56914 .31783 Mdot
.59545 .5229 Mdot
.32456 .59033 Mdot
.43678 .67197 Mdot
.57427 .5099 Mdot
.35094 .60383 Mdot
.52259 .36024 Mdot
.4408 .64856 Mdot
.58265 .32149 Mdot
.37539 .52417 Mdot
.60392 .46793 Mdot
.51173 .14723 Mdot
.31431 .57892 Mdot
.20953 .58888 Mdot
.52958 .50265 Mdot
.62474 .51124 Mdot
.3215 .5746 Mdot
.56887 .28928 Mdot
.41629 .41209 Mdot
.49946 .50446 Mdot
.57069 .34843 Mdot
.39579 .5599 Mdot
.34718 .53141 Mdot
.39012 .56934 Mdot
.56088 .36253 Mdot
.63002 .48205 Mdot
.55766 .35717 Mdot
.35594 .37482 Mdot
.64928 .53573 Mdot
.66718 .74598 Mdot
.22401 .42998 Mdot
.56523 .31674 Mdot
.36345 .54175 Mdot
.49215 .69803 Mdot
.62587 .56054 Mdot
.21299 .44686 Mdot
.62323 .50661 Mdot
.40106 .38206 Mdot
.6575 .32602 Mdot
.59604 .43082 Mdot
.61222 .49068 Mdot
.64325 .51254 Mdot
.4082 .4009 Mdot
.62629 .5486 Mdot
.65057 .5054 Mdot
.28877 .38265 Mdot
.54971 .36342 Mdot
.61181 .55544 Mdot
.35235 .54705 Mdot
.29401 .44329 Mdot
.55678 .55362 Mdot
.39351 .5067 Mdot
.5628 .64732 Mdot
.65004 .34234 Mdot
.57824 .5496 Mdot
.49384 .40237 Mdot
.64446 .57171 Mdot
.59823 .56843 Mdot
.64004 .51284 Mdot
.20042 .38542 Mdot
.3483 .60237 Mdot
.36478 .59045 Mdot
.4597 .70799 Mdot
.56181 .64771 Mdot
.44762 .67753 Mdot
.38896 .37837 Mdot
.37029 .67859 Mdot
.32732 .57769 Mdot
.53427 .35454 Mdot
.61155 .57603 Mdot
.31371 .57589 Mdot
.65835 .56844 Mdot
.63565 .55456 Mdot
.35249 .52551 Mdot
.35354 .60223 Mdot
.45008 .76308 Mdot
.43852 .68933 Mdot
.5483 .32392 Mdot
.64109 .49487 Mdot
.44787 .65552 Mdot
.57606 .55164 Mdot
.56706 .70153 Mdot
.54483 .32721 Mdot
.5514 .36165 Mdot
.59204 .3241 Mdot
.58742 .52243 Mdot
.63101 .55814 Mdot
.39846 .40729 Mdot
.55878 .30501 Mdot
.38462 .42774 Mdot
.48513 .52743 Mdot
.34049 .73166 Mdot
.58851 .52713 Mdot
.46647 .32366 Mdot
.44204 .67758 Mdot
.3563 .53439 Mdot
.81469 .3866 Mdot
.45916 .70796 Mdot
.6309 .52802 Mdot
.3699 .52647 Mdot
.46168 .66448 Mdot
.57397 .63437 Mdot
.84655 .50284 Mdot
.4922 .69312 Mdot
.64248 .50862 Mdot
.63987 .47248 Mdot
.16697 .5685 Mdot
.48574 .70004 Mdot
.3633 .38104 Mdot
.58896 .52095 Mdot
.56865 .37498 Mdot
.45637 .65158 Mdot
.26662 .60282 Mdot
.36317 .5841 Mdot
.69025 .67645 Mdot
.54588 .56574 Mdot
.60266 .29486 Mdot
.46354 .70661 Mdot
.51784 .34388 Mdot
.70603 .5183 Mdot
.6448 .57549 Mdot
.48364 .70333 Mdot
.42345 .3933 Mdot
.37471 .57618 Mdot
.28759 .46331 Mdot
.56304 .36159 Mdot
.42704 .3967 Mdot
.35374 .53816 Mdot
.22728 .57318 Mdot
.70497 .29303 Mdot
.68913 .51524 Mdot
.17571 .5178 Mdot
.3321 .33194 Mdot
.67249 .53725 Mdot
.48955 .65904 Mdot
.38622 .36254 Mdot
.36837 .42861 Mdot
.3754 .40351 Mdot
.38436 .3089 Mdot
.48099 .32963 Mdot
.34983 .60529 Mdot
.45007 .3804 Mdot
.45581 .7017 Mdot
.64217 .70329 Mdot
.61354 .58911 Mdot
.62075 .56216 Mdot
.63925 .4976 Mdot
.66403 .5328 Mdot
.6304 .57489 Mdot
.37355 .41794 Mdot
.38497 .29774 Mdot
.48242 .31417 Mdot
.53826 .33122 Mdot
.40892 .70442 Mdot
.34373 .55793 Mdot
.39488 .60001 Mdot
.45222 .66184 Mdot
.25878 .56088 Mdot
.31236 .53785 Mdot
.36392 .55742 Mdot
.66658 .50871 Mdot
.54822 .35751 Mdot
.70449 .53957 Mdot
.6429 .51068 Mdot
.37778 .55564 Mdot
.45316 .52401 Mdot
.75281 .51523 Mdot
.46567 .74738 Mdot
.43122 .65201 Mdot
.46729 .39043 Mdot
.46966 .70995 Mdot
.57969 .57886 Mdot
.52992 .19553 Mdot
.33489 .55457 Mdot
.36566 .56925 Mdot
.44245 .69175 Mdot
.36832 .21846 Mdot
.52749 .32094 Mdot
.40502 .45173 Mdot
.37915 .36937 Mdot
.58869 .50518 Mdot
.74402 .31209 Mdot
.53154 .49107 Mdot
.34722 .66673 Mdot
.37082 .40009 Mdot
.3464 .59107 Mdot
.58079 .58484 Mdot
.64979 .51952 Mdot
.44418 .67194 Mdot
.49401 .79935 Mdot
.69591 .55809 Mdot
.43543 .8389 Mdot
.8305 .44635 Mdot
.7488 .63324 Mdot
.64022 .57775 Mdot
.55411 .36273 Mdot
.38444 .59674 Mdot
.46798 .70013 Mdot
.58952 .48239 Mdot
.78152 .62068 Mdot
.51199 .3386 Mdot
.37553 .38964 Mdot
.45415 .48687 Mdot
.62407 .71573 Mdot
.6062 .58045 Mdot
.58077 .53535 Mdot
.59738 .57077 Mdot
.83697 .34474 Mdot
.32738 .56896 Mdot
.56763 .31975 Mdot
.47464 .67129 Mdot
.55334 .34851 Mdot
.34837 .58801 Mdot
.42989 .54129 Mdot
.6111 .50508 Mdot
.50977 .3516 Mdot
.51849 .34119 Mdot
.37187 .4285 Mdot
.41173 .38247 Mdot
.46894 .50076 Mdot
.60597 .52168 Mdot
.32702 .53285 Mdot
.53068 .30661 Mdot
.47781 .39344 Mdot
.45542 .68178 Mdot
.39378 .38361 Mdot
.66052 .53205 Mdot
.32955 .57904 Mdot
.68627 .54648 Mdot
.5442 .31474 Mdot
.36331 .55803 Mdot
.4059 .77395 Mdot
.48352 .6974 Mdot
.58548 .53718 Mdot
.50898 .65302 Mdot
.38253 .58497 Mdot
.62709 .56926 Mdot
.23117 .60891 Mdot
.49392 .70707 Mdot
.29488 .50742 Mdot
.38321 .53575 Mdot
.3068 .37177 Mdot
.57394 .33212 Mdot
.31402 .32098 Mdot
.37007 .56562 Mdot
.21501 .54317 Mdot
.43256 .77721 Mdot
.62091 .60286 Mdot
.54724 .34166 Mdot
.31398 .33844 Mdot
.71088 .75178 Mdot
.20492 .60731 Mdot
.62183 .53693 Mdot
.32345 .54464 Mdot
.45319 .66558 Mdot
.40127 .42523 Mdot
.32587 .49289 Mdot
.43092 .71051 Mdot
.34328 .51229 Mdot
.63987 .51331 Mdot
.51842 .35279 Mdot
.39428 .39954 Mdot
.41707 .29112 Mdot
.34431 .55331 Mdot
.35866 .54289 Mdot
.56637 .53862 Mdot
.44451 .68543 Mdot
.24995 .37344 Mdot
.38436 .57626 Mdot
.81961 .485 Mdot
.39358 .60711 Mdot
.4387 .66225 Mdot
.6522 .5628 Mdot
.69863 .64877 Mdot
.57887 .49647 Mdot
.24424 .6514 Mdot
.34157 .56285 Mdot
.54534 .32002 Mdot
.63053 .58602 Mdot
.79574 .42987 Mdot
.37345 .54644 Mdot
.47337 .40677 Mdot
.32218 .63044 Mdot
.37933 .37371 Mdot
.8118 .38253 Mdot
.59458 .5334 Mdot
.35322 .37059 Mdot
.44621 .67104 Mdot
.61357 .51822 Mdot
.63359 .55977 Mdot
.50711 .32798 Mdot
.37867 .43211 Mdot
.44598 .7639 Mdot
.3553 .39247 Mdot
.36223 .39332 Mdot
.52063 .38383 Mdot
.60187 .55305 Mdot
.3714 .55622 Mdot
.35615 .57892 Mdot
.67439 .5601 Mdot
.34393 .19526 Mdot
.52231 .32532 Mdot
.3926 .58966 Mdot
.81992 .31751 Mdot
.67592 .53885 Mdot
.80164 .37738 Mdot
.47906 .79402 Mdot
.3817 .36474 Mdot
.6426 .50794 Mdot
.52333 .35813 Mdot
.28409 .60184 Mdot
.36187 .54372 Mdot
.66674 .57596 Mdot
.39292 .40037 Mdot
.43626 .68703 Mdot
.38297 .5494 Mdot
.35655 .66704 Mdot
.58675 .55706 Mdot
.29147 .66423 Mdot
.33244 .5363 Mdot
.64443 .79769 Mdot
.24224 .47259 Mdot
.54909 .33895 Mdot
.63835 .55386 Mdot
.56567 .30923 Mdot
.47191 .66633 Mdot
.45632 .4883 Mdot
.39276 .38836 Mdot
.73192 .5423 Mdot
.55682 .19887 Mdot
.39014 .56973 Mdot
.5667 .31456 Mdot
.59756 .49339 Mdot
.34022 .27486 Mdot
.59486 .53872 Mdot
.58278 .46643 Mdot
.46054 .75459 Mdot
.40435 .41016 Mdot
.3809 .36694 Mdot
.64028 .56613 Mdot
.46604 .65714 Mdot
.34191 .55761 Mdot
.37753 .56795 Mdot
.57135 .84782 Mdot
.39405 .45936 Mdot
.79645 .49758 Mdot
.58046 .54213 Mdot
.34749 .51301 Mdot
.32446 .4561 Mdot
.36659 .4184 Mdot
.64596 .48339 Mdot
.36153 .52678 Mdot
.51099 .63142 Mdot
.60878 .64442 Mdot
.64353 .57424 Mdot
.5724 .49715 Mdot
.37073 .36934 Mdot
.4801 .36241 Mdot
.36071 .59599 Mdot
.68775 .55957 Mdot
.41639 .51421 Mdot
.56628 .63349 Mdot
.84107 .45778 Mdot
.54851 .32407 Mdot
.3532 .65205 Mdot
.37426 .41904 Mdot
.55493 .56366 Mdot
.48125 .68022 Mdot
.36614 .51384 Mdot
.3321 .58774 Mdot
.6374 .52255 Mdot
.59633 .59166 Mdot
.81862 .45023 Mdot
.54235 .35457 Mdot
.36823 .38657 Mdot
.60344 .5129 Mdot
.47368 .28601 Mdot
.66212 .52155 Mdot
.39721 .41467 Mdot
.49284 .14727 Mdot
.57197 .5056 Mdot
.59318 .54329 Mdot
.24873 .37945 Mdot
.57225 .34984 Mdot
.54419 .29946 Mdot
.75744 .3125 Mdot
.58074 .5417 Mdot
.82542 .42996 Mdot
.55122 .31873 Mdot
.53289 .31596 Mdot
.27372 .42208 Mdot
.62277 .55978 Mdot
.62575 .62216 Mdot
.39372 .37329 Mdot
.36145 .39214 Mdot
.56124 .35832 Mdot
.70019 .54511 Mdot
.41134 .38612 Mdot
.23031 .36105 Mdot
.35069 .57226 Mdot
.47733 .18022 Mdot
.51974 .32706 Mdot
.3243 .38987 Mdot
.36557 .40739 Mdot
.84739 .52423 Mdot
.29332 .54561 Mdot
.61598 .50661 Mdot
.58195 .54577 Mdot
.4457 .69494 Mdot
.63081 .49225 Mdot
.39586 .56098 Mdot
.37611 .41088 Mdot
.76187 .55758 Mdot
.54676 .32931 Mdot
.6042 .52968 Mdot
.26234 .63875 Mdot
.36522 .77837 Mdot
.369 .6433 Mdot
.51429 .34292 Mdot
.55883 .33309 Mdot
.33433 .58059 Mdot
.32597 .54101 Mdot
.61056 .56666 Mdot
.41001 .40519 Mdot
.56082 .30678 Mdot
.40144 .40953 Mdot
.33617 .55195 Mdot
.3692 .55684 Mdot
.36399 .60441 Mdot
.61319 .59055 Mdot
.36085 .55083 Mdot
.36584 .75182 Mdot
.4403 .39661 Mdot
.53999 .38616 Mdot
.8071 .34643 Mdot
.42147 .294 Mdot
.57511 .27859 Mdot
.44531 .65373 Mdot
.38777 .57661 Mdot
.35299 .37675 Mdot
.65049 .54575 Mdot
.66287 .54552 Mdot
.30016 .39976 Mdot
.35042 .38572 Mdot
.47292 .66982 Mdot
.36173 .36644 Mdot
.47587 .67289 Mdot
.30399 .66176 Mdot
.65601 .50742 Mdot
.62311 .59723 Mdot
.37081 .41217 Mdot
.36197 .55408 Mdot
.36436 .58758 Mdot
.49059 .69169 Mdot
.46025 .54848 Mdot
.38225 .54013 Mdot
.53158 .31406 Mdot
.74629 .54952 Mdot
.3355 .53712 Mdot
.59668 .52393 Mdot
.57173 .71879 Mdot
.31443 .24591 Mdot
.55704 .52127 Mdot
.27632 .40705 Mdot
.67007 .43883 Mdot
.64089 .58283 Mdot
.32041 .23986 Mdot
.37515 .34649 Mdot
.57019 .34209 Mdot
.38563 .58642 Mdot
.35648 .62172 Mdot
.66148 .61012 Mdot
.44305 .64585 Mdot
.60674 .47231 Mdot
.51083 .35318 Mdot
.51275 .31271 Mdot
.68734 .66157 Mdot
.21956 .6236 Mdot
.45952 .6655 Mdot
.44956 .66414 Mdot
.37221 .56514 Mdot
.35862 .81603 Mdot
.56095 .48063 Mdot
.47303 .67298 Mdot
.60163 .33231 Mdot
.63991 .51675 Mdot
.53438 .64045 Mdot
.54126 .4597 Mdot
.56131 .35999 Mdot
.63584 .67142 Mdot
.3722 .54896 Mdot
.56231 .34518 Mdot
.47269 .26146 Mdot
.63241 .48465 Mdot
.54443 .32864 Mdot
.40063 .40717 Mdot
.24527 .50277 Mdot
.52876 .31268 Mdot
.57377 .71011 Mdot
.4088 .42064 Mdot
.47586 .39151 Mdot
.65505 .65471 Mdot
.15513 .65779 Mdot
.37506 .41532 Mdot
.34765 .5318 Mdot
.35765 .5792 Mdot
.37718 .56714 Mdot
.55156 .35032 Mdot
.39046 .57139 Mdot
.54171 .3533 Mdot
.1781 .54344 Mdot
.32269 .25427 Mdot
.47247 .67583 Mdot
.28631 .46579 Mdot
.52662 .35125 Mdot
.58734 .23559 Mdot
.27662 .22356 Mdot
.64023 .50486 Mdot
.3677 .43026 Mdot
.47028 .67476 Mdot
.41449 .82509 Mdot
.45698 .67186 Mdot
.78622 .58954 Mdot
.63032 .32339 Mdot
.60392 .53707 Mdot
.75422 .4419 Mdot
.48814 .67467 Mdot
.51998 .37144 Mdot
.62732 .56835 Mdot
.48935 .5689 Mdot
.45132 .67095 Mdot
.43527 .67 Mdot
.61027 .56167 Mdot
.55566 .31088 Mdot
.36469 .54028 Mdot
.3581 .39468 Mdot
.46704 .65173 Mdot
.64715 .47052 Mdot
.59258 .48844 Mdot
.6194 .50358 Mdot
.48946 .28411 Mdot
.4971 .67391 Mdot
.37936 .41139 Mdot
.17747 .39393 Mdot
.35267 .52257 Mdot
.48817 .5983 Mdot
.82896 .47061 Mdot
.34774 .34129 Mdot
.34234 .56384 Mdot
.36002 .593 Mdot
.62912 .57549 Mdot
.57865 .44959 Mdot
.62166 .32236 Mdot
.45056 .57131 Mdot
.38449 .60219 Mdot
.37691 .57226 Mdot
.55746 .29965 Mdot
.73602 .64032 Mdot
.56024 .50005 Mdot
.40302 .37356 Mdot
.34009 .59666 Mdot
.30354 .28997 Mdot
.44747 .6938 Mdot
.63451 .30593 Mdot
.65609 .50596 Mdot
.61211 .5078 Mdot
.38886 .39597 Mdot
.39742 .40629 Mdot
.29379 .61504 Mdot
.75744 .62196 Mdot
.67045 .44323 Mdot
.38775 .28631 Mdot
.64778 .35718 Mdot
.53804 .29851 Mdot
.56506 .31641 Mdot
.28498 .5039 Mdot
.35612 .40264 Mdot
.63833 .58434 Mdot
.5627 .33763 Mdot
.4798 .62039 Mdot
.73413 .55418 Mdot
.72572 .62106 Mdot
.81157 .40374 Mdot
.63111 .53559 Mdot
.53979 .36445 Mdot
.57299 .35036 Mdot
.56728 .36579 Mdot
.31354 .36776 Mdot
.60077 .56008 Mdot
.62704 .53688 Mdot
.63295 .58154 Mdot
.35301 .24733 Mdot
.59991 .56557 Mdot
.32867 .31514 Mdot
.46655 .47924 Mdot
.69367 .30956 Mdot
.6892 .5574 Mdot
.36024 .36254 Mdot
.5916 .57212 Mdot
.46778 .65832 Mdot
.62772 .49865 Mdot
.72769 .61896 Mdot
.36733 .39568 Mdot
.69931 .60675 Mdot
.4086 .30243 Mdot
.66744 .56773 Mdot
.45482 .64661 Mdot
.38336 .32758 Mdot
.70414 .74058 Mdot
.44568 .63163 Mdot
.5296 .31568 Mdot
.34719 .56818 Mdot
.35188 .37803 Mdot
.36687 .56274 Mdot
.64365 .59422 Mdot
.27558 .5111 Mdot
.42889 .8195 Mdot
.47686 .5554 Mdot
.66335 .5351 Mdot
.55121 .50736 Mdot
.53844 .31192 Mdot
.35828 .52383 Mdot
.58696 .29216 Mdot
.61463 .58224 Mdot
.47108 .68638 Mdot
.44538 .67331 Mdot
.49477 .51494 Mdot
.57234 .81747 Mdot
.26389 .32476 Mdot
.38801 .40093 Mdot
.38455 .5724 Mdot
.48383 .68532 Mdot
.20991 .52184 Mdot
.38947 .35863 Mdot
.40588 .39103 Mdot
.36847 .39095 Mdot
.58347 .51925 Mdot
.34462 .60078 Mdot
.69768 .31172 Mdot
.37134 .51955 Mdot
.62818 .55024 Mdot
.32918 .55778 Mdot
.36987 .52963 Mdot
.47047 .6961 Mdot
.36679 .39026 Mdot
.33598 .55615 Mdot
.58543 .5035 Mdot
.55516 .31806 Mdot
.33287 .43947 Mdot
.51628 .70872 Mdot
.22572 .6294 Mdot
.524 .57445 Mdot
.5653 .36317 Mdot
.69048 .75475 Mdot
.40028 .37705 Mdot
.38361 .23055 Mdot
.45183 .76309 Mdot
.56885 .54531 Mdot
.36114 .18518 Mdot
.40274 .59306 Mdot
.36796 .53074 Mdot
.65077 .56485 Mdot
.40011 .6074 Mdot
.60137 .53334 Mdot
.34375 .54113 Mdot
.36273 .47987 Mdot
.50052 .375 Mdot
.35736 .55405 Mdot
.68119 .57026 Mdot
.63512 .56352 Mdot
.55591 .36099 Mdot
.32038 .55825 Mdot
.58343 .48433 Mdot
.60461 .84608 Mdot
.39436 .4142 Mdot
.34725 .33333 Mdot
.55772 .72933 Mdot
.37535 .42109 Mdot
.54442 .33481 Mdot
.61111 .58715 Mdot
.44695 .66977 Mdot
.52596 .35288 Mdot
.73365 .60814 Mdot
.47898 .69987 Mdot
.46062 .17237 Mdot
.57126 .35446 Mdot
.36285 .53395 Mdot
.47763 .66721 Mdot
.61729 .48823 Mdot
.38012 .52434 Mdot
.23264 .50326 Mdot
.34412 .56156 Mdot
.63004 .57855 Mdot
.31364 .47895 Mdot
.36754 .38574 Mdot
.62057 .53326 Mdot
.3731 .53495 Mdot
.27747 .40947 Mdot
.57867 .52216 Mdot
.64045 .57014 Mdot
.82889 .48496 Mdot
.63019 .25246 Mdot
.45649 .67718 Mdot
.58447 .32171 Mdot
.64118 .50693 Mdot
.44028 .66388 Mdot
.36804 .72846 Mdot
.5931 .51293 Mdot
.51157 .33849 Mdot
.64787 .48344 Mdot
.32174 .55159 Mdot
.38583 .42531 Mdot
.45952 .58517 Mdot
.4371 .67113 Mdot
.18764 .66059 Mdot
.34307 .59575 Mdot
.59965 .58813 Mdot
.65965 .51982 Mdot
.55584 .76718 Mdot
.56795 .34457 Mdot
.58664 .39079 Mdot
.58513 .53773 Mdot
.36419 .23694 Mdot
.61373 .52194 Mdot
.40672 .57942 Mdot
.52825 .3198 Mdot
.5918 .54967 Mdot
.36268 .46095 Mdot
.55637 .56237 Mdot
.44849 .70212 Mdot
.23021 .41433 Mdot
.62022 .48092 Mdot
.47329 .15921 Mdot
.50073 .5576 Mdot
.35656 .55213 Mdot
.30891 .71865 Mdot
.5884 .85831 Mdot
.3918 .3102 Mdot
.5512 .34795 Mdot
.46528 .8024 Mdot
.37107 .5557 Mdot
.28096 .66949 Mdot
.70568 .75101 Mdot
.64162 .55907 Mdot
.60847 .58158 Mdot
.61476 .73198 Mdot
.37074 .52161 Mdot
.3381 .52303 Mdot
.63225 .60075 Mdot
.55279 .54889 Mdot
.36551 .55108 Mdot
.57242 .52324 Mdot
.68453 .57445 Mdot
.36778 .42992 Mdot
.51409 .33506 Mdot
.40518 .4108 Mdot
.41212 .39191 Mdot
.20946 .4094 Mdot
.50138 .57406 Mdot
.39478 .41788 Mdot
.3868 .3646 Mdot
.53656 .63674 Mdot
.76801 .58708 Mdot
.46197 .65236 Mdot
.59957 .82348 Mdot
.37398 .57442 Mdot
.59803 .55371 Mdot
.57567 .35039 Mdot
.66377 .44503 Mdot
.3964 .74552 Mdot
.55518 .21379 Mdot
.62798 .58515 Mdot
.37141 .54417 Mdot
.33437 .35178 Mdot
.70524 .53281 Mdot
.3244 .59406 Mdot
.59868 .51593 Mdot
.39568 .5576 Mdot
.76655 .5337 Mdot
.21554 .54217 Mdot
.36619 .6204 Mdot
.5738 .3683 Mdot
.60998 .51127 Mdot
.51128 .35801 Mdot
.36797 .41875 Mdot
.46683 .65505 Mdot
.45291 .67905 Mdot
.62043 .56711 Mdot
.54795 .49955 Mdot
.30824 .67926 Mdot
.62744 .56142 Mdot
.64259 .51975 Mdot
.36676 .34555 Mdot
.64205 .5143 Mdot
.66756 .53197 Mdot
.65642 .57313 Mdot
.65031 .5854 Mdot
.36212 .39188 Mdot
.25935 .56613 Mdot
.64654 .61237 Mdot
.60293 .60821 Mdot
.41482 .41565 Mdot
.47357 .78655 Mdot
.40798 .3834 Mdot
.71746 .73677 Mdot
.37947 .36532 Mdot
.46003 .68436 Mdot
.49703 .77915 Mdot
.54467 .57056 Mdot
.51189 .32509 Mdot
.34762 .35588 Mdot
.47033 .66311 Mdot
.3755 .40678 Mdot
.34471 .53777 Mdot
.83523 .48075 Mdot
.50048 .32319 Mdot
.53591 .25696 Mdot
.41449 .33996 Mdot
.25119 .54059 Mdot
.3332 .58095 Mdot
.52321 .37563 Mdot
.75782 .49529 Mdot
.66502 .53089 Mdot
.44115 .66255 Mdot
.61291 .56702 Mdot
.36285 .41646 Mdot
.37495 .55478 Mdot
.19246 .57737 Mdot
.44386 .67252 Mdot
.82747 .3767 Mdot
.35936 .58571 Mdot
.66775 .54334 Mdot
.4108 .38548 Mdot
.75181 .27995 Mdot
.40522 .40565 Mdot
.60386 .3859 Mdot
.57182 .32517 Mdot
.18246 .60492 Mdot
.53567 .34862 Mdot
.22798 .52542 Mdot
.67958 .19446 Mdot
.25858 .61007 Mdot
.55699 .31466 Mdot
.43083 .55055 Mdot
.63282 .52578 Mdot
.61801 .50352 Mdot
.20451 .55098 Mdot
.58248 .33815 Mdot
.65524 .52091 Mdot
.31286 .43401 Mdot
.42607 .38969 Mdot
.77966 .35723 Mdot
.33818 .58297 Mdot
.59811 .53104 Mdot
.34971 .41103 Mdot
.34831 .3846 Mdot
.36948 .59682 Mdot
.40518 .38703 Mdot
.62629 .53943 Mdot
.52791 .35098 Mdot
.37396 .49208 Mdot
.4549 .69057 Mdot
.37266 .81128 Mdot
.43741 .70019 Mdot
.34196 .56469 Mdot
.56692 .51369 Mdot
.36857 .55718 Mdot
.70706 .81583 Mdot
.62671 .52761 Mdot
.55015 .31833 Mdot
.64755 .51983 Mdot
.61454 .51202 Mdot
.64255 .58629 Mdot
.36104 .54057 Mdot
.46368 .75069 Mdot
.58 .50881 Mdot
.39194 .38555 Mdot
.67027 .33973 Mdot
.64803 .49154 Mdot
.41796 .61801 Mdot
.71978 .63033 Mdot
.44587 .34931 Mdot
.57849 .32517 Mdot
.35235 .55534 Mdot
.55066 .3281 Mdot
.40013 .20862 Mdot
.54405 .33488 Mdot
.65969 .38638 Mdot
.76361 .49593 Mdot
.7927 .46988 Mdot
.78783 .45463 Mdot
.42811 .49062 Mdot
.58378 .33063 Mdot
.45729 .63548 Mdot
.55714 .30652 Mdot
.566 .35397 Mdot
.38392 .12723 Mdot
.50554 .34685 Mdot
.59096 .5279 Mdot
.65896 .50144 Mdot
.23694 .56838 Mdot
.5605 .68335 Mdot
.65067 .53422 Mdot
.65545 .53207 Mdot
.48361 .68117 Mdot
.39481 .21504 Mdot
.28542 .51866 Mdot
.62228 .24984 Mdot
.37819 .77765 Mdot
.61213 .56473 Mdot
.63414 .50009 Mdot
.65111 .6046 Mdot
.64217 .20721 Mdot
.1967 .43214 Mdot
.56886 .37717 Mdot
.61833 .60646 Mdot
.25412 .62624 Mdot
.62578 .58675 Mdot
.58084 .53041 Mdot
.6315 .53187 Mdot
.37138 .55527 Mdot
.58133 .32225 Mdot
.66095 .58239 Mdot
.53686 .7737 Mdot
.58569 .52582 Mdot
.32809 .34746 Mdot
.25191 .72198 Mdot
.59387 .53388 Mdot
.55796 .29377 Mdot
.62202 .50331 Mdot
.56227 .35172 Mdot
.53941 .37048 Mdot
.62007 .60459 Mdot
.64456 .35799 Mdot
.56331 .29999 Mdot
.62857 .55099 Mdot
.34647 .53449 Mdot
.63696 .79772 Mdot
.62537 .57789 Mdot
.45955 .65256 Mdot
.58201 .54363 Mdot
.44276 .64947 Mdot
.64471 .52666 Mdot
.3498 .59867 Mdot
.6308 .42996 Mdot
.36754 .56944 Mdot
.17611 .50051 Mdot
.35667 .60339 Mdot
.84331 .40662 Mdot
.56237 .36638 Mdot
.30068 .46848 Mdot
.48775 .19818 Mdot
.3012 .35042 Mdot
.50852 .42364 Mdot
.43757 .45678 Mdot
.40989 .40367 Mdot
.56934 .33496 Mdot
.44699 .21483 Mdot
.40597 .71651 Mdot
.40015 .66882 Mdot
.38482 .54789 Mdot
.16214 .39681 Mdot
.44234 .18176 Mdot
.57588 .57537 Mdot
.74011 .45152 Mdot
.7134 .38987 Mdot
.62811 .58743 Mdot
.63744 .58934 Mdot
.37134 .62569 Mdot
.57537 .51231 Mdot
.47336 .2902 Mdot
.33982 .57095 Mdot
.46638 .66005 Mdot
.54524 .31134 Mdot
.43615 .68752 Mdot
.42767 .74068 Mdot
.439 .45014 Mdot
.33961 .54462 Mdot
.5797 .49039 Mdot
.65341 .54024 Mdot
.55437 .35728 Mdot
.58351 .27589 Mdot
.53679 .30353 Mdot
.46622 .67105 Mdot
.34196 .57721 Mdot
.28599 .27157 Mdot
.65597 .54015 Mdot
.52016 .33839 Mdot
.51602 .43122 Mdot
.6435 .51006 Mdot
.36853 .41483 Mdot
.6309 .5211 Mdot
.55237 .30976 Mdot
.64224 .51465 Mdot
.53756 .34863 Mdot
.34914 .56925 Mdot
.66477 .56405 Mdot
.65104 .56854 Mdot
.79534 .33903 Mdot
.47254 .68127 Mdot
.51852 .37563 Mdot
.48189 .60849 Mdot
.64645 .50548 Mdot
.2727 .45291 Mdot
.59648 .51895 Mdot
.4878 .37376 Mdot
.57577 .57014 Mdot
.34787 .33447 Mdot
.58278 .60181 Mdot
.61294 .57235 Mdot
.51875 .47889 Mdot
.7045 .39037 Mdot
.57762 .61475 Mdot
.37517 .36019 Mdot
.51344 .37325 Mdot
.78475 .37044 Mdot
.38193 .50547 Mdot
.32055 .54418 Mdot
.6317 .68921 Mdot
.66891 .57416 Mdot
.60234 .53897 Mdot
.45617 .35744 Mdot
.43937 .67518 Mdot
.5128 .3493 Mdot
.4759 .67329 Mdot
.82361 .39623 Mdot
.46706 .7076 Mdot
.40695 .58045 Mdot
.29194 .66623 Mdot
.25278 .31043 Mdot
.48311 .68425 Mdot
.55362 .30868 Mdot
.27866 .63667 Mdot
.67208 .54309 Mdot
.50195 .54149 Mdot
.46699 .69037 Mdot
.14137 .49295 Mdot
.66771 .53366 Mdot
.51247 .42262 Mdot
.39557 .42179 Mdot
.48195 .68072 Mdot
.40391 .42798 Mdot
.64832 .55143 Mdot
.28804 .5173 Mdot
.55102 .34693 Mdot
.40329 .43307 Mdot
.66945 .50022 Mdot
.47096 .67267 Mdot
.33624 .59374 Mdot
.38688 .44967 Mdot
.39719 .36895 Mdot
.52456 .80856 Mdot
.18271 .57858 Mdot
.34396 .57962 Mdot
.70684 .29138 Mdot
.35968 .36541 Mdot
.67299 .53635 Mdot
.41824 .21028 Mdot
.61417 .5064 Mdot
.27636 .33504 Mdot
.34591 .55606 Mdot
.2536 .54781 Mdot
.63997 .50643 Mdot
.61631 .57947 Mdot
.51629 .3068 Mdot
.36413 .57581 Mdot
.52941 .33748 Mdot
.52758 .38188 Mdot
.34922 .57104 Mdot
.54478 .34174 Mdot
.48762 .68392 Mdot
.477 .24052 Mdot
.37763 .36848 Mdot
.38321 .37877 Mdot
.37788 .56835 Mdot
.35387 .54954 Mdot
.36452 .55847 Mdot
.63083 .52033 Mdot
.51769 .33402 Mdot
.64057 .54801 Mdot
.57755 .54963 Mdot
.67082 .32392 Mdot
.58027 .33331 Mdot
.635 .54146 Mdot
.49079 .58343 Mdot
.55159 .459 Mdot
.33904 .53779 Mdot
.39406 .42026 Mdot
.30957 .44382 Mdot
.23348 .481 Mdot
.59988 .52791 Mdot
.51444 .66649 Mdot
.55436 .30745 Mdot
.45181 .66821 Mdot
.45609 .7105 Mdot
.45762 .67373 Mdot
.42459 .36009 Mdot
.5681 .36422 Mdot
.62259 .25776 Mdot
.5989 .53417 Mdot
.47693 .32106 Mdot
.5622 .38528 Mdot
.29873 .64687 Mdot
.39271 .4192 Mdot
.64949 .51967 Mdot
.46276 .58152 Mdot
.73932 .51215 Mdot
.6193 .50841 Mdot
.65662 .49594 Mdot
.37967 .76115 Mdot
.59177 .47089 Mdot
.52074 .30796 Mdot
.75779 .2915 Mdot
.61791 .49036 Mdot
.30071 .28866 Mdot
.40042 .83538 Mdot
.60315 .52078 Mdot
.60588 .57592 Mdot
.65876 .54906 Mdot
.62462 .49813 Mdot
.56351 .2979 Mdot
.58284 .66462 Mdot
.36344 .36316 Mdot
.4818 .31152 Mdot
.35901 .40758 Mdot
.38921 .59048 Mdot
.25521 .55134 Mdot
.57067 .32821 Mdot
.44488 .69379 Mdot
.33958 .76994 Mdot
.68473 .25119 Mdot
.36215 .59585 Mdot
.23874 .35344 Mdot
.46631 .68797 Mdot
.67243 .52126 Mdot
.47848 .65715 Mdot
.32562 .56634 Mdot
.38045 .37479 Mdot
.6263 .47954 Mdot
.56273 .31452 Mdot
.52547 .316 Mdot
.64944 .51629 Mdot
.26074 .65599 Mdot
.37556 .42493 Mdot
.38698 .36147 Mdot
.58628 .51548 Mdot
.62177 .48871 Mdot
.53188 .33866 Mdot
.37798 .58068 Mdot
.79907 .46574 Mdot
.44778 .66271 Mdot
.61506 .59023 Mdot
.63872 .51087 Mdot
.82638 .48074 Mdot
.39278 .38332 Mdot
.31861 .5776 Mdot
.56907 .55002 Mdot
.37455 .28258 Mdot
.56937 .54392 Mdot
.66123 .59896 Mdot
.34546 .53413 Mdot
.68961 .59005 Mdot
.61813 .59722 Mdot
.48966 .36587 Mdot
.40663 .41733 Mdot
.54567 .32422 Mdot
.48784 .36225 Mdot
.50451 .23168 Mdot
.36813 .40994 Mdot
.63507 .53092 Mdot
.38788 .4186 Mdot
.59442 .51215 Mdot
.6023 .49475 Mdot
.39705 .41527 Mdot
.52945 .33868 Mdot
.45682 .79928 Mdot
.25971 .59283 Mdot
.61473 .49691 Mdot
.62281 .60238 Mdot
.55931 .66569 Mdot
.42741 .71567 Mdot
.61355 .58248 Mdot
.54604 .30717 Mdot
.65273 .55197 Mdot
.38211 .43264 Mdot
.48787 .67653 Mdot
.55537 .31614 Mdot
.36493 .58955 Mdot
.34951 .59523 Mdot
.4062 .30556 Mdot
.37835 .5326 Mdot
.60441 .58089 Mdot
.56276 .27867 Mdot
.54654 .28872 Mdot
.30732 .74794 Mdot
.35095 .57444 Mdot
.45711 .65112 Mdot
.63689 .57105 Mdot
.6796 .68812 Mdot
.35298 .4181 Mdot
.33891 .17464 Mdot
.58313 .22952 Mdot
.4871 .66011 Mdot
.59168 .25121 Mdot
.3607 .60178 Mdot
.63743 .59685 Mdot
.45677 .6533 Mdot
.33471 .58123 Mdot
.59673 .5035 Mdot
.62512 .6057 Mdot
.5909 .39422 Mdot
.39859 .46626 Mdot
.39028 .41578 Mdot
.39236 .55523 Mdot
.47552 .64788 Mdot
.38349 .60552 Mdot
.54601 .37148 Mdot
.6009 .56286 Mdot
.56641 .5208 Mdot
.37764 .58356 Mdot
.3201 .5423 Mdot
.63136 .54597 Mdot
.56678 .31091 Mdot
.39876 .62553 Mdot
.61182 .55996 Mdot
.39172 .46017 Mdot
.58609 .33591 Mdot
.3391 .58052 Mdot
.61136 .57517 Mdot
.42823 .64798 Mdot
.36589 .58557 Mdot
.33589 .54051 Mdot
.63587 .5007 Mdot
.48469 .69074 Mdot
.59214 .59351 Mdot
.38832 .3704 Mdot
.16047 .42035 Mdot
.38068 .43251 Mdot
.39323 .50889 Mdot
.59246 .4678 Mdot
.38135 .25735 Mdot
.57623 .33302 Mdot
.67198 .66189 Mdot
.31336 .43645 Mdot
.68606 .57384 Mdot
.62591 .79069 Mdot
.32512 .39378 Mdot
.29967 .72951 Mdot
.67824 .72746 Mdot
.46807 .69435 Mdot
.37485 .40414 Mdot
.60556 .57598 Mdot
.36938 .43182 Mdot
.45117 .65446 Mdot
.17792 .49742 Mdot
.62479 .57951 Mdot
.53291 .31651 Mdot
.62942 .54004 Mdot
.52315 .32216 Mdot
.62635 .49538 Mdot
.56893 .57669 Mdot
.29939 .37841 Mdot
.58836 .64165 Mdot
.57034 .54799 Mdot
.82218 .32759 Mdot
.56304 .43764 Mdot
.4554 .65889 Mdot
.63956 .55626 Mdot
.34279 .60952 Mdot
.35089 .39538 Mdot
.31858 .33084 Mdot
.37081 .55313 Mdot
.39751 .37042 Mdot
.53916 .34037 Mdot
.34816 .55971 Mdot
.36849 .59547 Mdot
.69407 .58593 Mdot
.48967 .67024 Mdot
.37687 .38615 Mdot
.59096 .55109 Mdot
.62229 .57858 Mdot
.7069 .28709 Mdot
.39216 .71809 Mdot
.57293 .26715 Mdot
.58148 .18152 Mdot
.54532 .37935 Mdot
.4688 .66451 Mdot
.36518 .54144 Mdot
.58297 .56177 Mdot
.6204 .53793 Mdot
.28238 .45408 Mdot
.55027 .30089 Mdot
.45815 .4967 Mdot
.59218 .2689 Mdot
.47386 .61969 Mdot
.5928 .65026 Mdot
.54617 .30983 Mdot
.58579 .64978 Mdot
.49849 .68413 Mdot
.53095 .83596 Mdot
.55456 .6338 Mdot
.39251 .42348 Mdot
.57031 .6481 Mdot
.51462 .35087 Mdot
.58335 .50753 Mdot
.35245 .53125 Mdot
.36952 .52898 Mdot
.53793 .32843 Mdot
.34384 .60506 Mdot
.46423 .69897 Mdot
.59249 .56413 Mdot
.62326 .23904 Mdot
.43859 .28174 Mdot
.38133 .56685 Mdot
.70388 .55029 Mdot
.36759 .39221 Mdot
.649 .51513 Mdot
.47848 .6921 Mdot
.37912 .41783 Mdot
.7741 .60404 Mdot
.42879 .40538 Mdot
.63142 .57025 Mdot
.82979 .47989 Mdot
.37145 .4102 Mdot
.63036 .44747 Mdot
.60439 .55679 Mdot
.39594 .37568 Mdot
.71877 .54155 Mdot
.24216 .50836 Mdot
.4797 .5419 Mdot
.70675 .75126 Mdot
.48336 .50061 Mdot
.37486 .54417 Mdot
.24688 .52768 Mdot
.29552 .34886 Mdot
.35517 .37665 Mdot
.31609 .56094 Mdot
.509 .58336 Mdot
.4058 .42506 Mdot
.67203 .52389 Mdot
.60126 .51746 Mdot
.19526 .44453 Mdot
.33622 .39155 Mdot
.22443 .5289 Mdot
.42184 .32115 Mdot
.64832 .50604 Mdot
.57758 .58164 Mdot
.61673 .53999 Mdot
.53831 .2974 Mdot
.39415 .40454 Mdot
.79435 .31255 Mdot
.36936 .41933 Mdot
.64727 .31063 Mdot
.37545 .57091 Mdot
.33664 .58127 Mdot
.596 .53034 Mdot
.51408 .41767 Mdot
.746 .62092 Mdot
.62632 .5436 Mdot
.45448 .73042 Mdot
.20353 .46228 Mdot
.62815 .49091 Mdot
.57413 .32052 Mdot
.68686 .58267 Mdot
.64972 .46837 Mdot
.37613 .36811 Mdot
.44968 .69441 Mdot
.70352 .65054 Mdot
.37591 .37648 Mdot
.60383 .53919 Mdot
.38927 .26245 Mdot
.61983 .5162 Mdot
.61148 .49839 Mdot
.61778 .29078 Mdot
.46418 .71092 Mdot
.35866 .5646 Mdot
.46016 .67539 Mdot
.56864 .34657 Mdot
.304 .17457 Mdot
.4633 .70806 Mdot
.76025 .60834 Mdot
.18004 .45454 Mdot
.55464 .64244 Mdot
.5111 .34862 Mdot
.476 .65226 Mdot
.38393 .42719 Mdot
.63374 .80118 Mdot
.58691 .40775 Mdot
.33599 .42132 Mdot
.61015 .55487 Mdot
.50366 .36362 Mdot
.52311 .31461 Mdot
.40684 .43069 Mdot
.53522 .3724 Mdot
.63594 .62061 Mdot
.59567 .50111 Mdot
.35665 .39341 Mdot
.39817 .28128 Mdot
.36706 .35982 Mdot
.43071 .53035 Mdot
.63455 .5584 Mdot
.55182 .31482 Mdot
.62548 .59359 Mdot
.58138 .29821 Mdot
.32467 .58808 Mdot
.57444 .49788 Mdot
.46289 .70009 Mdot
.36662 .26876 Mdot
.34556 .58234 Mdot
.49226 .61948 Mdot
.5572 .3561 Mdot
.43725 .36999 Mdot
.553 .36213 Mdot
.56679 .28677 Mdot
.40934 .38434 Mdot
.52441 .36192 Mdot
.60256 .5732 Mdot
.48639 .55611 Mdot
.55283 .35276 Mdot
.38344 .39463 Mdot
.44736 .6887 Mdot
.53602 .34562 Mdot
.39818 .61012 Mdot
.63433 .57385 Mdot
.35871 .54244 Mdot
.43703 .73797 Mdot
.50351 .35557 Mdot
.48135 .70717 Mdot
.32381 .53866 Mdot
.43528 .66953 Mdot
.25815 .69571 Mdot
.41919 .42025 Mdot
.63374 .32766 Mdot
.45013 .7337 Mdot
.51428 .32053 Mdot
.46181 .7595 Mdot
.57853 .54723 Mdot
.63662 .57277 Mdot
.4419 .65129 Mdot
.52334 .31432 Mdot
.46253 .84886 Mdot
.55726 .47609 Mdot
.42144 .50294 Mdot
.36267 .35169 Mdot
.84289 .39522 Mdot
.4251 .51786 Mdot
.36336 .82256 Mdot
.69753 .5331 Mdot
.34154 .52085 Mdot
.6072 .52931 Mdot
.29587 .42358 Mdot
.47011 .67623 Mdot
.42481 .56809 Mdot
.55967 .53793 Mdot
.35279 .56427 Mdot
.65633 .5675 Mdot
.51045 .4903 Mdot
.65905 .46209 Mdot
.44694 .65244 Mdot
.2725 .65109 Mdot
.50625 .35782 Mdot
.45814 .69073 Mdot
.33089 .57032 Mdot
.64808 .65223 Mdot
.59782 .50223 Mdot
.6753 .53007 Mdot
.47226 .61987 Mdot
.5156 .33656 Mdot
.36684 .53386 Mdot
.38685 .37124 Mdot
.443 .68744 Mdot
.65198 .54043 Mdot
.57553 .54658 Mdot
.27163 .44109 Mdot
.36471 .3965 Mdot
.36314 .52239 Mdot
.40154 .42024 Mdot
.37315 .5986 Mdot
.58176 .50274 Mdot
.34889 .59187 Mdot
.6684 .58026 Mdot
.31978 .35728 Mdot
.62825 .307 Mdot
.71054 .40731 Mdot
.34265 .55876 Mdot
.77055 .57521 Mdot
.36567 .39972 Mdot
.40565 .39808 Mdot
.19869 .38788 Mdot
.60025 .38482 Mdot
.68467 .26151 Mdot
.59349 .78157 Mdot
.35986 .39088 Mdot
.37392 .39065 Mdot
.35719 .54334 Mdot
.52691 .36326 Mdot
.54369 .37829 Mdot
.37343 .59695 Mdot
.56624 .7236 Mdot
.51295 .34872 Mdot
.5875 .81712 Mdot
.75854 .3322 Mdot
.68261 .56336 Mdot
.41019 .57164 Mdot
.44819 .67251 Mdot
.57847 .71166 Mdot
.50466 .50431 Mdot
.62131 .58211 Mdot
.6653 .67948 Mdot
.3787 .57442 Mdot
.48851 .39709 Mdot
.70769 .74138 Mdot
.66104 .56615 Mdot
.59952 .55534 Mdot
.61072 .53673 Mdot
.492 .68261 Mdot
.60642 .40888 Mdot
.60182 .56901 Mdot
.56341 .72537 Mdot
.64869 .50998 Mdot
.66902 .46475 Mdot
.4547 .67754 Mdot
.54461 .61632 Mdot
.41587 .72943 Mdot
.76017 .30015 Mdot
.61915 .45281 Mdot
.38337 .36875 Mdot
.40963 .65268 Mdot
.40756 .40419 Mdot
.67181 .38797 Mdot
.53579 .63018 Mdot
.55066 .3792 Mdot
.61876 .58186 Mdot
.34125 .56549 Mdot
.52295 .3152 Mdot
.25656 .49129 Mdot
.3473 .14734 Mdot
.37306 .36531 Mdot
.49911 .89253 Mdot
.39923 .38061 Mdot
.37141 .59443 Mdot
.53295 .33814 Mdot
.76454 .51006 Mdot
.50165 .26413 Mdot
.53893 .3453 Mdot
.44525 .82327 Mdot
.57656 .37268 Mdot
.70065 .63695 Mdot
.50494 .32768 Mdot
.37864 .3951 Mdot
.41165 .3453 Mdot
.62251 .62465 Mdot
.58259 .53516 Mdot
.44264 .45558 Mdot
.74501 .61706 Mdot
.57893 .54889 Mdot
.3406 .5728 Mdot
.62435 .33035 Mdot
.64605 .68192 Mdot
.51964 .3586 Mdot
.42633 .40451 Mdot
.60439 .56271 Mdot
.63051 .50625 Mdot
.58948 .50527 Mdot
.58818 .22323 Mdot
.52648 .83635 Mdot
.58115 .50723 Mdot
.63463 .49718 Mdot
.34971 .56198 Mdot
.4229 .69889 Mdot
.27304 .62073 Mdot
.69177 .29477 Mdot
.65553 .57765 Mdot
.45526 .68669 Mdot
.47428 .64408 Mdot
.57271 .52818 Mdot
.49712 .57361 Mdot
.3938 .25539 Mdot
.59145 .55277 Mdot
.6231 .33771 Mdot
.29842 .59787 Mdot
.36997 .52093 Mdot
.36927 .58714 Mdot
.5159 .37132 Mdot
.38046 .58576 Mdot
.34641 .59881 Mdot
.75495 .53402 Mdot
.47286 .49615 Mdot
.31463 .37736 Mdot
.4647 .66895 Mdot
.6211 .53179 Mdot
.55867 .60205 Mdot
.37635 .27567 Mdot
.41157 .40529 Mdot
.56082 .32084 Mdot
.35038 .39966 Mdot
.47752 .64035 Mdot
.532 .23466 Mdot
.38685 .56173 Mdot
.36528 .37812 Mdot
.40823 .44381 Mdot
.45319 .685 Mdot
.38962 .43701 Mdot
.43803 .41512 Mdot
.60087 .48463 Mdot
.73086 .45695 Mdot
.6264 .55083 Mdot
.34565 .77922 Mdot
.37027 .38614 Mdot
.38626 .34108 Mdot
.59648 .5428 Mdot
.36296 .58493 Mdot
.71654 .59086 Mdot
.58255 .53062 Mdot
.38114 .5829 Mdot
.57254 .56933 Mdot
.43473 .69528 Mdot
.58579 .32098 Mdot
.4981 .26935 Mdot
.1629 .38802 Mdot
.48814 .66536 Mdot
.26087 .48385 Mdot
.62333 .58514 Mdot
.20827 .62216 Mdot
.5329 .34703 Mdot
.58465 .57383 Mdot
.63314 .67053 Mdot
.54331 .3554 Mdot
.55321 .33027 Mdot
.63624 .51978 Mdot
.39571 .42344 Mdot
.34312 .58241 Mdot
.45099 .68037 Mdot
.33277 .7902 Mdot
.61884 .56073 Mdot
.65236 .56297 Mdot
.46213 .68951 Mdot
.3631 .40701 Mdot
.57011 .54263 Mdot
.58853 .75614 Mdot
.49653 .8557 Mdot
.40275 .38203 Mdot
.6698 .54431 Mdot
.67393 .41236 Mdot
.57868 .462 Mdot
.18255 .62921 Mdot
.5012 .55426 Mdot
.35706 .55901 Mdot
.56288 .48869 Mdot
.43882 .14773 Mdot
.44683 .69093 Mdot
.68366 .25296 Mdot
.63283 .5065 Mdot
.65788 .53679 Mdot
.54235 .30272 Mdot
.63762 .54843 Mdot
.56899 .32419 Mdot
.21849 .32228 Mdot
.83434 .46192 Mdot
.53133 .37598 Mdot
.50877 .32896 Mdot
.71342 .64361 Mdot
.34073 .46747 Mdot
.53803 .33084 Mdot
.60763 .49298 Mdot
.51638 .60743 Mdot
.4859 .38367 Mdot
.46731 .64896 Mdot
.45077 .75553 Mdot
.53514 .52114 Mdot
.51254 .64599 Mdot
.4714 .78956 Mdot
.53158 .55934 Mdot
.44378 .5592 Mdot
.39885 .38692 Mdot
.66094 .56751 Mdot
.36949 .52823 Mdot
.37486 .52901 Mdot
.66295 .58681 Mdot
.62372 .52346 Mdot
.56547 .35022 Mdot
.44162 .67423 Mdot
.35459 .37169 Mdot
.65555 .53543 Mdot
.6688 .65966 Mdot
.43846 .68482 Mdot
.53146 .36965 Mdot
.66062 .33347 Mdot
.43148 .69631 Mdot
.57472 .58651 Mdot
.58681 .54229 Mdot
.63116 .53561 Mdot
.61489 .62526 Mdot
.39705 .40278 Mdot
.48476 .77649 Mdot
.65072 .49797 Mdot
.82075 .38613 Mdot
.3169 .40812 Mdot
.55729 .51363 Mdot
.54775 .3687 Mdot
.4155 .3754 Mdot
.36472 .60665 Mdot
.4893 .22199 Mdot
.62943 .56874 Mdot
.2637 .65165 Mdot
.19527 .45504 Mdot
.31968 .57293 Mdot
.58263 .30458 Mdot
.4581 .66968 Mdot
.62567 .5406 Mdot
.64215 .36138 Mdot
.59946 .51991 Mdot
.49659 .70364 Mdot
.33066 .54425 Mdot
.4004 .39013 Mdot
.31515 .74652 Mdot
.38646 .54144 Mdot
.55101 .32871 Mdot
.8213 .58008 Mdot
.56971 .3233 Mdot
.54021 .37892 Mdot
.66962 .33558 Mdot
.39814 .40308 Mdot
.38723 .154 Mdot
.23114 .32027 Mdot
.58495 .49385 Mdot
.36451 .40531 Mdot
.53989 .3212 Mdot
.65814 .52089 Mdot
.59283 .34233 Mdot
.57359 .3574 Mdot
.59129 .49693 Mdot
.66171 .54386 Mdot
.22574 .56404 Mdot
.68131 .75126 Mdot
.45985 .66954 Mdot
.57255 .34548 Mdot
.48353 .27985 Mdot
.65925 .52017 Mdot
.59821 .53495 Mdot
.27347 .36685 Mdot
.48787 .67013 Mdot
.46325 .27553 Mdot
.63153 .50634 Mdot
.81789 .52664 Mdot
.66894 .60175 Mdot
.56686 .30255 Mdot
.4086 .39775 Mdot
.77173 .31657 Mdot
.4275 .43503 Mdot
.56812 .32504 Mdot
.44794 .69882 Mdot
.52392 .29897 Mdot
.76825 .59932 Mdot
.3607 .40977 Mdot
.55227 .30967 Mdot
.45892 .58277 Mdot
.38835 .40851 Mdot
.37017 .38055 Mdot
.67763 .32504 Mdot
.32191 .58958 Mdot
.49294 .67595 Mdot
.37503 .38764 Mdot
.3742 .23656 Mdot
.38255 .40042 Mdot
.21874 .3374 Mdot
.66541 .55921 Mdot
.61637 .71108 Mdot
.40379 .52018 Mdot
.54101 .52727 Mdot
.3659 .3872 Mdot
.48426 .67836 Mdot
.59867 .50366 Mdot
.5152 .36175 Mdot
.44222 .66368 Mdot
.35384 .43403 Mdot
.36699 .55181 Mdot
.54783 .36269 Mdot
.34166 .37188 Mdot
.52617 .3171 Mdot
.44597 .216 Mdot
.16723 .45376 Mdot
.71934 .65924 Mdot
.50466 .25949 Mdot
.60009 .50107 Mdot
.54047 .80473 Mdot
.67158 .55298 Mdot
.62527 .51776 Mdot
.33875 .57673 Mdot
.63374 .69753 Mdot
.52974 .33777 Mdot
.40484 .81753 Mdot
.37291 .36946 Mdot
.76888 .30833 Mdot
.60563 .45506 Mdot
.59972 .5891 Mdot
.55614 .35075 Mdot
.55922 .30335 Mdot
.69518 .37464 Mdot
.3926 .59923 Mdot
.61906 .58823 Mdot
.65065 .4876 Mdot
.65787 .59291 Mdot
.37801 .37242 Mdot
.49916 .59975 Mdot
.37737 .54882 Mdot
.16686 .52218 Mdot
.32921 .54423 Mdot
.5048 .69389 Mdot
.522 .36335 Mdot
.46279 .70788 Mdot
.59616 .5362 Mdot
.5887 .28031 Mdot
.54765 .30015 Mdot
.43979 .65417 Mdot
.47969 .67206 Mdot
.24751 .45417 Mdot
.39641 .41547 Mdot
.57951 .52772 Mdot
.60916 .57417 Mdot
.64261 .54384 Mdot
.62972 .52199 Mdot
.37082 .36668 Mdot
.59004 .50846 Mdot
.3539 .42267 Mdot
.50381 .21218 Mdot
.62158 .73027 Mdot
.48645 .49705 Mdot
.254 .34859 Mdot
.51626 .35633 Mdot
.37525 .24255 Mdot
.62436 .46652 Mdot
.49695 .18353 Mdot
.19085 .52758 Mdot
.63163 .48691 Mdot
.34476 .59309 Mdot
.72426 .53976 Mdot
.38249 .5436 Mdot
.36874 .83474 Mdot
.28496 .38264 Mdot
.66821 .76515 Mdot
.62357 .57858 Mdot
.48463 .5559 Mdot
.34402 .24938 Mdot
.67316 .54397 Mdot
.26366 .42792 Mdot
.27545 .33401 Mdot
.26748 .63479 Mdot
.48342 .68778 Mdot
.62027 .57019 Mdot
.56853 .60917 Mdot
.59847 .56949 Mdot
.60279 .53057 Mdot
.58982 .5067 Mdot
.35552 .36285 Mdot
.58878 .57386 Mdot
.60839 .50459 Mdot
.3148 .68877 Mdot
.59048 .64708 Mdot
.34426 .52379 Mdot
.19082 .41091 Mdot
.46496 .70841 Mdot
.55749 .35339 Mdot
.51794 .82934 Mdot
.39229 .42309 Mdot
.70173 .37808 Mdot
.63023 .5278 Mdot
.23924 .57497 Mdot
.41837 .4361 Mdot
.45263 .70054 Mdot
.32544 .57061 Mdot
.66736 .77847 Mdot
.34324 .5696 Mdot
.40869 .36033 Mdot
.35836 .58381 Mdot
.59304 .46449 Mdot
.5669 .34936 Mdot
.57595 .52804 Mdot
.37951 .38522 Mdot
.3662 .59179 Mdot
.56195 .67604 Mdot
.61597 .53772 Mdot
.35008 .57101 Mdot
.57667 .52666 Mdot
.54132 .25265 Mdot
.73164 .32108 Mdot
.34063 .59464 Mdot
.40545 .44308 Mdot
.39125 .38948 Mdot
.48072 .69574 Mdot
.54794 .35879 Mdot
.56391 .32286 Mdot
.379 .41634 Mdot
.60875 .31564 Mdot
.65554 .57907 Mdot
.66223 .53059 Mdot
.79106 .3446 Mdot
.59763 .57269 Mdot
.64988 .65028 Mdot
.46632 .58372 Mdot
.52276 .37045 Mdot
.60279 .59251 Mdot
.63851 .5167 Mdot
.63282 .57105 Mdot
.5702 .24408 Mdot
.38101 .5785 Mdot
.66299 .56372 Mdot
.47638 .66548 Mdot
.28213 .60215 Mdot
.6485 .51445 Mdot
.67389 .60461 Mdot
.5632 .32106 Mdot
.58659 .18917 Mdot
.40071 .38371 Mdot
.33156 .56994 Mdot
.34265 .55739 Mdot
.47308 .77538 Mdot
.32726 .28675 Mdot
.46757 .58228 Mdot
.16514 .56915 Mdot
.29973 .37841 Mdot
.47388 .67083 Mdot
.37838 .51777 Mdot
.39245 .33641 Mdot
.34506 .54726 Mdot
.36732 .36526 Mdot
.66862 .54521 Mdot
.65809 .57572 Mdot
.4044 .17218 Mdot
.57009 .5366 Mdot
.45414 .67131 Mdot
.36138 .36027 Mdot
.51537 .34839 Mdot
.44823 .69734 Mdot
.40296 .41896 Mdot
.51823 .37211 Mdot
.63718 .4874 Mdot
.64808 .49406 Mdot
.56103 .3239 Mdot
.53989 .30537 Mdot
.58931 .54207 Mdot
.31598 .50093 Mdot
.51009 .32905 Mdot
.54741 .30899 Mdot
.38519 .56237 Mdot
.37494 .53084 Mdot
.60677 .61097 Mdot
.36789 .39935 Mdot
.60457 .50454 Mdot
.34573 .56129 Mdot
.46509 .7075 Mdot
.527 .34012 Mdot
.61882 .49736 Mdot
.64961 .52192 Mdot
.45195 .6854 Mdot
.47051 .70275 Mdot
.47915 .68975 Mdot
.34033 .38451 Mdot
.64383 .55162 Mdot
.53793 .33705 Mdot
.39929 .40911 Mdot
.48038 .64868 Mdot
.47439 .65497 Mdot
.39853 .53941 Mdot
.59128 .57063 Mdot
.37265 .49199 Mdot
.45785 .14289 Mdot
.82196 .42839 Mdot
.32937 .58922 Mdot
.36914 .60744 Mdot
.53203 .67937 Mdot
.47659 .38467 Mdot
.37168 .41812 Mdot
.42851 .71373 Mdot
.7244 .64308 Mdot
.61241 .48043 Mdot
.62729 .49217 Mdot
.56833 .57157 Mdot
.48 .68628 Mdot
.64767 .70237 Mdot
.57052 .33052 Mdot
.58672 .63072 Mdot
.43711 .682 Mdot
.32678 .53486 Mdot
.38866 .52207 Mdot
.32705 .54834 Mdot
.66785 .51426 Mdot
.7235 .41914 Mdot
.35165 .26567 Mdot
.57982 .77562 Mdot
.36472 .39266 Mdot
.55582 .59886 Mdot
.20772 .61272 Mdot
.55783 .32874 Mdot
.39104 .58929 Mdot
.47414 .66835 Mdot
.53713 .30668 Mdot
.35292 .40813 Mdot
.37593 .38966 Mdot
.38084 .56511 Mdot
.37793 .5622 Mdot
.3468 .53852 Mdot
.57633 .35587 Mdot
.52342 .36296 Mdot
.63121 .56727 Mdot
.52319 .34432 Mdot
.55173 .20278 Mdot
.43281 .65652 Mdot
.32224 .59917 Mdot
.37232 .40254 Mdot
.51109 .35524 Mdot
.61805 .54042 Mdot
.47933 .36463 Mdot
.35258 .31572 Mdot
.45611 .65723 Mdot
.71814 .30323 Mdot
.33217 .80301 Mdot
.5777 .53365 Mdot
.39595 .39353 Mdot
.6227 .23311 Mdot
.61148 .53955 Mdot
.362 .5378 Mdot
.3396 .7391 Mdot
.31655 .51585 Mdot
.58368 .52768 Mdot
.59753 .48259 Mdot
.38993 .3694 Mdot
.17113 .52981 Mdot
.62582 .56466 Mdot
.46849 .25892 Mdot
.41556 .43514 Mdot
.37058 .53935 Mdot
.62805 .83813 Mdot
.43426 .62958 Mdot
.57563 .71694 Mdot
.38168 .55957 Mdot
.61283 .51177 Mdot
.3872 .55377 Mdot
.46947 .65975 Mdot
.32889 .57466 Mdot
.57069 .32038 Mdot
.32393 .54689 Mdot
.65306 .56202 Mdot
.54012 .32784 Mdot
.37048 .41005 Mdot
.74672 .29296 Mdot
.36187 .73943 Mdot
.36524 .58432 Mdot
.35066 .5979 Mdot
.5931 .58857 Mdot
.46884 .29183 Mdot
.65971 .58584 Mdot
.66778 .53659 Mdot
.35916 .39934 Mdot
.54581 .35605 Mdot
.40451 .38202 Mdot
.55357 .57577 Mdot
.63691 .73513 Mdot
.40228 .41726 Mdot
.26067 .60968 Mdot
.4681 .68697 Mdot
.49003 .43964 Mdot
.62165 .53705 Mdot
.39723 .43408 Mdot
.64271 .55433 Mdot
.57101 .33504 Mdot
.49887 .47268 Mdot
.27499 .54068 Mdot
.37931 .37882 Mdot
.28159 .69834 Mdot
.5874 .74596 Mdot
.61981 .61652 Mdot
.40629 .39721 Mdot
.63268 .67697 Mdot
.3737 .59344 Mdot
.44572 .66338 Mdot
.43054 .68482 Mdot
.43539 .67974 Mdot
.68908 .56217 Mdot
.61426 .45383 Mdot
.48284 .70701 Mdot
.35211 .3977 Mdot
.44751 .65239 Mdot
.28837 .28969 Mdot
.4089 .81832 Mdot
.46902 .67945 Mdot
.60687 .55663 Mdot
.68289 .49078 Mdot
.53822 .63692 Mdot
.23847 .50776 Mdot
.65238 .77429 Mdot
.23537 .41129 Mdot
.58608 .52958 Mdot
.58404 .34866 Mdot
.5759 .34851 Mdot
.62533 .21652 Mdot
.75734 .59896 Mdot
.82583 .46061 Mdot
.51043 .3719 Mdot
.30852 .47193 Mdot
.53625 .36756 Mdot
.57836 .5148 Mdot
.66109 .52692 Mdot
.51304 .37709 Mdot
.65179 .72012 Mdot
.29319 .47937 Mdot
.32256 .76698 Mdot
.53139 .31156 Mdot
.40711 .41565 Mdot
.41562 .40569 Mdot
.3681 .38198 Mdot
.74037 .30717 Mdot
.55455 .34765 Mdot
.64801 .53509 Mdot
.34097 .56117 Mdot
.6531 .57695 Mdot
.38944 .4113 Mdot
.41942 .82993 Mdot
.54077 .34859 Mdot
.60444 .56636 Mdot
.69258 .60434 Mdot
.37367 .55722 Mdot
.45993 .68566 Mdot
.51001 .26869 Mdot
.82098 .47009 Mdot
.36943 .37231 Mdot
.50441 .35872 Mdot
.36657 .34025 Mdot
.33777 .76544 Mdot
.69873 .53045 Mdot
.62319 .47448 Mdot
.33247 .79254 Mdot
.80566 .55869 Mdot
.6163 .58544 Mdot
.33462 .58442 Mdot
.28098 .44537 Mdot
.64304 .51162 Mdot
.57509 .34603 Mdot
.43149 .69466 Mdot
.43722 .66659 Mdot
.61182 .61257 Mdot
.46807 .34862 Mdot
.50014 .50266 Mdot
.63478 .5284 Mdot
.57191 .58249 Mdot
.37469 .54536 Mdot
.29168 .40553 Mdot
.82424 .39717 Mdot
.46036 .70571 Mdot
.57429 .53076 Mdot
.43347 .8048 Mdot
.53447 .3035 Mdot
.32106 .57598 Mdot
.37797 .43339 Mdot
.56113 .38533 Mdot
.32617 .57306 Mdot
.61574 .49441 Mdot
.57116 .53476 Mdot
.41327 .39831 Mdot
.56743 .30383 Mdot
.47789 .68733 Mdot
.33599 .57565 Mdot
.46934 .70063 Mdot
.54447 .35375 Mdot
.52283 .35188 Mdot
.67898 .60983 Mdot
.68897 .51142 Mdot
.36408 .58902 Mdot
.67624 .5746 Mdot
.3042 .52506 Mdot
.20569 .67414 Mdot
.3477 .35574 Mdot
.58334 .56608 Mdot
.50911 .31675 Mdot
.37742 .37502 Mdot
.65911 .54013 Mdot
.3801 .83015 Mdot
.65533 .51428 Mdot
.36965 .35079 Mdot
.76687 .62415 Mdot
.47142 .69641 Mdot
.55026 .60849 Mdot
.20897 .55621 Mdot
.59041 .56623 Mdot
.34986 .5494 Mdot
.70098 .55774 Mdot
.39037 .42774 Mdot
.52008 .36004 Mdot
.19866 .67515 Mdot
.38545 .39754 Mdot
.59059 .55988 Mdot
.44413 .69101 Mdot
.516 .31208 Mdot
.50648 .56033 Mdot
.4965 .57986 Mdot
.71357 .54191 Mdot
.61874 .591 Mdot
.63069 .51316 Mdot
.59683 .75884 Mdot
.33251 .56392 Mdot
.54378 .31272 Mdot
.395 .38802 Mdot
.37663 .41781 Mdot
.38074 .57068 Mdot
.38074 .48826 Mdot
.48895 .44012 Mdot
.54449 .14338 Mdot
.39087 .56569 Mdot
.45403 .70687 Mdot
.46991 .27723 Mdot
.33576 .56559 Mdot
.35374 .57362 Mdot
.3853 .55988 Mdot
.45237 .568 Mdot
.51225 .34849 Mdot
.61802 .49415 Mdot
.57827 .32462 Mdot
.61264 .51002 Mdot
.37895 .35266 Mdot
.37794 .38169 Mdot
.53682 .35255 Mdot
.28576 .73567 Mdot
.71065 .45146 Mdot
.60597 .54543 Mdot
.20868 .6214 Mdot
.56229 .52738 Mdot
.54445 .65017 Mdot
.56452 .54987 Mdot
.37109 .57892 Mdot
.67725 .53075 Mdot
.67813 .58084 Mdot
.65247 .23032 Mdot
.36977 .40226 Mdot
.36863 .51876 Mdot
.55529 .54679 Mdot
.57924 .58903 Mdot
.57512 .35994 Mdot
.53978 .30665 Mdot
.43134 .68253 Mdot
.64357 .64349 Mdot
.36868 .41154 Mdot
.28437 .26594 Mdot
.58305 .53653 Mdot
.49733 .63391 Mdot
.78685 .43349 Mdot
.65907 .54329 Mdot
.21556 .58621 Mdot
.71758 .40852 Mdot
.62449 .53943 Mdot
.43227 .48558 Mdot
.36549 .3981 Mdot
.67984 .71921 Mdot
.64458 .50715 Mdot
.37064 .54937 Mdot
.52776 .36632 Mdot
.54538 .29891 Mdot
.43688 .69624 Mdot
.44649 .18022 Mdot
.4049 .38115 Mdot
.52655 .35834 Mdot
.61527 .53104 Mdot
.39776 .39492 Mdot
.38956 .57223 Mdot
.59292 .58441 Mdot
.77901 .56823 Mdot
.52092 .34113 Mdot
.57085 .56718 Mdot
.45232 .24624 Mdot
.54236 .70887 Mdot
.76977 .64366 Mdot
.39302 .38257 Mdot
.48128 .69381 Mdot
.67289 .59415 Mdot
.59288 .38322 Mdot
.60906 .60124 Mdot
.59474 .72211 Mdot
.27764 .30136 Mdot
.48778 .67986 Mdot
.59795 .54685 Mdot
.65154 .5381 Mdot
.54614 .42929 Mdot
.45361 .70352 Mdot
.61977 .57844 Mdot
.56064 .40032 Mdot
.52378 .32354 Mdot
.38505 .59256 Mdot
.5158 .34362 Mdot
.60939 .55431 Mdot
.69264 .51455 Mdot
.54293 .3034 Mdot
.2165 .6685 Mdot
.42294 .67617 Mdot
.40396 .39538 Mdot
.57611 .50131 Mdot
.6572 .50696 Mdot
.77328 .27444 Mdot
.3182 .56681 Mdot
.29535 .51919 Mdot
.31057 .63597 Mdot
.45134 .78896 Mdot
.42335 .63132 Mdot
.74542 .70036 Mdot
.80418 .56546 Mdot
.58801 .57393 Mdot
.51921 .53296 Mdot
.4159 .23354 Mdot
.36205 .40021 Mdot
.38368 .20897 Mdot
.58231 .53543 Mdot
.60494 .52918 Mdot
.33574 .59707 Mdot
.26526 .54103 Mdot
.82753 .45524 Mdot
.47856 .34553 Mdot
.47554 .68943 Mdot
.56839 .35114 Mdot
.61175 .49342 Mdot
.45096 .49851 Mdot
.32157 .54076 Mdot
.46347 .63301 Mdot
.60118 .56281 Mdot
.59029 .24253 Mdot
.36673 .30931 Mdot
.39575 .41115 Mdot
.34371 .5553 Mdot
.8178 .49041 Mdot
.5845 .56425 Mdot
.39145 .43846 Mdot
.61966 .55701 Mdot
.42806 .61887 Mdot
.55017 .56527 Mdot
.47054 .66976 Mdot
.62627 .50184 Mdot
.41012 .6371 Mdot
.8608 .39899 Mdot
.49454 .70043 Mdot
.56945 .37305 Mdot
.31172 .55596 Mdot
.38012 .58068 Mdot
.54482 .30588 Mdot
.37459 .58427 Mdot
.70235 .36077 Mdot
.76254 .53656 Mdot
.46976 .68855 Mdot
.61188 .60949 Mdot
.46421 .6796 Mdot
.32302 .58414 Mdot
.58437 .52957 Mdot
.25699 .74204 Mdot
.35439 .59026 Mdot
.81903 .5445 Mdot
.38185 .40394 Mdot
.3184 .54505 Mdot
.6484 .51026 Mdot
.34822 .33676 Mdot
.38583 .54084 Mdot
.29151 .50442 Mdot
.63266 .57057 Mdot
.51826 .34996 Mdot
.64547 .51721 Mdot
.58641 .49396 Mdot
.3417 .52199 Mdot
.60019 .50897 Mdot
.40251 .4202 Mdot
.51477 .37513 Mdot
.61422 .80835 Mdot
.2956 .31443 Mdot
.61615 .57954 Mdot
.61415 .53345 Mdot
.55305 .28799 Mdot
.66918 .52195 Mdot
.37193 .36663 Mdot
.11295 .42689 Mdot
.46749 .687 Mdot
.34504 .51256 Mdot
.40063 .63797 Mdot
.6268 .48432 Mdot
.59452 .5056 Mdot
.41651 .85398 Mdot
.6275 .73557 Mdot
.40684 .40497 Mdot
.66008 .59236 Mdot
.39314 .56241 Mdot
.44296 .67854 Mdot
.35264 .38269 Mdot
.63133 .53805 Mdot
.59642 .53921 Mdot
.47786 .6996 Mdot
.51956 .64247 Mdot
.77657 .35134 Mdot
.40894 .42448 Mdot
.58979 .46912 Mdot
.39111 .61742 Mdot
.6539 .58213 Mdot
.71426 .28904 Mdot
.55394 .31305 Mdot
.36674 .37399 Mdot
.47313 .78365 Mdot
.58588 .5677 Mdot
.41013 .39958 Mdot
.36818 .41003 Mdot
.61553 .59856 Mdot
.49629 .34859 Mdot
.52028 .37778 Mdot
.52261 .32168 Mdot
.32182 .19607 Mdot
.58505 .70159 Mdot
.34689 .53845 Mdot
.36456 .40018 Mdot
.35528 .60017 Mdot
.49654 .70414 Mdot
.47645 .54975 Mdot
.34894 .59859 Mdot
.51453 .33385 Mdot
.3278 .52634 Mdot
.64809 .55518 Mdot
.37042 .41231 Mdot
.34793 .54406 Mdot
.59541 .48958 Mdot
.4695 .32561 Mdot
.22378 .47668 Mdot
.47915 .66168 Mdot
.43701 .70387 Mdot
.65617 .52129 Mdot
.38789 .59987 Mdot
.59056 .53878 Mdot
.37288 .43324 Mdot
.47548 .30102 Mdot
.58375 .49736 Mdot
.369 .58364 Mdot
.5453 .29013 Mdot
.81765 .48327 Mdot
.68718 .53942 Mdot
.60556 .55529 Mdot
.60668 .50975 Mdot
.62027 .55738 Mdot
.33591 .75733 Mdot
.41637 .39229 Mdot
.26045 .34342 Mdot
.47468 .76924 Mdot
.54463 .34418 Mdot
.57974 .31686 Mdot
.81837 .40076 Mdot
.4082 .24299 Mdot
.3674 .39868 Mdot
.62694 .51933 Mdot
.37106 .28886 Mdot
.49523 .8546 Mdot
.3085 .77062 Mdot
.61152 .4408 Mdot
.31699 .56627 Mdot
.50493 .35893 Mdot
.36933 .59304 Mdot
.60806 .51423 Mdot
.58108 .58836 Mdot
.78149 .66638 Mdot
.35569 .40844 Mdot
.47398 .68473 Mdot
.613 .50829 Mdot
.58078 .70507 Mdot
.34948 .56033 Mdot
.31861 .54347 Mdot
.66485 .55145 Mdot
.54894 .29338 Mdot
.84984 .39235 Mdot
.39679 .40192 Mdot
.25502 .37764 Mdot
.33727 .25283 Mdot
.39227 .32127 Mdot
.39202 .40945 Mdot
.55463 .43945 Mdot
.32385 .58044 Mdot
.77791 .40291 Mdot
.55134 .34135 Mdot
.44506 .66169 Mdot
.55975 .50715 Mdot
.55873 .30879 Mdot
.33986 .53448 Mdot
.51851 .35597 Mdot
.59313 .5049 Mdot
.4206 .42282 Mdot
.35799 .55684 Mdot
.31237 .38699 Mdot
.51066 .31446 Mdot
.45083 .701 Mdot
.46355 .39982 Mdot
.68403 .4617 Mdot
.71575 .40415 Mdot
.66457 .55747 Mdot
.45023 .50762 Mdot
.6465 .537 Mdot
.57798 .29914 Mdot
.61799 .54556 Mdot
.54076 .28185 Mdot
.35094 .54989 Mdot
.63602 .49822 Mdot
.63357 .52457 Mdot
.21593 .353 Mdot
.62015 .57504 Mdot
.65347 .58681 Mdot
.6258 .53567 Mdot
.58287 .28 Mdot
.6262 .6117 Mdot
.55234 .36698 Mdot
.28414 .63597 Mdot
.35724 .57449 Mdot
.43532 .66539 Mdot
.48431 .69372 Mdot
.62151 .70245 Mdot
.40496 .70013 Mdot
.25218 .54887 Mdot
.52298 .33014 Mdot
.39337 .43077 Mdot
.61976 .55052 Mdot
.70308 .74117 Mdot
.36145 .62681 Mdot
.32683 .53658 Mdot
.29671 .31507 Mdot
.55305 .49647 Mdot
.70144 .70812 Mdot
.65148 .59482 Mdot
.37702 .1822 Mdot
.66906 .49772 Mdot
.55368 .5083 Mdot
.39225 .57703 Mdot
.50283 .65186 Mdot
.66648 .52142 Mdot
.56373 .36837 Mdot
.45648 .66195 Mdot
.59812 .45741 Mdot
.40367 .52913 Mdot
.27813 .58833 Mdot
.5359 .27243 Mdot
.63809 .56155 Mdot
.35897 .55765 Mdot
.54986 .36149 Mdot
.82715 .41427 Mdot
.40014 .4067 Mdot
.38959 .49473 Mdot
.48277 .23545 Mdot
.22183 .66494 Mdot
.43892 .68774 Mdot
.73746 .34304 Mdot
.65238 .55972 Mdot
.31086 .70471 Mdot
.57751 .50145 Mdot
.43557 .84092 Mdot
.47706 .70745 Mdot
.51159 .33892 Mdot
.40537 .42103 Mdot
.57526 .34381 Mdot
.70246 .39518 Mdot
.40913 .55218 Mdot
.47543 .4745 Mdot
.34488 .57047 Mdot
.49889 .52335 Mdot
.54406 .32036 Mdot
.57858 .52214 Mdot
.53815 .14076 Mdot
.54986 .30984 Mdot
.5115 .31773 Mdot
.17849 .46602 Mdot
.2301 .70823 Mdot
.63893 .47811 Mdot
.50859 .33087 Mdot
.34732 .57572 Mdot
.45806 .66731 Mdot
.63654 .50468 Mdot
.64182 .56333 Mdot
.56052 .3121 Mdot
.35099 .51763 Mdot
.64004 .39958 Mdot
.37724 .56765 Mdot
.51274 .34467 Mdot
.36736 .56914 Mdot
.39292 .34563 Mdot
.33312 .57345 Mdot
.65775 .50708 Mdot
.61854 .54686 Mdot
.36939 .65794 Mdot
.52227 .35136 Mdot
.63558 .52999 Mdot
.59132 .58731 Mdot
.53645 .33555 Mdot
.53144 .47137 Mdot
.6495 .39867 Mdot
.62829 .58503 Mdot
.62854 .57421 Mdot
.48558 .68707 Mdot
.46837 .53024 Mdot
.72543 .31907 Mdot
.60214 .50271 Mdot
.49072 .68648 Mdot
.55508 .37142 Mdot
.59022 .55121 Mdot
.49174 .83276 Mdot
.28193 .45011 Mdot
.57868 .53559 Mdot
.3722 .5938 Mdot
.67128 .58587 Mdot
.77757 .62894 Mdot
.66798 .53445 Mdot
.53461 .32892 Mdot
.53446 .35975 Mdot
.265 .28855 Mdot
.55052 .32692 Mdot
.36994 .52908 Mdot
.3886 .41009 Mdot
.3318 .76453 Mdot
.38481 .58188 Mdot
.68617 .51928 Mdot
.1769 .38291 Mdot
.5756 .56675 Mdot
.63086 .48883 Mdot
.83937 .50882 Mdot
.36296 .59306 Mdot
.56348 .34691 Mdot
.47529 .40367 Mdot
.67695 .49626 Mdot
.36757 .37597 Mdot
.55235 .55272 Mdot
.66954 .54433 Mdot
.78968 .60017 Mdot
.34338 .75784 Mdot
.39154 .44051 Mdot
.65434 .58562 Mdot
.59899 .50364 Mdot
.34248 .60896 Mdot
.618 .53507 Mdot
.46261 .66779 Mdot
.55322 .34973 Mdot
.33557 .58242 Mdot
.45133 .68808 Mdot
.58177 .55699 Mdot
.47878 .689 Mdot
.35838 .54204 Mdot
.36754 .42663 Mdot
.59718 .51882 Mdot
.46486 .64836 Mdot
.47682 .69013 Mdot
.64414 .53696 Mdot
.52027 .36314 Mdot
.55007 .49436 Mdot
.61626 .57458 Mdot
.61704 .49778 Mdot
.56453 .32473 Mdot
.60198 .86146 Mdot
.66272 .52899 Mdot
.60203 .72615 Mdot
.55883 .30417 Mdot
.50767 .5063 Mdot
.38612 .58597 Mdot
.67146 .53505 Mdot
.36743 .42689 Mdot
.3755 .43072 Mdot
.32616 .54775 Mdot
.50204 .35315 Mdot
.31982 .63608 Mdot
.49994 .37411 Mdot
.69327 .56874 Mdot
.6636 .57914 Mdot
.58258 .41048 Mdot
.68188 .76287 Mdot
.57529 .32958 Mdot
.41657 .5497 Mdot
.47523 .33454 Mdot
.39182 .43477 Mdot
.34355 .52371 Mdot
.51122 .37545 Mdot
.56839 .33096 Mdot
.51993 .36904 Mdot
.44588 .65997 Mdot
.37302 .6607 Mdot
.56209 .30141 Mdot
.5583 .29379 Mdot
.6393 .56903 Mdot
.60774 .50202 Mdot
.80522 .52701 Mdot
.79177 .5177 Mdot
.48262 .67418 Mdot
.35478 .53312 Mdot
.29821 .2004 Mdot
.36122 .41965 Mdot
.23241 .35667 Mdot
.62691 .49023 Mdot
.35456 .14994 Mdot
.64382 .50821 Mdot
.61732 .52963 Mdot
.51609 .37702 Mdot
.46736 .65045 Mdot
.46533 .68296 Mdot
.54567 .31212 Mdot
.57143 .29869 Mdot
.46418 .66902 Mdot
.20044 .55796 Mdot
.51305 .84133 Mdot
.29477 .54396 Mdot
.53409 .34185 Mdot
.73962 .51442 Mdot
.41231 .41374 Mdot
.66387 .47411 Mdot
.40729 .43856 Mdot
.35039 .56676 Mdot
.32694 .57949 Mdot
.37248 .37368 Mdot
.62947 .56984 Mdot
.34191 .5429 Mdot
.58035 .56547 Mdot
.21702 .44108 Mdot
.71423 .43024 Mdot
.35913 .63602 Mdot
.71084 .51506 Mdot
.53528 .4628 Mdot
.31138 .39128 Mdot
.58419 .55273 Mdot
.47016 .80943 Mdot
.47357 .68811 Mdot
.69969 .56371 Mdot
.36307 .37728 Mdot
.83902 .5315 Mdot
.5896 .52283 Mdot
.53116 .3318 Mdot
.36621 .4075 Mdot
.50156 .22126 Mdot
.47321 .26213 Mdot
.60968 .50952 Mdot
.47557 .1482 Mdot
.59527 .30587 Mdot
.33736 .56042 Mdot
.57613 .23625 Mdot
.57456 .31219 Mdot
.41821 .64616 Mdot
.49986 .78629 Mdot
.26087 .7123 Mdot
.55884 .3532 Mdot
.32342 .58942 Mdot
.54246 .37264 Mdot
.44465 .69483 Mdot
.57126 .36957 Mdot
.3513 .55491 Mdot
.59982 .55918 Mdot
.37762 .57656 Mdot
.45119 .65644 Mdot
.77971 .36287 Mdot
.39171 .44034 Mdot
.37898 .52705 Mdot
.3841 .3837 Mdot
.52167 .72131 Mdot
.57354 .76463 Mdot
.40108 .38989 Mdot
.6405 .34529 Mdot
.66716 .57426 Mdot
.57023 .30614 Mdot
.38428 .56919 Mdot
.41543 .75571 Mdot
.46563 .38962 Mdot
.55336 .33736 Mdot
.34296 .53542 Mdot
.49139 .26166 Mdot
.61418 .32107 Mdot
.65819 .58557 Mdot
.52919 .63172 Mdot
.53752 .33953 Mdot
.32881 .59328 Mdot
.78429 .33126 Mdot
.54727 .37133 Mdot
.39145 .56095 Mdot
.40911 .4115 Mdot
.38046 .41978 Mdot
.64793 .57798 Mdot
.42074 .38668 Mdot
.32973 .55137 Mdot
.34663 .43888 Mdot
.50681 .33432 Mdot
.52655 .22265 Mdot
.44912 .64714 Mdot
.365 .5764 Mdot
.56842 .55166 Mdot
.58337 .2995 Mdot
.28006 .40317 Mdot
.65426 .41329 Mdot
.5775 .17856 Mdot
.38049 .57085 Mdot
.55795 .34458 Mdot
.5282 .33469 Mdot
.68865 .53972 Mdot
.50792 .25834 Mdot
.32089 .64145 Mdot
.56749 .42805 Mdot
.52967 .4185 Mdot
.38729 .59165 Mdot
.35261 .49979 Mdot
.55487 .54977 Mdot
.63213 .56108 Mdot
.39571 .4332 Mdot
.6032 .56059 Mdot
.50694 .35458 Mdot
.66392 .55707 Mdot
.39468 .38961 Mdot
.34133 .57136 Mdot
.59358 .5221 Mdot
.47636 .69355 Mdot
.4119 .38596 Mdot
.35163 .40847 Mdot
.36457 .581 Mdot
.5614 .31209 Mdot
.50637 .52886 Mdot
.37781 .55991 Mdot
.63731 .56237 Mdot
.46266 .54993 Mdot
.5904 .50477 Mdot
.5314 .5755 Mdot
.55745 .3677 Mdot
.33692 .58385 Mdot
.52247 .38331 Mdot
.38357 .39106 Mdot
.47666 .77109 Mdot
.61123 .55028 Mdot
.39067 .56694 Mdot
.30936 .42628 Mdot
.52584 .5801 Mdot
.5199 .30235 Mdot
.21987 .53717 Mdot
.58108 .3141 Mdot
.3604 .53322 Mdot
.19386 .39117 Mdot
.43914 .67092 Mdot
.32449 .53872 Mdot
.63903 .79139 Mdot
.35697 .58831 Mdot
.65391 .57189 Mdot
.65771 .52529 Mdot
.33383 .57561 Mdot
.48212 .69416 Mdot
.83531 .4508 Mdot
.31902 .52075 Mdot
.56063 .34943 Mdot
.19669 .47855 Mdot
.65977 .21175 Mdot
.32202 .38188 Mdot
.39397 .43262 Mdot
.64623 .47804 Mdot
.67427 .5555 Mdot
.35836 .38405 Mdot
.38954 .44383 Mdot
.43277 .68024 Mdot
.38566 .55382 Mdot
.58289 .29359 Mdot
.34436 .38839 Mdot
.52629 .26469 Mdot
.3972 .68357 Mdot
.68647 .54106 Mdot
.32749 .26299 Mdot
.62392 .49119 Mdot
.53898 .76385 Mdot
.39406 .38626 Mdot
.57465 .51652 Mdot
.66394 .58595 Mdot
.35946 .40369 Mdot
.45753 .666 Mdot
.38883 .49656 Mdot
.36526 .56542 Mdot
.61153 .84781 Mdot
.59296 .58061 Mdot
.66023 .56017 Mdot
.36658 .38858 Mdot
.32331 .68898 Mdot
.54517 .34718 Mdot
.58142 .3331 Mdot
.33267 .56429 Mdot
.45059 .41729 Mdot
.66263 .57141 Mdot
.5901 .55685 Mdot
.36436 .55763 Mdot
.36494 .52419 Mdot
.24828 .52708 Mdot
.65401 .54012 Mdot
.37264 .39985 Mdot
.51053 .67942 Mdot
.39101 .38082 Mdot
.58389 .5093 Mdot
.65969 .55643 Mdot
.65777 .50653 Mdot
.56948 .53994 Mdot
.41161 .43913 Mdot
.58764 .50101 Mdot
.60839 .60514 Mdot
.55683 .34208 Mdot
.61281 .50517 Mdot
.51384 .4126 Mdot
.61063 .56311 Mdot
.46049 .66797 Mdot
.69469 .29458 Mdot
.59042 .52235 Mdot
.66688 .55184 Mdot
.33622 .51693 Mdot
.60138 .54222 Mdot
.36908 .43068 Mdot
.52882 .34959 Mdot
.36611 .39598 Mdot
.37695 .43202 Mdot
.35491 .60453 Mdot
.46031 .71015 Mdot
.62329 .48298 Mdot
.46788 .65997 Mdot
.69205 .52502 Mdot
.58665 .56872 Mdot
.42081 .71992 Mdot
.35574 .18929 Mdot
.74998 .31806 Mdot
.61213 .55239 Mdot
.35863 .59226 Mdot
.36828 .59391 Mdot
.52342 .50924 Mdot
.63925 .59123 Mdot
.358 .3696 Mdot
.38855 .43589 Mdot
.76107 .59184 Mdot
.70054 .67515 Mdot
.46 .66741 Mdot
.46821 .51205 Mdot
.61477 .58673 Mdot
.57424 .52058 Mdot
.58851 .58046 Mdot
.34544 .59801 Mdot
.67057 .46337 Mdot
.33565 .52897 Mdot
.33494 .31528 Mdot
.37432 .37759 Mdot
.59948 .51455 Mdot
.30693 .28866 Mdot
.52874 .31172 Mdot
.52783 .34955 Mdot
.3491 .39786 Mdot
.39347 .60899 Mdot
.81378 .47579 Mdot
.31163 .77931 Mdot
.58382 .36355 Mdot
.45841 .651 Mdot
.58964 .56238 Mdot
.34399 .57981 Mdot
.51121 .34862 Mdot
.45897 .65158 Mdot
.58246 .52038 Mdot
.37482 .66124 Mdot
.61672 .55893 Mdot
.3868 .24434 Mdot
.5322 .36843 Mdot
.46556 .85105 Mdot
.50095 .35012 Mdot
.40797 .3769 Mdot
.36748 .37024 Mdot
.65831 .54138 Mdot
.59221 .3712 Mdot
.57708 .31299 Mdot
.43423 .56836 Mdot
.45261 .70603 Mdot
.32977 .34607 Mdot
.44125 .67598 Mdot
.34239 .55401 Mdot
.44749 .66381 Mdot
.35206 .55264 Mdot
.80913 .46186 Mdot
.5755 .26987 Mdot
.45897 .68986 Mdot
.30821 .41499 Mdot
.67498 .54972 Mdot
.48352 .67266 Mdot
.58325 .58923 Mdot
.52709 .54983 Mdot
.36713 .55824 Mdot
.44978 .70279 Mdot
.57487 .52863 Mdot
.74044 .69376 Mdot
.40568 .39829 Mdot
.36026 .3696 Mdot
.58399 .58927 Mdot
.38052 .59831 Mdot
.54481 .37742 Mdot
.40621 .80982 Mdot
.34842 .36504 Mdot
.66159 .53319 Mdot
.66769 .52167 Mdot
.57808 .31041 Mdot
.26493 .30976 Mdot
.65707 .55073 Mdot
.60558 .61982 Mdot
.65564 .53801 Mdot
.39676 .37569 Mdot
.57317 .34657 Mdot
.52667 .34158 Mdot
.34266 .53668 Mdot
.52606 .31001 Mdot
.51814 .61434 Mdot
.32636 .29425 Mdot
.5437 .55275 Mdot
.38699 .39474 Mdot
.35953 .30536 Mdot
.32508 .31694 Mdot
.64526 .77635 Mdot
.5085 .3159 Mdot
.58582 .49725 Mdot
.52881 .30579 Mdot
.44454 .67413 Mdot
.51896 .34656 Mdot
.50509 .35926 Mdot
.58775 .53964 Mdot
.61326 .51187 Mdot
.33889 .56656 Mdot
.49814 .26751 Mdot
.56177 .30867 Mdot
.64331 .5087 Mdot
.67429 .52276 Mdot
.57499 .56018 Mdot
.44539 .57968 Mdot
.57485 .33713 Mdot
.17223 .53714 Mdot
.63844 .66234 Mdot
.56218 .30969 Mdot
.85464 .42059 Mdot
.29977 .41886 Mdot
.40548 .54655 Mdot
.4145 .52179 Mdot
.65469 .5341 Mdot
.38572 .53781 Mdot
.6072 .51457 Mdot
.32875 .26345 Mdot
.59969 .53527 Mdot
.46308 .66678 Mdot
.5879 .57396 Mdot
.32309 .56896 Mdot
.37846 .56764 Mdot
.66394 .53821 Mdot
.59686 .52161 Mdot
.79718 .38407 Mdot
.55996 .38117 Mdot
.52673 .35543 Mdot
.31453 .62804 Mdot
.45801 .6949 Mdot
.36754 .37437 Mdot
.62243 .53992 Mdot
.35258 .60319 Mdot
.37864 .57009 Mdot
.57666 .32149 Mdot
.36656 .54132 Mdot
.39627 .40379 Mdot
.61253 .54663 Mdot
.35851 .37895 Mdot
.44 .66376 Mdot
.57312 .34429 Mdot
.61154 .50683 Mdot
.63897 .56936 Mdot
.53486 .3597 Mdot
.58052 .49485 Mdot
.48045 .69407 Mdot
.3632 .58804 Mdot
.55847 .355 Mdot
.38608 .41369 Mdot
.34464 .55317 Mdot
.61314 .49634 Mdot
.43819 .16153 Mdot
.64579 .57539 Mdot
.64976 .52383 Mdot
.67485 .77956 Mdot
.60892 .58559 Mdot
.3826 .56916 Mdot
.51062 .34504 Mdot
.70025 .57944 Mdot
.61262 .68874 Mdot
.54779 .89199 Mdot
.33189 .53238 Mdot
.59596 .56689 Mdot
.68023 .74672 Mdot
.59947 .56654 Mdot
.66672 .43983 Mdot
.38204 .5255 Mdot
.51652 .45215 Mdot
.56571 .53615 Mdot
.39098 .42376 Mdot
.33686 .57416 Mdot
.35457 .54917 Mdot
.20557 .44529 Mdot
.58668 .54604 Mdot
.43879 .51718 Mdot
.58614 .51333 Mdot
.38731 .41633 Mdot
.72007 .63393 Mdot
.37996 .56661 Mdot
.62112 .20895 Mdot
.6478 .53839 Mdot
.57059 .32891 Mdot
.32341 .53097 Mdot
.39684 .34185 Mdot
.62173 .49791 Mdot
.4776 .67225 Mdot
.36613 .43756 Mdot
.5524 .566 Mdot
.3894 .39739 Mdot
.61399 .4984 Mdot
.71756 .56652 Mdot
.51044 .19826 Mdot
.5195 .36577 Mdot
.40506 .42264 Mdot
.46522 .56669 Mdot
.58315 .50143 Mdot
.5575 .35433 Mdot
.55282 .34019 Mdot
.44303 .66025 Mdot
.49345 .49357 Mdot
.45738 .24174 Mdot
.7324 .46995 Mdot
.19973 .46227 Mdot
.33289 .52351 Mdot
.28366 .52557 Mdot
.64174 .5207 Mdot
.50705 .61793 Mdot
.37432 .43347 Mdot
.64267 .57726 Mdot
.73383 .34675 Mdot
.53698 .30962 Mdot
.6433 .57352 Mdot
.46474 .67823 Mdot
.45963 .62309 Mdot
.51332 .66779 Mdot
.54881 .79445 Mdot
.34617 .56959 Mdot
.61714 .60663 Mdot
.6971 .5933 Mdot
.38687 .58733 Mdot
.66539 .50667 Mdot
.38667 .57358 Mdot
.20795 .60181 Mdot
.47977 .66339 Mdot
.57174 .34 Mdot
.31652 .36362 Mdot
.64287 .48934 Mdot
.67036 .55903 Mdot
.4509 .70884 Mdot
.63445 .5576 Mdot
.46792 .18206 Mdot
.44533 .58595 Mdot
.34365 .54625 Mdot
.51961 .36814 Mdot
.66728 .51296 Mdot
.47918 .55143 Mdot
.60788 .56987 Mdot
.77192 .47027 Mdot
.66745 .54898 Mdot
.47978 .25298 Mdot
.52645 .36647 Mdot
.38927 .3903 Mdot
.57303 .51235 Mdot
.60623 .53204 Mdot
.65613 .70374 Mdot
.67842 .50578 Mdot
.57643 .51031 Mdot
.49197 .33601 Mdot
.51304 .3648 Mdot
.54441 .37071 Mdot
.32827 .54149 Mdot
.74098 .64728 Mdot
.37726 .39662 Mdot
.70974 .55247 Mdot
.35193 .36668 Mdot
.61666 .40751 Mdot
.46519 .65273 Mdot
.61058 .77106 Mdot
.62992 .52938 Mdot
.5214 .32893 Mdot
.40637 .78955 Mdot
.57737 .35404 Mdot
.45962 .49915 Mdot
.36891 .41169 Mdot
.54879 .31131 Mdot
.61311 .52926 Mdot
.46924 .36016 Mdot
.70156 .73395 Mdot
.37575 .38902 Mdot
.68562 .52037 Mdot
.31957 .55471 Mdot
.39613 .63452 Mdot
.55021 .19371 Mdot
.40545 .39478 Mdot
.35245 .35115 Mdot
.58582 .5487 Mdot
.52176 .31713 Mdot
.39126 .42049 Mdot
.395 .37562 Mdot
.36288 .53913 Mdot
.6165 .51078 Mdot
.62144 .51064 Mdot
.35602 .5313 Mdot
.36636 .39354 Mdot
.61051 .60267 Mdot
.55128 .57064 Mdot
.81439 .61829 Mdot
.50005 .24253 Mdot
.61965 .84948 Mdot
.51653 .52861 Mdot
.69692 .32001 Mdot
.40716 .81433 Mdot
.56724 .31557 Mdot
.57799 .5467 Mdot
.56017 .50042 Mdot
.32946 .55118 Mdot
.60253 .55087 Mdot
.40124 .55423 Mdot
.367 .41904 Mdot
.83607 .53268 Mdot
.41274 .29888 Mdot
.23111 .65844 Mdot
.60046 .54959 Mdot
.52284 .29345 Mdot
.44796 .67698 Mdot
.33472 .36002 Mdot
.56739 .35781 Mdot
.57167 .56322 Mdot
.79387 .37958 Mdot
.32709 .53565 Mdot
.55857 .32513 Mdot
.8268 .41974 Mdot
.54604 .44477 Mdot
.5899 .50567 Mdot
.33965 .53032 Mdot
.44974 .81437 Mdot
.57589 .25416 Mdot
.36421 .35834 Mdot
.45725 .66515 Mdot
.33754 .58165 Mdot
.39186 .43671 Mdot
.56671 .27932 Mdot
.55225 .32014 Mdot
.56095 .37161 Mdot
.73798 .3158 Mdot
.36019 .51351 Mdot
.44899 .68016 Mdot
.6905 .70412 Mdot
.68176 .6883 Mdot
.46656 .67027 Mdot
.3264 .57922 Mdot
.51135 .35971 Mdot
.53988 .31271 Mdot
.52942 .34919 Mdot
.69398 .26118 Mdot
.52351 .30662 Mdot
.20471 .40216 Mdot
.57163 .55174 Mdot
.55867 .59055 Mdot
.59427 .56438 Mdot
.35551 .37362 Mdot
.53948 .36173 Mdot
.46712 .40674 Mdot
.69647 .54561 Mdot
.614 .75595 Mdot
.6514 .57525 Mdot
.41959 .40629 Mdot
.64776 .56735 Mdot
.33203 .24031 Mdot
.53783 .30196 Mdot
.60841 .55166 Mdot
.41251 .42913 Mdot
.45749 .69778 Mdot
.51784 .30338 Mdot
.60721 .50961 Mdot
.23353 .57524 Mdot
.60018 .5818 Mdot
.23227 .64638 Mdot
.47345 .21299 Mdot
.46014 .65127 Mdot
.38285 .22545 Mdot
.31852 .58525 Mdot
.585 .61132 Mdot
.68795 .50432 Mdot
.38075 .38611 Mdot
.32943 .3504 Mdot
.35495 .57513 Mdot
.62721 .44479 Mdot
.58242 .59912 Mdot
.44188 .65936 Mdot
.58823 .27434 Mdot
.35675 .39063 Mdot
.66951 .51274 Mdot
.67093 .58011 Mdot
.25077 .36915 Mdot
.58235 .59358 Mdot
.67025 .53109 Mdot
.45236 .71286 Mdot
.22153 .37666 Mdot
.61586 .56568 Mdot
.46458 .5038 Mdot
.56944 .37134 Mdot
.69745 .56016 Mdot
.2079 .38944 Mdot
.65642 .52213 Mdot
.55744 .31705 Mdot
.57357 .61219 Mdot
.44112 .23574 Mdot
.46311 .71037 Mdot
.66759 .55011 Mdot
.25496 .30015 Mdot
.64514 .54798 Mdot
.37612 .40178 Mdot
.64277 .58981 Mdot
.35087 .55769 Mdot
.75038 .31158 Mdot
.33808 .54202 Mdot
.64459 .58263 Mdot
.53219 .34687 Mdot
.36986 .38304 Mdot
.65088 .24405 Mdot
.34626 .66345 Mdot
.24374 .35012 Mdot
.31883 .7737 Mdot
.45918 .70695 Mdot
.47886 .64696 Mdot
.35737 .4086 Mdot
.60936 .55375 Mdot
.17565 .43892 Mdot
.66191 .49023 Mdot
.63183 .57435 Mdot
.59961 .53398 Mdot
.56623 .76485 Mdot
.37296 .42783 Mdot
.37224 .5604 Mdot
.6582 .55371 Mdot
.58245 .50422 Mdot
.56819 .32039 Mdot
.46665 .69533 Mdot
.385 .58681 Mdot
.46976 .68716 Mdot
.33923 .5778 Mdot
.84651 .47823 Mdot
.63464 .59976 Mdot
.45296 .69778 Mdot
.35163 .41757 Mdot
.56287 .31828 Mdot
.3352 .29204 Mdot
.349 .54945 Mdot
.33089 .54233 Mdot
.66618 .54062 Mdot
.55581 .3123 Mdot
.51796 .37998 Mdot
.44174 .68227 Mdot
.40045 .39501 Mdot
.58978 .52326 Mdot
.59757 .57694 Mdot
.70445 .60384 Mdot
.3732 .60356 Mdot
.37666 .24639 Mdot
.26706 .55626 Mdot
.61207 .5545 Mdot
.50702 .33532 Mdot
.59567 .52641 Mdot
.29564 .7143 Mdot
.52561 .31241 Mdot
.65271 .51676 Mdot
.83451 .37402 Mdot
.4111 .57975 Mdot
.408 .26131 Mdot
.66298 .51694 Mdot
.40003 .83117 Mdot
.63742 .52447 Mdot
.84372 .53281 Mdot
.38611 .75928 Mdot
.65773 .58041 Mdot
.6259 .49687 Mdot
.68633 .41448 Mdot
.5944 .57018 Mdot
.35008 .53125 Mdot
.80901 .54763 Mdot
.5695 .36562 Mdot
.31717 .33295 Mdot
.70397 .30614 Mdot
.47224 .70863 Mdot
.33273 .56453 Mdot
.36463 .50447 Mdot
.47142 .67731 Mdot
.53363 .3394 Mdot
.62046 .55731 Mdot
.44672 .45214 Mdot
.37404 .60021 Mdot
.57209 .458 Mdot
.37527 .40421 Mdot
.26683 .45371 Mdot
.47817 .61571 Mdot
.39183 .40046 Mdot
.61617 .50439 Mdot
.66981 .40845 Mdot
.79716 .4511 Mdot
.55459 .83943 Mdot
.39881 .43446 Mdot
.37499 .38701 Mdot
.72342 .28282 Mdot
.43369 .65881 Mdot
.25161 .37582 Mdot
.47765 .25797 Mdot
.36798 .37835 Mdot
.59999 .29819 Mdot
.36119 .52726 Mdot
.43149 .4058 Mdot
.67789 .593 Mdot
.5776 .55788 Mdot
.61116 .53047 Mdot
.39714 .38539 Mdot
.52101 .56794 Mdot
.56037 .22071 Mdot
.38374 .3816 Mdot
.61961 .46504 Mdot
.4961 .45532 Mdot
.33135 .47986 Mdot
.37502 .54642 Mdot
.44611 .70321 Mdot
.44596 .64384 Mdot
.56756 .33735 Mdot
.45235 .7072 Mdot
.48865 .62564 Mdot
.63015 .55225 Mdot
.38468 .3767 Mdot
.29363 .3773 Mdot
.38046 .41623 Mdot
.46984 .68084 Mdot
.43116 .67314 Mdot
.55599 .34252 Mdot
.5222 .35429 Mdot
.68343 .34362 Mdot
.56013 .64739 Mdot
.62106 .57782 Mdot
.43092 .75098 Mdot
.50735 .36636 Mdot
.55008 .46688 Mdot
.44717 .70475 Mdot
.45955 .69649 Mdot
.64311 .71398 Mdot
.62649 .52797 Mdot
.58679 .41707 Mdot
.62452 .53253 Mdot
.67551 .64694 Mdot
.63477 .49403 Mdot
.36379 .53939 Mdot
.62823 .52015 Mdot
.64336 .72111 Mdot
.60184 .48173 Mdot
.67781 .55522 Mdot
.34835 .60041 Mdot
.56446 .58814 Mdot
.35225 .55886 Mdot
.63448 .58296 Mdot
.47467 .6512 Mdot
.33069 .56249 Mdot
.59737 .69886 Mdot
.61934 .72476 Mdot
.3264 .58202 Mdot
.46049 .6559 Mdot
.48644 .69551 Mdot
.56548 .72336 Mdot
.56807 .35723 Mdot
.65546 .47677 Mdot
.60673 .55383 Mdot
.35186 .52134 Mdot
.3861 .4336 Mdot
.62146 .49421 Mdot
.67411 .53756 Mdot
.65143 .5068 Mdot
.56873 .3359 Mdot
.32603 .6445 Mdot
.44921 .69756 Mdot
.35666 .5298 Mdot
.50385 .53617 Mdot
.38658 .59391 Mdot
.67905 .57181 Mdot
.56402 .49722 Mdot
.71936 .326 Mdot
.32674 .4631 Mdot
.68925 .25077 Mdot
.55316 .32164 Mdot
.369 .59483 Mdot
.45375 .64578 Mdot
.57526 .48793 Mdot
.52041 .3282 Mdot
.35161 .55537 Mdot
.61652 .55809 Mdot
.67893 .51301 Mdot
.31283 .31376 Mdot
.51992 .66842 Mdot
.61068 .7165 Mdot
.3248 .55024 Mdot
.31635 .56678 Mdot
.60502 .7408 Mdot
.5032 .66475 Mdot
.46542 .39426 Mdot
.59261 .55297 Mdot
.47736 .67351 Mdot
.51202 .34429 Mdot
.75187 .34126 Mdot
.3808 .36909 Mdot
.50613 .26096 Mdot
.60172 .54862 Mdot
.5276 .46248 Mdot
.53419 .34719 Mdot
.4644 .67539 Mdot
.39527 .38179 Mdot
.44597 .63632 Mdot
.35735 .59874 Mdot
.2462 .70637 Mdot
.64193 .55391 Mdot
.66634 .5451 Mdot
.41592 .40669 Mdot
.52792 .31601 Mdot
.48256 .70756 Mdot
.19856 .48995 Mdot
.35863 .54428 Mdot
.17842 .42144 Mdot
.50879 .33312 Mdot
.73452 .50717 Mdot
.37343 .53739 Mdot
.34636 .38469 Mdot
.57401 .70987 Mdot
.39542 .3977 Mdot
.65258 .57854 Mdot
.52534 .33068 Mdot
.40091 .42604 Mdot
.51966 .24289 Mdot
.71137 .74068 Mdot
.73546 .50499 Mdot
.62572 .54916 Mdot
.7747 .65919 Mdot
.22481 .60777 Mdot
.58162 .36869 Mdot
.38377 .43729 Mdot
.64458 .5775 Mdot
.66901 .55454 Mdot
.64577 .55006 Mdot
.38615 .43037 Mdot
.43441 .7485 Mdot
.36606 .55501 Mdot
.58751 .55631 Mdot
.43279 .67775 Mdot
.35288 .5657 Mdot
.37104 .34588 Mdot
.37718 .55256 Mdot
.49581 .34172 Mdot
.68649 .55643 Mdot
.38411 .33292 Mdot
.84499 .344 Mdot
.37029 .39122 Mdot
.34708 .60279 Mdot
.62117 .59794 Mdot
.28781 .44211 Mdot
.52954 .37552 Mdot
.35737 .54231 Mdot
.65981 .56247 Mdot
.30726 .40417 Mdot
.77078 .34748 Mdot
.37938 .55906 Mdot
.51913 .3288 Mdot
.56256 .83495 Mdot
.60181 .55639 Mdot
.63885 .53387 Mdot
.5478 .31532 Mdot
.62246 .34576 Mdot
.79667 .35461 Mdot
.59672 .52318 Mdot
.38977 .38872 Mdot
.18512 .63282 Mdot
.67448 .53947 Mdot
.69127 .64983 Mdot
.33717 .56993 Mdot
.44108 .38143 Mdot
.42254 .2311 Mdot
.59093 .48048 Mdot
.22461 .4285 Mdot
.31724 .37619 Mdot
.73023 .68423 Mdot
.40322 .56274 Mdot
.28105 .64456 Mdot
.76624 .64405 Mdot
.41618 .42796 Mdot
.50231 .30496 Mdot
.21309 .45537 Mdot
.62331 .25688 Mdot
.49313 .8272 Mdot
.32016 .70323 Mdot
.79386 .37754 Mdot
.46021 .44569 Mdot
.34991 .5886 Mdot
.54704 .46279 Mdot
.60598 .51311 Mdot
.22832 .61463 Mdot
.50898 .20726 Mdot
.52886 .21112 Mdot
.7752 .66036 Mdot
.68766 .45257 Mdot
.68524 .74306 Mdot
.65435 .77771 Mdot
.714 .61665 Mdot
.27871 .54684 Mdot
.17266 .4311 Mdot
.82597 .49223 Mdot
.18476 .52494 Mdot
.55258 .58321 Mdot
.45115 .49903 Mdot
.26327 .69826 Mdot
.55326 .2716 Mdot
.61188 .31176 Mdot
.34653 .53693 Mdot
.56486 .36418 Mdot
.24288 .39699 Mdot
.57981 .30971 Mdot
.43938 .23342 Mdot
.58635 .83565 Mdot
.70383 .74613 Mdot
.26692 .29811 Mdot
.41075 .82648 Mdot
.72429 .34173 Mdot
.14907 .40283 Mdot
.39761 .56354 Mdot
.57456 .31802 Mdot
.55308 .75968 Mdot
.66365 .71766 Mdot
.38372 .31649 Mdot
.20831 .51887 Mdot
.39475 .65828 Mdot
.53316 .69685 Mdot
.53058 .33395 Mdot
.39428 .22477 Mdot
.42453 .37961 Mdot
.40578 .30353 Mdot
.8156 .51615 Mdot
.56822 .81668 Mdot
.43635 .45965 Mdot
.22192 .50233 Mdot
.2784 .47694 Mdot
.58558 .21938 Mdot
.61846 .67146 Mdot
.53801 .47637 Mdot
.49197 .24327 Mdot
.3779 .79629 Mdot
.63862 .29764 Mdot
.67226 .64426 Mdot
.67586 .70844 Mdot
.84331 .45521 Mdot
.26237 .66184 Mdot
.71044 .22437 Mdot
.58515 .31479 Mdot
.66789 .52011 Mdot
.63509 .35698 Mdot
.23152 .3233 Mdot
.4307 .69748 Mdot
.53035 .79926 Mdot
.43897 .69275 Mdot
.4978 .35304 Mdot
.77564 .33877 Mdot
.21572 .37965 Mdot
.1944 .36315 Mdot
.47568 .64836 Mdot
.71056 .55654 Mdot
.38435 .86155 Mdot
.67613 .73148 Mdot
.40005 .28286 Mdot
.81636 .60666 Mdot
.50816 .43613 Mdot
.51878 .22182 Mdot
.39821 .4292 Mdot
.78505 .62222 Mdot
.53617 .31821 Mdot
.71081 .2121 Mdot
.84828 .52005 Mdot
.7523 .35485 Mdot
.87924 .64169 Mdot
.5854 .75352 Mdot
.51992 .4532 Mdot
.33342 .41619 Mdot
.57748 .67637 Mdot
.57987 .23256 Mdot
.48139 .75918 Mdot
.28614 .4519 Mdot
.38726 .83372 Mdot
.76037 .6631 Mdot
.18232 .38938 Mdot
.2113 .64781 Mdot
.62321 .27497 Mdot
.47941 .54507 Mdot
.70006 .50328 Mdot
.39443 .62739 Mdot
.51183 .80871 Mdot
.84938 .44598 Mdot
.64111 .66336 Mdot
.53965 .89415 Mdot
.4942 .702 Mdot
.38505 .68693 Mdot
.63185 .82543 Mdot
.54171 .70443 Mdot
.43226 .21691 Mdot
.73424 .63997 Mdot
.68111 .47597 Mdot
.50205 .57543 Mdot
.528 .80476 Mdot
.37048 .26742 Mdot
.80116 .57547 Mdot
.4449 .82676 Mdot
.25318 .36581 Mdot
.72831 .44366 Mdot
.69025 .67098 Mdot
.56558 .28622 Mdot
.53472 .64658 Mdot
.43474 .22495 Mdot
.73372 .726 Mdot
.42327 .40762 Mdot
.75787 .71531 Mdot
.80063 .36325 Mdot
.62777 .60206 Mdot
.63196 .47079 Mdot
.56855 .42264 Mdot
.53887 .65553 Mdot
.58381 .60436 Mdot
.29556 .32569 Mdot
.69493 .76053 Mdot
.78801 .46227 Mdot
.30912 .38666 Mdot
.32424 .35416 Mdot
.62589 .83334 Mdot
.65674 .37058 Mdot
.49982 .66291 Mdot
.79353 .55313 Mdot
.58931 .23059 Mdot
.36059 .57271 Mdot
.18853 .38632 Mdot
.33915 .38451 Mdot
.76515 .34877 Mdot
.72846 .46828 Mdot
.66667 .28797 Mdot
.69541 .76086 Mdot
.28268 .63337 Mdot
.78936 .35816 Mdot
.52038 .73246 Mdot
.17405 .48368 Mdot
.33226 .47598 Mdot
.55217 .53528 Mdot
.21231 .53292 Mdot
.48521 .69031 Mdot
.69615 .38317 Mdot
.16899 .57891 Mdot
.3494 .70593 Mdot
.56167 .5658 Mdot
.75084 .34977 Mdot
.39533 .51745 Mdot
.46775 .36072 Mdot
.6142 .18007 Mdot
.68114 .54438 Mdot
.69638 .69411 Mdot
.25347 .62202 Mdot
.57382 .66268 Mdot
.49675 .84764 Mdot
.32808 .75051 Mdot
.75076 .25321 Mdot
.79776 .62433 Mdot
.33373 .65916 Mdot
.75607 .64908 Mdot
.75698 .6873 Mdot
.75052 .25849 Mdot
.66321 .48605 Mdot
.40562 .37294 Mdot
.41278 .15625 Mdot
.3767 .54694 Mdot
.6665 .72598 Mdot
.1997 .46188 Mdot
.45358 .61685 Mdot
.49869 .39585 Mdot
.61016 .44536 Mdot
.45734 .45417 Mdot
.55337 .38413 Mdot
.58512 .60417 Mdot
.68149 .22781 Mdot
.8013 .31004 Mdot
.70463 .2305 Mdot
.32103 .76409 Mdot
.78549 .61221 Mdot
.51342 .48139 Mdot
.24652 .31897 Mdot
.55127 .46985 Mdot
.57439 .53378 Mdot
.42673 .63606 Mdot
.5776 .75631 Mdot
.72947 .31917 Mdot
.43765 .30171 Mdot
.58382 .27114 Mdot
.52734 .80156 Mdot
.13138 .63012 Mdot
.701 .34889 Mdot
.19429 .42606 Mdot
.47996 .64012 Mdot
.55974 .65022 Mdot
.47929 .79447 Mdot
.69501 .29045 Mdot
.66481 .78027 Mdot
.55312 .38355 Mdot
.1904 .51123 Mdot
.35615 .72787 Mdot
.49912 .30241 Mdot
.33298 .64668 Mdot
.66181 .75368 Mdot
.33243 .3305 Mdot
.66971 .26493 Mdot
.4679 .27654 Mdot
.63942 .33956 Mdot
.43348 .58803 Mdot
.26283 .47438 Mdot
.17035 .53488 Mdot
.29955 .70614 Mdot
.69218 .64523 Mdot
.48874 .45828 Mdot
.36435 .23108 Mdot
.32222 .42082 Mdot
.66732 .65165 Mdot
.5077 .41025 Mdot
.72441 .66357 Mdot
.70515 .17343 Mdot
.62539 .20301 Mdot
.57653 .84753 Mdot
.44553 .76698 Mdot
.55804 .57 Mdot
.6462 .79641 Mdot
.67495 .19975 Mdot
.86241 .41138 Mdot
.24706 .48492 Mdot
.40046 .57672 Mdot
.34906 .37211 Mdot
.71535 .25913 Mdot
.4252 .73672 Mdot
.61251 .80646 Mdot
.67139 .66619 Mdot
.35352 .41556 Mdot
.32791 .1995 Mdot
.83844 .46503 Mdot
.73768 .4904 Mdot
.5213 .65852 Mdot
.55976 .52047 Mdot
.41663 .20104 Mdot
.58043 .31636 Mdot
.29738 .50149 Mdot
.5715 .64885 Mdot
.36942 .57629 Mdot
.51971 .77359 Mdot
.20667 .5354 Mdot
.58714 .57326 Mdot
.47096 .5584 Mdot
.5313 .29667 Mdot
.32521 .47053 Mdot
.35659 .29876 Mdot
.84794 .38142 Mdot
.46132 .63072 Mdot
.56544 .54341 Mdot
.58642 .6644 Mdot
.33425 .64144 Mdot
.78439 .33091 Mdot
.35797 .41407 Mdot
.74593 .68513 Mdot
.4357 .47864 Mdot
.53801 .64238 Mdot
.5788 .24809 Mdot
.52988 .52294 Mdot
.67221 .56757 Mdot
.36859 .78097 Mdot
.77594 .44766 Mdot
.48385 .30508 Mdot
.68854 .58606 Mdot
.5612 .46638 Mdot
.63748 .80162 Mdot
.47094 .62373 Mdot
.27133 .46196 Mdot
.73402 .70525 Mdot
.379 .42492 Mdot
.52631 .30755 Mdot
.47012 .7349 Mdot
.18954 .5394 Mdot
.7569 .55101 Mdot
.76955 .34564 Mdot
.47412 .60935 Mdot
.35675 .7007 Mdot
.72964 .71752 Mdot
.73285 .69204 Mdot
.35588 .21253 Mdot
.59943 .32893 Mdot
.61014 .64035 Mdot
.18403 .54037 Mdot
.51895 .37557 Mdot
.23942 .36811 Mdot
.25875 .34824 Mdot
.84231 .50324 Mdot
.46437 .55799 Mdot
.39753 .83891 Mdot
.60996 .71326 Mdot
.50047 .78938 Mdot
.64804 .24073 Mdot
.17642 .50913 Mdot
.63983 .75321 Mdot
.57545 .37542 Mdot
.69084 .42892 Mdot
.54577 .5597 Mdot
.31105 .2709 Mdot
.40726 .16578 Mdot
.46336 .7337 Mdot
.53707 .41924 Mdot
.45134 .8298 Mdot
.63001 .56244 Mdot
.5912 .18117 Mdot
.20002 .52677 Mdot
.71321 .27462 Mdot
.34891 .40469 Mdot
.60106 .50356 Mdot
.63957 .4859 Mdot
.77383 .597 Mdot
.43072 .2375 Mdot
.73154 .65547 Mdot
.19182 .63471 Mdot
.46496 .81321 Mdot
.59263 .26907 Mdot
.67001 .72036 Mdot
.57004 .81878 Mdot
.23356 .61985 Mdot
.48607 .48974 Mdot
.477 .76724 Mdot
.55501 .70296 Mdot
.39572 .81548 Mdot
.48335 .39172 Mdot
.39048 .48848 Mdot
.32827 .32187 Mdot
.26326 .5903 Mdot
.70977 .28936 Mdot
.62555 .502 Mdot
.82691 .42059 Mdot
.63174 .78829 Mdot
.39168 .20299 Mdot
.52458 .19338 Mdot
.63176 .20471 Mdot
.7619 .4507 Mdot
.27111 .6604 Mdot
.2203 .5849 Mdot
.15915 .53007 Mdot
.43037 .48064 Mdot
.58743 .76729 Mdot
.53731 .71661 Mdot
.73147 .71282 Mdot
.41627 .40052 Mdot
.46521 .26037 Mdot
.31068 .36484 Mdot
.74601 .65276 Mdot
.66058 .38262 Mdot
.66476 .76168 Mdot
.49465 .42941 Mdot
.75518 .25417 Mdot
.32676 .73795 Mdot
.47085 .43856 Mdot
.35129 .59611 Mdot
.29178 .65578 Mdot
.57588 .79396 Mdot
.34009 .74368 Mdot
.18001 .48142 Mdot
.40942 .57307 Mdot
.50863 .55702 Mdot
.69658 .46741 Mdot
.52843 .64388 Mdot
.36482 .78115 Mdot
.58526 .6644 Mdot
.69387 .7536 Mdot
.78337 .59337 Mdot
.82496 .41709 Mdot
.59404 .75268 Mdot
.30656 .76617 Mdot
.40065 .27981 Mdot
.51551 .64591 Mdot
.20254 .52966 Mdot
.39281 .70742 Mdot
.56204 .38402 Mdot
.41886 .10796 Mdot
.24882 .70328 Mdot
.29131 .68914 Mdot
.84824 .45036 Mdot
.32748 .75518 Mdot
.32397 .46304 Mdot
.62024 .31225 Mdot
.50246 .25312 Mdot
.81503 .4363 Mdot
.60074 .5342 Mdot
.6695 .21237 Mdot
.54848 .63435 Mdot
.83314 .33958 Mdot
.61064 .8141 Mdot
.53223 .41528 Mdot
.68524 .55964 Mdot
.34984 .52829 Mdot
.43167 .50957 Mdot
.72473 .61888 Mdot
.63478 .39055 Mdot
.46834 .20855 Mdot
.32789 .43919 Mdot
.39613 .56145 Mdot
.3281 .63326 Mdot
.57514 .37084 Mdot
.45103 .75986 Mdot
.2648 .57509 Mdot
.35739 .62031 Mdot
.4267 .46132 Mdot
.61886 .65671 Mdot
.41341 .23099 Mdot
.74146 .50042 Mdot
.69956 .29189 Mdot
.36639 .32966 Mdot
.36294 .53561 Mdot
.74296 .48437 Mdot
.26312 .70408 Mdot
.44836 .81799 Mdot
.84728 .44262 Mdot
.49726 .57169 Mdot
.64606 .4119 Mdot
.70587 .64255 Mdot
.55096 .21085 Mdot
.58847 .38344 Mdot
.33863 .46256 Mdot
.41438 .20407 Mdot
.60813 .35251 Mdot
.22112 .44671 Mdot
.83727 .53105 Mdot
.18632 .52139 Mdot
.18271 .54034 Mdot
.41905 .62132 Mdot
.68104 .61758 Mdot
.49194 .32952 Mdot
.60184 .70401 Mdot
.46416 .38501 Mdot
.18858 .34587 Mdot
.69964 .56411 Mdot
.17082 .33564 Mdot
.40105 .38032 Mdot
.6067 .26096 Mdot
.55171 .71077 Mdot
.49483 .4627 Mdot
.49985 .42053 Mdot
.30741 .71872 Mdot
.47461 .25006 Mdot
.25552 .64894 Mdot
.55496 .2229 Mdot
.3979 .56036 Mdot
.20279 .66723 Mdot
.32363 .78761 Mdot
.70707 .43244 Mdot
.60769 .58937 Mdot
.26486 .72502 Mdot
.39716 .58069 Mdot
.71847 .30889 Mdot
.50386 .84618 Mdot
.42101 .79241 Mdot
.66044 .4499 Mdot
.54958 .64731 Mdot
.59521 .76559 Mdot
.78428 .65803 Mdot
.39581 .18222 Mdot
.5187 .80291 Mdot
.41564 .39994 Mdot
.49463 .43941 Mdot
.62707 .77573 Mdot
.49479 .22196 Mdot
.42552 .39388 Mdot
.45684 .21187 Mdot
.13266 .41054 Mdot
.67183 .72592 Mdot
.72038 .66178 Mdot
.49294 .21427 Mdot
.50142 .34876 Mdot
.47032 .2367 Mdot
.42875 .21821 Mdot
.39585 .77822 Mdot
.23919 .66257 Mdot
.42886 .22179 Mdot
.14432 .4849 Mdot
.52686 .55221 Mdot
.32483 .50311 Mdot
.57882 .42675 Mdot
.73811 .59184 Mdot
.36397 .43203 Mdot
.8154 .48479 Mdot
.48073 .8227 Mdot
.39092 .36272 Mdot
.38511 .78997 Mdot
.22086 .51164 Mdot
.7337 .54844 Mdot
.75932 .54071 Mdot
.45319 .80047 Mdot
.66037 .39935 Mdot
.31554 .25393 Mdot
.76725 .36494 Mdot
.39278 .59958 Mdot
.51639 .82879 Mdot
.34588 .54721 Mdot
.57975 .45414 Mdot
.51734 .25314 Mdot
.48624 .7594 Mdot
.70078 .25881 Mdot
.47707 .70592 Mdot
.57904 .32936 Mdot
.40633 .16991 Mdot
.50828 .34571 Mdot
.69265 .23294 Mdot
.67074 .2869 Mdot
.44769 .19769 Mdot
.33186 .6647 Mdot
.32656 .68741 Mdot
.13284 .4431 Mdot
.41839 .3673 Mdot
.36596 .62658 Mdot
.28552 .3032 Mdot
.5757 .3163 Mdot
.41706 .63248 Mdot
.33317 .58777 Mdot
.39487 .4717 Mdot
.25754 .38324 Mdot
.53177 .56604 Mdot
.57633 .28488 Mdot
.40755 .46925 Mdot
.79593 .52412 Mdot
.81418 .57347 Mdot
.38492 .57876 Mdot
.20804 .30257 Mdot
.68082 .56284 Mdot
.72411 .43329 Mdot
.67383 .7776 Mdot
.32231 .20363 Mdot
.2921 .59631 Mdot
.34752 .81163 Mdot
.57205 .50555 Mdot
.45871 .7856 Mdot
.536 .32444 Mdot
.18987 .51916 Mdot
.43807 .67911 Mdot
.56926 .66548 Mdot
.38637 .36657 Mdot
.66643 .26286 Mdot
.28762 .59754 Mdot
.55311 .3743 Mdot
.43039 .77351 Mdot
.71317 .61644 Mdot
.37533 .45374 Mdot
.30842 .64503 Mdot
.71075 .43899 Mdot
.74866 .56227 Mdot
.58118 .27638 Mdot
.71134 .67285 Mdot
.17931 .56784 Mdot
.85156 .38288 Mdot
.49289 .38394 Mdot
.54301 .4513 Mdot
.27883 .34195 Mdot
.4133 .80184 Mdot
.32577 .27318 Mdot
.69322 .7675 Mdot
.61615 .64988 Mdot
.59206 .62495 Mdot
.65816 .65061 Mdot
.54111 .51526 Mdot
.47027 .47446 Mdot
.28278 .48693 Mdot
.48912 .19778 Mdot
.38477 .24566 Mdot
.62892 .29882 Mdot
.32867 .25403 Mdot
.70329 .6681 Mdot
.45046 .20022 Mdot
.36679 .61593 Mdot
.74374 .54434 Mdot
.33233 .36742 Mdot
.81665 .57563 Mdot
.68732 .77045 Mdot
.36241 .35105 Mdot
.37678 .63817 Mdot
.44047 .83979 Mdot
.65182 .48464 Mdot
.50175 .51816 Mdot
.66584 .55094 Mdot
.51742 .59997 Mdot
.28654 .2307 Mdot
.40728 .78967 Mdot
.5749 .58242 Mdot
.74658 .67249 Mdot
.76491 .65127 Mdot
.78938 .28693 Mdot
.1708 .45173 Mdot
.55625 .34623 Mdot
.75657 .27219 Mdot
.46045 .2075 Mdot
.77815 .66836 Mdot
.3255 .48686 Mdot
.70691 .77837 Mdot
.6896 .42449 Mdot
.41144 .81193 Mdot
.61614 .31218 Mdot
.48922 .25441 Mdot
.25682 .61503 Mdot
.49918 .50916 Mdot
.27152 .42641 Mdot
.29684 .72047 Mdot
.17848 .64572 Mdot
.54627 .53068 Mdot
.22522 .55737 Mdot
.39348 .32535 Mdot
.5331 .83035 Mdot
.33131 .72688 Mdot
.62434 .5911 Mdot
.32263 .35212 Mdot
.6956 .26628 Mdot
.62795 .65879 Mdot
.52784 .48581 Mdot
.31771 .71345 Mdot
.80293 .42136 Mdot
.71284 .63522 Mdot
.18123 .53409 Mdot
.70375 .43578 Mdot
.43614 .4982 Mdot
.58489 .50018 Mdot
.5888 .30225 Mdot
.49422 .69128 Mdot
.49136 .52495 Mdot
.62979 .58195 Mdot
.31572 .54981 Mdot
.39515 .45754 Mdot
.66585 .22483 Mdot
.3788 .26762 Mdot
.20551 .5728 Mdot
.54817 .2791 Mdot
.43554 .32695 Mdot
.31648 .28551 Mdot
.61521 .20695 Mdot
.38631 .74635 Mdot
.64036 .6636 Mdot
.69123 .7302 Mdot
.7858 .59572 Mdot
.53031 .26924 Mdot
.82894 .36049 Mdot
.37801 .43527 Mdot
.73415 .53627 Mdot
.45309 .30659 Mdot
.36217 .62928 Mdot
.64324 .60861 Mdot
.41077 .81077 Mdot
.4621 .61885 Mdot
.6517 .72072 Mdot
.26325 .66762 Mdot
.549 .61317 Mdot
.70988 .46786 Mdot
.74601 .68082 Mdot
.3351 .53023 Mdot
.19618 .58706 Mdot
.35067 .43747 Mdot
.32126 .71163 Mdot
.78821 .60167 Mdot
.84483 .46858 Mdot
.47365 .41635 Mdot
.55686 .69096 Mdot
.64408 .53406 Mdot
.17288 .5348 Mdot
.40147 .78936 Mdot
.70729 .50158 Mdot
.25358 .45937 Mdot
.52096 .31271 Mdot
.25726 .5086 Mdot
.44704 .50116 Mdot
.81046 .443 Mdot
.55083 .29178 Mdot
.42869 .19762 Mdot
.48426 .65942 Mdot
.52688 .44256 Mdot
.66626 .60751 Mdot
.56865 .6844 Mdot
.16687 .40719 Mdot
.69031 .58732 Mdot
.52729 .80781 Mdot
.72682 .46009 Mdot
.19786 .49344 Mdot
.44848 .79482 Mdot
.32055 .44425 Mdot
.4772 .24904 Mdot
.74936 .54529 Mdot
.31658 .33694 Mdot
.65932 .51525 Mdot
.39189 .60732 Mdot
.54627 .37448 Mdot
.51727 .83407 Mdot
.76905 .46072 Mdot
.59412 .69934 Mdot
.44555 .57934 Mdot
.52914 .48934 Mdot
.331 .40165 Mdot
.69844 .77828 Mdot
.48384 .24659 Mdot
.58959 .65085 Mdot
.46499 .55778 Mdot
.55805 .7071 Mdot
.66209 .29682 Mdot
.85472 .50268 Mdot
.61677 .30441 Mdot
.44449 .44357 Mdot
.60251 .25875 Mdot
.28015 .67503 Mdot
.4908 .85124 Mdot
.66787 .64615 Mdot
.52234 .42978 Mdot
.46855 .71578 Mdot
.3095 .31151 Mdot
.43579 .57434 Mdot
.51293 .51598 Mdot
.39937 .47684 Mdot
.2491 .42636 Mdot
.45001 .34978 Mdot
.71644 .53685 Mdot
.61401 .74428 Mdot
.71023 .7131 Mdot
.1961 .47501 Mdot
.32859 .43318 Mdot
.28514 .54196 Mdot
.80441 .47184 Mdot
.71438 .78084 Mdot
.47236 .16651 Mdot
.64428 .53689 Mdot
.32281 .40304 Mdot
.54513 .68434 Mdot
.32292 .56327 Mdot
.399 .23011 Mdot
.32988 .2844 Mdot
.41016 .40189 Mdot
.51692 .63252 Mdot
.67386 .70069 Mdot
.26581 .60409 Mdot
.52232 .68168 Mdot
.33259 .35184 Mdot
.65033 .21444 Mdot
.29301 .73847 Mdot
.41651 .80207 Mdot
.80138 .7006 Mdot
.35285 .45268 Mdot
.59211 .46146 Mdot
.66213 .3503 Mdot
.7986 .59493 Mdot
.59465 .66805 Mdot
.74998 .33312 Mdot
.29703 .42152 Mdot
.65875 .64677 Mdot
.55446 .39531 Mdot
.6368 .73223 Mdot
.2527 .50692 Mdot
.47352 .45894 Mdot
.33072 .69375 Mdot
.83663 .36452 Mdot
.67508 .45086 Mdot
.69184 .73633 Mdot
.66691 .24708 Mdot
.15517 .52245 Mdot
.79824 .60396 Mdot
.61517 .72512 Mdot
.37152 .75 Mdot
.63781 .35936 Mdot
.50275 .40684 Mdot
.58473 .26306 Mdot
.72416 .3128 Mdot
.77326 .51911 Mdot
.37277 .66153 Mdot
.63305 .27336 Mdot
.69101 .64564 Mdot
.78054 .51034 Mdot
.52251 .42818 Mdot
.74597 .50241 Mdot
.3704 .63722 Mdot
.48063 .21571 Mdot
.47968 .34865 Mdot
.61832 .68756 Mdot
.73665 .47065 Mdot
.26935 .35413 Mdot
.31889 .74047 Mdot
.14331 .53527 Mdot
.41748 .73788 Mdot
.61255 .21318 Mdot
.57245 .55642 Mdot
.78693 .26707 Mdot
.26273 .63694 Mdot
.27387 .62751 Mdot
.24623 .65386 Mdot
.37167 .49322 Mdot
.55406 .47845 Mdot
.65887 .51472 Mdot
.56774 .79617 Mdot
.65662 .44766 Mdot
.72423 .33577 Mdot
.65107 .25183 Mdot
.55997 .65631 Mdot
.66313 .66862 Mdot
.60474 .70883 Mdot
.58942 .61944 Mdot
.51367 .32816 Mdot
.71269 .23669 Mdot
.46095 .41656 Mdot
.7035 .49776 Mdot
.67871 .60814 Mdot
.63732 .33899 Mdot
.42222 .85995 Mdot
.51347 .40565 Mdot
.72296 .6487 Mdot
.6915 .44736 Mdot
.51113 .27924 Mdot
.33511 .26053 Mdot
.91234 .55255 Mdot
.82186 .29212 Mdot
.56422 .36911 Mdot
.19491 .41377 Mdot
.68989 .4507 Mdot
.73503 .65717 Mdot
.36428 .73101 Mdot
.24193 .45241 Mdot
.71953 .51369 Mdot
.49872 .27745 Mdot
.62275 .61405 Mdot
.24857 .625 Mdot
.82647 .56525 Mdot
.63575 .24812 Mdot
.74472 .67454 Mdot
.53611 .52439 Mdot
.6504 .61098 Mdot
.77528 .74231 Mdot
.6385 .76955 Mdot
.68756 .53801 Mdot
.60217 .27338 Mdot
.70758 .52637 Mdot
.60803 .51634 Mdot
.48787 .7784 Mdot
.20259 .66506 Mdot
.7117 .64013 Mdot
.74501 .65325 Mdot
.57222 .29857 Mdot
.37417 .50298 Mdot
.3998 .378 Mdot
.4804 .41582 Mdot
.69273 .53549 Mdot
.39747 .42694 Mdot
.55486 .62596 Mdot
.44423 .83379 Mdot
.43893 .55454 Mdot
.19721 .62583 Mdot
.76617 .7147 Mdot
.76342 .46512 Mdot
.32018 .30609 Mdot
.64459 .48207 Mdot
.7514 .57232 Mdot
.7769 .55017 Mdot
.51462 .55075 Mdot
.36392 .79166 Mdot
.50831 .09943 Mdot
.29603 .3679 Mdot
.8171 .45967 Mdot
.50476 .36912 Mdot
.41774 .48994 Mdot
.72207 .48715 Mdot
.34135 .48399 Mdot
.37943 .5879 Mdot
.53432 .54948 Mdot
.51501 .30489 Mdot
.34851 .41084 Mdot
.22641 .2733 Mdot
.60302 .58859 Mdot
.36742 .2469 Mdot
.76808 .67608 Mdot
.76653 .36331 Mdot
.69444 .39985 Mdot
.63237 .49043 Mdot
.39728 .30688 Mdot
.52186 .43125 Mdot
.51288 .81701 Mdot
.8266 .4333 Mdot
.7075 .7042 Mdot
.77076 .46444 Mdot
.70554 .46374 Mdot
.5831 .50326 Mdot
.43187 .66529 Mdot
.44024 .38532 Mdot
.53586 .7961 Mdot
.70123 .52069 Mdot
.80156 .63013 Mdot
.28292 .59406 Mdot
.48126 .57506 Mdot
.54417 .41447 Mdot
.78318 .28464 Mdot
.6489 .3138 Mdot
.51732 .2929 Mdot
.62278 .20798 Mdot
.31161 .62136 Mdot
.52727 .6545 Mdot
.34752 .52681 Mdot
.67811 .49612 Mdot
.55849 .28742 Mdot
.59946 .17983 Mdot
.52966 .78731 Mdot
.27535 .41748 Mdot
.263 .46876 Mdot
.20524 .43226 Mdot
.37361 .45182 Mdot
.81373 .68229 Mdot
.30537 .65268 Mdot
.62068 .19449 Mdot
.1831 .57393 Mdot
.54768 .28488 Mdot
.33645 .75878 Mdot
.68984 .57854 Mdot
.38093 .57728 Mdot
.72927 .68197 Mdot
.63058 .45565 Mdot
.77787 .3457 Mdot
.58147 .49393 Mdot
.74098 .29158 Mdot
.4722 .71823 Mdot
.39137 .63954 Mdot
.27917 .66692 Mdot
.64128 .33392 Mdot
.61453 .82838 Mdot
.30311 .31511 Mdot
.6477 .80297 Mdot
.59003 .83399 Mdot
.75436 .67873 Mdot
.74881 .31962 Mdot
.36056 .19516 Mdot
.28707 .6779 Mdot
.44763 .80234 Mdot
.29194 .50054 Mdot
.62545 .34803 Mdot
.29031 .6563 Mdot
.57141 .42063 Mdot
.42837 .23963 Mdot
.32531 .36961 Mdot
.25094 .20774 Mdot
.65868 .68495 Mdot
.49531 .32793 Mdot
.30148 .66479 Mdot
.77644 .65118 Mdot
.64138 .35037 Mdot
.28812 .71214 Mdot
.45148 .49665 Mdot
.55322 .52612 Mdot
.77105 .51367 Mdot
.19366 .46598 Mdot
.28887 .62766 Mdot
.11982 .50361 Mdot
.26915 .70845 Mdot
.26165 .42532 Mdot
.46073 .47337 Mdot
.56892 .36183 Mdot
.30014 .27396 Mdot
.33288 .68533 Mdot
.34589 .7817 Mdot
.42493 .8228 Mdot
.63102 .77408 Mdot
.1354 .43842 Mdot
.19461 .51225 Mdot
.80817 .58261 Mdot
.35635 .76944 Mdot
.55992 .37335 Mdot
.59517 .73106 Mdot
.39231 .59384 Mdot
.28251 .45433 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0:_ooooo0_l0002Looooo`007?ooool00ol0003oooooooooo`2[ooooo`;o0000W?ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo0_l0002Rooooo`;o0000Y_ooool001cooooo00?o0000ooooooooool0
XOooool2o`000:Kooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0Q?ooool2o`000<?ooooo000Looooo`03o`000?oooooooooo08Cooooo0_l00033oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo07Wooooo0_l0003>ooooo`007?ooool00ol0003o
ooooooooo`1iooooo`;o0000c_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0:_ooooo0_l0002L
ooooo`007?ooool00ol0003oooooooooo`2Aooooo`;o00006?ooool4o`0009[ooooo000Looooo`03
o`000?oooooooooo06gooooo0_l0000Rooooo`;o00002Oooool2o`0000Cooooo0_l00009ooooo`;o
0000V_ooool001cooooo00?o0000ooooooooool0KOooool4o`0001[ooooo0_l0000:ooooo`;o0000
0oooool2o`0000Cooooo0_l0002Uooooo`007?ooool2o`00073ooooo0_l0000Jooooo`;o00002_oo
ool2o`000;3ooooo000Looooo`03o`000?oooooooooo07[ooooo0_l00006ooooo`;o0000>_ooool2
o`0000Sooooo0_l0001oooooo`007?ooool00ol0003oooooooooo`1jooooo`;o00001_ooool2o`00
01;ooooo0_l0000Vooooo`;o00002?ooool2o`0007oooooo000Looooo`03o`000?oooooooooo08_o
oooo0_l00009ooooo`;o0000/Oooool001cooooo00?o0000ooooooooool0POooool2o`0000Sooooo
0_l0002looooo`007?ooool00ol0003oooooooooo`21ooooo`;o00004oooool2o`000;7ooooo000L
ooooo`03o`000?oooooooooo083ooooo0_l0000Dooooo`;o0000/Oooool001cooooo00?o0000oooo
ooooool0Goooool2o`0000Wooooo0_l0000Dooooo`;o00004?ooool2o`0004gooooo0_l0001Voooo
o`007?ooool00ol0003oooooooooo`1Oooooo`;o00000_ooool2o`0000Gooooo0_l0000Vooooo`;o
0000COooool2o`0006Kooooo000Looooo`03o`000?oooooooooo06?ooooo0_l0000Xooooo`;o0000
2?ooool2o`0001oooooo0ol000001?oooooo0000o`000?ooool2o`0000?ooooo0_l00023ooooo`00
7?ooool00ol0003oooooooooo`1gooooo`;o00001?ooool2o`0000gooooo0ol00005ooooo`;o0000
00?oooooo`000?l000001Oooool2o`0001Sooooo0ol000001?oooooo0000o`000?ooool2o`0000?o
oooo0_l00023ooooo`007?ooool00ol0003oooooooooo`1booooo`;o00000oooool2o`0000Cooooo
0_l0000=ooooo`;o00001?ooool4o`0000Sooooo0_l00003ooooo`;o0000Y?ooool001cooooo00?o
0000ooooooooool0L?ooool4o`0001kooooo0_l0000?ooooo`;o00005_ooool2o`0008cooooo0000
1_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003ooooo
ooooo`1`ooooo`;o00001_ooool2o`0001Sooooo0_l0000Cooooo`;o00001_ooool2o`0000[ooooo
0_l0002<ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0IOooool2o`0000Gooooo0_l00003oooo
o`;o00001Oooool2o`0000kooooo0_l0000Mooooo`?o00001Oooool2o`0001Gooooo0_l0000Aoooo
o`;o0000K_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00onHV9So
8B4Qonk^kP07ooooo`03o`000?oooooooooo06Gooooo1?l00003ooooo`;o00000oooool2o`0001Go
oooo0_l00004ooooo`;o00002oooool2o`0000Gooooo0_l00004ooooo`;o00001oooool2o`0001?o
oooo0_l0000?ooooo`Co0000K_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
2oooool00onHV9So8B4Qonk^kP06ooooo`?o0000GOooool2o`0000Sooooo0_l0000Booooo`?o0000
1_ooool2o`0000;ooooo0_l00004ooooo`?o000000?oooooo`000?l000001oooool2o`0000Gooooo
0_l0000;ooooo`Co00005?ooool2o`0000kooooo0_l0001`ooooo`0000?oooooo`000?ooool00_oo
ool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0GOoo
ool2o`0000Kooooo0_l0000Dooooo`?o00001Oooool3o`0000Wooooo0_l000000ooooooo0000o`00
000Kooooo`;o00005_ooool4o`0007kooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooo
oooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1>ooooo`;o00005Oooool2
o`0001;ooooo0_l00003ooooo`;o00000oooool2o`0000Wooooo0_l00002ooooo`Co00003?ooool2
o`00023ooooo1ol00002ooooo`;o0000N_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2ooo
ool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0C_ooool2o`00023ooooo
0_l00007ooooo`;o00000oooool2o`0000?ooooo0ol00008ooooo`;o000000?oooooo`000?l00000
0ol0000:ooooo`Co00001?ooool2o`0000Gooooo0_l0000Cooooo`Go00001?ooool2o`0000Cooooo
0_l000000ooooooo0000o`00000;ooooo`;o0000I?ooool00006ooooooo^k^ko<S8bo`000?lb<S;o
k^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0L?ooool2o`00
00_ooooo0_l00004ooooo`?o00001oooool2o`0000;ooooo0_l00003ooooo`;o00001?ooool2o`00
00;ooooo0_l00006ooooo`;o00001Oooool4o`00013ooooo0_l00002ooooo`;o00001_ooool2o`00
00;ooooo0_l000000ooooooo0000o`00000;ooooo`;o0000I?ooool001cooooo00?o0000oooooooo
ool0L?ooool2o`0000;ooooo0_l00007ooooo`;o00002Oooool3o`0000;ooooo0_l00007ooooo`Co
00000_ooool2o`0001?ooooo0_l0000@ooooo`;o00000_ooool2o`0000Kooooo0_l0001hooooo`00
7?ooool00ol0003oooooooooo`1dooooo`;o00004_ooool3o`0000;ooooo0_l00009ooooo`;o0000
1Oooool2o`00017ooooo0_l00006ooooo`;o00002oooool2o`00083ooooo000Looooo`03o`000?oo
oooooooo05Kooooo0_l0000Kooooo`;o00001Oooool2o`000003ooooool0003o000000Wooooo0_l0
000Aooooo`Ko00001?ooool4o`0000Oooooo1?l00005ooooo`Co00003oooool2o`0001Gooooo0_l0
001Tooooo`007?ooool00ol0003oooooooooo`1Fooooo`;o00006oooool2o`0000Cooooo1_l00009
ooooo`?o00004?ooool5o`0000Gooooo1?l000000ooooooo0000o`000004ooooo`;o00001oooool4
o`0000oooooo0_l00006ooooo`;o00003Oooool2o`0006Cooooo000Looooo`03o`000?oooooooooo
05Wooooo0_l0000Nooooo`;o000000?oooooo`000?l000000_l00009ooooo`;o00007oooool2o`00
00kooooo1?l0000Booooo`;o00000_ooool2o`0000Cooooo0_l00005ooooo`;o00000oooool2o`00
067ooooo000Looooo`03o`000?oooooooooo05Wooooo0_l0000@ooooo`;o00001_ooool2o`0000Co
oooo0_l00003ooooo`;o00000oooool2o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o
00003oooool2o`0001Oooooo1Ol00008ooooo`;o00002?ooool2o`0000Sooooo0_l000000ooooooo
0000o`000002ooooo`;o00000oooool2o`00067ooooo000Looooo`03o`000?oooooooooo06[ooooo
0ol00006ooooo`;o000000?oooooo`000?l000002oooool2o`000003ooooool0003o000000?ooooo
0ol000000ooooooo0000o`000004ooooo`;o00000_ooool2o`0000Gooooo0_l00007ooooo`;o0000
3?ooool6o`0000Wooooo0_l00008ooooo`;o00002oooool2o`0000Gooooo0_l0001Sooooo`007?oo
ool00ol0003oooooooooo`1Tooooo`;o00001?ooool2o`0000Oooooo0_l000000ooooooo0000o`00
000?ooooo`?o00000_ooool2o`0000Oooooo0_l00002ooooo`;o00001Oooool2o`0000Oooooo0_l0
000<ooooo`;o00000_ooool2o`0000[ooooo0_l0000Kooooo`;o0000Hoooool001cooooo00?o0000
ooooooooool0I?ooool6o`0000cooooo0_l00009ooooo`;o00001?ooool3o`0000Oooooo0_l00000
1?oooooo0000o`000?ooool2o`0000Kooooo1?l00002ooooo`;o00005Oooool2o`0000Wooooo0_l0
0006ooooo`;o00001?ooool2o`0007;ooooo000Looooo`03o`000?oooooooooo067ooooo0ol00002
ooooo`Co00003?ooool2o`000004ooooool0003o0000o`0000Gooooo0_l0000<ooooo`Co000000Co
ooooo`000?l0003ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o0000
1oooool2o`0000Gooooo0_l00005ooooo`;o00003oooool5o`0000?ooooo0_l0001booooo`007?oo
ool00ol0003oooooooooo`1Qooooo`?o00002oooool2o`0000?ooooo0_l000000ooooooo0000o`00
0003o`0001?ooooo0_l00002ooooo`;o00000_ooool4o`000003ooooool0003o0000013ooooo0_l0
0005ooooo`;o000000?oooooo`000?l000004Oooool4o`000003ooooool0003o000000?ooooo0_l0
001booooo`007?ooool2o`0006gooooo0_l000000ooooooo0000o`000003ooooo`;o000000?ooooo
o`000?l000006_ooool2o`000003ooooool0003o000000?o00007Oooool2o`0000;ooooo0_l00008
ooooo`;o00000oooool2o`0000?ooooo0_l00003ooooo`;o00001?ooool3o`0006_ooooo000Loooo
o`03o`000?oooooooooo06?ooooo1_l000000ooooooo0000o`000002o`0000kooooo0_l0000Hoooo
o`Co000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l00006ooooo`;o00002Oooool2o`00
00?ooooo1?l00006ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Sooooo1?l0000Boooo
o`?o0000E_ooool001cooooo00?o0000ooooooooool0Hoooool6o`000003ooooool0003o000000co
oooo0_l00002ooooo`;o00006Oooool6o`0000;ooooo1?l000000ooooooo0000o`000004ooooo`Co
000000?oooooo`000?l000001_ooool2o`0000Gooooo0_l00006ooooo`Go00003?ooool2o`000003
ooooool0003o000001Cooooo0ol0001Fooooo`007?ooool00ol0003oooooooooo`1Sooooo`;o0000
1?ooool2o`0000gooooo0_l00007ooooo`;o00004?ooool8o`0000Gooooo1Ol00005ooooo`;o0000
0oooool2o`000003ooooool0003o000000cooooo0ol00003ooooo`?o00003_ooool2o`0000;ooooo
0_l000000ooooooo0000o`000002o`0000?ooooo0_l00009ooooo`;o0000Eoooool001cooooo00?o
0000ooooooooool0Hoooool2o`0000;ooooo1?l0000@ooooo`;o00001?ooool2o`00013ooooo1Ol0
0004ooooo`;o000000?oooooo`000?l000002?l00009ooooo`;o00001_ooool2o`0000Cooooo0ol0
000Booooo`;o00001?ooool2o`000003ooooool0003o000000;o00000oooool2o`0006;ooooo000L
ooooo`03o`000?oooooooooo05Wooooo0_l0000<ooooo`;o00001Oooool2o`0000Gooooo1?l00002
ooooo`;o00005oooool5o`0000?ooooo1Ol00004ooooo`Co00003Oooool2o`0000;ooooo0_l0000I
ooooo`?o00001_ooool2o`0001cooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`1Ioooo
o`;o00004oooool2o`0000?ooooo1_l0000Nooooo`;o000000?oooooo`000?l000000_ooool2o`00
00;ooooo0_l00004ooooo`;o00003?ooool3o`0000Cooooo0_l0000Gooooo`;o00001_ooool2o`00
01cooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`16ooooo`;o00004Oooool2o`0000?o
oooo0_l000000ooooooo0000o`000003ooooo`;o00002oooool2o`000003ooooool0003o000002;o
oooo0_l00002ooooo`;o00000_ooool2o`0000Cooooo1?l00004ooooo`;o00001Oooool2o`000004
ooooool0003o0000ooooo`;o000000?oooooo`000?l000002?ooool2o`0002Kooooo0_l0001Eoooo
o`007?ooool00ol0003oooooooooo`16ooooo`;o00004Oooool2o`0000?ooooo0_l000000ooooooo
0000o`000003ooooo`;o00000oooool2o`0000[ooooo0_l0000Jooooo`?o00002?ooool2o`0000[o
oooo0_l00004ooooo`?o00001_ooool4o`0000?ooooo0_l00003ooooo`Co000000?oooooo`000?l0
00002?ooool2o`0000kooooo0_l0000<ooooo`;o00000oooool2o`00053ooooo000Looooo`03o`00
0?oooooooooo06_ooooo0_l0000:ooooo`;o00001Oooool2o`0001?ooooo1?l00002ooooo`;o0000
0oooool2o`0000;ooooo0_l0000:ooooo`;o000000?oooooo`000?l000000ol000000ooooooo0000
o`000004o`0000Sooooo1?l0000;ooooo`;o00003_ooool2o`0000[ooooo0_l00005ooooo`;o0000
D?ooool001cooooo00?o0000ooooooooool0Joooool2o`0000;ooooo0_l00005ooooo`;o00001_oo
ool2o`0000[ooooo0ol00002ooooo`;o00001?ooool2o`0000;ooooo0_l00003ooooo`;o00000_oo
ool2o`0000Sooooo1?l00003ooooo`?o000000Coooooo`000?l0003ooooo0ol0000Gooooo`;o0000
4Oooool2o`0000Oooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`1Sooooo`;o00000_oo
ool2o`0000Kooooo0_l00005ooooo`;o00001_ooool2o`0000[ooooo0ol00002ooooo`;o00001Ooo
ool2o`0000?ooooo0_l0000?ooooo`Co00001?ooool2o`000003ooooool0003o000000;ooooo0_l0
000Gooooo`;o00004Oooool2o`0001;ooooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`1B
ooooo`;o00002_ooool4o`000003ooooool0003o000000;ooooo0ol0000;ooooo`;o00000oooool2
o`0000Sooooo0_l0000@ooooo`;o00000oooool2o`0000cooooo0_l00003ooooo`_o00000_ooool2
o`0001Sooooo0ol0000:ooooo`Co00005Oooool4o`0004[ooooo000Looooo`03o`000?oooooooooo
05;ooooo0_l00006ooooo`;o00000_ooool4o`0000Gooooo1?l0000:ooooo`;o00000oooool2o`00
00Sooooo0_l0000?ooooo`?o00000_ooool2o`0000gooooo0_l00002ooooo`[o00001?ooool2o`00
00Sooooo0_l0000>ooooo`?o00001_ooool3o`000003ooooool0003o000000;o000000?oooooo`00
0?l000001?ooool2o`0000?ooooo0_l00009ooooo`;o00002?ooool2o`00043ooooo000Looooo`03
o`000?oooooooooo05[ooooo0_l00003ooooo`;o00001Oooool5o`0001Wooooo0ol0000>ooooo`?o
00000_ooool2o`0000Sooooo1?l00004ooooo`So00001_ooool3o`0000?ooooo0_l00003ooooo`;o
00005_ooool7o`0000?ooooo0_l00004ooooo`Co000000?oooooo`000?l000004oooool2o`00043o
oooo000Looooo`03o`000?oooooooooo05?ooooo0_l0000Aooooo`Go00000_ooool2o`0000[ooooo
0_l0000:ooooo`;o000000?oooooo`000?l000006_ooool4o`000003ooooool0003o000000?o0000
00?oooooo`000?l000001?l000001?oooooo0000o`000?ooool3o`0000?ooooo0ol0000:ooooo`;o
00001Oooool2o`0000Sooooo0ol000000ooooooo0000o`00000<ooooo`;o0000F?ooool001cooooo
0_l00017ooooo`;o00001oooool2o`0000;ooooo0_l000000ooooooo0000o`00000Eooooo`;o0000
00Coooooo`000?l0003o00001_ooool2o`0000Oooooo0_l00004ooooo`;o00003Oooool2o`0000go
oooo0_l000000ooooooo0000o`00000Ao`0000?ooooo0_l00008ooooo`;o000000?oooooo`000?l0
00001Oooool2o`0001kooooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`10ooooo`;o0000
1?ooool2o`0000Oooooo0_l00005ooooo`;o000000?oooooo`000?l000005Oooool3o`0000_ooooo
1_l00006ooooo`;o00002oooool2o`0000Gooooo0_l00004ooooo`Co00000_oooolCo`0000Sooooo
0ol000000ooooooo0000o`000006ooooo`;o00004_ooool2o`0000cooooo0_l0001Dooooo`007?oo
ool00ol0003oooooooooo`0looooo`;o00000_ooool2o`0001Oooooo0_l00009ooooo`;o00002ooo
ool2o`0000[ooooo1_l00007ooooo`;o00000oooool2o`0000Sooooo0_l00003ooooo`?o00000ooo
oolCo`0000;ooooo1?l000000ooooooo0000o`000005ooooo`Oo00001Oooool2o`0000kooooo0_l0
0002ooooo`;o00001_ooool2o`0005[ooooo000Looooo`03o`000?oooooooooo03cooooo0_l0000@
ooooo`;o00000_ooool2o`00013ooooo0_l0000;ooooo`Go00000oooool2o`000005ooooool0003o
0000o`000?ooool00_l0000=ooooo`;o00002?ooool2o`0000Cooooo0_l00003oooooa?o000000Co
ooooo`000?l0003o00000oooool2o`0000Sooooo1?l00002ooooo`;o00003_ooool2o`000003oooo
ool0003o000000?ooooo0_l00005ooooo`;o00001oooool2o`0000Sooooo0_l00017ooooo`007?oo
ool00ol0003oooooooooo`1>ooooo`;o00000_ooool2o`0000gooooo0ol0000?ooooo`?o00000ooo
ool2o`000003ooooool0003o000001_ooooo0_l00008oooooa?o000000?oooooo`000?l000000_l0
0008ooooo`Go00001_ooool3o`0000Wooooo0_l00002ooooo`?o00001Oooool3o`0000Gooooo1_l0
0002ooooo`;o00001_ooool4o`0004Oooooo000Looooo`03o`000?oooooooooo05cooooo2?l00002
ooooo`Go00001?ooool2o`0000Sooooo0_l0000Nooooo`;o00001_oooolEo`000003ooooool0003o
000000Ko00000oooool6o`0000;ooooo0_l00003ooooo`;o00002Oooool2o`0000;ooooo0ol00006
ooooo`;o00000oooool8o`0000?ooooo0_l00005ooooo`;o0000BOooool001cooooo00?o0000oooo
ooooool0C?ooool2o`0000gooooo1_l00005ooooo`Go00001?ooool2o`0000Sooooo0_l0000Doooo
o`;o00001?ooool2o`000004ooooool0003o0000o`0000Gooooo7ol00003ooooo`;o00001_ooool2
o`0001?ooooo0_l00007ooooo`?o000000Coooooo`000?l0003ooooo1?l00004ooooo`;o00003_oo
ool2o`00043ooooo000Looooo`03o`000?oooooooooo04?ooooo0_l00002ooooo`;o00000oooool2
o`0000gooooo0_l00005ooooo`;o00000oooool2o`0001?ooooo0ol00006ooooo`;o00002?ooool2
o`0000Cooooo1_l00004oooooako00001oooool4o`0000Oooooo0_l0000>ooooo`?o00001_ooool4
o`0000?ooooo1?l0000Dooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0@oooool2o`00
00;ooooo1?l00003ooooo`;o00000_ooool2o`0000Sooooo0_l00004ooooo`;o00000oooool2o`00
01?ooooo0ol000000ooooooo0000o`000003ooooo`;o00003Oooool7o`0000Cooooo0_l00002oooo
oaco00001Oooool4o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000002oooo
o`Co00001_ooool2o`0000Cooooo0_l00002ooooo`;o0000GOooool001cooooo00?o0000oooooooo
ool0Aoooool6o`000003ooooool0003o000000;ooooo0_l00008ooooo`;o00006oooool2o`000003
ooooool0003o000000;ooooo0_l00008ooooo`;o00002?ooool3o`0000;ooooo0_l00002ooooo`;o
000000?oooooo`000?l000006Ol000000ooooooo0000o`000003o`0000Sooooo0ol00006ooooo`;o
00000_ooool4o`0000cooooo0_l0000Oooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0
Boooool2o`0001Oooooo0_l00002ooooo`;o00002Oooool2o`0000Cooooo0_l0000?ooooo`;o0000
1?ooool2o`0000Kooooo0_l00002ooooo`?o000000?oooooo`000?l000007?l000001?oooooo0000
o`000?l00005ooooo`;o000000?oooooo`000?l000001?ooool2o`00027ooooo0_l00006ooooo`;o
00002_ooool2o`00043ooooo000Looooo`03o`000?oooooooooo03Oooooo0_l0000Mooooo`;o0000
2oooool3o`0000;ooooo0_l00003ooooo`;o00001?ooool2o`0000Cooooo0_l00006ooooo`;o0000
3Oooool2o`0000Gooooo0ol00002ooooo`;o00000_oooolLo`0000Cooooo0_l00005ooooo`;o0000
1?ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000004_ooool2o`000004
ooooool0003o0000ooooo`;o000000?oooooo`000?l000001Oooool3o`0004cooooo000Looooo`03
o`000?oooooooooo03Cooooo0_l000000ooooooo0000o`00000:ooooo`;o00004Oooool2o`0000[o
oooo0ol00008ooooo`;o00001_ooool2o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o
00005?ooool2o`0000?ooooo0_l00003ooooo`Ko000000?oooooo`000?l000001Ol000000ooooooo
0000o`00000=o`0000Sooooo0_l00004ooooo`;o00001?ooool2o`000003ooooool0003o000000oo
oooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000Sooooo0_l0001=oooo
o`007?ooool00ol0003oooooooooo`0dooooo`;o00002Oooool2o`0000;ooooo0_l0000Mooooo`?o
00002?ooool2o`0000;ooooo1_l00003ooooo`Co00001Oooool2o`0001Oooooo0ol00003oooooago
00002?ooool2o`0000;ooooo0ol00008ooooo`;o00003oooool2o`0000?ooooo0_l00002ooooo`;o
00001_ooool2o`0000Gooooo0_l0000:ooooo`;o0000??ooool001cooooo00?o0000ooooooooool0
?oooool2o`00013ooooo0_l00004ooooo`;o00005?ooool2o`0000;ooooo1_l00003ooooo`;o0000
00Coooooo`000?l0003o00000oooool2o`00017ooooo0_l00005ooooo`;o00000ooooolGo`0000Co
oooo0_l0000<ooooo`?o000000?oooooo`000?l000001Oooool2o`0000;ooooo0_l0000;ooooo`;o
00000oooool2o`0000;ooooo0_l00006ooooo`;o00000oooool4o`0000[ooooo0ol000000ooooooo
0000o`00000hooooo`007?ooool00ol0003oooooooooo`0jooooo`;o00001?ooool2o`0000oooooo
0_l00004ooooo`;o00003_ooool2o`0000[ooooo1Ol00004ooooo`Co00000_ooool2o`0001;ooooo
1?l00006ooooo`So000000?oooooo`000?l000003_l00004ooooo`;o00001oooool2o`000004oooo
ool0003o0000ooooo`;o000000?oooooo`000?l000002Oooool2o`0000oooooo0ol00008ooooo`Go
00000_ooool2o`0000?ooooo0_l00008ooooo`;o000000?oooooo`000?l00000>?ooool001cooooo
0_l0000kooooo`;o00001?ooool2o`0000Wooooo0_l00002ooooo`?o00002_ooool4o`0000Oooooo
0_l00008ooooo`Oo00001?ooool2o`0000Cooooo0_l00003ooooo`;o00001?ooool3o`0000Cooooo
0_l00002ooooo`;o00000oooool:o`000003ooooool0003o000001;o00002_ooool5o`000004oooo
ool0003o0000o`0000Cooooo0_l0000;ooooo`;o00002Oooool2o`0000?ooooo0_l00003ooooo`Ko
00001oooool2o`0004Gooooo000Looooo`03o`000?oooooooooo04;ooooo0_l00006ooooo`?o0000
0_ooool3o`0000[ooooo1?l00005ooooo`Ko00001?ooool7o`000003ooooool0003o000000kooooo
1?l00002ooooo`?o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00000oooool4o`000003
ooooool0003o000001So00001_ooool2o`0000?ooooo0_l00004ooooo`;o00001?ooool2o`0000_o
oooo0_l0000>ooooo`;o00000oooool2o`000003ooooool0003o000004oooooo000Looooo`03o`00
0?oooooooooo04;ooooo0_l00004ooooo`Co00002?ooool2o`0000oooooo1_l00002ooooo`Co0000
00?oooooo`000?l000000oooool2o`0000kooooo1?l00006ooooo`;o000000?oooooo`000?l00000
2?ooool;o`000003ooooool0003o0000013o00001_ooool2o`0000Oooooo0_l0000Tooooo`Co0000
0oooool2o`0000Gooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00000ooo
ool2o`0000[ooooo0_l0000>ooooo`Co000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l0
00001?oooooo0000o`000?l00002ooooo`;o00002Oooool3o`0000Oooooo0ol000001?oooooo0000
o`000?l00004ooooo`;o00000ooooolJo`0000?ooooo0_l0000<ooooo`;o000000Coooooo`000?l0
003o00008?ooool4o`0000Cooooo0_l00002ooooo`Co0000B?ooool001cooooo00?o0000oooooooo
ool0>oooool2o`0000Kooooo0_l00002ooooo`;o00001_ooool2o`0001?ooooo0_l00003ooooo`;o
00001Oooool=o`0000Cooooo1?l000000ooooooo0000o`000008ooooo`;o00000_ooool3o`000004
ooooool0003o0000ooooo`;o00000ooooolKo`0000;ooooo0_l0000<ooooo`Ko00003_ooool3o`00
01?ooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000Oooooo0_l0000noooo
o`007?ooool00ol0003oooooooooo`0kooooo`;o00002_ooool2o`0000Kooooo0_l0000@ooooo`Co
00002?ooool2o`000003ooooool0003o000000Go000000?oooooo`000?l000001Ol00002ooooo`Co
00003oooool2o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`[o000000?oooooo`000?l0
00002_l000000ooooooo0000o`000002o`00017ooooo0_l0000@ooooo`?o00004oooool2o`0000;o
oooo0_l00005ooooo`;o00001oooool2o`000003ooooool0003o000003_ooooo000Looooo`03o`00
0?oooooooooo03Sooooo0_l0000@ooooo`;o00000_ooool3o`0000Cooooo0_l00005ooooo`;o0000
0oooool4o`0000?ooooo0_l00003oooooa;o00001Oooool2o`0000Sooooo0_l00008ooooo`;o0000
00?oooooo`000?l000000ooooolLo`0003Wooooo0_l0000;ooooo`;o00002?ooool2o`0003_ooooo
000Looooo`03o`000?oooooooooo03Sooooo0_l0000@ooooo`;o00000_ooool2o`0000Gooooo0_l0
0003ooooo`Co00000_ooool4o`0000;ooooo1?l000001?oooooo0000o`000?oooolAo`0000Gooooo
0_l00004ooooo`;o00000_ooool2o`0000Wooooo0_l00005oooooa_o00000_ooool2o`0001?ooooo
0_l0000Nooooo`Co00001Oooool2o`0000Gooooo0_l00015ooooo`007?ooool00ol0003ooooooooo
o`1=ooooo`;o00002oooool4o`0000;ooooo0_l00004ooooo`;o00000oooool2o`000003ooooool0
003o000001;o000000?oooooo`000?l000001Oooool2o`0000gooooo1?l00002oooooaGo000000?o
ooooo`000?l000000ol00003ooooo`;o00004oooool2o`0000[ooooo0_l0000Booooo`Co00001Ooo
ool2o`0000kooooo0_l0000looooo`007?ooool00ol0003oooooooooo`14ooooo`;o00001oooool4
o`0000[ooooo1Ol00002ooooo`?o00002OoooolGo`0001Kooooo0_l00002ooooo`co000000?ooooo
o`000?l000001_l000000ooooooo0000o`000003o`0002Cooooo1?l0000Looooo`;o000000?ooooo
o`000?l000001_ooool4o`000003ooooool0003o000003Wooooo000Looooo`03o`000?oooooooooo
04;ooooo1?l00007ooooo`Co00002_ooool6o`000004ooooool0003o0000o`0000[ooooo5?l00003
ooooo`;o00001?ooool4o`0000oooooo0_l00002ooooo`So000000?oooooo`000?l000000ol00000
1?oooooo0000o`000?ooool2o`0002Wooooo0_l0000Looooo`;o000000?oooooo`000?l000001_oo
ool2o`0000?ooooo1?l0000gooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00002_ooool2
o`0000Wooooo0_l000000ooooooo0000o`000007ooooo`So00001?ooool2o`0000?ooooo6_l00002
ooooo`;o00001?ooool4o`0000Oooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o
000000?ooooo1_l00002ooooo`Wo00001_ooool6o`0001;ooooo0_l00009ooooo`;o00006Oooool2
o`0000?ooooo0ol00003ooooo`;o00002_ooool3o`0003Kooooo000Looooo`03o`000?oooooooooo
03Kooooo0_l00002ooooo`;o000000?oooooo`000?l000004Oooool2o`0000Oooooo0ol00005oooo
o`?o000000?oooooo`000?l000000ooooolJo`000003ooooool0003o000000;o00000_ooool2o`00
00Kooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l00007ooooo`Go00000_ooool3o`00
0004ooooool0003o0000ooooo`;o00001_ooool7o`00013ooooo0ol00008ooooo`?o00006Oooool2
o`0000Cooooo0_l00003ooooo`Go00002?ooool2o`0003Kooooo000Looooo`03o`000?oooooooooo
037ooooo1?l00003ooooo`Co000000Coooooo`000?l0003ooooo0_l0000Oooooo`?o00000_ooool2
o`0000Cooooo6?l000000ooooooo0000o`000002o`0000;ooooo0_l00006ooooo`?o00001oooool2
o`0000gooooo0_l00005ooooo`;o00001_ooool2o`0000?ooooo0_l00008ooooo`?o00001Oooool2
o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`000003ooooool0003o000001Cooooo0_l00009
ooooo`Co0000@?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l0
00000ol@413oooooooooo`04ooooo`03o`000?oooooooooo037ooooo1?l000000ooooooo0000o`00
0002o`000003ooooool0003o000000?ooooo0_l0000Oooooo`;o00000oooool2o`000004ooooool0
003o0000ooooo`;o00000_ooool8o`000003ooooool0003o000000ko00002_ooool3o`000003oooo
ool0003o000000;o00000_ooool2o`0001cooooo0_l0000=ooooo`?o00002Oooool2o`0000Wooooo
0_l000000ooooooo0000o`00000Dooooo`;o00005?ooool2o`0003Oooooo00001_ooooooMgMgoiRH
V?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0<Oooool2o`0000?ooooo0_l00003ooooo`;o00003_ooool2o`0000_ooooo0_l00007ooooo`;o
00000oooool2o`000004ooooool0003o0000o`0000;ooooo6ol00002ooooo`;o00001_ooool2o`00
00;ooooo1_l000000ooooooo0000o`000006ooooo`;o00002?ooool2o`0000[ooooo0_l0000Roooo
o`;o00009_ooool2o`0000Cooooo1?l0000gooooo`0000?ooooooa0@4?ooool00_ooool00ol@413o
ooooooooo`09ooooo`Go00001_ooool00ol0003oooooooooo`0aooooo`;o00006?ooool2o`0000_o
oooo0_l000001?oooooo0000o`000?ooool2o`0000[ooooo0_l00002oooooa_o00000_ooool2o`00
00Kooooo0_l00006ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Cooooo0_l00002oooo
o`;o00002_ooool2o`0000kooooo0_l000000ooooooo0000o`000002ooooo`;o00002Oooool4o`00
02Kooooo0_l00004ooooo`;o00001?ooool2o`0003?ooooo00000ooooooo0000ooooo`02ooooo`03
o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`0002gooooo0_l0000@oooo
o`;o00005_ooool2o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`Co000000?oooooo`00
0?l000001?ooool:o`000003ooooool0003o000000_o00003Oooool2o`0000?ooooo0_l00003oooo
o`;o00003Oooool2o`0000Cooooo0_l0000Hooooo`;o000000?oooooo`000?l000000_ooool2o`00
00Wooooo0_l000000ooooooo0000o`00000Eooooo`?o00002oooool2o`0000cooooo0_l0000coooo
o`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`00
00Oooooo00?o0000ooooooooool0;Oooool2o`00013ooooo0_l0000Booooo`;o00000_ooool2o`00
00;ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000004oooo
oaco00003Oooool3o`0000?ooooo0_l00004ooooo`;o00001Oooool2o`0000Kooooo0_l0000]oooo
o`;o00000_ooool2o`00017ooooo0ol00009ooooo`Co0000@Oooool00003ooooool@413ooooo00;o
oooo00?o410@ooooooooool02_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo03?o
oooo0_l0000;ooooo`;o00004Oooool2o`000003ooooool0003o000000?ooooo0_l00003ooooo`;o
000000?oooooo`000?l000002OoooolLo`0000Kooooo0_l00002ooooo`Go00001oooool2o`000003
ooooool0003o000000Gooooo0ol0000>ooooo`;o00001?ooool2o`0000;ooooo0_l0000?ooooo`;o
00002oooool4o`0001gooooo0_l00008ooooo`;o0000>Oooool00006oooooomgMgOoV9RHoooooonH
V9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo02Oooooo0_l0000:oooo
o`;o00001Oooool2o`0000Cooooo0_l00007ooooo`;o00002oooool2o`0000_ooooo0_l00008oooo
o`co000000?oooooo`000?l000002Ol000001?oooooo0000o`000?l00007ooooo`;o00000_ooool4
o`0000Sooooo0ol00008ooooo`;o00003?ooool4o`0000Cooooo0_l00002ooooo`;o00001oooool2
o`0000Kooooo0ol0000:ooooo`Co00006Oooool2o`0000cooooo0_l00004ooooo`;o0000<oooool0
0006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oo
oooooooo02Oooooo0_l0000Aooooo`Co00002Oooool4o`0001Gooooo0_l0000;ooooo`co000000?o
ooooo`000?l000002_l000000ooooooo0000o`000002ooooo`;o00002_ooool3o`0000Oooooo1?l0
0004ooooo`;o00000_ooool2o`0000[ooooo0_l0000Cooooo`;o000000?oooooo`000?l000001?oo
ool2o`0000;ooooo0_l0000Sooooo`;o00001oooool2o`0000Wooooo0_l0000cooooo`007?ooool0
0ol0003oooooooooo`0looooo`;o00002Oooool2o`0000gooooo0_l00008ooooo`;o00000_ooool2
o`0000?ooooo1?l000000ooooooo0000o`00000Fo`0000Gooooo0_l00002ooooo`;o000000?ooooo
o`000?l000000_ooool4o`0000Wooooo0_l00003ooooo`?o00000_ooool2o`0000cooooo0_l0000D
ooooo`;o00002?ooool2o`0002_ooooo0ol0000nooooo`007?ooool00ol0003oooooooooo`0`oooo
o`;o00001?ooool2o`0001kooooo0_l00005ooooo`?o00001?ooool9o`000003ooooool0003o0000
01Ko00002Oooool2o`000003ooooool0003o000000;ooooo1?l00005ooooo`;o00000_ooool2o`00
00?ooooo0_l000000ooooooo0000o`000009ooooo`;o00000oooool2o`0002[ooooo0_l0000Hoooo
o`;o000000?oooooo`000?l000000_ooool3o`0000Oooooo0_l0000eooooo`007?ooool00ol0003o
ooooooooo`0`ooooo`;o00001?ooool2o`0000Wooooo0_l0000Booooo`;o00001Oooool4o`0000Go
oooo1_l00004oooooaCo000000Coooooo`000?l0003o00004Oooool2o`0000Gooooo1_l00006oooo
o`;o00002?ooool3o`0000Gooooo0_l0000?ooooo`;o00002oooool3o`0000Wooooo0_l0000Boooo
o`;o00000oooool3o`000003ooooool0003o000000?ooooo0_l00007ooooo`;o0000=Oooool001co
oooo00?o0000ooooooooool08Oooool2o`0001Sooooo0_l00004ooooo`;o00002_ooool2o`0000;o
oooo1_l00005ooooo`;o00000oooool2o`0000?ooooo0_l00007ooooo`Co000000?oooooo`000?l0
00004Ol0000Jooooo`Co00004?ooool5o`0000?ooooo0_l0000?ooooo`;o00002oooool3o`0000Ko
oooo0_l0000Eooooo`;o00000oooool2o`0004Oooooo000Looooo`03o`000?oooooooooo027ooooo
0_l0000Hooooo`;o00002?ooool2o`0000Kooooo2Ol0000;ooooo`;o00000oooool2o`0000;ooooo
0_l00008oooooa7o00006?ooool2o`0000Oooooo0_l00006ooooo`;o00001Oooool5o`0000Cooooo
0_l00009ooooo`?o00004Oooool2o`0000Gooooo0_l00002ooooo`;o00005Oooool2o`0000Kooooo
0ol0000oooooo`007?ooool00ol0003oooooooooo`0dooooo`;o00000oooool2o`000004ooooool0
003o0000ooooo`;o00001?ooool2o`0000Sooooo0_l0000Aooooo`;o00000oooool2o`000003oooo
ool0003o000000?ooooo0_l000000ooooooo0000o`00000Ao`0000gooooo0_l00009ooooo`;o0000
1Oooool4o`000003ooooool0003o000000?ooooo0_l00005ooooo`;o00001oooool2o`0000Wooooo
0ol0000Aooooo`;o00000oooool4o`000004ooooool0003o0000o`0001;ooooo0_l000000ooooooo
0000o`000006ooooo`Co0000?_ooool001cooooo00?o0000ooooooooool0=?ooool2o`0000?ooooo
0_l000001?oooooo0000o`000?ooool2o`00027ooooo0_l00003ooooo`;o00001_ooool2o`000003
ooooool0003o000000go000000?oooooo`000?l000000_l000000ooooooo0000o`000009ooooo`;o
00003Oooool2o`000003ooooool0003o000000;o000000?oooooo`000?l00000=_ooool3o`0000?o
oooo0_l0000:ooooo`;o00001oooool2o`0000Oooooo0_l00002ooooo`;o0000?_ooool001cooooo
00?o0000ooooooooool0:?ooool3o`0000[ooooo0_l0000[ooooo`;o00000oooool3o`0000?ooooo
0ol00003ooooo`;o000000?oooooo`000?l000002?l000000ooooooo0000o`000003o`000003oooo
ool0003o000000cooooo0_l00004ooooo`Co00000_ooool2o`0000gooooo0_l000000ooooooo0000
o`000006ooooo`;o00004oooool2o`0000?ooooo0ol00009ooooo`Co00003_ooool2o`00013ooooo
0_l00012ooooo`007?ooool00ol0003oooooooooo`0Wooooo`Co00002_ooool2o`0000cooooo0_l0
000>ooooo`Co00000oooool4o`0000Wooooo1?l00002ooooo`?o00000oooool2o`000004ooooool0
003o0000ooooo`Ko000000?oooooo`000?l000000_l0000Aooooo`;o00001?ooool4o`0000Sooooo
0_l00007ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Kooooo0_l0000;ooooo`;o0000
0oooool3o`0000_ooooo0_l0000<ooooo`;o00004?ooool2o`0000[ooooo0_l0000hooooo`007?oo
ool00ol0003oooooooooo`0Wooooo`;o00004oooool2o`000003ooooool0003o000000;ooooo0_l0
0002ooooo`;o00002_ooool4o`000003ooooool0003o000000Co00000oooool2o`000003ooooool0
003o000000?ooooo0_l0000@ooooo`So00002_ooool2o`0000?ooooo0_l0000Cooooo`;o00001Ooo
ool2o`0001;ooooo0ol00003ooooo`;o00002_ooool4o`00017ooooo0_l00006ooooo`Co00003_oo
ool2o`0000Gooooo0_l00003ooooo`?o0000=oooool001cooooo00?o0000ooooooooool0??ooool2
o`000003ooooool0003o000000;o000000Coooooo`000?l0003ooooo0_l00005ooooo`;o00002?oo
ool4o`0000Gooooo0_l000000ooooooo0000o`00000Eooooo`;o00000_ooool4o`0000[ooooo0_l0
0003ooooo`;o00006_ooool2o`0001;ooooo0_l00004ooooo`?o00001_ooool2o`000003ooooool0
003o000000Oooooo0_l0000:ooooo`;o00002?ooool2o`0000?ooooo0_l0000@ooooo`;o00000_oo
ool4o`0003Oooooo000Looooo`;o0000=Oooool2o`0000_ooooo0_l000000ooooooo0000o`000005
ooooo`;o000000?oooooo`000?l000002?ooool4o`0001[ooooo0_l00002ooooo`;o00001?ooool2
o`0000Wooooo1?l0000Eooooo`;o00001oooool2o`0000Wooooo0_l0000?ooooo`;o00001_ooool4
o`0000;ooooo0_l00003ooooo`?o00001?ooool2o`0000Sooooo0_l00005ooooo`;o00000_ooool2
o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`;o00000_ooool8o`0003Oooooo000Loooo
o`03o`000?oooooooooo03?ooooo0ol000000ooooooo0000o`000003ooooo`;o00001?ooool4o`00
00Gooooo1?l00004ooooo`[o00004_ooool2o`0000Gooooo0_l00002ooooo`;o00001?ooool2o`00
00Wooooo1?l00002ooooo`;o00002_ooool2o`0000Gooooo0ol00003ooooo`;o000000?oooooo`00
0?l000002Oooool3o`0000Kooooo1_l00002ooooo`;o00002?ooool2o`0000;ooooo0_l00003oooo
o`;o00001Oooool2o`0000Sooooo0_l00005ooooo`;o00001_ooool2o`000003ooooool0003o0000
00Gooooo0_l000001?oooooo0000o`000?ooool6o`0003Oooooo000Looooo`03o`000?oooooooooo
03?ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l00004ooooo`Co00001oooool2o`00
00;ooooo2Ol000000ooooooo0000o`000009ooooo`;o00001oooool2o`0000Gooooo0_l00005oooo
o`;o00002oooool4o`0000?ooooo0_l00008ooooo`Co00001_ooool2o`0000?ooooo0_l0000:oooo
o`;o000000?oooooo`000?l000001?ooool8o`0000;ooooo0_l0000Oooooo`;o00004?ooool2o`00
00_ooooo0_l00002ooooo`?o0000>Oooool001cooooo00?o0000ooooooooool0>_ooool2o`000003
ooooool0003o0000013ooooo1?l0000Cooooo`;o00002_ooool2o`0000;ooooo0_l00004ooooo`?o
00002?ooool2o`000003ooooool0003o000000[ooooo0_l00003ooooo`;o00003oooool2o`000003
ooooool0003o000000Gooooo0_l00005ooooo`Co00006Oooool2o`0000cooooo1?l0000:ooooo`?o
00002_ooool2o`000003ooooool0003o000000;o00000oooool2o`0003[ooooo000Looooo`03o`00
0?oooooooooo03Sooooo0_l00003ooooo`?o00003oooool2o`0000?ooooo0_l00004ooooo`;o0000
2_ooool2o`0000;ooooo0_l00006ooooo`;o00002?ooool2o`0000Wooooo0_l000000ooooooo0000
o`00000:ooooo`;o00001Oooool2o`0000Wooooo2Ol00006ooooo`?o00000oooool2o`0001?ooooo
0_l00002ooooo`;o00000_ooool3o`0000;ooooo1?l00005ooooo`;o00003?ooool3o`0000?ooooo
0_l00005ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`00000looooo`007?oo
ool00ol0003oooooooooo`0fooooo`Co000000?oooooo`000?l000000ol0000Dooooo`;o00000ooo
ool4o`0000Wooooo0_l00002ooooo`?o00000_ooool2o`0000gooooo0_l0000Mooooo`;o00002Ooo
ool4o`0000;ooooo0ol00002ooooo`;o00000_ooool5o`000004ooooool0003o0000ooooo`Co0000
00?oooooo`000?l000000_l00009ooooo`;o00000_ooool2o`0000?ooooo0_l000000ooooooo0000
o`000005o`0000oooooo0_l000000ooooooo0000o`000003ooooo`;o00000_ooool2o`0000Wooooo
1?l0000jooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00000oooool2o`0001Gooooo0_l0
0005ooooo`Co000000?oooooo`000?l000001_ooool2o`0000?ooooo1_l0000=ooooo`;o000000?o
ooooo`000?l00000;?ooool2o`0000;ooooo0_l00005ooooo`Go000000?oooooo`000?l000000_l0
00000ooooooo0000o`000004o`0000?ooooo0ol00004ooooo`;o00001oooool2o`0000?ooooo0_l0
0004ooooo`Co00001oooool2o`000003ooooool0003o000000Gooooo1?l00005ooooo`Co00000_oo
ool4o`0003Sooooo000Looooo`03o`000?oooooooooo04_ooooo0_l00005ooooo`;o00002_ooool4
o`0000Cooooo0_l00005ooooo`;o00003_ooool2o`0000;ooooo0_l00002ooooo`;o00002oooool2
o`0000[ooooo0_l00009ooooo`;o00001?ooool2o`0000Wooooo1?l00003ooooo`;o00000_ooool6
o`000003ooooool0003o000000?o00000oooool3o`0001;ooooo1?l0000:ooooo`;o00001Oooool2
o`000003ooooool0003o000000Cooooo1?l00004ooooo`;o0000>?ooool001cooooo00?o0000oooo
ooooool0??ooool2o`0000Gooooo1?l00004ooooo`;o000000?oooooo`000?l000000_ooool2o`00
00?ooooo0_l00007ooooo`;o00001Oooool3o`0000;ooooo0_l0000?ooooo`?o00001Oooool2o`00
00_ooooo0_l000000ooooooo0000o`000002o`0000Gooooo0_l00009ooooo`Co00001?ooool2o`00
00kooooo0_l00004ooooo`;o00000oooool2o`000003ooooool0003o000000;o000000?oooooo`00
0?l000000oooool2o`0002Kooooo0_l00002ooooo`;o00003_ooool2o`0003;ooooo000Looooo`03
o`000?oooooooooo03cooooo0_l00005ooooo`Co00001oooool2o`0000;ooooo0_l00003ooooo`;o
00000oooool2o`0000Cooooo0_l00003ooooo`?o00000_ooool2o`0000Cooooo0_l0000:ooooo`;o
00002_ooool2o`0000Sooooo1Ol0000<ooooo`;o00001?ooool2o`0000?ooooo0ol0000=ooooo`;o
00001Oooool3o`0000;ooooo1ol00006ooooo`;o0000:?ooool4o`0000?ooooo0_l00003ooooo`;o
00001?ooool2o`0003;ooooo000Looooo`03o`000?oooooooooo03Oooooo0_l00003ooooo`;o0000
2_ooool2o`0000?ooooo0_l0000=ooooo`;o00001?ooool2o`0000Cooooo0_l00008ooooo`;o0000
5?ooool4o`0000Sooooo0_l0000=ooooo`Co00002Oooool6o`0000Gooooo2_l000000ooooooo0000
o`000003o`000003ooooool0003o000000?o00001_ooool2o`0002[ooooo0_l000001?oooooo0000
o`000?ooool4o`0000;ooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o0000
2?ooool4o`0000Cooooo0_l00009ooooo`;o00000oooool2o`0000;ooooo0_l0000Hooooo`;o0000
6oooool3o`0000_ooooo0_l0000;ooooo`;o00000oooool2o`0000Sooooo1?l00003ooooo`co0000
00?oooooo`000?l000002_l00002ooooo`;o000000?oooooo`000?l000002Oooool2o`0000?ooooo
0_l00005ooooo`;o00005Oooool3o`000003ooooool0003o000000;o0000??ooool001cooooo00?o
0000ooooooooool08Oooool2o`0000Sooooo0_l00008ooooo`;o00001_ooool2o`0000kooooo0_l0
0002ooooo`;o00001Oooool4o`0000[ooooo0_l00003ooooo`;o00002oooool2o`000003ooooool0
003o000000cooooo0_l00005ooooo`;o00001?ooool2o`00013ooooo0_l00009ooooo`;o00000_oo
ool5o`000003ooooool0003o000000;o00001?ooool>o`000004ooooool0003o0000ooooo`Co0000
1oooool2o`0000?ooooo0_l00005ooooo`;o00005Oooool3o`000003ooooool0003o000003kooooo
000Looooo`03o`000?oooooooooo027ooooo0_l0000Jooooo`;o00002oooool2o`0000Cooooo0_l0
0006ooooo`Co00002_ooool2o`0000gooooo1Ol000000ooooooo0000o`000007ooooo`;o000000?o
ooooo`000?l000001oooool2o`0000Sooooo0_l00006ooooo`;o00001?ooool3o`0000Sooooo0_l0
00000ooooooo0000o`000003o`0000;ooooo0ol000000ooooooo0000o`00000Bo`0000;ooooo1Ol0
000;ooooo`;o00000oooool2o`0001;ooooo0_l00004ooooo`Co0000?oooool001cooooo00?o0000
ooooooooool0:_ooool2o`00017ooooo0_l00008ooooo`;o000000?oooooo`000?l000001?ooool2
o`0000Oooooo0_l0000;ooooo`;o00003Oooool3o`0000?ooooo0_l00007ooooo`;o000000?ooooo
o`000?l000002oooool2o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`;o00001Oooool2
o`0000?ooooo0ol00005ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`00000A
o`0000;ooooo0_l00005ooooo`;o00004?ooool2o`0000Cooooo0_l0000<ooooo`;o00001?ooool4
o`0000Wooooo0_l0000dooooo`007?ooool00ol0003oooooooooo`0Zooooo`;o00002_ooool2o`00
00Gooooo0_l00008ooooo`;o00007Oooool2o`0000gooooo0_l00004ooooo`;o00003Oooool2o`00
00?ooooo1?l000000ooooooo0000o`000002o`0000;ooooo0_l000000ooooooo0000o`00000?oooo
o`Co000000Coooooo`000?l0003ooooo7Ol00003ooooo`Co00001oooool2o`0000oooooo1?l00009
ooooo`;o00004_ooool2o`0003Cooooo000Looooo`;o0000=oooool2o`00017ooooo0_l0000@oooo
o`Co00001?ooool2o`0000[ooooo0_l0000:ooooo`;o00003Oooool2o`000003ooooool0003o0000
00Go000000Goooooo`000?l0003o0000ooooo`03o`0001;ooooo1ol000000ooooooo0000o`000009
o`0000;ooooo2ol00002ooooo`Co00000_ooool4o`0000Oooooo0ol00009ooooo`;o00001Oooool2
o`0000Wooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`0Sooooo`;o00004Oooool2o`00
00cooooo0_l00002ooooo`?o000000?oooooo`000?l000002oooool6o`0000Cooooo0_l000000ooo
oooo0000o`000007ooooo`;o00000_ooool2o`000003ooooool0003o000000gooooo0_l00006oooo
o`Co000000?oooooo`000?l000000ol00002ooooo`;o00000oooool4o`000003ooooool0003o0000
00?ooooo0_l00004ooooo`;o00000_ooool2o`0000;ooooo6Ol000000ooooooo0000o`000002o`00
00;ooooo0ol00003ooooo`;o00000_ooool4o`0000Oooooo1_l00004ooooo`;o00001Oooool2o`00
013ooooo0ol000000ooooooo0000o`00000eooooo`007?ooool00ol0003oooooooooo`0Sooooo`;o
00007oooool2o`0000;ooooo2?l00009ooooo`Go00002?ooool2o`0000;ooooo0_l00007ooooo`;o
000000?oooooo`000?l000000_l00002ooooo`;o00001oooool2o`0000Oooooo0_l00003ooooo`;o
00002Oooool7o`0000?ooooo0_l00005ooooo`;o000000?oooooo`000?l000001?l000000ooooooo
0000o`00000Ko`000003ooooool0003o000000;o000000?oooooo`000?l000000_ooool2o`0000Wo
oooo0_l00002ooooo`;o00001?ooool2o`0000Gooooo0_l000000ooooooo0000o`00000=ooooo`?o
000000?oooooo`000?l00000=Oooool001cooooo00?o0000ooooooooool0=_ooool2o`0001;ooooo
0ol000000ooooooo0000o`000002o`0000Cooooo0ol00003ooooo`;o00003?ooool2o`0000cooooo
0_l00002ooooo`;o00002_ooool2o`0000Cooooo0_l0000>ooooo`;o000000?oooooo`000?l00000
0oooool2o`0000Kooooo:Ol00002ooooo`;o00001Oooool2o`0000Wooooo0_l00008ooooo`;o0000
0oooool2o`0000?ooooo0_l0000<ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0=_oo
ool2o`0000;ooooo1?l00006ooooo`;o00001Oooool2o`0000?ooooo0_l00004ooooo`?o00004ooo
ool3o`0000;ooooo1?l00007ooooo`;o00001_ooool2o`0000;ooooo0_l0000:ooooo`;o00002?oo
ool2o`0000Kooooo0_l00006ooooo`Go000000?oooooo`000?l000007?l00003ooooo`?o000000?o
ooooo`000?l000000ol000000ooooooo0000o`000005ooooo`;o00001?ooool2o`0000Oooooo1?l0
00000ooooooo0000o`000009ooooo`;o000000?oooooo`000?l000000oooool2o`0003[ooooo000L
ooooo`03o`000?oooooooooo03[ooooo1?l00006ooooo`;o00005?ooool2o`0000Oooooo0_l00004
ooooo`;o000000Coooooo`000?l0003o00000_ooool4o`0000oooooo0_l00005ooooo`;o00001ooo
ool2o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`;o00001oooool2o`0000?ooooo0_l0
00000ooooooo0000o`00000[o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`;o00000ooo
ool2o`0000Cooooo0_l0000<ooooo`;o000000?oooooo`000?l00000?oooool001cooooo00?o0000
ooooooooool0=Oooool2o`0000?ooooo0_l00002ooooo`Co00005oooool5o`0000Gooooo0_l00004
ooooo`Co000000Coooooo`000?l0003o00000oooool5o`0000Cooooo1ol00002ooooo`;o00000ooo
ool2o`0000gooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00007ooooo`;o00002Ooo
oolPo`000004ooooool0003o0000ooooo`Co00000oooool3o`0000Oooooo0_l00003ooooo`;o0000
1?ooool2o`0000Cooooo0_l00006ooooo`;o00002Oooool2o`0003Oooooo000Looooo`03o`000?oo
oooooooo02oooooo0_l00002ooooo`Co00000_ooool3o`0000;ooooo1?l0000Gooooo`;o000000?o
ooooo`000?l000001_ooool2o`0000Cooooo0ol000000ooooooo0000o`000009o`0000;ooooo2_l0
00000ooooooo0000o`000004ooooo`;o00004?ooool3o`0000Oooooo1?l00005oooooaGo000000?o
ooooo`000?l000004?l000001?oooooo0000o`000?l00003ooooo`Co00004oooool2o`0000Cooooo
0_l0000Aooooo`;o0000=oooool001cooooo00?o0000ooooooooool0;oooool6o`0000?ooooo0ol0
0005ooooo`;o00001?ooool2o`00013ooooo0_l00004ooooo`?o00000oooool2o`000003ooooool0
003o000000Go000000?oooooo`000?l000002Ol000000ooooooo0000o`000006ooooo`;o00001ooo
ool2o`000003ooooool0003o000000_ooooo1?l00008ooooo`Co00001?oooolFo`000003ooooool0
003o0000013o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000002o`0001_ooooo
0_l00009ooooo`;o00000oooool2o`0003Sooooo000Looooo`03o`000?oooooooooo037ooooo0_l0
0005ooooo`Co000000?oooooo`000?l000001_ooool3o`0000Cooooo0ol00009ooooo`;o00001?oo
ool3o`0000Kooooo1?l000000ooooooo0000o`00000=o`0000Cooooo0_l000000ooooooo0000o`00
000;ooooo`;o00002Oooool4o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`Co00000_oo
ool5o`000003ooooool0003o000000oo000000?oooooo`000?l000000ol000001Ooooooo0000o`00
0?l0003ooooo00Oo00001?ooool2o`0000;ooooo0ol0000Kooooo`;o000000?oooooo`000?l00000
0_ooool2o`0000;ooooo0_l00003ooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0<?oo
ool2o`0000;ooooo0_l00004ooooo`;o000000Coooooo`000?l0003o00001Oooool2o`0000Gooooo
0ol00003ooooo`;o00004Oooool2o`000003ooooool0003o0000017o00001?ooool2o`000003oooo
ool0003o000000Cooooo0_l0000:ooooo`;o00001?ooool2o`0000Gooooo0_l000000ooooooo0000
o`000006ooooobko000000?oooooo`000?l000000_ooool2o`0001Sooooo0_l00007ooooo`;o0000
0_ooool2o`0000Cooooo0ol0000jooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o00000ooo
ool2o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`Go00003oooool2o`0000kooooo0_l0
00000ooooooo0000o`00000Do`0000Gooooo0_l00006ooooo`;o00001_ooool2o`0000;ooooo0_l0
000?ooooo`;o00001oooool4o`0000?ooooo9Ol000000ooooooo0000o`000006o`0000kooooo0_l0
0002ooooo`;o00000_ooool2o`00017ooooo1?l0000iooooo`007?ooool00ol0003oooooooooo`0[
ooooo`;o00001oooool2o`000003ooooool0003o000000Kooooo1?l000000ooooooo0000o`00000L
ooooo`;o000000?oooooo`000?l000005Ol00004ooooo`;o00003_ooool2o`0000kooooo0_l00003
ooooo`;o00002OoooolKo`000003ooooool0003o000000co00000_ooool7o`0000;ooooo0_l00004
ooooo`;o00001?ooool2o`000004ooooool0003o0000o`0001Oooooo0_l0000iooooo`007?ooool0
0ol0003oooooooooo`0dooooo`;o00000_ooool4o`0000Sooooo0_l00008ooooo`;o00000_ooool2
o`0000;ooooo0_l000001?oooooo0000o`000?l00006ooooo`;o000000?oooooo`000?l000002_l0
00000ooooooo0000o`000008o`0000;ooooo0_l00008ooooo`;o00003_ooool2o`0000Gooooo0ol0
000@ooooobSo000000Goooooo`000?l0003o0000ooooo`04o`000003ooooool0003o000000?o0000
0_ooool2o`0000Kooooo0ol00006ooooo`;o00000oooool2o`0004Kooooo000Looooo`03o`000?oo
oooooooo03Kooooo1ol00005ooooo`;o00002_ooool2o`0000;ooooo0_l00002ooooo`;o000000?o
ooooo`000?l000000ol00006oooooaSo00000_ooool2o`0000Sooooo0_l0000>ooooo`;o00001Ooo
ool2o`0001?ooooo0ol00002ooooob[o000000?oooooo`000?l000000ol000000ooooooo0000o`00
0002ooooo`;o00000oooool2o`0000Oooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l0
0011ooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00000oooool2o`0000Gooooo0_l00006
ooooo`;o00000oooool2o`0000Kooooo0_l00003ooooo`;o00001_ooool@o`000003ooooool0003o
000000Co000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l0000Aooooo`;o00005ooooolF
o`000003ooooool0003o000001So00002?ooool2o`0000;ooooo1?l0000Aooooo`Go0000@Oooool0
01cooooo0_l00010ooooo`;o00002Oooool2o`0000;ooooo0ol00006ooooo`;o00000oooool2o`00
00Gooooo1ol000000ooooooo0000o`00000>o`000003ooooool0003o000000;ooooo0_l00002oooo
o`?o000000?oooooo`000?l000000_l00006ooooo`?o00000_ooool3o`0000Wooooo0_l00002oooo
o`;o000000?oooooo`000?l000001?oooolYo`0000;ooooo0_l000000ooooooo0000o`000003o`00
00Sooooo0_l00002ooooo`Go00001Oooool2o`0000Sooooo0_l00014ooooo`007?ooool00ol0003o
ooooooooo`0oooooo`;o00003Oooool3o`0001;ooooo6ol000000ooooooo0000o`000002o`000003
ooooool0003o000000;ooooo1?l00005ooooo`Co00000_ooool3o`0000Gooooo0_l00002ooooo`;o
00000_ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000009ol00005oooo
o`;o000000?oooooo`000?l000000_l00006ooooo`;o00000_ooool2o`000003ooooool0003o0000
00Gooooo0_l00003ooooo`;o00009Oooool2o`0002;ooooo000Looooo`03o`000?oooooooooo043o
oooo0_l00003ooooo`;o00002?ooool2o`0000;ooooo0_l0000=oooooaco000000?oooooo`000?l0
00000ol00007ooooo`;o00001?ooool2o`0000Cooooo1Ol00003ooooo`Co00001?ooool2o`0000Co
oooo0_l000000ooooooo0000o`00000Fo`000003ooooool0003o000000oo000000?oooooo`000?l0
00001_ooool2o`0000Kooooo0_l0000Aooooo`;o00009Oooool2o`0002;ooooo000Looooo`03o`00
0?oooooooooo03gooooo0_l000000ooooooo0000o`000003ooooo`;o00003?ooool2o`0000gooooo
1?l000000ooooooo0000o`00000Bo`000003ooooool0003o000000;o00000_ooool2o`0000Oooooo
0ol00005ooooo`Ko000000?oooooo`000?l000000oooool4o`0000Kooooo1?l000000ooooooo0000
o`000005ooooo`Wo000000?oooooo`000?l000006Ol000000ooooooo0000o`000005o`000003oooo
ool0003o000000oooooo0_l0000<ooooo`;o0000AOooool001cooooo00?o0000ooooooooool0?Ooo
ool2o`000003ooooool0003o000000kooooo0_l0000Aoooooako00002_ooool3o`0000Gooooo1?l0
0008ooooo`Co00001_ooool4o`000003ooooool0003o000000?o000000?oooooo`000?l000002?l0
00000ooooooo0000o`00000Ao`000003ooooool0003o000000go00003Oooool2o`0000?ooooo0_l0
000<ooooo`;o0000AOooool001cooooo00?o0000ooooooooool0AOooool3o`0000Sooooo0ol0000@
oooooako0000:?ooool2o`0000?ooooo<?l000000ooooooo0000o`000004ooooo`;o00002?ooool2
o`00013ooooo0_l00006ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0<_ooool3o`00
00;ooooo0_l0000<ooooo`?o000000?oooooo`000?l000001_ooool2o`00013ooooo7?l00007oooo
o`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo0_l00006ooooo`;o00002?ooool2o`00
00;ooooo0_l00003ooooo`Co000000Coooooo`000?l0003ooooo5Ol000000ooooooo0000o`00000;
o`0000Cooooo1?l00003ooooo`?o00004Oooool3o`0000Kooooo0_l00006ooooo`;o0000?_ooool0
01cooooo00?o0000ooooooooool0<_ooool3o`0000;ooooo0_l0000>ooooo`Co00002_ooool2o`00
00cooooo3Ol000000ooooooo0000o`00000:o`0000Gooooo0_l00002ooooo`;o000000?oooooo`00
0?l000001?ooool2o`0000;ooooo0_l00006ooooo`;o000000?oooooo`000?l000001Oooool2o`00
00Kooooo6?l000000ooooooo0000o`00000Co`0000;ooooo0_l00005ooooo`;o00002_ooool2o`00
00Kooooo0ol0001>ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00001Oooool2o`0000Go
oooo1_l00006ooooo`;o000000?oooooo`000?l000003OoooolAo`000003ooooool0003o000000Go
00001?ooool3o`0000Kooooo0_l00003ooooo`;o00002?ooool2o`0000?ooooo0ol00005ooooo`;o
000000?oooooo`000?l000000_ooool6o`0000;ooooo8_l000000ooooooo0000o`000003o`0001?o
oooo0_l00004ooooo`Go00001Oooool2o`0000?ooooo0_l00012ooooo`007?ooool00ol0003ooooo
ooooo`0cooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo0_l00005ooooo`Ko0000
1_ooool2o`0000Kooooo0_l00006oooooa3o000000?oooooo`000?l000002ol000000ooooooo0000
o`000007ooooo`;o00001_ooool2o`0000Gooooo0_l00003ooooo`?o00001Oooool2o`000003oooo
ool0003o000000Gooooo0_l00003oooooaoo000000?oooooo`000?l000001ol0000Hooooo`?o0000
1oooool2o`0000?ooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00000ooo
ool2o`000003ooooool0003o000001gooooo0_l00006ooooo`co000000?oooooo`000?l000004ol0
0009ooooo`;o00000oooool5o`0000Oooooo0ol00006ooooo`;o00002Oooool2o`000004ooooool0
003o0000ooooob;o00000_ooool2o`0000;ooooo0_l0000Eooooo`;o00003_ooool2o`00043ooooo
000Looooo`03o`000?oooooooooo04Cooooo0_l0000Oooooo`[o000000?oooooo`000?l000002_l0
00001?oooooo0000o`000?ooool4o`0000Wooooo0_l00002ooooo`Ko00001Oooool5o`000003oooo
ool0003o000000?ooooo0_l00007ooooo`Co00000_oooolTo`000003ooooool0003o000000?ooooo
0_l0000Eooooo`;o00002_ooool2o`0000;ooooo0_l00010ooooo`007?ooool00ol0003ooooooooo
o`0dooooo`;o00001_ooool2o`0000Cooooo1?l0000:ooooo`;o00004_ooool;o`0000;ooooo2ol0
000=ooooo`;o00000_ooool2o`0000;ooooo1Ol00006ooooo`;o00001?ooool2o`0000cooooo0_l0
0002ooooo`Oo000000?oooooo`000?l000007?l000000ooooooo0000o`000003o`0000Sooooo0_l0
000<ooooo`;o00002Oooool4o`0004Cooooo000Looooo`03o`000?oooooooooo03Cooooo0_l00006
ooooo`;o00000_ooool4o`0000cooooo1?l00003ooooo`;o00002oooool6o`0000?ooooo4Ol0000;
ooooo`;o00000_ooool2o`0000?ooooo0_l0000Hooooo`;o00001?ooool4o`000003ooooool0003o
0000027o00000_ooool4o`0000Gooooo0_l000000ooooooo0000o`00000<ooooo`;o00001?ooool2
o`0000?ooooo0_l00016ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?oo
ool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0@?ooool2o`0000oooooo
0ol00003ooooo`?o00002oooool6o`000003ooooool0003o0000013o000000?oooooo`000?l00000
4_ooool2o`0001Kooooo0ol00004ooooo`?o00000ooooolAo`0000;ooooo1_l000000ooooooo0000
o`000006o`0000;ooooo1Ol00004ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`?o0000
Boooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMgMooo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo057ooooo0_l00004ooooo`?o000000?oooooo`00
0?l000002Oooool:o`000003ooooool0003o000000_o000000?oooooo`000?l000004_ooool2o`00
00cooooo0_l00008ooooo`;o00001_ooool2o`000003ooooool0003o0000017o00000_ooool?o`00
00Gooooo0_l00007ooooo`;o00000_ooool2o`0000Gooooo0_l00003ooooo`;o000000Coooooo`00
0?l0003o00000_ooool2o`0004Oooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo
00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo05[ooooo1Ol00006
ooooo`;o00000_oooolFo`0000kooooo0_l0000<ooooo`;o000000Coooooo`000?l0003ooooo0_l0
00000ooooooo0000o`00000;ooooo`;o00000oooool5o`0000Cooooo1?l000000ooooooo0000o`00
0007o`0000?ooooo0_l000000ooooooo0000o`00000Cooooo`;o00002?ooool2o`0000;ooooo1?l0
00000ooooooo0000o`000002o`000004ooooool0003o0000o`0004Kooooo00000ooooooo0000oooo
o`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000
@?ooool2o`00017ooooo0_l00003ooooo`Co000000?oooooo`000?l000001_ooool2o`0000;ooooo
0_l000000ooooooo0000o`00000Ao`0000kooooo0_l00009ooooo`;o000000Coooooo`000?l0003o
oooo0_l00004ooooo`;o00002oooool3o`0000Gooooo0ol000000ooooooo0000o`000002o`000003
ooooool0003o000000So00001oooool4o`0001_ooooo0_l00002ooooo`;o00000_ooool5o`0000;o
oooo0_l00016ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`00
0?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0hooooo`;o00001_ooool2o`00017o
oooo0_l00003ooooo`?o00003_ooool2o`000003ooooool0003o000000go00006oooool4o`0000_o
oooo0_l0000;ooooo`;o00001_ooool2o`000003ooooool0003o000000?ooooo2_l00004ooooo`;o
000000?oooooo`000?l000001?l00004ooooo`;o000000Coooooo`000?l0003o00005Oooool6o`00
0003ooooool0003o000000Cooooo0_l00012ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413o
ooooooooo`09ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0>?ooool2o`0000Go
oooo0_l00004ooooo`Co00002?ooool4o`0001Oooooo1_l000001Ooooooo0000o`000?l0003ooooo
00Co000000?oooooo`000?l000000_l0000Aooooo`;o00000oooool2o`000003ooooool0003o0000
00Wooooo0ol00008ooooo`;o00001?ooool2o`0000?ooooo0_l00004ooooo`Wo00001?ooool2o`00
0004ooooool0003o0000ooooo`So00000_ooool6o`0000Sooooo0_l00006ooooo`;o00000oooool2
o`0000Gooooo0_l00004ooooo`;o0000@_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2ooo
ool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo03oooooo0ol00003ooooo`Co00000ooo
ool2o`0000;ooooo0ol0000Iooooo`;o00001_ooool2o`0000Gooooo1Ol0000Aooooo`;o00000ooo
ool2o`000003ooooool0003o000000Wooooo0_l00009ooooo`;o00001?ooool4o`000003ooooool0
003o000000Cooooo1Ol00003ooooo`;o00000oooool4o`0000;ooooo1?l00002ooooo`;o00001?oo
ool2o`0000[ooooo0_l00006ooooo`;o00001Oooool3o`0004cooooo00001_ooooook^k^oc8b<_l0
003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`10ooooo`;o
00001?ooool2o`0000Cooooo0_l00002ooooo`;o00000_ooool2o`0000Kooooo0_l0000Mooooo`Go
00006?ooool2o`0000_ooooo0_l00008ooooo`;o00001_ooool5o`0000Gooooo1?l00002ooooo`?o
00001?ooool3o`0000;ooooo0_l00004ooooo`;o00007oooool3o`0004cooooo000Looooo`03o`00
0?oooooooooo04Kooooo0_l00008ooooo`;o00000_ooool2o`0000Kooooo0_l0000Eooooo`;o0000
1_ooool4o`0000Gooooo0_l000000ooooooo0000o`000007ooooo`Co00001?ooool2o`0000Oooooo
0_l00002ooooo`;o00001_ooool4o`0000Oooooo0_l0000<ooooo`?o00004?ooool2o`0000Wooooo
0_l00002ooooo`?o00000oooool2o`0001Gooooo0_l00012ooooo`007?ooool00ol0003ooooooooo
o`10ooooo`;o00001_ooool2o`0000Gooooo0_l00004ooooo`;o00002_ooool2o`0000gooooo0_l0
00000ooooooo0000o`000006ooooo`;o00001oooool2o`000003ooooool0003o000000Oooooo1?l0
0002ooooo`Co00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000007ooooo`;o00002?oo
ool2o`0000?ooooo0_l00003ooooo`;o00000oooool2o`0000?ooooo0_l00008ooooo`;o00000_oo
ool2o`0000Wooooo0_l00002ooooo`?o00000oooool3o`000003ooooool0003o000000Kooooo0_l0
0009ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0@?ooool2o`0000;ooooo0_l00002
ooooo`;o00000oooool4o`0000Cooooo0_l00002ooooo`;o00001_ooool2o`0000gooooo0_l00000
0ooooooo0000o`000008ooooo`;o00001Oooool2o`0000cooooo0_l000000ooooooo0000o`000003
o`0000;ooooo0_l00006ooooo`;o00004Oooool2o`0000?ooooo0ol00002ooooo`;o00000oooool3
o`0000;ooooo0_l00008ooooo`;o00004Oooool2o`0000Gooooo0_l000001?oooooo0000o`000?oo
ool2o`0000?ooooo0ol00002ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0??ooool2
o`0000;ooooo0_l00002ooooo`;o00001oooool4o`0000Cooooo0_l00002ooooo`?o00001_ooool2
o`0000kooooo1Ol00005ooooo`Co00004_ooool2o`000003ooooool0003o000000Cooooo0_l0000C
ooooo`;o00002oooool2o`0000Gooooo1Ol0000Jooooo`;o00004?ooool2o`0000Cooooo0_l00002
ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool09oooool2o`0000oooooo0_l00002oooo
o`;o00000_ooool2o`0000Cooooo0_l00007ooooo`;o00001?ooool2o`0000?ooooo0_l00006oooo
o`;o000000?oooooo`000?l000002oooool5o`0000Gooooo1?l000000ooooooo0000o`000006oooo
o`;o00000_ooool2o`0000?ooooo0_l00007ooooo`;o00003Oooool3o`0000?ooooo0_l00009oooo
o`;o00001oooool2o`0001gooooo0_l000000ooooooo0000o`000005ooooo`;o00002_ooool2o`00
00Kooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`0Wooooo`;o00003oooool2o`0000co
oooo0_l0000@ooooo`;o00002oooool4o`0000Wooooo0_l0000=ooooo`;o000000?oooooo`000?l0
00000_l000000ooooooo0000o`000002ooooo`;o00000oooool3o`0000Wooooo2?l00002ooooo`Go
000000?oooooo`000?l000000_l00002ooooo`;o000000Coooooo`000?l0003ooooo0ol0000Poooo
o`;o00001oooool2o`0000Gooooo1?l00008ooooo`;o00001_ooool2o`0004Kooooo000Looooo`03
o`000?oooooooooo03Sooooo0_l000000ooooooo0000o`00000Eooooo`Co000000?oooooo`000?l0
00000_l00004ooooo`Oo000000?oooooo`000?l000002?ooool2o`0000;ooooo0_l00006ooooo`;o
00000_ooool2o`000003ooooool0003o000000?o00001?ooool2o`0000;ooooo1?l00009ooooo`Wo
000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l000001?oo
oooo0000o`000?ooool2o`0001oooooo1ol00002ooooo`Co00001oooool2o`000003ooooool0003o
000005Gooooo000Looooo`03o`000?oooooooooo03_ooooo0_l0000Eooooo`Co000000?oooooo`00
0?l000000_l00004ooooo`Oo00002oooool2o`0000;ooooo1?l00002ooooo`Go000000?oooooo`00
0?l000001?ooool2o`0000Cooooo0_l00002ooooo`Co00000_ooool3o`0000_ooooo0_l00003oooo
o`?o00005Oooool2o`0001Oooooo1ol000001?oooooo0000o`000?l00005ooooo`;o00001Oooool2
o`0005Gooooo000Looooo`03o`000?oooooooooo05;ooooo0_l00004ooooo`;o00002oooool2o`00
00;ooooo0_l00009ooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o0000
01?ooooo0_l00002ooooo`Co00002_ooool2o`0000?ooooo0ol00003ooooo`;o00002Oooool2o`00
00Gooooo0_l00009ooooo`;o00004_ooool5o`0000;ooooo0_l000000ooooooo0000o`00000]oooo
o`;o0000;Oooool001cooooo00?o0000ooooooooool0=_ooool2o`00013ooooo0_l0000>ooooo`;o
00001_ooool2o`0000?ooooo1ol00008ooooo`;o00001_ooool2o`0000Cooooo1?l00006ooooo`?o
000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000Sooooo1?l000000ooooooo
0000o`000003o`0000?ooooo0_l00009ooooo`;o00001Oooool2o`0000Wooooo0_l00006ooooo`Co
00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00002oooool3o`0002;o
oooo0_l0000]ooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00002Oooool2o`0000Gooooo
0_l00005ooooo`;o00001oooool3o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`Ko0000
4?ooool2o`0000Cooooo1?l000000ooooooo0000o`000002ooooo`oo00002Oooool3o`0000;ooooo
1?l00003ooooo`;o000000?oooooo`000?l000001?l00003ooooo`?o00001?ooool2o`0000?ooooo
0_l00009ooooo`;o000000?oooooo`000?l000000ol00003ooooo`Ko00000_ooool4o`0000Cooooo
0_l00003ooooo`;o000000Coooooo`000?l0003o0000DOooool001cooooo0_l00012ooooo`;o0000
2Oooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;o
oooo1?l0000>ooooo`;o00004?ooool2o`0000Cooooo0ol000000ooooooo0000o`00000>o`0000Go
oooo0_l0000;ooooo`Co000000?oooooo`000?l000001?l00003ooooo`Co00001Oooool2o`000003
ooooool0003o000000Kooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o0000
00?ooooo1_l00002ooooo`Go00000oooool4o`000004ooooool0003o0000ooooo`;o000000?ooooo
o`000?l00000Coooool001cooooo00?o0000ooooooooool0C?ooool2o`0000Cooooo0_l000000ooo
oooo0000o`000004ooooo`;o00000_ooool2o`0000kooooo0_l0000@ooooo`;o00001Oooool2o`00
0003ooooool0003o000000ko00001Oooool4o`0000Cooooo0_l000000ooooooo0000o`000002o`00
00?ooooo1?l00002ooooo`;o00000_ooool3o`0000Gooooo0_l00009ooooo`Go000000Coooooo`00
0?l0003ooooo0_l00003ooooo`;o00000_ooool2o`0000Gooooo1?l00002ooooo`?o00001?ooool2
o`000004ooooool0003o0000o`0004kooooo000Looooo`03o`000?oooooooooo02oooooo0_l0000D
ooooo`Co00000oooool2o`0000?ooooo0_l00008ooooo`;o00005oooool2o`0000Kooooo0_l0000;
oooooa7o00002?ooool2o`0000;ooooo1?l000000ooooooo0000o`000005ooooo`;o00001?ooool2
o`0000_ooooo0_l000000ooooooo0000o`000007ooooo`;o00001Oooool2o`0000[ooooo0_l00004
ooooo`?o000000?oooooo`000?l000002Oooool4o`0004cooooo000Looooo`03o`000?oooooooooo
02oooooo0_l00008ooooo`;o00002_ooool4o`0000Sooooo1Ol00005ooooo`;o00000_ooool2o`00
00Sooooo0_l00009ooooo`Co00001?ooool2o`0000_ooooo5?l00009ooooo`;o00001oooool2o`00
0003ooooool0003o0000017ooooo1Ol0000;ooooo`Co00000_ooool2o`0000Oooooo1?l00003oooo
o`;o00002oooool2o`000003ooooool0003o000004cooooo000Looooo`03o`000?oooooooooo03Wo
oooo0_l00003ooooo`;o00001?ooool2o`0000Cooooo0_l00006ooooo`Co00001Oooool2o`000004
ooooool0003o0000o`0000Oooooo0ol00002ooooo`;o00001_ooool3o`00017ooooo5?l00002oooo
o`?o00003Oooool2o`0000Kooooo0_l000001?oooooo0000o`000?l0000:ooooo`;o00000oooool2
o`0000Oooooo1?l00002ooooo`;o00002Oooool4o`0000Wooooo0_l00003ooooo`;o0000Coooool0
01cooooo00?o0000ooooooooool0?_ooool2o`0000Cooooo0_l00004ooooo`;o00001_ooool2o`00
00?ooooo0_l00002ooooo`;o000000?oooooo`000?l000002?ooool2o`0000?ooooo0_l000000ooo
oooo0000o`00000Dooooo`;o000000?oooooo`000?l000004_l00002ooooo`?o000000?oooooo`00
0?l000003Oooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000000ol0000=oooo
o`;o00002?ooool2o`0000Wooooo0_l00005ooooo`;o00002Oooool2o`0000Gooooo0_l0001=oooo
o`007?ooool00ol0003oooooooooo`0nooooo`;o00000oooool2o`0000gooooo0_l00003ooooo`?o
000000Coooooo`000?l0003ooooo0_l0000=ooooo`;o000000?oooooo`000?l000003?ooool2o`00
00Kooooo0_l000000ooooooo0000o`00000>o`0000;ooooo0_l00006ooooo`Co00002oooool2o`00
0003ooooool0003o000000Kooooo0_l0000;ooooo`;o00002?ooool4o`0000Cooooo0_l00003oooo
o`;o00005_ooool3o`0004gooooo000Looooo`03o`000?oooooooooo03oooooo0_l00002ooooo`;o
00004oooool2o`0000Cooooo0_l0000Nooooo`;o00002?oooolEo`000003ooooool0003o000000;o
oooo0_l000000ooooooo0000o`00000Booooo`;o00001?ooool2o`0000Cooooo0_l00003ooooo`?o
00001oooool2o`0000Kooooo0_l00005ooooo`;o00002_ooool2o`0000Sooooo0_l0001>ooooo`00
7?ooool00ol0003oooooooooo`0mooooo`Co00005_ooool2o`0000;ooooo0_l0000Yoooooa[o0000
0_ooool2o`0000oooooo0_l00003ooooo`?o00001?ooool2o`0000Cooooo0_l000000ooooooo0000
o`000003o`0000oooooo0_l00002ooooo`;o000000?oooooo`000?l000002Oooool3o`0000Gooooo
0_l0001Aooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00002Oooool2o`0000gooooo0_l0
00001?oooooo0000o`000?l00003ooooo`;o00004oooool2o`0000oooooo4_l000000ooooooo0000
o`000003o`0000Cooooo0_l00005ooooo`;o00002?ooool2o`0000?ooooo0_l0000>ooooo`Co0000
2?ooool2o`0000Kooooo0_l00002ooooo`?o00002?ooool2o`000004ooooool0003o0000ooooo`;o
00000oooool2o`00057ooooo000Looooo`03o`000?oooooooooo04Sooooo0_l0000@ooooo`;o0000
1?ooool2o`0001?ooooo0_l00006ooooo`;o00001ooooolBo`000003ooooool0003o000000?o0000
1?ooool2o`0000;ooooo0_l000000ooooooo0000o`000007ooooo`;o00004Oooool2o`0000Oooooo
0_l00004ooooo`;o00002oooool2o`0000Kooooo1?l00002ooooo`Co00001?ooool2o`0000cooooo
0_l00012ooooo`007?ooool00ol0003oooooooooo`1Xooooo`;o00004oooool2o`0000Kooooo7Ol0
0004ooooo`;o00001Oooool2o`0000?ooooo0_l000000ooooooo0000o`00000<ooooo`Co00001_oo
ool3o`0000;ooooo0_l0000Eooooo`;o00000oooool3o`0000Kooooo0_l0000<ooooo`;o0000@_oo
ool001cooooo00?o0000ooooooooool0Foooool2o`0000Kooooo1ol00006ooooo`;o00001oooool2
o`0000[ooooo0_l000000ooooooo0000o`00000Ho`0000_ooooo0_l00006ooooo`;o00003?ooool4
o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0000Gooooo0ol0000=ooooo`;o00000oooool2
o`0000;ooooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`17ooooo`;o00001Oooool2o`00
00_ooooo0_l00006ooooo`Go00002?ooool2o`0000Oooooo0_l0000=oooooaOo00004_ooool2o`00
013ooooo1?l00002ooooo`;o00003_ooool3o`0000kooooo0_l00006ooooo`;o0000EOooool001co
oooo00?o0000ooooooooool0Aoooool2o`0000?ooooo1_l00003ooooo`;o00004Oooool2o`0001ko
oooo2ol000000ooooooo0000o`000009o`000003ooooool0003o000000oooooo0_l00007ooooo`;o
00006oooool2o`0000Gooooo0_l000000ooooooo0000o`000007ooooo`;o000000?oooooo`000?l0
0000F_ooool001cooooo00?o0000ooooooooool0C?ooool2o`0000;ooooo1?l000001?oooooo0000
o`000?ooool2o`0000kooooo0_l0000LoooooaWo000000?oooooo`000?l000001oooool2o`0000oo
oooo0_l00002ooooo`;o00002_ooool3o`0000[ooooo0_l00005ooooo`;o000000?oooooo`000?l0
00002_ooool2o`0000oooooo0_l00019ooooo`007?ooool2o`0005?ooooo0_l00004ooooo`;o0000
5_ooool2o`0000kooooo0_l00004oooooaWo00002_ooool2o`0000Wooooo0ol00003ooooo`;o0000
00Coooooo`000?l0003o00002_ooool3o`0000[ooooo0_l0000Eooooo`;o00003_ooool4o`0004Oo
oooo000Looooo`03o`000?oooooooooo04gooooo0_l00003ooooo`;o00003Oooool2o`000003oooo
ool0003o000000[ooooo0_l0000>ooooo`?o00001ooooolBo`000004ooooool0003o0000o`0000co
oooo0_l00003ooooo`;o000000Coooooo`000?l0003o00000_ooool3o`000004ooooool0003o0000
ooooo`;o00001?ooool2o`0000Gooooo1_l00004ooooo`;o00000oooool2o`0000Cooooo0_l0000:
ooooo`;o00004?ooool2o`0004Oooooo000Looooo`03o`000?oooooooooo04Oooooo0_l00003oooo
o`?o00000oooool2o`0000[ooooo0_l000001?oooooo0000o`000?ooool2o`0000Sooooo0_l0000<
ooooo`;o00000oooool2o`0000Oooooo0_l000000ooooooo0000o`00000<o`0000;ooooo0ol00007
ooooo`;o00000oooool2o`0000?ooooo1?l00004ooooo`;o00001Oooool2o`0000Cooooo0_l00005
ooooo`Ko00002Oooool2o`0000;ooooo1?l00007ooooo`;o0000G?ooool001cooooo00?o0000oooo
ooooool0Aoooool2o`0000?ooooo0_l00006ooooo`;o00002?ooool2o`0000kooooo0_l0000<oooo
o`;o00002_ooool2o`0000Gooooo3?l00002ooooo`;o00001Oooool2o`000003ooooool0003o0000
00?ooooo0_l000001?oooooo0000o`000?ooool3o`0000;ooooo0_l00008ooooo`;o000000?ooooo
o`000?l000004_ooool2o`0000Kooooo1?l00007ooooo`;o0000G?ooool001cooooo00?o0000oooo
ooooool0DOooool2o`000003ooooool0003o000000;ooooo1_l00005ooooo`Co00008?ooool3o`00
00Cooooo2_l0000<ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`;o00001_ooool3
o`0000Oooooo1Ol00005ooooo`Co00002Oooool2o`0000Sooooo0ol00005ooooo`;o0000GOooool0
01cooooo00?o0000ooooooooool0DOooool2o`0000Gooooo1ol00004ooooo`Co00006Oooool2o`00
00Gooooo0_l00005ooooo`?o00000oooool2o`0001;ooooo1Ol0000:ooooo`?o00002?ooool3o`00
00;ooooo0_l00002ooooo`Co00005?ooool2o`0000Cooooo0ol00006ooooo`;o000000?oooooo`00
0?l00000D_ooool001cooooo00?o0000ooooooooool0EOooool2o`0000Kooooo0_l000001?oooooo
0000o`000?l0000Iooooo`;o00000_ooool2o`0000?ooooo1?l0000;ooooo`Co00001oooool2o`00
00Oooooo0_l000000ooooooo0000o`000009ooooo`Co00001Oooool2o`0000;ooooo0_l00002oooo
o`;o00001oooool2o`0000;ooooo1?l000000ooooooo0000o`00000>ooooo`;o00001oooool2o`00
0003ooooool0003o000005;ooooo000Looooo`03o`000?oooooooooo04Wooooo0_l00003ooooo`;o
00001Oooool2o`0000;ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00006Oooool2o`00
00Gooooo1?l0000?ooooo`;o00001oooool2o`0000Gooooo0_l00007ooooo`Co000000?oooooo`00
0?l000000_l00005ooooo`Co00003?ooool2o`000003ooooool0003o000000;ooooo1?l000000ooo
oooo0000o`00001^ooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00000oooool2o`0000;o
oooo0_l00005ooooo`;o00009_ooool4o`00027ooooo0_l00007ooooo`Oo00001oooool2o`000003
ooooool0003o000000;ooooo1Ol00004ooooo`;o000000?oooooo`000?l000000oooool3o`0001?o
oooo0_l0001Looooo`007?ooool00ol0003oooooooooo`1Booooo`;o00002_ooool2o`0000Sooooo
0_l00006ooooo`;o00000_ooool2o`0000_ooooo1?l0000/ooooo`Co00002oooool2o`0000;ooooo
1Ol0000<ooooo`?o000000?oooooo`000?l000004?ooool2o`0005cooooo000Looooo`03o`000?oo
oooooooo05kooooo0_l00008ooooo`;o000000?oooooo`000?l000000oooool2o`000004ooooool0
003o0000o`0000cooooo0ol0000;ooooo`;o00004oooool2o`0000[ooooo1?l00009ooooo`;o0000
1?ooool4o`0000?ooooo0_l0000;ooooo`?o00000_ooool2o`0006[ooooo000Looooo`03o`000?oo
oooooooo05Wooooo0_l00003ooooo`;o00002oooool2o`0000Kooooo0_l0000=ooooo`;o00002_oo
ool4o`000003ooooool0003o000000;o00000oooool2o`0000Wooooo0_l0000<ooooo`;o00002Ooo
ool2o`0000Cooooo1_l000000ooooooo0000o`00000;ooooo`;o00000oooool2o`000003ooooool0
003o000006Oooooo000Looooo`03o`000?oooooooooo05Wooooo1?l00005ooooo`?o000000?ooooo
o`000?l000000oooool2o`0001Oooooo1?l00002ooooo`;o00000_ooool2o`0000?ooooo1?l00003
ooooo`;o0000;?ooool2o`000003ooooool0003o0000013ooooo0_l000000ooooooo0000o`000003
ooooo`;o0000H_ooool001cooooo00?o0000ooooooooool0D?ooool2o`0000Wooooo0_l000000ooo
oooo0000o`000002ooooo`Ko00000oooool2o`0000Gooooo0_l0000@ooooo`Go000000?oooooo`00
0?l00000=Oooool2o`0000[ooooo0_l0000>ooooo`;o00000_ooool6o`0006;ooooo000Looooo`03
o`000?oooooooooo053ooooo0_l0000<ooooo`;o00001?ooool2o`0000Gooooo0_l00005ooooo`;o
00004oooool2o`0003Sooooo0_l000000ooooooo0000o`000007ooooo`;o00001Oooool2o`000003
ooooool0003o000000;ooooo0_l00004ooooo`Co00004oooool2o`0004oooooo000Looooo`03o`00
0?oooooooooo063ooooo0_l000000ooooooo0000o`000006ooooo`;o00003Oooool2o`000003oooo
ool0003o000001Gooooo0_l00004ooooo`;o00005_ooool2o`0000Oooooo0ol00006ooooo`;o0000
3_ooool9o`0000Cooooo0_l0000Eooooo`;o0000Coooool001cooooo0_l0001Qooooo`;o000000Co
ooooo`000?l0003ooooo1Ol0000:ooooo`;o00000oooool2o`000003ooooool0003o000000Wooooo
0ol00008ooooo`?o00001?ooool2o`0001Kooooo1?l00005ooooo`?o00005oooool2o`0000;ooooo
0ol00005ooooo`?o0000IOooool001cooooo00?o0000ooooooooool0E_ooool2o`0000kooooo1Ol0
0008ooooo`Co00004Oooool3o`0000Sooooo0_l0000Oooooo`;o00001?ooool2o`000003ooooool0
003o000000cooooo0ol00005ooooo`;o00001Oooool2o`0000;ooooo0_l000000ooooooo0000o`00
0002o`0006Cooooo000Looooo`03o`000?oooooooooo05Kooooo0_l0000?ooooo`Co00002?ooool2
o`0000kooooo0_l0000:ooooo`;o000000?oooooo`000?l000009?ooool7o`0000Gooooo0_l00005
ooooo`?o00001Oooool2o`0000Oooooo1?l00003ooooo`;o0000I?ooool001cooooo00?o0000oooo
ooooool0Ioooool7o`0000cooooo0_l00007ooooo`;o00002_ooool2o`000003ooooool0003o0000
00Gooooo0ol0000Dooooo`;o00001_ooool2o`000004ooooool0003o0000ooooo`;o00001?ooool2
o`0001Kooooo1?l0001Yooooo`007?ooool00ol0003oooooooooo`1Zooooo`Co00002_ooool4o`00
01;ooooo0ol000000ooooooo0000o`000005ooooo`?o00005?ooool2o`0000Kooooo0_l00004oooo
o`;o00005?ooool2o`0000Cooooo1_l0001Yooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o
00000oooool2o`000003ooooool0003o000000;o00003?ooool2o`0001?ooooo1?l00003ooooo`;o
00005Oooool2o`0000Oooooo0_l000001?oooooo0000o`000?l00004ooooo`;o00004Oooool2o`00
0004ooooool0003o0000o`0000;ooooo0ol00002ooooo`;o0000JOooool001cooooo00?o0000oooo
ooooool0H?ooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l0000Koooo
o`;o00001Oooool5o`0001;ooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l00002
ooooo`;o000000?oooooo`000?l000003?ooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool2
o`0000;ooooo0_l0001Zooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o00000oooool2o`00
00Cooooo0_l00003ooooo`;o00004oooool2o`0000Kooooo0_l00006ooooo`Co00006?ooool2o`00
00Sooooo0_l00006ooooo`;o00001oooool2o`0000gooooo1?l0001Zooooo`007?ooool00ol0003o
ooooooooo`1Pooooo`;o00000_ooool2o`0000Gooooo0_l0000Cooooo`;o00000oooool2o`000003
ooooool0003o000000cooooo0ol0000<ooooo`;o00001?ooool2o`0000Cooooo0_l00006ooooo`;o
00002?ooool2o`0000?ooooo0ol00005ooooo`;o00002Oooool3o`0006_ooooo000Looooo`03o`00
0?oooooooooo06Cooooo0_l0000=ooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000
o`000002o`0000Cooooo0ol00009ooooo`Co00000_ooool3o`000003ooooool0003o000000;o0000
0oooool2o`0000Cooooo0_l00004ooooo`;o00001_ooool2o`0000gooooo0ol00003ooooo`Go0000
0_ooool4o`0000Kooooo0_l000000ooooooo0000o`00001Uooooo`007?ooool00ol0003ooooooooo
o`1Rooooo`;o00002Oooool2o`0000Cooooo0ol000000ooooooo0000o`000004ooooo`;o00000ooo
ool2o`0000Gooooo0_l00009ooooo`;o00001?ooool3o`000003ooooool0003o000000;o00006ooo
ool2o`0000oooooo0_l000001?oooooo0000o`000?ooool7o`0000Cooooo0_l000000ooooooo0000
o`000002o`0006?ooooo000Looooo`03o`000?oooooooooo06;ooooo0_l00006ooooo`;o000000?o
ooooo`000?l000001?ooool3o`0000Sooooo0_l0000Fooooo`;o00009Oooool2o`0001Gooooo0_l0
00000ooooooo0000o`000002o`0000Wooooo0_l0001Sooooo`007?ooool00ol0003oooooooooo`1U
ooooo`;o00000oooool2o`0001;ooooo0_l0000Aooooo`;o00000oooool2o`0000Oooooo0_l00007
ooooo`;o00007oooool2o`0000_ooooo0_l0001aooooo`007?ooool00ol0003oooooooooo`1Uoooo
o`;o000000?oooooo`000?l000003oooool2o`0000Cooooo1?l0000<ooooo`Co00000_ooool3o`00
00Kooooo0ol00007ooooo`;o00007_ooool3o`000003ooooool0003o000000Sooooo0_l0001aoooo
o`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<00Kooooo00?o0000ooooooooool0J?ooool2o`0000Sooooo0_l00005ooooo`;o00001?oo
ool4o`0000;ooooo0_l00008ooooo`;o00001?ooool2o`000003ooooool0003o000000Cooooo0ol0
0003ooooo`;o00002Oooool2o`0000Kooooo0_l0000?ooooo`;o00000_ooool2o`0000;ooooo0_l0
001gooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RH
oooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0J?ooool2o`0000Sooooo0_l00003ooooo`;o
00003?ooool2o`0000Oooooo0_l00008ooooo`;o00002_ooool2o`0000Cooooo0_l00003ooooo`;o
00001?ooool4o`0000Wooooo0_l0000:ooooo`Co0000Moooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool0Moooool2o`000003ooooool0003o000000_ooooo0_l00005ooooo`Go00001Oooool2o`0000?o
oooo0_l0000:ooooo`?o00002Oooool2o`0000_ooooo0_l00007ooooo`;o000000?oooooo`000?l0
0000NOooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Olb<S;oV9RH
oooooonHV9So<S8b00Kooooo0ol0001Xooooo`;o00004?ooool2o`0000Oooooo0ol000000ooooooo
0000o`000005ooooo`Oo00000oooool2o`0000?ooooo0_l00006ooooo`;o000000Coooooo`000?l0
003o00007oooool3o`000004ooooool0003o0000o`0007Sooooo00000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00Wooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooo
oooo06Sooooo0_l0000Iooooo`?o00000oooool2o`0000?ooooo0_l00003ooooo`;o00004?ooool2
o`000003ooooool0003o000000;ooooo0_l0000Eooooo`?o00001?ooool3o`0000;ooooo0_l0001h
ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooo
okZj^_l@41001_ooool00ol0003oooooooooo`20ooooo`;o00001oooool2o`0000[ooooo0_l0000;
ooooo`;o00000oooool3o`0000;ooooo0_l0000Eooooo`?o0000Poooool00006oooooomgMgOoV9RH
oooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0
KOooool2o`0000Kooooo0_l00009ooooo`Co00004Oooool2o`0000_ooooo0_l00003ooooo`?o0000
6_ooool2o`0008?ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@06ooooo`03o`000?oooooooooo06gooooo0_l00002ooooo`;o00000_ooool2o`00
00Kooooo0_l00002ooooo`?o00002_ooool2o`0000?ooooo0_l0000Eooooo`;o00005oooool2o`00
01gooooo0_l0001Uooooo`007?ooool00ol0003oooooooooo`1aooooo`;o00002_ooool2o`000003
ooooool0003o000000?o00002Oooool2o`0000?ooooo0_l0000>ooooo`;o00001Oooool2o`0000Wo
oooo0ol00003ooooo`;o00001_ooool2o`0001gooooo0_l0001Uooooo`007?ooool00ol0003ooooo
ooooo`20ooooo`Go00000oooool2o`0000Cooooo0_l0000Cooooo`;o00004?ooool3o`0000?ooooo
0_l0002<ooooo`007?ooool00ol0003oooooooooo`1booooo`;o00003oooool2o`000003ooooool0
003o000000;o00000oooool3o`0000Sooooo0_l0000Uooooo`;o0000R?ooool001cooooo00?o0000
ooooooooool0L_ooool2o`0000kooooo0ol000000ooooooo0000o`000005ooooo`?o00002?ooool2
o`0000;ooooo0_l0000Qooooo`;o00000oooool2o`0000?ooooo0_l0001nooooo`007?ooool00ol0
003oooooooooo`1hooooo`;o00001?ooool2o`0000;ooooo1?l00007ooooo`Co00002oooool2o`00
00Gooooo0ol00003ooooo`;o00006Oooool2o`0000?ooooo0_l0001nooooo`007?ooool00ol0003o
ooooooooo`1hooooo`Co00000_ooool2o`0000Cooooo0_l00007ooooo`Co00002oooool2o`0000Go
oooo0ol00003ooooo`;o00004Oooool2o`0000[ooooo0_l0001oooooo`007?ooool00ol0003ooooo
ooooo`1dooooo`;o00001?ooool2o`0000;ooooo0_l0000=ooooo`;o00003Oooool2o`0000Kooooo
0_l000000ooooooo0000o`000002o`0000Sooooo0_l00006ooooo`?o00001?ooool3o`0000?ooooo
0_l0001oooooo`007?ooool00ol0003oooooooooo`1dooooo`;o00001oooool3o`0000[ooooo0ol0
000Jooooo`Co00001Oooool2o`000003ooooool0003o000000;o00001?ooool2o`0000Gooooo0ol0
0003ooooo`;o0000Ooooool001cooooo00?o0000ooooooooool0OOooool2o`0000_ooooo0ol0000D
ooooo`Co00002oooool2o`0000?ooooo0_l0000Aooooo`;o0000Ooooool001cooooo00?o0000oooo
ooooool0R_ooool2o`0001Cooooo1Ol0000Looooo`;o0000Q_ooool001cooooo00?o0000oooooooo
ool0T_ooool2o`0000[ooooo1?l0000Dooooo`?o00002?ooool6o`0008;ooooo000Looooo`;o0000
Toooool3o`0000Oooooo1?l0000Fooooo`Co00002Oooool4o`0008;ooooo000Looooo`03o`000?oo
oooooooo08Cooooo0_l0000=ooooo`;o00001oooool4o`0001Sooooo0_l00006ooooo`;o0000Qooo
ool001cooooo00?o0000ooooooooool0Q?ooool2o`0001Oooooo0ol0000Kooooo`;o00000oooool2
o`0008Oooooo000Looooo`03o`000?oooooooooo07Wooooo0_l0000:ooooo`;o0000=?ooool2o`00
00?ooooo0_l00027ooooo`007?ooool00ol0003oooooooooo`1iooooo`;o00002_ooool2o`0003Wo
oooo0_l00027ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0W_ooool2o`00
00kooooo0_l0002Iooooo`007?ooool00ol0003oooooooooo`2Nooooo`;o00003?ooool4o`0009Wo
oooo000Looooo`03o`000?oooooooooo0:cooooo0_l0002Kooooo`007?ooool2o`000?ooooooBooo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001;ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oo
oooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
oooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo0ol0003ooooood[ooooo000Dooooo`03
o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?oo
ool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool0
01;ooooo00?oEEEEofIVI_l00000oooooomDooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00XOooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo01Kooooo1?l0
00000ol@413oooooooooo`02ooooo`;o000000?o410@ooooooooool00_ooool4o`000008oa0@4?oo
ooooooooonk^k_lb<S;o0000oa0@4?o<c<b<ooooo`00X_ooool01Ol0003ooooooooooooooooo0000
00Wooooo1_l0000<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`02ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40S?ooool00:;ooooo00Go0000oooo
ooooooooooooo`00000Kooooo`03o`000?oooooooooo00;ooooo1Ol00006ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`00002<ooooo`00X_ooool01Ol0003ooooooooooooo
oooo000000Wooooo1_l0000<ooooo`03o`000?oooooooooo00;ooooo00CoA4A4omgMgOoooooo0000
1oooool00ol0003oooooooooo`02ooooo`05o`000?nHV9SooooooiRHV?lQ8B40S?ooool00:;ooooo
00Go0000ohN7QoooooooZJVYo`00000Kooooo`03o`000?oooooooooo00;ooooo00CogMgMoeEEEOoo
oooo00001oooool00ol0003oooooooooo`02ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0S?ooool0
0:7ooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Iooooo`03o`000?oooooooooo
00?ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`02ooooo`03oeEEEOn7QhOooooo
08kooooo0032ooooo`03o`000?oooooooooo00?ooooo00?ok^k^odA4A?l000001oooool00ol0003o
ooooooooo`02ooooo`03omgMgOl@413oV9RH08kooooo0030ooooo`03oeEEEOmVIVKo000000Kooooo
00?oMgMgo`000?ooool01?ooool00omEEEGoIVIVo`000005ooooo`04olc<c?m4A4Co0000oa0@48co
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1422) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.55423 .38031 Mdot
.53446 .37151 Mdot
.36353 .53694 Mdot
.62339 .5842 Mdot
.44761 .79597 Mdot
.3283 .5447 Mdot
.39299 .33892 Mdot
.37593 .37602 Mdot
.37035 .53912 Mdot
.50867 .30648 Mdot
.3849 .4102 Mdot
.68938 .54023 Mdot
.40276 .38438 Mdot
.58982 .56319 Mdot
.77257 .72326 Mdot
.56827 .51167 Mdot
.553 .37884 Mdot
.47865 .68768 Mdot
.56104 .53691 Mdot
.32666 .56501 Mdot
.6128 .35452 Mdot
.59454 .5642 Mdot
.57914 .36326 Mdot
.58948 .56269 Mdot
.6328 .56624 Mdot
.5827 .35305 Mdot
.54849 .30719 Mdot
.64085 .54015 Mdot
.60392 .51697 Mdot
.3789 .40571 Mdot
.51642 .66792 Mdot
.6613 .78961 Mdot
.53833 .5771 Mdot
.67364 .71969 Mdot
.40552 .35759 Mdot
.72784 .46225 Mdot
.33811 .53681 Mdot
.38449 .39399 Mdot
.38963 .40164 Mdot
.37992 .3645 Mdot
.3803 .38083 Mdot
.56302 .35349 Mdot
.48594 .22701 Mdot
.35267 .44578 Mdot
.65201 .52065 Mdot
.30981 .73683 Mdot
.67425 .47137 Mdot
.58079 .58245 Mdot
.56752 .31758 Mdot
.30001 .61421 Mdot
.30367 .41727 Mdot
.41816 .35637 Mdot
.35002 .5771 Mdot
.33872 .16113 Mdot
.41377 .38626 Mdot
.67681 .58769 Mdot
.35013 .54094 Mdot
.60142 .55003 Mdot
.5879 .55745 Mdot
.72159 .34937 Mdot
.66454 .57917 Mdot
.43947 .69165 Mdot
.51626 .36262 Mdot
.45343 .53079 Mdot
.35559 .5523 Mdot
.39137 .40889 Mdot
.53241 .34908 Mdot
.41309 .37822 Mdot
.52843 .54338 Mdot
.3855 .51555 Mdot
.58425 .59023 Mdot
.38514 .40842 Mdot
.6094 .3469 Mdot
.6188 .52994 Mdot
.26312 .60439 Mdot
.27531 .71532 Mdot
.40452 .64008 Mdot
.7225 .43432 Mdot
.71708 .3412 Mdot
.32619 .66109 Mdot
.6424 .5231 Mdot
.51555 .72918 Mdot
.27628 .70768 Mdot
.57509 .30972 Mdot
.54978 .54811 Mdot
.4841 .63516 Mdot
.62392 .5335 Mdot
.38634 .80758 Mdot
.62747 .61224 Mdot
.48998 .57389 Mdot
.36936 .51897 Mdot
.57979 .32985 Mdot
.62892 .58175 Mdot
.59721 .523 Mdot
.75518 .366 Mdot
.5691 .58249 Mdot
.60947 .56765 Mdot
.55617 .3175 Mdot
.42055 .36155 Mdot
.66169 .59806 Mdot
.4112 .53062 Mdot
.32158 .51839 Mdot
.6575 .57445 Mdot
.36867 .50594 Mdot
.6062 .33806 Mdot
.59752 .52372 Mdot
.39657 .40106 Mdot
.64673 .58743 Mdot
.32019 .29141 Mdot
.55406 .37588 Mdot
.62593 .52352 Mdot
.42018 .64503 Mdot
.67136 .35502 Mdot
.58325 .32315 Mdot
.35906 .43849 Mdot
.56422 .53405 Mdot
.61486 .55709 Mdot
.53308 .34451 Mdot
.32549 .50741 Mdot
.35903 .78448 Mdot
.54555 .32079 Mdot
.38862 .42316 Mdot
.61594 .33756 Mdot
.69766 .56883 Mdot
.35623 .55983 Mdot
.35482 .44098 Mdot
.36867 .27229 Mdot
.54423 .68221 Mdot
.62285 .53611 Mdot
.50349 .2358 Mdot
.31351 .54201 Mdot
.5627 .33255 Mdot
.40943 .37737 Mdot
.55537 .59692 Mdot
.55029 .36446 Mdot
.39618 .41883 Mdot
.44734 .65857 Mdot
.28444 .36977 Mdot
.59206 .36583 Mdot
.51353 .4332 Mdot
.42915 .37653 Mdot
.39858 .34645 Mdot
.81289 .57512 Mdot
.54278 .33743 Mdot
.4184 .66877 Mdot
.4055 .36998 Mdot
.58551 .67491 Mdot
.65967 .52851 Mdot
.49613 .72091 Mdot
.42271 .1919 Mdot
.67391 .70418 Mdot
.26013 .43869 Mdot
.42344 .65215 Mdot
.43454 .37797 Mdot
.61914 .57366 Mdot
.59051 .34596 Mdot
.58002 .35874 Mdot
.66427 .57874 Mdot
.64369 .56672 Mdot
.58961 .59839 Mdot
.57035 .56274 Mdot
.52357 .60358 Mdot
.58239 .60917 Mdot
.66895 .45711 Mdot
.58431 .33238 Mdot
.61866 .58174 Mdot
.35792 .57364 Mdot
.63877 .49755 Mdot
.37845 .39445 Mdot
.6003 .55756 Mdot
.62558 .58226 Mdot
.66853 .55099 Mdot
.41172 .35058 Mdot
.62356 .80778 Mdot
.64619 .36814 Mdot
.60036 .79948 Mdot
.51682 .49629 Mdot
.38224 .55437 Mdot
.63088 .54153 Mdot
.43194 .68457 Mdot
.77018 .47804 Mdot
.61864 .59458 Mdot
.11469 .46836 Mdot
.60216 .56959 Mdot
.50728 .81935 Mdot
.58856 .48224 Mdot
.63073 .76914 Mdot
.52661 .71406 Mdot
.62887 .56157 Mdot
.52645 .26578 Mdot
.38893 .332 Mdot
.40042 .56105 Mdot
.38494 .37758 Mdot
.35262 .57359 Mdot
.35921 .53956 Mdot
.43241 .55407 Mdot
.68942 .53314 Mdot
.61167 .49342 Mdot
.60013 .60809 Mdot
.36085 .49177 Mdot
.52645 .3305 Mdot
.42602 .64256 Mdot
.52964 .37713 Mdot
.55456 .85702 Mdot
.25503 .57555 Mdot
.36845 .38104 Mdot
.45456 .66154 Mdot
.34961 .50749 Mdot
.37351 .52437 Mdot
.42838 .64705 Mdot
.58655 .53473 Mdot
.54195 .3411 Mdot
.76497 .6448 Mdot
.27402 .32904 Mdot
.85356 .39852 Mdot
.56319 .31539 Mdot
.50527 .25626 Mdot
.37421 .38586 Mdot
.34305 .52596 Mdot
.61381 .56007 Mdot
.59891 .53316 Mdot
.60772 .3679 Mdot
.58238 .58921 Mdot
.62093 .37177 Mdot
.62228 .55926 Mdot
.41826 .3274 Mdot
.39875 .65117 Mdot
.43247 .5556 Mdot
.5831 .6968 Mdot
.59788 .32551 Mdot
.80984 .45075 Mdot
.37836 .52922 Mdot
.76957 .467 Mdot
.39721 .41221 Mdot
.45068 .67546 Mdot
.37397 .55601 Mdot
.41571 .64497 Mdot
.56712 .59133 Mdot
.33042 .56318 Mdot
.40767 .66047 Mdot
.49709 .61988 Mdot
.63909 .50612 Mdot
.26581 .29918 Mdot
.38383 .362 Mdot
.54399 .38186 Mdot
.64155 .59539 Mdot
.38094 .52206 Mdot
.56399 .61235 Mdot
.23624 .5105 Mdot
.32256 .34216 Mdot
.31237 .54382 Mdot
.4331 .59393 Mdot
.44838 .68783 Mdot
.29291 .4541 Mdot
.49966 .24167 Mdot
.53485 .37454 Mdot
.5727 .59303 Mdot
.67606 .76609 Mdot
.40617 .37043 Mdot
.63612 .59512 Mdot
.43138 .75856 Mdot
.41418 .36446 Mdot
.60293 .54847 Mdot
.40672 .41903 Mdot
.5793 .35927 Mdot
.69082 .30772 Mdot
.5347 .34007 Mdot
.57804 .58663 Mdot
.40412 .39786 Mdot
.33076 .49871 Mdot
.57798 .34943 Mdot
.57877 .54462 Mdot
.63928 .54164 Mdot
.45874 .57683 Mdot
.61009 .58064 Mdot
.58587 .81532 Mdot
.62593 .56019 Mdot
.35521 .52675 Mdot
.65409 .53411 Mdot
.61793 .23766 Mdot
.42951 .54978 Mdot
.53575 .3444 Mdot
.31062 .54611 Mdot
.36375 .54667 Mdot
.26721 .64836 Mdot
.43435 .40262 Mdot
.58599 .51469 Mdot
.38371 .53355 Mdot
.66015 .66346 Mdot
.42053 .3988 Mdot
.65367 .59364 Mdot
.48527 .41805 Mdot
.2938 .60039 Mdot
.34208 .57501 Mdot
.65932 .6323 Mdot
.60248 .35365 Mdot
.63518 .57817 Mdot
.36847 .51209 Mdot
.70521 .55819 Mdot
.61551 .51496 Mdot
.49481 .19755 Mdot
.45352 .58914 Mdot
.42662 .37345 Mdot
.65196 .50209 Mdot
.61015 .60326 Mdot
.33178 .56106 Mdot
.59837 .33099 Mdot
.42438 .39361 Mdot
.56889 .35246 Mdot
.63574 .76007 Mdot
.27446 .2983 Mdot
.50199 .59963 Mdot
.4019 .65369 Mdot
.38534 .61217 Mdot
.64392 .76231 Mdot
.77109 .34374 Mdot
.79524 .53901 Mdot
.70793 .70738 Mdot
.35736 .50122 Mdot
.36314 .62101 Mdot
.35747 .54547 Mdot
.64874 .55324 Mdot
.35273 .55822 Mdot
.68975 .76049 Mdot
.61954 .5615 Mdot
.34219 .55264 Mdot
.79207 .41498 Mdot
.63083 .57726 Mdot
.53111 .37142 Mdot
.54313 .84488 Mdot
.65471 .22931 Mdot
.34244 .32834 Mdot
.33502 .51932 Mdot
.76713 .60706 Mdot
.60963 .56969 Mdot
.6538 .53468 Mdot
.59192 .3358 Mdot
.54905 .59697 Mdot
.42531 .69076 Mdot
.45644 .66831 Mdot
.35649 .37202 Mdot
.39246 .65257 Mdot
.65723 .50603 Mdot
.58016 .34728 Mdot
.5188 .58386 Mdot
.27519 .64016 Mdot
.30835 .61403 Mdot
.36478 .37318 Mdot
.54252 .844 Mdot
.53611 .40924 Mdot
.46395 .34839 Mdot
.28011 .5321 Mdot
.56627 .3225 Mdot
.65093 .79841 Mdot
.38497 .38204 Mdot
.23393 .33121 Mdot
.54104 .26977 Mdot
.58905 .53563 Mdot
.41544 .39882 Mdot
.61575 .63107 Mdot
.67006 .24288 Mdot
.19811 .40474 Mdot
.71756 .53188 Mdot
.63402 .60947 Mdot
.26719 .58746 Mdot
.60561 .55888 Mdot
.24939 .54853 Mdot
.63186 .55593 Mdot
.56714 .34882 Mdot
.50787 .30545 Mdot
.34419 .4016 Mdot
.63738 .35103 Mdot
.28576 .47005 Mdot
.41907 .65324 Mdot
.62138 .55658 Mdot
.58694 .5378 Mdot
.41866 .68973 Mdot
.58436 .36494 Mdot
.58297 .59331 Mdot
.80982 .43597 Mdot
.58824 .52607 Mdot
.37954 .39086 Mdot
.59021 .25531 Mdot
.61121 .4434 Mdot
.56714 .54597 Mdot
.59352 .31051 Mdot
.37245 .36316 Mdot
.40184 .39672 Mdot
.61304 .4819 Mdot
.37354 .40109 Mdot
.59865 .57731 Mdot
.18906 .43401 Mdot
.58207 .37313 Mdot
.41904 .2113 Mdot
.54374 .35572 Mdot
.7104 .41854 Mdot
.4163 .35937 Mdot
.30133 .35778 Mdot
.63747 .62843 Mdot
.3885 .38352 Mdot
.60646 .29641 Mdot
.60725 .50132 Mdot
.61059 .4991 Mdot
.76427 .63481 Mdot
.35666 .51816 Mdot
.45389 .577 Mdot
.37905 .40654 Mdot
.58061 .56805 Mdot
.56101 .55565 Mdot
.37309 .36408 Mdot
.22292 .39286 Mdot
.69978 .28054 Mdot
.62344 .56039 Mdot
.56657 .34144 Mdot
.55883 .33565 Mdot
.66862 .5335 Mdot
.6544 .57409 Mdot
.36319 .56454 Mdot
.32078 .50731 Mdot
.38116 .56471 Mdot
.44967 .58126 Mdot
.31393 .34371 Mdot
.39725 .78835 Mdot
.38052 .36379 Mdot
.47669 .27114 Mdot
.49143 .59226 Mdot
.61575 .61418 Mdot
.33124 .51839 Mdot
.60806 .60163 Mdot
.6054 .58812 Mdot
.43298 .4149 Mdot
.46352 .78993 Mdot
.50477 .38071 Mdot
.60186 .33051 Mdot
.4299 .36606 Mdot
.64093 .4926 Mdot
.46668 .38133 Mdot
.4471 .67737 Mdot
.68403 .68532 Mdot
.39238 .41235 Mdot
.52734 .36365 Mdot
.39244 .35895 Mdot
.59928 .52942 Mdot
.63737 .62238 Mdot
.56224 .32516 Mdot
.4352 .69735 Mdot
.54377 .58207 Mdot
.60626 .54937 Mdot
.38585 .19624 Mdot
.63534 .68794 Mdot
.41575 .32055 Mdot
.62627 .56252 Mdot
.58429 .52186 Mdot
.44587 .70533 Mdot
.58987 .52632 Mdot
.61456 .6085 Mdot
.67273 .36603 Mdot
.39628 .28061 Mdot
.44702 .64563 Mdot
.19824 .42757 Mdot
.56117 .31658 Mdot
.66173 .77655 Mdot
.32772 .52965 Mdot
.34893 .3884 Mdot
.67083 .26747 Mdot
.35766 .57846 Mdot
.25532 .44708 Mdot
.65068 .7837 Mdot
.41011 .51822 Mdot
.35622 .59421 Mdot
.51245 .34276 Mdot
.57424 .5746 Mdot
.61289 .55427 Mdot
.42944 .68624 Mdot
.54396 .34355 Mdot
.48494 .5086 Mdot
.20711 .627 Mdot
.59681 .56476 Mdot
.47998 .20092 Mdot
.20231 .48658 Mdot
.28952 .60284 Mdot
.4345 .6734 Mdot
.45835 .67372 Mdot
.62072 .55471 Mdot
.65896 .35113 Mdot
.58317 .35204 Mdot
.5788 .54606 Mdot
.58605 .61079 Mdot
.34705 .51692 Mdot
.55973 .37468 Mdot
.32443 .50874 Mdot
.29233 .41457 Mdot
.58057 .80665 Mdot
.22336 .31518 Mdot
.41949 .3786 Mdot
.23188 .57614 Mdot
.41619 .40946 Mdot
.52208 .72945 Mdot
.34689 .58386 Mdot
.64147 .57936 Mdot
.59945 .3381 Mdot
.58318 .57528 Mdot
.65185 .57491 Mdot
.58565 .53649 Mdot
.56526 .55461 Mdot
.24963 .27517 Mdot
.41839 .65097 Mdot
.55516 .57922 Mdot
.35924 .52993 Mdot
.28939 .7148 Mdot
.24949 .66586 Mdot
.587 .54127 Mdot
.63443 .54899 Mdot
.56783 .37016 Mdot
.65587 .58636 Mdot
.42073 .40365 Mdot
.52182 .36473 Mdot
.61296 .52506 Mdot
.47871 .84071 Mdot
.60698 .51613 Mdot
.62555 .78112 Mdot
.39179 .3606 Mdot
.28493 .31325 Mdot
.62364 .62479 Mdot
.32779 .34222 Mdot
.45407 .57712 Mdot
.37213 .56024 Mdot
.41521 .41685 Mdot
.33821 .53956 Mdot
.19398 .59677 Mdot
.68623 .59318 Mdot
.62281 .57223 Mdot
.60613 .61207 Mdot
.3825 .55396 Mdot
.41731 .82702 Mdot
.30457 .4644 Mdot
.68537 .59987 Mdot
.35829 .56986 Mdot
.55453 .30857 Mdot
.71847 .66455 Mdot
.5551 .35558 Mdot
.40353 .69054 Mdot
.3757 .38429 Mdot
.43504 .69609 Mdot
.5463 .77046 Mdot
.54728 .37497 Mdot
.58291 .38879 Mdot
.32975 .52976 Mdot
.51739 .30412 Mdot
.62268 .16438 Mdot
.54147 .26846 Mdot
.54792 .70327 Mdot
.58656 .34176 Mdot
.60056 .51863 Mdot
.52444 .75212 Mdot
.52762 .28208 Mdot
.34029 .54231 Mdot
.60644 .59483 Mdot
.69063 .30238 Mdot
.36393 .56441 Mdot
.63379 .61697 Mdot
.36129 .5258 Mdot
.38596 .37245 Mdot
.33823 .51327 Mdot
.60814 .37603 Mdot
.62902 .53138 Mdot
.64975 .16771 Mdot
.40239 .61694 Mdot
.61334 .57068 Mdot
.42408 .35448 Mdot
.24165 .41113 Mdot
.63319 .58975 Mdot
.4041 .65967 Mdot
.34097 .5584 Mdot
.52237 .30601 Mdot
.62681 .5585 Mdot
.3573 .5706 Mdot
.56549 .38416 Mdot
.43434 .3629 Mdot
.74911 .36071 Mdot
.36845 .32003 Mdot
.59271 .33272 Mdot
.54481 .45365 Mdot
.41262 .42585 Mdot
.58214 .52343 Mdot
.56873 .58328 Mdot
.56258 .34055 Mdot
.45828 .72462 Mdot
.66214 .55589 Mdot
.64826 .52904 Mdot
.34754 .5209 Mdot
.33541 .54255 Mdot
.7876 .53805 Mdot
.33368 .50183 Mdot
.6271 .6226 Mdot
.56107 .34249 Mdot
.62731 .58354 Mdot
.56879 .37288 Mdot
.65522 .58644 Mdot
.5989 .47218 Mdot
.58527 .3641 Mdot
.44397 .39415 Mdot
.607 .59242 Mdot
.53713 .55165 Mdot
.64331 .5897 Mdot
.57288 .56672 Mdot
.36322 .56155 Mdot
.43615 .6806 Mdot
.60125 .61414 Mdot
.44895 .6329 Mdot
.43098 .64415 Mdot
.33776 .36023 Mdot
.34985 .51656 Mdot
.41377 .66682 Mdot
.19066 .5111 Mdot
.34088 .57007 Mdot
.42484 .68653 Mdot
.25078 .6684 Mdot
.40677 .35649 Mdot
.60366 .35348 Mdot
.63375 .57528 Mdot
.61232 .7554 Mdot
.65852 .46038 Mdot
.31276 .56705 Mdot
.62257 .56301 Mdot
.63148 .59659 Mdot
.54781 .31699 Mdot
.21169 .66455 Mdot
.38622 .51776 Mdot
.60126 .51267 Mdot
.53543 .36919 Mdot
.21682 .69833 Mdot
.35558 .53309 Mdot
.42933 .68877 Mdot
.4008 .35199 Mdot
.53249 .31466 Mdot
.36364 .27156 Mdot
.40892 .3428 Mdot
.35355 .47565 Mdot
.29918 .4098 Mdot
.55617 .55481 Mdot
.32337 .52387 Mdot
.84954 .47274 Mdot
.53992 .61895 Mdot
.45393 .54707 Mdot
.7587 .61778 Mdot
.57495 .32235 Mdot
.41753 .40769 Mdot
.42369 .65106 Mdot
.57215 .31398 Mdot
.55627 .37951 Mdot
.37515 .36421 Mdot
.64865 .38197 Mdot
.48207 .41529 Mdot
.38492 .39907 Mdot
.64137 .7145 Mdot
.38883 .75712 Mdot
.32728 .52136 Mdot
.42398 .69005 Mdot
.52421 .78013 Mdot
.5659 .35428 Mdot
.58496 .84535 Mdot
.77258 .63013 Mdot
.60923 .56782 Mdot
.41899 .66053 Mdot
.41791 .81784 Mdot
.23719 .6879 Mdot
.41632 .36506 Mdot
.34205 .37633 Mdot
.44342 .69353 Mdot
.63813 .59714 Mdot
.67201 .67537 Mdot
.6536 .54481 Mdot
.37727 .37725 Mdot
.77174 .39843 Mdot
.54882 .37665 Mdot
.38782 .3516 Mdot
.69714 .68179 Mdot
.59732 .57584 Mdot
.60981 .59369 Mdot
.60193 .71299 Mdot
.57827 .31266 Mdot
.37278 .55999 Mdot
.56243 .57899 Mdot
.60413 .55267 Mdot
.6428 .61838 Mdot
.67529 .5384 Mdot
.67957 .33568 Mdot
.64461 .55336 Mdot
.25134 .60087 Mdot
.6369 .6063 Mdot
.59418 .58431 Mdot
.59897 .31481 Mdot
.19824 .34114 Mdot
.30252 .4302 Mdot
.6021 .5562 Mdot
.59008 .51738 Mdot
.38964 .35194 Mdot
.46404 .40859 Mdot
.49324 .34337 Mdot
.52106 .31014 Mdot
.78305 .57458 Mdot
.63741 .50403 Mdot
.53319 .35201 Mdot
.40571 .66531 Mdot
.58518 .51641 Mdot
.53123 .35952 Mdot
.66515 .54188 Mdot
.36635 .5648 Mdot
.34438 .57167 Mdot
.52067 .57747 Mdot
.412 .6661 Mdot
.57377 .23252 Mdot
.47314 .27064 Mdot
.33475 .56474 Mdot
.6264 .57069 Mdot
.40397 .32676 Mdot
.37108 .51626 Mdot
.41527 .54739 Mdot
.44592 .7452 Mdot
.59257 .34646 Mdot
.58372 .32996 Mdot
.4916 .72372 Mdot
.27065 .42086 Mdot
.49361 .18589 Mdot
.38451 .37245 Mdot
.56206 .59184 Mdot
.52362 .25229 Mdot
.58593 .32758 Mdot
.52868 .74015 Mdot
.41633 .66073 Mdot
.4129 .36369 Mdot
.30935 .4818 Mdot
.55723 .3658 Mdot
.58045 .38186 Mdot
.66742 .5792 Mdot
.60197 .54184 Mdot
.7995 .52396 Mdot
.45558 .63786 Mdot
.39612 .33846 Mdot
.42753 .6908 Mdot
.34255 .58218 Mdot
.64485 .53697 Mdot
.58383 .36266 Mdot
.38009 .76252 Mdot
.57145 .52679 Mdot
.3713 .54742 Mdot
.57733 .32491 Mdot
.44978 .68715 Mdot
.40286 .66633 Mdot
.57024 .55638 Mdot
.79451 .48177 Mdot
.38687 .3918 Mdot
.55321 .32604 Mdot
.47285 .36167 Mdot
.65699 .55093 Mdot
.61029 .54207 Mdot
.55861 .49815 Mdot
.39754 .33848 Mdot
.44425 .31413 Mdot
.4074 .64867 Mdot
.54816 .33811 Mdot
.64138 .55207 Mdot
.4176 .68369 Mdot
.48781 .27058 Mdot
.31663 .56112 Mdot
.34181 .51103 Mdot
.40391 .67265 Mdot
.43143 .66461 Mdot
.40825 .65063 Mdot
.58753 .8454 Mdot
.53087 .3329 Mdot
.53886 .41231 Mdot
.61564 .50614 Mdot
.5333 .70863 Mdot
.55426 .58203 Mdot
.4284 .38384 Mdot
.36022 .51969 Mdot
.64282 .58445 Mdot
.56984 .54136 Mdot
.58388 .48134 Mdot
.44648 .20119 Mdot
.59075 .44099 Mdot
.55988 .377 Mdot
.63631 .6233 Mdot
.33529 .52081 Mdot
.57815 .86184 Mdot
.78918 .63106 Mdot
.62812 .62485 Mdot
.48516 .41034 Mdot
.59132 .35784 Mdot
.37999 .36315 Mdot
.59011 .73735 Mdot
.40333 .35522 Mdot
.55302 .3344 Mdot
.64646 .54908 Mdot
.46667 .28814 Mdot
.45006 .70554 Mdot
.57825 .56897 Mdot
.38252 .36917 Mdot
.58468 .58965 Mdot
.40014 .33945 Mdot
.60514 .76632 Mdot
.83607 .47412 Mdot
.60313 .56896 Mdot
.5584 .53277 Mdot
.81196 .50793 Mdot
.58401 .54636 Mdot
.46663 .69975 Mdot
.59202 .35736 Mdot
.77689 .39905 Mdot
.58883 .49844 Mdot
.70342 .63631 Mdot
.6555 .5437 Mdot
.75801 .35998 Mdot
.60817 .5392 Mdot
.28468 .60195 Mdot
.62872 .52658 Mdot
.60975 .60895 Mdot
.41366 .38969 Mdot
.38998 .35016 Mdot
.61011 .33361 Mdot
.37542 .51248 Mdot
.61641 .78988 Mdot
.6085 .54694 Mdot
.30888 .36164 Mdot
.40736 .29252 Mdot
.43309 .66727 Mdot
.55046 .33885 Mdot
.25136 .73064 Mdot
.38479 .41699 Mdot
.80484 .57479 Mdot
.77522 .56741 Mdot
.40978 .25559 Mdot
.4714 .77827 Mdot
.22454 .44368 Mdot
.44967 .68247 Mdot
.66832 .55316 Mdot
.37517 .70759 Mdot
.28021 .60096 Mdot
.44338 .73522 Mdot
.41545 .41961 Mdot
.77928 .49406 Mdot
.43196 .77159 Mdot
.40599 .68799 Mdot
.45473 .68591 Mdot
.41514 .35112 Mdot
.3645 .59859 Mdot
.69233 .54162 Mdot
.42434 .65692 Mdot
.38347 .55529 Mdot
.33387 .56892 Mdot
.38717 .55112 Mdot
.5833 .35502 Mdot
.78943 .61933 Mdot
.39405 .4323 Mdot
.42678 .37907 Mdot
.36417 .60483 Mdot
.72403 .58851 Mdot
.54288 .38838 Mdot
.33768 .52936 Mdot
.33694 .50585 Mdot
.59443 .35759 Mdot
.67703 .57989 Mdot
.68772 .56857 Mdot
.59917 .56087 Mdot
.43265 .68287 Mdot
.60219 .53697 Mdot
.35474 .56851 Mdot
.4176 .37331 Mdot
.34453 .50551 Mdot
.42098 .34868 Mdot
.36865 .76756 Mdot
.57555 .54426 Mdot
.63138 .53132 Mdot
.3387 .22527 Mdot
.59911 .36966 Mdot
.30861 .7293 Mdot
.44944 .36111 Mdot
.35789 .54324 Mdot
.61569 .60806 Mdot
.52239 .37267 Mdot
.46545 .65998 Mdot
.22648 .31884 Mdot
.65867 .56931 Mdot
.56859 .36209 Mdot
.64447 .53957 Mdot
.54707 .63568 Mdot
.56064 .19708 Mdot
.55998 .34911 Mdot
.46073 .18944 Mdot
.59931 .51584 Mdot
.2041 .52524 Mdot
.64547 .60021 Mdot
.51208 .62885 Mdot
.66207 .55593 Mdot
.56026 .31656 Mdot
.59778 .5569 Mdot
.52276 .37059 Mdot
.32393 .55288 Mdot
.38745 .35623 Mdot
.59085 .33268 Mdot
.56602 .56978 Mdot
.55008 .07807 Mdot
.39367 .36757 Mdot
.61732 .55838 Mdot
.41184 .35245 Mdot
.54124 .34793 Mdot
.572 .31744 Mdot
.23233 .66249 Mdot
.29063 .41786 Mdot
.38761 .37266 Mdot
.64469 .53758 Mdot
.22286 .53581 Mdot
.64488 .57066 Mdot
.66585 .66491 Mdot
.67578 .58993 Mdot
.64673 .52319 Mdot
.25809 .68805 Mdot
.42676 .3718 Mdot
.49231 .18394 Mdot
.25072 .69295 Mdot
.28652 .7122 Mdot
.61327 .35557 Mdot
.40852 .68949 Mdot
.64125 .80194 Mdot
.31613 .3413 Mdot
.36609 .56866 Mdot
.63958 .58822 Mdot
.6263 .31487 Mdot
.38994 .3963 Mdot
.44454 .67699 Mdot
.60405 .56811 Mdot
.33422 .51006 Mdot
.74394 .31823 Mdot
.43377 .37492 Mdot
.55823 .35217 Mdot
.55775 .30938 Mdot
.16123 .49694 Mdot
.63201 .55919 Mdot
.62442 .52844 Mdot
.3755 .38354 Mdot
.22944 .41115 Mdot
.44655 .65185 Mdot
.7903 .40916 Mdot
.38969 .37292 Mdot
.47708 .47996 Mdot
.52907 .35819 Mdot
.62716 .59966 Mdot
.48504 .82927 Mdot
.29069 .49519 Mdot
.36937 .2162 Mdot
.43072 .68381 Mdot
.65838 .66624 Mdot
.55895 .31748 Mdot
.40778 .37477 Mdot
.26757 .3952 Mdot
.62206 .49795 Mdot
.60102 .59802 Mdot
.58457 .66258 Mdot
.33894 .38365 Mdot
.50079 .35804 Mdot
.65819 .56452 Mdot
.45205 .57423 Mdot
.65725 .57672 Mdot
.56253 .51173 Mdot
.67348 .60208 Mdot
.61941 .53925 Mdot
.57789 .3639 Mdot
.66821 .64215 Mdot
.38089 .54812 Mdot
.52397 .39486 Mdot
.46962 .48801 Mdot
.61695 .56632 Mdot
.64146 .52509 Mdot
.70225 .50558 Mdot
.24106 .46531 Mdot
.58887 .33391 Mdot
.59258 .38576 Mdot
.37952 .41227 Mdot
.68371 .56978 Mdot
.37332 .51101 Mdot
.54832 .58192 Mdot
.36525 .55814 Mdot
.58124 .36272 Mdot
.35669 .5395 Mdot
.40061 .34922 Mdot
.32058 .52998 Mdot
.31088 .34678 Mdot
.40309 .36541 Mdot
.59405 .34106 Mdot
.61376 .52826 Mdot
.42493 .35511 Mdot
.56219 .68342 Mdot
.43051 .68223 Mdot
.33273 .79633 Mdot
.61298 .52449 Mdot
.38081 .27778 Mdot
.68796 .51647 Mdot
.34068 .50533 Mdot
.5451 .1908 Mdot
.60236 .33759 Mdot
.45503 .65399 Mdot
.58824 .31462 Mdot
.68785 .67882 Mdot
.42628 .66985 Mdot
.30978 .764 Mdot
.46605 .59925 Mdot
.63772 .68513 Mdot
.68038 .56027 Mdot
.6063 .70084 Mdot
.33923 .5767 Mdot
.39235 .39644 Mdot
.26297 .41395 Mdot
.60882 .60736 Mdot
.79627 .36099 Mdot
.59064 .31181 Mdot
.37912 .52019 Mdot
.41085 .37929 Mdot
.42647 .39039 Mdot
.60044 .50766 Mdot
.32723 .63795 Mdot
.59959 .59923 Mdot
.27946 .405 Mdot
.76585 .60403 Mdot
.56365 .41593 Mdot
.62178 .55928 Mdot
.3305 .56007 Mdot
.64458 .53984 Mdot
.40639 .64785 Mdot
.82529 .55417 Mdot
.53912 .5647 Mdot
.44051 .33816 Mdot
.46629 .64808 Mdot
.54226 .33451 Mdot
.6391 .47913 Mdot
.40348 .31832 Mdot
.63491 .5588 Mdot
.21484 .28461 Mdot
.42137 .6851 Mdot
.37384 .70016 Mdot
.56609 .53932 Mdot
.58173 .51697 Mdot
.44018 .51943 Mdot
.36409 .26467 Mdot
.26603 .55204 Mdot
.58466 .55625 Mdot
.54359 .66229 Mdot
.42309 .36045 Mdot
.64556 .59132 Mdot
.61497 .55483 Mdot
.6551 .42187 Mdot
.43144 .37983 Mdot
.36633 .54042 Mdot
.35815 .57922 Mdot
.309 .55881 Mdot
.41638 .64027 Mdot
.48537 .3449 Mdot
.54328 .72528 Mdot
.69367 .26413 Mdot
.46078 .67836 Mdot
.57276 .53729 Mdot
.38992 .62286 Mdot
.64938 .54582 Mdot
.44274 .67176 Mdot
.432 .37856 Mdot
.58917 .32726 Mdot
.51563 .25988 Mdot
.35523 .57657 Mdot
.61863 .49541 Mdot
.44285 .64657 Mdot
.5905 .34666 Mdot
.55613 .75746 Mdot
.54254 .33556 Mdot
.39155 .38086 Mdot
.48588 .33994 Mdot
.44536 .67333 Mdot
.53914 .35343 Mdot
.45888 .35123 Mdot
.22569 .66741 Mdot
.68016 .59828 Mdot
.48877 .30658 Mdot
.54111 .33124 Mdot
.58238 .39177 Mdot
.53188 .33844 Mdot
.57979 .5832 Mdot
.48589 .41177 Mdot
.65282 .52357 Mdot
.42625 .36793 Mdot
.36355 .52889 Mdot
.82236 .44573 Mdot
.33657 .44071 Mdot
.53748 .43428 Mdot
.58032 .61183 Mdot
.5961 .57546 Mdot
.6203 .55491 Mdot
.56965 .50673 Mdot
.31297 .33634 Mdot
.58765 .58606 Mdot
.41325 .39076 Mdot
.3458 .56248 Mdot
.66812 .5506 Mdot
.32543 .49125 Mdot
.27365 .68912 Mdot
.43954 .69838 Mdot
.36354 .35264 Mdot
.81986 .59584 Mdot
.59031 .34404 Mdot
.31093 .54203 Mdot
.34488 .56741 Mdot
.45008 .66416 Mdot
.38282 .39177 Mdot
.54038 .33819 Mdot
.65249 .66471 Mdot
.42962 .64408 Mdot
.60009 .55496 Mdot
.48978 .3968 Mdot
.81772 .39376 Mdot
.66796 .5609 Mdot
.63018 .58746 Mdot
.38867 .55045 Mdot
.37744 .69628 Mdot
.7433 .24975 Mdot
.56428 .72879 Mdot
.44063 .67945 Mdot
.41835 .69607 Mdot
.59282 .36319 Mdot
.59973 .49964 Mdot
.41613 .34877 Mdot
.56388 .26756 Mdot
.44651 .32578 Mdot
.5351 .2227 Mdot
.34454 .23865 Mdot
.65247 .57962 Mdot
.21604 .41289 Mdot
.59908 .58019 Mdot
.53211 .33133 Mdot
.57678 .36073 Mdot
.57586 .34361 Mdot
.39202 .39549 Mdot
.74083 .46403 Mdot
.40446 .39887 Mdot
.8589 .52069 Mdot
.56137 .31916 Mdot
.46171 .6001 Mdot
.33771 .5239 Mdot
.68792 .59584 Mdot
.44523 .69139 Mdot
.48929 .31791 Mdot
.52854 .54171 Mdot
.6497 .3366 Mdot
.38239 .53053 Mdot
.59475 .3369 Mdot
.22831 .42191 Mdot
.7292 .70679 Mdot
.50379 .32776 Mdot
.56415 .48676 Mdot
.59019 .7388 Mdot
.43636 .66941 Mdot
.36647 .21805 Mdot
.43578 .69358 Mdot
.38341 .36809 Mdot
.63522 .53698 Mdot
.62417 .53419 Mdot
.65794 .57687 Mdot
.58059 .54122 Mdot
.40889 .42968 Mdot
.57847 .60178 Mdot
.61826 .23807 Mdot
.35891 .5757 Mdot
.49636 .64027 Mdot
.43318 .69164 Mdot
.42747 .40309 Mdot
.34693 .56373 Mdot
.24497 .4574 Mdot
.57788 .69695 Mdot
.62514 .55905 Mdot
.64226 .58547 Mdot
.81446 .54384 Mdot
.65778 .56357 Mdot
.70061 .57903 Mdot
.36172 .56994 Mdot
.60884 .45556 Mdot
.43989 .69761 Mdot
.42697 .70129 Mdot
.40427 .3636 Mdot
.57681 .36295 Mdot
.41834 .67821 Mdot
.34181 .52158 Mdot
.58266 .61313 Mdot
.57089 .59167 Mdot
.54378 .32883 Mdot
.8215 .54251 Mdot
.40114 .65681 Mdot
.21861 .52967 Mdot
.5974 .34365 Mdot
.60708 .31556 Mdot
.6027 .59881 Mdot
.39588 .20763 Mdot
.61848 .35511 Mdot
.446 .64099 Mdot
.42505 .40794 Mdot
.60436 .72759 Mdot
.39212 .41751 Mdot
.55663 .35356 Mdot
.61054 .5133 Mdot
.5871 .35636 Mdot
.62782 .56081 Mdot
.75084 .70869 Mdot
.61915 .53557 Mdot
.6799 .25403 Mdot
.48978 .71454 Mdot
.32639 .54293 Mdot
.23635 .45949 Mdot
.32804 .52979 Mdot
.59721 .32783 Mdot
.56712 .53036 Mdot
.45506 .66983 Mdot
.24387 .6323 Mdot
.60391 .27758 Mdot
.37048 .51971 Mdot
.36996 .49964 Mdot
.39853 .4202 Mdot
.66341 .55619 Mdot
.59578 .59475 Mdot
.33999 .55024 Mdot
.60472 .39335 Mdot
.55 .36239 Mdot
.63739 .54685 Mdot
.59345 .57675 Mdot
.32647 .53842 Mdot
.2149 .65224 Mdot
.62511 .64718 Mdot
.63149 .54052 Mdot
.26816 .52712 Mdot
.42741 .385 Mdot
.68803 .59293 Mdot
.55578 .54098 Mdot
.4305 .66172 Mdot
.70435 .34188 Mdot
.737 .66764 Mdot
.43265 .37875 Mdot
.35062 .5715 Mdot
.63663 .55599 Mdot
.33288 .56215 Mdot
.57484 .59859 Mdot
.37405 .25995 Mdot
.31317 .54763 Mdot
.64325 .52341 Mdot
.67675 .57262 Mdot
.57473 .31198 Mdot
.64804 .58244 Mdot
.73122 .52742 Mdot
.37623 .54222 Mdot
.60065 .50866 Mdot
.79405 .45209 Mdot
.38666 .4047 Mdot
.67844 .54404 Mdot
.42421 .64613 Mdot
.68285 .66018 Mdot
.45362 .27573 Mdot
.48514 .79489 Mdot
.43139 .70371 Mdot
.58455 .58811 Mdot
.37449 .50583 Mdot
.39379 .33949 Mdot
.65443 .23177 Mdot
.63375 .59943 Mdot
.37966 .37352 Mdot
.41703 .37228 Mdot
.44569 .67942 Mdot
.18279 .36231 Mdot
.5663 .54393 Mdot
.58913 .53975 Mdot
.70564 .45996 Mdot
.58065 .38406 Mdot
.60867 .53389 Mdot
.59408 .5219 Mdot
.41684 .38722 Mdot
.67503 .52017 Mdot
.76642 .54233 Mdot
.77558 .38166 Mdot
.37245 .36066 Mdot
.54877 .2452 Mdot
.31859 .55793 Mdot
.41437 .68468 Mdot
.56618 .32617 Mdot
.44802 .65162 Mdot
.34231 .51497 Mdot
.5985 .52227 Mdot
.37497 .37395 Mdot
.71376 .50476 Mdot
.41368 .34983 Mdot
.43431 .76349 Mdot
.52864 .37262 Mdot
.37331 .42984 Mdot
.19748 .31141 Mdot
.26504 .49246 Mdot
.33413 .37629 Mdot
.4327 .6669 Mdot
.4064 .53587 Mdot
.59448 .57766 Mdot
.35392 .22315 Mdot
.57458 .53627 Mdot
.78548 .42879 Mdot
.36472 .57253 Mdot
.38303 .56224 Mdot
.63433 .53941 Mdot
.7592 .61028 Mdot
.39041 .3399 Mdot
.41908 .39939 Mdot
.62888 .51452 Mdot
.38822 .3829 Mdot
.59766 .54237 Mdot
.35718 .56637 Mdot
.40792 .18095 Mdot
.60258 .56335 Mdot
.54673 .54053 Mdot
.38703 .26285 Mdot
.26048 .69736 Mdot
.4354 .61892 Mdot
.16413 .55704 Mdot
.75622 .68533 Mdot
.38931 .38435 Mdot
.63603 .51315 Mdot
.54614 .24122 Mdot
.38907 .5278 Mdot
.4603 .3463 Mdot
.60143 .52631 Mdot
.58417 .52839 Mdot
.61521 .61049 Mdot
.61491 .59266 Mdot
.25838 .29698 Mdot
.59515 .27118 Mdot
.71519 .39097 Mdot
.65136 .57714 Mdot
.59058 .68971 Mdot
.39452 .36108 Mdot
.58325 .29665 Mdot
.4591 .65761 Mdot
.6511 .58082 Mdot
.51112 .37035 Mdot
.37049 .37993 Mdot
.86576 .50013 Mdot
.37762 .37345 Mdot
.36289 .54742 Mdot
.39525 .34568 Mdot
.61048 .57946 Mdot
.5593 .33572 Mdot
.42243 .46783 Mdot
.29691 .45105 Mdot
.37166 .56666 Mdot
.61381 .57026 Mdot
.44693 .6034 Mdot
.38229 .54403 Mdot
.3 .72823 Mdot
.56786 .33055 Mdot
.53285 .6588 Mdot
.58344 .35938 Mdot
.61895 .51142 Mdot
.61886 .51213 Mdot
.37178 .40656 Mdot
.39789 .34829 Mdot
.5818 .36045 Mdot
.14541 .41621 Mdot
.40507 .6528 Mdot
.57316 .34586 Mdot
.59984 .49257 Mdot
.46628 .4318 Mdot
.56384 .33671 Mdot
.45123 .71238 Mdot
.41848 .37849 Mdot
.59955 .36431 Mdot
.63741 .60862 Mdot
.64699 .70995 Mdot
.40575 .67515 Mdot
.3566 .58421 Mdot
.5308 .7553 Mdot
.37574 .52839 Mdot
.4169 .416 Mdot
.3264 .5322 Mdot
.4251 .37577 Mdot
.43879 .29013 Mdot
.54037 .40415 Mdot
.41506 .51969 Mdot
.4065 .42603 Mdot
.33013 .5298 Mdot
.63908 .53778 Mdot
.40467 .61694 Mdot
.58734 .50434 Mdot
.57543 .58702 Mdot
.41999 .39254 Mdot
.5754 .3144 Mdot
.61054 .36735 Mdot
.64159 .67873 Mdot
.57266 .36647 Mdot
.37245 .54297 Mdot
.65154 .30405 Mdot
.31422 .38026 Mdot
.39381 .41555 Mdot
.38997 .35344 Mdot
.65295 .55176 Mdot
.33878 .54023 Mdot
.37576 .56585 Mdot
.39082 .41821 Mdot
.42722 .21314 Mdot
.55819 .5275 Mdot
.58566 .39224 Mdot
.58426 .38117 Mdot
.56005 .34638 Mdot
.52703 .34641 Mdot
.70531 .62779 Mdot
.41127 .35934 Mdot
.58417 .31606 Mdot
.65398 .55268 Mdot
.59223 .526 Mdot
.55674 .26306 Mdot
.40774 .67014 Mdot
.66681 .54157 Mdot
.67518 .59906 Mdot
.62471 .60039 Mdot
.33473 .51404 Mdot
.69348 .61464 Mdot
.3196 .5244 Mdot
.3825 .51606 Mdot
.38558 .52091 Mdot
.31922 .33893 Mdot
.7968 .57433 Mdot
.68028 .73306 Mdot
.59579 .5133 Mdot
.20498 .45465 Mdot
.34703 .53422 Mdot
.63465 .27502 Mdot
.43581 .31133 Mdot
.6174 .60724 Mdot
.26302 .61531 Mdot
.33602 .54724 Mdot
.59772 .35174 Mdot
.60939 .52903 Mdot
.30723 .54032 Mdot
.4173 .64793 Mdot
.59757 .50594 Mdot
.31935 .56484 Mdot
.5375 .35181 Mdot
.43133 .63464 Mdot
.60519 .3614 Mdot
.38573 .52029 Mdot
.63629 .49145 Mdot
.53764 .14986 Mdot
.30529 .52697 Mdot
.20059 .5567 Mdot
.53817 .4929 Mdot
.63919 .54347 Mdot
.31521 .5229 Mdot
.61321 .31895 Mdot
.41794 .41431 Mdot
.50286 .49698 Mdot
.57856 .37642 Mdot
.38312 .56212 Mdot
.36267 .50774 Mdot
.37147 .56689 Mdot
.56356 .37934 Mdot
.65964 .5211 Mdot
.56353 .37272 Mdot
.39546 .34407 Mdot
.6372 .57549 Mdot
.63788 .76268 Mdot
.23624 .39818 Mdot
.59614 .34832 Mdot
.36838 .52945 Mdot
.44722 .70569 Mdot
.601 .57502 Mdot
.22256 .41554 Mdot
.6416 .53942 Mdot
.42559 .38343 Mdot
.67938 .35881 Mdot
.61731 .45218 Mdot
.64266 .51923 Mdot
.65152 .55672 Mdot
.41689 .40121 Mdot
.61062 .56799 Mdot
.66242 .55601 Mdot
.31048 .3458 Mdot
.55441 .3723 Mdot
.59569 .56072 Mdot
.35781 .52435 Mdot
.30585 .40623 Mdot
.55296 .53318 Mdot
.40086 .50141 Mdot
.53014 .65251 Mdot
.66974 .37615 Mdot
.57588 .53438 Mdot
.50124 .39854 Mdot
.60681 .59598 Mdot
.57672 .5599 Mdot
.64882 .5548 Mdot
.21534 .35743 Mdot
.31795 .56182 Mdot
.33616 .56127 Mdot
.41328 .69096 Mdot
.52927 .65291 Mdot
.42339 .65883 Mdot
.4195 .37257 Mdot
.33978 .65145 Mdot
.31799 .52719 Mdot
.54877 .35402 Mdot
.58046 .57467 Mdot
.30655 .52391 Mdot
.62114 .60306 Mdot
.61244 .57849 Mdot
.36884 .50617 Mdot
.32194 .56453 Mdot
.41279 .75269 Mdot
.40784 .66143 Mdot
.58107 .34132 Mdot
.66228 .54149 Mdot
.43612 .64451 Mdot
.57246 .5353 Mdot
.53223 .71038 Mdot
.57655 .34104 Mdot
.55655 .37193 Mdot
.6127 .36508 Mdot
.60373 .52251 Mdot
.60635 .57739 Mdot
.40522 .39926 Mdot
.60046 .33349 Mdot
.38349 .40159 Mdot
.48382 .51974 Mdot
.31341 .70888 Mdot
.60092 .52618 Mdot
.50287 .30964 Mdot
.41886 .65471 Mdot
.3682 .5175 Mdot
.82613 .41161 Mdot
.41289 .69054 Mdot
.63016 .55819 Mdot
.38118 .51985 Mdot
.4425 .66256 Mdot
.53993 .63768 Mdot
.84512 .53034 Mdot
.44883 .70231 Mdot
.65392 .55348 Mdot
.66866 .51324 Mdot
.16092 .54033 Mdot
.43898 .70364 Mdot
.39973 .35344 Mdot
.60599 .52283 Mdot
.56868 .39472 Mdot
.44454 .64723 Mdot
.25372 .56428 Mdot
.33866 .55552 Mdot
.65829 .70079 Mdot
.53506 .54732 Mdot
.63553 .33075 Mdot
.41666 .69239 Mdot
.54774 .33464 Mdot
.70438 .57153 Mdot
.6047 .59878 Mdot
.4362 .70491 Mdot
.43667 .39951 Mdot
.35295 .5601 Mdot
.29732 .42683 Mdot
.56587 .38026 Mdot
.43828 .40309 Mdot
.36444 .51881 Mdot
.22004 .53857 Mdot
.72726 .31928 Mdot
.68899 .57167 Mdot
.17656 .48781 Mdot
.36792 .30442 Mdot
.6556 .58967 Mdot
.46568 .67151 Mdot
.42729 .35732 Mdot
.37169 .392 Mdot
.39255 .37704 Mdot
.42368 .29428 Mdot
.51809 .31365 Mdot
.31802 .56595 Mdot
.46942 .37911 Mdot
.4131 .68189 Mdot
.60869 .71997 Mdot
.57444 .58845 Mdot
.59641 .57209 Mdot
.65927 .54301 Mdot
.65115 .58285 Mdot
.59384 .58782 Mdot
.38129 .38527 Mdot
.42283 .28316 Mdot
.52294 .3012 Mdot
.5696 .33899 Mdot
.37563 .67452 Mdot
.3447 .5239 Mdot
.36394 .58876 Mdot
.43718 .65296 Mdot
.25421 .52119 Mdot
.32348 .49266 Mdot
.35814 .54066 Mdot
.67245 .56403 Mdot
.55625 .36622 Mdot
.69152 .59345 Mdot
.65268 .55521 Mdot
.36955 .55025 Mdot
.45181 .51965 Mdot
.75166 .55608 Mdot
.42441 .74022 Mdot
.41814 .63199 Mdot
.48165 .38644 Mdot
.42136 .70065 Mdot
.55652 .56226 Mdot
.56437 .20145 Mdot
.34072 .51511 Mdot
.35094 .54874 Mdot
.40944 .66532 Mdot
.3982 .20426 Mdot
.57146 .32301 Mdot
.39942 .44059 Mdot
.41867 .35865 Mdot
.61485 .51329 Mdot
.7632 .33807 Mdot
.54158 .48369 Mdot
.31742 .63847 Mdot
.39202 .37109 Mdot
.3222 .54943 Mdot
.55391 .5695 Mdot
.65096 .56583 Mdot
.42447 .65287 Mdot
.46174 .79836 Mdot
.67127 .6093 Mdot
.40725 .83099 Mdot
.83653 .47325 Mdot
.72669 .66634 Mdot
.59951 .59714 Mdot
.55809 .37469 Mdot
.35131 .58074 Mdot
.42259 .68998 Mdot
.62163 .49683 Mdot
.7634 .6532 Mdot
.54744 .32706 Mdot
.40265 .36892 Mdot
.45648 .48199 Mdot
.59054 .7297 Mdot
.57396 .5747 Mdot
.5889 .52531 Mdot
.5745 .56139 Mdot
.85029 .3664 Mdot
.3244 .52026 Mdot
.59533 .35233 Mdot
.44652 .67661 Mdot
.56568 .36301 Mdot
.32552 .54802 Mdot
.42622 .54076 Mdot
.63403 .52977 Mdot
.53626 .33724 Mdot
.55016 .33291 Mdot
.37412 .3939 Mdot
.43354 .3875 Mdot
.47044 .49523 Mdot
.61804 .53643 Mdot
.34299 .49486 Mdot
.58034 .31388 Mdot
.49 .38815 Mdot
.42584 .66764 Mdot
.41922 .38006 Mdot
.64874 .58055 Mdot
.3187 .52932 Mdot
.66506 .60007 Mdot
.58585 .3312 Mdot
.35726 .54052 Mdot
.3743 .75785 Mdot
.43689 .70023 Mdot
.59108 .52996 Mdot
.48367 .66346 Mdot
.35382 .5717 Mdot
.59525 .58148 Mdot
.21923 .5752 Mdot
.44845 .71292 Mdot
.30343 .46813 Mdot
.38579 .53594 Mdot
.33324 .33509 Mdot
.59068 .36606 Mdot
.34566 .29306 Mdot
.35685 .55034 Mdot
.21233 .50999 Mdot
.3987 .7649 Mdot
.57513 .60844 Mdot
.5668 .35347 Mdot
.34553 .30748 Mdot
.68423 .77341 Mdot
.19419 .57622 Mdot
.61688 .55758 Mdot
.3349 .50157 Mdot
.4359 .65636 Mdot
.39731 .41446 Mdot
.33796 .45937 Mdot
.39206 .68212 Mdot
.36107 .48596 Mdot
.64833 .555 Mdot
.54104 .34264 Mdot
.40757 .39082 Mdot
.4542 .28019 Mdot
.34837 .52153 Mdot
.36455 .52665 Mdot
.57252 .5213 Mdot
.41535 .66148 Mdot
.26862 .34131 Mdot
.36106 .56761 Mdot
.82065 .51417 Mdot
.36127 .59296 Mdot
.42419 .643 Mdot
.61936 .59527 Mdot
.66699 .67714 Mdot
.60787 .50036 Mdot
.22654 .6198 Mdot
.33961 .52525 Mdot
.58257 .33614 Mdot
.58769 .59688 Mdot
.80482 .45751 Mdot
.37233 .54092 Mdot
.48259 .40423 Mdot
.29583 .59459 Mdot
.41598 .36183 Mdot
.8236 .4076 Mdot
.60061 .53455 Mdot
.39396 .33963 Mdot
.42679 .65389 Mdot
.62621 .54005 Mdot
.60689 .58032 Mdot
.55028 .31622 Mdot
.37745 .4015 Mdot
.40906 .75261 Mdot
.38563 .35463 Mdot
.39087 .36005 Mdot
.52357 .37715 Mdot
.59074 .55183 Mdot
.36438 .54566 Mdot
.33713 .54673 Mdot
.64231 .60607 Mdot
.36981 .18055 Mdot
.56483 .32276 Mdot
.36381 .58118 Mdot
.8351 .3392 Mdot
.65803 .59199 Mdot
.81385 .40284 Mdot
.44569 .79108 Mdot
.4229 .35656 Mdot
.65452 .55308 Mdot
.53959 .35034 Mdot
.26954 .56085 Mdot
.36609 .52982 Mdot
.62636 .61301 Mdot
.40607 .39029 Mdot
.40735 .65855 Mdot
.37773 .54917 Mdot
.32612 .63934 Mdot
.57685 .54412 Mdot
.26781 .63381 Mdot
.34785 .50066 Mdot
.6163 .81083 Mdot
.25005 .43773 Mdot
.56988 .35289 Mdot
.61493 .57994 Mdot
.60175 .34197 Mdot
.44809 .67113 Mdot
.4586 .48344 Mdot
.41489 .38243 Mdot
.72225 .58912 Mdot
.59113 .20843 Mdot
.37124 .56715 Mdot
.59864 .34746 Mdot
.62864 .51159 Mdot
.3726 .25517 Mdot
.59677 .53793 Mdot
.61129 .47894 Mdot
.42104 .74635 Mdot
.40844 .40524 Mdot
.42132 .358 Mdot
.60719 .58929 Mdot
.44997 .66003 Mdot
.34381 .52216 Mdot
.36092 .55757 Mdot
.54635 .85305 Mdot
.39046 .44334 Mdot
.79695 .52975 Mdot
.58361 .52937 Mdot
.36546 .48931 Mdot
.33308 .41972 Mdot
.37623 .38124 Mdot
.67077 .52988 Mdot
.37517 .51403 Mdot
.49031 .63437 Mdot
.56898 .65498 Mdot
.60439 .59702 Mdot
.59912 .49675 Mdot
.41176 .35186 Mdot
.50331 .34712 Mdot
.33024 .56293 Mdot
.65964 .60976 Mdot
.41858 .51185 Mdot
.53405 .63582 Mdot
.84524 .48476 Mdot
.58106 .3416 Mdot
.32211 .62327 Mdot
.38103 .38658 Mdot
.54476 .54401 Mdot
.44566 .68755 Mdot
.38097 .5014 Mdot
.31438 .53919 Mdot
.63899 .55923 Mdot
.56163 .58281 Mdot
.82468 .47764 Mdot
.55389 .35967 Mdot
.39989 .36084 Mdot
.62283 .52925 Mdot
.51317 .27724 Mdot
.65906 .57413 Mdot
.39982 .40344 Mdot
.51877 .14806 Mdot
.59699 .50199 Mdot
.59211 .53945 Mdot
.2666 .34697 Mdot
.57912 .37863 Mdot
.59403 .31743 Mdot
.77603 .33819 Mdot
.58416 .52924 Mdot
.83326 .45629 Mdot
.58674 .3398 Mdot
.57792 .32311 Mdot
.28868 .38535 Mdot
.59951 .57215 Mdot
.58006 .63398 Mdot
.42625 .37153 Mdot
.39113 .35867 Mdot
.56585 .37635 Mdot
.68331 .59883 Mdot
.43049 .39077 Mdot
.24871 .33126 Mdot
.33834 .5384 Mdot
.50846 .17945 Mdot
.56184 .32239 Mdot
.34921 .34863 Mdot
.38312 .37194 Mdot
.84349 .55188 Mdot
.29582 .49908 Mdot
.63653 .53428 Mdot
.58203 .53275 Mdot
.40986 .66974 Mdot
.65627 .53278 Mdot
.38258 .56294 Mdot
.38785 .38222 Mdot
.7517 .59685 Mdot
.57595 .34409 Mdot
.61045 .53972 Mdot
.24444 .6048 Mdot
.33672 .76004 Mdot
.33623 .61634 Mdot
.54608 .33177 Mdot
.57989 .35614 Mdot
.32096 .53335 Mdot
.33923 .5004 Mdot
.58651 .5673 Mdot
.41609 .4054 Mdot
.60055 .33658 Mdot
.40632 .40285 Mdot
.34362 .51416 Mdot
.36234 .54436 Mdot
.32929 .57284 Mdot
.57349 .58979 Mdot
.36062 .5342 Mdot
.33661 .73154 Mdot
.45241 .40123 Mdot
.53959 .3884 Mdot
.82159 .3709 Mdot
.45855 .28335 Mdot
.61877 .30538 Mdot
.43454 .6413 Mdot
.36418 .57012 Mdot
.39135 .34344 Mdot
.63029 .58266 Mdot
.64027 .59034 Mdot
.31914 .36071 Mdot
.38424 .34783 Mdot
.44634 .67436 Mdot
.40475 .34262 Mdot
.44627 .67863 Mdot
.27894 .63146 Mdot
.665 .55997 Mdot
.57752 .60291 Mdot
.38338 .37906 Mdot
.35913 .53717 Mdot
.33744 .55883 Mdot
.44762 .70055 Mdot
.45574 .54369 Mdot
.38288 .5408 Mdot
.57776 .3206 Mdot
.73624 .59228 Mdot
.35062 .50336 Mdot
.6095 .53059 Mdot
.53662 .72748 Mdot
.3428 .22539 Mdot
.57026 .50621 Mdot
.29319 .37014 Mdot
.69101 .47521 Mdot
.59718 .60141 Mdot
.34898 .22034 Mdot
.42076 .33271 Mdot
.58149 .37144 Mdot
.35631 .5749 Mdot
.32154 .58925 Mdot
.61602 .63608 Mdot
.4346 .63382 Mdot
.63988 .49765 Mdot
.53578 .3392 Mdot
.56132 .30752 Mdot
.65428 .687 Mdot
.20632 .59209 Mdot
.44037 .6615 Mdot
.4338 .65231 Mdot
.35881 .55176 Mdot
.33255 .79942 Mdot
.58324 .48076 Mdot
.44416 .6767 Mdot
.61955 .37232 Mdot
.64561 .55725 Mdot
.50752 .64436 Mdot
.55368 .46035 Mdot
.56507 .37767 Mdot
.59943 .68778 Mdot
.36981 .54163 Mdot
.57398 .36757 Mdot
.51133 .25495 Mdot
.66066 .52548 Mdot
.57519 .34179 Mdot
.40705 .40065 Mdot
.24947 .4668 Mdot
.57607 .31744 Mdot
.5388 .71929 Mdot
.40626 .41579 Mdot
.48889 .38603 Mdot
.61772 .67509 Mdot
.14288 .63635 Mdot
.38409 .38435 Mdot
.36291 .50845 Mdot
.33798 .54805 Mdot
.36121 .55682 Mdot
.56325 .36299 Mdot
.37049 .56839 Mdot
.55446 .35825 Mdot
.1747 .51334 Mdot
.35231 .2339 Mdot
.44172 .67821 Mdot
.29579 .42927 Mdot
.54693 .34639 Mdot
.62442 .25308 Mdot
.2992 .20445 Mdot
.655 .54939 Mdot
.37046 .39334 Mdot
.44095 .67581 Mdot
.38582 .81379 Mdot
.43414 .66329 Mdot
.7729 .62378 Mdot
.65333 .35901 Mdot
.60447 .54381 Mdot
.76487 .47503 Mdot
.45532 .68696 Mdot
.52894 .36211 Mdot
.59607 .58107 Mdot
.48019 .5622 Mdot
.43093 .65798 Mdot
.4167 .64585 Mdot
.58997 .56362 Mdot
.59487 .33677 Mdot
.3701 .52916 Mdot
.38664 .3578 Mdot
.45284 .65482 Mdot
.67392 .51256 Mdot
.62467 .50402 Mdot
.64111 .53464 Mdot
.53184 .27823 Mdot
.46431 .68815 Mdot
.38964 .38529 Mdot
.19045 .36729 Mdot
.36968 .50323 Mdot
.47492 .59448 Mdot
.83175 .49875 Mdot
.38929 .31566 Mdot
.33935 .52648 Mdot
.33117 .55989 Mdot
.59258 .58729 Mdot
.60097 .46275 Mdot
.64479 .35926 Mdot
.44158 .56715 Mdot
.3497 .58451 Mdot
.35746 .55959 Mdot
.60282 .32706 Mdot
.71146 .67274 Mdot
.58106 .49308 Mdot
.4327 .37574 Mdot
.31451 .55157 Mdot
.33289 .26496 Mdot
.41187 .66985 Mdot
.66114 .33964 Mdot
.66611 .55869 Mdot
.6329 .53233 Mdot
.40662 .3842 Mdot
.40505 .39778 Mdot
.27524 .57581 Mdot
.73735 .65572 Mdot
.69146 .4805 Mdot
.42437 .2723 Mdot
.66586 .39061 Mdot
.58985 .31199 Mdot
.59629 .34795 Mdot
.29235 .46506 Mdot
.37915 .36245 Mdot
.5943 .60083 Mdot
.57904 .36241 Mdot
.46729 .61954 Mdot
.721 .59955 Mdot
.70097 .6562 Mdot
.82183 .42938 Mdot
.62427 .56315 Mdot
.54624 .36629 Mdot
.57951 .37958 Mdot
.56861 .38663 Mdot
.34197 .33145 Mdot
.58457 .55543 Mdot
.62045 .5612 Mdot
.5918 .59479 Mdot
.38424 .23056 Mdot
.57995 .55874 Mdot
.36272 .28987 Mdot
.46995 .47477 Mdot
.71492 .33732 Mdot
.66263 .60838 Mdot
.40452 .33863 Mdot
.56947 .55971 Mdot
.45069 .66242 Mdot
.65031 .53661 Mdot
.70349 .65445 Mdot
.39283 .36557 Mdot
.66737 .64387 Mdot
.44633 .29114 Mdot
.6307 .60795 Mdot
.44526 .64153 Mdot
.42554 .31407 Mdot
.67711 .7622 Mdot
.4373 .62241 Mdot
.57547 .32043 Mdot
.33914 .53307 Mdot
.38955 .34361 Mdot
.3565 .54613 Mdot
.59601 .61292 Mdot
.28107 .47172 Mdot
.39935 .80993 Mdot
.47082 .54921 Mdot
.64864 .58399 Mdot
.56649 .49609 Mdot
.584 .32422 Mdot
.37371 .50857 Mdot
.6243 .32743 Mdot
.57883 .58235 Mdot
.43357 .68374 Mdot
.4246 .6546 Mdot
.49593 .50695 Mdot
.54476 .82361 Mdot
.28838 .29639 Mdot
.40249 .38652 Mdot
.36393 .56543 Mdot
.44472 .69249 Mdot
.21063 .48935 Mdot
.43055 .35407 Mdot
.42232 .39273 Mdot
.397 .36365 Mdot
.60212 .51775 Mdot
.31583 .55811 Mdot
.71842 .33938 Mdot
.38391 .51214 Mdot
.6106 .57041 Mdot
.33363 .51368 Mdot
.37948 .52294 Mdot
.42689 .68927 Mdot
.39634 .36182 Mdot
.34044 .51691 Mdot
.61272 .50988 Mdot
.58938 .34231 Mdot
.34169 .39957 Mdot
.47689 .71725 Mdot
.21153 .59769 Mdot
.51109 .56264 Mdot
.56732 .38319 Mdot
.66259 .77392 Mdot
.42847 .37849 Mdot
.41509 .21759 Mdot
.41446 .75314 Mdot
.57048 .52744 Mdot
.38727 .17234 Mdot
.37731 .58754 Mdot
.37765 .52263 Mdot
.61678 .59571 Mdot
.37116 .59586 Mdot
.60557 .53968 Mdot
.35581 .51289 Mdot
.36979 .4563 Mdot
.51403 .36168 Mdot
.35608 .53324 Mdot
.64656 .6156 Mdot
.60516 .58382 Mdot
.56026 .37442 Mdot
.32525 .50878 Mdot
.61429 .49444 Mdot
.58043 .85455 Mdot
.39806 .40057 Mdot
.38758 .30882 Mdot
.52212 .73633 Mdot
.38045 .38894 Mdot
.57026 .34637 Mdot
.57382 .58495 Mdot
.42825 .6537 Mdot
.54525 .34732 Mdot
.71151 .64516 Mdot
.43129 .69872 Mdot
.49013 .16942 Mdot
.57616 .38122 Mdot
.37258 .5219 Mdot
.45152 .67539 Mdot
.64776 .52023 Mdot
.38877 .52204 Mdot
.23632 .46845 Mdot
.34224 .52645 Mdot
.59142 .59031 Mdot
.32357 .44327 Mdot
.39999 .35977 Mdot
.61896 .5544 Mdot
.37875 .53064 Mdot
.29406 .37241 Mdot
.59614 .51596 Mdot
.60455 .59204 Mdot
.82969 .51365 Mdot
.66127 .27661 Mdot
.42992 .66592 Mdot
.60675 .36191 Mdot
.6542 .55148 Mdot
.42526 .64508 Mdot
.33831 .70535 Mdot
.61434 .52126 Mdot
.5472 .32674 Mdot
.67204 .53054 Mdot
.32996 .50526 Mdot
.38556 .40069 Mdot
.44873 .58029 Mdot
.41807 .64759 Mdot
.17311 .63496 Mdot
.31706 .55194 Mdot
.56548 .57977 Mdot
.6584 .57202 Mdot
.5228 .77278 Mdot
.57847 .37152 Mdot
.59483 .41523 Mdot
.59041 .53003 Mdot
.39522 .2216 Mdot
.62338 .54242 Mdot
.38577 .57931 Mdot
.5726 .3227 Mdot
.58621 .54243 Mdot
.36446 .43183 Mdot
.54694 .54248 Mdot
.40773 .67783 Mdot
.24421 .38237 Mdot
.65226 .5144 Mdot
.50111 .15795 Mdot
.49358 .54847 Mdot
.35691 .53136 Mdot
.28356 .69386 Mdot
.56499 .86488 Mdot
.43106 .297 Mdot
.56468 .36099 Mdot
.43275 .79735 Mdot
.36449 .54508 Mdot
.25821 .63925 Mdot
.67867 .77225 Mdot
.61335 .58564 Mdot
.57486 .57731 Mdot
.58135 .7442 Mdot
.38315 .51453 Mdot
.35655 .49339 Mdot
.58462 .61255 Mdot
.55142 .52888 Mdot
.36367 .53797 Mdot
.58887 .51284 Mdot
.64977 .61942 Mdot
.37067 .39303 Mdot
.55162 .32538 Mdot
.40877 .40624 Mdot
.42664 .39625 Mdot
.22295 .37968 Mdot
.4904 .56637 Mdot
.39617 .4034 Mdot
.42704 .35988 Mdot
.50998 .63969 Mdot
.75341 .62284 Mdot
.44874 .65218 Mdot
.57328 .8318 Mdot
.35359 .55849 Mdot
.58752 .5495 Mdot
.58197 .38138 Mdot
.68601 .48211 Mdot
.3635 .72492 Mdot
.59169 .22399 Mdot
.58636 .59437 Mdot
.37234 .53783 Mdot
.37081 .32007 Mdot
.69601 .58695 Mdot
.30501 .54478 Mdot
.61706 .52743 Mdot
.38427 .56022 Mdot
.76146 .57263 Mdot
.21305 .50895 Mdot
.32995 .59128 Mdot
.57536 .39296 Mdot
.6289 .53307 Mdot
.53226 .34405 Mdot
.37696 .38242 Mdot
.45141 .65836 Mdot
.42609 .66399 Mdot
.59254 .57504 Mdot
.56305 .49043 Mdot
.28259 .65105 Mdot
.60139 .57677 Mdot
.64526 .56101 Mdot
.41245 .32753 Mdot
.64922 .5571 Mdot
.65505 .58393 Mdot
.61666 .60494 Mdot
.6053 .60969 Mdot
.39183 .35903 Mdot
.25373 .52637 Mdot
.59912 .63198 Mdot
.56145 .60698 Mdot
.41465 .41594 Mdot
.43937 .78249 Mdot
.42985 .38722 Mdot
.69104 .75972 Mdot
.42086 .35552 Mdot
.42711 .67306 Mdot
.46318 .7794 Mdot
.5316 .55318 Mdot
.55642 .31634 Mdot
.38937 .3267 Mdot
.44924 .66775 Mdot
.39031 .37914 Mdot
.3581 .51107 Mdot
.83636 .50903 Mdot
.54448 .31022 Mdot
.58145 .26638 Mdot
.45182 .33355 Mdot
.2502 .50242 Mdot
.31992 .53293 Mdot
.529 .36862 Mdot
.76061 .53363 Mdot
.65363 .58205 Mdot
.42674 .64479 Mdot
.58779 .5693 Mdot
.3749 .37726 Mdot
.36798 .54749 Mdot
.18499 .54664 Mdot
.42381 .65299 Mdot
.83922 .40068 Mdot
.33474 .55369 Mdot
.64632 .59157 Mdot
.43054 .39001 Mdot
.77222 .30367 Mdot
.41178 .40258 Mdot
.61702 .41512 Mdot
.5941 .35921 Mdot
.17263 .57618 Mdot
.55432 .3504 Mdot
.22847 .49098 Mdot
.7036 .21265 Mdot
.24506 .57332 Mdot
.59292 .34095 Mdot
.42485 .54998 Mdot
.63326 .55811 Mdot
.64017 .53363 Mdot
.20024 .5187 Mdot
.5953 .37477 Mdot
.65398 .57043 Mdot
.3248 .39473 Mdot
.44178 .3962 Mdot
.79379 .38326 Mdot
.32193 .53764 Mdot
.605 .53584 Mdot
.36762 .36694 Mdot
.38213 .34633 Mdot
.33688 .56981 Mdot
.42488 .38921 Mdot
.6179 .56233 Mdot
.54788 .347 Mdot
.38364 .47606 Mdot
.41927 .67281 Mdot
.34547 .79509 Mdot
.40053 .67113 Mdot
.33843 .52679 Mdot
.58654 .50432 Mdot
.36165 .5441 Mdot
.68491 .83157 Mdot
.62763 .55504 Mdot
.58648 .33867 Mdot
.64899 .56449 Mdot
.63159 .53683 Mdot
.5973 .60532 Mdot
.36753 .52657 Mdot
.42324 .74312 Mdot
.6045 .50907 Mdot
.41646 .37999 Mdot
.68998 .37198 Mdot
.66883 .54068 Mdot
.39873 .60594 Mdot
.69315 .66376 Mdot
.47661 .34042 Mdot
.59914 .3629 Mdot
.35195 .5297 Mdot
.57906 .34621 Mdot
.4309 .1981 Mdot
.56999 .34614 Mdot
.67837 .41857 Mdot
.766 .53331 Mdot
.79714 .50047 Mdot
.79473 .48483 Mdot
.43016 .48505 Mdot
.60056 .36947 Mdot
.44868 .63138 Mdot
.59857 .33385 Mdot
.57198 .37682 Mdot
.40309 .11862 Mdot
.53635 .33133 Mdot
.60216 .52851 Mdot
.67127 .55507 Mdot
.23053 .53236 Mdot
.52599 .69186 Mdot
.63948 .57547 Mdot
.64484 .5773 Mdot
.44714 .68964 Mdot
.42572 .20378 Mdot
.29146 .47781 Mdot
.65465 .27329 Mdot
.34886 .75984 Mdot
.58895 .56713 Mdot
.65392 .54196 Mdot
.60307 .62654 Mdot
.67071 .22588 Mdot
.20746 .40225 Mdot
.56887 .39665 Mdot
.57274 .61155 Mdot
.23856 .59151 Mdot
.58397 .59432 Mdot
.59264 .52236 Mdot
.6275 .56104 Mdot
.36502 .54505 Mdot
.60351 .36171 Mdot
.61751 .61405 Mdot
.5043 .77787 Mdot
.59979 .52324 Mdot
.3628 .31602 Mdot
.22998 .69654 Mdot
.59972 .5343 Mdot
.60531 .32006 Mdot
.64312 .53628 Mdot
.57014 .37226 Mdot
.5429 .37157 Mdot
.57429 .61012 Mdot
.6624 .39143 Mdot
.60614 .33105 Mdot
.61028 .57115 Mdot
.36089 .50981 Mdot
.60875 .80997 Mdot
.58854 .58629 Mdot
.44672 .65054 Mdot
.58373 .5313 Mdot
.43349 .63645 Mdot
.64115 .56685 Mdot
.32061 .55865 Mdot
.65474 .45995 Mdot
.35219 .55039 Mdot
.17915 .47065 Mdot
.32389 .56755 Mdot
.85209 .43078 Mdot
.56332 .38348 Mdot
.31026 .43214 Mdot
.52188 .19833 Mdot
.3297 .31717 Mdot
.51374 .42248 Mdot
.43873 .45331 Mdot
.41681 .40425 Mdot
.58522 .36539 Mdot
.48018 .20903 Mdot
.37159 .68966 Mdot
.37202 .64089 Mdot
.38029 .54835 Mdot
.17401 .37157 Mdot
.47244 .17636 Mdot
.55575 .55768 Mdot
.75079 .48738 Mdot
.72992 .4219 Mdot
.58519 .59645 Mdot
.59147 .60442 Mdot
.33563 .59889 Mdot
.59759 .50808 Mdot
.51289 .28083 Mdot
.33209 .5297 Mdot
.44871 .66303 Mdot
.58865 .32922 Mdot
.40694 .65894 Mdot
.3892 .72194 Mdot
.44037 .44779 Mdot
.3509 .51194 Mdot
.60934 .49653 Mdot
.63676 .58101 Mdot
.56099 .37035 Mdot
.62455 .30356 Mdot
.58673 .31575 Mdot
.44085 .67026 Mdot
.32878 .53554 Mdot
.31281 .24777 Mdot
.63878 .5826 Mdot
.55332 .33175 Mdot
.52141 .43068 Mdot
.65361 .55515 Mdot
.37999 .37967 Mdot
.63568 .55386 Mdot
.59377 .33339 Mdot
.64909 .55746 Mdot
.55547 .35172 Mdot
.33958 .53531 Mdot
.62969 .60405 Mdot
.61457 .59837 Mdot
.81079 .36405 Mdot
.43804 .68173 Mdot
.52576 .36631 Mdot
.46905 .60596 Mdot
.65931 .5538 Mdot
.28351 .41642 Mdot
.61322 .52754 Mdot
.50479 .36035 Mdot
.55892 .55194 Mdot
.3885 .30995 Mdot
.5486 .59272 Mdot
.58397 .57304 Mdot
.52674 .47368 Mdot
.72157 .42259 Mdot
.54327 .6109 Mdot
.41881 .34731 Mdot
.52359 .36188 Mdot
.79763 .39647 Mdot
.3928 .49667 Mdot
.33192 .49971 Mdot
.59675 .70477 Mdot
.62957 .61296 Mdot
.60188 .5437 Mdot
.48329 .34778 Mdot
.418 .65147 Mdot
.54024 .33651 Mdot
.44601 .67896 Mdot
.83401 .42107 Mdot
.41923 .69621 Mdot
.38591 .58 Mdot
.26813 .63606 Mdot
.27666 .28378 Mdot
.44474 .69132 Mdot
.59517 .33333 Mdot
.25931 .60211 Mdot
.65083 .59346 Mdot
.49843 .53164 Mdot
.42801 .68276 Mdot
.14392 .46809 Mdot
.65378 .58516 Mdot
.51753 .42188 Mdot
.39447 .40681 Mdot
.44595 .68832 Mdot
.39919 .41855 Mdot
.6243 .58502 Mdot
.29467 .47654 Mdot
.5653 .36012 Mdot
.39762 .42233 Mdot
.68001 .556 Mdot
.44293 .67493 Mdot
.31356 .54715 Mdot
.38131 .42729 Mdot
.43138 .36882 Mdot
.49458 .81091 Mdot
.17525 .54893 Mdot
.32831 .53856 Mdot
.72917 .31751 Mdot
.4031 .34038 Mdot
.65682 .58918 Mdot
.44986 .20157 Mdot
.63538 .53287 Mdot
.30176 .30502 Mdot
.3474 .52461 Mdot
.25142 .50908 Mdot
.65365 .55036 Mdot
.58144 .58089 Mdot
.56718 .30476 Mdot
.34511 .55122 Mdot
.55939 .33745 Mdot
.52935 .37795 Mdot
.33828 .53648 Mdot
.56524 .35172 Mdot
.4493 .69362 Mdot
.51526 .23686 Mdot
.41793 .35675 Mdot
.41528 .36845 Mdot
.36093 .55807 Mdot
.35705 .52735 Mdot
.35782 .54176 Mdot
.63625 .55333 Mdot
.55498 .3267 Mdot
.62114 .57757 Mdot
.57525 .53417 Mdot
.69225 .35511 Mdot
.59556 .37019 Mdot
.6223 .56955 Mdot
.47879 .57804 Mdot
.56704 .46203 Mdot
.35363 .50652 Mdot
.39423 .40436 Mdot
.32039 .40608 Mdot
.24001 .44667 Mdot
.60872 .53538 Mdot
.48409 .6789 Mdot
.59637 .33272 Mdot
.43316 .6568 Mdot
.40995 .69155 Mdot
.43321 .6649 Mdot
.45585 .35917 Mdot
.56983 .38603 Mdot
.65493 .28291 Mdot
.60315 .53828 Mdot
.51517 .30668 Mdot
.56116 .39981 Mdot
.27553 .61396 Mdot
.39389 .40243 Mdot
.65061 .56572 Mdot
.45237 .57678 Mdot
.73908 .55553 Mdot
.63758 .53784 Mdot
.67276 .54852 Mdot
.34952 .74207 Mdot
.6235 .48776 Mdot
.57117 .30827 Mdot
.7775 .31585 Mdot
.6475 .5227 Mdot
.32971 .2636 Mdot
.37332 .82305 Mdot
.6167 .53376 Mdot
.57678 .57068 Mdot
.63431 .59018 Mdot
.6485 .53418 Mdot
.60729 .32857 Mdot
.5471 .67369 Mdot
.40753 .34144 Mdot
.52258 .29912 Mdot
.37812 .36773 Mdot
.35913 .57977 Mdot
.25243 .5123 Mdot
.59103 .36093 Mdot
.40999 .66832 Mdot
.31215 .74974 Mdot
.71 .27504 Mdot
.33142 .56378 Mdot
.25856 .32364 Mdot
.42905 .68069 Mdot
.66845 .57724 Mdot
.45861 .66654 Mdot
.32486 .51729 Mdot
.41603 .36346 Mdot
.65738 .51614 Mdot
.59631 .34487 Mdot
.57201 .31771 Mdot
.6533 .56346 Mdot
.24106 .62409 Mdot
.37838 .39248 Mdot
.42812 .35641 Mdot
.60672 .51761 Mdot
.65113 .52351 Mdot
.55986 .34015 Mdot
.35242 .56538 Mdot
.80383 .4954 Mdot
.43305 .64986 Mdot
.57488 .59057 Mdot
.64935 .55259 Mdot
.82781 .50941 Mdot
.41874 .37913 Mdot
.31029 .5257 Mdot
.56747 .53136 Mdot
.41013 .26683 Mdot
.57193 .52651 Mdot
.61445 .62647 Mdot
.36018 .50867 Mdot
.65407 .63096 Mdot
.57367 .59977 Mdot
.51009 .34971 Mdot
.40616 .41194 Mdot
.57939 .33948 Mdot
.51039 .34555 Mdot
.54395 .23389 Mdot
.3831 .37557 Mdot
.6307 .56289 Mdot
.39074 .39762 Mdot
.61597 .52181 Mdot
.6325 .51597 Mdot
.39934 .40369 Mdot
.55846 .33843 Mdot
.42431 .79265 Mdot
.24902 .55409 Mdot
.64215 .52644 Mdot
.57668 .60894 Mdot
.52555 .67314 Mdot
.38854 .68859 Mdot
.57795 .5818 Mdot
.59159 .32619 Mdot
.62738 .58827 Mdot
.37957 .40395 Mdot
.45397 .68845 Mdot
.59095 .34097 Mdot
.33678 .56072 Mdot
.32215 .55518 Mdot
.44422 .29413 Mdot
.38363 .53112 Mdot
.57251 .57413 Mdot
.61024 .30134 Mdot
.59797 .30642 Mdot
.28164 .72419 Mdot
.3369 .53996 Mdot
.44531 .64733 Mdot
.60117 .59003 Mdot
.64745 .71022 Mdot
.36607 .37419 Mdot
.3621 .161 Mdot
.62004 .2454 Mdot
.46318 .6723 Mdot
.62971 .2724 Mdot
.3276 .56825 Mdot
.58965 .61162 Mdot
.44417 .64913 Mdot
.32077 .53413 Mdot
.62321 .51827 Mdot
.57822 .61427 Mdot
.60148 .4193 Mdot
.39679 .45321 Mdot
.39418 .39793 Mdot
.38253 .55703 Mdot
.46024 .65389 Mdot
.34807 .58646 Mdot
.54753 .37691 Mdot
.58262 .55746 Mdot
.58277 .50863 Mdot
.35034 .5669 Mdot
.33208 .4982 Mdot
.61619 .56999 Mdot
.60128 .34428 Mdot
.3697 .6078 Mdot
.59225 .56365 Mdot
.38847 .4431 Mdot
.6002 .37448 Mdot
.32432 .53619 Mdot
.58095 .57392 Mdot
.41437 .62825 Mdot
.33987 .5587 Mdot
.34974 .5062 Mdot
.65478 .54356 Mdot
.44201 .69658 Mdot
.55798 .58365 Mdot
.42443 .36578 Mdot
.1702 .39436 Mdot
.37865 .40295 Mdot
.40043 .50436 Mdot
.62367 .48517 Mdot
.4147 .24343 Mdot
.59202 .36805 Mdot
.63709 .68493 Mdot
.32489 .39748 Mdot
.65208 .61939 Mdot
.59717 .80161 Mdot
.34889 .35177 Mdot
.27452 .70473 Mdot
.64902 .74681 Mdot
.42625 .68619 Mdot
.39175 .37696 Mdot
.57652 .57052 Mdot
.37112 .39608 Mdot
.43929 .64605 Mdot
.18126 .46738 Mdot
.58722 .5872 Mdot
.57763 .32356 Mdot
.61956 .56486 Mdot
.56766 .32082 Mdot
.65139 .53296 Mdot
.54952 .55851 Mdot
.32325 .34123 Mdot
.55138 .64835 Mdot
.57001 .53016 Mdot
.83691 .34968 Mdot
.57724 .44748 Mdot
.44088 .65312 Mdot
.61392 .58236 Mdot
.31188 .56847 Mdot
.37905 .35476 Mdot
.3512 .30171 Mdot
.36605 .54326 Mdot
.43069 .37048 Mdot
.5628 .34661 Mdot
.34615 .52877 Mdot
.33664 .568 Mdot
.66097 .6288 Mdot
.4593 .68331 Mdot
.406 .36799 Mdot
.58452 .54272 Mdot
.58604 .58457 Mdot
.72954 .31297 Mdot
.35961 .69235 Mdot
.61665 .28897 Mdot
.61174 .19246 Mdot
.54455 .38404 Mdot
.44723 .66777 Mdot
.36973 .53055 Mdot
.57033 .54636 Mdot
.61511 .55713 Mdot
.29308 .41752 Mdot
.59754 .32336 Mdot
.45964 .49165 Mdot
.63087 .29534 Mdot
.46245 .61772 Mdot
.55558 .65909 Mdot
.59014 .32866 Mdot
.54948 .6576 Mdot
.46082 .69724 Mdot
.5033 .83856 Mdot
.52483 .63583 Mdot
.3914 .40535 Mdot
.5364 .65395 Mdot
.54022 .33884 Mdot
.60843 .51078 Mdot
.3669 .51171 Mdot
.37961 .52206 Mdot
.57167 .33659 Mdot
.31376 .563 Mdot
.42068 .6862 Mdot
.57564 .55293 Mdot
.65517 .26051 Mdot
.47547 .2715 Mdot
.3648 .55991 Mdot
.6853 .60269 Mdot
.3955 .36366 Mdot
.65389 .56238 Mdot
.4355 .69313 Mdot
.38514 .38912 Mdot
.75749 .63801 Mdot
.43611 .41059 Mdot
.59764 .5854 Mdot
.83121 .50838 Mdot
.38518 .37814 Mdot
.65791 .47921 Mdot
.58963 .55597 Mdot
.42625 .37492 Mdot
.70745 .59189 Mdot
.24545 .47252 Mdot
.47612 .53495 Mdot
.6798 .77258 Mdot
.48573 .49444 Mdot
.37478 .54048 Mdot
.24769 .49065 Mdot
.32316 .31603 Mdot
.39395 .34469 Mdot
.31849 .51035 Mdot
.49524 .57583 Mdot
.40185 .41737 Mdot
.666 .57921 Mdot
.6179 .53036 Mdot
.20457 .41419 Mdot
.36358 .34874 Mdot
.22434 .49489 Mdot
.45889 .31163 Mdot
.66031 .5554 Mdot
.55329 .56518 Mdot
.611 .55547 Mdot
.59034 .31101 Mdot
.40397 .394 Mdot
.81118 .33611 Mdot
.37754 .38378 Mdot
.67211 .34338 Mdot
.35721 .55766 Mdot
.32207 .53534 Mdot
.60399 .53381 Mdot
.51875 .4169 Mdot
.72467 .65549 Mdot
.6146 .56494 Mdot
.40877 .71636 Mdot
.21077 .43115 Mdot
.65506 .5298 Mdot
.59908 .35696 Mdot
.65104 .62547 Mdot
.6759 .51023 Mdot
.41686 .35525 Mdot
.41305 .67177 Mdot
.67268 .67922 Mdot
.4118 .36104 Mdot
.60276 .54498 Mdot
.42344 .24945 Mdot
.63206 .54318 Mdot
.63865 .52529 Mdot
.64896 .32391 Mdot
.41626 .69751 Mdot
.34935 .54043 Mdot
.43371 .66799 Mdot
.5779 .3735 Mdot
.3245 .1595 Mdot
.41606 .69373 Mdot
.74184 .64297 Mdot
.18751 .42494 Mdot
.52387 .64656 Mdot
.5395 .33515 Mdot
.45908 .65966 Mdot
.3832 .40046 Mdot
.60578 .81305 Mdot
.59941 .42926 Mdot
.34969 .37706 Mdot
.59502 .5591 Mdot
.52264 .34776 Mdot
.57061 .31502 Mdot
.40198 .42254 Mdot
.53896 .37122 Mdot
.5897 .63617 Mdot
.62371 .51598 Mdot
.3863 .35598 Mdot
.43463 .26873 Mdot
.41181 .34125 Mdot
.42914 .52881 Mdot
.60865 .58015 Mdot
.58997 .33723 Mdot
.58029 .60048 Mdot
.61824 .33507 Mdot
.30864 .53767 Mdot
.6019 .49847 Mdot
.41904 .68589 Mdot
.40031 .25255 Mdot
.32744 .54169 Mdot
.47712 .61949 Mdot
.56376 .37155 Mdot
.46214 .3695 Mdot
.55753 .37343 Mdot
.61238 .31445 Mdot
.43023 .3885 Mdot
.53729 .35446 Mdot
.57642 .56646 Mdot
.47993 .54892 Mdot
.56253 .36575 Mdot
.40405 .37877 Mdot
.41519 .66573 Mdot
.55688 .34836 Mdot
.36819 .59697 Mdot
.59743 .59003 Mdot
.36487 .52632 Mdot
.39635 .72042 Mdot
.52843 .33888 Mdot
.43316 .70654 Mdot
.33755 .49758 Mdot
.41697 .64554 Mdot
.23685 .66796 Mdot
.41725 .42188 Mdot
.65578 .3629 Mdot
.40601 .71884 Mdot
.56046 .31425 Mdot
.42349 .75201 Mdot
.57794 .53256 Mdot
.59985 .591 Mdot
.43196 .63728 Mdot
.57092 .31495 Mdot
.4355 .84427 Mdot
.57697 .47624 Mdot
.42408 .49827 Mdot
.40839 .33112 Mdot
.85257 .41886 Mdot
.42596 .51558 Mdot
.33753 .80658 Mdot
.68692 .58861 Mdot
.36012 .49372 Mdot
.61289 .54179 Mdot
.31035 .3851 Mdot
.43976 .67664 Mdot
.41347 .56777 Mdot
.56587 .51851 Mdot
.34572 .53543 Mdot
.61992 .60111 Mdot
.51668 .4837 Mdot
.68273 .50332 Mdot
.43658 .64144 Mdot
.25211 .61849 Mdot
.5288 .34207 Mdot
.42144 .67552 Mdot
.32608 .5235 Mdot
.60987 .67127 Mdot
.62493 .51827 Mdot
.66415 .58518 Mdot
.46115 .61766 Mdot
.55164 .32745 Mdot
.37519 .52477 Mdot
.42284 .36546 Mdot
.41276 .6621 Mdot
.63553 .58019 Mdot
.57574 .53095 Mdot
.28408 .40462 Mdot
.39041 .36397 Mdot
.37751 .51025 Mdot
.39974 .41078 Mdot
.33932 .57394 Mdot
.6096 .50675 Mdot
.32343 .55162 Mdot
.62681 .61673 Mdot
.35122 .32291 Mdot
.65516 .34169 Mdot
.72685 .44075 Mdot
.34343 .5235 Mdot
.75821 .61181 Mdot
.38875 .36675 Mdot
.4168 .39756 Mdot
.21334 .35994 Mdot
.61238 .41382 Mdot
.70967 .28618 Mdot
.56265 .7902 Mdot
.39078 .35665 Mdot
.40086 .36811 Mdot
.36335 .52583 Mdot
.5379 .35726 Mdot
.54307 .38184 Mdot
.3403 .57291 Mdot
.53097 .73157 Mdot
.54078 .33608 Mdot
.56036 .82448 Mdot
.77539 .35837 Mdot
.65109 .61138 Mdot
.39418 .57319 Mdot
.42744 .65631 Mdot
.54357 .72122 Mdot
.50872 .49645 Mdot
.58345 .58698 Mdot
.63108 .70026 Mdot
.35739 .56228 Mdot
.49788 .39196 Mdot
.68084 .76332 Mdot
.62493 .60322 Mdot
.58734 .55157 Mdot
.60946 .54885 Mdot
.45457 .69449 Mdot
.62407 .43505 Mdot
.57884 .5627 Mdot
.52803 .73301 Mdot
.65765 .55857 Mdot
.68993 .50784 Mdot
.42842 .66461 Mdot
.51926 .61291 Mdot
.37897 .70633 Mdot
.77939 .32503 Mdot
.64866 .48189 Mdot
.42209 .36114 Mdot
.38574 .62849 Mdot
.41457 .40309 Mdot
.69045 .42027 Mdot
.51039 .63135 Mdot
.54959 .38727 Mdot
.58184 .58492 Mdot
.33731 .52685 Mdot
.57024 .31537 Mdot
.26261 .45488 Mdot
.36754 .13567 Mdot
.41543 .35053 Mdot
.47956 .89169 Mdot
.42536 .38142 Mdot
.33957 .56944 Mdot
.5609 .34051 Mdot
.76426 .54834 Mdot
.54455 .26381 Mdot
.5589 .35016 Mdot
.41542 .81626 Mdot
.57824 .39788 Mdot
.66948 .66738 Mdot
.54808 .31508 Mdot
.40066 .37488 Mdot
.44916 .34028 Mdot
.57756 .63572 Mdot
.59041 .52656 Mdot
.44446 .45253 Mdot
.72391 .65212 Mdot
.57702 .53404 Mdot
.33122 .53151 Mdot
.64534 .3668 Mdot
.61096 .69981 Mdot
.53713 .34858 Mdot
.43364 .40964 Mdot
.5852 .55989 Mdot
.64687 .54404 Mdot
.61554 .51393 Mdot
.62379 .23897 Mdot
.49871 .83853 Mdot
.60647 .50898 Mdot
.65616 .53978 Mdot
.34544 .53147 Mdot
.38943 .66704 Mdot
.2565 .58423 Mdot
.71465 .32153 Mdot
.61357 .60739 Mdot
.4222 .67055 Mdot
.46067 .64862 Mdot
.58641 .51604 Mdot
.48652 .56641 Mdot
.42747 .24311 Mdot
.58358 .54415 Mdot
.64222 .37393 Mdot
.28281 .55282 Mdot
.38272 .51315 Mdot
.3416 .56249 Mdot
.52625 .36024 Mdot
.3515 .5706 Mdot
.31798 .55682 Mdot
.74944 .57528 Mdot
.47501 .49072 Mdot
.34109 .33936 Mdot
.44134 .66775 Mdot
.6205 .55383 Mdot
.53179 .59232 Mdot
.41125 .26044 Mdot
.41738 .40648 Mdot
.59039 .34857 Mdot
.37566 .35772 Mdot
.46411 .64478 Mdot
.57273 .24227 Mdot
.37313 .56032 Mdot
.40286 .35331 Mdot
.40181 .43425 Mdot
.42196 .66779 Mdot
.38431 .41487 Mdot
.44299 .41901 Mdot
.63379 .50624 Mdot
.74172 .49464 Mdot
.60893 .56944 Mdot
.31805 .75987 Mdot
.40162 .36231 Mdot
.42985 .33088 Mdot
.59482 .54161 Mdot
.33797 .55591 Mdot
.69158 .63262 Mdot
.59377 .52378 Mdot
.35366 .56929 Mdot
.5569 .55044 Mdot
.40111 .66557 Mdot
.60844 .36147 Mdot
.54096 .26744 Mdot
.17554 .36305 Mdot
.46091 .67798 Mdot
.26792 .44743 Mdot
.58319 .5912 Mdot
.19574 .59162 Mdot
.55391 .34727 Mdot
.56329 .55846 Mdot
.59658 .68641 Mdot
.55392 .361 Mdot
.57879 .34976 Mdot
.64042 .5567 Mdot
.39375 .40819 Mdot
.32573 .54018 Mdot
.42378 .66316 Mdot
.30624 .7707 Mdot
.59623 .56967 Mdot
.61938 .59549 Mdot
.42506 .67808 Mdot
.3816 .37002 Mdot
.57353 .52576 Mdot
.55562 .76515 Mdot
.47066 .85438 Mdot
.42687 .38412 Mdot
.64765 .59321 Mdot
.69324 .44577 Mdot
.6047 .47326 Mdot
.17079 .60186 Mdot
.49481 .5449 Mdot
.35235 .53593 Mdot
.58575 .48671 Mdot
.46367 .14288 Mdot
.41329 .6671 Mdot
.70897 .27696 Mdot
.64834 .54575 Mdot
.64288 .58175 Mdot
.59124 .31919 Mdot
.61869 .57585 Mdot
.59286 .35666 Mdot
.23852 .29627 Mdot
.83816 .48947 Mdot
.5345 .37307 Mdot
.55143 .31771 Mdot
.68464 .67436 Mdot
.34786 .43485 Mdot
.56977 .33851 Mdot
.63781 .51813 Mdot
.49786 .60379 Mdot
.49922 .3745 Mdot
.45409 .65186 Mdot
.41192 .74458 Mdot
.54122 .50696 Mdot
.48844 .65337 Mdot
.43747 .78514 Mdot
.52369 .54357 Mdot
.43681 .55627 Mdot
.42027 .3857 Mdot
.62405 .60408 Mdot
.38 .52129 Mdot
.38303 .52551 Mdot
.6186 .61827 Mdot
.62894 .55037 Mdot
.57347 .37367 Mdot
.42068 .65243 Mdot
.39522 .34116 Mdot
.64221 .5794 Mdot
.63336 .68234 Mdot
.4108 .65767 Mdot
.5377 .36646 Mdot
.68134 .36637 Mdot
.39787 .66561 Mdot
.54868 .57103 Mdot
.58826 .53404 Mdot
.62428 .5632 Mdot
.57099 .63383 Mdot
.40711 .39505 Mdot
.44977 .77476 Mdot
.6674 .54895 Mdot
.83204 .41081 Mdot
.33495 .36643 Mdot
.57332 .50121 Mdot
.55026 .37558 Mdot
.44118 .38082 Mdot
.32947 .57563 Mdot
.5266 .2215 Mdot
.59726 .58292 Mdot
.24416 .61917 Mdot
.20324 .4245 Mdot
.31458 .5212 Mdot
.61588 .3433 Mdot
.4365 .66296 Mdot
.61654 .56263 Mdot
.65969 .39459 Mdot
.61471 .53044 Mdot
.4523 .71154 Mdot
.34284 .50533 Mdot
.41892 .38886 Mdot
.28922 .72315 Mdot
.38556 .54292 Mdot
.57877 .34693 Mdot
.81065 .61103 Mdot
.59399 .35645 Mdot
.5398 .38027 Mdot
.68977 .36772 Mdot
.40767 .39605 Mdot
.41072 .14458 Mdot
.25246 .29368 Mdot
.6154 .50279 Mdot
.38387 .36966 Mdot
.57864 .33265 Mdot
.65624 .5722 Mdot
.60535 .38112 Mdot
.5772 .38506 Mdot
.62151 .50982 Mdot
.64045 .58859 Mdot
.21991 .52951 Mdot
.65296 .76934 Mdot
.43774 .66428 Mdot
.58156 .37566 Mdot
.52446 .27336 Mdot
.65776 .57217 Mdot
.60205 .53822 Mdot
.29564 .33318 Mdot
.45777 .68276 Mdot
.50127 .26662 Mdot
.64752 .54478 Mdot
.81382 .55761 Mdot
.62456 .63227 Mdot
.60669 .33559 Mdot
.4192 .39928 Mdot
.78956 .3419 Mdot
.42603 .43414 Mdot
.59167 .35672 Mdot
.4091 .67436 Mdot
.57702 .30277 Mdot
.75179 .63399 Mdot
.3779 .37056 Mdot
.59377 .33324 Mdot
.44825 .57796 Mdot
.39748 .39147 Mdot
.4053 .35889 Mdot
.6985 .35559 Mdot
.30561 .53915 Mdot
.45921 .68924 Mdot
.40374 .3673 Mdot
.40573 .22231 Mdot
.39934 .38144 Mdot
.23804 .31026 Mdot
.63327 .60109 Mdot
.58245 .72427 Mdot
.40752 .52027 Mdot
.54695 .51118 Mdot
.39782 .35926 Mdot
.44949 .68809 Mdot
.62482 .51981 Mdot
.5319 .34933 Mdot
.42734 .64627 Mdot
.35908 .39281 Mdot
.36421 .53954 Mdot
.55334 .37037 Mdot
.3781 .3357 Mdot
.57212 .31908 Mdot
.47919 .21004 Mdot
.17421 .42564 Mdot
.69071 .68819 Mdot
.54745 .26047 Mdot
.62759 .51914 Mdot
.51054 .80895 Mdot
.64357 .59988 Mdot
.63451 .54791 Mdot
.32694 .53314 Mdot
.59952 .71325 Mdot
.55935 .33791 Mdot
.37625 .80449 Mdot
.41357 .35375 Mdot
.78723 .33335 Mdot
.63529 .47893 Mdot
.56509 .58096 Mdot
.56612 .3668 Mdot
.60173 .33212 Mdot
.71299 .40613 Mdot
.36098 .58712 Mdot
.57861 .59119 Mdot
.67236 .53676 Mdot
.61121 .61994 Mdot
.41593 .35992 Mdot
.48422 .59569 Mdot
.37365 .54545 Mdot
.16689 .49299 Mdot
.34131 .50448 Mdot
.46457 .70598 Mdot
.53489 .35449 Mdot
.41569 .69314 Mdot
.59961 .53741 Mdot
.62779 .31062 Mdot
.5961 .32068 Mdot
.42851 .6381 Mdot
.44966 .68076 Mdot
.25769 .41922 Mdot
.39877 .40325 Mdot
.59359 .51972 Mdot
.5802 .57167 Mdot
.62587 .5762 Mdot
.63417 .5536 Mdot
.41296 .3499 Mdot
.61419 .51627 Mdot
.36416 .37914 Mdot
.54049 .21443 Mdot
.58838 .74334 Mdot
.48948 .49097 Mdot
.2758 .31831 Mdot
.53687 .34471 Mdot
.40722 .22827 Mdot
.65594 .49962 Mdot
.52924 .1851 Mdot
.1903 .49653 Mdot
.65936 .52767 Mdot
.3198 .55028 Mdot
.71451 .58877 Mdot
.38098 .54397 Mdot
.34369 .81992 Mdot
.30627 .34612 Mdot
.63936 .78119 Mdot
.58692 .58553 Mdot
.47826 .54894 Mdot
.37494 .23169 Mdot
.65133 .59451 Mdot
.27768 .39202 Mdot
.30078 .30415 Mdot
.2496 .60022 Mdot
.44275 .69381 Mdot
.59019 .57694 Mdot
.53761 .60228 Mdot
.57615 .56093 Mdot
.60875 .53916 Mdot
.61502 .51505 Mdot
.39901 .3358 Mdot
.56628 .56013 Mdot
.63227 .52749 Mdot
.28877 .66166 Mdot
.55339 .65503 Mdot
.36238 .4985 Mdot
.20312 .38249 Mdot
.41732 .69539 Mdot
.5655 .36977 Mdot
.48943 .83058 Mdot
.39144 .40485 Mdot
.71917 .40958 Mdot
.62988 .55759 Mdot
.23179 .53875 Mdot
.41441 .4329 Mdot
.4115 .67889 Mdot
.32175 .52023 Mdot
.63874 .79419 Mdot
.33548 .53107 Mdot
.44402 .36107 Mdot
.33528 .55162 Mdot
.62358 .48234 Mdot
.57507 .37416 Mdot
.58994 .51766 Mdot
.40838 .3697 Mdot
.33655 .56338 Mdot
.52747 .68441 Mdot
.61228 .55353 Mdot
.33887 .53713 Mdot
.59155 .51727 Mdot
.58589 .26317 Mdot
.75028 .34758 Mdot
.31602 .54967 Mdot
.39849 .43216 Mdot
.41301 .38202 Mdot
.4349 .69713 Mdot
.55535 .36708 Mdot
.59066 .35222 Mdot
.38608 .38809 Mdot
.63395 .35475 Mdot
.61295 .60837 Mdot
.65141 .58051 Mdot
.80622 .37007 Mdot
.57336 .56322 Mdot
.6115 .66979 Mdot
.4557 .579 Mdot
.53135 .36258 Mdot
.56563 .58651 Mdot
.6446 .55627 Mdot
.59814 .58698 Mdot
.61072 .25991 Mdot
.35644 .5665 Mdot
.62819 .60276 Mdot
.45181 .67321 Mdot
.26775 .56153 Mdot
.65405 .56158 Mdot
.63155 .6365 Mdot
.59161 .35039 Mdot
.61768 .20124 Mdot
.42407 .38454 Mdot
.32685 .52366 Mdot
.34443 .52265 Mdot
.43752 .77114 Mdot
.3591 .26437 Mdot
.45707 .57757 Mdot
.15908 .54122 Mdot
.32363 .3412 Mdot
.4463 .67575 Mdot
.38905 .51287 Mdot
.4344 .32693 Mdot
.35304 .51824 Mdot
.41038 .34601 Mdot
.64583 .59324 Mdot
.61701 .60774 Mdot
.43138 .16355 Mdot
.57771 .52113 Mdot
.43261 .66057 Mdot
.40636 .33769 Mdot
.54267 .33704 Mdot
.41023 .67332 Mdot
.40183 .41075 Mdot
.5274 .36204 Mdot
.66324 .53139 Mdot
.66763 .54363 Mdot
.58813 .35098 Mdot
.58826 .31974 Mdot
.59025 .53578 Mdot
.32836 .46479 Mdot
.55263 .31842 Mdot
.59138 .32891 Mdot
.37119 .55984 Mdot
.38215 .52759 Mdot
.56387 .6123 Mdot
.39056 .36827 Mdot
.62927 .52468 Mdot
.34345 .52766 Mdot
.41765 .69453 Mdot
.55594 .33783 Mdot
.64489 .52962 Mdot
.64884 .56723 Mdot
.42081 .66702 Mdot
.42337 .69423 Mdot
.4376 .69216 Mdot
.37185 .34391 Mdot
.62073 .58218 Mdot
.56466 .34323 Mdot
.40477 .40114 Mdot
.46338 .65678 Mdot
.45694 .66239 Mdot
.39668 .54367 Mdot
.57023 .55813 Mdot
.3825 .47541 Mdot
.48255 .13997 Mdot
.83004 .45477 Mdot
.31147 .54002 Mdot
.3333 .57907 Mdot
.4983 .68967 Mdot
.49147 .37732 Mdot
.37991 .38426 Mdot
.38966 .68611 Mdot
.69766 .67476 Mdot
.64562 .5095 Mdot
.65378 .5305 Mdot
.55206 .55245 Mdot
.44062 .69059 Mdot
.61443 .71977 Mdot
.58925 .36266 Mdot
.5496 .63418 Mdot
.41146 .65491 Mdot
.34217 .49628 Mdot
.39556 .52127 Mdot
.33707 .50612 Mdot
.66971 .56972 Mdot
.73835 .45317 Mdot
.38422 .24789 Mdot
.54786 .78327 Mdot
.39314 .36163 Mdot
.53049 .5882 Mdot
.19628 .58164 Mdot
.58257 .35221 Mdot
.36188 .58008 Mdot
.44824 .67408 Mdot
.58551 .31875 Mdot
.37248 .36532 Mdot
.40289 .36928 Mdot
.36554 .55855 Mdot
.36527 .55456 Mdot
.3594 .51341 Mdot
.5804 .38587 Mdot
.53599 .35493 Mdot
.5996 .5833 Mdot
.55054 .33853 Mdot
.58679 .21191 Mdot
.41924 .6357 Mdot
.3009 .5511 Mdot
.39124 .37385 Mdot
.53432 .34128 Mdot
.61155 .55676 Mdot
.50162 .35005 Mdot
.39105 .2945 Mdot
.44208 .65219 Mdot
.73894 .32965 Mdot
.30654 .7844 Mdot
.58754 .52227 Mdot
.41318 .38814 Mdot
.6544 .25362 Mdot
.60777 .5511 Mdot
.36978 .52479 Mdot
.31263 .71689 Mdot
.33067 .47755 Mdot
.59685 .52285 Mdot
.6305 .50224 Mdot
.4262 .36586 Mdot
.16997 .50024 Mdot
.59786 .57759 Mdot
.50658 .25199 Mdot
.41126 .43079 Mdot
.37461 .53298 Mdot
.60376 .84917 Mdot
.42269 .6171 Mdot
.54064 .72608 Mdot
.37003 .55583 Mdot
.63058 .53545 Mdot
.37865 .55422 Mdot
.45098 .6647 Mdot
.32145 .52536 Mdot
.59686 .35476 Mdot
.33445 .50337 Mdot
.62061 .59531 Mdot
.5734 .33782 Mdot
.38463 .37732 Mdot
.76711 .31788 Mdot
.33286 .71776 Mdot
.34014 .55733 Mdot
.32162 .55836 Mdot
.56072 .57772 Mdot
.50776 .28184 Mdot
.61512 .61576 Mdot
.65145 .5872 Mdot
.38417 .36171 Mdot
.55531 .36331 Mdot
.42821 .38475 Mdot
.53705 .55809 Mdot
.60485 .74964 Mdot
.4023 .40905 Mdot
.24706 .57267 Mdot
.43102 .68159 Mdot
.49513 .43712 Mdot
.61666 .55754 Mdot
.39172 .41855 Mdot
.61778 .58324 Mdot
.58643 .36656 Mdot
.50449 .46819 Mdot
.27571 .49847 Mdot
.41261 .36535 Mdot
.25823 .67118 Mdot
.55393 .75509 Mdot
.57357 .62482 Mdot
.41793 .39738 Mdot
.5967 .69276 Mdot
.34202 .5705 Mdot
.43086 .64866 Mdot
.40334 .65452 Mdot
.41119 .65252 Mdot
.66031 .61177 Mdot
.64406 .48123 Mdot
.43486 .70734 Mdot
.37873 .35696 Mdot
.43712 .6418 Mdot
.31602 .26423 Mdot
.38014 .80588 Mdot
.43668 .67781 Mdot
.59145 .5577 Mdot
.695 .54288 Mdot
.51129 .63986 Mdot
.24166 .47231 Mdot
.62344 .78841 Mdot
.24984 .37884 Mdot
.59723 .52581 Mdot
.5925 .38342 Mdot
.58308 .38005 Mdot
.65591 .23496 Mdot
.73975 .63472 Mdot
.83025 .48835 Mdot
.52225 .35945 Mdot
.31809 .43589 Mdot
.54202 .36689 Mdot
.59955 .5115 Mdot
.65352 .57759 Mdot
.52137 .36673 Mdot
.61997 .73708 Mdot
.30234 .44255 Mdot
.29606 .74517 Mdot
.57872 .31845 Mdot
.4076 .41102 Mdot
.42078 .40921 Mdot
.40288 .35799 Mdot
.76014 .33302 Mdot
.56705 .36333 Mdot
.63675 .57425 Mdot
.34052 .52368 Mdot
.61149 .60536 Mdot
.39638 .39423 Mdot
.39093 .81953 Mdot
.55752 .35397 Mdot
.58257 .56257 Mdot
.65783 .64125 Mdot
.36539 .54806 Mdot
.42613 .67376 Mdot
.55524 .2701 Mdot
.8242 .49848 Mdot
.40928 .35292 Mdot
.52673 .34246 Mdot
.41165 .32205 Mdot
.31046 .74484 Mdot
.6899 .58591 Mdot
.65554 .50858 Mdot
.30608 .77318 Mdot
.79741 .59164 Mdot
.57825 .58665 Mdot
.31843 .53689 Mdot
.29283 .40869 Mdot
.65208 .55595 Mdot
.58359 .37764 Mdot
.39872 .66396 Mdot
.42055 .64486 Mdot
.56734 .61655 Mdot
.49763 .33411 Mdot
.50389 .49529 Mdot
.6325 .5611 Mdot
.54857 .56577 Mdot
.37391 .54114 Mdot
.30911 .36721 Mdot
.83455 .42202 Mdot
.41454 .68904 Mdot
.58641 .51847 Mdot
.40275 .79504 Mdot
.5849 .314 Mdot
.31379 .52421 Mdot
.37651 .4025 Mdot
.55986 .39923 Mdot
.32058 .52251 Mdot
.64415 .52503 Mdot
.58016 .52009 Mdot
.42269 .40231 Mdot
.60625 .33729 Mdot
.43821 .68967 Mdot
.32581 .53066 Mdot
.42332 .69144 Mdot
.55591 .36054 Mdot
.54428 .34449 Mdot
.63911 .64212 Mdot
.69104 .56744 Mdot
.3364 .55967 Mdot
.63855 .61658 Mdot
.31406 .48277 Mdot
.18905 .64782 Mdot
.38949 .32664 Mdot
.56749 .55041 Mdot
.55608 .30886 Mdot
.41379 .36124 Mdot
.64118 .5846 Mdot
.35391 .81558 Mdot
.65944 .56584 Mdot
.41559 .33433 Mdot
.74745 .65719 Mdot
.42739 .69024 Mdot
.52449 .60188 Mdot
.20405 .52342 Mdot
.57263 .55367 Mdot
.35462 .52378 Mdot
.67809 .60893 Mdot
.38789 .40689 Mdot
.53622 .35013 Mdot
.18246 .64959 Mdot
.40326 .38228 Mdot
.57746 .54842 Mdot
.41122 .66558 Mdot
.56496 .30872 Mdot
.49851 .55033 Mdot
.48462 .57343 Mdot
.70118 .59354 Mdot
.57692 .59369 Mdot
.64176 .54876 Mdot
.56432 .76865 Mdot
.33196 .52005 Mdot
.58693 .32922 Mdot
.41669 .38384 Mdot
.38344 .38721 Mdot
.36169 .56168 Mdot
.38812 .47349 Mdot
.494 .43759 Mdot
.56932 .14904 Mdot
.37458 .56483 Mdot
.40964 .68623 Mdot
.50868 .26889 Mdot
.33319 .52333 Mdot
.33939 .54165 Mdot
.37293 .55827 Mdot
.44409 .56393 Mdot
.54046 .33554 Mdot
.64606 .52634 Mdot
.59935 .36236 Mdot
.63172 .53418 Mdot
.42361 .34152 Mdot
.40979 .36615 Mdot
.55192 .35422 Mdot
.26121 .71084 Mdot
.72438 .49031 Mdot
.59941 .5503 Mdot
.19621 .59077 Mdot
.57451 .51175 Mdot
.51406 .65568 Mdot
.56343 .52956 Mdot
.34819 .55873 Mdot
.66553 .58639 Mdot
.63922 .6215 Mdot
.68074 .25184 Mdot
.38974 .37161 Mdot
.38209 .50945 Mdot
.55544 .5266 Mdot
.55082 .57468 Mdot
.57801 .3879 Mdot
.5876 .32081 Mdot
.4054 .65303 Mdot
.60351 .66184 Mdot
.38234 .37717 Mdot
.31074 .24266 Mdot
.58975 .52774 Mdot
.47943 .63824 Mdot
.79617 .46219 Mdot
.63873 .58656 Mdot
.20675 .5533 Mdot
.73333 .44189 Mdot
.61667 .56106 Mdot
.43421 .47996 Mdot
.38981 .36558 Mdot
.65025 .73936 Mdot
.65663 .55378 Mdot
.36843 .54072 Mdot
.53683 .36095 Mdot
.59509 .31774 Mdot
.40232 .66716 Mdot
.47657 .17535 Mdot
.42917 .38416 Mdot
.54124 .3524 Mdot
.61712 .54899 Mdot
.4134 .39031 Mdot
.36899 .56845 Mdot
.56265 .57269 Mdot
.76857 .6043 Mdot
.55171 .33441 Mdot
.55693 .54783 Mdot
.48806 .23855 Mdot
.50625 .7165 Mdot
.74909 .67505 Mdot
.41947 .37881 Mdot
.4367 .69631 Mdot
.6299 .62833 Mdot
.6024 .41135 Mdot
.56653 .60002 Mdot
.56053 .7327 Mdot
.30419 .27481 Mdot
.4519 .69089 Mdot
.59275 .54519 Mdot
.63703 .57844 Mdot
.55418 .43545 Mdot
.41071 .68239 Mdot
.58439 .58254 Mdot
.56238 .41308 Mdot
.56717 .32234 Mdot
.35334 .57846 Mdot
.54662 .33318 Mdot
.59493 .55819 Mdot
.69287 .57039 Mdot
.59134 .32027 Mdot
.19949 .64081 Mdot
.39896 .64586 Mdot
.41759 .39458 Mdot
.60398 .50186 Mdot
.66623 .55994 Mdot
.79222 .29673 Mdot
.31723 .51551 Mdot
.30306 .47779 Mdot
.28633 .60116 Mdot
.41782 .78069 Mdot
.40712 .61591 Mdot
.7196 .72622 Mdot
.795 .59855 Mdot
.56568 .55989 Mdot
.51907 .5204 Mdot
.44852 .22377 Mdot
.38577 .36433 Mdot
.41373 .19677 Mdot
.59001 .52652 Mdot
.61137 .54 Mdot
.31135 .55075 Mdot
.26513 .5005 Mdot
.8326 .48265 Mdot
.50939 .32848 Mdot
.43498 .68915 Mdot
.57533 .37661 Mdot
.64123 .52136 Mdot
.4523 .49342 Mdot
.33432 .49791 Mdot
.45427 .63144 Mdot
.58285 .55763 Mdot
.6277 .26172 Mdot
.40565 .29127 Mdot
.4009 .3998 Mdot
.34658 .52226 Mdot
.81817 .51998 Mdot
.56967 .54916 Mdot
.38573 .41787 Mdot
.59959 .56798 Mdot
.41348 .60769 Mdot
.53934 .54614 Mdot
.44472 .67264 Mdot
.6471 .53812 Mdot
.387 .61782 Mdot
.86949 .42107 Mdot
.44992 .7085 Mdot
.56978 .3937 Mdot
.31562 .50622 Mdot
.35413 .5671 Mdot
.59151 .32407 Mdot
.34749 .56488 Mdot
.72 .39123 Mdot
.75678 .57627 Mdot
.43121 .68395 Mdot
.56772 .61248 Mdot
.43334 .67387 Mdot
.30989 .53291 Mdot
.59594 .52451 Mdot
.2347 .71838 Mdot
.32836 .55376 Mdot
.81265 .57581 Mdot
.39639 .38293 Mdot
.32908 .49928 Mdot
.65722 .55858 Mdot
.3893 .31201 Mdot
.3854 .54223 Mdot
.29973 .4655 Mdot
.59834 .58654 Mdot
.54323 .34002 Mdot
.64952 .56134 Mdot
.61706 .50394 Mdot
.36019 .49492 Mdot
.62293 .52431 Mdot
.40063 .41138 Mdot
.52351 .36459 Mdot
.58678 .81812 Mdot
.32419 .28637 Mdot
.58129 .58084 Mdot
.61442 .54956 Mdot
.60303 .30943 Mdot
.66498 .57674 Mdot
.41396 .35076 Mdot
.12007 .40774 Mdot
.43055 .6811 Mdot
.36296 .48732 Mdot
.37311 .61718 Mdot
.65647 .52186 Mdot
.61997 .51791 Mdot
.39092 .84458 Mdot
.59484 .74908 Mdot
.41352 .40317 Mdot
.61384 .62074 Mdot
.37894 .56325 Mdot
.41902 .65592 Mdot
.38834 .34694 Mdot
.62246 .56488 Mdot
.59753 .5394 Mdot
.43035 .69759 Mdot
.49497 .64787 Mdot
.79135 .37734 Mdot
.40535 .41888 Mdot
.62079 .48497 Mdot
.35803 .59952 Mdot
.61008 .6095 Mdot
.73641 .3149 Mdot
.5924 .33739 Mdot
.40615 .35186 Mdot
.43863 .77942 Mdot
.56828 .55294 Mdot
.41919 .40155 Mdot
.38307 .37567 Mdot
.57152 .59992 Mdot
.5268 .33013 Mdot
.52584 .36957 Mdot
.56745 .3201 Mdot
.346 .18006 Mdot
.55028 .71188 Mdot
.3595 .51342 Mdot
.38761 .36621 Mdot
.32409 .5634 Mdot
.45218 .71188 Mdot
.47148 .54338 Mdot
.31999 .55807 Mdot
.55289 .32463 Mdot
.34497 .49024 Mdot
.62134 .58741 Mdot
.38301 .3789 Mdot
.357 .51847 Mdot
.62744 .50693 Mdot
.50579 .31108 Mdot
.2302 .44349 Mdot
.45628 .6714 Mdot
.39852 .675 Mdot
.65436 .57129 Mdot
.35435 .58499 Mdot
.59362 .53473 Mdot
.3731 .39966 Mdot
.51558 .29018 Mdot
.61349 .50457 Mdot
.34347 .55993 Mdot
.59695 .30741 Mdot
.81902 .51248 Mdot
.67067 .5949 Mdot
.59159 .55591 Mdot
.6275 .52966 Mdot
.59971 .5687 Mdot
.30881 .7361 Mdot
.43018 .3978 Mdot
.28339 .3133 Mdot
.43833 .76542 Mdot
.56333 .3534 Mdot
.60584 .35628 Mdot
.82865 .42599 Mdot
.44118 .23232 Mdot
.3907 .36747 Mdot
.63441 .55003 Mdot
.4072 .27238 Mdot
.46922 .85312 Mdot
.28298 .74837 Mdot
.63783 .46639 Mdot
.31621 .51501 Mdot
.52696 .34282 Mdot
.33852 .5668 Mdot
.62533 .53354 Mdot
.55242 .57403 Mdot
.76046 .69523 Mdot
.37476 .36668 Mdot
.43688 .68497 Mdot
.63321 .5333 Mdot
.54597 .71495 Mdot
.34652 .53028 Mdot
.32992 .4983 Mdot
.63786 .59539 Mdot
.59916 .31376 Mdot
.85948 .4153 Mdot
.40752 .39426 Mdot
.27366 .34471 Mdot
.36802 .23427 Mdot
.43267 .30912 Mdot
.39934 .39535 Mdot
.56699 .44656 Mdot
.31312 .52903 Mdot
.78926 .43042 Mdot
.5695 .35633 Mdot
.43105 .64699 Mdot
.57911 .49755 Mdot
.59802 .33714 Mdot
.35543 .50448 Mdot
.53854 .34556 Mdot
.61913 .51643 Mdot
.41861 .42428 Mdot
.3545 .53544 Mdot
.33596 .34772 Mdot
.55845 .30785 Mdot
.40998 .67821 Mdot
.47488 .3985 Mdot
.70147 .50405 Mdot
.73176 .43722 Mdot
.63356 .59941 Mdot
.45073 .50275 Mdot
.63409 .57443 Mdot
.6155 .33562 Mdot
.60745 .55975 Mdot
.59247 .29506 Mdot
.35496 .52503 Mdot
.6565 .54155 Mdot
.63474 .55787 Mdot
.23398 .32499 Mdot
.58669 .58014 Mdot
.60817 .61273 Mdot
.62057 .55957 Mdot
.62382 .30932 Mdot
.57868 .62194 Mdot
.55464 .37713 Mdot
.26421 .60122 Mdot
.34117 .54496 Mdot
.41903 .6429 Mdot
.43967 .69828 Mdot
.58728 .7164 Mdot
.37279 .6701 Mdot
.24973 .51036 Mdot
.5614 .3271 Mdot
.38914 .41225 Mdot
.60474 .56411 Mdot
.67599 .76265 Mdot
.32627 .59686 Mdot
.34168 .4976 Mdot
.32545 .28695 Mdot
.57053 .48905 Mdot
.6728 .73124 Mdot
.60392 .61797 Mdot
.40385 .17077 Mdot
.68102 .55295 Mdot
.56982 .49701 Mdot
.36866 .57302 Mdot
.47905 .6628 Mdot
.663 .57543 Mdot
.56413 .38604 Mdot
.44043 .6566 Mdot
.62766 .47801 Mdot
.40479 .53107 Mdot
.26737 .54595 Mdot
.58583 .28245 Mdot
.60882 .58473 Mdot
.35457 .53674 Mdot
.55545 .37072 Mdot
.8361 .4398 Mdot
.40691 .4 Mdot
.39668 .48464 Mdot
.52103 .23316 Mdot
.2047 .63651 Mdot
.40923 .66025 Mdot
.7536 .37001 Mdot
.62157 .59331 Mdot
.28541 .67896 Mdot
.60567 .5029 Mdot
.40756 .83309 Mdot
.42867 .70382 Mdot
.54692 .32709 Mdot
.40283 .41388 Mdot
.5849 .37601 Mdot
.71958 .42771 Mdot
.40127 .55598 Mdot
.47938 .47027 Mdot
.3359 .53283 Mdot
.49879 .51437 Mdot
.58159 .33537 Mdot
.59605 .51588 Mdot
.56262 .14574 Mdot
.59226 .33156 Mdot
.55843 .31071 Mdot
.18465 .43622 Mdot
.21047 .6825 Mdot
.66723 .52047 Mdot
.55014 .31906 Mdot
.33351 .53815 Mdot
.43815 .66146 Mdot
.65238 .54688 Mdot
.6104 .58857 Mdot
.59677 .34136 Mdot
.36905 .4967 Mdot
.65926 .43044 Mdot
.3609 .55716 Mdot
.54366 .33249 Mdot
.35227 .55008 Mdot
.43532 .33839 Mdot
.3254 .52722 Mdot
.66656 .56022 Mdot
.6068 .56095 Mdot
.33809 .63097 Mdot
.54438 .34369 Mdot
.63179 .56265 Mdot
.56006 .57551 Mdot
.56501 .341 Mdot
.5418 .46803 Mdot
.6688 .4303 Mdot
.58664 .59448 Mdot
.59296 .58593 Mdot
.44523 .69477 Mdot
.46631 .52437 Mdot
.74443 .34569 Mdot
.62834 .52171 Mdot
.45095 .69693 Mdot
.55487 .38271 Mdot
.5839 .54225 Mdot
.46312 .83081 Mdot
.29313 .41351 Mdot
.58697 .52411 Mdot
.34056 .5696 Mdot
.62903 .62191 Mdot
.75857 .66112 Mdot
.65339 .58582 Mdot
.56934 .33446 Mdot
.54474 .35832 Mdot
.2902 .26346 Mdot
.5799 .34524 Mdot
.37983 .52246 Mdot
.39659 .39269 Mdot
.30481 .74337 Mdot
.35766 .57139 Mdot
.68348 .57648 Mdot
.19078 .35679 Mdot
.56102 .54856 Mdot
.65804 .52933 Mdot
.83726 .53724 Mdot
.33337 .562 Mdot
.57381 .36972 Mdot
.485 .40073 Mdot
.68803 .55095 Mdot
.40586 .35383 Mdot
.54877 .53269 Mdot
.64737 .5931 Mdot
.77486 .63361 Mdot
.31585 .73723 Mdot
.38548 .41997 Mdot
.60943 .61237 Mdot
.6251 .52002 Mdot
.31179 .56761 Mdot
.61577 .55353 Mdot
.44078 .66539 Mdot
.56477 .36381 Mdot
.3205 .53566 Mdot
.41848 .66829 Mdot
.57309 .54184 Mdot
.43781 .69141 Mdot
.36492 .52573 Mdot
.37208 .38943 Mdot
.61385 .52801 Mdot
.45251 .64986 Mdot
.43551 .69059 Mdot
.63236 .57282 Mdot
.534 .35325 Mdot
.56639 .48716 Mdot
.58451 .57698 Mdot
.64336 .52875 Mdot
.58962 .35404 Mdot
.57944 .86933 Mdot
.65318 .5797 Mdot
.56811 .73721 Mdot
.60101 .33268 Mdot
.51177 .49798 Mdot
.35704 .57494 Mdot
.65627 .58769 Mdot
.37189 .38964 Mdot
.37579 .39831 Mdot
.33644 .50521 Mdot
.52905 .33595 Mdot
.29368 .60158 Mdot
.51405 .36033 Mdot
.66381 .61682 Mdot
.62154 .61334 Mdot
.59447 .43021 Mdot
.65351 .78061 Mdot
.59347 .36482 Mdot
.41007 .5519 Mdot
.5098 .31862 Mdot
.38675 .41461 Mdot
.36176 .49791 Mdot
.52099 .36425 Mdot
.58744 .36159 Mdot
.53016 .35938 Mdot
.43258 .64641 Mdot
.34201 .63393 Mdot
.60459 .33189 Mdot
.60552 .32031 Mdot
.60442 .59047 Mdot
.63342 .52526 Mdot
.80135 .55954 Mdot
.78952 .55184 Mdot
.45068 .6841 Mdot
.36779 .51521 Mdot
.32073 .18325 Mdot
.37162 .37878 Mdot
.25137 .32705 Mdot
.65454 .52838 Mdot
.37559 .13858 Mdot
.65526 .55405 Mdot
.61967 .54973 Mdot
.52343 .36727 Mdot
.45356 .65356 Mdot
.43168 .67679 Mdot
.5884 .33022 Mdot
.61158 .33309 Mdot
.44094 .66739 Mdot
.19515 .52598 Mdot
.48558 .84187 Mdot
.298 .49739 Mdot
.55865 .34415 Mdot
.73879 .55793 Mdot
.4134 .41297 Mdot
.68511 .52062 Mdot
.4011 .42918 Mdot
.3423 .53488 Mdot
.31634 .52881 Mdot
.41105 .35638 Mdot
.59651 .58366 Mdot
.3535 .51263 Mdot
.56564 .54876 Mdot
.22754 .40964 Mdot
.72928 .46587 Mdot
.32564 .60671 Mdot
.71056 .56655 Mdot
.54625 .46165 Mdot
.33365 .35162 Mdot
.57834 .53935 Mdot
.43833 .80534 Mdot
.43433 .68677 Mdot
.67417 .61354 Mdot
.40141 .35094 Mdot
.83411 .56029 Mdot
.60506 .52443 Mdot
.56496 .33419 Mdot
.3835 .37245 Mdot
.5394 .22306 Mdot
.51193 .25563 Mdot
.62992 .53171 Mdot
.50156 .14715 Mdot
.62533 .34561 Mdot
.33838 .52078 Mdot
.6147 .25193 Mdot
.60532 .34973 Mdot
.39902 .62487 Mdot
.4668 .78659 Mdot
.23858 .68589 Mdot
.56662 .37069 Mdot
.30688 .5391 Mdot
.54419 .37562 Mdot
.40915 .66911 Mdot
.57229 .39222 Mdot
.35159 .52853 Mdot
.5846 .55419 Mdot
.35502 .56267 Mdot
.43853 .64773 Mdot
.7933 .38895 Mdot
.38565 .41994 Mdot
.38675 .52487 Mdot
.4125 .37254 Mdot
.48291 .72772 Mdot
.54068 .77184 Mdot
.41961 .3891 Mdot
.65952 .3795 Mdot
.62749 .61211 Mdot
.60653 .34124 Mdot
.36586 .56335 Mdot
.3807 .73817 Mdot
.48038 .38586 Mdot
.57355 .355 Mdot
.35766 .50775 Mdot
.53246 .25907 Mdot
.63746 .35937 Mdot
.61354 .61466 Mdot
.50485 .63359 Mdot
.56245 .34482 Mdot
.30865 .54457 Mdot
.80072 .3565 Mdot
.54858 .3776 Mdot
.3781 .56166 Mdot
.41181 .40931 Mdot
.38477 .39155 Mdot
.60598 .60266 Mdot
.4385 .39297 Mdot
.33799 .50976 Mdot
.35252 .39888 Mdot
.54599 .32119 Mdot
.56514 .22889 Mdot
.44043 .63849 Mdot
.34533 .55228 Mdot
.56576 .5325 Mdot
.61907 .33697 Mdot
.29758 .36601 Mdot
.67475 .44554 Mdot
.60753 .18884 Mdot
.36136 .56159 Mdot
.57131 .36377 Mdot
.5609 .33439 Mdot
.67226 .59521 Mdot
.55102 .26025 Mdot
.29422 .60828 Mdot
.58018 .44055 Mdot
.53414 .42123 Mdot
.35637 .57932 Mdot
.3677 .47656 Mdot
.55322 .52953 Mdot
.60486 .58007 Mdot
.39045 .41649 Mdot
.58592 .55752 Mdot
.53182 .33902 Mdot
.63319 .59878 Mdot
.41527 .38465 Mdot
.33283 .53099 Mdot
.60861 .52711 Mdot
.43283 .69241 Mdot
.43107 .3908 Mdot
.37105 .36522 Mdot
.34174 .55465 Mdot
.59728 .3419 Mdot
.50589 .51859 Mdot
.36674 .55307 Mdot
.60763 .58469 Mdot
.45792 .54492 Mdot
.61669 .51431 Mdot
.51742 .56227 Mdot
.55819 .38106 Mdot
.32042 .53766 Mdot
.5251 .37734 Mdot
.40674 .37671 Mdot
.44063 .76773 Mdot
.59926 .55722 Mdot
.37358 .56558 Mdot
.32288 .38657 Mdot
.511 .56903 Mdot
.57261 .30327 Mdot
.21835 .50361 Mdot
.60882 .35387 Mdot
.37149 .51948 Mdot
.208 .36346 Mdot
.42031 .64875 Mdot
.33831 .49797 Mdot
.61048 .8039 Mdot
.33141 .55396 Mdot
.61501 .60248 Mdot
.65216 .57473 Mdot
.3243 .52924 Mdot
.43726 .69711 Mdot
.84061 .47777 Mdot
.33414 .48219 Mdot
.57016 .36933 Mdot
.20187 .4475 Mdot
.68686 .23157 Mdot
.34885 .34237 Mdot
.38913 .41447 Mdot
.67232 .52274 Mdot
.64494 .60281 Mdot
.39369 .3514 Mdot
.38343 .42207 Mdot
.40822 .65181 Mdot
.37722 .55379 Mdot
.62109 .32896 Mdot
.37537 .34772 Mdot
.57327 .27135 Mdot
.36736 .65408 Mdot
.66866 .59613 Mdot
.35798 .24257 Mdot
.6519 .52746 Mdot
.50537 .76825 Mdot
.41738 .38201 Mdot
.59467 .51012 Mdot
.62 .61821 Mdot
.38124 .36511 Mdot
.43872 .66023 Mdot
.39643 .4868 Mdot
.35339 .5463 Mdot
.58771 .85696 Mdot
.56488 .56854 Mdot
.62785 .59865 Mdot
.39734 .36065 Mdot
.29652 .66216 Mdot
.56141 .35604 Mdot
.59683 .37047 Mdot
.33182 .52041 Mdot
.45676 .41855 Mdot
.62373 .60767 Mdot
.57946 .54586 Mdot
.3583 .54114 Mdot
.37838 .51363 Mdot
.24929 .48986 Mdot
.63731 .58132 Mdot
.39338 .37248 Mdot
.47605 .69334 Mdot
.4193 .37601 Mdot
.60795 .51221 Mdot
.62989 .59576 Mdot
.66698 .55971 Mdot
.57478 .52344 Mdot
.40604 .43187 Mdot
.61628 .50999 Mdot
.56565 .60501 Mdot
.57228 .3611 Mdot
.63527 .53107 Mdot
.51812 .4113 Mdot
.58915 .56489 Mdot
.43927 .66382 Mdot
.71742 .32121 Mdot
.60605 .52479 Mdot
.63953 .59677 Mdot
.35436 .48648 Mdot
.59871 .5449 Mdot
.37128 .3946 Mdot
.54952 .34651 Mdot
.39176 .36477 Mdot
.37632 .4005 Mdot
.32215 .56782 Mdot
.41317 .69381 Mdot
.65408 .51834 Mdot
.44976 .66396 Mdot
.68593 .58145 Mdot
.56814 .55423 Mdot
.38305 .694 Mdot
.38192 .17579 Mdot
.76839 .34416 Mdot
.59824 .55915 Mdot
.33052 .55835 Mdot
.33723 .56665 Mdot
.52948 .49901 Mdot
.59247 .60735 Mdot
.39971 .34211 Mdot
.38371 .41284 Mdot
.7449 .62786 Mdot
.66962 .70072 Mdot
.43935 .66308 Mdot
.46834 .50629 Mdot
.57652 .58688 Mdot
.59228 .51226 Mdot
.56186 .56668 Mdot
.31767 .55549 Mdot
.69116 .50606 Mdot
.35321 .49692 Mdot
.37013 .29093 Mdot
.41003 .36046 Mdot
.61864 .52721 Mdot
.33661 .26398 Mdot
.57647 .31666 Mdot
.54898 .34581 Mdot
.3755 .35592 Mdot
.36109 .59426 Mdot
.81643 .5049 Mdot
.28614 .75792 Mdot
.58878 .39419 Mdot
.44641 .64818 Mdot
.57486 .54991 Mdot
.32818 .53872 Mdot
.53958 .33521 Mdot
.44663 .64915 Mdot
.6006 .51767 Mdot
.34391 .63456 Mdot
.59622 .56684 Mdot
.41926 .23146 Mdot
.53881 .36559 Mdot
.43888 .84673 Mdot
.53023 .33266 Mdot
.4344 .38089 Mdot
.40855 .34988 Mdot
.63961 .58487 Mdot
.60046 .40237 Mdot
.60654 .35152 Mdot
.42423 .56639 Mdot
.40896 .68448 Mdot
.36506 .31517 Mdot
.41923 .65322 Mdot
.34667 .52034 Mdot
.4322 .65037 Mdot
.35371 .52776 Mdot
.81409 .49055 Mdot
.61877 .2933 Mdot
.4226 .6756 Mdot
.32415 .37478 Mdot
.64942 .59917 Mdot
.45241 .68343 Mdot
.55355 .57559 Mdot
.52271 .53464 Mdot
.35988 .54365 Mdot
.40832 .67929 Mdot
.58843 .51743 Mdot
.71413 .72003 Mdot
.41667 .39772 Mdot
.40216 .34371 Mdot
.55404 .5758 Mdot
.34651 .57911 Mdot
.54422 .38168 Mdot
.37718 .79651 Mdot
.38945 .33344 Mdot
.6487 .58183 Mdot
.66387 .57603 Mdot
.60899 .34914 Mdot
.29004 .28274 Mdot
.63174 .59022 Mdot
.56279 .62387 Mdot
.64021 .58105 Mdot
.42682 .37536 Mdot
.58154 .37689 Mdot
.55461 .33876 Mdot
.35695 .50854 Mdot
.57497 .31341 Mdot
.49852 .61229 Mdot
.35859 .27105 Mdot
.53958 .53356 Mdot
.40629 .38189 Mdot
.39716 .28621 Mdot
.3586 .29095 Mdot
.6163 .78966 Mdot
.55562 .30796 Mdot
.6158 .50601 Mdot
.5791 .31191 Mdot
.42335 .65444 Mdot
.54638 .33752 Mdot
.52683 .34322 Mdot
.59092 .53313 Mdot
.63081 .53583 Mdot
.33479 .52604 Mdot
.54082 .26585 Mdot
.59984 .33897 Mdot
.65449 .55407 Mdot
.66898 .57906 Mdot
.56517 .54226 Mdot
.43442 .57511 Mdot
.58826 .37053 Mdot
.16987 .50753 Mdot
.60112 .67925 Mdot
.59939 .34019 Mdot
.86186 .44451 Mdot
.31494 .37978 Mdot
.40001 .55066 Mdot
.41611 .52118 Mdot
.64263 .57804 Mdot
.38681 .53895 Mdot
.62445 .53311 Mdot
.35938 .24316 Mdot
.60287 .53953 Mdot
.4418 .66512 Mdot
.56558 .55988 Mdot
.32093 .51784 Mdot
.36188 .55813 Mdot
.64666 .58628 Mdot
.61145 .52939 Mdot
.80892 .40982 Mdot
.55838 .39461 Mdot
.54363 .34992 Mdot
.29016 .59131 Mdot
.41871 .67835 Mdot
.40664 .35277 Mdot
.61489 .55986 Mdot
.32083 .56501 Mdot
.36036 .55969 Mdot
.60025 .35906 Mdot
.37073 .53155 Mdot
.40588 .39517 Mdot
.60295 .5561 Mdot
.39642 .34847 Mdot
.42502 .64481 Mdot
.58266 .37514 Mdot
.63317 .53128 Mdot
.60393 .59045 Mdot
.54502 .35854 Mdot
.61004 .50034 Mdot
.43579 .69588 Mdot
.33626 .55824 Mdot
.56533 .37172 Mdot
.39255 .39274 Mdot
.34867 .52172 Mdot
.64107 .52481 Mdot
.4652 .15636 Mdot
.60558 .59941 Mdot
.64736 .56851 Mdot
.64649 .79601 Mdot
.57311 .58193 Mdot
.36435 .56217 Mdot
.54178 .33181 Mdot
.67074 .62488 Mdot
.57749 .70164 Mdot
.52901 .89512 Mdot
.34846 .49727 Mdot
.57617 .55725 Mdot
.65179 .76488 Mdot
.57894 .55917 Mdot
.68821 .47613 Mdot
.38959 .52375 Mdot
.52323 .45024 Mdot
.57345 .5192 Mdot
.39014 .40418 Mdot
.32755 .53012 Mdot
.35775 .52772 Mdot
.21512 .41439 Mdot
.58535 .5363 Mdot
.43858 .51368 Mdot
.60781 .51624 Mdot
.3917 .39558 Mdot
.69325 .66678 Mdot
.36379 .55874 Mdot
.65168 .22612 Mdot
.63397 .57617 Mdot
.59046 .36143 Mdot
.33885 .49175 Mdot
.43823 .33442 Mdot
.64661 .53206 Mdot
.44797 .67944 Mdot
.36702 .40106 Mdot
.54103 .54677 Mdot
.40594 .38554 Mdot
.64066 .52708 Mdot
.69713 .61374 Mdot
.54533 .20154 Mdot
.53176 .35555 Mdot
.40187 .41495 Mdot
.45757 .56182 Mdot
.61168 .50699 Mdot
.56498 .37047 Mdot
.5712 .35662 Mdot
.42973 .64451 Mdot
.49749 .48742 Mdot
.49342 .23502 Mdot
.74131 .50933 Mdot
.20688 .43136 Mdot
.35099 .49061 Mdot
.28838 .48382 Mdot
.64382 .56103 Mdot
.48909 .61745 Mdot
.37401 .40068 Mdot
.60185 .59853 Mdot
.74983 .37404 Mdot
.58402 .32113 Mdot
.60468 .59637 Mdot
.43469 .67354 Mdot
.45046 .61845 Mdot
.48259 .68067 Mdot
.51819 .79959 Mdot
.33741 .53319 Mdot
.57184 .61118 Mdot
.66454 .63417 Mdot
.35733 .57632 Mdot
.67286 .56172 Mdot
.36516 .56755 Mdot
.19771 .57019 Mdot
.45562 .67335 Mdot
.58388 .37092 Mdot
.34629 .32796 Mdot
.66629 .53615 Mdot
.6385 .60347 Mdot
.40673 .68668 Mdot
.6092 .57957 Mdot
.49901 .18 Mdot
.43371 .58081 Mdot
.35284 .51639 Mdot
.53041 .35818 Mdot
.67017 .56838 Mdot
.47382 .54487 Mdot
.5824 .56763 Mdot
.77743 .5037 Mdot
.64208 .59513 Mdot
.51891 .24864 Mdot
.53587 .36036 Mdot
.41106 .38097 Mdot
.59486 .50668 Mdot
.61004 .54265 Mdot
.62354 .7221 Mdot
.68425 .5625 Mdot
.59984 .50757 Mdot
.52893 .31878 Mdot
.52828 .35171 Mdot
.54668 .37516 Mdot
.34161 .502 Mdot
.71665 .67883 Mdot
.3987 .37456 Mdot
.69177 .60365 Mdot
.39373 .33635 Mdot
.63559 .43548 Mdot
.45106 .65478 Mdot
.57966 .78144 Mdot
.62841 .55838 Mdot
.56141 .32503 Mdot
.37606 .77502 Mdot
.58217 .38507 Mdot
.46087 .49403 Mdot
.3824 .37744 Mdot
.5907 .33198 Mdot
.61706 .54628 Mdot
.4943 .34735 Mdot
.67432 .75564 Mdot
.40324 .36875 Mdot
.68219 .57773 Mdot
.32617 .50616 Mdot
.36671 .61386 Mdot
.58397 .20214 Mdot
.41915 .39514 Mdot
.39596 .32525 Mdot
.58271 .53735 Mdot
.5685 .31606 Mdot
.39207 .40199 Mdot
.42562 .37439 Mdot
.36958 .5267 Mdot
.63389 .53742 Mdot
.63738 .54078 Mdot
.36951 .51449 Mdot
.39368 .36349 Mdot
.56747 .60271 Mdot
.53757 .55218 Mdot
.79935 .64822 Mdot
.54057 .2435 Mdot
.59629 .85942 Mdot
.51723 .5168 Mdot
.7169 .34832 Mdot
.3783 .80142 Mdot
.59822 .34868 Mdot
.57785 .53195 Mdot
.5809 .4933 Mdot
.33784 .50946 Mdot
.59287 .55097 Mdot
.39169 .55867 Mdot
.3761 .38204 Mdot
.83104 .5618 Mdot
.45017 .28784 Mdot
.21382 .6286 Mdot
.59242 .54868 Mdot
.57516 .29702 Mdot
.42405 .65877 Mdot
.37058 .32601 Mdot
.57134 .38073 Mdot
.56029 .5439 Mdot
.80592 .40539 Mdot
.34228 .49703 Mdot
.58577 .3501 Mdot
.83539 .44555 Mdot
.55733 .44892 Mdot
.6157 .51448 Mdot
.35659 .50088 Mdot
.41901 .80752 Mdot
.6172 .27315 Mdot
.40956 .33797 Mdot
.43914 .65947 Mdot
.32242 .53618 Mdot
.38638 .41651 Mdot
.61302 .30367 Mdot
.58621 .34165 Mdot
.56028 .38663 Mdot
.75702 .34201 Mdot
.37667 .49749 Mdot
.42249 .66144 Mdot
.66063 .72641 Mdot
.64983 .71065 Mdot
.44164 .67002 Mdot
.31612 .52837 Mdot
.53094 .34576 Mdot
.58451 .32603 Mdot
.55018 .34659 Mdot
.71838 .28577 Mdot
.57423 .30895 Mdot
.21849 .37314 Mdot
.56853 .53374 Mdot
.53501 .57636 Mdot
.57675 .55416 Mdot
.39547 .34302 Mdot
.54739 .3636 Mdot
.47657 .40518 Mdot
.67843 .59958 Mdot
.58197 .76739 Mdot
.61072 .60311 Mdot
.42478 .41062 Mdot
.61252 .59535 Mdot
.36161 .2219 Mdot
.58828 .31514 Mdot
.5963 .55586 Mdot
.40863 .42459 Mdot
.41661 .68007 Mdot
.5701 .30292 Mdot
.628 .52995 Mdot
.22601 .5398 Mdot
.56911 .57282 Mdot
.21597 .61529 Mdot
.50848 .21052 Mdot
.44771 .64973 Mdot
.41399 .21253 Mdot
.30536 .53386 Mdot
.54872 .60672 Mdot
.69378 .55918 Mdot
.40856 .3713 Mdot
.36428 .31834 Mdot
.3391 .54352 Mdot
.65442 .47531 Mdot
.54923 .58893 Mdot
.42889 .64309 Mdot
.6279 .30219 Mdot
.38822 .3543 Mdot
.6722 .56885 Mdot
.62996 .61792 Mdot
.27002 .33729 Mdot
.55123 .5813 Mdot
.65838 .58425 Mdot
.40676 .69245 Mdot
.23801 .34697 Mdot
.59067 .57062 Mdot
.46554 .49837 Mdot
.56994 .39236 Mdot
.67244 .61087 Mdot
.22283 .36071 Mdot
.65385 .57197 Mdot
.5914 .34322 Mdot
.54075 .60693 Mdot
.47517 .22799 Mdot
.41536 .69611 Mdot
.64143 .59596 Mdot
.27926 .27431 Mdot
.62454 .58061 Mdot
.39425 .37662 Mdot
.59628 .60842 Mdot
.34932 .52986 Mdot
.76934 .3374 Mdot
.35097 .50892 Mdot
.60065 .60379 Mdot
.55362 .34666 Mdot
.40343 .36011 Mdot
.67928 .26717 Mdot
.31639 .63486 Mdot
.26436 .32027 Mdot
.29262 .75214 Mdot
.41323 .68946 Mdot
.46287 .65393 Mdot
.37608 .36762 Mdot
.59534 .55783 Mdot
.18461 .41028 Mdot
.67914 .5426 Mdot
.59522 .58851 Mdot
.60381 .53871 Mdot
.53317 .77132 Mdot
.37517 .39383 Mdot
.36216 .54897 Mdot
.63055 .59295 Mdot
.60943 .50815 Mdot
.59521 .35321 Mdot
.42461 .68568 Mdot
.35543 .57472 Mdot
.43211 .6831 Mdot
.32646 .53422 Mdot
.84783 .50547 Mdot
.58677 .61292 Mdot
.41332 .6767 Mdot
.36524 .37341 Mdot
.59355 .34803 Mdot
.36834 .27025 Mdot
.35404 .52306 Mdot
.34398 .50413 Mdot
.64683 .58902 Mdot
.59397 .33811 Mdot
.52312 .37141 Mdot
.41539 .65752 Mdot
.41526 .39216 Mdot
.60486 .52483 Mdot
.57046 .56701 Mdot
.67452 .64229 Mdot
.33787 .57809 Mdot
.40895 .23218 Mdot
.26383 .51491 Mdot
.59658 .56035 Mdot
.54547 .32213 Mdot
.60681 .53125 Mdot
.2711 .68863 Mdot
.5736 .315 Mdot
.65544 .56603 Mdot
.84618 .3974 Mdot
.39185 .5796 Mdot
.44275 .25022 Mdot
.66355 .57057 Mdot
.37257 .81848 Mdot
.63745 .56045 Mdot
.83867 .56104 Mdot
.35527 .74022 Mdot
.61465 .61069 Mdot
.65018 .53397 Mdot
.70465 .44839 Mdot
.57279 .55929 Mdot
.36505 .50987 Mdot
.80225 .58015 Mdot
.57103 .38807 Mdot
.34948 .30329 Mdot
.72497 .33314 Mdot
.42389 .70125 Mdot
.33168 .52061 Mdot
.37916 .48834 Mdot
.4399 .67836 Mdot
.56027 .34197 Mdot
.59988 .5688 Mdot
.44902 .44955 Mdot
.33955 .57584 Mdot
.59461 .46742 Mdot
.39196 .37735 Mdot
.27747 .41742 Mdot
.46589 .61385 Mdot
.4053 .38945 Mdot
.63825 .53292 Mdot
.68921 .44148 Mdot
.804 .48008 Mdot
.52821 .84359 Mdot
.3931 .42016 Mdot
.40416 .36689 Mdot
.7455 .30804 Mdot
.41973 .63768 Mdot
.27015 .34336 Mdot
.51674 .25272 Mdot
.40496 .35568 Mdot
.6323 .33536 Mdot
.37477 .51429 Mdot
.43908 .41118 Mdot
.63695 .62952 Mdot
.56905 .54114 Mdot
.61474 .5455 Mdot
.42021 .38355 Mdot
.5103 .55558 Mdot
.59777 .23211 Mdot
.41373 .37085 Mdot
.65149 .49594 Mdot
.50144 .45207 Mdot
.34122 .44703 Mdot
.37348 .54209 Mdot
.40549 .6778 Mdot
.43805 .63383 Mdot
.58244 .36595 Mdot
.40834 .68565 Mdot
.47373 .62738 Mdot
.61038 .57309 Mdot
.41765 .36801 Mdot
.31697 .34063 Mdot
.38713 .3893 Mdot
.43629 .67933 Mdot
.41039 .64609 Mdot
.57147 .36076 Mdot
.542 .34625 Mdot
.70244 .37476 Mdot
.52787 .65248 Mdot
.58563 .583 Mdot
.39342 .73486 Mdot
.52338 .3518 Mdot
.56584 .46759 Mdot
.40561 .68002 Mdot
.41886 .68071 Mdot
.61037 .73033 Mdot
.6272 .55512 Mdot
.60182 .43726 Mdot
.62221 .55667 Mdot
.63987 .67198 Mdot
.65822 .53708 Mdot
.37003 .52765 Mdot
.63463 .55142 Mdot
.61099 .73711 Mdot
.63509 .5042 Mdot
.64918 .60409 Mdot
.31875 .55964 Mdot
.54031 .57282 Mdot
.34935 .53177 Mdot
.59213 .59703 Mdot
.45851 .6578 Mdot
.33159 .51787 Mdot
.56271 .71023 Mdot
.58589 .73779 Mdot
.3141 .53122 Mdot
.44613 .65452 Mdot
.44093 .70086 Mdot
.53018 .73128 Mdot
.57219 .38082 Mdot
.6789 .52331 Mdot
.5935 .5559 Mdot
.36929 .50136 Mdot
.38237 .40838 Mdot
.64857 .52868 Mdot
.65708 .59044 Mdot
.66205 .55762 Mdot
.58419 .36569 Mdot
.2983 .61231 Mdot
.41079 .67413 Mdot
.3706 .51354 Mdot
.50152 .52609 Mdot
.35473 .58033 Mdot
.64318 .61584 Mdot
.58692 .49265 Mdot
.7378 .35314 Mdot
.33517 .42788 Mdot
.71419 .27457 Mdot
.58551 .34344 Mdot
.33738 .5679 Mdot
.44473 .64009 Mdot
.60371 .49206 Mdot
.56137 .32376 Mdot
.35146 .52908 Mdot
.59672 .56614 Mdot
.68026 .57087 Mdot
.34409 .28674 Mdot
.48865 .68008 Mdot
.57676 .72886 Mdot
.33378 .50611 Mdot
.31513 .51546 Mdot
.5717 .75177 Mdot
.47431 .67872 Mdot
.47861 .39149 Mdot
.58424 .54512 Mdot
.4469 .68021 Mdot
.54341 .33182 Mdot
.76786 .36769 Mdot
.42008 .35966 Mdot
.54934 .26221 Mdot
.59404 .54901 Mdot
.53697 .46048 Mdot
.55455 .34828 Mdot
.43652 .67154 Mdot
.42166 .37991 Mdot
.43788 .6269 Mdot
.32632 .56325 Mdot
.22537 .67966 Mdot
.61751 .58243 Mdot
.64373 .59199 Mdot
.42051 .41014 Mdot
.57396 .31948 Mdot
.43448 .70761 Mdot
.20271 .45859 Mdot
.36362 .52771 Mdot
.18913 .39341 Mdot
.54872 .32097 Mdot
.73576 .55119 Mdot
.37765 .53331 Mdot
.37962 .34571 Mdot
.53905 .71908 Mdot
.4097 .39048 Mdot
.61017 .60611 Mdot
.56237 .3292 Mdot
.39673 .41483 Mdot
.5616 .24816 Mdot
.6847 .76298 Mdot
.73721 .54851 Mdot
.60978 .56791 Mdot
.75337 .68899 Mdot
.21326 .57473 Mdot
.5853 .3971 Mdot
.37933 .41004 Mdot
.60331 .60003 Mdot
.63987 .5997 Mdot
.6234 .58242 Mdot
.38355 .40534 Mdot
.39604 .73268 Mdot
.36135 .54084 Mdot
.578 .54392 Mdot
.40968 .65001 Mdot
.34472 .53633 Mdot
.41681 .33003 Mdot
.3711 .54777 Mdot
.53028 .32401 Mdot
.65946 .60735 Mdot
.42703 .32048 Mdot
.85791 .36482 Mdot
.39804 .36534 Mdot
.31688 .56162 Mdot
.57588 .60254 Mdot
.29998 .40516 Mdot
.53347 .3717 Mdot
.36411 .52516 Mdot
.62605 .59996 Mdot
.32569 .36411 Mdot
.78605 .37354 Mdot
.36852 .55375 Mdot
.56001 .32342 Mdot
.53604 .83979 Mdot
.58814 .55386 Mdot
.63096 .56731 Mdot
.58742 .33451 Mdot
.6399 .38128 Mdot
.81086 .38009 Mdot
.61011 .53019 Mdot
.41259 .38036 Mdot
.17291 .60542 Mdot
.656 .59198 Mdot
.65839 .67711 Mdot
.33096 .52732 Mdot
.46063 .38335 Mdot
.4553 .222 Mdot
.62337 .49616 Mdot
.23704 .39668 Mdot
.34447 .3382 Mdot
.70285 .71088 Mdot
.38965 .56609 Mdot
.26044 .6111 Mdot
.74519 .67551 Mdot
.41295 .42576 Mdot
.55033 .29732 Mdot
.22149 .42385 Mdot
.65553 .28184 Mdot
.46393 .82548 Mdot
.29394 .67769 Mdot
.80607 .40332 Mdot
.46406 .44354 Mdot
.32622 .54948 Mdot
.56144 .46389 Mdot
.62462 .53128 Mdot
.21577 .58164 Mdot
.54512 .21037 Mdot
.56562 .21736 Mdot
.75384 .69004 Mdot
.70512 .49256 Mdot
.65708 .7621 Mdot
.62552 .79203 Mdot
.68671 .65232 Mdot
.27838 .5035 Mdot
.18217 .40315 Mdot
.82591 .52132 Mdot
.1846 .49424 Mdot
.53281 .56757 Mdot
.45245 .49394 Mdot
.24145 .67076 Mdot
.60184 .28825 Mdot
.63842 .34982 Mdot
.35988 .51188 Mdot
.56658 .38364 Mdot
.2588 .36418 Mdot
.61071 .34888 Mdot
.47317 .22569 Mdot
.56074 .84256 Mdot
.67675 .76744 Mdot
.29239 .27208 Mdot
.38234 .81477 Mdot
.74112 .36931 Mdot
.15973 .37898 Mdot
.38299 .56536 Mdot
.60118 .35512 Mdot
.51931 .76508 Mdot
.63262 .73607 Mdot
.42418 .30213 Mdot
.20944 .48651 Mdot
.36601 .6325 Mdot
.49728 .70617 Mdot
.56289 .33548 Mdot
.42572 .21319 Mdot
.44648 .38551 Mdot
.44372 .29196 Mdot
.81294 .54708 Mdot
.54042 .82254 Mdot
.43736 .45563 Mdot
.22548 .46856 Mdot
.28675 .44007 Mdot
.621 .23424 Mdot
.58181 .68492 Mdot
.55027 .47273 Mdot
.5318 .24243 Mdot
.34951 .77953 Mdot
.66615 .32965 Mdot
.63579 .66897 Mdot
.64514 .72882 Mdot
.84775 .48187 Mdot
.24201 .63056 Mdot
.73334 .2454 Mdot
.61187 .35516 Mdot
.66531 .57481 Mdot
.65232 .39063 Mdot
.25276 .29642 Mdot
.39661 .66656 Mdot
.49985 .80249 Mdot
.40605 .66458 Mdot
.52547 .33467 Mdot
.79173 .36458 Mdot
.2317 .35049 Mdot
.21058 .33646 Mdot
.46018 .65457 Mdot
.69113 .60689 Mdot
.36161 .84993 Mdot
.64694 .75026 Mdot
.43672 .27047 Mdot
.80258 .63715 Mdot
.51368 .43472 Mdot
.55718 .22674 Mdot
.39359 .41513 Mdot
.76705 .65445 Mdot
.57873 .32748 Mdot
.7332 .23194 Mdot
.8449 .54755 Mdot
.76707 .38149 Mdot
.86806 .66018 Mdot
.55225 .76225 Mdot
.52717 .45156 Mdot
.34932 .37165 Mdot
.5422 .68569 Mdot
.61753 .24836 Mdot
.44383 .75712 Mdot
.2971 .41532 Mdot
.36093 .82 Mdot
.73727 .6927 Mdot
.19596 .36257 Mdot
.19623 .61885 Mdot
.65494 .30408 Mdot
.47529 .53824 Mdot
.7051 .5555 Mdot
.36366 .60805 Mdot
.48145 .80946 Mdot
.85467 .47169 Mdot
.60401 .68077 Mdot
.52109 .8966 Mdot
.44937 .70945 Mdot
.35447 .65903 Mdot
.60621 .83705 Mdot
.50588 .71247 Mdot
.46481 .20935 Mdot
.70942 .67241 Mdot
.69736 .52322 Mdot
.49071 .56782 Mdot
.49783 .8076 Mdot
.40424 .25174 Mdot
.79057 .6088 Mdot
.41538 .81981 Mdot
.27305 .33405 Mdot
.74094 .47994 Mdot
.65798 .69582 Mdot
.61169 .31318 Mdot
.50654 .65188 Mdot
.4678 .21733 Mdot
.70786 .74986 Mdot
.42845 .41199 Mdot
.73377 .73984 Mdot
.81403 .38864 Mdot
.58073 .61146 Mdot
.66277 .508 Mdot
.57991 .43618 Mdot
.50828 .66246 Mdot
.5487 .59644 Mdot
.324 .29618 Mdot
.6672 .78002 Mdot
.7938 .49296 Mdot
.33232 .34776 Mdot
.35722 .32073 Mdot
.60101 .8443 Mdot
.67494 .40316 Mdot
.47212 .67663 Mdot
.78583 .5877 Mdot
.6256 .24758 Mdot
.34482 .5466 Mdot
.20277 .35918 Mdot
.37027 .34373 Mdot
.78034 .37496 Mdot
.73804 .50794 Mdot
.6919 .3158 Mdot
.66771 .7804 Mdot
.26325 .59826 Mdot
.80331 .38402 Mdot
.48206 .73755 Mdot
.17843 .4542 Mdot
.34154 .44291 Mdot
.55798 .51665 Mdot
.21127 .50015 Mdot
.4428 .69664 Mdot
.71381 .41505 Mdot
.16185 .55088 Mdot
.32088 .6809 Mdot
.54988 .5458 Mdot
.76607 .37635 Mdot
.401 .5167 Mdot
.49271 .34845 Mdot
.64234 .19407 Mdot
.66001 .59763 Mdot
.66623 .7177 Mdot
.23854 .58696 Mdot
.5389 .67074 Mdot
.46992 .84622 Mdot
.30155 .72825 Mdot
.77128 .27496 Mdot
.78065 .65552 Mdot
.30497 .6295 Mdot
.73352 .68022 Mdot
.73245 .71456 Mdot
.77112 .28065 Mdot
.68165 .53731 Mdot
.43499 .37568 Mdot
.43788 .14889 Mdot
.37435 .54369 Mdot
.63622 .74411 Mdot
.2069 .43098 Mdot
.44373 .61055 Mdot
.50634 .38993 Mdot
.63759 .47063 Mdot
.46079 .45145 Mdot
.55226 .39391 Mdot
.54963 .59634 Mdot
.70707 .24946 Mdot
.81777 .33287 Mdot
.72822 .25221 Mdot
.29462 .74196 Mdot
.76857 .64508 Mdot
.52066 .4758 Mdot
.26948 .29182 Mdot
.56775 .47007 Mdot
.58424 .52062 Mdot
.41236 .6198 Mdot
.54433 .76408 Mdot
.74837 .34567 Mdot
.4745 .29112 Mdot
.62478 .29701 Mdot
.49694 .80438 Mdot
.12192 .61072 Mdot
.71901 .37873 Mdot
.20554 .39662 Mdot
.46586 .64526 Mdot
.52722 .65577 Mdot
.44596 .79157 Mdot
.71803 .31681 Mdot
.63619 .79571 Mdot
.55201 .39319 Mdot
.19236 .48024 Mdot
.32758 .70485 Mdot
.54594 .29446 Mdot
.30412 .6154 Mdot
.63247 .76938 Mdot
.36829 .30332 Mdot
.69576 .29016 Mdot
.50641 .268 Mdot
.65928 .37409 Mdot
.41999 .58349 Mdot
.27093 .43807 Mdot
.16835 .50542 Mdot
.27492 .68006 Mdot
.65935 .67323 Mdot
.49374 .45488 Mdot
.39496 .21593 Mdot
.33656 .37875 Mdot
.63095 .6747 Mdot
.5126 .40809 Mdot
.69643 .69231 Mdot
.725 .18964 Mdot
.65517 .21995 Mdot
.55167 .85322 Mdot
.40915 .7559 Mdot
.54402 .55083 Mdot
.61802 .80976 Mdot
.69982 .21848 Mdot
.87004 .43381 Mdot
.25359 .44939 Mdot
.37861 .5763 Mdot
.38828 .33834 Mdot
.73838 .28311 Mdot
.38671 .7166 Mdot
.58487 .81606 Mdot
.63673 .68879 Mdot
.36813 .37193 Mdot
.35297 .18355 Mdot
.84162 .49257 Mdot
.74257 .53167 Mdot
.49251 .66817 Mdot
.57424 .50631 Mdot
.44757 .1925 Mdot
.60675 .356 Mdot
.30656 .46312 Mdot
.53736 .65494 Mdot
.3487 .55583 Mdot
.48659 .77646 Mdot
.20503 .50314 Mdot
.56548 .55887 Mdot
.46456 .55285 Mdot
.58438 .30538 Mdot
.33418 .43591 Mdot
.39298 .2796 Mdot
.85856 .40404 Mdot
.45234 .62783 Mdot
.56849 .52465 Mdot
.55039 .67381 Mdot
.30511 .60934 Mdot
.80084 .35613 Mdot
.37286 .37229 Mdot
.72026 .71235 Mdot
.43746 .47336 Mdot
.51011 .64655 Mdot
.61873 .26638 Mdot
.5344 .50935 Mdot
.63627 .61015 Mdot
.33999 .76292 Mdot
.78443 .47863 Mdot
.52578 .29413 Mdot
.65299 .62812 Mdot
.58119 .47018 Mdot
.60957 .81394 Mdot
.46015 .62208 Mdot
.28094 .4255 Mdot
.70739 .73042 Mdot
.38067 .39444 Mdot
.57624 .3116 Mdot
.42497 .72814 Mdot
.18687 .50839 Mdot
.74758 .59163 Mdot
.78502 .37171 Mdot
.46226 .60612 Mdot
.32749 .67506 Mdot
.70322 .74177 Mdot
.70583 .71813 Mdot
.38438 .19755 Mdot
.61839 .36946 Mdot
.56958 .65067 Mdot
.18111 .50972 Mdot
.52608 .36639 Mdot
.25783 .33717 Mdot
.28108 .31774 Mdot
.84082 .53125 Mdot
.45828 .55302 Mdot
.37095 .82657 Mdot
.57595 .72566 Mdot
.46772 .7896 Mdot
.6768 .26336 Mdot
.17849 .47914 Mdot
.60923 .76684 Mdot
.57679 .39922 Mdot
.70873 .4645 Mdot
.53809 .54059 Mdot
.34034 .2481 Mdot
.43351 .15762 Mdot
.41779 .72391 Mdot
.54178 .42371 Mdot
.42196 .82377 Mdot
.60237 .57935 Mdot
.62083 .19307 Mdot
.19974 .49518 Mdot
.73618 .29964 Mdot
.37085 .36129 Mdot
.62693 .52148 Mdot
.66548 .53073 Mdot
.75824 .63149 Mdot
.46419 .22877 Mdot
.70509 .68566 Mdot
.17906 .60673 Mdot
.43356 .80853 Mdot
.6312 .29565 Mdot
.63968 .73931 Mdot
.54249 .8247 Mdot
.22009 .58663 Mdot
.48983 .48425 Mdot
.44046 .76401 Mdot
.51988 .71118 Mdot
.36755 .8013 Mdot
.49498 .38541 Mdot
.39618 .47685 Mdot
.36273 .29561 Mdot
.2529 .55083 Mdot
.73211 .31533 Mdot
.64648 .53775 Mdot
.83543 .44645 Mdot
.60296 .79994 Mdot
.42162 .19185 Mdot
.55871 .19853 Mdot
.66109 .22239 Mdot
.77091 .48365 Mdot
.24995 .62892 Mdot
.21153 .55144 Mdot
.15785 .50173 Mdot
.43212 .47485 Mdot
.55514 .77587 Mdot
.5003 .72356 Mdot
.70495 .73741 Mdot
.42439 .40512 Mdot
.50299 .25284 Mdot
.33914 .32908 Mdot
.72195 .68359 Mdot
.67913 .41486 Mdot
.63574 .77741 Mdot
.50018 .42705 Mdot
.77541 .27579 Mdot
.30051 .71498 Mdot
.47543 .43638 Mdot
.32302 .55705 Mdot
.26872 .62418 Mdot
.54584 .80099 Mdot
.31303 .72185 Mdot
.18471 .45134 Mdot
.3925 .57437 Mdot
.50147 .54637 Mdot
.71075 .51075 Mdot
.50189 .64895 Mdot
.33644 .76295 Mdot
.54932 .6737 Mdot
.66616 .77328 Mdot
.76919 .62757 Mdot
.83381 .44283 Mdot
.56109 .76237 Mdot
.28107 .74349 Mdot
.43704 .26756 Mdot
.49087 .65287 Mdot
.20179 .49785 Mdot
.36075 .67992 Mdot
.56092 .39855 Mdot
.43614 .10229 Mdot
.22794 .67625 Mdot
.2672 .66135 Mdot
.85309 .47639 Mdot
.30087 .7331 Mdot
.33266 .42756 Mdot
.64633 .3488 Mdot
.54427 .25392 Mdot
.82267 .46325 Mdot
.60445 .5397 Mdot
.69564 .23242 Mdot
.51991 .63647 Mdot
.84688 .36131 Mdot
.58368 .82356 Mdot
.53606 .41842 Mdot
.65621 .60942 Mdot
.36592 .50694 Mdot
.43284 .50561 Mdot
.69993 .65439 Mdot
.65284 .42144 Mdot
.50244 .20567 Mdot
.33737 .39956 Mdot
.3826 .56337 Mdot
.30019 .5986 Mdot
.57662 .39565 Mdot
.41306 .7494 Mdot
.25746 .53449 Mdot
.3222 .58784 Mdot
.42638 .45592 Mdot
.58053 .66997 Mdot
.4458 .22109 Mdot
.744 .54217 Mdot
.72222 .31819 Mdot
.40943 .31118 Mdot
.37166 .52349 Mdot
.74863 .52403 Mdot
.24107 .67706 Mdot
.41799 .81115 Mdot
.85303 .46832 Mdot
.48706 .56425 Mdot
.66667 .44333 Mdot
.67568 .67269 Mdot
.5872 .2203 Mdot
.59609 .41015 Mdot
.34568 .42849 Mdot
.44547 .1952 Mdot
.6222 .38868 Mdot
.23105 .41475 Mdot
.83243 .56002 Mdot
.18677 .49061 Mdot
.17978 .50978 Mdot
.40043 .60837 Mdot
.64282 .64858 Mdot
.53174 .3135 Mdot
.56738 .71573 Mdot
.48059 .38067 Mdot
.20519 .32073 Mdot
.67397 .61383 Mdot
.18638 .31299 Mdot
.42691 .38208 Mdot
.64211 .28627 Mdot
.51603 .71842 Mdot
.50014 .45904 Mdot
.50543 .41847 Mdot
.28214 .69386 Mdot
.51308 .24505 Mdot
.23707 .61641 Mdot
.59298 .23364 Mdot
.38503 .56306 Mdot
.18682 .64058 Mdot
.29754 .76741 Mdot
.72278 .46851 Mdot
.5704 .58534 Mdot
.24182 .69957 Mdot
.37229 .57789 Mdot
.73866 .33548 Mdot
.47691 .84558 Mdot
.38985 .78001 Mdot
.68359 .4877 Mdot
.51892 .65223 Mdot
.5631 .77496 Mdot
.76404 .68759 Mdot
.42371 .17247 Mdot
.48811 .80465 Mdot
.42406 .40448 Mdot
.49988 .43692 Mdot
.59745 .78715 Mdot
.5324 .22248 Mdot
.43843 .40028 Mdot
.49041 .20737 Mdot
.14199 .38881 Mdot
.64199 .74465 Mdot
.69183 .69047 Mdot
.52947 .21465 Mdot
.53156 .33154 Mdot
.50751 .23216 Mdot
.46119 .21024 Mdot
.36538 .76165 Mdot
.22094 .6325 Mdot
.46147 .2137 Mdot
.14772 .45966 Mdot
.52159 .53715 Mdot
.33901 .46905 Mdot
.59437 .4431 Mdot
.7185 .63097 Mdot
.36713 .39315 Mdot
.81666 .51426 Mdot
.45056 .81989 Mdot
.4308 .35992 Mdot
.35599 .77333 Mdot
.22323 .47798 Mdot
.72226 .5944 Mdot
.75251 .58112 Mdot
.42101 .79333 Mdot
.67963 .43163 Mdot
.34446 .23282 Mdot
.78089 .39136 Mdot
.36112 .58744 Mdot
.48783 .82983 Mdot
.3536 .51891 Mdot
.60387 .46707 Mdot
.56079 .2577 Mdot
.44905 .75847 Mdot
.72479 .28317 Mdot
.42883 .70247 Mdot
.59678 .36655 Mdot
.4331 .16153 Mdot
.53942 .33141 Mdot
.71738 .255 Mdot
.69564 .31429 Mdot
.47962 .19256 Mdot
.30344 .6356 Mdot
.29942 .66051 Mdot
.13932 .42045 Mdot
.44769 .37019 Mdot
.33042 .598 Mdot
.31295 .27642 Mdot
.60322 .35423 Mdot
.39754 .61567 Mdot
.31512 .53964 Mdot
.39513 .45808 Mdot
.27579 .3496 Mdot
.52119 .55091 Mdot
.61878 .31498 Mdot
.40691 .45942 Mdot
.7926 .55785 Mdot
.80415 .60536 Mdot
.35984 .56951 Mdot
.22745 .27913 Mdot
.64894 .61046 Mdot
.73804 .46872 Mdot
.64537 .79399 Mdot
.34731 .18709 Mdot
.27789 .55241 Mdot
.32169 .79422 Mdot
.59711 .50199 Mdot
.42449 .77847 Mdot
.57379 .33207 Mdot
.1907 .48818 Mdot
.41425 .65328 Mdot
.53467 .67335 Mdot
.42563 .36146 Mdot
.69286 .28796 Mdot
.27366 .55497 Mdot
.5524 .38405 Mdot
.39622 .76041 Mdot
.68567 .65212 Mdot
.37269 .42688 Mdot
.28378 .61205 Mdot
.72559 .47587 Mdot
.73578 .60348 Mdot
.62294 .30379 Mdot
.68156 .69954 Mdot
.17301 .53823 Mdot
.86192 .40526 Mdot
.50462 .37386 Mdot
.5546 .4537 Mdot
.3042 .31102 Mdot
.38343 .78903 Mdot
.35662 .25176 Mdot
.66541 .78643 Mdot
.57684 .66242 Mdot
.5533 .62725 Mdot
.62059 .67188 Mdot
.55045 .50192 Mdot
.47398 .47026 Mdot
.29087 .44961 Mdot
.52327 .19811 Mdot
.41727 .2325 Mdot
.65739 .33218 Mdot
.35881 .23439 Mdot
.67244 .69463 Mdot
.48274 .19539 Mdot
.33055 .58674 Mdot
.73482 .58795 Mdot
.36596 .33094 Mdot
.80641 .6072 Mdot
.65922 .78857 Mdot
.4081 .3304 Mdot
.34359 .61291 Mdot
.41221 .83256 Mdot
.6743 .53325 Mdot
.50288 .50925 Mdot
.63914 .59561 Mdot
.49969 .59445 Mdot
.31067 .2109 Mdot
.37691 .77526 Mdot
.55088 .56587 Mdot
.72139 .701 Mdot
.74315 .68203 Mdot
.80703 .30913 Mdot
.17816 .42321 Mdot
.5691 .36364 Mdot
.77672 .29508 Mdot
.49386 .20367 Mdot
.75661 .69716 Mdot
.33639 .45327 Mdot
.68076 .79757 Mdot
.70765 .45952 Mdot
.38225 .79947 Mdot
.64239 .34946 Mdot
.52951 .25197 Mdot
.24266 .579 Mdot
.50172 .50129 Mdot
.28593 .3899 Mdot
.27209 .6952 Mdot
.16561 .62016 Mdot
.55252 .51344 Mdot
.22049 .5229 Mdot
.43419 .31393 Mdot
.50505 .83325 Mdot
.30477 .70348 Mdot
.58061 .59733 Mdot
.35541 .31906 Mdot
.71978 .29118 Mdot
.58993 .67369 Mdot
.53755 .47961 Mdot
.29181 .68871 Mdot
.81233 .44813 Mdot
.68441 .66727 Mdot
.17938 .50362 Mdot
.71973 .47235 Mdot
.43774 .49311 Mdot
.61402 .50746 Mdot
.62182 .34097 Mdot
.4521 .70192 Mdot
.49067 .51665 Mdot
.58937 .5929 Mdot
.32371 .50178 Mdot
.39102 .44185 Mdot
.69276 .24608 Mdot
.41297 .25303 Mdot
.19841 .54053 Mdot
.5987 .29543 Mdot
.47123 .31689 Mdot
.34704 .26191 Mdot
.64619 .22335 Mdot
.35484 .72562 Mdot
.60326 .68087 Mdot
.66319 .75089 Mdot
.77143 .62963 Mdot
.57893 .27713 Mdot
.84178 .38372 Mdot
.37596 .40461 Mdot
.72674 .58256 Mdot
.49031 .29504 Mdot
.32732 .59987 Mdot
.59493 .62676 Mdot
.38156 .79815 Mdot
.4524 .61458 Mdot
.6199 .73763 Mdot
.24242 .63696 Mdot
.52295 .6084 Mdot
.72175 .50979 Mdot
.72044 .70844 Mdot
.35233 .49759 Mdot
.18767 .55622 Mdot
.35583 .39722 Mdot
.2951 .68688 Mdot
.77305 .63509 Mdot
.84742 .49568 Mdot
.48082 .41429 Mdot
.52227 .69955 Mdot
.6346 .57097 Mdot
.1709 .50511 Mdot
.37145 .77424 Mdot
.71224 .55148 Mdot
.26331 .4237 Mdot
.56951 .31213 Mdot
.26135 .47125 Mdot
.44823 .49607 Mdot
.81763 .47053 Mdot
.60089 .31302 Mdot
.45986 .19035 Mdot
.46142 .67093 Mdot
.53425 .4433 Mdot
.62176 .63584 Mdot
.5339 .69327 Mdot
.17809 .38103 Mdot
.65542 .62924 Mdot
.49732 .81051 Mdot
.7377 .4987 Mdot
.20171 .46209 Mdot
.41583 .7865 Mdot
.33033 .40599 Mdot
.5159 .24462 Mdot
.74072 .58768 Mdot
.34872 .30648 Mdot
.66183 .56812 Mdot
.35879 .59234 Mdot
.54624 .37978 Mdot
.48915 .83519 Mdot
.77616 .49366 Mdot
.55944 .71043 Mdot
.43467 .57479 Mdot
.53882 .48239 Mdot
.35287 .3577 Mdot
.67142 .79697 Mdot
.5231 .24373 Mdot
.55281 .65934 Mdot
.45892 .55274 Mdot
.52282 .71522 Mdot
.68713 .32614 Mdot
.85334 .52919 Mdot
.64521 .3404 Mdot
.44657 .44204 Mdot
.6388 .28313 Mdot
.25729 .64538 Mdot
.46437 .84922 Mdot
.63094 .66981 Mdot
.52789 .43045 Mdot
.41979 .7059 Mdot
.34017 .28452 Mdot
.42464 .57147 Mdot
.51582 .50601 Mdot
.40055 .46577 Mdot
.26277 .39182 Mdot
.4802 .34001 Mdot
.70677 .58801 Mdot
.5812 .75608 Mdot
.68257 .73659 Mdot
.20166 .44406 Mdot
.33917 .39211 Mdot
.28696 .4977 Mdot
.80805 .50141 Mdot
.68933 .80005 Mdot
.50128 .16511 Mdot
.63251 .57287 Mdot
.34295 .36043 Mdot
.51089 .69311 Mdot
.3247 .51348 Mdot
.43088 .21889 Mdot
.36185 .26258 Mdot
.41799 .40318 Mdot
.49486 .63532 Mdot
.64233 .7213 Mdot
.25274 .56581 Mdot
.48797 .69337 Mdot
.36839 .31983 Mdot
.67846 .23423 Mdot
.268 .71388 Mdot
.38646 .78972 Mdot
.78203 .72433 Mdot
.35604 .41794 Mdot
.62164 .47903 Mdot
.68106 .38333 Mdot
.78507 .62804 Mdot
.55826 .67854 Mdot
.76682 .35951 Mdot
.3118 .38284 Mdot
.62069 .66843 Mdot
.55408 .40556 Mdot
.60457 .74691 Mdot
.25676 .4701 Mdot
.47778 .45558 Mdot
.30336 .66755 Mdot
.84888 .38728 Mdot
.6952 .49012 Mdot
.66403 .75668 Mdot
.69373 .27061 Mdot
.15491 .49472 Mdot
.78343 .63659 Mdot
.5816 .73765 Mdot
.34173 .72958 Mdot
.65511 .39276 Mdot
.50838 .40388 Mdot
.62519 .28629 Mdot
.74383 .33929 Mdot
.77105 .55631 Mdot
.3418 .63472 Mdot
.6632 .30156 Mdot
.65796 .67343 Mdot
.77979 .54581 Mdot
.52792 .42894 Mdot
.74787 .54354 Mdot
.33672 .61049 Mdot
.51657 .21409 Mdot
.50928 .33145 Mdot
.58308 .70117 Mdot
.74504 .50953 Mdot
.29233 .32235 Mdot
.29293 .71713 Mdot
.14119 .50967 Mdot
.38059 .71711 Mdot
.64426 .23007 Mdot
.56587 .53806 Mdot
.80493 .28796 Mdot
.24503 .60278 Mdot
.25627 .59185 Mdot
.22813 .62239 Mdot
.38206 .47663 Mdot
.57262 .47713 Mdot
.66189 .56752 Mdot
.53773 .80261 Mdot
.68037 .48447 Mdot
.74153 .36304 Mdot
.67932 .27593 Mdot
.52678 .66285 Mdot
.62783 .68973 Mdot
.57048 .72078 Mdot
.55104 .6193 Mdot
.55648 .31954 Mdot
.73567 .25886 Mdot
.46815 .41603 Mdot
.71015 .54778 Mdot
.63857 .64077 Mdot
.65718 .37369 Mdot
.39734 .85149 Mdot
.51728 .40364 Mdot
.69554 .67944 Mdot
.70864 .48621 Mdot
.55868 .2799 Mdot
.36616 .24124 Mdot
.90789 .56833 Mdot
.83738 .31191 Mdot
.56444 .38698 Mdot
.20724 .3849 Mdot
.70707 .49028 Mdot
.70905 .68727 Mdot
.33496 .70831 Mdot
.25212 .41812 Mdot
.71944 .56252 Mdot
.5426 .27464 Mdot
.57582 .62312 Mdot
.23359 .5906 Mdot
.81769 .59574 Mdot
.66599 .27158 Mdot
.71921 .70277 Mdot
.54159 .50944 Mdot
.60313 .63223 Mdot
.75418 .76356 Mdot
.60899 .78231 Mdot
.67209 .59381 Mdot
.63826 .30226 Mdot
.70201 .57973 Mdot
.62373 .53483 Mdot
.45331 .7772 Mdot
.18679 .63825 Mdot
.68277 .67126 Mdot
.72077 .68403 Mdot
.61212 .33325 Mdot
.38661 .49082 Mdot
.4275 .37926 Mdot
.48741 .4133 Mdot
.67991 .59135 Mdot
.39369 .41258 Mdot
.52585 .62551 Mdot
.41535 .8269 Mdot
.43256 .55245 Mdot
.18491 .59662 Mdot
.74298 .73905 Mdot
.7703 .49932 Mdot
.35229 .28083 Mdot
.67028 .52775 Mdot
.73694 .61191 Mdot
.76913 .58729 Mdot
.50931 .53844 Mdot
.33603 .77393 Mdot
.52543 .1008 Mdot
.32153 .33223 Mdot
.82207 .48765 Mdot
.51989 .35475 Mdot
.42018 .48379 Mdot
.72904 .53085 Mdot
.35153 .45417 Mdot
.34952 .5712 Mdot
.53077 .53248 Mdot
.56652 .30258 Mdot
.3666 .36653 Mdot
.24715 .25142 Mdot
.5676 .58202 Mdot
.39933 .23161 Mdot
.74498 .70438 Mdot
.78031 .38972 Mdot
.71204 .43268 Mdot
.65833 .53187 Mdot
.43593 .29437 Mdot
.52751 .43177 Mdot
.48327 .8177 Mdot
.83412 .45974 Mdot
.67902 .72804 Mdot
.7772 .49748 Mdot
.71868 .50529 Mdot
.61059 .50805 Mdot
.41505 .64099 Mdot
.45801 .38817 Mdot
.5052 .8 Mdot
.69827 .57549 Mdot
.78439 .66054 Mdot
.27036 .55167 Mdot
.4714 .56965 Mdot
.54837 .42115 Mdot
.80129 .30711 Mdot
.67315 .34669 Mdot
.56866 .2937 Mdot
.65313 .2252 Mdot
.28858 .58256 Mdot
.49853 .66246 Mdot
.36443 .50378 Mdot
.68906 .55063 Mdot
.60693 .31171 Mdot
.6284 .19245 Mdot
.49821 .7907 Mdot
.29089 .38059 Mdot
.27172 .43252 Mdot
.21638 .40185 Mdot
.3712 .42354 Mdot
.79601 .7067 Mdot
.28066 .62095 Mdot
.65018 .2102 Mdot
.17611 .54409 Mdot
.59882 .30232 Mdot
.3093 .73769 Mdot
.65619 .62328 Mdot
.35724 .56571 Mdot
.70174 .70877 Mdot
.65972 .48881 Mdot
.79321 .37159 Mdot
.61125 .50033 Mdot
.76178 .31664 Mdot
.42297 .71068 Mdot
.3609 .61697 Mdot
.25673 .63634 Mdot
.6622 .36843 Mdot
.58892 .83818 Mdot
.33282 .28725 Mdot
.62007 .81638 Mdot
.56439 .84127 Mdot
.72974 .70677 Mdot
.7671 .34579 Mdot
.38771 .18165 Mdot
.26342 .6488 Mdot
.41597 .79443 Mdot
.30042 .4621 Mdot
.64283 .38303 Mdot
.26739 .62474 Mdot
.58297 .43535 Mdot
.46184 .23059 Mdot
.3562 .33255 Mdot
.27001 .1904 Mdot
.62453 .70453 Mdot
.53652 .31269 Mdot
.27661 .63484 Mdot
.75584 .68169 Mdot
.65971 .38431 Mdot
.26403 .68609 Mdot
.45297 .49159 Mdot
.56332 .50925 Mdot
.76993 .551 Mdot
.2002 .43534 Mdot
.26932 .59143 Mdot
.12071 .48233 Mdot
.24642 .68181 Mdot
.27591 .3896 Mdot
.46399 .4693 Mdot
.5713 .38485 Mdot
.32854 .25021 Mdot
.30507 .65837 Mdot
.31835 .76248 Mdot
.39572 .81282 Mdot
.60147 .78595 Mdot
.1424 .4155 Mdot
.19646 .48099 Mdot
.79678 .61509 Mdot
.32809 .75022 Mdot
.55878 .38742 Mdot
.56121 .7413 Mdot
.36221 .5836 Mdot
.29319 .41777 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0[oooool2o`0009Sooooo000Loooo
o`03o`000?oooooooooo0:oooooo0_l0002Hooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo0_l0002Xooooo`;o0000X?ooool001cooooo00?o0000ooooooooool0
R_ooool2o`0001_ooooo0_l0002Pooooo`007?ooool00ol0003oooooooooo`2:ooooo`;o0000_Ooo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
Ooooool2o`000<Sooooo000Looooo`03o`000?oooooooooo07oooooo0_l00038ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo07Cooooo0_l0003Cooooo`007?ooool00ol0003oooooooooo`1d
ooooo`Co00008Oooool2o`000:kooooo000Looooo`03o`000?oooooooooo07Kooooo0_l0000:oooo
o`;o00003oooool2o`0000Cooooo0_l0002^ooooo`007?ooool00ol0003oooooooooo`22ooooo`;o
00003oooool2o`0000[ooooo0_l0000Booooo`;o0000U?ooool001cooooo00?o0000ooooooooool0
R_ooool2o`0001?ooooo0_l00004ooooo`;o00001?ooool2o`0000Kooooo1?l0002Booooo`007?oo
ool2o`0008_ooooo0_l0000Iooooo`;o00001?ooool2o`0000Sooooo0_l0002Booooo`007?ooool0
0ol0003oooooooooo`2Cooooo`;o0000]?ooool001cooooo00?o0000ooooooooool0I_ooool2o`00
027ooooo0_l00008ooooo`;o00002_ooool2o`000:Sooooo000Looooo`03o`000?oooooooooo06Ko
oooo0_l00002ooooo`;o00001_ooool2o`0001Gooooo0_l0000Dooooo`;o0000Z?ooool001cooooo
00?o0000ooooooooool0J_ooool2o`0000Kooooo0_l0000Dooooo`?o00005?ooool2o`0002Gooooo
0_l00021ooooo`007?ooool00ol0003oooooooooo`28ooooo`;o00005Oooool2o`0002Gooooo0_l0
0007ooooo`;o0000N?ooool001cooooo00?o0000ooooooooool0Ooooool2o`0001[ooooo0_l0000b
ooooo`;o0000N?ooool001cooooo00?o0000ooooooooool0N_ooool2o`0000?ooooo0_l00005oooo
o`;o00003oooool2o`0000;ooooo0_l0002/ooooo`007?ooool00ol0003oooooooooo`1hooooo`Co
00002_ooool2o`0000kooooo0ol0002`ooooo`007?ooool00ol0003oooooooooo`1]ooooo`;o0000
1Oooool2o`0000;ooooo0_l00007ooooo`;o00004oooool2o`0000Kooooo0_l000000ooooooo0000
o`00002Vooooo`007?ooool00ol0003oooooooooo`1Tooooo`;o00001oooool4o`0000?ooooo0_l0
0004ooooo`;o00001Oooool2o`0001Wooooo1?l000000ooooooo0000o`00002Vooooo`007?ooool0
0ol0003oooooooooo`1Tooooo`;o00001oooool4o`0000Wooooo0_l0000Pooooo`?o00002Oooool2
o`0009oooooo000Looooo`03o`000?oooooooooo05Cooooo0_l0000Gooooo`;o00008oooool2o`00
00Wooooo0_l00009ooooo`;o00000oooool2o`0001?ooooo0_l0000Tooooo`;o0000Goooool00006
ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooo
oooo05Cooooo0_l0000_ooooo`?o00001_ooool2o`0000;ooooo0_l00004ooooo`;o00004oooool2
o`0001?ooooo0ol000000ooooooo0000o`000002o`0001kooooo0_l0001Oooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo
00?o0000ooooooooool0N_ooool2o`0000Oooooo1Ol00005ooooo`?o00002?ooool3o`0002Sooooo
0_l000000ooooooo0000o`000002o`0000?ooooo0_l0001jooooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0NOoo
ool3o`0000Oooooo0_l00003ooooo`;o00000oooool2o`0000[ooooo0_l00002ooooo`;o00001ooo
ool2o`0000[ooooo0_l0000Iooooo`;o0000N_ooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool02oooool00onHV9So8B4Qonk^kP06ooooo`?o0000NOooool2o`0000gooooo0_l00003
ooooo`?o00002?ooool2o`0000?ooooo0_l00007ooooo`;o00001Oooool2o`0000?ooooo1?l00004
ooooo`;o00002Oooool2o`0008;ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`1Mooooo`;o00007oooool2o`00
00Oooooo0_l00004ooooo`?o00002?ooool2o`0000?ooooo1?l0000<ooooo`;o00001Oooool2o`00
00Cooooo0_l00009ooooo`;o0000P_ooool00003ooooool@413ooooo00;ooooo00?o410@oooooooo
ool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05gooooo0_l0000Nooooo`?o
00001oooool2o`0000oooooo0_l00002ooooo`Go00006oooool2o`0008_ooooo00001_ooooooMgMg
oiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooo
oooo067ooooo0_l0000Jooooo`;o00001Oooool2o`0000cooooo0ol00003ooooo`;o00000_ooool2
o`0000?ooooo0_l0000:ooooo`;o00003?ooool3o`00017ooooo0_l0001hooooo`0000Koooooonk^
k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`1Qooooo`;o00008?ooool3o`000003ooooool0003o000000Wooooo0ol00003ooooo`;o0000
1oooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`?o00003?ooool2o`0001;ooooo
0_l0000@ooooo`;o0000I_ooool001cooooo00?o0000ooooooooool0Loooool3o`0000Oooooo0_l0
0004ooooo`;o00000_ooool2o`0000Wooooo1?l0000>ooooo`;o00000_ooool2o`0000;ooooo0_l0
0006ooooo`;o0000:_ooool3o`0006Kooooo000Looooo`03o`000?oooooooooo06kooooo0_l00003
ooooo`?o00001oooool2o`0000Cooooo0_l00003ooooo`;o00000oooool2o`0000Gooooo0_l0000A
ooooo`;o00002oooool2o`0000Gooooo0_l0000Dooooo`;o00003Oooool2o`0006Oooooo000Loooo
o`03o`000?oooooooooo06kooooo0ol000000ooooooo0000o`000009ooooo`;o000000?oooooo`00
0?l000001_ooool2o`0000?ooooo1Ol0000Eooooo`Ko00003_ooool3o`00013ooooo0_l000000ooo
oooo0000o`000002o`0007Cooooo000Looooo`03o`000?oooooooooo06[ooooo1?l000001?oooooo
0000o`000?ooool2o`0000cooooo0_l0000<ooooo`Co00001?ooool2o`0000;ooooo0_l0000=oooo
o`Co00001?ooool2o`0000Wooooo0_l0000@ooooo`Co000000Coooooo`000?l0003ooooo0_l0001a
ooooo`007?ooool00ol0003oooooooooo`1Zooooo`Co00002oooool2o`0000Kooooo0_l0000?oooo
o`?o000000Goooooo`000?l0003o0000ooooo`02o`0001Gooooo0_l000000ooooooo0000o`00000G
ooooo`;o000000Coooooo`000?l0003o00000oooool2o`00077ooooo000Looooo`03o`000?oooooo
oooo06cooooo0_l000000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l000000oooool2
o`000004ooooool0003o0000ooooo`;o00001_ooool2o`0000Cooooo0ol00002ooooo`;o00002?oo
ool2o`0000;ooooo0_l00006ooooo`;o00001Oooool2o`000003ooooool0003o000000Cooooo0ol0
000=ooooo`;o00000_ooool2o`0000Sooooo0_l000000ooooooo0000o`00000:ooooo`;o0000GOoo
ool001cooooo00?o0000ooooooooool0K?ooool2o`000003ooooool0003o000000;o000000?ooooo
o`000?l000000_l00006ooooo`;o000000Coooooo`000?l0003ooooo0_l00006ooooo`;o00003ooo
ool2o`000005ooooool0003o0000o`000?ooool00ol00006ooooo`;o00002?ooool2o`0000Cooooo
0ol00006ooooo`;o00002Oooool2o`0000Kooooo1?l000000ooooooo0000o`00000:ooooo`;o0000
GOooool001cooooo00?o0000ooooooooool0K?ooool2o`0000?ooooo0_l000000ooooooo0000o`00
000Uooooo`Co000000?oooooo`000?l000000_ooool2o`0001oooooo1?l00008ooooo`;o00001_oo
ool2o`0006kooooo000Looooo`03o`000?oooooooooo067ooooo0_l00009ooooo`;o00000oooool4
o`0001;ooooo0_l0000Booooo`;o00000_ooool2o`0000Sooooo0_l00003ooooo`;o00001_ooool2
o`0000gooooo1?l0000=ooooo`;o0000LOooool001cooooo00?o0000ooooooooool0HOooool2o`00
00kooooo1?l0000>ooooo`;o00000_ooool2o`0001Kooooo0_l00002ooooo`Go000000Coooooo`00
0?l0003ooooo1?l00006ooooo`;o00003_ooool2o`0000kooooo0_l00005ooooo`;o00002oooool2
o`0005gooooo000Looooo`03o`000?oooooooooo06;ooooo0_l00007ooooo`;o00003?ooool2o`00
00Sooooo0_l0000Nooooo`Go00001?ooool4o`0000?ooooo0_l0000@ooooo`Co00005?ooool2o`00
00_ooooo0_l0001Mooooo`007?ooool2o`0004kooooo0_l0000Cooooo`;o00000oooool2o`0000;o
oooo0_l00003ooooo`;o00001oooool2o`0000Gooooo0_l00004ooooo`;o00001?ooool2o`0001?o
oooo0_l00002ooooo`Go00002Oooool2o`0000oooooo1Ol0000@ooooo`;o00001oooool2o`0000Go
oooo0_l00003ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0COooool2o`0001Sooooo
0_l00007ooooo`;o00000oooool2o`0000Oooooo1_l00002ooooo`;o00001?ooool2o`0001;ooooo
2_l00003ooooo`;o00003Oooool2o`0000Kooooo0_l000000ooooooo0000o`000008ooooo`;o0000
1_ooool2o`0000Oooooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool2o`0005Wooooo
000Looooo`03o`000?oooooooooo07Gooooo0_l00007ooooo`;o000000Coooooo`000?l0003o0000
7?ooool6o`0000Oooooo0_l00003ooooo`;o00002?ooool2o`0000Wooooo0_l00008ooooo`;o0000
1_ooool2o`0000[ooooo0_l0001Rooooo`007?ooool00ol0003oooooooooo`1fooooo`;o00002Ooo
ool3o`0001cooooo0_l000001?oooooo0000o`000?l00003ooooo`;o00000oooool3o`000003oooo
ool0003o000000oooooo0_l0000<ooooo`;o00006?ooool2o`0005cooooo000Looooo`03o`000?oo
oooooooo05_ooooo0_l00006ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o0000
0_ooool4o`000003ooooool0003o000000;ooooo0_l00006ooooo`;o00008?ooool2o`0000?ooooo
0_l00002ooooo`Ko00002?ooool2o`0000Kooooo0_l00003ooooo`;o00001oooool2o`0000Gooooo
0_l00004ooooo`;o00002oooool2o`0005cooooo000Looooo`03o`000?oooooooooo05_ooooo0_l0
0006ooooo`;o00000_ooool5o`000003ooooool0003o000000;ooooo1?l00005ooooo`;o00001Ooo
ool2o`0000Oooooo0_l0000Cooooo`;o00001_ooool2o`0000?ooooo2Ol00004ooooo`Co00002?oo
ool2o`000003ooooool0003o000000cooooo1Ol00003ooooo`;o0000JOooool001cooooo00?o0000
ooooooooool0J?ooool2o`0000[ooooo0_l0000;ooooo`;o00001_ooool3o`0000[ooooo0_l00003
ooooo`;o00000_ooool4o`0000Cooooo0_l00003ooooo`;o00000oooool4o`0000Cooooo0_l0000:
ooooo`;o00003oooool2o`000003ooooool0003o000000?ooooo0_l0001Yooooo`007?ooool00ol0
003oooooooooo`1Kooooo`;o00005?ooool5o`0000_ooooo0_l00003ooooo`;o000000Coooooo`00
0?l0003o00002_ooool3o`0000;ooooo0_l00004ooooo`;o00001?ooool2o`0000?ooooo0_l00003
ooooo`;o00000oooool2o`0000Kooooo0_l00005ooooo`;o00000_ooool2o`0000Kooooo0_l00002
ooooo`;o00001oooool2o`0006Wooooo000Looooo`03o`000?oooooooooo04gooooo0_l00008oooo
o`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000=ooooo`Go00002oooool2o`00
00?ooooo0_l00008ooooo`;o00001Oooool2o`0000kooooo0_l00003ooooo`;o00002?ooool2o`00
00Kooooo0_l00005ooooo`;o00000_ooool3o`0000Gooooo1_l00002ooooo`;o00001oooool4o`00
017ooooo0ol0001?ooooo`007?ooool00ol0003oooooooooo`16ooooo`;o00001Oooool2o`0000So
oooo0_l00006ooooo`;o000000?oooooo`000?l000005?ooool2o`0000;ooooo0_l0000Booooo`;o
00004Oooool2o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`;o00001?ooool2o`0000Ko
oooo0_l00008ooooo`;o00001oooool2o`0000Cooooo0_l00007ooooo`Co00004Oooool3o`0004oo
oooo000Looooo`03o`000?oooooooooo04Kooooo0_l0000Booooo`;o00004oooool2o`0000Oooooo
0_l00002ooooo`?o00001oooool2o`0000Sooooo0_l0000?ooooo`Co00000oooool3o`0000Oooooo
0_l00004ooooo`;o000000?oooooo`000?l000000oooool2o`0000[ooooo0_l00003ooooo`;o0000
3Oooool2o`0000Kooooo0_l00002ooooo`;o00002Oooool2o`00053ooooo000Looooo`03o`000?oo
oooooooo04;ooooo0_l0000Booooo`;o00000_ooool2o`0000oooooo0_l00002ooooo`;o00003?oo
ool2o`0000Oooooo0_l00008ooooo`?o00003_ooool4o`0000?ooooo0_l0000Aooooo`;o00002_oo
ool2o`0000?ooooo0ol00002ooooo`;o00003Oooool2o`000004ooooool0003o0000ooooo`Co0000
0_ooool2o`0000Wooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00004_oo
ool2o`0000kooooo1?l000001?oooooo0000o`000?l0000?ooooo`;o00003oooool2o`000004oooo
ool0003o0000ooooo`;o0000:_ooool2o`0000?ooooo1?l00004ooooo`;o00003_ooool2o`0000Co
oooo0_l000000ooooooo0000o`00000Jooooo`;o0000AOooool001cooooo00?o0000ooooooooool0
E?ooool2o`0000kooooo1_l00002ooooo`;o00000oooool5o`0000[ooooo0_l00009ooooo`Go0000
1?ooool4o`0000cooooo0_l0000Jooooo`;o00000oooool2o`0001Kooooo0ol00006ooooo`;o0000
6_ooool2o`0004Gooooo000Looooo`03o`000?oooooooooo04kooooo0_l00004ooooo`;o00003_oo
ool2o`0000Oooooo0_l00002ooooo`Go00001Oooool2o`0000?ooooo0ol00003ooooo`;o00000_oo
ool5o`0000Oooooo0_l00004ooooo`;o00001_ooool2o`000003ooooool0003o000000Gooooo0_l0
0005ooooo`;o00001_ooool4o`0000Cooooo0_l00002ooooo`;o00004oooool2o`0000Kooooo0_l0
000@ooooo`;o0000Coooool001cooooo00?o0000ooooooooool0B_ooool2o`0000;ooooo1?l00003
ooooo`;o00000oooool2o`0000[ooooo0_l00005ooooo`;o00000oooool2o`0000Oooooo0_l00004
ooooo`;o00000oooool6o`000003ooooool0003o000000gooooo0_l00009ooooo`;o00001Oooool3
o`0000Cooooo1?l000001?oooooo0000o`000?ooool6o`0000;ooooo1_l0000]ooooo`;o00001?oo
ool2o`0004Wooooo000Looooo`;o0000Boooool2o`0000;ooooo1?l000000ooooooo0000o`000002
o`0000?ooooo0_l0000:ooooo`;o00002_ooool2o`0001Cooooo0_l0000Looooo`;o00001oooool2
o`0000Kooooo0_l000000ooooooo0000o`000005ooooo`?o00000oooool4o`0000Wooooo0_l0000E
ooooo`;o00004Oooool2o`0004Wooooo000Looooo`03o`000?oooooooooo05?ooooo0_l00009oooo
o`;o00003_ooool2o`0000Cooooo0_l0000@ooooo`;o00007?ooool4o`0000cooooo1_l00005oooo
o`;o000000Coooooo`000?l0003o00000_ooool3o`0000;ooooo0_l00002ooooo`?o000000?ooooo
o`000?l000001oooool2o`0000cooooo0_l0000:ooooo`;o0000D?ooool001cooooo00?o0000oooo
ooooool0G_ooool2o`0000gooooo0ol00004ooooo`;o00004?ooool2o`0001?ooooo0_l00004oooo
o`;o000000?oooooo`000?l000000_l00006ooooo`;o00000_ooool:o`0000;ooooo0ol00002oooo
o`Oo00000_ooool2o`0000;ooooo0ol0000:ooooo`;o00006?ooool2o`0000Oooooo0_l00017oooo
o`007?ooool00ol0003oooooooooo`1:ooooo`;o00004_ooool2o`0000gooooo0ol0000:ooooo`;o
00003Oooool2o`00013ooooo0_l00003ooooo`?o000000?oooooo`000?l000000_l00005ooooo`co
000000Coooooo`000?l0003ooooo1Ol00003ooooo`Go00004oooool2o`0000oooooo0_l0000@oooo
o`Co0000AOooool001cooooo00?o0000ooooooooool0>Oooool2o`000003ooooool0003o000000co
oooo0_l0000<ooooo`?o00001?ooool2o`0001Wooooo0ol00004ooooo`;o00001_ooool3o`0000Go
oooo0_l0000=ooooo`?o00000_ooool2o`0000;ooooo1_l000000ooooooo0000o`00000Co`0000;o
oooo0ol0000Oooooo`;o00000oooool2o`0001;ooooo0_l00008ooooo`;o0000>oooool001cooooo
00?o0000ooooooooool0>Oooool2o`000003ooooool0003o000000Oooooo0_l0000Aooooo`?o0000
1?ooool2o`0000Cooooo0_l0000;ooooo`?o00001_ooool2o`0000Cooooo0_l00003ooooo`;o0000
00Goooooo`000?l0003o0000ooooo`02o`0000;ooooo0_l00002ooooo`;o00002_ooool2o`0000;o
oooo0_l00002ooooo`Co000000?oooooo`000?l000003_l000000ooooooo0000o`000006o`000003
ooooool0003o000001?ooooo0ol00005ooooo`;o00000_ooool4o`0000Oooooo0_l00003ooooo`;o
00004Oooool2o`0003_ooooo000Looooo`03o`000?oooooooooo04Gooooo0ol0000>ooooo`Co0000
2oooool4o`0000Oooooo1ol00004ooooo`;o00000_ooool2o`0000Gooooo0_l00005ooooo`;o0000
1_ooool2o`0000Cooooo0_l00005ooooo`;o00001?ooool3o`0000?ooooo6Ol000000ooooooo0000
o`00000Cooooo`?o00001Oooool8o`000003ooooool0003o000000Cooooo0ol00002ooooo`;o0000
C_ooool001cooooo00?o0000ooooooooool0?oooool2o`0000Gooooo0_l0000:ooooo`;o00000_oo
ool4o`000003ooooool0003o000000[ooooo0_l00005ooooo`Co000000?oooooo`000?l000000_l0
0008ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0001;ooooo0_l00005ooooo`;o0000
1?ooool2o`0000?ooooo4ol000000ooooooo0000o`000002o`0001oooooo1ol00003ooooo`;o0000
1Oooool2o`0005;ooooo000Looooo`03o`000?oooooooooo03oooooo0_l00007ooooo`;o00001_oo
ool4o`0000Oooooo0_l0000Aooooo`Co00000oooool2o`0000Kooooo0_l00003ooooo`?o00000_oo
ool2o`0000Cooooo0_l0000Iooooo`;o00000ooooolCo`000003ooooool0003o000000cooooo0_l0
000:ooooo`;o00001oooool3o`0001;ooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`18
ooooo`;o00001?ooool4o`0000?ooooo0_l0000Cooooo`Go00001_ooool2o`0000Cooooo1_l00000
0ooooooo0000o`000002o`0000?ooooo0_l00002ooooo`;o00004Oooool4o`0000Cooooo0_l00003
ooooo`Wo00000_ooool;o`0000?ooooo0ol00006ooooo`;o00002_ooool2o`0001cooooo0_l0001>
ooooo`007?ooool00ol0003oooooooooo`18ooooo`;o00000oooool3o`0000Gooooo0_l0000>oooo
o`;o00000oooool5o`0000Cooooo0_l00006ooooo`;o00000_ooool7o`0000;ooooo0ol0000Eoooo
o`Co00000ooooolLo`0000?ooooo0ol00002ooooo`;o00001Oooool2o`000003ooooool0003o0000
01Gooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`18ooooo`;o00000oooool2o`0000Ko
oooo0_l00005ooooo`;o00001oooool2o`0000;ooooo1?l00003ooooo`;o000000?oooooo`000?l0
00001_ooool2o`0000Cooooo1_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l0000=oooo
o`;o00000_ooool2o`0000?ooooo8?l00003ooooo`?o00001Oooool2o`000003ooooool0003o0000
017ooooo0_l00002ooooo`;o00001Oooool2o`0000Oooooo0_l00008ooooo`;o0000@Oooool001co
oooo00?o0000ooooooooool0@Oooool2o`0000gooooo0_l00002ooooo`?o00001Oooool2o`0000Co
oooo0_l00005ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Gooooo0_l000000ooooooo
0000o`00000;o`0000?ooooo0ol00002ooooo`;o00003Oooool2o`0000Oooooo8?l00003ooooo`;o
00000oooool2o`0000Sooooo0_l00009ooooo`;o00000_ooool2o`0000;ooooo0_l00005ooooo`Oo
00000_ooool2o`0000Kooooo1?l00011ooooo`007?ooool00ol0003oooooooooo`0mooooo`;o0000
0_ooool2o`0000gooooo0_l00002ooooo`;o00003?ooool5o`0000Cooooo0ol00009ooooo`;o0000
00?oooooo`000?l000002?l00002ooooo`;o00000_ooool3o`000003ooooool0003o000000Oooooo
1Ol0000<oooooa_o000000?oooooo`000?l000000_l00006ooooo`Oo00001?ooool2o`0000Wooooo
1?l00006ooooo`;o00001?ooool6o`0000[ooooo0_l00005ooooo`;o0000??ooool001cooooo00?o
0000ooooooooool0?Oooool2o`0001Gooooo0ol0000;ooooo`Oo00000_ooool2o`000003ooooool0
003o000000Gooooo0_l00004ooooo`Wo00000_ooool2o`0000Kooooo0_l00007ooooo`Oo00001Ooo
ool2o`0000;ooooo7?l000000ooooooo0000o`000002o`0000Kooooo0_l000000ooooooo0000o`00
0002o`0000;ooooo0_l00008ooooo`;o00000_ooool3o`0000Kooooo0_l00002ooooo`;o00000_oo
ool3o`0000Cooooo0_l0000<ooooo`;o0000??ooool001cooooo00?o0000ooooooooool0B_ooool2
o`0000Oooooo1?l00009ooooo`Co000000?oooooo`000?l000001?l00003ooooo`;o00001OoooolA
o`0000cooooo0_l00005ooooo`Ko000000?oooooo`000?l000000ol000000ooooooo0000o`00000N
o`000003ooooool0003o000000kooooo0_l00008ooooo`;o00002oooool6o`000003ooooool0003o
000000;o00001?ooool2o`0004[ooooo000Looooo`;o0000BOooool4o`0000Oooooo0_l000000ooo
oooo0000o`000008ooooo`?o00001Oooool3o`0000?ooooo0_l00002ooooo`;o00000_oooolAo`00
00_ooooo0ol00004ooooo`_o00000_oooolOo`0000;ooooo0_l00003ooooo`Co00001oooool2o`00
00cooooo1?l00005ooooo`Co00000oooool2o`0001Gooooo0_l0000kooooo`007?ooool00ol0003o
ooooooooo`18ooooo`;o00003?ooool2o`00017ooooo0_l00003ooooo`;o00000_ooool2o`0000Ko
oooo3Ol000000ooooooo0000o`000007ooooo`Co00001oooool2o`000004ooooool0003o0000oooo
o`;o00000_oooolAo`000003ooooool0003o000000_o00001_ooool5o`0000;ooooo0_l0000Aoooo
o`Co00000oooool2o`0001kooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0jooooo`;o
0000;Oooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool3o`000003ooooool0003o000000ko
00001oooool2o`0001;ooooo8_l00003ooooo`?o00001Oooool2o`0000;ooooo0_l00005ooooo`Co
00002oooool2o`0001;ooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`0jooooo`;o0000
0_ooool2o`0000;ooooo0_l0000Jooooo`;o00002_ooool2o`0000?ooooo0_l00005ooooo`?o0000
00?oooooo`000?l000003_l00006ooooo`;o00003Oooool2o`0000Cooooo2_l000000ooooooo0000
o`00000Eo`0000?ooooo0ol000000ooooooo0000o`000002o`0000Cooooo0_l000000ooooooo0000
o`000002ooooo`Co00004Oooool2o`000004ooooool0003o0000ooooo`;o00001_ooool2o`0004Oo
oooo000Looooo`03o`000?oooooooooo03Gooooo0_l000000ooooooo0000o`000002ooooo`Co0000
0_ooool2o`000003ooooool0003o000001Oooooo0_l000001?oooooo0000o`000?ooool2o`0000Co
oooo1?l000000ooooooo0000o`000004oooooaKo000000?oooooo`000?l000001?l00004ooooo`;o
00001oooool3o`000003ooooool0003o000001oo00001oooool2o`000003ooooool0003o000000?o
00001_ooool2o`0001;ooooo0_l000000ooooooo0000o`000002o`000004ooooool0003o0000oooo
o`;o00001Oooool2o`0000kooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0eooooo`;o
000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00003ooooo`;o00002Oooool2o`0000_o
oooo0_l00002ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o00001ooooolFo`000003
ooooool0003o000000;o00001_ooool2o`0000Sooooo0_l000000ooooooo0000o`000008o`000003
ooooool0003o000001Go00003?ooool2o`0000Cooooo0_l000000ooooooo0000o`00000Aooooo`;o
000000Coooooo`000?l0003o00002_ooool4o`0000?ooooo0_l00009ooooo`;o00000_ooool2o`00
03Cooooo000Looooo`03o`000?oooooooooo03[ooooo0_l00004ooooo`;o00003_ooool2o`0000_o
oooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000000Sooooo5ol0000Koooooaco
000000?oooooo`000?l000000ol00007ooooo`;o00000oooool2o`0000;ooooo0_l000000ooooooo
0000o`000002o`0000oooooo0_l00002ooooo`;o00000oooool2o`0000Gooooo0_l00005ooooo`;o
00002_ooool2o`000003ooooool0003o000003Cooooo000Looooo`03o`000?oooooooooo03Gooooo
0_l00003ooooo`;o00007Oooool2o`000003ooooool0003o000000?ooooo0_l00006ooooo`;o0000
0oooool4o`000003ooooool0003o0000017o000000Coooooo`000?l0003o00001?ooool2o`0000;o
oooo0_l0000>ooooo`;o00000_ooool9o`000003ooooool0003o000000oo000000?oooooo`000?l0
00001?l00006ooooo`;o00000oooool2o`0000Oooooo0_l0000?ooooo`;o00000_ooool2o`0000?o
oooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l00007ooooo`;o
0000=oooool001cooooo00?o0000ooooooooool0=Oooool2o`0000cooooo0_l0000Dooooo`;o0000
00?oooooo`000?l000002?ooool2o`0000Kooooo1?l000000ooooooo0000o`00000Fo`0000?ooooo
0_l00002ooooo`;o00002_ooool6o`0000;ooooo5ol000001?oooooo0000o`000?l00004ooooo`?o
00001Oooool2o`0000?ooooo0_l00008ooooo`;o00000_ooool2o`0000kooooo0ol00007ooooo`Ko
00000_ooool2o`0000?ooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`13ooooo`;o0000
8Oooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000000oooool2o`000003oooo
ool0003o000001Co00004?ooool6o`0000Cooooo1_l000000ooooooo0000o`00000=o`0000;ooooo
0ol000000ooooooo0000o`000009ooooo`;o00000oooool2o`0000;ooooo0_l00008ooooo`;o0000
3_ooool2o`0000?ooooo0_l00003ooooo`Go0000B_ooool001cooooo00?o0000ooooooooool0<?oo
ool2o`0000Cooooo0_l0000=ooooo`;o00001_ooool2o`0000cooooo0_l00005ooooo`?o00001?oo
ool4o`000003ooooool0003o000000?ooooo6ol00006ooooo`?o000000?oooooo`000?l000000_oo
ool2o`0000;ooooo0_l00004ooooo`Co00000_ooool@o`0000Gooooo0ol00008ooooo`;o00001?oo
ool2o`0000;ooooo0_l0000>ooooo`;o00003Oooool2o`000003ooooool0003o000000?ooooo0_l0
0005ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0<?ooool2o`0000Cooooo0_l00006
ooooo`;o00001Oooool2o`0000Gooooo0ol0000<ooooo`;o00001Oooool3o`0000Gooooo0_l00007
oooooaSo000000?oooooo`000?l000001?ooool5o`000003ooooool0003o000000Kooooo0_l0000:
oooooa3o000000?oooooo`000?l000000_ooool2o`0000Wooooo1Ol000001?oooooo0000o`000?l0
0004ooooo`;o00002oooool2o`0000gooooo0_l000000ooooooo0000o`000004ooooo`;o000000Co
ooooo`000?l0003ooooo0_l00008ooooo`;o0000>Oooool001cooooo00?o0000ooooooooool0?_oo
ool4o`0000[ooooo0_l0000<ooooo`;o00001Oooool3o`000003ooooool0003o000000?ooooo0_l0
000:oooooaGo00000_ooool2o`0000?ooooo0_l00004ooooo`Oo00003_ooool>o`0000;ooooo0_l0
000>ooooo`Co00000_ooool2o`0000Cooooo0_l0000Sooooo`;o000000?oooooo`000?l000002ooo
ool4o`0003Oooooo000Looooo`03o`000?oooooooooo02[ooooo0_l0000Dooooo`;o00005?ooool2
o`000004ooooool0003o0000o`0000Gooooo0_l00002ooooo`;o00001oooool2o`0000Gooooo2?l0
0002ooooo`co00000_ooool2o`0000;ooooo0_l00005ooooo`Oo00000_ooool2o`0000Wooooo1Ol0
00000ooooooo0000o`000008o`000003ooooool0003o000000Oooooo0_l00008ooooo`;o00000_oo
ool2o`0000oooooo0_l0000Cooooo`;o00000_ooool2o`0000Gooooo0_l00009ooooo`;o0000=ooo
ool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413ooooo
ooooo`04ooooo`03o`000?oooooooooo02[ooooo0_l0000>ooooo`;o00002Oooool2o`0000_ooooo
0_l00002ooooo`;o000000?oooooo`000?l000003oooool2o`0000;ooooo0_l000001?oooooo0000
o`000?oooolFo`000003ooooool0003o000000Cooooo0_l00005ooooo`;o000000Coooooo`000?l0
003ooooo0_l000000ooooooo0000o`000009ooooo`?o000000?oooooo`000?l000000oooool7o`00
00Gooooo0_l00003ooooo`;o00002?ooool6o`0000oooooo0ol0000Booooo`;o00000_ooool2o`00
00Gooooo0ol00011ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Cooooo0_l00004ooooo`;o00000oooool2
o`0000Cooooo0_l00002ooooo`;o00001oooool3o`000003ooooool0003o000000kooooo0_l00002
ooooo`;o00001Oooool2o`000003ooooool0003o000001?o00000_ooool3o`0000[ooooo0_l00000
1?oooooo0000o`000?ooool2o`0000Kooooo0_l00008ooooo`Co000000?oooooo`000?l000001_l0
0004ooooo`;o00003_ooool4o`00017ooooo0_l0000Booooo`;o00000oooool2o`0000Gooooo0_l0
0011ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`Go00001_ooool0
0ol0003oooooooooo`0dooooo`;o00002Oooool2o`0000Sooooo0_l00008ooooo`;o00004Oooool2
o`0000;ooooo0ol00002ooooo`?o00000ooooolIo`0000Wooooo0_l00002ooooo`;o00000_ooool2
o`0000Gooooo0_l0000:ooooo`Go000000?oooooo`000?l000000ol0000Eooooo`;o00008oooool4
o`0000Cooooo0_l0000>ooooo`Co0000=_ooool00003ooooool0003ooooo00;ooooo00?o0000oooo
ooooool02Oooool01?m4A4CogMgMooooool00007ooooo`?o0000=oooool2o`0000Oooooo0_l00000
0ooooooo0000o`000004ooooo`;o00006oooool2o`0000;ooooo1?l000001Ooooooo0000o`000?l0
003ooooo01[o00000_ooool2o`0000Kooooo0_l000000ooooooo0000o`000003ooooo`;o00004Ooo
ool3o`0000?ooooo0_l00005ooooo`;o00005_ooool2o`0001kooooo1?l00007ooooo`;o000000?o
ooooo`000?l000001_ooool6o`0003Kooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`0gooooo`;o00001?oo
ool2o`000004ooooool0003o0000ooooo`;o00004_ooool4o`0000?ooooo1?l00002ooooo`;o0000
0_ooool2o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l000005Ol00002ooooo`;o0000
1_ooool5o`0000Gooooo0_l000000ooooooo0000o`000006ooooo`;o00000_ooool2o`0000gooooo
0_l0000Fooooo`;o00002oooool2o`0001cooooo0_l000000ooooooo0000o`000006ooooo`;o0000
1?ooool3o`0003?ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?o
MgMgolc<c?l000001oooool00ol0003oooooooooo`0Sooooo`;o00006?ooool2o`0001Sooooo1_l0
00000ooooooo0000o`000002o`0000;ooooo0_l00002ooooo`;o00002ooooolCo`0000_ooooo0_l0
0002ooooo`Co00001_ooool5o`0000Cooooo1?l00002ooooo`;o0000<_ooool2o`0001Oooooo0_l0
0003ooooo`;o00001?ooool2o`0000Wooooo0ol0000cooooo`0000KoooooogMgMonHV9SooooooiRH
V?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool08oooool2o`0001?ooooo
0_l0000<ooooo`?o00000_ooool2o`0000kooooo1?l0000FoooooaSo00001_ooool2o`0000Gooooo
0_l00007ooooo`Co00000oooool3o`00017ooooo1?l0000Tooooo`;o00005Oooool2o`0000Cooooo
0_l00003ooooo`Co0000?Oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo
0000ooooo`06ooooo`03o`000?oooooooooo02_ooooo0_l0000;ooooo`;o00001Oooool2o`000004
ooooool0003o0000ooooo`Co00000_ooool2o`0000Gooooo0_l00007ooooo`Co00006?oooolFo`00
00_ooooo1Ol00008ooooo`;o00001?ooool2o`0000Kooooo0_l00008ooooo`Go000000?oooooo`00
0?l000000_l0000Booooo`;o00002Oooool4o`0001Gooooo0_l00004ooooo`;o00001?ooool3o`00
00Oooooo0_l0000dooooo`007?ooool00ol0003oooooooooo`0[ooooo`?o00004Oooool2o`000004
ooooool0003o0000ooooo`Co00001Oooool2o`0000;ooooo0_l00002ooooo`Co000000?oooooo`00
0?l000001?l0000?ooooo`;o00001oooool9o`000004ooooool0003o0000o`0000?ooooo0_l00006
ooooo`;o000000?oooooo`000?l000000_ooool5o`0000?ooooo0_l00003ooooo`;o00000oooool2
o`0000Oooooo0_l00008ooooo`;o00001?ooool4o`0001;ooooo0_l00008ooooo`?o00005oooool2
o`0001Cooooo0_l0000dooooo`007?ooool00ol0003oooooooooo`0Zooooo`Co00008?ooool4o`00
00;ooooo1_l000001Ooooooo0000o`000?l0003ooooo00;o00001oooool2o`0000Kooooo0_l00007
ooooo`Wo000000Coooooo`000?l0003o00001_ooool2o`0000?ooooo0_l000000ooooooo0000o`00
0004ooooo`;o00001?ooool2o`0000?ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l0
000;ooooo`;o00003_ooool2o`0000Oooooo0_l000000ooooooo0000o`000005ooooo`;o00009_oo
ool2o`0000Cooooo0_l00004ooooo`;o0000<?ooool001cooooo00?o0000ooooooooool0:_ooool2
o`0000[ooooo0_l00006ooooo`;o00001?ooool4o`0000Sooooo1_l0000Booooo`;o00002oooool2
o`0000;ooooo3Ol00006ooooo`;o00005Oooool3o`0000Cooooo1_l0000@ooooo`;o00003_ooool3
o`0000Wooooo0_l00009ooooo`Co00008?ooool2o`0000Cooooo0_l00004ooooo`;o0000<?ooool0
01cooooo00?o0000ooooooooool0=Oooool3o`000003ooooool0003o000000;ooooo0ol00004oooo
o`Co00002_ooool2o`0000Cooooo0_l00003ooooo`;o00002Oooool3o`0000[ooooo0_l000000ooo
oooo0000o`000002o`000003ooooool0003o000000Oo00006Oooool2o`0000;ooooo0ol00006oooo
o`;o00008oooool2o`0001?ooooo1Ol0000Nooooo`Co0000??ooool001cooooo00?o0000oooooooo
ool0=Oooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000005_ooool2o`0000;o
oooo1Ol00007ooooo`?o00000_ooool2o`0000Kooooo1Ol00005ooooo`Go00006oooool2o`0000Go
oooo1?l0000Cooooo`Co00004Oooool2o`000003ooooool0003o000000oooooo0_l0000Cooooo`Co
00002?ooool4o`0000Kooooo0_l0000fooooo`007?ooool00ol0003oooooooooo`0jooooo`;o0000
1?ooool3o`0001;ooooo0_l00005ooooo`;o000000?oooooo`000?l000000_l0000:ooooo`;o0000
1?ooool2o`000003ooooool0003o000000Cooooo2Ol00002ooooo`;o00002oooool2o`0000gooooo
0_l000000ooooooo0000o`000002o`0001?ooooo1?l0000Aooooo`;o000000?oooooo`000?l00000
0_ooool2o`0000Sooooo0_l0000Fooooo`Co00002?ooool2o`0000Sooooo0_l00004ooooo`;o0000
<?ooool001cooooo00?o0000ooooooooool0>?ooool4o`000004ooooool0003o0000ooooo`?o0000
4_ooool2o`0000[ooooo0_l000000ooooooo0000o`000003ooooo`;o00000_ooool2o`0000Cooooo
0_l00007ooooo`Ko000000?oooooo`000?l000000_ooool2o`0000_ooooo0_l000000ooooooo0000
o`000004ooooo`Co00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`;o0000
1oooool3o`0000_ooooo0_l00002ooooo`;o00003?ooool2o`0000Sooooo0_l00002ooooo`;o0000
00?oooooo`000?l000005oooool2o`0001;ooooo0_l0000`ooooo`007?ooool00ol0003ooooooooo
o`0hooooo`;o00000oooool2o`0000oooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo
0_l00009ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`;o00003?ooool2o`0001Kooooo
0_l00004ooooo`Co00000_ooool2o`0000Kooooo0_l00003ooooo`;o00001oooool3o`0000Cooooo
0_l00005ooooo`;o00000_ooool2o`0001[ooooo0_l000000ooooooo0000o`00000Gooooo`;o0000
1oooool2o`0003_ooooo000Looooo`03o`000?oooooooooo04kooooo0_l000001?oooooo0000o`00
0?ooool2o`0000?ooooo0_l00003ooooo`;o00001Oooool2o`0000?ooooo0ol00003ooooo`?o0000
1oooool3o`000003ooooool0003o000000gooooo0_l0000>ooooo`;o00002oooool2o`0000gooooo
0_l000001Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`000?l000004?ooool2o`0000Go
oooo0_l0000:ooooo`Co00007oooool3o`0003_ooooo000Looooo`03o`000?oooooooooo03kooooo
0_l00005ooooo`Co00005Oooool2o`0000Gooooo0_l00003ooooo`?o00000_ooool3o`0000Sooooo
0ol000000ooooooo0000o`00000=ooooo`;o00001?ooool2o`0001Gooooo0_l0000=ooooo`;o0000
00Coooooo`000?l0003o00001?ooool2o`00013ooooo1?l00003ooooo`?o00002Oooool4o`0001_o
oooo0_l00002ooooo`?o00001_ooool2o`0003?ooooo000Looooo`03o`000?oooooooooo03kooooo
0_l00005ooooo`Co000000?oooooo`000?l000000oooool2o`0000;ooooo0_l0000Fooooo`;o0000
0_ooool2o`0001[ooooo0_l000000ooooooo0000o`000003ooooo`;o00007?ooool2o`000003oooo
ool0003o000000;ooooo0_l0000Mooooo`;o00001?ooool2o`0000;ooooo0_l0000Qooooo`;o0000
00?oooooo`000?l000000oooool2o`0000Kooooo0_l0000cooooo`007?ooool2o`0003Wooooo0_l0
0004ooooo`;o00002_ooool2o`0000?ooooo0_l00002ooooo`;o00001_ooool4o`0000cooooo0_l0
000Nooooo`Go00000_ooool2o`0000_ooooo0_l00005ooooo`?o00002?ooool2o`000003ooooool0
003o000000;ooooo0_l0000;ooooo`;o00006_ooool2o`0001_ooooo0_l00003ooooo`?o0000@ooo
ool001cooooo00?o0000ooooooooool0=_ooool4o`0000Gooooo0_l0000Aooooo`;o00001oooool4
o`0000_ooooo0_l00002ooooo`;o00003Oooool2o`0000_ooooo1Ol00003ooooo`;o00000oooool2
o`0000Cooooo1?l00005ooooo`?o00001?ooool2o`000003ooooool0003o0000013ooooo0_l00000
0ooooooo0000o`00000Uooooo`;o00004?ooool2o`0000?ooooo0_l00005ooooo`;o0000?Oooool0
01cooooo00?o0000ooooooooool0=_ooool2o`0000Kooooo0ol0000;ooooo`;o00001?ooool2o`00
00Oooooo0_l0000=ooooo`;o00000_ooool2o`0000Cooooo0_l00007ooooo`;o00002?ooool2o`00
0004ooooool0003o0000o`0000[ooooo0_l00004ooooo`;o00003_ooool2o`000003ooooool0003o
0000013ooooo0_l0000Booooo`;o00005?ooool2o`0001Cooooo0_l00006ooooo`?o0000??ooool0
01cooooo00?o0000ooooooooool0;?ooool2o`00013ooooo0_l00009ooooo`;o000000?oooooo`00
0?l000007?ooool2o`0000Sooooo0_l00007ooooo`;o000000?oooooo`000?l000001Oooool2o`00
01Kooooo0_l0000:ooooo`;o000000?oooooo`000?l000000_l0000Oooooo`?o00000_ooool2o`00
00Wooooo0ol0000Nooooo`;o00001oooool2o`0003cooooo000Looooo`03o`000?oooooooooo02co
oooo0_l0000@ooooo`;o00002Oooool2o`0001?ooooo1?l00005ooooo`;o000000?oooooo`000?l0
00005?ooool2o`0001gooooo0_l0000:ooooo`;o000000?oooooo`000?l000000_l000001?oooooo
0000o`000?l00009ooooo`;o00004?ooool3o`0000gooooo0ol00005ooooo`;o00000_ooool2o`00
013ooooo0_l00006ooooo`;o00000_ooool2o`0003cooooo000Looooo`03o`000?oooooooooo03Oo
oooo0_l00005ooooo`;o00002oooool4o`0000cooooo0_l000000ooooooo0000o`000002o`0000Go
oooo0_l0000Eooooo`;o00001Oooool2o`0002Gooooo0_l00005ooooo`?o00001oooool5o`0000Wo
oooo0_l0000Eooooo`;o00001Oooool2o`0000;ooooo0_l00007ooooo`;o00001oooool2o`0000Ko
oooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0Rooooo`;o00001oooool2o`0000Wooooo
0ol0000=ooooo`;o000000?oooooo`000?l000001?l000000ooooooo0000o`000007ooooo`Co0000
00Coooooo`000?l0003o00002Oooool2o`0001;ooooo0_l00005ooooo`;o00003?ooool2o`000003
ooooool0003o000000;o00001_ooool2o`0000[ooooo0_l00006ooooo`?o00000_ooool2o`0000;o
oooo0_l000000ooooooo0000o`000009ooooo`;o00006_ooool4o`000003ooooool0003o000000So
oooo0_l0000>ooooo`;o00002Oooool2o`0003Kooooo000Looooo`03o`000?oooooooooo02;ooooo
0_l00007ooooo`;o00002Oooool2o`0000kooooo0_l000000ooooooo0000o`000003o`0000;ooooo
0ol00005ooooo`?o00001?ooool2o`0000Wooooo0_l0000>ooooo`;o00003_ooool2o`0000Oooooo
0_l000000ooooooo0000o`000002o`0000Kooooo0_l00005ooooo`;o00001_ooool2o`0000Cooooo
0_l00002ooooo`;o00001?ooool4o`0000Sooooo0_l0000:ooooo`;o00003Oooool3o`0000?ooooo
0_l0000Hooooo`;o00001?ooool2o`0000;ooooo1?l0000eooooo`007?ooool00ol0003ooooooooo
o`1;ooooo`?o00000oooool2o`0000Gooooo0_l00002ooooo`;o00004Oooool2o`0000?ooooo0_l0
0002ooooo`Co000000?oooooo`000?l000002_ooool3o`0000Wooooo0_l0000>ooooo`Co00001_oo
ool2o`0000Gooooo1?l00005ooooo`Co00003_ooool2o`0000Cooooo0_l00003ooooo`?o00001ooo
ool4o`0000_ooooo0_l0000Eooooo`;o00000_ooool4o`0003Gooooo000Looooo`03o`000?oooooo
oooo03Kooooo0_l00003ooooo`;o00002?ooool2o`0001Cooooo0ol000000ooooooo0000o`000007
ooooo`;o00001Oooool2o`0000?ooooo0_l00002ooooo`?o00000_ooool2o`0000[ooooo0_l0000:
ooooo`Co00003?ooool2o`0000Cooooo0_l00009ooooo`Co00002Oooool2o`000003ooooool0003o
000000;o000000Coooooo`000?l0003o00000oooool3o`0000Sooooo0ol00009ooooo`;o00000ooo
ool2o`0000Kooooo0ol00003ooooo`;o00001?ooool2o`0000Gooooo0_l00003ooooo`;o00000_oo
ool2o`0003Kooooo000Looooo`03o`000?oooooooooo02Cooooo0_l0000@ooooo`;o00000oooool3
o`0000Oooooo0_l0000Dooooo`;o00000_ooool5o`0000Cooooo0ol0000Nooooo`;o00001_ooool2
o`0000Cooooo0_l0000Booooo`;o00003Oooool3o`0000Kooooo0_l000000ooooooo0000o`000002
o`000003ooooool0003o000000Co000000?oooooo`000?l000001oooool4o`0000kooooo0_l00007
ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`;o00001Oooool2o`000003ooooool0
003o000000;o000000?oooooo`000?l00000=oooool001cooooo00?o0000ooooooooool09?ooool2
o`0001Kooooo0_l00002ooooo`;o00006?ooool2o`0000Gooooo0ol00005ooooo`;o00001?ooool2
o`000003ooooool0003o000000Wooooo0_l00006ooooo`;o000000?oooooo`000?l000001oooool2
o`0000Sooooo0_l00007ooooo`;o00001Oooool3o`0000cooooo0ol00006ooooo`;o000000Cooooo
o`000?l0003o00001?ooool4o`0000Sooooo1_l00003ooooo`;o00004oooool2o`0000Gooooo0_l0
000;ooooo`;o00000_ooool3o`0003Oooooo000Looooo`03o`000?oooooooooo03Kooooo0_l00002
ooooo`;o00000_ooool5o`0001Oooooo0_l0000Cooooo`;o000000Coooooo`000?l0003o00000_oo
ool2o`0000Cooooo0_l00006ooooo`;o000000?oooooo`000?l000002oooool2o`0000Cooooo0_l0
00000ooooooo0000o`000004ooooo`;o00001_ooool2o`0000Gooooo1Ol00002ooooo`;o00002_oo
ool3o`0000[ooooo0_l00004ooooo`?o00001_ooool2o`0000cooooo0_l00005ooooo`;o00001Ooo
ool2o`0000Oooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000003Sooooo000L
ooooo`03o`000?oooooooooo03Kooooo0_l000001?oooooo0000o`000?l00002ooooo`;o000000?o
ooooo`000?l000001?ooool2o`0000Cooooo0_l00003ooooo`;o00004Oooool3o`0000;ooooo1_l0
00000ooooooo0000o`000002o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`00013ooooo
0_l000001?oooooo0000o`000?ooool4o`0000;ooooo0_l000000ooooooo0000o`00000Cooooo`Go
00000_ooool3o`0000;ooooo0ol00005ooooo`;o00000_ooool3o`0000Gooooo0_l00005ooooo`;o
00000_ooool2o`000004ooooool0003o0000o`0000?ooooo0_l00007ooooo`;o00004oooool4o`00
0003ooooool0003o000000Co0000>Oooool001cooooo00?o0000ooooooooool0;oooool2o`0000;o
oooo0_l00003ooooo`?o00000_ooool2o`0000Kooooo1?l00004ooooo`;o00000oooool2o`0000Oo
oooo0_l00008ooooo`?o00000_ooool9o`0000Oooooo0_l0000>ooooo`;o00000oooool2o`000004
ooooool0003o0000ooooo`Co000000Coooooo`000?l0003o00000oooool2o`0000Wooooo0_l00006
ooooo`;o00001?ooool4o`0000;ooooo0ol000000ooooooo0000o`000002o`0000Cooooo0ol0000@
ooooo`;o000000Coooooo`000?l0003o00000oooool2o`0000Cooooo0_l00009ooooo`?o00000ooo
ool2o`000003ooooool0003o000000;ooooo0_l00007ooooo`?o0000>?ooool001cooooo00?o0000
ooooooooool0;oooool6o`0000?ooooo1?l000001?oooooo0000o`000?l00005ooooo`;o00003ooo
ool2o`000003ooooool0003o000000Co00002?ooool?o`000003ooooool0003o000000?ooooo0_l0
0008ooooo`;o00000_ooool2o`0000;ooooo0ol000000ooooooo0000o`000003o`0000?ooooo0_l0
0004ooooo`Ko00001Oooool2o`0000Gooooo1Ol000000ooooooo0000o`000003o`0000;ooooo2_l0
0003ooooo`;o00000_ooool2o`0001[ooooo0ol00009ooooo`?o00000oooool2o`000003ooooool0
003o000000Gooooo1?l00003ooooo`;o0000>?ooool001cooooo0_l0000aooooo`?o000000?ooooo
o`000?l000001?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000?ooooo`;o00000_ooool2
o`000004ooooool0003o0000ooooo`?o00001_oooolAo`000004ooooool0003o0000o`0000;ooooo
1?l00006ooooo`;o00001_ooool2o`0000?ooooo0_l0000:ooooo`Oo00000_ooool2o`0000Gooooo
0_l000000ooooooo0000o`000006o`000003ooooool0003o000000;ooooo1_l000001?oooooo0000
o`000?l00003ooooo`;o00000_ooool3o`0001Wooooo0_l00008ooooo`;o000000?oooooo`000?l0
00001?ooool2o`0000;ooooo0_l00003ooooo`Co00002Oooool2o`0003;ooooo000Looooo`03o`00
0?oooooooooo033ooooo0_l00002ooooo`;o000000?oooooo`000?l000001_ooool6o`0000Wooooo
0_l00002ooooo`;o00000oooool2o`0000?ooooo0_l00007ooooo`go000000Coooooo`000?l0003o
00000_ooool2o`0000Cooooo0_l0000?ooooo`;o00003_ooool2o`0000Oooooo0_l00005ooooo`;o
00001Oooool2o`0000?ooooo0_l000000ooooooo0000o`00000=o`0000?ooooo0ol00007ooooo`;o
00001?ooool2o`0000;ooooo0_l0000@ooooo`;o000000?oooooo`000?l000001?ooool2o`0000;o
oooo1?l0000>ooooo`;o0000<_ooool001cooooo00?o0000ooooooooool0<oooool3o`000003oooo
ool0003o000000Kooooo0_l00002ooooo`;o00002Oooool2o`0000Oooooo0_l0000:oooooaGo0000
1_ooool2o`0000Wooooo0_l00004ooooo`;o00000oooool2o`0000Oooooo0_l00005ooooo`;o0000
1_ooool2o`0000Oooooo1?l00002oooooa?o00000_ooool5o`0000Gooooo1Ol000000ooooooo0000
o`000002ooooo`Co00001?ooool2o`0000_ooooo0_l00009ooooo`?o00002Oooool2o`0003Oooooo
000Looooo`03o`000?oooooooooo02[ooooo0_l00007ooooo`?o000000?oooooo`000?l000000ol0
0005ooooo`?o00001Oooool2o`0000;ooooo0ol0000CoooooaOo00003oooool2o`0000Wooooo0_l0
0004ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00001?ooool4o`0000Gooooo
1_l000001?oooooo0000o`000?oooolCo`000003ooooool0003o000000;o00000oooool2o`0000;o
oooo0ol000001?oooooo0000o`000?ooool2o`000004ooooool0003o0000o`0000?ooooo1?l0000D
ooooo`;o00000oooool5o`0000;ooooo0_l0000gooooo`007?ooool00ol0003oooooooooo`0Zoooo
o`;o00002Oooool7o`0000Gooooo0ol00005ooooo`;o00000_ooool3o`0001Cooooo1?l000000ooo
oooo0000o`00000Bo`0000Oooooo0_l00005ooooo`;o00003Oooool2o`0000Cooooo0_l00008oooo
o`So000000?oooooo`000?l000001?l000000ooooooo0000o`00000>o`000004ooooool0003o0000
ooooo`;o000000?oooooo`000?l000000_ooool5o`0000Wooooo0_l00002ooooo`;o00001?ooool3
o`0001Kooooo2?l0000kooooo`007?ooool00ol0003oooooooooo`0eooooo`;o00005oooool2o`00
00;ooooo0_l0000?ooooo`;o000000Coooooo`000?l0003ooooo5?l00002ooooo`;o00000oooool2
o`000003ooooool0003o000000;ooooo0_l0000?ooooo`Co00001?ooool2o`0000Sooooo7ol00003
ooooo`Co000000?oooooo`000?l000000_l00003ooooo`;o00009oooool4o`000003ooooool0003o
000003gooooo000Looooo`03o`000?oooooooooo03gooooo0_l0000Cooooo`;o00003ooooolIo`00
00?ooooo1_l00002ooooo`;o00000_ooool2o`0000;ooooo0_l00008ooooo`;o000000?oooooo`00
0?l000000_l000001?oooooo0000o`000?ooool3o`0000[ooooo0_l000001?oooooo0000o`000?oo
oolMo`0000?ooooo0_l00003ooooo`;o00009oooool3o`00047ooooo000Looooo`03o`000?oooooo
oooo03gooooo1?l00003ooooo`;o00002Oooool2o`00017ooooo7Ol00002ooooo`Co00001_ooool2
o`0000;ooooo0_l00008ooooo`;o00001_ooool2o`0000;ooooo0_l0000=ooooo`oo000000?ooooo
o`000?l000001?l000000ooooooo0000o`000007o`000003ooooool0003o000000Ko00000_ooool2
o`0002Gooooo1?l00009ooooo`;o0000=?ooool001cooooo00?o0000ooooooooool0??ooool2o`00
0003ooooool0003o000000?ooooo0_l00009ooooo`;o00003ooooolOo`0000Cooooo0_l0000?oooo
o`;o00002Oooool2o`0001Cooooo4Ol000000ooooooo0000o`00000Do`0000;ooooo0_l0000>oooo
o`;o00003oooool2o`0000Kooooo0_l00009ooooo`;o0000=?ooool001cooooo00?o0000oooooooo
ool0??ooool2o`000003ooooool0003o000000?ooooo0_l00009ooooo`;o00000_ooool2o`0000[o
oooo7_l0000;ooooo`;o00002_ooool2o`0000Wooooo0_l0000>ooooo`[o000000?oooooo`000?l0
00006Ol000000ooooooo0000o`00000Booooo`;o00000oooool2o`0000oooooo0_l0000?ooooo`;o
0000=_ooool001cooooo00?o0000ooooooooool0@oooool3o`000003ooooool0003o000000[ooooo
0_l00002ooooo`;o00001_ooool2o`000003ooooool0003o000001Wo00000oooool4o`0000Cooooo
0_l00006ooooo`;o00003?ooool2o`0000Wooooo0_l00003oooooa3o000000?oooooo`000?l00000
6?l0000<ooooo`;o00000_ooool3o`000003ooooool0003o0000013ooooo0_l0000<ooooo`Ko0000
=_ooool001cooooo00?o0000ooooooooool0@oooool6o`0000Oooooo0_l00005ooooo`;o00001_oo
oolLo`0000Gooooo1?l0000<ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o000000Co
ooooo`000?l0003ooooo;Ol00003ooooo`;o00001oooool2o`0000;ooooo0_l00002ooooo`;o0000
1?ooool4o`0000Sooooo0_l0000<ooooo`Co0000>?ooool001cooooo00?o0000ooooooooool0=Ooo
ool2o`0000gooooo0ol000000ooooooo0000o`000006ooooo`;o00003Oooool4o`000003ooooool0
003o000000ko000000?oooooo`000?l000001Ol00004ooooo`;o00005Oooool2o`0000Wooooo0_l0
0002ooooo`;o00001?ooool2o`0000;ooooo5?l000000ooooooo0000o`00000=o`000003ooooool0
003o000000Oo00005Oooool4o`0000Gooooo0_l0000>ooooo`;o0000>oooool001cooooo00?o0000
ooooooooool0<?ooool3o`0000;ooooo0_l00006ooooo`;o00001Oooool6o`0001Kooooo6?l00000
1?oooooo0000o`000?l00004ooooo`;o00001Oooool2o`0000kooooo0_l00009ooooo`;o00000_oo
ool4o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l00000;?l0000Mooooo`Co0000
3?ooool2o`0003_ooooo000Looooo`03o`000?oooooooooo033ooooo0ol00003ooooo`;o00001Ooo
ool2o`0000Oooooo0_l0000Gooooo`Ko000000?oooooo`000?l000001Ol000000ooooooo0000o`00
000<o`000003ooooool0003o000000Sooooo0_l00007ooooo`?o00000_ooool3o`0000Gooooo0_l0
0007ooooo`Co000000?oooooo`000?l000000ol000000ooooooo0000o`00000To`0000;ooooo0_l0
00000ooooooo0000o`000002o`0000kooooo0ol00004ooooo`;o00001oooool2o`0000Gooooo1?l0
0010ooooo`007?ooool00ol0003oooooooooo`0fooooo`Co00006Oooool2o`0000[ooooo1Ol00002
ooooo`So000000?oooooo`000?l000002ol000000ooooooo0000o`000004ooooo`;o00002oooool3
o`0000;ooooo0ol00005ooooo`Co00001OoooolSo`000003ooooool0003o000000So000000?ooooo
o`000?l000000_ooool2o`0000?ooooo0_l00003ooooo`;o00002Oooool3o`0000Cooooo0_l00002
ooooo`;o00002Oooool5o`0000Kooooo0_l0000hooooo`007?ooool2o`0003;ooooo0_l00002oooo
o`;o000000?oooooo`000?l000004oooool3o`0000?ooooo0_l00009ooooo`;o000000?oooooo`00
0?l000001Ol000000ooooooo0000o`00000Bo`000003ooooool0003o000000?ooooo0_l000000ooo
oooo0000o`000002o`0000Kooooo0_l00003ooooo`;o000000?oooooo`000?l000000oooool4o`00
00Gooooo0_l00002oooooako000000?oooooo`000?l000002Ol000000ooooooo0000o`000002o`00
00?ooooo0_l00005ooooo`;o00001_ooool3o`0000Kooooo1?l000000ooooooo0000o`000009oooo
o`;o00002Oooool2o`0003Sooooo000Looooo`03o`000?oooooooooo037ooooo0_l00002ooooo`;o
00002?ooool4o`0000[ooooo0ol00003ooooo`?o000000Coooooo`000?l0003o00001?ooool2o`00
0003ooooool0003o000001?o000000?oooooo`000?l000001?l000001?oooooo0000o`000?ooool2
o`0000?ooooo1Ol00006ooooo`Ko000000?oooooo`000?l000000oooool3o`0000Kooooo0_l00000
0ooooooo0000o`000004o`000003ooooool0003o000001Ko000000?oooooo`000?l000002Ol00000
0ooooooo0000o`000004o`000003ooooool0003o000000Kooooo0_l00005ooooo`?o00001_ooool4
o`0000Gooooo0_l00009ooooo`;o00001?ooool2o`0003Wooooo000Looooo`03o`000?oooooooooo
03;ooooo0_l00005ooooo`;o00000_ooool6o`0000[ooooo0_l00004ooooo`Oo00002?oooolIo`00
00Cooooo1?l00006ooooo`?o00001Oooool4o`0000gooooo0_l00005ooooo`Co00000ooooolBo`00
0003ooooool0003o000001?o000000?oooooo`000?l000001_ooool2o`000003ooooool0003o0000
00Kooooo0_l00002ooooo`;o00001Oooool2o`0000Cooooo0_l00009ooooo`;o00001?ooool2o`00
03Wooooo000Looooo`03o`000?oooooooooo03;ooooo0_l00005ooooo`;o00000_ooool2o`0001Ko
oooo0_l0000:ooooo`Ko000000?oooooo`000?l000004ol00002ooooo`;o00002?ooool3o`0001Ko
oooo0_l00007ooooo`;o00000_oooolYo`000003ooooool0003o000000?ooooo0_l000000ooooooo
0000o`000009ooooo`;o00000_ooool2o`0000Gooooo0_l00005ooooo`Co00000oooool2o`0000Co
oooo0_l0000looooo`007?ooool00ol0003oooooooooo`1Cooooo`?o00002ooooolLo`000003oooo
ool0003o0000017ooooo0_l00005ooooo`;o00002?ooool4o`0000Gooooo0_l00002ooooobgo0000
0_ooool2o`000003ooooool0003o000000?ooooo0_l00004ooooo`;o00004?ooool4o`0000?ooooo
0_l00003ooooo`Go0000>_ooool001cooooo00?o0000ooooooooool0C_ooool3o`0000;ooooo0ol0
000<oooooa?o000000?oooooo`000?l000001Ol000000ooooooo0000o`000006ooooo`;o00001Ooo
ool2o`0000;ooooo0_l00005ooooo`Ko00001?ooool4o`0000Gooooo0_l000000ooooooo0000o`00
0003o`0000;ooooo1_l000000ooooooo0000o`000005o`000003ooooool0003o000000Ko000000?o
ooooo`000?l000001Ol000000ooooooo0000o`000002o`000003ooooool0003o000000Oooooo0_l0
00000ooooooo0000o`00000Rooooo`;o000000?oooooo`000?l00000>_ooool001cooooo00?o0000
ooooooooool0C_ooool3o`00017ooooo6ol00006ooooo`;o000000?oooooo`000?l000001?ooool3
o`0000Kooooo0_l00003ooooo`Co00001?ooool2o`0000Gooooo1?l000000ooooooo0000o`000002
o`000003ooooool0003o000001?o000000?oooooo`000?l000002_l000001?oooooo0000o`000?l0
0003ooooo`Go00000_ooool2o`0001?ooooo0_l0000Yooooo`;o00009?ooool001cooooo00?o0000
ooooooooool0?Oooool2o`0000kooooo0_l0000Cooooo`;o000000?oooooo`000?l000004?l0000<
ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Oooooo0_l00005ooooo`;o00001?ooool2
o`0000Gooooo0_l00003ooooo`Co000000?oooooo`000?l00000;_l0000Aooooo`;o00000_ooool2
o`0002Wooooo0_l0000Tooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00000oooool4o`00
00Kooooo1Ol00005ooooo`;o00003oooool2o`000003ooooool0003o000000[o00001_ooool2o`00
00Sooooo0_l000000ooooooo0000o`000004ooooo`;o00002Oooool5o`0000gooooo5Ol000000ooo
oooo0000o`00000Oo`0000gooooo0_l00002ooooo`;o00001Oooool2o`0000;ooooo0_l000000ooo
oooo0000o`000002o`0004?ooooo000Looooo`03o`000?oooooooooo03Cooooo0_l00005ooooo`;o
00001Oooool4o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000001Oooool2o`0000oo
oooo0_l000001Ooooooo0000o`000?l0003ooooo00Go000000?oooooo`000?l000000ol00003oooo
o`;o00002oooool2o`0000?ooooo1Ol00005ooooo`Oo00001_ooool2o`0000?ooooo1?l000000ooo
oooo0000o`000003o`000003ooooool0003o0000023o00000oooool2o`0000?ooooo0_l0000?oooo
o`Co00001oooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0004?ooooo000Looooo`03
o`000?oooooooooo03Cooooo0_l00005ooooo`?o00001?ooool2o`0000Cooooo0_l000000ooooooo
0000o`00000Looooo`?o000000?oooooo`000?l000001Ol000000ooooooo0000o`000002o`000003
ooooool0003o000000;o00002oooool2o`0000?ooooo1Ol00005ooooo`;o00002oooool2o`0000?o
oooo0ol000000ooooooo0000o`00000]o`0000?ooooo0_l0000?ooooo`?o00003Oooool2o`0004Ko
oooo000Looooo`03o`000?oooooooooo03cooooo0_l00004ooooo`;o00001oooool2o`0000?ooooo
0_l00008ooooo`;o00003Oooool2o`000003ooooool0003o000000Ko00001_ooool4o`0000Oooooo
0_l00002ooooo`;o00000oooool4o`0001?ooooo0_l00006ooooobgo000000?oooooo`000?l00000
0oooool2o`0000Kooooo0_l00007ooooo`;o00003_ooool2o`0004Kooooo000Looooo`03o`000?oo
oooooooo04Cooooo0_l00004ooooo`;o00001?ooool2o`000003ooooool0003o000000Gooooo0_l0
0009ooooo`;o000000?oooooo`000?l000000_ooool8o`0000?ooooo0_l0000<ooooo`;o00007_oo
ool2o`0000Kooooo0_l000000ooooooo0000o`00000Io`000003ooooool0003o000000So00000_oo
ool2o`0000;ooooo1?l00002ooooo`;o00001?ooool2o`000003ooooool0003o000000;o00001ooo
ool2o`0000?ooooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`0looooo`;o00001_ooool2
o`0000;ooooo1?l00007ooooo`;o00004?ooool2o`000003ooooool0003o000000?ooooo0_l00003
ooooo`;o00000oooool2o`0001Oooooo0_l0000Gooooo`;o00001?ooool2o`0000?ooooo4Ol00000
0ooooooo0000o`00000>o`0000;ooooo0_l000000ooooooo0000o`000003o`0000;ooooo1?l00000
0ooooooo0000o`000002ooooo`Co00001oooool2o`0000?ooooo0_l0001<ooooo`0000Koooooonk^
k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo
00?o0000ooooooooool0??ooool2o`000003ooooool0003o000000Oooooo1?l00004ooooo`;o0000
0_ooool2o`0000Gooooo0_l00008ooooo`Co00001oooool4o`0001Gooooo0_l00005ooooo`;o0000
2_ooool2o`0000_ooooo0_l00003ooooo`?o00000_oooolQo`0000?ooooo2?l000000ooooooo0000
o`000004o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o00003_ooool2o`0004Sooooo
00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRH
V?lQ8B401_ooool00ol0003oooooooooo`0hooooo`;o000000Goooooo`000?l0003o0000ooooo`02
o`0000Wooooo0_l00004ooooo`;o00000_ooool2o`0000Gooooo0ol00008ooooo`?o00001oooool7
o`0001;ooooo0_l0000<ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000008
ooooo`;o00000ooooolJo`000003ooooool0003o000000Wo000000?oooooo`000?l000002?l00000
0ooooooo0000o`000002o`0000?ooooo0_l00002ooooo`;o00000_ooool3o`0000gooooo0_l00005
ooooo`;o0000@Oooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0>?ooool2o`000003ooooool0003o
000000Cooooo0_l0000:ooooo`;o00000oooool2o`0000Sooooo1?l00006ooooo`Go00001_ooool6
o`0001_ooooo1?l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l0000=ooooo`Go000000?o
ooooo`000?l000007?l000000ooooooo0000o`000009o`0000Sooooo0ol00007ooooo`;o00003?oo
ool2o`0000Kooooo0_l00011ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09
ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0003Cooooo0_l0000;ooooo`;o00002Ooo
ool4o`000004ooooool0003o0000o`0000?ooooo2Ol00007ooooo`Co00001_ooool4o`0001Sooooo
0_l00003ooooo`Co00002Oooool2o`0000Gooooo0ol00002ooooo`;o00001oooool7o`000003oooo
ool0003o000001?o00000_ooool3o`000003ooooool0003o000000Co00002Oooool2o`0000?ooooo
0_l0000Aooooo`;o0000BOooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0=?ooool2o`0001Kooooo
1?l000001?oooooo0000o`000?l00003ooooo`Oo00005Oooool2o`0000Wooooo0_l0000=ooooo`;o
00000oooool2o`000003ooooool0003o000000Oooooo0_l00006ooooo`?o00000_ooool2o`0000Oo
oooo1_l00002oooooaGo00001_ooool2o`0000;ooooo1?l0000<ooooo`;o00002?ooool3o`0000Wo
oooo0_l00016ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`03oeEE
EOn7QhOooooo00Sooooo00?o0000ooooooooool0=?ooool4o`0001Cooooo0_l00004ooooo`;o0000
2?ooool2o`000003ooooool0003o000000Gooooo0_l0000:ooooo`Co00002?ooool2o`0000?ooooo
0_l0000=ooooo`;o000000?oooooo`000?l000001oooool2o`0000Kooooo0_l00004ooooo`Co0000
0oooool3o`000003ooooool0003o000000;o000000?oooooo`000?l000005ol000000ooooooo0000
o`000002o`0000?ooooo0_l0000Fooooo`?o00001Oooool2o`0000;ooooo0ol00015ooooo`0000Ko
ooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000oooooooo
ool09?ooool2o`00013ooooo0_l0000Iooooo`;o00001Oooool2o`0000;ooooo1Ol00005ooooo`;o
00000_ooool2o`0000Kooooo1?l00003ooooo`;o00000oooool2o`0000?ooooo0_l00007ooooo`;o
00004?ooool2o`0000Kooooo0_l00004ooooo`Co00000ooooolJo`0000;ooooo1_l000000ooooooo
0000o`000002o`0000?ooooo0_l0000=ooooo`;o00001?ooool5o`0000Kooooo0_l00003ooooo`Co
0000@oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106
ooooo`03o`000?oooooooooo02Cooooo0_l0000Looooo`;o00003Oooool3o`0000;ooooo1?l00003
ooooo`Go00002?ooool4o`0000Gooooo0_l00004ooooo`;o00000_ooool2o`0000gooooo0_l00000
0ooooooo0000o`000003ooooo`;o00002?ooool2o`0000Gooooo0_l00006ooooo`;o00001?oooolR
o`0000;ooooo0_l00004ooooo`Co00002oooool2o`0000Cooooo0ol0000:ooooo`;o00000oooool2
o`0004?ooooo000Looooo`03o`000?oooooooooo03cooooo0_l00004ooooo`;o00001Oooool2o`00
00?ooooo0_l00002ooooo`;o00000_ooool2o`0000Kooooo1?l00007ooooo`;o000000?oooooo`00
0?l000000oooool6o`0000?ooooo0_l000000ooooooo0000o`000004o`0000?ooooo0_l00002oooo
o`;o00000oooool2o`000003ooooool0003o000000;o00001Oooool2o`0000Sooooo0_l00005oooo
o`;o00001oooool2o`000003ooooool0003o000000?o000000?oooooo`000?l000000_l00002oooo
o`co00001?ooool2o`000003ooooool0003o000000Cooooo1?l0000Booooo`;o00002_ooool2o`00
04Sooooo000Looooo`03o`000?oooooooooo03;ooooo0_l00008ooooo`;o00002?ooool2o`000004
ooooool0003o0000ooooo`Co00001oooool2o`00013ooooo0_l00006ooooo`?o000000?oooooo`00
0?l000000oooool2o`0000?ooooo1Ol00002ooooo`;o00000_ooool2o`0000?ooooo0_l000000ooo
oooo0000o`000002o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`00000<oooo
o`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000Kooooo0_l000000ooo
oooo0000o`00000=o`0000;ooooo0_l0000Mooooo`;o00002?ooool2o`0004[ooooo000Looooo`03
o`000?oooooooooo03;ooooo0_l0000Booooo`;o00000oooool3o`0000Gooooo0ol000000ooooooo
0000o`00000<ooooo`;o00002oooool2o`0000Oooooo0_l000000ooooooo0000o`000002ooooo`;o
00001_ooool2o`0000Kooooo1?l000000ooooooo0000o`000005ooooo`;o00003oooool2o`0000;o
oooo0_l00002ooooo`?o00002Oooool3o`000003ooooool0003o000000Go000000?oooooo`000?l0
00000_l00003ooooo`;o00006Oooool2o`0000Cooooo0_l00004ooooo`;o0000B_ooool001cooooo
00?o0000ooooooooool0@?ooool2o`0000Cooooo0_l00003ooooo`;o00001_ooool3o`0000oooooo
0_l0000Dooooo`;o000000?oooooo`000?l000002_ooool2o`0000?ooooo0_l000000ooooooo0000
o`000002ooooo`;o00003oooool2o`0000Oooooo0_l000000ooooooo0000o`000002ooooo`;o0000
1?ooool2o`000003ooooool0003o000000;ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o
00000oooool3o`0000?ooooo0_l00009ooooo`;o00002oooool2o`000003ooooool0003o000000?o
oooo0ol00002ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0@?ooool4o`0000Oooooo
1?l0000@ooooo`;o00002Oooool2o`0000kooooo0_l00007ooooo`;o00001Oooool2o`0000?ooooo
0_l00005ooooo`;o00002oooool2o`0000;ooooo0_l00007ooooo`;o00002oooool2o`000003oooo
ool0003o000000;ooooo0_l00003ooooo`Co00000oooool5o`0000cooooo0_l00003ooooo`;o0000
1_ooool2o`0000Kooooo0ol00002ooooo`Co0000B_ooool001cooooo00?o0000ooooooooool0@_oo
ool4o`0000Gooooo1?l00004ooooo`;o00000_ooool2o`0000Kooooo0_l00009ooooo`?o00001_oo
ool2o`0000Gooooo0_l00007ooooo`?o00000oooool4o`000003ooooool0003o000000;o00002_oo
ool2o`0000;ooooo1Ol0000:ooooo`;o00001Oooool2o`000003ooooool0003o000000Cooooo0ol0
0002ooooo`;o000000?oooooo`000?l000001?l00004ooooo`Go00001oooool2o`0000Oooooo0_l0
0008ooooo`Co00000oooool3o`0000?ooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`0[
ooooo`;o00002?ooool2o`0000Sooooo0_l00003ooooo`;o00001Oooool3o`0000;ooooo0_l00000
1?oooooo0000o`000?ooool3o`0000Kooooo0_l00002ooooo`;o00001_ooool3o`0000Gooooo0_l0
000?ooooo`;o00000_ooool5o`000003ooooool0003o000000;o00001oooool2o`000005ooooool0
003o0000o`000?ooool01?l000000ooooooo0000o`000002o`000003ooooool0003o000000;ooooo
0ol00005ooooo`Go000000Coooooo`000?l0003ooooo0ol00002ooooo`Oo00001oooool4o`0000Oo
oooo0_l00002ooooo`;o00002Oooool2o`0000;ooooo1_l000001Ooooooo0000o`000?l0003ooooo
00;o00001?ooool2o`0004Kooooo000Looooo`03o`000?oooooooooo02_ooooo0_l00008ooooo`;o
00000_ooool2o`0000Cooooo0_l0000:ooooo`;o00000oooool2o`000004ooooool0003o0000oooo
o`;o00001oooool2o`0000;ooooo0_l000001?oooooo0000o`000?l00002ooooo`?o00004_ooool2
o`0000;ooooo2ol000000ooooooo0000o`000006ooooo`?o00000_ooool2o`0000?ooooo0_l00000
0ooooooo0000o`000002o`000003ooooool0003o000000Co00002?ooool2o`0000;ooooo0_l00006
ooooo`Co000000?oooooo`000?l000005_ooool2o`0000Wooooo0_l00004ooooo`Co000000?ooooo
o`000?l000000_ooool2o`0000Cooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`0ioooo
o`;o00000_ooool2o`00017ooooo0_l00004ooooo`;o00002oooool2o`000004ooooool0003o0000
o`0000cooooo0_l00009ooooo`;o000000?oooooo`000?l000002_l000000ooooooo0000o`000006
ooooo`;o00000oooool2o`0000?ooooo0_l00008ooooo`;o00007_ooool2o`0000Cooooo0_l00000
0ooooooo0000o`000002o`0001Cooooo0_l00003ooooo`;o0000EOooool001cooooo00?o0000oooo
ooooool0>Oooool2o`0000;ooooo0_l0000Aooooo`;o00008oooool2o`0000Oooooo0_l00002oooo
o`go00001?ooool3o`0000_ooooo0ol00002ooooo`;o00009?ooool2o`0000Cooooo0_l000000ooo
oooo0000o`000002o`0000[ooooo0_l00008ooooo`;o00001_ooool3o`00057ooooo000Looooo`03
o`000?oooooooooo03Sooooo1?l0000Dooooo`Go0000:OoooolBo`0000;ooooo1?l00007ooooo`Oo
00000_ooool2o`0000Oooooo0_l0000Fooooo`;o00001?ooool2o`0000Kooooo0_l0000<ooooo`;o
00004?ooool3o`0000Sooooo0_l00017ooooo`007?ooool2o`0003Wooooo1?l00006ooooo`;o0000
3_ooool3o`0000?ooooo0_l0000Aooooo`;o00003ooooolJo`0000Kooooo1ol00002ooooo`;o0000
00?oooooo`000?l000001Oooool2o`0000Cooooo0_l0000@ooooo`;o00001?ooool2o`0000cooooo
0_l0000:ooooo`;o00005oooool2o`0004Oooooo000Looooo`03o`000?oooooooooo04;ooooo0_l0
000Dooooo`;o00004Oooool2o`0000Oooooo0_l00006oooooaWo00001_ooool3o`0000?ooooo3?l0
0003ooooo`;o00000oooool2o`0002Cooooo0_l00003ooooo`?o00001?ooool3o`0000;ooooo0_l0
0006ooooo`?o00000oooool2o`0004gooooo000Looooo`03o`000?oooooooooo05oooooo0_l0000>
ooooo`;o00000oooool2o`0000Wooooo5_l00006ooooo`;o00001_ooool2o`0000;ooooo1_l00002
ooooo`?o00000oooool2o`0002Wooooo0ol00005ooooo`;o00000_ooool2o`000003ooooool0003o
000000?ooooo0ol00003ooooo`;o0000COooool001cooooo00?o0000ooooooooool0Doooool2o`00
00Gooooo0_l00002ooooo`?o00001Oooool2o`0000Oooooo0_l0000>ooooo`ko000000?oooooo`00
0?l000001Ol0000Dooooo`;o00001?ooool4o`0000gooooo0_l0000Hooooo`;o00001?ooool2o`00
00gooooo0_l00002ooooo`;o00001_ooool2o`0001Wooooo0_l0000aooooo`007?ooool00ol0003o
ooooooooo`11ooooo`;o00001Oooool2o`0000Wooooo0_l00005ooooo`;o000000Coooooo`000?l0
003o00001_ooool2o`0001Kooooo5ol00003ooooo`?o00000oooool2o`000003ooooool0003o0000
00Cooooo0_l00004ooooo`;o000000Coooooo`000?l0003o00001Oooool4o`0000Cooooo0_l0000>
ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`000003ooooool0003o000000Oooooo0_l0
000;ooooo`;o00001_ooool2o`0001Wooooo0_l0000aooooo`007?ooool00ol0003oooooooooo`11
ooooo`;o00000oooool5o`0000;ooooo0_l0000>ooooo`Co00006_oooolHo`0000Gooooo0ol00000
0ooooooo0000o`000002o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000001?oo
ool2o`0000Wooooo1?l0000Dooooo`So00000oooool4o`0000Oooooo1?l00002ooooo`;o0000Fooo
ool001cooooo00?o0000ooooooooool0A_ooool2o`000003ooooool0003o000000Oo00003Oooool2
o`0001Cooooo0_l00004oooooaWo00002?ooool2o`0000Kooooo0_l00005ooooo`;o00003?ooool2
o`0000Oooooo0ol000001?oooooo0000o`000?ooool4o`0000Gooooo0_l00002ooooo`;o00000_oo
ool5o`0000Wooooo0_l00002ooooo`;o0000Foooool001cooooo00?o0000ooooooooool0Boooool2
o`000003ooooool0003o000000;o00008oooool2o`0000Oooooo6?l0000Aooooo`;o000000Gooooo
o`000?l0003o0000ooooo`03o`0000Sooooo0_l000000ooooooo0000o`000004ooooo`?o000000Co
ooooo`000?l0003ooooo1Ol00004ooooo`;o00001?ooool5o`0000Kooooo0_l0001Tooooo`007?oo
ool00ol0003oooooooooo`16ooooo`;o00000oooool2o`0001[ooooo0_l0000=ooooo`;o00001_oo
oolJo`0000oooooo0_l000000ooooooo0000o`000002ooooo`?o00002Oooool4o`0000Oooooo0ol0
00001?oooooo0000o`000?ooool2o`0000Cooooo0_l000000ooooooo0000o`000003o`000003oooo
ool0003o000000;ooooo0_l00002ooooo`;o00002Oooool4o`0005Oooooo000Looooo`03o`000?oo
oooooooo04Kooooo0_l00003ooooo`;o00002Oooool2o`000004ooooool0003o0000ooooo`;o0000
2Oooool2o`0000Sooooo0_l00003ooooo`;o00001_oooolCo`000003ooooool0003o000000;ooooo
0_l000000ooooooo0000o`000002o`0001Gooooo0_l00006ooooo`;o00000oooool2o`0000Cooooo
0_l00002ooooo`;o00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`0000?ooooo
1Ol00004ooooo`;o00000oooool2o`0000;ooooo1?l0001Gooooo`007?ooool00ol0003ooooooooo
o`11ooooo`;o00000oooool2o`0000Cooooo0_l00008ooooo`;o000000Coooooo`000?l0003ooooo
0_l00007ooooo`;o00002_ooool2o`0000Wooooo0_l00002oooooaCo00000_ooool2o`000003oooo
ool0003o000000;o00004?ooool2o`0000?ooooo0ol0000:ooooo`?o00002?ooool2o`000003oooo
ool0003o000000Sooooo0_l00003ooooo`Go00001?ooool4o`000003ooooool0003o000000;ooooo
0_l00002ooooo`;o0000EOooool001cooooo00?o0000ooooooooool0@Oooool2o`0000Oooooo1?l0
0004ooooo`;o00004Oooool2o`0001Cooooo0ol00002ooooo`go000000?oooooo`000?l000000ol0
0006ooooo`;o00003Oooool2o`0000;ooooo0ol00004ooooo`;o00001?ooool2o`0000?ooooo1?l0
0008ooooo`?o00003Oooool2o`0000?ooooo1?l00003ooooo`?o00001Oooool2o`0000;ooooo0_l0
001Eooooo`007?ooool00ol0003oooooooooo`19ooooo`?o00001?ooool7o`0000Cooooo0ol0000G
ooooo`;o00000oooool3o`0000?ooooo5Ol00003ooooo`;o00001?ooool2o`0000Sooooo0_l00002
ooooo`;o00002oooool2o`000003ooooool0003o000000?o00001oooool2o`000003ooooool0003o
000000Cooooo0_l00007ooooo`;o000000?oooooo`000?l000000_ooool4o`000003ooooool0003o
000000Wooooo1Ol0001Cooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00001Oooool2o`00
00;ooooo0ol00004ooooo`?o00004oooool2o`0000;ooooo0_l00003ooooo`;o00000ooooolFo`00
00?ooooo0_l00004ooooo`;o00001oooool2o`0001?ooooo1Ol00007ooooo`;o000000?oooooo`00
0?l000001?ooool2o`0000[ooooo0ol00003ooooo`;o00001oooool2o`0000?ooooo0_l000000ooo
oooo0000o`00001Cooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o00001Oooool2o`000003
ooooool0003o000001Oooooo0_l00006ooooo`;o00001?oooolCo`0000Gooooo0_l00002ooooo`;o
00001Oooool2o`0000?ooooo0_l000000ooooooo0000o`00000Booooo`;o00004_ooool2o`0000?o
oooo0_l00004ooooo`?o00003?ooool2o`0000?ooooo1?l0001Dooooo`007?ooool00ol0003ooooo
ooooo`13ooooo`;o00000_ooool2o`0000Gooooo0_l000000ooooooo0000o`000002ooooo`;o0000
00?oooooo`000?l000007Oooool4o`0000Oooooo4_l00003ooooo`;o00000_ooool2o`0000Gooooo
0_l00006ooooo`;o00003?ooool4o`0001Kooooo0_l00003ooooo`;o00006Oooool3o`0005Cooooo
000Looooo`;o0000A?ooool2o`0000;ooooo0_l00002ooooo`;o00001?ooool2o`0002?ooooo0ol0
000:ooooo`ko000000?oooooo`000?l000000_l0000@ooooo`;o00004?ooool4o`0000Gooooo1?l0
0004ooooo`;o00001oooool2o`0000;ooooo0_l00002ooooo`;o00002oooool2o`0000Wooooo0_l0
001Eooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o00002?ooool2o`0000Sooooo0_l00006
ooooo`;o00003Oooool2o`0000gooooo2?l000001?oooooo0000o`000?l00003ooooo`;o00004?oo
ool2o`0000Kooooo0_l00008ooooo`Co00000_ooool2o`000003ooooool0003o000000;o00000_oo
ool4o`0000Oooooo0_l00002ooooo`?o000000?oooooo`000?l000002_ooool3o`0000Gooooo0_l0
001Iooooo`007?ooool00ol0003oooooooooo`1Eooooo`?o00001oooool2o`0000Kooooo1Ol0000:
ooooo`?o00003?ooool;o`0000?ooooo0_l00009ooooo`;o00003_ooool2o`0000kooooo0_l00007
ooooo`;o00003_ooool2o`0000Wooooo0_l00002ooooo`;o000000?oooooo`000?l000000oooool2
o`0000oooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o00000oooool2o`00
00[ooooo0_l00005ooooo`?o00002_ooool3o`0000cooooo0ol000001Ooooooo0000o`000?l0003o
oooo00?o00000oooool2o`0000Wooooo0_l00005ooooo`;o00000_ooool2o`0000Oooooo0ol0000I
ooooo`?o00003oooool4o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`;o00003Oooool2
o`0004Sooooo000Looooo`03o`000?oooooooooo057ooooo1?l00004ooooo`;o00001oooool2o`00
02;ooooo0_l00006ooooo`?o00004?ooool2o`0000;ooooo1_l00004ooooo`;o000000Coooooo`00
0?l0003o00002_ooool3o`0000cooooo0ol0000?ooooo`?o00000oooool2o`0000Sooooo0_l0001G
ooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o000000Coooooo`000?l0003ooooo1?l00000
0ooooooo0000o`000002ooooo`;o00005?ooool4o`0000Gooooo0_l0000;ooooo`?o00001_ooool2
o`0000;ooooo0_l00004ooooo`;o00000oooool3o`0000Gooooo0ol00004ooooo`;o00001?ooool2
o`0000;ooooo0ol0000;ooooo`;o00005oooool2o`0000;ooooo0_l0001Mooooo`007?ooool00ol0
003oooooooooo`19ooooo`;o00002oooool2o`0000;ooooo0ol000000ooooooo0000o`000002oooo
o`;o00001?ooool2o`0000kooooo1?l000001?oooooo0000o`000?ooool3o`0001Cooooo0_l00002
ooooo`;o00001?ooool2o`000003ooooool0003o000000;o00000oooool2o`000003ooooool0003o
000000Gooooo0_l00004ooooo`;o00001Oooool4o`0000Oooooo0_l00006ooooo`Co00002?ooool2
o`000003ooooool0003o000000Cooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`19oooo
o`;o00003oooool2o`0000Kooooo0_l00004ooooo`;o00004Oooool4o`000003ooooool0003o0000
01[ooooo1Ol00003ooooo`;o00001Oooool4o`0000Oooooo0_l0000:ooooo`Co000000?oooooo`00
0?l000001?ooool2o`0000Kooooo1?l00008ooooo`;o000000?oooooo`000?l000004Oooool2o`00
053ooooo000Looooo`03o`000?oooooooooo05Sooooo1?l00006ooooo`;o00003?ooool4o`0000Oo
oooo0_l00007ooooo`;o00002oooool2o`0000Wooooo1Ol0000;ooooo`?o00001oooool5o`0000co
oooo0_l00004ooooo`;o00001?ooool2o`00017ooooo0_l0000?ooooo`;o000000?oooooo`000?l0
0000COooool001cooooo00?o0000ooooooooool0F?ooool2o`0000Cooooo0_l000000ooooooo0000
o`000008ooooo`;o00000oooool4o`00013ooooo1?l00009ooooo`;o00001_ooool2o`0000Wooooo
1?l00003ooooo`Co00001Oooool2o`000003ooooool0003o000000;o000000?oooooo`000?l00000
0oooool2o`0000_ooooo0_l00003ooooo`;o00001?ooool2o`0000_ooooo0_l0000Booooo`;o0000
COooool001cooooo00?o0000ooooooooool0C_ooool2o`0000kooooo0_l000000ooooooo0000o`00
0007ooooo`?o00004?ooool2o`0000Oooooo0_l0000Aooooo`;o00002Oooool9o`0000Gooooo1?l0
0002ooooo`;o00000_ooool2o`0000?ooooo0ol0000:ooooo`;o00001oooool4o`0000Oooooo0_l0
001Uooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o00003_ooool2o`0000[ooooo0_l0000@
ooooo`?o00003Oooool2o`0001[ooooo0ol00007ooooo`;o00003_ooool2o`0001?ooooo1?l00007
ooooo`;o0000IOooool001cooooo00?o0000ooooooooool0G_ooool2o`000003ooooool0003o0000
00;o00004oooool2o`0000;ooooo0_l0000>ooooo`;o00002oooool2o`0000_ooooo1?l0000;oooo
o`;o00000_ooool5o`0000Gooooo0_l000000ooooooo0000o`000002ooooo`;o00003Oooool3o`00
00Gooooo0_l0000;ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0G?ooool2o`0000?o
oooo1?l00009ooooo`Co00001_ooool2o`0000cooooo0_l0000Aooooo`;o00002oooool4o`0000Wo
oooo1?l00002ooooo`Go00001Oooool2o`000003ooooool0003o000000;ooooo1?l000000ooooooo
0000o`000009ooooo`;o00001Oooool2o`0000Sooooo0_l000000ooooooo0000o`00001Iooooo`00
7?ooool00ol0003oooooooooo`1Hooooo`;o00000_ooool2o`000003ooooool0003o000000;o0000
2oooool4o`00013ooooo0_l00002ooooo`;o00001Oooool2o`0001Wooooo0_l00009ooooo`;o0000
1?ooool4o`0000kooooo1_l0000@ooooo`;o00002?ooool2o`0005cooooo000Looooo`03o`000?oo
oooooooo05Sooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l0000Oooooo`;o000000Co
ooooo`000?l0003o00001Oooool2o`0002[ooooo1?l00004ooooo`;o00002?ooool6o`0007Sooooo
000Looooo`;o0000FOooool2o`0000Sooooo0_l00003ooooo`;o00006Oooool2o`000003ooooool0
003o000003Kooooo0_l00002ooooo`;o00002oooool3o`0000?ooooo0_l0000<ooooo`;o0000IOoo
ool001cooooo00?o0000ooooooooool0F?ooool2o`000003ooooool0003o000000Gooooo0_l00003
ooooo`;o00006?ooool4o`000003ooooool0003o000001oooooo0_l0000=ooooo`;o00001Oooool2
o`0000;ooooo0_l0000;ooooo`;o00001?ooool2o`0000cooooo0_l0001Uooooo`007?ooool00ol0
003oooooooooo`1Kooooo`;o00007_ooool2o`0000Cooooo1?l000000ooooooo0000o`000004oooo
o`;o00006Oooool4o`0000Gooooo0ol00003ooooo`;o000000?oooooo`000?l000002?ooool2o`00
00oooooo0_l000000ooooooo0000o`00001`ooooo`007?ooool00ol0003oooooooooo`1Iooooo`;o
00002Oooool2o`0000Cooooo0_l00002ooooo`;o00001_ooool2o`0000?ooooo1?l00002ooooo`;o
00001Oooool2o`0000;ooooo1?l0000Iooooo`;o00001Oooool3o`0000Kooooo0_l00008ooooo`;o
00001_ooool2o`0000Oooooo0_l000000ooooooo0000o`000003ooooo`?o0000J_ooool001cooooo
00?o0000ooooooooool0FOooool2o`0000Wooooo0_l00004ooooo`?o000000?oooooo`000?l00000
0oooool2o`000003ooooool0003o000000;o00000oooool2o`0000Wooooo0ol00003ooooo`;o0000
8?ooool4o`0001Oooooo1?l00003ooooo`;o00001?ooool7o`0001;ooooo0_l0001Fooooo`007?oo
ool00ol0003oooooooooo`1Qooooo`;o000000?oooooo`000?l000001?ooool3o`0000Kooooo0_l0
0003ooooo`;o00001?ooool2o`0000Wooooo1?l0000Hooooo`;o00001_ooool2o`000003ooooool0
003o000000;o00003Oooool3o`0000Oooooo1?l000000ooooooo0000o`000002o`0000Cooooo1Ol0
000Dooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0GOooool2o`0000;ooooo0_l0000A
ooooo`;o00002?ooool2o`0000_ooooo0_l0000Cooooo`;o00000oooool2o`0000Kooooo0_l00002
ooooo`;o000000?oooooo`000?l000000oooool2o`0000Kooooo0ol00005ooooo`?o00001?ooool2
o`0000Kooooo0_l0001_ooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o000000?oooooo`00
0?l000004_ooool2o`0001?ooooo1?l0000Cooooo`;o00001?ooool2o`000004ooooool0003o0000
ooooo`Co00001?ooool2o`0000?ooooo0_l0000>ooooo`?o00001?ooool2o`0000Kooooo0ol0001^
ooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o00001oooool2o`0000Gooooo0_l00003oooo
o`Co00004?ooool3o`0000;ooooo0_l0000Fooooo`;o000000Coooooo`000?l0003ooooo1?l00000
0ooooooo0000o`000002o`0001kooooo1?l00002ooooo`?o0000KOooool001cooooo00?o0000oooo
ooooool0H?ooool2o`0000Oooooo0_l00005ooooo`;o00000oooool4o`0000gooooo0_l00006oooo
o`?o00001?ooool2o`0000?ooooo0_l00004ooooo`;o00003oooool4o`0001Kooooo0_l00006oooo
o`Co00000oooool2o`0006gooooo000Looooo`03o`000?oooooooooo06kooooo0_l0000;ooooo`;o
00001oooool4o`0000?ooooo0_l00002ooooo`;o00000_ooool4o`0000?ooooo0_l00004ooooo`;o
00001Oooool2o`00013ooooo0_l0000<ooooo`;o00000_ooool3o`0000;ooooo0_l000000ooooooo
0000o`000002o`0007;ooooo000Looooo`03o`000?oooooooooo063ooooo0_l0000<ooooo`;o0000
00?oooooo`000?l000002?ooool2o`0000Oooooo0_l00004ooooo`?o00001_ooool2o`0001;ooooo
0_l00005ooooo`;o00002Oooool2o`0000Oooooo0_l00003ooooo`;o00000oooool2o`0000;ooooo
0_l00003ooooo`;o0000L_ooool001cooooo00?o0000ooooooooool0H?ooool2o`0000oooooo0_l0
000:ooooo`;o00001?ooool2o`0000Gooooo0ol00007ooooo`;o00006?ooool2o`0000kooooo1_l0
0003ooooo`;o00001oooool2o`0000;ooooo0_l0001cooooo`007?ooool00ol0003oooooooooo`1i
ooooo`?o000000?oooooo`000?l000001?ooool2o`0000Sooooo0_l00004ooooo`?o00002?ooool2
o`0001?ooooo0_l00009ooooo`Co00000_ooool2o`000003ooooool0003o000000Wooooo1?l0001c
ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`00
0?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0IOooool2o`0001;ooooo0ol00007ooooo`Go0000
1Oooool2o`0000Cooooo0ol00008ooooo`;o00004oooool2o`0000oooooo0_l000000ooooooo0000
o`000003ooooo`Co00000_ooool3o`0007Cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Go
oooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1Uoooo
o`;o000000?oooooo`000?l000000_ooool2o`0000Wooooo0_l00006ooooo`;o00000_ooool5o`00
0003ooooool0003o000000;ooooo0ol0000:ooooo`;o0000:oooool2o`0000;ooooo1Ol00006oooo
o`;o000000?oooooo`000?l00000K_ooool00003ooooool@413ooooo00;ooooo00?o410@oooooooo
ool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0J?ooool2o`00
00;ooooo0_l00009ooooo`?o00001Oooool2o`0000Sooooo0_l00003ooooo`;o00000_ooool2o`00
00Kooooo0_l00004ooooo`;o00000oooool2o`0001Sooooo0ol00009ooooo`;o000000?oooooo`00
0?l000000_l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l0001[ooooo`0000?oooooo`00
0?ooool00_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3
o`0006Sooooo0_l0000:ooooo`;o000000Coooooo`000?l0003o00006?ooool2o`0000_ooooo0ol0
0003ooooo`;o00001?ooool2o`000003ooooool0003o000000kooooo1?l0000;ooooo`;o000000?o
ooooo`000?l000002_ooool2o`0006_ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo00Wooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo06[ooooo0_l0
0008ooooo`Ko00004Oooool2o`0000kooooo0_l000001?oooooo0000o`000?l0000:ooooo`;o0000
00?oooooo`000?l000002Oooool2o`0000?ooooo0_l00003ooooo`;o00002?ooool2o`0007[ooooo
00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go410@okZj^_oooooo^[Zj
oa0@4006ooooo`03o`000?oooooooooo06[ooooo0_l0000:ooooo`Ko00000_ooool2o`0000Cooooo
0_l00003ooooo`Co00003?ooool4o`000003ooooool0003o000000;ooooo0_l0000Eooooo`;o0000
1oooool7o`00083ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oo
oooo^[Zjo`000006ooooo`03o`000?oooooooooo07[ooooo0_l000001?oooooo0000o`000?l00004
ooooo`;o00000oooool2o`0000kooooo0_l00002ooooo`?o00000_ooool2o`0001gooooo2?l00020
ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0
1_ooool00ol0003oooooooooo`1_ooooo`;o00001oooool4o`000003ooooool0003o000000Gooooo
0_l0000Gooooo`?o00006_ooool3o`0000Cooooo1Ol00023ooooo`007?ooool00ol0003ooooooooo
o`1_ooooo`;o00001?ooool2o`000003ooooool0003o000000;o00001oooool3o`0001?ooooo0_l0
000Oooooo`?o00001Oooool2o`0000;ooooo0_l00021ooooo`007?ooool00ol0003oooooooooo`1/
ooooo`;o00001?ooool2o`000003ooooool0003o000000Cooooo0_l00006ooooo`?o00002Oooool2
o`0000Sooooo0_l00006ooooo`;o00006?ooool2o`0000Wooooo0_l00021ooooo`007?ooool00ol0
003oooooooooo`1/ooooo`;o00001?ooool2o`0000;ooooo0_l00003ooooo`;o00001_ooool4o`00
00Sooooo0_l0000@ooooo`;o00002Oooool3o`0000?ooooo0_l00006ooooo`;o0000SOooool001co
oooo00?o0000ooooooooool0MOooool3o`0000_ooooo1?l0000<ooooo`;o00005oooool3o`0000?o
oooo0_l00006ooooo`;o0000SOooool001cooooo00?o0000ooooooooool0MOooool2o`0000[ooooo
1Ol0000=ooooo`;o00001Oooool3o`000:cooooo000Looooo`03o`000?oooooooooo087ooooo0ol0
000?ooooo`;o00001Oooool3o`0000?ooooo0_l0000Dooooo`;o00008oooool2o`0006cooooo000L
ooooo`03o`000?oooooooooo087ooooo0ol0000Gooooo`;o00000oooool2o`0001Cooooo0_l00009
ooooo`;o00006?ooool2o`0006cooooo000Looooo`03o`000?oooooooooo09Sooooo0_l000001?oo
oooo0000o`000?ooool4o`0000Sooooo0_l0000@ooooo`;o00000oooool2o`0008Kooooo000Loooo
o`03o`000?oooooooooo09Sooooo1?l00002ooooo`Co00001_ooool4o`0000Kooooo1?l00006oooo
o`;o0000Roooool001cooooo00?o0000ooooooooool0Noooool2o`0000gooooo0ol00008ooooo`Co
000000?oooooo`000?l000003?ooool2o`0000;ooooo0ol00003ooooo`Co00001?ooool3o`0000;o
oooo0_l00028ooooo`007?ooool00ol0003oooooooooo`1booooo`;o00001oooool2o`0000gooooo
0ol00006ooooo`Ko00004oooool3o`0000_ooooo0ol00002ooooo`?o0000Qoooool001cooooo0_l0
001cooooo`;o00002Oooool2o`0001Cooooo0_l0000Iooooo`;o00004?ooool2o`0008Oooooo000L
ooooo`03o`000?oooooooooo07gooooo0_l0000Fooooo`;o00005oooool3o`0000Sooooo0_l0002>
ooooo`007?ooool00ol0003oooooooooo`2Eooooo`;o00006?ooool3o`0000Oooooo1?l0002<oooo
o`007?ooool00ol0003oooooooooo`2`ooooo`;o00001_ooool2o`000004ooooool0003o0000oooo
o`;o0000ROooool001cooooo00?o0000ooooooooool0]?ooool2o`0000;ooooo0_l00004ooooo`;o
0000ROooool001cooooo00?o0000ooooooooool0]?ooool2o`0009?ooooo000Looooo`03o`000?oo
oooooooo0;Sooooo0_l0002?ooooo`007?ooool00ol0003oooooooooo`2hooooo`;o0000Soooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
09Sooooo0_l0002_ooooo`007?ooool00ol0003oooooooooo`2Hooooo`;o00003_ooool2o`0009oo
oooo000Looooo`03o`000?oooooooooo0:Kooooo1?l0002Oooooo`007?ooool2o`000:Oooooo0_l0
002Qooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o
0000ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Co
oooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo
000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomB
ooooo`004_ooool00omEEEGoIVIVo`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo002Qooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05_oo
ool4o`000003oa0@4?oooooooooo00;ooooo0_l000001?l@413oooooooooooooool5o`0000?ooooo
1Ol0002<ooooo`00X_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l0000<ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01OnHV9So8B4Qonk^k_ooooooA4A400?o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A02<ooooo`00X_ooool01Ol0003ooooooooooooooooo0000
01_ooooo00?o0000ooooooooool00_ooool5o`0000Cooooo00?oV9RHob4Q8Oo^k^h01Oooool00onH
V9So8B4Qonk^kP2=ooooo`00X_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l0000<oooo
o`03o`000?oooooooooo00;ooooo00CoA4A4omgMgOoooooo00001_ooool00onHV9So8B4Qonk^kP05
ooooo`03oiRHV?lQ8B7ok^k^08cooooo002Rooooo`05o`000?n7QhOoooooojVYZOl000006oooool0
0ol0003oooooooooo`02ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?oMgMgofIVI_ooool01Ooo
ool00omgMgOoIVIVooooo`2;ooooo`00XOooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooo
oooo01Wooooo00?o0000ooooooooool00oooool00omgMgOoc<c<o`000008ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0R_ooool00<;ooooo00?o0000ooooooooool00oooool00oo^
k^koA4A4o`000004ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Ol0003o^[ZjoooooonH
V9So410@08cooooo0030ooooo`03oeEEEOmVIVKo000000Kooooo00?oMgMgo`000?ooool00oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c02<ooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1428) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.5591 .3771 Mdot
.54997 .36115 Mdot
.35622 .52394 Mdot
.59101 .59814 Mdot
.41548 .78943 Mdot
.32779 .50075 Mdot
.44019 .32623 Mdot
.40841 .34167 Mdot
.3593 .53047 Mdot
.55073 .30199 Mdot
.3926 .37631 Mdot
.68261 .59595 Mdot
.41976 .36836 Mdot
.58468 .55995 Mdot
.75044 .74702 Mdot
.59175 .51141 Mdot
.55911 .37523 Mdot
.44033 .69346 Mdot
.57571 .52546 Mdot
.31215 .5168 Mdot
.62065 .39545 Mdot
.58676 .56424 Mdot
.58722 .38044 Mdot
.58485 .55936 Mdot
.61173 .59362 Mdot
.59684 .37571 Mdot
.59919 .31615 Mdot
.63845 .58427 Mdot
.62663 .54207 Mdot
.39103 .36777 Mdot
.48372 .67 Mdot
.6323 .80511 Mdot
.52802 .5566 Mdot
.64149 .73995 Mdot
.44044 .35266 Mdot
.73656 .49877 Mdot
.34012 .50223 Mdot
.40218 .36102 Mdot
.40036 .37096 Mdot
.41926 .33658 Mdot
.40862 .34791 Mdot
.58409 .36144 Mdot
.52076 .22616 Mdot
.3646 .41577 Mdot
.66132 .57431 Mdot
.2844 .71273 Mdot
.68913 .51166 Mdot
.56328 .56827 Mdot
.61324 .33858 Mdot
.27879 .57845 Mdot
.32082 .38228 Mdot
.44956 .36056 Mdot
.32251 .54167 Mdot
.36018 .14802 Mdot
.42481 .37913 Mdot
.64147 .63328 Mdot
.34494 .51501 Mdot
.60191 .56053 Mdot
.58761 .55484 Mdot
.73747 .37968 Mdot
.62929 .62328 Mdot
.39615 .67895 Mdot
.54008 .3497 Mdot
.45083 .52572 Mdot
.34058 .5273 Mdot
.39739 .37925 Mdot
.56541 .33986 Mdot
.43013 .37297 Mdot
.53129 .52743 Mdot
.38675 .51761 Mdot
.55964 .5766 Mdot
.39364 .37458 Mdot
.6212 .38853 Mdot
.62913 .56208 Mdot
.2486 .56813 Mdot
.25238 .68883 Mdot
.39441 .61654 Mdot
.7334 .46892 Mdot
.73416 .37148 Mdot
.30113 .63064 Mdot
.65233 .57224 Mdot
.47929 .72987 Mdot
.25361 .68093 Mdot
.62207 .33568 Mdot
.55667 .53072 Mdot
.46305 .63653 Mdot
.63068 .56801 Mdot
.35753 .79311 Mdot
.57905 .62276 Mdot
.47979 .56444 Mdot
.37249 .51414 Mdot
.61306 .35741 Mdot
.59694 .60033 Mdot
.61815 .54047 Mdot
.76819 .39417 Mdot
.5545 .56304 Mdot
.59345 .57761 Mdot
.60502 .33036 Mdot
.44759 .36655 Mdot
.61782 .63363 Mdot
.40568 .53214 Mdot
.33918 .47777 Mdot
.62524 .61605 Mdot
.38042 .50184 Mdot
.62451 .38 Mdot
.61792 .54119 Mdot
.40499 .37537 Mdot
.60749 .61684 Mdot
.35113 .26634 Mdot
.56182 .37297 Mdot
.63929 .56332 Mdot
.41103 .6305 Mdot
.68828 .39206 Mdot
.62009 .35438 Mdot
.36897 .40709 Mdot
.5808 .52485 Mdot
.60565 .57505 Mdot
.56942 .33662 Mdot
.34725 .472 Mdot
.33081 .76548 Mdot
.59503 .32617 Mdot
.38992 .39417 Mdot
.63394 .38204 Mdot
.67828 .62055 Mdot
.33606 .53273 Mdot
.36592 .40982 Mdot
.40448 .25537 Mdot
.50858 .68509 Mdot
.6279 .56878 Mdot
.54055 .23653 Mdot
.31726 .49166 Mdot
.60019 .3472 Mdot
.42861 .36948 Mdot
.53334 .57682 Mdot
.56677 .36149 Mdot
.39614 .3934 Mdot
.42262 .66109 Mdot
.30631 .33639 Mdot
.59455 .39215 Mdot
.51907 .43189 Mdot
.44271 .38271 Mdot
.44294 .33799 Mdot
.80313 .60607 Mdot
.58233 .33704 Mdot
.39635 .64508 Mdot
.43178 .36147 Mdot
.54698 .6804 Mdot
.66185 .58418 Mdot
.45824 .72114 Mdot
.45307 .18476 Mdot
.6402 .72546 Mdot
.27385 .40412 Mdot
.41068 .6384 Mdot
.44696 .38581 Mdot
.59556 .58836 Mdot
.6069 .37665 Mdot
.59103 .37774 Mdot
.62925 .62287 Mdot
.61948 .60186 Mdot
.55711 .58693 Mdot
.56994 .54791 Mdot
.50372 .59094 Mdot
.54604 .59628 Mdot
.68445 .49446 Mdot
.61392 .36248 Mdot
.58926 .59322 Mdot
.32995 .54465 Mdot
.66034 .54294 Mdot
.39781 .35754 Mdot
.5955 .56429 Mdot
.59403 .59835 Mdot
.65306 .60607 Mdot
.44889 .35095 Mdot
.59485 .81867 Mdot
.65854 .40626 Mdot
.57114 .8072 Mdot
.52437 .49034 Mdot
.36108 .54881 Mdot
.62983 .57794 Mdot
.39473 .66671 Mdot
.77486 .51065 Mdot
.58031 .60205 Mdot
.11877 .44805 Mdot
.58721 .5735 Mdot
.47833 .81928 Mdot
.61485 .49877 Mdot
.60017 .78103 Mdot
.49098 .71618 Mdot
.61239 .58807 Mdot
.56786 .26956 Mdot
.43719 .31676 Mdot
.38266 .55803 Mdot
.41401 .34915 Mdot
.32607 .54044 Mdot
.35161 .52213 Mdot
.42437 .54983 Mdot
.68618 .58827 Mdot
.64048 .52494 Mdot
.55902 .6026 Mdot
.37932 .47979 Mdot
.56979 .3239 Mdot
.41728 .63293 Mdot
.54252 .36651 Mdot
.53017 .86007 Mdot
.24636 .53678 Mdot
.39776 .34212 Mdot
.42618 .66696 Mdot
.36667 .49098 Mdot
.3717 .52131 Mdot
.41738 .63861 Mdot
.60262 .53932 Mdot
.57947 .33912 Mdot
.74396 .67661 Mdot
.29799 .30015 Mdot
.86243 .42114 Mdot
.61118 .33335 Mdot
.54383 .25614 Mdot
.40019 .34827 Mdot
.351 .49934 Mdot
.60254 .57609 Mdot
.61275 .5483 Mdot
.60974 .40251 Mdot
.55917 .57467 Mdot
.62606 .40915 Mdot
.60922 .58188 Mdot
.46158 .32588 Mdot
.38393 .62184 Mdot
.42416 .55117 Mdot
.54621 .70338 Mdot
.62752 .36516 Mdot
.81557 .47759 Mdot
.37191 .52813 Mdot
.7756 .49904 Mdot
.39946 .38663 Mdot
.41338 .67646 Mdot
.35189 .54485 Mdot
.40627 .62703 Mdot
.54644 .57141 Mdot
.31607 .51658 Mdot
.39176 .63208 Mdot
.47769 .61581 Mdot
.65834 .55363 Mdot
.29054 .27332 Mdot
.42372 .3379 Mdot
.55078 .37467 Mdot
.59838 .61872 Mdot
.37863 .52377 Mdot
.53235 .59743 Mdot
.23945 .47404 Mdot
.35235 .30984 Mdot
.31481 .4931 Mdot
.42252 .5855 Mdot
.40542 .6835 Mdot
.30775 .41804 Mdot
.53691 .24146 Mdot
.54836 .36433 Mdot
.5495 .57465 Mdot
.64749 .78457 Mdot
.43183 .36233 Mdot
.59407 .61465 Mdot
.39512 .74781 Mdot
.44115 .36486 Mdot
.60413 .56076 Mdot
.40385 .40102 Mdot
.59022 .37757 Mdot
.71347 .33822 Mdot
.57367 .33419 Mdot
.55813 .57021 Mdot
.41164 .37943 Mdot
.35401 .46803 Mdot
.59689 .36959 Mdot
.59049 .53983 Mdot
.63603 .58425 Mdot
.44893 .57014 Mdot
.58394 .58656 Mdot
.55787 .82149 Mdot
.61124 .58511 Mdot
.35822 .51026 Mdot
.65325 .58757 Mdot
.65242 .257 Mdot
.42189 .54632 Mdot
.57199 .33781 Mdot
.3115 .49485 Mdot
.3495 .53081 Mdot
.24743 .61744 Mdot
.43427 .4045 Mdot
.61278 .52528 Mdot
.37358 .53426 Mdot
.62092 .68601 Mdot
.4212 .39386 Mdot
.61048 .62581 Mdot
.49164 .41687 Mdot
.27571 .56184 Mdot
.3175 .534 Mdot
.61403 .65888 Mdot
.61032 .3896 Mdot
.60439 .60242 Mdot
.37637 .50739 Mdot
.69216 .60958 Mdot
.63632 .5497 Mdot
.52741 .19886 Mdot
.44272 .58245 Mdot
.443 .37892 Mdot
.66913 .55121 Mdot
.569 .60371 Mdot
.31845 .51536 Mdot
.6238 .37049 Mdot
.42827 .39209 Mdot
.58887 .36484 Mdot
.60477 .77301 Mdot
.3001 .27242 Mdot
.48573 .59059 Mdot
.38741 .62471 Mdot
.36311 .59107 Mdot
.61348 .77622 Mdot
.78667 .37095 Mdot
.79041 .57151 Mdot
.67809 .73185 Mdot
.37452 .48979 Mdot
.3354 .59307 Mdot
.34638 .5245 Mdot
.6337 .59759 Mdot
.33487 .5287 Mdot
.6617 .78074 Mdot
.60545 .58121 Mdot
.33167 .51639 Mdot
.80022 .44198 Mdot
.60174 .59881 Mdot
.54728 .3604 Mdot
.51738 .84703 Mdot
.68416 .25029 Mdot
.37758 .29944 Mdot
.34983 .48817 Mdot
.75151 .64213 Mdot
.59193 .57904 Mdot
.65259 .58784 Mdot
.61592 .37032 Mdot
.52805 .57747 Mdot
.38678 .66634 Mdot
.42328 .67355 Mdot
.38803 .33249 Mdot
.37483 .62092 Mdot
.67184 .55676 Mdot
.59985 .36979 Mdot
.50551 .56866 Mdot
.25509 .60848 Mdot
.28576 .57825 Mdot
.39817 .33498 Mdot
.51667 .84612 Mdot
.5396 .40755 Mdot
.49321 .34854 Mdot
.28313 .48559 Mdot
.60943 .34191 Mdot
.62201 .81237 Mdot
.41091 .35218 Mdot
.25418 .30407 Mdot
.58441 .27744 Mdot
.6041 .54183 Mdot
.41783 .38989 Mdot
.56669 .63639 Mdot
.69816 .26618 Mdot
.21174 .37569 Mdot
.71436 .57866 Mdot
.58589 .62475 Mdot
.25533 .54872 Mdot
.59785 .56916 Mdot
.24624 .50881 Mdot
.61899 .58699 Mdot
.59055 .36121 Mdot
.54983 .30106 Mdot
.36257 .36111 Mdot
.65252 .39267 Mdot
.2994 .43243 Mdot
.40625 .63556 Mdot
.61066 .57962 Mdot
.60112 .54161 Mdot
.38275 .66096 Mdot
.58945 .38569 Mdot
.55649 .5787 Mdot
.81656 .4623 Mdot
.60923 .53506 Mdot
.40105 .35516 Mdot
.63 .27376 Mdot
.62767 .46926 Mdot
.57806 .53435 Mdot
.63413 .34642 Mdot
.41231 .33103 Mdot
.41094 .37653 Mdot
.64088 .51184 Mdot
.38969 .36125 Mdot
.57885 .57616 Mdot
.19923 .40431 Mdot
.58319 .39048 Mdot
.4511 .2033 Mdot
.56877 .35094 Mdot
.72257 .45273 Mdot
.44633 .36248 Mdot
.32595 .32418 Mdot
.58732 .64473 Mdot
.41212 .35589 Mdot
.64651 .32967 Mdot
.63548 .5306 Mdot
.63879 .53073 Mdot
.74432 .66748 Mdot
.36492 .50521 Mdot
.44408 .57032 Mdot
.39069 .36869 Mdot
.57462 .55717 Mdot
.56608 .53816 Mdot
.41262 .33197 Mdot
.23905 .36327 Mdot
.72378 .30779 Mdot
.60919 .58341 Mdot
.59589 .35601 Mdot
.59534 .34674 Mdot
.66613 .59022 Mdot
.62273 .61377 Mdot
.33816 .54194 Mdot
.34232 .46902 Mdot
.35523 .55555 Mdot
.43934 .57441 Mdot
.34208 .31114 Mdot
.36669 .77391 Mdot
.42016 .33655 Mdot
.51465 .26789 Mdot
.47746 .58409 Mdot
.56826 .61707 Mdot
.34747 .48453 Mdot
.56806 .60083 Mdot
.57522 .5885 Mdot
.43048 .41315 Mdot
.43136 .78539 Mdot
.51981 .37351 Mdot
.62664 .37158 Mdot
.45153 .37373 Mdot
.66263 .53696 Mdot
.48216 .38469 Mdot
.40933 .67518 Mdot
.65033 .70978 Mdot
.39639 .38367 Mdot
.54929 .35176 Mdot
.43143 .34271 Mdot
.61554 .54629 Mdot
.58707 .63887 Mdot
.60493 .34111 Mdot
.39054 .68007 Mdot
.531 .56078 Mdot
.60572 .56391 Mdot
.41492 .18475 Mdot
.5969 .70337 Mdot
.46038 .31625 Mdot
.60968 .58674 Mdot
.6085 .52923 Mdot
.39745 .69573 Mdot
.61041 .53653 Mdot
.57001 .6112 Mdot
.68781 .40278 Mdot
.4355 .26827 Mdot
.43028 .6485 Mdot
.2095 .39753 Mdot
.60923 .33304 Mdot
.6326 .79251 Mdot
.3378 .48986 Mdot
.37214 .34691 Mdot
.69849 .29409 Mdot
.32772 .54864 Mdot
.26798 .41244 Mdot
.62121 .7979 Mdot
.40874 .5206 Mdot
.32427 .56404 Mdot
.54807 .33065 Mdot
.56458 .55883 Mdot
.60648 .57188 Mdot
.39213 .66586 Mdot
.57918 .34216 Mdot
.48693 .5018 Mdot
.19389 .59709 Mdot
.58772 .56632 Mdot
.51257 .2002 Mdot
.2078 .45469 Mdot
.27173 .56507 Mdot
.40389 .66183 Mdot
.42124 .67915 Mdot
.61165 .57802 Mdot
.67639 .38967 Mdot
.59788 .37536 Mdot
.58954 .54075 Mdot
.5479 .59951 Mdot
.35962 .49668 Mdot
.56666 .37508 Mdot
.34575 .47234 Mdot
.30976 .37969 Mdot
.55173 .81227 Mdot
.24352 .28986 Mdot
.43395 .37796 Mdot
.22405 .54024 Mdot
.41394 .39946 Mdot
.48609 .73062 Mdot
.31747 .54657 Mdot
.60844 .60766 Mdot
.61916 .37679 Mdot
.57062 .56416 Mdot
.61997 .61251 Mdot
.60084 .5398 Mdot
.57081 .5395 Mdot
.27269 .25203 Mdot
.40671 .63348 Mdot
.54392 .55764 Mdot
.35851 .51572 Mdot
.266 .68858 Mdot
.23059 .6367 Mdot
.59889 .54392 Mdot
.62639 .58492 Mdot
.57504 .37738 Mdot
.61641 .62246 Mdot
.41899 .39808 Mdot
.54374 .35209 Mdot
.62797 .55468 Mdot
.4514 .83724 Mdot
.62931 .54395 Mdot
.59553 .79211 Mdot
.42998 .34334 Mdot
.31112 .28572 Mdot
.57394 .63325 Mdot
.35853 .31003 Mdot
.44424 .57043 Mdot
.34777 .54626 Mdot
.41145 .40533 Mdot
.33822 .50423 Mdot
.1845 .56637 Mdot
.65306 .63895 Mdot
.59942 .59008 Mdot
.56187 .6099 Mdot
.36159 .54866 Mdot
.38859 .81752 Mdot
.32065 .42861 Mdot
.64995 .64326 Mdot
.33194 .54183 Mdot
.60541 .32093 Mdot
.69084 .69511 Mdot
.57702 .35771 Mdot
.37074 .65533 Mdot
.40255 .34776 Mdot
.39091 .67882 Mdot
.5131 .77341 Mdot
.5575 .36937 Mdot
.57879 .40516 Mdot
.33923 .49137 Mdot
.56163 .30171 Mdot
.6479 .17704 Mdot
.58468 .27629 Mdot
.5124 .70707 Mdot
.60792 .37082 Mdot
.62331 .54047 Mdot
.48949 .75287 Mdot
.57136 .28513 Mdot
.33767 .50762 Mdot
.571 .59409 Mdot
.71378 .33241 Mdot
.33878 .54248 Mdot
.5841 .63143 Mdot
.36274 .51421 Mdot
.41826 .34652 Mdot
.35551 .48625 Mdot
.60859 .40871 Mdot
.63628 .57052 Mdot
.67357 .18223 Mdot
.38924 .59892 Mdot
.59368 .58236 Mdot
.45504 .36081 Mdot
.25715 .3793 Mdot
.59492 .60869 Mdot
.38807 .62969 Mdot
.3268 .51959 Mdot
.56797 .30432 Mdot
.61323 .58476 Mdot
.33088 .54163 Mdot
.56629 .38834 Mdot
.45769 .3718 Mdot
.76287 .38914 Mdot
.41062 .2979 Mdot
.61881 .3685 Mdot
.55362 .45653 Mdot
.40792 .41263 Mdot
.60566 .52861 Mdot
.55359 .56368 Mdot
.59399 .35267 Mdot
.41463 .71986 Mdot
.64279 .60723 Mdot
.65258 .58014 Mdot
.35735 .49988 Mdot
.33418 .50433 Mdot
.78302 .57163 Mdot
.35649 .47295 Mdot
.57727 .63294 Mdot
.59151 .35289 Mdot
.59441 .60039 Mdot
.57373 .38016 Mdot
.61576 .62206 Mdot
.62386 .49415 Mdot
.59057 .38575 Mdot
.44878 .39999 Mdot
.57317 .59267 Mdot
.53911 .53311 Mdot
.60322 .61594 Mdot
.56931 .55215 Mdot
.33982 .53992 Mdot
.39988 .66786 Mdot
.55733 .60961 Mdot
.43671 .63375 Mdot
.42055 .63774 Mdot
.36722 .32442 Mdot
.3617 .49881 Mdot
.39383 .64044 Mdot
.1916 .47957 Mdot
.31928 .52865 Mdot
.38894 .66233 Mdot
.23165 .63944 Mdot
.44195 .3528 Mdot
.61161 .39008 Mdot
.60547 .59964 Mdot
.57969 .76576 Mdot
.67587 .49755 Mdot
.30016 .51601 Mdot
.60649 .58434 Mdot
.58954 .61252 Mdot
.59797 .32436 Mdot
.19532 .6369 Mdot
.38609 .52026 Mdot
.62679 .53638 Mdot
.55224 .35912 Mdot
.19839 .67294 Mdot
.35395 .51461 Mdot
.39055 .66778 Mdot
.44114 .34431 Mdot
.58089 .31437 Mdot
.39883 .25377 Mdot
.45184 .34151 Mdot
.37248 .45447 Mdot
.31727 .3748 Mdot
.56094 .53655 Mdot
.33787 .48285 Mdot
.85196 .49846 Mdot
.51282 .60839 Mdot
.44885 .54122 Mdot
.74051 .65242 Mdot
.61536 .34802 Mdot
.41542 .39899 Mdot
.41152 .63786 Mdot
.61824 .33828 Mdot
.561 .3771 Mdot
.41484 .33319 Mdot
.65964 .41804 Mdot
.48884 .41443 Mdot
.39902 .36557 Mdot
.60645 .73028 Mdot
.35622 .73807 Mdot
.34263 .48374 Mdot
.38627 .66477 Mdot
.49177 .78101 Mdot
.58544 .36396 Mdot
.55989 .85182 Mdot
.7541 .66297 Mdot
.59316 .57754 Mdot
.40202 .64033 Mdot
.38841 .80805 Mdot
.21769 .66046 Mdot
.44209 .36675 Mdot
.36827 .33718 Mdot
.39869 .68374 Mdot
.59459 .61759 Mdot
.63606 .69902 Mdot
.64436 .59494 Mdot
.40872 .34339 Mdot
.78137 .42627 Mdot
.55752 .37156 Mdot
.43198 .33357 Mdot
.66545 .70839 Mdot
.57921 .57418 Mdot
.57423 .59543 Mdot
.56585 .72295 Mdot
.62317 .34099 Mdot
.34851 .54658 Mdot
.55128 .5582 Mdot
.60172 .56426 Mdot
.59282 .63836 Mdot
.669 .5957 Mdot
.69964 .37063 Mdot
.63042 .59489 Mdot
.23849 .56484 Mdot
.58952 .62401 Mdot
.57064 .57812 Mdot
.63537 .35392 Mdot
.21592 .31583 Mdot
.31847 .39522 Mdot
.59765 .56483 Mdot
.61573 .53066 Mdot
.43335 .33528 Mdot
.47028 .41039 Mdot
.52541 .33424 Mdot
.56619 .30708 Mdot
.77274 .60908 Mdot
.65778 .55057 Mdot
.5636 .34272 Mdot
.38716 .63441 Mdot
.61153 .52597 Mdot
.55574 .3488 Mdot
.65672 .5979 Mdot
.34049 .54477 Mdot
.32083 .5324 Mdot
.50959 .56126 Mdot
.39276 .6387 Mdot
.61143 .24611 Mdot
.51101 .26727 Mdot
.31816 .52029 Mdot
.60337 .59168 Mdot
.45131 .31926 Mdot
.37536 .51284 Mdot
.40555 .5462 Mdot
.40693 .7375 Mdot
.60776 .37845 Mdot
.61539 .36022 Mdot
.45338 .72358 Mdot
.28667 .38617 Mdot
.52502 .18709 Mdot
.41729 .34541 Mdot
.54198 .57106 Mdot
.56336 .25612 Mdot
.61853 .35983 Mdot
.49293 .74157 Mdot
.39974 .63832 Mdot
.44094 .36338 Mdot
.32765 .44467 Mdot
.57097 .36667 Mdot
.57828 .39703 Mdot
.63263 .6248 Mdot
.6085 .55601 Mdot
.79643 .55502 Mdot
.44029 .64159 Mdot
.44298 .32799 Mdot
.38825 .66797 Mdot
.31483 .54212 Mdot
.644 .58433 Mdot
.59053 .38357 Mdot
.349 .74333 Mdot
.59297 .52356 Mdot
.3544 .53733 Mdot
.61512 .35181 Mdot
.40703 .68399 Mdot
.3835 .63381 Mdot
.57421 .54327 Mdot
.79767 .51155 Mdot
.40522 .36081 Mdot
.59775 .33536 Mdot
.49696 .36088 Mdot
.64219 .60105 Mdot
.61407 .5627 Mdot
.57859 .49755 Mdot
.44418 .32903 Mdot
.48307 .31223 Mdot
.39615 .62391 Mdot
.58625 .34109 Mdot
.62901 .59187 Mdot
.38561 .65499 Mdot
.52611 .26778 Mdot
.30669 .51039 Mdot
.3593 .48755 Mdot
.38094 .63911 Mdot
.40813 .6536 Mdot
.39645 .62574 Mdot
.56249 .85218 Mdot
.57352 .32737 Mdot
.54195 .41174 Mdot
.64047 .54175 Mdot
.49789 .71138 Mdot
.54119 .56023 Mdot
.43776 .38746 Mdot
.36617 .50885 Mdot
.60611 .61199 Mdot
.58351 .53242 Mdot
.60881 .49542 Mdot
.47841 .19655 Mdot
.60326 .45961 Mdot
.56521 .37693 Mdot
.58598 .63913 Mdot
.34913 .48943 Mdot
.55479 .8674 Mdot
.77196 .66293 Mdot
.57811 .63592 Mdot
.493 .40943 Mdot
.59839 .38572 Mdot
.42005 .33575 Mdot
.55541 .74555 Mdot
.44061 .34892 Mdot
.59225 .34171 Mdot
.6353 .59352 Mdot
.50494 .28458 Mdot
.40207 .6987 Mdot
.57205 .55663 Mdot
.41815 .34169 Mdot
.56037 .57634 Mdot
.44619 .33201 Mdot
.57319 .77543 Mdot
.83871 .50065 Mdot
.58832 .5738 Mdot
.57439 .52153 Mdot
.81071 .53718 Mdot
.59303 .54487 Mdot
.42256 .70159 Mdot
.59915 .38592 Mdot
.78633 .42655 Mdot
.61824 .5143 Mdot
.67289 .67114 Mdot
.64675 .59532 Mdot
.77175 .38795 Mdot
.61474 .55937 Mdot
.26782 .56423 Mdot
.63949 .56732 Mdot
.56604 .6088 Mdot
.42253 .38159 Mdot
.43441 .33416 Mdot
.63106 .37718 Mdot
.38063 .51202 Mdot
.58674 .79966 Mdot
.60913 .56418 Mdot
.33368 .32723 Mdot
.44893 .28249 Mdot
.40731 .65671 Mdot
.5874 .34322 Mdot
.22979 .70594 Mdot
.38958 .38404 Mdot
.79506 .60663 Mdot
.76572 .6032 Mdot
.4458 .24583 Mdot
.43847 .77483 Mdot
.2354 .41138 Mdot
.40872 .68064 Mdot
.65117 .60771 Mdot
.34334 .67716 Mdot
.26419 .56329 Mdot
.40132 .72611 Mdot
.41101 .40805 Mdot
.78103 .52628 Mdot
.39764 .76158 Mdot
.37395 .6532 Mdot
.41234 .68646 Mdot
.45076 .3535 Mdot
.33286 .57263 Mdot
.68505 .59664 Mdot
.40827 .64239 Mdot
.36204 .55006 Mdot
.31495 .52369 Mdot
.36848 .54857 Mdot
.5957 .37756 Mdot
.77367 .65179 Mdot
.39303 .40967 Mdot
.43917 .38311 Mdot
.33346 .57836 Mdot
.70482 .63182 Mdot
.54762 .38214 Mdot
.34514 .49697 Mdot
.35816 .47907 Mdot
.60057 .38786 Mdot
.64508 .62841 Mdot
.66545 .62153 Mdot
.59225 .56554 Mdot
.39626 .66617 Mdot
.61227 .55329 Mdot
.33007 .53784 Mdot
.43669 .37311 Mdot
.36389 .48501 Mdot
.45615 .35341 Mdot
.33897 .74797 Mdot
.58772 .53752 Mdot
.63818 .57224 Mdot
.36766 .20733 Mdot
.59867 .40008 Mdot
.28366 .70461 Mdot
.4733 .36854 Mdot
.34819 .52339 Mdot
.57111 .61146 Mdot
.53927 .36116 Mdot
.43658 .66873 Mdot
.24677 .29304 Mdot
.62978 .61371 Mdot
.58137 .37164 Mdot
.64164 .58597 Mdot
.51523 .63095 Mdot
.59405 .20674 Mdot
.58558 .35647 Mdot
.49191 .18644 Mdot
.62389 .53732 Mdot
.20322 .49209 Mdot
.59953 .62501 Mdot
.48848 .62492 Mdot
.64269 .60722 Mdot
.60858 .33238 Mdot
.59442 .56199 Mdot
.54081 .35871 Mdot
.31866 .50431 Mdot
.42958 .33671 Mdot
.61768 .36723 Mdot
.56147 .55087 Mdot
.56316 .08224 Mdot
.42654 .34966 Mdot
.60635 .57767 Mdot
.4478 .35286 Mdot
.57353 .34356 Mdot
.61646 .34164 Mdot
.21496 .63344 Mdot
.3076 .38296 Mdot
.41919 .34797 Mdot
.64339 .58468 Mdot
.22097 .50053 Mdot
.6174 .60497 Mdot
.62786 .68863 Mdot
.63919 .63443 Mdot
.6556 .57443 Mdot
.23735 .66029 Mdot
.44442 .37763 Mdot
.52352 .18497 Mdot
.23005 .66551 Mdot
.26332 .6858 Mdot
.62074 .39635 Mdot
.37517 .65563 Mdot
.61233 .81477 Mdot
.34494 .30904 Mdot
.33852 .54734 Mdot
.60104 .61221 Mdot
.65525 .35636 Mdot
.40406 .36657 Mdot
.40777 .67294 Mdot
.58957 .57392 Mdot
.35406 .48043 Mdot
.76305 .34589 Mdot
.44818 .38298 Mdot
.58194 .35738 Mdot
.60853 .32378 Mdot
.16389 .46808 Mdot
.61656 .58898 Mdot
.63471 .5653 Mdot
.40289 .34707 Mdot
.24414 .38028 Mdot
.42623 .65435 Mdot
.79885 .43614 Mdot
.42035 .34981 Mdot
.48102 .47573 Mdot
.55498 .34699 Mdot
.58443 .61194 Mdot
.45682 .82653 Mdot
.30371 .45364 Mdot
.39985 .20222 Mdot
.39445 .66509 Mdot
.61925 .68807 Mdot
.60721 .33232 Mdot
.42957 .36645 Mdot
.28624 .36174 Mdot
.64789 .53668 Mdot
.5649 .59318 Mdot
.54487 .66674 Mdot
.36249 .34416 Mdot
.52684 .34733 Mdot
.63279 .61054 Mdot
.44262 .56763 Mdot
.62348 .61727 Mdot
.58408 .50875 Mdot
.63247 .64161 Mdot
.62279 .56805 Mdot
.586 .37996 Mdot
.62728 .67002 Mdot
.36276 .54373 Mdot
.53156 .38901 Mdot
.47254 .48326 Mdot
.59975 .58225 Mdot
.65027 .57345 Mdot
.7073 .55162 Mdot
.2508 .43054 Mdot
.61551 .36685 Mdot
.58963 .40879 Mdot
.38811 .37504 Mdot
.65945 .62251 Mdot
.38019 .50941 Mdot
.53555 .56003 Mdot
.34339 .53943 Mdot
.58887 .38163 Mdot
.35007 .51984 Mdot
.44283 .34192 Mdot
.33205 .48515 Mdot
.33817 .31388 Mdot
.43368 .35648 Mdot
.61309 .3756 Mdot
.62639 .55727 Mdot
.4553 .36174 Mdot
.52561 .68736 Mdot
.39533 .66378 Mdot
.30683 .77701 Mdot
.62836 .55434 Mdot
.41855 .2627 Mdot
.69208 .56822 Mdot
.36121 .48166 Mdot
.57792 .19829 Mdot
.62173 .37801 Mdot
.43114 .66014 Mdot
.62879 .34894 Mdot
.6546 .70466 Mdot
.40118 .65229 Mdot
.28388 .74168 Mdot
.45376 .59358 Mdot
.59907 .70112 Mdot
.66041 .61528 Mdot
.56899 .71117 Mdot
.31461 .53411 Mdot
.40545 .36845 Mdot
.27945 .38005 Mdot
.56603 .60674 Mdot
.80978 .38729 Mdot
.63176 .34686 Mdot
.37826 .52172 Mdot
.42802 .37188 Mdot
.43218 .39096 Mdot
.62813 .53135 Mdot
.30183 .60595 Mdot
.56303 .59329 Mdot
.29771 .37046 Mdot
.75052 .63948 Mdot
.5638 .42395 Mdot
.60883 .58152 Mdot
.31822 .51377 Mdot
.6415 .58623 Mdot
.39514 .62279 Mdot
.81806 .58348 Mdot
.53508 .54432 Mdot
.47583 .342 Mdot
.44335 .65514 Mdot
.58367 .33456 Mdot
.66166 .51825 Mdot
.45005 .30947 Mdot
.61899 .59091 Mdot
.23454 .26231 Mdot
.38747 .65866 Mdot
.34313 .66805 Mdot
.5804 .52931 Mdot
.60789 .52369 Mdot
.43872 .51628 Mdot
.3986 .24745 Mdot
.26217 .5091 Mdot
.58631 .55163 Mdot
.5093 .66364 Mdot
.45032 .36655 Mdot
.60415 .61867 Mdot
.6075 .57378 Mdot
.66836 .4554 Mdot
.4427 .38633 Mdot
.35554 .52861 Mdot
.32782 .54969 Mdot
.30169 .50654 Mdot
.4082 .62379 Mdot
.51639 .33791 Mdot
.50781 .72861 Mdot
.71905 .28997 Mdot
.42143 .68384 Mdot
.58869 .53133 Mdot
.37149 .59993 Mdot
.64025 .59312 Mdot
.41028 .66794 Mdot
.44401 .38556 Mdot
.62075 .36173 Mdot
.55526 .2615 Mdot
.32672 .5451 Mdot
.64585 .53175 Mdot
.42691 .64746 Mdot
.60631 .37715 Mdot
.52219 .76152 Mdot
.58326 .33552 Mdot
.41586 .3565 Mdot
.51854 .33278 Mdot
.41095 .67109 Mdot
.56727 .34655 Mdot
.48707 .35371 Mdot
.20841 .63897 Mdot
.64288 .64107 Mdot
.5277 .30141 Mdot
.58471 .33142 Mdot
.57809 .40761 Mdot
.57166 .33178 Mdot
.562 .5683 Mdot
.49348 .41076 Mdot
.66002 .5777 Mdot
.44708 .37409 Mdot
.362 .51797 Mdot
.82812 .47173 Mdot
.35094 .40729 Mdot
.54264 .43615 Mdot
.54363 .59914 Mdot
.57877 .57302 Mdot
.61119 .57783 Mdot
.59397 .50866 Mdot
.34186 .30488 Mdot
.56507 .57521 Mdot
.42158 .38204 Mdot
.32743 .52613 Mdot
.65292 .60566 Mdot
.34827 .45808 Mdot
.25209 .6615 Mdot
.39338 .68441 Mdot
.4036 .32059 Mdot
.80802 .62567 Mdot
.60832 .37514 Mdot
.31456 .49119 Mdot
.32372 .52925 Mdot
.42093 .66702 Mdot
.40262 .35806 Mdot
.57988 .33605 Mdot
.61221 .68521 Mdot
.41957 .63678 Mdot
.59732 .56254 Mdot
.50083 .39522 Mdot
.82766 .41923 Mdot
.64528 .61302 Mdot
.59396 .60498 Mdot
.37062 .54855 Mdot
.34698 .66281 Mdot
.76444 .27248 Mdot
.52918 .73392 Mdot
.40343 .67119 Mdot
.37924 .66708 Mdot
.5964 .39073 Mdot
.62958 .52336 Mdot
.45284 .35143 Mdot
.60802 .28196 Mdot
.48366 .32575 Mdot
.57227 .22941 Mdot
.37511 .22033 Mdot
.61729 .61581 Mdot
.22975 .38263 Mdot
.57685 .57849 Mdot
.57577 .32673 Mdot
.58764 .3767 Mdot
.60015 .36407 Mdot
.40589 .36746 Mdot
.74846 .49963 Mdot
.41121 .3805 Mdot
.85565 .54632 Mdot
.60814 .33555 Mdot
.44982 .59433 Mdot
.34889 .49347 Mdot
.65465 .64091 Mdot
.40116 .6836 Mdot
.52733 .31156 Mdot
.53196 .52607 Mdot
.67046 .37668 Mdot
.37435 .53131 Mdot
.61685 .37303 Mdot
.2417 .39058 Mdot
.70173 .73272 Mdot
.54268 .31899 Mdot
.58418 .49061 Mdot
.55556 .74699 Mdot
.40783 .66094 Mdot
.39699 .20366 Mdot
.39247 .67723 Mdot
.41951 .34164 Mdot
.63678 .57852 Mdot
.63038 .56861 Mdot
.624 .61783 Mdot
.59402 .53905 Mdot
.40471 .41465 Mdot
.54749 .58589 Mdot
.65274 .25751 Mdot
.32982 .54718 Mdot
.47229 .64087 Mdot
.39157 .67342 Mdot
.4265 .40134 Mdot
.32741 .52792 Mdot
.25588 .42285 Mdot
.54124 .70289 Mdot
.61153 .58386 Mdot
.60501 .61228 Mdot
.8086 .57411 Mdot
.63311 .60972 Mdot
.6778 .62838 Mdot
.33441 .54471 Mdot
.62896 .48088 Mdot
.39397 .68406 Mdot
.38302 .6778 Mdot
.43568 .35628 Mdot
.58604 .37841 Mdot
.38985 .65141 Mdot
.35317 .49544 Mdot
.54475 .60157 Mdot
.54912 .57268 Mdot
.5885 .33126 Mdot
.81563 .57199 Mdot
.38543 .6265 Mdot
.21758 .49503 Mdot
.61336 .37959 Mdot
.64026 .35678 Mdot
.56547 .59483 Mdot
.42675 .19669 Mdot
.62741 .39681 Mdot
.43229 .6434 Mdot
.42274 .404 Mdot
.56936 .7379 Mdot
.39404 .38934 Mdot
.57972 .35729 Mdot
.63343 .5445 Mdot
.59686 .38144 Mdot
.61218 .58686 Mdot
.72571 .73479 Mdot
.62539 .56571 Mdot
.70691 .27883 Mdot
.45122 .7154 Mdot
.32779 .49811 Mdot
.24644 .42535 Mdot
.33794 .49019 Mdot
.62539 .36709 Mdot
.58608 .52362 Mdot
.42106 .6742 Mdot
.22742 .59999 Mdot
.6446 .30315 Mdot
.37274 .51557 Mdot
.38379 .49505 Mdot
.39723 .3964 Mdot
.64381 .60802 Mdot
.56386 .58742 Mdot
.33183 .51307 Mdot
.6055 .42115 Mdot
.56798 .35965 Mdot
.63031 .5859 Mdot
.5761 .57202 Mdot
.33103 .49497 Mdot
.19911 .62366 Mdot
.57844 .65882 Mdot
.63112 .57782 Mdot
.27106 .48385 Mdot
.43625 .38765 Mdot
.6557 .63892 Mdot
.56763 .52632 Mdot
.40948 .65095 Mdot
.72207 .37367 Mdot
.71181 .69793 Mdot
.44454 .38592 Mdot
.3256 .53706 Mdot
.62244 .59059 Mdot
.31851 .51696 Mdot
.54717 .58141 Mdot
.40897 .2447 Mdot
.31289 .49682 Mdot
.65277 .5729 Mdot
.64859 .62354 Mdot
.62091 .33791 Mdot
.61172 .61447 Mdot
.729 .57057 Mdot
.36151 .5368 Mdot
.62792 .53241 Mdot
.80021 .48022 Mdot
.39664 .37184 Mdot
.66847 .60127 Mdot
.41444 .63465 Mdot
.64821 .68805 Mdot
.49185 .27146 Mdot
.45418 .79228 Mdot
.38557 .68355 Mdot
.56146 .57498 Mdot
.38419 .50438 Mdot
.4408 .32739 Mdot
.68397 .25305 Mdot
.58984 .61627 Mdot
.41319 .34242 Mdot
.43708 .37203 Mdot
.4068 .67552 Mdot
.19837 .33681 Mdot
.57828 .53257 Mdot
.60147 .54458 Mdot
.71666 .4974 Mdot
.57776 .39925 Mdot
.61889 .55665 Mdot
.61646 .53713 Mdot
.42623 .38227 Mdot
.67949 .57561 Mdot
.76124 .57943 Mdot
.78675 .40892 Mdot
.41332 .32938 Mdot
.58903 .25503 Mdot
.31045 .50762 Mdot
.38248 .65406 Mdot
.60704 .34485 Mdot
.42741 .65484 Mdot
.35748 .4911 Mdot
.61955 .5411 Mdot
.40891 .33967 Mdot
.71764 .54863 Mdot
.45059 .35142 Mdot
.39894 .7537 Mdot
.54447 .36138 Mdot
.37878 .39715 Mdot
.21567 .28823 Mdot
.27389 .45342 Mdot
.35906 .33826 Mdot
.40733 .65613 Mdot
.39812 .53794 Mdot
.57601 .57341 Mdot
.38412 .20702 Mdot
.59111 .53175 Mdot
.79318 .45683 Mdot
.33573 .54916 Mdot
.35829 .55476 Mdot
.63415 .5793 Mdot
.74217 .64574 Mdot
.43771 .32541 Mdot
.41961 .39336 Mdot
.64702 .55811 Mdot
.41238 .35524 Mdot
.60521 .55289 Mdot
.3329 .53819 Mdot
.43643 .17247 Mdot
.5924 .56971 Mdot
.55605 .52478 Mdot
.42315 .24948 Mdot
.23903 .67005 Mdot
.42778 .61163 Mdot
.15935 .52884 Mdot
.73231 .71387 Mdot
.41201 .3571 Mdot
.65317 .56019 Mdot
.58586 .25043 Mdot
.38291 .53005 Mdot
.49043 .34726 Mdot
.61908 .54617 Mdot
.60442 .53341 Mdot
.56958 .61338 Mdot
.57869 .59811 Mdot
.28236 .27148 Mdot
.6368 .29349 Mdot
.72819 .42392 Mdot
.61803 .6135 Mdot
.55284 .69694 Mdot
.4314 .34597 Mdot
.63085 .32352 Mdot
.43226 .66524 Mdot
.61535 .61561 Mdot
.53059 .35891 Mdot
.40057 .34201 Mdot
.8648 .52472 Mdot
.41155 .34102 Mdot
.34844 .53057 Mdot
.44053 .33457 Mdot
.58506 .58603 Mdot
.5956 .34711 Mdot
.42521 .46159 Mdot
.31206 .41538 Mdot
.34439 .55033 Mdot
.59435 .58243 Mdot
.43653 .59668 Mdot
.3661 .54163 Mdot
.27564 .70307 Mdot
.60502 .34942 Mdot
.50007 .65963 Mdot
.59255 .38081 Mdot
.6409 .54925 Mdot
.64046 .54978 Mdot
.38524 .36631 Mdot
.44159 .33908 Mdot
.59083 .38034 Mdot
.1548 .39248 Mdot
.3918 .62549 Mdot
.59672 .36358 Mdot
.62972 .5161 Mdot
.47008 .43053 Mdot
.59778 .35097 Mdot
.40429 .70579 Mdot
.43335 .37717 Mdot
.60145 .39609 Mdot
.58926 .62633 Mdot
.61186 .72678 Mdot
.38122 .64192 Mdot
.32503 .55348 Mdot
.4962 .7566 Mdot
.37059 .52579 Mdot
.41305 .40578 Mdot
.33513 .49068 Mdot
.44011 .37973 Mdot
.47831 .28511 Mdot
.54283 .40169 Mdot
.41335 .52108 Mdot
.40249 .4087 Mdot
.33948 .49167 Mdot
.63903 .58161 Mdot
.39258 .5996 Mdot
.61587 .51814 Mdot
.55594 .56951 Mdot
.42506 .38855 Mdot
.62035 .34096 Mdot
.61335 .4033 Mdot
.60239 .69577 Mdot
.5808 .37794 Mdot
.35809 .53491 Mdot
.679 .33935 Mdot
.33651 .34412 Mdot
.39593 .38818 Mdot
.43292 .33669 Mdot
.63823 .59923 Mdot
.33813 .50511 Mdot
.34883 .55274 Mdot
.39293 .38933 Mdot
.45955 .20615 Mdot
.57623 .51783 Mdot
.58183 .41016 Mdot
.58178 .39912 Mdot
.58778 .35473 Mdot
.56224 .33596 Mdot
.67532 .66459 Mdot
.44301 .35892 Mdot
.62552 .34848 Mdot
.63833 .60045 Mdot
.61248 .53824 Mdot
.59989 .27529 Mdot
.38624 .63909 Mdot
.65858 .5978 Mdot
.63549 .64012 Mdot
.5821 .61086 Mdot
.35244 .48397 Mdot
.65954 .65439 Mdot
.33438 .48069 Mdot
.38388 .51774 Mdot
.38367 .52331 Mdot
.34885 .30706 Mdot
.78692 .60712 Mdot
.65004 .75335 Mdot
.62225 .53226 Mdot
.21382 .42325 Mdot
.34774 .50795 Mdot
.66832 .30299 Mdot
.47601 .30863 Mdot
.57284 .61176 Mdot
.2468 .58059 Mdot
.33121 .50812 Mdot
.60716 .38568 Mdot
.6227 .55435 Mdot
.3117 .489 Mdot
.40691 .63046 Mdot
.6262 .52745 Mdot
.30664 .51466 Mdot
.56736 .34441 Mdot
.42308 .62769 Mdot
.60908 .39657 Mdot
.38419 .52277 Mdot
.65931 .5341 Mdot
.56351 .15521 Mdot
.31646 .47788 Mdot
.19569 .52419 Mdot
.55036 .48889 Mdot
.63444 .58529 Mdot
.33062 .47728 Mdot
.6428 .36217 Mdot
.4143 .40504 Mdot
.50826 .49087 Mdot
.57886 .39065 Mdot
.35844 .55473 Mdot
.37547 .50005 Mdot
.34413 .55035 Mdot
.56651 .38176 Mdot
.66685 .576 Mdot
.57048 .37629 Mdot
.44121 .33323 Mdot
.60794 .60221 Mdot
.60716 .77577 Mdot
.25271 .36746 Mdot
.60863 .38219 Mdot
.36481 .52168 Mdot
.39885 .69702 Mdot
.58215 .57631 Mdot
.23633 .38483 Mdot
.63961 .58419 Mdot
.43566 .38535 Mdot
.69566 .39493 Mdot
.63684 .48016 Mdot
.65511 .56899 Mdot
.63314 .60154 Mdot
.41726 .39296 Mdot
.59396 .57867 Mdot
.64296 .60745 Mdot
.33785 .31304 Mdot
.56449 .37011 Mdot
.59022 .56281 Mdot
.36154 .5108 Mdot
.32431 .37091 Mdot
.56715 .52024 Mdot
.40564 .50216 Mdot
.49888 .65229 Mdot
.68333 .41273 Mdot
.59346 .53133 Mdot
.51123 .39557 Mdot
.5704 .59518 Mdot
.57747 .54914 Mdot
.63253 .5986 Mdot
.23329 .3303 Mdot
.30735 .51131 Mdot
.32144 .51845 Mdot
.3781 .65935 Mdot
.49804 .65277 Mdot
.40642 .64287 Mdot
.4385 .37395 Mdot
.3139 .62031 Mdot
.33131 .48165 Mdot
.57382 .35264 Mdot
.5692 .56215 Mdot
.31944 .47569 Mdot
.57795 .61066 Mdot
.58714 .58675 Mdot
.38039 .50215 Mdot
.30885 .51491 Mdot
.37666 .73703 Mdot
.39144 .63284 Mdot
.60507 .36644 Mdot
.65428 .59692 Mdot
.42381 .64136 Mdot
.58943 .52983 Mdot
.49678 .71301 Mdot
.60257 .36288 Mdot
.56629 .37098 Mdot
.61669 .40263 Mdot
.62316 .54574 Mdot
.58375 .58177 Mdot
.41143 .38146 Mdot
.62335 .37376 Mdot
.39651 .36687 Mdot
.48444 .51206 Mdot
.28892 .68267 Mdot
.61882 .54566 Mdot
.54358 .30403 Mdot
.40526 .63637 Mdot
.37268 .51206 Mdot
.83443 .4366 Mdot
.37802 .65874 Mdot
.61597 .58704 Mdot
.38032 .52174 Mdot
.41658 .66128 Mdot
.50946 .634 Mdot
.84068 .55757 Mdot
.40064 .69484 Mdot
.63765 .60094 Mdot
.67775 .56648 Mdot
.15808 .51211 Mdot
.39125 .68895 Mdot
.43952 .34462 Mdot
.62448 .54778 Mdot
.56525 .40167 Mdot
.42765 .64897 Mdot
.2473 .5246 Mdot
.32721 .51595 Mdot
.62288 .71992 Mdot
.53831 .52979 Mdot
.65773 .37349 Mdot
.37985 .66249 Mdot
.58807 .33824 Mdot
.68568 .62157 Mdot
.5669 .59606 Mdot
.38886 .68831 Mdot
.43734 .40341 Mdot
.33375 .53014 Mdot
.31345 .39186 Mdot
.56791 .38455 Mdot
.43863 .40675 Mdot
.36942 .51077 Mdot
.21759 .5036 Mdot
.7468 .34773 Mdot
.66557 .62384 Mdot
.18117 .45757 Mdot
.40792 .28443 Mdot
.61438 .62445 Mdot
.4301 .67967 Mdot
.45574 .36478 Mdot
.39392 .35235 Mdot
.41919 .35482 Mdot
.4647 .28752 Mdot
.56223 .30904 Mdot
.30493 .51567 Mdot
.48604 .38154 Mdot
.38325 .65106 Mdot
.57323 .73093 Mdot
.55412 .57055 Mdot
.58165 .57094 Mdot
.65029 .59707 Mdot
.61415 .61696 Mdot
.56779 .58063 Mdot
.40619 .35183 Mdot
.46255 .2755 Mdot
.56871 .30085 Mdot
.59973 .35651 Mdot
.34978 .63926 Mdot
.35348 .49943 Mdot
.33162 .56282 Mdot
.41933 .64945 Mdot
.25691 .48126 Mdot
.34614 .45841 Mdot
.35016 .52191 Mdot
.64841 .6166 Mdot
.56998 .36637 Mdot
.66048 .63942 Mdot
.63525 .60136 Mdot
.35136 .53788 Mdot
.45068 .51515 Mdot
.74333 .59594 Mdot
.38462 .72568 Mdot
.41151 .61772 Mdot
.49617 .38569 Mdot
.37921 .67349 Mdot
.55652 .54276 Mdot
.59824 .21178 Mdot
.35632 .48983 Mdot
.34005 .52086 Mdot
.39092 .6365 Mdot
.42886 .19371 Mdot
.61266 .34612 Mdot
.39806 .423 Mdot
.44842 .36316 Mdot
.63675 .54785 Mdot
.77963 .36544 Mdot
.55414 .48217 Mdot
.29296 .6062 Mdot
.42307 .35055 Mdot
.31993 .50048 Mdot
.54892 .54874 Mdot
.62573 .60655 Mdot
.41098 .63975 Mdot
.43018 .79342 Mdot
.62851 .64576 Mdot
.37928 .82033 Mdot
.83925 .49973 Mdot
.70023 .69678 Mdot
.56452 .59154 Mdot
.56552 .37404 Mdot
.3219 .54615 Mdot
.38538 .66374 Mdot
.64783 .53512 Mdot
.74149 .68436 Mdot
.59257 .33231 Mdot
.4309 .35834 Mdot
.45941 .47744 Mdot
.55547 .73802 Mdot
.56428 .55875 Mdot
.61024 .5351 Mdot
.57448 .54907 Mdot
.86156 .38788 Mdot
.3408 .48098 Mdot
.60484 .38463 Mdot
.40945 .67422 Mdot
.57874 .37033 Mdot
.32347 .50116 Mdot
.41989 .53883 Mdot
.64135 .57301 Mdot
.57664 .33305 Mdot
.59102 .3386 Mdot
.39477 .35497 Mdot
.44014 .39321 Mdot
.47266 .49005 Mdot
.62389 .56538 Mdot
.36541 .47262 Mdot
.62405 .34367 Mdot
.50392 .38566 Mdot
.40241 .65056 Mdot
.43266 .37874 Mdot
.61347 .61373 Mdot
.33078 .48353 Mdot
.62146 .63672 Mdot
.61576 .36265 Mdot
.3497 .52103 Mdot
.34349 .73758 Mdot
.3906 .68395 Mdot
.60913 .53983 Mdot
.45315 .67066 Mdot
.32786 .53973 Mdot
.57348 .57675 Mdot
.21178 .54082 Mdot
.40119 .70484 Mdot
.31951 .43189 Mdot
.37407 .53694 Mdot
.36585 .3043 Mdot
.59338 .3913 Mdot
.38046 .27011 Mdot
.34266 .52714 Mdot
.21441 .47662 Mdot
.36567 .74834 Mdot
.54155 .59357 Mdot
.58669 .36403 Mdot
.38121 .28247 Mdot
.65624 .79258 Mdot
.18709 .5448 Mdot
.60667 .57686 Mdot
.35767 .47361 Mdot
.4164 .65142 Mdot
.39855 .38916 Mdot
.35434 .42925 Mdot
.36428 .64546 Mdot
.37973 .47201 Mdot
.63199 .5984 Mdot
.57773 .33963 Mdot
.41811 .37712 Mdot
.49266 .27601 Mdot
.35745 .50099 Mdot
.36423 .517 Mdot
.59646 .5205 Mdot
.39851 .63799 Mdot
.29099 .31144 Mdot
.33503 .54239 Mdot
.81823 .54293 Mdot
.32898 .56544 Mdot
.41558 .63198 Mdot
.58049 .60308 Mdot
.6304 .69964 Mdot
.63628 .53009 Mdot
.21284 .58738 Mdot
.3493 .49595 Mdot
.60998 .36398 Mdot
.55696 .58447 Mdot
.8102 .48499 Mdot
.35942 .53324 Mdot
.49155 .40379 Mdot
.27842 .5543 Mdot
.44431 .36429 Mdot
.83225 .4327 Mdot
.61293 .55054 Mdot
.44094 .32767 Mdot
.41196 .64237 Mdot
.62746 .57359 Mdot
.58196 .58412 Mdot
.60041 .32524 Mdot
.39248 .36313 Mdot
.3733 .73611 Mdot
.42881 .33411 Mdot
.42975 .3422 Mdot
.53764 .36653 Mdot
.59356 .55346 Mdot
.3506 .53066 Mdot
.33234 .50855 Mdot
.59467 .62753 Mdot
.39592 .16842 Mdot
.60828 .34106 Mdot
.33209 .5556 Mdot
.84844 .36094 Mdot
.61576 .6275 Mdot
.82289 .42853 Mdot
.41312 .78421 Mdot
.45288 .36276 Mdot
.63846 .60103 Mdot
.57025 .34438 Mdot
.26325 .51779 Mdot
.36303 .52041 Mdot
.57781 .62271 Mdot
.41759 .37542 Mdot
.39227 .63059 Mdot
.35919 .54259 Mdot
.30085 .6074 Mdot
.58904 .53824 Mdot
.24894 .60143 Mdot
.36803 .48259 Mdot
.58776 .82085 Mdot
.26337 .40386 Mdot
.5892 .36585 Mdot
.58786 .58942 Mdot
.618 .38092 Mdot
.41452 .67144 Mdot
.46147 .47888 Mdot
.42811 .37721 Mdot
.70245 .63267 Mdot
.62454 .22214 Mdot
.34381 .55035 Mdot
.61123 .38309 Mdot
.64824 .55512 Mdot
.40692 .23993 Mdot
.60794 .54949 Mdot
.63877 .50747 Mdot
.38299 .73183 Mdot
.41002 .38919 Mdot
.45077 .36365 Mdot
.5756 .59053 Mdot
.42362 .66366 Mdot
.35411 .49754 Mdot
.34057 .53541 Mdot
.52145 .85538 Mdot
.39194 .42304 Mdot
.79325 .56154 Mdot
.60336 .53362 Mdot
.38289 .4788 Mdot
.34881 .38322 Mdot
.40514 .34561 Mdot
.67038 .58659 Mdot
.37947 .51348 Mdot
.46854 .63455 Mdot
.53111 .65641 Mdot
.56796 .59447 Mdot
.62917 .52001 Mdot
.44811 .35223 Mdot
.53538 .33575 Mdot
.3161 .51626 Mdot
.61301 .64098 Mdot
.41878 .51147 Mdot
.50509 .63186 Mdot
.84624 .5112 Mdot
.60485 .36662 Mdot
.29702 .5895 Mdot
.4051 .35261 Mdot
.55211 .5272 Mdot
.40309 .68117 Mdot
.39107 .50075 Mdot
.32007 .48938 Mdot
.62166 .5942 Mdot
.54773 .56171 Mdot
.82734 .5047 Mdot
.57283 .35982 Mdot
.43484 .35041 Mdot
.63286 .56463 Mdot
.55419 .2772 Mdot
.62683 .61691 Mdot
.40565 .38011 Mdot
.54463 .15162 Mdot
.62653 .52343 Mdot
.60373 .54672 Mdot
.28834 .3167 Mdot
.5784 .39308 Mdot
.63072 .35503 Mdot
.79206 .36502 Mdot
.60391 .53395 Mdot
.83789 .48234 Mdot
.60959 .3696 Mdot
.61677 .35077 Mdot
.30947 .35096 Mdot
.58351 .57327 Mdot
.53915 .62986 Mdot
.44422 .37717 Mdot
.43075 .34143 Mdot
.56958 .38078 Mdot
.64726 .64217 Mdot
.43553 .39369 Mdot
.27006 .30316 Mdot
.33915 .5035 Mdot
.53935 .18264 Mdot
.60643 .33858 Mdot
.38423 .31568 Mdot
.41669 .344 Mdot
.83665 .57934 Mdot
.30994 .45661 Mdot
.6399 .5777 Mdot
.59998 .53467 Mdot
.38848 .63999 Mdot
.65595 .5878 Mdot
.35752 .55502 Mdot
.41263 .35449 Mdot
.73571 .63462 Mdot
.59982 .36446 Mdot
.61594 .56147 Mdot
.23151 .56958 Mdot
.30924 .73841 Mdot
.30878 .58292 Mdot
.58854 .33499 Mdot
.59289 .37575 Mdot
.3303 .48768 Mdot
.36174 .4758 Mdot
.57937 .56022 Mdot
.41498 .39585 Mdot
.6211 .37628 Mdot
.40998 .38531 Mdot
.35886 .49162 Mdot
.35019 .52808 Mdot
.30954 .52597 Mdot
.55243 .57152 Mdot
.35631 .51974 Mdot
.30924 .70738 Mdot
.45764 .40562 Mdot
.54504 .38084 Mdot
.83354 .39564 Mdot
.49701 .27949 Mdot
.6526 .34403 Mdot
.42418 .63723 Mdot
.33628 .54686 Mdot
.43784 .32945 Mdot
.59734 .60187 Mdot
.60028 .61419 Mdot
.34519 .32582 Mdot
.43008 .32783 Mdot
.41092 .67252 Mdot
.44898 .33878 Mdot
.40779 .67544 Mdot
.25903 .59874 Mdot
.64272 .61122 Mdot
.54613 .58704 Mdot
.41195 .34896 Mdot
.35326 .52043 Mdot
.32401 .51749 Mdot
.39964 .69236 Mdot
.45134 .53776 Mdot
.36812 .53969 Mdot
.61843 .34858 Mdot
.71862 .63289 Mdot
.36908 .48755 Mdot
.62172 .55537 Mdot
.50102 .73009 Mdot
.37217 .20784 Mdot
.59482 .50862 Mdot
.31571 .33613 Mdot
.7029 .5158 Mdot
.56003 .594 Mdot
.37845 .20384 Mdot
.46234 .33367 Mdot
.58363 .38863 Mdot
.32823 .54447 Mdot
.29832 .54584 Mdot
.56711 .64236 Mdot
.42579 .62854 Mdot
.66115 .54342 Mdot
.57513 .33416 Mdot
.61197 .3242 Mdot
.61714 .70624 Mdot
.19692 .56005 Mdot
.41591 .65901 Mdot
.41761 .64658 Mdot
.34296 .5298 Mdot
.30685 .78032 Mdot
.60787 .49455 Mdot
.40771 .67243 Mdot
.62414 .40948 Mdot
.62814 .59787 Mdot
.48089 .6443 Mdot
.5652 .46485 Mdot
.56836 .38136 Mdot
.5611 .69637 Mdot
.35708 .53208 Mdot
.58084 .37974 Mdot
.55029 .25598 Mdot
.6648 .58099 Mdot
.60114 .36238 Mdot
.41169 .38413 Mdot
.25965 .43142 Mdot
.61932 .34451 Mdot
.50326 .72235 Mdot
.40433 .39737 Mdot
.50354 .38357 Mdot
.57732 .68667 Mdot
.13234 .61536 Mdot
.4087 .35318 Mdot
.37516 .50081 Mdot
.33199 .5101 Mdot
.34125 .53519 Mdot
.57711 .36863 Mdot
.34264 .55066 Mdot
.5744 .35916 Mdot
.17499 .48313 Mdot
.38323 .21687 Mdot
.40503 .67133 Mdot
.31168 .39424 Mdot
.57886 .3461 Mdot
.65904 .27563 Mdot
.32211 .187 Mdot
.6418 .59883 Mdot
.39196 .35311 Mdot
.40622 .66913 Mdot
.35734 .79963 Mdot
.41075 .65507 Mdot
.75537 .65712 Mdot
.66866 .39773 Mdot
.60872 .55916 Mdot
.77014 .50825 Mdot
.41258 .68755 Mdot
.55178 .35063 Mdot
.57431 .57701 Mdot
.47263 .55367 Mdot
.41212 .64866 Mdot
.40705 .62846 Mdot
.58442 .56036 Mdot
.61703 .37301 Mdot
.36618 .52262 Mdot
.42818 .33719 Mdot
.42898 .66013 Mdot
.682 .56552 Mdot
.64815 .54503 Mdot
.64301 .58054 Mdot
.5755 .28281 Mdot
.42249 .69218 Mdot
.41154 .35803 Mdot
.2062 .34096 Mdot
.38261 .49958 Mdot
.46215 .58815 Mdot
.83124 .52654 Mdot
.43527 .30114 Mdot
.34827 .49651 Mdot
.31882 .514 Mdot
.56736 .57938 Mdot
.62278 .48524 Mdot
.65887 .39887 Mdot
.4327 .56108 Mdot
.31949 .54918 Mdot
.337 .53363 Mdot
.62986 .36861 Mdot
.68236 .70188 Mdot
.6083 .5044 Mdot
.44655 .38341 Mdot
.31137 .50085 Mdot
.36419 .24341 Mdot
.39021 .6413 Mdot
.68118 .3778 Mdot
.64484 .61081 Mdot
.63864 .57399 Mdot
.42206 .37157 Mdot
.41225 .38018 Mdot
.26488 .53391 Mdot
.71281 .68726 Mdot
.70276 .52214 Mdot
.46275 .26479 Mdot
.67805 .4262 Mdot
.63116 .34666 Mdot
.60903 .38201 Mdot
.30696 .4281 Mdot
.41961 .33471 Mdot
.55845 .59175 Mdot
.58777 .37972 Mdot
.45291 .61764 Mdot
.6984 .64146 Mdot
.67021 .6871 Mdot
.82878 .4549 Mdot
.60766 .58566 Mdot
.56248 .36099 Mdot
.57831 .39422 Mdot
.56778 .39323 Mdot
.3768 .30193 Mdot
.58683 .55105 Mdot
.60635 .5817 Mdot
.56123 .58504 Mdot
.41675 .2178 Mdot
.58114 .54994 Mdot
.39989 .27035 Mdot
.4737 .4707 Mdot
.73262 .36756 Mdot
.61703 .64143 Mdot
.44963 .33392 Mdot
.57123 .54527 Mdot
.42257 .66593 Mdot
.64842 .58724 Mdot
.67326 .68585 Mdot
.42737 .34761 Mdot
.6265 .6712 Mdot
.48533 .28689 Mdot
.58338 .62111 Mdot
.43148 .64368 Mdot
.46763 .31069 Mdot
.64851 .78099 Mdot
.42981 .61615 Mdot
.61707 .34681 Mdot
.3435 .5005 Mdot
.43617 .32828 Mdot
.34532 .52406 Mdot
.55399 .60583 Mdot
.29401 .43393 Mdot
.37009 .79734 Mdot
.46594 .54167 Mdot
.61126 .61592 Mdot
.58931 .49914 Mdot
.61978 .35577 Mdot
.38199 .50706 Mdot
.64798 .37182 Mdot
.56196 .56713 Mdot
.39627 .66761 Mdot
.40995 .64104 Mdot
.49935 .49974 Mdot
.51704 .82621 Mdot
.3155 .27059 Mdot
.4181 .3696 Mdot
.33824 .54319 Mdot
.40027 .684 Mdot
.21601 .45671 Mdot
.46022 .36207 Mdot
.42702 .39013 Mdot
.43122 .34992 Mdot
.62492 .54114 Mdot
.30797 .50729 Mdot
.73567 .36942 Mdot
.3874 .51346 Mdot
.59202 .58021 Mdot
.35177 .48283 Mdot
.37676 .5241 Mdot
.38868 .66614 Mdot
.43202 .34807 Mdot
.3551 .49093 Mdot
.63666 .54313 Mdot
.60915 .37326 Mdot
.36068 .35939 Mdot
.43608 .71688 Mdot
.20124 .56537 Mdot
.50439 .5485 Mdot
.56803 .38873 Mdot
.63349 .79008 Mdot
.44086 .38383 Mdot
.44753 .20899 Mdot
.37824 .73791 Mdot
.59152 .52344 Mdot
.41347 .16214 Mdot
.34762 .56945 Mdot
.37565 .52273 Mdot
.57814 .60163 Mdot
.34059 .57335 Mdot
.61259 .55761 Mdot
.36785 .50035 Mdot
.37969 .43392 Mdot
.53847 .34887 Mdot
.35416 .51513 Mdot
.59712 .63819 Mdot
.57822 .58531 Mdot
.56718 .37526 Mdot
.34656 .4729 Mdot
.64265 .52794 Mdot
.55623 .86043 Mdot
.40623 .3762 Mdot
.43187 .29396 Mdot
.48611 .73722 Mdot
.40305 .35415 Mdot
.59448 .36183 Mdot
.5563 .56698 Mdot
.4131 .64343 Mdot
.57691 .34566 Mdot
.683 .6785 Mdot
.38716 .67828 Mdot
.51943 .17005 Mdot
.5753 .39335 Mdot
.37268 .51886 Mdot
.41411 .67691 Mdot
.65839 .57226 Mdot
.386 .52475 Mdot
.24537 .43385 Mdot
.35015 .49897 Mdot
.56433 .58105 Mdot
.33904 .4092 Mdot
.4356 .3497 Mdot
.61064 .57652 Mdot
.37126 .52946 Mdot
.31639 .33822 Mdot
.62138 .53467 Mdot
.57175 .5908 Mdot
.82718 .54194 Mdot
.68989 .30501 Mdot
.40626 .65308 Mdot
.6107 .3977 Mdot
.63947 .59978 Mdot
.41578 .63461 Mdot
.3116 .67768 Mdot
.63157 .55336 Mdot
.59257 .33191 Mdot
.67107 .58746 Mdot
.35222 .47328 Mdot
.39839 .36739 Mdot
.43851 .57346 Mdot
.40785 .63082 Mdot
.16104 .60944 Mdot
.31343 .50174 Mdot
.55349 .55952 Mdot
.62766 .61519 Mdot
.48969 .77343 Mdot
.58131 .38634 Mdot
.59923 .4365 Mdot
.60856 .53934 Mdot
.42729 .21026 Mdot
.62337 .57284 Mdot
.35943 .56722 Mdot
.61362 .34666 Mdot
.59747 .54406 Mdot
.37274 .39861 Mdot
.55555 .52624 Mdot
.38132 .64498 Mdot
.26242 .35171 Mdot
.66499 .56704 Mdot
.52882 .1598 Mdot
.48979 .53805 Mdot
.35603 .51464 Mdot
.26123 .66664 Mdot
.54181 .869 Mdot
.47163 .2916 Mdot
.57952 .36807 Mdot
.40097 .78866 Mdot
.35107 .53036 Mdot
.23982 .60741 Mdot
.65032 .79083 Mdot
.58266 .59222 Mdot
.56294 .56125 Mdot
.54683 .75118 Mdot
.38537 .51609 Mdot
.37603 .47958 Mdot
.54629 .60137 Mdot
.56662 .5169 Mdot
.35557 .52478 Mdot
.61611 .52612 Mdot
.60043 .64327 Mdot
.39234 .35291 Mdot
.59696 .33376 Mdot
.40974 .39036 Mdot
.4286 .39549 Mdot
.24005 .35083 Mdot
.48196 .55646 Mdot
.40335 .37708 Mdot
.4538 .36723 Mdot
.48427 .63861 Mdot
.73379 .65719 Mdot
.42757 .65573 Mdot
.54681 .83695 Mdot
.33524 .52961 Mdot
.59312 .54954 Mdot
.57969 .39765 Mdot
.69811 .52442 Mdot
.33284 .69898 Mdot
.62698 .23914 Mdot
.55795 .58145 Mdot
.36167 .53079 Mdot
.4137 .29863 Mdot
.66882 .63476 Mdot
.30676 .49249 Mdot
.62948 .55926 Mdot
.36051 .55392 Mdot
.75049 .61048 Mdot
.21534 .47555 Mdot
.30383 .54995 Mdot
.5714 .4043 Mdot
.63493 .57146 Mdot
.56894 .33592 Mdot
.40493 .34692 Mdot
.42576 .66295 Mdot
.40503 .64855 Mdot
.5769 .57014 Mdot
.58341 .49311 Mdot
.26144 .62037 Mdot
.581 .57779 Mdot
.62497 .59979 Mdot
.45743 .32397 Mdot
.63102 .60027 Mdot
.61704 .62033 Mdot
.57338 .60927 Mdot
.56228 .60707 Mdot
.43098 .34226 Mdot
.25538 .48624 Mdot
.55332 .63112 Mdot
.53279 .58979 Mdot
.4112 .40408 Mdot
.40608 .77434 Mdot
.43705 .39076 Mdot
.66301 .7801 Mdot
.45201 .3609 Mdot
.3995 .65499 Mdot
.43009 .77506 Mdot
.53156 .5353 Mdot
.60567 .32948 Mdot
.43734 .312 Mdot
.41778 .66949 Mdot
.41633 .35436 Mdot
.37046 .50031 Mdot
.83431 .53691 Mdot
.59487 .31653 Mdot
.62429 .28496 Mdot
.48654 .3343 Mdot
.25589 .46438 Mdot
.32976 .48668 Mdot
.54732 .35709 Mdot
.75705 .57146 Mdot
.61687 .61815 Mdot
.41711 .63548 Mdot
.57855 .56259 Mdot
.40667 .34191 Mdot
.35184 .53482 Mdot
.18122 .51576 Mdot
.41041 .63928 Mdot
.84838 .42458 Mdot
.32574 .51193 Mdot
.60465 .61938 Mdot
.43603 .39318 Mdot
.79067 .32854 Mdot
.41344 .38977 Mdot
.62639 .44386 Mdot
.59935 .38875 Mdot
.16594 .54742 Mdot
.58069 .35363 Mdot
.23431 .45638 Mdot
.72729 .2327 Mdot
.23741 .53559 Mdot
.61245 .37477 Mdot
.41655 .547 Mdot
.61832 .58929 Mdot
.6431 .57931 Mdot
.2002 .48615 Mdot
.5936 .40145 Mdot
.62487 .6113 Mdot
.34485 .35716 Mdot
.44477 .40173 Mdot
.80474 .40993 Mdot
.32834 .49121 Mdot
.615 .55488 Mdot
.40478 .33138 Mdot
.42843 .32512 Mdot
.31658 .52606 Mdot
.43153 .38909 Mdot
.60363 .5805 Mdot
.57901 .34714 Mdot
.39459 .46548 Mdot
.39428 .64836 Mdot
.31866 .77613 Mdot
.37838 .63645 Mdot
.34745 .49595 Mdot
.61497 .51755 Mdot
.34994 .52732 Mdot
.66268 .84582 Mdot
.61653 .58333 Mdot
.61033 .36861 Mdot
.62516 .60443 Mdot
.63413 .57572 Mdot
.55807 .59814 Mdot
.36622 .51895 Mdot
.38429 .72874 Mdot
.63071 .53591 Mdot
.43089 .37671 Mdot
.70444 .4071 Mdot
.66122 .5972 Mdot
.38182 .58964 Mdot
.66079 .69257 Mdot
.50866 .33569 Mdot
.6016 .39479 Mdot
.35407 .50933 Mdot
.60004 .36823 Mdot
.4621 .19178 Mdot
.59448 .36149 Mdot
.69146 .45335 Mdot
.76244 .57021 Mdot
.79735 .5308 Mdot
.79742 .51476 Mdot
.43307 .48051 Mdot
.60044 .4006 Mdot
.43685 .63159 Mdot
.62177 .37307 Mdot
.57387 .386 Mdot
.42177 .11158 Mdot
.58013 .32884 Mdot
.61812 .54815 Mdot
.65309 .60988 Mdot
.22963 .49601 Mdot
.491 .6944 Mdot
.60969 .60384 Mdot
.61256 .60888 Mdot
.40355 .68386 Mdot
.45736 .19671 Mdot
.30559 .43925 Mdot
.6845 .30116 Mdot
.3205 .73851 Mdot
.58101 .56194 Mdot
.64691 .59319 Mdot
.55646 .62541 Mdot
.69847 .24729 Mdot
.22185 .37287 Mdot
.5654 .40393 Mdot
.53864 .59732 Mdot
.22805 .55579 Mdot
.55641 .58016 Mdot
.61507 .53621 Mdot
.61176 .58676 Mdot
.35144 .53077 Mdot
.60704 .39598 Mdot
.56968 .61793 Mdot
.47205 .77709 Mdot
.61989 .54283 Mdot
.40282 .29302 Mdot
.21052 .67009 Mdot
.61251 .54966 Mdot
.63647 .36183 Mdot
.64323 .58284 Mdot
.57504 .38065 Mdot
.55648 .36433 Mdot
.54025 .59565 Mdot
.67431 .42684 Mdot
.62955 .37351 Mdot
.59121 .58045 Mdot
.37302 .50088 Mdot
.58019 .81898 Mdot
.56548 .57595 Mdot
.42715 .65318 Mdot
.6023 .53498 Mdot
.42438 .63097 Mdot
.61747 .60006 Mdot
.31165 .5087 Mdot
.67266 .49664 Mdot
.33973 .52305 Mdot
.18593 .44064 Mdot
.30853 .51852 Mdot
.85803 .45469 Mdot
.56487 .38595 Mdot
.32623 .39722 Mdot
.55569 .20305 Mdot
.36274 .28906 Mdot
.51952 .42094 Mdot
.44004 .44875 Mdot
.41588 .39545 Mdot
.5898 .3867 Mdot
.51332 .20818 Mdot
.34289 .65585 Mdot
.34839 .61101 Mdot
.36203 .54356 Mdot
.18839 .34631 Mdot
.50241 .17477 Mdot
.55861 .53886 Mdot
.75487 .52348 Mdot
.74106 .4555 Mdot
.55565 .58281 Mdot
.55439 .59407 Mdot
.30743 .56151 Mdot
.62561 .52937 Mdot
.5542 .28048 Mdot
.34098 .493 Mdot
.42065 .66541 Mdot
.61898 .36303 Mdot
.39166 .63062 Mdot
.35374 .69554 Mdot
.44128 .44365 Mdot
.36525 .496 Mdot
.63838 .52702 Mdot
.60357 .60532 Mdot
.57044 .37269 Mdot
.65743 .34121 Mdot
.62726 .34948 Mdot
.41008 .66541 Mdot
.33466 .49463 Mdot
.34101 .2266 Mdot
.60409 .60783 Mdot
.59419 .33989 Mdot
.52675 .43002 Mdot
.63606 .60188 Mdot
.40921 .34688 Mdot
.62341 .58866 Mdot
.61897 .36973 Mdot
.63063 .60039 Mdot
.5804 .35528 Mdot
.3422 .50228 Mdot
.58438 .61722 Mdot
.57487 .6022 Mdot
.82364 .38951 Mdot
.40029 .67036 Mdot
.54609 .35422 Mdot
.45575 .60123 Mdot
.64183 .60432 Mdot
.30047 .38156 Mdot
.62648 .55642 Mdot
.52976 .34888 Mdot
.56594 .53487 Mdot
.43316 .29534 Mdot
.52986 .5722 Mdot
.57298 .56294 Mdot
.53561 .4715 Mdot
.73307 .45656 Mdot
.51757 .5967 Mdot
.45547 .35105 Mdot
.54728 .34943 Mdot
.80712 .42295 Mdot
.40018 .49592 Mdot
.35511 .46976 Mdot
.55999 .7137 Mdot
.58081 .62485 Mdot
.60704 .55705 Mdot
.51302 .34162 Mdot
.4061 .63351 Mdot
.58076 .33475 Mdot
.40736 .67547 Mdot
.84147 .4458 Mdot
.3798 .66764 Mdot
.35951 .56772 Mdot
.24903 .60393 Mdot
.3027 .25923 Mdot
.40077 .68316 Mdot
.61992 .37058 Mdot
.24554 .56576 Mdot
.6077 .62381 Mdot
.49834 .52156 Mdot
.39342 .662 Mdot
.14922 .44284 Mdot
.61513 .62026 Mdot
.52313 .42047 Mdot
.40041 .37918 Mdot
.40303 .68196 Mdot
.39813 .39489 Mdot
.59109 .59931 Mdot
.30937 .43834 Mdot
.58057 .36781 Mdot
.3962 .39848 Mdot
.66257 .61179 Mdot
.40815 .67024 Mdot
.31361 .49646 Mdot
.38435 .39549 Mdot
.45067 .37673 Mdot
.46497 .80933 Mdot
.1713 .51921 Mdot
.3322 .4964 Mdot
.74885 .34579 Mdot
.4483 .33513 Mdot
.61586 .62493 Mdot
.48192 .19728 Mdot
.64013 .57601 Mdot
.33039 .27818 Mdot
.35472 .5022 Mdot
.25613 .4704 Mdot
.63993 .59869 Mdot
.56494 .56743 Mdot
.61731 .32502 Mdot
.33462 .51763 Mdot
.59433 .34839 Mdot
.54179 .36747 Mdot
.34048 .50212 Mdot
.587 .36177 Mdot
.404 .68831 Mdot
.5533 .23962 Mdot
.44917 .36084 Mdot
.43883 .36828 Mdot
.34028 .53573 Mdot
.35897 .51221 Mdot
.34918 .52236 Mdot
.62425 .58878 Mdot
.59865 .33712 Mdot
.5941 .59221 Mdot
.59294 .53079 Mdot
.70885 .38949 Mdot
.59545 .39802 Mdot
.60114 .58809 Mdot
.46807 .57024 Mdot
.58185 .47061 Mdot
.36994 .49306 Mdot
.40158 .37657 Mdot
.33852 .36956 Mdot
.25176 .41301 Mdot
.61788 .55757 Mdot
.44853 .68587 Mdot
.62117 .37082 Mdot
.41434 .64961 Mdot
.37525 .6584 Mdot
.40905 .6553 Mdot
.48069 .36443 Mdot
.56892 .39351 Mdot
.68415 .31292 Mdot
.61197 .55484 Mdot
.55875 .3032 Mdot
.55852 .40272 Mdot
.258 .5787 Mdot
.40247 .3745 Mdot
.62552 .60625 Mdot
.4426 .5701 Mdot
.73027 .59791 Mdot
.63786 .58074 Mdot
.65944 .60464 Mdot
.3208 .71902 Mdot
.64999 .52431 Mdot
.61959 .33145 Mdot
.79512 .34131 Mdot
.65652 .57439 Mdot
.36061 .24194 Mdot
.34619 .80816 Mdot
.62478 .56279 Mdot
.56955 .55718 Mdot
.59555 .60978 Mdot
.64893 .58437 Mdot
.63222 .37137 Mdot
.51154 .67616 Mdot
.45128 .33909 Mdot
.56796 .29889 Mdot
.41572 .33748 Mdot
.32838 .55092 Mdot
.25667 .47324 Mdot
.59629 .38771 Mdot
.3895 .63903 Mdot
.28618 .72662 Mdot
.73352 .30151 Mdot
.31641 .51763 Mdot
.28133 .29571 Mdot
.39547 .66146 Mdot
.63511 .62394 Mdot
.42631 .67303 Mdot
.34268 .47909 Mdot
.44311 .36549 Mdot
.66797 .56986 Mdot
.61157 .3798 Mdot
.61632 .34189 Mdot
.62936 .60679 Mdot
.2257 .59112 Mdot
.39908 .35583 Mdot
.45694 .36409 Mdot
.62833 .54487 Mdot
.65879 .57702 Mdot
.59254 .35053 Mdot
.33012 .53348 Mdot
.80468 .52491 Mdot
.41865 .64402 Mdot
.55288 .57277 Mdot
.63469 .59758 Mdot
.82593 .53769 Mdot
.43305 .37778 Mdot
.3234 .47758 Mdot
.58598 .52448 Mdot
.44758 .25703 Mdot
.59365 .52367 Mdot
.56581 .63036 Mdot
.37331 .4995 Mdot
.60715 .65543 Mdot
.54552 .58246 Mdot
.54191 .33711 Mdot
.40554 .39345 Mdot
.60551 .36394 Mdot
.5444 .33316 Mdot
.58267 .24252 Mdot
.41419 .3464 Mdot
.61275 .59016 Mdot
.40366 .36819 Mdot
.63242 .55493 Mdot
.649 .56124 Mdot
.40521 .37991 Mdot
.59298 .34843 Mdot
.39246 .78236 Mdot
.24477 .51455 Mdot
.64981 .57484 Mdot
.54236 .59454 Mdot
.4916 .67506 Mdot
.35871 .65235 Mdot
.56175 .56626 Mdot
.62304 .36242 Mdot
.59122 .6036 Mdot
.39252 .36648 Mdot
.41064 .68777 Mdot
.61119 .37343 Mdot
.32224 .51844 Mdot
.31545 .50584 Mdot
.48343 .28992 Mdot
.37515 .53221 Mdot
.56363 .55752 Mdot
.64791 .33744 Mdot
.63839 .34242 Mdot
.25817 .6981 Mdot
.33704 .50357 Mdot
.42811 .64942 Mdot
.57094 .58709 Mdot
.61239 .72711 Mdot
.39916 .3361 Mdot
.38516 .14936 Mdot
.65483 .26616 Mdot
.42694 .67981 Mdot
.66434 .29945 Mdot
.31087 .52043 Mdot
.55009 .60187 Mdot
.42625 .65056 Mdot
.32967 .48806 Mdot
.64048 .55777 Mdot
.54135 .60209 Mdot
.60881 .44275 Mdot
.3993 .43848 Mdot
.40556 .37099 Mdot
.36004 .55085 Mdot
.43526 .66181 Mdot
.31777 .55042 Mdot
.55642 .37128 Mdot
.58407 .55085 Mdot
.61013 .51818 Mdot
.3278 .533 Mdot
.35535 .46842 Mdot
.59627 .58397 Mdot
.61588 .38232 Mdot
.34087 .5831 Mdot
.5858 .56212 Mdot
.39039 .42191 Mdot
.5983 .40443 Mdot
.33104 .4919 Mdot
.57015 .56185 Mdot
.40702 .61255 Mdot
.32584 .51902 Mdot
.36731 .4898 Mdot
.64629 .5948 Mdot
.39621 .68496 Mdot
.54372 .56214 Mdot
.44732 .37152 Mdot
.18271 .36829 Mdot
.39247 .36507 Mdot
.40419 .50583 Mdot
.65003 .52099 Mdot
.44939 .23453 Mdot
.59349 .39382 Mdot
.59838 .7008 Mdot
.3444 .35997 Mdot
.60317 .6445 Mdot
.56808 .80898 Mdot
.38326 .3179 Mdot
.25205 .67785 Mdot
.61793 .76233 Mdot
.39009 .66312 Mdot
.41876 .3541 Mdot
.56947 .55693 Mdot
.39079 .35581 Mdot
.4249 .64482 Mdot
.18841 .43734 Mdot
.56392 .57586 Mdot
.61628 .35094 Mdot
.60281 .58327 Mdot
.61144 .34154 Mdot
.65207 .5851 Mdot
.55068 .53898 Mdot
.35329 .30908 Mdot
.51718 .64731 Mdot
.58951 .52501 Mdot
.84964 .37177 Mdot
.58956 .4607 Mdot
.42161 .65221 Mdot
.58543 .59037 Mdot
.29875 .51756 Mdot
.42273 .32934 Mdot
.3876 .27847 Mdot
.35336 .53037 Mdot
.44878 .37802 Mdot
.58942 .35677 Mdot
.35102 .50378 Mdot
.31745 .52422 Mdot
.61562 .65667 Mdot
.41814 .6869 Mdot
.43354 .36064 Mdot
.59609 .54295 Mdot
.56517 .57302 Mdot
.74965 .34101 Mdot
.33152 .66078 Mdot
.65425 .32032 Mdot
.64156 .20656 Mdot
.5502 .37738 Mdot
.41627 .66828 Mdot
.36496 .52343 Mdot
.58118 .5361 Mdot
.60579 .57526 Mdot
.31015 .38263 Mdot
.62889 .36283 Mdot
.46166 .48688 Mdot
.66388 .3297 Mdot
.44931 .61525 Mdot
.51986 .66067 Mdot
.62031 .36355 Mdot
.51481 .65861 Mdot
.41513 .69777 Mdot
.47589 .83805 Mdot
.49767 .63251 Mdot
.39926 .37565 Mdot
.50406 .65394 Mdot
.57937 .33643 Mdot
.63297 .54058 Mdot
.37561 .50608 Mdot
.37744 .52344 Mdot
.6029 .35639 Mdot
.30319 .51176 Mdot
.38631 .65908 Mdot
.58166 .54348 Mdot
.68521 .28596 Mdot
.51341 .26821 Mdot
.34196 .54018 Mdot
.64928 .64514 Mdot
.43031 .34861 Mdot
.63065 .60652 Mdot
.39244 .6766 Mdot
.40601 .35749 Mdot
.73647 .67055 Mdot
.43494 .41119 Mdot
.57206 .5813 Mdot
.82939 .53648 Mdot
.41378 .3497 Mdot
.67604 .521 Mdot
.58981 .55522 Mdot
.44156 .3799 Mdot
.6827 .63742 Mdot
.25467 .43705 Mdot
.47401 .5273 Mdot
.65152 .79129 Mdot
.48926 .48891 Mdot
.36154 .53452 Mdot
.25486 .45377 Mdot
.35511 .28784 Mdot
.43974 .33259 Mdot
.33885 .47001 Mdot
.48454 .56552 Mdot
.40031 .39529 Mdot
.63096 .62408 Mdot
.62813 .56166 Mdot
.21756 .38439 Mdot
.40443 .31797 Mdot
.22943 .46067 Mdot
.4965 .30889 Mdot
.64148 .60595 Mdot
.55095 .54493 Mdot
.60424 .57117 Mdot
.6319 .34569 Mdot
.41393 .37633 Mdot
.82588 .36011 Mdot
.40446 .3483 Mdot
.6912 .38 Mdot
.33811 .53218 Mdot
.32991 .48977 Mdot
.61574 .55285 Mdot
.52461 .41508 Mdot
.69838 .68731 Mdot
.59919 .57968 Mdot
.36815 .69029 Mdot
.22208 .4004 Mdot
.65721 .58458 Mdot
.60482 .39025 Mdot
.60255 .6492 Mdot
.68434 .56213 Mdot
.44937 .3587 Mdot
.38995 .64344 Mdot
.63708 .70252 Mdot
.44225 .36079 Mdot
.60667 .55851 Mdot
.45901 .24184 Mdot
.62936 .57978 Mdot
.64799 .57221 Mdot
.67288 .36313 Mdot
.37705 .66756 Mdot
.3448 .51399 Mdot
.40718 .65771 Mdot
.57979 .38757 Mdot
.34469 .14586 Mdot
.37872 .66352 Mdot
.71864 .67564 Mdot
.19852 .39568 Mdot
.49469 .64557 Mdot
.5809 .33334 Mdot
.43102 .66716 Mdot
.39702 .36565 Mdot
.57743 .82172 Mdot
.60954 .45149 Mdot
.37739 .3368 Mdot
.59105 .56126 Mdot
.5569 .336 Mdot
.61667 .33827 Mdot
.39912 .40127 Mdot
.55373 .36225 Mdot
.54623 .63455 Mdot
.64225 .55637 Mdot
.4288 .33563 Mdot
.47266 .26261 Mdot
.4544 .34143 Mdot
.42575 .52716 Mdot
.58328 .58522 Mdot
.61357 .37006 Mdot
.54959 .58497 Mdot
.63787 .37987 Mdot
.31481 .48701 Mdot
.63165 .52375 Mdot
.38531 .65772 Mdot
.4357 .24136 Mdot
.32939 .49798 Mdot
.46089 .61728 Mdot
.57142 .37556 Mdot
.48241 .37361 Mdot
.56597 .37273 Mdot
.64451 .35635 Mdot
.43663 .39191 Mdot
.56494 .34645 Mdot
.57243 .55382 Mdot
.47544 .54051 Mdot
.57467 .37026 Mdot
.42452 .36581 Mdot
.39572 .64072 Mdot
.58409 .3539 Mdot
.33701 .5729 Mdot
.56847 .58467 Mdot
.36466 .51697 Mdot
.35912 .69413 Mdot
.56788 .33061 Mdot
.38633 .68809 Mdot
.36056 .47162 Mdot
.40743 .62842 Mdot
.2188 .63917 Mdot
.41214 .41144 Mdot
.67053 .40103 Mdot
.36619 .69324 Mdot
.60958 .33032 Mdot
.38634 .7388 Mdot
.59648 .53154 Mdot
.56933 .58697 Mdot
.42302 .63102 Mdot
.61693 .33841 Mdot
.40865 .83684 Mdot
.59852 .48733 Mdot
.42641 .49556 Mdot
.45379 .32672 Mdot
.85952 .44231 Mdot
.42523 .51444 Mdot
.31193 .78815 Mdot
.65559 .63587 Mdot
.37834 .48194 Mdot
.61609 .56455 Mdot
.33173 .34913 Mdot
.40486 .66864 Mdot
.3997 .5627 Mdot
.5881 .51495 Mdot
.34605 .50759 Mdot
.57788 .6082 Mdot
.52465 .47956 Mdot
.69185 .55177 Mdot
.42569 .63876 Mdot
.2365 .58447 Mdot
.56668 .33303 Mdot
.39401 .65179 Mdot
.34033 .48444 Mdot
.56916 .68087 Mdot
.64185 .55894 Mdot
.6257 .62681 Mdot
.44832 .61505 Mdot
.59565 .33539 Mdot
.37258 .52272 Mdot
.44633 .37065 Mdot
.39596 .63641 Mdot
.60319 .60392 Mdot
.59522 .52899 Mdot
.30255 .36998 Mdot
.42694 .3445 Mdot
.38353 .51027 Mdot
.40169 .38677 Mdot
.31599 .53124 Mdot
.63552 .53778 Mdot
.31924 .50297 Mdot
.5775 .62664 Mdot
.38854 .29617 Mdot
.67471 .38088 Mdot
.73719 .47561 Mdot
.35295 .49809 Mdot
.74081 .64717 Mdot
.424 .34499 Mdot
.41942 .3901 Mdot
.23104 .3328 Mdot
.62049 .44147 Mdot
.73261 .31354 Mdot
.53143 .79471 Mdot
.43173 .33968 Mdot
.43043 .35628 Mdot
.36402 .5156 Mdot
.56307 .34914 Mdot
.55012 .37426 Mdot
.3172 .5307 Mdot
.49523 .73348 Mdot
.58149 .33477 Mdot
.53305 .82837 Mdot
.78928 .38562 Mdot
.60276 .63739 Mdot
.37255 .56554 Mdot
.41086 .64459 Mdot
.50809 .72469 Mdot
.51501 .49041 Mdot
.56159 .57343 Mdot
.59386 .71468 Mdot
.33531 .53541 Mdot
.51016 .38838 Mdot
.65244 .78257 Mdot
.58093 .61335 Mdot
.59148 .5507 Mdot
.60834 .56605 Mdot
.409 .69248 Mdot
.63906 .46422 Mdot
.57724 .55227 Mdot
.49221 .73459 Mdot
.63672 .60651 Mdot
.69633 .5566 Mdot
.40619 .65097 Mdot
.49783 .6037 Mdot
.34662 .6752 Mdot
.79633 .35097 Mdot
.66895 .52368 Mdot
.44907 .36676 Mdot
.36593 .60314 Mdot
.41491 .39257 Mdot
.70336 .45503 Mdot
.4865 .62823 Mdot
.55312 .38346 Mdot
.56209 .57083 Mdot
.34665 .49507 Mdot
.61624 .33836 Mdot
.27495 .41938 Mdot
.38731 .12557 Mdot
.45131 .35301 Mdot
.4601 .88904 Mdot
.43665 .38378 Mdot
.31871 .52723 Mdot
.59293 .35148 Mdot
.7579 .58593 Mdot
.58728 .27264 Mdot
.584 .35645 Mdot
.38591 .80607 Mdot
.5744 .41115 Mdot
.63244 .69156 Mdot
.59853 .32285 Mdot
.4254 .36039 Mdot
.48256 .34287 Mdot
.53731 .63204 Mdot
.6107 .53712 Mdot
.44625 .44849 Mdot
.69764 .6844 Mdot
.59475 .53188 Mdot
.33914 .49362 Mdot
.65782 .40518 Mdot
.57349 .71087 Mdot
.56981 .34168 Mdot
.43223 .40941 Mdot
.58409 .55432 Mdot
.63978 .59044 Mdot
.63691 .54889 Mdot
.65763 .25905 Mdot
.47122 .83755 Mdot
.63228 .53744 Mdot
.65041 .593 Mdot
.34868 .50486 Mdot
.36734 .63138 Mdot
.24613 .5462 Mdot
.73447 .35079 Mdot
.56977 .60961 Mdot
.39795 .64922 Mdot
.4385 .6555 Mdot
.61286 .52665 Mdot
.47803 .55716 Mdot
.46239 .23609 Mdot
.59436 .54313 Mdot
.65289 .41125 Mdot
.27894 .50535 Mdot
.38585 .51444 Mdot
.32451 .52307 Mdot
.55085 .34828 Mdot
.32669 .53698 Mdot
.3107 .50645 Mdot
.7371 .61504 Mdot
.47793 .48573 Mdot
.37504 .30826 Mdot
.41217 .66409 Mdot
.61218 .57733 Mdot
.51481 .57511 Mdot
.44789 .25087 Mdot
.41557 .39784 Mdot
.60471 .37842 Mdot
.41801 .32926 Mdot
.44317 .65102 Mdot
.61194 .25657 Mdot
.34865 .54706 Mdot
.44157 .34699 Mdot
.39872 .41602 Mdot
.39962 .64734 Mdot
.39015 .38124 Mdot
.44206 .41908 Mdot
.65429 .55177 Mdot
.74522 .53289 Mdot
.59167 .57836 Mdot
.29165 .73762 Mdot
.43493 .35302 Mdot
.46919 .33267 Mdot
.60391 .55018 Mdot
.32645 .51577 Mdot
.65716 .66737 Mdot
.61506 .53808 Mdot
.32891 .53757 Mdot
.56436 .53329 Mdot
.38189 .63253 Mdot
.6128 .39819 Mdot
.58397 .27514 Mdot
.19059 .3381 Mdot
.4217 .6836 Mdot
.28121 .41205 Mdot
.5582 .57683 Mdot
.18678 .56071 Mdot
.58295 .35124 Mdot
.56642 .54127 Mdot
.55828 .69443 Mdot
.57189 .36086 Mdot
.59711 .37043 Mdot
.62466 .59381 Mdot
.39924 .3801 Mdot
.32928 .49567 Mdot
.40398 .64603 Mdot
.28073 .74876 Mdot
.58346 .56917 Mdot
.58039 .60327 Mdot
.39471 .65634 Mdot
.41694 .34155 Mdot
.59584 .52414 Mdot
.52215 .76915 Mdot
.44498 .85028 Mdot
.43632 .38667 Mdot
.60486 .62145 Mdot
.70592 .48212 Mdot
.6305 .49802 Mdot
.1618 .57455 Mdot
.49191 .53438 Mdot
.34989 .51365 Mdot
.61263 .50139 Mdot
.48831 .14067 Mdot
.39323 .6403 Mdot
.73248 .30362 Mdot
.6395 .59246 Mdot
.60792 .61024 Mdot
.62785 .35557 Mdot
.59357 .58941 Mdot
.60014 .38605 Mdot
.26048 .27155 Mdot
.83865 .5166 Mdot
.549 .36275 Mdot
.60106 .32731 Mdot
.65078 .70036 Mdot
.36039 .40099 Mdot
.60021 .35632 Mdot
.65197 .5658 Mdot
.48122 .59609 Mdot
.5176 .36702 Mdot
.43169 .65752 Mdot
.37459 .72744 Mdot
.55494 .50021 Mdot
.46101 .65845 Mdot
.40447 .77672 Mdot
.52517 .5282 Mdot
.42896 .55143 Mdot
.42983 .38354 Mdot
.57983 .61348 Mdot
.37828 .52292 Mdot
.37832 .52724 Mdot
.56974 .623 Mdot
.62121 .5816 Mdot
.57654 .38435 Mdot
.40817 .63631 Mdot
.44172 .33017 Mdot
.60899 .60824 Mdot
.5941 .69745 Mdot
.39637 .63209 Mdot
.55585 .35725 Mdot
.69647 .40231 Mdot
.37805 .63136 Mdot
.54229 .54954 Mdot
.60442 .5402 Mdot
.60763 .5857 Mdot
.5327 .62873 Mdot
.41518 .3799 Mdot
.41576 .76843 Mdot
.65346 .60413 Mdot
.84041 .43543 Mdot
.3624 .32966 Mdot
.59927 .50671 Mdot
.55927 .37117 Mdot
.45277 .38892 Mdot
.30822 .52915 Mdot
.56347 .22665 Mdot
.57367 .57919 Mdot
.22917 .58553 Mdot
.21502 .39434 Mdot
.33073 .47579 Mdot
.63026 .38717 Mdot
.41246 .65683 Mdot
.60243 .57968 Mdot
.67134 .42965 Mdot
.6256 .5593 Mdot
.40546 .70555 Mdot
.36276 .48347 Mdot
.42669 .385 Mdot
.26552 .69725 Mdot
.37011 .54222 Mdot
.59931 .36849 Mdot
.79686 .64147 Mdot
.60101 .38672 Mdot
.54862 .37131 Mdot
.70474 .40281 Mdot
.4149 .38115 Mdot
.434 .13742 Mdot
.27586 .26865 Mdot
.64144 .53811 Mdot
.41877 .34305 Mdot
.61026 .35867 Mdot
.62561 .61386 Mdot
.60474 .41159 Mdot
.57481 .3978 Mdot
.64367 .5495 Mdot
.60151 .61309 Mdot
.21895 .49475 Mdot
.62334 .78421 Mdot
.41229 .65877 Mdot
.58157 .39224 Mdot
.56658 .27616 Mdot
.62698 .61486 Mdot
.61126 .55392 Mdot
.32202 .3028 Mdot
.41669 .68571 Mdot
.54018 .26529 Mdot
.63967 .59133 Mdot
.80628 .58824 Mdot
.57449 .64184 Mdot
.62674 .37797 Mdot
.41974 .39338 Mdot
.80491 .36811 Mdot
.42296 .42769 Mdot
.59933 .3852 Mdot
.38479 .64304 Mdot
.62542 .32855 Mdot
.73058 .66711 Mdot
.41373 .3392 Mdot
.61908 .36961 Mdot
.43834 .57123 Mdot
.41183 .36885 Mdot
.43946 .35354 Mdot
.71479 .38917 Mdot
.31061 .48771 Mdot
.41604 .69117 Mdot
.43272 .35827 Mdot
.43825 .21235 Mdot
.41992 .36347 Mdot
.25959 .28441 Mdot
.58865 .61726 Mdot
.54714 .73152 Mdot
.40539 .52319 Mdot
.56256 .50383 Mdot
.43459 .34747 Mdot
.40639 .68447 Mdot
.64085 .56006 Mdot
.56475 .33988 Mdot
.41697 .63721 Mdot
.38137 .35041 Mdot
.35479 .52633 Mdot
.56501 .36797 Mdot
.42497 .31407 Mdot
.61562 .34323 Mdot
.51236 .20904 Mdot
.18443 .3975 Mdot
.65804 .71319 Mdot
.58979 .27016 Mdot
.64344 .56132 Mdot
.48078 .80917 Mdot
.59788 .62345 Mdot
.62733 .58436 Mdot
.33493 .4917 Mdot
.56346 .72285 Mdot
.59396 .34869 Mdot
.34794 .78855 Mdot
.44809 .3553 Mdot
.80324 .3593 Mdot
.65875 .51695 Mdot
.55223 .56056 Mdot
.57632 .37357 Mdot
.62532 .37307 Mdot
.72551 .43974 Mdot
.32869 .55935 Mdot
.5551 .57468 Mdot
.66733 .59378 Mdot
.56323 .62082 Mdot
.44571 .36278 Mdot
.47034 .58884 Mdot
.35748 .53758 Mdot
.17033 .46366 Mdot
.36198 .48138 Mdot
.42028 .70594 Mdot
.56295 .34554 Mdot
.37874 .66275 Mdot
.61021 .55147 Mdot
.65789 .35069 Mdot
.62987 .35947 Mdot
.4202 .62992 Mdot
.40935 .67945 Mdot
.27337 .38554 Mdot
.40509 .37903 Mdot
.61744 .53528 Mdot
.57143 .55969 Mdot
.59871 .59466 Mdot
.62251 .58738 Mdot
.45008 .35108 Mdot
.63459 .54973 Mdot
.39411 .33938 Mdot
.57664 .22192 Mdot
.55392 .75122 Mdot
.49372 .48571 Mdot
.30071 .29043 Mdot
.57277 .33861 Mdot
.44029 .21843 Mdot
.67269 .54821 Mdot
.5612 .19064 Mdot
.19376 .4653 Mdot
.6622 .58324 Mdot
.31718 .50065 Mdot
.69277 .63384 Mdot
.36481 .54093 Mdot
.31862 .80277 Mdot
.333 .31348 Mdot
.60954 .79388 Mdot
.565 .57433 Mdot
.4737 .54068 Mdot
.40722 .21784 Mdot
.60775 .62488 Mdot
.29727 .35804 Mdot
.32929 .27742 Mdot
.237 .56423 Mdot
.39799 .68341 Mdot
.57389 .56989 Mdot
.516 .58631 Mdot
.57624 .5496 Mdot
.61517 .55981 Mdot
.6359 .5494 Mdot
.44583 .32703 Mdot
.56808 .54396 Mdot
.64165 .57034 Mdot
.26695 .63186 Mdot
.51828 .65562 Mdot
.3787 .48932 Mdot
.21869 .35456 Mdot
.37884 .66588 Mdot
.5738 .37543 Mdot
.4613 .82843 Mdot
.39955 .37516 Mdot
.73132 .44301 Mdot
.61622 .58648 Mdot
.22983 .50207 Mdot
.41056 .4215 Mdot
.38389 .64776 Mdot
.33847 .47921 Mdot
.60931 .80676 Mdot
.34243 .49639 Mdot
.46798 .3698 Mdot
.32759 .51079 Mdot
.64978 .51728 Mdot
.57741 .386 Mdot
.61549 .53076 Mdot
.43368 .36369 Mdot
.32034 .52035 Mdot
.49262 .68681 Mdot
.60665 .57097 Mdot
.34041 .503 Mdot
.61704 .53179 Mdot
.62758 .28215 Mdot
.76577 .37567 Mdot
.31412 .49938 Mdot
.39613 .41168 Mdot
.42728 .37541 Mdot
.3904 .67965 Mdot
.56873 .36649 Mdot
.602 .38126 Mdot
.40734 .35739 Mdot
.64725 .39629 Mdot
.56882 .61014 Mdot
.61581 .61563 Mdot
.81859 .39601 Mdot
.5722 .54982 Mdot
.57042 .67961 Mdot
.44561 .57228 Mdot
.55348 .35163 Mdot
.54862 .56608 Mdot
.62813 .59658 Mdot
.57121 .58281 Mdot
.64807 .28222 Mdot
.33233 .53768 Mdot
.58378 .61517 Mdot
.41597 .67527 Mdot
.26137 .51902 Mdot
.63139 .60615 Mdot
.58236 .64982 Mdot
.60399 .38062 Mdot
.64813 .21669 Mdot
.43374 .38514 Mdot
.34086 .48509 Mdot
.35416 .49838 Mdot
.40306 .76233 Mdot
.39308 .24632 Mdot
.44716 .57087 Mdot
.15615 .5133 Mdot
.35375 .30906 Mdot
.4099 .67347 Mdot
.39122 .51506 Mdot
.47345 .32779 Mdot
.36261 .50259 Mdot
.45083 .34559 Mdot
.60323 .62019 Mdot
.57229 .61198 Mdot
.45837 .15798 Mdot
.60269 .52377 Mdot
.41159 .65195 Mdot
.4511 .3338 Mdot
.58248 .33668 Mdot
.38647 .64288 Mdot
.40309 .38855 Mdot
.5505 .35023 Mdot
.66289 .58752 Mdot
.65782 .59973 Mdot
.6015 .37846 Mdot
.62568 .35453 Mdot
.60492 .54288 Mdot
.34631 .43303 Mdot
.60183 .32875 Mdot
.6209 .36459 Mdot
.34717 .54528 Mdot
.37609 .52881 Mdot
.53229 .59735 Mdot
.42413 .34749 Mdot
.6412 .56644 Mdot
.35007 .50076 Mdot
.37948 .66515 Mdot
.59181 .34628 Mdot
.64961 .57878 Mdot
.623 .60587 Mdot
.39932 .6459 Mdot
.38363 .66825 Mdot
.39447 .67768 Mdot
.41671 .31751 Mdot
.59046 .59494 Mdot
.59327 .35585 Mdot
.41002 .38255 Mdot
.43638 .66537 Mdot
.42756 .66868 Mdot
.38332 .5445 Mdot
.57299 .54453 Mdot
.3937 .46427 Mdot
.50706 .13961 Mdot
.83488 .48085 Mdot
.31642 .48954 Mdot
.30933 .53448 Mdot
.46261 .69356 Mdot
.50917 .37278 Mdot
.40597 .35008 Mdot
.36053 .64959 Mdot
.6661 .70243 Mdot
.66203 .55957 Mdot
.65573 .58446 Mdot
.55728 .53431 Mdot
.39753 .67915 Mdot
.57906 .73153 Mdot
.59414 .38767 Mdot
.51727 .62881 Mdot
.3982 .63072 Mdot
.36468 .47364 Mdot
.39282 .52491 Mdot
.35814 .47941 Mdot
.64142 .61945 Mdot
.74715 .48822 Mdot
.41842 .2346 Mdot
.51571 .78643 Mdot
.43017 .34519 Mdot
.51522 .57053 Mdot
.18849 .55015 Mdot
.59741 .37501 Mdot
.33057 .5532 Mdot
.41252 .67372 Mdot
.62465 .35198 Mdot
.41134 .33246 Mdot
.43078 .35878 Mdot
.34337 .53994 Mdot
.34553 .5372 Mdot
.36974 .50307 Mdot
.57693 .40079 Mdot
.5635 .34633 Mdot
.57489 .58109 Mdot
.58768 .34304 Mdot
.62092 .22546 Mdot
.4121 .6217 Mdot
.29878 .49844 Mdot
.42066 .35167 Mdot
.57262 .33487 Mdot
.6036 .57236 Mdot
.53198 .33895 Mdot
.43262 .28087 Mdot
.42298 .65218 Mdot
.75683 .35792 Mdot
.28165 .7636 Mdot
.611 .53204 Mdot
.42322 .38004 Mdot
.68445 .27797 Mdot
.60542 .5661 Mdot
.3689 .51914 Mdot
.28794 .69137 Mdot
.35182 .44705 Mdot
.61798 .54007 Mdot
.65312 .54582 Mdot
.44863 .37229 Mdot
.17228 .47051 Mdot
.57815 .57578 Mdot
.545 .25232 Mdot
.40706 .41739 Mdot
.3667 .52854 Mdot
.57945 .85781 Mdot
.41561 .60595 Mdot
.50512 .72912 Mdot
.34855 .54181 Mdot
.63445 .57414 Mdot
.35737 .54672 Mdot
.42126 .66792 Mdot
.33542 .48259 Mdot
.60429 .38734 Mdot
.35683 .47491 Mdot
.58149 .60398 Mdot
.60306 .35845 Mdot
.41399 .34874 Mdot
.78527 .34417 Mdot
.30623 .69202 Mdot
.32698 .51824 Mdot
.31268 .50869 Mdot
.55059 .55676 Mdot
.54849 .28054 Mdot
.56711 .61823 Mdot
.61178 .62003 Mdot
.42415 .33797 Mdot
.57131 .36353 Mdot
.43708 .38798 Mdot
.53596 .53873 Mdot
.57136 .75942 Mdot
.40419 .38731 Mdot
.23943 .53463 Mdot
.39608 .66382 Mdot
.5005 .43504 Mdot
.60655 .57667 Mdot
.39339 .39031 Mdot
.58757 .59363 Mdot
.58998 .38852 Mdot
.51068 .46509 Mdot
.28522 .45745 Mdot
.43951 .36424 Mdot
.23841 .64237 Mdot
.51983 .75891 Mdot
.53511 .61615 Mdot
.42019 .39091 Mdot
.55892 .7012 Mdot
.31984 .5298 Mdot
.41804 .64159 Mdot
.38903 .62585 Mdot
.39897 .62896 Mdot
.61356 .64283 Mdot
.66547 .52207 Mdot
.38753 .69019 Mdot
.42158 .33069 Mdot
.42597 .63952 Mdot
.3455 .24173 Mdot
.35162 .79049 Mdot
.40215 .66659 Mdot
.58977 .55769 Mdot
.6873 .59723 Mdot
.48536 .6387 Mdot
.25061 .43713 Mdot
.59374 .7991 Mdot
.26859 .34785 Mdot
.6164 .54228 Mdot
.58952 .40673 Mdot
.58107 .39724 Mdot
.68535 .25674 Mdot
.71687 .66842 Mdot
.83127 .51573 Mdot
.54786 .34684 Mdot
.33382 .40113 Mdot
.55889 .3596 Mdot
.62599 .53397 Mdot
.61957 .6153 Mdot
.54205 .35423 Mdot
.58626 .74916 Mdot
.31784 .40742 Mdot
.27119 .72089 Mdot
.62048 .34728 Mdot
.40692 .3938 Mdot
.41779 .40275 Mdot
.43852 .35078 Mdot
.77722 .36035 Mdot
.57943 .37154 Mdot
.60854 .60115 Mdot
.35095 .49571 Mdot
.56909 .60649 Mdot
.40935 .36995 Mdot
.36258 .8063 Mdot
.58 .35815 Mdot
.58035 .55419 Mdot
.6138 .66586 Mdot
.34968 .5331 Mdot
.39839 .65454 Mdot
.59967 .28206 Mdot
.82407 .52657 Mdot
.44589 .35164 Mdot
.56426 .33278 Mdot
.4573 .31676 Mdot
.28472 .72132 Mdot
.66072 .6341 Mdot
.66971 .55999 Mdot
.28068 .75144 Mdot
.7853 .6241 Mdot
.55826 .57032 Mdot
.32586 .48868 Mdot
.31102 .37381 Mdot
.63419 .60143 Mdot
.58246 .3955 Mdot
.37974 .63049 Mdot
.41146 .63066 Mdot
.53325 .60374 Mdot
.53331 .32504 Mdot
.50955 .48939 Mdot
.61545 .59044 Mdot
.54527 .54496 Mdot
.36043 .53445 Mdot
.33309 .33232 Mdot
.84192 .44675 Mdot
.38006 .65811 Mdot
.61205 .52851 Mdot
.37233 .78189 Mdot
.62711 .34658 Mdot
.32836 .47761 Mdot
.39117 .3637 Mdot
.55743 .40153 Mdot
.33625 .48004 Mdot
.65235 .5747 Mdot
.60563 .52481 Mdot
.42146 .39808 Mdot
.62512 .37933 Mdot
.39601 .67628 Mdot
.3357 .48922 Mdot
.38504 .66557 Mdot
.57369 .36177 Mdot
.57862 .34304 Mdot
.59176 .65908 Mdot
.6704 .6204 Mdot
.32268 .51739 Mdot
.58873 .63413 Mdot
.33361 .44652 Mdot
.17501 .62137 Mdot
.43746 .31199 Mdot
.57576 .53758 Mdot
.60692 .32218 Mdot
.44334 .36247 Mdot
.60468 .61091 Mdot
.32777 .79851 Mdot
.63294 .61214 Mdot
.45839 .33406 Mdot
.72395 .68837 Mdot
.38846 .66737 Mdot
.505 .58864 Mdot
.20345 .49034 Mdot
.57835 .54249 Mdot
.35991 .50783 Mdot
.63819 .64773 Mdot
.3962 .37484 Mdot
.56777 .3424 Mdot
.16869 .62399 Mdot
.42155 .36739 Mdot
.58667 .5414 Mdot
.39241 .6378 Mdot
.61466 .32786 Mdot
.49444 .53911 Mdot
.47462 .56481 Mdot
.67388 .63939 Mdot
.55206 .5766 Mdot
.632 .5902 Mdot
.53114 .77362 Mdot
.34711 .48628 Mdot
.61791 .36184 Mdot
.42834 .37965 Mdot
.40628 .35481 Mdot
.33865 .5387 Mdot
.39742 .46296 Mdot
.49929 .43551 Mdot
.59426 .15711 Mdot
.34796 .5512 Mdot
.37782 .653 Mdot
.54845 .26858 Mdot
.34601 .4895 Mdot
.33753 .50652 Mdot
.34967 .54555 Mdot
.43586 .55801 Mdot
.58154 .33418 Mdot
.65287 .57675 Mdot
.60205 .39447 Mdot
.63634 .57425 Mdot
.46191 .3457 Mdot
.43716 .3626 Mdot
.57589 .35475 Mdot
.23911 .68424 Mdot
.72995 .53049 Mdot
.60036 .55912 Mdot
.18734 .55976 Mdot
.59981 .51495 Mdot
.48375 .65682 Mdot
.58209 .52138 Mdot
.33153 .5253 Mdot
.62688 .62825 Mdot
.58891 .63911 Mdot
.7077 .27638 Mdot
.42129 .349 Mdot
.3875 .51011 Mdot
.57274 .51633 Mdot
.54238 .55303 Mdot
.57442 .40111 Mdot
.62452 .35517 Mdot
.39214 .6258 Mdot
.56158 .66912 Mdot
.41259 .34688 Mdot
.33834 .2219 Mdot
.60943 .53734 Mdot
.45837 .64122 Mdot
.80146 .49063 Mdot
.60143 .61047 Mdot
.20221 .51999 Mdot
.74322 .47654 Mdot
.60377 .57881 Mdot
.43699 .47505 Mdot
.42548 .34508 Mdot
.61857 .75547 Mdot
.63963 .60274 Mdot
.35677 .53039 Mdot
.55919 .3519 Mdot
.63117 .3558 Mdot
.38248 .63418 Mdot
.5065 .17425 Mdot
.43823 .38818 Mdot
.56973 .34693 Mdot
.61356 .57195 Mdot
.42197 .38183 Mdot
.34117 .54954 Mdot
.55613 .5525 Mdot
.75345 .63946 Mdot
.59125 .3408 Mdot
.5658 .53142 Mdot
.52408 .2371 Mdot
.46942 .71746 Mdot
.72489 .70462 Mdot
.43378 .37808 Mdot
.39205 .68035 Mdot
.57956 .64052 Mdot
.60744 .43584 Mdot
.54026 .58121 Mdot
.52548 .73738 Mdot
.33282 .25108 Mdot
.40767 .68811 Mdot
.59983 .55081 Mdot
.60562 .6039 Mdot
.55991 .4415 Mdot
.381 .65015 Mdot
.56566 .57041 Mdot
.56182 .42008 Mdot
.61014 .34244 Mdot
.32444 .54543 Mdot
.5881 .3364 Mdot
.59167 .56063 Mdot
.67136 .62253 Mdot
.62718 .35675 Mdot
.18542 .61287 Mdot
.38549 .61834 Mdot
.42182 .38849 Mdot
.63266 .52866 Mdot
.64406 .6117 Mdot
.80954 .31973 Mdot
.33604 .47306 Mdot
.31954 .44032 Mdot
.26937 .56319 Mdot
.38511 .76852 Mdot
.39585 .59955 Mdot
.69141 .74996 Mdot
.78198 .6311 Mdot
.56769 .54348 Mdot
.52478 .51 Mdot
.4818 .21902 Mdot
.42359 .34102 Mdot
.44432 .18841 Mdot
.6104 .53676 Mdot
.61638 .56235 Mdot
.30902 .4994 Mdot
.27286 .46057 Mdot
.83429 .50967 Mdot
.54935 .31941 Mdot
.39402 .6729 Mdot
.57643 .38839 Mdot
.65263 .57024 Mdot
.45405 .48877 Mdot
.35752 .46966 Mdot
.44082 .63253 Mdot
.58411 .55114 Mdot
.66228 .28624 Mdot
.447 .28084 Mdot
.40846 .37808 Mdot
.35581 .49995 Mdot
.81501 .54913 Mdot
.57876 .53774 Mdot
.38983 .3857 Mdot
.58688 .57053 Mdot
.40229 .59457 Mdot
.54425 .52843 Mdot
.41099 .67012 Mdot
.64479 .58646 Mdot
.36647 .59563 Mdot
.87584 .4427 Mdot
.4023 .70143 Mdot
.56634 .40134 Mdot
.33624 .46561 Mdot
.33039 .53623 Mdot
.62457 .36049 Mdot
.32706 .5292 Mdot
.73278 .42379 Mdot
.74484 .61478 Mdot
.39466 .66561 Mdot
.5349 .59788 Mdot
.40285 .66107 Mdot
.31895 .48332 Mdot
.61625 .54037 Mdot
.21443 .69362 Mdot
.32126 .50743 Mdot
.80281 .60679 Mdot
.41717 .36194 Mdot
.3523 .46747 Mdot
.63636 .60627 Mdot
.43451 .29759 Mdot
.37021 .54168 Mdot
.31521 .42909 Mdot
.57166 .58262 Mdot
.58116 .3392 Mdot
.62798 .60296 Mdot
.64237 .5405 Mdot
.37808 .48352 Mdot
.63628 .56161 Mdot
.402 .38811 Mdot
.54531 .35212 Mdot
.55903 .82444 Mdot
.35549 .26209 Mdot
.56488 .5673 Mdot
.61123 .57024 Mdot
.64059 .34792 Mdot
.63128 .62201 Mdot
.4502 .35251 Mdot
.12886 .38807 Mdot
.39612 .66307 Mdot
.38114 .4748 Mdot
.34711 .59203 Mdot
.66393 .57655 Mdot
.63808 .55523 Mdot
.36517 .83292 Mdot
.56089 .75768 Mdot
.41422 .39176 Mdot
.56545 .62317 Mdot
.3531 .55316 Mdot
.40477 .63729 Mdot
.43411 .33024 Mdot
.60493 .58538 Mdot
.60736 .55099 Mdot
.38689 .67643 Mdot
.46874 .65029 Mdot
.80301 .40409 Mdot
.40275 .39979 Mdot
.64779 .51953 Mdot
.32626 .57055 Mdot
.56604 .6095 Mdot
.75609 .34275 Mdot
.61496 .37182 Mdot
.44458 .34841 Mdot
.40504 .77106 Mdot
.57482 .53978 Mdot
.41853 .39517 Mdot
.41409 .34645 Mdot
.54392 .58208 Mdot
.57039 .32375 Mdot
.54403 .35766 Mdot
.61177 .34079 Mdot
.37026 .16615 Mdot
.51479 .71598 Mdot
.3698 .50314 Mdot
.4236 .34373 Mdot
.31123 .51431 Mdot
.40536 .7058 Mdot
.46782 .53587 Mdot
.31156 .50798 Mdot
.59842 .33402 Mdot
.36721 .46863 Mdot
.58718 .59888 Mdot
.41182 .34857 Mdot
.36494 .5057 Mdot
.64929 .5497 Mdot
.54696 .3053 Mdot
.24152 .41076 Mdot
.421 .67615 Mdot
.37413 .63924 Mdot
.6246 .61206 Mdot
.3231 .55282 Mdot
.60804 .54493 Mdot
.39019 .35971 Mdot
.5582 .28928 Mdot
.63933 .53853 Mdot
.32751 .52248 Mdot
.63741 .34344 Mdot
.8169 .54132 Mdot
.63034 .6359 Mdot
.59114 .55667 Mdot
.63634 .56834 Mdot
.58639 .57109 Mdot
.2835 .7119 Mdot
.43093 .39872 Mdot
.3094 .28579 Mdot
.40323 .75663 Mdot
.58437 .36159 Mdot
.61234 .39323 Mdot
.83576 .45112 Mdot
.4752 .22686 Mdot
.42477 .34708 Mdot
.62554 .5855 Mdot
.44541 .26208 Mdot
.44341 .84882 Mdot
.25902 .72392 Mdot
.65938 .50171 Mdot
.33497 .4722 Mdot
.5643 .33312 Mdot
.31952 .5243 Mdot
.63177 .56908 Mdot
.54447 .55261 Mdot
.73668 .72271 Mdot
.41322 .33458 Mdot
.39759 .67155 Mdot
.63816 .57482 Mdot
.51049 .71872 Mdot
.35019 .50504 Mdot
.3532 .4671 Mdot
.59533 .6161 Mdot
.63604 .35267 Mdot
.86657 .43797 Mdot
.41593 .37967 Mdot
.29627 .31428 Mdot
.40014 .2194 Mdot
.47341 .30571 Mdot
.41034 .37332 Mdot
.57726 .45619 Mdot
.32498 .48089 Mdot
.79677 .45818 Mdot
.58628 .36797 Mdot
.41918 .64031 Mdot
.60659 .50712 Mdot
.6189 .37521 Mdot
.37203 .49219 Mdot
.57354 .34014 Mdot
.6383 .55351 Mdot
.41329 .41476 Mdot
.3516 .5152 Mdot
.36748 .31471 Mdot
.60929 .32271 Mdot
.38304 .64642 Mdot
.4849 .39936 Mdot
.70699 .54987 Mdot
.74203 .47166 Mdot
.5897 .61613 Mdot
.45154 .49821 Mdot
.60638 .59937 Mdot
.63474 .38015 Mdot
.5984 .57111 Mdot
.63737 .32449 Mdot
.35926 .50894 Mdot
.64926 .59444 Mdot
.61959 .59025 Mdot
.25456 .29826 Mdot
.56906 .56999 Mdot
.56313 .61161 Mdot
.60772 .58081 Mdot
.65518 .34933 Mdot
.53908 .61275 Mdot
.56141 .37432 Mdot
.25013 .56449 Mdot
.33636 .51015 Mdot
.41048 .6279 Mdot
.39352 .68443 Mdot
.55158 .7243 Mdot
.34759 .63542 Mdot
.25407 .47186 Mdot
.60308 .34204 Mdot
.3944 .38145 Mdot
.59317 .57182 Mdot
.64735 .78126 Mdot
.30068 .55712 Mdot
.36419 .47474 Mdot
.35694 .26268 Mdot
.59326 .49523 Mdot
.64186 .7508 Mdot
.55771 .6149 Mdot
.43075 .16216 Mdot
.66558 .60934 Mdot
.59411 .50151 Mdot
.33928 .55268 Mdot
.44874 .67071 Mdot
.6299 .6201 Mdot
.56457 .38929 Mdot
.41914 .65496 Mdot
.65271 .51323 Mdot
.39823 .5338 Mdot
.26521 .50235 Mdot
.63128 .30542 Mdot
.5801 .58848 Mdot
.35071 .5161 Mdot
.56631 .36941 Mdot
.84198 .4651 Mdot
.41199 .3835 Mdot
.40445 .47987 Mdot
.55897 .23714 Mdot
.19072 .6077 Mdot
.39352 .63283 Mdot
.76617 .39834 Mdot
.58343 .60315 Mdot
.2635 .65074 Mdot
.63373 .53098 Mdot
.3798 .82256 Mdot
.38354 .68183 Mdot
.59212 .33199 Mdot
.4024 .39252 Mdot
.58418 .39504 Mdot
.73093 .46204 Mdot
.38529 .55424 Mdot
.48378 .46654 Mdot
.34146 .4979 Mdot
.50151 .50611 Mdot
.60998 .36273 Mdot
.62135 .53454 Mdot
.58721 .1531 Mdot
.61943 .3673 Mdot
.60886 .32552 Mdot
.19442 .40677 Mdot
.19321 .65616 Mdot
.67318 .57559 Mdot
.59951 .32768 Mdot
.33604 .49987 Mdot
.41453 .65719 Mdot
.64171 .59561 Mdot
.57842 .59222 Mdot
.6147 .37756 Mdot
.38372 .49052 Mdot
.67345 .46443 Mdot
.34082 .53513 Mdot
.58609 .33396 Mdot
.33999 .52291 Mdot
.47164 .34279 Mdot
.33759 .48656 Mdot
.64423 .61202 Mdot
.597 .57136 Mdot
.3115 .59916 Mdot
.57935 .34255 Mdot
.61374 .59081 Mdot
.5515 .55466 Mdot
.59523 .35464 Mdot
.55242 .46876 Mdot
.68265 .465 Mdot
.55806 .58172 Mdot
.56863 .57856 Mdot
.39978 .68612 Mdot
.46524 .51815 Mdot
.76022 .37407 Mdot
.64245 .56376 Mdot
.40431 .69187 Mdot
.55864 .38012 Mdot
.59601 .54217 Mdot
.43492 .82555 Mdot
.31071 .37862 Mdot
.60939 .53279 Mdot
.31933 .52803 Mdot
.57912 .63338 Mdot
.73584 .69178 Mdot
.61437 .62043 Mdot
.60304 .35327 Mdot
.56732 .35351 Mdot
.31707 .24064 Mdot
.60131 .36822 Mdot
.37736 .52385 Mdot
.4105 .36899 Mdot
.27944 .71944 Mdot
.33075 .54255 Mdot
.65568 .62736 Mdot
.20721 .33103 Mdot
.57015 .53331 Mdot
.65994 .58486 Mdot
.83202 .56524 Mdot
.31895 .51712 Mdot
.57917 .38131 Mdot
.49466 .4001 Mdot
.67523 .60689 Mdot
.44312 .34983 Mdot
.56172 .51924 Mdot
.60468 .62118 Mdot
.75609 .6661 Mdot
.29004 .71345 Mdot
.38882 .38803 Mdot
.56425 .61193 Mdot
.64095 .56042 Mdot
.2991 .51649 Mdot
.60908 .5736 Mdot
.41346 .66205 Mdot
.57756 .37032 Mdot
.32854 .4889 Mdot
.39673 .64482 Mdot
.58665 .5345 Mdot
.39495 .67727 Mdot
.3651 .51657 Mdot
.3959 .35035 Mdot
.62663 .55719 Mdot
.43169 .65486 Mdot
.39366 .67452 Mdot
.6063 .59718 Mdot
.56326 .34412 Mdot
.5873 .49184 Mdot
.57016 .56626 Mdot
.64909 .57728 Mdot
.60001 .38174 Mdot
.5571 .87495 Mdot
.61788 .61636 Mdot
.53324 .74255 Mdot
.62437 .37327 Mdot
.51844 .49175 Mdot
.32876 .54508 Mdot
.61608 .62361 Mdot
.39558 .35045 Mdot
.3932 .35952 Mdot
.35801 .4781 Mdot
.56994 .32882 Mdot
.2754 .56332 Mdot
.53936 .34748 Mdot
.61811 .64828 Mdot
.57329 .61972 Mdot
.60396 .45058 Mdot
.6241 .79526 Mdot
.59606 .39242 Mdot
.39811 .55063 Mdot
.55145 .31165 Mdot
.39182 .38253 Mdot
.3784 .48821 Mdot
.54335 .3515 Mdot
.59354 .38551 Mdot
.55495 .34836 Mdot
.42047 .64078 Mdot
.31535 .60257 Mdot
.62772 .37384 Mdot
.63647 .36216 Mdot
.57282 .58956 Mdot
.64404 .56938 Mdot
.79364 .59165 Mdot
.78286 .5855 Mdot
.40905 .68249 Mdot
.37391 .50977 Mdot
.34327 .16784 Mdot
.40247 .34156 Mdot
.27322 .29915 Mdot
.65785 .58302 Mdot
.39622 .12892 Mdot
.63829 .60211 Mdot
.61478 .5743 Mdot
.54346 .35497 Mdot
.43028 .65913 Mdot
.39979 .6614 Mdot
.61807 .36368 Mdot
.63273 .37702 Mdot
.41216 .66354 Mdot
.19391 .49368 Mdot
.45833 .83931 Mdot
.31293 .45547 Mdot
.58862 .35232 Mdot
.72939 .60039 Mdot
.41086 .40041 Mdot
.688 .57416 Mdot
.3979 .40912 Mdot
.34426 .50428 Mdot
.3287 .48195 Mdot
.4448 .35613 Mdot
.57264 .57923 Mdot
.36658 .49855 Mdot
.57488 .53557 Mdot
.2423 .37895 Mdot
.73753 .50265 Mdot
.29981 .57015 Mdot
.69527 .61582 Mdot
.55673 .46419 Mdot
.36394 .31778 Mdot
.59311 .53621 Mdot
.40708 .79778 Mdot
.39492 .6705 Mdot
.6322 .64979 Mdot
.44221 .34393 Mdot
.82623 .58873 Mdot
.62279 .54805 Mdot
.60043 .35 Mdot
.4166 .34464 Mdot
.57666 .23055 Mdot
.55098 .25674 Mdot
.63674 .57139 Mdot
.52746 .14886 Mdot
.64029 .38938 Mdot
.35139 .49195 Mdot
.65073 .27323 Mdot
.61565 .38836 Mdot
.38549 .60385 Mdot
.43449 .7825 Mdot
.21912 .65826 Mdot
.57389 .37692 Mdot
.31203 .4879 Mdot
.55481 .36868 Mdot
.38823 .6391 Mdot
.56873 .40151 Mdot
.35466 .50829 Mdot
.58774 .55029 Mdot
.33349 .53366 Mdot
.42339 .64581 Mdot
.8036 .41563 Mdot
.38895 .38811 Mdot
.38238 .52708 Mdot
.43402 .36884 Mdot
.44398 .72675 Mdot
.50753 .7742 Mdot
.42707 .38566 Mdot
.67201 .41592 Mdot
.57911 .62265 Mdot
.62245 .38286 Mdot
.34086 .54336 Mdot
.34761 .7152 Mdot
.49511 .38536 Mdot
.58994 .37005 Mdot
.37213 .49707 Mdot
.57357 .2648 Mdot
.65014 .39971 Mdot
.56636 .61632 Mdot
.48125 .63161 Mdot
.59059 .35536 Mdot
.31056 .49303 Mdot
.81454 .38239 Mdot
.55674 .37234 Mdot
.3528 .55149 Mdot
.41056 .39575 Mdot
.40406 .35914 Mdot
.56597 .60055 Mdot
.44225 .39904 Mdot
.35714 .48323 Mdot
.37182 .35685 Mdot
.59513 .32677 Mdot
.60275 .24092 Mdot
.42934 .63789 Mdot
.33404 .51854 Mdot
.5834 .52442 Mdot
.63761 .38175 Mdot
.32086 .33198 Mdot
.68906 .48165 Mdot
.63719 .20226 Mdot
.33846 .53837 Mdot
.58193 .37486 Mdot
.59764 .34726 Mdot
.63242 .63672 Mdot
.59348 .2709 Mdot
.27472 .5715 Mdot
.59067 .45506 Mdot
.5382 .42193 Mdot
.32636 .54843 Mdot
.38328 .46138 Mdot
.56889 .51776 Mdot
.58074 .58252 Mdot
.39343 .38714 Mdot
.58624 .55339 Mdot
.57131 .33216 Mdot
.58975 .61538 Mdot
.42683 .37915 Mdot
.34064 .49441 Mdot
.62346 .55257 Mdot
.39096 .67379 Mdot
.43604 .39406 Mdot
.40974 .33164 Mdot
.32998 .51751 Mdot
.61465 .37827 Mdot
.50927 .50933 Mdot
.34753 .53746 Mdot
.5793 .58764 Mdot
.45341 .53871 Mdot
.63759 .55003 Mdot
.51141 .54654 Mdot
.56179 .37962 Mdot
.32721 .49018 Mdot
.53876 .36677 Mdot
.42755 .3668 Mdot
.40579 .75951 Mdot
.59511 .5633 Mdot
.34666 .55101 Mdot
.34447 .34922 Mdot
.5023 .555 Mdot
.62194 .32662 Mdot
.22184 .46988 Mdot
.61667 .39308 Mdot
.37355 .51605 Mdot
.22516 .33641 Mdot
.40968 .63344 Mdot
.36123 .47259 Mdot
.58158 .81302 Mdot
.32322 .50976 Mdot
.57323 .60605 Mdot
.62036 .61262 Mdot
.33548 .48719 Mdot
.39215 .68149 Mdot
.84265 .50423 Mdot
.35646 .4534 Mdot
.57713 .37839 Mdot
.21119 .41656 Mdot
.71311 .25394 Mdot
.38461 .31106 Mdot
.39341 .38394 Mdot
.67597 .57866 Mdot
.59822 .62669 Mdot
.43686 .33813 Mdot
.38687 .3895 Mdot
.39598 .62651 Mdot
.3562 .54555 Mdot
.64406 .3739 Mdot
.42042 .32204 Mdot
.61792 .28862 Mdot
.34285 .62198 Mdot
.6273 .63581 Mdot
.39002 .22581 Mdot
.6565 .58081 Mdot
.472 .76744 Mdot
.43002 .37882 Mdot
.62241 .52868 Mdot
.57098 .62376 Mdot
.41993 .33798 Mdot
.41573 .65678 Mdot
.40401 .48278 Mdot
.34326 .52141 Mdot
.56393 .8637 Mdot
.56129 .54939 Mdot
.58552 .61162 Mdot
.4334 .34809 Mdot
.27402 .63235 Mdot
.58099 .36213 Mdot
.59643 .39913 Mdot
.34678 .48642 Mdot
.45993 .41926 Mdot
.57776 .61626 Mdot
.59022 .54109 Mdot
.34992 .52237 Mdot
.38203 .51433 Mdot
.25671 .45286 Mdot
.60379 .60591 Mdot
.42292 .35259 Mdot
.43579 .69793 Mdot
.43578 .3761 Mdot
.63198 .54148 Mdot
.58871 .61078 Mdot
.64504 .61185 Mdot
.59851 .52339 Mdot
.40229 .41552 Mdot
.63946 .54599 Mdot
.53677 .58734 Mdot
.58453 .37355 Mdot
.64136 .57468 Mdot
.52458 .40872 Mdot
.58292 .56057 Mdot
.41358 .65975 Mdot
.73715 .35028 Mdot
.62324 .54908 Mdot
.59594 .6183 Mdot
.37472 .46937 Mdot
.60399 .55525 Mdot
.39189 .3545 Mdot
.58056 .34785 Mdot
.42725 .34618 Mdot
.39222 .36171 Mdot
.30706 .51843 Mdot
.37658 .66219 Mdot
.66426 .57209 Mdot
.42082 .6667 Mdot
.65688 .63094 Mdot
.57378 .54065 Mdot
.3524 .65925 Mdot
.40824 .16495 Mdot
.78398 .37149 Mdot
.59302 .56373 Mdot
.31945 .51237 Mdot
.31869 .52334 Mdot
.53975 .49306 Mdot
.55368 .59791 Mdot
.44527 .33459 Mdot
.39064 .3785 Mdot
.72343 .66209 Mdot
.63517 .72164 Mdot
.41414 .65931 Mdot
.4693 .50065 Mdot
.55684 .5698 Mdot
.61955 .52845 Mdot
.55957 .54707 Mdot
.31138 .50515 Mdot
.69779 .55409 Mdot
.3728 .48191 Mdot
.40857 .27284 Mdot
.44147 .35885 Mdot
.63088 .56029 Mdot
.36823 .24285 Mdot
.62001 .34404 Mdot
.58076 .34702 Mdot
.41841 .32793 Mdot
.32888 .56666 Mdot
.81554 .53369 Mdot
.26196 .7344 Mdot
.58575 .4139 Mdot
.42835 .65073 Mdot
.58322 .54087 Mdot
.332 .49642 Mdot
.58095 .33342 Mdot
.42793 .65178 Mdot
.62388 .5398 Mdot
.31722 .60338 Mdot
.58571 .56725 Mdot
.45292 .22331 Mdot
.55731 .35689 Mdot
.4124 .8396 Mdot
.57295 .32694 Mdot
.44502 .3882 Mdot
.44734 .34825 Mdot
.60323 .60995 Mdot
.60219 .42731 Mdot
.61572 .39026 Mdot
.41308 .56092 Mdot
.37827 .65108 Mdot
.40564 .29289 Mdot
.40642 .63567 Mdot
.35718 .49877 Mdot
.41782 .64389 Mdot
.35655 .50962 Mdot
.81545 .51893 Mdot
.65545 .32657 Mdot
.39476 .65276 Mdot
.34819 .33805 Mdot
.60386 .62689 Mdot
.41094 .68323 Mdot
.54466 .55415 Mdot
.52642 .52112 Mdot
.34914 .52546 Mdot
.3809 .64641 Mdot
.61427 .52935 Mdot
.68525 .74389 Mdot
.41924 .39011 Mdot
.44674 .33817 Mdot
.54503 .55439 Mdot
.31893 .54112 Mdot
.55105 .37457 Mdot
.34846 .78012 Mdot
.43766 .31841 Mdot
.61265 .61455 Mdot
.63046 .62097 Mdot
.61951 .38992 Mdot
.31739 .25821 Mdot
.59345 .60799 Mdot
.52794 .6141 Mdot
.60628 .60784 Mdot
.44165 .38057 Mdot
.58102 .3933 Mdot
.59022 .34602 Mdot
.37123 .49735 Mdot
.62051 .33963 Mdot
.48026 .60633 Mdot
.39318 .2524 Mdot
.54894 .51917 Mdot
.42353 .36974 Mdot
.43737 .27396 Mdot
.39527 .27049 Mdot
.58661 .79942 Mdot
.60652 .32103 Mdot
.64065 .54173 Mdot
.62406 .34068 Mdot
.40913 .63988 Mdot
.58518 .33948 Mdot
.56393 .3334 Mdot
.60707 .54173 Mdot
.63433 .57454 Mdot
.34541 .49256 Mdot
.58357 .27356 Mdot
.61877 .37769 Mdot
.63764 .60168 Mdot
.63467 .62534 Mdot
.57792 .53091 Mdot
.42388 .5683 Mdot
.58933 .393 Mdot
.171 .47779 Mdot
.56197 .68761 Mdot
.6175 .37832 Mdot
.86642 .468 Mdot
.33735 .34359 Mdot
.38531 .5501 Mdot
.414 .52228 Mdot
.61028 .6077 Mdot
.37317 .53977 Mdot
.63139 .56817 Mdot
.39159 .22658 Mdot
.61085 .55537 Mdot
.41432 .66266 Mdot
.5676 .54342 Mdot
.33885 .47694 Mdot
.34092 .53658 Mdot
.60816 .61601 Mdot
.62392 .55617 Mdot
.81734 .43577 Mdot
.5573 .39553 Mdot
.57355 .34655 Mdot
.27451 .55069 Mdot
.39003 .65174 Mdot
.4443 .34957 Mdot
.60347 .57675 Mdot
.3077 .51514 Mdot
.33887 .53625 Mdot
.60476 .39242 Mdot
.36496 .52486 Mdot
.41436 .37891 Mdot
.59826 .56542 Mdot
.44037 .33799 Mdot
.41569 .63421 Mdot
.58271 .39262 Mdot
.63962 .57352 Mdot
.5725 .58922 Mdot
.56735 .35384 Mdot
.63805 .5317 Mdot
.39155 .67924 Mdot
.32359 .51627 Mdot
.57233 .37679 Mdot
.40806 .36576 Mdot
.35751 .50138 Mdot
.65016 .57304 Mdot
.49204 .15425 Mdot
.56718 .59717 Mdot
.62091 .60554 Mdot
.61728 .8095 Mdot
.5581 .56396 Mdot
.34029 .54129 Mdot
.58494 .33226 Mdot
.62814 .65715 Mdot
.54113 .70776 Mdot
.51043 .89638 Mdot
.36941 .47918 Mdot
.57892 .54694 Mdot
.62194 .7798 Mdot
.57993 .54975 Mdot
.70048 .51702 Mdot
.38581 .5264 Mdot
.52966 .44962 Mdot
.59786 .5196 Mdot
.39911 .37363 Mdot
.33735 .49007 Mdot
.35915 .51304 Mdot
.2286 .3841 Mdot
.6007 .53944 Mdot
.43796 .51046 Mdot
.62987 .54471 Mdot
.40564 .3673 Mdot
.66092 .69513 Mdot
.34192 .5386 Mdot
.68138 .2465 Mdot
.60498 .60033 Mdot
.59563 .38765 Mdot
.36187 .46632 Mdot
.47487 .33741 Mdot
.64913 .58167 Mdot
.40852 .67728 Mdot
.38426 .35956 Mdot
.54618 .52898 Mdot
.42075 .3719 Mdot
.64823 .57461 Mdot
.66469 .65396 Mdot
.57974 .20939 Mdot
.55944 .34539 Mdot
.40129 .39279 Mdot
.44996 .55524 Mdot
.63706 .53961 Mdot
.57298 .37559 Mdot
.58718 .36943 Mdot
.41949 .63726 Mdot
.50287 .48245 Mdot
.52953 .23441 Mdot
.7424 .54917 Mdot
.21803 .40078 Mdot
.37217 .4728 Mdot
.30171 .44434 Mdot
.62387 .59877 Mdot
.47125 .61388 Mdot
.39031 .36099 Mdot
.56509 .59409 Mdot
.76206 .40276 Mdot
.62206 .35321 Mdot
.56864 .59414 Mdot
.40391 .66208 Mdot
.44009 .61467 Mdot
.44645 .68751 Mdot
.48758 .80052 Mdot
.34224 .49926 Mdot
.53816 .59666 Mdot
.62113 .66235 Mdot
.32839 .54651 Mdot
.65041 .61511 Mdot
.33823 .54577 Mdot
.19126 .53823 Mdot
.4191 .67741 Mdot
.58573 .39003 Mdot
.38234 .29954 Mdot
.66216 .59256 Mdot
.59188 .62276 Mdot
.37522 .65211 Mdot
.58408 .58521 Mdot
.52988 .18197 Mdot
.42258 .57328 Mdot
.36368 .50101 Mdot
.55613 .34737 Mdot
.64286 .61875 Mdot
.46998 .53709 Mdot
.5763 .55785 Mdot
.77773 .53684 Mdot
.59898 .6189 Mdot
.55804 .25158 Mdot
.55889 .35103 Mdot
.42691 .37314 Mdot
.62358 .5259 Mdot
.61345 .56285 Mdot
.5886 .73506 Mdot
.66408 .61707 Mdot
.62769 .53077 Mdot
.57646 .31613 Mdot
.55947 .34089 Mdot
.55694 .36929 Mdot
.36313 .47924 Mdot
.68822 .70739 Mdot
.42451 .35848 Mdot
.65832 .64652 Mdot
.44118 .32404 Mdot
.65104 .46687 Mdot
.42768 .65934 Mdot
.54807 .78761 Mdot
.61452 .58586 Mdot
.60442 .34039 Mdot
.3462 .75685 Mdot
.57869 .40122 Mdot
.4627 .48917 Mdot
.41244 .34712 Mdot
.61813 .3666 Mdot
.61562 .57032 Mdot
.52503 .33792 Mdot
.64541 .77431 Mdot
.43137 .35874 Mdot
.6533 .62814 Mdot
.34827 .47144 Mdot
.33835 .58751 Mdot
.61701 .21462 Mdot
.42256 .39005 Mdot
.44406 .31382 Mdot
.59791 .53815 Mdot
.61468 .33783 Mdot
.40164 .37289 Mdot
.44151 .37912 Mdot
.3675 .52042 Mdot
.63541 .57778 Mdot
.63533 .58239 Mdot
.37549 .51022 Mdot
.42929 .34692 Mdot
.53933 .5847 Mdot
.53942 .5335 Mdot
.78146 .67767 Mdot
.58041 .25151 Mdot
.57307 .86709 Mdot
.52293 .50721 Mdot
.73312 .37906 Mdot
.34972 .78549 Mdot
.60995 .38374 Mdot
.59675 .53108 Mdot
.60814 .5045 Mdot
.35717 .48285 Mdot
.5956 .55455 Mdot
.37107 .5553 Mdot
.40446 .34618 Mdot
.82295 .59057 Mdot
.48893 .28367 Mdot
.20002 .59816 Mdot
.597 .55276 Mdot
.62458 .32039 Mdot
.40693 .64339 Mdot
.41415 .30336 Mdot
.57187 .38926 Mdot
.57172 .52984 Mdot
.8147 .43148 Mdot
.36473 .47455 Mdot
.60085 .37603 Mdot
.84083 .47112 Mdot
.5667 .45528 Mdot
.63672 .54946 Mdot
.37409 .48891 Mdot
.38871 .79742 Mdot
.65448 .29933 Mdot
.45339 .336 Mdot
.41647 .65646 Mdot
.32965 .49057 Mdot
.3908 .38452 Mdot
.64909 .34127 Mdot
.60781 .37049 Mdot
.5614 .38698 Mdot
.77314 .3697 Mdot
.38883 .49448 Mdot
.40413 .64383 Mdot
.62828 .74465 Mdot
.61497 .72791 Mdot
.41077 .66588 Mdot
.32873 .48153 Mdot
.56656 .33658 Mdot
.61881 .35764 Mdot
.58096 .34833 Mdot
.74081 .31278 Mdot
.62166 .33421 Mdot
.23571 .34497 Mdot
.58595 .52664 Mdot
.52485 .55656 Mdot
.58174 .54496 Mdot
.44153 .33223 Mdot
.56517 .35922 Mdot
.48515 .40541 Mdot
.64004 .64145 Mdot
.54904 .77416 Mdot
.56953 .60393 Mdot
.42182 .40608 Mdot
.57495 .59839 Mdot
.39225 .20678 Mdot
.62853 .34957 Mdot
.59424 .56021 Mdot
.40444 .4085 Mdot
.38724 .65158 Mdot
.62 .32473 Mdot
.63652 .56889 Mdot
.2236 .50398 Mdot
.56191 .55474 Mdot
.20342 .58358 Mdot
.54324 .21316 Mdot
.42833 .65285 Mdot
.44602 .20385 Mdot
.31315 .48334 Mdot
.52325 .59037 Mdot
.67793 .61315 Mdot
.4326 .36487 Mdot
.40499 .29534 Mdot
.33599 .50763 Mdot
.67335 .51568 Mdot
.53246 .56768 Mdot
.41937 .63536 Mdot
.66028 .33918 Mdot
.43109 .33592 Mdot
.64508 .6197 Mdot
.58034 .62989 Mdot
.29287 .30774 Mdot
.53871 .55926 Mdot
.61995 .62275 Mdot
.37243 .65831 Mdot
.25766 .31865 Mdot
.57928 .56562 Mdot
.46716 .49321 Mdot
.56676 .40006 Mdot
.63 .64732 Mdot
.241 .33298 Mdot
.62368 .61212 Mdot
.60965 .37534 Mdot
.51691 .59174 Mdot
.50947 .22597 Mdot
.3771 .66567 Mdot
.59798 .61905 Mdot
.30542 .25057 Mdot
.59442 .59654 Mdot
.42047 .35598 Mdot
.55601 .60096 Mdot
.35228 .50719 Mdot
.78565 .36452 Mdot
.36692 .49337 Mdot
.56126 .59841 Mdot
.58325 .35063 Mdot
.43751 .35295 Mdot
.70591 .29365 Mdot
.29203 .60223 Mdot
.28796 .29246 Mdot
.2679 .72825 Mdot
.37883 .65782 Mdot
.43744 .66218 Mdot
.41401 .33599 Mdot
.59219 .56072 Mdot
.19685 .38193 Mdot
.67008 .60006 Mdot
.56817 .58206 Mdot
.6121 .55563 Mdot
.49992 .77291 Mdot
.39569 .35535 Mdot
.34693 .53096 Mdot
.59086 .60914 Mdot
.63487 .53898 Mdot
.6041 .38518 Mdot
.38933 .66148 Mdot
.32765 .54361 Mdot
.39577 .66584 Mdot
.33388 .49208 Mdot
.84614 .5323 Mdot
.54761 .60247 Mdot
.38686 .64725 Mdot
.39862 .33526 Mdot
.60709 .38027 Mdot
.40388 .25341 Mdot
.36003 .50687 Mdot
.36406 .48324 Mdot
.60663 .61798 Mdot
.6154 .3734 Mdot
.54062 .3597 Mdot
.40068 .63545 Mdot
.42192 .38478 Mdot
.62239 .54814 Mdot
.56708 .55111 Mdot
.63552 .67178 Mdot
.313 .53504 Mdot
.44244 .22254 Mdot
.26885 .47371 Mdot
.59107 .56325 Mdot
.59412 .32717 Mdot
.61943 .55361 Mdot
.24969 .66096 Mdot
.61879 .34032 Mdot
.62931 .60969 Mdot
.85539 .42061 Mdot
.36843 .56922 Mdot
.47868 .24495 Mdot
.63366 .6174 Mdot
.34522 .80316 Mdot
.61959 .59374 Mdot
.83075 .58897 Mdot
.32587 .71694 Mdot
.56906 .61325 Mdot
.65038 .58518 Mdot
.71627 .48465 Mdot
.57446 .54667 Mdot
.37561 .50332 Mdot
.79174 .61225 Mdot
.5691 .39644 Mdot
.38567 .27951 Mdot
.74275 .36232 Mdot
.38079 .67574 Mdot
.34655 .48646 Mdot
.39212 .48209 Mdot
.40373 .66986 Mdot
.59138 .352 Mdot
.58641 .57129 Mdot
.45105 .44602 Mdot
.31524 .53335 Mdot
.61715 .48716 Mdot
.41861 .35453 Mdot
.29412 .38259 Mdot
.45232 .61074 Mdot
.4177 .37412 Mdot
.64222 .57773 Mdot
.7022 .47745 Mdot
.80708 .50881 Mdot
.50205 .84462 Mdot
.39369 .39309 Mdot
.43327 .35837 Mdot
.76533 .33503 Mdot
.41231 .62382 Mdot
.29251 .31322 Mdot
.55599 .25498 Mdot
.44133 .35062 Mdot
.65262 .37894 Mdot
.37903 .51346 Mdot
.43834 .41286 Mdot
.58688 .64551 Mdot
.58276 .5319 Mdot
.61458 .56811 Mdot
.43116 .38194 Mdot
.50576 .54181 Mdot
.6336 .24864 Mdot
.43606 .36867 Mdot
.66997 .54295 Mdot
.507 .44974 Mdot
.35521 .41538 Mdot
.35947 .5349 Mdot
.37933 .64382 Mdot
.42846 .63052 Mdot
.5875 .38499 Mdot
.37709 .65184 Mdot
.45635 .62769 Mdot
.58976 .58178 Mdot
.44073 .36962 Mdot
.34602 .30847 Mdot
.40714 .35907 Mdot
.40085 .66719 Mdot
.40026 .62405 Mdot
.58424 .37268 Mdot
.5755 .34282 Mdot
.71654 .40859 Mdot
.49691 .65229 Mdot
.56612 .57153 Mdot
.35783 .71238 Mdot
.55476 .33979 Mdot
.58183 .47508 Mdot
.37808 .64564 Mdot
.38853 .65351 Mdot
.57574 .74144 Mdot
.61615 .58306 Mdot
.61495 .46002 Mdot
.61121 .58029 Mdot
.59954 .68885 Mdot
.65415 .59213 Mdot
.36715 .52144 Mdot
.62459 .58647 Mdot
.57689 .74812 Mdot
.65598 .54997 Mdot
.60219 .63047 Mdot
.30942 .50927 Mdot
.5323 .55187 Mdot
.35095 .50841 Mdot
.55978 .58716 Mdot
.43167 .66521 Mdot
.34802 .48441 Mdot
.52712 .71529 Mdot
.55114 .7454 Mdot
.3248 .48287 Mdot
.42429 .65669 Mdot
.39351 .68762 Mdot
.49442 .73312 Mdot
.57247 .39 Mdot
.68115 .5791 Mdot
.5924 .55811 Mdot
.38291 .49703 Mdot
.39188 .37269 Mdot
.65308 .58001 Mdot
.61552 .6259 Mdot
.64143 .60832 Mdot
.58889 .38614 Mdot
.27758 .57623 Mdot
.38643 .64382 Mdot
.37681 .51005 Mdot
.50291 .5162 Mdot
.32472 .5482 Mdot
.59349 .63634 Mdot
.61546 .50768 Mdot
.75271 .38213 Mdot
.34997 .39232 Mdot
.73741 .30087 Mdot
.60598 .37122 Mdot
.31803 .52451 Mdot
.43195 .64203 Mdot
.63332 .51809 Mdot
.60522 .33934 Mdot
.35419 .50852 Mdot
.58657 .56717 Mdot
.65423 .62314 Mdot
.37818 .26432 Mdot
.45343 .68631 Mdot
.54164 .73536 Mdot
.35552 .47683 Mdot
.33357 .47201 Mdot
.53748 .7576 Mdot
.43711 .68639 Mdot
.49135 .39158 Mdot
.59411 .54426 Mdot
.40724 .67701 Mdot
.58631 .33329 Mdot
.78063 .39527 Mdot
.44868 .36479 Mdot
.59206 .27239 Mdot
.59783 .55421 Mdot
.54586 .46108 Mdot
.58257 .35233 Mdot
.40644 .66246 Mdot
.43457 .38028 Mdot
.42978 .62181 Mdot
.31301 .51491 Mdot
.20726 .65206 Mdot
.58795 .5929 Mdot
.60221 .61783 Mdot
.41735 .40334 Mdot
.61668 .34491 Mdot
.38723 .69027 Mdot
.21116 .42723 Mdot
.36289 .51715 Mdot
.203 .36565 Mdot
.59746 .32837 Mdot
.72784 .59433 Mdot
.36866 .5308 Mdot
.42594 .32297 Mdot
.50351 .72217 Mdot
.41961 .37874 Mdot
.56768 .60636 Mdot
.60237 .34441 Mdot
.39803 .38921 Mdot
.6022 .26089 Mdot
.65648 .78269 Mdot
.73002 .59124 Mdot
.59346 .57801 Mdot
.729 .71715 Mdot
.20599 .54106 Mdot
.58195 .41454 Mdot
.38903 .37248 Mdot
.56514 .59631 Mdot
.59462 .62073 Mdot
.59228 .59695 Mdot
.3943 .3704 Mdot
.35974 .71001 Mdot
.35204 .52489 Mdot
.59023 .53886 Mdot
.39828 .62622 Mdot
.34478 .5073 Mdot
.46006 .32886 Mdot
.35403 .53743 Mdot
.57772 .32058 Mdot
.61315 .63908 Mdot
.46891 .31864 Mdot
.86895 .38534 Mdot
.4307 .35199 Mdot
.30658 .51094 Mdot
.54526 .58623 Mdot
.31865 .37007 Mdot
.54904 .36115 Mdot
.36499 .51561 Mdot
.58338 .61143 Mdot
.35206 .3284 Mdot
.79817 .40042 Mdot
.34853 .5393 Mdot
.60448 .33807 Mdot
.50962 .84145 Mdot
.59035 .55276 Mdot
.60951 .59293 Mdot
.61416 .36626 Mdot
.64954 .41731 Mdot
.82218 .406 Mdot
.62242 .55561 Mdot
.42825 .37397 Mdot
.16349 .57807 Mdot
.61366 .6262 Mdot
.62063 .69792 Mdot
.34177 .49055 Mdot
.47443 .38854 Mdot
.48853 .21797 Mdot
.64924 .53511 Mdot
.2537 .36597 Mdot
.37941 .30756 Mdot
.67256 .7346 Mdot
.3667 .55976 Mdot
.2451 .57586 Mdot
.72055 .70502 Mdot
.40822 .41274 Mdot
.60123 .30803 Mdot
.23421 .39284 Mdot
.68473 .31158 Mdot
.43522 .8203 Mdot
.27136 .64935 Mdot
.81501 .42941 Mdot
.46738 .44117 Mdot
.3229 .50275 Mdot
.57536 .47035 Mdot
.63286 .56719 Mdot
.20749 .54792 Mdot
.58069 .21848 Mdot
.60158 .22874 Mdot
.72947 .71809 Mdot
.71257 .53542 Mdot
.62745 .77795 Mdot
.59599 .80296 Mdot
.65247 .68223 Mdot
.28763 .46144 Mdot
.19487 .37538 Mdot
.82245 .54996 Mdot
.18832 .46339 Mdot
.52646 .54826 Mdot
.45415 .48928 Mdot
.22288 .64208 Mdot
.64378 .31721 Mdot
.65413 .39144 Mdot
.37104 .50207 Mdot
.5673 .38863 Mdot
.27887 .33324 Mdot
.62138 .39051 Mdot
.50719 .22356 Mdot
.53516 .84644 Mdot
.64824 .78596 Mdot
.31977 .2485 Mdot
.3541 .80024 Mdot
.75418 .39862 Mdot
.17266 .35494 Mdot
.35747 .55686 Mdot
.60808 .39001 Mdot
.48548 .76533 Mdot
.59951 .74987 Mdot
.466 .29614 Mdot
.2152 .45403 Mdot
.34036 .60366 Mdot
.46005 .70825 Mdot
.59811 .34945 Mdot
.45803 .20601 Mdot
.45675 .39281 Mdot
.48292 .28755 Mdot
.80673 .5776 Mdot
.5125 .82482 Mdot
.43886 .45078 Mdot
.23397 .43492 Mdot
.30161 .40468 Mdot
.65486 .25338 Mdot
.54423 .69064 Mdot
.56337 .47466 Mdot
.57114 .24853 Mdot
.32171 .75966 Mdot
.68799 .36626 Mdot
.59468 .68488 Mdot
.61207 .74469 Mdot
.8491 .50804 Mdot
.22587 .59818 Mdot
.75535 .26814 Mdot
.61935 .39548 Mdot
.63282 .621 Mdot
.66334 .42573 Mdot
.27614 .27112 Mdot
.37613 .63182 Mdot
.46965 .80154 Mdot
.3879 .63407 Mdot
.56656 .32666 Mdot
.8049 .39117 Mdot
.25082 .32255 Mdot
.22923 .31061 Mdot
.43484 .66255 Mdot
.65703 .64875 Mdot
.33845 .83648 Mdot
.61597 .76528 Mdot
.4749 .26459 Mdot
.7858 .66723 Mdot
.51919 .43344 Mdot
.59478 .23743 Mdot
.39596 .38757 Mdot
.74533 .68542 Mdot
.61416 .35485 Mdot
.75498 .25333 Mdot
.83859 .57483 Mdot
.77831 .40922 Mdot
.85571 .67919 Mdot
.51858 .76586 Mdot
.53399 .45138 Mdot
.37885 .33245 Mdot
.50669 .68861 Mdot
.65288 .26935 Mdot
.40728 .74935 Mdot
.3145 .3804 Mdot
.33458 .80375 Mdot
.71097 .72027 Mdot
.2124 .33617 Mdot
.18441 .58953 Mdot
.68188 .33892 Mdot
.47263 .53054 Mdot
.69313 .60706 Mdot
.33354 .58121 Mdot
.45162 .80625 Mdot
.85706 .49707 Mdot
.56483 .68977 Mdot
.50273 .89722 Mdot
.40178 .70202 Mdot
.3288 .6272 Mdot
.58037 .84605 Mdot
.46923 .71381 Mdot
.49761 .2066 Mdot
.67999 .70148 Mdot
.6977 .57453 Mdot
.48193 .55791 Mdot
.468 .80642 Mdot
.43963 .24116 Mdot
.77617 .64153 Mdot
.38613 .80977 Mdot
.2965 .3047 Mdot
.74666 .51682 Mdot
.62202 .71518 Mdot
.64463 .35459 Mdot
.47794 .65317 Mdot
.50107 .21483 Mdot
.68013 .77157 Mdot
.42574 .40891 Mdot
.70771 .76274 Mdot
.82448 .41436 Mdot
.54404 .59877 Mdot
.67524 .55944 Mdot
.58883 .45066 Mdot
.47697 .66496 Mdot
.52802 .57682 Mdot
.35564 .27074 Mdot
.63834 .79666 Mdot
.79528 .5234 Mdot
.36306 .31468 Mdot
.39604 .29558 Mdot
.57601 .8527 Mdot
.68762 .43822 Mdot
.43514 .68476 Mdot
.77385 .62158 Mdot
.65971 .26926 Mdot
.33763 .51415 Mdot
.21986 .33263 Mdot
.41461 .31675 Mdot
.79229 .40203 Mdot
.73952 .54822 Mdot
.71368 .3469 Mdot
.63888 .79709 Mdot
.24979 .56121 Mdot
.8142 .41028 Mdot
.44396 .73576 Mdot
.18653 .42469 Mdot
.35519 .41046 Mdot
.57745 .51038 Mdot
.21496 .4672 Mdot
.39685 .68563 Mdot
.72597 .44897 Mdot
.1578 .52281 Mdot
.29618 .65209 Mdot
.55791 .52897 Mdot
.77785 .40406 Mdot
.39999 .52084 Mdot
.52281 .33951 Mdot
.67011 .2107 Mdot
.61589 .63244 Mdot
.63329 .73717 Mdot
.22877 .55096 Mdot
.50427 .67263 Mdot
.44328 .84181 Mdot
.2771 .70318 Mdot
.79046 .2978 Mdot
.76016 .68586 Mdot
.28198 .59618 Mdot
.70731 .70907 Mdot
.70533 .73988 Mdot
.79024 .30391 Mdot
.676 .5947 Mdot
.4489 .38392 Mdot
.46289 .1442 Mdot
.35911 .53671 Mdot
.60404 .75797 Mdot
.21809 .40042 Mdot
.43425 .60439 Mdot
.51823 .38456 Mdot
.65985 .50682 Mdot
.46409 .44855 Mdot
.55314 .39262 Mdot
.52885 .57658 Mdot
.73152 .27343 Mdot
.83226 .35602 Mdot
.75072 .27581 Mdot
.26993 .71737 Mdot
.74786 .67678 Mdot
.52884 .47281 Mdot
.29472 .26661 Mdot
.58492 .47796 Mdot
.60921 .52837 Mdot
.40341 .60456 Mdot
.51068 .7668 Mdot
.76413 .37382 Mdot
.51281 .28747 Mdot
.65913 .33196 Mdot
.46686 .80308 Mdot
.11398 .59183 Mdot
.73243 .41087 Mdot
.22027 .36767 Mdot
.44434 .65163 Mdot
.49566 .65611 Mdot
.41344 .78475 Mdot
.73826 .34559 Mdot
.60682 .80797 Mdot
.55317 .39165 Mdot
.19842 .44915 Mdot
.30192 .67779 Mdot
.5957 .30321 Mdot
.28212 .57985 Mdot
.60199 .78147 Mdot
.40821 .28355 Mdot
.71944 .31853 Mdot
.54587 .26735 Mdot
.67239 .41101 Mdot
.40699 .57492 Mdot
.28517 .40293 Mdot
.1698 .47582 Mdot
.2537 .6519 Mdot
.62128 .6946 Mdot
.49902 .45218 Mdot
.42652 .20469 Mdot
.36119 .34008 Mdot
.59059 .68936 Mdot
.51995 .40528 Mdot
.66469 .71743 Mdot
.74493 .207 Mdot
.68427 .23983 Mdot
.52688 .85605 Mdot
.37383 .73985 Mdot
.54813 .53236 Mdot
.58942 .81999 Mdot
.72423 .23926 Mdot
.87526 .45577 Mdot
.26591 .41475 Mdot
.35 .56189 Mdot
.43591 .32243 Mdot
.75962 .30895 Mdot
.35197 .68834 Mdot
.55695 .82212 Mdot
.59846 .70449 Mdot
.40288 .3351 Mdot
.37822 .16989 Mdot
.84159 .51961 Mdot
.73934 .57261 Mdot
.46052 .67382 Mdot
.59998 .51089 Mdot
.4787 .1881 Mdot
.61345 .39349 Mdot
.32282 .42762 Mdot
.50472 .65511 Mdot
.33385 .52374 Mdot
.45394 .77433 Mdot
.20789 .47069 Mdot
.56818 .54266 Mdot
.45877 .54588 Mdot
.62991 .33559 Mdot
.34885 .40157 Mdot
.4319 .26668 Mdot
.86676 .42638 Mdot
.44023 .62726 Mdot
.59057 .52047 Mdot
.51456 .67647 Mdot
.28352 .5726 Mdot
.81469 .38199 Mdot
.40793 .3373 Mdot
.69183 .73731 Mdot
.43992 .46842 Mdot
.48259 .64659 Mdot
.65522 .2911 Mdot
.54561 .50128 Mdot
.58777 .62689 Mdot
.31234 .74156 Mdot
.78847 .50941 Mdot
.57118 .29542 Mdot
.60536 .65246 Mdot
.60191 .48368 Mdot
.58126 .82314 Mdot
.44714 .62049 Mdot
.29675 .39048 Mdot
.67845 .75313 Mdot
.39936 .35892 Mdot
.62215 .33849 Mdot
.38201 .71124 Mdot
.18815 .4772 Mdot
.73192 .63051 Mdot
.79736 .39862 Mdot
.44994 .60126 Mdot
.30235 .64541 Mdot
.67469 .76365 Mdot
.67616 .7415 Mdot
.41352 .18585 Mdot
.62303 .40732 Mdot
.5315 .65098 Mdot
.18201 .47893 Mdot
.54631 .35435 Mdot
.27952 .30814 Mdot
.30659 .28981 Mdot
.83624 .55895 Mdot
.45228 .5466 Mdot
.34429 .81174 Mdot
.54073 .73211 Mdot
.43567 .7855 Mdot
.70388 .28935 Mdot
.18437 .44892 Mdot
.57754 .77636 Mdot
.57321 .41172 Mdot
.71908 .5024 Mdot
.54467 .52425 Mdot
.37119 .22861 Mdot
.45969 .15237 Mdot
.37546 .70326 Mdot
.54537 .42602 Mdot
.3928 .81477 Mdot
.57962 .58026 Mdot
.65005 .20801 Mdot
.2037 .46337 Mdot
.75703 .32664 Mdot
.41111 .329 Mdot
.64148 .56269 Mdot
.66527 .58703 Mdot
.73808 .66464 Mdot
.49819 .22558 Mdot
.67471 .71256 Mdot
.16922 .57868 Mdot
.40276 .80043 Mdot
.66407 .33012 Mdot
.6073 .75392 Mdot
.51483 .82711 Mdot
.21101 .55264 Mdot
.49469 .47969 Mdot
.40516 .75567 Mdot
.48413 .71303 Mdot
.33966 .78414 Mdot
.50949 .38141 Mdot
.40355 .46936 Mdot
.4006 .27547 Mdot
.2493 .51051 Mdot
.75191 .34338 Mdot
.64461 .58584 Mdot
.84081 .47205 Mdot
.57379 .80799 Mdot
.45194 .18459 Mdot
.59239 .20803 Mdot
.6897 .24291 Mdot
.77469 .51649 Mdot
.23326 .59612 Mdot
.2072 .5175 Mdot
.1597 .47322 Mdot
.43487 .46973 Mdot
.52235 .77981 Mdot
.46294 .72377 Mdot
.67625 .75959 Mdot
.42265 .40134 Mdot
.54117 .25254 Mdot
.37351 .29973 Mdot
.69417 .71178 Mdot
.69211 .44961 Mdot
.60574 .78969 Mdot
.50613 .42518 Mdot
.7943 .29841 Mdot
.27672 .68913 Mdot
.47986 .43449 Mdot
.31476 .50783 Mdot
.25068 .59062 Mdot
.51555 .80397 Mdot
.28811 .69675 Mdot
.19319 .42145 Mdot
.36997 .56593 Mdot
.49856 .53478 Mdot
.71358 .55624 Mdot
.4746 .65033 Mdot
.30902 .7415 Mdot
.51358 .67629 Mdot
.63721 .79001 Mdot
.75077 .66075 Mdot
.83951 .46835 Mdot
.52747 .767 Mdot
.25726 .71859 Mdot
.47495 .2617 Mdot
.46341 .65727 Mdot
.2054 .4658 Mdot
.33387 .64708 Mdot
.55821 .40106 Mdot
.45297 .09804 Mdot
.2099 .6483 Mdot
.24702 .63164 Mdot
.855 .50204 Mdot
.2762 .70828 Mdot
.34774 .39207 Mdot
.66351 .38926 Mdot
.58552 .26281 Mdot
.82692 .48985 Mdot
.6118 .55673 Mdot
.72097 .25485 Mdot
.49347 .6337 Mdot
.85857 .3829 Mdot
.55647 .82964 Mdot
.53974 .41905 Mdot
.60896 .63883 Mdot
.37804 .50117 Mdot
.43366 .50264 Mdot
.66894 .6855 Mdot
.66602 .45479 Mdot
.53625 .20774 Mdot
.35644 .36017 Mdot
.35742 .55533 Mdot
.28114 .55916 Mdot
.57263 .40787 Mdot
.37639 .73334 Mdot
.25763 .49333 Mdot
.29902 .5439 Mdot
.42751 .44942 Mdot
.54193 .6744 Mdot
.47886 .21608 Mdot
.7385 .5832 Mdot
.7421 .34682 Mdot
.45418 .30325 Mdot
.37102 .51943 Mdot
.74688 .56357 Mdot
.22208 .6488 Mdot
.388 .80108 Mdot
.85583 .49367 Mdot
.47908 .55486 Mdot
.68156 .47875 Mdot
.6402 .69738 Mdot
.62235 .23461 Mdot
.59911 .4324 Mdot
.35881 .39284 Mdot
.47679 .19054 Mdot
.62768 .42203 Mdot
.24544 .3836 Mdot
.82456 .58864 Mdot
.19117 .45966 Mdot
.18064 .47908 Mdot
.38475 .59188 Mdot
.59763 .66695 Mdot
.57994 .31318 Mdot
.53194 .72141 Mdot
.49712 .37982 Mdot
.22387 .29624 Mdot
.63192 .64994 Mdot
.2036 .2906 Mdot
.43754 .38526 Mdot
.67358 .31755 Mdot
.47977 .71966 Mdot
.5058 .45638 Mdot
.51185 .41663 Mdot
.25989 .66662 Mdot
.55159 .24698 Mdot
.22301 .58292 Mdot
.6294 .24978 Mdot
.3607 .55617 Mdot
.17352 .61384 Mdot
.27257 .74495 Mdot
.73136 .50601 Mdot
.55338 .56615 Mdot
.22133 .67281 Mdot
.34207 .55895 Mdot
.7558 .36393 Mdot
.45014 .84199 Mdot
.3592 .76388 Mdot
.69546 .53156 Mdot
.48903 .65241 Mdot
.53034 .77978 Mdot
.74091 .71579 Mdot
.4517 .16589 Mdot
.458 .80224 Mdot
.42243 .40064 Mdot
.50535 .43495 Mdot
.56716 .79475 Mdot
.5695 .22868 Mdot
.43918 .40483 Mdot
.52377 .20786 Mdot
.15326 .36669 Mdot
.61022 .75928 Mdot
.65938 .71531 Mdot
.56559 .22029 Mdot
.57504 .32665 Mdot
.54455 .23371 Mdot
.49396 .20706 Mdot
.33571 .74121 Mdot
.2063 .60175 Mdot
.49442 .21049 Mdot
.15396 .43406 Mdot
.52428 .52325 Mdot
.35772 .44068 Mdot
.60825 .46302 Mdot
.69188 .66675 Mdot
.38902 .35198 Mdot
.81433 .54334 Mdot
.42094 .81373 Mdot
.45678 .36829 Mdot
.32752 .75337 Mdot
.23056 .44433 Mdot
.70116 .63705 Mdot
.73934 .62008 Mdot
.38941 .78258 Mdot
.69308 .46681 Mdot
.3746 .21489 Mdot
.79099 .41851 Mdot
.3288 .55975 Mdot
.45964 .82746 Mdot
.36253 .50353 Mdot
.62751 .49102 Mdot
.60296 .27081 Mdot
.41289 .75188 Mdot
.74692 .30975 Mdot
.384 .68035 Mdot
.59794 .39611 Mdot
.45984 .15618 Mdot
.58311 .33053 Mdot
.7409 .27924 Mdot
.71731 .3448 Mdot
.51145 .19182 Mdot
.28053 .60302 Mdot
.27667 .63053 Mdot
.14805 .39746 Mdot
.46633 .37887 Mdot
.30361 .55932 Mdot
.34257 .2527 Mdot
.61072 .39039 Mdot
.38178 .59661 Mdot
.32056 .4899 Mdot
.39935 .44426 Mdot
.29826 .31858 Mdot
.51963 .53498 Mdot
.64901 .35728 Mdot
.40984 .44914 Mdot
.78504 .59115 Mdot
.79065 .63673 Mdot
.33321 .54284 Mdot
.24831 .25657 Mdot
.60056 .63536 Mdot
.74533 .50501 Mdot
.61602 .80737 Mdot
.37255 .1728 Mdot
.27406 .50627 Mdot
.29639 .77443 Mdot
.62664 .52353 Mdot
.39118 .76731 Mdot
.60767 .35475 Mdot
.1956 .45703 Mdot
.40161 .63178 Mdot
.5001 .67535 Mdot
.45151 .36823 Mdot
.71694 .31629 Mdot
.26897 .51015 Mdot
.55628 .38069 Mdot
.363 .74288 Mdot
.65114 .6819 Mdot
.37865 .39272 Mdot
.26534 .57624 Mdot
.73308 .51401 Mdot
.71591 .64244 Mdot
.65614 .34164 Mdot
.64819 .72217 Mdot
.17025 .50856 Mdot
.86992 .42724 Mdot
.52281 .36479 Mdot
.56476 .45901 Mdot
.3331 .28342 Mdot
.35394 .77284 Mdot
.38924 .2342 Mdot
.63652 .80259 Mdot
.5381 .66576 Mdot
.52074 .61903 Mdot
.57961 .68401 Mdot
.56771 .49799 Mdot
.47808 .46646 Mdot
.30563 .41381 Mdot
.55709 .203 Mdot
.45098 .22406 Mdot
.6791 .37056 Mdot
.39031 .21824 Mdot
.63777 .7164 Mdot
.51488 .19506 Mdot
.30505 .54376 Mdot
.71791 .62934 Mdot
.40833 .30574 Mdot
.79281 .63826 Mdot
.6301 .80384 Mdot
.45371 .32566 Mdot
.3147 .58024 Mdot
.38423 .82258 Mdot
.67136 .59053 Mdot
.50702 .50152 Mdot
.59625 .61717 Mdot
.4847 .5851 Mdot
.33529 .19311 Mdot
.347 .7572 Mdot
.5478 .54529 Mdot
.6931 .72711 Mdot
.71797 .71084 Mdot
.82302 .33181 Mdot
.18882 .39477 Mdot
.58057 .37321 Mdot
.79513 .31899 Mdot
.52702 .20472 Mdot
.7323 .72446 Mdot
.35191 .42182 Mdot
.65383 .81452 Mdot
.71846 .49683 Mdot
.35334 .7839 Mdot
.65884 .3905 Mdot
.56965 .25721 Mdot
.2341 .542 Mdot
.50663 .49465 Mdot
.30615 .35555 Mdot
.25026 .66787 Mdot
.15518 .5947 Mdot
.57011 .50652 Mdot
.22072 .48828 Mdot
.47461 .31161 Mdot
.47723 .83291 Mdot
.28107 .67696 Mdot
.55202 .58173 Mdot
.39366 .29382 Mdot
.74188 .31849 Mdot
.55096 .67969 Mdot
.54877 .47808 Mdot
.26917 .66128 Mdot
.81818 .47469 Mdot
.65035 .69431 Mdot
.18128 .47302 Mdot
.72816 .51057 Mdot
.43952 .48882 Mdot
.63868 .54182 Mdot
.63844 .38545 Mdot
.40418 .69662 Mdot
.49228 .5087 Mdot
.56104 .58198 Mdot
.34633 .46634 Mdot
.39203 .42124 Mdot
.71854 .26996 Mdot
.44874 .24379 Mdot
.19537 .50798 Mdot
.6416 .32671 Mdot
.50819 .3129 Mdot
.37956 .24221 Mdot
.67635 .24298 Mdot
.32542 .70008 Mdot
.56413 .68973 Mdot
.63342 .76828 Mdot
.75291 .66256 Mdot
.62443 .29693 Mdot
.85222 .40688 Mdot
.38953 .3655 Mdot
.70965 .6262 Mdot
.52961 .29092 Mdot
.30126 .56141 Mdot
.5502 .62293 Mdot
.35263 .78239 Mdot
.44154 .61032 Mdot
.58623 .74968 Mdot
.22567 .60516 Mdot
.50191 .59713 Mdot
.72382 .55304 Mdot
.69201 .73377 Mdot
.37202 .48214 Mdot
.18285 .52517 Mdot
.37592 .35481 Mdot
.27226 .65931 Mdot
.75393 .66752 Mdot
.84693 .52234 Mdot
.48775 .41357 Mdot
.48703 .70205 Mdot
.60942 .59768 Mdot
.17242 .47527 Mdot
.34189 .75554 Mdot
.70266 .60102 Mdot
.27873 .38943 Mdot
.61707 .33452 Mdot
.27209 .43466 Mdot
.4497 .49155 Mdot
.82132 .49758 Mdot
.63751 .35217 Mdot
.49111 .18724 Mdot
.42605 .678 Mdot
.54047 .44458 Mdot
.57233 .64446 Mdot
.49872 .69611 Mdot
.19205 .35492 Mdot
.60855 .65458 Mdot
.46769 .80928 Mdot
.74078 .53806 Mdot
.20984 .43071 Mdot
.38389 .77448 Mdot
.34819 .36823 Mdot
.55456 .24715 Mdot
.72481 .62806 Mdot
.38494 .28208 Mdot
.63358 .61496 Mdot
.32656 .56344 Mdot
.55364 .37345 Mdot
.46136 .83304 Mdot
.77809 .52632 Mdot
.52387 .71523 Mdot
.42419 .56802 Mdot
.55058 .48065 Mdot
.38745 .3221 Mdot
.64354 .81317 Mdot
.56212 .24784 Mdot
.5175 .66083 Mdot
.453 .54628 Mdot
.48703 .71704 Mdot
.70802 .35894 Mdot
.84915 .55542 Mdot
.66477 .38142 Mdot
.44775 .43873 Mdot
.67122 .31349 Mdot
.23855 .61414 Mdot
.43813 .84429 Mdot
.58975 .68447 Mdot
.53297 .43069 Mdot
.37669 .6792 Mdot
.37354 .26181 Mdot
.41319 .56513 Mdot
.52261 .49857 Mdot
.40573 .45555 Mdot
.28145 .35893 Mdot
.51247 .33433 Mdot
.68294 .63447 Mdot
.54724 .76299 Mdot
.65281 .75696 Mdot
.21128 .41326 Mdot
.36031 .35218 Mdot
.29893 .45584 Mdot
.80789 .53078 Mdot
.66363 .81724 Mdot
.53005 .16712 Mdot
.60638 .59732 Mdot
.37374 .32427 Mdot
.47567 .6959 Mdot
.34439 .4761 Mdot
.46364 .2123 Mdot
.39594 .24512 Mdot
.41709 .39553 Mdot
.47223 .63503 Mdot
.60826 .73702 Mdot
.24606 .5264 Mdot
.4504 .69768 Mdot
.41051 .29772 Mdot
.70564 .25682 Mdot
.24544 .68735 Mdot
.3568 .77398 Mdot
.7611 .74747 Mdot
.36891 .37887 Mdot
.64797 .51231 Mdot
.69441 .41901 Mdot
.76791 .6604 Mdot
.52172 .68202 Mdot
.78057 .38711 Mdot
.33358 .34681 Mdot
.57903 .68041 Mdot
.55368 .40771 Mdot
.57088 .75676 Mdot
.26715 .43398 Mdot
.48229 .45257 Mdot
.28016 .63817 Mdot
.85882 .40987 Mdot
.70449 .53358 Mdot
.63464 .77386 Mdot
.7188 .29714 Mdot
.15769 .46679 Mdot
.76506 .66845 Mdot
.5468 .74469 Mdot
.31389 .70505 Mdot
.66639 .42778 Mdot
.51657 .40095 Mdot
.66064 .31722 Mdot
.76045 .36755 Mdot
.76333 .59285 Mdot
.3152 .60337 Mdot
.68933 .33479 Mdot
.61973 .69447 Mdot
.77406 .58078 Mdot
.53292 .42912 Mdot
.74215 .58391 Mdot
.30868 .57625 Mdot
.55222 .21771 Mdot
.54816 .32173 Mdot
.54647 .70795 Mdot
.74595 .54873 Mdot
.31901 .29358 Mdot
.26934 .69112 Mdot
.14168 .48403 Mdot
.34708 .689 Mdot
.67494 .25043 Mdot
.58076 .52835 Mdot
.8216 .30932 Mdot
.23237 .56733 Mdot
.24455 .5546 Mdot
.21402 .59007 Mdot
.39355 .4659 Mdot
.5932 .48619 Mdot
.63406 .61461 Mdot
.50753 .80498 Mdot
.6933 .52774 Mdot
.75522 .39209 Mdot
.70546 .30358 Mdot
.49408 .66399 Mdot
.58928 .70367 Mdot
.53517 .72672 Mdot
.52091 .60787 Mdot
.60435 .3324 Mdot
.75747 .28281 Mdot
.47346 .41634 Mdot
.70169 .59789 Mdot
.59084 .65748 Mdot
.67017 .4107 Mdot
.37232 .84088 Mdot
.52457 .40007 Mdot
.66359 .70618 Mdot
.71666 .52756 Mdot
.60583 .29341 Mdot
.39873 .22576 Mdot
.90223 .58449 Mdot
.8515 .33171 Mdot
.56448 .39052 Mdot
.22292 .3566 Mdot
.71464 .53249 Mdot
.67927 .71425 Mdot
.30847 .68124 Mdot
.2676 .38499 Mdot
.70702 .60973 Mdot
.58691 .28267 Mdot
.53692 .61402 Mdot
.22344 .55534 Mdot
.80578 .62582 Mdot
.69414 .29894 Mdot
.69066 .72857 Mdot
.55528 .50201 Mdot
.55645 .63282 Mdot
.73196 .78384 Mdot
.57865 .79129 Mdot
.63261 .63577 Mdot
.66827 .33867 Mdot
.67937 .62873 Mdot
.62956 .56867 Mdot
.41966 .77144 Mdot
.1737 .61133 Mdot
.64851 .69741 Mdot
.69282 .71212 Mdot
.63311 .37728 Mdot
.39671 .48683 Mdot
.43963 .38372 Mdot
.49476 .41212 Mdot
.64457 .63652 Mdot
.3971 .38476 Mdot
.50042 .61902 Mdot
.38668 .81713 Mdot
.42483 .54837 Mdot
.17584 .56721 Mdot
.71795 .76201 Mdot
.77159 .53331 Mdot
.38706 .26026 Mdot
.67129 .58416 Mdot
.71595 .64931 Mdot
.7564 .62343 Mdot
.50939 .52609 Mdot
.3089 .75317 Mdot
.5427 .1036 Mdot
.35232 .30148 Mdot
.82357 .51531 Mdot
.54918 .34189 Mdot
.42385 .4793 Mdot
.72603 .57471 Mdot
.3651 .42625 Mdot
.32494 .53591 Mdot
.53758 .51866 Mdot
.61695 .32222 Mdot
.40366 .33079 Mdot
.26896 .23064 Mdot
.55362 .56214 Mdot
.43246 .2206 Mdot
.71922 .73093 Mdot
.79059 .41687 Mdot
.72359 .46753 Mdot
.65832 .5876 Mdot
.47587 .28937 Mdot
.53267 .43202 Mdot
.45416 .81468 Mdot
.8384 .48587 Mdot
.64817 .74844 Mdot
.77847 .53023 Mdot
.72192 .54844 Mdot
.63579 .5398 Mdot
.40658 .62346 Mdot
.46944 .39369 Mdot
.4748 .79967 Mdot
.67617 .6259 Mdot
.76407 .69016 Mdot
.26665 .50753 Mdot
.46244 .56215 Mdot
.55089 .42502 Mdot
.81769 .33016 Mdot
.69159 .3833 Mdot
.61876 .31303 Mdot
.68264 .24556 Mdot
.27508 .53982 Mdot
.46782 .66654 Mdot
.37865 .49708 Mdot
.67664 .60639 Mdot
.64205 .35177 Mdot
.65699 .20795 Mdot
.46708 .7895 Mdot
.31224 .34621 Mdot
.28652 .39751 Mdot
.23133 .37209 Mdot
.3783 .38779 Mdot
.77656 .73068 Mdot
.26149 .58672 Mdot
.67913 .22872 Mdot
.17268 .51418 Mdot
.6402 .33677 Mdot
.28389 .71362 Mdot
.60865 .64992 Mdot
.3333 .53776 Mdot
.67124 .73259 Mdot
.67689 .5338 Mdot
.80557 .39821 Mdot
.63902 .53257 Mdot
.7803 .34318 Mdot
.37833 .6872 Mdot
.33218 .58881 Mdot
.23872 .60421 Mdot
.67636 .40571 Mdot
.56312 .84515 Mdot
.36531 .26344 Mdot
.59198 .82693 Mdot
.53874 .84554 Mdot
.70233 .73272 Mdot
.78253 .3732 Mdot
.41516 .17108 Mdot
.24396 .61791 Mdot
.38474 .78304 Mdot
.31595 .42602 Mdot
.65286 .41883 Mdot
.24942 .59127 Mdot
.59214 .45105 Mdot
.49592 .22713 Mdot
.39488 .30463 Mdot
.28914 .17411 Mdot
.58766 .71784 Mdot
.58584 .31455 Mdot
.25674 .60254 Mdot
.73204 .71061 Mdot
.67183 .42027 Mdot
.24312 .65823 Mdot
.4549 .48693 Mdot
.58532 .5074 Mdot
.76316 .58769 Mdot
.21068 .40493 Mdot
.25649 .55302 Mdot
.1236 .46074 Mdot
.22674 .65379 Mdot
.29563 .35583 Mdot
.46759 .4654 Mdot
.57045 .39339 Mdot
.35847 .22958 Mdot
.2818 .62812 Mdot
.29196 .74041 Mdot
.36679 .79988 Mdot
.5712 .794 Mdot
.1517 .39225 Mdot
.20252 .44964 Mdot
.78189 .64696 Mdot
.30117 .72774 Mdot
.56001 .38723 Mdot
.52647 .74591 Mdot
.33016 .55669 Mdot
.31022 .38288 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`2cooooo`;o0000U?ooool001cooooo00?o0000ooooooooool0/oooool2o`0009Co
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
08oooooo0_l0002hooooo`007?ooool2o`00093ooooo0_l0002hooooo`007?ooool00ol0003ooooo
ooooo`2]ooooo`;o0000V_ooool001cooooo00?o0000ooooooooool0[Oooool2o`0009[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0QOooool2o`00
0<;ooooo000Looooo`03o`000?oooooooooo08Gooooo0_l00032ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0N_ooool2o`000<gooooo000Looooo`03o`000?oooooooooo07[ooooo0_l000000ooo
oooo0000o`00003:ooooo`007?ooool00ol0003oooooooooo`1mooooo`;o0000b_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`29ooooo`;o0000__oo
ool001cooooo00?o0000ooooooooool0ROooool2o`00013ooooo0_l00004ooooo`;o0000Y_ooool0
01cooooo00?o0000ooooooooool0Toooool2o`0000Kooooo0_l00004ooooo`;o0000Y_ooool001co
oooo00?o0000ooooooooool0K?ooool2o`0002Gooooo0_l0002dooooo`007?ooool00ol0003ooooo
ooooo`1/ooooo`;o00000oooool2o`0000Kooooo0_l0000]ooooo`;o0000Woooool001cooooo0_l0
001booooo`;o00001_ooool2o`0001Oooooo0_l0000Dooooo`;o00000oooool2o`0000cooooo0_l0
002<ooooo`007?ooool00ol0003oooooooooo`2Booooo`;o00002?ooool2o`0000oooooo0_l00004
ooooo`;o00001_ooool2o`0008cooooo000Looooo`03o`000?oooooooooo097ooooo0ol00008oooo
o`;o00002_ooool2o`0000Wooooo0_l00008ooooo`;o0000R_ooool001cooooo00?o0000oooooooo
ool0Poooool2o`0000?ooooo0_l00007ooooo`;o00005Oooool2o`0001?ooooo0_l0002:ooooo`00
7?ooool00ol0003oooooooooo`1eooooo`;o00002_ooool4o`0000?ooooo0_l00005ooooo`;o0000
^?ooool001cooooo00?o0000ooooooooool0K?ooool2o`0000Oooooo0_l00006ooooo`;o00000_oo
ool2o`0000cooooo0_l0000Gooooo`;o0000Woooool001cooooo00?o0000ooooooooool0K?ooool2
o`0000Wooooo0_l00004ooooo`;o00001?ooool2o`00023ooooo0_l000000ooooooo0000o`00002O
ooooo`007?ooool00ol0003oooooooooo`1Jooooo`;o00006Oooool4o`0000[ooooo0_l00005oooo
o`;o00004oooool4o`0000;ooooo0_l0002Rooooo`007?ooool00ol0003oooooooooo`1Jooooo`;o
00006Oooool2o`0001?ooooo0_l0000Cooooo`Co0000;?ooool2o`0007Sooooo000Looooo`03o`00
0?oooooooooo0<oooooo0_l0001hooooo`007?ooool00ol0003oooooooooo`2?ooooo`;o00005ooo
ool2o`000003ooooool0003o000002[ooooo0_l0001`ooooo`007?ooool00ol0003oooooooooo`1U
ooooo`;o00007?ooool2o`0000[ooooo0_l0000;ooooo`;o00002?ooool4o`000003ooooool0003o
000002[ooooo0_l0001`ooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o00007?ooool2o`00
00Sooooo1?l00006ooooo`?o00000_ooool2o`0000Sooooo0ol0000:ooooo`;o0000U?ooool00006
ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooo
oooo06Wooooo0_l0000Mooooo`;o00000oooool2o`0000?ooooo0_l00003ooooo`?o00002?ooool2
o`0000oooooo0_l0002Dooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0JOooool2o`0001cooooo
0ol00007ooooo`?o00001?ooool2o`0000Sooooo0ol0002Tooooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0Qooo
ool2o`0000Sooooo0_l00005ooooo`?o00002?ooool2o`0000?ooooo0_l0000>ooooo`;o0000Sooo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06
ooooo`?o0000O_ooool2o`0001Wooooo0_l00008ooooo`;o00000oooool2o`0000Oooooo0_l00005
ooooo`;o00004Oooool2o`0007cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`1gooooo`;o00001?ooool3o`00
00Oooooo0_l00004ooooo`Oo00003oooool2o`0000;ooooo0_l00008ooooo`;o00006?ooool2o`00
07cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`1dooooo`Oo000000Coooooo`000?l0003o00002?ooool2o`00
00Cooooo1ol00009ooooo`?o00000oooool2o`000005ooooool0003o0000o`000?ooool00_l0000A
ooooo`;o00003_ooool4o`000003ooooool0003o000001[ooooo0_l0001Iooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003ooooo
ooooo`1dooooo`?o00000_ooool2o`000003ooooool0003o000000Wooooo0_l00002ooooo`;o0000
00?oooooo`000?l000000oooool2o`0000Sooooo0ol00003ooooo`;o000000?oooooo`000?l00000
0_ooool2o`0000gooooo0_l00002ooooo`Co00003?ooool4o`000003ooooool0003o000000;ooooo
0_l0000Fooooo`;o0000FOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So
410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0M_ooool2o`0000oooooo0_l00002oooo
o`;o00001_ooool2o`0000Sooooo1?l0000<ooooo`;o00002_ooool2o`0000Cooooo0_l00004oooo
o`;o00003oooool2o`00077ooooo000Looooo`03o`000?oooooooooo07Kooooo0_l000000ooooooo
0000o`000002o`0000Cooooo0_l000000ooooooo0000o`000005ooooo`;o00002oooool2o`000003
ooooool0003o000000;ooooo0_l0000<ooooo`;o000000?oooooo`000?l000001oooool2o`0000[o
oooo0_l00008ooooo`;o0000N?ooool001cooooo00?o0000ooooooooool0M_ooool2o`000003oooo
ool0003o000000;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000003ooooo`Co
00002oooool5o`0001?ooooo0_l00002ooooo`;o00000oooool2o`0001Cooooo0_l0001hooooo`00
7?ooool00ol0003oooooooooo`1Zooooo`;o00002_ooool2o`0000Kooooo0_l00009ooooo`;o0000
00Coooooo`000?l0003ooooo0_l00008ooooo`;o00001_ooool2o`00017ooooo0_l00002ooooo`;o
00003Oooool2o`00083ooooo000Looooo`03o`000?oooooooooo06[ooooo0ol0000>ooooo`;o0000
00?oooooo`000?l000003?ooool2o`000003ooooool0003o000000Kooooo0_l00004ooooo`?o0000
00Goooooo`000?l0003o0000ooooo`02o`0000cooooo0_l00003ooooo`;o00003?ooool3o`00083o
oooo000Looooo`03o`000?oooooooooo05Cooooo0_l0000Eooooo`;o00001?ooool2o`0000;ooooo
0_l00004ooooo`;o000000?oooooo`000?l000005oooool2o`0000Cooooo0ol00002ooooo`;o0000
00?oooooo`000?l000003?ooool7o`0000Kooooo0_l00004ooooo`;o00004Oooool2o`0006kooooo
000Looooo`03o`000?oooooooooo05Cooooo0_l0000Kooooo`;o00000_ooool2o`0003Kooooo0_l0
0006ooooo`Go00001_ooool2o`0001Oooooo0_l0000=ooooo`;o0000Goooool001cooooo00?o0000
ooooooooool0Noooool2o`0000Oooooo0_l00008ooooo`;o00000_ooool2o`0001Cooooo0_l00002
ooooo`?o00005oooool2o`00023ooooo0_l0001Oooooo`007?ooool00ol0003oooooooooo`1koooo
o`;o00000oooool2o`0000;ooooo0_l00008ooooo`;o00000_ooool2o`0001;ooooo1?l00002oooo
o`;o00000_ooool4o`0000Wooooo0_l00007ooooo`Co00004?ooool2o`0000_ooooo0_l0001Poooo
o`007?ooool00ol0003oooooooooo`1Sooooo`;o00002?ooool2o`0000;ooooo0_l000000ooooooo
0000o`000002ooooo`;o00001_ooool2o`0000Sooooo0ol00004ooooo`;o00004oooool2o`0000?o
oooo0_l00003ooooo`Co00001Oooool2o`0000;ooooo0_l000000ooooooo0000o`000006ooooo`;o
00003_ooool6o`0000Wooooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`1Sooooo`;o0000
2?ooool2o`0000;ooooo1Ol00002ooooo`;o00000oooool2o`0000;ooooo0_l00007ooooo`Ko0000
00?oooooo`000?l000001Oooool2o`00017ooooo0_l0000<ooooo`;o00001Oooool2o`000003oooo
ool0003o000001?ooooo1_l0001[ooooo`007?ooool00ol0003oooooooooo`1Tooooo`;o00003Ooo
ool2o`0000Oooooo1?l000000ooooooo0000o`00000:ooooo`?o00002?ooool2o`0001Gooooo0ol0
00001?oooooo0000o`000?ooool2o`0000_ooooo0_l00005ooooo`;o00003_ooool2o`0000?ooooo
0_l0001Xooooo`007?ooool2o`0005Kooooo0_l00008ooooo`;o00000oooool2o`0000;ooooo0_l0
000Booooo`Co00001_ooool2o`0000Kooooo0_l0000Mooooo`So000000Coooooo`000?l0003ooooo
1?l0000<ooooo`?o00002oooool2o`000003ooooool0003o000000?ooooo0_l0001Xooooo`007?oo
ool00ol0003oooooooooo`1Eooooo`;o00002?ooool2o`0000Oooooo0_l00002ooooo`;o00003_oo
ool6o`0000Cooooo0_l00006ooooo`;o00007?ooool3o`0000;ooooo0_l00006ooooo`Go00002ooo
ool2o`0000Kooooo0_l00004ooooo`;o000000?oooooo`000?l000002?ooool4o`0000Wooooo0_l0
001Fooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00005?ooool2o`0000Oooooo0_l0000@
ooooo`Co00003?ooool2o`0001cooooo2ol00005ooooo`;o00001Oooool2o`0000_ooooo0ol00007
ooooo`?o00001?ooool2o`000003ooooool0003o000000;o00002Oooool2o`0005Kooooo000Loooo
o`03o`000?oooooooooo04gooooo0_l0000@ooooo`;o00000_ooool2o`0001Gooooo0_l0000Boooo
o`;o00007Oooool:o`0000Wooooo0_l000000ooooooo0000o`00000;ooooo`Co00001oooool2o`00
00Cooooo0_l0001Vooooo`007?ooool00ol0003oooooooooo`18ooooo`;o00005Oooool2o`0000oo
oooo0_l000001?oooooo0000o`000?ooool3o`000003ooooool0003o000000Sooooo0_l00007oooo
o`;o00001oooool3o`0001Sooooo0_l00007ooooo`;o00001?ooool2o`00013ooooo0_l0001eoooo
o`007?ooool00ol0003oooooooooo`18ooooo`;o00004_ooool2o`00013ooooo1?l000001?oooooo
0000o`000?ooool3o`0000_ooooo0_l00003ooooo`;o00000_ooool2o`0000Cooooo0_l000001?oo
oooo0000o`000?l00009ooooo`;o00000oooool2o`0000?ooooo1?l00007ooooo`;o000000?ooooo
o`000?l000005Oooool2o`0000cooooo0_l0001Xooooo`007?ooool00ol0003oooooooooo`1Foooo
o`;o00001?ooool2o`0000Gooooo0_l00009ooooo`Co00001_ooool2o`0000?ooooo0ol00009oooo
o`?o00001oooool2o`0000gooooo0ol00002ooooo`;o00000oooool4o`0000Gooooo1?l00003oooo
o`;o00000_ooool2o`0000kooooo1Ol0000:ooooo`;o00001Oooool2o`0000[ooooo0_l0001Eoooo
o`007?ooool00ol0003oooooooooo`1Aooooo`;o00000oooool4o`000004ooooool0003o0000oooo
o`;o00000oooool2o`0000_ooooo0_l00006ooooo`;o00000oooool3o`000003ooooool0003o0000
00Oooooo0_l0000@ooooo`;o00001Oooool2o`0000Wooooo0_l00005ooooo`;o00000oooool5o`00
0003ooooool0003o000000Oooooo0_l00005ooooo`;o000000?oooooo`000?l000004Oooool2o`00
00;ooooo0_l00006ooooo`;o000000?oooooo`000?l00000D_ooool001cooooo00?o0000oooooooo
ool0DOooool2o`0000?ooooo1?l000001?oooooo0000o`000?ooool2o`0001kooooo0_l000000ooo
oooo0000o`000007ooooo`;o00001_ooool2o`0000Sooooo0_l0000Fooooo`;o00001?ooool7o`00
00Sooooo0_l00005ooooo`Co00003_ooool2o`0000Kooooo0_l00004ooooo`;o00000oooool2o`00
05;ooooo000Looooo`03o`000?oooooooooo06Oooooo0ol0000@ooooo`;o00000_ooool2o`0001;o
oooo0_l00008ooooo`Co00004?ooool2o`0000;ooooo0_l00004ooooo`;o00000oooool2o`00017o
oooo0_l00007ooooo`;o00001Oooool2o`0000Wooooo0_l000000ooooooo0000o`00001Gooooo`00
7?ooool00ol0003oooooooooo`1Wooooo`?o00003_ooool4o`0000gooooo0_l00002ooooo`?o0000
3_ooool2o`0000kooooo1?l00005ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`000003
ooooool0003o000000Cooooo0_l00005ooooo`;o00002_ooool2o`0000Gooooo0_l00009ooooo`;o
00000oooool2o`0005Gooooo000Looooo`03o`000?oooooooooo057ooooo0_l0000>ooooo`;o0000
1Oooool2o`0000kooooo0ol00006ooooo`;o00001_ooool2o`0000;ooooo0ol00008ooooo`;o0000
00?oooooo`000?l000000oooool2o`0000cooooo1?l00004ooooo`?o00000_ooool2o`0000;ooooo
0_l000000ooooooo0000o`000003ooooo`?o00001Oooool2o`0000;ooooo0_l00006ooooo`;o0000
5Oooool2o`0005Gooooo000Looooo`03o`000?oooooooooo04;ooooo0_l0000=ooooo`;o00003_oo
ool2o`0000Gooooo0_l00006ooooo`Co00003Oooool2o`00013ooooo0_l00002ooooo`Ko00000ooo
ool2o`000003ooooool0003o000000gooooo0_l00002ooooo`;o00003Oooool4o`0000[ooooo0_l0
0006ooooo`;o00001?ooool2o`0006Kooooo000Looooo`03o`000?oooooooooo03kooooo0_l00002
ooooo`;o00001oooool2o`0000gooooo0_l00002ooooo`Co00003_ooool4o`0001oooooo2Ol00007
ooooo`;o00000oooool2o`0000Sooooo0_l0000Aooooo`;o00002_ooool2o`0000kooooo0_l00003
ooooo`;o0000HOooool001cooooo00?o0000ooooooooool0?_ooool2o`0000_ooooo0ol0000<oooo
o`;o00000_ooool4o`0000;ooooo0_l0000Fooooo`;o000000Coooooo`000?l0003o00001oooool2
o`0000[ooooo0_l00002ooooo`;o00003Oooool2o`0000cooooo0_l00009ooooo`;o00002?ooool2
o`0000Cooooo0_l0000<ooooo`;o000000?oooooo`000?l000000_ooool2o`00067ooooo000Loooo
o`03o`000?oooooooooo04Gooooo0_l00005ooooo`;o000000?oooooo`000?l000001oooool2o`00
00[ooooo0_l0000Dooooo`[o00001Oooool2o`0000Wooooo0_l0000Pooooo`;o00002Oooool2o`00
00Cooooo0_l00002ooooo`;o00004_ooool2o`000003ooooool0003o000000;ooooo0_l0000Eoooo
o`?o0000BOooool001cooooo0_l00016ooooo`;o00002?ooool2o`0000Cooooo0_l000000ooooooo
0000o`000003ooooo`;o00004?ooool2o`0000Gooooo1_l000000ooooooo0000o`000003ooooo`?o
00001?ooool3o`0000Sooooo0_l0000Booooo`;o00001Oooool2o`0000Cooooo0_l0000@ooooo`;o
00002?ooool2o`000003ooooool0003o000000Gooooo0_l000000ooooooo0000o`000006ooooo`;o
00000_ooool4o`0000oooooo0ol00019ooooo`007?ooool00ol0003oooooooooo`1?ooooo`;o0000
0oooool3o`0000Kooooo0_l00006ooooo`;o00002?ooool2o`0000;ooooo0_l000000ooooooo0000
o`000002o`0000?ooooo0_l00004ooooo`;o00001Oooool2o`0000Cooooo0_l0000Fooooo`;o0000
0oooool4o`000003ooooool0003o000000?o00001oooool2o`0000kooooo0_l000001?oooooo0000
o`000?ooool3o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0000Oooooo1?l0000?oooo
o`;o0000B_ooool001cooooo00?o0000ooooooooool0Coooool2o`0000?ooooo0_l00005ooooo`Co
00001_ooool2o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`;o00000_ooool3o`0000?o
oooo0_l00002ooooo`Co00002oooool2o`0000Cooooo0_l0000Eooooo`Co000000?oooooo`000?l0
00000ol00007ooooo`;o00002Oooool2o`0000?ooooo0_l00005ooooo`;o00001Oooool2o`0000?o
oooo0_l00004ooooo`;o000000?oooooo`000?l000004Oooool2o`0004[ooooo000Looooo`03o`00
0?oooooooooo04Oooooo0_l0000>ooooo`;o00000_ooool2o`0000kooooo2?l00003ooooo`Co0000
1oooool2o`0000_ooooo0_l00004ooooo`Go00001Oooool2o`0000kooooo0_l00003ooooo`?o0000
2_ooool2o`0000Oooooo0_l0000Aooooo`;o00002Oooool2o`0000Kooooo0_l00002ooooo`;o0000
4_ooool2o`00043ooooo000Looooo`03o`000?oooooooooo04Oooooo0_l0000>ooooo`;o00000_oo
ool2o`0000_ooooo2ol00003ooooo`;o000000?oooooo`000?l000003oooool6o`0000Cooooo1ol0
0003ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Gooooo0_l00002ooooo`;o00001?oo
ool2o`0000Gooooo0_l00003ooooo`;o00003oooool2o`0000;ooooo0ol0000=ooooo`;o000000?o
ooooo`000?l000000_l00002ooooo`;o00004_ooool2o`00043ooooo000Looooo`03o`000?oooooo
oooo04;ooooo0_l0000Fooooo`Go00002Oooool5o`0000Gooooo1?l00003ooooo`;o00002?ooool2
o`000003ooooool0003o000000;ooooo1?l00003ooooo`?o00000_ooool2o`000003ooooool0003o
000000Kooooo0_l00005ooooo`;o00001Oooool2o`0000Kooooo2_l00004ooooo`;o00003oooool2
o`0000;ooooo0ol00008ooooo`;o00000oooool2o`000003ooooool0003o000005[ooooo000Loooo
o`03o`000?oooooooooo04;ooooo0_l0000<ooooo`;o00002?ooool2o`000003ooooool0003o0000
01?ooooo1?l00003ooooo`;o00001Oooool2o`000003ooooool0003o000000?o00000_ooool2o`00
00?ooooo1Ol000000ooooooo0000o`00000Fooooo`Co00001_ooool:o`0000cooooo0_l00004oooo
o`;o00000_ooool2o`0000cooooo0ol00005ooooo`;o00003oooool2o`0000?ooooo0_l00014oooo
o`007?ooool00ol0003oooooooooo`1>ooooo`Co00002oooool2o`0001?ooooo0_l00005ooooo`?o
00000oooool3o`0000;ooooo1Ol000000ooooooo0000o`000003ooooo`;o00001?ooool2o`0001Ko
oooo1?l00007ooooo`;o00001Oooool5o`000003ooooool0003o000000;o00001?ooool2o`0000;o
oooo1?l00002ooooo`;o00003Oooool2o`0000Gooooo0_l0000?ooooo`;o00000oooool2o`0004Co
oooo000Looooo`03o`000?oooooooooo04kooooo0_l0000Fooooo`;o00001?ooool2o`0000Kooooo
1?l00002ooooo`;o00000oooool2o`0000Cooooo1?l000000ooooooo0000o`000002o`0000;ooooo
1?l00005ooooo`;o00003_ooool2o`0000?ooooo0_l00005ooooo`Go00001?ooool?o`0000Cooooo
0_l0001fooooo`007?ooool00ol0003oooooooooo`1Vooooo`;o000000Coooooo`000?l0003ooooo
0_l000000ooooooo0000o`000003ooooo`Co00002_ooool=o`000003ooooool0003o000000;o0000
0_ooool2o`000003ooooool0003o000000kooooo0_l00009ooooo`Oo00000_oooolBo`0000;ooooo
0_l0000Oooooo`;o00002Oooool2o`0004[ooooo000Looooo`03o`000?oooooooooo043ooooo0_l0
0006ooooo`;o00006oooool2o`000004ooooool0003o0000o`0000Cooooo0_l000000ooooooo0000
o`000003ooooo`;o000000?oooooo`000?l000000oooool@o`000003ooooool0003o000000;o0000
0_ooool2o`0001Kooooo0_l00004oooooaGo00001?ooool3o`000003ooooool0003o000000?o0000
3_ooool2o`0000cooooo0_l00009ooooo`;o00001oooool4o`0000Oooooo0_l0000fooooo`007?oo
ool00ol0003oooooooooo`10ooooo`;o00000_ooool2o`000005ooooool0003o0000o`000?ooool0
0_l0000:ooooo`;o00003?ooool2o`000003ooooool0003o000000Sooooo0_l00003ooooo`;o0000
00?oooooo`000?l000000_ooool9o`000003ooooool0003o000000[o000000?oooooo`000?l00000
0oooool2o`0000Oooooo1_l00004ooooo`?o00000ooooolEo`0000Kooooo0_l00002ooooo`Co0000
1_ooool2o`0000Kooooo0_l0000?ooooo`;o00003oooool4o`0000Oooooo0_l0000fooooo`007?oo
ool00ol0003oooooooooo`0jooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0
003o000000?o00000_ooool2o`0000[ooooo0_l00007ooooo`;o000000?oooooo`000?l000002?oo
ool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000Gooooo5_l000001?oooooo0000
o`000?l00002ooooo`;o00001Oooool8o`000003ooooool0003o000000?o00000_oooolGo`000004
ooooool0003o0000ooooo`;o000000?oooooo`000?l000002oooool2o`0000Kooooo0_l0000?oooo
o`;o0000D_ooool001cooooo00?o0000ooooooooool0>_ooool2o`000003ooooool0003o000000Co
00000_ooool2o`0001Wooooo0_l000000ooooooo0000o`000008ooooo`;o00000_ooool5o`000003
ooooool0003o000000?ooooo5_l00004ooooo`;o00002Oooool=o`0000;ooooo6ol000001?oooooo
0000o`000?ooool8o`0000;ooooo0ol00008ooooo`;o00002_ooool2o`0000cooooo0_l00019oooo
o`007?ooool00ol0003oooooooooo`0oooooo`;o0000:Oooool2o`0000Kooooo0_l00008ooooo`ko
000000?oooooo`000?l000001Ol00003ooooo`Ko00002?ooool2o`000004ooooool0003o0000oooo
o`;o00001?ooool@o`000003ooooool0003o000000Oo00000_ooool3o`000003ooooool0003o0000
00Ko00000_ooool3o`0000Wooooo0_l00009ooooo`Co00001_ooool3o`000003ooooool0003o0000
04Wooooo000Looooo`03o`000?oooooooooo03Wooooo0_l0000>ooooo`;o00002Oooool2o`0000co
oooo0_l00005ooooo`?o00001_ooool2o`000003ooooool0003o000000Kooooo4Ol000001?oooooo
0000o`000?ooool2o`000003ooooool0003o000000Co000000?oooooo`000?l000002Oooool2o`00
00;ooooo0_l000000ooooooo0000o`00000No`0000;ooooo0_l0000Booooo`?o00001Oooool:o`00
00Cooooo0ol0001<ooooo`007?ooool2o`0003[ooooo0_l0000>ooooo`?o00002?ooool2o`0000_o
oooo0ol00004ooooo`?o000000?oooooo`000?l000001oooool2o`000003ooooool0003o000000?o
oooo5?l000000ooooooo0000o`000008ooooo`;o00002Oooool3o`000003ooooool0003o0000027o
00000oooool3o`00013ooooo0_l00005ooooo`Ko00000oooool2o`0000Wooooo0_l00018ooooo`00
7?ooool00ol0003oooooooooo`1:ooooo`;o00001_ooool2o`0000gooooo0_l00005ooooo`;o0000
0_ooool2o`0000?ooooo0_l00005ooooo`;o000000?oooooo`000?l000005Ol00008ooooo`Co0000
2_ooool2o`000003ooooool0003o000001Ko000000?oooooo`000?l000001?l000000ooooooo0000
o`000002o`0000;ooooo0ol0000Gooooo`?o00004Oooool2o`0004Sooooo000Looooo`03o`000?oo
oooooooo03Cooooo0_l00005ooooo`;o00001_ooool4o`0000_ooooo0_l00008ooooo`;o00000_oo
ool2o`0000oooooo0_l00002ooooo`?o00000ooooolGo`0000Sooooo0_l0000@ooooo`So000000?o
ooooo`000?l000006Ol000000ooooooo0000o`00000hooooo`;o0000??ooool001cooooo00?o0000
ooooooooool0=?ooool2o`0000Gooooo0_l00006ooooo`Co00004Oooool2o`0000;ooooo0ol00000
0ooooooo0000o`00000:ooooo`;o00000_ooool3o`0000;ooooo0ol000000ooooooo0000o`00000E
o`0001Wooooo0_l000000ooooooo0000o`00000Mo`000003ooooool0003o000000Go00003oooool2
o`0000kooooo0_l0000=ooooo`;o00001Oooool2o`000003ooooool0003o000003cooooo000Loooo
o`03o`000?oooooooooo04[ooooo0_l0000<ooooo`?o00000_ooool2o`0000gooooo0_l00002oooo
o`Co00001OoooolKo`0000[ooooo0_l00009ooooobSo00001_ooool2o`0000Wooooo0_l00009oooo
o`;o00000oooool2o`0000Gooooo0_l00006ooooo`;o00001Oooool2o`0000Kooooo0_l0000goooo
o`007?ooool00ol0003oooooooooo`0nooooo`;o00002_ooool2o`0000?ooooo0_l00008ooooo`;o
00005oooool2o`0000Gooooo2_l000000ooooooo0000o`000002o`000003ooooool0003o000000Wo
00001?ooool2o`0000Cooooo0_l00006ooooo`;o00000ooooolOo`000003ooooool0003o000000;o
00002?ooool2o`0000?ooooo0_l0000?ooooo`;o00000oooool2o`0000Gooooo1_l0000Aooooo`;o
0000=oooool001cooooo00?o0000ooooooooool0;_ooool2o`0000Sooooo0_l00004ooooo`;o0000
1?ooool2o`0000Sooooo0ol0000Looooo`;o00002_ooool;o`000003ooooool0003o000000co0000
0oooool4o`0000[ooooo1?l00003ooooo`So000000?oooooo`000?l000005Ol0000Aooooo`;o0000
3?ooool3o`0000Gooooo0ol00004ooooo`Ko00000oooool2o`0004Gooooo000Looooo`03o`000?oo
oooooooo02kooooo0_l00008ooooo`;o00002_ooool2o`000003ooooool0003o000000Gooooo0_l0
000=ooooo`Co00000oooool4o`0000;ooooo0_l000000ooooooo0000o`00000<oooooaSo000000?o
ooooo`000?l000000_l0000<ooooo`;o00001OoooolQo`0000?ooooo0_l00008ooooo`;o00001?oo
ool2o`0000Wooooo0ol00006ooooo`;o00000_ooool2o`0000;ooooo0ol00004ooooo`;o00003?oo
ool2o`0003Oooooo000Looooo`03o`000?oooooooooo03cooooo0_l00006ooooo`;o000000?ooooo
o`000?l000005?ooool;o`0000;ooooo0_l0000>oooooaWo000000?oooooo`000?l000000oooool2
o`0000Oooooo0_l000000ooooooo0000o`000007oooooako000000?oooooo`000?l000000_l00000
0ooooooo0000o`000005ooooo`;o00001?ooool2o`0000Kooooo0_l00002ooooo`;o00001_ooool3
o`000004ooooool0003o0000ooooo`Co00004_ooool2o`0003Oooooo000Looooo`03o`000?oooooo
oooo03cooooo0_l00003ooooo`;o000000?oooooo`000?l000006oooool4o`0001Gooooo3?l00000
0ooooooo0000o`000008o`0000Sooooo0_l00007ooooo`;o000000?oooooo`000?l000002?oooolM
o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000003?ooool2
o`0000[ooooo1?l00003ooooo`;o0000COooool001cooooo00?o0000ooooooooool0@Oooool2o`00
00Sooooo0ol00002ooooo`;o00001Oooool2o`0000Gooooo0_l000001?oooooo0000o`000?l0000@
ooooo`;o00001OoooolFo`0000?ooooo0_l00004ooooo`;o00000_ooool2o`0000;ooooo0_l00009
ooooob3o00000oooool2o`0000;ooooo1ol00002ooooo`;o00002oooool4o`0000Oooooo0_l0001B
ooooo`007?ooool00ol0003oooooooooo`0looooo`;o00001Oooool2o`0000;ooooo1ol00002oooo
o`;o00001Oooool2o`0000?ooooo2_l00008ooooo`;o00001?ooool2o`0000Gooooo5Ol00004oooo
o`;o00000oooool3o`0000;ooooo1_l000000ooooooo0000o`000006oooooaco000000Coooooo`00
0?l0003o00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`;o00002oooool4
o`0000?ooooo0_l0000Booooo`;o00003?ooool2o`0003Cooooo000Looooo`03o`000?oooooooooo
03cooooo0_l00005ooooo`;o00000_ooool4o`000003ooooool0003o000000Gooooo1?l00002oooo
o`;o000000?oooooo`000?l000000_ooool3o`000003ooooool0003o000000Sooooo0_l00007oooo
o`;o00000_ooool9o`000003ooooool0003o000000Wo00002Oooool2o`0000;ooooo0_l000000ooo
oooo0000o`000003ooooo`;o00001ooooolJo`000003ooooool0003o000000?o00003oooool2o`00
01;ooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`Co00003?ooool5
o`00037ooooo000Looooo`03o`000?oooooooooo02Kooooo0_l0000Sooooo`;o00001_ooool8o`00
00;ooooo0_l0000Hooooo`;o000000?oooooo`000?l000005Ol00005ooooo`;o00001Oooool2o`00
0003ooooool0003o000000;o00001Oooool2o`0000Oooooo5_l000001?oooooo0000o`000?ooool2
o`0000Cooooo1?l00002ooooo`;o00002?ooool4o`0000kooooo0_l000001?oooooo0000o`000?oo
ool2o`000003ooooool0003o000000Cooooo0_l00003ooooo`;o00002_ooool4o`00037ooooo0000
1_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0
1?ooool00ol0003oooooooooo`0Vooooo`;o00001_ooool3o`0001Oooooo0_l000000ooooooo0000
o`00000:ooooo`;o00001?ooool2o`0000?ooooo0_l00009ooooo`?o000000?oooooo`000?l00000
1?ooool2o`000003ooooool0003o000001Oo00000_ooool3o`0000Cooooo0_l00004ooooo`;o0000
1Oooool2o`0000Gooooo0_l00002oooooaCo00001?ooool2o`0000;ooooo1_l00002ooooo`;o0000
0_ooool2o`0000Cooooo1?l0000<ooooo`Co00003?ooool2o`0000Cooooo0_l0000oooooo`0000Ko
ooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo02kooooo0ol00009ooooo`;o000000?oooooo`000?l000000oooool2o`0000Co
oooo0_l0000Hooooo`Co00001oooool3o`000003ooooool0003o000000Cooooo4_l000001?oooooo
0000o`000?l00004ooooo`;o00000_ooool2o`0000Gooooo0_l000001?oooooo0000o`000?ooool2
o`0000cooooo0ol00002oooooaGo00001?ooool5o`0000Wooooo1?l0000Booooo`;o00000_ooool2
o`0000;ooooo0_l00006ooooo`;o00000_ooool2o`0000?ooooo0_l0000looooo`0000?ooooooa0@
4?ooool00_ooool00ol@413oooooooooo`09ooooo`Go00001_ooool00ol0003oooooooooo`0/oooo
o`;o00002_ooool4o`000004ooooool0003o0000ooooo`Co00005Oooool2o`0000Oooooo1_l0000=
oooooaGo00000_ooool4o`0000[ooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o
000000?ooooo0_l00008ooooo`;o000000?oooooo`000?l000001_l00002ooooo`co00001?ooool3
o`000004ooooool0003o0000ooooo`;o00001oooool2o`00017ooooo0_l00002ooooo`?o00000_oo
ool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool2o`0003cooooo0000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001ooo
ool3o`0002cooooo0_l0000:ooooo`;o00001_ooool2o`000004ooooool0003o0000o`0001?ooooo
0_l0000;ooooo`;o000000?oooooo`000?l000000oooool2o`000003ooooool0003o000000;ooooo
0_l00006ooooo`go00000_ooool4o`0000[ooooo0_l000000ooooooo0000o`000005ooooo`;o0000
00?oooooo`000?l000001?ooool2o`0000;ooooo2_l00002ooooo`Co000000?oooooo`000?l00000
0ol00008ooooo`;o000000Coooooo`000?l0003ooooo0ol00004ooooo`Co000000?oooooo`000?l0
00003_ooool2o`000004ooooool0003o0000o`0000Oooooo0ol000000ooooooo0000o`000015oooo
o`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`00
00Oooooo00?o0000ooooooooool0?Oooool2o`0000;ooooo1Ol0000<ooooo`;o000000?oooooo`00
0?l000000_ooool2o`0000?ooooo0_l00009ooooo`;o00000oooool2o`000003ooooool0003o0000
00_ooooo0ol000000ooooooo0000o`00000;o`0000;ooooo0_l00007ooooo`Co00001_ooool3o`00
00Kooooo0_l00002ooooo`Wo00000oooool4o`000003ooooool0003o000000?o00002oooool2o`00
00;ooooo1?l00002ooooo`Co000000?oooooo`000?l000004Oooool2o`0000?ooooo0_l00003oooo
o`Go00001?ooool2o`00043ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[o
oooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0kooooo`Co00000_ooool2o`0000oo
oooo0_l000000ooooooo0000o`000007ooooo`;o00001?ooool2o`0000Cooooo0_l00002ooooo`;o
00001?ooool2o`0000Sooooo3ol00004ooooo`;o00001oooool4o`0000Oooooo1?l00003ooooo`;o
00000_ooool2o`0000;ooooo1_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l00003oooo
o`?o00002?ooool2o`0000Cooooo0_l00007ooooo`;o00000_ooool2o`0001;ooooo0_l000000ooo
oooo0000o`000003ooooo`;o00001?ooool2o`0000Sooooo0_l0000fooooo`0000KoooooogMgMonH
V9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0>oooool2
o`0000cooooo1?l00006ooooo`;o00000oooool2o`0000[ooooo0_l00004ooooo`;o00000_ooool4
o`000004ooooool0003o0000o`0000Kooooo2?l00003ooooo`Ko00002?ooool2o`0000Gooooo0ol0
0008ooooo`;o00000oooool2o`0000;ooooo0_l00004ooooo`Go000000?oooooo`000?l000000ooo
ool3o`0000?ooooo0ol00006ooooo`;o00001?ooool3o`0000Sooooo0_l00002ooooo`;o00000ooo
ool2o`0000gooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000002_oo
ool4o`0003Cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool0
1_ooool00ol0003oooooooooo`11ooooo`;o00001_ooool4o`000003ooooool0003o000000?ooooo
0_l00003ooooo`;o00001_ooool4o`0000cooooo0_l000000ooooooo0000o`000007ooooo`Wo0000
0oooool5o`0000Sooooo0_l00004ooooo`Co00002?ooool2o`0000?ooooo0_l00008ooooo`Ko0000
1Oooool2o`0000gooooo0_l00004ooooo`?o000000?oooooo`000?l000003_ooool2o`0001Gooooo
0ol000001?oooooo0000o`000?ooool2o`0000Wooooo0_l0000dooooo`007?ooool00ol0003ooooo
ooooo`11ooooo`;o00002oooool2o`0000?ooooo0_l0000;ooooo`Co00003?ooool2o`000003oooo
ool0003o000000Wooooo1ol00003ooooo`;o000000?oooooo`000?l000002Oooool2o`0000?ooooo
0ol00005ooooo`;o00000_ooool2o`00013ooooo0ol0000Cooooo`;o000000?oooooo`000?l00000
0_ooool2o`0000;ooooo0_l0000Qooooo`;o00000_ooool2o`0000Gooooo0_l0000oooooo`007?oo
ool00ol0003oooooooooo`0kooooo`;o00001?ooool2o`0001?ooooo0_l00008ooooo`;o00003Ooo
ool2o`0000;ooooo0_l00007ooooo`So00002?ooool2o`0000Cooooo0_l00002ooooo`;o00001?oo
ool2o`0000Gooooo1Ol00004ooooo`;o00001Oooool2o`0000cooooo0_l0000<ooooo`Go00000_oo
ool2o`0000Kooooo0_l0000Mooooo`;o00002_ooool2o`0000Oooooo1?l0000cooooo`007?ooool0
0ol0003oooooooooo`0iooooo`Co00001Oooool2o`0000_ooooo0_l00005ooooo`;o00005oooool2
o`0000[ooooo1Ol00002ooooo`;o00002?ooool2o`0000Cooooo0_l0000Aooooo`?o00000oooool3
o`0000Gooooo0_l0000<ooooo`;o00001Oooool2o`0000Kooooo0_l00004ooooo`;o00001_ooool2
o`0000Wooooo0ol0000Fooooo`;o00001Oooool2o`0000Gooooo1_l0000cooooo`007?ooool00ol0
003oooooooooo`0iooooo`;o00001_ooool3o`0000Sooooo0_l000000ooooooo0000o`00000Boooo
o`Co00003?ooool2o`0000Kooooo1Ol00006ooooo`;o00006Oooool2o`0000Sooooo1_l00002oooo
o`;o00002oooool2o`0000Kooooo0_l0000:ooooo`Ko00003oooool3o`0000kooooo1?l00004oooo
o`;o00003?ooool2o`0000Cooooo0ol0000`ooooo`007?ooool00ol0003oooooooooo`10ooooo`?o
00002Oooool4o`00013ooooo0_l000000ooooooo0000o`000002o`0000Sooooo0_l00002ooooo`;o
00004Oooool2o`0000gooooo0_l0000:ooooo`;o00001?ooool4o`0000;ooooo1?l0000?ooooo`;o
00004_ooool6o`00023ooooo1?l00007ooooo`Co00003Oooool3o`00033ooooo000Looooo`03o`00
0?oooooooooo02kooooo0_l0000@ooooo`;o00002_ooool4o`000003ooooool0003o000000;o0000
1oooool6o`000004ooooool0003o0000o`0000Oooooo1?l00007ooooo`;o00006oooool2o`0000ko
oooo1_l0000Dooooo`;o00005Oooool2o`0002gooooo1?l00002ooooo`;o0000??ooool001cooooo
00?o0000ooooooooool0;_ooool2o`0001Sooooo0_l00002ooooo`_o00001Oooool4o`0000Cooooo
0_l00007ooooo`;o00002Oooool2o`0001kooooo0_l00004ooooo`Co00000oooool2o`0000;ooooo
0_l000000ooooooo0000o`00000Aooooo`;o000000?oooooo`000?l00000??ooool2o`0000?ooooo
0ol00003ooooo`Co0000>_ooool001cooooo00?o0000ooooooooool0>_ooool2o`0000cooooo0_l0
0004ooooo`?o00001?ooool2o`0000Wooooo0ol000000ooooooo0000o`00000Hooooo`;o00003_oo
ool2o`0000Sooooo0_l00004ooooo`Co00002_ooool2o`00017ooooo0_l000000ooooooo0000o`00
000Hooooo`;o00002_ooool2o`0001Kooooo0_l00004ooooo`;o00000oooool4o`0000Oooooo0_l0
000aooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o00002_ooool3o`0002Cooooo0ol00000
0ooooooo0000o`00000:ooooo`;o00003?ooool2o`0000kooooo0_l00004ooooo`;o00007?ooool2
o`0000kooooo0_l00002ooooo`;o00005?ooool2o`0000[ooooo1?l0000Dooooo`;o00004Oooool2
o`000004ooooool0003o0000ooooo`;o0000;_ooool001cooooo00?o0000ooooooooool0;Oooool2
o`0000[ooooo0_l0000<ooooo`;o00005Oooool2o`0000Oooooo0_l00007ooooo`;o00003?ooool2
o`0000cooooo0_l000000ooooooo0000o`000003ooooo`;o00005_ooool2o`0000Cooooo0_l0000>
ooooo`;o00000_ooool4o`00023ooooo0_l0000Dooooo`;o00003?ooool2o`0000?ooooo0_l00004
ooooo`;o0000;_ooool001cooooo00?o0000ooooooooool08oooool2o`0001?ooooo0_l00003oooo
o`;o00002?ooool2o`0001Gooooo0_l00007ooooo`Co00001?ooool2o`0000gooooo0_l000000ooo
oooo0000o`000004ooooo`;o00000_ooool6o`0000;ooooo0_l0000Gooooo`;o00006_ooool2o`00
01kooooo0_l0000Tooooo`;o0000>Oooool001cooooo0_l0000Tooooo`;o00004oooool2o`0000?o
oooo0ol0000Yooooo`;o00001?ooool2o`00013ooooo0_l00004ooooo`;o00000_ooool4o`0000Co
oooo0_l00004ooooo`;o00000oooool2o`000003ooooool0003o000000Gooooo1?l0000?ooooo`Co
000000?oooooo`000?l000000_l0000Iooooo`;o00002Oooool2o`0002;ooooo1?l0000iooooo`00
7?ooool00ol0003oooooooooo`0nooooo`Ko00002oooool3o`0000?ooooo0_l00008ooooo`;o0000
00?oooooo`000?l000003?ooool2o`0000?ooooo0_l00009ooooo`;o00002Oooool2o`0000cooooo
0_l00003ooooo`;o000000?oooooo`000?l000001Oooool4o`0000Sooooo0_l00005ooooo`Co0000
00?oooooo`000?l000000_l0000Aooooo`;o00001_ooool2o`0000;ooooo0_l00004ooooo`;o0000
1?ooool2o`0001[ooooo0_l000000ooooooo0000o`000005ooooo`;o0000=?ooool001cooooo00?o
0000ooooooooool0=oooool2o`0000?ooooo0_l00002ooooo`Co00001?ooool2o`0000Gooooo0ol0
0003ooooo`;o00000_ooool2o`0000;ooooo1ol00009ooooo`;o000000?oooooo`000?l000000ooo
ool2o`0000Wooooo0_l0000Oooooo`;o00003Oooool2o`0000;ooooo0_l00002ooooo`;o00000_oo
ool2o`0001Oooooo0_l00006ooooo`;o00000_ooool2o`0000Cooooo0_l000001?oooooo0000o`00
0?ooool2o`0000oooooo0ol00008ooooo`;o00002?ooool2o`0000?ooooo0_l0000_ooooo`007?oo
ool00ol0003oooooooooo`0Tooooo`;o00004Oooool2o`000003ooooool0003o000000;o00001?oo
ool2o`0000?ooooo0ol0000;ooooo`;o00000_ooool3o`000003ooooool0003o000000;ooooo0_l0
000:ooooo`;o00002_ooool2o`0000_ooooo0_l0000Iooooo`;o00002oooool4o`0000;ooooo0_l0
0002ooooo`;o00000_ooool2o`0000;ooooo0_l00002ooooo`;o00009?ooool2o`0001;ooooo0ol0
000Gooooo`;o0000;oooool001cooooo00?o0000ooooooooool09?ooool2o`0000kooooo0_l00003
ooooo`?o00000_ooool2o`0000Oooooo0_l00006ooooo`;o00001?ooool2o`0000?ooooo0_l0000M
ooooo`;o000000Coooooo`000?l0003o00001oooool2o`0002Kooooo0_l000001?oooooo0000o`00
0?ooool2o`0000Kooooo0_l00002ooooo`Ko00001_ooool2o`0000Wooooo0_l0000Aooooo`;o0000
6Oooool2o`0004;ooooo000Looooo`03o`000?oooooooooo033ooooo0_l00002ooooo`;o00000ooo
ool4o`000005ooooool0003o0000o`000?ooool00_l0000;ooooo`;o00006?ooool2o`0000;ooooo
1?l000000ooooooo0000o`000008ooooo`?o00005Oooool2o`0000;ooooo0ol00007ooooo`;o0000
3Oooool2o`000003ooooool0003o000000cooooo0_l00008ooooo`;o00000_ooool2o`0000Gooooo
0_l000001?oooooo0000o`000?ooool2o`0000Sooooo0_l000000ooooooo0000o`00000Iooooo`;o
00001oooool2o`0000Kooooo0_l0000aooooo`007?ooool00ol0003oooooooooo`0`ooooo`Ko0000
1Oooool2o`0000;ooooo1ol00009ooooo`;o00006?ooool?o`0000Cooooo0_l000000ooooooo0000
o`000009ooooo`?o00001oooool7o`0000Oooooo0_l0000<ooooo`;o00001Oooool4o`0000gooooo
0_l00006ooooo`;o00002?ooool2o`000003ooooool0003o000000Sooooo0_l000000ooooooo0000
o`00000Qooooo`?o00001_ooool2o`00037ooooo000Looooo`03o`000?oooooooooo033ooooo1_l0
00000ooooooo0000o`000007ooooo`;o00000_ooool2o`0000Cooooo0_l00003ooooo`?o00000_oo
ool2o`0001?ooooo4Ol00005ooooo`;o00002Oooool3o`0000Wooooo0_l0000@ooooo`Co00001?oo
ool2o`0000Gooooo1?l0000=ooooo`;o00008?ooool2o`000003ooooool0003o000001[ooooo0_l0
0002ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0<?ooool2o`000005ooooool0003o
0000o`000?ooool01?l00007ooooo`;o00001_ooool2o`0000?ooooo0ol00002ooooo`;o00003_oo
ool2o`0000;ooooo3ol000000ooooooo0000o`00000@ooooo`;o00003?ooool2o`0000kooooo1?l0
0007ooooo`;o00001?ooool2o`00037ooooo1?l0000Fooooo`;o000000?oooooo`000?l000000_oo
ool2o`0003[ooooo000Looooo`03o`000?oooooooooo03?ooooo0ol000000ooooooo0000o`000004
o`0000Gooooo0_l0000Oooooo`_o00000_ooool;o`0000Gooooo0_l00004ooooo`;o00000_ooool2
o`0000Gooooo0ol00004ooooo`;o00000oooool2o`0000Sooooo0_l00005ooooo`;o00000oooool2
o`0000Cooooo0ol0000?ooooo`;o00003Oooool2o`0000Cooooo0_l0000:ooooo`Co00004?ooool2
o`0000?ooooo0ol00011ooooo`007?ooool00ol0003oooooooooo`0dooooo`Go00000_ooool2o`00
01?ooooo0_l0000@ooooo`co000000?oooooo`000?l000002_l000001?oooooo0000o`000?ooool3
o`0000Cooooo0_l000000ooooooo0000o`000006ooooo`?o00000_ooool2o`0000Gooooo0_l00000
0ooooooo0000o`000005ooooo`;o00001Oooool4o`0000Sooooo0_l0000=ooooo`Co00003Oooool4
o`0000;ooooo1?l0000Looooo`;o00000oooool2o`0000Cooooo0ol0000kooooo`007?ooool00ol0
003oooooooooo`0Zooooo`;o00002Oooool2o`0000Kooooo0_l0000@ooooo`?o00000_ooool2o`00
00;ooooo0_l00008oooooaOo00000oooool2o`000003ooooool0003o000000Sooooo0_l0000;oooo
o`?o00001?ooool2o`000003ooooool0003o000000gooooo0ol0000;ooooo`;o000000?oooooo`00
0?l000001Oooool4o`00017ooooo0_l00004ooooo`;o000000?oooooo`000?l000007?ooool2o`00
00Kooooo1?l0000jooooo`007?ooool00ol0003oooooooooo`0Zooooo`;o00004Oooool2o`0000Go
oooo0_l00009ooooo`;o00000oooool2o`0000;ooooo0_l00007oooooaSo00001?ooool2o`0000co
oooo0_l00003ooooo`Go00000_ooool2o`0000;ooooo1?l00003ooooo`;o00002oooool2o`0000co
oooo1Ol00003ooooo`Co00007?ooool2o`0000Sooooo0_l0000Booooo`;o00002?ooool2o`0003[o
oooo000Looooo`03o`000?oooooooooo03kooooo0_l00004ooooo`;o00006_oooolKo`0000;ooooo
0_l0000<ooooo`;o000000?oooooo`000?l000001Ol000000ooooooo0000o`000003ooooo`;o0000
1?ooool8o`0000Kooooo0_l00009ooooo`?o00000_ooool2o`0000Cooooo0_l000000ooooooo0000
o`00000Uooooo`;o00004?ooool2o`0000Kooooo0_l0000nooooo`007?ooool00ol0003ooooooooo
o`0kooooo`;o000000?oooooo`000?l000000oooool2o`0000_ooooo0_l0000>ooooo`Ko000000?o
ooooo`000?l000003ol000000ooooooo0000o`000002o`0000[ooooo0_l00005ooooo`;o00001?oo
ool4o`0000Wooooo0_l000000ooooooo0000o`000003o`0000?ooooo0_l0000<ooooo`Go00000ooo
ool2o`0000?ooooo0ol0000Aooooo`;o00009?ooool2o`0000Kooooo0_l00007ooooo`;o0000=Ooo
ool001cooooo00?o0000ooooooooool0>oooool2o`0000Kooooo0_l00002ooooo`;o00001oooool2
o`0000_ooooo0_l00002ooooo`Co00000_oooolFo`000003ooooool0003o000000Oooooo0_l00006
ooooo`;o00000oooool2o`0000_ooooo0_l00003ooooo`;o00001?ooool2o`0000Oooooo0_l00000
0ooooooo0000o`000002o`000003ooooool0003o000000?ooooo1?l000000ooooooo0000o`000002
o`0000cooooo0ol000000ooooooo0000o`000008ooooo`?o00000oooool2o`0001[ooooo0_l00008
ooooo`Co0000=?ooool001cooooo0_l00015ooooo`;o000000?oooooo`000?l000005?ooool2o`00
00;ooooo7?l000000ooooooo0000o`00000?ooooo`;o00001?ooool2o`0000?ooooo0_l00002oooo
o`;o000000?oooooo`000?l000000oooool2o`0000Gooooo0_l000000ooooooo0000o`000003oooo
o`;o000000?oooooo`000?l000000_ooool3o`0000Cooooo0ol00003ooooo`;o00001oooool2o`00
00?ooooo0ol0000;ooooo`?o00000oooool2o`0000;ooooo0_l00007ooooo`;o00003Oooool2o`00
00Cooooo0_l00002ooooo`Co0000=?ooool001cooooo00?o0000ooooooooool0@oooool6o`0000Wo
oooo0_l0000=oooooaco00000oooool2o`0000Oooooo0_l0000:ooooo`;o00000oooool2o`0000;o
oooo0_l000000ooooooo0000o`00000:ooooo`;o000000?oooooo`000?l000000ol00007ooooo`?o
00000oooool3o`0000gooooo0_l0000Booooo`;o00001?ooool5o`0000Oooooo0_l0000?ooooo`;o
00000_ooool3o`0000;ooooo0_l0000eooooo`007?ooool00ol0003oooooooooo`0looooo`;o0000
1Oooool6o`0000Wooooo1ol00005ooooo`Wo00000_oooolBo`0000Gooooo0_l00007ooooo`;o0000
5?ooool2o`0000Gooooo0_l00009ooooo`Ko00000oooool2o`0000?ooooo1ol00006ooooo`;o0000
1Oooool2o`00017ooooo0_l00002ooooo`Ko00006Oooool2o`0000?ooooo1_l0000eooooo`007?oo
ool00ol0003oooooooooo`0dooooo`;o00001_ooool2o`0000kooooo0ol00002ooooo`So00001Ooo
oolNo`0000Cooooo0_l00009ooooo`;o00003oooool2o`000004ooooool0003o0000ooooo`;o0000
0_ooool3o`0000cooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000Co0000
00?oooooo`000?l000001_ooool2o`0000Gooooo0_l0000Dooooo`?o00002_ooool4o`0000;ooooo
0_l00004ooooo`;o00001oooool2o`0000?ooooo0_l0000gooooo`007?ooool00ol0003ooooooooo
o`0_ooooo`?o00000_ooool2o`0001Kooooo0ol00002ooooo`;o000000?oooooo`000?l000002Ooo
oolMo`0000Sooooo0_l00005ooooo`;o00003Oooool4o`0000Cooooo0_l00003ooooo`;o00003ooo
ool9o`0000_ooooo0_l000001?oooooo0000o`000?l0000:ooooo`;o00002oooool3o`0000[ooooo
1?l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l00007ooooo`;o00000_ooool2o`0003So
oooo000Looooo`03o`000?oooooooooo02oooooo0ol00002ooooo`;o000000?oooooo`000?l00000
4oooool2o`0000oooooo8?l00007ooooo`Co00000oooool2o`0000;ooooo0_l00009ooooo`;o0000
1?ooool2o`0001;ooooo1?l00003ooooo`?o000000?oooooo`000?l000001?ooool2o`0000;ooooo
0_l000001?oooooo0000o`000?ooool5o`0000?ooooo0_l00003ooooo`;o00000_ooool3o`0000Oo
oooo0_l00003ooooo`;o00001oooool2o`0000Gooooo0_l00007ooooo`Co000000?oooooo`000?l0
00000_l0000hooooo`007?ooool00ol0003oooooooooo`0dooooo`;o000000?oooooo`000?l00000
1Oooool4o`0000[ooooo0_l00003ooooo`?o00002Oooool>o`000003ooooool0003o000000oo0000
2Oooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`0000_ooooo0_l00009ooooo`;o0000
0_ooool2o`0000;ooooo1_l00002ooooo`;o000000Goooooo`000?l0003o0000ooooo`05o`0000;o
oooo0ol00003ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0000Oooooo0ol0000<oooo
o`;o00001oooool2o`0000Gooooo0_l00004ooooo`;o000000?oooooo`000?l000000_l000001?oo
oooo0000o`000?l0000iooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00000_ooool2o`00
00Sooooo1?l0000?ooooo`?o00002Oooool2o`000003ooooool0003o000001[o00000_ooool7o`00
00kooooo0_l00009ooooo`;o00001oooool2o`0000;ooooo0_l00002ooooo`;o00000_ooool8o`00
0003ooooool0003o000000?o000000?oooooo`000?l000000_l00002ooooo`Co00000oooool2o`00
00;ooooo0ol00002ooooo`;o00001_ooool2o`0000oooooo0_l0000<ooooo`;o00001?ooool2o`00
00Oooooo0ol0000hooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00001_ooool2o`0000;o
oooo0_l0000>ooooo`?o00004_oooolAo`000003ooooool0003o0000013o00002_ooool2o`0000go
oooo0_l00002ooooo`;o00000oooool4o`0000;ooooo0_l00002ooooo`;o00000_oooolAo`000003
ooooool0003o000000;o000000Coooooo`000?l0003ooooo0_l00003ooooo`Ko00001Oooool3o`00
00oooooo0_l00006ooooo`?o00000oooool2o`000003ooooool0003o000000Cooooo1?l00003oooo
o`;o00001?ooool2o`0003;ooooo000Looooo`03o`000?oooooooooo033ooooo0_l00006ooooo`;o
00000_ooool2o`0000kooooo0ol0000Aoooooa;o000000?oooooo`000?l000002Ol00009ooooo`;o
00001_ooool2o`0000Gooooo0_l0000:ooooo`;o00000oooool4o`0000;ooooo1_l00002oooooaco
00001Oooool2o`0000Gooooo1?l00004ooooo`;o00004_ooool3o`0000Kooooo0_l00004ooooo`Co
00002Oooool2o`0003;ooooo000Looooo`03o`000?oooooooooo033ooooo0_l0000^ooooo`;o0000
00?oooooo`000?l000005_l00005ooooo`;o00001Oooool2o`0000gooooo0_l0000?ooooo`co0000
00?oooooo`000?l000002_l000000ooooooo0000o`00000=o`0000gooooo0ol00004ooooo`?o0000
0_ooool2o`0000kooooo0_l00004ooooo`;o00000_ooool2o`0000[ooooo0_l0000hooooo`007?oo
ool00ol0003oooooooooo`19ooooo`?o00001_ooool2o`0000gooooo1Ol000000ooooooo0000o`00
000?o`000003ooooool0003o000000?ooooo1?l0000Dooooo`;o00001?ooool4o`0000Gooooo0_l0
0002ooooo`Co000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00000Ko`000003oooo
ool0003o000000Cooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o
00000oooool2o`0000Oooooo1?l00004ooooo`;o00000_ooool4o`0000Sooooo0_l0000hooooo`00
7?ooool00ol0003oooooooooo`0jooooo`;o00003Oooool5o`0000Cooooo0_l0000=ooooo`Co0000
00?oooooo`000?l000003?l00002ooooo`;o00001_ooool2o`0000Gooooo0_l00008ooooo`?o0000
0_ooool3o`0000Cooooo1Ol00005ooooo`;o00000_ooool4o`0000Cooooo8?l000001?oooooo0000
o`000?l00003ooooo`;o00001oooool2o`000003ooooool0003o000000Oooooo0ol00007ooooo`Co
00002Oooool3o`000003ooooool0003o000000?o0000??ooool001cooooo00?o0000ooooooooool0
>_ooool2o`0000?ooooo1?l00002ooooo`;o00001Oooool2o`0000Sooooo0_l0000<oooooaCo0000
1_ooool2o`0000Gooooo0_l00007ooooo`Co00000_ooool5o`0000;ooooo1?l00002ooooo`;o0000
1oooool2o`0000?ooooo0_l000000ooooooo0000o`00000Mo`0000;ooooo0_l0000Hooooo`;o0000
2_ooool2o`0000Wooooo2Ol0000looooo`007?ooool00ol0003oooooooooo`0iooooo`;o00001?oo
ool4o`0000;ooooo0_l000000ooooooo0000o`00000<ooooo`;o00001Oooool4o`0000;ooooo5?l0
0002ooooo`;o00004oooool2o`0000Cooooo1Ol00004ooooo`;o00000_ooool2o`0000Oooooo0_l0
00000ooooooo0000o`000004o`000003ooooool0003o000001_o00000_ooool2o`000003ooooool0
003o000002gooooo0ol000000ooooooo0000o`00000nooooo`007?ooool00ol0003oooooooooo`0b
ooooo`;o00001Oooool2o`0000Gooooo0_l00006ooooo`;o00000_ooool2o`0000oooooo1?l00002
oooooa?o00000oooool2o`0000Gooooo0_l00002ooooo`?o00002?ooool4o`0000oooooo0_l00006
ooooo`;o000000?oooooo`000?l000001Ol000000ooooooo0000o`000004o`0000;ooooo4Ol00000
1Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`000?l00000;Oooool3o`0000[ooooo0_l0
000eooooo`007?ooool2o`0003?ooooo0_l00006ooooo`;o00001?ooool2o`0000Gooooo0_l00003
ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Kooooo1?l00002oooooaCo00000_ooool2
o`0000?ooooo1?l00002ooooo`Co00001oooool4o`0000gooooo1?l00003ooooo`;o00000oooool5
o`000003ooooool0003o000001Go000000?oooooo`000?l000002?l00002ooooo`?o00002Oooool2
o`000003ooooool0003o000000;o00000oooool4o`0001Gooooo1?l00009ooooo`;o0000=Oooool0
01cooooo00?o0000ooooooooool0>_ooool2o`0000Gooooo0_l00004ooooo`;o00001_ooool3o`00
00?ooooo0_l00008ooooo`;o00000_oooolDo`0000;ooooo0_l00003ooooo`;o00001_ooool4o`00
00cooooo0_l00008ooooo`;o00001Oooool4o`000003ooooool0003o000002Ko00000_ooool3o`00
00Cooooo1?l000001?oooooo0000o`000?ooool4o`0000?ooooo1?l0000Eooooo`Co0000@?ooool0
01cooooo00?o0000ooooooooool0@Oooool2o`0000;ooooo0ol00004ooooo`;o00000_ooool2o`00
00Gooooo0_l00005ooooo`;o00001Oooool7o`0000;ooooo1Ol00002ooooo`;o00000_ooool2o`00
00gooooo0_l00004ooooo`;o00001_ooool5o`0000Cooooo0_l00006ooooo`Co000000?oooooo`00
0?l000009_l00002ooooo`;o00001Oooool4o`000003ooooool0003o000000;o000000?oooooo`00
0?l000005_ooool2o`0000oooooo0_l0000gooooo`007?ooool00ol0003oooooooooo`0iooooo`;o
000000?oooooo`000?l000001oooool3o`0000Cooooo0_l00009ooooo`?o00001?ooool3o`0000Ko
oooo0ol000000ooooooo0000o`000003ooooo`Oo00000_ooool2o`0000oooooo0_l00002ooooo`;o
00002?ooool3o`0000Cooooo0_l00006ooooo`_o000000?oooooo`000?l000007Ol000001?oooooo
0000o`000?ooool4o`0000Cooooo0_l00004ooooo`;o00006Oooool2o`0000_ooooo0ol000000ooo
oooo0000o`00000gooooo`007?ooool00ol0003oooooooooo`0iooooo`;o000000?oooooo`000?l0
00003oooool2o`0000?ooooo2?l00004ooooo`Co00001?ooool4o`000004ooooool0003o0000oooo
o`;o00000oooool2o`0000Cooooo0_l00003ooooo`;o00000_ooool2o`0000Gooooo0ol00006oooo
o`;o00001Oooool2o`0000Oooooo0_l00005ooooo`Wo000000?oooooo`000?l000007Ol000001?oo
oooo0000o`000?ooool6o`0002;ooooo0_l0000<ooooo`?o0000>_ooool001cooooo00?o0000oooo
ooooool0>?ooool3o`0000?ooooo0_l00009ooooo`Oo00000_ooool6o`0000Kooooo1?l00004oooo
o`Co00001?ooool2o`0000Cooooo0ol00007ooooo`;o00000_ooool2o`0000Gooooo0_l00007oooo
o`;o00000_ooool6o`0000Kooooo0_l00005ooooo`;o00000_oooolIo`000003ooooool0003o0000
00Wo00001_ooool4o`0001?ooooo0_l0000=ooooo`;o00002_ooool2o`0003gooooo000Looooo`03
o`000?oooooooooo03Gooooo0_l000000ooooooo0000o`000004ooooo`;o00001oooool9o`0000?o
oooo1?l0000?ooooo`?o00001?ooool2o`0000;ooooo0_l000001?oooooo0000o`000?l0000;oooo
o`;o00000_ooool2o`0000Cooooo0_l00008ooooo`Ko00001?ooool2o`0000Oooooo0_l00003oooo
oaSo000000?oooooo`000?l000001_l000001Ooooooo0000o`000?l0003ooooo00;o00000_ooool4
o`000003ooooool0003o0000013ooooo0_l0000Iooooo`;o0000?Oooool001cooooo00?o0000oooo
ooooool0=Oooool2o`00013ooooo0ol00003ooooo`;o00001oooool4o`0000Cooooo0_l00006oooo
o`Co00000oooool2o`0000;ooooo0_l000000ooooooo0000o`00000@ooooo`;o00000oooool5o`00
00Cooooo0_l0000:ooooo`;o00000_ooool2o`0000;ooooo0ol000000ooooooo0000o`00000Ho`00
0003ooooool0003o000000ko00001_ooool2o`0000[ooooo0_l000000ooooooo0000o`000004oooo
o`Co00001Oooool4o`0000Kooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`0aooooo`;o
00006Oooool2o`0000Sooooo1?l00004ooooo`;o00001_ooool7o`0001?ooooo0_l00004ooooo`;o
00000oooool5o`0000Cooooo0_l0000=ooooo`?o00000_ooool2o`0000;ooooo6_l000000ooooooo
0000o`00000Bo`000004ooooool0003o0000ooooo`;o00001oooool3o`000003ooooool0003o0000
00Cooooo1?l00005ooooo`Co00001?ooool4o`0000Kooooo0_l0000jooooo`007?ooool00ol0003o
ooooooooo`0aooooo`Co00005oooool2o`0000;ooooo1?l00002ooooo`Go00001_ooool2o`0000Ko
oooo1?l0000Cooooo`;o00001?ooool2o`0000?ooooo0_l0000Fooooo`;o00000oooool3o`0000Co
oooo4?l000000ooooooo0000o`000004o`000003ooooool0003o000001;o000000Coooooo`000?l0
003ooooo0_l00003ooooo`;o00000_ooool2o`0001Sooooo0ol00008ooooo`;o0000>_ooool001co
oooo00?o0000ooooooooool0<Oooool4o`0001Oooooo0_l00002ooooo`Co00000_ooool5o`0000Ko
oooo1?l00004ooooo`;o0000?Oooool3o`000003ooooool0003o000001Oo000000Coooooo`000?l0
003ooooo3_l000001?oooooo0000o`000?l00009ooooo`;o00003Oooool2o`0000?ooooo0_l00008
ooooo`;o00002?ooool2o`0003_ooooo000Looooo`03o`000?oooooooooo03kooooo0_l00005oooo
o`;o00000_ooool2o`000003ooooool0003o000000[ooooo0_l00007ooooo`Co00001?ooool4o`00
01oooooo0_l00009ooooo`;o000000?oooooo`000?l000003oooool]o`000003ooooool0003o0000
017ooooo0ol00004ooooo`;o00000oooool2o`0000cooooo0_l00004ooooo`;o00004oooool2o`00
02Kooooo000Looooo`03o`000?oooooooooo03kooooo0_l000000ooooooo0000o`000002ooooo`Ko
00001_ooool2o`0000kooooo0_l00007ooooo`?o00006Oooool2o`0000Cooooo0_l00004ooooo`;o
00000oooool2o`000003ooooool0003o000000Sooooo0_l00005ooooobgo00005?ooool3o`0000?o
oooo1?l00004ooooo`;o00002_ooool2o`0001Wooooo0_l0000Vooooo`007?ooool00ol0003ooooo
ooooo`0hooooo`;o00001oooool3o`0000;ooooo0ol00005ooooo`;o000000?oooooo`000?l00000
2_ooool2o`0000Wooooo1?l00006ooooo`;o00001?ooool2o`0000cooooo0_l0000:ooooo`;o0000
00?oooooo`000?l000000oooool2o`0000Cooooo0_l00002ooooo`Co000000?oooooo`000?l00000
1Ol000000ooooooo0000o`00000Uo`0000?ooooo0_l0000<ooooo`;o00001oooool4o`0000Cooooo
0ol00005ooooo`;o00000oooool5o`0003gooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGo
oooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0Qoooo
o`;o00005Oooool2o`0000Sooooo0_l00002ooooo`;o00001Oooool3o`0000gooooo0_l00009oooo
o`?o00000_ooool2o`0000?ooooo0_l00004ooooo`?o00004oooool4o`0000?ooooo0_l00003oooo
o`;o00001?ooool2o`0000;ooooo1?l000001?oooooo0000o`000?ooool2o`0000;ooooo:?l00003
ooooo`;o00003?ooool2o`0000Wooooo0_l00005ooooo`;o000000?oooooo`000?l000000_ooool2
o`0000?ooooo1Ol0000mooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?oo
ool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool08Oooool2o`0000cooooo
0_l0000:ooooo`;o00002oooool2o`0000?ooooo0_l00009ooooo`;o00003oooool2o`0000;ooooo
0_l00004ooooo`;o00000oooool3o`0000Cooooo0_l00009ooooo`;o00000_ooool4o`0000Oooooo
0_l00004ooooo`;o00000oooool2o`0000?ooooo=?l0000<ooooo`;o00000oooool2o`0000Cooooo
0_l00008ooooo`;o0000BOooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0;oooool2o`0000[ooooo
1?l00007ooooo`Co00001_ooool2o`0000Kooooo0_l00007ooooo`;o00004?ooool4o`000004oooo
ool0003o0000ooooo`Ko00002Oooool2o`0000gooooo0_l00004ooooo`;o00000oooool2o`0000?o
oooo4Ol000000ooooooo0000o`000007o`000003ooooool0003o000000ko000000?oooooo`000?l0
00001Ol00003ooooo`;o00001oooool2o`0000?ooooo0_l0001Iooooo`0000?oooooo`000?ooool0
0_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0003go
oooo1?l00005ooooo`;o00001Oooool2o`000003ooooool0003o000000Gooooo0_l00002ooooo`;o
00001?ooool4o`0000kooooo1?l00004ooooo`Co00003oooool4o`0001Oooooo6ol000000ooooooo
0000o`000008o`0000?ooooo0_l000001?oooooo0000o`000?l00008ooooo`;o00001oooool2o`00
00[ooooo0_l0001Booooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05
o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0oooooo`;o00001Oooool2o`00
00;ooooo0_l000001?oooooo0000o`000?ooool2o`0000Gooooo0_l00002ooooo`;o000000?ooooo
o`000?l000000oooool2o`0000Kooooo0_l00006ooooo`;o00001?ooool2o`0000Cooooo0_l00002
ooooo`;o00001?ooool2o`0000?ooooo1?l00006ooooo`;o00001?ooool2o`0000Wooooo0_l00000
0ooooooo0000o`00000Fo`000003ooooool0003o000000So000000?oooooo`000?l000000_l00000
1?oooooo0000o`000?ooool2o`0000Kooooo0_l0000Cooooo`;o00001oooool2o`000003ooooool0
003o000004Kooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEE
ohN7Qoooool02?ooool00ol0003oooooooooo`0aooooo`;o00001oooool2o`0000[ooooo0_l00002
ooooo`;o000000?oooooo`000?l000000_l0000:ooooo`;o000000?oooooo`000?l000002oooool2
o`0000cooooo0_l00004ooooo`;o00000_ooool2o`0000Cooooo0_l0000=ooooo`;o00001?ooool2
o`0000?ooooo1?l00002ooooo`;o00001Oooool;o`000005ooooool0003o0000o`000?ooool03ol0
00000ooooooo0000o`000004o`0000;ooooo0_l00003ooooo`;o00000oooool2o`0001?ooooo0_l0
0003ooooo`Co000000?oooooo`000?l00000A_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo037ooooo0_l00002ooooo`;o0000
0oooool2o`0000kooooo0_l00003ooooo`;o00003Oooool2o`0000gooooo0_l0000Aooooo`;o0000
1Oooool2o`0000?ooooo0_l000000ooooooo0000o`00000Booooo`Co00001?ooool2o`0000Cooooo
5?l000000ooooooo0000o`000004o`000003ooooool0003o000000?o000000Coooooo`000?l0003o
00000_ooool2o`0000?ooooo0_l00003ooooo`;o00003?ooool2o`0000Gooooo0_l00003ooooo`?o
00000_ooool2o`0004Kooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4
A?l0003o410@1_ooool00ol0003oooooooooo`0Wooooo`;o00003?ooool2o`0000;ooooo0_l0000?
ooooo`;o00008Oooool2o`00017ooooo0_l00005ooooo`;o00000_ooool6o`0000Cooooo1?l0000?
ooooo`;o000000?oooooo`000?l000001?oooolKo`000003ooooool0003o000000?o000000?ooooo
o`000?l000000oooool2o`0000Cooooo0_l0000<ooooo`Ko00002oooool2o`0004[ooooo000Loooo
o`03o`000?oooooooooo02Oooooo0_l0000<ooooo`;o00000_ooool2o`0000oooooo1Ol0000Zoooo
o`;o000000?oooooo`000?l000001?ooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool3
o`000004ooooool0003o0000ooooo`Co00003oooool5o`0000Cooooo0_l000001Ooooooo0000o`00
0?l0003ooooo01Co000000?oooooo`000?l000000_l00002ooooo`?o00000_ooool2o`0000Cooooo
0_l0000<ooooo`Co0000FOooool001cooooo00?o0000ooooooooool0=Oooool2o`0001Gooooo0ol0
0002ooooo`;o00003oooool2o`0000Sooooo0_l00008ooooo`;o000000Coooooo`000?l0003ooooo
0_l00004ooooo`;o00001?ooool2o`0000?ooooo1?l000000ooooooo0000o`00000;ooooo`;o0000
1?ooool2o`0000?ooooo0_l00007oooooaWo000000?oooooo`000?l000000_l00003ooooo`Co0000
00?oooooo`000?l000000_l0000?ooooo`;o00002_ooool2o`0004oooooo000Looooo`03o`000?oo
oooooooo03?ooooo1?l00006ooooo`;o00004_ooool2o`0000oooooo0_l00008ooooo`;o00002?oo
ool2o`000005ooooool0003o0000o`000?ooool01ol00004ooooo`;o00000oooool2o`0000cooooo
0_l00002ooooo`;o00001?ooool2o`0000Sooooo0_l00002oooooaGo000000?oooooo`000?l00000
3Ol000000ooooooo0000o`000002o`0000oooooo0_l00004ooooo`;o00001?ooool2o`000003oooo
ool0003o000004cooooo000Looooo`03o`000?oooooooooo03?ooooo0_l00008ooooo`;o00006Ooo
ool2o`0000gooooo0_l0000@ooooo`_o00000_ooool2o`0000?ooooo0_l00003ooooo`;o00002Ooo
ool2o`0001;ooooo1?l000000ooooooo0000o`00000Go`0000;ooooo2ol00009ooooo`;o00000ooo
ool2o`0000Sooooo0_l00007ooooo`;o00001Oooool3o`0004Cooooo000Looooo`03o`000?oooooo
oooo05Kooooo1?l00004ooooo`;o00001oooool2o`0000oooooo3?l000000ooooooo0000o`000002
o`0000;ooooo0_l00003ooooo`;o00002?ooool2o`0000Sooooo0_l00003ooooo`Co00000oooool3
o`000003ooooool0003o000000;ooooo2_l000001Ooooooo0000o`000?l0003ooooo00Go00000_oo
ool6o`0000Cooooo0ol00008ooooo`Co000000?oooooo`000?l000000_l0000>ooooo`;o00001_oo
ool3o`0004Cooooo000Looooo`03o`000?oooooooooo04;ooooo0_l00009ooooo`;o00001?ooool5
o`0000Kooooo0_l0000DoooooaGo000000Coooooo`000?l0003o00003?ooool3o`000003ooooool0
003o000000Oo00000oooool4o`0000?ooooo0ol000001?oooooo0000o`000?ooool6o`0000?ooooo
0_l00002ooooo`?o000000?oooooo`000?l000000oooool3o`0000;ooooo0ol00003ooooo`?o0000
0_ooool2o`000004ooooool0003o0000o`0000;ooooo0ol00002ooooo`;o00003_ooool2o`0004go
oooo000Looooo`03o`000?oooooooooo03cooooo0_l00004ooooo`;o00000oooool2o`0000Cooooo
0_l00004ooooo`Co00005_ooool2o`0000Gooooo5?l00002ooooo`?o00001_ooool5o`000003oooo
ool0003o000000;ooooo1ol00007ooooo`;o000000Coooooo`000?l0003ooooo0_l000001?oooooo
0000o`000?ooool;o`0000;ooooo3?l000000ooooooo0000o`000004o`0000?ooooo0_l000001?oo
oooo0000o`000?ooool3o`0000?ooooo0_l00003ooooo`;o00004?ooool2o`0004[ooooo000Loooo
o`03o`000?oooooooooo03cooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool3o`00
00gooooo0_l0000Dooooo`?o00001_oooolDo`0000Wooooo1Ol00002ooooo`;o00004_ooool2o`00
00Cooooo0_l00002ooooo`;o000000?oooooo`000?l000002?l000000ooooooo0000o`00000Ao`00
0003ooooool0003o000000Cooooo0_l00009ooooo`;o00000oooool3o`0000[ooooo0ol00019oooo
o`007?ooool00ol0003oooooooooo`10ooooo`;o000000?oooooo`000?l000000_l000000ooooooo
0000o`000002o`0000_ooooo0_l0000Eooooo`;o00001_oooolGo`0000Cooooo0_l00003ooooo`;o
00000_ooool2o`0001Sooooo0_l000001Ooooooo0000o`000?l0003ooooo00Ko000000?oooooo`00
0?l000000ol00003ooooo`_o00000_ooool2o`0000Kooooo0_l00004ooooo`;o00002Oooool3o`00
00Gooooo0_l00004ooooo`?o0000B?ooool001cooooo00?o0000ooooooooool0AOooool2o`0000?o
oooo0_l0000Booooo`;o00004oooool2o`0000;ooooo5_l00004ooooo`;o00000oooool5o`0000;o
oooo0_l0000Eooooo`Go00000_ooool2o`0000;ooooo0ol000000ooooooo0000o`000002o`000003
ooooool0003o000000[o00002oooool2o`0000Cooooo0_l00006ooooo`;o000000?oooooo`000?l0
00001_ooool2o`0000Gooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o0000
0_ooool2o`0000kooooo0_l00008ooooo`;o00002Oooool2o`0000Kooooo1?l00002oooooa?o0000
3_ooool3o`0000;ooooo0_l00005ooooo`;o00004?ooool2o`0000?ooooo0_l00003ooooo`;o0000
0oooool2o`000003ooooool0003o000000Co000000Coooooo`000?l0003ooooo0_l0000Aooooo`;o
00001_ooool2o`0000_ooooo0_l0001=ooooo`007?ooool2o`00047ooooo0_l00002ooooo`;o0000
2Oooool2o`000003ooooool0003o000000;o00001_ooool2o`0000_ooooo0_l00006ooooo`;o0000
0ooooolDo`0000;ooooo0ol00006ooooo`?o00000oooool2o`000003ooooool0003o000000Cooooo
0_l00003ooooo`;o00003_ooool2o`0000Gooooo1?l000000ooooooo0000o`000002ooooo`Go0000
1?ooool2o`00017ooooo0_l00006ooooo`;o00002?ooool2o`000003ooooool0003o000004gooooo
000Looooo`03o`000?oooooooooo043ooooo0_l00004ooooo`;o00001oooool2o`000003ooooool0
003o000000Sooooo0_l0000>ooooo`;o00000oooool2o`0000;ooooo5Ol000000ooooooo0000o`00
0002o`0000Kooooo1?l00002ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o00000_oo
ool2o`0000kooooo0_l00006ooooo`?o00001Oooool2o`0000Oooooo1?l0000Gooooo`;o00002?oo
ool2o`00053ooooo000Looooo`03o`000?oooooooooo03_ooooo0_l00006ooooo`;o000000?ooooo
o`000?l000000oooool2o`0001oooooo0_l00007oooooaGo000000Coooooo`000?l0003o00001?oo
ool3o`0000;ooooo1?l00002ooooo`;o000000Coooooo`000?l0003ooooo1?l00002ooooo`;o0000
3Oooool2o`0000;ooooo0_l00003ooooo`Go00000_ooool2o`0000Sooooo1?l0000Eooooo`;o0000
1Oooool2o`0005Gooooo000Looooo`03o`000?oooooooooo03_ooooo0_l00006ooooo`;o00001?oo
ool7o`0000Cooooo0ol0000Aooooo`;o00001Oooool2o`0000Cooooo5ol00006ooooo`?o00001?oo
ool2o`0000;ooooo1?l00002ooooo`Co00000_ooool2o`0000gooooo0_l00002ooooo`;o00001_oo
ool2o`0000;ooooo0_l0000Mooooo`;o00000_ooool2o`0000?ooooo1?l00002ooooo`;o0000DOoo
ool001cooooo00?o0000ooooooooool0@oooool2o`0000Cooooo0_l00002ooooo`?o00001?ooool3
o`00017ooooo0_l00003ooooo`Co00001_oooolEo`0000_ooooo0_l00004ooooo`Co000000?ooooo
o`000?l000000ol0000Eooooo`;o00002?ooool2o`00013ooooo0_l0000=ooooo`;o00000oooool2
o`0000;ooooo0ol00003ooooo`?o0000D?ooool001cooooo00?o0000ooooooooool0Aoooool2o`00
00Gooooo0_l000000ooooooo0000o`00000Iooooo`?o00002?oooolEo`0000Sooooo0_l000000ooo
oooo0000o`000004ooooo`;o00000oooool2o`0000Oooooo1?l0000?ooooo`;o00001?ooool4o`00
00[ooooo0_l00004ooooo`;o00000oooool2o`0000_ooooo1_l000001?oooooo0000o`000?l00003
ooooo`;o00000_ooool2o`0004cooooo000Looooo`03o`000?oooooooooo047ooooo0_l00004oooo
o`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000001Wooooo0_l00009oooo
oaGo00000_ooool3o`0000?ooooo0_l00003ooooo`;o00004?ooool4o`0000Cooooo0_l00009oooo
o`;o00001?ooool2o`0000;ooooo0_l00008ooooo`;o00000oooool2o`0000Cooooo0_l00006oooo
o`;o00000oooool3o`000004ooooool0003o0000ooooo`?o000000?oooooo`000?l000001?ooool2
o`0004cooooo000Looooo`03o`000?oooooooooo03gooooo0_l00002ooooo`;o000000?oooooo`00
0?l000001?ooool2o`0002_ooooo0_l00002ooooo`ko000000?oooooo`000?l000000_ooool3o`00
0003ooooool0003o000000Gooooo0_l00005ooooo`;o00002_ooool2o`0000Gooooo0_l0000Coooo
o`;o000000?oooooo`000?l000002_ooool2o`0000cooooo0_l00004ooooo`;o00002?ooool2o`00
05;ooooo000Looooo`03o`000?oooooooooo03gooooo0_l00005ooooo`;o00004_ooool2o`0001;o
oooo0ol00008ooooo`So000000?oooooo`000?l000001ol00009ooooo`;o00002?ooool2o`000003
ooooool0003o000000Co00001oooool2o`0001gooooo0_l0000Iooooo`;o00001_ooool3o`0005So
oooo000Looooo`03o`000?oooooooooo04kooooo0_l00008ooooo`;o00001?ooool2o`000003oooo
ool0003o000000Wooooo0ol00008ooooo`So000000?oooooo`000?l000002?l0000Booooo`;o0000
00Coooooo`000?l0003ooooo0ol00009ooooo`?o00001Oooool4o`00023ooooo0_l0000:ooooo`;o
00001_ooool3o`0000Wooooo0_l0000Fooooo`;o0000=Oooool001cooooo00?o0000ooooooooool0
C_ooool3o`0000Wooooo0_l00002ooooo`Go00005?ooool=o`000003ooooool0003o000000?o0000
7?ooool2o`0000Kooooo0ol00004ooooo`Go00005_ooool2o`0000Sooooo0_l0000Nooooo`;o0000
5_ooool2o`0003Gooooo000Looooo`03o`000?oooooooooo04[ooooo0_l00003ooooo`;o000000?o
ooooo`000?l000001_ooool2o`0000Cooooo0_l0000Gooooo`ko00000oooool2o`0000;ooooo1?l0
000?ooooo`;o00000oooool2o`0000gooooo0_l000000ooooooo0000o`000002ooooo`?o00001?oo
ool2o`000003ooooool0003o000000Sooooo0_l00003ooooo`Co00001_ooool2o`0000cooooo0ol0
0003ooooo`;o0000E?ooool001cooooo00?o0000ooooooooool0B_ooool6o`0000;ooooo0ol00000
0ooooooo0000o`00000Eooooo`Co00001_ooool2o`000003ooooool0003o000000_o00000oooool2
o`000003ooooool0003o000000?o00002_ooool2o`0000?ooooo0_l00004ooooo`;o00002_ooool3
o`0000;ooooo0_l00002ooooo`Go00000_ooool7o`0000Gooooo0_l00004ooooo`Co00001_ooool2
o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`?o00000oooool2o`0005Cooooo000Loooo
o`03o`000?oooooooooo04cooooo1?l00003ooooo`Go00000_ooool2o`0000Cooooo0_l0000;oooo
o`Co00000oooool2o`000004ooooool0003o0000ooooo`go00001_ooool2o`0000gooooo0_l00003
ooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`?o00001_ooool2o`000003ooooool0003o
000000Cooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l00002ooooo`;o000000?ooooo
o`000?l000001oooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o00001oooool2
o`0005?ooooo000Looooo`03o`000?oooooooooo04;ooooo0_l0000@ooooo`;o00001?ooool2o`00
00Cooooo0_l0000=ooooo`Oo00001?ooool2o`000003ooooool0003o000000So00001?ooool2o`00
00Kooooo0_l00002ooooo`;o00000oooool2o`0000oooooo0_l00003ooooo`;o00003?ooool2o`00
00Cooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00008ooooo`;o00003?ooool2o`00
00Oooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00003?ooool2o`000003
ooooool0003o000000Gooooo0_l0000<ooooo`;o00001Oooool6o`0000Sooooo1Ol000000ooooooo
0000o`000005ooooo`?o00000_ooool2o`0000;ooooo0_l00002ooooo`;o00000oooool4o`00013o
oooo1?l00009ooooo`;o000000?oooooo`000?l000001?ooool2o`0000?ooooo0ol000000ooooooo
0000o`000002ooooo`;o00002?ooool2o`000004ooooool0003o0000ooooo`;o0000I?ooool001co
oooo0_l0001Aooooo`;o000000?oooooo`000?l000001Oooool2o`0000[ooooo1?l0000Dooooo`Co
000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00000oooool2o`0000Wooooo0_l00002oooo
o`;o00004?ooool4o`0000Wooooo1?l00005ooooo`;o000000?oooooo`000?l000000ol000001?oo
oooo0000o`000?l00007ooooo`?o00001?ooool2o`000003ooooool0003o000006Cooooo000Loooo
o`03o`000?oooooooooo05Kooooo1?l00008ooooo`;o00000_ooool2o`0000kooooo0_l00007oooo
o`;o00001Oooool2o`0001;ooooo0_l0000@ooooo`Co00000_ooool2o`0000Sooooo1Ol00008oooo
o`Co00000oooool3o`0000;ooooo0_l00002ooooo`?o00002_ooool4o`0005oooooo000Looooo`03
o`000?oooooooooo04Oooooo0_l0000=ooooo`Co00001oooool3o`0001;ooooo0_l00007ooooo`?o
00000oooool2o`0000_ooooo0_l0000?ooooo`;o00001oooool4o`0000cooooo1Ol00004ooooo`;o
00001?ooool2o`0000Cooooo0_l000001?oooooo0000o`000?l00005ooooo`;o00002?ooool4o`00
05oooooo000Looooo`03o`000?oooooooooo04Oooooo0_l0000=ooooo`;o00002Oooool2o`0000ko
oooo0_l00005ooooo`;o00001_ooool2o`0000?ooooo0_l0000;ooooo`;o00002_ooool2o`0000?o
oooo0_l00007ooooo`Co00001Oooool4o`0000cooooo0_l00008ooooo`;o00000oooool2o`0000Ko
oooo0_l00004ooooo`;o000000?oooooo`000?l000000oooool2o`0005gooooo000Looooo`03o`00
0?oooooooooo05Sooooo1?l0000Eooooo`;o00001Oooool2o`0001_ooooo0_l00003ooooo`;o0000
0_ooool2o`0001;ooooo0_l000000ooooooo0000o`000002o`0001Kooooo0_l000000ooooooo0000
o`000002o`000003ooooool0003o000000;o00000_ooool3o`0000;ooooo0_l000000ooooooo0000
o`000003ooooo`;o0000GOooool001cooooo00?o0000ooooooooool0E?ooool2o`0000;ooooo1?l0
000:ooooo`;o00001Oooool2o`0000;ooooo0_l0000Gooooo`;o00000oooool2o`0000Cooooo0_l0
0003ooooo`Ko00000oooool2o`000004ooooool0003o0000o`0000Wooooo0_l00009ooooo`;o0000
1oooool2o`0000?ooooo0_l00005ooooo`Co000000?oooooo`000?l000000_l00002ooooo`?o0000
2Oooool3o`000003ooooool0003o000005[ooooo000Looooo`03o`000?oooooooooo053ooooo0_l0
0002ooooo`;o000000?oooooo`000?l000002oooool4o`0000Gooooo0_l0000Dooooo`;o00001Ooo
ool2o`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l000001?l00004ooooo`?o000000Co
ooooo`000?l0003o00004_ooool4o`0000Oooooo0ol00002ooooo`;o00001Oooool4o`0000gooooo
0_l00004ooooo`;o00000_ooool2o`0005[ooooo000Looooo`03o`000?oooooooooo053ooooo0_l0
0002ooooo`;o000000?oooooo`000?l000000_l00009ooooo`;o00007Oooool2o`0000_ooooo0ol0
0005ooooo`;o00001_ooool4o`0000Gooooo0_l00008ooooo`?o00001Oooool2o`0000[ooooo0_l0
0002ooooo`;o00000_ooool2o`0001;ooooo0_l00004ooooo`Co0000G?ooool001cooooo00?o0000
ooooooooool0D?ooool2o`0000;ooooo0_l00003ooooo`;o00007_ooool2o`0000Cooooo0_l0000;
ooooo`;o00000_ooool5o`0000_ooooo0ol00006ooooo`?o00000oooool2o`0000;ooooo0ol0000=
ooooo`;o00001_ooool3o`000003ooooool0003o000001Wooooo0ol0001Looooo`007?ooool00ol0
003oooooooooo`1@ooooo`;o000000?oooooo`000?l000001?ooool2o`0000?ooooo0_l0000Foooo
o`;o000000?oooooo`000?l000001?ooool2o`0000_ooooo0_l00005ooooo`;o00000oooool2o`00
00Kooooo0ol00007ooooo`;o00000oooool2o`0001;ooooo0ol00006ooooo`;o00003oooool2o`00
00_ooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00002Oooool2o`0001Ko
oooo0_l000000ooooooo0000o`00000Mooooo`Co00000oooool4o`0000Wooooo1?l00006ooooo`Co
00001oooool5o`00013ooooo1?l00003ooooo`;o000000?oooooo`000?l000001?ooool2o`00013o
oooo0_l0001?ooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o00009?ooool4o`00017ooooo
0_l0000<ooooo`Oo00001oooool2o`0000;ooooo1?l00006ooooo`Co000000?oooooo`000?l00000
1?ooool2o`0001?ooooo1?l00003ooooo`;o000000?oooooo`000?l000001?ooool4o`0000kooooo
0_l0001?ooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o00002?ooool2o`0000Cooooo0_l0
00000ooooooo0000o`000006ooooo`;o00000_ooool2o`0000Cooooo0ol000000ooooooo0000o`00
0004ooooo`;o00002_ooool2o`0000cooooo1Ol00008ooooo`?o00000_ooool2o`0000?ooooo0_l0
0002ooooo`;o00001?ooool2o`0000Gooooo0_l00006ooooo`;o00002oooool2o`0000Cooooo0_l0
0009ooooo`;o0000Goooool001cooooo00?o0000ooooooooool0F?ooool2o`000003ooooool0003o
000000Cooooo1Ol00003ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Cooooo0ol00000
0ooooooo0000o`000004ooooo`;o00006?ooool4o`0000Wooooo0_l00008ooooo`;o00000_ooool4
o`0000Wooooo0_l00006ooooo`;o000000?oooooo`000?l000002Oooool2o`0000?ooooo0_l00002
ooooo`;o0000I_ooool001cooooo00?o0000ooooooooool0EOooool2o`000004ooooool0003o0000
ooooo`;o00001?ooool3o`0000Gooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo0_l0000T
ooooo`;o00002oooool2o`0000?ooooo0_l00007ooooo`;o00002_ooool2o`0000?ooooo0_l00003
ooooo`;o00002Oooool2o`000003ooooool0003o000000Cooooo0_l0001Vooooo`007?ooool00ol0
003oooooooooo`1Eooooo`;o00004oooool2o`0000;ooooo0_l00002ooooo`?o00002?ooool2o`00
02Sooooo1?l00003ooooo`Go00001Oooool2o`0000Wooooo0_l00003ooooo`;o00004Oooool2o`00
01?ooooo0_l000000ooooooo0000o`00001Dooooo`007?ooool2o`0005Sooooo0_l0000Aooooo`;o
00001oooool2o`0000Sooooo0_l00002ooooo`;o00009?ooool2o`0000Gooooo1Ol00005ooooo`;o
000000?oooooo`000?l000000_ooool2o`0000cooooo1?l0000<ooooo`;o00004Oooool2o`000003
ooooool0003o000005Cooooo000Looooo`03o`000?oooooooooo05Oooooo0_l00008ooooo`;o0000
1?ooool2o`0001Gooooo0_l000001?oooooo0000o`000?l0000Gooooo`;o00004Oooool4o`0000Wo
oooo0_l00002ooooo`Co00002_ooool4o`0000Sooooo0_l00002ooooo`;o0000J_ooool001cooooo
00?o0000ooooooooool0HOooool2o`0000Cooooo0_l00002ooooo`Co00003oooool6o`0001Oooooo
1?l0000<ooooo`;o00002Oooool2o`0000Wooooo0_l00002ooooo`;o00002?ooool3o`0000Oooooo
0_l0001^ooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o00001?ooool4o`00013ooooo0ol0
000Kooooo`;o00001_ooool2o`0000Cooooo0_l00005ooooo`;o00000_ooool2o`0000Sooooo1?l0
00000ooooooo0000o`000009ooooo`;o00001_ooool2o`0006oooooo000Looooo`03o`000?oooooo
oooo05Sooooo0_l0000;ooooo`;o00005_ooool5o`0002?ooooo0ol00006ooooo`;o00000_ooool2
o`0000;ooooo0_l00008ooooo`Co000000?oooooo`000?l000004?ooool3o`0000Sooooo0_l00000
0ooooooo0000o`00001Rooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o00003_ooool2o`00
00Oooooo0_l0000:ooooo`Co00006Oooool2o`0000Kooooo0_l000001?oooooo0000o`000?l00006
ooooo`;o00002Oooool2o`0000Wooooo0ol0000@ooooo`;o00002Oooool2o`000003ooooool0003o
000006;ooooo000Looooo`03o`000?oooooooooo06Sooooo0_l00007ooooo`;o00001_ooool4o`00
00Kooooo0_l0000Aooooo`;o00000_ooool2o`0000Kooooo0_l000000ooooooo0000o`000003o`00
00oooooo0_l00009ooooo`;o00001?ooool2o`0007gooooo000Looooo`03o`000?oooooooooo06oo
oooo0_l00008ooooo`Co00000oooool2o`000003ooooool0003o000000;o00003oooool2o`0000Oo
oooo0_l00005ooooo`Co00008?ooool2o`0000gooooo0_l0001^ooooo`007?ooool00ol0003ooooo
ooooo`1Mooooo`;o00004?ooool3o`000003ooooool0003o000000Cooooo0_l00005ooooo`;o0000
0oooool2o`000004ooooool0003o0000ooooo`;o00000oooool2o`0000Wooooo0_l00002ooooo`Ko
00001?ooool2o`0000Cooooo0_l00005ooooo`;o00002Oooool2o`0000Oooooo0_l00002ooooo`;o
00002Oooool2o`0006kooooo000Looooo`03o`000?oooooooooo05gooooo0_l000000ooooooo0000
o`000002ooooo`;o00002_ooool2o`000003ooooool0003o000000Cooooo0_l00005ooooo`;o0000
1_ooool2o`000003ooooool0003o000000?ooooo0_l00004ooooo`;o00000oooool2o`0000Cooooo
1?l00004ooooo`;o00001?ooool2o`0000Gooooo1?l00007ooooo`Co00000oooool4o`0000;ooooo
0_l0001iooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o00000_ooool2o`0000Oooooo0_l0
0006ooooo`;o00002Oooool2o`0001Cooooo0_l00004ooooo`;o00002?ooool2o`000003ooooool0
003o000000gooooo0_l00005ooooo`?o000000Coooooo`000?l0003ooooo1?l00004ooooo`?o0000
0_ooool3o`0007?ooooo000Looooo`03o`000?oooooooooo063ooooo0_l00009ooooo`Ko00001?oo
ool2o`0000;ooooo1Ol00004ooooo`?o00001?ooool2o`00017ooooo0_l00008ooooo`;o000000?o
ooooo`000?l000005?ooool3o`0000Cooooo0ol00005ooooo`So00005?ooool2o`0005gooooo000L
ooooo`03o`000?oooooooooo06;ooooo0_l00007ooooo`;o000000Coooooo`000?l0003o00002?oo
ool5o`0000Cooooo0ol00003ooooo`Co00006?ooool2o`0000Sooooo0_l0000Gooooo`;o00001_oo
ool4o`0001Oooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1Rooooo`;o00002Oooool3
o`0000oooooo0_l00002ooooo`;o00000oooool4o`0000Sooooo0_l0000>ooooo`;o00002?ooool2
o`0000Sooooo0_l00007ooooo`;o00001oooool3o`0000;ooooo0ol0001gooooo`0000Koooooonk^
k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo
00?o0000ooooooooool0KOooool5o`0000gooooo0_l00002ooooo`;o00000oooool2o`0000Kooooo
0_l00002ooooo`;o00008?ooool4o`0000Cooooo0_l000001?oooooo0000o`000?l00006ooooo`?o
00000_ooool4o`0007Kooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44oooo
o`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1`ooooo`;o00000_ooool2
o`0000Gooooo0_l0000;ooooo`;o00001_ooool2o`0001Oooooo0_l00009ooooo`Co00001_ooool2
o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o0000M_ooool0
0003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool0Ioooool2o`0000Kooooo0ol000001?oooooo0000o`000?l0
0005ooooo`;o00000_ooool3o`0001Cooooo0_l00003ooooo`;o00003?ooool2o`0000Wooooo0_l0
0005ooooo`Co00001oooool3o`0000?ooooo0_l0001kooooo`0000?oooooo`000?ooool00_ooool0
0ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`0006Cooooo0_l0
00000ooooooo0000o`000002o`000004ooooool0003o0000ooooo`?o000000?oooooo`000?l00000
1Oooool2o`0000?ooooo0ol0000?ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o0000
7_ooool5o`0000Kooooo0_l00003ooooo`;o0000O?ooool00003ooooool0003ooooo00;ooooo00?o
0000ooooooooool02Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0
I?ooool2o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`;o00001_ooool2o`0001?ooooo
1?l000001?oooooo0000o`000?l0000:ooooo`;o000000?oooooo`000?l000006?ooool2o`0000;o
oooo0_l00005ooooo`Co0000O?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool0
2Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0KOooool2o`0000?o
oooo0_l00006ooooo`;o00004oooool2o`0000;ooooo0ol00002ooooo`;o00001oooool2o`000003
ooooool0003o000000oooooo1?l00008ooooo`Ko00000_ooool3o`0007gooooo00001_ooooooMgMg
oiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooo
oooo06cooooo0ol0000;ooooo`;o00005oooool3o`0000;ooooo0_l0000Eooooo`;o00001?ooool6
o`0000Kooooo0_l000000ooooooo0000o`000002o`00087ooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo06cooooo
0_l0000>ooooo`;o00001oooool2o`0000Wooooo0_l0000Mooooo`;o00002?ooool2o`0000Sooooo
0_l000000ooooooo0000o`000005ooooo`;o00000_ooool2o`0007Kooooo000Looooo`03o`000?oo
oooooooo07[ooooo1?l00007ooooo`;o00002Oooool2o`0002Oooooo0_l00002ooooo`;o00001?oo
ool2o`0000Sooooo0_l00002ooooo`;o000000?oooooo`000?l00000Loooool001cooooo00?o0000
ooooooooool0Moooool2o`000003ooooool0003o000000kooooo0_l0000<ooooo`;o00005oooool2
o`0000Gooooo1ol0000Eooooo`;o0000Loooool001cooooo00?o0000ooooooooool0Moooool4o`00
00oooooo0_l0000<ooooo`;o00002Oooool2o`0000cooooo0ol00004ooooo`Ko0000Roooool001co
oooo00?o0000ooooooooool0N?ooool3o`0000oooooo0_l00005ooooo`?o00003oooool3o`0000?o
oooo0_l00007ooooo`;o00001Oooool2o`0000;ooooo0_l0002:ooooo`007?ooool00ol0003ooooo
ooooo`2:ooooo`;o00001Oooool3o`0000oooooo0ol00003ooooo`;o00001_ooool2o`0000[ooooo
0_l0002:ooooo`007?ooool00ol0003oooooooooo`1cooooo`;o00007Oooool2o`0000?ooooo0_l0
000Hooooo`;o0000U_ooool001cooooo00?o0000ooooooooool0J_ooool2o`0000Oooooo0_l0000<
ooooo`;o00003?ooool2o`000004ooooool0003o0000ooooo`Co00005Oooool2o`0009Wooooo000L
ooooo`03o`000?oooooooooo06[ooooo0_l0000Eooooo`?o00002oooool4o`0000;ooooo1?l0000E
ooooo`;o0000VOooool001cooooo00?o0000ooooooooool0MOooool2o`0000_ooooo0_l00008oooo
o`Co000000?oooooo`000?l000001?ooool2o`0000Wooooo0_l0002Uooooo`007?ooool00ol0003o
ooooooooo`1eooooo`;o00005?ooool5o`0000oooooo0_l000000ooooooo0000o`000002o`0000Co
oooo0ol00006ooooo`;o00001?ooool2o`0001Sooooo0_l0001dooooo`007?ooool00ol0003ooooo
ooooo`2;ooooo`?o00004Oooool2o`0000?ooooo0_l00004ooooo`?o00001_ooool2o`0000Cooooo
0_l0000Hooooo`;o0000M?ooool001cooooo0_l0002=ooooo`?o00005Oooool2o`0000cooooo0ol0
0002ooooo`;o0000T?ooool001cooooo00?o0000ooooooooool0SOooool2o`0001Oooooo0ol00009
ooooo`?o00000_ooool2o`00093ooooo000Looooo`03o`000?oooooooooo0:Kooooo0ol0000?oooo
o`;o0000Soooool001cooooo00?o0000ooooooooool0Z?ooool2o`0000Oooooo0_l00005ooooo`;o
0000Soooool001cooooo00?o0000ooooooooool0Z?ooool2o`0000Oooooo1?l0002Dooooo`007?oo
ool00ol0003oooooooooo`2`ooooo`;o000000Coooooo`000?l0003ooooo0_l0002Aooooo`007?oo
ool00ol0003oooooooooo`2/ooooo`;o00000_ooool2o`0000Cooooo0_l0002Aooooo`007?ooool0
0ol0003oooooooooo`2/ooooo`;o0000Voooool001cooooo00?o0000ooooooooool0/Oooool2o`00
09Kooooo000Looooo`03o`000?oooooooooo0;7ooooo0_l0002Fooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0T_ooool2o`000;Gooooo000Looooo`03o`000?oooooooooo09;ooooo0_l0002eoooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0:3ooooo
1?l0002Uooooo`007?ooool2o`000:7ooooo1?l0002Uooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`004_oo
ool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000oooo
ooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`00
5?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_oo
ool001Cooooo00?o0000ooooooooool0oooooomBooooo`004_ooool00omEEEGoIVIVo`00003ooooo
oeCooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Qooooo`04oa0@4?l0003o
0000ooooo`;o000000?o410@ooooooooool05_ooool4o`000003oa0@4?oooooooooo00;ooooo0_l0
00001?l@413oooooooooooooool5o`0000?ooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c02<ooooo`00
X_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l0000<ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00_ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Go8B4QoiRH
V?ooooooV9RHob4Q8@2<ooooo`00X_ooool01Ol0003ooooooooooooooooo000001_ooooo00?o0000
ooooooooool00_ooool5o`0000Cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol0003ooooooooooooo
oooo000008cooooo002Rooooo`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo00?o
0000ooooooooool00_ooool01?m4A4CogMgMooooool00006ooooo`03oiRHV?lQ8B7ok^k^00?ooooo
00Go<S8boiRHV?ooooooV9RHoc8b<P2<ooooo`00X_ooool01Ol0003oQhN7oooooonYZJWo000001_o
oooo00?o0000ooooooooool00_ooool01?oMgMgoEEEEooooool00007ooooo`03ogMgMomVIVKooooo
00;ooooo00Goc<c<o`000?l0003o0000olc<c02<ooooo`00XOooool00ol@413o0000ogMgM`02o`00
0003oiRHV?oooooooooo01Wooooo00?o0000ooooooooool00oooool00omgMgOoc<c<o`000008oooo
o`09o`000?ooooooooooooooool@413o^[Zjoooooonj^[[o410@08cooooo0032ooooo`03o`000?oo
oooooooo00?ooooo00?ok^k^odA4A?l000001?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo
00Go0000okZj^_oooooo^[Zjo`00002<ooooo`00`?ooool00omEEEGoIVIVo`000006ooooo`03ogMg
Mol0003ooooo00?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05ojVYZOl@413o0000oa0@
4?nYZJT0S?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1434) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.57827 .37024 Mdot
.58039 .3548 Mdot
.34499 .50369 Mdot
.56592 .59506 Mdot
.38443 .77922 Mdot
.34446 .46466 Mdot
.48277 .3315 Mdot
.45267 .32452 Mdot
.34238 .51098 Mdot
.59484 .30842 Mdot
.41842 .34083 Mdot
.65572 .6457 Mdot
.44125 .35273 Mdot
.59089 .56668 Mdot
.72691 .76957 Mdot
.61703 .53332 Mdot
.57963 .36876 Mdot
.39873 .68902 Mdot
.59974 .53517 Mdot
.32112 .46768 Mdot
.61422 .42458 Mdot
.58891 .57083 Mdot
.59672 .38892 Mdot
.59146 .56643 Mdot
.58454 .60726 Mdot
.60641 .39249 Mdot
.64593 .34576 Mdot
.61099 .62238 Mdot
.63235 .58651 Mdot
.42277 .33289 Mdot
.45101 .66699 Mdot
.60269 .81752 Mdot
.53232 .53866 Mdot
.6073 .75572 Mdot
.46431 .35746 Mdot
.73848 .53572 Mdot
.35158 .47523 Mdot
.43652 .3339 Mdot
.42828 .34031 Mdot
.46353 .3288 Mdot
.44946 .32912 Mdot
.60894 .37378 Mdot
.55533 .23086 Mdot
.38078 .38507 Mdot
.64011 .62848 Mdot
.26126 .68605 Mdot
.69379 .55562 Mdot
.56846 .5572 Mdot
.64537 .37784 Mdot
.26479 .5403 Mdot
.34386 .34994 Mdot
.46484 .36876 Mdot
.31205 .4933 Mdot
.38117 .13658 Mdot
.43598 .36526 Mdot
.59049 .65715 Mdot
.3452 .4884 Mdot
.60224 .57987 Mdot
.59672 .56546 Mdot
.74907 .41173 Mdot
.57948 .64079 Mdot
.35957 .6502 Mdot
.57571 .34411 Mdot
.4487 .5199 Mdot
.33366 .49389 Mdot
.42015 .34551 Mdot
.60953 .34632 Mdot
.44325 .36487 Mdot
.54321 .51766 Mdot
.37495 .51794 Mdot
.55877 .56055 Mdot
.42053 .33977 Mdot
.61695 .41978 Mdot
.61975 .6022 Mdot
.23988 .53076 Mdot
.23223 .66061 Mdot
.38938 .59941 Mdot
.73821 .50447 Mdot
.74708 .40362 Mdot
.28143 .59736 Mdot
.63217 .62357 Mdot
.44343 .72434 Mdot
.23395 .65242 Mdot
.65331 .37841 Mdot
.57683 .5279 Mdot
.44 .63535 Mdot
.61675 .60712 Mdot
.32937 .77586 Mdot
.54086 .60816 Mdot
.4726 .55328 Mdot
.36354 .50818 Mdot
.63105 .3925 Mdot
.56888 .6006 Mdot
.62783 .57932 Mdot
.77748 .42349 Mdot
.56313 .54896 Mdot
.58291 .58391 Mdot
.64509 .36545 Mdot
.4593 .37231 Mdot
.5658 .64142 Mdot
.39561 .52991 Mdot
.3653 .45455 Mdot
.57938 .6324 Mdot
.37853 .50403 Mdot
.62434 .41551 Mdot
.62715 .57968 Mdot
.42787 .34709 Mdot
.56498 .61928 Mdot
.38418 .24558 Mdot
.58362 .36811 Mdot
.62671 .61053 Mdot
.40046 .62359 Mdot
.69808 .43118 Mdot
.63814 .3946 Mdot
.38505 .37343 Mdot
.6052 .53832 Mdot
.59358 .59162 Mdot
.61457 .34652 Mdot
.37261 .45417 Mdot
.30351 .74371 Mdot
.63965 .3549 Mdot
.40524 .35797 Mdot
.63415 .42168 Mdot
.64221 .6625 Mdot
.32689 .49437 Mdot
.3823 .37717 Mdot
.44202 .2441 Mdot
.47362 .68168 Mdot
.61408 .60546 Mdot
.57712 .2432 Mdot
.3405 .45089 Mdot
.63055 .37607 Mdot
.44501 .36089 Mdot
.53015 .55444 Mdot
.59641 .36242 Mdot
.41006 .3589 Mdot
.38717 .65721 Mdot
.33255 .30651 Mdot
.59303 .40303 Mdot
.52499 .43076 Mdot
.44535 .38178 Mdot
.47774 .34635 Mdot
.79015 .63644 Mdot
.62505 .35591 Mdot
.38206 .62494 Mdot
.45262 .35735 Mdot
.50956 .67753 Mdot
.63412 .63573 Mdot
.42073 .71457 Mdot
.48381 .18145 Mdot
.60399 .7415 Mdot
.293 .37141 Mdot
.3957 .63105 Mdot
.44852 .38647 Mdot
.57658 .59199 Mdot
.61206 .40097 Mdot
.60117 .38961 Mdot
.5796 .64045 Mdot
.58412 .61841 Mdot
.54813 .56731 Mdot
.58661 .54802 Mdot
.49074 .57432 Mdot
.53132 .57253 Mdot
.69167 .5353 Mdot
.62756 .3968 Mdot
.56826 .59061 Mdot
.31482 .50007 Mdot
.65809 .59951 Mdot
.43518 .32856 Mdot
.59494 .57733 Mdot
.56809 .59725 Mdot
.61103 .64535 Mdot
.47151 .36037 Mdot
.56565 .82624 Mdot
.66292 .44377 Mdot
.54146 .81117 Mdot
.5338 .48745 Mdot
.33526 .52678 Mdot
.60912 .61229 Mdot
.36674 .63885 Mdot
.7745 .54288 Mdot
.55475 .59078 Mdot
.12465 .42725 Mdot
.5818 .57676 Mdot
.44952 .81556 Mdot
.63652 .53183 Mdot
.56865 .78897 Mdot
.45553 .71199 Mdot
.58901 .60443 Mdot
.60826 .28138 Mdot
.48405 .31859 Mdot
.36186 .54493 Mdot
.4526 .33416 Mdot
.31525 .49351 Mdot
.34371 .49881 Mdot
.41611 .54321 Mdot
.66361 .63924 Mdot
.65225 .57508 Mdot
.53798 .58112 Mdot
.39054 .4802 Mdot
.61816 .33648 Mdot
.40324 .6293 Mdot
.56866 .3578 Mdot
.50571 .86034 Mdot
.24436 .49733 Mdot
.44277 .31768 Mdot
.38771 .66363 Mdot
.37534 .48648 Mdot
.35743 .51298 Mdot
.40005 .63527 Mdot
.6183 .56681 Mdot
.62165 .35536 Mdot
.71939 .70651 Mdot
.32474 .27429 Mdot
.8689 .44355 Mdot
.64748 .37163 Mdot
.58186 .26288 Mdot
.44239 .32344 Mdot
.3598 .48227 Mdot
.59057 .58988 Mdot
.61849 .58071 Mdot
.60264 .42339 Mdot
.55992 .55895 Mdot
.62179 .43863 Mdot
.59115 .59836 Mdot
.4981 .33566 Mdot
.37809 .59778 Mdot
.41572 .54435 Mdot
.50917 .7026 Mdot
.63599 .407 Mdot
.81772 .50416 Mdot
.35388 .5181 Mdot
.7768 .53081 Mdot
.41646 .3534 Mdot
.37232 .66201 Mdot
.3289 .51662 Mdot
.39912 .61789 Mdot
.5487 .5515 Mdot
.32521 .46886 Mdot
.38436 .61134 Mdot
.45957 .6084 Mdot
.65037 .61013 Mdot
.31717 .24991 Mdot
.4659 .33357 Mdot
.572 .36604 Mdot
.55718 .61444 Mdot
.36279 .51872 Mdot
.51697 .57431 Mdot
.24865 .43785 Mdot
.38667 .28348 Mdot
.33739 .45073 Mdot
.41303 .57567 Mdot
.36325 .66183 Mdot
.32863 .38466 Mdot
.57367 .24746 Mdot
.57658 .35689 Mdot
.54995 .55498 Mdot
.61782 .79997 Mdot
.45197 .35803 Mdot
.55679 .60878 Mdot
.36075 .73234 Mdot
.4558 .36682 Mdot
.60349 .58176 Mdot
.41064 .37183 Mdot
.60078 .38893 Mdot
.73213 .37153 Mdot
.61942 .34751 Mdot
.56237 .55541 Mdot
.4287 .35501 Mdot
.37821 .45357 Mdot
.61121 .38862 Mdot
.60877 .5576 Mdot
.60919 .62059 Mdot
.43995 .56189 Mdot
.56923 .58253 Mdot
.52953 .82404 Mdot
.59029 .6018 Mdot
.35593 .49582 Mdot
.62214 .63379 Mdot
.68453 .28039 Mdot
.41355 .54026 Mdot
.61635 .34914 Mdot
.33308 .45057 Mdot
.33624 .50356 Mdot
.23222 .58528 Mdot
.43057 .39544 Mdot
.6328 .56226 Mdot
.35308 .52342 Mdot
.57758 .69894 Mdot
.4245 .3749 Mdot
.56316 .62949 Mdot
.49747 .41628 Mdot
.26584 .52073 Mdot
.31363 .48446 Mdot
.56408 .66722 Mdot
.60697 .41275 Mdot
.57289 .60729 Mdot
.37148 .50579 Mdot
.6645 .65468 Mdot
.63385 .59918 Mdot
.55974 .20476 Mdot
.43238 .57405 Mdot
.44704 .379 Mdot
.66248 .60679 Mdot
.54496 .58627 Mdot
.32821 .46912 Mdot
.6293 .40856 Mdot
.43028 .37911 Mdot
.60963 .37955 Mdot
.57274 .7818 Mdot
.32769 .24923 Mdot
.47266 .5784 Mdot
.38161 .60228 Mdot
.34288 .56517 Mdot
.58204 .78634 Mdot
.79934 .39909 Mdot
.7815 .60336 Mdot
.64592 .75283 Mdot
.38141 .49014 Mdot
.3124 .55992 Mdot
.33909 .49639 Mdot
.5977 .62669 Mdot
.3292 .49047 Mdot
.63248 .79817 Mdot
.58891 .5951 Mdot
.33632 .47912 Mdot
.80466 .46922 Mdot
.57354 .60297 Mdot
.57781 .35361 Mdot
.49159 .8461 Mdot
.71201 .27414 Mdot
.41699 .27836 Mdot
.36674 .47276 Mdot
.73156 .67553 Mdot
.58073 .58362 Mdot
.62122 .63361 Mdot
.62269 .40383 Mdot
.52352 .55534 Mdot
.36174 .63263 Mdot
.38198 .66681 Mdot
.43186 .30664 Mdot
.36561 .59289 Mdot
.66245 .61216 Mdot
.61291 .39101 Mdot
.50006 .55213 Mdot
.24 .57543 Mdot
.27089 .53952 Mdot
.44493 .31288 Mdot
.49078 .84513 Mdot
.54713 .40319 Mdot
.5202 .35334 Mdot
.29794 .44171 Mdot
.64047 .37838 Mdot
.59242 .82329 Mdot
.44842 .33384 Mdot
.27677 .27866 Mdot
.62601 .2942 Mdot
.61755 .56965 Mdot
.42486 .36847 Mdot
.52675 .62215 Mdot
.72434 .29216 Mdot
.22872 .34728 Mdot
.70021 .62348 Mdot
.54491 .61332 Mdot
.25047 .50876 Mdot
.5927 .58212 Mdot
.2499 .46917 Mdot
.59463 .60895 Mdot
.6135 .37837 Mdot
.59367 .30738 Mdot
.39176 .32504 Mdot
.65648 .43259 Mdot
.31982 .39759 Mdot
.39436 .62557 Mdot
.59381 .59814 Mdot
.61566 .56713 Mdot
.36192 .62601 Mdot
.59424 .39449 Mdot
.55398 .56081 Mdot
.81975 .48857 Mdot
.62557 .56875 Mdot
.43931 .32891 Mdot
.66617 .29854 Mdot
.64075 .50035 Mdot
.60055 .54396 Mdot
.65517 .3927 Mdot
.46099 .31901 Mdot
.43045 .35224 Mdot
.65666 .55733 Mdot
.42511 .32727 Mdot
.5737 .57246 Mdot
.213 .37484 Mdot
.58668 .39391 Mdot
.48372 .19963 Mdot
.60506 .35615 Mdot
.72878 .48822 Mdot
.46105 .36847 Mdot
.35515 .29503 Mdot
.54002 .63846 Mdot
.44659 .33735 Mdot
.67479 .37324 Mdot
.64583 .5807 Mdot
.64801 .58184 Mdot
.72061 .69831 Mdot
.36419 .49698 Mdot
.43507 .56217 Mdot
.42184 .33353 Mdot
.58504 .5576 Mdot
.5869 .53857 Mdot
.46086 .31999 Mdot
.25883 .33495 Mdot
.74514 .33744 Mdot
.59003 .59923 Mdot
.6211 .37893 Mdot
.62764 .37221 Mdot
.63588 .6407 Mdot
.57858 .6288 Mdot
.32149 .50334 Mdot
.36943 .44733 Mdot
.32847 .52866 Mdot
.42981 .566 Mdot
.37455 .28389 Mdot
.33707 .75621 Mdot
.4642 .32948 Mdot
.55279 .27164 Mdot
.46593 .57305 Mdot
.5359 .59849 Mdot
.36743 .46761 Mdot
.54633 .58336 Mdot
.56116 .57792 Mdot
.42768 .4026 Mdot
.40013 .77679 Mdot
.54011 .36918 Mdot
.63124 .41091 Mdot
.45758 .38018 Mdot
.66322 .59197 Mdot
.49299 .38968 Mdot
.37009 .6577 Mdot
.61324 .72859 Mdot
.41636 .349 Mdot
.5855 .34742 Mdot
.46758 .34387 Mdot
.62178 .58151 Mdot
.54057 .63082 Mdot
.63809 .37486 Mdot
.35539 .64712 Mdot
.53473 .54166 Mdot
.60212 .58493 Mdot
.44434 .17661 Mdot
.55639 .71063 Mdot
.50105 .32328 Mdot
.58799 .60157 Mdot
.62796 .56315 Mdot
.35409 .67011 Mdot
.62546 .57079 Mdot
.54077 .59347 Mdot
.69603 .44131 Mdot
.47601 .26324 Mdot
.40311 .65004 Mdot
.22446 .36802 Mdot
.64639 .37035 Mdot
.60256 .80524 Mdot
.3582 .46406 Mdot
.40746 .31348 Mdot
.72344 .32369 Mdot
.31103 .50331 Mdot
.28616 .37946 Mdot
.59099 .80873 Mdot
.40196 .52108 Mdot
.30255 .52195 Mdot
.59201 .33149 Mdot
.57536 .55208 Mdot
.59657 .59036 Mdot
.36571 .63614 Mdot
.61934 .35723 Mdot
.49046 .49563 Mdot
.18413 .56704 Mdot
.58791 .5728 Mdot
.54499 .20417 Mdot
.21762 .42278 Mdot
.26149 .52518 Mdot
.37542 .64289 Mdot
.37728 .66993 Mdot
.59567 .59797 Mdot
.68578 .42995 Mdot
.60733 .39305 Mdot
.60743 .5575 Mdot
.53071 .57596 Mdot
.36679 .48673 Mdot
.58603 .37198 Mdot
.37143 .4535 Mdot
.33277 .34746 Mdot
.52251 .81409 Mdot
.26557 .26595 Mdot
.44159 .37192 Mdot
.22146 .50393 Mdot
.41726 .37602 Mdot
.45044 .72562 Mdot
.30547 .49742 Mdot
.572 .61371 Mdot
.62072 .4104 Mdot
.5773 .55955 Mdot
.57709 .62573 Mdot
.61675 .56571 Mdot
.59193 .54266 Mdot
.29696 .23063 Mdot
.3959 .62409 Mdot
.55292 .54132 Mdot
.35218 .49976 Mdot
.2455 .66026 Mdot
.21556 .60665 Mdot
.6125 .56689 Mdot
.60161 .61361 Mdot
.59084 .37826 Mdot
.56922 .6307 Mdot
.42097 .3775 Mdot
.57871 .34657 Mdot
.62417 .59643 Mdot
.42436 .8307 Mdot
.63285 .58985 Mdot
.5648 .79931 Mdot
.46635 .34329 Mdot
.33972 .26142 Mdot
.5328 .61927 Mdot
.39404 .28426 Mdot
.43522 .56229 Mdot
.32512 .51469 Mdot
.41377 .38204 Mdot
.34906 .47511 Mdot
.1785 .53581 Mdot
.60529 .66787 Mdot
.57815 .59585 Mdot
.5353 .58922 Mdot
.33577 .527 Mdot
.36035 .80523 Mdot
.34245 .39631 Mdot
.60162 .6699 Mdot
.31784 .49848 Mdot
.64924 .35454 Mdot
.65924 .7217 Mdot
.60686 .36618 Mdot
.35308 .61647 Mdot
.44465 .32469 Mdot
.35641 .64625 Mdot
.47981 .77137 Mdot
.58251 .3635 Mdot
.57671 .40698 Mdot
.3582 .46643 Mdot
.60738 .31169 Mdot
.67296 .19178 Mdot
.62609 .29305 Mdot
.47707 .70444 Mdot
.61715 .39798 Mdot
.63128 .58296 Mdot
.45485 .74807 Mdot
.61446 .29833 Mdot
.34634 .47713 Mdot
.55373 .57939 Mdot
.73318 .36522 Mdot
.3215 .50428 Mdot
.5409 .62039 Mdot
.35584 .50194 Mdot
.45719 .33585 Mdot
.37134 .47541 Mdot
.60176 .42867 Mdot
.6193 .61272 Mdot
.69728 .19853 Mdot
.38067 .58063 Mdot
.57958 .58694 Mdot
.46975 .37103 Mdot
.27707 .34908 Mdot
.56148 .60508 Mdot
.38139 .6067 Mdot
.33098 .47785 Mdot
.61506 .31686 Mdot
.59199 .60313 Mdot
.31735 .49757 Mdot
.57635 .38349 Mdot
.46504 .38104 Mdot
.77289 .41885 Mdot
.45661 .28685 Mdot
.62627 .40437 Mdot
.56112 .46076 Mdot
.41016 .39023 Mdot
.62606 .56058 Mdot
.56168 .54902 Mdot
.62234 .37525 Mdot
.37313 .70641 Mdot
.59953 .63953 Mdot
.62669 .62892 Mdot
.36306 .48773 Mdot
.34643 .47203 Mdot
.77409 .60445 Mdot
.37839 .46127 Mdot
.53532 .61974 Mdot
.62046 .37351 Mdot
.5669 .59889 Mdot
.5878 .37936 Mdot
.56888 .62989 Mdot
.64313 .52953 Mdot
.59492 .3953 Mdot
.44568 .39844 Mdot
.55643 .57955 Mdot
.55309 .52321 Mdot
.56248 .61564 Mdot
.58346 .55057 Mdot
.32387 .50291 Mdot
.369 .64391 Mdot
.53187 .58799 Mdot
.41739 .6359 Mdot
.40273 .6363 Mdot
.40394 .29678 Mdot
.36665 .4898 Mdot
.38281 .61943 Mdot
.19657 .44791 Mdot
.3191 .48005 Mdot
.36593 .63107 Mdot
.21638 .60956 Mdot
.46514 .35844 Mdot
.60783 .41409 Mdot
.57567 .60622 Mdot
.54612 .77122 Mdot
.68419 .5396 Mdot
.30876 .46383 Mdot
.58741 .59773 Mdot
.55484 .60442 Mdot
.64255 .35475 Mdot
.18197 .60901 Mdot
.37267 .51967 Mdot
.63643 .58202 Mdot
.5842 .35385 Mdot
.18236 .64716 Mdot
.35043 .49541 Mdot
.36341 .63642 Mdot
.47166 .35111 Mdot
.63032 .33385 Mdot
.43571 .24137 Mdot
.48124 .35294 Mdot
.39093 .44162 Mdot
.3411 .34267 Mdot
.58122 .53436 Mdot
.36227 .45828 Mdot
.85141 .52387 Mdot
.49344 .59177 Mdot
.44443 .53425 Mdot
.71795 .685 Mdot
.63976 .38685 Mdot
.41837 .37637 Mdot
.39657 .63111 Mdot
.64891 .37978 Mdot
.57988 .37102 Mdot
.462 .32259 Mdot
.66381 .45389 Mdot
.49469 .41418 Mdot
.43127 .33515 Mdot
.56955 .74011 Mdot
.32521 .71488 Mdot
.36488 .46295 Mdot
.36237 .63108 Mdot
.45955 .77714 Mdot
.60798 .37645 Mdot
.53467 .85544 Mdot
.73197 .69424 Mdot
.58276 .58365 Mdot
.38885 .62623 Mdot
.35948 .79536 Mdot
.2012 .6322 Mdot
.45517 .36884 Mdot
.40393 .30629 Mdot
.35859 .6568 Mdot
.55521 .61124 Mdot
.59629 .71553 Mdot
.60825 .63286 Mdot
.45205 .326 Mdot
.78708 .45482 Mdot
.58089 .36525 Mdot
.47352 .33541 Mdot
.63024 .73016 Mdot
.57557 .57148 Mdot
.55512 .58227 Mdot
.52868 .72615 Mdot
.65045 .38427 Mdot
.32554 .51554 Mdot
.56192 .54436 Mdot
.59925 .582 Mdot
.54482 .63256 Mdot
.63679 .64486 Mdot
.71356 .40837 Mdot
.59718 .62258 Mdot
.23107 .52802 Mdot
.54792 .61429 Mdot
.56614 .56816 Mdot
.65108 .40033 Mdot
.23578 .29135 Mdot
.34025 .36263 Mdot
.59601 .57927 Mdot
.63257 .56947 Mdot
.47344 .33814 Mdot
.47326 .41091 Mdot
.56272 .33189 Mdot
.61366 .31879 Mdot
.75813 .64258 Mdot
.6516 .60711 Mdot
.60603 .34726 Mdot
.37931 .60962 Mdot
.63159 .56214 Mdot
.59445 .34755 Mdot
.61954 .64198 Mdot
.32106 .50763 Mdot
.31756 .48389 Mdot
.5073 .54468 Mdot
.38286 .61722 Mdot
.64728 .26512 Mdot
.54911 .27085 Mdot
.32454 .4726 Mdot
.57987 .59974 Mdot
.49363 .32589 Mdot
.36689 .50899 Mdot
.39306 .54008 Mdot
.37004 .7237 Mdot
.61128 .40284 Mdot
.63035 .39613 Mdot
.4156 .71647 Mdot
.308 .35375 Mdot
.55616 .19247 Mdot
.45726 .33424 Mdot
.54386 .54953 Mdot
.60211 .26703 Mdot
.63283 .3978 Mdot
.45745 .73704 Mdot
.38829 .62274 Mdot
.45667 .36559 Mdot
.35199 .41399 Mdot
.59575 .36853 Mdot
.57884 .39683 Mdot
.58231 .64439 Mdot
.60991 .58224 Mdot
.78938 .58574 Mdot
.41634 .64527 Mdot
.48363 .33475 Mdot
.36172 .63495 Mdot
.30614 .49168 Mdot
.61538 .62633 Mdot
.59652 .39362 Mdot
.31926 .72036 Mdot
.61729 .54644 Mdot
.3349 .51241 Mdot
.63673 .38964 Mdot
.36415 .66358 Mdot
.3756 .6067 Mdot
.59334 .54774 Mdot
.79684 .54098 Mdot
.43874 .33584 Mdot
.63716 .3655 Mdot
.51967 .36421 Mdot
.60241 .63511 Mdot
.60852 .59076 Mdot
.60002 .51071 Mdot
.48385 .3365 Mdot
.5207 .31759 Mdot
.39067 .60778 Mdot
.62527 .36165 Mdot
.59842 .61971 Mdot
.36798 .62349 Mdot
.56445 .27218 Mdot
.31932 .46102 Mdot
.37288 .47912 Mdot
.37128 .60914 Mdot
.38376 .64071 Mdot
.39063 .60969 Mdot
.53731 .85615 Mdot
.62132 .34176 Mdot
.5481 .40853 Mdot
.64246 .59416 Mdot
.46264 .70785 Mdot
.54832 .54205 Mdot
.43901 .38258 Mdot
.36242 .50042 Mdot
.56727 .61491 Mdot
.60617 .54665 Mdot
.63059 .52477 Mdot
.51055 .19642 Mdot
.6133 .48129 Mdot
.58347 .37264 Mdot
.53971 .63072 Mdot
.36555 .47326 Mdot
.53142 .8705 Mdot
.75162 .69354 Mdot
.53505 .62389 Mdot
.50019 .40958 Mdot
.59987 .40052 Mdot
.46456 .3287 Mdot
.51991 .748 Mdot
.46753 .35464 Mdot
.62913 .36646 Mdot
.60183 .62543 Mdot
.54364 .28811 Mdot
.35721 .6765 Mdot
.58317 .55548 Mdot
.46007 .33216 Mdot
.55968 .56066 Mdot
.48357 .34099 Mdot
.54044 .77991 Mdot
.8381 .52683 Mdot
.58233 .57776 Mdot
.59901 .53115 Mdot
.8058 .5661 Mdot
.60754 .56292 Mdot
.37732 .69045 Mdot
.6002 .40116 Mdot
.792 .45471 Mdot
.64012 .55319 Mdot
.63588 .6994 Mdot
.61028 .63469 Mdot
.78199 .41702 Mdot
.61141 .58925 Mdot
.25825 .5247 Mdot
.62406 .61309 Mdot
.53924 .58951 Mdot
.43302 .3653 Mdot
.47474 .33755 Mdot
.63283 .41703 Mdot
.372 .51152 Mdot
.55658 .80565 Mdot
.60415 .58778 Mdot
.36358 .29761 Mdot
.49108 .2808 Mdot
.38101 .6422 Mdot
.62464 .36393 Mdot
.21037 .68009 Mdot
.41082 .34682 Mdot
.78179 .63781 Mdot
.75145 .63782 Mdot
.4828 .24197 Mdot
.40646 .7668 Mdot
.25073 .38005 Mdot
.36682 .66172 Mdot
.60819 .64528 Mdot
.31787 .64045 Mdot
.25522 .52403 Mdot
.36197 .70963 Mdot
.41285 .38547 Mdot
.77808 .55808 Mdot
.36493 .74753 Mdot
.35769 .61576 Mdot
.3674 .67004 Mdot
.4709 .36342 Mdot
.30789 .53588 Mdot
.65877 .64593 Mdot
.39177 .63278 Mdot
.33595 .52848 Mdot
.31895 .47441 Mdot
.34307 .53133 Mdot
.60426 .39285 Mdot
.75454 .68307 Mdot
.40111 .37957 Mdot
.44178 .38008 Mdot
.30882 .54304 Mdot
.67702 .67028 Mdot
.56402 .37252 Mdot
.35813 .47565 Mdot
.37669 .46964 Mdot
.59992 .40366 Mdot
.59538 .65561 Mdot
.62354 .66064 Mdot
.59168 .57568 Mdot
.36804 .63965 Mdot
.61439 .5835 Mdot
.31954 .49353 Mdot
.44676 .37017 Mdot
.3774 .47967 Mdot
.47583 .36512 Mdot
.31052 .72495 Mdot
.60782 .55384 Mdot
.61957 .61512 Mdot
.39711 .19253 Mdot
.59333 .41359 Mdot
.26119 .67729 Mdot
.48757 .3782 Mdot
.34089 .49702 Mdot
.54145 .59418 Mdot
.56812 .35298 Mdot
.39838 .66882 Mdot
.26904 .26875 Mdot
.58443 .63424 Mdot
.59951 .37872 Mdot
.61218 .62568 Mdot
.48878 .61971 Mdot
.62677 .22041 Mdot
.61368 .3715 Mdot
.52315 .18764 Mdot
.63384 .58078 Mdot
.20674 .45894 Mdot
.55502 .62132 Mdot
.46723 .61711 Mdot
.59944 .63946 Mdot
.64637 .36934 Mdot
.59602 .57509 Mdot
.57132 .35118 Mdot
.33546 .4612 Mdot
.47026 .33689 Mdot
.62639 .40275 Mdot
.57691 .54476 Mdot
.57675 .08743 Mdot
.45943 .34494 Mdot
.59213 .5937 Mdot
.46906 .36157 Mdot
.61396 .35419 Mdot
.64531 .38217 Mdot
.20107 .60388 Mdot
.33016 .3506 Mdot
.4568 .33764 Mdot
.61458 .62614 Mdot
.22413 .46518 Mdot
.58031 .61878 Mdot
.58561 .70356 Mdot
.58778 .65665 Mdot
.63389 .62663 Mdot
.22001 .63129 Mdot
.44912 .37885 Mdot
.55446 .19012 Mdot
.21251 .63694 Mdot
.24306 .65739 Mdot
.61422 .42534 Mdot
.35772 .61817 Mdot
.58279 .82452 Mdot
.37803 .28228 Mdot
.31832 .50856 Mdot
.56352 .61158 Mdot
.6706 .40299 Mdot
.43381 .33945 Mdot
.37029 .65459 Mdot
.58311 .57878 Mdot
.37355 .46846 Mdot
.77922 .37487 Mdot
.45068 .38499 Mdot
.61052 .36945 Mdot
.65031 .35937 Mdot
.16979 .43919 Mdot
.59142 .60822 Mdot
.62175 .6084 Mdot
.4453 .32444 Mdot
.26293 .35067 Mdot
.39515 .65386 Mdot
.80369 .46339 Mdot
.4561 .33987 Mdot
.4855 .47191 Mdot
.59482 .34588 Mdot
.55137 .60102 Mdot
.42885 .8204 Mdot
.32584 .41699 Mdot
.43102 .19188 Mdot
.3677 .63737 Mdot
.57628 .70053 Mdot
.64553 .36863 Mdot
.44771 .35933 Mdot
.30964 .33072 Mdot
.65127 .59065 Mdot
.54979 .57555 Mdot
.50785 .66175 Mdot
.39535 .31153 Mdot
.5602 .34248 Mdot
.58876 .63439 Mdot
.43389 .55951 Mdot
.57731 .63192 Mdot
.60885 .52533 Mdot
.58038 .65888 Mdot
.61074 .60095 Mdot
.59629 .38768 Mdot
.58062 .68493 Mdot
.33831 .52377 Mdot
.54584 .38262 Mdot
.47616 .47894 Mdot
.58403 .59143 Mdot
.62923 .62339 Mdot
.7003 .59784 Mdot
.26612 .39681 Mdot
.62516 .40103 Mdot
.58436 .41758 Mdot
.41524 .33811 Mdot
.61499 .65911 Mdot
.37333 .50947 Mdot
.54102 .54096 Mdot
.32637 .50534 Mdot
.5969 .39099 Mdot
.34451 .49598 Mdot
.47465 .3499 Mdot
.35672 .45569 Mdot
.36982 .28606 Mdot
.45757 .35533 Mdot
.61691 .4052 Mdot
.62115 .59697 Mdot
.4694 .37187 Mdot
.48985 .68431 Mdot
.36914 .63709 Mdot
.28172 .75544 Mdot
.62471 .59649 Mdot
.45796 .25418 Mdot
.67886 .61938 Mdot
.37744 .47458 Mdot
.61028 .20973 Mdot
.62259 .41263 Mdot
.39567 .66075 Mdot
.64886 .39371 Mdot
.61763 .72481 Mdot
.38068 .634 Mdot
.25952 .71706 Mdot
.4417 .58588 Mdot
.55822 .70872 Mdot
.61772 .65474 Mdot
.53074 .71405 Mdot
.31116 .48377 Mdot
.43326 .3419 Mdot
.30095 .34824 Mdot
.5406 .58762 Mdot
.82039 .41415 Mdot
.65284 .39255 Mdot
.36329 .51709 Mdot
.44295 .36227 Mdot
.43359 .38122 Mdot
.64059 .57825 Mdot
.28256 .57092 Mdot
.54823 .57481 Mdot
.32118 .33858 Mdot
.73078 .67321 Mdot
.56423 .42661 Mdot
.59112 .59785 Mdot
.32907 .46784 Mdot
.61188 .62573 Mdot
.38981 .60599 Mdot
.80773 .61241 Mdot
.54565 .52996 Mdot
.50363 .35252 Mdot
.4117 .65887 Mdot
.62742 .35494 Mdot
.67001 .56752 Mdot
.49389 .31304 Mdot
.59183 .61129 Mdot
.25544 .24104 Mdot
.36719 .62738 Mdot
.31958 .6303 Mdot
.60398 .54169 Mdot
.62959 .55747 Mdot
.43689 .51232 Mdot
.43463 .23528 Mdot
.26687 .46632 Mdot
.59791 .56234 Mdot
.47673 .65924 Mdot
.46135 .37401 Mdot
.56144 .61837 Mdot
.59583 .59228 Mdot
.67595 .49118 Mdot
.44398 .38465 Mdot
.34133 .50663 Mdot
.31051 .5046 Mdot
.31566 .45683 Mdot
.4015 .61532 Mdot
.55061 .33614 Mdot
.47239 .72576 Mdot
.74224 .31818 Mdot
.37597 .67403 Mdot
.61115 .54977 Mdot
.35673 .57505 Mdot
.60591 .62885 Mdot
.37483 .65279 Mdot
.4456 .38473 Mdot
.63302 .40054 Mdot
.59423 .27045 Mdot
.31257 .49884 Mdot
.65248 .58454 Mdot
.40092 .64804 Mdot
.61131 .40084 Mdot
.48807 .76017 Mdot
.62663 .35544 Mdot
.44829 .34081 Mdot
.55451 .33146 Mdot
.37335 .65581 Mdot
.60672 .35216 Mdot
.51096 .36078 Mdot
.19443 .61004 Mdot
.59213 .66442 Mdot
.56838 .30436 Mdot
.62973 .35304 Mdot
.5757 .40993 Mdot
.6184 .34419 Mdot
.5674 .55638 Mdot
.50052 .41075 Mdot
.63635 .63062 Mdot
.4538 .3777 Mdot
.35263 .50396 Mdot
.83056 .49764 Mdot
.37028 .3745 Mdot
.54725 .43737 Mdot
.52701 .57536 Mdot
.57619 .57048 Mdot
.59548 .5975 Mdot
.61894 .53177 Mdot
.37468 .27856 Mdot
.56443 .56262 Mdot
.4322 .36488 Mdot
.32664 .48294 Mdot
.61101 .64502 Mdot
.37434 .43713 Mdot
.23412 .63233 Mdot
.35479 .6536 Mdot
.45233 .3047 Mdot
.79334 .65494 Mdot
.61408 .4011 Mdot
.3378 .44921 Mdot
.32211 .48238 Mdot
.38292 .66043 Mdot
.43873 .33205 Mdot
.62376 .35338 Mdot
.56847 .69547 Mdot
.40259 .63472 Mdot
.5976 .57759 Mdot
.51199 .39579 Mdot
.83461 .44488 Mdot
.59922 .64502 Mdot
.56333 .60182 Mdot
.34551 .53252 Mdot
.32453 .62404 Mdot
.78432 .29637 Mdot
.4938 .73292 Mdot
.3688 .64949 Mdot
.3553 .62903 Mdot
.59519 .40311 Mdot
.64576 .56975 Mdot
.47428 .36237 Mdot
.64845 .30526 Mdot
.51808 .33246 Mdot
.60852 .24146 Mdot
.40644 .20554 Mdot
.57309 .62598 Mdot
.24728 .3533 Mdot
.57035 .57255 Mdot
.62376 .34273 Mdot
.5998 .38652 Mdot
.61763 .38754 Mdot
.43426 .34144 Mdot
.74992 .53522 Mdot
.42768 .35555 Mdot
.84971 .57172 Mdot
.64411 .37227 Mdot
.43798 .58692 Mdot
.36273 .47622 Mdot
.60761 .67016 Mdot
.36029 .65852 Mdot
.56809 .31318 Mdot
.54427 .51677 Mdot
.68166 .41903 Mdot
.35512 .52175 Mdot
.62134 .40635 Mdot
.25938 .3604 Mdot
.672 .75591 Mdot
.58721 .32133 Mdot
.60412 .50643 Mdot
.52012 .74948 Mdot
.37823 .64558 Mdot
.42822 .19291 Mdot
.35841 .64592 Mdot
.46106 .33326 Mdot
.61396 .61786 Mdot
.61609 .60727 Mdot
.57745 .63273 Mdot
.61199 .55978 Mdot
.40785 .39147 Mdot
.54014 .56258 Mdot
.68483 .281 Mdot
.31315 .50276 Mdot
.44749 .6384 Mdot
.3603 .64191 Mdot
.42503 .38668 Mdot
.32532 .48419 Mdot
.27234 .38954 Mdot
.50455 .70161 Mdot
.5914 .60129 Mdot
.56629 .61435 Mdot
.79934 .60387 Mdot
.58949 .63409 Mdot
.64045 .66782 Mdot
.31739 .50301 Mdot
.6447 .51447 Mdot
.35533 .65359 Mdot
.3518 .64084 Mdot
.45875 .35673 Mdot
.59748 .38658 Mdot
.37361 .62397 Mdot
.3638 .4811 Mdot
.52639 .57797 Mdot
.55085 .55345 Mdot
.63261 .35554 Mdot
.80656 .60109 Mdot
.37929 .60237 Mdot
.22141 .4604 Mdot
.61449 .40796 Mdot
.65414 .40379 Mdot
.54896 .57717 Mdot
.45808 .18974 Mdot
.62245 .42901 Mdot
.40833 .64587 Mdot
.42125 .38692 Mdot
.53327 .74225 Mdot
.411 .35361 Mdot
.60907 .36778 Mdot
.63536 .5933 Mdot
.60208 .39638 Mdot
.58972 .60356 Mdot
.6985 .75884 Mdot
.61434 .60162 Mdot
.73188 .30614 Mdot
.41277 .70892 Mdot
.34607 .46266 Mdot
.26178 .39224 Mdot
.3581 .46445 Mdot
.63292 .40711 Mdot
.61065 .54124 Mdot
.37958 .66595 Mdot
.21537 .56705 Mdot
.6787 .33654 Mdot
.36269 .50936 Mdot
.38592 .49758 Mdot
.40907 .36272 Mdot
.60013 .64075 Mdot
.55352 .5705 Mdot
.33883 .47678 Mdot
.60143 .44008 Mdot
.59868 .36183 Mdot
.60378 .61722 Mdot
.57505 .56807 Mdot
.3503 .46265 Mdot
.18665 .5949 Mdot
.53383 .65464 Mdot
.61017 .61322 Mdot
.28304 .44219 Mdot
.43785 .38158 Mdot
.60889 .66909 Mdot
.59058 .53064 Mdot
.38649 .63992 Mdot
.73501 .40766 Mdot
.68324 .72521 Mdot
.44601 .3853 Mdot
.3174 .4901 Mdot
.59459 .6138 Mdot
.32718 .4703 Mdot
.54296 .5589 Mdot
.44531 .23464 Mdot
.33392 .45259 Mdot
.63212 .62424 Mdot
.60045 .65421 Mdot
.65101 .3804 Mdot
.56958 .6207 Mdot
.71813 .61227 Mdot
.3404 .51747 Mdot
.6398 .5792 Mdot
.80239 .50814 Mdot
.42499 .33876 Mdot
.63334 .64849 Mdot
.40037 .62955 Mdot
.60846 .70854 Mdot
.53048 .27413 Mdot
.42379 .78543 Mdot
.35036 .64824 Mdot
.56185 .56017 Mdot
.38077 .50653 Mdot
.48254 .33315 Mdot
.71182 .27727 Mdot
.55264 .60753 Mdot
.45608 .32867 Mdot
.44783 .36959 Mdot
.36814 .65586 Mdot
.21636 .31174 Mdot
.60116 .54271 Mdot
.61382 .56937 Mdot
.72001 .53594 Mdot
.57718 .39894 Mdot
.61615 .59083 Mdot
.62908 .57557 Mdot
.4345 .36892 Mdot
.66099 .62965 Mdot
.75055 .61544 Mdot
.79431 .43699 Mdot
.46249 .31835 Mdot
.62771 .2715 Mdot
.32536 .45977 Mdot
.36577 .62083 Mdot
.63674 .37905 Mdot
.3958 .65477 Mdot
.36937 .48085 Mdot
.6283 .58078 Mdot
.45407 .32341 Mdot
.71153 .59235 Mdot
.47239 .36157 Mdot
.36521 .7394 Mdot
.57399 .35387 Mdot
.39558 .36019 Mdot
.23547 .26582 Mdot
.2901 .41628 Mdot
.39191 .30697 Mdot
.38145 .64181 Mdot
.38364 .53355 Mdot
.57386 .56887 Mdot
.41491 .19428 Mdot
.61305 .55197 Mdot
.79689 .48502 Mdot
.31562 .50856 Mdot
.33143 .53002 Mdot
.61142 .61635 Mdot
.72063 .67916 Mdot
.48163 .32938 Mdot
.42377 .37309 Mdot
.63714 .61075 Mdot
.44722 .33711 Mdot
.61018 .57768 Mdot
.32096 .49605 Mdot
.46508 .16718 Mdot
.58845 .57835 Mdot
.57681 .52335 Mdot
.46063 .24183 Mdot
.22078 .64143 Mdot
.418 .60697 Mdot
.15773 .5006 Mdot
.70581 .74024 Mdot
.44563 .33815 Mdot
.64153 .61442 Mdot
.62412 .266 Mdot
.36543 .52499 Mdot
.51755 .35304 Mdot
.62419 .584 Mdot
.623 .56381 Mdot
.53907 .59536 Mdot
.55644 .58689 Mdot
.30813 .24818 Mdot
.67283 .32343 Mdot
.73569 .4585 Mdot
.57499 .6249 Mdot
.51503 .69632 Mdot
.46493 .34629 Mdot
.6656 .36499 Mdot
.3948 .66498 Mdot
.57171 .62433 Mdot
.55901 .35177 Mdot
.44572 .31927 Mdot
.86123 .54916 Mdot
.45555 .32638 Mdot
.33579 .50255 Mdot
.47842 .34163 Mdot
.57047 .58297 Mdot
.62754 .37266 Mdot
.43005 .45691 Mdot
.33311 .38232 Mdot
.32087 .51591 Mdot
.58001 .58749 Mdot
.42615 .5892 Mdot
.34224 .52436 Mdot
.25377 .67551 Mdot
.63205 .38108 Mdot
.46886 .65527 Mdot
.59983 .39291 Mdot
.63778 .60117 Mdot
.63705 .60152 Mdot
.41747 .32991 Mdot
.47608 .3469 Mdot
.59908 .39136 Mdot
.16655 .36852 Mdot
.38597 .60597 Mdot
.61581 .38459 Mdot
.64811 .56036 Mdot
.47313 .42853 Mdot
.62616 .37694 Mdot
.35965 .68629 Mdot
.44186 .3708 Mdot
.59665 .41148 Mdot
.54666 .61672 Mdot
.57459 .73754 Mdot
.37068 .61131 Mdot
.30681 .5081 Mdot
.46182 .75246 Mdot
.35374 .51559 Mdot
.41463 .38355 Mdot
.35586 .46254 Mdot
.44404 .37792 Mdot
.51801 .28749 Mdot
.55102 .3958 Mdot
.40747 .52071 Mdot
.40733 .38151 Mdot
.35817 .46687 Mdot
.6134 .62129 Mdot
.38481 .58253 Mdot
.63757 .55653 Mdot
.5605 .55399 Mdot
.4299 .37323 Mdot
.64847 .38329 Mdot
.60639 .42652 Mdot
.56074 .7039 Mdot
.59443 .3825 Mdot
.33887 .51341 Mdot
.69972 .37952 Mdot
.36483 .31251 Mdot
.41307 .35317 Mdot
.47239 .33941 Mdot
.60016 .63109 Mdot
.3484 .47567 Mdot
.32355 .52157 Mdot
.41019 .35324 Mdot
.49245 .20371 Mdot
.60136 .52915 Mdot
.57785 .41459 Mdot
.58006 .40046 Mdot
.61651 .37196 Mdot
.60758 .3414 Mdot
.63811 .69445 Mdot
.46109 .36369 Mdot
.64661 .39211 Mdot
.59942 .63193 Mdot
.62571 .5736 Mdot
.64022 .29597 Mdot
.37706 .6124 Mdot
.62182 .64284 Mdot
.58353 .65929 Mdot
.55028 .59888 Mdot
.37075 .47098 Mdot
.61593 .68267 Mdot
.36046 .45365 Mdot
.37148 .5171 Mdot
.36868 .52084 Mdot
.38272 .28086 Mdot
.77332 .6391 Mdot
.61812 .7699 Mdot
.63605 .57523 Mdot
.22672 .39228 Mdot
.35183 .48567 Mdot
.69722 .3359 Mdot
.51478 .31394 Mdot
.5426 .59522 Mdot
.23597 .54485 Mdot
.3419 .47263 Mdot
.60642 .40737 Mdot
.62057 .59226 Mdot
.33524 .44639 Mdot
.39779 .6215 Mdot
.64149 .57293 Mdot
.31665 .46443 Mdot
.60823 .35073 Mdot
.41012 .62639 Mdot
.60322 .4175 Mdot
.3695 .52067 Mdot
.6616 .58924 Mdot
.5894 .16329 Mdot
.34305 .43991 Mdot
.19495 .49154 Mdot
.56411 .49107 Mdot
.60724 .61999 Mdot
.35793 .44776 Mdot
.65387 .40872 Mdot
.4156 .38328 Mdot
.51525 .48652 Mdot
.58372 .39113 Mdot
.33158 .5301 Mdot
.37554 .50026 Mdot
.32067 .51574 Mdot
.58097 .37708 Mdot
.6456 .63063 Mdot
.58818 .37484 Mdot
.47961 .34033 Mdot
.57559 .60976 Mdot
.57544 .78487 Mdot
.2732 .33826 Mdot
.6095 .40605 Mdot
.3518 .50858 Mdot
.35492 .67257 Mdot
.57596 .57478 Mdot
.25411 .35521 Mdot
.61191 .6232 Mdot
.43831 .37926 Mdot
.70539 .43326 Mdot
.65136 .51548 Mdot
.63729 .62222 Mdot
.59458 .62873 Mdot
.42261 .37093 Mdot
.58247 .58493 Mdot
.59959 .63979 Mdot
.3695 .28532 Mdot
.58801 .3673 Mdot
.59245 .5725 Mdot
.35751 .49875 Mdot
.34876 .33857 Mdot
.59101 .52571 Mdot
.40446 .50482 Mdot
.46955 .64733 Mdot
.69023 .45069 Mdot
.61519 .55347 Mdot
.52318 .39458 Mdot
.55245 .57995 Mdot
.59244 .55409 Mdot
.59608 .62643 Mdot
.25402 .30435 Mdot
.3195 .46192 Mdot
.32842 .47313 Mdot
.35867 .62225 Mdot
.46864 .64792 Mdot
.39027 .63173 Mdot
.4473 .37213 Mdot
.29364 .58614 Mdot
.35746 .4522 Mdot
.60803 .36053 Mdot
.57744 .55731 Mdot
.34665 .43957 Mdot
.54721 .59656 Mdot
.57149 .5849 Mdot
.3783 .50427 Mdot
.31888 .46522 Mdot
.34242 .71655 Mdot
.3838 .61168 Mdot
.61881 .39288 Mdot
.61724 .64013 Mdot
.40282 .64147 Mdot
.6123 .54912 Mdot
.46148 .70937 Mdot
.6201 .3886 Mdot
.58884 .36884 Mdot
.60988 .42804 Mdot
.62728 .58663 Mdot
.57269 .57927 Mdot
.42711 .3565 Mdot
.6267 .41059 Mdot
.42843 .33463 Mdot
.48677 .50482 Mdot
.26773 .65355 Mdot
.6244 .58346 Mdot
.58679 .30849 Mdot
.39322 .62555 Mdot
.36522 .5068 Mdot
.83972 .46175 Mdot
.35894 .62176 Mdot
.59237 .60661 Mdot
.36535 .51827 Mdot
.38298 .65289 Mdot
.48325 .62459 Mdot
.83322 .58455 Mdot
.35653 .67098 Mdot
.59855 .63175 Mdot
.66372 .62106 Mdot
.15838 .48389 Mdot
.35176 .65797 Mdot
.47041 .35053 Mdot
.6267 .58906 Mdot
.56789 .39731 Mdot
.40043 .64966 Mdot
.24775 .48457 Mdot
.33385 .47552 Mdot
.58494 .73278 Mdot
.5525 .52071 Mdot
.66747 .41787 Mdot
.35852 .62548 Mdot
.62847 .36095 Mdot
.65269 .66369 Mdot
.54912 .57887 Mdot
.35042 .65579 Mdot
.43327 .39623 Mdot
.32745 .49066 Mdot
.33537 .35931 Mdot
.58012 .38035 Mdot
.43466 .40032 Mdot
.36353 .50385 Mdot
.22003 .46852 Mdot
.76307 .37787 Mdot
.6234 .66222 Mdot
.1895 .42726 Mdot
.45056 .273 Mdot
.56679 .63098 Mdot
.38617 .67505 Mdot
.46781 .37454 Mdot
.43413 .32272 Mdot
.45143 .34237 Mdot
.50575 .2889 Mdot
.60954 .3189 Mdot
.31417 .4648 Mdot
.4988 .38634 Mdot
.36829 .61909 Mdot
.53649 .73557 Mdot
.55776 .55399 Mdot
.57998 .57114 Mdot
.61266 .63806 Mdot
.57005 .62446 Mdot
.56206 .56778 Mdot
.44521 .33012 Mdot
.50288 .27544 Mdot
.61508 .31371 Mdot
.62329 .38219 Mdot
.33165 .60239 Mdot
.36112 .48439 Mdot
.30785 .52289 Mdot
.39367 .646 Mdot
.267 .44197 Mdot
.37267 .43652 Mdot
.34306 .49751 Mdot
.60171 .64936 Mdot
.59522 .36771 Mdot
.61554 .67144 Mdot
.59639 .6302 Mdot
.3325 .51047 Mdot
.4498 .51001 Mdot
.72859 .63403 Mdot
.34745 .70454 Mdot
.40479 .60968 Mdot
.50974 .38783 Mdot
.35152 .63507 Mdot
.57505 .53639 Mdot
.63134 .22623 Mdot
.36956 .47904 Mdot
.3382 .48874 Mdot
.38211 .61408 Mdot
.45992 .18707 Mdot
.63942 .38366 Mdot
.40341 .40104 Mdot
.46215 .37027 Mdot
.63543 .59816 Mdot
.7931 .39387 Mdot
.56698 .48604 Mdot
.27459 .57126 Mdot
.45692 .34268 Mdot
.33877 .45914 Mdot
.56362 .53699 Mdot
.58542 .62631 Mdot
.39514 .6325 Mdot
.39948 .78465 Mdot
.57639 .66067 Mdot
.35164 .80709 Mdot
.83874 .52586 Mdot
.67011 .72371 Mdot
.55078 .57406 Mdot
.58589 .37066 Mdot
.30879 .49809 Mdot
.36236 .62969 Mdot
.6521 .58895 Mdot
.71632 .71355 Mdot
.63508 .35925 Mdot
.45465 .35446 Mdot
.46269 .47323 Mdot
.51962 .74037 Mdot
.57514 .55185 Mdot
.62623 .56951 Mdot
.58992 .55192 Mdot
.87081 .40912 Mdot
.36521 .45894 Mdot
.60523 .40477 Mdot
.37066 .65702 Mdot
.59868 .376 Mdot
.34106 .46202 Mdot
.41213 .53418 Mdot
.62152 .61782 Mdot
.6225 .34869 Mdot
.63037 .36335 Mdot
.43371 .325 Mdot
.43861 .38895 Mdot
.47569 .4852 Mdot
.61344 .60022 Mdot
.38397 .46558 Mdot
.6491 .38713 Mdot
.51838 .38621 Mdot
.38262 .63386 Mdot
.44035 .37146 Mdot
.57134 .6215 Mdot
.35626 .45339 Mdot
.569 .64694 Mdot
.62868 .39814 Mdot
.34344 .49653 Mdot
.31427 .71339 Mdot
.35333 .65144 Mdot
.62243 .57231 Mdot
.4178 .67155 Mdot
.31685 .4938 Mdot
.56932 .56922 Mdot
.209 .50611 Mdot
.35685 .68358 Mdot
.34156 .39941 Mdot
.35248 .52562 Mdot
.40305 .28045 Mdot
.59266 .40148 Mdot
.41751 .25284 Mdot
.335 .49541 Mdot
.2212 .44334 Mdot
.33403 .72787 Mdot
.52877 .56967 Mdot
.60877 .37741 Mdot
.41978 .26415 Mdot
.62736 .80889 Mdot
.18373 .51317 Mdot
.59295 .59346 Mdot
.3788 .46274 Mdot
.3903 .64545 Mdot
.41424 .3554 Mdot
.37343 .4018 Mdot
.34883 .60744 Mdot
.39343 .46931 Mdot
.59581 .6259 Mdot
.61997 .35449 Mdot
.43392 .3582 Mdot
.53148 .27887 Mdot
.36231 .48866 Mdot
.35483 .50491 Mdot
.62129 .54638 Mdot
.38752 .62144 Mdot
.31647 .28444 Mdot
.31929 .5013 Mdot
.81244 .57142 Mdot
.30542 .52533 Mdot
.40264 .62741 Mdot
.55417 .59168 Mdot
.59017 .71474 Mdot
.64665 .58038 Mdot
.2033 .55462 Mdot
.36124 .47838 Mdot
.62385 .39502 Mdot
.54989 .56534 Mdot
.81183 .51222 Mdot
.34077 .51318 Mdot
.49943 .40459 Mdot
.27039 .51097 Mdot
.45845 .36844 Mdot
.83788 .45799 Mdot
.6169 .58228 Mdot
.48247 .33354 Mdot
.39418 .63543 Mdot
.61038 .60794 Mdot
.56959 .57955 Mdot
.64402 .35716 Mdot
.42705 .32974 Mdot
.33949 .71487 Mdot
.4712 .33369 Mdot
.46715 .34227 Mdot
.56321 .35763 Mdot
.60201 .56896 Mdot
.33699 .50432 Mdot
.34236 .47376 Mdot
.55029 .6211 Mdot
.42211 .15882 Mdot
.64034 .37701 Mdot
.31035 .51391 Mdot
.85996 .38259 Mdot
.56644 .63456 Mdot
.82873 .45444 Mdot
.38173 .77356 Mdot
.46628 .37198 Mdot
.59914 .6324 Mdot
.61068 .35259 Mdot
.26576 .47455 Mdot
.35152 .50638 Mdot
.53997 .60765 Mdot
.43487 .35646 Mdot
.3853 .61055 Mdot
.33561 .52028 Mdot
.28164 .57251 Mdot
.60851 .55536 Mdot
.23504 .56795 Mdot
.38147 .47991 Mdot
.55886 .82751 Mdot
.28185 .37161 Mdot
.6091 .38047 Mdot
.57003 .58715 Mdot
.61735 .41239 Mdot
.37574 .65894 Mdot
.46479 .47465 Mdot
.4391 .3665 Mdot
.67381 .67111 Mdot
.65676 .23979 Mdot
.32043 .5155 Mdot
.611 .40872 Mdot
.64023 .60852 Mdot
.44257 .2296 Mdot
.61449 .57767 Mdot
.65569 .55098 Mdot
.34708 .71165 Mdot
.42096 .36262 Mdot
.46374 .37186 Mdot
.55988 .57957 Mdot
.38677 .65975 Mdot
.36283 .48343 Mdot
.32762 .49996 Mdot
.4965 .8548 Mdot
.3994 .3996 Mdot
.78548 .59284 Mdot
.62209 .56317 Mdot
.39347 .47909 Mdot
.37192 .34812 Mdot
.44799 .32496 Mdot
.64373 .63876 Mdot
.36996 .51188 Mdot
.44591 .63184 Mdot
.49706 .64988 Mdot
.55116 .57808 Mdot
.64681 .56536 Mdot
.46984 .36115 Mdot
.57508 .33298 Mdot
.32547 .46863 Mdot
.56118 .64627 Mdot
.41634 .51082 Mdot
.48006 .62265 Mdot
.84417 .53729 Mdot
.61854 .39283 Mdot
.2791 .55236 Mdot
.4439 .32992 Mdot
.57146 .52337 Mdot
.36272 .65768 Mdot
.38985 .504 Mdot
.34426 .45073 Mdot
.59137 .61537 Mdot
.55572 .54544 Mdot
.82662 .53144 Mdot
.60225 .36491 Mdot
.46306 .35202 Mdot
.6208 .60662 Mdot
.59475 .28554 Mdot
.58026 .63426 Mdot
.42477 .35133 Mdot
.57056 .15791 Mdot
.64369 .56847 Mdot
.6138 .57256 Mdot
.31331 .28922 Mdot
.58163 .39303 Mdot
.64597 .40014 Mdot
.80531 .39267 Mdot
.62234 .56386 Mdot
.83929 .50818 Mdot
.61915 .3985 Mdot
.63863 .38981 Mdot
.33524 .3199 Mdot
.57941 .57389 Mdot
.50816 .61381 Mdot
.4493 .37835 Mdot
.46826 .34242 Mdot
.5841 .37758 Mdot
.59793 .66769 Mdot
.43498 .38611 Mdot
.29391 .27719 Mdot
.35012 .47534 Mdot
.56988 .18969 Mdot
.6409 .37387 Mdot
.42649 .29319 Mdot
.4577 .33271 Mdot
.82705 .60645 Mdot
.33382 .42062 Mdot
.61697 .61962 Mdot
.61897 .56127 Mdot
.37879 .61474 Mdot
.62497 .63531 Mdot
.33066 .52974 Mdot
.44793 .33678 Mdot
.71449 .66992 Mdot
.61711 .38755 Mdot
.61066 .59149 Mdot
.22363 .53375 Mdot
.28331 .71388 Mdot
.2893 .54459 Mdot
.63072 .35875 Mdot
.60387 .3896 Mdot
.35407 .45643 Mdot
.38034 .46774 Mdot
.58695 .563 Mdot
.41971 .37259 Mdot
.62296 .41111 Mdot
.42355 .35883 Mdot
.36986 .48216 Mdot
.3386 .50204 Mdot
.31227 .4748 Mdot
.55524 .55398 Mdot
.34806 .50078 Mdot
.28437 .6798 Mdot
.45726 .40624 Mdot
.56231 .37138 Mdot
.84294 .4206 Mdot
.53584 .28272 Mdot
.67351 .39038 Mdot
.40566 .63748 Mdot
.3172 .50648 Mdot
.47951 .33424 Mdot
.56809 .60194 Mdot
.56161 .61244 Mdot
.37691 .29653 Mdot
.47543 .32799 Mdot
.37255 .6569 Mdot
.4812 .34945 Mdot
.36887 .65662 Mdot
.24452 .56459 Mdot
.59736 .6421 Mdot
.53798 .56341 Mdot
.45126 .33241 Mdot
.34586 .49889 Mdot
.33073 .47431 Mdot
.35634 .66734 Mdot
.44754 .53088 Mdot
.34505 .52416 Mdot
.64139 .38909 Mdot
.69433 .66989 Mdot
.37912 .48501 Mdot
.61911 .5922 Mdot
.46555 .72656 Mdot
.40208 .19347 Mdot
.61976 .53229 Mdot
.34291 .30598 Mdot
.70512 .55855 Mdot
.54527 .5741 Mdot
.40844 .19048 Mdot
.49491 .34558 Mdot
.58832 .39275 Mdot
.3139 .49895 Mdot
.29083 .49559 Mdot
.52564 .63043 Mdot
.41161 .62813 Mdot
.65862 .59984 Mdot
.62071 .34851 Mdot
.65254 .36138 Mdot
.57708 .71807 Mdot
.19144 .52774 Mdot
.38428 .65068 Mdot
.39473 .64257 Mdot
.33317 .49761 Mdot
.28188 .75901 Mdot
.62949 .52326 Mdot
.37055 .65413 Mdot
.61936 .4382 Mdot
.59329 .62263 Mdot
.45472 .64058 Mdot
.57498 .47247 Mdot
.58272 .3775 Mdot
.52244 .69677 Mdot
.33996 .51045 Mdot
.59311 .38382 Mdot
.58858 .26396 Mdot
.63986 .63415 Mdot
.6196 .38717 Mdot
.42534 .35895 Mdot
.27575 .39729 Mdot
.64505 .38608 Mdot
.46781 .71915 Mdot
.41282 .36784 Mdot
.51863 .38426 Mdot
.53617 .68851 Mdot
.12349 .5949 Mdot
.44622 .33284 Mdot
.37482 .50058 Mdot
.34106 .47467 Mdot
.32818 .50032 Mdot
.59881 .37374 Mdot
.31943 .51493 Mdot
.60391 .36545 Mdot
.17887 .45279 Mdot
.41489 .20349 Mdot
.36962 .65096 Mdot
.33336 .36162 Mdot
.61637 .35963 Mdot
.69037 .3027 Mdot
.34502 .17138 Mdot
.60342 .63344 Mdot
.43154 .32237 Mdot
.37171 .65027 Mdot
.3294 .7828 Mdot
.38419 .64383 Mdot
.73406 .68892 Mdot
.67559 .43719 Mdot
.60765 .58437 Mdot
.77014 .54112 Mdot
.36736 .67131 Mdot
.589 .34737 Mdot
.5697 .56994 Mdot
.46735 .54394 Mdot
.38976 .6403 Mdot
.39902 .61968 Mdot
.59038 .56675 Mdot
.62149 .40645 Mdot
.35211 .51025 Mdot
.46911 .33632 Mdot
.39341 .66003 Mdot
.66888 .6193 Mdot
.64653 .59915 Mdot
.61739 .62343 Mdot
.61822 .29721 Mdot
.3769 .68203 Mdot
.44466 .33846 Mdot
.2246 .31522 Mdot
.38213 .50225 Mdot
.45029 .57949 Mdot
.82755 .55397 Mdot
.48205 .29876 Mdot
.36026 .47794 Mdot
.32944 .46834 Mdot
.56275 .56672 Mdot
.64033 .51788 Mdot
.66393 .43786 Mdot
.424 .55301 Mdot
.30544 .50097 Mdot
.32679 .49581 Mdot
.63608 .41062 Mdot
.64959 .72683 Mdot
.63163 .53557 Mdot
.4489 .38443 Mdot
.33032 .45495 Mdot
.39677 .22589 Mdot
.37965 .61706 Mdot
.69315 .41853 Mdot
.5997 .64329 Mdot
.61867 .61649 Mdot
.44006 .3571 Mdot
.42849 .35605 Mdot
.26323 .49089 Mdot
.68442 .71575 Mdot
.70376 .56594 Mdot
.50193 .26424 Mdot
.68413 .46317 Mdot
.65247 .39222 Mdot
.6099 .40624 Mdot
.32798 .3942 Mdot
.46481 .32745 Mdot
.54563 .57167 Mdot
.5976 .38876 Mdot
.43682 .61436 Mdot
.66754 .67797 Mdot
.63438 .71245 Mdot
.83244 .48048 Mdot
.58731 .5994 Mdot
.59316 .35968 Mdot
.58076 .39408 Mdot
.57432 .38913 Mdot
.4162 .28031 Mdot
.5987 .56234 Mdot
.58921 .59607 Mdot
.55326 .56748 Mdot
.45017 .20936 Mdot
.5949 .55735 Mdot
.43921 .25742 Mdot
.47791 .46696 Mdot
.74621 .39972 Mdot
.56486 .64917 Mdot
.48484 .34452 Mdot
.5894 .54705 Mdot
.38486 .6607 Mdot
.6174 .63083 Mdot
.63793 .71182 Mdot
.46152 .34423 Mdot
.5801 .68584 Mdot
.5245 .28985 Mdot
.54497 .60835 Mdot
.40744 .64597 Mdot
.50744 .31651 Mdot
.61876 .79664 Mdot
.41893 .61306 Mdot
.6418 .38688 Mdot
.35475 .47683 Mdot
.47908 .33193 Mdot
.33882 .49524 Mdot
.53159 .58346 Mdot
.31382 .39869 Mdot
.34142 .78181 Mdot
.46256 .53325 Mdot
.56841 .62145 Mdot
.61231 .51836 Mdot
.63686 .39548 Mdot
.3767 .50846 Mdot
.65583 .41679 Mdot
.56816 .55565 Mdot
.36706 .64074 Mdot
.39369 .63294 Mdot
.50466 .49378 Mdot
.48917 .82527 Mdot
.34457 .24792 Mdot
.43945 .35236 Mdot
.32068 .50449 Mdot
.35953 .65826 Mdot
.22599 .4242 Mdot
.47466 .37306 Mdot
.43026 .37629 Mdot
.46161 .34887 Mdot
.63187 .58459 Mdot
.32274 .45878 Mdot
.74888 .4013 Mdot
.37853 .51467 Mdot
.57994 .58439 Mdot
.37095 .46932 Mdot
.36066 .51796 Mdot
.36323 .63378 Mdot
.46353 .34822 Mdot
.36808 .47908 Mdot
.63865 .59428 Mdot
.61605 .40055 Mdot
.38988 .32382 Mdot
.3958 .70836 Mdot
.19496 .53277 Mdot
.50431 .53484 Mdot
.57738 .38463 Mdot
.60342 .80304 Mdot
.44312 .38163 Mdot
.48062 .20483 Mdot
.34387 .71786 Mdot
.61601 .54524 Mdot
.43974 .15459 Mdot
.32043 .53832 Mdot
.36021 .51636 Mdot
.5534 .58921 Mdot
.31432 .53946 Mdot
.61133 .58645 Mdot
.3698 .49525 Mdot
.39252 .41293 Mdot
.57417 .3433 Mdot
.35016 .49594 Mdot
.54791 .63426 Mdot
.56589 .57781 Mdot
.58633 .37238 Mdot
.37188 .45471 Mdot
.6522 .57922 Mdot
.53198 .86367 Mdot
.42799 .34861 Mdot
.47749 .28982 Mdot
.45053 .73209 Mdot
.44146 .32953 Mdot
.6157 .38173 Mdot
.56267 .55241 Mdot
.3942 .63707 Mdot
.61516 .35797 Mdot
.64917 .70684 Mdot
.35435 .64335 Mdot
.54864 .17425 Mdot
.57938 .39211 Mdot
.36015 .51173 Mdot
.37261 .66295 Mdot
.63835 .62596 Mdot
.3711 .52261 Mdot
.25987 .40015 Mdot
.35958 .48128 Mdot
.55914 .56593 Mdot
.35956 .3769 Mdot
.46405 .35206 Mdot
.59603 .59631 Mdot
.35266 .51865 Mdot
.34352 .30785 Mdot
.63399 .57687 Mdot
.5568 .5773 Mdot
.82144 .56988 Mdot
.71496 .33696 Mdot
.38307 .6388 Mdot
.60438 .41966 Mdot
.60078 .63234 Mdot
.40128 .63024 Mdot
.2889 .64608 Mdot
.62778 .59823 Mdot
.63528 .35889 Mdot
.64415 .63942 Mdot
.37566 .45901 Mdot
.4295 .33618 Mdot
.42905 .56503 Mdot
.39822 .62237 Mdot
.15149 .58414 Mdot
.33203 .45649 Mdot
.56392 .54617 Mdot
.58182 .63365 Mdot
.45685 .76913 Mdot
.58851 .38931 Mdot
.60052 .45417 Mdot
.62237 .57151 Mdot
.46014 .20321 Mdot
.60783 .60425 Mdot
.33255 .54214 Mdot
.63964 .3847 Mdot
.61142 .56586 Mdot
.39021 .36209 Mdot
.57599 .52417 Mdot
.36954 .61355 Mdot
.28442 .32293 Mdot
.64914 .62295 Mdot
.55643 .16475 Mdot
.48943 .52759 Mdot
.35155 .49709 Mdot
.24246 .63759 Mdot
.51861 .87062 Mdot
.51203 .29415 Mdot
.60091 .375 Mdot
.37015 .77655 Mdot
.33748 .50446 Mdot
.22601 .57467 Mdot
.621 .80645 Mdot
.56397 .58542 Mdot
.57258 .55262 Mdot
.51168 .75258 Mdot
.37435 .51635 Mdot
.38826 .47925 Mdot
.52792 .57786 Mdot
.59004 .52244 Mdot
.34402 .50381 Mdot
.63496 .56526 Mdot
.55033 .64208 Mdot
.43207 .3224 Mdot
.63748 .36353 Mdot
.42005 .36363 Mdot
.4291 .38253 Mdot
.26051 .32334 Mdot
.47675 .54548 Mdot
.42561 .34733 Mdot
.46404 .37609 Mdot
.45956 .63377 Mdot
.70969 .68926 Mdot
.39525 .65563 Mdot
.5201 .83888 Mdot
.32874 .49142 Mdot
.60448 .56606 Mdot
.57931 .39792 Mdot
.69897 .56936 Mdot
.30562 .66809 Mdot
.66056 .25883 Mdot
.55319 .56343 Mdot
.34378 .51304 Mdot
.46023 .28868 Mdot
.62718 .67062 Mdot
.32809 .44729 Mdot
.62201 .60064 Mdot
.33374 .53078 Mdot
.73414 .64667 Mdot
.22239 .44224 Mdot
.29372 .49988 Mdot
.57162 .40315 Mdot
.61759 .61233 Mdot
.6144 .34567 Mdot
.44709 .32574 Mdot
.38907 .66045 Mdot
.38561 .63467 Mdot
.57717 .56745 Mdot
.60409 .50867 Mdot
.24509 .58804 Mdot
.57392 .5749 Mdot
.58958 .62138 Mdot
.49578 .33295 Mdot
.59373 .62632 Mdot
.57062 .62936 Mdot
.54458 .59323 Mdot
.53746 .58646 Mdot
.46771 .34321 Mdot
.26436 .44662 Mdot
.51848 .61426 Mdot
.5219 .56645 Mdot
.41396 .38023 Mdot
.37413 .76241 Mdot
.43723 .38474 Mdot
.63381 .79769 Mdot
.46675 .37011 Mdot
.37779 .6344 Mdot
.39808 .76633 Mdot
.54237 .52322 Mdot
.64596 .36484 Mdot
.48413 .31272 Mdot
.37917 .66002 Mdot
.45023 .33968 Mdot
.37169 .49702 Mdot
.82912 .56445 Mdot
.64239 .34404 Mdot
.66245 .31143 Mdot
.51831 .34112 Mdot
.26835 .42717 Mdot
.35412 .45524 Mdot
.57987 .35112 Mdot
.7475 .60827 Mdot
.57155 .62748 Mdot
.40168 .63188 Mdot
.5845 .56392 Mdot
.45111 .32343 Mdot
.33485 .50848 Mdot
.18124 .48478 Mdot
.39502 .63169 Mdot
.85473 .4485 Mdot
.33565 .47156 Mdot
.56149 .61939 Mdot
.43554 .38603 Mdot
.80695 .35425 Mdot
.42247 .36529 Mdot
.63227 .47244 Mdot
.59848 .40352 Mdot
.16237 .51856 Mdot
.61243 .36598 Mdot
.24545 .42203 Mdot
.75023 .2543 Mdot
.23569 .49742 Mdot
.617 .40416 Mdot
.40689 .54084 Mdot
.59249 .6098 Mdot
.61839 .62275 Mdot
.20444 .45352 Mdot
.58908 .41174 Mdot
.58174 .62879 Mdot
.37225 .32365 Mdot
.44073 .39848 Mdot
.81243 .43708 Mdot
.35052 .45777 Mdot
.61493 .58665 Mdot
.45317 .31424 Mdot
.47583 .3241 Mdot
.31866 .47701 Mdot
.43388 .37908 Mdot
.5881 .59331 Mdot
.61577 .36043 Mdot
.40518 .46189 Mdot
.37868 .62548 Mdot
.29264 .75468 Mdot
.36877 .60596 Mdot
.36018 .47684 Mdot
.63705 .55535 Mdot
.33901 .50127 Mdot
.6406 .8585 Mdot
.59542 .60488 Mdot
.6204 .39844 Mdot
.58642 .62448 Mdot
.61394 .61427 Mdot
.54054 .57686 Mdot
.35482 .50766 Mdot
.34768 .70821 Mdot
.6394 .5844 Mdot
.44092 .36841 Mdot
.71287 .44419 Mdot
.62542 .64368 Mdot
.36819 .56999 Mdot
.62372 .71541 Mdot
.54211 .33597 Mdot
.59728 .41037 Mdot
.35433 .49182 Mdot
.61426 .39016 Mdot
.49368 .18962 Mdot
.61596 .3815 Mdot
.69833 .48998 Mdot
.75336 .60616 Mdot
.79353 .56076 Mdot
.79617 .54433 Mdot
.43614 .4772 Mdot
.59461 .41529 Mdot
.41854 .63314 Mdot
.62564 .40923 Mdot
.58355 .38448 Mdot
.43998 .10601 Mdot
.62718 .3476 Mdot
.62205 .58467 Mdot
.60968 .64774 Mdot
.23433 .4597 Mdot
.45617 .69082 Mdot
.57566 .61214 Mdot
.574 .61753 Mdot
.36182 .6607 Mdot
.48938 .19393 Mdot
.32698 .40447 Mdot
.7108 .33275 Mdot
.29369 .71399 Mdot
.58676 .56524 Mdot
.6118 .63351 Mdot
.5228 .60665 Mdot
.72484 .27112 Mdot
.23969 .34435 Mdot
.5674 .40034 Mdot
.52334 .57364 Mdot
.22273 .5195 Mdot
.55276 .56184 Mdot
.62878 .57386 Mdot
.58949 .60317 Mdot
.3374 .50506 Mdot
.60156 .41546 Mdot
.5365 .59989 Mdot
.44019 .7715 Mdot
.62724 .58226 Mdot
.44646 .27957 Mdot
.19375 .64295 Mdot
.6173 .58139 Mdot
.64671 .40791 Mdot
.61583 .62494 Mdot
.58842 .38055 Mdot
.58536 .35912 Mdot
.52609 .57179 Mdot
.68011 .46353 Mdot
.633 .4138 Mdot
.57917 .58392 Mdot
.37315 .49925 Mdot
.55121 .82451 Mdot
.56413 .56335 Mdot
.39686 .65318 Mdot
.62057 .56336 Mdot
.40929 .63053 Mdot
.58399 .6157 Mdot
.326 .46104 Mdot
.68162 .53857 Mdot
.33636 .4901 Mdot
.19643 .41065 Mdot
.31618 .4681 Mdot
.86114 .47851 Mdot
.57684 .38044 Mdot
.34789 .36454 Mdot
.58896 .21209 Mdot
.39897 .26691 Mdot
.52601 .41956 Mdot
.44267 .44353 Mdot
.42043 .37269 Mdot
.59371 .3955 Mdot
.54625 .21229 Mdot
.32167 .61796 Mdot
.32903 .57911 Mdot
.33771 .52312 Mdot
.20518 .32128 Mdot
.53233 .17701 Mdot
.57818 .53474 Mdot
.75275 .55926 Mdot
.74658 .48996 Mdot
.54997 .56353 Mdot
.54048 .57206 Mdot
.29171 .51603 Mdot
.64002 .57458 Mdot
.59527 .28874 Mdot
.35826 .46918 Mdot
.38342 .65906 Mdot
.63069 .40044 Mdot
.38469 .6101 Mdot
.32335 .66149 Mdot
.44354 .43826 Mdot
.37101 .48981 Mdot
.64974 .57723 Mdot
.57022 .60863 Mdot
.59084 .37235 Mdot
.67923 .3863 Mdot
.64719 .39373 Mdot
.37634 .65071 Mdot
.35306 .46519 Mdot
.37002 .20849 Mdot
.5688 .61068 Mdot
.63177 .36662 Mdot
.53245 .42923 Mdot
.59669 .63114 Mdot
.4505 .32885 Mdot
.5967 .61343 Mdot
.62544 .40536 Mdot
.59335 .6261 Mdot
.61103 .36689 Mdot
.35274 .47702 Mdot
.54806 .60541 Mdot
.5505 .5879 Mdot
.83379 .41524 Mdot
.36754 .64619 Mdot
.58019 .34867 Mdot
.44262 .59419 Mdot
.60022 .63696 Mdot
.32289 .34917 Mdot
.62182 .59648 Mdot
.56309 .34335 Mdot
.58727 .53604 Mdot
.47898 .29169 Mdot
.52829 .55075 Mdot
.58008 .56037 Mdot
.54443 .47166 Mdot
.73878 .49164 Mdot
.50261 .57683 Mdot
.47686 .36291 Mdot
.58458 .34521 Mdot
.81326 .44982 Mdot
.40083 .49974 Mdot
.37865 .45651 Mdot
.52246 .71551 Mdot
.54111 .61112 Mdot
.60819 .58174 Mdot
.54555 .34013 Mdot
.39545 .62371 Mdot
.62512 .353 Mdot
.36856 .65628 Mdot
.84585 .47056 Mdot
.35545 .62973 Mdot
.33273 .54267 Mdot
.23485 .57067 Mdot
.33035 .23728 Mdot
.36021 .65774 Mdot
.62565 .40651 Mdot
.23753 .5284 Mdot
.56191 .62572 Mdot
.50159 .51246 Mdot
.36918 .63423 Mdot
.15726 .41713 Mdot
.56918 .62789 Mdot
.52947 .4191 Mdot
.42226 .34718 Mdot
.3623 .65839 Mdot
.41053 .36142 Mdot
.56511 .59588 Mdot
.33113 .40412 Mdot
.60182 .37556 Mdot
.40726 .36484 Mdot
.62155 .6533 Mdot
.37212 .65277 Mdot
.33486 .45264 Mdot
.40045 .35876 Mdot
.45519 .38184 Mdot
.43574 .80382 Mdot
.17088 .4894 Mdot
.35026 .46462 Mdot
.76532 .37572 Mdot
.48318 .3454 Mdot
.56771 .63242 Mdot
.51414 .19753 Mdot
.61837 .61877 Mdot
.36145 .25511 Mdot
.35984 .4874 Mdot
.26782 .43248 Mdot
.60188 .63201 Mdot
.5704 .55778 Mdot
.65583 .36423 Mdot
.33726 .48222 Mdot
.62575 .37261 Mdot
.56726 .35857 Mdot
.35186 .47546 Mdot
.61067 .37613 Mdot
.36054 .66578 Mdot
.59061 .2484 Mdot
.46433 .3688 Mdot
.45175 .36788 Mdot
.3272 .49997 Mdot
.35493 .49775 Mdot
.3422 .49707 Mdot
.59724 .61417 Mdot
.63667 .36758 Mdot
.57267 .59335 Mdot
.61496 .55261 Mdot
.71967 .4262 Mdot
.59135 .40931 Mdot
.58083 .59594 Mdot
.45914 .56067 Mdot
.59449 .48449 Mdot
.37617 .49037 Mdot
.42492 .3457 Mdot
.36353 .33609 Mdot
.2686 .38063 Mdot
.61481 .59061 Mdot
.40926 .68396 Mdot
.62664 .40735 Mdot
.3904 .64262 Mdot
.35638 .62039 Mdot
.38303 .64264 Mdot
.49875 .37287 Mdot
.57494 .38987 Mdot
.70917 .34697 Mdot
.61302 .58424 Mdot
.60432 .31203 Mdot
.56285 .39648 Mdot
.24634 .54204 Mdot
.42698 .34467 Mdot
.58546 .62594 Mdot
.43358 .56194 Mdot
.71382 .63795 Mdot
.61317 .61993 Mdot
.61966 .64756 Mdot
.29424 .69235 Mdot
.65905 .57605 Mdot
.6542 .37293 Mdot
.81038 .36753 Mdot
.63489 .62697 Mdot
.39276 .22413 Mdot
.3194 .79088 Mdot
.61596 .59934 Mdot
.58067 .5542 Mdot
.56119 .60627 Mdot
.61998 .62941 Mdot
.63676 .41379 Mdot
.47717 .6724 Mdot
.48261 .35053 Mdot
.61382 .31147 Mdot
.46045 .32679 Mdot
.31021 .50638 Mdot
.26802 .43494 Mdot
.59706 .40062 Mdot
.37999 .61484 Mdot
.2621 .70101 Mdot
.75476 .33008 Mdot
.32479 .46981 Mdot
.30651 .27019 Mdot
.37084 .63551 Mdot
.58499 .64556 Mdot
.38509 .66824 Mdot
.36726 .45857 Mdot
.45678 .36855 Mdot
.65075 .62555 Mdot
.61307 .40671 Mdot
.64502 .38233 Mdot
.58819 .62928 Mdot
.21497 .55756 Mdot
.43728 .32813 Mdot
.46958 .37425 Mdot
.63149 .5898 Mdot
.63547 .62968 Mdot
.62294 .37271 Mdot
.3228 .49027 Mdot
.80175 .55403 Mdot
.3973 .64111 Mdot
.55487 .55502 Mdot
.59847 .62743 Mdot
.82079 .56566 Mdot
.44125 .37103 Mdot
.35067 .44342 Mdot
.61039 .5419 Mdot
.48609 .25377 Mdot
.61786 .54706 Mdot
.5278 .61383 Mdot
.37429 .49828 Mdot
.55687 .66008 Mdot
.54063 .55908 Mdot
.58317 .33479 Mdot
.41576 .36425 Mdot
.62109 .39157 Mdot
.58706 .33232 Mdot
.62006 .25703 Mdot
.4545 .33239 Mdot
.58777 .60595 Mdot
.43237 .34043 Mdot
.62731 .59993 Mdot
.63684 .614 Mdot
.42465 .35086 Mdot
.6248 .37163 Mdot
.36173 .76872 Mdot
.24721 .475 Mdot
.62777 .62404 Mdot
.52893 .57065 Mdot
.45808 .67157 Mdot
.34005 .61278 Mdot
.56855 .55498 Mdot
.63433 .40232 Mdot
.56217 .59898 Mdot
.42505 .33242 Mdot
.3657 .6701 Mdot
.61721 .40228 Mdot
.32893 .4737 Mdot
.33162 .46055 Mdot
.52269 .29301 Mdot
.35562 .52283 Mdot
.57521 .5506 Mdot
.67249 .38317 Mdot
.66151 .38945 Mdot
.23732 .67013 Mdot
.34878 .47369 Mdot
.4005 .65023 Mdot
.55913 .57409 Mdot
.57518 .73798 Mdot
.44595 .31423 Mdot
.40789 .13971 Mdot
.68677 .29128 Mdot
.3826 .67373 Mdot
.69429 .33159 Mdot
.31731 .47036 Mdot
.53098 .5787 Mdot
.39809 .65051 Mdot
.35337 .45626 Mdot
.63154 .60771 Mdot
.52288 .57859 Mdot
.61319 .46522 Mdot
.40668 .42397 Mdot
.43145 .34398 Mdot
.33385 .52781 Mdot
.39958 .6631 Mdot
.3036 .50214 Mdot
.58004 .36466 Mdot
.59664 .56015 Mdot
.63311 .55321 Mdot
.32179 .48815 Mdot
.3791 .45492 Mdot
.58029 .58986 Mdot
.61501 .41174 Mdot
.31596 .55064 Mdot
.58993 .56883 Mdot
.3983 .39755 Mdot
.59225 .41802 Mdot
.35218 .46031 Mdot
.57844 .55775 Mdot
.40169 .60191 Mdot
.33078 .47673 Mdot
.37653 .48587 Mdot
.61017 .63407 Mdot
.35646 .65629 Mdot
.55057 .54423 Mdot
.45577 .37587 Mdot
.1979 .34234 Mdot
.42587 .33127 Mdot
.40162 .50854 Mdot
.66045 .57157 Mdot
.48502 .23103 Mdot
.59139 .40378 Mdot
.55751 .70823 Mdot
.3713 .32624 Mdot
.55272 .64495 Mdot
.53854 .81257 Mdot
.42533 .29469 Mdot
.23269 .64926 Mdot
.5854 .77365 Mdot
.36621 .6325 Mdot
.45177 .34151 Mdot
.58074 .55398 Mdot
.42898 .32373 Mdot
.40121 .64492 Mdot
.19927 .40727 Mdot
.56307 .56225 Mdot
.63817 .38966 Mdot
.58552 .59433 Mdot
.64207 .37935 Mdot
.62262 .63165 Mdot
.56822 .53104 Mdot
.38783 .28292 Mdot
.48678 .64004 Mdot
.61377 .54507 Mdot
.86043 .39377 Mdot
.59936 .477 Mdot
.39316 .64962 Mdot
.56748 .58608 Mdot
.30624 .46497 Mdot
.46988 .32481 Mdot
.42661 .26193 Mdot
.3388 .50626 Mdot
.45284 .38169 Mdot
.6161 .37455 Mdot
.35664 .48544 Mdot
.32088 .47563 Mdot
.56508 .66545 Mdot
.37226 .67469 Mdot
.45417 .35813 Mdot
.61112 .56403 Mdot
.56625 .56134 Mdot
.76671 .37071 Mdot
.30939 .62476 Mdot
.68368 .35966 Mdot
.67065 .22369 Mdot
.56958 .36833 Mdot
.37861 .65793 Mdot
.35069 .50996 Mdot
.6029 .54773 Mdot
.59352 .59185 Mdot
.33284 .3503 Mdot
.63872 .40609 Mdot
.46435 .48234 Mdot
.68895 .37077 Mdot
.43423 .6118 Mdot
.48675 .65565 Mdot
.63129 .40163 Mdot
.48261 .65346 Mdot
.3692 .68321 Mdot
.44871 .83424 Mdot
.47344 .62465 Mdot
.42408 .34349 Mdot
.47395 .64877 Mdot
.62316 .3533 Mdot
.63778 .59004 Mdot
.37174 .50442 Mdot
.36167 .51786 Mdot
.62542 .38446 Mdot
.31449 .46128 Mdot
.366 .62689 Mdot
.59943 .55337 Mdot
.71243 .31487 Mdot
.55157 .27192 Mdot
.32498 .50481 Mdot
.60103 .67116 Mdot
.46221 .34726 Mdot
.58942 .6301 Mdot
.3588 .64534 Mdot
.44149 .33401 Mdot
.71158 .701 Mdot
.43169 .40282 Mdot
.5646 .57107 Mdot
.82435 .56426 Mdot
.45208 .33437 Mdot
.68047 .56935 Mdot
.59804 .56734 Mdot
.44527 .3789 Mdot
.64664 .67477 Mdot
.2698 .40261 Mdot
.47366 .51931 Mdot
.62229 .80705 Mdot
.49395 .48415 Mdot
.34154 .51577 Mdot
.2684 .41775 Mdot
.39011 .26499 Mdot
.479 .33893 Mdot
.36655 .44611 Mdot
.47743 .55356 Mdot
.41165 .36301 Mdot
.58083 .64262 Mdot
.61929 .60118 Mdot
.23423 .35525 Mdot
.45303 .30281 Mdot
.2397 .42659 Mdot
.53404 .31268 Mdot
.59894 .63777 Mdot
.56751 .53525 Mdot
.59556 .58821 Mdot
.6538 .39145 Mdot
.43224 .35432 Mdot
.83837 .38435 Mdot
.44594 .3264 Mdot
.70334 .41925 Mdot
.32852 .49557 Mdot
.35256 .45779 Mdot
.61694 .58596 Mdot
.53193 .41323 Mdot
.66784 .71536 Mdot
.58548 .58948 Mdot
.33562 .65319 Mdot
.23742 .37038 Mdot
.62853 .63396 Mdot
.60203 .40896 Mdot
.55247 .65038 Mdot
.67304 .61526 Mdot
.46594 .36718 Mdot
.37834 .6184 Mdot
.59786 .71904 Mdot
.45933 .36453 Mdot
.60683 .58235 Mdot
.49541 .24006 Mdot
.60748 .61299 Mdot
.62798 .62133 Mdot
.68754 .40608 Mdot
.35305 .62881 Mdot
.34586 .48756 Mdot
.38022 .64278 Mdot
.58661 .38921 Mdot
.36436 .13369 Mdot
.3569 .6258 Mdot
.69121 .70545 Mdot
.21299 .36669 Mdot
.46732 .64037 Mdot
.62595 .35198 Mdot
.39263 .66607 Mdot
.42962 .33403 Mdot
.54877 .82694 Mdot
.61703 .47499 Mdot
.41645 .30696 Mdot
.59426 .57215 Mdot
.60153 .3387 Mdot
.64786 .37913 Mdot
.40771 .36935 Mdot
.58382 .35667 Mdot
.51238 .61937 Mdot
.63404 .60752 Mdot
.47035 .33523 Mdot
.51138 .26325 Mdot
.48323 .35371 Mdot
.42106 .52396 Mdot
.56974 .58119 Mdot
.62132 .40194 Mdot
.54274 .56267 Mdot
.6394 .42206 Mdot
.33942 .44621 Mdot
.64692 .57102 Mdot
.36606 .62524 Mdot
.47214 .2357 Mdot
.34731 .46372 Mdot
.44396 .61288 Mdot
.58946 .37488 Mdot
.49702 .38038 Mdot
.58725 .36994 Mdot
.65911 .40363 Mdot
.43649 .3854 Mdot
.60471 .35075 Mdot
.58521 .55379 Mdot
.47309 .53132 Mdot
.59584 .37325 Mdot
.44562 .35467 Mdot
.38406 .62122 Mdot
.61458 .36866 Mdot
.31127 .53761 Mdot
.55928 .57085 Mdot
.35517 .5052 Mdot
.32793 .65894 Mdot
.61474 .34079 Mdot
.34884 .65411 Mdot
.38144 .46194 Mdot
.39929 .61982 Mdot
.2043 .60974 Mdot
.41303 .39076 Mdot
.67734 .44007 Mdot
.33354 .6573 Mdot
.64825 .36766 Mdot
.35107 .72049 Mdot
.61763 .55601 Mdot
.55805 .57303 Mdot
.40828 .63011 Mdot
.64794 .37939 Mdot
.38221 .8268 Mdot
.61826 .51003 Mdot
.42743 .49386 Mdot
.49168 .3362 Mdot
.86377 .46564 Mdot
.42277 .51257 Mdot
.28692 .76752 Mdot
.60864 .66675 Mdot
.3888 .48259 Mdot
.60853 .59349 Mdot
.35903 .3173 Mdot
.37125 .64872 Mdot
.38547 .55195 Mdot
.61358 .53456 Mdot
.35113 .48402 Mdot
.54874 .59444 Mdot
.53342 .47798 Mdot
.68486 .60204 Mdot
.40593 .63978 Mdot
.2259 .54975 Mdot
.61296 .34193 Mdot
.37634 .62761 Mdot
.36309 .46169 Mdot
.5287 .68059 Mdot
.63192 .60922 Mdot
.57492 .6409 Mdot
.43344 .61166 Mdot
.63562 .36405 Mdot
.35729 .51459 Mdot
.45561 .37457 Mdot
.38639 .61808 Mdot
.57095 .60742 Mdot
.61754 .5529 Mdot
.32634 .3381 Mdot
.46385 .34177 Mdot
.37622 .51135 Mdot
.41772 .35496 Mdot
.31434 .48155 Mdot
.64142 .58868 Mdot
.33676 .46057 Mdot
.53781 .61196 Mdot
.42989 .27809 Mdot
.68555 .42223 Mdot
.74132 .51124 Mdot
.36178 .48294 Mdot
.71891 .68045 Mdot
.46188 .33963 Mdot
.42564 .36992 Mdot
.25154 .30678 Mdot
.62524 .4683 Mdot
.75292 .34306 Mdot
.49991 .7949 Mdot
.46997 .34159 Mdot
.45606 .35265 Mdot
.35572 .50381 Mdot
.60128 .35156 Mdot
.5716 .3656 Mdot
.31576 .48142 Mdot
.45971 .72931 Mdot
.62567 .35354 Mdot
.50551 .82877 Mdot
.80004 .4137 Mdot
.55226 .6361 Mdot
.34888 .54688 Mdot
.39196 .63639 Mdot
.47267 .72193 Mdot
.52295 .48653 Mdot
.56327 .55921 Mdot
.55479 .72193 Mdot
.32447 .49583 Mdot
.52436 .38755 Mdot
.62291 .79873 Mdot
.54785 .60037 Mdot
.60247 .56557 Mdot
.60222 .58829 Mdot
.3635 .67391 Mdot
.65014 .49732 Mdot
.59028 .55606 Mdot
.45666 .73009 Mdot
.59446 .63467 Mdot
.68763 .60607 Mdot
.38457 .63729 Mdot
.48101 .59005 Mdot
.32135 .63753 Mdot
.81079 .37767 Mdot
.67401 .57379 Mdot
.46025 .37342 Mdot
.3498 .576 Mdot
.42154 .36904 Mdot
.70996 .49147 Mdot
.46455 .62135 Mdot
.56843 .37413 Mdot
.56567 .55795 Mdot
.36031 .47553 Mdot
.64751 .37902 Mdot
.29321 .38571 Mdot
.40656 .11695 Mdot
.47172 .36324 Mdot
.44056 .8845 Mdot
.43961 .37878 Mdot
.31969 .47865 Mdot
.6225 .37364 Mdot
.74588 .62228 Mdot
.62804 .28984 Mdot
.61262 .37034 Mdot
.35698 .79296 Mdot
.57237 .41332 Mdot
.59117 .70762 Mdot
.64354 .35342 Mdot
.45027 .35144 Mdot
.51057 .35135 Mdot
.50615 .6171 Mdot
.62526 .57145 Mdot
.44902 .44388 Mdot
.66691 .71281 Mdot
.61608 .55493 Mdot
.35669 .46808 Mdot
.66214 .44285 Mdot
.53495 .71442 Mdot
.61215 .35046 Mdot
.42891 .39948 Mdot
.59445 .56251 Mdot
.60745 .62694 Mdot
.63484 .59903 Mdot
.68908 .28305 Mdot
.44397 .83332 Mdot
.63944 .58685 Mdot
.61547 .63553 Mdot
.35455 .48426 Mdot
.35498 .5976 Mdot
.24223 .50731 Mdot
.75067 .38205 Mdot
.54159 .5919 Mdot
.38063 .62918 Mdot
.4062 .65862 Mdot
.63231 .56367 Mdot
.47237 .54662 Mdot
.49811 .23464 Mdot
.60968 .5628 Mdot
.6558 .44712 Mdot
.28714 .4587 Mdot
.37603 .5152 Mdot
.32707 .47863 Mdot
.58944 .34532 Mdot
.31814 .49061 Mdot
.32635 .45896 Mdot
.71864 .6525 Mdot
.48164 .48121 Mdot
.41426 .28523 Mdot
.37846 .65143 Mdot
.59655 .59797 Mdot
.50888 .55577 Mdot
.48557 .24751 Mdot
.41897 .37514 Mdot
.60934 .40041 Mdot
.46659 .32153 Mdot
.41393 .65481 Mdot
.64882 .27693 Mdot
.32544 .51608 Mdot
.46975 .35352 Mdot
.40384 .39059 Mdot
.38298 .6293 Mdot
.41306 .34432 Mdot
.43964 .41354 Mdot
.64779 .60724 Mdot
.74181 .57087 Mdot
.58105 .58301 Mdot
.26687 .71286 Mdot
.46098 .3539 Mdot
.50161 .34363 Mdot
.61137 .57493 Mdot
.3335 .47483 Mdot
.61533 .69272 Mdot
.6275 .57532 Mdot
.31905 .49248 Mdot
.5857 .53393 Mdot
.37397 .60482 Mdot
.60616 .42155 Mdot
.62521 .2916 Mdot
.20792 .31345 Mdot
.37629 .67398 Mdot
.30033 .37865 Mdot
.55714 .56016 Mdot
.18142 .52962 Mdot
.61576 .36602 Mdot
.5868 .54108 Mdot
.51984 .69421 Mdot
.60079 .36505 Mdot
.61069 .38932 Mdot
.59383 .61749 Mdot
.42083 .34726 Mdot
.34861 .46189 Mdot
.38668 .63205 Mdot
.25662 .7247 Mdot
.58267 .5714 Mdot
.55396 .59176 Mdot
.37384 .63132 Mdot
.45927 .33105 Mdot
.61966 .54917 Mdot
.48847 .768 Mdot
.41939 .84338 Mdot
.43827 .38084 Mdot
.56074 .62149 Mdot
.71139 .52007 Mdot
.64908 .53657 Mdot
.15566 .54728 Mdot
.49243 .52413 Mdot
.34891 .49145 Mdot
.63501 .53408 Mdot
.51292 .1411 Mdot
.38244 .61882 Mdot
.75362 .33242 Mdot
.60579 .62791 Mdot
.56979 .61504 Mdot
.64311 .39957 Mdot
.57434 .5912 Mdot
.6008 .40202 Mdot
.28403 .24852 Mdot
.83598 .54337 Mdot
.5783 .3558 Mdot
.64362 .35978 Mdot
.6129 .72017 Mdot
.37927 .36627 Mdot
.62374 .38241 Mdot
.63645 .61865 Mdot
.46707 .58532 Mdot
.54047 .36303 Mdot
.39777 .65871 Mdot
.3396 .70463 Mdot
.57223 .50277 Mdot
.42983 .6596 Mdot
.37273 .76462 Mdot
.53472 .51774 Mdot
.4211 .54453 Mdot
.43561 .37295 Mdot
.54693 .59991 Mdot
.36276 .51795 Mdot
.36115 .52092 Mdot
.53378 .60538 Mdot
.6001 .60759 Mdot
.58673 .38454 Mdot
.39523 .62755 Mdot
.48162 .33688 Mdot
.57197 .6145 Mdot
.55298 .70377 Mdot
.38864 .61501 Mdot
.58922 .35376 Mdot
.70522 .44034 Mdot
.36929 .60211 Mdot
.55421 .53536 Mdot
.61894 .56885 Mdot
.58726 .59939 Mdot
.50342 .61349 Mdot
.43032 .35803 Mdot
.38331 .75788 Mdot
.61234 .64432 Mdot
.8458 .46016 Mdot
.39724 .30039 Mdot
.62385 .53307 Mdot
.58279 .3656 Mdot
.45373 .39161 Mdot
.30893 .47731 Mdot
.59955 .23708 Mdot
.56747 .57085 Mdot
.21899 .55129 Mdot
.23059 .36481 Mdot
.35824 .44644 Mdot
.62812 .42333 Mdot
.38387 .64642 Mdot
.58783 .59192 Mdot
.67695 .46582 Mdot
.61908 .59773 Mdot
.36066 .68658 Mdot
.37753 .47747 Mdot
.43296 .37154 Mdot
.24447 .66924 Mdot
.34614 .52729 Mdot
.61359 .38976 Mdot
.78017 .67112 Mdot
.601 .4032 Mdot
.57208 .36281 Mdot
.71367 .43996 Mdot
.42927 .35882 Mdot
.45712 .13243 Mdot
.30091 .24563 Mdot
.64552 .59071 Mdot
.45974 .33375 Mdot
.62826 .39147 Mdot
.58088 .63115 Mdot
.598 .42923 Mdot
.57613 .3964 Mdot
.63995 .60209 Mdot
.56324 .61251 Mdot
.22292 .45999 Mdot
.59269 .79568 Mdot
.38234 .64767 Mdot
.58435 .3942 Mdot
.60783 .28762 Mdot
.58142 .63291 Mdot
.61326 .5831 Mdot
.35173 .27647 Mdot
.37118 .67256 Mdot
.57878 .27127 Mdot
.60673 .62738 Mdot
.79536 .61833 Mdot
.53093 .63094 Mdot
.62784 .4153 Mdot
.42384 .37322 Mdot
.81758 .39486 Mdot
.42271 .41635 Mdot
.60087 .40081 Mdot
.37402 .61426 Mdot
.65976 .37077 Mdot
.70521 .69794 Mdot
.45814 .32663 Mdot
.62562 .40535 Mdot
.42907 .56285 Mdot
.43664 .3469 Mdot
.463 .35754 Mdot
.72566 .42499 Mdot
.33429 .44502 Mdot
.36994 .67735 Mdot
.45564 .35583 Mdot
.47154 .2068 Mdot
.44507 .34915 Mdot
.28304 .26031 Mdot
.55116 .60764 Mdot
.51118 .7325 Mdot
.39728 .52347 Mdot
.58234 .50882 Mdot
.46534 .34968 Mdot
.36352 .66355 Mdot
.63027 .60947 Mdot
.60891 .34592 Mdot
.40059 .63359 Mdot
.41929 .31709 Mdot
.34247 .50434 Mdot
.59008 .36602 Mdot
.47389 .30972 Mdot
.64355 .38316 Mdot
.54534 .21303 Mdot
.19782 .36955 Mdot
.62214 .73314 Mdot
.6301 .28781 Mdot
.63165 .61168 Mdot
.45121 .80553 Mdot
.55441 .61861 Mdot
.6027 .61402 Mdot
.3551 .46317 Mdot
.52638 .72571 Mdot
.62528 .37253 Mdot
.3203 .7699 Mdot
.46738 .36376 Mdot
.81674 .38583 Mdot
.66812 .56602 Mdot
.56186 .54634 Mdot
.59457 .37654 Mdot
.62902 .41121 Mdot
.73226 .47476 Mdot
.3067 .51711 Mdot
.55578 .55729 Mdot
.63545 .64333 Mdot
.53004 .60149 Mdot
.46042 .36827 Mdot
.45803 .5793 Mdot
.33681 .51499 Mdot
.17725 .43418 Mdot
.37807 .47472 Mdot
.37552 .69383 Mdot
.60355 .34891 Mdot
.35736 .62517 Mdot
.61446 .58072 Mdot
.67574 .39673 Mdot
.64189 .40391 Mdot
.4069 .62769 Mdot
.36789 .66121 Mdot
.29403 .35381 Mdot
.42522 .35008 Mdot
.63098 .57475 Mdot
.58083 .55717 Mdot
.57431 .59815 Mdot
.59696 .61197 Mdot
.47229 .36103 Mdot
.63254 .59792 Mdot
.43925 .31387 Mdot
.61195 .23429 Mdot
.5187 .75355 Mdot
.49911 .48136 Mdot
.3281 .26552 Mdot
.61662 .35026 Mdot
.47418 .21321 Mdot
.66738 .60275 Mdot
.59273 .20007 Mdot
.20131 .43388 Mdot
.63518 .63517 Mdot
.3363 .4576 Mdot
.66069 .67239 Mdot
.34128 .52296 Mdot
.29384 .78349 Mdot
.36389 .2856 Mdot
.57895 .80305 Mdot
.56508 .56204 Mdot
.47118 .53163 Mdot
.44038 .20809 Mdot
.56146 .62675 Mdot
.32173 .3269 Mdot
.36017 .2544 Mdot
.22977 .5275 Mdot
.35826 .6559 Mdot
.57517 .56528 Mdot
.50549 .56622 Mdot
.59111 .55351 Mdot
.61137 .58986 Mdot
.63374 .59864 Mdot
.486 .33468 Mdot
.5873 .54404 Mdot
.62368 .6164 Mdot
.24973 .60022 Mdot
.48625 .64977 Mdot
.38488 .49078 Mdot
.23739 .32743 Mdot
.35565 .62783 Mdot
.59136 .37619 Mdot
.43337 .82291 Mdot
.42465 .34323 Mdot
.73785 .47774 Mdot
.59295 .60648 Mdot
.23351 .46538 Mdot
.41211 .40386 Mdot
.37076 .61709 Mdot
.36432 .45544 Mdot
.57931 .81603 Mdot
.3569 .47295 Mdot
.48002 .37977 Mdot
.33766 .47203 Mdot
.66153 .56636 Mdot
.58613 .38643 Mdot
.63235 .56939 Mdot
.45195 .36054 Mdot
.32635 .47371 Mdot
.458 .68332 Mdot
.59736 .58994 Mdot
.35122 .47603 Mdot
.6328 .57135 Mdot
.66485 .30839 Mdot
.77785 .40512 Mdot
.33402 .45505 Mdot
.40276 .38325 Mdot
.43999 .36441 Mdot
.35557 .64664 Mdot
.59418 .36705 Mdot
.60552 .40018 Mdot
.44246 .33489 Mdot
.64896 .43468 Mdot
.54052 .59197 Mdot
.57206 .6247 Mdot
.82813 .4224 Mdot
.58746 .55087 Mdot
.52968 .67939 Mdot
.43636 .5641 Mdot
.59024 .34873 Mdot
.55438 .54873 Mdot
.59425 .62185 Mdot
.56276 .57145 Mdot
.6814 .31013 Mdot
.321 .4952 Mdot
.54887 .60337 Mdot
.37489 .66307 Mdot
.26341 .47632 Mdot
.59024 .63042 Mdot
.53644 .64357 Mdot
.60726 .40131 Mdot
.67761 .2353 Mdot
.43706 .37753 Mdot
.36308 .46272 Mdot
.36226 .48413 Mdot
.37024 .74936 Mdot
.42854 .2331 Mdot
.4381 .56269 Mdot
.1563 .48539 Mdot
.38837 .28295 Mdot
.37136 .6568 Mdot
.38214 .51639 Mdot
.50751 .33702 Mdot
.36454 .49344 Mdot
.47737 .35633 Mdot
.56 .61909 Mdot
.54204 .59516 Mdot
.48548 .15546 Mdot
.62551 .55399 Mdot
.38698 .6423 Mdot
.48595 .34473 Mdot
.62538 .35575 Mdot
.37571 .6153 Mdot
.41739 .35763 Mdot
.58784 .34662 Mdot
.6333 .63824 Mdot
.61979 .64369 Mdot
.60727 .3979 Mdot
.64218 .39767 Mdot
.61737 .571 Mdot
.36743 .4052 Mdot
.64352 .36174 Mdot
.63097 .40272 Mdot
.32511 .51333 Mdot
.35805 .52089 Mdot
.51696 .57423 Mdot
.45996 .34146 Mdot
.62607 .61372 Mdot
.35826 .48251 Mdot
.35667 .62743 Mdot
.62556 .36929 Mdot
.62466 .62646 Mdot
.58379 .62372 Mdot
.38368 .62804 Mdot
.35818 .63216 Mdot
.35934 .6478 Mdot
.46649 .3091 Mdot
.56789 .59257 Mdot
.61944 .37684 Mdot
.42552 .35644 Mdot
.39947 .66617 Mdot
.38837 .66557 Mdot
.3617 .53522 Mdot
.59146 .54775 Mdot
.40484 .46018 Mdot
.53154 .14184 Mdot
.83647 .50676 Mdot
.34045 .44887 Mdot
.30653 .48257 Mdot
.42578 .6904 Mdot
.52886 .37197 Mdot
.4461 .32872 Mdot
.343 .61052 Mdot
.63065 .72503 Mdot
.65065 .61614 Mdot
.62696 .63318 Mdot
.57712 .53077 Mdot
.36029 .65141 Mdot
.54226 .73703 Mdot
.59574 .39916 Mdot
.49099 .61655 Mdot
.39083 .6154 Mdot
.3831 .46658 Mdot
.38006 .52405 Mdot
.37653 .47003 Mdot
.59268 .64674 Mdot
.7499 .52345 Mdot
.45384 .22624 Mdot
.48339 .78502 Mdot
.46495 .34479 Mdot
.51114 .55151 Mdot
.18445 .51849 Mdot
.60731 .39247 Mdot
.31037 .51022 Mdot
.37307 .65915 Mdot
.64327 .39498 Mdot
.45951 .31949 Mdot
.45424 .35467 Mdot
.32598 .50573 Mdot
.32929 .50531 Mdot
.36923 .49866 Mdot
.57626 .4006 Mdot
.60351 .3498 Mdot
.56682 .57284 Mdot
.62496 .36401 Mdot
.65381 .24318 Mdot
.4049 .61469 Mdot
.31565 .45018 Mdot
.45475 .34142 Mdot
.61821 .3473 Mdot
.59419 .58845 Mdot
.57003 .33528 Mdot
.47545 .27584 Mdot
.39419 .65044 Mdot
.77152 .38767 Mdot
.25784 .74089 Mdot
.62856 .56746 Mdot
.43449 .36464 Mdot
.71202 .30567 Mdot
.60025 .58603 Mdot
.35675 .50961 Mdot
.2662 .663 Mdot
.37499 .4242 Mdot
.62801 .57891 Mdot
.65022 .60122 Mdot
.45625 .37729 Mdot
.17817 .44067 Mdot
.57349 .57176 Mdot
.58283 .25935 Mdot
.40932 .39661 Mdot
.34893 .51499 Mdot
.55512 .86408 Mdot
.40898 .5968 Mdot
.46969 .72601 Mdot
.32808 .51142 Mdot
.61531 .61361 Mdot
.3326 .52233 Mdot
.38279 .66131 Mdot
.36056 .45611 Mdot
.60317 .4063 Mdot
.3777 .4638 Mdot
.55431 .59299 Mdot
.62392 .38599 Mdot
.45286 .33386 Mdot
.80082 .37139 Mdot
.2828 .66271 Mdot
.33206 .47701 Mdot
.3271 .46142 Mdot
.5618 .54312 Mdot
.5891 .28761 Mdot
.53439 .59939 Mdot
.56671 .6252 Mdot
.46615 .33398 Mdot
.59835 .36656 Mdot
.43832 .38249 Mdot
.54791 .52628 Mdot
.53686 .76402 Mdot
.41885 .3571 Mdot
.23793 .49615 Mdot
.36956 .63773 Mdot
.50583 .43348 Mdot
.59301 .59326 Mdot
.40994 .35442 Mdot
.56666 .58971 Mdot
.59248 .39702 Mdot
.51728 .46309 Mdot
.30335 .41918 Mdot
.4551 .36527 Mdot
.22253 .61249 Mdot
.4856 .75725 Mdot
.50989 .59623 Mdot
.42559 .37127 Mdot
.5207 .7018 Mdot
.31872 .48123 Mdot
.39867 .63864 Mdot
.38308 .6043 Mdot
.3922 .61455 Mdot
.56182 .64873 Mdot
.67178 .57215 Mdot
.34895 .6575 Mdot
.4684 .32532 Mdot
.4057 .64065 Mdot
.37622 .22274 Mdot
.32377 .77239 Mdot
.37113 .64484 Mdot
.59618 .56894 Mdot
.6616 .6461 Mdot
.46056 .63373 Mdot
.26533 .40287 Mdot
.56347 .80608 Mdot
.29117 .31891 Mdot
.62534 .57937 Mdot
.58472 .41511 Mdot
.58043 .39803 Mdot
.71301 .28149 Mdot
.68932 .69922 Mdot
.82905 .54278 Mdot
.58694 .34329 Mdot
.35504 .36832 Mdot
.59075 .35682 Mdot
.63752 .57935 Mdot
.57517 .62741 Mdot
.57539 .34795 Mdot
.55115 .75578 Mdot
.33899 .37468 Mdot
.24839 .69445 Mdot
.64377 .38906 Mdot
.41635 .36548 Mdot
.4184 .38234 Mdot
.46477 .35479 Mdot
.79139 .38883 Mdot
.59827 .37728 Mdot
.57679 .60952 Mdot
.36234 .47955 Mdot
.54312 .58877 Mdot
.43443 .3459 Mdot
.33466 .79041 Mdot
.60862 .36857 Mdot
.5916 .55964 Mdot
.56561 .67509 Mdot
.33471 .50545 Mdot
.3774 .63316 Mdot
.6411 .30354 Mdot
.82063 .55433 Mdot
.46876 .35954 Mdot
.61042 .34019 Mdot
.49865 .3236 Mdot
.26098 .69531 Mdot
.61577 .66763 Mdot
.65858 .61593 Mdot
.25662 .72763 Mdot
.76968 .65562 Mdot
.56242 .55554 Mdot
.3498 .45404 Mdot
.33476 .34177 Mdot
.59549 .62945 Mdot
.58256 .39745 Mdot
.37171 .60223 Mdot
.40066 .62396 Mdot
.51427 .58131 Mdot
.57467 .32471 Mdot
.51674 .48531 Mdot
.58955 .60823 Mdot
.55974 .53321 Mdot
.34074 .51489 Mdot
.36238 .30213 Mdot
.8462 .47149 Mdot
.36124 .62233 Mdot
.63094 .56495 Mdot
.34281 .76559 Mdot
.64926 .39088 Mdot
.3557 .44655 Mdot
.42539 .32966 Mdot
.56245 .39493 Mdot
.36228 .4545 Mdot
.63038 .62527 Mdot
.62744 .557 Mdot
.42267 .37937 Mdot
.62537 .41538 Mdot
.36118 .64776 Mdot
.35712 .46184 Mdot
.36095 .63085 Mdot
.60144 .36682 Mdot
.61829 .35741 Mdot
.54431 .65862 Mdot
.63078 .66125 Mdot
.32996 .47328 Mdot
.5434 .62573 Mdot
.35856 .4176 Mdot
.1637 .59505 Mdot
.48423 .31276 Mdot
.59738 .54475 Mdot
.6498 .3567 Mdot
.45897 .36646 Mdot
.56703 .61319 Mdot
.30202 .77914 Mdot
.588 .63557 Mdot
.49134 .3461 Mdot
.69699 .71694 Mdot
.36227 .6346 Mdot
.49284 .57155 Mdot
.20724 .45724 Mdot
.59739 .55022 Mdot
.35864 .49552 Mdot
.58755 .6679 Mdot
.42241 .34118 Mdot
.60992 .34962 Mdot
.15743 .59855 Mdot
.44291 .35343 Mdot
.60475 .55574 Mdot
.38292 .61624 Mdot
.65289 .36696 Mdot
.49451 .52801 Mdot
.46706 .55434 Mdot
.63421 .67506 Mdot
.55127 .55741 Mdot
.60183 .62101 Mdot
.4976 .77362 Mdot
.36622 .46891 Mdot
.63083 .39892 Mdot
.43744 .36857 Mdot
.44339 .3323 Mdot
.32404 .50101 Mdot
.40765 .45852 Mdot
.50456 .4339 Mdot
.61927 .16762 Mdot
.32338 .51945 Mdot
.36182 .61751 Mdot
.58775 .27595 Mdot
.36361 .47072 Mdot
.34704 .47622 Mdot
.32688 .51552 Mdot
.42785 .55034 Mdot
.62602 .35311 Mdot
.62939 .62692 Mdot
.59778 .4104 Mdot
.6167 .61501 Mdot
.48697 .35867 Mdot
.45477 .36236 Mdot
.60818 .36336 Mdot
.21978 .65622 Mdot
.72749 .57078 Mdot
.60234 .57779 Mdot
.18209 .52856 Mdot
.6249 .54301 Mdot
.45377 .65356 Mdot
.6071 .53637 Mdot
.32974 .48544 Mdot
.57564 .64296 Mdot
.5418 .63183 Mdot
.73268 .30338 Mdot
.45725 .34011 Mdot
.3808 .51178 Mdot
.59729 .52551 Mdot
.55302 .53772 Mdot
.57443 .40004 Mdot
.64082 .39762 Mdot
.38626 .60648 Mdot
.52155 .66528 Mdot
.45304 .33145 Mdot
.36664 .20404 Mdot
.62427 .57068 Mdot
.43382 .64187 Mdot
.80283 .51882 Mdot
.56502 .61066 Mdot
.20205 .48656 Mdot
.7471 .51166 Mdot
.58943 .59243 Mdot
.4401 .47109 Mdot
.46263 .34094 Mdot
.58534 .7671 Mdot
.59912 .63437 Mdot
.34088 .50893 Mdot
.59591 .35144 Mdot
.64579 .40101 Mdot
.37431 .60638 Mdot
.53635 .17697 Mdot
.43908 .38351 Mdot
.60853 .35399 Mdot
.60141 .59593 Mdot
.43256 .36503 Mdot
.31879 .51268 Mdot
.57061 .54278 Mdot
.73402 .673 Mdot
.62909 .36511 Mdot
.58765 .53338 Mdot
.55985 .24173 Mdot
.43283 .71192 Mdot
.69775 .73168 Mdot
.44141 .37188 Mdot
.35619 .64848 Mdot
.53474 .6303 Mdot
.60915 .45711 Mdot
.53576 .55772 Mdot
.49021 .73601 Mdot
.36292 .23065 Mdot
.36327 .66829 Mdot
.60826 .57211 Mdot
.57272 .60916 Mdot
.56408 .4464 Mdot
.36659 .6171 Mdot
.56871 .56006 Mdot
.56207 .4213 Mdot
.64056 .37924 Mdot
.31092 .49819 Mdot
.62959 .35956 Mdot
.59519 .57221 Mdot
.63183 .66291 Mdot
.64168 .40031 Mdot
.17447 .58488 Mdot
.37989 .59579 Mdot
.42804 .37048 Mdot
.64508 .57741 Mdot
.59846 .64334 Mdot
.82509 .34319 Mdot
.36364 .4474 Mdot
.34253 .40777 Mdot
.25989 .52328 Mdot
.35373 .75275 Mdot
.38864 .58379 Mdot
.66141 .77098 Mdot
.76543 .66263 Mdot
.58722 .54346 Mdot
.53495 .50386 Mdot
.51549 .21937 Mdot
.46412 .33621 Mdot
.47526 .1839 Mdot
.6253 .57096 Mdot
.61033 .59237 Mdot
.32845 .45296 Mdot
.28835 .42251 Mdot
.83271 .53634 Mdot
.59546 .32348 Mdot
.36214 .64334 Mdot
.58366 .38789 Mdot
.6339 .62229 Mdot
.45624 .48437 Mdot
.38031 .45781 Mdot
.42124 .63446 Mdot
.59649 .56037 Mdot
.69304 .31549 Mdot
.48904 .27867 Mdot
.42791 .35165 Mdot
.36208 .48662 Mdot
.80845 .57793 Mdot
.60014 .54712 Mdot
.41 .34851 Mdot
.58396 .57473 Mdot
.39481 .58128 Mdot
.56085 .52149 Mdot
.37395 .65508 Mdot
.61454 .6281 Mdot
.34856 .56999 Mdot
.8799 .46412 Mdot
.35745 .67989 Mdot
.56875 .3973 Mdot
.36471 .43968 Mdot
.32091 .49254 Mdot
.63694 .40176 Mdot
.32417 .48485 Mdot
.74028 .45793 Mdot
.72737 .65131 Mdot
.36746 .63794 Mdot
.5192 .5745 Mdot
.37538 .64146 Mdot
.34495 .4454 Mdot
.62666 .57791 Mdot
.19641 .66809 Mdot
.3355 .46522 Mdot
.78973 .63718 Mdot
.4448 .34581 Mdot
.37708 .45181 Mdot
.5943 .63423 Mdot
.48067 .29457 Mdot
.34641 .52693 Mdot
.33681 .39606 Mdot
.56325 .57164 Mdot
.62286 .35665 Mdot
.5896 .62572 Mdot
.64475 .59334 Mdot
.38774 .48429 Mdot
.62556 .60727 Mdot
.41703 .3565 Mdot
.58054 .34691 Mdot
.53097 .82725 Mdot
.38871 .2421 Mdot
.57044 .55766 Mdot
.60104 .59308 Mdot
.66007 .39528 Mdot
.58177 .64128 Mdot
.47123 .36233 Mdot
.13933 .36782 Mdot
.37011 .63722 Mdot
.3935 .47337 Mdot
.32413 .5616 Mdot
.64171 .63068 Mdot
.63139 .60439 Mdot
.3396 .81908 Mdot
.52601 .76097 Mdot
.42165 .36778 Mdot
.53052 .60461 Mdot
.32708 .52499 Mdot
.39236 .62593 Mdot
.47671 .333 Mdot
.58553 .59718 Mdot
.61299 .57816 Mdot
.35532 .64135 Mdot
.44086 .64922 Mdot
.81145 .43137 Mdot
.41057 .36962 Mdot
.65953 .56919 Mdot
.30292 .53127 Mdot
.53879 .59017 Mdot
.77277 .37208 Mdot
.62086 .40421 Mdot
.47056 .35618 Mdot
.37291 .75885 Mdot
.5958 .54572 Mdot
.4221 .37406 Mdot
.4544 .33234 Mdot
.53923 .55855 Mdot
.61882 .33672 Mdot
.57569 .35095 Mdot
.64284 .37897 Mdot
.39432 .15436 Mdot
.47936 .71372 Mdot
.36922 .49875 Mdot
.4625 .33839 Mdot
.32186 .46535 Mdot
.3606 .68682 Mdot
.46553 .52772 Mdot
.32634 .46045 Mdot
.63839 .36478 Mdot
.38665 .46103 Mdot
.5624 .59296 Mdot
.45141 .33204 Mdot
.36383 .49736 Mdot
.64464 .60384 Mdot
.59089 .31041 Mdot
.25749 .37912 Mdot
.37855 .66744 Mdot
.36286 .60585 Mdot
.58108 .6291 Mdot
.30592 .50659 Mdot
.61795 .57481 Mdot
.42651 .32624 Mdot
.60112 .2984 Mdot
.64367 .59068 Mdot
.32934 .48043 Mdot
.66002 .39033 Mdot
.81134 .56988 Mdot
.57813 .65212 Mdot
.59792 .56928 Mdot
.62088 .61144 Mdot
.58316 .57471 Mdot
.26049 .68513 Mdot
.4295 .38732 Mdot
.33781 .26146 Mdot
.3697 .74336 Mdot
.60902 .37408 Mdot
.60727 .4171 Mdot
.83976 .47631 Mdot
.50976 .2267 Mdot
.46062 .3417 Mdot
.60055 .61328 Mdot
.48466 .25857 Mdot
.41768 .84169 Mdot
.23701 .69764 Mdot
.67113 .54517 Mdot
.3628 .44578 Mdot
.61039 .34048 Mdot
.32272 .47634 Mdot
.61683 .60858 Mdot
.55599 .53813 Mdot
.71064 .74826 Mdot
.45999 .32254 Mdot
.36519 .64493 Mdot
.6177 .61665 Mdot
.47508 .71619 Mdot
.35527 .48565 Mdot
.37776 .45186 Mdot
.55674 .61063 Mdot
.65259 .39928 Mdot
.87121 .46037 Mdot
.43089 .35843 Mdot
.32219 .28695 Mdot
.43319 .2086 Mdot
.51286 .31054 Mdot
.43249 .34927 Mdot
.58516 .46739 Mdot
.35166 .44721 Mdot
.80033 .48599 Mdot
.60556 .37976 Mdot
.40027 .63818 Mdot
.6305 .53798 Mdot
.62151 .40914 Mdot
.37817 .49097 Mdot
.61631 .35189 Mdot
.63274 .60337 Mdot
.41356 .3959 Mdot
.34871 .49392 Mdot
.40478 .28917 Mdot
.65125 .35837 Mdot
.37074 .61556 Mdot
.49221 .40118 Mdot
.70049 .59602 Mdot
.74632 .50668 Mdot
.55264 .60734 Mdot
.45258 .49376 Mdot
.57652 .60673 Mdot
.63566 .42084 Mdot
.59153 .58373 Mdot
.66986 .36679 Mdot
.35746 .49576 Mdot
.61329 .63579 Mdot
.59274 .61136 Mdot
.27732 .27325 Mdot
.57155 .56209 Mdot
.53519 .59132 Mdot
.59084 .59659 Mdot
.67358 .39578 Mdot
.51484 .59116 Mdot
.58227 .369 Mdot
.24202 .52663 Mdot
.34375 .47797 Mdot
.40155 .62071 Mdot
.35488 .65371 Mdot
.51512 .72563 Mdot
.32928 .59941 Mdot
.26527 .434 Mdot
.6362 .37433 Mdot
.41637 .34609 Mdot
.5873 .58021 Mdot
.61757 .79674 Mdot
.28811 .51029 Mdot
.38233 .46778 Mdot
.39038 .24278 Mdot
.61538 .51625 Mdot
.60919 .7663 Mdot
.529 .59389 Mdot
.45774 .15644 Mdot
.62651 .65278 Mdot
.61789 .52376 Mdot
.31623 .51461 Mdot
.41252 .67187 Mdot
.58132 .63885 Mdot
.57447 .38374 Mdot
.38931 .65016 Mdot
.66456 .56082 Mdot
.38497 .53068 Mdot
.27205 .45923 Mdot
.66891 .33904 Mdot
.56487 .58117 Mdot
.34757 .49385 Mdot
.59004 .36775 Mdot
.84472 .49025 Mdot
.42597 .35861 Mdot
.4102 .48042 Mdot
.59615 .247 Mdot
.18004 .57877 Mdot
.38574 .61331 Mdot
.7749 .42784 Mdot
.55637 .59351 Mdot
.24562 .62067 Mdot
.64445 .58053 Mdot
.35231 .80949 Mdot
.34989 .64543 Mdot
.63491 .35866 Mdot
.41451 .36133 Mdot
.584 .39825 Mdot
.73633 .49743 Mdot
.36517 .54294 Mdot
.4887 .46328 Mdot
.35532 .47324 Mdot
.50677 .49937 Mdot
.62486 .39415 Mdot
.63406 .57675 Mdot
.61189 .16287 Mdot
.62767 .40387 Mdot
.64985 .36164 Mdot
.20773 .37743 Mdot
.17854 .62955 Mdot
.65352 .63038 Mdot
.64234 .35926 Mdot
.35065 .4702 Mdot
.38482 .64831 Mdot
.60547 .63141 Mdot
.56073 .58259 Mdot
.61677 .4077 Mdot
.38842 .49255 Mdot
.68145 .50124 Mdot
.32797 .49995 Mdot
.6295 .35616 Mdot
.33662 .49021 Mdot
.49884 .3542 Mdot
.36002 .46122 Mdot
.59851 .64366 Mdot
.59034 .58283 Mdot
.29128 .56364 Mdot
.6192 .3576 Mdot
.58803 .60712 Mdot
.56405 .54203 Mdot
.62169 .37751 Mdot
.56225 .4726 Mdot
.69009 .50208 Mdot
.55308 .56368 Mdot
.56434 .56707 Mdot
.35835 .66018 Mdot
.46516 .51158 Mdot
.7725 .40385 Mdot
.62904 .6128 Mdot
.35987 .66999 Mdot
.57572 .37242 Mdot
.61155 .56345 Mdot
.40717 .81704 Mdot
.33388 .34643 Mdot
.627 .56698 Mdot
.31962 .4795 Mdot
.53657 .62093 Mdot
.70997 .72027 Mdot
.56852 .62748 Mdot
.62788 .38241 Mdot
.60212 .35714 Mdot
.34509 .22051 Mdot
.61506 .39112 Mdot
.36139 .51811 Mdot
.43579 .34601 Mdot
.25616 .69314 Mdot
.31667 .49842 Mdot
.60924 .66068 Mdot
.22607 .30589 Mdot
.59225 .53752 Mdot
.6314 .63542 Mdot
.82369 .59284 Mdot
.32745 .47066 Mdot
.59085 .38384 Mdot
.50368 .40098 Mdot
.64125 .653 Mdot
.46841 .35664 Mdot
.58426 .52182 Mdot
.56071 .6211 Mdot
.73384 .69704 Mdot
.26646 .68691 Mdot
.40781 .35068 Mdot
.53586 .59195 Mdot
.6301 .60976 Mdot
.30724 .46412 Mdot
.59707 .59339 Mdot
.38063 .65095 Mdot
.59787 .37518 Mdot
.352 .4561 Mdot
.38249 .62508 Mdot
.60822 .55072 Mdot
.3599 .64781 Mdot
.35577 .50524 Mdot
.43711 .3224 Mdot
.62138 .5971 Mdot
.39979 .65627 Mdot
.36087 .64446 Mdot
.57804 .6053 Mdot
.60477 .34806 Mdot
.60796 .50933 Mdot
.57537 .56053 Mdot
.62528 .62521 Mdot
.60388 .39896 Mdot
.53471 .87836 Mdot
.57325 .62685 Mdot
.49802 .74206 Mdot
.62798 .41082 Mdot
.52692 .48801 Mdot
.31382 .49989 Mdot
.56847 .63144 Mdot
.43674 .32229 Mdot
.42972 .3275 Mdot
.37701 .46837 Mdot
.6173 .34064 Mdot
.26518 .52257 Mdot
.57612 .34231 Mdot
.56626 .65743 Mdot
.53822 .60295 Mdot
.61084 .47174 Mdot
.59387 .80655 Mdot
.59403 .40434 Mdot
.38282 .54271 Mdot
.59706 .31727 Mdot
.41362 .34609 Mdot
.3853 .48951 Mdot
.5786 .34604 Mdot
.59698 .39713 Mdot
.59393 .34686 Mdot
.40083 .6394 Mdot
.29475 .56763 Mdot
.63098 .41304 Mdot
.64651 .40819 Mdot
.55855 .57704 Mdot
.62641 .61728 Mdot
.78215 .6232 Mdot
.772 .61839 Mdot
.36621 .66367 Mdot
.36785 .50594 Mdot
.36554 .15427 Mdot
.44768 .3202 Mdot
.29749 .27344 Mdot
.63031 .63327 Mdot
.41639 .12093 Mdot
.59836 .63297 Mdot
.60059 .59826 Mdot
.57662 .34876 Mdot
.3952 .65972 Mdot
.37346 .63908 Mdot
.62951 .40037 Mdot
.63469 .41777 Mdot
.37883 .65101 Mdot
.19683 .46134 Mdot
.43128 .83369 Mdot
.33728 .42027 Mdot
.6189 .37096 Mdot
.71236 .64038 Mdot
.41498 .3753 Mdot
.67177 .62647 Mdot
.40433 .37988 Mdot
.35248 .48017 Mdot
.35495 .45058 Mdot
.46432 .36265 Mdot
.56669 .57018 Mdot
.37015 .49284 Mdot
.59702 .54254 Mdot
.26107 .34949 Mdot
.73891 .53975 Mdot
.2838 .52836 Mdot
.66719 .65901 Mdot
.5659 .46918 Mdot
.40025 .29122 Mdot
.6128 .55701 Mdot
.37668 .7869 Mdot
.36428 .64204 Mdot
.58107 .66666 Mdot
.47265 .35131 Mdot
.81541 .61682 Mdot
.62533 .588 Mdot
.62863 .37823 Mdot
.45725 .3331 Mdot
.6129 .2434 Mdot
.58934 .26485 Mdot
.61904 .61358 Mdot
.55335 .15332 Mdot
.64038 .42893 Mdot
.36523 .47707 Mdot
.68341 .29943 Mdot
.61206 .41581 Mdot
.37742 .58352 Mdot
.40309 .77418 Mdot
.20277 .6298 Mdot
.59032 .37724 Mdot
.33596 .4457 Mdot
.58038 .36207 Mdot
.37888 .61389 Mdot
.57032 .39839 Mdot
.35542 .49158 Mdot
.5999 .5625 Mdot
.32467 .49304 Mdot
.39931 .64517 Mdot
.81052 .44276 Mdot
.40787 .35079 Mdot
.36583 .5228 Mdot
.44839 .36477 Mdot
.40585 .71863 Mdot
.47438 .77156 Mdot
.43278 .37242 Mdot
.67774 .45327 Mdot
.54096 .60806 Mdot
.62082 .41642 Mdot
.32218 .50666 Mdot
.31722 .68707 Mdot
.50864 .38775 Mdot
.6064 .38379 Mdot
.37507 .49533 Mdot
.61357 .2781 Mdot
.65252 .4376 Mdot
.53487 .59713 Mdot
.45878 .62614 Mdot
.61797 .37448 Mdot
.33257 .4489 Mdot
.82565 .40879 Mdot
.57956 .36561 Mdot
.32724 .52323 Mdot
.41728 .36981 Mdot
.43908 .33381 Mdot
.54494 .58214 Mdot
.43831 .395 Mdot
.37406 .47364 Mdot
.40445 .32082 Mdot
.63949 .35559 Mdot
.63883 .25831 Mdot
.4093 .6399 Mdot
.33624 .48247 Mdot
.60786 .53992 Mdot
.63852 .42324 Mdot
.34886 .3021 Mdot
.69604 .52031 Mdot
.66621 .21868 Mdot
.32417 .5006 Mdot
.59749 .38126 Mdot
.62881 .37428 Mdot
.58033 .65426 Mdot
.63369 .28956 Mdot
.26259 .53244 Mdot
.59855 .47132 Mdot
.5434 .42087 Mdot
.31032 .50249 Mdot
.39813 .45451 Mdot
.59291 .52451 Mdot
.56992 .57768 Mdot
.41191 .35114 Mdot
.59671 .56347 Mdot
.61793 .34426 Mdot
.55314 .60678 Mdot
.43703 .36695 Mdot
.35713 .46995 Mdot
.62245 .59161 Mdot
.35967 .64181 Mdot
.43521 .3868 Mdot
.45828 .31776 Mdot
.33446 .47868 Mdot
.61628 .40811 Mdot
.51572 .50228 Mdot
.33033 .50711 Mdot
.56492 .58007 Mdot
.44961 .53158 Mdot
.63457 .60036 Mdot
.51357 .53214 Mdot
.5787 .37333 Mdot
.35022 .45615 Mdot
.56431 .35777 Mdot
.44641 .35793 Mdot
.37255 .7469 Mdot
.59546 .57641 Mdot
.32242 .51831 Mdot
.37308 .31664 Mdot
.5 .54081 Mdot
.65837 .36762 Mdot
.2303 .43616 Mdot
.61115 .42007 Mdot
.36302 .5102 Mdot
.24513 .31034 Mdot
.39793 .62585 Mdot
.38143 .4635 Mdot
.55217 .81859 Mdot
.33539 .46823 Mdot
.54659 .59034 Mdot
.57733 .62611 Mdot
.35817 .46003 Mdot
.35561 .64973 Mdot
.84151 .53033 Mdot
.37993 .43445 Mdot
.5916 .38025 Mdot
.2245 .38607 Mdot
.73795 .27845 Mdot
.42665 .28962 Mdot
.41395 .348 Mdot
.65522 .63284 Mdot
.55328 .62219 Mdot
.47394 .34339 Mdot
.40543 .35183 Mdot
.39001 .61002 Mdot
.33206 .52045 Mdot
.64993 .41813 Mdot
.47041 .31608 Mdot
.65776 .31504 Mdot
.32379 .58814 Mdot
.5749 .64995 Mdot
.42305 .21311 Mdot
.63036 .63126 Mdot
.4391 .76151 Mdot
.43892 .36933 Mdot
.63823 .57185 Mdot
.53431 .60658 Mdot
.4633 .33053 Mdot
.38586 .64889 Mdot
.40897 .48382 Mdot
.33964 .49166 Mdot
.54016 .86793 Mdot
.57757 .54365 Mdot
.55241 .60138 Mdot
.46422 .34932 Mdot
.25626 .60048 Mdot
.60634 .37199 Mdot
.59181 .41112 Mdot
.36594 .46877 Mdot
.46079 .41771 Mdot
.54368 .60147 Mdot
.60775 .55824 Mdot
.3426 .49766 Mdot
.37182 .51384 Mdot
.27057 .41681 Mdot
.56995 .60918 Mdot
.45519 .34395 Mdot
.39296 .69161 Mdot
.44397 .37189 Mdot
.63646 .58999 Mdot
.55535 .60258 Mdot
.59945 .6441 Mdot
.62221 .55058 Mdot
.40619 .39152 Mdot
.6388 .59785 Mdot
.52774 .56381 Mdot
.6002 .38224 Mdot
.62032 .61882 Mdot
.53317 .40623 Mdot
.58917 .56579 Mdot
.38236 .64939 Mdot
.75335 .38127 Mdot
.62488 .58904 Mdot
.55571 .6126 Mdot
.39103 .46456 Mdot
.60762 .57822 Mdot
.43079 .32332 Mdot
.61645 .362 Mdot
.46263 .34316 Mdot
.42755 .32859 Mdot
.31472 .46762 Mdot
.35561 .62396 Mdot
.645 .62726 Mdot
.38298 .66012 Mdot
.6105 .66377 Mdot
.59451 .54561 Mdot
.33101 .61952 Mdot
.43464 .15677 Mdot
.79661 .3998 Mdot
.59366 .57513 Mdot
.33103 .46755 Mdot
.3227 .47526 Mdot
.55224 .49223 Mdot
.53706 .57531 Mdot
.48149 .34365 Mdot
.41528 .34196 Mdot
.69728 .69365 Mdot
.59814 .73687 Mdot
.38301 .64952 Mdot
.47112 .49513 Mdot
.56128 .55457 Mdot
.63643 .56986 Mdot
.57722 .54101 Mdot
.3279 .4582 Mdot
.68995 .60294 Mdot
.38498 .48125 Mdot
.44919 .26193 Mdot
.46009 .36263 Mdot
.62234 .60237 Mdot
.40109 .22583 Mdot
.64588 .38602 Mdot
.61717 .3616 Mdot
.46763 .32063 Mdot
.30519 .52691 Mdot
.81113 .56221 Mdot
.23949 .70907 Mdot
.58031 .42136 Mdot
.39974 .6515 Mdot
.60235 .55279 Mdot
.3501 .46448 Mdot
.62595 .35208 Mdot
.3986 .65226 Mdot
.63213 .58284 Mdot
.29646 .56862 Mdot
.58576 .57189 Mdot
.48729 .22009 Mdot
.5909 .35415 Mdot
.38623 .82979 Mdot
.62083 .34101 Mdot
.44567 .38734 Mdot
.47265 .35727 Mdot
.56668 .61153 Mdot
.60009 .44529 Mdot
.61134 .41726 Mdot
.40184 .55193 Mdot
.3633 .61632 Mdot
.44973 .28035 Mdot
.39441 .62578 Mdot
.36376 .48672 Mdot
.39687 .64049 Mdot
.35548 .49403 Mdot
.81335 .54699 Mdot
.68295 .36807 Mdot
.37622 .6289 Mdot
.3789 .30689 Mdot
.55755 .62608 Mdot
.36732 .66585 Mdot
.55553 .53924 Mdot
.53701 .51252 Mdot
.33992 .49927 Mdot
.36848 .61433 Mdot
.63227 .56727 Mdot
.6544 .76476 Mdot
.42553 .36978 Mdot
.4801 .34804 Mdot
.5559 .53953 Mdot
.30984 .49159 Mdot
.57234 .36599 Mdot
.3205 .76088 Mdot
.48441 .32084 Mdot
.57024 .62147 Mdot
.58144 .63991 Mdot
.61479 .41971 Mdot
.34637 .2367 Mdot
.56085 .60361 Mdot
.50469 .59512 Mdot
.57035 .61224 Mdot
.44511 .37948 Mdot
.58322 .39468 Mdot
.62464 .36792 Mdot
.37424 .49497 Mdot
.64955 .38206 Mdot
.46403 .59689 Mdot
.42939 .23889 Mdot
.56734 .51613 Mdot
.44217 .35688 Mdot
.47883 .26958 Mdot
.4341 .25643 Mdot
.55644 .80539 Mdot
.64996 .3551 Mdot
.64261 .59418 Mdot
.65133 .38424 Mdot
.39384 .63136 Mdot
.62562 .35978 Mdot
.60994 .34047 Mdot
.61968 .57197 Mdot
.61493 .61375 Mdot
.36127 .47262 Mdot
.62459 .28979 Mdot
.6198 .41079 Mdot
.59808 .63221 Mdot
.58422 .6463 Mdot
.60109 .54111 Mdot
.41404 .55917 Mdot
.58877 .40007 Mdot
.17563 .44796 Mdot
.52285 .68707 Mdot
.61839 .41033 Mdot
.86833 .49114 Mdot
.36583 .31201 Mdot
.36478 .53992 Mdot
.40802 .52156 Mdot
.57326 .61508 Mdot
.3503 .52717 Mdot
.61717 .60774 Mdot
.42482 .21411 Mdot
.6119 .58369 Mdot
.38071 .65208 Mdot
.58717 .54336 Mdot
.36523 .45344 Mdot
.32695 .50114 Mdot
.56594 .61912 Mdot
.62012 .59439 Mdot
.82234 .46192 Mdot
.56537 .38793 Mdot
.61193 .35623 Mdot
.26787 .50746 Mdot
.37354 .62435 Mdot
.46942 .35701 Mdot
.59074 .59098 Mdot
.31749 .46511 Mdot
.32596 .49927 Mdot
.60092 .41066 Mdot
.34974 .51103 Mdot
.43058 .35664 Mdot
.59596 .58011 Mdot
.47609 .34533 Mdot
.40145 .62977 Mdot
.58481 .3953 Mdot
.61977 .61692 Mdot
.55859 .57659 Mdot
.60193 .35739 Mdot
.64695 .5828 Mdot
.35655 .64707 Mdot
.33132 .47313 Mdot
.58924 .37625 Mdot
.43682 .34169 Mdot
.36206 .48899 Mdot
.62943 .62306 Mdot
.51886 .15517 Mdot
.54847 .57992 Mdot
.58244 .62187 Mdot
.58748 .81983 Mdot
.56654 .55136 Mdot
.32322 .50443 Mdot
.62952 .35393 Mdot
.57817 .67204 Mdot
.5046 .70685 Mdot
.49179 .89577 Mdot
.38387 .47629 Mdot
.59503 .55365 Mdot
.59106 .79119 Mdot
.59408 .55631 Mdot
.70271 .56034 Mdot
.37032 .52363 Mdot
.53577 .44962 Mdot
.62277 .54659 Mdot
.42548 .34168 Mdot
.35778 .46386 Mdot
.35445 .49845 Mdot
.24592 .35471 Mdot
.61686 .56535 Mdot
.43689 .50684 Mdot
.63269 .59082 Mdot
.43423 .34114 Mdot
.62411 .71768 Mdot
.32609 .50352 Mdot
.70954 .26975 Mdot
.57481 .60631 Mdot
.59669 .40014 Mdot
.38381 .45553 Mdot
.50485 .34798 Mdot
.6221 .62793 Mdot
.36845 .65874 Mdot
.41959 .32443 Mdot
.56344 .52243 Mdot
.43912 .35628 Mdot
.62644 .62302 Mdot
.62275 .68381 Mdot
.61348 .22154 Mdot
.60039 .34683 Mdot
.41369 .36092 Mdot
.44328 .54743 Mdot
.64131 .59111 Mdot
.59063 .3758 Mdot
.60507 .38139 Mdot
.40226 .63517 Mdot
.50942 .47887 Mdot
.5653 .23971 Mdot
.73625 .58844 Mdot
.23312 .37087 Mdot
.38816 .46857 Mdot
.3228 .40863 Mdot
.58956 .61989 Mdot
.45409 .60729 Mdot
.42596 .32727 Mdot
.54924 .57638 Mdot
.77028 .4327 Mdot
.64045 .39476 Mdot
.55192 .57817 Mdot
.37524 .64309 Mdot
.42693 .61154 Mdot
.40661 .68515 Mdot
.45715 .79734 Mdot
.35486 .47488 Mdot
.52328 .573 Mdot
.57201 .6743 Mdot
.3127 .50123 Mdot
.6046 .64957 Mdot
.31903 .50681 Mdot
.18872 .50606 Mdot
.37629 .6671 Mdot
.58864 .39531 Mdot
.42277 .27948 Mdot
.62927 .6411 Mdot
.55028 .61434 Mdot
.3596 .61552 Mdot
.57035 .58175 Mdot
.56043 .18787 Mdot
.4127 .56381 Mdot
.36643 .49293 Mdot
.59575 .3467 Mdot
.59452 .64723 Mdot
.46769 .52866 Mdot
.58602 .55922 Mdot
.77315 .56955 Mdot
.55749 .61497 Mdot
.59625 .26129 Mdot
.59617 .35067 Mdot
.44145 .36233 Mdot
.64049 .56967 Mdot
.608 .59036 Mdot
.55209 .74207 Mdot
.62239 .65724 Mdot
.64065 .57739 Mdot
.62613 .3333 Mdot
.60333 .34354 Mdot
.58204 .36323 Mdot
.37975 .47283 Mdot
.65652 .73219 Mdot
.45131 .34937 Mdot
.61331 .67611 Mdot
.48459 .32921 Mdot
.66137 .50219 Mdot
.39255 .65879 Mdot
.51598 .78933 Mdot
.59215 .60478 Mdot
.63829 .374 Mdot
.31732 .73539 Mdot
.57744 .40183 Mdot
.4652 .48451 Mdot
.45279 .3315 Mdot
.62724 .40255 Mdot
.60403 .59659 Mdot
.56137 .33488 Mdot
.61527 .78969 Mdot
.45457 .35511 Mdot
.60599 .66002 Mdot
.37348 .45418 Mdot
.31433 .55476 Mdot
.64915 .23092 Mdot
.42752 .37248 Mdot
.48924 .31722 Mdot
.61552 .56221 Mdot
.64684 .37778 Mdot
.42765 .34279 Mdot
.44565 .37824 Mdot
.35467 .50958 Mdot
.61345 .61642 Mdot
.61005 .619 Mdot
.36884 .50722 Mdot
.46307 .34529 Mdot
.53235 .56105 Mdot
.55347 .52356 Mdot
.76102 .70618 Mdot
.6189 .26609 Mdot
.54993 .87243 Mdot
.53263 .50153 Mdot
.74492 .41164 Mdot
.32186 .7668 Mdot
.60966 .40818 Mdot
.61805 .55585 Mdot
.63151 .5356 Mdot
.37427 .47328 Mdot
.60266 .57122 Mdot
.34595 .53807 Mdot
.44711 .32489 Mdot
.81187 .61899 Mdot
.52796 .28661 Mdot
.18985 .56746 Mdot
.60495 .57115 Mdot
.66242 .35965 Mdot
.39027 .63252 Mdot
.46186 .29357 Mdot
.5798 .38673 Mdot
.59459 .53591 Mdot
.82007 .45785 Mdot
.38275 .4678 Mdot
.60869 .39578 Mdot
.84313 .49654 Mdot
.5741 .46309 Mdot
.63432 .5993 Mdot
.38166 .48904 Mdot
.35912 .78419 Mdot
.6864 .33163 Mdot
.48622 .34785 Mdot
.38656 .64922 Mdot
.3519 .45822 Mdot
.41152 .34765 Mdot
.67164 .3877 Mdot
.61734 .39767 Mdot
.57348 .37997 Mdot
.78611 .3986 Mdot
.39083 .49744 Mdot
.38818 .63059 Mdot
.59407 .75817 Mdot
.57795 .73926 Mdot
.37643 .65164 Mdot
.3551 .45025 Mdot
.61185 .34462 Mdot
.63475 .39631 Mdot
.61641 .36261 Mdot
.76076 .34174 Mdot
.65399 .37671 Mdot
.2561 .31804 Mdot
.60998 .54374 Mdot
.52811 .5387 Mdot
.59854 .55443 Mdot
.48037 .33927 Mdot
.59663 .35992 Mdot
.49169 .40644 Mdot
.58875 .66319 Mdot
.51549 .77612 Mdot
.54521 .5867 Mdot
.42005 .38884 Mdot
.55342 .58496 Mdot
.42359 .19526 Mdot
.64818 .39423 Mdot
.59731 .57385 Mdot
.40861 .38236 Mdot
.37145 .62215 Mdot
.65778 .36469 Mdot
.62063 .6119 Mdot
.22641 .46808 Mdot
.57517 .54766 Mdot
.19479 .55154 Mdot
.57748 .22074 Mdot
.39814 .65337 Mdot
.47863 .19943 Mdot
.33831 .44273 Mdot
.51149 .56852 Mdot
.64339 .65745 Mdot
.45049 .36057 Mdot
.44953 .28244 Mdot
.34532 .47583 Mdot
.67961 .56282 Mdot
.53368 .54692 Mdot
.40327 .63308 Mdot
.68263 .38332 Mdot
.47166 .33723 Mdot
.59684 .64933 Mdot
.53858 .6169 Mdot
.31873 .2811 Mdot
.54553 .54071 Mdot
.57183 .63349 Mdot
.35348 .61941 Mdot
.2801 .29222 Mdot
.58259 .56627 Mdot
.46954 .48824 Mdot
.56957 .39592 Mdot
.57819 .66304 Mdot
.26214 .30661 Mdot
.5803 .62841 Mdot
.61478 .40229 Mdot
.5041 .57161 Mdot
.54373 .2295 Mdot
.3542 .62707 Mdot
.55668 .61444 Mdot
.33297 .22939 Mdot
.56973 .59634 Mdot
.45119 .34426 Mdot
.53672 .5788 Mdot
.35489 .48887 Mdot
.79911 .39256 Mdot
.37392 .48868 Mdot
.5429 .57832 Mdot
.6164 .36582 Mdot
.46243 .35572 Mdot
.73008 .32285 Mdot
.27394 .56686 Mdot
.31397 .26723 Mdot
.24506 .70235 Mdot
.36022 .6215 Mdot
.40189 .66397 Mdot
.45987 .32427 Mdot
.59549 .57265 Mdot
.21233 .35384 Mdot
.63616 .64792 Mdot
.56117 .56893 Mdot
.6125 .58484 Mdot
.4668 .76949 Mdot
.43442 .32576 Mdot
.33464 .50165 Mdot
.55809 .60274 Mdot
.64017 .58965 Mdot
.60432 .40457 Mdot
.36677 .63072 Mdot
.3141 .49771 Mdot
.36798 .639 Mdot
.35413 .46263 Mdot
.84142 .55892 Mdot
.52836 .57912 Mdot
.3737 .61876 Mdot
.44543 .31333 Mdot
.60956 .40352 Mdot
.44109 .24208 Mdot
.35947 .49491 Mdot
.3785 .47805 Mdot
.56371 .61961 Mdot
.62 .40559 Mdot
.57054 .35193 Mdot
.39051 .62122 Mdot
.4305 .36739 Mdot
.62498 .58778 Mdot
.58205 .5484 Mdot
.59024 .68967 Mdot
.3092 .48416 Mdot
.47672 .21768 Mdot
.28212 .43404 Mdot
.59269 .57339 Mdot
.63858 .35535 Mdot
.61881 .58931 Mdot
.23186 .63179 Mdot
.64787 .38207 Mdot
.58632 .63116 Mdot
.86205 .44379 Mdot
.34415 .54824 Mdot
.51519 .24575 Mdot
.58592 .63972 Mdot
.31824 .78539 Mdot
.5902 .61346 Mdot
.82006 .61656 Mdot
.29876 .68976 Mdot
.53875 .59502 Mdot
.62083 .63074 Mdot
.72084 .52216 Mdot
.59142 .55025 Mdot
.37356 .50255 Mdot
.77773 .64361 Mdot
.57324 .39296 Mdot
.42454 .26246 Mdot
.75698 .39326 Mdot
.35141 .63787 Mdot
.36577 .4686 Mdot
.39912 .48398 Mdot
.36982 .64869 Mdot
.62104 .37283 Mdot
.58302 .57484 Mdot
.45379 .44186 Mdot
.31222 .48324 Mdot
.63592 .51825 Mdot
.45134 .34169 Mdot
.31614 .35016 Mdot
.43776 .60591 Mdot
.43588 .35554 Mdot
.61881 .62123 Mdot
.70814 .51522 Mdot
.80643 .53721 Mdot
.47588 .84245 Mdot
.40855 .35768 Mdot
.45583 .35633 Mdot
.78253 .36335 Mdot
.40459 .61723 Mdot
.31807 .28604 Mdot
.5944 .26421 Mdot
.46657 .35639 Mdot
.65956 .4225 Mdot
.36959 .51161 Mdot
.43515 .40618 Mdot
.53972 .63932 Mdot
.60565 .54564 Mdot
.60491 .59445 Mdot
.43732 .37273 Mdot
.50747 .52899 Mdot
.66735 .26987 Mdot
.44971 .36619 Mdot
.66721 .59746 Mdot
.51266 .44804 Mdot
.37346 .38432 Mdot
.3398 .51449 Mdot
.36777 .61166 Mdot
.41257 .63101 Mdot
.59351 .3926 Mdot
.36168 .61628 Mdot
.43682 .62613 Mdot
.57714 .58365 Mdot
.45211 .37018 Mdot
.37932 .28187 Mdot
.44118 .33595 Mdot
.37001 .6442 Mdot
.39483 .61113 Mdot
.60067 .38146 Mdot
.61601 .35507 Mdot
.72512 .44439 Mdot
.46768 .6475 Mdot
.56815 .56106 Mdot
.32538 .68356 Mdot
.59838 .34055 Mdot
.59601 .48918 Mdot
.36562 .61233 Mdot
.37128 .62448 Mdot
.53987 .74668 Mdot
.59533 .60442 Mdot
.62555 .48624 Mdot
.59372 .59895 Mdot
.55678 .69579 Mdot
.62007 .63707 Mdot
.35368 .51006 Mdot
.59916 .61309 Mdot
.54155 .75349 Mdot
.65033 .606 Mdot
.55471 .62861 Mdot
.32318 .46074 Mdot
.53971 .53511 Mdot
.35328 .48863 Mdot
.55032 .5685 Mdot
.39415 .66481 Mdot
.36783 .46794 Mdot
.49146 .71388 Mdot
.51569 .74726 Mdot
.35093 .44871 Mdot
.39171 .6548 Mdot
.35365 .65752 Mdot
.45889 .72888 Mdot
.57972 .3877 Mdot
.66127 .63254 Mdot
.59769 .57115 Mdot
.38394 .49969 Mdot
.42032 .3374 Mdot
.62729 .6291 Mdot
.56699 .63302 Mdot
.59763 .6393 Mdot
.59355 .39444 Mdot
.26415 .53776 Mdot
.37527 .61595 Mdot
.37004 .5079 Mdot
.50756 .50785 Mdot
.30942 .5015 Mdot
.54604 .63049 Mdot
.63808 .54345 Mdot
.76376 .4126 Mdot
.37151 .35758 Mdot
.75842 .32918 Mdot
.61562 .3967 Mdot
.32119 .47607 Mdot
.40892 .64452 Mdot
.65017 .56422 Mdot
.63957 .37369 Mdot
.35499 .49135 Mdot
.58643 .57248 Mdot
.60781 .65702 Mdot
.41428 .24713 Mdot
.41531 .68447 Mdot
.50599 .73573 Mdot
.37603 .46526 Mdot
.36151 .44466 Mdot
.50278 .75799 Mdot
.39455 .68277 Mdot
.50233 .39397 Mdot
.60876 .56335 Mdot
.36767 .65746 Mdot
.62999 .35574 Mdot
.7899 .42376 Mdot
.46124 .37171 Mdot
.63255 .29084 Mdot
.60443 .57272 Mdot
.5538 .46367 Mdot
.61469 .36648 Mdot
.37637 .6455 Mdot
.44022 .37424 Mdot
.4179 .62056 Mdot
.32334 .46634 Mdot
.19214 .62389 Mdot
.56749 .58949 Mdot
.56048 .61628 Mdot
.41796 .38283 Mdot
.64297 .38512 Mdot
.34873 .65743 Mdot
.22364 .39622 Mdot
.3538 .50405 Mdot
.21991 .33837 Mdot
.64053 .35872 Mdot
.71179 .63509 Mdot
.34956 .51797 Mdot
.4751 .32037 Mdot
.46806 .719 Mdot
.43353 .36068 Mdot
.54212 .58802 Mdot
.63401 .3756 Mdot
.41386 .35519 Mdot
.64056 .28032 Mdot
.62714 .7994 Mdot
.71484 .63181 Mdot
.58261 .58416 Mdot
.70209 .74308 Mdot
.20312 .5071 Mdot
.57705 .42025 Mdot
.41782 .33616 Mdot
.54757 .57823 Mdot
.5533 .61383 Mdot
.56778 .59515 Mdot
.42405 .33644 Mdot
.32685 .68049 Mdot
.34195 .50114 Mdot
.60913 .55673 Mdot
.39235 .61159 Mdot
.35063 .48276 Mdot
.49542 .33963 Mdot
.33458 .51219 Mdot
.62695 .33847 Mdot
.56122 .64418 Mdot
.50711 .32625 Mdot
.8781 .40554 Mdot
.45966 .3499 Mdot
.31886 .46144 Mdot
.53768 .56253 Mdot
.34308 .33801 Mdot
.57934 .35458 Mdot
.3564 .50449 Mdot
.5509 .60003 Mdot
.38464 .29889 Mdot
.80705 .42797 Mdot
.32966 .50934 Mdot
.63995 .37216 Mdot
.48318 .83987 Mdot
.60019 .56609 Mdot
.58343 .60513 Mdot
.62472 .39968 Mdot
.65203 .45176 Mdot
.83055 .43214 Mdot
.61944 .59288 Mdot
.44155 .36409 Mdot
.15695 .55073 Mdot
.56543 .632 Mdot
.5795 .71069 Mdot
.36033 .46796 Mdot
.48209 .39381 Mdot
.52209 .21906 Mdot
.65316 .58928 Mdot
.27437 .33681 Mdot
.41969 .28553 Mdot
.64 .75472 Mdot
.34055 .53934 Mdot
.23524 .53963 Mdot
.69293 .73187 Mdot
.41034 .39054 Mdot
.64725 .33591 Mdot
.25106 .36283 Mdot
.70984 .34528 Mdot
.40699 .81178 Mdot
.25302 .6189 Mdot
.82059 .45579 Mdot
.47067 .43835 Mdot
.33962 .46284 Mdot
.58743 .48164 Mdot
.61899 .60821 Mdot
.20362 .51389 Mdot
.61546 .23124 Mdot
.63638 .24489 Mdot
.7026 .74394 Mdot
.70985 .57912 Mdot
.59674 .79031 Mdot
.56587 .81034 Mdot
.61251 .70441 Mdot
.30616 .42245 Mdot
.21061 .34788 Mdot
.8157 .57822 Mdot
.196 .4324 Mdot
.53283 .53246 Mdot
.45629 .48486 Mdot
.20793 .61264 Mdot
.67655 .35607 Mdot
.6589 .43186 Mdot
.37088 .4988 Mdot
.57692 .38422 Mdot
.30255 .3047 Mdot
.61641 .42133 Mdot
.5412 .22689 Mdot
.50942 .84722 Mdot
.61865 .80144 Mdot
.34851 .22784 Mdot
.32638 .78311 Mdot
.76294 .42923 Mdot
.18779 .33083 Mdot
.33038 .53138 Mdot
.60489 .41134 Mdot
.45197 .76038 Mdot
.56486 .75847 Mdot
.50727 .29878 Mdot
.22547 .42168 Mdot
.319 .57139 Mdot
.42253 .70314 Mdot
.62751 .37614 Mdot
.49092 .20336 Mdot
.45717 .39609 Mdot
.52226 .29043 Mdot
.79707 .60757 Mdot
.48445 .82354 Mdot
.44165 .44558 Mdot
.24733 .40188 Mdot
.32228 .37158 Mdot
.68654 .27636 Mdot
.50715 .68854 Mdot
.57548 .48186 Mdot
.6093 .26109 Mdot
.29493 .73695 Mdot
.70266 .40614 Mdot
.55156 .69025 Mdot
.57723 .7554 Mdot
.84741 .53385 Mdot
.21417 .56517 Mdot
.77608 .2922 Mdot
.61286 .42375 Mdot
.58355 .64165 Mdot
.66822 .46132 Mdot
.30124 .24787 Mdot
.36668 .60153 Mdot
.43983 .79643 Mdot
.3801 .60991 Mdot
.61414 .3368 Mdot
.81503 .41836 Mdot
.27276 .29627 Mdot
.25012 .28591 Mdot
.39883 .66356 Mdot
.61179 .67738 Mdot
.31517 .82132 Mdot
.58364 .77616 Mdot
.51371 .26556 Mdot
.76639 .69631 Mdot
.52502 .43236 Mdot
.63104 .25346 Mdot
.41349 .35257 Mdot
.72048 .71453 Mdot
.63378 .39132 Mdot
.7758 .27594 Mdot
.82944 .6018 Mdot
.78571 .43777 Mdot
.84222 .69854 Mdot
.48476 .76423 Mdot
.54031 .4518 Mdot
.41889 .3042 Mdot
.47175 .68527 Mdot
.68516 .29494 Mdot
.3727 .73646 Mdot
.33759 .34815 Mdot
.30852 .78525 Mdot
.68209 .74508 Mdot
.23145 .31049 Mdot
.17587 .56014 Mdot
.70248 .3784 Mdot
.47163 .5224 Mdot
.66648 .65269 Mdot
.30916 .54644 Mdot
.42225 .79908 Mdot
.85659 .52216 Mdot
.52546 .6899 Mdot
.4843 .89596 Mdot
.35706 .68035 Mdot
.30868 .59271 Mdot
.5544 .85233 Mdot
.43267 .70857 Mdot
.53047 .20868 Mdot
.64682 .72621 Mdot
.68274 .62408 Mdot
.47638 .54683 Mdot
.43852 .80122 Mdot
.47605 .23615 Mdot
.75823 .67312 Mdot
.35742 .79686 Mdot
.32288 .27837 Mdot
.74578 .55351 Mdot
.58338 .72792 Mdot
.66028 .40198 Mdot
.44912 .65055 Mdot
.53439 .21741 Mdot
.65101 .79069 Mdot
.42294 .39499 Mdot
.68017 .78357 Mdot
.83191 .44029 Mdot
.52766 .57497 Mdot
.66466 .61434 Mdot
.59513 .46579 Mdot
.445 .66288 Mdot
.5238 .55479 Mdot
.38958 .24992 Mdot
.60861 .81023 Mdot
.79269 .55344 Mdot
.39931 .28861 Mdot
.43883 .27975 Mdot
.55093 .8585 Mdot
.69417 .47481 Mdot
.39197 .68099 Mdot
.75785 .65437 Mdot
.69092 .29518 Mdot
.34165 .4819 Mdot
.23959 .30693 Mdot
.46423 .30711 Mdot
.80086 .42985 Mdot
.73354 .58797 Mdot
.73107 .38074 Mdot
.60918 .81074 Mdot
.24242 .52306 Mdot
.82196 .43701 Mdot
.40701 .72761 Mdot
.19817 .39527 Mdot
.37369 .37822 Mdot
.60181 .5227 Mdot
.22339 .43434 Mdot
.35661 .65753 Mdot
.7323 .48418 Mdot
.15687 .49472 Mdot
.2761 .62028 Mdot
.57859 .52724 Mdot
.78589 .43265 Mdot
.39078 .52182 Mdot
.55818 .33641 Mdot
.69717 .22977 Mdot
.56431 .63898 Mdot
.59828 .75169 Mdot
.22431 .51438 Mdot
.47076 .66874 Mdot
.41679 .8344 Mdot
.25515 .67565 Mdot
.80806 .3214 Mdot
.73687 .71478 Mdot
.26538 .56046 Mdot
.6781 .73489 Mdot
.67615 .76271 Mdot
.80765 .32794 Mdot
.6471 .64481 Mdot
.45112 .38606 Mdot
.48794 .14209 Mdot
.3385 .5156 Mdot
.57048 .76713 Mdot
.23321 .37052 Mdot
.42408 .59787 Mdot
.53408 .3814 Mdot
.67095 .55203 Mdot
.46754 .44533 Mdot
.56343 .38428 Mdot
.52492 .55453 Mdot
.75434 .29927 Mdot
.84472 .37931 Mdot
.77173 .3009 Mdot
.2474 .69064 Mdot
.72368 .7067 Mdot
.53729 .47204 Mdot
.32174 .24387 Mdot
.60043 .49352 Mdot
.62885 .56284 Mdot
.39831 .59202 Mdot
.477 .76431 Mdot
.77648 .40335 Mdot
.5517 .29104 Mdot
.68422 .37452 Mdot
.43721 .79765 Mdot
.10753 .57345 Mdot
.74076 .44476 Mdot
.23836 .33955 Mdot
.41481 .65545 Mdot
.46552 .65175 Mdot
.38209 .77415 Mdot
.75504 .37631 Mdot
.57685 .81693 Mdot
.56396 .38313 Mdot
.20852 .41796 Mdot
.28001 .64729 Mdot
.64194 .32748 Mdot
.26746 .54169 Mdot
.57053 .78969 Mdot
.45072 .27223 Mdot
.74006 .34943 Mdot
.58493 .27428 Mdot
.67849 .44891 Mdot
.39605 .56357 Mdot
.30505 .36992 Mdot
.17471 .44615 Mdot
.23635 .62216 Mdot
.57966 .7076 Mdot
.50447 .45006 Mdot
.45876 .19757 Mdot
.39436 .30839 Mdot
.54848 .69423 Mdot
.52947 .40309 Mdot
.62992 .73808 Mdot
.76464 .22527 Mdot
.71208 .26233 Mdot
.50201 .856 Mdot
.34034 .71937 Mdot
.56561 .52545 Mdot
.56041 .82685 Mdot
.74773 .26176 Mdot
.87807 .47748 Mdot
.28379 .38169 Mdot
.32253 .53149 Mdot
.48208 .325 Mdot
.77872 .33624 Mdot
.32311 .65225 Mdot
.52868 .82461 Mdot
.55804 .71212 Mdot
.45027 .3158 Mdot
.40342 .15853 Mdot
.83841 .54634 Mdot
.72867 .61234 Mdot
.42558 .67351 Mdot
.62492 .53845 Mdot
.51005 .18791 Mdot
.60815 .41811 Mdot
.34458 .39562 Mdot
.4743 .65003 Mdot
.3323 .48609 Mdot
.42197 .76738 Mdot
.21529 .43816 Mdot
.58817 .54321 Mdot
.45412 .53784 Mdot
.65901 .38022 Mdot
.36905 .36803 Mdot
.47218 .26088 Mdot
.87262 .44845 Mdot
.42313 .62774 Mdot
.61562 .54183 Mdot
.47996 .67273 Mdot
.27002 .53288 Mdot
.82584 .40837 Mdot
.45427 .3209 Mdot
.66126 .75928 Mdot
.44326 .46419 Mdot
.45567 .64279 Mdot
.68719 .32133 Mdot
.56089 .50094 Mdot
.54532 .61661 Mdot
.28615 .71728 Mdot
.7881 .53984 Mdot
.61645 .30911 Mdot
.55507 .65568 Mdot
.62045 .50749 Mdot
.55268 .82896 Mdot
.43137 .61865 Mdot
.31816 .35777 Mdot
.64776 .77285 Mdot
.43573 .33051 Mdot
.65148 .38141 Mdot
.34327 .68508 Mdot
.19342 .44587 Mdot
.71059 .66668 Mdot
.80648 .42621 Mdot
.43741 .59456 Mdot
.28222 .61267 Mdot
.64469 .78265 Mdot
.64445 .76157 Mdot
.44303 .17751 Mdot
.61763 .43587 Mdot
.49806 .64305 Mdot
.18678 .44802 Mdot
.58037 .34881 Mdot
.30401 .28153 Mdot
.33461 .26502 Mdot
.82858 .58624 Mdot
.44719 .53902 Mdot
.31789 .79462 Mdot
.505 .73232 Mdot
.40451 .77727 Mdot
.72857 .31808 Mdot
.19395 .41871 Mdot
.54504 .7813 Mdot
.57141 .41368 Mdot
.72165 .54121 Mdot
.56187 .51865 Mdot
.40297 .21285 Mdot
.48596 .14997 Mdot
.33835 .67264 Mdot
.5493 .42621 Mdot
.3642 .80287 Mdot
.57091 .57549 Mdot
.67853 .22582 Mdot
.21207 .43139 Mdot
.77522 .35517 Mdot
.46037 .31652 Mdot
.62897 .61154 Mdot
.63672 .63837 Mdot
.7139 .69576 Mdot
.53234 .22789 Mdot
.64112 .73518 Mdot
.1624 .55064 Mdot
.37265 .78918 Mdot
.68899 .37126 Mdot
.57341 .7637 Mdot
.48702 .82599 Mdot
.20642 .5183 Mdot
.50039 .47594 Mdot
.37146 .74273 Mdot
.44856 .70853 Mdot
.31246 .76437 Mdot
.5259 .38065 Mdot
.41131 .46686 Mdot
.44082 .26242 Mdot
.25276 .47027 Mdot
.76861 .37302 Mdot
.61484 .62761 Mdot
.84303 .4975 Mdot
.54416 .81234 Mdot
.48265 .18113 Mdot
.62536 .22161 Mdot
.71697 .26599 Mdot
.77343 .54892 Mdot
.22129 .56263 Mdot
.20744 .4834 Mdot
.16466 .44466 Mdot
.43842 .46565 Mdot
.48929 .77898 Mdot
.42593 .71735 Mdot
.64597 .77886 Mdot
.42209 .38376 Mdot
.57885 .25889 Mdot
.41214 .27782 Mdot
.66335 .73648 Mdot
.69895 .48618 Mdot
.57485 .79836 Mdot
.51211 .42391 Mdot
.81165 .32171 Mdot
.25584 .66082 Mdot
.48402 .43262 Mdot
.32973 .46169 Mdot
.23795 .55592 Mdot
.48506 .80289 Mdot
.26593 .66881 Mdot
.20536 .39158 Mdot
.34551 .54609 Mdot
.49985 .52384 Mdot
.70543 .60129 Mdot
.4467 .64813 Mdot
.28308 .7172 Mdot
.47907 .67253 Mdot
.60727 .80359 Mdot
.72852 .69226 Mdot
.84206 .49375 Mdot
.49357 .7664 Mdot
.23555 .69192 Mdot
.51355 .26256 Mdot
.43287 .65781 Mdot
.21348 .43364 Mdot
.31335 .61086 Mdot
.56324 .39441 Mdot
.46951 .09513 Mdot
.19501 .61974 Mdot
.23109 .60062 Mdot
.85398 .52735 Mdot
.2539 .68106 Mdot
.36941 .35762 Mdot
.67083 .43016 Mdot
.62518 .27897 Mdot
.82779 .51617 Mdot
.61148 .58529 Mdot
.745 .27926 Mdot
.46936 .62673 Mdot
.86828 .40429 Mdot
.52894 .83237 Mdot
.54495 .41761 Mdot
.5574 .64133 Mdot
.37683 .50261 Mdot
.4336 .5 Mdot
.63271 .71086 Mdot
.67366 .49035 Mdot
.56965 .21459 Mdot
.38472 .325 Mdot
.33053 .52995 Mdot
.27141 .51652 Mdot
.57177 .40836 Mdot
.34175 .71212 Mdot
.26547 .45265 Mdot
.29237 .49289 Mdot
.43124 .44287 Mdot
.50515 .67048 Mdot
.5124 .21609 Mdot
.72569 .62272 Mdot
.75862 .37729 Mdot
.49753 .3058 Mdot
.35828 .51116 Mdot
.73826 .60215 Mdot
.20654 .61975 Mdot
.35867 .78798 Mdot
.85573 .51875 Mdot
.47402 .54433 Mdot
.68939 .51718 Mdot
.60067 .71502 Mdot
.65597 .25343 Mdot
.59882 .44956 Mdot
.37968 .35675 Mdot
.50836 .19016 Mdot
.627 .45089 Mdot
.26404 .35373 Mdot
.81372 .6169 Mdot
.19954 .42857 Mdot
.18533 .44828 Mdot
.37289 .57288 Mdot
.55082 .67024 Mdot
.62939 .33203 Mdot
.49623 .72067 Mdot
.51266 .38219 Mdot
.24442 .27277 Mdot
.58078 .66666 Mdot
.22237 .26873 Mdot
.43968 .38066 Mdot
.69967 .35387 Mdot
.44381 .71452 Mdot
.51172 .45448 Mdot
.51908 .41542 Mdot
.24118 .63758 Mdot
.58933 .25535 Mdot
.2136 .54888 Mdot
.66368 .27085 Mdot
.33369 .53287 Mdot
.163 .58724 Mdot
.24911 .72055 Mdot
.73269 .54395 Mdot
.5599 .55064 Mdot
.20369 .64511 Mdot
.31625 .52327 Mdot
.7696 .39386 Mdot
.42349 .83541 Mdot
.3295 .74444 Mdot
.69474 .57817 Mdot
.46017 .6483 Mdot
.49721 .77984 Mdot
.71535 .74217 Mdot
.47984 .16256 Mdot
.42837 .79574 Mdot
.42221 .38281 Mdot
.51083 .4335 Mdot
.5364 .79815 Mdot
.60574 .24023 Mdot
.43495 .39876 Mdot
.55683 .21325 Mdot
.16653 .34426 Mdot
.57704 .7694 Mdot
.6238 .7353 Mdot
.60096 .23088 Mdot
.62303 .34216 Mdot
.58105 .24106 Mdot
.52686 .20869 Mdot
.30745 .71725 Mdot
.1954 .57064 Mdot
.52751 .21221 Mdot
.16299 .40807 Mdot
.53399 .51396 Mdot
.37811 .41748 Mdot
.61968 .48702 Mdot
.65922 .69777 Mdot
.42874 .32024 Mdot
.80853 .57211 Mdot
.3919 .80429 Mdot
.4665 .3778 Mdot
.30018 .73035 Mdot
.24283 .411 Mdot
.6716 .67452 Mdot
.7205 .65676 Mdot
.35888 .76851 Mdot
.69987 .5041 Mdot
.40541 .20035 Mdot
.79741 .44626 Mdot
.30663 .51768 Mdot
.43167 .82172 Mdot
.36378 .4941 Mdot
.64559 .5267 Mdot
.64238 .29157 Mdot
.37851 .74016 Mdot
.76675 .33811 Mdot
.351 .64395 Mdot
.5939 .4091 Mdot
.48669 .15382 Mdot
.62888 .35114 Mdot
.76273 .30522 Mdot
.73486 .37794 Mdot
.54315 .19551 Mdot
.26358 .56822 Mdot
.25878 .59841 Mdot
.15904 .37414 Mdot
.47356 .38678 Mdot
.28957 .51304 Mdot
.37375 .23262 Mdot
.60693 .41365 Mdot
.37028 .57588 Mdot
.34449 .45144 Mdot
.40789 .4321 Mdot
.32421 .29076 Mdot
.52603 .52243 Mdot
.66349 .40463 Mdot
.41647 .44037 Mdot
.77344 .62372 Mdot
.77399 .66722 Mdot
.31792 .50036 Mdot
.27032 .23527 Mdot
.55146 .63281 Mdot
.74617 .54126 Mdot
.58611 .81753 Mdot
.39774 .1608 Mdot
.28105 .46072 Mdot
.27195 .75258 Mdot
.64373 .56865 Mdot
.35936 .75246 Mdot
.62971 .38682 Mdot
.2045 .42574 Mdot
.39329 .61903 Mdot
.46635 .67161 Mdot
.46119 .37599 Mdot
.73796 .34723 Mdot
.27418 .46556 Mdot
.57319 .37218 Mdot
.33131 .72124 Mdot
.6109 .70378 Mdot
.39735 .35454 Mdot
.25339 .53876 Mdot
.73319 .55239 Mdot
.6898 .67782 Mdot
.67786 .38705 Mdot
.61215 .73974 Mdot
.171 .47881 Mdot
.87565 .44897 Mdot
.54722 .35895 Mdot
.57308 .46639 Mdot
.36468 .25981 Mdot
.32526 .75362 Mdot
.42306 .22093 Mdot
.60697 .81568 Mdot
.50212 .66074 Mdot
.49679 .60324 Mdot
.5379 .68597 Mdot
.58738 .50584 Mdot
.48265 .463 Mdot
.32639 .38046 Mdot
.59036 .2122 Mdot
.48545 .22056 Mdot
.69245 .41199 Mdot
.42264 .20593 Mdot
.60024 .73229 Mdot
.54686 .19927 Mdot
.29775 .49154 Mdot
.69398 .66705 Mdot
.45578 .29353 Mdot
.77613 .66848 Mdot
.60036 .81595 Mdot
.49217 .33478 Mdot
.29407 .5417 Mdot
.35654 .81002 Mdot
.6428 .64162 Mdot
.51356 .49573 Mdot
.55669 .61198 Mdot
.47291 .57282 Mdot
.36002 .17751 Mdot
.31806 .73586 Mdot
.56322 .53424 Mdot
.66237 .75008 Mdot
.68995 .73697 Mdot
.83723 .35473 Mdot
.20272 .36651 Mdot
.59781 .37919 Mdot
.8116 .34361 Mdot
.55988 .21052 Mdot
.70576 .74972 Mdot
.37073 .39217 Mdot
.62641 .82896 Mdot
.72174 .53515 Mdot
.32518 .76549 Mdot
.66507 .43126 Mdot
.60869 .26959 Mdot
.2312 .50448 Mdot
.5133 .48973 Mdot
.33139 .32434 Mdot
.23182 .63897 Mdot
.14729 .56948 Mdot
.59215 .51482 Mdot
.22595 .45366 Mdot
.51317 .31756 Mdot
.44961 .82919 Mdot
.26073 .64784 Mdot
.54739 .56118 Mdot
.43567 .27744 Mdot
.76135 .34772 Mdot
.51309 .677 Mdot
.56003 .48089 Mdot
.25033 .63178 Mdot
.82052 .501 Mdot
.61177 .71466 Mdot
.18707 .4423 Mdot
.72906 .54925 Mdot
.44133 .48504 Mdot
.64104 .59374 Mdot
.6385 .42595 Mdot
.35903 .67538 Mdot
.49592 .5016 Mdot
.55558 .56508 Mdot
.37275 .44669 Mdot
.39934 .39691 Mdot
.74262 .29598 Mdot
.48545 .24039 Mdot
.19649 .47529 Mdot
.67216 .36977 Mdot
.54609 .31529 Mdot
.41334 .22681 Mdot
.70505 .26557 Mdot
.29918 .67011 Mdot
.52484 .68976 Mdot
.60232 .78197 Mdot
.7307 .69388 Mdot
.66369 .32654 Mdot
.86025 .43002 Mdot
.42259 .33055 Mdot
.6841 .66541 Mdot
.56982 .29483 Mdot
.2871 .5163 Mdot
.51907 .60344 Mdot
.32447 .76379 Mdot
.42884 .60595 Mdot
.55118 .75629 Mdot
.21315 .57273 Mdot
.48691 .58164 Mdot
.71671 .59569 Mdot
.66134 .75605 Mdot
.38433 .48123 Mdot
.18186 .49403 Mdot
.41048 .31945 Mdot
.25335 .62959 Mdot
.73128 .69834 Mdot
.84342 .54868 Mdot
.49358 .41345 Mdot
.45188 .69822 Mdot
.57994 .60799 Mdot
.1775 .44533 Mdot
.31337 .73357 Mdot
.68057 .64634 Mdot
.29938 .3572 Mdot
.65068 .37548 Mdot
.28923 .39978 Mdot
.45146 .48729 Mdot
.82157 .52427 Mdot
.65438 .39902 Mdot
.52242 .18836 Mdot
.38256 .67185 Mdot
.54595 .4459 Mdot
.52907 .63414 Mdot
.46382 .69272 Mdot
.20869 .32906 Mdot
.558 .65973 Mdot
.4384 .8041 Mdot
.73659 .57711 Mdot
.22202 .39961 Mdot
.35309 .75902 Mdot
.37403 .33348 Mdot
.59239 .25611 Mdot
.70252 .66527 Mdot
.42402 .26462 Mdot
.58703 .63796 Mdot
.30424 .52186 Mdot
.57573 .36562 Mdot
.43378 .82764 Mdot
.77517 .55857 Mdot
.4883 .71358 Mdot
.41437 .55893 Mdot
.56262 .4837 Mdot
.4313 .29906 Mdot
.615 .82669 Mdot
.60013 .25842 Mdot
.48462 .65592 Mdot
.44799 .53866 Mdot
.45146 .71252 Mdot
.72373 .39453 Mdot
.84214 .58148 Mdot
.67385 .42368 Mdot
.44956 .43413 Mdot
.6984 .34896 Mdot
.22428 .58197 Mdot
.412 .83643 Mdot
.547 .68865 Mdot
.53839 .43026 Mdot
.34626 .64047 Mdot
.4088 .24405 Mdot
.402 .55543 Mdot
.53215 .49442 Mdot
.41372 .44853 Mdot
.30463 .32834 Mdot
.54685 .33382 Mdot
.64715 .67265 Mdot
.51274 .76465 Mdot
.62143 .77376 Mdot
.22488 .38293 Mdot
.39102 .31799 Mdot
.32007 .41827 Mdot
.80399 .55977 Mdot
.63761 .83222 Mdot
.55867 .17251 Mdot
.578 .60545 Mdot
.41245 .29751 Mdot
.4401 .69229 Mdot
.36944 .45671 Mdot
.49702 .21045 Mdot
.43149 .23253 Mdot
.42106 .3735 Mdot
.44927 .63168 Mdot
.57233 .74717 Mdot
.24614 .4866 Mdot
.41116 .69351 Mdot
.45645 .28663 Mdot
.73122 .28172 Mdot
.22565 .65925 Mdot
.32796 .75515 Mdot
.73892 .76965 Mdot
.3936 .34013 Mdot
.66141 .55907 Mdot
.70155 .45653 Mdot
.74745 .69146 Mdot
.48619 .67866 Mdot
.79102 .41567 Mdot
.36131 .31507 Mdot
.53704 .68185 Mdot
.55796 .40332 Mdot
.53612 .76133 Mdot
.2838 .39935 Mdot
.48695 .44986 Mdot
.26169 .60645 Mdot
.86643 .43236 Mdot
.7026 .57861 Mdot
.60403 .78757 Mdot
.74151 .32612 Mdot
.16347 .43864 Mdot
.74352 .69894 Mdot
.51139 .74595 Mdot
.28867 .67685 Mdot
.67158 .46354 Mdot
.52705 .39909 Mdot
.6893 .35482 Mdot
.77371 .39722 Mdot
.75047 .6282 Mdot
.29464 .56849 Mdot
.71015 .37213 Mdot
.57801 .70707 Mdot
.76364 .61492 Mdot
.53839 .42856 Mdot
.7295 .62275 Mdot
.2897 .5362 Mdot
.58727 .22632 Mdot
.59376 .32494 Mdot
.50958 .70758 Mdot
.73992 .58738 Mdot
.34847 .26845 Mdot
.24858 .6629 Mdot
.14473 .45837 Mdot
.31889 .65388 Mdot
.70386 .27398 Mdot
.60451 .54118 Mdot
.83684 .33091 Mdot
.22482 .53125 Mdot
.23894 .51646 Mdot
.20407 .5574 Mdot
.40437 .46241 Mdot
.61238 .50613 Mdot
.58761 .63808 Mdot
.47719 .8033 Mdot
.69383 .5742 Mdot
.76481 .42244 Mdot
.72876 .33407 Mdot
.46218 .66022 Mdot
.5491 .70942 Mdot
.49946 .72629 Mdot
.50103 .589 Mdot
.64354 .36704 Mdot
.77768 .30813 Mdot
.47687 .41591 Mdot
.6802 .64394 Mdot
.54344 .65629 Mdot
.67597 .44844 Mdot
.34736 .82822 Mdot
.53512 .3967 Mdot
.62797 .72789 Mdot
.71541 .56975 Mdot
.64858 .31846 Mdot
.43237 .21452 Mdot
.8953 .60109 Mdot
.86422 .35132 Mdot
.57363 .38499 Mdot
.24185 .3292 Mdot
.71249 .57553 Mdot
.64644 .73725 Mdot
.28573 .6504 Mdot
.2879 .35369 Mdot
.68402 .65259 Mdot
.62936 .30066 Mdot
.51238 .59315 Mdot
.21833 .51952 Mdot
.79097 .65533 Mdot
.71925 .32951 Mdot
.65969 .75119 Mdot
.57293 .50438 Mdot
.52025 .61655 Mdot
.70894 .80286 Mdot
.54775 .79616 Mdot
.58056 .65351 Mdot
.69008 .381 Mdot
.64268 .66825 Mdot
.61542 .60668 Mdot
.38739 .76151 Mdot
.16342 .58456 Mdot
.61003 .71702 Mdot
.66183 .73668 Mdot
.63499 .41814 Mdot
.40098 .4896 Mdot
.44196 .38086 Mdot
.50175 .41192 Mdot
.59407 .66159 Mdot
.41612 .35036 Mdot
.47927 .60776 Mdot
.35849 .80461 Mdot
.41682 .54196 Mdot
.17001 .53776 Mdot
.69149 .78312 Mdot
.76763 .56687 Mdot
.42366 .24507 Mdot
.64627 .63709 Mdot
.68918 .68332 Mdot
.73898 .65801 Mdot
.5145 .51586 Mdot
.28298 .72975 Mdot
.56026 .10788 Mdot
.38703 .27643 Mdot
.82176 .54264 Mdot
.59124 .34004 Mdot
.42754 .47689 Mdot
.71403 .61689 Mdot
.38129 .39927 Mdot
.31783 .48871 Mdot
.55195 .5124 Mdot
.6567 .36044 Mdot
.45199 .31306 Mdot
.29155 .21128 Mdot
.56262 .54797 Mdot
.46645 .21422 Mdot
.69125 .75516 Mdot
.79718 .44465 Mdot
.72892 .50353 Mdot
.62777 .63635 Mdot
.51579 .29199 Mdot
.53807 .43168 Mdot
.42541 .80795 Mdot
.83944 .51176 Mdot
.61552 .76489 Mdot
.77489 .56256 Mdot
.71585 .59125 Mdot
.64028 .59082 Mdot
.40032 .61422 Mdot
.47387 .3976 Mdot
.44469 .79512 Mdot
.6383 .66587 Mdot
.74111 .71847 Mdot
.27231 .46367 Mdot
.45479 .55328 Mdot
.55383 .42569 Mdot
.83226 .35354 Mdot
.70315 .42241 Mdot
.6601 .34808 Mdot
.71067 .26873 Mdot
.27161 .49459 Mdot
.43526 .66586 Mdot
.37994 .49933 Mdot
.64346 .65278 Mdot
.65922 .39915 Mdot
.68486 .22617 Mdot
.43646 .78383 Mdot
.33853 .31533 Mdot
.30688 .36468 Mdot
.24987 .3434 Mdot
.39925 .3488 Mdot
.75567 .75386 Mdot
.24816 .55097 Mdot
.70701 .24981 Mdot
.17282 .48418 Mdot
.66628 .38304 Mdot
.26072 .68699 Mdot
.55781 .65429 Mdot
.32153 .49604 Mdot
.63838 .7527 Mdot
.67713 .5852 Mdot
.81481 .42541 Mdot
.64713 .58408 Mdot
.79618 .37077 Mdot
.34387 .65041 Mdot
.3088 .55474 Mdot
.22533 .57124 Mdot
.68348 .44438 Mdot
.53715 .84912 Mdot
.39977 .24442 Mdot
.56366 .83427 Mdot
.51291 .84669 Mdot
.67266 .75595 Mdot
.79496 .40162 Mdot
.44276 .16341 Mdot
.22898 .58588 Mdot
.35453 .76837 Mdot
.33739 .39316 Mdot
.65604 .45364 Mdot
.23674 .55671 Mdot
.59866 .46751 Mdot
.53022 .2292 Mdot
.43901 .28742 Mdot
.30808 .15899 Mdot
.54914 .72416 Mdot
.63476 .33678 Mdot
.24205 .56889 Mdot
.70554 .7373 Mdot
.6774 .4572 Mdot
.22576 .62903 Mdot
.45733 .48254 Mdot
.60994 .5247 Mdot
.75115 .62322 Mdot
.22499 .37504 Mdot
.25057 .51331 Mdot
.12847 .43874 Mdot
.21046 .6248 Mdot
.32008 .32487 Mdot
.47173 .46173 Mdot
.57607 .39033 Mdot
.38938 .21241 Mdot
.26358 .5956 Mdot
.2671 .71584 Mdot
.33837 .78411 Mdot
.54043 .7979 Mdot
.16327 .36871 Mdot
.21275 .41821 Mdot
.76377 .67777 Mdot
.27611 .70244 Mdot
.57225 .37957 Mdot
.49152 .74474 Mdot
.30866 .51435 Mdot
.33289 .35055 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0^?ooool2o`0008oooooo000Looooo`03o`000?oooooooooo0;Sooooo0_l0
002?ooooo`007?ooool00ol0003oooooooooo`2Eooooo`;o0000/_ooool001cooooo00?o0000oooo
ooooool0UOooool2o`000;;ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo08_ooooo0_l0002looooo`007?ooool0
0ol0003oooooooooo`2;ooooo`;o00009Oooool2o`0009Gooooo000Looooo`03o`000?oooooooooo
0;;ooooo0_l0002Eooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo083ooooo0_l00037ooooo`007?ooool00ol0003oooooooooo`20ooooo`;o00000_oo
ool2o`000<?ooooo000Looooo`03o`000?oooooooooo08Cooooo0_l00033ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0Loooool2o`0001cooooo0_l0002fooooo`007?ooool00ol0003ooooooooo
o`1cooooo`;o00000oooool2o`0001Oooooo0_l0002fooooo`007?ooool00ol0003oooooooooo`1h
ooooo`;o00001oooool2o`00023ooooo0_l0002Tooooo`007?ooool00ol0003oooooooooo`21oooo
o`;o00006?ooool2o`0000Kooooo0_l00004ooooo`;o0000W_ooool001cooooo00?o0000oooooooo
ool0Voooool2o`0000cooooo0_l0002Nooooo`007?ooool00ol0003oooooooooo`2Jooooo`;o0000
[Oooool001cooooo0_l0002Kooooo`;o00005?ooool2o`0009Oooooo000Looooo`03o`000?oooooo
oooo07?ooooo0_l00007ooooo`;o00002oooool4o`0000Cooooo0_l00007ooooo`;o00002Oooool2
o`0000Wooooo0_l0002Gooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o00004Oooool2o`00
00Oooooo0_l000000ooooooo0000o`000004ooooo`;o00000_ooool4o`0000Cooooo0_l00007oooo
o`;o00002Oooool2o`0000oooooo0_l0002Aooooo`007?ooool00ol0003oooooooooo`1Pooooo`;o
00006oooool4o`0000Cooooo0_l0000Aooooo`;o00007?ooool2o`0000_ooooo0_l00024ooooo`00
7?ooool00ol0003oooooooooo`1mooooo`;o00003Oooool2o`0000[ooooo0_l0000Gooooo`;o0000
2Oooool2o`0000Gooooo0_l00024ooooo`007?ooool00ol0003oooooooooo`2<ooooo`;o00001Ooo
ool2o`0001cooooo0_l00009ooooo`;o00001oooool2o`0008;ooooo000Looooo`03o`000?oooooo
oooo06cooooo0_l0000Uooooo`;o0000<?ooool2o`0008;ooooo000Looooo`03o`000?oooooooooo
06cooooo0_l00010ooooo`;o00000_ooool2o`0009Gooooo000Looooo`03o`000?oooooooooo077o
oooo0_l0000Iooooo`?o00006_ooool3o`0000;ooooo0_l00002ooooo`;o0000UOooool001cooooo
00?o0000ooooooooool0LOooool2o`0001Wooooo0ol0000:ooooo`;o00003_ooool3o`0009gooooo
000Looooo`03o`000?oooooooooo09Oooooo1?l0002^ooooo`007?ooool00ol0003oooooooooo`2B
ooooo`;o00000oooool2o`0000gooooo0_l0002Qooooo`007?ooool00ol0003oooooooooo`21oooo
o`;o00003_ooool3o`0000Wooooo0_l00002ooooo`?o00000_ooool2o`0000Sooooo1?l000000ooo
oooo0000o`00002Booooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5
o`0000Kooooo00?o0000ooooooooool0OOooool6o`0000Cooooo0ol00007ooooo`;o00002_ooool2
o`0000;ooooo0ol00002ooooo`;o00002?ooool4o`000003ooooool0003o0000023ooooo0_l0001`
ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^
k_ooooooA4A400Kooooo00?o0000ooooooooool0OOooool4o`0000;ooooo0_l000000ooooooo0000
o`000002o`00017ooooo0_l00005ooooo`;o00002Oooool2o`0000;ooooo0_l0000Tooooo`;o0000
L?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^
kP07ooooo`03o`000?oooooooooo08?ooooo0_l000000ooooooo0000o`000009ooooo`;o00001Ooo
ool5o`0000Gooooo0ol00008ooooo`?o0000;oooool2o`0006Sooooo00000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`00083ooooo0_l0000?
ooooo`;o00001Oooool3o`0000Sooooo0_l00009ooooo`;o00003Oooool2o`00023ooooo0_l0001X
ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo
00Gooooo00?o0000ooooooooool0Loooool2o`0000_ooooo0_l000001?oooooo0000o`000?ooool2
o`0000[ooooo0_l00004ooooo`;o00000_ooool2o`0000oooooo0_l00003ooooo`;o00002Oooool2
o`0008[ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`1cooooo`?o00002_ooool2o`000004ooooool0003o0000
ooooo`;o000000?oooooo`000?l000000_l00005ooooo`;o000000Coooooo`000?l0003ooooo0_l0
0002ooooo`;o00002Oooool4o`0000;ooooo0_l00003ooooo`;o0000UOooool00006oooooomgMgOo
V9RHoooooonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000oooooooo
ool0Foooool2o`0001Oooooo0_l0000Cooooo`Co000000?oooooo`000?l000001Oooool2o`0000Oo
oooo0_l00007ooooo`Co00000oooool2o`0000;ooooo0_l00008ooooo`;o00001?ooool2o`0008Go
oooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006
ooooo`03o`000?oooooooooo05_ooooo0_l0000Nooooo`;o00000_ooool2o`0000Gooooo0_l00000
0ooooooo0000o`000003ooooo`;o00001?ooool4o`0000Kooooo0_l00008ooooo`;o00000oooool3
o`000005ooooool0003o0000o`000?ooool00_l00005ooooo`;o00001?ooool2o`0008Gooooo000L
ooooo`03o`000?oooooooooo07_ooooo0_l00002ooooo`;o00001Oooool2o`000003ooooool0003o
000000Wooooo1Ol0000:ooooo`;o00001Oooool2o`000003ooooool0003o000000;ooooo0_l00002
ooooo`;o0000T_ooool001cooooo00?o0000ooooooooool0K?ooool2o`0001Sooooo0_l0000?oooo
o`;o000000Coooooo`000?l0003o00001_ooool5o`0000;ooooo0_l0000<ooooo`;o00002Oooool2
o`0000;ooooo0ol0000;ooooo`;o0000L_ooool001cooooo00?o0000ooooooooool0K?ooool2o`00
00Sooooo0_l00004ooooo`;o00002?ooool2o`0001;ooooo0ol00007ooooo`Co00004?ooool2o`00
00Wooooo0_l00002ooooo`?o00002oooool3o`00077ooooo000Looooo`03o`000?oooooooooo07Ko
oooo0_l00004ooooo`Go00000_ooool2o`0000_ooooo0_l0000@ooooo`;o00002?ooool2o`0000go
oooo0_l0000<ooooo`;o00002oooool2o`000003ooooool0003o000000;o00006?ooool2o`0005;o
oooo000Looooo`03o`000?oooooooooo05gooooo0_l00009ooooo`;o00000oooool2o`0000?ooooo
0_l00009ooooo`Co00000_ooool2o`0000Oooooo0_l00002ooooo`;o00004?ooool2o`0000Cooooo
0ol000001?oooooo0000o`000?l0000<ooooo`;o00003?ooool2o`0000kooooo1?l00002ooooo`;o
00005?ooool2o`0005;ooooo000Looooo`03o`000?oooooooooo05gooooo0_l00009ooooo`;o0000
0oooool2o`0000?ooooo0_l00002ooooo`;o00003oooool3o`0000;ooooo0_l0000<ooooo`;o0000
3?ooool3o`0000;ooooo0_l00002ooooo`;o00003?ooool2o`0000?ooooo0_l00009ooooo`;o0000
3_ooool2o`0006Sooooo000Looooo`03o`000?oooooooooo05Cooooo0_l0000Gooooo`;o00001ooo
ool2o`0000oooooo1?l00002ooooo`;o00001oooool3o`000003ooooool0003o000000;ooooo0_l0
000Aooooo`;o00003?ooool2o`0000;ooooo0ol00009ooooo`;o00001oooool2o`0006oooooo000L
ooooo`03o`000?oooooooooo05Cooooo0_l0000Booooo`;o00000oooool2o`0001Wooooo0ol00002
ooooo`;o00001oooool3o`0000Cooooo0ol0000Dooooo`;o00002Oooool2o`0000;ooooo0_l0000=
ooooo`;o00001?ooool2o`0006oooooo000Looooo`03o`000?oooooooooo04oooooo0_l0000Goooo
o`;o00004Oooool2o`0000_ooooo1_l00004ooooo`;o00001Oooool3o`000003ooooool0003o0000
01?ooooo1?l00003ooooo`;o00001?ooool5o`0000kooooo0_l0001eooooo`007?ooool00ol0003o
ooooooooo`1?ooooo`;o00003Oooool2o`0000Gooooo0_l0000Booooo`Co000000Coooooo`000?l0
003ooooo0_l00003ooooo`;o00000_ooool4o`0000Cooooo0_l00005ooooo`?o00002?ooool2o`00
00cooooo0_l00004ooooo`?o00001_ooool4o`0000Kooooo0_l00004ooooo`;o0000M_ooool001co
oooo00?o0000ooooooooool0FOooool2o`0000?ooooo1?l00003ooooo`Co00000oooool2o`0000_o
oooo0_l00003ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000004ooooo`;o
00003?ooool2o`0000Sooooo0_l0000Aooooo`?o00000_ooool4o`0000?ooooo0_l00006ooooo`;o
00001?ooool2o`0007Kooooo000Looooo`;o0000F_ooool2o`0000?ooooo1?l000000ooooooo0000
o`000002ooooo`;o00000oooool2o`0000gooooo0_l00006ooooo`;o00005Oooool2o`0001_ooooo
0_l00003ooooo`Co00008_ooool2o`0006Gooooo000Looooo`03o`000?oooooooooo06?ooooo0_l0
000<ooooo`?o00001oooool2o`0000Oooooo0_l0000;ooooo`;o00001oooool2o`00023ooooo0_l0
000;ooooo`;o00001_ooool2o`0000oooooo0_l0000<ooooo`;o0000Eoooool001cooooo00?o0000
ooooooooool0LOooool3o`00013ooooo0_l00003ooooo`Co00001?ooool2o`0000Oooooo0_l0000P
ooooo`Go00001Oooool2o`000004ooooool0003o0000ooooo`;o00000oooool2o`0001gooooo0_l0
001Gooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o00004?ooool3o`0000Kooooo0_l0000D
ooooo`Co00002Oooool2o`0000;ooooo0_l0000Looooo`Co000000?oooooo`000?l000000_l00000
0ooooooo0000o`000002ooooo`;o00001?ooool2o`0000Gooooo0_l0001dooooo`007?ooool00ol0
003oooooooooo`1Hooooo`;o00004?ooool3o`0000Kooooo0_l0000@ooooo`Co00000_ooool2o`00
0003ooooool0003o000000Kooooo0ol00006ooooo`;o000000Coooooo`000?l0003o00004oooool8
o`0000;ooooo0_l0000?ooooo`;o00003oooool2o`0000Wooooo0_l0001Hooooo`007?ooool00ol0
003oooooooooo`19ooooo`;o00002?ooool2o`0000gooooo0_l00003ooooo`Co00004?ooool2o`00
0003ooooool0003o000000Gooooo1?l00002ooooo`;o000000?oooooo`000?l000001oooool2o`00
00Kooooo0_l000001?oooooo0000o`000?l0000Dooooo`Ko000000?oooooo`000?l000000oooool4
o`0000Gooooo0_l0000Aooooo`;o000000Coooooo`000?l0003o00002?ooool2o`0005Sooooo000L
ooooo`03o`000?oooooooooo04Gooooo0_l00002ooooo`;o00002?ooool3o`0000[ooooo1?l00003
ooooo`Co00000_ooool2o`0000cooooo0_l000000ooooooo0000o`00000Hooooo`;o00002Oooool2
o`0000[ooooo0_l0000;ooooo`?o000000?oooooo`000?l000000_l000000ooooooo0000o`000002
o`0000Gooooo0_l00004ooooo`?o00002_ooool6o`0006;ooooo000Looooo`03o`000?oooooooooo
04Gooooo0_l00005ooooo`;o00001_ooool4o`0000Gooooo0_l000000ooooooo0000o`00000;oooo
o`;o00008?ooool2o`0000Oooooo0_l0000Eooooo`?o00000_ooool2o`0000;ooooo0_l00003oooo
o`;o00000oooool2o`0000Cooooo0_l0000:ooooo`?o00002_ooool4o`0000?ooooo0_l0001Ooooo
o`007?ooool00ol0003oooooooooo`1<ooooo`;o00002?ooool2o`0000Gooooo0_l00007ooooo`;o
00001oooool2o`0000Wooooo0_l0000Cooooo`;o00001_ooool2o`0000Oooooo0_l00007ooooo`;o
00001?ooool3o`0000;ooooo0_l00002ooooo`Go00002oooool2o`0000Gooooo0_l0000:ooooo`;o
00001?ooool4o`0000?ooooo0_l0000>ooooo`;o0000Coooool001cooooo00?o0000ooooooooool0
E_ooool2o`0000Cooooo0_l00007ooooo`?o00001oooool2o`0000Gooooo0_l00002ooooo`;o0000
1_ooool=o`0000Sooooo0_l00002ooooo`;o00000oooool2o`0000Oooooo0_l0000?ooooo`?o0000
1oooool2o`000003ooooool0003o000000Kooooo0_l0000:ooooo`;o00001_ooool2o`0000Oooooo
1?l00008ooooo`;o0000Coooool001cooooo00?o0000ooooooooool0E_ooool2o`0000Cooooo0_l0
00000ooooooo0000o`000003ooooo`?o00003oooool6o`0000?ooooo0_l000000ooooooo0000o`00
000<o`0000_ooooo0ol0000;ooooo`?o00005_ooool4o`000003ooooool0003o000000?ooooo0_l0
000=ooooo`?o00001Oooool3o`0000Cooooo1_l0001Iooooo`007?ooool00ol0003oooooooooo`1>
ooooo`;o00003oooool2o`0000;ooooo0ol0000<ooooo`co000000?oooooo`000?l000000_ooool4
o`0000Oooooo0_l0000<ooooo`;o00003?ooool2o`00017ooooo0_l00003ooooo`;o00002?ooool2
o`0000gooooo0ol00006ooooo`;o00001?ooool2o`0005gooooo000Looooo`03o`000?oooooooooo
04kooooo0_l0000Booooo`Go00002oooool6o`0000;ooooo2?l000000ooooooo0000o`000002o`00
00Cooooo0_l00004ooooo`?o00003Oooool2o`0000;ooooo0_l000000ooooooo0000o`000003oooo
o`;o00003Oooool4o`0000;ooooo0_l00005ooooo`;o0000O_ooool001cooooo00?o0000oooooooo
ool0BOooool2o`0000cooooo0_l00009ooooo`;o000000Coooooo`000?l0003o00005_ooool4o`00
00Gooooo0_l00002ooooo`;o00001?ooool3o`0000?ooooo0ol00007ooooo`;o000000?oooooo`00
0?l000001?l00003ooooo`Co00002oooool4o`0000;ooooo0_l00003ooooo`Go000000?oooooo`00
0?l000003?ooool2o`0000[ooooo0_l0000?ooooo`;o0000Coooool001cooooo00?o0000oooooooo
ool0BOooool2o`0000cooooo0_l0000=ooooo`;o00002?ooool2o`0000cooooo0_l00006ooooo`?o
00001oooool4o`0000?ooooo0ol00009ooooo`Ko00001_ooool2o`0000Cooooo0_l0000@ooooo`Go
000000?oooooo`000?l000003?ooool4o`0000Sooooo0_l0000?ooooo`;o0000Coooool001cooooo
00?o0000ooooooooool0EOooool2o`0001Wooooo1?l00003ooooo`;o00001_ooool2o`000003oooo
ool0003o000000;ooooo0ol00007ooooo`Co00001?ooool2o`0000Wooooo0_l000000ooooooo0000
o`00000=ooooo`;o00002?ooool2o`0000?ooooo0ol000000ooooooo0000o`000002ooooo`;o0000
1oooool2o`0000Cooooo1?l0000>ooooo`;o00003?ooool2o`0004cooooo000Looooo`;o0000E_oo
ool2o`0001_ooooo0_l00003ooooo`Co00000_ooool4o`000003ooooool0003o000000Cooooo0_l0
000?ooooo`;o00001_ooool2o`0001cooooo0_l00003ooooo`?o00000_ooool2o`000003ooooool0
003o000000Oooooo0_l00003ooooo`;o00004Oooool2o`0000;ooooo0_l00004ooooo`;o00000_oo
ool2o`0004cooooo000Looooo`03o`000?oooooooooo04oooooo0_l0000>ooooo`;o00003Oooool2
o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`0000Gooooo0_l00002ooooo`;o00001Oooool2
o`0000Sooooo0_l00006ooooo`;o00004_ooool2o`0001;ooooo0_l000000ooooooo0000o`00000<
ooooo`Co00003?ooool2o`0000Gooooo0_l00004ooooo`;o0000D?ooool001cooooo00?o0000oooo
ooooool0A_ooool2o`0000;ooooo0_l00002ooooo`Go00003?ooool2o`0000Oooooo0_l00002oooo
o`Co00000_ooool2o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000000oooool2o`00
00?ooooo0_l00004ooooo`;o00000_ooool2o`0000Wooooo0_l0000Eooooo`;o00001_ooool2o`00
00gooooo0_l000000ooooooo0000o`00000;ooooo`;o00001Oooool2o`0000Gooooo0_l00008oooo
o`;o0000Doooool001cooooo00?o0000ooooooooool0A_ooool3o`000003ooooool0003o000000Co
000000?oooooo`000?l000005Oooool2o`0000;ooooo0_l00009ooooo`;o00000oooool2o`000003
ooooool0003o000000?ooooo0_l00003ooooo`;o00002?ooool5o`0000Kooooo0_l00003ooooo`;o
00005_ooool4o`0000Gooooo0_l00009ooooo`;o00000oooool2o`0000Cooooo0_l00007ooooo`;o
00001Oooool2o`0000Sooooo0_l00003ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0
@?ooool2o`000003ooooool0003o000000;ooooo0_l00003ooooo`;o00009Oooool2o`0000Oooooo
0ol00002ooooo`;o00002?ooool6o`0000?ooooo1?l00002ooooo`;o000000?oooooo`000?l00000
1?ooool2o`0000Gooooo0_l00009ooooo`;o00001?ooool4o`0000;ooooo1Ol0000=ooooo`?o0000
1?ooool2o`0001gooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o000000?o
ooooo`000?l000000_l0000Sooooo`;o00001_ooool5o`0000Kooooo0_l00002ooooo`;o000000?o
ooooo`000?l000001Oooool6o`000004ooooool0003o0000ooooo`;o00000oooool2o`000003oooo
ool0003o000000;ooooo1?l00005ooooo`;o00000_ooool2o`0000Gooooo0_l0000:ooooo`Go0000
3?ooool3o`0000Sooooo0_l00005ooooo`;o0000Hoooool001cooooo00?o0000ooooooooool0AOoo
ool2o`0000Sooooo0_l0000:ooooo`;o00003?ooool3o`0000Gooooo0ol000000ooooooo0000o`00
0004ooooo`;o00001Oooool4o`0000Kooooo2?l000000ooooooo0000o`000002ooooo`Co00001?oo
ool6o`0000Oooooo0_l0000>ooooo`;o00000_ooool4o`0000Wooooo0_l000000ooooooo0000o`00
0009ooooo`;o00001Oooool2o`0000?ooooo0_l00002ooooo`;o0000F_ooool001cooooo00?o0000
ooooooooool0?oooool2o`0000kooooo0_l00008ooooo`Co00003?ooool2o`0000Kooooo0_l00008
ooooo`;o00000oooool4o`0000Cooooo3_l000000ooooooo0000o`000004o`0000Kooooo1?l0000D
ooooo`;o000000?oooooo`000?l000000_ooool4o`0000Wooooo0_l0000:ooooo`;o00003?ooool2
o`0000;ooooo0_l0000Dooooo`?o0000@oooool001cooooo00?o0000ooooooooool0?oooool2o`00
013ooooo0_l00006ooooo`;o00002Oooool2o`0000;ooooo0_l0000;ooooo`;o00000_ooool5o`00
00;ooooo0_l00003oooooaOo000000?oooooo`000?l000001?l0000Dooooo`;o00000_ooool5o`00
01Oooooo0_l00002ooooo`;o00002_ooool4o`0000;ooooo0_l0000Dooooo`?o0000@oooool001co
oooo00?o0000ooooooooool0@?ooool2o`0000Oooooo1?l00004ooooo`;o00003?ooool2o`0000?o
oooo0ol000000ooooooo0000o`00000;ooooo`;o00000_ooool5o`0000Oooooo5ol000000ooooooo
0000o`000004o`0001Cooooo0_l00004ooooo`?o00003Oooool2o`0000Gooooo0_l000000ooooooo
0000o`00000>ooooo`;o00001?ooool2o`0000Cooooo0_l0000>ooooo`;o0000A?ooool001cooooo
00?o0000ooooooooool0>Oooool2o`0000Gooooo0_l00007ooooo`Co00004_ooool4o`0000;ooooo
0_l0000Moooooa7o00000_ooool5o`0000Wooooo0_l00009ooooo`;o000000?oooooo`000?l00000
1_ooool4o`0000[ooooo0_l00002ooooo`;o00001Oooool2o`0000Gooooo0_l000000ooooooo0000
o`000006ooooo`;o00002Oooool4o`0000kooooo0_l00007ooooo`;o0000>oooool001cooooo00?o
0000ooooooooool0>Oooool2o`0001Gooooo0_l0000?ooooo`;o00004oooool2o`0000cooooo6ol0
0006ooooo`;o00001oooool4o`000003ooooool0003o000000Co000000?oooooo`000?l000000ol0
0009ooooo`?o00004?ooool2o`000003ooooool0003o000000?ooooo0_l000001?oooooo0000o`00
0?ooool2o`0000Kooooo0_l0000Iooooo`;o0000>oooool001cooooo00?o0000ooooooooool0A?oo
ool2o`0000[ooooo0_l00003ooooo`;o00003_ooool3o`0000Cooooo1?l00002ooooo`;o00000_oo
ool2o`0000_ooooo7Ol000000ooooooo0000o`000009ooooo`Go000000?oooooo`000?l000001Ol0
00000ooooooo0000o`000008ooooo`?o000000?oooooo`000?l000000_l00002ooooo`;o00002Ooo
ool2o`0000Cooooo0_l00002ooooo`?o00000oooool2o`0000?ooooo0_l00005ooooo`;o00000_oo
ool2o`0004kooooo000Looooo`03o`000?oooooooooo04Cooooo0_l00004ooooo`;o00002Oooool2
o`0000kooooo0ol00004ooooo`Co00000_ooool2o`0000Sooooo0_l00005oooooaSo000000?ooooo
o`000?l000000_l000000ooooooo0000o`000002ooooo`;o00001Oooool5o`000003ooooool0003o
000000Sooooo0_l000000ooooooo0000o`00000;o`0000;ooooo0_l00005ooooo`;o00000_ooool2
o`0000Cooooo0_l00003ooooo`;o00002?ooool2o`0000?ooooo1?l00002ooooo`;o0000C_ooool0
01cooooo00?o0000ooooooooool0<_ooool2o`0000Wooooo0_l0000;ooooo`;o000000?oooooo`00
0?l000006_ooool4o`0000oooooo0_l00004ooooo`[o00000_ooool>o`000003ooooool0003o0000
00;o00001?ooool2o`0000Kooooo0_l00003ooooo`?o00000_ooool2o`0000;ooooo0ol000000ooo
oooo0000o`000008o`0000Cooooo0_l00006ooooo`;o00006_ooool4o`0000oooooo0_l00002oooo
o`;o0000?oooool001cooooo00?o0000ooooooooool0<_ooool2o`0000Wooooo0_l00002ooooo`;o
00001?ooool2o`000004ooooool0003o0000ooooo`;o00006Oooool5o`0001Gooooo2_l000000ooo
oooo0000o`00000Bo`00017ooooo0ol00002oooooa?o00000oooool3o`0001?ooooo0_l00007oooo
o`;o00000oooool4o`0000oooooo0_l00002ooooo`;o0000?oooool001cooooo0_l00012ooooo`;o
00001?ooool2o`0000Sooooo0ol00002ooooo`;o00001_ooool2o`0000?ooooo1?l000000ooooooo
0000o`000004o`0000Oooooo0_l00007ooooo`;o000000?oooooo`000?l000002Ol000000ooooooo
0000o`00000@o`000003ooooool0003o000001Gooooo4ol00004ooooo`;o00000oooool2o`0000[o
oooo0_l00002ooooo`;o00001oooool3o`0000Cooooo0_l0001Dooooo`007?ooool00ol0003ooooo
ooooo`11ooooo`;o00002_ooool2o`0000;ooooo0ol00002ooooo`;o00000_ooool8o`000003oooo
ool0003o000000;o000000?oooooo`000?l000001?l00007ooooo`;o00001ooooolMo`0000Gooooo
1ol0000;ooooo`;o000000?oooooo`000?l000005?l00002ooooo`;o00001?ooool2o`0000[ooooo
0_l0000<ooooo`;o00007?ooool2o`0000Sooooo0_l0000booooo`007?ooool00ol0003ooooooooo
o`11ooooo`;o00001Oooool2o`0000;ooooo1Ol000000ooooooo0000o`000006ooooo`Co00000_oo
ool2o`0001Kooooo0_l00003ooooo`;o000000?oooooo`000?l000006Ol00003ooooo`Wo00002ooo
ool2o`000003ooooool0003o000001[o00001oooool2o`0000;ooooo0_l000000ooooooo0000o`00
000Gooooo`;o00002?ooool2o`0000Oooooo0ol00007ooooo`;o0000<_ooool001cooooo00?o0000
ooooooooool0B?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000=ooooo`;o00001?ooool2
o`0000?ooooo0_l00009ooooo`?o000000?oooooo`000?l000000ooooolLo`000003ooooool0003o
000000;ooooo0_l0000>ooooo`;o00000oooool4o`000003ooooool0003o000001So000000?ooooo
o`000?l000000oooool6o`0001[ooooo0_l00008ooooo`;o00002?ooool2o`0003_ooooo000Loooo
o`03o`000?oooooooooo04kooooo0_l000000ooooooo0000o`00000;ooooo`;o00001?ooool2o`00
00?ooooo1?l00007ooooo`?o00001?ooool@o`000003ooooool0003o000000_o000000?oooooo`00
0?l000001_ooool2o`0000Sooooo1?l00003ooooo`Go000000Goooooo`000?l0003o0000ooooo`0H
o`0000Gooooo0_l0001]ooooo`007?ooool00ol0003oooooooooo`17ooooo`;o00001Oooool2o`00
0003ooooool0003o000000gooooo0_l00007ooooo`Ko00002?ooool2o`0000;ooooo0_l00004oooo
o`Ko00000_ooool@o`0000Wooooo0_l000000ooooooo0000o`000005ooooo`;o00002?oooolPo`00
01Cooooo0_l0000>ooooo`;o0000COooool001cooooo00?o0000ooooooooool0:_ooool2o`0000Go
oooo0ol0000:ooooo`;o000000?oooooo`000?l000000_ooool4o`0001Oooooo0_l0000;ooooo`;o
000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000Sooooo6?l0000<ooooo`;o
00001Oooool2o`0000Oooooo4Ol000000ooooooo0000o`00000?o`0000;ooooo0_l0000>ooooo`;o
00003_ooool2o`0000Oooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0Zooooo`;o0000
1Oooool3o`0000Wooooo0ol000000ooooooo0000o`000002ooooo`;o000000Coooooo`000?l0003o
00003Oooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o00002Oooool2o`0000;o
oooo0_l0000;oooooaKo00004Oooool2o`0000;ooooo0_l00005ooooob;o000000Goooooo`000?l0
003o0000ooooo`04o`0000Gooooo0_l00005ooooo`;o00002Oooool4o`0000Kooooo0ol000000ooo
oooo0000o`000014ooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00002oooool2o`0000;o
oooo0_l00002ooooo`;o000000Coooooo`000?l0003o00003Oooool2o`000003ooooool0003o0000
00;ooooo0_l00004ooooo`;o00000oooool2o`0000Wooooo0_l00002ooooo`;o00001ooooolFo`00
00Kooooo0_l00008ooooo`;o00002OoooolRo`0000;ooooo0_l000000ooooooo0000o`000002o`00
00Gooooo0_l00005ooooo`;o00002Oooool6o`0000Cooooo0ol00017ooooo`007?ooool00ol0003o
ooooooooo`0`ooooo`;o00003_ooool3o`0000;ooooo0_l0000Gooooo`;o00002_ooool2o`0000Go
oooo0_l00002ooooo`Ko00002?oooolEo`0000?ooooo0_l000000ooooooo0000o`00000Eooooo`;o
000000?oooooo`000?l000006Ol00004ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Wo
oooo0_l00004ooooo`Oo000000?oooooo`000?l000002Oooool2o`0004?ooooo000Looooo`03o`00
0?oooooooooo043ooooo0_l0000<ooooo`Co00000_ooool2o`0000;ooooo0ol00003ooooo`;o0000
1_ooool2o`0000Wooooo0_l00003ooooo`Co00001OoooolGo`0000;ooooo0_l000001?oooooo0000
o`000?ooool2o`0000Oooooo0_l000000ooooooo0000o`00000:oooooako00002?ooool2o`000004
ooooool0003o0000o`0000Sooooo0ol00004ooooo`Ko00003Oooool2o`0000Wooooo0_l0000hoooo
o`007?ooool00ol0003oooooooooo`15ooooo`;o00001oooool4o`0000;ooooo0_l00002ooooo`?o
00002oooool4o`0000cooooo0_l00007oooooaKo00000oooool2o`0000Cooooo0_l00003ooooo`Ko
000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l000000ooooooo0000o`00000Lo`000003
ooooool0003o000000;o000000?oooooo`000?l000000_l000000ooooooo0000o`000009ooooo`;o
00001?ooool3o`0001[ooooo1?l00003ooooo`;o0000<oooool001cooooo00?o0000ooooooooool0
AOooool2o`0001Gooooo0_l00009ooooo`?o00003?ooool4o`0000Gooooo4ol00004ooooo`;o0000
1_ooool2o`000003ooooool0003o000000Ko00001Oooool2o`0000?ooooo0ol000000ooooooo0000
o`00000:o`000003ooooool0003o000000Go000000?oooooo`000?l000001?l00003ooooo`Oo0000
5?ooool2o`0000Gooooo0_l0000<ooooo`;o00001_ooool2o`0000Gooooo0_l0000cooooo`007?oo
ool00ol0003oooooooooo`15ooooo`;o00003_ooool2o`0000Gooooo0_l0000Jooooo`;o00001Ooo
ool5o`000003ooooool0003o000000[o00001Oooool2o`0000Cooooo1?l000001Ooooooo0000o`00
0?l0003ooooo00Co00002oooool2o`000003ooooool0003o000000Co000000?oooooo`000?l00000
0_l000000ooooooo0000o`00000<o`0000;ooooo0_l000000ooooooo0000o`000003o`0001cooooo
0_l00004ooooo`;o00001_ooool2o`0004;ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGo
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0oooooo`;o
00001Oooool2o`0000Wooooo0_l00002ooooo`;o00004oooool2o`0000Wooooo0_l00008ooooo`Go
000000?oooooo`000?l000001?ooool2o`0000?ooooo0_l00007ooooo`;o000000Coooooo`000?l0
003ooooo0_l0000Eoooooaoo00000_ooool2o`0001Wooooo0_l00002ooooo`;o00001Oooool7o`00
013ooooo0_l0000cooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo03gooooo1?l00004ooooo`?o00002Oooool4
o`0001;ooooo0_l000000ooooooo0000o`000002o`0000Oooooo0_l00007ooooo`Oo000000?ooooo
o`000?l000001Ol00003ooooo`?o00001_ooool2o`0000Cooooo0_l00002ooooo`;o000000?ooooo
o`000?l000000_ooool2o`0000?ooooo0_l00002ooooob;o00000_ooool3o`0000gooooo0_l00009
ooooo`;o00000_ooool2o`0000Kooooo1_l00002ooooo`;o00003?ooool2o`0003?ooooo00000ooo
oooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006ooooo`03o`000?oooooooooo
03gooooo0_l00005ooooo`?o00002_ooool4o`000003ooooool0003o000000Co00001_ooool4o`00
0004ooooool0003o0000ooooo`Co00002_ooool2o`0000Cooooo0_l000000ooooooo0000o`000002
o`000003ooooool0003o000000Oo00000_ooool2o`0000?ooooo0_l0000;ooooo`;o000000Gooooo
o`000?l0003o0000ooooo`02o`0000?ooooo0_l00002ooooob;o00000_ooool3o`0000gooooo0_l0
0006ooooo`;o00001oooool2o`0000;ooooo0_l000001?oooooo0000o`000?l00004ooooo`;o0000
@Oooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?m4A4CogMgMoooo
ool00007ooooo`?o0000A?ooool2o`0000Oooooo0_l00002ooooo`_o00001_ooool4o`0000Gooooo
0_l00009ooooo`Co00001?ooool3o`0000Kooooo2?l00007ooooo`;o00001?ooool2o`0000;ooooo
0_l00005ooooo`?o00001?ooool2o`000003ooooool0003o000000;ooooo8?l000000ooooooo0000
o`00000Gooooo`;o00001oooool2o`0000;ooooo1_l00017ooooo`0000?oooooo`000?ooool00_oo
ool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0
COooool2o`0000?ooooo1?l0000@ooooo`Co00002_ooool4o`0000Oooooo0_l000000ooooooo0000
o`000003ooooo`Go00001Oooool2o`0000Wooooo1_l00006ooooo`?o00000oooool2o`000003oooo
ool0003o000000;ooooo1_l000000ooooooo0000o`00000Jo`0000Cooooo0_l00002ooooo`;o0000
3Oooool2o`0000Kooooo1?l00003ooooo`;o00005_ooool2o`000003ooooool0003o000002kooooo
00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oMgMgolc<c?l000001ooo
ool00ol0003oooooooooo`0aooooo`;o00002_ooool2o`0002Kooooo1Ol00002ooooo`;o00001_oo
ool2o`0000cooooo0_l00006ooooo`;o00001Oooool2o`0000Wooooo1?l00009ooooo`;o00000ooo
ool2o`0000Kooooo1?l00002oooooaCo000000?oooooo`000?l000000ol00006ooooo`;o00000_oo
ool2o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`0000Kooooo1?l0000=ooooo`;o00003?oo
ool5o`0002kooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l00000
1oooool00ol0003oooooooooo`0aooooo`;o00002Oooool3o`0000cooooo0_l0000Hooooo`;o0000
1Oooool2o`0002Sooooo0_l00004ooooo`;o000000?oooooo`000?l000003Oooool2o`0000Kooooo
1?l00002oooooa7o000000Coooooo`000?l0003ooooo0_l0000:ooooo`;o00001Oooool2o`0000Go
oooo0_l000000ooooooo0000o`000002o`0001Kooooo0_l0000=ooooo`;o0000<?ooool00006oooo
ooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo
03cooooo0_l0000=ooooo`;o00008_ooool2o`0000_ooooo0_l0000=ooooo`;o00002Oooool2o`00
00Gooooo1?l00004ooooo`;o00000_ooool2o`0000_ooooo5ol0000@ooooo`;o00003oooool4o`00
00;ooooo0_l00007ooooo`;o000000?oooooo`000?l000001Oooool2o`0000;ooooo0_l0000loooo
o`007?ooool00ol0003oooooooooo`0_ooooo`;o00002_ooool2o`0000?ooooo0ol0000@ooooo`?o
00001Oooool2o`0000Oooooo1?l00007ooooo`Co00001?ooool2o`0000?ooooo0_l00008ooooo`;o
00000oooool2o`0000Gooooo0_l00003ooooo`;o00001?ooool3o`0000Gooooo0_l00002ooooo`;o
00000_ooool2o`0000Oooooo1_l000001?oooooo0000o`000?ooool5o`000003ooooool0003o0000
00Go00000_ooool4o`0000;ooooo0_l00006ooooo`;o00005Oooool2o`0000Cooooo0_l000001?oo
oooo0000o`000?ooool2o`0000?ooooo1?l00002ooooo`;o0000??ooool001cooooo00?o0000oooo
ooooool0;oooool2o`0000[ooooo0_l00003ooooo`?o00000oooool2o`0000_ooooo0ol00005oooo
o`;o00000_ooool2o`0000?ooooo1?l000001?oooooo0000o`000?l00005ooooo`;o00001?ooool2
o`0000gooooo0_l0000:ooooo`;o00000oooool2o`0000Gooooo0_l00007ooooo`?o00000oooool2
o`0000Cooooo0_l00003ooooo`Co000000Coooooo`000?l0003ooooo2?l00002ooooo`?o00000_oo
ool4o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`0001Cooooo0_l0
00000ooooooo0000o`000009ooooo`;o00001oooool2o`0003Wooooo000Looooo`03o`000?oooooo
oooo04?ooooo0_l000000ooooooo0000o`000004ooooo`;o00003?ooool2o`0000?ooooo0ol00007
ooooo`?o00002_ooool2o`0000Sooooo0_l0000Qooooo`;o00000_ooool3o`0000?ooooo0_l00004
ooooo`;o00000oooool3o`0000Gooooo1ol000000ooooooo0000o`000004o`0000Cooooo0_l00003
ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`0001;ooooo1_l00002ooooo`;o00002_oo
ool2o`0000?ooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`0Uooooo`;o00004oooool2
o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool4o`0000Gooooo0_l00005
ooooo`;o00001?ooool2o`0001Cooooo0_l00008ooooo`;o00008Oooool2o`0000[ooooo0ol00002
ooooo`;o00002_ooool6o`0000;ooooo0_l00002ooooo`;o00001?ooool2o`0000?ooooo0_l00002
ooooo`;o00001?ooool2o`0000?ooooo1?l0000;ooooo`;o000000Coooooo`000?l0003o00000_oo
ool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o0000?_ooool001cooooo00?o0000
ooooooooool09Oooool2o`0001?ooooo0_l000000ooooooo0000o`000002o`0000Wooooo0_l00007
ooooo`;o0000@Oooool2o`0000oooooo1_l00002ooooo`?o00000_ooool2o`0000Sooooo2_l00004
ooooo`;o00002?ooool2o`0000?ooooo0_l00009ooooo`Co00002_ooool2o`0000;ooooo0_l00006
ooooo`Co000000?oooooo`000?l000003Oooool2o`0003?ooooo000Looooo`03o`000?oooooooooo
03cooooo1?l000001?oooooo0000o`000?l0000>ooooo`?o00000oooool2o`0002Oooooo0_l0000;
ooooo`;o00001_ooool2o`000003ooooool0003o000000Gooooo1?l00003ooooo`Ko00004Oooool6
o`0000;ooooo0_l00004ooooo`;o00000oooool7o`0000?ooooo0_l00002ooooo`Co00004Oooool4
o`0000?ooooo0_l00003ooooo`;o00000_ooool2o`0000Cooooo0_l00008ooooo`Co0000<Oooool0
01cooooo00?o0000ooooooooool0=_ooool2o`0000Cooooo1?l000001Ooooooo0000o`000?l0003o
oooo00Co00002Oooool3o`0000?ooooo0_l0000Kooooo`Go00001oooool2o`0000_ooooo0_l00009
ooooo`;o00001Oooool4o`0000?ooooo0_l00002ooooo`;o00006?ooool2o`0000Sooooo1ol00002
ooooo`;o00001Oooool4o`0001?ooooo0_l00003ooooo`;o000000?oooooo`000?l000001?ooool2
o`000004ooooool0003o0000ooooo`;o00002_ooool2o`00037ooooo000Looooo`03o`000?oooooo
oooo02Kooooo0_l00009ooooo`Co000000?oooooo`000?l000002_ooool2o`000003ooooool0003o
000000;o00001?ooool2o`0000Cooooo0_l0000Gooooo`?o00001?ooool7o`0001;ooooo0_l00007
ooooo`;o00005oooool2o`00013ooooo0_l00003ooooo`?o00001oooool3o`0000;ooooo0_l00002
ooooo`;o00002_ooool2o`0001Gooooo0_l000000ooooooo0000o`000004ooooo`;o000000Cooooo
o`000?l0003ooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0Vooooo`;o00002Oooool4
o`000004ooooool0003o0000ooooo`;o00001oooool5o`0000Kooooo0_l00004ooooo`;o00000ooo
ool2o`0000?ooooo0_l0000;ooooo`Go00001?ooool2o`0000Kooooo0_l00007ooooo`;o00000_oo
ool2o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0001Oooooo0_l0000@ooooo`;o00000ooo
ool3o`0000Sooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00001?ooool2o`000004oooo
ool0003o0000ooooo`;o00005Oooool2o`0000Kooooo0_l00005ooooo`;o0000?Oooool001cooooo
00?o0000ooooooooool0<_ooool2o`000005ooooool0003o0000o`000?ooool01?l00007ooooo`?o
00003?ooool2o`0000?ooooo0_l00003ooooo`;o00002_ooool7o`000003ooooool0003o000000;o
00001_ooool2o`0000Oooooo0_l00002ooooo`;o00000_ooool6o`0000;ooooo0_l0000Hooooo`;o
00000oooool2o`0000[ooooo0_l0000Booooo`?o00001?ooool2o`0000;ooooo0_l000001?oooooo
0000o`000?ooool2o`0000;ooooo0_l00003ooooo`;o00004?ooool2o`0000;ooooo0_l00006oooo
o`;o00001oooool4o`00037ooooo000Looooo`03o`000?oooooooooo03;ooooo0_l000001Ooooooo
0000o`000?l0003ooooo00Go00005?ooool2o`0001?ooooo4?l0000<ooooo`;o00001oooool4o`00
00Cooooo0_l0000=ooooo`;o00002Oooool2o`0000?ooooo0_l0000:ooooo`;o00004?ooool2o`00
0003ooooool0003o000000;ooooo1?l00008ooooo`;o00000_ooool2o`0000?ooooo0_l0000@oooo
o`;o00002_ooool2o`0000Gooooo2Ol0000^ooooo`007?ooool2o`0003Kooooo0_l00002ooooo`;o
000000?oooooo`000?l000005?ooool2o`0000oooooo0_l00002oooooa;o00002_ooool2o`0001Go
oooo0_l00004ooooo`;o000000?oooooo`000?l000001Oooool4o`00017ooooo0_l00007ooooo`;o
00001_ooool3o`0000Gooooo0ol000000ooooooo0000o`00000Vooooo`;o00003?ooool2o`0000Co
oooo0ol0000^ooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00001oooool2o`0000Gooooo
0_l0000;ooooo`;o00003_ooool2o`0000;ooooo5?l00003ooooo`;o00006_ooool2o`0000Cooooo
1?l00006ooooo`Co00004Oooool2o`0000Oooooo0_l00006ooooo`?o000000?oooooo`000?l00000
0_ooool2o`0000;ooooo0_l0000Nooooo`?o00001Oooool2o`0000?ooooo0_l0000nooooo`007?oo
ool00ol0003oooooooooo`0[ooooo`;o00002Oooool2o`0000Oooooo0ol00004ooooo`;o00002ooo
ool2o`0000Gooooo0_l00007ooooo`Wo00000_ooool=o`0000?ooooo0_l000000ooooooo0000o`00
0005ooooo`;o00006?ooool2o`0001_ooooo0_l000000ooooooo0000o`00000=ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0000Kooooo0_l00009ooooo`Co00003Oooool3o`0000Sooooo1?l0
00000ooooooo0000o`00000kooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o00003oooool2
o`000004ooooool0003o0000o`0000;ooooo0ol000000ooooooo0000o`00000;ooooo`;o000000?o
ooooo`000?l000000_l00006ooooo`[o00000_ooool>o`0000Cooooo0ol00005ooooo`;o00002ooo
ool2o`0001_ooooo0_l0000>ooooo`;o00004Oooool2o`000003ooooool0003o000000Kooooo0_l0
0009ooooo`Co00006?ooool2o`0000?ooooo1Ol00006ooooo`;o0000<?ooool001cooooo00?o0000
ooooooooool0??ooool2o`000003ooooool0003o000000?ooooo0ol000000ooooooo0000o`00000;
ooooo`;o000000?oooooo`000?l000001_oooolEo`000003ooooool0003o000000Go00000oooool2
o`0000[ooooo0_l00007ooooo`;o00000_ooool4o`0000Oooooo0_l0000:ooooo`Co00000oooool2
o`0001cooooo0ol000001?oooooo0000o`000?l0000Uooooo`;o00001?ooool2o`0000Cooooo1?l0
0006ooooo`;o000000?oooooo`000?l00000;Oooool001cooooo00?o0000ooooooooool0AOooool2
o`000003ooooool0003o000000Wooooo1?l00009oooooago00000oooool4o`0000Oooooo0ol00009
ooooo`Ko00001oooool2o`0000[ooooo0_l00004ooooo`?o000000?oooooo`000?l000000_ooool3
o`0000;ooooo0_l0000Aooooo`Ko00009Oooool2o`0000Cooooo0_l0000<ooooo`;o00000oooool2
o`0002gooooo000Looooo`03o`000?oooooooooo04Cooooo1_l00003ooooo`?o00000oooool4o`00
00Wooooo0_l000000ooooooo0000o`000006o`0000?ooooo4?l00004ooooo`;o00001oooool2o`00
00[ooooo0_l0000Kooooo`Co00000_ooool2o`0000;ooooo0ol00002ooooo`;o00000_ooool2o`00
00oooooo0_l0000Xooooo`;o00002oooool2o`0000Cooooo0_l0000booooo`007?ooool00ol0003o
ooooooooo`14ooooo`Co00001Oooool3o`0001?ooooo0_l000000ooooooo0000o`00000Fo`0000go
oooo0_l00006ooooo`;o00001Oooool2o`0000oooooo1?l00004ooooo`?o000000?oooooo`000?l0
00001_ooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l00000=_ooool2o`0000_o
oooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0looooo`;o00003oooool2o`0000?ooooo
0ol0000=oooooaWo000000?oooooo`000?l000002Oooool2o`000003ooooool0003o000000Oooooo
0_l00005ooooo`;o00000oooool2o`0000[ooooo1?l00004ooooo`;o00000_ooool2o`0000Kooooo
0_l00002ooooo`Co00000oooool2o`0001;ooooo0_l0000:ooooo`;o00008Oooool4o`0003Sooooo
000Looooo`03o`000?oooooooooo03Cooooo0_l00006ooooo`;o00003oooool2o`0000?ooooo0ol0
000<oooooago00002Oooool2o`000003ooooool0003o000000Oooooo0_l00002ooooo`;o00001_oo
ool2o`000003ooooool0003o000000Kooooo0_l0000Cooooo`;o00001?ooool2o`0001Oooooo0_l0
000:ooooo`Co00007oooool2o`0000Gooooo0_l00003ooooo`;o0000;_ooool001cooooo00?o0000
ooooooooool0=?ooool2o`0000[ooooo0_l0000Noooooako00001?ooool2o`0000gooooo1?l00002
ooooo`Co00000oooool2o`0000;ooooo0_l00006ooooo`;o00001_ooool2o`0000?ooooo0_l00002
ooooo`;o00001_ooool2o`0002Oooooo0_l0000Mooooo`;o00001oooool2o`0000?ooooo0_l0000^
ooooo`007?ooool00ol0003oooooooooo`0_ooooo`?o00000_ooool2o`000003ooooool0003o0000
00Oooooo0_l0000;ooooo`;o00004Oooool=o`000003ooooool0003o000000go000000Coooooo`00
0?l0003ooooo0ol00008ooooo`;o00000_ooool5o`0000;ooooo1?l00002ooooo`?o00001?ooool2
o`0000cooooo1?l000000ooooooo0000o`000002ooooo`Co00001?ooool2o`0000;ooooo0_l0000F
ooooo`;o00002Oooool2o`0001?ooooo0ol00009ooooo`;o0000??ooool001cooooo00?o0000oooo
ooooool0;oooool3o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`;o00003?ooool3o`00
01;ooooo5?l000000ooooooo0000o`000004o`0000;ooooo1Ol00009ooooo`;o000000Goooooo`00
0?l0003o0000ooooo`06o`0000Cooooo0_l00005ooooo`Go000000?oooooo`000?l000001oooool3
o`0000Oooooo0ol00006ooooo`?o00005_ooool2o`0000Sooooo0ol0000Cooooo`?o00001?ooool2
o`00047ooooo000Looooo`03o`000?oooooooooo03Cooooo0_l00006ooooo`Co00003?ooool2o`00
00Cooooo0_l00009ooooo`;o000000?oooooo`000?l000001ol000000ooooooo0000o`00000@o`00
00?ooooo0_l0000>ooooo`;o00001?ooool2o`0000cooooo0_l000001Ooooooo0000o`000?l0003o
oooo00;o00001?ooool2o`000003ooooool0003o000000Wooooo0_l00006ooooo`;o00003oooool3
o`0000Gooooo0_l00002ooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`;o00005Ooo
ool2o`0000Oooooo0_l00005ooooo`;o0000<Oooool001cooooo00?o0000ooooooooool0;oooool2
o`0000Kooooo0_l00003ooooo`;o00005?ooool2o`000003ooooool0003o000000Cooooo1?l00000
0ooooooo0000o`00000Jo`0000_ooooo0_l00006ooooo`;o00001?ooool2o`0000Gooooo0_l00002
ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Gooooo0_l000000ooooooo0000o`00000:
ooooo`;o00005_ooool3o`0000Gooooo0_l00002ooooo`;o00001oooool2o`000003ooooool0003o
000001gooooo0ol00005ooooo`;o0000<Oooool001cooooo00?o0000ooooooooool0;oooool2o`00
00Kooooo0_l0000@ooooo`Go00001oooool2o`0000Cooooo0_l00003oooooaSo00000_ooool3o`00
00[ooooo0_l00006ooooo`;o00001?ooool2o`0000Gooooo0_l00002ooooo`;o000000?oooooo`00
0?l000001?ooool2o`0001Cooooo0_l0000>ooooo`;o00006_ooool2o`0001gooooo0_l00002oooo
o`;o0000>Oooool001cooooo0_l0000aooooo`;o00005oooool5o`0000kooooo0_l000000ooooooo
0000o`00000Lo`000003ooooool0003o000000Wooooo0_l0000Booooo`;o00000_ooool2o`0000Ko
oooo0_l00007ooooo`;o00006?ooool2o`000003ooooool0003o000000Wooooo0_l0000?ooooo`;o
00006_ooool2o`000003ooooool0003o000000;ooooo0_l0000iooooo`007?ooool00ol0003ooooo
ooooo`0`ooooo`;o00004_ooool2o`000003ooooool0003o000001?ooooo0_l000000ooooooo0000
o`00000Co`000003ooooool0003o000000Ko000000?oooooo`000?l000000_l00007ooooo`;o0000
3oooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000003ooooo`?o0000
1_ooool2o`0000;ooooo0_l0000Dooooo`;o00001Oooool2o`0000Gooooo1?l00002ooooo`;o0000
1oooool2o`000003ooooool0003o000001Sooooo0ol00010ooooo`007?ooool00ol0003ooooooooo
o`0jooooo`;o00000_ooool4o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00001_oo
ool2o`0000[ooooo6ol000000ooooooo0000o`000003ooooo`;o00002?ooool2o`0000kooooo0_l0
0005ooooo`;o000000?oooooo`000?l000001?ooool2o`0000[ooooo0_l00003ooooo`;o00000ooo
ool2o`000004ooooool0003o0000ooooo`;o00002oooool2o`0000Oooooo0_l00002ooooo`;o0000
1oooool2o`000004ooooool0003o0000ooooo`;o00005Oooool2o`0000Cooooo0_l0000kooooo`00
7?ooool00ol0003oooooooooo`0jooooo`;o00000_ooool4o`0000Wooooo0_l000000ooooooo0000
o`000003ooooo`?o00001?ooool2o`0000Cooooo3Ol000000ooooooo0000o`00000:o`0000Gooooo
0_l00002ooooo`;o00001Oooool2o`0000;ooooo0_l0000Aooooo`;o00005_ooool4o`0000;ooooo
2Ol0000Wooooo`;o00004?ooool2o`0000Wooooo0ol0000jooooo`007?ooool00ol0003ooooooooo
o`0hooooo`;o00001?ooool2o`0000kooooo0_l00004ooooo`;o00001?ooool2o`0000Cooooo6_l0
0005ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o00000ooo
ool2o`0000[ooooo0_l00009ooooo`?o00000oooool2o`0000Oooooo0_l00004ooooo`Go000000?o
ooooo`000?l000009_ooool4o`00013ooooo0_l000000ooooooo0000o`000007ooooo`;o0000>_oo
ool001cooooo00?o0000ooooooooool0>?ooool2o`0000Cooooo0_l00005ooooo`;o00000oooool2
o`0000;ooooo0_l00004ooooo`;o00001?ooool3o`0000?ooooo6_l0000<ooooo`;o00000_ooool2
o`0000Oooooo0_l0000:ooooo`;o00000_ooool2o`0000Gooooo1Ol000000ooooooo0000o`000003
ooooo`;o00001_ooool2o`0000Gooooo0_l00008ooooo`Co00002_ooool2o`0000Cooooo0_l00009
ooooo`Co00004oooool2o`0000?ooooo0_l00002ooooo`;o0000>_ooool001cooooo00?o0000oooo
ooooool0<Oooool2o`0000Gooooo0_l00005ooooo`;o00000_ooool4o`0000?ooooo0_l00008oooo
o`;o00001?ooool3o`0000?ooooo3Ol000000ooooooo0000o`00000:o`0001Cooooo0_l00006oooo
o`;o00002oooool2o`0000Gooooo0_l000000ooooooo0000o`000004ooooo`Co00001_ooool2o`00
00Cooooo0ol00005ooooo`Oo00002_ooool4o`0000;ooooo0ol0000Looooo`;o00001_ooool2o`00
00Oooooo0_l0000eooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00001Oooool2o`0000Go
oooo0_l00002ooooo`Co00001?ooool2o`0000Cooooo1?l0000:ooooo`?o000000?oooooo`000?l0
00002?l000000ooooooo0000o`000008o`0000?ooooo2?l0000;ooooo`;o00001Oooool3o`0000oo
oooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000?o000000?oooooo`000?l0
00001_l00002ooooo`;o000000?oooooo`000?l000001?ooool5o`00013ooooo0_l00003ooooo`;o
000000?oooooo`000?l000002?ooool2o`0000oooooo0_l0000?ooooo`;o0000=Oooool001cooooo
00?o0000ooooooooool0Boooool2o`0000;ooooo1_l0000:ooooo`?o000000?oooooo`000?l00000
2Ol000000ooooooo0000o`000006o`000004ooooool0003o0000ooooo`So00000_ooool2o`0000ko
oooo0_l00005ooooo`;o000000?oooooo`000?l000001_ooool2o`0000?ooooo6?l000000ooooooo
0000o`000002ooooo`;o00006oooool2o`0000Sooooo0_l0000Eooooo`;o00001?ooool2o`0000;o
oooo0ol0000eooooo`007?ooool00ol0003oooooooooo`0gooooo`;o000000?oooooo`000?l00000
2oooool6o`0000;ooooo1?l00005ooooo`;o00001Oooool2o`0000Kooooo2_l00002ooooo`Co0000
00?oooooo`000?l000002oooool2o`0000cooooo0ol00005ooooo`So00002oooool4o`0000;ooooo
0_l000001?oooooo0000o`000?l00002ooooo`So000000?oooooo`000?l000000_ooool2o`0000;o
oooo0ol0000gooooo`;o00000oooool3o`0000;ooooo0ol0000eooooo`007?ooool00ol0003ooooo
ooooo`0gooooo`;o000000?oooooo`000?l000002Oooool8o`0000Gooooo0_l00004ooooo`;o0000
1Oooool2o`0000Cooooo1_l000000ooooooo0000o`000002o`0000Wooooo0_l00002ooooo`;o0000
3oooool2o`0000?ooooo1Ol00003ooooo`Co00000_ooool4o`0000Cooooo0_l00002ooooo`;o0000
1_ooool2o`000003ooooool0003o000000;ooooo0_l000001?oooooo0000o`000?l00003ooooo`?o
00000oooool5o`0002Wooooo0_l0000>ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o
0000=Oooool001cooooo00?o0000ooooooooool0=_ooool2o`0000Cooooo0_l00007ooooo`;o0000
0oooool2o`0000Kooooo1?l00009ooooo`;o00001?ooool2o`000005ooooool0003o0000o`000?oo
ool00ol00003ooooo`;o00001Oooool2o`0000;ooooo0_l00003ooooo`;o00002Oooool3o`0000?o
oooo1Ol00008ooooo`;o000000?oooooo`000?l000001?ooool2o`000005ooooool0003o0000o`00
0?ooool01ol000000ooooooo0000o`000004o`000003ooooool0003o000000?ooooo2Ol0000@oooo
o`;o00002?ooool2o`0000?ooooo0_l00002ooooo`;o00001oooool2o`0000kooooo0_l00003oooo
o`?o0000>?ooool001cooooo00?o0000ooooooooool0=?ooool4o`0000Cooooo0_l00007ooooo`;o
00002?ooool2o`000003ooooool0003o000000;o00001?ooool2o`0000Cooooo0ol000000ooooooo
0000o`000003ooooo`;o00000_ooool2o`0000?ooooo0_l00005ooooo`;o00001oooool2o`0000Wo
oooo1Ol000000ooooooo0000o`00000;ooooo`;o00001_ooool3o`000003ooooool0003o000000;o
oooo4ol000000ooooooo0000o`000006o`0000?ooooo0_l00009ooooo`;o000000?oooooo`000?l0
00001oooool3o`0000?ooooo0_l00002ooooo`;o00004?ooool2o`0000Oooooo0_l000001?oooooo
0000o`000?l0000hooooo`007?ooool00ol0003oooooooooo`0dooooo`;o00004oooool2o`0000Co
oooo0_l000000ooooooo0000o`000002o`0000Cooooo1?l00002ooooo`Ko00001Oooool4o`0000Co
oooo0_l00007ooooo`;o00000_ooool2o`000004ooooool0003o0000o`0000Sooooo1?l0000=oooo
o`;o00001oooool7o`000003ooooool0003o000000?o00000_ooool3o`000003ooooool0003o0000
00Wo000000?oooooo`000?l000000_l00004ooooo`;o00002Oooool2o`0000[ooooo0ol00003oooo
o`;o000000?oooooo`000?l000001Oooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool2
o`0000Oooooo0_l000000ooooooo0000o`00000iooooo`007?ooool00ol0003oooooooooo`19oooo
o`;o000000?oooooo`000?l000001?ooool4o`0000Cooooo1?l00003ooooo`?o00001?ooool2o`00
0003ooooool0003o000000Gooooo0ol00004ooooo`;o000000?oooooo`000?l000000_ooool2o`00
0003ooooool0003o000000;o00001oooool2o`0000Cooooo1?l00007ooooo`Co00001oooool;o`00
0003ooooool0003o000000;o000000?oooooo`000?l000002Ol000000ooooooo0000o`000002oooo
o`;o00003Oooool2o`0000_ooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o0000
00Gooooo1?l00002ooooo`;o000000?oooooo`000?l000001_ooool4o`000003ooooool0003o0000
03_ooooo000Looooo`03o`000?oooooooooo02oooooo0_l0000Hooooo`;o000000?oooooo`000?l0
00003?ooool2o`0000Gooooo0_l00005ooooo`;o00000oooool3o`0000;ooooo0ol00004ooooo`;o
00002?ooool4o`0000Gooooo0_l00006ooooo`Go00002?ooool2o`0000Oooooo0_l00002ooooo`Oo
000000?oooooo`000?l000000_l000000ooooooo0000o`00000<o`0000;ooooo0_l00009ooooo`;o
00004_ooool2o`0000cooooo0_l00005ooooo`;o00000oooool2o`000003ooooool0003o000000;o
000000Coooooo`000?l0003o0000>_ooool001cooooo0_l0000`ooooo`Co00003oooool2o`0000;o
oooo0_l00005ooooo`;o00004_ooool4o`0000Oooooo1?l0000Gooooo`;o00000oooool2o`0000So
oooo0ol0000?ooooo`Co000000Coooooo`000?l0003ooooo1Ol00002oooooa;o00002?ooool2o`00
00?ooooo0_l0000Aooooo`;o00003?ooool2o`0000_ooooo0_l00007ooooo`?o00001?ooool2o`00
03?ooooo000Looooo`03o`000?oooooooooo02oooooo1?l00009ooooo`;o00001?ooool3o`000003
ooooool0003o000000Gooooo0_l00008ooooo`;o00002_ooool2o`0000Oooooo0_l0000;ooooo`;o
00001?ooool2o`0000Gooooo0ol00007ooooo`;o00001?ooool3o`0000Kooooo0_l000000ooooooo
0000o`000004ooooo`;o00000ooooolLo`000003ooooool0003o000000;o00000oooool2o`0000?o
oooo0_l0000Aooooo`?o00000_ooool2o`0000Oooooo0_l00005ooooo`;o000000?oooooo`000?l0
00001_ooool2o`0000?ooooo0_l00004ooooo`;o0000<oooool001cooooo00?o0000ooooooooool0
??ooool4o`0000?ooooo0_l00004ooooo`?o00002oooool2o`0000Sooooo0ol0000Eooooo`;o0000
1?ooool2o`0000Gooooo0_l00008ooooo`;o00000_ooool5o`0000Kooooo0_l000000ooooooo0000
o`000002ooooo`Co00001?oooolPo`0000Cooooo0_l00002ooooo`;o00001_ooool2o`0000[ooooo
0_l00002ooooo`;o00003_ooool2o`000003ooooool0003o000000Cooooo1?l0000nooooo`007?oo
ool00ol0003oooooooooo`0eooooo`;o00001oooool3o`000003ooooool0003o000000Gooooo0ol0
000Eooooo`?o00006oooool2o`0000;ooooo0_l00004ooooo`;o00002Oooool2o`0000cooooo0_l0
0002ooooob7o000000?oooooo`000?l000000ol00002ooooo`;o000000Coooooo`000?l0003o0000
2Oooool5o`0000kooooo0_l00005ooooo`?o00001_ooool2o`0000Cooooo0_l00004ooooo`;o0000
>_ooool001cooooo00?o0000ooooooooool0=Oooool2o`0000Sooooo0_l000000ooooooo0000o`00
0002o`0000cooooo0_l0000>ooooo`;o00000_ooool2o`0001_ooooo0_l00003ooooo`Go00001?oo
ool2o`0001Kooooo6?l000000ooooooo0000o`000008o`0000?ooooo0_l00002ooooo`?o00000ooo
ool2o`0000Gooooo0ol0000>ooooo`;o00001Oooool3o`0000?ooooo0_l000001?oooooo0000o`00
0?ooool2o`0000Oooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`12ooooo`Co00001_oo
ool2o`0000Cooooo0_l00007ooooo`;o00002Oooool2o`0000Cooooo0_l0000?ooooo`;o00000ooo
ool2o`0000Cooooo1Ol00004ooooo`;o00003Oooool2o`0000Cooooo9_l00002ooooo`?o00000_oo
ool4o`0000;ooooo0_l00006ooooo`;o00005Oooool2o`0000Cooooo0_l00002ooooo`Co000000?o
ooooo`000?l000000_l0000nooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00002_ooool4
o`0000Kooooo0_l00005ooooo`Go00001?ooool2o`000003ooooool0003o000000Cooooo1?l0000=
ooooo`;o00003oooool2o`0000?ooooo0_l00004ooooo`Co00005?ooool4o`0000;ooooo1?l00004
ooooob?o000000?oooooo`000?l000001?l000000ooooooo0000o`000004ooooo`Co00004oooool3
o`0000Wooooo0_l00003ooooo`Co0000?_ooool001cooooo00?o0000ooooooooool0;?ooool2o`00
00[ooooo1_l00004ooooo`;o000000?oooooo`000?l000000_ooool4o`0000Gooooo0_l000001?oo
oooo0000o`000?ooool2o`0000;ooooo0ol00005ooooo`;o00001oooool2o`0000Gooooo0_l0000V
ooooo`;o00000_ooool4o`0000?ooooo1?l000000ooooooo0000o`00000Ro`0000;ooooo0ol00000
1?oooooo0000o`000?ooool2o`0000Cooooo0_l00004ooooo`;o00000_ooool2o`0000;ooooo0_l0
0007ooooo`?o00002_ooool3o`000003ooooool0003o000000Oooooo0_l0000gooooo`007?ooool0
0ol0003oooooooooo`0Oooooo`;o00006oooool2o`0000Cooooo0_l000001Ooooooo0000o`000?l0
003ooooo00?o00002Oooool2o`000003ooooool0003o000000[ooooo0_l00007ooooo`;o000000?o
ooooo`000?l000000_ooool3o`0000_ooooo0_l00005ooooo`;o00002Oooool4o`0000Cooooo0_l0
0002ooooo`;o00000_ooool^o`000004ooooool0003o0000ooooo`?o00001Oooool2o`0000Cooooo
0ol00002ooooo`;o00000_ooool2o`0001Cooooo0ol000000ooooooo0000o`000007ooooo`;o0000
=oooool001cooooo00?o0000ooooooooool07oooool2o`0001Kooooo0_l0000=ooooo`;o00000_oo
ool2o`0002;ooooo1?l00003ooooo`;o00002oooool2o`0000Gooooo0_l00009ooooo`Co00001?oo
ool2o`0000;ooooo0_l00002oooooc3o00000oooool2o`0000Gooooo1?l00002ooooo`;o00001Ooo
ool2o`0001Kooooo1?l00012ooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00003?ooool2
o`00023ooooo0_l00005ooooo`;o00001Oooool2o`000003ooooool0003o000000?ooooo0_l0000@
ooooo`Co00000oooool2o`0000;ooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo4_l0
00000ooooooo0000o`00000Io`0000[ooooo1?l000000ooooooo0000o`000006ooooo`;o00005_oo
ool4o`0000Oooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o000000?ooooo
o`000?l000000_ooool2o`0000kooooo0_l0000Pooooo`;o00003_ooool8o`00013ooooo1?l00007
ooooo`;o00001oooool2o`0000?ooooo:_l0000Aooooo`;o00009_ooool2o`000003ooooool0003o
000003Wooooo000Looooo`03o`000?oooooooooo02kooooo0_l000000ooooooo0000o`000002oooo
o`;o00004?ooool3o`0000;ooooo0_l0000>ooooo`;o00001oooool2o`00013ooooo1_l0000>oooo
o`?o00001_ooool2o`0001?ooooo:Ol00006ooooo`;o00004?ooool2o`000003ooooool0003o0000
00kooooo0_l0000:ooooo`Co0000??ooool001cooooo00?o0000ooooooooool0<Oooool2o`0001Co
oooo0ol00002ooooo`;o00003_ooool2o`0000Oooooo0_l0000Pooooo`;o00000_ooool3o`0000Ko
oooo0_l00002ooooo`;o00001Oooool2o`0000;ooooo0_l00004ooooobWo000000?oooooo`000?l0
00000oooool2o`0000_ooooo0_l00003ooooo`Go00003_ooool2o`0000[ooooo0_l0000nooooo`00
00Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413o
c<c<00Kooooo00?o0000ooooooooool0HOooool2o`00013ooooo0_l00009ooooo`;o00001oooool2
o`0000?ooooo0_l0000:ooooo`;o00000oooool4o`0000;ooooo0_l00003ooooob[o000000Cooooo
o`000?l0003o00003Oooool4o`0000Cooooo0_l0000>ooooo`;o00002oooool2o`0003oooooo0000
1_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B401_ooool00ol0003oooooooooo`0Tooooo`;o00002oooool2o`0000Kooooo0_l0000Gooooo`;o
00001?ooool2o`0000Oooooo0_l0000@ooooo`;o00000oooool2o`0000Cooooo0_l000000ooooooo
0000o`000007ooooo`Co00001Oooool2o`0000Sooooo0_l000000ooooooo0000o`000003o`0000?o
oooo8Ol00002ooooo`Go00001?ooool2o`0000[ooooo0_l000000ooooooo0000o`000002o`0001Co
oooo0_l0000;ooooo`;o0000?oooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool0
2Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool09?ooool2o`0000Wo
oooo1?l00006ooooo`;o00004_ooool2o`000003ooooool0003o000000;o00001?ooool2o`0000go
oooo0_l00007ooooo`;o00001Oooool3o`000003ooooool0003o000000Cooooo0_l00003ooooo`;o
00000_ooool2o`0000Oooooo0_l0000;ooooo`Co00001_ooool7o`0000;ooooo7Ol00002ooooo`;o
000000?oooooo`000?l000002Oooool2o`0000?ooooo0_l0001Rooooo`0000?oooooo`000?ooool0
0_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0002oo
oooo0_l0000Fooooo`;o00001?ooool2o`000003ooooool0003o000001Gooooo0ol00006ooooo`;o
000000?oooooo`000?l000001Ol000000ooooooo0000o`000002ooooo`;o00001Oooool2o`0001Ko
oooo0_l00005ooooo`;o000000?oooooo`000?l000005ol00002ooooo`ko000000Coooooo`000?l0
003ooooo0_l00004ooooo`?o00000_ooool3o`0000Wooooo0_l0000<ooooo`;o00001_ooool2o`00
00Kooooo0_l0000Cooooo`;o0000:?ooool00003ooooool0003ooooo00;ooooo00?o0000oooooooo
ool02Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0?_ooool2o`00
00;ooooo0_l00003ooooo`;o00002?ooool2o`0001Gooooo0_l00008ooooo`_o00000_ooool2o`00
00Oooooo1?l0000Booooo`;o00001OoooolKo`0000;ooooo1_l000000ooooooo0000o`000006o`00
00Cooooo0_l00004ooooo`?o00000oooool2o`0000Wooooo0_l00003ooooo`;o00001Oooool4o`00
00Cooooo1?l00005ooooo`?o00004oooool2o`0002Sooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`0gooooo`;o
00001Oooool3o`000004ooooool0003o0000o`0000cooooo0_l0000Kooooo`;o00000_ooool;o`00
00?ooooo0_l00002ooooo`;o00000_ooool4o`0000Cooooo1?l00004ooooo`;o00003?ooool2o`00
0003ooooool0003o000001Ko000000?oooooo`000?l000003_l000000ooooooo0000o`000007oooo
o`;o00004Oooool4o`0000Gooooo0_l00005ooooo`?o00001oooool2o`0003kooooo00001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0g
ooooo`;o00000_ooool2o`0000;ooooo0ol000000ooooooo0000o`000002o`00017ooooo0_l00008
ooooo`;o00001oooool5o`0000?ooooo3?l000000ooooooo0000o`000002ooooo`;o000000?ooooo
o`000?l000000_l00005ooooo`Co00001?ooool2o`00017ooooo5_l000000ooooooo0000o`00000:
o`000005ooooool0003o0000o`000?ooool00_l0000@ooooo`;o00000_ooool2o`0000Cooooo0_l0
000>ooooo`;o00000_ooool2o`0004Cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo
00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`0kooooo`;o00000oooool2o`0000?o
oooo0_l0000Aooooo`;o00002?ooool2o`0000Oooooo0ol00002oooooa;o00000_ooool2o`000003
ooooool0003o000000Go00004_ooool3o`0000;ooooo0_l000001?oooooo0000o`000?ooool>o`00
0003ooooool0003o000001Go00000_ooool3o`000003ooooool0003o000000cooooo0_l00002oooo
o`;o00001Oooool2o`0000;ooooo0_l0000=ooooo`;o0000A?ooool001cooooo00?o0000oooooooo
ool0C_ooool2o`0001Gooooo0_l00008oooooa?o00000_ooool2o`0000;ooooo1_l00006ooooo`;o
00001_ooool2o`0000;ooooo0ol00002ooooo`;o000000Coooooo`000?l0003ooooo7ol000000ooo
oooo0000o`000002o`000003ooooool0003o000000Co000000?oooooo`000?l000002oooool2o`00
00[ooooo0_l00002ooooo`;o000000?oooooo`000?l000001_ooool2o`0000?ooooo1Ol00010oooo
o`007?ooool00ol0003oooooooooo`0looooo`;o000000?oooooo`000?l000002oooool4o`0000Ko
oooo0_l0000=ooooo`;o000000?oooooo`000?l000001OoooolCo`0000;ooooo0_l00002ooooo`;o
00002Oooool3o`0000Gooooo0ol00003ooooo`Ko00000_oooolQo`000003ooooool0003o000000?o
oooo1ol00002ooooo`;o00002Oooool2o`00017ooooo0_l00006ooooo`;o00000oooool5o`00043o
oooo000Looooo`03o`000?oooooooooo03_ooooo0ol000000ooooooo0000o`000002o`0000Kooooo
0_l000000ooooooo0000o`000008ooooo`;o00002Oooool2o`0000?ooooo1?l00005oooooa;o0000
0oooool2o`0000gooooo0_l000000ooooooo0000o`000005o`0000Kooooo0_l00002ooooo`Oo0000
00?oooooo`000?l000005_l000000ooooooo0000o`000003o`0000;ooooo0_l00003ooooo`?o0000
0_ooool3o`0000Cooooo0_l00006ooooo`?o00000oooool4o`0000Gooooo0_l000000ooooooo0000
o`000008ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0>oooool2o`0000Cooooo0_l0
0006ooooo`;o00005_ooool2o`0000?ooooo0_l00007oooooaGo00000_ooool2o`0000;ooooo0_l0
0005ooooo`;o00000_ooool6o`0000cooooo0_l000001?oooooo0000o`000?ooool2o`000003oooo
ool0003o0000023o00001?ooool2o`0000;ooooo0_l00004ooooo`;o00001_ooool3o`0000?ooooo
1?l00005ooooo`;o000000?oooooo`000?l00000COooool001cooooo00?o0000ooooooooool0=_oo
ool2o`0000Kooooo0_l00004ooooo`Co00001oooool2o`0001?ooooo0_l00009oooooaGo00000_oo
ool2o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`00013ooooo:ol000001?oooooo0000o`00
0?ooool2o`0001Sooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00001_oo
ool2o`0000Cooooo1_l00004ooooo`?o00004oooool2o`0000Wooooo5ol00007ooooo`?o00000_oo
ool2o`0001?ooooo2ol000000ooooooo0000o`00000Po`0000oooooo0_l00003ooooo`;o0000G_oo
ool001cooooo00?o0000ooooooooool0?_ooool2o`000003ooooool0003o000000Gooooo0_l00004
ooooo`;o00007_ooool2o`000003ooooool0003o000000ko00000oooool3o`0000Cooooo1Ol00002
ooooo`;o00005?ooool2o`0000;ooooo1_l00002oooooaco000000?oooooo`000?l000000_l0000>
ooooo`?o00000oooool2o`0001;ooooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`11oooo
o`;o00001Oooool2o`000003ooooool0003o000001Oooooo0ol00006ooooo`?o00000_oooolAo`00
0004ooooool0003o0000o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`;o00001?ooool2
o`00013ooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo6?l00004ooooo`;o00003Oooool3
o`0000[ooooo0_l00005ooooo`;o000000Coooooo`000?l0003ooooo0_l0001:ooooo`007?ooool0
0ol0003oooooooooo`0kooooo`;o00001oooool2o`0000;ooooo0_l000000ooooooo0000o`00000G
ooooo`?o00001_oooolFo`0000Kooooo0_l00003ooooo`Co00000_ooool2o`0000Cooooo0_l00002
ooooo`;o00002_ooool4o`000003ooooool0003o000000;o000000Coooooo`000?l0003ooooo1_l0
00001?oooooo0000o`000?l00002ooooo`Go000000?oooooo`000?l000001?l00005ooooo`;o0000
3_ooool2o`0000[ooooo1?l00003ooooo`Go0000COooool001cooooo00?o0000ooooooooool0>ooo
ool2o`000003ooooool0003o000000Cooooo0_l0000Dooooo`;o00004_oooolGo`0000Cooooo0_l0
0005ooooo`;o00003?ooool2o`0000[ooooo0_l00003ooooo`Oo000000?oooooo`000?l000000ol0
0002ooooo`?o000000?oooooo`000?l000003?l000000ooooooo0000o`000002o`0000Cooooo0_l0
000@ooooo`;o00001Oooool2o`0000Gooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`0h
ooooo`;o00001?ooool2o`0000Sooooo0_l00007ooooo`;o00001?ooool2o`000003ooooool0003o
000001;ooooo5ol00006ooooo`Co00000oooool6o`0000;ooooo0_l0000Dooooo`;o000000?ooooo
o`000?l000000_l00002ooooo`?o000000?oooooo`000?l000001_l000001Ooooooo0000o`000?l0
003ooooo00?o000000Coooooo`000?l0003ooooo1?l00004ooooo`;o00004?ooool2o`0005cooooo
000Looooo`;o0000>Oooool2o`0000kooooo0_l00007ooooo`;o00001?ooool4o`0000[ooooo0_l0
0005oooooaGo00002_ooool5o`0000;ooooo1_l00002ooooo`;o00000_ooool2o`00013ooooo0_l0
00000ooooooo0000o`000005o`0000?ooooo1ol00002ooooo`Wo00001_ooool2o`0000?ooooo0_l0
000:ooooo`Co0000Goooool001cooooo00?o0000ooooooooool0B?ooool2o`0000Wooooo0_l00004
ooooo`;o00002Oooool3o`0000;ooooo0_l000000ooooooo0000o`000005o`000003ooooool0003o
000000_o00000_ooool2o`0000Wooooo1?l000000ooooooo0000o`000003o`000004ooooool0003o
0000o`0000;ooooo0_l0000:ooooo`;o00001?ooool3o`0000Cooooo1?l00003ooooo`?o00001?oo
ool5o`0000?ooooo0_l00005ooooo`?o00000oooool2o`0000[ooooo1?l00008ooooo`;o00000_oo
ool2o`0000Gooooo0ol00019ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00001Oooool2
o`0000Kooooo0_l0000?ooooo`;o000000?oooooo`000?l000000_l00003oooooaOo00001?ooool2
o`0000Gooooo0_l00003ooooo`;o00000_ooool3o`0000kooooo0_l000000ooooooo0000o`000002
ooooo`;o000000?oooooo`000?l000000oooool8o`000004ooooool0003o0000ooooo`?o00001Ooo
ool2o`0000Gooooo0ol0000?ooooo`;o00001?ooool2o`0000Cooooo0_l00002ooooo`;o00001Ooo
ool3o`0004Wooooo000Looooo`03o`000?oooooooooo04Cooooo1_l000001Ooooooo0000o`000?l0
003ooooo00;o00005?ooool6o`0000?ooooo5_l00004ooooo`?o00001oooool2o`0000?ooooo0_l0
0006ooooo`Co00002_ooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool8o`0000;ooooo
2_l00002ooooo`;o00001_ooool2o`0000oooooo0_l00004ooooo`;o0000Foooool001cooooo00?o
0000ooooooooool0A_ooool4o`0000;ooooo1Ol00002ooooo`;o00000oooool2o`0000_ooooo0_l0
000:oooooa3o00001oooool2o`0000?ooooo0_l00003ooooo`;o00000oooool2o`0000Kooooo1?l0
000>ooooo`;o00001?ooool8o`0000;ooooo1Ol000000ooooooo0000o`000002o`0000;ooooo0_l0
00000ooooooo0000o`00000Sooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0??ooool2
o`0000oooooo0_l00004ooooo`;o00000oooool2o`0000Kooooo0_l0000>oooooa7o00002Oooool2
o`000003ooooool0003o000000;o00005Oooool2o`0000_ooooo0ol00002ooooo`So000000?ooooo
o`000?l000000ol000000ooooooo0000o`000002o`000005ooooool0003o0000o`000?ooool00_l0
0008ooooo`;o00000_ooool4o`000003ooooool0003o0000013ooooo0_l000000ooooooo0000o`00
001?ooooo`007?ooool00ol0003oooooooooo`0looooo`;o00002oooool2o`000003ooooool0003o
000000Gooooo0_l00008ooooo`;o000000?oooooo`000?l000003OoooolAo`0000[ooooo0_l00003
ooooo`;o00001?ooool2o`0000Wooooo0_l00004ooooo`;o00001oooool2o`0000;ooooo0ol00003
ooooo`Co000000?oooooo`000?l000001_l00002ooooo`;o00000_ooool3o`0000Sooooo1Ol00002
ooooo`Co000000Coooooo`000?l0003o00004_ooool4o`0004gooooo000Looooo`03o`000?oooooo
oooo04Wooooo0_l000000ooooooo0000o`000005ooooo`;o00002?ooool2o`0000_ooooo0_l00003
ooooo`co00000oooool2o`0000;ooooo1_l00009ooooo`;o000000?oooooo`000?l000001?l00006
ooooo`;o00003Oooool2o`0000Gooooo1?l00005ooooo`Oo00000_ooool2o`0000Cooooo0_l00003
ooooo`;o00000_ooool3o`0000Cooooo0_l00004ooooo`;o00001?ooool3o`0000Gooooo0_l00004
ooooo`Co0000COooool001cooooo00?o0000ooooooooool0Coooool4o`0000Oooooo0_l0000>oooo
o`;o00001?ooool8o`000004ooooool0003o0000o`0000Kooooo1_l00009ooooo`;o000000Cooooo
o`000?l0003ooooo0ol00009ooooo`;o00003oooool6o`0000Wooooo0ol00004ooooo`;o00000_oo
ool2o`0000?ooooo0_l000000ooooooo0000o`00000Booooo`?o00001Oooool2o`0005Gooooo000L
ooooo`03o`000?oooooooooo047ooooo0_l0000<ooooo`Co00001_ooool3o`0000[ooooo0_l00008
ooooo`?o000000Coooooo`000?l0003o00000oooool2o`0001kooooo0_l00006ooooo`?o00000ooo
ool2o`0000[ooooo0_l0000=ooooo`;o00001Oooool2o`0000;ooooo0_l00005ooooo`?o00001?oo
ool2o`0000Sooooo0_l00002ooooo`;o00002?ooool2o`0005?ooooo000Looooo`03o`000?oooooo
oooo047ooooo0_l0000<ooooo`;o00002?ooool2o`0000_ooooo0_l00008ooooo`;o00000_ooool2
o`000003ooooool0003o000000?ooooo0_l0000Cooooo`;o00000oooool2o`0000;ooooo0_l00006
ooooo`;o00001?ooool2o`000003ooooool0003o000001Oooooo0_l0000?ooooo`;o00001Oooool2
o`0000Sooooo0_l00009ooooo`;o000000?oooooo`000?l00000Doooool001cooooo00?o0000oooo
ooooool0Coooool4o`0001?ooooo0_l00004ooooo`;o00000_ooool3o`000004ooooool0003o0000
ooooo`;o00000oooool2o`0000;ooooo1Ol0000<ooooo`;o00000_ooool3o`0000?ooooo0_l0000>
ooooo`;o00003?ooool2o`0000Wooooo0_l000000ooooooo0000o`00000Cooooo`;o00001oooool2
o`0000[ooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`1Aooooo`Co00002?ooool2o`00
00Cooooo0_l00007ooooo`;o00000oooool2o`0000_ooooo1ol0000@ooooo`;o00001?ooool2o`00
00Cooooo0_l00003ooooo`?o000000Goooooo`000?l0003o0000ooooo`02o`0000Wooooo0_l00000
0ooooooo0000o`000009ooooo`;o00006_ooool4o`0000Cooooo0_l0001Looooo`007?ooool00ol0
003oooooooooo`19ooooo`;o00000_ooool2o`0000;ooooo1?l00007ooooo`?o00001?ooool2o`00
00cooooo0_l00004ooooo`;o00000oooool4o`0000Oooooo0_l00002ooooo`;o00000oooool2o`00
0003ooooool0003o000000cooooo0_l00003ooooo`?o000000?oooooo`000?l000000_ooool3o`00
00_ooooo0_l00006ooooo`;o00007Oooool2o`0000Cooooo1?l00002ooooo`;o0000F?ooool001co
oooo00?o0000ooooooooool0BOooool2o`0000;ooooo1_l00009ooooo`;o00006?ooool3o`0000?o
oooo0_l00004ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l0
00004?ooool4o`0000Gooooo1Ol00002ooooo`;o00003Oooool2o`0000Gooooo0_l0000Booooo`;o
00000oooool2o`0000?ooooo0ol00003ooooo`?o0000Eoooool001cooooo00?o0000ooooooooool0
BOooool2o`0000;ooooo1_l0000Sooooo`;o00002_ooool2o`0000_ooooo0_l0000Cooooo`Co0000
1_ooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`00000Aooooo`;o0000
1Oooool2o`0000_ooooo1?l000000ooooooo0000o`000002o`0000;ooooo0ol000000ooooooo0000
o`000002o`0000?ooooo0_l0000Gooooo`;o0000>Oooool001cooooo0_l0001:ooooo`;o00001_oo
ool2o`0003cooooo0_l0000?ooooo`;o00000_ooool4o`0000oooooo0ol0000Aooooo`;o00001Ooo
ool2o`0000Sooooo0_l00003ooooo`Co000000?oooooo`000?l000000_ooool3o`000003ooooool0
003o000000Gooooo0_l0000Gooooo`;o0000>Oooool001cooooo00?o0000ooooooooool0C?ooool2
o`0000?ooooo0_l00003ooooo`;o00004oooool4o`0001Oooooo0_l0000?ooooo`;o00001oooool4
o`000003ooooool0003o000000Wooooo1?l00003ooooo`;o000000?oooooo`000?l000001oooool2
o`0000Kooooo0_l0000?ooooo`;o00001Oooool2o`0006Cooooo000Looooo`03o`000?oooooooooo
04cooooo0_l00008ooooo`;o00004oooool4o`0000Kooooo0_l0000?ooooo`;o00002oooool2o`00
00;ooooo0_l00007ooooo`Co00003?ooool4o`0000Cooooo1_l00005ooooo`;o00002_ooool2o`00
00cooooo0_l00007ooooo`?o00002_ooool2o`0005Cooooo000Looooo`03o`000?oooooooooo04[o
oooo0_l0000Qooooo`;o00000oooool2o`000003ooooool0003o000000Kooooo0_l00003ooooo`;o
00001Oooool2o`0000?ooooo0_l00002ooooo`?o00002oooool4o`0000_ooooo1Ol00004ooooo`?o
000000?oooooo`000?l000001?ooool2o`0000Kooooo0_l00003ooooo`;o00003?ooool2o`0000Oo
oooo0ol0000:ooooo`;o0000E?ooool001cooooo00?o0000ooooooooool0B_ooool2o`0000Oooooo
0_l00003ooooo`;o00000_ooool2o`0000Cooooo0_l00007ooooo`Co00000oooool2o`0000Wooooo
0_l00003ooooo`;o00001Oooool2o`0000?ooooo1_l00004ooooo`;o000000Coooooo`000?l0003o
00002oooool3o`0000?ooooo1Ol00004ooooo`;o00002?ooool2o`0000Kooooo0ol00008ooooo`;o
00003_ooool2o`0006;ooooo000Looooo`03o`000?oooooooooo057ooooo1?l00003ooooo`?o0000
00?oooooo`000?l000000_ooool4o`0000;ooooo0_l00003ooooo`Co00005?ooool8o`000004oooo
ool0003o0000ooooo`?o00001Oooool3o`000004ooooool0003o0000o`0000Sooooo0_l000001?oo
oooo0000o`000?l00005ooooo`;o00002Oooool5o`000004ooooool0003o0000o`0000;ooooo0_l0
00001?oooooo0000o`000?l00008ooooo`;o00001?ooool2o`0000;ooooo0_l00004ooooo`?o0000
1?ooool2o`0005_ooooo000Looooo`03o`000?oooooooooo04gooooo0_l00002ooooo`Co00000ooo
ool3o`0000Gooooo0_l00002ooooo`Co00000oooool5o`00013ooooo0_l000000ooooooo0000o`00
0004o`0000?ooooo0_l00006ooooo`;o000000?oooooo`000?l000003Oooool2o`00013ooooo0_l0
0002ooooo`Go000000Coooooo`000?l0003o00000_ooool2o`0000cooooo0_l00004ooooo`;o0000
0_ooool2o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`?o0000F_ooool001cooooo00?o
0000ooooooooool0COooool2o`0001Gooooo0_l00002ooooo`;o000000?oooooo`000?l000000ol0
0004ooooo`;o00002_ooool2o`0001;ooooo1?l00005ooooo`;o00004Oooool2o`0000Kooooo0_l0
0004ooooo`;o00000oooool2o`0000;ooooo0_l00009ooooo`;o00000_ooool2o`0000_ooooo0_l0
0008ooooo`;o0000F_ooool001cooooo00?o0000ooooooooool0D?ooool2o`0000oooooo0_l00005
ooooo`;o00002_ooool2o`0001Kooooo0_l000000ooooooo0000o`000002ooooo`Go00001Oooool3
o`0000Cooooo0_l000001?oooooo0000o`000?l00005ooooo`?o00004oooool2o`0000;ooooo0_l0
0003ooooo`;o00000_ooool2o`0000;ooooo0_l00002ooooo`;o0000KOooool001cooooo00?o0000
ooooooooool0D?ooool2o`0000Kooooo0_l00007ooooo`;o00001_ooool2o`0001Gooooo0_l0000:
ooooo`;o000000?oooooo`000?l000001ol00006ooooo`;o00001?ooool2o`000004ooooool0003o
0000o`0000Gooooo0_l00009ooooo`;o00001oooool4o`000004ooooool0003o0000o`0000?ooooo
0ol00009ooooo`;o0000KOooool001cooooo00?o0000ooooooooool0D?ooool2o`0000Kooooo0_l0
0004ooooo`;o00002Oooool2o`0000Kooooo0_l0000=ooooo`;o00003Oooool5o`0000Wooooo0_l0
00000ooooooo0000o`000002o`0001Kooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0ol0
0004ooooo`Co00002_ooool4o`0006Sooooo000Looooo`03o`000?oooooooooo05kooooo0_l00002
ooooo`Co00002oooool2o`0001cooooo1?l00008ooooo`Co000000?oooooo`000?l000000_l00007
ooooo`;o00003Oooool2o`0000?ooooo0_l00005ooooo`Go000000?oooooo`000?l000000oooool2
o`0000Gooooo0_l00003ooooo`Co0000J?ooool001cooooo00?o0000ooooooooool0G?ooool2o`00
00Cooooo1?l0000?ooooo`;o00006_ooool2o`0000Sooooo0_l00004ooooo`;o00002?ooool3o`00
00Wooooo0_l00006ooooo`;o00001Oooool5o`000003ooooool0003o000000;o00000oooool3o`00
00;ooooo0_l00002ooooo`;o00000oooool2o`0006Kooooo000Looooo`03o`000?oooooooooo053o
oooo0_l0000:ooooo`;o00005Oooool6o`0001Sooooo0_l0000;ooooo`;o00001Oooool2o`0000Go
oooo0_l00002ooooo`;o00000oooool5o`0000Gooooo0ol000000ooooooo0000o`000004ooooo`;o
00000oooool2o`0000?ooooo0ol00006ooooo`;o00000oooool2o`0000;ooooo0_l0001Rooooo`00
7?ooool00ol0003oooooooooo`1@ooooo`;o00003Oooool2o`0000Kooooo0_l0000:ooooo`Ko0000
8oooool4o`0000Gooooo0_l00002ooooo`;o00001Oooool2o`0000?ooooo0_l000000ooooooo0000
o`000006ooooo`;o000000?oooooo`000?l000005Oooool2o`0000Cooooo0ol00002ooooo`;o0000
H_ooool001cooooo00?o0000ooooooooool0Goooool2o`0000Kooooo0_l0000:ooooo`Co00006Ooo
ool2o`0000[ooooo0_l00004ooooo`Go00000_ooool2o`000003ooooool0003o000000Sooooo0_l0
000Rooooo`;o00001?ooool2o`000003ooooool0003o000006Cooooo000Looooo`;o0000M?ooool4
o`0001Wooooo0_l0000@ooooo`Go00001Oooool2o`0000Sooooo0_l0000Jooooo`?o00003?ooool4
o`0006Cooooo000Looooo`03o`000?oooooooooo05Gooooo0_l0000?ooooo`;o00001oooool4o`00
00;ooooo0_l0000Kooooo`;o00003_ooool2o`000003ooooool0003o000000Gooooo0_l0000Aoooo
o`;o00002oooool4o`0000;ooooo0ol0000<ooooo`;o00003oooool2o`0005Gooooo000Looooo`03
o`000?oooooooooo05Gooooo0_l000001?oooooo0000o`000?ooool2o`0000Wooooo0ol000000ooo
oooo0000o`000003ooooo`Co00007oooool2o`0000Kooooo0_l00006ooooo`;o000000?oooooo`00
0?l000001Oooool2o`000003ooooool0003o000000Oooooo0_l00005ooooo`Co00002Oooool4o`00
00?ooooo0_l000001?oooooo0000o`000?l00004ooooo`;o00004oooool2o`0005Gooooo000Loooo
o`03o`000?oooooooooo05Sooooo0_l000000ooooooo0000o`00000:ooooo`;o000000?oooooo`00
0?l000000oooool2o`0000Cooooo0_l00002ooooo`;o00005?ooool2o`0000Wooooo0ol00003oooo
o`;o00003Oooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00009oooo
o`;o00001Oooool2o`000004ooooool0003o0000o`0000Cooooo1?l0001Xooooo`007?ooool00ol0
003oooooooooo`1Hooooo`;o00002_ooool2o`0000Wooooo0_l00004ooooo`?o000000Coooooo`00
0?l0003o00003oooool2o`0000;ooooo0_l0000:ooooo`;o00000oooool2o`0000Gooooo0_l00000
0ooooooo0000o`000008ooooo`Co00001Oooool2o`0000oooooo0_l00003ooooo`;o00000oooool2
o`0000Gooooo0_l0001Xooooo`007?ooool00ol0003oooooooooo`1Rooooo`Ko00001?ooool2o`00
00Oooooo0ol00002ooooo`;o00000_ooool4o`0000Wooooo0_l0000:ooooo`;o000000Coooooo`00
0?l0003ooooo0_l00004ooooo`;o00000_ooool2o`000004ooooool0003o0000o`0000Wooooo0_l0
000:ooooo`Co00002?ooool2o`000003ooooool0003o000000Gooooo0_l0001_ooooo`007?ooool0
0ol0003oooooooooo`1Iooooo`;o00001oooool6o`0000Cooooo0_l000000ooooooo0000o`000003
o`000003ooooool0003o000000Oooooo1?l00003ooooo`;o00002_ooool2o`000004ooooool0003o
0000ooooo`;o000000?oooooo`000?l000000ol00004ooooo`;o00001_ooool2o`0000Wooooo1_l0
0006ooooo`Go00002_ooool2o`0001Gooooo0_l00002ooooo`;o0000Foooool001cooooo00?o0000
ooooooooool0FOooool2o`0000Wooooo0ol00008ooooo`Go00004Oooool2o`0000Cooooo0_l00004
ooooo`;o000000?oooooo`000?l000001?l000000ooooooo0000o`00000Aooooo`;o00001_ooool6
o`0000Wooooo0_l00008ooooo`;o00000_ooool2o`0001?ooooo0_l00002ooooo`;o0000Foooool0
01cooooo00?o0000ooooooooool0IOooool4o`0000oooooo0_l00005ooooo`;o00002_ooool2o`00
00Wooooo1?l00004ooooo`;o00003_ooool2o`0000[ooooo0_l0000:ooooo`;o00001oooool2o`00
00;ooooo0_l0001dooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o00001oooool2o`0000co
oooo0_l000000ooooooo0000o`000004ooooo`Co00004?ooool2o`0000Oooooo0_l000000ooooooo
0000o`000004ooooo`;o00005?ooool2o`0000[ooooo0_l00006ooooo`;o0000NOooool001cooooo
00?o0000ooooooooool0G_ooool2o`0000_ooooo0_l00008ooooo`;o00000_ooool2o`0000?ooooo
1?l0000@ooooo`;o00001oooool2o`000003ooooool0003o000000Cooooo0_l00006ooooo`?o0000
1oooool2o`0000;ooooo0_l00004ooooo`;o00003?ooool2o`0007Wooooo000Looooo`03o`000?oo
oooooooo05cooooo0_l00002ooooo`;o00001?ooool3o`000004ooooool0003o0000o`0000Cooooo
0_l00006ooooo`;o00000oooool2o`0000[ooooo0_l0000=ooooo`;o00000oooool2o`0000cooooo
0ol00007ooooo`?o00001oooool2o`0000cooooo0_l00009ooooo`;o00000_ooool2o`0006[ooooo
000Looooo`03o`000?oooooooooo05cooooo0_l00002ooooo`;o00000_ooool5o`000003ooooool0
003o000000Gooooo0_l00004ooooo`;o00001Oooool2o`0000Kooooo0_l00002ooooo`;o00003Ooo
ool2o`0001cooooo1?l00005ooooo`;o00003?ooool2o`0000Wooooo0_l00002ooooo`;o0000J_oo
ool001cooooo00?o0000ooooooooool0I?ooool2o`0000?ooooo0_l00006ooooo`;o00000_ooool4
o`0000gooooo0_l0000Looooo`;o00003oooool3o`000004ooooool0003o0000ooooo`Ko00000_oo
ool2o`0000[ooooo0_l0001gooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q
1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0I?ooool2o`0000?o
oooo0_l00005ooooo`;o00000oooool2o`0002gooooo0_l0000?ooooo`?o00001?ooool4o`0000Co
oooo0_l0000:ooooo`;o0000Moooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q
8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo06Cooooo0_l0000:
ooooo`?o00005?ooool2o`000003ooooool0003o000000?o00000_ooool2o`0000cooooo0_l0000=
ooooo`;o00003Oooool2o`0000Kooooo0_l00022ooooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`1T
ooooo`;o00002_ooool3o`0001;ooooo1?l000000ooooooo0000o`000003o`0000;ooooo0_l0000<
ooooo`;o00002Oooool6o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`;o00001_ooool7
o`0007gooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRH
V?ooooooV9RHoc8b<P06ooooo`?o0000Loooool2o`00013ooooo0_l00004ooooo`;o00002_ooool2
o`000003ooooool0003o000000kooooo1?l00006ooooo`;o000000Coooooo`000?l0003o00001_oo
ool3o`0000;ooooo1ol0000Fooooo`;o0000IOooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool02Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0LOoo
ool4o`0000Oooooo0_l0000<ooooo`?o00000_ooool2o`0000Kooooo0_l000000ooooooo0000o`00
000Eooooo`Co00000oooool2o`0000?ooooo0_l000001?oooooo0000o`000?l00002ooooo`?o0000
6_ooool2o`0006Gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go
410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo06kooooo1Ol00009ooooo`;o0000
2?ooool2o`0000;ooooo0ol00002ooooo`;o00008?ooool4o`0000Oooooo0ol000000ooooooo0000
o`000004ooooo`Co0000Ooooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o
^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0K_ooool4o`0000kooooo0_l00004oooo
o`;o00008oooool4o`0000Gooooo0_l00006ooooo`;o00001?ooool2o`0000;ooooo1?l0001ooooo
o`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_oo
ool00ol0003oooooooooo`1`ooooo`;o00003_ooool2o`0000cooooo0_l0000Fooooo`;o00000ooo
ool4o`0000Gooooo0_l00002ooooo`;o00001Oooool5o`0008Gooooo000Looooo`03o`000?oooooo
oooo06_ooooo0_l0000Dooooo`;o00002oooool2o`0001Kooooo0_l00008ooooo`;o00001_ooool2
o`000003ooooool0003o000000;ooooo1?l00026ooooo`007?ooool00ol0003oooooooooo`1Soooo
o`;o00001_ooool2o`0001Cooooo0_l00005ooooo`;o00009_ooool2o`0000Kooooo0_l000000ooo
oooo0000o`000003ooooo`;o0000Qoooool001cooooo00?o0000ooooooooool0Hoooool2o`0002?o
oooo0ol0000?ooooo`?o00002oooool2o`0000Gooooo0_l00009ooooo`Go0000R_ooool001cooooo
00?o0000ooooooooool0KOooool2o`0000Wooooo0_l0000?ooooo`;o00003oooool3o`0000_ooooo
0ol00003ooooo`?o000000?oooooo`000?l000000_l00004ooooo`;o000000?oooooo`000?l00000
1Oooool2o`0008?ooooo000Looooo`03o`000?oooooooooo06gooooo0_l00009ooooo`Co00002_oo
ool2o`000003ooooool0003o000000?ooooo0_l0000:ooooo`;o00001?ooool2o`0000Oooooo0_l0
0003ooooo`So00003_ooool2o`0000;ooooo0_l0001oooooo`007?ooool00ol0003oooooooooo`1j
ooooo`;o00002?ooool6o`0000;ooooo1?l0000@ooooo`;o00001_ooool2o`0000Kooooo0_l00000
0ooooooo0000o`00000Cooooo`;o000000?oooooo`000?l00000O?ooool001cooooo00?o0000oooo
ooooool0P_ooool8o`0000;ooooo1?l0000Hooooo`;o00002Oooool2o`0001Kooooo0_l0001loooo
o`007?ooool00ol0003oooooooooo`22ooooo`;o00000_ooool2o`00017ooooo0_l0000:ooooo`;o
0000X_ooool001cooooo00?o0000ooooooooool0Q?ooool2o`00017ooooo1?l0000:ooooo`;o0000
X_ooool001cooooo00?o0000ooooooooool0Q?ooool2o`00017ooooo0_l00003ooooo`;o00001Ooo
ool2o`000:Cooooo000Looooo`03o`000?oooooooooo09cooooo0_l00004ooooo`?o00001_ooool2
o`0009cooooo000Looooo`;o0000Xoooool2o`0000Oooooo0_l00003ooooo`;o0000Uoooool001co
oooo00?o0000ooooooooool0W_ooool3o`0000Wooooo0ol00003ooooo`;o0000Uoooool001cooooo
00?o0000ooooooooool0W_ooool3o`0000Wooooo0ol00002ooooo`;o00006oooool2o`0007_ooooo
000Looooo`03o`000?oooooooooo0:7ooooo0_l0000<ooooo`;o00006oooool2o`0007_ooooo000L
ooooo`03o`000?oooooooooo0:7ooooo0_l00006ooooo`;o00001_ooool2o`0009Kooooo000Loooo
o`03o`000?oooooooooo0:Wooooo0_l000000ooooooo0000o`000003ooooo`;o0000U_ooool001co
oooo00?o0000ooooooooool0YOooool2o`0000;ooooo0_l000000ooooooo0000o`00002Kooooo`00
7?ooool00ol0003oooooooooo`2Uooooo`;o00000_ooool2o`0000Cooooo0_l0002Hooooo`007?oo
ool00ol0003oooooooooo`2_ooooo`;o0000V?ooool001cooooo00?o0000ooooooooool0Z_ooool2
o`0009gooooo000Looooo`03o`000?oooooooooo0:[ooooo0_l0002Mooooo`007?ooool00ol0003o
ooooooooo`2;ooooo`;o0000_?ooool001cooooo00?o0000ooooooooool0Roooool2o`000;cooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0V_ooool4
o`000:_ooooo000Looooo`03o`000?oooooooooo09[ooooo1?l0002[ooooo`007?ooool2o`000?oo
ooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001;ooooo1?l000000ol@413oooooooooo`03ooooo`03
o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo0ol0003ooooood[ooooo000D
ooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBoooo
o`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?oooooo
D_ooool001;ooooo00?oEEEEofIVI_l00000oooooomDooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00XOooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo01Ko
oooo1?l000000ol@413oooooooooo`02ooooo`;o000000Wo410@oooooooooooooooooiRHV?l@413o
0000oc8b<_o<c<`01Oooool2o`000003oa0@4?oooooooooo08[ooooo002Rooooo`05o`000?oooooo
ooooooooool000002Oooool6o`0000cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?nj^[[oooooogMgMolb<S801_ooool00ol0003oooooooooo`2;ooooo`00X_oo
ool01Ol0003ooooooooooooooooo000001_ooooo00?o0000ooooooooool00_ooool5o`0000Oooooo
00Co0000oooooooooooooooo1Ol0002<ooooo`00X_ooool01Ol0003ooooooooooooooooo000000Wo
oooo1_l0000<ooooo`03o`000?oooooooooo00;ooooo00CoA4A4omgMgOoooooo00001oooool00onY
ZJWo410@ooooo`02ooooo`04odA4A?oMgMgoooooo`0008gooooo002Rooooo`05o`000?n7QhOooooo
ojVYZOl000006oooool00ol0003oooooooooo`02ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o
410@o`000?nj^[X00oooool01?oMgMgoEEEEooooool0002=ooooo`00XOooool00ol@413o0000ogMg
M`02o`000003oiRHV?oooooooooo01Wooooo00?o0000ooooooooool00oooool00omgMgOoc<c<o`00
0007ooooo`03okZj^_lQ8B7ooooo00?ooooo00?oMgMgolc<c?l00000SOooool00<;ooooo00?o0000
ooooooooool00oooool00oo^k^koA4A4o`000004ooooo`05oa0@4?nHV9SooooookZj^_l000001?oo
ool00oo^k^koA4A4o`00002=ooooo`00`?ooool00omEEEGoIVIVo`000006ooooo`03ogMgMol0003o
oooo00?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@05ooooo`03ogMgMol0003ooooo08cooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1440) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.61137 .37156 Mdot
.6219 .36222 Mdot
.33807 .47352 Mdot
.55639 .58718 Mdot
.35458 .76556 Mdot
.36773 .44399 Mdot
.51311 .34823 Mdot
.49669 .32833 Mdot
.33122 .47708 Mdot
.63772 .32575 Mdot
.46067 .3168 Mdot
.61349 .68224 Mdot
.46828 .34083 Mdot
.5954 .58952 Mdot
.70241 .79053 Mdot
.63075 .57562 Mdot
.61368 .37132 Mdot
.35681 .6738 Mdot
.61787 .5689 Mdot
.34869 .42971 Mdot
.60596 .43755 Mdot
.59104 .5904 Mdot
.61385 .3955 Mdot
.59599 .58982 Mdot
.56122 .60894 Mdot
.61786 .40501 Mdot
.67766 .39085 Mdot
.56949 .63938 Mdot
.61016 .63228 Mdot
.46824 .31361 Mdot
.41842 .65881 Mdot
.5725 .82673 Mdot
.54738 .52992 Mdot
.57156 .76643 Mdot
.47626 .36064 Mdot
.7339 .57215 Mdot
.36455 .45785 Mdot
.47937 .32385 Mdot
.46918 .32269 Mdot
.50058 .3383 Mdot
.49135 .32977 Mdot
.63396 .39486 Mdot
.58917 .24092 Mdot
.40255 .35383 Mdot
.59442 .66515 Mdot
.24078 .65723 Mdot
.68764 .60021 Mdot
.58401 .56617 Mdot
.65613 .42199 Mdot
.25804 .50117 Mdot
.37191 .32126 Mdot
.47015 .36958 Mdot
.32521 .44484 Mdot
.40147 .12675 Mdot
.45497 .34651 Mdot
.53815 .65437 Mdot
.35055 .46301 Mdot
.59372 .60618 Mdot
.60043 .59336 Mdot
.75585 .44518 Mdot
.53508 .62898 Mdot
.33754 .61194 Mdot
.61921 .35224 Mdot
.44719 .51313 Mdot
.33953 .45846 Mdot
.45952 .32128 Mdot
.65142 .37427 Mdot
.45894 .35148 Mdot
.55995 .51746 Mdot
.35587 .5052 Mdot
.57367 .56053 Mdot
.46329 .31722 Mdot
.6089 .43403 Mdot
.58959 .63363 Mdot
.23694 .49303 Mdot
.21526 .63104 Mdot
.38502 .58858 Mdot
.73683 .54019 Mdot
.75522 .43727 Mdot
.26775 .56221 Mdot
.58729 .6569 Mdot
.40853 .71272 Mdot
.21774 .62259 Mdot
.66276 .42618 Mdot
.59879 .54601 Mdot
.41519 .63062 Mdot
.58408 .63442 Mdot
.30227 .75616 Mdot
.52549 .58319 Mdot
.46866 .54145 Mdot
.3476 .49077 Mdot
.63379 .42365 Mdot
.55483 .59286 Mdot
.61225 .62482 Mdot
.78274 .45363 Mdot
.58212 .55571 Mdot
.57717 .59326 Mdot
.66522 .41203 Mdot
.4631 .36931 Mdot
.52502 .62338 Mdot
.38284 .52138 Mdot
.38613 .44806 Mdot
.54006 .62226 Mdot
.36396 .49769 Mdot
.61588 .43529 Mdot
.61144 .62464 Mdot
.46434 .32742 Mdot
.53801 .60277 Mdot
.41852 .22953 Mdot
.61789 .37332 Mdot
.58914 .64471 Mdot
.38211 .62019 Mdot
.70026 .47123 Mdot
.63751 .43037 Mdot
.40973 .33984 Mdot
.62112 .57601 Mdot
.57879 .60618 Mdot
.65518 .37775 Mdot
.39073 .45106 Mdot
.27764 .71955 Mdot
.66827 .40025 Mdot
.43728 .3246 Mdot
.6239 .44789 Mdot
.59436 .68986 Mdot
.33524 .45406 Mdot
.40595 .3444 Mdot
.4806 .23898 Mdot
.4401 .67233 Mdot
.58339 .63116 Mdot
.61248 .25535 Mdot
.37123 .42828 Mdot
.64593 .41199 Mdot
.46308 .34966 Mdot
.54262 .54059 Mdot
.63278 .37797 Mdot
.44161 .32668 Mdot
.34927 .63843 Mdot
.36227 .28086 Mdot
.60026 .40321 Mdot
.53118 .43013 Mdot
.44826 .36806 Mdot
.49637 .35957 Mdot
.77412 .666 Mdot
.65741 .39323 Mdot
.36855 .61031 Mdot
.46982 .3526 Mdot
.47502 .66687 Mdot
.58485 .66594 Mdot
.38458 .70181 Mdot
.51489 .18205 Mdot
.56596 .75155 Mdot
.31713 .34141 Mdot
.37307 .6242 Mdot
.44839 .37526 Mdot
.56653 .5933 Mdot
.6153 .41483 Mdot
.61651 .39922 Mdot
.53534 .62873 Mdot
.55287 .61585 Mdot
.55969 .55759 Mdot
.60321 .57308 Mdot
.48496 .55688 Mdot
.53779 .55348 Mdot
.68943 .57761 Mdot
.62844 .42385 Mdot
.56126 .58609 Mdot
.32241 .45128 Mdot
.62939 .65074 Mdot
.4819 .31899 Mdot
.59052 .59892 Mdot
.55654 .59014 Mdot
.55853 .65621 Mdot
.48005 .36721 Mdot
.53621 .83029 Mdot
.65985 .47914 Mdot
.51134 .81117 Mdot
.54392 .48746 Mdot
.31716 .48727 Mdot
.57506 .63151 Mdot
.35006 .608 Mdot
.76934 .57456 Mdot
.55037 .57712 Mdot
.13235 .40591 Mdot
.58175 .58822 Mdot
.42092 .80822 Mdot
.64454 .57897 Mdot
.53647 .79275 Mdot
.42106 .70176 Mdot
.56635 .61061 Mdot
.64641 .30038 Mdot
.52246 .33383 Mdot
.34121 .52119 Mdot
.48966 .33573 Mdot
.32794 .44626 Mdot
.3412 .46922 Mdot
.40819 .53424 Mdot
.62553 .67912 Mdot
.63765 .63028 Mdot
.54121 .56139 Mdot
.38927 .4831 Mdot
.66138 .36918 Mdot
.38025 .62627 Mdot
.6069 .35886 Mdot
.48097 .85777 Mdot
.24897 .45779 Mdot
.49182 .31503 Mdot
.3466 .64425 Mdot
.37106 .48314 Mdot
.34034 .48955 Mdot
.37301 .63013 Mdot
.61483 .61073 Mdot
.65549 .39056 Mdot
.69202 .73382 Mdot
.3536 .2519 Mdot
.87304 .46593 Mdot
.66257 .41831 Mdot
.61857 .27597 Mdot
.49054 .32043 Mdot
.36355 .46951 Mdot
.57796 .60276 Mdot
.60446 .61918 Mdot
.59717 .42788 Mdot
.57538 .56037 Mdot
.61336 .45852 Mdot
.57218 .6084 Mdot
.52584 .3524 Mdot
.37583 .58123 Mdot
.40768 .53518 Mdot
.47318 .6946 Mdot
.62974 .43733 Mdot
.81633 .53065 Mdot
.33498 .49085 Mdot
.77328 .5621 Mdot
.45117 .32505 Mdot
.33664 .63129 Mdot
.31844 .47261 Mdot
.38465 .61376 Mdot
.56627 .54718 Mdot
.35152 .43323 Mdot
.3781 .6 Mdot
.44342 .59804 Mdot
.61428 .65715 Mdot
.34524 .22936 Mdot
.49862 .34366 Mdot
.60705 .36581 Mdot
.53541 .59478 Mdot
.34242 .49791 Mdot
.51805 .55269 Mdot
.2639 .40248 Mdot
.42414 .26383 Mdot
.36871 .426 Mdot
.40458 .56536 Mdot
.3316 .62527 Mdot
.35444 .35475 Mdot
.60931 .25916 Mdot
.6169 .36168 Mdot
.56645 .55036 Mdot
.58744 .81203 Mdot
.4689 .35263 Mdot
.53924 .59037 Mdot
.32883 .71264 Mdot
.46435 .36235 Mdot
.59317 .60826 Mdot
.43361 .33862 Mdot
.61679 .39851 Mdot
.74606 .40679 Mdot
.65827 .38187 Mdot
.57903 .55986 Mdot
.45915 .33376 Mdot
.39467 .45217 Mdot
.62422 .4063 Mdot
.6144 .59709 Mdot
.56938 .63675 Mdot
.43199 .55224 Mdot
.56778 .58188 Mdot
.50081 .82295 Mdot
.56912 .60992 Mdot
.35074 .47654 Mdot
.57254 .65584 Mdot
.71362 .30729 Mdot
.4053 .5316 Mdot
.65526 .3814 Mdot
.36498 .42303 Mdot
.33304 .46725 Mdot
.22181 .55247 Mdot
.43369 .37608 Mdot
.62916 .61402 Mdot
.332 .49492 Mdot
.53308 .70086 Mdot
.44087 .34777 Mdot
.52961 .61034 Mdot
.5021 .41601 Mdot
.26434 .47863 Mdot
.3329 .43854 Mdot
.51816 .65679 Mdot
.60376 .41923 Mdot
.55296 .60012 Mdot
.35589 .49472 Mdot
.62556 .68984 Mdot
.60233 .64172 Mdot
.59158 .21509 Mdot
.42288 .56434 Mdot
.4511 .36662 Mdot
.63222 .65631 Mdot
.54504 .56816 Mdot
.35385 .43542 Mdot
.62322 .43346 Mdot
.44102 .35527 Mdot
.63013 .39925 Mdot
.53988 .78623 Mdot
.35666 .2292 Mdot
.46342 .56446 Mdot
.37878 .58885 Mdot
.32626 .53438 Mdot
.5497 .79238 Mdot
.80887 .42799 Mdot
.7688 .63428 Mdot
.61211 .76972 Mdot
.37416 .48935 Mdot
.2967 .52239 Mdot
.34057 .46414 Mdot
.55702 .63144 Mdot
.33968 .4528 Mdot
.60248 .81242 Mdot
.57298 .6046 Mdot
.35277 .44914 Mdot
.80532 .49679 Mdot
.55659 .59777 Mdot
.61921 .36002 Mdot
.46553 .84198 Mdot
.73772 .30033 Mdot
.4591 .26576 Mdot
.37493 .46658 Mdot
.70793 .7065 Mdot
.57583 .59142 Mdot
.57175 .655 Mdot
.62048 .42484 Mdot
.53323 .53997 Mdot
.35073 .59973 Mdot
.34099 .64331 Mdot
.48213 .29779 Mdot
.36239 .56869 Mdot
.63019 .66014 Mdot
.62344 .40911 Mdot
.50187 .53716 Mdot
.23017 .54171 Mdot
.26374 .49949 Mdot
.49435 .3115 Mdot
.46462 .84092 Mdot
.55924 .39918 Mdot
.54479 .36255 Mdot
.32346 .40336 Mdot
.65154 .4198 Mdot
.56257 .83092 Mdot
.48729 .33257 Mdot
.30131 .25543 Mdot
.66403 .31884 Mdot
.61218 .61189 Mdot
.44602 .34185 Mdot
.50363 .59661 Mdot
.74796 .32033 Mdot
.24882 .31993 Mdot
.67667 .66398 Mdot
.5257 .58878 Mdot
.25265 .46837 Mdot
.58534 .59993 Mdot
.26049 .43036 Mdot
.56707 .6179 Mdot
.63346 .40131 Mdot
.63636 .32425 Mdot
.4298 .29791 Mdot
.65126 .46759 Mdot
.34583 .36665 Mdot
.37625 .6191 Mdot
.57419 .61037 Mdot
.61274 .6089 Mdot
.3549 .59467 Mdot
.60749 .3973 Mdot
.56872 .55708 Mdot
.81943 .51488 Mdot
.61885 .61601 Mdot
.48492 .32232 Mdot
.69777 .32863 Mdot
.64807 .53716 Mdot
.6155 .57885 Mdot
.65605 .43758 Mdot
.50578 .3283 Mdot
.46241 .33288 Mdot
.65229 .61054 Mdot
.4725 .31093 Mdot
.57843 .5794 Mdot
.23022 .34604 Mdot
.60205 .39278 Mdot
.51671 .20043 Mdot
.64334 .3796 Mdot
.72876 .52429 Mdot
.46712 .3671 Mdot
.38763 .27097 Mdot
.50713 .61508 Mdot
.48359 .33379 Mdot
.68853 .4222 Mdot
.62687 .63445 Mdot
.62835 .63579 Mdot
.69376 .72649 Mdot
.35539 .48352 Mdot
.42691 .55243 Mdot
.46705 .31352 Mdot
.59703 .57933 Mdot
.60694 .56448 Mdot
.50512 .32921 Mdot
.2818 .30841 Mdot
.7633 .36888 Mdot
.57077 .60807 Mdot
.63776 .40722 Mdot
.64701 .40723 Mdot
.58606 .67045 Mdot
.54174 .61902 Mdot
.3248 .45664 Mdot
.39251 .44109 Mdot
.31176 .48638 Mdot
.4211 .55608 Mdot
.41005 .26252 Mdot
.30898 .73568 Mdot
.50053 .33925 Mdot
.59028 .28214 Mdot
.4572 .56068 Mdot
.52713 .57409 Mdot
.37909 .46286 Mdot
.54807 .5671 Mdot
.56436 .57285 Mdot
.43097 .3849 Mdot
.36997 .7643 Mdot
.56458 .3698 Mdot
.62384 .43674 Mdot
.45691 .37503 Mdot
.63979 .64486 Mdot
.4985 .39393 Mdot
.33824 .62567 Mdot
.57376 .74084 Mdot
.45394 .32168 Mdot
.62926 .35969 Mdot
.49073 .35261 Mdot
.60612 .62212 Mdot
.51121 .60566 Mdot
.65241 .41587 Mdot
.33656 .60726 Mdot
.55069 .53299 Mdot
.58982 .60902 Mdot
.47403 .1719 Mdot
.51548 .70896 Mdot
.53506 .33849 Mdot
.56769 .60797 Mdot
.62479 .61256 Mdot
.32149 .63182 Mdot
.6172 .61756 Mdot
.53595 .57146 Mdot
.69698 .48054 Mdot
.51677 .26612 Mdot
.36694 .64298 Mdot
.24293 .3394 Mdot
.66261 .41675 Mdot
.5719 .81457 Mdot
.37633 .4536 Mdot
.45162 .29256 Mdot
.7449 .35567 Mdot
.31648 .45325 Mdot
.30948 .34904 Mdot
.56023 .81614 Mdot
.39163 .51584 Mdot
.29707 .47205 Mdot
.63819 .34925 Mdot
.59226 .5678 Mdot
.58184 .60782 Mdot
.3513 .60519 Mdot
.65269 .39048 Mdot
.49542 .4903 Mdot
.17799 .53702 Mdot
.58892 .59076 Mdot
.57707 .21272 Mdot
.23179 .39126 Mdot
.25894 .48457 Mdot
.35182 .61798 Mdot
.33656 .64341 Mdot
.57563 .61174 Mdot
.68661 .47007 Mdot
.61804 .40606 Mdot
.61351 .596 Mdot
.53521 .55581 Mdot
.36455 .47786 Mdot
.61767 .37738 Mdot
.39038 .44969 Mdot
.36051 .31887 Mdot
.49298 .81195 Mdot
.28917 .24382 Mdot
.45264 .35612 Mdot
.2241 .46756 Mdot
.43564 .3451 Mdot
.41566 .71457 Mdot
.3158 .44656 Mdot
.54752 .60377 Mdot
.61523 .4282 Mdot
.58991 .5747 Mdot
.54261 .61572 Mdot
.61455 .60884 Mdot
.60953 .57184 Mdot
.32207 .21132 Mdot
.37844 .61848 Mdot
.57441 .54269 Mdot
.34542 .47634 Mdot
.22833 .63028 Mdot
.20461 .57607 Mdot
.61066 .60629 Mdot
.56874 .62627 Mdot
.61778 .38465 Mdot
.53336 .61453 Mdot
.43694 .34844 Mdot
.62211 .35538 Mdot
.59678 .63318 Mdot
.39746 .82102 Mdot
.60804 .63477 Mdot
.53362 .80256 Mdot
.49045 .35145 Mdot
.37003 .24087 Mdot
.51085 .5928 Mdot
.43285 .26572 Mdot
.42705 .55254 Mdot
.31755 .46877 Mdot
.42936 .35052 Mdot
.36323 .45581 Mdot
.17606 .50532 Mdot
.55215 .67527 Mdot
.5649 .59683 Mdot
.53267 .56681 Mdot
.31746 .4878 Mdot
.3328 .79033 Mdot
.3684 .36787 Mdot
.54892 .67561 Mdot
.32621 .45115 Mdot
.67575 .40204 Mdot
.62468 .74344 Mdot
.63806 .38814 Mdot
.34782 .58245 Mdot
.49148 .3231 Mdot
.33794 .60695 Mdot
.44675 .76432 Mdot
.61977 .36956 Mdot
.58505 .40047 Mdot
.37473 .45566 Mdot
.65033 .33395 Mdot
.69765 .20847 Mdot
.66399 .31751 Mdot
.44274 .69549 Mdot
.62083 .41676 Mdot
.61205 .62931 Mdot
.42093 .73785 Mdot
.65441 .32055 Mdot
.36014 .45529 Mdot
.55702 .56899 Mdot
.74812 .39999 Mdot
.324 .45738 Mdot
.51746 .59402 Mdot
.34612 .4806 Mdot
.49127 .34012 Mdot
.37569 .4719 Mdot
.5958 .43452 Mdot
.58198 .64023 Mdot
.7206 .21644 Mdot
.37598 .56367 Mdot
.57246 .59253 Mdot
.47318 .37409 Mdot
.30096 .32111 Mdot
.5458 .5908 Mdot
.37776 .59358 Mdot
.3502 .44422 Mdot
.65812 .34308 Mdot
.56935 .6121 Mdot
.32654 .45025 Mdot
.60138 .37982 Mdot
.46374 .37994 Mdot
.7788 .44949 Mdot
.50313 .2878 Mdot
.62293 .42802 Mdot
.56719 .46521 Mdot
.42295 .36087 Mdot
.62516 .60952 Mdot
.58069 .55462 Mdot
.64131 .40561 Mdot
.3355 .6856 Mdot
.55071 .64199 Mdot
.57921 .65623 Mdot
.36134 .47611 Mdot
.36399 .4514 Mdot
.76109 .63633 Mdot
.39061 .46203 Mdot
.51288 .5932 Mdot
.64144 .40306 Mdot
.5545 .59037 Mdot
.61454 .38331 Mdot
.53361 .61362 Mdot
.64988 .5759 Mdot
.60736 .39824 Mdot
.44445 .38694 Mdot
.55923 .57076 Mdot
.57303 .52694 Mdot
.53878 .59865 Mdot
.59954 .57283 Mdot
.32652 .45801 Mdot
.34771 .61355 Mdot
.52947 .56496 Mdot
.38977 .63493 Mdot
.37445 .63232 Mdot
.4456 .27836 Mdot
.3624 .48 Mdot
.37239 .60635 Mdot
.20559 .41639 Mdot
.34042 .43806 Mdot
.35482 .6015 Mdot
.20514 .57908 Mdot
.4762 .36188 Mdot
.60356 .42091 Mdot
.55574 .60149 Mdot
.51181 .77149 Mdot
.68203 .58379 Mdot
.3363 .42119 Mdot
.57004 .60507 Mdot
.54078 .58621 Mdot
.67052 .40089 Mdot
.17177 .58101 Mdot
.35265 .50509 Mdot
.61702 .63157 Mdot
.6262 .3638 Mdot
.16883 .62118 Mdot
.34782 .47203 Mdot
.34955 .60374 Mdot
.48666 .36054 Mdot
.67053 .37113 Mdot
.47368 .23482 Mdot
.49462 .36567 Mdot
.40764 .43748 Mdot
.36978 .31447 Mdot
.60272 .55613 Mdot
.38223 .45061 Mdot
.84788 .54908 Mdot
.48256 .57248 Mdot
.44072 .52629 Mdot
.69175 .71475 Mdot
.6443 .42572 Mdot
.43614 .34593 Mdot
.37367 .62473 Mdot
.65776 .42537 Mdot
.61255 .37293 Mdot
.50402 .33209 Mdot
.66171 .48866 Mdot
.49904 .41399 Mdot
.47463 .32096 Mdot
.53134 .74324 Mdot
.29667 .68802 Mdot
.38091 .45719 Mdot
.35224 .59893 Mdot
.42771 .76864 Mdot
.63137 .39596 Mdot
.50914 .85622 Mdot
.70677 .72323 Mdot
.57726 .59298 Mdot
.37198 .61632 Mdot
.33147 .77986 Mdot
.18798 .60341 Mdot
.46265 .36358 Mdot
.44635 .28601 Mdot
.33219 .61774 Mdot
.53611 .59135 Mdot
.55422 .72355 Mdot
.56096 .64387 Mdot
.49524 .32912 Mdot
.78862 .48395 Mdot
.6171 .36975 Mdot
.50239 .34933 Mdot
.59244 .7462 Mdot
.58065 .58028 Mdot
.55631 .57175 Mdot
.49146 .72227 Mdot
.6561 .42938 Mdot
.31716 .46984 Mdot
.58263 .55131 Mdot
.59001 .60504 Mdot
.51374 .60799 Mdot
.58689 .67399 Mdot
.72035 .44799 Mdot
.55944 .62845 Mdot
.22904 .49098 Mdot
.52767 .59069 Mdot
.57513 .571 Mdot
.64805 .44103 Mdot
.25762 .26802 Mdot
.36687 .33337 Mdot
.5898 .6009 Mdot
.62372 .61996 Mdot
.50007 .35144 Mdot
.47414 .40857 Mdot
.6043 .33878 Mdot
.65725 .34493 Mdot
.73963 .67453 Mdot
.61725 .65523 Mdot
.64832 .37281 Mdot
.37507 .59479 Mdot
.6283 .61335 Mdot
.63819 .36526 Mdot
.567 .65976 Mdot
.32075 .46011 Mdot
.33671 .44011 Mdot
.51307 .53129 Mdot
.37363 .60439 Mdot
.68064 .28878 Mdot
.58661 .28115 Mdot
.349 .43564 Mdot
.56336 .60049 Mdot
.52674 .34259 Mdot
.35011 .49381 Mdot
.38003 .52861 Mdot
.3362 .70467 Mdot
.61349 .41554 Mdot
.63087 .42552 Mdot
.37934 .70318 Mdot
.3339 .32443 Mdot
.58709 .20201 Mdot
.49251 .33892 Mdot
.56132 .54302 Mdot
.63888 .28414 Mdot
.63162 .42851 Mdot
.42294 .7268 Mdot
.37405 .61307 Mdot
.4657 .36194 Mdot
.37891 .38932 Mdot
.6283 .38164 Mdot
.59352 .3915 Mdot
.53555 .63451 Mdot
.59734 .61352 Mdot
.77856 .61577 Mdot
.38395 .64281 Mdot
.51153 .35147 Mdot
.3492 .60151 Mdot
.32032 .44194 Mdot
.57043 .64554 Mdot
.60994 .39824 Mdot
.29163 .69411 Mdot
.62656 .59175 Mdot
.32533 .47303 Mdot
.63968 .42601 Mdot
.33103 .62768 Mdot
.37262 .58894 Mdot
.60851 .57756 Mdot
.79221 .56995 Mdot
.47958 .32688 Mdot
.65896 .40842 Mdot
.54029 .37157 Mdot
.55497 .64057 Mdot
.58998 .6175 Mdot
.61694 .53813 Mdot
.51043 .3531 Mdot
.55626 .3291 Mdot
.38425 .599 Mdot
.65347 .39792 Mdot
.56226 .62757 Mdot
.3607 .59732 Mdot
.60186 .28343 Mdot
.34941 .42355 Mdot
.37388 .47604 Mdot
.3682 .58789 Mdot
.35791 .62321 Mdot
.3832 .60102 Mdot
.51184 .85731 Mdot
.66207 .377 Mdot
.55845 .40505 Mdot
.61338 .64331 Mdot
.42841 .69821 Mdot
.56875 .54025 Mdot
.4438 .36428 Mdot
.35151 .48458 Mdot
.54306 .6013 Mdot
.61859 .5855 Mdot
.64134 .56819 Mdot
.54291 .20077 Mdot
.62003 .50663 Mdot
.6149 .37622 Mdot
.51055 .60555 Mdot
.37386 .46618 Mdot
.50783 .87114 Mdot
.72861 .72238 Mdot
.51021 .59778 Mdot
.50574 .41029 Mdot
.60716 .40503 Mdot
.50134 .33878 Mdot
.48413 .74439 Mdot
.48058 .36078 Mdot
.65244 .40408 Mdot
.56083 .63385 Mdot
.58175 .2986 Mdot
.32144 .64157 Mdot
.59681 .5764 Mdot
.49584 .33912 Mdot
.57453 .56136 Mdot
.50664 .357 Mdot
.50704 .77951 Mdot
.83431 .55284 Mdot
.58139 .58921 Mdot
.61784 .56361 Mdot
.79744 .59453 Mdot
.60991 .59991 Mdot
.33575 .6678 Mdot
.60697 .40578 Mdot
.79362 .48337 Mdot
.64031 .6068 Mdot
.59409 .71939 Mdot
.56181 .64692 Mdot
.78841 .44695 Mdot
.59313 .61883 Mdot
.25596 .48443 Mdot
.58533 .64438 Mdot
.53705 .56803 Mdot
.45333 .34447 Mdot
.50152 .35162 Mdot
.62303 .44287 Mdot
.3544 .49902 Mdot
.52588 .80775 Mdot
.58911 .61229 Mdot
.39714 .27361 Mdot
.53232 .28795 Mdot
.35526 .62209 Mdot
.65132 .39919 Mdot
.19332 .6534 Mdot
.44966 .31737 Mdot
.76529 .66804 Mdot
.73286 .67076 Mdot
.52027 .24438 Mdot
.37569 .75455 Mdot
.2704 .35007 Mdot
.33368 .62719 Mdot
.55606 .65405 Mdot
.30079 .59957 Mdot
.25323 .48405 Mdot
.32642 .68704 Mdot
.42682 .35456 Mdot
.77063 .58932 Mdot
.33429 .72976 Mdot
.35348 .58431 Mdot
.32985 .6372 Mdot
.47812 .36904 Mdot
.29542 .49116 Mdot
.61791 .683 Mdot
.36899 .62317 Mdot
.31707 .48965 Mdot
.3436 .43349 Mdot
.32198 .49701 Mdot
.61609 .40357 Mdot
.73253 .71258 Mdot
.42142 .34576 Mdot
.4471 .36375 Mdot
.29466 .50093 Mdot
.64234 .70221 Mdot
.59365 .36889 Mdot
.36779 .46303 Mdot
.38342 .46991 Mdot
.60505 .40737 Mdot
.54223 .65549 Mdot
.57033 .67864 Mdot
.58947 .5954 Mdot
.35028 .6096 Mdot
.59951 .61768 Mdot
.33134 .44846 Mdot
.4568 .35851 Mdot
.3763 .47963 Mdot
.48167 .3729 Mdot
.28393 .69905 Mdot
.61607 .59339 Mdot
.58053 .64201 Mdot
.42663 .18102 Mdot
.59391 .41333 Mdot
.24161 .64782 Mdot
.49203 .38492 Mdot
.34109 .46587 Mdot
.53617 .57221 Mdot
.60751 .3554 Mdot
.35541 .65539 Mdot
.29296 .24636 Mdot
.54261 .62701 Mdot
.62396 .39117 Mdot
.56825 .64244 Mdot
.46853 .60384 Mdot
.65843 .23772 Mdot
.63868 .39677 Mdot
.55441 .19304 Mdot
.61582 .62936 Mdot
.21466 .42595 Mdot
.52868 .59944 Mdot
.44865 .60602 Mdot
.55066 .64186 Mdot
.66333 .41589 Mdot
.59294 .59849 Mdot
.61203 .35538 Mdot
.36361 .43429 Mdot
.49885 .34881 Mdot
.6239 .42695 Mdot
.59639 .56289 Mdot
.59096 .09372 Mdot
.48469 .34837 Mdot
.57623 .60628 Mdot
.47755 .3666 Mdot
.65096 .38432 Mdot
.65286 .42517 Mdot
.19102 .57407 Mdot
.35748 .32177 Mdot
.4897 .34122 Mdot
.56989 .64475 Mdot
.23249 .4301 Mdot
.54986 .6132 Mdot
.54131 .70806 Mdot
.53625 .65222 Mdot
.58779 .65999 Mdot
.20637 .60146 Mdot
.45248 .36797 Mdot
.58519 .19935 Mdot
.19837 .60763 Mdot
.22621 .6274 Mdot
.6058 .43842 Mdot
.35308 .58623 Mdot
.55298 .83085 Mdot
.41407 .26156 Mdot
.31792 .46033 Mdot
.54265 .59651 Mdot
.67144 .4478 Mdot
.4738 .32588 Mdot
.34054 .62312 Mdot
.58118 .5904 Mdot
.38212 .46738 Mdot
.79227 .40489 Mdot
.45042 .37514 Mdot
.63817 .39306 Mdot
.67373 .40762 Mdot
.17889 .41016 Mdot
.56532 .61492 Mdot
.58674 .63939 Mdot
.49207 .32335 Mdot
.2855 .32292 Mdot
.35769 .64124 Mdot
.80474 .49105 Mdot
.48755 .34241 Mdot
.49059 .46853 Mdot
.63901 .3641 Mdot
.54037 .58174 Mdot
.40112 .81087 Mdot
.35431 .38663 Mdot
.46244 .1852 Mdot
.35165 .60763 Mdot
.53215 .70225 Mdot
.66317 .41493 Mdot
.46572 .35048 Mdot
.33686 .30291 Mdot
.62589 .64316 Mdot
.55606 .56407 Mdot
.47538 .64928 Mdot
.43499 .28823 Mdot
.59969 .34646 Mdot
.54561 .63005 Mdot
.42603 .5499 Mdot
.53879 .62054 Mdot
.62567 .56147 Mdot
.5303 .65118 Mdot
.5842 .62556 Mdot
.61452 .39443 Mdot
.533 .68476 Mdot
.32058 .48573 Mdot
.56659 .37947 Mdot
.4803 .47497 Mdot
.57231 .59862 Mdot
.58437 .65469 Mdot
.68241 .64155 Mdot
.28674 .36489 Mdot
.62401 .42483 Mdot
.5853 .41442 Mdot
.45844 .31318 Mdot
.56094 .67179 Mdot
.35648 .49846 Mdot
.55913 .5353 Mdot
.32591 .46156 Mdot
.61233 .3969 Mdot
.34398 .46789 Mdot
.49025 .36106 Mdot
.38049 .4443 Mdot
.40459 .26393 Mdot
.47413 .35459 Mdot
.61552 .42139 Mdot
.59425 .63126 Mdot
.47239 .37456 Mdot
.45583 .67477 Mdot
.35269 .60856 Mdot
.25783 .732 Mdot
.59712 .63362 Mdot
.4983 .25281 Mdot
.65058 .66426 Mdot
.38015 .47515 Mdot
.64182 .22489 Mdot
.61566 .43149 Mdot
.35467 .64692 Mdot
.64889 .43526 Mdot
.57797 .73831 Mdot
.36126 .61587 Mdot
.23718 .69063 Mdot
.43041 .57626 Mdot
.51693 .70716 Mdot
.56356 .66935 Mdot
.49277 .70918 Mdot
.3309 .43695 Mdot
.47176 .32729 Mdot
.32675 .31938 Mdot
.53994 .56695 Mdot
.82802 .44147 Mdot
.65365 .43636 Mdot
.34347 .49706 Mdot
.46094 .34922 Mdot
.44156 .35953 Mdot
.62353 .63088 Mdot
.27009 .53409 Mdot
.55512 .56263 Mdot
.34891 .31016 Mdot
.70724 .70443 Mdot
.56784 .42494 Mdot
.57252 .60806 Mdot
.35522 .43503 Mdot
.56798 .64223 Mdot
.38428 .59662 Mdot
.7944 .64071 Mdot
.56447 .52878 Mdot
.52351 .3661 Mdot
.3728 .65266 Mdot
.65967 .39398 Mdot
.66015 .61958 Mdot
.53259 .32707 Mdot
.56343 .61721 Mdot
.2773 .2211 Mdot
.35794 .59967 Mdot
.30472 .58982 Mdot
.61899 .57887 Mdot
.62978 .60814 Mdot
.43482 .50721 Mdot
.47173 .22855 Mdot
.28043 .42505 Mdot
.60346 .59225 Mdot
.4464 .64967 Mdot
.46376 .37193 Mdot
.53594 .60003 Mdot
.57989 .60838 Mdot
.67711 .52888 Mdot
.44588 .3701 Mdot
.33364 .47306 Mdot
.31502 .45433 Mdot
.34639 .41842 Mdot
.38781 .61201 Mdot
.58809 .34133 Mdot
.43761 .71687 Mdot
.76268 .34822 Mdot
.33455 .64726 Mdot
.62074 .59215 Mdot
.34565 .54835 Mdot
.56142 .63922 Mdot
.34423 .62518 Mdot
.44693 .37134 Mdot
.63024 .4305 Mdot
.63135 .28602 Mdot
.32138 .4496 Mdot
.63145 .6386 Mdot
.36567 .64041 Mdot
.61489 .41416 Mdot
.45414 .75344 Mdot
.6588 .39388 Mdot
.48219 .33748 Mdot
.59355 .33755 Mdot
.34136 .62653 Mdot
.64671 .37757 Mdot
.53 .37098 Mdot
.18389 .58096 Mdot
.53979 .66416 Mdot
.60925 .31559 Mdot
.66246 .39363 Mdot
.58262 .40381 Mdot
.65896 .37787 Mdot
.58344 .56472 Mdot
.50603 .4113 Mdot
.58907 .66419 Mdot
.4561 .37024 Mdot
.34264 .47951 Mdot
.82965 .52357 Mdot
.39541 .34327 Mdot
.5522 .43767 Mdot
.53073 .55454 Mdot
.58185 .58019 Mdot
.57582 .61129 Mdot
.63232 .57421 Mdot
.41017 .25793 Mdot
.5775 .56643 Mdot
.45322 .34358 Mdot
.34373 .4452 Mdot
.55863 .65592 Mdot
.39739 .42767 Mdot
.22003 .60198 Mdot
.33179 .61304 Mdot
.50177 .30659 Mdot
.776 .68335 Mdot
.61655 .41646 Mdot
.36941 .42474 Mdot
.34105 .44179 Mdot
.34434 .6379 Mdot
.48225 .32414 Mdot
.65815 .39016 Mdot
.52443 .69424 Mdot
.37558 .63086 Mdot
.59218 .60119 Mdot
.52165 .39845 Mdot
.83855 .47092 Mdot
.54867 .64715 Mdot
.54966 .58986 Mdot
.32394 .49976 Mdot
.3112 .58369 Mdot
.80261 .32106 Mdot
.4588 .72578 Mdot
.34344 .61778 Mdot
.34678 .59309 Mdot
.60184 .40423 Mdot
.63494 .62485 Mdot
.4815 .37017 Mdot
.68343 .33599 Mdot
.54955 .34454 Mdot
.6432 .25837 Mdot
.43819 .19462 Mdot
.5394 .61312 Mdot
.26834 .32544 Mdot
.5756 .57685 Mdot
.66344 .37944 Mdot
.618 .39628 Mdot
.62904 .41044 Mdot
.47278 .32765 Mdot
.74543 .57024 Mdot
.45807 .33349 Mdot
.84107 .59708 Mdot
.6593 .41718 Mdot
.42676 .57761 Mdot
.36999 .46664 Mdot
.55475 .6791 Mdot
.33209 .62018 Mdot
.61016 .32384 Mdot
.56111 .51707 Mdot
.6829 .46088 Mdot
.33429 .4948 Mdot
.61794 .42558 Mdot
.28106 .33197 Mdot
.64061 .77582 Mdot
.63231 .3368 Mdot
.61932 .53441 Mdot
.4844 .74597 Mdot
.35124 .6223 Mdot
.45967 .18579 Mdot
.33962 .60785 Mdot
.49567 .34061 Mdot
.57467 .63903 Mdot
.58352 .63398 Mdot
.5384 .62126 Mdot
.61532 .60122 Mdot
.42095 .3625 Mdot
.55307 .5499 Mdot
.71387 .308 Mdot
.31871 .45332 Mdot
.42212 .63216 Mdot
.34366 .60588 Mdot
.43373 .36143 Mdot
.34194 .44531 Mdot
.294 .3583 Mdot
.469 .69326 Mdot
.57026 .61046 Mdot
.54273 .60025 Mdot
.78678 .63296 Mdot
.54632 .63033 Mdot
.59281 .69346 Mdot
.322 .45473 Mdot
.65215 .55572 Mdot
.33218 .61325 Mdot
.33754 .6001 Mdot
.47351 .35642 Mdot
.61629 .3946 Mdot
.36398 .60243 Mdot
.36685 .47136 Mdot
.52862 .55623 Mdot
.56796 .5499 Mdot
.66286 .39769 Mdot
.79434 .62956 Mdot
.3767 .58733 Mdot
.23021 .426 Mdot
.61202 .42149 Mdot
.65031 .44483 Mdot
.55427 .56463 Mdot
.4898 .18678 Mdot
.61217 .44776 Mdot
.37432 .64195 Mdot
.43143 .35962 Mdot
.49667 .7402 Mdot
.44586 .32268 Mdot
.63841 .39086 Mdot
.60761 .63866 Mdot
.61176 .40404 Mdot
.56747 .61061 Mdot
.66976 .78033 Mdot
.58626 .62887 Mdot
.75409 .33551 Mdot
.37556 .69547 Mdot
.36993 .44348 Mdot
.28211 .36081 Mdot
.37602 .45387 Mdot
.62703 .43513 Mdot
.6241 .58263 Mdot
.3395 .64072 Mdot
.2079 .53404 Mdot
.70478 .37601 Mdot
.34628 .49097 Mdot
.37496 .49672 Mdot
.43826 .32962 Mdot
.55077 .64363 Mdot
.5628 .56297 Mdot
.356 .44922 Mdot
.5962 .4497 Mdot
.63497 .37918 Mdot
.5678 .63023 Mdot
.58254 .57793 Mdot
.37255 .44661 Mdot
.17768 .5661 Mdot
.49771 .63715 Mdot
.57517 .63295 Mdot
.30405 .4038 Mdot
.44374 .36247 Mdot
.55591 .67865 Mdot
.61098 .55794 Mdot
.36013 .62473 Mdot
.74241 .4433 Mdot
.65199 .74882 Mdot
.44697 .37225 Mdot
.33227 .44473 Mdot
.56358 .62097 Mdot
.35237 .43564 Mdot
.55738 .54901 Mdot
.48261 .23011 Mdot
.3652 .42548 Mdot
.58694 .65728 Mdot
.54656 .65713 Mdot
.65915 .42696 Mdot
.54046 .60683 Mdot
.69967 .65136 Mdot
.32563 .48107 Mdot
.6221 .63123 Mdot
.80068 .5359 Mdot
.46753 .31933 Mdot
.58208 .67448 Mdot
.37768 .62539 Mdot
.5654 .72 Mdot
.5687 .28363 Mdot
.39409 .77451 Mdot
.33174 .60621 Mdot
.57677 .56285 Mdot
.36591 .50062 Mdot
.5117 .34981 Mdot
.73743 .30386 Mdot
.53664 .5872 Mdot
.49585 .33377 Mdot
.45781 .35882 Mdot
.33847 .62263 Mdot
.23656 .2874 Mdot
.61647 .57801 Mdot
.60978 .60886 Mdot
.71587 .57434 Mdot
.59055 .3927 Mdot
.59524 .6234 Mdot
.61622 .62301 Mdot
.45117 .34841 Mdot
.62334 .67224 Mdot
.73485 .64992 Mdot
.79809 .46568 Mdot
.5071 .32827 Mdot
.66377 .29362 Mdot
.35548 .42622 Mdot
.3603 .59348 Mdot
.64801 .41817 Mdot
.35781 .64234 Mdot
.37042 .47504 Mdot
.61143 .62606 Mdot
.49838 .32829 Mdot
.69637 .63414 Mdot
.48023 .36858 Mdot
.33381 .72101 Mdot
.61465 .35829 Mdot
.42577 .32501 Mdot
.2567 .24449 Mdot
.31333 .3823 Mdot
.43054 .28412 Mdot
.35578 .62217 Mdot
.36691 .52103 Mdot
.58102 .57745 Mdot
.44589 .1851 Mdot
.62091 .5955 Mdot
.79655 .51329 Mdot
.31587 .45962 Mdot
.31334 .48933 Mdot
.57388 .63596 Mdot
.6953 .70972 Mdot
.5136 .34595 Mdot
.44178 .34556 Mdot
.59854 .65175 Mdot
.48417 .33408 Mdot
.60098 .61105 Mdot
.33036 .45115 Mdot
.4939 .16519 Mdot
.58523 .59439 Mdot
.59825 .54098 Mdot
.49888 .2404 Mdot
.20597 .61186 Mdot
.40511 .6031 Mdot
.15915 .47236 Mdot
.67728 .76395 Mdot
.48243 .33364 Mdot
.60153 .65667 Mdot
.65996 .28704 Mdot
.34355 .50477 Mdot
.54149 .36304 Mdot
.60592 .6253 Mdot
.62057 .61087 Mdot
.53277 .57245 Mdot
.55438 .57562 Mdot
.33521 .2275 Mdot
.70192 .35958 Mdot
.73745 .49414 Mdot
.54158 .61364 Mdot
.47866 .68797 Mdot
.48675 .35284 Mdot
.68384 .41457 Mdot
.3524 .65002 Mdot
.53947 .61094 Mdot
.59551 .35293 Mdot
.4943 .31886 Mdot
.85507 .57355 Mdot
.49718 .3316 Mdot
.33361 .4662 Mdot
.5011 .35624 Mdot
.56844 .58311 Mdot
.6466 .40748 Mdot
.4356 .4545 Mdot
.35895 .35267 Mdot
.31384 .46856 Mdot
.57238 .59319 Mdot
.41544 .58103 Mdot
.32321 .48882 Mdot
.2348 .64603 Mdot
.643 .41661 Mdot
.43952 .6462 Mdot
.61295 .40021 Mdot
.6044 .64558 Mdot
.60355 .64536 Mdot
.46344 .30847 Mdot
.49432 .35934 Mdot
.61364 .39871 Mdot
.18064 .34439 Mdot
.38144 .59496 Mdot
.63019 .40715 Mdot
.64335 .61461 Mdot
.47609 .42546 Mdot
.6424 .40953 Mdot
.32161 .65602 Mdot
.45362 .35536 Mdot
.59754 .41245 Mdot
.52492 .59234 Mdot
.53593 .74148 Mdot
.36716 .58936 Mdot
.30935 .45674 Mdot
.42805 .74296 Mdot
.33615 .48873 Mdot
.42906 .35257 Mdot
.37596 .45056 Mdot
.44999 .36343 Mdot
.55676 .29722 Mdot
.56656 .3909 Mdot
.3989 .51596 Mdot
.42509 .34864 Mdot
.37441 .45601 Mdot
.57196 .64072 Mdot
.3805 .56723 Mdot
.63644 .61057 Mdot
.57774 .55732 Mdot
.44519 .34921 Mdot
.65488 .42768 Mdot
.59958 .4343 Mdot
.5187 .70226 Mdot
.61725 .38989 Mdot
.32729 .47664 Mdot
.712 .42276 Mdot
.39781 .28668 Mdot
.44818 .3232 Mdot
.4982 .35187 Mdot
.55575 .63606 Mdot
.36244 .45573 Mdot
.3118 .47577 Mdot
.44526 .3221 Mdot
.52572 .20591 Mdot
.61978 .56247 Mdot
.58198 .40943 Mdot
.5919 .3949 Mdot
.64013 .39915 Mdot
.65162 .36832 Mdot
.59564 .71551 Mdot
.4701 .36327 Mdot
.64742 .43301 Mdot
.55466 .63602 Mdot
.6152 .61972 Mdot
.6762 .32374 Mdot
.3722 .59549 Mdot
.56902 .66209 Mdot
.53245 .65315 Mdot
.54103 .57963 Mdot
.37858 .46786 Mdot
.56671 .69643 Mdot
.38393 .44448 Mdot
.35212 .50256 Mdot
.34784 .50349 Mdot
.41948 .26097 Mdot
.75626 .66996 Mdot
.58506 .78227 Mdot
.62206 .62631 Mdot
.24368 .36209 Mdot
.35642 .46609 Mdot
.72026 .37268 Mdot
.55109 .3261 Mdot
.53664 .57335 Mdot
.23055 .50872 Mdot
.36081 .44837 Mdot
.60704 .41501 Mdot
.59723 .62774 Mdot
.36779 .42025 Mdot
.38162 .61694 Mdot
.62848 .62702 Mdot
.34553 .42469 Mdot
.64851 .37737 Mdot
.38854 .62523 Mdot
.59852 .42057 Mdot
.34878 .50388 Mdot
.63927 .6427 Mdot
.61532 .17415 Mdot
.37527 .41775 Mdot
.19829 .45889 Mdot
.57673 .49925 Mdot
.56839 .63476 Mdot
.38536 .43635 Mdot
.64878 .4482 Mdot
.42985 .35253 Mdot
.52326 .48384 Mdot
.60183 .38924 Mdot
.31343 .48949 Mdot
.36261 .49324 Mdot
.31384 .4683 Mdot
.60988 .37757 Mdot
.60123 .66913 Mdot
.6178 .38063 Mdot
.50322 .35573 Mdot
.55308 .60376 Mdot
.54289 .78978 Mdot
.29721 .31123 Mdot
.61004 .41642 Mdot
.33897 .48204 Mdot
.32115 .63541 Mdot
.57871 .58249 Mdot
.27562 .32721 Mdot
.56961 .64067 Mdot
.44556 .36042 Mdot
.70784 .47259 Mdot
.65712 .55746 Mdot
.5934 .65944 Mdot
.55341 .63036 Mdot
.44273 .34285 Mdot
.57608 .59353 Mdot
.55065 .64228 Mdot
.40423 .26327 Mdot
.62243 .37557 Mdot
.59234 .59417 Mdot
.34954 .47972 Mdot
.37824 .31051 Mdot
.61139 .55232 Mdot
.39747 .50417 Mdot
.4422 .63814 Mdot
.69024 .48905 Mdot
.62156 .59815 Mdot
.53534 .39608 Mdot
.55555 .56857 Mdot
.60468 .58235 Mdot
.55605 .63004 Mdot
.27725 .28001 Mdot
.34928 .42435 Mdot
.35152 .43872 Mdot
.35307 .5899 Mdot
.44114 .63883 Mdot
.36876 .62142 Mdot
.45582 .36063 Mdot
.27982 .55 Mdot
.38304 .44114 Mdot
.64287 .38505 Mdot
.59136 .57332 Mdot
.37818 .41933 Mdot
.54013 .57624 Mdot
.56783 .58508 Mdot
.36363 .49772 Mdot
.3475 .42652 Mdot
.31095 .69189 Mdot
.37752 .6 Mdot
.6257 .41479 Mdot
.56555 .65658 Mdot
.37069 .63654 Mdot
.62187 .59217 Mdot
.42719 .69963 Mdot
.62974 .41294 Mdot
.62219 .37713 Mdot
.602 .43865 Mdot
.60617 .62906 Mdot
.5729 .5826 Mdot
.45698 .3338 Mdot
.61997 .43298 Mdot
.47269 .31862 Mdot
.49086 .49839 Mdot
.25036 .62206 Mdot
.60648 .62511 Mdot
.62965 .32343 Mdot
.37547 .61843 Mdot
.3497 .49106 Mdot
.84188 .48721 Mdot
.35353 .58968 Mdot
.56714 .61463 Mdot
.34517 .49938 Mdot
.34878 .63177 Mdot
.46189 .61085 Mdot
.82294 .61121 Mdot
.32264 .63367 Mdot
.55417 .63524 Mdot
.62915 .66651 Mdot
.16185 .45557 Mdot
.32659 .61646 Mdot
.4863 .35941 Mdot
.60394 .63019 Mdot
.58294 .39019 Mdot
.36446 .64133 Mdot
.25513 .44488 Mdot
.35367 .44447 Mdot
.54542 .73857 Mdot
.57209 .52447 Mdot
.66497 .45858 Mdot
.35166 .59229 Mdot
.65616 .39956 Mdot
.60911 .69412 Mdot
.55332 .56584 Mdot
.32701 .61369 Mdot
.43537 .37839 Mdot
.33846 .45173 Mdot
.3621 .33017 Mdot
.60713 .37921 Mdot
.43582 .38445 Mdot
.35002 .48776 Mdot
.22746 .43366 Mdot
.77578 .4093 Mdot
.57036 .68006 Mdot
.20153 .39693 Mdot
.49442 .27084 Mdot
.53139 .61342 Mdot
.34279 .65462 Mdot
.46937 .37584 Mdot
.48286 .31349 Mdot
.48281 .34086 Mdot
.5455 .29825 Mdot
.65365 .34346 Mdot
.34259 .42389 Mdot
.50672 .39164 Mdot
.36286 .59409 Mdot
.4993 .73347 Mdot
.57502 .55516 Mdot
.58439 .58356 Mdot
.56243 .6514 Mdot
.53811 .60992 Mdot
.57203 .56756 Mdot
.48795 .32756 Mdot
.54272 .28314 Mdot
.65756 .3392 Mdot
.63662 .411 Mdot
.32072 .56601 Mdot
.36268 .47213 Mdot
.30056 .4736 Mdot
.36056 .63439 Mdot
.28452 .40444 Mdot
.39638 .42624 Mdot
.34191 .46784 Mdot
.5492 .65317 Mdot
.6284 .38072 Mdot
.56332 .68471 Mdot
.55369 .63264 Mdot
.32536 .46983 Mdot
.44933 .50426 Mdot
.7082 .6696 Mdot
.31415 .67784 Mdot
.3932 .60644 Mdot
.52053 .39219 Mdot
.34034 .59537 Mdot
.59691 .55382 Mdot
.66322 .24444 Mdot
.3719 .47367 Mdot
.3464 .45793 Mdot
.37496 .60103 Mdot
.49136 .18436 Mdot
.64653 .42313 Mdot
.41549 .37647 Mdot
.46692 .36923 Mdot
.60436 .64201 Mdot
.80339 .42317 Mdot
.57825 .49469 Mdot
.26274 .5349 Mdot
.48542 .34501 Mdot
.36707 .43496 Mdot
.58605 .54635 Mdot
.54848 .62211 Mdot
.37155 .62504 Mdot
.36971 .77223 Mdot
.5272 .65187 Mdot
.32468 .79138 Mdot
.83505 .55183 Mdot
.63717 .7464 Mdot
.55792 .56367 Mdot
.61836 .37643 Mdot
.31846 .44797 Mdot
.35308 .59784 Mdot
.62806 .64199 Mdot
.68846 .74007 Mdot
.66209 .40237 Mdot
.47342 .35191 Mdot
.46652 .46935 Mdot
.48357 .73638 Mdot
.59218 .56744 Mdot
.61877 .61693 Mdot
.60392 .57877 Mdot
.87806 .43018 Mdot
.38354 .45312 Mdot
.60802 .41226 Mdot
.33903 .62551 Mdot
.6254 .38876 Mdot
.36717 .43916 Mdot
.40393 .52663 Mdot
.58035 .64529 Mdot
.65991 .38495 Mdot
.65567 .4026 Mdot
.48184 .31507 Mdot
.44049 .37149 Mdot
.47947 .4808 Mdot
.58662 .62724 Mdot
.39225 .46741 Mdot
.65305 .43069 Mdot
.53177 .38974 Mdot
.36245 .61735 Mdot
.45231 .35479 Mdot
.54122 .6086 Mdot
.3816 .44165 Mdot
.52508 .63105 Mdot
.62838 .42559 Mdot
.34293 .46746 Mdot
.28733 .68591 Mdot
.33209 .61037 Mdot
.61372 .61692 Mdot
.37918 .66363 Mdot
.32908 .4472 Mdot
.57702 .57411 Mdot
.21086 .47135 Mdot
.3199 .65152 Mdot
.36769 .37111 Mdot
.33103 .49669 Mdot
.44324 .26421 Mdot
.601 .40163 Mdot
.45598 .24177 Mdot
.33904 .46051 Mdot
.23274 .41032 Mdot
.30448 .70411 Mdot
.53574 .5509 Mdot
.63117 .39719 Mdot
.46015 .25313 Mdot
.59781 .82218 Mdot
.18411 .48158 Mdot
.57698 .60678 Mdot
.38993 .4636 Mdot
.35846 .63168 Mdot
.44788 .32542 Mdot
.3947 .37603 Mdot
.34313 .57354 Mdot
.39822 .47299 Mdot
.55621 .6295 Mdot
.65492 .38869 Mdot
.45972 .33965 Mdot
.56975 .28863 Mdot
.36014 .47631 Mdot
.34342 .48185 Mdot
.62935 .59316 Mdot
.37435 .61143 Mdot
.34436 .26079 Mdot
.32502 .45396 Mdot
.80333 .59952 Mdot
.29763 .4766 Mdot
.38111 .62438 Mdot
.54928 .57736 Mdot
.54793 .7211 Mdot
.62798 .63436 Mdot
.19807 .52182 Mdot
.36745 .46736 Mdot
.62728 .41988 Mdot
.56251 .55732 Mdot
.80982 .53926 Mdot
.3287 .47774 Mdot
.50526 .40596 Mdot
.27193 .46643 Mdot
.46505 .36549 Mdot
.84041 .48363 Mdot
.60217 .61889 Mdot
.51134 .35017 Mdot
.36863 .62671 Mdot
.57901 .62976 Mdot
.57018 .58036 Mdot
.67017 .40385 Mdot
.47362 .31409 Mdot
.30843 .68947 Mdot
.50212 .3467 Mdot
.49194 .35114 Mdot
.5996 .35762 Mdot
.60167 .59952 Mdot
.33287 .46833 Mdot
.36029 .4496 Mdot
.52498 .59742 Mdot
.44823 .15177 Mdot
.65251 .41872 Mdot
.30788 .46379 Mdot
.86963 .40404 Mdot
.52904 .61662 Mdot
.83131 .4807 Mdot
.35173 .75942 Mdot
.46949 .37297 Mdot
.55414 .6361 Mdot
.64944 .38068 Mdot
.27741 .43238 Mdot
.34024 .48029 Mdot
.52499 .5825 Mdot
.46171 .33902 Mdot
.37918 .59969 Mdot
.32058 .48046 Mdot
.26914 .53586 Mdot
.61567 .5952 Mdot
.22636 .53394 Mdot
.37983 .48139 Mdot
.5297 .83066 Mdot
.30515 .34178 Mdot
.62908 .39945 Mdot
.56508 .58533 Mdot
.61174 .42722 Mdot
.34055 .63106 Mdot
.46862 .47074 Mdot
.45556 .34974 Mdot
.6381 .70265 Mdot
.68741 .26094 Mdot
.31385 .46798 Mdot
.60917 .4194 Mdot
.6028 .65205 Mdot
.47912 .2245 Mdot
.60401 .61434 Mdot
.65411 .60288 Mdot
.31443 .68665 Mdot
.44821 .33454 Mdot
.46729 .37145 Mdot
.56216 .57291 Mdot
.34755 .64019 Mdot
.36446 .47256 Mdot
.33107 .45853 Mdot
.47133 .85126 Mdot
.4132 .37372 Mdot
.77394 .62333 Mdot
.62035 .60995 Mdot
.39287 .48264 Mdot
.40225 .31728 Mdot
.4934 .32561 Mdot
.59703 .67353 Mdot
.35206 .49796 Mdot
.42278 .62584 Mdot
.46787 .6372 Mdot
.55563 .56657 Mdot
.63901 .62025 Mdot
.47836 .36677 Mdot
.61997 .34317 Mdot
.35185 .43322 Mdot
.51978 .62763 Mdot
.41132 .50782 Mdot
.45945 .60939 Mdot
.83902 .56325 Mdot
.62557 .41454 Mdot
.26885 .51338 Mdot
.48727 .32648 Mdot
.59294 .53774 Mdot
.3341 .62073 Mdot
.37799 .50224 Mdot
.37424 .43076 Mdot
.56019 .61949 Mdot
.57603 .54759 Mdot
.8226 .5579 Mdot
.63572 .38389 Mdot
.48033 .35588 Mdot
.58728 .63743 Mdot
.63359 .3016 Mdot
.53957 .62424 Mdot
.45913 .32854 Mdot
.59663 .16702 Mdot
.63387 .62339 Mdot
.60738 .61077 Mdot
.34085 .26503 Mdot
.59865 .38976 Mdot
.6424 .43852 Mdot
.81566 .421 Mdot
.62004 .61062 Mdot
.83745 .53394 Mdot
.62171 .41863 Mdot
.64117 .42727 Mdot
.36513 .29314 Mdot
.58208 .58468 Mdot
.48949 .59138 Mdot
.45291 .36765 Mdot
.49255 .3519 Mdot
.61245 .37982 Mdot
.54522 .67109 Mdot
.43963 .36611 Mdot
.31975 .25382 Mdot
.36366 .45681 Mdot
.60013 .20061 Mdot
.65543 .41671 Mdot
.4729 .28262 Mdot
.49392 .33801 Mdot
.81471 .63324 Mdot
.36342 .39237 Mdot
.57566 .64267 Mdot
.61939 .60706 Mdot
.37236 .59896 Mdot
.57468 .65904 Mdot
.31291 .48863 Mdot
.48485 .33436 Mdot
.68883 .70179 Mdot
.62872 .41007 Mdot
.59097 .61961 Mdot
.22087 .49778 Mdot
.2595 .68695 Mdot
.279 .50343 Mdot
.65932 .39923 Mdot
.61842 .40127 Mdot
.37846 .44329 Mdot
.38772 .46898 Mdot
.59502 .5842 Mdot
.43971 .34283 Mdot
.61663 .43049 Mdot
.45282 .33327 Mdot
.36976 .47643 Mdot
.33565 .46783 Mdot
.33675 .43056 Mdot
.57244 .55328 Mdot
.34215 .47387 Mdot
.26267 .64932 Mdot
.45563 .40039 Mdot
.59214 .36777 Mdot
.84972 .44574 Mdot
.57395 .29283 Mdot
.67953 .43833 Mdot
.37628 .63435 Mdot
.31882 .458 Mdot
.50808 .35039 Mdot
.55328 .59317 Mdot
.54048 .59587 Mdot
.41252 .27366 Mdot
.50955 .34314 Mdot
.34016 .62682 Mdot
.49717 .36313 Mdot
.33834 .62384 Mdot
.23561 .52983 Mdot
.54814 .64284 Mdot
.55029 .54934 Mdot
.49009 .33349 Mdot
.34237 .47091 Mdot
.35236 .44126 Mdot
.32423 .62891 Mdot
.44458 .52306 Mdot
.32539 .4904 Mdot
.6443 .42816 Mdot
.66454 .70214 Mdot
.37485 .48447 Mdot
.59627 .62656 Mdot
.4308 .71702 Mdot
.43209 .18253 Mdot
.6328 .57521 Mdot
.37373 .2805 Mdot
.69797 .6011 Mdot
.55287 .56038 Mdot
.43853 .18054 Mdot
.51601 .36143 Mdot
.60427 .39271 Mdot
.3225 .45004 Mdot
.30053 .44466 Mdot
.49867 .60665 Mdot
.38884 .62702 Mdot
.62992 .65105 Mdot
.65872 .38366 Mdot
.67427 .41006 Mdot
.53562 .72141 Mdot
.18992 .4954 Mdot
.35105 .63108 Mdot
.36355 .63256 Mdot
.33617 .4608 Mdot
.25806 .73587 Mdot
.64065 .56578 Mdot
.341 .62293 Mdot
.61111 .45673 Mdot
.55662 .62553 Mdot
.42902 .63318 Mdot
.5824 .48187 Mdot
.61125 .3789 Mdot
.48517 .68895 Mdot
.32999 .47497 Mdot
.61519 .38979 Mdot
.62532 .27827 Mdot
.59252 .66863 Mdot
.63053 .41164 Mdot
.45391 .33449 Mdot
.29745 .36535 Mdot
.64983 .42788 Mdot
.43319 .70984 Mdot
.43817 .33534 Mdot
.53258 .38805 Mdot
.49703 .68058 Mdot
.11635 .57501 Mdot
.48664 .3303 Mdot
.36175 .49304 Mdot
.35886 .44929 Mdot
.33109 .45919 Mdot
.62711 .38735 Mdot
.3136 .46712 Mdot
.63653 .38547 Mdot
.18637 .42239 Mdot
.44695 .19397 Mdot
.34281 .6196 Mdot
.35985 .33234 Mdot
.64909 .39031 Mdot
.71772 .33352 Mdot
.36764 .15769 Mdot
.55665 .64017 Mdot
.48029 .31136 Mdot
.34442 .62068 Mdot
.3024 .76359 Mdot
.35578 .62586 Mdot
.70956 .71849 Mdot
.67455 .47563 Mdot
.59414 .61303 Mdot
.76517 .57342 Mdot
.32942 .63879 Mdot
.63283 .36173 Mdot
.57685 .57483 Mdot
.46447 .53361 Mdot
.36188 .62742 Mdot
.3836 .61569 Mdot
.59499 .58916 Mdot
.61799 .42578 Mdot
.33809 .48346 Mdot
.49853 .34773 Mdot
.35296 .64493 Mdot
.63696 .66519 Mdot
.61474 .64839 Mdot
.5737 .6454 Mdot
.65759 .32031 Mdot
.33433 .65734 Mdot
.48161 .33315 Mdot
.24541 .29038 Mdot
.36851 .4985 Mdot
.43987 .56889 Mdot
.82073 .58116 Mdot
.52544 .30817 Mdot
.36722 .46634 Mdot
.35525 .43567 Mdot
.57333 .56749 Mdot
.64881 .56006 Mdot
.6606 .47409 Mdot
.41638 .54369 Mdot
.3133 .44962 Mdot
.334 .45502 Mdot
.62832 .4401 Mdot
.61406 .74671 Mdot
.64022 .58335 Mdot
.44934 .37334 Mdot
.3613 .42524 Mdot
.43005 .21268 Mdot
.37163 .6017 Mdot
.69633 .46002 Mdot
.54965 .64581 Mdot
.57896 .64214 Mdot
.46391 .34322 Mdot
.45821 .33438 Mdot
.2705 .44779 Mdot
.65298 .74045 Mdot
.6949 .60927 Mdot
.54091 .27103 Mdot
.68374 .50058 Mdot
.65343 .43595 Mdot
.61017 .41686 Mdot
.3541 .36418 Mdot
.5024 .33784 Mdot
.55475 .55898 Mdot
.61464 .39603 Mdot
.41953 .60906 Mdot
.63014 .70738 Mdot
.59484 .73093 Mdot
.83276 .50622 Mdot
.56877 .60604 Mdot
.63187 .37384 Mdot
.59716 .39017 Mdot
.59506 .38379 Mdot
.45848 .26736 Mdot
.60401 .59283 Mdot
.57248 .60544 Mdot
.56463 .56086 Mdot
.48419 .20539 Mdot
.60465 .58665 Mdot
.47987 .25173 Mdot
.48266 .46353 Mdot
.75503 .43346 Mdot
.52143 .63244 Mdot
.50515 .36014 Mdot
.60579 .57419 Mdot
.34565 .63959 Mdot
.56969 .65011 Mdot
.59883 .73116 Mdot
.48657 .34921 Mdot
.53272 .68568 Mdot
.56286 .29993 Mdot
.52921 .58461 Mdot
.37329 .64179 Mdot
.5436 .32978 Mdot
.58827 .80892 Mdot
.40332 .61058 Mdot
.6462 .42677 Mdot
.36503 .46151 Mdot
.50952 .34806 Mdot
.34137 .46311 Mdot
.53193 .5615 Mdot
.33947 .36727 Mdot
.31376 .7637 Mdot
.46078 .52436 Mdot
.53901 .60657 Mdot
.62822 .55365 Mdot
.63603 .43 Mdot
.36068 .49965 Mdot
.65004 .4549 Mdot
.58444 .5648 Mdot
.34894 .60967 Mdot
.3702 .6245 Mdot
.5115 .48938 Mdot
.46111 .8207 Mdot
.37499 .22882 Mdot
.46768 .33923 Mdot
.32327 .45714 Mdot
.33178 .61957 Mdot
.24057 .39213 Mdot
.47669 .37816 Mdot
.44307 .35234 Mdot
.48231 .35268 Mdot
.61125 .63073 Mdot
.35329 .4238 Mdot
.75743 .43464 Mdot
.36117 .50486 Mdot
.57465 .59127 Mdot
.37989 .46663 Mdot
.34064 .49578 Mdot
.35112 .60161 Mdot
.48408 .35342 Mdot
.37098 .47267 Mdot
.60976 .64128 Mdot
.61823 .41759 Mdot
.4274 .29685 Mdot
.35766 .69235 Mdot
.19277 .50015 Mdot
.50997 .52372 Mdot
.60149 .38112 Mdot
.57272 .81253 Mdot
.44693 .36628 Mdot
.5141 .20529 Mdot
.31224 .69367 Mdot
.62622 .58982 Mdot
.46597 .14964 Mdot
.30367 .49656 Mdot
.34088 .49423 Mdot
.5503 .57526 Mdot
.29921 .49696 Mdot
.59517 .6171 Mdot
.3611 .48599 Mdot
.40811 .39339 Mdot
.61761 .351 Mdot
.34724 .47219 Mdot
.51527 .61032 Mdot
.56833 .57647 Mdot
.61769 .37782 Mdot
.38998 .45143 Mdot
.63478 .63418 Mdot
.50749 .86426 Mdot
.46336 .32863 Mdot
.52147 .29665 Mdot
.41593 .72111 Mdot
.48594 .32438 Mdot
.63229 .40516 Mdot
.58042 .55791 Mdot
.36738 .62797 Mdot
.64944 .38819 Mdot
.61119 .72893 Mdot
.33813 .6035 Mdot
.57784 .18205 Mdot
.59749 .38796 Mdot
.34302 .49072 Mdot
.33622 .63242 Mdot
.59312 .66249 Mdot
.35015 .50635 Mdot
.27956 .36799 Mdot
.36421 .46856 Mdot
.57088 .56415 Mdot
.3849 .34703 Mdot
.48088 .35657 Mdot
.57707 .61099 Mdot
.33375 .49042 Mdot
.37436 .28219 Mdot
.61907 .62651 Mdot
.56108 .5695 Mdot
.81258 .59756 Mdot
.73554 .37166 Mdot
.35898 .62127 Mdot
.59895 .42392 Mdot
.55534 .63732 Mdot
.37791 .62636 Mdot
.27123 .61117 Mdot
.59814 .637 Mdot
.66249 .40216 Mdot
.59751 .67415 Mdot
.39002 .4585 Mdot
.4726 .3205 Mdot
.42042 .55511 Mdot
.38135 .61798 Mdot
.14453 .55917 Mdot
.36245 .42776 Mdot
.58388 .55419 Mdot
.54109 .6248 Mdot
.42456 .75992 Mdot
.60716 .39041 Mdot
.59963 .46822 Mdot
.61429 .61635 Mdot
.49345 .20055 Mdot
.5798 .62532 Mdot
.31243 .50513 Mdot
.64588 .42403 Mdot
.6106 .60478 Mdot
.4191 .32731 Mdot
.59757 .54137 Mdot
.36558 .59043 Mdot
.30971 .2966 Mdot
.60795 .66549 Mdot
.58409 .17291 Mdot
.4925 .51813 Mdot
.34715 .47404 Mdot
.2276 .6071 Mdot
.49514 .86971 Mdot
.55108 .30428 Mdot
.62771 .38975 Mdot
.34073 .76123 Mdot
.33304 .46878 Mdot
.21707 .54148 Mdot
.59098 .81891 Mdot
.56153 .57958 Mdot
.58964 .56603 Mdot
.4764 .74817 Mdot
.35564 .50377 Mdot
.38731 .48194 Mdot
.53063 .55651 Mdot
.61039 .54783 Mdot
.33741 .47291 Mdot
.62874 .61765 Mdot
.5135 .62026 Mdot
.48084 .31174 Mdot
.66069 .40712 Mdot
.44685 .33476 Mdot
.43826 .35852 Mdot
.28399 .29764 Mdot
.47489 .53417 Mdot
.4625 .32615 Mdot
.46485 .37517 Mdot
.43629 .62536 Mdot
.68198 .71819 Mdot
.35689 .64265 Mdot
.493 .83746 Mdot
.33866 .4532 Mdot
.60549 .59958 Mdot
.59313 .39257 Mdot
.68913 .61393 Mdot
.28321 .6327 Mdot
.69194 .28251 Mdot
.5668 .55825 Mdot
.33077 .47968 Mdot
.50681 .29111 Mdot
.5765 .68988 Mdot
.3609 .417 Mdot
.59226 .63437 Mdot
.31471 .49131 Mdot
.71306 .68049 Mdot
.23422 .4092 Mdot
.3017 .44786 Mdot
.5827 .39587 Mdot
.58105 .63854 Mdot
.65538 .37679 Mdot
.49227 .32558 Mdot
.34911 .64237 Mdot
.36359 .62024 Mdot
.58465 .57924 Mdot
.61987 .53732 Mdot
.23385 .55483 Mdot
.57695 .58099 Mdot
.55481 .62193 Mdot
.52491 .35004 Mdot
.55444 .62819 Mdot
.53522 .61415 Mdot
.54008 .57259 Mdot
.53704 .56529 Mdot
.49144 .35218 Mdot
.28085 .40862 Mdot
.4997 .58923 Mdot
.52775 .54724 Mdot
.43057 .34841 Mdot
.34392 .7469 Mdot
.44155 .36564 Mdot
.60381 .81212 Mdot
.47101 .37173 Mdot
.35937 .61377 Mdot
.36744 .75349 Mdot
.55976 .52192 Mdot
.66638 .41176 Mdot
.52486 .32667 Mdot
.34182 .63463 Mdot
.4842 .3381 Mdot
.36143 .48847 Mdot
.82095 .59169 Mdot
.67594 .3882 Mdot
.6946 .34438 Mdot
.54688 .35243 Mdot
.2875 .39177 Mdot
.37919 .44213 Mdot
.62227 .35928 Mdot
.73262 .64353 Mdot
.53718 .61325 Mdot
.37699 .62797 Mdot
.59256 .58284 Mdot
.49649 .32647 Mdot
.32833 .46994 Mdot
.18504 .45378 Mdot
.37209 .62433 Mdot
.85838 .47258 Mdot
.35757 .44272 Mdot
.53522 .60082 Mdot
.43998 .36631 Mdot
.82088 .38048 Mdot
.44709 .33768 Mdot
.63467 .50183 Mdot
.60407 .40631 Mdot
.16196 .48968 Mdot
.64192 .39205 Mdot
.26196 .38855 Mdot
.77203 .2771 Mdot
.23991 .45924 Mdot
.61632 .42076 Mdot
.39737 .53159 Mdot
.56496 .61677 Mdot
.57488 .6458 Mdot
.21306 .42109 Mdot
.59195 .40998 Mdot
.54414 .6212 Mdot
.40558 .29625 Mdot
.44011 .38445 Mdot
.81672 .46478 Mdot
.37554 .44219 Mdot
.59752 .61997 Mdot
.50128 .31825 Mdot
.51254 .33896 Mdot
.34191 .43537 Mdot
.4431 .35736 Mdot
.57373 .60288 Mdot
.64814 .39049 Mdot
.41236 .46403 Mdot
.36614 .60789 Mdot
.26788 .73119 Mdot
.36643 .58309 Mdot
.36803 .4654 Mdot
.63672 .6092 Mdot
.3365 .46757 Mdot
.61886 .86955 Mdot
.57053 .61592 Mdot
.62256 .41953 Mdot
.55042 .62162 Mdot
.57711 .63673 Mdot
.54681 .55939 Mdot
.34161 .48373 Mdot
.31463 .6825 Mdot
.61771 .63478 Mdot
.45496 .35263 Mdot
.7147 .48236 Mdot
.5728 .66538 Mdot
.35784 .54775 Mdot
.58333 .73101 Mdot
.57725 .34214 Mdot
.59868 .41165 Mdot
.3529 .47253 Mdot
.62496 .40962 Mdot
.52559 .1917 Mdot
.63262 .4052 Mdot
.69852 .52783 Mdot
.73919 .64073 Mdot
.78587 .59025 Mdot
.79105 .57342 Mdot
.43871 .47464 Mdot
.59379 .41541 Mdot
.3927 .63231 Mdot
.61977 .43111 Mdot
.60698 .38417 Mdot
.45777 .10181 Mdot
.66377 .38672 Mdot
.60389 .62419 Mdot
.55648 .65729 Mdot
.24467 .424 Mdot
.42212 .68122 Mdot
.55138 .60538 Mdot
.54616 .60778 Mdot
.33152 .62326 Mdot
.52176 .19548 Mdot
.35369 .3743 Mdot
.73251 .36728 Mdot
.26902 .68681 Mdot
.59338 .5854 Mdot
.56366 .64731 Mdot
.5083 .5804 Mdot
.74931 .2969 Mdot
.26075 .3171 Mdot
.58053 .39323 Mdot
.52674 .55253 Mdot
.22257 .48305 Mdot
.56705 .55691 Mdot
.61736 .62156 Mdot
.56758 .61017 Mdot
.33251 .46916 Mdot
.59843 .41777 Mdot
.52682 .57531 Mdot
.40894 .76123 Mdot
.60948 .6263 Mdot
.49154 .27647 Mdot
.17982 .6154 Mdot
.60312 .61867 Mdot
.64024 .44452 Mdot
.57159 .64505 Mdot
.61412 .3845 Mdot
.62517 .36839 Mdot
.53122 .55182 Mdot
.67955 .50072 Mdot
.62426 .44032 Mdot
.57442 .5904 Mdot
.36114 .49103 Mdot
.52197 .8264 Mdot
.57676 .56662 Mdot
.35952 .64182 Mdot
.61908 .60947 Mdot
.38497 .62889 Mdot
.55476 .61399 Mdot
.35559 .42763 Mdot
.67984 .58304 Mdot
.34421 .45759 Mdot
.21058 .38072 Mdot
.34378 .42726 Mdot
.86148 .50232 Mdot
.60383 .37772 Mdot
.37456 .33502 Mdot
.6214 .22537 Mdot
.43728 .25122 Mdot
.5331 .41892 Mdot
.44772 .439 Mdot
.44008 .34333 Mdot
.60628 .39764 Mdot
.57879 .22123 Mdot
.30861 .57878 Mdot
.31475 .54484 Mdot
.3205 .4847 Mdot
.22425 .29677 Mdot
.56229 .18301 Mdot
.59994 .55435 Mdot
.74479 .59422 Mdot
.74634 .52474 Mdot
.56343 .55617 Mdot
.54942 .55626 Mdot
.29043 .46685 Mdot
.62583 .62785 Mdot
.63456 .30502 Mdot
.37279 .45797 Mdot
.34544 .63712 Mdot
.62846 .42866 Mdot
.37904 .59897 Mdot
.30045 .621 Mdot
.44812 .43307 Mdot
.36569 .48279 Mdot
.63359 .63217 Mdot
.55 .59909 Mdot
.62172 .38076 Mdot
.68769 .43408 Mdot
.64714 .43446 Mdot
.34652 .6247 Mdot
.37259 .45089 Mdot
.39942 .19364 Mdot
.5474 .59946 Mdot
.65417 .40594 Mdot
.53889 .42865 Mdot
.55326 .63345 Mdot
.4922 .33029 Mdot
.56534 .62236 Mdot
.62172 .42807 Mdot
.55432 .62777 Mdot
.64034 .39167 Mdot
.36379 .46014 Mdot
.53416 .58339 Mdot
.54873 .5726 Mdot
.84124 .44134 Mdot
.34523 .6142 Mdot
.62324 .35766 Mdot
.42988 .58533 Mdot
.55227 .64021 Mdot
.34993 .32017 Mdot
.59507 .63145 Mdot
.60339 .3476 Mdot
.60769 .56201 Mdot
.52287 .29912 Mdot
.54097 .53767 Mdot
.59151 .57732 Mdot
.55273 .47381 Mdot
.73847 .52713 Mdot
.49844 .55641 Mdot
.48393 .37162 Mdot
.62883 .35745 Mdot
.81589 .47713 Mdot
.39355 .50043 Mdot
.39346 .45618 Mdot
.48532 .70991 Mdot
.52372 .5858 Mdot
.5965 .6119 Mdot
.58083 .34498 Mdot
.37841 .61791 Mdot
.6593 .39069 Mdot
.3384 .62331 Mdot
.8471 .49549 Mdot
.34665 .59369 Mdot
.31255 .50587 Mdot
.22586 .53685 Mdot
.35904 .21831 Mdot
.33258 .61933 Mdot
.62122 .42905 Mdot
.2352 .49073 Mdot
.53109 .60629 Mdot
.5077 .50531 Mdot
.35473 .60646 Mdot
.16794 .39101 Mdot
.5351 .61206 Mdot
.53682 .41837 Mdot
.46009 .32384 Mdot
.33336 .62119 Mdot
.44046 .32893 Mdot
.5552 .58715 Mdot
.35788 .37458 Mdot
.62793 .3908 Mdot
.43522 .33103 Mdot
.56776 .67066 Mdot
.34283 .62303 Mdot
.36601 .42614 Mdot
.43181 .32419 Mdot
.45467 .37501 Mdot
.40693 .79453 Mdot
.17394 .45955 Mdot
.37129 .44831 Mdot
.77835 .40692 Mdot
.50263 .3606 Mdot
.5312 .61521 Mdot
.54654 .20233 Mdot
.57726 .64332 Mdot
.39407 .23628 Mdot
.35952 .47363 Mdot
.28645 .39635 Mdot
.55635 .63796 Mdot
.58539 .56814 Mdot
.67523 .41344 Mdot
.35104 .45227 Mdot
.64547 .4062 Mdot
.6048 .35911 Mdot
.36453 .45824 Mdot
.63333 .39773 Mdot
.32764 .62844 Mdot
.62646 .26265 Mdot
.46969 .3693 Mdot
.46123 .36028 Mdot
.33082 .45824 Mdot
.34867 .47708 Mdot
.34179 .46688 Mdot
.56521 .62323 Mdot
.65699 .40968 Mdot
.56267 .59114 Mdot
.62188 .59719 Mdot
.72399 .46444 Mdot
.59506 .40844 Mdot
.56676 .5989 Mdot
.45229 .54983 Mdot
.60383 .50318 Mdot
.36946 .48644 Mdot
.46307 .32449 Mdot
.39447 .30746 Mdot
.29026 .35021 Mdot
.59449 .62225 Mdot
.36845 .67204 Mdot
.62159 .43047 Mdot
.36055 .62961 Mdot
.35102 .58722 Mdot
.35602 .62405 Mdot
.5092 .3816 Mdot
.59512 .38455 Mdot
.72868 .38412 Mdot
.598 .61708 Mdot
.64761 .33322 Mdot
.57854 .38976 Mdot
.2407 .50479 Mdot
.46534 .32505 Mdot
.54876 .62189 Mdot
.42541 .55218 Mdot
.69082 .67448 Mdot
.57269 .63967 Mdot
.566 .66435 Mdot
.27052 .66261 Mdot
.644 .63098 Mdot
.66767 .42147 Mdot
.82314 .39424 Mdot
.58878 .66088 Mdot
.42559 .2105 Mdot
.29335 .7715 Mdot
.589 .62868 Mdot
.59554 .57353 Mdot
.5447 .59141 Mdot
.57258 .65127 Mdot
.62773 .443 Mdot
.44466 .66297 Mdot
.49794 .36429 Mdot
.65607 .33602 Mdot
.50002 .33491 Mdot
.31338 .45597 Mdot
.28645 .39843 Mdot
.60496 .40321 Mdot
.37311 .60004 Mdot
.24034 .67338 Mdot
.7732 .36022 Mdot
.35069 .43367 Mdot
.33358 .24753 Mdot
.35475 .60877 Mdot
.53719 .63755 Mdot
.34304 .64693 Mdot
.38495 .45388 Mdot
.46386 .36447 Mdot
.60954 .6677 Mdot
.61195 .41956 Mdot
.65249 .42513 Mdot
.54853 .62611 Mdot
.20886 .52399 Mdot
.48398 .32025 Mdot
.47122 .37652 Mdot
.60701 .63386 Mdot
.58839 .66299 Mdot
.6436 .40428 Mdot
.33587 .44827 Mdot
.79523 .58269 Mdot
.36647 .63309 Mdot
.57167 .55374 Mdot
.55707 .63249 Mdot
.81249 .59337 Mdot
.45312 .3551 Mdot
.38093 .42651 Mdot
.62367 .58324 Mdot
.52489 .25755 Mdot
.62667 .59265 Mdot
.50931 .58733 Mdot
.36282 .49102 Mdot
.51364 .64537 Mdot
.55469 .54784 Mdot
.62917 .34816 Mdot
.4431 .33322 Mdot
.6281 .4156 Mdot
.63319 .34771 Mdot
.65537 .27679 Mdot
.49214 .33569 Mdot
.5644 .61061 Mdot
.47211 .3256 Mdot
.5966 .63784 Mdot
.59664 .65377 Mdot
.45937 .32813 Mdot
.64561 .40484 Mdot
.33242 .75195 Mdot
.25641 .43608 Mdot
.58261 .65402 Mdot
.53554 .55162 Mdot
.42542 .66274 Mdot
.33153 .57518 Mdot
.58508 .56462 Mdot
.63038 .43274 Mdot
.55072 .58724 Mdot
.47064 .31474 Mdot
.32873 .63632 Mdot
.61777 .41964 Mdot
.35151 .43952 Mdot
.36074 .43099 Mdot
.56105 .30326 Mdot
.33442 .4961 Mdot
.59276 .5665 Mdot
.68137 .43225 Mdot
.66512 .43655 Mdot
.21944 .64072 Mdot
.36415 .45449 Mdot
.36427 .64178 Mdot
.56527 .56903 Mdot
.53657 .74205 Mdot
.49508 .31361 Mdot
.43016 .13197 Mdot
.71519 .32006 Mdot
.3398 .65108 Mdot
.71845 .36781 Mdot
.34392 .42953 Mdot
.53405 .55784 Mdot
.36189 .6406 Mdot
.37813 .44265 Mdot
.595 .64619 Mdot
.52382 .55585 Mdot
.61478 .48717 Mdot
.41823 .41161 Mdot
.46906 .32755 Mdot
.3158 .48775 Mdot
.3576 .65113 Mdot
.31083 .45019 Mdot
.61665 .36885 Mdot
.60406 .58989 Mdot
.63476 .60526 Mdot
.3368 .44602 Mdot
.39459 .45419 Mdot
.57081 .59482 Mdot
.61025 .42479 Mdot
.29941 .51175 Mdot
.59319 .59003 Mdot
.41293 .3705 Mdot
.59057 .41738 Mdot
.37512 .44585 Mdot
.59187 .57438 Mdot
.39418 .59668 Mdot
.3508 .4432 Mdot
.37233 .48345 Mdot
.56202 .64638 Mdot
.33108 .61641 Mdot
.57092 .54328 Mdot
.45848 .37 Mdot
.21565 .31671 Mdot
.47194 .31442 Mdot
.39318 .50681 Mdot
.64802 .6264 Mdot
.5211 .23315 Mdot
.59854 .40318 Mdot
.51626 .70648 Mdot
.40425 .29845 Mdot
.51418 .62422 Mdot
.50858 .81222 Mdot
.47189 .28354 Mdot
.21682 .6194 Mdot
.55182 .78034 Mdot
.35403 .60281 Mdot
.48375 .3405 Mdot
.59572 .57342 Mdot
.47737 .31076 Mdot
.36732 .63834 Mdot
.21386 .37738 Mdot
.57664 .56514 Mdot
.64087 .4269 Mdot
.5712 .60149 Mdot
.65216 .42135 Mdot
.574 .65483 Mdot
.59063 .54362 Mdot
.42548 .26352 Mdot
.46078 .6279 Mdot
.62477 .5886 Mdot
.86921 .41561 Mdot
.60589 .49604 Mdot
.35805 .63677 Mdot
.56385 .5827 Mdot
.33273 .42135 Mdot
.50773 .3377 Mdot
.46722 .25279 Mdot
.33241 .47102 Mdot
.45314 .37326 Mdot
.63793 .40061 Mdot
.35926 .46968 Mdot
.34449 .43561 Mdot
.51891 .65466 Mdot
.33181 .64591 Mdot
.46987 .35428 Mdot
.61169 .60337 Mdot
.57987 .56714 Mdot
.78041 .40165 Mdot
.29445 .58615 Mdot
.70292 .4048 Mdot
.69869 .24357 Mdot
.60278 .36677 Mdot
.34289 .63242 Mdot
.33733 .48221 Mdot
.61564 .58419 Mdot
.57857 .60627 Mdot
.36032 .32157 Mdot
.63249 .43867 Mdot
.46765 .47813 Mdot
.70394 .4162 Mdot
.41785 .60662 Mdot
.457 .64504 Mdot
.62832 .42995 Mdot
.45354 .64318 Mdot
.32832 .65534 Mdot
.42162 .82721 Mdot
.45261 .61308 Mdot
.46388 .32229 Mdot
.44619 .63918 Mdot
.65779 .38971 Mdot
.61206 .63787 Mdot
.3568 .49393 Mdot
.34165 .49645 Mdot
.63621 .4141 Mdot
.34406 .42137 Mdot
.35746 .59834 Mdot
.61029 .5868 Mdot
.73607 .34652 Mdot
.58909 .28237 Mdot
.32556 .46019 Mdot
.54853 .67675 Mdot
.48417 .35187 Mdot
.54887 .62756 Mdot
.3403 .60762 Mdot
.48273 .32759 Mdot
.68354 .72849 Mdot
.43367 .38675 Mdot
.57188 .5715 Mdot
.81623 .59179 Mdot
.48918 .33552 Mdot
.67003 .6186 Mdot
.60004 .59552 Mdot
.45008 .36524 Mdot
.60227 .701 Mdot
.29058 .37011 Mdot
.47508 .51141 Mdot
.59236 .8197 Mdot
.49964 .48022 Mdot
.3275 .48038 Mdot
.28818 .38355 Mdot
.4271 .24805 Mdot
.50387 .35436 Mdot
.39135 .43838 Mdot
.4741 .54114 Mdot
.44046 .33064 Mdot
.53518 .63165 Mdot
.58999 .63258 Mdot
.25423 .32729 Mdot
.50259 .30469 Mdot
.25519 .39326 Mdot
.57103 .32279 Mdot
.55091 .6399 Mdot
.58995 .54738 Mdot
.58273 .60575 Mdot
.65523 .43605 Mdot
.46193 .3356 Mdot
.84859 .40872 Mdot
.49107 .32528 Mdot
.70756 .45977 Mdot
.33519 .45606 Mdot
.37678 .44363 Mdot
.59941 .62109 Mdot
.54077 .41254 Mdot
.634 .73881 Mdot
.57477 .59856 Mdot
.31496 .60916 Mdot
.25655 .34143 Mdot
.57888 .6608 Mdot
.60295 .41281 Mdot
.51232 .63146 Mdot
.64384 .6618 Mdot
.472 .36897 Mdot
.37007 .60179 Mdot
.55638 .72753 Mdot
.46821 .36284 Mdot
.59508 .61121 Mdot
.53208 .24436 Mdot
.5734 .6306 Mdot
.58409 .65251 Mdot
.69178 .4498 Mdot
.34455 .59164 Mdot
.3516 .46289 Mdot
.35438 .62187 Mdot
.60571 .38926 Mdot
.3833 .12297 Mdot
.34982 .59162 Mdot
.66038 .73164 Mdot
.23076 .33839 Mdot
.44195 .63121 Mdot
.66049 .39029 Mdot
.35016 .64963 Mdot
.47407 .31899 Mdot
.51981 .82859 Mdot
.62147 .50041 Mdot
.46315 .29076 Mdot
.59387 .59539 Mdot
.64704 .36192 Mdot
.65732 .42431 Mdot
.43281 .33542 Mdot
.62479 .36566 Mdot
.49122 .59652 Mdot
.59738 .64765 Mdot
.5003 .34751 Mdot
.54975 .27092 Mdot
.49653 .36671 Mdot
.41558 .51838 Mdot
.56917 .58146 Mdot
.62067 .4225 Mdot
.55593 .55142 Mdot
.62964 .45162 Mdot
.37142 .42266 Mdot
.63518 .62624 Mdot
.35852 .59711 Mdot
.5092 .23595 Mdot
.37007 .44533 Mdot
.42691 .60596 Mdot
.6189 .38149 Mdot
.50516 .38728 Mdot
.62005 .37684 Mdot
.65621 .44687 Mdot
.44081 .36603 Mdot
.64586 .37499 Mdot
.59931 .5767 Mdot
.473 .52203 Mdot
.62525 .38484 Mdot
.46877 .3455 Mdot
.37216 .60883 Mdot
.64135 .39548 Mdot
.29743 .49391 Mdot
.56763 .56718 Mdot
.34344 .48229 Mdot
.30545 .61689 Mdot
.65758 .37212 Mdot
.32681 .61146 Mdot
.3925 .46332 Mdot
.38372 .61598 Mdot
.19357 .57992 Mdot
.42461 .36214 Mdot
.67653 .47846 Mdot
.31128 .61394 Mdot
.66617 .41505 Mdot
.31864 .69791 Mdot
.62175 .60172 Mdot
.56508 .56761 Mdot
.38429 .62831 Mdot
.6572 .42454 Mdot
.35615 .81412 Mdot
.63183 .54455 Mdot
.42678 .49187 Mdot
.5186 .35325 Mdot
.86543 .48896 Mdot
.41893 .50878 Mdot
.26291 .74504 Mdot
.55536 .67598 Mdot
.38631 .48479 Mdot
.588 .61917 Mdot
.39095 .29081 Mdot
.34531 .61907 Mdot
.37284 .53673 Mdot
.62811 .57583 Mdot
.35737 .4643 Mdot
.54288 .57577 Mdot
.54234 .47839 Mdot
.66303 .64895 Mdot
.37471 .63654 Mdot
.22043 .5148 Mdot
.6558 .37221 Mdot
.36336 .60754 Mdot
.38067 .45472 Mdot
.49117 .67054 Mdot
.59446 .64746 Mdot
.53176 .62674 Mdot
.41713 .6066 Mdot
.65891 .40643 Mdot
.33939 .49063 Mdot
.45921 .36876 Mdot
.37553 .60757 Mdot
.55144 .5988 Mdot
.6235 .5987 Mdot
.35448 .30988 Mdot
.49029 .34882 Mdot
.35931 .50135 Mdot
.45123 .3269 Mdot
.33537 .43662 Mdot
.61639 .63881 Mdot
.36492 .43474 Mdot
.52005 .58574 Mdot
.47359 .26945 Mdot
.68707 .46344 Mdot
.73929 .54684 Mdot
.36422 .47143 Mdot
.69322 .71083 Mdot
.49106 .34605 Mdot
.44533 .3436 Mdot
.27457 .2823 Mdot
.62697 .49496 Mdot
.77007 .37417 Mdot
.46825 .79071 Mdot
.49446 .35226 Mdot
.47577 .35159 Mdot
.34475 .48177 Mdot
.64272 .37322 Mdot
.60685 .36533 Mdot
.33676 .43722 Mdot
.425 .7192 Mdot
.65934 .39154 Mdot
.47773 .82559 Mdot
.80742 .44249 Mdot
.51768 .61342 Mdot
.3276 .51731 Mdot
.36633 .62605 Mdot
.43792 .71304 Mdot
.53178 .48491 Mdot
.57846 .56335 Mdot
.51507 .72127 Mdot
.33265 .45341 Mdot
.53874 .38982 Mdot
.59264 .81167 Mdot
.5378 .57938 Mdot
.60441 .59775 Mdot
.58737 .61106 Mdot
.32617 .6404 Mdot
.6553 .5344 Mdot
.60197 .58229 Mdot
.42198 .71968 Mdot
.5494 .63421 Mdot
.66527 .65175 Mdot
.36098 .62134 Mdot
.46957 .57397 Mdot
.30517 .59614 Mdot
.82266 .40491 Mdot
.66144 .62537 Mdot
.46314 .37081 Mdot
.3374 .54679 Mdot
.44353 .34044 Mdot
.70993 .52873 Mdot
.44495 .6112 Mdot
.59809 .37081 Mdot
.58118 .56443 Mdot
.36911 .46444 Mdot
.6571 .42404 Mdot
.31687 .35483 Mdot
.42518 .10976 Mdot
.47889 .36939 Mdot
.42076 .87799 Mdot
.44669 .3609 Mdot
.34173 .43729 Mdot
.64261 .40462 Mdot
.7288 .65691 Mdot
.66544 .31427 Mdot
.63886 .3952 Mdot
.32898 .77707 Mdot
.57813 .40812 Mdot
.54749 .71391 Mdot
.67208 .3997 Mdot
.47394 .34655 Mdot
.53316 .36349 Mdot
.48614 .59569 Mdot
.61654 .61797 Mdot
.45363 .43968 Mdot
.63271 .73648 Mdot
.62131 .59996 Mdot
.37271 .45597 Mdot
.65886 .47816 Mdot
.49658 .7101 Mdot
.65158 .37983 Mdot
.43207 .38095 Mdot
.60087 .58979 Mdot
.56384 .63929 Mdot
.60328 .64224 Mdot
.71746 .31042 Mdot
.4168 .82592 Mdot
.61588 .63657 Mdot
.56584 .65177 Mdot
.35906 .46715 Mdot
.35014 .56811 Mdot
.24466 .46817 Mdot
.76269 .41479 Mdot
.53798 .5705 Mdot
.36477 .61232 Mdot
.36636 .6507 Mdot
.62781 .61504 Mdot
.4697 .53556 Mdot
.53408 .23896 Mdot
.61154 .60148 Mdot
.65231 .48048 Mdot
.30752 .41612 Mdot
.35798 .50389 Mdot
.34703 .44212 Mdot
.63376 .36034 Mdot
.33249 .44553 Mdot
.35664 .42616 Mdot
.69498 .68665 Mdot
.48614 .47726 Mdot
.45691 .27129 Mdot
.34714 .627 Mdot
.57623 .61244 Mdot
.51305 .53948 Mdot
.52362 .25077 Mdot
.4374 .34498 Mdot
.61386 .41234 Mdot
.50776 .33311 Mdot
.37731 .64987 Mdot
.68261 .30237 Mdot
.31668 .47036 Mdot
.48301 .36135 Mdot
.41859 .36079 Mdot
.36604 .61433 Mdot
.45348 .3165 Mdot
.44049 .4032 Mdot
.61216 .65451 Mdot
.73207 .60782 Mdot
.57652 .5913 Mdot
.24419 .68606 Mdot
.47737 .35587 Mdot
.52556 .35893 Mdot
.6039 .61034 Mdot
.35389 .44368 Mdot
.56888 .7064 Mdot
.6152 .62194 Mdot
.33177 .44742 Mdot
.60663 .55866 Mdot
.37143 .58581 Mdot
.60015 .42775 Mdot
.66311 .31563 Mdot
.22738 .28937 Mdot
.3348 .64742 Mdot
.32468 .3482 Mdot
.5722 .55899 Mdot
.17971 .49857 Mdot
.64406 .39449 Mdot
.60612 .5669 Mdot
.483 .68584 Mdot
.63453 .38292 Mdot
.62332 .40634 Mdot
.56046 .62269 Mdot
.4589 .323 Mdot
.37198 .44469 Mdot
.36621 .61915 Mdot
.23435 .69898 Mdot
.58617 .58581 Mdot
.54905 .57728 Mdot
.3594 .60818 Mdot
.49615 .33772 Mdot
.62691 .59567 Mdot
.45489 .76169 Mdot
.39371 .83374 Mdot
.44446 .36197 Mdot
.53312 .60206 Mdot
.70946 .55852 Mdot
.65318 .5851 Mdot
.1524 .52022 Mdot
.49637 .51512 Mdot
.35012 .46809 Mdot
.64299 .58193 Mdot
.53767 .14414 Mdot
.37248 .60551 Mdot
.77189 .36281 Mdot
.56198 .63854 Mdot
.54488 .6031 Mdot
.63954 .43674 Mdot
.56545 .59111 Mdot
.60681 .40687 Mdot
.30878 .22755 Mdot
.83028 .56985 Mdot
.61921 .36182 Mdot
.66815 .4064 Mdot
.57224 .73264 Mdot
.4062 .33311 Mdot
.63673 .41149 Mdot
.594 .65661 Mdot
.45596 .57229 Mdot
.56736 .36456 Mdot
.35762 .64657 Mdot
.30806 .67685 Mdot
.58859 .51534 Mdot
.3956 .65439 Mdot
.34267 .74903 Mdot
.54913 .51444 Mdot
.41393 .53578 Mdot
.44857 .35263 Mdot
.53731 .57861 Mdot
.34267 .49731 Mdot
.34007 .49844 Mdot
.52035 .57913 Mdot
.57194 .6213 Mdot
.60955 .38608 Mdot
.37538 .62115 Mdot
.50796 .35318 Mdot
.54691 .60429 Mdot
.51189 .70066 Mdot
.37887 .60576 Mdot
.63115 .36687 Mdot
.70689 .47926 Mdot
.36727 .57979 Mdot
.57552 .5383 Mdot
.61376 .61247 Mdot
.56873 .606 Mdot
.4849 .59239 Mdot
.4578 .33703 Mdot
.35248 .74338 Mdot
.56 .65631 Mdot
.84811 .48513 Mdot
.43728 .27982 Mdot
.63542 .57746 Mdot
.6187 .37113 Mdot
.4522 .38385 Mdot
.33199 .43115 Mdot
.63434 .25234 Mdot
.57439 .57362 Mdot
.21365 .51698 Mdot
.24968 .3363 Mdot
.38592 .43483 Mdot
.61744 .44541 Mdot
.35372 .62753 Mdot
.57456 .60183 Mdot
.67644 .50255 Mdot
.59228 .63013 Mdot
.32232 .65673 Mdot
.37799 .47787 Mdot
.44822 .34962 Mdot
.22648 .6396 Mdot
.32523 .49438 Mdot
.62485 .40886 Mdot
.76086 .69964 Mdot
.60614 .40787 Mdot
.60908 .36364 Mdot
.71594 .47829 Mdot
.45654 .3369 Mdot
.48006 .12963 Mdot
.32715 .22502 Mdot
.61915 .64184 Mdot
.49446 .34017 Mdot
.63275 .42087 Mdot
.54198 .6223 Mdot
.59304 .43401 Mdot
.59143 .39033 Mdot
.60584 .64754 Mdot
.54173 .59697 Mdot
.23194 .42546 Mdot
.56147 .80345 Mdot
.35196 .62723 Mdot
.59996 .39194 Mdot
.64677 .30687 Mdot
.54127 .62398 Mdot
.59903 .61659 Mdot
.38383 .25463 Mdot
.33156 .64264 Mdot
.61601 .28409 Mdot
.56302 .63897 Mdot
.78126 .64769 Mdot
.50301 .60657 Mdot
.61895 .43772 Mdot
.44172 .34572 Mdot
.8275 .42218 Mdot
.42843 .40291 Mdot
.60768 .40603 Mdot
.36906 .59462 Mdot
.67459 .42025 Mdot
.67646 .72551 Mdot
.49865 .33344 Mdot
.62188 .42821 Mdot
.42065 .55299 Mdot
.47045 .33327 Mdot
.47532 .35984 Mdot
.73031 .46235 Mdot
.36718 .41832 Mdot
.32961 .64804 Mdot
.47267 .35362 Mdot
.50526 .20591 Mdot
.47338 .34102 Mdot
.30797 .23838 Mdot
.53527 .58654 Mdot
.47535 .727 Mdot
.38497 .51683 Mdot
.60039 .52721 Mdot
.48382 .35567 Mdot
.33068 .62729 Mdot
.59281 .64659 Mdot
.65109 .37349 Mdot
.37475 .62905 Mdot
.46743 .29989 Mdot
.33608 .47219 Mdot
.62511 .37606 Mdot
.51785 .32127 Mdot
.65057 .42493 Mdot
.57794 .22189 Mdot
.21429 .34194 Mdot
.58392 .74724 Mdot
.66709 .31236 Mdot
.59275 .64899 Mdot
.42192 .79801 Mdot
.53011 .59689 Mdot
.56925 .62739 Mdot
.37511 .4506 Mdot
.48931 .72152 Mdot
.64523 .40581 Mdot
.2938 .74889 Mdot
.47506 .3672 Mdot
.82759 .41285 Mdot
.65895 .61843 Mdot
.58184 .55276 Mdot
.62195 .38614 Mdot
.62174 .43529 Mdot
.73302 .51053 Mdot
.30307 .4664 Mdot
.5718 .55598 Mdot
.58522 .67205 Mdot
.51901 .57497 Mdot
.4667 .36657 Mdot
.44781 .56774 Mdot
.32488 .47656 Mdot
.1876 .40457 Mdot
.38055 .47551 Mdot
.3348 .67125 Mdot
.64568 .37258 Mdot
.35054 .59141 Mdot
.60167 .6161 Mdot
.67999 .44353 Mdot
.63637 .43923 Mdot
.38468 .62582 Mdot
.33459 .62734 Mdot
.31908 .32485 Mdot
.46033 .32792 Mdot
.61838 .62335 Mdot
.59404 .5758 Mdot
.56051 .59533 Mdot
.56657 .62164 Mdot
.48038 .36814 Mdot
.60208 .64001 Mdot
.48906 .30884 Mdot
.64588 .25117 Mdot
.48318 .75004 Mdot
.50537 .47795 Mdot
.35732 .24407 Mdot
.65492 .38265 Mdot
.50852 .21289 Mdot
.64041 .65296 Mdot
.62364 .21327 Mdot
.21291 .40261 Mdot
.5863 .6663 Mdot
.36571 .43175 Mdot
.62076 .70222 Mdot
.32313 .48679 Mdot
.26979 .76243 Mdot
.39779 .26311 Mdot
.54785 .80856 Mdot
.57844 .56661 Mdot
.47079 .52242 Mdot
.47413 .20267 Mdot
.53007 .60702 Mdot
.35013 .29941 Mdot
.3926 .23555 Mdot
.22788 .49057 Mdot
.3326 .61672 Mdot
.5845 .57642 Mdot
.50572 .54746 Mdot
.60402 .58095 Mdot
.59265 .61916 Mdot
.6026 .64129 Mdot
.51392 .35156 Mdot
.60539 .57001 Mdot
.58301 .64614 Mdot
.23748 .56736 Mdot
.45784 .6388 Mdot
.37758 .49104 Mdot
.25893 .3015 Mdot
.34765 .59241 Mdot
.61966 .38364 Mdot
.4056 .81405 Mdot
.46447 .32248 Mdot
.73851 .51314 Mdot
.56764 .615 Mdot
.24285 .42925 Mdot
.42076 .38207 Mdot
.36545 .59441 Mdot
.38505 .44855 Mdot
.5488 .82168 Mdot
.36919 .46001 Mdot
.48108 .3851 Mdot
.35857 .44461 Mdot
.65207 .62044 Mdot
.60754 .38703 Mdot
.6236 .61979 Mdot
.46668 .35448 Mdot
.34968 .43774 Mdot
.42424 .67395 Mdot
.58271 .6082 Mdot
.36374 .45819 Mdot
.62248 .62162 Mdot
.69656 .34063 Mdot
.78617 .4354 Mdot
.3646 .42783 Mdot
.42085 .35049 Mdot
.45772 .34873 Mdot
.33703 .60691 Mdot
.62796 .37954 Mdot
.61139 .40921 Mdot
.48273 .32895 Mdot
.64223 .46685 Mdot
.53677 .57023 Mdot
.53948 .61145 Mdot
.83473 .44907 Mdot
.60258 .57613 Mdot
.49206 .66911 Mdot
.428 .55431 Mdot
.63379 .36357 Mdot
.57344 .54899 Mdot
.55783 .62576 Mdot
.5701 .57027 Mdot
.70985 .34266 Mdot
.33103 .45058 Mdot
.53643 .58214 Mdot
.3375 .63424 Mdot
.27431 .43441 Mdot
.54924 .62837 Mdot
.50239 .62217 Mdot
.61182 .41137 Mdot
.7057 .25677 Mdot
.44604 .35789 Mdot
.38002 .45571 Mdot
.36357 .47272 Mdot
.33945 .73255 Mdot
.46501 .22513 Mdot
.42996 .55297 Mdot
.15952 .45739 Mdot
.42612 .26363 Mdot
.33958 .62583 Mdot
.36523 .50785 Mdot
.53587 .35165 Mdot
.35826 .48129 Mdot
.48792 .36699 Mdot
.53429 .59976 Mdot
.53609 .57314 Mdot
.51273 .15592 Mdot
.62865 .60292 Mdot
.35862 .62685 Mdot
.50619 .36046 Mdot
.65774 .39331 Mdot
.36992 .5969 Mdot
.44912 .3287 Mdot
.63182 .36044 Mdot
.58321 .66702 Mdot
.56677 .66128 Mdot
.61424 .40904 Mdot
.63967 .43487 Mdot
.61105 .61257 Mdot
.39024 .38031 Mdot
.66668 .40822 Mdot
.6275 .43047 Mdot
.31864 .46741 Mdot
.33716 .49614 Mdot
.51806 .55263 Mdot
.48822 .34621 Mdot
.58662 .6463 Mdot
.3625 .46861 Mdot
.34888 .59271 Mdot
.6479 .4037 Mdot
.57845 .65312 Mdot
.549 .61918 Mdot
.36738 .61395 Mdot
.34795 .59718 Mdot
.339 .60989 Mdot
.51236 .31822 Mdot
.55961 .58702 Mdot
.63831 .40458 Mdot
.45595 .33275 Mdot
.35686 .65366 Mdot
.34651 .6465 Mdot
.3394 .51185 Mdot
.60707 .57626 Mdot
.41268 .46225 Mdot
.55614 .14664 Mdot
.83478 .53259 Mdot
.37172 .42615 Mdot
.3266 .43442 Mdot
.38887 .68009 Mdot
.54939 .37547 Mdot
.48951 .32714 Mdot
.33541 .57388 Mdot
.59231 .74159 Mdot
.61227 .66145 Mdot
.57756 .65914 Mdot
.59917 .54935 Mdot
.33719 .61338 Mdot
.50485 .73583 Mdot
.60494 .40128 Mdot
.47163 .5996 Mdot
.38016 .60715 Mdot
.39088 .46824 Mdot
.36114 .51224 Mdot
.383 .47024 Mdot
.54295 .64425 Mdot
.74676 .55832 Mdot
.48998 .2231 Mdot
.45102 .77898 Mdot
.48818 .35172 Mdot
.51713 .53627 Mdot
.18414 .48684 Mdot
.61849 .40568 Mdot
.31059 .45992 Mdot
.33888 .62915 Mdot
.64237 .43343 Mdot
.50453 .32802 Mdot
.47302 .35178 Mdot
.32537 .46157 Mdot
.32761 .4636 Mdot
.35817 .48815 Mdot
.58854 .39387 Mdot
.64528 .37332 Mdot
.57249 .57427 Mdot
.65148 .39947 Mdot
.685 .26459 Mdot
.3908 .61223 Mdot
.34722 .41327 Mdot
.48542 .3426 Mdot
.65749 .38089 Mdot
.58159 .6048 Mdot
.61381 .3434 Mdot
.51809 .27998 Mdot
.35853 .63804 Mdot
.78265 .41845 Mdot
.2355 .71667 Mdot
.62209 .61639 Mdot
.45469 .34497 Mdot
.73628 .33608 Mdot
.58768 .60818 Mdot
.34172 .48658 Mdot
.24791 .6323 Mdot
.3976 .40786 Mdot
.61272 .62466 Mdot
.61822 .65076 Mdot
.45787 .37157 Mdot
.18754 .41071 Mdot
.57874 .57883 Mdot
.61933 .27253 Mdot
.42021 .37041 Mdot
.33308 .48482 Mdot
.53068 .86781 Mdot
.40033 .59062 Mdot
.43491 .71688 Mdot
.32196 .46749 Mdot
.57855 .63745 Mdot
.31741 .48075 Mdot
.34383 .63859 Mdot
.38252 .44721 Mdot
.60554 .41178 Mdot
.38839 .46439 Mdot
.5485 .5783 Mdot
.6341 .41401 Mdot
.49003 .33569 Mdot
.81371 .39931 Mdot
.26328 .63033 Mdot
.35148 .44434 Mdot
.35643 .42864 Mdot
.58296 .55027 Mdot
.62818 .30255 Mdot
.52491 .57438 Mdot
.53507 .60835 Mdot
.49846 .34414 Mdot
.63166 .38218 Mdot
.44345 .36374 Mdot
.56704 .52689 Mdot
.50174 .76308 Mdot
.45067 .32911 Mdot
.24247 .45768 Mdot
.35249 .60937 Mdot
.511 .4323 Mdot
.57717 .60671 Mdot
.44425 .32299 Mdot
.56065 .5843 Mdot
.60412 .39797 Mdot
.52416 .4619 Mdot
.32911 .38534 Mdot
.46492 .36057 Mdot
.21074 .58184 Mdot
.45165 .75012 Mdot
.49923 .57254 Mdot
.44424 .34478 Mdot
.48347 .69453 Mdot
.33936 .43874 Mdot
.36932 .63206 Mdot
.37962 .59185 Mdot
.38158 .60687 Mdot
.51943 .63097 Mdot
.65982 .62425 Mdot
.32477 .61509 Mdot
.50634 .33762 Mdot
.37387 .63723 Mdot
.4076 .20745 Mdot
.29703 .75188 Mdot
.34816 .61595 Mdot
.59757 .59504 Mdot
.62197 .68352 Mdot
.4373 .62516 Mdot
.28555 .37036 Mdot
.53268 .80925 Mdot
.31701 .29261 Mdot
.61036 .62326 Mdot
.58689 .41188 Mdot
.59397 .39315 Mdot
.73829 .30864 Mdot
.65801 .72609 Mdot
.82364 .56951 Mdot
.63169 .35729 Mdot
.38145 .33847 Mdot
.63128 .37017 Mdot
.62004 .63018 Mdot
.54002 .61564 Mdot
.61784 .35484 Mdot
.51512 .75658 Mdot
.36498 .34524 Mdot
.22804 .66631 Mdot
.64664 .42935 Mdot
.4427 .33451 Mdot
.43222 .35236 Mdot
.47883 .35903 Mdot
.80242 .41817 Mdot
.62417 .38931 Mdot
.55413 .60449 Mdot
.3672 .46908 Mdot
.54182 .5687 Mdot
.46977 .33099 Mdot
.30762 .77216 Mdot
.63754 .39107 Mdot
.60081 .58581 Mdot
.51978 .66792 Mdot
.33063 .46754 Mdot
.36007 .61253 Mdot
.67744 .33305 Mdot
.81392 .58189 Mdot
.4783 .36495 Mdot
.65437 .36891 Mdot
.53262 .33923 Mdot
.23973 .66724 Mdot
.56281 .68099 Mdot
.62344 .66248 Mdot
.23433 .70218 Mdot
.75081 .68582 Mdot
.57903 .56 Mdot
.37716 .43805 Mdot
.36316 .31357 Mdot
.55357 .63148 Mdot
.59608 .39367 Mdot
.36957 .58157 Mdot
.382 .62059 Mdot
.51147 .55856 Mdot
.61887 .33563 Mdot
.52487 .48293 Mdot
.56401 .61347 Mdot
.58177 .54 Mdot
.32755 .47912 Mdot
.3956 .27752 Mdot
.84735 .49639 Mdot
.3558 .59142 Mdot
.62581 .61547 Mdot
.31465 .74648 Mdot
.65086 .43345 Mdot
.38417 .4336 Mdot
.47202 .31291 Mdot
.57907 .38827 Mdot
.38445 .44639 Mdot
.58466 .65668 Mdot
.62843 .60675 Mdot
.43662 .3513 Mdot
.61678 .43593 Mdot
.34026 .61102 Mdot
.37713 .45078 Mdot
.3512 .59783 Mdot
.63383 .3846 Mdot
.65188 .38991 Mdot
.50488 .64226 Mdot
.57911 .68331 Mdot
.35251 .4399 Mdot
.51633 .60005 Mdot
.38494 .39524 Mdot
.15521 .56884 Mdot
.52492 .32673 Mdot
.61281 .57748 Mdot
.67496 .4046 Mdot
.46672 .36418 Mdot
.54417 .59996 Mdot
.27712 .75774 Mdot
.54432 .63037 Mdot
.5113 .362 Mdot
.66721 .74222 Mdot
.34985 .6016 Mdot
.4883 .55397 Mdot
.21544 .42434 Mdot
.61037 .58259 Mdot
.35266 .47839 Mdot
.5363 .66615 Mdot
.46401 .31948 Mdot
.65031 .37756 Mdot
.14878 .57338 Mdot
.46851 .34258 Mdot
.6127 .59265 Mdot
.37424 .60356 Mdot
.67072 .41557 Mdot
.49843 .51832 Mdot
.46215 .54308 Mdot
.58621 .69699 Mdot
.56702 .5529 Mdot
.56384 .63107 Mdot
.46398 .76857 Mdot
.37745 .4631 Mdot
.62945 .42773 Mdot
.45302 .35021 Mdot
.4852 .3278 Mdot
.32817 .45675 Mdot
.4156 .45971 Mdot
.50964 .43266 Mdot
.64426 .18053 Mdot
.31296 .47322 Mdot
.35786 .58796 Mdot
.62537 .29039 Mdot
.37464 .46281 Mdot
.36124 .45512 Mdot
.318 .47044 Mdot
.42079 .5413 Mdot
.65984 .39138 Mdot
.58286 .65699 Mdot
.59902 .41185 Mdot
.57856 .63952 Mdot
.49845 .37114 Mdot
.46665 .35797 Mdot
.64096 .38714 Mdot
.20359 .62719 Mdot
.71763 .61009 Mdot
.59535 .60506 Mdot
.1805 .4974 Mdot
.6333 .5905 Mdot
.42434 .64593 Mdot
.62308 .57484 Mdot
.34392 .44931 Mdot
.5313 .62925 Mdot
.5117 .60691 Mdot
.75497 .33239 Mdot
.48799 .34338 Mdot
.36468 .50411 Mdot
.61659 .55561 Mdot
.57431 .5396 Mdot
.58727 .39309 Mdot
.63827 .43414 Mdot
.38153 .59567 Mdot
.4866 .65195 Mdot
.49191 .33402 Mdot
.39524 .18928 Mdot
.61638 .61686 Mdot
.40565 .63855 Mdot
.80038 .54668 Mdot
.54453 .59686 Mdot
.20624 .45316 Mdot
.74508 .54669 Mdot
.57529 .60338 Mdot
.44349 .46813 Mdot
.49031 .34747 Mdot
.55084 .77376 Mdot
.55278 .63731 Mdot
.33166 .47445 Mdot
.63815 .36942 Mdot
.64185 .43906 Mdot
.37149 .58761 Mdot
.56622 .18343 Mdot
.4433 .36534 Mdot
.64713 .38036 Mdot
.58118 .61505 Mdot
.4533 .34394 Mdot
.31494 .46463 Mdot
.59128 .55644 Mdot
.71087 .70418 Mdot
.65344 .40305 Mdot
.60835 .5593 Mdot
.59478 .25214 Mdot
.39729 .70016 Mdot
.66827 .75565 Mdot
.45257 .35595 Mdot
.33625 .60884 Mdot
.50657 .60543 Mdot
.60834 .47562 Mdot
.54915 .54458 Mdot
.45541 .7286 Mdot
.39389 .2139 Mdot
.32794 .63286 Mdot
.60381 .60627 Mdot
.55146 .60123 Mdot
.56776 .44918 Mdot
.36213 .59112 Mdot
.58275 .56834 Mdot
.56666 .41838 Mdot
.65094 .42048 Mdot
.32037 .44861 Mdot
.65796 .39919 Mdot
.59449 .59616 Mdot
.5807 .68531 Mdot
.63763 .43654 Mdot
.16677 .55705 Mdot
.37761 .58017 Mdot
.44629 .34557 Mdot
.62861 .63159 Mdot
.54864 .64493 Mdot
.83876 .36681 Mdot
.38912 .43875 Mdot
.3695 .38038 Mdot
.25796 .48267 Mdot
.32417 .73384 Mdot
.3841 .56968 Mdot
.63009 .78891 Mdot
.74571 .69272 Mdot
.60555 .5694 Mdot
.54743 .50284 Mdot
.54927 .22483 Mdot
.49537 .34475 Mdot
.50655 .18333 Mdot
.61695 .61761 Mdot
.59008 .61988 Mdot
.36003 .42231 Mdot
.31127 .38766 Mdot
.82796 .56274 Mdot
.64097 .34244 Mdot
.34398 .60819 Mdot
.60435 .38666 Mdot
.58968 .65729 Mdot
.4589 .48013 Mdot
.39397 .45833 Mdot
.39484 .63365 Mdot
.6038 .58992 Mdot
.7192 .34854 Mdot
.53039 .28525 Mdot
.46113 .3308 Mdot
.36154 .47458 Mdot
.79849 .60621 Mdot
.61386 .58166 Mdot
.44785 .31826 Mdot
.58474 .58876 Mdot
.38902 .5686 Mdot
.58165 .52965 Mdot
.34219 .62639 Mdot
.56874 .64597 Mdot
.33402 .54072 Mdot
.88168 .48547 Mdot
.32078 .64643 Mdot
.58378 .39016 Mdot
.39112 .42831 Mdot
.33297 .44865 Mdot
.63275 .4343 Mdot
.3407 .44507 Mdot
.74215 .49312 Mdot
.70506 .6851 Mdot
.35111 .60788 Mdot
.5209 .55261 Mdot
.35288 .6169 Mdot
.37606 .42533 Mdot
.61249 .62317 Mdot
.1808 .64206 Mdot
.36154 .43759 Mdot
.77363 .66676 Mdot
.47618 .33841 Mdot
.39482 .44954 Mdot
.54957 .6338 Mdot
.52446 .3028 Mdot
.32553 .49417 Mdot
.363 .36703 Mdot
.57037 .57077 Mdot
.65543 .3924 Mdot
.5519 .62478 Mdot
.61646 .64352 Mdot
.38432 .48604 Mdot
.59035 .64162 Mdot
.4496 .32766 Mdot
.62408 .35656 Mdot
.50251 .8265 Mdot
.42311 .22684 Mdot
.58548 .56809 Mdot
.583 .61301 Mdot
.66046 .44103 Mdot
.53651 .6309 Mdot
.47892 .36844 Mdot
.15152 .34707 Mdot
.35315 .60944 Mdot
.39602 .47708 Mdot
.30702 .52602 Mdot
.59592 .66734 Mdot
.59689 .64379 Mdot
.31445 .80324 Mdot
.49063 .75862 Mdot
.4446 .33934 Mdot
.51755 .57791 Mdot
.31238 .48125 Mdot
.37457 .61825 Mdot
.50677 .3484 Mdot
.56914 .60325 Mdot
.60258 .61348 Mdot
.34011 .6025 Mdot
.41151 .64369 Mdot
.81653 .45923 Mdot
.43506 .33637 Mdot
.64848 .62385 Mdot
.29325 .4848 Mdot
.53606 .56842 Mdot
.78623 .40254 Mdot
.61891 .4237 Mdot
.48162 .36373 Mdot
.34255 .74299 Mdot
.61122 .57735 Mdot
.44006 .34561 Mdot
.49212 .33559 Mdot
.5532 .54671 Mdot
.66182 .36981 Mdot
.61741 .35709 Mdot
.65311 .42146 Mdot
.418 .14473 Mdot
.44475 .70515 Mdot
.3581 .48821 Mdot
.49253 .34549 Mdot
.35026 .42839 Mdot
.3223 .65704 Mdot
.46502 .51926 Mdot
.35614 .42738 Mdot
.66043 .40859 Mdot
.39712 .46338 Mdot
.55509 .58339 Mdot
.49046 .33332 Mdot
.35484 .48352 Mdot
.61003 .65096 Mdot
.6342 .32664 Mdot
.27797 .34905 Mdot
.33825 .64156 Mdot
.36089 .57898 Mdot
.54345 .62095 Mdot
.30973 .45498 Mdot
.60859 .6153 Mdot
.47417 .31109 Mdot
.64195 .31672 Mdot
.6172 .64115 Mdot
.34734 .4451 Mdot
.66282 .43717 Mdot
.80244 .59804 Mdot
.53024 .64153 Mdot
.59855 .59661 Mdot
.58402 .64069 Mdot
.5842 .58811 Mdot
.24014 .65624 Mdot
.43597 .3647 Mdot
.36793 .24081 Mdot
.33845 .72602 Mdot
.63379 .39513 Mdot
.60192 .42334 Mdot
.84053 .50165 Mdot
.54442 .23197 Mdot
.48838 .3468 Mdot
.56823 .62524 Mdot
.52415 .26246 Mdot
.39191 .83181 Mdot
.21731 .67004 Mdot
.66936 .59286 Mdot
.38905 .43623 Mdot
.65425 .36918 Mdot
.34537 .43739 Mdot
.58311 .63545 Mdot
.57793 .54198 Mdot
.68286 .7714 Mdot
.50277 .33102 Mdot
.34478 .6115 Mdot
.57816 .64142 Mdot
.44047 .7074 Mdot
.35834 .46876 Mdot
.39525 .44978 Mdot
.53784 .59168 Mdot
.65018 .44098 Mdot
.87342 .48275 Mdot
.45781 .33772 Mdot
.35067 .26321 Mdot
.46681 .20202 Mdot
.54987 .3226 Mdot
.46598 .33208 Mdot
.5902 .47927 Mdot
.38098 .4318 Mdot
.79993 .51387 Mdot
.62729 .39634 Mdot
.37092 .63261 Mdot
.63887 .58622 Mdot
.61648 .42782 Mdot
.37078 .48811 Mdot
.65389 .38393 Mdot
.59866 .64397 Mdot
.42312 .36989 Mdot
.34802 .46968 Mdot
.44605 .27219 Mdot
.67512 .40667 Mdot
.36596 .59309 Mdot
.49647 .40248 Mdot
.68312 .63982 Mdot
.74472 .54172 Mdot
.53678 .58704 Mdot
.45401 .48917 Mdot
.55597 .60247 Mdot
.62551 .44811 Mdot
.5833 .59994 Mdot
.68687 .41605 Mdot
.35175 .47766 Mdot
.56387 .65018 Mdot
.56402 .61797 Mdot
.30187 .2504 Mdot
.5837 .57174 Mdot
.53116 .56838 Mdot
.57324 .60704 Mdot
.67755 .44261 Mdot
.50745 .56701 Mdot
.61605 .37308 Mdot
.23992 .48838 Mdot
.35803 .45395 Mdot
.38493 .61801 Mdot
.33177 .61319 Mdot
.47883 .72019 Mdot
.31764 .5632 Mdot
.28332 .39776 Mdot
.65136 .41439 Mdot
.45575 .31953 Mdot
.58302 .59455 Mdot
.58705 .80881 Mdot
.28991 .46089 Mdot
.38944 .46931 Mdot
.425 .22768 Mdot
.6304 .55194 Mdot
.57521 .7773 Mdot
.52253 .56869 Mdot
.48477 .15356 Mdot
.57343 .67351 Mdot
.63241 .563 Mdot
.31159 .46608 Mdot
.37234 .66302 Mdot
.53752 .62847 Mdot
.59928 .37939 Mdot
.35478 .63452 Mdot
.65795 .61334 Mdot
.36834 .51931 Mdot
.28797 .41834 Mdot
.69672 .38072 Mdot
.56518 .57768 Mdot
.34744 .46875 Mdot
.62396 .37719 Mdot
.84429 .51544 Mdot
.45459 .33462 Mdot
.41063 .48266 Mdot
.63178 .26217 Mdot
.17279 .55 Mdot
.37789 .60264 Mdot
.77944 .45818 Mdot
.54981 .57996 Mdot
.23213 .58929 Mdot
.62557 .63393 Mdot
.32549 .79401 Mdot
.33301 .60344 Mdot
.66237 .40176 Mdot
.44415 .33023 Mdot
.59662 .39495 Mdot
.73558 .53315 Mdot
.34454 .52083 Mdot
.49412 .46049 Mdot
.36811 .45911 Mdot
.51392 .49451 Mdot
.62858 .42007 Mdot
.61923 .62645 Mdot
.63663 .17504 Mdot
.62429 .42874 Mdot
.67185 .40982 Mdot
.22445 .34868 Mdot
.16657 .60284 Mdot
.61235 .6716 Mdot
.6675 .40551 Mdot
.36776 .4532 Mdot
.35296 .6297 Mdot
.55946 .6405 Mdot
.56081 .57542 Mdot
.6138 .42305 Mdot
.38084 .49306 Mdot
.68237 .54007 Mdot
.33128 .45877 Mdot
.66028 .39629 Mdot
.34428 .45785 Mdot
.51616 .36811 Mdot
.37919 .45221 Mdot
.54856 .64528 Mdot
.58316 .59848 Mdot
.27846 .5258 Mdot
.65235 .39069 Mdot
.56374 .61157 Mdot
.58545 .55107 Mdot
.6392 .40668 Mdot
.57038 .47856 Mdot
.69043 .54074 Mdot
.56658 .55833 Mdot
.57439 .56895 Mdot
.3297 .62115 Mdot
.46614 .50487 Mdot
.78093 .43456 Mdot
.58975 .64789 Mdot
.32512 .63342 Mdot
.6074 .37172 Mdot
.61242 .60334 Mdot
.37976 .80533 Mdot
.36179 .31793 Mdot
.62126 .61526 Mdot
.34116 .43794 Mdot
.51328 .59443 Mdot
.68153 .74592 Mdot
.53489 .61133 Mdot
.63931 .41453 Mdot
.64055 .37825 Mdot
.37374 .20343 Mdot
.62472 .41084 Mdot
.3413 .49644 Mdot
.47058 .33204 Mdot
.23539 .6649 Mdot
.32531 .4506 Mdot
.55513 .66971 Mdot
.24713 .28169 Mdot
.61158 .56689 Mdot
.58162 .66384 Mdot
.8124 .62013 Mdot
.35234 .4361 Mdot
.6134 .38827 Mdot
.51066 .4028 Mdot
.59237 .68225 Mdot
.47973 .36271 Mdot
.60515 .54382 Mdot
.53338 .60172 Mdot
.70864 .72577 Mdot
.24557 .65811 Mdot
.44415 .31935 Mdot
.5315 .56904 Mdot
.59248 .64668 Mdot
.33426 .42099 Mdot
.57995 .61003 Mdot
.34868 .62837 Mdot
.62541 .38762 Mdot
.37739 .44156 Mdot
.36872 .61077 Mdot
.61812 .59091 Mdot
.3394 .61022 Mdot
.34381 .48278 Mdot
.48588 .31544 Mdot
.59432 .63152 Mdot
.36069 .6459 Mdot
.34236 .60821 Mdot
.5581 .60268 Mdot
.64702 .37269 Mdot
.62329 .5399 Mdot
.58777 .57381 Mdot
.57965 .65283 Mdot
.6111 .40709 Mdot
.51213 .87955 Mdot
.53892 .61387 Mdot
.46303 .73546 Mdot
.62099 .43417 Mdot
.53631 .48686 Mdot
.32167 .45085 Mdot
.53235 .61476 Mdot
.48554 .31507 Mdot
.47709 .3142 Mdot
.38461 .46874 Mdot
.6596 .37352 Mdot
.26316 .4809 Mdot
.62017 .35112 Mdot
.52068 .64403 Mdot
.52649 .5782 Mdot
.61474 .49413 Mdot
.56308 .81444 Mdot
.60016 .40485 Mdot
.36714 .5279 Mdot
.64165 .33637 Mdot
.45307 .3181 Mdot
.37878 .49007 Mdot
.62212 .35494 Mdot
.60746 .40071 Mdot
.63792 .36435 Mdot
.37043 .63389 Mdot
.28127 .53033 Mdot
.62274 .43823 Mdot
.6399 .44464 Mdot
.56275 .57046 Mdot
.58485 .64882 Mdot
.76726 .65382 Mdot
.7573 .65024 Mdot
.33216 .62893 Mdot
.35244 .49235 Mdot
.38731 .14258 Mdot
.49592 .32134 Mdot
.32365 .25037 Mdot
.58109 .66165 Mdot
.43603 .1145 Mdot
.55319 .63586 Mdot
.57891 .61583 Mdot
.61908 .35599 Mdot
.35475 .6458 Mdot
.35363 .61356 Mdot
.62759 .4277 Mdot
.62482 .44481 Mdot
.34762 .62696 Mdot
.20382 .42908 Mdot
.4044 .82495 Mdot
.3668 .39295 Mdot
.64238 .40019 Mdot
.68881 .67671 Mdot
.43456 .34351 Mdot
.63931 .6702 Mdot
.42371 .34633 Mdot
.36121 .46241 Mdot
.38233 .43787 Mdot
.47324 .36449 Mdot
.57421 .57261 Mdot
.36303 .48445 Mdot
.61343 .57508 Mdot
.28354 .32187 Mdot
.73378 .57623 Mdot
.27848 .48398 Mdot
.62919 .69322 Mdot
.57315 .47567 Mdot
.44063 .27287 Mdot
.61771 .59973 Mdot
.34743 .7728 Mdot
.3463 .60863 Mdot
.53088 .66164 Mdot
.4872 .36123 Mdot
.80186 .6444 Mdot
.60373 .62857 Mdot
.64298 .4122 Mdot
.49335 .33802 Mdot
.64749 .2611 Mdot
.62613 .27932 Mdot
.5812 .64058 Mdot
.57942 .16057 Mdot
.63129 .4583 Mdot
.3708 .46906 Mdot
.71203 .32974 Mdot
.60624 .42607 Mdot
.37317 .56523 Mdot
.37277 .76185 Mdot
.18975 .60079 Mdot
.61808 .38363 Mdot
.36856 .42 Mdot
.61864 .36733 Mdot
.3729 .59829 Mdot
.58457 .39125 Mdot
.35371 .47321 Mdot
.60475 .59383 Mdot
.33492 .45157 Mdot
.36549 .63743 Mdot
.81398 .47041 Mdot
.44416 .31945 Mdot
.34434 .5032 Mdot
.46156 .35519 Mdot
.36955 .70433 Mdot
.44153 .76401 Mdot
.44743 .35028 Mdot
.67684 .49056 Mdot
.52566 .58313 Mdot
.61279 .43354 Mdot
.32238 .45968 Mdot
.29055 .65428 Mdot
.51913 .39219 Mdot
.62475 .39954 Mdot
.36546 .48934 Mdot
.65117 .29811 Mdot
.64703 .47064 Mdot
.52695 .57275 Mdot
.43791 .61751 Mdot
.63916 .40192 Mdot
.36486 .42112 Mdot
.83388 .43554 Mdot
.61556 .36921 Mdot
.31338 .47919 Mdot
.44012 .33894 Mdot
.48125 .32566 Mdot
.54759 .56546 Mdot
.43886 .37901 Mdot
.37863 .4723 Mdot
.44774 .297 Mdot
.66772 .4009 Mdot
.67273 .28039 Mdot
.37808 .63755 Mdot
.35023 .45168 Mdot
.62256 .57952 Mdot
.62873 .45211 Mdot
.38041 .27711 Mdot
.6949 .56027 Mdot
.69429 .23783 Mdot
.32859 .45655 Mdot
.6205 .39131 Mdot
.64618 .40952 Mdot
.53135 .6453 Mdot
.67031 .31511 Mdot
.25793 .49255 Mdot
.60335 .48887 Mdot
.55021 .41929 Mdot
.31653 .45228 Mdot
.40875 .45578 Mdot
.61297 .55195 Mdot
.57175 .57952 Mdot
.44833 .32112 Mdot
.60181 .59208 Mdot
.65858 .37765 Mdot
.53764 .58686 Mdot
.45413 .34859 Mdot
.37159 .45781 Mdot
.59901 .62875 Mdot
.34325 .60541 Mdot
.43944 .36708 Mdot
.50453 .32547 Mdot
.3519 .44741 Mdot
.61319 .42296 Mdot
.52429 .49792 Mdot
.32673 .46567 Mdot
.56597 .57705 Mdot
.44676 .52358 Mdot
.60215 .64301 Mdot
.52213 .52183 Mdot
.60992 .37385 Mdot
.37626 .44041 Mdot
.60106 .35796 Mdot
.46631 .34849 Mdot
.34146 .73028 Mdot
.59156 .59881 Mdot
.31308 .47163 Mdot
.40703 .29037 Mdot
.50371 .52838 Mdot
.67529 .41703 Mdot
.24374 .40293 Mdot
.60434 .42991 Mdot
.3461 .49181 Mdot
.26765 .28563 Mdot
.37862 .62096 Mdot
.39149 .46488 Mdot
.52235 .82035 Mdot
.35954 .4399 Mdot
.54382 .57179 Mdot
.54254 .61617 Mdot
.37885 .44976 Mdot
.33498 .6097 Mdot
.83723 .5563 Mdot
.40103 .42476 Mdot
.61686 .38648 Mdot
.24168 .35634 Mdot
.76089 .30474 Mdot
.47224 .27936 Mdot
.45223 .31971 Mdot
.61434 .67354 Mdot
.52668 .59956 Mdot
.4958 .35563 Mdot
.44082 .31965 Mdot
.3826 .60111 Mdot
.31803 .47834 Mdot
.64238 .45357 Mdot
.5135 .32846 Mdot
.69084 .34886 Mdot
.31037 .55273 Mdot
.52837 .63729 Mdot
.45666 .20467 Mdot
.58201 .66042 Mdot
.40699 .75069 Mdot
.4532 .35193 Mdot
.62647 .62477 Mdot
.5201 .58029 Mdot
.49917 .33964 Mdot
.35323 .63096 Mdot
.40837 .48589 Mdot
.34482 .46114 Mdot
.5162 .86969 Mdot
.59733 .56242 Mdot
.54097 .58264 Mdot
.48349 .35467 Mdot
.24366 .56723 Mdot
.63357 .39173 Mdot
.5943 .41039 Mdot
.3774 .4628 Mdot
.46161 .41303 Mdot
.53303 .57855 Mdot
.61325 .59679 Mdot
.34153 .46759 Mdot
.35349 .50051 Mdot
.29071 .38269 Mdot
.54939 .59926 Mdot
.4833 .34473 Mdot
.35106 .67457 Mdot
.454 .3579 Mdot
.61096 .63705 Mdot
.54253 .58531 Mdot
.54917 .64641 Mdot
.62803 .59808 Mdot
.41983 .3624 Mdot
.60747 .64388 Mdot
.53669 .54658 Mdot
.62168 .39392 Mdot
.57874 .64495 Mdot
.54381 .40544 Mdot
.59476 .58763 Mdot
.35076 .62855 Mdot
.7655 .41367 Mdot
.60263 .62891 Mdot
.53553 .59264 Mdot
.3987 .46777 Mdot
.59877 .6094 Mdot
.47934 .31164 Mdot
.64744 .39212 Mdot
.48825 .34911 Mdot
.47452 .31357 Mdot
.34233 .42624 Mdot
.34911 .58949 Mdot
.60126 .6667 Mdot
.34453 .63767 Mdot
.55691 .67389 Mdot
.61029 .57637 Mdot
.31955 .57966 Mdot
.46102 .15118 Mdot
.80604 .4289 Mdot
.59126 .59665 Mdot
.35692 .43618 Mdot
.34603 .43653 Mdot
.56484 .49657 Mdot
.54371 .55691 Mdot
.50229 .35885 Mdot
.45693 .31591 Mdot
.66736 .72159 Mdot
.55927 .74562 Mdot
.35106 .62918 Mdot
.47392 .48983 Mdot
.57827 .55836 Mdot
.62649 .6222 Mdot
.59782 .5598 Mdot
.35827 .42652 Mdot
.66892 .64852 Mdot
.38284 .48308 Mdot
.49088 .25888 Mdot
.46994 .36182 Mdot
.59131 .63579 Mdot
.43466 .21324 Mdot
.65066 .42826 Mdot
.6482 .39233 Mdot
.50906 .33257 Mdot
.29673 .47877 Mdot
.80333 .59037 Mdot
.21907 .6824 Mdot
.5807 .41763 Mdot
.36294 .6423 Mdot
.6127 .58841 Mdot
.37129 .44807 Mdot
.66043 .39038 Mdot
.36152 .64221 Mdot
.61283 .62975 Mdot
.28276 .53145 Mdot
.58804 .58854 Mdot
.52204 .22196 Mdot
.63256 .36825 Mdot
.3604 .81737 Mdot
.66202 .37591 Mdot
.44598 .37426 Mdot
.48265 .36564 Mdot
.54514 .59858 Mdot
.59657 .45626 Mdot
.60517 .42694 Mdot
.39199 .54036 Mdot
.35959 .58798 Mdot
.495 .27836 Mdot
.37613 .61929 Mdot
.36254 .47581 Mdot
.36662 .63233 Mdot
.35185 .47497 Mdot
.80775 .57476 Mdot
.69904 .41471 Mdot
.36241 .60839 Mdot
.41447 .28259 Mdot
.5275 .60471 Mdot
.33156 .63207 Mdot
.57746 .54267 Mdot
.5512 .51071 Mdot
.33866 .46679 Mdot
.36445 .59027 Mdot
.62512 .61801 Mdot
.62219 .78218 Mdot
.44538 .34341 Mdot
.49709 .36177 Mdot
.57788 .54319 Mdot
.32428 .4427 Mdot
.60747 .36592 Mdot
.29388 .73916 Mdot
.52148 .3365 Mdot
.54039 .60783 Mdot
.53697 .62938 Mdot
.60727 .43233 Mdot
.37638 .21857 Mdot
.54636 .58943 Mdot
.49387 .57271 Mdot
.5474 .6016 Mdot
.44957 .36565 Mdot
.59869 .39179 Mdot
.64833 .40208 Mdot
.36498 .48856 Mdot
.65668 .42738 Mdot
.45036 .58485 Mdot
.46671 .23096 Mdot
.58757 .52778 Mdot
.46515 .3446 Mdot
.52024 .27367 Mdot
.47433 .24938 Mdot
.52573 .80747 Mdot
.676 .40279 Mdot
.61353 .64339 Mdot
.65695 .42981 Mdot
.37149 .6234 Mdot
.65509 .39673 Mdot
.6539 .3689 Mdot
.61195 .61494 Mdot
.57818 .63723 Mdot
.37189 .46276 Mdot
.66241 .3134 Mdot
.61435 .42781 Mdot
.55351 .63517 Mdot
.53637 .63792 Mdot
.61707 .57635 Mdot
.40538 .54847 Mdot
.59893 .39853 Mdot
.18373 .41798 Mdot
.48588 .67788 Mdot
.61351 .42633 Mdot
.86758 .51421 Mdot
.39898 .28626 Mdot
.3434 .51783 Mdot
.39951 .51658 Mdot
.54743 .6056 Mdot
.32881 .49686 Mdot
.58394 .63518 Mdot
.45864 .20595 Mdot
.59764 .61589 Mdot
.34796 .62933 Mdot
.60555 .56929 Mdot
.38674 .4467 Mdot
.32972 .4589 Mdot
.53888 .60328 Mdot
.59537 .62876 Mdot
.82392 .48839 Mdot
.58664 .38135 Mdot
.64835 .38456 Mdot
.27057 .46324 Mdot
.36371 .60267 Mdot
.48023 .3636 Mdot
.57726 .60354 Mdot
.34616 .42565 Mdot
.33069 .45687 Mdot
.60105 .41324 Mdot
.33602 .4823 Mdot
.45907 .33619 Mdot
.58914 .60134 Mdot
.49579 .35812 Mdot
.37841 .62601 Mdot
.59949 .39301 Mdot
.57951 .64332 Mdot
.56309 .5702 Mdot
.64028 .3783 Mdot
.62649 .63633 Mdot
.33748 .60775 Mdot
.35355 .44077 Mdot
.61783 .38223 Mdot
.47434 .32968 Mdot
.35973 .4764 Mdot
.58472 .65462 Mdot
.54582 .15918 Mdot
.5521 .56614 Mdot
.54925 .61691 Mdot
.55725 .82674 Mdot
.58456 .56022 Mdot
.32488 .45866 Mdot
.66178 .39435 Mdot
.52916 .66757 Mdot
.46895 .69898 Mdot
.47282 .89323 Mdot
.38479 .47828 Mdot
.60686 .58385 Mdot
.55941 .79874 Mdot
.60468 .58528 Mdot
.69521 .6035 Mdot
.3491 .50669 Mdot
.5419 .44988 Mdot
.63028 .59389 Mdot
.4661 .32186 Mdot
.37622 .45312 Mdot
.34784 .47719 Mdot
.26678 .32676 Mdot
.6149 .60869 Mdot
.43541 .50239 Mdot
.60722 .63531 Mdot
.47296 .3274 Mdot
.5841 .73324 Mdot
.32726 .46003 Mdot
.73568 .29535 Mdot
.55507 .6009 Mdot
.605 .4026 Mdot
.39767 .45591 Mdot
.52737 .36202 Mdot
.57529 .65205 Mdot
.33659 .62537 Mdot
.46713 .30557 Mdot
.58455 .53205 Mdot
.46412 .34193 Mdot
.58178 .65239 Mdot
.57471 .70043 Mdot
.64616 .23772 Mdot
.64382 .36858 Mdot
.4437 .32958 Mdot
.43771 .53845 Mdot
.61443 .64055 Mdot
.61931 .38288 Mdot
.62569 .39701 Mdot
.37493 .63115 Mdot
.51661 .4764 Mdot
.60014 .25063 Mdot
.72368 .62631 Mdot
.25192 .34194 Mdot
.39397 .47123 Mdot
.34985 .37777 Mdot
.55578 .62096 Mdot
.43833 .59789 Mdot
.47336 .3115 Mdot
.55502 .56428 Mdot
.7741 .46355 Mdot
.63954 .43189 Mdot
.55624 .56709 Mdot
.35159 .61798 Mdot
.41103 .60774 Mdot
.36539 .67244 Mdot
.42699 .78993 Mdot
.3666 .46005 Mdot
.52694 .55207 Mdot
.52463 .66862 Mdot
.31961 .45176 Mdot
.55146 .65529 Mdot
.31996 .45877 Mdot
.19008 .47385 Mdot
.33677 .63954 Mdot
.6025 .39477 Mdot
.46587 .26851 Mdot
.57773 .66621 Mdot
.52968 .59161 Mdot
.35582 .58511 Mdot
.56923 .58227 Mdot
.59075 .19769 Mdot
.40398 .55271 Mdot
.36006 .48214 Mdot
.63965 .36539 Mdot
.54421 .64603 Mdot
.46732 .51998 Mdot
.59678 .58116 Mdot
.764 .60163 Mdot
.53528 .59534 Mdot
.63274 .27701 Mdot
.63869 .36898 Mdot
.46016 .34818 Mdot
.62999 .62392 Mdot
.58991 .61686 Mdot
.51466 .74249 Mdot
.56881 .67478 Mdot
.62425 .63023 Mdot
.66774 .36881 Mdot
.64744 .36763 Mdot
.61951 .36909 Mdot
.38347 .47405 Mdot
.62236 .75243 Mdot
.47634 .3458 Mdot
.56205 .68836 Mdot
.51642 .34601 Mdot
.66496 .54114 Mdot
.35288 .6434 Mdot
.48355 .78642 Mdot
.56829 .61328 Mdot
.65325 .41536 Mdot
.2901 .71115 Mdot
.58875 .39524 Mdot
.46837 .48015 Mdot
.49172 .33389 Mdot
.62467 .42748 Mdot
.58257 .61753 Mdot
.60245 .34097 Mdot
.58426 .80145 Mdot
.47278 .35234 Mdot
.55173 .66687 Mdot
.39127 .45142 Mdot
.29816 .51647 Mdot
.67991 .25065 Mdot
.44441 .34705 Mdot
.52734 .33227 Mdot
.6162 .60562 Mdot
.65742 .42275 Mdot
.4671 .32406 Mdot
.45075 .36491 Mdot
.34029 .48496 Mdot
.57529 .63769 Mdot
.57108 .63648 Mdot
.35271 .49393 Mdot
.48651 .35097 Mdot
.54385 .54565 Mdot
.57351 .52745 Mdot
.73849 .73325 Mdot
.65509 .28634 Mdot
.52667 .87551 Mdot
.54438 .50036 Mdot
.7517 .44574 Mdot
.29523 .74568 Mdot
.60866 .41802 Mdot
.62215 .60176 Mdot
.64013 .58336 Mdot
.37902 .47215 Mdot
.60049 .60141 Mdot
.32396 .50622 Mdot
.49289 .32495 Mdot
.79802 .64684 Mdot
.56622 .29661 Mdot
.18344 .53682 Mdot
.60217 .60313 Mdot
.68388 .40896 Mdot
.36815 .62202 Mdot
.50913 .29725 Mdot
.60203 .38384 Mdot
.61379 .56657 Mdot
.82194 .48454 Mdot
.38978 .46941 Mdot
.61682 .40881 Mdot
.84225 .52194 Mdot
.57949 .47067 Mdot
.60264 .64211 Mdot
.37502 .48865 Mdot
.33062 .76806 Mdot
.71186 .36876 Mdot
.504 .36317 Mdot
.35346 .63175 Mdot
.37614 .44362 Mdot
.44992 .31831 Mdot
.67834 .436 Mdot
.62118 .41671 Mdot
.60056 .37628 Mdot
.79563 .42837 Mdot
.38127 .49749 Mdot
.36827 .61916 Mdot
.55844 .76644 Mdot
.53946 .7439 Mdot
.34589 .62551 Mdot
.38257 .43761 Mdot
.6539 .37417 Mdot
.63396 .42896 Mdot
.64696 .39252 Mdot
.77776 .37212 Mdot
.66466 .42488 Mdot
.27935 .29276 Mdot
.62263 .58503 Mdot
.54171 .5289 Mdot
.60904 .58702 Mdot
.50481 .35503 Mdot
.63458 .37641 Mdot
.49571 .40698 Mdot
.53673 .66082 Mdot
.48161 .77299 Mdot
.54499 .5686 Mdot
.4298 .36152 Mdot
.55311 .57248 Mdot
.45513 .18739 Mdot
.6479 .4353 Mdot
.59477 .59879 Mdot
.42556 .34991 Mdot
.36364 .59915 Mdot
.67669 .4141 Mdot
.58351 .6408 Mdot
.23457 .43253 Mdot
.59389 .56405 Mdot
.19016 .51959 Mdot
.61084 .23301 Mdot
.36056 .64277 Mdot
.51161 .19946 Mdot
.371 .41824 Mdot
.51301 .54874 Mdot
.5955 .68643 Mdot
.46597 .35344 Mdot
.49524 .28051 Mdot
.36054 .45349 Mdot
.67162 .61164 Mdot
.54896 .53641 Mdot
.37744 .62965 Mdot
.69258 .43064 Mdot
.49955 .3498 Mdot
.54533 .64981 Mdot
.51763 .59038 Mdot
.34688 .25785 Mdot
.56515 .5375 Mdot
.53365 .61846 Mdot
.34788 .58491 Mdot
.30489 .2681 Mdot
.58956 .58275 Mdot
.47271 .48357 Mdot
.58551 .38894 Mdot
.52838 .65572 Mdot
.28589 .28205 Mdot
.54331 .61989 Mdot
.61618 .41782 Mdot
.50212 .55185 Mdot
.5775 .23844 Mdot
.34646 .59101 Mdot
.53499 .59455 Mdot
.3614 .21111 Mdot
.5584 .59076 Mdot
.48095 .34202 Mdot
.54117 .55931 Mdot
.35555 .47086 Mdot
.80955 .42138 Mdot
.36866 .48382 Mdot
.5481 .56175 Mdot
.64461 .39481 Mdot
.47661 .35814 Mdot
.75102 .3542 Mdot
.2625 .53012 Mdot
.34183 .24504 Mdot
.22446 .6749 Mdot
.35506 .59017 Mdot
.35989 .65296 Mdot
.50146 .33245 Mdot
.59438 .59665 Mdot
.2308 .32646 Mdot
.58579 .67581 Mdot
.57052 .56753 Mdot
.59719 .61704 Mdot
.4341 .7611 Mdot
.48234 .31622 Mdot
.33368 .46474 Mdot
.5447 .58712 Mdot
.61443 .63897 Mdot
.60753 .41143 Mdot
.35561 .60189 Mdot
.32368 .44906 Mdot
.35069 .60907 Mdot
.37486 .44939 Mdot
.83374 .5854 Mdot
.53052 .55751 Mdot
.3669 .59823 Mdot
.49473 .31229 Mdot
.61186 .41471 Mdot
.47936 .23675 Mdot
.35363 .47861 Mdot
.37822 .47897 Mdot
.53677 .60222 Mdot
.6174 .42402 Mdot
.61084 .3556 Mdot
.37658 .61303 Mdot
.4502 .34445 Mdot
.60364 .62818 Mdot
.59941 .56998 Mdot
.54269 .69386 Mdot
.32865 .4365 Mdot
.51147 .21787 Mdot
.30341 .39726 Mdot
.59186 .59487 Mdot
.66721 .40032 Mdot
.59818 .62452 Mdot
.2179 .60151 Mdot
.65518 .42648 Mdot
.54595 .6261 Mdot
.86621 .46699 Mdot
.32318 .51686 Mdot
.55158 .25277 Mdot
.54027 .63207 Mdot
.29209 .76547 Mdot
.56073 .61735 Mdot
.80667 .64374 Mdot
.27469 .65925 Mdot
.53265 .57211 Mdot
.57274 .65282 Mdot
.71835 .55981 Mdot
.60588 .57843 Mdot
.35948 .4937 Mdot
.76045 .67389 Mdot
.59119 .38675 Mdot
.46507 .25275 Mdot
.76701 .42542 Mdot
.3388 .59747 Mdot
.37742 .46256 Mdot
.39717 .48748 Mdot
.34459 .61792 Mdot
.64232 .40302 Mdot
.584 .58808 Mdot
.45799 .43777 Mdot
.3323 .43696 Mdot
.64552 .56015 Mdot
.48336 .34032 Mdot
.34274 .32096 Mdot
.42309 .5992 Mdot
.46305 .33903 Mdot
.57608 .6452 Mdot
.70674 .55367 Mdot
.80221 .5652 Mdot
.44949 .83703 Mdot
.44086 .32523 Mdot
.47232 .35413 Mdot
.79678 .39261 Mdot
.38925 .61507 Mdot
.34611 .26227 Mdot
.6311 .27964 Mdot
.4786 .36136 Mdot
.65465 .46063 Mdot
.35175 .49753 Mdot
.43606 .39255 Mdot
.50652 .61622 Mdot
.61863 .5841 Mdot
.58474 .61692 Mdot
.44969 .35366 Mdot
.51446 .51929 Mdot
.69845 .29514 Mdot
.46119 .35734 Mdot
.64234 .64883 Mdot
.5185 .44676 Mdot
.39644 .35379 Mdot
.32719 .47815 Mdot
.36451 .58744 Mdot
.3879 .62982 Mdot
.60845 .39563 Mdot
.35804 .58688 Mdot
.41539 .62208 Mdot
.57309 .58867 Mdot
.45995 .3625 Mdot
.41556 .26137 Mdot
.48114 .32876 Mdot
.34805 .61456 Mdot
.38528 .60437 Mdot
.62262 .39378 Mdot
.65191 .38648 Mdot
.72754 .48141 Mdot
.4403 .6385 Mdot
.58163 .56848 Mdot
.2975 .64907 Mdot
.64367 .36168 Mdot
.60678 .50947 Mdot
.36246 .58642 Mdot
.36224 .60087 Mdot
.50331 .74565 Mdot
.57079 .61556 Mdot
.63239 .51638 Mdot
.57355 .61081 Mdot
.51452 .69202 Mdot
.56925 .65652 Mdot
.33929 .48453 Mdot
.56736 .62403 Mdot
.50547 .75291 Mdot
.61603 .65421 Mdot
.52371 .60619 Mdot
.35313 .42565 Mdot
.55699 .53005 Mdot
.35484 .46942 Mdot
.56121 .55967 Mdot
.35185 .64948 Mdot
.37908 .4634 Mdot
.45651 .70591 Mdot
.48007 .74309 Mdot
.38001 .43307 Mdot
.35418 .63975 Mdot
.32825 .61665 Mdot
.42418 .71867 Mdot
.6012 .38458 Mdot
.6232 .67427 Mdot
.59702 .59752 Mdot
.37139 .49758 Mdot
.46411 .31539 Mdot
.57974 .6568 Mdot
.53032 .61538 Mdot
.54927 .64027 Mdot
.607 .39685 Mdot
.25805 .49837 Mdot
.36931 .5971 Mdot
.35358 .49525 Mdot
.51485 .50184 Mdot
.31651 .45114 Mdot
.51579 .60567 Mdot
.64268 .59463 Mdot
.77054 .44419 Mdot
.40005 .326 Mdot
.77673 .35895 Mdot
.62079 .41475 Mdot
.34444 .43616 Mdot
.37557 .64107 Mdot
.64282 .61884 Mdot
.65448 .41587 Mdot
.35364 .47272 Mdot
.58811 .58941 Mdot
.5533 .66483 Mdot
.45163 .23563 Mdot
.37593 .67368 Mdot
.47051 .72979 Mdot
.38616 .4653 Mdot
.38848 .43414 Mdot
.46806 .75281 Mdot
.35124 .66623 Mdot
.51003 .39726 Mdot
.61048 .60112 Mdot
.33707 .62368 Mdot
.6609 .39624 Mdot
.79548 .45304 Mdot
.4652 .3699 Mdot
.6694 .31636 Mdot
.60063 .60368 Mdot
.56085 .46698 Mdot
.64303 .39405 Mdot
.35036 .62071 Mdot
.45018 .35714 Mdot
.39912 .61983 Mdot
.35118 .4301 Mdot
.18018 .59541 Mdot
.56146 .58481 Mdot
.53674 .5979 Mdot
.43164 .35277 Mdot
.64854 .42609 Mdot
.32464 .61495 Mdot
.24022 .36588 Mdot
.34333 .48047 Mdot
.23969 .31189 Mdot
.66647 .40445 Mdot
.68877 .67224 Mdot
.33175 .48767 Mdot
.51447 .33464 Mdot
.43344 .7097 Mdot
.45745 .34124 Mdot
.54134 .56773 Mdot
.64874 .41393 Mdot
.44766 .32509 Mdot
.67571 .30544 Mdot
.59704 .81294 Mdot
.69278 .66907 Mdot
.57677 .59318 Mdot
.67323 .76629 Mdot
.20461 .4731 Mdot
.57853 .4164 Mdot
.46189 .31314 Mdot
.55236 .56449 Mdot
.53261 .59247 Mdot
.55776 .58857 Mdot
.46795 .317 Mdot
.29904 .64492 Mdot
.33832 .46955 Mdot
.61523 .59671 Mdot
.38333 .60378 Mdot
.35811 .46295 Mdot
.52045 .35629 Mdot
.32527 .47262 Mdot
.66719 .37593 Mdot
.52057 .62505 Mdot
.53996 .34066 Mdot
.88545 .42545 Mdot
.48025 .35209 Mdot
.34879 .42363 Mdot
.5502 .54861 Mdot
.37229 .31007 Mdot
.62075 .36149 Mdot
.34473 .48276 Mdot
.5407 .58078 Mdot
.42167 .27659 Mdot
.81251 .45611 Mdot
.32456 .46695 Mdot
.65596 .41497 Mdot
.45647 .83494 Mdot
.60244 .59636 Mdot
.56197 .60672 Mdot
.62453 .42359 Mdot
.649 .48397 Mdot
.83596 .45861 Mdot
.59599 .62726 Mdot
.45874 .34961 Mdot
.15332 .52359 Mdot
.52976 .61371 Mdot
.53674 .71406 Mdot
.37484 .45841 Mdot
.48357 .39561 Mdot
.55564 .22528 Mdot
.62908 .64243 Mdot
.29852 .30984 Mdot
.46334 .27319 Mdot
.60589 .77063 Mdot
.3191 .505 Mdot
.23079 .50307 Mdot
.66293 .75549 Mdot
.42295 .36135 Mdot
.68162 .37748 Mdot
.2718 .3343 Mdot
.72958 .38203 Mdot
.37916 .79993 Mdot
.23929 .58692 Mdot
.82271 .48251 Mdot
.47445 .43518 Mdot
.36576 .43875 Mdot
.59637 .49705 Mdot
.58488 .637 Mdot
.2041 .47983 Mdot
.64892 .24833 Mdot
.66943 .26528 Mdot
.67382 .7671 Mdot
.69782 .6216 Mdot
.5652 .79886 Mdot
.53527 .81396 Mdot
.56877 .71713 Mdot
.33273 .38847 Mdot
.22922 .32102 Mdot
.80576 .60613 Mdot
.20754 .40146 Mdot
.5478 .52541 Mdot
.4589 .4806 Mdot
.19675 .58271 Mdot
.69778 .40205 Mdot
.65418 .46779 Mdot
.35948 .48929 Mdot
.60138 .3806 Mdot
.32916 .27917 Mdot
.60819 .43537 Mdot
.57482 .23553 Mdot
.48335 .84486 Mdot
.58835 .81362 Mdot
.37807 .21044 Mdot
.29957 .76366 Mdot
.7672 .46094 Mdot
.20505 .30689 Mdot
.31216 .49058 Mdot
.60331 .41667 Mdot
.41919 .75037 Mdot
.52902 .76148 Mdot
.54644 .30938 Mdot
.24028 .3898 Mdot
.3035 .53584 Mdot
.38575 .69113 Mdot
.64387 .40993 Mdot
.52417 .20533 Mdot
.45498 .39002 Mdot
.5607 .3005 Mdot
.78412 .63686 Mdot
.45623 .81861 Mdot
.44672 .44119 Mdot
.26552 .36996 Mdot
.348 .3417 Mdot
.71542 .30264 Mdot
.47195 .67902 Mdot
.58538 .49283 Mdot
.64544 .27938 Mdot
.26972 .71195 Mdot
.70896 .44776 Mdot
.50975 .68452 Mdot
.54102 .76049 Mdot
.84271 .55949 Mdot
.20701 .53213 Mdot
.79518 .31721 Mdot
.6051 .43563 Mdot
.53764 .63239 Mdot
.66713 .49675 Mdot
.32759 .22707 Mdot
.3648 .57754 Mdot
.41042 .78733 Mdot
.37563 .59574 Mdot
.65822 .36734 Mdot
.82207 .44612 Mdot
.29711 .27212 Mdot
.27302 .26272 Mdot
.35673 .65109 Mdot
.56077 .68896 Mdot
.2921 .80459 Mdot
.55035 .78253 Mdot
.55213 .27357 Mdot
.74469 .72402 Mdot
.53111 .43173 Mdot
.66528 .27423 Mdot
.44896 .32294 Mdot
.69296 .74114 Mdot
.63644 .42495 Mdot
.79533 .29942 Mdot
.81756 .62845 Mdot
.78912 .46708 Mdot
.82768 .718 Mdot
.45114 .75734 Mdot
.54644 .45255 Mdot
.46593 .28944 Mdot
.43802 .67592 Mdot
.71369 .32439 Mdot
.34049 .719 Mdot
.36552 .31964 Mdot
.28323 .76472 Mdot
.65124 .76667 Mdot
.25289 .28586 Mdot
.17075 .5308 Mdot
.71513 .42088 Mdot
.47257 .51424 Mdot
.62844 .68865 Mdot
.29444 .50546 Mdot
.39346 .78817 Mdot
.85323 .54702 Mdot
.48802 .68128 Mdot
.46551 .89279 Mdot
.32044 .64697 Mdot
.29479 .55628 Mdot
.52827 .85579 Mdot
.39704 .69697 Mdot
.56318 .21557 Mdot
.61083 .74572 Mdot
.65467 .66739 Mdot
.47422 .53539 Mdot
.40946 .79217 Mdot
.51304 .23708 Mdot
.73722 .70306 Mdot
.32958 .78122 Mdot
.35151 .25553 Mdot
.73861 .58939 Mdot
.54318 .73317 Mdot
.65813 .44603 Mdot
.42019 .64362 Mdot
.5675 .22504 Mdot
.62101 .80696 Mdot
.42913 .37176 Mdot
.65167 .80196 Mdot
.83633 .46659 Mdot
.53178 .55441 Mdot
.63255 .66178 Mdot
.59854 .48084 Mdot
.41249 .65553 Mdot
.53376 .53964 Mdot
.42495 .23419 Mdot
.57825 .82054 Mdot
.78615 .58298 Mdot
.43935 .27047 Mdot
.48365 .27412 Mdot
.52566 .86167 Mdot
.69434 .51239 Mdot
.34848 .66338 Mdot
.73823 .68555 Mdot
.71854 .32464 Mdot
.35383 .45538 Mdot
.26172 .28247 Mdot
.51093 .31489 Mdot
.80586 .45829 Mdot
.7209 .62627 Mdot
.74336 .41656 Mdot
.57885 .82114 Mdot
.24114 .48454 Mdot
.82653 .46412 Mdot
.3719 .71364 Mdot
.2134 .36611 Mdot
.39782 .34683 Mdot
.62015 .5545 Mdot
.23647 .40175 Mdot
.33033 .61771 Mdot
.73251 .52 Mdot
.15898 .46661 Mdot
.26136 .58621 Mdot
.60041 .54644 Mdot
.79001 .46203 Mdot
.3759 .51455 Mdot
.59808 .34181 Mdot
.72309 .25104 Mdot
.52518 .62025 Mdot
.56171 .76072 Mdot
.22511 .47768 Mdot
.43868 .65952 Mdot
.39048 .82411 Mdot
.2361 .64617 Mdot
.82391 .34542 Mdot
.71116 .74169 Mdot
.25529 .52365 Mdot
.64655 .7571 Mdot
.64552 .78249 Mdot
.82316 .35242 Mdot
.6012 .67903 Mdot
.45048 .37657 Mdot
.51308 .14256 Mdot
.32558 .47821 Mdot
.5358 .77111 Mdot
.25205 .34162 Mdot
.41243 .59154 Mdot
.55265 .38197 Mdot
.66726 .60117 Mdot
.4717 .44203 Mdot
.58689 .37796 Mdot
.53537 .53967 Mdot
.77499 .32654 Mdot
.8551 .40262 Mdot
.79082 .32705 Mdot
.2274 .66219 Mdot
.69675 .73416 Mdot
.54561 .47297 Mdot
.35001 .22402 Mdot
.61225 .51656 Mdot
.6257 .6127 Mdot
.39241 .5827 Mdot
.44366 .75662 Mdot
.78507 .43373 Mdot
.5901 .30177 Mdot
.69775 .42141 Mdot
.40797 .78831 Mdot
.10253 .55556 Mdot
.74359 .47992 Mdot
.25955 .31267 Mdot
.37816 .6505 Mdot
.43706 .64295 Mdot
.3521 .76008 Mdot
.76801 .40844 Mdot
.54643 .82225 Mdot
.58815 .37701 Mdot
.22266 .38707 Mdot
.26264 .61386 Mdot
.67908 .36484 Mdot
.26019 .50243 Mdot
.53842 .79378 Mdot
.49444 .27008 Mdot
.757 .38228 Mdot
.62239 .28819 Mdot
.67769 .48665 Mdot
.38707 .54992 Mdot
.32997 .3399 Mdot
.18304 .41631 Mdot
.22316 .59132 Mdot
.53637 .71077 Mdot
.51002 .44837 Mdot
.49141 .1947 Mdot
.43368 .28562 Mdot
.50742 .68879 Mdot
.54043 .40285 Mdot
.59299 .75346 Mdot
.78383 .24422 Mdot
.73813 .28702 Mdot
.4769 .853 Mdot
.30937 .69499 Mdot
.58721 .53631 Mdot
.53115 .83019 Mdot
.76993 .28562 Mdot
.87845 .49918 Mdot
.30684 .35112 Mdot
.30679 .48802 Mdot
.51696 .34119 Mdot
.79534 .36462 Mdot
.30301 .61044 Mdot
.50004 .82344 Mdot
.51709 .71093 Mdot
.49862 .31819 Mdot
.42834 .14954 Mdot
.83227 .57279 Mdot
.71146 .64988 Mdot
.38889 .66585 Mdot
.63487 .58491 Mdot
.54158 .19192 Mdot
.60237 .4252 Mdot
.37035 .36729 Mdot
.44622 .64043 Mdot
.34501 .45162 Mdot
.39095 .75593 Mdot
.22711 .40591 Mdot
.60639 .56981 Mdot
.45081 .52898 Mdot
.66747 .42884 Mdot
.39547 .3366 Mdot
.51286 .2628 Mdot
.8762 .47047 Mdot
.4004 .62665 Mdot
.62734 .58575 Mdot
.44739 .6632 Mdot
.2646 .49189 Mdot
.83412 .4351 Mdot
.50029 .32635 Mdot
.62912 .77786 Mdot
.44748 .46122 Mdot
.42931 .63525 Mdot
.71375 .35597 Mdot
.57622 .50858 Mdot
.52385 .59177 Mdot
.26199 .69057 Mdot
.78358 .56977 Mdot
.6579 .334 Mdot
.51308 .63898 Mdot
.63306 .54185 Mdot
.52381 .83127 Mdot
.41269 .61535 Mdot
.34432 .32828 Mdot
.61588 .7892 Mdot
.48117 .32082 Mdot
.65889 .42793 Mdot
.31073 .65091 Mdot
.20262 .41467 Mdot
.68447 .69913 Mdot
.81217 .45442 Mdot
.42499 .58628 Mdot
.2678 .57777 Mdot
.61362 .79853 Mdot
.61136 .77783 Mdot
.47281 .17262 Mdot
.60903 .45293 Mdot
.47037 .62909 Mdot
.19535 .41719 Mdot
.6234 .35787 Mdot
.33072 .25784 Mdot
.36445 .24391 Mdot
.81801 .61326 Mdot
.44312 .53045 Mdot
.29215 .77548 Mdot
.4695 .72615 Mdot
.37433 .76507 Mdot
.75017 .34901 Mdot
.20723 .38846 Mdot
.51188 .78146 Mdot
.57717 .40863 Mdot
.7167 .57969 Mdot
.58236 .52747 Mdot
.43528 .2011 Mdot
.51235 .15038 Mdot
.30962 .6329 Mdot
.55511 .42495 Mdot
.33634 .78826 Mdot
.57406 .579 Mdot
.70592 .24625 Mdot
.2247 .39967 Mdot
.7905 .3848 Mdot
.50649 .32523 Mdot
.59044 .64702 Mdot
.58758 .66942 Mdot
.68637 .72395 Mdot
.56623 .23563 Mdot
.60521 .75281 Mdot
.15868 .52267 Mdot
.3437 .77477 Mdot
.70381 .41673 Mdot
.5383 .76818 Mdot
.45903 .82127 Mdot
.20627 .48391 Mdot
.50667 .47296 Mdot
.34004 .72561 Mdot
.41396 .69792 Mdot
.28647 .74234 Mdot
.54273 .38349 Mdot
.41631 .46825 Mdot
.48236 .25721 Mdot
.26348 .43092 Mdot
.78199 .40386 Mdot
.56925 .64591 Mdot
.84207 .52293 Mdot
.51407 .81273 Mdot
.51368 .18158 Mdot
.65724 .23891 Mdot
.74242 .29117 Mdot
.76733 .58078 Mdot
.21418 .52894 Mdot
.21223 .44939 Mdot
.17271 .41604 Mdot
.44246 .4629 Mdot
.45627 .77325 Mdot
.3902 .7049 Mdot
.61458 .79491 Mdot
.43353 .35599 Mdot
.61533 .27139 Mdot
.45348 .26396 Mdot
.63026 .75714 Mdot
.69916 .52396 Mdot
.54353 .8032 Mdot
.518 .4233 Mdot
.82728 .34537 Mdot
.23834 .63053 Mdot
.48782 .43038 Mdot
.35864 .43063 Mdot
.23069 .52074 Mdot
.45453 .79773 Mdot
.247 .63856 Mdot
.22117 .3622 Mdot
.32406 .51505 Mdot
.50519 .51486 Mdot
.68742 .64363 Mdot
.41823 .6417 Mdot
.25915 .69055 Mdot
.44653 .66303 Mdot
.57669 .81375 Mdot
.70308 .72138 Mdot
.8414 .51918 Mdot
.45968 .76059 Mdot
.21626 .6639 Mdot
.55176 .2704 Mdot
.39977 .65254 Mdot
.22587 .40173 Mdot
.29986 .57306 Mdot
.58018 .38769 Mdot
.48586 .0935 Mdot
.18341 .59091 Mdot
.21971 .5688 Mdot
.85007 .55243 Mdot
.23435 .65191 Mdot
.39782 .32634 Mdot
.66886 .46881 Mdot
.66205 .30138 Mdot
.82531 .54232 Mdot
.59614 .61652 Mdot
.76724 .30527 Mdot
.44811 .61618 Mdot
.87599 .4255 Mdot
.50102 .83164 Mdot
.55255 .41563 Mdot
.51901 .62067 Mdot
.3627 .49571 Mdot
.43256 .49671 Mdot
.59267 .7291 Mdot
.67503 .52785 Mdot
.60234 .22611 Mdot
.4207 .29753 Mdot
.31274 .48884 Mdot
.27101 .47242 Mdot
.58007 .40205 Mdot
.31014 .68641 Mdot
.28126 .41363 Mdot
.3037 .44193 Mdot
.43775 .43802 Mdot
.47174 .65932 Mdot
.54603 .22107 Mdot
.70654 .6597 Mdot
.77142 .40909 Mdot
.53701 .31796 Mdot
.34197 .48888 Mdot
.72359 .63908 Mdot
.1946 .59014 Mdot
.33036 .77201 Mdot
.85273 .54363 Mdot
.47199 .5334 Mdot
.6891 .55743 Mdot
.55859 .72424 Mdot
.68756 .27623 Mdot
.59673 .46162 Mdot
.40909 .32389 Mdot
.54014 .19405 Mdot
.62285 .47529 Mdot
.28654 .32573 Mdot
.80011 .64463 Mdot
.21186 .39757 Mdot
.1938 .41754 Mdot
.36448 .55231 Mdot
.50857 .65862 Mdot
.67015 .36826 Mdot
.46099 .7134 Mdot
.52555 .38731 Mdot
.26661 .25063 Mdot
.53065 .66151 Mdot
.24251 .24764 Mdot
.44542 .36275 Mdot
.71881 .39404 Mdot
.40892 .70333 Mdot
.51788 .45309 Mdot
.52651 .41541 Mdot
.22635 .60714 Mdot
.62559 .26957 Mdot
.20881 .51489 Mdot
.69525 .29617 Mdot
.31423 .49388 Mdot
.15538 .5608 Mdot
.22751 .69461 Mdot
.72709 .58127 Mdot
.57838 .55442 Mdot
.18904 .61675 Mdot
.30605 .4761 Mdot
.77967 .42482 Mdot
.397 .82583 Mdot
.30143 .72213 Mdot
.68206 .62406 Mdot
.43248 .64007 Mdot
.464 .775 Mdot
.68789 .76614 Mdot
.50819 .16245 Mdot
.39926 .78538 Mdot
.43414 .3549 Mdot
.51634 .43249 Mdot
.50518 .79724 Mdot
.64047 .25661 Mdot
.43621 .38248 Mdot
.5893 .22346 Mdot
.18173 .32165 Mdot
.54273 .77454 Mdot
.58598 .74964 Mdot
.63514 .24602 Mdot
.66314 .37839 Mdot
.61631 .25373 Mdot
.55966 .21516 Mdot
.2813 .69027 Mdot
.18841 .53958 Mdot
.56049 .21885 Mdot
.1748 .38178 Mdot
.54768 .51105 Mdot
.39892 .39847 Mdot
.62748 .51572 Mdot
.62192 .72258 Mdot
.4777 .30778 Mdot
.79932 .60039 Mdot
.36357 .79167 Mdot
.46612 .37787 Mdot
.27457 .70477 Mdot
.25998 .37861 Mdot
.63523 .70508 Mdot
.69678 .69026 Mdot
.32974 .75141 Mdot
.69947 .54256 Mdot
.43649 .18952 Mdot
.80008 .47454 Mdot
.30267 .46704 Mdot
.4039 .81259 Mdot
.3572 .48124 Mdot
.6521 .5721 Mdot
.67779 .31882 Mdot
.34642 .72395 Mdot
.78384 .3678 Mdot
.33491 .60249 Mdot
.59705 .40923 Mdot
.51369 .15439 Mdot
.66301 .39127 Mdot
.78238 .33248 Mdot
.74766 .41295 Mdot
.57471 .20354 Mdot
.25285 .53229 Mdot
.24618 .5649 Mdot
.17229 .35055 Mdot
.47329 .38815 Mdot
.28995 .46375 Mdot
.40583 .21646 Mdot
.60313 .41984 Mdot
.36251 .55423 Mdot
.37421 .43168 Mdot
.41938 .42347 Mdot
.35291 .26667 Mdot
.53847 .51629 Mdot
.66166 .44828 Mdot
.42566 .43489 Mdot
.75814 .65523 Mdot
.75451 .69643 Mdot
.32476 .45263 Mdot
.2932 .21555 Mdot
.51878 .60957 Mdot
.74081 .57687 Mdot
.55569 .8242 Mdot
.42261 .15116 Mdot
.29913 .41837 Mdot
.24876 .72902 Mdot
.63378 .62356 Mdot
.3294 .73426 Mdot
.63713 .41885 Mdot
.21752 .39463 Mdot
.37982 .61215 Mdot
.43393 .6625 Mdot
.46225 .37357 Mdot
.75528 .38016 Mdot
.28932 .42328 Mdot
.60474 .37061 Mdot
.3019 .69616 Mdot
.56688 .71598 Mdot
.43013 .32037 Mdot
.24785 .50052 Mdot
.72631 .59 Mdot
.65856 .70848 Mdot
.68585 .43502 Mdot
.57416 .75148 Mdot
.17523 .44905 Mdot
.87914 .47065 Mdot
.57771 .3594 Mdot
.57927 .47425 Mdot
.39803 .2407 Mdot
.29804 .73173 Mdot
.45756 .21225 Mdot
.57679 .82562 Mdot
.47037 .64881 Mdot
.48203 .58319 Mdot
.49843 .67776 Mdot
.60427 .5261 Mdot
.48778 .45995 Mdot
.35211 .3505 Mdot
.6228 .22561 Mdot
.52029 .22218 Mdot
.69651 .45437 Mdot
.45542 .19764 Mdot
.56073 .74146 Mdot
.57859 .2079 Mdot
.31111 .44037 Mdot
.66426 .69989 Mdot
.5038 .29511 Mdot
.7567 .69747 Mdot
.57002 .82481 Mdot
.52003 .35193 Mdot
.28331 .49958 Mdot
.32952 .79499 Mdot
.59535 .67503 Mdot
.52162 .49186 Mdot
.5368 .59267 Mdot
.46494 .55915 Mdot
.38455 .16419 Mdot
.29078 .71172 Mdot
.58568 .5434 Mdot
.62982 .76942 Mdot
.65972 .75988 Mdot
.84957 .3777 Mdot
.21972 .33876 Mdot
.62237 .39024 Mdot
.82595 .36864 Mdot
.59215 .22101 Mdot
.67746 .77249 Mdot
.39319 .36369 Mdot
.59882 .84077 Mdot
.71765 .5733 Mdot
.29829 .74457 Mdot
.66172 .46874 Mdot
.64558 .28816 Mdot
.23398 .46684 Mdot
.52118 .4865 Mdot
.36079 .29721 Mdot
.21709 .6089 Mdot
.14195 .54452 Mdot
.61108 .53959 Mdot
.23632 .41938 Mdot
.54874 .33015 Mdot
.42203 .82217 Mdot
.24428 .6166 Mdot
.56158 .55306 Mdot
.47978 .27071 Mdot
.77774 .37831 Mdot
.47817 .66619 Mdot
.57004 .48696 Mdot
.23571 .60067 Mdot
.81938 .52725 Mdot
.57019 .727 Mdot
.19658 .41167 Mdot
.72273 .58726 Mdot
.44307 .48161 Mdot
.61229 .64229 Mdot
.62899 .45458 Mdot
.32291 .64051 Mdot
.50145 .49563 Mdot
.56836 .56098 Mdot
.39475 .44148 Mdot
.41377 .36965 Mdot
.76442 .32365 Mdot
.5226 .24314 Mdot
.20174 .44273 Mdot
.68759 .41893 Mdot
.58457 .32442 Mdot
.44786 .21614 Mdot
.7318 .29058 Mdot
.27719 .63624 Mdot
.4875 .68107 Mdot
.57017 .79167 Mdot
.70537 .72287 Mdot
.69467 .36419 Mdot
.86589 .4532 Mdot
.46887 .31179 Mdot
.65178 .69876 Mdot
.60944 .30669 Mdot
.286 .4683 Mdot
.50602 .57775 Mdot
.29761 .74266 Mdot
.41479 .6007 Mdot
.5152 .75712 Mdot
.20512 .54022 Mdot
.47831 .56447 Mdot
.70133 .63638 Mdot
.62901 .77484 Mdot
.38216 .48296 Mdot
.1846 .46283 Mdot
.45606 .29798 Mdot
.23877 .59815 Mdot
.70568 .72688 Mdot
.83689 .57489 Mdot
.49778 .41325 Mdot
.41757 .68825 Mdot
.5575 .60586 Mdot
.1861 .41525 Mdot
.2865 .70887 Mdot
.64843 .6844 Mdot
.3246 .32786 Mdot
.66247 .42281 Mdot
.31234 .36771 Mdot
.45353 .48316 Mdot
.81841 .55073 Mdot
.6523 .44161 Mdot
.55377 .19372 Mdot
.34013 .64902 Mdot
.55132 .44685 Mdot
.50002 .61078 Mdot
.42992 .68327 Mdot
.22782 .30377 Mdot
.51449 .6451 Mdot
.40951 .79515 Mdot
.72584 .61503 Mdot
.23833 .36913 Mdot
.32393 .74055 Mdot
.40666 .30445 Mdot
.62866 .27092 Mdot
.67495 .69819 Mdot
.46483 .25471 Mdot
.54213 .63146 Mdot
.29847 .47184 Mdot
.61154 .36718 Mdot
.40632 .81899 Mdot
.7676 .59023 Mdot
.45348 .70545 Mdot
.40573 .54829 Mdot
.57329 .49075 Mdot
.48003 .29033 Mdot
.58628 .83732 Mdot
.63635 .27482 Mdot
.45492 .64557 Mdot
.44404 .53008 Mdot
.41688 .70196 Mdot
.7333 .43227 Mdot
.83236 .60749 Mdot
.67288 .46401 Mdot
.45326 .42898 Mdot
.71878 .3884 Mdot
.21461 .54931 Mdot
.38603 .82579 Mdot
.50592 .68194 Mdot
.54469 .42972 Mdot
.33231 .59789 Mdot
.44523 .23169 Mdot
.39247 .5436 Mdot
.54294 .49366 Mdot
.42262 .4457 Mdot
.3315 .30083 Mdot
.58354 .33974 Mdot
.60263 .69948 Mdot
.47797 .76092 Mdot
.58902 .7866 Mdot
.24228 .35339 Mdot
.42921 .29258 Mdot
.3483 .38663 Mdot
.79658 .58831 Mdot
.61159 .84483 Mdot
.58731 .18137 Mdot
.55796 .60274 Mdot
.45647 .28138 Mdot
.40501 .68232 Mdot
.38734 .4528 Mdot
.53074 .21345 Mdot
.46806 .22518 Mdot
.43986 .34449 Mdot
.42636 .62501 Mdot
.535 .75107 Mdot
.253 .44704 Mdot
.37192 .68099 Mdot
.50293 .2875 Mdot
.75467 .30857 Mdot
.20898 .62995 Mdot
.30057 .73364 Mdot
.71588 .79049 Mdot
.4301 .30881 Mdot
.65572 .61202 Mdot
.70203 .49488 Mdot
.72418 .72065 Mdot
.45281 .66905 Mdot
.7979 .44503 Mdot
.39365 .28886 Mdot
.49784 .67268 Mdot
.57025 .39703 Mdot
.50072 .76027 Mdot
.30632 .36729 Mdot
.49177 .44736 Mdot
.24843 .57316 Mdot
.87175 .45479 Mdot
.6903 .62258 Mdot
.57247 .79744 Mdot
.76118 .35694 Mdot
.17224 .4104 Mdot
.71932 .72752 Mdot
.47592 .74115 Mdot
.26689 .64551 Mdot
.67082 .49951 Mdot
.53862 .39941 Mdot
.70939 .39746 Mdot
.78328 .42782 Mdot
.73298 .6619 Mdot
.28114 .53128 Mdot
.72432 .41227 Mdot
.53474 .70978 Mdot
.74895 .64785 Mdot
.54485 .42789 Mdot
.71077 .65928 Mdot
.28102 .49299 Mdot
.62123 .23963 Mdot
.63947 .34324 Mdot
.47351 .70009 Mdot
.7277 .62468 Mdot
.37998 .24752 Mdot
.2311 .63294 Mdot
.15037 .43268 Mdot
.29841 .61323 Mdot
.73056 .30007 Mdot
.6196 .5787 Mdot
.85059 .35249 Mdot
.22243 .49501 Mdot
.23928 .47806 Mdot
.19842 .52464 Mdot
.41143 .46473 Mdot
.62625 .53745 Mdot
.54245 .63193 Mdot
.44687 .79761 Mdot
.68235 .62021 Mdot
.77006 .45393 Mdot
.74842 .36679 Mdot
.43144 .65159 Mdot
.5089 .7064 Mdot
.46412 .71945 Mdot
.49213 .56777 Mdot
.66274 .41282 Mdot
.79596 .33438 Mdot
.47874 .41374 Mdot
.64819 .68265 Mdot
.50459 .63902 Mdot
.6749 .48575 Mdot
.32268 .81362 Mdot
.54866 .39578 Mdot
.58967 .74362 Mdot
.70568 .6111 Mdot
.68386 .35285 Mdot
.46666 .20769 Mdot
.88699 .61819 Mdot
.87552 .37062 Mdot
.59753 .38013 Mdot
.26369 .3031 Mdot
.70143 .61752 Mdot
.61139 .75555 Mdot
.26766 .61637 Mdot
.31249 .32496 Mdot
.65245 .68899 Mdot
.6675 .32728 Mdot
.50357 .56922 Mdot
.21817 .48361 Mdot
.77343 .68394 Mdot
.74041 .36265 Mdot
.62697 .77011 Mdot
.5898 .51747 Mdot
.50035 .59135 Mdot
.68552 .82041 Mdot
.51634 .79672 Mdot
.53169 .64447 Mdot
.70155 .4267 Mdot
.59589 .69459 Mdot
.58347 .63305 Mdot
.35668 .74759 Mdot
.15608 .55796 Mdot
.56872 .72882 Mdot
.62858 .75714 Mdot
.62507 .44533 Mdot
.39737 .49217 Mdot
.4467 .36466 Mdot
.50734 .41233 Mdot
.54106 .66173 Mdot
.45288 .32257 Mdot
.46287 .59285 Mdot
.33099 .78948 Mdot
.40908 .53324 Mdot
.16749 .50838 Mdot
.66407 .80202 Mdot
.75877 .59973 Mdot
.46146 .23568 Mdot
.6009 .67359 Mdot
.65773 .71291 Mdot
.71744 .69039 Mdot
.5233 .50902 Mdot
.25878 .70412 Mdot
.57825 .11371 Mdot
.42431 .25777 Mdot
.81659 .56968 Mdot
.63679 .35701 Mdot
.42992 .47583 Mdot
.69418 .6561 Mdot
.40069 .37266 Mdot
.33359 .44394 Mdot
.56946 .51622 Mdot
.67843 .40966 Mdot
.50045 .31617 Mdot
.31457 .1936 Mdot
.58198 .55457 Mdot
.50097 .21274 Mdot
.66164 .77657 Mdot
.80005 .47297 Mdot
.72783 .53986 Mdot
.57716 .66184 Mdot
.55461 .30202 Mdot
.54425 .43123 Mdot
.39714 .79756 Mdot
.83726 .53754 Mdot
.58156 .77691 Mdot
.76674 .5943 Mdot
.70135 .63233 Mdot
.61363 .63988 Mdot
.38751 .6103 Mdot
.47339 .3967 Mdot
.415 .78646 Mdot
.58963 .69098 Mdot
.7159 .74496 Mdot
.28741 .42199 Mdot
.449 .54323 Mdot
.55931 .42415 Mdot
.84491 .37702 Mdot
.70689 .4627 Mdot
.68719 .39456 Mdot
.73671 .29421 Mdot
.27862 .44905 Mdot
.40094 .65908 Mdot
.36729 .49526 Mdot
.59549 .68303 Mdot
.65776 .44379 Mdot
.71166 .24681 Mdot
.40635 .77389 Mdot
.36876 .28896 Mdot
.3321 .33488 Mdot
.27176 .31624 Mdot
.4349 .31585 Mdot
.7337 .77588 Mdot
.24081 .51455 Mdot
.73333 .27307 Mdot
.17652 .45416 Mdot
.67422 .43174 Mdot
.24019 .65826 Mdot
.51526 .63752 Mdot
.33072 .45152 Mdot
.60392 .76849 Mdot
.65993 .63585 Mdot
.82085 .45314 Mdot
.62576 .63734 Mdot
.80932 .39911 Mdot
.32449 .60671 Mdot
.29365 .51579 Mdot
.21684 .53788 Mdot
.68322 .4829 Mdot
.51084 .85005 Mdot
.43542 .23053 Mdot
.53499 .83837 Mdot
.48673 .84467 Mdot
.64134 .77592 Mdot
.8041 .43083 Mdot
.47048 .15865 Mdot
.21868 .55322 Mdot
.32567 .75077 Mdot
.36347 .36406 Mdot
.65349 .48677 Mdot
.22945 .52168 Mdot
.60223 .48425 Mdot
.56428 .23676 Mdot
.48562 .28194 Mdot
.32664 .14515 Mdot
.51011 .72283 Mdot
.67296 .37658 Mdot
.2328 .53462 Mdot
.67695 .76127 Mdot
.67654 .49422 Mdot
.21225 .5989 Mdot
.46023 .47834 Mdot
.62651 .56115 Mdot
.7344 .65716 Mdot
.24297 .34598 Mdot
.2516 .47311 Mdot
.13532 .41633 Mdot
.19779 .59517 Mdot
.34842 .29752 Mdot
.4765 .45839 Mdot
.59584 .3853 Mdot
.42074 .19897 Mdot
.2509 .56164 Mdot
.24429 .68926 Mdot
.31092 .76583 Mdot
.5092 .79747 Mdot
.17711 .34495 Mdot
.2271 .38714 Mdot
.74283 .70705 Mdot
.25337 .67476 Mdot
.59944 .37563 Mdot
.45687 .73759 Mdot
.30633 .46383 Mdot
.36035 .3218 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo09[ooooo0_l0000Pooooo`;o0000Roooool001cooooo00?o0000oooo
ooooool0V_ooool2o`00023ooooo0_l0002;ooooo`007?ooool2o`000?ooooooBoooool001cooooo
00?o0000ooooooooool0TOooool2o`000;Kooooo000Looooo`03o`000?oooooooooo097ooooo0_l0
002fooooo`007?ooool00ol0003oooooooooo`26ooooo`;o0000`Oooool001cooooo00?o0000oooo
ooooool0Q_ooool2o`00033ooooo0_l0002?ooooo`007?ooool00ol0003oooooooooo`2:ooooo`;o
0000;?ooool2o`0008oooooo000Looooo`03o`000?oooooooooo08[ooooo0_l0002mooooo`007?oo
ool00ol0003oooooooooo`1iooooo`;o0000c_ooool001cooooo00?o0000ooooooooool0NOooool2
o`000<kooooo000Looooo`03o`000?oooooooooo07oooooo0_l00038ooooo`007?ooool00ol0003o
ooooooooo`1oooooo`;o00001oooool2o`0000kooooo0_l0002_ooooo`007?ooool00ol0003ooooo
ooooo`28ooooo`;o00003_ooool2o`000:oooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`1joooo
o`;o00009oooool2o`0000Kooooo0_l0002Looooo`007?ooool00ol0003oooooooooo`1Vooooo`;o
00004_ooool2o`0000Sooooo0_l0000Mooooo`;o00001_ooool2o`0000Cooooo0_l0002Fooooo`00
7?ooool00ol0003oooooooooo`1Vooooo`;o00007?ooool2o`000003ooooool0003o000000_ooooo
0_l0000=ooooo`;o00003?ooool2o`0009Kooooo000Looooo`;o0000Qoooool3o`0000Gooooo0_l0
0002ooooo`Co00001?ooool2o`0000Oooooo0_l0002Tooooo`007?ooool00ol0003oooooooooo`26
ooooo`;o00001_ooool2o`0000;ooooo0_l00006ooooo`;o00001oooool2o`000:Cooooo000Loooo
o`03o`000?oooooooooo07Cooooo0_l0000Oooooo`;o00003?ooool2o`0000Wooooo0_l0002Ioooo
o`007?ooool00ol0003oooooooooo`1dooooo`;o00007oooool2o`0000[ooooo0_l0000;ooooo`;o
00002?ooool2o`0008oooooo000Looooo`03o`000?oooooooooo07Wooooo0_l0000Rooooo`;o0000
0_ooool2o`0001Gooooo0_l0002?ooooo`007?ooool00ol0003oooooooooo`1iooooo`;o00008_oo
ool2o`0001oooooo0_l00029ooooo`007?ooool00ol0003oooooooooo`2Fooooo`;o00009_ooool2
o`0008Wooooo000Looooo`03o`000?oooooooooo09Kooooo0_l0000Rooooo`;o00002?ooool2o`00
00Gooooo0_l0001looooo`007?ooool00ol0003oooooooooo`2Fooooo`;o00008_ooool2o`0000So
oooo0_l00005ooooo`;o0000O?ooool001cooooo00?o0000ooooooooool0Qoooool2o`0000;ooooo
0_l0000^ooooo`;o00004?ooool2o`0007[ooooo000Looooo`03o`000?oooooooooo08Oooooo1_l0
000?ooooo`;o00000oooool4o`0000kooooo0ol00002ooooo`;o000000?oooooo`000?l000004?oo
ool2o`0007[ooooo000Looooo`03o`000?oooooooooo08Wooooo0_l00002ooooo`;o000000?ooooo
o`000?l000000_l00007ooooo`?o00000oooool4o`0000kooooo0ol00002ooooo`;o0000Soooool0
01cooooo00?o0000ooooooooool0OOooool2o`0000_ooooo0_l000001?oooooo0000o`000?ooool4
o`0000Oooooo0_l0002/ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?oo
ool5o`0000Kooooo00?o0000ooooooooool0H_ooool2o`0001Wooooo0ol0000:ooooo`;o00006ooo
ool2o`0000?ooooo0_l00002ooooo`;o0000Uoooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo06;o
oooo0_l0000Jooooo`;o00002oooool4o`0000gooooo0_l00008ooooo`?o00000oooool2o`0000;o
oooo0_l0002Gooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0QOooool2o`0000Cooooo1?l000000ooooooo0000
o`00000:ooooo`;o00001?ooool2o`0000;ooooo0_l00004ooooo`;o00003?ooool4o`0008_ooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_oo
ool3o`0008Gooooo0_l00003ooooo`;o00001?ooool2o`0000;ooooo1?l00005ooooo`;o00000ooo
ool4o`0000Oooooo0ol0000:ooooo`Co000000?oooooo`000?l00000R?ooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooo
oooo07Kooooo0_l0000Booooo`;o00001Oooool2o`000003ooooool0003o000000;o00000_ooool2
o`000004ooooool0003o0000ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000Cooooo
0ol00007ooooo`;o00000_ooool2o`0000;ooooo0_l00028ooooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0M_oo
ool2o`0000Wooooo0_l0000>ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Cooooo0_l0
00000ooooooo0000o`000002ooooo`;o00003_ooool3o`0002Gooooo0_l0001Xooooo`0000Kooooo
ogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003o
ooooooooo`1Uooooo`;o00002oooool2o`0000?ooooo0_l00008ooooo`;o00001?ooool2o`0000So
oooo0_l000000ooooooo0000o`00000Rooooo`;o00009Oooool2o`0006Sooooo00001_ooooook^k^
oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooo
oooo06Gooooo0_l0000;ooooo`;o00000oooool2o`0000?ooooo0_l00009ooooo`Co00001_ooool2
o`0000cooooo1?l00006ooooo`;o00001oooool2o`0000Cooooo0_l00002ooooo`;o00002Oooool2
o`00083ooooo000Looooo`03o`000?oooooooooo05cooooo0_l0000Cooooo`;o00002Oooool2o`00
00;ooooo0_l00006ooooo`?o00000oooool2o`0000oooooo1Ol00005ooooo`;o00001oooool3o`00
00?ooooo0_l00002ooooo`;o00002Oooool2o`0001gooooo0_l0001Qooooo`007?ooool00ol0003o
ooooooooo`1Fooooo`;o00001?ooool2o`0001?ooooo0_l00004ooooo`;o00001oooool2o`0000co
oooo0_l0000Booooo`;o00002_ooool2o`0000;ooooo0ol00003ooooo`;o00000oooool2o`0002Oo
oooo0_l0001Qooooo`007?ooool00ol0003oooooooooo`1Fooooo`;o00005_ooool2o`0000Oooooo
0_l0000Oooooo`;o000000?oooooo`000?l000002?ooool3o`0000Kooooo0_l00002ooooo`;o0000
1?ooool2o`0000;ooooo0ol0002:ooooo`007?ooool00ol0003oooooooooo`1Qooooo`;o00001?oo
ool4o`0000?ooooo0_l0000Fooooo`;o00002oooool3o`0000;ooooo0_l000000ooooooo0000o`00
0008ooooo`?o00001oooool4o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00000_oo
ool2o`0000Cooooo0ol00004ooooo`;o0000N_ooool001cooooo00?o0000ooooooooool0HOooool2
o`0000Cooooo1?l000000ooooooo0000o`000002ooooo`;o00001?ooool2o`0000cooooo1?l00002
ooooo`;o00001oooool4o`0000;ooooo0_l0000Dooooo`Co00000_ooool2o`0000Wooooo0_l00004
ooooo`?o00001?ooool2o`0007[ooooo000Looooo`03o`000?oooooooooo06cooooo0_l00002oooo
o`;o00001?ooool2o`0000cooooo0_l00004ooooo`;o000000?oooooo`000?l000001Oooool3o`00
00;ooooo0_l0000;ooooo`;o00001Oooool2o`0001Cooooo0_l00024ooooo`007?ooool00ol0003o
ooooooooo`1looooo`;o00002?ooool2o`0000Gooooo1?l000000ooooooo0000o`000006o`0000So
oooo0_l00002ooooo`;o00001Oooool2o`0000Gooooo0_l000000ooooooo0000o`00000:ooooo`;o
0000Q?ooool001cooooo00?o0000ooooooooool0H?ooool2o`0001[ooooo0_l00008ooooo`;o0000
1oooool2o`000003ooooool0003o000000;ooooo1?l00008ooooo`?o00001Oooool2o`0000Sooooo
0_l000001?oooooo0000o`000?l0000<ooooo`;o00001_ooool2o`0000;ooooo0_l0000:ooooo`;o
0000JOooool001cooooo00?o0000ooooooooool0H?ooool2o`0001;ooooo0_l00008ooooo`;o0000
4?ooool2o`0000Kooooo0_l00004ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo
0_l0000<ooooo`;o00000_ooool2o`0000Sooooo0_l00006ooooo`;o00000_ooool2o`0000[ooooo
0_l0001Yooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00002?ooool2o`0000oooooo0_l0
0003ooooo`;o000000Coooooo`000?l0003o00002?ooool2o`00013ooooo0_l0000<ooooo`;o0000
1Oooool3o`000003ooooool0003o0000017ooooo0_l0000=ooooo`;o00001oooool2o`0000Wooooo
0_l000000ooooooo0000o`00000Gooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0Booo
ool2o`0000?ooooo0_l00008ooooo`?o00003?ooool4o`0000?ooooo0_l000000ooooooo0000o`00
0003ooooo`;o00003Oooool2o`0001cooooo0_l00002ooooo`;o00008?ooool2o`0000;ooooo0_l0
0003ooooo`;o00002Oooool2o`000004ooooool0003o0000o`0001Kooooo0_l0001<ooooo`007?oo
ool2o`0004cooooo0_l00006ooooo`;o00001_ooool2o`000003ooooool0003o000000Gooooo0_l0
0002ooooo`;o00001?ooool2o`0000Oooooo0_l0000=ooooo`;o000000?oooooo`000?l000002_oo
ool4o`0000cooooo0_l0000Eooooo`Co00002Oooool2o`0000;ooooo0ol00008ooooo`;o00002?oo
ool2o`0000;ooooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00002Oooool2
o`0000Cooooo0ol00008ooooo`;o00002?ooool2o`0000oooooo0_l00006ooooo`So00001?ooool2
o`0000Kooooo0_l00007ooooo`;o00003?ooool4o`0000;ooooo0ol00004ooooo`;o00000_ooool2
o`0000Wooooo0_l0000<ooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0G_ooool2o`00
00Cooooo0_l00002ooooo`;o00000oooool3o`0000Wooooo0_l00006ooooo`;o00000oooool2o`00
00[ooooo1?l00003ooooo`;o00000oooool2o`0000Oooooo0_l00006ooooo`;o00004_ooool3o`00
00Kooooo0ol0000Booooo`;o0000I_ooool001cooooo00?o0000ooooooooool0J?ooool2o`0000;o
oooo1?l0000Aooooo`Oo00004Oooool2o`000003ooooool0003o000000Wooooo0_l0000Iooooo`;o
00002?ooool5o`0000[ooooo0_l00004ooooo`;o0000I_ooool001cooooo00?o0000ooooooooool0
EOooool2o`0001Gooooo1?l0000=ooooo`;o000000?oooooo`000?l000001ol00003ooooo`;o0000
0_ooool2o`0000[ooooo0_l00005ooooo`;o000000?oooooo`000?l000006_ooool2o`0000Cooooo
0ol00004ooooo`;o00002_ooool2o`0006cooooo000Looooo`03o`000?oooooooooo05Gooooo0_l0
000Dooooo`Ko00003?ooool2o`000004ooooool0003o0000o`0000?ooooo1Ol000000ooooooo0000
o`000002ooooo`?o00004?ooool5o`00023ooooo0ol0000;ooooo`;o00000oooool2o`0006cooooo
000Looooo`03o`000?oooooooooo053ooooo0_l0000=ooooo`;o00002_ooool2o`0000;ooooo0_l0
000Hooooo`Co00001?ooool2o`000003ooooool0003o000000Co00000oooool2o`0000Gooooo0_l0
0009ooooo`;o00005_ooool2o`0000gooooo0_l0001aooooo`007?ooool00ol0003oooooooooo`1@
ooooo`;o00002oooool4o`0001Wooooo0_l000000ooooooo0000o`000003ooooo`;o00001oooool4
o`0000;ooooo2Ol00003ooooo`;o00001_ooool2o`0000Gooooo0_l000001?oooooo0000o`000?l0
000Booooo`Ko00008?ooool2o`0005gooooo000Looooo`03o`000?oooooooooo05gooooo0_l0000K
ooooo`;o000000?oooooo`000?l000000oooool2o`000003ooooool0003o000000Cooooo1?l00002
ooooo`Co00001?ooool2o`000003ooooool0003o000000Oooooo0_l00005ooooo`;o000000Cooooo
o`000?l0003o00004_ooool3o`000003ooooool0003o000000?o00001?ooool2o`000003ooooool0
003o000000Kooooo0_l0000<ooooo`;o0000GOooool001cooooo00?o0000ooooooooool0E_ooool2
o`0000oooooo0_l0000?ooooo`;o00000oooool2o`0000Kooooo0_l00003ooooo`;o000000?ooooo
o`000?l000001oooool2o`000004ooooool0003o0000ooooo`?o00001_ooool2o`0001kooooo2?l0
00001?oooooo0000o`000?ooool2o`000003ooooool0003o000000Kooooo0_l0000Iooooo`;o0000
D?ooool001cooooo00?o0000ooooooooool0COooool2o`0000;ooooo0_l00002ooooo`?o000000?o
ooooo`000?l000003?ooool2o`0000Wooooo0_l00002ooooo`Co00000oooool2o`0000Cooooo0_l0
0005ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l00002ooooo`;o000000?o
ooooo`000?l000001_ooool2o`0000Kooooo0_l0000<ooooo`?o00002Oooool4o`0000?ooooo0_l0
0007ooooo`;o00001?ooool2o`0001Sooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`1=
ooooo`?o000000?oooooo`000?l000001?l00002ooooo`;o00005oooool2o`0000;ooooo0_l00006
ooooo`;o00000oooool2o`0000?ooooo0ol00002ooooo`;o00000_ooool2o`0000?ooooo0_l00002
ooooo`;o000000?oooooo`000?l000002_ooool2o`0000;ooooo0_l00006ooooo`;o00001?ooool3
o`0000;ooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000000Wooooo0_l00004
ooooo`;o00005oooool2o`00057ooooo000Looooo`03o`000?oooooooooo04Kooooo0_l000000ooo
oooo0000o`000003ooooo`;o00000oooool2o`0001oooooo0_l00006ooooo`Co00002?ooool4o`00
0003ooooool0003o000000Oooooo0_l00008ooooo`;o00001oooool2o`0000[ooooo0_l00009oooo
o`;o00000_ooool4o`000004ooooool0003o0000ooooo`Co000000?oooooo`000?l000000_l00004
ooooo`;o00004Oooool2o`0000Sooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`16oooo
o`;o000000Coooooo`000?l0003ooooo0_l0000Vooooo`;o00001Oooool4o`000003ooooool0003o
000000Sooooo0_l00007ooooo`?o00000_ooool2o`0000Kooooo0ol00006ooooo`;o00002_ooool2
o`0000oooooo0ol00005ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o00003oooool5
o`0005[ooooo000Looooo`03o`000?oooooooooo04cooooo0_l00009ooooo`;o00002_ooool2o`00
00kooooo0_l00006ooooo`;o00000oooool2o`0000Kooooo0_l00005ooooo`;o00000_ooool3o`00
00;ooooo0_l00006ooooo`?o00005?ooool2o`0000kooooo0_l0000;ooooo`;o00002Oooool2o`00
00Wooooo1Ol0001Jooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00004?ooool4o`0000Ko
oooo1?l00008ooooo`;o00000_ooool4o`0000_ooooo0_l00003ooooo`Go00001?ooool4o`0000Oo
oooo0_l00005ooooo`Co00000_ooool2o`0000Gooooo0_l00002ooooo`;o000000Coooooo`000?l0
003ooooo1?l0000Eooooo`;o00000_ooool2o`0000Sooooo0ol0000:ooooo`;o00000oooool2o`00
05Oooooo000Looooo`;o0000A_ooool2o`0000Wooooo0_l00007ooooo`;o00001_ooool2o`0000Go
oooo0_l00003ooooo`?o000000?oooooo`000?l000003Oooool2o`0000?ooooo1Ol00004ooooo`Co
00000_ooool2o`0000?ooooo0_l00007ooooo`;o00000_ooool2o`0000Gooooo0_l00002ooooo`Go
00000oooool2o`0000oooooo0_l00002ooooo`Co000000?oooooo`000?l000002Oooool2o`0000[o
oooo1?l00002ooooo`;o00003Oooool2o`0004Sooooo000Looooo`03o`000?oooooooooo04Kooooo
0_l00008ooooo`Co00005?ooool4o`0000;ooooo0_l0000@ooooo`;o00004_ooool2o`0000Wooooo
0_l00005ooooo`?o00001_ooool6o`0000Oooooo0_l0000:ooooo`Co00000_ooool2o`0000?ooooo
0_l00005ooooo`;o00002Oooool2o`0000?ooooo1?l00005ooooo`;o00002_ooool2o`0004Sooooo
000Looooo`03o`000?oooooooooo03oooooo0_l00005ooooo`;o00002_ooool2o`0001Kooooo0_l0
000@ooooo`;o00000_ooool2o`0001;ooooo0_l000000ooooooo0000o`000006ooooo`;o00001_oo
ool2o`0000Kooooo1Ol00008ooooo`;o00001?ooool2o`0000Cooooo1?l00002ooooo`;o00002?oo
ool4o`0000Sooooo0ol00005ooooo`;o00001Oooool4o`0005;ooooo000Looooo`03o`000?oooooo
oooo03oooooo0_l0000Gooooo`;o00000oooool2o`0000oooooo0ol00004ooooo`Co00000oooool2
o`0000[ooooo0_l00009ooooo`Ko00000_ooool2o`0000;ooooo0_l00006ooooo`;o00001Oooool2
o`0001;ooooo0_l00006ooooo`;o00000_ooool2o`0000Sooooo0_l0000:ooooo`?o00001Oooool2
o`0000?ooooo0_l00002ooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0B_ooool2o`00
00Gooooo0_l00005ooooo`;o00000oooool2o`0000oooooo0ol000001?oooooo0000o`000?ooool4
o`0000oooooo0_l00007ooooo`ko00002?ooool2o`0000Gooooo0_l0000Sooooo`Co00003Oooool3
o`0000Gooooo0_l00003ooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0@_ooool2o`00
00Kooooo0_l00005ooooo`;o00000_ooool2o`0000Kooooo0_l0000Cooooo`Co00005?ooool2o`00
00Cooooo4Ol000000ooooooo0000o`00000Nooooo`;o00002Oooool2o`0000Cooooo1Ol0001aoooo
o`007?ooool00ol0003oooooooooo`12ooooo`;o00002Oooool2o`0000;ooooo0_l00002ooooo`;o
00003oooool2o`0000Kooooo0_l000000ooooooo0000o`000003o`0000Wooooo0_l00009oooooaOo
000000Coooooo`000?l0003o00001_ooool2o`0001Gooooo0_l00009ooooo`;o00001Oooool6o`00
00_ooooo0_l0000Gooooo`;o0000BOooool001cooooo00?o0000ooooooooool0=oooool2o`0000ko
oooo0_l00004ooooo`;o00002Oooool3o`0000?ooooo0_l00006ooooo`;o00001?ooool;o`0000So
oooo0_l00007ooooo`;o000000?oooooo`000?l000002ol000000ooooooo0000o`000006o`0000;o
oooo0ol00005ooooo`;o00000_ooool2o`0000Gooooo0_l0000Iooooo`Go00000_ooool2o`0000_o
oooo0_l00008ooooo`;o00003Oooool2o`000003ooooool0003o000004Kooooo000Looooo`03o`00
0?oooooooooo03Oooooo0_l0000>ooooo`;o00002_ooool2o`0000?ooooo0ol00003ooooo`;o0000
0_ooool4o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`?o00000_ooool2o`0000Kooooo
0ol000000ooooooo0000o`000004oooooaSo000000Goooooo`000?l0003o0000ooooo`02o`0000Wo
oooo0_l00005ooooo`;o00000_ooool2o`0000Kooooo0_l00005ooooo`Co00001?ooool3o`0000Co
oooo0_l0000:ooooo`Co00001oooool2o`0000?ooooo0_l0000;ooooo`;o0000A_ooool001cooooo
00?o0000ooooooooool0Aoooool2o`0000Kooooo0_l00002ooooo`;o000000Coooooo`000?l0003o
oooo0_l00007ooooo`Ko000000Coooooo`000?l0003ooooo0_l0000?ooooo`?o000000Coooooo`00
0?l0003ooooo0_l000000ooooooo0000o`00000Lo`0000;ooooo1?l00004ooooo`Co00001oooool2
o`0000Kooooo0_l00005ooooo`Co00002?ooool2o`000003ooooool0003o000000Gooooo0_l00003
ooooo`Co00003?ooool2o`0000;ooooo0_l00003ooooo`;o0000B_ooool001cooooo00?o0000oooo
ooooool0Aoooool2o`0000Kooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l0000<oooo
o`;o00001?ooool2o`0000?ooooo0ol0000@ooooo`;o00001?oooolKo`0000;ooooo1?l00002oooo
o`?o000000?oooooo`000?l000005oooool2o`0000Wooooo0_l00008ooooo`;o00000_ooool2o`00
00cooooo0_l00005ooooo`Co000000?oooooo`000?l00000B_ooool001cooooo00?o0000oooooooo
ool0EOooool2o`000003ooooool0003o000000kooooo0_l00007ooooo`Co000000?oooooo`000?l0
00002?ooool2o`0000Oooooo3ol000000ooooooo0000o`00000:o`000003ooooool0003o000000;o
00000oooool3o`0001oooooo0_l000000ooooooo0000o`000004ooooo`;o00002Oooool4o`0000[o
oooo0_l00007ooooo`;o00000oooool2o`0004Sooooo000Looooo`03o`000?oooooooooo04Oooooo
0_l00004ooooo`;o00001_ooool2o`00017ooooo0_l00009ooooo`;o000000?oooooo`000?l00000
0_l00003ooooo`;o000000?oooooo`000?l000001oooool;o`000003ooooool0003o000000ko0000
00?oooooo`000?l000000_ooool2o`00017ooooo0_l00006ooooo`;o00000oooool2o`000003oooo
ool0003o000000Go00001?ooool4o`0000Wooooo0_l00004ooooo`;o00001?ooool2o`0000cooooo
0_l00018ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o000000?oooooo`000?l000000_oo
ool7o`00017ooooo0_l00002ooooo`;o00001?ooool2o`0000Wooooo0_l00003ooooo`;o00000_oo
ool2o`0000Kooooo1_l00002oooooaOo000000?oooooo`000?l000000ol0000<ooooo`Go000000Co
ooooo`000?l0003o00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`?o0000
1_ooool2o`0000;ooooo0_l0000;ooooo`;o0000G?ooool001cooooo00?o0000ooooooooool0=ooo
ool2o`0000Wooooo1?l00005ooooo`;o000000?oooooo`000?l000000_l0000=ooooo`;o00000_oo
ool2o`0000;ooooo0_l00004ooooo`;o00003_ooool2o`000004ooooool0003o0000o`0000Kooooo
6?l000000ooooooo0000o`000002o`000003ooooool0003o000000;o000000Coooooo`000?l0003o
oooo0_l00007ooooo`Go000000?oooooo`000?l000000ol000000ooooooo0000o`000002o`0000Co
oooo0_l00003ooooo`?o00002_ooool2o`0000?ooooo0_l0001Tooooo`007?ooool00ol0003ooooo
ooooo`0^ooooo`;o00001_ooool3o`0000Wooooo0_l00003ooooo`;o00000_ooool2o`000003oooo
ool0003o000000oooooo0_l0000Booooo`;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000
o`000003ooooo`?o000000?oooooo`000?l000001ol000000ooooooo0000o`00000<o`000003oooo
ool0003o000000;o000000?oooooo`000?l000001_ooool2o`0000Oooooo0ol00003ooooo`Co0000
0_ooool4o`0000;ooooo1?l00003ooooo`?o00002_ooool2o`0000?ooooo0_l00006ooooo`;o0000
6oooool3o`0003kooooo000Looooo`;o0000;oooool2o`0000Cooooo1?l0000=ooooo`Co00000_oo
ool2o`0000Oooooo0_l000000ooooooo0000o`000002ooooo`;o00001?ooool2o`0000?ooooo0_l0
0007ooooo`;o00000_ooool2o`0000Cooooo0_l00002ooooo`;o00001_oooolDo`000003ooooool0
003o000000[o000000?oooooo`000?l000004?ooool2o`0000Cooooo0ol00007ooooo`Go00001?oo
ool2o`0000Wooooo0_l00007ooooo`;o00000oooool2o`0000?ooooo0_l00002ooooo`;o00004_oo
ool3o`0003kooooo000Looooo`03o`000?oooooooooo03Cooooo0_l0000?ooooo`;o00001?ooool2
o`0000Oooooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool3o`0000?ooooo0_l00007
ooooo`Co00002_ooool4o`0000Cooooo9?l000000ooooooo0000o`000002ooooo`;o00003_ooool2
o`0000Gooooo0ol000001?oooooo0000o`000?ooool2o`0000cooooo0_l000000ooooooo0000o`00
0007ooooo`;o00002?ooool2o`0000;ooooo0_l0000Booooo`;o00001_ooool2o`0003Oooooo000L
ooooo`03o`000?oooooooooo04_ooooo0_l0000Cooooo`;o000000?oooooo`000?l000002_ooool4
o`0000[ooooo1?l00006ooooob;o000000?oooooo`000?l000000_ooool2o`0000kooooo0_l00002
ooooo`Oo00000_ooool2o`0000gooooo0_l00008ooooo`;o00002?ooool4o`000003ooooool0003o
000001?ooooo0_l00006ooooo`;o0000=oooool001cooooo00?o0000ooooooooool0Boooool2o`00
00oooooo0_l00005ooooo`;o00002_ooool2o`0001Kooooo5Ol000000ooooooo0000o`000004o`00
00;ooooo1?l0000?ooooo`;o00001Oooool>o`0001?ooooo0_l00002ooooo`;o00002?ooool4o`00
0003ooooool0003o000000;ooooo0ol0001?ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o
00001Oooool2o`0000_ooooo0_l00002ooooo`;o00009_ooool;o`000003ooooool0003o000001Co
000000Coooooo`000?l0003o00000_ooool3o`0000Wooooo0_l00005ooooo`Co000000?oooooo`00
0?l000001_l000001?oooooo0000o`000?l0000@ooooo`;o00002oooool2o`0000Sooooo0ol0001?
ooooo`007?ooool00ol0003oooooooooo`12ooooo`Co00001?ooool3o`0000_ooooo0ol00002oooo
o`;o00004?ooool2o`000003ooooool0003o000000Sooooo0_l00006ooooobOo000000Coooooo`00
0?l0003o00001_ooool2o`0000[ooooo0ol000000ooooooo0000o`000009o`0000Wooooo0_l00003
ooooo`;o00003Oooool2o`0000Sooooo0_l00006ooooo`;o0000B?ooool001cooooo00?o0000oooo
ooooool0@_ooool2o`0000Kooooo0_l0000;ooooo`Co00000_ooool2o`000003ooooool0003o0000
00;o00001oooool6o`000003ooooool0003o000000?o00001Oooool2o`0000cooooo5_l00004oooo
o`Co000000?oooooo`000?l000002_ooool2o`0000Kooooo0_l000000ooooooo0000o`00000Fo`00
0003ooooool0003o000000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`00
00?ooooo0_l00003ooooo`;o00001Oooool2o`0000;ooooo0_l00007ooooo`;o00000oooool2o`00
03[ooooo000Looooo`03o`000?oooooooooo04[ooooo0_l00007ooooo`;o00000_ooool6o`0000?o
oooo1?l00007ooooo`Co00000oooool5o`0000_ooooo2?l000000ooooooo0000o`00000@o`000003
ooooool0003o000000Cooooo0_l00002ooooo`;o00000_ooool2o`0000Kooooo0_l00007oooooa_o
00002oooool2o`000003ooooool0003o000000;ooooo0ol00002ooooo`;o00000oooool2o`0000?o
oooo1?l0000;ooooo`;o00000oooool2o`0000[ooooo0_l0000^ooooo`007?ooool00ol0003ooooo
ooooo`1Cooooo`;o00001?ooool4o`0001;ooooo1?l000000ooooooo0000o`000008ooooo`;o0000
0_ooool8o`000003ooooool0003o000000_o000000?oooooo`000?l000000oooool2o`0000Sooooo
0_l00002ooooo`;o000000?oooooo`000?l000000oooool2o`0000Sooooo2_l000000ooooooo0000
o`000002ooooo`So000000?oooooo`000?l000003_ooool2o`0000?ooooo0_l00009ooooo`;o0000
00?oooooo`000?l000007_ooool2o`0002kooooo000Looooo`03o`000?oooooooooo04;ooooo0_l0
000=ooooo`;o00006oooool5o`0000Wooooo1?l00002ooooo`?o00001?ooool3o`000003ooooool0
003o000000co00005?ooool2o`0000[ooooo0_l00002oooooa[o000000?oooooo`000?l000001Ooo
ool2o`0000?ooooo0_l0000>ooooo`;o000000?oooooo`000?l000005?ooool3o`0003Oooooo000L
ooooo`03o`000?oooooooooo03Gooooo0_l0000:ooooo`?o00003Oooool2o`0001_ooooo0_l00004
ooooo`;o00001Oooool3o`0000Gooooo0_l00004ooooo`Co00000_ooool2o`0000;ooooo1_l00009
ooooo`;o00004?ooool2o`0000Gooooo0_l000000ooooooo0000o`00000Io`000003ooooool0003o
000000?ooooo1?l0000?ooooo`;o00001Oooool2o`0000cooooo0_l00006ooooo`?o0000=oooool0
01cooooo00?o0000ooooooooool0=Oooool2o`0000[ooooo0_l0000Gooooo`?o00001Oooool2o`00
013ooooo0_l00005ooooo`;o00002?ooool2o`0000;ooooo1?l00002ooooo`;o00000_ooool2o`00
00gooooo0_l00009ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Gooooo0_l000000ooo
oooo0000o`00000Fo`0000Wooooo0_l00008ooooo`;o00001oooool2o`0000Wooooo0_l00008oooo
o`;o0000@?ooool001cooooo00?o0000ooooooooool0AOooool3o`0001;ooooo0ol00004ooooo`?o
00000oooool2o`0000Cooooo1?l0000Dooooo`;o000000?oooooo`000?l000001ol00008ooooo`;o
000000?oooooo`000?l000000_ooool2o`0000Gooooo0_l00004ooooo`;o000000?oooooo`000?l0
00001oooool2o`000003ooooool0003o000001So00004oooool2o`0000Oooooo0_l00009ooooo`;o
0000B_ooool001cooooo00?o0000ooooooooool0<oooool2o`0000_ooooo0_l00003ooooo`?o0000
0_ooool2o`0000Gooooo0_l0000>ooooo`;o00001?ooool3o`0000?ooooo1?l00006ooooo`;o0000
3oooool3o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`;o000000Coooooo`000?l0003o
oooo0_l00002ooooo`;o00001Oooool6o`0000Oooooo0_l00002oooooa;o000000?oooooo`000?l0
00002Ol00002ooooo`;o00003?ooool2o`00067ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^
kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0coooo
o`;o00002oooool2o`0000Kooooo1?l00003ooooo`Co00001oooool2o`0000cooooo0_l00008oooo
o`?o00000_ooool2o`0000Sooooo0_l00007ooooo`;o00001?ooool2o`0000Cooooo0_l00006oooo
o`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo1?l00007ooooo`;o00000_oooolNo`00
00;ooooo0_l0000<ooooo`;o00005oooool2o`0004Sooooo00001_ooooooMgMgoiRHV?ooooooV9RH
ogMgM`Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0?_ooool2
o`0000?ooooo0_l00003ooooo`Co00000oooool2o`0000Sooooo0ol0000Fooooo`?o00001?ooool2
o`0000Kooooo0_l00007ooooo`;o00002_ooool2o`000003ooooool0003o000000?ooooo0_l00000
0ooooooo0000o`000002ooooo`;o00000oooool2o`0000;ooooo0_l00005ooooo`;o00000_oooolM
o`0000Gooooo0_l00009ooooo`;o00005oooool2o`0000Oooooo0_l0000oooooo`0000?ooooooa0@
4?ooool00_ooool00ol@413oooooooooo`09ooooo`Go00001_ooool00ol0003oooooooooo`0noooo
o`;o000000?oooooo`000?l000001?l0000Aooooo`?o00001?ooool2o`0001Sooooo0_l00003oooo
o`;o00005_ooool2o`000003ooooool0003o000000Oooooo0_l00002ooooo`;o00000_ooool3o`00
0003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000003oooooaoo00000_ooool2o`00
00Kooooo0_l0000:ooooo`;o00004_ooool3o`0000;ooooo0_l0000oooooo`0000?oooooo`000?oo
ool00_ooool00ol0003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol00010oooo
o`?o00000_ooool3o`000003ooooool0003o000000;o00001Oooool2o`0000Cooooo0ol00004oooo
o`;o00007Oooool2o`0000Oooooo0_l00002ooooo`;o00000oooool2o`0000cooooo0_l00002oooo
o`;o00000_ooool2o`0000?ooooo0ol00004ooooo`;o00001Oooool3o`0000?ooooo6ol00005oooo
o`;o00000_ooool2o`0000[ooooo0_l00009ooooo`Co00001Oooool3o`0000cooooo0_l0000eoooo
o`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`00
00Oooooo00?o0000ooooooooool09oooool2o`00013ooooo0_l00005ooooo`?o00000oooool2o`00
0003ooooool0003o000000;o00001Oooool2o`0000Gooooo0_l00004ooooo`;o00001?ooool2o`00
023ooooo0_l00002ooooo`;o00000oooool2o`0000cooooo1_l00008ooooo`?o00000oooool2o`00
00Gooooo0ol00003ooooo`[o000000?oooooo`000?l000003_l00005ooooo`Co00005oooool6o`00
00Oooooo0_l00009ooooo`;o00000oooool2o`00033ooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00[ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0Wooooo`;o
00004?ooool2o`0000_ooooo1?l0000>ooooo`?o00001?ooool2o`0000Cooooo0_l0000Fooooo`;o
00005oooool2o`0000Gooooo0_l000000ooooooo0000o`00000;ooooo`;o00000oooool2o`0000Co
oooo0ol00003oooooako00001Oooool2o`0000cooooo0_l00005ooooo`Ko00000_ooool2o`0000Oo
oooo0_l00007ooooo`;o00001Oooool2o`00033ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMg
M`cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0dooooo`Co000000Coooooo`00
0?l0003ooooo0_l0000:ooooo`;o00003_ooool2o`0002?ooooo0_l00005ooooo`;o00004?ooool2
o`0000Gooooo0_l00002ooooo`;o00002Oooool2o`0000[ooooo6?l00002ooooo`[o00002oooool2
o`0000Kooooo0_l00005ooooo`Go00005Oooool2o`0003Oooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`0dooooo`Co000000Co
ooooo`000?l0003ooooo1?l00008ooooo`;o00003_ooool2o`0001?ooooo0_l0000Eooooo`;o0000
3?ooool2o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l000001?ooool2o`0000?ooooo
0_l00002ooooo`;o00002?oooolRo`0000?ooooo0_l00006ooooo`;o00001_ooool2o`0000?ooooo
0ol0000Booooo`;o00003?ooool2o`00033ooooo000Looooo`03o`000?oooooooooo02Sooooo0_l0
000:ooooo`;o00000_ooool9o`0001Oooooo1?l000001?oooooo0000o`000?ooool2o`0000_ooooo
0_l00002ooooo`;o000000?oooooo`000?l000000_l0000Jooooo`;o00001?ooool2o`0000Cooooo
0ol00006ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000_oooolUo`0000;ooooo
1?l0000;ooooo`?o00000oooool3o`0000?ooooo0_l00005ooooo`;o00001_ooool2o`0000cooooo
0_l0000`ooooo`007?ooool00ol0003oooooooooo`0Xooooo`;o00002_ooool2o`0000;ooooo0_l0
00001Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`000?l000001Oooool2o`0000oooooo
0_l000001?oooooo0000o`000?ooool2o`0000Kooooo1ol00002ooooo`So00009_ooool2o`0000So
oooo1?l00002ooooo`;o00000oooool2o`0000;ooooo0ol000001?oooooo0000o`000?oooolKo`00
0005ooooool0003o0000o`000?ooool01?l000000ooooooo0000o`000008ooooo`;o00002_ooool2
o`0000Gooooo1_l00012ooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00001oooool2o`00
00Gooooo0_l000000ooooooo0000o`00000<ooooo`;o00003?oooolAo`0000Kooooo0_l00003oooo
o`;o00007_ooool2o`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l000002oooool>o`00
0003ooooool0003o000000Wo00000oooool2o`000003ooooool0003o000000;ooooo0ol0000Coooo
o`;o00001_ooool6o`0000;ooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0iooooo`;o
00001oooool2o`0000?ooooo0ol00002ooooo`;o00002Oooool2o`000003ooooool0003o000000oo
oooo3ol00003ooooo`Co00000oooool2o`00017ooooo0_l0000;ooooo`;o00001oooool2o`0000;o
oooo0ol000000ooooooo0000o`000007oooooaSo00001_ooool2o`0000;ooooo0_l000000ooooooo
0000o`00000@ooooo`;o00000_ooool4o`0000Cooooo1?l00004ooooo`;o00003_ooool2o`000003
ooooool0003o000002_ooooo000Looooo`03o`000?oooooooooo03oooooo0_l000000ooooooo0000
o`000003ooooo`?o000000?oooooo`000?l000001?ooool3o`0000?ooooo0_l0000Aoooooa3o0000
00?oooooo`000?l000000_l0000@ooooo`;o00001_ooool2o`0000;ooooo0_l0000<ooooo`Ko0000
0_ooool2o`0000;ooooo0_l00007oooooaWo00001_ooool2o`000003ooooool0003o000001?ooooo
0_l00004ooooo`;o00000_ooool6o`0001Cooooo0_l000000ooooooo0000o`00000[ooooo`007?oo
ool00ol0003oooooooooo`0]ooooo`;o00004?ooool2o`0000Gooooo1?l000000ooooooo0000o`00
0004ooooo`?o00000_ooool2o`00013ooooo5Ol0000Aooooo`?o00002_ooool2o`0000Gooooo1?l0
0003ooooo`Ko00003_ooool2o`0000;ooooo4ol000000ooooooo0000o`000002o`000003ooooool0
003o000000?o00002oooool2o`0000Gooooo0_l00008ooooo`;o00000_ooool5o`0001Gooooo0_l0
000^ooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o00005oooool4o`0000Kooooo0_l00003
ooooo`?o00003_oooolGo`0000[ooooo0_l00005ooooo`;o00001_ooool2o`0000[ooooo1?l00003
ooooo`;o00000_ooool2o`0000kooooo5_l000001?oooooo0000o`000?ooool7o`0000cooooo0_l0
0005ooooo`?o00001_ooool4o`0000gooooo0_l0000looooo`007?ooool00ol0003oooooooooo`1@
ooooo`;o00000oooool2o`0000oooooo4?l000000ooooooo0000o`000004o`0000Cooooo0_l00004
ooooo`;o000000?oooooo`000?l000000_ooool5o`0000?ooooo0_l0000Hooooo`;o00003?oooolE
o`000003ooooool0003o000000?ooooo1?l0000Eooooo`;o00001_ooool4o`0000gooooo0_l0000l
ooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00007oooool4o`000003ooooool0003o0000
01So00000oooool2o`0000Oooooo0_l000000ooooooo0000o`000004o`0000;ooooo0_l0000Ioooo
o`;o00003_ooool3o`0000;ooooo4?l00003ooooo`?o00004_ooool2o`0000?ooooo0_l0000>oooo
o`;o00001Oooool2o`0000;ooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`0nooooo`;o
00003oooool2o`0000gooooo1Ol000000ooooooo0000o`00000=o`000003ooooool0003o000000Go
000000?oooooo`000?l000002?ooool2o`0000Gooooo0_l00006ooooo`;o0000;_ooool5o`0000;o
oooo0_l000000ooooooo0000o`000004o`0000?ooooo0ol0000Booooo`;o000000?oooooo`000?l0
00000_l00002ooooo`;o00001oooool2o`000003ooooool0003o000000?ooooo1?l00002ooooo`;o
000000?oooooo`000?l00000=oooool001cooooo00?o0000ooooooooool0=Oooool2o`0000[ooooo
0_l0000;ooooo`?o00000oooool2o`000003ooooool0003o000000Gooooo0_l00003oooooa3o0000
00?oooooo`000?l000001_l000000ooooooo0000o`000007ooooo`;o00005?ooool2o`0000Cooooo
0_l000000ooooooo0000o`000008ooooo`;o00001?ooool2o`0000cooooo1_l00003ooooo`;o0000
00?oooooo`000?l000001?l000001?oooooo0000o`000?ooool2o`0000Oooooo0_l00002ooooo`;o
00002?ooool4o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o0000
00Kooooo0_l00002ooooo`;o00000oooool2o`0003Oooooo000Looooo`;o0000=_ooool2o`0000[o
oooo0_l0000;ooooo`;o00001?ooool2o`000003ooooool0003o000000Gooooo0_l000000ooooooo
0000o`00000Lo`0001gooooo0_l00004ooooo`;o000000?oooooo`000?l000001Oooool5o`0000Co
oooo0_l00007ooooo`;o00000oooool2o`0000;ooooo1?l00004ooooo`Ko000000?oooooo`000?l0
00001Oooool2o`0000?ooooo0_l00002ooooo`;o00004Oooool2o`000003ooooool0003o000000go
oooo0_l0000looooo`007?ooool00ol0003oooooooooo`0aooooo`;o00000oooool4o`0000Gooooo
0_l0000Poooooako00002oooool2o`0001Sooooo0_l00006ooooo`Co00003_ooool2o`0000;ooooo
0_l00004ooooo`?o00000_ooool4o`0000cooooo0ol0000Fooooo`;o00000_ooool2o`0000?ooooo
0_l00003ooooo`;o000000?oooooo`000?l000003?ooool4o`00033ooooo000Looooo`03o`000?oo
oooooooo033ooooo0ol00003ooooo`Co00001Oooool2o`0000[ooooo1?l0000Boooooako00000_oo
ool2o`0000Oooooo0_l0000;ooooo`;o00002oooool2o`0001Sooooo0_l00002ooooo`?o00001?oo
ool2o`0000;ooooo1?l00003ooooo`;o00002?ooool2o`0001Kooooo0_l000001?oooooo0000o`00
0?l00003ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000003ooooo`;o0000
1oooool4o`00033ooooo000Looooo`03o`000?oooooooooo033ooooo0_l00003ooooo`;o00001_oo
ool2o`0000_ooooo1Ol0000;ooooo`;o00001Oooool>o`0000?ooooo2?l000000ooooooo0000o`00
0002o`0000;ooooo1?l00009ooooo`;o00001oooool2o`0000;ooooo1?l0000Oooooo`;o00000ooo
ool2o`0000Cooooo0_l00006ooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo0_l0
0002ooooo`;o00004Oooool2o`0000;ooooo0_l00007ooooo`Go00001Oooool2o`0003_ooooo000L
ooooo`03o`000?oooooooooo03Gooooo0_l000000ooooooo0000o`000003ooooo`;o00002oooool2
o`0000Sooooo0_l00004ooooo`;o00001?oooolIo`000003ooooool0003o000000?o00000oooool3
o`0000Oooooo1?l00009ooooo`Ko00001oooool2o`0001Kooooo0_l0000Aooooo`;o00001?ooool2
o`000005ooooool0003o0000o`000?ooool00_l00002ooooo`;o00000oooool4o`0000[ooooo0_l0
00000ooooooo0000o`000003ooooo`;o00001_ooool2o`0000;ooooo0_l0000nooooo`007?ooool0
0ol0003oooooooooo`0`ooooo`;o00001_ooool2o`0000_ooooo0_l000000ooooooo0000o`00000:
ooooo`?o00000oooool3o`0000;ooooo8Ol00002ooooo`;o00002?ooool2o`0000_ooooo0_l0000;
ooooo`;o00002_ooool4o`0001Oooooo0_l000001?oooooo0000o`000?l00004ooooo`;o00000_oo
ool2o`0000Gooooo0_l00003ooooo`Co00003Oooool2o`0000?ooooo1?l00004ooooo`;o00000_oo
ool2o`000003ooooool0003o000000Sooooo1?l0000_ooooo`007?ooool00ol0003oooooooooo`0`
ooooo`;o00004oooool2o`000003ooooool0003o000000;ooooo1?l00005ooooo`;o00000_ooool4
o`0000;ooooo8Ol00003ooooo`;o00001oooool2o`0000Kooooo0_l00006ooooo`;o00005?ooool4
o`0000;ooooo0_l00005ooooo`;o00003?ooool:o`0000Cooooo0_l0000Pooooo`Co00001?ooool2
o`0000Gooooo0ol00007ooooo`Ko0000;Oooool001cooooo00?o0000ooooooooool0<?ooool2o`00
00Sooooo0_l00003ooooo`Co00002Oooool4o`0000Cooooo0_l00003ooooo`;o00000_ooool3o`00
00;ooooo7_l00003ooooo`;o00001oooool2o`0000Kooooo0_l00006ooooo`;o00000oooool2o`00
00[ooooo0_l000000ooooooo0000o`000006ooooo`;o00001Oooool2o`0000gooooo0_l00003oooo
o`Co00001?ooool2o`0000?ooooo1?l0000Looooo`;o00000oooool2o`0000Kooooo0_l00004oooo
o`;o00001?ooool3o`0002gooooo000Looooo`03o`000?oooooooooo033ooooo0_l00008ooooo`;o
00000oooool4o`0000_ooooo0_l00004ooooo`;o00001ooooolNo`000003ooooool0003o000000;o
00002?ooool2o`000003ooooool0003o000000_ooooo1?l00005ooooo`;o000000?oooooo`000?l0
00001oooool2o`000003ooooool0003o000000Cooooo1?l00008ooooo`;o00000oooool2o`0000[o
oooo0_l00002ooooo`;o00001oooool4o`0001cooooo0_l00003ooooo`;o00003?ooool2o`0003Co
oooo000Looooo`03o`000?oooooooooo03oooooo0_l00004ooooo`;o00000oooool2o`0000Kooooo
0_l00009ooooo`;o000000?oooooo`000?l000002?l000000ooooooo0000o`00000>o`0000;ooooo
0_l00009ooooo`;o000000?oooooo`000?l000001?ooool5o`0000;ooooo1?l00003ooooo`?o0000
0_ooool2o`0000Kooooo0_l00008ooooo`Co00000_ooool2o`0000Cooooo0_l00003ooooo`;o0000
2Oooool3o`0000;ooooo0ol00008ooooo`;o000000?oooooo`000?l000001oooool2o`00013ooooo
0_l00003ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0>?ooool2o`0000Gooooo0_l0
0004ooooo`;o00000oooool2o`0000Cooooo1?l00009ooooo`;o00000ooooolLo`0000Cooooo0_l0
0008ooooo`;o00000_ooool6o`0000;ooooo0_l00005ooooo`?o00001Oooool2o`0000?ooooo0_l0
0008ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00000?ooooo`Go0000
0oooool4o`0000?ooooo0_l000000ooooooo0000o`000003o`0000;ooooo0_l00003ooooo`;o0000
3_ooool2o`0000Oooooo0_l000000ooooooo0000o`00000<ooooo`;o0000;oooool001cooooo00?o
0000ooooooooool0>?ooool2o`0000Gooooo0_l00002ooooo`Co00001?ooool2o`0000;ooooo1Ol0
0003ooooo`;o00000oooool2o`0000Cooooo7?l00003ooooo`?o00002?ooool2o`0000;ooooo0ol0
0003ooooo`Co00003?ooool5o`0000kooooo0_l00004ooooo`?o00003Oooool3o`0000Gooooo0_l0
00000ooooooo0000o`000003ooooo`;o00000oooool2o`0000?ooooo0_l0000Aooooo`Co00001ooo
ool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000001_ooool2o`000003oooo
ool0003o000002cooooo000Looooo`03o`000?oooooooooo03Sooooo0_l00005ooooo`;o00000_oo
ool2o`0000Gooooo0ol00002ooooo`?o00001Oooool2o`0000?ooooo0_l00002ooooo`Oo000000?o
ooooo`000?l000000ol000000ooooooo0000o`000008o`000005ooooool0003o0000o`000?ooool0
0_l00002ooooo`;o00003Oooool2o`0000Cooooo0_l0000:ooooo`;o00000_ooool2o`000005oooo
ool0003o0000o`000?ooool00_l00006ooooo`;o00002Oooool2o`0000;ooooo0_l00009ooooo`?o
000000?oooooo`000?l000000_ooool3o`0000;ooooo0_l0000Nooooo`;o00002Oooool3o`0000?o
oooo1Ol00003ooooo`;o00001?ooool2o`0002cooooo000Looooo`03o`000?oooooooooo037ooooo
0_l00005ooooo`;o00003?ooool6o`0000Cooooo1?l00008ooooo`;o00000_oooolIo`0000Cooooo
0_l00008ooooo`;o00001oooool2o`0000Cooooo0_l00005ooooo`;o00000oooool2o`0000;ooooo
0_l00002ooooo`;o000000?oooooo`000?l000001_ooool3o`0000Sooooo0_l00002ooooo`;o0000
2_ooool2o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o00009?ooool2o`0000Cooooo
0_l00004ooooo`;o00001Oooool2o`0003;ooooo000Looooo`03o`000?oooooooooo037ooooo0_l0
0007ooooo`;o00002Oooool6o`0000Gooooo1?l00004ooooo`;o00000_ooool3o`0000?ooooo0ol0
00000ooooooo0000o`00000>o`000004ooooool0003o0000o`0000?ooooo0_l00008ooooo`;o0000
3Oooool2o`0000Gooooo1?l00002ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Oooooo
1_l00008ooooo`;o00000_ooool2o`0000kooooo0_l00006ooooo`;o00002_ooool3o`0001?ooooo
0_l0000;ooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0=oooool2o`000003ooooool0
003o000000Sooooo0ol00002ooooo`;o00001Oooool2o`0000Kooooo0_l00003ooooo`Co000000Co
ooooo`000?l0003ooooo5Ol0000?ooooo`;o00004Oooool2o`000003ooooool0003o000000;ooooo
0_l00002ooooo`;o00001?ooool2o`0000Gooooo0_l00002ooooo`Co00000_ooool2o`000004oooo
ool0003o0000ooooo`;o00000_ooool2o`0000_ooooo0_l000000ooooooo0000o`000006ooooo`;o
00002_ooool3o`0001?ooooo0_l0000;ooooo`;o0000>?ooool001cooooo0_l0000hooooo`;o0000
0_ooool2o`0000Oooooo0_l00007ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o0000
0_ooool5o`0000Cooooo2Ol000000ooooooo0000o`000009o`0000;ooooo0_l0000;ooooo`;o0000
4Oooool2o`0000Gooooo0_l00002ooooo`;o00001?ooool2o`0000Gooooo0_l00002ooooo`;o0000
1?ooool2o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o00002Oooool3o`000004oooo
ool0003o0000o`0002Kooooo0_l00009ooooo`Co00002Oooool2o`0002gooooo000Looooo`03o`00
0?oooooooooo03_ooooo0_l0000:ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo
0000o`000002o`0000?ooooo0ol00002ooooo`;o00001_ooool4o`0000Cooooo2Ol00002ooooo`;o
00000oooool3o`0000_ooooo0_l00002ooooo`;o00001?ooool2o`0000gooooo0_l00008ooooo`?o
00002?ooool2o`0000Kooooo0_l00004ooooo`;o00000_ooool2o`0000[ooooo1_l0000aooooo`;o
00001Oooool2o`0000Cooooo0_l0000]ooooo`007?ooool00ol0003oooooooooo`0eooooo`;o0000
4?ooool2o`000003ooooool0003o000000Gooooo0_l00004ooooo`;o00000oooool2o`0000Cooooo
1_l00004ooooo`Wo00000_ooool2o`0000?ooooo0ol00003ooooo`;o00001Oooool3o`0000;ooooo
0_l00004ooooo`;o00002oooool2o`0000_ooooo0_l0000@ooooo`;o00001?ooool2o`00013ooooo
0_l0000aooooo`;o00001oooool2o`0003?ooooo000Looooo`03o`000?oooooooooo03?ooooo1?l0
000@ooooo`;o00004oooool2o`0000Cooooo0_l00002ooooo`;o00001_ooool4o`000003ooooool0
003o000000Oooooo0_l00004ooooo`Co00000oooool2o`0001Kooooo0_l00003ooooo`;o00001_oo
ool3o`0000Kooooo0_l00008ooooo`;o00000oooool2o`0002;ooooo0_l0000Oooooo`;o0000??oo
ool001cooooo00?o0000ooooooooool0<oooool2o`0001;ooooo0_l0000;ooooo`;o00002?ooool2
o`0000_ooooo0_l00005ooooo`;o00004?ooool2o`0000Sooooo0_l00006ooooo`?o00003Oooool2
o`0000Kooooo0ol00006ooooo`;o00002?ooool2o`0001_ooooo0_l0000:ooooo`Co00004Oooool3
o`0001Cooooo0_l0000aooooo`007?ooool00ol0003oooooooooo`10ooooo`Ko00001Oooool2o`00
00Oooooo0_l00006ooooo`Co00001Oooool4o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`00
0003ooooool0003o000000;o000000?oooooo`000?l000003_ooool2o`0000Kooooo0ol00004oooo
o`;o000000?oooooo`000?l000002Oooool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2
o`0000Cooooo0_l00006ooooo`;o00000oooool4o`0001;ooooo0_l0000<ooooo`;o00004Oooool3
o`0000Cooooo0_l00006ooooo`;o00001_ooool2o`00037ooooo000Looooo`03o`000?oooooooooo
02kooooo0_l0000:ooooo`;o00001?ooool6o`0000Gooooo0_l0000?ooooo`?o00001_ooool4o`00
00?ooooo0_l00006ooooo`Co000000?oooooo`000?l000000_l000000ooooooo0000o`000003oooo
o`;o00003_ooool3o`0000Kooooo1_l000000ooooooo0000o`000006ooooo`;o00000_ooool2o`00
0004ooooool0003o0000ooooo`;o00001?ooool3o`0000Gooooo0_l00003ooooo`Co00007_ooool2
o`0001[ooooo0_l00005ooooo`?o0000>Oooool001cooooo00?o0000ooooooooool0;_ooool4o`00
00Sooooo0_l000000ooooooo0000o`000008ooooo`;o00005?ooool2o`0000cooooo0ol00005oooo
o`?o00000oooool2o`0000Sooooo0_l00008ooooo`;o00001?ooool5o`0000Cooooo1?l00003oooo
o`;o000000?oooooo`000?l000002_ooool2o`0000Sooooo0_l0000/ooooo`;o00008Oooool3o`00
03Wooooo000Looooo`03o`000?oooooooooo02kooooo1?l0000;ooooo`;o000000?oooooo`000?l0
00001Oooool2o`0000Kooooo0_l00006ooooo`;o00001?ooool2o`000003ooooool0003o000000Wo
oooo0ol00005ooooo`;o00001?ooool2o`00013ooooo1?l00003ooooo`;o000000Coooooo`000?l0
003o00002_ooool2o`0000;ooooo0_l00006ooooo`;o00000_ooool2o`0000;ooooo0_l00009oooo
o`;o00007?ooool2o`0000Sooooo0_l00004ooooo`;o00006Oooool2o`0000;ooooo0_l0000ioooo
o`007?ooool00ol0003oooooooooo`0^ooooo`;o00003Oooool2o`000003ooooool0003o000000;o
00002oooool2o`0000Kooooo0_l00007ooooo`;o00004_ooool2o`0000;ooooo0_l00005ooooo`;o
00002_ooool6o`000003ooooool0003o000000cooooo1?l00008ooooo`Co00001?ooool9o`0000;o
oooo1?l0000Dooooo`?o00001Oooool2o`0000;ooooo0_l00004ooooo`;o000000Coooooo`000?l0
003ooooo0_l0000Eooooo`;o00000_ooool2o`0003gooooo000Looooo`03o`000?oooooooooo03Co
oooo0_l0000:ooooo`Co00001Oooool2o`0000?ooooo0_l00002ooooo`;o00001?ooool2o`0001[o
oooo0_l00002ooooo`;o00000oooool5o`0000[ooooo0_l000000ooooooo0000o`00000?ooooo`;o
000000?oooooo`000?l000001oooool4o`000004ooooool0003o0000ooooo`Wo00000_ooool2o`00
01Kooooo0ol00005ooooo`;o00000_ooool2o`0000Oooooo0_l0000Gooooo`?o00000oooool2o`00
03cooooo000Looooo`03o`000?oooooooooo03Cooooo0_l0000:ooooo`;o00001?ooool5o`0000?o
oooo0_l00002ooooo`Co00000_ooool2o`0000cooooo0_l0000Eooooo`;o000000?oooooo`000?l0
00000ol00007ooooo`;o00001Oooool6o`0000[ooooo0_l00009ooooo`Ko00001_ooool2o`0000Wo
oooo0_l0000:ooooo`;o00006?ooool2o`0001Sooooo0_l00004ooooo`?o0000>oooool001cooooo
00?o0000ooooooooool0=_ooool4o`0000Kooooo0_l000001?oooooo0000o`000?ooool4o`0000So
oooo1?l00009ooooo`;o00001Oooool2o`0000gooooo0_l0000:ooooo`Co00001Oooool2o`0000Oo
oooo1_l00006ooooo`;o00000oooool2o`0000Kooooo0_l000001?oooooo0000o`000?ooool4o`00
0003ooooool0003o000000;ooooo1?l00006ooooo`Go00001Oooool4o`0001Sooooo0_l0000Coooo
o`;o00002_ooool2o`0003_ooooo000Looooo`03o`000?oooooooooo03Kooooo1_l00003ooooo`;o
00000_ooool2o`000004ooooool0003o0000o`0000_ooooo0_l00009ooooo`;o00002?ooool2o`00
00[ooooo0_l00005ooooo`;o00001oooool2o`0000?ooooo0_l00008ooooo`Co00001oooool2o`00
00;ooooo0ol00003ooooo`Go000000?oooooo`000?l000000oooool=o`0000;ooooo2Ol00003oooo
o`;o00000oooool2o`0000Cooooo1?l0000;ooooo`;o000000?oooooo`000?l000000_l0000@oooo
o`;o000000?oooooo`000?l000001oooool2o`0003_ooooo000Looooo`03o`000?oooooooooo02[o
oooo0_l0000>ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`;o00006_ooool2o`0000Co
oooo0_l0000Aooooo`;o00001_ooool3o`0000Oooooo0_l00002ooooo`Ko00002oooool2o`0000Co
oooo1Ol000000ooooooo0000o`000002oooooa;o00000_ooool5o`0000Sooooo0_l00004ooooo`Co
000000?oooooo`000?l000002?ooool2o`000003ooooool0003o000000;o00004oooool2o`0000?o
oooo0_l00007ooooo`;o0000=_ooool001cooooo00?o0000ooooooooool0:_ooool2o`0003Oooooo
0_l00005ooooo`;o00001Oooool2o`0000Wooooo0_l00006ooooo`;o00002?ooool2o`0000;ooooo
0_l0000=ooooo`;o00001Oooool2o`000003ooooool0003o000000Go000000?oooooo`000?l00000
2Ol000000ooooooo0000o`000003o`0000Gooooo0_l0000Dooooo`;o00002oooool4o`00013ooooo
0_l00006ooooo`;o00001oooool2o`0003Kooooo000Looooo`;o0000=Oooool2o`0000cooooo0_l0
000Cooooo`;o00004Oooool2o`000003ooooool0003o000000;ooooo0_l00007ooooo`;o00001?oo
ool2o`0000Gooooo0_l00006ooooo`;o00004?ooool4o`0000?ooooo2ol000000ooooooo0000o`00
0003o`000003ooooool0003o000000;o000000Coooooo`000?l0003ooooo0_l0000Xooooo`Co0000
4?ooool2o`0000Cooooo0_l00008ooooo`?o0000=_ooool001cooooo00?o0000ooooooooool0=?oo
ool2o`0000cooooo1?l0000Aooooo`;o00002?ooool2o`0000[ooooo0_l00003ooooo`?o00001Ooo
ool2o`0000?ooooo0ol00003ooooo`Ko00001?ooool2o`0000[ooooo0_l00002ooooo`;o00000_oo
ool:o`0000;ooooo2Ol000001?oooooo0000o`000?l00002ooooo`?o00000_ooool2o`0000?ooooo
0ol0000Gooooo`;o00008_ooool2o`0000?ooooo0_l00003ooooo`;o0000=oooool001cooooo00?o
0000ooooooooool07_ooool2o`0001;ooooo0_l0000?ooooo`?o00000_ooool2o`0001;ooooo0_l0
0003ooooo`;o00003oooool3o`0000[ooooo0_l00004ooooo`Ko00003oooool3o`000004ooooool0
003o0000o`0000Cooooo7Ol000000ooooooo0000o`000006o`0000Gooooo0_l0000@ooooo`;o0000
9oooool3o`0000;ooooo0_l0000gooooo`007?ooool00ol0003oooooooooo`0Nooooo`;o00002ooo
ool2o`0000;ooooo0_l000000ooooooo0000o`00000Dooooo`;o00004_ooool2o`0002Oooooo1?l0
000:ooooo`;o00001Oooool2o`0000;ooooo0_l00002ooooo`;o00000_oooolRo`0000Kooooo1_l0
0008ooooo`Co00000oooool2o`000003ooooool0003o000000Oooooo0_l0000Fooooo`;o00000ooo
ool4o`0003Wooooo000Looooo`03o`000?oooooooooo02_ooooo0_l00002ooooo`;o00007Oooool2
o`0000?ooooo0_l0000>ooooo`;o0000;?ooool4o`0000gooooo0_l00005oooooa?o00000_ooool2
o`000003ooooool0003o000000;o000000?oooooo`000?l000001?l00002ooooo`?o000000?ooooo
o`000?l000002?ooool4o`0000?ooooo0_l000000ooooooo0000o`000007ooooo`;o00001_ooool2
o`0000kooooo1?l00002ooooo`?o0000>Oooool001cooooo00?o0000ooooooooool0;oooool2o`00
00Gooooo0_l0000Dooooo`Co00000oooool2o`0000kooooo0ol0000?ooooo`?o00002?ooool2o`00
00Cooooo0_l00009ooooo`Co00000oooool2o`0000kooooo6?l000000ooooooo0000o`00000;o`00
02Wooooo0_l00008ooooo`;o00001_ooool2o`0000;ooooo0_l0000jooooo`007?ooool00ol0003o
ooooooooo`0_ooooo`;o00001Oooool2o`0000cooooo0_l00003ooooo`Go00005_ooool2o`0000So
oooo0_l00002ooooo`;o000000?oooooo`000?l000001_l00003ooooo`;o00001?ooool2o`0000?o
oooo0_l000000ooooooo0000o`000003ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`?o
00000ooooolIo`0000;ooooo1_l00005ooooo`?o0000<_ooool2o`0000;ooooo0_l000000ooooooo
0000o`00000oooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00004oooool2o`0000?ooooo
1?l0000Qooooo`;o00000_ooool2o`0000Cooooo1Ol0000>ooooo`;o000000?oooooo`000?l00000
0_l00007ooooo`;o000000?oooooo`000?l000001Ol00003oooooaKo000000?oooooo`000?l00000
2?l00006ooooo`;o000000?oooooo`000?l000006Oooool2o`000003ooooool0003o000000_ooooo
0_l000000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l000000_l0000mooooo`007?oo
ool00ol0003oooooooooo`0Rooooo`;o00002Oooool2o`0000_ooooo0_l0000Aooooo`;o00003ooo
ool2o`0000Sooooo0ol000000ooooooo0000o`00000Rooooo`;o00000oooool2o`0000;ooooo0_l0
0002ooooo`?o00001OoooolPo`0000;ooooo1Ol00004ooooo`;o00004oooool2o`0000Cooooo0_l0
00000ooooooo0000o`000005ooooo`?o00000oooool5o`0000?ooooo0_l00005ooooo`Co00001?oo
ool2o`0003Gooooo000Looooo`03o`000?oooooooooo02;ooooo0_l00009ooooo`;o00002oooool2
o`0000?ooooo0_l0000<ooooo`;o00001?ooool2o`0000Wooooo0_l000000ooooooo0000o`000005
ooooo`?o000000?oooooo`000?l000001Oooool2o`0001;ooooo0ol0000;ooooo`;o00002_ooool2
o`000003ooooool0003o000002Oo00000_ooool2o`0000_ooooo0_l00007ooooo`;o00001?ooool4
o`0000Kooooo0ol00005ooooo`;o00001?ooool2o`0000Kooooo0ol00004ooooo`;o0000=Oooool0
01cooooo00?o0000ooooooooool0=?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002oooo
o`Co00004?ooool2o`0000cooooo0_l000000ooooooo0000o`00000;ooooo`So00002_ooool2o`00
00;ooooo0ol0000Gooooo`;o000000?oooooo`000?l000002ol00002oooooaGo00000oooool6o`00
00_ooooo0_l00007ooooo`;o000000Coooooo`000?l0003ooooo1?l00006ooooo`;o00003_ooool4
o`00043ooooo000Looooo`03o`000?oooooooooo03Cooooo0_l00002ooooo`;o000000Goooooo`00
0?l0003o0000ooooo`04o`0001kooooo0_l000000ooooooo0000o`000007ooooo`co00000oooool2
o`0000Gooooo0_l0000:ooooo`;o00002?ooool2o`0000Kooooo0_l00002ooooo`Wo000000?ooooo
o`000?l000006?l000000ooooooo0000o`000006o`0000Oooooo0ol00009ooooo`;o000000?ooooo
o`000?l000002oooool2o`0000Gooooo1?l00005ooooo`Co0000@?ooool001cooooo00?o0000oooo
ooooool0??ooool2o`0000cooooo0_l00005ooooo`;o00002Oooool2o`0000?ooooo0_l0000:oooo
o`co00000oooool2o`0000Sooooo1?l00005ooooo`;o00002?ooool2o`0000Oooooo0_l000000ooo
oooo0000o`00000Wo`0000;ooooo0_l00007ooooo`?o00002oooool2o`0001?ooooo1?l0000;oooo
o`;o0000??ooool001cooooo00?o0000ooooooooool0>?ooool2o`0000;ooooo0_l0000:ooooo`Co
00001Oooool2o`0000Wooooo0_l000000ooooooo0000o`00000<ooooo`ko00000oooool2o`0000Ko
oooo1?l0000Eooooo`;o000000?oooooo`000?l00000:_l0000Iooooo`?o00000_ooool2o`0000So
oooo0ol00002ooooo`;o00000_ooool4o`0000Sooooo0_l0000looooo`0000Koooooonk^k_lb<S;o
0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000
ooooooooool0>?ooool2o`0000;ooooo0_l00007ooooo`;o000000?oooooo`000?l000005Oooool2
o`0000_ooooo3ol00003ooooo`;o00000_ooool2o`0000oooooo0_l00005ooooo`?o00000_ooool2
o`000003ooooool0003o000002So00002_ooool2o`00013ooooo0_l00002ooooo`Co00001Oooool4
o`0000;ooooo0_l00002ooooo`Co000000?oooooo`000?l000000ol00010ooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo
00?o0000ooooooooool0=oooool2o`0000Cooooo0_l00006ooooo`;o00006?ooool2o`0000[ooooo
4?l000000ooooooo0000o`000004ooooo`;o00003oooool2o`0000Gooooo1?l000000ooooooo0000
o`00000>o`000003ooooool0003o000001Wo00000_ooool2o`0000Oooooo0_l0000Fooooo`;o0000
1Oooool2o`0000Sooooo0_l00003ooooo`Go00001?ooool2o`0003[ooooo00000ooooooo410@oooo
o`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo03Oooooo0_l00004ooooo`;o00000_ooool2o`0000Oooooo0_l0000Booooo`?o0000
1ooooolCo`000003ooooool0003o000000Sooooo0_l00003ooooo`?o00001oooool2o`0000?ooooo
1?l00002ooooo`Ko000000?oooooo`000?l000004?l000000ooooooo0000o`00000>o`0000?ooooo
0_l0000=ooooo`;o00005Oooool2o`0000[ooooo1?l000000ooooooo0000o`000007ooooo`;o0000
>_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oV9RHoooo
oonHV9So8B4Q00Kooooo0ol0000booooo`;o00001Oooool3o`0000?ooooo1ol00003ooooo`?o0000
4_ooool2o`0000Sooooo1Ol000000ooooooo0000o`00000;o`0000Gooooo0_l000001?oooooo0000
o`000?ooool2o`0000?ooooo0ol00007ooooo`;o00002oooool4o`000003ooooool0003o0000027o
00001oooool2o`0000;ooooo0_l00005ooooo`Go00004_ooool3o`0000[ooooo0ol000000ooooooo
0000o`000013ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`00
0?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0booooo`;o00001Oooool3o`0000?o
oooo0_l00002ooooo`?o00000oooool2o`0001gooooo4ol000000ooooooo0000o`000002ooooo`;o
000000Goooooo`000?l0003o0000ooooo`02o`0000Gooooo0_l00004ooooo`;o00002?oooolFo`00
0003ooooool0003o000000_o000000?oooooo`000?l000001ol00005ooooo`;o00000_ooool2o`00
00Oooooo0ol0000Cooooo`;o00002_ooool4o`0004Gooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`0mooooo`;o
00001?ooool2o`000003ooooool0003o000001_ooooo0_l000000ooooooo0000o`00000Co`000003
ooooool0003o000000Cooooo1ol00005ooooo`;o000000Coooooo`000?l0003ooooo0_l00008oooo
oc3o00004?ooool2o`0000[ooooo0_l0000Dooooo`Co00001oooool2o`0003cooooo00001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0m
ooooo`Co00000_ooool2o`000003ooooool0003o000000cooooo0_l00009ooooo`;o00000_ooool2
o`000003ooooool0003o000001Go00000_ooool2o`000004ooooool0003o0000ooooo`;o00001_oo
ool2o`0000;ooooo0ol0000;ooooo`;o000000?oooooo`000?l000000ol000000ooooooo0000o`00
0006o`0000?ooooo6ol00002ooooo`?o00000oooool2o`0000Kooooo0_l000000ooooooo0000o`00
0002ooooo`;o00000oooool2o`0001_ooooo0_l00002ooooo`;o0000??ooool00006ooooooo^k^ko
<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo03Oo
oooo0_l00006ooooo`;o00004Oooool4o`0000Oooooo1_l00003oooooaOo00000_ooool2o`000003
ooooool0003o000000Wooooo1?l000000ooooooo0000o`00000;ooooo`Co000000?oooooo`000?l0
00000_ooool6o`000005ooooool0003o0000o`000?ooool07?l000000ooooooo0000o`000002o`00
00;ooooo0_l00004ooooo`;o00000oooool2o`0000;ooooo0_l000000ooooooo0000o`00000?oooo
o`;o00002oooool3o`00043ooooo000Looooo`03o`000?oooooooooo03Oooooo0_l000000ooooooo
0000o`00000@ooooo`;o00001?ooool3o`0000Sooooo1_l00003oooooaOo00001Oooool2o`0000Ko
oooo0_l00002ooooo`?o00004?ooool2o`000003ooooool0003o000000;ooooo1_l000000ooooooo
0000o`00000Jo`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000Cooooo0_l00002ooooo`;o
00001_ooool2o`0000oooooo0_l0000;ooooo`;o00005?ooool2o`0002_ooooo000Looooo`03o`00
0?oooooooooo03?ooooo0_l00005ooooo`;o00001oooool2o`0000Oooooo1?l00003ooooo`;o0000
2Oooool3o`0000Gooooo1Ol000000ooooooo0000o`00000=o`0000?ooooo0_l0000:ooooo`;o0000
0_ooool2o`00017ooooo5ol000000ooooooo0000o`000008o`000003ooooool0003o000000Co0000
0_ooool3o`000003ooooool0003o000000?o000000?oooooo`000?l000000_ooool2o`0000?ooooo
0ol0000Rooooo`;o00005_ooool2o`0002_ooooo000Looooo`03o`000?oooooooooo03?ooooo0_l0
000>ooooo`;o00002Oooool2o`0000kooooo0_l00007oooooa?o00001?ooool2o`0000?ooooo0_l0
0002ooooo`;o00005_ooool2o`0000;ooooo1_l00002ooooo`go00000ooooolCo`000005ooooool0
003o0000o`000?ooool00_l00005ooooo`Co000000?oooooo`000?l000002?ooool2o`0000gooooo
0_l0000:ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0?_ooool2o`0000?ooooo0_l0
00000ooooooo0000o`00000PoooooaGo000000?oooooo`000?l000000oooool2o`000005ooooool0
003o0000o`000?ooool00_l00006ooooo`;o00002oooool2o`0000;ooooo2?l000000ooooooo0000
o`000009o`0000;ooooo5?l00002ooooo`;o00000_ooool2o`0000Gooooo1?l00008ooooo`Go0000
3Oooool2o`0004oooooo000Looooo`03o`000?oooooooooo03kooooo1_l00002ooooo`;o00000_oo
ool2o`0000Kooooo0_l0000BoooooaOo000000?oooooo`000?l000000oooool2o`000003ooooool0
003o000000;ooooo1?l00004ooooo`;o000000?oooooo`000?l000003_oooolUo`000003ooooool0
003o000000Co00000_ooool2o`00017ooooo0ol0000Eooooo`;o00001_ooool2o`00047ooooo000L
ooooo`03o`000?oooooooooo043ooooo1?l00002ooooo`?o000000Coooooo`000?l0003ooooo0_l0
0003ooooo`;o00001?ooool2o`0000Oooooo0_l00002oooooa[o00001?ooool4o`000003ooooool0
003o000000;ooooo0_l00007ooooo`;o00003?ooool/o`0000oooooo1?l0000Dooooo`;o00001?oo
ool4o`0000Gooooo0ol00011ooooo`007?ooool00ol0003oooooooooo`17ooooo`;o00001?ooool2
o`0000Oooooo1?l00007ooooo`;o00000_oooolCo`0000?ooooo1?l00006ooooo`;o000000?ooooo
o`000?l000002_ooool2o`0000Sooooo0_l00003ooooo`;o000000?oooooo`000?l000001_l00000
0ooooooo0000o`000003o`000003ooooool0003o000001Go00001oooool2o`0000Wooooo1?l0000A
ooooo`;o000000?oooooo`000?l000000oooool3o`0000Oooooo0_l00012ooooo`007?ooool00ol0
003oooooooooo`16ooooo`;o00001Oooool2o`0000Oooooo0_l0000=ooooo`Co000000?oooooo`00
0?l000003Ol00002ooooo`;o00000oooool2o`0000Kooooo1ol00002ooooo`;o000000?oooooo`00
0?l000002?ooool4o`000004ooooool0003o0000o`0000;ooooo1Ol00002oooooaco00002?ooool2
o`0000Gooooo0_l00004ooooo`;o00001Oooool2o`0000[ooooo0_l00006ooooo`;o0000C?ooool0
01cooooo00?o0000ooooooooool0=oooool2o`0000_ooooo1?l00005ooooo`;o00005_oooolFo`00
00Gooooo0_l00002ooooo`?o00000_ooool6o`000004ooooool0003o0000o`0000gooooo0_l00000
1?oooooo0000o`000?l00002ooooo`Go000000?oooooo`000?l000005ol000001Ooooooo0000o`00
0?l0003ooooo00;o00003?ooool3o`0000[ooooo0_l000000ooooooo0000o`000002o`00013ooooo
0_l00019ooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00002oooool2o`0000?ooooo0_l0
0008ooooo`;o00002?ooool2o`0000Gooooo0ol000000ooooooo0000o`00000;o`000004ooooool0
003o0000ooooo`;o00001oooool6o`0000;ooooo0ol00003ooooo`?o00003Oooool2o`000003oooo
ool0003o000000;o000000Coooooo`000?l0003o00000_oooolJo`000005ooooool0003o0000o`00
0?ooool00_l0000<ooooo`?o00003Oooool4o`00013ooooo1_l00015ooooo`007?ooool00ol0003o
ooooooooo`19ooooo`Co00001Oooool3o`0000Sooooo0_l00005ooooo`;o000000?oooooo`000?l0
00002_l0000?ooooo`;o00000_ooool2o`0000?ooooo1?l000001?oooooo0000o`000?l00002oooo
o`Co00002_ooool4o`0000;ooooo0_l00002ooooo`Co000000?oooooo`000?l000004_l00006oooo
o`?o00001Oooool3o`0001Sooooo0_l00009ooooo`;o00000oooool5o`0004Gooooo000Looooo`;o
0000BOooool2o`000003ooooool0003o000000Gooooo0_l00009ooooo`;o00000_ooool2o`000004
ooooool0003o0000ooooo`_o000000?oooooo`000?l000001?l00005ooooo`;o00002?ooool2o`00
00?ooooo0_l00006ooooo`Co000000?oooooo`000?l000002oooool5o`000004ooooool0003o0000
o`0000?ooooo5?l00002ooooo`;o00000_ooool2o`0000Gooooo0ol00008ooooo`;o00000_ooool2
o`0000Kooooo0_l00002ooooo`;o000000?oooooo`000?l000001_ooool2o`0000?ooooo0_l00018
ooooo`007?ooool00ol0003oooooooooo`0kooooo`;o00002oooool2o`00017ooooo0_l00004oooo
o`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`?o000000?oooooo`000?l000002?l00004
ooooo`?o00000_ooool2o`0000Cooooo0_l0000@ooooo`;o00002OoooolGo`0000;ooooo2Ol00002
ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Wooooo0_l00002ooooo`;o00001_ooool2
o`0000Gooooo0_l000000ooooooo0000o`00001Booooo`007?ooool00ol0003oooooooooo`0koooo
o`;o00003Oooool4o`0000gooooo0_l00008ooooo`Ko000000?oooooo`000?l000000_ooool3o`00
00[ooooo0_l00003ooooo`Co00006oooool2o`0000;ooooo0_l000000ooooooo0000o`00000Ho`00
0003ooooool0003o000000;o00000oooool4o`00013ooooo0_l00009ooooo`Co00001Oooool2o`00
0003ooooool0003o000005;ooooo000Looooo`03o`000?oooooooooo04[ooooo1?l00008ooooo`;o
00003Oooool2o`0000;ooooo0_l0000Cooooo`;o00001?ooool2o`0000Gooooo0_l00008ooooo`;o
00002_ooool2o`0000;ooooo0_l00002ooooo`Oo000000?oooooo`000?l000003?l000001?oooooo
0000o`000?ooool3o`0000?ooooo0ol000000ooooooo0000o`00000?ooooo`;o00000_ooool3o`00
00Cooooo1?l0001Looooo`007?ooool00ol0003oooooooooo`13ooooo`;o000000Coooooo`000?l0
003ooooo0_l00009ooooo`Co00005Oooool2o`0000Kooooo1?l00005ooooo`;o00001_ooool2o`00
0003ooooool0003o000000Go00001Oooool2o`0001;ooooo1Ol00002ooooo`;o00000_ooool;o`00
00Cooooo0_l00002ooooo`So000000?oooooo`000?l000001_ooool2o`0000Sooooo0ol00005oooo
o`;o0000GOooool001cooooo00?o0000ooooooooool0@oooool2o`000004ooooool0003o0000oooo
o`?o00002?ooool2o`0001?ooooo0_l00002ooooo`?o00001Oooool4o`0000;ooooo0_l00009oooo
o`;o000000?oooooo`000?l000000_ooool3o`0000Oooooo0ol0000;ooooo`;o000000?oooooo`00
0?l000001?l000001?oooooo0000o`000?l00002oooooa3o00000oooool6o`0000?ooooo0ol00005
ooooo`;o00006oooool5o`0004oooooo000Looooo`03o`000?oooooooooo04?ooooo0_l000000ooo
oooo0000o`000002ooooo`;o00007Oooool2o`0000?ooooo0_l0000;ooooo`;o00004_ooool2o`00
00Kooooo0ol00002ooooo`;o00001oooool7o`000003ooooool0003o000001Go00001Oooool2o`00
0003ooooool0003o000000?ooooo0_l0000:ooooo`;o00000oooool2o`0000Kooooo0_l00006oooo
o`;o000000?oooooo`000?l000000ol0001?ooooo`007?ooool00ol0003oooooooooo`13ooooo`;o
00001Oooool2o`0001gooooo0_l00005ooooo`;o000000?oooooo`000?l000000ol0000>ooooo`;o
00000oooool2o`0000;ooooo0_l0000;ooooo`Co00001oooool2o`0000Cooooo0_l00002ooooo`Oo
00000_ooool8o`000005ooooool0003o0000o`000?ooool00_l00003ooooo`;o00003_ooool3o`00
00?ooooo0_l00006ooooo`;o00001_ooool3o`0005Cooooo000Looooo`03o`000?oooooooooo04Go
oooo0_l00003ooooo`;o00000oooool2o`0000oooooo0_l0000<ooooo`Co000000?oooooo`000?l0
00000ol0000>ooooo`;o00000oooool2o`0000?ooooo0_l0000<ooooo`;o00003_ooool6o`000005
ooooool0003o0000o`000?ooool01?l000001?oooooo0000o`000?l00002ooooo`?o000000?ooooo
o`000?l000004oooool3o`0000gooooo0_l00005ooooo`;o0000E?ooool001cooooo00?o0000oooo
ooooool0AOooool2o`0000Sooooo0_l0000?ooooo`Co00002_ooool2o`0000_ooooo0_l0000>oooo
o`;o00000oooool2o`0000Cooooo0_l00002ooooo`;o00000_ooool2o`0000kooooo1Ol00002oooo
o`;o00000_ooool4o`000003ooooool0003o000000;o00001Oooool2o`0001?ooooo0ol00005oooo
o`;o00001_ooool2o`0005_ooooo000Looooo`03o`000?oooooooooo04?ooooo0_l0000Mooooo`;o
00004Oooool2o`0000Cooooo0_l00003ooooo`;o00000oooool2o`000003ooooool0003o000000co
oooo0_l00002ooooo`?o000000Coooooo`000?l0003ooooo0_l0000=ooooo`Oo000000?oooooo`00
0?l000000oooool5o`000003ooooool0003o000000Co00001_ooool2o`0001?ooooo0_l0000Boooo
o`;o0000Coooool001cooooo00?o0000ooooooooool0@oooool2o`0000Oooooo0_l0000<ooooo`;o
00001Oooool3o`0000Gooooo0_l0000:ooooo`;o00002Oooool2o`0000?ooooo0_l000000ooooooo
0000o`00000?ooooo`Co00001?ooool3o`0000Gooooo0_l00008ooooo`;o00000oooool3o`0000;o
oooo0ol00003ooooo`Go00001oooool2o`0000gooooo0_l000000ooooooo0000o`000009ooooo`;o
00000_ooool2o`0000Gooooo0ol0001?ooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o0000
0oooool2o`000003ooooool0003o000000Cooooo0_l000001?oooooo0000o`000?ooool4o`0000;o
oooo0_l000000ooooooo0000o`00000Iooooo`;o00004_ooool4o`0000Gooooo0ol00005ooooo`;o
00001oooool3o`0000Cooooo0_l00003ooooo`;o00002?ooool2o`0000Gooooo0ol0000<ooooo`;o
000000?oooooo`000?l000002Oooool2o`0000;ooooo0_l00005ooooo`;o0000D?ooool001cooooo
00?o0000ooooooooool0BOooool2o`000003ooooool0003o000000;ooooo0ol000000ooooooo0000
o`000002ooooo`;o00000oooool2o`000004ooooool0003o0000o`0000?ooooo0_l00008ooooo`;o
00002?ooool2o`0000Sooooo0_l0000Booooo`Co00001Oooool4o`0000gooooo0ol00002ooooo`;o
00000oooool3o`0000Sooooo0ol00006ooooo`;o00003Oooool2o`0000Cooooo0_l00007ooooo`;o
0000FOooool001cooooo00?o0000ooooooooool0A_ooool2o`000003ooooool0003o000000Gooooo
0ol00005ooooo`;o000000?oooooo`000?l000001?ooool3o`0000cooooo0_l00004ooooo`;o0000
0_ooool2o`00013ooooo0_l00007ooooo`?o000000?oooooo`000?l000002?ooool2o`0000;ooooo
0_l00004ooooo`;o00002?ooool2o`0000?ooooo1?l00002ooooo`;o00000oooool4o`0001Cooooo
0_l00004ooooo`;o00001oooool2o`0005Wooooo000Looooo`03o`000?oooooooooo04Kooooo1?l0
000?ooooo`Co000000Coooooo`000?l0003ooooo1Ol0000@ooooo`;o00001Oooool2o`0000Cooooo
0_l00002ooooo`;o00000oooool2o`0000Oooooo0ol000000ooooooo0000o`00000<ooooo`;o0000
1?ooool2o`0000Gooooo0_l00005ooooo`Go00000_ooool2o`0000Gooooo0_l00005ooooo`;o0000
1Oooool2o`0001Sooooo0ol0001Eooooo`007?ooool2o`0004Wooooo0_l0000?ooooo`;o00000ooo
ool2o`0000Cooooo0_l0000Cooooo`;o00000_ooool2o`0000Cooooo1_l0000<ooooo`?o00002ooo
ool2o`0000Cooooo0_l00009ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l0
000>ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo0ol0000Cooooo`Co0000E?oo
ool001cooooo00?o0000ooooooooool0B?ooool2o`0000Kooooo0_l00003ooooo`;o00002?ooool2
o`0000Sooooo0_l00009ooooo`;o000000?oooooo`000?l000001_l00002ooooo`;o000000?ooooo
o`000?l000000ol00004ooooo`;o00001oooool2o`0000_ooooo1?l00002ooooo`;o00003?ooool2
o`0000Oooooo0_l00004ooooo`;o00000oooool4o`0000Gooooo0_l00005ooooo`?o00001?ooool3
o`0000Oooooo0_l00005ooooo`;o0000E?ooool001cooooo00?o0000ooooooooool0B?ooool2o`00
00Kooooo0_l00003ooooo`;o00002?ooool2o`0000Sooooo0_l00009ooooo`;o000000?oooooo`00
0?l000000_ooool2o`0000Cooooo0_l00008ooooo`Co000000Coooooo`000?l0003o00003oooool5
o`0000;ooooo0_l000000ooooooo0000o`000007ooooo`;o00003oooool2o`000003ooooool0003o
000000Co00004oooool3o`0000Oooooo0ol0001Jooooo`007?ooool00ol0003oooooooooo`1Ioooo
o`Co0000;?ooool4o`0000?ooooo0ol00007ooooo`Ko00000_ooool4o`0000Cooooo1?l00007oooo
o`;o00004_ooool2o`0000Oooooo0_l00009ooooo`?o00000_ooool2o`0000Wooooo0_l0001Joooo
o`007?ooool00ol0003oooooooooo`1Dooooo`;o00000oooool4o`0000[ooooo0_l0000<ooooo`;o
00002_ooool2o`0000Kooooo1?l00005ooooo`;o00001_ooool6o`0000Cooooo0_l00004ooooo`?o
000000?oooooo`000?l000008_ooool2o`0000Wooooo0ol0000:ooooo`;o0000GOooool001cooooo
00?o0000ooooooooool0BOooool2o`0000Wooooo0_l00005ooooo`;o00002_ooool2o`0000cooooo
0_l0000:ooooo`Co00000oooool5o`0000Gooooo0_l0000Gooooo`;o000000?oooooo`000?l00000
1?ooool3o`0000Oooooo0_l0000Booooo`;o00002Oooool2o`0000_ooooo0_l0001Mooooo`007?oo
ool00ol0003oooooooooo`19ooooo`;o00002oooool2o`0001?ooooo0_l0000Fooooo`Wo00001ooo
ool2o`0000?ooooo0_l0000Jooooo`?o00001_ooool3o`0001[ooooo0_l000000ooooooo0000o`00
0004ooooo`;o00009?ooool2o`0003kooooo000Looooo`03o`000?oooooooooo05Kooooo0_l00006
ooooo`;o00002Oooool4o`0001Kooooo1Ol0000;ooooo`;o00000oooool2o`000004ooooool0003o
0000o`0000Cooooo1?l00004ooooo`;o00000_ooool4o`0000;ooooo0_l00007ooooo`;o00001ooo
ool2o`0000gooooo0_l00003ooooo`;o00001Oooool4o`0000;ooooo1?l0000Nooooo`;o0000?_oo
ool001cooooo00?o0000ooooooooool0G_ooool2o`0000Wooooo1_l0000Dooooo`;o000000?ooooo
o`000?l000002Oooool2o`0000;ooooo0_l00004ooooo`?o00001?ooool4o`0000Cooooo0_l00002
ooooo`Ko00004_ooool2o`0000[ooooo0_l000001?oooooo0000o`000?ooool2o`000004ooooool0
003o0000ooooo`;o000000Coooooo`000?l0003o00000oooool4o`0000?ooooo0_l0001Iooooo`00
7?ooool00ol0003oooooooooo`1=ooooo`;o00006_ooool6o`0001Oooooo0_l00008ooooo`?o0000
0_ooool4o`0001Sooooo0ol000000ooooooo0000o`000006ooooo`;o00001?ooool2o`0000gooooo
0_l00004ooooo`Go000000Coooooo`000?l0003ooooo0ol00002ooooo`;o00001_ooool2o`0005Wo
oooo000Looooo`03o`000?oooooooooo04gooooo0_l000001?oooooo0000o`000?ooool2o`0000So
oooo0_l0000:ooooo`Co00008oooool2o`0000?ooooo1?l0000Hooooo`;o00000_ooool3o`0000;o
oooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l0000>ooooo`;o00001Oooool2o`0000Go
oooo0_l00003ooooo`;o0000HOooool001cooooo00?o0000ooooooooool0D?ooool2o`000003oooo
ool0003o000000Sooooo0ol000000ooooooo0000o`000003ooooo`?o00000_ooool2o`0002Kooooo
0_l00009ooooo`Co00002oooool2o`0000Oooooo0_l00002ooooo`;o000000?oooooo`000?l00000
0_l0000Booooo`;o00002?ooool4o`0000_ooooo0_l0001Kooooo`007?ooool00ol0003ooooooooo
o`1@ooooo`;o00003?ooool2o`000003ooooool0003o000000?ooooo0ol0000Looooo`;o00002_oo
ool4o`0000Cooooo0_l00003ooooo`Co00002oooool2o`0000Wooooo1?l0000>ooooo`;o00004Ooo
ool4o`0000_ooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`1Looooo`;o00001oooool2
o`0001kooooo0_l0000:ooooo`;o00001?ooool4o`0000?ooooo0_l0000:ooooo`Go00000oooool2
o`0000?ooooo0ol00003ooooo`;o00002oooool2o`0000Cooooo0_l0000:ooooo`?o00001?ooool2
o`0006Cooooo000Looooo`03o`000?oooooooooo05;ooooo0_l00005ooooo`;o000000Coooooo`00
0?l0003o00001_ooool2o`0000Gooooo0_l000000ooooooo0000o`00000Fooooo`;o00003_ooool5
o`0000;ooooo0_l00003ooooo`;o00001?ooool4o`0000Gooooo0_l00003ooooo`;o00000oooool3
o`0000Sooooo0_l00007ooooo`;o00000oooool2o`0000Gooooo0ol00004ooooo`Co0000H_ooool0
01cooooo00?o0000ooooooooool0D_ooool2o`0000Gooooo0_l000001?oooooo0000o`000?l00003
ooooo`;o00002?ooool2o`000004ooooool0003o0000o`0001Gooooo0_l0000>ooooo`Go00001?oo
ool2o`000003ooooool0003o000000Cooooo1?l00005ooooo`;o00001_ooool5o`0000Cooooo0ol0
00000ooooooo0000o`000002ooooo`;o00002?ooool2o`0000?ooooo0_l00009ooooo`;o0000H_oo
ool001cooooo0_l0001Mooooo`;o00001?ooool2o`0000;ooooo0ol00003ooooo`;o00000_ooool2
o`0000kooooo0_l00002ooooo`;o00002Oooool2o`0000Kooooo1Ol00004ooooo`;o00002?ooool2
o`0000Kooooo0_l00006ooooo`Go00001?ooool3o`0000Gooooo0_l00003ooooo`;o00002?ooool2
o`0006gooooo000Looooo`03o`000?oooooooooo05cooooo0ol00007ooooo`Co00000_ooool2o`00
00Kooooo0_l0000:ooooo`;o00000_ooool2o`0000Wooooo0ol00002ooooo`;o00000oooool2o`00
00Gooooo0_l00008ooooo`;o00002?ooool2o`000003ooooool0003o000000;ooooo1?l00002oooo
o`;o00000oooool2o`0000Sooooo0_l0001gooooo`007?ooool00ol0003oooooooooo`1Mooooo`?o
00002?ooool2o`0000[ooooo1?l00003ooooo`;o00003oooool2o`000004ooooool0003o0000o`00
00;ooooo0_l0000:ooooo`;o00000_ooool2o`0000kooooo0_l000000ooooooo0000o`000004oooo
o`;o00000_ooool4o`000003ooooool0003o000000?o00000oooool2o`0000Cooooo0ol0001boooo
o`007?ooool00ol0003oooooooooo`1Fooooo`;o00001_ooool2o`0000oooooo0_l00005ooooo`;o
00000oooool2o`0000Wooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l00008oooo
o`;o000000?oooooo`000?l000000oooool2o`0000Kooooo0_l0000Eooooo`;o00000oooool3o`00
00?ooooo0_l00003ooooo`Co0000L_ooool001cooooo00?o0000ooooooooool0E?ooool4o`0000Ko
oooo0ol000000ooooooo0000o`000007ooooo`;o00000_ooool2o`0000Cooooo0_l0000:ooooo`;o
00000oooool2o`000003ooooool0003o000000Gooooo1?l00004ooooo`;o00000_ooool2o`000003
ooooool0003o000000Oooooo0_l00002ooooo`;o00001Oooool2o`0001kooooo0_l00003ooooo`;o
0000Koooool001cooooo00?o0000ooooooooool0E?ooool2o`0000;ooooo0_l000001?oooooo0000
o`000?ooool6o`0000Oooooo0_l00002ooooo`;o00000oooool4o`0000Wooooo0_l00006ooooo`;o
000000Goooooo`000?l0003o0000ooooo`02o`0000Kooooo0_l00005ooooo`;o00001oooool2o`00
00Sooooo0ol000000ooooooo0000o`00000Hooooo`;o00001Oooool3o`0000;ooooo0_l0001[oooo
o`007?ooool00ol0003oooooooooo`1Hooooo`;o000000?oooooo`000?l000001?ooool2o`0000Go
oooo0_l00005ooooo`;o00000oooool4o`0000oooooo0_l00003ooooo`?o00001?ooool2o`0001Ko
oooo0_l00005ooooo`;o00000_ooool2o`0000Sooooo0_l000000ooooooo0000o`000004ooooo`;o
00001Oooool2o`0000Gooooo0ol00002ooooo`;o0000Joooool001cooooo00?o0000ooooooooool0
G?ooool2o`0000;ooooo0_l00006ooooo`;o00000oooool2o`0000Gooooo0_l0000Aooooo`;o0000
2_ooool2o`0000Cooooo0_l00007ooooo`;o00001_ooool3o`0001?ooooo1Ol00003ooooo`?o0000
3?ooool5o`0006gooooo000Looooo`03o`000?oooooooooo05_ooooo0ol00002ooooo`;o00001_oo
ool2o`0000;ooooo0ol00005ooooo`;o00001_ooool2o`0000;ooooo0_l0000>ooooo`;o000000?o
ooooo`000?l000001?ooool2o`0000Oooooo0_l00006ooooo`;o000000?oooooo`000?l000000_l0
000@ooooo`;o00001Oooool3o`000004ooooool0003o0000o`0000Wooooo1?l0000?ooooo`;o0000
G?ooool001cooooo00?o0000ooooooooool0Foooool2o`0000[ooooo0_l00003ooooo`;o00003_oo
ool2o`0000;ooooo0_l0000=ooooo`?o000000?oooooo`000?l000006?ooool4o`0000Kooooo1?l0
0008ooooo`;o00001?ooool2o`000004ooooool0003o0000o`0000Cooooo0_l0000Fooooo`;o0000
G?ooool001cooooo00?o0000ooooooooool0Ioooool3o`0002Gooooo0_l0000@ooooo`Co00002_oo
ool2o`0000Kooooo1?l00008ooooo`;o000000Coooooo`000?l0003ooooo0_l00008ooooo`;o0000
00?oooooo`000?l00000LOooool001cooooo00?o0000ooooooooool0Ioooool3o`0003Oooooo1?l0
000:ooooo`;o00002Oooool2o`0000[ooooo0_l00006ooooo`;o00001_ooool2o`00077ooooo000L
ooooo`03o`000?oooooooooo06[ooooo0_l0000@ooooo`Co000000?oooooo`000?l000000_l0000D
ooooo`;o00004Oooool2o`000003ooooool0003o000000Wooooo1?l0000@ooooo`;o0000NOooool0
01cooooo00?o0000ooooooooool0I_ooool6o`00013ooooo1?l000000ooooooo0000o`000002o`00
00;ooooo0_l0000;ooooo`;o00000oooool2o`00017ooooo0ol0000=ooooo`;o00001_ooool2o`00
00?ooooo0_l0000Eooooo`;o00000oooool2o`0006;ooooo00001_ooooook^k^oc8b<_l0003o<S8b
onk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003ooooooooo
o`1Vooooo`Co00002?ooool2o`0000cooooo0ol00004ooooo`;o00002oooool2o`0001Cooooo1ol0
0004ooooo`;o00003Oooool2o`0000?ooooo0_l0000Eooooo`;o00000oooool2o`0006;ooooo0000
1_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ
8B401_ooool00ol0003oooooooooo`1Vooooo`?o00002Oooool2o`0000Wooooo0_l000001?oooooo
0000o`000?l0000:ooooo`;o00004Oooool6o`0000Cooooo0ol00002ooooo`;o00001?ooool3o`00
00cooooo0_l00023ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`1Wooooo`;o00003_ooool2o`00
00Cooooo0_l00002ooooo`;o00000_ooool2o`0000Kooooo0_l000000ooooooo0000o`00000>oooo
o`Ko00003?ooool6o`0000cooooo0_l00023ooooo`0000?oooooo`000?ooool00_ooool00ol0003o
ooooooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`0006;ooooo0_l0000Coooo
o`;o00003?ooool2o`0000Wooooo0_l0000Hooooo`;o000000?oooooo`000?l000000oooool4o`00
00Cooooo0_l00008ooooo`;o00002_ooool2o`0000;ooooo0_l0001cooooo`0000?oooooo`000?oo
ool00_ooool00ol0003oooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0
003oooooooooo`1Kooooo`;o00001Oooool2o`0001Cooooo0_l0000`ooooo`;o000000?oooooo`00
0?l000001?ooool2o`0000Gooooo0_l0000Dooooo`;o00000_ooool2o`0007?ooooo00000ooooooo
410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go410@okZj^_oooooo^[Zjoa0@4006oooo
o`03o`000?oooooooooo05_ooooo0_l0000Kooooo`;o00002oooool2o`00023ooooo1?l00003oooo
o`;o00002oooool2o`0000Wooooo0_l00021ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;
ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`1oooooo`;o00001?oo
ool2o`0001Gooooo0_l00003ooooo`Co00000_ooool4o`0000?ooooo0_l00006ooooo`;o00000ooo
ool7o`0000Cooooo0_l00021ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`1Uooooo`;o00002Oooool2o`0000go
oooo0ol0000Jooooo`;o00000oooool4o`0000Gooooo0_l00007ooooo`;o000000?oooooo`000?l0
00000_l000000ooooooo0000o`000005o`0008Oooooo000Looooo`03o`000?oooooooooo06Gooooo
0_l00009ooooo`?o00003Oooool2o`0000kooooo0_l0000Hooooo`;o00001_ooool3o`000003oooo
ool0003o000000;o000000Coooooo`000?l0003o0000Roooool001cooooo00?o0000ooooooooool0
LOooool2o`0000[ooooo0_l000000ooooooo0000o`000003ooooo`;o00002Oooool4o`0001;ooooo
0_l00006ooooo`;o00000_ooool2o`0000Cooooo0_l00002ooooo`Co00006oooool2o`0006cooooo
000Looooo`03o`000?oooooooooo07_ooooo1?l000000ooooooo0000o`000003ooooo`;o00002_oo
ool3o`0000_ooooo0_l00005ooooo`;o00001_ooool2o`000003ooooool0003o000000;ooooo0_l0
00000ooooooo0000o`000003ooooo`?o00006oooool2o`0006cooooo000Looooo`03o`000?oooooo
oooo07[ooooo1Ol000000ooooooo0000o`000002ooooo`?o00004?ooool2o`0000Kooooo0_l00005
ooooo`;o00002Oooool2o`0000;ooooo1Ol0002?ooooo`007?ooool00ol0003oooooooooo`1joooo
o`;o000000?oooooo`000?l000001Oooool3o`00013ooooo0_l00006ooooo`;o00001?ooool7o`00
00Cooooo1Ol000000ooooooo0000o`000002o`0008oooooo000Looooo`03o`000?oooooooooo07co
oooo0_l0000Qooooo`;o00001?ooool7o`0000Cooooo0_l000000ooooooo0000o`00002Dooooo`00
7?ooool00ol0003oooooooooo`1looooo`;o00004?ooool2o`000003ooooool0003o000000Wooooo
0_l000000ooooooo0000o`00000Jooooo`;o0000S?ooool001cooooo00?o0000ooooooooool0S_oo
ool2o`000003ooooool0003o000000Wooooo0_l0000<ooooo`;o00003oooool2o`0000;ooooo0_l0
0028ooooo`007?ooool00ol0003oooooooooo`2Cooooo`;o00005Oooool2o`0001?ooooo0_l00028
ooooo`007?ooool00ol0003oooooooooo`2Cooooo`;o00001?ooool3o`0002Oooooo0_l00024oooo
o`007?ooool00ol0003oooooooooo`2Iooooo`?o00009oooool2o`0008Cooooo000Looooo`;o0000
U_ooool4o`0000Wooooo0_l0002Uooooo`007?ooool00ol0003oooooooooo`2Eooooo`Co00002Ooo
ool2o`0000Cooooo0_l0002Oooooo`007?ooool00ol0003oooooooooo`2Hooooo`;o00002?ooool2
o`0000Cooooo0_l0002Oooooo`007?ooool00ol0003oooooooooo`2Hooooo`;o00002?ooool2o`00
00?ooooo0_l0002Pooooo`007?ooool00ol0003oooooooooo`2Qooooo`;o00001?ooool2o`000:3o
oooo000Looooo`03o`000?oooooooooo0:7ooooo0_l00006ooooo`;o0000W_ooool001cooooo00?o
0000ooooooooool0WOooool2o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o00006_oo
ool2o`0008;ooooo000Looooo`03o`000?oooooooooo09gooooo0_l00002ooooo`;o000000?ooooo
o`000?l000007oooool2o`0008;ooooo000Looooo`03o`000?oooooooooo0:Oooooo0_l0002Poooo
o`007?ooool00ol0003oooooooooo`25ooooo`;o00007?ooool2o`0000;ooooo0_l0002Pooooo`00
7?ooool00ol0003oooooooooo`25ooooo`;o00007?ooool2o`000:Cooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`2Cooooo`;o0000]?ooool001cooooo00?o0000ooooooooool0Toooool2o`000003
ooooool0003o00000;7ooooo000Looooo`03o`000?oooooooooo09Kooooo0_l0002aooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001;ooooo1?l000000ol@413ooooooooo
o`03ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo0ol0003ooooo
od[ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0
oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooo
oooo0?ooooooD_ooool001;ooooo00?oEEEEofIVI_l00000oooooomDooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00XOooool01?l@413o0000o`000?ooool2o`000003oa0@4?oo
oooooooo01Kooooo1?l000000ol@413oooooooooo`02ooooo`;o000000?o410@ooooooooool00ooo
ool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^08cooooo002Rooooo`05
o`000?ooooooooooooooool000002Oooool6o`0000cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`2<
ooooo`00X_ooool01Ol0003ooooooooooooooooo000001_ooooo00?o0000ooooooooool00_ooool5
o`0000?ooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@4100S?ooool00:;ooooo00Go0000
ooooooooooooooooo`000009ooooo`Ko00003?ooool00ol0003oooooooooo`02ooooo`04odA4A?oM
gMgoooooo`0000Cooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo0000
08cooooo002Rooooo`05o`000?n7QhOoooooojVYZOl000006oooool00ol0003oooooooooo`02oooo
o`04omgMgOmEEEGoooooo`0000Cooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooo
oooooooo000008cooooo002Qooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool06Ooo
ool00ol0003oooooooooo`03ooooo`03ogMgMoo<c<co000000Gooooo00?oMgMgolc<c?l000001?oo
ool01Ol@413ooooooooooooooooo410@08cooooo0032ooooo`03o`000?oooooooooo00?ooooo00?o
k^k^odA4A?l000001Oooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
S?ooool00<3ooooo00?oEEEEofIVI_l000001_ooool00omgMgOo0000ooooo`05ooooo`03ogMgMol0
003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP2<ooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1446) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.65047 .39027 Mdot
.66241 .38948 Mdot
.34378 .43719 Mdot
.5584 .58887 Mdot
.32623 .74868 Mdot
.38535 .43706 Mdot
.5289 .36629 Mdot
.52854 .34608 Mdot
.3362 .43562 Mdot
.67613 .35269 Mdot
.50862 .31399 Mdot
.56201 .70122 Mdot
.49831 .33639 Mdot
.58503 .62267 Mdot
.67736 .80959 Mdot
.62179 .62753 Mdot
.65248 .39174 Mdot
.31886 .64931 Mdot
.61481 .6185 Mdot
.3821 .41072 Mdot
.60405 .4364 Mdot
.58113 .61955 Mdot
.63849 .40941 Mdot
.58528 .62335 Mdot
.54728 .60664 Mdot
.63414 .41828 Mdot
.68928 .44304 Mdot
.53176 .63183 Mdot
.56562 .65957 Mdot
.51609 .31648 Mdot
.38674 .64523 Mdot
.5421 .83248 Mdot
.56586 .53499 Mdot
.53489 .77162 Mdot
.48511 .35469 Mdot
.72323 .60731 Mdot
.37244 .44567 Mdot
.51925 .33291 Mdot
.5132 .32541 Mdot
.5234 .35522 Mdot
.5233 .34441 Mdot
.65231 .42419 Mdot
.622 .25612 Mdot
.4316 .32481 Mdot
.53948 .67388 Mdot
.2234 .62687 Mdot
.67135 .64247 Mdot
.59103 .5969 Mdot
.64932 .45826 Mdot
.25842 .46201 Mdot
.40396 .29753 Mdot
.47546 .35852 Mdot
.35678 .40894 Mdot
.42104 .11859 Mdot
.48482 .33117 Mdot
.50056 .62951 Mdot
.36002 .43962 Mdot
.57208 .63126 Mdot
.58616 .6293 Mdot
.75729 .47956 Mdot
.51305 .60226 Mdot
.33065 .57536 Mdot
.66231 .37729 Mdot
.44639 .50575 Mdot
.35725 .42861 Mdot
.50639 .31704 Mdot
.67892 .41902 Mdot
.48306 .3372 Mdot
.5757 .52753 Mdot
.33795 .47653 Mdot
.58656 .58441 Mdot
.51078 .31629 Mdot
.60788 .43456 Mdot
.54942 .64438 Mdot
.23975 .45566 Mdot
.20172 .60054 Mdot
.37646 .58301 Mdot
.72944 .57539 Mdot
.75808 .47192 Mdot
.26054 .52607 Mdot
.53437 .65988 Mdot
.37542 .6957 Mdot
.20514 .59178 Mdot
.65336 .46568 Mdot
.60928 .58455 Mdot
.38895 .62163 Mdot
.54511 .64046 Mdot
.2767 .73429 Mdot
.53247 .56472 Mdot
.46794 .52987 Mdot
.33712 .45672 Mdot
.63098 .44286 Mdot
.55344 .59133 Mdot
.57239 .65671 Mdot
.78376 .48458 Mdot
.5947 .58637 Mdot
.5692 .60969 Mdot
.66362 .45644 Mdot
.47068 .35367 Mdot
.5079 .59418 Mdot
.37016 .50638 Mdot
.3951 .44955 Mdot
.52187 .59935 Mdot
.34685 .47537 Mdot
.6115 .43929 Mdot
.57184 .65599 Mdot
.5063 .32503 Mdot
.5335 .58525 Mdot
.45349 .21841 Mdot
.65478 .39656 Mdot
.54236 .65184 Mdot
.3535 .61199 Mdot
.69462 .51076 Mdot
.62986 .45081 Mdot
.44417 .31103 Mdot
.61346 .62696 Mdot
.56156 .61891 Mdot
.67947 .42443 Mdot
.39665 .45415 Mdot
.25381 .69357 Mdot
.67421 .44939 Mdot
.48313 .30483 Mdot
.6133 .45871 Mdot
.54163 .69911 Mdot
.35813 .42243 Mdot
.43841 .31536 Mdot
.51963 .2403 Mdot
.40855 .65766 Mdot
.54693 .63789 Mdot
.64617 .27251 Mdot
.39765 .42296 Mdot
.64756 .44427 Mdot
.48723 .33873 Mdot
.56271 .54324 Mdot
.66331 .41144 Mdot
.48728 .30857 Mdot
.31828 .60438 Mdot
.39447 .25997 Mdot
.6226 .40474 Mdot
.53741 .43043 Mdot
.46245 .34464 Mdot
.50209 .36651 Mdot
.75542 .69433 Mdot
.66989 .43891 Mdot
.35056 .59701 Mdot
.48862 .3451 Mdot
.44457 .6499 Mdot
.53071 .66735 Mdot
.35064 .68334 Mdot
.54617 .18665 Mdot
.52686 .75497 Mdot
.34539 .31505 Mdot
.34332 .60982 Mdot
.45784 .35334 Mdot
.56193 .60102 Mdot
.62504 .42218 Mdot
.63759 .41377 Mdot
.51344 .60214 Mdot
.5362 .60414 Mdot
.57686 .57048 Mdot
.60158 .61598 Mdot
.48583 .54136 Mdot
.55593 .55075 Mdot
.6777 .61924 Mdot
.62721 .4387 Mdot
.56279 .59206 Mdot
.35053 .41195 Mdot
.58044 .68399 Mdot
.52475 .33101 Mdot
.57488 .62435 Mdot
.55656 .59092 Mdot
.51421 .63886 Mdot
.48429 .36257 Mdot
.50646 .83079 Mdot
.6514 .51184 Mdot
.48088 .80708 Mdot
.55332 .48991 Mdot
.31804 .43851 Mdot
.54114 .63146 Mdot
.34185 .58121 Mdot
.75973 .60545 Mdot
.55948 .57745 Mdot
.14187 .3841 Mdot
.57569 .61037 Mdot
.39259 .79739 Mdot
.63249 .63127 Mdot
.50374 .79201 Mdot
.38825 .68584 Mdot
.54983 .61177 Mdot
.68097 .32526 Mdot
.55005 .35582 Mdot
.32572 .48746 Mdot
.51703 .34734 Mdot
.35843 .41169 Mdot
.34932 .43673 Mdot
.40115 .52356 Mdot
.57681 .70362 Mdot
.59804 .6742 Mdot
.55852 .55944 Mdot
.37688 .47887 Mdot
.6886 .41654 Mdot
.34804 .61568 Mdot
.64993 .37644 Mdot
.4558 .8523 Mdot
.26 .41906 Mdot
.53409 .332 Mdot
.31315 .6088 Mdot
.35869 .46846 Mdot
.33297 .45108 Mdot
.33973 .61418 Mdot
.5846 .65047 Mdot
.67047 .43579 Mdot
.66252 .75792 Mdot
.38389 .23336 Mdot
.87486 .48844 Mdot
.65691 .45987 Mdot
.65297 .29464 Mdot
.5298 .33664 Mdot
.36271 .45338 Mdot
.56333 .61615 Mdot
.57029 .64734 Mdot
.60267 .4229 Mdot
.5879 .58563 Mdot
.60603 .46876 Mdot
.55547 .61498 Mdot
.54424 .37033 Mdot
.37238 .571 Mdot
.40057 .52436 Mdot
.43948 .67976 Mdot
.62047 .45042 Mdot
.81138 .55721 Mdot
.32855 .44944 Mdot
.76526 .59281 Mdot
.49734 .31369 Mdot
.31568 .59016 Mdot
.33077 .42501 Mdot
.36082 .60746 Mdot
.5851 .56567 Mdot
.38249 .41634 Mdot
.36489 .5929 Mdot
.42958 .58531 Mdot
.56059 .68033 Mdot
.37416 .21199 Mdot
.51687 .35751 Mdot
.64853 .3824 Mdot
.53631 .57827 Mdot
.32985 .46034 Mdot
.53111 .54033 Mdot
.28504 .36881 Mdot
.46346 .25129 Mdot
.39741 .41926 Mdot
.39685 .5547 Mdot
.3167 .58216 Mdot
.3841 .32903 Mdot
.64325 .27612 Mdot
.65862 .38545 Mdot
.58464 .56915 Mdot
.55651 .82061 Mdot
.48803 .34452 Mdot
.5427 .57769 Mdot
.29992 .68934 Mdot
.47665 .34832 Mdot
.57019 .63199 Mdot
.47341 .3131 Mdot
.63829 .41354 Mdot
.75457 .44342 Mdot
.67893 .42978 Mdot
.5907 .58797 Mdot
.49784 .32536 Mdot
.3992 .45678 Mdot
.63721 .42404 Mdot
.59416 .64159 Mdot
.53354 .63009 Mdot
.42545 .54152 Mdot
.5701 .59478 Mdot
.47166 .818 Mdot
.55228 .61353 Mdot
.34914 .44852 Mdot
.52437 .64775 Mdot
.73916 .33698 Mdot
.3979 .52089 Mdot
.67709 .42796 Mdot
.3959 .41333 Mdot
.34584 .42981 Mdot
.21635 .5194 Mdot
.44824 .34993 Mdot
.59599 .66083 Mdot
.32403 .45184 Mdot
.49041 .69092 Mdot
.47391 .32349 Mdot
.52123 .58511 Mdot
.50543 .4151 Mdot
.27104 .43679 Mdot
.36647 .40846 Mdot
.48456 .63168 Mdot
.61326 .41801 Mdot
.54723 .59452 Mdot
.34127 .4666 Mdot
.57887 .71238 Mdot
.55349 .65995 Mdot
.62278 .22984 Mdot
.41441 .55351 Mdot
.46524 .34431 Mdot
.584 .689 Mdot
.55928 .56718 Mdot
.38266 .42003 Mdot
.61712 .44159 Mdot
.46809 .32951 Mdot
.64635 .42426 Mdot
.50636 .78589 Mdot
.38649 .2126 Mdot
.45798 .54994 Mdot
.37174 .58144 Mdot
.31538 .49868 Mdot
.51676 .79407 Mdot
.81507 .4574 Mdot
.7526 .66396 Mdot
.57733 .78212 Mdot
.359 .47541 Mdot
.28972 .48218 Mdot
.35318 .4331 Mdot
.52835 .61728 Mdot
.36189 .42466 Mdot
.57198 .8235 Mdot
.55866 .61327 Mdot
.37231 .43115 Mdot
.80207 .52472 Mdot
.55157 .59591 Mdot
.66112 .38552 Mdot
.43903 .83455 Mdot
.76081 .32835 Mdot
.50252 .26227 Mdot
.37236 .45917 Mdot
.68129 .73446 Mdot
.5695 .60746 Mdot
.52428 .64646 Mdot
.62122 .43293 Mdot
.55172 .5373 Mdot
.34758 .57509 Mdot
.31022 .6049 Mdot
.53102 .30677 Mdot
.36255 .54933 Mdot
.58106 .69089 Mdot
.63461 .42511 Mdot
.50968 .5262 Mdot
.22566 .50781 Mdot
.26429 .4594 Mdot
.53751 .32886 Mdot
.43804 .83338 Mdot
.57559 .39948 Mdot
.56695 .37498 Mdot
.35724 .37342 Mdot
.64675 .45349 Mdot
.53237 .83517 Mdot
.51802 .34376 Mdot
.32735 .23475 Mdot
.69693 .34973 Mdot
.5816 .64924 Mdot
.48231 .32214 Mdot
.4989 .57009 Mdot
.76855 .35018 Mdot
.27179 .29403 Mdot
.64583 .69848 Mdot
.53002 .56857 Mdot
.26168 .42868 Mdot
.57039 .6205 Mdot
.27798 .39312 Mdot
.54522 .61686 Mdot
.64705 .4281 Mdot
.67482 .35048 Mdot
.47386 .28191 Mdot
.64038 .49673 Mdot
.37579 .34042 Mdot
.34948 .60797 Mdot
.55549 .61781 Mdot
.58424 .64789 Mdot
.35271 .5738 Mdot
.63279 .40578 Mdot
.58435 .57747 Mdot
.81557 .54142 Mdot
.58421 .65644 Mdot
.52437 .33524 Mdot
.72401 .36292 Mdot
.64655 .57894 Mdot
.60738 .62724 Mdot
.6435 .47 Mdot
.53641 .34908 Mdot
.5007 .32711 Mdot
.62663 .66002 Mdot
.52051 .31665 Mdot
.57919 .60214 Mdot
.25071 .31827 Mdot
.63116 .39899 Mdot
.54996 .20582 Mdot
.66989 .41966 Mdot
.72243 .5602 Mdot
.47477 .35418 Mdot
.42236 .2525 Mdot
.49377 .58585 Mdot
.51439 .34218 Mdot
.68655 .4698 Mdot
.58172 .67233 Mdot
.58306 .67394 Mdot
.66458 .75144 Mdot
.34692 .45705 Mdot
.42008 .54182 Mdot
.51509 .31554 Mdot
.59311 .61743 Mdot
.60885 .60911 Mdot
.53513 .3497 Mdot
.30766 .28419 Mdot
.77777 .40161 Mdot
.55473 .61367 Mdot
.64546 .4352 Mdot
.65182 .44192 Mdot
.53099 .67306 Mdot
.5255 .59825 Mdot
.34878 .41719 Mdot
.40477 .4451 Mdot
.31412 .43721 Mdot
.41362 .54534 Mdot
.44739 .24751 Mdot
.28299 .71268 Mdot
.5225 .35585 Mdot
.62597 .29882 Mdot
.4516 .54738 Mdot
.53839 .55932 Mdot
.37758 .45945 Mdot
.5625 .56871 Mdot
.5731 .58583 Mdot
.44304 .36282 Mdot
.34115 .74829 Mdot
.59245 .37633 Mdot
.61615 .44523 Mdot
.46308 .35617 Mdot
.59655 .68411 Mdot
.49946 .39446 Mdot
.32099 .58617 Mdot
.53294 .74573 Mdot
.50117 .31315 Mdot
.66888 .39187 Mdot
.50205 .35867 Mdot
.56942 .65036 Mdot
.50366 .57759 Mdot
.64977 .45144 Mdot
.33269 .57119 Mdot
.57 .54003 Mdot
.56727 .62966 Mdot
.5039 .17068 Mdot
.47599 .69816 Mdot
.56265 .35795 Mdot
.55264 .61118 Mdot
.59225 .65807 Mdot
.30384 .58599 Mdot
.58171 .65614 Mdot
.54938 .56276 Mdot
.69066 .51919 Mdot
.55664 .27722 Mdot
.32851 .62078 Mdot
.26467 .31211 Mdot
.65788 .45877 Mdot
.54076 .82021 Mdot
.3831 .45026 Mdot
.50005 .28579 Mdot
.76229 .38938 Mdot
.34353 .41015 Mdot
.33723 .32209 Mdot
.52902 .81973 Mdot
.38005 .50448 Mdot
.30933 .42216 Mdot
.67747 .38371 Mdot
.59632 .60482 Mdot
.56256 .62238 Mdot
.34453 .58004 Mdot
.66852 .43417 Mdot
.50155 .48596 Mdot
.17552 .50716 Mdot
.57929 .61801 Mdot
.60871 .22582 Mdot
.25019 .3605 Mdot
.26374 .44421 Mdot
.33506 .58992 Mdot
.30746 .60331 Mdot
.55553 .6198 Mdot
.67951 .50875 Mdot
.63347 .41904 Mdot
.59425 .64023 Mdot
.55275 .55089 Mdot
.35728 .46006 Mdot
.65254 .39971 Mdot
.39733 .45276 Mdot
.39194 .29487 Mdot
.46312 .8058 Mdot
.31398 .2238 Mdot
.47512 .33646 Mdot
.23178 .43159 Mdot
.47151 .31881 Mdot
.38259 .69809 Mdot
.34652 .4052 Mdot
.54062 .59244 Mdot
.61555 .43276 Mdot
.59064 .60825 Mdot
.52855 .59666 Mdot
.58573 .64914 Mdot
.60697 .61765 Mdot
.34762 .19437 Mdot
.35166 .60878 Mdot
.59232 .56642 Mdot
.34602 .44431 Mdot
.21475 .59904 Mdot
.19794 .54517 Mdot
.5845 .64487 Mdot
.5405 .62324 Mdot
.64828 .40515 Mdot
.52173 .59025 Mdot
.47016 .32206 Mdot
.66438 .38259 Mdot
.55473 .6498 Mdot
.37072 .80833 Mdot
.56222 .65954 Mdot
.50194 .80165 Mdot
.50293 .35776 Mdot
.40143 .22439 Mdot
.50996 .56764 Mdot
.47363 .25491 Mdot
.42022 .54193 Mdot
.33308 .42175 Mdot
.46151 .32143 Mdot
.37328 .44327 Mdot
.17722 .47498 Mdot
.50465 .66043 Mdot
.55852 .60194 Mdot
.5478 .55736 Mdot
.31791 .43912 Mdot
.30627 .77303 Mdot
.39729 .3432 Mdot
.50231 .65994 Mdot
.35389 .41419 Mdot
.68047 .45371 Mdot
.58803 .75971 Mdot
.66016 .42261 Mdot
.35022 .55647 Mdot
.52851 .3393 Mdot
.33417 .57177 Mdot
.41424 .75232 Mdot
.65796 .39475 Mdot
.60781 .39734 Mdot
.38032 .45105 Mdot
.68645 .36657 Mdot
.72165 .22691 Mdot
.69692 .3481 Mdot
.41016 .68078 Mdot
.62725 .4277 Mdot
.56917 .65921 Mdot
.38837 .7225 Mdot
.68923 .35018 Mdot
.37186 .4408 Mdot
.56924 .57693 Mdot
.75796 .43614 Mdot
.34758 .4172 Mdot
.51789 .56916 Mdot
.343 .44761 Mdot
.51424 .35112 Mdot
.36962 .46334 Mdot
.59815 .43057 Mdot
.53999 .64275 Mdot
.74324 .23573 Mdot
.37306 .54837 Mdot
.56649 .60541 Mdot
.4757 .36485 Mdot
.32829 .29612 Mdot
.54776 .58292 Mdot
.36841 .58594 Mdot
.37449 .42534 Mdot
.69206 .38072 Mdot
.55091 .61508 Mdot
.35475 .41375 Mdot
.63824 .38985 Mdot
.46589 .36583 Mdot
.78035 .4809 Mdot
.54684 .30065 Mdot
.62052 .4371 Mdot
.57228 .46854 Mdot
.44878 .33017 Mdot
.59472 .65614 Mdot
.59403 .58418 Mdot
.64914 .43673 Mdot
.30281 .65912 Mdot
.5163 .62069 Mdot
.52863 .65289 Mdot
.35623 .45647 Mdot
.37725 .44046 Mdot
.74444 .66678 Mdot
.38932 .46339 Mdot
.5124 .56812 Mdot
.65118 .43515 Mdot
.55482 .58946 Mdot
.64674 .40171 Mdot
.52255 .5898 Mdot
.63905 .62678 Mdot
.63203 .40628 Mdot
.45117 .36858 Mdot
.57016 .57999 Mdot
.5902 .5459 Mdot
.53688 .58297 Mdot
.59901 .61416 Mdot
.34902 .41926 Mdot
.33638 .5835 Mdot
.54449 .55416 Mdot
.35543 .62533 Mdot
.33987 .61673 Mdot
.49014 .26998 Mdot
.35414 .46002 Mdot
.35628 .59619 Mdot
.21859 .38503 Mdot
.3724 .41304 Mdot
.34895 .57984 Mdot
.19818 .54825 Mdot
.48413 .35557 Mdot
.61194 .41913 Mdot
.54846 .59762 Mdot
.47704 .76626 Mdot
.66907 .62732 Mdot
.37418 .39427 Mdot
.55632 .61121 Mdot
.54656 .57616 Mdot
.67596 .45089 Mdot
.16484 .55303 Mdot
.33502 .4742 Mdot
.57209 .66424 Mdot
.66511 .39407 Mdot
.15786 .59516 Mdot
.35099 .44338 Mdot
.34453 .57748 Mdot
.49317 .36139 Mdot
.69423 .42003 Mdot
.51221 .23439 Mdot
.49827 .36988 Mdot
.41936 .44039 Mdot
.40216 .29126 Mdot
.60924 .5984 Mdot
.39007 .45023 Mdot
.84132 .57431 Mdot
.47962 .55388 Mdot
.43788 .51731 Mdot
.66266 .7409 Mdot
.63775 .45259 Mdot
.47134 .31969 Mdot
.34343 .61059 Mdot
.64911 .46182 Mdot
.65088 .39228 Mdot
.53188 .35184 Mdot
.6544 .52238 Mdot
.50184 .41285 Mdot
.51823 .3279 Mdot
.49266 .73915 Mdot
.27139 .65843 Mdot
.38359 .45555 Mdot
.34895 .57558 Mdot
.39662 .75552 Mdot
.64969 .42301 Mdot
.48313 .85403 Mdot
.67919 .74936 Mdot
.56944 .60959 Mdot
.3484 .60342 Mdot
.30463 .76182 Mdot
.1781 .57422 Mdot
.47463 .3482 Mdot
.49244 .27741 Mdot
.32242 .57644 Mdot
.53909 .5764 Mdot
.51125 .72213 Mdot
.52271 .62879 Mdot
.52677 .34601 Mdot
.78592 .51363 Mdot
.65579 .39291 Mdot
.5155 .36293 Mdot
.55303 .75581 Mdot
.58021 .60453 Mdot
.56727 .57832 Mdot
.45525 .7113 Mdot
.64594 .46363 Mdot
.33184 .4224 Mdot
.59644 .58196 Mdot
.57023 .6275 Mdot
.5053 .57977 Mdot
.53114 .67741 Mdot
.71932 .48848 Mdot
.53229 .61717 Mdot
.23236 .45434 Mdot
.53108 .57096 Mdot
.58204 .59365 Mdot
.63485 .46766 Mdot
.28118 .24619 Mdot
.39755 .30851 Mdot
.57298 .62491 Mdot
.58615 .662 Mdot
.51117 .36313 Mdot
.47596 .40293 Mdot
.64694 .35671 Mdot
.69139 .38321 Mdot
.71781 .70442 Mdot
.56422 .68067 Mdot
.67757 .41603 Mdot
.36587 .58594 Mdot
.59546 .66008 Mdot
.67354 .40293 Mdot
.51857 .64756 Mdot
.34288 .41718 Mdot
.36875 .41237 Mdot
.52417 .52312 Mdot
.35867 .59503 Mdot
.71083 .31617 Mdot
.62239 .29766 Mdot
.37944 .41687 Mdot
.55489 .60309 Mdot
.55046 .3628 Mdot
.3373 .46127 Mdot
.36867 .51202 Mdot
.30579 .68128 Mdot
.62323 .42137 Mdot
.62765 .44179 Mdot
.34553 .68426 Mdot
.36344 .299 Mdot
.61759 .21561 Mdot
.51629 .35111 Mdot
.58091 .55757 Mdot
.67274 .30652 Mdot
.6263 .44453 Mdot
.38981 .71112 Mdot
.3524 .60226 Mdot
.47777 .34887 Mdot
.4063 .3694 Mdot
.65766 .4109 Mdot
.62318 .39353 Mdot
.50972 .60743 Mdot
.56933 .6384 Mdot
.76415 .64496 Mdot
.34565 .6294 Mdot
.52462 .36808 Mdot
.34565 .57537 Mdot
.35348 .40404 Mdot
.52855 .63729 Mdot
.63389 .40817 Mdot
.26682 .66542 Mdot
.60815 .64296 Mdot
.33554 .4292 Mdot
.63391 .44929 Mdot
.31452 .58416 Mdot
.36767 .57869 Mdot
.60288 .62253 Mdot
.78379 .59848 Mdot
.51702 .33506 Mdot
.65969 .45094 Mdot
.55808 .38197 Mdot
.52045 .62223 Mdot
.56127 .63477 Mdot
.62321 .57899 Mdot
.5222 .36879 Mdot
.58947 .34559 Mdot
.37025 .59424 Mdot
.66333 .44026 Mdot
.53498 .61883 Mdot
.35494 .58083 Mdot
.63722 .30077 Mdot
.38478 .40455 Mdot
.36555 .46506 Mdot
.3651 .5753 Mdot
.33416 .59833 Mdot
.3682 .59611 Mdot
.48591 .85556 Mdot
.6849 .42619 Mdot
.57259 .40496 Mdot
.56303 .66922 Mdot
.39579 .68286 Mdot
.58784 .55984 Mdot
.46263 .33879 Mdot
.34355 .45472 Mdot
.53881 .58748 Mdot
.60544 .6346 Mdot
.63408 .61919 Mdot
.57527 .20961 Mdot
.62236 .53601 Mdot
.6511 .39671 Mdot
.50293 .57743 Mdot
.37184 .45818 Mdot
.48382 .8693 Mdot
.70354 .74892 Mdot
.50668 .57135 Mdot
.50927 .41035 Mdot
.62671 .41039 Mdot
.5237 .35586 Mdot
.44873 .73463 Mdot
.48798 .35762 Mdot
.65789 .44379 Mdot
.52949 .6217 Mdot
.61816 .31563 Mdot
.29815 .59711 Mdot
.59481 .6152 Mdot
.51866 .3532 Mdot
.58679 .58576 Mdot
.51546 .36951 Mdot
.47325 .77395 Mdot
.82737 .57869 Mdot
.57478 .61067 Mdot
.61744 .61259 Mdot
.78569 .62256 Mdot
.58864 .64047 Mdot
.3012 .63619 Mdot
.62598 .41074 Mdot
.79113 .51257 Mdot
.61336 .65805 Mdot
.54956 .72975 Mdot
.52147 .63199 Mdot
.79085 .47765 Mdot
.56248 .63808 Mdot
.26078 .44451 Mdot
.53989 .64855 Mdot
.55214 .56116 Mdot
.4854 .32867 Mdot
.51271 .3639 Mdot
.61397 .45202 Mdot
.33818 .46924 Mdot
.49479 .80574 Mdot
.56444 .631 Mdot
.43314 .25569 Mdot
.57113 .30348 Mdot
.33358 .59549 Mdot
.66085 .43979 Mdot
.1788 .6262 Mdot
.49809 .30679 Mdot
.74596 .69687 Mdot
.71065 .70143 Mdot
.55755 .25333 Mdot
.34639 .7384 Mdot
.29408 .32213 Mdot
.31679 .58488 Mdot
.51337 .63523 Mdot
.29314 .55747 Mdot
.25813 .44445 Mdot
.29557 .65962 Mdot
.45631 .32462 Mdot
.75893 .61976 Mdot
.30613 .70882 Mdot
.35489 .56229 Mdot
.30689 .59372 Mdot
.48174 .36293 Mdot
.29713 .44342 Mdot
.56766 .70387 Mdot
.34103 .60642 Mdot
.3164 .44125 Mdot
.37672 .41094 Mdot
.31575 .45024 Mdot
.63406 .41605 Mdot
.70817 .73985 Mdot
.45598 .31598 Mdot
.46511 .33967 Mdot
.29236 .45574 Mdot
.60252 .72636 Mdot
.63305 .37757 Mdot
.37028 .4517 Mdot
.37735 .46662 Mdot
.62325 .41053 Mdot
.50299 .63178 Mdot
.51746 .67273 Mdot
.57652 .62134 Mdot
.34082 .58262 Mdot
.56779 .64252 Mdot
.35979 .41555 Mdot
.47554 .34066 Mdot
.36506 .46921 Mdot
.48304 .36843 Mdot
.25985 .67092 Mdot
.59811 .63968 Mdot
.53793 .64288 Mdot
.45605 .17288 Mdot
.60883 .40926 Mdot
.22536 .61671 Mdot
.49117 .38424 Mdot
.35203 .43457 Mdot
.54923 .56342 Mdot
.651 .37365 Mdot
.31642 .6271 Mdot
.31814 .22619 Mdot
.52048 .6043 Mdot
.6481 .4143 Mdot
.52888 .63306 Mdot
.45461 .5853 Mdot
.68858 .2583 Mdot
.65413 .42895 Mdot
.58572 .20271 Mdot
.57244 .66204 Mdot
.22683 .39333 Mdot
.52722 .57725 Mdot
.43313 .59231 Mdot
.51636 .62055 Mdot
.65921 .45847 Mdot
.57697 .62615 Mdot
.6555 .37622 Mdot
.38928 .42511 Mdot
.51227 .36088 Mdot
.62194 .43715 Mdot
.60184 .60326 Mdot
.60591 .10119 Mdot
.50198 .35212 Mdot
.55973 .61692 Mdot
.48246 .36043 Mdot
.67194 .42818 Mdot
.6451 .45827 Mdot
.18478 .54415 Mdot
.3885 .29741 Mdot
.51208 .35081 Mdot
.52864 .63622 Mdot
.24576 .3958 Mdot
.53585 .60016 Mdot
.49765 .70115 Mdot
.50017 .62655 Mdot
.53413 .66334 Mdot
.19656 .57097 Mdot
.46505 .34633 Mdot
.6156 .21261 Mdot
.18782 .57778 Mdot
.21299 .59621 Mdot
.6035 .43717 Mdot
.3541 .56401 Mdot
.52288 .83375 Mdot
.45185 .24731 Mdot
.34022 .41578 Mdot
.54161 .58406 Mdot
.66052 .48604 Mdot
.51381 .33058 Mdot
.32447 .58561 Mdot
.57384 .61122 Mdot
.37761 .46418 Mdot
.80178 .4356 Mdot
.45911 .3539 Mdot
.65661 .42607 Mdot
.67524 .45708 Mdot
.1911 .38118 Mdot
.54605 .61363 Mdot
.54381 .64606 Mdot
.52876 .33981 Mdot
.31143 .29765 Mdot
.32195 .61293 Mdot
.80193 .51914 Mdot
.50945 .3502 Mdot
.4963 .46565 Mdot
.6746 .40218 Mdot
.54859 .57297 Mdot
.37372 .79809 Mdot
.38576 .36275 Mdot
.49407 .1824 Mdot
.34297 .5822 Mdot
.48969 .69252 Mdot
.65964 .45767 Mdot
.48807 .34101 Mdot
.36709 .27904 Mdot
.57741 .6772 Mdot
.57089 .57261 Mdot
.44871 .63117 Mdot
.47902 .27542 Mdot
.64226 .36194 Mdot
.52065 .60836 Mdot
.4195 .53941 Mdot
.52208 .59744 Mdot
.62442 .61046 Mdot
.49622 .62431 Mdot
.55148 .6351 Mdot
.63967 .40924 Mdot
.49019 .66975 Mdot
.32202 .43695 Mdot
.59286 .38284 Mdot
.48522 .47135 Mdot
.56231 .60906 Mdot
.53302 .65556 Mdot
.65578 .68014 Mdot
.31229 .3357 Mdot
.62355 .43578 Mdot
.59909 .40941 Mdot
.50761 .3092 Mdot
.51129 .65888 Mdot
.34016 .47037 Mdot
.57888 .54771 Mdot
.34571 .42133 Mdot
.6365 .40913 Mdot
.35208 .43793 Mdot
.4961 .364 Mdot
.39356 .44403 Mdot
.4413 .24798 Mdot
.4894 .34926 Mdot
.62036 .42714 Mdot
.55423 .64656 Mdot
.4749 .36487 Mdot
.42441 .65952 Mdot
.34288 .58375 Mdot
.23563 .70715 Mdot
.55468 .65035 Mdot
.53857 .25901 Mdot
.611 .69897 Mdot
.37102 .46852 Mdot
.67213 .24342 Mdot
.61371 .43584 Mdot
.31757 .61685 Mdot
.63704 .46319 Mdot
.5368 .74427 Mdot
.34177 .59575 Mdot
.21721 .66288 Mdot
.42036 .56517 Mdot
.47719 .69622 Mdot
.5135 .65699 Mdot
.45635 .69652 Mdot
.36533 .40583 Mdot
.51133 .33011 Mdot
.35602 .29425 Mdot
.55539 .56253 Mdot
.83256 .46916 Mdot
.64135 .4674 Mdot
.331 .46008 Mdot
.4863 .33699 Mdot
.46502 .3332 Mdot
.57942 .6682 Mdot
.26461 .49658 Mdot
.57083 .57084 Mdot
.38 .28618 Mdot
.68061 .7326 Mdot
.57625 .42201 Mdot
.55595 .61505 Mdot
.38376 .42062 Mdot
.52883 .63268 Mdot
.37161 .59166 Mdot
.7783 .66822 Mdot
.58289 .54338 Mdot
.53558 .37894 Mdot
.3323 .63311 Mdot
.6711 .44061 Mdot
.63314 .66615 Mdot
.56428 .34762 Mdot
.54306 .61351 Mdot
.29983 .20273 Mdot
.35191 .58077 Mdot
.29885 .54918 Mdot
.61003 .62906 Mdot
.60055 .65681 Mdot
.43272 .50093 Mdot
.50931 .2275 Mdot
.30271 .3867 Mdot
.58923 .63092 Mdot
.41874 .63571 Mdot
.46954 .35679 Mdot
.53343 .58214 Mdot
.56082 .62114 Mdot
.67137 .56781 Mdot
.45957 .34607 Mdot
.34122 .43413 Mdot
.34123 .41031 Mdot
.38345 .39689 Mdot
.36524 .60674 Mdot
.62768 .35495 Mdot
.40432 .70217 Mdot
.77987 .37954 Mdot
.30424 .6076 Mdot
.60268 .64125 Mdot
.33828 .51978 Mdot
.52615 .62565 Mdot
.32511 .58959 Mdot
.45935 .34792 Mdot
.62405 .44486 Mdot
.66567 .30724 Mdot
.35069 .41017 Mdot
.58615 .67716 Mdot
.32839 .61764 Mdot
.62527 .42148 Mdot
.42088 .74131 Mdot
.67049 .4401 Mdot
.51035 .34362 Mdot
.63416 .3528 Mdot
.32232 .58878 Mdot
.67355 .41975 Mdot
.54358 .38242 Mdot
.17701 .55165 Mdot
.49806 .64236 Mdot
.64808 .33482 Mdot
.6737 .44155 Mdot
.60292 .3997 Mdot
.68211 .42626 Mdot
.59136 .59527 Mdot
.50964 .41131 Mdot
.53472 .66877 Mdot
.46559 .35037 Mdot
.34172 .4442 Mdot
.82535 .54958 Mdot
.42678 .31576 Mdot
.55838 .43764 Mdot
.54767 .54731 Mdot
.58115 .60545 Mdot
.55598 .61968 Mdot
.62385 .62602 Mdot
.44724 .24341 Mdot
.58624 .59208 Mdot
.48606 .32797 Mdot
.37001 .42163 Mdot
.51442 .63861 Mdot
.41504 .4279 Mdot
.2101 .57076 Mdot
.32511 .57271 Mdot
.54447 .32481 Mdot
.75639 .71054 Mdot
.62465 .42414 Mdot
.39838 .41808 Mdot
.3708 .41684 Mdot
.31563 .60065 Mdot
.52106 .33488 Mdot
.67276 .4368 Mdot
.48347 .6812 Mdot
.34155 .61634 Mdot
.57451 .62709 Mdot
.52831 .40198 Mdot
.83935 .49745 Mdot
.51176 .6246 Mdot
.55138 .58532 Mdot
.31578 .45397 Mdot
.30714 .5447 Mdot
.81909 .34618 Mdot
.42489 .71251 Mdot
.33055 .58352 Mdot
.34712 .56604 Mdot
.62311 .40643 Mdot
.59683 .66994 Mdot
.48421 .36597 Mdot
.7115 .37247 Mdot
.57836 .36008 Mdot
.67576 .27951 Mdot
.46997 .18759 Mdot
.52777 .59291 Mdot
.29264 .29955 Mdot
.57883 .5981 Mdot
.68441 .42926 Mdot
.64067 .41309 Mdot
.63725 .43043 Mdot
.51173 .33104 Mdot
.7352 .60414 Mdot
.49731 .32441 Mdot
.82982 .62237 Mdot
.6544 .45714 Mdot
.41643 .56698 Mdot
.36894 .45582 Mdot
.50612 .66651 Mdot
.32074 .57819 Mdot
.65054 .34344 Mdot
.57671 .52764 Mdot
.67505 .50014 Mdot
.32573 .45296 Mdot
.61905 .43205 Mdot
.30636 .30587 Mdot
.60817 .79208 Mdot
.67311 .36487 Mdot
.62513 .57411 Mdot
.44901 .73634 Mdot
.3313 .59255 Mdot
.49131 .18256 Mdot
.33522 .5734 Mdot
.51716 .35403 Mdot
.53559 .63571 Mdot
.54502 .63972 Mdot
.52125 .59771 Mdot
.59189 .645 Mdot
.44607 .33173 Mdot
.57217 .55825 Mdot
.73933 .3378 Mdot
.34589 .4112 Mdot
.39672 .62187 Mdot
.33974 .57453 Mdot
.45772 .33237 Mdot
.3689 .42045 Mdot
.32041 .33008 Mdot
.43573 .6783 Mdot
.55269 .61476 Mdot
.53924 .58656 Mdot
.77114 .66115 Mdot
.52099 .60903 Mdot
.54083 .7021 Mdot
.34807 .41407 Mdot
.6473 .60199 Mdot
.32536 .57308 Mdot
.33707 .56601 Mdot
.48732 .35006 Mdot
.64073 .4107 Mdot
.35361 .58776 Mdot
.36349 .45699 Mdot
.54483 .54743 Mdot
.58595 .56982 Mdot
.67108 .44489 Mdot
.77914 .6573 Mdot
.37119 .57888 Mdot
.2438 .39228 Mdot
.61786 .42508 Mdot
.6368 .47277 Mdot
.5691 .57163 Mdot
.52183 .18793 Mdot
.6058 .4532 Mdot
.33566 .6242 Mdot
.45709 .33011 Mdot
.46033 .73154 Mdot
.49299 .30837 Mdot
.65843 .42475 Mdot
.55947 .66179 Mdot
.63081 .41306 Mdot
.55063 .61266 Mdot
.64006 .79886 Mdot
.55046 .63876 Mdot
.77312 .36642 Mdot
.34096 .67598 Mdot
.38713 .43799 Mdot
.30709 .33187 Mdot
.38266 .45032 Mdot
.61912 .44597 Mdot
.6119 .63411 Mdot
.31086 .6012 Mdot
.20509 .50114 Mdot
.72145 .41987 Mdot
.3361 .45599 Mdot
.35854 .4817 Mdot
.48251 .30885 Mdot
.51531 .6222 Mdot
.57692 .5773 Mdot
.37417 .43344 Mdot
.5946 .45078 Mdot
.66418 .41395 Mdot
.53705 .62485 Mdot
.58313 .60448 Mdot
.38632 .44216 Mdot
.17237 .53736 Mdot
.47394 .6115 Mdot
.54019 .63242 Mdot
.33349 .37089 Mdot
.46406 .33694 Mdot
.50698 .66627 Mdot
.61467 .60348 Mdot
.33425 .60114 Mdot
.74366 .48007 Mdot
.61886 .76821 Mdot
.4588 .34904 Mdot
.3628 .41327 Mdot
.54055 .61592 Mdot
.38161 .41922 Mdot
.57654 .56059 Mdot
.5203 .23141 Mdot
.39529 .41665 Mdot
.53395 .65994 Mdot
.50532 .63505 Mdot
.64962 .46392 Mdot
.53294 .58943 Mdot
.67507 .6866 Mdot
.32916 .43537 Mdot
.5776 .6675 Mdot
.79508 .5635 Mdot
.51396 .32159 Mdot
.52707 .6748 Mdot
.34629 .61352 Mdot
.52105 .72142 Mdot
.6052 .29973 Mdot
.36519 .75968 Mdot
.3286 .56767 Mdot
.58759 .58867 Mdot
.34816 .47922 Mdot
.52598 .36701 Mdot
.76027 .33234 Mdot
.54208 .57393 Mdot
.52338 .34979 Mdot
.47587 .34149 Mdot
.32345 .584 Mdot
.25872 .26412 Mdot
.60862 .62695 Mdot
.58194 .64569 Mdot
.70463 .61159 Mdot
.61891 .39335 Mdot
.56053 .64252 Mdot
.57707 .6586 Mdot
.4807 .33009 Mdot
.57282 .69728 Mdot
.71489 .68223 Mdot
.79798 .49498 Mdot
.53764 .3494 Mdot
.69625 .32032 Mdot
.38839 .41156 Mdot
.35707 .57704 Mdot
.64497 .44987 Mdot
.32144 .61409 Mdot
.36359 .46204 Mdot
.57084 .65682 Mdot
.52993 .34677 Mdot
.67374 .67217 Mdot
.4838 .36385 Mdot
.30519 .69913 Mdot
.65745 .38071 Mdot
.46847 .30093 Mdot
.27911 .22449 Mdot
.34262 .35299 Mdot
.47292 .27059 Mdot
.33382 .59595 Mdot
.35111 .49932 Mdot
.58232 .60292 Mdot
.47695 .17962 Mdot
.60051 .64401 Mdot
.79218 .54172 Mdot
.33873 .41432 Mdot
.31356 .44067 Mdot
.53719 .63319 Mdot
.66686 .73675 Mdot
.53118 .36479 Mdot
.47629 .32235 Mdot
.54589 .66476 Mdot
.51456 .34274 Mdot
.57376 .63997 Mdot
.35708 .41692 Mdot
.5229 .16647 Mdot
.57407 .61708 Mdot
.60972 .57758 Mdot
.53727 .24548 Mdot
.1948 .58156 Mdot
.38825 .59854 Mdot
.16367 .44417 Mdot
.64733 .78453 Mdot
.51368 .34133 Mdot
.54745 .67132 Mdot
.69255 .31266 Mdot
.32804 .46841 Mdot
.56229 .37592 Mdot
.56697 .65208 Mdot
.58934 .65452 Mdot
.5456 .56133 Mdot
.56369 .57951 Mdot
.36313 .20972 Mdot
.72309 .40022 Mdot
.7331 .53019 Mdot
.52918 .59463 Mdot
.44505 .6724 Mdot
.49921 .35629 Mdot
.68357 .4639 Mdot
.31505 .619 Mdot
.52932 .59152 Mdot
.63748 .36606 Mdot
.53364 .33685 Mdot
.84633 .5978 Mdot
.52629 .34883 Mdot
.34711 .42951 Mdot
.50907 .36657 Mdot
.56977 .59611 Mdot
.65135 .44179 Mdot
.4408 .45365 Mdot
.38859 .32711 Mdot
.32966 .42026 Mdot
.566 .60575 Mdot
.40518 .57199 Mdot
.32182 .44092 Mdot
.21911 .61507 Mdot
.64224 .44524 Mdot
.41222 .63294 Mdot
.63451 .41164 Mdot
.55351 .66439 Mdot
.55282 .66357 Mdot
.51335 .30818 Mdot
.50031 .3652 Mdot
.63608 .41125 Mdot
.19701 .32028 Mdot
.37025 .58909 Mdot
.64044 .42932 Mdot
.61299 .66441 Mdot
.47993 .42147 Mdot
.64692 .4401 Mdot
.29285 .61702 Mdot
.47638 .3365 Mdot
.61303 .40989 Mdot
.52742 .57045 Mdot
.49672 .73801 Mdot
.36378 .57647 Mdot
.33314 .41011 Mdot
.39549 .72831 Mdot
.33071 .44811 Mdot
.45979 .32323 Mdot
.38537 .44743 Mdot
.46717 .34074 Mdot
.59339 .31372 Mdot
.58805 .39148 Mdot
.38941 .50634 Mdot
.45828 .31902 Mdot
.37984 .4511 Mdot
.53261 .63472 Mdot
.37716 .55453 Mdot
.60663 .66031 Mdot
.59092 .58471 Mdot
.47591 .3271 Mdot
.64561 .46151 Mdot
.60134 .43023 Mdot
.4787 .69057 Mdot
.64454 .40836 Mdot
.33389 .43295 Mdot
.71459 .46708 Mdot
.43399 .26736 Mdot
.49516 .3103 Mdot
.50887 .36246 Mdot
.52415 .61956 Mdot
.37287 .44267 Mdot
.32188 .42606 Mdot
.49256 .30754 Mdot
.55913 .21283 Mdot
.61945 .61147 Mdot
.59857 .40488 Mdot
.61925 .39526 Mdot
.6533 .4316 Mdot
.68218 .41265 Mdot
.55025 .72632 Mdot
.47931 .35275 Mdot
.63672 .46038 Mdot
.52336 .61878 Mdot
.57844 .65595 Mdot
.70648 .35723 Mdot
.36352 .58531 Mdot
.51911 .65142 Mdot
.49696 .62708 Mdot
.55019 .57206 Mdot
.37428 .46246 Mdot
.51695 .6939 Mdot
.396 .44546 Mdot
.3352 .47115 Mdot
.33162 .46942 Mdot
.45791 .24777 Mdot
.73621 .69923 Mdot
.55116 .79022 Mdot
.58035 .66465 Mdot
.26443 .33318 Mdot
.36105 .44596 Mdot
.73646 .41238 Mdot
.58427 .34347 Mdot
.54914 .56453 Mdot
.23058 .47283 Mdot
.37773 .43603 Mdot
.61887 .41705 Mdot
.5588 .64671 Mdot
.39843 .41095 Mdot
.35553 .60917 Mdot
.58742 .66875 Mdot
.38142 .40328 Mdot
.67495 .42061 Mdot
.35753 .61799 Mdot
.60812 .41606 Mdot
.33222 .47041 Mdot
.59629 .6826 Mdot
.64124 .18776 Mdot
.40379 .41048 Mdot
.20572 .4264 Mdot
.5861 .51214 Mdot
.53425 .62808 Mdot
.40225 .43776 Mdot
.63513 .47511 Mdot
.46059 .32334 Mdot
.53168 .48299 Mdot
.63301 .39654 Mdot
.31353 .44086 Mdot
.34713 .47057 Mdot
.32986 .42005 Mdot
.64654 .39405 Mdot
.54569 .68248 Mdot
.65075 .40227 Mdot
.51197 .36719 Mdot
.54489 .5969 Mdot
.50971 .79011 Mdot
.3243 .28698 Mdot
.62005 .41981 Mdot
.33739 .44392 Mdot
.30135 .5898 Mdot
.57734 .60431 Mdot
.30052 .30139 Mdot
.53099 .63281 Mdot
.46694 .33591 Mdot
.70282 .51188 Mdot
.6511 .60341 Mdot
.53933 .66744 Mdot
.52637 .61397 Mdot
.47909 .32085 Mdot
.56828 .60898 Mdot
.51607 .62089 Mdot
.44087 .24734 Mdot
.65702 .40185 Mdot
.57954 .62301 Mdot
.34583 .44969 Mdot
.41158 .28784 Mdot
.6168 .59677 Mdot
.38646 .49645 Mdot
.41733 .62514 Mdot
.68347 .52692 Mdot
.5992 .64642 Mdot
.54609 .40056 Mdot
.56822 .57546 Mdot
.59698 .62473 Mdot
.52859 .61564 Mdot
.30259 .25773 Mdot
.38447 .40536 Mdot
.3791 .42144 Mdot
.35312 .56774 Mdot
.416 .62591 Mdot
.34217 .60502 Mdot
.47308 .34157 Mdot
.27284 .51277 Mdot
.39772 .44218 Mdot
.66577 .42371 Mdot
.59254 .60841 Mdot
.40545 .41382 Mdot
.55102 .56905 Mdot
.56808 .59686 Mdot
.34651 .47516 Mdot
.38237 .40652 Mdot
.28313 .6639 Mdot
.36447 .59263 Mdot
.63185 .43042 Mdot
.51911 .64358 Mdot
.33451 .61772 Mdot
.60363 .64176 Mdot
.39453 .68418 Mdot
.63585 .43255 Mdot
.65602 .40295 Mdot
.60093 .43549 Mdot
.5645 .65453 Mdot
.57323 .59952 Mdot
.49633 .32384 Mdot
.61539 .43931 Mdot
.51828 .32469 Mdot
.49646 .49301 Mdot
.2373 .58867 Mdot
.56755 .65241 Mdot
.66893 .34777 Mdot
.3494 .60702 Mdot
.33845 .45852 Mdot
.84084 .51308 Mdot
.35356 .56787 Mdot
.54756 .6149 Mdot
.33114 .46342 Mdot
.32268 .59811 Mdot
.44565 .59418 Mdot
.80987 .63764 Mdot
.30368 .58814 Mdot
.52352 .61789 Mdot
.58017 .69522 Mdot
.16835 .42736 Mdot
.31868 .57235 Mdot
.49334 .3603 Mdot
.56204 .65349 Mdot
.61068 .38987 Mdot
.32705 .61766 Mdot
.26931 .4064 Mdot
.37636 .42795 Mdot
.50518 .7366 Mdot
.58883 .54225 Mdot
.65347 .49321 Mdot
.35124 .56898 Mdot
.66402 .44306 Mdot
.55947 .71009 Mdot
.56769 .57178 Mdot
.3205 .57045 Mdot
.44815 .35341 Mdot
.362 .42301 Mdot
.39279 .30544 Mdot
.64342 .39334 Mdot
.44627 .36262 Mdot
.34053 .456 Mdot
.23976 .39943 Mdot
.78449 .44157 Mdot
.51738 .67455 Mdot
.21708 .36689 Mdot
.53768 .27846 Mdot
.52079 .58829 Mdot
.30729 .62025 Mdot
.47205 .36449 Mdot
.52842 .32615 Mdot
.50772 .34615 Mdot
.58261 .31491 Mdot
.68887 .38053 Mdot
.37931 .40055 Mdot
.50949 .39442 Mdot
.35836 .57938 Mdot
.46253 .72443 Mdot
.58973 .58054 Mdot
.58075 .60968 Mdot
.51942 .63654 Mdot
.52885 .59005 Mdot
.58177 .58855 Mdot
.52252 .34076 Mdot
.58058 .29844 Mdot
.69173 .37523 Mdot
.64183 .43684 Mdot
.31619 .53044 Mdot
.36015 .45464 Mdot
.31226 .42345 Mdot
.3279 .60894 Mdot
.30931 .37002 Mdot
.41491 .42598 Mdot
.35088 .43639 Mdot
.50899 .63131 Mdot
.65835 .41032 Mdot
.51226 .67722 Mdot
.52498 .61574 Mdot
.33827 .4269 Mdot
.44952 .49801 Mdot
.68322 .70187 Mdot
.28567 .64672 Mdot
.37433 .60251 Mdot
.52717 .39718 Mdot
.34139 .56343 Mdot
.60592 .59371 Mdot
.69337 .26591 Mdot
.36562 .46206 Mdot
.36172 .4332 Mdot
.36199 .59244 Mdot
.52307 .18568 Mdot
.64093 .4523 Mdot
.43512 .34992 Mdot
.47332 .3561 Mdot
.55499 .66169 Mdot
.81024 .45305 Mdot
.58623 .5069 Mdot
.25762 .49792 Mdot
.50558 .35046 Mdot
.39095 .42783 Mdot
.60014 .57849 Mdot
.52847 .60484 Mdot
.34161 .60946 Mdot
.34115 .75641 Mdot
.49356 .62492 Mdot
.29869 .77346 Mdot
.8282 .57767 Mdot
.60231 .76426 Mdot
.57265 .5738 Mdot
.65356 .39947 Mdot
.34881 .40746 Mdot
.35001 .57527 Mdot
.58056 .67762 Mdot
.65864 .76336 Mdot
.66698 .44804 Mdot
.49146 .34703 Mdot
.47102 .46586 Mdot
.44816 .72594 Mdot
.59644 .60445 Mdot
.58349 .65692 Mdot
.5987 .62136 Mdot
.88337 .45108 Mdot
.38916 .453 Mdot
.62173 .41573 Mdot
.32165 .58651 Mdot
.65075 .41374 Mdot
.38832 .43214 Mdot
.39623 .51626 Mdot
.53583 .64519 Mdot
.67794 .4333 Mdot
.66128 .44498 Mdot
.52697 .32731 Mdot
.45537 .34567 Mdot
.4841 .47686 Mdot
.55187 .63804 Mdot
.38831 .46794 Mdot
.64269 .46251 Mdot
.54244 .39594 Mdot
.3413 .59767 Mdot
.47605 .33532 Mdot
.53237 .59108 Mdot
.39632 .44211 Mdot
.50299 .60141 Mdot
.62592 .43983 Mdot
.35181 .4369 Mdot
.26349 .65591 Mdot
.32678 .57095 Mdot
.57923 .65325 Mdot
.33998 .6456 Mdot
.3588 .41313 Mdot
.58152 .5974 Mdot
.2173 .43689 Mdot
.29285 .61045 Mdot
.3966 .34675 Mdot
.3224 .45317 Mdot
.48516 .25611 Mdot
.62452 .40404 Mdot
.49521 .23718 Mdot
.35528 .42965 Mdot
.24896 .37798 Mdot
.2777 .67765 Mdot
.554 .54746 Mdot
.64862 .42368 Mdot
.50141 .24974 Mdot
.56798 .83219 Mdot
.18822 .45015 Mdot
.5599 .61783 Mdot
.38783 .46429 Mdot
.32833 .60515 Mdot
.49403 .31171 Mdot
.41907 .35162 Mdot
.34408 .54485 Mdot
.39232 .47403 Mdot
.5291 .61541 Mdot
.67147 .43395 Mdot
.49358 .32971 Mdot
.60625 .30501 Mdot
.35526 .45569 Mdot
.34036 .4464 Mdot
.60986 .6449 Mdot
.35388 .60116 Mdot
.37396 .24084 Mdot
.35104 .41542 Mdot
.79104 .62716 Mdot
.30729 .42646 Mdot
.34991 .61469 Mdot
.55841 .57677 Mdot
.5052 .71785 Mdot
.58317 .67289 Mdot
.19718 .48924 Mdot
.36679 .45457 Mdot
.62919 .43501 Mdot
.57928 .57259 Mdot
.80413 .56616 Mdot
.33394 .43462 Mdot
.50851 .40635 Mdot
.28292 .4228 Mdot
.47459 .35139 Mdot
.83975 .50972 Mdot
.56884 .64534 Mdot
.52526 .36718 Mdot
.33832 .60874 Mdot
.54504 .63356 Mdot
.57278 .59583 Mdot
.6738 .45283 Mdot
.52069 .32079 Mdot
.28108 .66078 Mdot
.51745 .3612 Mdot
.50426 .35848 Mdot
.64227 .37144 Mdot
.58268 .63401 Mdot
.34478 .43042 Mdot
.37646 .43664 Mdot
.52481 .57375 Mdot
.47416 .14731 Mdot
.64815 .45343 Mdot
.32684 .41502 Mdot
.87747 .42527 Mdot
.51645 .58963 Mdot
.83056 .50743 Mdot
.32338 .74205 Mdot
.47343 .36155 Mdot
.52291 .61848 Mdot
.67347 .4242 Mdot
.29795 .39282 Mdot
.33958 .44324 Mdot
.53222 .56398 Mdot
.49539 .33067 Mdot
.36585 .59311 Mdot
.3261 .4319 Mdot
.26357 .49854 Mdot
.59652 .64088 Mdot
.22299 .49993 Mdot
.36694 .4728 Mdot
.50021 .83023 Mdot
.33259 .3152 Mdot
.6455 .4236 Mdot
.56598 .59474 Mdot
.61388 .42992 Mdot
.31833 .59195 Mdot
.47312 .46718 Mdot
.48246 .3338 Mdot
.5972 .72595 Mdot
.71591 .285 Mdot
.33013 .4198 Mdot
.6172 .42143 Mdot
.54978 .66832 Mdot
.51609 .22486 Mdot
.57354 .64425 Mdot
.63234 .653 Mdot
.28592 .65788 Mdot
.48946 .31819 Mdot
.47245 .35861 Mdot
.57139 .584 Mdot
.31602 .60486 Mdot
.361 .45619 Mdot
.35185 .42269 Mdot
.44571 .84469 Mdot
.43435 .34632 Mdot
.75876 .6528 Mdot
.58978 .65382 Mdot
.38175 .47958 Mdot
.43872 .29349 Mdot
.52809 .34236 Mdot
.54138 .68386 Mdot
.33683 .46655 Mdot
.39935 .61625 Mdot
.4443 .62008 Mdot
.56929 .57408 Mdot
.60443 .66793 Mdot
.48305 .36111 Mdot
.66319 .36746 Mdot
.38273 .41657 Mdot
.50006 .59726 Mdot
.40455 .50136 Mdot
.4435 .59328 Mdot
.83089 .58904 Mdot
.63194 .43016 Mdot
.26616 .47398 Mdot
.52287 .33958 Mdot
.60634 .571 Mdot
.32181 .57987 Mdot
.36132 .48778 Mdot
.39804 .42707 Mdot
.53909 .61227 Mdot
.59263 .57317 Mdot
.81529 .58413 Mdot
.6615 .41793 Mdot
.49212 .35414 Mdot
.54538 .64511 Mdot
.66916 .32423 Mdot
.52007 .60044 Mdot
.50198 .32194 Mdot
.62286 .17899 Mdot
.59611 .66869 Mdot
.57869 .64494 Mdot
.37022 .2445 Mdot
.62975 .39487 Mdot
.63029 .46149 Mdot
.8229 .4498 Mdot
.58903 .65403 Mdot
.83234 .55971 Mdot
.62645 .42964 Mdot
.63437 .4514 Mdot
.39791 .27134 Mdot
.57828 .60849 Mdot
.48293 .56822 Mdot
.46556 .34619 Mdot
.50397 .35934 Mdot
.64725 .39764 Mdot
.50025 .65278 Mdot
.45859 .33907 Mdot
.34706 .23345 Mdot
.37274 .44429 Mdot
.62988 .21532 Mdot
.65163 .45412 Mdot
.52006 .28487 Mdot
.51818 .3514 Mdot
.79981 .65953 Mdot
.39445 .37109 Mdot
.53406 .63923 Mdot
.59101 .65137 Mdot
.36147 .58904 Mdot
.52409 .65204 Mdot
.31362 .43984 Mdot
.51481 .34336 Mdot
.65963 .72959 Mdot
.63732 .42993 Mdot
.56041 .63682 Mdot
.2231 .46219 Mdot
.23828 .65817 Mdot
.27793 .46132 Mdot
.66683 .44447 Mdot
.63729 .41648 Mdot
.39287 .44229 Mdot
.38253 .46752 Mdot
.58833 .61893 Mdot
.47672 .31908 Mdot
.61495 .43549 Mdot
.49387 .3205 Mdot
.36215 .4626 Mdot
.34705 .43193 Mdot
.37255 .40355 Mdot
.58845 .5767 Mdot
.34606 .4403 Mdot
.24477 .61652 Mdot
.45891 .38965 Mdot
.63135 .37624 Mdot
.85384 .47108 Mdot
.61032 .3095 Mdot
.67135 .48125 Mdot
.34074 .61936 Mdot
.34285 .41456 Mdot
.52106 .36625 Mdot
.55203 .59031 Mdot
.54022 .58214 Mdot
.45065 .2578 Mdot
.52845 .36183 Mdot
.32136 .58822 Mdot
.50161 .36943 Mdot
.32243 .58484 Mdot
.23235 .49494 Mdot
.5139 .62006 Mdot
.56945 .55577 Mdot
.51929 .34615 Mdot
.34861 .43862 Mdot
.37787 .42428 Mdot
.30816 .58334 Mdot
.44258 .51439 Mdot
.32227 .44364 Mdot
.63643 .4544 Mdot
.63055 .72878 Mdot
.36129 .47196 Mdot
.55896 .64524 Mdot
.39759 .7018 Mdot
.46209 .17501 Mdot
.62374 .62719 Mdot
.40709 .26022 Mdot
.68217 .64141 Mdot
.57001 .56748 Mdot
.46863 .174 Mdot
.52612 .37531 Mdot
.63309 .40052 Mdot
.35141 .41114 Mdot
.32663 .40032 Mdot
.48808 .57966 Mdot
.35721 .61937 Mdot
.58114 .68445 Mdot
.67798 .43159 Mdot
.67449 .45904 Mdot
.49419 .71557 Mdot
.1924 .46333 Mdot
.32449 .59916 Mdot
.33104 .60962 Mdot
.3533 .42779 Mdot
.23585 .71133 Mdot
.63445 .61635 Mdot
.32491 .58578 Mdot
.60423 .46532 Mdot
.5322 .61317 Mdot
.40426 .62192 Mdot
.58707 .49202 Mdot
.64687 .39606 Mdot
.45083 .67346 Mdot
.33712 .43334 Mdot
.64321 .40671 Mdot
.65954 .2981 Mdot
.53718 .67591 Mdot
.63733 .43237 Mdot
.49368 .32211 Mdot
.32427 .33667 Mdot
.64119 .45811 Mdot
.40015 .69474 Mdot
.47974 .31287 Mdot
.54381 .39468 Mdot
.46228 .66375 Mdot
.11088 .55561 Mdot
.5194 .34183 Mdot
.34653 .46975 Mdot
.37583 .43543 Mdot
.35133 .42317 Mdot
.65291 .41403 Mdot
.33055 .41905 Mdot
.66097 .41963 Mdot
.19736 .39222 Mdot
.47905 .18844 Mdot
.3287 .58444 Mdot
.39027 .30742 Mdot
.66618 .43182 Mdot
.74051 .36728 Mdot
.38977 .14598 Mdot
.52198 .62304 Mdot
.52716 .32233 Mdot
.32881 .58635 Mdot
.27677 .74228 Mdot
.331 .59862 Mdot
.68253 .74523 Mdot
.66652 .51181 Mdot
.56742 .63553 Mdot
.75554 .60483 Mdot
.30554 .59542 Mdot
.67083 .39624 Mdot
.58096 .59776 Mdot
.46397 .52334 Mdot
.33335 .60442 Mdot
.35834 .60882 Mdot
.58496 .62209 Mdot
.61896 .43225 Mdot
.33572 .44459 Mdot
.51299 .36003 Mdot
.31692 .61346 Mdot
.5912 .69707 Mdot
.56293 .67388 Mdot
.53103 .63983 Mdot
.69178 .35049 Mdot
.30111 .62135 Mdot
.51349 .34046 Mdot
.26834 .26682 Mdot
.35128 .47916 Mdot
.43136 .55697 Mdot
.8108 .6081 Mdot
.56312 .32741 Mdot
.36741 .45368 Mdot
.38334 .42122 Mdot
.58274 .58957 Mdot
.64351 .60794 Mdot
.65137 .50684 Mdot
.40991 .53291 Mdot
.3419 .40644 Mdot
.35659 .42225 Mdot
.61838 .45214 Mdot
.5767 .76081 Mdot
.62609 .63629 Mdot
.4595 .35124 Mdot
.39275 .41407 Mdot
.46358 .20388 Mdot
.35921 .5915 Mdot
.69073 .50045 Mdot
.51321 .62373 Mdot
.53674 .64166 Mdot
.49344 .33499 Mdot
.4967 .3251 Mdot
.28646 .40638 Mdot
.61936 .76068 Mdot
.6772 .64979 Mdot
.5787 .28513 Mdot
.67693 .53797 Mdot
.64124 .46691 Mdot
.61981 .42019 Mdot
.38385 .33853 Mdot
.52553 .35565 Mdot
.57213 .56776 Mdot
.63865 .41035 Mdot
.40152 .60117 Mdot
.58807 .7283 Mdot
.55299 .74156 Mdot
.82971 .53225 Mdot
.55475 .61082 Mdot
.66505 .40742 Mdot
.628 .39429 Mdot
.62961 .38892 Mdot
.5022 .26367 Mdot
.58925 .63171 Mdot
.55774 .61338 Mdot
.57943 .57723 Mdot
.51861 .20607 Mdot
.59404 .62791 Mdot
.521 .25375 Mdot
.4881 .46056 Mdot
.75862 .4682 Mdot
.4988 .60225 Mdot
.51226 .37083 Mdot
.60284 .61817 Mdot
.31528 .60312 Mdot
.52546 .64063 Mdot
.55735 .74285 Mdot
.50243 .35387 Mdot
.48994 .67097 Mdot
.59921 .31658 Mdot
.5358 .56778 Mdot
.33469 .62349 Mdot
.57534 .34825 Mdot
.55718 .81764 Mdot
.38286 .60586 Mdot
.63876 .45473 Mdot
.36982 .44869 Mdot
.52444 .36526 Mdot
.3545 .43302 Mdot
.54821 .55314 Mdot
.36946 .34052 Mdot
.28751 .74326 Mdot
.46085 .51542 Mdot
.53187 .58837 Mdot
.62885 .60063 Mdot
.6289 .44932 Mdot
.34319 .47465 Mdot
.63647 .48257 Mdot
.59204 .5961 Mdot
.34005 .5816 Mdot
.34096 .60818 Mdot
.51939 .48664 Mdot
.43288 .81248 Mdot
.40613 .21361 Mdot
.49918 .33493 Mdot
.3472 .41657 Mdot
.32091 .57754 Mdot
.25962 .36102 Mdot
.47653 .37072 Mdot
.47191 .32827 Mdot
.49645 .35332 Mdot
.56756 .65946 Mdot
.3876 .40732 Mdot
.7609 .46894 Mdot
.34303 .47996 Mdot
.5688 .60641 Mdot
.37599 .46249 Mdot
.32971 .45725 Mdot
.34679 .57698 Mdot
.49692 .35494 Mdot
.36559 .46073 Mdot
.56022 .66517 Mdot
.62494 .42614 Mdot
.47055 .2804 Mdot
.32314 .67018 Mdot
.1947 .46781 Mdot
.51987 .51683 Mdot
.63755 .39083 Mdot
.54149 .81836 Mdot
.463 .34217 Mdot
.54784 .21052 Mdot
.28421 .66615 Mdot
.6091 .64113 Mdot
.49214 .14732 Mdot
.30194 .44878 Mdot
.33068 .45585 Mdot
.56036 .5761 Mdot
.29795 .44977 Mdot
.56517 .6387 Mdot
.34942 .46351 Mdot
.42666 .37536 Mdot
.661 .37499 Mdot
.35051 .44305 Mdot
.5057 .58186 Mdot
.57391 .59171 Mdot
.65231 .40007 Mdot
.39577 .45416 Mdot
.59242 .67584 Mdot
.48254 .86214 Mdot
.5047 .32508 Mdot
.56138 .3134 Mdot
.38289 .70473 Mdot
.52353 .33731 Mdot
.64331 .42971 Mdot
.59258 .58725 Mdot
.33659 .60882 Mdot
.66802 .43037 Mdot
.57051 .74374 Mdot
.33618 .56912 Mdot
.60695 .19341 Mdot
.62964 .39302 Mdot
.33397 .45366 Mdot
.31458 .59103 Mdot
.53865 .67024 Mdot
.33277 .47402 Mdot
.30414 .33819 Mdot
.36385 .45317 Mdot
.58276 .58501 Mdot
.41494 .32058 Mdot
.49186 .35494 Mdot
.55706 .62049 Mdot
.32799 .44837 Mdot
.40781 .26178 Mdot
.57724 .66274 Mdot
.57228 .58064 Mdot
.80065 .62485 Mdot
.75085 .40843 Mdot
.33623 .5978 Mdot
.60643 .41915 Mdot
.52297 .62017 Mdot
.34592 .61437 Mdot
.25948 .57384 Mdot
.55321 .65342 Mdot
.6675 .44807 Mdot
.54198 .68479 Mdot
.39058 .46054 Mdot
.51719 .32626 Mdot
.41304 .54436 Mdot
.35448 .60991 Mdot
.14019 .5344 Mdot
.39256 .4178 Mdot
.59648 .58604 Mdot
.52087 .60178 Mdot
.39318 .74596 Mdot
.63684 .40105 Mdot
.5979 .47806 Mdot
.5801 .65335 Mdot
.52714 .20244 Mdot
.54872 .63147 Mdot
.30533 .46016 Mdot
.63991 .45248 Mdot
.58558 .64392 Mdot
.45904 .30155 Mdot
.60919 .57788 Mdot
.36221 .57688 Mdot
.33768 .27332 Mdot
.55304 .68348 Mdot
.6118 .1842 Mdot
.49832 .51026 Mdot
.34894 .44415 Mdot
.21696 .57551 Mdot
.4712 .86622 Mdot
.58735 .32127 Mdot
.65165 .41612 Mdot
.31291 .74297 Mdot
.34451 .43083 Mdot
.21296 .50836 Mdot
.56059 .82798 Mdot
.56713 .58809 Mdot
.59525 .60124 Mdot
.44157 .73781 Mdot
.33781 .47484 Mdot
.37463 .47724 Mdot
.54729 .54871 Mdot
.61719 .59066 Mdot
.34387 .43636 Mdot
.59314 .66322 Mdot
.49785 .59007 Mdot
.52755 .32312 Mdot
.6623 .45081 Mdot
.48817 .31745 Mdot
.46349 .33097 Mdot
.31006 .27427 Mdot
.47621 .52355 Mdot
.5061 .3229 Mdot
.46891 .36107 Mdot
.41466 .61378 Mdot
.65147 .74321 Mdot
.32067 .61377 Mdot
.4654 .83254 Mdot
.36095 .42422 Mdot
.58552 .63702 Mdot
.62209 .39412 Mdot
.66974 .6552 Mdot
.26697 .59375 Mdot
.72058 .30935 Mdot
.58241 .57696 Mdot
.33375 .4373 Mdot
.5499 .30524 Mdot
.5241 .68995 Mdot
.39438 .40292 Mdot
.55077 .647 Mdot
.31346 .44304 Mdot
.68804 .71129 Mdot
.25077 .3769 Mdot
.32722 .40264 Mdot
.60731 .39384 Mdot
.54037 .64077 Mdot
.68021 .42353 Mdot
.52725 .34173 Mdot
.31572 .6082 Mdot
.33972 .60054 Mdot
.58384 .6071 Mdot
.62537 .5782 Mdot
.22793 .5211 Mdot
.57711 .6019 Mdot
.53335 .60948 Mdot
.5441 .36868 Mdot
.52868 .61326 Mdot
.52355 .59115 Mdot
.55276 .56652 Mdot
.55318 .55924 Mdot
.50293 .35885 Mdot
.30464 .37339 Mdot
.49701 .56467 Mdot
.54496 .54044 Mdot
.46419 .3198 Mdot
.31564 .72826 Mdot
.46017 .33936 Mdot
.57333 .82339 Mdot
.47513 .36122 Mdot
.34239 .59284 Mdot
.33841 .73699 Mdot
.57661 .53259 Mdot
.66502 .45678 Mdot
.5563 .3485 Mdot
.3165 .596 Mdot
.51118 .34533 Mdot
.34835 .46574 Mdot
.80975 .61871 Mdot
.6892 .44026 Mdot
.71965 .38228 Mdot
.57271 .36707 Mdot
.31306 .35943 Mdot
.39425 .4416 Mdot
.66373 .38686 Mdot
.71318 .67659 Mdot
.52581 .5917 Mdot
.34428 .61503 Mdot
.58738 .61599 Mdot
.52983 .34447 Mdot
.34027 .42875 Mdot
.19252 .42291 Mdot
.34249 .60928 Mdot
.85933 .49696 Mdot
.37998 .42916 Mdot
.53228 .58222 Mdot
.45868 .33941 Mdot
.83232 .40705 Mdot
.48627 .31971 Mdot
.63301 .53277 Mdot
.6233 .40921 Mdot
.16471 .46099 Mdot
.65999 .42812 Mdot
.28362 .35668 Mdot
.79239 .30071 Mdot
.24988 .42164 Mdot
.62135 .4271 Mdot
.389 .51936 Mdot
.54449 .61448 Mdot
.53165 .6411 Mdot
.22581 .38892 Mdot
.60922 .40617 Mdot
.5258 .60125 Mdot
.44313 .27632 Mdot
.449 .36349 Mdot
.81751 .49298 Mdot
.39173 .43999 Mdot
.5647 .64225 Mdot
.53933 .33851 Mdot
.53525 .35949 Mdot
.37466 .41156 Mdot
.46784 .33223 Mdot
.56035 .61282 Mdot
.66541 .43132 Mdot
.41311 .46699 Mdot
.3509 .59363 Mdot
.24488 .70612 Mdot
.36523 .5687 Mdot
.36861 .45357 Mdot
.60776 .65932 Mdot
.34782 .43235 Mdot
.59765 .87898 Mdot
.54907 .61838 Mdot
.62636 .43093 Mdot
.53028 .60594 Mdot
.53883 .63627 Mdot
.56463 .56209 Mdot
.3378 .44675 Mdot
.28604 .65274 Mdot
.57101 .66669 Mdot
.47958 .33542 Mdot
.70961 .52071 Mdot
.52109 .65794 Mdot
.35103 .52385 Mdot
.54089 .73833 Mdot
.61381 .35482 Mdot
.61468 .40985 Mdot
.35369 .44754 Mdot
.63522 .42664 Mdot
.55775 .19799 Mdot
.64351 .42999 Mdot
.69182 .56579 Mdot
.7207 .67334 Mdot
.77447 .61909 Mdot
.78219 .60205 Mdot
.4408 .47216 Mdot
.60723 .41085 Mdot
.36014 .62383 Mdot
.61649 .43764 Mdot
.64033 .39672 Mdot
.47515 .09899 Mdot
.67968 .43637 Mdot
.56621 .64982 Mdot
.51228 .63902 Mdot
.2605 .38934 Mdot
.38971 .666 Mdot
.54247 .59653 Mdot
.53687 .59393 Mdot
.31811 .58036 Mdot
.55443 .20139 Mdot
.38386 .34911 Mdot
.74885 .40403 Mdot
.24708 .65759 Mdot
.58627 .61833 Mdot
.52259 .63367 Mdot
.51189 .55816 Mdot
.77148 .32419 Mdot
.28468 .2916 Mdot
.60593 .39166 Mdot
.54293 .5438 Mdot
.22742 .44699 Mdot
.58313 .57598 Mdot
.57906 .6586 Mdot
.55101 .61247 Mdot
.34382 .43074 Mdot
.61001 .41404 Mdot
.53746 .56002 Mdot
.37868 .74651 Mdot
.56911 .65546 Mdot
.53595 .28414 Mdot
.16887 .58761 Mdot
.5697 .64598 Mdot
.62724 .46586 Mdot
.5297 .63783 Mdot
.64572 .40224 Mdot
.66251 .39766 Mdot
.54863 .54557 Mdot
.67283 .53774 Mdot
.61536 .44957 Mdot
.56922 .60569 Mdot
.34693 .46761 Mdot
.49236 .82462 Mdot
.58562 .59164 Mdot
.3229 .61476 Mdot
.58902 .65268 Mdot
.35192 .61966 Mdot
.53891 .6045 Mdot
.38795 .41325 Mdot
.667 .62708 Mdot
.36071 .43138 Mdot
.2283 .35122 Mdot
.37924 .40481 Mdot
.85903 .52645 Mdot
.6414 .38994 Mdot
.4055 .31005 Mdot
.65266 .24257 Mdot
.47671 .24228 Mdot
.54013 .41983 Mdot
.45433 .43602 Mdot
.47666 .31965 Mdot
.63164 .40511 Mdot
.61074 .23492 Mdot
.30384 .54026 Mdot
.30652 .5086 Mdot
.32272 .43588 Mdot
.24535 .27308 Mdot
.5922 .19283 Mdot
.60792 .59551 Mdot
.73141 .6278 Mdot
.7404 .55938 Mdot
.58045 .57233 Mdot
.56769 .56132 Mdot
.30421 .41842 Mdot
.58373 .66787 Mdot
.67051 .32815 Mdot
.3773 .45144 Mdot
.31683 .60051 Mdot
.62382 .44202 Mdot
.36616 .59225 Mdot
.28754 .57654 Mdot
.45488 .42916 Mdot
.3547 .4645 Mdot
.59151 .6742 Mdot
.54562 .59149 Mdot
.65356 .40537 Mdot
.68244 .47903 Mdot
.63581 .46132 Mdot
.32679 .59084 Mdot
.38289 .44578 Mdot
.42876 .18224 Mdot
.54338 .58966 Mdot
.65767 .44623 Mdot
.54571 .42912 Mdot
.52408 .616 Mdot
.52351 .34529 Mdot
.54087 .61816 Mdot
.61971 .43625 Mdot
.52888 .61289 Mdot
.65919 .42672 Mdot
.37017 .44685 Mdot
.54169 .56982 Mdot
.56032 .57306 Mdot
.8459 .46771 Mdot
.33445 .58211 Mdot
.66494 .38585 Mdot
.41835 .57457 Mdot
.51867 .62024 Mdot
.38059 .29551 Mdot
.55468 .64733 Mdot
.64671 .36438 Mdot
.61057 .60681 Mdot
.5623 .31642 Mdot
.56035 .53934 Mdot
.59021 .61143 Mdot
.56016 .4767 Mdot
.73217 .56238 Mdot
.50365 .54026 Mdot
.48578 .36861 Mdot
.66917 .3891 Mdot
.81486 .50493 Mdot
.381 .49267 Mdot
.39533 .45992 Mdot
.44973 .69696 Mdot
.52932 .56548 Mdot
.56992 .63681 Mdot
.61836 .35712 Mdot
.35207 .60831 Mdot
.67325 .4378 Mdot
.32288 .58448 Mdot
.84525 .52077 Mdot
.34683 .56649 Mdot
.3052 .46112 Mdot
.22211 .50303 Mdot
.38832 .20258 Mdot
.32166 .57787 Mdot
.61873 .43673 Mdot
.23851 .45345 Mdot
.5251 .58331 Mdot
.51586 .50066 Mdot
.34549 .58376 Mdot
.18121 .36463 Mdot
.52484 .58967 Mdot
.54438 .41936 Mdot
.50591 .31952 Mdot
.32095 .57977 Mdot
.48522 .3095 Mdot
.55748 .58791 Mdot
.38778 .34985 Mdot
.65105 .41699 Mdot
.47846 .30843 Mdot
.5165 .66111 Mdot
.32598 .58703 Mdot
.39558 .41794 Mdot
.47649 .30221 Mdot
.46169 .35523 Mdot
.37853 .78156 Mdot
.18043 .42979 Mdot
.38416 .44285 Mdot
.78746 .43892 Mdot
.50897 .37006 Mdot
.51944 .58944 Mdot
.57885 .21161 Mdot
.53482 .6411 Mdot
.42756 .22194 Mdot
.35693 .45337 Mdot
.3118 .3633 Mdot
.52329 .62131 Mdot
.59098 .59956 Mdot
.67375 .46185 Mdot
.36888 .43238 Mdot
.65155 .44013 Mdot
.6478 .37541 Mdot
.37212 .44595 Mdot
.64971 .42565 Mdot
.31135 .58372 Mdot
.66014 .28182 Mdot
.47523 .35795 Mdot
.47659 .34472 Mdot
.35191 .42232 Mdot
.34742 .44729 Mdot
.35161 .43571 Mdot
.54017 .61858 Mdot
.65719 .4506 Mdot
.56057 .59647 Mdot
.60017 .64579 Mdot
.72122 .50333 Mdot
.6136 .40597 Mdot
.55839 .60475 Mdot
.44777 .53824 Mdot
.60908 .52653 Mdot
.35572 .46997 Mdot
.50779 .32226 Mdot
.42993 .28523 Mdot
.31629 .32258 Mdot
.56087 .64122 Mdot
.32971 .65073 Mdot
.618 .4381 Mdot
.331 .60508 Mdot
.35215 .56351 Mdot
.33249 .59748 Mdot
.51215 .387 Mdot
.62922 .38947 Mdot
.74178 .42344 Mdot
.56718 .64097 Mdot
.68441 .36492 Mdot
.60505 .38905 Mdot
.24097 .46773 Mdot
.50882 .32422 Mdot
.52883 .60489 Mdot
.41854 .54161 Mdot
.66263 .7065 Mdot
.5338 .63452 Mdot
.5163 .65212 Mdot
.25031 .63058 Mdot
.60681 .67591 Mdot
.66104 .46454 Mdot
.83327 .42126 Mdot
.5349 .6651 Mdot
.45862 .20114 Mdot
.26851 .75029 Mdot
.55239 .64081 Mdot
.59559 .61202 Mdot
.54651 .58244 Mdot
.52688 .64382 Mdot
.61725 .45513 Mdot
.41425 .64854 Mdot
.50197 .37063 Mdot
.69067 .37063 Mdot
.52584 .35261 Mdot
.33842 .41081 Mdot
.31178 .36506 Mdot
.62643 .40773 Mdot
.36134 .59055 Mdot
.22134 .64425 Mdot
.78846 .39147 Mdot
.38168 .41618 Mdot
.36194 .22807 Mdot
.34382 .58555 Mdot
.50905 .61071 Mdot
.30968 .61026 Mdot
.38973 .45428 Mdot
.47465 .34973 Mdot
.55502 .68632 Mdot
.61912 .42336 Mdot
.64481 .45798 Mdot
.52566 .6076 Mdot
.20745 .49065 Mdot
.5253 .33322 Mdot
.47314 .36622 Mdot
.56195 .65817 Mdot
.53427 .66699 Mdot
.65173 .43752 Mdot
.36301 .41853 Mdot
.7852 .61096 Mdot
.33279 .61215 Mdot
.58773 .57658 Mdot
.52764 .61801 Mdot
.80109 .6207 Mdot
.47629 .33602 Mdot
.40469 .42456 Mdot
.61114 .63457 Mdot
.56309 .26859 Mdot
.60765 .64377 Mdot
.51045 .56338 Mdot
.34827 .46889 Mdot
.4852 .61782 Mdot
.57401 .55748 Mdot
.67064 .37799 Mdot
.48573 .31408 Mdot
.63282 .4329 Mdot
.67378 .3794 Mdot
.68781 .30097 Mdot
.5189 .34884 Mdot
.54842 .61022 Mdot
.51289 .32928 Mdot
.55159 .6528 Mdot
.54358 .66494 Mdot
.50248 .32185 Mdot
.65268 .43934 Mdot
.30492 .73243 Mdot
.27229 .39857 Mdot
.53219 .65365 Mdot
.55367 .54789 Mdot
.39402 .64862 Mdot
.33085 .5419 Mdot
.5926 .59645 Mdot
.62298 .44678 Mdot
.55392 .58446 Mdot
.51789 .31932 Mdot
.30668 .59236 Mdot
.62313 .4272 Mdot
.37857 .42217 Mdot
.38971 .42022 Mdot
.5972 .32 Mdot
.32514 .45438 Mdot
.59737 .60414 Mdot
.6747 .4773 Mdot
.65339 .47468 Mdot
.20482 .61024 Mdot
.37488 .4429 Mdot
.32672 .61795 Mdot
.57587 .58386 Mdot
.49738 .73874 Mdot
.53714 .33157 Mdot
.45187 .12615 Mdot
.73956 .35179 Mdot
.30602 .61425 Mdot
.73588 .40711 Mdot
.3786 .40724 Mdot
.55117 .55171 Mdot
.32526 .61525 Mdot
.39313 .44158 Mdot
.5456 .65754 Mdot
.53854 .54493 Mdot
.6138 .50865 Mdot
.43249 .40287 Mdot
.50931 .32841 Mdot
.31657 .43898 Mdot
.31881 .62343 Mdot
.33846 .40608 Mdot
.65581 .39179 Mdot
.59134 .62977 Mdot
.60785 .65597 Mdot
.3653 .41742 Mdot
.39774 .45859 Mdot
.56385 .60549 Mdot
.61442 .42689 Mdot
.29354 .46874 Mdot
.58301 .62113 Mdot
.43535 .34208 Mdot
.60262 .412 Mdot
.38861 .44292 Mdot
.5923 .60962 Mdot
.38048 .59231 Mdot
.37557 .42488 Mdot
.3596 .46954 Mdot
.52195 .63166 Mdot
.32245 .57475 Mdot
.5895 .56474 Mdot
.46723 .35139 Mdot
.23577 .29174 Mdot
.51912 .31993 Mdot
.38086 .49748 Mdot
.61423 .67298 Mdot
.55714 .24112 Mdot
.62106 .40377 Mdot
.47662 .69534 Mdot
.44158 .27806 Mdot
.49632 .59385 Mdot
.47828 .80779 Mdot
.51928 .2855 Mdot
.20462 .5886 Mdot
.5175 .78212 Mdot
.34764 .58029 Mdot
.50869 .34655 Mdot
.5958 .61209 Mdot
.52478 .31972 Mdot
.33077 .617 Mdot
.232 .34798 Mdot
.58633 .5904 Mdot
.63433 .45089 Mdot
.55959 .60993 Mdot
.64637 .45501 Mdot
.5259 .6479 Mdot
.60389 .57776 Mdot
.46497 .25128 Mdot
.43961 .61205 Mdot
.60857 .63966 Mdot
.87604 .43729 Mdot
.60896 .51764 Mdot
.3248 .6091 Mdot
.56679 .59203 Mdot
.37058 .39269 Mdot
.53102 .35732 Mdot
.50858 .2514 Mdot
.34214 .43196 Mdot
.46179 .35251 Mdot
.65066 .43096 Mdot
.3599 .4505 Mdot
.37636 .41364 Mdot
.48593 .62882 Mdot
.30308 .60495 Mdot
.48708 .34625 Mdot
.58746 .64386 Mdot
.58754 .59447 Mdot
.79033 .43339 Mdot
.28747 .54667 Mdot
.71006 .45239 Mdot
.72527 .26577 Mdot
.64391 .38053 Mdot
.31873 .59463 Mdot
.33618 .44314 Mdot
.60404 .63195 Mdot
.56135 .61879 Mdot
.39154 .29736 Mdot
.62227 .45406 Mdot
.4716 .47414 Mdot
.70733 .46294 Mdot
.40059 .59921 Mdot
.43098 .63014 Mdot
.62289 .44283 Mdot
.42785 .62873 Mdot
.29759 .61701 Mdot
.39455 .81711 Mdot
.43535 .59864 Mdot
.50981 .3213 Mdot
.42125 .62569 Mdot
.67283 .43626 Mdot
.564 .66453 Mdot
.34231 .46662 Mdot
.33005 .45846 Mdot
.63928 .43849 Mdot
.38108 .39877 Mdot
.35245 .5792 Mdot
.5982 .63124 Mdot
.7554 .38027 Mdot
.62483 .29902 Mdot
.34657 .42017 Mdot
.50192 .66141 Mdot
.49842 .35401 Mdot
.52489 .60882 Mdot
.33598 .57363 Mdot
.5187 .33752 Mdot
.65321 .75246 Mdot
.44432 .36592 Mdot
.57942 .59128 Mdot
.80503 .61899 Mdot
.51688 .34691 Mdot
.64599 .66324 Mdot
.58433 .6303 Mdot
.46574 .34252 Mdot
.55338 .71401 Mdot
.3166 .34056 Mdot
.47813 .50406 Mdot
.56209 .82897 Mdot
.50607 .47716 Mdot
.33098 .43591 Mdot
.31388 .35236 Mdot
.46517 .23732 Mdot
.51358 .36665 Mdot
.40549 .4419 Mdot
.47449 .52936 Mdot
.48446 .3107 Mdot
.51131 .60465 Mdot
.55039 .64402 Mdot
.27733 .30094 Mdot
.54542 .32245 Mdot
.27569 .36127 Mdot
.60679 .33862 Mdot
.51785 .61914 Mdot
.60271 .58226 Mdot
.5646 .62183 Mdot
.64299 .46821 Mdot
.49822 .32855 Mdot
.8565 .43304 Mdot
.52659 .34085 Mdot
.70355 .50023 Mdot
.35653 .42383 Mdot
.39145 .44185 Mdot
.56521 .64442 Mdot
.54982 .4141 Mdot
.59786 .75689 Mdot
.56401 .611 Mdot
.30835 .56502 Mdot
.27916 .31417 Mdot
.52652 .65699 Mdot
.61733 .41312 Mdot
.4906 .60181 Mdot
.6012 .69624 Mdot
.47713 .35911 Mdot
.35806 .59083 Mdot
.51383 .72704 Mdot
.47851 .35119 Mdot
.56941 .63526 Mdot
.56843 .2549 Mdot
.54065 .62958 Mdot
.53412 .65366 Mdot
.68583 .49155 Mdot
.34575 .5631 Mdot
.36074 .4403 Mdot
.33329 .59466 Mdot
.63633 .39924 Mdot
.40144 .1137 Mdot
.34999 .56694 Mdot
.62709 .75342 Mdot
.2516 .31115 Mdot
.41905 .61857 Mdot
.67449 .43801 Mdot
.31348 .61727 Mdot
.51913 .32599 Mdot
.49048 .82661 Mdot
.62224 .52803 Mdot
.51222 .28954 Mdot
.57985 .62506 Mdot
.68139 .40339 Mdot
.64924 .46076 Mdot
.47389 .31053 Mdot
.66332 .39482 Mdot
.48318 .57229 Mdot
.5465 .66049 Mdot
.51486 .36082 Mdot
.5869 .28555 Mdot
.49965 .37164 Mdot
.40984 .51031 Mdot
.57135 .59568 Mdot
.62304 .43146 Mdot
.57484 .5618 Mdot
.61736 .46667 Mdot
.40034 .41619 Mdot
.59648 .67089 Mdot
.3538 .57894 Mdot
.54629 .24236 Mdot
.38577 .43965 Mdot
.41042 .59655 Mdot
.65103 .40374 Mdot
.50719 .39053 Mdot
.6546 .40107 Mdot
.64299 .47829 Mdot
.45941 .33946 Mdot
.67454 .41687 Mdot
.59651 .61729 Mdot
.47522 .51336 Mdot
.65331 .41092 Mdot
.49456 .33976 Mdot
.3542 .59804 Mdot
.65697 .43004 Mdot
.29772 .44635 Mdot
.57869 .58452 Mdot
.34003 .44675 Mdot
.29432 .57148 Mdot
.68448 .41925 Mdot
.32133 .56879 Mdot
.39061 .46503 Mdot
.35824 .60911 Mdot
.18671 .54991 Mdot
.44947 .33165 Mdot
.66884 .51498 Mdot
.30204 .56864 Mdot
.66283 .45911 Mdot
.28971 .67176 Mdot
.59688 .64917 Mdot
.57642 .58265 Mdot
.35139 .61897 Mdot
.64903 .46084 Mdot
.33063 .7989 Mdot
.63339 .58888 Mdot
.42467 .48848 Mdot
.53338 .37047 Mdot
.86444 .51257 Mdot
.41399 .50252 Mdot
.24037 .72111 Mdot
.50685 .66243 Mdot
.37298 .4789 Mdot
.55869 .63419 Mdot
.4262 .27048 Mdot
.33063 .58579 Mdot
.36301 .51752 Mdot
.61944 .62762 Mdot
.36305 .44543 Mdot
.55364 .57081 Mdot
.55057 .48028 Mdot
.62936 .68797 Mdot
.33834 .62009 Mdot
.22007 .48015 Mdot
.68321 .41882 Mdot
.34947 .59139 Mdot
.38546 .45328 Mdot
.45888 .65225 Mdot
.54447 .65806 Mdot
.51177 .59913 Mdot
.39983 .59936 Mdot
.66109 .44949 Mdot
.33163 .45156 Mdot
.46856 .3506 Mdot
.35763 .5987 Mdot
.54692 .59245 Mdot
.60057 .64769 Mdot
.38603 .28622 Mdot
.50531 .35598 Mdot
.3416 .47521 Mdot
.49659 .31506 Mdot
.36925 .40831 Mdot
.56781 .66828 Mdot
.38978 .42632 Mdot
.5253 .56348 Mdot
.51807 .27085 Mdot
.67995 .50284 Mdot
.73135 .58176 Mdot
.36169 .45521 Mdot
.66446 .73758 Mdot
.5085 .35469 Mdot
.48046 .32301 Mdot
.29976 .25981 Mdot
.62549 .5222 Mdot
.78364 .40643 Mdot
.43655 .78205 Mdot
.50506 .3607 Mdot
.49323 .34838 Mdot
.34123 .44734 Mdot
.6733 .41352 Mdot
.64844 .38188 Mdot
.37006 .40977 Mdot
.39182 .70352 Mdot
.67266 .43852 Mdot
.44968 .81868 Mdot
.81136 .47184 Mdot
.50659 .58465 Mdot
.31468 .4778 Mdot
.33718 .60665 Mdot
.40474 .69833 Mdot
.54074 .48529 Mdot
.58853 .59038 Mdot
.476 .71242 Mdot
.35695 .42016 Mdot
.5517 .3956 Mdot
.56182 .82115 Mdot
.54738 .56948 Mdot
.58602 .63508 Mdot
.5641 .62885 Mdot
.30226 .59649 Mdot
.65245 .57516 Mdot
.59494 .6231 Mdot
.38884 .70375 Mdot
.52062 .61391 Mdot
.632 .68989 Mdot
.33732 .59937 Mdot
.4635 .55727 Mdot
.29879 .55433 Mdot
.83174 .43246 Mdot
.63289 .6705 Mdot
.46979 .35524 Mdot
.32917 .5156 Mdot
.48154 .31953 Mdot
.70313 .56596 Mdot
.42792 .5983 Mdot
.6379 .38107 Mdot
.5899 .59332 Mdot
.37 .45364 Mdot
.64918 .46041 Mdot
.34518 .32776 Mdot
.44312 .10394 Mdot
.48221 .36371 Mdot
.40051 .86943 Mdot
.46724 .3369 Mdot
.37366 .41326 Mdot
.65079 .43702 Mdot
.70741 .68915 Mdot
.69811 .34437 Mdot
.65547 .42803 Mdot
.30222 .75864 Mdot
.59497 .40374 Mdot
.50371 .70935 Mdot
.67816 .45074 Mdot
.49679 .34388 Mdot
.5505 .37729 Mdot
.47715 .57264 Mdot
.58085 .65589 Mdot
.45966 .43644 Mdot
.59609 .75459 Mdot
.59771 .64769 Mdot
.37886 .44989 Mdot
.6503 .51052 Mdot
.45969 .69781 Mdot
.67556 .4246 Mdot
.44489 .35678 Mdot
.58899 .6274 Mdot
.52785 .6275 Mdot
.55394 .66104 Mdot
.74228 .34044 Mdot
.38971 .81541 Mdot
.56833 .66648 Mdot
.52177 .6393 Mdot
.36179 .44861 Mdot
.35006 .54277 Mdot
.25328 .42957 Mdot
.77022 .44861 Mdot
.55183 .56353 Mdot
.34661 .59586 Mdot
.32628 .62798 Mdot
.59378 .66108 Mdot
.46991 .52486 Mdot
.56978 .24921 Mdot
.58873 .64259 Mdot
.64432 .51115 Mdot
.33908 .3811 Mdot
.34003 .47672 Mdot
.37411 .42131 Mdot
.67202 .39529 Mdot
.3625 .41406 Mdot
.38923 .41226 Mdot
.66714 .71683 Mdot
.49144 .47374 Mdot
.50132 .26704 Mdot
.32532 .59306 Mdot
.55547 .62072 Mdot
.52462 .52935 Mdot
.56129 .26087 Mdot
.47318 .31952 Mdot
.62595 .41963 Mdot
.5347 .35372 Mdot
.33725 .6326 Mdot
.71259 .33182 Mdot
.33097 .42262 Mdot
.48968 .35967 Mdot
.44488 .32978 Mdot
.34584 .59817 Mdot
.50202 .30861 Mdot
.44794 .39125 Mdot
.55875 .67684 Mdot
.71668 .64294 Mdot
.57006 .60796 Mdot
.22398 .65773 Mdot
.49023 .35222 Mdot
.54103 .37467 Mdot
.57642 .64193 Mdot
.37708 .42744 Mdot
.52104 .70673 Mdot
.57693 .65722 Mdot
.3608 .41506 Mdot
.61117 .60271 Mdot
.36809 .57449 Mdot
.6053 .42347 Mdot
.69621 .34567 Mdot
.24875 .26617 Mdot
.30433 .60788 Mdot
.35334 .32165 Mdot
.58616 .58194 Mdot
.18167 .46772 Mdot
.65959 .43135 Mdot
.60703 .61125 Mdot
.44924 .67 Mdot
.6613 .41637 Mdot
.6366 .42335 Mdot
.53708 .61442 Mdot
.50521 .31794 Mdot
.38749 .44021 Mdot
.34224 .60164 Mdot
.21426 .67207 Mdot
.58056 .61258 Mdot
.55826 .57654 Mdot
.34675 .58881 Mdot
.52018 .35251 Mdot
.60585 .64643 Mdot
.42179 .75026 Mdot
.36811 .82138 Mdot
.46493 .33677 Mdot
.52959 .58173 Mdot
.70013 .59638 Mdot
.63873 .63596 Mdot
.15207 .49337 Mdot
.50287 .50781 Mdot
.3556 .44257 Mdot
.62954 .63465 Mdot
.5627 .14986 Mdot
.35699 .59552 Mdot
.78688 .39433 Mdot
.52703 .62563 Mdot
.53905 .58997 Mdot
.62865 .45779 Mdot
.56255 .59873 Mdot
.62501 .41133 Mdot
.33433 .20894 Mdot
.82151 .59606 Mdot
.66046 .38721 Mdot
.6702 .45371 Mdot
.52997 .7368 Mdot
.44141 .30597 Mdot
.64154 .43724 Mdot
.54045 .66527 Mdot
.44826 .55802 Mdot
.59765 .37221 Mdot
.3199 .61839 Mdot
.28101 .64509 Mdot
.6001 .53778 Mdot
.35953 .6411 Mdot
.3145 .73036 Mdot
.56428 .51952 Mdot
.40756 .52547 Mdot
.47545 .33155 Mdot
.54727 .56861 Mdot
.33031 .45987 Mdot
.32793 .45961 Mdot
.52839 .55921 Mdot
.54625 .6228 Mdot
.64129 .39989 Mdot
.34725 .60899 Mdot
.51916 .36781 Mdot
.53981 .59227 Mdot
.47312 .68799 Mdot
.36148 .59865 Mdot
.66764 .40036 Mdot
.70135 .51814 Mdot
.36637 .56501 Mdot
.5935 .56188 Mdot
.58246 .65073 Mdot
.55476 .61077 Mdot
.47676 .57002 Mdot
.49432 .32659 Mdot
.3237 .72538 Mdot
.51525 .63981 Mdot
.84738 .51048 Mdot
.48056 .26868 Mdot
.62483 .62983 Mdot
.65643 .39531 Mdot
.45681 .36644 Mdot
.36816 .4013 Mdot
.66725 .27194 Mdot
.57997 .5949 Mdot
.21313 .48301 Mdot
.27204 .30929 Mdot
.40349 .43604 Mdot
.60972 .45251 Mdot
.3286 .5983 Mdot
.56164 .61284 Mdot
.66993 .53932 Mdot
.55362 .64428 Mdot
.29318 .61811 Mdot
.36757 .46904 Mdot
.4777 .32917 Mdot
.21184 .60871 Mdot
.31965 .44779 Mdot
.63571 .42608 Mdot
.73932 .72663 Mdot
.62373 .41153 Mdot
.65097 .3819 Mdot
.71121 .51684 Mdot
.49357 .32561 Mdot
.50294 .12895 Mdot
.35416 .20712 Mdot
.56955 .67222 Mdot
.51661 .35305 Mdot
.63214 .44011 Mdot
.52333 .60061 Mdot
.59614 .43003 Mdot
.62142 .39196 Mdot
.55414 .66698 Mdot
.54057 .58369 Mdot
.2458 .39168 Mdot
.52964 .80741 Mdot
.32785 .59677 Mdot
.62976 .39707 Mdot
.68186 .33256 Mdot
.52159 .60131 Mdot
.56826 .64151 Mdot
.41745 .23777 Mdot
.3047 .60077 Mdot
.65088 .30283 Mdot
.52748 .62668 Mdot
.76422 .67603 Mdot
.49337 .57866 Mdot
.61248 .44343 Mdot
.47613 .32244 Mdot
.83454 .44976 Mdot
.43968 .39012 Mdot
.62633 .41138 Mdot
.36198 .58293 Mdot
.66971 .46645 Mdot
.64521 .74926 Mdot
.52594 .35089 Mdot
.61971 .43645 Mdot
.41352 .54228 Mdot
.50571 .33301 Mdot
.48524 .3535 Mdot
.72818 .50049 Mdot
.39834 .40781 Mdot
.30074 .60721 Mdot
.48941 .34766 Mdot
.53927 .20982 Mdot
.50154 .33995 Mdot
.33395 .21895 Mdot
.54109 .57265 Mdot
.44052 .71507 Mdot
.37188 .5033 Mdot
.61123 .55892 Mdot
.49466 .35623 Mdot
.31455 .58364 Mdot
.54383 .6561 Mdot
.67916 .41807 Mdot
.34178 .61445 Mdot
.51856 .30189 Mdot
.34359 .43503 Mdot
.65877 .40428 Mdot
.55185 .3436 Mdot
.64331 .45648 Mdot
.60995 .23551 Mdot
.23367 .31496 Mdot
.5443 .75481 Mdot
.69947 .34235 Mdot
.54235 .65784 Mdot
.39293 .78673 Mdot
.53004 .57645 Mdot
.54006 .62432 Mdot
.38477 .44701 Mdot
.45332 .71027 Mdot
.65168 .4397 Mdot
.26898 .72588 Mdot
.48023 .35937 Mdot
.8357 .44013 Mdot
.63201 .66541 Mdot
.59546 .58303 Mdot
.65018 .40937 Mdot
.61526 .44238 Mdot
.72761 .5464 Mdot
.31956 .4169 Mdot
.58707 .57887 Mdot
.53005 .67422 Mdot
.52817 .55583 Mdot
.47487 .35343 Mdot
.44006 .55502 Mdot
.33227 .43146 Mdot
.20125 .37513 Mdot
.37112 .46902 Mdot
.30076 .64062 Mdot
.67577 .41439 Mdot
.35063 .56728 Mdot
.57052 .64337 Mdot
.6715 .48531 Mdot
.62521 .45766 Mdot
.35279 .61738 Mdot
.3173 .58549 Mdot
.34777 .29945 Mdot
.50328 .32242 Mdot
.57873 .66038 Mdot
.59308 .61247 Mdot
.55622 .59747 Mdot
.54225 .61872 Mdot
.48415 .36357 Mdot
.55426 .65854 Mdot
.53457 .32365 Mdot
.67787 .27196 Mdot
.44798 .74056 Mdot
.51222 .47549 Mdot
.38775 .22642 Mdot
.67595 .42891 Mdot
.54311 .21763 Mdot
.59636 .68954 Mdot
.65363 .23007 Mdot
.22847 .37159 Mdot
.53189 .66882 Mdot
.39217 .4238 Mdot
.57546 .72148 Mdot
.32318 .43888 Mdot
.24688 .73991 Mdot
.43358 .24639 Mdot
.51622 .81018 Mdot
.5868 .59294 Mdot
.47263 .51369 Mdot
.50824 .20171 Mdot
.52375 .58316 Mdot
.38162 .27634 Mdot
.42587 .22115 Mdot
.23129 .45403 Mdot
.32341 .57593 Mdot
.58554 .60505 Mdot
.51461 .53439 Mdot
.5974 .62326 Mdot
.5619 .6379 Mdot
.55395 .65984 Mdot
.5278 .36868 Mdot
.60487 .614 Mdot
.53719 .64798 Mdot
.23046 .53372 Mdot
.43351 .62379 Mdot
.36228 .4788 Mdot
.28299 .27722 Mdot
.34801 .56605 Mdot
.65023 .40587 Mdot
.37816 .8019 Mdot
.51017 .3219 Mdot
.73316 .54859 Mdot
.54767 .61553 Mdot
.25767 .39411 Mdot
.43701 .35799 Mdot
.35979 .58101 Mdot
.39388 .44955 Mdot
.51802 .82365 Mdot
.3735 .45047 Mdot
.47887 .3798 Mdot
.37921 .43146 Mdot
.62204 .66817 Mdot
.63911 .39908 Mdot
.58614 .66182 Mdot
.48499 .3443 Mdot
.37864 .41929 Mdot
.39208 .6591 Mdot
.56289 .62332 Mdot
.37169 .44537 Mdot
.58381 .6622 Mdot
.72176 .37747 Mdot
.79056 .46656 Mdot
.39392 .41916 Mdot
.45273 .3201 Mdot
.4847 .3345 Mdot
.33334 .5712 Mdot
.65878 .40912 Mdot
.62661 .41594 Mdot
.51763 .33843 Mdot
.63126 .49222 Mdot
.55079 .56248 Mdot
.52897 .59186 Mdot
.83833 .47618 Mdot
.5993 .61842 Mdot
.45992 .65049 Mdot
.42098 .54359 Mdot
.67087 .39871 Mdot
.59039 .57291 Mdot
.53296 .61424 Mdot
.57883 .58889 Mdot
.73268 .37869 Mdot
.35798 .41695 Mdot
.54465 .57041 Mdot
.3141 .5934 Mdot
.29378 .3948 Mdot
.5246 .60964 Mdot
.48498 .59377 Mdot
.62525 .41759 Mdot
.73204 .28055 Mdot
.46937 .33412 Mdot
.38407 .4539 Mdot
.36029 .45569 Mdot
.31102 .71247 Mdot
.50189 .22256 Mdot
.42322 .54226 Mdot
.16575 .4294 Mdot
.46571 .25151 Mdot
.32176 .58708 Mdot
.34714 .48555 Mdot
.5583 .36861 Mdot
.3504 .45771 Mdot
.49157 .36713 Mdot
.53212 .58093 Mdot
.5487 .56401 Mdot
.54021 .15939 Mdot
.60279 .65266 Mdot
.33182 .60152 Mdot
.51347 .37147 Mdot
.67008 .43913 Mdot
.36109 .58571 Mdot
.49373 .31485 Mdot
.67055 .39429 Mdot
.52917 .66733 Mdot
.5178 .64904 Mdot
.62872 .41791 Mdot
.62947 .45623 Mdot
.58022 .64877 Mdot
.41501 .35751 Mdot
.66754 .45434 Mdot
.62194 .44253 Mdot
.33516 .42126 Mdot
.32707 .45585 Mdot
.53113 .54029 Mdot
.50635 .35301 Mdot
.53963 .65102 Mdot
.36273 .45202 Mdot
.3489 .56725 Mdot
.6551 .44026 Mdot
.52989 .6498 Mdot
.53096 .60331 Mdot
.34701 .5988 Mdot
.34669 .57064 Mdot
.33337 .57462 Mdot
.54841 .34018 Mdot
.56101 .5913 Mdot
.64784 .43387 Mdot
.49646 .3224 Mdot
.31782 .62589 Mdot
.31204 .61143 Mdot
.32385 .47504 Mdot
.60256 .62064 Mdot
.41405 .4655 Mdot
.581 .15407 Mdot
.82979 .55843 Mdot
.39921 .42084 Mdot
.362 .40133 Mdot
.35324 .66282 Mdot
.56968 .38336 Mdot
.52401 .34142 Mdot
.33526 .54204 Mdot
.55219 .7513 Mdot
.55794 .68258 Mdot
.52604 .65421 Mdot
.60885 .58907 Mdot
.32933 .57626 Mdot
.46768 .72761 Mdot
.62793 .40647 Mdot
.45922 .58022 Mdot
.36149 .60039 Mdot
.38638 .46808 Mdot
.34326 .48748 Mdot
.37672 .46667 Mdot
.50926 .61927 Mdot
.73791 .5923 Mdot
.52646 .22541 Mdot
.41896 .76841 Mdot
.50117 .35649 Mdot
.52981 .52787 Mdot
.1876 .45538 Mdot
.63404 .41917 Mdot
.33273 .41264 Mdot
.31874 .58938 Mdot
.63229 .4571 Mdot
.53547 .34853 Mdot
.49134 .34668 Mdot
.34531 .42099 Mdot
.3452 .42382 Mdot
.34616 .4629 Mdot
.61578 .39356 Mdot
.6751 .41494 Mdot
.57822 .59373 Mdot
.66074 .4401 Mdot
.71391 .28906 Mdot
.36823 .60745 Mdot
.38405 .39149 Mdot
.50785 .34894 Mdot
.67907 .42854 Mdot
.56445 .62033 Mdot
.6574 .36487 Mdot
.55875 .29335 Mdot
.32434 .61057 Mdot
.78992 .45011 Mdot
.215 .69138 Mdot
.58692 .65885 Mdot
.48591 .3299 Mdot
.75676 .36862 Mdot
.56636 .6274 Mdot
.33586 .44922 Mdot
.23348 .59977 Mdot
.41925 .39757 Mdot
.57291 .65696 Mdot
.56626 .67792 Mdot
.46576 .35268 Mdot
.20029 .38097 Mdot
.57977 .60201 Mdot
.65359 .29113 Mdot
.4413 .34143 Mdot
.33137 .44289 Mdot
.50601 .86904 Mdot
.38856 .58507 Mdot
.40166 .70197 Mdot
.33771 .4232 Mdot
.5393 .6379 Mdot
.32313 .43141 Mdot
.31486 .60108 Mdot
.39291 .44733 Mdot
.62018 .41392 Mdot
.38583 .46431 Mdot
.55727 .57683 Mdot
.63794 .43675 Mdot
.51734 .34755 Mdot
.82368 .42769 Mdot
.24838 .59551 Mdot
.37516 .42632 Mdot
.38812 .41495 Mdot
.59695 .581 Mdot
.66417 .32429 Mdot
.53565 .55836 Mdot
.52726 .58716 Mdot
.51629 .35773 Mdot
.65973 .41375 Mdot
.46284 .33809 Mdot
.58485 .54254 Mdot
.46632 .75637 Mdot
.49495 .3162 Mdot
.25292 .41983 Mdot
.34216 .58419 Mdot
.51593 .43146 Mdot
.56008 .61794 Mdot
.49127 .30756 Mdot
.56349 .59041 Mdot
.62977 .40378 Mdot
.53104 .46152 Mdot
.36043 .35733 Mdot
.47849 .34734 Mdot
.20334 .55072 Mdot
.41847 .73753 Mdot
.50179 .55201 Mdot
.47874 .32322 Mdot
.44885 .67971 Mdot
.37133 .41293 Mdot
.33559 .6133 Mdot
.37066 .58502 Mdot
.36287 .6007 Mdot
.49777 .60054 Mdot
.63108 .66992 Mdot
.3176 .57068 Mdot
.52965 .35687 Mdot
.33724 .62014 Mdot
.43917 .19612 Mdot
.27192 .72932 Mdot
.33474 .58562 Mdot
.58284 .62793 Mdot
.57294 .70594 Mdot
.41582 .61345 Mdot
.31092 .34054 Mdot
.50145 .8084 Mdot
.34543 .26955 Mdot
.57191 .65436 Mdot
.60241 .40703 Mdot
.6227 .39483 Mdot
.76066 .33769 Mdot
.62396 .74831 Mdot
.81501 .59601 Mdot
.67135 .39065 Mdot
.4125 .3128 Mdot
.66635 .40364 Mdot
.57591 .66557 Mdot
.52654 .59493 Mdot
.66084 .37927 Mdot
.4787 .75113 Mdot
.39482 .31979 Mdot
.21047 .63696 Mdot
.63775 .45697 Mdot
.48465 .31475 Mdot
.46299 .3237 Mdot
.48819 .35526 Mdot
.81002 .44814 Mdot
.64953 .41319 Mdot
.54518 .5982 Mdot
.36538 .45561 Mdot
.55617 .56514 Mdot
.50707 .33109 Mdot
.28183 .75176 Mdot
.65766 .42426 Mdot
.59165 .62475 Mdot
.48263 .64642 Mdot
.34395 .42843 Mdot
.34374 .59251 Mdot
.70689 .36886 Mdot
.80402 .60913 Mdot
.48388 .35952 Mdot
.68385 .41449 Mdot
.5594 .35904 Mdot
.22132 .63769 Mdot
.51174 .67204 Mdot
.57182 .68963 Mdot
.21413 .67558 Mdot
.72922 .71426 Mdot
.59064 .5881 Mdot
.39551 .43645 Mdot
.39513 .29011 Mdot
.5257 .61486 Mdot
.62482 .39602 Mdot
.36776 .56835 Mdot
.35311 .61225 Mdot
.52142 .54279 Mdot
.66142 .3586 Mdot
.53329 .48235 Mdot
.54612 .61168 Mdot
.59816 .56785 Mdot
.33202 .43497 Mdot
.43143 .25903 Mdot
.84541 .52164 Mdot
.35477 .5714 Mdot
.59133 .66043 Mdot
.28832 .72491 Mdot
.63952 .4631 Mdot
.40295 .43403 Mdot
.51958 .31841 Mdot
.60655 .38804 Mdot
.39501 .44737 Mdot
.53221 .65744 Mdot
.6 .65538 Mdot
.46775 .32418 Mdot
.6117 .44034 Mdot
.33358 .57626 Mdot
.38601 .44822 Mdot
.34875 .57377 Mdot
.65963 .41705 Mdot
.66839 .43322 Mdot
.47869 .61562 Mdot
.52508 .68333 Mdot
.37892 .4232 Mdot
.51316 .57367 Mdot
.41084 .37782 Mdot
.14968 .54286 Mdot
.55634 .34855 Mdot
.60617 .62459 Mdot
.67816 .45553 Mdot
.4766 .35135 Mdot
.54057 .5874 Mdot
.25353 .73474 Mdot
.51942 .60779 Mdot
.51943 .37447 Mdot
.6354 .76359 Mdot
.34602 .57596 Mdot
.49067 .53893 Mdot
.22791 .39178 Mdot
.6011 .62785 Mdot
.34887 .45125 Mdot
.49508 .64451 Mdot
.51086 .31895 Mdot
.67612 .42174 Mdot
.14281 .54843 Mdot
.497 .33768 Mdot
.59601 .63726 Mdot
.35972 .59454 Mdot
.66756 .46147 Mdot
.50537 .51074 Mdot
.4599 .53159 Mdot
.53483 .70279 Mdot
.58443 .57214 Mdot
.53364 .62223 Mdot
.4306 .75847 Mdot
.37628 .45851 Mdot
.62515 .44218 Mdot
.48042 .33251 Mdot
.52032 .3392 Mdot
.35119 .41948 Mdot
.41824 .46312 Mdot
.5145 .43171 Mdot
.66906 .19582 Mdot
.32509 .42389 Mdot
.3576 .56951 Mdot
.66023 .31088 Mdot
.37464 .45633 Mdot
.37265 .44141 Mdot
.33213 .4232 Mdot
.41484 .53111 Mdot
.67317 .43863 Mdot
.53072 .65628 Mdot
.61483 .41016 Mdot
.538 .63937 Mdot
.49988 .37577 Mdot
.48182 .34665 Mdot
.66296 .42399 Mdot
.19064 .59742 Mdot
.70132 .64715 Mdot
.57407 .63198 Mdot
.18262 .46645 Mdot
.61543 .6431 Mdot
.39552 .63356 Mdot
.61577 .62609 Mdot
.36706 .42507 Mdot
.50966 .60125 Mdot
.50351 .57867 Mdot
.77418 .36292 Mdot
.50883 .35109 Mdot
.34656 .4816 Mdot
.61961 .6025 Mdot
.59251 .56272 Mdot
.61463 .39272 Mdot
.62869 .45451 Mdot
.36991 .58988 Mdot
.45894 .63157 Mdot
.52017 .34762 Mdot
.42376 .17776 Mdot
.58151 .65513 Mdot
.37486 .62916 Mdot
.79407 .57427 Mdot
.54284 .58575 Mdot
.21472 .41993 Mdot
.73728 .58109 Mdot
.56108 .61438 Mdot
.44687 .4659 Mdot
.5066 .35513 Mdot
.51558 .77507 Mdot
.52105 .61842 Mdot
.3387 .43397 Mdot
.67193 .40726 Mdot
.62964 .46158 Mdot
.36749 .57663 Mdot
.596 .19368 Mdot
.4615 .33974 Mdot
.67209 .42256 Mdot
.55702 .62626 Mdot
.48582 .32827 Mdot
.33391 .41761 Mdot
.60099 .59385 Mdot
.68468 .73243 Mdot
.65934 .44385 Mdot
.61222 .6041 Mdot
.6284 .26786 Mdot
.36362 .68268 Mdot
.63714 .77605 Mdot
.47522 .33631 Mdot
.33146 .57222 Mdot
.49823 .57713 Mdot
.60587 .49127 Mdot
.56889 .55073 Mdot
.42161 .71523 Mdot
.42519 .20104 Mdot
.30848 .58841 Mdot
.57936 .63955 Mdot
.54534 .59401 Mdot
.57237 .44948 Mdot
.35956 .57594 Mdot
.58895 .59764 Mdot
.57707 .41555 Mdot
.64589 .45354 Mdot
.35041 .40889 Mdot
.66574 .44375 Mdot
.57976 .62604 Mdot
.52694 .68663 Mdot
.6272 .45612 Mdot
.16243 .52935 Mdot
.37385 .5705 Mdot
.47961 .32504 Mdot
.58518 .67151 Mdot
.513 .62234 Mdot
.85044 .39039 Mdot
.40362 .44185 Mdot
.39825 .35742 Mdot
.26331 .44238 Mdot
.29691 .7121 Mdot
.37997 .55846 Mdot
.59802 .80336 Mdot
.7233 .72088 Mdot
.6053 .61348 Mdot
.55962 .50677 Mdot
.58284 .23555 Mdot
.51305 .35641 Mdot
.53804 .18678 Mdot
.58146 .65598 Mdot
.5596 .63627 Mdot
.39274 .40961 Mdot
.34073 .35763 Mdot
.82004 .58889 Mdot
.67972 .37547 Mdot
.33834 .57656 Mdot
.63669 .39657 Mdot
.53641 .6623 Mdot
.4621 .47593 Mdot
.39447 .46193 Mdot
.36241 .62507 Mdot
.59112 .62962 Mdot
.74 .38452 Mdot
.56944 .30034 Mdot
.50151 .32485 Mdot
.35751 .45556 Mdot
.78537 .63401 Mdot
.60435 .62887 Mdot
.49609 .30633 Mdot
.57751 .61325 Mdot
.38397 .55745 Mdot
.59759 .55403 Mdot
.32292 .58921 Mdot
.52707 .63631 Mdot
.32405 .50804 Mdot
.8812 .50698 Mdot
.29537 .60347 Mdot
.61179 .39002 Mdot
.41041 .42849 Mdot
.36078 .41681 Mdot
.62418 .45014 Mdot
.36835 .41936 Mdot
.73809 .52878 Mdot
.67885 .71553 Mdot
.34251 .58196 Mdot
.53501 .5414 Mdot
.33648 .58998 Mdot
.40232 .42171 Mdot
.57376 .65592 Mdot
.16768 .61577 Mdot
.38586 .4271 Mdot
.75485 .69508 Mdot
.50551 .34016 Mdot
.40112 .45426 Mdot
.52103 .61374 Mdot
.56315 .32095 Mdot
.32 .44765 Mdot
.39232 .34206 Mdot
.57875 .58947 Mdot
.66903 .43722 Mdot
.52915 .60912 Mdot
.56619 .67154 Mdot
.37044 .47888 Mdot
.54499 .65053 Mdot
.4947 .31445 Mdot
.66584 .38524 Mdot
.47359 .82196 Mdot
.45804 .21653 Mdot
.59108 .59959 Mdot
.55971 .62648 Mdot
.64756 .47566 Mdot
.51291 .60446 Mdot
.4827 .36291 Mdot
.16541 .32586 Mdot
.34246 .58477 Mdot
.38763 .47639 Mdot
.29829 .48653 Mdot
.54051 .67713 Mdot
.54833 .65726 Mdot
.28996 .78561 Mdot
.45534 .75049 Mdot
.48315 .31939 Mdot
.52533 .55733 Mdot
.31826 .43158 Mdot
.34886 .60636 Mdot
.52098 .36448 Mdot
.55697 .60937 Mdot
.57313 .64263 Mdot
.33868 .56938 Mdot
.38074 .6327 Mdot
.81817 .48761 Mdot
.476 .31209 Mdot
.61582 .67113 Mdot
.29811 .43637 Mdot
.55097 .56074 Mdot
.79605 .43376 Mdot
.621 .43106 Mdot
.48738 .36067 Mdot
.31425 .724 Mdot
.60505 .62369 Mdot
.47497 .32137 Mdot
.51897 .34876 Mdot
.57267 .55537 Mdot
.68861 .4174 Mdot
.66015 .38136 Mdot
.64709 .45576 Mdot
.44108 .13728 Mdot
.41176 .69074 Mdot
.34608 .46288 Mdot
.5101 .35522 Mdot
.38383 .41043 Mdot
.29309 .61858 Mdot
.46619 .51095 Mdot
.38843 .41333 Mdot
.66098 .45177 Mdot
.39541 .46673 Mdot
.55988 .58537 Mdot
.5197 .34626 Mdot
.34653 .45661 Mdot
.55735 .67264 Mdot
.67335 .35282 Mdot
.30256 .32129 Mdot
.30958 .60172 Mdot
.36184 .56104 Mdot
.52545 .60063 Mdot
.33454 .409 Mdot
.57628 .64843 Mdot
.52193 .31795 Mdot
.67861 .3428 Mdot
.5677 .6704 Mdot
.37218 .42407 Mdot
.65065 .47394 Mdot
.79033 .62574 Mdot
.50109 .61307 Mdot
.58246 .62969 Mdot
.54114 .64477 Mdot
.57754 .61239 Mdot
.22291 .62583 Mdot
.45706 .33629 Mdot
.39914 .22419 Mdot
.30978 .7052 Mdot
.65199 .42425 Mdot
.60918 .4203 Mdot
.83805 .52734 Mdot
.57879 .24272 Mdot
.5059 .35349 Mdot
.54087 .62221 Mdot
.56285 .27402 Mdot
.36622 .81917 Mdot
.2002 .64153 Mdot
.65346 .63957 Mdot
.40495 .43862 Mdot
.68364 .41478 Mdot
.37609 .41595 Mdot
.54377 .64034 Mdot
.59505 .56787 Mdot
.65387 .79176 Mdot
.53157 .35058 Mdot
.33634 .57974 Mdot
.53659 .64044 Mdot
.40745 .69281 Mdot
.36007 .44918 Mdot
.40133 .45459 Mdot
.54054 .57768 Mdot
.63696 .46904 Mdot
.8732 .50534 Mdot
.4938 .32707 Mdot
.38096 .24346 Mdot
.50064 .19981 Mdot
.58363 .34017 Mdot
.50368 .32914 Mdot
.5927 .49086 Mdot
.40181 .43096 Mdot
.79561 .5419 Mdot
.64662 .42022 Mdot
.33659 .61479 Mdot
.62329 .63909 Mdot
.61661 .43311 Mdot
.35619 .4722 Mdot
.67428 .42944 Mdot
.54949 .65877 Mdot
.44378 .34079 Mdot
.35303 .44203 Mdot
.48958 .26435 Mdot
.6772 .45704 Mdot
.36096 .57989 Mdot
.49813 .40149 Mdot
.65693 .67865 Mdot
.73736 .57626 Mdot
.54231 .57391 Mdot
.45598 .48437 Mdot
.54798 .59842 Mdot
.61433 .45984 Mdot
.56893 .61878 Mdot
.68674 .46494 Mdot
.34886 .45004 Mdot
.52112 .63637 Mdot
.54296 .61446 Mdot
.32781 .23004 Mdot
.58773 .601 Mdot
.54553 .55752 Mdot
.55715 .61498 Mdot
.66844 .48385 Mdot
.51448 .54845 Mdot
.65351 .39498 Mdot
.24374 .45051 Mdot
.37166 .4384 Mdot
.35795 .61118 Mdot
.32502 .5728 Mdot
.44379 .70799 Mdot
.31235 .52739 Mdot
.30807 .36438 Mdot
.64989 .4497 Mdot
.50348 .31275 Mdot
.57237 .61528 Mdot
.55593 .81732 Mdot
.30638 .41316 Mdot
.38421 .46838 Mdot
.46016 .21762 Mdot
.63089 .59852 Mdot
.54044 .78348 Mdot
.53454 .55328 Mdot
.51188 .15351 Mdot
.52046 .66822 Mdot
.62901 .61266 Mdot
.32927 .41766 Mdot
.33222 .64273 Mdot
.51542 .60272 Mdot
.63649 .38823 Mdot
.32428 .60479 Mdot
.63271 .66132 Mdot
.3523 .49832 Mdot
.31293 .38129 Mdot
.71256 .428 Mdot
.57092 .58987 Mdot
.35344 .44101 Mdot
.6573 .40433 Mdot
.84069 .54086 Mdot
.49405 .32267 Mdot
.40531 .48211 Mdot
.66525 .28208 Mdot
.16909 .52133 Mdot
.36301 .59539 Mdot
.77957 .48925 Mdot
.55759 .57898 Mdot
.22338 .55686 Mdot
.58032 .67127 Mdot
.29958 .77634 Mdot
.33094 .56624 Mdot
.66767 .44773 Mdot
.48831 .3126 Mdot
.62463 .39714 Mdot
.72876 .56852 Mdot
.32846 .48832 Mdot
.49996 .45817 Mdot
.37358 .44905 Mdot
.52236 .49163 Mdot
.62991 .43619 Mdot
.57742 .66282 Mdot
.66128 .18965 Mdot
.62089 .4387 Mdot
.67202 .45781 Mdot
.24439 .32081 Mdot
.15738 .57606 Mdot
.55882 .69126 Mdot
.67012 .45278 Mdot
.37808 .44438 Mdot
.32657 .59945 Mdot
.52383 .62514 Mdot
.569 .58462 Mdot
.61804 .42751 Mdot
.36564 .48226 Mdot
.67561 .57984 Mdot
.35181 .42301 Mdot
.66985 .44269 Mdot
.36053 .43162 Mdot
.52401 .3795 Mdot
.38636 .45044 Mdot
.51274 .62265 Mdot
.56982 .61777 Mdot
.27327 .48696 Mdot
.66813 .43413 Mdot
.54727 .61029 Mdot
.59857 .58372 Mdot
.64686 .4359 Mdot
.57645 .48514 Mdot
.68326 .57988 Mdot
.58221 .57685 Mdot
.58267 .59152 Mdot
.31829 .57761 Mdot
.46837 .49834 Mdot
.78526 .46617 Mdot
.54088 .65468 Mdot
.30589 .58831 Mdot
.64711 .38757 Mdot
.58805 .64437 Mdot
.35289 .79054 Mdot
.39336 .29406 Mdot
.58691 .65764 Mdot
.37297 .41346 Mdot
.51229 .5691 Mdot
.65129 .76825 Mdot
.52515 .58905 Mdot
.64104 .4412 Mdot
.66877 .4168 Mdot
.40262 .18957 Mdot
.63415 .4272 Mdot
.32981 .45826 Mdot
.50679 .33231 Mdot
.21746 .63526 Mdot
.35347 .41323 Mdot
.50745 .6538 Mdot
.27013 .25878 Mdot
.6111 .61354 Mdot
.52834 .66262 Mdot
.79825 .64689 Mdot
.3813 .41963 Mdot
.64292 .40431 Mdot
.51478 .40441 Mdot
.53794 .68993 Mdot
.48618 .35861 Mdot
.61415 .5836 Mdot
.53004 .58167 Mdot
.68118 .75173 Mdot
.22779 .62765 Mdot
.49211 .30481 Mdot
.5457 .55818 Mdot
.54354 .65591 Mdot
.37219 .39305 Mdot
.55972 .6222 Mdot
.32514 .59522 Mdot
.65153 .41296 Mdot
.39344 .44031 Mdot
.35032 .59745 Mdot
.60142 .63882 Mdot
.33346 .57511 Mdot
.33988 .44738 Mdot
.52965 .32972 Mdot
.5541 .64678 Mdot
.32246 .61966 Mdot
.33727 .57541 Mdot
.54944 .60026 Mdot
.67669 .41521 Mdot
.62772 .582 Mdot
.58957 .60584 Mdot
.53086 .65047 Mdot
.62801 .41444 Mdot
.48922 .87854 Mdot
.52685 .59313 Mdot
.42898 .72293 Mdot
.61528 .44088 Mdot
.54566 .48794 Mdot
.35015 .41121 Mdot
.52073 .58979 Mdot
.52962 .32918 Mdot
.52366 .32337 Mdot
.37934 .46623 Mdot
.68512 .42153 Mdot
.26913 .43942 Mdot
.66322 .3766 Mdot
.49193 .61511 Mdot
.53581 .56186 Mdot
.61549 .51782 Mdot
.53181 .81852 Mdot
.62121 .40585 Mdot
.35357 .50636 Mdot
.68016 .3674 Mdot
.50129 .30965 Mdot
.36372 .47879 Mdot
.66444 .38211 Mdot
.63026 .40789 Mdot
.67368 .40183 Mdot
.33549 .61547 Mdot
.27543 .49179 Mdot
.61489 .44617 Mdot
.62692 .46575 Mdot
.57314 .58275 Mdot
.53686 .65147 Mdot
.74924 .68317 Mdot
.73912 .68057 Mdot
.31442 .58587 Mdot
.33974 .46178 Mdot
.40842 .13277 Mdot
.53312 .33972 Mdot
.3512 .23036 Mdot
.5282 .65972 Mdot
.45511 .1096 Mdot
.52236 .61765 Mdot
.55491 .62494 Mdot
.66175 .38128 Mdot
.31797 .61566 Mdot
.33954 .58818 Mdot
.62386 .44065 Mdot
.61471 .45545 Mdot
.32562 .59337 Mdot
.21489 .39714 Mdot
.37757 .81316 Mdot
.39724 .37243 Mdot
.65405 .43393 Mdot
.66014 .70839 Mdot
.47159 .3171 Mdot
.59496 .70128 Mdot
.45819 .31681 Mdot
.36683 .44672 Mdot
.39922 .43841 Mdot
.4804 .35577 Mdot
.58044 .59405 Mdot
.35173 .4638 Mdot
.60805 .62264 Mdot
.30931 .29665 Mdot
.72258 .61136 Mdot
.2837 .43932 Mdot
.58417 .71621 Mdot
.57846 .48216 Mdot
.4835 .26335 Mdot
.59488 .64552 Mdot
.31954 .75573 Mdot
.33936 .5787 Mdot
.49247 .63803 Mdot
.49337 .36225 Mdot
.78573 .67128 Mdot
.563 .65233 Mdot
.64535 .44228 Mdot
.51774 .35106 Mdot
.67982 .28298 Mdot
.66036 .29934 Mdot
.53924 .64237 Mdot
.60567 .17069 Mdot
.61966 .47635 Mdot
.36783 .45808 Mdot
.73599 .3633 Mdot
.61076 .42562 Mdot
.37096 .54923 Mdot
.34381 .74586 Mdot
.18019 .5714 Mdot
.64914 .40466 Mdot
.399 .411 Mdot
.65798 .3919 Mdot
.36225 .58859 Mdot
.61221 .39092 Mdot
.35364 .44861 Mdot
.5891 .6329 Mdot
.35989 .42039 Mdot
.32964 .61501 Mdot
.81382 .49857 Mdot
.4921 .30489 Mdot
.32909 .46707 Mdot
.48132 .34144 Mdot
.33609 .68451 Mdot
.40933 .75154 Mdot
.47662 .32918 Mdot
.66975 .527 Mdot
.53268 .56478 Mdot
.61065 .43616 Mdot
.34453 .41781 Mdot
.269 .61763 Mdot
.52531 .39709 Mdot
.64258 .42035 Mdot
.35114 .46947 Mdot
.68518 .32362 Mdot
.63676 .49841 Mdot
.53875 .55829 Mdot
.41871 .60587 Mdot
.65049 .43273 Mdot
.39627 .41064 Mdot
.83927 .46268 Mdot
.65481 .39131 Mdot
.32069 .42954 Mdot
.47977 .31641 Mdot
.51916 .3353 Mdot
.5629 .56721 Mdot
.45004 .355 Mdot
.37161 .46554 Mdot
.49654 .28819 Mdot
.67329 .44959 Mdot
.70363 .30633 Mdot
.34114 .6228 Mdot
.36887 .43137 Mdot
.61255 .63079 Mdot
.6166 .46674 Mdot
.4144 .25753 Mdot
.68556 .60009 Mdot
.72102 .25932 Mdot
.35165 .41962 Mdot
.64574 .41179 Mdot
.64955 .44282 Mdot
.49991 .61748 Mdot
.70209 .34606 Mdot
.26046 .4528 Mdot
.60519 .50739 Mdot
.55904 .4193 Mdot
.34418 .4095 Mdot
.41198 .4601 Mdot
.61805 .59684 Mdot
.57442 .5966 Mdot
.49592 .30884 Mdot
.58809 .62959 Mdot
.68198 .42586 Mdot
.54326 .57435 Mdot
.48251 .33209 Mdot
.37671 .45049 Mdot
.55936 .64874 Mdot
.33971 .57385 Mdot
.45775 .34009 Mdot
.53729 .34625 Mdot
.37312 .42916 Mdot
.61767 .42707 Mdot
.53394 .49662 Mdot
.3428 .42472 Mdot
.57186 .59011 Mdot
.445 .51483 Mdot
.55264 .66074 Mdot
.53489 .51783 Mdot
.64835 .39113 Mdot
.39346 .43863 Mdot
.64387 .37244 Mdot
.49027 .34009 Mdot
.31279 .71024 Mdot
.57573 .62518 Mdot
.32647 .42257 Mdot
.44472 .27148 Mdot
.51208 .5197 Mdot
.67206 .46443 Mdot
.26214 .37072 Mdot
.60715 .42811 Mdot
.33554 .45666 Mdot
.29237 .26274 Mdot
.34987 .61081 Mdot
.38879 .4658 Mdot
.4922 .81831 Mdot
.38316 .42805 Mdot
.55642 .56878 Mdot
.52818 .5969 Mdot
.38809 .44813 Mdot
.3298 .57212 Mdot
.82988 .5821 Mdot
.41875 .42374 Mdot
.64648 .40573 Mdot
.26252 .32786 Mdot
.7815 .33228 Mdot
.51873 .28095 Mdot
.50015 .31038 Mdot
.5615 .69403 Mdot
.52527 .57612 Mdot
.50362 .36359 Mdot
.48849 .30304 Mdot
.36764 .59602 Mdot
.32561 .42939 Mdot
.62904 .47698 Mdot
.54363 .35098 Mdot
.71599 .38829 Mdot
.30326 .51615 Mdot
.50206 .60833 Mdot
.49044 .20063 Mdot
.52912 .65908 Mdot
.37608 .73528 Mdot
.47907 .33382 Mdot
.58616 .66641 Mdot
.52766 .55985 Mdot
.52097 .35537 Mdot
.32583 .60067 Mdot
.40206 .48464 Mdot
.35815 .43424 Mdot
.49187 .86897 Mdot
.60274 .60324 Mdot
.54865 .57401 Mdot
.49538 .35537 Mdot
.23653 .53315 Mdot
.65435 .42179 Mdot
.61137 .40715 Mdot
.37643 .45826 Mdot
.46537 .40608 Mdot
.54291 .56575 Mdot
.59348 .64062 Mdot
.35087 .43596 Mdot
.33691 .47001 Mdot
.31678 .35174 Mdot
.54504 .59111 Mdot
.50445 .3489 Mdot
.3139 .6486 Mdot
.47439 .33854 Mdot
.56339 .66321 Mdot
.54854 .57692 Mdot
.51253 .6241 Mdot
.60535 .64872 Mdot
.44516 .33152 Mdot
.55702 .66541 Mdot
.55563 .54465 Mdot
.6447 .4144 Mdot
.53489 .64359 Mdot
.5548 .40764 Mdot
.58583 .62092 Mdot
.32618 .59689 Mdot
.77329 .44716 Mdot
.56193 .65168 Mdot
.53774 .57692 Mdot
.39523 .47041 Mdot
.57338 .63725 Mdot
.52628 .32203 Mdot
.6637 .43209 Mdot
.50364 .35487 Mdot
.52162 .32088 Mdot
.37846 .40282 Mdot
.35007 .56438 Mdot
.54574 .68028 Mdot
.31591 .60051 Mdot
.50816 .66007 Mdot
.60492 .6223 Mdot
.31706 .54227 Mdot
.48733 .14824 Mdot
.81205 .45853 Mdot
.57701 .62363 Mdot
.38401 .42281 Mdot
.37698 .41561 Mdot
.5748 .50501 Mdot
.5617 .55766 Mdot
.50925 .36876 Mdot
.50544 .31051 Mdot
.63462 .74514 Mdot
.51939 .74722 Mdot
.32587 .59761 Mdot
.47775 .4849 Mdot
.59088 .58608 Mdot
.58771 .66491 Mdot
.60428 .60079 Mdot
.39025 .41376 Mdot
.63729 .68713 Mdot
.36928 .47588 Mdot
.53264 .26416 Mdot
.48034 .35149 Mdot
.5492 .6472 Mdot
.46849 .20513 Mdot
.6417 .45899 Mdot
.66405 .43276 Mdot
.53637 .35364 Mdot
.30503 .42881 Mdot
.79232 .61809 Mdot
.20097 .65483 Mdot
.59249 .41249 Mdot
.32545 .61755 Mdot
.59893 .63383 Mdot
.38435 .44266 Mdot
.67437 .43807 Mdot
.32434 .61651 Mdot
.56954 .66006 Mdot
.2767 .49296 Mdot
.58013 .61587 Mdot
.55693 .22925 Mdot
.66813 .40263 Mdot
.33502 .80238 Mdot
.68549 .4249 Mdot
.45695 .35117 Mdot
.4874 .36289 Mdot
.5422 .58731 Mdot
.59414 .46032 Mdot
.60947 .42578 Mdot
.38409 .52644 Mdot
.35896 .57092 Mdot
.5392 .28728 Mdot
.34924 .60805 Mdot
.3573 .45716 Mdot
.33332 .61164 Mdot
.35109 .44835 Mdot
.79888 .60215 Mdot
.7023 .46274 Mdot
.34826 .59132 Mdot
.45322 .26585 Mdot
.5229 .58002 Mdot
.31168 .5888 Mdot
.5946 .56839 Mdot
.56548 .51629 Mdot
.34983 .43338 Mdot
.36152 .57615 Mdot
.58894 .6616 Mdot
.58915 .79581 Mdot
.48064 .3229 Mdot
.50203 .36843 Mdot
.59483 .5693 Mdot
.3569 .40679 Mdot
.64891 .38277 Mdot
.2691 .7154 Mdot
.54738 .35836 Mdot
.53221 .59004 Mdot
.51433 .60331 Mdot
.60778 .43209 Mdot
.40686 .20409 Mdot
.54908 .58248 Mdot
.4946 .55272 Mdot
.54198 .59099 Mdot
.4651 .34268 Mdot
.62858 .39622 Mdot
.65662 .43952 Mdot
.35108 .46849 Mdot
.64732 .46254 Mdot
.43982 .57083 Mdot
.50457 .22883 Mdot
.60185 .55456 Mdot
.49306 .33674 Mdot
.56031 .28628 Mdot
.51515 .24978 Mdot
.49462 .80541 Mdot
.68029 .45439 Mdot
.56316 .66938 Mdot
.6465 .46453 Mdot
.34269 .60822 Mdot
.66543 .44033 Mdot
.68353 .41434 Mdot
.57921 .65079 Mdot
.5392 .63744 Mdot
.37298 .45437 Mdot
.69562 .34293 Mdot
.61523 .43192 Mdot
.52308 .61739 Mdot
.50816 .61086 Mdot
.61008 .62569 Mdot
.39805 .53656 Mdot
.62489 .40069 Mdot
.19518 .38822 Mdot
.45298 .66101 Mdot
.61565 .43016 Mdot
.86416 .53754 Mdot
.43533 .2671 Mdot
.32724 .48418 Mdot
.39024 .50701 Mdot
.53932 .59351 Mdot
.32071 .45214 Mdot
.54452 .64085 Mdot
.49268 .20225 Mdot
.5678 .64 Mdot
.324 .59548 Mdot
.60536 .61336 Mdot
.39655 .44858 Mdot
.35061 .42204 Mdot
.53394 .58611 Mdot
.55677 .64587 Mdot
.82203 .51531 Mdot
.62065 .3844 Mdot
.66994 .42679 Mdot
.28241 .42008 Mdot
.35328 .58778 Mdot
.48619 .35967 Mdot
.56232 .61607 Mdot
.38161 .40471 Mdot
.35291 .42127 Mdot
.61549 .41231 Mdot
.33524 .44247 Mdot
.49584 .32692 Mdot
.57218 .6246 Mdot
.50217 .36521 Mdot
.34655 .61441 Mdot
.62866 .39748 Mdot
.53642 .643 Mdot
.57354 .58285 Mdot
.66854 .41668 Mdot
.58045 .67325 Mdot
.33325 .57211 Mdot
.37893 .42467 Mdot
.64979 .40347 Mdot
.51119 .33339 Mdot
.35493 .45543 Mdot
.5333 .65578 Mdot
.573 .16631 Mdot
.56649 .57107 Mdot
.53277 .60204 Mdot
.52679 .83011 Mdot
.59446 .59244 Mdot
.34725 .41866 Mdot
.67259 .44183 Mdot
.48963 .64596 Mdot
.43534 .68456 Mdot
.45327 .88872 Mdot
.3735 .47338 Mdot
.59762 .62707 Mdot
.5273 .80239 Mdot
.595 .62692 Mdot
.67876 .64422 Mdot
.33185 .47377 Mdot
.54816 .45033 Mdot
.6103 .64575 Mdot
.51174 .32267 Mdot
.38343 .44979 Mdot
.34682 .44671 Mdot
.29089 .30073 Mdot
.58612 .64931 Mdot
.43377 .49678 Mdot
.56122 .65927 Mdot
.51205 .33101 Mdot
.54217 .74083 Mdot
.34797 .42117 Mdot
.75932 .32279 Mdot
.54834 .5967 Mdot
.62694 .40736 Mdot
.39938 .46133 Mdot
.54265 .37669 Mdot
.52834 .64653 Mdot
.32009 .58499 Mdot
.51727 .30766 Mdot
.60005 .55885 Mdot
.49467 .33428 Mdot
.53258 .65174 Mdot
.5248 .70188 Mdot
.6773 .25743 Mdot
.67645 .40935 Mdot
.48819 .31187 Mdot
.43318 .52856 Mdot
.56508 .66804 Mdot
.65048 .40506 Mdot
.64507 .41945 Mdot
.34085 .61614 Mdot
.52423 .47497 Mdot
.63359 .2667 Mdot
.70554 .66174 Mdot
.27417 .31458 Mdot
.38825 .47136 Mdot
.38041 .35232 Mdot
.53477 .60961 Mdot
.42432 .58609 Mdot
.52112 .31784 Mdot
.56992 .57196 Mdot
.77326 .49518 Mdot
.63071 .45366 Mdot
.56954 .57494 Mdot
.33494 .58974 Mdot
.39275 .60178 Mdot
.32668 .65028 Mdot
.39718 .77857 Mdot
.37192 .4487 Mdot
.54327 .54356 Mdot
.48606 .64729 Mdot
.34769 .41065 Mdot
.50959 .63471 Mdot
.34329 .41573 Mdot
.19533 .44185 Mdot
.30987 .59878 Mdot
.63039 .40059 Mdot
.51012 .26729 Mdot
.52478 .66235 Mdot
.53262 .57274 Mdot
.35668 .56486 Mdot
.57087 .59625 Mdot
.62074 .21141 Mdot
.3966 .5409 Mdot
.35105 .45979 Mdot
.67459 .4039 Mdot
.50916 .6216 Mdot
.4688 .51157 Mdot
.59172 .61845 Mdot
.75049 .63264 Mdot
.53583 .57857 Mdot
.66658 .29797 Mdot
.67252 .40712 Mdot
.48673 .33576 Mdot
.59083 .66775 Mdot
.56169 .63434 Mdot
.47712 .73604 Mdot
.51679 .66698 Mdot
.5806 .66828 Mdot
.69325 .41675 Mdot
.67952 .41008 Mdot
.65795 .39412 Mdot
.37481 .46965 Mdot
.5866 .7676 Mdot
.49898 .34499 Mdot
.51181 .68152 Mdot
.53479 .36531 Mdot
.66006 .58268 Mdot
.31763 .61177 Mdot
.45091 .77877 Mdot
.54933 .61497 Mdot
.65073 .45168 Mdot
.26512 .68473 Mdot
.61525 .39454 Mdot
.47224 .47606 Mdot
.52015 .34742 Mdot
.62207 .43813 Mdot
.55618 .62886 Mdot
.64499 .35809 Mdot
.55269 .8095 Mdot
.49067 .34689 Mdot
.50569 .64894 Mdot
.39685 .45469 Mdot
.29162 .47482 Mdot
.70882 .27335 Mdot
.47707 .32503 Mdot
.5564 .35363 Mdot
.5894 .64836 Mdot
.65004 .45971 Mdot
.51074 .32483 Mdot
.46642 .34251 Mdot
.33604 .447 Mdot
.53693 .63538 Mdot
.53492 .63124 Mdot
.33915 .46336 Mdot
.50077 .35495 Mdot
.56338 .54832 Mdot
.59072 .54682 Mdot
.71435 .75838 Mdot
.68807 .31134 Mdot
.50318 .87633 Mdot
.55581 .50343 Mdot
.75289 .48084 Mdot
.27034 .72251 Mdot
.61782 .42009 Mdot
.59721 .64938 Mdot
.62599 .6363 Mdot
.37201 .46569 Mdot
.58045 .63414 Mdot
.3135 .46237 Mdot
.5282 .34156 Mdot
.78157 .67391 Mdot
.60268 .3132 Mdot
.18087 .5063 Mdot
.58044 .63648 Mdot
.68632 .45919 Mdot
.34131 .60503 Mdot
.55144 .31332 Mdot
.63637 .39306 Mdot
.61291 .61417 Mdot
.82034 .5117 Mdot
.38453 .46857 Mdot
.63062 .41972 Mdot
.83813 .54754 Mdot
.58324 .47697 Mdot
.55352 .66046 Mdot
.36005 .47539 Mdot
.30356 .74928 Mdot
.7297 .40951 Mdot
.50985 .37234 Mdot
.32541 .60149 Mdot
.39103 .44152 Mdot
.49817 .30771 Mdot
.67018 .47915 Mdot
.62751 .42795 Mdot
.63906 .38664 Mdot
.80154 .45886 Mdot
.36561 .48584 Mdot
.34358 .60307 Mdot
.52189 .76898 Mdot
.5003 .74124 Mdot
.32579 .59101 Mdot
.39955 .4382 Mdot
.68074 .42015 Mdot
.62782 .4468 Mdot
.66307 .43206 Mdot
.79141 .40351 Mdot
.65593 .46577 Mdot
.30504 .26967 Mdot
.60906 .63591 Mdot
.55941 .5311 Mdot
.5971 .63076 Mdot
.51427 .36749 Mdot
.66558 .4114 Mdot
.49771 .40562 Mdot
.49695 .63747 Mdot
.4477 .76468 Mdot
.55902 .56744 Mdot
.4544 .33165 Mdot
.5642 .57633 Mdot
.48682 .1834 Mdot
.63616 .46255 Mdot
.57811 .62785 Mdot
.45801 .32019 Mdot
.35559 .5846 Mdot
.67505 .46293 Mdot
.54073 .64444 Mdot
.24777 .3978 Mdot
.59946 .60296 Mdot
.18959 .48783 Mdot
.64296 .24968 Mdot
.32334 .61639 Mdot
.54488 .20404 Mdot
.4009 .40946 Mdot
.52451 .53617 Mdot
.54213 .69616 Mdot
.48551 .34314 Mdot
.53967 .28993 Mdot
.37352 .43973 Mdot
.65013 .65673 Mdot
.56888 .54271 Mdot
.34382 .61654 Mdot
.68947 .47632 Mdot
.51203 .36187 Mdot
.50792 .62613 Mdot
.52 .56638 Mdot
.37667 .23832 Mdot
.5847 .55428 Mdot
.51933 .59307 Mdot
.34998 .55901 Mdot
.33156 .24671 Mdot
.58517 .61344 Mdot
.4767 .47928 Mdot
.61474 .38949 Mdot
.49283 .62998 Mdot
.31183 .25978 Mdot
.52609 .59983 Mdot
.62338 .42478 Mdot
.50927 .53725 Mdot
.61036 .25267 Mdot
.34747 .56388 Mdot
.53606 .57786 Mdot
.39025 .19596 Mdot
.55759 .59279 Mdot
.50542 .34565 Mdot
.55877 .55776 Mdot
.35666 .44845 Mdot
.81671 .45074 Mdot
.35638 .46736 Mdot
.56519 .56495 Mdot
.65972 .43197 Mdot
.48762 .35323 Mdot
.76819 .38711 Mdot
.25788 .49282 Mdot
.37093 .22623 Mdot
.20646 .64637 Mdot
.35462 .56956 Mdot
.32034 .62678 Mdot
.52923 .35126 Mdot
.57933 .62624 Mdot
.2521 .30013 Mdot
.53 .67866 Mdot
.58068 .58725 Mdot
.56663 .64029 Mdot
.40223 .74788 Mdot
.52676 .32877 Mdot
.34841 .42862 Mdot
.54928 .57972 Mdot
.56575 .66698 Mdot
.62201 .41485 Mdot
.34913 .58078 Mdot
.35304 .41116 Mdot
.34143 .58254 Mdot
.38559 .44584 Mdot
.82333 .61154 Mdot
.54703 .54938 Mdot
.35827 .58566 Mdot
.53747 .32993 Mdot
.62272 .41973 Mdot
.51809 .23768 Mdot
.34931 .45216 Mdot
.36704 .46998 Mdot
.53275 .58413 Mdot
.61979 .43045 Mdot
.65433 .37574 Mdot
.35438 .60355 Mdot
.48328 .32664 Mdot
.5632 .65203 Mdot
.60047 .61147 Mdot
.49756 .68342 Mdot
.36339 .40415 Mdot
.54641 .22332 Mdot
.33222 .3653 Mdot
.57869 .62304 Mdot
.67317 .44894 Mdot
.5618 .64551 Mdot
.20804 .5704 Mdot
.64642 .46084 Mdot
.52371 .6058 Mdot
.86789 .49037 Mdot
.31124 .47633 Mdot
.58719 .26603 Mdot
.51512 .6069 Mdot
.26726 .74369 Mdot
.54099 .61141 Mdot
.79077 .6703 Mdot
.25442 .62618 Mdot
.54563 .56102 Mdot
.52614 .64525 Mdot
.70899 .59668 Mdot
.60037 .62202 Mdot
.34446 .46855 Mdot
.74036 .70267 Mdot
.62329 .3894 Mdot
.5064 .25076 Mdot
.77261 .45865 Mdot
.33926 .56444 Mdot
.37661 .45811 Mdot
.3871 .48426 Mdot
.33113 .58443 Mdot
.65182 .43575 Mdot
.57742 .61221 Mdot
.46362 .43413 Mdot
.36656 .40668 Mdot
.64068 .60859 Mdot
.5086 .34617 Mdot
.37291 .29591 Mdot
.40829 .59036 Mdot
.49626 .33161 Mdot
.53285 .64158 Mdot
.69793 .59173 Mdot
.79441 .59274 Mdot
.42289 .82839 Mdot
.48701 .30711 Mdot
.48872 .34776 Mdot
.80781 .42257 Mdot
.36466 .60967 Mdot
.37592 .24231 Mdot
.66512 .30048 Mdot
.48614 .35678 Mdot
.64241 .49076 Mdot
.3368 .46593 Mdot
.44492 .37507 Mdot
.4925 .58702 Mdot
.6064 .63346 Mdot
.55811 .63023 Mdot
.47533 .33296 Mdot
.5251 .51377 Mdot
.72633 .32351 Mdot
.47919 .34267 Mdot
.59983 .68718 Mdot
.52439 .44602 Mdot
.42536 .32574 Mdot
.33257 .43402 Mdot
.36266 .57294 Mdot
.35502 .62121 Mdot
.63464 .4054 Mdot
.35807 .5685 Mdot
.39197 .61433 Mdot
.56944 .60351 Mdot
.47392 .34554 Mdot
.45351 .24741 Mdot
.51665 .33731 Mdot
.33578 .58452 Mdot
.36783 .59969 Mdot
.6454 .41502 Mdot
.671 .43049 Mdot
.72342 .51893 Mdot
.41519 .62568 Mdot
.58807 .59688 Mdot
.27593 .60971 Mdot
.67896 .40169 Mdot
.6128 .536 Mdot
.36156 .57073 Mdot
.3536 .58517 Mdot
.46676 .73815 Mdot
.54951 .61837 Mdot
.63356 .55118 Mdot
.55474 .61757 Mdot
.47567 .67773 Mdot
.52176 .64604 Mdot
.3357 .4461 Mdot
.54111 .62078 Mdot
.46925 .74607 Mdot
.56299 .67912 Mdot
.51814 .57952 Mdot
.38689 .40935 Mdot
.5758 .54037 Mdot
.35739 .44697 Mdot
.57729 .5735 Mdot
.31474 .61801 Mdot
.37727 .45979 Mdot
.42321 .69185 Mdot
.44492 .73276 Mdot
.40042 .43211 Mdot
.32047 .609 Mdot
.32009 .57321 Mdot
.39102 .70292 Mdot
.6352 .39302 Mdot
.57291 .69884 Mdot
.58068 .62897 Mdot
.35448 .48025 Mdot
.51201 .31519 Mdot
.52867 .65375 Mdot
.51851 .58916 Mdot
.51636 .61838 Mdot
.63273 .40513 Mdot
.25909 .45901 Mdot
.36056 .58562 Mdot
.33924 .46524 Mdot
.52381 .49855 Mdot
.34487 .40868 Mdot
.50915 .5781 Mdot
.6227 .64733 Mdot
.77273 .4767 Mdot
.43518 .30064 Mdot
.79198 .38977 Mdot
.62871 .42641 Mdot
.37607 .41413 Mdot
.33722 .62414 Mdot
.61018 .6675 Mdot
.65138 .4529 Mdot
.354 .44823 Mdot
.57959 .61647 Mdot
.50731 .64681 Mdot
.48964 .23014 Mdot
.33803 .65435 Mdot
.436 .7176 Mdot
.38303 .46416 Mdot
.40565 .43579 Mdot
.43389 .74193 Mdot
.31279 .63845 Mdot
.51388 .39955 Mdot
.58818 .64162 Mdot
.32168 .58398 Mdot
.67043 .44293 Mdot
.79722 .48299 Mdot
.47174 .35565 Mdot
.70131 .34748 Mdot
.57891 .63555 Mdot
.56693 .46997 Mdot
.65922 .4303 Mdot
.3321 .59073 Mdot
.47269 .33579 Mdot
.37303 .61488 Mdot
.38377 .4129 Mdot
.17149 .56676 Mdot
.56374 .5914 Mdot
.5355 .58121 Mdot
.46216 .32391 Mdot
.64106 .4559 Mdot
.31753 .57054 Mdot
.26058 .33673 Mdot
.34138 .44537 Mdot
.26205 .28664 Mdot
.66979 .45155 Mdot
.6603 .70466 Mdot
.32842 .44464 Mdot
.54053 .35647 Mdot
.4004 .69463 Mdot
.49079 .32922 Mdot
.55621 .56412 Mdot
.64825 .44754 Mdot
.49394 .31132 Mdot
.70671 .33512 Mdot
.56643 .82317 Mdot
.6653 .70195 Mdot
.56898 .60932 Mdot
.64301 .7863 Mdot
.21049 .43937 Mdot
.5909 .41142 Mdot
.5107 .31151 Mdot
.56754 .57008 Mdot
.53503 .57505 Mdot
.55854 .59085 Mdot
.51492 .31963 Mdot
.27832 .60413 Mdot
.3473 .43485 Mdot
.59509 .64181 Mdot
.36647 .59868 Mdot
.36456 .445 Mdot
.53458 .37261 Mdot
.33584 .42887 Mdot
.68933 .42578 Mdot
.50243 .59489 Mdot
.56775 .35883 Mdot
.89105 .4451 Mdot
.4956 .35162 Mdot
.38428 .40422 Mdot
.56945 .55505 Mdot
.40513 .28731 Mdot
.6618 .38798 Mdot
.34048 .44802 Mdot
.54935 .57258 Mdot
.46147 .26201 Mdot
.81446 .48483 Mdot
.34011 .42435 Mdot
.65306 .45333 Mdot
.42955 .82669 Mdot
.58554 .63272 Mdot
.54942 .60587 Mdot
.62479 .43535 Mdot
.64181 .51423 Mdot
.83828 .48558 Mdot
.55828 .64544 Mdot
.48458 .33579 Mdot
.15264 .49667 Mdot
.51916 .58761 Mdot
.49444 .70725 Mdot
.37818 .45321 Mdot
.48313 .39139 Mdot
.58887 .23666 Mdot
.58182 .67844 Mdot
.32573 .2857 Mdot
.50851 .27122 Mdot
.57087 .78198 Mdot
.31033 .46027 Mdot
.23178 .46681 Mdot
.63127 .77539 Mdot
.44848 .3307 Mdot
.70026 .42778 Mdot
.29608 .30783 Mdot
.7431 .42096 Mdot
.35196 .78494 Mdot
.23054 .55379 Mdot
.82135 .5097 Mdot
.47907 .4318 Mdot
.3877 .43086 Mdot
.60164 .51602 Mdot
.544 .64285 Mdot
.20896 .44599 Mdot
.68051 .26918 Mdot
.70005 .28927 Mdot
.64369 .7871 Mdot
.67784 .6608 Mdot
.53318 .80355 Mdot
.50426 .81367 Mdot
.52364 .71927 Mdot
.36488 .36086 Mdot
.25053 .29517 Mdot
.79275 .63354 Mdot
.2229 .37078 Mdot
.56536 .53051 Mdot
.46206 .47636 Mdot
.18953 .55254 Mdot
.70555 .45115 Mdot
.64352 .4981 Mdot
.34649 .46486 Mdot
.63776 .39039 Mdot
.358 .25715 Mdot
.60667 .43546 Mdot
.60758 .24941 Mdot
.45676 .83926 Mdot
.55754 .82235 Mdot
.40797 .19654 Mdot
.27414 .74217 Mdot
.76652 .49349 Mdot
.22428 .2834 Mdot
.31184 .44206 Mdot
.61476 .41599 Mdot
.38751 .73556 Mdot
.49248 .75836 Mdot
.58236 .32698 Mdot
.2595 .35889 Mdot
.29538 .49762 Mdot
.35098 .67293 Mdot
.64765 .44143 Mdot
.55759 .21201 Mdot
.45766 .3758 Mdot
.59703 .31716 Mdot
.76808 .66516 Mdot
.42785 .81005 Mdot
.45332 .4386 Mdot
.28824 .33994 Mdot
.37759 .31599 Mdot
.74103 .33152 Mdot
.43983 .66297 Mdot
.59163 .50684 Mdot
.67867 .30246 Mdot
.24663 .68518 Mdot
.70638 .4895 Mdot
.47241 .66844 Mdot
.50399 .75935 Mdot
.83496 .58512 Mdot
.20449 .4992 Mdot
.8124 .34279 Mdot
.60452 .43408 Mdot
.5128 .60618 Mdot
.66047 .53197 Mdot
.35476 .20902 Mdot
.36479 .56101 Mdot
.38149 .77432 Mdot
.36569 .5872 Mdot
.68722 .41363 Mdot
.82585 .47429 Mdot
.3234 .2505 Mdot
.29759 .24139 Mdot
.31815 .62287 Mdot
.51088 .68184 Mdot
.26957 .78644 Mdot
.51629 .78408 Mdot
.58927 .28851 Mdot
.7212 .74982 Mdot
.53725 .43196 Mdot
.69669 .29896 Mdot
.49601 .31062 Mdot
.66356 .76467 Mdot
.63211 .44591 Mdot
.81328 .32341 Mdot
.80308 .65465 Mdot
.78839 .49709 Mdot
.81215 .73733 Mdot
.41817 .74524 Mdot
.55265 .45326 Mdot
.51471 .28944 Mdot
.40624 .66118 Mdot
.73789 .35693 Mdot
.31118 .69768 Mdot
.39724 .29581 Mdot
.25916 .74249 Mdot
.61907 .7846 Mdot
.27643 .26268 Mdot
.16908 .50165 Mdot
.71865 .46466 Mdot
.47513 .50654 Mdot
.5824 .71229 Mdot
.29083 .46148 Mdot
.36525 .77367 Mdot
.84698 .57181 Mdot
.45436 .66479 Mdot
.44612 .88766 Mdot
.29489 .60418 Mdot
.28778 .51884 Mdot
.50181 .8564 Mdot
.36324 .67959 Mdot
.59557 .22718 Mdot
.57297 .75929 Mdot
.61667 .70145 Mdot
.47529 .52458 Mdot
.38083 .77933 Mdot
.55001 .24418 Mdot
.71364 .73083 Mdot
.3029 .76308 Mdot
.38169 .23654 Mdot
.72569 .62381 Mdot
.50242 .73017 Mdot
.64506 .47865 Mdot
.39122 .63189 Mdot
.6001 .23767 Mdot
.5905 .82012 Mdot
.44735 .34362 Mdot
.62262 .81758 Mdot
.8376 .49338 Mdot
.54896 .5478 Mdot
.58453 .69301 Mdot
.5996 .49527 Mdot
.38026 .64256 Mdot
.55232 .53728 Mdot
.461 .22381 Mdot
.54756 .82732 Mdot
.77585 .61191 Mdot
.48167 .26082 Mdot
.52852 .2792 Mdot
.50008 .86213 Mdot
.68788 .55011 Mdot
.31033 .63393 Mdot
.71558 .71461 Mdot
.74204 .35692 Mdot
.36805 .43662 Mdot
.28594 .25965 Mdot
.54873 .33615 Mdot
.80721 .48736 Mdot
.70252 .66204 Mdot
.74981 .45377 Mdot
.54821 .82802 Mdot
.24585 .44642 Mdot
.82779 .49166 Mdot
.33939 .69472 Mdot
.232 .33749 Mdot
.42856 .31875 Mdot
.62259 .60141 Mdot
.25423 .37003 Mdot
.32102 .57526 Mdot
.72657 .55572 Mdot
.16414 .43851 Mdot
.25246 .55064 Mdot
.61035 .58569 Mdot
.79006 .49212 Mdot
.36026 .49743 Mdot
.63992 .35747 Mdot
.74752 .27409 Mdot
.51016 .5915 Mdot
.52417 .76367 Mdot
.23101 .44137 Mdot
.40859 .64545 Mdot
.36426 .81088 Mdot
.22032 .61516 Mdot
.83781 .3696 Mdot
.68371 .76607 Mdot
.25182 .48656 Mdot
.61344 .77526 Mdot
.61396 .7989 Mdot
.83662 .37709 Mdot
.54686 .69186 Mdot
.45836 .35575 Mdot
.53845 .14561 Mdot
.33142 .4331 Mdot
.50041 .76948 Mdot
.27432 .31429 Mdot
.39976 .58425 Mdot
.57231 .38761 Mdot
.64848 .64815 Mdot
.47684 .43905 Mdot
.62238 .38205 Mdot
.55425 .53815 Mdot
.7931 .3548 Mdot
.86334 .42579 Mdot
.80772 .35386 Mdot
.21025 .63255 Mdot
.6677 .75858 Mdot
.55324 .47492 Mdot
.37903 .20735 Mdot
.61833 .54747 Mdot
.59309 .6586 Mdot
.3849 .57588 Mdot
.4111 .74384 Mdot
.78971 .46501 Mdot
.6268 .31907 Mdot
.69861 .46879 Mdot
.37922 .77511 Mdot
.09897 .53811 Mdot
.74049 .5158 Mdot
.28349 .2875 Mdot
.33817 .63354 Mdot
.41037 .63009 Mdot
.32375 .74276 Mdot
.77674 .44161 Mdot
.51572 .8239 Mdot
.62436 .38162 Mdot
.24075 .3568 Mdot
.25045 .57829 Mdot
.70313 .41145 Mdot
.26021 .46314 Mdot
.50576 .79342 Mdot
.53758 .2776 Mdot
.76967 .41643 Mdot
.65723 .30807 Mdot
.67045 .52326 Mdot
.38063 .53531 Mdot
.35889 .31381 Mdot
.19468 .38668 Mdot
.21446 .55968 Mdot
.4938 .70336 Mdot
.5157 .44711 Mdot
.52442 .19619 Mdot
.47698 .27275 Mdot
.47008 .67357 Mdot
.55124 .40574 Mdot
.55475 .76294 Mdot
.80224 .26359 Mdot
.76193 .31341 Mdot
.45134 .847 Mdot
.28183 .66744 Mdot
.60239 .56622 Mdot
.50156 .82995 Mdot
.79042 .3104 Mdot
.87646 .52111 Mdot
.3344 .32396 Mdot
.30891 .43878 Mdot
.53885 .36191 Mdot
.80916 .39369 Mdot
.29338 .56629 Mdot
.47096 .81843 Mdot
.47741 .70063 Mdot
.53729 .33777 Mdot
.45279 .14295 Mdot
.82316 .59896 Mdot
.68879 .68431 Mdot
.35164 .64982 Mdot
.62026 .6376 Mdot
.57326 .20019 Mdot
.60842 .42238 Mdot
.39909 .34264 Mdot
.42093 .6269 Mdot
.36592 .42762 Mdot
.36114 .74027 Mdot
.24342 .37419 Mdot
.60571 .61425 Mdot
.44894 .5196 Mdot
.65804 .46997 Mdot
.42811 .30992 Mdot
.55285 .27287 Mdot
.87748 .49263 Mdot
.37187 .62029 Mdot
.61277 .63769 Mdot
.41706 .64863 Mdot
.26721 .45092 Mdot
.83957 .46221 Mdot
.53297 .34587 Mdot
.59606 .79257 Mdot
.45193 .45923 Mdot
.40399 .62374 Mdot
.73403 .39394 Mdot
.5882 .5238 Mdot
.52659 .56946 Mdot
.24037 .662 Mdot
.77502 .5991 Mdot
.69205 .36821 Mdot
.48759 .61022 Mdot
.63462 .58532 Mdot
.49458 .83001 Mdot
.39151 .60861 Mdot
.37425 .30296 Mdot
.58336 .80184 Mdot
.52286 .33193 Mdot
.64901 .46447 Mdot
.28617 .61016 Mdot
.21571 .38361 Mdot
.65457 .72715 Mdot
.81438 .48319 Mdot
.41328 .57634 Mdot
.25967 .54153 Mdot
.58203 .81089 Mdot
.57746 .7899 Mdot
.50277 .17124 Mdot
.60285 .45901 Mdot
.44916 .61086 Mdot
.20761 .38652 Mdot
.66502 .38618 Mdot
.35902 .23743 Mdot
.39549 .22679 Mdot
.80461 .63989 Mdot
.44004 .52108 Mdot
.26754 .75457 Mdot
.43508 .71366 Mdot
.34543 .74924 Mdot
.76806 .38155 Mdot
.22405 .35858 Mdot
.47825 .77655 Mdot
.59354 .40431 Mdot
.70473 .61688 Mdot
.59778 .55143 Mdot
.46765 .1934 Mdot
.53896 .1536 Mdot
.29226 .5873 Mdot
.56335 .42451 Mdot
.30951 .77114 Mdot
.57638 .59821 Mdot
.73186 .26883 Mdot
.24162 .36848 Mdot
.80248 .41522 Mdot
.53918 .34651 Mdot
.5419 .65457 Mdot
.53249 .67307 Mdot
.65641 .74861 Mdot
.59943 .24872 Mdot
.56783 .76481 Mdot
.15806 .49491 Mdot
.31601 .75752 Mdot
.70701 .46346 Mdot
.50244 .76688 Mdot
.43088 .81293 Mdot
.21058 .44976 Mdot
.51344 .47085 Mdot
.31123 .70494 Mdot
.38098 .68163 Mdot
.26223 .71842 Mdot
.5584 .39037 Mdot
.4166 .4701 Mdot
.52431 .26028 Mdot
.28141 .39321 Mdot
.7916 .43549 Mdot
.52748 .63664 Mdot
.83788 .54853 Mdot
.48366 .80912 Mdot
.54492 .186 Mdot
.68758 .25954 Mdot
.76558 .31795 Mdot
.75677 .61176 Mdot
.21191 .49547 Mdot
.22147 .41564 Mdot
.18377 .38745 Mdot
.44649 .46125 Mdot
.42361 .76273 Mdot
.35655 .68686 Mdot
.58263 .80737 Mdot
.46155 .32728 Mdot
.64967 .2894 Mdot
.49621 .25877 Mdot
.5957 .77321 Mdot
.69255 .5618 Mdot
.51162 .804 Mdot
.52326 .42341 Mdot
.84103 .36914 Mdot
.22449 .59867 Mdot
.49182 .4277 Mdot
.38865 .41858 Mdot
.22891 .48567 Mdot
.42406 .78844 Mdot
.23172 .60651 Mdot
.24044 .33354 Mdot
.31198 .47406 Mdot
.51345 .50861 Mdot
.66156 .68126 Mdot
.38936 .63046 Mdot
.23774 .66209 Mdot
.41619 .64852 Mdot
.5456 .8203 Mdot
.67514 .74753 Mdot
.83751 .5448 Mdot
.42624 .74953 Mdot
.19967 .63495 Mdot
.58875 .28509 Mdot
.36497 .63997 Mdot
.24263 .37036 Mdot
.29365 .53475 Mdot
.60839 .38772 Mdot
.50209 .09314 Mdot
.17526 .5618 Mdot
.21304 .53646 Mdot
.84322 .57748 Mdot
.21795 .62135 Mdot
.43246 .30106 Mdot
.65948 .504 Mdot
.69504 .32888 Mdot
.81951 .56838 Mdot
.56628 .63915 Mdot
.78726 .33238 Mdot
.42981 .60271 Mdot
.88177 .44655 Mdot
.47261 .82724 Mdot
.56258 .41585 Mdot
.50354 .59083 Mdot
.34637 .47275 Mdot
.43096 .49209 Mdot
.55026 .7391 Mdot
.66955 .56672 Mdot
.63402 .24203 Mdot
.46183 .27943 Mdot
.31336 .44007 Mdot
.28 .42893 Mdot
.60086 .39817 Mdot
.28249 .65722 Mdot
.30478 .37748 Mdot
.33203 .39893 Mdot
.44539 .43551 Mdot
.44282 .64242 Mdot
.57954 .2312 Mdot
.68212 .69331 Mdot
.7801 .44185 Mdot
.57159 .3372 Mdot
.33448 .45139 Mdot
.70374 .67348 Mdot
.18645 .56023 Mdot
.30339 .75343 Mdot
.8468 .56847 Mdot
.47288 .52298 Mdot
.6803 .59789 Mdot
.51538 .72405 Mdot
.71657 .30222 Mdot
.59482 .46802 Mdot
.44656 .29854 Mdot
.57209 .20228 Mdot
.61693 .49537 Mdot
.31252 .30025 Mdot
.7839 .67163 Mdot
.22799 .36689 Mdot
.20591 .38696 Mdot
.35969 .53135 Mdot
.47625 .63525 Mdot
.69521 .41624 Mdot
.42727 .69978 Mdot
.53427 .39381 Mdot
.29016 .2301 Mdot
.49234 .63784 Mdot
.26381 .22758 Mdot
.46489 .33795 Mdot
.72975 .43657 Mdot
.37574 .6865 Mdot
.52414 .45231 Mdot
.53304 .41663 Mdot
.21573 .57564 Mdot
.65953 .28898 Mdot
.2087 .48123 Mdot
.72351 .32474 Mdot
.31157 .44608 Mdot
.15075 .53464 Mdot
.20814 .66764 Mdot
.71506 .61712 Mdot
.59242 .58228 Mdot
.17759 .58799 Mdot
.31605 .4261 Mdot
.78573 .45666 Mdot
.37056 .81332 Mdot
.27564 .69742 Mdot
.65906 .66558 Mdot
.40611 .6278 Mdot
.43104 .76526 Mdot
.6591 .78732 Mdot
.53671 .16554 Mdot
.37076 .77123 Mdot
.46289 .32648 Mdot
.52161 .43204 Mdot
.47356 .79186 Mdot
.67316 .27729 Mdot
.44709 .35964 Mdot
.62103 .23826 Mdot
.19882 .29909 Mdot
.50771 .77431 Mdot
.54678 .75767 Mdot
.66762 .26529 Mdot
.68484 .42801 Mdot
.64986 .27124 Mdot
.59218 .22635 Mdot
.25798 .66098 Mdot
.18539 .50865 Mdot
.59316 .23034 Mdot
.18935 .35532 Mdot
.56193 .5154 Mdot
.42034 .38314 Mdot
.62974 .54952 Mdot
.58137 .74014 Mdot
.52574 .31654 Mdot
.78685 .62823 Mdot
.3361 .77608 Mdot
.46867 .36483 Mdot
.25121 .67727 Mdot
.2818 .34786 Mdot
.59397 .72743 Mdot
.66915 .71996 Mdot
.3024 .73159 Mdot
.69182 .58103 Mdot
.46761 .18238 Mdot
.79879 .50335 Mdot
.31869 .41746 Mdot
.37647 .80019 Mdot
.34971 .45683 Mdot
.64257 .62183 Mdot
.70805 .35129 Mdot
.31698 .70384 Mdot
.7978 .39834 Mdot
.33329 .56652 Mdot
.61496 .40737 Mdot
.54092 .15792 Mdot
.67585 .43988 Mdot
.79953 .36056 Mdot
.75503 .44929 Mdot
.60591 .2159 Mdot
.24848 .49606 Mdot
.23919 .53058 Mdot
.18774 .32684 Mdot
.47237 .38008 Mdot
.30512 .41568 Mdot
.43829 .2045 Mdot
.61234 .41805 Mdot
.35846 .53281 Mdot
.39747 .42806 Mdot
.43238 .42008 Mdot
.38354 .24673 Mdot
.55321 .51751 Mdot
.64883 .48258 Mdot
.43534 .43379 Mdot
.73952 .68528 Mdot
.73259 .72397 Mdot
.35173 .41431 Mdot
.31664 .19766 Mdot
.51029 .58154 Mdot
.72962 .61121 Mdot
.52505 .82727 Mdot
.44698 .1439 Mdot
.32774 .38183 Mdot
.22725 .70421 Mdot
.59592 .66878 Mdot
.30176 .71315 Mdot
.63649 .44229 Mdot
.23442 .36395 Mdot
.35757 .60444 Mdot
.40308 .64831 Mdot
.46765 .35761 Mdot
.76829 .41446 Mdot
.31436 .38509 Mdot
.64496 .38486 Mdot
.27554 .66824 Mdot
.52155 .71732 Mdot
.47507 .29897 Mdot
.24872 .46241 Mdot
.71303 .62595 Mdot
.62344 .73348 Mdot
.67992 .47974 Mdot
.53502 .75677 Mdot
.18289 .41937 Mdot
.88042 .49244 Mdot
.61336 .36791 Mdot
.58341 .48158 Mdot
.43237 .22638 Mdot
.27283 .70762 Mdot
.49236 .20827 Mdot
.54639 .83209 Mdot
.44379 .63171 Mdot
.47616 .56273 Mdot
.46393 .66029 Mdot
.61388 .55851 Mdot
.4934 .45734 Mdot
.38176 .32473 Mdot
.65404 .24291 Mdot
.55529 .22923 Mdot
.69127 .49562 Mdot
.4883 .1935 Mdot
.52016 .74315 Mdot
.60989 .22093 Mdot
.34292 .39937 Mdot
.63011 .72694 Mdot
.54749 .30989 Mdot
.73491 .72483 Mdot
.53945 .83013 Mdot
.53614 .36975 Mdot
.28289 .45612 Mdot
.30343 .77769 Mdot
.53979 .68423 Mdot
.53056 .49035 Mdot
.53894 .57771 Mdot
.4607 .54515 Mdot
.40865 .15325 Mdot
.26573 .6854 Mdot
.60039 .57453 Mdot
.59616 .78463 Mdot
.62794 .77912 Mdot
.86001 .40052 Mdot
.23964 .31175 Mdot
.64769 .41248 Mdot
.83806 .3939 Mdot
.62368 .236 Mdot
.64798 .79233 Mdot
.42 .33673 Mdot
.57116 .84991 Mdot
.70658 .61032 Mdot
.27319 .7215 Mdot
.65162 .50186 Mdot
.6793 .31189 Mdot
.24228 .42967 Mdot
.52968 .4852 Mdot
.39324 .27488 Mdot
.20627 .57795 Mdot
.13927 .51978 Mdot
.61891 .57967 Mdot
.25162 .38592 Mdot
.58092 .34768 Mdot
.39455 .81198 Mdot
.23213 .58375 Mdot
.57982 .56789 Mdot
.52432 .27426 Mdot
.79065 .40992 Mdot
.44778 .6488 Mdot
.57763 .49507 Mdot
.22565 .56825 Mdot
.81474 .55364 Mdot
.52687 .73027 Mdot
.20978 .38118 Mdot
.70976 .62369 Mdot
.44458 .47812 Mdot
.56231 .66772 Mdot
.61704 .4701 Mdot
.2998 .59602 Mdot
.50838 .49126 Mdot
.58234 .58045 Mdot
.40631 .44579 Mdot
.43639 .34085 Mdot
.78351 .35256 Mdot
.55957 .25228 Mdot
.21105 .41039 Mdot
.68646 .46724 Mdot
.62235 .34025 Mdot
.48271 .21029 Mdot
.75611 .31752 Mdot
.26047 .59919 Mdot
.45392 .66458 Mdot
.5374 .79719 Mdot
.67765 .74898 Mdot
.71593 .4076 Mdot
.86916 .4765 Mdot
.51712 .31507 Mdot
.61421 .72498 Mdot
.64682 .32569 Mdot
.29831 .42094 Mdot
.50965 .5561 Mdot
.27257 .71939 Mdot
.39938 .59388 Mdot
.47882 .75171 Mdot
.20153 .50772 Mdot
.47607 .54798 Mdot
.67911 .6735 Mdot
.5957 .78966 Mdot
.36859 .47541 Mdot
.19108 .43176 Mdot
.5064 .29349 Mdot
.2289 .56541 Mdot
.67782 .75259 Mdot
.82753 .60083 Mdot
.50041 .41196 Mdot
.38484 .67253 Mdot
.54672 .60174 Mdot
.19808 .38541 Mdot
.26189 .68203 Mdot
.60875 .71346 Mdot
.35354 .30227 Mdot
.65458 .46307 Mdot
.34067 .33961 Mdot
.45594 .47897 Mdot
.81183 .57711 Mdot
.63906 .47103 Mdot
.58517 .20336 Mdot
.30697 .61166 Mdot
.55728 .44732 Mdot
.48774 .58318 Mdot
.39772 .66823 Mdot
.24922 .2794 Mdot
.48606 .61733 Mdot
.38102 .78248 Mdot
.70931 .65083 Mdot
.25846 .33978 Mdot
.29684 .71938 Mdot
.44453 .28318 Mdot
.66251 .29089 Mdot
.64316 .72604 Mdot
.50648 .25272 Mdot
.51697 .60734 Mdot
.31105 .42184 Mdot
.65225 .38663 Mdot
.37909 .80714 Mdot
.75567 .62101 Mdot
.42028 .6913 Mdot
.3984 .53641 Mdot
.58119 .50051 Mdot
.52831 .29691 Mdot
.55714 .845 Mdot
.66993 .29624 Mdot
.42866 .63091 Mdot
.44113 .52072 Mdot
.38395 .68573 Mdot
.73593 .47123 Mdot
.81999 .63327 Mdot
.66354 .50055 Mdot
.45942 .4243 Mdot
.73119 .43045 Mdot
.20971 .51661 Mdot
.36017 .81228 Mdot
.4696 .66525 Mdot
.55168 .42992 Mdot
.33199 .56151 Mdot
.48223 .225 Mdot
.38501 .52967 Mdot
.55321 .49616 Mdot
.43011 .44709 Mdot
.3613 .27707 Mdot
.62188 .35326 Mdot
.55335 .71264 Mdot
.44338 .75167 Mdot
.55584 .79527 Mdot
.2633 .32512 Mdot
.47232 .27741 Mdot
.3801 .36165 Mdot
.78574 .61645 Mdot
.58571 .85503 Mdot
.61584 .19358 Mdot
.5493 .60019 Mdot
.50289 .27691 Mdot
.37127 .66627 Mdot
.39255 .4543 Mdot
.56448 .2214 Mdot
.50506 .22326 Mdot
.47564 .32041 Mdot
.40371 .61493 Mdot
.49699 .74819 Mdot
.2665 .40863 Mdot
.33501 .66073 Mdot
.54665 .30024 Mdot
.77556 .33683 Mdot
.19564 .59981 Mdot
.27522 .70983 Mdot
.69235 .8097 Mdot
.47538 .29059 Mdot
.63041 .66065 Mdot
.69567 .53313 Mdot
.69871 .74743 Mdot
.42187 .65399 Mdot
.8011 .47502 Mdot
.42926 .26894 Mdot
.46424 .65417 Mdot
.59046 .39545 Mdot
.46513 .75332 Mdot
.33406 .33892 Mdot
.49688 .44505 Mdot
.24071 .53881 Mdot
.87481 .47732 Mdot
.66907 .66286 Mdot
.54047 .80344 Mdot
.77741 .38909 Mdot
.18394 .38213 Mdot
.69308 .75359 Mdot
.44104 .73023 Mdot
.2492 .61163 Mdot
.66431 .53543 Mdot
.54966 .40296 Mdot
.71933 .44288 Mdot
.7889 .45933 Mdot
.71156 .69336 Mdot
.27521 .49285 Mdot
.73071 .45401 Mdot
.49234 .70192 Mdot
.73049 .67904 Mdot
.55205 .42811 Mdot
.68699 .69265 Mdot
.28298 .44887 Mdot
.65369 .25725 Mdot
.67861 .37605 Mdot
.43944 .68582 Mdot
.7101 .65972 Mdot
.41275 .23115 Mdot
.21715 .60163 Mdot
.15863 .40687 Mdot
.28757 .56972 Mdot
.75448 .3282 Mdot
.6106 .62919 Mdot
.86274 .37383 Mdot
.2251 .45918 Mdot
.24547 .44009 Mdot
.19713 .49211 Mdot
.41177 .46765 Mdot
.63 .57886 Mdot
.51689 .6079 Mdot
.41664 .78785 Mdot
.66037 .66217 Mdot
.77052 .48625 Mdot
.76381 .40109 Mdot
.40226 .63829 Mdot
.4704 .69449 Mdot
.4301 .70625 Mdot
.49345 .54912 Mdot
.66049 .4559 Mdot
.81201 .3612 Mdot
.48086 .40919 Mdot
.60829 .7121 Mdot
.47973 .61188 Mdot
.66753 .52187 Mdot
.29851 .79721 Mdot
.56316 .399 Mdot
.54973 .75264 Mdot
.6885 .6498 Mdot
.70982 .39421 Mdot
.50123 .20544 Mdot
.87724 .63581 Mdot
.88543 .3895 Mdot
.63438 .38775 Mdot
.28813 .2788 Mdot
.68268 .65649 Mdot
.57493 .76856 Mdot
.25502 .57994 Mdot
.34073 .29959 Mdot
.61441 .71747 Mdot
.69945 .3608 Mdot
.50857 .54979 Mdot
.22286 .44803 Mdot
.7536 .71128 Mdot
.75701 .39766 Mdot
.59316 .78487 Mdot
.60162 .54125 Mdot
.49699 .56627 Mdot
.66202 .83626 Mdot
.4845 .79281 Mdot
.50062 .61659 Mdot
.70168 .47259 Mdot
.54445 .70475 Mdot
.54564 .63911 Mdot
.32788 .73017 Mdot
.15176 .53163 Mdot
.52577 .73177 Mdot
.59387 .77297 Mdot
.61475 .45623 Mdot
.38696 .48767 Mdot
.46414 .34036 Mdot
.51117 .41241 Mdot
.49971 .63941 Mdot
.49992 .31307 Mdot
.45145 .57594 Mdot
.30453 .77197 Mdot
.40217 .52274 Mdot
.16835 .47915 Mdot
.63609 .8184 Mdot
.74527 .63144 Mdot
.49991 .23238 Mdot
.54567 .68643 Mdot
.62269 .73705 Mdot
.69255 .71999 Mdot
.53432 .50659 Mdot
.23672 .67682 Mdot
.59678 .12117 Mdot
.46307 .24578 Mdot
.80808 .59653 Mdot
.67521 .39301 Mdot
.43055 .47459 Mdot
.66801 .69105 Mdot
.42454 .34658 Mdot
.36428 .4135 Mdot
.58435 .53062 Mdot
.6793 .46019 Mdot
.53984 .33609 Mdot
.33772 .1778 Mdot
.59497 .58506 Mdot
.5358 .2163 Mdot
.63093 .79474 Mdot
.79898 .50185 Mdot
.72036 .57572 Mdot
.52502 .65688 Mdot
.59095 .31878 Mdot
.55106 .43143 Mdot
.36931 .78378 Mdot
.83183 .56331 Mdot
.54678 .78418 Mdot
.7542 .62511 Mdot
.6798 .66993 Mdot
.56456 .66699 Mdot
.36608 .60521 Mdot
.47358 .38962 Mdot
.38575 .77385 Mdot
.5369 .69786 Mdot
.68916 .76908 Mdot
.31196 .3841 Mdot
.44502 .53251 Mdot
.56785 .42297 Mdot
.85557 .40039 Mdot
.70255 .50291 Mdot
.69737 .44573 Mdot
.76031 .3215 Mdot
.296 .40592 Mdot
.36614 .64541 Mdot
.35064 .47568 Mdot
.54142 .69262 Mdot
.64468 .47644 Mdot
.73703 .26949 Mdot
.37698 .75975 Mdot
.40181 .26767 Mdot
.36124 .30901 Mdot
.29662 .29114 Mdot
.48173 .29755 Mdot
.71104 .79643 Mdot
.2394 .47822 Mdot
.75773 .29803 Mdot
.18367 .42421 Mdot
.6657 .47459 Mdot
.22271 .62799 Mdot
.49034 .60817 Mdot
.35705 .41744 Mdot
.56853 .77959 Mdot
.62773 .6787 Mdot
.82355 .48134 Mdot
.57913 .67344 Mdot
.8194 .42796 Mdot
.32098 .56422 Mdot
.28792 .47432 Mdot
.21322 .50463 Mdot
.67606 .52048 Mdot
.48404 .84786 Mdot
.47164 .22205 Mdot
.50599 .83907 Mdot
.46001 .83942 Mdot
.60895 .79225 Mdot
.80979 .46061 Mdot
.49825 .15682 Mdot
.21327 .52039 Mdot
.29859 .73052 Mdot
.39277 .3389 Mdot
.64654 .51854 Mdot
.2276 .48676 Mdot
.60322 .50092 Mdot
.59767 .24975 Mdot
.53162 .28884 Mdot
.34465 .13262 Mdot
.47171 .71367 Mdot
.69344 .4271 Mdot
.22909 .5002 Mdot
.64684 .78205 Mdot
.66961 .53067 Mdot
.20275 .56805 Mdot
.46368 .47426 Mdot
.6252 .61011 Mdot
.7136 .68891 Mdot
.26439 .31824 Mdot
.25942 .4335 Mdot
.14411 .39361 Mdot
.18892 .56513 Mdot
.3797 .27453 Mdot
.48177 .45532 Mdot
.62953 .39035 Mdot
.45212 .18939 Mdot
.24406 .52688 Mdot
.22389 .66118 Mdot
.28484 .74529 Mdot
.47755 .79259 Mdot
.19317 .32116 Mdot
.24552 .35678 Mdot
.71956 .73431 Mdot
.23346 .64531 Mdot
.63817 .38548 Mdot
.42315 .72469 Mdot
.32503 .41477 Mdot
.39155 .29758 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo09oooooo0_l0002Xooooo`007?ooool00ol0003oooooooooo`2Ooooo
o`;o0000Z?ooool001cooooo0_l0002Hooooo`;o0000:?ooool2o`0008Kooooo000Looooo`03o`00
0?oooooooooo08cooooo0_l00009ooooo`;o0000:?ooool2o`0008Kooooo000Looooo`03o`000?oo
oooooooo08cooooo0_l0002kooooo`007?ooool00ol0003oooooooooo`2@ooooo`;o0000]oooool0
01cooooo00?o0000ooooooooool0Ooooool2o`0000oooooo0_l0002gooooo`007?ooool00ol0003o
ooooooooo`1oooooo`;o0000b?ooool001cooooo00?o0000ooooooooool0QOooool2o`000<;ooooo
000Looooo`03o`000?oooooooooo08Gooooo0_l0000gooooo`;o0000ROooool001cooooo00?o0000
ooooooooool0__ooool2o`0008Wooooo000Looooo`03o`000?oooooooooo08oooooo0_l0000?oooo
o`;o0000Yoooool001cooooo00?o0000ooooooooool0Soooool2o`0000oooooo0_l0002Wooooo`00
7?ooool00ol0003oooooooooo`1/ooooo`;o00004oooool2o`000<Kooooo000Looooo`03o`000?oo
oooooooo06cooooo0_l0000Cooooo`;o00002Oooool2o`000;_ooooo000Looooo`03o`000?oooooo
oooo08cooooo0_l0002kooooo`007?ooool00ol0003oooooooooo`2=ooooo`Co0000^?ooool001co
oooo00?o0000ooooooooool0Noooool2o`00013ooooo1?l00005ooooo`;o00001?ooool2o`0000go
oooo0_l0002Looooo`007?ooool00ol0003oooooooooo`1kooooo`;o00006Oooool2o`0000?ooooo
0ol0000=ooooo`;o00001_ooool2o`0009Cooooo000Looooo`;o0000P_ooool2o`0001Sooooo0_l0
0006ooooo`;o00001_ooool2o`0000Kooooo0_l0002Dooooo`007?ooool00ol0003oooooooooo`21
ooooo`;o00006oooool2o`0000?ooooo0_l00006ooooo`;o00003?ooool2o`0008kooooo000Loooo
o`03o`000?oooooooooo09kooooo0_l0000<ooooo`;o00002oooool2o`0008kooooo000Looooo`03
o`000?oooooooooo0:cooooo0_l0002Kooooo`007?ooool00ol0003oooooooooo`2[ooooo`;o0000
W?ooool001cooooo00?o0000ooooooooool0Y_ooool2o`0000?ooooo0_l00009ooooo`;o0000TOoo
ool001cooooo00?o0000ooooooooool0X?ooool2o`0000Cooooo0_l0000>ooooo`;o00002Oooool2
o`0008Kooooo000Looooo`03o`000?oooooooooo093ooooo1_l0000:ooooo`;o00007oooool2o`00
08Kooooo000Looooo`03o`000?oooooooooo06[ooooo0_l0000Jooooo`;o00002?ooool6o`000;?o
oooo000Looooo`03o`000?oooooooooo06[ooooo0_l0000Jooooo`;o00003oooool2o`0002kooooo
0_l00020ooooo`007?ooool00ol0003oooooooooo`28ooooo`;o00002_ooool2o`000004ooooool0
003o0000ooooo`Go00009?ooool2o`0000;ooooo0_l00020ooooo`007?ooool00ol0003ooooooooo
o`28ooooo`;o00002_ooool3o`0000?ooooo1Ol00007ooooo`;o00000oooool5o`0001?ooooo0_l0
0024ooooo`007?ooool00ol0003oooooooooo`1oooooo`;o00003_ooool2o`0000Cooooo0_l00000
0ooooooo0000o`00000<ooooo`;o00000oooool5o`0001gooooo0_l00004ooooo`;o0000M?ooool0
0006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oo
oooooooo07oooooo0_l0000>ooooo`;o00000oooool2o`0000;ooooo0_l000000ooooooo0000o`00
0009ooooo`;o00005Oooool3o`000004ooooool0003o0000ooooo`;o00001oooool2o`0000Cooooo
0_l0001dooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0KOooool2o`0000cooooo0_l00004oooo
o`;o00002?ooool2o`0000Oooooo0_l00005ooooo`;o00002_ooool2o`0001Cooooo0ol000001?oo
oooo0000o`000?ooool2o`00013ooooo0_l0001aooooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0Hoooool2o`00
00Sooooo0_l0000<ooooo`;o00001?ooool2o`0000Sooooo0_l0000Booooo`;o00001_ooool2o`00
00Sooooo0_l0000Sooooo`;o0000LOooool00003ooooool0003ooooo00;ooooo00?o0000oooooooo
ool02oooool00onHV9So8B4Qonk^kP06ooooo`?o0000G_ooool2o`0000?ooooo0_l0000Eooooo`;o
00002_ooool2o`0000Wooooo0_l00009ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o
00001oooool3o`0000?ooooo0_l00002ooooo`;o0000SOooool00003ooooool0003ooooo00;ooooo
00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo05kooooo
0_l0000Jooooo`;o00001?ooool2o`0000Cooooo0_l00003ooooo`;o00001?ooool5o`0000Kooooo
0_l000000ooooooo0000o`000002o`0000;ooooo1?l00004ooooo`Go00001?ooool2o`0000;ooooo
0_l0002=ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0JOooool2o`0000Cooooo0ol00005ooooo`;o00001ooo
ool2o`0000Wooooo0_l00006ooooo`?o00001_ooool2o`000003ooooool0003o000000Cooooo0_l0
0006ooooo`Co00002Oooool2o`0008gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo
00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo06Wooooo0_l00004ooooo`Go
00000_ooool3o`00023ooooo0_l000000ooooooo0000o`00000=ooooo`;o000000Coooooo`000?l0
003ooooo0_l00004ooooo`?o00003?ooool2o`00087ooooo00001_ooooook^k^oc8b<_l0003o<S8b
onk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo07;ooooo0_l0
0002ooooo`;o00000_ooool2o`0000Cooooo0_l0000Gooooo`;o00004?ooool2o`000004ooooool0
003o0000ooooo`?o00000oooool3o`0000[ooooo1?l000000ooooooo0000o`00001nooooo`007?oo
ool00ol0003oooooooooo`1jooooo`;o00001?ooool2o`0000kooooo1?l0000Fooooo`;o000000?o
ooooo`000?l000000oooool2o`0000gooooo0_l000001?oooooo0000o`000?l00002ooooo`;o0000
O_ooool001cooooo00?o0000ooooooooool0JOooool2o`0001cooooo0_l00007ooooo`Co00005_oo
ool2o`000003ooooool0003o000000Gooooo0_l0000;ooooo`?o000000?oooooo`000?l00000P_oo
ool001cooooo00?o0000ooooooooool0Eoooool2o`0000Wooooo0_l00005ooooo`;o00004oooool3
o`0000Kooooo0_l00009ooooo`;o000000?oooooo`000?l000002?ooool3o`0000cooooo0_l00004
ooooo`;o00003?ooool2o`0008Gooooo000Looooo`03o`000?oooooooooo05;ooooo0_l00003oooo
o`;o00002Oooool4o`0000oooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l00006oooo
o`Co00001oooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`Oo000000?oooooo`00
0?l000001Oooool2o`0000gooooo0ol00002ooooo`;o00008oooool2o`00063ooooo000Looooo`03
o`000?oooooooooo05;ooooo0_l00007ooooo`;o00001oooool2o`000003ooooool0003o000000Go
oooo0_l00002ooooo`;o000000?oooooo`000?l000000oooool2o`000003ooooool0003o000000[o
oooo0_l0000>ooooo`Co00000oooool6o`000003ooooool0003o000000Sooooo0_l0000:ooooo`?o
00000_ooool2o`0000?ooooo0_l00008ooooo`;o00005?ooool2o`00063ooooo000Looooo`03o`00
0?oooooooooo05_ooooo0_l0000:ooooo`;o00001?ooool3o`0000;ooooo0_l00005ooooo`;o0000
1oooool2o`0001Oooooo0_l00002ooooo`?o00000oooool2o`0000[ooooo0_l00005ooooo`;o0000
0oooool2o`0000Sooooo0_l00008ooooo`;o0000M_ooool001cooooo00?o0000ooooooooool0Iooo
ool2o`0000Cooooo0_l00009ooooo`?o00001oooool2o`0001_ooooo0_l00002ooooo`Co00004Ooo
ool6o`0000Cooooo0ol00002ooooo`;o00009Oooool2o`0005Wooooo000Looooo`03o`000?oooooo
oooo06Oooooo0_l00008ooooo`;o00001?ooool3o`0000[ooooo0_l0000=ooooo`;o00002?ooool2
o`0000Cooooo1?l0000Cooooo`Co000000Coooooo`000?l0003ooooo0ol000001?oooooo0000o`00
0?l0000Uooooo`;o0000FOooool001cooooo00?o0000ooooooooool0GOooool2o`0001;ooooo0_l0
0003ooooo`?o00002oooool2o`0000gooooo0_l00002ooooo`;o00001?ooool2o`0000Kooooo0_l0
0007ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Gooooo0_l00005ooooo`;o00000_oo
ool2o`0000Cooooo0ol0001fooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o00000oooool2
o`0001Kooooo1Ol0000Dooooo`;o00000oooool2o`0000;ooooo0_l0000<ooooo`;o00001?ooool2
o`000003ooooool0003o000000?o00001Oooool2o`00013ooooo0_l00004ooooo`?o00001?ooool2
o`00073ooooo000Looooo`03o`000?oooooooooo05Sooooo0_l0000>ooooo`;o00002oooool2o`00
0004ooooool0003o0000o`0000kooooo3?l0000Fooooo`;o00000_ooool2o`0000Cooooo0_l00008
ooooo`;o00005_ooool2o`00073ooooo000Looooo`;o0000I_ooool2o`000003ooooool0003o0000
00oooooo0_l0000>ooooo`go00002Oooool4o`000003ooooool0003o000000cooooo0_l000000ooo
oooo0000o`000007ooooo`?o000000?oooooo`000?l000002Oooool2o`0007[ooooo000Looooo`03
o`000?oooooooooo06Gooooo0_l0000Nooooo`;o00003?ooool5o`0000Oooooo1?l000001?oooooo
0000o`000?l0000:ooooo`?o000000?oooooo`000?l000001oooool2o`0000;ooooo0_l00009oooo
o`;o0000N_ooool001cooooo00?o0000ooooooooool0Goooool2o`00013ooooo0_l0000@ooooo`Co
00000_ooool2o`0000Cooooo0_l00005ooooo`;o00000_ooool2o`0000Gooooo0_l00002ooooo`;o
00002_ooool2o`0000;ooooo0_l0000;ooooo`;o00000_ooool2o`0000Wooooo0_l00005ooooo`;o
00000_ooool2o`0006_ooooo000Looooo`03o`000?oooooooooo05Cooooo0_l00003ooooo`;o0000
0oooool3o`000003ooooool0003o000000gooooo0_l00009ooooo`;o00000_ooool2o`000003oooo
ool0003o000000?ooooo0ol00004ooooo`;o00002?ooool3o`000003ooooool0003o000000Sooooo
0_l00002ooooo`;o00001_ooool2o`00017ooooo0_l00009ooooo`;o00001Oooool2o`0000;ooooo
0_l00008ooooo`;o0000HOooool001cooooo00?o0000ooooooooool0D?ooool2o`0000;ooooo1?l0
00000ooooooo0000o`000002o`000003ooooool0003o000000;ooooo0_l0000Hooooo`;o00000_oo
ool3o`0000Gooooo0_l00008ooooo`;o00001Oooool8o`0000Kooooo1_l00006ooooo`;o00009ooo
ool2o`0000Sooooo0_l0000Iooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0COooool2
o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000000oooool2o`0002;ooooo1?l0
0006ooooo`?o00000oooool2o`000003ooooool0003o000000Gooooo1?l00002ooooo`;o000000?o
ooooo`000?l000001Oooool2o`00013ooooo0_l0000=ooooo`;o00002Oooool2o`0000Kooooo0_l0
0009ooooo`;o00005oooool2o`0004Kooooo000Looooo`03o`000?oooooooooo04gooooo0_l00004
ooooo`;o00002_ooool2o`0000_ooooo0_l0000Aooooo`;o00001_ooool5o`0000?ooooo0_l00005
ooooo`Co000000?oooooo`000?l000000_ooool2o`000004ooooool0003o0000ooooo`;o00003?oo
ool2o`0000Kooooo0_l0000;ooooo`Co00002Oooool2o`0000;ooooo0_l00002ooooo`;o00002Ooo
ool6o`0005_ooooo000Looooo`03o`000?oooooooooo04cooooo0_l0000Aooooo`;o00002Oooool4
o`00013ooooo0_l00007ooooo`?o00000oooool2o`0000Oooooo1?l000000ooooooo0000o`000004
ooooo`;o00000_ooool2o`0000Wooooo0_l000000ooooooo0000o`00000Cooooo`;o00001?ooool3
o`0000Cooooo0_l000001?oooooo0000o`000?l00007ooooo`;o00001_ooool4o`0005_ooooo000L
ooooo`03o`000?oooooooooo04cooooo0_l0000Cooooo`;o00001oooool2o`0000cooooo0_l00002
ooooo`Co00003?ooool3o`0000Sooooo0ol00006ooooo`?o00001?ooool2o`0000Oooooo0_l00000
0ooooooo0000o`00000Hooooo`Co00001?ooool2o`000003ooooool0003o000000Sooooo0_l0000;
ooooo`;o0000F?ooool001cooooo00?o0000ooooooooool0COooool2o`0000Wooooo1?l00005oooo
o`;o00003oooool4o`0000;ooooo0_l00002ooooo`;o00003_ooool2o`0000Cooooo0_l00002oooo
o`Co00000_ooool2o`0000;ooooo0_l00005ooooo`?o000000?oooooo`000?l000001?ooool4o`00
01Sooooo0_l00008ooooo`?o00005Oooool2o`0005Sooooo000Looooo`03o`000?oooooooooo04go
oooo0_l00009ooooo`Co00005_ooool4o`0001Kooooo0ol00003ooooo`;o000000Coooooo`000?l0
003o00001?ooool2o`0000Oooooo0_l000001?oooooo0000o`000?ooool2o`0000Cooooo0_l0000P
ooooo`?o000000?oooooo`000?l000000_l0000?ooooo`;o0000GOooool001cooooo00?o0000oooo
ooooool0AOooool2o`0001Wooooo0_l00004ooooo`;o00004?ooool4o`0000cooooo0_l00003oooo
o`;o00001_ooool3o`0000Oooooo0_l00004ooooo`;o00000oooool2o`0000Kooooo0_l00004oooo
o`;o000000?oooooo`000?l000005_ooool3o`0000?ooooo0_l0000:ooooo`;o00000oooool2o`00
05gooooo000Looooo`03o`000?oooooooooo04Gooooo0_l0000:ooooo`;o00001Oooool2o`0000Ko
oooo0_l00004ooooo`;o00004?ooool4o`0000Cooooo1?l00004ooooo`;o00005?ooool3o`0000Co
oooo0_l00002ooooo`Co00001Oooool2o`0000Cooooo0_l000001?oooooo0000o`000?l0000Doooo
o`;o00003?ooool2o`0000;ooooo0ol0001Rooooo`007?ooool00ol0003oooooooooo`19ooooo`;o
00001_ooool2o`0000Gooooo0ol00002ooooo`;o00001oooool2o`0001Gooooo1ol0000Cooooo`;o
00001Oooool2o`0000?ooooo0_l00004ooooo`Go00003_ooool2o`00017ooooo1_l0000;ooooo`;o
00000_ooool2o`0006?ooooo000Looooo`03o`000?oooooooooo04Wooooo0_l00003ooooo`;o0000
1Oooool2o`0000;ooooo0_l00002ooooo`;o00004Oooool2o`0000Kooooo0_l00002ooooo`Go0000
2_ooool2o`0000[ooooo0_l00008ooooo`Co00001oooool2o`0000Cooooo0_l0000Kooooo`Ko0000
M?ooool001cooooo00?o0000ooooooooool0C_ooool2o`0000Gooooo0_l0000:ooooo`;o00001?oo
ool2o`0000Oooooo0_l00003ooooo`;o000000?oooooo`000?l000001ol0000:ooooo`Co00002_oo
ool2o`0000Kooooo0_l00005ooooo`;o00002?ooool2o`0000Gooooo0_l0000;ooooo`;o00002?oo
ool4o`000004ooooool0003o0000o`0001[ooooo0_l0001Eooooo`007?ooool2o`0003kooooo0_l0
000?ooooo`;o00001_ooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool3o`0000?ooooo
0_l00002ooooo`Co00000oooool2o`000003ooooool0003o000000?ooooo1ol00008ooooo`?o0000
00?oooooo`000?l000000_ooool2o`000004ooooool0003o0000ooooo`Co00003Oooool2o`0000Co
oooo0_l00005ooooo`;o00000_ooool2o`0000Kooooo0_l00003ooooo`Co000000?oooooo`000?l0
00001Oooool6o`0000Cooooo0_l000000ooooooo0000o`00000Aooooo`;o00002_ooool2o`0004Wo
oooo000Looooo`03o`000?oooooooooo03gooooo0_l0000?ooooo`;o00001_ooool2o`0000?ooooo
0_l000000ooooooo0000o`000002ooooo`;o00001oooool6o`000003ooooool0003o000000;ooooo
0_l0000Aooooo`?o00001Oooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000So
oooo0_l00007ooooo`;o00001Oooool3o`0000Wooooo0_l00004ooooo`?o000000?oooooo`000?l0
00000oooool2o`000004ooooool0003o0000o`0000?ooooo0_l000001?oooooo0000o`000?ooool2
o`0000Cooooo0_l0000Gooooo`;o0000BOooool001cooooo00?o0000ooooooooool0G?ooool2o`00
00;ooooo0_l0000=ooooo`;o00001Oooool2o`0000?ooooo0ol0000>ooooo`;o00002Oooool9o`00
00Cooooo0ol00002ooooo`;o00001?ooool2o`0000Gooooo0_l00009ooooo`;o00003Oooool2o`00
00;ooooo0_l000000ooooooo0000o`000002o`0000Kooooo0_l00002ooooo`;o0000H_ooool001co
oooo00?o0000ooooooooool0EOooool2o`0000Gooooo0_l00002ooooo`;o00004?ooool2o`0000Oo
oooo1?l000000ooooooo0000o`000005ooooo`;o00000oooool2o`0000Sooooo4?l00003ooooo`;o
00000oooool3o`00013ooooo0ol0000>ooooo`Co000000?oooooo`000?l000002?ooool2o`0000?o
oooo0_l0000Eooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0B_ooool2o`0000;ooooo
0_l00002ooooo`;o000000?oooooo`000?l000006_ooool3o`0000Wooooo0_l000000ooooooo0000
o`000002o`0000?ooooo0_l00004ooooo`;o00001oooool?o`0000Wooooo0ol00002ooooo`;o0000
2?ooool2o`000003ooooool0003o000000;o00003_ooool3o`0000Cooooo0_l000001?oooooo0000
o`000?l00007ooooo`;o00003?ooool2o`0000Oooooo0_l0001:ooooo`007?ooool00ol0003ooooo
ooooo`18ooooo`Co00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000oooooo
0_l00002ooooo`;o00000oooool2o`0000Cooooo0_l00009ooooo`;o00000oooool2o`0000;ooooo
1?l000001?oooooo0000o`000?l00002oooooaCo00001_ooool2o`0000;ooooo0_l00004ooooo`;o
00000_ooool5o`0000?ooooo0_l0000Booooo`;o000000Coooooo`000?l0003o00001?ooool2o`00
00oooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`18ooooo`;o00001?ooool2o`0000;o
oooo0_l000000ooooooo0000o`000002o`0000oooooo0_l00002ooooo`;o00002Oooool2o`0000Co
oooo0_l00008ooooo`;o00000_ooool2o`0000;ooooo6_l0000:ooooo`;o00001?ooool2o`000003
ooooool0003o000000?o00001?ooool2o`000003ooooool0003o000001Wooooo0_l0000=ooooo`;o
000000?oooooo`000?l00000D_ooool001cooooo00?o0000ooooooooool0>oooool3o`0000kooooo
1?l00002ooooo`;o00002?ooool2o`000003ooooool0003o000000;ooooo0_l00005ooooo`;o0000
0oooool2o`0000cooooo0_l00004ooooo`;o00000_ooool2o`0000Kooooo6ol00003ooooo`;o0000
1?ooool2o`0000Kooooo1Ol00008ooooo`;o00005?ooool2o`0001;ooooo1Ol0001Booooo`007?oo
ool00ol0003oooooooooo`0booooo`;o00001oooool3o`0000kooooo0_l00004ooooo`;o00002?oo
ool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`?o00000oooool2o`0000Oooooo0_l0
0009ooooo`;o000000?oooooo`000?l000000_l00006ooooo`_o00000_ooool?o`000003ooooool0
003o000000Cooooo0_l00006ooooo`;o00004Oooool2o`0000Cooooo1?l000000ooooooo0000o`00
0002o`000003ooooool0003o000000Oooooo0ol00009ooooo`;o00000_ooool2o`0000_ooooo0_l0
0013ooooo`007?ooool00ol0003oooooooooo`0booooo`;o00001Oooool2o`0001Oooooo0_l0000E
ooooo`;o000000?oooooo`000?l000002_ooool4o`0000[ooooo1?l00006oooooaoo00001?ooool2
o`0000Cooooo0_l0000Cooooo`;o00001?ooool4o`000003ooooool0003o000000;o000000?ooooo
o`000?l000001oooool3o`0000Oooooo1?l00002ooooo`;o00002oooool2o`0004?ooooo000Loooo
o`03o`000?oooooooooo03Wooooo0_l0000Gooooo`;o00003?ooool2o`0000;ooooo0_l00006oooo
o`;o00002oooool3o`00017ooooo8?l00006ooooo`;o00001?ooool2o`0001_ooooo0_l00006oooo
o`;o00001?ooool2o`0000Oooooo0_l00002ooooo`Co00001Oooool4o`0004_ooooo000Looooo`03
o`000?oooooooooo04[ooooo0_l00006ooooo`;o00003?ooool2o`0000;ooooo0_l0000Wooooo`oo
000000Goooooo`000?l0003o0000ooooo`0<o`0002;ooooo0_l00009ooooo`;o00001_ooool4o`00
00Oooooo0_l00004ooooo`;o00001Oooool4o`0004_ooooo000Looooo`03o`000?oooooooooo04So
oooo1?l00005ooooo`?o00002oooool2o`000003ooooool0003o000000;ooooo0_l0000Aooooo`;o
00002_ooool2o`0000[ooooo3ol000000ooooooo0000o`00000=o`0000Kooooo0_l00009ooooo`;o
00003?ooool2o`0000Wooooo0_l00006ooooo`;o00002?ooool2o`0000Gooooo0_l00003ooooo`;o
0000Coooool001cooooo00?o0000ooooooooool0B?ooool2o`0000Kooooo0ol00007ooooo`;o0000
0oooool6o`000004ooooool0003o0000ooooo`Co00001oooool4o`000004ooooool0003o0000oooo
o`;o00001oooool2o`0000?ooooo1?l00003oooooa7o000000?oooooo`000?l000002ol00006oooo
o`;o00000_ooool2o`0000Gooooo0_l00003ooooo`;o00009?ooool3o`0000Cooooo0_l00003oooo
o`;o0000Coooool001cooooo00?o0000ooooooooool0D?ooool2o`0000Sooooo0_l00005ooooo`Co
00001?ooool4o`0000Oooooo1?l00004ooooo`Co00002_ooool6o`000003ooooool0003o000001So
00000oooool3o`0000Wooooo0_l0000:ooooo`;o00002?ooool2o`0000Oooooo0_l00003ooooo`?o
00003?ooool2o`0001Gooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o0000
8_ooool4o`0000Kooooo0_l000001?oooooo0000o`000?l00002oooooaoo00000_ooool2o`0000?o
oooo0_l00003ooooo`Go00004_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool4o`0002;o
oooo1?l00011ooooo`007?ooool2o`0004Wooooo0_l0000>ooooo`;o00007oooool3o`000003oooo
ool0003o000000Oooooo0_l000001?oooooo0000o`000?l00002ooooob7o00000_ooool2o`000004
ooooool0003o0000ooooo`Co000000?oooooo`000?l000005oooool4o`0000?ooooo1_l0000Doooo
o`;o00003_ooool2o`00047ooooo000Looooo`03o`000?oooooooooo04Kooooo1?l0000Hooooo`?o
00001oooool2o`0000[ooooo1?l00008ooooo`;o00001?ooool2o`0000;ooooo0_l000000ooooooo
0000o`00000Lo`0000;ooooo0_l00004ooooo`;o00003Oooool2o`0000;ooooo0_l0000;ooooo`?o
00000_ooool5o`000003ooooool0003o000000Sooooo0_l00008ooooo`;o00000oooool2o`0000Ko
oooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0jooooo`;o00002_ooool2o`0000;ooooo
1?l0000:ooooo`;o00002?ooool3o`0000Oooooo0_l0000:ooooo`;o00002_ooool2o`0000Oooooo
0ol000000ooooooo0000o`00000Ko`000003ooooool0003o000000;o00004Oooool8o`0000;ooooo
0_l00007ooooo`?o00002?ooool2o`0000Sooooo0ol0000<ooooo`;o000000?oooooo`000?l00000
0oooool2o`0004Cooooo000Looooo`03o`000?oooooooooo03[ooooo0_l00009ooooo`;o00000ooo
ool4o`0000?ooooo0_l00005ooooo`;o00002?ooool2o`0000Oooooo0_l00004ooooo`;o00002ooo
ool2o`0000?ooooo0_l00005ooooo`;o000000Goooooo`000?l0003o0000ooooo`0Po`000003oooo
ool0003o000000?o000000?oooooo`000?l000002_ooool3o`000003ooooool0003o000000;ooooo
1?l00003ooooo`;o00003Oooool2o`0000Sooooo0ol0000?ooooo`;o0000BOooool001cooooo00?o
0000ooooooooool0AOooool2o`0000Oooooo0_l000000ooooooo0000o`000003ooooo`;o00002_oo
ool2o`0000Oooooo0_l00004ooooo`Co00000oooool4o`0000;ooooo0_l00003ooooo`;o00001Ooo
ool5o`0000Gooooo4_l00002ooooo`Go000000Goooooo`000?l0003o0000ooooo`05o`000003oooo
ool0003o000001;ooooo1?l00003ooooo`;o00002_ooool2o`000003ooooool0003o000000?ooooo
0_l00002ooooo`;o00002oooool2o`0000Kooooo0_l00002ooooo`;o0000@oooool001cooooo00?o
0000ooooooooool0=oooool2o`0000oooooo0_l00004ooooo`;o000000?oooooo`000?l000000ooo
ool2o`0000Sooooo1?l00004ooooo`;o00002Oooool2o`0000?ooooo1?l0000@ooooo`Co00001?oo
oolIo`0000;ooooo0_l0000Jooooo`Go00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000_oo
ool2o`0000Kooooo0_l00002ooooo`;o00002oooool2o`0000Kooooo0_l00002ooooo`;o0000@ooo
ool001cooooo00?o0000ooooooooool0=oooool2o`0000[ooooo0_l000000ooooooo0000o`000002
o`000003ooooool0003o000000cooooo0_l00005ooooo`Co00001?ooool2o`0001Kooooo0_l0000;
ooooo`Ko000000?oooooo`000?l000005_l000000ooooooo0000o`000003ooooo`;o00000_ooool2
o`0000_ooooo0_l00006ooooo`;o000000?oooooo`000?l000000_ooool4o`000003ooooool0003o
000000Ko00000oooool2o`0000Wooooo0_l00003ooooo`;o00000oooool2o`0001Cooooo0_l0000j
ooooo`007?ooool00ol0003oooooooooo`13ooooo`Ko00000_ooool2o`0000;ooooo1?l00006oooo
o`;o00001_ooool2o`0000Kooooo0_l0000Aooooo`?o000000?oooooo`000?l000003Oooool4o`00
00Cooooo2_l000000ooooooo0000o`000008o`000003ooooool0003o000000?ooooo0_l00002oooo
o`;o00001_ooool2o`0000?ooooo0_l00008ooooo`;o00001Oooool2o`0000?ooooo1_l00003oooo
o`?o00002?ooool2o`0000?ooooo0_l00003ooooo`;o00004oooool3o`0003[ooooo000Looooo`03
o`000?oooooooooo03kooooo0_l00005ooooo`Co00000_ooool2o`0000;ooooo1?l0000<ooooo`Co
00001_ooool2o`0000Gooooo0_l0000:ooooo`?o00002?ooool2o`0000Cooooo0_l00008ooooo`;o
00001Oooool3o`000003ooooool0003o000000_o00001Oooool2o`0000Sooooo0_l0000=ooooo`Go
000000?oooooo`000?l000001?ooool2o`0000;ooooo0_l00004ooooo`;o00009oooool2o`0000Ko
oooo0_l0000cooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00002oooool5o`0000oooooo
0_l0000?ooooo`;o00004?ooool2o`0000?ooooo0_l00004ooooo`;o00000_ooool2o`0000cooooo
0_l00004ooooo`Co000000?oooooo`000?l000001Ol00002ooooo`?o00001oooool2o`0000[ooooo
0ol00003ooooo`Wo000000?oooooo`000?l000000_ooool2o`0000Sooooo0_l000000ooooooo0000
o`00000Pooooo`;o00001_ooool2o`0003?ooooo000Looooo`03o`000?oooooooooo03[ooooo0_l0
00001?oooooo0000o`000?ooool2o`0000_ooooo0ol0000?ooooo`;o000000?oooooo`000?l00000
1_ooool2o`0001Kooooo0_l0000=ooooo`;o00000oooool4o`0000Gooooo0_l00005ooooo`;o0000
0_ooool2o`000003ooooool0003o000000;o00000_ooool2o`0000Sooooo0_l00008oooooaCo0000
00Coooooo`000?l0003o00002?ooool2o`000003ooooool0003o000000Kooooo0_l00002ooooo`;o
00000_ooool2o`00013ooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0Zooooo`;o0000
3?ooool4o`000004ooooool0003o0000ooooo`Co00007_ooool2o`0000?ooooo0_l000000ooooooo
0000o`00000Iooooo`;o00003oooool4o`0000;ooooo0_l00008ooooo`;o00000_ooool2o`000003
ooooool0003o000000?ooooo0_l000000ooooooo0000o`000006ooooo`;o00001oooool3o`0000;o
oooo2ol000001?oooooo0000o`000?l00002ooooo`?o00001oooool2o`0000Gooooo0_l00003oooo
o`;o00000_ooool2o`0000;ooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`0Zooooo`;o
00003?ooool2o`0000;ooooo2Ol00009ooooo`;o00003oooool2o`000003ooooool0003o000000?o
oooo0_l0000Looooo`;o00005Oooool2o`0000Gooooo0_l00008ooooo`;o00000oooool2o`000004
ooooool0003o0000o`0000Gooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo3?l00002oooo
o`;o00000oooool2o`0000Oooooo0_l00005ooooo`;o00001oooool2o`00057ooooo000Looooo`03
o`000?oooooooooo03Sooooo0_l00002ooooo`Ko000000Coooooo`000?l0003ooooo0_l00006oooo
o`;o000000?oooooo`000?l000003?ooool2o`000003ooooool0003o000002Oooooo0_l00004oooo
o`;o00000oooool2o`0000Wooooo1?l0000=ooooo`;o00000_ooool2o`0000Wooooo1Ol000000ooo
oooo0000o`00000?o`0000gooooo0_l0000=ooooo`Co000000?oooooo`000?l000000_ooool2o`00
017ooooo0_l0000:ooooo`;o0000:oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2
ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo02_ooooo0_l0000?
ooooo`;o00002?ooool2o`0000?ooooo0ol00002ooooo`?o00001?ooool3o`0000?ooooo0_l0000F
ooooo`;o00000_ooool2o`00013ooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l0
00000ooooooo0000o`000006ooooo`;o00001oooool2o`0000Kooooo0_l00007ooooo`;o00001?oo
oolIo`0000_ooooo0_l00004ooooo`;o00001oooool2o`0000?ooooo0_l000001?oooooo0000o`00
0?l00004ooooo`;o00001oooool2o`0000;ooooo0_l0000:ooooo`;o0000:oooool00006oooooomg
MgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0[ooooo`;o00003oooool2o`0000Cooooo0_l00002ooooo`;o00000oooool3o`0000;o
oooo0_l00005ooooo`?o00000_ooool3o`0001Kooooo0ol000000ooooooo0000o`00000Cooooo`;o
00002Oooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000000Go
00002_ooool3o`0000?ooooo0_l000000ooooooo0000o`00000Do`0000Wooooo0_l00006ooooo`;o
00003oooool2o`0000Gooooo0_l00007ooooo`;o0000>oooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool02Oooool5o`0000Kooooo00?o0000ooooooooool0@_ooool2o`0000Kooooo
1Ol00006ooooo`;o00001Oooool2o`0000[ooooo0_l00002ooooo`;o00002?ooool5o`0000Wooooo
0_l0000Hooooo`;o00000_ooool3o`0000;ooooo0_l00003ooooo`Go00000_ooool2o`0000;ooooo
0_l00003ooooo`;o000000?oooooo`000?l000005ol0000;ooooo`;o00000_ooool2o`0000Wooooo
0_l00008ooooo`;o000000?oooooo`000?l00000B?ooool00003ooooool0003ooooo00;ooooo00?o
0000ooooooooool02Oooool01?m4A4CogMgMooooool00007ooooo`?o0000B_ooool2o`000003oooo
ool0003o000000Kooooo0_l0000?ooooo`Co00000_ooool2o`0000Cooooo1?l000001?oooooo0000
o`000?l00002ooooo`;o00001_ooool2o`0000?ooooo0_l0000<ooooo`;o00001Oooool2o`0000?o
oooo0_l00003ooooo`;o00001?ooool3o`0000;ooooo0_l00002ooooo`;o00001_ooool5o`0000?o
oooo5?l0000<ooooo`;o00002Oooool4o`0000?ooooo0_l00004ooooo`;o00004Oooool4o`0003?o
oooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`1Dooooo`;o00000oooool2o`000003ooooool0003o000000So
oooo0ol000001?oooooo0000o`000?ooool4o`000003ooooool0003o000000Oo000000?oooooo`00
0?l000002oooool2o`0000Sooooo0_l00002ooooo`;o00001Oooool2o`000003ooooool0003o0000
00;o00000oooool2o`0000Cooooo0ol00005ooooo`;o00001Oooool4o`000003ooooool0003o0000
013o000000?oooooo`000?l000001Ol0000Cooooo`;o00000oooool2o`0000?ooooo1_l0000Coooo
o`Co0000<oooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00omgMgOo
c<c<o`000007ooooo`03o`000?oooooooooo033ooooo0_l0000Qooooo`?o00000oooool2o`000003
ooooool0003o000000_ooooo4ol00002ooooo`;o00004oooool2o`0000?ooooo0_l00004ooooo`;o
000000?oooooo`000?l000000_l0000:ooooo`?o00001?ooool2o`0000Gooooo7ol00009ooooo`;o
00000_ooool4o`0000;ooooo0ol00009ooooo`Co00003?ooool2o`0003cooooo00001_ooooooMgMg
oiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0`oooo
o`;o00003oooool2o`00013ooooo0_l0000CoooooaWo00005oooool2o`0000Gooooo0_l000000ooo
oooo0000o`00000<ooooo`;o00002_ooool:o`000003ooooool0003o000001;o00001_ooool2o`00
00;ooooo0_l00002ooooo`Co00000oooool2o`0000_ooooo0_l0000<ooooo`;o0000??ooool00006
ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooo
oooo047ooooo0_l000000ooooooo0000o`00000Jooooo`;o00001?oooolLo`0001gooooo1Ol0000;
ooooo`;o00001oooool2o`0000;ooooo0ol000000ooooooo0000o`00000Do`000003ooooool0003o
000000Co00001?ooool2o`0000Sooooo0_l00009ooooo`;o00001Oooool2o`0000;ooooo0_l00016
ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00006Oooool3o`0000;ooooo7_l0000Moooo
o`?o00001oooool2o`0000Cooooo0_l00002ooooo`;o00000oooool2o`0000Sooooo7_l0000Foooo
o`;o00002Oooool2o`0004Kooooo000Looooo`03o`000?oooooooooo03Sooooo0_l00008ooooo`;o
00002Oooool3o`000003ooooool0003o000000Gooooo0_l00003ooooo`Ko000000Coooooo`000?l0
003ooooo6_l00008ooooo`;o00003Oooool2o`0000oooooo0_l000001?oooooo0000o`000?l00003
ooooo`?o00003?oooolOo`0000Oooooo0_l00005ooooo`;o00001_ooool2o`0001?ooooo0_l0000l
ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o000000?oooooo`000?l000001Oooool2o`00
00Wooooo0ol000000ooooooo0000o`000005ooooo`;o00000oooool2o`0000;ooooo0ol00002oooo
oaco00000_ooool2o`0000?ooooo0_l00006ooooo`;o00001Oooool2o`0000cooooo0_l00004oooo
o`?o00000oooool7o`0000Oooooo7Ol000000ooooooo0000o`000007ooooo`;o00001?ooool3o`00
01?ooooo0_l00006ooooo`;o0000??ooool001cooooo00?o0000ooooooooool0<oooool2o`0000?o
oooo0_l000000ooooooo0000o`000002ooooo`;o00005oooool2o`0000Kooooo8_l000001?oooooo
0000o`000?l0000;ooooo`;o00002Oooool2o`0000Sooooo0_l0000;ooooo`Ko00001oooool=o`00
0003ooooool0003o000000oo000000?oooooo`000?l000000_ooool2o`0000Oooooo0_l0000Doooo
o`;o000000?oooooo`000?l000000_l0000;ooooo`;o00000_ooool2o`0002kooooo000Looooo`03
o`000?oooooooooo03;ooooo0ol00002ooooo`;o00001_ooool2o`0000[ooooo0_l00002ooooo`Co
00001?ooool2o`0000Kooooo0ol000000ooooooo0000o`00000=o`000003ooooool0003o000000co
000000Coooooo`000?l0003o00002oooool2o`0000[ooooo0_l0000=ooooo`Oo00003?oooolQo`00
0003ooooool0003o000000;ooooo0_l00004ooooo`;o00006_ooool4o`0000_ooooo0_l00002oooo
o`;o0000;_ooool001cooooo00?o0000ooooooooool0<_ooool2o`0000?ooooo0_l000000ooooooo
0000o`00000<ooooo`;o000000?oooooo`000?l000000_ooool4o`0000Cooooo0_l00006ooooo`;o
00000ooooolHo`000003ooooool0003o000000;o000000?oooooo`000?l000001_ooool2o`0000Co
oooo0_l000000ooooooo0000o`000003ooooo`;o00002Oooool5o`0000?ooooo1ol0000<oooooaoo
00003Oooool2o`00017ooooo1?l00009ooooo`;o00001_ooool2o`0003Gooooo000Looooo`03o`00
0?oooooooooo03[ooooo0_l00007ooooo`;o00000oooool2o`0000Oooooo0_l000000ooooooo0000
o`000007ooooo`;o00000ooooolJo`000003ooooool0003o000000?o00002?ooool2o`000004oooo
ool0003o0000ooooo`Go00000oooool2o`0000Wooooo1Ol00003ooooo`;o00000_ooool2o`0000ko
oooo7?l0000>ooooo`;o00001oooool2o`0000Wooooo1_l00007ooooo`;o00001_ooool2o`0003Go
oooo000Looooo`03o`000?oooooooooo03;ooooo0_l0000=ooooo`Co00001oooool2o`0000Kooooo
0_l00002ooooo`;o00000oooool2o`0000;ooooo2_l000000ooooooo0000o`000005o`000003oooo
ool0003o000000co00002oooool2o`000003ooooool0003o000000;o00000oooool2o`0001Wooooo
0_l0000;oooooaco000000?oooooo`000?l000002oooool2o`0000Oooooo0_l00008ooooo`?o0000
0_ooool2o`0000Wooooo0_l0000;ooooo`;o0000;_ooool001cooooo00?o0000ooooooooool0<_oo
ool2o`0000Sooooo0_l00003ooooo`;o00001?ooool2o`0000?ooooo0_l00004ooooo`Co00000_oo
ool2o`0000Oooooo1_l000000ooooooo0000o`000009o`0000;ooooo3Ol00002ooooo`;o00002_oo
ool2o`0000Gooooo0_l0000Iooooo`;o00003ooooolGo`0000;ooooo0_l00008ooooo`;o00004?oo
ool6o`0000kooooo0_l0000;ooooo`;o0000;_ooool001cooooo00?o0000ooooooooool0<Oooool2
o`0000Wooooo0_l00002ooooo`;o00001Oooool2o`0000?ooooo0_l00002ooooo`Co00002Oooool2
o`0000;ooooo8Ol00002ooooo`;o00006?ooool2o`0000Oooooo0_l0000JoooooaKo00000oooool2
o`000003ooooool0003o000000Gooooo0_l00009ooooo`;o00001Oooool5o`00027ooooo0_l0000Y
ooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00003Oooool2o`0000?ooooo0ol00004oooo
o`;o00000_ooool4o`0000Cooooo0_l00003ooooo`?o000000Coooooo`000?l0003ooooo6ol00000
0ooooooo0000o`000006ooooo`;o00005?ooool2o`0000Cooooo0_l000000ooooooo0000o`000008
ooooo`;o00000oooool2o`0000_ooooo2Ol000000ooooooo0000o`000002o`000003ooooool0003o
000000Go00001_ooool2o`00013ooooo0_l00003ooooo`?o00002_ooool2o`0001Kooooo0_l00000
0ooooooo0000o`00000Yooooo`007?ooool2o`0003[ooooo0_l00006ooooo`;o00000_ooool3o`00
00?ooooo0_l00006ooooo`;o00000oooool2o`0000?ooooo0ol00003oooooaco00002Oooool2o`00
01[ooooo1?l00006ooooo`;o000000?oooooo`000?l000000oooool2o`0000Gooooo0_l00003oooo
oaSo00001oooool4o`0000cooooo0_l00003ooooo`?o00001?ooool2o`0000Cooooo1_l00002oooo
o`;o00003_ooool2o`0002cooooo000Looooo`03o`000?oooooooooo03Wooooo0_l00006ooooo`;o
00001?ooool6o`0000Cooooo1?l00008ooooo`;o00001?ooool8o`000003ooooool0003o000001?o
00002_ooool2o`0000cooooo0_l0000;ooooo`;o00001_ooool4o`0000_ooooo0_l00002oooooa[o
00001_ooool4o`0000Gooooo0_l00004ooooo`;o00002oooool2o`0000Cooooo1_l00002ooooo`;o
00003_ooool2o`0002cooooo000Looooo`03o`000?oooooooooo03Wooooo0_l0000<ooooo`Go0000
1Oooool2o`0000Gooooo0_l000000ooooooo0000o`000006oooooako00002_ooool2o`0000cooooo
0_l00002ooooo`Co00003oooool2o`0000oooooo6_l0000?ooooo`;o00001?ooool2o`0000Gooooo
0_l00002ooooo`;o00001_ooool4o`0004;ooooo000Looooo`03o`000?oooooooooo03;ooooo0_l0
000Aooooo`;o00002Oooool4o`0000?ooooo0ol000000ooooooo0000o`000002ooooo`Co00001?oo
oolBo`0000;ooooo1Ol00002ooooo`;o00002Oooool4o`0000[ooooo1_l00008ooooo`;o00004_oo
ool2o`000004ooooool0003o0000ooooo`?o000000?oooooo`000?l000005?l0000Jooooo`;o0000
0_ooool3o`0000?ooooo1_l00012ooooo`007?ooool00ol0003oooooooooo`0booooo`;o00001ooo
ool2o`0000Sooooo0_l00006ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o00000_oo
ool2o`0000;ooooo1Ol00003oooooaWo00000_ooool4o`0000Oooooo1?l0000:ooooo`;o00003?oo
ool2o`0001;ooooo0_l000000ooooooo0000o`000002ooooo`;o00000ooooolDo`0000?ooooo1?l0
0002ooooo`;o00005?ooool2o`0000?ooooo1?l00008ooooo`;o0000>_ooool001cooooo00?o0000
ooooooooool0=oooool3o`000004ooooool0003o0000o`0000Oooooo0_l000001?oooooo0000o`00
0?ooool4o`000004ooooool0003o0000o`0000oooooo0_l00003oooooaSo00000oooool4o`0000Oo
oooo0_l00006ooooo`?o00001Oooool2o`0001kooooo0_l000000ooooooo0000o`000003ooooo`;o
000000?oooooo`000?l000002ol000001Ooooooo0000o`000?l0003ooooo00?o00000oooool8o`00
01?ooooo1?l0000>ooooo`Co0000>?ooool001cooooo00?o0000ooooooooool0=oooool3o`0000;o
oooo0_l0000:ooooo`;o000000?oooooo`000?l000003oooool2o`0000Wooooo6?l00003ooooo`Co
00001oooool2o`0000Kooooo0ol00005ooooo`;o00001?ooool2o`0000oooooo1?l00005ooooo`;o
000000Coooooo`000?l0003o00000_ooool2o`000003ooooool0003o000000Go000000?oooooo`00
0?l000000_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00003Oooool2o`00
00Kooooo1?l0000<ooooo`;o00000_ooool2o`000003ooooool0003o000003Gooooo000Looooo`03
o`000?oooooooooo04Oooooo0_l0000:ooooo`;o00001oooool2o`0000Cooooo0_l00003oooooa7o
000000?oooooo`000?l000001?l00005ooooo`;o00001Oooool2o`0000Sooooo0_l00003ooooo`Co
00001Oooool2o`0000oooooo1?l00009ooooo`;o00000_ooool2o`0000Cooooo1?l000000ooooooo
0000o`000002o`0000Oooooo0_l00002ooooo`?o00002Oooool2o`0000Gooooo0ol0000?ooooo`;o
00001Oooool2o`0000Gooooo0_l0000eooooo`007?ooool00ol0003oooooooooo`0fooooo`;o0000
3oooool2o`0000[ooooo0_l00005ooooo`?o00001?ooool3o`000004ooooool0003o0000oooooa3o
00000_ooool4o`0000[ooooo0_l000000ooooooo0000o`000005ooooo`Ko000000?oooooo`000?l0
00000ol00003ooooo`Co00000_ooool2o`0000Oooooo1?l00006ooooo`;o00002_ooool2o`000003
ooooool0003o000000;o000000?oooooo`000?l000000_l00002ooooo`;o00001_ooool2o`0000;o
oooo0_l00009ooooo`;o00001Oooool2o`0000?ooooo0_l00007ooooo`;o00000_ooool2o`0000;o
oooo0_l00002ooooo`;o00002?ooool2o`00037ooooo000Looooo`03o`000?oooooooooo03?ooooo
0_l000000ooooooo0000o`00000<ooooo`;o00001?ooool2o`0000kooooo0ol00004ooooo`?o0000
00?oooooo`000?l000000ooooolBo`0000cooooo0_l00003ooooo`;o000000?oooooo`000?l00000
0ol000000ooooooo0000o`000003o`0000Kooooo1?l00002ooooo`;o00001_ooool5o`0000Kooooo
0_l00002ooooo`;o00001_ooool2o`000003ooooool0003o000000Oo00000_ooool:o`00013ooooo
0_l00002ooooo`;o00000oooool2o`0000Cooooo0_l000000ooooooo0000o`000006ooooo`;o0000
0_ooool2o`0000Sooooo1?l0000_ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00002ooo
ool6o`0000Cooooo0_l0000>ooooo`;o00001_ooool2o`0000Sooooo3_l00006ooooo`;o00002ooo
ool2o`000003ooooool0003o000000Gooooo0_l0000@ooooo`;o00001?ooool2o`0000Oooooo1?l0
0002ooooo`;o00002oooool6o`0000Gooooo1_l0000Booooo`;o000000Coooooo`000?l0003o0000
1_ooool2o`000003ooooool0003o000000;o00001?ooool2o`000003ooooool0003o000000kooooo
0_l0000_ooooo`007?ooool00ol0003oooooooooo`10ooooo`Co00000oooool2o`00017ooooo0_l0
000;ooooo`;o00001?ooool2o`0000;ooooo1?l00005ooooo`;o00000oooool3o`0000kooooo0_l0
0005ooooo`;o00001_ooool2o`0000Oooooo0ol000000ooooooo0000o`000009ooooo`Go00003ooo
ool2o`0000;ooooo0_l00002ooooo`Go00006Oooool2o`0000?ooooo0_l00002ooooo`?o00000_oo
ool2o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o0000>oooool001cooooo00?o0000
ooooooooool0>_ooool4o`0000Sooooo0ol00005ooooo`;o00001Oooool2o`0000Kooooo0_l00007
ooooo`?o00000oooool3o`0000?ooooo0ol00005ooooo`;o00000oooool2o`0000Gooooo0_l00008
ooooo`;o00001Oooool2o`0000Kooooo0_l00004ooooo`;o000000?oooooo`000?l000000_ooool3
o`0000Sooooo0_l0000Jooooo`Go00002_ooool2o`0000;ooooo0_l0000>ooooo`;o000000?ooooo
o`000?l000000_l00005ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`0000[ooooo0_l0
000_ooooo`007?ooool00ol0003oooooooooo`0jooooo`Co00000_ooool2o`0000Cooooo0_l00006
ooooo`;o00001Oooool3o`0000Gooooo0_l00007ooooo`?o00000oooool2o`0000Cooooo0_l00004
ooooo`Co00002_ooool4o`0001Oooooo0_l00002ooooo`?o000000?oooooo`000?l000000_ooool2
o`000003ooooool0003o000000Wooooo1?l00002ooooo`;o00001_ooool2o`0000;ooooo0_l0000<
ooooo`;o00001Oooool2o`0000;ooooo0_l0000Aooooo`;o00000_ooool2o`0000?ooooo0_l00002
ooooo`;o000000?oooooo`000?l000002oooool6o`0002gooooo000Looooo`03o`000?oooooooooo
02kooooo1?l0000:ooooo`;o00000_ooool3o`0000Gooooo0_l00006ooooo`;o00001?ooool2o`00
023ooooo0_l0000>ooooo`;o00005?ooool2o`000003ooooool0003o000000?ooooo0_l000000ooo
oooo0000o`000005ooooo`;o00001_ooool2o`000003ooooool0003o000000Ko00000_ooool2o`00
00;ooooo0_l00002ooooo`;o000000?oooooo`000?l000002Oooool4o`0001Kooooo1?l00004oooo
o`Co00001Oooool2o`000004ooooool0003o0000ooooo`;o00002?ooool2o`000004ooooool0003o
0000o`0002gooooo000Looooo`03o`000?oooooooooo02kooooo1?l0000?ooooo`;o00001Oooool2
o`0000?ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00004ooooo`;o00001Oooool2
o`0000[ooooo1?l00005ooooo`Co00003Oooool2o`0000?ooooo0_l00004ooooo`;o00002?ooool2
o`0000Kooooo0_l00002ooooo`;o00001?ooool2o`0000Kooooo0_l00005ooooo`;o00001?ooool2
o`0000Cooooo1?l000000ooooooo0000o`00000;ooooo`;o00005_ooool4o`0000?ooooo0_l00000
0ooooooo0000o`000004ooooo`?o00001?ooool3o`0000Cooooo0_l0000dooooo`007?ooool2o`00
02oooooo0_l00003ooooo`;o00002_ooool2o`0000Cooooo1?l00004ooooo`;o000000?oooooo`00
0?l000000_l00008ooooo`;o00001Oooool2o`0000Wooooo1Ol00005ooooo`Co00001?ooool2o`00
00Oooooo0_l00003ooooo`;o00001?ooool2o`0000kooooo1?l00002ooooo`;o00001?ooool2o`00
00Oooooo0_l00005ooooo`;o00002Oooool4o`000003ooooool0003o000000;ooooo0_l000000ooo
oooo0000o`000004ooooo`;o00000_ooool2o`0000Kooooo0_l0000Aooooo`;o00000_ooool2o`00
00?ooooo0_l00006ooooo`;o00001?ooool2o`0003Cooooo000Looooo`03o`000?oooooooooo03?o
oooo0_l0000:ooooo`;o000000?oooooo`000?l000001Ol0000Uooooo`;o00001Oooool2o`000003
ooooool0003o000000Kooooo0_l000000ooooooo0000o`000004ooooo`;o00003Oooool2o`0000[o
oooo0_l0000;ooooo`;o00001?ooool4o`0000Gooooo0_l0000>ooooo`Ko000000?oooooo`000?l0
00000_l00002ooooo`;o000000Coooooo`000?l0003o00000oooool2o`000003ooooool0003o0000
01Gooooo0_l00003ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0=Oooool4o`0000Go
oooo0_l00002ooooo`Ko00007_ooool2o`0000Oooooo0_l00004ooooo`;o000000Coooooo`000?l0
003ooooo0_l00006ooooo`;o00002?ooool2o`0000Sooooo0ol00006ooooo`;o00002?ooool2o`00
00Gooooo0ol00003ooooo`;o00000_ooool3o`0000?ooooo0_l0000=ooooo`Co00001Oooool2o`00
00Gooooo0_l00004ooooo`;o00006?ooool2o`0000?ooooo0_l00003ooooo`;o00003?ooool4o`00
02gooooo000Looooo`03o`000?oooooooooo03Gooooo1_l00003ooooo`;o000000?oooooo`000?l0
00000oooool2o`0001Sooooo0_l00004ooooo`;o00001oooool2o`0000Cooooo0_l00004ooooo`;o
00001?ooool2o`0000[ooooo0_l00005ooooo`;o000000?oooooo`000?l000001Oooool4o`000003
ooooool0003o000000Gooooo0_l00006ooooo`;o00001oooool3o`0000?ooooo0_l000000ooooooo
0000o`000008ooooo`Co00001oooool2o`0000?ooooo0_l0000Wooooo`;o000000Coooooo`000?l0
003ooooo1?l00007ooooo`Co0000;Oooool001cooooo00?o0000ooooooooool0>Oooool2o`0000Ko
oooo0_l0000Booooo`;o00002Oooool2o`0001;ooooo0_l0000;ooooo`;o00004Oooool5o`0000Go
oooo1?l000000ooooooo0000o`000002ooooo`;o00004_ooool2o`0000Oooooo0_l00007ooooo`Go
00000oooool2o`0000;ooooo0_l00003ooooo`Co00006Oooool4o`0000Sooooo0_l00004ooooo`Co
00001?ooool2o`0003;ooooo000Looooo`03o`000?oooooooooo043ooooo0_l0000Cooooo`;o0000
2?ooool2o`0000Kooooo0_l0000;ooooo`;o00001oooool2o`0000_ooooo1Ol00003ooooo`;o0000
00?oooooo`000?l000000_l0000<ooooo`Co00002_ooool3o`0000Gooooo0_l00003ooooo`;o0000
2oooool2o`000003ooooool0003o000000?ooooo0_l00009ooooo`;o000000?oooooo`000?l00000
2?ooool2o`0000cooooo1?l00008ooooo`;o00001?ooool2o`0000Kooooo0_l0000booooo`007?oo
ool00ol0003oooooooooo`0Zooooo`;o00005?ooool5o`0001Gooooo0_l00003ooooo`;o00001_oo
ool2o`000003ooooool0003o000000Kooooo0_l00007ooooo`Co00002oooool6o`0000;ooooo0_l0
000?ooooo`Co00000oooool2o`0000Cooooo0_l000001?oooooo0000o`000?l0000:ooooo`Ko0000
2?ooool2o`0000Gooooo0_l00006ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o
00001?ooool2o`0001;ooooo0_l00004ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0
:_ooool2o`0000Oooooo0_l0000=ooooo`?o000000?oooooo`000?l000004_ooool2o`0000kooooo
0_l00006ooooo`;o00001oooool2o`000004ooooool0003o0000o`0000[ooooo1Ol00003ooooo`;o
000000?oooooo`000?l000002oooool2o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`;o
00000_ooool2o`0000cooooo1?l000000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l0
00000_ooool5o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l0000Hoooo
o`;o00003?ooool2o`0000Sooooo0_l0000^ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o
00004Oooool2o`0000Wooooo0_l0000Kooooo`;o00002Oooool2o`0000?ooooo1Ol00008ooooo`?o
00001Oooool6o`0000Wooooo0_l00003ooooo`;o00004_ooool2o`0000Gooooo0_l00003ooooo`;o
00002?ooool2o`0000;ooooo1Ol00009ooooo`;o00007?ooool2o`0000cooooo0_l00002ooooo`;o
00001?ooool2o`0002kooooo000Looooo`03o`000?oooooooooo037ooooo0_l0000Iooooo`;o0000
0oooool2o`0000oooooo0_l0000:ooooo`;o00002Oooool2o`0000?ooooo1Ol00006ooooo`;o0000
2_ooool4o`0000Wooooo0_l00003ooooo`?o00003Oooool3o`000003ooooool0003o000000Gooooo
0_l00002ooooo`;o00003_ooool2o`0000;ooooo0_l0000@ooooo`;o00004oooool2o`0000Wooooo
0_l00005ooooo`;o0000=?ooool001cooooo00?o0000ooooooooool0;_ooool2o`000003ooooool0
003o000001Oooooo1?l0000Dooooo`?o00003?ooool2o`0000Kooooo0_l00008ooooo`;o00001?oo
ool2o`0000;ooooo0_l00003ooooo`Ko00003oooool3o`0000Sooooo1?l000000ooooooo0000o`00
0003o`0000[ooooo0_l0000;ooooo`;o000000?oooooo`000?l000000_ooool2o`0000kooooo1?l0
000Looooo`Co0000>oooool001cooooo00?o0000ooooooooool0:_ooool2o`000004ooooool0003o
0000o`0001Oooooo1Ol0000@ooooo`;o00001Oooool2o`0000cooooo0_l00005ooooo`?o00001_oo
ool4o`0000Sooooo0_l00003ooooo`Co00003Oooool2o`0000gooooo1?l00002ooooo`Co00003_oo
ool2o`0000Oooooo1Ol00006ooooo`;o00002_ooool2o`0001kooooo0_l0000mooooo`007?ooool0
0ol0003oooooooooo`0Looooo`;o00003?ooool2o`000003ooooool0003o000000Gooooo0_l0000;
ooooo`;o00001?ooool5o`00013ooooo0_l0000Cooooo`;o00001Oooool2o`0000Cooooo0_l00000
0ooooooo0000o`00000;ooooo`;o00004_ooool3o`0000;ooooo0_l00006ooooo`?o00000_ooool2
o`0000Wooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Sooooo0_l00000
1?oooooo0000o`000?l00004ooooo`;o0000=Oooool2o`0003;ooooo000Looooo`03o`000?oooooo
oooo01cooooo0_l0000Fooooo`;o00002oooool2o`0000Oooooo0_l00005ooooo`;o00003?ooool2
o`0000Oooooo0_l0000Cooooo`?o00001?ooool4o`0000Kooooo0_l0000:ooooo`Co00000_ooool4
o`0000?ooooo1Ol000000ooooooo0000o`000005o`000003ooooool0003o000000;o00001_ooool3
o`000004ooooool0003o0000ooooo`;o00003_ooool4o`0002Cooooo0ol00004ooooo`;o00001_oo
ool2o`0000Kooooo0_l0000booooo`007?ooool00ol0003oooooooooo`0]ooooo`;o00002Oooool2
o`0001Oooooo0_l0000<ooooo`?o000000?oooooo`000?l000000oooool3o`000003ooooool0003o
000000;o00003Oooool2o`0000?ooooo1_l0000Booooo`Co00000_ooool2o`0000Cooooo0_l00000
0ooooooo0000o`000004o`0000;ooooo2?l000001?oooooo0000o`000?l00003ooooo`;o00005?oo
ool2o`0002Kooooo0ol00004ooooo`;o00001Oooool3o`0003[ooooo000Looooo`03o`000?oooooo
oooo02gooooo0_l00009ooooo`;o00000oooool2o`0001_ooooo0_l00004ooooo`;o000000?ooooo
o`000?l000001?ooool2o`000003ooooool0003o000000;o00004_ooool6o`0000Oooooo0_l00000
0ooooooo0000o`000003ooooo`;o00003Oooool2o`0000?ooooo3?l000000ooooooo0000o`000004
o`0000Oooooo0_l0000Rooooo`;o00008Oooool2o`0003_ooooo000Looooo`;o0000;?ooool2o`00
00cooooo0_l00002ooooo`?o00003_ooool2o`0000[ooooo0_l000000ooooooo0000o`00000Coooo
o`;o000000?oooooo`000?l000003?ooool2o`0000[ooooo1Ol00003ooooo`;o00001?ooool2o`00
00;ooooo1?l00008ooooo`[o000000?oooooo`000?l000000_ooool2o`0000Oooooo0_l00002oooo
o`?o00004?ooool2o`0000_ooooo0ol0000Looooo`;o00000_ooool2o`0003_ooooo000Looooo`03
o`000?oooooooooo02_ooooo0_l00005ooooo`;o00000_ooool2o`000005ooooool0003o0000o`00
0?ooool00ol00007ooooo`;o00001Oooool2o`0000gooooo0_l0000Cooooo`;o000000?oooooo`00
0?l000003?ooool2o`0000cooooo0_l00005ooooo`;o00000oooool8o`0000Gooooo0_l000000ooo
oooo0000o`000008o`0000?ooooo0_l00002ooooo`;o00002Oooool3o`00013ooooo0_l0000<oooo
o`;o00006Oooool2o`000003ooooool0003o000000;ooooo0_l0000kooooo`007?ooool00ol0003o
ooooooooo`0Pooooo`;o00004?ooool2o`0000;ooooo0_l00002ooooo`;o00002Oooool4o`0001Co
oooo0_l0000?ooooo`;o00001oooool2o`0000Cooooo0_l00004ooooo`;o00000oooool2o`000003
ooooool0003o000000Kooooo0_l00003ooooo`;o00000oooool4o`000003ooooool0003o000000?o
oooo1Ol000000ooooooo0000o`000002o`0000Cooooo0ol00002ooooo`;o00000_ooool4o`0002Ko
oooo0_l0000Jooooo`?o0000@_ooool001cooooo00?o0000ooooooooool08?ooool2o`0001Oooooo
0_l00007ooooo`;o000000?oooooo`000?l000005Oooool3o`0000oooooo0_l00007ooooo`Co0000
0_ooool2o`0000Wooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l0000=ooooo`?o
00000_oooolFo`0000;ooooo0ol000001?oooooo0000o`000?l0000Qooooo`?o00000oooool2o`00
01Gooooo0_l00004ooooo`?o0000??ooool001cooooo00?o0000ooooooooool0=Oooool2o`0000;o
oooo0_l00007ooooo`;o00006?ooool2o`0000[ooooo0_l000000ooooooo0000o`000008o`0000?o
oooo0ol0000Cooooo`;o00001oooool2o`0000Wooooo0ol00002oooooa[o00000_ooool3o`0001Oo
oooo0_l00008ooooo`;o000000Coooooo`000?l0003ooooo0_l0000?ooooo`;o00002_ooool3o`00
03cooooo000Looooo`03o`000?oooooooooo03Gooooo0_l00003ooooo`;o00002oooool2o`0001?o
oooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000000_o00004?ooool2o`00013o
oooo0_l00005ooooo`;o00000_ooool2o`000003ooooool0003o000000Go000000?oooooo`000?l0
00001?l000000ooooooo0000o`000009o`000003ooooool0003o000001_ooooo0_l00002ooooo`;o
00001oooool2o`0001;ooooo0_l000000ooooooo0000o`000007ooooo`;o0000?Oooool001cooooo
00?o0000ooooooooool0=?ooool2o`0000Cooooo0_l00002ooooo`;o00001_ooool3o`0001?ooooo
1_l00003ooooo`Oo000000?oooooo`000?l000001ol0000>ooooo`?o00004_ooool2o`0000?ooooo
0_l00002ooooo`[o000000?oooooo`000?l000002Ol000000ooooooo0000o`000007o`0001Cooooo
0_l00005ooooo`;o00000_ooool2o`0000Kooooo0_l0000Fooooo`;o00000oooool2o`0000Oooooo
0_l0000hooooo`007?ooool00ol0003oooooooooo`0dooooo`;o000000?oooooo`000?l000000ooo
ool7o`0000?ooooo0_l0000Booooo`Ko00000oooool9o`000003ooooool0003o000000Wo00002?oo
ool2o`0000;ooooo0_l00005ooooo`;o00002_ooool4o`0000?ooooo0_l000000ooooooo0000o`00
0003o`000003ooooool0003o000001[o00004oooool2o`00017ooooo0_l0000Kooooo`;o00001ooo
ool2o`0003Sooooo000Looooo`03o`000?oooooooooo03Kooooo0ol00003ooooo`;o00000_ooool5
o`0000cooooo0_l00007ooooo`Co00001OoooolEo`0000Sooooo0_l00002ooooo`;o00001Oooool2
o`0000[ooooo1?l00003ooooo`;o000000?oooooo`000?l000000_l00002oooooaco00001?ooool2
o`0000Oooooo0_l0000Dooooo`;o000000?oooooo`000?l000004oooool2o`0000gooooo1?l0000h
ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00001Oooool2o`000003ooooool0003o0000
00Cooooo0_l000001?oooooo0000o`000?l00009ooooo`;o000000?oooooo`000?l000001oooool2
o`0000Sooooo4ol00002ooooo`;o00002?ooool3o`0000Wooooo0_l0000<ooooo`So00000_ooool9
o`000003ooooool0003o0000017o00000oooool4o`0000?ooooo1?l0000Dooooo`;o000000Cooooo
o`000?l0003ooooo0_l0000@ooooo`;o00001?ooool2o`0000?ooooo0_l00002ooooo`?o0000>Ooo
ool001cooooo00?o0000ooooooooool0;oooool2o`0000Sooooo0_l000001?oooooo0000o`000?oo
ool2o`0000gooooo0ol00009ooooo`;o00002?oooolCo`0000;ooooo0_l00008ooooo`;o00002_oo
ool4o`0000Sooooo2Ol000000ooooooo0000o`00000Mo`000003ooooool0003o000000Co00000ooo
ool2o`0000Sooooo1?l000000ooooooo0000o`00000;ooooo`Co00005_ooool2o`0000?ooooo0_l0
0003ooooo`;o0000>Oooool001cooooo00?o0000ooooooooool0??ooool2o`0000[ooooo0_l00005
ooooo`;o00003ooooolDo`000003ooooool0003o000000;o000000?oooooo`000?l000000_ooool2
o`00017ooooo0_l00008ooooo`;o00000oooool4o`000003ooooool0003o000002?o00002Oooool2
o`0000?ooooo1?l000000ooooooo0000o`00000;ooooo`Co00005oooool2o`0000?ooooo0_l0000m
ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o000000?oooooo`000?l000004?ooool2o`00
017ooooo0_l00002ooooo`oo000000?oooooo`000?l000002?l000000ooooooo0000o`000002oooo
o`;o00001_ooool4o`0000Kooooo0_l00009ooooo`Co00000_ooool2o`0000;ooooo8Ol00004oooo
o`;o00001oooool2o`00033ooooo0_l00003ooooo`?o0000??ooool001cooooo00?o0000oooooooo
ool0<oooool2o`000003ooooool0003o000000Oooooo0_l00008ooooo`;o00004?ooool2o`000003
ooooool0003o000001Oo00002_ooool2o`0000?ooooo1?l00006ooooo`;o00002_ooool6o`0000;o
oooo7?l00002ooooo`;o000000?oooooo`000?l000000oooool2o`0003_ooooo0_l000001?oooooo
0000o`000?l0000looooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool0
1Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0?oooool2o`0000Sooooo0_l0
0008ooooo`;o00002OoooolBo`000003ooooool0003o000000Co000000?oooooo`000?l000001?oo
ool2o`000003ooooool0003o000000Kooooo0_l000001?oooooo0000o`000?l0000;ooooo`;o0000
00?oooooo`000?l000009Ol000000ooooooo0000o`000003ooooo`;o00004oooool2o`0000_ooooo
0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l000000ooooooo0000o`00000mooooo`0000Ko
ooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q
00Kooooo00?o0000ooooooooool0<?ooool2o`0000Sooooo0_l00003ooooo`Co00002_ooool2o`00
00Cooooo0_l00008oooooa[o000000?oooooo`000?l000001?ooool2o`0000;ooooo0_l00005oooo
o`;o000000Coooooo`000?l0003o00002oooool2o`000003ooooool0003o000000Go000000?ooooo
o`000?l000000ol000000ooooooo0000o`00000Go`000003ooooool0003o000001Sooooo0ol00000
0ooooooo0000o`000007ooooo`;o00001oooool2o`0000Oooooo0_l00003ooooo`Ko0000@?ooool0
0003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool0<?ooool2o`0000Sooooo1?l00003ooooo`?o000000Cooooo
o`000?l0003ooooo0_l00003ooooo`;o00000_ooool2o`0000[ooooo6Ol00004ooooo`;o00000_oo
ool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000004oooool2o`000004ooooool0
003o0000oooooa[o00000oooool2o`000003ooooool0003o000000;ooooo0_l0000>ooooo`Co0000
0oooool2o`000003ooooool0003o000001?ooooo0_l000000ooooooo0000o`000006ooooo`Oo0000
1Oooool2o`0003Sooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go
0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000??ooool4o`0000;ooooo1Ol000000ooooooo0000
o`000007ooooo`;o00002Oooool2o`000003ooooool0003o000001Oo00000_ooool7o`0000Kooooo
1Ol0000@oooooa3o000000?oooooo`000?l000007?l00003ooooo`Co00001oooool4o`0001_ooooo
1Ol00003ooooo`;o00001_ooool3o`0000Cooooo0_l0000hooooo`0000?oooooo`000?ooool00_oo
ool00ol0003oooooooooo`09ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003ooooo
ooooo`0nooooo`;o00000oooool2o`0000?ooooo0_l0000=ooooo`;o00000oooool2o`000003oooo
ool0003o000001Co000000Coooooo`000?l0003ooooo0_l000001?oooooo0000o`000?ooool2o`00
00?ooooo0_l00002ooooo`;o00004_oooolAo`000003ooooool0003o000000Oo000000?oooooo`00
0?l000004?l00004ooooo`Co00006Oooool2o`0000Gooooo0ol00005ooooo`;o00001?ooool2o`00
00Oooooo0_l0000nooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`03
oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0@Oooool2o`0000Gooooo0_l0000<ooooo`?o
00000ooooolJo`0000?ooooo1?l00007ooooo`;o00005_ooool2o`000004ooooool0003o0000oooo
o`_o000000?oooooo`000?l000001ol000000ooooooo0000o`000006o`0000;ooooo0ol00007oooo
o`?o00006?ooool2o`0000;ooooo0_l00005ooooo`?o00003?ooool2o`000003ooooool0003o0000
04?ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?ooool0
0ol0003oooooooooo`0oooooo`Co00002_ooool2o`0000Oooooo0_l000000ooooooo0000o`000002
o`000003ooooool0003o000001Ko00001Oooool2o`0000kooooo0_l000000ooooooo0000o`000006
ooooo`Co000000Goooooo`000?l0003o0000ooooo`0/o`000004ooooool0003o0000o`0001;ooooo
0ol00003ooooo`Co00001oooool2o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`;o0000
00?oooooo`000?l000000_ooool2o`0003oooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPco
oooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`0cooooo`;o00002_ooool2o`00
00;ooooo0ol00007ooooo`;o00002_ooool4o`0000?ooooo4ol00002ooooo`;o00001Oooool2o`00
0003ooooool0003o000000;ooooo0_l00006ooooo`;o000000?oooooo`000?l000001_ooool4o`00
0005ooooool0003o0000o`000?ooool01Ol000000ooooooo0000o`00000>o`000003ooooool0003o
000001?o00005_ooool3o`0000?ooooo1?l00007ooooo`;o00001?ooool2o`000003ooooool0003o
000000_ooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00003_ooool4o`00
00Gooooo0_l00006ooooo`;o00001Oooool4o`000003ooooool0003o0000013o00000oooool2o`00
00Gooooo1Ol00002ooooo`?o00004_ooool6o`000003ooooool0003o000000?ooooo8_l00004oooo
o`;o00005Oooool2o`000003ooooool0003o000001Gooooo0_l000000ooooooo0000o`000003oooo
o`;o0000A?ooool001cooooo00?o0000ooooooooool0@oooool4o`0000Gooooo0_l00006ooooo`;o
00001OoooolGo`0000?ooooo0_l00004ooooo`Oo00000_ooool2o`0000Oooooo0_l0000;ooooo`;o
00000oooool2o`000003ooooool0003o000001oo000000?oooooo`000?l000001?ooool2o`000003
ooooool0003o000000Wooooo0_l00007ooooo`;o000000?oooooo`000?l000003?ooool3o`0000?o
oooo0_l000001?oooooo0000o`000?ooool7o`0004Cooooo000Looooo`03o`000?oooooooooo04?o
oooo0_l0000Iooooo`Co000000?oooooo`000?l000002?l00002ooooo`Go000000?oooooo`000?l0
00001?ooool7o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000kooooo0_l00003ooooob;o
00001_ooool2o`000003ooooool0003o000000Wooooo0_l00009ooooo`;o00000oooool2o`0000Oo
oooo1?l00003ooooo`;o000000?oooooo`000?l000000oooool4o`0000Kooooo0_l0000mooooo`00
7?ooool00ol0003oooooooooo`0fooooo`;o00003Oooool3o`0000Oooooo0_l0000Booooo`Go0000
00?oooooo`000?l000000_l00003ooooo`Co00002oooool3o`000003ooooool0003o000000;o0000
0_ooool2o`0001;ooooo;?l00003ooooo`;o00001oooool3o`0000_ooooo0ol00002ooooo`Co0000
1Oooool2o`0000Sooooo1?l000000ooooooo0000o`000008ooooo`;o0000?Oooool001cooooo00?o
0000ooooooooool0=_ooool2o`0000gooooo0ol00006ooooo`?o00004_ooool5o`0000Gooooo0_l0
00000ooooooo0000o`000004ooooo`;o00000oooool2o`0000?ooooo2_l00004ooooo`;o00002_oo
ool9o`0000?ooooo2?l00003oooooaSo000000?oooooo`000?l000000_l00007ooooo`?o00003?oo
ool2o`0000Cooooo0_l0000@ooooo`?o0000B_ooool001cooooo00?o0000ooooooooool0@Oooool2
o`0000_ooooo0_l0000Aooooo`;o00001Oooool4o`000003ooooool0003o000000Oooooo1?l00000
0ooooooo0000o`000002o`0000?ooooo0_l00003ooooo`?o00000_ooool4o`000003ooooool0003o
000000Oooooo1?l000000ooooooo0000o`000003o`0000;ooooo2_l000000ooooooo0000o`00000B
o`0000;ooooo0_l000000ooooooo0000o`00000Rooooo`Co00002Oooool5o`0000Oooooo0_l00010
ooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00000_ooool4o`0001Wooooo0_l000000ooo
oooo0000o`000005ooooo`Co00003?ooool2o`000003ooooool0003o000000;o00000oooool4o`00
00Kooooo0_l00003ooooo`;o00001?ooool2o`000003ooooool0003o000000Cooooo4Ol000000ooo
oooo0000o`00000Ao`0000?ooooo0ol000000ooooooo0000o`00000Pooooo`Co00002Oooool2o`00
0003ooooool0003o000000Oooooo0_l0000@ooooo`;o0000;_ooool001cooooo00?o0000oooooooo
ool0?Oooool2o`0000;ooooo1Ol0000Hooooo`;o00000_ooool2o`0000oooooo0_l0000:ooooo`;o
00000oooool2o`00017ooooo0_l00003oooooaGo000000?oooooo`000?l000004Ol000000ooooooo
0000o`000003o`000003ooooool0003o000000;ooooo0_l0000`ooooo`?o00005?ooool2o`0002ko
oooo000Looooo`03o`000?oooooooooo03gooooo0_l00005ooooo`;o00006?ooool2o`0000;ooooo
0_l00004ooooo`;o00001oooool4o`0000?ooooo0_l00005ooooo`;o00002oooool2o`0000kooooo
1Ol00002oooooaOo000000?oooooo`000?l000003?l00007ooooo`;o00001?ooool2o`0000;ooooo
0_l00009ooooo`;o00006oooool3o`0004Cooooo000Looooo`03o`000?oooooooooo03gooooo1?l0
0003ooooo`;o00000_ooool2o`0000kooooo0_l00004ooooo`;o00002?ooool2o`000003ooooool0
003o000000Cooooo1?l00003ooooo`Co00001Oooool2o`0000Wooooo0_l0000;ooooo`Oo00001Ooo
oolQo`00013ooooo0_l000001?oooooo0000o`000?l00009ooooo`;o00003Oooool2o`0005?ooooo
000Looooo`03o`000?oooooooooo03oooooo0_l00003ooooo`;o00000_ooool2o`0000kooooo0ol0
0007ooooo`Co00001Oooool2o`0000Kooooo0_l00005ooooo`Co000000?oooooo`000?l000001Ol0
0008ooooo`;o00002Oooool6o`0000;ooooo0_l000000ooooooo0000o`00000No`0000;ooooo0_l0
0007ooooo`;o00001oooool3o`0000Gooooo0_l0000Booooo`;o00002Oooool2o`0004Sooooo000L
ooooo`;o0000F_ooool2o`0000Oooooo1ol00005ooooo`;o00003?ooool2o`000003ooooool0003o
000000;ooooo0ol00007ooooo`?o000000Coooooo`000?l0003o00001_ooool2o`0000?ooooo1?l0
00000ooooooo0000o`00000Mo`0000?ooooo0_l00007ooooo`;o00001oooool2o`0000;ooooo0_l0
0002ooooo`;o000000?oooooo`000?l000003_ooool2o`0000[ooooo0_l00018ooooo`007?ooool0
0ol0003oooooooooo`0nooooo`;o00004_ooool2o`0000Gooooo0_l0000;ooooo`?o000000?ooooo
o`000?l000000_ooool2o`0001Gooooo0_l00006ooooo`;o00000_ooool4o`0000[ooooo1?l00000
0ooooooo0000o`00000<o`000003ooooool0003o000000Wo000000Coooooo`000?l0003o00002?oo
ool2o`0000[ooooo0_l00004ooooo`;o00001Oooool2o`0000kooooo0_l0000<ooooo`;o0000A_oo
ool001cooooo00?o0000ooooooooool0?_ooool2o`0000Gooooo0_l00003ooooo`;o000000?ooooo
o`000?l000000oooool4o`0000;ooooo0ol0000?ooooo`;o00005Oooool2o`0000;ooooo0_l0000<
ooooo`;o00003?ooool4o`000003ooooool0003o000000[o000000?oooooo`000?l000003?l00000
1?oooooo0000o`000?l00005ooooo`;o00000oooool2o`0000Gooooo0_l00002ooooo`;o00007Ooo
ool2o`0000Kooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00000oooool2
o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000;ooooo0ol000001?oooooo0000o`00
0?ooool2o`0000Sooooo0_l0000Aooooo`;o00000_ooool3o`0000?ooooo0_l00007ooooo`;o0000
0_ooool2o`0000[ooooo9_l00003ooooo`Co00000oooool2o`0000Oooooo1?l00004ooooo`Go0000
4_ooool4o`0000Gooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`13ooooo`Co00000ooo
ool2o`0000Cooooo0_l00006ooooo`;o00000_ooool2o`000003ooooool0003o000000Sooooo0_l0
0004ooooo`;o00002oooool2o`0000;ooooo0_l00004ooooo`;o00000oooool2o`0000;ooooo1_l0
000:ooooo`Co000000Coooooo`000?l0003ooooo1Ol000000ooooooo0000o`00000Ao`000003oooo
ool0003o000000;o00000oooool4o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l00000
0_l00006ooooo`Go00003?ooool2o`0000?ooooo0ol00007ooooo`;o0000Aoooool001cooooo00?o
0000ooooooooool0@?ooool2o`000003ooooool0003o000000kooooo0_l000000ooooooo0000o`00
0003o`0001Cooooo0_l00004ooooo`;o00001?ooool4o`0000cooooo0_l00003ooooo`Co000000?o
ooooo`000?l000002_ooool2o`000003ooooool0003o000001Wo00000_ooool4o`000003ooooool0
003o000000;ooooo0_l00002ooooo`;o00000_ooool3o`000003ooooool0003o000001Kooooo0_l0
00000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l00000C_ooool001cooooo00?o0000
ooooooooool0@?ooool2o`0000oooooo1?l000000ooooooo0000o`000003o`0000[ooooo0_l0000>
ooooo`;o00001?ooool4o`0000oooooo0_l00005ooooo`?o00000oooool2o`0000Cooooo0_l00000
1Ooooooo0000o`000?l0003ooooo01So000000?oooooo`000?l000001Ol000001?oooooo0000o`00
0?l00006ooooo`;o00001Oooool2o`0001?ooooo0_l00009ooooo`Ko0000B_ooool001cooooo00?o
0000ooooooooool0@_ooool2o`0000gooooo0_l00007ooooo`;o00002Oooool2o`0000Oooooo0_l0
0009ooooo`;o00004_ooool4o`0000Cooooo0ol00003ooooo`;o00001Oooool4o`0000;ooooo1Ol0
00000ooooooo0000o`000007o`000003ooooool0003o000000Ko00001?ooool2o`0000?ooooo0ol0
000;ooooo`Co00001_ooool2o`0000?ooooo0_l0000Booooo`Go0000B_ooool001cooooo00?o0000
ooooooooool0@_ooool2o`0000Gooooo0_l00003ooooo`;o00002_ooool2o`0000oooooo0_l00000
0ooooooo0000o`000009ooooo`;o00004_ooool4o`0000Cooooo0_l0000;ooooo`Co000000?ooooo
o`000?l000001Ol00003ooooo`Ko000000?oooooo`000?l000001_l000001?oooooo0000o`000?oo
ool2o`00017ooooo1?l00006ooooo`;o000000?oooooo`000?l000000_l0000<ooooo`;o00001?oo
ool3o`0004cooooo000Looooo`03o`000?oooooooooo04;ooooo0_l00005ooooo`;o00000oooool2
o`0000Kooooo0_l0000Cooooo`;o00001Oooool2o`0001Kooooo0ol000000ooooooo0000o`000007
ooooo`;o00002_ooool3o`000003ooooool0003o000000Oo00000_ooool4o`0000;ooooo1ol00002
ooooo`;o00001Oooool2o`0000Oooooo0ol0000@ooooo`;o00000oooool2o`000003ooooool0003o
000000Kooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o00000oooool2o`00
00Sooooo0_l0000<ooooo`;o00000_ooool2o`0000Cooooo0_l00003ooooo`;o00000_ooool2o`00
00Oooooo0ol000000ooooooo0000o`000007ooooo`Co00000oooool2o`0000;ooooo0_l00003oooo
o`?o00000oooool9o`0000?ooooo0_l00003ooooo`;o00002?ooool2o`0000Oooooo1?l0000?oooo
o`;o00000oooool2o`000003ooooool0003o000000;ooooo0_l0001Gooooo`007?ooool00ol0003o
ooooooooo`1<ooooo`;o00000oooool4o`0000_ooooo0_l00007ooooo`;o00000_ooool3o`0000;o
oooo0_l00002ooooo`Wo00000_ooool2o`0000Oooooo0ol0000<ooooo`;o00000oooool2o`0000;o
oooo0_l00003ooooo`;o00000oooool3o`000005ooooool0003o0000o`000?ooool00_l00003oooo
o`;o00000oooool2o`0001?ooooo0_l00002ooooo`;o00000oooool2o`0000Kooooo0_l00006oooo
o`;o00000_ooool2o`0005Oooooo000Looooo`03o`000?oooooooooo04cooooo0_l00004ooooo`?o
00002Oooool2o`0000Wooooo0_l00002ooooo`;o000000?oooooo`000?l000001?ooool2o`000003
ooooool0003o000000?o00003?ooool3o`0000Wooooo0_l0000?ooooo`;o00000oooool3o`0000;o
oooo0_l00003ooooo`;o000000Coooooo`000?l0003o00000_ooool3o`0000Sooooo1?l0000:oooo
o`;o00000oooool2o`0000Cooooo1?l00006ooooo`;o0000Foooool001cooooo00?o0000oooooooo
ool0@_ooool2o`0001[ooooo0_l0000@ooooo`;o00003oooool3o`000004ooooool0003o0000o`00
00kooooo1?l000001?oooooo0000o`000?l00008ooooo`;o00000oooool5o`0000;ooooo0_l00002
ooooo`;o000000Coooooo`000?l0003o00000_ooool3o`0000Sooooo1?l00008ooooo`;o00001?oo
ool2o`0000Gooooo1?l0001Sooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00002oooool2
o`0001[ooooo0_l00009ooooo`;o00001_ooool2o`000005ooooool0003o0000o`000?ooool00ol0
000=ooooo`Go000000Coooooo`000?l0003o00001_ooool4o`0000?ooooo1Ol00002ooooo`?o0000
1?ooool3o`0000kooooo0_l00009ooooo`;o00000oooool3o`0000Kooooo0_l0000<ooooo`?o0000
EOooool001cooooo00?o0000ooooooooool0Coooool2o`0000Gooooo0_l00009ooooo`;o00002?oo
ool2o`0000Wooooo0_l000000ooooooo0000o`000003ooooo`Co00003?ooool6o`000003ooooool0
003o000000;o00002oooool2o`0000Gooooo0ol00005ooooo`;o000000Coooooo`000?l0003ooooo
1Ol00002ooooo`;o000000?oooooo`000?l000002Oooool2o`0000[ooooo0_l00007ooooo`;o0000
2_ooool5o`0005Gooooo000Looooo`;o0000Eoooool2o`0000Oooooo1?l0000Fooooo`;o00000_oo
ool5o`0000Gooooo0_l00005ooooo`Ko00000oooool2o`0000?ooooo1?l00007ooooo`;o00000_oo
ool3o`0000Gooooo0_l000000ooooooo0000o`000004ooooo`?o000000Coooooo`000?l0003ooooo
1?l00007ooooo`;o00001?ooool2o`0000Cooooo0_l00007ooooo`;o00001_ooool2o`0000;ooooo
0_l0001Hooooo`007?ooool00ol0003oooooooooo`16ooooo`;o00005oooool6o`0001Cooooo2Ol0
0005ooooo`;o00003_ooool2o`0000?ooooo1?l00007ooooo`;o000000?oooooo`000?l000000ol0
0004ooooo`Co000000?oooooo`000?l000000oooool2o`0000Kooooo0_l0000<ooooo`?o00001?oo
ool2o`0000Oooooo1?l00004ooooo`Co0000F_ooool001cooooo00?o0000ooooooooool0A_ooool2
o`000004ooooool0003o0000ooooo`;o00001oooool2o`0000[ooooo1?l0000Dooooo`Go00000_oo
ool2o`0000Kooooo0_l00002ooooo`;o00003oooool2o`0000Kooooo0_l00003ooooo`;o000000?o
ooooo`000?l000001_ooool5o`0001Wooooo0_l0000@ooooo`;o00001_ooool2o`0005[ooooo000L
ooooo`03o`000?oooooooooo04Wooooo0_l000000ooooooo0000o`000007ooooo`?o00002?ooool4
o`0001Oooooo0_l0000;ooooo`;o00000_ooool2o`0000;ooooo0_l0000;ooooo`;o000000?ooooo
o`000?l000000oooool2o`0000_ooooo0_l00002ooooo`;o00006oooool2o`0000Oooooo0_l0000C
ooooo`?o0000EOooool001cooooo00?o0000ooooooooool0BOooool2o`0000_ooooo1?l00003oooo
o`Oo00005oooool2o`0000Wooooo0_l00002ooooo`;o00001?ooool2o`0000?ooooo1?l00007oooo
o`;o00003_ooool4o`0000Cooooo0ol00007ooooo`;o00003oooool2o`0000Oooooo0_l0000;oooo
o`;o00001_ooool3o`0005Gooooo000Looooo`03o`000?oooooooooo05Cooooo0_l00002ooooo`;o
00000oooool3o`000003ooooool0003o000002;ooooo0ol00002ooooo`?o00002?ooool4o`0000Co
oooo0_l00007ooooo`;o00002?ooool2o`0000Kooooo1?l00006ooooo`Co00003oooool2o`0000;o
oooo0_l0000:ooooo`;o00000_ooool2o`0005kooooo000Looooo`03o`000?oooooooooo057ooooo
0_l000001?oooooo0000o`000?l00006ooooo`;o00009_ooool2o`0000?ooooo0ol0000@ooooo`;o
000000?oooooo`000?l000001?ooool2o`0001;ooooo0_l00008ooooo`;o00003oooool3o`000003
ooooool0003o000000;ooooo0_l00006ooooo`;o0000H_ooool001cooooo00?o0000ooooooooool0
B_ooool2o`0000Gooooo0_l000001?oooooo0000o`000?l00006ooooo`;o00006oooool2o`0000co
oooo1?l0000Dooooo`Co000000Coooooo`000?l0003o00003oooool2o`0001gooooo0_l00005oooo
o`;o00002?ooool2o`00063ooooo000Looooo`03o`000?oooooooooo04[ooooo0_l00008ooooo`?o
00000oooool2o`0000Kooooo0_l000000ooooooo0000o`00000Cooooo`;o00002_ooool4o`0000Co
oooo0_l00002ooooo`;o00003_ooool5o`0000Sooooo0_l00006ooooo`;o00001Oooool4o`0000;o
oooo0_l00007ooooo`;o00006?ooool2o`000003ooooool0003o000000;o0000Foooool001cooooo
00?o0000ooooooooool0E?ooool3o`0000?ooooo0_l00006ooooo`Go00005_ooool2o`0000Oooooo
0_l00006ooooo`;o00000_ooool4o`0000gooooo0ol00009ooooo`;o00002_ooool7o`0000;ooooo
0_l00003ooooo`;o00000_ooool2o`0000;ooooo0ol0000Fooooo`Co0000Foooool001cooooo00?o
0000ooooooooool0EOooool2o`0000Kooooo1?l000001?oooooo0000o`000?l00002ooooo`;o0000
5?ooool2o`0000gooooo0ol00003ooooo`Co00002Oooool2o`0000;ooooo0_l00002ooooo`;o0000
1_ooool2o`0000[ooooo1?l0000:ooooo`;o00001_ooool3o`0000Gooooo1?l00007ooooo`;o0000
Hoooool001cooooo00?o0000ooooooooool0Coooool2o`0000Gooooo0_l00005ooooo`Co000000?o
ooooo`000?l000000oooool2o`0000gooooo0_l00002ooooo`;o00004?ooool4o`0000;ooooo0_l0
0003ooooo`;o00001_ooool2o`0000Kooooo0_l0000Nooooo`;o00004?ooool4o`0000Oooooo1?l0
001Qooooo`007?ooool00ol0003oooooooooo`1?ooooo`;o00001Oooool2o`0001;ooooo0_l00000
0ooooooo0000o`000007ooooo`;o00000_ooool2o`0000Sooooo0_l00006ooooo`Co00001?ooool2
o`000003ooooool0003o000000Gooooo1?l00006ooooo`;o00000_ooool2o`000003ooooool0003o
000001Gooooo0ol0000;ooooo`?o00000oooool2o`0000[ooooo0_l0000Looooo`;o0000@oooool0
01cooooo00?o0000ooooooooool0C?ooool2o`0000Oooooo0_l0000>ooooo`;o00000oooool2o`00
0003ooooool0003o000000?ooooo0_l0000@ooooo`?o00000_ooool2o`000003ooooool0003o0000
00;o00001?ooool2o`0000Kooooo1_l00006ooooo`;o00000_ooool2o`000004ooooool0003o0000
o`0000Oooooo0_l0000;ooooo`;o00002oooool4o`0000_ooooo0_l0000Pooooo`;o0000@oooool0
01cooooo00?o0000ooooooooool0C?ooool2o`0000;ooooo0_l000000ooooooo0000o`000003o`00
00;ooooo0_l00006ooooo`;o000000?oooooo`000?l000002oooool2o`0000kooooo1Ol00002oooo
o`;o00000oooool2o`0000cooooo0_l000000ooooooo0000o`000004ooooo`;o00001?ooool3o`00
00;ooooo0ol00003ooooo`;o000000?oooooo`000?l000003oooool2o`0000Cooooo0_l000000ooo
oooo0000o`000005ooooo`;o00001_ooool2o`0006Gooooo000Looooo`03o`000?oooooooooo053o
oooo0_l000001?oooooo0000o`000?ooool2o`000004ooooool0003o0000o`0000Kooooo0_l00000
0ooooooo0000o`000004ooooo`?o00002Oooool2o`0000?ooooo0_l000001?oooooo0000o`000?oo
ool4o`0000oooooo0_l00007ooooo`;o00001Oooool2o`0000;ooooo1?l00004ooooo`;o00000ooo
ool2o`0000oooooo0_l000000ooooooo0000o`000004ooooo`;o00001_ooool4o`0000?ooooo0_l0
001Xooooo`007?ooool2o`0005Gooooo0_l00003ooooo`;o00001?ooool2o`0000Gooooo0_l00003
ooooo`?o00002Oooool2o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`Co00001oooool2
o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`;o00001Oooool2o`0000;ooooo0_l00005
ooooo`;o00005Oooool2o`0000Gooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0ol0
0004ooooo`Co00000oooool2o`00067ooooo000Looooo`03o`000?oooooooooo05Cooooo0_l00002
ooooo`;o00001Oooool2o`0000Gooooo0_l00004ooooo`;o00004oooool8o`0000?ooooo0_l00002
ooooo`;o000000?oooooo`000?l000000oooool2o`0001Gooooo0ol0000Fooooo`;o00001?ooool5
o`000003ooooool0003o000000;ooooo0ol00002ooooo`;o00000_ooool2o`0000?ooooo0_l0001Q
ooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00000oooool2o`0000Gooooo0_l00002oooo
o`?o00001Oooool2o`00013ooooo0_l00002ooooo`Co00001oooool2o`0000Gooooo0ol00002oooo
o`;o00003Oooool2o`000004ooooool0003o0000ooooo`Go00003?ooool2o`0000Sooooo0_l00006
ooooo`;o00001_ooool3o`0000;ooooo0_l0001Zooooo`007?ooool00ol0003oooooooooo`1Coooo
o`;o00002Oooool2o`0000?ooooo0ol00005ooooo`;o00001_ooool2o`0000;ooooo0_l00004oooo
o`;o00002Oooool2o`0000[ooooo0_l00006ooooo`;o00000_ooool2o`0000Gooooo0_l000001?oo
oooo0000o`000?ooool5o`0000Cooooo0_l00003ooooo`;o000000?oooooo`000?l000001Oooool2
o`0000cooooo1?l0000=ooooo`;o0000Hoooool001cooooo00?o0000ooooooooool0G_ooool3o`00
01;ooooo0_l00002ooooo`;o00003Oooool4o`0001;ooooo0_l00002ooooo`;o00001Oooool2o`00
00Gooooo1?l00004ooooo`Co000000?oooooo`000?l000002?ooool2o`0000Cooooo0_l00005oooo
o`Go00003Oooool2o`0006?ooooo000Looooo`03o`000?oooooooooo05oooooo0_l0000Uooooo`Co
00001?ooool2o`0000Oooooo0_l0000>ooooo`;o00001oooool2o`0000?ooooo0_l000000ooooooo
0000o`000006ooooo`;o00002Oooool2o`0000Gooooo1?l00004ooooo`;o0000KOooool001cooooo
00?o0000ooooooooool0Q?ooool2o`0000;ooooo0_l00004ooooo`;o00001oooool2o`0000Kooooo
0_l00005ooooo`;o00003Oooool4o`0000;ooooo0_l00003ooooo`;o00000oooool2o`0000Wooooo
0_l00002ooooo`;o00001?ooool4o`0006_ooooo000Looooo`03o`000?oooooooooo05oooooo1?l0
000Booooo`;o00003Oooool2o`0001Wooooo0_l00005ooooo`;o00000_ooool2o`0000_ooooo0_l0
0002ooooo`Co00001_ooool2o`0000Wooooo0_l0000:ooooo`;o0000Joooool001cooooo00?o0000
ooooooooool0GOooool6o`0000Kooooo0_l00008ooooo`Wo00006_ooool2o`0000Wooooo0_l00000
0ooooooo0000o`000004ooooo`;o00004Oooool3o`0000?ooooo0_l00004ooooo`Co0000O?ooool0
01cooooo00?o0000ooooooooool0GOooool5o`0000Oooooo0_l00008ooooo`;o00000_ooool5o`00
0003ooooool0003o0000013ooooo0_l00005ooooo`Co00001oooool2o`000003ooooool0003o0000
01Sooooo0_l00003ooooo`;o00000oooool5o`0007cooooo000Looooo`03o`000?oooooooooo05ko
oooo0ol0000Fooooo`?o00000oooool2o`0000_ooooo0_l00003ooooo`;o00001oooool2o`0000[o
oooo0_l0000?ooooo`Go00003_ooool2o`0000Cooooo0_l0001iooooo`007?ooool00ol0003ooooo
ooooo`1_ooooo`;o00000oooool2o`000004ooooool0003o0000o`00013ooooo0_l0000Hooooo`;o
00001_ooool4o`0000Gooooo1Ol00003ooooo`?o00001Oooool2o`0000Oooooo0_l0001iooooo`00
7?ooool00ol0003oooooooooo`1Dooooo`;o00001?ooool2o`0001?ooooo0_l00003ooooo`;o0000
0_ooool2o`0000;ooooo0_l00006ooooo`;o00006oooool2o`000003ooooool0003o000000Kooooo
1?l0000=ooooo`?o00001Oooool2o`0000Kooooo0ol00002ooooo`;o0000MOooool001cooooo00?o
0000ooooooooool0E?ooool2o`0000Cooooo0_l0000Cooooo`;o00002oooool2o`0000Kooooo1?l0
000Iooooo`?o00002oooool2o`0000Oooooo0_l00004ooooo`;o00003Oooool2o`0000?ooooo0_l0
001eooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Q
o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0Koooool2o`0001Gooooo0_l0000>ooooo`?o
000000?oooooo`000?l000001?ooool6o`0000Wooooo0_l00007ooooo`;o00001?ooool2o`0000;o
oooo0_l0000;ooooo`Co0000M_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q
8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo05gooooo0_l0000M
ooooo`;o00006?ooool3o`000003ooooool0003o000000Cooooo0ol000000ooooooo0000o`000005
ooooo`;o00001?ooool2o`0000Wooooo1?l00002ooooo`;o00001Oooool2o`0000Cooooo1?l0000@
ooooo`;o0000I?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0GOooool2o`0000Wooooo0_l0000<
ooooo`?o00000oooool2o`0002gooooo0_l00004ooooo`;o00002Oooool2o`0000Kooooo0_l00003
ooooo`;o000000?oooooo`000?l000005Oooool2o`0006Cooooo00000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000J?ooool3
o`0000_ooooo0ol0000Vooooo`;o00001oooool3o`000003ooooool0003o000000cooooo0_l00002
ooooo`;o00001?ooool2o`0000Kooooo0_l0001kooooo`0000?oooooo`000?ooool00_ooool00ol0
003oooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`1Y
ooooo`;o00003?ooool2o`0001[ooooo0_l00008ooooo`Co000000?oooooo`000?l000001?ooool3
o`000003ooooool0003o000000cooooo0_l00002ooooo`;o0000ROooool00003ooooool@413ooooo
00;ooooo00?o410@ooooooooool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000
ooooooooool0MOooool4o`0001[ooooo0_l00003ooooo`?o00000_ooool4o`000003ooooool0003o
000000Cooooo0_l00006ooooo`;o00001oooool2o`0001gooooo0_l00003ooooo`;o0000J_ooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo
00?o0000ooooooooool0LOooool8o`0000?ooooo0_l00009ooooo`Co00003Oooool3o`0000Cooooo
0_l00003ooooo`;o00000_ooool2o`0000Kooooo0_l00007ooooo`;o00007Oooool2o`0000?ooooo
0_l0001Zooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@
4?nYZJT01_ooool00ol0003oooooooooo`1aooooo`So00000_ooool3o`0000Wooooo1?l0000Eoooo
o`;o00000_ooool2o`0001?ooooo0_l0002>ooooo`007?ooool00ol0003oooooooooo`1cooooo`Ko
00000_ooool3o`00013ooooo0_l00005ooooo`;o00001Oooool2o`0000;ooooo0_l00007ooooo`;o
000000?oooooo`000?l000000oooool2o`0001?ooooo0_l00003ooooo`;o0000O?ooool001cooooo
00?o0000ooooooooool0Loooool3o`0000Kooooo0_l0000@ooooo`;o00001Oooool3o`0000Cooooo
0_l0000:ooooo`?o000000Coooooo`000?l0003o00000_ooool4o`0000Oooooo0_l00008ooooo`;o
00000oooool2o`0007cooooo000Looooo`03o`000?oooooooooo07Cooooo0_l0000Pooooo`;o0000
1?ooool2o`0000Kooooo0ol000000ooooooo0000o`000002ooooo`?o00000_ooool7o`0000Cooooo
0_l0002;ooooo`007?ooool00ol0003oooooooooo`26ooooo`Co00003?ooool2o`0000Cooooo0_l0
0006ooooo`Go00001Oooool2o`000003ooooool0003o000000Go0000TOooool001cooooo00?o0000
ooooooooool0Q_ooool4o`0000cooooo0_l00004ooooo`Oo00001?ooool2o`0000;ooooo0_l00000
0ooooooo0000o`000002ooooo`?o0000U?ooool001cooooo00?o0000ooooooooool0Roooool2o`00
00Kooooo0_l00008ooooo`Ko00000oooool3o`0000;ooooo1Ol00003ooooo`Co0000T_ooool001co
oooo00?o0000ooooooooool0Roooool2o`0000Kooooo0_l0000Aooooo`;o000000Coooooo`000?l0
003ooooo1?l00005ooooo`;o00007?ooool2o`0007Cooooo000Looooo`03o`000?oooooooooo097o
oooo0ol0000=ooooo`;o00001_ooool2o`0002Sooooo0_l0001dooooo`007?ooool00ol0003ooooo
ooooo`2Aooooo`?o00003Oooool2o`000:Kooooo000Looooo`03o`000?oooooooooo08gooooo0_l0
000Rooooo`;o0000U_ooool001cooooo00?o0000ooooooooool0SOooool4o`0000Sooooo0_l0000F
ooooo`;o00000oooool2o`00097ooooo000Looooo`;o0000T?ooool3o`0000Oooooo0_l0000Koooo
o`;o0000TOooool001cooooo00?o0000ooooooooool0T?ooool2o`0000Oooooo0ol0000Nooooo`;o
0000SOooool001cooooo00?o0000ooooooooool0VOooool3o`0000?ooooo0_l0000Iooooo`;o0000
SOooool001cooooo00?o0000ooooooooool0VOooool2o`0000Cooooo0_l0002Xooooo`007?ooool0
0ol0003oooooooooo`2Iooooo`;o00001?ooool2o`000:Sooooo000Looooo`03o`000?oooooooooo
09Gooooo0_l0002booooo`007?ooool00ol0003oooooooooo`1nooooo`;o00005Oooool2o`0000;o
oooo0_l000000ooooooo0000o`000003ooooo`;o0000Y_ooool001cooooo00?o0000ooooooooool0
O_ooool2o`0001Wooooo0_l000000ooooooo0000o`000003ooooo`;o0000Y_ooool001cooooo00?o
0000ooooooooool0X?ooool2o`000:Oooooo000Looooo`03o`000?oooooooooo09_ooooo0_l00003
ooooo`;o00007?ooool2o`0008Wooooo000Looooo`03o`000?oooooooooo09_ooooo0_l0000Qoooo
o`;o0000ROooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`2=ooooo`Co0000^?ooool001cooooo00?o0000ooooooooool0SOooool4o`000;Sooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001;ooooo1?l000000ol@413o
ooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo0ol0
003ooooood[ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000oooo
ooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`00
0?oooooooooo0?ooooooD_ooool001;ooooo00?oEEEEofIVI_l00000oooooomDooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00XOooool01?l@413o0000o`000?ooool2o`000003
oa0@4?oooooooooo01Kooooo1?l000000ol@413oooooooooo`02ooooo`;o000000?o410@oooooooo
ool00oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?l@413oc<c<08cooooo002R
ooooo`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00GoEEEEogMgMoooooooV9RH
ob4Q8@2<ooooo`00X_ooool01Ol0003ooooooooooooooooo000001_ooooo00?o0000ooooooooool0
0_ooool5o`0000?ooooo1Ol00003ooooo`05o`000?ooooooooooooooool00000S?ooool00:;ooooo
00Go0000ooooooooooooooooo`000009ooooo`Ko00003?ooool00ol0003oooooooooo`02ooooo`04
odA4A?oMgMgoooooo`0000Cooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003oV9RHoooooonH
V9So8B4Q08cooooo002Rooooo`05o`000?n7QhOoooooojVYZOl000006oooool00ol0003ooooooooo
o`02ooooo`04omgMgOmEEEGoooooo`0000Cooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003o
EEEEo`000?l@413oc<c<08cooooo002Qooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHoooooooo
ool06Oooool00ol0003oooooooooo`03ooooo`03ogMgMoo<c<co000000Gooooo00?oMgMgolc<c?l0
00001?ooool00omEEEGoQhN7ooooo`2>ooooo`00`_ooool00ol0003oooooooooo`03ooooo`03onk^
k_m4A4Co000000Gooooo00?ok^k^odA4A?l000001?ooool00ooMgMgo410@oiRHV02>ooooo`00`?oo
ool00omEEEGoIVIVo`000006ooooo`03ogMgMol0003ooooo00Gooooo00?oMgMgo`000?ooool01?oo
ool01?o<c<coA4A4o`000?l@412<ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1452) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.6818 .42799 Mdot
.68956 .43361 Mdot
.36459 .4046 Mdot
.55856 .60593 Mdot
.29964 .72897 Mdot
.39121 .43365 Mdot
.53421 .37715 Mdot
.5447 .36563 Mdot
.36061 .39841 Mdot
.70756 .38682 Mdot
.55135 .3319 Mdot
.50822 .70036 Mdot
.52721 .34014 Mdot
.55447 .65131 Mdot
.65219 .8265 Mdot
.58815 .67357 Mdot
.68216 .43088 Mdot
.28756 .61782 Mdot
.58454 .66527 Mdot
.40905 .40865 Mdot
.61613 .4331 Mdot
.55374 .64615 Mdot
.66209 .4358 Mdot
.5542 .65193 Mdot
.53936 .609 Mdot
.65279 .43834 Mdot
.6806 .49188 Mdot
.5119 .61216 Mdot
.51682 .65742 Mdot
.5557 .33804 Mdot
.3562 .62635 Mdot
.51136 .83475 Mdot
.5796 .55377 Mdot
.49769 .77099 Mdot
.50178 .34163 Mdot
.70686 .64071 Mdot
.37552 .43112 Mdot
.54682 .35239 Mdot
.54765 .34375 Mdot
.53305 .36712 Mdot
.54087 .36157 Mdot
.66039 .45684 Mdot
.65315 .27608 Mdot
.46805 .30194 Mdot
.49157 .65457 Mdot
.20938 .59549 Mdot
.6467 .67993 Mdot
.57561 .63764 Mdot
.63674 .47829 Mdot
.26556 .42386 Mdot
.43884 .27955 Mdot
.49177 .33906 Mdot
.39375 .39296 Mdot
.43983 .11205 Mdot
.52162 .32748 Mdot
.48652 .59665 Mdot
.37246 .41794 Mdot
.53999 .64553 Mdot
.55106 .65636 Mdot
.75286 .51462 Mdot
.51579 .5795 Mdot
.33236 .54741 Mdot
.69485 .4176 Mdot
.44662 .49792 Mdot
.38009 .40873 Mdot
.54804 .33345 Mdot
.6836 .4698 Mdot
.51522 .32974 Mdot
.58596 .54749 Mdot
.33204 .43462 Mdot
.58051 .62389 Mdot
.55176 .33531 Mdot
.62099 .43248 Mdot
.51527 .63458 Mdot
.24816 .41927 Mdot
.19174 .56936 Mdot
.36096 .57704 Mdot
.71621 .60942 Mdot
.75511 .50725 Mdot
.25988 .48964 Mdot
.49477 .63638 Mdot
.34478 .67383 Mdot
.19637 .56029 Mdot
.6371 .48875 Mdot
.59775 .63351 Mdot
.3615 .60715 Mdot
.515 .62843 Mdot
.25312 .71066 Mdot
.55074 .56505 Mdot
.47025 .51929 Mdot
.34418 .4136 Mdot
.63322 .45235 Mdot
.55343 .60362 Mdot
.52368 .66133 Mdot
.78033 .5162 Mdot
.58493 .63034 Mdot
.55283 .62945 Mdot
.64814 .48855 Mdot
.49206 .33296 Mdot
.51399 .57141 Mdot
.36031 .48509 Mdot
.39149 .4482 Mdot
.52629 .58282 Mdot
.33879 .4366 Mdot
.62108 .43729 Mdot
.52361 .66033 Mdot
.54241 .33901 Mdot
.54297 .58244 Mdot
.48869 .21227 Mdot
.68065 .43733 Mdot
.50541 .63462 Mdot
.32113 .59089 Mdot
.68173 .54858 Mdot
.62722 .45767 Mdot
.48692 .29273 Mdot
.57826 .6712 Mdot
.54152 .62883 Mdot
.6803 .47483 Mdot
.39047 .4522 Mdot
.23254 .66631 Mdot
.66125 .49029 Mdot
.53387 .306 Mdot
.61117 .45824 Mdot
.49099 .68887 Mdot
.38561 .40505 Mdot
.47858 .29515 Mdot
.55852 .24837 Mdot
.37953 .63832 Mdot
.51807 .62827 Mdot
.67747 .29406 Mdot
.41129 .42725 Mdot
.64359 .46591 Mdot
.51685 .33358 Mdot
.57766 .56334 Mdot
.67664 .45538 Mdot
.53605 .31224 Mdot
.30264 .56175 Mdot
.42835 .24429 Mdot
.65421 .42016 Mdot
.54301 .43184 Mdot
.49308 .3222 Mdot
.50693 .36023 Mdot
.73442 .72103 Mdot
.66294 .47979 Mdot
.32796 .57774 Mdot
.5123 .33821 Mdot
.41935 .62842 Mdot
.4884 .64304 Mdot
.31995 .65997 Mdot
.5776 .1952 Mdot
.48741 .75116 Mdot
.37696 .29314 Mdot
.31419 .5824 Mdot
.48232 .32811 Mdot
.55379 .61735 Mdot
.64416 .43366 Mdot
.65828 .43812 Mdot
.51629 .57962 Mdot
.53312 .59819 Mdot
.58198 .60514 Mdot
.57216 .65855 Mdot
.49241 .52942 Mdot
.5722 .56869 Mdot
.65744 .65786 Mdot
.63333 .44631 Mdot
.55988 .61176 Mdot
.38742 .39151 Mdot
.52347 .69186 Mdot
.55308 .35367 Mdot
.54646 .64373 Mdot
.55601 .60587 Mdot
.49376 .60782 Mdot
.49515 .34696 Mdot
.47636 .82757 Mdot
.63932 .54248 Mdot
.45012 .79872 Mdot
.56138 .49378 Mdot
.34079 .3923 Mdot
.51862 .61925 Mdot
.33547 .56071 Mdot
.74573 .63516 Mdot
.56545 .59837 Mdot
.15321 .36193 Mdot
.55637 .6355 Mdot
.3646 .78309 Mdot
.60059 .67654 Mdot
.47061 .78657 Mdot
.35783 .66486 Mdot
.53798 .61435 Mdot
.71086 .35459 Mdot
.56755 .37774 Mdot
.32066 .44555 Mdot
.53283 .35875 Mdot
.39351 .39663 Mdot
.3684 .40829 Mdot
.39556 .51141 Mdot
.52327 .71048 Mdot
.5432 .69563 Mdot
.57223 .58081 Mdot
.36272 .45958 Mdot
.6946 .46908 Mdot
.3147 .59057 Mdot
.687 .41106 Mdot
.43004 .84389 Mdot
.27708 .38206 Mdot
.56115 .35818 Mdot
.29588 .56379 Mdot
.35039 .43758 Mdot
.34545 .40744 Mdot
.30929 .58384 Mdot
.53678 .66817 Mdot
.66545 .47789 Mdot
.6316 .77834 Mdot
.41502 .2189 Mdot
.8744 .51126 Mdot
.64147 .48596 Mdot
.68425 .31799 Mdot
.55348 .36009 Mdot
.36301 .4288 Mdot
.54461 .62861 Mdot
.52805 .65366 Mdot
.62356 .4215 Mdot
.58064 .62579 Mdot
.60378 .47058 Mdot
.54002 .6211 Mdot
.55378 .38554 Mdot
.36418 .56402 Mdot
.39499 .51207 Mdot
.40918 .65907 Mdot
.62093 .4509 Mdot
.80282 .58379 Mdot
.34294 .40439 Mdot
.75295 .62254 Mdot
.5428 .3245 Mdot
.31156 .54874 Mdot
.36325 .38809 Mdot
.32978 .59169 Mdot
.58919 .60364 Mdot
.40527 .41482 Mdot
.34281 .58247 Mdot
.4185 .57059 Mdot
.5052 .67363 Mdot
.40353 .19801 Mdot
.52474 .3638 Mdot
.68403 .4177 Mdot
.54841 .57946 Mdot
.33554 .41444 Mdot
.54943 .5412 Mdot
.31166 .33788 Mdot
.5035 .24597 Mdot
.41365 .42362 Mdot
.39006 .54386 Mdot
.31781 .54308 Mdot
.41658 .30821 Mdot
.67476 .29762 Mdot
.68925 .42699 Mdot
.58764 .60748 Mdot
.5253 .82551 Mdot
.51237 .33749 Mdot
.55335 .58467 Mdot
.27451 .66323 Mdot
.50096 .33227 Mdot
.53821 .64435 Mdot
.52205 .30663 Mdot
.65889 .43854 Mdot
.75704 .48076 Mdot
.67605 .47917 Mdot
.58112 .62954 Mdot
.53561 .33332 Mdot
.39158 .4554 Mdot
.65045 .44464 Mdot
.54985 .67037 Mdot
.51433 .61227 Mdot
.42053 .52997 Mdot
.5631 .61979 Mdot
.44207 .8092 Mdot
.53865 .6175 Mdot
.35849 .41594 Mdot
.49581 .61983 Mdot
.76082 .36858 Mdot
.39202 .50825 Mdot
.67568 .47672 Mdot
.41636 .41624 Mdot
.37199 .40119 Mdot
.21588 .48633 Mdot
.47587 .32369 Mdot
.54259 .68442 Mdot
.33699 .40505 Mdot
.45297 .66977 Mdot
.51892 .3149 Mdot
.53305 .57271 Mdot
.50849 .41293 Mdot
.28547 .39674 Mdot
.40102 .39874 Mdot
.46775 .60032 Mdot
.63839 .42263 Mdot
.54691 .60078 Mdot
.3397 .42423 Mdot
.52815 .72076 Mdot
.50788 .64843 Mdot
.65295 .24877 Mdot
.40741 .54164 Mdot
.49568 .32332 Mdot
.52742 .69938 Mdot
.56999 .58923 Mdot
.40266 .41871 Mdot
.62421 .44124 Mdot
.51015 .31498 Mdot
.65635 .45211 Mdot
.47248 .78056 Mdot
.41668 .19967 Mdot
.45632 .53587 Mdot
.35708 .57531 Mdot
.3121 .45961 Mdot
.48338 .79123 Mdot
.81781 .48727 Mdot
.73325 .69198 Mdot
.54208 .78984 Mdot
.34784 .4446 Mdot
.29173 .44093 Mdot
.37382 .40873 Mdot
.51947 .59975 Mdot
.38614 .40932 Mdot
.54121 .83091 Mdot
.54341 .62271 Mdot
.38722 .42112 Mdot
.79489 .553 Mdot
.54931 .60533 Mdot
.6908 .42819 Mdot
.41221 .82383 Mdot
.78091 .35758 Mdot
.54583 .26819 Mdot
.36591 .44001 Mdot
.65255 .75898 Mdot
.55453 .62821 Mdot
.49662 .61859 Mdot
.63343 .4379 Mdot
.56897 .54926 Mdot
.3436 .55891 Mdot
.29662 .55869 Mdot
.57096 .33122 Mdot
.36343 .53465 Mdot
.5245 .69941 Mdot
.64801 .44322 Mdot
.52125 .52067 Mdot
.22649 .47413 Mdot
.27212 .42026 Mdot
.56655 .35618 Mdot
.41116 .82255 Mdot
.59408 .40592 Mdot
.58646 .39002 Mdot
.3949 .353 Mdot
.63747 .47204 Mdot
.50188 .83595 Mdot
.53675 .35766 Mdot
.35448 .21692 Mdot
.72363 .38531 Mdot
.53507 .66477 Mdot
.52696 .32025 Mdot
.50888 .55204 Mdot
.78584 .38114 Mdot
.29719 .27012 Mdot
.60984 .72577 Mdot
.54709 .56643 Mdot
.27714 .39056 Mdot
.54617 .63745 Mdot
.3019 .35846 Mdot
.53142 .61365 Mdot
.65412 .45509 Mdot
.70655 .3838 Mdot
.5209 .27819 Mdot
.62765 .52044 Mdot
.40844 .31932 Mdot
.31981 .58513 Mdot
.53815 .62295 Mdot
.53796 .66624 Mdot
.34768 .56052 Mdot
.66105 .42857 Mdot
.58324 .61607 Mdot
.80807 .56828 Mdot
.53336 .67172 Mdot
.54946 .35656 Mdot
.74435 .40027 Mdot
.63348 .62322 Mdot
.57107 .66927 Mdot
.62853 .48665 Mdot
.55195 .37076 Mdot
.53644 .33639 Mdot
.58441 .6965 Mdot
.55905 .34013 Mdot
.564 .63278 Mdot
.2741 .29198 Mdot
.66436 .42226 Mdot
.58327 .21586 Mdot
.67582 .46593 Mdot
.71 .59522 Mdot
.4947 .33534 Mdot
.45831 .23982 Mdot
.49823 .56195 Mdot
.53508 .35437 Mdot
.6713 .51127 Mdot
.52491 .68142 Mdot
.52607 .68395 Mdot
.63376 .77263 Mdot
.35039 .42014 Mdot
.41476 .53025 Mdot
.55544 .33667 Mdot
.56401 .65397 Mdot
.58356 .65611 Mdot
.54992 .37068 Mdot
.33591 .26285 Mdot
.7882 .43516 Mdot
.54033 .61963 Mdot
.64816 .45828 Mdot
.64793 .46788 Mdot
.48618 .65023 Mdot
.52944 .58506 Mdot
.38322 .39451 Mdot
.40411 .44835 Mdot
.33684 .39071 Mdot
.40761 .53347 Mdot
.48558 .23899 Mdot
.25954 .68769 Mdot
.5317 .36684 Mdot
.65887 .32095 Mdot
.44911 .53419 Mdot
.55738 .56477 Mdot
.3698 .44408 Mdot
.57178 .59301 Mdot
.57066 .61558 Mdot
.46436 .33899 Mdot
.31399 .7291 Mdot
.62342 .38953 Mdot
.62104 .44446 Mdot
.48433 .33224 Mdot
.54176 .70279 Mdot
.50051 .38875 Mdot
.31928 .54824 Mdot
.49175 .74254 Mdot
.54615 .32672 Mdot
.69255 .43897 Mdot
.51132 .35422 Mdot
.52541 .6547 Mdot
.51409 .55868 Mdot
.64066 .47297 Mdot
.33601 .54543 Mdot
.58305 .56323 Mdot
.53781 .6404 Mdot
.53389 .17294 Mdot
.44015 .67858 Mdot
.58458 .37861 Mdot
.54041 .6163 Mdot
.53984 .67955 Mdot
.30275 .53993 Mdot
.53141 .6693 Mdot
.56432 .5772 Mdot
.67754 .55655 Mdot
.59422 .29646 Mdot
.29842 .58363 Mdot
.2893 .28666 Mdot
.64265 .48582 Mdot
.50934 .82214 Mdot
.38032 .4418 Mdot
.54823 .29428 Mdot
.77516 .42436 Mdot
.38242 .38532 Mdot
.36864 .2995 Mdot
.49757 .81957 Mdot
.36991 .48709 Mdot
.33809 .37937 Mdot
.70222 .43084 Mdot
.57454 .64724 Mdot
.53974 .63183 Mdot
.33798 .56164 Mdot
.665 .47538 Mdot
.50851 .48296 Mdot
.17682 .47746 Mdot
.55353 .6436 Mdot
.63957 .24334 Mdot
.27254 .33112 Mdot
.27555 .40502 Mdot
.32465 .56147 Mdot
.29566 .55623 Mdot
.53681 .62424 Mdot
.66584 .545 Mdot
.65181 .4383 Mdot
.55069 .66958 Mdot
.5698 .56662 Mdot
.35451 .42957 Mdot
.67727 .43871 Mdot
.39188 .45162 Mdot
.42593 .27632 Mdot
.43303 .79543 Mdot
.33966 .20613 Mdot
.51024 .32378 Mdot
.24433 .39655 Mdot
.51839 .30984 Mdot
.35187 .67661 Mdot
.38704 .38303 Mdot
.54341 .59368 Mdot
.62929 .43407 Mdot
.56785 .64598 Mdot
.53249 .58649 Mdot
.53847 .66832 Mdot
.57646 .66225 Mdot
.3733 .17995 Mdot
.32111 .58718 Mdot
.59378 .60799 Mdot
.36003 .41094 Mdot
.20495 .56694 Mdot
.19566 .51404 Mdot
.53996 .66459 Mdot
.52396 .6136 Mdot
.67101 .44017 Mdot
.53126 .57655 Mdot
.51597 .31135 Mdot
.69417 .42555 Mdot
.51538 .64236 Mdot
.34429 .79277 Mdot
.51425 .65453 Mdot
.46986 .79648 Mdot
.51277 .35433 Mdot
.43333 .21221 Mdot
.5247 .55395 Mdot
.51518 .25186 Mdot
.41488 .53035 Mdot
.36745 .38716 Mdot
.50718 .30574 Mdot
.37796 .43018 Mdot
.18204 .44479 Mdot
.47285 .6291 Mdot
.5507 .61512 Mdot
.565 .57044 Mdot
.34025 .39273 Mdot
.281 .75358 Mdot
.42862 .32276 Mdot
.47115 .62858 Mdot
.38873 .39569 Mdot
.66629 .49692 Mdot
.5501 .77011 Mdot
.66683 .46144 Mdot
.35359 .53933 Mdot
.5501 .36134 Mdot
.3368 .54708 Mdot
.38283 .73553 Mdot
.68376 .43752 Mdot
.64258 .40673 Mdot
.37742 .44059 Mdot
.71351 .40695 Mdot
.74465 .24684 Mdot
.72376 .38329 Mdot
.3801 .66091 Mdot
.64137 .43903 Mdot
.51988 .66031 Mdot
.35773 .70242 Mdot
.71761 .3852 Mdot
.37903 .42747 Mdot
.5732 .60549 Mdot
.76213 .47304 Mdot
.38227 .39365 Mdot
.5347 .55887 Mdot
.35547 .41101 Mdot
.52726 .3586 Mdot
.36117 .44093 Mdot
.61338 .42704 Mdot
.50995 .62602 Mdot
.76487 .25609 Mdot
.37116 .53517 Mdot
.554 .6242 Mdot
.4874 .34502 Mdot
.35846 .27473 Mdot
.55406 .5929 Mdot
.35072 .57845 Mdot
.39328 .41825 Mdot
.71389 .4267 Mdot
.53666 .61733 Mdot
.38964 .39592 Mdot
.67393 .41905 Mdot
.48002 .34387 Mdot
.77734 .51302 Mdot
.58482 .324 Mdot
.62988 .43999 Mdot
.57749 .4703 Mdot
.48789 .30704 Mdot
.54301 .68026 Mdot
.58578 .62795 Mdot
.64958 .46222 Mdot
.27567 .62858 Mdot
.50736 .59447 Mdot
.49538 .62683 Mdot
.35657 .4263 Mdot
.38281 .43119 Mdot
.72456 .69535 Mdot
.37821 .45479 Mdot
.5279 .55533 Mdot
.65201 .46285 Mdot
.55554 .60343 Mdot
.67246 .43623 Mdot
.53215 .57687 Mdot
.61059 .67225 Mdot
.66021 .42833 Mdot
.46824 .34629 Mdot
.57215 .60871 Mdot
.59672 .5792 Mdot
.54665 .58364 Mdot
.571 .65567 Mdot
.38212 .39622 Mdot
.33063 .5581 Mdot
.56299 .5642 Mdot
.31906 .60308 Mdot
.30808 .58633 Mdot
.5355 .27226 Mdot
.35257 .42735 Mdot
.33292 .5807 Mdot
.23537 .35446 Mdot
.40141 .40633 Mdot
.34079 .56397 Mdot
.19554 .51712 Mdot
.50039 .34168 Mdot
.63641 .42265 Mdot
.54593 .604 Mdot
.44215 .75527 Mdot
.6466 .66695 Mdot
.41072 .38439 Mdot
.54307 .61939 Mdot
.55675 .58683 Mdot
.66233 .49239 Mdot
.1612 .52496 Mdot
.33098 .43096 Mdot
.52017 .66704 Mdot
.68878 .44015 Mdot
.1495 .56926 Mdot
.36383 .41386 Mdot
.33996 .5594 Mdot
.50224 .35038 Mdot
.69825 .47326 Mdot
.55079 .24027 Mdot
.50206 .36079 Mdot
.42314 .44578 Mdot
.43715 .27382 Mdot
.59009 .64713 Mdot
.38649 .44582 Mdot
.83177 .59972 Mdot
.48339 .53836 Mdot
.43618 .50785 Mdot
.6316 .76294 Mdot
.63171 .46462 Mdot
.51798 .31041 Mdot
.31382 .58314 Mdot
.63499 .48151 Mdot
.68087 .43036 Mdot
.54444 .37067 Mdot
.64295 .55552 Mdot
.50473 .40987 Mdot
.54985 .34832 Mdot
.45455 .72742 Mdot
.25005 .62684 Mdot
.37725 .44574 Mdot
.34404 .56009 Mdot
.36669 .73805 Mdot
.65946 .454 Mdot
.45656 .84878 Mdot
.64997 .77221 Mdot
.55305 .6296 Mdot
.32182 .58086 Mdot
.2793 .74153 Mdot
.1717 .54482 Mdot
.49961 .33102 Mdot
.53939 .28113 Mdot
.32585 .54213 Mdot
.55129 .58035 Mdot
.46944 .71054 Mdot
.50732 .60395 Mdot
.54293 .36463 Mdot
.77871 .54369 Mdot
.68352 .43432 Mdot
.52095 .36641 Mdot
.51277 .75844 Mdot
.56304 .63533 Mdot
.57095 .60506 Mdot
.42121 .69337 Mdot
.63216 .48113 Mdot
.36582 .3869 Mdot
.58877 .62722 Mdot
.54126 .64164 Mdot
.5158 .56072 Mdot
.48486 .65594 Mdot
.71005 .52839 Mdot
.52219 .60298 Mdot
.2409 .41865 Mdot
.54707 .56919 Mdot
.57145 .62894 Mdot
.62319 .47867 Mdot
.3061 .22618 Mdot
.43121 .28913 Mdot
.54484 .64242 Mdot
.53255 .67724 Mdot
.51689 .36375 Mdot
.48175 .39512 Mdot
.68496 .38549 Mdot
.71254 .43013 Mdot
.69339 .73166 Mdot
.50808 .67637 Mdot
.68441 .4667 Mdot
.34823 .57768 Mdot
.54222 .68348 Mdot
.68966 .45276 Mdot
.49162 .61729 Mdot
.3786 .39031 Mdot
.39965 .40362 Mdot
.53748 .52187 Mdot
.33561 .5813 Mdot
.73713 .34618 Mdot
.65546 .31968 Mdot
.40294 .41392 Mdot
.54726 .61288 Mdot
.56565 .38218 Mdot
.34067 .41767 Mdot
.36055 .49087 Mdot
.27927 .65458 Mdot
.64361 .43175 Mdot
.63162 .44901 Mdot
.3151 .66059 Mdot
.39566 .27832 Mdot
.64748 .23319 Mdot
.52894 .36004 Mdot
.58899 .59217 Mdot
.70276 .33311 Mdot
.62887 .45011 Mdot
.35885 .6905 Mdot
.32559 .58266 Mdot
.50129 .33332 Mdot
.43398 .353 Mdot
.67308 .45132 Mdot
.66054 .41227 Mdot
.50914 .58147 Mdot
.53331 .64747 Mdot
.74646 .67289 Mdot
.30904 .60247 Mdot
.52852 .37575 Mdot
.34224 .55812 Mdot
.39319 .38605 Mdot
.50588 .61389 Mdot
.66009 .43117 Mdot
.24549 .63497 Mdot
.5636 .68007 Mdot
.36511 .39358 Mdot
.63101 .45933 Mdot
.3144 .54356 Mdot
.35504 .57181 Mdot
.56928 .66382 Mdot
.77185 .62632 Mdot
.54326 .35245 Mdot
.64769 .4811 Mdot
.57237 .39501 Mdot
.50995 .59784 Mdot
.53017 .63842 Mdot
.6124 .62764 Mdot
.52542 .37475 Mdot
.62077 .36626 Mdot
.34764 .58516 Mdot
.65682 .47624 Mdot
.52297 .60627 Mdot
.34378 .56816 Mdot
.66953 .32332 Mdot
.41483 .4025 Mdot
.35708 .43929 Mdot
.35516 .5678 Mdot
.31701 .5666 Mdot
.34417 .586 Mdot
.45944 .85079 Mdot
.68487 .47718 Mdot
.58847 .41037 Mdot
.51084 .66404 Mdot
.36556 .66244 Mdot
.59296 .59779 Mdot
.49813 .31804 Mdot
.35016 .41617 Mdot
.54522 .58854 Mdot
.56472 .6732 Mdot
.60714 .66658 Mdot
.60743 .223 Mdot
.61859 .5701 Mdot
.67833 .43494 Mdot
.51313 .55831 Mdot
.36619 .43895 Mdot
.45926 .86491 Mdot
.67706 .77273 Mdot
.51959 .55545 Mdot
.51177 .40876 Mdot
.65381 .42703 Mdot
.533 .36768 Mdot
.41465 .7188 Mdot
.50152 .34518 Mdot
.65077 .47433 Mdot
.51728 .60353 Mdot
.65173 .33853 Mdot
.29063 .54946 Mdot
.56679 .65365 Mdot
.52941 .36275 Mdot
.57981 .62527 Mdot
.51817 .37127 Mdot
.43938 .76303 Mdot
.81729 .60444 Mdot
.55561 .63493 Mdot
.59074 .66098 Mdot
.77074 .6498 Mdot
.54585 .66533 Mdot
.27542 .5978 Mdot
.65307 .4267 Mdot
.78431 .54224 Mdot
.56542 .69208 Mdot
.50421 .72933 Mdot
.50421 .60557 Mdot
.78904 .50898 Mdot
.52872 .64147 Mdot
.27232 .40579 Mdot
.5059 .63029 Mdot
.56692 .57781 Mdot
.5241 .32645 Mdot
.51798 .36535 Mdot
.61525 .45114 Mdot
.3359 .42621 Mdot
.46332 .79952 Mdot
.53497 .63876 Mdot
.47047 .24408 Mdot
.60607 .32625 Mdot
.31913 .56413 Mdot
.65531 .47399 Mdot
.16691 .59879 Mdot
.5458 .31797 Mdot
.72425 .72384 Mdot
.68558 .7292 Mdot
.59391 .2689 Mdot
.31896 .71884 Mdot
.32124 .29689 Mdot
.31616 .54521 Mdot
.49546 .60435 Mdot
.29519 .51706 Mdot
.26953 .40614 Mdot
.26986 .62883 Mdot
.4998 .30564 Mdot
.74321 .64899 Mdot
.28079 .68521 Mdot
.35541 .54947 Mdot
.30158 .54716 Mdot
.49306 .34592 Mdot
.31292 .39707 Mdot
.51424 .70617 Mdot
.31475 .57794 Mdot
.33695 .39417 Mdot
.40562 .40662 Mdot
.32996 .40172 Mdot
.6544 .43678 Mdot
.68213 .76444 Mdot
.502 .29958 Mdot
.49955 .31993 Mdot
.30221 .41056 Mdot
.55953 .74201 Mdot
.67354 .40339 Mdot
.36949 .43345 Mdot
.36589 .44927 Mdot
.65126 .42448 Mdot
.4877 .59897 Mdot
.4771 .6461 Mdot
.54954 .64331 Mdot
.33377 .56095 Mdot
.52949 .64863 Mdot
.39174 .40076 Mdot
.50688 .32661 Mdot
.35476 .44258 Mdot
.49071 .35214 Mdot
.23894 .64122 Mdot
.55446 .67202 Mdot
.50845 .62458 Mdot
.48515 .16813 Mdot
.63793 .41497 Mdot
.21273 .58455 Mdot
.49285 .37459 Mdot
.37188 .40886 Mdot
.56396 .57773 Mdot
.68838 .40798 Mdot
.28785 .58703 Mdot
.34424 .20852 Mdot
.5222 .58509 Mdot
.66454 .44699 Mdot
.50903 .611 Mdot
.44713 .56603 Mdot
.71671 .28158 Mdot
.65828 .4613 Mdot
.61679 .21653 Mdot
.52134 .66552 Mdot
.2432 .3616 Mdot
.54124 .57132 Mdot
.42101 .5765 Mdot
.5075 .5944 Mdot
.64378 .48667 Mdot
.54666 .64664 Mdot
.69086 .41342 Mdot
.40326 .42644 Mdot
.51881 .36277 Mdot
.6308 .4411 Mdot
.58026 .64889 Mdot
.62171 .1099 Mdot
.51678 .35075 Mdot
.54167 .626 Mdot
.4954 .34421 Mdot
.67158 .47338 Mdot
.63393 .4751 Mdot
.18262 .51407 Mdot
.42214 .27836 Mdot
.5258 .35693 Mdot
.50668 .61316 Mdot
.26386 .36275 Mdot
.53534 .59516 Mdot
.45778 .68298 Mdot
.48787 .59389 Mdot
.49266 .63992 Mdot
.19079 .54002 Mdot
.4938 .32473 Mdot
.64547 .22979 Mdot
.1809 .54749 Mdot
.2036 .56419 Mdot
.61515 .4336 Mdot
.35425 .55115 Mdot
.49248 .83308 Mdot
.4904 .23971 Mdot
.37705 .38746 Mdot
.54917 .58847 Mdot
.64331 .51577 Mdot
.54425 .34766 Mdot
.32204 .55025 Mdot
.55466 .63448 Mdot
.36716 .44754 Mdot
.80758 .46685 Mdot
.48295 .32896 Mdot
.66194 .46134 Mdot
.65955 .4966 Mdot
.20625 .35245 Mdot
.53405 .61235 Mdot
.51025 .63134 Mdot
.54992 .36182 Mdot
.34022 .27552 Mdot
.29875 .57165 Mdot
.79511 .54764 Mdot
.52425 .3548 Mdot
.50251 .46341 Mdot
.69094 .4523 Mdot
.55964 .58597 Mdot
.34677 .78222 Mdot
.41778 .34452 Mdot
.52574 .1835 Mdot
.33531 .56223 Mdot
.45217 .67179 Mdot
.64443 .48638 Mdot
.51548 .33552 Mdot
.39937 .25977 Mdot
.52009 .68236 Mdot
.57659 .60302 Mdot
.42858 .60966 Mdot
.52522 .27369 Mdot
.68135 .39004 Mdot
.51957 .58815 Mdot
.41438 .52794 Mdot
.52755 .58168 Mdot
.59957 .65962 Mdot
.48459 .59195 Mdot
.5232 .63035 Mdot
.66295 .43664 Mdot
.45737 .64266 Mdot
.34627 .39229 Mdot
.62314 .39381 Mdot
.49095 .46827 Mdot
.54879 .62306 Mdot
.49662 .63174 Mdot
.62271 .71177 Mdot
.34224 .31013 Mdot
.63289 .44146 Mdot
.62522 .41159 Mdot
.55266 .32635 Mdot
.47895 .62781 Mdot
.33664 .42801 Mdot
.58904 .57803 Mdot
.37835 .39533 Mdot
.66105 .43399 Mdot
.36906 .41109 Mdot
.50276 .35398 Mdot
.39302 .44359 Mdot
.47897 .23829 Mdot
.5094 .34099 Mdot
.63723 .4335 Mdot
.51721 .63992 Mdot
.48682 .3448 Mdot
.39614 .63964 Mdot
.334 .5633 Mdot
.21553 .68136 Mdot
.51497 .64267 Mdot
.57777 .27299 Mdot
.56415 .72093 Mdot
.35978 .44616 Mdot
.70078 .26498 Mdot
.62546 .43533 Mdot
.2935 .57419 Mdot
.62639 .47493 Mdot
.49515 .74195 Mdot
.32334 .57059 Mdot
.19994 .63434 Mdot
.41189 .55275 Mdot
.44135 .67627 Mdot
.48179 .62606 Mdot
.42311 .67674 Mdot
.40149 .39523 Mdot
.54264 .34567 Mdot
.38789 .27359 Mdot
.56882 .58169 Mdot
.83388 .49731 Mdot
.62764 .48224 Mdot
.33665 .41454 Mdot
.5177 .33191 Mdot
.50462 .3156 Mdot
.52427 .67624 Mdot
.2661 .45927 Mdot
.57734 .60131 Mdot
.41336 .26718 Mdot
.6518 .75727 Mdot
.58916 .4228 Mdot
.54032 .62155 Mdot
.40295 .41982 Mdot
.50925 .61069 Mdot
.35076 .58349 Mdot
.75964 .69458 Mdot
.59189 .5731 Mdot
.53916 .38878 Mdot
.29778 .60054 Mdot
.6629 .48187 Mdot
.59321 .70122 Mdot
.5897 .37058 Mdot
.532 .60977 Mdot
.32279 .1861 Mdot
.34189 .56642 Mdot
.30169 .51032 Mdot
.57296 .67165 Mdot
.54893 .68505 Mdot
.43097 .49347 Mdot
.54703 .23229 Mdot
.33323 .35322 Mdot
.5523 .65987 Mdot
.39391 .61809 Mdot
.48873 .33509 Mdot
.5446 .58009 Mdot
.53945 .62957 Mdot
.65797 .60677 Mdot
.48942 .32206 Mdot
.36548 .40072 Mdot
.38034 .38395 Mdot
.41632 .39113 Mdot
.33468 .5932 Mdot
.66619 .37831 Mdot
.37318 .68228 Mdot
.79349 .4118 Mdot
.28986 .56052 Mdot
.55825 .67597 Mdot
.33527 .4897 Mdot
.51211 .60388 Mdot
.31949 .55344 Mdot
.48773 .32351 Mdot
.62709 .44865 Mdot
.69619 .33299 Mdot
.38842 .39007 Mdot
.5291 .68932 Mdot
.3 .58014 Mdot
.64484 .43338 Mdot
.38895 .72398 Mdot
.66269 .48108 Mdot
.53061 .35226 Mdot
.67242 .37771 Mdot
.31823 .55102 Mdot
.67839 .46851 Mdot
.55091 .39348 Mdot
.17378 .52228 Mdot
.47642 .60899 Mdot
.68253 .36096 Mdot
.66456 .48428 Mdot
.63507 .40654 Mdot
.68182 .47682 Mdot
.57693 .63643 Mdot
.51224 .40981 Mdot
.49039 .64638 Mdot
.49086 .32809 Mdot
.35744 .40787 Mdot
.81771 .5758 Mdot
.46383 .29507 Mdot
.5656 .43883 Mdot
.56579 .55874 Mdot
.56302 .63674 Mdot
.5372 .62455 Mdot
.59149 .67272 Mdot
.48504 .23513 Mdot
.57535 .63058 Mdot
.52513 .32652 Mdot
.39348 .41248 Mdot
.4941 .60766 Mdot
.42421 .43395 Mdot
.20447 .53884 Mdot
.32953 .54113 Mdot
.57566 .35229 Mdot
.73486 .73613 Mdot
.64239 .43468 Mdot
.41518 .42255 Mdot
.39754 .4088 Mdot
.30368 .55716 Mdot
.54679 .35469 Mdot
.66661 .48018 Mdot
.449 .6578 Mdot
.30947 .58703 Mdot
.5444 .64509 Mdot
.53128 .40498 Mdot
.83692 .52452 Mdot
.50094 .59467 Mdot
.55529 .59764 Mdot
.32746 .4051 Mdot
.31084 .50833 Mdot
.83356 .37142 Mdot
.39304 .69359 Mdot
.32724 .55351 Mdot
.34863 .54948 Mdot
.65361 .42165 Mdot
.54203 .69159 Mdot
.49291 .35012 Mdot
.73177 .41337 Mdot
.60522 .37849 Mdot
.70549 .30421 Mdot
.50172 .18455 Mdot
.53422 .5832 Mdot
.31968 .27621 Mdot
.56645 .62961 Mdot
.68237 .47979 Mdot
.66071 .44017 Mdot
.64589 .44872 Mdot
.54223 .34651 Mdot
.71977 .6365 Mdot
.53596 .33238 Mdot
.81596 .6475 Mdot
.64077 .48154 Mdot
.40759 .55499 Mdot
.36554 .43516 Mdot
.47128 .63679 Mdot
.32387 .54225 Mdot
.68609 .37101 Mdot
.58669 .548 Mdot
.66038 .53544 Mdot
.33765 .40654 Mdot
.63258 .43575 Mdot
.33477 .28278 Mdot
.57516 .80444 Mdot
.70451 .40308 Mdot
.61574 .62146 Mdot
.41488 .7207 Mdot
.32041 .56031 Mdot
.52297 .1832 Mdot
.33671 .54934 Mdot
.52734 .36209 Mdot
.51183 .61773 Mdot
.51546 .62786 Mdot
.52681 .58119 Mdot
.546 .67077 Mdot
.48379 .30787 Mdot
.58289 .58899 Mdot
.76088 .3695 Mdot
.38394 .38775 Mdot
.37132 .60712 Mdot
.33913 .5539 Mdot
.49756 .31145 Mdot
.3937 .41078 Mdot
.35099 .30572 Mdot
.40569 .65771 Mdot
.53816 .61863 Mdot
.54607 .58823 Mdot
.75268 .68809 Mdot
.51941 .58884 Mdot
.49062 .69259 Mdot
.38435 .39157 Mdot
.62805 .64786 Mdot
.32953 .54161 Mdot
.34177 .54376 Mdot
.50716 .34009 Mdot
.66253 .43855 Mdot
.33727 .57306 Mdot
.3608 .43177 Mdot
.56331 .55689 Mdot
.58817 .60883 Mdot
.66033 .48508 Mdot
.76117 .68398 Mdot
.35825 .57253 Mdot
.26205 .35975 Mdot
.63702 .43035 Mdot
.62327 .48618 Mdot
.57563 .60071 Mdot
.55404 .19324 Mdot
.60864 .45059 Mdot
.30184 .59152 Mdot
.49808 .30966 Mdot
.42528 .71629 Mdot
.54097 .31603 Mdot
.66412 .46173 Mdot
.51112 .6543 Mdot
.65459 .4321 Mdot
.538 .61557 Mdot
.60984 .81421 Mdot
.51989 .63182 Mdot
.78857 .3984 Mdot
.31009 .65139 Mdot
.39174 .43546 Mdot
.3362 .30627 Mdot
.3799 .44159 Mdot
.62285 .44617 Mdot
.57248 .6758 Mdot
.29986 .55517 Mdot
.20688 .46852 Mdot
.72751 .46606 Mdot
.34398 .41256 Mdot
.34564 .451 Mdot
.53191 .30915 Mdot
.50554 .59499 Mdot
.57858 .61194 Mdot
.38655 .42402 Mdot
.60032 .44675 Mdot
.6756 .45784 Mdot
.5204 .61169 Mdot
.56495 .63768 Mdot
.388 .43811 Mdot
.17075 .50857 Mdot
.46362 .58409 Mdot
.51728 .61906 Mdot
.36969 .34532 Mdot
.50092 .3175 Mdot
.47205 .63645 Mdot
.59272 .65262 Mdot
.31471 .56878 Mdot
.7381 .51731 Mdot
.58458 .7831 Mdot
.48636 .32425 Mdot
.39532 .40079 Mdot
.52872 .60915 Mdot
.40258 .41737 Mdot
.58527 .59405 Mdot
.55801 .23875 Mdot
.41375 .42012 Mdot
.49446 .63624 Mdot
.48803 .60232 Mdot
.63465 .48406 Mdot
.53999 .585 Mdot
.64593 .71699 Mdot
.35473 .39425 Mdot
.5231 .67418 Mdot
.78562 .59101 Mdot
.55086 .34137 Mdot
.48292 .65119 Mdot
.31435 .58759 Mdot
.47755 .71176 Mdot
.63909 .32174 Mdot
.33746 .74125 Mdot
.33442 .53928 Mdot
.57851 .6284 Mdot
.33825 .44179 Mdot
.53055 .37588 Mdot
.78002 .36206 Mdot
.55451 .58095 Mdot
.53673 .36431 Mdot
.50639 .32734 Mdot
.32245 .54836 Mdot
.28254 .24228 Mdot
.57259 .66967 Mdot
.53746 .66288 Mdot
.68686 .64656 Mdot
.65659 .40945 Mdot
.52436 .64255 Mdot
.5265 .66692 Mdot
.51972 .3239 Mdot
.51744 .70138 Mdot
.69148 .71168 Mdot
.79373 .52491 Mdot
.55338 .37132 Mdot
.72436 .35044 Mdot
.41245 .41182 Mdot
.34802 .56585 Mdot
.63836 .46769 Mdot
.2977 .57259 Mdot
.35731 .43546 Mdot
.52238 .66002 Mdot
.5457 .36674 Mdot
.6454 .7049 Mdot
.49392 .34785 Mdot
.27974 .67442 Mdot
.69057 .42026 Mdot
.51858 .29374 Mdot
.30239 .20603 Mdot
.37657 .32963 Mdot
.51732 .26679 Mdot
.31885 .56463 Mdot
.34068 .46878 Mdot
.56545 .63595 Mdot
.50793 .17782 Mdot
.5545 .67653 Mdot
.78365 .57023 Mdot
.37627 .38541 Mdot
.33397 .39335 Mdot
.51468 .61718 Mdot
.63631 .75971 Mdot
.53745 .37758 Mdot
.52161 .31582 Mdot
.49993 .64784 Mdot
.53474 .35477 Mdot
.53537 .65226 Mdot
.38906 .40007 Mdot
.55205 .17108 Mdot
.55084 .63849 Mdot
.60161 .62566 Mdot
.57518 .2574 Mdot
.18741 .55079 Mdot
.36765 .58962 Mdot
.17124 .41621 Mdot
.61659 .80166 Mdot
.53525 .35346 Mdot
.4982 .65587 Mdot
.72102 .34163 Mdot
.32899 .42228 Mdot
.57951 .39085 Mdot
.52252 .65368 Mdot
.53875 .67481 Mdot
.56215 .57274 Mdot
.56759 .60321 Mdot
.39145 .19509 Mdot
.73533 .44381 Mdot
.72258 .56592 Mdot
.53416 .58559 Mdot
.41557 .651 Mdot
.51108 .35108 Mdot
.66787 .50572 Mdot
.29056 .5761 Mdot
.53616 .5835 Mdot
.67736 .3929 Mdot
.55727 .36174 Mdot
.83488 .62226 Mdot
.54034 .36582 Mdot
.37304 .40192 Mdot
.51353 .3651 Mdot
.56205 .62048 Mdot
.6477 .46738 Mdot
.44473 .45333 Mdot
.42108 .30645 Mdot
.36471 .3843 Mdot
.55345 .624 Mdot
.39509 .56157 Mdot
.34311 .39529 Mdot
.20693 .58322 Mdot
.63939 .46217 Mdot
.38716 .61587 Mdot
.65795 .43412 Mdot
.50553 .65244 Mdot
.50544 .6512 Mdot
.55737 .32805 Mdot
.5057 .35771 Mdot
.65921 .43514 Mdot
.21548 .29644 Mdot
.35078 .58124 Mdot
.6488 .45058 Mdot
.56411 .69612 Mdot
.48558 .41741 Mdot
.64583 .46258 Mdot
.27478 .57186 Mdot
.51113 .32467 Mdot
.64242 .4174 Mdot
.54401 .56606 Mdot
.45806 .72667 Mdot
.35322 .56856 Mdot
.37224 .379 Mdot
.36473 .70887 Mdot
.34592 .40417 Mdot
.50455 .30612 Mdot
.38405 .44117 Mdot
.50032 .32179 Mdot
.62699 .33615 Mdot
.61435 .39945 Mdot
.38057 .49215 Mdot
.50417 .30255 Mdot
.377 .44028 Mdot
.51048 .61482 Mdot
.37324 .54406 Mdot
.55572 .69079 Mdot
.58329 .62667 Mdot
.51868 .31874 Mdot
.63282 .47869 Mdot
.61711 .4274 Mdot
.44336 .66949 Mdot
.66653 .43983 Mdot
.36088 .39516 Mdot
.70691 .51034 Mdot
.47212 .2549 Mdot
.54217 .31952 Mdot
.51501 .36164 Mdot
.5148 .59828 Mdot
.37816 .42946 Mdot
.35272 .3848 Mdot
.54087 .31491 Mdot
.59246 .22455 Mdot
.59351 .66043 Mdot
.62648 .40861 Mdot
.65631 .41114 Mdot
.65588 .46232 Mdot
.69091 .46425 Mdot
.50405 .72564 Mdot
.49915 .33688 Mdot
.62722 .4715 Mdot
.51472 .59721 Mdot
.52886 .66627 Mdot
.73035 .39471 Mdot
.3465 .57632 Mdot
.48955 .62133 Mdot
.48392 .59438 Mdot
.56118 .58662 Mdot
.36536 .44377 Mdot
.47261 .67515 Mdot
.39444 .44593 Mdot
.33271 .4275 Mdot
.33105 .42446 Mdot
.49702 .24143 Mdot
.7137 .72637 Mdot
.5169 .79353 Mdot
.5266 .67434 Mdot
.28868 .30613 Mdot
.36785 .42275 Mdot
.74506 .45381 Mdot
.61477 .36476 Mdot
.56347 .57872 Mdot
.23595 .43767 Mdot
.38675 .42825 Mdot
.64388 .42557 Mdot
.52033 .64369 Mdot
.41966 .41374 Mdot
.3242 .58993 Mdot
.53143 .68325 Mdot
.41356 .40001 Mdot
.67888 .47005 Mdot
.32282 .598 Mdot
.63374 .41889 Mdot
.33096 .42578 Mdot
.54119 .70134 Mdot
.66704 .20414 Mdot
.42386 .41362 Mdot
.21719 .39435 Mdot
.59092 .52851 Mdot
.51622 .61145 Mdot
.40481 .44221 Mdot
.62184 .4884 Mdot
.50543 .3066 Mdot
.54005 .48347 Mdot
.66709 .42159 Mdot
.3338 .39351 Mdot
.34114 .43157 Mdot
.36504 .38425 Mdot
.67721 .42913 Mdot
.49389 .66829 Mdot
.67447 .43967 Mdot
.51596 .36743 Mdot
.54371 .60056 Mdot
.47613 .78567 Mdot
.35391 .26612 Mdot
.64277 .42832 Mdot
.35475 .40476 Mdot
.29823 .54248 Mdot
.56142 .63272 Mdot
.3283 .27836 Mdot
.51068 .6123 Mdot
.50429 .31841 Mdot
.69052 .55007 Mdot
.63173 .64838 Mdot
.49405 .64684 Mdot
.52032 .59604 Mdot
.52472 .31675 Mdot
.55274 .62817 Mdot
.50702 .59449 Mdot
.47846 .23762 Mdot
.67867 .44363 Mdot
.55042 .64693 Mdot
.35554 .41438 Mdot
.44758 .27133 Mdot
.59835 .6465 Mdot
.37484 .48176 Mdot
.39489 .60881 Mdot
.67032 .56389 Mdot
.55197 .67726 Mdot
.55359 .40706 Mdot
.57314 .60343 Mdot
.56257 .66144 Mdot
.52072 .59895 Mdot
.32962 .23789 Mdot
.41412 .40337 Mdot
.39927 .41797 Mdot
.35191 .5549 Mdot
.39318 .60957 Mdot
.31642 .57762 Mdot
.50424 .32569 Mdot
.2729 .47544 Mdot
.39759 .44471 Mdot
.67006 .46599 Mdot
.56922 .64741 Mdot
.42329 .41817 Mdot
.56309 .58465 Mdot
.56049 .61961 Mdot
.33865 .43617 Mdot
.41209 .40407 Mdot
.25948 .63349 Mdot
.34257 .58211 Mdot
.64232 .44438 Mdot
.49471 .61361 Mdot
.30399 .58392 Mdot
.55902 .67686 Mdot
.36423 .66366 Mdot
.64347 .4489 Mdot
.6773 .44389 Mdot
.6136 .43164 Mdot
.51913 .65313 Mdot
.56207 .62586 Mdot
.53566 .33135 Mdot
.62436 .43856 Mdot
.55219 .34593 Mdot
.50324 .48899 Mdot
.22898 .55375 Mdot
.5227 .65436 Mdot
.70186 .37945 Mdot
.32029 .58432 Mdot
.34374 .41563 Mdot
.83653 .53954 Mdot
.35213 .55529 Mdot
.53434 .61441 Mdot
.33442 .41794 Mdot
.31067 .55863 Mdot
.43468 .57592 Mdot
.79412 .66362 Mdot
.30161 .54142 Mdot
.51547 .59671 Mdot
.52435 .70331 Mdot
.17787 .39928 Mdot
.32458 .53655 Mdot
.50321 .34973 Mdot
.51807 .65049 Mdot
.64794 .40263 Mdot
.29911 .57937 Mdot
.28989 .37017 Mdot
.39236 .42138 Mdot
.46541 .72631 Mdot
.59592 .57337 Mdot
.63803 .52087 Mdot
.34997 .55511 Mdot
.65559 .47882 Mdot
.50832 .70983 Mdot
.57446 .59976 Mdot
.32688 .53618 Mdot
.47367 .32732 Mdot
.38753 .40819 Mdot
.42629 .28609 Mdot
.67574 .42622 Mdot
.46703 .33838 Mdot
.34728 .41488 Mdot
.25672 .36632 Mdot
.7889 .47455 Mdot
.47639 .64851 Mdot
.23604 .33745 Mdot
.57834 .29587 Mdot
.53137 .57453 Mdot
.28452 .57608 Mdot
.48505 .34354 Mdot
.55973 .3513 Mdot
.52636 .35165 Mdot
.6161 .33769 Mdot
.71155 .42665 Mdot
.41296 .39535 Mdot
.51025 .39228 Mdot
.34712 .56875 Mdot
.42733 .70855 Mdot
.58502 .62205 Mdot
.55996 .63932 Mdot
.49963 .60782 Mdot
.53673 .58206 Mdot
.57464 .6247 Mdot
.54322 .35911 Mdot
.61541 .32054 Mdot
.7152 .41911 Mdot
.64462 .4564 Mdot
.31761 .49599 Mdot
.36034 .42773 Mdot
.3416 .38052 Mdot
.30515 .57121 Mdot
.34061 .34018 Mdot
.42508 .43194 Mdot
.36964 .40921 Mdot
.49399 .5995 Mdot
.67393 .45132 Mdot
.47192 .65165 Mdot
.5181 .59621 Mdot
.36903 .39384 Mdot
.45058 .49127 Mdot
.65488 .73018 Mdot
.26281 .61228 Mdot
.34756 .59236 Mdot
.52952 .40043 Mdot
.34575 .54334 Mdot
.58968 .64203 Mdot
.72125 .2901 Mdot
.35879 .43693 Mdot
.37894 .415 Mdot
.34032 .58095 Mdot
.55495 .19109 Mdot
.63416 .46664 Mdot
.46315 .32443 Mdot
.49208 .33612 Mdot
.50796 .65098 Mdot
.81351 .4834 Mdot
.59026 .52129 Mdot
.25913 .46125 Mdot
.521 .35231 Mdot
.40236 .42964 Mdot
.59333 .62566 Mdot
.52748 .59201 Mdot
.31325 .5809 Mdot
.31403 .73752 Mdot
.48121 .59245 Mdot
.27391 .75357 Mdot
.81823 .6034 Mdot
.5662 .77703 Mdot
.5774 .60546 Mdot
.67804 .43921 Mdot
.38806 .38643 Mdot
.34493 .56038 Mdot
.52322 .68532 Mdot
.62758 .78299 Mdot
.65496 .48471 Mdot
.51284 .34113 Mdot
.47614 .46275 Mdot
.41433 .70926 Mdot
.57488 .64701 Mdot
.53253 .67141 Mdot
.56617 .66048 Mdot
.88676 .4719 Mdot
.384 .44722 Mdot
.64681 .42681 Mdot
.31955 .54887 Mdot
.66662 .44859 Mdot
.39718 .43166 Mdot
.38978 .50348 Mdot
.50543 .62488 Mdot
.67302 .48109 Mdot
.65234 .47805 Mdot
.55769 .35166 Mdot
.48579 .32034 Mdot
.48967 .47341 Mdot
.52138 .63255 Mdot
.37602 .45775 Mdot
.63047 .47777 Mdot
.54873 .40294 Mdot
.32149 .57157 Mdot
.51192 .32373 Mdot
.53856 .58572 Mdot
.3964 .44387 Mdot
.50486 .57397 Mdot
.63168 .44613 Mdot
.36977 .41021 Mdot
.24344 .62411 Mdot
.33164 .54087 Mdot
.53091 .66519 Mdot
.30455 .6182 Mdot
.39288 .39813 Mdot
.56861 .63136 Mdot
.22807 .40315 Mdot
.27791 .56394 Mdot
.42769 .32659 Mdot
.33452 .40569 Mdot
.5276 .25618 Mdot
.65613 .42106 Mdot
.53464 .23929 Mdot
.378 .40799 Mdot
.26954 .3469 Mdot
.25426 .64918 Mdot
.57103 .56327 Mdot
.65828 .45356 Mdot
.54268 .2542 Mdot
.53785 .83883 Mdot
.19606 .41909 Mdot
.54115 .62672 Mdot
.37636 .4546 Mdot
.30823 .568 Mdot
.54073 .32007 Mdot
.44747 .32954 Mdot
.34829 .5219 Mdot
.38014 .46461 Mdot
.52121 .59923 Mdot
.66744 .47723 Mdot
.52904 .33287 Mdot
.64001 .32726 Mdot
.35657 .42509 Mdot
.35481 .40835 Mdot
.5648 .68211 Mdot
.32748 .58281 Mdot
.40463 .2249 Mdot
.3859 .39473 Mdot
.7757 .65409 Mdot
.3335 .38233 Mdot
.31675 .59091 Mdot
.56498 .59703 Mdot
.4641 .70427 Mdot
.52631 .68311 Mdot
.20063 .45699 Mdot
.36492 .43268 Mdot
.63724 .44534 Mdot
.58259 .60859 Mdot
.79478 .59285 Mdot
.35962 .39634 Mdot
.51061 .4045 Mdot
.30305 .38194 Mdot
.49687 .33322 Mdot
.83578 .53636 Mdot
.52835 .65121 Mdot
.52965 .37555 Mdot
.31152 .57796 Mdot
.51984 .6239 Mdot
.56417 .62281 Mdot
.65931 .49259 Mdot
.55678 .34402 Mdot
.258 .6297 Mdot
.52354 .36657 Mdot
.51321 .35559 Mdot
.68176 .40113 Mdot
.54551 .6564 Mdot
.37083 .40083 Mdot
.38542 .42787 Mdot
.54027 .56685 Mdot
.49985 .14544 Mdot
.63843 .47314 Mdot
.3633 .37942 Mdot
.88351 .44628 Mdot
.52652 .57242 Mdot
.82641 .53471 Mdot
.29697 .72185 Mdot
.48801 .34089 Mdot
.51457 .59672 Mdot
.67539 .47162 Mdot
.32697 .35763 Mdot
.35685 .40574 Mdot
.55083 .56423 Mdot
.52961 .33472 Mdot
.34363 .58299 Mdot
.3539 .39054 Mdot
.26486 .46141 Mdot
.55233 .67168 Mdot
.22486 .46628 Mdot
.35486 .44715 Mdot
.47029 .82606 Mdot
.36354 .29269 Mdot
.65624 .45102 Mdot
.56043 .61632 Mdot
.63001 .43122 Mdot
.31253 .55143 Mdot
.47834 .46397 Mdot
.51774 .32732 Mdot
.5531 .74027 Mdot
.74177 .31137 Mdot
.36544 .38421 Mdot
.63938 .42744 Mdot
.5011 .65404 Mdot
.55319 .23084 Mdot
.5324 .65462 Mdot
.59401 .6922 Mdot
.26218 .62626 Mdot
.53444 .32263 Mdot
.48947 .33781 Mdot
.57059 .61278 Mdot
.30071 .56114 Mdot
.3597 .42939 Mdot
.38147 .40072 Mdot
.41949 .83499 Mdot
.46391 .32067 Mdot
.74032 .68081 Mdot
.53951 .67472 Mdot
.36756 .46336 Mdot
.47948 .2783 Mdot
.54713 .36316 Mdot
.49059 .6682 Mdot
.33656 .42288 Mdot
.37617 .60252 Mdot
.42658 .60018 Mdot
.57464 .60306 Mdot
.5519 .69493 Mdot
.49531 .34508 Mdot
.69759 .40416 Mdot
.40525 .41517 Mdot
.50293 .57023 Mdot
.39748 .49169 Mdot
.43243 .57553 Mdot
.81979 .61465 Mdot
.64257 .44429 Mdot
.27087 .43518 Mdot
.54452 .35861 Mdot
.60183 .61736 Mdot
.32385 .54426 Mdot
.34777 .45961 Mdot
.40863 .43129 Mdot
.53001 .60568 Mdot
.59094 .61597 Mdot
.80468 .61021 Mdot
.67101 .45901 Mdot
.50738 .3454 Mdot
.51198 .63188 Mdot
.70022 .35197 Mdot
.52433 .58213 Mdot
.54132 .33409 Mdot
.64919 .19377 Mdot
.54136 .69015 Mdot
.53556 .65958 Mdot
.40075 .22798 Mdot
.6655 .41786 Mdot
.62216 .46837 Mdot
.82691 .47897 Mdot
.53872 .67424 Mdot
.82406 .58557 Mdot
.63938 .43972 Mdot
.62997 .46126 Mdot
.43272 .25506 Mdot
.55922 .63641 Mdot
.48655 .54899 Mdot
.49434 .32486 Mdot
.51226 .35585 Mdot
.67545 .43308 Mdot
.473 .62023 Mdot
.49408 .31629 Mdot
.37533 .21635 Mdot
.37678 .43044 Mdot
.65894 .2337 Mdot
.64042 .47669 Mdot
.5646 .30034 Mdot
.53036 .36151 Mdot
.78242 .68514 Mdot
.42493 .35544 Mdot
.50834 .61914 Mdot
.54185 .67415 Mdot
.34213 .57822 Mdot
.4928 .62381 Mdot
.33462 .39267 Mdot
.53442 .35524 Mdot
.62798 .75274 Mdot
.64629 .44846 Mdot
.52813 .63897 Mdot
.23017 .42741 Mdot
.22011 .62817 Mdot
.28553 .41997 Mdot
.65696 .48192 Mdot
.65606 .43973 Mdot
.39333 .44203 Mdot
.37015 .45374 Mdot
.5593 .65147 Mdot
.52322 .31363 Mdot
.62677 .43566 Mdot
.53644 .32763 Mdot
.35594 .43489 Mdot
.37102 .40348 Mdot
.40753 .3966 Mdot
.58633 .61746 Mdot
.36339 .40829 Mdot
.23116 .5822 Mdot
.46902 .37723 Mdot
.67199 .40118 Mdot
.85528 .49675 Mdot
.64395 .33201 Mdot
.65352 .51551 Mdot
.30735 .58938 Mdot
.37983 .38832 Mdot
.52524 .37235 Mdot
.55296 .60174 Mdot
.54938 .58591 Mdot
.49004 .24919 Mdot
.5355 .37423 Mdot
.31795 .55004 Mdot
.50539 .36259 Mdot
.32126 .54817 Mdot
.2347 .46043 Mdot
.50561 .59266 Mdot
.58148 .58432 Mdot
.5358 .35972 Mdot
.36637 .40903 Mdot
.39625 .4195 Mdot
.30847 .53996 Mdot
.44168 .50536 Mdot
.34152 .39762 Mdot
.62975 .46527 Mdot
.59368 .74925 Mdot
.35077 .44265 Mdot
.52143 .64292 Mdot
.36656 .68146 Mdot
.49182 .17101 Mdot
.59081 .67357 Mdot
.44206 .24554 Mdot
.65923 .67762 Mdot
.57813 .59746 Mdot
.49849 .17095 Mdot
.52729 .38133 Mdot
.66489 .42491 Mdot
.38852 .39139 Mdot
.36587 .3687 Mdot
.49183 .5574 Mdot
.32207 .59892 Mdot
.52423 .69285 Mdot
.67409 .47991 Mdot
.65811 .49769 Mdot
.45478 .70022 Mdot
.19889 .4317 Mdot
.31091 .56056 Mdot
.30649 .57382 Mdot
.37832 .40529 Mdot
.21567 .68582 Mdot
.60873 .66401 Mdot
.3222 .5507 Mdot
.60329 .46539 Mdot
.52474 .60047 Mdot
.38054 .60678 Mdot
.5891 .50123 Mdot
.67621 .43133 Mdot
.42093 .6517 Mdot
.36324 .39741 Mdot
.6669 .43756 Mdot
.69039 .32242 Mdot
.48939 .65616 Mdot
.6446 .44999 Mdot
.53509 .32847 Mdot
.35548 .3122 Mdot
.63134 .47217 Mdot
.3694 .67454 Mdot
.5281 .3107 Mdot
.55066 .40221 Mdot
.43395 .64013 Mdot
.10707 .53663 Mdot
.53957 .35763 Mdot
.34125 .43038 Mdot
.386 .42658 Mdot
.38078 .40069 Mdot
.66781 .45038 Mdot
.36618 .38391 Mdot
.66949 .45989 Mdot
.21168 .36241 Mdot
.51115 .18694 Mdot
.32546 .5527 Mdot
.42354 .28777 Mdot
.66478 .47205 Mdot
.75828 .40321 Mdot
.41125 .13627 Mdot
.51064 .59935 Mdot
.5611 .3476 Mdot
.32416 .5541 Mdot
.25296 .71924 Mdot
.31507 .5645 Mdot
.65375 .76875 Mdot
.65316 .54585 Mdot
.53391 .64409 Mdot
.74136 .63502 Mdot
.29939 .54799 Mdot
.69154 .4448 Mdot
.568 .63118 Mdot
.46594 .51364 Mdot
.31162 .57079 Mdot
.32687 .59133 Mdot
.55479 .65089 Mdot
.63237 .4358 Mdot
.35295 .4042 Mdot
.51979 .36262 Mdot
.29521 .57012 Mdot
.53775 .71127 Mdot
.50901 .66849 Mdot
.50586 .61739 Mdot
.71956 .38584 Mdot
.2795 .57699 Mdot
.53584 .35291 Mdot
.29306 .24495 Mdot
.34063 .44364 Mdot
.425 .54401 Mdot
.79786 .63464 Mdot
.59404 .3526 Mdot
.36601 .43256 Mdot
.40223 .42017 Mdot
.57462 .62621 Mdot
.62208 .65452 Mdot
.63858 .53651 Mdot
.4047 .52124 Mdot
.3824 .38122 Mdot
.38481 .40384 Mdot
.61837 .45225 Mdot
.53819 .76885 Mdot
.59009 .68039 Mdot
.48526 .32641 Mdot
.41367 .41623 Mdot
.49709 .1996 Mdot
.33853 .57892 Mdot
.6772 .53857 Mdot
.50275 .59487 Mdot
.50848 .6228 Mdot
.52462 .33584 Mdot
.53497 .33236 Mdot
.31093 .36844 Mdot
.58436 .77615 Mdot
.65234 .68559 Mdot
.61398 .30618 Mdot
.66404 .57485 Mdot
.62772 .48162 Mdot
.64229 .42841 Mdot
.41616 .31773 Mdot
.53512 .36882 Mdot
.57967 .59934 Mdot
.66148 .4366 Mdot
.38325 .58992 Mdot
.5432 .73988 Mdot
.51016 .74351 Mdot
.82323 .55867 Mdot
.54218 .61783 Mdot
.68049 .4533 Mdot
.66436 .41614 Mdot
.6677 .41244 Mdot
.54581 .26963 Mdot
.55181 .66037 Mdot
.54268 .622 Mdot
.58025 .61332 Mdot
.55324 .21152 Mdot
.55807 .66147 Mdot
.56157 .2637 Mdot
.49406 .45818 Mdot
.75643 .50363 Mdot
.49918 .57381 Mdot
.51477 .37051 Mdot
.57197 .66083 Mdot
.30154 .55919 Mdot
.50141 .61439 Mdot
.51464 .74606 Mdot
.51566 .35196 Mdot
.45681 .64424 Mdot
.63269 .33905 Mdot
.55225 .57027 Mdot
.30144 .59019 Mdot
.60333 .36954 Mdot
.52579 .82269 Mdot
.35754 .59566 Mdot
.63127 .46722 Mdot
.37144 .43112 Mdot
.52955 .37385 Mdot
.3747 .40964 Mdot
.56605 .56593 Mdot
.40231 .31911 Mdot
.26306 .72084 Mdot
.46267 .50665 Mdot
.5399 .58335 Mdot
.60893 .64997 Mdot
.62753 .4558 Mdot
.3365 .43399 Mdot
.62275 .4997 Mdot
.57689 .63754 Mdot
.33416 .55963 Mdot
.31355 .57934 Mdot
.52776 .4854 Mdot
.40445 .80058 Mdot
.43756 .20244 Mdot
.52909 .33992 Mdot
.3823 .3929 Mdot
.32427 .54189 Mdot
.28284 .33161 Mdot
.48479 .35211 Mdot
.51446 .31668 Mdot
.5114 .3477 Mdot
.51846 .65906 Mdot
.41476 .40657 Mdot
.75876 .50395 Mdot
.33429 .44039 Mdot
.5548 .62688 Mdot
.3667 .44506 Mdot
.33774 .41152 Mdot
.34167 .56018 Mdot
.51041 .34886 Mdot
.35958 .43592 Mdot
.51019 .65805 Mdot
.64104 .43625 Mdot
.51676 .27548 Mdot
.29331 .6432 Mdot
.20075 .43591 Mdot
.53159 .51457 Mdot
.67301 .41955 Mdot
.50997 .82041 Mdot
.4956 .32066 Mdot
.58161 .22053 Mdot
.26027 .63619 Mdot
.56561 .67928 Mdot
.51828 .14765 Mdot
.3157 .40146 Mdot
.33964 .41059 Mdot
.56679 .59794 Mdot
.31087 .40311 Mdot
.53019 .6441 Mdot
.34712 .42677 Mdot
.44845 .35928 Mdot
.69479 .41397 Mdot
.36382 .4133 Mdot
.51572 .56227 Mdot
.56751 .62071 Mdot
.67689 .43888 Mdot
.38959 .45173 Mdot
.53635 .6929 Mdot
.45702 .85721 Mdot
.54111 .33793 Mdot
.59549 .338 Mdot
.35212 .68343 Mdot
.54701 .35753 Mdot
.65048 .45311 Mdot
.58289 .62995 Mdot
.31042 .57683 Mdot
.66715 .47227 Mdot
.52815 .75046 Mdot
.33973 .54625 Mdot
.63592 .20833 Mdot
.66621 .41617 Mdot
.34416 .40985 Mdot
.30999 .54887 Mdot
.49238 .64979 Mdot
.32949 .43009 Mdot
.3331 .31172 Mdot
.36395 .42952 Mdot
.57759 .6223 Mdot
.4493 .29966 Mdot
.50652 .3457 Mdot
.53736 .62596 Mdot
.34328 .4033 Mdot
.44294 .24703 Mdot
.52485 .6702 Mdot
.57329 .61093 Mdot
.7858 .65163 Mdot
.76037 .4466 Mdot
.31858 .56779 Mdot
.6303 .42009 Mdot
.51344 .59792 Mdot
.31365 .5881 Mdot
.25447 .53498 Mdot
.51192 .64364 Mdot
.65539 .48511 Mdot
.4909 .66968 Mdot
.38066 .45333 Mdot
.5502 .34657 Mdot
.40712 .53248 Mdot
.32296 .58985 Mdot
.13854 .5097 Mdot
.41097 .42062 Mdot
.58641 .63105 Mdot
.52415 .58362 Mdot
.36324 .72755 Mdot
.66695 .42819 Mdot
.5967 .48292 Mdot
.53154 .66604 Mdot
.56104 .20904 Mdot
.52386 .62572 Mdot
.3133 .41268 Mdot
.63333 .46607 Mdot
.54136 .66494 Mdot
.50695 .2898 Mdot
.60103 .62599 Mdot
.35166 .56838 Mdot
.3677 .25366 Mdot
.49925 .67334 Mdot
.63949 .1987 Mdot
.50629 .50474 Mdot
.36195 .4129 Mdot
.21064 .54305 Mdot
.44661 .86006 Mdot
.62031 .34393 Mdot
.66556 .45094 Mdot
.28706 .72215 Mdot
.37032 .4009 Mdot
.21377 .47544 Mdot
.52992 .83352 Mdot
.5652 .61238 Mdot
.57602 .64371 Mdot
.40801 .72172 Mdot
.33262 .4325 Mdot
.36062 .45656 Mdot
.56548 .5601 Mdot
.6018 .64031 Mdot
.36533 .40411 Mdot
.53899 .68383 Mdot
.50257 .56508 Mdot
.56091 .3484 Mdot
.64962 .48317 Mdot
.53364 .32096 Mdot
.50462 .31328 Mdot
.33826 .25374 Mdot
.48047 .51449 Mdot
.54382 .33752 Mdot
.48506 .33892 Mdot
.39498 .59909 Mdot
.61908 .76388 Mdot
.29742 .57184 Mdot
.43727 .824 Mdot
.38594 .40835 Mdot
.54559 .66067 Mdot
.65937 .41202 Mdot
.64278 .69093 Mdot
.2581 .55245 Mdot
.74586 .33848 Mdot
.58229 .61456 Mdot
.35726 .39808 Mdot
.58661 .32957 Mdot
.47788 .67109 Mdot
.42166 .40281 Mdot
.51446 .63744 Mdot
.33224 .3953 Mdot
.66023 .73849 Mdot
.27169 .3459 Mdot
.36659 .37067 Mdot
.64274 .40415 Mdot
.51158 .62487 Mdot
.68169 .47416 Mdot
.54683 .36232 Mdot
.29806 .56411 Mdot
.31822 .57241 Mdot
.5637 .64007 Mdot
.61463 .62641 Mdot
.22733 .48726 Mdot
.56288 .63085 Mdot
.52788 .59917 Mdot
.55406 .38449 Mdot
.52233 .59756 Mdot
.53226 .57855 Mdot
.56539 .58364 Mdot
.56836 .57665 Mdot
.51186 .3549 Mdot
.33516 .34248 Mdot
.5069 .54783 Mdot
.56333 .5491 Mdot
.51069 .30609 Mdot
.28968 .7069 Mdot
.49547 .31717 Mdot
.54257 .83099 Mdot
.48948 .34121 Mdot
.32613 .56909 Mdot
.31136 .71723 Mdot
.58719 .55523 Mdot
.64929 .48988 Mdot
.57905 .37226 Mdot
.30798 .55371 Mdot
.5298 .35367 Mdot
.34493 .42791 Mdot
.79568 .64535 Mdot
.68168 .48972 Mdot
.73677 .42388 Mdot
.59627 .38407 Mdot
.34435 .3315 Mdot
.39486 .44235 Mdot
.69177 .43094 Mdot
.69 .7067 Mdot
.53358 .58074 Mdot
.31211 .58761 Mdot
.56044 .64883 Mdot
.54733 .36528 Mdot
.36921 .39642 Mdot
.20364 .3923 Mdot
.31394 .58137 Mdot
.85753 .5218 Mdot
.39376 .42447 Mdot
.54365 .57919 Mdot
.49394 .31656 Mdot
.84111 .43375 Mdot
.53128 .32145 Mdot
.6264 .56628 Mdot
.65214 .42362 Mdot
.17068 .43254 Mdot
.66282 .46513 Mdot
.31004 .32739 Mdot
.81101 .32469 Mdot
.26532 .38545 Mdot
.63791 .43422 Mdot
.38245 .50488 Mdot
.5324 .61156 Mdot
.5054 .61879 Mdot
.24262 .35763 Mdot
.64 .41317 Mdot
.52786 .58737 Mdot
.48338 .26439 Mdot
.46879 .33933 Mdot
.81467 .5217 Mdot
.39356 .43983 Mdot
.52749 .64585 Mdot
.56242 .36483 Mdot
.54454 .37656 Mdot
.40393 .40628 Mdot
.50807 .3165 Mdot
.54491 .62387 Mdot
.66455 .47115 Mdot
.40766 .46592 Mdot
.33072 .5756 Mdot
.22414 .67995 Mdot
.35976 .56099 Mdot
.36695 .43341 Mdot
.55744 .69065 Mdot
.37115 .40432 Mdot
.57702 .88674 Mdot
.53322 .61784 Mdot
.63835 .44049 Mdot
.52803 .59428 Mdot
.51366 .62057 Mdot
.57597 .58799 Mdot
.35278 .40689 Mdot
.26264 .61987 Mdot
.51826 .66815 Mdot
.51434 .32623 Mdot
.69756 .55831 Mdot
.48695 .62881 Mdot
.34804 .49868 Mdot
.49799 .73655 Mdot
.65069 .37528 Mdot
.64421 .41826 Mdot
.36203 .41847 Mdot
.64728 .44469 Mdot
.59012 .20858 Mdot
.65042 .45345 Mdot
.67818 .60289 Mdot
.69859 .70328 Mdot
.75952 .64703 Mdot
.76979 .62994 Mdot
.44229 .46925 Mdot
.63522 .41525 Mdot
.32427 .60394 Mdot
.62646 .43788 Mdot
.67194 .42717 Mdot
.49219 .09754 Mdot
.67266 .4844 Mdot
.5235 .65168 Mdot
.49196 .60743 Mdot
.2815 .35645 Mdot
.35945 .64564 Mdot
.54216 .59826 Mdot
.5399 .59158 Mdot
.32043 .54236 Mdot
.58721 .21177 Mdot
.41599 .32892 Mdot
.75934 .44229 Mdot
.22841 .62698 Mdot
.55814 .6495 Mdot
.50396 .60748 Mdot
.52741 .54755 Mdot
.79102 .35239 Mdot
.31108 .26842 Mdot
.64117 .40219 Mdot
.5615 .55156 Mdot
.23714 .41183 Mdot
.5833 .61396 Mdot
.52809 .66869 Mdot
.5384 .61577 Mdot
.36996 .40034 Mdot
.6369 .41851 Mdot
.55652 .56474 Mdot
.34978 .72771 Mdot
.52177 .65753 Mdot
.57712 .30262 Mdot
.16094 .5597 Mdot
.52853 .65234 Mdot
.6185 .47177 Mdot
.50632 .61504 Mdot
.67148 .43592 Mdot
.68491 .44297 Mdot
.56658 .55735 Mdot
.66008 .5744 Mdot
.61772 .44885 Mdot
.55554 .62675 Mdot
.34284 .42863 Mdot
.46222 .81897 Mdot
.57521 .6298 Mdot
.29823 .57407 Mdot
.53941 .67335 Mdot
.31659 .5963 Mdot
.53472 .60073 Mdot
.411 .41364 Mdot
.64428 .6671 Mdot
.37986 .41308 Mdot
.24927 .32257 Mdot
.41138 .40114 Mdot
.85376 .55102 Mdot
.67608 .42135 Mdot
.4398 .29066 Mdot
.68229 .26337 Mdot
.51652 .24038 Mdot
.54599 .42223 Mdot
.46153 .43451 Mdot
.52299 .31405 Mdot
.66074 .42718 Mdot
.64168 .25322 Mdot
.30642 .5033 Mdot
.30514 .47075 Mdot
.34773 .39183 Mdot
.2682 .25056 Mdot
.62206 .20644 Mdot
.59049 .64419 Mdot
.71326 .65952 Mdot
.72888 .59335 Mdot
.58345 .6089 Mdot
.5786 .58943 Mdot
.33216 .37651 Mdot
.52804 .67952 Mdot
.70173 .35654 Mdot
.37483 .43861 Mdot
.30464 .55764 Mdot
.6288 .44621 Mdot
.3445 .58246 Mdot
.28612 .5324 Mdot
.46294 .42703 Mdot
.34985 .43131 Mdot
.53539 .69087 Mdot
.54756 .59723 Mdot
.67411 .44415 Mdot
.66626 .51762 Mdot
.62622 .47197 Mdot
.31944 .55558 Mdot
.38298 .43858 Mdot
.45791 .17433 Mdot
.54706 .59401 Mdot
.64914 .47591 Mdot
.55225 .43103 Mdot
.51722 .59578 Mdot
.54034 .36217 Mdot
.52753 .61081 Mdot
.62994 .43886 Mdot
.5227 .59751 Mdot
.66326 .4636 Mdot
.37308 .43017 Mdot
.55588 .57702 Mdot
.56821 .59534 Mdot
.84766 .49441 Mdot
.33064 .55558 Mdot
.69303 .43004 Mdot
.4083 .56213 Mdot
.50975 .59543 Mdot
.41379 .27591 Mdot
.51701 .64077 Mdot
.68531 .39462 Mdot
.58665 .65465 Mdot
.5958 .34122 Mdot
.57584 .55678 Mdot
.5655 .64787 Mdot
.5666 .4795 Mdot
.72005 .59674 Mdot
.51559 .53121 Mdot
.49267 .35365 Mdot
.69416 .43569 Mdot
.81021 .53327 Mdot
.36796 .47561 Mdot
.38583 .4555 Mdot
.41709 .67732 Mdot
.54768 .56337 Mdot
.53479 .64702 Mdot
.65628 .37819 Mdot
.3217 .58708 Mdot
.6664 .48124 Mdot
.32178 .54826 Mdot
.84022 .54664 Mdot
.34826 .54984 Mdot
.31272 .41379 Mdot
.22357 .46951 Mdot
.41782 .19033 Mdot
.32468 .54267 Mdot
.62887 .43852 Mdot
.24736 .41716 Mdot
.53715 .57433 Mdot
.52505 .49841 Mdot
.3355 .5651 Mdot
.19699 .33825 Mdot
.53405 .57856 Mdot
.55101 .42208 Mdot
.54612 .3352 Mdot
.32332 .54356 Mdot
.53398 .31162 Mdot
.5584 .60451 Mdot
.41952 .32987 Mdot
.66456 .4511 Mdot
.52851 .30611 Mdot
.48171 .63127 Mdot
.32194 .55237 Mdot
.4131 .42174 Mdot
.52815 .29949 Mdot
.48399 .33096 Mdot
.35084 .76512 Mdot
.1903 .40018 Mdot
.38589 .43728 Mdot
.79241 .47164 Mdot
.51206 .36793 Mdot
.5297 .57429 Mdot
.61091 .22548 Mdot
.50756 .62105 Mdot
.4614 .21233 Mdot
.35935 .42462 Mdot
.34312 .33473 Mdot
.5129 .59892 Mdot
.57382 .63976 Mdot
.65673 .49956 Mdot
.38405 .41961 Mdot
.6489 .46643 Mdot
.68577 .40874 Mdot
.37509 .43106 Mdot
.65762 .45567 Mdot
.31151 .54172 Mdot
.69108 .30505 Mdot
.49206 .3385 Mdot
.50405 .32986 Mdot
.3818 .4005 Mdot
.35845 .41391 Mdot
.37065 .40929 Mdot
.52677 .61048 Mdot
.6462 .47872 Mdot
.55575 .61308 Mdot
.55325 .67749 Mdot
.71117 .54182 Mdot
.6452 .41516 Mdot
.54877 .61689 Mdot
.4456 .52643 Mdot
.60897 .55459 Mdot
.34757 .437 Mdot
.54561 .33821 Mdot
.46851 .27026 Mdot
.34617 .29852 Mdot
.52546 .64204 Mdot
.29645 .62158 Mdot
.62731 .43898 Mdot
.30979 .56972 Mdot
.35309 .5494 Mdot
.31684 .56473 Mdot
.51199 .38547 Mdot
.6672 .41269 Mdot
.74772 .46408 Mdot
.53009 .64717 Mdot
.71232 .40452 Mdot
.64023 .40013 Mdot
.24702 .43146 Mdot
.54502 .34019 Mdot
.52769 .59236 Mdot
.41316 .52999 Mdot
.63087 .73325 Mdot
.51143 .61553 Mdot
.4869 .62138 Mdot
.23417 .59697 Mdot
.55483 .70166 Mdot
.64377 .49366 Mdot
.84064 .44846 Mdot
.49224 .64218 Mdot
.49161 .19612 Mdot
.24525 .72757 Mdot
.51981 .63477 Mdot
.56942 .65198 Mdot
.55346 .5915 Mdot
.50025 .61781 Mdot
.6158 .45517 Mdot
.3865 .6298 Mdot
.50529 .36396 Mdot
.71558 .41276 Mdot
.53732 .36743 Mdot
.37745 .38258 Mdot
.34321 .33626 Mdot
.65535 .42498 Mdot
.34101 .57925 Mdot
.20543 .61425 Mdot
.80022 .42346 Mdot
.40487 .41428 Mdot
.39109 .21206 Mdot
.33304 .56521 Mdot
.50655 .58343 Mdot
.29237 .56445 Mdot
.38375 .44843 Mdot
.49831 .33208 Mdot
.50076 .67802 Mdot
.63928 .43008 Mdot
.63388 .47461 Mdot
.52387 .59143 Mdot
.21073 .45772 Mdot
.55189 .35557 Mdot
.48475 .3458 Mdot
.51488 .65333 Mdot
.49092 .64411 Mdot
.65076 .46485 Mdot
.39153 .40531 Mdot
.77175 .63849 Mdot
.30604 .57737 Mdot
.58593 .61696 Mdot
.51848 .59968 Mdot
.78671 .64758 Mdot
.51148 .32431 Mdot
.41643 .42983 Mdot
.57131 .67586 Mdot
.59961 .28696 Mdot
.5626 .68038 Mdot
.52567 .551 Mdot
.34293 .43078 Mdot
.4749 .58696 Mdot
.58437 .58905 Mdot
.69988 .42122 Mdot
.53279 .31607 Mdot
.64118 .44674 Mdot
.70143 .42413 Mdot
.71661 .32853 Mdot
.53316 .36078 Mdot
.53793 .6122 Mdot
.54453 .34622 Mdot
.51121 .64202 Mdot
.49824 .64664 Mdot
.54176 .33438 Mdot
.65018 .46684 Mdot
.27957 .71051 Mdot
.29447 .36339 Mdot
.49729 .62956 Mdot
.57078 .56359 Mdot
.36432 .62963 Mdot
.33546 .51313 Mdot
.57708 .63816 Mdot
.62508 .44938 Mdot
.55762 .59915 Mdot
.55546 .34148 Mdot
.30219 .54603 Mdot
.63902 .43561 Mdot
.39838 .41826 Mdot
.40726 .4222 Mdot
.63049 .34246 Mdot
.33603 .40758 Mdot
.57585 .64726 Mdot
.65693 .51318 Mdot
.63566 .49857 Mdot
.19362 .57905 Mdot
.37931 .43115 Mdot
.29873 .57949 Mdot
.57376 .61637 Mdot
.4587 .72759 Mdot
.56455 .3586 Mdot
.47304 .12225 Mdot
.75949 .38566 Mdot
.28698 .56846 Mdot
.74585 .44827 Mdot
.40935 .40359 Mdot
.5685 .56647 Mdot
.29945 .57585 Mdot
.39391 .4417 Mdot
.50398 .6413 Mdot
.55738 .54993 Mdot
.61018 .52993 Mdot
.44837 .39899 Mdot
.54235 .34323 Mdot
.33874 .39239 Mdot
.2909 .58275 Mdot
.37923 .3789 Mdot
.68417 .43305 Mdot
.5547 .6607 Mdot
.55833 .68849 Mdot
.39373 .40587 Mdot
.38908 .45587 Mdot
.5522 .62199 Mdot
.63277 .42944 Mdot
.29864 .42464 Mdot
.554 .64872 Mdot
.46681 .31619 Mdot
.6288 .41431 Mdot
.3894 .43999 Mdot
.56827 .64808 Mdot
.3607 .58494 Mdot
.39432 .41858 Mdot
.35058 .43923 Mdot
.5048 .6056 Mdot
.32661 .54087 Mdot
.59245 .60457 Mdot
.4913 .32963 Mdot
.25796 .26778 Mdot
.55607 .34263 Mdot
.36899 .48039 Mdot
.56537 .7023 Mdot
.59261 .25507 Mdot
.65353 .41842 Mdot
.44097 .67523 Mdot
.48173 .26563 Mdot
.49914 .56769 Mdot
.44768 .79914 Mdot
.56406 .30092 Mdot
.19631 .55713 Mdot
.48266 .77874 Mdot
.33964 .56364 Mdot
.52678 .35252 Mdot
.56955 .65216 Mdot
.56079 .34455 Mdot
.3019 .58084 Mdot
.25344 .31953 Mdot
.57651 .62923 Mdot
.63026 .46084 Mdot
.54629 .62132 Mdot
.6364 .47304 Mdot
.4968 .62068 Mdot
.59675 .62555 Mdot
.50517 .24632 Mdot
.42346 .59362 Mdot
.56567 .67806 Mdot
.8809 .45887 Mdot
.60796 .54172 Mdot
.30321 .5695 Mdot
.56261 .61501 Mdot
.40854 .38083 Mdot
.54028 .37329 Mdot
.54974 .25798 Mdot
.36787 .39995 Mdot
.48613 .32842 Mdot
.65456 .45979 Mdot
.36343 .42482 Mdot
.40344 .40914 Mdot
.47066 .59713 Mdot
.29068 .55745 Mdot
.51019 .33782 Mdot
.5429 .66649 Mdot
.57467 .63342 Mdot
.79624 .46585 Mdot
.28846 .50764 Mdot
.70421 .49886 Mdot
.74995 .28981 Mdot
.68159 .41271 Mdot
.31084 .55368 Mdot
.3545 .40348 Mdot
.56468 .6707 Mdot
.54145 .62858 Mdot
.42538 .27857 Mdot
.61986 .45522 Mdot
.47637 .47042 Mdot
.69871 .50782 Mdot
.38275 .58837 Mdot
.409 .61194 Mdot
.62762 .44612 Mdot
.40584 .61104 Mdot
.27869 .57143 Mdot
.36763 .80382 Mdot
.42204 .58197 Mdot
.54781 .33872 Mdot
.39921 .60898 Mdot
.66702 .47983 Mdot
.51347 .66044 Mdot
.34039 .42467 Mdot
.3371 .41272 Mdot
.64181 .4554 Mdot
.41446 .39331 Mdot
.34344 .56531 Mdot
.55952 .66655 Mdot
.77008 .41551 Mdot
.6578 .32115 Mdot
.37977 .39513 Mdot
.47015 .63044 Mdot
.51237 .34935 Mdot
.52259 .59156 Mdot
.3371 .55012 Mdot
.54261 .35494 Mdot
.62133 .77235 Mdot
.46412 .34315 Mdot
.57132 .62507 Mdot
.79089 .64579 Mdot
.53307 .35843 Mdot
.61146 .69922 Mdot
.54909 .65549 Mdot
.49763 .32225 Mdot
.50388 .71222 Mdot
.3473 .31496 Mdot
.483 .49773 Mdot
.53151 .83474 Mdot
.51303 .47507 Mdot
.35596 .39558 Mdot
.34489 .32528 Mdot
.50351 .23296 Mdot
.51765 .368 Mdot
.40646 .44592 Mdot
.47819 .51917 Mdot
.53292 .31214 Mdot
.51248 .58033 Mdot
.5162 .63516 Mdot
.3031 .2767 Mdot
.57768 .34981 Mdot
.3009 .33157 Mdot
.64082 .3603 Mdot
.50974 .59422 Mdot
.59336 .6302 Mdot
.54148 .63325 Mdot
.62857 .48421 Mdot
.53343 .33549 Mdot
.86202 .45738 Mdot
.54693 .36141 Mdot
.69159 .53935 Mdot
.38354 .40494 Mdot
.39236 .44092 Mdot
.52641 .64759 Mdot
.55774 .41821 Mdot
.56032 .76928 Mdot
.54862 .62582 Mdot
.31392 .52632 Mdot
.30485 .28908 Mdot
.49135 .62983 Mdot
.64505 .4219 Mdot
.48852 .57351 Mdot
.55037 .71539 Mdot
.49254 .3403 Mdot
.33809 .57781 Mdot
.47204 .71688 Mdot
.49986 .33532 Mdot
.53547 .64565 Mdot
.60365 .27176 Mdot
.51961 .61764 Mdot
.49859 .63068 Mdot
.67122 .52968 Mdot
.34882 .5453 Mdot
.37234 .4189 Mdot
.31968 .56333 Mdot
.66784 .42634 Mdot
.41869 .10586 Mdot
.35018 .55216 Mdot
.59222 .77042 Mdot
.27518 .28541 Mdot
.39865 .60285 Mdot
.66731 .48221 Mdot
.2905 .57355 Mdot
.55196 .34736 Mdot
.46061 .8208 Mdot
.61818 .55881 Mdot
.55897 .30381 Mdot
.5493 .64845 Mdot
.69579 .45484 Mdot
.63551 .48054 Mdot
.5234 .30489 Mdot
.68716 .44023 Mdot
.48625 .55192 Mdot
.50273 .64424 Mdot
.52121 .36447 Mdot
.62163 .3067 Mdot
.50272 .36338 Mdot
.4045 .50021 Mdot
.56334 .62149 Mdot
.63574 .43832 Mdot
.58371 .59457 Mdot
.6117 .46974 Mdot
.41788 .42072 Mdot
.54153 .69205 Mdot
.3445 .56581 Mdot
.58292 .25515 Mdot
.38944 .43589 Mdot
.39492 .58427 Mdot
.67364 .44107 Mdot
.50754 .38723 Mdot
.67764 .44137 Mdot
.62729 .49691 Mdot
.49464 .3169 Mdot
.68119 .46653 Mdot
.56689 .65622 Mdot
.47952 .50565 Mdot
.6702 .44836 Mdot
.52144 .33939 Mdot
.32998 .58076 Mdot
.6594 .46428 Mdot
.31222 .39977 Mdot
.57524 .61924 Mdot
.35431 .40835 Mdot
.29548 .52815 Mdot
.68894 .47089 Mdot
.32817 .53538 Mdot
.37918 .45676 Mdot
.32665 .59149 Mdot
.18383 .51967 Mdot
.48805 .30826 Mdot
.65562 .54964 Mdot
.30561 .52677 Mdot
.64656 .49012 Mdot
.26482 .64294 Mdot
.54839 .67733 Mdot
.57491 .61589 Mdot
.3163 .59541 Mdot
.63534 .48046 Mdot
.3058 .78134 Mdot
.61824 .63702 Mdot
.42144 .48305 Mdot
.5378 .38209 Mdot
.86079 .53671 Mdot
.40886 .49374 Mdot
.21973 .6961 Mdot
.47368 .63153 Mdot
.35872 .45695 Mdot
.52881 .63587 Mdot
.46354 .25674 Mdot
.32568 .55514 Mdot
.3568 .49521 Mdot
.58514 .67322 Mdot
.36957 .42389 Mdot
.56423 .58835 Mdot
.55797 .48273 Mdot
.58758 .71637 Mdot
.30527 .58861 Mdot
.22475 .4461 Mdot
.68794 .47027 Mdot
.33156 .57309 Mdot
.38045 .44529 Mdot
.43366 .6284 Mdot
.50287 .64095 Mdot
.51626 .57657 Mdot
.38178 .58863 Mdot
.64949 .48119 Mdot
.34393 .40723 Mdot
.493 .32958 Mdot
.33219 .58331 Mdot
.54792 .59902 Mdot
.55276 .67901 Mdot
.41988 .26777 Mdot
.51613 .35497 Mdot
.33513 .43405 Mdot
.54157 .32522 Mdot
.403 .40027 Mdot
.51499 .66685 Mdot
.40268 .42776 Mdot
.54412 .55895 Mdot
.56136 .28249 Mdot
.66578 .53922 Mdot
.71769 .6154 Mdot
.3609 .42922 Mdot
.6336 .7602 Mdot
.51969 .35639 Mdot
.52497 .31942 Mdot
.3267 .23972 Mdot
.62016 .55108 Mdot
.79331 .43947 Mdot
.40514 .76899 Mdot
.51223 .35747 Mdot
.51307 .34299 Mdot
.35459 .4096 Mdot
.68254 .46295 Mdot
.68418 .41703 Mdot
.40241 .40204 Mdot
.36085 .68278 Mdot
.66547 .48136 Mdot
.42123 .80801 Mdot
.81158 .50169 Mdot
.51605 .56448 Mdot
.31416 .4325 Mdot
.3122 .57537 Mdot
.37377 .67843 Mdot
.54912 .487 Mdot
.57807 .63048 Mdot
.43924 .69538 Mdot
.38664 .40254 Mdot
.56153 .40406 Mdot
.53072 .82701 Mdot
.56023 .58182 Mdot
.54724 .65987 Mdot
.53625 .63715 Mdot
.29548 .54861 Mdot
.63962 .6177 Mdot
.5619 .65897 Mdot
.35793 .68281 Mdot
.51572 .59213 Mdot
.59122 .71813 Mdot
.31783 .56973 Mdot
.46222 .54144 Mdot
.30192 .51471 Mdot
.83795 .46026 Mdot
.59243 .7042 Mdot
.49014 .33387 Mdot
.32611 .48229 Mdot
.52735 .31759 Mdot
.68967 .60212 Mdot
.41382 .58302 Mdot
.67688 .40974 Mdot
.57712 .63391 Mdot
.36789 .43452 Mdot
.63562 .48015 Mdot
.37713 .30542 Mdot
.46036 .0995 Mdot
.49287 .3469 Mdot
.37967 .85876 Mdot
.50369 .31924 Mdot
.40203 .40727 Mdot
.65047 .46375 Mdot
.68264 .71829 Mdot
.72504 .37876 Mdot
.65981 .46179 Mdot
.27703 .73798 Mdot
.6216 .40749 Mdot
.46249 .69374 Mdot
.66472 .49352 Mdot
.51967 .34306 Mdot
.56183 .39146 Mdot
.47795 .55227 Mdot
.53082 .66838 Mdot
.46659 .43441 Mdot
.558 .76677 Mdot
.54989 .67701 Mdot
.37704 .43877 Mdot
.63815 .54062 Mdot
.42601 .67815 Mdot
.6767 .47332 Mdot
.46883 .33118 Mdot
.55438 .65742 Mdot
.51211 .60631 Mdot
.50757 .64966 Mdot
.76319 .37233 Mdot
.36281 .8018 Mdot
.51617 .66572 Mdot
.49959 .61122 Mdot
.36618 .42501 Mdot
.35276 .52158 Mdot
.26771 .39243 Mdot
.77269 .48322 Mdot
.56582 .57994 Mdot
.32615 .57424 Mdot
.29409 .59131 Mdot
.54019 .68284 Mdot
.47291 .51524 Mdot
.60454 .26544 Mdot
.54468 .66674 Mdot
.63314 .53996 Mdot
.37833 .35638 Mdot
.33342 .43538 Mdot
.39624 .41483 Mdot
.69293 .44402 Mdot
.39453 .40126 Mdot
.41252 .41292 Mdot
.63639 .74232 Mdot
.49746 .47084 Mdot
.54566 .27307 Mdot
.31671 .55623 Mdot
.53611 .62476 Mdot
.53934 .52783 Mdot
.59765 .27794 Mdot
.5198 .31149 Mdot
.6467 .43267 Mdot
.54684 .37297 Mdot
.30172 .60215 Mdot
.73805 .36402 Mdot
.3648 .38658 Mdot
.5011 .34744 Mdot
.48316 .30628 Mdot
.32381 .57528 Mdot
.54855 .32256 Mdot
.46118 .38012 Mdot
.50481 .66873 Mdot
.6964 .67542 Mdot
.55453 .62902 Mdot
.20666 .62847 Mdot
.50754 .34316 Mdot
.54775 .38753 Mdot
.53595 .65577 Mdot
.39323 .42143 Mdot
.47596 .69317 Mdot
.52704 .66581 Mdot
.39274 .40101 Mdot
.5896 .65135 Mdot
.35833 .56753 Mdot
.6262 .42276 Mdot
.72339 .38025 Mdot
.27174 .24419 Mdot
.28975 .56086 Mdot
.38529 .29989 Mdot
.5818 .62138 Mdot
.18738 .43714 Mdot
.66028 .46712 Mdot
.58046 .65723 Mdot
.41999 .64815 Mdot
.67193 .45776 Mdot
.65056 .44371 Mdot
.52725 .60532 Mdot
.54662 .33356 Mdot
.39022 .43739 Mdot
.31884 .57511 Mdot
.19666 .64451 Mdot
.55793 .64111 Mdot
.56498 .59672 Mdot
.33201 .5695 Mdot
.53143 .36347 Mdot
.55926 .68121 Mdot
.38978 .73378 Mdot
.34257 .80643 Mdot
.50184 .31788 Mdot
.54165 .57663 Mdot
.68398 .63243 Mdot
.60729 .67959 Mdot
.15477 .46663 Mdot
.51126 .50317 Mdot
.36727 .41664 Mdot
.59544 .6793 Mdot
.58812 .15825 Mdot
.33396 .58064 Mdot
.79828 .42662 Mdot
.51279 .60444 Mdot
.54385 .59055 Mdot
.62223 .46284 Mdot
.55569 .61631 Mdot
.652 .42636 Mdot
.36033 .19289 Mdot
.80966 .62208 Mdot
.68955 .43006 Mdot
.65528 .4911 Mdot
.48757 .73182 Mdot
.48342 .28851 Mdot
.64416 .45643 Mdot
.49591 .64514 Mdot
.44397 .54352 Mdot
.63112 .387 Mdot
.29412 .57673 Mdot
.2593 .61036 Mdot
.60354 .56976 Mdot
.32385 .61905 Mdot
.2886 .70903 Mdot
.5757 .53191 Mdot
.4025 .51391 Mdot
.51479 .32106 Mdot
.56049 .58093 Mdot
.33625 .41412 Mdot
.33452 .41313 Mdot
.54754 .55725 Mdot
.52829 .61816 Mdot
.67048 .43066 Mdot
.31753 .58443 Mdot
.52237 .37221 Mdot
.54295 .59287 Mdot
.43892 .66664 Mdot
.33549 .58543 Mdot
.68682 .44813 Mdot
.6888 .55593 Mdot
.36273 .5568 Mdot
.59615 .60287 Mdot
.5349 .66646 Mdot
.54221 .6178 Mdot
.47787 .55034 Mdot
.53206 .33158 Mdot
.29728 .70442 Mdot
.49402 .60896 Mdot
.84356 .53643 Mdot
.52533 .26745 Mdot
.59106 .67561 Mdot
.68246 .43719 Mdot
.47335 .34321 Mdot
.40508 .39143 Mdot
.69755 .29518 Mdot
.56927 .62825 Mdot
.21748 .44957 Mdot
.29728 .28428 Mdot
.40726 .44083 Mdot
.61188 .45072 Mdot
.31404 .56255 Mdot
.54577 .62499 Mdot
.6573 .57598 Mdot
.51831 .63799 Mdot
.27459 .57326 Mdot
.35677 .44413 Mdot
.51841 .32125 Mdot
.20071 .57701 Mdot
.33582 .40023 Mdot
.648 .44473 Mdot
.71607 .75168 Mdot
.65095 .42552 Mdot
.68588 .4185 Mdot
.69945 .55464 Mdot
.53228 .33047 Mdot
.52586 .13037 Mdot
.38154 .19212 Mdot
.51475 .67164 Mdot
.52759 .36121 Mdot
.63581 .45114 Mdot
.52656 .58488 Mdot
.61126 .42644 Mdot
.65949 .40985 Mdot
.50483 .65547 Mdot
.54869 .58732 Mdot
.26437 .35913 Mdot
.49738 .80731 Mdot
.31493 .56083 Mdot
.66438 .41969 Mdot
.71189 .36298 Mdot
.52493 .58391 Mdot
.53049 .64842 Mdot
.45182 .22592 Mdot
.2951 .55305 Mdot
.68236 .32657 Mdot
.51241 .60548 Mdot
.74455 .70291 Mdot
.49955 .55697 Mdot
.61924 .44157 Mdot
.52142 .31576 Mdot
.8386 .47772 Mdot
.45544 .3793 Mdot
.65286 .42741 Mdot
.34698 .57379 Mdot
.65173 .50111 Mdot
.61235 .76864 Mdot
.53856 .36662 Mdot
.62979 .43899 Mdot
.40782 .53046 Mdot
.53586 .34348 Mdot
.50281 .34091 Mdot
.71897 .5386 Mdot
.42144 .40972 Mdot
.28701 .55993 Mdot
.51074 .34012 Mdot
.5734 .21855 Mdot
.52678 .34435 Mdot
.36059 .20226 Mdot
.5543 .57895 Mdot
.40769 .69694 Mdot
.36114 .4824 Mdot
.60924 .6016 Mdot
.50758 .34812 Mdot
.31475 .54318 Mdot
.50367 .63897 Mdot
.68447 .46897 Mdot
.31058 .58543 Mdot
.56289 .32227 Mdot
.36625 .40303 Mdot
.6782 .44683 Mdot
.57524 .36884 Mdot
.63358 .47207 Mdot
.64095 .25378 Mdot
.25565 .28903 Mdot
.50396 .75521 Mdot
.72632 .37635 Mdot
.50154 .63938 Mdot
.36449 .77178 Mdot
.54403 .57283 Mdot
.52291 .61388 Mdot
.38379 .44053 Mdot
.41953 .69217 Mdot
.64927 .46625 Mdot
.24628 .70126 Mdot
.49461 .34213 Mdot
.84098 .46771 Mdot
.59167 .70064 Mdot
.58747 .62769 Mdot
.66928 .44493 Mdot
.62219 .44124 Mdot
.71615 .58169 Mdot
.3537 .37777 Mdot
.58421 .61892 Mdot
.48514 .6514 Mdot
.54708 .554 Mdot
.49538 .33483 Mdot
.43488 .54169 Mdot
.36048 .39325 Mdot
.21798 .34616 Mdot
.35965 .44666 Mdot
.27458 .60407 Mdot
.68399 .46463 Mdot
.35044 .55292 Mdot
.53086 .65148 Mdot
.65436 .51965 Mdot
.61962 .46017 Mdot
.31828 .59488 Mdot
.31627 .54593 Mdot
.37926 .27832 Mdot
.54197 .33528 Mdot
.52701 .66969 Mdot
.5671 .6506 Mdot
.55187 .61019 Mdot
.52814 .61231 Mdot
.49437 .34778 Mdot
.50931 .64796 Mdot
.56676 .35082 Mdot
.70733 .2961 Mdot
.41386 .72522 Mdot
.51952 .47394 Mdot
.41881 .2128 Mdot
.67419 .47663 Mdot
.57771 .22746 Mdot
.54248 .70731 Mdot
.68235 .25022 Mdot
.24772 .34139 Mdot
.4885 .64529 Mdot
.40636 .42644 Mdot
.52729 .72892 Mdot
.34608 .39412 Mdot
.22552 .71625 Mdot
.47037 .23558 Mdot
.48428 .80778 Mdot
.57517 .63167 Mdot
.47649 .5058 Mdot
.54246 .20532 Mdot
.53603 .57321 Mdot
.41502 .25823 Mdot
.45948 .21142 Mdot
.23986 .41845 Mdot
.32681 .54246 Mdot
.56623 .63996 Mdot
.52843 .52894 Mdot
.56387 .66077 Mdot
.52844 .64088 Mdot
.50826 .64866 Mdot
.53194 .37798 Mdot
.57659 .6586 Mdot
.50445 .62801 Mdot
.22879 .49966 Mdot
.41348 .60575 Mdot
.34926 .4501 Mdot
.30917 .25506 Mdot
.34924 .55002 Mdot
.67171 .44218 Mdot
.35105 .78668 Mdot
.54768 .33937 Mdot
.72188 .58342 Mdot
.53401 .61489 Mdot
.27769 .36066 Mdot
.46146 .33352 Mdot
.34683 .57107 Mdot
.39036 .44751 Mdot
.48698 .82184 Mdot
.37268 .4351 Mdot
.48387 .36492 Mdot
.39142 .42574 Mdot
.57696 .70113 Mdot
.66968 .42832 Mdot
.53262 .67711 Mdot
.51037 .33526 Mdot
.40061 .41575 Mdot
.36196 .6392 Mdot
.53931 .6327 Mdot
.37525 .43035 Mdot
.53045 .6754 Mdot
.73971 .41778 Mdot
.7907 .49831 Mdot
.41104 .42257 Mdot
.4969 .30122 Mdot
.5187 .32933 Mdot
.33649 .54593 Mdot
.67502 .4507 Mdot
.64984 .43072 Mdot
.54097 .35469 Mdot
.62008 .51124 Mdot
.56545 .57806 Mdot
.5357 .58346 Mdot
.83879 .50375 Mdot
.56857 .65886 Mdot
.43522 .62637 Mdot
.4155 .53194 Mdot
.69016 .44758 Mdot
.58959 .6145 Mdot
.52456 .60176 Mdot
.5725 .62274 Mdot
.74928 .41732 Mdot
.3896 .4007 Mdot
.55783 .58018 Mdot
.30794 .55046 Mdot
.32151 .35911 Mdot
.52188 .59184 Mdot
.48369 .56749 Mdot
.64778 .43077 Mdot
.75616 .30611 Mdot
.50795 .31859 Mdot
.37878 .44491 Mdot
.35964 .42855 Mdot
.28531 .68963 Mdot
.53894 .22553 Mdot
.41803 .5307 Mdot
.17491 .4016 Mdot
.50601 .24671 Mdot
.31919 .54938 Mdot
.33605 .44919 Mdot
.57545 .38605 Mdot
.35203 .42308 Mdot
.49772 .35478 Mdot
.54407 .57806 Mdot
.56335 .57785 Mdot
.56794 .16588 Mdot
.5529 .68374 Mdot
.31309 .56734 Mdot
.5156 .3717 Mdot
.66296 .48009 Mdot
.34421 .57552 Mdot
.53939 .32289 Mdot
.69241 .44243 Mdot
.48738 .64242 Mdot
.49005 .61851 Mdot
.64973 .43372 Mdot
.62358 .46188 Mdot
.53426 .66325 Mdot
.44265 .33712 Mdot
.65248 .48978 Mdot
.62715 .44513 Mdot
.36977 .38807 Mdot
.33658 .40946 Mdot
.54945 .54118 Mdot
.51944 .35412 Mdot
.50407 .63205 Mdot
.36409 .42792 Mdot
.3493 .55187 Mdot
.65118 .46949 Mdot
.49827 .62478 Mdot
.53011 .59311 Mdot
.32412 .57656 Mdot
.34602 .55419 Mdot
.33466 .54889 Mdot
.57254 .36636 Mdot
.55908 .60977 Mdot
.65067 .45936 Mdot
.53686 .33058 Mdot
.28916 .5857 Mdot
.29328 .56638 Mdot
.32267 .42873 Mdot
.57017 .66237 Mdot
.40911 .46494 Mdot
.60624 .16422 Mdot
.8216 .58437 Mdot
.41403 .42553 Mdot
.40051 .38797 Mdot
.3206 .63921 Mdot
.58876 .39551 Mdot
.54402 .36034 Mdot
.3399 .51504 Mdot
.51111 .75351 Mdot
.50302 .6748 Mdot
.49277 .62684 Mdot
.59494 .63814 Mdot
.33095 .54711 Mdot
.4319 .71241 Mdot
.65724 .42526 Mdot
.45356 .56078 Mdot
.33426 .58671 Mdot
.37387 .4567 Mdot
.33301 .45022 Mdot
.36533 .44885 Mdot
.50182 .5895 Mdot
.72378 .62491 Mdot
.56299 .23332 Mdot
.38757 .75335 Mdot
.51246 .35249 Mdot
.54501 .52827 Mdot
.19483 .42433 Mdot
.65207 .43885 Mdot
.37093 .38063 Mdot
.31482 .54963 Mdot
.62532 .46484 Mdot
.55108 .37009 Mdot
.51305 .34087 Mdot
.37829 .39481 Mdot
.37631 .39667 Mdot
.34553 .424 Mdot
.65329 .40781 Mdot
.68303 .46494 Mdot
.56895 .62589 Mdot
.65502 .47411 Mdot
.74001 .31593 Mdot
.33795 .59463 Mdot
.41777 .38299 Mdot
.52407 .35309 Mdot
.67701 .47825 Mdot
.54244 .63219 Mdot
.69367 .39893 Mdot
.5957 .31522 Mdot
.30187 .57063 Mdot
.793 .48238 Mdot
.19667 .6655 Mdot
.53458 .67568 Mdot
.52343 .32753 Mdot
.77302 .40266 Mdot
.53877 .63821 Mdot
.34934 .40746 Mdot
.22328 .5658 Mdot
.43972 .39363 Mdot
.52396 .66197 Mdot
.51 .67455 Mdot
.48911 .33006 Mdot
.21623 .35165 Mdot
.56444 .6332 Mdot
.68485 .3143 Mdot
.47367 .31533 Mdot
.35073 .40068 Mdot
.481 .86778 Mdot
.37354 .57845 Mdot
.37056 .68192 Mdot
.37097 .39101 Mdot
.51286 .62206 Mdot
.35103 .38896 Mdot
.30281 .55714 Mdot
.39069 .44545 Mdot
.64692 .42442 Mdot
.37435 .45338 Mdot
.5641 .59621 Mdot
.64204 .45321 Mdot
.53292 .35907 Mdot
.83056 .45635 Mdot
.23874 .55886 Mdot
.3929 .41941 Mdot
.40993 .41565 Mdot
.58968 .62658 Mdot
.69573 .35137 Mdot
.555 .56159 Mdot
.53724 .57873 Mdot
.52405 .36349 Mdot
.67259 .45485 Mdot
.49891 .31765 Mdot
.59324 .57251 Mdot
.43135 .74366 Mdot
.53973 .32501 Mdot
.26898 .3835 Mdot
.33323 .56308 Mdot
.52038 .43081 Mdot
.5412 .62694 Mdot
.53978 .31403 Mdot
.56133 .61113 Mdot
.66036 .42474 Mdot
.53801 .46176 Mdot
.39498 .33595 Mdot
.50311 .33275 Mdot
.20041 .51922 Mdot
.38672 .71974 Mdot
.51373 .53991 Mdot
.52338 .31825 Mdot
.41807 .65855 Mdot
.40083 .40561 Mdot
.30712 .58026 Mdot
.35361 .57825 Mdot
.33536 .58763 Mdot
.49857 .57255 Mdot
.58991 .7036 Mdot
.32414 .53465 Mdot
.53897 .37217 Mdot
.30449 .58798 Mdot
.47064 .18872 Mdot
.24888 .70508 Mdot
.32804 .55828 Mdot
.54954 .65277 Mdot
.52008 .71113 Mdot
.39641 .59867 Mdot
.34091 .31438 Mdot
.46985 .80344 Mdot
.37575 .25027 Mdot
.52456 .65929 Mdot
.63085 .41106 Mdot
.65961 .413 Mdot
.77982 .368 Mdot
.58816 .7654 Mdot
.80326 .62223 Mdot
.69487 .43827 Mdot
.44738 .29306 Mdot
.68384 .45068 Mdot
.5226 .67127 Mdot
.53214 .58361 Mdot
.69326 .4198 Mdot
.44261 .73916 Mdot
.42769 .29951 Mdot
.19601 .6069 Mdot
.62942 .46862 Mdot
.53163 .31584 Mdot
.50799 .30809 Mdot
.50352 .34372 Mdot
.81406 .47855 Mdot
.66623 .44729 Mdot
.54312 .60175 Mdot
.36316 .43229 Mdot
.56848 .58496 Mdot
.53846 .34331 Mdot
.25765 .72953 Mdot
.66393 .46085 Mdot
.55818 .65768 Mdot
.45912 .61631 Mdot
.37187 .39889 Mdot
.32718 .56986 Mdot
.72863 .40936 Mdot
.79102 .63594 Mdot
.49712 .3443 Mdot
.69132 .46628 Mdot
.57973 .37962 Mdot
.20612 .60722 Mdot
.47327 .64452 Mdot
.51563 .69213 Mdot
.19637 .64835 Mdot
.70544 .74044 Mdot
.581 .62962 Mdot
.39894 .43947 Mdot
.42957 .27222 Mdot
.51924 .59612 Mdot
.6609 .41539 Mdot
.36198 .5608 Mdot
.32066 .59086 Mdot
.53825 .53905 Mdot
.69675 .39176 Mdot
.54164 .48303 Mdot
.53532 .6112 Mdot
.59704 .61258 Mdot
.35765 .3955 Mdot
.46877 .24692 Mdot
.84031 .54747 Mdot
.3507 .55945 Mdot
.53795 .68039 Mdot
.26425 .70129 Mdot
.62811 .47639 Mdot
.40821 .43879 Mdot
.55733 .34146 Mdot
.64247 .39988 Mdot
.39257 .44666 Mdot
.49487 .63304 Mdot
.54876 .68376 Mdot
.51265 .31131 Mdot
.62054 .43822 Mdot
.33386 .5504 Mdot
.38411 .44209 Mdot
.34531 .55836 Mdot
.67029 .45716 Mdot
.66552 .4746 Mdot
.46794 .58653 Mdot
.47936 .66219 Mdot
.39778 .41928 Mdot
.52785 .55965 Mdot
.43672 .36443 Mdot
.14709 .5169 Mdot
.57908 .37229 Mdot
.57132 .66696 Mdot
.66324 .497 Mdot
.49836 .33431 Mdot
.54646 .58998 Mdot
.2317 .71052 Mdot
.51878 .58704 Mdot
.51965 .37704 Mdot
.60234 .78073 Mdot
.342 .55885 Mdot
.49875 .52792 Mdot
.24454 .36012 Mdot
.56424 .66629 Mdot
.35614 .41756 Mdot
.47228 .61169 Mdot
.55023 .33762 Mdot
.67907 .47151 Mdot
.13947 .52351 Mdot
.52512 .33994 Mdot
.55397 .66894 Mdot
.33682 .58147 Mdot
.65033 .49551 Mdot
.51441 .50616 Mdot
.46038 .52038 Mdot
.4861 .6916 Mdot
.58608 .61061 Mdot
.51979 .60721 Mdot
.39805 .74333 Mdot
.36942 .44249 Mdot
.62963 .44738 Mdot
.51745 .32512 Mdot
.54256 .35692 Mdot
.3835 .39796 Mdot
.41514 .46363 Mdot
.51898 .43091 Mdot
.69347 .21343 Mdot
.35754 .38468 Mdot
.35378 .55923 Mdot
.69125 .33621 Mdot
.36957 .43983 Mdot
.37904 .42846 Mdot
.36567 .3876 Mdot
.41015 .51983 Mdot
.66583 .48179 Mdot
.49461 .63118 Mdot
.64419 .41854 Mdot
.51094 .62211 Mdot
.50152 .36761 Mdot
.50606 .33448 Mdot
.66785 .46426 Mdot
.18112 .56719 Mdot
.67959 .68089 Mdot
.54087 .64769 Mdot
.18849 .43579 Mdot
.57277 .68301 Mdot
.36758 .6166 Mdot
.58151 .67118 Mdot
.38897 .41318 Mdot
.51269 .57702 Mdot
.51363 .55934 Mdot
.78991 .39447 Mdot
.52301 .3548 Mdot
.33641 .44392 Mdot
.59827 .65221 Mdot
.59519 .60348 Mdot
.65226 .40656 Mdot
.62399 .45982 Mdot
.34995 .58177 Mdot
.43974 .60738 Mdot
.53532 .36107 Mdot
.45196 .16957 Mdot
.53175 .66845 Mdot
.34201 .61192 Mdot
.78402 .60161 Mdot
.54901 .59074 Mdot
.22738 .38734 Mdot
.72403 .61431 Mdot
.54433 .62552 Mdot
.44972 .4636 Mdot
.51785 .35538 Mdot
.47982 .77073 Mdot
.51303 .59553 Mdot
.36388 .39888 Mdot
.68563 .4565 Mdot
.62164 .46803 Mdot
.35633 .56967 Mdot
.6257 .20768 Mdot
.49636 .31812 Mdot
.67545 .46952 Mdot
.53327 .62951 Mdot
.52472 .32652 Mdot
.37027 .38481 Mdot
.58523 .64054 Mdot
.65635 .75735 Mdot
.6517 .4756 Mdot
.58988 .65275 Mdot
.66 .28844 Mdot
.33269 .66017 Mdot
.60506 .79257 Mdot
.51046 .32376 Mdot
.33455 .54538 Mdot
.50667 .55659 Mdot
.60251 .50346 Mdot
.58176 .57737 Mdot
.38981 .69628 Mdot
.45653 .19216 Mdot
.30613 .54388 Mdot
.53956 .65693 Mdot
.54583 .59882 Mdot
.57921 .44909 Mdot
.35045 .56622 Mdot
.57359 .63688 Mdot
.59191 .41756 Mdot
.63687 .4714 Mdot
.38882 .38876 Mdot
.65652 .4806 Mdot
.5486 .64898 Mdot
.48017 .66724 Mdot
.62191 .46011 Mdot
.16151 .50169 Mdot
.36568 .56359 Mdot
.52313 .32015 Mdot
.5286 .68362 Mdot
.5034 .59377 Mdot
.86011 .41387 Mdot
.4043 .44566 Mdot
.42837 .33858 Mdot
.27558 .4033 Mdot
.27234 .68807 Mdot
.37461 .54969 Mdot
.56565 .81419 Mdot
.69882 .74664 Mdot
.57735 .65837 Mdot
.56939 .51453 Mdot
.61573 .25139 Mdot
.52186 .3603 Mdot
.56968 .19427 Mdot
.53127 .66897 Mdot
.52796 .63795 Mdot
.41658 .4108 Mdot
.3752 .3339 Mdot
.80893 .61487 Mdot
.70658 .41945 Mdot
.33686 .55443 Mdot
.66967 .42435 Mdot
.49472 .63979 Mdot
.46592 .47187 Mdot
.38426 .4565 Mdot
.3267 .60581 Mdot
.55462 .66044 Mdot
.7549 .42263 Mdot
.60481 .32289 Mdot
.53879 .33558 Mdot
.35805 .42655 Mdot
.76914 .66096 Mdot
.56686 .66883 Mdot
.54426 .31614 Mdot
.55558 .63898 Mdot
.37801 .5484 Mdot
.60086 .59344 Mdot
.31833 .55171 Mdot
.50551 .6122 Mdot
.32027 .47197 Mdot
.87849 .52891 Mdot
.28402 .55614 Mdot
.64933 .40322 Mdot
.41939 .43447 Mdot
.39144 .40244 Mdot
.62371 .45303 Mdot
.39418 .40949 Mdot
.72793 .56419 Mdot
.64984 .742 Mdot
.33524 .56172 Mdot
.55372 .54428 Mdot
.32535 .56262 Mdot
.41612 .42679 Mdot
.52518 .66202 Mdot
.15712 .58946 Mdot
.3994 .42624 Mdot
.73378 .72177 Mdot
.52975 .34722 Mdot
.39496 .45462 Mdot
.51621 .59225 Mdot
.59566 .34597 Mdot
.33628 .40021 Mdot
.42403 .32165 Mdot
.57206 .62312 Mdot
.66336 .47796 Mdot
.52528 .59537 Mdot
.51237 .6685 Mdot
.35619 .45523 Mdot
.50808 .63552 Mdot
.54034 .32325 Mdot
.69391 .42956 Mdot
.44416 .81362 Mdot
.49317 .21116 Mdot
.57388 .63985 Mdot
.53495 .63192 Mdot
.63087 .4961 Mdot
.51429 .58104 Mdot
.49376 .34642 Mdot
.18093 .3044 Mdot
.33292 .56369 Mdot
.37432 .4641 Mdot
.29881 .44497 Mdot
.49142 .65913 Mdot
.50604 .6429 Mdot
.26642 .76635 Mdot
.42077 .73653 Mdot
.52875 .31871 Mdot
.54395 .55362 Mdot
.34536 .38729 Mdot
.32026 .58343 Mdot
.52594 .37114 Mdot
.54473 .61874 Mdot
.53319 .65329 Mdot
.3414 .5483 Mdot
.34949 .61545 Mdot
.8162 .51648 Mdot
.5249 .3075 Mdot
.56774 .70155 Mdot
.31729 .39058 Mdot
.56623 .57648 Mdot
.80202 .46561 Mdot
.63467 .43655 Mdot
.49871 .34701 Mdot
.28837 .7023 Mdot
.57069 .6658 Mdot
.52078 .31413 Mdot
.53329 .36079 Mdot
.58391 .58573 Mdot
.69412 .46988 Mdot
.69205 .42234 Mdot
.63647 .47425 Mdot
.46357 .13198 Mdot
.38118 .671 Mdot
.34549 .42393 Mdot
.52049 .35772 Mdot
.41032 .40895 Mdot
.27432 .57388 Mdot
.46909 .50308 Mdot
.41126 .4139 Mdot
.64811 .4828 Mdot
.38467 .46058 Mdot
.56158 .60459 Mdot
.53606 .36006 Mdot
.35051 .41957 Mdot
.50524 .66351 Mdot
.70547 .38656 Mdot
.33073 .29653 Mdot
.29853 .55515 Mdot
.36073 .5509 Mdot
.52799 .58665 Mdot
.37419 .37892 Mdot
.53154 .65953 Mdot
.55946 .34186 Mdot
.70938 .37477 Mdot
.51402 .6686 Mdot
.39289 .41584 Mdot
.6335 .49596 Mdot
.77513 .65273 Mdot
.49655 .58246 Mdot
.54814 .65354 Mdot
.50932 .62838 Mdot
.55617 .63843 Mdot
.20905 .59439 Mdot
.49439 .31378 Mdot
.43085 .21181 Mdot
.28407 .68152 Mdot
.66014 .45662 Mdot
.63287 .42199 Mdot
.83219 .5535 Mdot
.61233 .25896 Mdot
.51869 .35407 Mdot
.52491 .61328 Mdot
.59957 .29317 Mdot
.34067 .80393 Mdot
.18591 .61252 Mdot
.62548 .68023 Mdot
.40738 .44328 Mdot
.69094 .46652 Mdot
.40151 .41115 Mdot
.51417 .62728 Mdot
.59497 .61108 Mdot
.62421 .80901 Mdot
.5449 .36979 Mdot
.33349 .55536 Mdot
.50923 .62181 Mdot
.37677 .67298 Mdot
.3646 .42409 Mdot
.39503 .45494 Mdot
.55183 .58272 Mdot
.62412 .48153 Mdot
.87056 .52835 Mdot
.5313 .33148 Mdot
.41236 .22799 Mdot
.53455 .20207 Mdot
.61438 .36196 Mdot
.53723 .33972 Mdot
.59319 .50052 Mdot
.40931 .43565 Mdot
.78722 .57009 Mdot
.65938 .44978 Mdot
.3069 .58233 Mdot
.58514 .68208 Mdot
.6299 .4349 Mdot
.34698 .43954 Mdot
.67255 .47588 Mdot
.50588 .64483 Mdot
.47673 .31486 Mdot
.36617 .41445 Mdot
.53367 .2661 Mdot
.66173 .4976 Mdot
.3485 .57068 Mdot
.50022 .39665 Mdot
.62427 .71058 Mdot
.72449 .60971 Mdot
.55469 .58114 Mdot
.45854 .47934 Mdot
.54507 .60416 Mdot
.61137 .45977 Mdot
.54642 .6351 Mdot
.67177 .50754 Mdot
.3571 .41674 Mdot
.50105 .60865 Mdot
.53133 .61027 Mdot
.35471 .21248 Mdot
.57047 .63866 Mdot
.56328 .56879 Mdot
.5412 .62253 Mdot
.65085 .51695 Mdot
.53017 .5409 Mdot
.68087 .43498 Mdot
.25327 .41372 Mdot
.38088 .42573 Mdot
.3255 .59292 Mdot
.32942 .54114 Mdot
.41102 .68939 Mdot
.31306 .49205 Mdot
.33879 .33524 Mdot
.64178 .47178 Mdot
.5481 .32779 Mdot
.55099 .63586 Mdot
.5245 .82212 Mdot
.33647 .37298 Mdot
.37159 .45556 Mdot
.49554 .2126 Mdot
.61197 .64761 Mdot
.50509 .78462 Mdot
.55371 .55574 Mdot
.53914 .15629 Mdot
.48104 .64079 Mdot
.60384 .66133 Mdot
.36524 .38231 Mdot
.29757 .61253 Mdot
.51804 .5811 Mdot
.67336 .41626 Mdot
.30615 .56523 Mdot
.59313 .69792 Mdot
.34155 .46808 Mdot
.34595 .35011 Mdot
.71506 .47678 Mdot
.56668 .61683 Mdot
.36727 .41407 Mdot
.67721 .44589 Mdot
.83383 .56667 Mdot
.53491 .32906 Mdot
.39587 .47578 Mdot
.69581 .3059 Mdot
.16901 .49278 Mdot
.33925 .58361 Mdot
.77508 .52102 Mdot
.56325 .59813 Mdot
.21953 .52375 Mdot
.52372 .67933 Mdot
.27483 .75672 Mdot
.33688 .53961 Mdot
.65573 .48497 Mdot
.53551 .3167 Mdot
.66019 .41614 Mdot
.71602 .60286 Mdot
.32252 .44742 Mdot
.50608 .45637 Mdot
.37374 .43422 Mdot
.53117 .49074 Mdot
.63691 .44668 Mdot
.52497 .67042 Mdot
.68571 .20663 Mdot
.62897 .44129 Mdot
.65583 .49538 Mdot
.26724 .29425 Mdot
.15098 .5494 Mdot
.50423 .68633 Mdot
.65557 .49033 Mdot
.38031 .43459 Mdot
.31191 .56208 Mdot
.51069 .60198 Mdot
.56856 .61131 Mdot
.63528 .43208 Mdot
.35143 .45576 Mdot
.66088 .61903 Mdot
.38121 .40091 Mdot
.66061 .48261 Mdot
.37956 .41311 Mdot
.52409 .38349 Mdot
.38305 .44382 Mdot
.50298 .59384 Mdot
.54768 .63524 Mdot
.27562 .44827 Mdot
.66472 .47508 Mdot
.53704 .6113 Mdot
.58927 .63009 Mdot
.64862 .45985 Mdot
.58095 .49089 Mdot
.66843 .61808 Mdot
.58222 .61434 Mdot
.57329 .62772 Mdot
.32192 .54034 Mdot
.47201 .49215 Mdot
.78521 .49842 Mdot
.50253 .63583 Mdot
.30368 .54258 Mdot
.68087 .42271 Mdot
.54308 .66729 Mdot
.32668 .77289 Mdot
.4275 .2757 Mdot
.53514 .67487 Mdot
.40146 .40705 Mdot
.52763 .556 Mdot
.61991 .78682 Mdot
.53461 .57838 Mdot
.64122 .45855 Mdot
.67694 .46304 Mdot
.43143 .17907 Mdot
.64619 .44418 Mdot
.33706 .41246 Mdot
.53727 .34383 Mdot
.20277 .60477 Mdot
.38898 .3946 Mdot
.4787 .62154 Mdot
.29472 .23754 Mdot
.58332 .66035 Mdot
.48919 .63651 Mdot
.78143 .673 Mdot
.40207 .4176 Mdot
.66839 .43543 Mdot
.51652 .40403 Mdot
.48771 .67506 Mdot
.49949 .34491 Mdot
.6025 .63271 Mdot
.54206 .57694 Mdot
.65215 .7745 Mdot
.21345 .59608 Mdot
.54141 .31191 Mdot
.56325 .56965 Mdot
.50359 .63862 Mdot
.40959 .38192 Mdot
.53796 .62928 Mdot
.31471 .55781 Mdot
.66766 .44859 Mdot
.39482 .44103 Mdot
.32747 .57788 Mdot
.55819 .67361 Mdot
.33444 .54936 Mdot
.35372 .40868 Mdot
.55845 .3547 Mdot
.51697 .63995 Mdot
.29504 .57929 Mdot
.33688 .55263 Mdot
.54501 .60659 Mdot
.6842 .46569 Mdot
.61542 .63044 Mdot
.56862 .64348 Mdot
.49849 .62596 Mdot
.65183 .43081 Mdot
.46586 .87531 Mdot
.53345 .5826 Mdot
.39667 .70469 Mdot
.6232 .43979 Mdot
.55398 .49049 Mdot
.38748 .39062 Mdot
.53067 .57548 Mdot
.55879 .35425 Mdot
.55748 .34718 Mdot
.36773 .45042 Mdot
.68812 .47308 Mdot
.28265 .39955 Mdot
.69565 .41692 Mdot
.48424 .58417 Mdot
.55465 .56515 Mdot
.61259 .5432 Mdot
.50028 .81883 Mdot
.65246 .41991 Mdot
.34474 .47854 Mdot
.70896 .40777 Mdot
.54767 .32327 Mdot
.35044 .45096 Mdot
.69441 .42492 Mdot
.65792 .42808 Mdot
.69043 .45168 Mdot
.30583 .58228 Mdot
.27708 .45328 Mdot
.61944 .44513 Mdot
.61832 .47144 Mdot
.57258 .61325 Mdot
.5019 .63062 Mdot
.72859 .71072 Mdot
.71807 .70887 Mdot
.31328 .54481 Mdot
.34215 .41894 Mdot
.42882 .12485 Mdot
.55454 .36363 Mdot
.37961 .21362 Mdot
.49077 .63332 Mdot
.47363 .10622 Mdot
.51467 .59581 Mdot
.53276 .6269 Mdot
.69309 .42287 Mdot
.29448 .57293 Mdot
.3285 .56379 Mdot
.62972 .44514 Mdot
.61386 .45499 Mdot
.31662 .55668 Mdot
.22985 .36592 Mdot
.35099 .79853 Mdot
.42705 .35728 Mdot
.65475 .4644 Mdot
.62794 .73467 Mdot
.51895 .30857 Mdot
.54367 .71705 Mdot
.50459 .30096 Mdot
.37097 .42756 Mdot
.40104 .44243 Mdot
.49755 .33964 Mdot
.57014 .628 Mdot
.34841 .42866 Mdot
.5745 .66642 Mdot
.33789 .27448 Mdot
.70573 .64466 Mdot
.29898 .39632 Mdot
.53516 .72673 Mdot
.58245 .48728 Mdot
.52724 .26301 Mdot
.5484 .67343 Mdot
.29325 .73607 Mdot
.33606 .55694 Mdot
.47302 .60527 Mdot
.50179 .35116 Mdot
.7672 .69715 Mdot
.51953 .65054 Mdot
.64337 .46274 Mdot
.53022 .36104 Mdot
.70919 .30834 Mdot
.69114 .32385 Mdot
.5097 .62517 Mdot
.63214 .18363 Mdot
.61107 .4836 Mdot
.36312 .43582 Mdot
.75481 .39926 Mdot
.63035 .42663 Mdot
.3696 .53595 Mdot
.31655 .72663 Mdot
.17418 .54171 Mdot
.67187 .44041 Mdot
.42003 .41392 Mdot
.68544 .43439 Mdot
.3431 .57825 Mdot
.64968 .40406 Mdot
.36114 .41914 Mdot
.55094 .661 Mdot
.38827 .40476 Mdot
.30238 .57819 Mdot
.80995 .52728 Mdot
.54137 .31198 Mdot
.33052 .42111 Mdot
.51029 .33101 Mdot
.3064 .66018 Mdot
.3783 .73437 Mdot
.51765 .32049 Mdot
.65696 .56265 Mdot
.55089 .56525 Mdot
.6225 .43448 Mdot
.37955 .39195 Mdot
.25352 .57815 Mdot
.52729 .39984 Mdot
.65662 .4466 Mdot
.34449 .43331 Mdot
.71455 .35317 Mdot
.62529 .52158 Mdot
.55779 .56398 Mdot
.40175 .5915 Mdot
.65322 .46077 Mdot
.41832 .41295 Mdot
.84164 .49027 Mdot
.68384 .43195 Mdot
.34948 .3867 Mdot
.52684 .31365 Mdot
.54482 .35387 Mdot
.57271 .59187 Mdot
.47442 .32909 Mdot
.3616 .44415 Mdot
.54548 .29549 Mdot
.66023 .48989 Mdot
.73089 .33513 Mdot
.30629 .59312 Mdot
.38487 .41891 Mdot
.57505 .67365 Mdot
.61119 .4697 Mdot
.44983 .24368 Mdot
.66826 .6379 Mdot
.746 .28272 Mdot
.3837 .39839 Mdot
.66484 .44334 Mdot
.64584 .46658 Mdot
.49273 .58605 Mdot
.72813 .38098 Mdot
.26983 .41413 Mdot
.60394 .52639 Mdot
.56846 .42251 Mdot
.38324 .3852 Mdot
.40679 .46084 Mdot
.59954 .64664 Mdot
.56472 .62477 Mdot
.54331 .31861 Mdot
.55231 .65811 Mdot
.68194 .47646 Mdot
.55521 .58238 Mdot
.51925 .32636 Mdot
.375 .43755 Mdot
.51936 .64539 Mdot
.33954 .5533 Mdot
.49251 .31668 Mdot
.55493 .36923 Mdot
.38933 .42021 Mdot
.63534 .43156 Mdot
.54347 .4978 Mdot
.37395 .39555 Mdot
.56716 .6178 Mdot
.44444 .50579 Mdot
.50683 .64849 Mdot
.54818 .51994 Mdot
.68001 .42748 Mdot
.39577 .4399 Mdot
.68305 .40308 Mdot
.5179 .33654 Mdot
.28691 .68732 Mdot
.54648 .64497 Mdot
.35982 .3844 Mdot
.48469 .26043 Mdot
.52323 .51542 Mdot
.6545 .50073 Mdot
.28507 .34022 Mdot
.62482 .427 Mdot
.34299 .41286 Mdot
.3189 .24209 Mdot
.31859 .58768 Mdot
.37697 .45635 Mdot
.46161 .8123 Mdot
.39681 .42541 Mdot
.56717 .5886 Mdot
.53209 .58635 Mdot
.38597 .44324 Mdot
.33336 .54405 Mdot
.81947 .60776 Mdot
.42987 .42893 Mdot
.66953 .43929 Mdot
.28669 .30118 Mdot
.79953 .36056 Mdot
.56311 .29495 Mdot
.54648 .32326 Mdot
.50675 .69128 Mdot
.53984 .56902 Mdot
.50953 .35876 Mdot
.53893 .30781 Mdot
.34361 .58577 Mdot
.35507 .38863 Mdot
.61738 .48772 Mdot
.56071 .37383 Mdot
.73194 .43176 Mdot
.30287 .47867 Mdot
.50033 .57862 Mdot
.52425 .2011 Mdot
.49179 .63313 Mdot
.34683 .7157 Mdot
.51537 .32493 Mdot
.53079 .68043 Mdot
.5468 .55735 Mdot
.5303 .36552 Mdot
.31043 .56265 Mdot
.39194 .4769 Mdot
.37588 .4131 Mdot
.46706 .86573 Mdot
.58111 .64925 Mdot
.55922 .58692 Mdot
.50885 .3481 Mdot
.23498 .49863 Mdot
.66343 .4568 Mdot
.64206 .41478 Mdot
.3697 .44244 Mdot
.47344 .39921 Mdot
.55841 .57448 Mdot
.54979 .66924 Mdot
.36999 .40891 Mdot
.33455 .42672 Mdot
.34814 .32509 Mdot
.54736 .59647 Mdot
.52144 .35076 Mdot
.28382 .61626 Mdot
.50789 .32457 Mdot
.51352 .65874 Mdot
.55779 .58917 Mdot
.50192 .59474 Mdot
.5577 .68246 Mdot
.48275 .30763 Mdot
.50764 .65591 Mdot
.57229 .56082 Mdot
.66232 .44439 Mdot
.50589 .62299 Mdot
.56451 .41349 Mdot
.55617 .65082 Mdot
.31387 .55981 Mdot
.77621 .48136 Mdot
.51921 .64928 Mdot
.55005 .57959 Mdot
.38409 .46325 Mdot
.5369 .65029 Mdot
.56055 .34704 Mdot
.66276 .47051 Mdot
.51576 .35329 Mdot
.55749 .34443 Mdot
.41177 .39826 Mdot
.35132 .54925 Mdot
.49435 .66553 Mdot
.30398 .55719 Mdot
.47586 .6287 Mdot
.57144 .66479 Mdot
.32175 .50853 Mdot
.51354 .14796 Mdot
.81451 .48864 Mdot
.54835 .64513 Mdot
.40145 .42181 Mdot
.40234 .41134 Mdot
.5815 .51608 Mdot
.57513 .58109 Mdot
.51283 .36701 Mdot
.55052 .32659 Mdot
.60004 .76384 Mdot
.47937 .74102 Mdot
.31308 .56017 Mdot
.48273 .48053 Mdot
.58242 .62791 Mdot
.53282 .68063 Mdot
.584 .64783 Mdot
.41218 .41505 Mdot
.59827 .71654 Mdot
.3559 .4516 Mdot
.57313 .27801 Mdot
.50092 .33664 Mdot
.51323 .63635 Mdot
.50233 .20164 Mdot
.63129 .47339 Mdot
.66255 .47124 Mdot
.54913 .37352 Mdot
.32943 .384 Mdot
.7781 .64523 Mdot
.18551 .62679 Mdot
.61434 .41333 Mdot
.29815 .57834 Mdot
.5586 .66875 Mdot
.38617 .43725 Mdot
.66718 .48217 Mdot
.29808 .57667 Mdot
.5198 .66131 Mdot
.27816 .45443 Mdot
.55548 .64294 Mdot
.59151 .24195 Mdot
.68576 .45055 Mdot
.3102 .78498 Mdot
.68633 .47615 Mdot
.48314 .3258 Mdot
.49714 .34883 Mdot
.54764 .59132 Mdot
.59656 .45826 Mdot
.62895 .42615 Mdot
.37845 .51116 Mdot
.35365 .56125 Mdot
.5797 .30698 Mdot
.31959 .58503 Mdot
.3567 .42752 Mdot
.30668 .57722 Mdot
.35982 .41719 Mdot
.78668 .62911 Mdot
.6925 .50792 Mdot
.33085 .57225 Mdot
.49374 .25714 Mdot
.53639 .57031 Mdot
.30893 .5457 Mdot
.59444 .61147 Mdot
.57598 .52807 Mdot
.37153 .40646 Mdot
.35167 .5674 Mdot
.53523 .67928 Mdot
.55576 .80537 Mdot
.52517 .31948 Mdot
.50616 .36195 Mdot
.59419 .61265 Mdot
.3948 .39092 Mdot
.68414 .41836 Mdot
.24665 .69 Mdot
.56267 .37915 Mdot
.53909 .58484 Mdot
.51651 .58095 Mdot
.62261 .43039 Mdot
.43753 .19346 Mdot
.55524 .59371 Mdot
.50415 .53884 Mdot
.54525 .59379 Mdot
.49695 .32206 Mdot
.66389 .41815 Mdot
.65267 .47026 Mdot
.34502 .43236 Mdot
.6335 .48094 Mdot
.43248 .5558 Mdot
.54257 .23267 Mdot
.60365 .59467 Mdot
.52286 .33657 Mdot
.59738 .30714 Mdot
.55565 .25788 Mdot
.46314 .79915 Mdot
.66591 .49731 Mdot
.51087 .66429 Mdot
.63222 .48247 Mdot
.31469 .58061 Mdot
.65842 .47782 Mdot
.69111 .46608 Mdot
.53229 .66359 Mdot
.5131 .62167 Mdot
.36958 .43727 Mdot
.72313 .37682 Mdot
.62965 .43333 Mdot
.51545 .59607 Mdot
.50556 .58306 Mdot
.57501 .66925 Mdot
.39245 .52396 Mdot
.65842 .41899 Mdot
.20982 .35877 Mdot
.42545 .63838 Mdot
.63133 .43237 Mdot
.858 .56137 Mdot
.47361 .25488 Mdot
.32233 .44155 Mdot
.38169 .49302 Mdot
.54183 .59336 Mdot
.33374 .40427 Mdot
.51433 .62822 Mdot
.52677 .20314 Mdot
.53116 .64712 Mdot
.31377 .55731 Mdot
.57748 .6583 Mdot
.39335 .44835 Mdot
.38119 .39936 Mdot
.54275 .58344 Mdot
.51946 .64154 Mdot
.81655 .54271 Mdot
.66037 .40316 Mdot
.67102 .47103 Mdot
.30312 .37976 Mdot
.33703 .57289 Mdot
.49864 .34565 Mdot
.544 .62768 Mdot
.41284 .40179 Mdot
.38325 .40048 Mdot
.6437 .42029 Mdot
.3543 .40248 Mdot
.53292 .33284 Mdot
.54453 .64155 Mdot
.5075 .35911 Mdot
.31411 .58853 Mdot
.66331 .41924 Mdot
.50733 .6236 Mdot
.57279 .61366 Mdot
.67686 .4628 Mdot
.52345 .68113 Mdot
.33594 .54666 Mdot
.39662 .42042 Mdot
.67309 .43994 Mdot
.53992 .34753 Mdot
.35657 .42467 Mdot
.49666 .6321 Mdot
.60048 .17653 Mdot
.57384 .59818 Mdot
.5321 .59381 Mdot
.49605 .8299 Mdot
.58105 .63572 Mdot
.38119 .39452 Mdot
.66345 .48376 Mdot
.46621 .61423 Mdot
.4047 .66434 Mdot
.43292 .88225 Mdot
.36034 .45224 Mdot
.56161 .66343 Mdot
.49473 .80185 Mdot
.55947 .66152 Mdot
.65498 .68053 Mdot
.32897 .42953 Mdot
.5547 .45126 Mdot
.56499 .68286 Mdot
.54838 .34087 Mdot
.3809 .44166 Mdot
.35855 .4131 Mdot
.31777 .2772 Mdot
.53869 .66876 Mdot
.43231 .49 Mdot
.51365 .65349 Mdot
.5425 .34671 Mdot
.49968 .73971 Mdot
.3801 .39683 Mdot
.78012 .35145 Mdot
.54641 .60326 Mdot
.65595 .42512 Mdot
.38995 .45869 Mdot
.54991 .38925 Mdot
.49941 .62102 Mdot
.31927 .54687 Mdot
.56048 .32909 Mdot
.60147 .60068 Mdot
.52612 .33629 Mdot
.49882 .62813 Mdot
.4785 .68762 Mdot
.70643 .28023 Mdot
.68792 .45996 Mdot
.53566 .31593 Mdot
.43027 .5179 Mdot
.5129 .66447 Mdot
.6724 .44171 Mdot
.65891 .44803 Mdot
.30908 .5864 Mdot
.53191 .47457 Mdot
.66498 .28741 Mdot
.68283 .69388 Mdot
.29946 .28929 Mdot
.37557 .46042 Mdot
.41292 .33224 Mdot
.52875 .60043 Mdot
.41258 .5722 Mdot
.55888 .34147 Mdot
.57613 .60166 Mdot
.76743 .52739 Mdot
.62594 .46052 Mdot
.57441 .60401 Mdot
.32473 .56125 Mdot
.37217 .59177 Mdot
.29383 .62039 Mdot
.36804 .7633 Mdot
.37285 .43272 Mdot
.56181 .55152 Mdot
.46213 .61651 Mdot
.38578 .38852 Mdot
.49236 .60279 Mdot
.37968 .38952 Mdot
.20442 .4102 Mdot
.30088 .55257 Mdot
.66281 .42291 Mdot
.55376 .27614 Mdot
.48691 .63495 Mdot
.54767 .57185 Mdot
.35571 .55375 Mdot
.56268 .62151 Mdot
.65019 .22888 Mdot
.39102 .52831 Mdot
.35084 .42501 Mdot
.68989 .45407 Mdot
.50039 .59107 Mdot
.47209 .50376 Mdot
.56223 .65368 Mdot
.73304 .66226 Mdot
.54792 .5793 Mdot
.69694 .32318 Mdot
.68618 .4566 Mdot
.51906 .3315 Mdot
.53547 .68527 Mdot
.53077 .6385 Mdot
.4405 .7224 Mdot
.47899 .63848 Mdot
.52521 .67728 Mdot
.69902 .47006 Mdot
.69011 .46134 Mdot
.68413 .43687 Mdot
.36264 .44993 Mdot
.54978 .7774 Mdot
.52045 .3451 Mdot
.47045 .65761 Mdot
.54152 .37979 Mdot
.64536 .62466 Mdot
.29683 .56856 Mdot
.41849 .76635 Mdot
.53558 .61594 Mdot
.64118 .474 Mdot
.24294 .65675 Mdot
.65244 .40825 Mdot
.47697 .47221 Mdot
.53547 .36095 Mdot
.63017 .44184 Mdot
.53086 .63042 Mdot
.68339 .38652 Mdot
.52062 .81355 Mdot
.51235 .34054 Mdot
.47995 .61601 Mdot
.39036 .45268 Mdot
.29506 .43199 Mdot
.73533 .29842 Mdot
.52095 .31826 Mdot
.57733 .37603 Mdot
.542 .67091 Mdot
.63651 .48016 Mdot
.5461 .34181 Mdot
.4982 .32259 Mdot
.35125 .40602 Mdot
.51298 .61851 Mdot
.51447 .6141 Mdot
.34053 .42033 Mdot
.51344 .35141 Mdot
.57792 .57054 Mdot
.59701 .58072 Mdot
.68914 .78117 Mdot
.71694 .33983 Mdot
.47935 .87488 Mdot
.56547 .50967 Mdot
.74791 .51654 Mdot
.24766 .69769 Mdot
.64091 .42695 Mdot
.54861 .67772 Mdot
.58995 .68039 Mdot
.36187 .44457 Mdot
.54385 .65456 Mdot
.31999 .41389 Mdot
.5479 .36271 Mdot
.76271 .69989 Mdot
.6363 .33567 Mdot
.18222 .47594 Mdot
.54233 .656 Mdot
.67201 .50316 Mdot
.31584 .577 Mdot
.58624 .33906 Mdot
.67122 .4209 Mdot
.58492 .66132 Mdot
.81517 .53937 Mdot
.37187 .45593 Mdot
.64955 .43644 Mdot
.83079 .57337 Mdot
.58592 .4808 Mdot
.5076 .64887 Mdot
.34863 .44525 Mdot
.27826 .72819 Mdot
.7391 .45242 Mdot
.51199 .37037 Mdot
.3095 .56309 Mdot
.39218 .44045 Mdot
.54558 .319 Mdot
.65201 .51294 Mdot
.64135 .4394 Mdot
.67585 .41633 Mdot
.80354 .48984 Mdot
.35149 .45972 Mdot
.31869 .57715 Mdot
.48486 .76538 Mdot
.46147 .73087 Mdot
.31875 .55497 Mdot
.40151 .4423 Mdot
.68461 .47117 Mdot
.62844 .45303 Mdot
.66232 .47005 Mdot
.80147 .4356 Mdot
.63923 .49088 Mdot
.33272 .24921 Mdot
.56817 .67579 Mdot
.57428 .54518 Mdot
.55884 .66549 Mdot
.51793 .36905 Mdot
.67826 .45682 Mdot
.50022 .40121 Mdot
.47798 .60415 Mdot
.41422 .7512 Mdot
.56969 .58929 Mdot
.49411 .30962 Mdot
.5696 .60104 Mdot
.5185 .18327 Mdot
.62602 .47362 Mdot
.54632 .64868 Mdot
.50352 .30327 Mdot
.34121 .57166 Mdot
.65805 .50108 Mdot
.50928 .62782 Mdot
.26591 .36439 Mdot
.57835 .64746 Mdot
.19313 .45634 Mdot
.67333 .27036 Mdot
.29751 .57603 Mdot
.57827 .21328 Mdot
.42229 .4122 Mdot
.54069 .53421 Mdot
.4912 .68506 Mdot
.51177 .33496 Mdot
.57999 .31034 Mdot
.38099 .42801 Mdot
.6179 .69407 Mdot
.58224 .56637 Mdot
.31101 .58867 Mdot
.67481 .5172 Mdot
.5182 .36336 Mdot
.49634 .59451 Mdot
.53761 .55799 Mdot
.40745 .22281 Mdot
.59219 .58921 Mdot
.5279 .57659 Mdot
.35288 .5425 Mdot
.35957 .2284 Mdot
.56047 .64545 Mdot
.48171 .47533 Mdot
.65303 .40418 Mdot
.4777 .59713 Mdot
.33951 .24023 Mdot
.52891 .58665 Mdot
.64105 .43418 Mdot
.52235 .52993 Mdot
.64181 .27192 Mdot
.34973 .54718 Mdot
.54838 .57891 Mdot
.41913 .18416 Mdot
.55571 .60804 Mdot
.52497 .34982 Mdot
.57292 .57913 Mdot
.36308 .42115 Mdot
.82053 .48052 Mdot
.34932 .43501 Mdot
.57537 .59134 Mdot
.65993 .46766 Mdot
.50477 .34215 Mdot
.78118 .42114 Mdot
.25997 .4559 Mdot
.40075 .21104 Mdot
.19132 .61724 Mdot
.35184 .55764 Mdot
.29053 .58755 Mdot
.54176 .36896 Mdot
.54818 .64874 Mdot
.27585 .27528 Mdot
.48377 .65724 Mdot
.57476 .62288 Mdot
.53015 .6463 Mdot
.37167 .73 Mdot
.55651 .35277 Mdot
.37459 .40227 Mdot
.5569 .59193 Mdot
.51388 .66405 Mdot
.64758 .42643 Mdot
.34015 .56489 Mdot
.3898 .39252 Mdot
.33416 .56136 Mdot
.38519 .44021 Mdot
.81002 .63749 Mdot
.56526 .56068 Mdot
.34221 .57394 Mdot
.56588 .35716 Mdot
.64454 .43026 Mdot
.55674 .24512 Mdot
.3557 .41849 Mdot
.35595 .4446 Mdot
.54313 .58101 Mdot
.63432 .43523 Mdot
.69022 .41228 Mdot
.32632 .5849 Mdot
.52436 .32376 Mdot
.51988 .65054 Mdot
.57393 .65468 Mdot
.45968 .65988 Mdot
.40069 .39211 Mdot
.58129 .23414 Mdot
.36718 .3399 Mdot
.54984 .64622 Mdot
.66042 .48935 Mdot
.52326 .64542 Mdot
.20245 .53864 Mdot
.63362 .47856 Mdot
.52366 .58862 Mdot
.86709 .51412 Mdot
.31181 .431 Mdot
.62112 .2854 Mdot
.51503 .58402 Mdot
.24412 .7204 Mdot
.53186 .60672 Mdot
.77253 .69593 Mdot
.23853 .59132 Mdot
.56229 .57248 Mdot
.49875 .61854 Mdot
.69323 .6318 Mdot
.56723 .662 Mdot
.34062 .42776 Mdot
.71796 .72944 Mdot
.66197 .4089 Mdot
.5476 .2567 Mdot
.77327 .49259 Mdot
.34399 .54336 Mdot
.36994 .44247 Mdot
.37329 .47048 Mdot
.32696 .5546 Mdot
.65202 .46376 Mdot
.55622 .6382 Mdot
.47053 .43173 Mdot
.40199 .39695 Mdot
.61872 .65574 Mdot
.52703 .35228 Mdot
.40564 .27575 Mdot
.39419 .579 Mdot
.52951 .33589 Mdot
.50589 .62002 Mdot
.6822 .62817 Mdot
.7831 .61991 Mdot
.39604 .81648 Mdot
.53633 .3107 Mdot
.51014 .33973 Mdot
.81538 .45302 Mdot
.33295 .59512 Mdot
.40682 .22644 Mdot
.69558 .32568 Mdot
.50087 .34362 Mdot
.62805 .51328 Mdot
.33697 .42224 Mdot
.46164 .35644 Mdot
.49609 .56274 Mdot
.56644 .6729 Mdot
.53122 .6329 Mdot
.51348 .32181 Mdot
.53687 .51303 Mdot
.75049 .35404 Mdot
.5077 .33029 Mdot
.54662 .70717 Mdot
.53016 .44585 Mdot
.46043 .30318 Mdot
.35891 .39514 Mdot
.35483 .5648 Mdot
.31937 .59928 Mdot
.66256 .42978 Mdot
.35475 .55854 Mdot
.36732 .60152 Mdot
.55712 .62544 Mdot
.5014 .32882 Mdot
.49221 .24014 Mdot
.54109 .35344 Mdot
.3295 .55834 Mdot
.34134 .58865 Mdot
.66231 .44539 Mdot
.66932 .47441 Mdot
.71271 .55613 Mdot
.39231 .60941 Mdot
.57346 .63569 Mdot
.26224 .56693 Mdot
.69473 .45272 Mdot
.61206 .56891 Mdot
.35553 .56232 Mdot
.33942 .57102 Mdot
.43117 .72399 Mdot
.53355 .61821 Mdot
.62668 .59083 Mdot
.5378 .62215 Mdot
.443 .65429 Mdot
.49507 .61701 Mdot
.35171 .40522 Mdot
.52603 .61263 Mdot
.43362 .73282 Mdot
.50724 .67377 Mdot
.53201 .5666 Mdot
.41298 .40874 Mdot
.5872 .56636 Mdot
.36473 .42072 Mdot
.58086 .60845 Mdot
.29092 .57483 Mdot
.36931 .44408 Mdot
.39246 .67227 Mdot
.41118 .71647 Mdot
.40702 .43664 Mdot
.30062 .56706 Mdot
.32551 .53807 Mdot
.36007 .68211 Mdot
.67042 .42003 Mdot
.51795 .70316 Mdot
.54735 .65158 Mdot
.34272 .44687 Mdot
.55331 .33494 Mdot
.49485 .62767 Mdot
.52891 .57345 Mdot
.5089 .59289 Mdot
.66146 .42805 Mdot
.2669 .42068 Mdot
.34386 .57519 Mdot
.33924 .42224 Mdot
.53319 .49783 Mdot
.38416 .38497 Mdot
.52144 .561 Mdot
.58153 .68748 Mdot
.76993 .50991 Mdot
.47529 .28357 Mdot
.80385 .42129 Mdot
.6433 .4393 Mdot
.40288 .40944 Mdot
.30293 .59232 Mdot
.5599 .69713 Mdot
.64094 .47552 Mdot
.36166 .41914 Mdot
.55474 .64289 Mdot
.48263 .61402 Mdot
.52784 .23083 Mdot
.30436 .6276 Mdot
.40339 .69944 Mdot
.37172 .45142 Mdot
.40977 .44089 Mdot
.40091 .72562 Mdot
.28321 .60235 Mdot
.5151 .39896 Mdot
.54479 .66569 Mdot
.32128 .54702 Mdot
.66095 .48317 Mdot
.79487 .51354 Mdot
.49128 .33503 Mdot
.72737 .38269 Mdot
.54186 .65409 Mdot
.57262 .472 Mdot
.66076 .46612 Mdot
.32239 .5597 Mdot
.50901 .32178 Mdot
.34202 .60104 Mdot
.40856 .41165 Mdot
.16613 .53798 Mdot
.56092 .61206 Mdot
.54661 .58114 Mdot
.50698 .3078 Mdot
.63232 .46992 Mdot
.32411 .5345 Mdot
.28448 .30932 Mdot
.35628 .4084 Mdot
.28663 .26306 Mdot
.65583 .48921 Mdot
.62804 .73158 Mdot
.34665 .40059 Mdot
.55345 .37643 Mdot
.36966 .67444 Mdot
.52742 .33061 Mdot
.56888 .58395 Mdot
.64198 .46878 Mdot
.54078 .31962 Mdot
.7329 .36783 Mdot
.53554 .82976 Mdot
.63401 .72957 Mdot
.55295 .62901 Mdot
.61204 .80284 Mdot
.22056 .4062 Mdot
.61244 .41264 Mdot
.55407 .33051 Mdot
.5751 .59806 Mdot
.5487 .57572 Mdot
.55755 .60745 Mdot
.55293 .3403 Mdot
.26661 .55997 Mdot
.36874 .40559 Mdot
.55054 .67122 Mdot
.34057 .5874 Mdot
.37089 .42474 Mdot
.53872 .38402 Mdot
.36562 .39353 Mdot
.68988 .47752 Mdot
.50685 .56951 Mdot
.59127 .37868 Mdot
.89494 .46459 Mdot
.51218 .34625 Mdot
.41474 .40199 Mdot
.5816 .5834 Mdot
.44052 .27042 Mdot
.68997 .43154 Mdot
.35357 .40953 Mdot
.56035 .58632 Mdot
.50262 .25553 Mdot
.81273 .51405 Mdot
.37223 .39338 Mdot
.64185 .4773 Mdot
.40235 .81507 Mdot
.54841 .658 Mdot
.54143 .61023 Mdot
.63403 .44215 Mdot
.63155 .54328 Mdot
.83742 .513 Mdot
.52081 .64249 Mdot
.51752 .32999 Mdot
.15502 .46985 Mdot
.53021 .57288 Mdot
.45495 .69031 Mdot
.37434 .44041 Mdot
.48669 .38148 Mdot
.62134 .25312 Mdot
.52455 .68715 Mdot
.35541 .26497 Mdot
.55297 .28006 Mdot
.53542 .78853 Mdot
.31807 .41199 Mdot
.23806 .43134 Mdot
.59861 .79127 Mdot
.48727 .30732 Mdot
.70094 .47993 Mdot
.32341 .28401 Mdot
.7497 .46128 Mdot
.32554 .76701 Mdot
.22705 .51982 Mdot
.81646 .53741 Mdot
.48494 .42863 Mdot
.39774 .43028 Mdot
.60258 .53799 Mdot
.51258 .62919 Mdot
.21805 .41273 Mdot
.70969 .29322 Mdot
.72764 .31616 Mdot
.61283 .80365 Mdot
.65157 .69505 Mdot
.50067 .80406 Mdot
.47286 .80936 Mdot
.47944 .70972 Mdot
.39954 .34031 Mdot
.27413 .27075 Mdot
.77676 .66024 Mdot
.24184 .34083 Mdot
.57868 .5472 Mdot
.46585 .47226 Mdot
.18631 .52208 Mdot
.69899 .49865 Mdot
.63038 .52325 Mdot
.3443 .4258 Mdot
.67335 .41926 Mdot
.38836 .23901 Mdot
.61923 .43294 Mdot
.63906 .26831 Mdot
.42959 .83029 Mdot
.52644 .82742 Mdot
.43784 .18628 Mdot
.25051 .719 Mdot
.76049 .52657 Mdot
.24523 .26066 Mdot
.33097 .3944 Mdot
.64097 .42222 Mdot
.35752 .71627 Mdot
.45592 .74866 Mdot
.61452 .34977 Mdot
.28279 .32967 Mdot
.29511 .45823 Mdot
.31945 .64924 Mdot
.64546 .46407 Mdot
.59096 .22347 Mdot
.47032 .35667 Mdot
.63046 .33961 Mdot
.74924 .69214 Mdot
.39937 .79783 Mdot
.46016 .43746 Mdot
.31509 .3126 Mdot
.41017 .29526 Mdot
.76299 .3622 Mdot
.41187 .64175 Mdot
.59416 .5225 Mdot
.70821 .32943 Mdot
.22609 .65722 Mdot
.69513 .52991 Mdot
.44224 .64385 Mdot
.46674 .7515 Mdot
.82431 .61059 Mdot
.20655 .46658 Mdot
.82752 .36861 Mdot
.61801 .4313 Mdot
.51311 .58223 Mdot
.64862 .56728 Mdot
.38233 .19392 Mdot
.36291 .55122 Mdot
.35338 .75764 Mdot
.34723 .57857 Mdot
.69502 .46601 Mdot
.82623 .50293 Mdot
.35118 .2318 Mdot
.32346 .22224 Mdot
.29073 .58186 Mdot
.46973 .65797 Mdot
.24786 .76705 Mdot
.48174 .78058 Mdot
.62388 .30988 Mdot
.69646 .77334 Mdot
.54288 .43325 Mdot
.7247 .32682 Mdot
.54281 .32049 Mdot
.63291 .78471 Mdot
.63199 .45549 Mdot
.82947 .34753 Mdot
.78606 .68026 Mdot
.78325 .52767 Mdot
.79576 .7563 Mdot
.38643 .72807 Mdot
.55923 .45427 Mdot
.56087 .30454 Mdot
.3769 .64166 Mdot
.75737 .39174 Mdot
.28507 .67325 Mdot
.43159 .2776 Mdot
.23671 .71893 Mdot
.58613 .79855 Mdot
.30169 .24133 Mdot
.17098 .47265 Mdot
.71218 .5078 Mdot
.47954 .49974 Mdot
.53195 .72213 Mdot
.29842 .41714 Mdot
.33794 .75579 Mdot
.8378 .59689 Mdot
.42598 .6422 Mdot
.4259 .88055 Mdot
.28314 .55694 Mdot
.28777 .48109 Mdot
.47495 .85408 Mdot
.33218 .65706 Mdot
.62732 .2435 Mdot
.53399 .76657 Mdot
.57217 .72442 Mdot
.47934 .5153 Mdot
.35293 .76294 Mdot
.58643 .25767 Mdot
.68816 .75601 Mdot
.27769 .74275 Mdot
.41281 .22163 Mdot
.70762 .65627 Mdot
.46248 .71847 Mdot
.62882 .49849 Mdot
.36263 .61518 Mdot
.63177 .25519 Mdot
.55978 .82993 Mdot
.47899 .31754 Mdot
.59333 .8302 Mdot
.83564 .52068 Mdot
.56688 .5602 Mdot
.52864 .70364 Mdot
.59861 .50798 Mdot
.3486 .62361 Mdot
.56946 .54957 Mdot
.4973 .21885 Mdot
.51658 .83053 Mdot
.76187 .63999 Mdot
.52473 .25988 Mdot
.57088 .29509 Mdot
.47406 .85988 Mdot
.67474 .58733 Mdot
.28206 .59547 Mdot
.69057 .74102 Mdot
.76105 .39126 Mdot
.38005 .42186 Mdot
.31185 .2389 Mdot
.57489 .36294 Mdot
.80469 .51699 Mdot
.67945 .69438 Mdot
.74968 .49166 Mdot
.51729 .83135 Mdot
.25633 .40945 Mdot
.82564 .51972 Mdot
.31014 .67164 Mdot
.25375 .30986 Mdot
.46558 .29732 Mdot
.6019 .65123 Mdot
.27626 .33973 Mdot
.32532 .54026 Mdot
.71461 .59066 Mdot
.1723 .41064 Mdot
.24988 .51411 Mdot
.5981 .63477 Mdot
.78578 .52283 Mdot
.34837 .47059 Mdot
.67877 .38425 Mdot
.77012 .29846 Mdot
.51802 .57057 Mdot
.48618 .76008 Mdot
.24192 .406 Mdot
.38074 .62706 Mdot
.33835 .79492 Mdot
.2081 .58325 Mdot
.84972 .39372 Mdot
.65516 .78759 Mdot
.2548 .44997 Mdot
.57939 .78902 Mdot
.58193 .81163 Mdot
.84795 .4017 Mdot
.49461 .68123 Mdot
.48103 .3307 Mdot
.56413 .15127 Mdot
.35851 .39389 Mdot
.46467 .76188 Mdot
.29963 .28901 Mdot
.38645 .57517 Mdot
.59174 .39815 Mdot
.61727 .68768 Mdot
.4829 .43648 Mdot
.66243 .40209 Mdot
.57109 .55178 Mdot
.80836 .38363 Mdot
.86948 .44889 Mdot
.82219 .38099 Mdot
.19626 .60217 Mdot
.63726 .77947 Mdot
.56025 .47715 Mdot
.40841 .19405 Mdot
.61553 .58612 Mdot
.54039 .68059 Mdot
.37322 .56969 Mdot
.37986 .72613 Mdot
.79009 .49689 Mdot
.66038 .34236 Mdot
.68699 .51234 Mdot
.35128 .75831 Mdot
.09685 .52097 Mdot
.73116 .55168 Mdot
.30979 .26457 Mdot
.30237 .60365 Mdot
.38568 .61345 Mdot
.29731 .72262 Mdot
.78088 .47542 Mdot
.48476 .82174 Mdot
.66457 .40276 Mdot
.26247 .32761 Mdot
.24422 .54101 Mdot
.7118 .46223 Mdot
.26712 .42476 Mdot
.47268 .78844 Mdot
.57822 .2948 Mdot
.77777 .45159 Mdot
.68839 .33285 Mdot
.65753 .5587 Mdot
.37629 .52052 Mdot
.39088 .29246 Mdot
.20947 .35735 Mdot
.21033 .52737 Mdot
.45458 .6855 Mdot
.52136 .44635 Mdot
.55767 .20214 Mdot
.52236 .27028 Mdot
.43892 .65008 Mdot
.56008 .41178 Mdot
.51579 .76618 Mdot
.81965 .28309 Mdot
.78318 .34087 Mdot
.42512 .83793 Mdot
.25821 .6376 Mdot
.6008 .61093 Mdot
.47156 .82596 Mdot
.80899 .33564 Mdot
.87212 .54351 Mdot
.36575 .30112 Mdot
.32939 .39163 Mdot
.54868 .37916 Mdot
.82 .42318 Mdot
.29504 .52412 Mdot
.44144 .80957 Mdot
.44112 .68155 Mdot
.5606 .36365 Mdot
.47673 .13876 Mdot
.81101 .62494 Mdot
.66196 .71476 Mdot
.31672 .62571 Mdot
.58158 .68049 Mdot
.6049 .21268 Mdot
.63046 .42317 Mdot
.43037 .32211 Mdot
.39853 .61008 Mdot
.38618 .41423 Mdot
.33302 .72088 Mdot
.26378 .34354 Mdot
.57728 .65913 Mdot
.44869 .51 Mdot
.64026 .49673 Mdot
.46608 .29041 Mdot
.59086 .29106 Mdot
.87651 .51511 Mdot
.33913 .60475 Mdot
.57172 .67857 Mdot
.38955 .6298 Mdot
.27737 .41115 Mdot
.842 .48976 Mdot
.54986 .36751 Mdot
.56256 .80322 Mdot
.45605 .45731 Mdot
.37975 .60831 Mdot
.74733 .43422 Mdot
.59419 .54581 Mdot
.54362 .56467 Mdot
.22174 .63218 Mdot
.76261 .62766 Mdot
.71715 .40938 Mdot
.48113 .58015 Mdot
.62067 .63288 Mdot
.46487 .82501 Mdot
.36829 .59718 Mdot
.40691 .28253 Mdot
.55049 .81064 Mdot
.55071 .35351 Mdot
.63404 .48418 Mdot
.27194 .56468 Mdot
.23247 .35329 Mdot
.62201 .75019 Mdot
.8129 .51248 Mdot
.40266 .56461 Mdot
.25813 .50463 Mdot
.55005 .81977 Mdot
.54323 .79761 Mdot
.53286 .17337 Mdot
.60394 .45659 Mdot
.43457 .59032 Mdot
.2234 .35645 Mdot
.69292 .43049 Mdot
.38835 .22058 Mdot
.42711 .21392 Mdot
.78847 .66601 Mdot
.43835 .51117 Mdot
.2444 .7322 Mdot
.40265 .69519 Mdot
.31812 .73016 Mdot
.78192 .41525 Mdot
.24426 .32943 Mdot
.44447 .76629 Mdot
.61919 .40783 Mdot
.68633 .65163 Mdot
.60138 .58967 Mdot
.50001 .18992 Mdot
.56585 .15967 Mdot
.28854 .54097 Mdot
.57292 .42668 Mdot
.28401 .75177 Mdot
.56487 .6276 Mdot
.7559 .2931 Mdot
.26245 .33835 Mdot
.81095 .4462 Mdot
.5572 .36996 Mdot
.5033 .63642 Mdot
.48718 .65079 Mdot
.62474 .76919 Mdot
.63141 .26705 Mdot
.52954 .7709 Mdot
.16067 .46726 Mdot
.28995 .73774 Mdot
.69824 .50828 Mdot
.46624 .75942 Mdot
.40255 .80095 Mdot
.21921 .41626 Mdot
.52057 .46958 Mdot
.28538 .68135 Mdot
.35046 .66026 Mdot
.24019 .69303 Mdot
.57156 .40068 Mdot
.41211 .46853 Mdot
.5654 .27186 Mdot
.30609 .35831 Mdot
.79721 .4678 Mdot
.50557 .61272 Mdot
.83046 .57437 Mdot
.4529 .80127 Mdot
.5763 .19436 Mdot
.71585 .2829 Mdot
.78621 .34576 Mdot
.74186 .64153 Mdot
.2145 .46237 Mdot
.23505 .38265 Mdot
.19771 .35909 Mdot
.44972 .45964 Mdot
.39167 .74746 Mdot
.32589 .66399 Mdot
.55031 .81623 Mdot
.5047 .30978 Mdot
.68114 .3121 Mdot
.53904 .26233 Mdot
.5603 .78442 Mdot
.67913 .59879 Mdot
.47938 .80067 Mdot
.52751 .42374 Mdot
.85286 .39282 Mdot
.21469 .56583 Mdot
.49658 .42478 Mdot
.40768 .41999 Mdot
.23254 .45109 Mdot
.39382 .77511 Mdot
.22046 .57311 Mdot
.26289 .30606 Mdot
.31328 .4281 Mdot
.52338 .5054 Mdot
.62998 .7126 Mdot
.36052 .614 Mdot
.21925 .63242 Mdot
.38862 .62972 Mdot
.51422 .82314 Mdot
.64549 .77018 Mdot
.83033 .57069 Mdot
.39387 .73331 Mdot
.18602 .60553 Mdot
.62335 .30623 Mdot
.32997 .61927 Mdot
.26335 .34007 Mdot
.29473 .49688 Mdot
.64511 .40021 Mdot
.51831 .09403 Mdot
.17061 .53258 Mdot
.21123 .50385 Mdot
.8334 .60275 Mdot
.20492 .58987 Mdot
.47189 .28363 Mdot
.64558 .53558 Mdot
.72324 .36011 Mdot
.81033 .59444 Mdot
.53067 .64531 Mdot
.80485 .36015 Mdot
.41488 .5868 Mdot
.88563 .46749 Mdot
.44365 .81914 Mdot
.57331 .41947 Mdot
.50981 .56733 Mdot
.33949 .4333 Mdot
.42904 .48605 Mdot
.5071 .74015 Mdot
.6563 .60577 Mdot
.66428 .26209 Mdot
.50627 .27161 Mdot
.33414 .39283 Mdot
.29789 .38779 Mdot
.63265 .40488 Mdot
.25944 .62538 Mdot
.33553 .34592 Mdot
.37269 .36981 Mdot
.45278 .43549 Mdot
.41918 .62157 Mdot
.61251 .24638 Mdot
.65385 .72272 Mdot
.78432 .47526 Mdot
.6011 .36057 Mdot
.34646 .40834 Mdot
.67972 .70449 Mdot
.18215 .52996 Mdot
.27811 .73255 Mdot
.83791 .59362 Mdot
.47653 .51382 Mdot
.66313 .6366 Mdot
.47308 .71367 Mdot
.74238 .33064 Mdot
.59582 .46879 Mdot
.49001 .2837 Mdot
.60394 .21479 Mdot
.61045 .51171 Mdot
.34145 .27797 Mdot
.76527 .69758 Mdot
.24777 .33701 Mdot
.22152 .35696 Mdot
.35794 .51069 Mdot
.4571 .60609 Mdot
.70122 .46954 Mdot
.39592 .68051 Mdot
.53788 .39969 Mdot
.31473 .21145 Mdot
.47299 .6051 Mdot
.28599 .20878 Mdot
.5008 .31865 Mdot
.73146 .48015 Mdot
.34509 .66469 Mdot
.53036 .45213 Mdot
.53779 .4187 Mdot
.20939 .54327 Mdot
.69045 .31266 Mdot
.21327 .4481 Mdot
.74791 .35559 Mdot
.32802 .39785 Mdot
.14915 .5085 Mdot
.19125 .6401 Mdot
.6972 .65085 Mdot
.5858 .62522 Mdot
.16939 .55897 Mdot
.3455 .38291 Mdot
.78746 .48917 Mdot
.34439 .79806 Mdot
.25266 .67086 Mdot
.62832 .7002 Mdot
.38127 .61162 Mdot
.39867 .75068 Mdot
.62951 .80543 Mdot
.56541 .17189 Mdot
.34313 .75359 Mdot
.50654 .30995 Mdot
.52632 .43192 Mdot
.44166 .78188 Mdot
.70309 .30154 Mdot
.46916 .33444 Mdot
.65153 .2575 Mdot
.21763 .27681 Mdot
.47227 .76836 Mdot
.50686 .75886 Mdot
.69771 .28807 Mdot
.68365 .47875 Mdot
.68102 .29298 Mdot
.62411 .24229 Mdot
.23807 .6301 Mdot
.18645 .47789 Mdot
.62514 .24665 Mdot
.20645 .32897 Mdot
.57294 .52577 Mdot
.44283 .37133 Mdot
.62385 .58882 Mdot
.53884 .74964 Mdot
.56326 .34176 Mdot
.77127 .65526 Mdot
.30972 .75773 Mdot
.48249 .34312 Mdot
.23066 .64844 Mdot
.30789 .31959 Mdot
.54973 .74073 Mdot
.63876 .74518 Mdot
.27722 .70945 Mdot
.67699 .61825 Mdot
.49867 .17905 Mdot
.79347 .53281 Mdot
.35239 .37786 Mdot
.3494 .78471 Mdot
.35228 .42197 Mdot
.61652 .66755 Mdot
.73249 .38736 Mdot
.29056 .68058 Mdot
.80845 .42955 Mdot
.33861 .54155 Mdot
.64591 .4168 Mdot
.56841 .16443 Mdot
.66735 .48446 Mdot
.8139 .3891 Mdot
.75635 .48628 Mdot
.63657 .23244 Mdot
.25036 .46019 Mdot
.23791 .49589 Mdot
.20526 .30319 Mdot
.47936 .36452 Mdot
.33418 .37466 Mdot
.47077 .19674 Mdot
.63743 .42216 Mdot
.3573 .51206 Mdot
.40737 .43215 Mdot
.44408 .42176 Mdot
.41536 .23124 Mdot
.5661 .52557 Mdot
.63191 .50556 Mdot
.44315 .43555 Mdot
.71817 .71325 Mdot
.70882 .74936 Mdot
.38704 .39429 Mdot
.34036 .18179 Mdot
.522 .56381 Mdot
.71313 .64385 Mdot
.49414 .82669 Mdot
.47079 .13904 Mdot
.36501 .35388 Mdot
.20781 .6786 Mdot
.54112 .69006 Mdot
.27679 .68961 Mdot
.6374 .45597 Mdot
.25505 .33419 Mdot
.32838 .58752 Mdot
.37437 .62963 Mdot
.48666 .33511 Mdot
.7767 .44982 Mdot
.3481 .35344 Mdot
.68061 .41825 Mdot
.25282 .63834 Mdot
.47748 .70673 Mdot
.52597 .29543 Mdot
.25577 .42527 Mdot
.69407 .65951 Mdot
.58576 .75228 Mdot
.6633 .51736 Mdot
.49535 .75502 Mdot
.19393 .38992 Mdot
.87952 .51452 Mdot
.65187 .38646 Mdot
.5861 .48688 Mdot
.4671 .217 Mdot
.25017 .68177 Mdot
.52727 .20915 Mdot
.51565 .83509 Mdot
.42296 .61126 Mdot
.47807 .54494 Mdot
.43643 .63607 Mdot
.61116 .60122 Mdot
.49938 .45519 Mdot
.4143 .30391 Mdot
.68363 .26378 Mdot
.58999 .24174 Mdot
.67761 .5342 Mdot
.5212 .1936 Mdot
.47951 .73668 Mdot
.6405 .23821 Mdot
.38504 .37557 Mdot
.59294 .74764 Mdot
.58358 .33531 Mdot
.71132 .75012 Mdot
.50858 .83193 Mdot
.54161 .38298 Mdot
.29219 .4133 Mdot
.27848 .75839 Mdot
.4894 .66804 Mdot
.53951 .4908 Mdot
.55064 .58131 Mdot
.46 .53172 Mdot
.43221 .14467 Mdot
.24349 .6575 Mdot
.59557 .62123 Mdot
.56193 .79553 Mdot
.59525 .79438 Mdot
.86849 .42318 Mdot
.26217 .28592 Mdot
.66556 .44537 Mdot
.84782 .41914 Mdot
.65401 .2553 Mdot
.61785 .80896 Mdot
.45197 .31378 Mdot
.54374 .85628 Mdot
.68907 .64513 Mdot
.25033 .69673 Mdot
.638 .5306 Mdot
.70893 .33963 Mdot
.25585 .39365 Mdot
.53819 .48544 Mdot
.42774 .25794 Mdot
.19956 .54633 Mdot
.13931 .49511 Mdot
.60837 .62859 Mdot
.27164 .35386 Mdot
.61026 .36854 Mdot
.36726 .79854 Mdot
.22463 .54955 Mdot
.58493 .60384 Mdot
.56704 .28814 Mdot
.79981 .44223 Mdot
.423 .62685 Mdot
.58233 .50368 Mdot
.22041 .53496 Mdot
.80651 .58019 Mdot
.48372 .72356 Mdot
.22644 .35133 Mdot
.69088 .65765 Mdot
.446 .47413 Mdot
.51086 .66208 Mdot
.61064 .47439 Mdot
.29312 .54822 Mdot
.51624 .48855 Mdot
.58021 .6179 Mdot
.40564 .44906 Mdot
.46848 .31497 Mdot
.79958 .38223 Mdot
.59562 .26792 Mdot
.2243 .37864 Mdot
.67133 .50926 Mdot
.65804 .36306 Mdot
.51768 .20937 Mdot
.77767 .34571 Mdot
.25 .55976 Mdot
.4256 .64202 Mdot
.5043 .79837 Mdot
.64826 .77172 Mdot
.726 .45414 Mdot
.87009 .50005 Mdot
.55724 .33716 Mdot
.57331 .74343 Mdot
.68011 .35083 Mdot
.32333 .37838 Mdot
.52436 .54515 Mdot
.24981 .69443 Mdot
.38302 .58393 Mdot
.44276 .7398 Mdot
.20249 .47539 Mdot
.47924 .53389 Mdot
.65159 .70583 Mdot
.56192 .80033 Mdot
.35542 .4507 Mdot
.20118 .40095 Mdot
.55465 .30658 Mdot
.22406 .53168 Mdot
.64841 .775 Mdot
.81522 .6266 Mdot
.50325 .40863 Mdot
.35443 .65168 Mdot
.54203 .60538 Mdot
.21329 .35593 Mdot
.2401 .6537 Mdot
.56429 .73237 Mdot
.38532 .28116 Mdot
.63872 .48709 Mdot
.37314 .31657 Mdot
.45885 .47457 Mdot
.80183 .60328 Mdot
.62513 .48522 Mdot
.61631 .21718 Mdot
.28939 .56555 Mdot
.564 .44835 Mdot
.4905 .55986 Mdot
.36784 .64821 Mdot
.27255 .25633 Mdot
.47614 .58638 Mdot
.35321 .76632 Mdot
.68792 .68357 Mdot
.28216 .3121 Mdot
.27221 .696 Mdot
.48584 .27066 Mdot
.6932 .31506 Mdot
.60851 .74822 Mdot
.54796 .25886 Mdot
.51661 .58538 Mdot
.34058 .37928 Mdot
.68468 .42501 Mdot
.35212 .79232 Mdot
.73966 .65053 Mdot
.38962 .67171 Mdot
.39279 .52383 Mdot
.58567 .51154 Mdot
.5708 .3178 Mdot
.52818 .84965 Mdot
.70005 .32175 Mdot
.40621 .61291 Mdot
.43959 .51086 Mdot
.35347 .66447 Mdot
.73091 .51053 Mdot
.80501 .65878 Mdot
.64883 .53293 Mdot
.46755 .42132 Mdot
.73468 .47385 Mdot
.20962 .48394 Mdot
.33458 .79611 Mdot
.44047 .64066 Mdot
.55887 .43201 Mdot
.33918 .53561 Mdot
.51938 .22409 Mdot
.37976 .51482 Mdot
.56179 .50077 Mdot
.43381 .4493 Mdot
.3931 .25771 Mdot
.65957 .37534 Mdot
.5035 .71053 Mdot
.40966 .73694 Mdot
.52244 .79955 Mdot
.28757 .29867 Mdot
.51815 .2732 Mdot
.41304 .34283 Mdot
.77156 .64384 Mdot
.56015 .86278 Mdot
.64423 .20923 Mdot
.54495 .60642 Mdot
.54902 .28465 Mdot
.33976 .64462 Mdot
.38641 .45004 Mdot
.59801 .23438 Mdot
.5422 .22691 Mdot
.52178 .3139 Mdot
.38182 .60107 Mdot
.45909 .73818 Mdot
.28623 .37234 Mdot
.30272 .63417 Mdot
.58472 .32348 Mdot
.79362 .36601 Mdot
.18579 .56917 Mdot
.25238 .68423 Mdot
.66876 .82706 Mdot
.5245 .28726 Mdot
.58986 .69728 Mdot
.68273 .57034 Mdot
.67173 .77134 Mdot
.39407 .63457 Mdot
.80031 .50556 Mdot
.46689 .25569 Mdot
.43848 .62937 Mdot
.61736 .40198 Mdot
.43008 .74029 Mdot
.36615 .31536 Mdot
.50241 .44299 Mdot
.23871 .50388 Mdot
.87569 .50007 Mdot
.64095 .69737 Mdot
.50795 .80524 Mdot
.78978 .42214 Mdot
.19842 .35403 Mdot
.66544 .77675 Mdot
.40767 .7134 Mdot
.23625 .57597 Mdot
.65207 .57144 Mdot
.55821 .40941 Mdot
.71812 .48874 Mdot
.79028 .49146 Mdot
.68701 .72188 Mdot
.27674 .45444 Mdot
.7283 .49605 Mdot
.45347 .68365 Mdot
.70888 .70794 Mdot
.55941 .43041 Mdot
.65946 .72208 Mdot
.29481 .40582 Mdot
.68412 .27868 Mdot
.70567 .42014 Mdot
.40851 .66552 Mdot
.68804 .69169 Mdot
.44614 .21948 Mdot
.20697 .56941 Mdot
.16941 .38106 Mdot
.28733 .52693 Mdot
.77524 .35773 Mdot
.57357 .67193 Mdot
.87332 .39481 Mdot
.23266 .42418 Mdot
.25729 .40329 Mdot
.20019 .45989 Mdot
.40575 .46626 Mdot
.61858 .6264 Mdot
.51618 .58574 Mdot
.38675 .77418 Mdot
.6304 .69741 Mdot
.76592 .51922 Mdot
.77457 .43659 Mdot
.37479 .62074 Mdot
.43574 .67427 Mdot
.39826 .68725 Mdot
.50268 .53604 Mdot
.64579 .48562 Mdot
.8256 .38827 Mdot
.48596 .40306 Mdot
.56343 .73109 Mdot
.47067 .58297 Mdot
.65471 .55683 Mdot
.27508 .77913 Mdot
.57683 .4066 Mdot
.50891 .75428 Mdot
.66518 .6845 Mdot
.72465 .44022 Mdot
.53591 .20789 Mdot
.86595 .65396 Mdot
.89397 .40787 Mdot
.67196 .4144 Mdot
.31475 .25679 Mdot
.65773 .69094 Mdot
.53758 .77602 Mdot
.24871 .54167 Mdot
.37184 .27828 Mdot
.57218 .7371 Mdot
.72406 .39947 Mdot
.52271 .53999 Mdot
.23221 .41331 Mdot
.73181 .73695 Mdot
.76856 .43399 Mdot
.55881 .79527 Mdot
.60455 .57509 Mdot
.50671 .54895 Mdot
.63879 .8503 Mdot
.45229 .78417 Mdot
.49406 .58533 Mdot
.69053 .51565 Mdot
.49392 .69737 Mdot
.51632 .62795 Mdot
.30128 .70966 Mdot
.15052 .50534 Mdot
.48298 .72501 Mdot
.55832 .78387 Mdot
.61347 .45583 Mdot
.37354 .47358 Mdot
.49812 .31993 Mdot
.51387 .41122 Mdot
.47974 .60597 Mdot
.54516 .32575 Mdot
.44512 .55852 Mdot
.27934 .75234 Mdot
.39658 .51079 Mdot
.17264 .45009 Mdot
.60788 .83207 Mdot
.72763 .66163 Mdot
.53854 .23536 Mdot
.4935 .67345 Mdot
.58533 .75526 Mdot
.66518 .74627 Mdot
.54543 .50812 Mdot
.2173 .64844 Mdot
.61601 .13032 Mdot
.50239 .24072 Mdot
.79639 .62299 Mdot
.69643 .44222 Mdot
.42948 .47184 Mdot
.63739 .7206 Mdot
.45399 .32288 Mdot
.39604 .40189 Mdot
.59231 .55473 Mdot
.66334 .50105 Mdot
.56456 .36296 Mdot
.36072 .16398 Mdot
.58592 .6293 Mdot
.57071 .2249 Mdot
.59965 .8094 Mdot
.79386 .53136 Mdot
.70675 .61039 Mdot
.49038 .62913 Mdot
.62419 .3413 Mdot
.55808 .43335 Mdot
.34218 .7667 Mdot
.82323 .58913 Mdot
.51149 .78648 Mdot
.7377 .65464 Mdot
.65279 .70275 Mdot
.51291 .66312 Mdot
.33632 .59231 Mdot
.47937 .37792 Mdot
.35732 .75745 Mdot
.48731 .68554 Mdot
.66143 .79048 Mdot
.34493 .35224 Mdot
.443 .52141 Mdot
.57856 .42488 Mdot
.86417 .42366 Mdot
.69043 .54177 Mdot
.69008 .49467 Mdot
.78113 .34995 Mdot
.32338 .36754 Mdot
.33193 .62441 Mdot
.34145 .4394 Mdot
.49043 .67999 Mdot
.62863 .49541 Mdot
.76056 .29373 Mdot
.34868 .74177 Mdot
.43678 .25198 Mdot
.39331 .28788 Mdot
.32401 .26867 Mdot
.53288 .29784 Mdot
.68813 .81526 Mdot
.24374 .4425 Mdot
.77982 .32412 Mdot
.19428 .39448 Mdot
.64695 .50626 Mdot
.20859 .59673 Mdot
.48548 .57851 Mdot
.38867 .40046 Mdot
.53266 .78567 Mdot
.58486 .70936 Mdot
.82278 .51001 Mdot
.52209 .68016 Mdot
.82633 .45717 Mdot
.3287 .53132 Mdot
.29172 .4321 Mdot
.21451 .47165 Mdot
.66294 .55644 Mdot
.45668 .84244 Mdot
.50807 .21907 Mdot
.47668 .83622 Mdot
.4327 .83078 Mdot
.576 .8047 Mdot
.81182 .49086 Mdot
.52609 .15796 Mdot
.21274 .48752 Mdot
.27367 .70804 Mdot
.42465 .31835 Mdot
.63581 .54956 Mdot
.23114 .45232 Mdot
.60176 .5168 Mdot
.62982 .26805 Mdot
.57372 .30787 Mdot
.36197 .12139 Mdot
.43554 .69665 Mdot
.69362 .47925 Mdot
.23083 .46611 Mdot
.61591 .79929 Mdot
.65691 .56659 Mdot
.1975 .53668 Mdot
.46774 .47039 Mdot
.60061 .65927 Mdot
.68957 .71778 Mdot
.28887 .29235 Mdot
.27358 .39537 Mdot
.15493 .37063 Mdot
.18392 .53468 Mdot
.41286 .25639 Mdot
.48761 .45275 Mdot
.66717 .4137 Mdot
.48338 .1837 Mdot
.24318 .49185 Mdot
.2063 .63216 Mdot
.26051 .72284 Mdot
.44558 .78308 Mdot
.21128 .29754 Mdot
.26766 .32765 Mdot
.69455 .75915 Mdot
.21676 .61473 Mdot
.67559 .41453 Mdot
.39117 .70623 Mdot
.3612 .3785 Mdot
.42538 .27877 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0:Gooooo0_l0002Rooooo`007?ooool00ol0003oooooooooo`2Loooo
o`;o00001oooool2o`000:;ooooo000Looooo`;o0000Toooool2o`0000Sooooo0_l0002[ooooo`00
7?ooool00ol0003oooooooooo`2Booooo`;o0000]Oooool001cooooo00?o0000ooooooooool0Q?oo
ool2o`00013ooooo0_l0002aooooo`007?ooool00ol0003oooooooooo`24ooooo`;o00004?ooool2
o`0002kooooo0_l00021ooooo`007?ooool00ol0003oooooooooo`2;ooooo`;o0000>Oooool2o`00
087ooooo000Looooo`03o`000?oooooooooo08_ooooo0_l0002looooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo07;ooooo0_l0000Rooooo`;o0000/Ooo
ool001cooooo00?o0000ooooooooool0L_ooool2o`0001Cooooo0_l0000<ooooo`;o0000/Oooool0
01cooooo00?o0000ooooooooool0R?ooool2o`000;oooooo000Looooo`03o`000?oooooooooo09?o
oooo0_l0000Booooo`;o00006oooool2o`0008?ooooo000Looooo`03o`000?oooooooooo09?ooooo
0_l0000Booooo`;o00006oooool2o`0008?ooooo000Looooo`03o`000?oooooooooo08;ooooo0_l0
0035ooooo`007?ooool00ol0003oooooooooo`22ooooo`;o00004Oooool4o`000;3ooooo000Loooo
o`03o`000?oooooooooo09Gooooo1?l0002`ooooo`007?ooool00ol0003oooooooooo`29ooooo`;o
00005?ooool2o`0000Cooooo0_l0002Rooooo`007?ooool00ol0003oooooooooo`29ooooo`;o0000
5?ooool2o`0000;ooooo1?l0002Rooooo`007?ooool2o`000:Cooooo0_l0000>ooooo`;o0000U?oo
ool001cooooo00?o0000ooooooooool0Zoooool2o`0000Kooooo0_l0002Dooooo`007?ooool00ol0
003oooooooooo`2Wooooo`;o00000_ooool2o`0000Oooooo0_l00005ooooo`;o0000S?ooool001co
oooo00?o0000ooooooooool0Yoooool2o`0000_ooooo0_l00005ooooo`;o0000S?ooool001cooooo
00?o0000ooooooooool0LOooool2o`0004;ooooo0_l0000:ooooo`;o0000Q_ooool001cooooo00?o
0000ooooooooool0LOooool2o`0002Oooooo0_l0000Iooooo`;o00002_ooool2o`0008Kooooo000L
ooooo`03o`000?oooooooooo08oooooo0_l00009ooooo`Ko00004?ooool2o`0000;ooooo0_l0002C
ooooo`007?ooool00ol0003oooooooooo`2?ooooo`Co00002Oooool4o`0000Wooooo0ol00004oooo
o`;o00000_ooool2o`0009?ooooo000Looooo`03o`000?oooooooooo097ooooo0_l0000>ooooo`;o
00001_ooool3o`0001?ooooo0_l00028ooooo`007?ooool00ol0003oooooooooo`1fooooo`;o0000
4?ooool2o`0001Cooooo0_l000000ooooooo0000o`00000Looooo`;o0000R?ooool001cooooo00?o
0000ooooooooool0Joooool2o`0000Wooooo0_l0000<ooooo`;o00000_ooool2o`0000oooooo0_l0
0003ooooo`?o00001?ooool4o`00027ooooo0_l0001mooooo`007?ooool00ol0003oooooooooo`1U
ooooo`;o00001?ooool2o`0001Oooooo0_l00004ooooo`;o00003Oooool2o`0000Cooooo0_l00000
1?oooooo0000o`000?ooool4o`00027ooooo0_l0001mooooo`007?ooool00ol0003oooooooooo`1U
ooooo`;o00007Oooool2o`0000Cooooo0_l00009ooooo`;o00002?ooool2o`000003ooooool0003o
00000:Gooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_oo
ool00ol0003oooooooooo`1aooooo`;o00001Oooool2o`0000[ooooo0_l00004ooooo`;o00001Ooo
ool2o`0000;ooooo0_l00008ooooo`;o00001Oooool2o`0000Sooooo0_l0000Mooooo`;o0000N?oo
ool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A006ooooo`03o`000?oooooooooo077ooooo0_l00005ooooo`;o000000?oooooo`000?l0
00001?ooool2o`0000Oooooo0_l00005ooooo`;o00000_ooool2o`0000Gooooo0_l00008ooooo`;o
00002?ooool2o`0000?ooooo1Ol0000Eooooo`;o0000N?ooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo07Sooooo
0_l000000ooooooo0000o`000002ooooo`Co000000?oooooo`000?l000003oooool2o`0000Gooooo
1?l0000Eooooo`Go00004_ooool2o`0007_ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oo
oooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`00077ooooo0_l0000<ooooo`;o00000ooo
ool2o`0000Cooooo0_l0000Booooo`?o00001_ooool2o`000003ooooool0003o000000Gooooo0_l0
000Iooooo`;o0000Noooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool0
0omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo05oooooo0_l0000:ooooo`;o00001?ooool2
o`0001Oooooo0_l0000Cooooo`;o00001_ooool2o`000003ooooool0003o000000;o00000oooool2
o`0002;ooooo0_l0001booooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0=oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0FOooool2o`0000Cooooo0_l0000:oooo
o`?o0000>Oooool7o`0000Cooooo0_l00008ooooo`;o00002?ooool3o`0000;ooooo1?l00006oooo
o`;o00001?ooool2o`0006cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000
okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo05Wooooo0_l00008ooooo`;o00001ooo
ool2o`0000gooooo0_l000000ooooooo0000o`000008ooooo`?o00001oooool2o`0000Oooooo0ol0
0006ooooo`;o00000_ooool4o`0000Cooooo1?l00007ooooo`?o00002?ooool3o`0000;ooooo1?l0
000<ooooo`;o0000K?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@
o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0Hoooool2o`0000[ooooo0_l00007ooooo`;o
000000Coooooo`000?l0003ooooo0_l00004ooooo`;o000000?oooooo`000?l000000_l00007oooo
o`;o00001oooool4o`0000Gooooo0_l0000:ooooo`;o00001_ooool2o`000003ooooool0003o0000
00?ooooo0ol0000Jooooo`;o0000J_ooool001cooooo00?o0000ooooooooool0Koooool2o`0000Go
oooo1?l0000:ooooo`;o000000?oooooo`000?l000002oooool2o`0000Oooooo0_l0000Iooooo`Co
00001?ooool3o`000004ooooool0003o0000o`0001Kooooo0_l0001Zooooo`007?ooool00ol0003o
ooooooooo`1_ooooo`;o00001Oooool2o`0000;ooooo0_l00007ooooo`;o00002?ooool2o`0000Go
oooo0_l00008ooooo`;o000000?oooooo`000?l000004oooool2o`000004ooooool0003o0000o`00
00Sooooo0ol00022ooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o00004oooool2o`0000Go
oooo1?l00008ooooo`;o00003oooool2o`000003ooooool0003o000000;ooooo0_l0000?ooooo`;o
000000Coooooo`000?l0003ooooo0ol00003ooooo`;o0000QOooool001cooooo00?o0000oooooooo
ool0H?ooool2o`0000?ooooo0_l0000Iooooo`Co00002oooool2o`0001Cooooo0_l00004ooooo`?o
00002?ooool4o`0000;ooooo0ol00003ooooo`?o0000Q?ooool001cooooo00?o0000ooooooooool0
H?ooool2o`0000oooooo0_l0000;ooooo`Ko00002oooool2o`0001Oooooo0_l000001?oooooo0000
o`000?l00002ooooo`;o00001?ooool4o`0000Wooooo0_l00009ooooo`?o0000N?ooool001cooooo
00?o0000ooooooooool0K_ooool2o`000003ooooool0003o000000_ooooo0_l00002ooooo`?o0000
6oooool2o`0000Kooooo0_l00002ooooo`Ko000000?oooooo`000?l000005_ooool2o`000005oooo
ool0003o0000o`000?ooool00_l0001eooooo`007?ooool00ol0003oooooooooo`1^ooooo`;o0000
4oooool2o`00013ooooo0_l00003ooooo`;o00001?ooool2o`0000Wooooo1Ol00003ooooo`;o0000
1?ooool2o`0000?ooooo0_l0000;ooooo`;o00000_ooool2o`000003ooooool0003o000007Gooooo
000Looooo`03o`000?oooooooooo05cooooo0_l00004ooooo`;o00000_ooool3o`00017ooooo0_l0
000Eooooo`;o00000_ooool2o`000003ooooool0003o000000Co00003?ooool3o`0000Cooooo0_l0
0006ooooo`;o00000oooool2o`0000cooooo0_l0001kooooo`007?ooool00ol0003oooooooooo`1H
ooooo`;o00000_ooool4o`0000;ooooo1ol00002ooooo`;o00003Oooool2o`0001Gooooo0_l00005
ooooo`Wo00000oooool2o`0000Cooooo0_l00003ooooo`Co00002Oooool2o`0000Wooooo0_l00003
ooooo`;o0000Noooool001cooooo00?o0000ooooooooool0EOooool2o`000004ooooool0003o0000
ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Gooooo0_l0000Jooooo`;o00000oooool4
o`0000Gooooo0_l00005ooooo`Ko00000_ooool2o`0000Wooooo1?l00009ooooo`;o00002Oooool3
o`0000;ooooo0_l0001kooooo`007?ooool00ol0003oooooooooo`1Eooooo`;o00001?ooool2o`00
00_ooooo0_l0000Mooooo`;o00000oooool4o`0000Gooooo0_l00004ooooo`;o00000oooool3o`00
00kooooo0ol0000?ooooo`;o00000_ooool3o`0000;ooooo0_l00002ooooo`;o00007?ooool2o`00
05Wooooo000Looooo`;o0000E?ooool2o`0001?ooooo0_l0000<ooooo`;o00004_ooool4o`0000Oo
oooo0_l00004ooooo`;o00000oooool3o`000003ooooool0003o000000cooooo0_l0000?ooooo`?o
000000?oooooo`000?l000001oooool2o`0000Sooooo0_l0000Booooo`;o0000FOooool001cooooo
00?o0000ooooooooool0Doooool2o`0000cooooo0_l00007ooooo`;o00002?ooool4o`00017ooooo
0ol0000:ooooo`;o00003?ooool2o`0000Oooooo0_l0000;ooooo`;o000000?oooooo`000?l00000
1Oooool4o`000004ooooool0003o0000ooooo`?o00000_ooool2o`0000Oooooo0_l0001]ooooo`00
7?ooool00ol0003oooooooooo`1Eooooo`;o00002_ooool4o`0000Gooooo0_l00008ooooo`;o0000
1_ooool2o`0000Cooooo0ol00002ooooo`Co00002?ooool5o`0000Gooooo0_l000000ooooooo0000
o`000006ooooo`;o00000oooool6o`0000Cooooo0_l000000ooooooo0000o`000003o`0000Oooooo
0_l000001?oooooo0000o`000?ooool3o`000004ooooool0003o0000o`0002;ooooo0_l0001Boooo
o`007?ooool00ol0003oooooooooo`1<ooooo`;o00001oooool2o`0000cooooo0_l0000Gooooo`Co
00000_ooool3o`0000;ooooo0_l0000:ooooo`?o00001?ooool2o`000004ooooool0003o0000oooo
o`;o00001Oooool3o`0000Cooooo1Ol00004ooooo`;o00000_ooool2o`0000Kooooo0_l0000;oooo
o`;o00008oooool2o`0005;ooooo000Looooo`03o`000?oooooooooo04cooooo0_l0000;ooooo`;o
00001_ooool2o`0000Kooooo0_l0000Cooooo`;o00006Oooool3o`0000_ooooo0_l00002ooooo`;o
000000?oooooo`000?l000000oooool2o`0000kooooo0_l0000?ooooo`;o00001?ooool2o`0006go
oooo000Looooo`03o`000?oooooooooo053ooooo0_l00007ooooo`;o00001_ooool2o`0000Kooooo
0_l00004ooooo`?o00004Oooool4o`0001;ooooo0_l00009ooooo`;o000000Coooooo`000?l0003o
oooo0ol00006ooooo`;o00003?ooool2o`0000Kooooo0_l00009ooooo`;o00001?ooool2o`0000Co
oooo0_l0001Wooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00000oooool2o`0000Kooooo
0_l00002ooooo`;o00000oooool2o`0000Oooooo0ol0000Aooooo`Co00001?ooool2o`0000Oooooo
0_l00003ooooo`?o00002?ooool5o`000003ooooool0003o000000;ooooo0_l0000=ooooo`?o0000
00?oooooo`000?l000001_ooool2o`000003ooooool0003o000000Wooooo0_l00007ooooo`;o0000
Ioooool001cooooo00?o0000ooooooooool0EOooool2o`0000Kooooo0_l00002ooooo`;o00000ooo
ool2o`0001;ooooo0_l0000<ooooo`Go000000?oooooo`000?l000001?ooool2o`0000Cooooo0_l0
0005ooooo`;o00000_ooool4o`000004ooooool0003o0000ooooo`?o00001?ooool2o`0000;ooooo
0_l00003ooooo`Go00001oooool2o`000004ooooool0003o0000o`0000Sooooo0_l0001`ooooo`00
7?ooool00ol0003oooooooooo`13ooooo`;o00004Oooool2o`0000Oooooo0_l00003ooooo`;o0000
1?ooool3o`0000Cooooo0_l00007ooooo`;o00001?ooool2o`000003ooooool0003o000000;ooooo
1Ol00002ooooo`;o00004Oooool2o`000003ooooool0003o000000?o000000Coooooo`000?l0003o
oooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool2o`0000Kooooo0_l0000;ooooo`;o
000000?oooooo`000?l00000Moooool001cooooo00?o0000ooooooooool0@oooool2o`00017ooooo
0_l00007ooooo`;o00000_ooool3o`000004ooooool0003o0000ooooo`?o00001?ooool2o`0000;o
oooo1?l00004ooooo`;o000000Coooooo`000?l0003ooooo1ol000000ooooooo0000o`00000;oooo
o`;o00002_ooool3o`0000Wooooo0_l00004ooooo`;o00001_ooool2o`00013ooooo0_l00008oooo
o`;o0000KOooool001cooooo00?o0000ooooooooool0Hoooool2o`0000;ooooo1_l00008ooooo`Ko
00000_ooool2o`000003ooooool0003o000000?ooooo1Ol000000ooooooo0000o`00000;ooooo`;o
00002oooool2o`0000Cooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l00006oooo
o`;o00006_ooool2o`0000Kooooo0_l000000ooooooo0000o`000008ooooo`;o00005Oooool2o`00
047ooooo000Looooo`03o`000?oooooooooo057ooooo0_l00003ooooo`;o00001Oooool2o`0000Ko
oooo0_l00002ooooo`;o00003_ooool2o`0000Gooooo0_l00005ooooo`;o00003Oooool3o`0000;o
oooo0_l0000>ooooo`;o00000_ooool2o`0000;ooooo0_l0000Aooooo`;o00006_ooool2o`000003
ooooool0003o000000Sooooo0_l0000Eooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0
Coooool4o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o0000
5Oooool2o`0000Sooooo1?l0000<ooooo`Oo00002_ooool2o`0000Kooooo0_l00003ooooo`;o0000
2Oooool2o`0000Gooooo0_l0000;ooooo`?o00002Oooool2o`0006Sooooo000Looooo`03o`000?oo
oooooooo04oooooo0_l00004ooooo`;o00000oooool2o`0000;ooooo0ol0000Jooooo`?o00002?oo
ool4o`000003ooooool0003o000000Oooooo0_l00003ooooo`;o00001_ooool2o`0000Cooooo0_l0
000;ooooo`;o00001_ooool2o`000003ooooool0003o000001;ooooo0ol00009ooooo`;o00001Ooo
ool2o`0000Sooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`1Cooooo`Co00000oooool2
o`0001Kooooo0_l00003ooooo`;o00000_ooool2o`0000Cooooo0_l00008ooooo`;o000000?ooooo
o`000?l000000oooool3o`0000;ooooo1?l00005ooooo`;o00000_ooool4o`0000Cooooo0ol00003
ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o000000?oooooo`000?l000005oooool3
o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l000002?ooool5o`0005Cooooo000Loooo
o`03o`000?oooooooooo047ooooo0ol0000?ooooo`;o00004?ooool2o`000003ooooool0003o0000
00?ooooo0_l00003ooooo`;o00000oooool2o`0000Sooooo0_l0000;ooooo`;o00000oooool2o`00
00?ooooo1?l00009ooooo`Ko00000_ooool3o`0000?ooooo0_l000000ooooooo0000o`000002o`00
00?ooooo1?l0000Fooooo`Co00001?ooool2o`000004ooooool0003o0000o`0000Kooooo0_l00005
ooooo`?o000000?oooooo`000?l00000DOooool001cooooo0_l00012ooooo`?o00005Oooool3o`00
00Wooooo0_l000000ooooooo0000o`000003ooooo`;o00001?ooool3o`0000?ooooo0_l0000<oooo
o`;o00001Oooool2o`0000?ooooo0_l00009ooooo`Co00001_ooool3o`0000Sooooo0ol00002oooo
o`;o00000oooool2o`0001Sooooo0_l00008ooooo`?o00001oooool2o`0000Wooooo0_l0001Aoooo
o`007?ooool00ol0003oooooooooo`0gooooo`;o00001_ooool2o`0001Sooooo0ol0000Gooooo`?o
00000oooool2o`0000Sooooo0_l00002ooooo`;o00001Oooool2o`0000;ooooo1?l00008ooooo`Co
00001_ooool2o`0000Sooooo1?l00002ooooo`;o00009oooool2o`0006Kooooo000Looooo`03o`00
0?oooooooooo03Oooooo0_l00006ooooo`;o00004Oooool2o`0000Kooooo0_l0000=ooooo`;o0000
0oooool2o`0000Oooooo0_l0000:ooooo`Co00002oooool4o`0000?ooooo1?l00002ooooo`Go0000
0_ooool7o`0000?ooooo1?l00004ooooo`?o00000oooool2o`0000Cooooo1Ol0000Dooooo`?o0000
00?oooooo`000?l000003oooool2o`0005Gooooo000Looooo`03o`000?oooooooooo04oooooo0_l0
00000ooooooo0000o`000005ooooo`?o00003Oooool4o`000003ooooool0003o000000Oooooo0_l0
000;ooooo`?o00004_oooolDo`0000?ooooo0_l00005ooooo`Co00000oooool2o`0000Cooooo1Ol0
000Dooooo`?o00000oooool2o`0000gooooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`1?
ooooo`;o00001oooool3o`0000Sooooo0_l00003ooooo`;o000000?oooooo`000?l000000oooool2
o`0001;ooooo0_l00009ooooo`;o00002?oooolEo`0000Wooooo1?l0000<ooooo`;o00004?ooool2
o`000003ooooool0003o000000Gooooo0_l00008ooooo`;o0000F_ooool001cooooo00?o0000oooo
ooooool0F?ooool2o`0000Wooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l000001?oo
oooo0000o`000?ooool4o`0001Sooooo0_l00003ooooo`Go00000ooooolCo`0000oooooo0_l0000I
ooooo`Ko00002_ooool2o`0000;ooooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`1?oooo
o`;o00003oooool2o`0000Wooooo1?l00004ooooo`Co00002?ooool6o`000003ooooool0003o0000
00cooooo1_l00002oooooaCo00001_ooool2o`0000Kooooo0_l0000Aooooo`;o00001oooool5o`00
00[ooooo0_l00002ooooo`;o0000F_ooool001cooooo00?o0000ooooooooool0COooool4o`0000oo
oooo0_l0000Mooooo`Ko000000?oooooo`000?l000000_l00006ooooo`;o000000?oooooo`000?l0
00000ooooolHo`0000?ooooo0_l000000ooooooo0000o`000009ooooo`;o000000?oooooo`000?l0
00001_ooool2o`0000?ooooo0ol00006ooooo`Co000000Coooooo`000?l0003o0000Ioooool001co
oooo00?o0000ooooooooool0COooool2o`0001gooooo0ol0000Gooooo`Co00001_ooool2o`000003
ooooool0003o000000;ooooo6Ol00003ooooo`;o00001Oooool2o`0000Gooooo0_l000000ooooooo
0000o`000006ooooo`;o00001?ooool2o`0000;ooooo0_l00004ooooo`Ko00005oooool2o`0000Wo
oooo0_l00013ooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00004Oooool3o`0000cooooo
0_l00009ooooo`?o00005?ooool2o`0000;ooooo0_l0000:ooooo`;o000000?oooooo`000?l00000
4Ol000000ooooooo0000o`000008o`0000Kooooo0_l00005ooooo`;o00002Oooool2o`0000Sooooo
0_l00002ooooo`;o000000Coooooo`000?l0003o00001Oooool2o`000003ooooool0003o000000oo
oooo0_l00009ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0?oooool2o`0000_ooooo
0_l00004ooooo`Go000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000Wooooo
0_l00009ooooo`;o00002Oooool7o`0000Gooooo0_l00005oooooaSo000000?oooooo`000?l00000
1?l00002ooooo`;o00000oooool2o`0000oooooo0ol0000;ooooo`;o00001_ooool2o`000004oooo
ool0003o0000ooooo`;o00000oooool2o`0005[ooooo000Looooo`03o`000?oooooooooo04cooooo
0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000001?ooool2o`0000[ooooo
1?l00008ooooo`?o00002Oooool2o`000003ooooool0003o000000Oooooo0_l00002ooooo`;o0000
00Coooooo`000?l0003ooooo3ol000000ooooooo0000o`000008o`0000Cooooo0_l00002ooooo`?o
00004?ooool2o`0000gooooo2?l00006ooooo`;o000000?oooooo`000?l00000F_ooool001cooooo
00?o0000ooooooooool0??ooool2o`0000_ooooo0_l00002ooooo`Co000000?oooooo`000?l00000
3_ooool2o`0000Kooooo1?l00008ooooo`;o00001Oooool2o`0000Sooooo0_l00003ooooo`;o0000
1?ooool5o`0000?ooooo6Ol00007ooooo`;o00000_ooool2o`0000Cooooo0_l00002ooooo`;o0000
00?oooooo`000?l000000oooool2o`0000[ooooo1_l00008ooooo`;o00000_ooool2o`0001?ooooo
0_l00014ooooo`007?ooool00ol0003oooooooooo`0looooo`;o00002oooool6o`0000?ooooo0_l0
0002ooooo`;o000000?oooooo`000?l000001oooool2o`0000Oooooo0ol00006ooooo`;o00001ooo
ool3o`0000Oooooo0_l00003ooooo`;o00001Oooool4o`0000?ooooo6_l00007ooooo`;o000000?o
ooooo`000?l000001?ooool2o`000003ooooool0003o000000Co00000oooool2o`0000_ooooo0_l0
0003ooooo`;o000000Coooooo`000?l0003o00001_ooool2o`0000_ooooo0_l00006ooooo`;o0000
A?ooool001cooooo00?o0000ooooooooool0Boooool4o`0000?ooooo0_l00002ooooo`;o000000?o
ooooo`000?l000003_ooool4o`0000Oooooo0_l00008ooooo`;o00000_ooool4o`0000gooooo8_l0
0006ooooo`;o000000?oooooo`000?l000001_ooool6o`0000Oooooo0_l0000=ooooo`;o000000Co
ooooo`000?l0003o00004oooool2o`0004cooooo000Looooo`03o`000?oooooooooo04?ooooo0_l0
000=ooooo`Go00004_ooool2o`0000Wooooo0_l0000<ooooo`Co00003OoooolRo`0000Wooooo0_l0
0006ooooo`;o000000?oooooo`000?l000002?ooool2o`0001Oooooo0_l0000;ooooo`;o000000?o
ooooo`000?l000003?ooool2o`0003gooooo000Looooo`;o0000A?ooool2o`0000oooooo0ol0000B
ooooo`;o00000_ooool2o`0000Gooooo0_l0000Nooooo`;o00001?ooool@o`0000;ooooo2_l00002
ooooo`;o00001?ooool2o`0000Cooooo0_l0000Cooooo`;o00003?ooool2o`0000?ooooo0_l0000;
ooooo`Go00003?ooool2o`0003gooooo000Looooo`03o`000?oooooooooo03gooooo1?l00002oooo
o`;o000000?oooooo`000?l000000_l0000;ooooo`;o00004_ooool2o`000004ooooool0003o0000
o`0000Cooooo0_l00008ooooo`;o00002_ooool2o`0000oooooo7?l000001?oooooo0000o`000?l0
0003ooooo`;o00001Oooool2o`0001?ooooo0_l00003ooooo`Co00000_ooool2o`000003ooooool0
003o000000Oooooo0_l00008ooooo`;o000000?oooooo`000?l00000B_ooool001cooooo00?o0000
ooooooooool0?Oooool4o`000003ooooool0003o000000Oo00002_ooool2o`000003ooooool0003o
000000oooooo0_l000001?oooooo0000o`000?l00004ooooo`;o00000_ooool2o`0000Cooooo0_l0
0007ooooo`;o000000?oooooo`000?l000001oooool2o`000003ooooool0003o000000?ooooo7?l0
00000ooooooo0000o`000004ooooo`;o00007oooool4o`000004ooooool0003o0000o`0000Wooooo
0ol00008ooooo`;o000000?oooooo`000?l00000B_ooool001cooooo00?o0000ooooooooool0?Ooo
ool2o`000003ooooool0003o000000Go00000_ooool5o`0000?ooooo0ol00004ooooo`;o00001?oo
ool4o`0000?ooooo0ol0000?ooooo`;o00003Oooool3o`0000Gooooo0_l00002ooooo`;o000000?o
ooooo`000?l000001oooool2o`000003ooooool0003o000001?o0000:_ooool2o`000003ooooool0
003o000000;ooooo0_l00006ooooo`;o00001oooool4o`0000Kooooo0_l00015ooooo`007?ooool0
0ol0003oooooooooo`0^ooooo`;o00003Oooool2o`000004ooooool0003o0000o`0000Sooooo0ol0
0003ooooo`?o00000_ooool2o`0000Kooooo1?l00003ooooo`?o00007oooool2o`0000Gooooo0_l0
000?oooooaOo000000?oooooo`000?l000001_ooool2o`0000?ooooo0_l00006ooooo`;o00001?oo
ool2o`0000Kooooo0_l00007ooooo`;o00000_ooool2o`0000_ooooo0_l00002ooooo`Co00001?oo
ool4o`0004Gooooo000Looooo`03o`000?oooooooooo02kooooo0_l0000Aooooo`;o00001?ooool2
o`0000;ooooo0_l00003ooooo`Go000000?oooooo`000?l000001?ooool2o`0002cooooo0_l0000<
ooooo`?o00001?oooolJo`0000Kooooo0_l00003ooooo`Co00001?ooool2o`0000Cooooo0_l00006
ooooo`;o00001oooool2o`0000Oooooo0_l00006ooooo`;o00001?ooool2o`0000;ooooo1?l00017
ooooo`007?ooool00ol0003oooooooooo`17ooooo`;o00001oooool2o`000003ooooool0003o0000
00Oooooo0_l00003ooooo`;o00000_ooool2o`0000cooooo0_l0000Eooooo`;o00003?ooool3o`00
00Cooooo0ol000000ooooooo0000o`00000@o`000004ooooool0003o0000o`0000Wooooo1_l0000R
ooooo`Co00001Oooool2o`0000Cooooo0_l00003ooooo`;o00002Oooool2o`0003kooooo000Loooo
o`03o`000?oooooooooo02oooooo0_l0000Xooooo`?o00001Oooool2o`0000;ooooo0_l0000<oooo
o`Co00005Oooool2o`00017ooooo0_l00002oooooa3o00001?ooool3o`0000;ooooo0_l00002oooo
o`Co00005oooool2o`0000gooooo0_l00007ooooo`?o00000oooool2o`0000kooooo1?l0000loooo
o`007?ooool00ol0003oooooooooo`0_ooooo`;o0000:?ooool3o`0000gooooo0ol00007ooooo`Co
00000_ooool2o`00017ooooo0_l0000>ooooo`;o00001OoooolAo`0000Cooooo0_l00002ooooo`;o
00000_ooool2o`0000kooooo1?l00007ooooo`;o00001_ooool2o`0000kooooo0ol0000Eooooo`;o
0000??ooool001cooooo00?o0000ooooooooool0AOooool2o`0001kooooo0_l000000ooooooo0000
o`000002o`0000?ooooo0_l000000ooooooo0000o`000005ooooo`;o00006_ooool2o`000003oooo
ool0003o000000;ooooo0_l00007ooooo`oo000000Coooooo`000?l0003ooooo1_l00003ooooo`;o
00003Oooool4o`000003ooooool0003o000000;o00002_ooool2o`0000;ooooo0ol0001Oooooo`00
7?ooool00ol0003oooooooooo`0cooooo`;o00004?ooool2o`0001Sooooo0_l00004ooooo`;o0000
00?oooooo`000?l000000ol00002ooooo`;o000000Coooooo`000?l0003ooooo1Ol00007ooooo`;o
00003Oooool4o`000004ooooool0003o0000ooooo`Co00002Oooool2o`000003ooooool0003o0000
00So000000?oooooo`000?l000000_l000000ooooooo0000o`000004o`0000?ooooo0_l0000>oooo
o`;o00000_ooool4o`0000Oooooo0_l00005ooooo`Co00004?ooool2o`0000[ooooo0_l00010oooo
o`007?ooool00ol0003oooooooooo`0cooooo`;o00005?ooool2o`0000Wooooo1?l00007ooooo`;o
00001_oooolEo`0000Gooooo1Ol0000:ooooo`Co00001_ooool2o`0000[ooooo1?l000000ooooooo
0000o`000005o`000004ooooool0003o0000o`0000?ooooo0_l00003ooooo`;o00006Oooool2o`00
00Gooooo1?l00003ooooo`Co00004?ooool2o`0000?ooooo0_l000000ooooooo0000o`000002oooo
o`;o0000@?ooool001cooooo00?o0000ooooooooool0A_ooool2o`000003ooooool0003o000000Oo
oooo1_l00005ooooo`Co00001_ooool4o`000003ooooool0003o0000013o00000oooool5o`0001_o
oooo1?l000000ooooooo0000o`000003ooooo`Oo00000_ooool2o`000003ooooool0003o000000Go
oooo0_l00009ooooo`;o00001Oooool2o`0000Oooooo1?l00004ooooo`?o000000?oooooo`000?l0
00001Ol00007ooooo`;o00002oooool2o`000003ooooool0003o000004Cooooo000Looooo`03o`00
0?oooooooooo03_ooooo0_l00009ooooo`;o00002_ooool2o`0000;ooooo0_l00005ooooo`;o0000
1?ooool2o`0000Gooooo5_l0000Oooooo`Ko00001_ooool2o`000003ooooool0003o000000;o0000
1Oooool3o`000003ooooool0003o000000[ooooo1?l00005ooooo`;o00002?ooool3o`0000Cooooo
0ol000000ooooooo0000o`000002o`000003ooooool0003o000000Oooooo0_l0000@ooooo`;o0000
00?oooooo`000?l00000?oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Ko
oooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo03_ooooo0_l000000ooooooo
0000o`00000?ooooo`;o00000_ooool2o`000003ooooool0003o000000_ooooo0_l00002oooooa_o
000000?oooooo`000?l000001_ooool2o`0001;ooooo0_l000000ooooooo0000o`000007ooooo`;o
00000_ooool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000002_ooool2o`0000oo
oooo1?l00003ooooo`;o00004Oooool3o`00013ooooo0_l000000ooooooo0000o`000006ooooo`?o
0000=_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0kooooo`;o000000?oooooo`000?l000000oooool2o`00
00Oooooo0_l000000ooooooo0000o`000002ooooo`Co00000_ooool2o`0000;ooooo0_l00003oooo
o`;o00000ooooolNo`0000Kooooo0_l0000<ooooo`;o00001?ooool2o`000003ooooool0003o0000
00_ooooo0_l00002ooooo`;o000000?oooooo`000?l000000oooool2o`0000[ooooo0_l0000?oooo
o`;o000000?oooooo`000?l000000_ooool2o`0000Sooooo0_l00007ooooo`?o00002?ooool2o`00
017ooooo0ol00005ooooo`;o0000;oooool00003ooooool@413ooooo00;ooooo00?o410@oooooooo
ool02Oooool5o`0000Kooooo00?o0000ooooooooool0=_ooool2o`0000;ooooo0ol00006ooooo`;o
00001oooool2o`0000Oooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00000oooool2o`00
00?ooooo5ol000000ooooooo0000o`000004o`0000Wooooo0_l00006ooooo`;o000000?oooooo`00
0?l000001?ooool2o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000002Oooool2o`00
00?ooooo0ol00006ooooo`;o00001_ooool4o`0000_ooooo0_l000000ooooooo0000o`000007oooo
o`Co00000oooool2o`000003ooooool0003o000000Wooooo0ol0000Iooooo`;o0000;oooool00003
ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?m4A4CogMgMooooool00007oooo
o`?o0000=Oooool3o`0000;ooooo0_l00002ooooo`;o00001_ooool2o`0000Sooooo0_l00004oooo
o`Co00001oooool4o`0000;ooooo6_l000000ooooooo0000o`000003o`0000Oooooo0_l00006oooo
o`;o00000_ooool2o`0000?ooooo0_l00003ooooo`;o00000_ooool2o`000004ooooool0003o0000
ooooo`?o00001Oooool2o`0000Cooooo0_l00006ooooo`?o00001Oooool5o`0000;ooooo1Ol00002
ooooo`;o00000_ooool2o`000003ooooool0003o000000Cooooo0_l00005ooooo`;o000000?ooooo
o`000?l000000_l00002ooooo`;o00000oooool2o`0001;ooooo0_l0000gooooo`0000?oooooo`00
0?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000
ooooooooool0=Oooool2o`0000Oooooo0_l00004ooooo`Co00000oooool2o`0000?ooooo0_l00002
ooooo`Co00001?ooool2o`0000?ooooo1?l00002ooooo`_o000000?oooooo`000?l000004_l0000C
ooooo`;o00000oooool2o`000003ooooool0003o000000;o00000_ooool3o`0000?ooooo0ol00002
ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Kooooo0_l00003ooooo`So000000?ooooo
o`000?l000001?l000000ooooooo0000o`000003ooooo`Co000000?oooooo`000?l000003Oooool2
o`0000;ooooo0_l0000Gooooo`;o0000=oooool00003ooooool@413ooooo00;ooooo00?o410@oooo
ooooool02_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo04Cooooo0_l00005oooo
o`;o00000oooool2o`0000;ooooo1?l00004ooooo`;o00002OoooolNo`0001_ooooo1_l00003oooo
o`;o00001Oooool5o`0000?ooooo0_l00003ooooo`;o00001_ooool@o`0000;ooooo0_l00002oooo
o`?o000000Coooooo`000?l0003ooooo1Ol00002ooooo`;o0000=?ooool2o`0002Sooooo00001_oo
ooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l000001oooool00ol0003ooooooooo
o`0dooooo`;o00002Oooool2o`0000Sooooo0_l00005ooooo`;o00001?ooool2o`0000Kooooo0_l0
0004ooooo`;o00000ooooolNo`0001Wooooo1Ol0000;ooooo`Co00001?ooool2o`000003ooooool0
003o000000Sooooo2_l000000ooooooo0000o`000005o`000004ooooool0003o0000ooooo`?o0000
1?ooool5o`0000;ooooo0_l0000Cooooo`;o00007oooool2o`0002Sooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`0dooooo`;o
00002Oooool2o`0000;ooooo0_l00003ooooo`?o00001?ooool2o`0000?ooooo1?l00003ooooo`;o
000000?oooooo`000?l000000_ooool4o`0000?ooooo7ol0000Hooooo`Go00003Oooool4o`0000Go
oooo0_l00006ooooo`?o000000?oooooo`000?l000001ol000000ooooooo0000o`00000=o`0000Go
oooo0_l00003ooooo`;o00002_ooool2o`0000;ooooo0_l00002ooooo`;o00005?ooool2o`0003?o
oooo000Looooo`03o`000?oooooooooo03Cooooo0_l0000=ooooo`?o00000_ooool9o`0000?ooooo
0_l00005ooooo`Co00000oooool4o`0000?ooooo7ol0000Booooo`;o00001Oooool2o`0000Sooooo
0_l00004ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Gooooo0ol00002ooooo`;o0000
00?oooooo`000?l000004ol00005ooooo`;o00000oooool4o`0000;ooooo0_l00004ooooo`;o0000
0_ooool2o`0001Sooooo0_l0000cooooo`007?ooool00ol0003oooooooooo`0dooooo`;o00001_oo
ool2o`0000Kooooo0_l00004ooooo`Go00001?ooool4o`0000;ooooo0_l00002ooooo`;o00002Ooo
ool5o`000003ooooool0003o000000Oo00000_ooool?o`0000Gooooo0_l00005ooooo`;o00001?oo
ool2o`0000oooooo0_l00004ooooo`;o00000oooool2o`0000Cooooo0_l00009oooooago000000?o
ooooo`000?l000001Oooool2o`0000;ooooo0_l00008ooooo`;o00001Oooool2o`0000gooooo0_l0
000gooooo`007?ooool00ol0003oooooooooo`0looooo`;o00002_ooool2o`0000?ooooo0_l00004
ooooo`Co00000_ooool2o`0000;ooooo0_l00008oooooa3o000000?oooooo`000?l000003?l00007
ooooo`;o00001Oooool2o`0000Sooooo0_l00008ooooo`;o00001?ooool3o`0000Cooooo1Ol00002
ooooo`;o00002OoooolDo`0000;ooooo1ol000000ooooooo0000o`000005ooooo`;o00000oooool2
o`0000Gooooo1?l000001?oooooo0000o`000?ooool3o`0000Cooooo0_l00007ooooo`;o00000ooo
ool3o`00037ooooo000Looooo`03o`000?oooooooooo03cooooo0_l00009ooooo`?o00001Oooool2
o`0000;ooooo0_l00008ooooo`;o00002?oooolNo`0000kooooo0_l00009ooooo`;o00002?ooool2
o`0000Cooooo0ol00004ooooo`Go00000_ooool2o`0000Gooooo7ol000001?oooooo0000o`000?l0
0006ooooo`;o00000oooool2o`0000Gooooo0_l00003ooooo`Go00001Oooool2o`0000cooooo0ol0
000aooooo`007?ooool00ol0003oooooooooo`17ooooo`;o00001_ooool2o`00017ooooo0_l00000
0ooooooo0000o`00000Oo`0000;ooooo0_l00009ooooo`;o00001Oooool2o`0000Wooooo0_l00009
ooooo`Co00000_ooool2o`0000_ooooo7ol000001?oooooo0000o`000?l0000Iooooo`;o00000_oo
ool2o`0004Cooooo000Looooo`03o`000?oooooooooo03Cooooo0_l00007ooooo`;o00002oooool2
o`000003ooooool0003o000000cooooo0ol00004ooooo`;o000000?oooooo`000?l000007?l00000
0ooooooo0000o`000004o`0000_ooooo0_l00003ooooo`;o00002Oooool4o`0000Cooooo0_l00000
0ooooooo0000o`000002o`00013ooooo1?l000000ooooooo0000o`00000Go`0000;ooooo0_l00004
ooooo`;o00002_ooool2o`0000_ooooo0_l00008ooooo`;o0000>_ooool001cooooo00?o0000oooo
ooooool0=?ooool2o`0000?ooooo0ol000001?oooooo0000o`000?l0000:ooooo`;o000000?ooooo
o`000?l000001Oooool2o`0000Gooooo0ol00004ooooo`;o00001?oooolGo`000005ooooool0003o
0000o`000?ooool01?l00004ooooo`;o000000Coooooo`000?l0003ooooo1Ol00002ooooo`;o0000
3?ooool2o`0000Cooooo0_l00003ooooo`;o00004?oooolLo`0000[ooooo0_l00003ooooo`;o0000
1Oooool4o`0000;ooooo0_l00003ooooo`;o00002_ooool2o`0003[ooooo000Looooo`03o`000?oo
oooooooo03Wooooo0ol00002ooooo`;o00002Oooool2o`0000Wooooo0_l0000Boooooa_o000000?o
ooooo`000?l000001_ooool2o`000004ooooool0003o0000ooooo`Co00000oooool2o`0001Wooooo
0_l0000@oooooa[o00002?ooool2o`0000Gooooo0_l00007ooooo`;o00000_ooool4o`000003oooo
ool0003o000004Kooooo000Looooo`03o`000?oooooooooo04Wooooo1?l0000>ooooo`;o00002?oo
ool2o`0000;ooooo6_l0000?ooooo`;o00002oooool2o`0001?ooooo0_l0000?oooooa_o00002?oo
ool2o`0000Wooooo0_l00009ooooo`Co0000Aoooool001cooooo00?o0000ooooooooool0=oooool2
o`0000cooooo0_l00004ooooo`;o00003_ooool4o`0000Gooooo0ol00002oooooa[o00000oooool2
o`0001Oooooo0_l00005ooooo`Co00006oooool=o`000003ooooool0003o000000_o00002oooool2
o`0000Kooooo0_l0000;ooooo`;o00000_ooool2o`0001Gooooo0_l0000/ooooo`007?ooool00ol0
003oooooooooo`0gooooo`;o00002Oooool2o`000003ooooool0003o000000oooooo0_l00005oooo
o`;o00001Oooool3o`0000;ooooo3Ol000000ooooooo0000o`000006o`000003ooooool0003o0000
00Cooooo0_l000000ooooooo0000o`00000Kooooo`Co00002Oooool2o`0000?ooooo0_l00005oooo
o`;o00001?oooolJo`0000cooooo0_l000000ooooooo0000o`000003ooooo`;o00003oooool2o`00
00Oooooo0_l00008ooooo`;o00000_ooool2o`0002cooooo000Looooo`;o0000=Oooool2o`0000co
oooo0ol00002ooooo`?o00001Oooool2o`0000Gooooo0_l0000=ooooo`;o000000Goooooo`000?l0
003o0000ooooo`0;o`0000;ooooo1Ol00002ooooo`;o00001oooool2o`0001kooooo0_l00005oooo
o`;o000000?oooooo`000?l000000oooool2o`0000Gooooo0_l000000ooooooo0000o`00000Ko`00
00gooooo1?l00003ooooo`;o00000oooool3o`0001;ooooo0_l00008ooooo`;o0000<?ooool001co
oooo00?o0000ooooooooool0=?ooool2o`0000gooooo0_l00002ooooo`?o00001Oooool2o`0000Go
oooo0ol0000?ooooo`;o00000ooooolBo`0000kooooo0_l0000<ooooo`;o000000?oooooo`000?l0
00002Oooool2o`0000Gooooo1?l0000>oooooako00002?ooool2o`0000;ooooo1?l00008ooooo`?o
00002_ooool2o`0004;ooooo000Looooo`03o`000?oooooooooo03_ooooo1?l00002ooooo`;o0000
3_ooool2o`0000?ooooo0ol00003ooooo`;o00004?ooool5o`0000;ooooo2_l0000>ooooo`;o0000
00?oooooo`000?l000002Oooool5o`000003ooooool0003o000000oooooo0_l0000:ooooo`Co0000
00?oooooo`000?l000006ol00008ooooo`;o00001?ooool2o`0001Gooooo0_l00002ooooo`?o0000
2?ooool2o`0003?ooooo000Looooo`03o`000?oooooooooo03_ooooo1?l00002ooooo`;o00001_oo
ool2o`0000?ooooo1ol00007ooooo`;o00001?ooool2o`0000Wooooo0ol000001Ooooooo0000o`00
0?l0003ooooo00So00000oooool2o`0000cooooo1?l0000;ooooo`;o00000_ooool2o`0000Sooooo
0_l0000Aooooo`Co000000?oooooo`000?l000006Ol0000Booooo`;o00005oooool5o`0000Kooooo
0_l00004ooooo`;o0000;Oooool001cooooo00?o0000ooooooooool0?Oooool2o`0000?ooooo0_l0
0005ooooo`;o00000oooool7o`0000gooooo0_l00009ooooo`?o00000_ooool9o`0000Gooooo1Ol0
0009ooooo`;o00001oooool3o`0000Gooooo0_l0000:ooooo`;o00005_ooool8o`000003ooooool0
003o0000017o00001?ooool2o`0000[ooooo0ol0000Jooooo`;o00003?ooool2o`0000?ooooo0_l0
000Xooooo`007?ooool00ol0003oooooooooo`0_ooooo`?o00003Oooool2o`000004ooooool0003o
0000ooooo`Co0000:oooool7o`0000Gooooo1Ol00009ooooo`;o00001oooool3o`0000Gooooo0_l0
000Oooooo`;o00001?oooolJo`0000?ooooo0_l00004ooooo`;o00001?ooool2o`0000kooooo1_l0
0008ooooo`;o00003Oooool2o`000003ooooool0003o000002Sooooo000Looooo`03o`000?oooooo
oooo02oooooo0ol0000=ooooo`?o00000oooool4o`0001Kooooo0_l0000:ooooo`Co00001oooool2
o`0000Sooooo1?l00008ooooo`;o00001_ooool2o`000003ooooool0003o000000?ooooo1?l00005
ooooo`;o00004Oooool2o`0000Cooooo1?l000001?oooooo0000o`000?ooool2o`000003ooooool0
003o000000Oo000000?oooooo`000?l000003Ol00007ooooo`;o00005?ooool6o`0000Sooooo0_l0
000=ooooo`;o0000:oooool001cooooo00?o0000ooooooooool0;oooool2o`0000?ooooo0_l0000:
ooooo`Co000000Coooooo`000?l0003o00005oooool2o`0000?ooooo0_l00005ooooo`Co00001ooo
ool2o`0000[ooooo0_l00004ooooo`;o00000_ooool3o`0000Gooooo0_l000000ooooooo0000o`00
0002ooooo`Go00001Oooool2o`0000oooooo1?l00004ooooo`Co000000?oooooo`000?l000002_l0
00000ooooooo0000o`00000@o`0000Wooooo0_l00007ooooo`;o00002?ooool2o`0001cooooo0_l0
000[ooooo`007?ooool00ol0003oooooooooo`0dooooo`;o000000?oooooo`000?l000001Oooool2
o`0000;ooooo0_l00002ooooo`;o00003Oooool2o`0000gooooo0_l0000>ooooo`Co00001?ooool3
o`0000Wooooo0_l00003ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`Ko00001_oo
ool4o`0000;ooooo0_l00007ooooo`;o00000_ooool2o`0000_ooooo1?l000000ooooooo0000o`00
000Do`000003ooooool0003o000000?ooooo0_l00005ooooo`;o00001oooool2o`0000Cooooo1_l0
000Looooo`;o0000:oooool001cooooo00?o0000ooooooooool0=_ooool5o`0000?ooooo0_l00002
ooooo`;o00004Oooool2o`0000Sooooo0_l0000;ooooo`;o00001_ooool2o`0000Kooooo0ol0000B
ooooo`;o00001_ooool2o`0000Sooooo0_l00004ooooo`;o00001oooool4o`0000gooooo0_l00002
oooooa_o00000_ooool2o`0000Cooooo0_l0000>ooooo`Co00001oooool2o`0000;ooooo0_l00002
ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0=_ooool2o`000003ooooool0003o0000
01oooooo0_l00003ooooo`;o00001Oooool2o`0000Cooooo0_l00004ooooo`Ko00003Oooool2o`00
00[ooooo0_l00006ooooo`;o00001_ooool2o`0000Wooooo0_l00003ooooo`;o000000?oooooo`00
0?l000001Oooool2o`000003ooooool0003o000000Oooooo6ol00008ooooo`;o00001_ooool2o`00
00?ooooo0ol00004ooooo`;o00001?ooool7o`0000;ooooo0_l0000jooooo`007?ooool00ol0003o
ooooooooo`10ooooo`Co00005_ooool2o`0000[ooooo0_l00009ooooo`Oo00003Oooool2o`000003
ooooool0003o000000oooooo0_l00006ooooo`;o00001Oooool2o`000004ooooool0003o0000o`00
00?ooooo0_l00008ooooo`;o000000?oooooo`000?l000000oooool2o`0000;ooooo4_l0000Ioooo
o`;o00000oooool3o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l00000@?ooool001co
oooo00?o0000ooooooooool0@?ooool4o`0000;ooooo0_l0000Yooooo`;o000000?oooooo`000?l0
00004_ooool2o`0001Kooooo0_l00002ooooo`;o00000_ooool2o`000005ooooool0003o0000o`00
0?ooool00_l00008ooooo`Co00001_oooolFo`0000cooooo0_l0000;ooooo`;o00002?ooool2o`00
00Oooooo0ol00011ooooo`007?ooool00ol0003oooooooooo`11ooooo`;o00000oooool2o`0000?o
oooo0_l00004ooooo`;o00003oooool2o`0000Gooooo0_l00006ooooo`;o000000?oooooo`000?l0
00000_ooool2o`0000?ooooo0_l0000:ooooo`;o00001?ooool2o`0000Gooooo0_l00008ooooo`;o
00000_ooool2o`0000?ooooo1?l00002ooooo`?o00001oooool4o`0000Sooooo1Ol000000ooooooo
0000o`000008o`0000Cooooo0ol00009ooooo`;o00002Oooool2o`0000Gooooo0_l00003ooooo`?o
00000_ooool2o`000003ooooool0003o000000;o00001_ooool2o`0003Wooooo000Looooo`03o`00
0?oooooooooo02[ooooo0_l00007ooooo`;o00005_ooool2o`0000Cooooo0_l0000?ooooo`;o0000
1Oooool2o`0000Gooooo0ol00005ooooo`;o00000oooool2o`0000;ooooo0_l00005ooooo`?o0000
1?ooool2o`0000Gooooo0_l0000Aooooo`Co00000oooool2o`000003ooooool0003o000000Cooooo
0_l0000=ooooo`;o00000_ooool:o`0000?ooooo1Ol0000Booooo`;o00001Oooool2o`0000Cooooo
0_l00002ooooo`;o000000?oooooo`000?l000002?ooool4o`0003Oooooo000Looooo`03o`000?oo
oooooooo02[ooooo0_l00007ooooo`;o00005?ooool3o`00013ooooo0_l00005ooooo`;o00002?oo
ool2o`000003ooooool0003o000000Kooooo0_l00007ooooo`;o00001Oooool2o`0000?ooooo0_l0
000:ooooo`;o00003?ooool4o`0000;ooooo0_l00004ooooo`;o00004oooool?o`0000Gooooo0_l0
00000ooooooo0000o`000008ooooo`;o00004?ooool4o`0000cooooo0_l00003ooooo`Co0000=Ooo
ool001cooooo0_l0000booooo`;o00005?ooool5o`00013ooooo0_l00005ooooo`;o00002?ooool2
o`00017ooooo0_l0000;ooooo`;o00002Oooool3o`0000cooooo1?l00002ooooo`;o00001?ooool2
o`0000Oooooo0ol00008ooooo`Oo00000_ooool7o`0000Sooooo1?l00006ooooo`;o00004?ooool4
o`0000Gooooo0_l00005ooooo`;o00001Oooool2o`0000?ooooo1?l0000^ooooo`007?ooool00ol0
003oooooooooo`0aooooo`;o00003_ooool2o`0000Cooooo0_l000000ooooooo0000o`000004oooo
o`;o00003_ooool2o`0001Kooooo0_l000000ooooooo0000o`000003ooooo`;o00004oooool5o`00
00Oooooo0ol0000?ooooo`;o00001?ooool2o`000005ooooool0003o0000o`000?ooool00_l00005
ooooo`;o00001oooool8o`0000Wooooo0_l0000?ooooo`?o00003oooool2o`0000?ooooo0_l00002
ooooo`;o00002?ooool4o`0002kooooo000Looooo`03o`000?oooooooooo02gooooo0_l0000Boooo
o`;o00001oooool2o`0000Cooooo0_l00008ooooo`;o00001?ooool2o`0001Kooooo0_l000000ooo
oooo0000o`00000=ooooo`Go00001?ooool7o`0000Oooooo1?l000000ooooooo0000o`00000Aoooo
o`;o00001?ooool3o`0000Oooooo0_l00003ooooo`;o00001Oooool3o`0000Gooooo1?l00003oooo
o`;o00002oooool4o`0000_ooooo0_l00007ooooo`;o00000_ooool2o`0003[ooooo000Looooo`03
o`000?oooooooooo02Wooooo0_l00002ooooo`;o00001Oooool2o`0002Cooooo0_l00002ooooo`;o
000000?oooooo`000?l000000_ooool2o`0000[ooooo0_l00004ooooo`;o00000oooool3o`0000_o
oooo1_l00003ooooo`;o00000_ooool3o`0000Wooooo0_l000000ooooooo0000o`000005ooooo`;o
00001Oooool2o`0000Wooooo0_l00008ooooo`;o00000oooool2o`0000Gooooo0ol00005ooooo`Co
000000?oooooo`000?l000000_l00004ooooo`;o00001Oooool2o`0000?ooooo0_l00004ooooo`;o
00000_ooool2o`0000Gooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0Yooooo`;o0000
0_ooool2o`0000Gooooo0_l00002ooooo`;o00000_ooool2o`0000oooooo0_l0000?ooooo`;o0000
00?oooooo`000?l000000_ooool2o`0000;ooooo0_l00005ooooo`?o00001?ooool2o`0000?ooooo
1Ol0000:ooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000001;ooooo
1?l00005ooooo`;o00001?ooool2o`0000Oooooo0_l000000ooooooo0000o`000002o`0000Kooooo
1?l00002ooooo`;o00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000006ooooo`;o0000
2_ooool2o`000004ooooool0003o0000ooooo`Co00001?ooool2o`000003ooooool0003o000000?o
oooo0_l00008ooooo`Co0000;oooool001cooooo00?o0000ooooooooool0;?ooool2o`0000[ooooo
0_l00002ooooo`;o00003oooool2o`0000gooooo1?l00009ooooo`Co00000oooool2o`0000Kooooo
0_l00003ooooo`Co00004oooool6o`0000cooooo0_l000000ooooooo0000o`000002o`0000Sooooo
0_l00002ooooo`?o00001?ooool2o`000004ooooool0003o0000ooooo`Co00000oooool2o`000003
ooooool0003o000000;o00000_ooool3o`0000;ooooo1?l0000=ooooo`;o000000?oooooo`000?l0
00000_l00006ooooo`?o00000_ooool2o`0000;ooooo1Ol00005ooooo`;o00002?ooool6o`0002go
oooo000Looooo`03o`000?oooooooooo02cooooo0_l0000:ooooo`;o00000_ooool3o`0000Oooooo
0_l0000Dooooo`Co00002oooool2o`0000_ooooo0_l00007ooooo`;o00001Oooool2o`0000Sooooo
0_l000000ooooooo0000o`000003o`0000cooooo0_l000000ooooooo0000o`000003ooooo`;o0000
1Oooool2o`0000;ooooo0_l00005ooooo`;o00002oooool2o`000005ooooool0003o0000o`000?oo
ool01Ol00004ooooo`;o00003Oooool2o`000003ooooool0003o000000;o00000_ooool2o`0000?o
oooo0_l00006ooooo`;o000000Coooooo`000?l0003ooooo0_l0000?ooooo`?o0000;Oooool001co
oooo00?o0000ooooooooool07?ooool2o`0001Oooooo0_l000001?oooooo0000o`000?l00002oooo
o`;o00001oooool2o`0002Gooooo1?l00005ooooo`;o00002?ooool3o`0000Gooooo0_l00002oooo
o`;o00001?ooool2o`000004ooooool0003o0000ooooo`;o00003?ooool2o`0000?ooooo0_l00000
0ooooooo0000o`00000<ooooo`?o00002?ooool6o`0000Cooooo0_l000001?oooooo0000o`000?l0
000Nooooo`;o000000Coooooo`000?l0003ooooo0_l00008ooooo`;o000000?oooooo`000?l00000
0_ooool2o`0000Gooooo0_l0000dooooo`007?ooool00ol0003oooooooooo`0Looooo`;o00003?oo
ool2o`0000Gooooo0_l00002ooooo`;o00000_ooool2o`0000Wooooo0_l0000Fooooo`;o00001?oo
ool2o`0000Wooooo1?l00005ooooo`;o00001?ooool2o`0000;ooooo0_l0000:ooooo`?o00005ooo
ool2o`0000?ooooo0_l00007ooooo`Co00001?ooool3o`000003ooooool0003o000000Gooooo1_l0
000Vooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`;o00001Oooool2o`0000Gooooo
0_l00005ooooo`;o0000=?ooool001cooooo00?o0000ooooooooool0:_ooool2o`0000Gooooo0_l0
000>ooooo`;o000000?oooooo`000?l000005?ooool4o`0000;ooooo1?l0000Gooooo`?o00001Ooo
ool2o`0000Sooooo0_l0000=ooooo`Co00002?ooool2o`000003ooooool0003o000000;o00001Ooo
ool5o`0000?ooooo0_l00002ooooo`;o00008Oooool2o`0000kooooo1?l00004ooooo`;o000000?o
ooooo`000?l000000oooool2o`0000Oooooo0_l00009ooooo`;o000000?oooooo`000?l00000;Ooo
ool001cooooo00?o0000ooooooooool0=?ooool2o`000003ooooool0003o000000Sooooo0_l00002
ooooo`;o00004_ooool5o`0000;ooooo0_l00005ooooo`;o00004_ooool2o`0000Cooooo1_l0000;
ooooo`;o00002?ooool4o`0000Cooooo1_l000000ooooooo0000o`000002o`0000Sooooo0_l00003
ooooo`;o00001?ooool2o`0000Oooooo0_l00009ooooo`;o00001_ooool2o`0000?ooooo0_l0000@
ooooo`;o00001?ooool2o`000003ooooool0003o000000?ooooo0_l0000Booooo`;o000000?ooooo
o`000?l00000;Oooool001cooooo00?o0000ooooooooool0=?ooool2o`000004ooooool0003o0000
o`0000[ooooo0ol00008ooooo`;o00002?ooool2o`0000_ooooo0ol000000ooooooo0000o`000006
ooooo`;o000000?oooooo`000?l000002_ooool6o`0000Oooooo0_l00002ooooo`;o00001?ooool2
o`0000[ooooo1?l00004ooooo`;o00002Oooool2o`0000Wooooo0_l00007ooooo`;o000000Cooooo
o`000?l0003o00000_ooool2o`000003ooooool0003o000000;o00001?ooool2o`0001kooooo0_l0
0003ooooo`;o00001?ooool2o`0003kooooo000Looooo`03o`000?oooooooooo01oooooo0_l0000A
ooooo`;o00001?ooool2o`0000;ooooo1Ol00003ooooo`;o00002Oooool2o`0001Gooooo0ol00000
0ooooooo0000o`000006ooooo`Go00002_ooool2o`0000_ooooo1?l00006ooooo`?o00001Oooool2
o`0000[ooooo0_l0000Booooo`;o00002_ooool5o`0000;ooooo0_l00003ooooo`;o00003?ooool2
o`0001Kooooo0_l00003ooooo`Co00000_ooool2o`000003ooooool0003o000000;o00001?ooool2
o`0003?ooooo000Looooo`03o`000?oooooooooo01oooooo0_l0000Aooooo`;o000000?oooooo`00
0?l000000oooool7o`0000_ooooo0ol0000;ooooo`;o00000_ooool5o`0000;ooooo1ol00003oooo
o`;o00000oooool2o`0000_ooooo0_l00007ooooo`;o00001?ooool4o`0000Gooooo0_l00005oooo
o`;o000000Coooooo`000?l0003ooooo1?l000000ooooooo0000o`000002ooooo`;o00003oooool4
o`0000Kooooo1?l00006ooooo`;o00000_ooool2o`0000;ooooo0ol00004ooooo`;o000000?ooooo
o`000?l000007Oooool2o`0000Gooooo1?l00004ooooo`;o0000<oooool001cooooo00?o0000oooo
ooooool0=?ooool3o`0000?ooooo0_l00004ooooo`?o00002Oooool3o`0000_ooooo0_l000000ooo
oooo0000o`00000Bo`0000Gooooo0_l00003ooooo`;o00001?ooool2o`0000?ooooo0_l00002oooo
o`Co00001?ooool2o`0000Cooooo0_l00009ooooo`;o000000?oooooo`000?l000000_l000000ooo
oooo0000o`000002ooooo`?o00004?ooool3o`0000Cooooo1Ol00006ooooo`;o00001_ooool3o`00
00Cooooo0_l0000Dooooo`Co00002?ooool2o`0000Gooooo0_l00009ooooo`;o0000<?ooool001co
oooo00?o0000ooooooooool0=?ooool2o`000003ooooool0003o000000Cooooo0_l000001?oooooo
0000o`000?l0000JoooooaCo00001Oooool2o`0000?ooooo0_l00009ooooo`;o00001?ooool2o`00
00[ooooo0_l00007ooooo`;o00001?ooool3o`0000Kooooo0_l00005ooooo`?o000000?oooooo`00
0?l000000_l00004ooooo`;o00001?ooool2o`000003ooooool0003o000000;ooooo0_l00002oooo
o`;o00008oooool4o`000003ooooool0003o000000Gooooo0_l00006ooooo`;o00002?ooool2o`00
033ooooo000Looooo`;o0000;_ooool2o`0000Sooooo1?l00002ooooo`;o00001_ooool2o`0001Co
oooo3?l000000ooooooo0000o`000009o`0000?ooooo0ol0000Nooooo`;o000000?oooooo`000?l0
00001Oooool2o`0000Cooooo0ol00007ooooo`Wo000000?oooooo`000?l000000_l00007ooooo`;o
00000oooool2o`0000?ooooo0ol00007ooooo`;o000000?oooooo`000?l000007oooool2o`0000go
oooo0_l00002ooooo`;o0000=_ooool001cooooo00?o0000ooooooooool0;Oooool2o`0000[ooooo
0_l0000:ooooo`Co00001oooool2o`0000Wooooo6Ol00002ooooo`?o00002Oooool2o`0001?ooooo
0_l000000ooooooo0000o`000005ooooo`?o00000oooool2o`0000Cooooo0ol000000ooooooo0000
o`000007o`0000cooooo0_l00003ooooo`;o00001?ooool2o`0000Oooooo0_l000000ooooooo0000
o`00000;ooooo`;o00004_ooool2o`0000[ooooo0_l00005ooooo`;o0000=_ooool001cooooo00?o
0000ooooooooool0??ooool2o`0000Wooooo0_l00007ooooo`;o00001_ooool3o`000003ooooool0
003o000001Ko00003Oooool3o`0000Gooooo0_l0000<ooooo`;o000000?oooooo`000?l000000ooo
ool5o`000003ooooool0003o000000?o00000oooool5o`000003ooooool0003o000000Go000000?o
ooooo`000?l000000_l00003ooooo`;o00002Oooool2o`0000;ooooo0_l000000ooooooo0000o`00
0002ooooo`;o00000_ooool2o`000003ooooool0003o000000?ooooo0_l00004ooooo`;o00004_oo
ool2o`0000[ooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0aooooo`Co00001oooool2
o`0000cooooo0_l000000ooooooo0000o`000004ooooo`;o00000ooooolLo`0000gooooo0_l00006
ooooo`;o00000_ooool2o`0000gooooo0_l000000ooooooo0000o`000006o`000003ooooool0003o
000000So000000Goooooo`000?l0003o0000ooooo`02o`0000;ooooo1?l00003ooooo`;o000000?o
ooooo`000?l000001_ooool2o`0000;ooooo1Ol00002ooooo`;o00000_ooool2o`000003ooooool0
003o000000?ooooo0_l0000Rooooo`;o0000?oooool001cooooo00?o0000ooooooooool0<Oooool4
o`0000Oooooo0_l0000<ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Gooooo6_l00009
ooooo`;o00000_ooool2o`0000[ooooo0_l000000ooooooo0000o`00000:ooooo`Co00000oooool=
o`000004ooooool0003o0000ooooo`So00002Oooool2o`0000_ooooo0_l0000;ooooo`;o00009ooo
ool2o`0000Wooooo0_l0000dooooo`007?ooool00ol0003oooooooooo`0nooooo`;o00000_ooool2
o`000003ooooool0003o000000kooooo1?l000000ooooooo0000o`00000Io`0000Sooooo1_l0000:
ooooo`;o000000?oooooo`000?l000002oooool4o`0000?ooooo1?l000000ooooooo0000o`000002
oooooa3o00002oooool2o`0000Sooooo0_l00002ooooo`;o00003oooool4o`0002Sooooo0_l0000d
ooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o00002?ooool6o`000003ooooool0003o0000
00Co000000?oooooo`000?l000002_ooool2o`0000;ooooo1?l000000ooooooo0000o`00000Ko`00
00Sooooo0_l0000<ooooo`;o00002_ooool2o`0000?ooooo2_l000001?oooooo0000o`000?ooool<
o`000003ooooool0003o000000;o00001_ooool2o`0000?ooooo0_l00005ooooo`;o000000?ooooo
o`000?l000000_ooool2o`0000oooooo1?l0000Hooooo`;o00001_ooool2o`0003cooooo000Loooo
o`03o`000?oooooooooo02gooooo0_l00008ooooo`Ko00000_ooool3o`0000oooooo0_l00003oooo
o`?o000000?oooooo`000?l000003_l000000ooooooo0000o`000006o`0000;ooooo0_l0000;oooo
o`Co00004oooool2o`0000?ooooo5?l000000ooooooo0000o`000005o`0000?ooooo0_l000001?oo
oooo0000o`000?ooool4o`0000Sooooo0ol00008ooooo`;o00007oooool3o`0000Gooooo0_l00005
ooooo`?o0000??ooool001cooooo00?o0000ooooooooool0A?ooool2o`0000oooooo1?l00002oooo
oaCo000000Coooooo`000?l0003o00001oooool2o`0000Kooooo1?l00003ooooo`;o00004?ooool2
o`000003ooooool0003o000000;o000000?oooooo`000?l000004Ol00002ooooo`;o00000_ooool7
o`0000;ooooo0_l00009ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`0001oooooo0ol0
0008ooooo`;o00000_ooool2o`0003gooooo000Looooo`03o`000?oooooooooo03gooooo0_l00005
ooooo`;o00000oooool2o`0000Cooooo0_l00004oooooaoo00000_ooool2o`0000;ooooo0_l00009
ooooo`;o00000_ooool2o`0000oooooo0ol000000ooooooo0000o`000002o`000004ooooool0003o
0000o`0000;ooooo2?l000000ooooooo0000o`000004o`0000;ooooo0_l000000ooooooo0000o`00
0002o`000003ooooool0003o000000oooooo1?l0000`ooooo`;o00000_ooool2o`0003gooooo000L
ooooo`03o`000?oooooooooo03_ooooo1?l0000:ooooo`;o00001?ooool2o`0000Kooooo6_l00000
0ooooooo0000o`000002ooooo`;o00001?ooool2o`0000Oooooo0_l00002ooooo`;o00003_ooool3
o`0000?ooooo0_l000000ooooooo0000o`00000Go`000003ooooool0003o000000;o00004_ooool2
o`00017ooooo0_l0000Kooooo`;o0000AOooool001cooooo00?o0000ooooooooool0>oooool2o`00
00?ooooo0ol00004ooooo`;o00004_oooolEo`000003ooooool0003o000000Kooooo0_l000001?oo
oooo0000o`000?l00004ooooo`Co00003?ooool4o`0000;ooooo0ol00002oooooago00000oooool2
o`0002Gooooo1?l0000Hooooo`?o00000oooool2o`00043ooooo000Looooo`03o`000?oooooooooo
043ooooo0ol00004ooooo`;o00004OoooolFo`000003ooooool0003o000000Kooooo0_l00002oooo
o`;o00001?ooool2o`0000kooooo1_l000000ooooooo0000o`00000Po`0000Sooooo0_l0000Aoooo
o`;o00003_ooool2o`0001Sooooo0_l00004ooooo`?o0000?oooool001cooooo00?o0000oooooooo
ool0;oooool2o`0000kooooo0_l0000Iooooo`?o000000?oooooo`000?l000003ol00005ooooo`;o
00000_ooool3o`0000Sooooo0_l00004ooooo`;o00002Oooool2o`000003ooooool0003o000000?o
oooo1Ol00003oooooaSo000000Coooooo`000?l0003ooooo0_l00002ooooo`;o000000Coooooo`00
0?l0003o00003Oooool2o`0000_ooooo0_l0000Eooooo`;o00002oooool2o`0003oooooo00001_oo
ooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0
1_ooool00ol0003oooooooooo`0_ooooo`;o00003_ooool2o`0000Wooooo0_l0000@oooooa?o0000
1Oooool3o`000004ooooool0003o0000o`0000Cooooo0_l00005ooooo`;o000000?oooooo`000?l0
00003_ooool4o`0000;ooooo3?l000000ooooooo0000o`000005o`000003ooooool0003o000000co
00001Oooool3o`0001[ooooo0_l00003ooooo`;o00004?ooool2o`000003ooooool0003o000000So
oooo0_l00002ooooo`;o0000>oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q
8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo043ooooo1?l00004
ooooo`Co00003?ooool2o`0000;ooooo1_l000000ooooooo0000o`000007o`000004ooooool0003o
0000ooooo`;o00000_ooool3o`0000Sooooo0_l00005ooooo`;o00003OoooolTo`000003ooooool0
003o000000;o000000Coooooo`000?l0003o00008Oooool2o`000004ooooool0003o0000ooooo`;o
00004oooool2o`0000?ooooo0_l00007ooooo`;o0000>oooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool0<oooool2o`0000_ooooo1?l00004ooooo`;o00003?ooool4o`0000Wooooo1?l000000ooooooo
0000o`000002o`0000Cooooo0_l00002ooooo`;o00001oooool2o`0000Sooooo0_l0000;oooooaco
000000?oooooo`000?l000002Ol000001?oooooo0000o`000?ooool2o`0001Oooooo0_l00008oooo
o`;o000000?oooooo`000?l000006oooool2o`0000Gooooo1?l0000kooooo`0000?oooooo`000?oo
ool00_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`00
03?ooooo0_l00007ooooo`;o00006?ooool4o`0000?ooooo0ol000001?oooooo0000o`000?ooool3
o`0000Cooooo0_l00007ooooo`Ko00000oooool3o`0000Oooooo0_l0000;ooooo`;o00001Oooool4
o`0000?ooooo6Ol00002ooooo`So00004oooool3o`000003ooooool0003o000000Oooooo0_l0000D
ooooo`;o00001?ooool2o`0000?ooooo0_l00002ooooo`?o0000??ooool00003ooooool0003ooooo
00;ooooo00?o0000ooooooooool02Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000
ooooooooool0>Oooool2o`000003ooooool0003o000000;o00005Oooool2o`000003ooooool0003o
000000?ooooo0ol000001?oooooo0000o`000?ooool4o`0000;ooooo0ol00007ooooo`Ko00001?oo
ool2o`0000?ooooo0_l0000<ooooo`;o00000oooool4o`000003ooooool0003o000000;o000000?o
ooooo`000?l000008ol0000<ooooo`;o00001Oooool2o`0000;ooooo0_l00007ooooo`;o00005?oo
ool2o`0000Cooooo0_l00003ooooo`;o00000oooool2o`0003cooooo00000ooooooo410@ooooo`02
ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`0i
ooooo`;o000000?oooooo`000?l000000ol0000Dooooo`;o00001oooool2o`0000Kooooo0_l00002
ooooo`;o00001_ooool2o`000004ooooool0003o0000ooooo`;o00000_ooool4o`0000?ooooo0_l0
0002ooooo`;o00000_ooool2o`0000Cooooo0_l00003ooooo`Co00000_oooolIo`000003ooooool0
003o000000Oo00004_ooool3o`00017ooooo0_l000000ooooooo0000o`00000Looooo`;o0000@Ooo
ool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`00
0?oooooooooo03Wooooo0_l000001?oooooo0000o`000?ooool2o`00013ooooo0ol00009ooooo`;o
00003?ooool2o`0000Gooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo1ol00003oooo
o`?o00000_ooool2o`0000Wooooo0ol00003oooooa;o000000?oooooo`000?l000004?l0000Aoooo
o`;o00003_ooool2o`000004ooooool0003o0000ooooo`;o00006?ooool2o`0000;ooooo1?l0000o
ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo
00?o0000ooooooooool0>Oooool2o`0000Cooooo0_l00002ooooo`;o00003?ooool3o`0000Wooooo
0_l0000<ooooo`;o000000Coooooo`000?l0003ooooo0ol00004ooooo`Co00000_ooool5o`0000?o
oooo0_l0000<ooooo`Co000000?oooooo`000?l000000_oooolTo`00027ooooo0_l000000ooooooo
0000o`000002o`0001Wooooo0ol000000ooooooo0000o`000002o`0003oooooo000Looooo`03o`00
0?oooooooooo03[ooooo0_l00003ooooo`;o00000_ooool2o`0001?ooooo1?l00003ooooo`;o0000
3Oooool2o`000003ooooool0003o000000?o00001?ooool4o`0000;ooooo0_l0000?ooooo`Go0000
0_oooolVo`0000;ooooo0_l0000:ooooo`;o00001oooool2o`000003ooooool0003o000000_ooooo
1?l0000Jooooo`;o000000?oooooo`000?l00000@Oooool001cooooo00?o0000ooooooooool0>_oo
ool2o`0001Kooooo0_l00004ooooo`Wo00001?ooool4o`0000_ooooo1?l00004ooooo`;o00001_oo
ool2o`0000_ooooo0ol00002oooooa7o000000?oooooo`000?l000006?l00002ooooo`;o00001_oo
ool2o`0000Gooooo1?l000000ooooooo0000o`00000Qooooo`;o0000C?ooool001cooooo00?o0000
ooooooooool0Boooool2o`0000Gooooo0_l00008ooooo`?o00001_ooool5o`0000Cooooo0_l00006
ooooo`;o00003?ooool2o`00013ooooo4Ol00003oooooa;o00000_ooool2o`0000Cooooo0_l00004
ooooo`;o00000_ooool2o`0000?ooooo0_l0000Booooo`;o00002?ooool2o`0000Sooooo0_l00002
ooooo`Oo00001Oooool2o`0003cooooo000Looooo`03o`000?oooooooooo03Wooooo0_l00009oooo
o`Co00000oooool2o`000004ooooool0003o0000ooooo`;o00003?ooool2o`0000;ooooo0_l00003
ooooo`;o00001?ooool4o`0000Kooooo0_l0000<ooooo`;o00000_ooool2o`0000cooooo0ol00000
0ooooooo0000o`00000:o`000003ooooool0003o000001Oo000000?oooooo`000?l000000_l00003
ooooo`;o00000_ooool2o`0000[ooooo0_l0000;ooooo`;o00002?ooool2o`000004ooooool0003o
0000ooooo`;o00001_ooool8o`0000Cooooo0_l0000looooo`007?ooool00ol0003oooooooooo`0i
ooooo`;o00001?ooool2o`0000?ooooo1?l00002ooooo`;o00000_ooool5o`000003ooooool0003o
000000;o00001oooool2o`0000;ooooo0_l0000;ooooo`;o000000Coooooo`000?l0003ooooo1ol0
0007ooooo`Co000000?oooooo`000?l000000_l00008oooooa?o000000?oooooo`000?l000007?l0
000Cooooo`;o00006?ooool5o`0000?ooooo0_l00007ooooo`;o0000@_ooool001cooooo00?o0000
ooooooooool0?Oooool4o`0000?ooooo0_l00004ooooo`;o00001?ooool3o`000003ooooool0003o
000000;o00001oooool2o`0001;ooooo0_l000000ooooooo0000o`000002ooooo`?o00001oooool2
o`0000?ooooo1?l00008oooooa?o000000?oooooo`000?l000001?l000001?oooooo0000o`000?oo
oolEo`0001;ooooo0_l000000ooooooo0000o`00000Gooooo`;o00001?ooool2o`0004_ooooo000L
ooooo`03o`000?oooooooooo03gooooo1?l00003ooooo`;o00001_ooool2o`0000?ooooo0_l0000<
ooooo`;o00006oooool2o`0000cooooo0_l00009ooooo`?o00000_oooolQo`0000?ooooo1?l00003
ooooo`?o00003?ooool2o`0000Cooooo0_l000000ooooooo0000o`000007ooooo`;o00001Oooool3
o`0000gooooo1?l00018ooooo`007?ooool00ol0003oooooooooo`0jooooo`;o00004?ooool7o`00
017ooooo0_l0000<ooooo`;o00001?ooool2o`0000;ooooo0ol00007ooooo`;o000000Coooooo`00
0?l0003o00002OoooolBo`000003ooooool0003o000000?o000000?oooooo`000?l000003?l00000
0ooooooo0000o`000003o`0000?ooooo0_l0000=ooooo`?o00003oooool2o`0000Gooooo0ol00004
ooooo`;o000000?oooooo`000?l000001?ooool4o`0000;ooooo0_l00014ooooo`007?ooool00ol0
003oooooooooo`0jooooo`;o00003_ooool2o`0000;ooooo1_l00008ooooo`;o00001_ooool2o`00
00cooooo0_l00003ooooo`?o00000oooool2o`0000?ooooo0_l00002ooooo`Oo00001?ooool2o`00
00Gooooo9ol000000ooooooo0000o`00000Cooooo`;o00002oooool2o`0000Wooooo0_l00005oooo
o`;o000000?oooooo`000?l000002_ooool2o`0004Cooooo000Looooo`03o`000?oooooooooo03co
oooo0_l0000<ooooo`;o00001_ooool2o`0000Sooooo0_l0000=ooooo`;o00001?ooool2o`0000Co
oooo0_l00009ooooo`;o00000oooool2o`0000;ooooo0ol00003ooooo`;o00000ooooolNo`000003
ooooool0003o000000;o00000oooool2o`000003ooooool0003o000001[ooooo0ol00003ooooo`Go
00001oooool2o`0000Sooooo1?l00002ooooo`Co0000B?ooool001cooooo00?o0000ooooooooool0
??ooool2o`0000Gooooo0_l00002ooooo`;o00001_ooool2o`0001?ooooo0_l00005ooooo`;o0000
1?ooool2o`000003ooooool0003o000000oooooo0_l00005ooooo`;o00000oooool2o`0000?ooooo
0ol00002ooooob?o000000?oooooo`000?l000000_ooool2o`0000?ooooo0ol0000@ooooo`?o0000
0oooool2o`000003ooooool0003o000000Sooooo0_l00003ooooo`;o00000_ooool4o`000003oooo
ool0003o000000?o00001?ooool2o`0004;ooooo000Looooo`;o0000?Oooool2o`0000Gooooo0_l0
0002ooooo`;o00001_ooool2o`00013ooooo0_l000000ooooooo0000o`000009ooooo`;o00000ooo
ool2o`0000gooooo1?l00004ooooo`;o00002Oooool>o`000003ooooool0003o000001ko00000ooo
ool3o`00013ooooo0_l00002ooooo`;o00002oooool4o`0000?ooooo0_l00002ooooo`?o000000Co
ooooo`000?l0003o00001oooool2o`0004;ooooo000Looooo`03o`000?oooooooooo04[ooooo0_l0
000;ooooo`;o00002?ooool2o`0000cooooo0_l0000Booooo`Co00001?ooool3o`0000Sooooo0_l0
00000ooooooo0000o`00000No`0000;ooooo2Ol000001?oooooo0000o`000?l0000Cooooo`;o0000
0_ooool2o`0000_ooooo0_l00009ooooo`?o000000?oooooo`000?l000006?ooool2o`0003;ooooo
000Looooo`03o`000?oooooooooo04Kooooo0_l00002ooooo`?o00002_ooool2o`0000oooooo0_l0
000Fooooo`;o00000_ooool2o`0000Kooooo1?l00005ooooo`;o00000_oooolTo`0000Sooooo0ol0
000:ooooo`;o00002Oooool2o`0000?ooooo0_l00008ooooo`;o00002Oooool3o`0000Sooooo0_l0
000Aooooo`;o0000<_ooool001cooooo00?o0000ooooooooool0A_ooool2o`0000?ooooo0_l0000C
ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0000Cooooo0_l00008ooooo`;o00001_oo
ool3o`000003ooooool0003o000000Sooooo0_l00002ooooo`;o000000?oooooo`000?l000000_oo
ool5o`0000Cooooo8?l0000@ooooo`;o00002Oooool3o`0000;ooooo1?l00003ooooo`;o00002ooo
ool2o`000003ooooool0003o000000Oooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`1E
ooooo`;o00002Oooool2o`000003ooooool0003o000000Go00000_ooool9o`0000?ooooo0_l00006
ooooo`?o00003oooool2o`0000Cooooo0_l00002ooooo`;o00000_oooolTo`0001[ooooo0_l00004
ooooo`;o00000oooool3o`0000[ooooo0_l000000ooooooo0000o`000003ooooo`;o0000BOooool0
01cooooo00?o0000ooooooooool0??ooool2o`0000[ooooo0_l0000;ooooo`;o00003oooool2o`00
00Cooooo0_l000000ooooooo0000o`000004o`0000_ooooo0ol00008ooooo`;o00002oooool2o`00
0003ooooool0003o000000;o000000?oooooo`000?l000003_l00002ooooo`Oo000000?oooooo`00
0?l000001Oooool5o`0000Oooooo0ol0000Jooooo`;o00004?ooool4o`0004Wooooo000Looooo`03
o`000?oooooooooo03cooooo0_l0000:ooooo`;o00001?ooool2o`0002Sooooo0_l00007ooooo`;o
00002?ooool3o`000003ooooool0003o000000Kooooo0ol000000ooooooo0000o`000002o`000003
ooooool0003o000001[o00001Oooool2o`000003ooooool0003o000000Oooooo0ol0000/ooooo`;o
0000Boooool001cooooo00?o0000ooooooooool0C_ooool2o`0000Oooooo1?l00006ooooo`;o0000
2Oooool2o`0000Wooooo0ol000001?oooooo0000o`000?l0000<ooooo`Co000000?oooooo`000?l0
00001_ooool2o`0000?ooooo2Ol000000ooooooo0000o`00000Fo`0000Gooooo0_l0000Zooooo`;o
00002Oooool2o`0004gooooo000Looooo`03o`000?oooooooooo05Oooooo1?l00006ooooo`;o0000
2Oooool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000002ooooo`?o0000
1_ooool4o`0000;ooooo1?l000000ooooooo0000o`000005ooooo`;o00000oooool:o`000003oooo
ool0003o0000017o000000?oooooo`000?l000000_l000000ooooooo0000o`000002ooooo`;o0000
6Oooool2o`0000oooooo0_l00009ooooo`;o0000COooool001cooooo00?o0000ooooooooool0@?oo
ool2o`0000?ooooo0_l0000Dooooo`;o00004_ooool2o`0000?ooooo1?l00005ooooo`;o00001Ooo
ool5o`0000;ooooo0ol00008ooooo`;o00000oooool3o`000003ooooool0003o000000?o00000_oo
oolBo`000004ooooool0003o0000ooooo`Oo00001?ooool2o`0000Gooooo0_l000001?oooooo0000
o`000?l0000:ooooo`;o00007?ooool2o`0004_ooooo000Looooo`03o`000?oooooooooo043ooooo
1?l000000ooooooo0000o`000007ooooo`;o00002Oooool4o`0001;ooooo2Ol00005ooooo`;o0000
2?ooool2o`0000;ooooo0ol00002ooooo`?o00002Oooool5o`0000Cooooo4ol000000ooooooo0000
o`000005o`000003ooooool0003o000000Cooooo0_l00005ooooo`;o000000Coooooo`000?l0003o
00001Oooool2o`000003ooooool0003o000000oooooo0_l0000=ooooo`;o0000Boooool001cooooo
00?o0000ooooooooool0@_ooool2o`0000[ooooo0_l00007ooooo`Co00005?ooool8o`0001Gooooo
0_l00002ooooo`?o00002?ooool4o`000003ooooool0003o000000?ooooo4ol00002ooooo`;o0000
5?ooool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000003oooool2o`0000Cooooo
0_l00005ooooo`;o0000COooool001cooooo00?o0000ooooooooool0@_ooool2o`0000[ooooo0_l0
00000ooooooo0000o`000002ooooo`Ko00008oooool2o`0000;ooooo0_l0000<ooooo`;o00001_oo
ool2o`000004ooooool0003o0000o`0000;ooooo0_l00004ooooo`ko00001Oooool2o`0000[ooooo
0_l00009ooooo`;o00000_ooool2o`0001_ooooo1?l00005ooooo`;o0000COooool001cooooo00?o
0000ooooooooool0C?ooool2o`0000?ooooo0_l00002ooooo`?o000000?oooooo`000?l000005_oo
ool2o`0000_ooooo0_l00002ooooo`;o000000?oooooo`000?l000002Oooool2o`0000Kooooo1_l0
0003ooooo`;o000000?oooooo`000?l000002?l00003ooooo`Go00000oooool2o`0000;ooooo0_l0
0006ooooo`;o00001_ooool2o`0000?ooooo0_l00008ooooo`;o00003?ooool2o`0000Cooooo0ol0
001Fooooo`007?ooool00ol0003oooooooooo`1:ooooo`Go00008_ooool2o`0000Wooooo0_l00000
0ooooooo0000o`000004ooooo`;o00001?ooool2o`0000?ooooo1?l00003ooooo`;o000000?ooooo
o`000?l000000_l00003ooooo`;o000000?oooooo`000?l000000ol000000ooooooo0000o`000003
o`000005ooooool0003o0000o`000?ooool00_l00007ooooo`;o00001_ooool2o`0000Kooooo0_l0
00000ooooooo0000o`000002o`0000Gooooo1Ol0000:ooooo`Co00001?ooool2o`000003ooooool0
003o000000;ooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00001?ooool2
o`000004ooooool0003o0000o`0000Gooooo0_l0000Tooooo`?o000000?oooooo`000?l000000_l0
0002ooooo`;o00000oooool3o`0000Gooooo0_l00003ooooo`;o00001?ooool2o`0000kooooo0_l0
00000ooooooo0000o`000003o`0000Gooooo1Ol00006ooooo`;o00000_ooool2o`000003ooooool0
003o000000;ooooo0_l00007ooooo`?o00003?ooool2o`0000Wooooo1_l0001@ooooo`007?ooool2
o`0004Gooooo0_l00006ooooo`Co00000_ooool2o`000003ooooool0003o000002Cooooo0_l00002
ooooo`Co00001oooool2o`0000Cooooo0_l0000;ooooo`;o00000_ooool2o`000004ooooool0003o
0000ooooo`?o00000_ooool2o`0000;ooooo1ol000000ooooooo0000o`000005o`0000Cooooo0_l0
0003ooooo`?o000000?oooooo`000?l000009_ooool3o`0005;ooooo000Looooo`03o`000?oooooo
oooo04cooooo0ol00003ooooo`;o00001_ooool2o`000003ooooool0003o0000017ooooo0_l0000;
ooooo`Co00003oooool2o`000003ooooool0003o000000cooooo0_l000001?oooooo0000o`000?oo
ool3o`0000;ooooo0_l00002ooooo`;o00000_ooool3o`000003ooooool0003o000000;ooooo0ol0
0004ooooo`;o00000oooool2o`0000Cooooo1?l00007ooooo`;o00001?ooool2o`0000gooooo0_l0
0004ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0COooool2o`0000Kooooo0_l00003
ooooo`;o000000?oooooo`000?l000004Oooool2o`0000Wooooo1?l0000Dooooo`;o00000_ooool2
o`0000[ooooo0ol000001?oooooo0000o`000?l00002ooooo`Co00001?ooool2o`0000Kooooo0ol0
000?ooooo`Co00001oooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l00000
2_ooool2o`0005Wooooo000Looooo`03o`000?oooooooooo04Sooooo0_l00005ooooo`;o00001?oo
ool4o`000003ooooool0003o000000;ooooo0_l0000Cooooo`;o00001_ooool2o`0000Kooooo0_l0
0002ooooo`;o00003?ooool5o`0000Kooooo2?l00003ooooo`Go00002_ooool2o`0000_ooooo0_l0
0007ooooo`;o00002_ooool2o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o0000G_oo
ool001cooooo00?o0000ooooooooool0B?ooool2o`0000Gooooo0_l00005ooooo`?o000000?ooooo
o`000?l000000_ooool2o`0001?ooooo0_l0000<ooooo`Co00000_ooool4o`0000[ooooo1Ol00006
ooooo`?o00000_ooool3o`0000?ooooo0_l0000=ooooo`;o00002_ooool5o`0001;ooooo0_l00006
ooooo`;o00000_ooool2o`0005kooooo000Looooo`03o`000?oooooooooo04Kooooo0_l0000Ioooo
o`;o00002_ooool2o`000003ooooool0003o000000oooooo0ol00002ooooo`;o000000?oooooo`00
0?l000002oooool3o`0000Oooooo0_l0000;ooooo`Co00002_ooool2o`0000;ooooo0_l00005oooo
o`;o000000?oooooo`000?l000000oooool2o`0000?ooooo0_l00008ooooo`;o00001_ooool2o`00
06;ooooo000Looooo`03o`000?oooooooooo04Kooooo0_l000001?oooooo0000o`000?ooool4o`00
017ooooo0_l000000ooooooo0000o`000007ooooo`;o000000?oooooo`000?l000002?ooool2o`00
00Kooooo0ol000000ooooooo0000o`00000:ooooo`;o00000_ooool2o`0001Gooooo1?l0000:oooo
o`?o000000?oooooo`000?l000002_ooool2o`000003ooooool0003o000000?ooooo0_l00005oooo
o`Co0000Joooool001cooooo00?o0000ooooooooool0BOooool2o`000003ooooool0003o000000;o
000000Coooooo`000?l0003o00001_ooool2o`000003ooooool0003o000000Gooooo0_l00002oooo
o`;o00004?ooool2o`0000Gooooo1?l00006ooooo`;o00001Oooool2o`0000Gooooo0_l0000=oooo
o`?o00002?ooool2o`0000Oooooo0_l0000=ooooo`;o00001?ooool3o`0000Kooooo1?l0000=oooo
o`;o0000G?ooool001cooooo00?o0000ooooooooool0DOooool3o`0000Kooooo0_l000000ooooooo
0000o`000004ooooo`;o00000oooool2o`0000kooooo0_l000001?oooooo0000o`000?ooool2o`00
0003ooooool0003o000000;o00000oooool2o`000003ooooool0003o000000Cooooo1?l00004oooo
o`;o00001Oooool2o`0000Kooooo1?l00007ooooo`;o000000?oooooo`000?l000002_ooool2o`00
00gooooo0ol00007ooooo`;o00001oooool2o`000003ooooool0003o000000;ooooo0_l0001Loooo
o`007?ooool00ol0003oooooooooo`1<ooooo`;o00000_ooool2o`0000Gooooo0_l00005ooooo`;o
00000_ooool3o`0000Wooooo0_l00002ooooo`;o00001?ooool5o`000003ooooool0003o000000?o
oooo0_l00003ooooo`;o00001_ooool5o`0000Cooooo0_l00005ooooo`;o00001_ooool4o`0000[o
oooo0_l0000:ooooo`;o00001_ooool2o`0000oooooo0_l00007ooooo`Go0000H?ooool001cooooo
00?o0000ooooooooool0C?ooool2o`0000;ooooo0_l00005ooooo`;o00001Oooool2o`0000;ooooo
1?l00008ooooo`;o00000_ooool2o`000003ooooool0003o000000?ooooo0_l0000=ooooo`;o0000
1Oooool4o`0000Oooooo0_l00003ooooo`;o00001_ooool2o`0000Wooooo0ol0000Booooo`Co0000
1Oooool2o`0000Sooooo1?l00006ooooo`;o0000H_ooool001cooooo00?o0000ooooooooool0C?oo
ool2o`0000Wooooo0_l0000;ooooo`;o00003oooool9o`0000_ooooo0_l00007ooooo`;o00001ooo
ool2o`0001Kooooo0ol0000Booooo`?o00001_ooool2o`0000[ooooo0_l0001Zooooo`007?ooool0
0ol0003oooooooooo`1Fooooo`;o00000_ooool4o`0000Cooooo0_l0000?ooooo`;o00000_ooool7
o`0000?ooooo0_l00002ooooo`;o00002_ooool2o`0000Gooooo0_l00004ooooo`;o00005_ooool2
o`00013ooooo0ol00008ooooo`;o00005Oooool3o`0005cooooo000Looooo`03o`000?oooooooooo
05Kooooo0ol000000ooooooo0000o`000002o`0000Cooooo0_l00006ooooo`;o00000_ooool2o`00
00?ooooo0_l0000<ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo0_l00003oooo
o`;o00001Oooool2o`0000?ooooo1_l0000:ooooo`Oo00000_ooool2o`0001Oooooo0_l00002oooo
o`;o00002?ooool2o`0000;ooooo0_l00007ooooo`?o0000G?ooool001cooooo00?o0000oooooooo
ool0E_ooool3o`00017ooooo0_l00002ooooo`;o00003_ooool2o`0000Sooooo0_l00002ooooo`;o
00002_ooool2o`0000;ooooo2?l00009ooooo`Oo00000_ooool2o`0001?ooooo0ol000000ooooooo
0000o`00000<ooooo`;o00000_ooool2o`0006Kooooo000Looooo`03o`000?oooooooooo05Kooooo
0_l0000Sooooo`;o000000?oooooo`000?l000002?ooool2o`0001;ooooo0_l00004ooooo`?o0000
4Oooool2o`0000Gooooo0_l00003ooooo`;o00001oooool3o`0000Kooooo0_l00009ooooo`;o0000
J?ooool001cooooo0_l0001looooo`;o000000?oooooo`000?l000000oooool2o`0000_ooooo0_l0
0009ooooo`;o00001_ooool2o`0000?ooooo0_l000000ooooooo0000o`00000@ooooo`;o00000ooo
ool2o`0000;ooooo0_l0000<ooooo`;o00002Oooool2o`000004ooooool0003o0000o`0006Cooooo
000Looooo`03o`000?oooooooooo05Gooooo1_l0000Aooooo`;o00003?ooool2o`0000;ooooo0_l0
0003ooooo`;o00002oooool2o`0000;ooooo0_l00005ooooo`;o00001Oooool2o`0000Cooooo0_l0
00000ooooooo0000o`00000=ooooo`;o000000?oooooo`000?l000001oooool4o`0001Sooooo1Ol0
001Rooooo`007?ooool00ol0003oooooooooo`1Eooooo`Ko00003oooool4o`0000;ooooo0_l00008
ooooo`;o00004?ooool2o`0000Kooooo0_l00007ooooo`;o000000?oooooo`000?l000000_l0000F
ooooo`;o00003?ooool2o`0000Kooooo0ol00009ooooo`;o00001oooool2o`0001Sooooo0_l00018
ooooo`007?ooool00ol0003oooooooooo`1Fooooo`?o00002?ooool2o`0000Oooooo0_l00002oooo
o`Co00006_ooool2o`0000Kooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo1Ol0000E
ooooo`;o00003_ooool3o`0000?ooooo0ol00009ooooo`Co00007oooool2o`0004Sooooo000Loooo
o`03o`000?oooooooooo05Oooooo0_l00008ooooo`;o00002oooool3o`0000?ooooo0_l0000Eoooo
o`;o00001_ooool3o`0000Cooooo0_l00005ooooo`Co00009?ooool4o`0000?ooooo0_l0000<oooo
o`;o0000JOooool001cooooo00?o0000ooooooooool0Doooool2o`0001Kooooo0_l000001?oooooo
0000o`000?l00003ooooo`;o00003_ooool2o`0000Gooooo1?l00004ooooo`;o00001Oooool2o`00
00Sooooo0_l00004ooooo`;o00001Oooool2o`0000Sooooo0_l00002ooooo`;o00001?ooool2o`00
00;ooooo0_l0000?ooooo`;o0000KOooool001cooooo00?o0000ooooooooool0COooool2o`0000Co
oooo0_l0000Aooooo`;o00000oooool2o`000004ooooool0003o0000o`0000oooooo0_l00002oooo
o`;o00001oooool2o`0000Oooooo0_l00002ooooo`;o00002?ooool2o`0000Cooooo0ol00004oooo
o`?o00001oooool2o`0000;ooooo0_l00002ooooo`Ko00002?ooool2o`0000Oooooo0_l0001]oooo
o`007?ooool00ol0003oooooooooo`1=ooooo`;o00005oooool2o`0000_ooooo0_l0000;ooooo`;o
00005?ooool4o`0000Cooooo0_l00008ooooo`;o000000?oooooo`000?l000000_ooool2o`000003
ooooool0003o000000Wooooo0_l00004ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`00
00;ooooo1Ol00003ooooo`Co0000Koooool001cooooo00?o0000ooooooooool0I_ooool2o`0000_o
oooo0_l00005ooooo`Co00006_ooool2o`0000Cooooo0_l00008ooooo`;o000000?oooooo`000?l0
00000_ooool2o`0000cooooo0_l00007ooooo`;o00000_ooool2o`0000;ooooo1?l00004ooooo`Co
00001?ooool2o`0006Wooooo000Looooo`03o`000?oooooooooo05Kooooo0_l0000Rooooo`Co0000
6oooool2o`00013ooooo0_l00002ooooo`;o00000oooool2o`0000Cooooo0_l0000=ooooo`;o0000
1?ooool3o`0000;ooooo0_l00008ooooo`;o0000JOooool001cooooo00?o0000ooooooooool0E_oo
ool2o`0000Sooooo0_l0000;ooooo`;o00007Oooool2o`0000Sooooo0_l000000ooooooo0000o`00
000Dooooo`;o00000oooool2o`0000Cooooo0_l00004ooooo`;o00001oooool4o`0000Oooooo0_l0
0006ooooo`;o0000Joooool001cooooo00?o0000ooooooooool0H?ooool3o`0000[ooooo0ol00003
ooooo`;o00005oooool5o`0000Gooooo0_l000000ooooooo0000o`000005ooooo`;o00004?ooool2
o`0000Kooooo0_l00004ooooo`;o00001_ooool5o`0000oooooo0_l0001[ooooo`007?ooool00ol0
003oooooooooo`1Qooooo`;o00002oooool2o`0000?ooooo0_l0000Hooooo`Co00001?ooool4o`00
00Oooooo1?l00005ooooo`;o00001oooool2o`0000Kooooo0_l0000:ooooo`Ko00001Oooool2o`00
07Kooooo000Looooo`03o`000?oooooooooo06kooooo0_l0000Uooooo`Ko00001oooool2o`0000Go
oooo1Ol0000:ooooo`;o00001Oooool2o`0000Gooooo0_l00009ooooo`Co0000M?ooool00006oooo
ooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006
ooooo`03o`000?oooooooooo06cooooo0_l000000ooooooo0000o`00000Uooooo`;o000000?ooooo
o`000?l000002Oooool2o`0000Cooooo1?l0000:ooooo`;o00001?ooool5o`00013ooooo0_l0001d
ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooo
oonHV9So8B4Q00Kooooo00?o0000ooooooooool0JOooool5o`000003ooooool0003o000001Sooooo
0_l0000:ooooo`;o00003Oooool2o`0000Oooooo0_l00003ooooo`?o00002Oooool2o`000003oooo
ool0003o000008Kooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo06Wooooo1ol00004ooooo`;o0000
2?ooool4o`0000Oooooo0_l00003ooooo`;o00000oooool4o`000003ooooool0003o000000Kooooo
0_l00004ooooo`;o00001Oooool2o`0000?ooooo0ol00006ooooo`;o00001oooool2o`0008?ooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RH
oc8b<P06ooooo`?o0000K?ooool4o`0000;ooooo1?l00008ooooo`Co00003?ooool3o`0000;ooooo
1?l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000001?ooool2o`0000_ooooo
0_l00006ooooo`;o00001_ooool4o`0008;ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oo
oooooooo00Wooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo06_ooooo
0ol00004ooooo`Co00002Oooool2o`0000kooooo0_l00004ooooo`;o00001_ooool6o`0000kooooo
1?l00002ooooo`;o00002_ooool4o`0000;ooooo0_l0001nooooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003ooooo
ooooo`1[ooooo`?o00001_ooool2o`0000oooooo0_l00005ooooo`;o00002?ooool2o`0000;ooooo
0_l00002ooooo`Go00003_ooool2o`0000Cooooo0_l00006ooooo`;o00001?ooool6o`0007kooooo
00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zjo`000006oooo
o`03o`000?oooooooooo08Gooooo0_l00005ooooo`;o00001?ooool2o`0000;ooooo0_l00002oooo
o`;o00000_ooool2o`0000oooooo0_l00008ooooo`;o00001?ooool2o`0000Cooooo1?l00020oooo
o`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_oo
ool00ol0003oooooooooo`1oooooo`;o00003?ooool2o`0000?ooooo0_l0000Aooooo`;o00002?oo
ool2o`0000?ooooo0_l00003ooooo`;o00001oooool2o`0001Sooooo0_l0001[ooooo`007?ooool0
0ol0003oooooooooo`1mooooo`Co00002oooool3o`0000?ooooo0_l0000;ooooo`;o00001?ooool2
o`0000Sooooo0_l00003ooooo`;o00003?ooool2o`0001Sooooo0_l0001[ooooo`007?ooool00ol0
003oooooooooo`1mooooo`;o00003Oooool2o`0000Cooooo0_l00006ooooo`;o00000_ooool3o`00
0003ooooool0003o000000?ooooo0_l00006ooooo`;o0000V?ooool001cooooo00?o0000oooooooo
ool0P_ooool2o`0000Kooooo0_l00006ooooo`?o00001Oooool2o`0000;ooooo0_l00002ooooo`?o
00000_ooool2o`0000Kooooo0_l0002Hooooo`007?ooool00ol0003oooooooooo`22ooooo`;o0000
1_ooool2o`0000Oooooo1_l00004ooooo`;o00001?ooool2o`0000;ooooo1?l0000Uooooo`;o0000
0oooool2o`0007;ooooo000Looooo`03o`000?oooooooooo08Sooooo0ol0000:ooooo`Co00001?oo
ool2o`0000Gooooo0_l000000ooooooo0000o`000005o`0000Cooooo0_l00009ooooo`;o00004Ooo
ool2o`0000?ooooo0_l0001booooo`007?ooool00ol0003oooooooooo`28ooooo`?o00004Oooool3
o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`Ko00001?ooool2o`0000Wooooo0_l00003
ooooo`;o0000QOooool001cooooo00?o0000ooooooooool0QOooool2o`00013ooooo0_l00003oooo
o`;o000000?oooooo`000?l000001Ol00002ooooo`?o00005oooool2o`0008Gooooo000Looooo`03
o`000?oooooooooo08Gooooo0ol0000?ooooo`;o00001_ooool2o`000003ooooool0003o000000;o
00000oooool4o`0009cooooo000Looooo`03o`000?oooooooooo08Kooooo0_l00009ooooo`;o0000
6?ooool2o`0009cooooo000Looooo`03o`000?oooooooooo08Sooooo0_l00007ooooo`;o0000]_oo
ool001cooooo00?o0000ooooooooool0R?ooool2o`0000Oooooo0_l0000Eooooo`;o0000Woooool0
01cooooo0_l0002Booooo`;o00005Oooool2o`0002;ooooo0_l0001kooooo`007?ooool00ol0003o
ooooooooo`2Aooooo`;o00001?ooool2o`0003?ooooo0_l0001kooooo`007?ooool00ol0003ooooo
ooooo`1hooooo`;o00005oooool2o`0000Cooooo0_l0000Dooooo`;o0000V_ooool001cooooo00?o
0000ooooooooool0N?ooool2o`0001?ooooo0_l00002ooooo`;o00000oooool2o`0001Gooooo0_l0
002Jooooo`007?ooool00ol0003oooooooooo`2=ooooo`;o00000_ooool2o`0000?ooooo0_l0000J
ooooo`;o0000UOooool001cooooo00?o0000ooooooooool0TOooool2o`000003ooooool0003o0000
00;ooooo0_l0000Hooooo`;o0000UOooool001cooooo00?o0000ooooooooool0U?ooool2o`0000;o
oooo0_l0002_ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo09Cooooo0_l00002ooooo`;o0000[oooool001cooooo00?o0000ooooooooool0Qoooool2
o`0000_ooooo0_l00002ooooo`;o0000[oooool001cooooo00?o0000ooooooooool0Qoooool4o`00
0;kooooo000Looooo`03o`000?oooooooooo08Wooooo0_l0000]ooooo`;o0000Soooool001cooooo
00?o0000ooooooooool0^?ooool2o`0008oooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`004_ooool4o`000003
oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000ooooooooool01Ooo
ool3o`000?ooooooB_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0
003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo
00?o0000ooooooooool0oooooomBooooo`004_ooool00omEEEGoIVIVo`00003ooooooeCooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo002Qooooo`04oa0@4?l0003o0000ooooo`;o
000000?o410@ooooooooool05_ooool4o`000003oa0@4?oooooooooo00;ooooo0_l000000ol@413o
ooooooooo`02ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool5o`0008cooooo002Rooooo`05
o`000?ooooooooooooooool000002Oooool6o`0000cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`09ogMgMolb<S;ooooooooooonHV9So8B4Qonk^k_ooooooA4A408cooooo
002Rooooo`05o`000?ooooooooooooooool000006oooool00ol0003oooooooooo`02ooooo`Go0000
2?ooool01ol0003oooooooooooooooooV9RHob4Q8Oo^k^h0SOooool00:;ooooo00Go0000oooooooo
ooooooooo`000009ooooo`Ko00003?ooool00ol0003oooooooooo`02ooooo`04odA4A?oMgMgooooo
o`0000Sooooo00?oMgMgoc8b<_ooool00oooool00onHV9So8B4Qonk^kP2<ooooo`00X_ooool01Ol0
003oQhN7oooooonYZJWo000001_ooooo00?o0000ooooooooool00_ooool01?oMgMgoEEEEooooool0
0005ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00omgMgOoIVIVooooo`2;ooooo`00XOoo
ool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo01Wooooo00?o0000ooooooooool00ooo
ool00omgMgOoc<c<o`000005ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0R_oo
ool00<;ooooo00?o0000ooooooooool00oooool00oo^k^koA4A4o`000005ooooo`03o`000?oooooo
oooo00Cooooo00Go0000okZj^_ooooooV9RHoa0@402<ooooo`00`?ooool00omEEEGoIVIVo`000006
ooooo`03ogMgMol0003ooooo00Cooooo1?l00003ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0S?oo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1458) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.69345 .47638 Mdot
.6948 .48476 Mdot
.39443 .38398 Mdot
.54406 .63236 Mdot
.27513 .70689 Mdot
.38956 .42237 Mdot
.53526 .37692 Mdot
.55081 .37632 Mdot
.39632 .3771 Mdot
.73053 .42564 Mdot
.57891 .36047 Mdot
.4605 .67947 Mdot
.55269 .34916 Mdot
.51168 .66066 Mdot
.62729 .84111 Mdot
.53721 .7002 Mdot
.69148 .47929 Mdot
.26443 .58185 Mdot
.5337 .69282 Mdot
.42196 .41447 Mdot
.64078 .43797 Mdot
.51473 .65647 Mdot
.67526 .47163 Mdot
.5111 .66086 Mdot
.52998 .61847 Mdot
.66804 .46642 Mdot
.65755 .5295 Mdot
.51076 .59762 Mdot
.48371 .63314 Mdot
.57902 .36711 Mdot
.3275 .60199 Mdot
.48046 .83341 Mdot
.58263 .58498 Mdot
.46034 .76429 Mdot
.53077 .3296 Mdot
.68557 .67155 Mdot
.38023 .40913 Mdot
.56013 .37062 Mdot
.56689 .36647 Mdot
.5392 .36843 Mdot
.54915 .37091 Mdot
.6591 .48668 Mdot
.68198 .30032 Mdot
.51027 .2889 Mdot
.46568 .61947 Mdot
.19898 .56361 Mdot
.61605 .71086 Mdot
.53588 .66797 Mdot
.63117 .48562 Mdot
.27894 .38736 Mdot
.47541 .26796 Mdot
.52393 .32211 Mdot
.42254 .39412 Mdot
.45791 .10715 Mdot
.55769 .33803 Mdot
.49423 .57171 Mdot
.38855 .39814 Mdot
.50672 .64406 Mdot
.50627 .66114 Mdot
.74202 .54976 Mdot
.53158 .57521 Mdot
.33475 .52932 Mdot
.71033 .46808 Mdot
.44791 .48985 Mdot
.40081 .39773 Mdot
.57485 .35994 Mdot
.66736 .5136 Mdot
.55106 .33419 Mdot
.58747 .57567 Mdot
.34458 .38782 Mdot
.54852 .66165 Mdot
.57699 .36328 Mdot
.64704 .43957 Mdot
.49798 .61588 Mdot
.26177 .38446 Mdot
.18544 .53785 Mdot
.33914 .56483 Mdot
.69759 .64152 Mdot
.74572 .54278 Mdot
.26593 .45367 Mdot
.48079 .60407 Mdot
.31736 .64778 Mdot
.19151 .52836 Mdot
.62558 .49751 Mdot
.56122 .67575 Mdot
.33327 .58637 Mdot
.50193 .6116 Mdot
.23188 .68569 Mdot
.56225 .58801 Mdot
.47514 .51027 Mdot
.37155 .37598 Mdot
.64575 .46087 Mdot
.54208 .6263 Mdot
.48588 .64104 Mdot
.77205 .54824 Mdot
.54844 .66876 Mdot
.52553 .64432 Mdot
.63231 .50331 Mdot
.52927 .31853 Mdot
.53165 .56728 Mdot
.35549 .45853 Mdot
.38217 .4338 Mdot
.53846 .58674 Mdot
.34946 .39078 Mdot
.64521 .4425 Mdot
.48649 .64021 Mdot
.56584 .36033 Mdot
.54854 .6002 Mdot
.52371 .21107 Mdot
.68533 .48482 Mdot
.49079 .60878 Mdot
.29431 .55517 Mdot
.66267 .58425 Mdot
.63759 .46173 Mdot
.53448 .28742 Mdot
.52468 .69324 Mdot
.51879 .63424 Mdot
.66212 .51545 Mdot
.38008 .4365 Mdot
.21425 .63828 Mdot
.6407 .51534 Mdot
.57877 .32786 Mdot
.62271 .45619 Mdot
.45009 .66078 Mdot
.40745 .39916 Mdot
.52389 .28619 Mdot
.5965 .26323 Mdot
.35326 .61507 Mdot
.50406 .61399 Mdot
.70574 .31923 Mdot
.41137 .42915 Mdot
.6434 .47921 Mdot
.54943 .33747 Mdot
.57848 .59938 Mdot
.66996 .49791 Mdot
.57802 .33598 Mdot
.30468 .51956 Mdot
.46307 .23389 Mdot
.68237 .45407 Mdot
.54775 .43394 Mdot
.53722 .31303 Mdot
.52147 .34523 Mdot
.71155 .74565 Mdot
.64602 .50674 Mdot
.3073 .54795 Mdot
.54218 .33607 Mdot
.39968 .60428 Mdot
.47037 .60764 Mdot
.29339 .63259 Mdot
.6092 .2078 Mdot
.44835 .73969 Mdot
.41098 .27638 Mdot
.29542 .54295 Mdot
.52158 .31089 Mdot
.53406 .63691 Mdot
.66634 .45652 Mdot
.67132 .47051 Mdot
.53201 .57569 Mdot
.53276 .60484 Mdot
.56186 .64744 Mdot
.52177 .68012 Mdot
.50294 .52199 Mdot
.57306 .60414 Mdot
.63026 .69138 Mdot
.65 .45667 Mdot
.54149 .63792 Mdot
.41917 .38929 Mdot
.47173 .673 Mdot
.56559 .3756 Mdot
.51187 .64851 Mdot
.54243 .6302 Mdot
.49822 .58259 Mdot
.52083 .3292 Mdot
.44592 .82057 Mdot
.62435 .57255 Mdot
.41908 .78609 Mdot
.56766 .49797 Mdot
.37998 .36036 Mdot
.51037 .60813 Mdot
.32618 .54114 Mdot
.72782 .66337 Mdot
.55317 .63165 Mdot
.16639 .33952 Mdot
.52365 .65141 Mdot
.33728 .76563 Mdot
.55451 .70656 Mdot
.4373 .77627 Mdot
.33055 .63957 Mdot
.5258 .62125 Mdot
.7353 .38686 Mdot
.57634 .39634 Mdot
.32883 .40015 Mdot
.54338 .3624 Mdot
.4197 .39748 Mdot
.39392 .38903 Mdot
.39216 .49818 Mdot
.47162 .69872 Mdot
.48623 .69028 Mdot
.56744 .61855 Mdot
.35588 .4251 Mdot
.67999 .51696 Mdot
.29019 .55149 Mdot
.70865 .45848 Mdot
.40352 .83246 Mdot
.29963 .34782 Mdot
.57305 .38212 Mdot
.29679 .51877 Mdot
.35779 .39698 Mdot
.37718 .37285 Mdot
.29131 .54183 Mdot
.49007 .65718 Mdot
.64873 .50719 Mdot
.59999 .79485 Mdot
.44655 .2087 Mdot
.87164 .53451 Mdot
.62977 .49651 Mdot
.71164 .3451 Mdot
.56228 .37956 Mdot
.37353 .39825 Mdot
.52089 .63674 Mdot
.49389 .63901 Mdot
.65466 .43424 Mdot
.54736 .66311 Mdot
.60934 .46849 Mdot
.52286 .62777 Mdot
.55627 .39642 Mdot
.34936 .55625 Mdot
.3916 .49878 Mdot
.38314 .6339 Mdot
.63651 .45314 Mdot
.79067 .61034 Mdot
.37663 .36945 Mdot
.73661 .65105 Mdot
.57638 .35043 Mdot
.31975 .51571 Mdot
.40409 .37138 Mdot
.30068 .56116 Mdot
.56892 .64869 Mdot
.4137 .41711 Mdot
.31548 .56115 Mdot
.41072 .55449 Mdot
.4658 .64299 Mdot
.43289 .18755 Mdot
.53371 .3593 Mdot
.70265 .46652 Mdot
.55345 .60199 Mdot
.3624 .37227 Mdot
.5633 .55488 Mdot
.34315 .31074 Mdot
.54371 .24792 Mdot
.41563 .4276 Mdot
.38425 .53282 Mdot
.32773 .51518 Mdot
.45111 .29315 Mdot
.70316 .32287 Mdot
.69943 .47824 Mdot
.56526 .65175 Mdot
.49386 .8266 Mdot
.54281 .33577 Mdot
.55318 .61064 Mdot
.25298 .63505 Mdot
.53782 .32423 Mdot
.50647 .64171 Mdot
.56948 .32203 Mdot
.67135 .47126 Mdot
.7528 .51844 Mdot
.6565 .51607 Mdot
.54536 .66606 Mdot
.56453 .35226 Mdot
.38071 .44011 Mdot
.66205 .46891 Mdot
.49783 .67024 Mdot
.51223 .59963 Mdot
.41749 .51788 Mdot
.5386 .64637 Mdot
.41219 .79637 Mdot
.52428 .62411 Mdot
.38108 .38682 Mdot
.49312 .59249 Mdot
.77825 .40126 Mdot
.38853 .49435 Mdot
.65729 .51386 Mdot
.42234 .42326 Mdot
.4018 .38701 Mdot
.22039 .45333 Mdot
.5156 .30583 Mdot
.48679 .67685 Mdot
.36986 .36665 Mdot
.42399 .64027 Mdot
.56385 .32783 Mdot
.54769 .58314 Mdot
.51293 .40949 Mdot
.30686 .35973 Mdot
.42376 .40341 Mdot
.46788 .57184 Mdot
.66951 .44446 Mdot
.53965 .61864 Mdot
.35931 .38112 Mdot
.47784 .71426 Mdot
.48297 .62039 Mdot
.68166 .27161 Mdot
.40213 .52886 Mdot
.5394 .3156 Mdot
.47386 .68544 Mdot
.56153 .62587 Mdot
.40819 .41851 Mdot
.64594 .44715 Mdot
.5564 .32104 Mdot
.6601 .47951 Mdot
.43842 .77001 Mdot
.44692 .19046 Mdot
.45829 .52295 Mdot
.33515 .5626 Mdot
.31787 .41853 Mdot
.44967 .78362 Mdot
.8169 .51763 Mdot
.71117 .71789 Mdot
.50666 .79275 Mdot
.35137 .40233 Mdot
.30239 .40068 Mdot
.39694 .39322 Mdot
.52345 .59418 Mdot
.40422 .40231 Mdot
.51028 .83472 Mdot
.52397 .63174 Mdot
.3953 .41061 Mdot
.78359 .58163 Mdot
.53845 .62422 Mdot
.69965 .48 Mdot
.38498 .80975 Mdot
.79783 .38736 Mdot
.58746 .28362 Mdot
.3672 .40779 Mdot
.62253 .77959 Mdot
.52743 .64493 Mdot
.49472 .59199 Mdot
.65609 .45097 Mdot
.57682 .57402 Mdot
.33309 .54522 Mdot
.30109 .51452 Mdot
.59859 .36356 Mdot
.36261 .52436 Mdot
.47178 .68399 Mdot
.66166 .46592 Mdot
.53345 .52053 Mdot
.23268 .44085 Mdot
.28652 .38311 Mdot
.58145 .38305 Mdot
.38388 .80833 Mdot
.61306 .41818 Mdot
.6032 .40727 Mdot
.43212 .34177 Mdot
.63553 .4802 Mdot
.47119 .83311 Mdot
.54749 .36523 Mdot
.38232 .20218 Mdot
.74343 .42361 Mdot
.49092 .65298 Mdot
.56686 .33769 Mdot
.52618 .54706 Mdot
.79961 .41266 Mdot
.3246 .24865 Mdot
.57074 .74537 Mdot
.5594 .58699 Mdot
.29842 .35516 Mdot
.51599 .64399 Mdot
.33179 .32768 Mdot
.52208 .61497 Mdot
.65675 .47988 Mdot
.73012 .4217 Mdot
.56767 .28725 Mdot
.61502 .54007 Mdot
.44287 .30402 Mdot
.29676 .54865 Mdot
.52047 .62741 Mdot
.49187 .65663 Mdot
.33509 .54845 Mdot
.68031 .46553 Mdot
.55598 .65728 Mdot
.79691 .59536 Mdot
.48594 .65735 Mdot
.56009 .37481 Mdot
.75851 .43938 Mdot
.60797 .66459 Mdot
.51688 .68684 Mdot
.62133 .49072 Mdot
.55603 .38464 Mdot
.56291 .35462 Mdot
.53273 .71539 Mdot
.58122 .37 Mdot
.53046 .65596 Mdot
.29996 .26767 Mdot
.68704 .46235 Mdot
.61638 .23045 Mdot
.66282 .50557 Mdot
.69178 .62842 Mdot
.52979 .32146 Mdot
.49475 .23301 Mdot
.51403 .55058 Mdot
.5482 .36211 Mdot
.6484 .54384 Mdot
.47568 .66062 Mdot
.47549 .66428 Mdot
.60211 .78981 Mdot
.37147 .38406 Mdot
.41128 .51796 Mdot
.57965 .36605 Mdot
.51713 .67054 Mdot
.53474 .68602 Mdot
.55371 .38315 Mdot
.36607 .24488 Mdot
.79437 .46946 Mdot
.52401 .62704 Mdot
.65112 .47719 Mdot
.64462 .48448 Mdot
.46358 .6142 Mdot
.53897 .59123 Mdot
.4141 .38947 Mdot
.39495 .44248 Mdot
.3758 .35731 Mdot
.40326 .52087 Mdot
.52402 .23689 Mdot
.23903 .66122 Mdot
.53822 .36725 Mdot
.68803 .34761 Mdot
.44972 .52155 Mdot
.56621 .59167 Mdot
.36732 .41392 Mdot
.56084 .63054 Mdot
.54662 .64898 Mdot
.49505 .31828 Mdot
.28886 .70715 Mdot
.65613 .41062 Mdot
.64075 .44799 Mdot
.52138 .31453 Mdot
.48525 .69804 Mdot
.50732 .37818 Mdot
.32578 .52045 Mdot
.45116 .73067 Mdot
.57772 .35379 Mdot
.6935 .49082 Mdot
.52922 .34352 Mdot
.49149 .63753 Mdot
.53305 .55616 Mdot
.63703 .48282 Mdot
.33845 .53041 Mdot
.58207 .59984 Mdot
.50893 .63874 Mdot
.56395 .17868 Mdot
.41006 .65185 Mdot
.60179 .39954 Mdot
.52616 .62479 Mdot
.48616 .66928 Mdot
.31462 .50323 Mdot
.486 .65367 Mdot
.56414 .61054 Mdot
.65853 .59204 Mdot
.62789 .32323 Mdot
.28385 .53761 Mdot
.31636 .26357 Mdot
.63055 .497 Mdot
.47769 .8203 Mdot
.37635 .42035 Mdot
.59116 .31728 Mdot
.78328 .46011 Mdot
.42034 .38112 Mdot
.4028 .28204 Mdot
.46587 .8156 Mdot
.36402 .46462 Mdot
.37945 .34982 Mdot
.70786 .48334 Mdot
.52968 .67393 Mdot
.51572 .63474 Mdot
.32696 .5435 Mdot
.64974 .50483 Mdot
.51604 .48124 Mdot
.18197 .44789 Mdot
.51635 .65453 Mdot
.66921 .26504 Mdot
.29837 .3038 Mdot
.29375 .36825 Mdot
.319 .53396 Mdot
.30147 .51226 Mdot
.51878 .62713 Mdot
.64705 .57896 Mdot
.6675 .46561 Mdot
.49887 .67038 Mdot
.5725 .60013 Mdot
.36693 .39289 Mdot
.68181 .48466 Mdot
.38164 .43702 Mdot
.4615 .26369 Mdot
.40281 .78089 Mdot
.36589 .19103 Mdot
.55171 .3272 Mdot
.26133 .36304 Mdot
.56548 .32282 Mdot
.32426 .65094 Mdot
.42487 .38114 Mdot
.54181 .61005 Mdot
.65502 .44553 Mdot
.52475 .66808 Mdot
.53992 .595 Mdot
.4911 .65876 Mdot
.52474 .6858 Mdot
.39888 .16819 Mdot
.29627 .5514 Mdot
.5706 .65393 Mdot
.38635 .38473 Mdot
.19914 .53433 Mdot
.19777 .48258 Mdot
.49409 .65712 Mdot
.51745 .60843 Mdot
.67696 .48168 Mdot
.54495 .58548 Mdot
.56286 .32245 Mdot
.70419 .47771 Mdot
.49278 .62121 Mdot
.31843 .77448 Mdot
.48373 .62922 Mdot
.43744 .78683 Mdot
.53036 .34453 Mdot
.46542 .20439 Mdot
.54348 .55776 Mdot
.55667 .25673 Mdot
.41141 .51805 Mdot
.40801 .37352 Mdot
.55679 .311 Mdot
.38255 .41033 Mdot
.19055 .41491 Mdot
.46233 .59401 Mdot
.53346 .63272 Mdot
.56796 .60283 Mdot
.3792 .36035 Mdot
.25725 .7323 Mdot
.46215 .30746 Mdot
.46056 .59354 Mdot
.41698 .3938 Mdot
.64306 .52587 Mdot
.51163 .77444 Mdot
.65982 .49537 Mdot
.35382 .52924 Mdot
.55826 .37789 Mdot
.33787 .53243 Mdot
.35317 .71425 Mdot
.68757 .48614 Mdot
.67866 .43362 Mdot
.37499 .41721 Mdot
.72994 .45254 Mdot
.76634 .26798 Mdot
.74389 .42111 Mdot
.35315 .6368 Mdot
.66072 .45786 Mdot
.48399 .63735 Mdot
.3297 .6782 Mdot
.73858 .42364 Mdot
.38521 .40925 Mdot
.55478 .64272 Mdot
.76007 .51043 Mdot
.41412 .38819 Mdot
.55268 .5695 Mdot
.38301 .3816 Mdot
.53886 .35774 Mdot
.36329 .40484 Mdot
.6391 .43347 Mdot
.5003 .60583 Mdot
.78517 .27723 Mdot
.36884 .52447 Mdot
.52975 .64179 Mdot
.51514 .32493 Mdot
.39082 .25762 Mdot
.54875 .61819 Mdot
.32606 .56224 Mdot
.40144 .4129 Mdot
.72144 .47743 Mdot
.5231 .62228 Mdot
.41744 .39456 Mdot
.6952 .46423 Mdot
.50881 .32208 Mdot
.7693 .54557 Mdot
.61496 .35458 Mdot
.65182 .44985 Mdot
.58389 .47145 Mdot
.53678 .29982 Mdot
.48807 .67258 Mdot
.55069 .66753 Mdot
.6493 .4815 Mdot
.25437 .59548 Mdot
.51773 .5808 Mdot
.48797 .5974 Mdot
.37104 .39206 Mdot
.38504 .41451 Mdot
.70197 .72153 Mdot
.36908 .43023 Mdot
.54683 .5612 Mdot
.65026 .48412 Mdot
.54355 .62791 Mdot
.6808 .47963 Mdot
.5454 .58651 Mdot
.56899 .70519 Mdot
.67998 .46476 Mdot
.4957 .32521 Mdot
.55206 .6447 Mdot
.58624 .6224 Mdot
.5499 .60426 Mdot
.52213 .67722 Mdot
.41206 .39017 Mdot
.32541 .53592 Mdot
.56958 .59354 Mdot
.28859 .56817 Mdot
.28866 .54378 Mdot
.57925 .28539 Mdot
.36725 .3902 Mdot
.30843 .55356 Mdot
.25562 .32501 Mdot
.41778 .40922 Mdot
.3268 .547 Mdot
.19732 .48566 Mdot
.52955 .32863 Mdot
.66774 .44305 Mdot
.53713 .62034 Mdot
.40794 .73836 Mdot
.61693 .70016 Mdot
.43952 .38729 Mdot
.52591 .62921 Mdot
.55396 .61531 Mdot
.64087 .51836 Mdot
.16093 .49668 Mdot
.34603 .3843 Mdot
.47995 .64326 Mdot
.68967 .49049 Mdot
.14371 .54352 Mdot
.38643 .38927 Mdot
.33007 .54336 Mdot
.52439 .33531 Mdot
.68298 .52094 Mdot
.58881 .25256 Mdot
.51733 .34366 Mdot
.41871 .44669 Mdot
.47359 .2626 Mdot
.54587 .68295 Mdot
.37884 .42809 Mdot
.81923 .6252 Mdot
.49238 .52769 Mdot
.43586 .49799 Mdot
.5994 .78068 Mdot
.63634 .47043 Mdot
.56495 .32307 Mdot
.29464 .54345 Mdot
.62824 .48819 Mdot
.69096 .47833 Mdot
.54784 .37917 Mdot
.62694 .58898 Mdot
.50972 .40554 Mdot
.56572 .37054 Mdot
.41833 .70808 Mdot
.23307 .59406 Mdot
.37202 .42119 Mdot
.33245 .54633 Mdot
.33845 .71653 Mdot
.66054 .48363 Mdot
.42932 .84049 Mdot
.61985 .7914 Mdot
.52556 .6446 Mdot
.30109 .54628 Mdot
.25575 .71935 Mdot
.16882 .51518 Mdot
.53772 .3226 Mdot
.58375 .29774 Mdot
.33366 .51978 Mdot
.55458 .60521 Mdot
.43126 .68865 Mdot
.51254 .5881 Mdot
.54958 .37436 Mdot
.76684 .57402 Mdot
.68983 .48302 Mdot
.52904 .35825 Mdot
.47235 .75377 Mdot
.52809 .65691 Mdot
.55334 .64089 Mdot
.39078 .66934 Mdot
.62661 .48616 Mdot
.4068 .3722 Mdot
.55414 .66839 Mdot
.51016 .64257 Mdot
.53524 .55925 Mdot
.45893 .61992 Mdot
.69285 .56636 Mdot
.52312 .59904 Mdot
.25435 .38438 Mdot
.5582 .59023 Mdot
.53829 .65896 Mdot
.62188 .47821 Mdot
.332 .20829 Mdot
.46682 .27599 Mdot
.51178 .64621 Mdot
.48265 .66178 Mdot
.52708 .3529 Mdot
.49242 .38723 Mdot
.71381 .4225 Mdot
.71846 .48133 Mdot
.66707 .7558 Mdot
.46659 .64705 Mdot
.66965 .51167 Mdot
.32378 .56056 Mdot
.4867 .6755 Mdot
.68262 .50201 Mdot
.49044 .5886 Mdot
.41422 .38329 Mdot
.41869 .4065 Mdot
.54948 .52655 Mdot
.3101 .55579 Mdot
.75902 .37784 Mdot
.68487 .34627 Mdot
.41257 .41526 Mdot
.53264 .62818 Mdot
.57305 .39861 Mdot
.36524 .37666 Mdot
.35699 .4661 Mdot
.25708 .62551 Mdot
.66734 .4548 Mdot
.64681 .45745 Mdot
.28899 .63308 Mdot
.42967 .26295 Mdot
.67637 .25449 Mdot
.53929 .35995 Mdot
.57471 .63695 Mdot
.72826 .36269 Mdot
.64387 .45658 Mdot
.33073 .66564 Mdot
.30217 .55029 Mdot
.53722 .32501 Mdot
.46279 .3405 Mdot
.67038 .49203 Mdot
.69101 .45009 Mdot
.52459 .57201 Mdot
.50137 .63948 Mdot
.72576 .69918 Mdot
.28161 .56383 Mdot
.53138 .37232 Mdot
.3327 .54389 Mdot
.42683 .38666 Mdot
.50572 .59418 Mdot
.67772 .46679 Mdot
.22807 .60351 Mdot
.50666 .6897 Mdot
.40267 .37696 Mdot
.63931 .46526 Mdot
.32475 .51338 Mdot
.33458 .55955 Mdot
.51672 .68164 Mdot
.75635 .6533 Mdot
.55681 .36783 Mdot
.63619 .49539 Mdot
.582 .40913 Mdot
.51786 .58534 Mdot
.50542 .63084 Mdot
.58192 .67227 Mdot
.52927 .36936 Mdot
.65019 .39108 Mdot
.31932 .56562 Mdot
.64432 .49871 Mdot
.52152 .60217 Mdot
.32569 .5517 Mdot
.69789 .35022 Mdot
.43184 .41006 Mdot
.36147 .40141 Mdot
.33692 .55683 Mdot
.31018 .53244 Mdot
.3153 .56459 Mdot
.43232 .84299 Mdot
.6657 .51988 Mdot
.6044 .42113 Mdot
.47505 .63489 Mdot
.33841 .63768 Mdot
.57534 .64371 Mdot
.54407 .31391 Mdot
.37457 .38135 Mdot
.54606 .60726 Mdot
.50901 .68496 Mdot
.56475 .70088 Mdot
.63903 .24076 Mdot
.60587 .60888 Mdot
.68557 .48162 Mdot
.53191 .55523 Mdot
.36817 .4073 Mdot
.434 .85797 Mdot
.64978 .79344 Mdot
.53846 .5562 Mdot
.51554 .4051 Mdot
.67708 .45916 Mdot
.53887 .36881 Mdot
.38288 .6972 Mdot
.52771 .33147 Mdot
.64206 .49199 Mdot
.51965 .59541 Mdot
.68123 .36635 Mdot
.2984 .50595 Mdot
.51955 .67257 Mdot
.53834 .3624 Mdot
.54701 .66221 Mdot
.52446 .36076 Mdot
.40594 .74662 Mdot
.80401 .63018 Mdot
.52356 .65036 Mdot
.54263 .69275 Mdot
.75274 .67602 Mdot
.49774 .66298 Mdot
.25883 .55522 Mdot
.67686 .45838 Mdot
.77299 .5722 Mdot
.50769 .70142 Mdot
.45985 .71765 Mdot
.50938 .58699 Mdot
.78268 .54077 Mdot
.50251 .63156 Mdot
.29001 .36931 Mdot
.49435 .60598 Mdot
.56546 .61255 Mdot
.56037 .33935 Mdot
.52705 .35494 Mdot
.63076 .45102 Mdot
.35423 .38123 Mdot
.43154 .78899 Mdot
.50824 .63521 Mdot
.50839 .23878 Mdot
.63614 .35442 Mdot
.31353 .53204 Mdot
.64485 .49562 Mdot
.15775 .57141 Mdot
.58273 .34633 Mdot
.70069 .74846 Mdot
.65848 .75356 Mdot
.62822 .29102 Mdot
.29384 .69635 Mdot
.35135 .27505 Mdot
.32554 .51594 Mdot
.50214 .58062 Mdot
.30579 .47992 Mdot
.28689 .36991 Mdot
.2496 .59583 Mdot
.5502 .30596 Mdot
.72386 .67663 Mdot
.25865 .65957 Mdot
.35006 .541 Mdot
.31147 .50823 Mdot
.51974 .32751 Mdot
.34146 .35654 Mdot
.4646 .68956 Mdot
.29929 .5394 Mdot
.37474 .35965 Mdot
.4209 .4114 Mdot
.36298 .36191 Mdot
.67013 .46659 Mdot
.6551 .78592 Mdot
.55371 .30218 Mdot
.54491 .31635 Mdot
.3231 .36881 Mdot
.51504 .74855 Mdot
.70322 .44496 Mdot
.37442 .40614 Mdot
.36178 .41546 Mdot
.6773 .45536 Mdot
.49507 .57373 Mdot
.4572 .60957 Mdot
.51405 .65091 Mdot
.32492 .54011 Mdot
.49822 .63687 Mdot
.4153 .40016 Mdot
.54705 .32605 Mdot
.35763 .40335 Mdot
.5133 .33194 Mdot
.22148 .61072 Mdot
.50025 .67543 Mdot
.50034 .60364 Mdot
.51393 .16679 Mdot
.67251 .43817 Mdot
.20385 .55173 Mdot
.50453 .3582 Mdot
.39563 .39189 Mdot
.56363 .61094 Mdot
.71114 .45439 Mdot
.27348 .53951 Mdot
.37093 .19356 Mdot
.53444 .58502 Mdot
.66839 .48198 Mdot
.50959 .59454 Mdot
.44562 .54774 Mdot
.74231 .30706 Mdot
.65486 .48838 Mdot
.64738 .23447 Mdot
.48166 .64273 Mdot
.26336 .33122 Mdot
.55367 .58808 Mdot
.41265 .55934 Mdot
.51788 .58084 Mdot
.63072 .49858 Mdot
.50999 .65066 Mdot
.70997 .46219 Mdot
.40389 .42473 Mdot
.5293 .3535 Mdot
.65175 .45127 Mdot
.53409 .67906 Mdot
.63843 .11986 Mdot
.53633 .34567 Mdot
.52073 .63247 Mdot
.52315 .32729 Mdot
.65553 .5083 Mdot
.63125 .48093 Mdot
.18448 .48376 Mdot
.45743 .26517 Mdot
.53896 .35578 Mdot
.5067 .59428 Mdot
.28629 .33166 Mdot
.53604 .60438 Mdot
.42501 .65511 Mdot
.49678 .57018 Mdot
.47645 .60596 Mdot
.1891 .50863 Mdot
.53672 .31505 Mdot
.67441 .25068 Mdot
.17773 .51682 Mdot
.19824 .53168 Mdot
.63929 .43799 Mdot
.34801 .54221 Mdot
.46192 .82878 Mdot
.52917 .23869 Mdot
.41533 .38006 Mdot
.54843 .61045 Mdot
.62543 .53773 Mdot
.56097 .36625 Mdot
.3262 .524 Mdot
.52326 .64924 Mdot
.36358 .41488 Mdot
.80946 .49858 Mdot
.52185 .31173 Mdot
.65694 .49152 Mdot
.63762 .52095 Mdot
.22417 .32447 Mdot
.52456 .6163 Mdot
.49676 .6098 Mdot
.55787 .37803 Mdot
.3713 .25707 Mdot
.29352 .52643 Mdot
.78417 .57657 Mdot
.53932 .35353 Mdot
.50912 .46209 Mdot
.68413 .50198 Mdot
.55624 .61686 Mdot
.32056 .76344 Mdot
.45009 .33166 Mdot
.55729 .18838 Mdot
.32479 .54205 Mdot
.42272 .64272 Mdot
.63127 .49864 Mdot
.54685 .33732 Mdot
.43289 .24554 Mdot
.4721 .6588 Mdot
.55888 .64254 Mdot
.41503 .5866 Mdot
.57059 .28352 Mdot
.71106 .42812 Mdot
.53086 .58515 Mdot
.41108 .51577 Mdot
.53998 .58691 Mdot
.55499 .69479 Mdot
.49291 .5678 Mdot
.50609 .61959 Mdot
.6751 .47287 Mdot
.43801 .60978 Mdot
.386 .36349 Mdot
.65631 .41393 Mdot
.49729 .46601 Mdot
.52715 .63656 Mdot
.48561 .60167 Mdot
.58561 .73553 Mdot
.37578 .28917 Mdot
.65311 .45302 Mdot
.65939 .42821 Mdot
.58355 .35656 Mdot
.47043 .59298 Mdot
.35365 .38288 Mdot
.58085 .62046 Mdot
.41027 .38711 Mdot
.67607 .46956 Mdot
.39206 .39127 Mdot
.52231 .33835 Mdot
.38518 .43114 Mdot
.51694 .23482 Mdot
.53757 .3351 Mdot
.66191 .45098 Mdot
.49576 .62095 Mdot
.51475 .32459 Mdot
.37134 .61617 Mdot
.32306 .54187 Mdot
.1979 .65502 Mdot
.49227 .62112 Mdot
.61459 .2947 Mdot
.51394 .729 Mdot
.35903 .40876 Mdot
.7273 .28913 Mdot
.65065 .44384 Mdot
.28673 .5273 Mdot
.62624 .47665 Mdot
.45404 .73072 Mdot
.31043 .53948 Mdot
.18564 .60555 Mdot
.40564 .53914 Mdot
.41166 .64917 Mdot
.4749 .5916 Mdot
.39446 .65109 Mdot
.42657 .3998 Mdot
.56099 .36404 Mdot
.42154 .25798 Mdot
.5647 .61764 Mdot
.83189 .52593 Mdot
.62304 .48491 Mdot
.36357 .3727 Mdot
.55136 .33729 Mdot
.55115 .3171 Mdot
.4776 .65479 Mdot
.27418 .42295 Mdot
.56047 .64146 Mdot
.44814 .25372 Mdot
.62169 .77798 Mdot
.60414 .42962 Mdot
.52276 .62832 Mdot
.40751 .41945 Mdot
.50993 .59449 Mdot
.3235 .56578 Mdot
.73866 .71946 Mdot
.5848 .61431 Mdot
.53876 .3912 Mdot
.27436 .55839 Mdot
.64509 .50855 Mdot
.54542 .72221 Mdot
.61029 .39405 Mdot
.52488 .61259 Mdot
.34593 .17137 Mdot
.32557 .54936 Mdot
.31148 .47486 Mdot
.51841 .68993 Mdot
.49215 .68266 Mdot
.42975 .48504 Mdot
.58444 .24294 Mdot
.37083 .32672 Mdot
.50519 .66469 Mdot
.37191 .59742 Mdot
.52417 .31817 Mdot
.5509 .59946 Mdot
.51701 .63298 Mdot
.63662 .64383 Mdot
.53314 .31063 Mdot
.39796 .38209 Mdot
.41956 .37865 Mdot
.4401 .39666 Mdot
.30431 .56538 Mdot
.69874 .41046 Mdot
.34501 .65786 Mdot
.80339 .44464 Mdot
.29254 .51459 Mdot
.50191 .68186 Mdot
.33724 .45791 Mdot
.51594 .59166 Mdot
.32225 .52456 Mdot
.53055 .31051 Mdot
.64337 .45444 Mdot
.7222 .36209 Mdot
.4209 .38854 Mdot
.47607 .67293 Mdot
.2877 .53444 Mdot
.66697 .45687 Mdot
.35913 .70184 Mdot
.64527 .50767 Mdot
.54621 .35741 Mdot
.70388 .41092 Mdot
.32321 .52191 Mdot
.66348 .50931 Mdot
.55256 .40133 Mdot
.17433 .49269 Mdot
.47667 .57832 Mdot
.71093 .39229 Mdot
.64534 .51206 Mdot
.67147 .42921 Mdot
.66271 .51793 Mdot
.53765 .66806 Mdot
.51597 .40635 Mdot
.46993 .6112 Mdot
.53149 .31509 Mdot
.387 .38097 Mdot
.8066 .60234 Mdot
.50477 .28297 Mdot
.57306 .44231 Mdot
.57325 .58712 Mdot
.52713 .65788 Mdot
.51883 .62767 Mdot
.54193 .70099 Mdot
.52298 .23299 Mdot
.54008 .66289 Mdot
.56113 .34019 Mdot
.40651 .40916 Mdot
.4987 .58262 Mdot
.42274 .4378 Mdot
.20331 .50634 Mdot
.33662 .52139 Mdot
.59562 .38131 Mdot
.71183 .75971 Mdot
.66452 .4558 Mdot
.41767 .42755 Mdot
.41267 .40898 Mdot
.30834 .5169 Mdot
.55867 .37178 Mdot
.64851 .51001 Mdot
.42378 .6277 Mdot
.28906 .54514 Mdot
.50968 .64764 Mdot
.53245 .40521 Mdot
.83115 .55215 Mdot
.51208 .57659 Mdot
.54674 .62311 Mdot
.35807 .3636 Mdot
.32032 .47511 Mdot
.84592 .3965 Mdot
.36412 .66969 Mdot
.32703 .5302 Mdot
.34471 .53917 Mdot
.68087 .45484 Mdot
.48564 .68475 Mdot
.51658 .33083 Mdot
.74368 .45711 Mdot
.63065 .3999 Mdot
.73178 .3316 Mdot
.5333 .18546 Mdot
.54307 .59379 Mdot
.34892 .25594 Mdot
.53428 .65572 Mdot
.66218 .52057 Mdot
.67116 .47386 Mdot
.65643 .46806 Mdot
.56002 .36413 Mdot
.6996 .66665 Mdot
.56549 .35191 Mdot
.79961 .6723 Mdot
.63187 .4913 Mdot
.40057 .54151 Mdot
.37048 .4043 Mdot
.45624 .601 Mdot
.33231 .51852 Mdot
.71452 .4044 Mdot
.58786 .57658 Mdot
.64148 .56753 Mdot
.36981 .36791 Mdot
.65687 .44893 Mdot
.36571 .26333 Mdot
.54201 .81282 Mdot
.72456 .44795 Mdot
.58819 .66662 Mdot
.38299 .6993 Mdot
.31754 .53017 Mdot
.55449 .18765 Mdot
.33619 .53412 Mdot
.53687 .36016 Mdot
.50707 .60157 Mdot
.50261 .6116 Mdot
.53984 .58589 Mdot
.49488 .6672 Mdot
.53131 .29821 Mdot
.57126 .63218 Mdot
.77819 .40231 Mdot
.41958 .38405 Mdot
.34609 .58756 Mdot
.3341 .53903 Mdot
.54588 .3088 Mdot
.40812 .40816 Mdot
.38489 .28617 Mdot
.37973 .63281 Mdot
.52326 .62449 Mdot
.54675 .6077 Mdot
.73165 .71343 Mdot
.53032 .58556 Mdot
.4491 .66587 Mdot
.41706 .38762 Mdot
.59613 .68679 Mdot
.33636 .52186 Mdot
.34341 .53138 Mdot
.53646 .33288 Mdot
.67341 .47399 Mdot
.31707 .55089 Mdot
.36975 .39855 Mdot
.57228 .58324 Mdot
.56492 .65315 Mdot
.64197 .50941 Mdot
.74069 .70925 Mdot
.33801 .561 Mdot
.28449 .32904 Mdot
.66381 .44875 Mdot
.61814 .48777 Mdot
.55951 .63994 Mdot
.58629 .2026 Mdot
.62346 .44938 Mdot
.28122 .54739 Mdot
.54707 .30786 Mdot
.39276 .69474 Mdot
.57993 .34232 Mdot
.65796 .49354 Mdot
.48153 .627 Mdot
.67377 .46345 Mdot
.52506 .62217 Mdot
.5795 .82616 Mdot
.50295 .61782 Mdot
.80036 .43103 Mdot
.28402 .62282 Mdot
.38884 .42407 Mdot
.36875 .28487 Mdot
.37618 .41988 Mdot
.64127 .45031 Mdot
.51704 .69266 Mdot
.30652 .51302 Mdot
.21335 .43626 Mdot
.7218 .51178 Mdot
.37214 .37519 Mdot
.34655 .40835 Mdot
.57623 .33051 Mdot
.51596 .57993 Mdot
.55489 .65139 Mdot
.39262 .4121 Mdot
.61472 .44619 Mdot
.6677 .49907 Mdot
.51646 .60403 Mdot
.5278 .6601 Mdot
.38436 .42328 Mdot
.17288 .47962 Mdot
.46554 .56008 Mdot
.50964 .60692 Mdot
.40929 .3286 Mdot
.54702 .31565 Mdot
.45728 .60059 Mdot
.54727 .68782 Mdot
.30699 .53252 Mdot
.72515 .55415 Mdot
.54973 .79341 Mdot
.52859 .31018 Mdot
.41786 .40231 Mdot
.52323 .60928 Mdot
.40929 .41751 Mdot
.57073 .63808 Mdot
.59516 .25221 Mdot
.41748 .42518 Mdot
.48062 .60381 Mdot
.49425 .57623 Mdot
.62662 .49093 Mdot
.54527 .60002 Mdot
.61382 .74185 Mdot
.39361 .37016 Mdot
.47791 .652 Mdot
.77226 .61811 Mdot
.57176 .36694 Mdot
.45994 .61482 Mdot
.29184 .54816 Mdot
.43764 .69071 Mdot
.66933 .34866 Mdot
.31135 .71962 Mdot
.34082 .52293 Mdot
.54395 .66354 Mdot
.34559 .39563 Mdot
.53296 .37372 Mdot
.79646 .39234 Mdot
.55609 .60838 Mdot
.54379 .36926 Mdot
.54609 .32603 Mdot
.32772 .52279 Mdot
.30761 .22222 Mdot
.51846 .68822 Mdot
.49352 .65356 Mdot
.66356 .67825 Mdot
.68951 .44483 Mdot
.49895 .62852 Mdot
.48423 .64779 Mdot
.55879 .33455 Mdot
.46676 .68378 Mdot
.66548 .73772 Mdot
.78516 .55537 Mdot
.5575 .38597 Mdot
.74744 .38267 Mdot
.42216 .41835 Mdot
.33106 .55243 Mdot
.63895 .47688 Mdot
.29178 .52702 Mdot
.36449 .39865 Mdot
.48588 .63901 Mdot
.55121 .37774 Mdot
.61332 .73161 Mdot
.5191 .32936 Mdot
.25782 .64756 Mdot
.70538 .47101 Mdot
.56857 .30541 Mdot
.32623 .18934 Mdot
.41332 .313 Mdot
.56187 .27313 Mdot
.31294 .53222 Mdot
.33919 .43041 Mdot
.52932 .65929 Mdot
.53874 .17973 Mdot
.49834 .67904 Mdot
.7709 .59856 Mdot
.4158 .37766 Mdot
.37135 .3578 Mdot
.50922 .60347 Mdot
.60451 .7784 Mdot
.53754 .37904 Mdot
.5655 .3306 Mdot
.47718 .61536 Mdot
.54764 .36201 Mdot
.49934 .64446 Mdot
.41391 .39784 Mdot
.58139 .17907 Mdot
.51814 .64871 Mdot
.56949 .67073 Mdot
.61166 .27615 Mdot
.18387 .51958 Mdot
.34391 .5745 Mdot
.18181 .3884 Mdot
.58553 .81514 Mdot
.54899 .36182 Mdot
.47043 .62214 Mdot
.7448 .37294 Mdot
.3498 .37648 Mdot
.59287 .40724 Mdot
.49024 .63451 Mdot
.48789 .66438 Mdot
.56514 .60429 Mdot
.55194 .63714 Mdot
.41976 .18376 Mdot
.73748 .48898 Mdot
.70607 .60048 Mdot
.54152 .59571 Mdot
.39095 .62547 Mdot
.53133 .34156 Mdot
.64454 .53636 Mdot
.28276 .52817 Mdot
.54402 .59563 Mdot
.70797 .43139 Mdot
.56605 .38258 Mdot
.82085 .6467 Mdot
.54635 .37308 Mdot
.4019 .38825 Mdot
.52356 .35223 Mdot
.53744 .64602 Mdot
.64481 .48389 Mdot
.44676 .4523 Mdot
.4557 .29159 Mdot
.40686 .36911 Mdot
.52952 .64119 Mdot
.38598 .5496 Mdot
.38133 .36365 Mdot
.19847 .55083 Mdot
.64333 .47278 Mdot
.36435 .59554 Mdot
.67419 .46738 Mdot
.4785 .62204 Mdot
.47925 .62101 Mdot
.58678 .35945 Mdot
.52221 .34273 Mdot
.67413 .46906 Mdot
.23584 .27317 Mdot
.32454 .5642 Mdot
.65681 .47187 Mdot
.50676 .70437 Mdot
.49316 .41419 Mdot
.64689 .47856 Mdot
.26945 .52449 Mdot
.55172 .32834 Mdot
.67548 .44329 Mdot
.55753 .58422 Mdot
.42135 .70741 Mdot
.33434 .55666 Mdot
.41446 .36822 Mdot
.33644 .68513 Mdot
.37978 .37108 Mdot
.55436 .30951 Mdot
.37943 .42262 Mdot
.54488 .3182 Mdot
.65675 .36344 Mdot
.64436 .41573 Mdot
.3746 .47429 Mdot
.55522 .30631 Mdot
.37487 .41664 Mdot
.50814 .59841 Mdot
.3685 .53551 Mdot
.49789 .69383 Mdot
.54906 .66532 Mdot
.56158 .33067 Mdot
.62837 .48377 Mdot
.64419 .43475 Mdot
.41506 .64145 Mdot
.67471 .47799 Mdot
.39844 .37505 Mdot
.68934 .55056 Mdot
.51121 .24926 Mdot
.57899 .34614 Mdot
.52691 .3502 Mdot
.52118 .58932 Mdot
.38319 .41 Mdot
.39552 .36179 Mdot
.5804 .34112 Mdot
.62532 .24106 Mdot
.54647 .69343 Mdot
.66125 .42655 Mdot
.68875 .44653 Mdot
.65282 .48708 Mdot
.6777 .51228 Mdot
.45922 .713 Mdot
.5325 .32519 Mdot
.62886 .47406 Mdot
.52177 .5884 Mdot
.48614 .64905 Mdot
.74721 .43467 Mdot
.3228 .55877 Mdot
.486 .59044 Mdot
.49145 .5693 Mdot
.5569 .61839 Mdot
.36439 .41024 Mdot
.43975 .64377 Mdot
.38553 .4341 Mdot
.3501 .38151 Mdot
.35052 .37866 Mdot
.53628 .24192 Mdot
.68932 .75092 Mdot
.48244 .79209 Mdot
.48012 .65456 Mdot
.31587 .28157 Mdot
.38162 .39788 Mdot
.74534 .49613 Mdot
.64296 .38944 Mdot
.56279 .61177 Mdot
.24643 .40363 Mdot
.38972 .41522 Mdot
.67172 .45069 Mdot
.49545 .6259 Mdot
.42773 .42138 Mdot
.29696 .55598 Mdot
.4793 .66713 Mdot
.4326 .40752 Mdot
.66308 .51081 Mdot
.29284 .56382 Mdot
.66715 .43854 Mdot
.3495 .37975 Mdot
.48445 .69588 Mdot
.69251 .22314 Mdot
.43265 .42128 Mdot
.2323 .36315 Mdot
.59096 .54699 Mdot
.51396 .60053 Mdot
.3965 .43821 Mdot
.61611 .49051 Mdot
.55497 .31051 Mdot
.54804 .48501 Mdot
.68918 .4633 Mdot
.37109 .35784 Mdot
.35504 .38764 Mdot
.40715 .36928 Mdot
.68944 .47564 Mdot
.45976 .63436 Mdot
.67927 .48395 Mdot
.52425 .35561 Mdot
.53781 .6158 Mdot
.44232 .77631 Mdot
.38546 .24925 Mdot
.66915 .45179 Mdot
.38744 .37713 Mdot
.30927 .50278 Mdot
.52879 .65381 Mdot
.35842 .25868 Mdot
.50988 .59677 Mdot
.54986 .31901 Mdot
.6717 .58614 Mdot
.60066 .68671 Mdot
.47288 .61254 Mdot
.52631 .59199 Mdot
.56734 .33359 Mdot
.52632 .64339 Mdot
.51745 .58058 Mdot
.51631 .23408 Mdot
.67905 .48988 Mdot
.51211 .65414 Mdot
.38024 .38379 Mdot
.48503 .26129 Mdot
.55661 .68533 Mdot
.36698 .46002 Mdot
.37502 .58965 Mdot
.65131 .59935 Mdot
.49589 .67739 Mdot
.5572 .41379 Mdot
.55597 .64091 Mdot
.512 .67461 Mdot
.52474 .59462 Mdot
.35794 .22083 Mdot
.43056 .41083 Mdot
.40604 .41625 Mdot
.34336 .54493 Mdot
.3728 .59031 Mdot
.30052 .54024 Mdot
.54572 .32354 Mdot
.27981 .43873 Mdot
.38874 .43542 Mdot
.65888 .50141 Mdot
.52506 .67012 Mdot
.42922 .42529 Mdot
.55929 .61754 Mdot
.53699 .64415 Mdot
.34962 .39036 Mdot
.42827 .41119 Mdot
.24043 .60152 Mdot
.31546 .56074 Mdot
.65741 .46216 Mdot
.49587 .58736 Mdot
.28775 .53964 Mdot
.50247 .68329 Mdot
.33704 .63881 Mdot
.65486 .46619 Mdot
.67788 .48938 Mdot
.63787 .43635 Mdot
.48825 .63152 Mdot
.53384 .64971 Mdot
.56601 .35107 Mdot
.64785 .44527 Mdot
.56984 .37047 Mdot
.51084 .48658 Mdot
.22576 .51782 Mdot
.48991 .63514 Mdot
.72689 .41592 Mdot
.29762 .54823 Mdot
.36953 .37707 Mdot
.82882 .56658 Mdot
.34327 .54534 Mdot
.52345 .61809 Mdot
.35878 .37437 Mdot
.31245 .52254 Mdot
.42905 .55713 Mdot
.77587 .68894 Mdot
.31305 .50378 Mdot
.52261 .58858 Mdot
.47161 .68939 Mdot
.19036 .37143 Mdot
.33493 .51317 Mdot
.52567 .33547 Mdot
.48925 .62887 Mdot
.68416 .43261 Mdot
.28758 .53348 Mdot
.31625 .33734 Mdot
.39833 .41429 Mdot
.42759 .70757 Mdot
.58765 .61489 Mdot
.62217 .5434 Mdot
.34155 .54455 Mdot
.64205 .4998 Mdot
.4606 .69293 Mdot
.55916 .63841 Mdot
.33679 .51425 Mdot
.51117 .30793 Mdot
.40608 .40251 Mdot
.46168 .27277 Mdot
.69084 .47222 Mdot
.49819 .31726 Mdot
.3732 .37871 Mdot
.27788 .33498 Mdot
.78873 .5081 Mdot
.45512 .61214 Mdot
.258 .3092 Mdot
.61432 .32251 Mdot
.54582 .58361 Mdot
.27734 .52708 Mdot
.51395 .32307 Mdot
.57502 .37738 Mdot
.54331 .35366 Mdot
.64546 .36502 Mdot
.71929 .4777 Mdot
.43521 .4022 Mdot
.51428 .38447 Mdot
.32813 .55397 Mdot
.39508 .68616 Mdot
.55364 .66288 Mdot
.52335 .65711 Mdot
.50465 .58536 Mdot
.54525 .59488 Mdot
.54349 .65826 Mdot
.55271 .37132 Mdot
.64611 .34808 Mdot
.72635 .46828 Mdot
.65031 .47269 Mdot
.32415 .46233 Mdot
.37255 .39561 Mdot
.3839 .35235 Mdot
.29917 .52824 Mdot
.37731 .31675 Mdot
.42495 .43619 Mdot
.39395 .3905 Mdot
.50283 .5763 Mdot
.67088 .49268 Mdot
.449 .61619 Mdot
.52477 .59026 Mdot
.40535 .37991 Mdot
.45249 .48428 Mdot
.62435 .75387 Mdot
.2459 .57568 Mdot
.31712 .57107 Mdot
.53025 .39997 Mdot
.34649 .53203 Mdot
.54757 .67921 Mdot
.74636 .31642 Mdot
.36445 .40052 Mdot
.39499 .40091 Mdot
.31406 .55856 Mdot
.58689 .20048 Mdot
.63676 .4736 Mdot
.49932 .30544 Mdot
.52668 .32034 Mdot
.48133 .6224 Mdot
.81303 .51425 Mdot
.59029 .53624 Mdot
.267 .42553 Mdot
.5386 .34974 Mdot
.40102 .42685 Mdot
.55999 .66874 Mdot
.53328 .59504 Mdot
.29602 .54101 Mdot
.28872 .71595 Mdot
.48831 .56713 Mdot
.25067 .73203 Mdot
.80505 .62915 Mdot
.52976 .78456 Mdot
.55803 .64518 Mdot
.68195 .48551 Mdot
.42323 .38492 Mdot
.3329 .54702 Mdot
.47316 .66422 Mdot
.59591 .79875 Mdot
.63851 .50454 Mdot
.54028 .33794 Mdot
.48189 .46009 Mdot
.38319 .68674 Mdot
.5301 .67402 Mdot
.48555 .65641 Mdot
.51547 .67684 Mdot
.88826 .4927 Mdot
.37628 .42745 Mdot
.6728 .4538 Mdot
.32554 .52114 Mdot
.66843 .48487 Mdot
.39527 .42522 Mdot
.38578 .48891 Mdot
.49802 .60166 Mdot
.65318 .51555 Mdot
.64065 .49641 Mdot
.57227 .37672 Mdot
.52963 .30743 Mdot
.49597 .47078 Mdot
.50346 .61953 Mdot
.36659 .43171 Mdot
.62734 .48144 Mdot
.55086 .40867 Mdot
.30856 .53896 Mdot
.55302 .32847 Mdot
.54401 .59947 Mdot
.38795 .43387 Mdot
.52143 .56355 Mdot
.64886 .45543 Mdot
.39322 .39123 Mdot
.22755 .59131 Mdot
.33816 .52264 Mdot
.48808 .64982 Mdot
.27711 .58365 Mdot
.41811 .39849 Mdot
.53461 .65858 Mdot
.24309 .37053 Mdot
.27726 .51626 Mdot
.46086 .31134 Mdot
.36665 .36595 Mdot
.56953 .26454 Mdot
.68293 .45614 Mdot
.5737 .24803 Mdot
.40013 .39576 Mdot
.29413 .3178 Mdot
.23463 .61942 Mdot
.57457 .59608 Mdot
.66018 .48231 Mdot
.58305 .26642 Mdot
.5076 .84209 Mdot
.2076 .38869 Mdot
.51993 .63251 Mdot
.36776 .42874 Mdot
.30371 .52773 Mdot
.57753 .34598 Mdot
.48028 .31197 Mdot
.35349 .50384 Mdot
.36898 .44194 Mdot
.52486 .59527 Mdot
.65048 .50821 Mdot
.55965 .34693 Mdot
.67005 .35441 Mdot
.37204 .39128 Mdot
.38464 .37946 Mdot
.50775 .69237 Mdot
.30331 .55166 Mdot
.43585 .21316 Mdot
.41575 .39123 Mdot
.75744 .68008 Mdot
.37328 .35008 Mdot
.29125 .55284 Mdot
.55359 .63018 Mdot
.42732 .68072 Mdot
.47595 .66343 Mdot
.20837 .4252 Mdot
.37189 .4022 Mdot
.65349 .45884 Mdot
.56022 .65069 Mdot
.78176 .61939 Mdot
.39678 .37499 Mdot
.51442 .40009 Mdot
.33148 .34593 Mdot
.53356 .32172 Mdot
.82841 .56359 Mdot
.49575 .63757 Mdot
.53239 .37287 Mdot
.29741 .53744 Mdot
.5081 .61242 Mdot
.5373 .64928 Mdot
.63855 .51629 Mdot
.57617 .3715 Mdot
.23957 .59712 Mdot
.53133 .36064 Mdot
.5298 .34552 Mdot
.70947 .44376 Mdot
.50259 .65622 Mdot
.40134 .38595 Mdot
.38909 .41401 Mdot
.55468 .58235 Mdot
.52538 .14613 Mdot
.63547 .48172 Mdot
.40696 .36348 Mdot
.8877 .46705 Mdot
.54255 .57767 Mdot
.81875 .56261 Mdot
.27283 .69929 Mdot
.5188 .32193 Mdot
.52196 .58788 Mdot
.65945 .50962 Mdot
.36365 .32916 Mdot
.38827 .37922 Mdot
.56263 .58701 Mdot
.55871 .34838 Mdot
.31605 .56199 Mdot
.39457 .36694 Mdot
.27272 .42522 Mdot
.49891 .67336 Mdot
.23194 .43316 Mdot
.35502 .40784 Mdot
.43995 .81806 Mdot
.39716 .27495 Mdot
.66081 .47856 Mdot
.53905 .64174 Mdot
.6572 .44422 Mdot
.31874 .51842 Mdot
.48422 .4613 Mdot
.5548 .33488 Mdot
.50778 .74486 Mdot
.76453 .33936 Mdot
.40749 .3695 Mdot
.66741 .44858 Mdot
.47399 .62132 Mdot
.58998 .2425 Mdot
.49592 .64339 Mdot
.54555 .71568 Mdot
.24349 .59292 Mdot
.57102 .34433 Mdot
.52269 .32033 Mdot
.54837 .64683 Mdot
.30367 .51789 Mdot
.37081 .3962 Mdot
.40821 .39331 Mdot
.39279 .82211 Mdot
.50141 .3025 Mdot
.71893 .70697 Mdot
.48843 .66493 Mdot
.35871 .43229 Mdot
.52293 .27241 Mdot
.55449 .37671 Mdot
.45716 .63392 Mdot
.35737 .37882 Mdot
.35305 .58444 Mdot
.41475 .57884 Mdot
.55734 .64145 Mdot
.49388 .6953 Mdot
.5224 .32788 Mdot
.71918 .44966 Mdot
.41339 .41735 Mdot
.51993 .55959 Mdot
.39171 .47858 Mdot
.42642 .55709 Mdot
.80565 .64021 Mdot
.65763 .46229 Mdot
.28235 .39798 Mdot
.55424 .37208 Mdot
.57375 .66407 Mdot
.33118 .52035 Mdot
.34529 .41986 Mdot
.40639 .43104 Mdot
.5262 .60781 Mdot
.5632 .66026 Mdot
.79079 .63603 Mdot
.66404 .49657 Mdot
.53246 .3358 Mdot
.49759 .61147 Mdot
.72582 .38326 Mdot
.53769 .58451 Mdot
.56858 .35656 Mdot
.67541 .21128 Mdot
.48521 .68256 Mdot
.49446 .64947 Mdot
.43193 .21563 Mdot
.6908 .45869 Mdot
.62712 .46852 Mdot
.8275 .5086 Mdot
.48816 .66388 Mdot
.81245 .61171 Mdot
.65896 .45673 Mdot
.63727 .46644 Mdot
.46843 .24457 Mdot
.52485 .65448 Mdot
.49754 .53679 Mdot
.5372 .31552 Mdot
.52883 .34507 Mdot
.68517 .4785 Mdot
.46706 .58683 Mdot
.54041 .30982 Mdot
.40418 .20278 Mdot
.38158 .40963 Mdot
.68693 .25556 Mdot
.63451 .48609 Mdot
.60266 .32773 Mdot
.53979 .36224 Mdot
.76274 .70975 Mdot
.45509 .34466 Mdot
.50394 .59978 Mdot
.49027 .66637 Mdot
.31738 .55766 Mdot
.4876 .59383 Mdot
.37239 .35761 Mdot
.54703 .36196 Mdot
.59486 .77103 Mdot
.65684 .46821 Mdot
.50375 .62944 Mdot
.24196 .39377 Mdot
.20533 .59751 Mdot
.30105 .38075 Mdot
.64114 .50364 Mdot
.66886 .46996 Mdot
.38612 .43014 Mdot
.36331 .42327 Mdot
.51496 .66494 Mdot
.56783 .32981 Mdot
.65177 .44487 Mdot
.56923 .34914 Mdot
.36391 .3975 Mdot
.39941 .38783 Mdot
.43023 .40288 Mdot
.55783 .65983 Mdot
.39072 .38545 Mdot
.22211 .54686 Mdot
.48586 .3653 Mdot
.70281 .44141 Mdot
.85402 .52281 Mdot
.67373 .35939 Mdot
.63302 .54128 Mdot
.2862 .54687 Mdot
.41649 .3824 Mdot
.53018 .36708 Mdot
.54287 .62445 Mdot
.5501 .60844 Mdot
.53003 .24778 Mdot
.53766 .37538 Mdot
.32369 .52096 Mdot
.51884 .3467 Mdot
.32708 .52179 Mdot
.24246 .42675 Mdot
.5172 .57818 Mdot
.57234 .62686 Mdot
.54543 .36558 Mdot
.39204 .38804 Mdot
.4024 .41559 Mdot
.32044 .50656 Mdot
.44214 .49606 Mdot
.37866 .36428 Mdot
.63452 .46991 Mdot
.55519 .76318 Mdot
.35469 .4017 Mdot
.49672 .62628 Mdot
.33849 .65668 Mdot
.52129 .17047 Mdot
.54088 .70129 Mdot
.47785 .23655 Mdot
.63089 .70843 Mdot
.56325 .63836 Mdot
.52816 .17134 Mdot
.52823 .37681 Mdot
.68533 .46501 Mdot
.42 .38982 Mdot
.4102 .35348 Mdot
.5053 .54453 Mdot
.29194 .56448 Mdot
.47206 .67472 Mdot
.65453 .51532 Mdot
.63631 .52118 Mdot
.41974 .67595 Mdot
.20932 .40068 Mdot
.31119 .5241 Mdot
.29785 .53115 Mdot
.40254 .39427 Mdot
.19787 .65976 Mdot
.56732 .69926 Mdot
.32597 .52445 Mdot
.61112 .463 Mdot
.52624 .59932 Mdot
.35792 .58796 Mdot
.58981 .50767 Mdot
.68705 .47725 Mdot
.39647 .62566 Mdot
.39888 .37829 Mdot
.67665 .47654 Mdot
.71718 .35032 Mdot
.46278 .62074 Mdot
.65476 .46791 Mdot
.56759 .34879 Mdot
.39017 .29296 Mdot
.63131 .47692 Mdot
.34168 .64991 Mdot
.57276 .32998 Mdot
.55308 .40868 Mdot
.41318 .61274 Mdot
.10488 .51792 Mdot
.55004 .36758 Mdot
.356 .38671 Mdot
.39039 .4135 Mdot
.40778 .39281 Mdot
.66788 .48723 Mdot
.40821 .3697 Mdot
.6625 .49613 Mdot
.22909 .3334 Mdot
.54312 .18948 Mdot
.32655 .52831 Mdot
.45873 .27408 Mdot
.65159 .50206 Mdot
.77084 .44046 Mdot
.43208 .12856 Mdot
.51752 .58705 Mdot
.57898 .37558 Mdot
.32468 .5284 Mdot
.23128 .69486 Mdot
.31077 .52966 Mdot
.62399 .78859 Mdot
.63569 .57829 Mdot
.50404 .63778 Mdot
.72312 .66359 Mdot
.30903 .50755 Mdot
.68909 .49557 Mdot
.53431 .65799 Mdot
.47003 .50494 Mdot
.30349 .53198 Mdot
.29849 .55905 Mdot
.51216 .66065 Mdot
.65666 .44881 Mdot
.38632 .37555 Mdot
.53021 .35417 Mdot
.2914 .52417 Mdot
.48383 .70641 Mdot
.4712 .63853 Mdot
.50353 .5966 Mdot
.74003 .42442 Mdot
.27172 .52866 Mdot
.54988 .36206 Mdot
.31914 .22512 Mdot
.34651 .39812 Mdot
.42116 .53049 Mdot
.78193 .66067 Mdot
.61885 .38 Mdot
.37271 .40294 Mdot
.40664 .41933 Mdot
.54246 .65931 Mdot
.58714 .69253 Mdot
.62369 .56476 Mdot
.40114 .50882 Mdot
.42191 .37649 Mdot
.40793 .3978 Mdot
.63335 .45298 Mdot
.4992 .77053 Mdot
.53944 .7057 Mdot
.52613 .31106 Mdot
.41967 .42244 Mdot
.5304 .19975 Mdot
.3138 .55594 Mdot
.65776 .57363 Mdot
.51364 .57793 Mdot
.50157 .60244 Mdot
.55391 .34496 Mdot
.56472 .35123 Mdot
.34302 .33565 Mdot
.54876 .78671 Mdot
.62234 .71544 Mdot
.64553 .33324 Mdot
.64483 .61081 Mdot
.62341 .4842 Mdot
.66878 .4515 Mdot
.45033 .3026 Mdot
.54002 .37109 Mdot
.56342 .64102 Mdot
.6743 .47177 Mdot
.36509 .57492 Mdot
.49745 .74143 Mdot
.46738 .73632 Mdot
.8133 .58561 Mdot
.52635 .62738 Mdot
.67384 .49901 Mdot
.69124 .45632 Mdot
.69546 .45387 Mdot
.58759 .28534 Mdot
.50457 .66462 Mdot
.52397 .63064 Mdot
.5553 .65353 Mdot
.58782 .22163 Mdot
.5085 .67086 Mdot
.60043 .28163 Mdot
.50047 .45649 Mdot
.74784 .53931 Mdot
.51487 .56022 Mdot
.52196 .3583 Mdot
.52054 .68157 Mdot
.30551 .51699 Mdot
.5023 .5912 Mdot
.47183 .74038 Mdot
.53451 .3454 Mdot
.43675 .61153 Mdot
.66247 .36639 Mdot
.5608 .59556 Mdot
.28172 .54569 Mdot
.62849 .39304 Mdot
.49419 .82386 Mdot
.32894 .57688 Mdot
.63436 .4725 Mdot
.37746 .40604 Mdot
.53309 .37136 Mdot
.39673 .39443 Mdot
.57062 .59739 Mdot
.43703 .3036 Mdot
.24075 .69687 Mdot
.46628 .49856 Mdot
.54626 .59853 Mdot
.57025 .68933 Mdot
.63903 .46037 Mdot
.34924 .38791 Mdot
.61274 .50692 Mdot
.53699 .6688 Mdot
.32629 .53949 Mdot
.29744 .5398 Mdot
.53603 .48566 Mdot
.37612 .785 Mdot
.46893 .19545 Mdot
.55435 .35056 Mdot
.41471 .3876 Mdot
.33276 .51846 Mdot
.30974 .30459 Mdot
.50807 .33085 Mdot
.55941 .32586 Mdot
.53411 .34002 Mdot
.48379 .63544 Mdot
.42864 .41399 Mdot
.75042 .53926 Mdot
.34295 .39371 Mdot
.52848 .64428 Mdot
.36456 .41234 Mdot
.36672 .37113 Mdot
.33059 .54502 Mdot
.53241 .33987 Mdot
.3658 .40034 Mdot
.47838 .62934 Mdot
.66255 .45576 Mdot
.56328 .28245 Mdot
.2689 .61295 Mdot
.21085 .40463 Mdot
.54279 .51687 Mdot
.69428 .46433 Mdot
.47821 .81867 Mdot
.54051 .31387 Mdot
.6151 .23536 Mdot
.24083 .60465 Mdot
.50883 .69053 Mdot
.54445 .15061 Mdot
.34389 .35957 Mdot
.36934 .37148 Mdot
.5544 .63215 Mdot
.33679 .36127 Mdot
.50172 .63454 Mdot
.36346 .38669 Mdot
.47367 .34572 Mdot
.71246 .46323 Mdot
.38689 .3889 Mdot
.53529 .56069 Mdot
.541 .65038 Mdot
.68143 .48462 Mdot
.37937 .43545 Mdot
.48101 .68242 Mdot
.43083 .84948 Mdot
.56556 .35882 Mdot
.62322 .3669 Mdot
.32436 .65795 Mdot
.55722 .37345 Mdot
.65602 .47521 Mdot
.54674 .66736 Mdot
.29773 .53585 Mdot
.65294 .5041 Mdot
.4853 .74875 Mdot
.3404 .53351 Mdot
.66447 .22674 Mdot
.69233 .45727 Mdot
.37423 .37361 Mdot
.31835 .51478 Mdot
.46942 .61494 Mdot
.34509 .38336 Mdot
.36574 .28947 Mdot
.3736 .39941 Mdot
.54729 .6586 Mdot
.48686 .2858 Mdot
.53151 .33533 Mdot
.51802 .62877 Mdot
.37759 .36897 Mdot
.47888 .23804 Mdot
.48125 .64944 Mdot
.55152 .64722 Mdot
.76814 .67763 Mdot
.76365 .48567 Mdot
.31012 .5343 Mdot
.66304 .43721 Mdot
.52041 .588 Mdot
.29107 .54833 Mdot
.2571 .49549 Mdot
.48933 .61959 Mdot
.63863 .50529 Mdot
.45672 .6357 Mdot
.37137 .43056 Mdot
.56735 .36971 Mdot
.40283 .51991 Mdot
.29606 .55511 Mdot
.1396 .48485 Mdot
.41458 .42417 Mdot
.5495 .67001 Mdot
.53661 .58554 Mdot
.33527 .70504 Mdot
.68403 .46918 Mdot
.59894 .48254 Mdot
.48797 .65104 Mdot
.59492 .22016 Mdot
.50951 .61705 Mdot
.3362 .36859 Mdot
.63655 .47262 Mdot
.49487 .65866 Mdot
.5568 .29444 Mdot
.56865 .6709 Mdot
.3328 .55591 Mdot
.39916 .23808 Mdot
.46155 .64115 Mdot
.66699 .21628 Mdot
.51539 .50192 Mdot
.38599 .38732 Mdot
.2089 .50985 Mdot
.42132 .85122 Mdot
.64955 .37089 Mdot
.66618 .48593 Mdot
.26346 .69922 Mdot
.40096 .38564 Mdot
.21951 .44276 Mdot
.49902 .83542 Mdot
.54475 .64262 Mdot
.53282 .67253 Mdot
.37664 .70015 Mdot
.34661 .3859 Mdot
.35527 .42059 Mdot
.57263 .58896 Mdot
.56348 .68162 Mdot
.3953 .38418 Mdot
.48417 .67323 Mdot
.51976 .55533 Mdot
.57827 .37602 Mdot
.63611 .49887 Mdot
.57147 .34263 Mdot
.55197 .3153 Mdot
.36812 .23651 Mdot
.48712 .50732 Mdot
.56817 .3603 Mdot
.51736 .31945 Mdot
.37741 .58165 Mdot
.58563 .7799 Mdot
.29212 .52629 Mdot
.40857 .81182 Mdot
.40489 .40154 Mdot
.50008 .6593 Mdot
.69038 .44919 Mdot
.61065 .71993 Mdot
.2577 .51 Mdot
.76737 .36897 Mdot
.55616 .6556 Mdot
.39385 .37454 Mdot
.61547 .36008 Mdot
.44556 .63797 Mdot
.43784 .41052 Mdot
.49549 .61717 Mdot
.36844 .35839 Mdot
.63057 .76158 Mdot
.29664 .31698 Mdot
.41094 .35595 Mdot
.67925 .43123 Mdot
.50212 .60638 Mdot
.66367 .51581 Mdot
.5546 .376 Mdot
.29878 .51958 Mdot
.30598 .53747 Mdot
.52534 .66073 Mdot
.5851 .67099 Mdot
.23216 .45362 Mdot
.53102 .65373 Mdot
.52897 .60104 Mdot
.55666 .39576 Mdot
.52659 .59493 Mdot
.54468 .58818 Mdot
.56137 .61777 Mdot
.56697 .61198 Mdot
.52918 .34426 Mdot
.37145 .31765 Mdot
.5233 .54239 Mdot
.57334 .57151 Mdot
.55977 .31368 Mdot
.26633 .68332 Mdot
.54157 .31139 Mdot
.51167 .83501 Mdot
.51999 .32271 Mdot
.31328 .54032 Mdot
.28666 .69468 Mdot
.58708 .58812 Mdot
.6325 .50562 Mdot
.59477 .39502 Mdot
.31377 .51715 Mdot
.5445 .35737 Mdot
.36082 .38652 Mdot
.77882 .67131 Mdot
.65911 .52822 Mdot
.74533 .46796 Mdot
.6179 .40358 Mdot
.38028 .30946 Mdot
.38722 .43153 Mdot
.69836 .48307 Mdot
.66403 .73326 Mdot
.54425 .59121 Mdot
.2904 .54704 Mdot
.5174 .66408 Mdot
.55361 .37809 Mdot
.40353 .3818 Mdot
.21816 .36234 Mdot
.29607 .54185 Mdot
.8529 .54721 Mdot
.39703 .41745 Mdot
.55091 .59788 Mdot
.54016 .30991 Mdot
.84727 .46061 Mdot
.56932 .34139 Mdot
.61258 .60299 Mdot
.67846 .45533 Mdot
.17986 .40426 Mdot
.65491 .49519 Mdot
.34062 .30159 Mdot
.82768 .34863 Mdot
.28575 .35142 Mdot
.6619 .45198 Mdot
.37863 .48892 Mdot
.52401 .61427 Mdot
.50234 .59721 Mdot
.26314 .32761 Mdot
.67492 .43795 Mdot
.5365 .59169 Mdot
.52486 .26068 Mdot
.49962 .31794 Mdot
.80805 .55102 Mdot
.3875 .42862 Mdot
.49882 .63332 Mdot
.5721 .38647 Mdot
.5455 .38317 Mdot
.41983 .41034 Mdot
.55396 .32062 Mdot
.52417 .6338 Mdot
.65202 .50118 Mdot
.39817 .4577 Mdot
.31075 .54826 Mdot
.20602 .65309 Mdot
.34619 .55287 Mdot
.37271 .40419 Mdot
.49949 .69491 Mdot
.39883 .38847 Mdot
.55704 .89289 Mdot
.52058 .61964 Mdot
.65772 .45644 Mdot
.53217 .59731 Mdot
.50633 .60506 Mdot
.5665 .62796 Mdot
.38421 .37715 Mdot
.24469 .58511 Mdot
.47797 .64307 Mdot
.553 .33167 Mdot
.6791 .59412 Mdot
.47888 .59468 Mdot
.34914 .47284 Mdot
.45576 .7249 Mdot
.68439 .40396 Mdot
.67649 .44529 Mdot
.38132 .39093 Mdot
.66016 .46635 Mdot
.62229 .22341 Mdot
.65575 .47541 Mdot
.65785 .6379 Mdot
.67367 .73001 Mdot
.74129 .67376 Mdot
.75389 .65691 Mdot
.44301 .46525 Mdot
.66992 .43667 Mdot
.29251 .57126 Mdot
.65022 .44613 Mdot
.68775 .47118 Mdot
.509 .09746 Mdot
.65181 .51817 Mdot
.49226 .63387 Mdot
.49637 .58154 Mdot
.30718 .32615 Mdot
.33206 .6207 Mdot
.53825 .61273 Mdot
.54107 .60545 Mdot
.33 .51629 Mdot
.6198 .2265 Mdot
.44961 .31414 Mdot
.76353 .48155 Mdot
.21334 .5956 Mdot
.51535 .66258 Mdot
.50815 .58819 Mdot
.5451 .55219 Mdot
.80771 .38095 Mdot
.33946 .24801 Mdot
.67802 .42851 Mdot
.57202 .57449 Mdot
.25153 .37807 Mdot
.55743 .65558 Mdot
.48423 .65052 Mdot
.52519 .62266 Mdot
.40116 .38501 Mdot
.67027 .44036 Mdot
.56574 .59116 Mdot
.32282 .70521 Mdot
.48715 .63672 Mdot
.61236 .33082 Mdot
.156 .53168 Mdot
.49509 .63849 Mdot
.62222 .47023 Mdot
.50531 .59532 Mdot
.68049 .47871 Mdot
.68463 .49157 Mdot
.57413 .58542 Mdot
.64106 .61044 Mdot
.6347 .44998 Mdot
.52904 .64482 Mdot
.35859 .38607 Mdot
.43172 .80943 Mdot
.54049 .66225 Mdot
.29106 .52846 Mdot
.48908 .6637 Mdot
.28891 .55897 Mdot
.53215 .60819 Mdot
.41938 .41922 Mdot
.61414 .70046 Mdot
.39713 .40033 Mdot
.27321 .29535 Mdot
.42996 .40831 Mdot
.84558 .57616 Mdot
.69487 .4676 Mdot
.47625 .27792 Mdot
.70983 .28737 Mdot
.55613 .24529 Mdot
.55022 .42539 Mdot
.4685 .43446 Mdot
.56747 .33006 Mdot
.68117 .46423 Mdot
.67108 .27582 Mdot
.31492 .46856 Mdot
.311 .43218 Mdot
.3878 .36401 Mdot
.29244 .22955 Mdot
.65163 .22374 Mdot
.54757 .68107 Mdot
.69094 .68872 Mdot
.71202 .62588 Mdot
.56076 .65135 Mdot
.56774 .63085 Mdot
.37167 .34532 Mdot
.47861 .66067 Mdot
.7272 .38854 Mdot
.37443 .41376 Mdot
.30875 .51787 Mdot
.64649 .45364 Mdot
.31712 .56207 Mdot
.29579 .49188 Mdot
.47107 .42705 Mdot
.36204 .3916 Mdot
.48046 .67924 Mdot
.54217 .61636 Mdot
.67581 .48717 Mdot
.64437 .54885 Mdot
.62788 .47394 Mdot
.32065 .52612 Mdot
.38031 .41994 Mdot
.48662 .16998 Mdot
.54381 .61332 Mdot
.64013 .49185 Mdot
.55766 .43451 Mdot
.52443 .5892 Mdot
.54832 .37085 Mdot
.52145 .60947 Mdot
.65266 .44911 Mdot
.52686 .59521 Mdot
.65618 .49436 Mdot
.37929 .40665 Mdot
.5592 .60587 Mdot
.55691 .63074 Mdot
.84648 .52151 Mdot
.32747 .53415 Mdot
.69995 .4826 Mdot
.40036 .54803 Mdot
.51908 .58328 Mdot
.44862 .262 Mdot
.49505 .62136 Mdot
.71331 .43494 Mdot
.53894 .68662 Mdot
.62299 .36983 Mdot
.57959 .58882 Mdot
.52179 .66754 Mdot
.57276 .48163 Mdot
.70244 .62947 Mdot
.52994 .5296 Mdot
.51403 .33385 Mdot
.69682 .48849 Mdot
.80167 .56217 Mdot
.3599 .44898 Mdot
.375 .43621 Mdot
.38864 .65207 Mdot
.5609 .58369 Mdot
.50257 .64048 Mdot
.69015 .40828 Mdot
.29671 .55167 Mdot
.64792 .51077 Mdot
.32735 .52223 Mdot
.83193 .57319 Mdot
.34416 .53938 Mdot
.33498 .36958 Mdot
.23024 .43644 Mdot
.4472 .18155 Mdot
.3326 .51947 Mdot
.65198 .44815 Mdot
.26131 .38247 Mdot
.54977 .58804 Mdot
.53411 .49844 Mdot
.32245 .54412 Mdot
.21502 .31217 Mdot
.54578 .58965 Mdot
.55579 .42622 Mdot
.5719 .36012 Mdot
.33123 .51934 Mdot
.57676 .33424 Mdot
.54478 .63112 Mdot
.45281 .31512 Mdot
.66549 .48529 Mdot
.57473 .32527 Mdot
.47151 .59606 Mdot
.32458 .5255 Mdot
.41605 .426 Mdot
.57587 .31721 Mdot
.52183 .31352 Mdot
.32416 .74543 Mdot
.20345 .37107 Mdot
.38332 .42114 Mdot
.79292 .50491 Mdot
.52101 .35453 Mdot
.54462 .58202 Mdot
.64233 .24375 Mdot
.50218 .60049 Mdot
.49517 .20737 Mdot
.37436 .39292 Mdot
.37935 .31223 Mdot
.51942 .5884 Mdot
.53316 .66822 Mdot
.63496 .52253 Mdot
.39451 .40744 Mdot
.64612 .4842 Mdot
.70903 .45508 Mdot
.37998 .40876 Mdot
.65833 .48339 Mdot
.32288 .50996 Mdot
.7185 .33164 Mdot
.52466 .32189 Mdot
.54225 .32545 Mdot
.4086 .39336 Mdot
.38275 .3855 Mdot
.39452 .39128 Mdot
.52119 .60857 Mdot
.63674 .49195 Mdot
.53798 .63547 Mdot
.49697 .67876 Mdot
.69399 .57862 Mdot
.67855 .44325 Mdot
.53113 .63233 Mdot
.44584 .51491 Mdot
.60151 .58834 Mdot
.35608 .39517 Mdot
.56921 .36185 Mdot
.50873 .26275 Mdot
.37912 .27885 Mdot
.50002 .62913 Mdot
.27098 .58723 Mdot
.65031 .44743 Mdot
.30326 .53001 Mdot
.34825 .54031 Mdot
.31165 .53098 Mdot
.5158 .37591 Mdot
.69501 .45391 Mdot
.74573 .50513 Mdot
.49959 .63644 Mdot
.7299 .44939 Mdot
.67735 .4261 Mdot
.25857 .39659 Mdot
.56719 .36271 Mdot
.5332 .5955 Mdot
.40959 .51766 Mdot
.59687 .75427 Mdot
.50827 .59968 Mdot
.4833 .5892 Mdot
.2225 .56238 Mdot
.49793 .70453 Mdot
.62757 .5067 Mdot
.84522 .47587 Mdot
.4745 .60779 Mdot
.52439 .1954 Mdot
.22387 .7037 Mdot
.50098 .61967 Mdot
.52269 .67345 Mdot
.54921 .61653 Mdot
.49888 .59316 Mdot
.62915 .45447 Mdot
.36158 .60753 Mdot
.518 .34801 Mdot
.72944 .45994 Mdot
.5426 .37171 Mdot
.41777 .37539 Mdot
.37966 .31367 Mdot
.67956 .45875 Mdot
.31566 .55774 Mdot
.19282 .58381 Mdot
.80827 .45593 Mdot
.41383 .41651 Mdot
.42067 .19975 Mdot
.3208 .54249 Mdot
.52141 .57183 Mdot
.29267 .5185 Mdot
.37557 .42831 Mdot
.53573 .32219 Mdot
.4606 .64715 Mdot
.66564 .4503 Mdot
.63152 .48046 Mdot
.53144 .59145 Mdot
.21871 .42535 Mdot
.56311 .37598 Mdot
.51208 .3249 Mdot
.48499 .62875 Mdot
.47196 .60921 Mdot
.64823 .48459 Mdot
.41129 .40316 Mdot
.75508 .66511 Mdot
.29448 .53409 Mdot
.55779 .65923 Mdot
.52286 .59333 Mdot
.76948 .67369 Mdot
.55225 .32843 Mdot
.41527 .43328 Mdot
.51568 .69188 Mdot
.63305 .31224 Mdot
.5056 .68922 Mdot
.54395 .55506 Mdot
.35705 .38785 Mdot
.48081 .56232 Mdot
.57241 .63263 Mdot
.71201 .47255 Mdot
.57368 .33803 Mdot
.65504 .46282 Mdot
.71151 .47584 Mdot
.74123 .35857 Mdot
.54256 .364 Mdot
.5271 .6196 Mdot
.56224 .36575 Mdot
.48992 .61794 Mdot
.4766 .61369 Mdot
.56875 .35702 Mdot
.64658 .48563 Mdot
.25671 .68667 Mdot
.3224 .33172 Mdot
.48774 .60043 Mdot
.5743 .59641 Mdot
.33677 .60595 Mdot
.343 .48845 Mdot
.53679 .66937 Mdot
.64114 .45401 Mdot
.54736 .62626 Mdot
.57642 .36933 Mdot
.31238 .50772 Mdot
.66171 .45375 Mdot
.40508 .41596 Mdot
.4102 .42347 Mdot
.66018 .36968 Mdot
.36745 .36779 Mdot
.53081 .67491 Mdot
.63552 .53979 Mdot
.62121 .50966 Mdot
.186 .54756 Mdot
.38271 .412 Mdot
.28718 .53349 Mdot
.54837 .65172 Mdot
.42188 .70853 Mdot
.57754 .3837 Mdot
.49373 .12032 Mdot
.7748 .42081 Mdot
.28455 .52062 Mdot
.74767 .49063 Mdot
.42638 .41017 Mdot
.57181 .5993 Mdot
.29071 .53032 Mdot
.38674 .43031 Mdot
.48488 .61266 Mdot
.56962 .5704 Mdot
.60363 .55163 Mdot
.46378 .3998 Mdot
.56254 .36262 Mdot
.37751 .35936 Mdot
.27856 .53466 Mdot
.41997 .37195 Mdot
.69127 .48209 Mdot
.50645 .6674 Mdot
.50055 .69349 Mdot
.41238 .40484 Mdot
.37804 .4388 Mdot
.53003 .63875 Mdot
.66076 .44502 Mdot
.31412 .38248 Mdot
.51313 .65847 Mdot
.50625 .29921 Mdot
.66336 .43209 Mdot
.3842 .42568 Mdot
.52388 .66987 Mdot
.33534 .57031 Mdot
.40185 .41378 Mdot
.35674 .39843 Mdot
.50979 .58745 Mdot
.33485 .5191 Mdot
.57133 .6504 Mdot
.53093 .31623 Mdot
.28186 .24521 Mdot
.57631 .37032 Mdot
.36158 .45578 Mdot
.5098 .71118 Mdot
.62675 .27497 Mdot
.68303 .45206 Mdot
.41152 .64806 Mdot
.52322 .26141 Mdot
.51536 .55556 Mdot
.41682 .78621 Mdot
.60213 .32846 Mdot
.19196 .52521 Mdot
.44756 .76989 Mdot
.3263 .54601 Mdot
.54299 .35439 Mdot
.5227 .67367 Mdot
.58043 .37351 Mdot
.28858 .53578 Mdot
.27784 .29259 Mdot
.54189 .66273 Mdot
.63776 .46621 Mdot
.5267 .63326 Mdot
.63418 .48049 Mdot
.4935 .59363 Mdot
.56393 .66955 Mdot
.5455 .24868 Mdot
.4124 .57373 Mdot
.50907 .68958 Mdot
.88379 .48034 Mdot
.60198 .5691 Mdot
.29924 .52585 Mdot
.54134 .64257 Mdot
.43987 .38244 Mdot
.54214 .37771 Mdot
.58969 .27252 Mdot
.40011 .38327 Mdot
.52595 .31273 Mdot
.65377 .48393 Mdot
.37695 .39599 Mdot
.41704 .41213 Mdot
.4727 .56957 Mdot
.29517 .51225 Mdot
.54079 .33418 Mdot
.49508 .66122 Mdot
.5377 .6644 Mdot
.79786 .49884 Mdot
.29705 .47022 Mdot
.6863 .54102 Mdot
.77234 .31519 Mdot
.70417 .45968 Mdot
.3159 .519 Mdot
.38812 .37615 Mdot
.50965 .68303 Mdot
.51892 .63402 Mdot
.46087 .26572 Mdot
.63303 .45602 Mdot
.48205 .46717 Mdot
.67928 .54784 Mdot
.36483 .57377 Mdot
.39116 .59134 Mdot
.64555 .45285 Mdot
.38759 .59087 Mdot
.27404 .52326 Mdot
.34098 .78759 Mdot
.41294 .56391 Mdot
.5708 .36351 Mdot
.38014 .58959 Mdot
.64896 .51003 Mdot
.47925 .63325 Mdot
.35957 .3818 Mdot
.36525 .37163 Mdot
.64931 .46953 Mdot
.43752 .39962 Mdot
.32765 .54956 Mdot
.50695 .67576 Mdot
.77996 .45173 Mdot
.68704 .34784 Mdot
.41134 .38785 Mdot
.45841 .59518 Mdot
.5337 .34161 Mdot
.53055 .59045 Mdot
.33584 .53499 Mdot
.55459 .36859 Mdot
.58863 .78792 Mdot
.49298 .32261 Mdot
.54079 .65619 Mdot
.77391 .67188 Mdot
.54379 .36243 Mdot
.57003 .72463 Mdot
.50541 .65879 Mdot
.54197 .3164 Mdot
.45757 .69509 Mdot
.38172 .2944 Mdot
.48936 .4928 Mdot
.50073 .83692 Mdot
.52042 .47398 Mdot
.39403 .37192 Mdot
.38014 .30374 Mdot
.5418 .23482 Mdot
.52538 .35713 Mdot
.398 .44173 Mdot
.48457 .51106 Mdot
.57573 .33424 Mdot
.52824 .57342 Mdot
.49823 .61699 Mdot
.33106 .25515 Mdot
.59916 .3794 Mdot
.33023 .305 Mdot
.67182 .38755 Mdot
.51978 .5823 Mdot
.55759 .6721 Mdot
.51589 .63718 Mdot
.62262 .4878 Mdot
.56118 .3518 Mdot
.8652 .48177 Mdot
.55513 .37555 Mdot
.67265 .57584 Mdot
.40617 .39768 Mdot
.38592 .42855 Mdot
.49696 .6335 Mdot
.56328 .42408 Mdot
.52216 .77579 Mdot
.52524 .63829 Mdot
.32723 .49613 Mdot
.33313 .26681 Mdot
.4823 .59742 Mdot
.67487 .44882 Mdot
.50106 .55573 Mdot
.49727 .71743 Mdot
.52364 .32329 Mdot
.31422 .55486 Mdot
.43315 .6967 Mdot
.53439 .32492 Mdot
.50393 .64018 Mdot
.63673 .29475 Mdot
.51207 .60776 Mdot
.48808 .60192 Mdot
.65098 .56341 Mdot
.34764 .53511 Mdot
.38769 .39867 Mdot
.31454 .53182 Mdot
.68599 .46809 Mdot
.43513 .09946 Mdot
.34397 .54198 Mdot
.55657 .78241 Mdot
.30106 .26164 Mdot
.38089 .58451 Mdot
.64821 .51231 Mdot
.2845 .52593 Mdot
.56858 .3712 Mdot
.43031 .81113 Mdot
.60746 .59376 Mdot
.5976 .33201 Mdot
.51037 .65419 Mdot
.68751 .50564 Mdot
.6291 .48737 Mdot
.571 .32096 Mdot
.6883 .48996 Mdot
.49734 .53898 Mdot
.48185 .61409 Mdot
.53029 .35682 Mdot
.65282 .33351 Mdot
.51635 .34641 Mdot
.40043 .48844 Mdot
.53763 .64774 Mdot
.6575 .453 Mdot
.56919 .63817 Mdot
.61713 .46783 Mdot
.4214 .42713 Mdot
.48518 .68494 Mdot
.32807 .55053 Mdot
.61825 .27429 Mdot
.38684 .42272 Mdot
.38085 .5694 Mdot
.67778 .4844 Mdot
.51247 .37741 Mdot
.67996 .48732 Mdot
.61611 .50367 Mdot
.54078 .31063 Mdot
.66671 .50973 Mdot
.51826 .67443 Mdot
.48568 .49953 Mdot
.67066 .48747 Mdot
.54863 .34413 Mdot
.30638 .55165 Mdot
.65348 .49167 Mdot
.33972 .35856 Mdot
.54756 .65481 Mdot
.38425 .37912 Mdot
.30724 .49009 Mdot
.67259 .51687 Mdot
.33795 .51418 Mdot
.36928 .4329 Mdot
.29824 .55907 Mdot
.18507 .48914 Mdot
.53656 .30073 Mdot
.63795 .58294 Mdot
.3185 .49284 Mdot
.63064 .50406 Mdot
.24424 .61243 Mdot
.49299 .67427 Mdot
.54953 .65213 Mdot
.2891 .55781 Mdot
.62903 .48719 Mdot
.28185 .76164 Mdot
.58619 .67929 Mdot
.41774 .47519 Mdot
.53759 .38371 Mdot
.8544 .56152 Mdot
.40439 .48286 Mdot
.20131 .67045 Mdot
.46194 .59613 Mdot
.35381 .4204 Mdot
.5062 .628 Mdot
.50186 .2496 Mdot
.32477 .53024 Mdot
.35508 .47068 Mdot
.53314 .6986 Mdot
.38183 .39988 Mdot
.55799 .62181 Mdot
.5648 .48549 Mdot
.54091 .73297 Mdot
.28529 .54515 Mdot
.23425 .4129 Mdot
.67175 .51599 Mdot
.31324 .54701 Mdot
.37454 .42322 Mdot
.4162 .60199 Mdot
.48424 .61175 Mdot
.53262 .57316 Mdot
.36349 .57402 Mdot
.63716 .49685 Mdot
.37584 .37184 Mdot
.53276 .31725 Mdot
.3063 .55518 Mdot
.54133 .6181 Mdot
.49629 .67977 Mdot
.45515 .25502 Mdot
.53268 .34726 Mdot
.34792 .38771 Mdot
.57492 .35041 Mdot
.42406 .40543 Mdot
.47641 .63978 Mdot
.40252 .42549 Mdot
.55955 .57566 Mdot
.6013 .30438 Mdot
.6467 .57268 Mdot
.69881 .64704 Mdot
.37177 .39697 Mdot
.60152 .77848 Mdot
.53456 .35069 Mdot
.56592 .3358 Mdot
.35497 .22237 Mdot
.60973 .58297 Mdot
.79883 .47315 Mdot
.37445 .75155 Mdot
.52763 .34602 Mdot
.53905 .339 Mdot
.38346 .3801 Mdot
.66969 .50785 Mdot
.7032 .46574 Mdot
.42216 .40666 Mdot
.33283 .65772 Mdot
.64716 .51016 Mdot
.39262 .79353 Mdot
.80795 .53212 Mdot
.5353 .56285 Mdot
.32802 .38656 Mdot
.30001 .53579 Mdot
.34581 .65402 Mdot
.55662 .4896 Mdot
.54226 .66468 Mdot
.4067 .67092 Mdot
.41023 .39816 Mdot
.56707 .41338 Mdot
.49939 .82904 Mdot
.55901 .6133 Mdot
.50164 .6602 Mdot
.51008 .63525 Mdot
.30451 .50634 Mdot
.61587 .65791 Mdot
.51274 .67231 Mdot
.32999 .65759 Mdot
.52567 .58511 Mdot
.54593 .7355 Mdot
.30803 .53523 Mdot
.46551 .52775 Mdot
.31254 .47937 Mdot
.84119 .48837 Mdot
.54488 .72435 Mdot
.52663 .31794 Mdot
.32899 .44696 Mdot
.56878 .33592 Mdot
.66993 .6362 Mdot
.40317 .56585 Mdot
.70274 .4545 Mdot
.53935 .66643 Mdot
.37255 .40565 Mdot
.62939 .48699 Mdot
.41172 .2886 Mdot
.477 .0965 Mdot
.51884 .3282 Mdot
.35819 .84594 Mdot
.54905 .31917 Mdot
.41749 .41016 Mdot
.64879 .48348 Mdot
.65538 .74374 Mdot
.74566 .41556 Mdot
.65539 .4901 Mdot
.25367 .71548 Mdot
.65491 .42353 Mdot
.42718 .66779 Mdot
.64239 .52124 Mdot
.54443 .34433 Mdot
.56687 .4038 Mdot
.48615 .53748 Mdot
.48614 .6524 Mdot
.47371 .43385 Mdot
.51921 .7728 Mdot
.49428 .67531 Mdot
.37586 .41558 Mdot
.62347 .57006 Mdot
.39699 .6524 Mdot
.65966 .51184 Mdot
.50349 .31065 Mdot
.508 .6648 Mdot
.5145 .5935 Mdot
.48191 .62114 Mdot
.77992 .40529 Mdot
.33624 .78533 Mdot
.47792 .6395 Mdot
.50259 .58783 Mdot
.37867 .39812 Mdot
.35652 .5045 Mdot
.28741 .35751 Mdot
.76971 .51829 Mdot
.56364 .61429 Mdot
.30898 .54408 Mdot
.27586 .54545 Mdot
.48531 .67309 Mdot
.47824 .50706 Mdot
.63747 .28752 Mdot
.49616 .66299 Mdot
.61968 .56854 Mdot
.4194 .34318 Mdot
.34536 .38866 Mdot
.40647 .4124 Mdot
.69076 .49537 Mdot
.41689 .40218 Mdot
.42127 .41934 Mdot
.60384 .76288 Mdot
.50406 .46884 Mdot
.58784 .28944 Mdot
.31831 .52477 Mdot
.51801 .62689 Mdot
.55235 .53413 Mdot
.6315 .30172 Mdot
.56609 .32546 Mdot
.66861 .45783 Mdot
.54935 .38237 Mdot
.27665 .56129 Mdot
.75851 .39784 Mdot
.40603 .3712 Mdot
.52561 .33257 Mdot
.5307 .29675 Mdot
.30678 .54328 Mdot
.5823 .3515 Mdot
.47898 .37098 Mdot
.46797 .63725 Mdot
.67207 .70456 Mdot
.52688 .64548 Mdot
.19248 .59878 Mdot
.53434 .33473 Mdot
.5489 .39482 Mdot
.49729 .6473 Mdot
.39884 .41492 Mdot
.43808 .66661 Mdot
.48526 .64725 Mdot
.41583 .40096 Mdot
.54371 .68568 Mdot
.34067 .55749 Mdot
.65715 .43651 Mdot
.74407 .4174 Mdot
.29598 .22374 Mdot
.29221 .51485 Mdot
.41962 .28357 Mdot
.55125 .66062 Mdot
.19681 .40698 Mdot
.65208 .49459 Mdot
.53071 .6851 Mdot
.39616 .62229 Mdot
.66544 .49627 Mdot
.66279 .46834 Mdot
.52473 .60516 Mdot
.57352 .35922 Mdot
.38648 .42438 Mdot
.30407 .5399 Mdot
.1818 .61678 Mdot
.52083 .65661 Mdot
.55376 .62991 Mdot
.31646 .54476 Mdot
.5397 .36453 Mdot
.50214 .6874 Mdot
.35955 .71261 Mdot
.31732 .78898 Mdot
.54777 .31666 Mdot
.55126 .59389 Mdot
.66169 .66545 Mdot
.56389 .70995 Mdot
.16058 .43985 Mdot
.52054 .50101 Mdot
.38633 .3935 Mdot
.54705 .70694 Mdot
.614 .16927 Mdot
.30921 .5542 Mdot
.80586 .45944 Mdot
.51608 .59261 Mdot
.54402 .60782 Mdot
.63053 .46358 Mdot
.53595 .63779 Mdot
.67645 .45735 Mdot
.3865 .17963 Mdot
.7948 .64777 Mdot
.69739 .48134 Mdot
.63614 .51148 Mdot
.44643 .71715 Mdot
.52947 .28249 Mdot
.65002 .47232 Mdot
.47563 .61158 Mdot
.44316 .52947 Mdot
.66559 .41051 Mdot
.28539 .52973 Mdot
.24324 .57372 Mdot
.59434 .61015 Mdot
.29288 .58861 Mdot
.26526 .68552 Mdot
.58111 .54963 Mdot
.39897 .50156 Mdot
.5571 .32918 Mdot
.55969 .61256 Mdot
.3634 .37228 Mdot
.36208 .37104 Mdot
.56232 .57564 Mdot
.51724 .61554 Mdot
.68409 .47351 Mdot
.29587 .54671 Mdot
.52777 .36479 Mdot
.54204 .609 Mdot
.41145 .63891 Mdot
.30794 .55904 Mdot
.68288 .4969 Mdot
.66989 .59181 Mdot
.35205 .54965 Mdot
.57559 .64945 Mdot
.48983 .6542 Mdot
.52639 .62739 Mdot
.48595 .53602 Mdot
.56299 .34857 Mdot
.27357 .68101 Mdot
.49788 .58356 Mdot
.83656 .56312 Mdot
.56952 .27648 Mdot
.54103 .70278 Mdot
.68683 .48534 Mdot
.50239 .32125 Mdot
.4316 .39601 Mdot
.72478 .32138 Mdot
.53718 .6569 Mdot
.22665 .41685 Mdot
.32492 .26185 Mdot
.3996 .43817 Mdot
.62721 .44989 Mdot
.31168 .52758 Mdot
.52398 .6353 Mdot
.63837 .6122 Mdot
.49783 .62052 Mdot
.2685 .52592 Mdot
.35807 .40562 Mdot
.55967 .33204 Mdot
.19334 .54493 Mdot
.37106 .36304 Mdot
.66055 .46697 Mdot
.6916 .77438 Mdot
.67638 .45594 Mdot
.70335 .46797 Mdot
.68115 .59064 Mdot
.56398 .3481 Mdot
.54893 .13391 Mdot
.40893 .18026 Mdot
.47357 .64448 Mdot
.53753 .35969 Mdot
.64846 .46172 Mdot
.5373 .5886 Mdot
.63624 .43261 Mdot
.69151 .44685 Mdot
.47598 .62423 Mdot
.54884 .60907 Mdot
.2872 .32847 Mdot
.46491 .80302 Mdot
.31361 .52694 Mdot
.6889 .45993 Mdot
.73599 .39657 Mdot
.53691 .58643 Mdot
.49899 .63762 Mdot
.48653 .21928 Mdot
.30223 .50961 Mdot
.70966 .35422 Mdot
.5152 .5931 Mdot
.72262 .72793 Mdot
.51521 .54707 Mdot
.64094 .44472 Mdot
.56539 .33042 Mdot
.83954 .50612 Mdot
.47462 .37114 Mdot
.67621 .45875 Mdot
.32474 .55733 Mdot
.63125 .52142 Mdot
.57858 .78337 Mdot
.54418 .37217 Mdot
.65245 .44909 Mdot
.40381 .51795 Mdot
.55703 .35766 Mdot
.53221 .32999 Mdot
.70268 .57536 Mdot
.43284 .41744 Mdot
.28976 .51349 Mdot
.53937 .33574 Mdot
.60737 .23212 Mdot
.54917 .35071 Mdot
.38761 .18854 Mdot
.55716 .60642 Mdot
.37793 .67328 Mdot
.35553 .45526 Mdot
.58871 .6481 Mdot
.53056 .33743 Mdot
.3252 .51327 Mdot
.48629 .61079 Mdot
.66862 .51342 Mdot
.29091 .54402 Mdot
.5947 .35437 Mdot
.39671 .38414 Mdot
.67647 .49237 Mdot
.58994 .39251 Mdot
.63289 .47806 Mdot
.67039 .27638 Mdot
.27987 .26457 Mdot
.46366 .74804 Mdot
.74708 .41264 Mdot
.4843 .60982 Mdot
.33691 .75344 Mdot
.55462 .59187 Mdot
.51661 .60774 Mdot
.37963 .42195 Mdot
.38935 .66804 Mdot
.64645 .48438 Mdot
.22604 .67544 Mdot
.52407 .32548 Mdot
.84325 .49558 Mdot
.54324 .72129 Mdot
.55251 .66821 Mdot
.67254 .48405 Mdot
.64406 .44596 Mdot
.69882 .61545 Mdot
.39794 .35634 Mdot
.55496 .66005 Mdot
.46189 .61523 Mdot
.56238 .57096 Mdot
.53085 .3216 Mdot
.43266 .52813 Mdot
.39919 .3734 Mdot
.23763 .31805 Mdot
.35868 .40923 Mdot
.2567 .56383 Mdot
.67022 .50989 Mdot
.34362 .54273 Mdot
.49712 .63996 Mdot
.6342 .54691 Mdot
.63011 .45981 Mdot
.29069 .55811 Mdot
.32521 .5166 Mdot
.41279 .26211 Mdot
.56825 .35773 Mdot
.48295 .6506 Mdot
.52147 .6707 Mdot
.53722 .63008 Mdot
.52088 .61111 Mdot
.51955 .3295 Mdot
.48439 .62096 Mdot
.58442 .37949 Mdot
.73367 .3228 Mdot
.38183 .70422 Mdot
.52703 .47342 Mdot
.45015 .20331 Mdot
.65606 .51276 Mdot
.61193 .24253 Mdot
.48714 .70399 Mdot
.7094 .27343 Mdot
.27037 .31255 Mdot
.46891 .60978 Mdot
.40693 .42623 Mdot
.47915 .72385 Mdot
.38499 .36463 Mdot
.20607 .69183 Mdot
.50741 .2307 Mdot
.45214 .80125 Mdot
.5392 .66354 Mdot
.48224 .49931 Mdot
.57662 .21348 Mdot
.54954 .58601 Mdot
.44951 .24549 Mdot
.49303 .20629 Mdot
.25331 .38426 Mdot
.33411 .52075 Mdot
.52718 .66267 Mdot
.54247 .53179 Mdot
.51339 .6752 Mdot
.50271 .63094 Mdot
.48311 .62081 Mdot
.53311 .37631 Mdot
.5261 .68338 Mdot
.49491 .60337 Mdot
.23267 .46549 Mdot
.39789 .58556 Mdot
.34957 .40879 Mdot
.33701 .23546 Mdot
.34479 .53981 Mdot
.67589 .48378 Mdot
.32463 .76851 Mdot
.57019 .36387 Mdot
.7049 .61686 Mdot
.52294 .61815 Mdot
.30241 .32974 Mdot
.49414 .3135 Mdot
.32631 .5554 Mdot
.3814 .43239 Mdot
.45567 .81618 Mdot
.37541 .40967 Mdot
.50086 .34594 Mdot
.39458 .41672 Mdot
.52385 .7159 Mdot
.68551 .47096 Mdot
.48276 .66171 Mdot
.54298 .33307 Mdot
.40906 .4154 Mdot
.33449 .61466 Mdot
.51488 .63494 Mdot
.3806 .4084 Mdot
.48218 .65848 Mdot
.74995 .46039 Mdot
.78635 .53057 Mdot
.41363 .42561 Mdot
.54839 .3006 Mdot
.55406 .33673 Mdot
.33846 .53124 Mdot
.67196 .49301 Mdot
.67193 .45889 Mdot
.5532 .36716 Mdot
.60985 .52466 Mdot
.5644 .61206 Mdot
.54378 .59522 Mdot
.83601 .53178 Mdot
.51838 .67758 Mdot
.41861 .59982 Mdot
.4119 .51956 Mdot
.68622 .49753 Mdot
.56281 .65856 Mdot
.52532 .60017 Mdot
.5432 .65542 Mdot
.75931 .45765 Mdot
.41379 .39872 Mdot
.55849 .61036 Mdot
.31574 .51467 Mdot
.35672 .32943 Mdot
.52994 .59006 Mdot
.4946 .55008 Mdot
.67064 .45736 Mdot
.77764 .33288 Mdot
.55312 .32219 Mdot
.37355 .42166 Mdot
.37143 .39562 Mdot
.26268 .66462 Mdot
.5759 .23415 Mdot
.41475 .51847 Mdot
.18701 .37395 Mdot
.54644 .24927 Mdot
.32497 .52129 Mdot
.33995 .40408 Mdot
.58731 .4036 Mdot
.37032 .38702 Mdot
.51761 .33651 Mdot
.55181 .59717 Mdot
.56319 .61075 Mdot
.59593 .1754 Mdot
.496 .68464 Mdot
.30721 .53042 Mdot
.5222 .35999 Mdot
.64588 .50701 Mdot
.32098 .557 Mdot
.57466 .34743 Mdot
.69126 .49381 Mdot
.46981 .60689 Mdot
.48812 .58871 Mdot
.66968 .46089 Mdot
.63214 .46346 Mdot
.49133 .65111 Mdot
.47365 .32067 Mdot
.63469 .50785 Mdot
.64584 .45183 Mdot
.40944 .37587 Mdot
.36684 .36924 Mdot
.56331 .55486 Mdot
.53602 .34938 Mdot
.49164 .60607 Mdot
.37495 .39848 Mdot
.34347 .54148 Mdot
.64539 .48855 Mdot
.49207 .59739 Mdot
.53418 .5982 Mdot
.30593 .54445 Mdot
.339 .54261 Mdot
.33521 .53225 Mdot
.58659 .39064 Mdot
.54215 .63575 Mdot
.65185 .4802 Mdot
.5675 .35139 Mdot
.27532 .53793 Mdot
.29224 .5204 Mdot
.33891 .38205 Mdot
.51818 .68129 Mdot
.39993 .45727 Mdot
.63185 .177 Mdot
.81002 .61059 Mdot
.41502 .42914 Mdot
.43047 .39094 Mdot
.29265 .6104 Mdot
.60605 .41108 Mdot
.55282 .37267 Mdot
.34684 .49231 Mdot
.46993 .74785 Mdot
.46368 .64375 Mdot
.4856 .59599 Mdot
.55562 .67836 Mdot
.33403 .52801 Mdot
.39893 .69045 Mdot
.6805 .46028 Mdot
.4542 .54311 Mdot
.30635 .55937 Mdot
.36519 .42908 Mdot
.33713 .40545 Mdot
.36154 .41461 Mdot
.5147 .57338 Mdot
.70473 .65554 Mdot
.5991 .24693 Mdot
.35743 .73407 Mdot
.53145 .34332 Mdot
.55734 .53645 Mdot
.2058 .39388 Mdot
.66724 .46619 Mdot
.41305 .36931 Mdot
.3217 .51856 Mdot
.63159 .46709 Mdot
.55526 .38363 Mdot
.54065 .33798 Mdot
.41063 .38667 Mdot
.40792 .38678 Mdot
.36439 .3838 Mdot
.68745 .44111 Mdot
.66915 .50962 Mdot
.53855 .65502 Mdot
.64461 .49547 Mdot
.76284 .34449 Mdot
.3068 .56845 Mdot
.4451 .38508 Mdot
.54044 .35255 Mdot
.65777 .51596 Mdot
.51718 .63729 Mdot
.71816 .44194 Mdot
.62728 .34395 Mdot
.29719 .52637 Mdot
.79169 .51518 Mdot
.18078 .63949 Mdot
.48473 .66183 Mdot
.55907 .33945 Mdot
.78493 .4376 Mdot
.51097 .63813 Mdot
.38081 .37526 Mdot
.21754 .53116 Mdot
.45792 .39534 Mdot
.48565 .64175 Mdot
.46881 .64563 Mdot
.5283 .31514 Mdot
.23515 .3232 Mdot
.53048 .6566 Mdot
.71233 .34117 Mdot
.51553 .29964 Mdot
.38661 .37185 Mdot
.45556 .86401 Mdot
.35553 .56698 Mdot
.34243 .65736 Mdot
.40872 .3791 Mdot
.50483 .60546 Mdot
.39228 .36394 Mdot
.3077 .51631 Mdot
.38245 .43092 Mdot
.67451 .45212 Mdot
.36666 .42607 Mdot
.55343 .62887 Mdot
.65096 .46811 Mdot
.54328 .36268 Mdot
.83427 .48532 Mdot
.23482 .52082 Mdot
.40024 .41338 Mdot
.41682 .42013 Mdot
.5555 .66821 Mdot
.72184 .38228 Mdot
.56611 .58605 Mdot
.54758 .59238 Mdot
.53325 .35845 Mdot
.66775 .49446 Mdot
.54498 .31421 Mdot
.58598 .61359 Mdot
.39753 .72505 Mdot
.57358 .34925 Mdot
.29013 .3495 Mdot
.32277 .54118 Mdot
.52482 .43004 Mdot
.51982 .63271 Mdot
.57999 .33974 Mdot
.54283 .63864 Mdot
.68279 .46207 Mdot
.54497 .46283 Mdot
.4309 .32143 Mdot
.53918 .32612 Mdot
.20205 .48732 Mdot
.35722 .69715 Mdot
.52979 .53773 Mdot
.56545 .3338 Mdot
.39228 .63269 Mdot
.41792 .40845 Mdot
.29271 .53725 Mdot
.32947 .56331 Mdot
.30686 .56083 Mdot
.51433 .55895 Mdot
.54141 .72307 Mdot
.33493 .51073 Mdot
.54146 .37601 Mdot
.28517 .54412 Mdot
.50183 .18532 Mdot
.22825 .6796 Mdot
.3237 .53419 Mdot
.50755 .65733 Mdot
.46928 .69835 Mdot
.37921 .58119 Mdot
.37471 .29292 Mdot
.43799 .79429 Mdot
.40736 .23522 Mdot
.48783 .64018 Mdot
.66629 .43069 Mdot
.69004 .45039 Mdot
.79554 .3989 Mdot
.55142 .77714 Mdot
.78837 .64806 Mdot
.69584 .49104 Mdot
.48487 .28028 Mdot
.67851 .49824 Mdot
.47915 .64886 Mdot
.54157 .59238 Mdot
.70768 .47076 Mdot
.40779 .72064 Mdot
.46274 .28528 Mdot
.1848 .57665 Mdot
.63218 .47272 Mdot
.57295 .33716 Mdot
.55673 .31357 Mdot
.53055 .33203 Mdot
.81439 .50947 Mdot
.66913 .48352 Mdot
.53674 .61622 Mdot
.37097 .40063 Mdot
.56275 .62074 Mdot
.55928 .35964 Mdot
.23542 .70589 Mdot
.65845 .49269 Mdot
.5106 .66828 Mdot
.45092 .58517 Mdot
.40345 .38538 Mdot
.31324 .54161 Mdot
.74201 .45292 Mdot
.77498 .66216 Mdot
.52461 .32816 Mdot
.67725 .51403 Mdot
.59451 .39987 Mdot
.19431 .57634 Mdot
.45412 .60837 Mdot
.46645 .66997 Mdot
.1813 .62097 Mdot
.68011 .76393 Mdot
.54521 .66603 Mdot
.39192 .43231 Mdot
.46546 .26033 Mdot
.52559 .59113 Mdot
.68959 .45367 Mdot
.34867 .55328 Mdot
.29398 .55487 Mdot
.5536 .5473 Mdot
.72178 .43199 Mdot
.54951 .48468 Mdot
.52607 .61656 Mdot
.57128 .65886 Mdot
.39553 .37303 Mdot
.50679 .24116 Mdot
.83194 .57398 Mdot
.33868 .54869 Mdot
.48458 .66864 Mdot
.24278 .67611 Mdot
.62656 .47886 Mdot
.40145 .43689 Mdot
.57849 .37012 Mdot
.6795 .42697 Mdot
.38363 .43331 Mdot
.48318 .6017 Mdot
.49212 .68113 Mdot
.55988 .31981 Mdot
.64423 .44282 Mdot
.33357 .53279 Mdot
.37892 .42336 Mdot
.3349 .54567 Mdot
.66482 .49455 Mdot
.65051 .50462 Mdot
.47115 .5619 Mdot
.45065 .62703 Mdot
.40372 .41633 Mdot
.547 .56607 Mdot
.46308 .3547 Mdot
.14746 .49075 Mdot
.59482 .39504 Mdot
.51779 .68536 Mdot
.64041 .52396 Mdot
.53394 .32333 Mdot
.54591 .60949 Mdot
.21198 .68539 Mdot
.53106 .5836 Mdot
.52343 .36754 Mdot
.56867 .79342 Mdot
.33193 .54427 Mdot
.51027 .522 Mdot
.26497 .32981 Mdot
.51091 .67946 Mdot
.37802 .38621 Mdot
.46995 .58033 Mdot
.57386 .36417 Mdot
.66246 .51206 Mdot
.1388 .4985 Mdot
.55116 .34737 Mdot
.50156 .67275 Mdot
.31094 .55673 Mdot
.63143 .51319 Mdot
.52434 .50437 Mdot
.46341 .51016 Mdot
.44597 .66438 Mdot
.56198 .65394 Mdot
.51897 .60022 Mdot
.36693 .72342 Mdot
.36807 .41242 Mdot
.64636 .45501 Mdot
.55617 .33346 Mdot
.55333 .36959 Mdot
.41166 .39245 Mdot
.40771 .4578 Mdot
.52346 .42998 Mdot
.71726 .23324 Mdot
.40024 .36467 Mdot
.34171 .54941 Mdot
.71761 .36522 Mdot
.36991 .41053 Mdot
.38448 .40995 Mdot
.40637 .37271 Mdot
.40702 .5078 Mdot
.64726 .51081 Mdot
.48425 .60019 Mdot
.67634 .44552 Mdot
.50359 .60394 Mdot
.51333 .35054 Mdot
.54014 .32929 Mdot
.65859 .49839 Mdot
.17505 .53661 Mdot
.65363 .71041 Mdot
.50577 .64628 Mdot
.19809 .40557 Mdot
.51663 .69847 Mdot
.34072 .59484 Mdot
.52872 .69523 Mdot
.40284 .40674 Mdot
.52911 .57094 Mdot
.53265 .55654 Mdot
.80207 .42663 Mdot
.53834 .35255 Mdot
.34281 .39778 Mdot
.55482 .68931 Mdot
.57441 .64993 Mdot
.68699 .43916 Mdot
.63375 .4618 Mdot
.32332 .5642 Mdot
.42912 .58222 Mdot
.5443 .36602 Mdot
.47977 .16472 Mdot
.48669 .65321 Mdot
.30989 .58601 Mdot
.7702 .62841 Mdot
.54697 .61223 Mdot
.2439 .35581 Mdot
.70568 .6457 Mdot
.52273 .63442 Mdot
.45186 .46052 Mdot
.5338 .34875 Mdot
.44396 .76039 Mdot
.52155 .58577 Mdot
.39827 .37974 Mdot
.67636 .50412 Mdot
.62695 .46793 Mdot
.33719 .5585 Mdot
.65505 .22537 Mdot
.5422 .31268 Mdot
.66065 .50805 Mdot
.51313 .62763 Mdot
.5608 .33987 Mdot
.41123 .3732 Mdot
.54319 .67607 Mdot
.62672 .77842 Mdot
.64178 .49381 Mdot
.54359 .68676 Mdot
.68885 .3132 Mdot
.30553 .63338 Mdot
.57254 .80502 Mdot
.55189 .32735 Mdot
.3375 .52922 Mdot
.52415 .5501 Mdot
.59945 .511 Mdot
.57566 .61901 Mdot
.36084 .67241 Mdot
.4876 .18732 Mdot
.31691 .50841 Mdot
.49865 .65128 Mdot
.54015 .6162 Mdot
.5882 .45094 Mdot
.33307 .55386 Mdot
.53472 .66604 Mdot
.6088 .42592 Mdot
.63554 .47931 Mdot
.4221 .3875 Mdot
.64153 .50209 Mdot
.50958 .65394 Mdot
.44904 .6329 Mdot
.63199 .46093 Mdot
.16412 .47388 Mdot
.35141 .55606 Mdot
.56402 .33489 Mdot
.47729 .66552 Mdot
.5147 .57754 Mdot
.86768 .43708 Mdot
.3955 .44054 Mdot
.45999 .32418 Mdot
.29415 .36668 Mdot
.25081 .66226 Mdot
.36779 .54138 Mdot
.53311 .8213 Mdot
.67292 .7696 Mdot
.52698 .68375 Mdot
.5749 .52401 Mdot
.64731 .27227 Mdot
.53341 .35436 Mdot
.60149 .20581 Mdot
.4861 .65328 Mdot
.5043 .62862 Mdot
.42692 .41829 Mdot
.41261 .31733 Mdot
.79468 .6406 Mdot
.7188 .46984 Mdot
.33226 .53781 Mdot
.68863 .4673 Mdot
.47835 .60663 Mdot
.47033 .46804 Mdot
.37342 .43611 Mdot
.2943 .57436 Mdot
.50653 .66714 Mdot
.76354 .46214 Mdot
.63527 .35113 Mdot
.56541 .35583 Mdot
.3719 .39323 Mdot
.75003 .6868 Mdot
.51241 .68337 Mdot
.58245 .34386 Mdot
.52078 .65311 Mdot
.37148 .53955 Mdot
.58408 .63955 Mdot
.32277 .52249 Mdot
.5065 .5927 Mdot
.32399 .43329 Mdot
.87359 .55139 Mdot
.28804 .50993 Mdot
.68524 .43399 Mdot
.41607 .43781 Mdot
.41367 .40117 Mdot
.63762 .45624 Mdot
.40958 .40756 Mdot
.71185 .59856 Mdot
.61908 .76405 Mdot
.32518 .54166 Mdot
.56697 .56084 Mdot
.31843 .53526 Mdot
.4165 .43098 Mdot
.48642 .64273 Mdot
.14914 .5633 Mdot
.40026 .42265 Mdot
.71085 .74636 Mdot
.54935 .35444 Mdot
.38437 .44172 Mdot
.52594 .58559 Mdot
.62197 .37408 Mdot
.37161 .36324 Mdot
.45776 .30648 Mdot
.54263 .65538 Mdot
.64726 .50558 Mdot
.52979 .59578 Mdot
.47361 .64015 Mdot
.35262 .41746 Mdot
.49219 .61119 Mdot
.57519 .34825 Mdot
.70101 .48219 Mdot
.41439 .80134 Mdot
.52814 .21072 Mdot
.53315 .66832 Mdot
.51263 .63068 Mdot
.61857 .50378 Mdot
.5298 .57531 Mdot
.51999 .32819 Mdot
.19792 .28292 Mdot
.32204 .54138 Mdot
.36419 .43772 Mdot
.30851 .4037 Mdot
.46272 .62406 Mdot
.48537 .61509 Mdot
.24408 .74572 Mdot
.38779 .71682 Mdot
.56916 .33773 Mdot
.56004 .56858 Mdot
.38692 .35942 Mdot
.29824 .54743 Mdot
.53133 .36653 Mdot
.52739 .63018 Mdot
.49732 .6432 Mdot
.34015 .53604 Mdot
.31878 .59104 Mdot
.81046 .54598 Mdot
.57154 .32473 Mdot
.51238 .71169 Mdot
.34914 .35195 Mdot
.56571 .61071 Mdot
.8039 .49794 Mdot
.65795 .45102 Mdot
.52391 .3309 Mdot
.26521 .67841 Mdot
.51751 .68407 Mdot
.56571 .32856 Mdot
.54267 .36411 Mdot
.57358 .62899 Mdot
.67909 .5175 Mdot
.70495 .47368 Mdot
.63346 .4816 Mdot
.48556 .12891 Mdot
.35369 .64688 Mdot
.36442 .38372 Mdot
.53422 .35198 Mdot
.42277 .41517 Mdot
.26789 .5266 Mdot
.47369 .49613 Mdot
.41938 .41954 Mdot
.63546 .49741 Mdot
.37309 .44033 Mdot
.54684 .63379 Mdot
.54546 .36601 Mdot
.37205 .38376 Mdot
.47121 .6318 Mdot
.72898 .42525 Mdot
.36193 .2755 Mdot
.30517 .51237 Mdot
.35361 .54377 Mdot
.53704 .59124 Mdot
.416 .36918 Mdot
.49207 .64603 Mdot
.58059 .37127 Mdot
.73326 .41044 Mdot
.47472 .64099 Mdot
.40322 .41105 Mdot
.62032 .50485 Mdot
.75699 .67878 Mdot
.51048 .56521 Mdot
.50615 .65663 Mdot
.49824 .607 Mdot
.52152 .65325 Mdot
.19882 .56247 Mdot
.54167 .30831 Mdot
.46277 .20374 Mdot
.2617 .65565 Mdot
.65911 .4863 Mdot
.66471 .44017 Mdot
.82296 .5802 Mdot
.64429 .28054 Mdot
.53544 .34877 Mdot
.51825 .60903 Mdot
.63281 .31938 Mdot
.31543 .78618 Mdot
.17466 .58335 Mdot
.5891 .7115 Mdot
.39941 .44007 Mdot
.6767 .51415 Mdot
.41377 .41263 Mdot
.50217 .61014 Mdot
.57004 .65706 Mdot
.59432 .82299 Mdot
.54878 .37897 Mdot
.3294 .53605 Mdot
.50271 .60236 Mdot
.34914 .64871 Mdot
.37833 .39638 Mdot
.3844 .44204 Mdot
.55346 .6077 Mdot
.62104 .48196 Mdot
.86549 .55194 Mdot
.56247 .34792 Mdot
.44432 .21698 Mdot
.56842 .20884 Mdot
.64244 .3871 Mdot
.56104 .35694 Mdot
.59289 .50662 Mdot
.40455 .43477 Mdot
.7747 .59817 Mdot
.66347 .48017 Mdot
.29092 .53921 Mdot
.5325 .70483 Mdot
.65508 .44648 Mdot
.35384 .39706 Mdot
.65506 .51097 Mdot
.4839 .6164 Mdot
.51978 .30019 Mdot
.38746 .39132 Mdot
.57673 .27761 Mdot
.63908 .52361 Mdot
.32816 .55601 Mdot
.50658 .38857 Mdot
.58754 .73473 Mdot
.70646 .6414 Mdot
.55608 .60869 Mdot
.46182 .47425 Mdot
.5365 .61974 Mdot
.62221 .45756 Mdot
.51774 .64263 Mdot
.64848 .54012 Mdot
.37942 .38635 Mdot
.50542 .58688 Mdot
.52416 .61238 Mdot
.38223 .19794 Mdot
.53115 .66505 Mdot
.56773 .59983 Mdot
.52268 .62974 Mdot
.6311 .54212 Mdot
.54662 .54603 Mdot
.68734 .48269 Mdot
.26812 .37865 Mdot
.38771 .40935 Mdot
.29674 .55979 Mdot
.33654 .52132 Mdot
.38165 .66521 Mdot
.3194 .45702 Mdot
.37459 .31181 Mdot
.63851 .48247 Mdot
.57869 .35565 Mdot
.52003 .64705 Mdot
.49286 .82307 Mdot
.37712 .34413 Mdot
.36384 .42627 Mdot
.53078 .21258 Mdot
.57499 .6877 Mdot
.46956 .78055 Mdot
.56666 .57704 Mdot
.56667 .16197 Mdot
.46454 .60458 Mdot
.56078 .69674 Mdot
.40788 .36753 Mdot
.27206 .57528 Mdot
.53321 .57828 Mdot
.69668 .46086 Mdot
.3045 .52437 Mdot
.54487 .71966 Mdot
.33986 .42954 Mdot
.38526 .32733 Mdot
.70357 .52336 Mdot
.54298 .64701 Mdot
.38847 .39187 Mdot
.67649 .49088 Mdot
.82372 .59289 Mdot
.56703 .34906 Mdot
.38642 .46223 Mdot
.72288 .33289 Mdot
.17265 .46416 Mdot
.3118 .55994 Mdot
.76555 .55321 Mdot
.55173 .6299 Mdot
.22079 .49003 Mdot
.47581 .65763 Mdot
.25155 .73546 Mdot
.34225 .52475 Mdot
.63892 .50545 Mdot
.5754 .34012 Mdot
.6887 .45408 Mdot
.69779 .63537 Mdot
.32966 .40233 Mdot
.51251 .45532 Mdot
.37676 .40989 Mdot
.53977 .49159 Mdot
.65232 .45949 Mdot
.4812 .64973 Mdot
.70969 .22588 Mdot
.6501 .45018 Mdot
.63526 .51683 Mdot
.29257 .26951 Mdot
.14736 .52278 Mdot
.46012 .65868 Mdot
.63661 .51085 Mdot
.38099 .41514 Mdot
.31067 .52585 Mdot
.51606 .58913 Mdot
.54782 .64428 Mdot
.66133 .44858 Mdot
.34902 .41634 Mdot
.63822 .65537 Mdot
.40788 .39327 Mdot
.64319 .50733 Mdot
.39691 .40014 Mdot
.52521 .37739 Mdot
.3772 .42396 Mdot
.51429 .57732 Mdot
.51842 .6438 Mdot
.28507 .41074 Mdot
.6497 .50436 Mdot
.5271 .61814 Mdot
.553 .67071 Mdot
.65033 .47881 Mdot
.58451 .49466 Mdot
.64634 .65354 Mdot
.55625 .65539 Mdot
.54044 .65944 Mdot
.33188 .51542 Mdot
.47701 .48664 Mdot
.78047 .53112 Mdot
.48765 .60787 Mdot
.31483 .50589 Mdot
.69692 .47091 Mdot
.49477 .662 Mdot
.30142 .75261 Mdot
.46318 .26329 Mdot
.48551 .66155 Mdot
.41721 .40973 Mdot
.54669 .56179 Mdot
.58796 .80145 Mdot
.54621 .58994 Mdot
.64683 .47144 Mdot
.66537 .50412 Mdot
.45998 .17202 Mdot
.65989 .46511 Mdot
.36538 .37144 Mdot
.55791 .35894 Mdot
.19143 .57395 Mdot
.41797 .39299 Mdot
.47365 .58788 Mdot
.3205 .21831 Mdot
.53319 .68884 Mdot
.47569 .60195 Mdot
.76207 .69817 Mdot
.40867 .41742 Mdot
.67913 .47603 Mdot
.51916 .40035 Mdot
.45197 .64233 Mdot
.52618 .3299 Mdot
.56745 .6762 Mdot
.55131 .5945 Mdot
.62231 .79368 Mdot
.2028 .56391 Mdot
.58216 .33811 Mdot
.56731 .60093 Mdot
.48648 .6105 Mdot
.44001 .38392 Mdot
.51625 .63151 Mdot
.31579 .5246 Mdot
.66902 .48569 Mdot
.3878 .43046 Mdot
.30688 .54772 Mdot
.50245 .67986 Mdot
.33473 .53246 Mdot
.38351 .37893 Mdot
.57138 .37891 Mdot
.49557 .62078 Mdot
.28428 .53231 Mdot
.33373 .5366 Mdot
.535 .62155 Mdot
.66992 .5108 Mdot
.58468 .67425 Mdot
.52684 .66694 Mdot
.4914 .59838 Mdot
.67308 .46047 Mdot
.44195 .86985 Mdot
.54299 .59264 Mdot
.36706 .68131 Mdot
.64602 .44545 Mdot
.56115 .49393 Mdot
.41986 .38853 Mdot
.54495 .58396 Mdot
.57209 .37878 Mdot
.57489 .37383 Mdot
.36274 .41807 Mdot
.67083 .51819 Mdot
.30301 .36249 Mdot
.71135 .46724 Mdot
.49405 .56221 Mdot
.56452 .59065 Mdot
.60504 .57152 Mdot
.46848 .8153 Mdot
.68138 .45261 Mdot
.3428 .44505 Mdot
.72607 .45415 Mdot
.58113 .3517 Mdot
.35002 .41022 Mdot
.70487 .47698 Mdot
.67879 .46292 Mdot
.68401 .50127 Mdot
.29024 .53872 Mdot
.28586 .41577 Mdot
.63878 .44772 Mdot
.62225 .46988 Mdot
.54952 .64858 Mdot
.49092 .60373 Mdot
.70572 .73601 Mdot
.69463 .73457 Mdot
.32327 .5137 Mdot
.36554 .37837 Mdot
.44853 .11881 Mdot
.56176 .38226 Mdot
.40852 .20044 Mdot
.47942 .59975 Mdot
.49171 .10441 Mdot
.5226 .58723 Mdot
.51448 .62545 Mdot
.70535 .47444 Mdot
.28857 .52647 Mdot
.31926 .53832 Mdot
.64799 .45344 Mdot
.6272 .45386 Mdot
.31792 .52504 Mdot
.24843 .33584 Mdot
.3249 .78111 Mdot
.45658 .34677 Mdot
.65078 .48772 Mdot
.59353 .75516 Mdot
.56634 .32198 Mdot
.49094 .71623 Mdot
.55611 .30525 Mdot
.37986 .40333 Mdot
.3925 .43613 Mdot
.52875 .32562 Mdot
.53797 .65736 Mdot
.36299 .38882 Mdot
.5214 .68732 Mdot
.36872 .25591 Mdot
.68403 .67532 Mdot
.32329 .35759 Mdot
.48571 .72403 Mdot
.58615 .49006 Mdot
.5704 .27207 Mdot
.49512 .6713 Mdot
.26891 .71416 Mdot
.32967 .53893 Mdot
.4736 .57551 Mdot
.52347 .33565 Mdot
.7465 .72171 Mdot
.49028 .62999 Mdot
.64535 .47656 Mdot
.53991 .36178 Mdot
.73502 .3363 Mdot
.71783 .35191 Mdot
.50072 .60506 Mdot
.65871 .19937 Mdot
.61016 .48343 Mdot
.36832 .4029 Mdot
.76831 .43666 Mdot
.65984 .44155 Mdot
.36737 .52561 Mdot
.29137 .70455 Mdot
.17181 .51181 Mdot
.67727 .48252 Mdot
.42802 .42157 Mdot
.69118 .48386 Mdot
.31827 .55825 Mdot
.68538 .43508 Mdot
.38014 .39072 Mdot
.50363 .66432 Mdot
.40949 .40073 Mdot
.29112 .53339 Mdot
.8022 .55656 Mdot
.58211 .33818 Mdot
.35228 .37582 Mdot
.54626 .33091 Mdot
.28115 .63233 Mdot
.34905 .71282 Mdot
.55964 .33103 Mdot
.63883 .59763 Mdot
.56227 .58837 Mdot
.64792 .44159 Mdot
.41361 .38518 Mdot
.24495 .53674 Mdot
.52822 .3986 Mdot
.66418 .47547 Mdot
.3564 .39065 Mdot
.73863 .38546 Mdot
.61346 .54126 Mdot
.56678 .59083 Mdot
.38725 .57468 Mdot
.65235 .48353 Mdot
.42691 .42054 Mdot
.84088 .51821 Mdot
.69187 .48092 Mdot
.39152 .36133 Mdot
.57051 .33212 Mdot
.55732 .3698 Mdot
.56212 .62995 Mdot
.51126 .30934 Mdot
.36147 .40768 Mdot
.58911 .31833 Mdot
.64005 .51412 Mdot
.75397 .36585 Mdot
.28325 .55076 Mdot
.39559 .40756 Mdot
.52038 .69286 Mdot
.61667 .46777 Mdot
.48595 .23562 Mdot
.644 .67202 Mdot
.7688 .30754 Mdot
.41147 .39293 Mdot
.67119 .47938 Mdot
.64427 .48166 Mdot
.50507 .56611 Mdot
.74791 .41818 Mdot
.28546 .37749 Mdot
.59947 .5456 Mdot
.5767 .42912 Mdot
.42095 .38141 Mdot
.39668 .45315 Mdot
.55819 .68569 Mdot
.53636 .65105 Mdot
.58041 .34582 Mdot
.50616 .66346 Mdot
.66297 .51773 Mdot
.55565 .6102 Mdot
.55666 .33555 Mdot
.3753 .41315 Mdot
.49363 .62626 Mdot
.33485 .53892 Mdot
.53858 .30904 Mdot
.55998 .38579 Mdot
.39735 .41146 Mdot
.66171 .44827 Mdot
.55171 .50064 Mdot
.40726 .3844 Mdot
.54269 .64806 Mdot
.4453 .49659 Mdot
.48213 .61975 Mdot
.55847 .52703 Mdot
.6926 .47526 Mdot
.38918 .4303 Mdot
.70972 .44676 Mdot
.548 .33981 Mdot
.26419 .66218 Mdot
.51103 .64936 Mdot
.40249 .36589 Mdot
.52569 .25728 Mdot
.53463 .51563 Mdot
.63319 .52259 Mdot
.31215 .31232 Mdot
.65365 .43838 Mdot
.37101 .3748 Mdot
.34681 .22404 Mdot
.2944 .55048 Mdot
.36771 .43094 Mdot
.43074 .80231 Mdot
.39868 .42032 Mdot
.55988 .62368 Mdot
.53976 .59454 Mdot
.37971 .42563 Mdot
.33754 .5271 Mdot
.80592 .63343 Mdot
.43273 .43384 Mdot
.6768 .47986 Mdot
.31364 .27689 Mdot
.81477 .38912 Mdot
.6022 .32054 Mdot
.58015 .35117 Mdot
.46068 .66615 Mdot
.55373 .58447 Mdot
.52451 .34532 Mdot
.58191 .33235 Mdot
.31484 .56411 Mdot
.39642 .36623 Mdot
.61323 .48933 Mdot
.56671 .39139 Mdot
.73788 .47775 Mdot
.30907 .44113 Mdot
.51551 .56445 Mdot
.558 .20611 Mdot
.48045 .60009 Mdot
.31989 .69241 Mdot
.55473 .33175 Mdot
.47999 .66355 Mdot
.56179 .57534 Mdot
.5377 .3652 Mdot
.30926 .5253 Mdot
.38228 .46171 Mdot
.39462 .3975 Mdot
.44165 .85993 Mdot
.5348 .67983 Mdot
.55542 .61741 Mdot
.53165 .33833 Mdot
.23921 .46409 Mdot
.66091 .48902 Mdot
.67616 .44077 Mdot
.3683 .4126 Mdot
.48511 .39353 Mdot
.56203 .60452 Mdot
.4984 .66936 Mdot
.39441 .39057 Mdot
.35252 .38127 Mdot
.38366 .30413 Mdot
.54251 .61558 Mdot
.5401 .34936 Mdot
.26178 .57969 Mdot
.54935 .32579 Mdot
.48041 .63193 Mdot
.55323 .61814 Mdot
.51295 .57729 Mdot
.50055 .68731 Mdot
.52996 .29751 Mdot
.47786 .62606 Mdot
.57626 .59321 Mdot
.66901 .47823 Mdot
.49977 .60056 Mdot
.57165 .42133 Mdot
.51316 .6618 Mdot
.31373 .5255 Mdot
.77393 .51605 Mdot
.4909 .62886 Mdot
.55432 .60348 Mdot
.37237 .44278 Mdot
.50161 .64452 Mdot
.57864 .37502 Mdot
.65133 .49924 Mdot
.53361 .34614 Mdot
.5767 .37206 Mdot
.4324 .40551 Mdot
.34696 .53968 Mdot
.46153 .63132 Mdot
.30854 .51711 Mdot
.46614 .59375 Mdot
.51861 .68392 Mdot
.33034 .47833 Mdot
.53973 .15033 Mdot
.81321 .51925 Mdot
.51207 .6511 Mdot
.40494 .42019 Mdot
.41428 .41315 Mdot
.58407 .52774 Mdot
.56929 .62042 Mdot
.52201 .35382 Mdot
.58154 .35578 Mdot
.56443 .77742 Mdot
.44023 .72652 Mdot
.31293 .52524 Mdot
.48869 .47696 Mdot
.54754 .66567 Mdot
.48121 .66522 Mdot
.53857 .68044 Mdot
.41918 .42086 Mdot
.55465 .73588 Mdot
.35355 .41299 Mdot
.61081 .3003 Mdot
.53418 .32639 Mdot
.49536 .61549 Mdot
.53601 .20273 Mdot
.63052 .47797 Mdot
.65074 .49963 Mdot
.55184 .38439 Mdot
.36762 .3498 Mdot
.76088 .6715 Mdot
.17282 .59866 Mdot
.64424 .425 Mdot
.28761 .53225 Mdot
.50507 .67657 Mdot
.38354 .42132 Mdot
.64813 .51218 Mdot
.28885 .53073 Mdot
.48327 .63811 Mdot
.28679 .41685 Mdot
.51803 .65575 Mdot
.62522 .26012 Mdot
.68036 .49875 Mdot
.28618 .7654 Mdot
.66767 .51977 Mdot
.52384 .30973 Mdot
.52122 .33145 Mdot
.54579 .61157 Mdot
.60644 .45623 Mdot
.65858 .44034 Mdot
.37587 .49528 Mdot
.34001 .55118 Mdot
.61382 .336 Mdot
.29669 .54843 Mdot
.37017 .39293 Mdot
.29502 .53426 Mdot
.38093 .38854 Mdot
.77125 .65542 Mdot
.6717 .54707 Mdot
.31344 .5459 Mdot
.53507 .25642 Mdot
.55089 .58324 Mdot
.31894 .51163 Mdot
.56929 .65731 Mdot
.58102 .54406 Mdot
.39735 .39011 Mdot
.33345 .55522 Mdot
.48336 .66561 Mdot
.52226 .81095 Mdot
.56604 .33599 Mdot
.51981 .34641 Mdot
.56838 .65832 Mdot
.4247 .39256 Mdot
.70228 .46735 Mdot
.22691 .66343 Mdot
.5688 .39557 Mdot
.54487 .59916 Mdot
.53187 .57694 Mdot
.64974 .43918 Mdot
.46797 .1867 Mdot
.54901 .61984 Mdot
.51852 .53328 Mdot
.54286 .61165 Mdot
.54134 .31577 Mdot
.68963 .45811 Mdot
.64574 .49043 Mdot
.35752 .39014 Mdot
.62758 .48671 Mdot
.42873 .54037 Mdot
.5803 .24249 Mdot
.58608 .64093 Mdot
.55194 .3439 Mdot
.6298 .33505 Mdot
.59483 .27368 Mdot
.43134 .78856 Mdot
.64267 .52603 Mdot
.47493 .63515 Mdot
.62592 .48777 Mdot
.2971 .5416 Mdot
.64426 .50135 Mdot
.6771 .51382 Mdot
.48991 .64971 Mdot
.50525 .60538 Mdot
.37172 .40878 Mdot
.74434 .41323 Mdot
.65574 .44531 Mdot
.523 .58805 Mdot
.52044 .57094 Mdot
.52125 .68969 Mdot
.38899 .51087 Mdot
.68577 .45577 Mdot
.22744 .3301 Mdot
.40423 .61239 Mdot
.65781 .44587 Mdot
.84911 .58569 Mdot
.51286 .2495 Mdot
.33184 .39539 Mdot
.3758 .47561 Mdot
.54108 .60849 Mdot
.36644 .36473 Mdot
.50164 .6109 Mdot
.56081 .20864 Mdot
.50031 .63735 Mdot
.31551 .52361 Mdot
.52714 .6838 Mdot
.38385 .4353 Mdot
.40907 .39208 Mdot
.5478 .60089 Mdot
.49627 .62379 Mdot
.80744 .57072 Mdot
.69402 .43934 Mdot
.6564 .50609 Mdot
.3319 .34426 Mdot
.31704 .5506 Mdot
.52488 .32989 Mdot
.52111 .63559 Mdot
.43067 .40916 Mdot
.40958 .3943 Mdot
.67501 .4466 Mdot
.38861 .37538 Mdot
.56275 .34996 Mdot
.51219 .64535 Mdot
.52265 .34458 Mdot
.29109 .54902 Mdot
.68856 .45888 Mdot
.50031 .60207 Mdot
.54941 .64904 Mdot
.66546 .50387 Mdot
.47483 .65938 Mdot
.33759 .53142 Mdot
.40187 .41644 Mdot
.67829 .4831 Mdot
.55726 .36284 Mdot
.37238 .391 Mdot
.48539 .60196 Mdot
.62819 .18984 Mdot
.55956 .63657 Mdot
.53495 .60048 Mdot
.46512 .82601 Mdot
.54166 .67025 Mdot
.41275 .38823 Mdot
.64471 .5107 Mdot
.46084 .58222 Mdot
.378 .6395 Mdot
.41164 .8738 Mdot
.35655 .41543 Mdot
.51022 .67525 Mdot
.46192 .79695 Mdot
.50952 .67209 Mdot
.62575 .71109 Mdot
.34491 .3828 Mdot
.56114 .45352 Mdot
.50789 .69316 Mdot
.56974 .36521 Mdot
.37685 .42069 Mdot
.3835 .38505 Mdot
.34687 .2567 Mdot
.49101 .65931 Mdot
.43122 .4821 Mdot
.48397 .62804 Mdot
.56011 .36444 Mdot
.45764 .72912 Mdot
.41025 .38939 Mdot
.79778 .38067 Mdot
.53787 .62016 Mdot
.67982 .45927 Mdot
.37845 .44195 Mdot
.55147 .3974 Mdot
.49582 .59516 Mdot
.32666 .51936 Mdot
.58912 .36105 Mdot
.58152 .64767 Mdot
.55476 .34641 Mdot
.49012 .60016 Mdot
.44104 .65924 Mdot
.73294 .30551 Mdot
.67652 .50798 Mdot
.57592 .33947 Mdot
.42891 .50694 Mdot
.47631 .63642 Mdot
.67662 .48395 Mdot
.66445 .47843 Mdot
.28925 .54429 Mdot
.53958 .4752 Mdot
.69362 .31216 Mdot
.65664 .72195 Mdot
.32731 .26665 Mdot
.36548 .43421 Mdot
.44663 .31778 Mdot
.52869 .60279 Mdot
.40365 .55656 Mdot
.58019 .37078 Mdot
.55933 .64108 Mdot
.75632 .55979 Mdot
.63478 .46352 Mdot
.5566 .64216 Mdot
.31924 .53387 Mdot
.34976 .57633 Mdot
.26903 .58553 Mdot
.33996 .74442 Mdot
.37725 .4082 Mdot
.57221 .57455 Mdot
.4547 .58465 Mdot
.42024 .38568 Mdot
.49928 .57819 Mdot
.41551 .38329 Mdot
.21727 .3793 Mdot
.30847 .51178 Mdot
.68563 .46205 Mdot
.5948 .29512 Mdot
.47456 .60003 Mdot
.55728 .59371 Mdot
.34748 .54498 Mdot
.53717 .64723 Mdot
.6787 .24993 Mdot
.38732 .51554 Mdot
.36783 .38756 Mdot
.68205 .50325 Mdot
.51278 .57362 Mdot
.47715 .49705 Mdot
.51588 .6689 Mdot
.71206 .68995 Mdot
.55327 .60145 Mdot
.72321 .35164 Mdot
.67682 .50443 Mdot
.55274 .33817 Mdot
.48138 .67235 Mdot
.50574 .6314 Mdot
.40617 .70174 Mdot
.46381 .60236 Mdot
.47776 .65648 Mdot
.68498 .51862 Mdot
.6782 .50968 Mdot
.68834 .48567 Mdot
.35905 .41387 Mdot
.51273 .7817 Mdot
.54353 .34589 Mdot
.44469 .62311 Mdot
.54134 .38363 Mdot
.62077 .66337 Mdot
.29413 .52321 Mdot
.3867 .74913 Mdot
.52328 .62031 Mdot
.63669 .48405 Mdot
.22416 .62778 Mdot
.68667 .4411 Mdot
.48268 .46885 Mdot
.5445 .36608 Mdot
.65071 .45138 Mdot
.511 .62616 Mdot
.71266 .42368 Mdot
.48829 .81358 Mdot
.54035 .33725 Mdot
.47813 .58359 Mdot
.3799 .43685 Mdot
.30803 .39066 Mdot
.75902 .32526 Mdot
.5636 .33201 Mdot
.5915 .39735 Mdot
.49206 .66384 Mdot
.62995 .4875 Mdot
.56692 .36436 Mdot
.5424 .31704 Mdot
.3836 .37559 Mdot
.50728 .60305 Mdot
.51112 .60107 Mdot
.36306 .37855 Mdot
.53307 .34346 Mdot
.57583 .60945 Mdot
.58591 .62429 Mdot
.66339 .80133 Mdot
.74116 .37083 Mdot
.45511 .87113 Mdot
.57159 .51739 Mdot
.73625 .55214 Mdot
.22751 .67164 Mdot
.66883 .44942 Mdot
.49299 .6748 Mdot
.53924 .70565 Mdot
.36139 .4082 Mdot
.50285 .65351 Mdot
.34415 .36896 Mdot
.55547 .37703 Mdot
.7417 .72444 Mdot
.66616 .36305 Mdot
.18755 .44578 Mdot
.50095 .65312 Mdot
.64834 .53566 Mdot
.30073 .5394 Mdot
.6127 .36939 Mdot
.69219 .46483 Mdot
.53498 .6903 Mdot
.80626 .56764 Mdot
.36393 .42686 Mdot
.66757 .46259 Mdot
.8202 .59959 Mdot
.59 .48148 Mdot
.48246 .62054 Mdot
.35156 .4033 Mdot
.25503 .70521 Mdot
.73914 .49616 Mdot
.51993 .35725 Mdot
.30831 .525 Mdot
.38606 .42808 Mdot
.58198 .34718 Mdot
.63163 .53731 Mdot
.66043 .45808 Mdot
.6982 .46203 Mdot
.8015 .52137 Mdot
.34794 .42133 Mdot
.30224 .54133 Mdot
.44785 .75536 Mdot
.42425 .71258 Mdot
.32062 .5252 Mdot
.393 .43635 Mdot
.6678 .51516 Mdot
.64155 .45864 Mdot
.65136 .49853 Mdot
.80767 .46821 Mdot
.62571 .50087 Mdot
.36198 .23181 Mdot
.51206 .68962 Mdot
.58046 .5697 Mdot
.50699 .67441 Mdot
.52515 .35834 Mdot
.67006 .50025 Mdot
.50628 .39457 Mdot
.48078 .57471 Mdot
.38191 .73258 Mdot
.56128 .62577 Mdot
.54291 .30523 Mdot
.55472 .63665 Mdot
.55005 .18702 Mdot
.62675 .47529 Mdot
.50837 .65174 Mdot
.55441 .30648 Mdot
.32101 .55251 Mdot
.63582 .52526 Mdot
.49861 .60656 Mdot
.28849 .33306 Mdot
.53295 .67678 Mdot
.20072 .42513 Mdot
.70141 .29459 Mdot
.28886 .53002 Mdot
.61153 .22704 Mdot
.43193 .41987 Mdot
.55479 .54227 Mdot
.45111 .65556 Mdot
.54433 .33404 Mdot
.61343 .33997 Mdot
.38608 .41099 Mdot
.57861 .72145 Mdot
.58038 .60439 Mdot
.28902 .54768 Mdot
.65286 .55123 Mdot
.52842 .3535 Mdot
.50728 .57381 Mdot
.55503 .57027 Mdot
.43873 .21152 Mdot
.57865 .63399 Mdot
.54254 .58271 Mdot
.35208 .5331 Mdot
.38852 .21349 Mdot
.51958 .66176 Mdot
.48765 .47204 Mdot
.68811 .43694 Mdot
.48249 .56968 Mdot
.36854 .22376 Mdot
.53762 .59203 Mdot
.66405 .45441 Mdot
.53656 .53066 Mdot
.67113 .29579 Mdot
.34714 .53732 Mdot
.55376 .60146 Mdot
.4479 .17572 Mdot
.54097 .63163 Mdot
.54359 .3517 Mdot
.56873 .6171 Mdot
.37975 .39339 Mdot
.82079 .51079 Mdot
.35886 .39434 Mdot
.56437 .63093 Mdot
.65153 .49471 Mdot
.53283 .33213 Mdot
.78985 .45594 Mdot
.26841 .42004 Mdot
.43093 .19964 Mdot
.17925 .58792 Mdot
.34119 .54737 Mdot
.27529 .54029 Mdot
.54606 .3761 Mdot
.50948 .65341 Mdot
.30162 .25236 Mdot
.45717 .6212 Mdot
.54479 .65707 Mdot
.50022 .63593 Mdot
.34305 .70786 Mdot
.57014 .37686 Mdot
.4026 .3896 Mdot
.55107 .61974 Mdot
.47728 .63659 Mdot
.67356 .4541 Mdot
.32558 .5472 Mdot
.42007 .39154 Mdot
.32482 .54066 Mdot
.38088 .42274 Mdot
.79396 .66305 Mdot
.57228 .58969 Mdot
.32023 .55473 Mdot
.58007 .38336 Mdot
.66897 .45452 Mdot
.59463 .25921 Mdot
.37691 .3865 Mdot
.3572 .40571 Mdot
.5495 .59908 Mdot
.65856 .4499 Mdot
.71019 .46056 Mdot
.30114 .55267 Mdot
.56246 .33796 Mdot
.49054 .63024 Mdot
.52528 .67871 Mdot
.43353 .6277 Mdot
.42801 .39595 Mdot
.61558 .2504 Mdot
.40578 .32242 Mdot
.51224 .65315 Mdot
.6404 .51371 Mdot
.4963 .62942 Mdot
.2013 .50635 Mdot
.62898 .48411 Mdot
.5331 .58906 Mdot
.86378 .53835 Mdot
.32614 .38549 Mdot
.65237 .31044 Mdot
.5296 .5782 Mdot
.22301 .69596 Mdot
.52669 .6102 Mdot
.75214 .72038 Mdot
.22755 .55531 Mdot
.56536 .60404 Mdot
.4969 .59299 Mdot
.67177 .66413 Mdot
.51564 .67877 Mdot
.35741 .3843 Mdot
.6938 .75375 Mdot
.69356 .44702 Mdot
.58768 .27054 Mdot
.76859 .52696 Mdot
.34521 .53155 Mdot
.36845 .41281 Mdot
.36366 .44514 Mdot
.32599 .53078 Mdot
.64966 .48484 Mdot
.52171 .65313 Mdot
.47804 .43073 Mdot
.4258 .40188 Mdot
.58241 .69358 Mdot
.54337 .35449 Mdot
.44005 .26116 Mdot
.3812 .56505 Mdot
.55775 .34892 Mdot
.50183 .59845 Mdot
.66015 .66164 Mdot
.76835 .64639 Mdot
.36909 .80134 Mdot
.57891 .33448 Mdot
.53919 .33507 Mdot
.81943 .4839 Mdot
.30224 .56621 Mdot
.43829 .21488 Mdot
.72187 .35422 Mdot
.52839 .3301 Mdot
.61502 .5294 Mdot
.35825 .37847 Mdot
.48567 .33897 Mdot
.51132 .55027 Mdot
.51083 .68608 Mdot
.50964 .6281 Mdot
.55559 .32861 Mdot
.54753 .51641 Mdot
.77052 .38571 Mdot
.5448 .32852 Mdot
.49103 .70604 Mdot
.53583 .44634 Mdot
.50031 .28899 Mdot
.3968 .37365 Mdot
.33854 .55444 Mdot
.28981 .56369 Mdot
.68026 .46749 Mdot
.34314 .54906 Mdot
.34143 .58291 Mdot
.53092 .64527 Mdot
.54101 .32284 Mdot
.53111 .23953 Mdot
.55415 .36662 Mdot
.32453 .53528 Mdot
.31169 .56518 Mdot
.66829 .479 Mdot
.65332 .50742 Mdot
.6955 .59182 Mdot
.37179 .5902 Mdot
.53535 .66512 Mdot
.25774 .52225 Mdot
.68757 .5035 Mdot
.6011 .60811 Mdot
.34105 .55265 Mdot
.32017 .5509 Mdot
.39771 .70336 Mdot
.52056 .62019 Mdot
.60842 .63281 Mdot
.52076 .62657 Mdot
.4188 .62522 Mdot
.49414 .59006 Mdot
.38454 .37538 Mdot
.51937 .60951 Mdot
.39964 .7132 Mdot
.46721 .64376 Mdot
.54858 .57606 Mdot
.42526 .41571 Mdot
.58379 .60473 Mdot
.38121 .39429 Mdot
.55888 .64971 Mdot
.28397 .52715 Mdot
.36698 .41355 Mdot
.365 .64805 Mdot
.37984 .69451 Mdot
.4015 .43464 Mdot
.29903 .52279 Mdot
.33523 .51544 Mdot
.33209 .65698 Mdot
.69236 .46358 Mdot
.46708 .68651 Mdot
.507 .65461 Mdot
.34629 .40242 Mdot
.5787 .36378 Mdot
.4869 .59774 Mdot
.54422 .58057 Mdot
.51989 .58063 Mdot
.68094 .46541 Mdot
.28097 .38412 Mdot
.32084 .55658 Mdot
.36043 .37938 Mdot
.54218 .49924 Mdot
.42171 .38165 Mdot
.54113 .56329 Mdot
.52783 .70703 Mdot
.76175 .5434 Mdot
.51862 .27605 Mdot
.81216 .45322 Mdot
.6617 .45956 Mdot
.41633 .41208 Mdot
.2815 .54868 Mdot
.50212 .7028 Mdot
.63557 .48529 Mdot
.3805 .39109 Mdot
.51761 .65508 Mdot
.48246 .58236 Mdot
.56586 .23764 Mdot
.27737 .59537 Mdot
.37372 .67588 Mdot
.36538 .42215 Mdot
.40255 .43912 Mdot
.36997 .70414 Mdot
.26358 .56057 Mdot
.5179 .39396 Mdot
.49681 .6623 Mdot
.32783 .52087 Mdot
.6432 .50814 Mdot
.78815 .54463 Mdot
.5268 .31925 Mdot
.74699 .42028 Mdot
.50198 .65144 Mdot
.57897 .47356 Mdot
.65303 .49424 Mdot
.31921 .53111 Mdot
.55228 .3252 Mdot
.30947 .57594 Mdot
.41905 .41652 Mdot
.16416 .50899 Mdot
.542 .639 Mdot
.5514 .60202 Mdot
.55594 .31261 Mdot
.63338 .47548 Mdot
.33494 .51054 Mdot
.31139 .28429 Mdot
.38575 .38049 Mdot
.31301 .24159 Mdot
.63721 .50983 Mdot
.59342 .7525 Mdot
.38259 .36926 Mdot
.55639 .38933 Mdot
.34194 .64982 Mdot
.56004 .34438 Mdot
.56356 .61996 Mdot
.64061 .48003 Mdot
.57784 .34562 Mdot
.75368 .40244 Mdot
.50445 .83261 Mdot
.6003 .75147 Mdot
.52589 .64413 Mdot
.5808 .81566 Mdot
.2347 .37405 Mdot
.6413 .42415 Mdot
.5823 .36069 Mdot
.56059 .63718 Mdot
.55579 .59861 Mdot
.54252 .63271 Mdot
.57464 .36732 Mdot
.26544 .51481 Mdot
.3963 .38756 Mdot
.49787 .67148 Mdot
.31139 .56374 Mdot
.38205 .40141 Mdot
.53841 .38617 Mdot
.40308 .37729 Mdot
.67127 .52222 Mdot
.52462 .56123 Mdot
.61135 .39975 Mdot
.89717 .48401 Mdot
.53585 .33988 Mdot
.43214 .40955 Mdot
.57286 .62587 Mdot
.47726 .25984 Mdot
.69661 .48295 Mdot
.38272 .37937 Mdot
.55651 .61762 Mdot
.54427 .25718 Mdot
.80715 .54389 Mdot
.40779 .38168 Mdot
.63503 .48753 Mdot
.375 .80007 Mdot
.50348 .65992 Mdot
.53054 .62122 Mdot
.65349 .4543 Mdot
.61841 .57277 Mdot
.83326 .54094 Mdot
.49658 .62549 Mdot
.55265 .33614 Mdot
.16053 .443 Mdot
.54542 .58105 Mdot
.4212 .66413 Mdot
.37285 .41466 Mdot
.49836 .36864 Mdot
.6524 .27451 Mdot
.4735 .66733 Mdot
.38698 .24824 Mdot
.59445 .29983 Mdot
.49984 .79017 Mdot
.34264 .36757 Mdot
.24945 .39711 Mdot
.56552 .80298 Mdot
.53592 .29969 Mdot
.68451 .52643 Mdot
.35325 .26348 Mdot
.74863 .50212 Mdot
.3002 .74639 Mdot
.22906 .48527 Mdot
.80784 .56572 Mdot
.49198 .42649 Mdot
.39652 .4246 Mdot
.5985 .56303 Mdot
.49984 .61012 Mdot
.23126 .38049 Mdot
.73584 .31972 Mdot
.75165 .34511 Mdot
.58171 .81654 Mdot
.62087 .72344 Mdot
.46793 .80027 Mdot
.44127 .80101 Mdot
.43918 .68822 Mdot
.43498 .32661 Mdot
.29963 .24816 Mdot
.75798 .68598 Mdot
.26403 .31213 Mdot
.58301 .57418 Mdot
.47024 .46838 Mdot
.18728 .49131 Mdot
.67956 .54032 Mdot
.61702 .54481 Mdot
.36194 .38458 Mdot
.69469 .46419 Mdot
.41967 .22514 Mdot
.64481 .43894 Mdot
.66853 .29187 Mdot
.40187 .81788 Mdot
.49512 .82871 Mdot
.46756 .17974 Mdot
.229 .69455 Mdot
.74885 .55978 Mdot
.26757 .23898 Mdot
.36715 .35731 Mdot
.67179 .44603 Mdot
.32982 .69296 Mdot
.42001 .73228 Mdot
.64299 .37635 Mdot
.30971 .30285 Mdot
.30284 .41906 Mdot
.29241 .62109 Mdot
.64569 .47939 Mdot
.62389 .2397 Mdot
.49314 .33716 Mdot
.66019 .3669 Mdot
.72788 .71741 Mdot
.37107 .78198 Mdot
.46661 .4374 Mdot
.34541 .2887 Mdot
.44474 .28025 Mdot
.78098 .39385 Mdot
.38851 .617 Mdot
.59296 .53853 Mdot
.73343 .35911 Mdot
.2086 .62862 Mdot
.67615 .56719 Mdot
.4212 .6147 Mdot
.42996 .73665 Mdot
.81059 .63612 Mdot
.21326 .43435 Mdot
.84042 .39432 Mdot
.64387 .43749 Mdot
.52836 .57536 Mdot
.63099 .60282 Mdot
.40992 .18202 Mdot
.35552 .54437 Mdot
.32642 .73754 Mdot
.3222 .56067 Mdot
.68165 .51464 Mdot
.82314 .53213 Mdot
.38003 .21634 Mdot
.35024 .20553 Mdot
.279 .53365 Mdot
.44384 .62365 Mdot
.22722 .74666 Mdot
.44695 .77177 Mdot
.6549 .33676 Mdot
.67096 .79428 Mdot
.54772 .43526 Mdot
.74866 .35681 Mdot
.5789 .34725 Mdot
.6017 .80103 Mdot
.64269 .46248 Mdot
.84376 .37143 Mdot
.76666 .70497 Mdot
.77349 .55867 Mdot
.7786 .77468 Mdot
.35668 .70622 Mdot
.56602 .45642 Mdot
.59888 .33311 Mdot
.35034 .61804 Mdot
.77196 .42794 Mdot
.26261 .64643 Mdot
.46751 .26549 Mdot
.21625 .69438 Mdot
.55288 .80846 Mdot
.32826 .22219 Mdot
.1765 .44377 Mdot
.69578 .54842 Mdot
.48558 .49426 Mdot
.48154 .71746 Mdot
.31639 .37547 Mdot
.31191 .73487 Mdot
.82574 .6221 Mdot
.40389 .61586 Mdot
.40475 .87142 Mdot
.28669 .51037 Mdot
.29464 .44382 Mdot
.44762 .84867 Mdot
.30492 .63014 Mdot
.65789 .26436 Mdot
.49456 .76728 Mdot
.52429 .73534 Mdot
.48581 .50786 Mdot
.32607 .74322 Mdot
.62144 .27748 Mdot
.66145 .77817 Mdot
.25422 .72057 Mdot
.44436 .21103 Mdot
.68511 .68604 Mdot
.42523 .69795 Mdot
.61681 .5066 Mdot
.33466 .59309 Mdot
.6619 .27739 Mdot
.52909 .83623 Mdot
.5219 .30263 Mdot
.56416 .8397 Mdot
.83032 .54855 Mdot
.57339 .58975 Mdot
.47477 .69192 Mdot
.59631 .51754 Mdot
.31865 .59834 Mdot
.57707 .57469 Mdot
.53352 .21922 Mdot
.48542 .83007 Mdot
.74452 .66693 Mdot
.56749 .26781 Mdot
.60827 .32125 Mdot
.44758 .85477 Mdot
.655 .62296 Mdot
.2648 .55097 Mdot
.66391 .76433 Mdot
.77543 .42689 Mdot
.39016 .40616 Mdot
.33906 .22055 Mdot
.59099 .38867 Mdot
.79812 .54718 Mdot
.65284 .7225 Mdot
.7423 .52961 Mdot
.48617 .83102 Mdot
.27215 .37424 Mdot
.81998 .54843 Mdot
.28481 .6452 Mdot
.27819 .28373 Mdot
.50699 .2849 Mdot
.56015 .68936 Mdot
.30217 .31168 Mdot
.33434 .51765 Mdot
.69689 .62394 Mdot
.18343 .38291 Mdot
.25401 .47738 Mdot
.56107 .67677 Mdot
.77693 .55397 Mdot
.3447 .43511 Mdot
.70922 .42016 Mdot
.79054 .32368 Mdot
.53568 .56942 Mdot
.44836 .74962 Mdot
.25749 .37211 Mdot
.35532 .60496 Mdot
.31295 .7764 Mdot
.1996 .55076 Mdot
.85958 .41758 Mdot
.62614 .80583 Mdot
.26387 .41449 Mdot
.5449 .79837 Mdot
.54972 .82066 Mdot
.85707 .42614 Mdot
.45481 .65046 Mdot
.51856 .31219 Mdot
.59013 .1595 Mdot
.39713 .37249 Mdot
.42917 .74798 Mdot
.32749 .26641 Mdot
.37301 .56296 Mdot
.61022 .41296 Mdot
.57776 .71672 Mdot
.48975 .43477 Mdot
.69577 .43892 Mdot
.57778 .57884 Mdot
.82065 .41271 Mdot
.87351 .47189 Mdot
.83413 .40812 Mdot
.18559 .57162 Mdot
.60613 .79664 Mdot
.56697 .47935 Mdot
.43768 .18422 Mdot
.59959 .62941 Mdot
.48614 .67078 Mdot
.35829 .56046 Mdot
.35069 .70388 Mdot
.78596 .52927 Mdot
.68966 .37058 Mdot
.66567 .5499 Mdot
.32448 .73815 Mdot
.09617 .50395 Mdot
.71563 .58668 Mdot
.33799 .24434 Mdot
.27671 .56353 Mdot
.36302 .59349 Mdot
.27314 .70011 Mdot
.78012 .50977 Mdot
.4535 .81572 Mdot
.69714 .44061 Mdot
.28744 .30021 Mdot
.24452 .50274 Mdot
.7035 .51188 Mdot
.28038 .38807 Mdot
.43939 .77867 Mdot
.61432 .3212 Mdot
.78096 .48733 Mdot
.71506 .3614 Mdot
.63954 .59326 Mdot
.37445 .50599 Mdot
.42501 .2765 Mdot
.2272 .32881 Mdot
.21104 .49446 Mdot
.42169 .65845 Mdot
.52708 .44611 Mdot
.5909 .21245 Mdot
.56738 .27867 Mdot
.41577 .62168 Mdot
.56576 .41924 Mdot
.47664 .76289 Mdot
.83587 .30246 Mdot
.80161 .36884 Mdot
.39835 .82568 Mdot
.23891 .60631 Mdot
.5759 .65797 Mdot
.44116 .81815 Mdot
.82544 .36087 Mdot
.86544 .56656 Mdot
.39992 .28335 Mdot
.36593 .355 Mdot
.55021 .38821 Mdot
.82773 .45295 Mdot
.30647 .48642 Mdot
.41162 .79671 Mdot
.41038 .65507 Mdot
.5699 .38511 Mdot
.50026 .13697 Mdot
.79593 .65057 Mdot
.63229 .74053 Mdot
.28754 .5949 Mdot
.52763 .70184 Mdot
.63625 .22929 Mdot
.66164 .43937 Mdot
.46393 .30675 Mdot
.37909 .59056 Mdot
.40021 .40549 Mdot
.30708 .69821 Mdot
.28795 .31468 Mdot
.52662 .68422 Mdot
.45006 .50054 Mdot
.62448 .50899 Mdot
.50757 .27964 Mdot
.62527 .31692 Mdot
.8733 .53804 Mdot
.30639 .57823 Mdot
.51578 .69426 Mdot
.36503 .60755 Mdot
.29432 .37372 Mdot
.84132 .51766 Mdot
.555 .38123 Mdot
.52893 .80983 Mdot
.45986 .45511 Mdot
.35668 .58914 Mdot
.75306 .47621 Mdot
.59274 .57416 Mdot
.55763 .58227 Mdot
.20647 .60172 Mdot
.74652 .65514 Mdot
.73206 .45525 Mdot
.49039 .55854 Mdot
.59047 .67566 Mdot
.43469 .81617 Mdot
.34344 .5799 Mdot
.44139 .26773 Mdot
.51752 .81554 Mdot
.56316 .37405 Mdot
.62616 .49075 Mdot
.26977 .51811 Mdot
.25262 .32405 Mdot
.58791 .76799 Mdot
.80758 .54237 Mdot
.39367 .55103 Mdot
.26354 .46797 Mdot
.51804 .82483 Mdot
.5089 .80085 Mdot
.56299 .17898 Mdot
.61535 .45468 Mdot
.42652 .56903 Mdot
.24244 .32736 Mdot
.69952 .48307 Mdot
.41827 .20756 Mdot
.45899 .20534 Mdot
.7698 .69135 Mdot
.43814 .50109 Mdot
.22303 .70871 Mdot
.3733 .6714 Mdot
.2928 .70823 Mdot
.79159 .44973 Mdot
.26743 .30162 Mdot
.41097 .75054 Mdot
.65157 .42282 Mdot
.66255 .68296 Mdot
.58601 .63524 Mdot
.53221 .19055 Mdot
.59307 .16858 Mdot
.29808 .49901 Mdot
.58208 .43289 Mdot
.26007 .73048 Mdot
.53455 .65312 Mdot
.77767 .31856 Mdot
.28684 .30996 Mdot
.81579 .47764 Mdot
.56265 .38748 Mdot
.48784 .60875 Mdot
.46414 .61492 Mdot
.59215 .78544 Mdot
.66148 .2903 Mdot
.49095 .77077 Mdot
.16655 .43968 Mdot
.26577 .7158 Mdot
.67872 .54817 Mdot
.43035 .74545 Mdot
.37432 .78532 Mdot
.23206 .38378 Mdot
.52784 .46927 Mdot
.26289 .65552 Mdot
.32318 .6345 Mdot
.22072 .66662 Mdot
.58074 .41304 Mdot
.40443 .46113 Mdot
.60418 .29193 Mdot
.33702 .32759 Mdot
.79857 .50063 Mdot
.50623 .59311 Mdot
.81981 .60058 Mdot
.42187 .78925 Mdot
.60786 .20675 Mdot
.74152 .30851 Mdot
.80394 .374 Mdot
.72308 .66966 Mdot
.22199 .42977 Mdot
.25261 .35091 Mdot
.21437 .33124 Mdot
.45206 .45721 Mdot
.3611 .72771 Mdot
.29909 .6371 Mdot
.51791 .82127 Mdot
.55324 .31257 Mdot
.70893 .33854 Mdot
.5809 .27485 Mdot
.52454 .79075 Mdot
.65907 .63383 Mdot
.44685 .79299 Mdot
.53118 .42376 Mdot
.86272 .4162 Mdot
.20899 .53218 Mdot
.50259 .42202 Mdot
.41181 .42206 Mdot
.24138 .41742 Mdot
.36426 .75786 Mdot
.21336 .5391 Mdot
.28807 .28032 Mdot
.32903 .38231 Mdot
.53332 .50531 Mdot
.59474 .73686 Mdot
.33205 .59178 Mdot
.20407 .60214 Mdot
.36398 .60749 Mdot
.48263 .82222 Mdot
.61486 .78909 Mdot
.8199 .59699 Mdot
.36329 .71227 Mdot
.17552 .5759 Mdot
.65447 .33295 Mdot
.29864 .59029 Mdot
.28774 .31155 Mdot
.30274 .46 Mdot
.68192 .42863 Mdot
.53461 .09623 Mdot
.16954 .50315 Mdot
.21436 .47098 Mdot
.82069 .62803 Mdot
.19551 .55796 Mdot
.5144 .27526 Mdot
.629 .56472 Mdot
.74599 .39356 Mdot
.79777 .62045 Mdot
.50122 .63574 Mdot
.81981 .38812 Mdot
.40367 .56899 Mdot
.88758 .4884 Mdot
.41421 .80721 Mdot
.58288 .42725 Mdot
.5283 .56128 Mdot
.35243 .38828 Mdot
.42716 .4784 Mdot
.46411 .73154 Mdot
.63502 .64307 Mdot
.69257 .2859 Mdot
.55197 .27458 Mdot
.37173 .35753 Mdot
.32381 .35091 Mdot
.66893 .42653 Mdot
.2413 .59196 Mdot
.37242 .3208 Mdot
.41639 .35765 Mdot
.45878 .43657 Mdot
.40108 .59833 Mdot
.64434 .26653 Mdot
.62301 .74722 Mdot
.78378 .50926 Mdot
.62636 .38601 Mdot
.37752 .374 Mdot
.65266 .73146 Mdot
.18183 .49937 Mdot
.2548 .70979 Mdot
.8261 .61892 Mdot
.48247 .50623 Mdot
.63853 .67147 Mdot
.43407 .69277 Mdot
.76453 .36059 Mdot
.60227 .4668 Mdot
.53688 .28079 Mdot
.63548 .23152 Mdot
.60374 .52431 Mdot
.37276 .25943 Mdot
.74446 .72217 Mdot
.27077 .30854 Mdot
.24034 .32791 Mdot
.35901 .49094 Mdot
.45175 .57735 Mdot
.68786 .51861 Mdot
.3678 .65633 Mdot
.53775 .40174 Mdot
.34 .1949 Mdot
.47361 .57538 Mdot
.30873 .19144 Mdot
.54653 .3164 Mdot
.72312 .5231 Mdot
.31777 .63858 Mdot
.53652 .45267 Mdot
.54074 .42033 Mdot
.20759 .51021 Mdot
.71763 .33981 Mdot
.22255 .41565 Mdot
.76805 .38763 Mdot
.36193 .35884 Mdot
.15065 .48218 Mdot
.17707 .61245 Mdot
.67438 .68159 Mdot
.55228 .66568 Mdot
.16448 .52979 Mdot
.38829 .35623 Mdot
.78457 .52217 Mdot
.31868 .78013 Mdot
.23292 .64302 Mdot
.59241 .72678 Mdot
.358 .59186 Mdot
.36757 .73149 Mdot
.5997 .82017 Mdot
.59437 .18152 Mdot
.31682 .73272 Mdot
.55482 .31407 Mdot
.53078 .43191 Mdot
.40982 .76705 Mdot
.7297 .32857 Mdot
.50239 .31344 Mdot
.68032 .28081 Mdot
.23791 .25511 Mdot
.43684 .7564 Mdot
.46688 .75284 Mdot
.72495 .31375 Mdot
.66388 .52045 Mdot
.70913 .31823 Mdot
.65493 .26283 Mdot
.22191 .59838 Mdot
.19161 .44729 Mdot
.6559 .26765 Mdot
.22586 .30313 Mdot
.57864 .54011 Mdot
.46644 .36303 Mdot
.60625 .63108 Mdot
.49556 .75065 Mdot
.58504 .37225 Mdot
.75272 .68127 Mdot
.28475 .73696 Mdot
.51173 .322 Mdot
.21332 .61892 Mdot
.33769 .29463 Mdot
.50437 .74431 Mdot
.6067 .76572 Mdot
.25453 .68544 Mdot
.65546 .65282 Mdot
.52951 .17945 Mdot
.78379 .56276 Mdot
.39654 .35573 Mdot
.32306 .76628 Mdot
.37144 .38644 Mdot
.57778 .70217 Mdot
.75053 .42566 Mdot
.26755 .65488 Mdot
.81555 .46116 Mdot
.34243 .52785 Mdot
.6785 .44525 Mdot
.59618 .17391 Mdot
.64744 .51437 Mdot
.82536 .41782 Mdot
.75095 .52359 Mdot
.66629 .25302 Mdot
.25826 .42521 Mdot
.24249 .46129 Mdot
.22466 .27992 Mdot
.49751 .34585 Mdot
.37427 .34457 Mdot
.50298 .19321 Mdot
.66889 .44343 Mdot
.35877 .4926 Mdot
.40459 .43116 Mdot
.45215 .42625 Mdot
.44781 .22036 Mdot
.57361 .53838 Mdot
.61788 .51867 Mdot
.44735 .43816 Mdot
.69458 .73867 Mdot
.68375 .77223 Mdot
.41685 .39153 Mdot
.36414 .16804 Mdot
.54096 .56628 Mdot
.69197 .67406 Mdot
.46303 .82239 Mdot
.49416 .13661 Mdot
.40667 .33668 Mdot
.19075 .65259 Mdot
.48501 .68227 Mdot
.25485 .66417 Mdot
.64616 .46641 Mdot
.27892 .306 Mdot
.30131 .55639 Mdot
.34799 .60681 Mdot
.52194 .31737 Mdot
.78015 .48577 Mdot
.38844 .3311 Mdot
.69999 .46614 Mdot
.23414 .60722 Mdot
.4378 .68425 Mdot
.57456 .31111 Mdot
.26855 .38976 Mdot
.67035 .68982 Mdot
.54668 .76452 Mdot
.64154 .54748 Mdot
.45589 .74582 Mdot
.20817 .36097 Mdot
.87645 .53704 Mdot
.68735 .41639 Mdot
.58922 .48914 Mdot
.50183 .21255 Mdot
.2305 .65467 Mdot
.56214 .21491 Mdot
.48475 .83449 Mdot
.40795 .58895 Mdot
.4859 .53191 Mdot
.41713 .60851 Mdot
.59076 .64745 Mdot
.50579 .45373 Mdot
.44889 .28886 Mdot
.71111 .28781 Mdot
.62384 .25976 Mdot
.65789 .56925 Mdot
.55399 .19795 Mdot
.44 .72149 Mdot
.67004 .25954 Mdot
.4248 .37018 Mdot
.55404 .76163 Mdot
.61072 .36635 Mdot
.68645 .77294 Mdot
.47753 .83009 Mdot
.54149 .38685 Mdot
.31043 .37331 Mdot
.25494 .73738 Mdot
.45627 .63359 Mdot
.54784 .49272 Mdot
.55362 .6055 Mdot
.46277 .51964 Mdot
.45519 .13847 Mdot
.22464 .6286 Mdot
.56488 .66595 Mdot
.52754 .80199 Mdot
.56219 .80555 Mdot
.87503 .44557 Mdot
.28691 .26174 Mdot
.67014 .48151 Mdot
.85519 .44435 Mdot
.68268 .27857 Mdot
.5875 .82219 Mdot
.48851 .29751 Mdot
.51635 .85989 Mdot
.66609 .67679 Mdot
.23006 .67067 Mdot
.62291 .55677 Mdot
.7338 .37017 Mdot
.27415 .35947 Mdot
.54637 .48693 Mdot
.46323 .24671 Mdot
.19709 .51422 Mdot
.14211 .47029 Mdot
.57653 .67337 Mdot
.29594 .3239 Mdot
.63738 .39241 Mdot
.34037 .78207 Mdot
.22205 .51451 Mdot
.56511 .64751 Mdot
.60568 .31216 Mdot
.80502 .47507 Mdot
.40428 .60241 Mdot
.58472 .51101 Mdot
.22011 .50093 Mdot
.79474 .60676 Mdot
.44271 .70644 Mdot
.24631 .32248 Mdot
.66703 .68827 Mdot
.44733 .4694 Mdot
.47627 .63307 Mdot
.6138 .47269 Mdot
.30188 .5054 Mdot
.52461 .48736 Mdot
.55223 .65709 Mdot
.39666 .44375 Mdot
.50878 .29853 Mdot
.81245 .41225 Mdot
.6297 .28997 Mdot
.24128 .34791 Mdot
.6482 .54173 Mdot
.68946 .39221 Mdot
.55262 .21344 Mdot
.7961 .37454 Mdot
.24669 .51877 Mdot
.40351 .61573 Mdot
.47086 .79498 Mdot
.61795 .79078 Mdot
.72352 .50149 Mdot
.8687 .52398 Mdot
.58119 .36714 Mdot
.53059 .75366 Mdot
.70814 .38062 Mdot
.35949 .34435 Mdot
.54167 .54798 Mdot
.22968 .6682 Mdot
.36636 .57038 Mdot
.40793 .72136 Mdot
.20805 .44334 Mdot
.48664 .52332 Mdot
.62051 .73259 Mdot
.528 .80681 Mdot
.35365 .41184 Mdot
.21483 .37078 Mdot
.59373 .3351 Mdot
.22446 .49719 Mdot
.61818 .79379 Mdot
.8001 .65207 Mdot
.5085 .40391 Mdot
.32705 .62626 Mdot
.53387 .61808 Mdot
.23149 .3273 Mdot
.22169 .62446 Mdot
.51766 .74045 Mdot
.4191 .26515 Mdot
.62748 .49639 Mdot
.40859 .29942 Mdot
.46231 .47009 Mdot
.78843 .62925 Mdot
.61985 .48714 Mdot
.64697 .23515 Mdot
.28886 .51874 Mdot
.57116 .45089 Mdot
.50376 .54606 Mdot
.34084 .62383 Mdot
.29744 .23492 Mdot
.48264 .56196 Mdot
.32637 .74687 Mdot
.66265 .71247 Mdot
.30891 .28675 Mdot
.25038 .67085 Mdot
.52899 .26715 Mdot
.72008 .34262 Mdot
.57218 .76451 Mdot
.58822 .27314 Mdot
.5305 .58049 Mdot
.38266 .35086 Mdot
.69777 .47453 Mdot
.32576 .77461 Mdot
.71993 .67837 Mdot
.36218 .64756 Mdot
.38932 .51075 Mdot
.58693 .52178 Mdot
.60341 .34942 Mdot
.49919 .85122 Mdot
.72614 .35035 Mdot
.38761 .59242 Mdot
.43954 .50086 Mdot
.32618 .63888 Mdot
.7177 .54912 Mdot
.78754 .68385 Mdot
.63136 .56203 Mdot
.4763 .4207 Mdot
.72834 .5169 Mdot
.21433 .45139 Mdot
.30948 .7775 Mdot
.42026 .61199 Mdot
.56508 .43618 Mdot
.3455 .52058 Mdot
.55647 .22892 Mdot
.37709 .49971 Mdot
.56811 .50616 Mdot
.43319 .44942 Mdot
.42612 .24318 Mdot
.69269 .40574 Mdot
.45719 .69268 Mdot
.37761 .71689 Mdot
.48883 .79941 Mdot
.31457 .27462 Mdot
.56408 .28044 Mdot
.44619 .32982 Mdot
.75427 .67027 Mdot
.53491 .8681 Mdot
.67215 .22814 Mdot
.53506 .62137 Mdot
.59167 .30478 Mdot
.31168 .61795 Mdot
.37706 .43163 Mdot
.63079 .25236 Mdot
.5792 .23624 Mdot
.56662 .3291 Mdot
.36066 .58351 Mdot
.42236 .72075 Mdot
.31158 .33925 Mdot
.27643 .60292 Mdot
.61499 .35404 Mdot
.8086 .39553 Mdot
.17946 .53812 Mdot
.23249 .65733 Mdot
.64548 .84241 Mdot
.57257 .30004 Mdot
.54033 .71807 Mdot
.66353 .60602 Mdot
.64389 .792 Mdot
.36959 .61171 Mdot
.79535 .53665 Mdot
.50549 .24909 Mdot
.42152 .60181 Mdot
.64877 .41819 Mdot
.39633 .7213 Mdot
.4014 .29743 Mdot
.50849 .44155 Mdot
.24268 .46883 Mdot
.87436 .52317 Mdot
.60816 .72515 Mdot
.47513 .80275 Mdot
.79817 .45589 Mdot
.21552 .32648 Mdot
.63711 .79668 Mdot
.37681 .69104 Mdot
.2284 .53906 Mdot
.63381 .60743 Mdot
.5631 .41697 Mdot
.70515 .53244 Mdot
.78715 .5241 Mdot
.66017 .74694 Mdot
.28539 .41702 Mdot
.7165 .53711 Mdot
.42105 .65636 Mdot
.68475 .73399 Mdot
.56568 .43484 Mdot
.62941 .7469 Mdot
.31569 .36619 Mdot
.71194 .3034 Mdot
.71766 .47073 Mdot
.38167 .64045 Mdot
.66248 .71983 Mdot
.47979 .21263 Mdot
.20074 .53663 Mdot
.18273 .35533 Mdot
.29739 .48756 Mdot
.79262 .38791 Mdot
.51903 .69057 Mdot
.88228 .41532 Mdot
.24497 .39039 Mdot
.27429 .36829 Mdot
.20756 .42806 Mdot
.39584 .45737 Mdot
.58991 .67046 Mdot
.52997 .58042 Mdot
.35758 .75673 Mdot
.59506 .7247 Mdot
.75581 .55238 Mdot
.78036 .47284 Mdot
.34903 .59902 Mdot
.40679 .64749 Mdot
.36961 .66318 Mdot
.51623 .53025 Mdot
.6325 .4987 Mdot
.83667 .41532 Mdot
.49472 .39718 Mdot
.5163 .73891 Mdot
.47555 .5594 Mdot
.63704 .59101 Mdot
.25267 .75959 Mdot
.58804 .41805 Mdot
.46804 .74818 Mdot
.63726 .71418 Mdot
.7268 .48877 Mdot
.57054 .21509 Mdot
.85309 .67264 Mdot
.90119 .42567 Mdot
.69702 .45812 Mdot
.34307 .23746 Mdot
.6283 .71991 Mdot
.49999 .77772 Mdot
.24948 .50245 Mdot
.40509 .26169 Mdot
.52779 .74738 Mdot
.74085 .44125 Mdot
.53914 .54167 Mdot
.24611 .37988 Mdot
.70853 .76055 Mdot
.77477 .47134 Mdot
.52433 .80121 Mdot
.59364 .61712 Mdot
.52322 .54331 Mdot
.61612 .86243 Mdot
.42002 .7707 Mdot
.5069 .56615 Mdot
.67002 .55356 Mdot
.45075 .67268 Mdot
.50311 .61236 Mdot
.27726 .68664 Mdot
.15243 .47889 Mdot
.44217 .70814 Mdot
.52243 .78983 Mdot
.62635 .45448 Mdot
.36427 .44926 Mdot
.54346 .31524 Mdot
.51741 .40813 Mdot
.48254 .57607 Mdot
.57751 .35254 Mdot
.44363 .54181 Mdot
.25569 .73091 Mdot
.39317 .4977 Mdot
.18037 .42115 Mdot
.57979 .84291 Mdot
.70629 .68972 Mdot
.57685 .24459 Mdot
.45711 .64055 Mdot
.54672 .76717 Mdot
.63624 .76883 Mdot
.55456 .51258 Mdot
.20085 .61958 Mdot
.63602 .14115 Mdot
.54174 .24247 Mdot
.78145 .64899 Mdot
.6948 .49505 Mdot
.42693 .46672 Mdot
.60386 .74416 Mdot
.48894 .30494 Mdot
.41746 .40344 Mdot
.59041 .58792 Mdot
.64017 .52855 Mdot
.57589 .38623 Mdot
.38347 .15226 Mdot
.55005 .66854 Mdot
.60537 .23876 Mdot
.5682 .82039 Mdot
.78439 .56139 Mdot
.6875 .64291 Mdot
.4819 .59638 Mdot
.6537 .36844 Mdot
.5642 .43727 Mdot
.31608 .74658 Mdot
.81133 .61518 Mdot
.47604 .78366 Mdot
.71751 .68243 Mdot
.62199 .72999 Mdot
.47714 .63519 Mdot
.306 .56549 Mdot
.49371 .36433 Mdot
.33005 .73754 Mdot
.44815 .65613 Mdot
.63331 .80885 Mdot
.38453 .32903 Mdot
.44301 .51042 Mdot
.58946 .43157 Mdot
.87073 .44667 Mdot
.67149 .5781 Mdot
.66847 .53546 Mdot
.79886 .37896 Mdot
.35965 .33641 Mdot
.30135 .59617 Mdot
.34972 .39433 Mdot
.45212 .64878 Mdot
.6173 .50187 Mdot
.78188 .31903 Mdot
.32194 .72026 Mdot
.47262 .24209 Mdot
.42739 .27211 Mdot
.35343 .2493 Mdot
.57971 .31725 Mdot
.66535 .83217 Mdot
.25365 .40789 Mdot
.79919 .35081 Mdot
.20816 .36527 Mdot
.62757 .52589 Mdot
.19804 .565 Mdot
.4965 .55853 Mdot
.41332 .3979 Mdot
.49666 .7867 Mdot
.53589 .72611 Mdot
.81844 .53931 Mdot
.47432 .65743 Mdot
.82993 .48669 Mdot
.33914 .50963 Mdot
.3045 .39148 Mdot
.22075 .43898 Mdot
.64453 .5911 Mdot
.42866 .83375 Mdot
.54444 .22153 Mdot
.44706 .82982 Mdot
.40482 .81867 Mdot
.54291 .81319 Mdot
.81002 .52165 Mdot
.55404 .16207 Mdot
.21712 .45471 Mdot
.25125 .68378 Mdot
.45861 .30321 Mdot
.62155 .58132 Mdot
.23985 .41876 Mdot
.59808 .53098 Mdot
.66003 .29134 Mdot
.60846 .3374 Mdot
.37852 .11149 Mdot
.4033 .67253 Mdot
.67526 .52465 Mdot
.23797 .43269 Mdot
.5846 .81281 Mdot
.63856 .60199 Mdot
.19654 .50483 Mdot
.4724 .46679 Mdot
.55654 .69477 Mdot
.66313 .74323 Mdot
.31593 .26883 Mdot
.29347 .35972 Mdot
.16773 .34746 Mdot
.1829 .50388 Mdot
.44706 .24353 Mdot
.49395 .45092 Mdot
.69448 .45507 Mdot
.51437 .18188 Mdot
.24835 .45706 Mdot
.19179 .60275 Mdot
.23827 .6989 Mdot
.41363 .76869 Mdot
.23123 .27442 Mdot
.29314 .30045 Mdot
.66842 .78117 Mdot
.20361 .58348 Mdot
.6992 .45987 Mdot
.36178 .68281 Mdot
.40523 .36126 Mdot
.46087 .2659 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0Uoooool2o`00
00Wooooo0_l00006ooooo`;o0000WOooool001cooooo0_l0002;ooooo`;o00002oooool2o`0000Wo
oooo0_l00006ooooo`;o0000WOooool001cooooo00?o0000ooooooooool0R_ooool2o`00013ooooo
0_l0002[ooooo`007?ooool00ol0003oooooooooo`2Aooooo`;o00002Oooool2o`000:_ooooo000L
ooooo`03o`000?oooooooooo097ooooo0_l0002fooooo`007?ooool00ol0003oooooooooo`1goooo
o`;o0000d?ooool001cooooo00?o0000ooooooooool0Moooool2o`000=3ooooo000Looooo`03o`00
0?oooooooooo08kooooo0_l0000looooo`;o0000Noooool001cooooo00?o0000ooooooooool0S_oo
ool2o`0000gooooo0_l0000]ooooo`;o0000Noooool001cooooo00?o0000ooooooooool0WOooool2
o`000:[ooooo000Looooo`03o`000?oooooooooo08Wooooo0_l0000?ooooo`;o0000[Oooool001co
oooo00?o0000ooooooooool0ROooool2o`0000oooooo0_l0002]ooooo`007?ooool00ol0003ooooo
ooooo`2_ooooo`;o0000V?ooool001cooooo00?o0000ooooooooool0WOooool4o`0000kooooo0_l0
002Hooooo`007?ooool00ol0003oooooooooo`2@ooooo`;o00002oooool4o`0002[ooooo0_l0001l
ooooo`007?ooool00ol0003oooooooooo`2@ooooo`;o0000>Oooool2o`0007cooooo000Looooo`03
o`000?oooooooooo0:Oooooo0_l0002Pooooo`007?ooool00ol0003oooooooooo`2Wooooo`;o0000
0oooool3o`0009[ooooo000Looooo`;o0000N_ooool2o`00037ooooo0ol0002Jooooo`007?ooool0
0ol0003oooooooooo`1iooooo`;o0000c_ooool001cooooo00?o0000ooooooooool0_?ooool2o`00
08_ooooo000Looooo`03o`000?oooooooooo0;3ooooo0_l00002ooooo`;o00001_ooool2o`0008_o
oooo000Looooo`03o`000?oooooooooo09Sooooo0_l0000Fooooo`;o00000_ooool2o`0009?ooooo
000Looooo`03o`000?oooooooooo07?ooooo0_l00009ooooo`;o00006?ooool2o`0000Wooooo0_l0
000Hooooo`;o0000R_ooool001cooooo00?o0000ooooooooool0KOooool2o`0000Cooooo0_l00009
ooooo`;o00004_ooool2o`0000Kooooo0_l00007ooooo`;o000000?oooooo`000?l000000_l0000C
ooooo`;o00001Oooool2o`0008?ooooo000Looooo`03o`000?oooooooooo06gooooo0_l0000Soooo
o`;o00001_ooool2o`0000[ooooo1?l0000Dooooo`;o00001?ooool2o`0008?ooooo000Looooo`03
o`000?oooooooooo08kooooo0_l0000^ooooo`;o00002Oooool2o`0007kooooo000Looooo`03o`00
0?oooooooooo07[ooooo0_l00005ooooo`;o00002oooool2o`0000Cooooo0_l0000Booooo`;o0000
00?oooooo`000?l000001_ooool2o`0000Cooooo0_l00002ooooo`;o00002_ooool2o`0007kooooo
000Looooo`03o`000?oooooooooo07[ooooo0_l00005ooooo`;o00000_ooool2o`0000?ooooo0_l0
0002ooooo`;o00001?ooool2o`0000gooooo0_l00003ooooo`;o000000?oooooo`000?l000001_oo
ool2o`0000Cooooo0_l00002ooooo`;o0000R_ooool001cooooo00?o0000ooooooooool0POooool2
o`0000;ooooo0_l00002ooooo`?o00002?ooool2o`0000Gooooo0_l00002ooooo`;o00000_ooool2
o`0000Cooooo0_l00004ooooo`?o0000Uoooool001cooooo00?o0000ooooooooool0I_ooool2o`00
01;ooooo0_l0000=ooooo`;o00000_ooool2o`0000Gooooo0_l00005ooooo`;o00000_ooool2o`00
00Sooooo0_l00002ooooo`Ko00005Oooool2o`0007oooooo00001_ooooook^k^oc8b<_l0003o<S8b
onk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`1Qooooo`;o00000oooool2
o`0000_ooooo1?l00003ooooo`;o00004Oooool2o`00017ooooo0_l00007ooooo`;o00000_ooool2
o`0000;ooooo0_l0000Eooooo`;o0000Ooooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Ooo
ool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo067ooooo
0_l00008ooooo`;o00001_ooool4o`0001kooooo0_l00009ooooo`;o00001Oooool2o`000:3ooooo
00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00ol0003oooooooooo`1[ooooo`;o00002oooool2o`0000_ooooo0_l000000ooooooo0000o`00
000;ooooo`;o00004?ooool4o`0000Gooooo0_l0000Pooooo`;o0000MOooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06ooooo`?o0000N?ooool2
o`0000Kooooo0ol00002ooooo`;o000000?oooooo`000?l000007oooool3o`0000Cooooo0_l00009
ooooo`;o00005Oooool2o`0007Gooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`1^ooooo`;o00002?ooool2o`00
00Kooooo0ol0000;ooooo`;o000000?oooooo`000?l000000_l0000Eooooo`;o00001Oooool2o`00
00Sooooo0_l00003ooooo`;o0000Qoooool00003ooooool@413ooooo00;ooooo00?o410@oooooooo
ool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06Sooooo0_l00004ooooo`;o
00005?ooool2o`0000Oooooo0ol000000ooooooo0000o`000002o`0000Oooooo0ol0000Booooo`?o
000000?oooooo`000?l000002Oooool4o`0008Gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMg
M`_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo06Sooooo0_l0000J
ooooo`;o00001Oooool4o`0000gooooo0ol00007ooooo`Co00002?ooool2o`000003ooooool0003o
000000_ooooo0_l0000Dooooo`;o0000Koooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2ooo
ool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0N_ooool2o`0000kooooo
1Ol00009ooooo`;o00001Oooool2o`0000Gooooo1Ol00005ooooo`;o000000Coooooo`000?l0003o
oooo1?l00002ooooo`;o00006_ooool2o`0006oooooo000Looooo`03o`000?oooooooooo06Cooooo
0_l0000Booooo`Co00003Oooool6o`0000Wooooo0_l00005ooooo`;o00002?ooool2o`0000Gooooo
0_l000001?oooooo0000o`000?ooool4o`0000;ooooo0_l0000Gooooo`;o0000L_ooool001cooooo
00?o0000ooooooooool0I?ooool2o`0000Cooooo0_l00005ooooo`;o00001Oooool2o`0000oooooo
0_l00002ooooo`?o00002_ooool2o`0000kooooo0_l000000ooooooo0000o`00000>ooooo`;o0000
5_ooool2o`0007;ooooo000Looooo`03o`000?oooooooooo05cooooo0_l00002ooooo`;o00001Ooo
ool2o`000004ooooool0003o0000ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0001So
oooo0_l0000:ooooo`;o00003_ooool2o`000003ooooool0003o000000cooooo1?l00007ooooo`;o
00002?ooool2o`0000_ooooo0_l0001Zooooo`007?ooool00ol0003oooooooooo`1Looooo`;o0000
0_ooool2o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l00000
0_ooool2o`0000oooooo0_l0000dooooo`;o00001_ooool2o`000003ooooool0003o000000Sooooo
0ol000000ooooooo0000o`000007ooooo`;o00001?ooool2o`0006Cooooo000Looooo`03o`000?oo
oooooooo05_ooooo0_l00007ooooo`;o00007oooool2o`0001[ooooo0_l0000>ooooo`;o00004?oo
ool5o`0000?ooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l0000:ooooo`;o0000
I?ooool001cooooo00?o0000ooooooooool0Foooool2o`0001Gooooo0_l0000Oooooo`;o00002?oo
ool2o`0000;ooooo0_l00003ooooo`;o00002Oooool2o`0000oooooo1?l00005ooooo`;o00002_oo
ool2o`0000cooooo0_l0001Rooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o00002oooool2
o`0000Kooooo1?l0000;ooooo`;o00004?ooool2o`0000;ooooo0_l000001?oooooo0000o`000?oo
ool2o`0000Gooooo1?l00004ooooo`;o00002Oooool3o`0000Sooooo1?l00005ooooo`;o000000Co
ooooo`000?l0003o00005?ooool2o`0006;ooooo000Looooo`03o`000?oooooooooo05?ooooo0_l0
0008ooooo`;o00002oooool4o`0000Kooooo0_l00008ooooo`;o000000?oooooo`000?l000005?oo
ool5o`0000Gooooo0_l000000ooooooo0000o`000005o`000003ooooool0003o000000Kooooo0_l0
00001?oooooo0000o`000?l00007ooooo`;o000000Coooooo`000?l0003ooooo0_l00005ooooo`?o
0000N?ooool001cooooo00?o0000ooooooooool0Doooool2o`0000gooooo0_l00008ooooo`;o0000
4?ooool2o`0001Kooooo1?l00007ooooo`;o00001Oooool6o`0000Kooooo0_l00003ooooo`Go0000
0oooool4o`0000;ooooo0_l00003ooooo`;o0000Noooool001cooooo00?o0000ooooooooool0F?oo
ool2o`0000Sooooo0_l00006ooooo`;o00001oooool2o`0001;ooooo1?l00002ooooo`?o00001?oo
ool4o`0000Wooooo0_l00007ooooo`Co00000oooool2o`0000Gooooo1_l00005ooooo`;o00000_oo
ool2o`0000?ooooo0ol0001jooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o00001?ooool2
o`0000Kooooo0_l00002ooooo`?o00000_ooool2o`0000;ooooo0_l00004ooooo`?o00002oooool4
o`0000;ooooo0ol00003ooooo`?o00002_ooool4o`0000Cooooo0_l00003ooooo`?o000000?ooooo
o`000?l000001?ooool3o`0000Gooooo0_l0000<ooooo`;o0000N_ooool001cooooo0_l0001Ooooo
o`;o00001_ooool2o`0000?ooooo0_l00002ooooo`;o00002?ooool3o`0001Oooooo0_l0000:oooo
o`Ko00000oooool2o`0000?ooooo0ol00007ooooo`;o00001Oooool3o`0000?ooooo0_l00003oooo
o`;o00003?ooool4o`0006kooooo000Looooo`03o`000?oooooooooo04[ooooo0_l0000Booooo`;o
00002?ooool2o`0002Cooooo1?l0000=ooooo`;o00000_ooool2o`0001Kooooo0_l000000ooooooo
0000o`000004ooooo`;o00000oooool2o`0000[ooooo1_l0001^ooooo`007?ooool00ol0003ooooo
ooooo`1:ooooo`;o00007?ooool2o`0000?ooooo0ol00004ooooo`?o00001?ooool2o`0000Sooooo
0_l00007ooooo`Co00005Oooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000So
oooo0_l0000Hooooo`;o000000Coooooo`000?l0003ooooo0_l0001/ooooo`007?ooool00ol0003o
ooooooooo`1Nooooo`;o00003Oooool3o`000004ooooool0003o0000ooooo`?o00001?ooool2o`00
00Sooooo0_l00004ooooo`;o00001_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000:oooo
o`?o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00002_ooool2o`0000Sooooo0_l0000=
ooooo`;o00000oooool2o`0006cooooo000Looooo`03o`000?oooooooooo05Oooooo1?l00003oooo
o`;o00000oooool2o`000003ooooool0003o000000Oooooo2?l00009ooooo`Co00001?ooool2o`00
0004ooooool0003o0000ooooo`;o00000_ooool3o`000005ooooool0003o0000o`000?ooool00_l0
0005ooooo`;o00000oooool3o`0000cooooo0_l00006ooooo`?o00001oooool2o`0000Sooooo0ol0
0002ooooo`;o0000LOooool001cooooo00?o0000ooooooooool0Eoooool4o`0000?ooooo0_l00003
ooooo`;o000000?oooooo`000?l000000_l00005ooooo`;o00000_ooool2o`0000_ooooo1_l00002
ooooo`;o00000_ooool4o`000003ooooool0003o000000Go00002Oooool2o`0000Gooooo0_l0000;
ooooo`;o00000oooool2o`0000;ooooo0_l0000>ooooo`;o000000Coooooo`000?l0003o00000_oo
ool2o`00077ooooo000Looooo`03o`000?oooooooooo05_ooooo0_l000000ooooooo0000o`000003
ooooo`;o00000_ooool3o`0001[ooooo0_l00006ooooo`;o00000oooool5o`000003ooooool0003o
000000oooooo0_l0000;ooooo`;o00000oooool3o`00017ooooo0_l000000ooooooo0000o`000003
ooooo`;o00007Oooool2o`0005;ooooo000Looooo`03o`000?oooooooooo04Wooooo0_l0000@oooo
o`;o00001_ooool2o`0002;ooooo0_l00009ooooo`;o00000oooool2o`0000gooooo0_l0000;oooo
o`;o000000?oooooo`000?l000000oooool4o`0000oooooo0_l0000:ooooo`;o00001oooool2o`00
013ooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`17ooooo`Co00005oooool2o`0000[o
oooo0_l00002ooooo`;o00002Oooool2o`0000?ooooo0_l00002ooooo`?o00002?ooool5o`0000go
oooo1Ol00008ooooo`;o000000?oooooo`000?l000000ol000000ooooooo0000o`000004o`0000Co
oooo1?l000000ooooooo0000o`000004ooooo`Co00001?ooool2o`0000;ooooo0_l00007ooooo`;o
0000I?ooool001cooooo00?o0000ooooooooool0AOooool4o`0001Wooooo0_l0000:ooooo`;o0000
0_ooool2o`0000?ooooo0_l00004ooooo`;o00000oooool2o`0000;ooooo0_l00009ooooo`;o0000
00Coooooo`000?l0003ooooo0_l00008ooooo`Ko00002Oooool2o`0000?ooooo0_l000001?oooooo
0000o`000?l00008ooooo`Oo00001_ooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2
o`0001oooooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`0mooooo`;o00001_ooool2o`00
01?ooooo0_l00007ooooo`;o00004_ooool2o`0000Kooooo0_l0000<ooooo`;o00002?ooool2o`00
0003ooooool0003o000000Cooooo0ol00005ooooo`;o000000?oooooo`000?l000001_ooool4o`00
0003ooooool0003o000000Gooooo0_l00005ooooo`;o00001Oooool2o`0000Cooooo0_l00004oooo
o`?o00007oooool2o`0004cooooo000Looooo`03o`000?oooooooooo03gooooo0_l0000Hooooo`;o
000000?oooooo`000?l000001Oooool4o`0000oooooo0_l00003ooooo`;o00000oooool3o`0000Co
oooo0_l00006ooooo`;o00001?ooool2o`0000Gooooo0_l00004ooooo`?o00000oooool4o`000003
ooooool0003o000000Kooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000;o
oooo0_l0000<ooooo`;o00002_ooool2o`0000;ooooo0_l0001Zooooo`007?ooool00ol0003ooooo
ooooo`1Gooooo`;o00002?ooool2o`0000Wooooo0_l00006ooooo`Co000000?oooooo`000?l00000
0oooool2o`0000;ooooo0_l000000ooooooo0000o`000007ooooo`;o00000oooool2o`0000Gooooo
0_l00003ooooo`Go00000_ooool2o`0000;ooooo0_l00009ooooo`Go000000?oooooo`000?l00000
3_ooool2o`00013ooooo0_l00004ooooo`;o00000oooool2o`0005oooooo000Looooo`03o`000?oo
oooooooo067ooooo0_l00009ooooo`;o00001Oooool2o`000003ooooool0003o000000[ooooo0_l0
000:ooooo`Co00003Oooool2o`000003ooooool0003o000000Kooooo0_l00009ooooo`;o00001?oo
ool2o`0000?ooooo0_l00006ooooo`Go00001_ooool4o`0000cooooo0_l00003ooooo`;o0000Gooo
ool001cooooo00?o0000ooooooooool0EOooool4o`00017ooooo0_l00007ooooo`;o000000?ooooo
o`000?l000000_l000000ooooooo0000o`00000Booooo`?o00007oooool2o`0000Sooooo1?l00000
0ooooooo0000o`000002ooooo`;o00000_ooool5o`0000Kooooo1?l00009ooooo`;o0000Ioooool0
01cooooo00?o0000ooooooooool0EOooool4o`00017ooooo0_l0000:ooooo`Co000000?oooooo`00
0?l000000_ooool2o`0000kooooo0_l0000:ooooo`;o00001Oooool2o`0000Cooooo0ol00006oooo
o`;o00001oooool2o`000003ooooool0003o000000Gooooo0_l00005ooooo`;o00002Oooool2o`00
00Sooooo0_l0001Wooooo`007?ooool2o`0005Cooooo0_l00005ooooo`Co00003Oooool2o`0001;o
oooo1?l0000Hooooo`;o00001?ooool6o`000003ooooool0003o000000?o000000?oooooo`000?l0
00001_ooool2o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`;o00004Oooool2o`0000;o
oooo0_l0001]ooooo`007?ooool00ol0003oooooooooo`16ooooo`;o00002oooool2o`0000Gooooo
1Ol00002ooooo`;o00002?ooool2o`0000_ooooo0ol00006ooooo`;o00001oooool4o`000003oooo
ool0003o000000;o00003?ooool4o`000003ooooool0003o000000;o00000_ooool3o`000003oooo
ool0003o000000;o00001?ooool2o`0000Cooooo0ol000001?oooooo0000o`000?ooool2o`0000Co
oooo0_l0000?ooooo`;o00001oooool2o`0002Oooooo0_l0000kooooo`007?ooool00ol0003ooooo
ooooo`16ooooo`;o00003oooool2o`0000Cooooo0_l00002ooooo`;o00001Oooool2o`0000kooooo
0ol0000?ooooo`Co000000?oooooo`000?l000001?l00006ooooo`;o000000Coooooo`000?l0003o
00000oooool6o`0000?ooooo1_l00002ooooo`;o00001Oooool2o`0000;ooooo0_l00007ooooo`;o
00006?ooool2o`0000Gooooo0_l000000ooooooo0000o`000007ooooo`;o00005?ooool2o`0003_o
oooo000Looooo`03o`000?oooooooooo053ooooo0_l00002ooooo`;o000000?oooooo`000?l00000
0_l0000=ooooo`;o00000_ooool2o`0000[ooooo0_l0000Gooooo`Co00001_ooool2o`000003oooo
ool0003o000001?o00000_ooool2o`0001Wooooo0_l0000Hooooo`;o000000?oooooo`000?l00000
1oooool2o`00057ooooo000Looooo`03o`000?oooooooooo04;ooooo0_l0000<ooooo`Ko00000ooo
ool3o`0000;ooooo0_l00002ooooo`;o00002?ooool2o`0000Sooooo1?l00009ooooo`;o00003Ooo
ool2o`0000Cooooo0_l00003ooooo`Oo000000?oooooo`000?l000003Ol00003ooooo`;o00002?oo
ool2o`0000Oooooo0_l00004ooooo`;o00002_ooool4o`0000Sooooo0_l00003ooooo`;o0000F_oo
ool001cooooo00?o0000ooooooooool0@_ooool2o`0000kooooo1?l00004ooooo`;o000000Cooooo
o`000?l0003o00000_ooool2o`0001;ooooo1?l00009ooooo`;o00002Oooool3o`000003ooooool0
003o000000Cooooo0_l00003ooooo`Co00001?ooool?o`0000?ooooo0_l00008ooooo`;o00001?oo
ool2o`000003ooooool0003o0000013ooooo1?l00008ooooo`;o00001Oooool2o`0000Kooooo0_l0
001@ooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00003oooool5o`0001Kooooo1?l00009
ooooo`;o00002Oooool4o`0000cooooo1?l00003oooooa3o00000oooool4o`000003ooooool0003o
000000Wooooo0_l000000ooooooo0000o`00000Eooooo`Co00001_ooool2o`0000;ooooo0_l00006
ooooo`Go0000COooool001cooooo00?o0000ooooooooool0BOooool2o`000003ooooool0003o0000
00kooooo0_l0000Gooooo`;o00002Oooool4o`0000Cooooo0_l00003ooooo`;o00001oooool2o`00
00Cooooo1Ol000000ooooooo0000o`00000Go`000003ooooool0003o000000;ooooo1_l00002oooo
o`Co00005Oooool4o`0000?ooooo0_l000000ooooooo0000o`00000<ooooo`?o0000COooool001co
oooo00?o0000ooooooooool0AOooool2o`0000;ooooo0_l000000ooooooo0000o`000003o`0000_o
oooo0_l00002ooooo`;o00004oooool2o`0000Wooooo0_l00006ooooo`;o00002?ooool2o`0000;o
oooo0_l00004ooooo`Go000000?oooooo`000?l000005Ol00007ooooo`Ko00000_ooool2o`0001Oo
oooo0_l00005ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Sooooo0_l0001:ooooo`00
7?ooool00ol0003oooooooooo`12ooooo`;o000000?oooooo`000?l000000_l000001Ooooooo0000
o`000?l0003ooooo00?o000000?oooooo`000?l000001Oooool5o`0000;ooooo0_l00006ooooo`Co
00001_ooool2o`000003ooooool0003o000000;ooooo0_l00006ooooo`;o00001oooool2o`0000Ko
oooo0_l00009ooooo`;o00001?oooolGo`0000Kooooo0_l0000Wooooo`;o00002?ooool2o`0000So
oooo0_l0001:ooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00000_ooool3o`000004oooo
ool0003o0000o`0000Gooooo0_l00005ooooo`?o00000oooool2o`0000Cooooo0_l000000ooooooo
0000o`000002o`0000Cooooo1?l000000ooooooo0000o`000002ooooo`?o00001Oooool2o`0000Oo
oooo0_l000001?oooooo0000o`000?l0000Aoooooa[o00000oooool4o`000003ooooool0003o0000
027ooooo0_l000001?oooooo0000o`000?l0001Mooooo`007?ooool00ol0003oooooooooo`12oooo
o`;o00000_ooool3o`0000Wooooo0_l00003ooooo`Go00000oooool2o`0000Cooooo0_l00009oooo
o`;o00002?ooool2o`00017ooooo0ol0000Aoooooa[o00000_ooool4o`0000;ooooo0_l00004oooo
o`;o00000oooool5o`0001?ooooo0ol000000ooooooo0000o`00000=ooooo`;o0000C_ooool001co
oooo00?o0000ooooooooool0Aoooool2o`0000Cooooo0_l00008ooooo`;o000000?oooooo`000?l0
00001oooool2o`0000Oooooo0_l00003ooooo`;o00003Oooool2o`0001[ooooo0_l00005oooooaSo
00000_ooool4o`000003ooooool0003o000000;o00000oooool2o`0000?ooooo1Ol0000?ooooo`;o
00000oooool2o`0000;ooooo0_l0000<ooooo`;o0000C_ooool001cooooo00?o0000ooooooooool0
<_ooool2o`0001Wooooo0_l0000Booooo`Co00001oooool2o`0000?ooooo0_l0000=ooooo`;o0000
4Oooool2o`0000Gooooo1?l00006ooooo`Co000000?oooooo`000?l000004?l00007ooooo`Co0000
2oooool2o`0000oooooo1Ol00004ooooo`;o00002?ooool2o`0005;ooooo000Looooo`03o`000?oo
oooooooo03;ooooo0_l0000]ooooo`;o00001Oooool2o`0000Oooooo0_l00003ooooo`?o00002ooo
ool2o`0000?ooooo0_l00005ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Sooooo5ol0
0008ooooo`;o00000oooool2o`0001[ooooo1?l0000<ooooo`?o0000D_ooool001cooooo00?o0000
ooooooooool0<oooool2o`0001Kooooo0_l0000Aooooo`;o00002?ooool2o`0000Oooooo0_l00002
ooooo`Co00002oooool2o`0000?ooooo0_l00005ooooo`?o00000oooool2o`0000Kooooo0ol00003
ooooo`So000000?oooooo`000?l000001Ol00002ooooo`Ko00003?ooool2o`00017ooooo0ol00005
ooooo`;o000000?oooooo`000?l000002?ooool2o`0000;ooooo0_l0001Cooooo`007?ooool2o`00
03Cooooo0_l0000Fooooo`;o000000?oooooo`000?l000002oooool2o`000003ooooool0003o0000
00Gooooo0_l000000ooooooo0000o`00000:ooooo`Oo00005_ooool2o`0000?ooooo0_l00006oooo
o`?o00000_oooolIo`0000Cooooo0_l0000<ooooo`;o00001_ooool2o`0000?ooooo0ol000000ooo
oooo0000o`000002ooooo`Co000000?oooooo`000?l000001_ooool2o`0000kooooo0_l00007oooo
o`;o0000?_ooool001cooooo00?o0000ooooooooool0C_ooool2o`0000Wooooo1?l00008ooooo`;o
00001oooool2o`0000Cooooo1ol00007ooooo`;o00007ooooolHo`0000Gooooo0_l00002ooooo`;o
00001Oooool2o`000003ooooool0003o000000Kooooo0_l00007ooooo`;o00001?ooool5o`0001Ko
oooo0_l00007ooooo`;o0000?_ooool001cooooo00?o0000ooooooooool0>?ooool2o`0001;ooooo
0_l0000;ooooo`;o00000_ooool2o`0000cooooo0_l000000ooooooo0000o`000003ooooo`;o0000
1?ooool3o`000004ooooool0003o0000o`0000;ooooo0_l0000?ooooo`;o00004?ooool<o`000003
ooooool0003o000000?o000000?oooooo`000?l000000_l000000ooooooo0000o`000005ooooo`;o
00001Oooool2o`0000Wooooo0_l0000;ooooo`Ko00001_ooool2o`0005Sooooo000Looooo`03o`00
0?oooooooooo03Sooooo0_l0000Booooo`;o00001oooool2o`0000?ooooo1Ol000000ooooooo0000
o`000003ooooo`;o00001?ooool3o`0000Cooooo1ol000001?oooooo0000o`000?ooool3o`0000;o
oooo1?l0000=ooooo`;o00002oooool2o`0000?ooooo6_l00005ooooo`;o00001Oooool2o`0000Wo
oooo0ol0000:ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`Co0000F?ooool001co
oooo00?o0000ooooooooool0@?ooool2o`000003ooooool0003o000000?ooooo0_l00007ooooo`;o
00000_ooool2o`0000?ooooo1?l000001?oooooo0000o`000?l00003ooooo`;o00000oooool4o`00
00Cooooo3Ol000000ooooooo0000o`000002ooooo`;o00003_ooool2o`0000[ooooo0_l00003oooo
oaWo00001_ooool2o`0000oooooo1?l0000;ooooo`;o000000?oooooo`000?l000000ol000000ooo
oooo0000o`000006ooooo`;o00004Oooool2o`0003oooooo000Looooo`03o`000?oooooooooo043o
oooo0_l000000ooooooo0000o`000003ooooo`;o00001oooool2o`0000cooooo0_l00002ooooo`;o
00001Oooool2o`0000Gooooo4Ol0000Booooo`;o00001?ooool2o`000003ooooool0003o000000So
oooo5?l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00009ooooo`;o00000_ooool5o`00
00;ooooo0_l00009ooooo`Oo00001_ooool2o`0000;ooooo0_l0000Aooooo`;o0000?oooool001co
oooo00?o0000ooooooooool0@?ooool2o`0001?ooooo0_l00003ooooo`Co00001Oooool4o`0000;o
oooo0_l000000ooooooo0000o`000003ooooo`Go000000?oooooo`000?l000003?l0000Eooooo`;o
000000Coooooo`000?l0003o00001_oooolEo`0000Cooooo0_l00002ooooo`;o00000_ooool2o`00
00Gooooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l0000:ooooo`;o00002_ooool2o`00
00;ooooo0_l0000:ooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0>_ooool2o`0000;o
oooo0_l00002ooooo`;o00001oooool2o`0000?ooooo0_l00003ooooo`;o00000_ooool5o`0000Oo
oooo0_l00002ooooo`;o000000?oooooo`000?l000001?ooool=o`000003ooooool0003o000000Ko
00003_ooool4o`0000Cooooo0_l00006oooooaKo00001oooool2o`0000;ooooo0_l00006ooooo`Ko
00001oooool2o`0000gooooo1?l00006ooooo`;o00002_ooool2o`0000_ooooo0_l0000iooooo`00
7?ooool00ol0003oooooooooo`0iooooo`?o00000_ooool2o`0000;ooooo0_l00005ooooo`Co0000
0oooool2o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000000oooool4o`0000Cooooo
0_l00006oooooaOo00003_ooool4o`0000oooooo4ol0000:ooooo`?o00001_ooool2o`0000;ooooo
0_l00007ooooo`;o00003Oooool5o`0000oooooo1?l0000;ooooo`;o0000>Oooool001cooooo00?o
0000ooooooooool0>Oooool2o`0000kooooo0_l00003ooooo`;o00000oooool4o`0000;ooooo0_l0
00000ooooooo0000o`000003ooooo`Co00002OoooolIo`0001[ooooo1Ol000000ooooooo0000o`00
000Bo`0000_ooooo0_l00005ooooo`;o00007oooool2o`0000?ooooo0_l0000:ooooo`Co0000A_oo
ool001cooooo00?o0000ooooooooool0@oooool2o`0000;ooooo0_l00003ooooo`Co00000oooool2
o`0000Cooooo0_l00003ooooo`;o00003_ooool:o`000005ooooool0003o0000o`000?ooool02ol0
000Iooooo`Go000000?oooooo`000?l000004ol00002ooooo`?o00001?ooool2o`0000Kooooo0_l0
000Cooooo`;o00003oooool2o`0000[ooooo0ol000000ooooooo0000o`000014ooooo`007?ooool0
0ol0003oooooooooo`0hooooo`;o00002Oooool2o`0000;ooooo0ol00002ooooo`;o000000?ooooo
o`000?l000000_l00005ooooo`?o00000oooool2o`0000;ooooo0_l00003ooooo`;o000000?ooooo
o`000?l000007?l00003ooooo`;o00005_ooool2o`0000Kooooo4Ol00002ooooo`?o00001?ooool2
o`0001_ooooo0_l00003ooooo`?o00001Oooool2o`0000kooooo0ol000000ooooooo0000o`000014
ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00003_ooool2o`0000Gooooo1?l00004oooo
o`Co00001oooool2o`0000;ooooo0ol000000ooooooo0000o`00000Mo`0000;ooooo1?l0000=oooo
o`;o00001Oooool2o`0000Kooooo4?l0000=ooooo`;o00000oooool2o`0000Oooooo0_l0000?oooo
o`?o000000Goooooo`000?l0003o0000ooooo`02o`0000Gooooo0_l00006ooooo`?o0000B?ooool0
01cooooo00?o0000ooooooooool0=oooool2o`0000Oooooo0_l0000:ooooo`;o00001_ooool2o`00
0003ooooool0003o000000Oooooo0_l00004ooooo`?o00000ooooolNo`000003ooooool0003o0000
00;o00003Oooool2o`0000?ooooo0_l00008ooooo`?o000000?oooooo`000?l000002?l00002oooo
o`?o00002_ooool2o`0000?ooooo0_l00007ooooo`;o00004?ooool2o`000004ooooool0003o0000
o`0000Sooooo0_l00006ooooo`?o00001?ooool3o`00047ooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003ooooooooo
o`0gooooo`;o00001_ooool3o`0000Wooooo0ol00006ooooo`;o000000?oooooo`000?l000001_oo
ool3o`0000[ooooo7_l0000@ooooo`;o00001Oooool2o`000003ooooool0003o000000Gooooo0_l0
0002ooooo`Co000000?oooooo`000?l000001Oooool3o`0000Cooooo0_l00004ooooo`;o000000?o
ooooo`000?l000001?l0000;ooooo`;o00001Oooool2o`0000?ooooo0_l00005ooooo`;o00002Ooo
ool2o`0000?ooooo0_l00004ooooo`?o0000@Oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0oooooo`;o0000
2_ooool4o`000003ooooool0003o000000gooooo0_l00007ooooo`;o00000_oooolNo`000003oooo
ool0003o000000Cooooo0_l00007ooooo`;o000000?oooooo`000?l000000_ooool2o`000003oooo
ool0003o000000Gooooo0_l00002ooooo`Co000000?oooooo`000?l000000ol00003ooooo`?o0000
0oooool2o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o00002oooool2o`0000Gooooo
0_l00006ooooo`;o00000_ooool2o`0000Wooooo0_l00003ooooo`;o00000_ooool2o`0000Sooooo
1?l0000hooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`Go00001_oo
ool00ol0003oooooooooo`1=ooooo`;o000000?oooooo`000?l000001_ooool2o`0000gooooo0ol0
0002ooooob7o00001?ooool4o`0000Sooooo0_l00002ooooo`Co00000oooool2o`0000Gooooo1?l0
0002ooooo`Co00000oooool3o`000004ooooool0003o0000ooooo`;o00001?ooool2o`00023ooooo
0_l00006ooooo`;o00002_ooool2o`0000;ooooo0_l00008ooooo`Co0000>?ooool00003ooooool0
003ooooo00;ooooo00?o0000ooooooooool02Oooool01?m4A4CogMgMooooool00007ooooo`?o0000
@?ooool2o`0001Kooooo0_l00005ooooo`;o00001_ooool2o`0000?ooooo8?l00007ooooo`;o0000
3_ooool4o`000004ooooool0003o0000ooooo`;o00000_ooool3o`0000Cooooo0_l00004ooooo`?o
000000Coooooo`000?l0003ooooo0_l00004ooooo`;o00009_ooool4o`0000Cooooo0_l00004oooo
o`;o0000B?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?oMgMgo
EEEEooooool00007ooooo`03o`000?oooooooooo03Oooooo0_l00004ooooo`;o000000Coooooo`00
0?l0003o00002Oooool2o`00017ooooo0ol00005ooooo`;o000000?oooooo`000?l000003_l00000
0ooooooo0000o`00000?o`0001Gooooo1_l00002ooooo`Co00000oooool2o`0000;ooooo0_l00005
ooooo`;o00002?ooool2o`0001Cooooo1?l00005ooooo`;o00002oooool2o`0000Kooooo0ol0001=
ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co0000
00Oooooo00?o0000ooooooooool0=oooool2o`0000?ooooo0ol00002ooooo`;o00002Oooool2o`00
0003ooooool0003o000000oooooo0_l00008ooooob7o00005_ooool5o`0000?ooooo0_l00004oooo
o`?o00000_ooool2o`0000?ooooo1_l000000ooooooo0000o`000003ooooo`;o00005?ooool4o`00
00Gooooo0_l0000Dooooo`;o00003oooool2o`0003cooooo00001_ooooooMgMgoiRHV?ooooooV9RH
ogMgM`cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0looooo`;o00004Oooool2
o`0000Sooooo0_l0000Boooooaoo00005oooool3o`0000Wooooo0ol00007ooooo`;o00000_ooool2
o`000004ooooool0003o0000o`0000kooooo0_l000000ooooooo0000o`000006ooooo`;o000000?o
ooooo`000?l000000_l00007ooooo`;o00006?ooool2o`0000Gooooo0_l0000looooo`0000Kooooo
onk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0
>_ooool2o`0000Wooooo0_l000000ooooooo0000o`000008ooooo`;o00001Oooool2o`0001?ooooo
7_l0000@ooooo`;o00004oooool2o`000003ooooool0003o000000?ooooo0_l00006ooooo`?o0000
3Oooool2o`000003ooooool0003o000000Wooooo1?l00007ooooo`;o00000_ooool3o`0000oooooo
0_l00002ooooo`;o000000?oooooo`000?l000000oooool2o`0000gooooo0_l0000/ooooo`007?oo
ool00ol0003oooooooooo`0jooooo`;o00002Oooool5o`000003ooooool0003o000000Gooooo0_l0
0005ooooo`;o00002Oooool2o`0000Sooooo7Ol0000Aooooo`;o00004oooool5o`0000?ooooo1?l0
0005ooooo`?o00002Oooool5o`0000Sooooo0_l0000;ooooo`;o00001?ooool3o`0000oooooo0_l0
0005ooooo`?o00000_ooool2o`0000Gooooo0ol00005ooooo`;o0000;?ooool001cooooo00?o0000
ooooooooool0=oooool2o`0000gooooo0_l00002ooooo`?o00001_ooool2o`0000Cooooo0_l00004
ooooo`;o00000oooool2o`0000Kooooo2?l000000ooooooo0000o`000004o`000003ooooool0003o
000000go00003?ooool2o`0001?ooooo0_l00005ooooo`Go00000oooool2o`0000Cooooo1?l00009
ooooo`?o00002_ooool2o`0000Kooooo0_l00003ooooo`?o00000oooool3o`0000Oooooo0_l0000>
ooooo`;o00002Oooool3o`0003?ooooo000Looooo`03o`000?oooooooooo03Oooooo0_l0000Aoooo
o`;o00001oooool4o`0000Sooooo0_l0000;oooooaoo00003?ooool2o`0000Kooooo0_l00008oooo
o`;o000000?oooooo`000?l000001Oooool5o`0000Wooooo0_l0000:ooooo`;o000000Coooooo`00
0?l0003o00004?ooool3o`0000?ooooo0_l000000ooooooo0000o`000003o`0000Oooooo0_l0001?
ooooo`007?ooool00ol0003oooooooooo`0nooooo`Co000000?oooooo`000?l000001_ooool2o`00
00?ooooo0_l000000ooooooo0000o`000002o`0001Wooooo1Ol000000ooooooo0000o`00000?o`00
0003ooooool0003o000000Gooooo0_l00004ooooo`;o00001Oooool2o`000003ooooool0003o0000
00Sooooo0_l00004ooooo`Ko00001Oooool2o`0000Kooooo0_l00009ooooo`;o000000?oooooo`00
0?l000001Ol000001?oooooo0000o`000?l00009ooooo`;o00000oooool2o`000003ooooool0003o
000000Co00001Oooool3o`0000Oooooo0_l0000@ooooo`;o00003?ooool2o`0002Kooooo000Loooo
o`03o`000?oooooooooo03kooooo1?l000001?oooooo0000o`000?l00005ooooo`;o00000oooool2
o`000003ooooool0003o000000;o00004oooool3o`0000?ooooo5ol000000ooooooo0000o`000005
ooooo`;o00001?ooool2o`000003ooooool0003o000000;ooooo0_l00008ooooo`?o00001_ooool4
o`0000Gooooo1?l00004ooooo`Co00002Oooool2o`0000?ooooo2_l00007ooooo`;o00001?ooool2
o`0000Gooooo0_l00005ooooo`?o00001_ooool3o`00013ooooo0_l0000<ooooo`;o00009_ooool0
01cooooo00?o0000ooooooooool0@?ooool2o`0000;ooooo0_l00002ooooo`Co00005Oooool2o`00
00?ooooo0_l00002ooooo`?o00001?ooool=o`0000;ooooo1_l00003ooooo`;o00002oooool4o`00
00cooooo1Ol00003ooooo`;o00002?ooool3o`000003ooooool0003o000000;ooooo0_l00009oooo
o`?o00001?ooool;o`0000Gooooo0ol00002ooooo`;o00005oooool2o`0004Oooooo000Looooo`03
o`000?oooooooooo04;ooooo0_l00003ooooo`Go00005Oooool2o`0000?ooooo0_l00004ooooo`;o
00000oooool=o`000005ooooool0003o0000o`000?ooool00_l000001?oooooo0000o`000?ooool2
o`0000Kooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l0000<ooooo`;o00000oooool2
o`000004ooooool0003o0000ooooo`;o00000oooool2o`000003ooooool0003o000000gooooo1?l0
0002ooooo`Oo000000?oooooo`000?l000000ol00004ooooo`Co000000?oooooo`000?l000001_oo
ool2o`0000Gooooo0_l0000Nooooo`;o0000<Oooool001cooooo00?o0000ooooooooool0<?ooool4
o`0000kooooo1?l000000ooooooo0000o`00000>ooooo`;o00004oooool2o`0000Gooooo0_l00000
0ooooooo0000o`00000:o`000004ooooool0003o0000ooooo`;o00001_ooool2o`000004ooooool0
003o0000ooooo`;o00001Oooool2o`00017ooooo0_l000000ooooooo0000o`000003o`0001Gooooo
3_l00002ooooo`Go00001?ooool2o`0000Wooooo0_l00002ooooo`;o000000?oooooo`000?l00000
0oooool2o`0001Wooooo0_l0000aooooo`007?ooool00ol0003oooooooooo`0`ooooo`Co00003?oo
ool2o`0000;ooooo0_l00002ooooo`;o00003Oooool2o`0000Sooooo0_l0000@ooooo`So00000_oo
ool4o`0000;ooooo0_l000000ooooooo0000o`000006ooooo`;o00001?ooool2o`0000_ooooo0_l0
000@ooooo`;o000000?oooooo`000?l000005?oooolFo`0000?ooooo0_l00006ooooo`;o00001?oo
ool2o`0000;ooooo0_l00002ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0<?ooool2
o`0000Cooooo0_l000000ooooooo0000o`000005ooooo`;o00000_ooool2o`0000;ooooo0_l0000B
ooooo`;o00000oooool2o`0000Wooooo0_l00004ooooo`Wo00000_ooool3o`00027ooooo0_l00004
ooooo`;o000000?oooooo`000?l000002_ooool2o`0000cooooo0_l00006oooooa;o000000?ooooo
o`000?l000001_l00006ooooo`;o00002?ooool2o`0000Sooooo0_l0000?ooooo`;o00001?ooool2
o`0002oooooo000Looooo`03o`000?oooooooooo03Kooooo1ol0000Oooooo`;o00002Oooool2o`00
00?ooooo0_l00003ooooo`Co00002?ooool2o`0000Gooooo0_l00003ooooo`;o00007?ooool2o`00
0003ooooool0003o000001Sooooo0_l000000ooooooo0000o`000003ooooo`oo000000Coooooo`00
0?l0003o00000_ooool4o`0000?ooooo0ol0000Fooooo`;o00003oooool2o`0000?ooooo0ol0000_
ooooo`007?ooool2o`0003Sooooo0_l00002ooooo`;o00001Oooool2o`0002?ooooo0_l00008oooo
o`Co00003oooool2o`0000?ooooo0_l00002ooooo`;o00003_ooool2o`0001Oooooo0_l00003oooo
o`;o00002_oooolBo`000003ooooool0003o000000?o00001?ooool2o`000003ooooool0003o0000
00?o00003oooool2o`000003ooooool0003o000001Sooooo0_l0000`ooooo`007?ooool00ol0003o
ooooooooo`12ooooo`Co00000_ooool2o`0000Wooooo0_l0000Kooooo`;o00002oooool2o`0000ko
oooo0_l00003ooooo`;o00002Oooool2o`0000;ooooo1?l00006ooooo`;o00001_ooool2o`000003
ooooool0003o000000?ooooo0_l00007ooooo`;o00000_oooolJo`000004ooooool0003o0000oooo
o`Ko000000?oooooo`000?l000002oooool2o`000003ooooool0003o000000Gooooo0_l00003oooo
o`;o0000?_ooool001cooooo00?o0000ooooooooool0@oooool3o`0000;ooooo0_l00003ooooo`;o
00001?ooool2o`0000oooooo0_l00004ooooo`;o00001?ooool4o`0000Wooooo0ol000000ooooooo
0000o`00000<ooooo`;o000000?oooooo`000?l000002oooool6o`0000Kooooo0_l00006ooooo`?o
00002oooool2o`000003ooooool0003o000001oo00000oooool4o`000004ooooool0003o0000o`00
00?ooooo0_l00008ooooo`Co00000_ooool3o`0000?ooooo0_l0000nooooo`007?ooool00ol0003o
ooooooooo`1;ooooo`Co00004?ooool2o`0000?ooooo0_l00004ooooo`;o00001?ooool5o`0000?o
oooo0_l00003ooooo`Ko00003?ooool2o`0000Sooooo0ol00003ooooo`;o00004oooool2o`0000_o
oooo0_l00003ooooo`;o000000?oooooo`000?l000006_l00004ooooo`;o00000oooool4o`000003
ooooool0003o000000Kooooo1_l000000ooooooo0000o`000003o`0000Sooooo0_l0000hooooo`00
7?ooool00ol0003oooooooooo`0dooooo`;o00005?ooool3o`0001;ooooo0_l00005ooooo`;o0000
2oooool2o`0000?ooooo1?l00004ooooo`;o00003Oooool2o`0000Sooooo0ol00006ooooo`;o0000
2Oooool2o`0001Cooooo0_l00004oooooago00000oooool2o`0000Gooooo0_l00002ooooo`;o0000
1Oooool2o`0000Gooooo0_l000000ooooooo0000o`000008ooooo`;o0000>?ooool001cooooo00?o
0000ooooooooool0=?ooool2o`0001;ooooo1?l00006ooooo`;o00004_ooool2o`0000Sooooo0_l0
00000ooooooo0000o`000005ooooo`;o00002oooool2o`0000?ooooo0_l00007ooooo`?o000000?o
ooooo`000?l000000oooool2o`0000;ooooo0_l00009ooooo`;o00004Oooool2o`000003ooooool0
003o000000;o000000?oooooo`000?l000001_l000000ooooooo0000o`00000Co`0000Sooooo0_l0
0004ooooo`;o00009oooool2o`0002[ooooo000Looooo`03o`000?oooooooooo02[ooooo0_l0000F
ooooo`;o00001?ooool2o`000003ooooool0003o000000Gooooo0_l00009ooooo`;o00001?ooool2
o`0000_ooooo0_l0000Eooooo`;o00000oooool4o`0000;ooooo0_l000001Ooooooo0000o`000?l0
003ooooo00;o00000_ooool5o`0000Kooooo0_l0000Fooooo`Co000000?oooooo`000?l000008ol0
0004ooooo`;o00003_ooool2o`0000?ooooo0_l0000Hooooo`;o0000:_ooool001cooooo00?o0000
ooooooooool0:_ooool2o`0000Kooooo0_l0000>ooooo`;o00001oooool2o`00013ooooo0_l00004
ooooo`;o00002Oooool4o`0001cooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool6
o`000003ooooool0003o000000?ooooo1Ol0000>ooooo`Co00001_oooolXo`0000kooooo1?l00002
ooooo`Co000000?oooooo`000?l000004oooool2o`0002oooooo000Looooo`03o`000?oooooooooo
03;ooooo0_l0000]ooooo`;o000000?oooooo`000?l000002?ooool2o`0000Kooooo0_l0000<oooo
o`;o00003?ooool2o`0000Oooooo0_l00008ooooo`Co00000oooool2o`0000[ooooo1?l00008oooo
o`;o00000_oooolMo`0000cooooo0_l00005ooooo`Co00001?ooool4o`0000_ooooo0_l00007oooo
o`;o0000;oooool001cooooo00?o0000ooooooooool0;_ooool2o`0000Cooooo0_l0000Iooooo`;o
00003oooool6o`0000;ooooo0_l0000<ooooo`;o00001?ooool2o`0000Kooooo0_l000000ooooooo
0000o`000009ooooo`;o00001oooool2o`0000oooooo0_l00006ooooo`;o00004?oooolOo`000004
ooooool0003o0000o`0000?ooooo0_l00003ooooo`;o00003oooool2o`000003ooooool0003o0000
00Sooooo0_l0000:ooooo`;o0000;?ooool001cooooo00?o0000ooooooooool0;Oooool3o`0000Co
oooo0_l00007ooooo`;o00004?ooool2o`0000oooooo1?l00004ooooo`;o00004_ooool2o`0000;o
oooo0_l00005ooooo`?o00006_ooool2o`0000kooooo1?l00004ooooo`;o000000Coooooo`000?l0
003ooooo0_l00002oooooako00000_ooool3o`0000?ooooo0_l00006ooooo`;o00003oooool2o`00
00kooooo0_l00004ooooo`;o0000;?ooool001cooooo00?o0000ooooooooool0:_ooool2o`000003
ooooool0003o000000Wooooo0_l00002ooooo`?o00002?ooool2o`0001Oooooo0_l0000Nooooo`;o
00001_ooool2o`0000Gooooo0_l0000Cooooo`;o00001?ooool2o`0000;ooooo0ol00003ooooo`Co
00001?ooool2o`000004ooooool0003o0000ooooo`;o00000_oooolNo`0000;ooooo0_l0000<oooo
o`;o00001?ooool2o`0000[ooooo0_l00003ooooo`;o00002?ooool2o`0000Wooooo0_l0000Woooo
o`007?ooool00ol0003oooooooooo`0Zooooo`;o00003?ooool2o`0000;ooooo1?l00007ooooo`;o
00005?ooool2o`000003ooooool0003o000000[ooooo0_l00009ooooo`;o000000?oooooo`000?l0
00000_ooool2o`0000Sooooo0_l00005ooooo`;o00001_ooool2o`0000Wooooo0_l00003ooooo`;o
000000?oooooo`000?l000000_ooool5o`000003ooooool0003o000000Kooooo0_l00005ooooo`[o
000000?oooooo`000?l000004Ol00007ooooo`;o00000_ooool2o`0000Kooooo0_l00004ooooo`;o
00002_ooool2o`0000;ooooo1Ol0000=ooooo`;o00000_ooool2o`0002Oooooo000Looooo`03o`00
0?oooooooooo02cooooo0_l00007ooooo`;o000000Coooooo`000?l0003o00000oooool2o`0000Co
oooo0_l0000Fooooo`?o000000?oooooo`000?l000002_ooool3o`0000;ooooo0_l00004ooooo`;o
000000?oooooo`000?l000000_ooool2o`0000kooooo0_l00007ooooo`;o00002Oooool2o`0000?o
oooo0_l00003ooooo`Co000000?oooooo`000?l000002?ooool3o`0000Gooooo7_l00007ooooo`;o
00000_ooool2o`000003ooooool0003o000000Wooooo0_l0000>ooooo`;o000000?oooooo`000?l0
00003Oooool2o`0002_ooooo000Looooo`03o`000?oooooooooo02cooooo0_l00007ooooo`;o0000
0_ooool2o`0000Kooooo0_l000000ooooooo0000o`00000:ooooo`;o00002_ooool2o`0000;ooooo
0_l00002ooooo`;o00001oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0001;ooooo
0_l0000:ooooo`?o00003oooool4o`0000?ooooo0_l00005ooooo`?o00001ooooolLo`0000oooooo
0_l0000Mooooo`;o00003Oooool2o`0002[ooooo000Looooo`03o`000?oooooooooo02Wooooo0_l0
0006ooooo`;o00003_ooool2o`0000;ooooo0_l00009ooooo`;o00004_ooool2o`000003ooooool0
003o000000gooooo0_l00002ooooo`Co00003?ooool5o`0000Gooooo1Ol000001?oooooo0000o`00
0?l0000=ooooo`;o00000_ooool2o`0000?ooooo1?l00003ooooo`;o00002ooooolAo`000003oooo
ool0003o000000Go00003?ooool4o`0000oooooo1_l00009ooooo`;o00003Oooool2o`0002[ooooo
000Looooo`;o0000:_ooool2o`0000Kooooo0_l00004ooooo`;o00002oooool3o`0001Kooooo0_l0
0008ooooo`;o00003_ooool2o`0000;ooooo1Ol0000:ooooo`Ko00001?ooool8o`0000Sooooo0ol0
0003ooooo`Co000000?oooooo`000?l000001?ooool2o`0000kooooo6?l0000:ooooo`;o00000ooo
ool4o`0000oooooo1_l00014ooooo`007?ooool00ol0003oooooooooo`0Looooo`;o00005Oooool2
o`0000;ooooo0ol00002ooooo`;o00001_ooool2o`0000Kooooo0ol0000>ooooo`;o00000_ooool3
o`0000_ooooo0ol00005ooooo`;o00001Oooool2o`0000_ooooo0_l000000ooooooo0000o`000005
ooooo`;o00000_ooool3o`0000Sooooo1Ol00003ooooo`;o000000?oooooo`000?l000004ooooolJ
o`0000Wooooo0_l00006ooooo`;o00003Oooool4o`0004Oooooo000Looooo`03o`000?oooooooooo
01cooooo0_l0000Eooooo`;o00000oooool2o`0000;ooooo1?l0000<ooooo`?o00003_ooool9o`00
00Wooooo0ol00004ooooo`;o00002?ooool2o`0000Kooooo0_l0000;ooooo`;o000000?oooooo`00
0?l000000_l0000;ooooo`Co00002_ooool2o`0000Gooooo0ol00004oooooa_o00004?ooool3o`00
00gooooo0_l0000=ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0<_ooool2o`0000Ko
oooo0_l00002ooooo`Co00003_ooool2o`0000Oooooo0ol000000ooooooo0000o`000008o`0000;o
oooo0ol0000:ooooo`;o00000oooool2o`0000;ooooo0ol00006ooooo`;o00000_ooool2o`0000Go
oooo0_l00002ooooo`Go00003Oooool2o`0000[ooooo0_l00003ooooo`Oo00000_oooolHo`000003
ooooool0003o0000013ooooo0_l00003ooooo`;o00001Oooool4o`0000Oooooo1_l00002ooooo`;o
0000>_ooool001cooooo00?o0000ooooooooool0<_ooool4o`0000Cooooo1?l00002ooooo`;o0000
3_ooool2o`0000Oooooo3ol000001?oooooo0000o`000?l0000?ooooo`;o00000_ooool2o`0000_o
oooo0_l00005ooooo`;o00000_ooool2o`000003ooooool0003o000001Cooooo0_l00008ooooo`;o
00000oooool2o`0000Gooooo5Ol00006ooooo`;o00001?ooool2o`0000[ooooo0_l00005ooooo`Co
00001_ooool7o`0003kooooo000Looooo`03o`000?oooooooooo03?ooooo1Ol00004ooooo`;o0000
1_ooool2o`0000gooooo0_l000000ooooooo0000o`000002oooooa;o00003_ooool2o`0000Kooooo
0_l00009ooooo`;o00006oooool2o`000003ooooool0003o000000?o00005ooooolCo`0000Gooooo
0_l00004ooooo`Co00003Oooool2o`0000?ooooo0_l00005ooooo`;o0000@oooool001cooooo00?o
0000ooooooooool07_ooool2o`0001?ooooo0_l000000ooooooo0000o`000002o`0000[ooooo1?l0
0004ooooo`;o00001Oooool5o`0000;ooooo4Ol0000?ooooo`;o00000oooool7o`0000Oooooo0_l0
0004ooooo`;o00005Oooool2o`000004ooooool0003o0000o`0000Kooooo0_l00006ooooo`;o0000
1Oooool2o`0000Cooooo0ol000000ooooooo0000o`00000=o`0000_ooooo0_l00006ooooo`;o0000
0oooool4o`0000?ooooo0_l00005ooooo`Co00001Oooool2o`0003[ooooo000Looooo`03o`000?oo
oooooooo01kooooo0_l0000<ooooo`;o00002_ooool2o`0000cooooo0_l000001?oooooo0000o`00
0?ooool2o`0000;ooooo0_l00002ooooo`?o00000_oooolFo`00013ooooo1ol00008ooooo`;o0000
00?oooooo`000?l000000_l00005ooooo`;o00001?ooool4o`0000Kooooo0_l0000:ooooo`;o0000
0oooool2o`000003ooooool0003o000000Gooooo0_l00002ooooo`Ko000000Coooooo`000?l0003o
oooo1Ol000000ooooooo0000o`000003o`0000?ooooo0_l00004ooooo`;o00002?ooool2o`0000?o
oooo0_l00003ooooo`;o00001?ooool7o`0000Gooooo1?l000000ooooooo0000o`000004ooooo`;o
0000;oooool001cooooo00?o0000ooooooooool0;?ooool2o`0000gooooo0_l0000<ooooo`;o0000
1Oooool2o`0000;ooooo0ol00002oooooaKo00000oooool4o`0000Wooooo0_l0000=ooooo`;o0000
00?oooooo`000?l000001oooool2o`0000Cooooo1?l00006ooooo`;o00000oooool2o`0000Kooooo
0_l00002ooooo`;o00000oooool4o`0000Cooooo1ol00004ooooo`[o00001?ooool2o`0000Cooooo
0_l00007ooooo`;o00002Oooool3o`0000?ooooo1?l00005ooooo`;o00000oooool2o`000003oooo
ool0003o000000;ooooo1?l0000_ooooo`007?ooool00ol0003oooooooooo`0kooooo`;o00005_oo
oolEo`000003ooooool0003o000000?o000000Coooooo`000?l0003ooooo1?l00009ooooo`;o0000
2?ooool2o`000003ooooool0003o000000Gooooo0_l00007ooooo`;o00002_ooool2o`0000Gooooo
0_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000001?ooool6o`0000;ooooo
0_l000000ooooooo0000o`000002o`0000?ooooo0_l00004ooooo`;o000000?oooooo`000?l00000
4?ooool2o`000003ooooool0003o000000Cooooo0_l00003ooooo`?o00003?ooool2o`0000[ooooo
0_l0000aooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o000000?oooooo`000?l000001ooo
ool4o`000004ooooool0003o0000ooooo`;o00003_oooolNo`0000kooooo0_l00004ooooo`;o0000
0_ooool2o`000003ooooool0003o000000Gooooo0_l00005ooooo`Co00001_ooool2o`0000;ooooo
0_l000001?oooooo0000o`000?l00004ooooo`;o00001_ooool2o`0000;ooooo0_l00004ooooo`;o
00001_ooool2o`0000Cooooo0_l0000=ooooo`;o00002_ooool2o`0000Oooooo0_l00002ooooo`Co
00001Oooool2o`0000?ooooo0_l00002ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0
;oooool2o`000003ooooool0003o000000Wooooo0_l000001?oooooo0000o`000?ooool2o`0001;o
oooo6_l00003ooooo`;o00000oooool2o`0000[ooooo0_l0000Cooooo`;o00002?ooool3o`0000Co
oooo0ol00002ooooo`;o00003?ooool2o`0000oooooo0_l00004ooooo`;o00002_ooool2o`0001Oo
oooo1?l00005ooooo`;o00000oooool2o`0000;ooooo0_l00009ooooo`;o0000<?ooool001cooooo
00?o0000ooooooooool0=Oooool6o`0000;ooooo0ol0000<ooooo`;o00002?ooool=o`000003oooo
ool0003o000000_o00000oooool2o`0000?ooooo0_l0000Oooooo`;o00000_ooool2o`0000Gooooo
0_l000000ooooooo0000o`000006ooooo`?o00001?ooool2o`0000?ooooo0ol00008ooooo`Co0000
0oooool3o`0000Cooooo0_l0000>ooooo`;o00006?ooool2o`0001Cooooo1_l0000^ooooo`007?oo
ool00ol0003oooooooooo`0eooooo`Ko00000oooool2o`0000;ooooo0_l00002ooooo`;o00001?oo
ool2o`0000Oooooo6ol00004ooooo`?o00001oooool4o`0000Kooooo0_l00002ooooo`;o00003?oo
ool2o`0000;ooooo0_l00008ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Cooooo0ol0
0002ooooo`?o00001?ooool3o`000003ooooool0003o000000Co000000Coooooo`000?l0003o0000
2?ooool4o`0000Sooooo0_l00008ooooo`?o00002?ooool2o`0000?ooooo0_l00005ooooo`;o0000
0oooool2o`0000Sooooo0_l000001?oooooo0000o`000?l0000^ooooo`007?ooool00ol0003ooooo
ooooo`0[ooooo`;o00003_ooool2o`0000Gooooo0_l00002ooooo`;o00003Oooool3o`000003oooo
ool0003o000001Oo00000_ooool3o`0000Oooooo1?l00006ooooo`;o00000_ooool2o`0000;ooooo
0_l0000<ooooo`Co00001?ooool2o`0000?ooooo0_l00003ooooo`;o00001_ooool3o`0000Sooooo
1Ol000000ooooooo0000o`000002o`0000;ooooo0_l00008ooooo`Co00004Oooool4o`0000;ooooo
0_l00004ooooo`Co00001?ooool3o`000003ooooool0003o000000?ooooo0_l0000looooo`007?oo
ool00ol0003oooooooooo`0[ooooo`;o00003?ooool4o`0000Oooooo0_l0000@oooooaco00003?oo
ool2o`0000gooooo0_l000000ooooooo0000o`00000>ooooo`;o00000_ooool5o`0000?ooooo1_l0
0007ooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`?o000000Goooooo`000?l0003o
0000ooooo`04o`0000Gooooo0_l000000ooooooo0000o`00000Cooooo`;o00001?ooool4o`0000Co
oooo0_l000001?oooooo0000o`000?ooool3o`0000cooooo0_l0000fooooo`007?ooool2o`0003[o
oooo0_l00002ooooo`;o00001Oooool2o`0000cooooo0_l00002oooooaSo000000?oooooo`000?l0
00002Oooool6o`0000gooooo0_l0000>ooooo`;o000000?oooooo`000?l000001ol00003ooooo`Ko
00001oooool2o`000004ooooool0003o0000ooooo`;o00002Oooool2o`000004ooooool0003o0000
o`0000Cooooo1?l000001?oooooo0000o`000?ooool4o`0000Gooooo0_l00006ooooo`;o00001ooo
ool3o`0000Kooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000Gooooo0_l0
000fooooo`007?ooool00ol0003oooooooooo`0mooooo`Co00004Oooool2o`0000Cooooo0_l00000
0ooooooo0000o`00000Do`0000Wooooo1?l0000Oooooo`;o00000oooool3o`000003ooooool0003o
000000Gooooo0_l0000:ooooo`;o00001Oooool2o`0000cooooo1?l00002ooooo`Co000000Cooooo
o`000?l0003ooooo1?l00005ooooo`;o000000Coooooo`000?l0003ooooo1?l00003ooooo`;o0000
00?oooooo`000?l000001?l00008ooooo`;o00000_ooool2o`000003ooooool0003o000000Wooooo
0_l000000ooooooo0000o`00000_ooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00001Ooo
ool2o`0000Sooooo0_l00009oooooaGo00003oooool2o`000003ooooool0003o000000?ooooo0ol0
000Eooooo`;o00000oooool3o`0000;ooooo1_l00004ooooo`;o00002oooool2o`0000Gooooo0_l0
0007ooooo`;o00001?ooool2o`00013ooooo0_l000000ooooooo0000o`000005ooooo`;o000000?o
ooooo`000?l000000_ooool4o`0000Cooooo0_l00007ooooo`;o00002Oooool2o`000003ooooool0
003o000002oooooo000Looooo`03o`000?oooooooooo03cooooo0_l00008ooooo`;o00002?ooool2
o`0000?ooooo0_l00003oooooa?o000000?oooooo`000?l000003oooool2o`000003ooooool0003o
000000?ooooo0ol00009ooooo`;o00000_ooool2o`0000?ooooo1Ol00002ooooo`Co00000_ooool6
o`0000Cooooo0_l0000Booooo`;o00009_ooool2o`000003ooooool0003o000000?ooooo0_l00002
ooooo`;o00001?ooool2o`0004Kooooo000Looooo`03o`000?oooooooooo02gooooo0_l0000=oooo
o`?o00001_ooool2o`0000_ooooo0_l000001?oooooo0000o`000?l00002oooooa?o00001?ooool2
o`0000;ooooo0_l0000;ooooo`;o00003oooool8o`000003ooooool0003o000000;o00000oooool=
o`0000Cooooo0_l00009ooooo`;o00002?ooool2o`0000Gooooo0_l0000Mooooo`;o000000?ooooo
o`000?l000000oooool2o`0000;ooooo0_l00004ooooo`;o00000oooool2o`0000Cooooo0_l00004
ooooo`;o0000=Oooool001cooooo00?o0000ooooooooool0;Oooool2o`0000kooooo0ol00005oooo
o`;o00002Oooool4o`0000;ooooo1ol000000ooooooo0000o`00000<o`0000Gooooo0_l00002oooo
o`;o000000?oooooo`000?l000001Oooool2o`000003ooooool0003o0000017ooooo0_l000001?oo
oooo0000o`000?l00002ooooo`;o000000?oooooo`000?l000003_l00004ooooo`;o00002Oooool2
o`0000Kooooo1?l00005ooooo`;o00002oooool2o`0001cooooo0_l00004ooooo`Co000000Cooooo
o`000?l0003ooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l00000<_oo
ool001cooooo00?o0000ooooooooool0?Oooool3o`00013ooooo0_l00006ooooo`Go000000?ooooo
o`000?l000002?l00002ooooo`;o00001?ooool2o`0000Kooooo0_l00005ooooo`;o000000?ooooo
o`000?l000000oooool2o`0000gooooo0_l000000ooooooo0000o`000003o`0000;ooooo2?l00000
0ooooooo0000o`000009o`0000Gooooo0_l00005ooooo`;o00001?ooool5o`0000;ooooo0_l00003
ooooo`;o00001?ooool2o`0000?ooooo0_l0000Sooooo`?o00001?ooool2o`0000[ooooo0_l0000b
ooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00001oooool2o`0001oooooo0ol00003oooo
o`;o000000?oooooo`000?l000001?ooool2o`0000Gooooo0_l000000ooooooo0000o`000003oooo
o`;o00001Oooool2o`0000Kooooo0_l0000;ooooo`Co000000?oooooo`000?l000001Ol00005oooo
o`Oo00001?ooool8o`000003ooooool0003o000000Gooooo0ol00002ooooo`Co00001?ooool3o`00
00;ooooo0_l00004ooooo`;o00007Oooool2o`0000Wooooo0_l00015ooooo`007?ooool00ol0003o
ooooooooo`0`ooooo`;o00001oooool3o`0000oooooo0ol00007ooooo`;o00001?ooool3o`0000Go
oooo0_l00004ooooo`;o000000?oooooo`000?l000001?ooool3o`0000Gooooo0_l00006ooooo`;o
00004?ooool6o`0000?ooooo0ol000000ooooooo0000o`000008o`0000Kooooo3_l00002ooooo`;o
00000_ooool4o`0000Gooooo0_l00002ooooo`;o00000oooool2o`0000Oooooo0_l0000Cooooo`Co
00002Oooool2o`0000Kooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0eooooo`;o0000
00?oooooo`000?l000000ol0000>ooooo`?o00001oooool2o`0000Gooooo0_l00002ooooo`?o0000
1?ooool2o`0000?ooooo1?l00002ooooo`?o00001Oooool2o`0000Kooooo0ol0000:ooooo`;o0000
1Oooool5o`0000;ooooo2Ol00002ooooo`?o000000?oooooo`000?l000000_l00002ooooo`go0000
3?ooool2o`0000Gooooo0_l00002ooooo`?o00001Oooool4o`0001?ooooo0_l00004ooooo`;o0000
3Oooool2o`0000?ooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0eooooo`;o000000Co
ooooo`000?l0003ooooo0_l0000Dooooo`?o00003?ooool3o`0000Cooooo0_l00003ooooo`Co0000
1oooool2o`0000[ooooo0_l0000:ooooo`;o00001?ooool6o`0000;ooooo1Ol000000ooooooo0000
o`000002o`000005ooooool0003o0000o`000?ooool01?l00004ooooo`;o00000_ooool2o`000003
ooooool0003o000000Wooooo0_l00003ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Ko
oooo0_l0000Kooooo`;o00002_ooool2o`0000Kooooo0_l0000hooooo`007?ooool00ol0003ooooo
ooooo`0eooooo`;o00001?ooool2o`000003ooooool0003o0000017ooooo0ol00002ooooo`;o0000
4oooool3o`000003ooooool0003o000000;o00001?ooool3o`0000kooooo0_l00006ooooo`Co0000
00Coooooo`000?l0003ooooo0ol00002ooooo`Co00000oooool3o`000003ooooool0003o000000[o
00000_ooool2o`000003ooooool0003o000000Oooooo0_l00002ooooo`;o00000oooool2o`000003
ooooool0003o000000?ooooo0_l0000Vooooo`;o00002_ooool2o`00043ooooo000Looooo`03o`00
0?oooooooooo03Gooooo1?l00002ooooo`;o000000?oooooo`000?l000003?ooool2o`0000Kooooo
1?l00009ooooo`;o00001_ooool:o`0000Gooooo0_l00004ooooo`;o00000oooool2o`0000?ooooo
0_l00005ooooo`co00000_oooolQo`0000Cooooo0_l00007ooooo`;o00001_ooool2o`000003oooo
ool0003o000000gooooo0_l0000Mooooo`;o00002_ooool2o`0003Oooooo000Looooo`03o`000?oo
oooooooo03Oooooo0_l0000Cooooo`;o00001_ooool2o`0000Gooooo1?l00002ooooo`;o000000?o
ooooo`000?l000000oooool2o`0000;ooooo0_l000001?oooooo0000o`000?l00002ooooo`Oo0000
0_ooool2o`000003ooooool0003o000000;o00002_ooool2o`0000?ooooo1?l000000ooooooo0000
o`00000Oo`000004ooooool0003o0000o`0000;ooooo0_l00006ooooo`;o000000Coooooo`000?l0
003ooooo0_l00006ooooo`;o000000?oooooo`000?l000002_ooool2o`0001gooooo0_l0000:oooo
o`;o0000=oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo04Kooooo1?l000000ooooooo0000o`00
000>ooooo`Co00001Oooool2o`0000;ooooo0ol00005ooooo`Co000000?oooooo`000?l000001_l0
0004ooooo`;o00003ooooolXo`0000Kooooo1?l00004ooooo`;o000000?oooooo`000?l000000ol0
0002ooooo`;o00000_ooool2o`000003ooooool0003o000000?ooooo0_l0000Xooooo`;o0000?ooo
ool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMgMooooooo
V9RHob4Q8@06ooooo`03o`000?oooooooooo04;ooooo0_l00002ooooo`_o00001Oooool2o`0000;o
oooo0_l00002ooooo`;o00002?ooool5o`0000Cooooo1_l00003ooooo`?o00005?oooolXo`0000Wo
oooo0_l00008ooooo`;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o
00007oooool2o`0000Kooooo0ol0000oooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooo
ooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0dooooo`;o
00001Oooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l000000ooooooo
0000o`000002o`0000Gooooo0_l00002ooooo`;o00000_ooool2o`0000Cooooo0_l00005ooooo`;o
000000?oooooo`000?l000000oooool4o`0000Sooooo0_l00003ooooo`;o00002oooool3o`000003
ooooool0003o000001go000000?oooooo`000?l000001?l0000Aooooo`;o00000_ooool2o`00013o
oooo0ol0000Booooo`?o00001Oooool2o`0000Kooooo0_l00010ooooo`0000?oooooo`000?ooool0
0_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0003Co
oooo0_l00005ooooo`;o00000_ooool2o`0000?ooooo1?l00002ooooo`;o00002_ooool2o`0000co
oooo0_l000000ooooooo0000o`000005ooooo`;o00003oooool3o`000003ooooool0003o000000;o
00002Oooool5o`000003ooooool0003o000001Co000000?oooooo`000?l000001?l00002ooooo`Ko
00002?ooool2o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o00004?ooool3o`0001;o
oooo0ol00008ooooo`;o00000_ooool3o`00043ooooo00000ooooooo0000ooooo`02ooooo`03o`00
0?oooooooooo00Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo03Wo
oooo1?l00002ooooo`;o00001Oooool2o`0000;ooooo0ol00009ooooo`;o00003oooool2o`000003
ooooool0003o000000Cooooo0_l0000<ooooo`Co000000?oooooo`000?l000000_l00009ooooo`Go
00000_oooolQo`000004ooooool0003o0000o`0000Oooooo0_l00004ooooo`;o000000?oooooo`00
0?l000001_ooool2o`0002cooooo0_l00002ooooo`;o0000@Oooool00003ooooool@413ooooo00;o
oooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo03Wo
oooo0_l0000=ooooo`Go00007Oooool2o`000004ooooool0003o0000ooooo`Go00002Oooool2o`00
00Cooooo0_l0000:ooooo`[o000000?oooooo`000?l000007ol00003ooooo`Co00001oooool2o`00
00Sooooo0_l0000Xooooo`;o0000BOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool0
0ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo03Kooooo0_l0000<ooooo`;o00000_ooool2
o`0000;ooooo0_l0000=ooooo`;o00004?ooool2o`0000?ooooo1?l0000:ooooo`Oo00000oooool3
o`0000?ooooo0ol00002ooooo`Co000000?oooooo`000?l000006_l000000ooooooo0000o`000004
ooooo`Ko00001oooool6o`0002gooooo0ol00003ooooo`?o0000@oooool00006ooooooo^k^ko<S8b
o`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo03Kooooo
0_l0000<ooooo`;o00001_ooool2o`0000Kooooo0_l00005ooooo`;o00003?ooool2o`0000Cooooo
0_l00003ooooo`;o00002Oooool5o`000003ooooool0003o000000?ooooo0ol00003oooooa?o0000
00?oooooo`000?l000000ol00002ooooo`_o00001?ooool5o`0000gooooo1?l0000?ooooo`;o0000
7?ooool2o`0000Cooooo0ol00013ooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00002Ooo
ool2o`00013ooooo0_l0000<ooooo`;o00001Oooool2o`0000?ooooo0ol00004ooooo`;o00000ooo
ool2o`0000?ooooo0_l00004ooooo`;o00001oooool2o`0000;ooooo9Ol00003ooooo`Go00008?oo
ool4o`0001Cooooo0_l0000;ooooo`;o00000oooool2o`0003kooooo000Looooo`03o`000?oooooo
oooo03Oooooo0_l00005ooooo`;o00000_ooool2o`0000Gooooo0_l0000@ooooo`;o00001Oooool2
o`0000Cooooo0_l00004ooooo`;o00001Oooool2o`0000?ooooo0_l00007ooooo`;o00002Oooool2
o`000003ooooool0003o0000017o000000?oooooo`000?l000005?l00002ooooo`;o00008_ooool2
o`0001Cooooo0_l000000ooooooo0000o`000003ooooo`;o00002?ooool2o`0003kooooo000Loooo
o`03o`000?oooooooooo03Oooooo0_l00005ooooo`;o00001?ooool2o`0000?ooooo0_l0000>oooo
o`Co00002oooool2o`000003ooooool0003o0000013ooooo0_l00004ooooo`;o00001oooool3o`00
00;ooooo4_l00002oooooaSo00005?ooool2o`0000cooooo0_l0000Iooooo`;o00000oooool2o`00
00Oooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`14ooooo`?o00002Oooool2o`0000Oo
oooo0_l0000<ooooo`;o00000_ooool2o`0000kooooo1?l00005ooooo`Co000000Coooooo`000?l0
003ooooo1Ol00002ooooo`So00000_ooool3o`000003ooooool0003o000000go00000_ooool6o`00
00?ooooo0_l0000Dooooo`;o00003?ooool2o`0000;ooooo0_l0000Qooooo`Co0000?oooool001co
oooo00?o0000ooooooooool0@?ooool2o`0000?ooooo0_l00009ooooo`;o00003Oooool2o`0000Ko
oooo0_l0000Booooo`Co00001Oooool4o`000003ooooool0003o000000Cooooo0_l00006ooooob;o
00001_ooool4o`0001[ooooo0_l000001?oooooo0000o`000?ooool2o`00017ooooo0_l00004oooo
o`;o00000oooool3o`0000;ooooo0ol00010ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o
00000oooool2o`00017ooooo1_l000001?oooooo0000o`000?l0000Fooooo`?o000000?oooooo`00
0?l000004?ooool6o`000003ooooool0003o000002?o00001Oooool5o`0000kooooo0_l00009oooo
o`;o000000?oooooo`000?l000005?ooool2o`0000Cooooo0_l00003ooooo`?o0000AOooool001co
oooo00?o0000ooooooooool0C_ooool2o`0000Sooooo1ol000000ooooooo0000o`000003ooooo`;o
00002?ooool2o`0000Oooooo0ol000000ooooooo0000o`00000@ooooobKo00000_ooool4o`000003
ooooool0003o000000Gooooo0_l0000>ooooo`;o00000_ooool2o`0000Oooooo0_l0000Looooo`;o
00000oooool3o`0004Cooooo000Looooo`03o`000?oooooooooo03Oooooo0_l00009ooooo`;o0000
2_ooool2o`0000gooooo0_l00004ooooo`Wo00000oooool2o`0000Kooooo0ol00008ooooo`;o0000
0_ooool2o`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l000006Ol000000ooooooo0000
o`000007o`000004ooooool0003o0000o`0001Gooooo0_l00002ooooo`;o00001oooool2o`0001co
oooo0_l00003ooooo`?o0000A?ooool001cooooo00?o0000ooooooooool0=oooool2o`0000Wooooo
0_l00004ooooo`;o00006Oooool2o`000003ooooool0003o000000Co00002oooool3o`0000Sooooo
0ol000000ooooooo0000o`000005oooooaWo000000?oooooo`000?l000001_l000000ooooooo0000
o`000006o`0000;ooooo0ol0000=ooooo`;o00001_ooool2o`0000Sooooo0_l000001?oooooo0000
o`000?ooool2o`0001[ooooo0_l00002ooooo`;o0000AOooool001cooooo00?o0000ooooooooool0
B?ooool2o`0000Sooooo0_l00005ooooo`;o0000:?ooool2o`000003ooooool0003o000000?ooooo
0_l00002ooooo`;o000000?oooooo`000?l000008Ol00002ooooo`;o00000_ooool2o`0000gooooo
0ol0000?ooooo`;o000000?oooooo`000?l000000ol0000Booooo`;o00001_ooool2o`0000Oooooo
0_l00010ooooo`007?ooool00ol0003oooooooooo`1@ooooo`Co00001Oooool2o`0000Sooooo0_l0
0009ooooo`?o000000Coooooo`000?l0003o00002oooool4o`0000Oooooo0_l00002ooooo`;o0000
00?oooooo`000?l00000:_l0000=ooooo`;o00004_ooool4o`0001?ooooo0_l00002ooooo`Ko0000
1oooool2o`00043ooooo000Looooo`;o0000>oooool2o`0001Cooooo0_l0000Aooooo`;o000000?o
ooooo`000?l000000oooool2o`000005ooooool0003o0000o`000?ooool00ol00006ooooo`Co0000
00?oooooo`000?l000000_l0000;ooooo`Oo000000?oooooo`000?l000003ol00002oooooaCo0000
4oooool2o`0000cooooo0_l0000:ooooo`;o00003Oooool8o`0004Oooooo000Looooo`03o`000?oo
oooooooo03[ooooo0_l000000ooooooo0000o`000002o`0000Kooooo0_l00008ooooo`Co00004Ooo
ool2o`0000?ooooo1?l0000<ooooo`Co00000_ooool3o`0000;ooooo0_l00007ooooo`?o00001Ooo
oolRo`0001?ooooo1?l000000ooooooo0000o`00000>ooooo`;o00002?ooool2o`0000;ooooo0_l0
00000ooooooo0000o`000003ooooo`;o00001_ooool3o`0004Oooooo000Looooo`03o`000?oooooo
oooo03gooooo1?l00006ooooo`?o00001oooool4o`00017ooooo2Ol00005ooooo`;o00003?ooool2
o`000004ooooool0003o0000o`0000Kooooo0ol000000ooooooo0000o`000002ooooob?o00002ooo
ool2o`0000Kooooo1?l0000Aooooo`;o00003?ooool5o`0000?ooooo0_l0001@ooooo`007?ooool0
0ol0003oooooooooo`0mooooo`;o00002Oooool4o`0000Cooooo0_l0000Dooooo`So00001_ooool2
o`0000oooooo0_l00005ooooo`Co00000_ooool2o`0000;ooooo8ol0000;ooooo`;o00003Oooool2
o`0001cooooo0_l00007ooooo`;o0000COooool001cooooo00?o0000ooooooooool0?Oooool2o`00
00Oooooo0_l00002ooooo`;o00000_ooool6o`00023ooooo0_l0000?ooooo`;o00001Oooool4o`00
00Kooooo7ol00002ooooo`;o00002Oooool2o`0000;ooooo0_l0000;ooooo`;o000000?oooooo`00
0?l000003oooool4o`0000Kooooo0_l00005ooooo`Co00000_ooool2o`0004Wooooo000Looooo`03
o`000?oooooooooo04Cooooo1Ol00005ooooo`?o000000?oooooo`000?l000005?ooool2o`0000[o
oooo0_l00002ooooo`;o000000?oooooo`000?l000002?ooool4o`0000;ooooo1Ol00002ooooo`;o
00000_ooool=o`000003ooooool0003o000000go000000Coooooo`000?l0003ooooo0_l00002oooo
o`;o00001Oooool2o`0000;ooooo0_l0000;ooooo`;o000000?oooooo`000?l000001oooool2o`00
00Kooooo1?l00003ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Cooooo0_l00019oooo
o`007?ooool00ol0003oooooooooo`0nooooo`;o00001?ooool2o`000003ooooool0003o000000Go
oooo0_l0000Hooooo`;o00002Oooool2o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`;o
00001Oooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`ko000000?oooooo`000?l0
00005?l00003ooooo`Co00005Oooool2o`0000[ooooo0_l00006ooooo`;o00001Oooool2o`000003
ooooool0003o000000Kooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`0nooooo`;o0000
1_ooool3o`0000Gooooo0_l0000Qooooo`Co000000Coooooo`000?l0003o00000_ooool2o`0000;o
oooo0ol0000=ooooo`;o00000ooooolZo`0000kooooo0ol0000<ooooo`Co00002?ooool2o`0000Co
oooo0_l00002ooooo`Co000000?oooooo`000?l000000ol00005ooooo`;o00003oooool2o`0003Ko
oooo000Looooo`03o`000?oooooooooo04Kooooo0_l00003ooooo`;o00009?ooool2o`0000?ooooo
0ol00006ooooo`;o00001?ooool2o`0000Sooooo0_l00004oooooaKo00000_ooool2o`0000;ooooo
3Ol0000>ooooo`?o00001_ooool2o`0000?ooooo1Ol00008ooooo`;o00001?ooool2o`0000;ooooo
1?l000000ooooooo0000o`000002o`0000Kooooo0_l0000?ooooo`;o0000=_ooool001cooooo00?o
0000ooooooooool0A_ooool2o`0000?ooooo0_l00005ooooo`;o00004oooool2o`0000gooooo0_l0
000=ooooo`;o00002oooool2o`0000;ooooo6_l000000ooooooo0000o`000004o`0000Cooooo0ol0
000Fooooo`?o00000oooool2o`0000[ooooo0ol00008ooooo`?o00000_ooool2o`00057ooooo000L
ooooo`03o`000?oooooooooo04Kooooo0_l0000:ooooo`Go00004?ooool2o`0000Wooooo0ol0000B
ooooo`;o00002Oooool2o`0000Cooooo2Ol000000ooooooo0000o`000005o`000005ooooool0003o
0000o`000?ooool00_l000000ooooooo0000o`000002o`0000Kooooo0_l0000Fooooo`?o000000?o
ooooo`000?l000003?ooool3o`0000Wooooo0ol00002ooooo`;o0000DOooool001cooooo00?o0000
ooooooooool0@Oooool2o`0000Gooooo0_l00004ooooo`[o00004_ooool2o`0000Kooooo0ol00004
ooooo`;o00000_ooool2o`0000Sooooo0_l000000ooooooo0000o`000008ooooo`go000000?ooooo
o`000?l000003?l000000ooooooo0000o`000002o`0000[ooooo0_l0000Booooo`;o00000_ooool2
o`0000;ooooo0_l00008ooooo`;o00002_ooool3o`0000Sooooo0_l0001;ooooo`007?ooool00ol0
003oooooooooo`11ooooo`;o00001Oooool2o`0000Cooooo1_l00002ooooo`;o00004_ooool2o`00
00gooooo0_l00002ooooo`;o00002Oooool5o`0000Kooooo1Ol00002ooooo`;o000000?oooooo`00
0?l000005Ol000000ooooooo0000o`000002o`0000Gooooo0ol0000Dooooo`?o00000oooool4o`00
00?ooooo0_l0000<ooooo`Co00001?ooool2o`0000;ooooo0_l0001;ooooo`007?ooool00ol0003o
ooooooooo`0oooooo`;o00008oooool2o`00017ooooo0_l00005ooooo`;o00002?ooool5o`0000Co
oooo1ol00002ooooo`;o00000oooool9o`000003ooooool0003o000000Wo000000?oooooo`000?l0
00000_l00002ooooo`;o000000?oooooo`000?l000002Oooool2o`0000[ooooo0ol00005ooooo`;o
00000oooool3o`0000_ooooo0_l00004ooooo`Co0000Coooool001cooooo00?o0000ooooooooool0
?oooool2o`0000;ooooo1_l0000@ooooo`;o00002Oooool2o`000003ooooool0003o000000kooooo
0ol00002ooooo`Co00002Oooool3o`0000Gooooo0ol00002ooooo`;o00000_ooool2o`000003oooo
ool0003o0000017o000000?oooooo`000?l000001_ooool4o`0000cooooo0_l0000Hooooo`;o0000
4Oooool2o`00057ooooo000Looooo`03o`000?oooooooooo04?ooooo1_l000000ooooooo0000o`00
000=ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Gooooo0_l00007ooooo`;o00001_oo
ool3o`000003ooooool0003o000000Sooooo0_l000000ooooooo0000o`000006ooooo`?o000000?o
ooooo`000?l000000oooool2o`000003ooooool0003o000000Co000000Coooooo`000?l0003ooooo
1?l00003ooooo`;o000000Coooooo`000?l0003o00001Oooool2o`0003Wooooo0_l0001Cooooo`00
7?ooool2o`0004_ooooo0_l00006ooooo`;o000000?oooooo`000?l000001Oooool2o`0000;ooooo
0_l0000>ooooo`?o00001?ooool4o`0000Gooooo0_l00004ooooo`;o000000?oooooo`000?l00000
2_ooool2o`0000?ooooo0_l00005ooooo`;o000000?oooooo`000?l000000_ooool6o`0000Cooooo
1Ol0000=ooooo`?o00008Oooool2o`0000[ooooo0_l0001Cooooo`007?ooool00ol0003ooooooooo
o`15ooooo`;o00002?ooool2o`000004ooooool0003o0000ooooo`;o00001?ooool2o`0000Sooooo
0_l00002ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l0
00000_l00002ooooo`;o000000?oooooo`000?l000006?ooool2o`0000;ooooo1Ol00005ooooo`Ko
00001_ooool3o`000003ooooool0003o000000[ooooo0ol0000@ooooo`;o00003oooool2o`0000_o
oooo0_l0001Booooo`007?ooool00ol0003oooooooooo`15ooooo`;o00000_ooool2o`0000Cooooo
0_l00005ooooo`;o00000_ooool3o`0000Sooooo0_l00002ooooo`;o000000?oooooo`000?l00000
1?l00002ooooo`;o00000_ooool2o`0000?ooooo0_l00005ooooo`Go00000oooool2o`0000_ooooo
2_l00005ooooo`[o00000oooool2o`000003ooooool0003o000001gooooo0_l0000=ooooo`;o0000
3Oooool2o`0005;ooooo000Looooo`03o`000?oooooooooo04Gooooo0_l00002ooooo`;o00001?oo
ool2o`0000Gooooo0_l00002ooooo`?o00003oooool2o`0000;ooooo0_l0000Booooo`Go00000ooo
ool2o`0000_ooooo0_l000000ooooooo0000o`000004ooooo`;o00001?ooool2o`000004ooooool0
003o0000ooooo`Co000000?oooooo`000?l000003oooool2o`000003ooooool0003o000000;o0000
1_ooool2o`0001?ooooo0_l00005ooooo`;o00001Oooool2o`0005?ooooo000Looooo`03o`000?oo
oooooooo04Gooooo0_l00008ooooo`;o00000oooool2o`0001Sooooo1_l0000:ooooo`;o00001Ooo
ool3o`0000Wooooo0_l00004ooooo`;o00002Oooool3o`0000kooooo0_l00007ooooo`;o00001_oo
ool2o`000003ooooool0003o000000Co00001?ooool4o`0001Gooooo0_l000000ooooooo0000o`00
0005ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0Coooool2o`0000;ooooo0ol00004
ooooo`;o00003_ooool2o`0000;ooooo1_l00003ooooo`;o000000?oooooo`000?l000000_ooool2
o`0000Kooooo0_l00005ooooo`;o00000_ooool2o`0000Cooooo1?l000000ooooooo0000o`000002
o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00009ooooo`;o00000_oo
ool2o`0000Sooooo0_l00003ooooo`;o00001_ooool2o`0001Cooooo0ol0001Mooooo`007?ooool0
0ol0003oooooooooo`1?ooooo`;o00000_ooool2o`0000Gooooo0_l00005ooooo`;o00000_ooool2
o`0000?ooooo0_l0000;ooooo`;o000000?oooooo`000?l000001Oooool2o`0000[ooooo0_l00003
ooooo`;o00001Oooool2o`000003ooooool0003o000000;o00001_ooool2o`000004ooooool0003o
0000ooooo`?o00002Oooool2o`0000Wooooo0_l000000ooooooo0000o`000002o`0000Wooooo0_l0
000>ooooo`;o00001?ooool2o`000003ooooool0003o000000?ooooo0_l0001Fooooo`007?ooool0
0ol0003oooooooooo`1?ooooo`;o00004?ooool2o`0000;ooooo0_l0000<ooooo`;o00002?ooool2
o`0000;ooooo0_l00002ooooo`;o00001?ooool2o`0000Gooooo0_l0000Hooooo`?o00002Oooool2
o`0000Wooooo0_l000000ooooooo0000o`000002o`0000Kooooo1Ol0000;ooooo`;o000000?ooooo
o`000?l000001oooool7o`0005Kooooo000Looooo`03o`000?oooooooooo07?ooooo0_l00008oooo
o`;o00000_ooool2o`0000;ooooo0_l00004ooooo`;o00000oooool2o`0000Kooooo1?l0000>oooo
o`Go00001_ooool2o`000003ooooool0003o000000?ooooo0ol00002ooooo`;o00000_ooool2o`00
00Sooooo1?l0000<ooooo`;o00002oooool4o`0005Sooooo000Looooo`03o`000?oooooooooo07;o
oooo0_l00009ooooo`;o00003?ooool2o`0000?ooooo0ol00005ooooo`Co00001oooool2o`0000Go
oooo0_l000000ooooooo0000o`000006ooooo`;o00001_ooool3o`0000;ooooo0_l0000Sooooo`;o
00001?ooool2o`0005[ooooo000Looooo`03o`000?oooooooooo04kooooo1Ol0000@ooooo`;o0000
3Oooool4o`0000;ooooo0_l0000;ooooo`;o00002?ooool6o`0000kooooo0_l0000Nooooo`;o0000
00?oooooo`000?l000002?ooool2o`0000Gooooo0_l0000>ooooo`;o0000H?ooool001cooooo00?o
0000ooooooooool0C_ooool5o`0000oooooo0ol0000;ooooo`;o00000_ooool2o`0000;ooooo0_l0
000;ooooo`;o00002?ooool3o`000003ooooool0003o000001;ooooo0_l00003ooooo`Ko00002?oo
ool3o`0000Kooooo0_l000000ooooooo0000o`000008ooooo`;o00000_ooool2o`000003ooooool0
003o000000;ooooo0_l000001?oooooo0000o`000?ooool2o`0006Kooooo000Looooo`03o`000?oo
oooooooo04kooooo0ol00008ooooo`;o00001oooool2o`0000;ooooo0ol00007ooooo`;o00003ooo
ool2o`0000Gooooo0_l0000:ooooo`;o00003_ooool2o`000003ooooool0003o000000?ooooo1_l0
0008ooooo`Go00005Oooool2o`0000Gooooo0_l000001?oooooo0000o`000?ooool2o`0006Kooooo
000Looooo`03o`000?oooooooooo04oooooo0_l00008ooooo`;o00002oooool3o`0001Sooooo0_l0
0005ooooo`;o00001?ooool2o`0000Cooooo1?l00006ooooo`;o00001?ooool2o`0001Oooooo0_l0
0005ooooo`;o00001?ooool2o`0000Sooooo0_l00008ooooo`;o0000JOooool001cooooo00?o0000
ooooooooool0I_ooool2o`0000?ooooo0_l0000Qooooo`;o00001_ooool2o`0000Kooooo1Ol00000
0ooooooo0000o`00000Jooooo`;o00000_ooool2o`0000Cooooo0_l00005ooooo`;o000000?ooooo
o`000?l00000Loooool001cooooo00?o0000ooooooooool0A_ooool2o`0000Cooooo0_l0000@oooo
o`;o00000oooool2o`000003ooooool0003o000000?ooooo0_l0000Cooooo`;o00001_ooool2o`00
00Kooooo0_l000000ooooooo0000o`000002o`0000Wooooo0ol00005ooooo`;o00003?ooool2o`00
00Sooooo0_l00005ooooo`Co00001_ooool5o`0000gooooo0_l0001Tooooo`007?ooool2o`0004Oo
oooo0_l00004ooooo`;o00004?ooool2o`0000?ooooo0_l000000ooooooo0000o`00000Booooo`;o
00001?ooool4o`0000Cooooo0_l00004ooooo`Co000000?oooooo`000?l000000_l00003ooooo`;o
000000?oooooo`000?l000001Oooool2o`0000;ooooo0_l0000<ooooo`;o00003oooool4o`0000So
oooo0_l00007ooooo`;o00000_ooool2o`000003ooooool0003o000006Cooooo000Looooo`03o`00
0?oooooooooo05kooooo0_l0000:ooooo`;o00002_ooool2o`0000;ooooo0_l00006ooooo`;o0000
2_ooool2o`0000Cooooo1?l00002ooooo`;o000000?oooooo`000?l000001Oooool2o`0000?ooooo
0_l0000Booooo`Co00001_ooool2o`0000Wooooo0_l00008ooooo`Ko0000Ioooool001cooooo00?o
0000ooooooooool0G_ooool2o`0000[ooooo0_l00004ooooo`;o00001?ooool2o`0001;ooooo0_l0
0002ooooo`;o00001?ooool4o`00017ooooo0_l0000Booooo`Co00001_ooool2o`0000Wooooo0_l0
00000ooooooo0000o`000007ooooo`;o0000JOooool001cooooo00?o0000ooooooooool0C_ooool2
o`00023ooooo0_l000000ooooooo0000o`00000Eooooo`Ko0000;Oooool2o`0001Kooooo0_l0000;
ooooo`?o0000I?ooool001cooooo00?o0000ooooooooool0C_ooool2o`0000Sooooo0_l0000:oooo
o`;o00003Oooool2o`0001Oooooo0_l00009ooooo`;o00005oooool3o`0000gooooo0_l00007oooo
o`;o00005oooool3o`0006Cooooo000Looooo`03o`000?oooooooooo05Sooooo0ol00009ooooo`?o
00000oooool2o`0002Kooooo0_l00003ooooo`;o00005Oooool5o`0000?ooooo0_l00008ooooo`?o
00000_ooool2o`0000;ooooo0_l00009ooooo`;o00000oooool2o`0006kooooo000Looooo`03o`00
0?oooooooooo05Wooooo0_l0000:ooooo`?o00000_ooool2o`0001Gooooo1?l00009ooooo`;o0000
0_ooool2o`0000Wooooo0_l0000?ooooo`;o00001_ooool2o`0000?ooooo0_l00004ooooo`;o0000
0_ooool2o`0000Cooooo0_l00007ooooo`;o000000?oooooo`000?l000000_l0001^ooooo`007?oo
ool00ol0003oooooooooo`1Vooooo`;o00006Oooool6o`0000Cooooo1Ol0000<ooooo`Co00001Ooo
ool2o`0000Oooooo0_l0000;ooooo`Co00003?ooool2o`0000[ooooo0_l000001?oooooo0000o`00
0?l0001/ooooo`007?ooool00ol0003oooooooooo`1Tooooo`Co00007Oooool2o`0000Cooooo1?l0
000=ooooo`Co00000_ooool2o`000004ooooool0003o0000o`0001Gooooo0_l0000Kooooo`Go0000
6_ooool2o`0004kooooo000Looooo`03o`000?oooooooooo067ooooo1ol0000Rooooo`Co00004Ooo
ool2o`000003ooooool0003o000000;ooooo0_l00007ooooo`;o00000oooool2o`0000[ooooo0ol0
0003ooooo`Co00002Oooool2o`0000Sooooo0_l0000Jooooo`;o0000C_ooool001cooooo00?o0000
ooooooooool0HOooool7o`0000?ooooo0_l00008ooooo`;o00002?ooool2o`0000Wooooo1?l00007
ooooo`;o00002?ooool2o`0000;ooooo0_l0000:ooooo`;o00000oooool2o`0000Cooooo0_l00003
ooooo`Co00000oooool4o`0000Wooooo1?l0001booooo`007?ooool00ol0003oooooooooo`1Toooo
o`Co000000?oooooo`000?l000000_l00008ooooo`?o00001oooool2o`0000gooooo0_l00005oooo
o`Co00002_ooool2o`0000?ooooo0_l00007ooooo`;o00001Oooool4o`0000?ooooo0_l00005oooo
o`;o00003Oooool2o`0007;ooooo000Looooo`03o`000?oooooooooo06?ooooo0_l00004ooooo`Co
00002Oooool2o`0000cooooo0_l00004ooooo`;o00000_ooool2o`0000Oooooo0_l00005ooooo`;o
00002?ooool2o`0000Cooooo0_l000000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l0
00000_l0000Booooo`;o0000M_ooool001cooooo00?o0000ooooooooool0Hoooool2o`0000Kooooo
0_l0000Gooooo`?o000000?oooooo`000?l000000_l0000Booooo`?o00001Oooool3o`0000Gooooo
0_l0000;ooooo`Co000000?oooooo`000?l000000_ooool5o`0000Sooooo0_l0001fooooo`0000Ko
ooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<
00Kooooo00?o0000ooooooooool0Hoooool2o`0001Oooooo0_l00007ooooo`;o000000Coooooo`00
0?l0003ooooo1?l0000:ooooo`;o00001?ooool4o`0000?ooooo0ol00006ooooo`;o00001?ooool2
o`0000Wooooo0_l00002ooooo`Go00001?ooool4o`0000Gooooo0_l0001aooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo
00?o0000ooooooooool0O?ooool2o`0000Cooooo0_l00007ooooo`Co00000oooool2o`000003oooo
ool0003o000000;ooooo0_l00006ooooo`;o00003?ooool2o`0000Cooooo0_l00008ooooo`Co0000
0_ooool3o`0000?ooooo1_l00005ooooo`;o0000LOooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
M_ooool2o`0000[ooooo0_l0000>ooooo`Go00001?ooool2o`00013ooooo0_l0000?ooooo`Go0000
2?ooool2o`0007cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go
<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000M?ooool4o`0000_ooooo0_l00003ooooo`;o0000
0_ooool2o`000003ooooool0003o000000;ooooo0ol000000ooooooo0000o`000002ooooo`;o0000
1Oooool2o`0000?ooooo0ol00003ooooo`;o00001Oooool2o`0000Gooooo0_l000000ooooooo0000
o`000002o`0001;ooooo0_l0001cooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooooooo
o`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`1dooooo`;o0000
3Oooool2o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo
0_l00009ooooo`;o00000oooool3o`0000Wooooo1Ol00003ooooo`;o00000oooool2o`0000Kooooo
0_l0000:ooooo`;o0000Loooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Ooo
ool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0NOooool2o`0000Sooooo
0_l00003ooooo`;o00007_ooool2o`0000Kooooo0_l000001?oooooo0000o`000?ooool2o`00013o
oooo1?l0001mooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooo
okZj^_l000001_ooool00ol0003oooooooooo`1iooooo`;o00001_ooool4o`0000?ooooo0_l0000L
ooooo`Co00000_ooool2o`0000;ooooo0_l00008ooooo`;o00003_ooool2o`0007gooooo00001_oo
ooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`00
0?oooooooooo087ooooo0_l00005ooooo`;o00001_ooool2o`0000;ooooo0_l00005ooooo`;o0000
1oooool4o`0000Cooooo0ol0000:ooooo`?o0000SOooool001cooooo00?o0000ooooooooool0Oooo
ool3o`0000Oooooo1Ol00002ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`00
0007ooooo`;o00001oooool2o`0000[ooooo0ol0002=ooooo`007?ooool00ol0003oooooooooo`1l
ooooo`;o000000Coooooo`000?l0003o00001oooool6o`000003ooooool0003o000000Gooooo1?l0
0009ooooo`;o00000oooool2o`0000Cooooo0_l00004ooooo`;o00000_ooool4o`0000;ooooo0_l0
0028ooooo`007?ooool00ol0003oooooooooo`1looooo`;o00003oooool2o`0000Cooooo0_l00002
ooooo`Co000000Coooooo`000?l0003o00001Oooool3o`0000;ooooo0_l00004ooooo`;o00001?oo
ool2o`0000Cooooo1_l00028ooooo`007?ooool00ol0003oooooooooo`1nooooo`;o00004oooool2
o`0000Oooooo0ol00006ooooo`;o00004Oooool2o`0000?ooooo0_l0002:ooooo`007?ooool00ol0
003oooooooooo`1nooooo`;o00003Oooool2o`0000?ooooo0ol00002ooooo`;o000000Coooooo`00
0?l0003ooooo0ol0000Hooooo`;o0000Soooool001cooooo00?o0000ooooooooool0Ooooool2o`00
00Kooooo0_l00004ooooo`;o00000oooool2o`000003ooooool0003o000000Go000000?oooooo`00
0?l000000ol0000booooo`;o0000Loooool001cooooo00?o0000ooooooooool0Ooooool2o`0000Ko
oooo0_l0000<ooooo`;o000000?oooooo`000?l000000_l00002ooooo`Ko00001?ooool2o`0002[o
oooo0_l0001cooooo`007?ooool00ol0003oooooooooo`28ooooo`;o00005?ooool3o`000003oooo
ool0003o000000Cooooo0_l00009ooooo`;o0000U?ooool001cooooo00?o0000ooooooooool0R?oo
ool3o`0001Kooooo0_l0000@ooooo`;o00001?ooool2o`0000gooooo0_l00004ooooo`;o0000NOoo
ool001cooooo00?o0000ooooooooool0LOooool2o`0001Kooooo0_l0000Fooooo`;o00005_ooool2
o`0000gooooo0_l00004ooooo`;o0000NOooool001cooooo00?o0000ooooooooool0LOooool2o`00
01Gooooo0_l00004ooooo`;o0000^Oooool001cooooo0_l00026ooooo`;o000000?oooooo`000?l0
00001?ooool2o`0000kooooo0_l0002Yooooo`007?ooool00ol0003oooooooooo`25ooooo`;o0000
1oooool2o`0000kooooo0_l0002Yooooo`007?ooool00ol0003oooooooooo`29ooooo`;o00000ooo
ool2o`000;Wooooo000Looooo`03o`000?oooooooooo08Wooooo0_l000000ooooooo0000o`00000F
ooooo`;o0000Xoooool001cooooo00?o0000ooooooooool0S?ooool2o`0000;ooooo0_l0000Boooo
o`;o00007_ooool2o`0008?ooooo000Looooo`03o`000?oooooooooo093ooooo0_l0000Hooooo`;o
00006?ooool2o`0008?ooooo000Looooo`03o`000?oooooooooo083ooooo0_l0000:ooooo`;o0000
0_ooool2o`0001Sooooo0_l0002Mooooo`007?ooool00ol0003oooooooooo`20ooooo`Co00002?oo
ool2o`0000;ooooo0_l0002gooooo`007?ooool00ol0003oooooooooo`22ooooo`;o0000aOooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`2aooooo`;o0000U_ooool001cooooo00?o0000oooo
ooooool0/Oooool2o`0009Kooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Booooo`Co000000?o410@ooooooooool0
0oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`?o0000oooooom:
ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?oo
ooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003ooooooooo
o`3ooooooe;ooooo000Booooo`03oeEEEOmVIVKo00000?ooooooE?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00:7ooooo00Co410@o`000?l0003ooooo0_l000000ol@413ooooo
ooooo`0Fooooo`Co000000?o410@ooooooooool00_ooool2o`000003oa0@4?oooooooooo00;ooooo
00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0S?ooool00:;o
oooo00Go0000ooooooooooooooooo`000009ooooo`Ko00003?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooob4Q8OnHV9SooooooiRHV?lQ8B40
S?ooool00:;ooooo00Go0000ooooooooooooooooo`00000Kooooo`03o`000?oooooooooo00;ooooo
1Ol00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0R_ooool00:;ooooo
00Go0000ooooooooooooooooo`000009ooooo`Ko00003?ooool00ol0003oooooooooo`02ooooo`04
odA4A?oMgMgoooooo`0000Sooooo00WoMgMgoc8b<_oooooooooooc8b<_nHV9SooooooiRHV?lb<S80
S?ooool00:;ooooo00Go0000ohN7QoooooooZJVYo`00000Kooooo`03o`000?oooooooooo00;ooooo
00CogMgMoeEEEOoooooo00001Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Goc<c<o`00
0?l0003o0000olc<c02<ooooo`00XOooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo
01Wooooo00?o0000ooooooooool00oooool00omgMgOoc<c<o`000005ooooo`03o`000?oooooooooo
00Cooooo00Go410@okZj^_oooooo^[Zjoa0@402<ooooo`00`_ooool00ol0003oooooooooo`03oooo
o`03onk^k_m4A4Co000000Gooooo00?o0000ooooooooool01?ooool01Ol0003o^[Zjoooooonj^[[o
000008cooooo0030ooooo`03oeEEEOmVIVKo000000Kooooo00?oMgMgo`000?ooool01?ooool4o`00
00?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2<ooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1464) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.68226 .5232 Mdot
.67781 .53074 Mdot
.42346 .37748 Mdot
.51166 .65361 Mdot
.25301 .68282 Mdot
.39055 .39829 Mdot
.54436 .36656 Mdot
.55615 .37582 Mdot
.42951 .37382 Mdot
.74468 .46706 Mdot
.59002 .38762 Mdot
.42659 .64263 Mdot
.5741 .35998 Mdot
.4726 .64637 Mdot
.60291 .85334 Mdot
.47993 .70214 Mdot
.67834 .52474 Mdot
.24936 .54337 Mdot
.47623 .69236 Mdot
.42043 .41523 Mdot
.67124 .45899 Mdot
.47736 .64599 Mdot
.67347 .50915 Mdot
.47212 .64606 Mdot
.51212 .63036 Mdot
.67404 .5001 Mdot
.63085 .5537 Mdot
.51604 .59895 Mdot
.47477 .60474 Mdot
.587 .39183 Mdot
.30221 .57213 Mdot
.4495 .82851 Mdot
.56908 .62474 Mdot
.42342 .75135 Mdot
.57023 .32949 Mdot
.66009 .69908 Mdot
.39372 .38191 Mdot
.56655 .37885 Mdot
.57484 .3824 Mdot
.55179 .36089 Mdot
.55795 .37053 Mdot
.65335 .51025 Mdot
.70768 .32823 Mdot
.55524 .28686 Mdot
.46529 .58557 Mdot
.1924 .53154 Mdot
.58171 .73444 Mdot
.48465 .67223 Mdot
.63793 .49059 Mdot
.29787 .35351 Mdot
.5126 .26313 Mdot
.56887 .31945 Mdot
.43576 .40148 Mdot
.47546 .10392 Mdot
.58547 .35856 Mdot
.51271 .56472 Mdot
.4076 .38111 Mdot
.48137 .63088 Mdot
.469 .64239 Mdot
.72421 .58408 Mdot
.54218 .59477 Mdot
.33109 .51539 Mdot
.70556 .52006 Mdot
.45028 .48194 Mdot
.41641 .39003 Mdot
.58578 .38493 Mdot
.64165 .54182 Mdot
.58276 .35066 Mdot
.57715 .61124 Mdot
.37614 .34778 Mdot
.49826 .678 Mdot
.58638 .38831 Mdot
.67737 .46436 Mdot
.49576 .60264 Mdot
.28013 .35179 Mdot
.18291 .50613 Mdot
.31371 .54199 Mdot
.67415 .67086 Mdot
.72927 .57769 Mdot
.27849 .41886 Mdot
.48999 .5818 Mdot
.294 .61835 Mdot
.19058 .49615 Mdot
.62584 .49831 Mdot
.50769 .69688 Mdot
.30622 .55805 Mdot
.50129 .60253 Mdot
.21324 .65975 Mdot
.5528 .62584 Mdot
.48223 .50328 Mdot
.41117 .35522 Mdot
.66529 .47956 Mdot
.51406 .647 Mdot
.47096 .61214 Mdot
.75859 .58042 Mdot
.49494 .68291 Mdot
.49227 .64698 Mdot
.6267 .50797 Mdot
.57545 .32178 Mdot
.54481 .58479 Mdot
.35767 .4276 Mdot
.37919 .40378 Mdot
.5396 .61148 Mdot
.38054 .35122 Mdot
.67452 .46539 Mdot
.47197 .61194 Mdot
.57754 .37789 Mdot
.53547 .62974 Mdot
.55836 .21463 Mdot
.66944 .52642 Mdot
.49556 .592 Mdot
.28222 .50978 Mdot
.63844 .61734 Mdot
.65883 .4748 Mdot
.58328 .2964 Mdot
.46788 .68629 Mdot
.49521 .63408 Mdot
.63707 .54001 Mdot
.37682 .40584 Mdot
.19924 .6099 Mdot
.62434 .5256 Mdot
.60923 .36286 Mdot
.64576 .46335 Mdot
.4256 .6219 Mdot
.41984 .39582 Mdot
.57146 .28999 Mdot
.63269 .28488 Mdot
.33012 .58831 Mdot
.50081 .60611 Mdot
.73037 .34728 Mdot
.40449 .41935 Mdot
.65096 .4925 Mdot
.57933 .35088 Mdot
.55757 .64175 Mdot
.65123 .52861 Mdot
.60406 .37017 Mdot
.31778 .48811 Mdot
.49813 .22903 Mdot
.69305 .4998 Mdot
.5517 .43625 Mdot
.58443 .32468 Mdot
.55207 .33206 Mdot
.68724 .76782 Mdot
.63232 .51908 Mdot
.29719 .50919 Mdot
.57479 .34328 Mdot
.38558 .57891 Mdot
.4765 .57918 Mdot
.27174 .60219 Mdot
.64059 .22425 Mdot
.4108 .72033 Mdot
.44661 .26538 Mdot
.29295 .49956 Mdot
.56926 .30999 Mdot
.50246 .64897 Mdot
.68136 .49174 Mdot
.67234 .5055 Mdot
.54225 .59565 Mdot
.52317 .6217 Mdot
.51747 .67748 Mdot
.468 .67037 Mdot
.51473 .51952 Mdot
.55002 .64562 Mdot
.59828 .71834 Mdot
.67106 .47944 Mdot
.50656 .6559 Mdot
.43681 .39637 Mdot
.43847 .63508 Mdot
.56927 .38691 Mdot
.48121 .63827 Mdot
.51192 .65055 Mdot
.51547 .57733 Mdot
.56163 .32131 Mdot
.4153 .80969 Mdot
.60561 .60342 Mdot
.38816 .76911 Mdot
.57318 .50158 Mdot
.4249 .34865 Mdot
.50859 .60669 Mdot
.31501 .51753 Mdot
.70635 .68964 Mdot
.51833 .65964 Mdot
.18137 .31708 Mdot
.48625 .65009 Mdot
.31105 .74514 Mdot
.50153 .71832 Mdot
.40411 .76089 Mdot
.30713 .61063 Mdot
.50797 .62934 Mdot
.7539 .42086 Mdot
.57746 .4102 Mdot
.35056 .35721 Mdot
.55842 .35957 Mdot
.43064 .40257 Mdot
.41893 .37997 Mdot
.39115 .4845 Mdot
.42877 .66957 Mdot
.44051 .66065 Mdot
.53671 .65682 Mdot
.36549 .38163 Mdot
.65203 .55249 Mdot
.28196 .50464 Mdot
.7108 .51088 Mdot
.37647 .81799 Mdot
.32679 .31728 Mdot
.57522 .39766 Mdot
.31156 .4823 Mdot
.38557 .35875 Mdot
.41774 .35721 Mdot
.29056 .49684 Mdot
.46194 .62723 Mdot
.63337 .52136 Mdot
.5682 .80727 Mdot
.47808 .20281 Mdot
.86662 .55832 Mdot
.62946 .49948 Mdot
.7346 .37491 Mdot
.5646 .38697 Mdot
.39739 .3701 Mdot
.49471 .63783 Mdot
.47749 .6166 Mdot
.68613 .46478 Mdot
.49651 .67811 Mdot
.62354 .46984 Mdot
.50193 .63234 Mdot
.5553 .39942 Mdot
.32922 .54046 Mdot
.39063 .4851 Mdot
.36184 .60577 Mdot
.6623 .46757 Mdot
.77482 .63671 Mdot
.41891 .35427 Mdot
.71655 .67782 Mdot
.59334 .37964 Mdot
.33091 .49452 Mdot
.43869 .37328 Mdot
.28286 .51829 Mdot
.52448 .68204 Mdot
.41164 .41167 Mdot
.29339 .52532 Mdot
.40646 .53755 Mdot
.45217 .60418 Mdot
.46221 .18073 Mdot
.55309 .34996 Mdot
.69832 .51862 Mdot
.53714 .63444 Mdot
.40417 .34614 Mdot
.56689 .57813 Mdot
.37859 .28877 Mdot
.58348 .25689 Mdot
.40891 .42083 Mdot
.37941 .52023 Mdot
.33652 .49861 Mdot
.4868 .2845 Mdot
.72777 .3511 Mdot
.68604 .52734 Mdot
.5191 .68256 Mdot
.46233 .82389 Mdot
.57545 .34373 Mdot
.53078 .64179 Mdot
.23552 .6055 Mdot
.57913 .33301 Mdot
.4829 .62902 Mdot
.60478 .35412 Mdot
.67173 .5061 Mdot
.74115 .55603 Mdot
.63324 .53667 Mdot
.49324 .67859 Mdot
.58154 .37221 Mdot
.37586 .41043 Mdot
.66878 .49753 Mdot
.45777 .64355 Mdot
.51574 .60171 Mdot
.41662 .50533 Mdot
.49918 .65948 Mdot
.38226 .77965 Mdot
.50519 .6305 Mdot
.41136 .36896 Mdot
.50681 .58178 Mdot
.79128 .43427 Mdot
.38767 .47999 Mdot
.6347 .53479 Mdot
.41646 .42167 Mdot
.42616 .38459 Mdot
.22999 .42061 Mdot
.56333 .30307 Mdot
.44677 .64413 Mdot
.41361 .34712 Mdot
.4055 .60698 Mdot
.59693 .35597 Mdot
.54726 .61273 Mdot
.52002 .40526 Mdot
.33421 .327 Mdot
.43049 .40842 Mdot
.48097 .55295 Mdot
.69194 .48409 Mdot
.51738 .63841 Mdot
.39719 .34997 Mdot
.43229 .69264 Mdot
.48291 .59434 Mdot
.70827 .29798 Mdot
.39897 .51508 Mdot
.58523 .32887 Mdot
.43386 .6511 Mdot
.52774 .6602 Mdot
.40653 .40877 Mdot
.67323 .46944 Mdot
.595 .34618 Mdot
.65926 .50472 Mdot
.40463 .75402 Mdot
.47699 .18514 Mdot
.46347 .51205 Mdot
.30994 .53818 Mdot
.33326 .37803 Mdot
.41602 .77121 Mdot
.81218 .5485 Mdot
.68687 .74126 Mdot
.47129 .79084 Mdot
.37517 .36003 Mdot
.32072 .36321 Mdot
.4175 .38459 Mdot
.52598 .60622 Mdot
.41501 .39525 Mdot
.47928 .83489 Mdot
.49989 .63649 Mdot
.40238 .39389 Mdot
.76799 .61025 Mdot
.51319 .64227 Mdot
.68512 .52879 Mdot
.35761 .79233 Mdot
.81126 .4172 Mdot
.62552 .30857 Mdot
.38556 .37188 Mdot
.592 .79624 Mdot
.49302 .64899 Mdot
.50842 .5825 Mdot
.67896 .47981 Mdot
.57055 .60889 Mdot
.31717 .52467 Mdot
.3169 .48145 Mdot
.61445 .39583 Mdot
.35929 .51685 Mdot
.433 .64898 Mdot
.67104 .49499 Mdot
.54394 .52471 Mdot
.24408 .40844 Mdot
.30668 .34887 Mdot
.58525 .40325 Mdot
.35651 .79076 Mdot
.632 .43572 Mdot
.6171 .42649 Mdot
.46708 .33787 Mdot
.64551 .4881 Mdot
.44049 .82677 Mdot
.55992 .36503 Mdot
.41062 .19071 Mdot
.75618 .4633 Mdot
.46555 .62461 Mdot
.59326 .36504 Mdot
.5413 .55504 Mdot
.80965 .44427 Mdot
.35355 .23009 Mdot
.53013 .75728 Mdot
.5516 .62361 Mdot
.32457 .32348 Mdot
.48682 .63874 Mdot
.36676 .30205 Mdot
.51014 .62124 Mdot
.65732 .50256 Mdot
.74526 .46212 Mdot
.61065 .30929 Mdot
.60214 .55697 Mdot
.47856 .2949 Mdot
.28916 .50486 Mdot
.50079 .63007 Mdot
.46347 .62807 Mdot
.31672 .52809 Mdot
.68159 .50781 Mdot
.50717 .68067 Mdot
.78195 .62253 Mdot
.45922 .6245 Mdot
.5641 .38134 Mdot
.76622 .47915 Mdot
.57213 .6975 Mdot
.46237 .67359 Mdot
.62659 .4904 Mdot
.55766 .38715 Mdot
.57868 .37209 Mdot
.47873 .71548 Mdot
.58869 .39474 Mdot
.48738 .65891 Mdot
.32777 .24583 Mdot
.68918 .5089 Mdot
.64884 .24956 Mdot
.64237 .53063 Mdot
.66828 .65887 Mdot
.57473 .3243 Mdot
.53105 .23195 Mdot
.53127 .55361 Mdot
.56225 .36332 Mdot
.62408 .56898 Mdot
.44934 .62279 Mdot
.44668 .62637 Mdot
.57019 .80283 Mdot
.40619 .36026 Mdot
.40989 .50513 Mdot
.58826 .39149 Mdot
.46999 .65861 Mdot
.47806 .68665 Mdot
.55607 .3842 Mdot
.39761 .23071 Mdot
.79618 .50416 Mdot
.50308 .6327 Mdot
.6565 .49627 Mdot
.64772 .49764 Mdot
.46529 .58106 Mdot
.53672 .6159 Mdot
.43275 .39393 Mdot
.38673 .422 Mdot
.42146 .34274 Mdot
.40099 .50757 Mdot
.56215 .24093 Mdot
.22173 .63378 Mdot
.55168 .35917 Mdot
.71252 .37772 Mdot
.45326 .51017 Mdot
.55305 .631 Mdot
.38122 .37676 Mdot
.52466 .66377 Mdot
.5035 .66789 Mdot
.53297 .30589 Mdot
.26613 .68294 Mdot
.68698 .44098 Mdot
.66824 .46644 Mdot
.56808 .31233 Mdot
.43803 .67107 Mdot
.52295 .36551 Mdot
.33183 .50256 Mdot
.41269 .7099 Mdot
.59255 .38266 Mdot
.67334 .53532 Mdot
.55991 .33611 Mdot
.47705 .61361 Mdot
.54713 .57039 Mdot
.64459 .49116 Mdot
.33297 .51844 Mdot
.56039 .64261 Mdot
.48639 .62897 Mdot
.59404 .18774 Mdot
.38729 .62047 Mdot
.61491 .42082 Mdot
.50582 .63261 Mdot
.45096 .63547 Mdot
.33168 .47809 Mdot
.46195 .62171 Mdot
.53859 .6483 Mdot
.63412 .62534 Mdot
.65602 .35583 Mdot
.28731 .49041 Mdot
.34535 .24336 Mdot
.6297 .50029 Mdot
.44592 .81457 Mdot
.38295 .3872 Mdot
.62402 .3522 Mdot
.78658 .49639 Mdot
.44412 .39032 Mdot
.43885 .27033 Mdot
.43411 .80766 Mdot
.36407 .43828 Mdot
.42581 .33734 Mdot
.69259 .53319 Mdot
.47684 .67158 Mdot
.49309 .63184 Mdot
.31366 .51952 Mdot
.63553 .5197 Mdot
.52382 .48093 Mdot
.19094 .41836 Mdot
.47968 .64604 Mdot
.69698 .2906 Mdot
.32712 .2793 Mdot
.31737 .33489 Mdot
.31659 .50819 Mdot
.3181 .47975 Mdot
.50001 .62844 Mdot
.62418 .61121 Mdot
.67444 .49912 Mdot
.45833 .6444 Mdot
.55214 .64152 Mdot
.39639 .36224 Mdot
.66712 .52426 Mdot
.37758 .40721 Mdot
.49779 .25734 Mdot
.37291 .7621 Mdot
.39245 .17867 Mdot
.58771 .3471 Mdot
.28244 .33168 Mdot
.60113 .35284 Mdot
.30055 .6218 Mdot
.44772 .391 Mdot
.52433 .63294 Mdot
.68141 .47486 Mdot
.47657 .66294 Mdot
.53444 .61968 Mdot
.46142 .62915 Mdot
.46893 .6785 Mdot
.42429 .1592 Mdot
.2866 .50712 Mdot
.52462 .68656 Mdot
.41676 .37169 Mdot
.19735 .50148 Mdot
.20443 .45079 Mdot
.46446 .63009 Mdot
.51233 .61256 Mdot
.66653 .51845 Mdot
.54414 .61371 Mdot
.59926 .35115 Mdot
.69136 .5283 Mdot
.48877 .60251 Mdot
.29347 .75374 Mdot
.47749 .60168 Mdot
.405 .77266 Mdot
.5602 .33755 Mdot
.49735 .20099 Mdot
.55389 .57702 Mdot
.59736 .26939 Mdot
.41002 .50523 Mdot
.44025 .37753 Mdot
.59991 .33686 Mdot
.39433 .38443 Mdot
.20264 .3853 Mdot
.47071 .56701 Mdot
.50483 .64526 Mdot
.54669 .64282 Mdot
.42417 .34811 Mdot
.23531 .70956 Mdot
.49746 .29856 Mdot
.46843 .56612 Mdot
.43132 .39858 Mdot
.62169 .54147 Mdot
.47309 .77269 Mdot
.64722 .51869 Mdot
.34844 .52088 Mdot
.56108 .38196 Mdot
.33104 .51935 Mdot
.32599 .68893 Mdot
.67052 .52871 Mdot
.70401 .47714 Mdot
.38429 .38391 Mdot
.73499 .50061 Mdot
.78644 .29006 Mdot
.75713 .46029 Mdot
.32988 .60917 Mdot
.67711 .48837 Mdot
.47212 .60813 Mdot
.30511 .65051 Mdot
.75193 .46383 Mdot
.39685 .38565 Mdot
.51353 .66946 Mdot
.7512 .548 Mdot
.43382 .39302 Mdot
.55711 .59805 Mdot
.41653 .36725 Mdot
.55802 .35264 Mdot
.38464 .36732 Mdot
.66984 .45442 Mdot
.50432 .59694 Mdot
.8039 .29889 Mdot
.36553 .51543 Mdot
.49656 .64883 Mdot
.55722 .31518 Mdot
.42481 .24516 Mdot
.52306 .64511 Mdot
.30116 .53265 Mdot
.40523 .40006 Mdot
.71286 .52806 Mdot
.50575 .62802 Mdot
.43104 .39936 Mdot
.69348 .51455 Mdot
.55001 .31057 Mdot
.75595 .5782 Mdot
.63693 .3878 Mdot
.67655 .47574 Mdot
.59203 .47383 Mdot
.5871 .31176 Mdot
.45014 .6399 Mdot
.49777 .68374 Mdot
.65233 .49855 Mdot
.23903 .56101 Mdot
.53082 .59018 Mdot
.49961 .58194 Mdot
.40017 .36466 Mdot
.3929 .38913 Mdot
.67721 .74489 Mdot
.37234 .39308 Mdot
.55561 .58342 Mdot
.65089 .5014 Mdot
.514 .64954 Mdot
.67012 .51927 Mdot
.5437 .61502 Mdot
.52002 .723 Mdot
.68205 .50705 Mdot
.53209 .31119 Mdot
.51022 .66904 Mdot
.55418 .66456 Mdot
.53328 .63406 Mdot
.46972 .66815 Mdot
.43067 .39328 Mdot
.31898 .51376 Mdot
.55425 .63391 Mdot
.27085 .52396 Mdot
.28681 .49726 Mdot
.61921 .30951 Mdot
.39857 .36087 Mdot
.29349 .51449 Mdot
.27888 .29737 Mdot
.42019 .40947 Mdot
.31091 .52169 Mdot
.20363 .45384 Mdot
.56986 .32791 Mdot
.69169 .4817 Mdot
.51489 .6378 Mdot
.37527 .71568 Mdot
.5826 .72565 Mdot
.45693 .39747 Mdot
.50272 .63606 Mdot
.52822 .64633 Mdot
.62317 .52971 Mdot
.16401 .46812 Mdot
.37972 .34577 Mdot
.46504 .61008 Mdot
.66988 .53345 Mdot
.14052 .51799 Mdot
.41331 .37439 Mdot
.31613 .52151 Mdot
.56096 .32771 Mdot
.6547 .55738 Mdot
.6256 .27108 Mdot
.54892 .32883 Mdot
.40979 .43859 Mdot
.51058 .25804 Mdot
.48938 .69224 Mdot
.37976 .39585 Mdot
.80366 .65075 Mdot
.50439 .52247 Mdot
.43689 .48816 Mdot
.5668 .79394 Mdot
.65254 .48073 Mdot
.60055 .35275 Mdot
.29189 .49962 Mdot
.63377 .49146 Mdot
.67866 .52368 Mdot
.55246 .37615 Mdot
.60506 .62306 Mdot
.51773 .40076 Mdot
.57162 .38377 Mdot
.38572 .68153 Mdot
.22065 .56081 Mdot
.3795 .38556 Mdot
.31585 .52499 Mdot
.31249 .69144 Mdot
.65634 .50866 Mdot
.40161 .82905 Mdot
.58942 .80682 Mdot
.4921 .6472 Mdot
.29443 .50464 Mdot
.23423 .69568 Mdot
.16944 .48538 Mdot
.58009 .33205 Mdot
.62206 .32669 Mdot
.33741 .50692 Mdot
.5355 .63801 Mdot
.39953 .65763 Mdot
.52312 .59265 Mdot
.55635 .37348 Mdot
.75003 .60409 Mdot
.67425 .52717 Mdot
.55019 .34648 Mdot
.43266 .74142 Mdot
.48519 .65749 Mdot
.51334 .66715 Mdot
.3651 .6404 Mdot
.63384 .48889 Mdot
.44015 .37551 Mdot
.50113 .68692 Mdot
.48443 .63281 Mdot
.54839 .57579 Mdot
.45685 .58461 Mdot
.66889 .60094 Mdot
.52234 .60983 Mdot
.2723 .35206 Mdot
.54862 .62632 Mdot
.49133 .66774 Mdot
.63475 .47987 Mdot
.35856 .19276 Mdot
.50335 .26947 Mdot
.48278 .63666 Mdot
.45378 .62645 Mdot
.55209 .34124 Mdot
.50735 .38033 Mdot
.73214 .46444 Mdot
.70721 .53138 Mdot
.63952 .77641 Mdot
.45045 .60788 Mdot
.64425 .54145 Mdot
.29999 .5298 Mdot
.44749 .64255 Mdot
.6584 .54034 Mdot
.5062 .577 Mdot
.43787 .38953 Mdot
.42312 .40812 Mdot
.55764 .5351 Mdot
.29307 .51738 Mdot
.7762 .41023 Mdot
.70964 .37642 Mdot
.41206 .40968 Mdot
.50729 .64083 Mdot
.57376 .41035 Mdot
.40507 .35116 Mdot
.35922 .43869 Mdot
.23933 .59496 Mdot
.6833 .49123 Mdot
.66833 .47772 Mdot
.26775 .60273 Mdot
.46472 .25321 Mdot
.70373 .27928 Mdot
.55688 .35439 Mdot
.53562 .67491 Mdot
.74879 .39434 Mdot
.66673 .47502 Mdot
.30623 .63722 Mdot
.29184 .50851 Mdot
.57819 .33288 Mdot
.49333 .33234 Mdot
.65531 .52344 Mdot
.70209 .50032 Mdot
.53875 .5858 Mdot
.48152 .62308 Mdot
.70246 .72339 Mdot
.2676 .51776 Mdot
.54384 .3605 Mdot
.31785 .52355 Mdot
.4453 .39677 Mdot
.51486 .59233 Mdot
.67875 .50731 Mdot
.21481 .57169 Mdot
.45421 .66969 Mdot
.43427 .37783 Mdot
.65791 .47863 Mdot
.33553 .49503 Mdot
.31034 .53556 Mdot
.46391 .66795 Mdot
.73758 .67902 Mdot
.56554 .37427 Mdot
.63465 .50171 Mdot
.58669 .4227 Mdot
.52816 .5943 Mdot
.48981 .62013 Mdot
.53641 .70247 Mdot
.54375 .35663 Mdot
.67668 .42057 Mdot
.29413 .53184 Mdot
.63714 .50965 Mdot
.51916 .61098 Mdot
.30685 .52421 Mdot
.72152 .38024 Mdot
.43476 .4168 Mdot
.38565 .36382 Mdot
.31399 .53499 Mdot
.3124 .50103 Mdot
.29155 .52868 Mdot
.4047 .83212 Mdot
.63841 .54714 Mdot
.61947 .43647 Mdot
.4661 .60133 Mdot
.31496 .60929 Mdot
.53389 .68052 Mdot
.58944 .3313 Mdot
.41041 .36085 Mdot
.52876 .63387 Mdot
.45736 .66581 Mdot
.51351 .71809 Mdot
.66951 .26286 Mdot
.58032 .64885 Mdot
.67191 .52378 Mdot
.54635 .56855 Mdot
.38665 .37216 Mdot
.40813 .84847 Mdot
.62227 .81085 Mdot
.5508 .57286 Mdot
.52258 .39992 Mdot
.68528 .50108 Mdot
.55133 .36096 Mdot
.35458 .67049 Mdot
.56649 .32788 Mdot
.64101 .50178 Mdot
.52297 .60424 Mdot
.70566 .39798 Mdot
.31695 .47221 Mdot
.4705 .66223 Mdot
.5546 .35535 Mdot
.49666 .67721 Mdot
.54498 .34635 Mdot
.37374 .72478 Mdot
.78755 .65573 Mdot
.48691 .64933 Mdot
.48503 .69857 Mdot
.73191 .70083 Mdot
.46249 .63726 Mdot
.25212 .50999 Mdot
.68581 .50033 Mdot
.75693 .6021 Mdot
.45318 .68508 Mdot
.4192 .69452 Mdot
.52175 .58936 Mdot
.77144 .57279 Mdot
.48764 .61823 Mdot
.31297 .33602 Mdot
.49997 .5926 Mdot
.53842 .65069 Mdot
.58674 .3615 Mdot
.55075 .34279 Mdot
.65672 .46301 Mdot
.39159 .34702 Mdot
.39972 .77406 Mdot
.48843 .62577 Mdot
.5461 .23958 Mdot
.66078 .38606 Mdot
.31486 .50313 Mdot
.63973 .50703 Mdot
.15141 .54433 Mdot
.60235 .37999 Mdot
.67573 .77039 Mdot
.63009 .77408 Mdot
.65914 .31929 Mdot
.27143 .67141 Mdot
.38375 .25725 Mdot
.33463 .49808 Mdot
.51933 .57843 Mdot
.32184 .44718 Mdot
.3094 .33673 Mdot
.23493 .56172 Mdot
.59659 .32717 Mdot
.70128 .70217 Mdot
.23999 .63247 Mdot
.3369 .53049 Mdot
.32786 .48195 Mdot
.56159 .31951 Mdot
.38073 .32574 Mdot
.42599 .65614 Mdot
.29919 .49843 Mdot
.42014 .34437 Mdot
.42164 .41257 Mdot
.40818 .3387 Mdot
.67498 .50175 Mdot
.6276 .80405 Mdot
.60002 .32459 Mdot
.58894 .33412 Mdot
.35337 .33319 Mdot
.47044 .74561 Mdot
.71527 .49548 Mdot
.39207 .37567 Mdot
.37596 .37484 Mdot
.68865 .4982 Mdot
.51335 .56707 Mdot
.45903 .57672 Mdot
.48084 .6417 Mdot
.31493 .51604 Mdot
.48149 .61859 Mdot
.4248 .40195 Mdot
.58487 .34248 Mdot
.38078 .36317 Mdot
.55146 .31882 Mdot
.20788 .57993 Mdot
.45615 .65003 Mdot
.50572 .5954 Mdot
.54246 .16874 Mdot
.69765 .47958 Mdot
.19902 .51874 Mdot
.52853 .34178 Mdot
.4177 .38286 Mdot
.53794 .64842 Mdot
.71593 .5066 Mdot
.2749 .49089 Mdot
.39797 .18148 Mdot
.53849 .60706 Mdot
.66173 .51283 Mdot
.51718 .5956 Mdot
.44945 .5317 Mdot
.76495 .33417 Mdot
.65 .50848 Mdot
.67699 .25632 Mdot
.4667 .61071 Mdot
.28686 .30285 Mdot
.54743 .62135 Mdot
.40834 .54149 Mdot
.53088 .59033 Mdot
.62877 .50189 Mdot
.47857 .63814 Mdot
.70944 .51458 Mdot
.39949 .41043 Mdot
.55347 .34301 Mdot
.67566 .47675 Mdot
.47823 .6795 Mdot
.65606 .13104 Mdot
.5641 .34298 Mdot
.49753 .63434 Mdot
.56512 .32193 Mdot
.63643 .52756 Mdot
.64157 .48641 Mdot
.19048 .45313 Mdot
.49353 .25817 Mdot
.55938 .35148 Mdot
.51545 .59316 Mdot
.31245 .30323 Mdot
.52526 .6239 Mdot
.40203 .62137 Mdot
.51543 .56479 Mdot
.48465 .58053 Mdot
.19147 .47689 Mdot
.58331 .32599 Mdot
.70191 .27503 Mdot
.17836 .48596 Mdot
.19689 .4989 Mdot
.66959 .45811 Mdot
.33367 .53078 Mdot
.43119 .82076 Mdot
.56765 .24393 Mdot
.44122 .38762 Mdot
.52794 .63825 Mdot
.60901 .55432 Mdot
.56995 .37703 Mdot
.32954 .50587 Mdot
.4875 .64834 Mdot
.37773 .37539 Mdot
.80735 .5308 Mdot
.56933 .31076 Mdot
.64868 .51289 Mdot
.62035 .53192 Mdot
.24454 .29753 Mdot
.51057 .62422 Mdot
.49926 .59711 Mdot
.56069 .38178 Mdot
.40414 .24278 Mdot
.30436 .48628 Mdot
.76886 .60557 Mdot
.56113 .35035 Mdot
.51605 .46175 Mdot
.65973 .54108 Mdot
.52883 .64918 Mdot
.29547 .74203 Mdot
.48303 .3244 Mdot
.58877 .19704 Mdot
.31326 .51714 Mdot
.40334 .60954 Mdot
.62909 .50226 Mdot
.57747 .34836 Mdot
.46717 .23665 Mdot
.44764 .62007 Mdot
.51702 .67207 Mdot
.40792 .56337 Mdot
.61267 .30507 Mdot
.72856 .47239 Mdot
.5363 .60433 Mdot
.4098 .50308 Mdot
.54033 .6125 Mdot
.49989 .70819 Mdot
.51175 .56045 Mdot
.49796 .61208 Mdot
.67237 .50997 Mdot
.43291 .57815 Mdot
.42953 .35588 Mdot
.68782 .44447 Mdot
.50419 .46475 Mdot
.49849 .64299 Mdot
.49536 .58339 Mdot
.54633 .75131 Mdot
.41213 .27354 Mdot
.6756 .47906 Mdot
.69101 .46124 Mdot
.59757 .38739 Mdot
.48191 .56901 Mdot
.39005 .34776 Mdot
.54899 .66238 Mdot
.43194 .3901 Mdot
.67558 .50818 Mdot
.41571 .37981 Mdot
.55707 .32811 Mdot
.38257 .40305 Mdot
.55459 .2373 Mdot
.57197 .33843 Mdot
.68288 .48432 Mdot
.4908 .6047 Mdot
.55686 .31474 Mdot
.35017 .59012 Mdot
.3122 .51584 Mdot
.18298 .62848 Mdot
.48851 .60204 Mdot
.6472 .3238 Mdot
.4641 .72273 Mdot
.37825 .36794 Mdot
.75122 .31537 Mdot
.67881 .47029 Mdot
.29689 .48415 Mdot
.63989 .48046 Mdot
.41506 .71038 Mdot
.30641 .5056 Mdot
.17451 .57674 Mdot
.40192 .52438 Mdot
.3896 .6176 Mdot
.488 .56994 Mdot
.37134 .6214 Mdot
.43565 .40736 Mdot
.57131 .37576 Mdot
.45626 .24781 Mdot
.53483 .65483 Mdot
.82648 .55506 Mdot
.6317 .48609 Mdot
.40515 .34724 Mdot
.58095 .35257 Mdot
.59311 .33944 Mdot
.45514 .61802 Mdot
.28838 .38835 Mdot
.51898 .6722 Mdot
.48356 .24606 Mdot
.59102 .79466 Mdot
.6196 .44241 Mdot
.5015 .6327 Mdot
.40537 .40894 Mdot
.51743 .59583 Mdot
.29754 .53432 Mdot
.7157 .7425 Mdot
.55595 .65714 Mdot
.54206 .38459 Mdot
.26437 .51126 Mdot
.63061 .52036 Mdot
.4944 .72876 Mdot
.62712 .41813 Mdot
.51334 .62152 Mdot
.36904 .15862 Mdot
.30834 .52248 Mdot
.32621 .44256 Mdot
.46295 .67813 Mdot
.44704 .65318 Mdot
.42946 .47574 Mdot
.62092 .25939 Mdot
.41313 .30929 Mdot
.46595 .64432 Mdot
.35271 .5742 Mdot
.5702 .31701 Mdot
.53744 .6306 Mdot
.49504 .63158 Mdot
.60765 .67649 Mdot
.58125 .31891 Mdot
.42749 .37888 Mdot
.44536 .38782 Mdot
.45189 .40717 Mdot
.28318 .52446 Mdot
.72227 .4488 Mdot
.32052 .62971 Mdot
.80944 .4777 Mdot
.30903 .4768 Mdot
.45378 .65754 Mdot
.34497 .42429 Mdot
.52308 .59822 Mdot
.3266 .50381 Mdot
.57872 .31663 Mdot
.66753 .47308 Mdot
.74318 .39349 Mdot
.43883 .39657 Mdot
.44172 .63594 Mdot
.29308 .48972 Mdot
.68144 .49248 Mdot
.33224 .67537 Mdot
.6313 .51955 Mdot
.56363 .35854 Mdot
.72618 .44948 Mdot
.32917 .50223 Mdot
.64083 .53477 Mdot
.55225 .4032 Mdot
.17864 .46273 Mdot
.49236 .56102 Mdot
.73251 .42695 Mdot
.62861 .52435 Mdot
.70041 .46845 Mdot
.63649 .54309 Mdot
.48593 .67377 Mdot
.52283 .40141 Mdot
.47424 .58153 Mdot
.57854 .32114 Mdot
.41996 .36984 Mdot
.79197 .62897 Mdot
.54792 .28036 Mdot
.5794 .44856 Mdot
.5611 .62671 Mdot
.48394 .65732 Mdot
.49968 .62892 Mdot
.48542 .70602 Mdot
.56057 .23673 Mdot
.49059 .67205 Mdot
.58681 .36259 Mdot
.41169 .40134 Mdot
.51591 .57771 Mdot
.41403 .43274 Mdot
.20661 .47336 Mdot
.33834 .51046 Mdot
.60683 .40768 Mdot
.68771 .78098 Mdot
.6809 .48983 Mdot
.41088 .42208 Mdot
.41647 .40573 Mdot
.32199 .48838 Mdot
.56463 .37824 Mdot
.63151 .52418 Mdot
.40911 .59563 Mdot
.28602 .49858 Mdot
.48053 .63584 Mdot
.53566 .40184 Mdot
.82198 .58049 Mdot
.52844 .58169 Mdot
.51885 .64784 Mdot
.40235 .33714 Mdot
.33353 .44461 Mdot
.85616 .42116 Mdot
.33901 .64169 Mdot
.32508 .51101 Mdot
.33215 .52738 Mdot
.6914 .49969 Mdot
.44193 .6531 Mdot
.55595 .31968 Mdot
.74687 .50211 Mdot
.65453 .42501 Mdot
.75419 .36099 Mdot
.56465 .19018 Mdot
.53716 .6207 Mdot
.37987 .23929 Mdot
.49023 .66205 Mdot
.6354 .54562 Mdot
.66953 .50796 Mdot
.66641 .49269 Mdot
.57042 .37496 Mdot
.67533 .69398 Mdot
.58255 .37284 Mdot
.7808 .69658 Mdot
.63441 .49597 Mdot
.39592 .52673 Mdot
.39062 .37169 Mdot
.46068 .57045 Mdot
.33732 .50473 Mdot
.73509 .44144 Mdot
.57707 .61255 Mdot
.6197 .59764 Mdot
.41312 .34808 Mdot
.68077 .47889 Mdot
.39856 .24804 Mdot
.5089 .81723 Mdot
.73195 .49651 Mdot
.54583 .69938 Mdot
.35446 .67276 Mdot
.31902 .50479 Mdot
.58594 .19587 Mdot
.32843 .51938 Mdot
.55492 .35268 Mdot
.51129 .5991 Mdot
.50169 .60309 Mdot
.54095 .61141 Mdot
.45787 .63873 Mdot
.58209 .30645 Mdot
.5337 .66998 Mdot
.79108 .43544 Mdot
.44129 .39257 Mdot
.32132 .56251 Mdot
.32287 .52122 Mdot
.59259 .32748 Mdot
.41361 .40188 Mdot
.42129 .27209 Mdot
.35824 .60496 Mdot
.50436 .62997 Mdot
.52886 .63474 Mdot
.70842 .73679 Mdot
.53571 .60427 Mdot
.42235 .62771 Mdot
.43651 .39411 Mdot
.55572 .71453 Mdot
.33784 .51073 Mdot
.33663 .52145 Mdot
.57258 .33627 Mdot
.67059 .50965 Mdot
.30127 .51781 Mdot
.39439 .36756 Mdot
.56281 .62143 Mdot
.51811 .68341 Mdot
.62839 .51947 Mdot
.718 .73275 Mdot
.31346 .53855 Mdot
.31054 .3009 Mdot
.68553 .48395 Mdot
.62548 .48663 Mdot
.51886 .67046 Mdot
.61838 .21598 Mdot
.64761 .45903 Mdot
.27763 .49824 Mdot
.59375 .3273 Mdot
.36404 .66755 Mdot
.60196 .37599 Mdot
.64768 .51554 Mdot
.47722 .59861 Mdot
.67953 .50217 Mdot
.50694 .62951 Mdot
.54936 .83468 Mdot
.49743 .60813 Mdot
.80831 .4639 Mdot
.26338 .59143 Mdot
.38902 .39918 Mdot
.40394 .26841 Mdot
.38317 .38671 Mdot
.66781 .46853 Mdot
.4615 .68028 Mdot
.32207 .48364 Mdot
.22441 .40442 Mdot
.70335 .5544 Mdot
.41207 .35511 Mdot
.36631 .36392 Mdot
.60567 .36466 Mdot
.5302 .58808 Mdot
.50912 .67578 Mdot
.39955 .39298 Mdot
.63531 .45484 Mdot
.64908 .52809 Mdot
.51499 .60842 Mdot
.48311 .65949 Mdot
.38632 .39513 Mdot
.17883 .45028 Mdot
.47689 .54343 Mdot
.50905 .60519 Mdot
.44907 .32108 Mdot
.59078 .33507 Mdot
.46226 .57017 Mdot
.49035 .69739 Mdot
.31032 .49884 Mdot
.70465 .58923 Mdot
.51488 .79911 Mdot
.57683 .31479 Mdot
.42547 .40485 Mdot
.51487 .61772 Mdot
.40804 .40887 Mdot
.53067 .67468 Mdot
.63106 .27167 Mdot
.41117 .42012 Mdot
.48996 .58151 Mdot
.51227 .56885 Mdot
.63067 .49309 Mdot
.53368 .62741 Mdot
.58017 .76085 Mdot
.43198 .36647 Mdot
.45745 .61567 Mdot
.75502 .64459 Mdot
.57909 .38684 Mdot
.4605 .58064 Mdot
.28579 .50234 Mdot
.4046 .65948 Mdot
.69483 .37947 Mdot
.28731 .69524 Mdot
.34047 .51363 Mdot
.49339 .67568 Mdot
.37301 .35348 Mdot
.5443 .36251 Mdot
.8093 .42272 Mdot
.53419 .64179 Mdot
.55487 .36525 Mdot
.58415 .34159 Mdot
.33142 .50583 Mdot
.33357 .20427 Mdot
.46323 .67626 Mdot
.4667 .62701 Mdot
.63581 .70563 Mdot
.70504 .49407 Mdot
.4876 .613 Mdot
.46506 .61607 Mdot
.58862 .35737 Mdot
.42957 .64823 Mdot
.63767 .75986 Mdot
.77197 .58606 Mdot
.55858 .38932 Mdot
.76515 .41603 Mdot
.41759 .41803 Mdot
.31081 .52828 Mdot
.65023 .48752 Mdot
.30228 .4859 Mdot
.3902 .36401 Mdot
.47236 .61062 Mdot
.55567 .37718 Mdot
.57909 .75183 Mdot
.55968 .32028 Mdot
.23971 .61917 Mdot
.69765 .52282 Mdot
.60994 .33458 Mdot
.35035 .17458 Mdot
.45127 .30374 Mdot
.60468 .28943 Mdot
.31433 .50283 Mdot
.34993 .38778 Mdot
.48463 .66023 Mdot
.56941 .18521 Mdot
.45286 .65232 Mdot
.75382 .62644 Mdot
.44334 .38571 Mdot
.41722 .34039 Mdot
.51132 .60223 Mdot
.57225 .79263 Mdot
.54493 .36949 Mdot
.59662 .35905 Mdot
.4803 .58762 Mdot
.56189 .36279 Mdot
.47682 .62491 Mdot
.42548 .39955 Mdot
.6108 .19024 Mdot
.4848 .64368 Mdot
.51931 .69747 Mdot
.64552 .30168 Mdot
.18422 .48809 Mdot
.31841 .55137 Mdot
.19539 .36094 Mdot
.55446 .82487 Mdot
.56302 .36377 Mdot
.46911 .58956 Mdot
.76347 .40549 Mdot
.38812 .3418 Mdot
.602 .42448 Mdot
.47834 .61038 Mdot
.45539 .63161 Mdot
.54349 .64309 Mdot
.51431 .66333 Mdot
.44806 .1758 Mdot
.72883 .53411 Mdot
.68399 .63277 Mdot
.53481 .62134 Mdot
.37159 .59755 Mdot
.56293 .33647 Mdot
.62118 .55739 Mdot
.29226 .48327 Mdot
.53631 .6229 Mdot
.72522 .47717 Mdot
.56786 .39275 Mdot
.80417 .67111 Mdot
.55467 .3702 Mdot
.4252 .3854 Mdot
.54963 .33869 Mdot
.49865 .65824 Mdot
.64825 .4973 Mdot
.44704 .44969 Mdot
.49148 .28324 Mdot
.442 .37235 Mdot
.49682 .64823 Mdot
.37839 .5352 Mdot
.42538 .35283 Mdot
.19388 .51828 Mdot
.65559 .48721 Mdot
.34371 .57215 Mdot
.67642 .50524 Mdot
.47762 .59322 Mdot
.47908 .59277 Mdot
.60014 .39083 Mdot
.55424 .33085 Mdot
.67498 .50643 Mdot
.25775 .25087 Mdot
.29892 .53345 Mdot
.66356 .49597 Mdot
.45246 .68854 Mdot
.50238 .41209 Mdot
.65328 .49441 Mdot
.27799 .47862 Mdot
.58701 .34785 Mdot
.69668 .48657 Mdot
.55236 .61947 Mdot
.38842 .68068 Mdot
.31155 .53334 Mdot
.44782 .37407 Mdot
.31143 .65775 Mdot
.42097 .3579 Mdot
.59861 .33374 Mdot
.38346 .39101 Mdot
.58797 .33561 Mdot
.68198 .39446 Mdot
.67489 .44176 Mdot
.37356 .45388 Mdot
.6002 .33051 Mdot
.38462 .3834 Mdot
.51387 .59751 Mdot
.36162 .52612 Mdot
.44721 .67001 Mdot
.49698 .68098 Mdot
.59335 .35672 Mdot
.637 .4876 Mdot
.67542 .45849 Mdot
.3952 .60967 Mdot
.66813 .51379 Mdot
.43237 .37349 Mdot
.66392 .58579 Mdot
.55032 .25028 Mdot
.59867 .37812 Mdot
.55371 .33907 Mdot
.52776 .60032 Mdot
.39499 .38467 Mdot
.43798 .35971 Mdot
.60316 .37527 Mdot
.65714 .2622 Mdot
.48931 .70173 Mdot
.6927 .46034 Mdot
.70325 .49574 Mdot
.64997 .50578 Mdot
.65073 .54699 Mdot
.41877 .68831 Mdot
.57451 .32868 Mdot
.64388 .47954 Mdot
.52868 .59998 Mdot
.46542 .61829 Mdot
.75687 .47578 Mdot
.30017 .52768 Mdot
.50091 .57556 Mdot
.51007 .56102 Mdot
.52841 .65091 Mdot
.38159 .37209 Mdot
.42216 .60685 Mdot
.38149 .40637 Mdot
.38648 .34517 Mdot
.38825 .34353 Mdot
.57527 .2489 Mdot
.66363 .77253 Mdot
.44793 .78581 Mdot
.45729 .61885 Mdot
.34544 .26013 Mdot
.40316 .37582 Mdot
.73668 .53846 Mdot
.66845 .41798 Mdot
.53673 .64877 Mdot
.2617 .37111 Mdot
.39546 .39307 Mdot
.68901 .49096 Mdot
.48723 .60819 Mdot
.42387 .42278 Mdot
.28356 .51159 Mdot
.44771 .63033 Mdot
.43719 .41541 Mdot
.63984 .53597 Mdot
.27584 .51894 Mdot
.6938 .4769 Mdot
.38657 .34378 Mdot
.43793 .66781 Mdot
.71731 .24458 Mdot
.43049 .42476 Mdot
.25094 .33327 Mdot
.58556 .56712 Mdot
.51616 .60379 Mdot
.38893 .41834 Mdot
.6218 .48897 Mdot
.59873 .33523 Mdot
.55548 .48757 Mdot
.68988 .51075 Mdot
.41697 .34026 Mdot
.38905 .35142 Mdot
.44211 .37267 Mdot
.67958 .5207 Mdot
.45045 .59629 Mdot
.66616 .52198 Mdot
.54805 .34189 Mdot
.51821 .63448 Mdot
.40863 .76177 Mdot
.41846 .2367 Mdot
.68665 .49016 Mdot
.42283 .36756 Mdot
.32739 .47485 Mdot
.48777 .65605 Mdot
.39031 .24287 Mdot
.516 .59759 Mdot
.59115 .34002 Mdot
.64734 .61942 Mdot
.5618 .71469 Mdot
.47697 .58372 Mdot
.52911 .60666 Mdot
.59631 .36245 Mdot
.49339 .64703 Mdot
.53078 .58977 Mdot
.55385 .23643 Mdot
.66202 .52715 Mdot
.47741 .64224 Mdot
.41297 .36654 Mdot
.52299 .25818 Mdot
.50126 .70139 Mdot
.3657 .43272 Mdot
.35773 .56805 Mdot
.62661 .6329 Mdot
.45225 .64927 Mdot
.55822 .41793 Mdot
.51545 .6689 Mdot
.46435 .65803 Mdot
.5264 .60758 Mdot
.38718 .20691 Mdot
.43283 .41674 Mdot
.40644 .40571 Mdot
.3268 .53059 Mdot
.35484 .56851 Mdot
.29943 .4996 Mdot
.58542 .33981 Mdot
.2931 .4035 Mdot
.38338 .41007 Mdot
.64251 .52353 Mdot
.47565 .66478 Mdot
.42508 .42614 Mdot
.53061 .65175 Mdot
.49959 .65656 Mdot
.381 .35098 Mdot
.42999 .41592 Mdot
.2261 .56887 Mdot
.2936 .52492 Mdot
.67176 .48898 Mdot
.51191 .57971 Mdot
.28934 .49355 Mdot
.45354 .6595 Mdot
.31357 .61032 Mdot
.66705 .49011 Mdot
.6616 .52594 Mdot
.66813 .45605 Mdot
.47911 .60659 Mdot
.49381 .65766 Mdot
.58354 .37277 Mdot
.67571 .46938 Mdot
.57558 .38728 Mdot
.51887 .48577 Mdot
.22801 .48119 Mdot
.4777 .6106 Mdot
.74378 .45512 Mdot
.29017 .50484 Mdot
.40885 .35448 Mdot
.8178 .5944 Mdot
.32645 .53081 Mdot
.50875 .62481 Mdot
.39953 .34523 Mdot
.32194 .49592 Mdot
.42855 .53909 Mdot
.75525 .71325 Mdot
.33034 .47793 Mdot
.52909 .6008 Mdot
.43097 .65636 Mdot
.20574 .34408 Mdot
.34243 .50048 Mdot
.56201 .32876 Mdot
.48149 .60541 Mdot
.70807 .47725 Mdot
.29362 .48899 Mdot
.3476 .30895 Mdot
.40192 .3987 Mdot
.39374 .68076 Mdot
.55879 .65758 Mdot
.60637 .56258 Mdot
.32517 .52937 Mdot
.6351 .5093 Mdot
.42228 .6608 Mdot
.51933 .66904 Mdot
.34297 .50245 Mdot
.55692 .30235 Mdot
.41615 .39677 Mdot
.49793 .2659 Mdot
.68353 .51855 Mdot
.53722 .30533 Mdot
.41108 .35822 Mdot
.30273 .306 Mdot
.78382 .54207 Mdot
.45517 .57872 Mdot
.28254 .28268 Mdot
.64334 .35627 Mdot
.54587 .61222 Mdot
.28685 .48078 Mdot
.55642 .31334 Mdot
.57834 .3958 Mdot
.56395 .35381 Mdot
.67024 .39576 Mdot
.71001 .52843 Mdot
.44322 .41224 Mdot
.5264 .3727 Mdot
.30743 .52748 Mdot
.36716 .6581 Mdot
.50247 .68275 Mdot
.48213 .65361 Mdot
.51954 .5845 Mdot
.53759 .623 Mdot
.4958 .67161 Mdot
.56032 .37332 Mdot
.67177 .37959 Mdot
.72363 .51852 Mdot
.65949 .492 Mdot
.335 .42906 Mdot
.39867 .36783 Mdot
.42946 .34243 Mdot
.30823 .49065 Mdot
.41781 .3011 Mdot
.41698 .43245 Mdot
.4177 .38081 Mdot
.5204 .5747 Mdot
.65511 .5244 Mdot
.44533 .58193 Mdot
.52936 .60397 Mdot
.43436 .38216 Mdot
.45531 .47744 Mdot
.59269 .77282 Mdot
.23518 .53802 Mdot
.29096 .53653 Mdot
.5343 .39513 Mdot
.33928 .52255 Mdot
.49148 .69029 Mdot
.76832 .34423 Mdot
.38876 .36518 Mdot
.40971 .38751 Mdot
.29395 .52212 Mdot
.61868 .21378 Mdot
.65099 .48344 Mdot
.54128 .29695 Mdot
.57234 .32076 Mdot
.48022 .59484 Mdot
.80865 .54561 Mdot
.58635 .55073 Mdot
.28075 .39141 Mdot
.56308 .3474 Mdot
.39629 .41035 Mdot
.50758 .69121 Mdot
.53082 .61458 Mdot
.29511 .49826 Mdot
.2656 .69217 Mdot
.50666 .55753 Mdot
.2292 .70917 Mdot
.78869 .65474 Mdot
.49318 .78687 Mdot
.515 .67346 Mdot
.66659 .52509 Mdot
.44357 .39439 Mdot
.31577 .52574 Mdot
.44487 .62573 Mdot
.56414 .81043 Mdot
.62969 .51251 Mdot
.57218 .34241 Mdot
.48798 .4581 Mdot
.35596 .6592 Mdot
.4771 .67199 Mdot
.45965 .62353 Mdot
.46546 .66264 Mdot
.88789 .5136 Mdot
.37844 .39385 Mdot
.68727 .49424 Mdot
.33119 .50301 Mdot
.65957 .51547 Mdot
.39292 .40485 Mdot
.3849 .47356 Mdot
.50533 .59219 Mdot
.63146 .53375 Mdot
.6368 .50504 Mdot
.57568 .39325 Mdot
.57855 .3134 Mdot
.50291 .46922 Mdot
.49649 .60985 Mdot
.37001 .39344 Mdot
.63784 .48502 Mdot
.55164 .41057 Mdot
.30572 .50398 Mdot
.58792 .34899 Mdot
.53336 .62609 Mdot
.38343 .40789 Mdot
.53778 .5733 Mdot
.67105 .47769 Mdot
.41657 .38066 Mdot
.21608 .55817 Mdot
.33854 .51265 Mdot
.4661 .62022 Mdot
.25888 .54509 Mdot
.42847 .40243 Mdot
.48883 .66431 Mdot
.26195 .33958 Mdot
.29123 .47297 Mdot
.4957 .30239 Mdot
.41073 .34435 Mdot
.61005 .28124 Mdot
.6917 .50177 Mdot
.61181 .26325 Mdot
.41758 .38841 Mdot
.32202 .29149 Mdot
.21905 .58903 Mdot
.55646 .63757 Mdot
.65716 .50721 Mdot
.62161 .28641 Mdot
.47735 .8419 Mdot
.22276 .35909 Mdot
.49704 .6337 Mdot
.37225 .3908 Mdot
.31195 .49341 Mdot
.59735 .37722 Mdot
.51653 .30176 Mdot
.35835 .4906 Mdot
.36798 .40753 Mdot
.52601 .6082 Mdot
.63365 .52368 Mdot
.58107 .36509 Mdot
.69527 .3854 Mdot
.40149 .36492 Mdot
.41922 .36708 Mdot
.45434 .67363 Mdot
.2915 .51022 Mdot
.46727 .20577 Mdot
.43252 .3961 Mdot
.73649 .70473 Mdot
.41969 .33413 Mdot
.28174 .50636 Mdot
.51946 .6587 Mdot
.3976 .64879 Mdot
.44761 .62565 Mdot
.22045 .39394 Mdot
.39323 .37133 Mdot
.67194 .48358 Mdot
.51429 .67895 Mdot
.76506 .64545 Mdot
.4312 .37239 Mdot
.52253 .39367 Mdot
.36715 .31652 Mdot
.57753 .32778 Mdot
.8177 .5916 Mdot
.47956 .61708 Mdot
.5443 .36144 Mdot
.29936 .49612 Mdot
.50421 .60816 Mdot
.49638 .66037 Mdot
.62269 .5258 Mdot
.5815 .39297 Mdot
.22597 .56385 Mdot
.55039 .34954 Mdot
.5591 .3378 Mdot
.72094 .49397 Mdot
.47019 .63591 Mdot
.42674 .38364 Mdot
.39588 .39174 Mdot
.5519 .61574 Mdot
.55079 .14939 Mdot
.6443 .48933 Mdot
.44528 .36629 Mdot
.89013 .48766 Mdot
.54757 .60391 Mdot
.80751 .59121 Mdot
.25125 .6748 Mdot
.56297 .31548 Mdot
.52911 .59968 Mdot
.63806 .53199 Mdot
.40574 .30937 Mdot
.42212 .36963 Mdot
.55373 .62479 Mdot
.57935 .36503 Mdot
.29331 .52643 Mdot
.43464 .36418 Mdot
.28669 .3907 Mdot
.45654 .64716 Mdot
.24411 .40097 Mdot
.37516 .3655 Mdot
.40945 .80626 Mdot
.43276 .26261 Mdot
.66038 .50442 Mdot
.50251 .65663 Mdot
.68379 .47548 Mdot
.32878 .49651 Mdot
.49041 .45937 Mdot
.58522 .35437 Mdot
.46273 .73941 Mdot
.78383 .3684 Mdot
.44223 .37305 Mdot
.68798 .48637 Mdot
.47335 .59058 Mdot
.62585 .25977 Mdot
.47558 .6214 Mdot
.49277 .72233 Mdot
.23008 .55868 Mdot
.59239 .37224 Mdot
.56809 .31726 Mdot
.5061 .66775 Mdot
.31776 .48605 Mdot
.39693 .36693 Mdot
.42531 .39286 Mdot
.36564 .8061 Mdot
.54441 .29517 Mdot
.69507 .73083 Mdot
.45535 .63245 Mdot
.36441 .39046 Mdot
.56723 .27606 Mdot
.55858 .37848 Mdot
.4475 .59598 Mdot
.39624 .34731 Mdot
.33007 .56152 Mdot
.40875 .55722 Mdot
.51628 .67023 Mdot
.44427 .67031 Mdot
.56401 .3217 Mdot
.72603 .5 Mdot
.41124 .41161 Mdot
.53719 .56757 Mdot
.38903 .46295 Mdot
.42526 .53915 Mdot
.78853 .66547 Mdot
.67178 .48925 Mdot
.29984 .36328 Mdot
.56099 .3749 Mdot
.52623 .69465 Mdot
.33539 .50587 Mdot
.35894 .37533 Mdot
.3993 .41768 Mdot
.51749 .61886 Mdot
.51362 .68741 Mdot
.77365 .66137 Mdot
.64852 .52307 Mdot
.56756 .33421 Mdot
.49867 .59896 Mdot
.74553 .41675 Mdot
.54065 .60881 Mdot
.58211 .37815 Mdot
.70125 .23138 Mdot
.44266 .65021 Mdot
.47027 .62467 Mdot
.46337 .20772 Mdot
.69493 .50803 Mdot
.64504 .47451 Mdot
.82458 .53862 Mdot
.45592 .63131 Mdot
.79754 .6379 Mdot
.67697 .48621 Mdot
.65564 .47824 Mdot
.50479 .23998 Mdot
.48485 .65314 Mdot
.51196 .53246 Mdot
.5835 .3268 Mdot
.55859 .33681 Mdot
.67392 .52091 Mdot
.47872 .56361 Mdot
.58819 .32455 Mdot
.43332 .19286 Mdot
.39423 .38324 Mdot
.71336 .28055 Mdot
.64021 .49264 Mdot
.6309 .3636 Mdot
.5558 .35639 Mdot
.74098 .73308 Mdot
.48551 .33855 Mdot
.51036 .59531 Mdot
.45552 .63494 Mdot
.29686 .52329 Mdot
.50119 .57909 Mdot
.41825 .34085 Mdot
.56146 .36226 Mdot
.56115 .78435 Mdot
.66653 .49311 Mdot
.4898 .61768 Mdot
.2582 .36173 Mdot
.19417 .5667 Mdot
.32329 .34523 Mdot
.63186 .51289 Mdot
.67152 .50331 Mdot
.38378 .40275 Mdot
.37218 .38275 Mdot
.47185 .65228 Mdot
.59903 .35988 Mdot
.67921 .47192 Mdot
.58757 .37411 Mdot
.39057 .36293 Mdot
.42383 .38342 Mdot
.43747 .41115 Mdot
.50784 .68373 Mdot
.41949 .37547 Mdot
.21798 .51125 Mdot
.50827 .35496 Mdot
.71709 .49105 Mdot
.84996 .54935 Mdot
.69864 .3906 Mdot
.61351 .56135 Mdot
.28236 .49879 Mdot
.44025 .38991 Mdot
.54566 .35469 Mdot
.51565 .64603 Mdot
.53038 .63776 Mdot
.56982 .2533 Mdot
.54689 .36604 Mdot
.33015 .50171 Mdot
.54867 .33181 Mdot
.33172 .50454 Mdot
.2555 .39417 Mdot
.53172 .5872 Mdot
.53719 .66577 Mdot
.55817 .36367 Mdot
.4184 .37798 Mdot
.40412 .40262 Mdot
.33509 .48494 Mdot
.44389 .48695 Mdot
.42272 .35146 Mdot
.65133 .47929 Mdot
.51604 .77075 Mdot
.37908 .3607 Mdot
.48775 .60951 Mdot
.31411 .62828 Mdot
.55048 .17333 Mdot
.48429 .70567 Mdot
.51386 .23337 Mdot
.59905 .73306 Mdot
.523 .67138 Mdot
.55758 .17514 Mdot
.53947 .36482 Mdot
.68564 .51004 Mdot
.43704 .39718 Mdot
.44992 .35376 Mdot
.52172 .54308 Mdot
.27488 .51961 Mdot
.43779 .63722 Mdot
.63236 .53441 Mdot
.61953 .53172 Mdot
.39161 .64449 Mdot
.22368 .37047 Mdot
.31996 .49618 Mdot
.30497 .49181 Mdot
.42056 .38936 Mdot
.18272 .63347 Mdot
.51674 .71772 Mdot
.32905 .50608 Mdot
.62785 .46581 Mdot
.52382 .61247 Mdot
.33622 .56524 Mdot
.5911 .51091 Mdot
.6763 .52088 Mdot
.37781 .59731 Mdot
.43063 .37653 Mdot
.67028 .51395 Mdot
.73935 .38071 Mdot
.46139 .58534 Mdot
.66561 .49135 Mdot
.5864 .37264 Mdot
.42737 .27973 Mdot
.64454 .48299 Mdot
.31768 .62165 Mdot
.60307 .36279 Mdot
.55368 .4113 Mdot
.40025 .58458 Mdot
.10429 .49933 Mdot
.56049 .36869 Mdot
.39068 .35139 Mdot
.3971 .39233 Mdot
.42543 .39226 Mdot
.6575 .51726 Mdot
.44262 .37358 Mdot
.64803 .52149 Mdot
.24929 .30564 Mdot
.57492 .19588 Mdot
.32634 .50937 Mdot
.49484 .2668 Mdot
.63838 .51836 Mdot
.77804 .47816 Mdot
.45231 .12289 Mdot
.52691 .59553 Mdot
.5835 .3972 Mdot
.32505 .50823 Mdot
.21205 .66952 Mdot
.31514 .49965 Mdot
.59385 .8047 Mdot
.61433 .61027 Mdot
.48424 .62409 Mdot
.70124 .6901 Mdot
.32611 .47983 Mdot
.66691 .53764 Mdot
.48894 .66364 Mdot
.47603 .49784 Mdot
.30852 .49604 Mdot
.28258 .51522 Mdot
.4729 .64675 Mdot
.6807 .47863 Mdot
.42303 .36564 Mdot
.55375 .34406 Mdot
.30355 .48363 Mdot
.43633 .6828 Mdot
.46051 .60189 Mdot
.51195 .59254 Mdot
.75301 .46463 Mdot
.27894 .48181 Mdot
.56359 .3647 Mdot
.34621 .20767 Mdot
.37251 .35556 Mdot
.42013 .51679 Mdot
.76314 .6859 Mdot
.63877 .40812 Mdot
.39327 .37239 Mdot
.40479 .40824 Mdot
.49439 .67148 Mdot
.54358 .71779 Mdot
.60593 .59312 Mdot
.39968 .49593 Mdot
.44861 .38582 Mdot
.42132 .3954 Mdot
.65911 .4657 Mdot
.46025 .76576 Mdot
.48369 .70927 Mdot
.57408 .31351 Mdot
.41378 .41946 Mdot
.56347 .20421 Mdot
.29549 .51963 Mdot
.634 .60592 Mdot
.52932 .58429 Mdot
.50725 .59548 Mdot
.57784 .35891 Mdot
.58237 .3718 Mdot
.38169 .31002 Mdot
.513 .7924 Mdot
.58923 .73873 Mdot
.67223 .36494 Mdot
.61905 .64471 Mdot
.63249 .48564 Mdot
.68666 .48967 Mdot
.48584 .2937 Mdot
.55098 .36376 Mdot
.52193 .67354 Mdot
.67285 .50858 Mdot
.34722 .55614 Mdot
.45256 .73257 Mdot
.4263 .71956 Mdot
.79979 .61296 Mdot
.5042 .63491 Mdot
.65321 .53225 Mdot
.69722 .50632 Mdot
.70236 .50553 Mdot
.62558 .31079 Mdot
.46561 .64378 Mdot
.50063 .6356 Mdot
.5084 .67757 Mdot
.62196 .23653 Mdot
.46418 .65203 Mdot
.63605 .30757 Mdot
.50734 .45566 Mdot
.73218 .5745 Mdot
.53311 .56535 Mdot
.54449 .34317 Mdot
.46661 .67084 Mdot
.31967 .48654 Mdot
.51437 .58741 Mdot
.43043 .72544 Mdot
.56289 .34134 Mdot
.43068 .57977 Mdot
.68766 .39759 Mdot
.54645 .63304 Mdot
.27942 .49645 Mdot
.65118 .41916 Mdot
.46248 .82117 Mdot
.30133 .54766 Mdot
.64974 .48117 Mdot
.39422 .37785 Mdot
.54558 .36013 Mdot
.41632 .38512 Mdot
.55247 .6382 Mdot
.47295 .29431 Mdot
.22092 .67174 Mdot
.47152 .49163 Mdot
.53539 .62681 Mdot
.51969 .7111 Mdot
.66085 .47465 Mdot
.38202 .34918 Mdot
.61031 .50776 Mdot
.48501 .67377 Mdot
.31644 .51658 Mdot
.29731 .49794 Mdot
.54401 .48732 Mdot
.34821 .76584 Mdot
.50008 .19261 Mdot
.57445 .36224 Mdot
.43475 .39292 Mdot
.33766 .50496 Mdot
.33966 .28081 Mdot
.5456 .31637 Mdot
.59451 .35181 Mdot
.56614 .33781 Mdot
.47327 .60656 Mdot
.42847 .41805 Mdot
.7352 .57422 Mdot
.37086 .35156 Mdot
.49412 .64946 Mdot
.38025 .37383 Mdot
.40892 .34831 Mdot
.3153 .52293 Mdot
.56488 .33634 Mdot
.39 .36594 Mdot
.47272 .59881 Mdot
.67981 .48829 Mdot
.60702 .3017 Mdot
.25018 .58062 Mdot
.22499 .37416 Mdot
.55151 .52187 Mdot
.69272 .51416 Mdot
.44634 .81298 Mdot
.58684 .32841 Mdot
.64784 .25489 Mdot
.22605 .57241 Mdot
.45556 .67212 Mdot
.5707 .15617 Mdot
.38411 .3285 Mdot
.41125 .35043 Mdot
.51893 .6609 Mdot
.37374 .32826 Mdot
.48514 .61977 Mdot
.39794 .35616 Mdot
.50261 .33576 Mdot
.71125 .51561 Mdot
.41393 .37453 Mdot
.54823 .57781 Mdot
.49836 .66423 Mdot
.66691 .524 Mdot
.37678 .40428 Mdot
.43998 .64861 Mdot
.40407 .83895 Mdot
.57823 .37679 Mdot
.64514 .39752 Mdot
.30037 .62905 Mdot
.56245 .37802 Mdot
.66053 .49813 Mdot
.4938 .6806 Mdot
.30106 .49504 Mdot
.63763 .52138 Mdot
.44327 .7383 Mdot
.33225 .52155 Mdot
.69221 .24837 Mdot
.69719 .50768 Mdot
.41475 .35555 Mdot
.33039 .49276 Mdot
.47173 .58399 Mdot
.37894 .34486 Mdot
.40116 .27228 Mdot
.39657 .37083 Mdot
.49875 .67494 Mdot
.52618 .2798 Mdot
.56711 .33314 Mdot
.49848 .62912 Mdot
.42001 .35463 Mdot
.51508 .23494 Mdot
.46177 .61546 Mdot
.50844 .6704 Mdot
.7478 .70252 Mdot
.76037 .52526 Mdot
.31074 .50216 Mdot
.69162 .47306 Mdot
.5281 .59857 Mdot
.28506 .50216 Mdot
.26791 .45656 Mdot
.48769 .59858 Mdot
.62925 .51338 Mdot
.44597 .59747 Mdot
.3737 .39464 Mdot
.57357 .38469 Mdot
.40061 .50663 Mdot
.28356 .51043 Mdot
.14337 .45964 Mdot
.40866 .4174 Mdot
.49567 .68462 Mdot
.53939 .60918 Mdot
.30995 .679 Mdot
.68099 .51263 Mdot
.607 .48186 Mdot
.46513 .62108 Mdot
.62845 .23591 Mdot
.5017 .61288 Mdot
.37159 .33321 Mdot
.65145 .48253 Mdot
.4638 .63181 Mdot
.60296 .3157 Mdot
.51815 .69723 Mdot
.31046 .53187 Mdot
.43166 .22691 Mdot
.44859 .60211 Mdot
.69397 .23673 Mdot
.52474 .50151 Mdot
.41451 .37294 Mdot
.21178 .47613 Mdot
.39537 .83968 Mdot
.67447 .40145 Mdot
.65756 .51486 Mdot
.24237 .6746 Mdot
.42673 .3832 Mdot
.23009 .41053 Mdot
.46806 .83372 Mdot
.50583 .66202 Mdot
.47992 .67309 Mdot
.3485 .67368 Mdot
.37971 .34701 Mdot
.36735 .37674 Mdot
.55952 .62891 Mdot
.50993 .70244 Mdot
.42396 .37828 Mdot
.44717 .63896 Mdot
.53696 .56213 Mdot
.58241 .39711 Mdot
.63209 .50513 Mdot
.59394 .3714 Mdot
.59457 .33834 Mdot
.39913 .22293 Mdot
.49552 .50272 Mdot
.57949 .37995 Mdot
.56189 .31304 Mdot
.36205 .56169 Mdot
.55181 .79115 Mdot
.30305 .48551 Mdot
.37962 .79609 Mdot
.41609 .39529 Mdot
.4665 .63616 Mdot
.70235 .49915 Mdot
.57552 .74157 Mdot
.26659 .46811 Mdot
.78474 .4001 Mdot
.50815 .67964 Mdot
.42935 .37013 Mdot
.63661 .39236 Mdot
.43151 .60024 Mdot
.44152 .41925 Mdot
.49326 .60163 Mdot
.41432 .33914 Mdot
.59999 .78032 Mdot
.32488 .29092 Mdot
.45021 .35737 Mdot
.70522 .47419 Mdot
.5051 .59875 Mdot
.63801 .5415 Mdot
.55906 .37802 Mdot
.31304 .48417 Mdot
.30542 .50125 Mdot
.48107 .65784 Mdot
.54104 .70208 Mdot
.2424 .42052 Mdot
.48925 .65792 Mdot
.52401 .61588 Mdot
.55576 .3989 Mdot
.52722 .60928 Mdot
.54214 .61631 Mdot
.53203 .65324 Mdot
.54005 .65079 Mdot
.5594 .33655 Mdot
.41185 .30043 Mdot
.53827 .54792 Mdot
.56935 .60477 Mdot
.60116 .3414 Mdot
.2459 .65803 Mdot
.58855 .32695 Mdot
.48069 .83541 Mdot
.56415 .31677 Mdot
.30742 .50811 Mdot
.26469 .66989 Mdot
.57105 .62857 Mdot
.62533 .51062 Mdot
.60462 .4165 Mdot
.32599 .49222 Mdot
.56239 .35709 Mdot
.39565 .35425 Mdot
.75925 .6964 Mdot
.63213 .55293 Mdot
.74495 .5129 Mdot
.63781 .42597 Mdot
.41951 .29443 Mdot
.38388 .40492 Mdot
.68215 .5307 Mdot
.6361 .75579 Mdot
.53974 .619 Mdot
.28556 .50074 Mdot
.47389 .6536 Mdot
.5572 .37898 Mdot
.43165 .38245 Mdot
.23594 .33336 Mdot
.29442 .49896 Mdot
.84541 .57328 Mdot
.39893 .40002 Mdot
.53864 .62917 Mdot
.58797 .32445 Mdot
.85069 .48749 Mdot
.59289 .36919 Mdot
.58869 .64108 Mdot
.68942 .49882 Mdot
.19222 .37618 Mdot
.64496 .51462 Mdot
.37459 .2804 Mdot
.84222 .37221 Mdot
.31045 .32039 Mdot
.68218 .48504 Mdot
.37849 .47253 Mdot
.51168 .62218 Mdot
.51081 .59211 Mdot
.28687 .29958 Mdot
.69942 .48065 Mdot
.53502 .61438 Mdot
.56654 .26486 Mdot
.53891 .30588 Mdot
.79751 .58088 Mdot
.38555 .40231 Mdot
.48428 .61649 Mdot
.57329 .40022 Mdot
.54916 .37869 Mdot
.4213 .41134 Mdot
.59338 .34426 Mdot
.49861 .63831 Mdot
.63921 .51787 Mdot
.3907 .44127 Mdot
.29908 .51157 Mdot
.1908 .62588 Mdot
.32627 .53708 Mdot
.39233 .37318 Mdot
.44806 .67221 Mdot
.42288 .38335 Mdot
.53764 .89741 Mdot
.50608 .62379 Mdot
.67642 .48505 Mdot
.52853 .6155 Mdot
.50852 .60111 Mdot
.53089 .66458 Mdot
.42038 .36519 Mdot
.23241 .54936 Mdot
.46354 .60887 Mdot
.58589 .35097 Mdot
.65488 .62724 Mdot
.49186 .57419 Mdot
.35448 .44675 Mdot
.41621 .7034 Mdot
.71088 .4396 Mdot
.696 .48903 Mdot
.40839 .37153 Mdot
.66987 .49417 Mdot
.65393 .24237 Mdot
.66024 .4981 Mdot
.63137 .66938 Mdot
.64668 .75305 Mdot
.72003 .69881 Mdot
.7348 .68255 Mdot
.44314 .45984 Mdot
.69663 .47652 Mdot
.27257 .52873 Mdot
.6773 .47174 Mdot
.68202 .51617 Mdot
.52576 .09881 Mdot
.62957 .53596 Mdot
.47999 .61152 Mdot
.51387 .57508 Mdot
.33683 .29942 Mdot
.30841 .59171 Mdot
.52051 .63228 Mdot
.5272 .62869 Mdot
.33723 .50104 Mdot
.65181 .24554 Mdot
.48436 .30551 Mdot
.76117 .52142 Mdot
.20206 .56404 Mdot
.47356 .65075 Mdot
.52017 .5894 Mdot
.55531 .5694 Mdot
.82137 .40943 Mdot
.36932 .23084 Mdot
.70521 .47019 Mdot
.5673 .60909 Mdot
.27013 .34622 Mdot
.50933 .68055 Mdot
.46307 .61815 Mdot
.50668 .63004 Mdot
.42739 .38296 Mdot
.69501 .48071 Mdot
.55307 .63032 Mdot
.29842 .67953 Mdot
.4748 .60977 Mdot
.63959 .36565 Mdot
.1541 .50374 Mdot
.47855 .6172 Mdot
.63875 .47399 Mdot
.51389 .5929 Mdot
.67064 .51831 Mdot
.66494 .53197 Mdot
.56274 .62455 Mdot
.61527 .64459 Mdot
.66145 .46426 Mdot
.4941 .65029 Mdot
.39375 .35252 Mdot
.401 .79608 Mdot
.49125 .67192 Mdot
.3006 .4867 Mdot
.45661 .63172 Mdot
.27562 .51201 Mdot
.52037 .62378 Mdot
.41445 .41688 Mdot
.57917 .7258 Mdot
.41165 .38876 Mdot
.29951 .2701 Mdot
.43378 .41472 Mdot
.83451 .60212 Mdot
.69046 .51691 Mdot
.51366 .27212 Mdot
.73476 .31406 Mdot
.59506 .25685 Mdot
.5531 .42803 Mdot
.47462 .43514 Mdot
.59858 .35985 Mdot
.68337 .50725 Mdot
.69825 .30236 Mdot
.32824 .43564 Mdot
.32446 .39401 Mdot
.43092 .35755 Mdot
.31765 .21036 Mdot
.6805 .24454 Mdot
.49128 .69185 Mdot
.66526 .71475 Mdot
.69026 .65618 Mdot
.51452 .67977 Mdot
.53072 .66753 Mdot
.41763 .32855 Mdot
.45163 .62373 Mdot
.7466 .42273 Mdot
.38643 .38099 Mdot
.32185 .48951 Mdot
.67035 .47467 Mdot
.29406 .52712 Mdot
.31387 .45711 Mdot
.47848 .42829 Mdot
.39329 .35811 Mdot
.44122 .6445 Mdot
.52027 .63847 Mdot
.66191 .52257 Mdot
.62142 .57451 Mdot
.64296 .47901 Mdot
.32435 .504 Mdot
.38588 .38946 Mdot
.51501 .16912 Mdot
.52324 .63719 Mdot
.63995 .50051 Mdot
.56148 .43856 Mdot
.52983 .60279 Mdot
.55737 .36989 Mdot
.51378 .61649 Mdot
.67762 .47583 Mdot
.52716 .60972 Mdot
.64621 .51487 Mdot
.39497 .37959 Mdot
.53807 .64145 Mdot
.52158 .66137 Mdot
.84227 .54909 Mdot
.32197 .51392 Mdot
.68394 .53094 Mdot
.39496 .53252 Mdot
.53016 .5934 Mdot
.48428 .25402 Mdot
.49008 .60443 Mdot
.728 .48167 Mdot
.48197 .69043 Mdot
.64458 .39997 Mdot
.56467 .62955 Mdot
.47482 .66003 Mdot
.57951 .48428 Mdot
.6798 .65968 Mdot
.54222 .53474 Mdot
.55116 .32046 Mdot
.67786 .53455 Mdot
.78915 .59154 Mdot
.36087 .41384 Mdot
.37374 .40312 Mdot
.36529 .62287 Mdot
.55483 .6204 Mdot
.48152 .62482 Mdot
.71574 .44542 Mdot
.28673 .50754 Mdot
.63076 .52461 Mdot
.33158 .50511 Mdot
.8204 .60039 Mdot
.33141 .52729 Mdot
.3696 .33373 Mdot
.242 .40422 Mdot
.47648 .17647 Mdot
.33691 .50591 Mdot
.67762 .47459 Mdot
.27992 .34991 Mdot
.54518 .61904 Mdot
.5426 .50025 Mdot
.30995 .51683 Mdot
.23503 .28686 Mdot
.54173 .61837 Mdot
.55857 .43005 Mdot
.58276 .38297 Mdot
.33609 .5049 Mdot
.60399 .36822 Mdot
.51288 .65316 Mdot
.48733 .30646 Mdot
.65767 .51378 Mdot
.60723 .35913 Mdot
.48249 .57153 Mdot
.32733 .50601 Mdot
.40964 .41984 Mdot
.61197 .35095 Mdot
.56885 .31197 Mdot
.29895 .72285 Mdot
.21974 .34266 Mdot
.38705 .39265 Mdot
.78885 .53865 Mdot
.54603 .33929 Mdot
.54622 .6099 Mdot
.67253 .2663 Mdot
.5088 .59449 Mdot
.52859 .20703 Mdot
.40196 .36757 Mdot
.41903 .29701 Mdot
.52725 .59816 Mdot
.48252 .67013 Mdot
.6183 .53311 Mdot
.4042 .39119 Mdot
.64871 .49849 Mdot
.71353 .50732 Mdot
.39383 .38148 Mdot
.65545 .50677 Mdot
.33569 .49018 Mdot
.74198 .36065 Mdot
.56973 .31994 Mdot
.58165 .33771 Mdot
.42554 .39316 Mdot
.41354 .36943 Mdot
.41744 .38168 Mdot
.5143 .61561 Mdot
.63748 .49893 Mdot
.50585 .65113 Mdot
.45216 .65125 Mdot
.6706 .61255 Mdot
.69881 .48815 Mdot
.50368 .643 Mdot
.44855 .50403 Mdot
.5831 .62657 Mdot
.3852 .35671 Mdot
.57946 .38175 Mdot
.54935 .26277 Mdot
.41453 .26421 Mdot
.48783 .61434 Mdot
.25369 .54991 Mdot
.67668 .4728 Mdot
.30996 .4946 Mdot
.33523 .5295 Mdot
.3146 .50114 Mdot
.5308 .36163 Mdot
.70196 .50551 Mdot
.7351 .54588 Mdot
.48259 .6194 Mdot
.73627 .4969 Mdot
.70529 .46679 Mdot
.2751 .36362 Mdot
.57729 .38047 Mdot
.53043 .61488 Mdot
.40808 .50479 Mdot
.56182 .76944 Mdot
.5132 .5986 Mdot
.49832 .57296 Mdot
.21551 .52752 Mdot
.44604 .68475 Mdot
.62161 .50929 Mdot
.84691 .50345 Mdot
.48141 .58094 Mdot
.55685 .19886 Mdot
.20466 .67903 Mdot
.49492 .6079 Mdot
.47215 .66545 Mdot
.52436 .64403 Mdot
.5109 .58639 Mdot
.65403 .46469 Mdot
.33948 .58215 Mdot
.5471 .33245 Mdot
.73113 .5092 Mdot
.55262 .36631 Mdot
.44623 .38377 Mdot
.41962 .29857 Mdot
.68721 .50216 Mdot
.2956 .52232 Mdot
.18388 .55326 Mdot
.81259 .48867 Mdot
.41215 .41138 Mdot
.4503 .1912 Mdot
.31018 .51467 Mdot
.53656 .58323 Mdot
.30769 .47995 Mdot
.37754 .39439 Mdot
.57886 .33 Mdot
.44401 .60728 Mdot
.6857 .48652 Mdot
.64218 .48611 Mdot
.53237 .61022 Mdot
.23129 .39367 Mdot
.56662 .38495 Mdot
.55331 .31366 Mdot
.47878 .60211 Mdot
.47763 .58094 Mdot
.6495 .50032 Mdot
.4195 .4011 Mdot
.73538 .69038 Mdot
.29968 .49231 Mdot
.50805 .68331 Mdot
.52621 .60505 Mdot
.7495 .69873 Mdot
.58735 .34834 Mdot
.4074 .42522 Mdot
.46052 .67847 Mdot
.66196 .34344 Mdot
.45362 .66846 Mdot
.55442 .57322 Mdot
.39106 .35269 Mdot
.49702 .54992 Mdot
.53474 .6707 Mdot
.70426 .52416 Mdot
.59893 .36959 Mdot
.66982 .4877 Mdot
.70145 .52707 Mdot
.7612 .39021 Mdot
.55688 .36011 Mdot
.50978 .629 Mdot
.57133 .37785 Mdot
.48917 .59781 Mdot
.48059 .58614 Mdot
.58197 .37856 Mdot
.6479 .49997 Mdot
.23662 .66135 Mdot
.35525 .30471 Mdot
.49786 .58397 Mdot
.55603 .63791 Mdot
.31215 .57751 Mdot
.35202 .46738 Mdot
.48456 .67402 Mdot
.66603 .47118 Mdot
.51741 .651 Mdot
.58278 .39177 Mdot
.32873 .48192 Mdot
.68083 .48619 Mdot
.4059 .40482 Mdot
.4052 .41383 Mdot
.68538 .4008 Mdot
.41088 .34632 Mdot
.47714 .67327 Mdot
.6152 .55975 Mdot
.61561 .51103 Mdot
.18205 .51589 Mdot
.39321 .38567 Mdot
.29323 .48884 Mdot
.50338 .67112 Mdot
.38877 .68198 Mdot
.57961 .40179 Mdot
.51412 .12034 Mdot
.78532 .45649 Mdot
.29809 .47841 Mdot
.7408 .5333 Mdot
.42859 .41432 Mdot
.55212 .6405 Mdot
.29889 .48796 Mdot
.38415 .40339 Mdot
.4888 .59043 Mdot
.5674 .6027 Mdot
.59338 .57398 Mdot
.47673 .40404 Mdot
.57347 .37629 Mdot
.42278 .34597 Mdot
.28388 .48657 Mdot
.44977 .38001 Mdot
.67606 .52708 Mdot
.46499 .64752 Mdot
.44907 .67089 Mdot
.41915 .40294 Mdot
.37466 .40763 Mdot
.49876 .64696 Mdot
.68586 .47871 Mdot
.33845 .34479 Mdot
.47499 .646 Mdot
.55099 .29401 Mdot
.69368 .46774 Mdot
.38479 .39712 Mdot
.47498 .66361 Mdot
.3087 .54453 Mdot
.40494 .40097 Mdot
.38347 .35925 Mdot
.52173 .59004 Mdot
.33864 .50697 Mdot
.52665 .68432 Mdot
.5777 .32154 Mdot
.30703 .2244 Mdot
.5822 .39232 Mdot
.36185 .4246 Mdot
.45583 .69905 Mdot
.65852 .30064 Mdot
.69514 .49842 Mdot
.38971 .61653 Mdot
.56494 .26512 Mdot
.53317 .56007 Mdot
.38609 .76902 Mdot
.63015 .36451 Mdot
.19157 .49298 Mdot
.41273 .75543 Mdot
.31129 .5207 Mdot
.56324 .35399 Mdot
.47204 .66564 Mdot
.58627 .3966 Mdot
.29298 .49105 Mdot
.30458 .2677 Mdot
.49212 .67341 Mdot
.65617 .47837 Mdot
.50045 .64003 Mdot
.64428 .48756 Mdot
.50647 .58291 Mdot
.51218 .6941 Mdot
.58535 .25812 Mdot
.40649 .55328 Mdot
.45595 .67113 Mdot
.88475 .50178 Mdot
.58941 .60009 Mdot
.30994 .48907 Mdot
.50351 .65913 Mdot
.46016 .39202 Mdot
.54903 .37103 Mdot
.62727 .29509 Mdot
.42812 .38121 Mdot
.57347 .31459 Mdot
.6528 .50381 Mdot
.40149 .37127 Mdot
.41757 .4108 Mdot
.4874 .55267 Mdot
.31238 .47611 Mdot
.575 .34099 Mdot
.46208 .63391 Mdot
.48798 .67115 Mdot
.79513 .53235 Mdot
.31195 .43504 Mdot
.65939 .57641 Mdot
.79213 .34145 Mdot
.70554 .51204 Mdot
.32654 .49528 Mdot
.42402 .36738 Mdot
.45853 .66417 Mdot
.49543 .63402 Mdot
.49713 .25917 Mdot
.65777 .46774 Mdot
.48821 .46468 Mdot
.65261 .58164 Mdot
.34706 .55529 Mdot
.37746 .56906 Mdot
.67007 .47342 Mdot
.37313 .56886 Mdot
.2846 .47756 Mdot
.31494 .76857 Mdot
.40827 .54525 Mdot
.57994 .38408 Mdot
.3641 .568 Mdot
.63175 .52451 Mdot
.47097 .60226 Mdot
.3971 .35055 Mdot
.40728 .34766 Mdot
.66134 .48873 Mdot
.44731 .4101 Mdot
.3098 .52402 Mdot
.46031 .6552 Mdot
.78485 .48831 Mdot
.71158 .378 Mdot
.43209 .39125 Mdot
.46513 .56667 Mdot
.56477 .33837 Mdot
.53258 .60869 Mdot
.32749 .51971 Mdot
.56333 .37285 Mdot
.55571 .79909 Mdot
.52945 .30926 Mdot
.49479 .66795 Mdot
.7542 .69699 Mdot
.55872 .35994 Mdot
.5251 .73922 Mdot
.47011 .64 Mdot
.58681 .33182 Mdot
.41953 .66389 Mdot
.41899 .27967 Mdot
.49685 .48949 Mdot
.46988 .83554 Mdot
.52788 .47417 Mdot
.43117 .36816 Mdot
.41853 .28864 Mdot
.57969 .24276 Mdot
.54801 .34371 Mdot
.38947 .42302 Mdot
.49302 .50565 Mdot
.6031 .36782 Mdot
.5408 .59027 Mdot
.49513 .60369 Mdot
.36068 .23677 Mdot
.61221 .40685 Mdot
.36305 .28257 Mdot
.69795 .41986 Mdot
.53117 .59305 Mdot
.50403 .69198 Mdot
.4915 .63382 Mdot
.62946 .48845 Mdot
.57908 .36904 Mdot
.86603 .50622 Mdot
.55969 .37802 Mdot
.64829 .60913 Mdot
.4202 .39402 Mdot
.38444 .40106 Mdot
.48304 .61511 Mdot
.56629 .42992 Mdot
.48395 .77642 Mdot
.4962 .64267 Mdot
.34147 .47436 Mdot
.36339 .24793 Mdot
.49447 .57822 Mdot
.69235 .49131 Mdot
.51915 .55286 Mdot
.44698 .70235 Mdot
.5681 .31991 Mdot
.29654 .51899 Mdot
.39978 .66733 Mdot
.57613 .33024 Mdot
.48251 .62575 Mdot
.66636 .32342 Mdot
.50981 .60777 Mdot
.49733 .58527 Mdot
.62765 .59371 Mdot
.33832 .52529 Mdot
.40658 .38078 Mdot
.31568 .50371 Mdot
.68339 .51279 Mdot
.45086 .09449 Mdot
.32929 .52897 Mdot
.52073 .78941 Mdot
.32871 .24033 Mdot
.36591 .56394 Mdot
.63009 .52654 Mdot
.29529 .48231 Mdot
.57403 .38666 Mdot
.39978 .79771 Mdot
.58654 .63188 Mdot
.6245 .3688 Mdot
.47631 .64083 Mdot
.66164 .54588 Mdot
.63502 .49115 Mdot
.60652 .35366 Mdot
.66894 .53237 Mdot
.51219 .53451 Mdot
.48568 .58925 Mdot
.55208 .34608 Mdot
.67941 .36475 Mdot
.54638 .33044 Mdot
.39863 .47528 Mdot
.49763 .6596 Mdot
.67861 .48239 Mdot
.52903 .67407 Mdot
.63387 .4705 Mdot
.41464 .42402 Mdot
.44155 .65317 Mdot
.30948 .52497 Mdot
.65116 .29973 Mdot
.38842 .39655 Mdot
.36866 .5519 Mdot
.66501 .5214 Mdot
.52753 .36374 Mdot
.66414 .52547 Mdot
.61472 .50339 Mdot
.5882 .3256 Mdot
.6429 .53756 Mdot
.46862 .66276 Mdot
.49323 .4953 Mdot
.65883 .51938 Mdot
.57432 .35357 Mdot
.29354 .5117 Mdot
.64688 .51032 Mdot
.37817 .32685 Mdot
.50101 .67257 Mdot
.41914 .36656 Mdot
.3248 .45924 Mdot
.6451 .54833 Mdot
.34381 .50269 Mdot
.37136 .39632 Mdot
.28239 .51516 Mdot
.19038 .45829 Mdot
.5867 .31252 Mdot
.61576 .61553 Mdot
.33468 .46674 Mdot
.62516 .50792 Mdot
.22833 .58099 Mdot
.45224 .64447 Mdot
.50413 .67229 Mdot
.27653 .51073 Mdot
.6351 .49096 Mdot
.25907 .74009 Mdot
.54199 .70807 Mdot
.41452 .46489 Mdot
.54288 .37453 Mdot
.84526 .587 Mdot
.40192 .47007 Mdot
.18542 .64446 Mdot
.46971 .56828 Mdot
.3662 .37626 Mdot
.49218 .61866 Mdot
.54028 .24898 Mdot
.32356 .50958 Mdot
.3584 .44474 Mdot
.47519 .69768 Mdot
.40176 .37717 Mdot
.52723 .65455 Mdot
.57147 .4885 Mdot
.49234 .73777 Mdot
.28296 .49693 Mdot
.24848 .38091 Mdot
.64457 .54698 Mdot
.30169 .51243 Mdot
.37986 .3888 Mdot
.40651 .57545 Mdot
.48881 .58936 Mdot
.54364 .59297 Mdot
.34518 .55534 Mdot
.63423 .50364 Mdot
.41708 .35548 Mdot
.57911 .32403 Mdot
.29088 .51483 Mdot
.51868 .63929 Mdot
.45116 .65197 Mdot
.49099 .24817 Mdot
.56025 .34107 Mdot
.38048 .34862 Mdot
.59193 .37874 Mdot
.42941 .40994 Mdot
.46429 .60564 Mdot
.39805 .41016 Mdot
.55887 .60956 Mdot
.63504 .3358 Mdot
.6241 .60413 Mdot
.67524 .67591 Mdot
.39706 .36807 Mdot
.56898 .79223 Mdot
.55942 .34476 Mdot
.5937 .36312 Mdot
.3842 .20811 Mdot
.59173 .61815 Mdot
.80014 .50717 Mdot
.34508 .72997 Mdot
.557 .33658 Mdot
.57055 .34178 Mdot
.41791 .36663 Mdot
.64596 .5378 Mdot
.69956 .51789 Mdot
.42657 .40987 Mdot
.30854 .62909 Mdot
.63069 .52342 Mdot
.36408 .77531 Mdot
.80034 .56314 Mdot
.54794 .58081 Mdot
.35482 .34597 Mdot
.30303 .49611 Mdot
.32157 .62591 Mdot
.56352 .49297 Mdot
.49138 .67511 Mdot
.38012 .64064 Mdot
.42259 .39728 Mdot
.56902 .42113 Mdot
.46799 .82733 Mdot
.53292 .64797 Mdot
.46681 .63806 Mdot
.48946 .62738 Mdot
.32271 .47606 Mdot
.58238 .69121 Mdot
.46608 .65658 Mdot
.3058 .62885 Mdot
.53307 .60012 Mdot
.49875 .74199 Mdot
.30862 .50128 Mdot
.4724 .5172 Mdot
.32785 .44818 Mdot
.84139 .51679 Mdot
.4944 .73067 Mdot
.57284 .31897 Mdot
.33873 .40966 Mdot
.59605 .36514 Mdot
.64453 .66703 Mdot
.39616 .54736 Mdot
.70821 .50662 Mdot
.48813 .67399 Mdot
.39112 .37399 Mdot
.63552 .49095 Mdot
.44798 .27791 Mdot
.4932 .09495 Mdot
.56013 .31939 Mdot
.33612 .83101 Mdot
.59046 .33951 Mdot
.41927 .40989 Mdot
.65061 .49981 Mdot
.62656 .76504 Mdot
.75978 .45361 Mdot
.64898 .51041 Mdot
.23244 .69154 Mdot
.68714 .45394 Mdot
.40055 .63424 Mdot
.62296 .53454 Mdot
.57102 .34971 Mdot
.56727 .41197 Mdot
.49903 .52981 Mdot
.46297 .62084 Mdot
.48065 .43415 Mdot
.48031 .77267 Mdot
.45243 .64625 Mdot
.38608 .38326 Mdot
.60522 .60017 Mdot
.37371 .62249 Mdot
.63707 .53441 Mdot
.54583 .3015 Mdot
.46762 .64659 Mdot
.52102 .59861 Mdot
.4816 .59418 Mdot
.79227 .43857 Mdot
.31036 .76607 Mdot
.46577 .60622 Mdot
.51661 .58497 Mdot
.40103 .3738 Mdot
.36028 .49186 Mdot
.31171 .32567 Mdot
.76089 .55363 Mdot
.53585 .65141 Mdot
.30151 .50753 Mdot
.27355 .49662 Mdot
.44801 .63928 Mdot
.4855 .50093 Mdot
.66738 .31511 Mdot
.46151 .63611 Mdot
.60252 .59824 Mdot
.45764 .34007 Mdot
.37668 .34855 Mdot
.40942 .40344 Mdot
.6686 .53814 Mdot
.42471 .40422 Mdot
.4161 .41819 Mdot
.57047 .77833 Mdot
.51113 .46794 Mdot
.62561 .31611 Mdot
.32399 .50153 Mdot
.49973 .6276 Mdot
.56016 .54561 Mdot
.66135 .33157 Mdot
.60013 .35534 Mdot
.68155 .49438 Mdot
.55258 .38047 Mdot
.26484 .51477 Mdot
.77373 .43226 Mdot
.44019 .37408 Mdot
.56385 .32699 Mdot
.58137 .3045 Mdot
.30085 .50549 Mdot
.59885 .38346 Mdot
.50015 .36412 Mdot
.45808 .59971 Mdot
.64469 .72969 Mdot
.49231 .6489 Mdot
.18174 .56901 Mdot
.56976 .3353 Mdot
.54966 .39438 Mdot
.47355 .62529 Mdot
.40187 .39951 Mdot
.41149 .63083 Mdot
.46616 .61633 Mdot
.42467 .40279 Mdot
.48692 .69307 Mdot
.31781 .53752 Mdot
.68754 .46861 Mdot
.75804 .45588 Mdot
.32109 .20513 Mdot
.3086 .47686 Mdot
.4554 .27331 Mdot
.50119 .67941 Mdot
.20991 .37727 Mdot
.64402 .51184 Mdot
.4744 .68251 Mdot
.37805 .59435 Mdot
.64951 .52383 Mdot
.66965 .49766 Mdot
.51868 .61571 Mdot
.58484 .38359 Mdot
.38718 .39769 Mdot
.30214 .50144 Mdot
.16988 .58918 Mdot
.48093 .65115 Mdot
.51972 .6586 Mdot
.30556 .51313 Mdot
.55437 .35809 Mdot
.45181 .66412 Mdot
.33191 .68715 Mdot
.29268 .76926 Mdot
.59083 .33648 Mdot
.54183 .62568 Mdot
.63433 .69423 Mdot
.5141 .72522 Mdot
.16951 .41293 Mdot
.52968 .50121 Mdot
.40984 .37675 Mdot
.49259 .71482 Mdot
.64021 .18291 Mdot
.29359 .51549 Mdot
.80961 .49254 Mdot
.52257 .59912 Mdot
.52716 .63282 Mdot
.65131 .47226 Mdot
.50308 .65118 Mdot
.68644 .49927 Mdot
.41271 .16922 Mdot
.77697 .67294 Mdot
.68224 .52895 Mdot
.62382 .51889 Mdot
.40872 .69276 Mdot
.57676 .28881 Mdot
.65962 .49149 Mdot
.4807 .58417 Mdot
.44566 .51651 Mdot
.6958 .44362 Mdot
.29401 .4854 Mdot
.23319 .53614 Mdot
.56791 .65227 Mdot
.27039 .55206 Mdot
.24478 .66031 Mdot
.57881 .57136 Mdot
.39776 .48858 Mdot
.59068 .35256 Mdot
.53384 .6478 Mdot
.40516 .34683 Mdot
.40437 .34507 Mdot
.56062 .60977 Mdot
.50707 .61789 Mdot
.67722 .51619 Mdot
.29008 .50282 Mdot
.54513 .35149 Mdot
.52519 .63227 Mdot
.39185 .60783 Mdot
.28929 .51926 Mdot
.66085 .53583 Mdot
.64543 .62507 Mdot
.33503 .53701 Mdot
.53222 .6851 Mdot
.46397 .62478 Mdot
.50421 .63496 Mdot
.49849 .52843 Mdot
.58271 .36885 Mdot
.2529 .65568 Mdot
.51493 .57795 Mdot
.82637 .59047 Mdot
.61127 .29565 Mdot
.48482 .70729 Mdot
.67035 .52765 Mdot
.54174 .30855 Mdot
.44301 .40661 Mdot
.74834 .34977 Mdot
.49166 .66537 Mdot
.24034 .38515 Mdot
.35442 .24252 Mdot
.39159 .42031 Mdot
.65248 .46073 Mdot
.31746 .49892 Mdot
.49749 .63935 Mdot
.61236 .64662 Mdot
.49238 .60603 Mdot
.27609 .47981 Mdot
.37957 .36505 Mdot
.59094 .35636 Mdot
.18974 .51263 Mdot
.41586 .34495 Mdot
.66958 .49494 Mdot
.66639 .79446 Mdot
.68759 .49813 Mdot
.6979 .51996 Mdot
.65705 .6239 Mdot
.58384 .36936 Mdot
.57223 .13953 Mdot
.43627 .17156 Mdot
.45896 .60761 Mdot
.55573 .35284 Mdot
.66653 .48209 Mdot
.53768 .61243 Mdot
.66638 .45229 Mdot
.70493 .49684 Mdot
.47366 .59371 Mdot
.52917 .63739 Mdot
.31364 .30049 Mdot
.43243 .79452 Mdot
.31924 .49986 Mdot
.69256 .50805 Mdot
.75391 .43184 Mdot
.53897 .61024 Mdot
.48143 .61975 Mdot
.52108 .21767 Mdot
.31961 .47781 Mdot
.73212 .38467 Mdot
.52171 .59884 Mdot
.69879 .75074 Mdot
.53183 .5501 Mdot
.6696 .46413 Mdot
.59664 .35885 Mdot
.83731 .53482 Mdot
.49612 .3657 Mdot
.6851 .50022 Mdot
.30263 .5278 Mdot
.61651 .52991 Mdot
.54451 .79344 Mdot
.55355 .36789 Mdot
.67748 .47566 Mdot
.40182 .50481 Mdot
.57192 .36854 Mdot
.57114 .33096 Mdot
.67995 .60952 Mdot
.43166 .4223 Mdot
.30655 .47473 Mdot
.57292 .34044 Mdot
.64074 .25042 Mdot
.57036 .35752 Mdot
.41483 .17788 Mdot
.53632 .64069 Mdot
.3523 .64514 Mdot
.35768 .42278 Mdot
.5496 .68583 Mdot
.56498 .33352 Mdot
.3359 .49518 Mdot
.49094 .59016 Mdot
.64268 .54249 Mdot
.28843 .49845 Mdot
.61214 .38883 Mdot
.42504 .3793 Mdot
.65882 .52777 Mdot
.59734 .41324 Mdot
.64508 .48479 Mdot
.69759 .30295 Mdot
.30587 .242 Mdot
.42439 .73297 Mdot
.76153 .4501 Mdot
.48994 .5881 Mdot
.31065 .73195 Mdot
.54529 .62578 Mdot
.51237 .61136 Mdot
.38405 .39058 Mdot
.36389 .63914 Mdot
.64875 .49887 Mdot
.20854 .64883 Mdot
.56723 .32157 Mdot
.84255 .52376 Mdot
.49162 .72685 Mdot
.49946 .68557 Mdot
.6624 .51755 Mdot
.67202 .46723 Mdot
.67618 .64675 Mdot
.44053 .35408 Mdot
.50484 .68183 Mdot
.46283 .58114 Mdot
.56266 .60283 Mdot
.5755 .32531 Mdot
.43339 .51497 Mdot
.43395 .37252 Mdot
.25976 .29134 Mdot
.37762 .36812 Mdot
.24725 .52136 Mdot
.64545 .54011 Mdot
.32843 .52928 Mdot
.47871 .61991 Mdot
.61417 .56975 Mdot
.6531 .46909 Mdot
.27747 .51142 Mdot
.33399 .49854 Mdot
.44768 .25119 Mdot
.58112 .37856 Mdot
.46212 .61741 Mdot
.47283 .66225 Mdot
.50878 .64621 Mdot
.51228 .61733 Mdot
.56008 .32064 Mdot
.48354 .59579 Mdot
.59023 .4023 Mdot
.75641 .35141 Mdot
.35293 .67812 Mdot
.53445 .47417 Mdot
.48136 .19808 Mdot
.63447 .53268 Mdot
.64519 .26263 Mdot
.43866 .68024 Mdot
.73431 .29928 Mdot
.29581 .28574 Mdot
.4737 .58012 Mdot
.40133 .41383 Mdot
.43419 .70613 Mdot
.42834 .35635 Mdot
.18877 .66697 Mdot
.54417 .23151 Mdot
.41993 .79051 Mdot
.48958 .67179 Mdot
.48944 .49455 Mdot
.61055 .22623 Mdot
.54645 .61683 Mdot
.48478 .23838 Mdot
.52625 .20574 Mdot
.27122 .35199 Mdot
.33706 .50816 Mdot
.48128 .6609 Mdot
.55263 .54036 Mdot
.46496 .65961 Mdot
.48818 .61794 Mdot
.48274 .59474 Mdot
.54312 .36526 Mdot
.47043 .67704 Mdot
.50202 .59114 Mdot
.24204 .43155 Mdot
.38678 .56395 Mdot
.36914 .36478 Mdot
.36605 .21878 Mdot
.33174 .52787 Mdot
.66443 .51958 Mdot
.29924 .74767 Mdot
.57921 .38376 Mdot
.68272 .64796 Mdot
.50842 .62446 Mdot
.33112 .30221 Mdot
.53287 .30232 Mdot
.30509 .52736 Mdot
.37933 .4018 Mdot
.42433 .80662 Mdot
.39011 .37876 Mdot
.53019 .32927 Mdot
.39771 .39771 Mdot
.46979 .71143 Mdot
.68049 .51484 Mdot
.45391 .62644 Mdot
.57734 .34251 Mdot
.40931 .4073 Mdot
.31046 .58587 Mdot
.49246 .63127 Mdot
.39451 .3817 Mdot
.45585 .62328 Mdot
.75226 .50394 Mdot
.77721 .56312 Mdot
.40741 .41792 Mdot
.59623 .31966 Mdot
.58344 .35477 Mdot
.33237 .51896 Mdot
.65556 .52543 Mdot
.6825 .49754 Mdot
.56311 .3708 Mdot
.60183 .53268 Mdot
.53785 .64977 Mdot
.53648 .62239 Mdot
.82986 .56031 Mdot
.46699 .66553 Mdot
.40997 .57346 Mdot
.41048 .50667 Mdot
.66336 .53809 Mdot
.51371 .68604 Mdot
.5227 .6124 Mdot
.49714 .66943 Mdot
.76257 .49864 Mdot
.42465 .40005 Mdot
.53442 .64508 Mdot
.32858 .49107 Mdot
.39767 .30763 Mdot
.53251 .60789 Mdot
.51122 .54426 Mdot
.68306 .49548 Mdot
.79617 .36038 Mdot
.5918 .34486 Mdot
.38021 .38682 Mdot
.39782 .36703 Mdot
.24345 .63806 Mdot
.61214 .2483 Mdot
.41362 .50576 Mdot
.20195 .34677 Mdot
.58636 .25898 Mdot
.33072 .50279 Mdot
.3617 .35963 Mdot
.59379 .42017 Mdot
.40325 .36118 Mdot
.55352 .32397 Mdot
.53972 .62907 Mdot
.53769 .64805 Mdot
.6241 .1879 Mdot
.44876 .65746 Mdot
.31221 .49764 Mdot
.54364 .34484 Mdot
.63207 .51926 Mdot
.29993 .5251 Mdot
.59366 .37658 Mdot
.66978 .53699 Mdot
.47619 .57842 Mdot
.50375 .57558 Mdot
.67958 .49735 Mdot
.65293 .47301 Mdot
.46718 .62353 Mdot
.50782 .31016 Mdot
.62524 .5142 Mdot
.67085 .47287 Mdot
.4399 .38071 Mdot
.40981 .34702 Mdot
.5669 .57809 Mdot
.5614 .34505 Mdot
.49784 .5907 Mdot
.39821 .37127 Mdot
.32913 .52838 Mdot
.64519 .50146 Mdot
.50316 .58473 Mdot
.52895 .61775 Mdot
.29931 .5057 Mdot
.32414 .52657 Mdot
.3291 .51761 Mdot
.59233 .41061 Mdot
.50834 .65478 Mdot
.65461 .49929 Mdot
.58457 .37418 Mdot
.27799 .48936 Mdot
.3065 .48122 Mdot
.3712 .34257 Mdot
.46505 .66872 Mdot
.39223 .44151 Mdot
.65775 .19236 Mdot
.79509 .63685 Mdot
.40801 .42169 Mdot
.44532 .40173 Mdot
.27083 .57778 Mdot
.62139 .42966 Mdot
.55964 .37439 Mdot
.35485 .47337 Mdot
.42975 .73401 Mdot
.44941 .60455 Mdot
.4982 .57935 Mdot
.50064 .69527 Mdot
.33163 .51402 Mdot
.37026 .66259 Mdot
.68649 .50387 Mdot
.46015 .52847 Mdot
.28795 .51882 Mdot
.37037 .38981 Mdot
.35788 .36099 Mdot
.37634 .37398 Mdot
.53105 .58009 Mdot
.68135 .68352 Mdot
.63418 .26611 Mdot
.32922 .71089 Mdot
.56188 .3376 Mdot
.56377 .54977 Mdot
.22046 .36419 Mdot
.67381 .49936 Mdot
.44626 .37505 Mdot
.33056 .49836 Mdot
.65032 .47552 Mdot
.55726 .38565 Mdot
.57242 .34279 Mdot
.43255 .39002 Mdot
.43058 .38844 Mdot
.40052 .35508 Mdot
.7062 .48916 Mdot
.64476 .53913 Mdot
.49377 .66527 Mdot
.63972 .50671 Mdot
.78203 .37409 Mdot
.28376 .52915 Mdot
.46389 .39367 Mdot
.5626 .35068 Mdot
.63406 .53745 Mdot
.49218 .63503 Mdot
.72903 .49042 Mdot
.65247 .37687 Mdot
.30785 .48817 Mdot
.78576 .54843 Mdot
.16752 .61364 Mdot
.45514 .62757 Mdot
.58563 .36052 Mdot
.79241 .47301 Mdot
.48799 .63028 Mdot
.41909 .36146 Mdot
.21656 .49592 Mdot
.47214 .40128 Mdot
.4703 .61251 Mdot
.45364 .60706 Mdot
.5753 .31837 Mdot
.25669 .29609 Mdot
.487 .65936 Mdot
.73555 .3707 Mdot
.56382 .29834 Mdot
.42577 .3633 Mdot
.4296 .85771 Mdot
.33487 .54924 Mdot
.31797 .62912 Mdot
.43727 .38347 Mdot
.50737 .6002 Mdot
.43475 .36031 Mdot
.32175 .48744 Mdot
.38069 .40082 Mdot
.6896 .4939 Mdot
.3729 .38732 Mdot
.52007 .6575 Mdot
.66335 .48877 Mdot
.55818 .3597 Mdot
.83475 .51466 Mdot
.23718 .48205 Mdot
.40397 .3995 Mdot
.41198 .41579 Mdot
.50266 .68779 Mdot
.742 .4156 Mdot
.55679 .62442 Mdot
.5408 .62205 Mdot
.5533 .34909 Mdot
.65206 .52384 Mdot
.58995 .33224 Mdot
.55753 .65643 Mdot
.36596 .70081 Mdot
.59143 .37712 Mdot
.31561 .3187 Mdot
.31256 .51521 Mdot
.52986 .4292 Mdot
.49685 .63376 Mdot
.60361 .37405 Mdot
.50701 .65753 Mdot
.68645 .50642 Mdot
.55158 .46502 Mdot
.46704 .31357 Mdot
.57896 .33528 Mdot
.20828 .45503 Mdot
.33076 .67031 Mdot
.54328 .54454 Mdot
.59459 .36139 Mdot
.37198 .60403 Mdot
.42091 .40903 Mdot
.29555 .49391 Mdot
.30388 .53558 Mdot
.28746 .52059 Mdot
.53262 .56352 Mdot
.49009 .72786 Mdot
.34382 .4976 Mdot
.54943 .36908 Mdot
.28367 .49601 Mdot
.5327 .18589 Mdot
.21029 .65325 Mdot
.31938 .51154 Mdot
.47242 .64071 Mdot
.42724 .66877 Mdot
.3644 .56131 Mdot
.41145 .27697 Mdot
.40597 .78081 Mdot
.43983 .22465 Mdot
.4729 .61284 Mdot
.69621 .46765 Mdot
.70118 .50034 Mdot
.80754 .42991 Mdot
.51456 .78347 Mdot
.77043 .67328 Mdot
.67555 .53639 Mdot
.52372 .27494 Mdot
.65689 .53451 Mdot
.46065 .61377 Mdot
.53737 .61854 Mdot
.70051 .52257 Mdot
.37544 .69589 Mdot
.49894 .27771 Mdot
.17712 .54633 Mdot
.64771 .48016 Mdot
.59885 .36851 Mdot
.59891 .33961 Mdot
.56848 .33058 Mdot
.81083 .54085 Mdot
.66095 .51472 Mdot
.51734 .63395 Mdot
.39375 .3697 Mdot
.53144 .65655 Mdot
.57251 .37168 Mdot
.21542 .68121 Mdot
.64855 .51515 Mdot
.46707 .65146 Mdot
.45642 .55943 Mdot
.42867 .38468 Mdot
.30627 .5089 Mdot
.74658 .49792 Mdot
.75603 .68744 Mdot
.56588 .32359 Mdot
.64991 .54833 Mdot
.60417 .41973 Mdot
.18624 .5453 Mdot
.4553 .57588 Mdot
.43607 .63058 Mdot
.16908 .59373 Mdot
.65382 .78441 Mdot
.49312 .67845 Mdot
.38711 .40913 Mdot
.50194 .25472 Mdot
.52926 .60535 Mdot
.69827 .5032 Mdot
.32932 .53832 Mdot
.28221 .50936 Mdot
.56111 .565 Mdot
.73583 .47642 Mdot
.55689 .48732 Mdot
.51124 .62563 Mdot
.52406 .69023 Mdot
.43154 .36998 Mdot
.54467 .24163 Mdot
.82032 .60114 Mdot
.31996 .53042 Mdot
.45032 .63411 Mdot
.22419 .64978 Mdot
.63899 .48237 Mdot
.39346 .42019 Mdot
.58498 .39345 Mdot
.70666 .46859 Mdot
.38038 .40413 Mdot
.49324 .58178 Mdot
.4478 .65139 Mdot
.59841 .34747 Mdot
.67346 .46497 Mdot
.32745 .51693 Mdot
.38262 .39132 Mdot
.31841 .52609 Mdot
.65039 .52179 Mdot
.63606 .52006 Mdot
.4847 .54615 Mdot
.44286 .59036 Mdot
.40461 .40409 Mdot
.55465 .59054 Mdot
.49031 .34892 Mdot
.1508 .46427 Mdot
.60469 .41653 Mdot
.46342 .67264 Mdot
.62088 .53751 Mdot
.57679 .32899 Mdot
.5271 .6356 Mdot
.19462 .6597 Mdot
.53734 .60305 Mdot
.54036 .35307 Mdot
.53489 .80164 Mdot
.31694 .52331 Mdot
.52246 .52121 Mdot
.28873 .30154 Mdot
.46106 .66157 Mdot
.40957 .36633 Mdot
.48365 .55985 Mdot
.58248 .38687 Mdot
.63885 .53677 Mdot
.14079 .47323 Mdot
.57411 .35762 Mdot
.4586 .64849 Mdot
.29297 .51869 Mdot
.62013 .51851 Mdot
.53375 .50529 Mdot
.46876 .50153 Mdot
.41997 .62669 Mdot
.51457 .68237 Mdot
.51921 .60751 Mdot
.33804 .69908 Mdot
.38285 .37592 Mdot
.6695 .47559 Mdot
.58724 .35461 Mdot
.56176 .37251 Mdot
.42847 .39455 Mdot
.40013 .44498 Mdot
.52861 .42902 Mdot
.74013 .25503 Mdot
.43998 .36492 Mdot
.32261 .53265 Mdot
.73881 .39674 Mdot
.38558 .3756 Mdot
.39586 .38558 Mdot
.43954 .37578 Mdot
.40593 .49531 Mdot
.63037 .5242 Mdot
.49495 .58145 Mdot
.69574 .48917 Mdot
.5076 .59813 Mdot
.54107 .33365 Mdot
.57766 .33785 Mdot
.64444 .52049 Mdot
.17261 .50605 Mdot
.62461 .73504 Mdot
.47923 .6316 Mdot
.21139 .37585 Mdot
.46041 .68672 Mdot
.31543 .56777 Mdot
.47116 .69111 Mdot
.41063 .397 Mdot
.54219 .58785 Mdot
.54683 .57073 Mdot
.81044 .45895 Mdot
.56104 .34894 Mdot
.36841 .35458 Mdot
.49913 .70347 Mdot
.53059 .6851 Mdot
.70701 .4866 Mdot
.65547 .47257 Mdot
.29789 .53272 Mdot
.42672 .55852 Mdot
.55706 .3631 Mdot
.50728 .16319 Mdot
.46273 .62184 Mdot
.28378 .55147 Mdot
.75267 .65446 Mdot
.52585 .63867 Mdot
.26396 .32588 Mdot
.68278 .67451 Mdot
.49736 .63758 Mdot
.45355 .45662 Mdot
.56013 .34292 Mdot
.40869 .74386 Mdot
.53014 .5975 Mdot
.4293 .37735 Mdot
.65264 .5386 Mdot
.64517 .47398 Mdot
.31354 .53631 Mdot
.68365 .24651 Mdot
.58855 .32866 Mdot
.63966 .53136 Mdot
.49644 .62417 Mdot
.58675 .36215 Mdot
.44278 .3788 Mdot
.48751 .68436 Mdot
.59653 .79558 Mdot
.63948 .50321 Mdot
.48668 .69394 Mdot
.71417 .34139 Mdot
.28294 .60317 Mdot
.54003 .8133 Mdot
.58775 .34735 Mdot
.33315 .51708 Mdot
.53994 .55791 Mdot
.59827 .51366 Mdot
.54434 .65984 Mdot
.33559 .64446 Mdot
.51839 .18646 Mdot
.33199 .48522 Mdot
.47143 .62924 Mdot
.51923 .63671 Mdot
.59818 .45665 Mdot
.31175 .53056 Mdot
.48486 .66983 Mdot
.62625 .44043 Mdot
.64619 .48735 Mdot
.44065 .39624 Mdot
.63318 .51145 Mdot
.476 .64 Mdot
.43812 .59522 Mdot
.6543 .47095 Mdot
.17023 .44571 Mdot
.33204 .54098 Mdot
.59269 .36127 Mdot
.44725 .6281 Mdot
.53021 .58467 Mdot
.87323 .46001 Mdot
.38752 .42017 Mdot
.49335 .31523 Mdot
.3181 .33348 Mdot
.23263 .63521 Mdot
.35878 .53172 Mdot
.50077 .82454 Mdot
.64616 .78941 Mdot
.47114 .67811 Mdot
.57692 .53356 Mdot
.67678 .29787 Mdot
.55611 .34634 Mdot
.6331 .22126 Mdot
.4623 .62148 Mdot
.49067 .61753 Mdot
.42356 .42027 Mdot
.45096 .30846 Mdot
.77732 .66585 Mdot
.71391 .52163 Mdot
.32241 .51929 Mdot
.68602 .51354 Mdot
.48638 .58202 Mdot
.47526 .46458 Mdot
.37277 .40222 Mdot
.27293 .53324 Mdot
.4652 .64736 Mdot
.76584 .50236 Mdot
.66014 .38303 Mdot
.57995 .37497 Mdot
.39995 .36596 Mdot
.72836 .71112 Mdot
.46031 .6666 Mdot
.60352 .37801 Mdot
.48333 .6488 Mdot
.36368 .52924 Mdot
.5459 .67892 Mdot
.32847 .50245 Mdot
.51627 .59176 Mdot
.33609 .39333 Mdot
.8665 .57454 Mdot
.30535 .47119 Mdot
.70823 .47933 Mdot
.40725 .42939 Mdot
.42274 .40156 Mdot
.66201 .47056 Mdot
.41513 .40258 Mdot
.69018 .63083 Mdot
.58749 .78155 Mdot
.31386 .51716 Mdot
.56834 .58773 Mdot
.31508 .50858 Mdot
.40906 .42407 Mdot
.47015 .61376 Mdot
.14378 .53742 Mdot
.39787 .40623 Mdot
.68651 .76849 Mdot
.56801 .35969 Mdot
.37782 .41429 Mdot
.53295 .60078 Mdot
.64301 .40346 Mdot
.41635 .3455 Mdot
.49306 .29765 Mdot
.4967 .66894 Mdot
.63376 .51872 Mdot
.52837 .61246 Mdot
.46164 .60439 Mdot
.36684 .37315 Mdot
.4951 .5947 Mdot
.59361 .37747 Mdot
.68524 .53099 Mdot
.38447 .78526 Mdot
.56277 .21502 Mdot
.48246 .6702 Mdot
.49407 .62611 Mdot
.61675 .50342 Mdot
.54105 .59364 Mdot
.56145 .32009 Mdot
.21618 .2617 Mdot
.31192 .51483 Mdot
.36619 .39964 Mdot
.32673 .36501 Mdot
.45964 .58797 Mdot
.48775 .59245 Mdot
.22319 .72403 Mdot
.35742 .69183 Mdot
.59519 .36663 Mdot
.56197 .59905 Mdot
.43109 .35206 Mdot
.2913 .5044 Mdot
.54683 .35462 Mdot
.50292 .63811 Mdot
.47654 .62239 Mdot
.33013 .52301 Mdot
.29205 .55904 Mdot
.80085 .57603 Mdot
.60496 .35747 Mdot
.45821 .70094 Mdot
.39124 .32436 Mdot
.53976 .64917 Mdot
.80164 .5308 Mdot
.68021 .48129 Mdot
.5634 .3247 Mdot
.24509 .65283 Mdot
.4636 .67106 Mdot
.59801 .3576 Mdot
.5569 .36029 Mdot
.53759 .66794 Mdot
.6511 .55251 Mdot
.69505 .52512 Mdot
.64286 .48812 Mdot
.50721 .12804 Mdot
.33 .61907 Mdot
.40058 .35505 Mdot
.55831 .34534 Mdot
.4208 .41611 Mdot
.275 .48039 Mdot
.47984 .49039 Mdot
.41429 .41711 Mdot
.63271 .50328 Mdot
.37103 .40728 Mdot
.51268 .65691 Mdot
.55796 .36402 Mdot
.40684 .36049 Mdot
.46444 .59699 Mdot
.74351 .46671 Mdot
.39542 .25885 Mdot
.3212 .48218 Mdot
.3397 .53314 Mdot
.53565 .61443 Mdot
.44839 .37563 Mdot
.47136 .62032 Mdot
.58729 .39525 Mdot
.75 .44822 Mdot
.46207 .60563 Mdot
.40787 .40014 Mdot
.61763 .50469 Mdot
.73612 .70348 Mdot
.52872 .5683 Mdot
.47207 .63907 Mdot
.50216 .59621 Mdot
.48369 .64952 Mdot
.19241 .53036 Mdot
.58956 .32395 Mdot
.49452 .20007 Mdot
.24294 .62817 Mdot
.65363 .50992 Mdot
.69132 .47708 Mdot
.81033 .60753 Mdot
.67374 .30712 Mdot
.56137 .34421 Mdot
.51234 .61365 Mdot
.6611 .35133 Mdot
.29086 .76618 Mdot
.16653 .55448 Mdot
.54778 .73239 Mdot
.39095 .42212 Mdot
.6494 .54811 Mdot
.41477 .40883 Mdot
.50248 .60161 Mdot
.52295 .68853 Mdot
.56461 .83356 Mdot
.55324 .3766 Mdot
.32168 .51639 Mdot
.50802 .59629 Mdot
.32527 .62077 Mdot
.40214 .37252 Mdot
.37778 .4147 Mdot
.53301 .63942 Mdot
.6319 .48254 Mdot
.85796 .57624 Mdot
.58271 .36805 Mdot
.47648 .21054 Mdot
.60209 .22007 Mdot
.66762 .41581 Mdot
.57564 .37173 Mdot
.59397 .50909 Mdot
.39672 .42 Mdot
.75793 .6259 Mdot
.66051 .50773 Mdot
.29239 .49462 Mdot
.47599 .70403 Mdot
.68093 .47565 Mdot
.38145 .35708 Mdot
.63473 .53001 Mdot
.48591 .59228 Mdot
.56964 .30114 Mdot
.4124 .37634 Mdot
.61707 .29885 Mdot
.62026 .53645 Mdot
.30625 .529 Mdot
.51896 .37924 Mdot
.5486 .75094 Mdot
.6838 .67058 Mdot
.53396 .64205 Mdot
.46568 .46946 Mdot
.51493 .63676 Mdot
.64483 .46412 Mdot
.48879 .63932 Mdot
.62386 .56405 Mdot
.41049 .36745 Mdot
.51913 .5863 Mdot
.51311 .62081 Mdot
.41013 .18659 Mdot
.48281 .66607 Mdot
.54851 .63988 Mdot
.5005 .63379 Mdot
.61222 .56219 Mdot
.55636 .56096 Mdot
.67245 .52566 Mdot
.28771 .34595 Mdot
.39838 .38753 Mdot
.28082 .51537 Mdot
.33833 .51033 Mdot
.35673 .63667 Mdot
.33103 .42215 Mdot
.41404 .29541 Mdot
.64586 .49178 Mdot
.59241 .38445 Mdot
.48708 .64417 Mdot
.46111 .82014 Mdot
.42311 .33007 Mdot
.37084 .38598 Mdot
.56569 .21737 Mdot
.5263 .71156 Mdot
.43418 .77117 Mdot
.56265 .61224 Mdot
.59435 .17052 Mdot
.47059 .57482 Mdot
.50759 .71295 Mdot
.44364 .37108 Mdot
.25666 .53396 Mdot
.54173 .59943 Mdot
.69737 .51274 Mdot
.31482 .49162 Mdot
.49304 .72593 Mdot
.35071 .38668 Mdot
.42782 .31455 Mdot
.67923 .56389 Mdot
.50188 .66359 Mdot
.41267 .37742 Mdot
.65978 .52641 Mdot
.81031 .61964 Mdot
.58574 .37238 Mdot
.38073 .44191 Mdot
.74596 .36214 Mdot
.18001 .43531 Mdot
.29146 .52213 Mdot
.75063 .58533 Mdot
.5183 .65718 Mdot
.22734 .45579 Mdot
.45161 .61996 Mdot
.22998 .71289 Mdot
.34038 .51568 Mdot
.62932 .51368 Mdot
.59913 .37207 Mdot
.69734 .50308 Mdot
.67459 .6652 Mdot
.35068 .35905 Mdot
.51926 .4551 Mdot
.39088 .37988 Mdot
.54775 .49376 Mdot
.67071 .4832 Mdot
.46153 .61565 Mdot
.73295 .24721 Mdot
.67506 .47472 Mdot
.62055 .52496 Mdot
.31986 .24707 Mdot
.14655 .49616 Mdot
.43673 .61809 Mdot
.62448 .51843 Mdot
.38982 .38659 Mdot
.31824 .49705 Mdot
.52472 .59619 Mdot
.50714 .66554 Mdot
.68403 .48199 Mdot
.36416 .37158 Mdot
.60855 .6866 Mdot
.42512 .39262 Mdot
.63044 .51795 Mdot
.41167 .38848 Mdot
.53709 .36491 Mdot
.38111 .39089 Mdot
.52998 .58412 Mdot
.48838 .64066 Mdot
.30091 .37536 Mdot
.63584 .51922 Mdot
.51075 .62776 Mdot
.49924 .68771 Mdot
.65488 .49705 Mdot
.58908 .49654 Mdot
.6178 .68435 Mdot
.50833 .67956 Mdot
.49271 .6699 Mdot
.33903 .50129 Mdot
.48325 .48214 Mdot
.77065 .56411 Mdot
.49369 .58911 Mdot
.33118 .48127 Mdot
.6894 .52045 Mdot
.46134 .63429 Mdot
.2775 .72999 Mdot
.49956 .25721 Mdot
.45586 .62771 Mdot
.41935 .40943 Mdot
.55543 .58424 Mdot
.556 .81192 Mdot
.54178 .6189 Mdot
.65854 .48855 Mdot
.64479 .53116 Mdot
.48824 .1684 Mdot
.67074 .49305 Mdot
.4075 .34761 Mdot
.57183 .37006 Mdot
.18379 .54299 Mdot
.4328 .3985 Mdot
.48731 .56675 Mdot
.3471 .20138 Mdot
.47625 .68814 Mdot
.4857 .57738 Mdot
.74036 .72203 Mdot
.40764 .40837 Mdot
.67198 .51525 Mdot
.52614 .39404 Mdot
.43684 .60316 Mdot
.56616 .32583 Mdot
.51572 .70039 Mdot
.54141 .6263 Mdot
.5922 .8092 Mdot
.19604 .53156 Mdot
.60663 .37326 Mdot
.54745 .6408 Mdot
.49126 .59009 Mdot
.45944 .39365 Mdot
.49561 .6298 Mdot
.32256 .49977 Mdot
.65928 .51662 Mdot
.38484 .40431 Mdot
.29711 .50876 Mdot
.45511 .65585 Mdot
.32857 .51745 Mdot
.41872 .36589 Mdot
.57418 .39408 Mdot
.4908 .60441 Mdot
.29121 .48684 Mdot
.32455 .51943 Mdot
.51293 .6371 Mdot
.64483 .5408 Mdot
.54011 .70427 Mdot
.47868 .66385 Mdot
.50206 .585 Mdot
.68179 .49951 Mdot
.41742 .86215 Mdot
.53798 .61963 Mdot
.34109 .65352 Mdot
.67401 .4682 Mdot
.56755 .4975 Mdot
.43797 .39613 Mdot
.54514 .61213 Mdot
.57494 .39454 Mdot
.57931 .39346 Mdot
.37495 .37761 Mdot
.64325 .54857 Mdot
.32913 .32946 Mdot
.70728 .51929 Mdot
.51271 .55585 Mdot
.55255 .62942 Mdot
.59108 .60334 Mdot
.43663 .8078 Mdot
.69359 .49811 Mdot
.34946 .40699 Mdot
.73048 .50356 Mdot
.59746 .38304 Mdot
.36873 .36611 Mdot
.6926 .52784 Mdot
.68297 .50496 Mdot
.65989 .54038 Mdot
.29221 .49394 Mdot
.30114 .38028 Mdot
.66643 .46496 Mdot
.63895 .47373 Mdot
.50606 .66983 Mdot
.49867 .58853 Mdot
.68113 .75866 Mdot
.66939 .75731 Mdot
.33433 .4945 Mdot
.40455 .3525 Mdot
.46767 .11467 Mdot
.56347 .38893 Mdot
.43764 .19091 Mdot
.49077 .57796 Mdot
.50951 .1042 Mdot
.5299 .59961 Mdot
.49868 .62356 Mdot
.69496 .5258 Mdot
.29927 .48424 Mdot
.31286 .51102 Mdot
.6716 .47559 Mdot
.65184 .46342 Mdot
.32354 .50148 Mdot
.27021 .30744 Mdot
.29955 .76113 Mdot
.48637 .34084 Mdot
.64849 .50479 Mdot
.55808 .7697 Mdot
.6023 .35262 Mdot
.44199 .6988 Mdot
.60113 .32973 Mdot
.39785 .37788 Mdot
.38613 .41348 Mdot
.57117 .32562 Mdot
.49199 .66636 Mdot
.39603 .35712 Mdot
.46584 .67754 Mdot
.40126 .24141 Mdot
.65827 .70262 Mdot
.35543 .32484 Mdot
.43922 .70797 Mdot
.59157 .49148 Mdot
.61158 .2904 Mdot
.45538 .64263 Mdot
.24678 .69044 Mdot
.31946 .51841 Mdot
.48864 .55755 Mdot
.55991 .32721 Mdot
.72391 .7446 Mdot
.48137 .60706 Mdot
.65395 .49169 Mdot
.55618 .35614 Mdot
.75687 .36616 Mdot
.73983 .38244 Mdot
.50508 .59671 Mdot
.68515 .21776 Mdot
.61934 .48206 Mdot
.39006 .36928 Mdot
.77635 .47455 Mdot
.68722 .47512 Mdot
.36368 .517 Mdot
.26867 .68014 Mdot
.17305 .48169 Mdot
.66609 .51939 Mdot
.42422 .42304 Mdot
.67491 .5285 Mdot
.2971 .52433 Mdot
.70784 .4808 Mdot
.40774 .37055 Mdot
.46523 .64281 Mdot
.41992 .39826 Mdot
.29705 .49039 Mdot
.79039 .58632 Mdot
.60653 .37331 Mdot
.39145 .34257 Mdot
.5812 .34446 Mdot
.26076 .60196 Mdot
.32231 .68735 Mdot
.59154 .35565 Mdot
.6147 .63159 Mdot
.55256 .62627 Mdot
.67741 .46657 Mdot
.43592 .39058 Mdot
.2441 .49464 Mdot
.5331 .39297 Mdot
.66458 .50425 Mdot
.38864 .35399 Mdot
.75697 .41926 Mdot
.601 .55868 Mdot
.55405 .63019 Mdot
.37564 .5558 Mdot
.65239 .50243 Mdot
.42293 .42183 Mdot
.83691 .54661 Mdot
.67743 .52633 Mdot
.43476 .35703 Mdot
.59989 .36323 Mdot
.56475 .37589 Mdot
.52603 .66402 Mdot
.55667 .30331 Mdot
.38105 .36845 Mdot
.62201 .35341 Mdot
.62456 .52374 Mdot
.7725 .39768 Mdot
.27697 .50199 Mdot
.40485 .39207 Mdot
.46418 .68281 Mdot
.63332 .47034 Mdot
.52215 .23342 Mdot
.61413 .70075 Mdot
.78912 .3333 Mdot
.42793 .39475 Mdot
.6652 .5125 Mdot
.6496 .49511 Mdot
.52379 .56593 Mdot
.76121 .45652 Mdot
.30652 .34375 Mdot
.59133 .56485 Mdot
.58225 .43791 Mdot
.44437 .39071 Mdot
.38846 .43545 Mdot
.50321 .70261 Mdot
.49458 .66074 Mdot
.60028 .37863 Mdot
.46736 .64409 Mdot
.63675 .54305 Mdot
.53267 .64306 Mdot
.58627 .35626 Mdot
.38747 .38114 Mdot
.48589 .60699 Mdot
.32356 .52161 Mdot
.58673 .3222 Mdot
.56073 .39062 Mdot
.40317 .39601 Mdot
.68447 .48202 Mdot
.5588 .50447 Mdot
.43208 .38644 Mdot
.50102 .66406 Mdot
.44751 .48771 Mdot
.48267 .59331 Mdot
.56458 .53709 Mdot
.68244 .52188 Mdot
.38593 .40515 Mdot
.71941 .49767 Mdot
.57672 .35074 Mdot
.24496 .63542 Mdot
.48011 .63814 Mdot
.44081 .36706 Mdot
.56675 .26168 Mdot
.54447 .51928 Mdot
.61725 .53248 Mdot
.34256 .28782 Mdot
.68397 .468 Mdot
.41125 .35401 Mdot
.3757 .20893 Mdot
.28592 .50549 Mdot
.37109 .39315 Mdot
.39965 .78833 Mdot
.39818 .40328 Mdot
.52761 .65738 Mdot
.5347 .6192 Mdot
.38166 .39381 Mdot
.3348 .51567 Mdot
.78928 .65889 Mdot
.42819 .43334 Mdot
.66778 .51676 Mdot
.34287 .25558 Mdot
.82703 .41751 Mdot
.63261 .35537 Mdot
.59673 .38221 Mdot
.43315 .62611 Mdot
.54993 .61756 Mdot
.55473 .33412 Mdot
.6096 .36794 Mdot
.29143 .52795 Mdot
.43637 .36451 Mdot
.61948 .48793 Mdot
.56647 .40054 Mdot
.73303 .52434 Mdot
.32198 .40406 Mdot
.53302 .57057 Mdot
.59163 .21559 Mdot
.49159 .57887 Mdot
.2959 .66597 Mdot
.58718 .35241 Mdot
.45065 .62696 Mdot
.56045 .60928 Mdot
.55244 .35709 Mdot
.31774 .49567 Mdot
.37702 .43972 Mdot
.41228 .38528 Mdot
.41564 .85155 Mdot
.47876 .6808 Mdot
.52793 .64911 Mdot
.56528 .33489 Mdot
.24924 .42995 Mdot
.65249 .51376 Mdot
.69876 .48439 Mdot
.38289 .37621 Mdot
.49917 .38997 Mdot
.54098 .64188 Mdot
.4587 .64317 Mdot
.41797 .3812 Mdot
.38953 .34618 Mdot
.42212 .28979 Mdot
.52098 .63807 Mdot
.56444 .34841 Mdot
.24761 .54084 Mdot
.58679 .3443 Mdot
.47287 .60186 Mdot
.52603 .64823 Mdot
.52899 .58309 Mdot
.45079 .66307 Mdot
.58065 .30484 Mdot
.47441 .59598 Mdot
.55956 .6345 Mdot
.66493 .51 Mdot
.5072 .5927 Mdot
.57542 .42983 Mdot
.47274 .64839 Mdot
.32052 .49898 Mdot
.76602 .55111 Mdot
.4825 .60672 Mdot
.53658 .63631 Mdot
.36995 .41022 Mdot
.47809 .62684 Mdot
.58325 .39666 Mdot
.64025 .5155 Mdot
.56171 .34109 Mdot
.5819 .39366 Mdot
.43818 .41395 Mdot
.33423 .52861 Mdot
.45431 .59382 Mdot
.32205 .4887 Mdot
.47593 .5681 Mdot
.46444 .67174 Mdot
.34168 .4509 Mdot
.56596 .15531 Mdot
.80803 .55041 Mdot
.47951 .64018 Mdot
.4029 .40763 Mdot
.4148 .40952 Mdot
.58319 .53854 Mdot
.53742 .65913 Mdot
.54731 .33923 Mdot
.59559 .38595 Mdot
.52854 .7858 Mdot
.40348 .70372 Mdot
.32023 .49824 Mdot
.49537 .47441 Mdot
.49535 .68005 Mdot
.45034 .62913 Mdot
.48221 .68447 Mdot
.41369 .41795 Mdot
.50898 .74504 Mdot
.37044 .36935 Mdot
.64356 .33052 Mdot
.57504 .33082 Mdot
.49436 .60026 Mdot
.56952 .20821 Mdot
.64319 .48343 Mdot
.63967 .51538 Mdot
.55424 .38433 Mdot
.41364 .33079 Mdot
.74083 .69654 Mdot
.16306 .57082 Mdot
.67579 .44994 Mdot
.29449 .48813 Mdot
.45861 .65454 Mdot
.38708 .39296 Mdot
.63011 .52633 Mdot
.29678 .48751 Mdot
.47106 .60824 Mdot
.30197 .38126 Mdot
.47984 .64826 Mdot
.65725 .28361 Mdot
.65794 .53611 Mdot
.26323 .74391 Mdot
.64014 .54825 Mdot
.57203 .31078 Mdot
.5605 .32301 Mdot
.52558 .63724 Mdot
.62273 .46062 Mdot
.687 .47321 Mdot
.37638 .4799 Mdot
.31988 .5329 Mdot
.63983 .37076 Mdot
.2893 .50464 Mdot
.39885 .36455 Mdot
.30005 .49267 Mdot
.40994 .36986 Mdot
.75274 .68079 Mdot
.6448 .57917 Mdot
.30273 .51181 Mdot
.57623 .26347 Mdot
.54907 .61459 Mdot
.33226 .48986 Mdot
.52195 .68839 Mdot
.5793 .5628 Mdot
.42043 .38316 Mdot
.31141 .53177 Mdot
.45155 .63048 Mdot
.48886 .81244 Mdot
.59368 .36333 Mdot
.54979 .33203 Mdot
.52052 .68866 Mdot
.43889 .40127 Mdot
.69724 .51934 Mdot
.21022 .63607 Mdot
.56854 .40536 Mdot
.5341 .62642 Mdot
.54159 .59699 Mdot
.68019 .46589 Mdot
.49824 .18387 Mdot
.52223 .64669 Mdot
.53263 .53556 Mdot
.52381 .63506 Mdot
.58664 .33075 Mdot
.69461 .50693 Mdot
.64399 .50327 Mdot
.3901 .35434 Mdot
.63426 .48984 Mdot
.42866 .52532 Mdot
.61714 .25822 Mdot
.54803 .68013 Mdot
.57702 .35655 Mdot
.65632 .36801 Mdot
.6315 .29729 Mdot
.39951 .77355 Mdot
.62141 .54154 Mdot
.46584 .60146 Mdot
.63219 .48999 Mdot
.29547 .4992 Mdot
.6352 .51234 Mdot
.64982 .54805 Mdot
.46734 .62142 Mdot
.50766 .60048 Mdot
.3882 .37555 Mdot
.75906 .45096 Mdot
.68208 .47524 Mdot
.52965 .60064 Mdot
.53595 .58145 Mdot
.46538 .67999 Mdot
.38751 .49779 Mdot
.69394 .50295 Mdot
.24773 .30263 Mdot
.38947 .58526 Mdot
.68331 .47726 Mdot
.83748 .6108 Mdot
.55211 .25085 Mdot
.35625 .35263 Mdot
.37471 .45581 Mdot
.52501 .6311 Mdot
.41093 .34326 Mdot
.50162 .60176 Mdot
.59467 .21866 Mdot
.48238 .62065 Mdot
.32313 .49881 Mdot
.47128 .67829 Mdot
.37973 .40649 Mdot
.42695 .39266 Mdot
.5345 .62981 Mdot
.48917 .60725 Mdot
.79455 .59921 Mdot
.7118 .48811 Mdot
.63826 .52605 Mdot
.36773 .3153 Mdot
.30145 .51758 Mdot
.56497 .32483 Mdot
.49564 .63713 Mdot
.43403 .41564 Mdot
.42543 .39442 Mdot
.69411 .48944 Mdot
.42492 .36719 Mdot
.58158 .3694 Mdot
.48364 .63643 Mdot
.55353 .33241 Mdot
.28453 .50278 Mdot
.69323 .507 Mdot
.50665 .59424 Mdot
.50572 .67007 Mdot
.64499 .53099 Mdot
.44952 .62136 Mdot
.33156 .51855 Mdot
.40312 .40281 Mdot
.66623 .52058 Mdot
.56896 .37173 Mdot
.40194 .36501 Mdot
.49503 .58345 Mdot
.65597 .20608 Mdot
.52057 .66786 Mdot
.52763 .6201 Mdot
.43401 .8183 Mdot
.48789 .67863 Mdot
.43279 .3923 Mdot
.62904 .52244 Mdot
.47083 .55855 Mdot
.35575 .61134 Mdot
.38942 .86333 Mdot
.37163 .37229 Mdot
.46281 .65723 Mdot
.42892 .78757 Mdot
.4641 .6539 Mdot
.59318 .73519 Mdot
.37897 .34444 Mdot
.56723 .45726 Mdot
.45426 .67467 Mdot
.57809 .38413 Mdot
.38304 .38779 Mdot
.41442 .36973 Mdot
.3777 .23979 Mdot
.46096 .62951 Mdot
.43086 .47324 Mdot
.47851 .60089 Mdot
.57032 .37522 Mdot
.41788 .70894 Mdot
.43004 .39163 Mdot
.81211 .40996 Mdot
.51542 .63825 Mdot
.68692 .50272 Mdot
.37397 .41179 Mdot
.55122 .39849 Mdot
.50744 .5857 Mdot
.33314 .50208 Mdot
.60254 .39283 Mdot
.54032 .68496 Mdot
.57754 .36044 Mdot
.50002 .58542 Mdot
.41713 .62222 Mdot
.7564 .33273 Mdot
.65117 .54229 Mdot
.60002 .37188 Mdot
.42943 .49586 Mdot
.4663 .60313 Mdot
.6647 .52022 Mdot
.66239 .50694 Mdot
.28686 .49795 Mdot
.54703 .47695 Mdot
.71879 .34015 Mdot
.62799 .74547 Mdot
.35715 .24725 Mdot
.36834 .39594 Mdot
.48132 .30937 Mdot
.52255 .61698 Mdot
.39781 .53953 Mdot
.58692 .39475 Mdot
.51815 .67122 Mdot
.73944 .59189 Mdot
.65532 .47451 Mdot
.51531 .67027 Mdot
.31682 .50831 Mdot
.32601 .55451 Mdot
.25238 .54782 Mdot
.31343 .72226 Mdot
.39246 .37911 Mdot
.5674 .6092 Mdot
.46195 .55908 Mdot
.44053 .39412 Mdot
.517 .57399 Mdot
.43881 .39016 Mdot
.23368 .34939 Mdot
.3242 .48373 Mdot
.68845 .50793 Mdot
.63078 .32401 Mdot
.48511 .57554 Mdot
.54558 .62919 Mdot
.33138 .53249 Mdot
.49767 .65885 Mdot
.70581 .2743 Mdot
.38526 .50263 Mdot
.40088 .35973 Mdot
.65744 .54119 Mdot
.52944 .57898 Mdot
.48375 .49169 Mdot
.47006 .65623 Mdot
.68805 .71515 Mdot
.53743 .63384 Mdot
.74484 .38235 Mdot
.65286 .53917 Mdot
.58145 .35431 Mdot
.44583 .63678 Mdot
.48961 .62082 Mdot
.37563 .67474 Mdot
.47042 .57306 Mdot
.45402 .61959 Mdot
.65704 .55608 Mdot
.65186 .54493 Mdot
.67143 .52869 Mdot
.37483 .372 Mdot
.47563 .78056 Mdot
.5693 .34968 Mdot
.43699 .5876 Mdot
.5457 .37631 Mdot
.58787 .69519 Mdot
.30679 .48423 Mdot
.35625 .7273 Mdot
.50717 .62652 Mdot
.64343 .49198 Mdot
.20895 .59836 Mdot
.70569 .48893 Mdot
.48891 .46629 Mdot
.55718 .3633 Mdot
.67482 .47606 Mdot
.4962 .62128 Mdot
.73099 .46613 Mdot
.45587 .80951 Mdot
.57268 .34213 Mdot
.4936 .56577 Mdot
.37656 .40616 Mdot
.32917 .35292 Mdot
.7795 .35334 Mdot
.59419 .35897 Mdot
.59962 .41711 Mdot
.45836 .6339 Mdot
.63561 .49167 Mdot
.57609 .38119 Mdot
.58682 .33273 Mdot
.42096 .36369 Mdot
.51048 .60036 Mdot
.51413 .60194 Mdot
.40214 .35085 Mdot
.56306 .33897 Mdot
.54945 .65127 Mdot
.55304 .66628 Mdot
.63754 .81863 Mdot
.76026 .40325 Mdot
.43039 .8651 Mdot
.57488 .52454 Mdot
.71738 .58664 Mdot
.21021 .64479 Mdot
.68828 .48804 Mdot
.45192 .64503 Mdot
.48346 .70909 Mdot
.38062 .36882 Mdot
.47229 .63419 Mdot
.38297 .33507 Mdot
.5591 .37932 Mdot
.71884 .74722 Mdot
.69129 .39431 Mdot
.19683 .41568 Mdot
.47145 .63238 Mdot
.6238 .55781 Mdot
.30034 .49905 Mdot
.63192 .39991 Mdot
.69076 .51347 Mdot
.47776 .69089 Mdot
.79358 .5964 Mdot
.37061 .38667 Mdot
.67702 .49698 Mdot
.80627 .62617 Mdot
.59749 .482 Mdot
.48244 .59409 Mdot
.37472 .36084 Mdot
.23412 .68074 Mdot
.72894 .53966 Mdot
.54346 .34142 Mdot
.31724 .49477 Mdot
.38478 .4007 Mdot
.60106 .3803 Mdot
.61293 .555 Mdot
.67677 .48832 Mdot
.69763 .51421 Mdot
.79526 .55345 Mdot
.36058 .37696 Mdot
.29969 .50128 Mdot
.41159 .73864 Mdot
.39045 .68668 Mdot
.32508 .50329 Mdot
.38645 .41404 Mdot
.64135 .54367 Mdot
.66384 .47495 Mdot
.64078 .51485 Mdot
.81 .50113 Mdot
.62393 .50167 Mdot
.39233 .21786 Mdot
.45816 .67333 Mdot
.57444 .60264 Mdot
.46111 .65402 Mdot
.54705 .34461 Mdot
.64997 .53087 Mdot
.51721 .38714 Mdot
.49751 .56016 Mdot
.35156 .70916 Mdot
.5276 .65997 Mdot
.59117 .32156 Mdot
.5167 .66478 Mdot
.58149 .1945 Mdot
.6411 .47962 Mdot
.47683 .63751 Mdot
.59956 .33027 Mdot
.30285 .52167 Mdot
.61782 .53759 Mdot
.50271 .59618 Mdot
.31487 .30451 Mdot
.47778 .6765 Mdot
.21239 .39431 Mdot
.72665 .32182 Mdot
.2973 .48699 Mdot
.64428 .24531 Mdot
.42975 .42353 Mdot
.56196 .55784 Mdot
.42919 .6162 Mdot
.57772 .34429 Mdot
.63849 .37471 Mdot
.39611 .38744 Mdot
.53544 .73845 Mdot
.55628 .64732 Mdot
.28396 .5007 Mdot
.62837 .57944 Mdot
.55278 .34249 Mdot
.52474 .57531 Mdot
.55831 .6003 Mdot
.47014 .20453 Mdot
.54121 .67345 Mdot
.54455 .60954 Mdot
.34445 .52402 Mdot
.41812 .20221 Mdot
.47672 .65368 Mdot
.4942 .46969 Mdot
.70886 .48393 Mdot
.49974 .5569 Mdot
.39849 .21072 Mdot
.53539 .61552 Mdot
.68171 .48847 Mdot
.54794 .53772 Mdot
.69747 .32373 Mdot
.33618 .5269 Mdot
.53773 .63416 Mdot
.47639 .17078 Mdot
.51012 .65055 Mdot
.56547 .35295 Mdot
.53872 .65598 Mdot
.4054 .37181 Mdot
.81735 .54149 Mdot
.38849 .35772 Mdot
.52751 .66602 Mdot
.64367 .5115 Mdot
.57025 .33262 Mdot
.79404 .49117 Mdot
.2827 .38591 Mdot
.46106 .19214 Mdot
.17041 .55876 Mdot
.32317 .53102 Mdot
.27646 .49146 Mdot
.55281 .37244 Mdot
.47632 .63957 Mdot
.32893 .23182 Mdot
.45393 .58569 Mdot
.49752 .67186 Mdot
.48331 .61954 Mdot
.31704 .68194 Mdot
.57345 .39164 Mdot
.42456 .3867 Mdot
.52361 .64811 Mdot
.46706 .60375 Mdot
.68747 .49497 Mdot
.30985 .52099 Mdot
.4357 .39849 Mdot
.31441 .51631 Mdot
.38433 .3921 Mdot
.77522 .68798 Mdot
.55881 .62976 Mdot
.30079 .52281 Mdot
.58313 .40286 Mdot
.68446 .49218 Mdot
.63095 .27982 Mdot
.40855 .36568 Mdot
.37868 .36474 Mdot
.53689 .62939 Mdot
.68133 .48091 Mdot
.71083 .513 Mdot
.28917 .51015 Mdot
.58939 .36218 Mdot
.48136 .60746 Mdot
.47108 .6718 Mdot
.421 .59366 Mdot
.43952 .40536 Mdot
.6486 .27195 Mdot
.44541 .31342 Mdot
.47818 .64168 Mdot
.62496 .52343 Mdot
.48538 .61154 Mdot
.20451 .47359 Mdot
.63726 .48819 Mdot
.53498 .60951 Mdot
.85799 .5632 Mdot
.35272 .34538 Mdot
.67983 .34034 Mdot
.53957 .59668 Mdot
.20425 .67074 Mdot
.516 .62107 Mdot
.72985 .74332 Mdot
.22173 .51895 Mdot
.54383 .64295 Mdot
.50954 .58481 Mdot
.6455 .69269 Mdot
.46453 .66445 Mdot
.39356 .35073 Mdot
.66839 .77524 Mdot
.70628 .49748 Mdot
.62557 .29232 Mdot
.75815 .5615 Mdot
.33831 .52202 Mdot
.38285 .37647 Mdot
.36389 .4096 Mdot
.3239 .51073 Mdot
.65006 .50156 Mdot
.48388 .6496 Mdot
.48566 .43084 Mdot
.43356 .40836 Mdot
.53708 .71775 Mdot
.56345 .35437 Mdot
.4753 .25232 Mdot
.36991 .54842 Mdot
.57823 .36446 Mdot
.50976 .59268 Mdot
.6328 .69089 Mdot
.75027 .67193 Mdot
.34226 .78301 Mdot
.60574 .36921 Mdot
.57322 .33994 Mdot
.81977 .51519 Mdot
.28128 .52466 Mdot
.46996 .20773 Mdot
.74339 .38505 Mdot
.56798 .32768 Mdot
.6039 .54019 Mdot
.39732 .34763 Mdot
.51645 .32564 Mdot
.52867 .55199 Mdot
.45826 .66839 Mdot
.49409 .62163 Mdot
.58984 .35109 Mdot
.55544 .522 Mdot
.78607 .41786 Mdot
.58162 .34177 Mdot
.4413 .68448 Mdot
.54129 .44732 Mdot
.54262 .28417 Mdot
.43206 .37127 Mdot
.31677 .53428 Mdot
.27373 .51816 Mdot
.67978 .50932 Mdot
.32433 .53318 Mdot
.31523 .55733 Mdot
.49495 .65218 Mdot
.58238 .33514 Mdot
.56973 .24525 Mdot
.56417 .37124 Mdot
.31895 .51279 Mdot
.2886 .52751 Mdot
.66395 .51015 Mdot
.6357 .52498 Mdot
.67248 .62495 Mdot
.3536 .56837 Mdot
.48583 .66969 Mdot
.26346 .47768 Mdot
.66238 .544 Mdot
.57568 .6491 Mdot
.32033 .53445 Mdot
.30337 .51992 Mdot
.36771 .67685 Mdot
.50569 .62423 Mdot
.57713 .67107 Mdot
.50153 .62962 Mdot
.40391 .59428 Mdot
.50908 .58063 Mdot
.42181 .36422 Mdot
.51261 .6149 Mdot
.3686 .68767 Mdot
.45319 .60509 Mdot
.55203 .60499 Mdot
.42326 .41768 Mdot
.55938 .64777 Mdot
.40569 .37341 Mdot
.51352 .67737 Mdot
.29408 .483 Mdot
.38123 .37625 Mdot
.34154 .62021 Mdot
.35201 .6676 Mdot
.394 .41799 Mdot
.31149 .48672 Mdot
.3412 .50324 Mdot
.30787 .62831 Mdot
.69194 .51261 Mdot
.42877 .65193 Mdot
.47399 .63835 Mdot
.36961 .35882 Mdot
.58819 .38957 Mdot
.49849 .58147 Mdot
.54691 .60811 Mdot
.53224 .59162 Mdot
.68216 .50804 Mdot
.30055 .35028 Mdot
.3001 .52468 Mdot
.39921 .34959 Mdot
.55012 .50195 Mdot
.4448 .39108 Mdot
.55167 .58409 Mdot
.47154 .70351 Mdot
.74772 .57684 Mdot
.56317 .2782 Mdot
.81689 .4854 Mdot
.67633 .49036 Mdot
.41707 .41028 Mdot
.27693 .49963 Mdot
.44905 .6842 Mdot
.64164 .49244 Mdot
.4077 .37102 Mdot
.48006 .64745 Mdot
.4988 .56723 Mdot
.60313 .25041 Mdot
.25806 .55988 Mdot
.34797 .64788 Mdot
.37432 .38282 Mdot
.39393 .42305 Mdot
.34204 .67796 Mdot
.25451 .51532 Mdot
.52667 .38528 Mdot
.46239 .63605 Mdot
.33285 .50421 Mdot
.6299 .5188 Mdot
.77682 .57599 Mdot
.57273 .32008 Mdot
.76 .45905 Mdot
.47327 .63201 Mdot
.58643 .47623 Mdot
.64474 .51227 Mdot
.31924 .50656 Mdot
.58935 .34626 Mdot
.28403 .53918 Mdot
.41605 .41494 Mdot
.16557 .47978 Mdot
.50623 .65712 Mdot
.53584 .63319 Mdot
.59869 .3381 Mdot
.64718 .48295 Mdot
.34391 .49736 Mdot
.34072 .26229 Mdot
.41935 .36859 Mdot
.34073 .22262 Mdot
.62546 .5176 Mdot
.55767 .76731 Mdot
.42432 .35859 Mdot
.55693 .39213 Mdot
.31795 .62157 Mdot
.58308 .36408 Mdot
.5325 .65636 Mdot
.64887 .49123 Mdot
.59788 .37714 Mdot
.76885 .43785 Mdot
.47328 .83181 Mdot
.56551 .76747 Mdot
.49262 .64716 Mdot
.54958 .82471 Mdot
.2526 .34331 Mdot
.67226 .44778 Mdot
.59404 .38943 Mdot
.52115 .66894 Mdot
.54108 .63285 Mdot
.51045 .65266 Mdot
.5817 .38934 Mdot
.27596 .4714 Mdot
.42187 .38094 Mdot
.45702 .6447 Mdot
.28906 .52582 Mdot
.40072 .37829 Mdot
.54271 .37781 Mdot
.43437 .37839 Mdot
.64313 .55288 Mdot
.54053 .57248 Mdot
.62858 .42238 Mdot
.89779 .50343 Mdot
.56757 .33928 Mdot
.43542 .41659 Mdot
.53817 .66508 Mdot
.51447 .25588 Mdot
.68055 .52994 Mdot
.41784 .3656 Mdot
.52857 .65001 Mdot
.58556 .26683 Mdot
.79762 .57426 Mdot
.43465 .38488 Mdot
.63951 .49417 Mdot
.34778 .78176 Mdot
.46813 .6393 Mdot
.51064 .63316 Mdot
.67502 .48029 Mdot
.60097 .60401 Mdot
.82568 .56948 Mdot
.48819 .6088 Mdot
.58272 .35316 Mdot
.16921 .41599 Mdot
.5473 .60926 Mdot
.39562 .63139 Mdot
.38467 .38064 Mdot
.51864 .35526 Mdot
.68125 .30046 Mdot
.44317 .62908 Mdot
.41996 .23586 Mdot
.63005 .33005 Mdot
.46428 .78687 Mdot
.38114 .33371 Mdot
.26554 .36459 Mdot
.53243 .81044 Mdot
.58634 .31104 Mdot
.65635 .56277 Mdot
.385 .24678 Mdot
.73924 .54289 Mdot
.27634 .7234 Mdot
.23671 .45036 Mdot
.79547 .59455 Mdot
.49985 .42553 Mdot
.39414 .40521 Mdot
.5883 .59132 Mdot
.50112 .59971 Mdot
.24834 .34955 Mdot
.75856 .34806 Mdot
.7717 .37544 Mdot
.55061 .82569 Mdot
.58762 .7455 Mdot
.43508 .79213 Mdot
.40948 .78849 Mdot
.40638 .65619 Mdot
.47041 .31948 Mdot
.32657 .22783 Mdot
.73667 .71037 Mdot
.28892 .28533 Mdot
.57457 .60939 Mdot
.47517 .46489 Mdot
.19237 .46019 Mdot
.65182 .57423 Mdot
.6029 .56434 Mdot
.39781 .35385 Mdot
.69314 .51426 Mdot
.45147 .2157 Mdot
.67524 .46236 Mdot
.69518 .31959 Mdot
.3738 .80211 Mdot
.46372 .82624 Mdot
.49706 .17694 Mdot
.20993 .66919 Mdot
.73102 .59244 Mdot
.29094 .21871 Mdot
.41314 .33736 Mdot
.69245 .48701 Mdot
.30513 .66624 Mdot
.38601 .70922 Mdot
.66751 .40618 Mdot
.33958 .27924 Mdot
.31805 .3814 Mdot
.27087 .58964 Mdot
.65203 .49425 Mdot
.65584 .26056 Mdot
.52506 .32211 Mdot
.68541 .39801 Mdot
.70439 .74059 Mdot
.3433 .76265 Mdot
.47207 .43779 Mdot
.37851 .26917 Mdot
.48044 .27146 Mdot
.79476 .42579 Mdot
.37001 .59031 Mdot
.58787 .55415 Mdot
.75386 .39067 Mdot
.19433 .59984 Mdot
.65138 .60062 Mdot
.40961 .58512 Mdot
.39482 .71476 Mdot
.79389 .66147 Mdot
.22454 .40257 Mdot
.85105 .41968 Mdot
.67465 .46057 Mdot
.54011 .5926 Mdot
.60642 .63778 Mdot
.43751 .17333 Mdot
.34187 .53379 Mdot
.30111 .7144 Mdot
.29864 .52888 Mdot
.65396 .55122 Mdot
.81643 .56199 Mdot
.40964 .2044 Mdot
.37767 .19152 Mdot
.28503 .48589 Mdot
.43569 .58819 Mdot
.20786 .72554 Mdot
.41236 .75746 Mdot
.68132 .36794 Mdot
.64519 .81239 Mdot
.55183 .4376 Mdot
.76823 .38821 Mdot
.59789 .37884 Mdot
.57038 .81346 Mdot
.66206 .47874 Mdot
.85604 .39479 Mdot
.74513 .72847 Mdot
.75878 .58978 Mdot
.76081 .79229 Mdot
.32969 .68014 Mdot
.57276 .46032 Mdot
.62536 .36986 Mdot
.32705 .59086 Mdot
.78148 .46467 Mdot
.2441 .6179 Mdot
.50412 .2599 Mdot
.19808 .66922 Mdot
.51968 .81426 Mdot
.35576 .20558 Mdot
.18568 .4149 Mdot
.67099 .58447 Mdot
.49284 .49033 Mdot
.43521 .69795 Mdot
.34298 .33884 Mdot
.28756 .71129 Mdot
.81069 .64758 Mdot
.38835 .58822 Mdot
.38265 .86024 Mdot
.30374 .47107 Mdot
.30806 .40774 Mdot
.41981 .84025 Mdot
.28238 .59973 Mdot
.68664 .28941 Mdot
.45525 .76126 Mdot
.47581 .73393 Mdot
.4941 .50298 Mdot
.30073 .72054 Mdot
.65386 .3035 Mdot
.63408 .797 Mdot
.23276 .69695 Mdot
.476 .20479 Mdot
.65903 .71246 Mdot
.39289 .66935 Mdot
.61376 .50719 Mdot
.30856 .56479 Mdot
.68972 .30384 Mdot
.49843 .83909 Mdot
.57175 .30435 Mdot
.53519 .84598 Mdot
.82159 .57711 Mdot
.55957 .62997 Mdot
.43246 .6602 Mdot
.59395 .52265 Mdot
.29301 .56686 Mdot
.57043 .60991 Mdot
.56936 .2247 Mdot
.45416 .82593 Mdot
.72403 .69229 Mdot
.60871 .28455 Mdot
.63801 .35552 Mdot
.42061 .84679 Mdot
.62892 .6557 Mdot
.25966 .50336 Mdot
.63624 .78416 Mdot
.78495 .46302 Mdot
.40232 .38719 Mdot
.36719 .20491 Mdot
.59915 .41114 Mdot
.78731 .57782 Mdot
.62377 .74589 Mdot
.7269 .56674 Mdot
.45497 .82702 Mdot
.29268 .34157 Mdot
.81067 .57782 Mdot
.26383 .61623 Mdot
.30485 .25959 Mdot
.55076 .28256 Mdot
.50589 .70662 Mdot
.33125 .28661 Mdot
.33921 .5051 Mdot
.67393 .65464 Mdot
.1975 .35558 Mdot
.26518 .44121 Mdot
.50738 .69752 Mdot
.76312 .5853 Mdot
.35284 .39367 Mdot
.72912 .46145 Mdot
.80852 .34935 Mdot
.54678 .58995 Mdot
.41153 .73202 Mdot
.27725 .34033 Mdot
.33242 .57923 Mdot
.2884 .75557 Mdot
.195 .51812 Mdot
.86734 .44109 Mdot
.59712 .82073 Mdot
.27854 .38076 Mdot
.51047 .80327 Mdot
.51767 .82586 Mdot
.86394 .45028 Mdot
.43576 .61046 Mdot
.56532 .30893 Mdot
.61653 .17027 Mdot
.43303 .37047 Mdot
.3947 .72766 Mdot
.35733 .24704 Mdot
.35992 .54753 Mdot
.62753 .43164 Mdot
.53355 .73449 Mdot
.49712 .43406 Mdot
.71325 .48774 Mdot
.56891 .61599 Mdot
.82978 .44162 Mdot
.87541 .49481 Mdot
.84342 .43499 Mdot
.1785 .54096 Mdot
.57482 .80987 Mdot
.57404 .48202 Mdot
.46693 .17801 Mdot
.56756 .66949 Mdot
.44999 .63709 Mdot
.34029 .54525 Mdot
.32431 .67758 Mdot
.77702 .56195 Mdot
.71342 .40246 Mdot
.6394 .58083 Mdot
.29932 .71501 Mdot
.09689 .4869 Mdot
.69414 .61966 Mdot
.36757 .22724 Mdot
.26393 .51773 Mdot
.34227 .57035 Mdot
.25149 .67566 Mdot
.77416 .54455 Mdot
.42223 .8058 Mdot
.7133 .49002 Mdot
.31512 .27524 Mdot
.25197 .46408 Mdot
.67939 .55488 Mdot
.29929 .35406 Mdot
.40619 .76394 Mdot
.6436 .3548 Mdot
.77913 .52351 Mdot
.73666 .39254 Mdot
.61593 .62689 Mdot
.37466 .49276 Mdot
.46049 .26646 Mdot
.24756 .30144 Mdot
.21651 .46107 Mdot
.39762 .6254 Mdot
.53291 .44645 Mdot
.62391 .22712 Mdot
.60978 .29787 Mdot
.40122 .59171 Mdot
.56844 .42612 Mdot
.4379 .75281 Mdot
.85075 .32147 Mdot
.8169 .39685 Mdot
.37105 .81031 Mdot
.22414 .57437 Mdot
.53033 .69128 Mdot
.4106 .80651 Mdot
.83956 .38572 Mdot
.8563 .59041 Mdot
.43611 .27135 Mdot
.41192 .33455 Mdot
.55209 .38756 Mdot
.83233 .48278 Mdot
.32359 .45474 Mdot
.38175 .77996 Mdot
.38688 .62365 Mdot
.5713 .39768 Mdot
.52353 .13761 Mdot
.77794 .6757 Mdot
.60091 .7613 Mdot
.26621 .55944 Mdot
.47006 .69752 Mdot
.66684 .24995 Mdot
.68966 .47433 Mdot
.4994 .29783 Mdot
.36262 .56877 Mdot
.40965 .3942 Mdot
.28384 .67278 Mdot
.3152 .28834 Mdot
.47077 .67831 Mdot
.4531 .49164 Mdot
.61832 .51066 Mdot
.55087 .27821 Mdot
.6544 .34916 Mdot
.86787 .56155 Mdot
.28125 .54107 Mdot
.46029 .6813 Mdot
.34347 .58239 Mdot
.31701 .3397 Mdot
.83745 .54601 Mdot
.55755 .38301 Mdot
.4954 .81233 Mdot
.4634 .45276 Mdot
.33458 .56598 Mdot
.75089 .51889 Mdot
.58155 .60842 Mdot
.55372 .61733 Mdot
.19476 .57108 Mdot
.72707 .68111 Mdot
.73589 .50317 Mdot
.50797 .55062 Mdot
.54812 .70598 Mdot
.40432 .80361 Mdot
.31761 .55541 Mdot
.47686 .25882 Mdot
.48465 .81644 Mdot
.56748 .38368 Mdot
.63042 .49272 Mdot
.28092 .47368 Mdot
.2757 .29656 Mdot
.55312 .78049 Mdot
.79832 .57282 Mdot
.38698 .5357 Mdot
.27598 .4324 Mdot
.48607 .82603 Mdot
.47465 .79967 Mdot
.59315 .18793 Mdot
.63567 .46054 Mdot
.42465 .54862 Mdot
.26435 .29978 Mdot
.68329 .53114 Mdot
.44842 .19849 Mdot
.49075 .20116 Mdot
.74876 .71556 Mdot
.43951 .49112 Mdot
.20373 .68444 Mdot
.34795 .64328 Mdot
.26987 .68395 Mdot
.79693 .48457 Mdot
.29314 .27569 Mdot
.3785 .72931 Mdot
.68381 .45157 Mdot
.63456 .70992 Mdot
.54958 .67547 Mdot
.56416 .19517 Mdot
.62051 .18027 Mdot
.31688 .46525 Mdot
.58959 .44194 Mdot
.23797 .70766 Mdot
.492 .66056 Mdot
.79688 .34477 Mdot
.31418 .28404 Mdot
.81687 .50948 Mdot
.56313 .39429 Mdot
.49333 .58985 Mdot
.46561 .58178 Mdot
.55929 .79729 Mdot
.68871 .31796 Mdot
.4525 .76429 Mdot
.17573 .41205 Mdot
.24376 .69213 Mdot
.65207 .58185 Mdot
.39558 .72489 Mdot
.34652 .76618 Mdot
.24887 .35262 Mdot
.53503 .47012 Mdot
.24403 .62803 Mdot
.29991 .60503 Mdot
.20413 .63954 Mdot
.58542 .42545 Mdot
.39734 .44727 Mdot
.63868 .32031 Mdot
.37322 .30251 Mdot
.7956 .53398 Mdot
.51584 .59188 Mdot
.80581 .62712 Mdot
.39085 .77291 Mdot
.6392 .22296 Mdot
.76419 .33577 Mdot
.81861 .40223 Mdot
.70084 .69571 Mdot
.23417 .39788 Mdot
.27376 .32103 Mdot
.2335 .30429 Mdot
.45379 .45398 Mdot
.33263 .70382 Mdot
.27687 .60704 Mdot
.4856 .8224 Mdot
.59668 .3364 Mdot
.73253 .36778 Mdot
.62025 .29632 Mdot
.48879 .79215 Mdot
.63286 .66554 Mdot
.41417 .78084 Mdot
.53521 .42302 Mdot
.87056 .43919 Mdot
.20769 .4981 Mdot
.50978 .42029 Mdot
.40712 .41382 Mdot
.25526 .38499 Mdot
.3359 .7369 Mdot
.21077 .5045 Mdot
.31547 .25688 Mdot
.35764 .34266 Mdot
.54241 .50766 Mdot
.55759 .75387 Mdot
.30559 .56294 Mdot
.19242 .57171 Mdot
.34225 .58228 Mdot
.45093 .81744 Mdot
.58393 .80402 Mdot
.8061 .62368 Mdot
.33534 .68681 Mdot
.16824 .54657 Mdot
.68106 .36407 Mdot
.27486 .55472 Mdot
.31511 .28552 Mdot
.31634 .42474 Mdot
.70783 .47139 Mdot
.55113 .09976 Mdot
.17205 .47343 Mdot
.22234 .43795 Mdot
.805 .65344 Mdot
.18987 .52589 Mdot
.5581 .27606 Mdot
.60992 .59327 Mdot
.76299 .42812 Mdot
.7818 .64631 Mdot
.48402 .62023 Mdot
.83195 .41587 Mdot
.39636 .54994 Mdot
.88767 .50936 Mdot
.38456 .79162 Mdot
.59002 .43751 Mdot
.54328 .57482 Mdot
.38569 .35056 Mdot
.42567 .46937 Mdot
.42322 .71305 Mdot
.60595 .676 Mdot
.71828 .31297 Mdot
.59647 .28823 Mdot
.41763 .34037 Mdot
.3567 .31983 Mdot
.69885 .464 Mdot
.2283 .55773 Mdot
.41355 .30385 Mdot
.45384 .36049 Mdot
.46317 .43753 Mdot
.38843 .574 Mdot
.67427 .29141 Mdot
.59081 .76669 Mdot
.7783 .54364 Mdot
.64822 .41325 Mdot
.41735 .35825 Mdot
.62352 .7539 Mdot
.18546 .46845 Mdot
.23372 .68556 Mdot
.81126 .64453 Mdot
.49017 .50092 Mdot
.60796 .70063 Mdot
.4012 .66239 Mdot
.78269 .39138 Mdot
.61479 .46869 Mdot
.58403 .29011 Mdot
.66619 .25238 Mdot
.59787 .53213 Mdot
.4059 .24517 Mdot
.72176 .74505 Mdot
.29647 .28207 Mdot
.26201 .30032 Mdot
.36301 .47308 Mdot
.45832 .55394 Mdot
.66024 .55705 Mdot
.34376 .62829 Mdot
.53963 .39847 Mdot
.36567 .18065 Mdot
.48866 .55746 Mdot
.33174 .17574 Mdot
.59006 .33536 Mdot
.70399 .56322 Mdot
.2946 .60891 Mdot
.54248 .45396 Mdot
.54353 .42057 Mdot
.21035 .47663 Mdot
.74061 .36942 Mdot
.23622 .38415 Mdot
.78356 .42018 Mdot
.40748 .33557 Mdot
.15525 .45546 Mdot
.1658 .58508 Mdot
.64754 .70855 Mdot
.50009 .68364 Mdot
.16287 .50052 Mdot
.43259 .34913 Mdot
.7768 .55552 Mdot
.29375 .75979 Mdot
.21675 .6144 Mdot
.55372 .74507 Mdot
.33611 .56842 Mdot
.33847 .70798 Mdot
.56994 .83158 Mdot
.62339 .1943 Mdot
.29226 .70905 Mdot
.59726 .33893 Mdot
.53544 .4317 Mdot
.37852 .74744 Mdot
.75247 .35764 Mdot
.54365 .30319 Mdot
.70669 .30779 Mdot
.25936 .23433 Mdot
.40208 .7382 Mdot
.42774 .73925 Mdot
.74878 .34159 Mdot
.63678 .54659 Mdot
.73367 .34623 Mdot
.68398 .28762 Mdot
.20984 .56639 Mdot
.20086 .41673 Mdot
.6847 .29296 Mdot
.24732 .27825 Mdot
.5781 .55672 Mdot
.49119 .35805 Mdot
.57498 .66992 Mdot
.45284 .74279 Mdot
.59319 .39799 Mdot
.73148 .70584 Mdot
.26149 .71414 Mdot
.5539 .31165 Mdot
.1994 .58923 Mdot
.37052 .27389 Mdot
.45947 .73784 Mdot
.57389 .78135 Mdot
.23463 .66 Mdot
.62803 .68319 Mdot
.5601 .18353 Mdot
.76963 .59292 Mdot
.43946 .35265 Mdot
.29778 .74519 Mdot
.4045 .36165 Mdot
.53149 .72316 Mdot
.76193 .46496 Mdot
.24827 .62734 Mdot
.81911 .49305 Mdot
.33821 .51858 Mdot
.69734 .49004 Mdot
.62415 .18632 Mdot
.62864 .5284 Mdot
.83376 .44632 Mdot
.73813 .56068 Mdot
.69451 .27733 Mdot
.27175 .39168 Mdot
.25302 .42722 Mdot
.24564 .2574 Mdot
.52666 .32962 Mdot
.42024 .32908 Mdot
.53483 .19388 Mdot
.69221 .48277 Mdot
.36285 .47534 Mdot
.39757 .4166 Mdot
.45606 .42995 Mdot
.48046 .21425 Mdot
.57484 .55377 Mdot
.60889 .52327 Mdot
.44761 .43867 Mdot
.6693 .76115 Mdot
.65789 .79228 Mdot
.43313 .39688 Mdot
.38782 .15656 Mdot
.55089 .58823 Mdot
.66684 .70117 Mdot
.43175 .81418 Mdot
.51724 .1366 Mdot
.4477 .33084 Mdot
.17631 .62651 Mdot
.44267 .64978 Mdot
.23625 .6374 Mdot
.66178 .48406 Mdot
.30554 .27999 Mdot
.28647 .51368 Mdot
.32427 .57998 Mdot
.56795 .31468 Mdot
.77854 .52215 Mdot
.43149 .31969 Mdot
.69579 .51806 Mdot
.21979 .57556 Mdot
.40607 .65148 Mdot
.61301 .34341 Mdot
.28653 .35652 Mdot
.64292 .71611 Mdot
.507 .77033 Mdot
.61927 .57206 Mdot
.4176 .72888 Mdot
.22545 .33278 Mdot
.87124 .56012 Mdot
.71346 .45554 Mdot
.59482 .49002 Mdot
.53615 .21291 Mdot
.21404 .62677 Mdot
.59674 .22543 Mdot
.45378 .83031 Mdot
.39863 .56592 Mdot
.49759 .52473 Mdot
.40615 .58058 Mdot
.5524 .68538 Mdot
.51259 .45314 Mdot
.48464 .28019 Mdot
.73597 .31448 Mdot
.65603 .28314 Mdot
.63399 .6011 Mdot
.58669 .2065 Mdot
.4033 .69769 Mdot
.69792 .28462 Mdot
.45426 .37781 Mdot
.51448 .76904 Mdot
.62986 .39765 Mdot
.66081 .79301 Mdot
.44642 .82463 Mdot
.54504 .38039 Mdot
.33609 .33782 Mdot
.23311 .71498 Mdot
.44659 .59573 Mdot
.55527 .4956 Mdot
.53468 .63765 Mdot
.46852 .50979 Mdot
.47775 .13466 Mdot
.20936 .59922 Mdot
.51424 .69211 Mdot
.49326 .80409 Mdot
.52914 .81252 Mdot
.87967 .46769 Mdot
.31338 .23965 Mdot
.66301 .51362 Mdot
.86012 .46931 Mdot
.709 .30541 Mdot
.5573 .83191 Mdot
.52787 .28953 Mdot
.4891 .86075 Mdot
.63866 .70427 Mdot
.21268 .64375 Mdot
.60603 .58214 Mdot
.75347 .40248 Mdot
.29678 .32781 Mdot
.55389 .48944 Mdot
.49938 .24133 Mdot
.19877 .48173 Mdot
.14767 .44515 Mdot
.52863 .70187 Mdot
.32382 .29692 Mdot
.66222 .41978 Mdot
.31419 .76279 Mdot
.22465 .47883 Mdot
.52075 .67933 Mdot
.63763 .34512 Mdot
.80618 .5083 Mdot
.39159 .57704 Mdot
.58619 .51582 Mdot
.22503 .46623 Mdot
.77926 .63329 Mdot
.40638 .67921 Mdot
.26895 .29523 Mdot
.63935 .71471 Mdot
.44856 .46387 Mdot
.46834 .60061 Mdot
.62779 .47344 Mdot
.32034 .4736 Mdot
.53279 .48789 Mdot
.50386 .67773 Mdot
.3881 .42448 Mdot
.55437 .29437 Mdot
.82192 .44222 Mdot
.66047 .31805 Mdot
.26154 .31871 Mdot
.62377 .56613 Mdot
.71428 .42622 Mdot
.5873 .22226 Mdot
.81125 .40349 Mdot
.25126 .47735 Mdot
.38792 .58815 Mdot
.43727 .78695 Mdot
.58734 .806 Mdot
.70727 .54628 Mdot
.86497 .54839 Mdot
.58984 .39292 Mdot
.48728 .75556 Mdot
.73001 .41357 Mdot
.4038 .32193 Mdot
.55305 .56219 Mdot
.2125 .64112 Mdot
.34971 .55295 Mdot
.37553 .6967 Mdot
.21811 .4116 Mdot
.49678 .5172 Mdot
.5874 .75345 Mdot
.49418 .80909 Mdot
.37126 .36838 Mdot
.2318 .34153 Mdot
.61942 .37191 Mdot
.23032 .46205 Mdot
.58771 .80881 Mdot
.7821 .6771 Mdot
.5169 .39891 Mdot
.30366 .59694 Mdot
.51454 .6332 Mdot
.25236 .29993 Mdot
.2068 .59488 Mdot
.47087 .73743 Mdot
.4542 .25465 Mdot
.62788 .49826 Mdot
.44574 .28885 Mdot
.46615 .46582 Mdot
.77162 .65479 Mdot
.62752 .48658 Mdot
.67664 .25706 Mdot
.30366 .47845 Mdot
.57791 .4558 Mdot
.52035 .54405 Mdot
.31739 .59568 Mdot
.32347 .21552 Mdot
.49924 .5504 Mdot
.30098 .72448 Mdot
.63457 .73695 Mdot
.33815 .26437 Mdot
.23166 .64443 Mdot
.57244 .27275 Mdot
.74267 .37254 Mdot
.53509 .77491 Mdot
.62608 .29561 Mdot
.53884 .59967 Mdot
.42865 .34018 Mdot
.68727 .52369 Mdot
.30031 .75424 Mdot
.69697 .704 Mdot
.33867 .61979 Mdot
.38785 .49767 Mdot
.5861 .52984 Mdot
.62461 .38467 Mdot
.47017 .84976 Mdot
.74767 .38108 Mdot
.37288 .5701 Mdot
.44105 .49102 Mdot
.30282 .60965 Mdot
.69623 .58525 Mdot
.76774 .70815 Mdot
.61188 .58993 Mdot
.48493 .42157 Mdot
.71121 .55783 Mdot
.22381 .41901 Mdot
.28521 .75662 Mdot
.40915 .58304 Mdot
.56997 .44169 Mdot
.34592 .51143 Mdot
.59307 .23938 Mdot
.37724 .48515 Mdot
.57294 .51113 Mdot
.42888 .44537 Mdot
.45999 .23382 Mdot
.71763 .44253 Mdot
.41976 .6606 Mdot
.34808 .69194 Mdot
.4551 .79479 Mdot
.34378 .25355 Mdot
.6074 .29928 Mdot
.47984 .32261 Mdot
.73405 .69534 Mdot
.51003 .87096 Mdot
.69923 .25012 Mdot
.51308 .63699 Mdot
.62715 .33643 Mdot
.2884 .5871 Mdot
.37695 .39881 Mdot
.66214 .27518 Mdot
.61544 .2511 Mdot
.59844 .35855 Mdot
.34017 .5621 Mdot
.38827 .69615 Mdot
.34182 .31037 Mdot
.25695 .569 Mdot
.63707 .38733 Mdot
.82034 .42498 Mdot
.17685 .50699 Mdot
.2158 .62958 Mdot
.6228 .85565 Mdot
.6137 .32835 Mdot
.48748 .72215 Mdot
.63851 .63914 Mdot
.61583 .80928 Mdot
.34847 .5862 Mdot
.78596 .56819 Mdot
.54415 .24907 Mdot
.41321 .57471 Mdot
.68046 .44577 Mdot
.365 .69666 Mdot
.43874 .28601 Mdot
.51506 .44084 Mdot
.25282 .43415 Mdot
.87083 .54671 Mdot
.5728 .74572 Mdot
.4423 .79599 Mdot
.80247 .48991 Mdot
.23499 .29979 Mdot
.60864 .81316 Mdot
.34951 .66384 Mdot
.22607 .50159 Mdot
.60845 .64226 Mdot
.56507 .42309 Mdot
.68131 .57127 Mdot
.77926 .55709 Mdot
.63185 .7681 Mdot
.30051 .38155 Mdot
.69504 .57507 Mdot
.39755 .62337 Mdot
.65877 .7568 Mdot
.57047 .44058 Mdot
.59795 .76688 Mdot
.34413 .33165 Mdot
.73664 .33076 Mdot
.71205 .52245 Mdot
.35955 .61202 Mdot
.63446 .74366 Mdot
.5133 .21047 Mdot
.19856 .50366 Mdot
.19843 .32987 Mdot
.31495 .45316 Mdot
.80632 .41825 Mdot
.46337 .67929 Mdot
.88967 .43523 Mdot
.2617 .35828 Mdot
.29589 .33587 Mdot
.21928 .39675 Mdot
.38847 .43993 Mdot
.54777 .70222 Mdot
.53855 .59919 Mdot
.32969 .73572 Mdot
.55681 .74372 Mdot
.73966 .58529 Mdot
.78111 .5096 Mdot
.32527 .57304 Mdot
.38484 .61656 Mdot
.34499 .63503 Mdot
.52995 .53153 Mdot
.62986 .50299 Mdot
.84504 .4421 Mdot
.50688 .392 Mdot
.46915 .7352 Mdot
.49001 .54544 Mdot
.61393 .62459 Mdot
.23149 .73884 Mdot
.59601 .43127 Mdot
.42816 .73401 Mdot
.60627 .73821 Mdot
.71532 .53616 Mdot
.6049 .227 Mdot
.83861 .69178 Mdot
.90713 .44286 Mdot
.70001 .51024 Mdot
.37262 .22127 Mdot
.59612 .74292 Mdot
.46238 .77365 Mdot
.25791 .46308 Mdot
.43984 .2502 Mdot
.48268 .7482 Mdot
.74919 .48473 Mdot
.55091 .55272 Mdot
.26414 .34816 Mdot
.68418 .78176 Mdot
.77553 .50922 Mdot
.48997 .80273 Mdot
.56455 .6591 Mdot
.53832 .54902 Mdot
.59422 .87263 Mdot
.38812 .75225 Mdot
.52544 .56709 Mdot
.64411 .58569 Mdot
.42108 .63538 Mdot
.50143 .60408 Mdot
.25616 .6616 Mdot
.1575 .45202 Mdot
.40578 .68135 Mdot
.48653 .79082 Mdot
.65068 .4635 Mdot
.36376 .41591 Mdot
.5884 .33201 Mdot
.52384 .40354 Mdot
.49944 .56216 Mdot
.59314 .38169 Mdot
.4467 .52679 Mdot
.23388 .70805 Mdot
.3921 .48409 Mdot
.19159 .39234 Mdot
.55201 .85088 Mdot
.68184 .71513 Mdot
.61424 .25998 Mdot
.44377 .6015 Mdot
.5076 .77293 Mdot
.60654 .78734 Mdot
.5613 .51849 Mdot
.18761 .59063 Mdot
.65675 .15366 Mdot
.58075 .25073 Mdot
.76339 .67427 Mdot
.67276 .53938 Mdot
.42363 .45868 Mdot
.569 .76156 Mdot
.528 .2956 Mdot
.42428 .40538 Mdot
.57394 .62794 Mdot
.61928 .54416 Mdot
.57739 .40249 Mdot
.40583 .14268 Mdot
.49671 .68396 Mdot
.63926 .2576 Mdot
.53689 .8276 Mdot
.77043 .59163 Mdot
.66326 .6724 Mdot
.49445 .57725 Mdot
.6788 .39928 Mdot
.5691 .44253 Mdot
.29138 .72382 Mdot
.79615 .64125 Mdot
.44072 .77563 Mdot
.69418 .70791 Mdot
.58903 .75131 Mdot
.4678 .60264 Mdot
.28431 .5253 Mdot
.51591 .35137 Mdot
.30444 .71449 Mdot
.42583 .61737 Mdot
.60529 .82401 Mdot
.42748 .31619 Mdot
.44519 .49985 Mdot
.59903 .44197 Mdot
.87528 .46944 Mdot
.64717 .61136 Mdot
.64012 .5657 Mdot
.81334 .40802 Mdot
.40261 .31481 Mdot
.27745 .562 Mdot
.37872 .3537 Mdot
.43372 .60918 Mdot
.61673 .50098 Mdot
.80072 .34498 Mdot
.29732 .6957 Mdot
.50901 .23811 Mdot
.46273 .26218 Mdot
.38436 .23354 Mdot
.6149 .35169 Mdot
.64302 .847 Mdot
.26862 .3749 Mdot
.81572 .37765 Mdot
.22516 .33682 Mdot
.61281 .53586 Mdot
.1913 .53307 Mdot
.51478 .55344 Mdot
.425 .39921 Mdot
.46071 .78259 Mdot
.48498 .72856 Mdot
.81035 .56925 Mdot
.45049 .6194 Mdot
.83014 .5166 Mdot
.34713 .49726 Mdot
.32495 .35429 Mdot
.23182 .40685 Mdot
.62084 .62443 Mdot
.40025 .82169 Mdot
.58041 .22924 Mdot
.41719 .81972 Mdot
.37658 .80319 Mdot
.50985 .81771 Mdot
.80426 .55299 Mdot
.58205 .16918 Mdot
.22643 .42205 Mdot
.23163 .65817 Mdot
.49413 .29448 Mdot
.60189 .61454 Mdot
.25359 .38641 Mdot
.59246 .54248 Mdot
.68733 .31912 Mdot
.63389 .37294 Mdot
.39432 .10288 Mdot
.37663 .64276 Mdot
.64684 .55734 Mdot
.25037 .40028 Mdot
.55329 .82248 Mdot
.61386 .63618 Mdot
.19983 .47257 Mdot
.47761 .4636 Mdot
.50182 .70908 Mdot
.63508 .7648 Mdot
.34505 .24825 Mdot
.31834 .32746 Mdot
.18249 .32428 Mdot
.18584 .47274 Mdot
.48202 .23623 Mdot
.50086 .44989 Mdot
.70057 .50662 Mdot
.54501 .18386 Mdot
.25963 .42302 Mdot
.18064 .57327 Mdot
.21843 .67384 Mdot
.38212 .74952 Mdot
.25273 .25216 Mdot
.32139 .27587 Mdot
.6417 .80007 Mdot
.19424 .5521 Mdot
.70048 .51223 Mdot
.33592 .65508 Mdot
.44535 .36328 Mdot
.49713 .25935 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo08oooooo0_l0000;ooooo`;o0000Zoooool001cooooo00?o0000oooo
ooooool0Soooool2o`0000_ooooo0_l0002[ooooo`007?ooool2o`000:Sooooo0_l00006ooooo`;o
0000V?ooool001cooooo00?o0000ooooooooool0O?ooool2o`0001Wooooo0_l00009ooooo`;o0000
0oooool2o`0000Kooooo0_l0002Hooooo`007?ooool00ol0003oooooooooo`1looooo`;o00006Ooo
ool2o`0000Wooooo0_l0002Uooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0U?ooool2o`000;?o
oooo000Looooo`03o`000?oooooooooo09Cooooo0_l0002cooooo`007?ooool00ol0003ooooooooo
o`2?ooooo`;o00004_ooool2o`000:Cooooo000Looooo`03o`000?oooooooooo08oooooo0_l0000B
ooooo`;o0000Y?ooool001cooooo00?o0000ooooooooool0XOooool2o`000:Kooooo000Looooo`03
o`000?oooooooooo0:7ooooo0_l0000^ooooo`;o0000M_ooool001cooooo00?o0000ooooooooool0
Uoooool2o`0003Sooooo0_l0001fooooo`007?ooool00ol0003oooooooooo`2Gooooo`;o00002ooo
ool4o`000:7ooooo000Looooo`03o`000?oooooooooo0:Cooooo1?l0000>ooooo`;o0000TOooool0
01cooooo00?o0000ooooooooool0P?ooool2o`0003Cooooo0_l0002Aooooo`007?ooool00ol0003o
ooooooooo`20ooooo`;o0000aoooool001cooooo00?o0000ooooooooool0[oooool2o`0009Sooooo
000Looooo`;o0000/?ooool2o`00027ooooo0_l0001eooooo`007?ooool00ol0003oooooooooo`1j
ooooo`;o0000>?ooool4o`0001[ooooo0_l0001eooooo`007?ooool00ol0003oooooooooo`1doooo
o`;o00001?ooool2o`0000[ooooo0_l0000/ooooo`Co0000TOooool001cooooo00?o0000oooooooo
ool0M?ooool2o`00013ooooo0_l00031ooooo`007?ooool00ol0003oooooooooo`2Qooooo`;o0000
Y_ooool001cooooo00?o0000ooooooooool0P_ooool2o`0001Oooooo0_l00004ooooo`;o000000?o
ooooo`000?l000001_ooool2o`0000_ooooo0_l0002>ooooo`007?ooool00ol0003oooooooooo`22
ooooo`;o00001_ooool2o`0000_ooooo0_l00002ooooo`;o00001oooool2o`0000Kooooo0_l0000;
ooooo`;o00000_ooool2o`0000Gooooo0_l00023ooooo`007?ooool00ol0003oooooooooo`1^oooo
o`;o00006_ooool2o`0000_ooooo0_l0000Fooooo`Co00002_ooool2o`0000Gooooo0_l00023oooo
o`007?ooool00ol0003oooooooooo`1Xooooo`;o00001?ooool2o`0001?ooooo0_l00005ooooo`;o
00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`000005ooooo`;o00003oooool4o`0009Ko
oooo000Looooo`03o`000?oooooooooo06Sooooo0_l00009ooooo`;o00001oooool4o`0000?ooooo
0_l00009ooooo`;o00000_ooool4o`000003ooooool0003o000000Gooooo0_l0000Vooooo`;o0000
POooool001cooooo00?o0000ooooooooool0Loooool2o`0000Oooooo1?l0000Booooo`;o00002_oo
ool2o`0000gooooo0_l00003ooooo`;o00004_ooool2o`0000Cooooo0_l0001kooooo`007?ooool0
0ol0003oooooooooo`21ooooo`;o00005?ooool2o`0000Gooooo0_l00005ooooo`;o00000_ooool2
o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000004?ooool2o`0000?ooooo0_l0001k
ooooo`007?ooool00ol0003oooooooooo`21ooooo`?o00004oooool2o`0000cooooo0_l00002oooo
o`;o00002Oooool3o`0000Kooooo0_l00004ooooo`;o00000_ooool2o`00083ooooo00001_oooooo
k^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`1a
ooooo`;o00001?ooool2o`0000Wooooo0_l00005ooooo`?o00000oooool2o`000003ooooool0003o
000000_ooooo0_l00009ooooo`;o00002?ooool2o`0000Oooooo0_l00004ooooo`;o00000_ooool2
o`0000Wooooo0_l0001eooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0LOooool2o`0000Cooooo
0_l0000@ooooo`?o00000oooool2o`000003ooooool0003o000000_ooooo0_l00009ooooo`;o0000
1oooool2o`0000;ooooo1_l0000:ooooo`;o00002Oooool2o`0007Gooooo00000ooooooo410@oooo
o`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003ooooooooo
o`2>ooooo`;o00002Oooool2o`0001Kooooo1?l00002ooooo`Ko00002_ooool2o`00083ooooo0000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3
o`0006gooooo0_l0000Eooooo`;o00002?ooool2o`0000Sooooo0ol000000ooooooo0000o`000002
o`00017ooooo0_l00008ooooo`;o0000S?ooool00003ooooool0003ooooo00;ooooo00?o0000oooo
ooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo06Gooooo0_l00002oooo
o`;o00000_ooool2o`000003ooooool0003o000000;ooooo0_l0000;ooooo`;o000000?oooooo`00
0?l000003_ooool6o`0000;ooooo1?l00007ooooo`;o00002_ooool2o`0001cooooo0_l0001foooo
o`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0IOooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l0
00000_ooool4o`000004ooooool0003o0000o`0000Gooooo0_l0000@ooooo`Ko00003_ooool3o`00
00Wooooo1?l00004ooooo`;o00005?ooool2o`0007Kooooo00001_ooooooMgMgoiRHV?ooooooV9RH
ogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo06?ooooo0_l0
0008ooooo`;o00001oooool2o`000004ooooool0003o0000o`0000;ooooo0_l0000Cooooo`Ko0000
2_ooool2o`0000?ooooo0_l0000;ooooo`;o00001?ooool2o`0008cooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo
06?ooooo0_l0000Iooooo`;o00005oooool3o`0000Wooooo0_l00005ooooo`;o00001_ooool3o`00
013ooooo0_l00022ooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o00005Oooool2o`00017o
oooo0_l00007ooooo`;o00002oooool2o`0000?ooooo0_l00006ooooo`Co00001_ooool2o`0000Oo
oooo0_l0000Dooooo`;o0000K?ooool001cooooo00?o0000ooooooooool0Foooool2o`0000Sooooo
0_l0000<ooooo`Co00001Oooool2o`00017ooooo0_l0000Dooooo`;o00003Oooool2o`0000Kooooo
0ol000000ooooooo0000o`000003ooooo`;o00000oooool2o`0000oooooo0_l0001/ooooo`007?oo
ool00ol0003oooooooooo`1Kooooo`;o00000oooool2o`0000Wooooo0_l00006ooooo`Co00001ooo
ool2o`0000_ooooo0_l0000^ooooo`Co000000?oooooo`000?l000002?ooool4o`0007_ooooo000L
ooooo`03o`000?oooooooooo063ooooo0_l00009ooooo`;o00001oooool2o`0000Sooooo0_l00008
ooooo`;o000000?oooooo`000?l00000:?ooool2o`0000Cooooo0_l000001?oooooo0000o`000?oo
ool4o`0000;ooooo0_l00003ooooo`;o0000Noooool001cooooo00?o0000ooooooooool0I_ooool2
o`0000Oooooo0_l00003ooooo`;o00001oooool2o`0000Wooooo0_l0000Dooooo`;o00005Oooool2
o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o0000P?ooool0
01cooooo00?o0000ooooooooool0I_ooool3o`0000Kooooo0_l00003ooooo`;o00000oooool2o`00
00;ooooo0_l0000Cooooo`;o00002_ooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool2
o`0000;ooooo0_l0000:ooooo`;o00009Oooool2o`0006Oooooo000Looooo`03o`000?oooooooooo
057ooooo0_l0000Dooooo`;o00002?ooool2o`0000Kooooo0_l00009ooooo`?o00002oooool4o`00
00?ooooo0_l00008ooooo`Go000000?oooooo`000?l000000_ooool2o`000003ooooool0003o0000
00;o00004_ooool4o`0001Cooooo1?l0001Wooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o
00003oooool2o`0000gooooo0_l00004ooooo`?o00002_ooool3o`0000gooooo0_l00003ooooo`?o
00001?ooool6o`0000Sooooo1_l00009ooooo`;o00001oooool4o`0001Cooooo0_l0001Yooooo`00
7?ooool00ol0003oooooooooo`1Pooooo`Co00000oooool2o`0000Kooooo0_l00006ooooo`?o0000
00?oooooo`000?l000000_ooool3o`0001Sooooo0_l00002ooooo`Ko00002Oooool5o`000003oooo
ool0003o000000Cooooo0_l00002ooooo`;o00004_ooool2o`0007Kooooo000Looooo`03o`000?oo
oooooooo063ooooo0_l00005ooooo`;o00000oooool2o`000003ooooool0003o000000[ooooo0_l0
0002ooooo`?o00001?ooool2o`00017ooooo0_l00003ooooo`;o00003Oooool2o`0000Cooooo1?l0
0002ooooo`;o00004_ooool2o`000004ooooool0003o0000o`0000Kooooo0_l0000:ooooo`;o0000
H_ooool001cooooo00?o0000ooooooooool0I?ooool2o`000003ooooool0003o000000?ooooo0_l0
0002ooooo`Co00001Oooool2o`0000?ooooo1?l00004ooooo`;o00002?ooool2o`0000Oooooo0_l0
00000ooooooo0000o`00000>ooooo`?o00001_ooool4o`0000[ooooo0_l00008ooooo`;o000000?o
ooooo`000?l000001oooool3o`000003ooooool0003o000000Kooooo0_l00003ooooo`;o0000GOoo
ool001cooooo0_l0001?ooooo`Co00004_ooool2o`0000Kooooo0_l00002ooooo`Co00001Oooool2
o`0000?ooooo0_l0000;ooooo`;o000000?oooooo`000?l000000_l00005ooooo`;o00000oooool2
o`0000kooooo1_l00005ooooo`Co00001Oooool2o`000004ooooool0003o0000o`0000Kooooo0_l0
00000ooooooo0000o`000004ooooo`;o00000oooool2o`000003ooooool0003o000000;o00002Ooo
ool2o`0005gooooo000Looooo`03o`000?oooooooooo04kooooo1?l0000Jooooo`;o00007Oooool2
o`000003ooooool0003o000000;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o
000000?ooooo0_l0000>ooooo`?o00000oooool2o`0000;ooooo0_l00005ooooo`;o00000_ooool2
o`0000Kooooo0_l000000ooooooo0000o`000004ooooo`;o00002?ooool2o`0000cooooo0_l0001J
ooooo`007?ooool00ol0003oooooooooo`1<ooooo`;o00005Oooool2o`0000Oooooo0_l0000;oooo
o`;o00005Oooool2o`000003ooooool0003o000000Gooooo0_l000000ooooooo0000o`000002o`00
0005ooooool0003o0000o`000?ooool00_l0000=ooooo`;o00000oooool2o`0000;ooooo0_l00005
ooooo`;o00001Oooool2o`000003ooooool0003o000000Oooooo0_l0000Cooooo`;o0000F_ooool0
01cooooo00?o0000ooooooooool0C?ooool2o`00017ooooo0_l00002ooooo`;o00001oooool2o`00
00_ooooo0_l00002ooooo`;o00006?ooool2o`0000Cooooo2?l000000ooooooo0000o`00000Boooo
o`?o000000?oooooo`000?l000001?ooool6o`0000;ooooo0_l00003ooooo`;o00001Oooool2o`00
06oooooo000Looooo`03o`000?oooooooooo04?ooooo0_l0000Jooooo`;o00002Oooool4o`0000oo
oooo0_l00004ooooo`;o00001?ooool2o`0000Sooooo0_l00002ooooo`;o00001Oooool4o`000003
ooooool0003o000000[ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Ko
oooo1ol00004ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`00077ooooo000Looooo`03
o`000?oooooooooo04?ooooo0_l0000Jooooo`;o00002Oooool3o`0001Kooooo0_l00004ooooo`;o
00000_ooool2o`0000?ooooo0ol00008ooooo`?o00000oooool2o`0000[ooooo0_l00003ooooo`;o
000000Coooooo`000?l0003ooooo0_l00007ooooo`;o00001Oooool2o`0000;ooooo0_l00002oooo
o`;o00000_ooool3o`00073ooooo000Looooo`03o`000?oooooooooo05kooooo0ol0000Fooooo`;o
00001_ooool2o`0000[ooooo1?l00003ooooo`;o00002Oooool5o`0001;ooooo0_l00004ooooo`;o
00000_ooool2o`0000[ooooo0_l0000;ooooo`;o0000L?ooool001cooooo00?o0000ooooooooool0
G_ooool2o`0001Gooooo1?l00006ooooo`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`?o
00000oooool2o`0000Kooooo0_l00006ooooo`;o000000?oooooo`000?l000004Oooool2o`0000Ko
oooo0_l00007ooooo`Co00001?ooool2o`0007Sooooo000Looooo`03o`000?oooooooooo05cooooo
0_l00005ooooo`Co00003_ooool2o`0000Sooooo0_l000001?oooooo0000o`000?ooool2o`0000?o
oooo0_l00004ooooo`;o00001_ooool2o`0000Wooooo0_l000000ooooooo0000o`00000:ooooo`Ko
00003oooool4o`0000Cooooo0_l00002ooooo`;o00002oooool3o`0006Kooooo000Looooo`03o`00
0?oooooooooo04gooooo0_l0000=ooooo`;o00000_ooool2o`000003ooooool0003o000000Co0000
0_ooool2o`0001Gooooo1?l000000ooooooo0000o`000005ooooo`;o00003_ooool2o`0000Kooooo
0ol00006ooooo`;o000000?oooooo`000?l000000_l0000Cooooo`;o00002?ooool2o`0000Wooooo
1Ol0001Vooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00002Oooool2o`0000?ooooo0_l0
00000ooooooo0000o`000005ooooo`;o00000_ooool2o`0000Gooooo0_l00002ooooo`;o00003?oo
ool2o`000003ooooool0003o000000Gooooo0_l0000:ooooo`;o00000_ooool2o`0000Oooooo0_l0
0005ooooo`?o00000_ooool2o`0000gooooo0_l00005ooooo`;o00001_ooool2o`0000_ooooo0_l0
00001?oooooo0000o`000?ooool2o`0006?ooooo000Looooo`03o`000?oooooooooo05Sooooo1ol0
0003ooooo`?o00001_ooool2o`0000Gooooo0_l00002ooooo`;o00004oooool2o`0000gooooo1?l0
000>ooooo`Go00004Oooool2o`0000Kooooo0_l00005ooooo`?o00002oooool2o`0000?ooooo0_l0
001Sooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00003oooool4o`0000Cooooo0ol00003
ooooo`;o00000_ooool2o`0000Wooooo0_l0000;ooooo`;o00001Oooool4o`0000_ooooo1?l0000>
ooooo`;o00000oooool2o`0000Gooooo0_l00004ooooo`;o00000_ooool2o`0000;ooooo0_l00002
ooooo`;o00001_ooool2o`0000Kooooo0_l00003ooooo`;o0000J?ooool001cooooo00?o0000oooo
ooooool0BOooool2o`0000Kooooo0_l0000@ooooo`Oo00000_ooool2o`0000Wooooo0_l0000;oooo
o`?o00001_ooool2o`0001Wooooo0_l00007ooooo`;o00000oooool6o`0000;ooooo0_l000000ooo
oooo0000o`000002o`000004ooooool0003o0000o`0000kooooo0_l000001?oooooo0000o`000?l0
0002ooooo`;o00006oooool2o`0004_ooooo000Looooo`03o`000?oooooooooo057ooooo0_l00000
0ooooooo0000o`00000?ooooo`?o00006oooool4o`0000oooooo1_l000000ooooooo0000o`000009
ooooo`;o00000oooool5o`0000Cooooo0_l00002ooooo`;o00001Oooool4o`0000;ooooo0ol0000=
ooooo`;o00000_ooool2o`0000;ooooo0_l0000Kooooo`;o0000Boooool001cooooo00?o0000oooo
ooooool0C?ooool2o`0000;ooooo0_l00002ooooo`Go00003?ooool2o`0001cooooo1?l0000?oooo
o`[o00002?ooool2o`0000;ooooo1_l000000ooooooo0000o`000005ooooo`;o00001_ooool3o`00
0003ooooool0003o000000?o00003Oooool2o`000003ooooool0003o000000Gooooo0_l0001Uoooo
o`007?ooool2o`0004[ooooo0_l000000ooooooo0000o`000006o`0000;ooooo1_l00005ooooo`?o
000000?oooooo`000?l000000oooool2o`0001Kooooo1Ol0000Eooooo`Co00002?ooool2o`0000;o
oooo1?l00003ooooo`Co00000oooool2o`0000Gooooo2_l00003ooooo`Ko00001?ooool3o`0000Oo
oooo0_l00007ooooo`;o00005?ooool2o`0004Kooooo000Looooo`03o`000?oooooooooo04Sooooo
0ol00002ooooo`?o000000Coooooo`000?l0003o00001Oooool3o`0000Gooooo1?l00003ooooo`Co
00001?ooool2o`000003ooooool0003o000000;o00002oooool4o`0000Wooooo0_l0000<ooooo`;o
00001Oooool2o`0000?ooooo0_l00002ooooo`?o000000?oooooo`000?l000001Ol000000ooooooo
0000o`000006ooooo`?o000000?oooooo`000?l000001oooool6o`0000Gooooo0_l000001?oooooo
0000o`000?ooool2o`0000[ooooo0_l0000Dooooo`;o0000A_ooool001cooooo00?o0000oooooooo
ool0B?ooool2o`0000?ooooo0_l00005ooooo`;o00000oooool2o`0000Cooooo0_l000001?oooooo
0000o`000?l00003ooooo`;o00001_ooool2o`000003ooooool0003o000000;o00001_ooool2o`00
00Cooooo0_l0000:ooooo`;o00002Oooool5o`0000Gooooo0_l00003ooooo`Ko00000_ooool4o`00
0004ooooool0003o0000ooooo`;o00002?ooool2o`0000Kooooo0_l00004ooooo`;o00001?ooool2
o`0000?ooooo0_l000001?oooooo0000o`000?ooool3o`0006Cooooo000Looooo`03o`000?oooooo
oooo04gooooo0_l00005ooooo`;o00002Oooool2o`0000[ooooo1?l00009ooooo`;o00000oooool2
o`000003ooooool0003o000000;o00002oooool2o`0000Sooooo1?l00004ooooo`;o00001Oooool6
o`000003ooooool0003o000000?ooooo1?l000000ooooooo0000o`000008ooooo`Ko00000_ooool2
o`0000[ooooo0_l00009ooooo`?o0000I?ooool001cooooo00?o0000ooooooooool0Joooool4o`00
00Wooooo0_l00006ooooo`Co00002Oooool4o`0000?ooooo0_l00003ooooo`;o00001_ooool2o`00
00Gooooo0ol000001?oooooo0000o`000?ooool;o`000003ooooool0003o000000Kooooo1_l0000M
ooooo`;o0000HOooool001cooooo00?o0000ooooooooool0=oooool2o`0003_ooooo0_l00009oooo
o`;o00001_ooool2o`0000Cooooo0_l00005ooooo`;o00001_ooool2o`0000_ooooo0_l00002oooo
o`;o000000?oooooo`000?l000002?l000000ooooooo0000o`000003ooooo`;o00001Oooool2o`00
00cooooo0_l0000?ooooo`;o00000oooool2o`0000?ooooo0_l0001Gooooo`007?ooool00ol0003o
ooooooooo`0gooooo`;o00006?ooool2o`00013ooooo0_l000000ooooooo0000o`000008ooooo`;o
00000_ooool2o`0000Wooooo0_l00006ooooo`?o00002oooool2o`0000Gooooo0_l0000?ooooo`ko
00000oooool4o`0000Gooooo0_l00009ooooo`Go00001?ooool5o`0000_ooooo0_l00003ooooo`;o
0000Eoooool001cooooo00?o0000ooooooooool0DOooool2o`0000;ooooo0_l0000:ooooo`Co0000
00?oooooo`000?l000002?ooool2o`0000gooooo0_l00007ooooo`;o00001?ooool2o`0000Gooooo
0_l000000ooooooo0000o`00000=ooooo`;o00001_oooolAo`0000cooooo0_l00004ooooo`?o0000
1_ooool5o`0000Sooooo0_l0000Wooooo`;o0000=_ooool001cooooo00?o0000ooooooooool0>?oo
ool2o`0001Sooooo0_l000000ooooooo0000o`00000:ooooo`?o00000_ooool2o`0000Sooooo0_l0
0006ooooo`;o000000?oooooo`000?l000000_ooool2o`0000gooooo0_l00008ooooo`?o00002Ooo
ool2o`000003ooooool0003o000000Kooooo3ol000000ooooooo0000o`000008ooooo`;o000000?o
ooooo`000?l000000_l00005ooooo`;o00002?ooool2o`0000Oooooo0_l0000Wooooo`;o0000=_oo
ool001cooooo00?o0000ooooooooool0>?ooool2o`0001Sooooo0_l00009ooooo`;o00000oooool6
o`000003ooooool0003o000000Gooooo0_l00004ooooo`Oo00001oooool3o`0001;ooooo0_l00009
ooooo`;o00000_ooool2o`0000Gooooo4_l00003ooooo`Co000000?oooooo`000?l000000oooool2
o`0000Gooooo0_l00008ooooo`;o000000?oooooo`000?l00000IOooool001cooooo00?o0000oooo
ooooool0?Oooool2o`0001Wooooo0_l00003ooooo`;o00001Oooool2o`000003ooooool0003o0000
00;o000000?oooooo`000?l000002?ooool5o`0000Sooooo1Ol00006ooooo`;o00003?ooool2o`00
00Wooooo0ol00004oooooa?o00000oooool4o`000003ooooool0003o000000;ooooo0_l00004oooo
o`;o00003Oooool2o`0000Oooooo0_l0001Looooo`007?ooool00ol0003oooooooooo`0mooooo`;o
00001oooool2o`000003ooooool0003o000000?ooooo0_l00008ooooo`;o00002Oooool3o`000003
ooooool0003o000000?ooooo0_l000000ooooooo0000o`000003ooooo`?o000000Coooooo`000?l0
003o00001_ooool7o`0000Kooooo0_l0000<ooooo`;o00002Oooool2o`0000?ooooo1_l00002oooo
o`[o000000Coooooo`000?l0003ooooo0_l00005ooooo`;o00000_ooool2o`0000Cooooo0_l0000F
ooooo`;o00001Oooool2o`000003ooooool0003o000000Kooooo0_l0001:ooooo`007?ooool00ol0
003oooooooooo`15ooooo`?o000000?oooooo`000?l000000oooool2o`0000cooooo0_l00003oooo
o`Go00000oooool2o`0000Cooooo0_l00003ooooo`?o000000Coooooo`000?l0003o00001?ooool5
o`000003ooooool0003o000000;o00002oooool2o`0000Cooooo0_l00004ooooo`;o00002_ooool2
o`0000;ooooo4Ol000000ooooooo0000o`000004ooooo`Co00009_ooool5o`0000Kooooo0_l0001:
ooooo`007?ooool00ol0003oooooooooo`15ooooo`;o000000?oooooo`000?l000001oooool2o`00
00?ooooo0_l00003ooooo`?o00000oooool4o`0000Cooooo0_l000000ooooooo0000o`00000Aoooo
o`Oo000000?oooooo`000?l000002?ooool2o`000003ooooool0003o000000Cooooo0_l00004oooo
o`;o00002ooooolDo`0000Oooooo1?l0000=ooooo`;o00002Oooool4o`0000Oooooo0_l00003oooo
o`;o00001oooool2o`0004[ooooo000Looooo`03o`000?oooooooooo03oooooo0_l00003ooooo`;o
00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`;o00000oooool2o`0000?o
oooo0_l000000ooooooo0000o`000005ooooo`Co00000_ooool2o`0000?ooooo1?l000001?oooooo
0000o`000?l00004ooooo`Wo00001oooool2o`0000Oooooo0_l0000<ooooo`;o00000ooooolDo`00
00;ooooo0_l0000>ooooo`;o00001?ooool2o`0000Wooooo1?l00007ooooo`;o00001Oooool2o`00
00Gooooo1?l00018ooooo`007?ooool00ol0003oooooooooo`0nooooo`?o00000oooool2o`0000So
oooo0_l00004ooooo`;o00001?ooool2o`0000Cooooo0_l00003ooooo`;o00000oooool2o`0000?o
oooo0ol00003oooooaGo00007_ooool2o`0000?ooooo2?l000000ooooooo0000o`000009o`0000;o
oooo0_l00006ooooo`;o00001_ooool2o`0001Cooooo1?l00009ooooo`;o00001oooool3o`0004Oo
oooo000Looooo`;o0000?oooool2o`0000Sooooo0_l00003ooooo`;o00000oooool4o`000004oooo
ool0003o0000ooooo`;o00000_ooool4o`0000?ooooo0_l00008ooooo`?o00001?oooolBo`000003
ooooool0003o0000017ooooo0_l0000?oooooaCo00000_ooool2o`0000Kooooo0_l00004ooooo`;o
00005_ooool4o`0000;ooooo0_l00002ooooo`;o00002oooool2o`000003ooooool0003o000004Co
oooo000Looooo`03o`000?oooooooooo04Sooooo0_l00003ooooo`;o00000oooool7o`0000Cooooo
1Ol00005ooooo`;o00001oooool2o`0000?ooooo3ol00002ooooo`Oo000000?oooooo`000?l00000
3?ooool2o`0000Kooooo0_l00006oooooago00002?ooool4o`0001Cooooo0_l00004ooooo`;o0000
00Coooooo`000?l0003o00001?ooool2o`0000Sooooo0_l00014ooooo`007?ooool00ol0003ooooo
ooooo`0looooo`;o00003oooool2o`0000Gooooo1ol00002ooooo`;o00001oooool3o`0000Oooooo
0_l00002oooooaWo000000?oooooo`000?l000004Oooool2o`000004ooooool0003o0000o`0000Go
oooo2_l000000ooooooo0000o`00000:o`000003ooooool0003o000000?o000000?oooooo`000?l0
00000ol00002ooooo`Co00005?ooool2o`0000Oooooo0_l00005ooooo`;o0000C_ooool001cooooo
00?o0000ooooooooool0??ooool2o`0000Oooooo0_l0000:ooooo`;o00001_ooool2o`0000_ooooo
0_l00006ooooo`;o00000_ooool>o`000003ooooool0003o000000[o000000?oooooo`000?l00000
3?ooool2o`0000?ooooo0_l00002ooooo`;o00001_oooolFo`0000Oooooo1Ol00002ooooo`;o0000
7_ooool2o`0005Kooooo000Looooo`03o`000?oooooooooo03cooooo0_l00007ooooo`;o00002Ooo
ool3o`0000_ooooo0_l00004ooooo`;o00002?ooool2o`000003ooooool0003o000001oo00002_oo
ool2o`0000_ooooo0_l00002oooooaOo0000:Oooool6o`0000cooooo0_l00018ooooo`007?ooool0
0ol0003oooooooooo`0looooo`;o00001_ooool2o`0000[ooooo0_l000001?oooooo0000o`000?oo
ool2o`0000Kooooo0_l00004ooooo`Co00002OoooolNo`000003ooooool0003o000000_ooooo1?l0
0005ooooo`oo00000_ooool=o`0000Gooooo0_l000000ooooooo0000o`000009ooooo`Co00004_oo
ool7o`0000_ooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00003Oooool2
o`000003ooooool0003o000000kooooo0_l0000;oooooaco00003_ooool4o`0000Gooooo1?l00000
0ooooooo0000o`000008o`000003ooooool0003o000000Co000000?oooooo`000?l000001Ol00003
ooooo`Co000000?oooooo`000?l000000oooool2o`0000Cooooo1Ol0000>ooooo`;o000000?ooooo
o`000?l000000oooool2o`0000Oooooo0_l0001<ooooo`007?ooool00ol0003oooooooooo`15oooo
o`;o00002_ooool2o`00023ooooo6ol0000Oooooo`oo000000?oooooo`000?l000001Ol000000ooo
oooo0000o`000002o`0000?ooooo0_l00003ooooo`;o00001oooool2o`0000kooooo1Ol0000<oooo
o`;o00004Oooool2o`0003Wooooo000Looooo`03o`000?oooooooooo04Gooooo0_l0000:ooooo`;o
000000?oooooo`000?l000002?ooool2o`00017ooooo5_l000000ooooooo0000o`000006o`0001Oo
oooo0_l00004oooooaKo00000_ooool4o`000003ooooool0003o000000;o00007Oooool4o`0000So
oooo0_l000000ooooooo0000o`00000Booooo`;o0000>Oooool001cooooo00?o0000ooooooooool0
>oooool2o`0000?ooooo0ol00002ooooo`;o00003Oooool2o`0000Sooooo0_l00009ooooo`;o0000
1_oooolQo`0001Gooooo0_l00004oooooaKo00001oooool4o`0000;ooooo0_l0000Aooooo`?o0000
1Oooool2o`0000[ooooo0_l000000ooooooo0000o`000009ooooo`;o0000@_ooool001cooooo00?o
0000ooooooooool0>oooool2o`0000?ooooo0ol0000:ooooo`;o00002?ooool2o`0000Gooooo0_l0
0004ooooo`;o00000oooool2o`0000Kooooo8Ol0000?ooooo`;o00000_ooool2o`0000Kooooo3_l0
00000ooooooo0000o`000004o`0000kooooo0_l00004ooooo`;o00001_ooool2o`0000?ooooo0ol0
00000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000005?ooool2o`0004;ooooo000L
ooooo`03o`000?oooooooooo04Wooooo0_l00002ooooo`;o00002?ooool2o`0000Gooooo0_l00004
ooooo`;o00003Oooool5o`000003ooooool0003o000000Co000000?oooooo`000?l000003_l0000A
ooooo`;o00000_ooool2o`0000Gooooo0ol000000ooooooo0000o`00000@o`0000Gooooo0_l0000:
ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Oooooo0_l000000ooooooo0000o`000005
o`0005Sooooo000Looooo`03o`000?oooooooooo03kooooo0_l00009ooooo`?o00000oooool2o`00
00Oooooo0_l0000Dooooo`;o00001OoooolKo`0001Cooooo0_l000000ooooooo0000o`000003oooo
o`;o00000_oooolAo`0000Kooooo0_l00002ooooo`;o00001_ooool2o`0000Wooooo0_l0000:oooo
o`;o000000Coooooo`000?l0003o00007Oooool2o`0003[ooooo000Looooo`03o`000?oooooooooo
03kooooo0_l0000:ooooo`;o00000oooool2o`0000Oooooo1?l0000Booooo`;o00000oooool4o`00
0003ooooool0003o000001Ko00003_ooool2o`0000Cooooo0_l000000ooooooo0000o`000007oooo
oa7o00000_ooool2o`0000Kooooo0_l00006ooooo`;o00002Oooool3o`0000gooooo0_l000000ooo
oooo0000o`000002o`000003ooooool0003o000001Gooooo0_l0000jooooo`0000Koooooonk^k_lb
<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000
ooooooooool0>oooool2o`0000Oooooo0_l000000ooooooo0000o`00000<ooooo`Oo00002_ooool2
o`000003ooooool0003o000000Cooooo0_l00002oooooago000000?oooooo`000?l000000_l00009
ooooo`;o000000?oooooo`000?l000000oooool5o`0000Kooooo4Ol000000ooooooo0000o`000006
ooooo`;o00004_ooool2o`0000[ooooo0_l000001?oooooo0000o`000?ooool4o`000003ooooool0
003o000000;ooooo0_l0001=ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q
1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03_ooooo0_l00004ooooo`;o0000
00Coooooo`000?l0003ooooo0_l00006ooooo`;o00001?ooool4o`0000gooooo0_l000000ooooooo
0000o`000004ooooo`;o00000oooool8o`000003ooooool0003o0000013o00000_ooool4o`0000co
oooo0_l00003ooooo`Ko00000oooool?o`0000;ooooo0_l00002ooooo`;o00001Oooool2o`0000Wo
oooo0_l00002ooooo`;o000000?oooooo`000?l000003?ooool6o`0000Wooooo0_l0000:ooooo`;o
00002_ooool2o`0003Gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo
1Ol00006ooooo`03o`000?oooooooooo047ooooo0_l000000ooooooo0000o`000002ooooo`;o0000
1Oooool2o`0002;ooooo7?l00002ooooo`;o00004Oooool4o`0000;ooooo1?l000000ooooooo0000
o`000004o`000003ooooool0003o000000Oo00001Oooool2o`0000?ooooo0_l00003ooooo`;o0000
1_ooool2o`000003ooooool0003o000000Co00000_ooool2o`0000Wooooo0_l000000ooooooo0000
o`000006ooooo`;o00000_ooool2o`0000Wooooo0_l0000:ooooo`;o0000=Oooool00003ooooool0
003ooooo00;ooooo00?o0000ooooooooool02Oooool01?m4A4CogMgMooooool00007ooooo`?o0000
AOooool2o`000003ooooool0003o000000;ooooo1?l0000Soooooaco00000_ooool2o`0000?ooooo
0_l0000<ooooo`Co00000_ooool4o`000003ooooool0003o000000;o000000?oooooo`000?l00000
2Ol0000:ooooo`;o00000oooool2o`0000Oooooo1ol00003ooooo`;o000000?oooooo`000?l00000
2oooool4o`0000;ooooo0_l00002ooooo`;o00002Oooool2o`00047ooooo00000ooooooo0000oooo
o`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003ooooo
ooooo`15ooooo`;o00001?ooool5o`0000_ooooo0_l00008ooooo`;o00003_oooolJo`0000Oooooo
0ol0000;ooooo`Co00000_ooool2o`0000Cooooo0_l00002ooooo`?o000000?oooooo`000?l00000
1?l0000?ooooo`;o00001_ooool4o`0000;ooooo0_l00007ooooo`;o00002oooool5o`0000kooooo
1?l00011ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03ogMgMoo<
c<co000000Oooooo00?o0000ooooooooool0AOooool2o`000004ooooool0003o0000ooooo`?o0000
3Oooool2o`0000?ooooo0_l00003ooooo`;o00001oooool2o`0000Cooooo6_l000000ooooooo0000
o`000006ooooo`;o00003?ooool3o`0000gooooo0_l0000:ooooo`Co00001oooool3o`0000Kooooo
0_l0000Mooooo`;o00003_ooool2o`000003ooooool0003o0000043ooooo00001_ooooooMgMgoiRH
V?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0eooooo`;o
00003?ooool2o`0000;ooooo0ol00002ooooo`;o00004_ooool2o`0000Sooooo0_l00002ooooo`;o
00000_ooool:o`000003ooooool0003o000001;o00003_ooool2o`0000kooooo0ol00002ooooo`;o
000000Coooooo`000?l0003o00000oooool8o`0000Oooooo0_l0000Zooooo`;o00002_ooool2o`00
0003ooooool0003o0000043ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPgooooo00?oMgMg
o`000?ooool01_ooool00ol0003oooooooooo`0cooooo`Co00000_ooool2o`0000Sooooo0_l00002
ooooo`;o00008Oooool2o`0000Gooooo2ol000000ooooooo0000o`00000Ao`0000oooooo0_l0000>
ooooo`?o00000_ooool2o`000004ooooool0003o0000o`0000?ooooo1?l0000>ooooo`;o00006?oo
ool2o`0000;ooooo0_l00009ooooo`;o00002_ooool2o`0004?ooooo000Looooo`03o`000?oooooo
oooo03?ooooo0_l00004ooooo`Oo0000<Oooool3o`0000?ooooo0_l000000ooooooo0000o`00000A
o`0002Gooooo0_l0000:ooooo`Go00001Oooool2o`0000Gooooo0_l00004ooooo`;o00004_ooool2
o`0000;ooooo0ol00005ooooo`;o00001Oooool2o`0000Cooooo1?l00003ooooo`?o0000?Oooool0
01cooooo00?o0000ooooooooool0<oooool2o`0000Gooooo1_l00005ooooo`Co00000_ooool2o`00
00[ooooo0_l0000Iooooo`;o00001_oooolDo`0000cooooo0_l00006ooooo`;o00002Oooool2o`00
00?ooooo0_l000000ooooooo0000o`000006ooooo`Ko000000?oooooo`000?l000000_ooool2o`00
00Kooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000Gooooo0_l0000=oooo
o`;o000000Goooooo`000?l0003o0000ooooo`02o`0000Cooooo0ol00004ooooo`Co00000oooool3
o`0000Gooooo0ol0000eooooo`007?ooool00ol0003oooooooooo`15ooooo`Co00000_ooool2o`00
00Cooooo0_l00004ooooo`;o00002_ooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool4o`00
00Kooooo1Ol000000ooooooo0000o`000008o`0000;ooooo0_l0000<ooooo`;o00001_ooool2o`00
00Kooooo0_l000000ooooooo0000o`000005ooooo`?o00001?ooool4o`000003ooooool0003o0000
00;ooooo0_l00002ooooo`;o00001_ooool2o`000003ooooool0003o000000?ooooo0_l00005oooo
o`;o00003_ooool5o`0000Oooooo0_l00006ooooo`;o00003?ooool3o`0003Gooooo000Looooo`03
o`000?oooooooooo04Kooooo0_l00006ooooo`;o000000?oooooo`000?l000004?ooool2o`0000?o
oooo0_l00002ooooo`;o00000_ooool4o`0000Kooooo1?l00003ooooo`Co000000?oooooo`000?l0
00000_l0000Eooooo`;o00002Oooool2o`0000Sooooo0ol00003ooooo`?o00000oooool2o`0000?o
oooo0_l000001?oooooo0000o`000?ooool2o`0000Cooooo0_l0000Aooooo`;o00001?ooool2o`00
00?ooooo0_l0000=ooooo`;o00000oooool2o`0000;ooooo0_l00010ooooo`007?ooool00ol0003o
ooooooooo`1=ooooo`?o00006Oooool2o`0000Gooooo0_l0000?ooooo`;o00000oooool2o`0000So
oooo0_l00006ooooo`Co00000oooool2o`0000Oooooo0_l00006ooooo`Wo000000?oooooo`000?l0
00002Oooool3o`0000?ooooo0_l00004ooooo`;o00004Oooool2o`0000Cooooo0_l00008ooooo`;o
00002?ooool2o`0000;ooooo0_l00003ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0
Boooool5o`0000Kooooo0_l0000Aooooo`;o00002?ooool2o`0000cooooo1Ol000000ooooooo0000
o`000007ooooo`;o00001_ooool4o`0000;ooooo0_l00008ooooo`Co00001?ooool6o`000003oooo
ool0003o000000Gooooo0_l00006ooooo`Co00009oooool2o`000003ooooool0003o000000;ooooo
0_l00008ooooo`;o0000AOooool001cooooo00?o0000ooooooooool0=oooool2o`0001;ooooo0_l0
00000ooooooo0000o`000006ooooo`;o00002_ooool2o`0000?ooooo0_l0000:ooooo`;o00001Ooo
ool2o`0000Oooooo0ol000000ooooooo0000o`00000=ooooo`Co00001?ooool2o`0000[ooooo0_l0
0003ooooo`;o00003Oooool2o`0000Gooooo0_l000000ooooooo0000o`000002o`0002Gooooo0_l0
0005ooooo`;o00000oooool2o`0000oooooo0_l0000=ooooo`;o0000:_ooool001cooooo00?o0000
ooooooooool0=oooool2o`0000cooooo0_l0000Kooooo`;o00000oooool2o`0000Sooooo1?l00002
ooooo`;o000000?oooooo`000?l000001Oooool2o`0000_ooooo0_l00003ooooo`;o000000?ooooo
o`000?l000005oooool2o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l000001oooool2
o`0000?ooooo0_l0000Gooooo`;o00004Oooool2o`0000Gooooo0ol0000>ooooo`;o00001oooool2
o`0000Cooooo0_l0000Zooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00002oooool2o`00
01;ooooo0_l00009ooooo`Co00000_ooool7o`0000?ooooo0_l0000;ooooo`;o00000oooool2o`00
0003ooooool0003o000000cooooo0_l00009ooooo`;o00000_ooool5o`000004ooooool0003o0000
ooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000gooooo0_l00002
ooooo`;o00001_ooool4o`0000Cooooo0_l00009ooooo`;o00001_ooool2o`0000Oooooo0_l00000
0ooooooo0000o`000003ooooo`;o00001Oooool3o`0000[ooooo0_l0000Tooooo`007?ooool00ol0
003oooooooooo`0/ooooo`;o00001_ooool2o`0001cooooo0_l0000Booooo`;o000000?oooooo`00
0?l000001_ooool2o`0000Gooooo0_l000000ooooooo0000o`000003o`0000Sooooo0_l0000Joooo
o`;o00000oooool2o`0000[ooooo0ol00004ooooo`;o000000?oooooo`000?l000001?ooool2o`00
0003ooooool0003o000000gooooo2Ol00005ooooo`;o00001?ooool2o`0001Kooooo0_l00002oooo
o`;o000000Coooooo`000?l0003o00000_ooool2o`0000Gooooo0_l0000;ooooo`;o00009?ooool0
01cooooo00?o0000ooooooooool0;?ooool2o`0000Kooooo0_l0000_ooooo`Ko00001?ooool4o`00
00[ooooo0ol00008ooooo`;o00007oooool2o`000003ooooool0003o000000[ooooo0_l0000Moooo
o`Co000000?oooooo`000?l000000_l00005ooooo`Go00001_ooool2o`00017ooooo0_l00006oooo
o`;o0000??ooool001cooooo0_l0000`ooooo`;o00001Oooool2o`0000Oooooo0_l00008ooooo`;o
00006_ooool4o`0000;ooooo0_l00002ooooo`;o00003?ooool2o`0000kooooo0_l0000@ooooo`;o
00002oooool2o`0000[ooooo0_l0000Kooooo`Oo00002oooool3o`0000Kooooo0_l000001?oooooo
0000o`000?l0000Oooooo`;o0000<_ooool001cooooo00?o0000ooooooooool0;oooool2o`0000Go
oooo0_l00002ooooo`;o00000_ooool4o`0000Oooooo0_l0000Hooooo`Co00001?ooool2o`0000Wo
oooo0_l0000Eooooo`;o000000Coooooo`000?l0003ooooo0_l0000:ooooo`So00001Oooool2o`00
01gooooo0_l00008ooooo`So00001oooool2o`0000Sooooo0_l00003ooooo`?o00007oooool2o`00
03;ooooo000Looooo`03o`000?oooooooooo02oooooo0_l00009ooooo`;o00000_ooool4o`0000Co
oooo0_l0000;ooooo`;o00003Oooool5o`0000oooooo0_l0000>ooooo`;o00002?ooool2o`000003
ooooool0003o000000Kooooo0_l00004ooooo`Ko00001Oooool2o`0000Kooooo0_l00002ooooo`;o
00001Oooool2o`0000[ooooo0_l00008ooooo`Go000000?oooooo`000?l000001oooool2o`0000So
oooo0_l00002ooooo`?o00001_ooool2o`0004cooooo000Looooo`03o`000?oooooooooo02_ooooo
0_l0000=ooooo`?o00001_ooool2o`000003ooooool0003o000000_ooooo0_l0000=ooooo`;o0000
0_ooool2o`0000kooooo0_l0000>ooooo`;o00001?ooool2o`0000;ooooo0_l00009ooooo`?o0000
1_ooool2o`0000kooooo1_l00005ooooo`;o00001Oooool2o`0000?ooooo0_l00002ooooo`?o0000
0oooool5o`0000?ooooo0_l0000:ooooo`;o00001oooool3o`0000Kooooo0_l00006ooooo`;o0000
4oooool2o`0002oooooo000Looooo`03o`000?oooooooooo02_ooooo1?l00007ooooo`;o00000ooo
ool2o`0000Kooooo0_l00002ooooo`;o00001Oooool4o`0001Cooooo0_l0000Cooooo`;o00001_oo
ool2o`0000Oooooo1?l00007ooooo`;o00000_ooool3o`0000;ooooo0_l00002ooooo`;o00004?oo
ool2o`0000kooooo0_l00003ooooo`;o000000?oooooo`000?l000002_l000000ooooooo0000o`00
0004o`0000Sooooo0ol00002ooooo`So00001?ooool3o`0000Kooooo0_l0000Cooooo`;o0000;ooo
ool001cooooo00?o0000ooooooooool0;Oooool2o`0000Oooooo0_l0000=ooooo`Co00001Oooool4
o`00017ooooo0_l00004ooooo`;o00001?ooool2o`0000[ooooo0_l00006ooooo`;o00002Oooool2
o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool4o`0000_ooooo0_l0000G
ooooo`;o00001?ooool?o`000003ooooool0003o000000?o00001oooool2o`0000;ooooo2?l00004
ooooo`?o00001_ooool2o`0001Gooooo0_l0000]ooooo`007?ooool00ol0003oooooooooo`0boooo
o`;o00001Oooool2o`0000[ooooo0_l0000<ooooo`;o00002_ooool2o`0000;ooooo0_l00004oooo
o`;o00001?ooool2o`0000kooooo0_l00006ooooo`;o00002oooool2o`0000Gooooo1?l000000ooo
oooo0000o`000002o`0000Kooooo0_l00003ooooo`;o00004oooool2o`000003ooooool0003o0000
00?o00001?oooolDo`0000Kooooo0_l00002ooooo`;o00009?ooool2o`0000;ooooo1?l0000]oooo
o`007?ooool00ol0003oooooooooo`0Zooooo`;o00001_ooool4o`0000?ooooo0_l00002ooooo`Co
00004_ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000000_ooool2o`0000;o
oooo0ol0000:ooooo`Co00000oooool4o`0000Cooooo0_l00006ooooo`?o00002_ooool2o`0000Oo
oooo0_l000000ooooooo0000o`000006ooooo`Co00004Oooool2o`0000Gooooo0_l000000ooooooo
0000o`00000Fo`000003ooooool0003o000000;o00001Oooool2o`0001?ooooo0_l0000Dooooo`;o
00000_ooool2o`0002oooooo000Looooo`03o`000?oooooooooo02[ooooo0_l00008ooooo`;o0000
0oooool3o`000003ooooool0003o000000Co00004oooool4o`000003ooooool0003o000000;ooooo
2_l00002ooooo`;o00000oooool4o`0000?ooooo1?l00003ooooo`;o00002?ooool2o`0001?ooooo
0_l00009ooooo`Co00000_ooool2o`0000_ooooo1?l00009ooooo`;o00000_oooolDo`000004oooo
ool0003o0000o`0000Cooooo1Ol00005ooooo`;o00001?ooool2o`0000Cooooo0_l00019ooooo`00
7?ooool00ol0003oooooooooo`0booooo`;o00001_ooool2o`0000Gooooo0_l00002ooooo`;o0000
1oooool2o`0000;ooooo0_l00002ooooo`Go00000_ooool=o`000003ooooool0003o000000Gooooo
0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Sooooo0_l00006ooooo`;o0000
2oooool2o`0000oooooo0_l0000;ooooo`;o00003OoooolJo`0000Cooooo0_l000000ooooooo0000
o`000005ooooo`;o000000Coooooo`000?l0003ooooo0ol00008ooooo`;o0000A?ooool001cooooo
00?o0000ooooooooool0<_ooool2o`000003ooooool0003o000000Kooooo0_l00006ooooo`?o0000
00?oooooo`000?l000000oooool2o`0000;ooooo0_l00002oooooaCo00003Oooool2o`000003oooo
ool0003o000001?ooooo0ol00007ooooo`;o00002oooool2o`0000oooooo0_l00005ooooo`;o0000
00?oooooo`000?l000000_ooool2o`0000;ooooo6?l000000ooooooo0000o`000005ooooo`;o0000
2_ooool2o`0000;ooooo0_l00008ooooo`;o00001_ooool2o`0003cooooo000Looooo`03o`000?oo
oooooooo03?ooooo1Ol00005ooooo`;o00001oooool2o`000003ooooool0003o000000_ooooo5Ol0
000<ooooo`;o00000_ooool3o`00017ooooo0_l00008ooooo`;o00002_ooool3o`0000oooooo0ol0
0004ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo2Ol000000ooooooo0000o`00
000<o`000003ooooool0003o000000Gooooo0_l00005ooooo`;o00003Oooool2o`0000Gooooo0_l0
0003ooooo`;o0000??ooool001cooooo00?o0000ooooooooool07?ooool2o`0001Gooooo0_l00000
0ooooooo0000o`000002o`0001gooooo5?l0000<ooooo`;o00000_ooool4o`0000_ooooo1_l0000>
ooooo`;o00001Oooool2o`0000;ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00000ooo
ool4o`0000_ooooo8Ol0000:ooooo`;o00002Oooool2o`0000;ooooo0_l00003ooooo`Co00002Ooo
ool2o`0000[ooooo0_l0000Zooooo`007?ooool00ol0003oooooooooo`0Looooo`;o00006_ooool2
o`0001cooooo5Ol00006ooooo`;o00002_ooool2o`0000_ooooo1ol00004ooooo`;o000000Gooooo
o`000?l0003o0000ooooo`04o`0000Wooooo0_l00002ooooo`;o000000Coooooo`000?l0003o0000
0oooool2o`0000Cooooo0ol00006ooooob;o00000_ooool2o`00013ooooo0_l000001?oooooo0000
o`000?ooool5o`0000_ooooo0_l0000:ooooo`;o0000:_ooool001cooooo00?o0000ooooooooool0
>oooool2o`0000oooooo0_l00008ooooo`;o00000_ooool;o`000003ooooool0003o000000?o0000
1_ooool2o`0000?ooooo0_l00008ooooo`;o00002Oooool3o`000003ooooool0003o000000Cooooo
0_l000000ooooooo0000o`000004o`00013ooooo0_l000000ooooooo0000o`000002o`0000Oooooo
0ol00009oooooa_o000000?oooooo`000?l000000_l000000ooooooo0000o`00000Cooooo`;o0000
00?oooooo`000?l000000_l000000ooooooo0000o`00000Aooooo`;o0000;_ooool001cooooo00?o
0000ooooooooool0;?ooool2o`0000cooooo0ol00003ooooo`;o000000?oooooo`000?l000001ooo
ool2o`0000Oooooo6_l00007ooooo`;o00000_ooool2o`0000;ooooo1?l00006ooooo`;o00003Ooo
ool2o`0000;ooooo0ol0000@ooooo`;o000000?oooooo`000?l000001?l00005ooooo`;o00002_oo
ool6o`000003ooooool0003o000000oo000000Goooooo`000?l0003o0000ooooo`03o`0000;ooooo
0ol00002ooooo`;o00000oooool2o`0000Kooooo0_l00008ooooo`;o00004Oooool2o`0002kooooo
000Looooo`;o00007oooool2o`0000cooooo0_l00003ooooo`;o00001oooool4o`0000;ooooo0_l0
00001?oooooo0000o`000?ooool2o`0000gooooo6_l0000;ooooo`;o00000_ooool2o`0000Sooooo
0_l00003ooooo`;o00001_ooool4o`000004ooooool0003o0000o`0000[ooooo0ol00002ooooo`;o
00001oooool3o`0000Cooooo0_l00007oooooaoo00000_ooool7o`0000;ooooo0_l00003ooooo`;o
00001_ooool2o`0000Gooooo0_l0000Gooooo`;o0000:oooool001cooooo00?o0000ooooooooool0
7_ooool2o`0000kooooo0_l000000ooooooo0000o`000009ooooo`?o00000_ooool2o`0000?ooooo
0_l00009ooooo`;o00000ooooolHo`0000_ooooo0_l00004ooooo`Co00002_ooool3o`0000Gooooo
0_l00002ooooo`Ko00002?ooool3o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000;o
oooo0_l0000<oooooako00001_ooool5o`0000;ooooo1?l00002ooooo`;o00002?ooool2o`0000;o
oooo0_l0000:ooooo`;o00002oooool2o`0000;ooooo0_l0000Wooooo`007?ooool00ol0003ooooo
ooooo`0^ooooo`;o00001?ooool6o`0000?ooooo0_l00002ooooo`;o00003_ooool2o`0000?ooooo
6?l0000;ooooo`;o00000oooool8o`0000Sooooo0_l00009ooooo`;o000000Coooooo`000?l0003o
00002oooool4o`000004ooooool0003o0000ooooo`;o00003_oooolUo`0000;ooooo1?l00002oooo
o`Co00000_ooool2o`0000Sooooo0ol0000=ooooo`;o00001?ooool2o`0000Wooooo0_l0000Woooo
o`007?ooool00ol0003oooooooooo`0dooooo`Ko00005?ooool2o`0000Kooooo5_l0000Booooo`So
00002Oooool2o`0000?ooooo0_l00006ooooo`;o00003?ooool4o`0000Sooooo0_l00004ooooo`?o
00000ooooolUo`0000?ooooo0_l0000<ooooo`Co00001?ooool4o`0000;ooooo0_l0000=ooooo`;o
00001_ooool2o`0002[ooooo000Looooo`03o`000?oooooooooo03[ooooo0_l00007ooooo`;o0000
2Oooool2o`0000;ooooo0_l00002oooooaWo00008?ooool2o`0000;ooooo0ol0000Pooooo`;o0000
1?ooool5o`0000?ooooo8Ol00005ooooo`;o00000_ooool2o`0000Sooooo1?l00006ooooo`;o0000
0_ooool2o`0001Gooooo0_l0000Zooooo`007?ooool00ol0003oooooooooo`0gooooo`;o000000?o
ooooo`000?l000001oooool2o`0000[ooooo0_l000000ooooooo0000o`000002oooooaWo00000_oo
ool4o`0000Wooooo0_l00005ooooo`;o00000_ooool2o`0000;ooooo0_l00004ooooo`;o000000?o
ooooo`000?l000001_ooool2o`0001_ooooo0_l00002ooooo`;o00001_oooolNo`0000Wooooo0_l0
000Fooooo`;o00000_ooool5o`0000kooooo0_l0000Zooooo`007?ooool00ol0003oooooooooo`0Z
ooooo`;o00002oooool2o`0000;ooooo1?l00005ooooo`;o00002Oooool2o`000003ooooool0003o
000001Wo00001?ooool4o`0000?ooooo0_l00004ooooo`;o00001Oooool2o`0000;ooooo0_l00002
ooooo`;o00001oooool2o`0000Kooooo0_l00003ooooo`;o00002?ooool2o`0000Cooooo0_l00006
ooooo`;o00002Oooool;o`000003ooooool0003o0000017o00000_ooool2o`0000Oooooo0_l0000D
ooooo`;o00000_ooool5o`0003[ooooo000Looooo`03o`000?oooooooooo02[ooooo0_l0000?oooo
o`Co00001Oooool2o`0000Oooooo0_l00003oooooa[o000000?oooooo`000?l000002Oooool2o`00
02Kooooo0_l000001?oooooo0000o`000?ooool2o`0000Gooooo2?l00008ooooo`;o00000oooool2
o`0000;ooooo8?l000000ooooooo0000o`000007ooooo`;o000000?oooooo`000?l000001?ooool2
o`0004kooooo000Looooo`03o`000?oooooooooo03[ooooo0_l0000Aooooo`;o00001Oooool2o`00
00;ooooo5ol00003ooooo`;o00002oooool2o`0000Kooooo0_l0000Eooooo`Co00001?ooool2o`00
00Gooooo1_l00004ooooo`;o00001?ooool2o`0000?ooooo0_l00002ooooob3o00001?ooool2o`00
00Oooooo0_l00004ooooo`;o00004oooool2o`0003Wooooo000Looooo`03o`000?oooooooooo03[o
oooo0_l00006ooooo`;o00004?ooool3o`000003ooooool0003o000001Co00001?ooool2o`0000Wo
oooo1?l00006ooooo`;o00001?ooool2o`0000?ooooo0_l0000:ooooo`;o00003Oooool2o`0000So
oooo0_l0000=ooooob3o00001?ooool2o`0000Oooooo0_l00004ooooo`;o00004oooool2o`0003Wo
oooo000Looooo`03o`000?oooooooooo03_ooooo0ol00004ooooo`;o00004Oooool2o`000003oooo
ool0003o000001;o00001Oooool3o`0000Wooooo0_l0000>ooooo`?o00000_ooool2o`0000[ooooo
0_l00003ooooo`;o00000oooool2o`00017ooooo0_l000000ooooooo0000o`000002o`0000;ooooo
6ol000000ooooooo0000o`000004o`0001Sooooo0_l000001?oooooo0000o`000?l00015ooooo`00
7?ooool00ol0003oooooooooo`0jooooo`Co00004_ooool2o`0000?ooooo0_l00005oooooa7o0000
1?ooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0000oooooo0_l0000>ooooo`;o
00000oooool2o`0000?ooooo0ol000000ooooooo0000o`000003ooooo`;o00001Oooool2o`000004
ooooool0003o0000ooooo`Co00000_oooolKo`0000?ooooo0_l00005ooooo`;o00000_ooool2o`00
00oooooo1_l00008ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0:oooool2o`0000go
oooo0_l0000<ooooo`?o00001Oooool2o`0000?ooooo0_l00004oooooa;o00002_ooool2o`000003
ooooool0003o000000Cooooo0_l0000Qooooo`;o00001?ooool2o`000003ooooool0003o000000;o
000000Coooooo`000?l0003ooooo0_l00002ooooo`Co00001ooooolGo`0000?ooooo0_l00006oooo
o`;o00000_ooool6o`0000gooooo0_l000000ooooooo0000o`000007ooooo`;o00000_ooool2o`00
03_ooooo000Looooo`03o`000?oooooooooo02_ooooo0_l00009ooooo`;o00004?ooool3o`0000;o
oooo0_l00009ooooo`Go00001?ooool:o`0001;ooooo0_l000001?oooooo0000o`000?l00003oooo
o`?o00009Oooool4o`0000;ooooo0_l00004ooooo`;o00001?ooool2o`000003ooooool0003o0000
00?o000000?oooooo`000?l000003ol0000;ooooo`;o00000_ooool4o`0000oooooo0_l00006oooo
o`Ko0000?oooool001cooooo00?o0000ooooooooool0;Oooool2o`0000Oooooo1?l0000Cooooo`;o
00002Oooool3o`0000Kooooo0ol00003ooooo`?o00004oooool2o`0000;ooooo0_l00003ooooo`?o
00003_ooool2o`0000Wooooo0_l000001?oooooo0000o`000?l00005ooooo`;o000000?oooooo`00
0?l000002oooool2o`000003ooooool0003o000000?ooooo0ol00003ooooo`[o00000_ooool2o`00
013ooooo0_l000000ooooooo0000o`00000:ooooo`Go00001oooool4o`00047ooooo000Looooo`03
o`000?oooooooooo02gooooo0_l00004ooooo`;o000000?oooooo`000?l000000ol0000Booooo`Go
00003?ooool2o`000004ooooool0003o0000o`0000Oooooo0_l00004ooooo`;o00002_ooool2o`00
00;ooooo0_l0000Dooooo`;o000000Coooooo`000?l0003o00001Oooool2o`000004ooooool0003o
0000o`0000?ooooo1?l00003ooooo`;o00002Oooool2o`0000Kooooo0_l00004ooooo`Oo000000?o
ooooo`000?l000003Oooool2o`0000Oooooo0ol00002ooooo`;o00001_ooool5o`0000Kooooo0_l0
0007ooooo`;o00002Oooool2o`00033ooooo000Looooo`;o0000=?ooool2o`000004ooooool0003o
0000ooooo`;o00003Oooool2o`0000Cooooo1?l0000<ooooo`;o00002Oooool4o`0000Cooooo0_l0
00000ooooooo0000o`000007ooooo`;o00000_ooool2o`0000?ooooo0_l0000Booooo`?o000000Co
ooooo`000?l0003ooooo0_l00006ooooo`Co00001Oooool3o`0000Kooooo0_l0000>ooooo`Oo0000
00?oooooo`000?l000003Oooool2o`0000Oooooo0_l00003ooooo`;o00000oooool2o`0000Cooooo
0_l00006ooooo`?o00001_ooool6o`0000?ooooo1?l0000`ooooo`007?ooool00ol0003ooooooooo
o`0hooooo`;o000000?oooooo`000?l000002oooool2o`0000Gooooo0_l00003ooooo`;o00000_oo
ool2o`0000[ooooo0_l00003ooooo`;o00000oooool2o`0000Cooooo0_l00007ooooo`;o000000?o
ooooo`000?l000001?ooool2o`0000Wooooo0_l00005ooooo`;o000000Coooooo`000?l0003ooooo
0_l000000ooooooo0000o`000004o`000003ooooool0003o000000?o00000_ooool2o`0000;ooooo
0_l00002ooooo`;o00000_ooool2o`0000cooooo2_l0000Pooooo`Co00001?ooool2o`0000;ooooo
1ol00008ooooo`Co00000oooool2o`0003;ooooo000Looooo`03o`000?oooooooooo03;ooooo0_l0
0004ooooo`;o000000?oooooo`000?l000005oooool6o`0000Wooooo1Ol00004ooooo`Co00001?oo
ool4o`0000Sooooo0ol0000>ooooo`;o00001Oooool2o`000003ooooool0003o000000;ooooo0_l0
0002ooooo`Co000000Goooooo`000?l0003o0000ooooo`02o`000003ooooool0003o000000Kooooo
0ol000000ooooooo0000o`000003ooooo`Go00001?ooool3o`000003ooooool0003o000000Ko0000
1?ooool2o`0000Kooooo0_l0000:ooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`Co0000
1_ooool2o`0003kooooo000Looooo`03o`000?oooooooooo03;ooooo1?l0000<ooooo`;o00000_oo
ool3o`0000Oooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l00003ooooo`;o0000
00Coooooo`000?l0003ooooo0_l00004ooooo`?o00001oooool2o`0000Wooooo0_l00004ooooo`;o
00002?ooool3o`000003ooooool0003o000000;ooooo1?l000000ooooooo0000o`000005o`0000Co
oooo0_l000000ooooooo0000o`000005ooooo`;o00000oooool2o`0000Gooooo2_l00005ooooo`;o
000000?oooooo`000?l000000_l00004ooooo`;o00001_ooool4o`0000Sooooo0_l0000:ooooo`;o
00003_ooool3o`0000[ooooo0ol0000`ooooo`007?ooool00ol0003oooooooooo`0dooooo`;o0000
3?ooool:o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l00003ooooo`;o
00000oooool4o`0000;ooooo0_l00005ooooo`?o00003?ooool2o`0000Cooooo0_l00008ooooo`?o
000000?oooooo`000?l000000_ooool7o`000004ooooool0003o0000o`0000Gooooo1Ol00002oooo
o`Go00000oooool2o`0000Gooooo2_l00008ooooo`;o00003_ooool4o`0000Oooooo0_l00004oooo
o`;o00001Oooool2o`0000Gooooo0_l00003ooooo`;o00000oooool2o`0000Oooooo0_l000001?oo
oooo0000o`000?l0000`ooooo`007?ooool00ol0003oooooooooo`0nooooo`Co00000_ooool4o`00
0004ooooool0003o0000o`0000[ooooo0_l00008ooooo`?o00000_ooool8o`0000Gooooo0ol00005
ooooo`;o00000_ooool2o`000003ooooool0003o0000017ooooo0_l00002ooooo`;o00000_ooool4
o`0000;ooooo1_l000000ooooooo0000o`000002o`0000?ooooo1?l00004ooooo`;o00000_ooool2
o`0000;ooooo1_l000000ooooooo0000o`000003ooooo`;o00000oooool2o`0000Kooooo0_l00006
ooooo`;o00002Oooool2o`0000Cooooo0_l00003ooooo`Co00001Oooool2o`0000?ooooo0_l0000<
ooooo`;o000000?oooooo`000?l00000<Oooool001cooooo00?o0000ooooooooool0=oooool2o`00
00;ooooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l00008ooooo`;o00002Oooool2o`00
00Cooooo1?l00004ooooo`;o00001?ooool:o`000003ooooool0003o000000;ooooo0_l0000Coooo
o`go00000oooool:o`000004ooooool0003o0000ooooo`?o00001_ooool4o`0000;ooooo0_l00005
ooooo`;o00000oooool2o`0000_ooooo0_l0000=ooooo`;o00003Oooool2o`0000;ooooo0_l00006
ooooo`;o00000oooool2o`0003oooooo000Looooo`03o`000?oooooooooo037ooooo0_l00004oooo
o`;o00000_ooool3o`0000Cooooo0_l00002ooooo`;o00002?ooool2o`0000Wooooo0_l000000ooo
oooo0000o`000003ooooo`;o00001?ooool5o`000003ooooool0003o000000So00006Oooool;o`00
0003ooooool0003o000000?ooooo0_l00002ooooo`Wo000000?oooooo`000?l000001Oooool4o`00
00Sooooo1Ol0000Aooooo`;o00003?ooool2o`00017ooooo0_l00006ooooo`;o00000oooool2o`00
03oooooo000Looooo`03o`000?oooooooooo037ooooo0_l00004ooooo`;o00000_ooool3o`0000Co
oooo1_l0000Fooooo`;o00001_ooool2o`0000?ooooo0ol000000ooooooo0000o`000004ooooo`;o
00000oooool2o`0000Cooooo1?l0000>ooooo`;o000000?oooooo`000?l000000_ooool9o`000003
ooooool0003o000000go00001_ooool2o`0000?ooooo0_l00005ooooo`Co00002?ooool2o`0000So
oooo0_l00002ooooo`;o00002_ooool3o`0000[ooooo0_l00006ooooo`;o00003_ooool2o`0000Go
oooo0_l0000aooooo`007?ooool00ol0003oooooooooo`0eooooo`Co00002oooool3o`0000gooooo
0_l0000<ooooo`;o00000_ooool2o`0000Oooooo0_l00009ooooo`?o00000oooool4o`0000Gooooo
0_l00005ooooo`?o00000_ooool4o`000003ooooool0003o000000go00000_ooool7o`0000;ooooo
0_l00007ooooo`;o00001oooool2o`0000Sooooo1?l0000:ooooo`;o00002Oooool4o`0000;ooooo
0_l000000ooooooo0000o`000003ooooo`Co000000Coooooo`000?l0003ooooo0ol00002ooooo`;o
000000?oooooo`000?l000001_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000aooooo`00
7?ooool00ol0003oooooooooo`0eooooo`;o00002Oooool2o`0000Cooooo0_l00006ooooo`;o0000
1?ooool2o`0000cooooo0_l00002ooooo`Co00004?ooool3o`0000?ooooo0_l00006ooooo`?o0000
0_ooool2o`000003ooooool0003o000000?o000000?oooooo`000?l000003ol000000ooooooo0000
o`000002o`0000;ooooo1?l00002ooooo`;o00004_ooool2o`0000;ooooo2?l0000Eooooo`;o0000
1?ooool2o`000004ooooool0003o0000o`0000Cooooo0_l000001?oooooo0000o`000?ooool3o`00
00;ooooo0_l000000ooooooo0000o`00000:ooooo`;o0000=?ooool001cooooo00?o0000oooooooo
ool0<_ooool2o`0000cooooo0_l00004ooooo`;o00001_ooool2o`0001Kooooo1?l000001?oooooo
0000o`000?l0000@ooooo`Go00001Oooool2o`0000?ooooo0_l00002oooooaKo000000?oooooo`00
0?l000002Ol0000>ooooo`;o00001Oooool2o`0000;ooooo1_l00004ooooo`;o00003oooool2o`00
00[ooooo0_l0000:ooooo`;o00001_ooool2o`00043ooooo000Looooo`03o`000?oooooooooo03;o
oooo0_l0000Vooooo`;o00001Oooool2o`0000Sooooo1?l0000;ooooo`?o000000Coooooo`000?l0
003ooooo0_l00007ooooo`;o00001?ooool:o`000003ooooool0003o000000[o000000?oooooo`00
0?l000002Ol00002ooooo`;o00002_ooool2o`0000[ooooo0_l00005ooooo`Co00001_ooool2o`00
00Gooooo1?l00003ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000004oooo
o`;o00004?ooool2o`0003Sooooo000Looooo`03o`000?oooooooooo03?ooooo0_l00004ooooo`;o
00000_ooool2o`0000Cooooo0_l0000?ooooo`;o00001?ooool2o`0000Gooooo0_l00004ooooo`?o
00000oooool3o`0000Cooooo0_l00004ooooo`?o00001?ooool2o`0000Oooooo1?l00002ooooob;o
00000oooool2o`0000cooooo0_l00008ooooo`;o00001Oooool2o`0000Sooooo0_l000000ooooooo
0000o`000002ooooo`;o00001Oooool2o`0000;ooooo0_l000001Ooooooo0000o`000?l0003ooooo
00;o00001?ooool2o`0000?ooooo0_l00005ooooo`;o00001?ooool2o`000003ooooool0003o0000
03Gooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o
0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0cooooo`;o00001?ooool2o`0000;ooooo0_l0
0004ooooo`;o00003Oooool4o`0000[ooooo0_l00005ooooo`?o00001?ooool2o`0000Cooooo0_l0
0004ooooo`;o00000oooool2o`0000Cooooo0_l00003ooooo`Co00000_ooool2o`0000?ooooo5_l0
00000ooooooo0000o`000004o`0000Wooooo0_l00004ooooo`Co00000oooool2o`0001Oooooo0_l0
0007ooooo`Co00001Oooool2o`000003ooooool0003o000000Gooooo0_l00003ooooo`;o00000_oo
ool2o`000003ooooool0003o000000Oooooo0_l0000eooooo`0000KoooooogMgMonHV9SooooooiRH
V?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000oooooooo
ool0<oooool2o`0000[ooooo0_l00009ooooo`;o00001_ooool2o`0000_ooooo0ol000000ooooooo
0000o`00000Booooo`;o00001_ooool4o`0000;ooooo0_l00004ooooo`Oo000000Coooooo`000?l0
003ooooo5Ol000001?oooooo0000o`000?l0000<ooooo`;o00001?ooool3o`0000Cooooo0_l0000P
ooooo`Co00002?ooool2o`0000Gooooo1?l00005ooooo`;o0000@Oooool00003ooooool@413ooooo
00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool0>oooool2o`0000;ooooo0ol00008ooooo`;o00003?ooool2o`0000Gooooo0_l00002
ooooo`;o00004?ooool4o`0000Sooooo0_l00005ooooo`;o000000?oooooo`000?l000002?l00000
0ooooooo0000o`00000Fo`0000?ooooo1?l00007ooooo`;o00000_ooool3o`0000?ooooo0_l0000f
ooooo`?o00001Oooool3o`00043ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000>oooool2o`0000?ooooo0_l0000?
ooooo`Ko000000?oooooo`000?l000006oooool2o`00017ooooo2?l000000ooooooo0000o`000007
o`000003ooooool0003o0000017o00000oooool8o`0000?ooooo0_l00002ooooo`?o00000oooool2
o`0000;ooooo0_l00004ooooo`;o00000oooool2o`0001_ooooo0_l0000:ooooo`;o00001oooool2
o`0000;ooooo0_l0000looooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09oooo
o`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`19ooooo`;o00001_ooool6
o`000003ooooool0003o000000Cooooo0_l0000Aooooo`?o000000?oooooo`000?l000004oooool7
o`000003ooooool0003o000001Wo000000?oooooo`000?l000000_l000000ooooooo0000o`000004
o`0000?ooooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l000000ooooooo0000o`000004
ooooo`;o00000oooool2o`0001Wooooo1?l00002ooooo`;o00003oooool2o`0000;ooooo0_l0000l
ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`03oeEEEOn7QhOooooo
00Sooooo00?o0000ooooooooool0BOooool2o`0000_ooooo0_l00004ooooo`Go00000_ooool2o`00
00;ooooo0_l00008ooooo`?o000000?oooooo`000?l000001Oooool6o`0000?ooooo0_l00002oooo
o`;o000000?oooooo`000?l000009_l000000ooooooo0000o`000004o`0000Cooooo0_l00006oooo
o`;o000000?oooooo`000?l000000oooool2o`0000Sooooo0_l0000Eooooo`;o00001?ooool2o`00
00_ooooo0_l00014ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413o
V9RH00Sooooo00?o0000ooooooooool0?Oooool2o`0001Oooooo0_l00004ooooo`;o000000?ooooo
o`000?l000001?l00002ooooo`;o00001oooool3o`0000Wooooo1_l00003ooooo`;o00000_ooool5
o`000003ooooool0003o000001oo00000_ooool9o`0000Wooooo0_l000000ooooooo0000o`000005
ooooo`?o00001Oooool2o`000003ooooool0003o000001_ooooo0_l0000;ooooo`;o00001oooool2
o`0003_ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@
1_ooool00ol0003oooooooooo`0cooooo`;o00002?ooool2o`0000Cooooo0_l0000Kooooo`Co0000
3?ooool3o`0001Oooooo0_l00005ooooo`co000000Coooooo`000?l0003o00000_oooolBo`000003
ooooool0003o000000;o00001_ooool2o`0000;ooooo0_l000000ooooooo0000o`000005ooooo`;o
00001_ooool2o`0001kooooo0_l00008ooooo`;o00002_ooool2o`0003_ooooo000Looooo`03o`00
0?oooooooooo03?ooooo0_l0000>ooooo`;o00001oooool2o`0000Cooooo0_l00008ooooo`;o0000
6oooool4o`0000[ooooo1Ol00004ooooo`ko000000?oooooo`000?l000004Ol00003ooooo`;o0000
1Oooool2o`0000;ooooo0_l00002ooooo`;o00001_ooool2o`0003;ooooo0_l00017ooooo`007?oo
ool00ol0003oooooooooo`1:ooooo`Co00001?ooool2o`0000Sooooo1?l00003ooooo`Ko000000Co
ooooo`000?l0003o00002?ooool2o`0000;ooooo1?l00002ooooo`;o00001_ooool5o`0000;ooooo
4Ol00002oooooa7o000000?oooooo`000?l000000_l00005ooooo`;o00003_ooool4o`0000kooooo
0_l0000Sooooo`;o0000A?ooool001cooooo00?o0000ooooooooool0B_ooool2o`0001;ooooo0_l0
0003ooooo`Ko000000Coooooo`000?l0003o00001_ooool5o`0000;ooooo0_l000000ooooooo0000
o`000002o`0000?ooooo0_l000000ooooooo0000o`000005oooooa;o000000?oooooo`000?l00000
5?l0000:ooooo`;o000000?oooooo`000?l000000_l00006ooooo`;o00000_ooool2o`0000?ooooo
0_l00005ooooo`;o00006_ooool2o`0000Kooooo0ol00014ooooo`007?ooool00ol0003ooooooooo
o`0fooooo`;o00000_ooool2o`0000Kooooo0_l00007ooooo`Co00005_ooool2o`0000cooooo0_l0
00000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000001Oooool3o`0000;ooooo0_l0
0002oooooaOo000000?oooooo`000?l000004_l000000ooooooo0000o`000005ooooo`;o000000?o
ooooo`000?l000000_l00002ooooo`;o00000_ooool2o`000004ooooool0003o0000o`0000?ooooo
0_l0000Hooooo`?o00001_ooool2o`0000Kooooo0_l00015ooooo`007?ooool00ol0003ooooooooo
o`0fooooo`Ko00001_ooool2o`0000Oooooo1?l0000?ooooo`Wo00001Oooool2o`0000oooooo0_l0
0003ooooo`;o000000?oooooo`000?l000000_oooolLo`0000;ooooo4_l000000ooooooo0000o`00
0008ooooo`;o00001?ooool2o`0000Gooooo0_l00009ooooo`;o00004oooool3o`0000Wooooo0_l0
0003ooooo`;o0000AOooool001cooooo00?o0000ooooooooool0>?ooool2o`0000Sooooo1?l00004
ooooo`;o00004_ooool8o`0000Kooooo0_l0000?ooooo`?o00000_ooool2o`0000Kooooo;_l00003
ooooo`;o00001oooool2o`0000;ooooo0_l0000@ooooo`Co00006oooool2o`0000;ooooo0_l0001:
ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00001oooool2o`000003ooooool0003o0000
00;ooooo1_l0000Booooo`;o00002_ooool2o`0000;ooooo0_l0000;ooooo`?o00001Oooool2o`00
00?ooooo:_l00007ooooo`;o00001oooool2o`0000;ooooo0_l0000@ooooo`;o00007?ooool3o`00
00?ooooo0_l00019ooooo`007?ooool00ol0003oooooooooo`0oooooo`Co00001Oooool6o`0001;o
oooo0_l0000:ooooo`;o00000_ooool5o`00013ooooo0_l00003oooooaSo000000?oooooo`000?l0
00002?l000000ooooooo0000o`000004o`0000gooooo0_l000000ooooooo0000o`000006ooooo`;o
0000:_ooool2o`0000Cooooo0ol00018ooooo`007?ooool00ol0003oooooooooo`0oooooo`Co0000
2?ooool2o`0001gooooo0_l000000ooooooo0000o`000003ooooo`?o00000_ooool3o`0000gooooo
0_l00005ooooobKo00001oooool2o`0000Cooooo0ol00008ooooo`;o0000<Oooool2o`0004Sooooo
000Looooo`03o`000?oooooooooo03Wooooo0_l00006ooooo`;o00001Oooool2o`0001oooooo0ol0
00000ooooooo0000o`000002o`0000Kooooo0ol000000ooooooo0000o`00000:ooooo`;o00000ooo
oolXo`0000Oooooo0_l00005ooooo`Go0000:_ooool2o`0000;ooooo0_l00003ooooo`;o00000ooo
ool2o`0000?ooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00001Oooool3
o`0000;ooooo0_l000000ooooooo0000o`00000Oooooo`;o00000_ooool4o`0000[ooooo1?l00009
ooooobKo000000?oooooo`000?l000000ol00003ooooo`Co00002?ooool4o`00017ooooo1?l0000E
ooooo`;o00000_ooool2o`0000?ooooo0_l00008ooooo`;o0000@oooool001cooooo0_l00011oooo
o`;o00000oooool2o`0000Gooooo0_l0000Aooooo`;o00003?ooool2o`0000kooooo0_l000000ooo
oooo0000o`000006ooooobKo000000?oooooo`000?l000000ol000000ooooooo0000o`000004o`00
01gooooo1?l0000Uooooo`;o000000?oooooo`000?l00000@oooool001cooooo00?o0000oooooooo
ool0@Oooool2o`0000Wooooo1?l0000?ooooo`;o00002?ooool4o`0001?ooooo0_l00006ooooo`?o
000000?oooooo`000?l000003_l000001?oooooo0000o`000?ooool6o`000003ooooool0003o0000
00Go000000?oooooo`000?l000001?ooool2o`0001;ooooo0_l0000<ooooo`;o00006?ooool2o`00
00Cooooo0_l00003ooooo`;o00000oooool3o`0004Gooooo000Looooo`03o`000?oooooooooo047o
oooo0_l00005ooooo`;o00000_ooool4o`00017ooooo0_l00006ooooo`Co00001oooool2o`0000So
oooo1?l00005ooooo`?o00000_oooolQo`0000Cooooo0ol0000Eooooo`;o00002_ooool4o`0000?o
oooo0_l0000Cooooo`;o00001?ooool2o`0000?ooooo0ol00003ooooo`;o0000AOooool001cooooo
00?o0000ooooooooool0??ooool2o`0000Cooooo0_l00004ooooo`?o000000Coooooo`000?l0003o
oooo0_l0000@ooooo`;o00003Oooool2o`0000;ooooo0_l00008ooooo`Co00000oooool8o`000003
ooooool0003o000000So000000?oooooo`000?l000005?l00002ooooo`Go00007oooool2o`0000;o
oooo0_l000000ooooooo0000o`00000Iooooo`;o00001?ooool3o`0004Wooooo000Looooo`03o`00
0?oooooooooo03cooooo0_l00004ooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`;o
00007Oooool4o`0000?ooooo0_l00008ooooo`?o00000oooool2o`0000;ooooo1?l00002ooooob?o
00000_ooool2o`0002?ooooo0_l0000Looooo`;o00001Oooool2o`0004Wooooo000Looooo`03o`00
0?oooooooooo03[ooooo0_l0000Pooooo`;o000000?oooooo`000?l000003Oooool3o`0000;ooooo
1?l00007ooooo`?o00001?ooool2o`0000Cooooo0_l00002oooooako00000_ooool3o`0001Sooooo
0_l00002ooooo`;o00001oooool2o`00023ooooo0_l000000ooooooo0000o`00001;ooooo`007?oo
ool00ol0003oooooooooo`0jooooo`;o000000?oooooo`000?l000001?l0000?ooooo`;o00002?oo
ool2o`000003ooooool0003o000000Oooooo0_l00005ooooo`;o00000_ooool2o`0000Oooooo1?l0
0007ooooo`?o000000?oooooo`000?l000002ol000000ooooooo0000o`00000Bo`0000?ooooo0_l0
0003ooooo`Go00003oooool3o`0000;ooooo0_l00007ooooo`;o000000?oooooo`000?l000007Ooo
ool2o`000003ooooool0003o000000?ooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`0m
ooooo`Wo00003?ooool4o`0000;ooooo0_l0000>ooooo`;o00000oooool4o`0000_ooooo0_l00009
ooooo`?o000000?oooooo`000?l000008Ol00007ooooo`Go00003oooool2o`0000Wooooo0_l00000
1?oooooo0000o`000?ooool2o`0001Cooooo0_l00002ooooo`Co000000?oooooo`000?l000001_oo
ool2o`0004Kooooo000Looooo`03o`000?oooooooooo04?ooooo0ol00005ooooo`;o000000?ooooo
o`000?l000001?ooool2o`0000;ooooo0_l0000>ooooo`;o00000oooool4o`0000?ooooo1?l0000F
ooooob3o000000?oooooo`000?l000004?ooool3o`00013ooooo0_l00002ooooo`Co00005?ooool2
o`0000;ooooo1?l000001?oooooo0000o`000?l0001=ooooo`007?ooool00ol0003oooooooooo`0o
ooooo`;o00002_ooool2o`000003ooooool0003o000000Cooooo0_l00007ooooo`;o00000_ooool2
o`0000?ooooo1?l000000ooooooo0000o`000002ooooo`;o00000oooool4o`0000Sooooo0_l00009
ooooo`;o00000oooool:o`000003ooooool0003o000000[o00000_ooool3o`0000;ooooo0ol0000@
ooooo`?o00005?ooool4o`0000Wooooo0_l00005ooooo`;o00002oooool3o`0004gooooo000Loooo
o`03o`000?oooooooooo03oooooo0_l000000ooooooo0000o`000004ooooo`;o00001?ooool2o`00
00?ooooo0ol00007ooooo`;o00000_ooool4o`000004ooooool0003o0000o`0000;ooooo0_l00002
ooooo`;o00002Oooool4o`0000;ooooo0_l00008ooooo`?o00001Oooool8o`000003ooooool0003o
000000co000000?oooooo`000?l000000_ooool2o`0001Sooooo0_l0000@ooooo`;o00002Oooool2
o`000004ooooool0003o0000ooooo`?o00000oooool2o`0005Kooooo000Looooo`03o`000?oooooo
oooo03kooooo0_l00002ooooo`;o00001?ooool2o`0000Cooooo0_l00003ooooo`?o00003Oooool2
o`0001Gooooo1?l00002ooooo`;o00002?ooool7o`000003ooooool0003o000001Oo000000Cooooo
o`000?l0003ooooo0ol0000@ooooo`;o000000Coooooo`000?l0003ooooo0_l0000@ooooo`;o0000
3?ooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`00001Cooooo`007?oo
ool00ol0003oooooooooo`0nooooo`;o00002?ooool2o`0000[ooooo0_l0000?ooooo`Ko00002Ooo
ool2o`0000Gooooo0_l00007ooooo`;o00001_ooool5o`000003ooooool0003o000000;o000000?o
ooooo`000?l000004_l000001?oooooo0000o`000?ooool3o`00013ooooo0_l000000ooooooo0000
o`00000Kooooo`;o00003_ooool4o`0000;ooooo0_l0001?ooooo`007?ooool00ol0003ooooooooo
o`18ooooo`;o000000Coooooo`000?l0003o00001Oooool2o`0000gooooo0_l000000ooooooo0000
o`000004o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00002oooool2o`000003oooo
ool0003o000000?ooooo0_l00004ooooo`;o00001?oooolCo`000003ooooool0003o000000kooooo
0_l0000?ooooo`;o00000_ooool2o`00013ooooo1?l00003ooooo`;o00000_ooool2o`0000Gooooo
0_l00004ooooo`;o00004oooool2o`0003[ooooo000Looooo`03o`000?oooooooooo04Sooooo0_l0
00001?oooooo0000o`000?l00005ooooo`;o00001Oooool2o`000003ooooool0003o000000?ooooo
0_l00009ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Wooooo0_l000000ooooooo0000
o`000003ooooo`;o00002_ooool9o`000003ooooool0003o000000Co000000?oooooo`000?l00000
0ol0000>ooooo`Co00003Oooool2o`0000;ooooo0_l00008ooooo`;o00001_ooool2o`0000Gooooo
0_l00002ooooo`;o00008?ooool2o`0003[ooooo000Looooo`03o`000?oooooooooo04Sooooo0_l0
000@ooooo`;o000000?oooooo`000?l000005?ooool2o`000003ooooool0003o000000;ooooo0_l0
0003ooooo`;o00000oooool2o`0000Cooooo1?l00002ooooo`;o00000oooool4o`000003ooooool0
003o000000;o000000?oooooo`000?l000002?l0000=ooooo`;o00000oooool2o`0000gooooo0_l0
000<ooooo`;o00001_ooool2o`0000Cooooo0_l00003ooooo`Co000000?oooooo`000?l000000ol0
0005ooooo`;o0000COooool001cooooo0_l00019ooooo`;o00008?ooool2o`0000Oooooo0_l00000
0ooooooo0000o`000002ooooo`;o00000oooool2o`0000Wooooo1?l00002ooooo`?o00000_ooool9
o`000003ooooool0003o000000;o000000Goooooo`000?l0003o0000ooooo`02o`0000;ooooo1?l0
0006ooooo`;o00002_ooool4o`0000gooooo1?l0000?ooooo`;o00000_ooool2o`000004ooooool0
003o0000ooooo`Go00001Oooool2o`0004gooooo000Looooo`03o`000?oooooooooo06Sooooo1?l0
0007ooooo`;o00002_ooool2o`0000;ooooo0_l00008ooooo`;o00000_ooool2o`0000;ooooo1Ol0
00001?oooooo0000o`000?ooool8o`0000;ooooo2?l0000Booooo`Co00001_ooool2o`0000Cooooo
1Ol00008ooooo`?o00002?ooool3o`0000;ooooo0_l0001Hooooo`007?ooool00ol0003ooooooooo
o`18ooooo`Co00007?ooool4o`0001?ooooo0_l00002ooooo`;o00001?ooool6o`0000Kooooo1?l0
00000ooooooo0000o`000002ooooo`Ko00001_ooool6o`0001_ooooo0ol00004ooooo`;o00002_oo
ool4o`0000Sooooo0ol00002ooooo`;o00001Oooool2o`00057ooooo000Looooo`03o`000?oooooo
oooo04Oooooo1Ol0000>ooooo`?o00002_ooool2o`000003ooooool0003o000000;ooooo0_l0000:
ooooo`;o00001_ooool4o`0000?ooooo1?l0000<ooooo`?o00000oooool4o`0000;ooooo0_l00005
ooooo`Co00006_ooool3o`0000;ooooo0_l0000=ooooo`;o00002Oooool4o`0000Wooooo0_l0001A
ooooo`007?ooool00ol0003oooooooooo`17ooooo`Co00001_ooool2o`0000Oooooo0ol000000ooo
oooo0000o`000007ooooo`;o00001Oooool2o`0000[ooooo0_l00006ooooo`Ko00003Oooool2o`00
00;ooooo0_l00004ooooo`Co00000_ooool4o`00027ooooo0_l00003ooooo`;o000000?oooooo`00
0?l000005Oooool4o`0000Gooooo0_l0001Eooooo`007?ooool00ol0003oooooooooo`17ooooo`?o
00001oooool2o`0000_ooooo0ol0000Eooooo`;o00001Oooool2o`0000Oooooo0_l0000=ooooo`;o
000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l00004ooooo`;o00002?ooool4o`0001Oo
oooo0ol00003ooooo`Co00001?ooool4o`00017ooooo0_l000000ooooooo0000o`00001Eooooo`00
7?ooool00ol0003oooooooooo`18ooooo`;o00005?ooool3o`0001Gooooo0_l00005ooooo`;o0000
0oooool2o`0000?ooooo0_l0000?ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo
0ol00005ooooo`Co00000_ooool4o`0000[ooooo0_l0000;ooooo`?o00001Oooool2o`0000Cooooo
1?l0000Aooooo`;o0000F?ooool001cooooo00?o0000ooooooooool0E_ooool2o`0000Gooooo0ol0
0002ooooo`;o00007_ooool2o`0000?ooooo0_l0000:ooooo`;o00001_ooool3o`000003ooooool0
003o000000;ooooo1?l00002ooooo`Ko00004?ooool2o`0001oooooo0_l0000;ooooo`;o0000F_oo
ool001cooooo00?o0000ooooooooool0@?ooool2o`0000?ooooo0_l0000?ooooo`;o00000oooool5
o`0000;ooooo0_l0000Booooo`;o00001Oooool2o`0000Wooooo0_l00009ooooo`;o00001_ooool3
o`0000Gooooo1?l00002ooooo`;o00003Oooool3o`0002Gooooo0_l0000;ooooo`;o0000F_ooool0
01cooooo00?o0000ooooooooool0@?ooool2o`0000?ooooo0_l0000Dooooo`;o000000?oooooo`00
0?l000004?ooool2o`0000Cooooo0ol00003ooooo`?o00001Oooool2o`0000;ooooo0_l0000@oooo
o`Go00001?ooool2o`0001?ooooo0ol0000Cooooo`;o00007_ooool2o`0005Wooooo000Looooo`03
o`000?oooooooooo05Kooooo0_l00009ooooo`;o00002Oooool2o`0000;ooooo0_l00005ooooo`;o
00000oooool2o`0000Cooooo1?l00009ooooo`;o00002Oooool5o`0000oooooo0_l0000Nooooo`;o
00003_ooool2o`0000Gooooo0_l00007ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0
E_ooool2o`0000Wooooo0_l00004ooooo`;o00000oooool2o`0001Cooooo0_l00002ooooo`Co0000
1Oooool2o`0000Cooooo1?l00004ooooo`;o00002oooool2o`0000;ooooo0_l00009ooooo`;o0000
0_ooool4o`0000Kooooo0_l0000Eooooo`;o00001Oooool2o`0000Kooooo0_l0001Jooooo`007?oo
ool00ol0003oooooooooo`17ooooo`;o00007_ooool4o`0001Cooooo0_l000000ooooooo0000o`00
0002ooooo`Co00000_ooool2o`0000?ooooo0_l00002ooooo`Co00000oooool2o`0000cooooo0_l0
000=ooooo`;o000000?oooooo`000?l000001Ol00004ooooo`;o000000?oooooo`000?l000005_oo
ool2o`0000Wooooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`17ooooo`;o00001oooool2
o`0000[ooooo0_l0000;ooooo`;o00005?ooool2o`000003ooooool0003o000000?ooooo1?l00000
0ooooooo0000o`000003ooooo`Ko00001Oooool4o`0000Oooooo0_l000000ooooooo0000o`00000;
ooooo`;o00000oooool2o`0000?ooooo0_l00007ooooo`;o00003oooool2o`0000Cooooo0ol0001U
ooooo`007?ooool00ol0003oooooooooo`1@ooooo`Co00002?ooool3o`0000;ooooo0_l0000Noooo
o`;o00001?ooool4o`0000Cooooo0_l00002ooooo`;o00002Oooool2o`0000;ooooo0_l00003oooo
o`;o00001oooool3o`0000Cooooo0_l00005ooooo`;o00002_ooool2o`0000cooooo0_l000000ooo
oooo0000o`000004ooooo`;o00000_ooool6o`0005kooooo000Looooo`03o`000?oooooooooo05;o
oooo0_l00009ooooo`;o00000_ooool2o`0001Cooooo0_l00008ooooo`;o00003?ooool2o`0000Co
oooo0_l00002ooooo`;o00001oooool2o`0000cooooo0ol00003ooooo`;o00000oooool2o`000003
ooooool0003o000000Oooooo1Ol0000<ooooo`;o00002oooool6o`0005kooooo000Looooo`;o0000
G_ooool2o`0001Sooooo0ol0000<ooooo`;o00003Oooool2o`0000;ooooo0_l0000Cooooo`;o0000
1_ooool2o`0000?ooooo0ol00009ooooo`?o00005Oooool2o`0000Gooooo0_l0001Qooooo`007?oo
ool00ol0003oooooooooo`1Looooo`Co00006?ooool4o`0000Cooooo0_l00004ooooo`;o00000_oo
ool2o`0002;ooooo0_l000000ooooooo0000o`000005ooooo`;o000000Coooooo`000?l0003o0000
2Oooool2o`0000Gooooo0_l0000?ooooo`;o0000J?ooool001cooooo00?o0000ooooooooool0FOoo
ool7o`0001[ooooo0_l00004ooooo`Co00001_ooool2o`0000oooooo0_l0000;ooooo`;o00001ooo
ool2o`0000Gooooo0_l000000ooooooo0000o`00000:ooooo`;o00000_ooool2o`000003ooooool0
003o000000;ooooo0_l00002ooooo`;o0000LOooool001cooooo00?o0000ooooooooool0FOooool5
o`0002Cooooo0_l0000Gooooo`;o00002oooool2o`00027ooooo0_l00005ooooo`;o00000_ooool2
o`000003ooooool0003o000006kooooo000Looooo`03o`000?oooooooooo05cooooo1?l00002oooo
o`;o00002?ooool2o`0000Oooooo0_l00009ooooo`?o00003Oooool2o`0002?ooooo0_l00002oooo
o`;o00001?ooool2o`0000[ooooo0_l00009ooooo`;o000000?oooooo`000?l00000K_ooool001co
oooo00?o0000ooooooooool0Foooool2o`000004ooooool0003o0000ooooo`?o00002?ooool3o`00
00Kooooo0_l00009ooooo`?o00003?ooool5o`00027ooooo0_l00002ooooo`;o000000Coooooo`00
0?l0003ooooo0_l00007ooooo`;o000000?oooooo`000?l000002Oooool2o`00077ooooo000Loooo
o`03o`000?oooooooooo05_ooooo0_l00004ooooo`Co00002?ooool2o`0000_ooooo0_l00004oooo
o`;o00003Oooool2o`000003ooooool0003o000000oooooo0_l0000<ooooo`Go00001_ooool4o`00
00Sooooo1Ol0000>ooooo`;o0000K?ooool001cooooo00?o0000ooooooooool0Foooool2o`0000Ko
oooo0_l0000Eooooo`?o00000oooool2o`000003ooooool0003o000000Cooooo0_l0000;ooooo`Co
00001oooool5o`0000_ooooo1Ol00007ooooo`?o00002Oooool2o`0000Wooooo0_l00002ooooo`;o
000000?oooooo`000?l00000K?ooool001cooooo00?o0000ooooooooool0Loooool2o`0000Kooooo
0_l000000ooooooo0000o`000002o`000003ooooool0003o000000Cooooo1?l00005ooooo`;o0000
0_ooool4o`0000Oooooo0_l000000ooooooo0000o`000004ooooo`;o00004Oooool2o`0000[ooooo
0_l00009ooooo`?o000000?oooooo`000?l00000Koooool001cooooo00?o0000ooooooooool0Looo
ool2o`0000Wooooo0_l0000;ooooo`;o00001Oooool2o`0000Gooooo0_l0000?ooooo`;o00002_oo
ool2o`00017ooooo0_l000000ooooooo0000o`000007ooooo`;o0000L_ooool001cooooo00?o0000
ooooooooool0KOooool2o`0000Wooooo0_l00006ooooo`;o000000?oooooo`000?l000004_ooool4
o`0001Gooooo0_l00004ooooo`?o00000_ooool2o`0000;ooooo0_l0000;ooooo`;o00003?ooool4
o`0006_ooooo000Looooo`03o`000?oooooooooo06_ooooo1?l00009ooooo`?o00001Oooool2o`00
0003ooooool0003o000000gooooo0_l00003ooooo`;o00002_ooool2o`0000_ooooo0_l000000ooo
oooo0000o`000002ooooo`;o00000_ooool2o`0000;ooooo0_l0000:ooooo`;o00001?ooool2o`00
00Oooooo1?l0001[ooooo`007?ooool00ol0003oooooooooo`1[ooooo`;o00003?ooool2o`0000?o
oooo0_l00008ooooo`Co00000_ooool2o`0000;ooooo0ol00007ooooo`;o00001Oooool2o`0000?o
oooo0_l00009ooooo`;o00003?ooool2o`0000Sooooo0_l00004ooooo`;o0000M_ooool001cooooo
00?o0000ooooooooool0L?ooool2o`0000cooooo0_l000000ooooooo0000o`000002ooooo`;o0000
00?oooooo`000?l000000_l00002ooooo`;o00000oooool4o`0000?ooooo1?l00007ooooo`;o0000
00?oooooo`000?l000001Oooool2o`00013ooooo0_l0000;ooooo`;o0000NOooool00006ooooooo^
k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006oooo
o`03o`000?oooooooooo073ooooo0_l00007ooooo`;o00001_ooool2o`0000;ooooo0_l00002oooo
o`?o00002Oooool2o`0000?ooooo0ol00006ooooo`Co00001_ooool4o`0000?ooooo1?l0000Foooo
o`;o00000_ooool5o`0001cooooo0_l0001Dooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5
ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0L?oo
ool2o`0000Kooooo0ol00004ooooo`;o00002?ooool5o`0000;ooooo0_l00009ooooo`;o00001_oo
ool2o`0000Sooooo0_l00003ooooo`Ko00001?ooool4o`0000[ooooo0_l00006ooooo`Go00007?oo
ool2o`0005Cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo07Sooooo0_l00004ooooo`?o00002ooo
ool2o`0000;ooooo0_l00004ooooo`;o00002oooool2o`0000cooooo0ol00008ooooo`Co00002_oo
ool2o`000003ooooool0003o000007[ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000M_ooool3o`0000Gooooo1?l0
000Dooooo`;o00000oooool2o`0000Gooooo0ol00005ooooo`;o00001Oooool2o`0000;ooooo0_l0
000Fooooo`;o0000N_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool0
1Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0Loooool2o`000004ooooool0
003o0000o`0000Oooooo1?l000001?oooooo0000o`000?l0000Cooooo`?o00001?ooool2o`0000Ko
oooo0_l00009ooooo`;o00000oooool5o`0000Wooooo0_l0001oooooo`0000?ooooooa0@4?ooool0
0_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003o
ooooooooo`1cooooo`;o00003?ooool7o`000004ooooool0003o0000o`0000Cooooo0_l0000:oooo
o`?o00005_ooool4o`000003ooooool0003o000000?o00001Oooool2o`0000;ooooo0_l0001ooooo
o`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l000001_oo
ool00ol0003oooooooooo`1eooooo`;o00003?ooool2o`0000Cooooo0ol000001?oooooo0000o`00
0?ooool2o`0000Wooooo1?l00009ooooo`?o00001_ooool8o`0000;ooooo1?l00005ooooo`Co0000
1_ooool2o`0007Wooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@06ooooo`03o`000?oooooooooo07Gooooo0_l0000Aooooo`;o00000oooool2o`00
00cooooo1?l00006ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000?ooooo1?l00000
0ooooooo0000o`00000:ooooo`;o00000_ooool2o`0000Kooooo0_l0001iooooo`007?ooool00ol0
003oooooooooo`1gooooo`;o00003oooool3o`0000;ooooo1?l00009ooooo`;o00001_ooool2o`00
0003ooooool0003o000000Gooooo0_l00008ooooo`;o00002_ooool2o`0000Oooooo0_l0001loooo
o`007?ooool00ol0003oooooooooo`1gooooo`;o00001Oooool2o`0000Cooooo0_l00002ooooo`?o
00001?ooool2o`000003ooooool0003o000000Kooooo0_l00006ooooo`;o00006_ooool2o`0000_o
oooo0_l0001looooo`007?ooool00ol0003oooooooooo`1nooooo`;o00001?ooool2o`0000;ooooo
0_l00003ooooo`;o00000oooool2o`0000Kooooo0_l00003ooooo`;o00003_ooool3o`0000cooooo
0_l000000ooooooo0000o`000026ooooo`007?ooool00ol0003oooooooooo`2;ooooo`Co000000?o
ooooo`000?l000001?l00004ooooo`;o00000oooool2o`0000?ooooo0_l00005ooooo`;o00000_oo
ool3o`0000oooooo0_l00026ooooo`007?ooool00ol0003oooooooooo`1Yooooo`;o00005?ooool2
o`0000[ooooo0_l000000ooooooo0000o`000002o`000004ooooool0003o0000o`0000Cooooo0_l0
0008ooooo`;o00001Oooool2o`0000;ooooo0_l0002Hooooo`007?ooool00ol0003oooooooooo`1Y
ooooo`;o00005?ooool3o`0000cooooo1?l00002ooooo`Co00006Oooool2o`000004ooooool0003o
0000o`0009;ooooo000Looooo`03o`000?oooooooooo083ooooo0_l0000Booooo`Ko00005Oooool4
o`000004ooooool0003o0000o`0009;ooooo000Looooo`03o`000?oooooooooo07gooooo0_l00000
0ooooooo0000o`000003ooooo`;o00003_ooool2o`000003ooooool0003o000000Cooooo0_l0000?
ooooo`;o0000V?ooool001cooooo00?o0000ooooooooool0OOooool2o`000003ooooool0003o0000
00?ooooo0_l0000@ooooo`;o00001Oooool2o`000:Wooooo000Looooo`03o`000?oooooooooo08Go
oooo0_l0000@ooooo`;o00004Oooool2o`0009gooooo000Looooo`03o`000?oooooooooo087ooooo
0_l00002ooooo`;o00003_ooool2o`0001?ooooo0_l0000Qooooo`;o0000N_ooool001cooooo0_l0
0022ooooo`Co00004?ooool2o`0001Wooooo0_l0000Kooooo`;o0000N_ooool001cooooo00?o0000
ooooooooool0Poooool2o`0002_ooooo0_l0000>ooooo`;o00001Oooool2o`00083ooooo000Loooo
o`03o`000?oooooooooo08Sooooo0_l0000fooooo`;o00001Oooool2o`00083ooooo000Looooo`03
o`000?oooooooooo07Wooooo0_l00009ooooo`;o00000_ooool2o`00017ooooo0_l0002/ooooo`00
7?ooool00ol0003oooooooooo`1iooooo`Co00001oooool2o`0000;ooooo0_l0000Aooooo`;o0000
[?ooool001cooooo00?o0000ooooooooool0Noooool2o`0000_ooooo0_l0002oooooo`007?ooool0
0ol0003oooooooooo`2Rooooo`;o0000YOooool001cooooo00?o0000ooooooooool0X_ooool2o`00
01Wooooo0_l0002:ooooo`007?ooool00ol0003oooooooooo`2mooooo`;o0000R_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0Zoooool2o`0009cooooo000Looooo`;o0000[?ooool2
o`0009cooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Booooo`Co000000?o410@ooooooooool00oooool0
0ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`?o0000oooooom:ooooo`00
5?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_oo
ool001Cooooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooo
oe;ooooo000Booooo`03oeEEEOmVIVKo00000?ooooooE?ooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00:7ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0F
ooooo`Co000000?o410@ooooooooool00_ooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8b
o`000?l@413oc<c<00Gooooo0_l000000ol@413oooooooooo`2:ooooo`00X_ooool01Ol0003ooooo
oooooooooooo000000Wooooo1_l0000<ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00_ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0Roooool00:;o
oooo00Go0000ooooooooooooooooo`00000Kooooo`03o`000?oooooooooo00;ooooo1Ol00003oooo
o`05o`000?ooooooooooooooool000000oooool5o`0008cooooo002Rooooo`05o`000?oooooooooo
ooooool000002Oooool6o`0000cooooo00?o0000ooooooooool00_ooool01?m4A4CogMgMooooool0
0004ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01?m4A4CogMgMooooool0002=ooooo`00
X_ooool01Ol0003oQhN7oooooonYZJWo000001_ooooo00?o0000ooooooooool00_ooool01?oMgMgo
EEEEooooool00004ooooo`05o`000?mEEEGo0000oa0@4?o<c<`00oooool01?oMgMgoEEEEooooool0
002=ooooo`00XOooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo01Wooooo00?o0000
ooooooooool00oooool00omgMgOoc<c<o`000004ooooo`03oeEEEOn7QhOooooo00Kooooo00?oMgMg
olc<c?l00000SOooool00<;ooooo00?o0000ooooooooool00oooool00oo^k^koA4A4o`000004oooo
o`03omgMgOl@413oV9RH00Kooooo00?ok^k^odA4A?l00000SOooool00<3ooooo00?oEEEEofIVI_l0
00001_ooool00omgMgOo0000ooooo`04ooooo`04olc<c?m4A4Co0000oa0@40Gooooo00?oMgMgo`00
0?ooool0S?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1470) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.65544 .55752 Mdot
.64783 .56203 Mdot
.4434 .37862 Mdot
.46899 .65519 Mdot
.23353 .65724 Mdot
.40491 .36687 Mdot
.5688 .3557 Mdot
.57189 .36881 Mdot
.45041 .38023 Mdot
.75035 .50947 Mdot
.59125 .40469 Mdot
.41202 .60015 Mdot
.5938 .37145 Mdot
.45086 .61855 Mdot
.57926 .8631 Mdot
.42803 .67956 Mdot
.65169 .55671 Mdot
.242 .50383 Mdot
.42669 .66494 Mdot
.41609 .40156 Mdot
.69603 .49663 Mdot
.45404 .62183 Mdot
.66047 .54088 Mdot
.45079 .61795 Mdot
.48587 .63732 Mdot
.6689 .53451 Mdot
.60745 .56851 Mdot
.51196 .61659 Mdot
.48294 .58995 Mdot
.58702 .40532 Mdot
.28275 .53734 Mdot
.41857 .82003 Mdot
.53494 .66288 Mdot
.38777 .73189 Mdot
.60996 .34709 Mdot
.63135 .72261 Mdot
.41913 .35754 Mdot
.57711 .37838 Mdot
.58138 .3876 Mdot
.57838 .3542 Mdot
.57664 .36559 Mdot
.64869 .52891 Mdot
.72954 .35909 Mdot
.60043 .29577 Mdot
.48239 .5685 Mdot
.18978 .4995 Mdot
.54557 .75055 Mdot
.44075 .64853 Mdot
.65452 .5035 Mdot
.32155 .32299 Mdot
.54965 .265 Mdot
.61393 .33764 Mdot
.43515 .40308 Mdot
.49272 .10234 Mdot
.60253 .38119 Mdot
.52706 .57708 Mdot
.42958 .36807 Mdot
.46751 .61458 Mdot
.45161 .61294 Mdot
.69908 .61631 Mdot
.53073 .62895 Mdot
.3212 .49679 Mdot
.68043 .56543 Mdot
.45386 .4745 Mdot
.42922 .38043 Mdot
.58866 .39906 Mdot
.61875 .55513 Mdot
.60531 .37345 Mdot
.55077 .64875 Mdot
.42121 .32281 Mdot
.44701 .66422 Mdot
.5876 .40209 Mdot
.69854 .50596 Mdot
.49721 .604 Mdot
.30265 .32189 Mdot
.18418 .47441 Mdot
.29284 .50631 Mdot
.64667 .6966 Mdot
.70522 .61076 Mdot
.29713 .3861 Mdot
.50658 .58245 Mdot
.27533 .58631 Mdot
.19365 .46387 Mdot
.6393 .50328 Mdot
.45043 .69103 Mdot
.28536 .52208 Mdot
.5004 .60802 Mdot
.19745 .63321 Mdot
.51679 .66035 Mdot
.49065 .49882 Mdot
.44949 .3538 Mdot
.68175 .51333 Mdot
.47501 .65182 Mdot
.47543 .59287 Mdot
.73956 .61222 Mdot
.44262 .66617 Mdot
.46201 .6345 Mdot
.63319 .51213 Mdot
.61749 .34537 Mdot
.53884 .61723 Mdot
.36805 .39321 Mdot
.39321 .36568 Mdot
.51658 .64221 Mdot
.42559 .32778 Mdot
.69607 .50558 Mdot
.47627 .59346 Mdot
.58567 .38641 Mdot
.50031 .65361 Mdot
.59233 .22273 Mdot
.64459 .55328 Mdot
.50404 .59525 Mdot
.28861 .46268 Mdot
.6095 .64727 Mdot
.68038 .50475 Mdot
.62837 .31947 Mdot
.42255 .65357 Mdot
.47305 .62758 Mdot
.61705 .55056 Mdot
.39011 .36681 Mdot
.18772 .58147 Mdot
.61963 .52753 Mdot
.62225 .39964 Mdot
.67175 .48673 Mdot
.42004 .58306 Mdot
.42723 .38669 Mdot
.61779 .30639 Mdot
.66581 .31306 Mdot
.31067 .55825 Mdot
.49737 .61037 Mdot
.75083 .37743 Mdot
.40229 .39385 Mdot
.66249 .51342 Mdot
.60275 .37054 Mdot
.51327 .67458 Mdot
.63219 .54445 Mdot
.61299 .40206 Mdot
.33211 .46884 Mdot
.53304 .22955 Mdot
.68166 .54573 Mdot
.55534 .43807 Mdot
.62195 .35479 Mdot
.59474 .33257 Mdot
.6619 .78729 Mdot
.62945 .52455 Mdot
.30188 .46927 Mdot
.60446 .36123 Mdot
.37703 .55315 Mdot
.49505 .57001 Mdot
.25542 .56965 Mdot
.67129 .24432 Mdot
.37636 .69328 Mdot
.48324 .26036 Mdot
.30609 .46054 Mdot
.61692 .32805 Mdot
.46666 .64434 Mdot
.68065 .53301 Mdot
.66313 .53742 Mdot
.53017 .62985 Mdot
.49891 .6386 Mdot
.46189 .68024 Mdot
.43099 .63575 Mdot
.52597 .52145 Mdot
.50341 .67448 Mdot
.56327 .73812 Mdot
.68523 .51704 Mdot
.46438 .653 Mdot
.43818 .40077 Mdot
.43043 .59351 Mdot
.57514 .38788 Mdot
.46195 .61945 Mdot
.47125 .65299 Mdot
.52538 .59522 Mdot
.60791 .33273 Mdot
.38474 .79523 Mdot
.58084 .63442 Mdot
.35791 .74782 Mdot
.57892 .50545 Mdot
.46265 .35511 Mdot
.50152 .61663 Mdot
.3072 .48682 Mdot
.6818 .71341 Mdot
.4701 .6655 Mdot
.19806 .29477 Mdot
.45632 .63192 Mdot
.28634 .72198 Mdot
.44803 .71202 Mdot
.3718 .74045 Mdot
.2884 .57885 Mdot
.48412 .63351 Mdot
.76655 .45553 Mdot
.57594 .41683 Mdot
.38404 .32221 Mdot
.58405 .35737 Mdot
.43033 .39979 Mdot
.43843 .37661 Mdot
.39295 .47116 Mdot
.40085 .62826 Mdot
.41635 .61717 Mdot
.48595 .67618 Mdot
.39479 .34189 Mdot
.62178 .57421 Mdot
.29211 .45873 Mdot
.69218 .55992 Mdot
.34917 .80053 Mdot
.35762 .29136 Mdot
.57478 .4018 Mdot
.33092 .45948 Mdot
.42796 .33647 Mdot
.4531 .3602 Mdot
.30577 .45732 Mdot
.45883 .59709 Mdot
.62825 .52749 Mdot
.53661 .81571 Mdot
.5095 .20125 Mdot
.85938 .58276 Mdot
.6419 .50579 Mdot
.75272 .40654 Mdot
.57166 .38465 Mdot
.43016 .35325 Mdot
.47001 .62982 Mdot
.47636 .60119 Mdot
.70416 .51045 Mdot
.44576 .66292 Mdot
.64388 .48163 Mdot
.47827 .63138 Mdot
.55943 .394 Mdot
.30758 .51363 Mdot
.39241 .47177 Mdot
.34535 .57571 Mdot
.68614 .50048 Mdot
.75533 .66259 Mdot
.45552 .35806 Mdot
.69322 .70227 Mdot
.59706 .40184 Mdot
.33683 .48144 Mdot
.45811 .38465 Mdot
.28275 .46949 Mdot
.46831 .6896 Mdot
.41131 .39199 Mdot
.28584 .48037 Mdot
.40609 .52039 Mdot
.4628 .57551 Mdot
.49146 .17758 Mdot
.58663 .34605 Mdot
.67281 .56192 Mdot
.49805 .6584 Mdot
.44977 .34097 Mdot
.55714 .60846 Mdot
.4171 .27297 Mdot
.62206 .27229 Mdot
.40509 .39874 Mdot
.37606 .50624 Mdot
.33785 .48819 Mdot
.52309 .2826 Mdot
.74811 .38147 Mdot
.65631 .56307 Mdot
.46287 .68613 Mdot
.43082 .81744 Mdot
.60459 .36215 Mdot
.48898 .65984 Mdot
.22228 .5751 Mdot
.61362 .3579 Mdot
.46976 .61454 Mdot
.62169 .39122 Mdot
.66226 .53747 Mdot
.72153 .59254 Mdot
.61675 .54435 Mdot
.44331 .6608 Mdot
.59175 .38629 Mdot
.38676 .37157 Mdot
.66843 .52914 Mdot
.44297 .60678 Mdot
.50964 .61836 Mdot
.41824 .4929 Mdot
.45753 .64978 Mdot
.35279 .75896 Mdot
.48159 .63238 Mdot
.44089 .36413 Mdot
.51764 .59443 Mdot
.79975 .46711 Mdot
.38982 .46604 Mdot
.61877 .54259 Mdot
.41046 .4049 Mdot
.43993 .38515 Mdot
.24444 .38842 Mdot
.6118 .31656 Mdot
.43332 .60255 Mdot
.45554 .34779 Mdot
.39734 .57437 Mdot
.61323 .38824 Mdot
.52134 .64721 Mdot
.53001 .40143 Mdot
.36608 .29973 Mdot
.42783 .40384 Mdot
.49936 .54721 Mdot
.69428 .53294 Mdot
.48308 .6475 Mdot
.44249 .33901 Mdot
.39602 .65779 Mdot
.49441 .58764 Mdot
.73211 .32739 Mdot
.39844 .50059 Mdot
.62021 .35912 Mdot
.41552 .60759 Mdot
.47703 .67305 Mdot
.40936 .38578 Mdot
.69327 .50912 Mdot
.61736 .37985 Mdot
.65682 .5283 Mdot
.37195 .73254 Mdot
.50704 .18366 Mdot
.47123 .50374 Mdot
.29108 .50039 Mdot
.35763 .34123 Mdot
.38291 .75389 Mdot
.80359 .57978 Mdot
.66086 .76175 Mdot
.43622 .78425 Mdot
.41661 .33044 Mdot
.34554 .33019 Mdot
.43403 .37811 Mdot
.51226 .62906 Mdot
.4244 .38243 Mdot
.44833 .83151 Mdot
.47397 .6329 Mdot
.41651 .37195 Mdot
.74805 .63851 Mdot
.4778 .6474 Mdot
.65472 .5639 Mdot
.3305 .77171 Mdot
.82106 .44676 Mdot
.65752 .34268 Mdot
.41999 .3451 Mdot
.56142 .80874 Mdot
.46103 .63665 Mdot
.51827 .59631 Mdot
.68962 .52216 Mdot
.5453 .64726 Mdot
.30329 .49305 Mdot
.33496 .46145 Mdot
.62139 .42404 Mdot
.35287 .50608 Mdot
.41582 .60551 Mdot
.67193 .52878 Mdot
.55131 .53121 Mdot
.26054 .37704 Mdot
.33169 .31842 Mdot
.58384 .41431 Mdot
.32944 .77 Mdot
.65026 .45839 Mdot
.62822 .44734 Mdot
.49954 .34061 Mdot
.66188 .50647 Mdot
.40973 .81674 Mdot
.58154 .3627 Mdot
.4393 .18266 Mdot
.76181 .50334 Mdot
.46328 .59772 Mdot
.6046 .39204 Mdot
.54753 .57192 Mdot
.81586 .47565 Mdot
.38358 .21477 Mdot
.48934 .76159 Mdot
.5172 .65807 Mdot
.3547 .29643 Mdot
.46484 .62425 Mdot
.40578 .28289 Mdot
.49146 .62879 Mdot
.65769 .52535 Mdot
.75234 .50351 Mdot
.64587 .34378 Mdot
.58846 .57157 Mdot
.51476 .29254 Mdot
.29855 .4623 Mdot
.47929 .62885 Mdot
.45928 .59869 Mdot
.30099 .4953 Mdot
.6662 .54506 Mdot
.45222 .67407 Mdot
.76322 .64949 Mdot
.45855 .59357 Mdot
.57394 .37871 Mdot
.76754 .51895 Mdot
.52959 .71881 Mdot
.42527 .63659 Mdot
.64309 .49761 Mdot
.56634 .38015 Mdot
.58972 .38358 Mdot
.42807 .69725 Mdot
.58814 .40912 Mdot
.45082 .63963 Mdot
.35702 .22696 Mdot
.67095 .55037 Mdot
.68003 .27284 Mdot
.62594 .54162 Mdot
.64037 .68555 Mdot
.61568 .34695 Mdot
.56672 .23647 Mdot
.5411 .56803 Mdot
.58413 .36323 Mdot
.60046 .58997 Mdot
.44988 .58742 Mdot
.4452 .58854 Mdot
.53845 .81178 Mdot
.44307 .35422 Mdot
.41096 .49219 Mdot
.58839 .40613 Mdot
.44026 .62632 Mdot
.4295 .6586 Mdot
.56656 .37632 Mdot
.43016 .22067 Mdot
.79358 .53891 Mdot
.47868 .6325 Mdot
.66278 .51997 Mdot
.65633 .51529 Mdot
.48308 .56483 Mdot
.5113 .64384 Mdot
.43722 .39607 Mdot
.3891 .3894 Mdot
.46302 .34719 Mdot
.40118 .49376 Mdot
.59934 .25061 Mdot
.20782 .60574 Mdot
.5794 .35273 Mdot
.73173 .41017 Mdot
.45946 .50053 Mdot
.5135 .66473 Mdot
.41339 .3452 Mdot
.47312 .67398 Mdot
.45568 .66018 Mdot
.57509 .3047 Mdot
.24614 .65697 Mdot
.70948 .47949 Mdot
.69108 .50304 Mdot
.61556 .32971 Mdot
.40828 .62903 Mdot
.5479 .35444 Mdot
.3315 .48859 Mdot
.37841 .6806 Mdot
.59526 .40327 Mdot
.64215 .56433 Mdot
.59979 .34187 Mdot
.47849 .59855 Mdot
.54712 .59605 Mdot
.65918 .50823 Mdot
.32091 .49983 Mdot
.51642 .67602 Mdot
.47177 .61726 Mdot
.62399 .2 Mdot
.37229 .58728 Mdot
.62432 .44245 Mdot
.48038 .63443 Mdot
.44331 .59709 Mdot
.34618 .46331 Mdot
.46301 .59306 Mdot
.49119 .67034 Mdot
.60455 .65534 Mdot
.67737 .3921 Mdot
.30633 .45109 Mdot
.37568 .22646 Mdot
.64146 .50663 Mdot
.41424 .80498 Mdot
.4076 .35361 Mdot
.64399 .39207 Mdot
.78494 .53269 Mdot
.45079 .39948 Mdot
.47613 .26478 Mdot
.4025 .79596 Mdot
.37122 .40919 Mdot
.46785 .34211 Mdot
.66073 .57071 Mdot
.43601 .64228 Mdot
.47349 .62438 Mdot
.30461 .48698 Mdot
.63083 .52684 Mdot
.53138 .48222 Mdot
.20372 .38887 Mdot
.45538 .62365 Mdot
.72212 .31959 Mdot
.35804 .2583 Mdot
.3452 .30591 Mdot
.31616 .48264 Mdot
.33652 .46007 Mdot
.48004 .62706 Mdot
.59643 .64133 Mdot
.67 .53405 Mdot
.4428 .60772 Mdot
.50721 .67234 Mdot
.43467 .34737 Mdot
.64453 .54983 Mdot
.38988 .3685 Mdot
.53415 .25729 Mdot
.34396 .7392 Mdot
.41922 .16916 Mdot
.61112 .37513 Mdot
.3069 .3032 Mdot
.61885 .38845 Mdot
.2814 .58993 Mdot
.45427 .40136 Mdot
.49123 .64828 Mdot
.69483 .51899 Mdot
.4413 .63452 Mdot
.50702 .64517 Mdot
.45685 .59823 Mdot
.42692 .64482 Mdot
.44954 .15297 Mdot
.29452 .46274 Mdot
.46814 .69363 Mdot
.44276 .36999 Mdot
.19961 .46856 Mdot
.21542 .41878 Mdot
.45834 .60084 Mdot
.49925 .62373 Mdot
.64856 .54412 Mdot
.51811 .6466 Mdot
.61804 .38621 Mdot
.66111 .56629 Mdot
.49333 .59866 Mdot
.26983 .73087 Mdot
.48671 .58951 Mdot
.37308 .75394 Mdot
.59931 .34314 Mdot
.52907 .20207 Mdot
.54876 .60692 Mdot
.6362 .28943 Mdot
.4111 .49229 Mdot
.45648 .38866 Mdot
.6268 .37493 Mdot
.41772 .35961 Mdot
.21825 .35622 Mdot
.49008 .55577 Mdot
.47063 .64334 Mdot
.50103 .67071 Mdot
.46239 .35419 Mdot
.21542 .68572 Mdot
.53372 .29673 Mdot
.48737 .55385 Mdot
.43281 .39767 Mdot
.60718 .54784 Mdot
.43492 .76503 Mdot
.6381 .53222 Mdot
.33659 .50864 Mdot
.57143 .377 Mdot
.31837 .4993 Mdot
.30209 .6602 Mdot
.64379 .55612 Mdot
.70949 .52868 Mdot
.41093 .35211 Mdot
.72768 .54861 Mdot
.80475 .3128 Mdot
.76349 .49984 Mdot
.31086 .57875 Mdot
.68114 .52793 Mdot
.47887 .59068 Mdot
.28454 .62006 Mdot
.75782 .50456 Mdot
.41858 .3623 Mdot
.46208 .66995 Mdot
.7351 .58516 Mdot
.4386 .39641 Mdot
.53978 .63527 Mdot
.44572 .36704 Mdot
.58833 .35188 Mdot
.42215 .34148 Mdot
.69585 .4906 Mdot
.5064 .60605 Mdot
.82087 .32082 Mdot
.36102 .50454 Mdot
.46324 .63943 Mdot
.60568 .32364 Mdot
.45994 .23782 Mdot
.48185 .65703 Mdot
.28692 .49058 Mdot
.41408 .37821 Mdot
.68767 .57224 Mdot
.48377 .6309 Mdot
.43207 .39792 Mdot
.67056 .55672 Mdot
.59707 .31483 Mdot
.73677 .61039 Mdot
.65219 .42075 Mdot
.69123 .51714 Mdot
.60127 .47998 Mdot
.62927 .34179 Mdot
.43957 .59987 Mdot
.4443 .6692 Mdot
.65833 .51899 Mdot
.22949 .52606 Mdot
.52681 .61783 Mdot
.5129 .58943 Mdot
.4359 .35218 Mdot
.41324 .36172 Mdot
.65082 .76513 Mdot
.39488 .35329 Mdot
.54686 .61629 Mdot
.65502 .52028 Mdot
.4732 .6538 Mdot
.65001 .54698 Mdot
.51677 .64746 Mdot
.46872 .72573 Mdot
.66715 .54479 Mdot
.57375 .30856 Mdot
.45988 .6668 Mdot
.50391 .69055 Mdot
.49588 .65545 Mdot
.43349 .63461 Mdot
.43635 .39399 Mdot
.31303 .48761 Mdot
.51309 .66743 Mdot
.26789 .47584 Mdot
.30189 .45567 Mdot
.65228 .3442 Mdot
.43713 .34825 Mdot
.29438 .4714 Mdot
.30464 .27209 Mdot
.41853 .39637 Mdot
.30103 .48629 Mdot
.21421 .42174 Mdot
.61056 .34552 Mdot
.69607 .53086 Mdot
.48201 .64515 Mdot
.34552 .68767 Mdot
.5458 .74305 Mdot
.46243 .40835 Mdot
.47594 .63473 Mdot
.48433 .6617 Mdot
.61561 .53229 Mdot
.17046 .43926 Mdot
.42607 .32338 Mdot
.47233 .58713 Mdot
.6405 .56063 Mdot
.13998 .49265 Mdot
.43839 .36884 Mdot
.30482 .49013 Mdot
.60435 .33692 Mdot
.6232 .58151 Mdot
.66016 .29555 Mdot
.59275 .3282 Mdot
.40388 .42099 Mdot
.54735 .25991 Mdot
.43611 .67241 Mdot
.39905 .35882 Mdot
.78509 .67624 Mdot
.51646 .52248 Mdot
.4395 .47851 Mdot
.53428 .80274 Mdot
.67217 .50536 Mdot
.61836 .38809 Mdot
.3051 .45997 Mdot
.65024 .50175 Mdot
.65254 .55593 Mdot
.56896 .36746 Mdot
.57541 .65543 Mdot
.529 .39654 Mdot
.57836 .38659 Mdot
.35864 .64896 Mdot
.2129 .52754 Mdot
.40615 .35019 Mdot
.30213 .4923 Mdot
.28951 .66335 Mdot
.65171 .52955 Mdot
.37353 .81445 Mdot
.55915 .81833 Mdot
.46176 .63453 Mdot
.30337 .46475 Mdot
.21502 .67093 Mdot
.17359 .45537 Mdot
.61483 .35799 Mdot
.65025 .36581 Mdot
.33255 .49509 Mdot
.49459 .66006 Mdot
.37688 .62063 Mdot
.52074 .61601 Mdot
.57357 .36699 Mdot
.72812 .63331 Mdot
.64738 .5567 Mdot
.5867 .34135 Mdot
.39485 .72119 Mdot
.45047 .63675 Mdot
.46305 .66782 Mdot
.34506 .60812 Mdot
.6514 .49997 Mdot
.45781 .38705 Mdot
.44603 .67537 Mdot
.46781 .61833 Mdot
.54582 .60453 Mdot
.4729 .56333 Mdot
.63984 .63109 Mdot
.50731 .6291 Mdot
.29426 .32227 Mdot
.51244 .65912 Mdot
.44765 .64999 Mdot
.65651 .49395 Mdot
.38548 .17979 Mdot
.54003 .26973 Mdot
.46404 .61962 Mdot
.45201 .59217 Mdot
.5912 .33897 Mdot
.52585 .37565 Mdot
.74 .50855 Mdot
.67895 .57369 Mdot
.61131 .79332 Mdot
.45896 .57752 Mdot
.62042 .55591 Mdot
.28781 .48724 Mdot
.43518 .6013 Mdot
.62929 .56209 Mdot
.51971 .58899 Mdot
.44475 .39653 Mdot
.42156 .39766 Mdot
.5614 .54493 Mdot
.29166 .47341 Mdot
.78851 .4429 Mdot
.72912 .40898 Mdot
.41272 .39061 Mdot
.47518 .6418 Mdot
.5729 .41533 Mdot
.44759 .34591 Mdot
.36792 .40935 Mdot
.22631 .56351 Mdot
.6824 .5337 Mdot
.68492 .51383 Mdot
.25177 .57039 Mdot
.50032 .24953 Mdot
.72891 .30709 Mdot
.58643 .35222 Mdot
.48078 .69068 Mdot
.7641 .42712 Mdot
.68574 .51041 Mdot
.28602 .60605 Mdot
.29801 .46623 Mdot
.61308 .35695 Mdot
.52552 .32947 Mdot
.63835 .54178 Mdot
.68909 .55036 Mdot
.53423 .61742 Mdot
.47356 .60926 Mdot
.67703 .74505 Mdot
.26834 .4693 Mdot
.57195 .35016 Mdot
.30455 .49279 Mdot
.44785 .40456 Mdot
.51619 .61041 Mdot
.66502 .54287 Mdot
.20575 .53986 Mdot
.42181 .62963 Mdot
.45116 .38609 Mdot
.67749 .50732 Mdot
.33973 .48447 Mdot
.29253 .49788 Mdot
.42979 .63133 Mdot
.71579 .70303 Mdot
.57933 .37411 Mdot
.64434 .51029 Mdot
.58733 .43391 Mdot
.52248 .62049 Mdot
.48047 .61334 Mdot
.4838 .71396 Mdot
.5742 .34688 Mdot
.69788 .45467 Mdot
.28223 .48722 Mdot
.63971 .5184 Mdot
.50456 .6276 Mdot
.29638 .48536 Mdot
.73993 .41245 Mdot
.42834 .41304 Mdot
.42517 .33994 Mdot
.29564 .4994 Mdot
.31941 .47537 Mdot
.28218 .48286 Mdot
.37672 .81811 Mdot
.61415 .56111 Mdot
.63312 .45562 Mdot
.47792 .58133 Mdot
.29606 .57799 Mdot
.47862 .69425 Mdot
.62184 .36423 Mdot
.4458 .3582 Mdot
.49323 .65218 Mdot
.42663 .62646 Mdot
.46013 .7178 Mdot
.6982 .28889 Mdot
.54076 .68179 Mdot
.64791 .55215 Mdot
.5473 .59312 Mdot
.42066 .34608 Mdot
.38174 .83639 Mdot
.59486 .8248 Mdot
.54849 .60025 Mdot
.53351 .3949 Mdot
.67462 .54244 Mdot
.57797 .35402 Mdot
.33074 .6395 Mdot
.6083 .3423 Mdot
.64874 .51416 Mdot
.512 .62554 Mdot
.72394 .43228 Mdot
.33771 .45 Mdot
.43798 .62969 Mdot
.58414 .35139 Mdot
.44631 .66228 Mdot
.58187 .33865 Mdot
.34391 .69787 Mdot
.76799 .68083 Mdot
.45725 .63189 Mdot
.43204 .6775 Mdot
.70858 .72375 Mdot
.45123 .60487 Mdot
.25561 .46452 Mdot
.67569 .5422 Mdot
.73597 .63141 Mdot
.41304 .64793 Mdot
.38555 .66107 Mdot
.52218 .61198 Mdot
.75515 .60481 Mdot
.48078 .61023 Mdot
.3401 .30688 Mdot
.50651 .59907 Mdot
.48995 .67216 Mdot
.6017 .38429 Mdot
.58932 .33907 Mdot
.68281 .4926 Mdot
.43832 .33235 Mdot
.36838 .75476 Mdot
.47534 .61659 Mdot
.58291 .24622 Mdot
.67986 .41991 Mdot
.31933 .47845 Mdot
.64363 .51751 Mdot
.14793 .51759 Mdot
.60673 .40795 Mdot
.64983 .78936 Mdot
.601 .79063 Mdot
.68502 .35299 Mdot
.25216 .64459 Mdot
.4179 .24408 Mdot
.33685 .48659 Mdot
.52712 .59851 Mdot
.34083 .41797 Mdot
.33605 .30749 Mdot
.2257 .52727 Mdot
.62924 .36392 Mdot
.676 .7251 Mdot
.22499 .6043 Mdot
.31896 .51029 Mdot
.34218 .46715 Mdot
.60868 .33124 Mdot
.42747 .30753 Mdot
.40459 .61367 Mdot
.31203 .4639 Mdot
.46135 .34842 Mdot
.41823 .40009 Mdot
.45445 .33557 Mdot
.66791 .53635 Mdot
.60006 .81869 Mdot
.633 .36214 Mdot
.61985 .36633 Mdot
.39088 .30543 Mdot
.42693 .73339 Mdot
.70734 .54727 Mdot
.42239 .35238 Mdot
.40988 .34066 Mdot
.67973 .54215 Mdot
.52714 .58057 Mdot
.47612 .55816 Mdot
.45922 .62149 Mdot
.3084 .48589 Mdot
.4771 .60587 Mdot
.42619 .39451 Mdot
.61184 .36958 Mdot
.42127 .33595 Mdot
.599 .32248 Mdot
.19823 .54915 Mdot
.43709 .61107 Mdot
.50836 .60588 Mdot
.57074 .17396 Mdot
.70207 .5312 Mdot
.19821 .48576 Mdot
.56416 .3316 Mdot
.43547 .37728 Mdot
.49061 .67 Mdot
.70125 .55675 Mdot
.29186 .44651 Mdot
.4253 .17239 Mdot
.51929 .63782 Mdot
.65084 .53641 Mdot
.51519 .6149 Mdot
.45768 .51909 Mdot
.78434 .36239 Mdot
.64843 .52531 Mdot
.70503 .28181 Mdot
.4732 .58875 Mdot
.31308 .27708 Mdot
.51501 .65451 Mdot
.40832 .52376 Mdot
.52675 .61802 Mdot
.63936 .50768 Mdot
.4605 .61725 Mdot
.68831 .56239 Mdot
.40336 .38206 Mdot
.59158 .34117 Mdot
.68995 .51751 Mdot
.43254 .65072 Mdot
.6745 .14337 Mdot
.59835 .35066 Mdot
.4742 .62954 Mdot
.61014 .33631 Mdot
.62509 .53556 Mdot
.65975 .50271 Mdot
.20043 .42224 Mdot
.52979 .25747 Mdot
.59001 .35216 Mdot
.51596 .61157 Mdot
.34154 .27824 Mdot
.49848 .64187 Mdot
.38956 .58632 Mdot
.52891 .57841 Mdot
.50235 .57722 Mdot
.19794 .44497 Mdot
.62049 .3552 Mdot
.72737 .30244 Mdot
.1828 .45489 Mdot
.19961 .46605 Mdot
.69498 .49477 Mdot
.31521 .50876 Mdot
.4005 .8091 Mdot
.60523 .2549 Mdot
.44977 .39642 Mdot
.48962 .65504 Mdot
.59383 .56708 Mdot
.58058 .37946 Mdot
.32723 .48955 Mdot
.45829 .63164 Mdot
.41119 .34208 Mdot
.8012 .56333 Mdot
.61683 .32896 Mdot
.64387 .52806 Mdot
.61199 .53465 Mdot
.26701 .27215 Mdot
.48952 .63143 Mdot
.50313 .60229 Mdot
.57126 .37654 Mdot
.43817 .23309 Mdot
.3238 .45881 Mdot
.74918 .63428 Mdot
.59184 .35291 Mdot
.52312 .46247 Mdot
.62988 .5637 Mdot
.48311 .66444 Mdot
.27192 .71837 Mdot
.51667 .32288 Mdot
.61997 .2092 Mdot
.30634 .48528 Mdot
.39399 .57661 Mdot
.63935 .50815 Mdot
.60304 .36714 Mdot
.5017 .23332 Mdot
.44963 .58476 Mdot
.4634 .67516 Mdot
.40703 .54123 Mdot
.64816 .33802 Mdot
.73393 .51954 Mdot
.51997 .63421 Mdot
.41093 .49027 Mdot
.51626 .64352 Mdot
.44433 .69894 Mdot
.52704 .57088 Mdot
.49124 .61293 Mdot
.65913 .5408 Mdot
.44041 .55281 Mdot
.46258 .36514 Mdot
.71021 .48413 Mdot
.51143 .46456 Mdot
.4684 .63654 Mdot
.50928 .58772 Mdot
.50636 .75943 Mdot
.45026 .26401 Mdot
.68816 .51952 Mdot
.70924 .50743 Mdot
.5988 .41062 Mdot
.50161 .56406 Mdot
.43659 .33184 Mdot
.49753 .68706 Mdot
.43958 .39314 Mdot
.6625 .5415 Mdot
.43627 .37393 Mdot
.60095 .33379 Mdot
.39609 .36675 Mdot
.59129 .24541 Mdot
.6058 .35525 Mdot
.68826 .528 Mdot
.49298 .60192 Mdot
.60534 .32296 Mdot
.33264 .56187 Mdot
.30672 .48371 Mdot
.17099 .60194 Mdot
.49348 .59808 Mdot
.67361 .35919 Mdot
.41797 .70249 Mdot
.4162 .33741 Mdot
.77221 .34328 Mdot
.69626 .51308 Mdot
.31867 .45194 Mdot
.6614 .49728 Mdot
.38031 .68124 Mdot
.31154 .47356 Mdot
.16666 .5484 Mdot
.40114 .50895 Mdot
.37554 .58459 Mdot
.50695 .56885 Mdot
.3542 .58937 Mdot
.43289 .40695 Mdot
.58231 .37948 Mdot
.49165 .24338 Mdot
.48513 .67326 Mdot
.81769 .58472 Mdot
.65038 .49686 Mdot
.44982 .34258 Mdot
.60286 .37315 Mdot
.61989 .37353 Mdot
.45878 .58683 Mdot
.30803 .3562 Mdot
.46484 .6769 Mdot
.51926 .24435 Mdot
.56029 .80715 Mdot
.63438 .46022 Mdot
.47773 .63133 Mdot
.40844 .38506 Mdot
.51517 .61527 Mdot
.28334 .49109 Mdot
.69108 .76337 Mdot
.5069 .68555 Mdot
.55596 .37407 Mdot
.26864 .46315 Mdot
.62742 .525 Mdot
.44402 .72105 Mdot
.64067 .44312 Mdot
.4932 .63131 Mdot
.39198 .14793 Mdot
.29868 .48495 Mdot
.34391 .4126 Mdot
.42309 .64186 Mdot
.4272 .61098 Mdot
.43037 .46584 Mdot
.65572 .28133 Mdot
.45695 .30229 Mdot
.44819 .61229 Mdot
.33622 .54855 Mdot
.61585 .3364 Mdot
.50097 .65562 Mdot
.47481 .62566 Mdot
.57246 .7024 Mdot
.62284 .34716 Mdot
.44524 .38255 Mdot
.45407 .39806 Mdot
.45284 .41362 Mdot
.27852 .4758 Mdot
.73596 .49036 Mdot
.30043 .59864 Mdot
.81159 .51073 Mdot
.33092 .45196 Mdot
.42971 .61717 Mdot
.35906 .38924 Mdot
.51671 .62105 Mdot
.32674 .48633 Mdot
.62206 .3429 Mdot
.68743 .50915 Mdot
.75889 .42625 Mdot
.43995 .40219 Mdot
.43376 .59447 Mdot
.31248 .45387 Mdot
.68003 .53363 Mdot
.30914 .64537 Mdot
.62847 .52451 Mdot
.588 .36103 Mdot
.73904 .49071 Mdot
.32982 .48673 Mdot
.62224 .54559 Mdot
.55614 .39842 Mdot
.18673 .43244 Mdot
.51206 .56181 Mdot
.74702 .46332 Mdot
.62312 .52825 Mdot
.71203 .51815 Mdot
.61518 .5547 Mdot
.44073 .65086 Mdot
.53325 .39665 Mdot
.49249 .57058 Mdot
.6199 .34737 Mdot
.44629 .37117 Mdot
.77383 .65552 Mdot
.59088 .28678 Mdot
.58392 .45619 Mdot
.5247 .66377 Mdot
.44982 .63562 Mdot
.47949 .62717 Mdot
.43224 .68757 Mdot
.59723 .246 Mdot
.44476 .65302 Mdot
.60111 .38503 Mdot
.41771 .3839 Mdot
.52547 .59591 Mdot
.40695 .41608 Mdot
.21444 .44006 Mdot
.33107 .49792 Mdot
.61096 .42976 Mdot
.66288 .7997 Mdot
.6821 .53125 Mdot
.40615 .4015 Mdot
.41808 .39064 Mdot
.33482 .47125 Mdot
.57618 .37651 Mdot
.62493 .52954 Mdot
.40463 .56542 Mdot
.30023 .45625 Mdot
.46334 .61726 Mdot
.54417 .3957 Mdot
.80941 .60944 Mdot
.53065 .60686 Mdot
.47733 .65614 Mdot
.44981 .33019 Mdot
.34953 .41603 Mdot
.86409 .44528 Mdot
.3184 .61046 Mdot
.3197 .49026 Mdot
.31494 .50543 Mdot
.68046 .54478 Mdot
.42252 .6099 Mdot
.6037 .32663 Mdot
.74082 .54694 Mdot
.6757 .4548 Mdot
.77239 .39167 Mdot
.59563 .19852 Mdot
.50793 .64784 Mdot
.41206 .22663 Mdot
.45043 .64443 Mdot
.61326 .55788 Mdot
.65938 .53744 Mdot
.67146 .52396 Mdot
.5822 .37822 Mdot
.64777 .71782 Mdot
.59216 .38762 Mdot
.75962 .72008 Mdot
.64849 .50548 Mdot
.39416 .51108 Mdot
.42406 .34875 Mdot
.47808 .55392 Mdot
.33399 .49355 Mdot
.74786 .48012 Mdot
.55004 .65017 Mdot
.59425 .62657 Mdot
.45471 .34846 Mdot
.69144 .52235 Mdot
.43276 .23736 Mdot
.47608 .81772 Mdot
.72604 .54548 Mdot
.49542 .715 Mdot
.33034 .64192 Mdot
.32069 .48249 Mdot
.61712 .20756 Mdot
.3159 .49769 Mdot
.58619 .34942 Mdot
.50901 .61307 Mdot
.50021 .60874 Mdot
.51754 .64297 Mdot
.44659 .60327 Mdot
.62702 .33241 Mdot
.47931 .68543 Mdot
.7994 .46841 Mdot
.44576 .40018 Mdot
.29957 .53103 Mdot
.30984 .49498 Mdot
.62617 .36251 Mdot
.41863 .38568 Mdot
.45933 .26409 Mdot
.34134 .57503 Mdot
.48148 .63138 Mdot
.49266 .65292 Mdot
.6834 .75778 Mdot
.51965 .63379 Mdot
.41353 .58801 Mdot
.43952 .39923 Mdot
.51098 .72994 Mdot
.33044 .4978 Mdot
.32258 .50388 Mdot
.60748 .3543 Mdot
.65843 .53941 Mdot
.29759 .47737 Mdot
.42973 .34918 Mdot
.52981 .65963 Mdot
.46184 .68613 Mdot
.6268 .52291 Mdot
.69345 .7541 Mdot
.29378 .50259 Mdot
.33946 .27606 Mdot
.69025 .5292 Mdot
.64315 .49446 Mdot
.46557 .6753 Mdot
.64995 .23316 Mdot
.67419 .48394 Mdot
.29179 .4523 Mdot
.6271 .3629 Mdot
.34027 .63588 Mdot
.60774 .40502 Mdot
.64104 .52967 Mdot
.48823 .58683 Mdot
.66999 .5396 Mdot
.48337 .6329 Mdot
.5195 .83964 Mdot
.49397 .60946 Mdot
.81229 .4966 Mdot
.24843 .55825 Mdot
.4032 .36668 Mdot
.44085 .25758 Mdot
.40811 .35339 Mdot
.68995 .50493 Mdot
.42094 .64384 Mdot
.33745 .4664 Mdot
.2399 .3733 Mdot
.67265 .59059 Mdot
.45019 .35437 Mdot
.40407 .32913 Mdot
.61748 .39911 Mdot
.52782 .61522 Mdot
.45576 .6715 Mdot
.41514 .36918 Mdot
.65886 .47495 Mdot
.63142 .54264 Mdot
.50401 .62267 Mdot
.44778 .63667 Mdot
.40425 .36183 Mdot
.18845 .42057 Mdot
.49313 .53609 Mdot
.50296 .61586 Mdot
.48714 .322 Mdot
.62068 .3684 Mdot
.48003 .55442 Mdot
.43624 .67941 Mdot
.31968 .47243 Mdot
.67686 .62089 Mdot
.48045 .80027 Mdot
.62136 .33939 Mdot
.42507 .39716 Mdot
.49694 .62944 Mdot
.41036 .38698 Mdot
.47548 .68744 Mdot
.6647 .29685 Mdot
.40706 .39962 Mdot
.50667 .58215 Mdot
.52612 .58244 Mdot
.64647 .50132 Mdot
.50086 .65059 Mdot
.54597 .77408 Mdot
.45749 .37575 Mdot
.46265 .58623 Mdot
.73394 .67002 Mdot
.5823 .39455 Mdot
.47761 .562 Mdot
.29741 .45886 Mdot
.38145 .62155 Mdot
.71486 .41301 Mdot
.26589 .66862 Mdot
.33126 .50106 Mdot
.44481 .65835 Mdot
.4159 .325 Mdot
.57117 .35205 Mdot
.81841 .45282 Mdot
.49124 .66218 Mdot
.57793 .35949 Mdot
.61186 .36838 Mdot
.32866 .49067 Mdot
.36003 .18864 Mdot
.42432 .63989 Mdot
.46213 .60027 Mdot
.60481 .72801 Mdot
.69704 .54594 Mdot
.48486 .60604 Mdot
.46871 .59142 Mdot
.60553 .38315 Mdot
.4125 .60509 Mdot
.60875 .77794 Mdot
.75408 .61667 Mdot
.56607 .38294 Mdot
.77744 .44973 Mdot
.41279 .40216 Mdot
.29643 .49123 Mdot
.66574 .5091 Mdot
.32247 .45709 Mdot
.4288 .34353 Mdot
.47743 .59276 Mdot
.57065 .36972 Mdot
.54402 .76566 Mdot
.60687 .33023 Mdot
.22558 .58975 Mdot
.66991 .56472 Mdot
.63666 .37464 Mdot
.37449 .16187 Mdot
.48932 .30175 Mdot
.64375 .31566 Mdot
.31922 .47788 Mdot
.37422 .34671 Mdot
.44821 .63845 Mdot
.59978 .1941 Mdot
.4328 .61188 Mdot
.73235 .65338 Mdot
.45352 .3957 Mdot
.4612 .34276 Mdot
.50661 .6154 Mdot
.54002 .80242 Mdot
.56746 .3586 Mdot
.61113 .39025 Mdot
.49656 .58017 Mdot
.58423 .36253 Mdot
.46948 .60681 Mdot
.42827 .39351 Mdot
.64008 .20454 Mdot
.46008 .62606 Mdot
.46185 .69992 Mdot
.67522 .33354 Mdot
.1885 .45648 Mdot
.29594 .51849 Mdot
.21182 .33392 Mdot
.52376 .83077 Mdot
.58433 .36419 Mdot
.4855 .57397 Mdot
.77695 .4386 Mdot
.43588 .32558 Mdot
.60679 .4414 Mdot
.48173 .59705 Mdot
.44983 .59675 Mdot
.49795 .66911 Mdot
.46556 .66537 Mdot
.47616 .17133 Mdot
.70861 .57673 Mdot
.65707 .66165 Mdot
.50602 .6467 Mdot
.3574 .56847 Mdot
.60161 .34505 Mdot
.60061 .57245 Mdot
.31455 .44846 Mdot
.5058 .64892 Mdot
.72869 .52646 Mdot
.5714 .3926 Mdot
.78487 .69531 Mdot
.57453 .36339 Mdot
.43866 .38484 Mdot
.58982 .33553 Mdot
.45806 .64839 Mdot
.65693 .51537 Mdot
.44622 .44487 Mdot
.52782 .28173 Mdot
.46163 .38513 Mdot
.4638 .6392 Mdot
.37284 .51874 Mdot
.46101 .35992 Mdot
.19321 .48573 Mdot
.66961 .51244 Mdot
.32534 .54552 Mdot
.66558 .53985 Mdot
.49147 .58275 Mdot
.49278 .58347 Mdot
.60126 .4146 Mdot
.59727 .3334 Mdot
.66373 .53982 Mdot
.28086 .22993 Mdot
.28483 .4906 Mdot
.66703 .52448 Mdot
.41127 .65257 Mdot
.51228 .41185 Mdot
.66241 .51641 Mdot
.29964 .43865 Mdot
.61014 .37511 Mdot
.69544 .53749 Mdot
.5208 .65498 Mdot
.36124 .64775 Mdot
.29442 .49638 Mdot
.46591 .38769 Mdot
.29041 .62745 Mdot
.45508 .36294 Mdot
.62743 .37146 Mdot
.40522 .35681 Mdot
.61827 .3669 Mdot
.70158 .4284 Mdot
.69968 .47754 Mdot
.37791 .43241 Mdot
.63035 .36867 Mdot
.41152 .35199 Mdot
.51176 .61384 Mdot
.35315 .51312 Mdot
.41635 .62817 Mdot
.44476 .66582 Mdot
.60965 .38639 Mdot
.65508 .50081 Mdot
.69934 .49816 Mdot
.38395 .57741 Mdot
.65342 .54116 Mdot
.45282 .38169 Mdot
.63373 .61537 Mdot
.58849 .25761 Mdot
.60277 .40482 Mdot
.59353 .33863 Mdot
.51788 .62568 Mdot
.418 .36027 Mdot
.46675 .37176 Mdot
.60953 .40513 Mdot
.68721 .28767 Mdot
.43514 .68414 Mdot
.71077 .50659 Mdot
.69379 .54712 Mdot
.65075 .52312 Mdot
.62206 .56641 Mdot
.38632 .65314 Mdot
.61314 .35042 Mdot
.66542 .49897 Mdot
.51867 .62597 Mdot
.46758 .59325 Mdot
.75904 .51706 Mdot
.28924 .48521 Mdot
.51647 .58358 Mdot
.52576 .5709 Mdot
.48188 .66558 Mdot
.41665 .3424 Mdot
.42017 .57247 Mdot
.3932 .36937 Mdot
.43355 .32727 Mdot
.43574 .32714 Mdot
.61328 .26181 Mdot
.6371 .7909 Mdot
.41364 .77471 Mdot
.46051 .58849 Mdot
.3768 .24236 Mdot
.4302 .36142 Mdot
.71821 .57924 Mdot
.68932 .45074 Mdot
.48947 .66948 Mdot
.28138 .3406 Mdot
.41215 .36626 Mdot
.68647 .53669 Mdot
.48839 .60199 Mdot
.41581 .41085 Mdot
.28847 .46467 Mdot
.44379 .59175 Mdot
.43125 .41362 Mdot
.62094 .54656 Mdot
.2756 .47003 Mdot
.70125 .52742 Mdot
.43394 .32622 Mdot
.40988 .62521 Mdot
.74104 .26819 Mdot
.42216 .41707 Mdot
.27261 .30517 Mdot
.57402 .58905 Mdot
.50828 .62019 Mdot
.39212 .38582 Mdot
.63798 .49495 Mdot
.62673 .37292 Mdot
.56241 .49134 Mdot
.67003 .55209 Mdot
.46106 .34249 Mdot
.43437 .33391 Mdot
.46152 .38543 Mdot
.65497 .55381 Mdot
.46289 .56929 Mdot
.64558 .54709 Mdot
.58718 .33665 Mdot
.48645 .645 Mdot
.37578 .74208 Mdot
.4525 .22885 Mdot
.68557 .53475 Mdot
.44994 .37143 Mdot
.34443 .45757 Mdot
.45304 .63772 Mdot
.42348 .23136 Mdot
.51298 .61554 Mdot
.61803 .3726 Mdot
.61824 .6492 Mdot
.5188 .73123 Mdot
.49474 .57437 Mdot
.5138 .63152 Mdot
.60887 .39238 Mdot
.46262 .63546 Mdot
.52705 .61737 Mdot
.59044 .24438 Mdot
.63933 .5496 Mdot
.45681 .61916 Mdot
.44376 .36398 Mdot
.5605 .26161 Mdot
.44466 .69155 Mdot
.37279 .40114 Mdot
.34287 .544 Mdot
.59607 .66304 Mdot
.43451 .60887 Mdot
.55982 .41808 Mdot
.46375 .67111 Mdot
.43705 .62215 Mdot
.51147 .63036 Mdot
.41701 .19633 Mdot
.42651 .41171 Mdot
.41116 .38326 Mdot
.30836 .50439 Mdot
.33917 .54411 Mdot
.31137 .46483 Mdot
.61388 .36809 Mdot
.31214 .37055 Mdot
.39234 .37412 Mdot
.63167 .53433 Mdot
.4395 .63543 Mdot
.41641 .41503 Mdot
.48313 .66781 Mdot
.45977 .64788 Mdot
.42617 .32792 Mdot
.42417 .40911 Mdot
.21663 .53604 Mdot
.28629 .48008 Mdot
.67767 .52486 Mdot
.52212 .59599 Mdot
.30681 .45436 Mdot
.4281 .61897 Mdot
.29467 .57893 Mdot
.67406 .52249 Mdot
.63996 .54815 Mdot
.69419 .49165 Mdot
.48483 .59464 Mdot
.45558 .64394 Mdot
.59293 .3885 Mdot
.69487 .51047 Mdot
.57951 .39241 Mdot
.52681 .4868 Mdot
.23608 .44431 Mdot
.48115 .59674 Mdot
.75287 .49542 Mdot
.29946 .46277 Mdot
.44829 .35146 Mdot
.80329 .62269 Mdot
.30793 .50432 Mdot
.48798 .63058 Mdot
.44632 .33679 Mdot
.32964 .47769 Mdot
.43295 .52298 Mdot
.73248 .7362 Mdot
.34534 .46269 Mdot
.51829 .62689 Mdot
.40959 .61321 Mdot
.22385 .31745 Mdot
.34172 .49171 Mdot
.60465 .33867 Mdot
.48707 .59548 Mdot
.71295 .5289 Mdot
.31338 .45366 Mdot
.38294 .28604 Mdot
.4127 .37481 Mdot
.36606 .64725 Mdot
.51044 .68678 Mdot
.58983 .58001 Mdot
.30741 .50237 Mdot
.63854 .51713 Mdot
.39858 .61931 Mdot
.46658 .67445 Mdot
.34085 .49376 Mdot
.60508 .31196 Mdot
.42407 .38427 Mdot
.53436 .2656 Mdot
.65933 .55435 Mdot
.58058 .3053 Mdot
.44774 .35641 Mdot
.33051 .28014 Mdot
.77407 .5762 Mdot
.47129 .55809 Mdot
.30919 .25847 Mdot
.66409 .39369 Mdot
.52058 .6462 Mdot
.30971 .44372 Mdot
.60484 .32138 Mdot
.57766 .40175 Mdot
.59127 .35799 Mdot
.68976 .42919 Mdot
.68362 .5721 Mdot
.43899 .41473 Mdot
.54811 .36149 Mdot
.29457 .48854 Mdot
.3447 .62579 Mdot
.4481 .67214 Mdot
.45137 .63129 Mdot
.52398 .60568 Mdot
.50653 .6499 Mdot
.44847 .65685 Mdot
.57644 .36945 Mdot
.69181 .41382 Mdot
.70567 .56581 Mdot
.66817 .51876 Mdot
.35087 .39583 Mdot
.43266 .35293 Mdot
.46864 .34934 Mdot
.32394 .46504 Mdot
.45972 .29421 Mdot
.40941 .41734 Mdot
.43697 .37611 Mdot
.52938 .59418 Mdot
.63748 .54258 Mdot
.45787 .55755 Mdot
.51603 .62963 Mdot
.44781 .38928 Mdot
.45911 .47106 Mdot
.56066 .78682 Mdot
.23039 .50012 Mdot
.27728 .49146 Mdot
.54549 .38714 Mdot
.32474 .5061 Mdot
.43806 .67166 Mdot
.7868 .37304 Mdot
.42694 .34314 Mdot
.42644 .37349 Mdot
.28858 .47769 Mdot
.64999 .23082 Mdot
.66909 .50644 Mdot
.58546 .29978 Mdot
.61581 .34182 Mdot
.49236 .58602 Mdot
.8003 .57735 Mdot
.5792 .56415 Mdot
.29987 .3595 Mdot
.5949 .3527 Mdot
.40115 .38042 Mdot
.45101 .68511 Mdot
.50873 .63872 Mdot
.30883 .46101 Mdot
.24503 .66663 Mdot
.52354 .56472 Mdot
.20973 .68536 Mdot
.76922 .6799 Mdot
.45701 .78414 Mdot
.46124 .67461 Mdot
.64362 .55031 Mdot
.44711 .40229 Mdot
.30159 .4928 Mdot
.44368 .58726 Mdot
.53254 .81812 Mdot
.63235 .5174 Mdot
.60343 .35811 Mdot
.49448 .45683 Mdot
.33354 .62766 Mdot
.43593 .64283 Mdot
.45968 .59307 Mdot
.43446 .62692 Mdot
.88568 .53467 Mdot
.39947 .35643 Mdot
.68236 .53828 Mdot
.33068 .48853 Mdot
.64736 .53726 Mdot
.40203 .37365 Mdot
.38745 .45853 Mdot
.51029 .60287 Mdot
.61766 .53988 Mdot
.6432 .51423 Mdot
.57672 .39784 Mdot
.62301 .33901 Mdot
.51027 .46883 Mdot
.49214 .61011 Mdot
.39252 .35292 Mdot
.6571 .49943 Mdot
.55509 .40776 Mdot
.31239 .47211 Mdot
.61012 .37666 Mdot
.50162 .64935 Mdot
.39365 .37191 Mdot
.54023 .59953 Mdot
.68653 .51554 Mdot
.43627 .37511 Mdot
.20898 .52506 Mdot
.32997 .49937 Mdot
.46674 .59511 Mdot
.24975 .50434 Mdot
.4286 .39792 Mdot
.44812 .64511 Mdot
.28419 .31076 Mdot
.3157 .43891 Mdot
.53174 .30033 Mdot
.45506 .34345 Mdot
.64776 .30598 Mdot
.67886 .54655 Mdot
.64805 .28462 Mdot
.43122 .38044 Mdot
.35255 .2687 Mdot
.20766 .55838 Mdot
.51377 .67101 Mdot
.65344 .52892 Mdot
.65688 .31405 Mdot
.44704 .83832 Mdot
.2413 .33063 Mdot
.47439 .6287 Mdot
.39623 .35134 Mdot
.32471 .46977 Mdot
.60164 .40341 Mdot
.55509 .29997 Mdot
.36151 .4811 Mdot
.3823 .36699 Mdot
.51075 .63055 Mdot
.62656 .53008 Mdot
.59553 .38131 Mdot
.71488 .41917 Mdot
.43668 .35349 Mdot
.4477 .36882 Mdot
.41959 .634 Mdot
.2963 .46734 Mdot
.49871 .20272 Mdot
.43544 .39717 Mdot
.71316 .72759 Mdot
.46374 .33561 Mdot
.29066 .4599 Mdot
.47135 .66561 Mdot
.37716 .61196 Mdot
.44653 .58851 Mdot
.2366 .36348 Mdot
.42626 .35059 Mdot
.68238 .52094 Mdot
.45872 .67879 Mdot
.74471 .67072 Mdot
.45271 .38018 Mdot
.53567 .38726 Mdot
.40853 .29524 Mdot
.61561 .35231 Mdot
.80349 .62009 Mdot
.4772 .60319 Mdot
.5718 .35114 Mdot
.3137 .46247 Mdot
.49778 .61446 Mdot
.45527 .64814 Mdot
.61833 .52729 Mdot
.58124 .40138 Mdot
.21732 .53048 Mdot
.58477 .34402 Mdot
.59841 .34232 Mdot
.71467 .54575 Mdot
.45733 .60915 Mdot
.44104 .38506 Mdot
.41342 .36564 Mdot
.52307 .65162 Mdot
.57617 .15517 Mdot
.66019 .50664 Mdot
.46863 .37933 Mdot
.8908 .50812 Mdot
.52817 .6395 Mdot
.79261 .62017 Mdot
.23249 .64888 Mdot
.61091 .32866 Mdot
.51915 .62597 Mdot
.62259 .541 Mdot
.45012 .30007 Mdot
.44797 .37246 Mdot
.51842 .65985 Mdot
.59436 .37967 Mdot
.28499 .48136 Mdot
.4611 .37511 Mdot
.30611 .35854 Mdot
.43945 .60885 Mdot
.26113 .36998 Mdot
.4143 .33393 Mdot
.37898 .7908 Mdot
.46965 .25598 Mdot
.65769 .52878 Mdot
.46147 .6503 Mdot
.69585 .52081 Mdot
.33386 .4819 Mdot
.4971 .45822 Mdot
.60485 .37813 Mdot
.41937 .72378 Mdot
.79947 .39797 Mdot
.46137 .38578 Mdot
.68975 .5325 Mdot
.4893 .57756 Mdot
.66001 .28231 Mdot
.4715 .60329 Mdot
.44099 .71257 Mdot
.22189 .52427 Mdot
.59988 .39613 Mdot
.61424 .33488 Mdot
.45758 .66227 Mdot
.33325 .46681 Mdot
.43202 .35091 Mdot
.43312 .38938 Mdot
.33844 .78699 Mdot
.58916 .29932 Mdot
.66924 .75198 Mdot
.44918 .59735 Mdot
.38881 .34909 Mdot
.61027 .28893 Mdot
.57189 .37231 Mdot
.45895 .56814 Mdot
.44267 .3361 Mdot
.30872 .5328 Mdot
.40843 .53647 Mdot
.46373 .67296 Mdot
.41384 .62823 Mdot
.60946 .33513 Mdot
.71738 .55038 Mdot
.41106 .39165 Mdot
.54195 .59057 Mdot
.39051 .44623 Mdot
.42889 .52281 Mdot
.76851 .69023 Mdot
.67745 .52507 Mdot
.32253 .33191 Mdot
.57586 .37121 Mdot
.46957 .70173 Mdot
.33166 .49316 Mdot
.38999 .33568 Mdot
.39945 .38911 Mdot
.49767 .63223 Mdot
.45714 .68623 Mdot
.75335 .68596 Mdot
.63517 .5373 Mdot
.60568 .34804 Mdot
.5015 .60331 Mdot
.75924 .45129 Mdot
.51936 .64063 Mdot
.589 .39082 Mdot
.72631 .25377 Mdot
.4251 .60731 Mdot
.46596 .60144 Mdot
.49491 .20417 Mdot
.67663 .55273 Mdot
.6686 .49564 Mdot
.81812 .56906 Mdot
.4505 .59683 Mdot
.77936 .66401 Mdot
.68296 .52614 Mdot
.6761 .50543 Mdot
.54103 .24128 Mdot
.45333 .63312 Mdot
.52536 .53561 Mdot
.62018 .35608 Mdot
.59843 .34119 Mdot
.6512 .5507 Mdot
.49876 .55694 Mdot
.62462 .35709 Mdot
.46274 .18673 Mdot
.41851 .35877 Mdot
.73763 .3083 Mdot
.65512 .50649 Mdot
.64862 .40147 Mdot
.58434 .35299 Mdot
.71739 .75478 Mdot
.51658 .33731 Mdot
.51128 .6094 Mdot
.44747 .59928 Mdot
.28993 .48 Mdot
.51545 .58776 Mdot
.46175 .34378 Mdot
.58429 .36179 Mdot
.52741 .79275 Mdot
.67116 .52435 Mdot
.48239 .61138 Mdot
.27848 .33167 Mdot
.18678 .536 Mdot
.35103 .31462 Mdot
.63364 .51873 Mdot
.66465 .53525 Mdot
.39713 .36711 Mdot
.40128 .34473 Mdot
.44604 .62257 Mdot
.61296 .39227 Mdot
.69551 .51498 Mdot
.59525 .39304 Mdot
.42975 .34311 Mdot
.43925 .38254 Mdot
.43314 .41082 Mdot
.45218 .67772 Mdot
.44201 .37439 Mdot
.21887 .47546 Mdot
.53589 .34814 Mdot
.71229 .54311 Mdot
.8431 .57627 Mdot
.71774 .42455 Mdot
.59486 .57812 Mdot
.29648 .45469 Mdot
.44683 .39782 Mdot
.57718 .34599 Mdot
.47666 .65226 Mdot
.49147 .65637 Mdot
.6086 .26513 Mdot
.57124 .3562 Mdot
.33093 .48693 Mdot
.59136 .33014 Mdot
.32987 .48996 Mdot
.27348 .36319 Mdot
.52925 .61507 Mdot
.48363 .68407 Mdot
.58124 .36041 Mdot
.43946 .37501 Mdot
.41153 .37921 Mdot
.34594 .47338 Mdot
.44712 .47826 Mdot
.45972 .35715 Mdot
.672 .50342 Mdot
.47716 .77207 Mdot
.42073 .33325 Mdot
.48765 .6034 Mdot
.29416 .59699 Mdot
.57942 .17954 Mdot
.43138 .68653 Mdot
.54953 .23587 Mdot
.56516 .75125 Mdot
.46847 .67938 Mdot
.58677 .18226 Mdot
.5655 .35241 Mdot
.66724 .54914 Mdot
.43795 .40141 Mdot
.47972 .36456 Mdot
.53434 .55099 Mdot
.27423 .47076 Mdot
.4282 .5953 Mdot
.61769 .54105 Mdot
.6115 .53435 Mdot
.37184 .60882 Mdot
.24168 .34133 Mdot
.32811 .47685 Mdot
.32077 .46357 Mdot
.43253 .38343 Mdot
.17039 .60713 Mdot
.4635 .71896 Mdot
.3267 .48939 Mdot
.64964 .48029 Mdot
.5062 .63209 Mdot
.31606 .53786 Mdot
.59522 .51235 Mdot
.65276 .55206 Mdot
.36496 .56812 Mdot
.4493 .38297 Mdot
.65446 .54261 Mdot
.75658 .41273 Mdot
.47806 .56621 Mdot
.67218 .52243 Mdot
.59513 .39102 Mdot
.466 .273 Mdot
.6641 .50199 Mdot
.29812 .5905 Mdot
.61555 .39643 Mdot
.5566 .40893 Mdot
.39473 .55745 Mdot
.10527 .48074 Mdot
.57955 .36597 Mdot
.43596 .33509 Mdot
.41385 .36693 Mdot
.43365 .38912 Mdot
.64474 .5375 Mdot
.46138 .38635 Mdot
.6362 .53543 Mdot
.2719 .27956 Mdot
.60644 .20593 Mdot
.322 .48995 Mdot
.53119 .26605 Mdot
.63358 .52693 Mdot
.77979 .51583 Mdot
.47214 .11923 Mdot
.52088 .62093 Mdot
.58224 .4069 Mdot
.322 .48841 Mdot
.19548 .64355 Mdot
.32237 .47652 Mdot
.56384 .81684 Mdot
.58736 .64111 Mdot
.47428 .61215 Mdot
.67625 .71397 Mdot
.34186 .46373 Mdot
.63624 .56355 Mdot
.44861 .64466 Mdot
.48356 .49253 Mdot
.32044 .46919 Mdot
.28482 .46696 Mdot
.45076 .61906 Mdot
.69158 .52208 Mdot
.45141 .37017 Mdot
.59108 .34215 Mdot
.32455 .45593 Mdot
.40176 .64412 Mdot
.47287 .57817 Mdot
.51423 .60832 Mdot
.75857 .50531 Mdot
.30015 .44131 Mdot
.58411 .36531 Mdot
.37389 .19288 Mdot
.41473 .32612 Mdot
.42211 .50337 Mdot
.74162 .70996 Mdot
.65467 .43721 Mdot
.42557 .35128 Mdot
.40844 .38406 Mdot
.44756 .65558 Mdot
.49606 .7295 Mdot
.58342 .62213 Mdot
.40059 .48269 Mdot
.45895 .3978 Mdot
.42855 .38763 Mdot
.68418 .49664 Mdot
.42189 .75465 Mdot
.43117 .69108 Mdot
.61977 .33577 Mdot
.40933 .40084 Mdot
.5961 .21276 Mdot
.29168 .47625 Mdot
.60613 .63545 Mdot
.52965 .61041 Mdot
.50924 .60712 Mdot
.59695 .37431 Mdot
.5926 .38678 Mdot
.42524 .29333 Mdot
.47763 .79327 Mdot
.55449 .75532 Mdot
.6932 .3997 Mdot
.58682 .67438 Mdot
.65141 .49695 Mdot
.68601 .53436 Mdot
.52196 .29161 Mdot
.57594 .35614 Mdot
.4669 .6804 Mdot
.66063 .54006 Mdot
.32977 .53314 Mdot
.41024 .71311 Mdot
.38895 .6934 Mdot
.78271 .64052 Mdot
.47768 .63497 Mdot
.63081 .54961 Mdot
.68007 .55253 Mdot
.68561 .55417 Mdot
.65717 .34555 Mdot
.44837 .61166 Mdot
.47505 .63283 Mdot
.45433 .67236 Mdot
.65521 .25592 Mdot
.44132 .61714 Mdot
.66635 .34101 Mdot
.51447 .45575 Mdot
.70886 .60802 Mdot
.54009 .58606 Mdot
.58284 .33602 Mdot
.42977 .63554 Mdot
.3343 .4683 Mdot
.51929 .60564 Mdot
.39227 .70119 Mdot
.59872 .34836 Mdot
.43716 .55388 Mdot
.70703 .4318 Mdot
.50595 .66317 Mdot
.29478 .45172 Mdot
.67074 .44877 Mdot
.43079 .81466 Mdot
.28181 .50834 Mdot
.66958 .50387 Mdot
.42239 .3554 Mdot
.5737 .35057 Mdot
.43283 .37746 Mdot
.50903 .67001 Mdot
.50932 .2918 Mdot
.20378 .6458 Mdot
.47815 .48614 Mdot
.50237 .6513 Mdot
.46529 .71381 Mdot
.68204 .50607 Mdot
.42787 .32731 Mdot
.61739 .50796 Mdot
.44012 .65015 Mdot
.30897 .48734 Mdot
.31088 .46225 Mdot
.55134 .49023 Mdot
.32124 .7433 Mdot
.53103 .19398 Mdot
.5927 .37326 Mdot
.43927 .3971 Mdot
.33409 .49392 Mdot
.37189 .26102 Mdot
.59157 .3169 Mdot
.61358 .38367 Mdot
.60274 .34916 Mdot
.4807 .5903 Mdot
.42178 .4097 Mdot
.7125 .60773 Mdot
.41363 .32274 Mdot
.46136 .6379 Mdot
.41443 .34261 Mdot
.45174 .346 Mdot
.3032 .49046 Mdot
.60286 .3469 Mdot
.42741 .34461 Mdot
.48472 .58378 Mdot
.68281 .52944 Mdot
.64468 .33279 Mdot
.23717 .54724 Mdot
.24289 .34474 Mdot
.55752 .52815 Mdot
.67014 .55605 Mdot
.41455 .80342 Mdot
.62159 .35987 Mdot
.67913 .27878 Mdot
.21606 .53995 Mdot
.4213 .63263 Mdot
.597 .1643 Mdot
.43181 .31154 Mdot
.45218 .34953 Mdot
.46997 .66707 Mdot
.4188 .30687 Mdot
.4782 .60961 Mdot
.43942 .34423 Mdot
.53486 .33102 Mdot
.69012 .56342 Mdot
.43873 .36942 Mdot
.54479 .60754 Mdot
.45414 .65288 Mdot
.64459 .54945 Mdot
.39108 .36525 Mdot
.42348 .60539 Mdot
.37687 .82551 Mdot
.58678 .38629 Mdot
.66187 .42921 Mdot
.28083 .59747 Mdot
.57484 .37474 Mdot
.66345 .52406 Mdot
.44275 .66302 Mdot
.31567 .46298 Mdot
.63069 .52967 Mdot
.40335 .71884 Mdot
.31808 .50149 Mdot
.71867 .27298 Mdot
.679 .5535 Mdot
.45185 .35666 Mdot
.33776 .47969 Mdot
.48954 .57106 Mdot
.42532 .32227 Mdot
.43852 .26089 Mdot
.42906 .35301 Mdot
.44886 .66206 Mdot
.56585 .28176 Mdot
.60601 .34685 Mdot
.47864 .62644 Mdot
.45613 .35913 Mdot
.55091 .23759 Mdot
.46675 .58865 Mdot
.45793 .66644 Mdot
.72506 .72587 Mdot
.7503 .56461 Mdot
.31734 .47479 Mdot
.70259 .52236 Mdot
.51938 .62439 Mdot
.29684 .45839 Mdot
.28734 .41985 Mdot
.49502 .59468 Mdot
.63147 .51793 Mdot
.45654 .56871 Mdot
.39501 .35514 Mdot
.57933 .38877 Mdot
.40083 .49287 Mdot
.28932 .46379 Mdot
.14981 .43399 Mdot
.40629 .39506 Mdot
.44254 .66849 Mdot
.51824 .64016 Mdot
.28796 .65002 Mdot
.6619 .54823 Mdot
.6205 .48689 Mdot
.46552 .59497 Mdot
.66109 .25595 Mdot
.49272 .61626 Mdot
.4163 .30994 Mdot
.67005 .50604 Mdot
.45649 .60169 Mdot
.63875 .35176 Mdot
.46053 .69888 Mdot
.2942 .49428 Mdot
.46484 .22035 Mdot
.45887 .57279 Mdot
.72002 .25981 Mdot
.53342 .50337 Mdot
.44028 .36897 Mdot
.21937 .44215 Mdot
.36891 .82548 Mdot
.69417 .435 Mdot
.64686 .53546 Mdot
.22405 .64874 Mdot
.44137 .38479 Mdot
.24539 .37898 Mdot
.43714 .82848 Mdot
.4602 .65727 Mdot
.43716 .6458 Mdot
.32456 .64312 Mdot
.42576 .32427 Mdot
.3995 .3386 Mdot
.52166 .66516 Mdot
.45279 .69871 Mdot
.44318 .37951 Mdot
.43749 .59808 Mdot
.54331 .58217 Mdot
.5811 .40586 Mdot
.63954 .51205 Mdot
.60155 .39688 Mdot
.62167 .37363 Mdot
.43104 .21334 Mdot
.50476 .50097 Mdot
.58607 .38969 Mdot
.6104 .32535 Mdot
.34896 .53943 Mdot
.51806 .79766 Mdot
.32327 .4573 Mdot
.35073 .7768 Mdot
.42511 .38332 Mdot
.45485 .60667 Mdot
.69024 .54957 Mdot
.53904 .75593 Mdot
.28561 .42899 Mdot
.79783 .43139 Mdot
.45329 .67396 Mdot
.45291 .37729 Mdot
.65153 .4243 Mdot
.43558 .56798 Mdot
.4344 .41897 Mdot
.49658 .60136 Mdot
.45922 .3396 Mdot
.5691 .79462 Mdot
.35575 .2685 Mdot
.47831 .36892 Mdot
.71249 .52523 Mdot
.50557 .60806 Mdot
.61683 .55303 Mdot
.57252 .37224 Mdot
.33103 .46229 Mdot
.31438 .47028 Mdot
.4477 .63376 Mdot
.48968 .71556 Mdot
.25791 .38821 Mdot
.45264 .64038 Mdot
.50373 .63474 Mdot
.55997 .3934 Mdot
.51064 .6322 Mdot
.51459 .6477 Mdot
.48359 .67003 Mdot
.4913 .6733 Mdot
.5992 .34172 Mdot
.4541 .29196 Mdot
.54642 .56132 Mdot
.54647 .6428 Mdot
.62533 .37943 Mdot
.22868 .63148 Mdot
.6236 .35962 Mdot
.44978 .83226 Mdot
.61153 .33094 Mdot
.31011 .47574 Mdot
.24583 .64338 Mdot
.53531 .6661 Mdot
.63037 .51381 Mdot
.60897 .43578 Mdot
.33511 .47687 Mdot
.58819 .35889 Mdot
.43883 .341 Mdot
.73717 .72023 Mdot
.60844 .56766 Mdot
.73512 .55713 Mdot
.65582 .45183 Mdot
.4604 .28732 Mdot
.39579 .36919 Mdot
.6512 .56419 Mdot
.60691 .7741 Mdot
.51088 .64829 Mdot
.29831 .4576 Mdot
.44634 .6251 Mdot
.57057 .37194 Mdot
.44545 .38786 Mdot
.25658 .30576 Mdot
.30778 .46104 Mdot
.83507 .60004 Mdot
.4096 .37348 Mdot
.50276 .65534 Mdot
.62452 .35686 Mdot
.85138 .51423 Mdot
.60191 .39456 Mdot
.55273 .67462 Mdot
.67975 .54304 Mdot
.20766 .34843 Mdot
.64038 .52708 Mdot
.4112 .26458 Mdot
.85452 .39529 Mdot
.33859 .29311 Mdot
.68719 .52819 Mdot
.38192 .45686 Mdot
.49171 .63063 Mdot
.51383 .60707 Mdot
.31324 .27411 Mdot
.70271 .5325 Mdot
.51143 .6415 Mdot
.60737 .27656 Mdot
.58276 .30616 Mdot
.78295 .61102 Mdot
.39866 .36763 Mdot
.48034 .60635 Mdot
.57294 .40349 Mdot
.5648 .36875 Mdot
.41853 .39879 Mdot
.61722 .37729 Mdot
.47188 .63321 Mdot
.63447 .52686 Mdot
.38943 .41806 Mdot
.30134 .47183 Mdot
.17871 .59864 Mdot
.30553 .50915 Mdot
.42432 .35102 Mdot
.41572 .63083 Mdot
.43866 .38173 Mdot
.51878 .90037 Mdot
.48711 .62788 Mdot
.68364 .52489 Mdot
.50666 .63778 Mdot
.5058 .61245 Mdot
.47801 .67904 Mdot
.44983 .36827 Mdot
.22562 .51338 Mdot
.47183 .58523 Mdot
.60741 .37636 Mdot
.62581 .65659 Mdot
.50952 .57583 Mdot
.36437 .42066 Mdot
.38181 .67252 Mdot
.72799 .47955 Mdot
.69297 .539 Mdot
.43697 .36323 Mdot
.67204 .52739 Mdot
.68452 .26514 Mdot
.66331 .52385 Mdot
.59971 .69585 Mdot
.61831 .77215 Mdot
.69613 .72169 Mdot
.71272 .7064 Mdot
.4433 .45314 Mdot
.70366 .52766 Mdot
.26686 .48141 Mdot
.69442 .51374 Mdot
.65993 .55158 Mdot
.54266 .10161 Mdot
.61504 .5419 Mdot
.48194 .59921 Mdot
.52535 .59151 Mdot
.36951 .27716 Mdot
.28957 .55924 Mdot
.48946 .64496 Mdot
.49605 .647 Mdot
.33662 .49073 Mdot
.68265 .26854 Mdot
.52 .30335 Mdot
.75207 .5611 Mdot
.1948 .53251 Mdot
.44822 .62264 Mdot
.52128 .61119 Mdot
.55255 .59536 Mdot
.83181 .4375 Mdot
.40025 .2173 Mdot
.71486 .52026 Mdot
.54194 .64779 Mdot
.2925 .31681 Mdot
.45402 .67589 Mdot
.46604 .59144 Mdot
.48283 .63311 Mdot
.44201 .38516 Mdot
.69906 .53182 Mdot
.51398 .66417 Mdot
.27717 .65124 Mdot
.47973 .59391 Mdot
.65819 .40253 Mdot
.15525 .47578 Mdot
.4765 .60248 Mdot
.66266 .49162 Mdot
.51518 .61014 Mdot
.65109 .54647 Mdot
.63801 .55634 Mdot
.52786 .66225 Mdot
.58266 .67452 Mdot
.68655 .49668 Mdot
.46078 .63852 Mdot
.43829 .33825 Mdot
.37042 .77891 Mdot
.44527 .65343 Mdot
.32073 .45655 Mdot
.45079 .59751 Mdot
.2803 .46319 Mdot
.49574 .63817 Mdot
.41093 .39886 Mdot
.54175 .74277 Mdot
.42689 .37579 Mdot
.32765 .24737 Mdot
.42826 .41085 Mdot
.82048 .62872 Mdot
.66619 .55693 Mdot
.55111 .27343 Mdot
.75661 .34293 Mdot
.6326 .27468 Mdot
.55606 .429 Mdot
.47985 .43582 Mdot
.61255 .39197 Mdot
.66782 .54577 Mdot
.72237 .33232 Mdot
.34536 .40406 Mdot
.34521 .35796 Mdot
.46267 .36747 Mdot
.34345 .19327 Mdot
.70822 .26854 Mdot
.43761 .67336 Mdot
.63694 .73708 Mdot
.66429 .68336 Mdot
.45881 .67974 Mdot
.47683 .68148 Mdot
.46272 .32732 Mdot
.45166 .58918 Mdot
.7598 .45791 Mdot
.41456 .3516 Mdot
.33404 .47226 Mdot
.68825 .51242 Mdot
.28507 .48232 Mdot
.33575 .42912 Mdot
.48484 .42997 Mdot
.43479 .34195 Mdot
.42741 .60187 Mdot
.48478 .6497 Mdot
.64265 .54507 Mdot
.59801 .59737 Mdot
.66488 .498 Mdot
.32501 .48512 Mdot
.40808 .35718 Mdot
.54317 .17172 Mdot
.48749 .65085 Mdot
.64917 .51245 Mdot
.56451 .44231 Mdot
.51721 .62896 Mdot
.57665 .36472 Mdot
.49719 .62773 Mdot
.69181 .51781 Mdot
.51027 .63248 Mdot
.64082 .52812 Mdot
.42168 .35705 Mdot
.49421 .66451 Mdot
.47174 .66955 Mdot
.83504 .57703 Mdot
.31496 .48994 Mdot
.65267 .56524 Mdot
.39269 .51601 Mdot
.52426 .62077 Mdot
.52021 .25222 Mdot
.49279 .60118 Mdot
.72919 .53096 Mdot
.43116 .66545 Mdot
.66124 .43121 Mdot
.52725 .6667 Mdot
.44225 .63085 Mdot
.58674 .48881 Mdot
.65292 .68648 Mdot
.54996 .54346 Mdot
.5985 .32363 Mdot
.64609 .56576 Mdot
.77254 .62105 Mdot
.37409 .37436 Mdot
.38944 .36319 Mdot
.34747 .59119 Mdot
.52248 .65658 Mdot
.4722 .6105 Mdot
.73127 .48675 Mdot
.29432 .4631 Mdot
.62417 .52962 Mdot
.32934 .49027 Mdot
.80548 .62817 Mdot
.31422 .50492 Mdot
.4136 .30962 Mdot
.25864 .37307 Mdot
.50559 .17498 Mdot
.33284 .49411 Mdot
.69273 .51669 Mdot
.30263 .32013 Mdot
.51487 .65152 Mdot
.55009 .50335 Mdot
.30435 .48259 Mdot
.25679 .26276 Mdot
.51272 .6491 Mdot
.56092 .43203 Mdot
.58719 .39493 Mdot
.33292 .49291 Mdot
.61384 .40066 Mdot
.47003 .65578 Mdot
.52283 .30429 Mdot
.64787 .53462 Mdot
.62177 .39607 Mdot
.50174 .56689 Mdot
.32549 .48831 Mdot
.40601 .39821 Mdot
.63087 .39053 Mdot
.61622 .32991 Mdot
.27571 .69781 Mdot
.23899 .31529 Mdot
.40658 .36037 Mdot
.78015 .57257 Mdot
.58593 .33388 Mdot
.52263 .64435 Mdot
.70081 .29277 Mdot
.5109 .60751 Mdot
.56155 .21118 Mdot
.43521 .35558 Mdot
.4603 .29004 Mdot
.51919 .62352 Mdot
.44056 .64508 Mdot
.60961 .53609 Mdot
.41978 .37155 Mdot
.65621 .51659 Mdot
.6978 .55736 Mdot
.41952 .35735 Mdot
.65291 .52746 Mdot
.34327 .47965 Mdot
.76105 .39132 Mdot
.61434 .33885 Mdot
.61246 .36355 Mdot
.43305 .38974 Mdot
.44209 .36614 Mdot
.43615 .3764 Mdot
.49816 .62744 Mdot
.64879 .50963 Mdot
.4672 .64873 Mdot
.43299 .61067 Mdot
.64212 .64254 Mdot
.69574 .53973 Mdot
.47149 .64068 Mdot
.45349 .4945 Mdot
.55036 .66282 Mdot
.42851 .33481 Mdot
.58517 .39103 Mdot
.58929 .26982 Mdot
.45148 .25511 Mdot
.48394 .60727 Mdot
.24427 .51113 Mdot
.69337 .51446 Mdot
.3225 .46925 Mdot
.31735 .50872 Mdot
.32082 .47708 Mdot
.55817 .34929 Mdot
.68521 .55401 Mdot
.71506 .58502 Mdot
.47708 .60736 Mdot
.73079 .54468 Mdot
.71676 .51592 Mdot
.29609 .33314 Mdot
.58415 .38808 Mdot
.50827 .63867 Mdot
.40902 .49173 Mdot
.52664 .7789 Mdot
.51053 .61416 Mdot
.51496 .5788 Mdot
.21325 .49246 Mdot
.40821 .64664 Mdot
.62828 .51102 Mdot
.84577 .53117 Mdot
.49936 .57514 Mdot
.58888 .20627 Mdot
.18781 .65388 Mdot
.49277 .60745 Mdot
.4368 .63361 Mdot
.48341 .65711 Mdot
.51761 .60193 Mdot
.67983 .49252 Mdot
.32053 .55367 Mdot
.58949 .32956 Mdot
.71942 .55715 Mdot
.57558 .35909 Mdot
.45789 .39537 Mdot
.46105 .29189 Mdot
.67505 .54438 Mdot
.28969 .4786 Mdot
.17858 .52289 Mdot
.81307 .52142 Mdot
.41183 .39211 Mdot
.48006 .18654 Mdot
.30636 .48153 Mdot
.53445 .613 Mdot
.32913 .45482 Mdot
.39838 .35646 Mdot
.61522 .35529 Mdot
.45119 .57469 Mdot
.68814 .53134 Mdot
.66041 .50286 Mdot
.51303 .63647 Mdot
.24822 .36303 Mdot
.57411 .38413 Mdot
.60116 .31945 Mdot
.48736 .59081 Mdot
.49589 .57237 Mdot
.65514 .51854 Mdot
.42315 .38958 Mdot
.71288 .71388 Mdot
.31652 .4601 Mdot
.45242 .67748 Mdot
.51331 .62836 Mdot
.72702 .72229 Mdot
.61009 .37574 Mdot
.40262 .40268 Mdot
.42124 .64139 Mdot
.68482 .37897 Mdot
.42215 .62813 Mdot
.55061 .60118 Mdot
.43578 .33633 Mdot
.51463 .55106 Mdot
.48026 .68669 Mdot
.6771 .56798 Mdot
.6074 .39894 Mdot
.67767 .5226 Mdot
.67274 .56925 Mdot
.77632 .42264 Mdot
.58265 .35669 Mdot
.48547 .63456 Mdot
.58109 .38112 Mdot
.4964 .59519 Mdot
.49736 .57915 Mdot
.58869 .39098 Mdot
.65448 .51722 Mdot
.21958 .63494 Mdot
.39206 .28338 Mdot
.51054 .59001 Mdot
.51312 .67113 Mdot
.29219 .54454 Mdot
.3621 .45007 Mdot
.43968 .65002 Mdot
.68752 .50642 Mdot
.47425 .65756 Mdot
.5829 .40156 Mdot
.34279 .46746 Mdot
.68533 .52835 Mdot
.41136 .38219 Mdot
.40558 .38917 Mdot
.70484 .43504 Mdot
.45413 .34544 Mdot
.43523 .64402 Mdot
.59632 .57574 Mdot
.62154 .511 Mdot
.18189 .4843 Mdot
.41601 .3596 Mdot
.31308 .45331 Mdot
.45398 .66274 Mdot
.36133 .64916 Mdot
.5781 .40873 Mdot
.53447 .12235 Mdot
.79103 .49215 Mdot
.32158 .4475 Mdot
.72454 .57471 Mdot
.42358 .40685 Mdot
.5076 .67157 Mdot
.31861 .45633 Mdot
.39696 .36789 Mdot
.50065 .5889 Mdot
.54583 .64066 Mdot
.57787 .59817 Mdot
.48652 .40974 Mdot
.58354 .38164 Mdot
.46241 .35125 Mdot
.30447 .44668 Mdot
.46402 .39338 Mdot
.64872 .5576 Mdot
.44519 .61407 Mdot
.41725 .62959 Mdot
.42166 .39053 Mdot
.38742 .36816 Mdot
.46582 .63981 Mdot
.69474 .525 Mdot
.36983 .31363 Mdot
.45259 .62006 Mdot
.59703 .30106 Mdot
.7075 .51646 Mdot
.40173 .36266 Mdot
.43983 .63393 Mdot
.28813 .50696 Mdot
.41325 .37865 Mdot
.42575 .3353 Mdot
.52173 .61268 Mdot
.33352 .49588 Mdot
.47042 .69308 Mdot
.61912 .34708 Mdot
.33303 .20571 Mdot
.58214 .40148 Mdot
.37148 .38914 Mdot
.41127 .66786 Mdot
.68661 .3317 Mdot
.68449 .54577 Mdot
.37589 .58367 Mdot
.60583 .27637 Mdot
.54132 .57811 Mdot
.35606 .74749 Mdot
.64752 .40229 Mdot
.19523 .46067 Mdot
.37895 .73526 Mdot
.30205 .48593 Mdot
.59072 .35744 Mdot
.4366 .63371 Mdot
.58528 .40871 Mdot
.3117 .45475 Mdot
.33314 .24551 Mdot
.44504 .65539 Mdot
.67644 .5059 Mdot
.47166 .63588 Mdot
.66128 .50527 Mdot
.51674 .59525 Mdot
.45497 .69157 Mdot
.62395 .27409 Mdot
.40575 .53324 Mdot
.42217 .63167 Mdot
.88381 .52324 Mdot
.56729 .63337 Mdot
.32613 .46491 Mdot
.46035 .65304 Mdot
.46892 .40348 Mdot
.56973 .36151 Mdot
.66087 .32547 Mdot
.44387 .38458 Mdot
.61904 .33653 Mdot
.65405 .5234 Mdot
.43227 .35741 Mdot
.41599 .39559 Mdot
.50598 .54996 Mdot
.3336 .45286 Mdot
.60603 .35987 Mdot
.45356 .60217 Mdot
.44352 .65017 Mdot
.78795 .5661 Mdot
.3316 .40255 Mdot
.62851 .60479 Mdot
.80909 .36822 Mdot
.68495 .55972 Mdot
.33324 .47967 Mdot
.45092 .37203 Mdot
.42862 .62518 Mdot
.47322 .6277 Mdot
.53349 .25897 Mdot
.68241 .4977 Mdot
.49486 .46303 Mdot
.62283 .60956 Mdot
.32956 .53243 Mdot
.36793 .54554 Mdot
.68883 .51107 Mdot
.36241 .54539 Mdot
.30783 .44015 Mdot
.28988 .74694 Mdot
.40818 .52684 Mdot
.58439 .39322 Mdot
.35099 .54451 Mdot
.62482 .53001 Mdot
.48144 .5853 Mdot
.44213 .33939 Mdot
.45099 .34432 Mdot
.67193 .51755 Mdot
.44553 .41434 Mdot
.29852 .48708 Mdot
.43641 .6175 Mdot
.7847 .52492 Mdot
.73083 .41053 Mdot
.4388 .39394 Mdot
.48344 .55278 Mdot
.60163 .3482 Mdot
.51433 .63543 Mdot
.31481 .49727 Mdot
.57875 .37138 Mdot
.52293 .80586 Mdot
.57048 .30675 Mdot
.44976 .65299 Mdot
.73195 .72072 Mdot
.58401 .35788 Mdot
.47916 .74314 Mdot
.45412 .61198 Mdot
.61966 .36284 Mdot
.39462 .62326 Mdot
.45796 .27143 Mdot
.50512 .48812 Mdot
.43906 .83064 Mdot
.53512 .47569 Mdot
.45568 .37674 Mdot
.45867 .28077 Mdot
.61673 .25627 Mdot
.58632 .33799 Mdot
.39062 .39177 Mdot
.50255 .50336 Mdot
.61303 .3999 Mdot
.53278 .62354 Mdot
.49608 .60433 Mdot
.39151 .22194 Mdot
.61876 .43114 Mdot
.39853 .26508 Mdot
.71714 .45592 Mdot
.52509 .62103 Mdot
.44788 .68318 Mdot
.47112 .62455 Mdot
.64699 .49746 Mdot
.59178 .382 Mdot
.86453 .53075 Mdot
.57296 .37267 Mdot
.6195 .63882 Mdot
.42881 .38591 Mdot
.39872 .3659 Mdot
.48076 .60433 Mdot
.568 .43421 Mdot
.44607 .77135 Mdot
.46732 .63444 Mdot
.35396 .45951 Mdot
.3951 .23289 Mdot
.51098 .58202 Mdot
.6885 .5388 Mdot
.53281 .56329 Mdot
.4048 .67164 Mdot
.61317 .33735 Mdot
.29301 .47622 Mdot
.37466 .63107 Mdot
.6133 .35309 Mdot
.47204 .61196 Mdot
.69111 .35697 Mdot
.50142 .61834 Mdot
.5094 .59078 Mdot
.60142 .62182 Mdot
.32247 .50741 Mdot
.42908 .36705 Mdot
.31939 .47941 Mdot
.66338 .54982 Mdot
.46608 .09095 Mdot
.31141 .5048 Mdot
.48512 .7915 Mdot
.35767 .22192 Mdot
.35371 .54143 Mdot
.6223 .53135 Mdot
.31784 .4494 Mdot
.57871 .39084 Mdot
.36937 .78051 Mdot
.5525 .66705 Mdot
.63929 .40595 Mdot
.4572 .6173 Mdot
.63008 .57036 Mdot
.6516 .50221 Mdot
.6237 .39154 Mdot
.64048 .55899 Mdot
.52587 .53801 Mdot
.4993 .58558 Mdot
.58844 .34241 Mdot
.70049 .39905 Mdot
.58941 .32773 Mdot
.3997 .46147 Mdot
.45653 .64858 Mdot
.68723 .52406 Mdot
.4738 .68592 Mdot
.65762 .48639 Mdot
.40843 .40623 Mdot
.42212 .6099 Mdot
.29762 .48759 Mdot
.6803 .33101 Mdot
.40468 .36423 Mdot
.35859 .53223 Mdot
.64534 .54585 Mdot
.55361 .35176 Mdot
.64184 .54923 Mdot
.62505 .50391 Mdot
.62408 .35814 Mdot
.62174 .55016 Mdot
.43642 .62885 Mdot
.50175 .49328 Mdot
.64359 .54023 Mdot
.59781 .36753 Mdot
.29675 .46939 Mdot
.64512 .52475 Mdot
.42441 .30743 Mdot
.4516 .66195 Mdot
.44801 .36842 Mdot
.34403 .43461 Mdot
.61785 .56555 Mdot
.34154 .49403 Mdot
.39184 .35593 Mdot
.28471 .46682 Mdot
.19971 .42716 Mdot
.62881 .34263 Mdot
.58772 .6466 Mdot
.35059 .44765 Mdot
.63201 .51141 Mdot
.217 .5492 Mdot
.43801 .60463 Mdot
.45392 .66435 Mdot
.28219 .46192 Mdot
.65176 .50211 Mdot
.23774 .71702 Mdot
.49207 .72086 Mdot
.41343 .45259 Mdot
.56251 .36318 Mdot
.8334 .61325 Mdot
.40235 .45615 Mdot
.1722 .61833 Mdot
.48896 .55638 Mdot
.39843 .33789 Mdot
.48294 .6139 Mdot
.57793 .25463 Mdot
.31976 .48839 Mdot
.3671 .41806 Mdot
.42501 .67151 Mdot
.42822 .36104 Mdot
.47916 .66781 Mdot
.57817 .49271 Mdot
.44452 .73082 Mdot
.29826 .45364 Mdot
.26712 .35047 Mdot
.61794 .56345 Mdot
.30257 .47389 Mdot
.40416 .35292 Mdot
.40408 .55045 Mdot
.50132 .58804 Mdot
.53297 .62742 Mdot
.3271 .53203 Mdot
.64241 .51171 Mdot
.45355 .35807 Mdot
.61873 .35048 Mdot
.29199 .47046 Mdot
.48323 .64917 Mdot
.43164 .61099 Mdot
.52703 .24736 Mdot
.59737 .34565 Mdot
.42627 .3259 Mdot
.59635 .40001 Mdot
.42623 .40413 Mdot
.4742 .58338 Mdot
.40249 .38106 Mdot
.53359 .64803 Mdot
.66005 .3741 Mdot
.59728 .63369 Mdot
.64781 .70122 Mdot
.43133 .35172 Mdot
.5365 .80149 Mdot
.59445 .34744 Mdot
.60613 .39106 Mdot
.41404 .19717 Mdot
.56294 .65306 Mdot
.79722 .54129 Mdot
.31782 .70461 Mdot
.59724 .33966 Mdot
.60287 .35611 Mdot
.4471 .3676 Mdot
.62336 .55209 Mdot
.67448 .56197 Mdot
.42375 .40185 Mdot
.28868 .59764 Mdot
.62506 .52832 Mdot
.33615 .75339 Mdot
.7886 .59451 Mdot
.54313 .6119 Mdot
.39206 .31467 Mdot
.3164 .46517 Mdot
.30175 .59492 Mdot
.57018 .49695 Mdot
.4437 .65629 Mdot
.36047 .60678 Mdot
.42802 .3898 Mdot
.56924 .42552 Mdot
.43663 .82195 Mdot
.48686 .66626 Mdot
.45356 .60825 Mdot
.47471 .61851 Mdot
.34091 .45739 Mdot
.54215 .71447 Mdot
.43926 .62201 Mdot
.28605 .59733 Mdot
.52117 .62877 Mdot
.4518 .73781 Mdot
.31658 .47268 Mdot
.48202 .51007 Mdot
.34551 .42016 Mdot
.83856 .5455 Mdot
.44453 .72329 Mdot
.61697 .34057 Mdot
.35648 .37175 Mdot
.60705 .39407 Mdot
.61443 .69342 Mdot
.39332 .52822 Mdot
.6916 .55639 Mdot
.44208 .65274 Mdot
.42286 .35059 Mdot
.65217 .50234 Mdot
.48517 .27372 Mdot
.50922 .09488 Mdot
.6076 .32988 Mdot
.31364 .81401 Mdot
.61781 .37171 Mdot
.41767 .39605 Mdot
.65623 .51886 Mdot
.59681 .78204 Mdot
.76755 .49203 Mdot
.64619 .52621 Mdot
.21356 .66654 Mdot
.70879 .49655 Mdot
.38439 .59773 Mdot
.61198 .53826 Mdot
.59813 .36181 Mdot
.56748 .41422 Mdot
.5128 .52911 Mdot
.46429 .59321 Mdot
.48692 .43494 Mdot
.44177 .76655 Mdot
.43687 .60623 Mdot
.41269 .3529 Mdot
.58128 .63076 Mdot
.35663 .5902 Mdot
.62035 .54332 Mdot
.59168 .3055 Mdot
.44757 .61514 Mdot
.51519 .62003 Mdot
.49364 .58653 Mdot
.8001 .47166 Mdot
.28551 .74433 Mdot
.47507 .58481 Mdot
.52209 .60461 Mdot
.43013 .35849 Mdot
.36283 .48228 Mdot
.33965 .29777 Mdot
.74593 .58882 Mdot
.48751 .67107 Mdot
.30657 .47101 Mdot
.28765 .45021 Mdot
.43807 .5986 Mdot
.49389 .49724 Mdot
.69292 .34763 Mdot
.4514 .60344 Mdot
.5794 .6288 Mdot
.49085 .34551 Mdot
.42171 .32364 Mdot
.41471 .38374 Mdot
.63737 .56496 Mdot
.42483 .39605 Mdot
.41162 .40127 Mdot
.537 .78868 Mdot
.5184 .46826 Mdot
.65608 .35229 Mdot
.32674 .48314 Mdot
.4805 .62623 Mdot
.56165 .55963 Mdot
.68558 .36643 Mdot
.61653 .38972 Mdot
.67833 .53519 Mdot
.56621 .37139 Mdot
.26724 .46649 Mdot
.78357 .46678 Mdot
.45884 .38594 Mdot
.60685 .33913 Mdot
.62681 .32946 Mdot
.30781 .46937 Mdot
.60125 .40868 Mdot
.52423 .36014 Mdot
.4713 .57517 Mdot
.61513 .75047 Mdot
.46069 .63599 Mdot
.17446 .5395 Mdot
.60638 .35093 Mdot
.55739 .38719 Mdot
.46735 .60447 Mdot
.41206 .37532 Mdot
.39843 .5927 Mdot
.46932 .5924 Mdot
.4256 .395 Mdot
.43413 .67173 Mdot
.29773 .50411 Mdot
.70283 .5156 Mdot
.76541 .49477 Mdot
.34668 .18861 Mdot
.33057 .45179 Mdot
.49201 .26942 Mdot
.44835 .66783 Mdot
.22653 .34826 Mdot
.64225 .52413 Mdot
.42852 .65195 Mdot
.36562 .56566 Mdot
.63506 .53864 Mdot
.66878 .52981 Mdot
.50071 .63071 Mdot
.58855 .39725 Mdot
.40299 .36443 Mdot
.3119 .46795 Mdot
.16104 .56201 Mdot
.45243 .62846 Mdot
.47159 .66573 Mdot
.30457 .47719 Mdot
.58215 .35347 Mdot
.42358 .62308 Mdot
.3077 .6581 Mdot
.26901 .74754 Mdot
.61989 .36957 Mdot
.50746 .65476 Mdot
.60306 .71783 Mdot
.46283 .72551 Mdot
.18158 .38581 Mdot
.53803 .50342 Mdot
.43427 .3674 Mdot
.43933 .70304 Mdot
.66653 .19898 Mdot
.29363 .4722 Mdot
.8094 .52568 Mdot
.51573 .62145 Mdot
.49302 .6502 Mdot
.67511 .49755 Mdot
.46552 .64654 Mdot
.67711 .54178 Mdot
.43895 .16174 Mdot
.75624 .69734 Mdot
.65221 .56262 Mdot
.62436 .52004 Mdot
.37714 .65976 Mdot
.62222 .30722 Mdot
.66866 .51846 Mdot
.49804 .57752 Mdot
.45131 .50531 Mdot
.71623 .48427 Mdot
.31549 .45119 Mdot
.2289 .4984 Mdot
.52357 .68434 Mdot
.2577 .512 Mdot
.22744 .63386 Mdot
.56804 .5964 Mdot
.39915 .47556 Mdot
.61004 .38141 Mdot
.48766 .66675 Mdot
.45005 .34223 Mdot
.45038 .34013 Mdot
.53502 .64853 Mdot
.49207 .62398 Mdot
.65676 .54867 Mdot
.30099 .46126 Mdot
.57877 .343 Mdot
.49224 .64836 Mdot
.38024 .57617 Mdot
.28718 .47318 Mdot
.63314 .55824 Mdot
.61604 .65473 Mdot
.31497 .51409 Mdot
.47668 .69705 Mdot
.46223 .59662 Mdot
.47766 .63502 Mdot
.51197 .52748 Mdot
.59452 .3852 Mdot
.23553 .62891 Mdot
.52479 .5957 Mdot
.81289 .61852 Mdot
.6485 .32491 Mdot
.43188 .68895 Mdot
.64438 .55499 Mdot
.58649 .30912 Mdot
.44099 .41063 Mdot
.76783 .37972 Mdot
.44924 .6483 Mdot
.25843 .35476 Mdot
.38523 .22668 Mdot
.39304 .38915 Mdot
.67918 .488 Mdot
.32443 .47751 Mdot
.47047 .63307 Mdot
.57924 .67652 Mdot
.49281 .60412 Mdot
.297 .43902 Mdot
.41915 .33637 Mdot
.60791 .38434 Mdot
.19002 .48037 Mdot
.45817 .34686 Mdot
.6712 .52776 Mdot
.6408 .81172 Mdot
.67901 .54151 Mdot
.67158 .56269 Mdot
.62812 .65338 Mdot
.59505 .38657 Mdot
.59578 .1472 Mdot
.46347 .16616 Mdot
.46867 .58134 Mdot
.58668 .35015 Mdot
.68044 .51613 Mdot
.51458 .64178 Mdot
.69306 .48646 Mdot
.6947 .54833 Mdot
.48815 .5803 Mdot
.49097 .65523 Mdot
.34297 .27591 Mdot
.39999 .78169 Mdot
.32486 .47926 Mdot
.67451 .55156 Mdot
.76562 .46775 Mdot
.51715 .64077 Mdot
.47613 .60672 Mdot
.55523 .221 Mdot
.33828 .45839 Mdot
.7494 .41694 Mdot
.51543 .62067 Mdot
.6735 .77103 Mdot
.54181 .56318 Mdot
.69301 .50143 Mdot
.61126 .39011 Mdot
.83188 .5638 Mdot
.51947 .3633 Mdot
.67528 .5417 Mdot
.29097 .4864 Mdot
.61033 .53203 Mdot
.51057 .79874 Mdot
.57524 .36089 Mdot
.69185 .51758 Mdot
.40227 .49127 Mdot
.58722 .37505 Mdot
.60972 .34908 Mdot
.6518 .63974 Mdot
.42353 .4155 Mdot
.32935 .44823 Mdot
.60511 .35754 Mdot
.67282 .27319 Mdot
.59285 .36637 Mdot
.44217 .17042 Mdot
.49337 .66273 Mdot
.33157 .61354 Mdot
.36906 .38643 Mdot
.49855 .70544 Mdot
.60445 .34501 Mdot
.33989 .48481 Mdot
.50222 .59029 Mdot
.619 .55654 Mdot
.30267 .4573 Mdot
.61863 .41848 Mdot
.44321 .381 Mdot
.63697 .54824 Mdot
.5982 .43036 Mdot
.66361 .50367 Mdot
.72171 .33296 Mdot
.33308 .22183 Mdot
.38761 .70981 Mdot
.76988 .48787 Mdot
.50284 .58783 Mdot
.28623 .70771 Mdot
.51006 .65689 Mdot
.50018 .62287 Mdot
.40596 .35686 Mdot
.34399 .60699 Mdot
.65591 .51691 Mdot
.19404 .62175 Mdot
.61177 .33793 Mdot
.83883 .55224 Mdot
.44103 .71762 Mdot
.44502 .6725 Mdot
.64705 .54084 Mdot
.69355 .50614 Mdot
.64891 .67453 Mdot
.47195 .36557 Mdot
.45015 .67322 Mdot
.48024 .56361 Mdot
.54138 .64112 Mdot
.61565 .34848 Mdot
.43708 .50272 Mdot
.45475 .38178 Mdot
.28402 .26652 Mdot
.41549 .33712 Mdot
.24634 .47818 Mdot
.62179 .55476 Mdot
.31046 .50448 Mdot
.47446 .60469 Mdot
.59358 .59062 Mdot
.67781 .49593 Mdot
.28272 .46261 Mdot
.33606 .48662 Mdot
.48336 .24603 Mdot
.58803 .39019 Mdot
.46583 .59025 Mdot
.43945 .6313 Mdot
.47235 .64716 Mdot
.49565 .62727 Mdot
.60704 .33085 Mdot
.49399 .5893 Mdot
.58929 .41697 Mdot
.77521 .38132 Mdot
.3282 .64771 Mdot
.5416 .47615 Mdot
.51247 .19704 Mdot
.62011 .54006 Mdot
.67675 .28742 Mdot
.40457 .64049 Mdot
.75665 .32734 Mdot
.32351 .2615 Mdot
.49218 .56902 Mdot
.4028 .38629 Mdot
.39543 .67625 Mdot
.46142 .3651 Mdot
.17379 .64194 Mdot
.58005 .2378 Mdot
.38795 .77551 Mdot
.44424 .65199 Mdot
.49766 .49185 Mdot
.64373 .2433 Mdot
.51756 .65033 Mdot
.5201 .237 Mdot
.55905 .20966 Mdot
.29311 .32222 Mdot
.33142 .4957 Mdot
.44567 .63634 Mdot
.55709 .55186 Mdot
.43629 .62388 Mdot
.48131 .61039 Mdot
.49407 .58784 Mdot
.5685 .35411 Mdot
.42874 .644 Mdot
.50876 .59937 Mdot
.257 .39826 Mdot
.38036 .54152 Mdot
.40753 .33049 Mdot
.39593 .20539 Mdot
.31431 .50554 Mdot
.64643 .54384 Mdot
.2753 .7245 Mdot
.58398 .39231 Mdot
.65601 .67572 Mdot
.48803 .63007 Mdot
.36289 .279 Mdot
.5751 .302 Mdot
.293 .48717 Mdot
.39461 .36387 Mdot
.3931 .79329 Mdot
.41881 .35283 Mdot
.56931 .32212 Mdot
.41038 .37104 Mdot
.42099 .68866 Mdot
.65984 .54962 Mdot
.45214 .59223 Mdot
.60657 .36308 Mdot
.4122 .38664 Mdot
.29122 .55321 Mdot
.47356 .6235 Mdot
.41983 .35801 Mdot
.45614 .59097 Mdot
.74627 .54734 Mdot
.76313 .59586 Mdot
.40514 .39464 Mdot
.63254 .35534 Mdot
.60332 .37682 Mdot
.31994 .49982 Mdot
.63691 .54387 Mdot
.67598 .53812 Mdot
.57991 .36962 Mdot
.5974 .53504 Mdot
.48989 .67104 Mdot
.50628 .64866 Mdot
.82047 .58938 Mdot
.43347 .63045 Mdot
.40888 .54896 Mdot
.41155 .49366 Mdot
.63355 .56219 Mdot
.45739 .68499 Mdot
.50558 .63122 Mdot
.45049 .65613 Mdot
.759 .53962 Mdot
.42735 .39313 Mdot
.48957 .66495 Mdot
.33769 .47727 Mdot
.44184 .2956 Mdot
.51491 .63476 Mdot
.52614 .5496 Mdot
.6783 .53691 Mdot
.81156 .38821 Mdot
.61562 .37661 Mdot
.40584 .35155 Mdot
.4326 .35172 Mdot
.2278 .61037 Mdot
.64717 .26776 Mdot
.41499 .49306 Mdot
.2196 .32023 Mdot
.625 .27528 Mdot
.33051 .48809 Mdot
.39916 .32499 Mdot
.59523 .43466 Mdot
.44036 .3524 Mdot
.59952 .32793 Mdot
.50352 .656 Mdot
.49059 .66954 Mdot
.65221 .20323 Mdot
.42568 .61556 Mdot
.32191 .47304 Mdot
.58124 .33685 Mdot
.62916 .52461 Mdot
.29089 .48278 Mdot
.59872 .40006 Mdot
.63869 .56432 Mdot
.49483 .56911 Mdot
.51849 .58559 Mdot
.67432 .53614 Mdot
.67629 .49923 Mdot
.46503 .59822 Mdot
.5443 .30719 Mdot
.62807 .51679 Mdot
.68967 .51103 Mdot
.4538 .39088 Mdot
.45304 .34542 Mdot
.55717 .6084 Mdot
.59545 .34948 Mdot
.50634 .59585 Mdot
.42992 .35465 Mdot
.31151 .50427 Mdot
.65156 .51663 Mdot
.51347 .59451 Mdot
.50521 .63979 Mdot
.30654 .46838 Mdot
.30782 .49957 Mdot
.3178 .49703 Mdot
.59188 .42558 Mdot
.46621 .65353 Mdot
.65903 .52104 Mdot
.59294 .39037 Mdot
.29637 .44631 Mdot
.32778 .45544 Mdot
.41581 .31675 Mdot
.43005 .63262 Mdot
.39054 .4188 Mdot
.68366 .21013 Mdot
.77684 .66299 Mdot
.4041 .39902 Mdot
.44591 .40795 Mdot
.25576 .54274 Mdot
.63462 .45083 Mdot
.57529 .36978 Mdot
.3633 .45868 Mdot
.39201 .71173 Mdot
.4591 .57477 Mdot
.51335 .58594 Mdot
.4446 .68415 Mdot
.32267 .49622 Mdot
.34708 .63014 Mdot
.67297 .54522 Mdot
.4699 .51808 Mdot
.28647 .47221 Mdot
.39511 .34988 Mdot
.39342 .32519 Mdot
.41076 .34031 Mdot
.5331 .60623 Mdot
.65437 .70821 Mdot
.66728 .2906 Mdot
.30365 .6843 Mdot
.60036 .3448 Mdot
.56347 .56526 Mdot
.23858 .33555 Mdot
.66946 .53381 Mdot
.46377 .38845 Mdot
.33374 .48445 Mdot
.67296 .49968 Mdot
.5667 .37833 Mdot
.60334 .3586 Mdot
.44004 .39359 Mdot
.43994 .39105 Mdot
.442 .34549 Mdot
.70232 .54111 Mdot
.62193 .55313 Mdot
.45064 .64995 Mdot
.64388 .51724 Mdot
.79739 .40424 Mdot
.27596 .48133 Mdot
.47312 .40402 Mdot
.59249 .35452 Mdot
.61675 .54576 Mdot
.47062 .62591 Mdot
.72581 .54011 Mdot
.67116 .41182 Mdot
.32518 .46272 Mdot
.77513 .58187 Mdot
.15701 .58808 Mdot
.45251 .59368 Mdot
.60148 .38262 Mdot
.79533 .5084 Mdot
.47172 .6194 Mdot
.45149 .36481 Mdot
.22054 .46054 Mdot
.48155 .4086 Mdot
.47472 .59266 Mdot
.46327 .57819 Mdot
.61895 .34202 Mdot
.28044 .27085 Mdot
.45027 .63967 Mdot
.75403 .40205 Mdot
.61209 .31208 Mdot
.45503 .3699 Mdot
.40324 .84885 Mdot
.31359 .52371 Mdot
.29792 .59797 Mdot
.44924 .39174 Mdot
.50582 .6109 Mdot
.46382 .37167 Mdot
.33522 .47022 Mdot
.39625 .36367 Mdot
.68431 .53931 Mdot
.39913 .34863 Mdot
.47235 .66505 Mdot
.67306 .51896 Mdot
.58381 .3573 Mdot
.83198 .54426 Mdot
.2462 .44337 Mdot
.41358 .37689 Mdot
.40949 .39598 Mdot
.44718 .67759 Mdot
.75612 .45012 Mdot
.52173 .66053 Mdot
.50936 .65132 Mdot
.58737 .34556 Mdot
.63635 .54019 Mdot
.62168 .3654 Mdot
.50902 .68553 Mdot
.33787 .67165 Mdot
.59672 .39848 Mdot
.34451 .29187 Mdot
.30749 .48362 Mdot
.53593 .42829 Mdot
.47423 .62859 Mdot
.61055 .40454 Mdot
.46353 .65462 Mdot
.67076 .54704 Mdot
.55765 .46832 Mdot
.50296 .3125 Mdot
.61213 .35945 Mdot
.21896 .42246 Mdot
.30822 .64 Mdot
.55007 .55701 Mdot
.60793 .3905 Mdot
.35716 .57393 Mdot
.4193 .39654 Mdot
.31213 .45837 Mdot
.28753 .49483 Mdot
.28472 .47347 Mdot
.54025 .58313 Mdot
.43991 .71818 Mdot
.34506 .48855 Mdot
.57133 .35993 Mdot
.29957 .45331 Mdot
.56321 .19029 Mdot
.19528 .62638 Mdot
.31515 .48663 Mdot
.45498 .61421 Mdot
.39982 .62751 Mdot
.35204 .53931 Mdot
.45005 .26732 Mdot
.37432 .76306 Mdot
.47284 .2188 Mdot
.4763 .59483 Mdot
.70935 .51682 Mdot
.68815 .55007 Mdot
.81571 .46065 Mdot
.47798 .78458 Mdot
.74955 .69758 Mdot
.64359 .56647 Mdot
.56259 .27707 Mdot
.63155 .55438 Mdot
.46683 .58672 Mdot
.50971 .6463 Mdot
.67308 .56573 Mdot
.34712 .66568 Mdot
.53549 .2771 Mdot
.17295 .51637 Mdot
.66845 .5018 Mdot
.60792 .39814 Mdot
.62445 .37697 Mdot
.60825 .34625 Mdot
.80335 .5726 Mdot
.64874 .5375 Mdot
.48632 .64395 Mdot
.42777 .34999 Mdot
.48162 .67244 Mdot
.58569 .37768 Mdot
.19784 .65584 Mdot
.64184 .52989 Mdot
.44363 .61858 Mdot
.47146 .54337 Mdot
.44155 .38723 Mdot
.30867 .47533 Mdot
.74191 .54296 Mdot
.73433 .71141 Mdot
.60989 .33834 Mdot
.6211 .56779 Mdot
.60892 .43821 Mdot
.18196 .51442 Mdot
.47141 .55595 Mdot
.4299 .58993 Mdot
.15991 .56691 Mdot
.62698 .80163 Mdot
.44329 .66058 Mdot
.39548 .37498 Mdot
.53836 .25535 Mdot
.5149 .63062 Mdot
.68332 .5508 Mdot
.30829 .51197 Mdot
.28891 .46235 Mdot
.55768 .58891 Mdot
.73897 .52254 Mdot
.56379 .49118 Mdot
.48887 .63301 Mdot
.46724 .69647 Mdot
.45469 .37842 Mdot
.58167 .24803 Mdot
.80534 .62888 Mdot
.30245 .49954 Mdot
.44372 .59575 Mdot
.20876 .62272 Mdot
.65951 .49817 Mdot
.39437 .38972 Mdot
.58456 .4049 Mdot
.71688 .51827 Mdot
.39385 .36661 Mdot
.50888 .5848 Mdot
.42912 .60949 Mdot
.61945 .38292 Mdot
.69548 .50451 Mdot
.31683 .49554 Mdot
.4044 .35657 Mdot
.30339 .49504 Mdot
.63717 .53717 Mdot
.63085 .52748 Mdot
.50206 .54176 Mdot
.45348 .56288 Mdot
.41091 .38068 Mdot
.54244 .62591 Mdot
.51866 .34717 Mdot
.15705 .43733 Mdot
.60907 .43582 Mdot
.42654 .63602 Mdot
.60868 .54182 Mdot
.61445 .35265 Mdot
.49097 .65235 Mdot
.17982 .6338 Mdot
.52159 .63381 Mdot
.57319 .34231 Mdot
.50134 .80542 Mdot
.30408 .49195 Mdot
.53305 .52458 Mdot
.31518 .2759 Mdot
.43225 .62371 Mdot
.44151 .36118 Mdot
.5035 .5559 Mdot
.58502 .39759 Mdot
.61989 .5471 Mdot
.14545 .44766 Mdot
.59522 .36995 Mdot
.44004 .61099 Mdot
.29051 .47439 Mdot
.62184 .51824 Mdot
.54204 .50825 Mdot
.47584 .49486 Mdot
.41083 .58759 Mdot
.45861 .68223 Mdot
.50723 .62514 Mdot
.31228 .67092 Mdot
.4152 .34579 Mdot
.68711 .51273 Mdot
.60618 .38005 Mdot
.57792 .36994 Mdot
.43394 .39295 Mdot
.39663 .42549 Mdot
.53481 .42809 Mdot
.76177 .27854 Mdot
.46488 .37752 Mdot
.30372 .50317 Mdot
.7545 .42974 Mdot
.41757 .34748 Mdot
.41794 .36152 Mdot
.45709 .38702 Mdot
.40709 .48256 Mdot
.62426 .52899 Mdot
.5102 .58572 Mdot
.69267 .53896 Mdot
.50754 .6095 Mdot
.58209 .32753 Mdot
.60969 .36019 Mdot
.63517 .53229 Mdot
.17373 .47549 Mdot
.59361 .75445 Mdot
.46576 .61335 Mdot
.22821 .34686 Mdot
.41732 .65158 Mdot
.29438 .5349 Mdot
.42346 .66121 Mdot
.42011 .3802 Mdot
.53524 .6209 Mdot
.54681 .59654 Mdot
.81494 .49111 Mdot
.5927 .35184 Mdot
.40962 .32363 Mdot
.44296 .69263 Mdot
.47479 .69611 Mdot
.70515 .53861 Mdot
.67864 .50051 Mdot
.2845 .48951 Mdot
.43169 .53827 Mdot
.58086 .35917 Mdot
.5346 .16496 Mdot
.46345 .59371 Mdot
.26796 .51076 Mdot
.73156 .67931 Mdot
.48802 .6539 Mdot
.28705 .29812 Mdot
.65603 .70003 Mdot
.47169 .63172 Mdot
.45521 .452 Mdot
.59609 .3468 Mdot
.37499 .72105 Mdot
.52137 .62467 Mdot
.4477 .38273 Mdot
.6268 .55677 Mdot
.66889 .49529 Mdot
.2947 .50039 Mdot
.71102 .27082 Mdot
.62267 .36122 Mdot
.62394 .54105 Mdot
.48112 .62125 Mdot
.60133 .38471 Mdot
.45798 .39047 Mdot
.43688 .662 Mdot
.56628 .80862 Mdot
.6466 .5143 Mdot
.4338 .67265 Mdot
.73526 .3722 Mdot
.2657 .57047 Mdot
.50772 .81746 Mdot
.611 .37534 Mdot
.32202 .49906 Mdot
.54612 .57613 Mdot
.60172 .5137 Mdot
.49233 .68311 Mdot
.31472 .61323 Mdot
.54889 .18956 Mdot
.3436 .47283 Mdot
.46314 .60553 Mdot
.48542 .64753 Mdot
.60747 .46683 Mdot
.29576 .4938 Mdot
.44225 .64663 Mdot
.64342 .46049 Mdot
.66288 .50634 Mdot
.44234 .40262 Mdot
.63558 .51811 Mdot
.45762 .61647 Mdot
.44611 .56498 Mdot
.67821 .49832 Mdot
.17983 .41712 Mdot
.31059 .51557 Mdot
.60638 .38905 Mdot
.44471 .59 Mdot
.52992 .61131 Mdot
.87671 .48262 Mdot
.39031 .38739 Mdot
.52806 .31271 Mdot
.34619 .30471 Mdot
.21795 .60729 Mdot
.34797 .51695 Mdot
.4687 .82407 Mdot
.619 .80588 Mdot
.4286 .6455 Mdot
.57666 .54106 Mdot
.70313 .32779 Mdot
.59124 .34571 Mdot
.66413 .24042 Mdot
.46341 .59315 Mdot
.48299 .61189 Mdot
.41632 .40818 Mdot
.48897 .30722 Mdot
.75693 .69041 Mdot
.69097 .56802 Mdot
.31093 .49343 Mdot
.66478 .55195 Mdot
.50357 .57994 Mdot
.48076 .46161 Mdot
.38922 .36202 Mdot
.26503 .48705 Mdot
.44544 .61409 Mdot
.76166 .54257 Mdot
.67926 .41718 Mdot
.58903 .38666 Mdot
.43488 .35284 Mdot
.7044 .73348 Mdot
.42824 .62831 Mdot
.609 .40719 Mdot
.45553 .62859 Mdot
.35532 .51535 Mdot
.49314 .69888 Mdot
.32916 .48647 Mdot
.51748 .61102 Mdot
.35751 .35488 Mdot
.85716 .59845 Mdot
.3289 .44357 Mdot
.7117 .53117 Mdot
.40171 .40782 Mdot
.42503 .39255 Mdot
.68478 .50316 Mdot
.4192 .3873 Mdot
.66359 .65983 Mdot
.55565 .79441 Mdot
.30673 .48574 Mdot
.5543 .6218 Mdot
.31482 .48173 Mdot
.4042 .40249 Mdot
.47377 .59347 Mdot
.14106 .51181 Mdot
.40469 .37754 Mdot
.66114 .78791 Mdot
.59004 .36566 Mdot
.38626 .37659 Mdot
.52061 .62924 Mdot
.65953 .43394 Mdot
.45822 .34768 Mdot
.52914 .29573 Mdot
.45046 .65536 Mdot
.63059 .52493 Mdot
.5089 .63537 Mdot
.47265 .58073 Mdot
.40082 .33577 Mdot
.50203 .59715 Mdot
.59828 .40061 Mdot
.65386 .56587 Mdot
.35488 .76531 Mdot
.59671 .22384 Mdot
.44049 .6451 Mdot
.47832 .62101 Mdot
.62733 .50428 Mdot
.53072 .62733 Mdot
.60834 .33161 Mdot
.23548 .24108 Mdot
.30738 .48293 Mdot
.3852 .35801 Mdot
.35231 .33096 Mdot
.47568 .56728 Mdot
.49873 .58975 Mdot
.20395 .70157 Mdot
.33083 .66228 Mdot
.60537 .39453 Mdot
.5431 .63682 Mdot
.46567 .36147 Mdot
.30082 .46299 Mdot
.57828 .34647 Mdot
.47453 .63638 Mdot
.47127 .60478 Mdot
.31513 .50116 Mdot
.27389 .52088 Mdot
.78724 .60643 Mdot
.62021 .39372 Mdot
.41267 .67089 Mdot
.43912 .31091 Mdot
.49176 .67178 Mdot
.79518 .56395 Mdot
.68914 .52408 Mdot
.60761 .33695 Mdot
.22828 .62605 Mdot
.42759 .63441 Mdot
.61327 .39006 Mdot
.58255 .35684 Mdot
.48368 .68609 Mdot
.62108 .57384 Mdot
.66608 .56536 Mdot
.65983 .50479 Mdot
.52875 .12938 Mdot
.31068 .58849 Mdot
.44207 .34552 Mdot
.59336 .34686 Mdot
.41597 .40261 Mdot
.29545 .43916 Mdot
.48715 .4862 Mdot
.41071 .39896 Mdot
.64151 .51067 Mdot
.38482 .36704 Mdot
.46745 .6586 Mdot
.58087 .36052 Mdot
.44339 .35495 Mdot
.47841 .57693 Mdot
.74939 .50925 Mdot
.43054 .24717 Mdot
.33751 .46431 Mdot
.32157 .51361 Mdot
.51178 .64197 Mdot
.46547 .38924 Mdot
.46989 .59919 Mdot
.58658 .4084 Mdot
.75986 .4868 Mdot
.47239 .58191 Mdot
.4159 .38024 Mdot
.62748 .50561 Mdot
.71284 .72638 Mdot
.53656 .58864 Mdot
.45601 .61278 Mdot
.50557 .60379 Mdot
.45523 .62942 Mdot
.18996 .49827 Mdot
.62587 .35724 Mdot
.52606 .20084 Mdot
.22801 .59957 Mdot
.64914 .52883 Mdot
.69943 .52661 Mdot
.79427 .63526 Mdot
.69948 .33826 Mdot
.59597 .34888 Mdot
.49843 .62454 Mdot
.68308 .38718 Mdot
.26731 .74418 Mdot
.16166 .52586 Mdot
.50442 .74304 Mdot
.39195 .39118 Mdot
.62082 .56726 Mdot
.41509 .39189 Mdot
.50183 .60822 Mdot
.46623 .69423 Mdot
.53516 .84074 Mdot
.56925 .36816 Mdot
.31272 .49116 Mdot
.50914 .60838 Mdot
.30579 .58999 Mdot
.43185 .35868 Mdot
.38604 .37708 Mdot
.49199 .65949 Mdot
.65214 .49442 Mdot
.84794 .60125 Mdot
.59498 .3847 Mdot
.50858 .20868 Mdot
.63512 .23551 Mdot
.68817 .44846 Mdot
.5878 .38052 Mdot
.59865 .51011 Mdot
.39666 .39073 Mdot
.73685 .6528 Mdot
.65478 .53149 Mdot
.30892 .45688 Mdot
.42516 .68051 Mdot
.69395 .51947 Mdot
.4246 .33241 Mdot
.62227 .53733 Mdot
.49762 .58822 Mdot
.61748 .31842 Mdot
.43637 .36924 Mdot
.65246 .32977 Mdot
.6089 .54028 Mdot
.29279 .48929 Mdot
.53784 .37084 Mdot
.50894 .75955 Mdot
.65719 .69647 Mdot
.49092 .66223 Mdot
.4702 .46501 Mdot
.48278 .64436 Mdot
.67066 .48689 Mdot
.46555 .62622 Mdot
.60096 .58286 Mdot
.44136 .36256 Mdot
.52267 .60741 Mdot
.49359 .63058 Mdot
.43836 .17853 Mdot
.44322 .64181 Mdot
.50415 .6694 Mdot
.47633 .63141 Mdot
.59382 .57935 Mdot
.55583 .58239 Mdot
.6471 .55425 Mdot
.31144 .31626 Mdot
.41828 .36469 Mdot
.28318 .46636 Mdot
.33113 .49784 Mdot
.33697 .60504 Mdot
.34805 .38753 Mdot
.4554 .28709 Mdot
.65964 .50953 Mdot
.59456 .40441 Mdot
.46104 .62824 Mdot
.42938 .81335 Mdot
.46664 .33133 Mdot
.39795 .34686 Mdot
.59984 .22677 Mdot
.47309 .71745 Mdot
.3993 .75639 Mdot
.53536 .65122 Mdot
.62217 .18175 Mdot
.48949 .56249 Mdot
.45273 .7091 Mdot
.46396 .38425 Mdot
.25099 .49053 Mdot
.52711 .63328 Mdot
.67553 .55727 Mdot
.32789 .47022 Mdot
.44206 .71712 Mdot
.37551 .34561 Mdot
.47021 .31228 Mdot
.64634 .59524 Mdot
.45677 .65529 Mdot
.4358 .37008 Mdot
.63853 .54749 Mdot
.79357 .64665 Mdot
.59478 .39026 Mdot
.38241 .4163 Mdot
.76464 .39293 Mdot
.19104 .40618 Mdot
.28667 .47661 Mdot
.7299 .6168 Mdot
.47123 .66336 Mdot
.23927 .42129 Mdot
.45391 .58654 Mdot
.21036 .68935 Mdot
.32997 .50229 Mdot
.63131 .51823 Mdot
.60629 .40081 Mdot
.6826 .55027 Mdot
.6472 .69143 Mdot
.38386 .32349 Mdot
.52618 .45579 Mdot
.41858 .35411 Mdot
.55495 .49702 Mdot
.68202 .51984 Mdot
.46646 .58861 Mdot
.75515 .27035 Mdot
.69111 .51535 Mdot
.61733 .52589 Mdot
.34859 .2274 Mdot
.14855 .46947 Mdot
.43709 .58056 Mdot
.62507 .51996 Mdot
.41297 .35777 Mdot
.32634 .47656 Mdot
.51916 .62026 Mdot
.45939 .6613 Mdot
.69095 .52677 Mdot
.39822 .33394 Mdot
.57355 .71096 Mdot
.43317 .38907 Mdot
.62921 .52247 Mdot
.42711 .37564 Mdot
.56313 .35223 Mdot
.40361 .35536 Mdot
.53012 .61055 Mdot
.46433 .62682 Mdot
.32238 .3431 Mdot
.6314 .52651 Mdot
.48699 .63431 Mdot
.44437 .67464 Mdot
.66113 .51949 Mdot
.5964 .49912 Mdot
.58419 .70903 Mdot
.45346 .67404 Mdot
.44733 .6529 Mdot
.33779 .49207 Mdot
.49022 .47895 Mdot
.7556 .59716 Mdot
.50464 .59144 Mdot
.34474 .46749 Mdot
.66302 .55907 Mdot
.4527 .60201 Mdot
.25533 .70547 Mdot
.53596 .25743 Mdot
.45308 .59417 Mdot
.41797 .39573 Mdot
.54633 .61742 Mdot
.52418 .81834 Mdot
.51236 .64953 Mdot
.67044 .51548 Mdot
.62687 .5435 Mdot
.51633 .16821 Mdot
.67351 .52715 Mdot
.45116 .34442 Mdot
.58623 .37599 Mdot
.17989 .51223 Mdot
.43385 .39883 Mdot
.50688 .56513 Mdot
.37421 .187 Mdot
.42781 .65958 Mdot
.50372 .57486 Mdot
.7166 .74421 Mdot
.41038 .38627 Mdot
.65433 .54471 Mdot
.53875 .38705 Mdot
.44274 .57012 Mdot
.60903 .34038 Mdot
.45849 .70042 Mdot
.5067 .65498 Mdot
.56227 .82086 Mdot
.19332 .49921 Mdot
.61465 .40556 Mdot
.50265 .66958 Mdot
.50246 .59046 Mdot
.46723 .405 Mdot
.47646 .62482 Mdot
.32715 .48103 Mdot
.64621 .53808 Mdot
.39685 .36911 Mdot
.30219 .46894 Mdot
.43203 .61596 Mdot
.31743 .49659 Mdot
.44819 .36768 Mdot
.57528 .39772 Mdot
.49319 .6017 Mdot
.31217 .45066 Mdot
.31246 .49507 Mdot
.48132 .64313 Mdot
.62109 .55533 Mdot
.48894 .71704 Mdot
.44205 .63682 Mdot
.5126 .59395 Mdot
.67368 .53912 Mdot
.3923 .85226 Mdot
.50928 .64756 Mdot
.31954 .62227 Mdot
.69451 .50833 Mdot
.57395 .50139 Mdot
.4393 .40148 Mdot
.52007 .64579 Mdot
.5756 .39859 Mdot
.57914 .4001 Mdot
.40724 .34199 Mdot
.61656 .56506 Mdot
.35971 .30156 Mdot
.68305 .56529 Mdot
.52811 .56507 Mdot
.51406 .66323 Mdot
.56765 .63688 Mdot
.40492 .79651 Mdot
.68356 .54471 Mdot
.36691 .36662 Mdot
.72103 .55245 Mdot
.5997 .40755 Mdot
.40644 .33128 Mdot
.66257 .56645 Mdot
.66956 .54385 Mdot
.63019 .56296 Mdot
.30922 .45631 Mdot
.32211 .3477 Mdot
.6903 .50045 Mdot
.66295 .49153 Mdot
.45652 .66395 Mdot
.50823 .5946 Mdot
.65529 .77839 Mdot
.64289 .77679 Mdot
.33925 .48333 Mdot
.44646 .34666 Mdot
.48648 .11241 Mdot
.56993 .38582 Mdot
.46699 .18517 Mdot
.50798 .57909 Mdot
.52724 .10561 Mdot
.51967 .62638 Mdot
.48287 .62242 Mdot
.66574 .56584 Mdot
.32073 .45356 Mdot
.31125 .48145 Mdot
.68841 .51405 Mdot
.67801 .49009 Mdot
.32647 .48285 Mdot
.29471 .2813 Mdot
.27535 .73893 Mdot
.51701 .33952 Mdot
.65071 .52139 Mdot
.52251 .77849 Mdot
.62008 .38888 Mdot
.40182 .66632 Mdot
.63147 .36807 Mdot
.42492 .35828 Mdot
.39253 .37916 Mdot
.61265 .34495 Mdot
.44887 .64939 Mdot
.43743 .34341 Mdot
.42539 .64243 Mdot
.43499 .23139 Mdot
.62938 .72585 Mdot
.39376 .29953 Mdot
.39897 .67894 Mdot
.59963 .4946 Mdot
.64894 .31801 Mdot
.44179 .60481 Mdot
.2271 .66534 Mdot
.30951 .49069 Mdot
.50802 .55595 Mdot
.60379 .33559 Mdot
.69975 .7655 Mdot
.48591 .59671 Mdot
.66504 .51477 Mdot
.58479 .35303 Mdot
.77443 .39721 Mdot
.75685 .41456 Mdot
.50703 .60645 Mdot
.71108 .23855 Mdot
.63699 .4891 Mdot
.42528 .34679 Mdot
.77886 .51246 Mdot
.69826 .52239 Mdot
.35842 .50612 Mdot
.24881 .65391 Mdot
.17794 .45133 Mdot
.64753 .54469 Mdot
.41605 .41132 Mdot
.647 .55833 Mdot
.28935 .48102 Mdot
.71032 .53273 Mdot
.43721 .36213 Mdot
.44886 .61068 Mdot
.42549 .38821 Mdot
.31562 .45688 Mdot
.77449 .61625 Mdot
.61452 .40555 Mdot
.43915 .32844 Mdot
.60797 .36788 Mdot
.2455 .56985 Mdot
.29883 .65857 Mdot
.60882 .38431 Mdot
.58373 .66261 Mdot
.51625 .66062 Mdot
.69758 .50846 Mdot
.44207 .3963 Mdot
.25147 .4527 Mdot
.54529 .38446 Mdot
.66008 .5314 Mdot
.43289 .33544 Mdot
.76951 .45364 Mdot
.58719 .57435 Mdot
.51507 .66442 Mdot
.36708 .53516 Mdot
.655 .52206 Mdot
.41526 .40929 Mdot
.8298 .57529 Mdot
.65011 .55765 Mdot
.46589 .36821 Mdot
.61192 .39509 Mdot
.57776 .37478 Mdot
.47413 .67519 Mdot
.60483 .31266 Mdot
.41845 .33962 Mdot
.64125 .3933 Mdot
.62119 .52553 Mdot
.78635 .43001 Mdot
.28876 .45485 Mdot
.4196 .37261 Mdot
.42153 .64784 Mdot
.65694 .48601 Mdot
.55787 .2369 Mdot
.58021 .72317 Mdot
.80674 .35964 Mdot
.43344 .39263 Mdot
.65298 .5383 Mdot
.65955 .51455 Mdot
.53414 .58328 Mdot
.76823 .49514 Mdot
.33212 .31381 Mdot
.57872 .5849 Mdot
.58547 .44695 Mdot
.45077 .39988 Mdot
.38794 .40904 Mdot
.44648 .69438 Mdot
.45394 .64694 Mdot
.60455 .40602 Mdot
.44927 .61307 Mdot
.61535 .55474 Mdot
.4894 .66216 Mdot
.60447 .38036 Mdot
.41523 .35243 Mdot
.4886 .60005 Mdot
.31018 .49574 Mdot
.62487 .35398 Mdot
.56713 .38563 Mdot
.41555 .37396 Mdot
.6912 .52704 Mdot
.56494 .50888 Mdot
.44255 .39089 Mdot
.45596 .65497 Mdot
.45121 .47944 Mdot
.49486 .58662 Mdot
.56641 .54703 Mdot
.65635 .55648 Mdot
.39706 .37045 Mdot
.71066 .54923 Mdot
.60109 .36796 Mdot
.22938 .60748 Mdot
.46141 .61847 Mdot
.46416 .37982 Mdot
.60699 .27321 Mdot
.55176 .52459 Mdot
.60922 .53527 Mdot
.37561 .2676 Mdot
.70092 .51328 Mdot
.45022 .35277 Mdot
.40526 .19701 Mdot
.29513 .46123 Mdot
.39371 .35294 Mdot
.3688 .77041 Mdot
.4068 .37536 Mdot
.47815 .6705 Mdot
.50754 .64499 Mdot
.40189 .35816 Mdot
.32453 .49911 Mdot
.7696 .6839 Mdot
.42051 .42397 Mdot
.65066 .54342 Mdot
.37378 .23776 Mdot
.83622 .44544 Mdot
.65261 .39406 Mdot
.5992 .40641 Mdot
.42845 .58635 Mdot
.52003 .65239 Mdot
.59636 .33606 Mdot
.62042 .40348 Mdot
.28256 .48207 Mdot
.46225 .37608 Mdot
.6355 .49339 Mdot
.56731 .39982 Mdot
.71652 .56904 Mdot
.34137 .36842 Mdot
.5384 .59378 Mdot
.62471 .22922 Mdot
.50854 .58064 Mdot
.27552 .63702 Mdot
.60747 .37848 Mdot
.44869 .59093 Mdot
.53518 .64802 Mdot
.58135 .35147 Mdot
.327 .47519 Mdot
.3799 .41256 Mdot
.4299 .37426 Mdot
.38919 .84062 Mdot
.43222 .65236 Mdot
.48249 .66375 Mdot
.6039 .34628 Mdot
.26509 .3967 Mdot
.64514 .53127 Mdot
.69894 .53631 Mdot
.41505 .34601 Mdot
.51454 .38894 Mdot
.49629 .66669 Mdot
.44396 .607 Mdot
.43688 .37655 Mdot
.43646 .33019 Mdot
.46221 .28279 Mdot
.48549 .6499 Mdot
.59505 .35469 Mdot
.24109 .50109 Mdot
.61216 .37236 Mdot
.48317 .58632 Mdot
.48162 .66169 Mdot
.53015 .60881 Mdot
.42347 .62174 Mdot
.62626 .32953 Mdot
.48751 .58268 Mdot
.51872 .66961 Mdot
.65507 .5361 Mdot
.51114 .60476 Mdot
.57657 .43683 Mdot
.44944 .62019 Mdot
.32638 .4793 Mdot
.75237 .58613 Mdot
.48681 .59729 Mdot
.49644 .65947 Mdot
.38244 .3704 Mdot
.46872 .60919 Mdot
.58207 .40619 Mdot
.63705 .52511 Mdot
.59821 .34704 Mdot
.58139 .40231 Mdot
.43276 .41323 Mdot
.31657 .50753 Mdot
.46831 .56907 Mdot
.33467 .47159 Mdot
.49589 .55956 Mdot
.42777 .63552 Mdot
.35553 .42555 Mdot
.5922 .16287 Mdot
.79889 .58197 Mdot
.45956 .61937 Mdot
.40746 .38214 Mdot
.41471 .39248 Mdot
.58031 .54687 Mdot
.48569 .67859 Mdot
.58738 .33439 Mdot
.59717 .40807 Mdot
.49275 .78914 Mdot
.37119 .67317 Mdot
.32675 .47858 Mdot
.50283 .47318 Mdot
.44404 .66368 Mdot
.44699 .59228 Mdot
.43311 .65848 Mdot
.40991 .39934 Mdot
.46323 .74423 Mdot
.4071 .33411 Mdot
.66916 .36719 Mdot
.61226 .3526 Mdot
.49812 .6011 Mdot
.60252 .21789 Mdot
.66269 .5015 Mdot
.63681 .52472 Mdot
.56514 .37582 Mdot
.45945 .32854 Mdot
.71819 .7199 Mdot
.15637 .54332 Mdot
.70106 .48772 Mdot
.31465 .45357 Mdot
.43567 .61611 Mdot
.40637 .36062 Mdot
.62247 .53114 Mdot
.31706 .45458 Mdot
.47801 .59001 Mdot
.3229 .34857 Mdot
.45387 .62542 Mdot
.68661 .31213 Mdot
.63124 .55685 Mdot
.24166 .72083 Mdot
.6147 .56333 Mdot
.61892 .33108 Mdot
.60622 .33301 Mdot
.48887 .65258 Mdot
.64202 .47478 Mdot
.69951 .52041 Mdot
.37963 .46567 Mdot
.30129 .5015 Mdot
.65753 .40697 Mdot
.29884 .46221 Mdot
.43501 .35099 Mdot
.31655 .46061 Mdot
.43925 .36353 Mdot
.73131 .70482 Mdot
.61578 .60567 Mdot
.3038 .47432 Mdot
.61639 .27779 Mdot
.52145 .64956 Mdot
.34108 .47814 Mdot
.46519 .69342 Mdot
.57087 .5833 Mdot
.43713 .37966 Mdot
.29498 .49476 Mdot
.44727 .59383 Mdot
.45578 .80991 Mdot
.60599 .39119 Mdot
.59242 .33103 Mdot
.46368 .69268 Mdot
.43796 .40529 Mdot
.67126 .56195 Mdot
.19673 .60833 Mdot
.56882 .40687 Mdot
.50184 .65012 Mdot
.52876 .63091 Mdot
.69974 .50917 Mdot
.52835 .18499 Mdot
.48022 .6577 Mdot
.54266 .54348 Mdot
.48938 .64957 Mdot
.62015 .3618 Mdot
.67721 .55178 Mdot
.64931 .51728 Mdot
.43413 .3368 Mdot
.65142 .50087 Mdot
.43216 .51142 Mdot
.65235 .27954 Mdot
.49594 .70056 Mdot
.59779 .37201 Mdot
.67622 .40362 Mdot
.664 .32841 Mdot
.36819 .75418 Mdot
.60697 .54791 Mdot
.47763 .58126 Mdot
.64927 .49988 Mdot
.3085 .46186 Mdot
.63634 .51983 Mdot
.62112 .56737 Mdot
.46671 .59686 Mdot
.50578 .61133 Mdot
.41959 .34938 Mdot
.76743 .48909 Mdot
.69497 .51969 Mdot
.51874 .6271 Mdot
.53516 .61047 Mdot
.42371 .64496 Mdot
.38802 .48461 Mdot
.67975 .54854 Mdot
.27032 .27679 Mdot
.38107 .55809 Mdot
.69424 .52223 Mdot
.82306 .63651 Mdot
.59041 .25852 Mdot
.39294 .31936 Mdot
.37881 .43514 Mdot
.49299 .64731 Mdot
.45575 .3425 Mdot
.5012 .60769 Mdot
.62796 .23295 Mdot
.47596 .60814 Mdot
.32826 .48061 Mdot
.42859 .64576 Mdot
.39188 .36858 Mdot
.43435 .3906 Mdot
.49965 .65301 Mdot
.49015 .6027 Mdot
.77778 .6279 Mdot
.70883 .54015 Mdot
.6273 .53484 Mdot
.40907 .29436 Mdot
.29793 .47728 Mdot
.60867 .33849 Mdot
.47104 .63005 Mdot
.42812 .41169 Mdot
.43203 .3904 Mdot
.6913 .53829 Mdot
.45169 .37245 Mdot
.59338 .38453 Mdot
.4647 .62015 Mdot
.596 .33389 Mdot
.2959 .45859 Mdot
.6759 .55117 Mdot
.50975 .60564 Mdot
.45615 .66387 Mdot
.6271 .54342 Mdot
.45087 .58653 Mdot
.31946 .49909 Mdot
.41069 .37862 Mdot
.64668 .54584 Mdot
.58323 .37472 Mdot
.43695 .35394 Mdot
.50903 .58754 Mdot
.68348 .22511 Mdot
.46809 .67442 Mdot
.50268 .64062 Mdot
.40304 .80697 Mdot
.43959 .65668 Mdot
.43847 .39514 Mdot
.62486 .52643 Mdot
.48919 .54809 Mdot
.33816 .58094 Mdot
.36635 .8509 Mdot
.40691 .33668 Mdot
.4366 .62062 Mdot
.39619 .77367 Mdot
.43991 .61861 Mdot
.5587 .75258 Mdot
.42543 .32197 Mdot
.57255 .46247 Mdot
.41896 .63518 Mdot
.58294 .39162 Mdot
.40726 .3541 Mdot
.44249 .36701 Mdot
.40978 .22684 Mdot
.4562 .59824 Mdot
.43158 .46363 Mdot
.48788 .58963 Mdot
.58196 .37834 Mdot
.3827 .67949 Mdot
.43717 .39249 Mdot
.82288 .439 Mdot
.482 .6459 Mdot
.67433 .54463 Mdot
.38462 .37276 Mdot
.55687 .39247 Mdot
.5157 .5986 Mdot
.33281 .48903 Mdot
.60444 .41708 Mdot
.4864 .70129 Mdot
.59584 .375 Mdot
.51104 .59286 Mdot
.40863 .58457 Mdot
.77645 .36134 Mdot
.62408 .56057 Mdot
.60737 .40117 Mdot
.43187 .48503 Mdot
.47716 .58283 Mdot
.64607 .54458 Mdot
.65649 .53205 Mdot
.30148 .45619 Mdot
.55413 .47999 Mdot
.73983 .37064 Mdot
.59774 .76418 Mdot
.3884 .2315 Mdot
.38941 .35478 Mdot
.51666 .30738 Mdot
.50206 .63449 Mdot
.3957 .52178 Mdot
.58627 .40765 Mdot
.46466 .67537 Mdot
.71643 .62277 Mdot
.67767 .50209 Mdot
.463 .67216 Mdot
.31622 .48288 Mdot
.30378 .52486 Mdot
.24358 .50878 Mdot
.28901 .69723 Mdot
.42025 .3548 Mdot
.54197 .64789 Mdot
.47841 .54502 Mdot
.44361 .40108 Mdot
.52766 .59169 Mdot
.44515 .39741 Mdot
.25342 .32091 Mdot
.33886 .46751 Mdot
.67114 .54926 Mdot
.65874 .36136 Mdot
.5035 .57261 Mdot
.50787 .65969 Mdot
.31221 .50869 Mdot
.45707 .64804 Mdot
.73091 .30157 Mdot
.38505 .48948 Mdot
.43955 .34937 Mdot
.62834 .56257 Mdot
.53273 .60397 Mdot
.49141 .48809 Mdot
.44204 .62446 Mdot
.6616 .73736 Mdot
.49867 .65813 Mdot
.76159 .41451 Mdot
.62662 .55758 Mdot
.60218 .37474 Mdot
.43772 .59588 Mdot
.47982 .61374 Mdot
.35033 .64255 Mdot
.48952 .56087 Mdot
.45665 .58743 Mdot
.62512 .58075 Mdot
.62348 .56429 Mdot
.64442 .55661 Mdot
.41046 .3381 Mdot
.43885 .77414 Mdot
.59712 .36016 Mdot
.44558 .55967 Mdot
.56364 .36553 Mdot
.54927 .7179 Mdot
.32665 .45855 Mdot
.32802 .70122 Mdot
.48574 .63076 Mdot
.6578 .5081 Mdot
.19759 .56879 Mdot
.70197 .54088 Mdot
.49566 .46464 Mdot
.58081 .35942 Mdot
.68997 .5164 Mdot
.48313 .61889 Mdot
.73843 .51095 Mdot
.42358 .80142 Mdot
.60391 .35841 Mdot
.51238 .56776 Mdot
.38972 .36704 Mdot
.35705 .32062 Mdot
.7965 .38215 Mdot
.60902 .38855 Mdot
.60186 .43451 Mdot
.45063 .60005 Mdot
.65192 .50291 Mdot
.58291 .38761 Mdot
.61913 .3636 Mdot
.45128 .36753 Mdot
.50756 .61339 Mdot
.5085 .61731 Mdot
.44571 .34346 Mdot
.60029 .34691 Mdot
.50072 .67858 Mdot
.50241 .69147 Mdot
.61189 .83296 Mdot
.77414 .43635 Mdot
.40515 .85684 Mdot
.57679 .53023 Mdot
.69118 .61861 Mdot
.196 .61747 Mdot
.6885 .53397 Mdot
.43734 .60498 Mdot
.43098 .69073 Mdot
.41786 .33957 Mdot
.45986 .60957 Mdot
.43087 .31669 Mdot
.5717 .37331 Mdot
.69446 .76791 Mdot
.71059 .42847 Mdot
.21003 .38574 Mdot
.46076 .60768 Mdot
.60215 .57338 Mdot
.31242 .46514 Mdot
.64556 .42974 Mdot
.66883 .55453 Mdot
.42808 .66373 Mdot
.77693 .62535 Mdot
.39732 .34733 Mdot
.67331 .53419 Mdot
.78903 .65292 Mdot
.60779 .48674 Mdot
.49425 .58708 Mdot
.41579 .33069 Mdot
.21579 .65518 Mdot
.70772 .58076 Mdot
.58239 .33425 Mdot
.32733 .47421 Mdot
.39921 .36575 Mdot
.60495 .40755 Mdot
.59612 .5682 Mdot
.68101 .52767 Mdot
.67482 .55844 Mdot
.78463 .58582 Mdot
.39132 .33715 Mdot
.31028 .46603 Mdot
.37721 .71519 Mdot
.36204 .65428 Mdot
.3261 .48506 Mdot
.39247 .37993 Mdot
.61764 .55749 Mdot
.68392 .50843 Mdot
.6379 .5248 Mdot
.8084 .53414 Mdot
.63533 .50541 Mdot
.42344 .20761 Mdot
.42249 .63479 Mdot
.5525 .63951 Mdot
.43783 .61688 Mdot
.58488 .33825 Mdot
.62991 .54613 Mdot
.53315 .38047 Mdot
.51639 .56348 Mdot
.32414 .68146 Mdot
.47701 .67274 Mdot
.62818 .35556 Mdot
.4666 .66861 Mdot
.61268 .20548 Mdot
.66294 .49735 Mdot
.45996 .61544 Mdot
.62997 .36823 Mdot
.29558 .48116 Mdot
.60652 .54178 Mdot
.50593 .60419 Mdot
.34423 .27952 Mdot
.43383 .64748 Mdot
.22795 .3641 Mdot
.74844 .35144 Mdot
.31781 .45452 Mdot
.67589 .26775 Mdot
.4214 .41541 Mdot
.5603 .57762 Mdot
.4272 .57908 Mdot
.60571 .36463 Mdot
.65534 .41034 Mdot
.41674 .36293 Mdot
.49084 .74531 Mdot
.50988 .67831 Mdot
.2968 .45681 Mdot
.60276 .60435 Mdot
.59127 .34029 Mdot
.53166 .59685 Mdot
.53932 .638 Mdot
.50153 .20186 Mdot
.48733 .69248 Mdot
.52161 .64331 Mdot
.33005 .50955 Mdot
.44817 .19473 Mdot
.44804 .62721 Mdot
.50146 .46849 Mdot
.70898 .53599 Mdot
.51797 .56061 Mdot
.42908 .20129 Mdot
.51077 .64264 Mdot
.68386 .53062 Mdot
.55399 .54783 Mdot
.71995 .35505 Mdot
.31946 .50738 Mdot
.49864 .65858 Mdot
.5047 .16927 Mdot
.47017 .6516 Mdot
.59274 .35878 Mdot
.48804 .67674 Mdot
.43466 .36096 Mdot
.81011 .57259 Mdot
.4311 .33794 Mdot
.47449 .67802 Mdot
.64234 .52363 Mdot
.60823 .34946 Mdot
.79367 .52639 Mdot
.30222 .35412 Mdot
.49122 .18857 Mdot
.16485 .52991 Mdot
.3049 .50227 Mdot
.29353 .44731 Mdot
.57168 .36433 Mdot
.45813 .61641 Mdot
.35732 .21403 Mdot
.46917 .56289 Mdot
.44953 .65847 Mdot
.47737 .60802 Mdot
.29437 .65288 Mdot
.57591 .39502 Mdot
.43725 .38509 Mdot
.48009 .65984 Mdot
.47746 .58381 Mdot
.68184 .53896 Mdot
.30085 .48503 Mdot
.43622 .40113 Mdot
.30783 .48566 Mdot
.40505 .35821 Mdot
.75392 .71199 Mdot
.52042 .66562 Mdot
.29323 .48117 Mdot
.58155 .4123 Mdot
.68231 .53511 Mdot
.66458 .30667 Mdot
.44126 .35999 Mdot
.41837 .33561 Mdot
.50148 .6543 Mdot
.69016 .52438 Mdot
.69099 .56148 Mdot
.2944 .46619 Mdot
.60323 .38705 Mdot
.48565 .59702 Mdot
.43214 .63903 Mdot
.42126 .56329 Mdot
.43713 .40837 Mdot
.67952 .29843 Mdot
.48428 .3129 Mdot
.45768 .61935 Mdot
.62167 .52541 Mdot
.48481 .60325 Mdot
.21219 .44051 Mdot
.65506 .50138 Mdot
.51517 .63769 Mdot
.84965 .58866 Mdot
.38916 .31408 Mdot
.70229 .37405 Mdot
.52763 .62965 Mdot
.18803 .64508 Mdot
.49515 .63287 Mdot
.70597 .76437 Mdot
.22113 .48261 Mdot
.49832 .6692 Mdot
.51765 .59937 Mdot
.61557 .71661 Mdot
.43258 .62812 Mdot
.43893 .33676 Mdot
.64219 .79365 Mdot
.69572 .54903 Mdot
.65972 .32185 Mdot
.74151 .59582 Mdot
.32398 .50518 Mdot
.41486 .34615 Mdot
.37812 .36924 Mdot
.31903 .48936 Mdot
.65439 .51987 Mdot
.45528 .62964 Mdot
.49263 .43183 Mdot
.43061 .40611 Mdot
.48786 .72734 Mdot
.59061 .3579 Mdot
.51093 .24957 Mdot
.3606 .52952 Mdot
.59392 .37824 Mdot
.51278 .60674 Mdot
.60133 .71486 Mdot
.72903 .69612 Mdot
.31594 .76165 Mdot
.61539 .4023 Mdot
.60561 .35748 Mdot
.81639 .5467 Mdot
.27678 .47596 Mdot
.50164 .20503 Mdot
.75994 .41734 Mdot
.60944 .34356 Mdot
.59579 .54511 Mdot
.44357 .33722 Mdot
.55278 .31988 Mdot
.53948 .56493 Mdot
.42559 .62947 Mdot
.48168 .61764 Mdot
.61029 .3797 Mdot
.56073 .52852 Mdot
.79704 .44998 Mdot
.60993 .36639 Mdot
.40489 .64611 Mdot
.54665 .44879 Mdot
.58541 .28868 Mdot
.45418 .37974 Mdot
.29815 .50051 Mdot
.27408 .46936 Mdot
.66384 .54502 Mdot
.30507 .50476 Mdot
.29331 .52371 Mdot
.46 .64067 Mdot
.61454 .36224 Mdot
.60745 .25673 Mdot
.58033 .37076 Mdot
.31381 .48702 Mdot
.2807 .48044 Mdot
.65442 .53561 Mdot
.62671 .53248 Mdot
.64449 .65432 Mdot
.3376 .54388 Mdot
.44297 .64726 Mdot
.28029 .43608 Mdot
.63105 .56851 Mdot
.53465 .68222 Mdot
.30104 .50311 Mdot
.29729 .47998 Mdot
.34244 .64548 Mdot
.48655 .62795 Mdot
.53466 .69875 Mdot
.48005 .62905 Mdot
.3978 .56475 Mdot
.51982 .59499 Mdot
.45152 .36842 Mdot
.49765 .62567 Mdot
.34175 .65708 Mdot
.46372 .57657 Mdot
.53094 .64186 Mdot
.41724 .40569 Mdot
.51351 .67962 Mdot
.43372 .36211 Mdot
.45838 .67666 Mdot
.31646 .44927 Mdot
.41371 .34487 Mdot
.32262 .58969 Mdot
.32865 .63653 Mdot
.39573 .38745 Mdot
.32857 .4638 Mdot
.33841 .49439 Mdot
.28807 .59682 Mdot
.67045 .55453 Mdot
.40968 .6089 Mdot
.45769 .61376 Mdot
.41012 .3269 Mdot
.58888 .40459 Mdot
.51247 .58822 Mdot
.52452 .64308 Mdot
.52669 .62021 Mdot
.66637 .54558 Mdot
.32483 .31992 Mdot
.29133 .48248 Mdot
.44433 .34026 Mdot
.55705 .50574 Mdot
.45095 .40032 Mdot
.54385 .61687 Mdot
.42195 .67823 Mdot
.72726 .60955 Mdot
.60681 .28984 Mdot
.8179 .51756 Mdot
.67893 .52895 Mdot
.41592 .39479 Mdot
.29025 .45306 Mdot
.41056 .64618 Mdot
.65624 .50729 Mdot
.43685 .36238 Mdot
.45458 .62499 Mdot
.51629 .57246 Mdot
.6392 .26883 Mdot
.24627 .52278 Mdot
.32693 .61641 Mdot
.40333 .34564 Mdot
.39361 .39342 Mdot
.31802 .64792 Mdot
.25606 .46916 Mdot
.54253 .37589 Mdot
.45211 .60392 Mdot
.33097 .49042 Mdot
.62823 .52302 Mdot
.7607 .60742 Mdot
.61641 .34155 Mdot
.76649 .49812 Mdot
.46207 .60888 Mdot
.59499 .48173 Mdot
.64227 .52497 Mdot
.31932 .48371 Mdot
.61288 .37582 Mdot
.27103 .49416 Mdot
.41295 .39819 Mdot
.17039 .45035 Mdot
.46335 .65368 Mdot
.49812 .65653 Mdot
.62511 .37551 Mdot
.66639 .50361 Mdot
.34531 .48829 Mdot
.37189 .24387 Mdot
.44674 .36991 Mdot
.36937 .20647 Mdot
.62621 .51973 Mdot
.52175 .77621 Mdot
.45713 .36531 Mdot
.56364 .38549 Mdot
.2984 .59044 Mdot
.59757 .38252 Mdot
.48258 .67299 Mdot
.6621 .51106 Mdot
.60225 .40367 Mdot
.77843 .47337 Mdot
.44215 .8274 Mdot
.53051 .77773 Mdot
.46209 .63493 Mdot
.51871 .8299 Mdot
.27391 .31444 Mdot
.69797 .48372 Mdot
.59477 .40932 Mdot
.46805 .67581 Mdot
.50187 .65978 Mdot
.46893 .65351 Mdot
.58313 .39875 Mdot
.29784 .43271 Mdot
.4398 .37951 Mdot
.44158 .60723 Mdot
.2822 .47901 Mdot
.42668 .36083 Mdot
.56034 .36667 Mdot
.45081 .38656 Mdot
.61534 .57108 Mdot
.54225 .59866 Mdot
.64326 .44679 Mdot
.89682 .52289 Mdot
.60269 .35155 Mdot
.42906 .41332 Mdot
.48478 .68406 Mdot
.55134 .25831 Mdot
.65031 .56269 Mdot
.44777 .36687 Mdot
.48248 .66494 Mdot
.62546 .28395 Mdot
.78396 .60494 Mdot
.44583 .39142 Mdot
.65362 .50721 Mdot
.32107 .76028 Mdot
.45343 .61006 Mdot
.48286 .63838 Mdot
.68688 .52023 Mdot
.5765 .63576 Mdot
.8148 .59867 Mdot
.48844 .60318 Mdot
.60377 .37511 Mdot
.18106 .38877 Mdot
.52396 .64426 Mdot
.37946 .59592 Mdot
.41349 .35016 Mdot
.54729 .34549 Mdot
.70694 .33056 Mdot
.43987 .58911 Mdot
.45394 .22817 Mdot
.65667 .36854 Mdot
.429 .77875 Mdot
.42874 .3146 Mdot
.28592 .33424 Mdot
.49955 .81375 Mdot
.62893 .34051 Mdot
.62452 .58861 Mdot
.41815 .23438 Mdot
.72085 .58235 Mdot
.25436 .6985 Mdot
.25006 .41552 Mdot
.77916 .6236 Mdot
.50809 .42584 Mdot
.40264 .3746 Mdot
.56927 .62262 Mdot
.50247 .60575 Mdot
.26896 .32043 Mdot
.77745 .37765 Mdot
.78759 .40657 Mdot
.51987 .831 Mdot
.55313 .76119 Mdot
.4023 .77953 Mdot
.37798 .77187 Mdot
.38425 .61772 Mdot
.50554 .3188 Mdot
.35449 .21013 Mdot
.71308 .73298 Mdot
.31603 .26098 Mdot
.54909 .6472 Mdot
.48067 .46188 Mdot
.20157 .4288 Mdot
.62153 .60099 Mdot
.58699 .58288 Mdot
.44073 .34242 Mdot
.67045 .55634 Mdot
.48363 .21087 Mdot
.69791 .50262 Mdot
.71806 .35082 Mdot
.34568 .78303 Mdot
.43235 .8201 Mdot
.52639 .17787 Mdot
.19349 .64325 Mdot
.70673 .62347 Mdot
.31491 .20016 Mdot
.45845 .33669 Mdot
.69216 .53549 Mdot
.28417 .63673 Mdot
.35549 .68004 Mdot
.68729 .43905 Mdot
.3717 .25958 Mdot
.34013 .34695 Mdot
.25529 .55599 Mdot
.66177 .51547 Mdot
.6861 .28575 Mdot
.56408 .31649 Mdot
.70486 .43216 Mdot
.67917 .76133 Mdot
.31659 .74001 Mdot
.47659 .43787 Mdot
.41371 .2546 Mdot
.51662 .26909 Mdot
.80422 .45759 Mdot
.35619 .56249 Mdot
.57928 .56906 Mdot
.76928 .42325 Mdot
.18357 .57118 Mdot
.62257 .63009 Mdot
.40709 .55763 Mdot
.36296 .68625 Mdot
.77428 .68643 Mdot
.24021 .37155 Mdot
.85928 .44451 Mdot
.69815 .50027 Mdot
.53078 .62591 Mdot
.57377 .66915 Mdot
.46496 .16799 Mdot
.32416 .51505 Mdot
.27804 .68869 Mdot
.28736 .48584 Mdot
.6234 .5734 Mdot
.80603 .59227 Mdot
.43976 .19616 Mdot
.40547 .18035 Mdot
.30598 .44673 Mdot
.44365 .55991 Mdot
.18996 .70397 Mdot
.37876 .73758 Mdot
.70223 .40208 Mdot
.61947 .82756 Mdot
.55554 .4396 Mdot
.78319 .42032 Mdot
.60158 .40486 Mdot
.53927 .82197 Mdot
.68022 .51035 Mdot
.86622 .41745 Mdot
.72171 .75042 Mdot
.73885 .62044 Mdot
.74252 .80897 Mdot
.30631 .65057 Mdot
.57849 .46616 Mdot
.64015 .40679 Mdot
.30766 .5604 Mdot
.78592 .50145 Mdot
.22968 .58823 Mdot
.54069 .26076 Mdot
.18235 .64377 Mdot
.48674 .81602 Mdot
.38387 .19175 Mdot
.19845 .38603 Mdot
.64068 .61468 Mdot
.50099 .48834 Mdot
.39715 .66506 Mdot
.3765 .30909 Mdot
.26543 .6855 Mdot
.79273 .67307 Mdot
.37922 .56045 Mdot
.35972 .84706 Mdot
.3276 .44271 Mdot
.32728 .37372 Mdot
.39171 .82882 Mdot
.26533 .56679 Mdot
.71273 .3183 Mdot
.41668 .74848 Mdot
.42903 .72038 Mdot
.50331 .50097 Mdot
.27744 .69533 Mdot
.68222 .33527 Mdot
.60649 .81236 Mdot
.21357 .67228 Mdot
.50755 .20291 Mdot
.63019 .73491 Mdot
.36766 .63446 Mdot
.62169 .50733 Mdot
.2878 .5302 Mdot
.71436 .33409 Mdot
.46796 .83846 Mdot
.61944 .32339 Mdot
.50663 .84906 Mdot
.80942 .60628 Mdot
.52114 .66601 Mdot
.40889 .61719 Mdot
.59454 .52404 Mdot
.27471 .53031 Mdot
.54461 .64836 Mdot
.60439 .23511 Mdot
.42294 .81812 Mdot
.70072 .71558 Mdot
.64677 .31002 Mdot
.65849 .39356 Mdot
.39323 .83606 Mdot
.59709 .68379 Mdot
.26717 .45622 Mdot
.60812 .80038 Mdot
.78961 .49917 Mdot
.42136 .36753 Mdot
.39591 .19225 Mdot
.60013 .42953 Mdot
.77213 .60862 Mdot
.59314 .76433 Mdot
.70282 .60172 Mdot
.42381 .8194 Mdot
.31726 .31208 Mdot
.79763 .60764 Mdot
.24746 .58548 Mdot
.33313 .23803 Mdot
.59448 .28978 Mdot
.44967 .70085 Mdot
.36279 .26537 Mdot
.33524 .49497 Mdot
.64653 .68175 Mdot
.21435 .32876 Mdot
.28343 .40667 Mdot
.45009 .69148 Mdot
.74424 .61632 Mdot
.37524 .35187 Mdot
.73843 .50535 Mdot
.82389 .37514 Mdot
.53715 .62444 Mdot
.37699 .70731 Mdot
.30066 .31123 Mdot
.31263 .54985 Mdot
.2651 .73271 Mdot
.19434 .48548 Mdot
.87294 .46413 Mdot
.56853 .83213 Mdot
.29822 .34935 Mdot
.47638 .80383 Mdot
.48595 .8273 Mdot
.86852 .47405 Mdot
.43888 .57514 Mdot
.61379 .32387 Mdot
.64312 .18348 Mdot
.45549 .3796 Mdot
.36257 .70115 Mdot
.38858 .23132 Mdot
.34746 .52849 Mdot
.64344 .4539 Mdot
.48769 .74115 Mdot
.50486 .43435 Mdot
.71055 .53981 Mdot
.5396 .6547 Mdot
.83568 .4702 Mdot
.8752 .51764 Mdot
.84995 .46144 Mdot
.17501 .51064 Mdot
.54375 .81922 Mdot
.58101 .4866 Mdot
.49598 .17543 Mdot
.52175 .69696 Mdot
.44139 .59771 Mdot
.3206 .52268 Mdot
.30151 .64797 Mdot
.7631 .59483 Mdot
.73094 .43683 Mdot
.61141 .60703 Mdot
.27636 .68936 Mdot
.09901 .46967 Mdot
.66732 .64937 Mdot
.39818 .21365 Mdot
.26477 .46948 Mdot
.32359 .54369 Mdot
.23264 .64977 Mdot
.76275 .57953 Mdot
.39106 .79211 Mdot
.70902 .54204 Mdot
.34485 .25329 Mdot
.26686 .42603 Mdot
.64537 .58645 Mdot
.32302 .32344 Mdot
.37375 .74423 Mdot
.66464 .39228 Mdot
.77204 .55988 Mdot
.75286 .42527 Mdot
.58584 .65794 Mdot
.37613 .48053 Mdot
.49669 .26261 Mdot
.27018 .27569 Mdot
.22693 .4274 Mdot
.38331 .59031 Mdot
.53887 .44721 Mdot
.6562 .24586 Mdot
.64718 .32776 Mdot
.39479 .56289 Mdot
.56945 .43074 Mdot
.40032 .73567 Mdot
.86422 .33997 Mdot
.82903 .42461 Mdot
.34362 .79187 Mdot
.21403 .54222 Mdot
.47432 .70118 Mdot
.38009 .79122 Mdot
.85121 .41007 Mdot
.84479 .61502 Mdot
.47359 .26552 Mdot
.45777 .33252 Mdot
.56198 .37902 Mdot
.83369 .5125 Mdot
.34284 .42823 Mdot
.35233 .75926 Mdot
.37118 .59012 Mdot
.57161 .3995 Mdot
.54676 .1407 Mdot
.75712 .70006 Mdot
.56885 .777 Mdot
.25325 .52147 Mdot
.42142 .6694 Mdot
.69606 .27427 Mdot
.70037 .52296 Mdot
.5358 .29609 Mdot
.34904 .54502 Mdot
.42147 .3776 Mdot
.26384 .64515 Mdot
.34496 .2652 Mdot
.42824 .6455 Mdot
.45772 .48375 Mdot
.62458 .51101 Mdot
.59376 .2856 Mdot
.6766 .38561 Mdot
.86025 .58572 Mdot
.26831 .49679 Mdot
.41962 .64466 Mdot
.32505 .55443 Mdot
.34428 .31008 Mdot
.83045 .57465 Mdot
.56829 .37574 Mdot
.4622 .81081 Mdot
.46662 .44998 Mdot
.3142 .53811 Mdot
.74046 .56106 Mdot
.55648 .64486 Mdot
.52361 .65358 Mdot
.1868 .5406 Mdot
.70454 .70508 Mdot
.7277 .5507 Mdot
.52406 .55649 Mdot
.49967 .72105 Mdot
.37397 .78734 Mdot
.29539 .52249 Mdot
.51273 .25612 Mdot
.45202 .81346 Mdot
.57536 .38353 Mdot
.64637 .50094 Mdot
.30411 .43575 Mdot
.30122 .27133 Mdot
.51833 .78775 Mdot
.78493 .60358 Mdot
.38315 .51876 Mdot
.29514 .39888 Mdot
.45427 .82357 Mdot
.44073 .79417 Mdot
.62316 .20009 Mdot
.65995 .4796 Mdot
.42861 .53048 Mdot
.28869 .27427 Mdot
.65202 .56512 Mdot
.47876 .19346 Mdot
.52232 .20142 Mdot
.72557 .73826 Mdot
.4425 .48156 Mdot
.18665 .65971 Mdot
.32736 .61184 Mdot
.24969 .65784 Mdot
.79787 .51935 Mdot
.32075 .25223 Mdot
.34823 .70283 Mdot
.70682 .49249 Mdot
.60349 .73184 Mdot
.49781 .69742 Mdot
.59573 .20354 Mdot
.64803 .19464 Mdot
.33835 .44067 Mdot
.59465 .45264 Mdot
.21798 .68367 Mdot
.45249 .64469 Mdot
.81328 .37137 Mdot
.34387 .26124 Mdot
.81421 .54148 Mdot
.56728 .39112 Mdot
.50395 .59179 Mdot
.48336 .5656 Mdot
.52656 .80469 Mdot
.71213 .34943 Mdot
.41474 .75146 Mdot
.18822 .38427 Mdot
.22415 .66715 Mdot
.62236 .60973 Mdot
.36333 .69799 Mdot
.31966 .7437 Mdot
.26932 .32331 Mdot
.54197 .47211 Mdot
.22901 .5994 Mdot
.28168 .57278 Mdot
.19064 .61213 Mdot
.58646 .43604 Mdot
.3949 .42788 Mdot
.66652 .35603 Mdot
.41361 .28452 Mdot
.7882 .56758 Mdot
.51713 .61079 Mdot
.78851 .65383 Mdot
.3604 .75237 Mdot
.66991 .24281 Mdot
.78355 .36415 Mdot
.83006 .43014 Mdot
.67567 .71912 Mdot
.2509 .36703 Mdot
.29799 .29361 Mdot
.25479 .27862 Mdot
.4552 .44977 Mdot
.30703 .67632 Mdot
.25988 .57476 Mdot
.45347 .81981 Mdot
.62444 .37308 Mdot
.75145 .39895 Mdot
.65521 .32666 Mdot
.45343 .78878 Mdot
.60139 .6924 Mdot
.3819 .76424 Mdot
.54074 .42133 Mdot
.87635 .46168 Mdot
.2109 .46388 Mdot
.51788 .41963 Mdot
.40694 .39057 Mdot
.27379 .35424 Mdot
.30941 .71256 Mdot
.21283 .46976 Mdot
.3445 .23621 Mdot
.39646 .3128 Mdot
.54997 .5115 Mdot
.51988 .76381 Mdot
.28506 .52755 Mdot
.18445 .54147 Mdot
.32367 .55417 Mdot
.41925 .80877 Mdot
.55312 .81503 Mdot
.78895 .65056 Mdot
.3109 .65765 Mdot
.16431 .51752 Mdot
.70218 .39827 Mdot
.26075 .51519 Mdot
.34489 .26265 Mdot
.33506 .39111 Mdot
.71631 .52183 Mdot
.56798 .10466 Mdot
.17816 .44344 Mdot
.23534 .40508 Mdot
.78638 .67875 Mdot
.18811 .49385 Mdot
.60105 .28577 Mdot
.5867 .62194 Mdot
.77424 .46301 Mdot
.76246 .6717 Mdot
.47721 .6091 Mdot
.84119 .44319 Mdot
.39341 .53032 Mdot
.88592 .53043 Mdot
.3551 .7723 Mdot
.59439 .44884 Mdot
.543 .60251 Mdot
.43127 .33081 Mdot
.42547 .45905 Mdot
.38672 .68488 Mdot
.57047 .70203 Mdot
.74078 .34273 Mdot
.63757 .31245 Mdot
.46148 .34292 Mdot
.39522 .29589 Mdot
.71336 .51227 Mdot
.22046 .52338 Mdot
.45626 .29615 Mdot
.47983 .37215 Mdot
.46563 .43721 Mdot
.38124 .54934 Mdot
.70136 .32062 Mdot
.55814 .78094 Mdot
.76759 .57824 Mdot
.66651 .44303 Mdot
.45225 .36095 Mdot
.59313 .77162 Mdot
.19305 .43733 Mdot
.2151 .66024 Mdot
.79349 .67019 Mdot
.49888 .49818 Mdot
.57318 .72296 Mdot
.37728 .62538 Mdot
.79668 .42247 Mdot
.63116 .47841 Mdot
.62831 .31151 Mdot
.69546 .27699 Mdot
.5943 .53513 Mdot
.44028 .23562 Mdot
.6975 .7659 Mdot
.32433 .25816 Mdot
.2861 .27475 Mdot
.36962 .45809 Mdot
.47292 .53944 Mdot
.6276 .58311 Mdot
.3244 .59743 Mdot
.54849 .39131 Mdot
.39153 .16881 Mdot
.50802 .55585 Mdot
.35474 .16182 Mdot
.61998 .36814 Mdot
.6742 .59805 Mdot
.27645 .57659 Mdot
.54817 .45607 Mdot
.54773 .41928 Mdot
.21779 .44277 Mdot
.75893 .40071 Mdot
.2542 .35388 Mdot
.79434 .45273 Mdot
.45413 .33137 Mdot
.16286 .42819 Mdot
.15752 .55807 Mdot
.61775 .73103 Mdot
.44604 .67102 Mdot
.16455 .47118 Mdot
.46805 .35835 Mdot
.76389 .58908 Mdot
.26999 .73735 Mdot
.20422 .58536 Mdot
.51392 .75537 Mdot
.31613 .54066 Mdot
.31219 .6807 Mdot
.54057 .83949 Mdot
.65227 .21012 Mdot
.26998 .68304 Mdot
.62347 .37561 Mdot
.54094 .43105 Mdot
.34862 .72306 Mdot
.77107 .38809 Mdot
.58894 .30582 Mdot
.72993 .33782 Mdot
.28168 .21479 Mdot
.36916 .71373 Mdot
.39063 .71788 Mdot
.76878 .37102 Mdot
.61353 .55976 Mdot
.75408 .37625 Mdot
.71041 .31632 Mdot
.20186 .53443 Mdot
.21417 .3864 Mdot
.71071 .32224 Mdot
.27046 .25478 Mdot
.57173 .57414 Mdot
.51687 .35668 Mdot
.5318 .69785 Mdot
.41177 .72598 Mdot
.59262 .4153 Mdot
.70787 .72851 Mdot
.24028 .68968 Mdot
.60181 .31815 Mdot
.18923 .55963 Mdot
.40567 .25799 Mdot
.41647 .72105 Mdot
.54093 .7921 Mdot
.21778 .63353 Mdot
.5959 .70807 Mdot
.59032 .19112 Mdot
.75078 .62289 Mdot
.47178 .36377 Mdot
.27399 .72181 Mdot
.44098 .35381 Mdot
.48236 .73022 Mdot
.76687 .50443 Mdot
.23293 .59855 Mdot
.81902 .52503 Mdot
.32601 .50287 Mdot
.69311 .5405 Mdot
.65208 .20152 Mdot
.62005 .53264 Mdot
.83902 .47453 Mdot
.71724 .59649 Mdot
.72058 .305 Mdot
.29045 .36017 Mdot
.2694 .39422 Mdot
.26789 .23601 Mdot
.56467 .32234 Mdot
.46464 .32902 Mdot
.56627 .19856 Mdot
.69554 .53201 Mdot
.36911 .46104 Mdot
.39884 .38735 Mdot
.45614 .4308 Mdot
.51303 .21287 Mdot
.57027 .57004 Mdot
.60811 .52348 Mdot
.44517 .43563 Mdot
.64288 .78041 Mdot
.63164 .80929 Mdot
.43525 .39813 Mdot
.4113 .14732 Mdot
.54106 .62249 Mdot
.6386 .72454 Mdot
.40063 .80236 Mdot
.54026 .13903 Mdot
.48466 .33499 Mdot
.16468 .6006 Mdot
.4254 .6069 Mdot
.22115 .60966 Mdot
.67594 .51431 Mdot
.33435 .25685 Mdot
.28928 .46758 Mdot
.30421 .54913 Mdot
.61494 .33213 Mdot
.77163 .55873 Mdot
.47359 .31911 Mdot
.67052 .56038 Mdot
.20984 .54378 Mdot
.38542 .6129 Mdot
.63552 .3837 Mdot
.30902 .32618 Mdot
.61278 .73779 Mdot
.46772 .7698 Mdot
.59677 .59392 Mdot
.38195 .70413 Mdot
.24548 .30575 Mdot
.86395 .58384 Mdot
.7273 .50031 Mdot
.60348 .49322 Mdot
.56985 .21794 Mdot
.20103 .59847 Mdot
.63071 .24052 Mdot
.4229 .82263 Mdot
.39495 .54306 Mdot
.51025 .52328 Mdot
.40303 .55433 Mdot
.5022 .70591 Mdot
.51969 .45344 Mdot
.52096 .27818 Mdot
.75776 .3433 Mdot
.68556 .31159 Mdot
.60648 .63027 Mdot
.61897 .21886 Mdot
.37177 .66604 Mdot
.72334 .31302 Mdot
.47017 .3913 Mdot
.47516 .77004 Mdot
.64284 .42776 Mdot
.63478 .81013 Mdot
.41528 .81542 Mdot
.56056 .36976 Mdot
.36757 .3083 Mdot
.21322 .69154 Mdot
.45775 .56769 Mdot
.56208 .49942 Mdot
.49431 .65921 Mdot
.47658 .50247 Mdot
.50008 .13324 Mdot
.19792 .56969 Mdot
.45717 .69121 Mdot
.45936 .80191 Mdot
.49632 .8154 Mdot
.88233 .4895 Mdot
.34105 .22007 Mdot
.65082 .53787 Mdot
.86263 .49399 Mdot
.7323 .33523 Mdot
.52741 .83809 Mdot
.56832 .29032 Mdot
.46204 .85892 Mdot
.60797 .72687 Mdot
.19844 .61636 Mdot
.58554 .60801 Mdot
.76778 .43569 Mdot
.32291 .29942 Mdot
.56085 .49312 Mdot
.53558 .24186 Mdot
.20471 .44901 Mdot
.15599 .41945 Mdot
.47381 .70967 Mdot
.35455 .27369 Mdot
.68311 .45144 Mdot
.28913 .74086 Mdot
.23283 .44275 Mdot
.46478 .68452 Mdot
.66044 .38341 Mdot
.80332 .54163 Mdot
.38484 .55168 Mdot
.58917 .51811 Mdot
.23546 .43115 Mdot
.76016 .65944 Mdot
.37778 .64375 Mdot
.29393 .2701 Mdot
.60886 .73637 Mdot
.45026 .45758 Mdot
.48019 .58225 Mdot
.64971 .48585 Mdot
.33985 .45322 Mdot
.54048 .48994 Mdot
.45102 .66863 Mdot
.38918 .39315 Mdot
.60115 .30301 Mdot
.82791 .47191 Mdot
.68637 .35147 Mdot
.2847 .29156 Mdot
.6006 .58588 Mdot
.7314 .4633 Mdot
.62138 .23565 Mdot
.82289 .43223 Mdot
.26421 .43668 Mdot
.3787 .5604 Mdot
.40389 .77426 Mdot
.55687 .81732 Mdot
.6774 .58464 Mdot
.85898 .5733 Mdot
.58968 .40858 Mdot
.4445 .74941 Mdot
.74546 .44827 Mdot
.45119 .31377 Mdot
.55343 .58397 Mdot
.1985 .6136 Mdot
.33312 .53122 Mdot
.34711 .66656 Mdot
.23258 .38028 Mdot
.50809 .5154 Mdot
.55339 .76836 Mdot
.46071 .80726 Mdot
.40849 .33384 Mdot
.25186 .31359 Mdot
.63176 .40823 Mdot
.2418 .42667 Mdot
.5574 .81999 Mdot
.76136 .70144 Mdot
.52887 .39451 Mdot
.28524 .56445 Mdot
.48519 .64128 Mdot
.27551 .27433 Mdot
.19581 .5652 Mdot
.42569 .72336 Mdot
.48998 .2501 Mdot
.64129 .50407 Mdot
.48369 .28525 Mdot
.4705 .46171 Mdot
.75148 .6796 Mdot
.64554 .49527 Mdot
.7047 .28263 Mdot
.32631 .45084 Mdot
.58338 .46271 Mdot
.53336 .55195 Mdot
.29834 .56426 Mdot
.35019 .19843 Mdot
.51665 .55256 Mdot
.27754 .69958 Mdot
.60452 .75673 Mdot
.36927 .24556 Mdot
.21629 .61718 Mdot
.61457 .28701 Mdot
.76056 .40407 Mdot
.49811 .77956 Mdot
.65989 .32604 Mdot
.52503 .63194 Mdot
.46903 .3464 Mdot
.65934 .5606 Mdot
.27616 .73158 Mdot
.6713 .72688 Mdot
.31963 .5893 Mdot
.38837 .48449 Mdot
.58506 .53487 Mdot
.63646 .4177 Mdot
.44111 .8453 Mdot
.76438 .41318 Mdot
.36196 .54636 Mdot
.44421 .48166 Mdot
.28429 .57765 Mdot
.66733 .61706 Mdot
.74576 .73133 Mdot
.58884 .61763 Mdot
.49239 .42355 Mdot
.68288 .59411 Mdot
.23803 .38714 Mdot
.26214 .73379 Mdot
.40675 .55611 Mdot
.57325 .44753 Mdot
.33864 .50141 Mdot
.62884 .25509 Mdot
.37978 .4717 Mdot
.57735 .51527 Mdot
.42336 .43598 Mdot
.49416 .22979 Mdot
.73314 .48295 Mdot
.39617 .61955 Mdot
.32215 .66281 Mdot
.42138 .78569 Mdot
.37463 .23593 Mdot
.64529 .32943 Mdot
.51389 .32136 Mdot
.71116 .71858 Mdot
.48547 .87142 Mdot
.72497 .27491 Mdot
.48149 .64315 Mdot
.65227 .376 Mdot
.27108 .55309 Mdot
.39481 .36007 Mdot
.69126 .30251 Mdot
.65035 .27129 Mdot
.61314 .39098 Mdot
.32078 .53617 Mdot
.35874 .66517 Mdot
.37581 .28671 Mdot
.24417 .53365 Mdot
.6524 .42038 Mdot
.82865 .45403 Mdot
.17791 .47591 Mdot
.20251 .60139 Mdot
.60089 .86672 Mdot
.64242 .36826 Mdot
.43635 .70985 Mdot
.60814 .66844 Mdot
.58784 .82293 Mdot
.33075 .55831 Mdot
.77208 .59993 Mdot
.58196 .25533 Mdot
.41306 .54989 Mdot
.70465 .48412 Mdot
.33738 .66715 Mdot
.47711 .28146 Mdot
.52217 .44077 Mdot
.26905 .4004 Mdot
.86516 .57072 Mdot
.53635 .75918 Mdot
.40942 .78485 Mdot
.80257 .52393 Mdot
.2565 .27441 Mdot
.58037 .82607 Mdot
.3267 .63266 Mdot
.22949 .46393 Mdot
.57539 .67297 Mdot
.566 .4263 Mdot
.64964 .60278 Mdot
.7664 .5903 Mdot
.60267 .78518 Mdot
.32132 .34896 Mdot
.66511 .60765 Mdot
.38372 .58857 Mdot
.63154 .77603 Mdot
.57361 .44655 Mdot
.56598 .78185 Mdot
.37854 .3037 Mdot
.75772 .36014 Mdot
.68814 .56834 Mdot
.34229 .58146 Mdot
.60469 .76289 Mdot
.54654 .21301 Mdot
.20045 .47062 Mdot
.21643 .30495 Mdot
.33612 .42437 Mdot
.81624 .44835 Mdot
.42274 .64335 Mdot
.89545 .45449 Mdot
.28244 .32831 Mdot
.32127 .30678 Mdot
.23511 .36615 Mdot
.38775 .41558 Mdot
.49851 .71791 Mdot
.5252 .63133 Mdot
.30368 .71152 Mdot
.51739 .75474 Mdot
.71708 .61706 Mdot
.77675 .54648 Mdot
.30465 .54252 Mdot
.3702 .58411 Mdot
.3251 .60389 Mdot
.54029 .53806 Mdot
.63942 .50914 Mdot
.85067 .46852 Mdot
.52154 .389 Mdot
.42384 .72007 Mdot
.50731 .54309 Mdot
.5842 .65588 Mdot
.21173 .71717 Mdot
.60017 .44521 Mdot
.39071 .71154 Mdot
.57348 .75644 Mdot
.68929 .57814 Mdot
.63853 .24336 Mdot
.8225 .71129 Mdot
.91182 .4594 Mdot
.6799 .5566 Mdot
.40305 .20853 Mdot
.56247 .75982 Mdot
.42514 .76388 Mdot
.2744 .42497 Mdot
.47554 .2443 Mdot
.43827 .73982 Mdot
.74902 .52866 Mdot
.55421 .56938 Mdot
.28591 .31873 Mdot
.65913 .80037 Mdot
.77073 .54721 Mdot
.45601 .79994 Mdot
.51802 .68893 Mdot
.54639 .56287 Mdot
.57313 .88085 Mdot
.35739 .72886 Mdot
.53489 .58559 Mdot
.61547 .61318 Mdot
.40876 .59465 Mdot
.49928 .60929 Mdot
.23828 .63503 Mdot
.16567 .4246 Mdot
.37676 .6464 Mdot
.45102 .787 Mdot
.67683 .48951 Mdot
.37545 .37732 Mdot
.62069 .36414 Mdot
.53358 .39904 Mdot
.51763 .56687 Mdot
.59609 .4031 Mdot
.45363 .51451 Mdot
.21414 .68411 Mdot
.39387 .47075 Mdot
.20611 .36377 Mdot
.52473 .85594 Mdot
.65491 .73735 Mdot
.64994 .28119 Mdot
.45265 .57075 Mdot
.4689 .77259 Mdot
.57658 .80177 Mdot
.56605 .524 Mdot
.17783 .56188 Mdot
.67807 .1677 Mdot
.61871 .265 Mdot
.74235 .69847 Mdot
.64034 .56826 Mdot
.42088 .44791 Mdot
.53373 .77287 Mdot
.56878 .29554 Mdot
.42388 .39655 Mdot
.53902 .6653 Mdot
.60435 .55171 Mdot
.57626 .40833 Mdot
.42791 .13526 Mdot
.44347 .66858 Mdot
.6716 .2812 Mdot
.50592 .83109 Mdot
.75179 .62171 Mdot
.6349 .69792 Mdot
.51113 .58094 Mdot
.69842 .4331 Mdot
.57251 .44817 Mdot
.2686 .69878 Mdot
.77774 .66717 Mdot
.40575 .76227 Mdot
.66822 .73058 Mdot
.55506 .76662 Mdot
.47865 .58346 Mdot
.27887 .47688 Mdot
.54564 .34246 Mdot
.28109 .68878 Mdot
.42204 .57984 Mdot
.57777 .83588 Mdot
.47011 .31417 Mdot
.44941 .49031 Mdot
.60605 .45498 Mdot
.87778 .49193 Mdot
.61835 .64109 Mdot
.61179 .58808 Mdot
.8243 .43683 Mdot
.44844 .30519 Mdot
.2621 .52414 Mdot
.42274 .32835 Mdot
.43635 .57421 Mdot
.62886 .50211 Mdot
.81685 .37122 Mdot
.27535 .66861 Mdot
.54512 .24 Mdot
.49874 .25836 Mdot
.41639 .22173 Mdot
.63376 .39152 Mdot
.62131 .85972 Mdot
.28827 .34406 Mdot
.82926 .40435 Mdot
.24502 .30954 Mdot
.60398 .53919 Mdot
.18851 .50119 Mdot
.52965 .56262 Mdot
.4282 .39291 Mdot
.42503 .77345 Mdot
.43556 .71692 Mdot
.79848 .59961 Mdot
.45304 .58561 Mdot
.82694 .54676 Mdot
.34841 .48829 Mdot
.35178 .32211 Mdot
.24757 .37552 Mdot
.59126 .65508 Mdot
.37157 .80632 Mdot
.61572 .24196 Mdot
.38725 .80614 Mdot
.34826 .78438 Mdot
.47708 .81831 Mdot
.79445 .58473 Mdot
.6101 .17909 Mdot
.24057 .3899 Mdot
.21508 .6316 Mdot
.5303 .29272 Mdot
.57441 .64734 Mdot
.27199 .35567 Mdot
.58622 .55079 Mdot
.71074 .35077 Mdot
.65015 .40905 Mdot
.40942 .09554 Mdot
.35648 .60928 Mdot
.61723 .57866 Mdot
.26776 .36926 Mdot
.52231 .82826 Mdot
.58211 .66701 Mdot
.20745 .44002 Mdot
.48334 .46095 Mdot
.44633 .70122 Mdot
.60608 .78232 Mdot
.37566 .23106 Mdot
.34704 .29954 Mdot
.19913 .30127 Mdot
.19275 .44144 Mdot
.51696 .23456 Mdot
.5081 .44976 Mdot
.68299 .55426 Mdot
.57526 .18958 Mdot
.27683 .39035 Mdot
.1729 .54412 Mdot
.20125 .64804 Mdot
.35194 .72545 Mdot
.27542 .23116 Mdot
.3517 .2545 Mdot
.61483 .81572 Mdot
.18881 .52075 Mdot
.67905 .55821 Mdot
.31432 .62396 Mdot
.47061 .37604 Mdot
.53349 .25915 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Dooooo`;o0000/ooo
ool001cooooo00?o0000ooooooooool0U?ooool2o`0000cooooo0_l0002Uooooo`007?ooool00ol0
003oooooooooo`21ooooo`;o00007oooool2o`000:Gooooo000Looooo`;o0000P_ooool2o`000<Ko
oooo000Looooo`03o`000?oooooooooo09cooooo0_l0000?ooooo`;o0000V_ooool001cooooo00?o
0000ooooooooool0W?ooool2o`0000Wooooo0_l00004ooooo`;o00001_ooool2o`0009;ooooo000L
ooooo`03o`000?oooooooooo0:Oooooo0_l0000<ooooo`;o0000T_ooool001cooooo00?o0000oooo
ooooool0V_ooool2o`000:gooooo000Looooo`03o`000?oooooooooo09[ooooo0_l0002]ooooo`00
7?ooool00ol0003oooooooooo`2Fooooo`;o0000/Oooool001cooooo00?o0000ooooooooool0U_oo
ool2o`0001;ooooo0_l0002Mooooo`007?ooool00ol0003oooooooooo`2Zooooo`;o0000WOooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Xooooo`;o
0000Woooool001cooooo00?o0000ooooooooool0Qoooool2o`0001Kooooo0_l00007ooooo`;o0000
Woooool001cooooo00?o0000ooooooooool0Qoooool2o`0001Kooooo0_l0002Xooooo`007?ooool0
0ol0003oooooooooo`2/ooooo`Co0000VOooool001cooooo00?o0000ooooooooool0[?ooool4o`00
02Oooooo0_l0001`ooooo`007?ooool00ol0003oooooooooo`22ooooo`;o0000>_ooool2o`0001Oo
oooo0_l0001`ooooo`007?ooool00ol0003oooooooooo`1looooo`;o00001?ooool2o`0003[ooooo
0_l00029ooooo`007?ooool2o`0007gooooo0_l0000@ooooo`;o0000^Oooool001cooooo00?o0000
ooooooooool0S_ooool2o`0002Oooooo0_l0002@ooooo`007?ooool00ol0003oooooooooo`2goooo
o`;o0000T?ooool001cooooo00?o0000ooooooooool0L?ooool2o`0000Cooooo0_l0000Cooooo`;o
0000<?ooool2o`0008[ooooo000Looooo`03o`000?oooooooooo073ooooo0_l00004ooooo`;o0000
4oooool2o`0000Kooooo0_l0000Eooooo`;o00004Oooool3o`0008Wooooo000Looooo`03o`000?oo
oooooooo07_ooooo0_l00007ooooo`;o00003Oooool2o`0000oooooo0_l00004ooooo`;o00004_oo
ool2o`0001Sooooo0_l0001_ooooo`007?ooool00ol0003oooooooooo`1kooooo`;o00001oooool2
o`0000Kooooo0_l00005ooooo`;o00000_ooool2o`0000Oooooo0_l00002ooooo`;o00001oooool2
o`0002Wooooo0_l0001_ooooo`007?ooool00ol0003oooooooooo`26ooooo`;o00001?ooool2o`00
00Wooooo0_l00007ooooo`;o00002oooool2o`0000Oooooo0_l0002Aooooo`007?ooool00ol0003o
ooooooooo`26ooooo`;o00005?ooool3o`000003ooooool0003o000000Gooooo0_l0000=ooooo`;o
0000TOooool001cooooo00?o0000ooooooooool0NOooool2o`0000Gooooo0_l00009ooooo`;o0000
3oooool3o`0000Sooooo0_l0000?ooooo`;o00002?ooool2o`0008Gooooo000Looooo`03o`000?oo
oooooooo07Wooooo0_l00005ooooo`;o00002Oooool2o`0001Cooooo0_l0000Eooooo`;o000000?o
ooooo`000?l000001Oooool2o`0000;ooooo0_l00005ooooo`;o0000N_ooool001cooooo00?o0000
ooooooooool0M_ooool2o`0001?ooooo0_l00006ooooo`?o00000_ooool2o`0000Oooooo0_l00005
ooooo`;o00004Oooool2o`0000Wooooo0_l00005ooooo`;o0000N_ooool001cooooo00?o0000oooo
ooooool0KOooool2o`0000;ooooo0_l00003ooooo`;o00006oooool3o`0000;ooooo0_l00002oooo
o`;o00002_ooool2o`0000Gooooo0_l00002ooooo`;o00000_ooool2o`00093ooooo00001_oooooo
k^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`1/
ooooo`?o00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o00006Oooool2
o`0000;ooooo0_l0000Aooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o0000Roooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A006ooooo`03o`000?oooooooooo06cooooo0_l00008ooooo`;o000000?oooooo`000?l00000
0_ooool2o`0000Gooooo0_l00005ooooo`;o000000?oooooo`000?l000002?ooool2o`0000oooooo
0_l0000Aooooo`;o000000?oooooo`000?l000003_ooool2o`0007Sooooo00000ooooooo410@oooo
o`02ooooo`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003ooooooooo
o`1^ooooo`;o00004?ooool2o`000004ooooool0003o0000o`0000Gooooo0_l000000ooooooo0000
o`00000Cooooo`;o00001?ooool2o`0000Wooooo0_l00008ooooo`?o00001_ooool2o`0000Kooooo
0_l00004ooooo`;o0000L_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02ooo
ool00onHV9So8B4Qonk^kP06ooooo`?o0000Hoooool2o`0000Wooooo0_l0000@ooooo`;o000000?o
ooooo`000?l000000oooool2o`0001Cooooo1ol000000ooooooo0000o`000002o`0000[ooooo0_l0
0008ooooo`;o00001oooool2o`0000Oooooo0_l00003ooooo`;o0000L_ooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooo
oooo06?ooooo0_l00003ooooo`;o00004oooool2o`0000Wooooo0_l0000Cooooo`Oo00000_ooool4
o`0001Cooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00003ooooo`;o00000_ooool2
o`0007Oooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`1Xooooo`;o00002_ooool2o`0000Oooooo1?l00005oooo
o`;o00005Oooool6o`0001Wooooo1?l000000ooooooo0000o`000005o`0000Cooooo0_l00002oooo
o`;o0000Moooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonH
V9So410@00Kooooo00?o0000ooooooooool0Koooool2o`0000?ooooo0_l00009ooooo`;o00001Ooo
ool2o`00017ooooo0_l00006ooooo`;o00003oooool3o`0000Oooooo0_l00007ooooo`?o00002?oo
ool2o`0000Sooooo0_l0001]ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Hooooo`;o00005Oooool3o`0000Oo
oooo0_l00003ooooo`;o00002?ooool2o`0000oooooo0_l00008ooooo`;o00002Oooool2o`0000;o
oooo0ol00009ooooo`;o00004?ooool2o`0000Sooooo0_l0001]ooooo`007?ooool00ol0003ooooo
ooooo`1Hooooo`;o00005_ooool2o`0000Oooooo0_l00003ooooo`;o00002?ooool2o`0001Wooooo
0_l00009ooooo`;o00001Oooool2o`0000Oooooo1?l00027ooooo`007?ooool00ol0003ooooooooo
o`1[ooooo`;o00004Oooool2o`0000Sooooo0_l00009ooooo`;o000000?oooooo`000?l000006Ooo
ool2o`0000;ooooo0_l00009ooooo`;o00000oooool2o`0008;ooooo000Looooo`03o`000?oooooo
oooo06Sooooo0_l000000ooooooo0000o`000003ooooo`;o00002Oooool2o`0000Oooooo0_l00002
ooooo`;o00002Oooool2o`000003ooooool0003o000001Wooooo0_l0000:ooooo`?o00001Oooool2
o`0008;ooooo000Looooo`03o`000?oooooooooo06Sooooo0_l00004ooooo`Co00001?ooool2o`00
0003ooooool0003o000000;o00001?ooool5o`0003Oooooo1?l0000Iooooo`;o0000KOooool001co
oooo00?o0000ooooooooool0F?ooool2o`0001Cooooo1?l00004ooooo`;o000000?oooooo`000?l0
00001_ooool3o`0000_ooooo0ol0000;ooooo`;o00002_ooool2o`0001Cooooo0_l00006ooooo`;o
00001_ooool2o`0000Wooooo0_l0001]ooooo`007?ooool00ol0003oooooooooo`1Fooooo`Co0000
7?ooool2o`0000;ooooo0_l000000ooooooo0000o`000007ooooo`;o00000_ooool3o`0000;ooooo
0ol0000;ooooo`Co00002?ooool2o`0001cooooo0ol00005ooooo`;o0000N?ooool001cooooo00?o
0000ooooooooool0Doooool2o`000003ooooool0003o000001Cooooo0_l00008ooooo`;o00000_oo
ool2o`000003ooooool0003o000000Gooooo1?l00002ooooo`?o00004_ooool2o`0000?ooooo0ol0
0008ooooo`Co000000?oooooo`000?l000002oooool2o`0000?ooooo1?l000000ooooooo0000o`00
0002ooooo`;o0000N?ooool001cooooo00?o0000ooooooooool0Doooool2o`0001?ooooo0_l00002
ooooo`;o00002?ooool2o`0000cooooo0_l00003ooooo`Co00001Oooool2o`00013ooooo0ol00006
ooooo`Ko000000?oooooo`000?l000000oooool2o`0000Kooooo0_l00003ooooo`;o00000oooool2
o`0001Kooooo0_l0001Tooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00007Oooool2o`00
00cooooo0ol0000@ooooo`;o00001oooool2o`0001Kooooo1ol00008ooooo`;o00002Oooool2o`00
00?ooooo0_l00009ooooo`Co00002oooool2o`0006Cooooo000Looooo`03o`000?oooooooooo04Wo
oooo0_l0000Mooooo`;o00002_ooool5o`0000_ooooo0_l0000Aooooo`Co000000?oooooo`000?l0
00001oooool2o`0000?ooooo1?l0000<ooooo`Ko00001?ooool2o`0000?ooooo0_l000001?oooooo
0000o`000?l00002ooooo`;o000000?oooooo`000?l000000_l0001aooooo`007?ooool00ol0003o
ooooooooo`1Wooooo`?o00002_ooool3o`0000gooooo0_l00002ooooo`;o00003Oooool4o`000003
ooooool0003o000000Oooooo1?l0000@ooooo`Oo00003?ooool3o`0000;ooooo0_l00003ooooo`;o
0000LOooool001cooooo0_l0001Uooooo`;o000000?oooooo`000?l000007oooool2o`00017ooooo
0_l00002ooooo`;o000000Coooooo`000?l0003ooooo1?l0000@ooooo`;o00001?ooool2o`0008So
oooo000Looooo`03o`000?oooooooooo05Cooooo0_l0000>ooooo`;o00001_ooool2o`000003oooo
ool0003o000001;ooooo0_l0000:ooooo`;o00002_ooool2o`0000;ooooo0_l000001?oooooo0000
o`000?ooool2o`0000Cooooo0_l0000;ooooo`?o00001?ooool4o`0000Gooooo0_l0000Nooooo`;o
0000Goooool001cooooo00?o0000ooooooooool0E?ooool2o`0000_ooooo0_l00003ooooo`;o0000
00Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000002o`0000gooooo0_l000000ooooooo
0000o`000006ooooo`;o00000_ooool2o`0000Cooooo0_l00007ooooo`;o00000oooool2o`0000?o
oooo1Ol00002ooooo`;o00001oooool6o`0000?ooooo0ol000001?oooooo0000o`000?ooool2o`00
00Oooooo1?l0000Cooooo`;o0000Goooool001cooooo00?o0000ooooooooool0HOooool7o`000004
ooooool0003o0000ooooo`;o00000oooool2o`0000;ooooo0_l00009ooooo`;o00002Oooool2o`00
00Sooooo0_l00002ooooo`;o00000oooool2o`0000?ooooo0_l00003ooooo`Wo000000?oooooo`00
0?l000001oooool3o`0000Cooooo0_l000000ooooooo0000o`00000:ooooo`Co00004Oooool2o`00
067ooooo000Looooo`03o`000?oooooooooo053ooooo0_l0000Aooooo`Co00001Oooool2o`0000Oo
oooo0_l0000;ooooo`;o00001oooool2o`0000;ooooo1?l00006ooooo`;o00000oooool2o`0000[o
oooo1_l00002ooooo`;o00003oooool2o`00027ooooo0_l0001Qooooo`007?ooool00ol0003ooooo
ooooo`1@ooooo`;o00001oooool2o`00017ooooo0_l00004ooooo`;o00000_ooool2o`0000Kooooo
0_l00002ooooo`;o00002_ooool5o`0000?ooooo0ol00005ooooo`;o00002Oooool3o`0000?ooooo
0_l0000Aooooo`Go00001oooool2o`0000Sooooo0_l000000ooooooo0000o`00001/ooooo`007?oo
ool00ol0003oooooooooo`1Gooooo`Co000000?oooooo`000?l000003_ooool2o`000003ooooool0
003o000000?o00000_ooool2o`0000Kooooo0_l0000>ooooo`;o00001_ooool3o`0000?ooooo0_l0
0006ooooo`;o00000oooool5o`000003ooooool0003o000000_ooooo0_l00004ooooo`;o000000?o
ooooo`000?l000001Oooool4o`0000Sooooo1Ol00005ooooo`?o00002?ooool2o`0000;ooooo0_l0
001Fooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00000_ooool2o`0000?ooooo1Ol0000>
ooooo`?o00004_ooool2o`0000_ooooo0_l000000ooooooo0000o`000004ooooo`Co00001_ooool2
o`0000Kooooo0_l000000ooooooo0000o`00000;ooooo`;o00000oooool2o`0000?ooooo0_l00004
ooooo`;o000000?oooooo`000?l000001_ooool5o`0000Kooooo0ol000000ooooooo0000o`000005
ooooo`;o00000_ooool2o`0005Kooooo000Looooo`03o`000?oooooooooo053ooooo0_l000000ooo
oooo0000o`000003o`000004ooooool0003o0000o`0000;ooooo0ol000001?oooooo0000o`000?l0
0006ooooo`?o000000?oooooo`000?l000004oooool2o`0000_ooooo0_l000000ooooooo0000o`00
0004ooooo`;o00004oooool2o`00013ooooo0ol00002ooooo`?o000000?oooooo`000?l000000ooo
ool2o`0000Kooooo1?l00003ooooo`;o00001_ooool4o`0005oooooo000Looooo`03o`000?oooooo
oooo04oooooo0ol00002ooooo`Co000000Coooooo`000?l0003o00001_ooool3o`0000?ooooo0_l0
00001?oooooo0000o`000?l00004ooooo`Co0000;oooool2o`0000?ooooo0_l00007ooooo`;o0000
3?ooool5o`000004ooooool0003o0000ooooo`;o00001?ooool2o`0000Oooooo0_l00003ooooo`;o
00002?ooool2o`0000[ooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`1?ooooo`;o0000
1?ooool2o`0000Gooooo0_l00004ooooo`;o00001?ooool2o`000004ooooool0003o0000o`0000Co
oooo1?l0000:ooooo`;o00003oooool3o`0000?ooooo0_l0000<ooooo`Oo00001oooool3o`0000ko
oooo0_l00009ooooo`Ko000000Coooooo`000?l0003ooooo0_l00006ooooo`;o00004Oooool2o`00
05?ooooo000Looooo`03o`000?oooooooooo05cooooo0_l0000Kooooo`;o000000?oooooo`000?l0
00000_ooool2o`000003ooooool0003o000000cooooo0ol00003ooooo`Co00002oooool4o`0000[o
oooo0_l00007ooooo`Co00001_ooool2o`0000Kooooo1_l000000ooooooo0000o`000003ooooo`;o
00001?ooool2o`0006Kooooo000Looooo`03o`000?oooooooooo07Kooooo0_l000001?oooooo0000
o`000?ooool2o`0000Gooooo0_l0000;ooooo`Co00001Oooool2o`0001oooooo1ol000000ooooooo
0000o`000002o`000003ooooool0003o000000Kooooo0_l00007ooooo`;o000000?oooooo`000?l0
00000_ooool2o`0006Sooooo000Looooo`03o`000?oooooooooo05Wooooo0_l0000Aooooo`;o0000
0_ooool2o`0000Cooooo0_l0000Hooooo`Co00003_ooool2o`0000;ooooo0_l0000=ooooo`;o0000
0oooool5o`0000;ooooo1Ol00005ooooo`;o00002?ooool2o`000004ooooool0003o0000ooooo`;o
00000_ooool2o`0006Sooooo000Looooo`03o`000?oooooooooo03gooooo0_l0000Jooooo`;o0000
0_ooool2o`0000_ooooo1?l00002ooooo`;o00003oooool2o`0000?ooooo0_l00008ooooo`Co0000
3_ooool3o`000003ooooool0003o000000;o00002oooool2o`0000Kooooo0_l00002ooooo`;o0000
2?ooool2o`0000Sooooo0_l00009ooooo`;o0000Ioooool001cooooo00?o0000ooooooooool0?Ooo
ool2o`0001_ooooo0_l000000ooooooo0000o`00000;ooooo`?o00000_ooool2o`0000cooooo0_l0
0002ooooo`;o00000oooool2o`0000Cooooo0_l00002ooooo`Co00003oooool2o`0000?ooooo1?l0
0009ooooo`;o00002?ooool2o`0001;ooooo0ol00003ooooo`;o00001Oooool2o`0006Oooooo000L
ooooo`;o0000?_ooool2o`0001_ooooo0_l00009ooooo`;o00001?ooool:o`0000Oooooo0ol0000=
ooooo`Ko00005_ooool4o`0000Gooooo0_l00007ooooo`Oo00004_ooool3o`0000?ooooo0_l0000?
ooooo`;o0000GOooool001cooooo00?o0000ooooooooool0?Oooool2o`00027ooooo0_l00003oooo
o`;o00001_ooool2o`0000;ooooo1?l00002ooooo`;o00000oooool2o`00013ooooo0_l000000ooo
oooo0000o`000008ooooo`;o00002?ooool3o`000003ooooool0003o000000Kooooo0_l00004oooo
o`;o000000?oooooo`000?l000001Ol0000Looooo`;o00002Oooool4o`0005gooooo000Looooo`03
o`000?oooooooooo04?ooooo0_l00007ooooo`;o00000_ooool2o`0000?ooooo0_l00009ooooo`;o
00000oooool2o`0000;ooooo1_l00008ooooo`;o00000_ooool2o`0000Oooooo1Ol00005ooooo`;o
000000?oooooo`000?l000002?ooool2o`0000Oooooo1?l00005ooooo`;o00001oooool8o`000003
ooooool0003o000000Cooooo0ol00007ooooo`;o00000oooool2o`0000Oooooo0_l00007ooooo`Go
0000G_ooool001cooooo00?o0000ooooooooool0@oooool2o`0000Oooooo0_l00002ooooo`;o0000
0oooool2o`0000;ooooo0_l0000:ooooo`;o00000_ooool5o`0000Kooooo0_l000000ooooooo0000
o`000002ooooo`;o00001_ooool6o`0000;ooooo0_l000000ooooooo0000o`00000;ooooo`;o0000
1oooool2o`0000Oooooo0_l00007ooooo`So00001oooool3o`0000Kooooo0ol00003ooooo`;o0000
4?ooool2o`000004ooooool0003o0000ooooo`;o0000Foooool001cooooo00?o0000ooooooooool0
C?ooool4o`0000Wooooo0_l00003ooooo`;o00000oooool2o`0000?ooooo0_l00002ooooo`;o0000
1_ooool2o`000003ooooool0003o000000Cooooo0_l00004ooooo`;o00001?ooool4o`0000;ooooo
0_l00004ooooo`;o00000oooool2o`0000Cooooo0_l00006ooooo`;o00003Oooool2o`0000;ooooo
0_l00004ooooo`Co00000oooool2o`000004ooooool0003o0000ooooo`;o00001?ooool2o`0000Go
oooo0_l0000:ooooo`;o00000oooool2o`0001Cooooo0_l00015ooooo`007?ooool00ol0003ooooo
ooooo`1:ooooo`;o00000_ooool2o`0000Gooooo0_l00004ooooo`;o000000Coooooo`000?l0003o
oooo1?l00003ooooo`;o00001?ooool2o`0000Cooooo0_l00005ooooo`Co00001?ooool2o`0000?o
oooo0ol00004ooooo`;o00001?ooool2o`0000?ooooo0_l00004ooooo`;o00001_ooool2o`0000Wo
oooo0_l00007ooooo`Co000000?oooooo`000?l000000_l00003ooooo`;o000000?oooooo`000?l0
00000_l00003ooooo`Co00001Oooool2o`0000Kooooo0_l00002ooooo`;o00006Oooool2o`0004Go
oooo000Looooo`03o`000?oooooooooo04Gooooo0_l00003ooooo`;o00002Oooool2o`0000;ooooo
1?l00002ooooo`Co00000oooool4o`0000Cooooo0_l0000;ooooo`?o00001Oooool2o`0000?ooooo
0_l0000;ooooo`?o00002?ooool2o`0000kooooo0_l000000ooooooo0000o`000007ooooo`Ko0000
00?oooooo`000?l000000_l000000ooooooo0000o`000003ooooo`Co000000?oooooo`000?l00000
3oooool3o`000003ooooool0003o0000063ooooo000Looooo`03o`000?oooooooooo04Cooooo0ol0
0008ooooo`;o00000oooool2o`0000?ooooo1Ol000000ooooooo0000o`000004ooooo`Go00001Ooo
ool3o`0000Oooooo0_l000000ooooooo0000o`000005ooooo`Go00003_ooool2o`0000;ooooo0_l0
0004ooooo`;o000000Coooooo`000?l0003o00002_ooool2o`0000;ooooo0ol00008ooooo`Co0000
0_ooool2o`000003ooooool0003o000000Gooooo0_l00002ooooo`;o00002oooool2o`000005oooo
ool0003o0000o`000?ooool00_l0000Nooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0
A?ooool2o`0000Wooooo0_l00003ooooo`;o00001Oooool3o`000003ooooool0003o000000;o0000
0_ooool2o`0000Sooooo0ol00007ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000
o`000009o`0000kooooo0_l00007ooooo`?o00003_ooool3o`0000Sooooo2?l00008ooooo`;o0000
0_ooool2o`0000_ooooo0_l000000ooooooo0000o`00000Rooooo`;o0000@?ooool001cooooo00?o
0000ooooooooool0@_ooool2o`00013ooooo0_l00002ooooo`;o00001oooool2o`0000;ooooo0_l0
000Booooo`;o000000?oooooo`000?l000003ol00004ooooo`Co00009?ooool2o`000003ooooool0
003o000000Wo00001oooool8o`0000_ooooo0_l00007ooooo`;o00001_ooool2o`0005Gooooo000L
ooooo`03o`000?oooooooooo04;ooooo0_l00007ooooo`;o00002_ooool3o`0000_ooooo0_l00006
ooooo`Co00003oooool=o`000003ooooool0003o000000Ko00004Oooool2o`000003ooooool0003o
000000Oooooo0_l00004ooooo`;o000000?oooooo`000?l000002Ol000000ooooooo0000o`000004
ooooo`Go000000?oooooo`000?l000000oooool4o`0000Cooooo0ol00003ooooo`;o000000?ooooo
o`000?l000001_ooool2o`0005Gooooo000Looooo`03o`000?oooooooooo047ooooo0_l00007oooo
o`?o00002_ooool4o`000003ooooool0003o000000Oooooo0_l00006ooooo`Co00003Oooool?o`00
0003ooooool0003o000000?o000000?oooooo`000?l000001?ooool2o`0000_ooooo0_l000000ooo
oooo0000o`000007ooooo`;o00001?ooool>o`000003ooooool0003o000000Cooooo1?l00006oooo
o`Go00001Oooool4o`000004ooooool0003o0000ooooo`;o0000GOooool001cooooo00?o0000oooo
ooooool0@Oooool2o`0000Oooooo0_l0000=ooooo`;o000000?oooooo`000?l000007Oooool2o`00
0003ooooool0003o000000oo000000?oooooo`000?l000000ol00005ooooo`;o00002?ooool2o`00
01?ooooo3ol00006ooooo`?o00001oooool4o`0000?ooooo0_l00003ooooo`;o000000?oooooo`00
0?l000000ol0001Mooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o00002oooool2o`0001Ko
oooo0_l00009ooooo`;o000000?oooooo`000?l000005Ol0000:ooooo`;o00000oooool2o`0001?o
oooo4_l00004ooooo`;o00001?ooool2o`0000Sooooo0_l00008ooooo`;o0000:_ooool2o`0003;o
oooo000Looooo`03o`000?oooooooooo04_ooooo0_l0000;ooooo`Co00002Oooool2o`0000Wooooo
0_l0000;oooooaWo00002Oooool2o`0000?ooooo0_l00007ooooo`;o00001ooooolEo`0000?ooooo
1_l000000ooooooo0000o`00000Fooooo`;o00000oooool2o`0000?ooooo0_l0000Looooo`;o0000
<_ooool001cooooo00?o0000ooooooooool0A_ooool2o`0000?ooooo0_l0000=ooooo`;o00002Ooo
ool2o`0000Cooooo0_l00009ooooo`;o00001OoooolJo`0000Gooooo0_l00007ooooo`;o00001_oo
ool3o`0000Kooooo5Ol00003ooooo`Ko00002Oooool2o`0000kooooo0_l00003ooooo`;o00000ooo
ool2o`00053ooooo000Looooo`;o0000@Oooool2o`0000Cooooo0_l0000;ooooo`;o00002?ooool2
o`0000Kooooo0_l00004ooooo`;o00002Oooool2o`0000?ooooo1ol000000ooooooo0000o`00000B
o`0000Gooooo0_l00007ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`;o00000_ooool4
o`000003ooooool0003o000000co00002Oooool2o`0000Wooooo0_l00004ooooo`Co0000H_ooool0
01cooooo00?o0000ooooooooool0@?ooool2o`0000Cooooo0_l00007ooooo`;o00000_ooool2o`00
00Sooooo0_l00006ooooo`;o00003oooool2o`0000?ooooo4_l000000ooooooo0000o`000006o`00
01Cooooo0_l00004oooooaWo00000oooool2o`0000?ooooo0_l00008ooooo`;o00001_ooool4o`00
00Sooooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00002_ooool3o`0000?o
oooo0_l00007ooooo`Co00003_ooool2o`0000Cooooo0_l00003oooooaKo000000Coooooo`000?l0
003o00003oooool2o`0000Sooooo1?l000000ooooooo0000o`00000Io`0000?ooooo0_l00002oooo
o`;o00001?ooool4o`0000Oooooo0_l00007ooooo`;o0000F?ooool001cooooo00?o0000oooooooo
ool0@oooool2o`0000_ooooo0_l00003ooooo`;o00001?ooool2o`000003ooooool0003o000000;o
00002_ooool2o`0000;ooooo0_l00007oooooago00003_ooool2o`000003ooooool0003o000000Go
oooo0_l00005oooooaOo00002Oooool4o`0000Cooooo0_l00007ooooo`;o000000?oooooo`000?l0
00001oooool2o`0000kooooo0_l00015ooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o0000
1_ooool2o`0000Cooooo0_l000000ooooooo0000o`000002o`0000[ooooo0_l0000;oooooago0000
3oooool4o`0000Gooooo0_l00003oooooaWo00001_ooool2o`0000?ooooo0_l0000@ooooo`;o0000
1oooool2o`0000Cooooo0_l000000ooooooo0000o`000005ooooo`;o0000AOooool001cooooo00?o
0000ooooooooool0?oooool2o`0000Gooooo0_l000000ooooooo0000o`000002ooooo`;o00001_oo
ool2o`0002Cooooo2ol000000ooooooo0000o`000005o`000003ooooool0003o000000Wo00002ooo
ool2o`0000Oooooo0_l00003oooooaWo00000oooool2o`000003ooooool0003o000002Cooooo0_l0
00000ooooooo0000o`00001<ooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00001Oooool2
o`000003ooooool0003o000000?ooooo0_l00003ooooo`;o00005_ooool2o`0000Kooooo0_l00002
oooooa3o000000?oooooo`000?l000004?l0000HoooooaKo000000?oooooo`000?l000000_ooool4
o`000003ooooool0003o000000;ooooo0_l00003ooooo`;o00007_ooool2o`0000Kooooo0_l00014
ooooo`007?ooool00ol0003oooooooooo`1:ooooo`;o00000_ooool2o`000003ooooool0003o0000
00;o00003Oooool2o`0000Oooooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool@o`00
0003ooooool0003o000000So000000Coooooo`000?l0003o00000_ooool2o`00017ooooo0_l00005
ooooo`Wo00000_ooool>o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l0000>
ooooo`Co00001oooool2o`0000_ooooo1Ol00011ooooo`007?ooool00ol0003oooooooooo`1:oooo
o`;o000000Coooooo`000?l0003ooooo0ol0000?ooooo`;o00000oooool2o`0000Oooooo0_l00004
ooooob3o00000_ooool2o`00017ooooo0_l00004oooooaWo000000?oooooo`000?l000001_ooool2
o`0000_ooooo0_l00009ooooo`Co00001oooool2o`0000Cooooo0_l00006ooooo`Ko0000?oooool0
01cooooo00?o0000ooooooooool0B_ooool2o`000004ooooool0003o0000ooooo`?o00005?ooool2
o`0000gooooo0_l000000ooooooo0000o`00000Co`000003ooooool0003o000000Ko00004?ooool2
o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000005?l000000ooooooo0000o`000003
ooooo`;o000000?oooooo`000?l000002oooool2o`0000kooooo0ol00006ooooo`;o000000?ooooo
o`000?l000002_ooool2o`0003oooooo000Looooo`03o`000?oooooooooo04Sooooo0_l00002oooo
o`;o00000oooool2o`0002?ooooo0_l00002ooooo`Co000000?oooooo`000?l000003Ol000000ooo
oooo0000o`000006o`00013ooooo1?l000000ooooooo0000o`000005oooooaKo00001oooool2o`00
00Wooooo0_l0000Booooo`Co00000oooool5o`0004kooooo000Looooo`03o`000?oooooooooo03Wo
oooo0_l0000=ooooo`;o00000_ooool2o`0002kooooo0_l000000ooooooo0000o`00000Eo`0001?o
oooo0_l00002ooooo`;o00001?oooolFo`0000;ooooo0_l00006ooooo`;o00001_ooool2o`0001;o
oooo0_l00005ooooo`Co00001Oooool2o`0004Sooooo000Looooo`03o`000?oooooooooo03Oooooo
1?l00002ooooo`;o00000_ooool3o`0000Kooooo0_l0000Aooooo`;o00003_ooool2o`0000Gooooo
0_l00005oooooa_o00005?ooool5o`0000;ooooo5_l00004ooooo`;o00001_ooool2o`0000?ooooo
1?l0000Sooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0=oooool2o`0000Cooooo0ol0
00001?oooooo0000o`000?l00006ooooo`Co00000_ooool2o`0000Cooooo0_l00005ooooo`;o0000
3_ooool2o`0000;ooooo0_l000001?oooooo0000o`000?l00004oooooa_o00003Oooool2o`000003
ooooool0003o000000;ooooo1Ol00002oooooaOo000000?oooooo`000?l000003Oooool4o`0001_o
oooo0_l0000;ooooo`;o0000@oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q
8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo03Oooooo0_l00005oooo
o`;o00002_ooool4o`0000;ooooo0_l00004ooooo`;o00004Oooool2o`0000Kooooo0_l000001?oo
oooo0000o`000?l00004oooooaco00003?ooool2o`000003ooooool0003o000000Kooooo0_l00000
0ooooooo0000o`00000=o`000003ooooool0003o000000Wo000000Coooooo`000?l0003ooooo1_l0
0002ooooo`;o00006Oooool6o`0000_ooooo0_l00013ooooo`0000KoooooogMgMonHV9SooooooiRH
V?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05;ooooo
1?l0000Cooooo`;o00000oooool2o`0000Cooooo0_l00005ooooo`?o000000?oooooo`000?l00000
5_l0000Aooooo`Co000000Goooooo`000?l0003o0000ooooo`0<o`000003ooooool0003o000000Wo
000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000004o`0000;ooooo0_l0000Ioooo
o`Ko00006Oooool2o`0003Gooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wo
oooo1Ol00006ooooo`03o`000?oooooooooo053ooooo1_l00006ooooo`;o00004?ooool2o`00013o
oooo4ol0000Eooooo`Co000000?oooooo`000?l000000_ooool2o`0000;ooooo2?l000000ooooooo
0000o`000008o`0001Gooooo0_l000000ooooooo0000o`00000>ooooo`;o00001_ooool2o`0000Ko
oooo0_l0000@ooooo`;o0000=Oooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
2Oooool01?m4A4CogMgMooooool00007ooooo`?o0000D?ooool2o`0000;ooooo0_l00006ooooo`;o
00002_ooool2o`0000_ooooo0_l00008oooooaCo00005Oooool4o`0000Gooooo0_l00002ooooo`So
000000?oooooo`000?l000002?l00007ooooo`;o000000?oooooo`000?l000002Oooool2o`000003
ooooool0003o000000kooooo1Ol00003ooooo`;o00001_ooool2o`0004Oooooo00000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003o
ooooooooo`0jooooo`;o00003Oooool2o`0000Wooooo0_l0000Booooo`;o00000_ooool2o`0000Oo
oooo0_l00008oooooa?o00000_ooool4o`00013ooooo0_l0000<oooooa;o00001?ooool2o`000004
ooooool0003o0000ooooo`;o00001?ooool2o`0000Kooooo0_l0000?ooooo`Co00002_ooool2o`00
00Wooooo0_l0000mooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03
ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0>_ooool2o`0000gooooo0_l0000=ooooo`;o
00004_ooool2o`0000Kooooo0ol00003ooooo`;o00000ooooolAo`0000;ooooo1_l000000ooooooo
0000o`00000Fooooo`;o00000_oooolCo`000004ooooool0003o0000ooooo`;o000000Coooooo`00
0?l0003ooooo0_l00004ooooo`;o00003oooool2o`0000Kooooo1?l00007ooooo`;o000000?ooooo
o`000?l000002Oooool2o`0003gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?o
k^k^odA4A?l000001oooool00ol0003oooooooooo`1Hooooo`;o00006_ooool3o`000003ooooool0
003o000000;o00000oooool2o`0000;ooooo3?l00003ooooo`;o00001Oooool3o`0000Oooooo0_l0
000<ooooo`;o00000_ooool?o`0000Gooooo0_l000001?oooooo0000o`000?ooool5o`0000;ooooo
0_l0000Aooooo`?o000000?oooooo`000?l000000_ooool2o`0000Wooooo0_l0000Cooooo`;o0000
=_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03
o`000?oooooooooo04kooooo0_l0000Looooo`;o00002_ooool4o`0000Oooooo3_l00009ooooo`;o
00001oooool2o`00013ooooo0ol000001Ooooooo0000o`000?l0003ooooo00Go00003oooool2o`00
00?ooooo0_l00005ooooo`;o00001Oooool2o`0000Cooooo0_l000000ooooooo0000o`000003oooo
o`Co00006oooool2o`0003Kooooo000Looooo`03o`000?oooooooooo03Oooooo0_l0000Eooooo`;o
00006oooool5o`0000Cooooo0_l00002ooooo`Go00000oooool3o`000003ooooool0003o000000_o
00008Oooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000000ol000001?oooooo
0000o`000?l00002ooooo`;o00001?ooool2o`0000cooooo0_l00002ooooo`;o00001Oooool2o`00
00[ooooo1_l0000Pooooo`;o0000<Oooool001cooooo00?o0000ooooooooool0;oooool2o`0000Ko
oooo0_l000000ooooooo0000o`000006ooooo`;o00001_ooool2o`0000kooooo0_l0000?ooooo`Go
00000oooool3o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`Co00000_ooool2o`0000;o
oooo0_l0000Iooooo`;o00001_ooool4o`0000;ooooo0_l00003ooooo`;o00000oooool2o`0000?o
oooo0_l00002ooooo`;o00001?ooool2o`0000?ooooo0_l00007ooooo`;o00002Oooool2o`0000[o
oooo0_l000000ooooooo0000o`000006ooooo`;o00006Oooool2o`00037ooooo000Looooo`03o`00
0?oooooooooo02oooooo0_l000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l00000
0oooool3o`0000Gooooo0_l0000>ooooo`;o00003Oooool2o`0000;ooooo0_l00004ooooo`;o0000
1_ooool2o`0000;ooooo0_l00004ooooo`;o00000_ooool2o`00017ooooo0_l00006ooooo`;o0000
1_ooool4o`0001Kooooo0_l00008ooooo`;o00001oooool2o`0000Wooooo0ol0000?ooooo`Co0000
00?oooooo`000?l000000_ooool2o`0000Sooooo0_l0000nooooo`007?ooool00ol0003ooooooooo
o`0booooo`;o00002Oooool2o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`;o00001_oo
ool4o`0001;ooooo0_l00005ooooo`;o00002oooool2o`0000Kooooo0_l0000Eooooo`;o00000ooo
ool2o`00017ooooo0ol00005ooooo`;o00002?ooool2o`0000Gooooo0_l000000ooooooo0000o`00
000Cooooo`;o00002_ooool9o`0000Gooooo0_l00008ooooo`;o0000?_ooool001cooooo00?o0000
ooooooooool0<Oooool2o`0000[ooooo0ol00006ooooo`;o00000oooool2o`0000Kooooo1?l00002
ooooo`;o00003_ooool2o`000003ooooool0003o000000;ooooo0_l0000;ooooo`;o00004Oooool2
o`0000Sooooo0_l00005ooooo`;o00001oooool4o`0000?ooooo0_l000001?oooooo0000o`000?l0
0005ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Sooooo0ol00003ooooo`;o00001ooo
ool2o`0000;ooooo0_l000000ooooooo0000o`00000<ooooo`Go00001_ooool2o`0000cooooo0_l0
000mooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o00000_ooool2o`0000Kooooo0_l00003
ooooo`;o00002Oooool2o`0000kooooo0_l00002ooooo`;o00002_ooool2o`000003ooooool0003o
000000Wooooo0_l0000Gooooo`;o00002?ooool4o`0000cooooo1?l00003ooooo`?o000000?ooooo
o`000?l000001?ooool2o`0000;ooooo0_l00002ooooo`Co00001oooool2o`0000;ooooo0ol00007
ooooo`;o000000?oooooo`000?l000001?l00002ooooo`;o00002?ooool2o`0000Wooooo0_l00000
0ooooooo0000o`000006ooooo`;o000000?oooooo`000?l00000?Oooool001cooooo00?o0000oooo
ooooool0;Oooool2o`0000[ooooo0_l0000>ooooo`;o00001oooool2o`0000?ooooo0_l00004oooo
o`Co00002oooool2o`0000Wooooo0_l0000=ooooo`;o00001Oooool2o`0000Cooooo0_l00003oooo
o`Ko00000_ooool2o`00013ooooo0_l000001?oooooo0000o`000?ooool2o`000004ooooool0003o
0000ooooo`Ko000000?oooooo`000?l000002_ooool4o`0000Wooooo1_l00003ooooo`;o000000?o
ooooo`000?l000002_ooool4o`0000Gooooo0_l00006ooooo`?o0000?oooool001cooooo00?o0000
ooooooooool0;oooool2o`0000?ooooo0_l00005ooooo`;o00000oooool4o`0000kooooo0_l00003
ooooo`;o00000oooool6o`000003ooooool0003o000000Oooooo0_l00009ooooo`;o00003Oooool2
o`0000Gooooo0_l00004ooooo`;o00000_ooool5o`0000Cooooo0_l0000?ooooo`;o00000_ooool2
o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000001?l0000=ooooo`;o00002?oo
ool2o`000004ooooool0003o0000ooooo`;o00001oooool2o`0000[ooooo1Ol0000<ooooo`Go0000
?Oooool001cooooo00?o0000ooooooooool0;oooool2o`0000?ooooo0_l00005ooooo`;o00000ooo
ool6o`0000;ooooo0_l00002ooooo`;o00003_ooool6o`000003ooooool0003o000000;ooooo0_l0
00000ooooooo0000o`00000[ooooo`;o00003Oooool2o`0000Wooooo0_l000000ooooooo0000o`00
000;ooooo`?o00000oooool2o`0000?ooooo0_l00007ooooo`;o00001?ooool2o`0001cooooo0_l0
00000ooooooo0000o`000009ooooo`;o000000Coooooo`000?l0003ooooo0_l0000jooooo`007?oo
ool00ol0003oooooooooo`0fooooo`;o00000oooool4o`0000;ooooo1Ol00002ooooo`?o000000?o
ooooo`000?l000003oooool3o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`00
000?ooooo`;o00004?ooool2o`0001Oooooo0_l0000<ooooo`;o00002Oooool4o`0000Cooooo0_l0
0003ooooo`;o00001oooool2o`0002Gooooo0_l0000>ooooo`?o00001?ooool4o`0003;ooooo000L
ooooo`03o`000?oooooooooo02cooooo0_l00008ooooo`;o00001Oooool4o`0000Sooooo0_l0000@
ooooo`ko00001Oooool2o`0000_ooooo0_l00008ooooo`;o00001_ooool2o`0001cooooo0_l00000
0ooooooo0000o`000006ooooo`?o000000Coooooo`000?l0003ooooo1?l00007ooooo`;o00000ooo
ool2o`0000Oooooo0_l00004ooooo`;o00004?ooool2o`0001Gooooo1?l00003ooooo`;o00001Ooo
ool4o`0003;ooooo000Looooo`;o0000;Oooool2o`0000Kooooo1?l00007ooooo`;o00006Oooool4
o`000003ooooool0003o000000_o00000_ooool2o`0000;ooooo0_l0000?ooooo`Co00002Oooool2
o`0000;ooooo0_l0000;ooooo`;o00002?ooool2o`000003ooooool0003o000000Kooooo0ol00000
1?oooooo0000o`000?ooool2o`0000Wooooo1?l000000ooooooo0000o`000002ooooo`;o00000ooo
ool2o`0000;ooooo1?l0000@ooooo`;o00000_ooool3o`0000Cooooo0_l00004ooooo`;o00001?oo
ool4o`00043ooooo000Looooo`03o`000?oooooooooo03Cooooo1_l0000Dooooo`;o00002_oooolC
o`0000Gooooo0_l0000?ooooo`;o00001oooool2o`0000;ooooo0_l00002ooooo`;o00002oooool2
o`0000;ooooo0_l0000Fooooo`;o00000_ooool2o`0000Oooooo0_l000000ooooooo0000o`000002
ooooo`;o00001Oooool6o`000003ooooool0003o0000017ooooo1_l000000ooooooo0000o`000003
ooooo`?o00001Oooool2o`000003ooooool0003o000001Cooooo0_l0000Xooooo`007?ooool00ol0
003oooooooooo`0eooooo`;o000000?oooooo`000?l000000_l0000Booooo`;o00000oooool2o`00
00Gooooo5?l00004ooooo`Co00000_ooool4o`0000?ooooo0_l0000;ooooo`;o000000?oooooo`00
0?l000003?ooool3o`0000?ooooo1_l00005ooooo`;o00002_ooool2o`0000Gooooo0_l00007oooo
o`;o000000?oooooo`000?l000000_l00007ooooo`;o00001Oooool2o`0000Cooooo0_l0000<oooo
o`Go00001_ooool2o`000003ooooool0003o000000?ooooo0_l000000ooooooo0000o`00000Doooo
o`;o0000:?ooool001cooooo00?o0000ooooooooool0>_ooool4o`0000Kooooo0_l0000=ooooo`;o
00001_oooolCo`000004ooooool0003o0000ooooo`Co00000_ooool4o`0000;ooooo0ol00005oooo
o`;o00001oooool2o`0000Cooooo0_l000001?oooooo0000o`000?l00002ooooo`?o00000oooool2
o`0000;ooooo0_l00005ooooo`;o00002_ooool2o`0000kooooo0_l000000ooooooo0000o`000002
o`0001Cooooo0_l0000<ooooo`;o00003?ooool2o`0000;ooooo0_l00009ooooo`;o00001oooool2
o`0000Wooooo0_l0000Sooooo`007?ooool00ol0003oooooooooo`0kooooo`?o00000oooool2o`00
0004ooooool0003o0000ooooo`;o00001_ooool2o`0000?ooooo0_l000000ooooooo0000o`00000H
o`0000?ooooo0_l00008ooooo`;o00001_ooool4o`0000_ooooo0_l000001?oooooo0000o`000?l0
0002ooooo`;o00000oooool2o`0000;ooooo0_l0000>ooooo`;o00000_ooool2o`0000kooooo0_l0
00000ooooooo0000o`00000Kooooo`;o00000oooool2o`0000Oooooo0_l0000;ooooo`;o00002Ooo
ool2o`0000Kooooo0ol00009ooooo`;o00008oooool001cooooo00?o0000ooooooooool0>oooool4
o`0000;ooooo0_l00004ooooo`;o00001_ooool2o`0000;ooooo0ol000000ooooooo0000o`00000F
o`0000Wooooo0_l000000ooooooo0000o`00000;ooooo`;o00002oooool2o`0000Kooooo0_l00003
ooooo`;o00000_ooool2o`0000kooooo1_l00006ooooo`;o00009_ooool2o`0000?ooooo0_l00004
ooooo`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00005_ooool2o`0002oooooo000L
ooooo`03o`000?oooooooooo01cooooo0_l0000?ooooo`;o00003_ooool2o`0000;ooooo0_l0000<
ooooo`;o000000?oooooo`000?l000006_l0000:ooooo`;o000000Coooooo`000?l0003o00002_oo
ool2o`0000Oooooo0_l00002ooooo`;o00002?ooool2o`000004ooooool0003o0000ooooo`;o0000
2_ooool2o`0000Gooooo0_l00008ooooo`;o0000<Oooool2o`0000Cooooo0_l00003ooooo`;o0000
2_ooool2o`0000;ooooo0_l0000gooooo`007?ooool00ol0003oooooooooo`0Looooo`;o00003ooo
ool2o`0000?ooooo0_l00009ooooo`;o00000_ooool2o`0000cooooo0_l000000ooooooo0000o`00
000Go`000004ooooool0003o0000o`0000Wooooo0_l00002ooooo`;o00004oooool2o`0000cooooo
1Ol000000ooooooo0000o`000005ooooo`;o00000oooool2o`0004Kooooo0_l00005ooooo`;o0000
1oooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o0000<Oooool001cooooo00?o
0000ooooooooool0;oooool2o`000004ooooool0003o0000ooooo`Go00002Oooool2o`0000kooooo
0_l000000ooooooo0000o`00000Go`0000Wooooo0_l00002ooooo`Co00004?ooool2o`0000kooooo
0_l00008ooooo`Co00007oooool2o`0000?ooooo0_l0000Uooooo`;o00001Oooool2o`0000?ooooo
0_l00002ooooo`;o00000_ooool2o`0000Oooooo0_l0000aooooo`007?ooool00ol0003ooooooooo
o`0_ooooo`;o00001?ooool5o`0000Wooooo0_l00007ooooo`;o00001Oooool2o`000003ooooool0
003o000001Ko00004?ooool2o`0000_ooooo1ol00009ooooo`;o00003Oooool4o`0000;ooooo0_l0
000>ooooo`;o00001oooool2o`0000;ooooo1?l000001?oooooo0000o`000?l0000:ooooo`;o0000
0_ooool2o`0000Cooooo0_l00004ooooo`;o00005?ooool2o`0000Kooooo0_l0000jooooo`007?oo
ool00ol0003oooooooooo`0Oooooo`;o00006Oooool2o`0000Sooooo0_l00006ooooo`;o00001Ooo
ool2o`000003ooooool0003o000001Ko00001?ooool2o`0000;ooooo0_l00006ooooo`Co00002Ooo
ool6o`0000[ooooo0_l0000<ooooo`;o00001Oooool2o`0000_ooooo0_l000000ooooooo0000o`00
0007ooooo`;o00000_ooool4o`0000;ooooo0_l0000:ooooo`;o00000_ooool2o`0000Cooooo0ol0
0003ooooo`;o0000:?ooool2o`0002kooooo000Looooo`03o`000?oooooooooo01oooooo0_l0000F
ooooo`;o000000?oooooo`000?l000000ol00005ooooo`;o00003Oooool2o`000003ooooool0003o
000001Go00001Oooool2o`0000;ooooo0_l00002ooooo`;o00000_ooool4o`0000Oooooo0_l00000
1?oooooo0000o`000?l00002ooooo`;o00001Oooool4o`0000gooooo0_l0000Booooo`;o00003_oo
ool4o`000003ooooool0003o000000?ooooo0_l00004ooooo`[o00000oooool2o`0002gooooo0_l0
000^ooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00000_ooool4o`0001?ooooo0_l00004
oooooaOo00002_ooool3o`0000gooooo0_l00006ooooo`;o00001Oooool6o`000004ooooool0003o
0000o`0000Gooooo0_l0000@ooooo`Co00001Oooool2o`0000;ooooo0_l00003ooooo`;o00000_oo
ool2o`000003ooooool0003o000000;ooooo1Ol00002ooooo`[o00000oooool2o`0000Oooooo1Ol0
000Sooooo`;o0000;?ooool001cooooo00?o0000ooooooooool0:_ooool2o`0001Kooooo0_l0000:
ooooo`;o00000_ooool2o`0000;ooooo6Ol0000:ooooo`;o00001?ooool5o`0000[ooooo0_l00009
ooooo`;o000000?oooooo`000?l000001?l00005ooooo`;o00000oooool2o`000003ooooool0003o
000000;ooooo0_l00004ooooo`Co00001Oooool2o`0000;ooooo0_l00003ooooo`;o00001_ooool9
o`0000;ooooo1_l00006ooooo`Co00001Oooool5o`0000Gooooo0_l00006ooooo`;o00004_ooool4
o`0002cooooo000Looooo`03o`000?oooooooooo02[ooooo0_l0000=ooooo`;o00001oooool2o`00
00[ooooo0_l00004oooooaWo00004Oooool8o`0000Sooooo1?l00005ooooo`Co00000oooool3o`00
00_ooooo0_l000001?oooooo0000o`000?ooool3o`0000?ooooo0_l00005ooooo`?o00002Oooool<
o`000003ooooool0003o000000;o00000_ooool2o`0000;ooooo0_l00007ooooo`?o00000oooool2
o`0000;ooooo0ol00005ooooo`;o00001_ooool2o`0000gooooo0_l00003ooooo`;o0000;_ooool0
01cooooo00?o0000ooooooooool0>Oooool3o`0000_ooooo0_l0000:ooooo`?o00001?ooool=o`00
0003ooooool0003o000000?o00004Oooool3o`000003ooooool0003o000000;o00002_ooool2o`00
00Gooooo0_l00003ooooo`Go00003oooool4o`000004ooooool0003o0000ooooo`;o00001Oooool3
o`0000Wooooo3?l000000ooooooo0000o`000003o`000005ooooool0003o0000o`000?ooool00_l0
000=ooooo`;o00000_ooool3o`0000cooooo0_l0000>ooooo`;o0000<oooool001cooooo0_l0000k
ooooo`?o00002_ooool2o`0000;ooooo0_l00006ooooo`;o00001_ooool7o`000003ooooool0003o
000000Oo00004_ooool2o`00017ooooo0_l00009ooooo`Ko00003_ooool2o`000003ooooool0003o
000000Co00001Oooool2o`0000gooooo5?l000000ooooooo0000o`000004ooooo`;o00002_ooool3
o`0000Cooooo1?l00005ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0>_ooool3o`00
00[ooooo0_l00002ooooo`Co00003?oooolAo`0000Kooooo0_l0000:ooooo`;o00001Oooool2o`00
00?ooooo0_l00005ooooo`;o00000_ooool4o`0000Kooooo0ol00008ooooo`?o00000_ooool2o`00
00;ooooo0_l00002ooooo`;o00001Oooool2o`0000Oooooo0ol00002oooooaGo00001oooool2o`00
00Oooooo1_l00004ooooo`Co0000B_ooool001cooooo00?o0000ooooooooool0Boooool4o`0000_o
oooo3ol00006ooooo`Go00000_ooool2o`0000gooooo0_l00003ooooo`;o00000oooool2o`0000Co
oooo1?l00006ooooo`;o00002Oooool3o`0000;ooooo1?l00005ooooo`;o00002oooool5o`000003
ooooool0003o000001Co00000_ooool2o`0000Oooooo0_l00003ooooo`Ko0000D_ooool001cooooo
00?o0000ooooooooool0=Oooool2o`0001Cooooo0ol00005ooooo`;o00000oooool5o`0000?ooooo
2Ol000000ooooooo0000o`000003ooooo`Co00000oooool2o`0000Cooooo0_l000000ooooooo0000
o`00000>ooooo`;o00002?ooool2o`00017ooooo0_l00003ooooo`;o000000?oooooo`000?l00000
0_ooool2o`0000Gooooo0_l00004ooooo`Go000000?oooooo`000?l000006?l00007ooooo`?o0000
00Coooooo`000?l0003ooooo0_l0000:ooooo`;o00000oooool2o`0001Sooooo0_l0000Yooooo`00
7?ooool00ol0003oooooooooo`0Zooooo`;o00002Oooool4o`0000gooooo0_l00003ooooo`?o0000
0_ooool2o`000003ooooool0003o000000?ooooo0_l00006ooooo`Wo000000?oooooo`000?l00000
0oooool2o`0000_ooooo0_l000000ooooooo0000o`000008ooooo`;o00003_ooool2o`00017ooooo
0_l000000ooooooo0000o`000003ooooo`;o00002?ooool4o`0000Cooooo2ol000000ooooooo0000
o`000004o`000003ooooool0003o000000So000000?oooooo`000?l000001_ooool3o`000003oooo
ool0003o000000Oooooo0_l00004ooooo`;o00000oooool2o`0000Gooooo0_l00004ooooo`;o0000
2oooool2o`0002Wooooo000Looooo`03o`000?oooooooooo02[ooooo0_l00008ooooo`;o000000?o
ooooo`000?l000003Oooool2o`0000Sooooo0ol0000=ooooo`So00001Oooool5o`0000[ooooo0_l0
000;ooooo`;o00001Oooool2o`0000oooooo0_l0000<ooooo`;o00001oooool2o`0000Cooooo1?l0
0006oooooaoo00003?ooool2o`0000Cooooo0_l0000@ooooo`;o00001?ooool2o`0003Kooooo000L
ooooo`03o`000?oooooooooo02cooooo0_l00004ooooo`Co000000?oooooo`000?l000006?ooool2
o`0000Wooooo0_l00003ooooo`;o00000oooool2o`0000Gooooo0_l000000ooooooo0000o`000003
ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo0_l0000>ooooo`?o00000_ooool2
o`0000[ooooo0_l0000Eooooo`;o00000_ooool2o`0000Sooooo8Ol00004ooooo`;o00001_ooool2
o`000004ooooool0003o0000ooooo`;o00001?ooool2o`0000Gooooo0_l0000@ooooo`;o0000;ooo
ool001cooooo00?o0000ooooooooool0;?ooool2o`0000Cooooo0_l00002ooooo`;o00000_ooool2
o`0000Sooooo0_l00006ooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo0_l00000
0ooooooo0000o`000006ooooo`;o00003oooool2o`0000;ooooo0_l00002ooooo`;o000000?ooooo
o`000?l000001_ooool3o`0000Kooooo0_l00002ooooo`;o00002oooool4o`000003ooooool0003o
000001?ooooo0_l00004ooooo`;o00000_ooool9o`000003ooooool0003o0000013o000000?ooooo
o`000?l000000_l00004ooooo`?o00002?ooool2o`0000Oooooo0_l00003ooooo`Co00004?ooool2
o`000003ooooool0003o000000;ooooo0_l0000Xooooo`007?ooool00ol0003oooooooooo`0aoooo
o`;o00000oooool2o`0000;ooooo0_l00004ooooo`;o00000_ooool2o`000003ooooool0003o0000
00?ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00002ooooo`;o000000Coooooo`00
0?l0003ooooo0_l000000ooooooo0000o`000002o`0001Oooooo0_l00002ooooo`;o00001Oooool3
o`0001Oooooo1?l000000ooooooo0000o`000002o`0000Cooooo0_l00003ooooo`;o00001oooool2
o`0000?ooooo0_l000000ooooooo0000o`00000Ko`0000;ooooo0ol00002ooooo`;o000000?ooooo
o`000?l000003Oooool2o`000004ooooool0003o0000ooooo`Oo00004oooool2o`0000;ooooo0_l0
000Xooooo`007?ooool00ol0003oooooooooo`0aooooo`;o00003Oooool3o`000003ooooool0003o
000000?o00002?ooool2o`0000Kooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0
003o000000Wooooo0_l00002ooooo`;o00002Oooool2o`0000?ooooo0_l0000Pooooo`;o00001?oo
ool2o`0000Cooooo1ol00007ooooo`;o00001_oooolQo`0000?ooooo0_l00004ooooo`;o00002_oo
ool2o`000004ooooool0003o0000ooooo`Co000000?oooooo`000?l00000@Oooool001cooooo00?o
0000ooooooooool0<_ooool2o`0000Sooooo0_l00003ooooo`Co000000?oooooo`000?l000003_oo
ool2o`000004ooooool0003o0000o`0000;ooooo0_l00007ooooo`?o00000oooool2o`0000;ooooo
0_l00009ooooo`;o00000oooool2o`0000Cooooo0_l0000Jooooo`;o00002_ooool5o`0000Cooooo
0_l00008ooooobCo00000oooool2o`0000Cooooo0_l0000:ooooo`;o00004_ooool2o`0000Cooooo
0_l00005ooooo`;o0000:oooool001cooooo00?o0000ooooooooool0<_ooool2o`0000Sooooo1?l0
0003ooooo`;o00001oooool2o`0000Sooooo0_l00002ooooo`Ko000000?oooooo`000?l000001?oo
ool3o`0000Oooooo0_l000000ooooooo0000o`000006ooooo`;o00000_ooool2o`0000Gooooo0_l0
000Nooooo`;o00001_ooool2o`0000Oooooo1?l000001?oooooo0000o`000?l00002ooooob3o0000
00?oooooo`000?l000001?ooool2o`00013ooooo0_l00006ooooo`;o00002_ooool2o`0000Cooooo
0_l00005ooooo`;o0000:oooool001cooooo00?o0000ooooooooool0>Oooool2o`0000?ooooo0_l0
0003ooooo`;o00001oooool2o`0000[ooooo0_l00002ooooo`;o00000oooool5o`000003ooooool0
003o000000_ooooo0_l0000:ooooo`?o00001Oooool2o`0001;ooooo0_l00009ooooo`;o00000ooo
ool2o`0000cooooo0_l000001?oooooo0000o`000?l00002ooooo`?o000000?oooooo`000?l00000
1Ol000000ooooooo0000o`00000Do`0001oooooo0_l0000Gooooo`;o0000:oooool001cooooo00?o
0000ooooooooool0=Oooool2o`000004ooooool0003o0000o`0000Cooooo0_l000001?oooooo0000
o`000?l0000Cooooo`;o00002?ooool4o`0000Sooooo0ol00007ooooo`;o00001_ooool3o`0000Go
oooo0_l0000<ooooo`;o00001?ooool2o`000003ooooool0003o000000Kooooo0_l00003ooooo`;o
00002_ooool2o`0000Kooooo2_l000000ooooooo0000o`00000Ho`0000?ooooo0_l00009ooooo`;o
00002Oooool5o`0000;ooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o0000
0oooool3o`000004ooooool0003o0000o`0000Cooooo1Ol0000;ooooo`;o00002_ooool2o`0000;o
oooo0_l00002ooooo`Co00000oooool7o`0000Oooooo0_l00003ooooo`;o000000?oooooo`000?l0
00004oooool5o`0000Gooooo1?l0000:ooooo`Co00000_ooool2o`0000?ooooo0_l00006oooooaco
000000?oooooo`000?l000001ol00002ooooo`Co000000?oooooo`000?l000001?ooool3o`0000So
oooo1Ol00002ooooo`;o00000oooool2o`0003gooooo000Looooo`03o`000?oooooooooo02oooooo
0_l00003ooooo`;o00002_ooool4o`0000Gooooo0_l00004ooooo`;o00002_ooool2o`0000;ooooo
0_l00004ooooo`?o00000_ooool6o`0000;ooooo1?l00007ooooo`;o00005_ooool2o`000004oooo
ool0003o0000ooooo`;o000000Coooooo`000?l0003ooooo0_l0000:ooooo`Go000000Coooooo`00
0?l0003o00000oooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`ko000000?ooooo
o`000?l000001ol000001Ooooooo0000o`000?l0003ooooo00Co00000_ooool4o`000003ooooool0
003o000000;o00000oooool2o`000004ooooool0003o0000o`0000_ooooo0_l00002ooooo`?o0000
00?oooooo`000?l00000>_ooool001cooooo0_l0000cooooo`;o00002Oooool2o`0000Cooooo0_l0
0004ooooo`;o00005?ooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`00
0007ooooo`Co00000_ooool2o`0000Kooooo1?l0000Gooooo`;o000000Coooooo`000?l0003ooooo
1?l00002ooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo0_l00003ooooo`Co0000
00Coooooo`000?l0003ooooo0_l00002ooooo`?o000000?oooooo`000?l000005_l000000ooooooo
0000o`000003o`000004ooooool0003o0000o`0000;ooooo1?l00006ooooo`?o00002oooool2o`00
00;ooooo0_l00002ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0<_ooool2o`0000Wo
oooo0_l00004ooooo`;o00003oooool2o`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l0
00000ol00002ooooo`;o00003?ooool4o`0000Gooooo1?l00006ooooo`?o00002oooool5o`0000Co
oooo1Ol000000ooooooo0000o`000003o`0000Gooooo0_l00008ooooo`;o00001?ooool2o`0000;o
oooo6ol00003ooooo`Go000000?oooooo`000?l000008_ooool2o`0003[ooooo000Looooo`03o`00
0?oooooooooo04oooooo0_l00003ooooo`;o00001Oooool2o`0000Oooooo1?l0000?ooooo`Co0000
1?ooool3o`0000Sooooo0ol00008ooooo`;o000000?oooooo`000?l000000ol000000ooooooo0000
o`000003o`000003ooooool0003o000000;o000000?oooooo`000?l000001?ooool4o`0000kooooo
0_l000000ooooooo0000o`00000Lo`0000Cooooo0_l00003ooooo`;o00008?ooool2o`0003[ooooo
000Looooo`03o`000?oooooooooo02oooooo0_l00009ooooo`;o00001?ooool2o`0000_ooooo1?l0
0009ooooo`;o00001?ooool3o`0000?ooooo1?l0000=ooooo`?o00000_ooool2o`000004ooooool0
003o0000o`0000[ooooo0ol00002ooooo`;o00000_ooool5o`000003ooooool0003o000000Ko0000
0oooool2o`0000Oooooo0_l00002ooooo`;o00003_oooolOo`0000Cooooo0_l00003ooooo`;o0000
2_ooool2o`00053ooooo000Looooo`03o`000?oooooooooo02oooooo1?l00003ooooo`;o00000_oo
ool2o`0000Cooooo0_l00004ooooo`;o00001Oooool2o`0000_ooooo0_l00004ooooo`?o00001Ooo
ool2o`0000Kooooo0_l00005ooooo`?o00000_ooool3o`000003ooooool0003o000000?ooooo0_l0
0005ooooo`?o000000Coooooo`000?l0003o00000_ooool4o`0000;ooooo1?l00004ooooo`?o0000
0_ooool3o`000003ooooool0003o000000;o00000oooool2o`0000kooooo7?l0000>ooooo`;o0000
00?oooooo`000?l000001Oooool2o`0000Oooooo0_l00017ooooo`007?ooool00ol0003ooooooooo
o`0aooooo`;o00000oooool2o`0000Cooooo0_l00008ooooo`;o00004Oooool2o`0000;ooooo0_l0
0009ooooo`;o00001_ooool2o`000003ooooool0003o000000Sooooo0_l000000ooooooo0000o`00
0003ooooo`;o00001_ooool2o`000003ooooool0003o000000?ooooo2?l00002oooooa7o00000ooo
ool2o`0000?ooooo0_l0000:oooooa_o00000_ooool2o`0000[ooooo0_l000000ooooooo0000o`00
000:ooooo`Ko00002?ooool2o`0003gooooo000Looooo`03o`000?oooooooooo033ooooo0_l0000:
ooooo`?o00004?ooool2o`000003ooooool0003o000000Gooooo0_l00002ooooo`;o00004Oooool2
o`000003ooooool0003o000000Sooooo0_l000000ooooooo0000o`000008ooooo`;o000000?ooooo
o`000?l000000_ooool5o`000003ooooool0003o000000;o000000?oooooo`000?l000003?l00000
1?oooooo0000o`000?l00002ooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo0ol0
0002oooooago00000_ooool2o`0000;ooooo0_l00009ooooo`;o00002_ooool4o`0000Kooooo0_l0
0002ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0<?ooool2o`0000Kooooo0_l00002
ooooo`?o00003Oooool5o`000004ooooool0003o0000o`0000?ooooo0_l0000Fooooo`;o000000?o
ooooo`000?l000004?ooool2o`0000?ooooo1?l000000ooooooo0000o`000005o`000003ooooool0
003o000000go000000?oooooo`000?l000000oooool6o`0000?ooooo0_l000001?oooooo0000o`00
0?ooool6o`000003ooooool0003o000000Co000000Coooooo`000?l0003ooooo0_l00005ooooo`;o
00000_ooool8o`0000Kooooo0_l0000Cooooo`Co00000oooool4o`000003ooooool0003o000000go
oooo0_l0000booooo`007?ooool00ol0003oooooooooo`0hooooo`;o00002_ooool2o`0000Kooooo
1?l000000ooooooo0000o`000002o`0000?ooooo0_l0000Aooooo`?o00000_ooool2o`0000_ooooo
0_l00006ooooo`;o00000oooool4o`000003ooooool0003o000000Ko00000oooool<o`000003oooo
ool0003o000000Gooooo0_l00005ooooo`?o00000oooool2o`000003ooooool0003o000000;o0000
0_ooool7o`0000Sooooo0_l00004ooooo`Go00002_ooool2o`00013ooooo0_l00005ooooo`Co0000
1Oooool2o`0000Oooooo1?l0000booooo`007?ooool00ol0003oooooooooo`14ooooo`;o00002ooo
ool2o`0000?ooooo0_l000000ooooooo0000o`000003o`0000?ooooo0_l00008ooooo`?o00000_oo
ool2o`0000Kooooo0ol000001?oooooo0000o`000?l0000;ooooo`?o00000_oooolGo`000004oooo
ool0003o0000o`0000;ooooo1?l00002ooooo`;o00000_ooool2o`0000?ooooo1ol00003ooooo`Co
00004?ooool2o`000003ooooool0003o000000Cooooo0_l00004ooooo`;o00003?ooool4o`0000Ko
oooo0_l00008ooooo`?o000000?oooooo`000?l000000oooool2o`0003Cooooo000Looooo`03o`00
0?oooooooooo03Wooooo0_l0000Kooooo`;o000000?oooooo`000?l000000ol00003ooooo`;o0000
1oooool3o`0000_ooooo0ol000000ooooooo0000o`000007ooooo`Co000000?oooooo`000?l00000
1Oooool9o`000004ooooool0003o0000ooooo`So000000Coooooo`000?l0003o00000_ooool4o`00
00;ooooo0_l00008ooooo`?o00001_ooool4o`0001?ooooo0_l00004ooooo`;o000000?oooooo`00
0?l000003Oooool6o`0000Kooooo0ol00008ooooo`;o000000?oooooo`000?l00000>Oooool001co
oooo00?o0000ooooooooool0>Oooool2o`0002oooooo0ol00008ooooo`?o00002Oooool2o`0000;o
oooo1?l000000ooooooo0000o`000002ooooo`;o00001?oooolBo`000004ooooool0003o0000oooo
o`Go000000Coooooo`000?l0003o00000oooool4o`000003ooooool0003o000000Co00001_ooool3
o`0000kooooo0_l00008ooooo`Ko00003?ooool2o`0000;ooooo0_l00004ooooo`Go00000oooool2
o`0000_ooooo1?l0000booooo`007?ooool00ol0003oooooooooo`0_ooooo`;o00003_ooool2o`00
00cooooo0_l00007ooooo`;o00007Oooool3o`0000?ooooo0_l00004ooooo`So00000ooooolMo`00
0003ooooool0003o000000?o000000Coooooo`000?l0003o00000oooool4o`000003ooooool0003o
000000;ooooo0_l00002ooooo`;o00000oooool2o`0000Cooooo0_l00008ooooo`;o00002_ooool4
o`0000?ooooo0_l00004ooooo`;o00002?ooool2o`000003ooooool0003o000000Kooooo0_l0000;
ooooo`Co0000<_ooool001cooooo00?o0000ooooooooool0;oooool2o`0000kooooo0_l00005oooo
o`?o00001?ooool2o`0000Oooooo1?l00003ooooo`;o000000Goooooo`000?l0003o0000ooooo`03
o`0000Kooooo1Ol00003ooooo`;o00000_ooool4o`0000Gooooo0ol00002ooooo`?o000000?ooooo
o`000?l000006_l00003ooooo`Co00000oooool2o`0000Cooooo0_l00004ooooo`Co00000_ooool2
o`0000;ooooo0_l00005ooooo`;o00001oooool2o`0001;ooooo0_l000001?oooooo0000o`000?oo
ool2o`000004ooooool0003o0000o`0000Cooooo0_l0000:ooooo`;o00001oooool2o`0000;ooooo
0_l0000cooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko
<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0A_ooool3o`0000oooooo0_l00003oooo
o`;o000000Goooooo`000?l0003o0000ooooo`03o`0000Kooooo1Ol00003ooooo`;o00000_ooool2
o`0000?ooooo0_l00008ooooo`;o000000?oooooo`000?l000007Ol000000ooooooo0000o`000003
o`000003ooooool0003o000000Cooooo0_l00004ooooo`Co00001_ooool2o`0000kooooo0_l00000
0ooooooo0000o`00000;ooooo`;o00001Oooool2o`0000Cooooo0ol0000;ooooo`;o00000oooool2
o`0000Oooooo0_l0000gooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?oo
ool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0FOooool7o`0001Sooooo
0_l00004ooooo`;o000000?oooooo`000?l000001?oooolEo`000003ooooool0003o000000ko0000
00?oooooo`000?l000000_l00003ooooo`;o00001oooool2o`0000kooooo0_l0000:ooooo`;o0000
2Oooool4o`0000Cooooo0_l00003ooooo`Co00001_ooool2o`0000Cooooo0_l00015ooooo`0000?o
oooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`0fooooo`;o00001_ooool2o`0000Kooooo1?l0000>ooooo`So0000
1_ooool2o`00013ooooo0ol00006ooooo`?o00000ooooolTo`000003ooooool0003o000000Co0000
0oooool2o`000003ooooool0003o000000Cooooo0_l0000>ooooo`;o00001oooool2o`0000cooooo
0_l00006ooooo`;o00000oooool4o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o0000
0oooool2o`0000Cooooo0_l00006ooooo`;o0000=?ooool00003ooooool0003ooooo00;ooooo00?o
0000ooooooooool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0000booooo`Ko0000
1_ooool2o`0000Kooooo1?l0000>ooooo`Co000000Coooooo`000?l0003o00001_ooool2o`00017o
oooo0_l00007ooooo`;o00000ooooolOo`000003ooooool0003o000000?ooooo1Ol00007ooooo`;o
00003?ooool2o`0000Oooooo0_l00006ooooo`;o00001oooool2o`0001Gooooo0_l00002ooooo`;o
00000oooool2o`0000?ooooo0_l00004ooooo`;o00000oooool2o`000003ooooool0003o000003Co
oooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oeEEEOl0003o
410@olc<c006ooooo`03o`000?oooooooooo03;ooooo1?l00008ooooo`Co00000oooool2o`0001;o
oooo0_l0000;ooooo`;o00000_ooool2o`0001Kooooo0ol000000ooooooo0000o`00000Po`000003
ooooool0003o000000;ooooo1?l0000?ooooo`;o00000_ooool6o`0000Gooooo0_l0000?ooooo`;o
00003oooool2o`0000Sooooo0ol00005ooooo`;o00002oooool2o`0003Oooooo00000ooooooo410@
ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003ooooo
ooooo`0dooooo`;o00001_ooool2o`0000;ooooo0_l000000ooooooo0000o`000004o`00013ooooo
0_l0000;ooooo`;o00000_ooool4o`0000;ooooo0ol00002ooooo`;o00002_ooool4o`000003oooo
ool0003o000000Ko000000?oooooo`000?l000006_l00002ooooo`?o000000?oooooo`000?l00000
1oooool2o`0000Cooooo0_l000000ooooooo0000o`000005o`0000[ooooo0_l0000<ooooo`Co0000
0_ooool2o`0000Oooooo1?l00002ooooo`;o00000_ooool3o`000003ooooool0003o000000;ooooo
0_l00014ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00So
oooo00?o0000ooooooooool0=?ooool2o`0000Cooooo1?l00005ooooo`Ko00006oooool2o`000003
ooooool0003o000000?ooooo0_l00002ooooo`?o00000_ooool4o`0000Sooooo4ol000000ooooooo
0000o`000004o`000003ooooool0003o000000ko000000Goooooo`000?l0003o0000ooooo`02o`00
00Oooooo0_l00007ooooo`;o000000Coooooo`000?l0003o00002oooool2o`0000_ooooo1Ol00002
ooooo`;o00000_ooool2o`0000Gooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo0_l00002
ooooo`;o0000A?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`00
0?l@4106ooooo`03o`000?oooooooooo03[ooooo0_l000000ooooooo0000o`000007ooooo`;o0000
6oooool3o`000004ooooool0003o0000o`0000gooooo1?l00005ooooo`?o00000_oooolFo`000003
ooooool0003o000000ko000000?oooooo`000?l000005Oooool2o`0000Cooooo1?l0000Cooooo`;o
00002Oooool2o`0000gooooo0_l0000>ooooo`;o00000_ooool2o`0003Sooooo000Looooo`03o`00
0?oooooooooo03Cooooo0_l00006ooooo`?o00001?ooool2o`0001kooooo0_l000000ooooooo0000
o`000002o`0000oooooo0_l00005ooooo`?o000000Coooooo`000?l0003ooooo5?l000000ooooooo
0000o`00000Bo`0000_ooooo0_l00007ooooo`;o00001?ooool4o`0000Oooooo0_l00006ooooo`Co
00001?ooool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000001Oooool2o`0000[o
oooo0_l00005ooooo`;o00000_ooool2o`0003Sooooo000Looooo`03o`000?oooooooooo03Cooooo
0_l00005ooooo`Co00001?ooool2o`0001Cooooo0_l0000;ooooo`;o00003oooool4o`0000;ooooo
0ol000001?oooooo0000o`000?oooolGo`000004ooooool0003o0000ooooo`[o000000?oooooo`00
0?l000001_l00009ooooo`;o00000oooool2o`0001?ooooo0_l000000ooooooo0000o`000003oooo
o`Co00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000005o`0000Cooooo0ol00004oooo
o`;o000000Coooooo`000?l0003ooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`0koooo
o`;o00000oooool2o`0001Oooooo0_l00007ooooo`Co00004Oooool3o`0000;ooooo1?l00006oooo
o`;o000000?oooooo`000?l000004?l000000ooooooo0000o`000005o`000003ooooool0003o0000
00So00000_ooool2o`0000?ooooo0_l00003ooooo`?o00000oooool2o`0001Kooooo0_l00008oooo
o`;o000000?oooooo`000?l000001Oooool2o`0000;ooooo0_l00005ooooo`Co00000oooool2o`00
0003ooooool0003o000004Kooooo000Looooo`03o`000?oooooooooo03cooooo0_l00002ooooo`;o
00001?ooool2o`0001?ooooo0_l00005ooooo`Co00000oooool2o`000003ooooool0003o000000Wo
oooo0_l00003ooooo`Co000000Coooooo`000?l0003ooooo9?l000000ooooooo0000o`000003o`00
00Oooooo0_l00003ooooo`;o000000?oooooo`000?l000008oooool2o`000003ooooool0003o0000
00Wooooo0_l00007ooooo`;o00001_ooool3o`0004Gooooo000Looooo`03o`000?oooooooooo03co
oooo0_l00008ooooo`;o000000?oooooo`000?l000004?ooool2o`0000cooooo0_l000001?oooooo
0000o`000?l00007ooooo`?o00001Oooool2o`000003ooooool0003o000002So000000?oooooo`00
0?l000002_ooool3o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0000Cooooo0_l0000[oooo
o`;o00001oooool2o`0000?ooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0gooooo`;o
00000oooool2o`0000Cooooo0ol000000ooooooo0000o`000003o`0001_ooooo0_l00005ooooo`;o
00001oooool2o`0000Kooooo0_l000000ooooooo0000o`00000Ao`000003ooooool0003o000001Co
00002_ooool2o`000004ooooool0003o0000o`0000?ooooo0_l000000ooooooo0000o`000003oooo
o`;o00001?ooool2o`0001_ooooo1?l00003ooooo`;o00004?ooool2o`0000?ooooo0_l00010oooo
o`007?ooool00ol0003oooooooooo`0gooooo`;o00000oooool2o`0000Cooooo1ol000000ooooooo
0000o`00000:ooooo`;o000000?oooooo`000?l000002oooool3o`0000;ooooo0_l00007ooooo`;o
00003_oooolUo`0000?ooooo0ol00006ooooo`Ko00000oooool2o`000003ooooool0003o000002Ko
oooo1?l00003ooooo`;o00003?ooool2o`0000Sooooo0_l0000oooooo`007?ooool00ol0003ooooo
ooooo`14ooooo`;o00001?ooool2o`0000[ooooo0_l000000ooooooo0000o`000005ooooo`;o0000
1Oooool3o`000003ooooool0003o000000Oooooo0_l0000:ooooo`;o00000_ooool=o`000003oooo
ool0003o000000So000000?oooooo`000?l000002?l000001?oooooo0000o`000?ooool4o`000003
ooooool0003o000000?ooooo1_l00006ooooo`;o00000_ooool2o`0000Wooooo0_l0000Mooooo`;o
00002Oooool2o`0000;ooooo0_l00008ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0
=Oooool2o`0000Cooooo0ol0000>ooooo`;o00004_ooool2o`0000Cooooo1?l00004ooooo`;o0000
4?ooool2o`0000?ooooo0ol000000ooooooo0000o`000006o`000003ooooool0003o000000So0000
00?oooooo`000?l000004ol00009ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Kooooo
0_l000000ooooooo0000o`00000Mooooo`;o00002Oooool2o`0004gooooo000Looooo`03o`000?oo
oooooooo03Gooooo0_l000000ooooooo0000o`000006o`0000cooooo1?l00002ooooo`;o00003Ooo
ool2o`0000?ooooo1?l00002ooooo`Co00001oooool2o`0000Kooooo1Ol000000ooooooo0000o`00
000Fo`000003ooooool0003o000000_o000000?oooooo`000?l000000_l000000ooooooo0000o`00
0008ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Kooooo0_l0000_ooooo`;o0000BOoo
ool001cooooo00?o0000ooooooooool0>?ooool3o`0000?ooooo0_l00005ooooo`;o000000?ooooo
o`000?l000001?ooool2o`0000;ooooo0_l0000:ooooo`;o000000Coooooo`000?l0003ooooo0_l0
00000ooooooo0000o`000003ooooo`;o00000oooool4o`0000;ooooo0_l00006ooooo`Go000000?o
ooooo`000?l000008Ol00002ooooo`Wo00001?ooool2o`0000;ooooo0_l00005ooooo`;o000000?o
ooooo`000?l000003_ooool2o`0001gooooo0_l00008ooooo`;o0000BOooool001cooooo0_l0000o
ooooo`;o00001Oooool2o`000003ooooool0003o000000cooooo0_l00002ooooo`;o00000_ooool4
o`0000;ooooo0_l000000ooooooo0000o`000008ooooo`Co00003OoooolVo`0000;ooooo1ol00006
ooooo`;o00002Oooool2o`000003ooooool0003o000000kooooo0_l0000Eooooo`;o00001_ooool2
o`0000Kooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00000_ooool2o`00
00?ooooo0_l00009ooooo`;o00001oooool2o`0000;ooooo1?l00002ooooo`;o00004?ooool2o`00
00Kooooo0_l00006oooooaOo000000?oooooo`000?l000003?l00002ooooo`Co000000?oooooo`00
0?l000000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l000000ooo
oooo0000o`000002ooooo`;o00001?ooool2o`0001[ooooo1?l0000:ooooo`;o00000_ooool2o`00
04_ooooo000Looooo`03o`000?oooooooooo03Wooooo0_l00002ooooo`;o00000oooool2o`0000Co
oooo0_l00002ooooo`?o00003Oooool3o`000004ooooool0003o0000o`0000Sooooo0_l00005oooo
o`;o00001_ooool2o`000003ooooool0003o000000Oooooo8_l00004ooooo`;o00001Oooool2o`00
00;ooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l000001?oooooo0000o`000?ooool3
o`0000Cooooo0_l0000Jooooo`;o00003?ooool2o`0000;ooooo0_l0001;ooooo`007?ooool00ol0
003oooooooooo`0iooooo`;o00001oooool2o`0000Cooooo0_l00002ooooo`?o00003_ooool6o`00
00Sooooo0_l0000:ooooo`;o000000Coooooo`000?l0003ooooo0_l00007ooooobCo00004Oooool2
o`0000[ooooo0_l00009ooooo`Co00007Oooool2o`0005Cooooo000Looooo`03o`000?oooooooooo
03Wooooo0_l00007ooooo`;o00005_ooool2o`0000;ooooo0_l00005ooooo`;o000000?oooooo`00
0?l000001oooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0000Oooooo0ol00000
0ooooooo0000o`000007o`0000;ooooo5ol00003ooooo`;o00002Oooool2o`0000;ooooo0_l0000B
ooooo`Co00007?ooool3o`0000Cooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`12oooo
o`;o000000Coooooo`000?l0003o00001?ooool2o`0000cooooo0_l00009ooooo`;o000000?ooooo
o`000?l000000_l000000ooooooo0000o`000002ooooo`;o00000_ooool2o`0000Kooooo1?l00000
0ooooooo0000o`000003ooooo`?o00000_oooolCo`0000;ooooo3?l00002ooooo`?o00001oooool3
o`0000;ooooo0_l0000booooo`;o00001Oooool2o`0004kooooo000Looooo`03o`000?oooooooooo
04;ooooo0_l000001?oooooo0000o`000?l00004ooooo`;o00001Oooool2o`000003ooooool0003o
000000[ooooo0_l00006ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Sooooo0_l00000
1?oooooo0000o`000?ooool2o`000003ooooool0003o000000;ooooo2ol000000ooooooo0000o`00
000Co`0000?ooooo0_l00005ooooo`Co00001oooool2o`0002Oooooo0_l000000ooooooo0000o`00
0009ooooo`;o00000oooool2o`0004Wooooo000Looooo`03o`000?oooooooooo04;ooooo0_l0000?
ooooo`;o000000?oooooo`000?l000002_ooool2o`0000Kooooo0_l00009ooooo`;o000000?ooooo
o`000?l000001_ooool4o`000005ooooool0003o0000o`000?ooool07_l0000@ooooo`;o00000_oo
ool2o`0000Gooooo0_l0000Wooooo`;o000000?oooooo`000?l000001?ooool2o`0000Sooooo0_l0
0019ooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00007?ooool2o`0000Sooooo0_l00009
ooooo`;o000000?oooooo`000?l000000oooool2o`000003ooooool0003o000000Cooooo0_l00000
0ooooooo0000o`00000Co`0000;ooooo1_l0000:ooooo`;o00001Oooool6o`0001;ooooo1?l0000Q
ooooo`;o00001Oooool2o`000003ooooool0003o000004Wooooo000Looooo`03o`000?oooooooooo
063ooooo0_l0000>ooooo`;o00001oooool2o`0000;ooooo0ol00005ooooo`Oo000000?oooooo`00
0?l000003_l00002ooooo`Oo00002_ooool2o`0000Kooooo0ol0000Dooooo`Co00005oooool2o`00
00Cooooo0_l00004ooooo`;o00000oooool3o`0004_ooooo000Looooo`03o`000?oooooooooo04?o
oooo0_l0000?ooooo`;o00003?ooool2o`0000;ooooo0_l00008ooooo`;o00001Oooool4o`0000?o
oooo0_l00005ooooo`Co000000?oooooo`000?l000000_ooool@o`000004ooooool0003o0000oooo
o`?o00001Oooool4o`00023ooooo0_l00004ooooo`;o00005?ooool2o`0000Cooooo0_l00004oooo
o`;o00001?ooool2o`0004_ooooo000Looooo`03o`000?oooooooooo043ooooo1Ol0000>ooooo`?o
00002Oooool2o`000003ooooool0003o000000;ooooo0_l0000:ooooo`;o00000oooool5o`0000co
oooo1?l000000ooooooo0000o`000006o`000003ooooool0003o000000Ko00000oooool3o`0000;o
oooo0_l00002ooooo`Co00004?ooool2o`0000cooooo1_l00002ooooo`;o00006oooool2o`0000?o
oooo1?l0001?ooooo`007?ooool00ol0003oooooooooo`10ooooo`Co00001_ooool2o`0000Oooooo
0_l000000ooooooo0000o`000002o`0000Gooooo0_l0000<ooooo`;o00000oooool2o`0000Kooooo
0_l00009ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`00000=o`0000;ooooo
0_l000001Ooooooo0000o`000?l0003ooooo00?o00005_ooool2o`0000cooooo0_l00002ooooo`;o
00007oooool2o`0000?ooooo1?l0001?ooooo`007?ooool00ol0003oooooooooo`11ooooo`?o0000
1_ooool2o`0000[ooooo1?l0000Cooooo`;o00005_ooool2o`000005ooooool0003o0000o`000?oo
ool02_l000001Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`000?l000001?l000000ooo
oooo0000o`00000Iooooo`;o00003?ooool2o`0002;ooooo0_l00002ooooo`;o0000DOooool001co
oooo00?o0000ooooooooool0@_ooool2o`0001;ooooo0_l0000Oooooo`;o00000_ooool2o`0000_o
oooo0_l00002ooooo`_o000000Coooooo`000?l0003ooooo0_l00002ooooo`?o00007Oooool3o`00
00;ooooo0_l00008ooooo`;o00008_ooool2o`0000;ooooo0_l00003ooooo`;o0000C?ooool001co
oooo00?o0000ooooooooool0Coooool2o`0000?ooooo1?l00002ooooo`;o00004?ooool2o`0000Co
oooo0_l00003ooooo`;o00000_ooool2o`0000[ooooo0_l00004ooooo`Co000000?oooooo`000?l0
00001_l00002ooooo`Co00001_ooool2o`000004ooooool0003o0000o`0001?ooooo0_l00003oooo
o`;o00001?ooool2o`0000;ooooo0_l00002ooooo`;o00005Oooool2o`0000;ooooo0_l000000ooo
oooo0000o`000002o`0000Oooooo0_l0001<ooooo`007?ooool2o`00043ooooo0_l0000>ooooo`;o
00000oooool4o`0000;ooooo0_l0000;ooooo`;o00000oooool2o`0000Cooooo0_l00008ooooo`;o
00002Oooool2o`0000Cooooo3?l000000ooooooo0000o`000004o`0000Kooooo0_l000001?oooooo
0000o`000?l0000:ooooo`;o00004_ooool2o`0000;ooooo1_l0000Eooooo`;o00000_ooool2o`00
0003ooooool0003o000000Co0000Doooool001cooooo00?o0000ooooooooool0>_ooool2o`0000?o
oooo0_l0000Eooooo`;o00003?ooool2o`000003ooooool0003o000000Cooooo0_l00003ooooo`;o
00001?ooool2o`0000;ooooo0_l00006ooooo`;o00001Oooool5o`000005ooooool0003o0000o`00
0?ooool00ol00002ooooo`;o000000?oooooo`000?l000005oooool2o`0001Oooooo1?l0000:oooo
o`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o00001_ooool4o`0005?ooooo000Looooo`03
o`000?oooooooooo03[ooooo0_l0000Cooooo`;o00002?ooool2o`0000Wooooo0_l00007ooooo`;o
00002?ooool3o`0000[ooooo0_l00005ooooo`;o00004Oooool3o`0001Gooooo0_l00006ooooo`;o
00004Oooool2o`0000[ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00000oooool2o`00
05gooooo000Looooo`03o`000?oooooooooo04oooooo0_l00008ooooo`;o00007?ooool2o`000003
ooooool0003o000000kooooo0_l00003ooooo`;o00001Oooool2o`0000Kooooo0ol0000Fooooo`;o
000000?oooooo`000?l000000_ooool2o`00017ooooo0_l0000Aooooo`;o00001oooool2o`0001So
oooo0_l00010ooooo`007?ooool00ol0003oooooooooo`1Oooooo`Co00004Oooool2o`0000Cooooo
1?l00004ooooo`;o00001_ooool3o`000004ooooool0003o0000o`0000;ooooo0_l000001?oooooo
0000o`000?ooool2o`00017ooooo0_l00009ooooo`;o000000?oooooo`000?l000007?ooool4o`00
00Sooooo0_l00005ooooo`Co00000_ooool2o`0001Cooooo0_l00010ooooo`007?ooool00ol0003o
ooooooooo`11ooooo`;o00001oooool2o`0001?ooooo1?l0000Aooooo`;o000000?oooooo`000?l0
00000_ooool3o`0000Cooooo0_l00006ooooo`Ko00000oooool2o`000004ooooool0003o0000oooo
o`Ko00003Oooool2o`0001;ooooo0_l00002ooooo`;o00004_ooool4o`0000Cooooo0_l00002oooo
o`;o00001Oooool2o`0000Cooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`11ooooo`;o
00001oooool2o`0000Wooooo0_l0000Pooooo`;o00000_ooool2o`0000;ooooo0_l00005ooooo`So
00001?ooool3o`000003ooooool0003o000000?ooooo1Ol00008ooooo`;o00001Oooool2o`0000oo
oooo0_l00002ooooo`;o00002Oooool2o`0000Oooooo0_l00006ooooo`;o000000?oooooo`000?l0
00000_l00005ooooo`;o00001Oooool2o`0005Cooooo000Looooo`03o`000?oooooooooo04_ooooo
0_l00008ooooo`;o00000_ooool2o`0001?ooooo0_l00006ooooo`;o00000oooool6o`0000?ooooo
1_l000000ooooooo0000o`000002o`0000?ooooo0ol00007ooooo`Go00001oooool2o`0000Gooooo
0_l00005ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Oooooo0_l00004ooooo`;o0000
1oooool2o`0000Cooooo0_l00003ooooo`Co000000?oooooo`000?l000001?l00005ooooo`;o0000
E?ooool001cooooo00?o0000ooooooooool0Boooool2o`0000Sooooo0ol000000ooooooo0000o`00
000Cooooo`?o00001Oooool2o`0000Gooooo0_l00003ooooo`Co000000?oooooo`000?l000000ooo
ool3o`0000Cooooo1?l00005ooooo`;o000000?oooooo`000?l000005Oooool2o`000003ooooool0
003o000000kooooo0_l000000ooooooo0000o`00000:ooooo`;o00001?ooool2o`0000;ooooo1?l0
0002ooooo`Co0000GOooool001cooooo00?o0000ooooooooool0E_ooool2o`0001Oooooo0ol0000@
ooooo`Co00003Oooool4o`0000Cooooo1?l0000Rooooo`?o00001Oooool2o`000003ooooool0003o
000000Sooooo1?l00008ooooo`Co00000_ooool2o`0005oooooo000Looooo`03o`000?oooooooooo
05;ooooo1_l0000Hooooo`;o00000oooool2o`0000?ooooo0_l0000Aooooo`;o00002_ooool6o`00
00?ooooo0_l000000ooooooo0000o`00000Iooooo`Co000000?oooooo`000?l000003_ooool3o`00
00[ooooo1?l00008ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0DOooool7o`0001go
oooo1?l000000ooooooo0000o`000002ooooo`;o00001oooool2o`0000Cooooo0_l0000:ooooo`;o
00001oooool2o`000003ooooool0003o000001Wooooo0_l00003ooooo`;o00000_ooool2o`0000[o
oooo0_l0000:ooooo`;o000000?oooooo`000?l000002?ooool2o`0005Wooooo000Looooo`03o`00
0?oooooooooo057ooooo0_l000000ooooooo0000o`000002o`0001oooooo0_l00005ooooo`;o0000
1oooool2o`0000Kooooo0_l0000Rooooo`;o00003Oooool3o`0000Cooooo1?l00004ooooo`Co0000
3?ooool2o`000003ooooool0003o000000;ooooo1?l0001Mooooo`007?ooool00ol0003ooooooooo
o`1Dooooo`Co00000_ooool2o`0000Oooooo0_l00007ooooo`;o00001oooool4o`0001;ooooo0_l0
0002ooooo`;o00002_ooool2o`0001Kooooo0_l0000=ooooo`?o00001_ooool2o`0000Cooooo1?l0
000Cooooo`Co0000GOooool001cooooo00?o0000ooooooooool0Doooool2o`0000Cooooo0ol00007
ooooo`Co00001Oooool2o`0000Oooooo0ol0000Cooooo`;o00001_ooool2o`0000?ooooo0_l00000
0ooooooo0000o`000003ooooo`;o00002_ooool4o`0002Sooooo0_l0000;ooooo`;o0000H_ooool0
01cooooo00?o0000ooooooooool0Doooool3o`0000?ooooo0ol00008ooooo`?o00002Oooool3o`00
00?ooooo0_l0000Kooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`;o00002_ooool4o`00
02Sooooo0_l0000;ooooo`;o0000H_ooool001cooooo0_l0001Eooooo`;o00001?ooool2o`0001Co
oooo0ol0000Aooooo`;o00001oooool2o`0000gooooo0_l0000?ooooo`;o00001Oooool2o`0000ko
oooo0_l0000Qooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0JOooool2o`0000Kooooo
0_l000001?oooooo0000o`000?l00002ooooo`;o00002?ooool3o`0000Oooooo0_l0000Nooooo`;o
00000oooool4o`0000Oooooo0_l00005ooooo`;o00004?ooool2o`0000Gooooo0_l00008ooooo`;o
0000H?ooool001cooooo00?o0000ooooooooool0JOooool2o`0000Kooooo0_l000001?oooooo0000
o`000?l00002ooooo`;o00000oooool2o`0000?ooooo1?l0000Looooo`?o00001Oooool2o`0000?o
oooo1?l00003ooooo`;o00001?ooool2o`0000;ooooo0_l0000Cooooo`;o00001Oooool2o`0000Ko
oooo0_l0001Rooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o00002?ooool2o`0000?ooooo
0_l00008ooooo`;o00001Oooool2o`0001[ooooo1Ol00004ooooo`?o00000oooool2o`000003oooo
ool0003o000000;ooooo0_l00008ooooo`;o00005oooool2o`0000Wooooo0_l0001Rooooo`007?oo
ool00ol0003oooooooooo`1Sooooo`Co00002?ooool2o`0000Gooooo0_l00008ooooo`;o00006Ooo
ool2o`0000Cooooo0ol00006ooooo`;o00001?ooool2o`000003ooooool0003o000000cooooo0_l0
000@ooooo`;o00001?ooool3o`000003ooooool0003o000006[ooooo000Looooo`03o`000?oooooo
oooo06?ooooo0_l0000;ooooo`;o00001?ooool4o`0000Kooooo0_l00004ooooo`;o00000_ooool4
o`0000gooooo0_l00008ooooo`;o00001_ooool2o`000004ooooool0003o0000o`0000[ooooo0ol0
00000ooooooo0000o`00000=ooooo`;o000000?oooooo`000?l000001?ooool2o`0000;ooooo1ol0
001Uooooo`007?ooool00ol0003oooooooooo`1`ooooo`;o00001_ooool2o`0000cooooo0_l00002
ooooo`Co00001_ooool2o`0000oooooo0_l00006ooooo`;o000000Coooooo`000?l0003o00002_oo
ool3o`00013ooooo0_l0000<ooooo`Ko0000IOooool001cooooo00?o0000ooooooooool0Ioooool3
o`0000Kooooo0_l00002ooooo`;o000000?oooooo`000?l000005?ooool2o`0000Gooooo1Ol0000A
ooooo`;o00001?ooool2o`0000_ooooo0_l00006ooooo`;o00004?ooool2o`0000Gooooo0_l0001Y
ooooo`007?ooool00ol0003oooooooooo`1Wooooo`?o00001_ooool2o`0000;ooooo0_l000001?oo
oooo0000o`000?ooool2o`000003ooooool0003o000000;o00000_ooool2o`000003ooooool0003o
000000?ooooo1?l00006ooooo`Co00004Oooool2o`0000;ooooo0_l0000=ooooo`;o00000_ooool2
o`0000;ooooo0_l00002ooooo`;o00003?ooool2o`00073ooooo000Looooo`03o`000?oooooooooo
06kooooo0_l00005ooooo`;o00000oooool2o`000003ooooool0003o000000;o00000_ooool2o`00
0003ooooool0003o000000;o000000?oooooo`000?l000006Oooool5o`0000?ooooo0_l00005oooo
o`;o00002_ooool3o`0000Gooooo0_l00002ooooo`;o00000_ooool2o`0007Kooooo000Looooo`03
o`000?oooooooooo06kooooo0_l00004ooooo`?o00001oooool3o`0000Oooooo0_l0000Dooooo`;o
00001_ooool5o`0000Oooooo1Ol00007ooooo`;o00000_ooool2o`0000Wooooo0_l00002ooooo`;o
0000M_ooool001cooooo00?o0000ooooooooool0KOooool2o`0000Gooooo0_l00008ooooo`Go0000
1oooool2o`0000Gooooo0_l00005ooooo`;o00001?ooool2o`0001;ooooo1?l00008ooooo`Go0000
2_ooool2o`0007[ooooo000Looooo`03o`000?oooooooooo06[ooooo0_l000000ooooooo0000o`00
0007ooooo`;o00002Oooool2o`0000;ooooo0_l00003ooooo`;o00000oooool4o`0000Gooooo0_l0
000;ooooo`;o00002oooool2o`0000cooooo0ol0000@ooooo`;o0000M?ooool001cooooo00?o0000
ooooooooool0J_ooool2o`0000[ooooo1?l0000;ooooo`;o00002?ooool3o`0000[ooooo0_l00007
ooooo`;o00001?ooool2o`0000Gooooo0_l0000;ooooo`;o00002_ooool2o`0000;ooooo0_l00002
ooooo`;o0000M?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Go
c<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo06cooooo0_l00009ooooo`?o0000
00Coooooo`000?l0003o00003Oooool2o`0000?ooooo0_l00005ooooo`;o000000?oooooo`000?l0
00000_l0000:ooooo`;o000000Coooooo`000?l0003o00000oooool2o`0000cooooo0_l00002oooo
o`;o00001_ooool6o`0007Sooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44
ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`1/ooooo`;o00002ooo
ool5o`000004ooooool0003o0000o`0000Wooooo0_l0000:ooooo`;o000000?oooooo`000?l00000
3?ooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000cooooo0_l00008ooooo`;o0000
N_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool0K_ooool2o`0000Wooooo0_l00004ooooo`?o0000
3_ooool2o`0000Kooooo0_l00008ooooo`;o000000?oooooo`000?l000003_ooool2o`0000_ooooo
0_l0000>ooooo`Co0000Loooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Ooo
ool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0001^ooooo`;o00003_ooool2o`0000?ooooo
0_l000000ooooooo0000o`000008ooooo`?o00001Oooool2o`0000Sooooo0_l000000ooooooo0000
o`000003ooooo`Co00002_ooool2o`0000Sooooo0_l00004ooooo`;o00002?ooool4o`0007?ooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Goc<c<o`000?l0003o0000
olc<c006ooooo`03o`000?oooooooooo07Gooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo
0_l000000ooooooo0000o`000009ooooo`;o00001?ooool2o`0000Kooooo0_l00005ooooo`?o0000
00?oooooo`000?l000000_l0000:ooooo`;o00002oooool2o`000003ooooool0003o000007oooooo
00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go410@okZj^_oooooo^[Zj
oa0@4006ooooo`03o`000?oooooooooo07Gooooo0_l00003ooooo`;o00000_ooool3o`0000;ooooo
0ol0000:ooooo`Co00000oooool2o`0000Kooooo0_l00005ooooo`?o00002Oooool4o`0000oooooo
0_l00002ooooo`;o00008_ooool2o`0005[ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_o
oooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo07kooooo0ol00003oooo
o`;o00002_ooool4o`0001Oooooo0_l00005ooooo`Co00002oooool2o`0000Kooooo1Ol0000Ooooo
o`;o0000F_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@
413oZJVY00Kooooo00?o0000ooooooooool0H_ooool2o`0001;ooooo0_l0000;ooooo`;o00000ooo
ool2o`0000Gooooo0_l000000ooooooo0000o`000006ooooo`;o000000?oooooo`000?l000000_l0
000:ooooo`;o00000oooool2o`0000oooooo0_l000000ooooooo0000o`000004ooooo`Co0000Nooo
ool001cooooo00?o0000ooooooooool0H_ooool2o`0001;ooooo0ol00008ooooo`Co000000?ooooo
o`000?l000000_l00005ooooo`;o00001_ooool2o`000004ooooool0003o0000ooooo`Ko00001?oo
ool6o`0000?ooooo1Ol0000:ooooo`;o00000oooool2o`0008?ooooo000Looooo`03o`000?oooooo
oooo07Oooooo0_l00008ooooo`;o000000?oooooo`000?l000001_l00004ooooo`;o00001Oooool2
o`0000Sooooo0_l00004ooooo`So00000_ooool4o`0000[ooooo0_l00028ooooo`007?ooool00ol0
003oooooooooo`24ooooo`Co000000Coooooo`000?l0003o00001?ooool2o`0000;ooooo0_l0000E
ooooo`Co00000_ooool4o`0000Kooooo1?l0002:ooooo`007?ooool00ol0003oooooooooo`1doooo
o`;o000000?oooooo`000?l000003Oooool2o`0000Cooooo0_l00002ooooo`;o00000_ooool2o`00
00Cooooo0_l0000:ooooo`;o00004Oooool6o`0000Kooooo0_l00022ooooo`007?ooool00ol0003o
ooooooooo`1dooooo`;o000000?oooooo`000?l000000oooool2o`0000cooooo1_l0000:ooooo`;o
00001Oooool2o`0000;ooooo0ol0000Aooooo`;o00002_ooool2o`0008;ooooo000Looooo`03o`00
0?oooooooooo07cooooo0_l0000<ooooo`?o000000?oooooo`000?l000004Oooool2o`0000;ooooo
0ol0000=ooooo`;o00003?ooool2o`0008Cooooo000Looooo`03o`000?oooooooooo07Sooooo0_l0
0002ooooo`;o00004?ooool2o`0002Gooooo0_l000000ooooooo0000o`000009ooooo`;o0000Q?oo
ool001cooooo00?o0000ooooooooool0N?ooool2o`000004ooooool0003o0000o`0000oooooo0_l0
0005ooooo`;o00003oooool2o`000003ooooool0003o000000Co00002_ooool2o`0008oooooo000L
ooooo`03o`000?oooooooooo07_ooooo0_l0000@ooooo`;o00001Oooool2o`0000oooooo0_l00000
0ooooooo0000o`000004o`0009_ooooo000Looooo`03o`000?oooooooooo08cooooo0_l0002koooo
o`007?ooool00ol0003oooooooooo`1aooooo`;o00003?ooool2o`0000_ooooo0_l0000Cooooo`;o
0000Y_ooool001cooooo0_l0001booooo`Co00001oooool2o`000003ooooool0003o0000023ooooo
0_l0002Vooooo`007?ooool00ol0003oooooooooo`1cooooo`;o00001oooool2o`0002Wooooo0_l0
002Pooooo`007?ooool00ol0003oooooooooo`20ooooo`;o00004?ooool2o`0001?ooooo0_l0002P
ooooo`007?ooool00ol0003oooooooooo`20ooooo`;o00004?ooool2o`0003;ooooo0_l00021oooo
o`007?ooool00ol0003oooooooooo`2hooooo`;o00003?ooool2o`00087ooooo000Looooo`03o`00
0?oooooooooo0;Sooooo0_l00005ooooo`;o0000R?ooool001cooooo00?o0000ooooooooool0V_oo
ool2o`0002?ooooo0_l00028ooooo`007?ooool00ol0003oooooooooo`2Jooooo`;o0000[Oooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0;Kooooo0_l0002Aooooo`007?ooool00ol0003ooooooooo
o`2fooooo`;o0000TOooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000:Kooooo0_l0002Rooooo`007?ooool0
0ol0003oooooooooo`2Uooooo`;o0000X_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Booooo`Co000000?o410@ooooooooool00oooool00ol0003ooooooooo
o`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom:
ooooo`005?ooool00ol0003oooooooooo`05ooooo`?o0000oooooom:ooooo`005?ooool00ol0003o
ooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o
0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Boooo
o`03oeEEEOmVIVKo00000?ooooooE?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00:7ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0Fooooo`Co000000?o
410@ooooooooool00_ooool2o`000003oa0@4?oooooooooo00?ooooo00?o0000onk^k_ooool00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^08cooooo002Rooooo`05o`000?ooooooooooooooool00000
2Oooool6o`0000cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03oeEE
EOnYZJWooooo00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`2<ooooo`00X_ooool01Ol0003ooooo
oooooooooooo000001_ooooo00?o0000ooooooooool00_ooool5o`0000Gooooo00?oZJVYoeEEEOoo
ool00oooool01Ol@413ooooooooooooooooo410@08cooooo002Rooooo`05o`000?oooooooooooooo
ool000002Oooool6o`0000cooooo00?o0000ooooooooool00_ooool01?m4A4CogMgMooooool00007
ooooo`03ob4Q8Ooooooooooo00;ooooo00Go0000ooooooooooooooooo`00002<ooooo`00X_ooool0
1Ol0003oQhN7oooooonYZJWo000001_ooooo00?o0000ooooooooool00_ooool01?oMgMgoEEEEoooo
ool00007ooooo`03oeEEEOo<c<cooooo00;ooooo00Go0000ooooooooooooooooo`00002<ooooo`00
XOooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo01Wooooo00?o0000ooooooooool0
0oooool00omgMgOoc<c<o`000007ooooo`03ojVYZOmgMgOooooo00;ooooo00Go410@oooooooooooo
oooooa0@402<ooooo`00`_ooool00ol0003oooooooooo`03ooooo`03onk^k_m4A4Co000000Cooooo
00Go410@oooooooooooooooooc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0S?ooool00<3o
oooo00?oEEEEofIVI_l000001_ooool00omgMgOo0000ooooo`03ooooo`Go00000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^08cooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000
\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1476) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.62628 .57518 Mdot
.6183 .57665 Mdot
.45341 .37863 Mdot
.43251 .63418 Mdot
.21697 .63058 Mdot
.43661 .33991 Mdot
.60678 .35409 Mdot
.60223 .366 Mdot
.45729 .38511 Mdot
.74786 .55173 Mdot
.59289 .41041 Mdot
.41693 .56397 Mdot
.61419 .38406 Mdot
.44908 .59392 Mdot
.55632 .87047 Mdot
.39165 .63798 Mdot
.62435 .57253 Mdot
.24208 .46418 Mdot
.39763 .61977 Mdot
.42101 .37403 Mdot
.70504 .54541 Mdot
.44854 .5985 Mdot
.6433 .56379 Mdot
.44949 .59346 Mdot
.45599 .63316 Mdot
.65443 .56442 Mdot
.5888 .57743 Mdot
.48746 .6373 Mdot
.49007 .59605 Mdot
.58968 .40807 Mdot
.27119 .49891 Mdot
.38787 .80815 Mdot
.48285 .68445 Mdot
.35451 .70592 Mdot
.63916 .37894 Mdot
.60031 .74155 Mdot
.4531 .34415 Mdot
.59951 .37684 Mdot
.59606 .38754 Mdot
.61639 .35838 Mdot
.60838 .36597 Mdot
.64722 .54807 Mdot
.74681 .39226 Mdot
.64277 .31482 Mdot
.49993 .5733 Mdot
.19113 .46765 Mdot
.50882 .75952 Mdot
.41946 .6094 Mdot
.6705 .53276 Mdot
.34902 .29652 Mdot
.58591 .27325 Mdot
.64773 .37316 Mdot
.43219 .38981 Mdot
.50993 .10238 Mdot
.61276 .39922 Mdot
.52547 .60175 Mdot
.45271 .35979 Mdot
.46239 .60334 Mdot
.45378 .59056 Mdot
.66695 .6445 Mdot
.49229 .65824 Mdot
.31103 .46836 Mdot
.64278 .59534 Mdot
.45875 .46783 Mdot
.44372 .36795 Mdot
.59331 .40261 Mdot
.60476 .55875 Mdot
.61914 .39573 Mdot
.50745 .67724 Mdot
.47133 .31757 Mdot
.41273 .62692 Mdot
.59138 .40501 Mdot
.70052 .55684 Mdot
.48826 .61761 Mdot
.32863 .29532 Mdot
.18922 .44283 Mdot
.28525 .46122 Mdot
.61606 .71792 Mdot
.67365 .64011 Mdot
.32109 .3562 Mdot
.50944 .60276 Mdot
.26199 .55257 Mdot
.20067 .43163 Mdot
.65786 .52261 Mdot
.40277 .66065 Mdot
.27491 .48007 Mdot
.48701 .62286 Mdot
.18471 .60637 Mdot
.46266 .67333 Mdot
.49955 .49726 Mdot
.47547 .36416 Mdot
.68246 .55685 Mdot
.43851 .63591 Mdot
.48336 .59333 Mdot
.71484 .64269 Mdot
.40862 .62665 Mdot
.44331 .61334 Mdot
.64873 .52575 Mdot
.64462 .38283 Mdot
.50783 .65075 Mdot
.38834 .35738 Mdot
.42697 .33207 Mdot
.47192 .66003 Mdot
.47348 .3253 Mdot
.69889 .55608 Mdot
.48346 .59438 Mdot
.59949 .38957 Mdot
.45294 .65595 Mdot
.62524 .23509 Mdot
.62237 .56554 Mdot
.49925 .61503 Mdot
.31159 .42313 Mdot
.57584 .67255 Mdot
.68846 .54878 Mdot
.66495 .35509 Mdot
.40082 .60722 Mdot
.45513 .61685 Mdot
.60696 .55345 Mdot
.42297 .33192 Mdot
.17972 .55308 Mdot
.62666 .53143 Mdot
.62129 .4285 Mdot
.69083 .52572 Mdot
.43129 .55406 Mdot
.43809 .37065 Mdot
.65887 .33413 Mdot
.69458 .34728 Mdot
.29612 .52518 Mdot
.48333 .62238 Mdot
.76673 .40906 Mdot
.41653 .36026 Mdot
.66945 .54572 Mdot
.61956 .39121 Mdot
.45519 .68238 Mdot
.62271 .55159 Mdot
.61104 .42429 Mdot
.33951 .45659 Mdot
.56768 .23533 Mdot
.6537 .58047 Mdot
.55953 .43892 Mdot
.64151 .39369 Mdot
.63891 .35263 Mdot
.63588 .80391 Mdot
.6371 .53374 Mdot
.31905 .43622 Mdot
.62653 .38557 Mdot
.37386 .5277 Mdot
.50852 .58219 Mdot
.24466 .53588 Mdot
.70071 .26762 Mdot
.34722 .65919 Mdot
.52031 .26157 Mdot
.32791 .43309 Mdot
.65458 .36317 Mdot
.43873 .62401 Mdot
.66343 .5707 Mdot
.64814 .56288 Mdot
.49116 .65873 Mdot
.4634 .64394 Mdot
.41331 .65295 Mdot
.42128 .59439 Mdot
.53492 .52633 Mdot
.44545 .67589 Mdot
.52683 .75076 Mdot
.68153 .56145 Mdot
.43122 .62908 Mdot
.43524 .39007 Mdot
.44383 .5643 Mdot
.59168 .38397 Mdot
.45521 .6026 Mdot
.4354 .63408 Mdot
.51257 .62543 Mdot
.64714 .36345 Mdot
.35458 .77711 Mdot
.54789 .66221 Mdot
.32907 .72244 Mdot
.58519 .51059 Mdot
.48494 .37104 Mdot
.48113 .62991 Mdot
.30867 .45093 Mdot
.65475 .73407 Mdot
.42644 .64351 Mdot
.21633 .27281 Mdot
.44198 .6073 Mdot
.26368 .69655 Mdot
.39989 .68928 Mdot
.34118 .71499 Mdot
.27508 .54496 Mdot
.45769 .62921 Mdot
.77335 .49018 Mdot
.57733 .41596 Mdot
.42634 .29841 Mdot
.61875 .36506 Mdot
.43111 .38311 Mdot
.45181 .37319 Mdot
.39719 .4584 Mdot
.3911 .58424 Mdot
.41684 .57629 Mdot
.43144 .66548 Mdot
.43965 .31612 Mdot
.5952 .58678 Mdot
.31708 .42216 Mdot
.65652 .59621 Mdot
.32201 .78028 Mdot
.39107 .27071 Mdot
.58235 .39675 Mdot
.34518 .44694 Mdot
.4717 .33526 Mdot
.47348 .37154 Mdot
.32932 .43008 Mdot
.47 .58447 Mdot
.63388 .53551 Mdot
.50544 .82003 Mdot
.54086 .20406 Mdot
.8499 .6077 Mdot
.6592 .52631 Mdot
.76569 .43923 Mdot
.59119 .37953 Mdot
.46329 .35022 Mdot
.45158 .61613 Mdot
.47803 .60047 Mdot
.70202 .56177 Mdot
.41277 .62496 Mdot
.66478 .50632 Mdot
.45552 .62341 Mdot
.57492 .3862 Mdot
.29308 .47475 Mdot
.3966 .45901 Mdot
.33355 .54461 Mdot
.69558 .54694 Mdot
.73226 .68752 Mdot
.47686 .37106 Mdot
.66703 .72382 Mdot
.59802 .41156 Mdot
.33408 .4686 Mdot
.46122 .39317 Mdot
.30136 .42542 Mdot
.41507 .66892 Mdot
.42417 .36276 Mdot
.2969 .43459 Mdot
.40982 .50393 Mdot
.48263 .56885 Mdot
.52064 .17812 Mdot
.62675 .35814 Mdot
.63676 .58825 Mdot
.44827 .65779 Mdot
.4846 .35307 Mdot
.53154 .64085 Mdot
.45762 .26406 Mdot
.65842 .29355 Mdot
.41556 .36637 Mdot
.3746 .49055 Mdot
.33088 .47376 Mdot
.55924 .28741 Mdot
.76372 .41333 Mdot
.62334 .58138 Mdot
.41203 .66093 Mdot
.39956 .80735 Mdot
.62599 .38639 Mdot
.44153 .652 Mdot
.21343 .54428 Mdot
.63384 .39053 Mdot
.46371 .605 Mdot
.6228 .42187 Mdot
.64756 .56238 Mdot
.6934 .62623 Mdot
.61178 .54643 Mdot
.41255 .62156 Mdot
.60323 .3939 Mdot
.4166 .33488 Mdot
.65915 .56043 Mdot
.45164 .58021 Mdot
.48473 .63703 Mdot
.42254 .48085 Mdot
.42936 .62158 Mdot
.32438 .73468 Mdot
.45688 .62656 Mdot
.46236 .36641 Mdot
.50797 .62153 Mdot
.80361 .49963 Mdot
.39467 .45322 Mdot
.61508 .54472 Mdot
.41561 .37555 Mdot
.44679 .38025 Mdot
.26362 .35733 Mdot
.65486 .34531 Mdot
.44442 .57162 Mdot
.484 .36205 Mdot
.39874 .54524 Mdot
.61611 .4138 Mdot
.47266 .66679 Mdot
.54266 .39906 Mdot
.40145 .27867 Mdot
.42719 .38472 Mdot
.51473 .55362 Mdot
.67422 .57775 Mdot
.44664 .63851 Mdot
.48104 .34756 Mdot
.37325 .61453 Mdot
.49899 .60219 Mdot
.75252 .35926 Mdot
.40086 .4858 Mdot
.6376 .3961 Mdot
.41988 .5693 Mdot
.42664 .65586 Mdot
.42705 .3565 Mdot
.69403 .55818 Mdot
.62321 .41071 Mdot
.65272 .55267 Mdot
.34133 .70562 Mdot
.53699 .18605 Mdot
.48043 .49849 Mdot
.28697 .45399 Mdot
.38935 .3109 Mdot
.35101 .73167 Mdot
.79119 .61122 Mdot
.63364 .77909 Mdot
.40187 .77316 Mdot
.4654 .32149 Mdot
.37544 .30261 Mdot
.44815 .37052 Mdot
.47845 .64687 Mdot
.43943 .36529 Mdot
.41768 .82471 Mdot
.45171 .62128 Mdot
.44173 .35177 Mdot
.72371 .66568 Mdot
.44336 .6346 Mdot
.62179 .58164 Mdot
.30412 .74812 Mdot
.82722 .47595 Mdot
.68023 .38403 Mdot
.46175 .33623 Mdot
.53107 .81719 Mdot
.44112 .61413 Mdot
.50698 .62381 Mdot
.67993 .56758 Mdot
.50062 .6758 Mdot
.30136 .4517 Mdot
.34684 .45057 Mdot
.62154 .44734 Mdot
.34396 .49025 Mdot
.42102 .56788 Mdot
.6617 .56235 Mdot
.5559 .53821 Mdot
.28173 .34732 Mdot
.36042 .29245 Mdot
.58389 .41592 Mdot
.30313 .74625 Mdot
.66613 .48642 Mdot
.63635 .46932 Mdot
.52908 .34855 Mdot
.67405 .53989 Mdot
.37929 .80347 Mdot
.61364 .36725 Mdot
.46826 .17807 Mdot
.76093 .54295 Mdot
.4724 .58819 Mdot
.6079 .40933 Mdot
.54211 .59379 Mdot
.81812 .50667 Mdot
.41431 .20299 Mdot
.44926 .75894 Mdot
.46395 .67189 Mdot
.38766 .27471 Mdot
.45297 .60819 Mdot
.44747 .27123 Mdot
.46592 .63126 Mdot
.6559 .55118 Mdot
.75168 .54481 Mdot
.66891 .38719 Mdot
.57369 .58457 Mdot
.55092 .29685 Mdot
.3211 .42893 Mdot
.45803 .6224 Mdot
.46927 .58598 Mdot
.29802 .4524 Mdot
.64337 .57048 Mdot
.41035 .64036 Mdot
.7408 .67577 Mdot
.47214 .58164 Mdot
.5969 .37541 Mdot
.76268 .55817 Mdot
.48396 .728 Mdot
.41529 .59281 Mdot
.66342 .52047 Mdot
.5895 .37363 Mdot
.60384 .39013 Mdot
.38691 .66263 Mdot
.58896 .41297 Mdot
.4328 .60898 Mdot
.38719 .21139 Mdot
.64233 .57754 Mdot
.70913 .29984 Mdot
.62139 .54585 Mdot
.60899 .70749 Mdot
.64243 .38317 Mdot
.60143 .24635 Mdot
.53901 .58911 Mdot
.6147 .36975 Mdot
.57587 .60948 Mdot
.46769 .57082 Mdot
.46256 .56869 Mdot
.50708 .81656 Mdot
.47088 .3604 Mdot
.41468 .47946 Mdot
.59031 .40992 Mdot
.43585 .59248 Mdot
.40359 .61389 Mdot
.59216 .37042 Mdot
.46337 .21501 Mdot
.78646 .57347 Mdot
.45495 .6245 Mdot
.66403 .55065 Mdot
.6637 .54324 Mdot
.50138 .56928 Mdot
.46728 .65736 Mdot
.4377 .38573 Mdot
.40839 .35188 Mdot
.49048 .36308 Mdot
.40412 .47987 Mdot
.6349 .26551 Mdot
.19747 .57725 Mdot
.61795 .35794 Mdot
.74512 .44402 Mdot
.46749 .49341 Mdot
.45828 .67449 Mdot
.4564 .3309 Mdot
.42364 .65399 Mdot
.4209 .62883 Mdot
.61796 .31452 Mdot
.22925 .6297 Mdot
.72059 .52264 Mdot
.69727 .55153 Mdot
.65308 .36467 Mdot
.4 .5842 Mdot
.58154 .35014 Mdot
.32486 .46995 Mdot
.35092 .6441 Mdot
.59624 .41175 Mdot
.61321 .57729 Mdot
.63747 .36591 Mdot
.48119 .60003 Mdot
.52891 .62798 Mdot
.67089 .53958 Mdot
.3089 .47026 Mdot
.45867 .6856 Mdot
.46264 .60845 Mdot
.65341 .21524 Mdot
.3648 .55442 Mdot
.63004 .46393 Mdot
.45458 .62712 Mdot
.45727 .57371 Mdot
.35491 .45406 Mdot
.47537 .5845 Mdot
.4379 .66346 Mdot
.5699 .68028 Mdot
.6914 .42992 Mdot
.33259 .42471 Mdot
.40701 .21319 Mdot
.65844 .52668 Mdot
.38292 .79181 Mdot
.447 .33248 Mdot
.6517 .42956 Mdot
.77834 .56859 Mdot
.44625 .3983 Mdot
.5139 .26565 Mdot
.37123 .78041 Mdot
.3864 .37753 Mdot
.49783 .35763 Mdot
.6238 .5916 Mdot
.42047 .60199 Mdot
.45788 .61487 Mdot
.30689 .44898 Mdot
.63645 .53625 Mdot
.53852 .48491 Mdot
.22014 .35962 Mdot
.4479 .60077 Mdot
.74398 .35144 Mdot
.39049 .24125 Mdot
.37642 .28199 Mdot
.31767 .45555 Mdot
.34887 .44936 Mdot
.45983 .62169 Mdot
.56295 .66744 Mdot
.65556 .56478 Mdot
.45089 .58073 Mdot
.4495 .67652 Mdot
.47023 .34944 Mdot
.62526 .56225 Mdot
.42171 .33321 Mdot
.57007 .26345 Mdot
.31673 .71241 Mdot
.44609 .16253 Mdot
.62141 .40222 Mdot
.33424 .2781 Mdot
.62056 .41836 Mdot
.26751 .55624 Mdot
.45004 .40217 Mdot
.45124 .64509 Mdot
.68674 .56741 Mdot
.43037 .59922 Mdot
.46352 .65513 Mdot
.46792 .58388 Mdot
.41076 .6003 Mdot
.47475 .14954 Mdot
.31732 .42655 Mdot
.4144 .674 Mdot
.45926 .37204 Mdot
.20599 .43568 Mdot
.23081 .38681 Mdot
.46725 .58687 Mdot
.47455 .63341 Mdot
.63295 .55944 Mdot
.47028 .66429 Mdot
.62081 .41612 Mdot
.62551 .58692 Mdot
.49017 .61087 Mdot
.24793 .70618 Mdot
.49275 .5983 Mdot
.34238 .73069 Mdot
.63636 .36657 Mdot
.5606 .20736 Mdot
.52398 .64045 Mdot
.67175 .31615 Mdot
.41483 .47957 Mdot
.45746 .39495 Mdot
.63504 .4122 Mdot
.45076 .34443 Mdot
.23712 .32784 Mdot
.50795 .56128 Mdot
.44185 .62626 Mdot
.44515 .67089 Mdot
.4853 .37012 Mdot
.19779 .66111 Mdot
.57013 .30213 Mdot
.50562 .55776 Mdot
.43402 .38347 Mdot
.60118 .54898 Mdot
.39794 .75173 Mdot
.63761 .5442 Mdot
.32184 .48692 Mdot
.59601 .37286 Mdot
.30736 .46794 Mdot
.28219 .62872 Mdot
.61965 .56811 Mdot
.69347 .57896 Mdot
.45058 .33396 Mdot
.70774 .59353 Mdot
.82115 .33598 Mdot
.76357 .539 Mdot
.29676 .54613 Mdot
.66839 .56746 Mdot
.48704 .59388 Mdot
.26868 .58757 Mdot
.75667 .54492 Mdot
.44956 .34694 Mdot
.4188 .64221 Mdot
.71121 .62055 Mdot
.4383 .38705 Mdot
.49829 .6661 Mdot
.46325 .37223 Mdot
.62466 .36419 Mdot
.46524 .33521 Mdot
.70766 .53743 Mdot
.49227 .62545 Mdot
.836 .34284 Mdot
.3559 .49001 Mdot
.44031 .61779 Mdot
.64918 .35091 Mdot
.49575 .23572 Mdot
.43911 .64477 Mdot
.29019 .4434 Mdot
.43577 .35418 Mdot
.64912 .60417 Mdot
.4594 .62712 Mdot
.43342 .38306 Mdot
.63739 .58247 Mdot
.64307 .33516 Mdot
.71161 .64113 Mdot
.66183 .45301 Mdot
.68573 .56425 Mdot
.6104 .49062 Mdot
.65545 .38385 Mdot
.45255 .5732 Mdot
.40794 .63074 Mdot
.66195 .54719 Mdot
.22558 .491 Mdot
.49658 .64737 Mdot
.50866 .61373 Mdot
.46769 .35387 Mdot
.44624 .34233 Mdot
.62333 .78198 Mdot
.43517 .32414 Mdot
.51659 .65051 Mdot
.65877 .54602 Mdot
.43603 .63611 Mdot
.63117 .56257 Mdot
.46873 .66397 Mdot
.41947 .71435 Mdot
.64423 .57086 Mdot
.61704 .31768 Mdot
.41925 .63766 Mdot
.44667 .69224 Mdot
.44886 .65386 Mdot
.42412 .59496 Mdot
.43856 .38351 Mdot
.31183 .45603 Mdot
.45685 .67636 Mdot
.27976 .42828 Mdot
.32711 .42596 Mdot
.67474 .38667 Mdot
.4712 .35182 Mdot
.31169 .43231 Mdot
.33236 .24966 Mdot
.42611 .37064 Mdot
.30512 .44576 Mdot
.22923 .38967 Mdot
.64058 .37809 Mdot
.67754 .57694 Mdot
.44766 .63598 Mdot
.32001 .65506 Mdot
.50797 .7527 Mdot
.4595 .41156 Mdot
.45157 .62404 Mdot
.4375 .65023 Mdot
.61942 .53442 Mdot
.18021 .41008 Mdot
.47555 .32132 Mdot
.48544 .58653 Mdot
.61449 .57198 Mdot
.14207 .46741 Mdot
.45742 .36773 Mdot
.30459 .45109 Mdot
.64301 .36524 Mdot
.59412 .59767 Mdot
.69128 .32541 Mdot
.63854 .34655 Mdot
.40591 .39568 Mdot
.58337 .26797 Mdot
.40064 .63101 Mdot
.4366 .33034 Mdot
.76364 .7013 Mdot
.52685 .52668 Mdot
.44385 .46948 Mdot
.5021 .80719 Mdot
.68225 .54542 Mdot
.62022 .41779 Mdot
.32754 .43193 Mdot
.66815 .52854 Mdot
.62546 .57216 Mdot
.60053 .36356 Mdot
.53724 .68136 Mdot
.54331 .39429 Mdot
.59484 .38457 Mdot
.33872 .61232 Mdot
.20973 .49443 Mdot
.44764 .32905 Mdot
.30118 .4504 Mdot
.27015 .63289 Mdot
.64848 .55041 Mdot
.34549 .79686 Mdot
.52923 .82603 Mdot
.44315 .61317 Mdot
.32332 .43429 Mdot
.19831 .64544 Mdot
.1812 .42517 Mdot
.63453 .39151 Mdot
.66566 .40873 Mdot
.32208 .47498 Mdot
.44502 .65645 Mdot
.3644 .5817 Mdot
.49333 .64278 Mdot
.60498 .36527 Mdot
.70099 .66066 Mdot
.62153 .57044 Mdot
.62935 .35435 Mdot
.36033 .69304 Mdot
.43481 .60661 Mdot
.42064 .6408 Mdot
.33106 .57403 Mdot
.67011 .52779 Mdot
.45946 .39483 Mdot
.40578 .63854 Mdot
.45952 .60623 Mdot
.52257 .63807 Mdot
.494 .56186 Mdot
.60699 .65619 Mdot
.47549 .6433 Mdot
.31959 .29551 Mdot
.45942 .66934 Mdot
.42304 .61492 Mdot
.67669 .52541 Mdot
.41252 .16958 Mdot
.57616 .2766 Mdot
.45629 .6043 Mdot
.46773 .57594 Mdot
.6338 .35591 Mdot
.54734 .37424 Mdot
.73791 .55293 Mdot
.63962 .602 Mdot
.58281 .80649 Mdot
.47888 .56822 Mdot
.60535 .55983 Mdot
.29338 .44086 Mdot
.44713 .57167 Mdot
.60678 .57028 Mdot
.51307 .61677 Mdot
.44276 .39178 Mdot
.42712 .37403 Mdot
.56153 .55419 Mdot
.30784 .43204 Mdot
.79596 .47531 Mdot
.74274 .44298 Mdot
.42612 .36238 Mdot
.44582 .62852 Mdot
.57571 .41352 Mdot
.47969 .35633 Mdot
.38384 .37816 Mdot
.21792 .53166 Mdot
.66403 .57222 Mdot
.68421 .55865 Mdot
.24118 .53691 Mdot
.53604 .25185 Mdot
.75125 .33747 Mdot
.62325 .36293 Mdot
.42464 .67843 Mdot
.77408 .46042 Mdot
.68769 .55606 Mdot
.27072 .57287 Mdot
.31831 .43135 Mdot
.63414 .38938 Mdot
.55923 .33239 Mdot
.62897 .55227 Mdot
.65725 .58783 Mdot
.50341 .64965 Mdot
.47009 .60411 Mdot
.64996 .76374 Mdot
.28364 .42282 Mdot
.61235 .35154 Mdot
.30237 .45252 Mdot
.44249 .40046 Mdot
.49483 .63522 Mdot
.64446 .56807 Mdot
.20103 .50824 Mdot
.41643 .58648 Mdot
.45456 .38943 Mdot
.68452 .54985 Mdot
.33462 .47253 Mdot
.28964 .45195 Mdot
.42329 .59064 Mdot
.69119 .72482 Mdot
.60408 .37467 Mdot
.65879 .53151 Mdot
.58629 .44155 Mdot
.49124 .64735 Mdot
.47077 .6122 Mdot
.43096 .70696 Mdot
.61616 .3502 Mdot
.71149 .49237 Mdot
.28844 .43875 Mdot
.65019 .53463 Mdot
.47497 .64014 Mdot
.30227 .44256 Mdot
.75273 .44591 Mdot
.42394 .39525 Mdot
.46825 .33639 Mdot
.29109 .4545 Mdot
.32564 .45335 Mdot
.29153 .43517 Mdot
.34874 .80116 Mdot
.59765 .56618 Mdot
.64474 .47805 Mdot
.49285 .58515 Mdot
.28242 .54449 Mdot
.4229 .6813 Mdot
.63594 .40107 Mdot
.46984 .3654 Mdot
.44962 .64945 Mdot
.42363 .58563 Mdot
.41003 .70149 Mdot
.72429 .31839 Mdot
.49083 .70008 Mdot
.62538 .56608 Mdot
.53079 .62422 Mdot
.46172 .33754 Mdot
.35509 .82175 Mdot
.56779 .83531 Mdot
.52766 .63289 Mdot
.54864 .39143 Mdot
.65126 .57373 Mdot
.61614 .35797 Mdot
.3123 .60538 Mdot
.64162 .3735 Mdot
.65941 .53744 Mdot
.48081 .64404 Mdot
.73558 .46806 Mdot
.35516 .43729 Mdot
.43142 .5938 Mdot
.62211 .36046 Mdot
.41355 .62465 Mdot
.62709 .34833 Mdot
.3178 .66644 Mdot
.74545 .70513 Mdot
.44255 .60796 Mdot
.39538 .63604 Mdot
.68307 .7443 Mdot
.45934 .58464 Mdot
.26916 .42078 Mdot
.65219 .57421 Mdot
.71 .6592 Mdot
.39488 .60103 Mdot
.36217 .62053 Mdot
.49754 .64008 Mdot
.73365 .63614 Mdot
.47344 .61021 Mdot
.37049 .28248 Mdot
.4978 .61985 Mdot
.43616 .66433 Mdot
.61034 .40085 Mdot
.63243 .35449 Mdot
.69736 .5368 Mdot
.48115 .33814 Mdot
.33825 .73114 Mdot
.46522 .61065 Mdot
.61828 .25823 Mdot
.69294 .45538 Mdot
.32308 .45538 Mdot
.6535 .53656 Mdot
.14731 .49115 Mdot
.60378 .4245 Mdot
.62336 .8052 Mdot
.57161 .80316 Mdot
.70433 .39093 Mdot
.23638 .61638 Mdot
.45323 .23588 Mdot
.33083 .47208 Mdot
.51142 .62939 Mdot
.36227 .39133 Mdot
.3659 .28279 Mdot
.22188 .49279 Mdot
.64253 .40505 Mdot
.64854 .74489 Mdot
.21383 .57557 Mdot
.30325 .47805 Mdot
.34902 .45777 Mdot
.64827 .36223 Mdot
.47596 .30347 Mdot
.40193 .57276 Mdot
.32975 .43999 Mdot
.4882 .3642 Mdot
.42333 .37357 Mdot
.49118 .34887 Mdot
.65214 .5651 Mdot
.57267 .82984 Mdot
.64733 .40469 Mdot
.63304 .40155 Mdot
.43393 .28729 Mdot
.38594 .71208 Mdot
.67982 .59212 Mdot
.45879 .34332 Mdot
.45549 .32483 Mdot
.65501 .57668 Mdot
.52359 .60675 Mdot
.4965 .55764 Mdot
.45193 .60203 Mdot
.31015 .45131 Mdot
.4748 .60436 Mdot
.43204 .37551 Mdot
.62527 .39838 Mdot
.46685 .32973 Mdot
.6447 .34502 Mdot
.19256 .51864 Mdot
.4437 .5795 Mdot
.49359 .62655 Mdot
.59883 .18234 Mdot
.6829 .57944 Mdot
.20148 .45298 Mdot
.60716 .3342 Mdot
.44958 .37117 Mdot
.43762 .66271 Mdot
.66851 .59727 Mdot
.32098 .41236 Mdot
.45275 .16637 Mdot
.47678 .65852 Mdot
.64157 .55476 Mdot
.49072 .63818 Mdot
.4689 .51106 Mdot
.80023 .39137 Mdot
.65025 .54532 Mdot
.73081 .31039 Mdot
.48486 .58845 Mdot
.3414 .25444 Mdot
.46358 .66778 Mdot
.41265 .50712 Mdot
.49639 .64751 Mdot
.6562 .5261 Mdot
.45618 .59998 Mdot
.65162 .59649 Mdot
.42501 .35004 Mdot
.63281 .35815 Mdot
.68447 .56397 Mdot
.41147 .60752 Mdot
.69349 .15678 Mdot
.63084 .37198 Mdot
.45435 .6191 Mdot
.6465 .36912 Mdot
.6258 .54023 Mdot
.67495 .53543 Mdot
.21439 .39117 Mdot
.56572 .26299 Mdot
.62547 .36584 Mdot
.49378 .63602 Mdot
.37279 .25727 Mdot
.46066 .64601 Mdot
.38717 .5537 Mdot
.526 .60382 Mdot
.50993 .59462 Mdot
.20844 .41295 Mdot
.64017 .39316 Mdot
.7501 .33243 Mdot
.19091 .42383 Mdot
.20645 .43321 Mdot
.70519 .54286 Mdot
.30044 .47391 Mdot
.37006 .79404 Mdot
.6411 .27118 Mdot
.4471 .39537 Mdot
.4453 .64887 Mdot
.57969 .57696 Mdot
.60109 .37997 Mdot
.32054 .46781 Mdot
.44336 .60855 Mdot
.45601 .32689 Mdot
.79102 .59588 Mdot
.65416 .36434 Mdot
.64501 .54439 Mdot
.61427 .53607 Mdot
.29121 .24877 Mdot
.46273 .6317 Mdot
.49323 .62045 Mdot
.59618 .37238 Mdot
.47305 .22826 Mdot
.34084 .44273 Mdot
.72502 .66196 Mdot
.62598 .36802 Mdot
.53008 .46423 Mdot
.60611 .57273 Mdot
.4351 .6518 Mdot
.2504 .69281 Mdot
.55058 .32722 Mdot
.65048 .2247 Mdot
.30932 .44932 Mdot
.39412 .54669 Mdot
.65597 .52646 Mdot
.62191 .38885 Mdot
.5363 .23549 Mdot
.46832 .56854 Mdot
.41681 .64844 Mdot
.41203 .52137 Mdot
.67332 .38018 Mdot
.72729 .56715 Mdot
.47978 .6562 Mdot
.41464 .47769 Mdot
.4708 .66079 Mdot
.39748 .66915 Mdot
.52845 .59268 Mdot
.47756 .6198 Mdot
.64253 .56294 Mdot
.45678 .53745 Mdot
.47812 .37964 Mdot
.72018 .52879 Mdot
.51868 .46554 Mdot
.44555 .61965 Mdot
.50767 .61002 Mdot
.46678 .76036 Mdot
.48937 .26096 Mdot
.68135 .56481 Mdot
.70884 .55831 Mdot
.59585 .42134 Mdot
.5144 .57686 Mdot
.48006 .33652 Mdot
.43984 .68488 Mdot
.44106 .38544 Mdot
.64403 .56548 Mdot
.45247 .36952 Mdot
.64252 .35907 Mdot
.42921 .33424 Mdot
.62647 .25865 Mdot
.63129 .38212 Mdot
.67353 .57133 Mdot
.48736 .61303 Mdot
.64911 .34986 Mdot
.31908 .53149 Mdot
.3108 .4487 Mdot
.162 .57558 Mdot
.49071 .61053 Mdot
.69194 .39892 Mdot
.37914 .66934 Mdot
.46213 .32702 Mdot
.78995 .37242 Mdot
.69292 .56309 Mdot
.3414 .43305 Mdot
.67933 .53167 Mdot
.35249 .64463 Mdot
.32207 .44644 Mdot
.16216 .52034 Mdot
.40374 .49346 Mdot
.36918 .55227 Mdot
.51645 .58543 Mdot
.34303 .55653 Mdot
.42908 .39189 Mdot
.60211 .38125 Mdot
.52732 .2447 Mdot
.43216 .66194 Mdot
.80544 .61462 Mdot
.67049 .52436 Mdot
.48353 .35454 Mdot
.61796 .39331 Mdot
.6289 .40731 Mdot
.47607 .57656 Mdot
.3323 .32734 Mdot
.41687 .65129 Mdot
.55474 .24851 Mdot
.52978 .81553 Mdot
.64753 .48253 Mdot
.45522 .62299 Mdot
.42687 .35538 Mdot
.49042 .63846 Mdot
.28677 .44255 Mdot
.66518 .78173 Mdot
.44919 .68893 Mdot
.58285 .36617 Mdot
.28689 .41816 Mdot
.63506 .53312 Mdot
.39778 .70018 Mdot
.65102 .46934 Mdot
.4652 .63434 Mdot
.41472 .13929 Mdot
.30448 .44345 Mdot
.3649 .38436 Mdot
.40916 .5967 Mdot
.43321 .57499 Mdot
.43335 .45584 Mdot
.68784 .3082 Mdot
.49929 .306 Mdot
.45182 .58769 Mdot
.32279 .52012 Mdot
.6496 .37293 Mdot
.45189 .65792 Mdot
.45765 .6168 Mdot
.53306 .71999 Mdot
.64707 .38719 Mdot
.45221 .38266 Mdot
.45011 .39956 Mdot
.44765 .41095 Mdot
.2926 .42858 Mdot
.74019 .53272 Mdot
.28539 .56543 Mdot
.80981 .54351 Mdot
.34965 .43826 Mdot
.43227 .58055 Mdot
.38125 .35431 Mdot
.48696 .64398 Mdot
.32242 .46535 Mdot
.64937 .38267 Mdot
.6899 .55567 Mdot
.76914 .45964 Mdot
.43562 .39265 Mdot
.44779 .56638 Mdot
.336 .43134 Mdot
.66245 .57075 Mdot
.29068 .61255 Mdot
.63632 .53323 Mdot
.61837 .37119 Mdot
.74289 .53259 Mdot
.32468 .46763 Mdot
.6152 .54864 Mdot
.56956 .39077 Mdot
.19847 .40197 Mdot
.52185 .57742 Mdot
.75469 .50022 Mdot
.62913 .53364 Mdot
.70407 .56976 Mdot
.60253 .55785 Mdot
.41777 .61123 Mdot
.5477 .39332 Mdot
.50664 .58167 Mdot
.64476 .38615 Mdot
.46057 .37574 Mdot
.7523 .68158 Mdot
.63171 .30152 Mdot
.58686 .46441 Mdot
.46957 .6807 Mdot
.4353 .60534 Mdot
.4594 .62136 Mdot
.39173 .64957 Mdot
.63235 .26027 Mdot
.41898 .6155 Mdot
.60952 .40091 Mdot
.43428 .3608 Mdot
.51213 .62619 Mdot
.40905 .38944 Mdot
.22675 .40677 Mdot
.31901 .47599 Mdot
.60997 .44771 Mdot
.63763 .81576 Mdot
.66602 .57033 Mdot
.41468 .36977 Mdot
.42979 .36593 Mdot
.33978 .46002 Mdot
.60013 .37478 Mdot
.62972 .53551 Mdot
.4093 .53954 Mdot
.32557 .42532 Mdot
.45784 .6021 Mdot
.55913 .38976 Mdot
.79342 .63871 Mdot
.50795 .63869 Mdot
.43696 .64087 Mdot
.49027 .34082 Mdot
.36886 .38869 Mdot
.86968 .46882 Mdot
.30298 .57701 Mdot
.31432 .46292 Mdot
.30158 .47049 Mdot
.65353 .57906 Mdot
.4283 .5724 Mdot
.647 .35323 Mdot
.72535 .59012 Mdot
.69155 .48959 Mdot
.78609 .42317 Mdot
.62608 .21031 Mdot
.46214 .65779 Mdot
.44509 .21833 Mdot
.42891 .61238 Mdot
.59905 .56134 Mdot
.64582 .56063 Mdot
.66592 .55876 Mdot
.60294 .38012 Mdot
.61769 .73757 Mdot
.60258 .39529 Mdot
.73624 .74245 Mdot
.66476 .53047 Mdot
.39568 .49485 Mdot
.4624 .34222 Mdot
.49771 .55364 Mdot
.32436 .47485 Mdot
.75339 .51923 Mdot
.50607 .67827 Mdot
.56326 .65302 Mdot
.4829 .36237 Mdot
.68117 .56852 Mdot
.46794 .23167 Mdot
.4437 .81429 Mdot
.70655 .59139 Mdot
.4433 .71332 Mdot
.31156 .60788 Mdot
.32079 .4589 Mdot
.64762 .22259 Mdot
.30673 .46494 Mdot
.62458 .36054 Mdot
.48839 .63259 Mdot
.48634 .62324 Mdot
.47204 .66129 Mdot
.45678 .58025 Mdot
.65901 .37235 Mdot
.42378 .67123 Mdot
.8031 .50103 Mdot
.44115 .39518 Mdot
.28485 .49364 Mdot
.30442 .45829 Mdot
.64051 .40233 Mdot
.43363 .36278 Mdot
.49821 .26254 Mdot
.32904 .54388 Mdot
.45756 .62578 Mdot
.44872 .64958 Mdot
.65698 .77608 Mdot
.47986 .65566 Mdot
.42128 .55609 Mdot
.43699 .38986 Mdot
.46497 .73352 Mdot
.31839 .47552 Mdot
.30815 .47469 Mdot
.63282 .38279 Mdot
.64339 .5615 Mdot
.30977 .43807 Mdot
.46582 .34707 Mdot
.47682 .68003 Mdot
.41134 .66029 Mdot
.63613 .53115 Mdot
.66738 .77291 Mdot
.28782 .45727 Mdot
.37047 .25507 Mdot
.67401 .57317 Mdot
.66405 .51774 Mdot
.41813 .65006 Mdot
.68049 .25378 Mdot
.69315 .52328 Mdot
.31925 .41699 Mdot
.64109 .40318 Mdot
.32245 .60113 Mdot
.60543 .42274 Mdot
.64183 .54376 Mdot
.49553 .59697 Mdot
.65056 .56873 Mdot
.45766 .62824 Mdot
.48993 .84111 Mdot
.48198 .61925 Mdot
.81233 .52898 Mdot
.23918 .52414 Mdot
.43539 .33861 Mdot
.47903 .25289 Mdot
.44757 .3327 Mdot
.69505 .5529 Mdot
.40558 .59796 Mdot
.34536 .45649 Mdot
.25955 .3433 Mdot
.63441 .6168 Mdot
.47556 .36505 Mdot
.45275 .31178 Mdot
.61588 .42535 Mdot
.49934 .64552 Mdot
.41392 .6396 Mdot
.44263 .34888 Mdot
.67982 .50672 Mdot
.62389 .54958 Mdot
.4782 .63615 Mdot
.43319 .60478 Mdot
.43938 .33587 Mdot
.20174 .39058 Mdot
.50868 .53796 Mdot
.48259 .6304 Mdot
.52206 .33038 Mdot
.63251 .40372 Mdot
.49949 .55513 Mdot
.39742 .6395 Mdot
.32819 .45149 Mdot
.64318 .6473 Mdot
.44657 .79712 Mdot
.65117 .37881 Mdot
.4296 .37662 Mdot
.46894 .63581 Mdot
.42695 .35805 Mdot
.42064 .67106 Mdot
.69494 .32716 Mdot
.41636 .36812 Mdot
.50967 .60245 Mdot
.52175 .60926 Mdot
.66529 .52574 Mdot
.45556 .65422 Mdot
.51176 .78175 Mdot
.46578 .38638 Mdot
.47946 .57895 Mdot
.70915 .69383 Mdot
.59205 .39404 Mdot
.49802 .56285 Mdot
.322 .42556 Mdot
.36943 .5818 Mdot
.72864 .44828 Mdot
.24756 .64031 Mdot
.31771 .47832 Mdot
.41522 .62013 Mdot
.46605 .31616 Mdot
.6107 .35259 Mdot
.8237 .48259 Mdot
.44171 .65579 Mdot
.61358 .36199 Mdot
.62606 .39743 Mdot
.32104 .4695 Mdot
.38673 .17554 Mdot
.41185 .59528 Mdot
.47002 .58924 Mdot
.57174 .74491 Mdot
.66788 .58819 Mdot
.47919 .61019 Mdot
.48016 .5874 Mdot
.61335 .40339 Mdot
.41626 .56736 Mdot
.5792 .79186 Mdot
.73128 .64649 Mdot
.58751 .3761 Mdot
.78429 .48337 Mdot
.41859 .37333 Mdot
.2976 .44741 Mdot
.67502 .54447 Mdot
.34104 .44031 Mdot
.46909 .34227 Mdot
.48468 .59462 Mdot
.60045 .36624 Mdot
.50884 .77341 Mdot
.6476 .35974 Mdot
.21559 .5598 Mdot
.63327 .58934 Mdot
.64625 .41582 Mdot
.39855 .1513 Mdot
.52646 .30697 Mdot
.6768 .35114 Mdot
.32348 .45493 Mdot
.41075 .31422 Mdot
.43208 .60639 Mdot
.6297 .20625 Mdot
.43872 .57809 Mdot
.70656 .67862 Mdot
.45083 .39755 Mdot
.4918 .35811 Mdot
.48516 .63267 Mdot
.5081 .80785 Mdot
.60409 .35584 Mdot
.61361 .41354 Mdot
.50487 .59555 Mdot
.61525 .36929 Mdot
.46974 .59932 Mdot
.43397 .37648 Mdot
.66884 .22169 Mdot
.44878 .60591 Mdot
.40943 .67866 Mdot
.69895 .37106 Mdot
.19659 .42488 Mdot
.28342 .47731 Mdot
.2309 .3076 Mdot
.49344 .83292 Mdot
.61413 .37067 Mdot
.50082 .58188 Mdot
.78519 .47178 Mdot
.4819 .3293 Mdot
.60793 .45692 Mdot
.48431 .60116 Mdot
.46348 .57781 Mdot
.44344 .66723 Mdot
.42369 .64024 Mdot
.50425 .17031 Mdot
.67629 .61307 Mdot
.62612 .68605 Mdot
.46174 .65546 Mdot
.34813 .53883 Mdot
.63631 .37025 Mdot
.58211 .58397 Mdot
.33997 .42691 Mdot
.45994 .65692 Mdot
.71833 .57543 Mdot
.58567 .38685 Mdot
.76308 .71901 Mdot
.60842 .36282 Mdot
.44614 .37903 Mdot
.6343 .35161 Mdot
.43068 .62084 Mdot
.66405 .54368 Mdot
.44594 .43767 Mdot
.56395 .28698 Mdot
.4652 .39456 Mdot
.44082 .61805 Mdot
.36987 .50052 Mdot
.48021 .37488 Mdot
.1965 .45337 Mdot
.67505 .54946 Mdot
.31015 .5152 Mdot
.64746 .56616 Mdot
.50031 .59542 Mdot
.50065 .59697 Mdot
.59731 .42681 Mdot
.64031 .35559 Mdot
.64632 .56499 Mdot
.30485 .21072 Mdot
.28839 .44266 Mdot
.66261 .55638 Mdot
.39059 .60602 Mdot
.52237 .41341 Mdot
.66689 .54788 Mdot
.32994 .40874 Mdot
.62085 .40134 Mdot
.67166 .58154 Mdot
.46852 .67196 Mdot
.34161 .6107 Mdot
.29215 .45121 Mdot
.46929 .3976 Mdot
.27401 .5949 Mdot
.47297 .37483 Mdot
.63723 .40996 Mdot
.44313 .33309 Mdot
.63146 .40097 Mdot
.71469 .46436 Mdot
.71352 .52004 Mdot
.3873 .41097 Mdot
.64131 .40942 Mdot
.45113 .33433 Mdot
.48945 .63506 Mdot
.34371 .4952 Mdot
.41059 .58464 Mdot
.41025 .62735 Mdot
.61437 .4094 Mdot
.6726 .53087 Mdot
.70667 .54756 Mdot
.38069 .54682 Mdot
.63865 .55983 Mdot
.4583 .38784 Mdot
.60092 .63962 Mdot
.62496 .27076 Mdot
.60114 .41861 Mdot
.63552 .35752 Mdot
.48438 .64826 Mdot
.45051 .34511 Mdot
.47821 .38628 Mdot
.60714 .42421 Mdot
.71465 .31696 Mdot
.39479 .64527 Mdot
.71076 .55736 Mdot
.66386 .58765 Mdot
.65361 .54525 Mdot
.59952 .57502 Mdot
.3654 .61161 Mdot
.63856 .38421 Mdot
.68152 .5358 Mdot
.48468 .64904 Mdot
.47817 .58796 Mdot
.75431 .55787 Mdot
.29622 .43976 Mdot
.51466 .6089 Mdot
.5276 .59261 Mdot
.43366 .65195 Mdot
.46042 .33142 Mdot
.4315 .54686 Mdot
.42471 .33495 Mdot
.47955 .32976 Mdot
.48121 .33092 Mdot
.64952 .2802 Mdot
.61011 .80591 Mdot
.37999 .759 Mdot
.47673 .57921 Mdot
.40937 .2287 Mdot
.45774 .35583 Mdot
.68927 .61585 Mdot
.70352 .48728 Mdot
.43701 .66137 Mdot
.30485 .31265 Mdot
.44244 .34465 Mdot
.66457 .5766 Mdot
.48455 .60978 Mdot
.41629 .38537 Mdot
.31035 .42445 Mdot
.45987 .5702 Mdot
.42621 .39802 Mdot
.61334 .54947 Mdot
.29258 .42378 Mdot
.68505 .57639 Mdot
.48024 .32888 Mdot
.40398 .58157 Mdot
.76328 .29361 Mdot
.41836 .39608 Mdot
.29694 .27937 Mdot
.5552 .61285 Mdot
.48255 .63741 Mdot
.41306 .34884 Mdot
.65862 .51502 Mdot
.63587 .41066 Mdot
.56888 .49642 Mdot
.64035 .57836 Mdot
.49186 .3578 Mdot
.47759 .33725 Mdot
.46489 .39475 Mdot
.62865 .57133 Mdot
.48421 .56264 Mdot
.62839 .56038 Mdot
.63188 .35059 Mdot
.45063 .63912 Mdot
.34457 .71726 Mdot
.48719 .22587 Mdot
.6655 .57474 Mdot
.46266 .37879 Mdot
.35638 .44706 Mdot
.4356 .60909 Mdot
.4576 .22447 Mdot
.48887 .63719 Mdot
.62779 .40544 Mdot
.58479 .67414 Mdot
.4744 .73676 Mdot
.50675 .58768 Mdot
.47765 .64983 Mdot
.61093 .41326 Mdot
.44294 .61448 Mdot
.49712 .64708 Mdot
.62554 .25745 Mdot
.62233 .55959 Mdot
.45236 .59863 Mdot
.46426 .36843 Mdot
.59694 .27115 Mdot
.39891 .6587 Mdot
.38989 .36645 Mdot
.3306 .51747 Mdot
.56004 .68737 Mdot
.44246 .57657 Mdot
.56545 .41472 Mdot
.4192 .64449 Mdot
.43602 .58777 Mdot
.47704 .64728 Mdot
.44728 .18925 Mdot
.42291 .39225 Mdot
.43015 .3557 Mdot
.29728 .46475 Mdot
.32613 .51685 Mdot
.32868 .44027 Mdot
.62752 .3988 Mdot
.33621 .34081 Mdot
.42071 .33862 Mdot
.63145 .54258 Mdot
.4283 .59886 Mdot
.41523 .39126 Mdot
.43327 .655 Mdot
.43208 .62165 Mdot
.47385 .32581 Mdot
.42222 .38733 Mdot
.21189 .50327 Mdot
.29755 .43453 Mdot
.66902 .56324 Mdot
.50971 .62529 Mdot
.3315 .4281 Mdot
.42962 .58108 Mdot
.28106 .54537 Mdot
.66897 .55937 Mdot
.62404 .55859 Mdot
.70604 .53866 Mdot
.48799 .6014 Mdot
.43241 .61554 Mdot
.60246 .3966 Mdot
.69408 .56013 Mdot
.59173 .39026 Mdot
.53425 .48932 Mdot
.25005 .40785 Mdot
.48416 .60049 Mdot
.75456 .53576 Mdot
.3216 .42993 Mdot
.4763 .36145 Mdot
.78543 .65126 Mdot
.29703 .46445 Mdot
.46236 .62996 Mdot
.48491 .34738 Mdot
.33119 .46134 Mdot
.44172 .51003 Mdot
.7078 .75741 Mdot
.35454 .45329 Mdot
.48378 .64947 Mdot
.40917 .57284 Mdot
.24447 .29187 Mdot
.33334 .47825 Mdot
.64212 .36718 Mdot
.48879 .60374 Mdot
.6976 .57925 Mdot
.33675 .43168 Mdot
.42118 .26948 Mdot
.4371 .35089 Mdot
.34659 .60944 Mdot
.4532 .69211 Mdot
.57121 .59683 Mdot
.29781 .46223 Mdot
.65029 .5329 Mdot
.39175 .57741 Mdot
.41921 .64988 Mdot
.33156 .47907 Mdot
.64963 .33606 Mdot
.43792 .36629 Mdot
.57037 .27174 Mdot
.63111 .57408 Mdot
.62436 .31693 Mdot
.47244 .3652 Mdot
.36052 .258 Mdot
.75939 .61018 Mdot
.49208 .55523 Mdot
.33735 .23712 Mdot
.67643 .43161 Mdot
.47254 .6656 Mdot
.33793 .41897 Mdot
.64918 .34763 Mdot
.58452 .39758 Mdot
.62221 .37155 Mdot
.70317 .46477 Mdot
.64471 .60249 Mdot
.43268 .40422 Mdot
.57975 .35552 Mdot
.29816 .44445 Mdot
.32853 .59084 Mdot
.40877 .63587 Mdot
.43957 .60326 Mdot
.50371 .63526 Mdot
.45967 .6582 Mdot
.41868 .62113 Mdot
.60545 .36892 Mdot
.70557 .44982 Mdot
.67271 .60474 Mdot
.66863 .55314 Mdot
.37257 .36327 Mdot
.46512 .35199 Mdot
.49421 .36565 Mdot
.33672 .44846 Mdot
.50113 .29661 Mdot
.41026 .39212 Mdot
.4513 .37163 Mdot
.51625 .62501 Mdot
.6277 .55254 Mdot
.47851 .54831 Mdot
.48039 .64996 Mdot
.45002 .38906 Mdot
.46401 .46532 Mdot
.52874 .79614 Mdot
.23157 .46243 Mdot
.28077 .44211 Mdot
.56452 .38017 Mdot
.30949 .47808 Mdot
.40237 .63079 Mdot
.8016 .40249 Mdot
.46807 .34056 Mdot
.44697 .36087 Mdot
.30168 .43359 Mdot
.68034 .2512 Mdot
.67929 .54447 Mdot
.62865 .31333 Mdot
.64606 .37849 Mdot
.49873 .59916 Mdot
.78803 .60918 Mdot
.56963 .57586 Mdot
.32358 .33063 Mdot
.62772 .37055 Mdot
.42436 .34751 Mdot
.40459 .65285 Mdot
.46932 .6516 Mdot
.32958 .43542 Mdot
.22731 .6398 Mdot
.52859 .58338 Mdot
.19248 .66091 Mdot
.74676 .7043 Mdot
.42169 .77655 Mdot
.41573 .64642 Mdot
.62427 .56223 Mdot
.44186 .39799 Mdot
.30041 .45052 Mdot
.46131 .5668 Mdot
.5014 .82171 Mdot
.64519 .5294 Mdot
.62813 .38228 Mdot
.5014 .45645 Mdot
.31677 .59336 Mdot
.42001 .60236 Mdot
.47324 .58209 Mdot
.43037 .58993 Mdot
.88161 .55591 Mdot
.43828 .32895 Mdot
.66008 .57544 Mdot
.32417 .46938 Mdot
.63866 .55327 Mdot
.42976 .3429 Mdot
.39311 .44484 Mdot
.49711 .62524 Mdot
.61658 .54153 Mdot
.65551 .5338 Mdot
.58625 .3935 Mdot
.65253 .37898 Mdot
.51761 .46971 Mdot
.48035 .61841 Mdot
.43265 .32282 Mdot
.67493 .53095 Mdot
.5647 .40156 Mdot
.32376 .44615 Mdot
.61992 .40253 Mdot
.45698 .65393 Mdot
.42346 .33723 Mdot
.52083 .63248 Mdot
.6838 .56079 Mdot
.45161 .37035 Mdot
.20638 .49217 Mdot
.31708 .4763 Mdot
.47634 .58875 Mdot
.2492 .46298 Mdot
.4313 .38022 Mdot
.42694 .61139 Mdot
.30931 .28465 Mdot
.34368 .41602 Mdot
.56801 .3054 Mdot
.48663 .35749 Mdot
.68091 .33822 Mdot
.65101 .5794 Mdot
.68138 .3115 Mdot
.44488 .36968 Mdot
.38491 .25005 Mdot
.20055 .52772 Mdot
.45611 .67968 Mdot
.6501 .55103 Mdot
.68721 .34885 Mdot
.41703 .83151 Mdot
.26301 .30363 Mdot
.45509 .61866 Mdot
.43753 .32355 Mdot
.3337 .45266 Mdot
.60076 .41639 Mdot
.59413 .30661 Mdot
.36193 .47199 Mdot
.41409 .33018 Mdot
.47647 .64691 Mdot
.63065 .53672 Mdot
.60869 .39313 Mdot
.72813 .45467 Mdot
.46729 .35541 Mdot
.46318 .37509 Mdot
.41082 .58956 Mdot
.31616 .43092 Mdot
.53014 .20402 Mdot
.43593 .38517 Mdot
.68773 .74821 Mdot
.4981 .3501 Mdot
.31516 .42223 Mdot
.42714 .64448 Mdot
.36662 .57427 Mdot
.46397 .5695 Mdot
.25664 .33415 Mdot
.46258 .34527 Mdot
.67586 .56323 Mdot
.41203 .64936 Mdot
.72083 .6947 Mdot
.45902 .3868 Mdot
.55398 .38281 Mdot
.45353 .2836 Mdot
.63875 .38757 Mdot
.78587 .64887 Mdot
.47697 .60253 Mdot
.61176 .35221 Mdot
.33183 .44 Mdot
.48044 .62563 Mdot
.42916 .61865 Mdot
.62555 .53075 Mdot
.58717 .39929 Mdot
.21345 .49718 Mdot
.62654 .35502 Mdot
.63641 .36507 Mdot
.69054 .59192 Mdot
.4606 .59199 Mdot
.44765 .38105 Mdot
.44377 .34518 Mdot
.47222 .67094 Mdot
.60158 .16344 Mdot
.67272 .53896 Mdot
.47658 .39239 Mdot
.88968 .5285 Mdot
.48327 .66502 Mdot
.77409 .64921 Mdot
.21681 .62191 Mdot
.65066 .36061 Mdot
.48499 .64938 Mdot
.61977 .54367 Mdot
.49387 .30169 Mdot
.46066 .37805 Mdot
.46436 .67401 Mdot
.60908 .39086 Mdot
.29532 .43505 Mdot
.47005 .38711 Mdot
.33019 .32959 Mdot
.44745 .57925 Mdot
.28269 .34075 Mdot
.46194 .32269 Mdot
.34898 .77173 Mdot
.50722 .25548 Mdot
.65281 .55354 Mdot
.43137 .62481 Mdot
.68596 .56928 Mdot
.33134 .46699 Mdot
.50419 .45801 Mdot
.61598 .39894 Mdot
.37947 .69837 Mdot
.81133 .42781 Mdot
.4645 .39498 Mdot
.6707 .57531 Mdot
.50198 .58856 Mdot
.6915 .30964 Mdot
.47359 .59835 Mdot
.39488 .68759 Mdot
.21888 .48995 Mdot
.60237 .40844 Mdot
.64958 .37031 Mdot
.42067 .63196 Mdot
.34183 .45551 Mdot
.4661 .35005 Mdot
.43968 .37752 Mdot
.31164 .76501 Mdot
.63241 .31432 Mdot
.64195 .77004 Mdot
.4626 .57779 Mdot
.42982 .3186 Mdot
.65026 .31008 Mdot
.59969 .36902 Mdot
.48088 .55919 Mdot
.48278 .34473 Mdot
.29253 .49776 Mdot
.41352 .51771 Mdot
.41819 .64638 Mdot
.40739 .58435 Mdot
.64683 .36736 Mdot
.69269 .59525 Mdot
.42422 .36233 Mdot
.52792 .62135 Mdot
.3962 .42997 Mdot
.43691 .50926 Mdot
.74571 .71413 Mdot
.66868 .56324 Mdot
.34939 .3046 Mdot
.60371 .37011 Mdot
.41553 .68524 Mdot
.32228 .47311 Mdot
.43438 .30975 Mdot
.41729 .35431 Mdot
.46737 .63834 Mdot
.40822 .6576 Mdot
.73003 .70941 Mdot
.63116 .54683 Mdot
.63631 .3762 Mdot
.49141 .62017 Mdot
.76688 .48606 Mdot
.47488 .66074 Mdot
.59856 .39569 Mdot
.75017 .27805 Mdot
.43247 .57165 Mdot
.47157 .59291 Mdot
.52648 .205 Mdot
.64474 .58279 Mdot
.6856 .5343 Mdot
.8081 .59962 Mdot
.46402 .57833 Mdot
.75798 .68971 Mdot
.67129 .56726 Mdot
.685 .54752 Mdot
.57656 .24828 Mdot
.43932 .60597 Mdot
.5348 .54317 Mdot
.63941 .39367 Mdot
.6371 .36411 Mdot
.62867 .56644 Mdot
.51424 .56616 Mdot
.6423 .39695 Mdot
.49238 .1844 Mdot
.45186 .34449 Mdot
.75918 .33831 Mdot
.66911 .5356 Mdot
.65709 .4371 Mdot
.62143 .36186 Mdot
.69228 .77448 Mdot
.54814 .34109 Mdot
.49262 .63124 Mdot
.46007 .57801 Mdot
.30104 .43587 Mdot
.51132 .61321 Mdot
.49161 .35927 Mdot
.61582 .36876 Mdot
.49398 .79635 Mdot
.66536 .55884 Mdot
.47347 .61222 Mdot
.30227 .30413 Mdot
.18322 .50563 Mdot
.38285 .28972 Mdot
.64533 .53117 Mdot
.6511 .56229 Mdot
.42996 .33506 Mdot
.4458 .32179 Mdot
.44296 .59329 Mdot
.61419 .41659 Mdot
.69075 .56438 Mdot
.60088 .40211 Mdot
.47 .34268 Mdot
.44807 .37796 Mdot
.42812 .39623 Mdot
.4085 .64446 Mdot
.45561 .37454 Mdot
.22471 .43997 Mdot
.56803 .34695 Mdot
.68825 .58991 Mdot
.83356 .60353 Mdot
.73039 .46021 Mdot
.57568 .59334 Mdot
.32292 .42158 Mdot
.44363 .39423 Mdot
.61936 .35129 Mdot
.43923 .63744 Mdot
.44548 .65121 Mdot
.64552 .28277 Mdot
.60901 .35565 Mdot
.32547 .46847 Mdot
.63702 .34748 Mdot
.32257 .46982 Mdot
.29593 .33442 Mdot
.50065 .64594 Mdot
.4273 .67254 Mdot
.61512 .36522 Mdot
.45359 .37292 Mdot
.43324 .35306 Mdot
.34878 .46399 Mdot
.45195 .47042 Mdot
.48094 .37214 Mdot
.68348 .54362 Mdot
.43909 .76742 Mdot
.46759 .32697 Mdot
.48298 .61028 Mdot
.27931 .5636 Mdot
.60802 .18893 Mdot
.39146 .64799 Mdot
.58457 .24384 Mdot
.5304 .76323 Mdot
.41813 .65654 Mdot
.61556 .19253 Mdot
.60432 .35063 Mdot
.64065 .57431 Mdot
.43476 .39044 Mdot
.49737 .37969 Mdot
.53971 .56452 Mdot
.29043 .42412 Mdot
.44041 .56472 Mdot
.61553 .54285 Mdot
.61394 .53575 Mdot
.3609 .57221 Mdot
.26313 .31363 Mdot
.33067 .4598 Mdot
.33567 .4454 Mdot
.44351 .37286 Mdot
.16098 .58098 Mdot
.41317 .70424 Mdot
.32021 .46736 Mdot
.67102 .50798 Mdot
.47265 .6447 Mdot
.29994 .50529 Mdot
.60324 .51601 Mdot
.62856 .56851 Mdot
.35741 .53883 Mdot
.45493 .38603 Mdot
.63793 .56155 Mdot
.7686 .44565 Mdot
.49729 .56803 Mdot
.66783 .55816 Mdot
.60208 .40035 Mdot
.50512 .27327 Mdot
.67865 .5376 Mdot
.28371 .55725 Mdot
.61478 .42185 Mdot
.56567 .40295 Mdot
.39624 .5325 Mdot
.10783 .46203 Mdot
.61009 .36829 Mdot
.47832 .33955 Mdot
.44322 .34638 Mdot
.44018 .37778 Mdot
.63685 .55195 Mdot
.46419 .3954 Mdot
.6335 .54583 Mdot
.29649 .25564 Mdot
.63724 .21943 Mdot
.31612 .46448 Mdot
.5672 .27176 Mdot
.63856 .53768 Mdot
.77619 .55302 Mdot
.49185 .11757 Mdot
.4898 .64669 Mdot
.58567 .40634 Mdot
.31721 .46351 Mdot
.18179 .6173 Mdot
.32675 .45599 Mdot
.5341 .82521 Mdot
.55349 .6678 Mdot
.46819 .6067 Mdot
.64872 .73458 Mdot
.35095 .45417 Mdot
.61011 .57438 Mdot
.4276 .61136 Mdot
.49191 .48971 Mdot
.33126 .44962 Mdot
.30523 .42434 Mdot
.44864 .5942 Mdot
.68152 .56838 Mdot
.46463 .37878 Mdot
.63191 .35858 Mdot
.34314 .44022 Mdot
.38489 .59856 Mdot
.49023 .57836 Mdot
.49526 .63225 Mdot
.75718 .54559 Mdot
.33034 .41164 Mdot
.6132 .37137 Mdot
.40188 .18094 Mdot
.46474 .31638 Mdot
.42717 .49094 Mdot
.71756 .73247 Mdot
.66654 .46781 Mdot
.46165 .34517 Mdot
.42757 .3546 Mdot
.419 .61947 Mdot
.44804 .72842 Mdot
.55359 .64978 Mdot
.40403 .46963 Mdot
.45563 .40264 Mdot
.43821 .37244 Mdot
.69635 .54194 Mdot
.38481 .73733 Mdot
.39007 .6543 Mdot
.65235 .3742 Mdot
.41714 .37042 Mdot
.62788 .22515 Mdot
.30575 .43393 Mdot
.57364 .6612 Mdot
.50446 .64184 Mdot
.49316 .62811 Mdot
.61398 .389 Mdot
.60341 .39496 Mdot
.47103 .28693 Mdot
.44288 .78952 Mdot
.5192 .76545 Mdot
.70771 .43634 Mdot
.54892 .69709 Mdot
.6714 .52509 Mdot
.66617 .5747 Mdot
.55807 .2963 Mdot
.61349 .35819 Mdot
.41663 .65658 Mdot
.64414 .56327 Mdot
.31369 .50492 Mdot
.37276 .68343 Mdot
.35786 .6585 Mdot
.76212 .66787 Mdot
.45248 .62551 Mdot
.61721 .55577 Mdot
.64754 .58467 Mdot
.65171 .58891 Mdot
.67895 .38732 Mdot
.4524 .58738 Mdot
.45244 .62205 Mdot
.41257 .63971 Mdot
.68684 .27939 Mdot
.44353 .58623 Mdot
.68903 .3807 Mdot
.52172 .45691 Mdot
.67787 .63805 Mdot
.5292 .6153 Mdot
.6286 .34668 Mdot
.42045 .59356 Mdot
.34148 .45734 Mdot
.50052 .63286 Mdot
.35958 .66807 Mdot
.63259 .37042 Mdot
.45283 .53733 Mdot
.71972 .46802 Mdot
.45236 .6679 Mdot
.32247 .41816 Mdot
.68576 .48234 Mdot
.39939 .80448 Mdot
.276 .46171 Mdot
.68145 .54266 Mdot
.45674 .34537 Mdot
.61399 .3527 Mdot
.44793 .36904 Mdot
.45208 .67577 Mdot
.54561 .29595 Mdot
.18954 .6194 Mdot
.48579 .48256 Mdot
.45599 .65593 Mdot
.41364 .69859 Mdot
.68861 .55064 Mdot
.47535 .32634 Mdot
.63218 .51583 Mdot
.41786 .61031 Mdot
.30939 .45265 Mdot
.33015 .43787 Mdot
.55797 .49446 Mdot
.29587 .71764 Mdot
.56174 .19943 Mdot
.61238 .3845 Mdot
.43824 .38807 Mdot
.32426 .47516 Mdot
.40569 .24573 Mdot
.63801 .33422 Mdot
.61847 .41073 Mdot
.63405 .37464 Mdot
.48844 .59481 Mdot
.42038 .38622 Mdot
.68224 .63805 Mdot
.46375 .31247 Mdot
.44035 .61527 Mdot
.4585 .32979 Mdot
.4825 .35861 Mdot
.3033 .45002 Mdot
.63566 .37286 Mdot
.46746 .34203 Mdot
.49536 .59177 Mdot
.66817 .56947 Mdot
.67232 .37427 Mdot
.22968 .51342 Mdot
.26432 .3168 Mdot
.56142 .53453 Mdot
.63753 .58166 Mdot
.38313 .79021 Mdot
.63824 .3975 Mdot
.70812 .30656 Mdot
.21073 .50754 Mdot
.41373 .58879 Mdot
.62323 .17494 Mdot
.47997 .31032 Mdot
.48036 .36198 Mdot
.42542 .64489 Mdot
.4679 .29899 Mdot
.47245 .60783 Mdot
.47546 .35023 Mdot
.56973 .33277 Mdot
.65342 .59809 Mdot
.4572 .36841 Mdot
.5197 .6415 Mdot
.42507 .62173 Mdot
.62563 .56194 Mdot
.42494 .33098 Mdot
.43128 .56975 Mdot
.34954 .80932 Mdot
.60024 .39025 Mdot
.6737 .46195 Mdot
.26636 .56407 Mdot
.60035 .37257 Mdot
.66069 .55388 Mdot
.4107 .62349 Mdot
.33275 .44172 Mdot
.6342 .53842 Mdot
.36719 .69049 Mdot
.30593 .46944 Mdot
.74327 .30014 Mdot
.64606 .58478 Mdot
.47513 .36792 Mdot
.33607 .46794 Mdot
.50447 .58071 Mdot
.47502 .31965 Mdot
.47713 .2558 Mdot
.46274 .34918 Mdot
.41532 .62595 Mdot
.6045 .29118 Mdot
.63731 .37548 Mdot
.45941 .62021 Mdot
.4766 .37222 Mdot
.58603 .24578 Mdot
.48084 .58387 Mdot
.41823 .63602 Mdot
.70018 .74726 Mdot
.73324 .60294 Mdot
.32476 .45156 Mdot
.6905 .57301 Mdot
.48625 .64835 Mdot
.32172 .4248 Mdot
.3144 .38744 Mdot
.49429 .6089 Mdot
.64406 .52935 Mdot
.4784 .55839 Mdot
.43442 .32549 Mdot
.59402 .38706 Mdot
.40377 .47903 Mdot
.3117 .42428 Mdot
.1588 .40784 Mdot
.41866 .36328 Mdot
.4072 .62912 Mdot
.47444 .65959 Mdot
.26999 .61875 Mdot
.63773 .57032 Mdot
.63641 .50084 Mdot
.47567 .58775 Mdot
.69214 .27986 Mdot
.47588 .62326 Mdot
.46559 .30102 Mdot
.68027 .54476 Mdot
.4654 .58613 Mdot
.65851 .39579 Mdot
.40846 .67655 Mdot
.29348 .44923 Mdot
.49847 .21858 Mdot
.47984 .56362 Mdot
.74468 .28507 Mdot
.54099 .50696 Mdot
.45846 .36935 Mdot
.23175 .40815 Mdot
.34227 .80865 Mdot
.70747 .47092 Mdot
.64005 .55165 Mdot
.2087 .62201 Mdot
.44806 .38113 Mdot
.26513 .34866 Mdot
.40646 .81986 Mdot
.42573 .62957 Mdot
.4188 .60525 Mdot
.30574 .60945 Mdot
.47501 .32201 Mdot
.44612 .31619 Mdot
.46593 .67999 Mdot
.40313 .67252 Mdot
.45264 .37907 Mdot
.45101 .57073 Mdot
.53385 .60969 Mdot
.58527 .4043 Mdot
.65416 .52963 Mdot
.60328 .41053 Mdot
.63056 .40835 Mdot
.46348 .20788 Mdot
.51373 .50176 Mdot
.59754 .39263 Mdot
.65159 .35606 Mdot
.33807 .51473 Mdot
.4847 .79958 Mdot
.34144 .44094 Mdot
.32252 .75426 Mdot
.43922 .3665 Mdot
.46072 .58847 Mdot
.65888 .58779 Mdot
.50236 .76332 Mdot
.31349 .3952 Mdot
.80654 .46262 Mdot
.41108 .64084 Mdot
.46077 .38511 Mdot
.66135 .45589 Mdot
.45304 .54804 Mdot
.42842 .406 Mdot
.48997 .61522 Mdot
.49229 .35441 Mdot
.53837 .80451 Mdot
.38843 .25032 Mdot
.49327 .38408 Mdot
.69955 .5762 Mdot
.49019 .62647 Mdot
.60492 .5562 Mdot
.60028 .36926 Mdot
.34347 .45006 Mdot
.32648 .44637 Mdot
.4354 .60257 Mdot
.43742 .71138 Mdot
.27847 .35745 Mdot
.43333 .61078 Mdot
.46922 .64482 Mdot
.57574 .38562 Mdot
.47522 .64809 Mdot
.46688 .66263 Mdot
.43252 .65754 Mdot
.43665 .66641 Mdot
.63724 .36526 Mdot
.49629 .29288 Mdot
.54542 .57841 Mdot
.50361 .67269 Mdot
.63161 .41476 Mdot
.2148 .60405 Mdot
.63999 .39848 Mdot
.41917 .82569 Mdot
.6501 .36389 Mdot
.31939 .44665 Mdot
.23037 .61558 Mdot
.48309 .68691 Mdot
.64534 .52551 Mdot
.60906 .45246 Mdot
.33602 .4642 Mdot
.61998 .36968 Mdot
.47732 .34727 Mdot
.7128 .74238 Mdot
.58994 .5761 Mdot
.71529 .59913 Mdot
.6707 .48178 Mdot
.50122 .28856 Mdot
.42738 .33586 Mdot
.61923 .58051 Mdot
.577 .78813 Mdot
.46377 .66038 Mdot
.32336 .42516 Mdot
.4413 .59526 Mdot
.59879 .36814 Mdot
.44909 .38633 Mdot
.27977 .28001 Mdot
.32881 .43468 Mdot
.82194 .62727 Mdot
.43574 .34778 Mdot
.45337 .65915 Mdot
.64236 .3967 Mdot
.84931 .54081 Mdot
.60466 .40896 Mdot
.50653 .69631 Mdot
.65434 .57735 Mdot
.22598 .32125 Mdot
.64357 .54143 Mdot
.44959 .25473 Mdot
.86455 .41783 Mdot
.36931 .27019 Mdot
.67252 .57094 Mdot
.3884 .44302 Mdot
.46474 .63275 Mdot
.49599 .63093 Mdot
.34161 .25171 Mdot
.68262 .58058 Mdot
.46902 .65571 Mdot
.64577 .29498 Mdot
.62699 .31863 Mdot
.76442 .64106 Mdot
.43101 .33631 Mdot
.47626 .60712 Mdot
.58016 .39844 Mdot
.59557 .36317 Mdot
.42442 .37263 Mdot
.62447 .4086 Mdot
.45017 .61994 Mdot
.63932 .53806 Mdot
.39704 .38966 Mdot
.31674 .43746 Mdot
.16982 .57149 Mdot
.2931 .46853 Mdot
.461 .34398 Mdot
.40817 .58662 Mdot
.44826 .37692 Mdot
.50036 .90178 Mdot
.46378 .62742 Mdot
.67294 .56675 Mdot
.46874 .64934 Mdot
.48693 .62991 Mdot
.42469 .66298 Mdot
.46501 .37616 Mdot
.22433 .4775 Mdot
.48644 .58463 Mdot
.61853 .39986 Mdot
.59253 .68097 Mdot
.51495 .59594 Mdot
.37908 .39443 Mdot
.35565 .6342 Mdot
.73586 .52103 Mdot
.66825 .58151 Mdot
.46064 .3626 Mdot
.66307 .56147 Mdot
.71328 .29126 Mdot
.6608 .55365 Mdot
.56431 .71605 Mdot
.58914 .78722 Mdot
.66999 .7419 Mdot
.68793 .72796 Mdot
.44434 .44517 Mdot
.68741 .57724 Mdot
.27562 .4335 Mdot
.69102 .56282 Mdot
.63362 .57195 Mdot
.55986 .1059 Mdot
.61241 .54342 Mdot
.48286 .60305 Mdot
.51524 .62106 Mdot
.40434 .25993 Mdot
.27678 .52413 Mdot
.45258 .64133 Mdot
.45523 .64785 Mdot
.32841 .47463 Mdot
.71157 .29505 Mdot
.55575 .30786 Mdot
.73604 .59984 Mdot
.19155 .50134 Mdot
.44431 .59488 Mdot
.49754 .6389 Mdot
.53406 .6263 Mdot
.839 .46515 Mdot
.43187 .20763 Mdot
.70571 .5717 Mdot
.49597 .67576 Mdot
.318 .2904 Mdot
.41057 .64343 Mdot
.47844 .58547 Mdot
.45714 .62798 Mdot
.44828 .38187 Mdot
.67947 .57881 Mdot
.4589 .67438 Mdot
.25968 .62098 Mdot
.4853 .59717 Mdot
.66905 .4388 Mdot
.15943 .44779 Mdot
.47713 .60151 Mdot
.68255 .52682 Mdot
.49442 .63436 Mdot
.6323 .56274 Mdot
.6159 .56576 Mdot
.47372 .6811 Mdot
.54406 .69711 Mdot
.69807 .54291 Mdot
.43954 .61527 Mdot
.47862 .34443 Mdot
.34048 .75807 Mdot
.41903 .61616 Mdot
.34026 .43889 Mdot
.46385 .57903 Mdot
.30209 .41996 Mdot
.46174 .64116 Mdot
.41939 .36903 Mdot
.50333 .75175 Mdot
.44561 .36283 Mdot
.35704 .22777 Mdot
.42446 .3926 Mdot
.80363 .65576 Mdot
.63402 .58014 Mdot
.58782 .28163 Mdot
.77497 .37349 Mdot
.66778 .29814 Mdot
.56093 .42794 Mdot
.48412 .43617 Mdot
.61398 .41603 Mdot
.64387 .57203 Mdot
.74273 .36509 Mdot
.36679 .37353 Mdot
.37252 .32611 Mdot
.47658 .38161 Mdot
.36945 .17851 Mdot
.73415 .29528 Mdot
.4012 .63263 Mdot
.60682 .75521 Mdot
.6348 .70658 Mdot
.41163 .65048 Mdot
.42296 .66486 Mdot
.50058 .33947 Mdot
.46873 .57339 Mdot
.7668 .49319 Mdot
.45378 .33644 Mdot
.33849 .46027 Mdot
.68776 .55893 Mdot
.29467 .43584 Mdot
.35823 .40665 Mdot
.48974 .43147 Mdot
.47405 .34536 Mdot
.43738 .56886 Mdot
.44614 .64138 Mdot
.6285 .5572 Mdot
.5721 .61942 Mdot
.68164 .53457 Mdot
.32198 .46342 Mdot
.4453 .33533 Mdot
.57128 .17774 Mdot
.447 .6442 Mdot
.6609 .53642 Mdot
.56739 .44511 Mdot
.48163 .65028 Mdot
.60901 .36529 Mdot
.47035 .63476 Mdot
.68555 .56506 Mdot
.4748 .64804 Mdot
.64303 .54247 Mdot
.45515 .34591 Mdot
.44272 .66021 Mdot
.42511 .64852 Mdot
.8249 .60528 Mdot
.31139 .45899 Mdot
.61964 .58232 Mdot
.39396 .49894 Mdot
.49236 .64862 Mdot
.55594 .25648 Mdot
.48784 .61236 Mdot
.71683 .57935 Mdot
.40078 .62165 Mdot
.67318 .46364 Mdot
.47226 .68411 Mdot
.43394 .59701 Mdot
.59431 .49616 Mdot
.62261 .70893 Mdot
.55283 .55347 Mdot
.64406 .34595 Mdot
.61478 .58038 Mdot
.75182 .65021 Mdot
.40138 .33626 Mdot
.42422 .32892 Mdot
.3352 .55835 Mdot
.46958 .67415 Mdot
.46833 .60397 Mdot
.73706 .52932 Mdot
.31694 .42668 Mdot
.62905 .5352 Mdot
.3219 .46968 Mdot
.78734 .65622 Mdot
.30126 .46945 Mdot
.46265 .29941 Mdot
.27986 .34357 Mdot
.53461 .17712 Mdot
.32291 .4745 Mdot
.68723 .56456 Mdot
.32872 .29368 Mdot
.46495 .66554 Mdot
.55663 .50777 Mdot
.31018 .44619 Mdot
.27994 .24024 Mdot
.46463 .66228 Mdot
.56463 .43215 Mdot
.59476 .39785 Mdot
.32364 .47374 Mdot
.61208 .42381 Mdot
.43273 .63539 Mdot
.55858 .30883 Mdot
.64145 .55166 Mdot
.62136 .42563 Mdot
.51373 .58075 Mdot
.31999 .46585 Mdot
.41651 .36625 Mdot
.63442 .4256 Mdot
.65339 .36529 Mdot
.25494 .67075 Mdot
.2609 .28935 Mdot
.44215 .3365 Mdot
.76678 .60638 Mdot
.63169 .34701 Mdot
.47544 .66546 Mdot
.72639 .3227 Mdot
.49386 .62947 Mdot
.59394 .21966 Mdot
.46491 .35584 Mdot
.50132 .29177 Mdot
.48674 .64756 Mdot
.42185 .60663 Mdot
.61109 .53703 Mdot
.4442 .35404 Mdot
.66261 .54414 Mdot
.66408 .5965 Mdot
.4535 .34434 Mdot
.6511 .54968 Mdot
.34165 .46975 Mdot
.77539 .42307 Mdot
.64719 .37466 Mdot
.62949 .39407 Mdot
.4394 .37772 Mdot
.46164 .36878 Mdot
.45062 .37113 Mdot
.47117 .63528 Mdot
.66252 .53399 Mdot
.43592 .62777 Mdot
.43967 .57727 Mdot
.6096 .6676 Mdot
.67029 .58328 Mdot
.44436 .62495 Mdot
.46044 .48682 Mdot
.50397 .68747 Mdot
.4728 .33408 Mdot
.59611 .39313 Mdot
.62735 .28338 Mdot
.48943 .25209 Mdot
.47766 .61042 Mdot
.24234 .47193 Mdot
.68964 .56296 Mdot
.3326 .4509 Mdot
.30227 .47539 Mdot
.32522 .45539 Mdot
.5965 .34651 Mdot
.65139 .58859 Mdot
.68505 .61998 Mdot
.4736 .60539 Mdot
.71318 .59024 Mdot
.71053 .56745 Mdot
.32083 .30572 Mdot
.59745 .3899 Mdot
.46908 .65121 Mdot
.41259 .47884 Mdot
.49171 .78278 Mdot
.48847 .63446 Mdot
.51666 .6023 Mdot
.21575 .45766 Mdot
.39059 .60009 Mdot
.64421 .52234 Mdot
.84176 .55893 Mdot
.50919 .59078 Mdot
.62018 .21751 Mdot
.17354 .6285 Mdot
.48285 .61692 Mdot
.42753 .59606 Mdot
.44001 .64594 Mdot
.50232 .62864 Mdot
.69524 .53573 Mdot
.30569 .52212 Mdot
.63554 .34552 Mdot
.69366 .60006 Mdot
.61186 .36016 Mdot
.45508 .40034 Mdot
.50207 .29407 Mdot
.65003 .57544 Mdot
.30198 .43471 Mdot
.17702 .4928 Mdot
.8097 .554 Mdot
.42445 .36314 Mdot
.50992 .18575 Mdot
.31231 .44714 Mdot
.50662 .64574 Mdot
.34679 .44094 Mdot
.4372 .32832 Mdot
.63653 .38969 Mdot
.47205 .56085 Mdot
.67041 .57368 Mdot
.67534 .53598 Mdot
.47364 .65307 Mdot
.26922 .33389 Mdot
.59344 .38015 Mdot
.64677 .34308 Mdot
.49227 .59992 Mdot
.50826 .58567 Mdot
.66033 .54486 Mdot
.43363 .36929 Mdot
.68793 .73511 Mdot
.33528 .43984 Mdot
.40878 .64432 Mdot
.47959 .64709 Mdot
.70231 .74393 Mdot
.62044 .40179 Mdot
.41169 .36959 Mdot
.40757 .59589 Mdot
.70058 .41713 Mdot
.41784 .58536 Mdot
.52909 .63367 Mdot
.47769 .34073 Mdot
.52588 .56278 Mdot
.42434 .67337 Mdot
.63897 .59596 Mdot
.6071 .41726 Mdot
.67117 .56168 Mdot
.63453 .59503 Mdot
.78647 .45545 Mdot
.61833 .36337 Mdot
.45779 .63094 Mdot
.60025 .38175 Mdot
.49473 .61032 Mdot
.50594 .59478 Mdot
.59827 .3956 Mdot
.66095 .54349 Mdot
.20572 .60779 Mdot
.43176 .26872 Mdot
.50685 .61313 Mdot
.45542 .67935 Mdot
.279 .50791 Mdot
.37317 .43709 Mdot
.41763 .60998 Mdot
.69213 .55322 Mdot
.43411 .63978 Mdot
.58828 .40081 Mdot
.34937 .45813 Mdot
.67099 .57009 Mdot
.43104 .35506 Mdot
.42191 .35736 Mdot
.71752 .47136 Mdot
.48458 .35923 Mdot
.41859 .60292 Mdot
.57768 .5896 Mdot
.63656 .51958 Mdot
.18543 .45288 Mdot
.44959 .34306 Mdot
.33671 .43116 Mdot
.41811 .62993 Mdot
.3414 .61213 Mdot
.58196 .40611 Mdot
.55501 .12631 Mdot
.79201 .52728 Mdot
.34532 .42929 Mdot
.69809 .61271 Mdot
.4229 .38432 Mdot
.45015 .67612 Mdot
.33901 .4375 Mdot
.42932 .33553 Mdot
.50182 .60704 Mdot
.50354 .67107 Mdot
.55511 .62399 Mdot
.49239 .41508 Mdot
.6014 .38397 Mdot
.48727 .36721 Mdot
.33278 .41926 Mdot
.46373 .40134 Mdot
.62178 .57206 Mdot
.44841 .58681 Mdot
.41084 .58584 Mdot
.43208 .36874 Mdot
.41923 .33226 Mdot
.44156 .62002 Mdot
.68145 .57197 Mdot
.40648 .28998 Mdot
.44904 .5962 Mdot
.64066 .31944 Mdot
.70053 .5682 Mdot
.43676 .33474 Mdot
.42972 .59792 Mdot
.28146 .46058 Mdot
.43487 .35388 Mdot
.47052 .3325 Mdot
.49668 .64045 Mdot
.32264 .47611 Mdot
.41619 .67474 Mdot
.64447 .38542 Mdot
.35945 .18939 Mdot
.58777 .40012 Mdot
.39281 .35204 Mdot
.38318 .62357 Mdot
.70966 .36751 Mdot
.65591 .58211 Mdot
.36974 .55154 Mdot
.6443 .29434 Mdot
.53454 .60405 Mdot
.32743 .72199 Mdot
.65561 .43758 Mdot
.20286 .42838 Mdot
.3472 .70937 Mdot
.30607 .44634 Mdot
.62231 .37066 Mdot
.42729 .59603 Mdot
.5871 .41056 Mdot
.33496 .43168 Mdot
.36289 .22648 Mdot
.41749 .61765 Mdot
.68489 .54809 Mdot
.44805 .62166 Mdot
.67445 .53855 Mdot
.50682 .62186 Mdot
.40559 .66362 Mdot
.66023 .29594 Mdot
.41003 .51469 Mdot
.4154 .58819 Mdot
.88095 .54476 Mdot
.53288 .6633 Mdot
.3383 .4497 Mdot
.42877 .62623 Mdot
.46899 .40954 Mdot
.60534 .35879 Mdot
.6881 .36311 Mdot
.44998 .38294 Mdot
.65144 .37467 Mdot
.65541 .54756 Mdot
.46179 .35476 Mdot
.42494 .36843 Mdot
.51965 .55913 Mdot
.3509 .44006 Mdot
.62825 .38589 Mdot
.46295 .58437 Mdot
.42018 .61238 Mdot
.77637 .59975 Mdot
.35515 .37253 Mdot
.59623 .62761 Mdot
.82307 .39522 Mdot
.64873 .59282 Mdot
.33248 .46504 Mdot
.46286 .37995 Mdot
.42626 .58572 Mdot
.45514 .61707 Mdot
.56943 .26503 Mdot
.6945 .54248 Mdot
.50196 .46241 Mdot
.59121 .63296 Mdot
.31336 .50421 Mdot
.36252 .52131 Mdot
.6893 .55799 Mdot
.35543 .52083 Mdot
.33717 .41404 Mdot
.26622 .72305 Mdot
.41266 .5097 Mdot
.59419 .39442 Mdot
.34075 .51901 Mdot
.6293 .53582 Mdot
.49232 .59096 Mdot
.48056 .34773 Mdot
.48314 .35671 Mdot
.67216 .55461 Mdot
.43896 .40758 Mdot
.30259 .4448 Mdot
.43867 .58398 Mdot
.77953 .56112 Mdot
.74423 .44445 Mdot
.44004 .3854 Mdot
.50223 .55474 Mdot
.63416 .37287 Mdot
.47521 .65318 Mdot
.30624 .46379 Mdot
.60566 .37203 Mdot
.49048 .80832 Mdot
.61293 .3151 Mdot
.42225 .6188 Mdot
.70742 .74265 Mdot
.6184 .36542 Mdot
.43425 .7372 Mdot
.45624 .59168 Mdot
.63495 .39866 Mdot
.3851 .58112 Mdot
.49765 .27025 Mdot
.51324 .48862 Mdot
.40853 .82241 Mdot
.542 .47846 Mdot
.46344 .38631 Mdot
.49922 .28049 Mdot
.65213 .27486 Mdot
.63078 .35112 Mdot
.40842 .35452 Mdot
.51186 .50393 Mdot
.61148 .42258 Mdot
.49796 .65442 Mdot
.48732 .61704 Mdot
.42312 .21095 Mdot
.6197 .45247 Mdot
.43591 .25312 Mdot
.72839 .49414 Mdot
.49283 .64927 Mdot
.40335 .64881 Mdot
.45636 .6132 Mdot
.66717 .52277 Mdot
.6061 .39051 Mdot
.8607 .55532 Mdot
.60033 .36984 Mdot
.58665 .66411 Mdot
.43958 .37143 Mdot
.43219 .33509 Mdot
.47811 .60599 Mdot
.57014 .43622 Mdot
.40917 .76078 Mdot
.44646 .61734 Mdot
.36317 .45004 Mdot
.4278 .22204 Mdot
.51236 .60438 Mdot
.66446 .57918 Mdot
.53518 .58198 Mdot
.37618 .62907 Mdot
.64747 .37239 Mdot
.30697 .4346 Mdot
.35942 .59172 Mdot
.63683 .38649 Mdot
.46707 .60488 Mdot
.70962 .39429 Mdot
.4798 .63107 Mdot
.50564 .61335 Mdot
.57087 .64741 Mdot
.30702 .47771 Mdot
.45314 .35866 Mdot
.32234 .45607 Mdot
.6374 .57249 Mdot
.48104 .08881 Mdot
.29921 .46718 Mdot
.45011 .78885 Mdot
.38744 .20673 Mdot
.34429 .51685 Mdot
.62637 .53565 Mdot
.34195 .42978 Mdot
.59224 .38841 Mdot
.33956 .75971 Mdot
.50653 .69068 Mdot
.64473 .43913 Mdot
.45411 .59761 Mdot
.6021 .5823 Mdot
.66899 .52981 Mdot
.62515 .42308 Mdot
.61554 .56994 Mdot
.53507 .54626 Mdot
.5032 .60286 Mdot
.62996 .35663 Mdot
.71524 .43528 Mdot
.63574 .34366 Mdot
.40404 .44808 Mdot
.42962 .6199 Mdot
.67635 .56796 Mdot
.41971 .66806 Mdot
.67881 .51836 Mdot
.41369 .37639 Mdot
.42783 .57225 Mdot
.30145 .44479 Mdot
.70403 .36753 Mdot
.4382 .33786 Mdot
.35081 .51022 Mdot
.62939 .55921 Mdot
.58975 .34785 Mdot
.62417 .56043 Mdot
.64219 .5157 Mdot
.64123 .39758 Mdot
.61083 .55363 Mdot
.43068 .59238 Mdot
.51023 .49345 Mdot
.63359 .55355 Mdot
.6189 .38455 Mdot
.31511 .43255 Mdot
.64863 .54279 Mdot
.47325 .30202 Mdot
.41713 .62763 Mdot
.46366 .37502 Mdot
.36326 .41526 Mdot
.59736 .57321 Mdot
.33226 .47959 Mdot
.43049 .32461 Mdot
.30518 .42419 Mdot
.21303 .39584 Mdot
.65459 .38458 Mdot
.55289 .67279 Mdot
.36502 .43476 Mdot
.64788 .52454 Mdot
.2104 .51732 Mdot
.44859 .57544 Mdot
.417 .63135 Mdot
.30499 .41967 Mdot
.66918 .52982 Mdot
.21818 .69278 Mdot
.4414 .71806 Mdot
.4154 .43934 Mdot
.59671 .35766 Mdot
.81885 .64002 Mdot
.40618 .44223 Mdot
.16178 .5924 Mdot
.5071 .56156 Mdot
.445 .31508 Mdot
.47178 .61442 Mdot
.61405 .26611 Mdot
.31567 .4618 Mdot
.38149 .39054 Mdot
.39298 .62739 Mdot
.45673 .35397 Mdot
.43069 .65213 Mdot
.58494 .49895 Mdot
.39962 .7129 Mdot
.32497 .42185 Mdot
.28972 .32217 Mdot
.59872 .57008 Mdot
.31593 .43966 Mdot
.44439 .32962 Mdot
.40847 .52822 Mdot
.50278 .60646 Mdot
.49562 .65768 Mdot
.31054 .50305 Mdot
.65653 .53132 Mdot
.47537 .37004 Mdot
.64195 .38821 Mdot
.31019 .43029 Mdot
.44553 .63986 Mdot
.43802 .57691 Mdot
.56272 .25249 Mdot
.63368 .36698 Mdot
.47473 .32392 Mdot
.59821 .40926 Mdot
.42602 .38369 Mdot
.48918 .58459 Mdot
.425 .34875 Mdot
.48542 .67341 Mdot
.6747 .41496 Mdot
.56503 .65996 Mdot
.61738 .72222 Mdot
.4651 .35011 Mdot
.50434 .80637 Mdot
.63095 .36587 Mdot
.60951 .4099 Mdot
.44433 .18972 Mdot
.52233 .68017 Mdot
.78995 .57529 Mdot
.29346 .67596 Mdot
.63728 .36169 Mdot
.62924 .38024 Mdot
.4637 .37371 Mdot
.61035 .5561 Mdot
.63824 .58921 Mdot
.42576 .37941 Mdot
.27389 .56416 Mdot
.63068 .53461 Mdot
.30944 .72811 Mdot
.77279 .62592 Mdot
.51528 .64631 Mdot
.43672 .29495 Mdot
.33166 .44397 Mdot
.28696 .56179 Mdot
.57679 .50241 Mdot
.41594 .61766 Mdot
.34813 .57156 Mdot
.43638 .37354 Mdot
.57134 .42566 Mdot
.40547 .81298 Mdot
.43657 .65627 Mdot
.45863 .58867 Mdot
.4633 .61156 Mdot
.3537 .44666 Mdot
.49836 .72671 Mdot
.43817 .58875 Mdot
.27137 .56384 Mdot
.48443 .65285 Mdot
.40728 .72342 Mdot
.32599 .4496 Mdot
.49263 .50705 Mdot
.36553 .39428 Mdot
.83267 .5743 Mdot
.39847 .70329 Mdot
.6476 .37797 Mdot
.38278 .33673 Mdot
.6088 .41302 Mdot
.58082 .71428 Mdot
.39479 .50915 Mdot
.65717 .59336 Mdot
.41735 .61357 Mdot
.46033 .3425 Mdot
.66938 .53028 Mdot
.52255 .27623 Mdot
.52531 .09629 Mdot
.64818 .3598 Mdot
.29103 .7951 Mdot
.62813 .40458 Mdot
.42576 .36982 Mdot
.66074 .54579 Mdot
.56665 .79474 Mdot
.76934 .5301 Mdot
.64808 .54453 Mdot
.19725 .64083 Mdot
.7148 .54525 Mdot
.37829 .56228 Mdot
.6123 .53922 Mdot
.62297 .38045 Mdot
.5722 .41116 Mdot
.5243 .53405 Mdot
.47609 .58553 Mdot
.49234 .4358 Mdot
.40442 .75471 Mdot
.44659 .57589 Mdot
.45152 .33587 Mdot
.54927 .65864 Mdot
.34574 .55718 Mdot
.61579 .54574 Mdot
.6363 .32192 Mdot
.44936 .58924 Mdot
.48678 .64216 Mdot
.49922 .60056 Mdot
.80335 .50438 Mdot
.26212 .72042 Mdot
.48875 .58638 Mdot
.50318 .63342 Mdot
.45968 .35379 Mdot
.36303 .47282 Mdot
.37036 .27441 Mdot
.72445 .62294 Mdot
.43485 .66147 Mdot
.32087 .44096 Mdot
.31531 .41338 Mdot
.45145 .57143 Mdot
.50269 .49627 Mdot
.71277 .38417 Mdot
.46044 .58374 Mdot
.54775 .65703 Mdot
.51839 .35662 Mdot
.47174 .31877 Mdot
.43235 .35847 Mdot
.60988 .5766 Mdot
.43018 .37554 Mdot
.41837 .37187 Mdot
.5037 .79413 Mdot
.5256 .46986 Mdot
.67581 .39473 Mdot
.32481 .46323 Mdot
.46073 .62144 Mdot
.55727 .57387 Mdot
.70285 .4047 Mdot
.61801 .41761 Mdot
.65995 .57078 Mdot
.59515 .36596 Mdot
.28352 .42069 Mdot
.78815 .5009 Mdot
.46127 .39441 Mdot
.64298 .36947 Mdot
.6603 .36859 Mdot
.32296 .44084 Mdot
.59831 .42098 Mdot
.55104 .36017 Mdot
.48973 .57404 Mdot
.58423 .76665 Mdot
.44141 .61341 Mdot
.17077 .51035 Mdot
.63463 .37915 Mdot
.57701 .37885 Mdot
.47026 .5961 Mdot
.43629 .35078 Mdot
.39828 .55824 Mdot
.47986 .58859 Mdot
.43136 .37538 Mdot
.3996 .62958 Mdot
.28998 .46018 Mdot
.69645 .56729 Mdot
.7667 .53331 Mdot
.37242 .17439 Mdot
.3495 .43795 Mdot
.52877 .27205 Mdot
.41135 .63138 Mdot
.24644 .32023 Mdot
.64722 .54049 Mdot
.4072 .60724 Mdot
.35843 .53688 Mdot
.62986 .54789 Mdot
.65874 .56111 Mdot
.47038 .63953 Mdot
.59412 .40081 Mdot
.43671 .33684 Mdot
.32669 .44292 Mdot
.15529 .53518 Mdot
.44238 .60203 Mdot
.42722 .64477 Mdot
.31464 .44319 Mdot
.61968 .36048 Mdot
.42277 .58185 Mdot
.28771 .62616 Mdot
.24667 .72409 Mdot
.63113 .40419 Mdot
.45728 .66243 Mdot
.56925 .73566 Mdot
.41403 .71199 Mdot
.19668 .35859 Mdot
.54528 .50727 Mdot
.456 .36328 Mdot
.39376 .67333 Mdot
.69257 .21727 Mdot
.31049 .43236 Mdot
.80524 .55865 Mdot
.48606 .6436 Mdot
.45094 .64785 Mdot
.68929 .53939 Mdot
.43646 .62483 Mdot
.65349 .57478 Mdot
.46532 .1572 Mdot
.73279 .72058 Mdot
.62086 .57918 Mdot
.63622 .52767 Mdot
.35447 .62072 Mdot
.66211 .3365 Mdot
.66922 .55323 Mdot
.50722 .59316 Mdot
.45935 .49667 Mdot
.72481 .5287 Mdot
.33948 .43043 Mdot
.23046 .46091 Mdot
.46828 .69652 Mdot
.2544 .47032 Mdot
.21338 .60654 Mdot
.54712 .6242 Mdot
.403 .4626 Mdot
.61719 .40604 Mdot
.43693 .65735 Mdot
.48393 .35434 Mdot
.4856 .35249 Mdot
.48694 .67432 Mdot
.46981 .6283 Mdot
.63394 .56771 Mdot
.3237 .42993 Mdot
.62239 .34985 Mdot
.45181 .64591 Mdot
.37603 .54575 Mdot
.3036 .42973 Mdot
.61163 .56623 Mdot
.58219 .67943 Mdot
.29904 .47936 Mdot
.42135 .6835 Mdot
.47246 .5866 Mdot
.45243 .62552 Mdot
.52342 .53198 Mdot
.60558 .39528 Mdot
.22167 .60111 Mdot
.5118 .62578 Mdot
.7962 .64691 Mdot
.67809 .36356 Mdot
.39106 .65142 Mdot
.62088 .56718 Mdot
.63159 .32333 Mdot
.43472 .40144 Mdot
.78298 .41073 Mdot
.4253 .61462 Mdot
.28049 .32626 Mdot
.41697 .21469 Mdot
.41193 .3523 Mdot
.69631 .53 Mdot
.32746 .45795 Mdot
.44941 .61877 Mdot
.53997 .69869 Mdot
.48552 .61452 Mdot
.32729 .40798 Mdot
.46497 .32842 Mdot
.61422 .40636 Mdot
.19417 .44827 Mdot
.48664 .36192 Mdot
.66219 .5612 Mdot
.6151 .82607 Mdot
.655 .57577 Mdot
.6354 .58829 Mdot
.59504 .67794 Mdot
.60499 .39679 Mdot
.61949 .15691 Mdot
.49075 .16405 Mdot
.48614 .57886 Mdot
.62453 .36149 Mdot
.67902 .55858 Mdot
.47091 .65823 Mdot
.70702 .53156 Mdot
.66425 .58887 Mdot
.4998 .59081 Mdot
.446 .65001 Mdot
.37438 .25534 Mdot
.3681 .76467 Mdot
.32641 .45941 Mdot
.64404 .58061 Mdot
.77125 .50354 Mdot
.4733 .6593 Mdot
.47357 .60424 Mdot
.58875 .22912 Mdot
.35114 .44761 Mdot
.76119 .45024 Mdot
.48645 .6428 Mdot
.64715 .78851 Mdot
.54139 .58181 Mdot
.69983 .55073 Mdot
.61378 .41355 Mdot
.82335 .59293 Mdot
.54428 .36459 Mdot
.65233 .57359 Mdot
.29678 .44136 Mdot
.614 .53358 Mdot
.47704 .79951 Mdot
.61075 .36126 Mdot
.68579 .56489 Mdot
.40536 .47773 Mdot
.60813 .38136 Mdot
.63764 .38042 Mdot
.61941 .66502 Mdot
.41966 .39474 Mdot
.35025 .43305 Mdot
.62936 .38329 Mdot
.70277 .29992 Mdot
.61719 .37935 Mdot
.46968 .16616 Mdot
.44291 .65793 Mdot
.31635 .57974 Mdot
.39144 .34938 Mdot
.44396 .70481 Mdot
.63778 .37259 Mdot
.33456 .47286 Mdot
.50177 .60922 Mdot
.6039 .56037 Mdot
.32699 .42792 Mdot
.6169 .44145 Mdot
.45173 .38008 Mdot
.62217 .5573 Mdot
.59566 .44223 Mdot
.67719 .53871 Mdot
.74202 .36582 Mdot
.36105 .20433 Mdot
.35509 .67881 Mdot
.77237 .52532 Mdot
.50382 .60696 Mdot
.26418 .68115 Mdot
.45836 .66594 Mdot
.47575 .63347 Mdot
.44373 .33363 Mdot
.33003 .57303 Mdot
.66215 .54418 Mdot
.18264 .59447 Mdot
.64636 .372 Mdot
.83214 .58084 Mdot
.39516 .69466 Mdot
.40659 .63477 Mdot
.6351 .55591 Mdot
.69662 .55556 Mdot
.61797 .69771 Mdot
.48756 .3817 Mdot
.4095 .63824 Mdot
.49961 .56619 Mdot
.49765 .6708 Mdot
.64135 .38446 Mdot
.44357 .49212 Mdot
.45974 .38931 Mdot
.30995 .24405 Mdot
.46164 .32623 Mdot
.25387 .43549 Mdot
.60714 .55878 Mdot
.29868 .46619 Mdot
.47424 .60154 Mdot
.57035 .61122 Mdot
.6921 .53878 Mdot
.30525 .42038 Mdot
.3301 .4716 Mdot
.51949 .24664 Mdot
.59839 .39447 Mdot
.47913 .58442 Mdot
.43144 .59576 Mdot
.44016 .63041 Mdot
.46971 .6333 Mdot
.64745 .3606 Mdot
.49761 .60342 Mdot
.58714 .42233 Mdot
.78981 .4121 Mdot
.30862 .614 Mdot
.5483 .47944 Mdot
.54347 .20024 Mdot
.61869 .54203 Mdot
.70554 .31645 Mdot
.38979 .59445 Mdot
.77596 .35713 Mdot
.35284 .24054 Mdot
.50683 .57947 Mdot
.4217 .3534 Mdot
.36667 .6364 Mdot
.47701 .37924 Mdot
.16128 .61701 Mdot
.61474 .24922 Mdot
.35663 .75629 Mdot
.41935 .6143 Mdot
.50612 .49143 Mdot
.67561 .26429 Mdot
.46781 .66653 Mdot
.55527 .24125 Mdot
.59134 .21786 Mdot
.31836 .29544 Mdot
.32061 .47469 Mdot
.43205 .60319 Mdot
.55638 .56386 Mdot
.43412 .58866 Mdot
.47362 .61071 Mdot
.49864 .60213 Mdot
.60712 .35278 Mdot
.41306 .60016 Mdot
.4989 .62135 Mdot
.27733 .36639 Mdot
.37869 .51881 Mdot
.45646 .31516 Mdot
.42644 .19546 Mdot
.30105 .47011 Mdot
.63193 .55808 Mdot
.25329 .69937 Mdot
.59454 .39337 Mdot
.62562 .69913 Mdot
.46277 .62965 Mdot
.39686 .26066 Mdot
.61754 .312 Mdot
.29792 .44274 Mdot
.42943 .33144 Mdot
.3623 .7762 Mdot
.45607 .3407 Mdot
.61335 .32831 Mdot
.43795 .34666 Mdot
.38359 .64989 Mdot
.63518 .57023 Mdot
.46782 .57608 Mdot
.62641 .38882 Mdot
.42852 .35893 Mdot
.27821 .51754 Mdot
.45861 .61428 Mdot
.45327 .34504 Mdot
.47194 .57795 Mdot
.73201 .58938 Mdot
.74395 .62812 Mdot
.4181 .36235 Mdot
.65054 .39824 Mdot
.61593 .39656 Mdot
.30817 .46953 Mdot
.62615 .55339 Mdot
.65583 .57143 Mdot
.60769 .37146 Mdot
.59903 .53538 Mdot
.43662 .66319 Mdot
.46044 .6571 Mdot
.80773 .6188 Mdot
.42703 .59197 Mdot
.41477 .52776 Mdot
.41533 .48086 Mdot
.60933 .57167 Mdot
.40873 .65613 Mdot
.47293 .64359 Mdot
.42048 .6219 Mdot
.7487 .57994 Mdot
.43367 .37544 Mdot
.43914 .65709 Mdot
.33778 .46612 Mdot
.48656 .29435 Mdot
.47606 .65308 Mdot
.53418 .56196 Mdot
.65845 .572 Mdot
.82367 .41616 Mdot
.62356 .40698 Mdot
.44662 .3298 Mdot
.46592 .35108 Mdot
.2159 .58198 Mdot
.68016 .29195 Mdot
.41904 .48067 Mdot
.23977 .29461 Mdot
.66124 .29751 Mdot
.32433 .46898 Mdot
.44697 .30575 Mdot
.59366 .44556 Mdot
.47038 .35723 Mdot
.64378 .35154 Mdot
.4536 .66027 Mdot
.43782 .66225 Mdot
.67989 .22114 Mdot
.42908 .57759 Mdot
.32922 .45329 Mdot
.62702 .34628 Mdot
.63682 .53364 Mdot
.29965 .43843 Mdot
.5998 .41098 Mdot
.61109 .57614 Mdot
.50861 .5809 Mdot
.51458 .61229 Mdot
.65646 .56897 Mdot
.68926 .54171 Mdot
.47317 .58985 Mdot
.58194 .31214 Mdot
.64167 .52674 Mdot
.68992 .55833 Mdot
.45395 .39451 Mdot
.48381 .35878 Mdot
.53159 .64078 Mdot
.63016 .36844 Mdot
.50014 .6168 Mdot
.46217 .35099 Mdot
.29956 .46677 Mdot
.65948 .54115 Mdot
.50539 .61931 Mdot
.46637 .64974 Mdot
.32288 .4392 Mdot
.29977 .45988 Mdot
.3085 .46593 Mdot
.58974 .43389 Mdot
.43194 .63084 Mdot
.66059 .54907 Mdot
.60122 .39815 Mdot
.3259 .41444 Mdot
.34553 .44112 Mdot
.46562 .30776 Mdot
.42264 .59168 Mdot
.39762 .3908 Mdot
.70917 .23002 Mdot
.75534 .68866 Mdot
.41472 .36621 Mdot
.43997 .40209 Mdot
.24731 .5066 Mdot
.6454 .4743 Mdot
.60431 .36858 Mdot
.37166 .44771 Mdot
.35853 .6812 Mdot
.47959 .56566 Mdot
.51128 .61008 Mdot
.40091 .64856 Mdot
.31249 .46907 Mdot
.33035 .59488 Mdot
.64791 .5748 Mdot
.48177 .51268 Mdot
.30354 .42875 Mdot
.43696 .32191 Mdot
.43937 .30343 Mdot
.45642 .32522 Mdot
.51039 .63872 Mdot
.62465 .72892 Mdot
.69737 .31977 Mdot
.28145 .65489 Mdot
.63583 .36892 Mdot
.5566 .58142 Mdot
.25996 .30828 Mdot
.65543 .56428 Mdot
.4661 .3976 Mdot
.32946 .46865 Mdot
.6866 .54061 Mdot
.59098 .37221 Mdot
.62774 .38258 Mdot
.44107 .38612 Mdot
.44279 .38427 Mdot
.47628 .3528 Mdot
.67613 .58681 Mdot
.60852 .55698 Mdot
.425 .61689 Mdot
.65387 .53653 Mdot
.8088 .43461 Mdot
.28604 .43238 Mdot
.47492 .41079 Mdot
.62525 .36988 Mdot
.61059 .54802 Mdot
.45499 .6138 Mdot
.7082 .58743 Mdot
.68352 .44764 Mdot
.3392 .44723 Mdot
.75971 .61517 Mdot
.1494 .56293 Mdot
.46743 .57743 Mdot
.61126 .39939 Mdot
.79372 .5434 Mdot
.46087 .60994 Mdot
.46882 .3744 Mdot
.2295 .42518 Mdot
.48609 .41458 Mdot
.48306 .59266 Mdot
.48245 .57186 Mdot
.64784 .38053 Mdot
.30598 .24791 Mdot
.43243 .60865 Mdot
.7675 .43448 Mdot
.65504 .33952 Mdot
.46762 .38065 Mdot
.37657 .83756 Mdot
.29659 .48933 Mdot
.28295 .5647 Mdot
.44963 .39178 Mdot
.48814 .62877 Mdot
.47511 .38526 Mdot
.3408 .45942 Mdot
.43118 .33214 Mdot
.66065 .57729 Mdot
.44185 .32325 Mdot
.4281 .64468 Mdot
.6716 .55631 Mdot
.61865 .3648 Mdot
.82597 .57398 Mdot
.26234 .40548 Mdot
.43632 .35293 Mdot
.42029 .36563 Mdot
.40543 .64169 Mdot
.76407 .48498 Mdot
.4674 .67656 Mdot
.46071 .66139 Mdot
.62752 .35834 Mdot
.62922 .54987 Mdot
.63513 .4019 Mdot
.45143 .69014 Mdot
.31454 .63845 Mdot
.59911 .40807 Mdot
.37602 .26968 Mdot
.31136 .44925 Mdot
.54331 .4275 Mdot
.45508 .61846 Mdot
.60827 .42449 Mdot
.42957 .62979 Mdot
.64488 .57483 Mdot
.56313 .47253 Mdot
.53824 .31792 Mdot
.63189 .39062 Mdot
.23428 .38996 Mdot
.29038 .60695 Mdot
.54959 .57172 Mdot
.61111 .41102 Mdot
.34755 .54335 Mdot
.4265 .37132 Mdot
.33341 .4354 Mdot
.28772 .44739 Mdot
.30079 .42905 Mdot
.531 .61127 Mdot
.39436 .6951 Mdot
.33865 .47729 Mdot
.6076 .35837 Mdot
.32622 .42237 Mdot
.59332 .19843 Mdot
.18335 .59927 Mdot
.31396 .45711 Mdot
.4551 .59386 Mdot
.39012 .58377 Mdot
.3421 .51499 Mdot
.48963 .26445 Mdot
.34365 .74108 Mdot
.50621 .21774 Mdot
.48251 .59551 Mdot
.70218 .56854 Mdot
.65648 .58716 Mdot
.81993 .49107 Mdot
.44213 .78063 Mdot
.7259 .72055 Mdot
.61275 .58048 Mdot
.60044 .2864 Mdot
.61353 .56097 Mdot
.48226 .58246 Mdot
.46444 .65802 Mdot
.63584 .59189 Mdot
.32421 .63114 Mdot
.57164 .28328 Mdot
.17238 .48667 Mdot
.68204 .5402 Mdot
.60782 .41703 Mdot
.63176 .41243 Mdot
.63885 .37689 Mdot
.79199 .60445 Mdot
.63926 .55428 Mdot
.45132 .63824 Mdot
.46399 .34608 Mdot
.43007 .65858 Mdot
.6054 .38224 Mdot
.18298 .63009 Mdot
.64213 .54444 Mdot
.44418 .58882 Mdot
.48999 .53914 Mdot
.44659 .3829 Mdot
.31879 .44527 Mdot
.72784 .58661 Mdot
.7101 .73364 Mdot
.6451 .3711 Mdot
.59805 .57692 Mdot
.60964 .45474 Mdot
.18147 .48374 Mdot
.49188 .55291 Mdot
.4441 .56168 Mdot
.15379 .54046 Mdot
.6 .81553 Mdot
.41269 .62134 Mdot
.42314 .34047 Mdot
.57424 .26214 Mdot
.47897 .64993 Mdot
.65147 .5852 Mdot
.29395 .47308 Mdot
.31208 .42305 Mdot
.54174 .61651 Mdot
.73156 .56862 Mdot
.57026 .49636 Mdot
.46116 .63233 Mdot
.4136 .67712 Mdot
.46154 .387 Mdot
.6172 .2599 Mdot
.78714 .65687 Mdot
.2961 .45685 Mdot
.45821 .57303 Mdot
.19658 .59514 Mdot
.67744 .53132 Mdot
.41273 .35319 Mdot
.58811 .4058 Mdot
.7092 .56976 Mdot
.42707 .33303 Mdot
.50935 .60658 Mdot
.43611 .57475 Mdot
.62369 .41436 Mdot
.69931 .55479 Mdot
.30881 .46416 Mdot
.44257 .33234 Mdot
.29995 .4533 Mdot
.63253 .54775 Mdot
.63597 .53677 Mdot
.51664 .54722 Mdot
.4747 .55145 Mdot
.43176 .35367 Mdot
.5065 .65886 Mdot
.54799 .34978 Mdot
.16609 .40992 Mdot
.60919 .45255 Mdot
.41701 .59272 Mdot
.6068 .54238 Mdot
.63779 .38702 Mdot
.44809 .6479 Mdot
.16778 .60788 Mdot
.48127 .65693 Mdot
.61736 .3461 Mdot
.46817 .80489 Mdot
.30272 .45163 Mdot
.54093 .53064 Mdot
.34369 .25339 Mdot
.43055 .58648 Mdot
.46491 .3647 Mdot
.51756 .5663 Mdot
.59172 .39852 Mdot
.61205 .54989 Mdot
.15264 .42175 Mdot
.61594 .38414 Mdot
.44662 .5811 Mdot
.30607 .43211 Mdot
.63493 .52509 Mdot
.54901 .51266 Mdot
.48425 .49065 Mdot
.41731 .55559 Mdot
.41039 .6533 Mdot
.47829 .64031 Mdot
.29054 .63966 Mdot
.45756 .33281 Mdot
.6867 .5587 Mdot
.61557 .40161 Mdot
.60612 .37032 Mdot
.4378 .38081 Mdot
.40079 .40108 Mdot
.54229 .42737 Mdot
.78187 .30344 Mdot
.47305 .38998 Mdot
.29481 .46115 Mdot
.76452 .46342 Mdot
.45852 .33599 Mdot
.44964 .3459 Mdot
.45885 .39432 Mdot
.41071 .47008 Mdot
.62956 .53476 Mdot
.50955 .60826 Mdot
.668 .58134 Mdot
.49027 .62887 Mdot
.62843 .33855 Mdot
.63001 .38921 Mdot
.63554 .54274 Mdot
.1784 .44497 Mdot
.5614 .76866 Mdot
.46241 .60115 Mdot
.24833 .31891 Mdot
.39708 .60461 Mdot
.28082 .49719 Mdot
.39701 .61508 Mdot
.43841 .36018 Mdot
.50208 .65295 Mdot
.52834 .62863 Mdot
.81554 .52291 Mdot
.62715 .36792 Mdot
.45933 .31072 Mdot
.39759 .65958 Mdot
.41976 .68124 Mdot
.68119 .58568 Mdot
.69017 .54402 Mdot
.28886 .44157 Mdot
.44288 .52305 Mdot
.61574 .36394 Mdot
.56187 .16999 Mdot
.47521 .5853 Mdot
.26367 .46705 Mdot
.70703 .70242 Mdot
.44513 .64686 Mdot
.31275 .27308 Mdot
.62631 .72151 Mdot
.45117 .61874 Mdot
.45723 .44658 Mdot
.63225 .36681 Mdot
.34406 .69206 Mdot
.48745 .64984 Mdot
.45389 .38466 Mdot
.60879 .56225 Mdot
.68598 .53409 Mdot
.28975 .45518 Mdot
.73656 .29785 Mdot
.63831 .39919 Mdot
.62064 .54427 Mdot
.46479 .61835 Mdot
.60986 .40085 Mdot
.45776 .39718 Mdot
.40718 .61988 Mdot
.53622 .81766 Mdot
.65786 .53612 Mdot
.3989 .63056 Mdot
.75152 .40491 Mdot
.25418 .53614 Mdot
.47578 .81752 Mdot
.62121 .40229 Mdot
.31022 .47055 Mdot
.53912 .60034 Mdot
.61129 .51743 Mdot
.43456 .67724 Mdot
.29895 .57974 Mdot
.57909 .1965 Mdot
.34676 .46328 Mdot
.46696 .59373 Mdot
.4481 .64023 Mdot
.61529 .4805 Mdot
.29509 .44936 Mdot
.42189 .60885 Mdot
.65861 .486 Mdot
.67485 .54042 Mdot
.43721 .3948 Mdot
.64734 .53181 Mdot
.45504 .59734 Mdot
.46632 .54998 Mdot
.69113 .54154 Mdot
.19283 .38817 Mdot
.29506 .47854 Mdot
.61068 .40858 Mdot
.46151 .56948 Mdot
.504 .64278 Mdot
.87807 .50497 Mdot
.41054 .35006 Mdot
.56359 .31691 Mdot
.37761 .28103 Mdot
.2069 .57884 Mdot
.3362 .49725 Mdot
.43696 .8199 Mdot
.59179 .81902 Mdot
.41183 .6014 Mdot
.57605 .54595 Mdot
.72534 .36141 Mdot
.63001 .36167 Mdot
.69398 .26288 Mdot
.47557 .58485 Mdot
.47341 .61302 Mdot
.41774 .38209 Mdot
.52568 .31317 Mdot
.73365 .71387 Mdot
.65354 .60202 Mdot
.30624 .45811 Mdot
.63667 .57507 Mdot
.50914 .59845 Mdot
.48664 .4593 Mdot
.42458 .32797 Mdot
.27069 .43955 Mdot
.44858 .587 Mdot
.75109 .58206 Mdot
.6923 .45282 Mdot
.60136 .39218 Mdot
.46659 .3536 Mdot
.67849 .75339 Mdot
.42395 .58772 Mdot
.60624 .42556 Mdot
.44411 .60438 Mdot
.34671 .49706 Mdot
.43667 .69498 Mdot
.3243 .46702 Mdot
.49516 .63651 Mdot
.38725 .32177 Mdot
.84565 .62298 Mdot
.35149 .42651 Mdot
.69442 .5811 Mdot
.40864 .37565 Mdot
.43269 .37305 Mdot
.69274 .54903 Mdot
.43285 .36437 Mdot
.6329 .68452 Mdot
.5241 .80267 Mdot
.3092 .44989 Mdot
.52211 .65484 Mdot
.31755 .45395 Mdot
.41284 .37006 Mdot
.4819 .59264 Mdot
.14102 .48642 Mdot
.42919 .34742 Mdot
.63512 .80447 Mdot
.61621 .37644 Mdot
.41303 .33922 Mdot
.4837 .65284 Mdot
.67156 .4658 Mdot
.48612 .36278 Mdot
.56534 .30085 Mdot
.42101 .62124 Mdot
.63774 .53459 Mdot
.47187 .64921 Mdot
.48945 .581 Mdot
.44817 .31485 Mdot
.49661 .61567 Mdot
.5993 .4112 Mdot
.6202 .58352 Mdot
.32621 .74186 Mdot
.62959 .23688 Mdot
.42178 .60659 Mdot
.46335 .61606 Mdot
.64477 .51692 Mdot
.49343 .65685 Mdot
.64792 .36244 Mdot
.25558 .22137 Mdot
.31185 .44876 Mdot
.42167 .32397 Mdot
.38348 .30307 Mdot
.49518 .56789 Mdot
.50013 .60697 Mdot
.18655 .67865 Mdot
.309 .62911 Mdot
.6073 .41195 Mdot
.50165 .6678 Mdot
.4836 .37738 Mdot
.32255 .43109 Mdot
.62012 .35234 Mdot
.44946 .62415 Mdot
.47235 .59923 Mdot
.30394 .4669 Mdot
.26588 .47922 Mdot
.76973 .63683 Mdot
.61996 .42317 Mdot
.38314 .62714 Mdot
.48592 .3127 Mdot
.43767 .66527 Mdot
.78447 .59706 Mdot
.6778 .56885 Mdot
.64477 .36795 Mdot
.2149 .59846 Mdot
.41924 .5918 Mdot
.61533 .41519 Mdot
.61817 .36341 Mdot
.42713 .67492 Mdot
.59489 .58615 Mdot
.62986 .58815 Mdot
.67368 .53723 Mdot
.55043 .13291 Mdot
.29635 .55578 Mdot
.4763 .35286 Mdot
.63072 .36443 Mdot
.42032 .37514 Mdot
.32573 .40747 Mdot
.49506 .48405 Mdot
.41919 .36903 Mdot
.65643 .5299 Mdot
.41693 .33075 Mdot
.42924 .63578 Mdot
.61483 .36502 Mdot
.47058 .36118 Mdot
.49479 .58066 Mdot
.74699 .55169 Mdot
.4669 .24093 Mdot
.34691 .45435 Mdot
.3049 .48297 Mdot
.46891 .65632 Mdot
.46789 .39863 Mdot
.47552 .59415 Mdot
.58815 .41112 Mdot
.76315 .52525 Mdot
.48886 .58206 Mdot
.43563 .35689 Mdot
.64462 .51798 Mdot
.68744 .74704 Mdot
.52514 .61846 Mdot
.4569 .59359 Mdot
.49353 .62316 Mdot
.44328 .60474 Mdot
.19147 .46637 Mdot
.64325 .3977 Mdot
.55745 .2058 Mdot
.21706 .57035 Mdot
.64757 .54829 Mdot
.684 .57512 Mdot
.77479 .663 Mdot
.72043 .37326 Mdot
.63084 .36842 Mdot
.47344 .6334 Mdot
.69792 .42504 Mdot
.24514 .72047 Mdot
.16013 .4975 Mdot
.46095 .74422 Mdot
.40986 .35413 Mdot
.59821 .57608 Mdot
.42689 .36486 Mdot
.48774 .62402 Mdot
.41293 .6736 Mdot
.50617 .84451 Mdot
.6003 .36429 Mdot
.30903 .45801 Mdot
.49211 .62905 Mdot
.29132 .55709 Mdot
.46065 .3553 Mdot
.41251 .33961 Mdot
.44363 .65397 Mdot
.67265 .52317 Mdot
.83553 .62683 Mdot
.60618 .39527 Mdot
.54063 .21144 Mdot
.66709 .2548 Mdot
.70229 .48466 Mdot
.60473 .38616 Mdot
.6077 .51442 Mdot
.41404 .35477 Mdot
.71153 .67819 Mdot
.64856 .55365 Mdot
.33191 .43187 Mdot
.3892 .639 Mdot
.68565 .56741 Mdot
.47087 .329 Mdot
.62255 .54019 Mdot
.50053 .6048 Mdot
.65822 .35036 Mdot
.45591 .36634 Mdot
.67988 .36948 Mdot
.60821 .54068 Mdot
.2961 .44444 Mdot
.56312 .36621 Mdot
.46962 .76099 Mdot
.62749 .71832 Mdot
.44147 .6556 Mdot
.47543 .46111 Mdot
.44874 .63596 Mdot
.68992 .52545 Mdot
.45179 .61013 Mdot
.57844 .59947 Mdot
.4638 .36561 Mdot
.50146 .63623 Mdot
.46598 .63411 Mdot
.46681 .17385 Mdot
.42615 .60579 Mdot
.44825 .67192 Mdot
.45429 .62199 Mdot
.57445 .59529 Mdot
.54345 .60769 Mdot
.62318 .56775 Mdot
.33849 .29023 Mdot
.44778 .3483 Mdot
.30371 .42327 Mdot
.31912 .47597 Mdot
.32281 .57146 Mdot
.37124 .35427 Mdot
.49692 .28734 Mdot
.6703 .54091 Mdot
.5953 .41242 Mdot
.44761 .60817 Mdot
.39796 .80289 Mdot
.50223 .34486 Mdot
.4414 .32133 Mdot
.63291 .24044 Mdot
.42154 .70629 Mdot
.36557 .7363 Mdot
.4864 .67635 Mdot
.64978 .19558 Mdot
.50663 .56968 Mdot
.40312 .6871 Mdot
.46859 .39455 Mdot
.25477 .44691 Mdot
.48617 .65978 Mdot
.64118 .58577 Mdot
.33553 .45498 Mdot
.39588 .6943 Mdot
.41275 .31351 Mdot
.50951 .31989 Mdot
.61107 .61765 Mdot
.425 .62554 Mdot
.45496 .36645 Mdot
.62379 .55736 Mdot
.7736 .67363 Mdot
.60239 .39946 Mdot
.39272 .38708 Mdot
.77863 .42469 Mdot
.20566 .37688 Mdot
.30062 .43205 Mdot
.70311 .64643 Mdot
.42845 .64239 Mdot
.2567 .38735 Mdot
.47185 .57283 Mdot
.19289 .66517 Mdot
.31586 .47841 Mdot
.64372 .52951 Mdot
.6055 .41792 Mdot
.65116 .58441 Mdot
.61653 .71319 Mdot
.42613 .29929 Mdot
.53301 .45741 Mdot
.45504 .34138 Mdot
.56149 .50151 Mdot
.67667 .56223 Mdot
.48069 .58363 Mdot
.77595 .29497 Mdot
.68723 .5627 Mdot
.62546 .52931 Mdot
.3782 .21092 Mdot
.15332 .44269 Mdot
.45532 .55818 Mdot
.63691 .52794 Mdot
.44864 .33943 Mdot
.32958 .45849 Mdot
.48912 .64505 Mdot
.42245 .63236 Mdot
.67678 .5717 Mdot
.44526 .31207 Mdot
.53511 .72741 Mdot
.43992 .37734 Mdot
.63854 .53193 Mdot
.44585 .36291 Mdot
.60161 .34975 Mdot
.44258 .33094 Mdot
.50474 .64212 Mdot
.45062 .60963 Mdot
.34838 .31475 Mdot
.63717 .53626 Mdot
.45897 .63187 Mdot
.40509 .63692 Mdot
.66335 .54928 Mdot
.60601 .50583 Mdot
.54715 .72655 Mdot
.41114 .64104 Mdot
.42075 .61709 Mdot
.32892 .47622 Mdot
.49774 .47735 Mdot
.73505 .62951 Mdot
.50238 .61161 Mdot
.35114 .45833 Mdot
.63037 .58045 Mdot
.46241 .58363 Mdot
.2353 .67945 Mdot
.57188 .26386 Mdot
.46765 .57818 Mdot
.42618 .36976 Mdot
.51542 .65161 Mdot
.49279 .82063 Mdot
.46409 .66233 Mdot
.67304 .55222 Mdot
.62025 .54806 Mdot
.54438 .17143 Mdot
.66422 .56221 Mdot
.48319 .35689 Mdot
.6069 .38132 Mdot
.17972 .48168 Mdot
.4339 .38519 Mdot
.51754 .58025 Mdot
.40154 .17536 Mdot
.40159 .61436 Mdot
.51193 .59219 Mdot
.69113 .76433 Mdot
.42746 .35749 Mdot
.63592 .56312 Mdot
.5574 .38174 Mdot
.46255 .55276 Mdot
.64334 .37242 Mdot
.40693 .67758 Mdot
.45658 .662 Mdot
.53272 .82881 Mdot
.19465 .46704 Mdot
.61232 .42833 Mdot
.44696 .67103 Mdot
.50179 .60952 Mdot
.46649 .41023 Mdot
.45929 .61743 Mdot
.32676 .46208 Mdot
.63719 .55324 Mdot
.4284 .33638 Mdot
.31951 .43624 Mdot
.43534 .58075 Mdot
.30854 .46535 Mdot
.46435 .37455 Mdot
.58527 .39287 Mdot
.48767 .61302 Mdot
.33726 .42789 Mdot
.30614 .46043 Mdot
.44871 .634 Mdot
.60623 .5593 Mdot
.43704 .71266 Mdot
.42913 .60136 Mdot
.50527 .61828 Mdot
.65342 .57071 Mdot
.36683 .84016 Mdot
.46323 .65863 Mdot
.30318 .58849 Mdot
.69555 .558 Mdot
.58032 .50675 Mdot
.43555 .39152 Mdot
.47232 .665 Mdot
.58494 .39378 Mdot
.58648 .39654 Mdot
.45252 .32391 Mdot
.59682 .57239 Mdot
.39365 .27954 Mdot
.64544 .59646 Mdot
.53148 .58423 Mdot
.4593 .67369 Mdot
.53223 .66636 Mdot
.37353 .78136 Mdot
.65595 .58082 Mdot
.39595 .33007 Mdot
.69723 .59674 Mdot
.59762 .41889 Mdot
.45513 .31505 Mdot
.62661 .58771 Mdot
.64666 .57164 Mdot
.60679 .57177 Mdot
.33239 .43153 Mdot
.34779 .31897 Mdot
.69864 .54865 Mdot
.68282 .52691 Mdot
.41889 .63273 Mdot
.50219 .6166 Mdot
.62864 .79496 Mdot
.61563 .79278 Mdot
.33486 .47147 Mdot
.47842 .35629 Mdot
.50522 .11198 Mdot
.589 .37997 Mdot
.49651 .1832 Mdot
.51227 .5994 Mdot
.54514 .10865 Mdot
.48503 .65005 Mdot
.46502 .62048 Mdot
.6294 .58847 Mdot
.34202 .43591 Mdot
.3155 .45095 Mdot
.68646 .56038 Mdot
.69472 .53212 Mdot
.32483 .46286 Mdot
.32143 .2579 Mdot
.25272 .71479 Mdot
.54817 .34308 Mdot
.6551 .54401 Mdot
.48725 .78164 Mdot
.62174 .41934 Mdot
.37545 .6232 Mdot
.64279 .40933 Mdot
.45646 .34941 Mdot
.41757 .34297 Mdot
.64209 .37923 Mdot
.42427 .61525 Mdot
.47475 .34825 Mdot
.41104 .59776 Mdot
.46958 .22616 Mdot
.5983 .7445 Mdot
.43664 .28312 Mdot
.36894 .63916 Mdot
.61001 .50262 Mdot
.68025 .35427 Mdot
.45195 .57801 Mdot
.21014 .63927 Mdot
.30721 .45514 Mdot
.52062 .56787 Mdot
.64334 .36336 Mdot
.67431 .78411 Mdot
.48716 .60392 Mdot
.67006 .54834 Mdot
.62171 .36225 Mdot
.78744 .42896 Mdot
.76863 .44756 Mdot
.49234 .62618 Mdot
.73604 .2614 Mdot
.65754 .50939 Mdot
.46456 .34188 Mdot
.77595 .54984 Mdot
.68654 .57151 Mdot
.35196 .49085 Mdot
.23217 .62634 Mdot
.18639 .42081 Mdot
.6318 .55936 Mdot
.41625 .38608 Mdot
.62016 .57206 Mdot
.29967 .43645 Mdot
.69158 .58222 Mdot
.46158 .36202 Mdot
.45346 .58705 Mdot
.43599 .37027 Mdot
.33666 .43625 Mdot
.75439 .64589 Mdot
.61218 .42822 Mdot
.48322 .33425 Mdot
.62409 .39376 Mdot
.23539 .53679 Mdot
.27932 .62717 Mdot
.61486 .40713 Mdot
.54608 .68706 Mdot
.4621 .67317 Mdot
.69766 .55943 Mdot
.44073 .3896 Mdot
.26714 .41218 Mdot
.56558 .37741 Mdot
.65187 .55678 Mdot
.47587 .33785 Mdot
.77632 .48798 Mdot
.57155 .58894 Mdot
.45977 .67532 Mdot
.36186 .51321 Mdot
.65719 .54723 Mdot
.41661 .38312 Mdot
.81958 .60428 Mdot
.62265 .57275 Mdot
.47935 .38326 Mdot
.61222 .41789 Mdot
.60251 .37426 Mdot
.42374 .65601 Mdot
.6495 .33681 Mdot
.46313 .33065 Mdot
.64783 .43027 Mdot
.62938 .5306 Mdot
.79544 .46223 Mdot
.31511 .41744 Mdot
.44336 .35461 Mdot
.4035 .60164 Mdot
.67823 .51759 Mdot
.59275 .24585 Mdot
.54388 .73873 Mdot
.82154 .38627 Mdot
.43771 .38016 Mdot
.64109 .55744 Mdot
.6665 .54472 Mdot
.5267 .61102 Mdot
.76933 .53338 Mdot
.36119 .28831 Mdot
.56061 .60602 Mdot
.58674 .45505 Mdot
.44612 .3986 Mdot
.39858 .37611 Mdot
.39957 .6635 Mdot
.42922 .61678 Mdot
.60218 .42111 Mdot
.45204 .589 Mdot
.60262 .55792 Mdot
.44048 .65438 Mdot
.61439 .40031 Mdot
.45377 .33754 Mdot
.48622 .60851 Mdot
.3041 .45907 Mdot
.64435 .39436 Mdot
.58677 .37891 Mdot
.43969 .3524 Mdot
.67673 .57202 Mdot
.57066 .51377 Mdot
.44489 .38617 Mdot
.42473 .62471 Mdot
.45643 .4722 Mdot
.49994 .60151 Mdot
.56524 .55573 Mdot
.62759 .57461 Mdot
.4277 .33752 Mdot
.68361 .59393 Mdot
.62032 .38777 Mdot
.21764 .57883 Mdot
.45571 .60151 Mdot
.47105 .39141 Mdot
.64496 .29115 Mdot
.55688 .53067 Mdot
.61112 .53627 Mdot
.41044 .25226 Mdot
.69655 .56483 Mdot
.47671 .3637 Mdot
.43524 .18849 Mdot
.31872 .42586 Mdot
.43402 .32335 Mdot
.33877 .74863 Mdot
.43234 .34721 Mdot
.42863 .65407 Mdot
.464 .65539 Mdot
.43954 .33171 Mdot
.31221 .47243 Mdot
.74703 .70813 Mdot
.41674 .40498 Mdot
.63487 .56002 Mdot
.40586 .22383 Mdot
.84219 .4729 Mdot
.66293 .43175 Mdot
.59772 .41746 Mdot
.44294 .55874 Mdot
.46892 .66964 Mdot
.63857 .3575 Mdot
.61862 .4306 Mdot
.29247 .43468 Mdot
.47081 .38813 Mdot
.65596 .51232 Mdot
.57784 .39347 Mdot
.6876 .60825 Mdot
.36707 .33619 Mdot
.52318 .62536 Mdot
.6568 .24668 Mdot
.51171 .60155 Mdot
.25925 .60612 Mdot
.61728 .40155 Mdot
.46518 .57274 Mdot
.48734 .67401 Mdot
.62011 .35834 Mdot
.33111 .45798 Mdot
.39195 .38156 Mdot
.44848 .36434 Mdot
.36244 .82715 Mdot
.41004 .60888 Mdot
.43511 .65073 Mdot
.63663 .37322 Mdot
.28655 .36523 Mdot
.64292 .54754 Mdot
.67587 .58214 Mdot
.45733 .33285 Mdot
.53018 .39071 Mdot
.44328 .66379 Mdot
.45227 .58105 Mdot
.45093 .37185 Mdot
.48059 .33466 Mdot
.50247 .2835 Mdot
.44644 .64204 Mdot
.62642 .37225 Mdot
.24193 .46134 Mdot
.62374 .40088 Mdot
.49269 .59302 Mdot
.43581 .64827 Mdot
.50608 .64044 Mdot
.42347 .58087 Mdot
.65991 .36851 Mdot
.49784 .59263 Mdot
.46162 .68169 Mdot
.64444 .5571 Mdot
.49616 .62736 Mdot
.57713 .44123 Mdot
.44693 .59404 Mdot
.32751 .46041 Mdot
.73258 .62036 Mdot
.48728 .60505 Mdot
.44659 .6574 Mdot
.41252 .33303 Mdot
.46742 .60042 Mdot
.58583 .4054 Mdot
.64276 .538 Mdot
.63323 .36889 Mdot
.5869 .40046 Mdot
.42753 .39863 Mdot
.30196 .47368 Mdot
.48883 .56559 Mdot
.33943 .46018 Mdot
.51182 .56864 Mdot
.41859 .59274 Mdot
.37217 .40191 Mdot
.61835 .17297 Mdot
.7858 .61363 Mdot
.45386 .60078 Mdot
.42814 .35255 Mdot
.42622 .36508 Mdot
.57723 .55236 Mdot
.4302 .66779 Mdot
.63271 .34863 Mdot
.59566 .41781 Mdot
.4575 .78753 Mdot
.34575 .63644 Mdot
.32834 .46014 Mdot
.51033 .47327 Mdot
.41113 .62479 Mdot
.46297 .57263 Mdot
.40656 .61499 Mdot
.41843 .36906 Mdot
.41918 .73401 Mdot
.45519 .31772 Mdot
.68587 .40744 Mdot
.63656 .3853 Mdot
.4911 .61614 Mdot
.63458 .23146 Mdot
.67792 .53628 Mdot
.64289 .53756 Mdot
.59116 .36952 Mdot
.49777 .34096 Mdot
.69325 .74115 Mdot
.1527 .51629 Mdot
.71243 .53372 Mdot
.33771 .43237 Mdot
.43887 .58258 Mdot
.44183 .33652 Mdot
.62665 .53557 Mdot
.33892 .43487 Mdot
.48698 .59274 Mdot
.3486 .31973 Mdot
.44561 .60092 Mdot
.71233 .34506 Mdot
.61144 .56377 Mdot
.22181 .69651 Mdot
.59666 .56962 Mdot
.65444 .36813 Mdot
.64604 .36261 Mdot
.44661 .64649 Mdot
.66119 .499 Mdot
.68919 .57056 Mdot
.38503 .45315 Mdot
.29404 .4584 Mdot
.66812 .44237 Mdot
.3214 .42907 Mdot
.46795 .35235 Mdot
.33495 .4403 Mdot
.46179 .36468 Mdot
.70716 .72705 Mdot
.58542 .62854 Mdot
.3164 .44086 Mdot
.65401 .29861 Mdot
.4716 .66852 Mdot
.34034 .46811 Mdot
.41226 .6719 Mdot
.55495 .6056 Mdot
.44884 .37421 Mdot
.29375 .44992 Mdot
.46253 .57395 Mdot
.42323 .80343 Mdot
.60934 .40987 Mdot
.63765 .34918 Mdot
.41126 .67002 Mdot
.43315 .39407 Mdot
.63537 .58744 Mdot
.18655 .58037 Mdot
.57576 .40205 Mdot
.45654 .65465 Mdot
.48923 .65881 Mdot
.6989 .56047 Mdot
.55824 .18995 Mdot
.43765 .64412 Mdot
.54717 .55407 Mdot
.44912 .64466 Mdot
.63593 .39816 Mdot
.64589 .58239 Mdot
.65748 .54014 Mdot
.47626 .34008 Mdot
.66961 .52856 Mdot
.43916 .49945 Mdot
.68495 .30586 Mdot
.43985 .69833 Mdot
.61592 .38797 Mdot
.6894 .44042 Mdot
.69013 .36642 Mdot
.33807 .73046 Mdot
.60096 .54903 Mdot
.49272 .5849 Mdot
.6684 .52634 Mdot
.32882 .43587 Mdot
.64661 .53358 Mdot
.59833 .57629 Mdot
.47511 .59004 Mdot
.48778 .62907 Mdot
.45892 .339 Mdot
.76984 .52692 Mdot
.68623 .56804 Mdot
.48393 .64994 Mdot
.50903 .6435 Mdot
.40758 .59955 Mdot
.3905 .47145 Mdot
.65015 .58145 Mdot
.2948 .25307 Mdot
.37877 .53175 Mdot
.68347 .56966 Mdot
.80595 .6627 Mdot
.62699 .27203 Mdot
.43843 .29886 Mdot
.38772 .41486 Mdot
.45306 .6457 Mdot
.48777 .35672 Mdot
.48777 .62319 Mdot
.6602 .25111 Mdot
.47234 .60511 Mdot
.32792 .4625 Mdot
.41162 .60163 Mdot
.42383 .33385 Mdot
.43962 .37943 Mdot
.45298 .655 Mdot
.48505 .61156 Mdot
.75729 .65634 Mdot
.68491 .58747 Mdot
.62794 .54077 Mdot
.45393 .28294 Mdot
.3101 .43824 Mdot
.64436 .3703 Mdot
.45203 .61708 Mdot
.42413 .39348 Mdot
.43834 .37735 Mdot
.66727 .58022 Mdot
.46307 .38082 Mdot
.60536 .39381 Mdot
.45624 .60517 Mdot
.63925 .35502 Mdot
.32077 .42436 Mdot
.64538 .58114 Mdot
.49462 .62723 Mdot
.41872 .6324 Mdot
.62047 .5481 Mdot
.46896 .57077 Mdot
.30826 .46862 Mdot
.43304 .35207 Mdot
.63021 .55987 Mdot
.60602 .37806 Mdot
.46714 .35593 Mdot
.50765 .6097 Mdot
.71026 .24657 Mdot
.4202 .65091 Mdot
.4642 .64838 Mdot
.37233 .79215 Mdot
.41279 .61581 Mdot
.43906 .38601 Mdot
.63186 .53303 Mdot
.50668 .55133 Mdot
.32548 .54908 Mdot
.34266 .83653 Mdot
.45423 .31959 Mdot
.4367 .5864 Mdot
.36409 .75535 Mdot
.44127 .58649 Mdot
.52352 .76357 Mdot
.47513 .31939 Mdot
.57664 .46849 Mdot
.4093 .5904 Mdot
.59436 .39203 Mdot
.44642 .3326 Mdot
.46125 .36971 Mdot
.4427 .21822 Mdot
.46746 .58341 Mdot
.43428 .45376 Mdot
.49342 .59924 Mdot
.60271 .38005 Mdot
.35493 .64227 Mdot
.44004 .38308 Mdot
.83013 .46766 Mdot
.44711 .63654 Mdot
.64933 .57519 Mdot
.41362 .33549 Mdot
.57345 .38445 Mdot
.50368 .62453 Mdot
.32578 .47109 Mdot
.60059 .43142 Mdot
.43042 .69398 Mdot
.61292 .38856 Mdot
.50513 .61635 Mdot
.41433 .55337 Mdot
.79284 .39093 Mdot
.6045 .56675 Mdot
.60629 .41913 Mdot
.43649 .47495 Mdot
.49139 .58601 Mdot
.63101 .55851 Mdot
.64908 .55508 Mdot
.32657 .42613 Mdot
.56062 .48442 Mdot
.75623 .40296 Mdot
.56653 .77807 Mdot
.42065 .21979 Mdot
.42821 .32277 Mdot
.5521 .31187 Mdot
.46842 .64334 Mdot
.39757 .50398 Mdot
.58822 .41008 Mdot
.41751 .64953 Mdot
.68723 .65111 Mdot
.68842 .54512 Mdot
.41815 .64507 Mdot
.31752 .45573 Mdot
.28835 .4872 Mdot
.24229 .46939 Mdot
.26731 .66978 Mdot
.45571 .34321 Mdot
.49598 .67584 Mdot
.49693 .54347 Mdot
.43884 .39435 Mdot
.51675 .62167 Mdot
.44248 .3927 Mdot
.27613 .29421 Mdot
.34576 .45786 Mdot
.64331 .57678 Mdot
.67607 .40337 Mdot
.51282 .58915 Mdot
.45529 .66648 Mdot
.29806 .47167 Mdot
.43033 .61985 Mdot
.75337 .3313 Mdot
.3867 .47587 Mdot
.47197 .35434 Mdot
.6059 .5707 Mdot
.51174 .63634 Mdot
.49957 .48663 Mdot
.43871 .59208 Mdot
.63332 .75612 Mdot
.44885 .65806 Mdot
.77319 .44742 Mdot
.60808 .56326 Mdot
.61658 .39393 Mdot
.45207 .56937 Mdot
.47007 .612 Mdot
.33157 .60685 Mdot
.50707 .56762 Mdot
.47399 .5755 Mdot
.59558 .59673 Mdot
.60176 .5721 Mdot
.61969 .56892 Mdot
.45697 .32325 Mdot
.40288 .76254 Mdot
.62361 .3783 Mdot
.46479 .54514 Mdot
.59665 .35991 Mdot
.50764 .73078 Mdot
.34289 .44401 Mdot
.303 .67141 Mdot
.46077 .62847 Mdot
.66998 .53861 Mdot
.19005 .53931 Mdot
.67588 .58654 Mdot
.50286 .46408 Mdot
.61555 .36409 Mdot
.68548 .56306 Mdot
.46787 .61814 Mdot
.73547 .55618 Mdot
.39166 .78956 Mdot
.62815 .38292 Mdot
.52025 .58606 Mdot
.4224 .332 Mdot
.38997 .29482 Mdot
.80992 .41137 Mdot
.61284 .41048 Mdot
.60018 .44805 Mdot
.46214 .58077 Mdot
.66886 .5306 Mdot
.59699 .38863 Mdot
.63411 .39891 Mdot
.46659 .37651 Mdot
.48727 .63185 Mdot
.48484 .63543 Mdot
.48013 .35317 Mdot
.63437 .37062 Mdot
.44206 .67802 Mdot
.44522 .69235 Mdot
.58658 .84433 Mdot
.78272 .46961 Mdot
.37961 .84632 Mdot
.57891 .53424 Mdot
.65829 .64604 Mdot
.18495 .58994 Mdot
.66847 .57573 Mdot
.44772 .5753 Mdot
.39 .65376 Mdot
.46267 .33013 Mdot
.46199 .59412 Mdot
.47949 .3162 Mdot
.59881 .3698 Mdot
.66887 .78622 Mdot
.72328 .46457 Mdot
.22697 .35617 Mdot
.46395 .59347 Mdot
.58277 .58527 Mdot
.32912 .44124 Mdot
.65458 .45909 Mdot
.6376 .57962 Mdot
.39939 .61886 Mdot
.75648 .65404 Mdot
.44048 .32132 Mdot
.65756 .56696 Mdot
.76859 .67951 Mdot
.61965 .49747 Mdot
.49926 .60154 Mdot
.4646 .32111 Mdot
.20025 .62889 Mdot
.67515 .61597 Mdot
.62851 .34474 Mdot
.33208 .45751 Mdot
.43273 .33525 Mdot
.6021 .42278 Mdot
.58085 .57826 Mdot
.66853 .56721 Mdot
.63997 .58634 Mdot
.76974 .61815 Mdot
.43604 .31124 Mdot
.32708 .44035 Mdot
.34618 .68513 Mdot
.34098 .61735 Mdot
.32288 .46408 Mdot
.41701 .34362 Mdot
.6023 .56142 Mdot
.68801 .5535 Mdot
.64366 .53823 Mdot
.8028 .56705 Mdot
.6532 .52185 Mdot
.4551 .20126 Mdot
.41358 .59071 Mdot
.51258 .67031 Mdot
.44046 .58421 Mdot
.62964 .3502 Mdot
.61976 .55199 Mdot
.5539 .37659 Mdot
.52422 .58088 Mdot
.30064 .6502 Mdot
.42676 .65552 Mdot
.64629 .39715 Mdot
.42241 .64401 Mdot
.6432 .21982 Mdot
.68048 .53272 Mdot
.45735 .5983 Mdot
.64112 .40891 Mdot
.30511 .43925 Mdot
.60489 .54202 Mdot
.49344 .6237 Mdot
.37581 .25873 Mdot
.41489 .60516 Mdot
.24723 .3348 Mdot
.76634 .38291 Mdot
.33947 .43524 Mdot
.70558 .29394 Mdot
.41824 .39352 Mdot
.54908 .59987 Mdot
.44193 .55336 Mdot
.62495 .38928 Mdot
.66541 .4449 Mdot
.44789 .3459 Mdot
.44677 .74278 Mdot
.45148 .68365 Mdot
.32233 .42351 Mdot
.57467 .62744 Mdot
.63312 .35715 Mdot
.51605 .62846 Mdot
.4964 .66812 Mdot
.53289 .20353 Mdot
.43056 .6845 Mdot
.47505 .66414 Mdot
.31402 .48424 Mdot
.47865 .19112 Mdot
.44073 .59797 Mdot
.50885 .46848 Mdot
.68772 .58446 Mdot
.52612 .57691 Mdot
.46016 .1957 Mdot
.46779 .65606 Mdot
.66784 .57089 Mdot
.55501 .55886 Mdot
.7377 .38907 Mdot
.30442 .4756 Mdot
.44862 .65842 Mdot
.53292 .17121 Mdot
.43571 .6322 Mdot
.62239 .37343 Mdot
.43267 .66751 Mdot
.46088 .35913 Mdot
.79917 .6038 Mdot
.4735 .33909 Mdot
.42277 .65936 Mdot
.64769 .54018 Mdot
.63659 .37952 Mdot
.7887 .56135 Mdot
.32625 .32548 Mdot
.52142 .18898 Mdot
.16271 .50134 Mdot
.29616 .46074 Mdot
.32261 .41384 Mdot
.60537 .36199 Mdot
.45541 .59766 Mdot
.38637 .19929 Mdot
.49071 .55943 Mdot
.41822 .62321 Mdot
.47324 .60608 Mdot
.27576 .62135 Mdot
.58751 .39064 Mdot
.44508 .37804 Mdot
.43609 .64566 Mdot
.49091 .58706 Mdot
.65912 .57562 Mdot
.306 .4449 Mdot
.43385 .38888 Mdot
.30996 .45071 Mdot
.4422 .33394 Mdot
.73021 .73473 Mdot
.46445 .67962 Mdot
.30309 .43808 Mdot
.58304 .41208 Mdot
.66276 .57316 Mdot
.69419 .33934 Mdot
.46562 .36364 Mdot
.46465 .32718 Mdot
.45317 .65738 Mdot
.67831 .56953 Mdot
.65481 .59694 Mdot
.31529 .4289 Mdot
.60963 .40431 Mdot
.48677 .60398 Mdot
.41982 .59741 Mdot
.43259 .54062 Mdot
.43172 .39654 Mdot
.7072 .32933 Mdot
.52114 .32003 Mdot
.45273 .5994 Mdot
.62987 .53072 Mdot
.4814 .60812 Mdot
.22427 .40741 Mdot
.67225 .53134 Mdot
.47417 .6555 Mdot
.83887 .61458 Mdot
.43273 .29366 Mdot
.71873 .41043 Mdot
.48904 .65725 Mdot
.17452 .6192 Mdot
.4653 .6369 Mdot
.68077 .78324 Mdot
.2257 .44651 Mdot
.44369 .66758 Mdot
.5043 .62636 Mdot
.58309 .73529 Mdot
.42788 .58982 Mdot
.47983 .34331 Mdot
.61555 .80883 Mdot
.66499 .58977 Mdot
.68798 .35868 Mdot
.71841 .62887 Mdot
.30906 .47679 Mdot
.4571 .33279 Mdot
.40819 .33148 Mdot
.31451 .46183 Mdot
.65874 .54532 Mdot
.44315 .60494 Mdot
.49904 .43337 Mdot
.42786 .38924 Mdot
.43876 .72323 Mdot
.62193 .37092 Mdot
.54651 .25283 Mdot
.3536 .50837 Mdot
.60976 .38938 Mdot
.49561 .63002 Mdot
.56715 .73291 Mdot
.70485 .71848 Mdot
.29061 .73751 Mdot
.61336 .42625 Mdot
.62965 .38368 Mdot
.80935 .57828 Mdot
.29046 .42832 Mdot
.53331 .20678 Mdot
.77124 .45039 Mdot
.64134 .37549 Mdot
.59253 .5467 Mdot
.4828 .34638 Mdot
.59254 .32349 Mdot
.53905 .58476 Mdot
.42076 .58727 Mdot
.46802 .61617 Mdot
.61828 .40498 Mdot
.56429 .5346 Mdot
.80334 .48192 Mdot
.62615 .39425 Mdot
.38734 .60004 Mdot
.55197 .45056 Mdot
.62648 .30187 Mdot
.46036 .3876 Mdot
.2923 .45639 Mdot
.29102 .42306 Mdot
.64182 .56899 Mdot
.29484 .4634 Mdot
.28069 .48338 Mdot
.43747 .61624 Mdot
.63166 .39462 Mdot
.64346 .27357 Mdot
.60712 .37268 Mdot
.31279 .45629 Mdot
.29187 .43267 Mdot
.64451 .55635 Mdot
.62909 .53866 Mdot
.61248 .67885 Mdot
.32424 .51632 Mdot
.42192 .60979 Mdot
.3073 .39977 Mdot
.60377 .57984 Mdot
.48261 .69877 Mdot
.29295 .46004 Mdot
.30744 .43947 Mdot
.32308 .6106 Mdot
.46336 .62706 Mdot
.48551 .71203 Mdot
.45837 .6231 Mdot
.39992 .53825 Mdot
.5089 .62335 Mdot
.46608 .37738 Mdot
.47213 .63364 Mdot
.32039 .62267 Mdot
.48317 .57054 Mdot
.48502 .66797 Mdot
.4195 .37934 Mdot
.45566 .68707 Mdot
.45949 .35914 Mdot
.41286 .64677 Mdot
.34101 .42888 Mdot
.45683 .33092 Mdot
.30864 .55716 Mdot
.31064 .60249 Mdot
.41523 .35136 Mdot
.34074 .45024 Mdot
.32861 .47805 Mdot
.27336 .56332 Mdot
.63879 .58058 Mdot
.41088 .56982 Mdot
.45725 .59548 Mdot
.45974 .3139 Mdot
.59127 .40863 Mdot
.50922 .61218 Mdot
.47787 .66563 Mdot
.49475 .64933 Mdot
.64303 .57099 Mdot
.35283 .29373 Mdot
.30029 .43836 Mdot
.48144 .34968 Mdot
.56306 .51056 Mdot
.44629 .39908 Mdot
.51307 .6512 Mdot
.38769 .63585 Mdot
.70013 .64028 Mdot
.64739 .31011 Mdot
.81522 .54954 Mdot
.66599 .56681 Mdot
.42545 .36772 Mdot
.31734 .41682 Mdot
.39329 .59941 Mdot
.66942 .53697 Mdot
.46119 .36189 Mdot
.44637 .60113 Mdot
.52071 .59402 Mdot
.6732 .29235 Mdot
.24158 .48507 Mdot
.31128 .58262 Mdot
.44737 .3238 Mdot
.41002 .35681 Mdot
.2988 .6148 Mdot
.26814 .42451 Mdot
.56637 .36982 Mdot
.46065 .58459 Mdot
.32327 .47083 Mdot
.63727 .53191 Mdot
.73973 .6383 Mdot
.6466 .37859 Mdot
.76693 .53677 Mdot
.46383 .59526 Mdot
.60293 .49092 Mdot
.64656 .54111 Mdot
.31888 .45865 Mdot
.62205 .40428 Mdot
.27305 .44624 Mdot
.42115 .36925 Mdot
.17855 .42073 Mdot
.43012 .62889 Mdot
.44944 .65637 Mdot
.63307 .4117 Mdot
.67931 .54045 Mdot
.33909 .47711 Mdot
.40431 .22949 Mdot
.46176 .37521 Mdot
.39855 .19343 Mdot
.63811 .52828 Mdot
.48614 .77932 Mdot
.47292 .37777 Mdot
.58379 .37791 Mdot
.28399 .5572 Mdot
.60907 .39586 Mdot
.43049 .65984 Mdot
.67096 .54369 Mdot
.60116 .41715 Mdot
.78247 .50851 Mdot
.41127 .81954 Mdot
.4957 .78236 Mdot
.44303 .6137 Mdot
.48822 .83131 Mdot
.29812 .28796 Mdot
.7114 .52826 Mdot
.59351 .41754 Mdot
.41947 .65236 Mdot
.4505 .66195 Mdot
.43362 .63279 Mdot
.58982 .39814 Mdot
.32784 .40204 Mdot
.45054 .37634 Mdot
.45025 .57955 Mdot
.29438 .43215 Mdot
.45588 .35257 Mdot
.59245 .35982 Mdot
.45402 .38948 Mdot
.59246 .58158 Mdot
.52308 .6315 Mdot
.65492 .47337 Mdot
.89425 .54243 Mdot
.63235 .3765 Mdot
.42441 .39611 Mdot
.42819 .67329 Mdot
.58735 .26692 Mdot
.61954 .57844 Mdot
.46469 .37362 Mdot
.43441 .6518 Mdot
.66247 .30776 Mdot
.76629 .63556 Mdot
.44709 .38903 Mdot
.66755 .53521 Mdot
.29537 .73584 Mdot
.45718 .58985 Mdot
.45325 .63172 Mdot
.67975 .56481 Mdot
.54271 .66409 Mdot
.80048 .62814 Mdot
.48363 .61068 Mdot
.61725 .39563 Mdot
.19597 .36142 Mdot
.47675 .66615 Mdot
.37238 .56113 Mdot
.4538 .33457 Mdot
.58337 .34339 Mdot
.7285 .36419 Mdot
.45663 .56589 Mdot
.48856 .22536 Mdot
.67211 .41037 Mdot
.39444 .76595 Mdot
.47751 .31251 Mdot
.30997 .30664 Mdot
.46708 .81292 Mdot
.65595 .38241 Mdot
.59379 .60758 Mdot
.45237 .2266 Mdot
.69273 .61836 Mdot
.23466 .67214 Mdot
.26924 .38166 Mdot
.75907 .65245 Mdot
.51614 .42728 Mdot
.4296 .344 Mdot
.53858 .65295 Mdot
.49008 .62264 Mdot
.29267 .29353 Mdot
.79231 .40807 Mdot
.79913 .43797 Mdot
.4895 .83257 Mdot
.51827 .77075 Mdot
.37008 .76263 Mdot
.34725 .75117 Mdot
.37367 .57813 Mdot
.54008 .32435 Mdot
.38299 .19533 Mdot
.68751 .75336 Mdot
.34474 .23964 Mdot
.50568 .67604 Mdot
.48656 .45954 Mdot
.21479 .39725 Mdot
.59049 .62301 Mdot
.56792 .60144 Mdot
.47757 .34956 Mdot
.63756 .58209 Mdot
.51597 .21063 Mdot
.7026 .55294 Mdot
.73631 .38487 Mdot
.31808 .76085 Mdot
.40119 .81036 Mdot
.55564 .18245 Mdot
.17991 .61705 Mdot
.67607 .65133 Mdot
.33914 .18357 Mdot
.49346 .35097 Mdot
.67028 .57863 Mdot
.26747 .60505 Mdot
.33011 .64576 Mdot
.70089 .4746 Mdot
.40536 .24437 Mdot
.36784 .31716 Mdot
.24572 .52119 Mdot
.66728 .54681 Mdot
.7138 .31474 Mdot
.60644 .32221 Mdot
.71765 .46834 Mdot
.65267 .77932 Mdot
.29157 .71437 Mdot
.48035 .43755 Mdot
.45053 .24545 Mdot
.55268 .27315 Mdot
.80924 .48911 Mdot
.34693 .53386 Mdot
.56765 .58293 Mdot
.77956 .45632 Mdot
.17635 .54271 Mdot
.59012 .65519 Mdot
.41266 .53414 Mdot
.33621 .65197 Mdot
.75186 .71069 Mdot
.26001 .34167 Mdot
.86501 .46881 Mdot
.70448 .55015 Mdot
.49447 .65567 Mdot
.53379 .69261 Mdot
.49247 .16599 Mdot
.30719 .48585 Mdot
.25771 .66092 Mdot
.29405 .43955 Mdot
.59654 .58571 Mdot
.79195 .62283 Mdot
.47035 .19173 Mdot
.4335 .1722 Mdot
.33399 .42017 Mdot
.46241 .54461 Mdot
.17368 .68222 Mdot
.34705 .71215 Mdot
.71683 .43811 Mdot
.59406 .83974 Mdot
.55961 .44075 Mdot
.79345 .45258 Mdot
.60012 .41766 Mdot
.50867 .82659 Mdot
.68391 .55366 Mdot
.87423 .4394 Mdot
.69666 .77047 Mdot
.71357 .64972 Mdot
.72387 .82462 Mdot
.28736 .6182 Mdot
.58286 .47319 Mdot
.64587 .43988 Mdot
.29334 .52706 Mdot
.7854 .5377 Mdot
.21949 .5579 Mdot
.57667 .26786 Mdot
.16926 .61817 Mdot
.45424 .8138 Mdot
.41229 .18092 Mdot
.21469 .35734 Mdot
.60727 .63907 Mdot
.5092 .48831 Mdot
.37167 .62266 Mdot
.41514 .28728 Mdot
.24597 .65799 Mdot
.77198 .69832 Mdot
.37624 .53348 Mdot
.33617 .8319 Mdot
.35085 .42495 Mdot
.35183 .3429 Mdot
.36349 .81441 Mdot
.25415 .53222 Mdot
.73543 .35044 Mdot
.37953 .72919 Mdot
.38653 .69554 Mdot
.51229 .50154 Mdot
.25672 .66806 Mdot
.705 .37208 Mdot
.57891 .82423 Mdot
.19685 .64689 Mdot
.53905 .20546 Mdot
.5995 .75297 Mdot
.35113 .59634 Mdot
.63745 .51697 Mdot
.27579 .49059 Mdot
.73494 .3675 Mdot
.43786 .83439 Mdot
.65793 .35812 Mdot
.47842 .84894 Mdot
.79381 .63575 Mdot
.46509 .68034 Mdot
.40653 .57561 Mdot
.59996 .52576 Mdot
.26506 .49078 Mdot
.49933 .67652 Mdot
.63813 .24997 Mdot
.39197 .80682 Mdot
.67501 .73626 Mdot
.6799 .34353 Mdot
.67003 .43145 Mdot
.36568 .82254 Mdot
.56081 .70546 Mdot
.28733 .41318 Mdot
.57982 .81293 Mdot
.7895 .53482 Mdot
.44793 .35265 Mdot
.42501 .18275 Mdot
.59729 .44217 Mdot
.75258 .63914 Mdot
.5616 .77783 Mdot
.67026 .63218 Mdot
.39286 .80827 Mdot
.34507 .28644 Mdot
.7809 .63759 Mdot
.23588 .5536 Mdot
.36244 .21947 Mdot
.63582 .30591 Mdot
.4008 .67411 Mdot
.39604 .24848 Mdot
.32491 .47656 Mdot
.6156 .70426 Mdot
.2338 .30272 Mdot
.30814 .37505 Mdot
.40245 .66111 Mdot
.72003 .64621 Mdot
.41083 .31797 Mdot
.73757 .54971 Mdot
.83653 .40087 Mdot
.50176 .65643 Mdot
.34641 .67578 Mdot
.32708 .2854 Mdot
.29756 .51677 Mdot
.24346 .70817 Mdot
.19766 .45303 Mdot
.8764 .48675 Mdot
.54032 .84005 Mdot
.32217 .321 Mdot
.44287 .80016 Mdot
.45461 .825 Mdot
.87078 .49749 Mdot
.45774 .5549 Mdot
.65421 .35605 Mdot
.66954 .19895 Mdot
.46156 .38828 Mdot
.33442 .66891 Mdot
.42082 .21964 Mdot
.33568 .50585 Mdot
.65685 .47989 Mdot
.44241 .7376 Mdot
.51233 .43552 Mdot
.68739 .58745 Mdot
.4907 .68029 Mdot
.83824 .49844 Mdot
.87287 .54043 Mdot
.85364 .48745 Mdot
.17513 .48056 Mdot
.51309 .82459 Mdot
.58778 .49351 Mdot
.52497 .17646 Mdot
.46835 .7066 Mdot
.45515 .5729 Mdot
.30306 .49146 Mdot
.28311 .6157 Mdot
.74405 .62722 Mdot
.74179 .47251 Mdot
.58161 .6302 Mdot
.25609 .6617 Mdot
.10252 .45215 Mdot
.63605 .67464 Mdot
.42943 .20379 Mdot
.279 .42344 Mdot
.30814 .51306 Mdot
.21687 .62283 Mdot
.74587 .61402 Mdot
.36032 .77463 Mdot
.68428 .58879 Mdot
.37596 .23493 Mdot
.28956 .39045 Mdot
.60976 .60696 Mdot
.35059 .29693 Mdot
.34286 .71958 Mdot
.67721 .43039 Mdot
.75969 .59595 Mdot
.76348 .45882 Mdot
.54901 .68301 Mdot
.37844 .4684 Mdot
.53304 .2651 Mdot
.29466 .25207 Mdot
.24235 .39385 Mdot
.37813 .55668 Mdot
.54501 .44839 Mdot
.68715 .26833 Mdot
.6762 .36753 Mdot
.39612 .53662 Mdot
.57138 .43219 Mdot
.36487 .7116 Mdot
.87626 .35786 Mdot
.8378 .45199 Mdot
.3165 .77054 Mdot
.20849 .51012 Mdot
.41951 .68723 Mdot
.35003 .77228 Mdot
.86034 .43383 Mdot
.83091 .64025 Mdot
.5116 .26616 Mdot
.49507 .3458 Mdot
.58615 .37148 Mdot
.83178 .54201 Mdot
.3631 .40575 Mdot
.32397 .73499 Mdot
.36303 .55674 Mdot
.58135 .39375 Mdot
.57013 .14623 Mdot
.73363 .72326 Mdot
.53658 .7877 Mdot
.2481 .48245 Mdot
.39112 .62459 Mdot
.72325 .30185 Mdot
.68781 .57282 Mdot
.57233 .30167 Mdot
.33825 .51922 Mdot
.44105 .35954 Mdot
.24755 .61585 Mdot
.37645 .2459 Mdot
.41149 .6013 Mdot
.46382 .47731 Mdot
.64003 .52078 Mdot
.63437 .30111 Mdot
.6912 .42398 Mdot
.85045 .61043 Mdot
.26918 .44975 Mdot
.40367 .59844 Mdot
.31041 .52361 Mdot
.37516 .28553 Mdot
.82035 .60358 Mdot
.59415 .37048 Mdot
.4295 .80531 Mdot
.46986 .44671 Mdot
.29811 .50498 Mdot
.72139 .60144 Mdot
.51607 .67416 Mdot
.47192 .67264 Mdot
.1826 .51043 Mdot
.67926 .7265 Mdot
.70707 .59507 Mdot
.53137 .57142 Mdot
.4496 .72125 Mdot
.34413 .76753 Mdot
.28238 .48229 Mdot
.54854 .25958 Mdot
.41985 .80657 Mdot
.59478 .38022 Mdot
.66541 .52536 Mdot
.33397 .40748 Mdot
.32867 .24888 Mdot
.48384 .78994 Mdot
.76755 .63431 Mdot
.3827 .50067 Mdot
.32013 .3685 Mdot
.42275 .81744 Mdot
.40727 .7845 Mdot
.65264 .21527 Mdot
.68133 .51238 Mdot
.43768 .51591 Mdot
.31498 .25127 Mdot
.61922 .58191 Mdot
.50927 .19247 Mdot
.55376 .20594 Mdot
.70051 .75907 Mdot
.44735 .47292 Mdot
.17198 .63477 Mdot
.31215 .57821 Mdot
.23263 .63037 Mdot
.7944 .55391 Mdot
.34973 .23178 Mdot
.32143 .67163 Mdot
.71502 .53994 Mdot
.57049 .7483 Mdot
.44115 .696 Mdot
.62664 .21552 Mdot
.67525 .21146 Mdot
.35845 .42399 Mdot
.59708 .46382 Mdot
.20029 .65886 Mdot
.42998 .61398 Mdot
.82677 .39812 Mdot
.37515 .24216 Mdot
.80779 .57349 Mdot
.58329 .38434 Mdot
.50172 .61162 Mdot
.50139 .57037 Mdot
.49416 .80777 Mdot
.73076 .38397 Mdot
.37829 .73248 Mdot
.20389 .35651 Mdot
.20721 .64125 Mdot
.59079 .63314 Mdot
.33536 .66527 Mdot
.29439 .71815 Mdot
.29296 .29622 Mdot
.54847 .47526 Mdot
.218 .57013 Mdot
.26906 .53847 Mdot
.18032 .58458 Mdot
.58579 .4436 Mdot
.39944 .40466 Mdot
.68546 .39675 Mdot
.4565 .27471 Mdot
.77642 .60109 Mdot
.49513 .6361 Mdot
.76801 .68035 Mdot
.33123 .72772 Mdot
.69937 .26587 Mdot
.79933 .3933 Mdot
.83819 .45766 Mdot
.64813 .73932 Mdot
.27186 .3377 Mdot
.32478 .26922 Mdot
.27791 .25468 Mdot
.45686 .44446 Mdot
.28517 .6459 Mdot
.24835 .54101 Mdot
.42169 .81343 Mdot
.63355 .40948 Mdot
.76539 .43128 Mdot
.68305 .36524 Mdot
.41882 .78083 Mdot
.56608 .7131 Mdot
.35055 .74321 Mdot
.54821 .41945 Mdot
.8801 .48372 Mdot
.21859 .42982 Mdot
.52678 .42017 Mdot
.42199 .35929 Mdot
.29649 .32579 Mdot
.28545 .68527 Mdot
.21949 .4353 Mdot
.37454 .21882 Mdot
.44232 .29494 Mdot
.5562 .51633 Mdot
.48233 .7672 Mdot
.27386 .4871 Mdot
.18021 .51151 Mdot
.30895 .52313 Mdot
.38796 .79657 Mdot
.52265 .822 Mdot
.76857 .67729 Mdot
.29077 .6255 Mdot
.16377 .48872 Mdot
.717 .4344 Mdot
.25633 .4736 Mdot
.37631 .24357 Mdot
.3587 .35973 Mdot
.70631 .57308 Mdot
.58528 .11096 Mdot
.18783 .41323 Mdot
.25317 .37282 Mdot
.76495 .70366 Mdot
.19027 .46203 Mdot
.64138 .30355 Mdot
.55685 .64913 Mdot
.77973 .4977 Mdot
.73989 .69625 Mdot
.47229 .60673 Mdot
.84738 .46994 Mdot
.39491 .51088 Mdot
.88231 .55164 Mdot
.3264 .74959 Mdot
.59595 .4599 Mdot
.52126 .63594 Mdot
.47649 .33204 Mdot
.42748 .44809 Mdot
.35733 .64824 Mdot
.53068 .71952 Mdot
.75949 .37464 Mdot
.6728 .34646 Mdot
.49194 .35831 Mdot
.43773 .28035 Mdot
.70948 .56366 Mdot
.21768 .48914 Mdot
.49845 .29826 Mdot
.49359 .38671 Mdot
.46689 .43511 Mdot
.37946 .52497 Mdot
.72466 .35358 Mdot
.52547 .79018 Mdot
.75171 .61251 Mdot
.68046 .47575 Mdot
.47228 .3717 Mdot
.56208 .78463 Mdot
.20448 .40604 Mdot
.19919 .63417 Mdot
.77287 .69563 Mdot
.50771 .49804 Mdot
.53599 .73799 Mdot
.36374 .58589 Mdot
.80638 .45363 Mdot
.64864 .49755 Mdot
.6663 .34382 Mdot
.72261 .30494 Mdot
.59573 .53602 Mdot
.47552 .23105 Mdot
.67197 .7844 Mdot
.35372 .23752 Mdot
.31214 .25164 Mdot
.37744 .44587 Mdot
.49046 .53548 Mdot
.59684 .60033 Mdot
.31013 .56453 Mdot
.56562 .38408 Mdot
.4174 .15954 Mdot
.52064 .56774 Mdot
.37756 .14975 Mdot
.63204 .4031 Mdot
.63724 .62473 Mdot
.26384 .54246 Mdot
.55349 .45876 Mdot
.5548 .41665 Mdot
.22991 .40893 Mdot
.77236 .43298 Mdot
.27605 .32538 Mdot
.80033 .48505 Mdot
.49294 .34365 Mdot
.17348 .40053 Mdot
.15226 .53155 Mdot
.58599 .74864 Mdot
.40803 .63358 Mdot
.16954 .44187 Mdot
.48803 .37476 Mdot
.7458 .6222 Mdot
.24781 .71311 Mdot
.19553 .55607 Mdot
.47427 .75805 Mdot
.30031 .50817 Mdot
.28958 .65032 Mdot
.51157 .84404 Mdot
.68058 .22868 Mdot
.25049 .6552 Mdot
.63137 .41086 Mdot
.54754 .43043 Mdot
.3211 .69425 Mdot
.78521 .41943 Mdot
.63352 .32103 Mdot
.74935 .37039 Mdot
.30455 .19681 Mdot
.33943 .6833 Mdot
.35707 .68876 Mdot
.78469 .4016 Mdot
.59805 .56405 Mdot
.77002 .40768 Mdot
.73349 .34836 Mdot
.19815 .50278 Mdot
.23132 .3565 Mdot
.73309 .35483 Mdot
.29486 .23314 Mdot
.55954 .59216 Mdot
.54337 .35919 Mdot
.48157 .71052 Mdot
.37375 .70034 Mdot
.59005 .42248 Mdot
.6822 .7488 Mdot
.22141 .66398 Mdot
.64733 .34194 Mdot
.18271 .53029 Mdot
.4425 .24748 Mdot
.37721 .69445 Mdot
.50821 .79811 Mdot
.20413 .60635 Mdot
.56056 .72655 Mdot
.62007 .20207 Mdot
.72719 .65195 Mdot
.48852 .37997 Mdot
.25219 .69649 Mdot
.46981 .35871 Mdot
.4339 .72428 Mdot
.76571 .54339 Mdot
.22166 .56897 Mdot
.81525 .55684 Mdot
.3117 .47627 Mdot
.66728 .58265 Mdot
.67961 .21926 Mdot
.62372 .53557 Mdot
.84101 .5024 Mdot
.68791 .62911 Mdot
.74375 .33555 Mdot
.31367 .3314 Mdot
.29141 .36314 Mdot
.29108 .21611 Mdot
.6076 .32711 Mdot
.50151 .3418 Mdot
.59721 .20717 Mdot
.67608 .57761 Mdot
.37628 .44955 Mdot
.41789 .35241 Mdot
.45385 .42731 Mdot
.54551 .21626 Mdot
.56009 .5866 Mdot
.61637 .52582 Mdot
.44204 .42828 Mdot
.61577 .79623 Mdot
.60531 .82317 Mdot
.43518 .38575 Mdot
.43465 .14038 Mdot
.5069 .6558 Mdot
.60808 .74358 Mdot
.3698 .78691 Mdot
.56341 .14389 Mdot
.5163 .34673 Mdot
.15592 .57482 Mdot
.43301 .57149 Mdot
.2097 .58135 Mdot
.6777 .5548 Mdot
.3646 .2371 Mdot
.30957 .4269 Mdot
.28959 .51457 Mdot
.65154 .36742 Mdot
.75941 .59499 Mdot
.51127 .32838 Mdot
.63533 .58559 Mdot
.20431 .51211 Mdot
.37633 .57404 Mdot
.64201 .42257 Mdot
.3352 .29939 Mdot
.58095 .75454 Mdot
.42945 .76319 Mdot
.57196 .61516 Mdot
.35083 .67194 Mdot
.26798 .28026 Mdot
.85458 .60813 Mdot
.72908 .54696 Mdot
.61498 .50208 Mdot
.60272 .22744 Mdot
.19157 .56986 Mdot
.66346 .25971 Mdot
.39215 .81149 Mdot
.3968 .52131 Mdot
.52145 .52667 Mdot
.4071 .53106 Mdot
.44805 .70698 Mdot
.52686 .45474 Mdot
.55713 .28279 Mdot
.77606 .37377 Mdot
.71145 .34451 Mdot
.5746 .65592 Mdot
.65041 .23489 Mdot
.34777 .62843 Mdot
.74574 .34423 Mdot
.47316 .40131 Mdot
.43674 .76489 Mdot
.65098 .45679 Mdot
.60866 .82418 Mdot
.3845 .80289 Mdot
.59061 .36272 Mdot
.4035 .28567 Mdot
.19547 .66741 Mdot
.47968 .55811 Mdot
.56851 .50435 Mdot
.44529 .65551 Mdot
.48581 .49818 Mdot
.5224 .13418 Mdot
.19031 .54022 Mdot
.4071 .6643 Mdot
.42606 .79559 Mdot
.46394 .81421 Mdot
.883 .51107 Mdot
.36949 .20332 Mdot
.64018 .55582 Mdot
.86269 .51842 Mdot
.75192 .36753 Mdot
.49779 .84075 Mdot
.60824 .29955 Mdot
.43527 .85445 Mdot
.57517 .7441 Mdot
.1874 .58869 Mdot
.55908 .63408 Mdot
.77665 .46916 Mdot
.35186 .27496 Mdot
.56733 .49806 Mdot
.57121 .24813 Mdot
.21486 .41619 Mdot
.16703 .39318 Mdot
.42036 .69743 Mdot
.38726 .25482 Mdot
.69789 .48715 Mdot
.26562 .71665 Mdot
.24657 .40695 Mdot
.41378 .66014 Mdot
.67358 .42293 Mdot
.79635 .57487 Mdot
.38389 .52712 Mdot
.59568 .52104 Mdot
.25136 .39644 Mdot
.73753 .68475 Mdot
.35941 .60366 Mdot
.32077 .24757 Mdot
.57663 .75291 Mdot
.45277 .4509 Mdot
.49363 .58742 Mdot
.67118 .51343 Mdot
.35508 .44153 Mdot
.54748 .49339 Mdot
.41255 .63381 Mdot
.4065 .35592 Mdot
.64493 .32343 Mdot
.83039 .5012 Mdot
.70589 .38914 Mdot
.3103 .267 Mdot
.57714 .60384 Mdot
.7407 .50154 Mdot
.65433 .25316 Mdot
.83099 .46063 Mdot
.2861 .39878 Mdot
.37558 .53341 Mdot
.37115 .75704 Mdot
.52675 .82474 Mdot
.6384 .61205 Mdot
.85065 .59858 Mdot
.59025 .41344 Mdot
.40345 .73553 Mdot
.75442 .48373 Mdot
.49517 .31997 Mdot
.54078 .61045 Mdot
.18774 .5858 Mdot
.31741 .50422 Mdot
.32406 .63208 Mdot
.2512 .34983 Mdot
.51855 .51743 Mdot
.5192 .77755 Mdot
.4278 .8014 Mdot
.4567 .31846 Mdot
.27462 .28741 Mdot
.63428 .43854 Mdot
.25919 .39192 Mdot
.52749 .82736 Mdot
.73801 .72471 Mdot
.54388 .39225 Mdot
.27277 .52967 Mdot
.4526 .63548 Mdot
.30052 .25095 Mdot
.18856 .53569 Mdot
.38421 .69887 Mdot
.52607 .25153 Mdot
.6595 .52452 Mdot
.5215 .28876 Mdot
.47546 .45801 Mdot
.72815 .70323 Mdot
.66625 .51991 Mdot
.73048 .3113 Mdot
.34711 .43529 Mdot
.58742 .47084 Mdot
.53882 .56576 Mdot
.2848 .53031 Mdot
.37724 .18392 Mdot
.52711 .56519 Mdot
.25654 .67261 Mdot
.57332 .77168 Mdot
.40167 .23076 Mdot
.20432 .58931 Mdot
.6537 .30902 Mdot
.7735 .43649 Mdot
.46165 .7787 Mdot
.68713 .36394 Mdot
.48521 .65764 Mdot
.49633 .36251 Mdot
.62685 .58015 Mdot
.25378 .70694 Mdot
.64349 .74651 Mdot
.30555 .55674 Mdot
.3909 .47133 Mdot
.58614 .53746 Mdot
.64143 .44717 Mdot
.412 .83793 Mdot
.77604 .44601 Mdot
.3548 .52154 Mdot
.44919 .47329 Mdot
.27123 .54359 Mdot
.63297 .64293 Mdot
.7218 .75305 Mdot
.55985 .64432 Mdot
.4988 .42608 Mdot
.64572 .6225 Mdot
.25671 .35616 Mdot
.24067 .70936 Mdot
.41216 .53295 Mdot
.57547 .45251 Mdot
.326 .48274 Mdot
.66302 .27553 Mdot
.38405 .45929 Mdot
.5825 .51953 Mdot
.42062 .42144 Mdot
.52845 .2311 Mdot
.73956 .52444 Mdot
.38847 .57792 Mdot
.30069 .63031 Mdot
.38821 .77234 Mdot
.40662 .22218 Mdot
.67408 .36985 Mdot
.54795 .32602 Mdot
.68596 .73951 Mdot
.46114 .8695 Mdot
.74884 .30205 Mdot
.4488 .63414 Mdot
.66551 .4173 Mdot
.26033 .51711 Mdot
.43176 .32883 Mdot
.71719 .33382 Mdot
.68307 .29625 Mdot
.61484 .41577 Mdot
.3044 .50503 Mdot
.33549 .62928 Mdot
.41258 .269 Mdot
.23792 .49773 Mdot
.66205 .45274 Mdot
.83354 .48267 Mdot
.18262 .44487 Mdot
.19277 .57283 Mdot
.57972 .87565 Mdot
.65567 .41089 Mdot
.3916 .68242 Mdot
.57325 .69213 Mdot
.56025 .83307 Mdot
.31681 .52804 Mdot
.75364 .63142 Mdot
.61816 .2674 Mdot
.42033 .52909 Mdot
.71614 .52878 Mdot
.31463 .63369 Mdot
.5155 .28408 Mdot
.52943 .44148 Mdot
.29117 .36864 Mdot
.8574 .59517 Mdot
.49982 .76587 Mdot
.37704 .76955 Mdot
.79849 .55778 Mdot
.27974 .25079 Mdot
.5526 .83546 Mdot
.30921 .59867 Mdot
.23866 .42654 Mdot
.5355 .69572 Mdot
.56886 .42602 Mdot
.61463 .62658 Mdot
.74852 .62314 Mdot
.57308 .79816 Mdot
.34685 .32017 Mdot
.62958 .63324 Mdot
.37893 .55535 Mdot
.60355 .79158 Mdot
.57568 .45149 Mdot
.53395 .79204 Mdot
.41749 .28338 Mdot
.77481 .39104 Mdot
.65028 .60116 Mdot
.33 .54962 Mdot
.57392 .77746 Mdot
.57936 .22005 Mdot
.20648 .43761 Mdot
.23654 .28085 Mdot
.35864 .39988 Mdot
.82227 .47815 Mdot
.40775 .59791 Mdot
.89958 .47317 Mdot
.30663 .30098 Mdot
.34975 .28162 Mdot
.25486 .33663 Mdot
.39656 .38589 Mdot
.44746 .71764 Mdot
.48578 .65726 Mdot
.28017 .68455 Mdot
.47804 .75816 Mdot
.68786 .64619 Mdot
.76715 .58306 Mdot
.28961 .50746 Mdot
.36256 .55186 Mdot
.31046 .57066 Mdot
.54622 .547 Mdot
.65558 .52728 Mdot
.85346 .49454 Mdot
.53787 .3887 Mdot
.38269 .69418 Mdot
.52068 .55037 Mdot
.54743 .68127 Mdot
.19361 .69487 Mdot
.60099 .45809 Mdot
.3575 .68095 Mdot
.53985 .76891 Mdot
.65099 .60967 Mdot
.67088 .26379 Mdot
.80487 .73101 Mdot
.91523 .47536 Mdot
.64522 .58772 Mdot
.43411 .19945 Mdot
.52829 .77089 Mdot
.389 .74864 Mdot
.29902 .39005 Mdot
.51181 .24402 Mdot
.39612 .72253 Mdot
.74048 .57189 Mdot
.54811 .58894 Mdot
.31084 .29205 Mdot
.6337 .81623 Mdot
.76037 .58471 Mdot
.42262 .79301 Mdot
.46208 .69799 Mdot
.54485 .58069 Mdot
.55285 .88711 Mdot
.32884 .70075 Mdot
.52584 .61423 Mdot
.58459 .63715 Mdot
.41306 .56011 Mdot
.48534 .62297 Mdot
.22381 .60731 Mdot
.17693 .39679 Mdot
.35765 .6066 Mdot
.41629 .77855 Mdot
.69404 .531 Mdot
.40151 .33903 Mdot
.63503 .40032 Mdot
.54715 .39572 Mdot
.52393 .58607 Mdot
.59689 .41215 Mdot
.4636 .50584 Mdot
.19665 .65944 Mdot
.39814 .45797 Mdot
.22385 .33563 Mdot
.49776 .85815 Mdot
.62612 .75594 Mdot
.68292 .30759 Mdot
.4742 .55817 Mdot
.43112 .7664 Mdot
.54674 .81204 Mdot
.57 .52905 Mdot
.17151 .53351 Mdot
.69971 .18319 Mdot
.65478 .28475 Mdot
.7185 .72115 Mdot
.60962 .58181 Mdot
.42105 .43499 Mdot
.49858 .77835 Mdot
.60942 .30453 Mdot
.42927 .37513 Mdot
.48823 .68751 Mdot
.59642 .5534 Mdot
.58077 .40518 Mdot
.4498 .12997 Mdot
.40776 .62967 Mdot
.70146 .309 Mdot
.47532 .83077 Mdot
.72838 .65092 Mdot
.6034 .7187 Mdot
.5131 .60315 Mdot
.71155 .46914 Mdot
.57488 .45308 Mdot
.2482 .67193 Mdot
.75615 .69263 Mdot
.37179 .74382 Mdot
.64025 .74992 Mdot
.52086 .77617 Mdot
.49187 .58752 Mdot
.29232 .42945 Mdot
.5821 .34124 Mdot
.26053 .66091 Mdot
.4344 .55246 Mdot
.55071 .84444 Mdot
.50935 .32222 Mdot
.45561 .48228 Mdot
.61064 .46943 Mdot
.87817 .51418 Mdot
.58537 .66636 Mdot
.58467 .60658 Mdot
.8318 .46525 Mdot
.49278 .30797 Mdot
.25551 .48423 Mdot
.47113 .32394 Mdot
.45442 .55308 Mdot
.64709 .51598 Mdot
.83015 .39755 Mdot
.25658 .63959 Mdot
.58052 .24751 Mdot
.53489 .26078 Mdot
.44916 .21418 Mdot
.638 .42753 Mdot
.60028 .8703 Mdot
.3119 .31598 Mdot
.83966 .43077 Mdot
.26743 .28381 Mdot
.60412 .53899 Mdot
.18965 .46949 Mdot
.53329 .58077 Mdot
.43433 .37599 Mdot
.39015 .75942 Mdot
.39116 .6922 Mdot
.78281 .63015 Mdot
.47135 .57147 Mdot
.82041 .57708 Mdot
.34307 .47734 Mdot
.3834 .29594 Mdot
.26772 .3455 Mdot
.55546 .68034 Mdot
.34304 .78782 Mdot
.64969 .25915 Mdot
.35753 .78914 Mdot
.32044 .76246 Mdot
.44475 .81502 Mdot
.7806 .61652 Mdot
.63794 .19169 Mdot
.25935 .35869 Mdot
.20172 .60436 Mdot
.56652 .29799 Mdot
.53764 .67457 Mdot
.29459 .32717 Mdot
.58095 .55583 Mdot
.72926 .38552 Mdot
.65892 .44314 Mdot
.42395 .0894 Mdot
.34338 .57416 Mdot
.59085 .59323 Mdot
.28977 .34017 Mdot
.49175 .8302 Mdot
.54382 .6908 Mdot
.21932 .40738 Mdot
.4894 .45899 Mdot
.39855 .67323 Mdot
.57657 .79575 Mdot
.40734 .2176 Mdot
.37877 .27664 Mdot
.21749 .27865 Mdot
.20354 .41001 Mdot
.55178 .23845 Mdot
.51537 .45052 Mdot
.6492 .5876 Mdot
.60503 .19879 Mdot
.29962 .35989 Mdot
.16869 .5153 Mdot
.1869 .62181 Mdot
.32403 .69689 Mdot
.29899 .21176 Mdot
.38346 .23687 Mdot
.58804 .82809 Mdot
.18735 .48964 Mdot
.64371 .58853 Mdot
.29777 .5903 Mdot
.48039 .39063 Mdot
.56943 .2652 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0VOooool2o`000:kooooo000Looooo`03o`000?oooooooooo08Kooooo0_l0
000Aooooo`;o0000[_ooool001cooooo00?o0000ooooooooool0Q_ooool2o`000<7ooooo000Loooo
o`03o`000?oooooooooo0:Oooooo0_l0002Pooooo`007?ooool2o`000:Sooooo0_l0002Pooooo`00
7?ooool00ol0003oooooooooo`2Rooooo`;o0000YOooool001cooooo00?o0000ooooooooool0X_oo
ool2o`0000kooooo0_l0002Eooooo`007?ooool00ol0003oooooooooo`2]ooooo`;o00000oooool2
o`0009Gooooo000Looooo`03o`000?oooooooooo0:3ooooo0_l0000;ooooo`;o00002oooool2o`00
08gooooo000Looooo`03o`000?oooooooooo0:3ooooo0_l0000Hooooo`;o0000SOooool001cooooo
00?o0000ooooooooool0W?ooool2o`000:_ooooo000Looooo`03o`000?oooooooooo09cooooo0_l0
002[ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0;7ooooo0_l0002Fooooo`007?ooool00ol0003oooooooooo`2>ooooo`;o00008Oooool2o`0009Ko
oooo000Looooo`03o`000?oooooooooo08kooooo0_l0000Fooooo`;o00001oooool2o`0009Sooooo
000Looooo`03o`000?oooooooooo0:Kooooo0_l00007ooooo`;o0000V?ooool001cooooo00?o0000
ooooooooool0Poooool2o`0000Cooooo0_l0002nooooo`007?ooool00ol0003oooooooooo`23oooo
o`;o00001?ooool2o`0002Sooooo0_l0002Dooooo`007?ooool00ol0003oooooooooo`2cooooo`Co
0000T_ooool001cooooo00?o0000ooooooooool0Moooool2o`0001gooooo0_l0000Mooooo`;o0000
T_ooool001cooooo0_l0001hooooo`;o00001Oooool2o`0001Kooooo0_l0002aooooo`007?ooool0
0ol0003oooooooooo`1nooooo`;o0000AOooool2o`0001Kooooo0_l0001Zooooo`007?ooool00ol0
003oooooooooo`24ooooo`;o00003Oooool2o`00033ooooo0_l0000Fooooo`;o0000J_ooool001co
oooo00?o0000ooooooooool0Q?ooool2o`0000Oooooo0_l00004ooooo`;o0000]?ooool001cooooo
00?o0000ooooooooool0SOooool2o`0000Kooooo0_l00005ooooo`;o00008_ooool2o`0008Oooooo
000Looooo`03o`000?oooooooooo08oooooo0_l00004ooooo`;o00001Oooool2o`0002;ooooo0_l0
0027ooooo`007?ooool00ol0003oooooooooo`22ooooo`;o00001Oooool2o`0000Cooooo0_l0000?
ooooo`;o00001oooool2o`0000;ooooo0_l00004ooooo`;o0000U?ooool001cooooo00?o0000oooo
ooooool0MOooool2o`0000Sooooo0_l000000ooooooo0000o`000005ooooo`;o00002Oooool2o`00
00[ooooo0_l00007ooooo`;o00000_ooool2o`0000Cooooo0_l0000@ooooo`Co0000P?ooool001co
oooo00?o0000ooooooooool0MOooool2o`0000?ooooo0_l00003ooooo`;o00004oooool2o`0000oo
oooo1?l000000ooooooo0000o`00000:ooooo`;o00003Oooool4o`00083ooooo000Looooo`03o`00
0?oooooooooo07Cooooo0_l00004ooooo`;o00000oooool2o`000003ooooool0003o0000013ooooo
0_l0000?ooooo`Co000000?oooooo`000?l000002_ooool2o`00097ooooo000Looooo`03o`000?oo
oooooooo06[ooooo0_l00008ooooo`;o000000?oooooo`000?l000001_ooool2o`000003ooooool0
003o000000;ooooo0_l0000Dooooo`Co00004Oooool2o`0000cooooo0_l0000Nooooo`;o0000J?oo
ool001cooooo00?o0000ooooooooool0J_ooool2o`0000_ooooo0_l0000=ooooo`;o00005?ooool4
o`0000;ooooo0_l00007ooooo`;o00001?ooool2o`0000cooooo0_l0000Nooooo`;o0000J?ooool0
01cooooo00?o0000ooooooooool0LOooool2o`0001Oooooo0_l000001?oooooo0000o`000?l0000B
ooooo`;o00000_ooool2o`0000?ooooo0_l00005ooooo`;o00003_ooool2o`0008Gooooo00001_oo
ooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003ooooooooo
o`1aooooo`;o00002oooool2o`0000[ooooo0_l000001?oooooo0000o`000?l00005ooooo`;o0000
00?oooooo`000?l000002?ooool2o`0000;ooooo0_l0000:ooooo`;o00003_ooool4o`0000Gooooo
0_l0001looooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0Goooool2o`0001Sooooo0_l00003oooo
o`;o00001oooool2o`0000Wooooo0_l000001?oooooo0000o`000?ooool2o`0000Sooooo0_l0000D
ooooo`;o00002_ooool2o`0000Gooooo0_l00002ooooo`;o0000N?ooool00003ooooool@413ooooo
00;ooooo00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo
05oooooo0_l0000Hooooo`?o00002oooool4o`0000Oooooo0_l0000Oooooo`;o00000oooool2o`00
00?ooooo0_l00002ooooo`;o00003?ooool2o`0000Gooooo0_l0001aooooo`0000?oooooo`000?oo
ool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0001jooooo`;o
00001oooool2o`0000Cooooo0_l00005ooooo`;o00006oooool2o`0000Cooooo0_l00008ooooo`;o
00000_ooool2o`0000?ooooo0_l0000>ooooo`;o0000LOooool00003ooooool0003ooooo00;ooooo
00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo07;ooooo
1?l0000=ooooo`;o00000oooool2o`0000Kooooo0_l0000Eooooo`So000000Coooooo`000?l0003o
00004oooool2o`00087ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1booooo`Co00001?ooool2o`0000cooooo
0ol00008ooooo`;o00004_ooool7o`0000;ooooo1?l0000:ooooo`;o00002Oooool2o`0007kooooo
00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4006oooo
o`03o`000?oooooooooo05gooooo1?l0000Fooooo`;o000000?oooooo`000?l000002_ooool2o`00
0003ooooool0003o000000Sooooo0_l0000?ooooo`;o00000oooool2o`000003ooooool0003o0000
00Cooooo0_l0000:ooooo`;o00002?ooool3o`0000gooooo0_l0001_ooooo`0000Koooooonk^k_lb
<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooooooo
o`1Mooooo`Co00005_ooool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`Co00001_oo
ool2o`0000?ooooo0_l0000?ooooo`;o00001_ooool2o`0001[ooooo0_l00006ooooo`;o00001_oo
ool2o`0006oooooo000Looooo`03o`000?oooooooooo05_ooooo0_l0000Sooooo`?o000000?ooooo
o`000?l000001_ooool4o`0000?ooooo0_l0000<ooooo`;o00002_ooool2o`0000gooooo0_l00008
ooooo`Co00001_ooool2o`0000_ooooo0_l0001Zooooo`007?ooool00ol0003oooooooooo`1?oooo
o`;o00002_ooool2o`0001Gooooo0_l00002ooooo`;o00002Oooool2o`0000;ooooo0_l00005oooo
o`?o00003oooool2o`000003ooooool0003o000000[ooooo0_l00009ooooo`;o00000_ooool3o`00
00Oooooo1?l000000ooooooo0000o`000002o`0000[ooooo0_l00002ooooo`;o0000J_ooool001co
oooo00?o0000ooooooooool0Coooool2o`00027ooooo0_l00002ooooo`;o00002?ooool2o`0000?o
oooo1?l00008ooooo`;o00002oooool2o`0001Sooooo0_l00003ooooo`;o00003?ooool6o`0000Co
oooo0_l00002ooooo`;o0000K_ooool001cooooo00?o0000ooooooooool0L?ooool4o`0000cooooo
0_l00005ooooo`;o00001_ooool4o`0000;ooooo0_l00003ooooo`?o00008oooool2o`0000Kooooo
0_l00005ooooo`?o00000oooool2o`0007;ooooo000Looooo`03o`000?oooooooooo073ooooo1?l0
000;ooooo`Co00003?ooool2o`0000Cooooo0ol00002ooooo`?o00007_ooool2o`0000?ooooo0_l0
0006ooooo`;o00001_ooool2o`0000Oooooo0_l00008ooooo`;o0000I?ooool001cooooo00?o0000
ooooooooool0G?ooool2o`00013ooooo0_l0000?ooooo`Co00004Oooool5o`0000oooooo0_l0000A
ooooo`;o00003Oooool2o`0000gooooo0_l00008ooooo`;o0000I?ooool001cooooo00?o0000oooo
ooooool0G?ooool2o`00013ooooo0_l00006ooooo`;o000000?oooooo`000?l000005?ooool2o`00
00?ooooo0_l000000ooooooo0000o`000004ooooo`;o00002Oooool4o`0000Wooooo0_l0000@oooo
o`Go00000oooool2o`0007Sooooo000Looooo`03o`000?oooooooooo06[ooooo1?l000000ooooooo
0000o`000002ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Dooooo`;o00003?ooool2o`00
00_ooooo0_l00003ooooo`;o00001?ooool2o`00013ooooo1?l00004ooooo`;o0000N?ooool001co
oooo00?o0000ooooooooool0Eoooool2o`00017ooooo1?l000000ooooooo0000o`000002ooooo`;o
000000?oooooo`000?l000000oooool2o`0001Oooooo0_l0000Iooooo`Co00005oooool2o`0007go
oooo000Looooo`03o`000?oooooooooo05Oooooo0_l00008ooooo`;o00003?ooool2o`0000Gooooo
0ol00002ooooo`;o00000oooool2o`0000gooooo0_l00003ooooo`;o00003?ooool2o`0000Cooooo
0_l00007ooooo`;o00001oooool5o`0000_ooooo0_l0001mooooo`007?ooool00ol0003ooooooooo
o`1Kooooo`;o00000oooool3o`000004ooooool0003o0000ooooo`;o00003_ooool2o`0000Cooooo
0_l000000ooooooo0000o`00000:ooooo`;o000000?oooooo`000?l000004Oooool2o`000004oooo
ool0003o0000ooooo`;o00001_ooool2o`0000Cooooo2Ol000000ooooooo0000o`000002ooooo`;o
00003?ooool2o`0000oooooo0_l0001Tooooo`007?ooool2o`0005Sooooo0_l00002ooooo`_o0000
00Goooooo`000?l0003o0000ooooo`02o`0000cooooo0ol000000ooooooo0000o`000003ooooo`;o
00002?ooool2o`0000gooooo0_l00008ooooo`Co000000?oooooo`000?l000001?ooool2o`0000Co
oooo1Ol00005ooooo`;o00000_ooool2o`0000Gooooo0_l00005ooooo`?o00001?ooool2o`0000So
oooo0_l0001Tooooo`007?ooool00ol0003oooooooooo`1Gooooo`;o00000oooool4o`0000;ooooo
0ol00003ooooo`;o000000Coooooo`000?l0003o00001oooool3o`000004ooooool0003o0000o`00
00Kooooo0_l00006ooooo`;o00000_ooool2o`0000Sooooo0_l000000ooooooo0000o`000004oooo
o`;o00001?ooool2o`000003ooooool0003o000000;ooooo0_l00003ooooo`;o00005_ooool2o`00
00Cooooo1_l00002ooooo`;o0000K_ooool001cooooo00?o0000ooooooooool0Eoooool2o`0000?o
oooo0ol00006ooooo`;o00001?ooool3o`0000?ooooo0_l00002ooooo`?o00000_ooool2o`0000ko
oooo0_l00002ooooo`;o00001oooool3o`0000Oooooo0_l0000;ooooo`;o000000?oooooo`000?l0
00000_l0000@ooooo`Co00002?ooool2o`0000;ooooo0_l00002ooooo`;o0000K_ooool001cooooo
00?o0000ooooooooool0GOooool2o`0000Kooooo0_l0000:ooooo`;o00000_ooool3o`0000Gooooo
0_l000000ooooooo0000o`00000Eooooo`;o00000_ooool2o`0000Sooooo0_l00003ooooo`;o0000
0_ooool2o`000003ooooool0003o000001;ooooo1ol00003ooooo`;o00000oooool2o`0001Gooooo
0_l0001Looooo`007?ooool00ol0003oooooooooo`1fooooo`;o00001Oooool2o`000003ooooool0
003o000000oooooo0_l00008ooooo`;o000000?oooooo`000?l000001Oooool2o`0000?ooooo0_l0
0002ooooo`;o00001?ooool5o`0000cooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l0
0003ooooo`Ko00001?ooool2o`0000_ooooo0_l0001Looooo`007?ooool00ol0003oooooooooo`1Q
ooooo`;o0000;_ooool2o`0000Sooooo0_l000000ooooooo0000o`000002ooooo`?o00001?ooool2
o`0000Wooooo1Ol00002ooooo`;o00001oooool3o`0000?ooooo0_l0000:ooooo`Co00001?ooool4
o`0006Oooooo000Looooo`03o`000?oooooooooo067ooooo0_l00003ooooo`;o00003?ooool4o`00
00?ooooo0_l00005ooooo`;o000000?oooooo`000?l000000_ooool2o`0001?ooooo0_l00002oooo
o`?o00001?ooool2o`0000[ooooo0_l000000ooooooo0000o`000003o`0000Oooooo1Ol000000ooo
oooo0000o`00000?ooooo`;o00000_ooool3o`0006Oooooo000Looooo`03o`000?oooooooooo04?o
oooo0_l0000Mooooo`;o00000_ooool2o`0000cooooo1?l00003ooooo`;o00001Oooool2o`000003
ooooool0003o000000;ooooo0_l00003ooooo`;o00003_ooool4o`0000Kooooo0_l00006ooooo`;o
00000_ooool9o`000003ooooool0003o000000Oooooo0ol00002ooooo`?o00003?ooool2o`0006co
oooo000Looooo`03o`000?oooooooooo04?ooooo0_l0000Mooooo`;o00002oooool2o`0000Cooooo
1?l000000ooooooo0000o`00000Booooo`;o000000?oooooo`000?l000003Oooool2o`0000Cooooo
1?l00006ooooo`;o00000_ooool5o`0000;ooooo0_l000000ooooooo0000o`000008ooooo`;o0000
0_ooool3o`000003ooooool0003o000000;ooooo0_l0001cooooo`007?ooool00ol0003ooooooooo
o`13ooooo`;o00004_ooool2o`0000Cooooo0_l0000:ooooo`;o00001?ooool2o`0000Cooooo1?l0
00000ooooooo0000o`000002o`000003ooooool0003o0000013ooooo0_l0000Cooooo`;o00003ooo
ool2o`0001Oooooo0_l00002ooooo`;o00001Oooool4o`00017ooooo0_l0001Gooooo`007?ooool0
0ol0003oooooooooo`13ooooo`;o00001?ooool2o`0000Sooooo0_l00002ooooo`;o00001?ooool2
o`0000[ooooo0_l00003ooooo`;o00000oooool6o`0000?ooooo0_l000000ooooooo0000o`000009
ooooo`;o00001?ooool2o`0000cooooo0_l0000Aooooo`;o00002?ooool2o`00017ooooo0ol0000:
ooooo`Co00004Oooool2o`0005Oooooo000Looooo`03o`000?oooooooooo04Wooooo0_l00008oooo
o`;o00003?ooool2o`0000Cooooo0_l00005ooooo`;o00000oooool6o`0000Kooooo0_l00003oooo
o`;o00001?ooool2o`0000Cooooo0_l0000<ooooo`?o00000oooool2o`0000_ooooo0_l00003oooo
o`;o00000oooool2o`0000_ooooo0_l00004ooooo`Go00006oooool2o`0005Wooooo000Looooo`03
o`000?oooooooooo057ooooo1_l00006ooooo`;o00000_ooool2o`0000Cooooo0_l00003ooooo`;o
00001?ooool2o`0000;ooooo0_l00007ooooo`;o00000_ooool3o`0000?ooooo0_l00005ooooo`;o
00000oooool2o`0000Oooooo0ol00003ooooo`Co00002_ooool3o`000003ooooool0003o000000Oo
oooo0_l00007ooooo`;o00001oooool2o`0001_ooooo0_l0001Iooooo`007?ooool00ol0003ooooo
ooooo`1<ooooo`;o00000oooool2o`0000;ooooo0_l00006ooooo`;o00000_ooool2o`000003oooo
ool0003o000000Cooooo1?l00003ooooo`?o00001Oooool2o`0000Gooooo0_l000000ooooooo0000
o`000004ooooo`;o00002_ooool2o`0000Oooooo0ol00005ooooo`;o00002_ooool3o`0000[ooooo
1?l0000;ooooo`;o00001oooool4o`0000Wooooo0_l0001Sooooo`007?ooool00ol0003ooooooooo
o`1:ooooo`Co00002?ooool2o`0000?ooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo
0_l000000ooooooo0000o`000003ooooo`Co00001_ooool4o`0000?ooooo0_l00007ooooo`Go0000
3?ooool2o`000003ooooool0003o000000;o00008?ooool2o`0000_ooooo0_l00002ooooo`;o0000
0oooool4o`0000Kooooo1Ol00005ooooo`;o00001oooool2o`0000;ooooo0_l0001?ooooo`007?oo
ool00ol0003oooooooooo`1:ooooo`;o00002_ooool2o`0000?ooooo0_l00007ooooo`;o000000?o
ooooo`000?l000001Oooool3o`0000Sooooo1?l0000:ooooo`Oo00003?ooool2o`000003ooooool0
003o000000;o00003?ooool4o`000003ooooool0003o000000;o00006?ooool2o`000003ooooool0
003o000000Co00000oooool2o`0000Gooooo1?l00006ooooo`;o00001oooool2o`0000;ooooo0_l0
001?ooooo`007?ooool2o`0005cooooo0_l00003ooooo`;o00001oooool2o`0000?ooooo0_l00009
ooooo`;o00003?ooool2o`0000;ooooo0_l00006ooooo`?o00001oooool4o`0000cooooo1?l00000
0ooooooo0000o`000004o`0000[ooooo0_l00005ooooo`?o00001Oooool6o`0000?ooooo0_l00004
ooooo`;o000000?oooooo`000?l000001_ooool2o`000003ooooool0003o000005Wooooo000Loooo
o`03o`000?oooooooooo04Sooooo0_l00008ooooo`;o00002_ooool4o`0000Oooooo0_l00003oooo
o`;o00001_ooool2o`000003ooooool0003o000000cooooo0_l00002ooooo`;o00001_ooool6o`00
00Cooooo0_l0000Eooooo`Co00002_ooool2o`0000Cooooo1?l000000ooooooo0000o`00000Aoooo
o`;o000000?oooooo`000?l000000_ooool2o`0000Gooooo0ol00009ooooo`;o0000COooool001co
oooo00?o0000ooooooooool0Aoooool3o`0000Sooooo0_l0000:ooooo`;o000000Coooooo`000?l0
003ooooo0_l00008ooooo`;o00001_ooool2o`000003ooooool0003o0000013ooooo1?l00004oooo
o`;o000000Coooooo`000?l0003o00001Oooool2o`0000Oooooo0_l00008ooooo`;o00000_ooool2
o`0000Kooooo0_l00003ooooo`;o00001?ooool2o`000003ooooool0003o000000;o00001?ooool2
o`0000Gooooo0ol00005ooooo`;o00000oooool2o`0000Kooooo0_l00009ooooo`;o0000COooool0
01cooooo00?o0000ooooooooool0Aoooool2o`0000Sooooo0_l0000>ooooo`;o000000?oooooo`00
0?l000005Oooool2o`0000cooooo0_l00002ooooo`;o00000_ooool4o`0000?ooooo0_l00002oooo
o`Co00001oooool2o`0000Sooooo0ol000000ooooooo0000o`000006ooooo`;o00003?ooool2o`00
00;ooooo1_l00005ooooo`Go000000?oooooo`000?l000000_l00003ooooo`;o000000?oooooo`00
0?l00000GOooool001cooooo00?o0000ooooooooool0DOooool3o`0000_ooooo0_l0000Jooooo`;o
00001Oooool2o`0000Gooooo0ol000000ooooooo0000o`000006o`0000;ooooo1ol00009ooooo`;o
00001oooool4o`0000Gooooo0_l0000:ooooo`;o000000?oooooo`000?l000001Oooool4o`0000Oo
oooo1Ol000000ooooooo0000o`000007ooooo`?o0000GOooool001cooooo00?o0000ooooooooool0
D_ooool2o`0000_ooooo0_l000000ooooooo0000o`000009ooooo`;o00004oooool2o`0000Kooooo
3?l000000ooooooo0000o`000003o`0000_ooooo0_l00007ooooo`;o000000?oooooo`000?l00000
1?ooool2o`0000Sooooo2Ol000000ooooooo0000o`000007ooooo`;o00000_ooool2o`0000Gooooo
0_l000000ooooooo0000o`000003ooooo`;o0000G_ooool001cooooo00?o0000ooooooooool0COoo
ool2o`0000?ooooo0_l0000>ooooo`;o00002Oooool3o`0000Cooooo0_l0000<ooooo`;o00001?oo
ool2o`000003ooooool0003o000000go00000oooool2o`0000?ooooo0_l00002ooooo`;o00000ooo
ool2o`0000Kooooo0_l0000>ooooo`co00001oooool2o`0000Oooooo1?l000001?oooooo0000o`00
0?ooool2o`00063ooooo000Looooo`03o`000?oooooooooo04Kooooo0_l00004ooooo`?o00002ooo
ool2o`0000Wooooo0_l00006ooooo`?o00001?ooool2o`0000Cooooo0_l00006ooooo`;o00000ooo
ool8o`000003ooooool0003o000000Oo00001?ooool2o`0000?ooooo0_l00002ooooo`;o00000ooo
ool2o`0001Cooooo0_l00002ooooo`;o000000?oooooo`000?l000001?l0000Aooooo`;o00001_oo
ool3o`0005oooooo000Looooo`03o`000?oooooooooo04Kooooo0_l00004ooooo`;o00002?ooool3
o`000004ooooool0003o0000ooooo`;o00001_ooool3o`0000gooooo0_l00003ooooo`;o00002Ooo
oolDo`0000Wooooo0_l00008ooooo`Co00003Oooool2o`0000;ooooo0_l00006ooooo`Co000000?o
ooooo`000?l000003Oooool2o`0000Wooooo0_l0001Oooooo`007?ooool00ol0003oooooooooo`19
ooooo`;o00002oooool3o`0000?ooooo0ol00007ooooo`Co00002oooool2o`0000kooooo2?l00000
0ooooooo0000o`00000;o`0000Oooooo0_l00008ooooo`Go00003?ooool2o`0000?ooooo0ol00004
ooooo`;o00000oooool2o`0000gooooo0ol00002ooooo`;o0000IOooool001cooooo00?o0000oooo
ooooool0BOooool2o`00017ooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l0000C
ooooo`;o00000_oooolJo`0000Oooooo0_l00002ooooo`;o00001oooool2o`000003ooooool0003o
000000kooooo0ol0000Iooooo`;o00000_ooool2o`0000cooooo0ol0001Fooooo`007?ooool00ol0
003oooooooooo`1=ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Kooooo0_l00004oooo
o`;o000000Coooooo`000?l0003ooooo0_l0000Cooooo`;o00000_oooolJo`0000_ooooo0_l0000:
ooooo`;o000000?oooooo`000?l000002_ooool2o`0000Sooooo1?l00003ooooo`;o00004Oooool2
o`0000Oooooo1Ol0001Fooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00001_ooool5o`00
00;ooooo0ol00005ooooo`;o00005_ooool2o`0000?ooooo0_l00004ooooo`;o000000?oooooo`00
0?l000005ol0000Jooooo`;o00002_ooool2o`0000Gooooo0_l000000ooooooo0000o`000004o`00
0004ooooool0003o0000o`0000Cooooo0_l0000:ooooo`;o00001oooool4o`000003ooooool0003o
000001;ooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00002?ooool4o`00
00;ooooo0_l000000ooooooo0000o`000002o`0000gooooo0_l00009ooooo`;o00000oooool2o`00
00Cooooo0_l000001?oooooo0000o`000?oooolHo`000004ooooool0003o0000o`0000gooooo0_l0
0009ooooo`;o00003Oooool2o`0000Gooooo1_l00004ooooo`;o00000oooool2o`00013ooooo0_l0
00000ooooooo0000o`00000Booooo`;o0000@?ooool001cooooo00?o0000ooooooooool0DOooool2
o`0000Cooooo1Ol0000=ooooo`;o00001?ooool2o`0000kooooo0_l000000ooooooo0000o`00000M
o`0000gooooo0_l00009ooooo`?o00003?ooool2o`000004ooooool0003o0000ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0000;ooooo0_l00003ooooo`;o00000oooool2o`0000Wooooo0_l0
000Looooo`;o0000>oooool001cooooo00?o0000ooooooooool0DOooool4o`0000;ooooo0ol0000E
ooooo`;o00004ooooolMo`0000?ooooo0_l00008ooooo`;o00001Oooool2o`0000?ooooo1_l00005
ooooo`;o000000?oooooo`000?l000002Ol00002ooooo`Ko00000oooool2o`0000?ooooo0ol00008
ooooo`;o00007?ooool2o`0003_ooooo000Looooo`;o0000Coooool2o`0000;ooooo0ol00003oooo
o`;o00008Oooool2o`0000Gooooo0_l00002oooooa_o00000oooool2o`0000;ooooo0_l00004oooo
o`;o00001Oooool2o`0000;ooooo0_l000000ooooooo0000o`000005o`000003ooooool0003o0000
00ko00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000004ooooo`;o00001?ooool3o`00
05cooooo000Looooo`03o`000?oooooooooo04kooooo0_l00002ooooo`;o00009oooool3o`0000?o
oooo7ol00008ooooo`;o00001?ooool2o`0000Wooooo0_l00005oooooa7o000000?oooooo`000?l0
00001?ooool2o`000003ooooool0003o000000_ooooo1Ol000000ooooooo0000o`00001Iooooo`00
7?ooool00ol0003oooooooooo`0oooooo`;o00001Oooool3o`0000Oooooo0_l0000Cooooo`;o0000
3_ooool2o`000003ooooool0003o000000;ooooo0_l00002oooooako00001oooool2o`0001;ooooo
0_l00005oooooa?o000000?oooooo`000?l000000_ooool3o`0000gooooo1?l00002ooooo`;o0000
2?ooool2o`0004oooooo000Looooo`03o`000?oooooooooo03cooooo0_l000001?oooooo0000o`00
0?ooool7o`0000Oooooo1?l00003ooooo`;o00001Oooool2o`0000Gooooo0_l0000:ooooo`;o0000
0_ooool2o`000003ooooool0003o000000;o00001?ooool>o`000003ooooool0003o000000oo0000
1Oooool2o`0000Kooooo1?l00008ooooo`;o00000_oooolIo`0000?ooooo0_l000000ooooooo0000
o`00000<ooooo`;o00001Oooool2o`0000Gooooo0_l0000Oooooo`;o0000;_ooool001cooooo00?o
0000ooooooooool0??ooool2o`0000Cooooo1?l0000;ooooo`?o00000oooool2o`0000;ooooo0_l0
00000ooooooo0000o`00000Aooooo`;o00000_ooool2o`0000?ooooo0_l00008oooooa3o000000?o
ooooo`000?l000002Ol0000=ooooo`Co00002oooool4o`000003ooooool0003o0000017o00002?oo
ool2o`0000[ooooo0_l00007ooooo`;o00009_ooool2o`0002kooooo000Looooo`03o`000?oooooo
oooo03cooooo0_l0000Hooooo`;o000000?oooooo`000?l000000_l0000Hooooo`;o00003?oooolL
o`0000kooooo0_l00004ooooo`;o00001OoooolIo`0000Gooooo1_l0000:ooooo`?o00000_ooool2
o`0005[ooooo000Looooo`03o`000?oooooooooo05Kooooo0_l000000ooooooo0000o`000002o`00
00Oooooo0_l0000Eooooo`;o00001_oooolFo`0000;ooooo1?l0000>ooooo`;o00001?ooool2o`00
00Gooooo0_l00002oooooaOo00000oooool6o`0000?ooooo1?l00004ooooo`Ko000000?oooooo`00
0?l00000Eoooool001cooooo00?o0000ooooooooool0Foooool2o`0000Oooooo0_l0000:ooooo`;o
00002Oooool2o`0000Gooooo4ol000000ooooooo0000o`000005o`0001Oooooo0_l00005oooooa[o
00000_ooool4o`000004ooooool0003o0000ooooo`Ko00001_ooool2o`0000?ooooo0_l0000;oooo
o`;o0000B_ooool001cooooo00?o0000ooooooooool0Coooool2o`0000oooooo0_l0000>ooooo`;o
000000?oooooo`000?l000003OoooolKo`00017ooooo0_l00004ooooo`;o00001OoooolIo`0000?o
oooo1?l00004ooooo`Co00000oooool2o`0000Sooooo0_l000000ooooooo0000o`000003ooooo`;o
00000oooool2o`0004[ooooo000Looooo`03o`000?oooooooooo03oooooo0_l0000>ooooo`;o0000
3oooool2o`00017ooooo0_l00004ooooo`?o00000_ooool2o`000003ooooool0003o000001[o0000
4Oooool4o`0000;ooooo0_l00004ooooo`Wo000000?oooooo`000?l000000ol000000ooooooo0000
o`000006o`0000Gooooo0_l0000=ooooo`;o00002oooool2o`0000?ooooo0_l0001?ooooo`007?oo
ool00ol0003oooooooooo`0oooooo`;o00004oooool2o`0002?ooooo1ol000000ooooooo0000o`00
000Jo`000003ooooool0003o0000013ooooo0ol000000ooooooo0000o`000002oooooa[o00001Ooo
ool2o`0000?ooooo0_l0001[ooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o00007Oooool2
o`0000Oooooo0_l00006ooooo`ko000000Goooooo`000?l0003o0000ooooo`03o`000003ooooool0
003o000000?o00004?ooool3o`000004ooooool0003o0000oooooaco00001?ooool4o`000003oooo
ool0003o000000Kooooo0_l00004ooooo`?o00002?ooool2o`0005;ooooo000Looooo`03o`000?oo
oooooooo04Oooooo0_l00007ooooo`;o00004?ooool2o`0000oooooo0_l00007ooooo`?o00001?oo
oolGo`0000;ooooo0ol0000Aooooo`;o00000_ooool2o`000004ooooool0003o0000oooooaWo0000
0_ooool6o`0000Wooooo0_l00003ooooo`Co00002?ooool2o`00013ooooo0_l00010ooooo`007?oo
ool00ol0003oooooooooo`0kooooo`;o000000?oooooo`000?l000001oooool3o`0000Kooooo0_l0
0008ooooo`;o000000?oooooo`000?l000000oooool2o`00013ooooo0_l00002ooooo`;o00000_oo
ool3o`0000;ooooo6Ol00003ooooo`;o00002Oooool2o`000003ooooool0003o000000Gooooo0_l0
00000ooooooo0000o`000002o`000003ooooool0003o000001Co00001Oooool6o`0000Kooooo0_l0
0006ooooo`;o000000?oooooo`000?l000004?ooool2o`0000Oooooo0_l00010ooooo`0000Kooooo
onk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo
00?o0000ooooooooool0<oooool2o`0000Kooooo0_l000000ooooooo0000o`000002ooooo`;o0000
0oooool3o`000003ooooool0003o000000?ooooo0_l00008ooooo`;o000000?oooooo`000?l00000
4oooool4o`0000;ooooo0_l00003ooooo`;o00000_oooolCo`000003ooooool0003o000000?o0000
3_ooool2o`000003ooooool0003o000000?o00000_ooool2o`000004ooooool0003o0000oooooaOo
00004_ooool2o`0000Wooooo0_l000000ooooooo0000o`000007ooooo`;o00001?ooool4o`0004Oo
oooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0<oooool2o`000003ooooool0003o000000Wooooo0ol00007oooo
o`;o000000?oooooo`000?l000000_l0000@ooooo`;o00003_ooool3o`0000;ooooo0_l00007oooo
oaWo00005?ooool3o`0000Sooooo6?l00002ooooo`;o00001?ooool2o`000003ooooool0003o0000
00Kooooo0_l0000:ooooo`;o00001oooool2o`0000Kooooo0_l00006ooooo`;o0000?oooool00003
ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool5o`0000Kooooo00?o0000oooooooo
ool0=_ooool2o`0000Wooooo0ol0000:ooooo`;o00002Oooool2o`0000Gooooo1?l0000=ooooo`Co
00000_ooool2o`0000Oooooo0_l00002oooooa?o00005_ooool3o`0000Wooooo6ol00004ooooo`;o
000000?oooooo`000?l000000_l00004ooooo`;o00008oooool4o`0003gooooo00000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`0003Go
oooo0_l00006ooooo`;o00000oooool2o`0001Gooooo0_l00005ooooo`;o00001Oooool2o`0000So
oooo0_l00002ooooo`;o00001oooool2o`0000Oooooo2ol000000ooooooo0000o`000003o`0001Go
oooo0_l00005ooooo`;o000000?oooooo`000?l000005_l000000ooooooo0000o`00000;ooooo`;o
00004oooool2o`0000Oooooo0_l00004ooooo`;o00001_ooool5o`0003_ooooo00000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003o
ooooooooo`0eooooo`;o00001_ooool4o`00017ooooo0_l0000Cooooo`;o00002Oooool2o`000003
ooooool0003o000000Oooooo0_l00004ooooo`;o000000?oooooo`000?l000002Ol000001?oooooo
0000o`000?ooool2o`0001cooooo0_l000000ooooooo0000o`00000Go`0000Sooooo0_l00007oooo
o`;o00003Oooool4o`0000Oooooo0_l00004ooooo`;o00002Oooool2o`0003_ooooo00000ooooooo
410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?oMgMgolc<c?l000001oooool00ol0003o
ooooooooo`0`ooooo`;o00003Oooool2o`0000?ooooo1_l00002ooooo`Co00000_ooool2o`0001;o
oooo1Ol00006ooooo`?o00002_ooool2o`0000Cooooo0_l000000ooooooo0000o`000004o`0002co
oooo1Ol000000ooooooo0000o`00000?o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l0
00001?ooool2o`0000gooooo0_l00003ooooo`?o00001_ooool2o`0004Wooooo00001_ooooooMgMg
oiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0`oooo
o`Co00000oooool2o`0000Gooooo0_l00004ooooo`Ko00000_ooool4o`0000?ooooo0_l0000@oooo
o`Ko00001_ooool2o`0000Oooooo0_l0000?ooooo`;o000000?oooooo`000?l000000_ooool7o`00
01gooooo0_l00002oooooaGo00000_ooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2
o`0000Wooooo0_l0000=ooooo`?o00000oooool5o`0000?ooooo0_l00014ooooo`0000Koooooonk^
k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0<_oo
ool2o`0000?ooooo1?l00003ooooo`Co00004Oooool2o`0000Gooooo0_l00007ooooo`Wo00001_oo
ool2o`0000Kooooo0_l0000Booooo`;o00000_ooool7o`000003ooooool0003o000000;o00002?oo
ool2o`0000cooooo1Ol000000ooooooo0000o`00000Ao`0000Cooooo0_l00004ooooo`;o00003Ooo
ool2o`0000cooooo0_l00005ooooo`Co00001?ooool2o`0004Cooooo000Looooo`03o`000?oooooo
oooo03Wooooo0_l00005ooooo`Co00005Oooool3o`0000Oooooo1Ol00002ooooo`Co00001?ooool2
o`0000Kooooo0_l0000Nooooo`Co00002?ooool2o`0000Sooooo0_l00002ooooo`;o000000?ooooo
o`000?l000004_l00003ooooo`;o00001?ooool2o`000003ooooool0003o000000Oooooo0_l0000B
ooooo`;o00004_ooool2o`0000_ooooo0_l0000booooo`007?ooool00ol0003oooooooooo`0^oooo
o`;o00001_ooool2o`000003ooooool0003o000000Oooooo0_l0000@ooooo`;o00000_ooool3o`00
00?ooooo0ol00002ooooo`Co000000?oooooo`000?l000001?l0000Gooooo`;o00008?ooool2o`00
00Gooooo1?l00006ooooo`Co000000?oooooo`000?l000002Ol00006ooooo`;o00001?ooool2o`00
00[ooooo0_l0000Iooooo`;o00002oooool2o`0000_ooooo0_l0000booooo`007?ooool00ol0003o
ooooooooo`0^ooooo`;o00001_ooool2o`000003ooooool0003o000000?o00005Oooool3o`000005
ooooool0003o0000o`000?ooool00_l000000ooooooo0000o`00000<o`0000Gooooo0_l0000Boooo
o`;o00008?ooool2o`0000Gooooo0_l0000;ooooo`ko00001?ooool2o`0000Sooooo0_l00004oooo
o`;o00006Oooool6o`0004_ooooo000Looooo`03o`000?oooooooooo03Oooooo0_l000000ooooooo
0000o`000002o`0000Wooooo0_l000000ooooooo0000o`000007ooooo`;o00000_ooool3o`000004
ooooool0003o0000ooooo`oo000000Coooooo`000?l0003ooooo0_l0000Mooooo`;o00003?ooool2
o`0000Cooooo0_l00006ooooo`?o00000oooool2o`000004ooooool0003o0000o`0000?ooooo3_l0
00000ooooooo0000o`000003o`0000Sooooo0_l00004ooooo`Co00005oooool3o`000003ooooool0
003o000000Kooooo0_l00013ooooo`007?ooool00ol0003oooooooooo`0gooooo`;o00001Oooool2
o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000002oooool2o`0000;ooooo0_l00000
0ooooooo0000o`00000@o`0000gooooo0_l0000=ooooo`;o00000_ooool2o`0000cooooo0_l00004
ooooo`;o00001_ooool4o`0000;ooooo0_l000001?oooooo0000o`000?l00006ooooo`;o000000?o
ooooo`000?l000001Ol00002ooooo`?o00000_ooool3o`0000Kooooo0_l00003ooooo`Co00006ooo
ool2o`0000Kooooo0_l00007ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0?Oooool4
o`0000;ooooo0_l0000Aoooooa[o00003Oooool2o`0000gooooo0_l0000=ooooo`;o000000?ooooo
o`000?l000003_ooool2o`0000Cooooo1?l00004ooooo`;o000000?oooooo`000?l000000_ooool5
o`0000Oooooo0ol00002ooooo`Ko00000oooool2o`0001Kooooo1?l00003ooooo`;o00003oooool2
o`0000Gooooo0_l0000cooooo`007?ooool00ol0003oooooooooo`0mooooo`Co00000oooool2o`00
00Wooooo0_l00005ooooo`;o000000?oooooo`000?l000005Ol00003ooooo`Co00003_ooool2o`00
00gooooo0_l00004ooooo`Ko00000oooool2o`0000oooooo1?l00004ooooo`;o000000?oooooo`00
0?l000004Oooool8o`0000Sooooo0_l000000ooooooo0000o`00000>ooooo`Co00002_ooool2o`00
00oooooo0_l0000cooooo`007?ooool00ol0003oooooooooo`0oooooo`;o00000oooool3o`0000So
oooo0_l00003ooooo`;o00001?oooolHo`000003ooooool0003o000000;o00003?ooool4o`0000Ko
oooo0_l00005ooooo`;o00000_ooool6o`0000Gooooo0_l0000=ooooo`;o000000?oooooo`000?l0
00004oooool2o`0000;ooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00002_ooool2o`00
0003ooooool0003o000000kooooo1?l00007ooooo`;o000000?oooooo`000?l000004oooool2o`00
02oooooo000Looooo`03o`000?oooooooooo02kooooo0_l00003ooooo`;o00001Oooool2o`0000?o
oooo0_l00004ooooo`;o00003Oooool2o`000003ooooool0003o000001Wo00002?ooool2o`0000Co
oooo0_l000000ooooooo0000o`000008ooooo`;o00002Oooool2o`0000kooooo0_l00008ooooo`;o
00001?ooool2o`000004ooooool0003o0000ooooo`;o00001Oooool2o`0000?ooooo0_l00002oooo
o`;o000000Goooooo`000?l0003o0000ooooo`03o`0000Cooooo0_l00007ooooo`;o00001_ooool2
o`0000Kooooo0_l00009ooooo`;o00005_ooool2o`0002oooooo000Looooo`03o`000?oooooooooo
02kooooo0_l00003ooooo`;o000000?oooooo`000?l000001?l0000Ioooooa[o000000?oooooo`00
0?l000001Oooool2o`000003ooooool0003o000000;o00000_ooool2o`0000_ooooo0_l00002oooo
o`;o00005Oooool2o`0000Sooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o
000000?o00001Oooool2o`0000_ooooo1Ol00005ooooo`;o00003oooool3o`000003ooooool0003o
000000?ooooo1?l0001?ooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00001?ooool4o`00
0003ooooool0003o000000Wooooo0_l00007ooooo`;o00001?ooool2o`0000?ooooo6?l00003oooo
o`Co00000oooool2o`0000;ooooo0_l00005ooooo`;o00001?ooool2o`0000;ooooo0_l00002oooo
o`;o00005_ooool2o`0000Kooooo0_l00004ooooo`Ko000000?oooooo`000?l000000_ooool2o`00
00Gooooo0_l00005ooooo`;o00001?ooool2o`0000gooooo0_l00003ooooo`;o000000?oooooo`00
0?l000000oooool4o`0004oooooo000Looooo`;o00007oooool2o`00013ooooo0_l00009ooooo`;o
00002Oooool2o`0000Oooooo0_l00003ooooo`;o00001?oooolJo`000004ooooool0003o0000o`00
00Sooooo0_l00005ooooo`;o00001_ooool4o`0000;ooooo0_l0000=ooooo`;o00001oooool2o`00
0003ooooool0003o000000Gooooo0_l00006ooooo`;o000000?oooooo`000?l000000_ooool2o`00
00Gooooo0_l0000;ooooo`;o00001Oooool2o`0000Kooooo0_l00008ooooo`;o000000Coooooo`00
0?l0003o00001Oooool2o`0000cooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0Noooo
o`;o00006Oooool2o`000003ooooool0003o000000;o00005?ooool2o`0000?ooooo6ol00005oooo
o`;o000000?oooooo`000?l000002oooool2o`0000Cooooo0_l0000Cooooo`;o000000?oooooo`00
0?l000001oooool2o`0000Gooooo0_l00002ooooo`;o00001Oooool2o`0000;ooooo0_l0000;oooo
o`;o00002?ooool2o`0000;ooooo0_l00006ooooo`;o00002?ooool2o`0000;ooooo0_l00003oooo
o`Co00000_ooool2o`0000Sooooo0_l0000kooooo`007?ooool00ol0003oooooooooo`0iooooo`;o
000000?oooooo`000?l000000_l00002ooooo`;o00005OoooolIo`0000Oooooo0_l000000ooooooo
0000o`000002o`0000Wooooo0_l0000<ooooo`;o00001_ooool3o`0000Cooooo1Ol00005ooooo`;o
00001Oooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000003?ooool2o`000003
ooooool0003o000000Sooooo0_l0000:ooooo`;o00003_ooool2o`000003ooooool0003o000000Co
oooo0_l00008ooooo`;o0000>oooool001cooooo00?o0000ooooooooool0@_ooool2o`0000?ooooo
0_l00002ooooo`;o00002OoooolJo`0000Wooooo0_l00002ooooo`?o00002Oooool2o`0000cooooo
0_l000001?oooooo0000o`000?l00002ooooo`?o00001?ooool2o`000003ooooool0003o000000Go
oooo0_l0000<ooooo`?o000000?oooooo`000?l000003?ooool5o`0001Cooooo0_l00009ooooo`Oo
00003oooool4o`0003_ooooo000Looooo`03o`000?oooooooooo01oooooo0_l0000Iooooo`;o0000
2oooool3o`000003ooooool0003o000000;o00001ooooolJo`0000Wooooo0_l00002ooooo`Co0000
5_ooool2o`000004ooooool0003o0000o`0000;ooooo0ol00006ooooo`;o00004Oooool2o`000003
ooooool0003o000000Wooooo0_l00006ooooo`;o00001?ooool2o`0000Sooooo0_l000001?oooooo
0000o`000?ooool4o`0000Wooooo1_l00005ooooo`;o000000?oooooo`000?l000001_ooool2o`00
03gooooo000Looooo`03o`000?oooooooooo01oooooo0_l00009ooooo`;o00003_ooool4o`0000[o
oooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l00008oooooa3o000000Coooooo`000?l0
003o00003oooool2o`00013ooooo1?l0000:ooooo`?o00000oooool2o`000003ooooool0003o0000
017ooooo0_l000000ooooooo0000o`000009ooooo`;o00002_ooool4o`0000Sooooo0_l000000ooo
oooo0000o`000003o`0000cooooo0_l00008ooooo`;o000000?oooooo`000?l000001_ooool2o`00
0003ooooool0003o000003[ooooo000Looooo`03o`000?oooooooooo02[ooooo0_l0000>ooooo`Co
00003Oooool2o`0000;ooooo0_l000000ooooooo0000o`000007oooooa;o00002_ooool2o`0000Oo
oooo1?l00008ooooo`;o000000?oooooo`000?l000001?l0000=ooooo`Oo00003oooool2o`000003
ooooool0003o000000Kooooo0_l00006ooooo`;o00000oooool2o`0000?ooooo0ol0000:ooooo`Ko
00000oooool2o`0000_ooooo1?l0000>ooooo`;o000000?oooooo`000?l000000_l00004ooooo`Co
0000<?ooool001cooooo00?o0000ooooooooool0>_ooool2o`0000oooooo0_l00002ooooo`?o0000
2Oooool9o`000003ooooool0003o000000Ko00001Oooool2o`0000?ooooo0_l00002ooooo`;o0000
0oooool4o`0000Sooooo1ol0000?ooooo`Co000000?oooooo`000?l000002_ooool2o`0000?ooooo
1Ol00006ooooo`;o00001_ooool2o`0000?ooooo0ol0000?ooooo`Go00001?ooool4o`0000Wooooo
1Ol0000Aooooo`?o00001?ooool4o`0000Oooooo0_l0000Wooooo`007?ooool00ol0003ooooooooo
o`1;ooooo`;o00000oooool2o`0000Wooooo4Ol00006ooooo`;o00001_ooool3o`0000gooooo0_l0
0002ooooo`;o000000?oooooo`000?l000003oooool2o`0000[ooooo0_l00003ooooo`;o00001Ooo
ool2o`0001;ooooo0_l000000ooooooo0000o`000006ooooo`;o00001Oooool2o`0000?ooooo0_l0
0006ooooo`;o00003?ooool2o`0000;ooooo0_l00008ooooo`;o00000oooool2o`00013ooooo0_l0
0003ooooo`;o00008_ooool001cooooo00?o0000ooooooooool0AOooool2o`0000cooooo0_l00000
0ooooooo0000o`000002o`000003ooooool0003o0000017o00003?ooool2o`0000?ooooo1_l00005
ooooo`;o00001oooool2o`0000Wooooo0_l0000<ooooo`Co00007_ooool2o`0000;ooooo0_l00005
ooooo`;o00001Oooool2o`0001gooooo0_l00006ooooo`Co00006_ooool2o`0002;ooooo000Loooo
o`03o`000?oooooooooo03Gooooo1?l0000<ooooo`;o00001_ooool2o`0000Cooooo0_l000000ooo
oooo0000o`000002o`0000;ooooo2Ol000000ooooooo0000o`000006o`00017ooooo2Ol00008oooo
o`;o000000?oooooo`000?l000001Oooool2o`0000;ooooo0_l0000<ooooo`Co00005?ooool2o`00
00Sooooo0ol000000ooooooo0000o`000002ooooo`;o00000oooool2o`0001kooooo0_l00004oooo
o`;o00001?ooool3o`000003ooooool0003o000003cooooo000Looooo`03o`000?oooooooooo02[o
oooo0_l00009ooooo`Co00004_ooool6o`0000Kooooo0ol00005ooooo`Go00000_ooool2o`0001Ko
oooo0_l00003ooooo`Go00002?ooool2o`0000Sooooo0_l000000ooooooo0000o`00000<ooooo`;o
00001Oooool2o`00013ooooo0_l00009ooooo`;o000000Coooooo`000?l0003ooooo0ol00003oooo
o`;o00000oooool2o`0000oooooo0_l000001?oooooo0000o`000?l00004ooooo`;o00000oooool3
o`0000Gooooo0_l000000ooooooo0000o`00000=ooooo`;o0000;Oooool001cooooo00?o0000oooo
ooooool0:_ooool2o`0000Kooooo1?l000000ooooooo0000o`00000:ooooo`;o00001_ooool2o`00
00;ooooo0_l00004ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`Co000000?ooooo
o`000?l000005oooool2o`0001;ooooo0_l00009ooooo`Co000000Coooooo`000?l0003o00001Ooo
ool3o`0000Gooooo0_l0000Nooooo`;o000000?oooooo`000?l000001_ooool6o`0000kooooo0_l0
00001Ooooooo0000o`000?l0003ooooo00;o00001_ooool2o`000003ooooool0003o000000cooooo
0_l00006ooooo`?o0000;Oooool001cooooo00?o0000ooooooooool0;?ooool2o`0000Cooooo1?l0
0003ooooo`;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000:ooooo`;o000000Co
ooooo`000?l0003o00000_ooool2o`000003ooooool0003o000000;o00001?ooool2o`0000Gooooo
0_l000001?oooooo0000o`000?l00004ooooo`;o00003oooool2o`0000?ooooo0_l00004ooooo`;o
00001_ooool4o`000003ooooool0003o000000Co00001Oooool2o`0001Cooooo1?l0000Iooooo`So
00004_ooool3o`0000Wooooo0_l00002ooooo`;o00002?ooool2o`0000Kooooo0_l0000^ooooo`00
7?ooool00ol0003oooooooooo`0/ooooo`;o00002?ooool2o`000003ooooool0003o000000Cooooo
0ol000000ooooooo0000o`000003o`0000[ooooo0_l00002ooooo`;o000000?oooooo`000?l00000
1?ooool2o`0000_ooooo0_l000001?oooooo0000o`000?l00004ooooo`;o00001Oooool4o`0000Ko
oooo0_l00003ooooo`;o00001_ooool2o`0000Cooooo1?l00003ooooo`?o00002_ooool2o`000003
ooooool0003o000000Sooooo0_l00003ooooo`Co00007oooool2o`0000Cooooo0_l0000:ooooo`Co
00003_ooool2o`0000Sooooo0_l0000fooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o0000
1?ooool2o`0000Sooooo1_l00004ooooo`;o00003?ooool5o`0000cooooo0_l000001?oooooo0000
o`000?l0000>ooooo`Co00004?ooool2o`000003ooooool0003o000000;ooooo1?l00003ooooo`Go
00002_ooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`Co00001_ooool2o`0000So
oooo0_l0000Hooooo`;o00002_ooool2o`0000;ooooo0_l0000Aooooo`;o00000oooool2o`0000Co
oooo0_l0000`ooooo`007?ooool2o`00037ooooo0ol00008ooooo`;o00001Oooool2o`0000Kooooo
0_l00008ooooo`;o00000_ooool2o`000003ooooool0003o000000cooooo0_l00002ooooo`;o0000
1Oooool2o`0000?ooooo0_l000000ooooooo0000o`00000=ooooo`;o00001?ooool2o`0000Gooooo
1?l00003ooooo`Ko00003_ooool4o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`;o0000
1?ooool2o`0000;ooooo0_l00002ooooo`;o00006?ooool2o`0000;ooooo0_l00006ooooo`;o0000
00?oooooo`000?l000000oooool2o`0000Oooooo1?l00009ooooo`;o0000<?ooool001cooooo00?o
0000ooooooooool0<Oooool2o`0000Sooooo1?l00002ooooo`;o00004Oooool2o`0000Oooooo0_l0
0002ooooo`Co00003oooool2o`0000?ooooo0_l000001?oooooo0000o`000?l00002ooooo`;o0000
2?ooool2o`0001Kooooo0_l0000>ooooo`Co000000?oooooo`000?l000000_l00006ooooo`Co0000
1Oooool2o`0000Kooooo0_l0000Hooooo`;o00000_ooool2o`0000Cooooo0_l00003ooooo`;o0000
0oooool2o`0000Oooooo0_l000000ooooooo0000o`00000:ooooo`;o0000;_ooool001cooooo00?o
0000ooooooooool0>?ooool2o`0000?ooooo0_l00002ooooo`;o00002_ooool2o`0000Sooooo0_l0
00001?oooooo0000o`000?ooool8o`0000Cooooo0_l0000Booooo`;o00000_ooool3o`0000oooooo
0_l00007ooooo`;o00001Oooool2o`0000Oooooo0ol00002ooooo`;o00000_ooool2o`000004oooo
ool0003o0000o`0000Kooooo1Ol0000>ooooo`Co000000?oooooo`000?l000007?ooool2o`0000So
oooo0_l00003ooooo`;o00001Oooool2o`0000[ooooo0_l0000^ooooo`007?ooool00ol0003ooooo
ooooo`0dooooo`;o00000_ooool2o`0000Cooooo1Ol0000:ooooo`;o00002?ooool2o`000003oooo
ool0003o000000;ooooo0ol00008ooooo`;o00000oooool3o`0000cooooo0_l00003ooooo`;o0000
1_ooool4o`0000Gooooo1?l00005ooooo`;o00003_ooool3o`0000;ooooo1?l00004ooooo`?o0000
1Oooool2o`0000oooooo1_l000000ooooooo0000o`00000Oooooo`;o00002_ooool2o`0001?ooooo
0_l0000/ooooo`007?ooool00ol0003oooooooooo`0dooooo`;o000000Coooooo`000?l0003o0000
1?ooool4o`0000Gooooo0_l0000Eooooo`Co00003?ooool3o`000003ooooool0003o000000Wooooo
0_l00003ooooo`;o00001_ooool4o`0000Oooooo0_l00002ooooo`;o00005?ooool2o`0000;ooooo
0_l000000ooooooo0000o`000002ooooo`;o00005Oooool3o`0000;ooooo0_l00002ooooo`;o0000
7_ooool2o`0001gooooo1?l0000/ooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00000ooo
ool2o`0000;ooooo0_l00006ooooo`Co00001?ooool2o`0000Sooooo0_l00007ooooo`;o000000Co
ooooo`000?l0003ooooo0ol00003ooooo`;o00000_ooool4o`0000Cooooo0_l0000=ooooo`;o0000
1oooool2o`0000gooooo0_l0000Dooooo`Co00000oooool2o`0000Sooooo1?l00006ooooo`Ko0000
00Coooooo`000?l0003o00000_ooool2o`0000;ooooo0_l0000mooooo`;o0000;_ooool001cooooo
00?o0000ooooooooool0;_ooool2o`000003ooooool0003o000000;o00001_ooool2o`0000Cooooo
0_l0000>ooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000;o
oooo2Ol00009ooooo`;o00002?ooool4o`0000Gooooo0_l0000Iooooo`;o00002_ooool2o`0000Ko
oooo0_l00005ooooo`Go00001Oooool6o`0000;ooooo1Ol00002ooooo`;o00002Oooool2o`0000_o
oooo0_l0000Qooooo`;o0000<oooool001cooooo00?o0000ooooooooool0<Oooool2o`0000Sooooo
0_l0000?ooooo`;o00002Oooool2o`0000Oooooo0ol00002ooooo`;o000000?oooooo`000?l00000
0ol00003ooooo`Co00000oooool2o`0000Cooooo0_l00003ooooo`?o00001oooool2o`0001Oooooo
0_l0000Booooo`;o00000oooool2o`0000?ooooo0_l00006oooooa3o00000_ooool2o`0000Gooooo
1?l00003ooooo`;o00001?ooool2o`0001;ooooo0_l0000=ooooo`;o0000<oooool001cooooo00?o
0000ooooooooool0B_ooool4o`0000Sooooo0_l00004ooooo`;o00000_ooool3o`0000gooooo1?l0
0004ooooo`;o00000oooool2o`0000?ooooo0_l00008ooooo`;o00007?ooool2o`0001;ooooo0ol0
0003ooooo`;o00001?ooool@o`0000;ooooo0ol00007ooooo`;o00000oooool3o`0000Kooooo0_l0
00000ooooooo0000o`00000<ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0?Oooool2
o`0000_ooooo0_l0000:ooooo`;o00001?ooool2o`0000?ooooo1?l0000Aooooo`Go00001_ooool6
o`0001oooooo0ol000000ooooooo0000o`000009ooooo`;o00002?ooool2o`0000?ooooo0_l00000
1?oooooo0000o`000?oooolEo`0000Cooooo1ol00002ooooo`;o00001_ooool5o`0000Cooooo0_l0
0005ooooo`;o00005oooool2o`0002[ooooo000Looooo`03o`000?oooooooooo02kooooo0_l00008
ooooo`;o00000oooool2o`0000Cooooo0_l0000:ooooo`;o00001?ooool2o`0000;ooooo0_l00000
0ooooooo0000o`000005ooooo`?o00004?ooool5o`0000;ooooo0_l000000ooooooo0000o`000005
o`0001oooooo0ol00003ooooo`;o00000oooool2o`0000;ooooo0_l0000@ooooo`Wo000000?ooooo
o`000?l000002Ol00002ooooo`;o00000_ooool8o`0000;ooooo1?l00006ooooo`;o00001Oooool2
o`0000Gooooo0_l0000Gooooo`;o0000:_ooool001cooooo00?o0000ooooooooool0;_ooool3o`00
00?ooooo0_l00002ooooo`Co00001oooool2o`0000[ooooo0_l00004ooooo`;o00000_ooool2o`00
00Wooooo0_l00007ooooo`;o00001oooool3o`0000Cooooo0_l000000ooooooo0000o`000002o`00
01Sooooo0_l00008ooooo`?o00000oooool2o`0000?ooooo1Ol00002ooooo`;o00001Oooool2o`00
00?ooooo6Ol000000ooooooo0000o`000002ooooo`Co00001oooool3o`000003ooooool0003o0000
00;ooooo0ol00005ooooo`;o0000B_ooool001cooooo00?o0000ooooooooool0;oooool2o`0000?o
oooo0_l00004ooooo`;o00003Oooool5o`000003ooooool0003o000000?ooooo0_l0000Gooooo`;o
000000Coooooo`000?l0003o00000oooool2o`0000Gooooo0ol00002ooooo`;o00002oooool4o`00
00Wooooo0_l00003ooooo`;o00001?ooool2o`0000Sooooo1Ol00002ooooo`;o000000Coooooo`00
0?l0003ooooo0ol00002oooooako000000?oooooo`000?l000000_l0000;ooooo`;o00000_ooool3
o`0000?ooooo1?l0001:ooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00002_ooool2o`00
00gooooo2?l00003ooooo`;o00005oooool2o`000004ooooool0003o0000o`0000[ooooo0ol00000
0ooooooo0000o`000006ooooo`;o00001?ooool4o`0000Sooooo0_l00004ooooo`;o00003_ooool2
o`0000Sooooo0_l000000ooooooo0000o`00000Eo`000003ooooool0003o000000Wo000000?ooooo
o`000?l000000_l0000>ooooo`?o00001?ooool2o`0001?ooooo0_l00006ooooo`;o0000;oooool0
01cooooo00?o0000ooooooooool0;_ooool2o`0000Kooooo0_l00002ooooo`;o00001_ooool2o`00
00Wooooo0_l00003ooooo`So00003Oooool4o`0000;ooooo0_l0000Booooo`;o00001_ooool2o`00
00Oooooo0_l00007ooooo`;o000000?oooooo`000?l000002_ooool2o`0001Cooooo8ol000000ooo
oooo0000o`00000:ooooo`Oo00001oooool2o`0000?ooooo0_l00005ooooo`;o00001?ooool2o`00
00Kooooo1?l00003ooooo`;o0000:?ooool001cooooo00?o0000ooooooooool0=_ooool2o`0000[o
oooo0_l0000>ooooo`So00000oooool2o`0000Sooooo1?l00002ooooo`;o00001oooool4o`0000;o
oooo1?l00008ooooo`;o00001Oooool2o`000004ooooool0003o0000o`0000Wooooo0_l00004oooo
o`;o00001?ooool2o`0000;ooooo0_l00007ooooo`;o00001?ooool2o`0000;ooooo1ol000000ooo
oooo0000o`00000Ko`0000?ooooo0_l00005ooooo`Oo00001oooool2o`0000?ooooo0_l00005oooo
o`;o00003_ooool2o`0000?ooooo0_l0000Xooooo`007?ooool2o`0005Wooooo0_l00003ooooo`;o
00001oooool3o`0000gooooo1?l00002ooooo`Co00002?ooool2o`0000Gooooo0_l00002ooooo`?o
00000_ooool2o`0000[ooooo0ol00003ooooo`;o00000_ooool2o`0000Oooooo0_l00004ooooo`Go
000000?oooooo`000?l000001ol000000ooooooo0000o`00000:o`000003ooooool0003o000000[o
00000oooool2o`000003ooooool0003o000000Cooooo0_l00004ooooo`;o00002oooool2o`0004;o
oooo000Looooo`03o`000?oooooooooo03Oooooo0_l0000@ooooo`;o00001_ooool2o`0001?ooooo
0ol00009ooooo`Co00001?ooool2o`0000Oooooo0_l00003ooooo`?o000000?oooooo`000?l00000
0_ooool:o`0000;ooooo1?l000000ooooooo0000o`000004o`0000Oooooo1?l000000ooooooo0000
o`000003ooooo`;o00001?oooolKo`000003ooooool0003o000000Oo00002Oooool2o`000003oooo
ool0003o000000Oooooo0_l00004ooooo`;o00000oooool4o`0001Cooooo0_l0000/ooooo`007?oo
ool00ol0003oooooooooo`0gooooo`;o00000oooool2o`0000_ooooo0_l00006ooooo`Co00000ooo
ool7o`000004ooooool0003o0000o`0000Wooooo0ol00003ooooo`Co000000Coooooo`000?l0003o
oooo0_l00007ooooo`Co000000Goooooo`000?l0003o0000ooooo`02o`0000;ooooo1?l00002oooo
o`;o00001?ooool9o`0000Wooooo1?l000001?oooooo0000o`000?l00002ooooo`?o00000oooool2
o`000003ooooool0003o000000oo000000?oooooo`000?l000003Ol000000ooooooo0000o`000006
ooooo`?o000000?oooooo`000?l000001oooool2o`0000Cooooo0_l00003ooooo`Co00003Oooool2
o`0000Gooooo0_l0000/ooooo`007?ooool00ol0003oooooooooo`0looooo`;o00001?ooool4o`00
00gooooo0_l00003ooooo`Oo000000Coooooo`000?l0003o00001_ooool2o`000004ooooool0003o
0000o`0000?ooooo0ol00002ooooo`;o00001Oooool2o`0000;ooooo1Ol00005ooooo`;o00000_oo
ool3o`0000?ooooo1?l00002ooooo`Ko00000oooool2o`0000[ooooo0_l000000ooooooo0000o`00
0003ooooo`;o00001Oooool4o`000003ooooool0003o000001ko00001_ooool2o`0000Cooooo0_l0
00000ooooooo0000o`00000:ooooo`Co000000?oooooo`000?l000001oooool2o`0000Cooooo0_l0
0005ooooo`;o0000;?ooool001cooooo00?o0000ooooooooool0;Oooool2o`0001?ooooo1?l0000?
ooooo`;o00000_ooool2o`0000kooooo0_l0000:ooooo`Co00001Oooool2o`0000;ooooo0_l00008
ooooo`?o000000?oooooo`000?l000001?ooool=o`0000;ooooo1?l000000ooooooo0000o`000005
ooooo`;o00003?oooolUo`0000gooooo0_l000000ooooooo0000o`000003ooooo`;o000000?ooooo
o`000?l000000_ooool4o`0000[ooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`0]oooo
o`;o00009?ooool8o`0000Kooooo0_l0000Booooo`Co00002oooool2o`0000Gooooo1Ol000000ooo
oooo0000o`000003oooooa3o000000Coooooo`000?l0003ooooo1?l00003ooooo`;o00002ooooolT
o`000003ooooool0003o000001Cooooo0_l000000ooooooo0000o`00001;ooooo`007?ooool00ol0
003oooooooooo`14ooooo`;o00003Oooool8o`0000Kooooo0_l0000Pooooo`Co00000oooool<o`00
00;ooooo4Ol00002ooooo`?o00000oooool2o`0000_ooooo0_l000000ooooooo0000o`000009o`00
0003ooooool0003o000000Go000000?oooooo`000?l000002ol000000ooooooo0000o`000003oooo
o`Co00003Oooool2o`0000Kooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o
00001_ooool2o`0000Kooooo0ol0000Kooooo`;o00000_ooool2o`0000Kooooo0_l00002ooooo`;o
00003?ooool2o`000003ooooool0003o000000So000000?oooooo`000?l000000_l000000ooooooo
0000o`000003o`000004ooooool0003o0000o`0000;ooooo1ol000000ooooooo0000o`000002oooo
o`;o00001?ooool2o`0000gooooo9ol00003ooooo`Co000000?oooooo`000?l000002_ooool2o`00
00Kooooo0_l00016ooooo`007?ooool00ol0003oooooooooo`0_ooooo`Ko00001_ooool2o`0000Go
oooo0ol0000?ooooo`;o00002oooool2o`0000;ooooo1Ol00002ooooo`?o00000_ooool4o`0000;o
oooo0_l00006ooooo`Go00000oooool5o`000003ooooool0003o000000Wo000000?oooooo`000?l0
00000_l00002ooooo`;o00002?ooool2o`0000Cooooo1?l00002ooooo`;o00001ooooolPo`0000?o
oooo1?l000000ooooooo0000o`000005ooooo`;o00003Oooool5o`0000;ooooo0_l00003ooooo`;o
000000?oooooo`000?l00000??ooool001cooooo00?o0000ooooooooool0;oooool4o`0000Sooooo
0ol00002ooooo`Go00003oooool2o`0000Wooooo0_l000000ooooooo0000o`000003ooooo`?o0000
0_ooool2o`0000Gooooo0_l000001Ooooooo0000o`000?l0003ooooo00Co00000_ooool3o`000003
ooooool0003o000000;ooooo4Ol000001?oooooo0000o`000?l00002ooooo`;o00000_ooool2o`00
0004ooooool0003o0000o`0000Cooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo2?l00000
0ooooooo0000o`000003o`000003ooooool0003o000001Co000000Coooooo`000?l0003ooooo0_l0
0002ooooo`;o00005?ooool5o`0000;ooooo0_l00002ooooo`?o000000?oooooo`000?l00000??oo
ool001cooooo00?o0000ooooooooool0<Oooool2o`0000Kooooo0_l000000ooooooo0000o`000002
ooooo`Go00006?ooool4o`000004ooooool0003o0000o`0000kooooo1Ol000000ooooooo0000o`00
0003o`000003ooooool0003o000000?ooooo:ol00002ooooo`;o00001_oooolXo`0000Cooooo0_l0
0008ooooo`;o00004_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000mooooo`007?ooool0
0ol0003oooooooooo`0aooooo`;o00001?ooool4o`0000Gooooo1?l0000Iooooo`;o00000_ooool4
o`0000kooooo0ol00003ooooo`Co000000?oooooo`000?l000001?l00002ooooob3o000000?ooooo
o`000?l000001_l00002ooooo`;o00000_ooool6o`0000;ooooo0_l000000ooooooo0000o`00000A
o`000003ooooool0003o000000_o00001?ooool2o`0000Sooooo0ol000000ooooooo0000o`000002
o`0001?ooooo0_l0000mooooo`007?ooool00ol0003oooooooooo`0gooooo`Co00006Oooool2o`00
00_ooooo0_l0000?ooooo`;o00001oooool2o`000004ooooool0003o0000oooooako00000_ooool2
o`000003ooooool0003o000000Oo00001Oooool2o`000003ooooool0003o000000Go000000?ooooo
o`000?l000000ol00003oooooa[o00000oooool2o`0000Gooooo0_l00005ooooo`;o000000?ooooo
o`000?l000000_l0001Booooo`007?ooool00ol0003oooooooooo`0hooooo`?o00001?ooool2o`00
01?ooooo0_l00007ooooo`Co00001_ooool2o`0000Wooooo0_l0000=ooooobOo00000oooool2o`00
0003ooooool0003o000000;ooooo0_l00002ooooo`Ko000000Coooooo`000?l0003o00001oooool@
o`000003ooooool0003o000000Co00001?ooool4o`0000;ooooo1?l0001Mooooo`0000Koooooonk^
k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo
00?o0000ooooooooool0<Oooool2o`0000Gooooo0ol00004ooooo`;o00007?ooool4o`0000;ooooo
0_l00002ooooo`;o00002?ooool2o`0000kooooo9_l000001?oooooo0000o`000?ooool5o`0000;o
oooo0_l00002ooooo`Co00000_ooool2o`0000Wooooo4?l00002ooooo`Ko00000oooool4o`0000;o
oooo1?l0000Looooo`;o0000?oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q
8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo037ooooo0_l00005
ooooo`;o00000_ooool2o`0001Oooooo0_l0000<ooooo`;o00000oooool2o`0000Cooooo0_l00000
0ooooooo0000o`000008ooooo`;o00001?oooolVo`000003ooooool0003o000000;ooooo0_l00004
ooooo`;o00000_ooool3o`0000?ooooo1?l00007ooooo`;o000000?oooooo`000?l000002ol00002
ooooo`?o000000?oooooo`000?l000000_l000000ooooooo0000o`00000?ooooo`;o00001_ooool4
o`0000Wooooo0_l00009ooooo`;o0000=?ooool00003ooooool@413ooooo00;ooooo00?o410@oooo
ooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0>?ooool2
o`0000;ooooo0_l00004ooooo`;o00004Oooool2o`0000[ooooo0_l00005ooooo`;o00001?ooool2
o`0000Wooooo1Ol000000ooooooo0000o`000003o`000003ooooool0003o000001oo00001Oooool2
o`0000;ooooo0_l00005ooooo`Co00000oooool3o`0000[ooooo2Ol000001?oooooo0000o`000?l0
0006ooooo`Co000000Coooooo`000?l0003ooooo0_l00004ooooo`;o00001_ooool2o`0000?ooooo
0_l000000ooooooo0000o`000002o`0000Cooooo0_l0000;ooooo`;o000000?oooooo`000?l00000
=?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oV9RHoooo
oonHV9So8B4Q00Kooooo0ol0000hooooo`;o00002?ooool4o`0001_ooooo0_l00002ooooo`;o0000
4_ooool]o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o00001?ooool2o`000003oooo
ool0003o000000?ooooo0ol0000<ooooo`Ko00003?ooool2o`0000Gooooo1?l000001?oooooo0000
o`000?l0000;ooooo`;o00002Oooool2o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0003Oo
oooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oeEEEOl0003o
410@olc<c006ooooo`03o`000?oooooooooo03Sooooo0_l00004ooooo`?o000000?oooooo`000?l0
00000_l0000;ooooo`Co00003?ooool3o`000003ooooool0003o000000Wooooo0ol00008ooooo`Ko
000000?oooooo`000?l000006Ol000000ooooooo0000o`000006o`000004ooooool0003o0000oooo
o`;o00001?ooool4o`000004ooooool0003o0000ooooo`Co00004?ooool6o`0000Gooooo0_l0000>
ooooo`;o000000?oooooo`000?l000002Oooool2o`000003ooooool0003o000000?ooooo0_l00000
0ooooooo0000o`000004ooooo`Co000000?oooooo`000?l00000??ooool00003ooooool@413ooooo
00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo
03?ooooo0_l00003ooooo`;o00001?ooool3o`000004ooooool0003o0000ooooo`;o00002_ooool4
o`0000Kooooo0_l00003ooooo`Co00001?ooool2o`0000?ooooo0_l000001?oooooo0000o`000?l0
0008ooooo`Go000000?oooooo`000?l000008_l000001Ooooooo0000o`000?l0003ooooo00;o0000
00Coooooo`000?l0003ooooo1?l00003ooooo`Go000000?oooooo`000?l000000oooool2o`0000_o
oooo0ol00005ooooo`;o00000oooool2o`0001Oooooo0_l00005ooooo`?o000000?oooooo`000?l0
00001?ooool4o`0000Kooooo1?l0000eooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;oooo
o`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0<oooool2o`0000[ooooo0_l00004oooo
o`;o00005?ooool2o`0000?ooooo0ol00002ooooo`;o000000?oooooo`000?l000001Ol00004oooo
o`;o00002Oooool2o`000003ooooool0003o000000ko000000?oooooo`000?l000004Ol000000ooo
oooo0000o`000007o`0000Kooooo1?l00004ooooo`;o00000oooool2o`0000Sooooo0_l00002oooo
o`;o00002_ooool2o`000003ooooool0003o000000oooooo0_l000000ooooooo0000o`000007oooo
o`?o00004Oooool4o`0003Gooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<
odA4A?l0003o410@1_ooool00ol0003oooooooooo`17ooooo`;o00001?ooool2o`0000Wooooo0_l0
00000ooooooo0000o`000002o`0000;ooooo0_l00002ooooo`;o00000oooool3o`0000Kooooo0_l0
00000ooooooo0000o`000005oooooa7o000000?oooooo`000?l000005?l00002ooooo`Co000000?o
ooooo`000?l000000oooool2o`0000;ooooo0ol0000Dooooo`;o00002_ooool2o`0000;ooooo0_l0
00000ooooooo0000o`00000=ooooo`Co000000?oooooo`000?l000001_ooool4o`0000?ooooo0_l0
0009ooooo`;o000000?oooooo`000?l00000=oooool001cooooo00?o0000ooooooooool0<Oooool4
o`0000;ooooo0_l0000>ooooo`Co00000_ooool2o`0000Gooooo0_l00002ooooo`Co000000?ooooo
o`000?l000000_ooool2o`0000Sooooo0_l00009ooooo`;o00001OoooolXo`0000;ooooo0ol00002
ooooo`;o00000oooool2o`0000?ooooo0_l0000;ooooo`;o00001Oooool2o`0000cooooo0_l00002
ooooo`?o00003oooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`?o00001Oooool3
o`0000Sooooo0_l0000jooooo`007?ooool00ol0003oooooooooo`0aooooo`_o00001?ooool2o`00
0003ooooool0003o000000Cooooo0_l00006ooooo`;o000000?oooooo`000?l000000_l00002oooo
o`;o00003oooool2o`0000;ooooo0_l000000ooooooo0000o`000009ooooo`?o000000?oooooo`00
0?l000004ol000000ooooooo0000o`00000=o`000004ooooool0003o0000o`0000;ooooo0_l00008
ooooo`;o00002oooool2o`0000Gooooo0_l0000<ooooo`;o000000?oooooo`000?l000000_l00004
ooooo`;o00001Oooool2o`0000[ooooo0_l00002ooooo`;o00001oooool2o`0004Cooooo000Loooo
o`03o`000?oooooooooo03Gooooo0_l00002ooooo`?o00001?ooool2o`000003ooooool0003o0000
00cooooo0_l00003ooooo`;o00003?ooool2o`0000Wooooo0_l000001?oooooo0000o`000?ooool3
o`000003ooooool0003o000000Go000000?oooooo`000?l000004_l00002ooooo`oo00000_ooool3
o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`;o00001?ooool2o`0000gooooo0_l00000
0ooooooo0000o`00000;ooooo`;o00001_ooool2o`0000?ooooo1?l00002ooooo`?o00003?ooool2
o`00013ooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00000oooool2o`00
00gooooo0_l000001?oooooo0000o`000?l00007ooooo`;o00003oooool3o`000003ooooool0003o
000000?o00000ooooolDo`0000;ooooo5Ol00002ooooo`;o000000?oooooo`000?l000001?ooool2
o`0000?ooooo1?l00004ooooo`;o00001Oooool2o`000003ooooool0003o000000gooooo0_l00009
ooooo`;o00001?ooool3o`0000Kooooo0_l00004ooooo`;o000000?oooooo`000?l000001Oooool2
o`0000?ooooo0_l000000ooooooo0000o`00000hooooo`007?ooool00ol0003oooooooooo`0eoooo
o`;o000000?oooooo`000?l000000oooool2o`0000Cooooo0_l00002ooooo`?o00003Oooool6o`00
0004ooooool0003o0000ooooo`;o00000oooool2o`000003ooooool0003o000000;ooooo0_l00007
ooooo`;o000000Coooooo`000?l0003ooooo6ol000000ooooooo0000o`00000Bo`0000_ooooo1Ol0
0002ooooo`;o00001?ooool2o`0001Kooooo0ol00007ooooo`;o00000oooool2o`000003ooooool0
003o000000Oooooo0_l000000ooooooo0000o`000004ooooo`;o00001Oooool2o`0000?ooooo0_l0
000kooooo`007?ooool00ol0003oooooooooo`0eooooo`;o000000?oooooo`000?l000000oooool2
o`0000Cooooo0_l00002ooooo`?o00002_ooool2o`0000;ooooo0_l00004ooooo`;o000000Cooooo
o`000?l0003o00000_ooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`00
0004ooooo`;o00001_ooool/o`0000Sooooo0_l00005ooooo`Go00002oooool2o`0000_ooooo0_l0
0004ooooo`;o00002?ooool2o`0000?ooooo0_l00004ooooo`;o00000oooool2o`0000;ooooo0_l0
001=ooooo`007?ooool00ol0003oooooooooo`0dooooo`;o00001oooool2o`0001Gooooo0_l0000<
ooooo`;o00000_ooool2o`0000Gooooo0_l000001?oooooo0000o`000?ooool2o`0000Gooooo0_l0
00000ooooooo0000o`000008o`000003ooooool0003o000001[o000000?oooooo`000?l000000ol0
0008ooooo`;o00001_ooool4o`0000_ooooo0_l0000;ooooo`;o00004oooool2o`0000Cooooo0_l0
0002ooooo`?o00001_ooool2o`0004Wooooo000Looooo`03o`000?oooooooooo03Cooooo0_l0000;
ooooo`;o00000oooool2o`0000Gooooo0_l000000ooooooo0000o`000009ooooo`;o00001Oooool2
o`0000Wooooo0_l00004ooooo`?o00001?ooool5o`000003ooooool0003o000000oo00000_oooolA
o`0000;ooooo0_l0000Booooo`;o00000oooool4o`0001Cooooo1Ol00004ooooo`;o00002Oooool3
o`0000?ooooo0_l00002ooooo`?o00000_ooool2o`0000;ooooo0_l00006ooooo`;o00000_ooool2
o`0003gooooo000Looooo`03o`000?oooooooooo03cooooo0_l00002ooooo`?o00000oooool2o`00
00Gooooo0_l000000ooooooo0000o`000009ooooo`;o00001Oooool2o`0000cooooo0_l00002oooo
o`;o00001Oooool4o`000003ooooool0003o000000[o000000?oooooo`000?l000000_l000000ooo
oooo0000o`00000@o`000005ooooool0003o0000o`000?ooool00_l0000Dooooo`Co00001oooool2
o`0000_ooooo1Ol00004ooooo`;o000000Coooooo`000?l0003o00001_ooool2o`0000?ooooo0_l0
00000ooooooo0000o`000004ooooo`;o00000_ooool2o`0000Kooooo0_l00002ooooo`;o0000?Ooo
ool001cooooo00?o0000ooooooooool0??ooool3o`000003ooooool0003o000001Oooooo0_l0000=
ooooo`;o00001?ooool4o`0000_ooooo0_l000000ooooooo0000o`000007o`000003ooooool0003o
000000Go000000?oooooo`000?l000004ol00002ooooo`;o00001oooool2o`0001Kooooo0_l00006
ooooo`;o000000?oooooo`000?l000001Oooool2o`0000?ooooo1ol00002ooooo`;o00001Oooool2
o`000003ooooool0003o000005?ooooo000Looooo`03o`000?oooooooooo03cooooo0ol0000Joooo
o`;o00003Oooool2o`0000Cooooo1?l00009ooooo`ko000000?oooooo`000?l000005ol000000ooo
oooo0000o`00000:ooooo`Co00000_ooool2o`0001Gooooo0_l00003ooooo`;o000000?oooooo`00
0?l000001Oooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00005oooo
o`;o00001Oooool2o`000003ooooool0003o000000;ooooo0_l00018ooooo`007?ooool2o`0003go
oooo0_l0000Looooo`;o00000_ooool2o`0000Wooooo0_l00005ooooo`;o00001ooooolIo`000003
ooooool0003o0000017o00002_ooool3o`0000?ooooo0_l0000Eooooo`;o00002Oooool2o`000003
ooooool0003o000000Oooooo0_l00002ooooo`?o00001Oooool2o`000003ooooool0003o000000?o
oooo0_l000000ooooooo0000o`000002ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0
C_ooool2o`0000Sooooo1?l00002ooooo`;o00001?ooool2o`0000?ooooo0_l0000>ooooo`Co0000
0ooooolXo`0000?ooooo0_l00006ooooo`;o00000_ooool2o`0000?ooooo0_l0000Jooooo`;o0000
00?oooooo`000?l000002oooool3o`0000Gooooo1Ol00006ooooo`;o00001?ooool2o`0004Kooooo
000Looooo`03o`000?oooooooooo03gooooo0_l0000=ooooo`Co00002?ooool2o`0000[ooooo0_l0
000;ooooo`;o00002?ooool2o`000004ooooool0003o0000ooooob;o00000oooool2o`0000?ooooo
0_l000001?oooooo0000o`000?l00002ooooo`;o00000_ooool2o`0000?ooooo0_l00003ooooo`;o
0000;oooool2o`0000Sooooo0_l00003ooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0
>oooool4o`0000gooooo0_l000000ooooooo0000o`000002o`0001[ooooo0_l00002ooooo`;o0000
2_oooolVo`0000_ooooo0ol00003ooooo`;o000000?oooooo`000?l000002?ooool2o`0001gooooo
0_l000000ooooooo0000o`000003ooooo`;o00002?ooool2o`0000Sooooo0_l0001;ooooo`007?oo
ool00ol0003oooooooooo`0kooooo`Co00001Oooool2o`0000Wooooo1?l0000Jooooo`;o00002ooo
ool2o`000003ooooool0003o000000Ko000000?oooooo`000?l000001_l000000ooooooo0000o`00
000;o`0000gooooo0_l00002ooooo`?o00001?ooool2o`000003ooooool0003o000000;ooooo0_l0
0008ooooo`;o00006Oooool2o`000003ooooool0003o000000?ooooo0_l0000>ooooo`;o00002?oo
ool2o`0004Gooooo000Looooo`03o`000?oooooooooo03_ooooo0ol00006ooooo`;o00002_ooool2
o`0001;ooooo0_l00003ooooo`;o00001_ooool2o`0000Oooooo0_l00002ooooo`Co00000oooool9
o`000003ooooool0003o000000_o000000?oooooo`000?l000000_l00008ooooo`;o00000_ooool5
o`000003ooooool0003o000000Gooooo0ol00005ooooo`;o000000?oooooo`000?l000008?ooool2
o`0000_ooooo0_l00002ooooo`;o00002?ooool2o`0004Gooooo000Looooo`03o`000?oooooooooo
03cooooo0_l0000Aooooo`?o000000?oooooo`000?l000003oooool2o`0000?ooooo0_l00006oooo
o`;o00001?ooool2o`0000Cooooo0_l00003oooooaOo000000Coooooo`000?l0003ooooo1Ol00000
0ooooooo0000o`000004ooooo`;o00001Oooool2o`000003ooooool0003o000000Gooooo0_l00006
ooooo`;o00008oooool2o`0000_ooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`19oooo
o`;o00000_ooool5o`000003ooooool0003o000000[ooooo0_l00004ooooo`;o00000_ooool2o`00
00?ooooo0_l00007ooooo`;o00000oooool5o`000003ooooool0003o000000Go00001?ooool3o`00
0003ooooool0003o000000Go00000_ooool3o`000003ooooool0003o000000;o000000Coooooo`00
0?l0003o00002_ooool2o`0000Gooooo0_l000000ooooooo0000o`00000kooooo`;o0000D?ooool0
01cooooo00?o0000ooooooooool0BOooool2o`0000;ooooo0_l000000ooooooo0000o`00000:oooo
o`;o000000?oooooo`000?l000001?ooool2o`0000Kooooo0ol0000<ooooo`Wo000000?oooooo`00
0?l000000ol00002ooooo`_o00000_ooool9o`000003ooooool0003o000000Gooooo0_l00003oooo
o`;o00001Oooool2o`000003ooooool0003o000000oooooo0_l0000Pooooo`;o00001oooool3o`00
053ooooo000Looooo`03o`000?oooooooooo03Wooooo0_l0000>ooooo`;o00004Oooool2o`0000oo
oooo0_l000000ooooooo0000o`00000>ooooo`Go000000?oooooo`000?l000000ol000000ooooooo
0000o`000008o`000004ooooool0003o0000ooooo`Wo00000oooool2o`0000?ooooo0_l00004oooo
o`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o00000oooool2o`0000Kooooo0_l0000Eoooo
o`?o00002?ooool2o`0000Oooooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`0eooooo`;o
00000_ooool2o`0000kooooo0_l00007ooooo`;o00005oooool2o`0000?ooooo0ol00002ooooo`;o
00001?ooool2o`0000?ooooo0ol00002ooooo`?o00001?ooool2o`000003ooooool0003o000000So
00000oooool2o`0000?ooooo0_l00003ooooo`;o00000oooool2o`000003ooooool0003o000000?o
00000_ooool2o`0000;ooooo0_l00002ooooo`?o00000oooool2o`0001gooooo0ol0000<ooooo`;o
00000oooool2o`00057ooooo000Looooo`03o`000?oooooooooo03Gooooo0_l0000Kooooo`;o0000
0oooool4o`00013ooooo1?l000001?oooooo0000o`000?l00002ooooo`;o00001?ooool2o`0000Ko
oooo1ol000000ooooooo0000o`000002ooooo`Go000000Goooooo`000?l0003o0000ooooo`02o`00
013ooooo0_l000001?oooooo0000o`000?l0000<ooooo`;o00002Oooool4o`00023ooooo0_l00003
ooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0Eoooool4o`0001;ooooo0_l000000ooo
oooo0000o`00000;ooooo`Co00000_ooool4o`000004ooooool0003o0000ooooo`;o000000?ooooo
o`000?l000000ol00003ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o00003?ooool2
o`0000;ooooo0_l0000Dooooo`Co00007_ooool4o`0000Cooooo0_l0001Eooooo`007?ooool00ol0
003oooooooooo`13ooooo`;o00002Oooool2o`0001cooooo0_l00002ooooo`;o00000_ooool2o`00
00Gooooo1_l00004ooooo`;o00001_ooool5o`0000Oooooo1?l00003ooooo`?o00001oooool2o`00
0004ooooool0003o0000o`0000;ooooo0_l00002ooooo`;o0000<_ooool2o`0000Kooooo0_l0001E
ooooo`007?ooool00ol0003oooooooooo`0kooooo`;o00001_ooool2o`0000Wooooo0_l0000Eoooo
o`;o00001Oooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool8o`0000Wooooo1?l00000
0ooooooo0000o`000002o`00013ooooo0_l00007ooooo`;o000000?oooooo`000?l000001oooool2
o`0002_ooooo0_l000000ooooooo0000o`00000:ooooo`;o00000oooool2o`00053ooooo000Loooo
o`03o`000?oooooooooo03_ooooo0_l00007ooooo`;o00002?ooool2o`0000;ooooo0_l0000Aoooo
o`?o00002Oooool2o`0000Cooooo2?l00004ooooo`Co000000?oooooo`000?l000001?l00004oooo
o`Co00000oooool2o`0000Kooooo0_l00007ooooo`Oo00005?ooool2o`0001cooooo0_l000000ooo
oooo0000o`000005ooooo`;o00002?ooool2o`00053ooooo000Looooo`;o0000AOooool2o`0000So
oooo0ol000000ooooooo0000o`00000Booooo`?o00003Oooool5o`0000;ooooo0_l00002ooooo`Ko
00001?ooool3o`0000Cooooo1?l00003ooooo`;o000000?oooooo`000?l000000oooool2o`0000Wo
oooo1Ol0000Dooooo`Co00009?ooool2o`0000Gooooo0_l000000ooooooo0000o`00001@ooooo`00
7?ooool00ol0003oooooooooo`1?ooooo`;o00005_ooool2o`0000gooooo0_l00005ooooo`?o0000
00Coooooo`000?l0003o00002?ooool2o`0000kooooo0_l0000Vooooo`;o000000?oooooo`000?l0
00006Oooool2o`0000Gooooo0_l00003ooooo`?o00000oooool3o`0005;ooooo000Looooo`03o`00
0?oooooooooo04_ooooo1_l0000Jooooo`;o00000_ooool2o`0000gooooo0_l00002ooooo`;o0000
00Coooooo`000?l0003ooooo0_l00002ooooo`Co00001?ooool2o`0001cooooo0_l0000>ooooo`Co
00001?ooool2o`0001Kooooo0_l00005ooooo`;o00000oooool3o`0000Cooooo0_l0001Booooo`00
7?ooool00ol0003oooooooooo`1:ooooo`Oo00006_ooool6o`0001Cooooo0_l000000ooooooo0000
o`000002o`0000;ooooo0_l00004ooooo`;o00000oooool2o`0001Oooooo0_l0000>ooooo`;o0000
0_ooool2o`0000;ooooo0_l0000Mooooo`;o00001?ooool3o`0005Oooooo000Looooo`03o`000?oo
oooooooo04[ooooo0_l000000ooooooo0000o`00000<ooooo`;o00001_ooool2o`0000Sooooo0_l0
0004ooooo`;o00001Oooool2o`0000;ooooo0_l00003ooooo`Co00000oooool4o`0000_ooooo0ol0
000Hooooo`;o00000oooool2o`0000Wooooo1?l0000Qooooo`Co000000?oooooo`000?l000000_l0
001Gooooo`007?ooool00ol0003oooooooooo`1=ooooo`?o00000oooool2o`0000Kooooo0_l00006
ooooo`;o00001_ooool4o`0000Cooooo0_l00005ooooo`;o00000_ooool2o`0000?ooooo1?l00003
ooooo`Co00003?ooool2o`0001Sooooo0_l00003ooooo`;o00002Oooool2o`0002Gooooo0_l00000
0ooooooo0000o`00001Iooooo`007?ooool00ol0003oooooooooo`1<ooooo`Co000000?oooooo`00
0?l000000_l00007ooooo`;o00003Oooool3o`0001kooooo1?l0000Iooooo`;o00002Oooool2o`00
00[ooooo0_l00002ooooo`;o00000_ooool2o`0001Oooooo0_l00005ooooo`Co00002?ooool2o`00
05?ooooo000Looooo`03o`000?oooooooooo04cooooo0_l00003ooooo`Co00001oooool2o`0000Wo
oooo0_l00003ooooo`;o00003oooool2o`0000;ooooo0_l00008ooooo`Go00006Oooool2o`0001Go
oooo0_l00002ooooo`?o000000?oooooo`000?l000005oooool2o`0000?ooooo1_l00008ooooo`;o
0000Doooool001cooooo00?o0000ooooooooool0C?ooool2o`0000Gooooo0_l0000Booooo`;o0000
5?ooool2o`0000;ooooo0_l00006ooooo`Co000000?oooooo`000?l000003_ooool2o`0000kooooo
0_l00002ooooo`;o00004Oooool2o`000003ooooool0003o000000_ooooo0_l00002ooooo`;o0000
0_ooool2o`0000Oooooo0_l00002ooooo`Co0000Foooool001cooooo00?o0000ooooooooool0C?oo
ool2o`0001?ooooo0_l00005ooooo`;o00003_ooool2o`0000oooooo0_l00003ooooo`;o00002Ooo
ool2o`0000?ooooo0_l0000:ooooo`;o00000_ooool2o`0000;ooooo0_l0000Cooooo`;o00003?oo
ool2o`0000;ooooo0_l000001?oooooo0000o`000?l00003ooooo`;o00002?ooool2o`0005_ooooo
000Looooo`03o`000?oooooooooo067ooooo0_l00005ooooo`Go000000?oooooo`000?l000001ooo
ool3o`0001Cooooo0_l00009ooooo`;o00001_ooool2o`0000Oooooo0_l00008ooooo`;o00004Ooo
ool2o`0001?ooooo0_l00004ooooo`;o000000?oooooo`000?l000006oooool2o`0004Gooooo000L
ooooo`03o`000?oooooooooo05cooooo0_l00008ooooo`;o00000_ooool3o`000003ooooool0003o
000000Oooooo0_l00006ooooo`;o00000oooool2o`0000gooooo0_l0000<ooooo`;o00004Oooool3
o`0000?ooooo0_l0000Cooooo`Co00002Oooool2o`0000Gooooo1?l00002ooooo`;o00005oooool2
o`0004Gooooo000Looooo`03o`000?oooooooooo05_ooooo0ol00008ooooo`;o00002oooool2o`00
00Cooooo0_l00004ooooo`;o00000oooool2o`0000?ooooo0_l000000ooooooo0000o`000005oooo
o`;o000000?oooooo`000?l000004_ooool2o`000003ooooool0003o000000Kooooo0_l00003oooo
o`;o00002Oooool2o`0000Sooooo1?l00004ooooo`;o00000oooool2o`0000Gooooo0_l00004oooo
o`;o0000G_ooool001cooooo00?o0000ooooooooool0Foooool2o`0000Wooooo0_l00004ooooo`;o
00001Oooool2o`0000Cooooo0_l0000>ooooo`;o000000?oooooo`000?l000002?ooool2o`0001;o
oooo0_l000000ooooooo0000o`00000@ooooo`;o00001?ooool2o`0000Sooooo0_l00005ooooo`?o
00000_ooool4o`0006[ooooo000Looooo`03o`000?oooooooooo06Kooooo0_l00004ooooo`Co0000
1Oooool2o`0001Kooooo0_l00003ooooo`;o00008_ooool3o`0000Kooooo0_l000000ooooooo0000
o`00000;ooooo`;o00001Oooool2o`0000;ooooo1Ol000000ooooooo0000o`000004o`0000Gooooo
0_l0001Looooo`007?ooool00ol0003oooooooooo`1Oooooo`;o00003Oooool2o`0000Gooooo0_l0
000Fooooo`;o00000oooool2o`0002;ooooo0ol00006ooooo`;o000000?oooooo`000?l000002Ooo
ool4o`0000Wooooo1?l00002ooooo`Ko00001Oooool2o`0005cooooo000Looooo`;o0000H?ooool2
o`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l000003?ooool2o`0002[ooooo0_l0000=
ooooo`;o00000oooool2o`0000oooooo0ol0000;ooooo`Co00000_ooool2o`0006Oooooo000Loooo
o`03o`000?oooooooooo06Gooooo0ol00002ooooo`;o000000?oooooo`000?l000003?ooool2o`00
0003ooooool0003o0000023ooooo0ol00004ooooo`;o00003oooool2o`000003ooooool0003o0000
00;ooooo0_l0000;ooooo`;o00002oooool5o`0000Wooooo0_l0001Pooooo`007?ooool00ol0003o
ooooooooo`1Uooooo`;o00002Oooool2o`000003ooooool0003o000000;o00001oooool4o`0001ko
oooo0ol0000Eooooo`?o00001?ooool4o`0000Gooooo1?l0000=ooooo`;o000000?oooooo`000?l0
00001?ooool2o`0000?ooooo0_l0001Pooooo`007?ooool00ol0003oooooooooo`1[ooooo`;o0000
0oooool2o`000003ooooool0003o000000;o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o
00003?ooool2o`0000Cooooo1_l00008ooooo`;o00005Oooool2o`0000Kooooo0_l00005ooooo`Co
00005?ooool4o`0006Gooooo000Looooo`03o`000?oooooooooo06Cooooo0_l00005ooooo`;o0000
1oooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`Co00001Oooool2o`0000Cooooo
0_l00004ooooo`Ko00001Oooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000
o`00000Tooooo`;o00003oooool2o`0006Oooooo000Looooo`03o`000?oooooooooo06;ooooo1?l0
000>ooooo`;o00001_ooool2o`000003ooooool0003o000000;o00001Oooool4o`0000Wooooo0_l0
0008ooooo`;o00001?ooool3o`000003ooooool0003o000000oooooo0_l0000Cooooo`;o00003?oo
ool2o`0006[ooooo000Looooo`03o`000?oooooooooo06;ooooo0_l00008ooooo`;o00001_ooool2
o`000003ooooool0003o000000?ooooo0_l0000:ooooo`Go00003?ooool2o`0000Cooooo0_l00004
ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`;o00008Oooool2o`0006[ooooo000Loooo
o`03o`000?oooooooooo06?ooooo0_l00007ooooo`Co00001oooool2o`000003ooooool0003o0000
00oooooo0_l0000<ooooo`;o00002_ooool2o`000003ooooool0003o000000;ooooo0_l00005oooo
o`;o000000?oooooo`000?l000005Oooool2o`0000Kooooo0_l00007ooooo`;o0000JOooool001co
oooo00?o0000ooooooooool0Hoooool2o`0000Wooooo0_l000000ooooooo0000o`000007ooooo`;o
00000oooool2o`00027ooooo0_l000001?oooooo0000o`000?ooool2o`0000cooooo0_l0000Eoooo
o`;o00000oooool2o`000003ooooool0003o000000Kooooo0ol0001Yooooo`007?ooool00ol0003o
ooooooooo`1_ooooo`Go00002oooool2o`0000;ooooo1?l0000;ooooo`;o00002_ooool2o`0000;o
oooo0_l000000ooooooo0000o`00000<ooooo`?o000000?oooooo`000?l000004Oooool2o`0000Ko
oooo0_l00009ooooo`;o0000J_ooool001cooooo00?o0000ooooooooool0IOooool2o`0000Sooooo
0_l000001?oooooo0000o`000?ooool3o`0000_ooooo1?l00005ooooo`;o00001?ooool2o`0000Ko
oooo0ol000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000003?ooool3o`000003
ooooool0003o000000kooooo0_l000000ooooooo0000o`000004ooooo`;o00000_ooool2o`0007?o
oooo000Looooo`03o`000?oooooooooo06Gooooo0_l0000>ooooo`?o00002Oooool2o`000003oooo
ool0003o000000Kooooo0_l0000<ooooo`Go00000oooool2o`0000oooooo0_l0000Booooo`;o0000
1oooool2o`0000;ooooo1ol0001^ooooo`007?ooool00ol0003oooooooooo`1/ooooo`;o00001_oo
ool2o`0000_ooooo0_l0000>ooooo`;o00002Oooool3o`0000cooooo0_l00006ooooo`;o00000ooo
ool2o`0000;ooooo0_l0000Gooooo`Ko0000K_ooool001cooooo00?o0000ooooooooool0K?ooool2
o`0000;ooooo0_l00002ooooo`;o00000oooool4o`0000oooooo1?l000000ooooooo0000o`000006
ooooo`;o00003?ooool2o`0000;ooooo0_l0000;ooooo`;o00000_ooool2o`00013ooooo0_l00005
ooooo`;o0000L_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Go
c<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo073ooooo0_l00002ooooo`?o0000
0_ooool4o`0000Wooooo0_l00004ooooo`Co00002Oooool2o`0000Gooooo0_l00005ooooo`;o0000
00?oooooo`000?l000003?ooool2o`0000Kooooo0_l00002ooooo`;o00002?ooool2o`0007Wooooo
00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRH
V?lQ8B401_ooool00ol0003oooooooooo`1Kooooo`;o00003oooool2o`0000Kooooo0ol00002oooo
o`?o00002_ooool3o`0000Cooooo0_l0000>ooooo`;o000000?oooooo`000?l000001_ooool4o`00
00Sooooo0_l00002ooooo`;o00001_ooool2o`0000;ooooo0_l00002ooooo`;o0000Ooooool00003
ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool0Foooool2o`0000oooooo0_l0000<ooooo`;o00002oooool2o`00
00?ooooo0ol00008ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00001Oooool2
o`0000[ooooo1_l0000:ooooo`;o00000_ooool2o`0007oooooo00000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000K_ooool2
o`0000Oooooo1?l00003ooooo`;o00001_ooool3o`0000?ooooo0_l00009ooooo`;o000000?ooooo
o`000?l000001Oooool2o`0000?ooooo0_l0000>ooooo`;o0000TOooool00003ooooool0003ooooo
00;ooooo00?o0000ooooooooool02Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000
ooooooooool0K_ooool2o`0000Oooooo1?l000000ooooooo0000o`000002o`0000Gooooo1Ol0000:
ooooo`;o00002_ooool2o`0000Cooooo0_l00003ooooo`;o00002Oooool2o`0000;ooooo0_l00006
ooooo`;o00000oooool2o`0000;ooooo0_l0001looooo`0000?ooooooa0@4?ooool00_ooool00ol@
413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`1[
ooooo`;o000000?oooooo`000?l000002_ooool6o`0000Gooooo0_l000000ooooooo0000o`00000:
ooooo`;o00001_ooool7o`0000Sooooo0_l0000=ooooo`;o00001_ooool4o`000003ooooool0003o
000000;ooooo0_l0001looooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj
^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`1[ooooo`;o000000?oooooo`000?l00000
2_ooool8o`0001;ooooo0_l00006ooooo`Oo00002oooool2o`0000Wooooo0_l00009ooooo`;o0000
Poooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY
00Kooooo00?o0000ooooooooool0L_ooool2o`0000Sooooo0_l000001?oooooo0000o`000?l00003
ooooo`;o00001Oooool3o`000004ooooool0003o0000ooooo`?o00004_ooool2o`0000Cooooo0_l0
0009ooooo`;o00001?ooool2o`0000[ooooo0_l0001looooo`007?ooool00ol0003oooooooooo`1b
ooooo`;o00004Oooool3o`0000Cooooo0ol000001?oooooo0000o`000?ooool2o`0000;ooooo0_l0
0008ooooo`;o00001Oooool4o`00013ooooo0_l000000ooooooo0000o`000009ooooo`?o0000O?oo
ool001cooooo00?o0000ooooooooool0L?ooool2o`0000kooooo1?l00002ooooo`;o00000_ooool2
o`0000_ooooo0_l00003ooooo`;o000000?oooooo`000?l000000_l00003ooooo`;o000000Cooooo
o`000?l0003o00004?ooool2o`0000cooooo0_l0001mooooo`007?ooool00ol0003oooooooooo`1`
ooooo`;o000000?oooooo`000?l000002oooool6o`0000Cooooo0_l00004ooooo`;o00002_ooool2
o`000005ooooool0003o0000o`000?ooool00_l000001Ooooooo0000o`000?l0003ooooo00;o0000
3?ooool2o`0000Oooooo0ol0000Sooooo`;o0000H?ooool001cooooo00?o0000ooooooooool0L_oo
ool3o`0000cooooo0_l000000ooooooo0000o`00000:ooooo`;o00003oooool4o`0000;ooooo1Ol0
000<ooooo`;o000000?oooooo`000?l000001?ooool5o`00027ooooo0_l0001Pooooo`007?ooool0
0ol0003oooooooooo`1booooo`;o00004?ooool2o`00017ooooo0_l00002ooooo`?o00000oooool2
o`0000Gooooo0ol0000;ooooo`;o00000oooool2o`0000Oooooo0_l00023ooooo`007?ooool00ol0
003oooooooooo`1Yooooo`;o00006Oooool2o`0000Cooooo0_l0000;ooooo`;o00000_ooool4o`00
00[ooooo0_l00007ooooo`;o00000_ooool2o`00097ooooo000Looooo`03o`000?oooooooooo06Wo
oooo0_l000000ooooooo0000o`000009ooooo`;o00004Oooool2o`0000oooooo1?l0000Aooooo`Co
000000?oooooo`000?l00000T_ooool001cooooo00?o0000ooooooooool0K?ooool2o`0000Gooooo
0_l00002ooooo`;o00002Oooool2o`0001[ooooo0_l0000<ooooo`;o00000_ooool2o`0000?ooooo
0_l00006ooooo`;o0000R_ooool001cooooo00?o0000ooooooooool0Loooool2o`0000gooooo0_l0
000Gooooo`;o000000?oooooo`000?l000003?ooool2o`0000oooooo0_l0002:ooooo`007?ooool0
0ol0003oooooooooo`1hooooo`;o00008Oooool2o`0000Cooooo0ol0000;ooooo`;o00002_ooool2
o`0008cooooo000Looooo`03o`000?oooooooooo07Sooooo0_l0000Nooooo`;o00001oooool3o`00
00_ooooo0_l0000:ooooo`;o0000S?ooool001cooooo0_l0002Iooooo`;o0000[oooool001cooooo
00?o0000ooooooooool0R_ooool2o`000;gooooo000Looooo`03o`000?oooooooooo08[ooooo0_l0
000Booooo`;o0000ZOooool001cooooo00?o0000ooooooooool0W_ooool2o`000:Wooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`2Booooo`;o00007Oooool2o`0000cooooo0_l00028ooooo`007?oo
ool00ol0003oooooooooo`2Booooo`;o00007Oooool2o`0000cooooo0_l00028ooooo`007?ooool0
0ol0003oooooooooo`2iooooo`;o0000S_ooool001cooooo00?o0000ooooooooool0^Oooool2o`00
08kooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`2`ooooo`;o0000Uoooool001cooooo00?o0000
ooooooooool0/?ooool2o`0009Oooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000:3ooooo0_l0002Xooooo`007?oo
ool00ol0003oooooooooo`2Oooooo`;o0000Z?ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Booooo`Co000000?o410@ooooooooool00oooool00ol0003ooooo
ooooo`3ooooood[ooooo000Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooo
oom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`?o0000oooooom:ooooo`005?ooool00ol0
003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Cooooo
00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000B
ooooo`03oeEEEOmVIVKo00000?ooooooE?ooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00:7ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0Fooooo`Co0000
00?o410@ooooooooool00_ooool2o`000003oa0@4?oooooooooo00?ooooo00?o0000onk^k_ooool0
0oooool01Oo^k^ko<S8bo`000?l@413oc<c<08cooooo002Rooooo`05o`000?ooooooooooooooool0
00002Oooool6o`0000cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
oeEEEOnYZJWooooo00?ooooo00GoEEEEogMgMoooooooV9RHob4Q8@2<ooooo`00X_ooool01Ol0003o
oooooooooooooooo000001_ooooo00?o0000ooooooooool00_ooool5o`0000Gooooo00?oZJVYoeEE
EOooool00oooool01Ol0003ooooooooooooooooo000008cooooo002Rooooo`05o`000?oooooooooo
ooooool000002Oooool6o`0000cooooo00?o0000ooooooooool00_ooool01?m4A4CogMgMooooool0
0007ooooo`03ob4Q8Ooooooooooo00;ooooo00Go0000oiRHV?ooooooV9RHob4Q8@2<ooooo`00X_oo
ool01Ol0003oQhN7oooooonYZJWo000001_ooooo00?o0000ooooooooool00_ooool01?oMgMgoEEEE
ooooool00007ooooo`03oeEEEOo<c<cooooo00;ooooo00Go0000oeEEEOl0003o410@olc<c02<oooo
o`00XOooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo01Wooooo00?o0000oooooooo
ool00oooool00omgMgOoc<c<o`000007ooooo`03ojVYZOmgMgOooooo00;ooooo00?oEEEEohN7Qooo
ool0S_ooool00<;ooooo00?o0000ooooooooool00oooool00oo^k^koA4A4o`000004ooooo`05oa0@
4?oooooooooooooooolb<S800oooool00ooMgMgo410@oiRHV02>ooooo`00`?ooool00omEEEGoIVIV
o`000006ooooo`03ogMgMol0003ooooo00?ooooo1Ol00004ooooo`04olc<c?m4A4Co0000oa0@48co
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1482) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.60583 .58086 Mdot
.59841 .57979 Mdot
.46063 .37044 Mdot
.41437 .60143 Mdot
.2036 .60317 Mdot
.47852 .32834 Mdot
.6499 .37062 Mdot
.64072 .37756 Mdot
.45881 .37866 Mdot
.73789 .59259 Mdot
.60297 .40877 Mdot
.43585 .54213 Mdot
.63593 .40047 Mdot
.45646 .58502 Mdot
.53406 .87546 Mdot
.37777 .5885 Mdot
.60685 .57784 Mdot
.24897 .42495 Mdot
.39485 .57329 Mdot
.44495 .34372 Mdot
.69434 .59639 Mdot
.45253 .58789 Mdot
.62823 .58045 Mdot
.4571 .58497 Mdot
.43006 .61776 Mdot
.63509 .58743 Mdot
.57421 .58145 Mdot
.44627 .64435 Mdot
.47978 .61446 Mdot
.60229 .40544 Mdot
.26795 .4589 Mdot
.35777 .79305 Mdot
.42425 .68086 Mdot
.32487 .67395 Mdot
.65241 .41493 Mdot
.56784 .75549 Mdot
.48695 .34449 Mdot
.63305 .38421 Mdot
.62254 .39107 Mdot
.65566 .38115 Mdot
.64553 .38158 Mdot
.64527 .57222 Mdot
.75897 .42718 Mdot
.67974 .34215 Mdot
.50301 .59402 Mdot
.19633 .43606 Mdot
.47235 .76187 Mdot
.42329 .57491 Mdot
.67433 .57525 Mdot
.37932 .27456 Mdot
.62073 .28746 Mdot
.66223 .41533 Mdot
.44042 .3644 Mdot
.52733 .10402 Mdot
.62317 .41191 Mdot
.50275 .63035 Mdot
.47497 .35567 Mdot
.45702 .60105 Mdot
.46217 .58587 Mdot
.62919 .66651 Mdot
.43753 .66404 Mdot
.31002 .43017 Mdot
.60411 .60798 Mdot
.46494 .46219 Mdot
.46394 .35483 Mdot
.60939 .40177 Mdot
.60303 .55935 Mdot
.62908 .41396 Mdot
.45271 .68689 Mdot
.51472 .3309 Mdot
.40527 .58415 Mdot
.60603 .40309 Mdot
.68077 .60582 Mdot
.46141 .63003 Mdot
.35731 .27263 Mdot
.19792 .41154 Mdot
.29492 .41327 Mdot
.58321 .7342 Mdot
.63577 .66321 Mdot
.34947 .3301 Mdot
.48795 .62931 Mdot
.25432 .51769 Mdot
.21162 .39966 Mdot
.67052 .55892 Mdot
.37453 .61323 Mdot
.27606 .43515 Mdot
.45664 .63319 Mdot
.17505 .57929 Mdot
.40815 .65528 Mdot
.5081 .49831 Mdot
.48592 .37476 Mdot
.66286 .59892 Mdot
.41706 .60692 Mdot
.47774 .60856 Mdot
.68426 .67041 Mdot
.40213 .58172 Mdot
.43775 .59447 Mdot
.66189 .55671 Mdot
.65343 .42145 Mdot
.45625 .66729 Mdot
.41955 .32496 Mdot
.47401 .31563 Mdot
.42058 .64988 Mdot
.51246 .34074 Mdot
.67958 .60478 Mdot
.47694 .6095 Mdot
.62337 .39474 Mdot
.41173 .63248 Mdot
.65669 .25146 Mdot
.61194 .57101 Mdot
.47031 .63523 Mdot
.34297 .39732 Mdot
.53788 .69127 Mdot
.67532 .59597 Mdot
.68883 .40039 Mdot
.40518 .56415 Mdot
.44206 .60538 Mdot
.60803 .55589 Mdot
.46992 .31289 Mdot
.17531 .52484 Mdot
.64041 .54761 Mdot
.61454 .44523 Mdot
.69413 .57394 Mdot
.4524 .54048 Mdot
.45873 .35238 Mdot
.69185 .37131 Mdot
.71713 .38666 Mdot
.28781 .48986 Mdot
.45481 .63024 Mdot
.77772 .44181 Mdot
.45048 .33033 Mdot
.66296 .5842 Mdot
.63281 .41054 Mdot
.40039 .66083 Mdot
.62434 .55995 Mdot
.60766 .43421 Mdot
.33812 .44222 Mdot
.60167 .24616 Mdot
.62088 .59838 Mdot
.56489 .4391 Mdot
.64383 .42882 Mdot
.67244 .39077 Mdot
.60948 .81745 Mdot
.64863 .55573 Mdot
.34005 .41331 Mdot
.64058 .41127 Mdot
.37584 .50319 Mdot
.50319 .60619 Mdot
.23938 .50142 Mdot
.72816 .29362 Mdot
.3255 .61962 Mdot
.55709 .26914 Mdot
.34776 .41659 Mdot
.67504 .40846 Mdot
.42616 .59843 Mdot
.63574 .59679 Mdot
.63229 .58266 Mdot
.43629 .66366 Mdot
.42674 .63117 Mdot
.38719 .60756 Mdot
.43397 .56652 Mdot
.54129 .53298 Mdot
.39558 .64698 Mdot
.49003 .75663 Mdot
.65809 .60141 Mdot
.41728 .59664 Mdot
.442 .366 Mdot
.46689 .55707 Mdot
.62174 .3859 Mdot
.45338 .59541 Mdot
.41637 .60335 Mdot
.47387 .64998 Mdot
.66946 .406 Mdot
.3253 .75575 Mdot
.50673 .68175 Mdot
.30257 .69332 Mdot
.59229 .51831 Mdot
.49075 .38412 Mdot
.44779 .6342 Mdot
.32229 .41577 Mdot
.62568 .7511 Mdot
.40323 .60496 Mdot
.236 .25147 Mdot
.44169 .58948 Mdot
.24354 .66926 Mdot
.36162 .6526 Mdot
.31341 .6849 Mdot
.2677 .50997 Mdot
.43399 .61612 Mdot
.77441 .52449 Mdot
.58722 .41062 Mdot
.47401 .28727 Mdot
.65297 .38856 Mdot
.44468 .35701 Mdot
.46412 .36511 Mdot
.40374 .44609 Mdot
.39808 .54729 Mdot
.43537 .55136 Mdot
.3913 .62785 Mdot
.4899 .3108 Mdot
.57362 .59386 Mdot
.34747 .39975 Mdot
.61484 .6146 Mdot
.29552 .75741 Mdot
.42631 .25582 Mdot
.60388 .39294 Mdot
.35027 .4363 Mdot
.50524 .35035 Mdot
.47882 .37947 Mdot
.35084 .41464 Mdot
.47676 .59273 Mdot
.645 .55508 Mdot
.4747 .82042 Mdot
.57213 .21109 Mdot
.83826 .63297 Mdot
.66975 .56321 Mdot
.77334 .47249 Mdot
.62458 .38191 Mdot
.48827 .35632 Mdot
.44054 .6023 Mdot
.4687 .61042 Mdot
.67905 .60987 Mdot
.4066 .58268 Mdot
.67906 .54316 Mdot
.4371 .6103 Mdot
.60261 .38296 Mdot
.29321 .4288 Mdot
.40307 .44669 Mdot
.32661 .51274 Mdot
.68359 .59634 Mdot
.70581 .7109 Mdot
.48173 .38118 Mdot
.63838 .74185 Mdot
.6057 .412 Mdot
.32705 .44675 Mdot
.4585 .38803 Mdot
.33303 .39282 Mdot
.37871 .62607 Mdot
.4554 .33668 Mdot
.3244 .3968 Mdot
.41756 .48921 Mdot
.49441 .58261 Mdot
.54985 .18222 Mdot
.66231 .3889 Mdot
.60346 .598 Mdot
.40747 .63066 Mdot
.50227 .37058 Mdot
.48921 .66532 Mdot
.49902 .26263 Mdot
.69147 .31982 Mdot
.44591 .33463 Mdot
.37545 .47329 Mdot
.32188 .44843 Mdot
.59453 .29863 Mdot
.77426 .44627 Mdot
.59868 .58629 Mdot
.38111 .61555 Mdot
.36892 .79385 Mdot
.63967 .41154 Mdot
.40715 .62149 Mdot
.20873 .51328 Mdot
.64041 .42126 Mdot
.4565 .60321 Mdot
.6169 .43953 Mdot
.63236 .58198 Mdot
.65672 .65432 Mdot
.61731 .55172 Mdot
.40872 .57996 Mdot
.62231 .40079 Mdot
.46177 .31165 Mdot
.64207 .58766 Mdot
.46772 .57638 Mdot
.44471 .64213 Mdot
.42959 .46995 Mdot
.42166 .58989 Mdot
.29788 .707 Mdot
.43549 .61358 Mdot
.47548 .36773 Mdot
.47201 .64523 Mdot
.80286 .53172 Mdot
.40175 .44119 Mdot
.62199 .55132 Mdot
.4395 .34289 Mdot
.45581 .36623 Mdot
.28722 .32799 Mdot
.68597 .38695 Mdot
.46536 .56408 Mdot
.49566 .37692 Mdot
.40854 .52146 Mdot
.61481 .42692 Mdot
.41798 .65651 Mdot
.55741 .39947 Mdot
.43921 .26431 Mdot
.44105 .35661 Mdot
.52181 .5676 Mdot
.63911 .60789 Mdot
.42034 .61476 Mdot
.50291 .36502 Mdot
.3662 .57018 Mdot
.48044 .62458 Mdot
.76897 .39306 Mdot
.40636 .47126 Mdot
.63905 .42864 Mdot
.43965 .54778 Mdot
.39444 .61578 Mdot
.46157 .33383 Mdot
.67272 .60501 Mdot
.62137 .42945 Mdot
.64488 .57872 Mdot
.31408 .67371 Mdot
.56682 .19216 Mdot
.49014 .49663 Mdot
.30131 .40697 Mdot
.42626 .28867 Mdot
.32127 .70497 Mdot
.77506 .64239 Mdot
.60558 .793 Mdot
.36864 .75764 Mdot
.50898 .33288 Mdot
.40882 .28121 Mdot
.46429 .36022 Mdot
.43381 .64495 Mdot
.46357 .34954 Mdot
.38727 .81456 Mdot
.4365 .606 Mdot
.47459 .34109 Mdot
.69517 .69091 Mdot
.42115 .60948 Mdot
.59732 .58616 Mdot
.27909 .72187 Mdot
.82961 .50478 Mdot
.69103 .42857 Mdot
.49806 .34486 Mdot
.5011 .82169 Mdot
.43564 .59342 Mdot
.46962 .64646 Mdot
.65156 .60449 Mdot
.44374 .68269 Mdot
.31648 .41125 Mdot
.34979 .43971 Mdot
.61763 .46529 Mdot
.33455 .46859 Mdot
.44106 .54728 Mdot
.64207 .5904 Mdot
.55891 .54477 Mdot
.30726 .32005 Mdot
.39188 .27138 Mdot
.59237 .41203 Mdot
.27822 .71984 Mdot
.67689 .51966 Mdot
.64114 .4923 Mdot
.55609 .36031 Mdot
.6714 .5829 Mdot
.34945 .78696 Mdot
.64842 .3864 Mdot
.49748 .17696 Mdot
.75395 .58145 Mdot
.4752 .59728 Mdot
.61284 .41694 Mdot
.52352 .61779 Mdot
.81642 .53726 Mdot
.44559 .1949 Mdot
.41056 .74994 Mdot
.40957 .65468 Mdot
.42259 .25878 Mdot
.44761 .59772 Mdot
.49062 .26779 Mdot
.43756 .62375 Mdot
.64845 .57972 Mdot
.74394 .58494 Mdot
.67678 .43188 Mdot
.55709 .59632 Mdot
.58633 .30768 Mdot
.3463 .40871 Mdot
.43938 .61142 Mdot
.47511 .59336 Mdot
.31331 .40957 Mdot
.62211 .58511 Mdot
.39388 .59431 Mdot
.71488 .70068 Mdot
.48028 .59206 Mdot
.63171 .38155 Mdot
.75197 .5962 Mdot
.4381 .72588 Mdot
.42855 .5618 Mdot
.67583 .55956 Mdot
.62528 .37675 Mdot
.62553 .39812 Mdot
.36063 .61621 Mdot
.5981 .41032 Mdot
.43385 .58398 Mdot
.4179 .1995 Mdot
.6153 .58989 Mdot
.73535 .32981 Mdot
.62723 .55514 Mdot
.57512 .7239 Mdot
.65158 .42043 Mdot
.63469 .26113 Mdot
.52345 .61258 Mdot
.64734 .38919 Mdot
.54792 .62829 Mdot
.4837 .57788 Mdot
.4809 .57234 Mdot
.47614 .8173 Mdot
.48531 .36902 Mdot
.42139 .46752 Mdot
.60137 .40753 Mdot
.44829 .57497 Mdot
.40507 .56988 Mdot
.62935 .37547 Mdot
.49709 .21379 Mdot
.77501 .60738 Mdot
.43591 .61066 Mdot
.65463 .58434 Mdot
.66102 .57924 Mdot
.5063 .58853 Mdot
.41962 .64424 Mdot
.44661 .36323 Mdot
.44589 .321 Mdot
.50165 .38027 Mdot
.40992 .46641 Mdot
.66813 .28505 Mdot
.19075 .5488 Mdot
.65699 .38194 Mdot
.75245 .47876 Mdot
.47686 .48938 Mdot
.40468 .6534 Mdot
.49764 .33636 Mdot
.39371 .61255 Mdot
.41026 .59 Mdot
.65802 .33412 Mdot
.21571 .60151 Mdot
.72038 .56715 Mdot
.68153 .60065 Mdot
.67278 .40946 Mdot
.41116 .54917 Mdot
.62147 .35674 Mdot
.31843 .44116 Mdot
.33237 .60275 Mdot
.60436 .41133 Mdot
.59394 .57968 Mdot
.66173 .40321 Mdot
.47095 .61237 Mdot
.49098 .65513 Mdot
.66934 .58084 Mdot
.30737 .43027 Mdot
.4025 .66706 Mdot
.45315 .60488 Mdot
.68189 .23322 Mdot
.36407 .52326 Mdot
.63243 .485 Mdot
.43368 .61228 Mdot
.47478 .57407 Mdot
.35688 .44459 Mdot
.47991 .59651 Mdot
.39676 .62903 Mdot
.53106 .69803 Mdot
.69794 .46793 Mdot
.35647 .41069 Mdot
.4389 .20386 Mdot
.66898 .56315 Mdot
.35236 .77514 Mdot
.49019 .33071 Mdot
.65059 .46123 Mdot
.76697 .6038 Mdot
.44486 .38186 Mdot
.55138 .27304 Mdot
.34083 .76131 Mdot
.41087 .34542 Mdot
.51389 .37646 Mdot
.59191 .59871 Mdot
.42912 .57084 Mdot
.44525 .60598 Mdot
.32266 .4132 Mdot
.64664 .55722 Mdot
.54488 .48904 Mdot
.24005 .33099 Mdot
.45039 .58904 Mdot
.76185 .38552 Mdot
.42392 .22867 Mdot
.40983 .26356 Mdot
.32403 .42556 Mdot
.3526 .43934 Mdot
.44099 .61223 Mdot
.52387 .68648 Mdot
.63552 .58833 Mdot
.46688 .57631 Mdot
.39809 .65011 Mdot
.49328 .36042 Mdot
.61728 .56938 Mdot
.46819 .31304 Mdot
.60502 .27545 Mdot
.29215 .68212 Mdot
.47316 .15883 Mdot
.62539 .42102 Mdot
.36367 .25692 Mdot
.61614 .43457 Mdot
.25927 .52131 Mdot
.4463 .38865 Mdot
.41839 .62302 Mdot
.65824 .60795 Mdot
.43935 .57582 Mdot
.41888 .63966 Mdot
.476 .59081 Mdot
.41979 .56433 Mdot
.50007 .14883 Mdot
.34525 .40414 Mdot
.37586 .63261 Mdot
.46916 .36992 Mdot
.21646 .4031 Mdot
.25043 .35539 Mdot
.4732 .59259 Mdot
.44124 .63179 Mdot
.6252 .57154 Mdot
.41734 .65226 Mdot
.61707 .43257 Mdot
.59635 .59318 Mdot
.4678 .62617 Mdot
.22816 .68006 Mdot
.47964 .61787 Mdot
.31382 .70334 Mdot
.66063 .403 Mdot
.59185 .21679 Mdot
.47936 .66443 Mdot
.70248 .34827 Mdot
.42156 .46765 Mdot
.45486 .38695 Mdot
.63063 .43943 Mdot
.48536 .34286 Mdot
.25894 .30063 Mdot
.5144 .57767 Mdot
.42647 .60232 Mdot
.39753 .64106 Mdot
.49166 .38356 Mdot
.18258 .63603 Mdot
.60576 .31433 Mdot
.51416 .57249 Mdot
.44617 .35897 Mdot
.60457 .55068 Mdot
.36278 .73298 Mdot
.64175 .56349 Mdot
.30953 .45483 Mdot
.63205 .37916 Mdot
.30795 .42715 Mdot
.26703 .5952 Mdot
.60734 .57241 Mdot
.65889 .61829 Mdot
.49185 .33462 Mdot
.67455 .63197 Mdot
.83556 .35937 Mdot
.75767 .57706 Mdot
.2884 .51199 Mdot
.64239 .59763 Mdot
.47963 .61095 Mdot
.25797 .55366 Mdot
.74904 .58418 Mdot
.48275 .34372 Mdot
.39888 .59954 Mdot
.67906 .65217 Mdot
.44598 .36476 Mdot
.44209 .67391 Mdot
.47158 .37285 Mdot
.65675 .39245 Mdot
.501 .34632 Mdot
.70223 .5875 Mdot
.45785 .63878 Mdot
.84925 .36479 Mdot
.35088 .47121 Mdot
.43214 .59528 Mdot
.67956 .39273 Mdot
.53176 .23908 Mdot
.41086 .61412 Mdot
.31187 .39973 Mdot
.46926 .33826 Mdot
.60711 .6208 Mdot
.43659 .61585 Mdot
.44612 .35826 Mdot
.60817 .59235 Mdot
.68102 .3689 Mdot
.68031 .66886 Mdot
.66626 .48453 Mdot
.65949 .60546 Mdot
.61833 .50538 Mdot
.66159 .42802 Mdot
.47134 .57054 Mdot
.39884 .58478 Mdot
.65626 .58085 Mdot
.227 .45622 Mdot
.44616 .65868 Mdot
.47863 .63881 Mdot
.4881 .362 Mdot
.48395 .3377 Mdot
.59514 .79523 Mdot
.48459 .31517 Mdot
.4671 .6702 Mdot
.65505 .57815 Mdot
.41528 .60533 Mdot
.62108 .57279 Mdot
.41647 .65075 Mdot
.37519 .69025 Mdot
.62235 .58586 Mdot
.65771 .33732 Mdot
.40259 .59607 Mdot
.39378 .66947 Mdot
.4106 .62796 Mdot
.43637 .56877 Mdot
.44883 .36199 Mdot
.32003 .42154 Mdot
.40301 .65453 Mdot
.30564 .38624 Mdot
.35204 .40931 Mdot
.68407 .43148 Mdot
.49204 .36279 Mdot
.33775 .40502 Mdot
.36149 .23055 Mdot
.4511 .34401 Mdot
.32393 .4098 Mdot
.24841 .35809 Mdot
.65397 .41511 Mdot
.64272 .60923 Mdot
.42284 .61366 Mdot
.3001 .61889 Mdot
.47023 .75511 Mdot
.45481 .4047 Mdot
.43425 .60786 Mdot
.40576 .61741 Mdot
.63221 .54569 Mdot
.19314 .38087 Mdot
.51586 .33677 Mdot
.48444 .60338 Mdot
.59956 .57452 Mdot
.14675 .44223 Mdot
.47147 .36524 Mdot
.31932 .41303 Mdot
.66535 .40582 Mdot
.56724 .6099 Mdot
.71765 .35988 Mdot
.67514 .38288 Mdot
.41952 .36553 Mdot
.61806 .28179 Mdot
.39146 .5833 Mdot
.48373 .32118 Mdot
.73952 .72553 Mdot
.53436 .53325 Mdot
.45013 .46156 Mdot
.47032 .80735 Mdot
.67286 .59113 Mdot
.61609 .43378 Mdot
.34838 .41534 Mdot
.67538 .57016 Mdot
.60803 .57792 Mdot
.64061 .37458 Mdot
.49248 .69624 Mdot
.5597 .3952 Mdot
.62389 .38793 Mdot
.32697 .57356 Mdot
.21103 .46171 Mdot
.49261 .32844 Mdot
.31734 .41028 Mdot
.25504 .60066 Mdot
.64404 .57457 Mdot
.31792 .77649 Mdot
.49977 .82994 Mdot
.43778 .59424 Mdot
.34405 .41476 Mdot
.18424 .61949 Mdot
.19215 .39508 Mdot
.64007 .42264 Mdot
.6682 .4485 Mdot
.31377 .44349 Mdot
.40628 .62742 Mdot
.36158 .54459 Mdot
.4467 .6528 Mdot
.64326 .37879 Mdot
.66881 .68475 Mdot
.60664 .57507 Mdot
.66626 .38704 Mdot
.33103 .65777 Mdot
.43718 .58387 Mdot
.40124 .59937 Mdot
.32333 .53922 Mdot
.67731 .57056 Mdot
.45643 .38823 Mdot
.39135 .59119 Mdot
.45304 .60103 Mdot
.47843 .66246 Mdot
.50462 .57698 Mdot
.57106 .67562 Mdot
.43453 .63986 Mdot
.34761 .27238 Mdot
.40769 .64878 Mdot
.42214 .58088 Mdot
.6836 .57101 Mdot
.43962 .16214 Mdot
.61108 .28963 Mdot
.45266 .59735 Mdot
.48149 .58366 Mdot
.66759 .39165 Mdot
.57139 .37711 Mdot
.72675 .59628 Mdot
.60008 .61526 Mdot
.55429 .81593 Mdot
.49225 .58032 Mdot
.60301 .56036 Mdot
.31699 .39935 Mdot
.46761 .56578 Mdot
.59481 .57142 Mdot
.48022 .64305 Mdot
.44547 .37257 Mdot
.44925 .34725 Mdot
.56001 .56143 Mdot
.33506 .40211 Mdot
.79851 .50756 Mdot
.75022 .47793 Mdot
.4571 .33765 Mdot
.42726 .60686 Mdot
.58707 .40798 Mdot
.49537 .37086 Mdot
.4082 .34668 Mdot
.21409 .49968 Mdot
.63488 .59816 Mdot
.6628 .60101 Mdot
.23591 .5028 Mdot
.57143 .26005 Mdot
.77024 .36982 Mdot
.65697 .39034 Mdot
.3809 .64164 Mdot
.77862 .49379 Mdot
.66822 .60094 Mdot
.26089 .53838 Mdot
.34292 .40897 Mdot
.64139 .4205 Mdot
.59382 .3416 Mdot
.62875 .56409 Mdot
.61879 .60663 Mdot
.45153 .66451 Mdot
.46107 .60725 Mdot
.62167 .77911 Mdot
.31239 .38351 Mdot
.65532 .3718 Mdot
.3166 .41247 Mdot
.44094 .38115 Mdot
.45262 .64795 Mdot
.62504 .58406 Mdot
.20049 .47697 Mdot
.43261 .55825 Mdot
.45497 .38009 Mdot
.67081 .59523 Mdot
.32598 .45004 Mdot
.30554 .40581 Mdot
.43783 .56535 Mdot
.66411 .74388 Mdot
.63746 .3855 Mdot
.66657 .56768 Mdot
.58631 .44497 Mdot
.44214 .65494 Mdot
.45511 .61358 Mdot
.38328 .68374 Mdot
.65873 .37303 Mdot
.71649 .53203 Mdot
.31262 .39582 Mdot
.6582 .56497 Mdot
.43649 .63702 Mdot
.32403 .40573 Mdot
.75969 .47996 Mdot
.43222 .36727 Mdot
.50215 .34929 Mdot
.30518 .40817 Mdot
.33055 .43003 Mdot
.31822 .3946 Mdot
.32117 .78146 Mdot
.58992 .56709 Mdot
.65291 .5038 Mdot
.49019 .60565 Mdot
.27473 .50962 Mdot
.37877 .64515 Mdot
.63547 .43123 Mdot
.48089 .37226 Mdot
.41423 .6251 Mdot
.44051 .56213 Mdot
.36742 .67122 Mdot
.747 .35067 Mdot
.43683 .70009 Mdot
.61371 .57264 Mdot
.49502 .65197 Mdot
.49715 .34593 Mdot
.32853 .80471 Mdot
.54103 .84246 Mdot
.48716 .659 Mdot
.56704 .39135 Mdot
.62463 .59186 Mdot
.6557 .38059 Mdot
.30001 .56919 Mdot
.65807 .412 Mdot
.66279 .57273 Mdot
.43734 .64459 Mdot
.74041 .50466 Mdot
.36601 .42973 Mdot
.4437 .5729 Mdot
.65816 .38738 Mdot
.40743 .58286 Mdot
.66724 .37855 Mdot
.29658 .63127 Mdot
.72013 .72819 Mdot
.44153 .59031 Mdot
.3827 .58715 Mdot
.6557 .76197 Mdot
.47034 .5854 Mdot
.29261 .38068 Mdot
.62486 .59274 Mdot
.67911 .68419 Mdot
.39954 .55895 Mdot
.35107 .57743 Mdot
.45143 .65358 Mdot
.70683 .66571 Mdot
.45828 .61409 Mdot
.40314 .26331 Mdot
.46561 .63811 Mdot
.39502 .62884 Mdot
.62064 .41153 Mdot
.66778 .38922 Mdot
.69286 .58751 Mdot
.51019 .35682 Mdot
.31021 .70363 Mdot
.45297 .60836 Mdot
.65168 .27514 Mdot
.69951 .49182 Mdot
.32737 .42949 Mdot
.65926 .56854 Mdot
.14951 .46493 Mdot
.60233 .42917 Mdot
.5966 .81784 Mdot
.54222 .81173 Mdot
.71576 .43148 Mdot
.22431 .58707 Mdot
.48944 .23299 Mdot
.32254 .44709 Mdot
.47022 .6527 Mdot
.38648 .36668 Mdot
.39808 .26312 Mdot
.22316 .45866 Mdot
.63999 .43849 Mdot
.61946 .7611 Mdot
.20656 .54635 Mdot
.29889 .43422 Mdot
.34814 .44596 Mdot
.67119 .40526 Mdot
.52073 .31349 Mdot
.41488 .54239 Mdot
.34354 .42361 Mdot
.49854 .38027 Mdot
.44694 .34468 Mdot
.51181 .36862 Mdot
.6329 .58651 Mdot
.54558 .83758 Mdot
.64568 .44033 Mdot
.63317 .42945 Mdot
.48007 .27973 Mdot
.34949 .68243 Mdot
.63851 .62172 Mdot
.49097 .34817 Mdot
.50051 .33038 Mdot
.62476 .59615 Mdot
.49756 .63566 Mdot
.50792 .57138 Mdot
.45187 .59273 Mdot
.32296 .41709 Mdot
.4637 .61086 Mdot
.4513 .35152 Mdot
.63024 .42092 Mdot
.50553 .34232 Mdot
.67949 .3833 Mdot
.19081 .4884 Mdot
.46159 .5704 Mdot
.45782 .64053 Mdot
.62663 .19376 Mdot
.64657 .61384 Mdot
.20892 .42042 Mdot
.65116 .35168 Mdot
.46453 .36183 Mdot
.39706 .62815 Mdot
.62554 .62106 Mdot
.35362 .39075 Mdot
.48043 .16342 Mdot
.42446 .65258 Mdot
.63538 .57319 Mdot
.44784 .64736 Mdot
.48128 .50819 Mdot
.81248 .42089 Mdot
.64975 .57233 Mdot
.75361 .34147 Mdot
.48258 .6049 Mdot
.37124 .23543 Mdot
.41114 .65027 Mdot
.42119 .49266 Mdot
.44591 .65866 Mdot
.66753 .56137 Mdot
.45605 .59426 Mdot
.61071 .61277 Mdot
.4637 .32767 Mdot
.66554 .3933 Mdot
.65856 .60463 Mdot
.41661 .56949 Mdot
.71277 .17121 Mdot
.65355 .40341 Mdot
.43981 .60639 Mdot
.66454 .41102 Mdot
.63505 .55375 Mdot
.67556 .57994 Mdot
.23206 .36036 Mdot
.60074 .27442 Mdot
.65589 .39441 Mdot
.45135 .64786 Mdot
.40546 .24072 Mdot
.42357 .63067 Mdot
.39351 .52555 Mdot
.50189 .63252 Mdot
.49491 .62137 Mdot
.22279 .38117 Mdot
.64286 .42771 Mdot
.76961 .36444 Mdot
.20266 .39293 Mdot
.21735 .40069 Mdot
.69633 .59386 Mdot
.29931 .42862 Mdot
.34037 .77579 Mdot
.67449 .29205 Mdot
.44677 .37963 Mdot
.41189 .62158 Mdot
.56665 .58342 Mdot
.6319 .38784 Mdot
.3165 .43644 Mdot
.44157 .59127 Mdot
.49969 .33256 Mdot
.7769 .62806 Mdot
.67388 .40947 Mdot
.64691 .56836 Mdot
.6262 .54438 Mdot
.31676 .22772 Mdot
.43527 .62169 Mdot
.46224 .63558 Mdot
.63242 .37889 Mdot
.50848 .22853 Mdot
.34939 .43129 Mdot
.69652 .6877 Mdot
.65445 .39656 Mdot
.53675 .46697 Mdot
.59215 .57412 Mdot
.40302 .61721 Mdot
.23133 .66576 Mdot
.58438 .33719 Mdot
.67979 .24315 Mdot
.32407 .41516 Mdot
.40254 .52147 Mdot
.66718 .56158 Mdot
.63579 .4104 Mdot
.57067 .24304 Mdot
.48508 .57559 Mdot
.39286 .60436 Mdot
.42245 .50521 Mdot
.68454 .42609 Mdot
.70939 .61215 Mdot
.42794 .6532 Mdot
.42132 .46584 Mdot
.41949 .64964 Mdot
.3663 .62399 Mdot
.51164 .6194 Mdot
.45329 .62408 Mdot
.62849 .57941 Mdot
.47616 .53409 Mdot
.47897 .38823 Mdot
.71777 .57469 Mdot
.52577 .46775 Mdot
.43405 .60038 Mdot
.48072 .63518 Mdot
.42819 .75482 Mdot
.52862 .26476 Mdot
.65506 .6035 Mdot
.68987 .60778 Mdot
.59771 .42127 Mdot
.51092 .59951 Mdot
.51043 .355 Mdot
.38927 .65587 Mdot
.44875 .36555 Mdot
.62715 .58204 Mdot
.46735 .36288 Mdot
.67003 .39963 Mdot
.4754 .31872 Mdot
.65954 .27661 Mdot
.64557 .41208 Mdot
.64314 .60317 Mdot
.4644 .62595 Mdot
.6801 .39137 Mdot
.31023 .49915 Mdot
.32554 .41585 Mdot
.15607 .54921 Mdot
.4684 .62626 Mdot
.70108 .44043 Mdot
.35176 .62575 Mdot
.5038 .3367 Mdot
.80429 .40247 Mdot
.66776 .60795 Mdot
.35723 .42242 Mdot
.68161 .57833 Mdot
.3338 .603 Mdot
.334 .42277 Mdot
.16094 .49259 Mdot
.40984 .47861 Mdot
.36978 .52204 Mdot
.50666 .61082 Mdot
.33727 .52373 Mdot
.43724 .3654 Mdot
.63148 .38959 Mdot
.56273 .25178 Mdot
.39395 .62446 Mdot
.78988 .6445 Mdot
.67961 .56742 Mdot
.50023 .37125 Mdot
.63039 .41105 Mdot
.62742 .43095 Mdot
.48615 .58919 Mdot
.36034 .30255 Mdot
.39091 .6071 Mdot
.58956 .25832 Mdot
.49963 .81991 Mdot
.65726 .50944 Mdot
.43725 .60978 Mdot
.4621 .33287 Mdot
.44745 .64736 Mdot
.30847 .39791 Mdot
.63832 .79732 Mdot
.3956 .66615 Mdot
.62046 .36914 Mdot
.31767 .3811 Mdot
.64727 .55398 Mdot
.3587 .66773 Mdot
.65745 .49714 Mdot
.43486 .62545 Mdot
.43725 .13271 Mdot
.32512 .40783 Mdot
.38985 .35736 Mdot
.41948 .5612 Mdot
.4539 .55996 Mdot
.43839 .44602 Mdot
.71618 .33921 Mdot
.53768 .31979 Mdot
.46325 .58244 Mdot
.31313 .48884 Mdot
.66378 .41602 Mdot
.4097 .63329 Mdot
.44359 .60718 Mdot
.49151 .72854 Mdot
.65245 .42652 Mdot
.45697 .37256 Mdot
.44729 .38597 Mdot
.4436 .39768 Mdot
.32238 .39054 Mdot
.736 .57429 Mdot
.27587 .53078 Mdot
.80421 .57578 Mdot
.36045 .42986 Mdot
.45108 .5638 Mdot
.41211 .32348 Mdot
.44139 .64918 Mdot
.31931 .43585 Mdot
.65704 .42414 Mdot
.67066 .60162 Mdot
.77391 .49322 Mdot
.44058 .36905 Mdot
.47039 .56135 Mdot
.35443 .41904 Mdot
.63496 .59625 Mdot
.27752 .57769 Mdot
.64827 .55485 Mdot
.64827 .39316 Mdot
.73872 .57361 Mdot
.31958 .4392 Mdot
.61937 .55452 Mdot
.59301 .3869 Mdot
.21377 .37155 Mdot
.516 .60032 Mdot
.75574 .53676 Mdot
.64186 .55079 Mdot
.67707 .61569 Mdot
.60136 .55797 Mdot
.42038 .57527 Mdot
.56525 .39323 Mdot
.50222 .60543 Mdot
.65126 .42434 Mdot
.46704 .37374 Mdot
.72754 .70659 Mdot
.66892 .3234 Mdot
.58854 .47224 Mdot
.41127 .66801 Mdot
.43854 .58338 Mdot
.44099 .61168 Mdot
.37131 .60056 Mdot
.66528 .27912 Mdot
.41837 .57897 Mdot
.62017 .41099 Mdot
.46368 .34226 Mdot
.47291 .65047 Mdot
.42515 .35671 Mdot
.24357 .37387 Mdot
.31111 .44241 Mdot
.60653 .46071 Mdot
.61218 .82902 Mdot
.63804 .59809 Mdot
.44269 .33738 Mdot
.45708 .34289 Mdot
.3362 .44469 Mdot
.63468 .38297 Mdot
.64143 .55257 Mdot
.42191 .51989 Mdot
.35139 .40778 Mdot
.45534 .59691 Mdot
.58051 .38745 Mdot
.77416 .66781 Mdot
.46146 .65828 Mdot
.41234 .60964 Mdot
.51645 .36103 Mdot
.39229 .36227 Mdot
.87292 .49188 Mdot
.29325 .54213 Mdot
.31597 .42823 Mdot
.30243 .42523 Mdot
.62185 .59717 Mdot
.44928 .55496 Mdot
.67688 .39485 Mdot
.70047 .62999 Mdot
.69952 .52822 Mdot
.79522 .45511 Mdot
.65562 .22539 Mdot
.41621 .64063 Mdot
.4787 .21447 Mdot
.42837 .58343 Mdot
.59555 .56132 Mdot
.63281 .57974 Mdot
.64844 .59063 Mdot
.63285 .38924 Mdot
.58589 .75276 Mdot
.62087 .40148 Mdot
.71093 .76329 Mdot
.67161 .57001 Mdot
.40076 .47856 Mdot
.49401 .34994 Mdot
.50987 .56598 Mdot
.31559 .44486 Mdot
.75208 .55761 Mdot
.45101 .68721 Mdot
.52582 .67386 Mdot
.49432 .37672 Mdot
.65194 .60578 Mdot
.50377 .23121 Mdot
.41196 .80716 Mdot
.67318 .63037 Mdot
.39415 .69618 Mdot
.29887 .5717 Mdot
.32308 .43011 Mdot
.67697 .24058 Mdot
.3097 .42427 Mdot
.65945 .38936 Mdot
.45012 .64147 Mdot
.45595 .63301 Mdot
.42 .65105 Mdot
.47164 .58004 Mdot
.67266 .41827 Mdot
.38319 .63161 Mdot
.80219 .53323 Mdot
.44244 .37455 Mdot
.28051 .45171 Mdot
.31337 .41775 Mdot
.63862 .43537 Mdot
.46186 .3433 Mdot
.537 .26775 Mdot
.3215 .51171 Mdot
.43649 .61351 Mdot
.41357 .62456 Mdot
.62955 .79136 Mdot
.42838 .65285 Mdot
.44058 .53774 Mdot
.44318 .36664 Mdot
.41998 .72645 Mdot
.31091 .44159 Mdot
.30418 .4338 Mdot
.64581 .4138 Mdot
.63038 .57891 Mdot
.33271 .40793 Mdot
.49233 .35574 Mdot
.41753 .67229 Mdot
.38101 .61463 Mdot
.64919 .5531 Mdot
.64015 .78886 Mdot
.29997 .40993 Mdot
.40285 .23841 Mdot
.64205 .60466 Mdot
.67725 .5568 Mdot
.39266 .60642 Mdot
.70935 .2774 Mdot
.69712 .57147 Mdot
.35118 .39542 Mdot
.63898 .43634 Mdot
.31119 .5646 Mdot
.60408 .42829 Mdot
.64519 .56588 Mdot
.48254 .61825 Mdot
.62853 .58799 Mdot
.4347 .61538 Mdot
.46077 .83914 Mdot
.45637 .6269 Mdot
.80842 .56078 Mdot
.23551 .48968 Mdot
.47827 .32645 Mdot
.51772 .25472 Mdot
.49046 .33131 Mdot
.67817 .60122 Mdot
.41461 .56036 Mdot
.34467 .44399 Mdot
.28306 .31494 Mdot
.59498 .63297 Mdot
.48531 .37553 Mdot
.5021 .31457 Mdot
.61086 .43863 Mdot
.44955 .65906 Mdot
.39724 .59503 Mdot
.47724 .33961 Mdot
.69115 .54818 Mdot
.6267 .55922 Mdot
.44139 .63654 Mdot
.43743 .58149 Mdot
.48279 .32742 Mdot
.21843 .36069 Mdot
.51952 .54602 Mdot
.44829 .63564 Mdot
.55331 .34457 Mdot
.6318 .43077 Mdot
.51074 .56825 Mdot
.38275 .59045 Mdot
.33355 .43067 Mdot
.60562 .66717 Mdot
.41335 .78983 Mdot
.66073 .42201 Mdot
.44886 .35079 Mdot
.43607 .62932 Mdot
.46053 .33494 Mdot
.38126 .63036 Mdot
.72048 .36187 Mdot
.44543 .33643 Mdot
.48839 .6291 Mdot
.49401 .6382 Mdot
.67477 .56591 Mdot
.4146 .63299 Mdot
.47799 .78414 Mdot
.46555 .38553 Mdot
.4865 .59333 Mdot
.68088 .71532 Mdot
.61452 .39433 Mdot
.50693 .57911 Mdot
.34892 .40603 Mdot
.36813 .54463 Mdot
.73572 .48443 Mdot
.23277 .61079 Mdot
.30911 .44375 Mdot
.41191 .58034 Mdot
.51171 .327 Mdot
.65368 .37175 Mdot
.82515 .51197 Mdot
.40457 .62467 Mdot
.65162 .3821 Mdot
.63134 .42077 Mdot
.31584 .43814 Mdot
.41341 .16511 Mdot
.42339 .56154 Mdot
.47293 .59636 Mdot
.53757 .75617 Mdot
.62799 .6126 Mdot
.46171 .61824 Mdot
.48047 .60167 Mdot
.62027 .41585 Mdot
.43505 .54442 Mdot
.54941 .8017 Mdot
.7037 .67452 Mdot
.62209 .378 Mdot
.78583 .5166 Mdot
.44357 .34197 Mdot
.3167 .40599 Mdot
.66815 .58659 Mdot
.35149 .42915 Mdot
.49821 .35439 Mdot
.47752 .61037 Mdot
.63916 .37663 Mdot
.47403 .77545 Mdot
.6727 .40247 Mdot
.20964 .52946 Mdot
.60022 .59811 Mdot
.64228 .44847 Mdot
.42236 .1429 Mdot
.56178 .31899 Mdot
.70065 .39431 Mdot
.32798 .42948 Mdot
.45586 .29453 Mdot
.43534 .58176 Mdot
.65879 .22149 Mdot
.45788 .56591 Mdot
.67666 .70126 Mdot
.44871 .38457 Mdot
.50636 .37654 Mdot
.44808 .63921 Mdot
.47655 .809 Mdot
.64711 .37045 Mdot
.61328 .42478 Mdot
.49021 .62122 Mdot
.64799 .38925 Mdot
.46465 .60357 Mdot
.45171 .35353 Mdot
.69656 .24137 Mdot
.44691 .59321 Mdot
.37082 .63839 Mdot
.71484 .41268 Mdot
.20848 .39349 Mdot
.28462 .43071 Mdot
.25237 .28233 Mdot
.46354 .83143 Mdot
.64635 .38949 Mdot
.49791 .60538 Mdot
.78818 .50467 Mdot
.51647 .34785 Mdot
.6067 .47021 Mdot
.47195 .61522 Mdot
.47757 .58249 Mdot
.39824 .63611 Mdot
.40378 .60066 Mdot
.53244 .1727 Mdot
.63459 .63857 Mdot
.59219 .70497 Mdot
.41756 .63856 Mdot
.34347 .50914 Mdot
.65761 .40597 Mdot
.56472 .5928 Mdot
.36031 .4161 Mdot
.41546 .6383 Mdot
.69456 .62005 Mdot
.61395 .38596 Mdot
.739 .74185 Mdot
.64728 .37912 Mdot
.45645 .36481 Mdot
.67055 .38714 Mdot
.42314 .59034 Mdot
.66088 .57973 Mdot
.44746 .42861 Mdot
.59918 .29868 Mdot
.46169 .39163 Mdot
.43227 .59582 Mdot
.36971 .481 Mdot
.4831 .38551 Mdot
.20375 .42133 Mdot
.66374 .58992 Mdot
.30026 .4812 Mdot
.62881 .58447 Mdot
.48694 .61947 Mdot
.48589 .62105 Mdot
.59703 .42896 Mdot
.67132 .39494 Mdot
.62914 .58302 Mdot
.32942 .19352 Mdot
.3103 .39854 Mdot
.6483 .58715 Mdot
.39171 .56235 Mdot
.53137 .41678 Mdot
.65922 .5842 Mdot
.36097 .38939 Mdot
.62573 .41987 Mdot
.63454 .60922 Mdot
.41303 .6582 Mdot
.33044 .57173 Mdot
.30867 .40604 Mdot
.46464 .39649 Mdot
.26279 .5608 Mdot
.47631 .38156 Mdot
.63323 .43914 Mdot
.48713 .32825 Mdot
.63233 .4278 Mdot
.72072 .50155 Mdot
.71509 .56515 Mdot
.40131 .39057 Mdot
.6372 .44137 Mdot
.49201 .33535 Mdot
.44908 .64408 Mdot
.33464 .47248 Mdot
.4259 .55389 Mdot
.403 .58314 Mdot
.61621 .42166 Mdot
.67716 .57476 Mdot
.69463 .59827 Mdot
.38471 .51922 Mdot
.62872 .57506 Mdot
.45844 .38163 Mdot
.56558 .65882 Mdot
.659 .28915 Mdot
.60237 .41985 Mdot
.66738 .39435 Mdot
.43666 .6506 Mdot
.4847 .34315 Mdot
.4774 .39308 Mdot
.60486 .43132 Mdot
.73855 .34934 Mdot
.37669 .59582 Mdot
.69291 .60689 Mdot
.62457 .61002 Mdot
.65214 .57441 Mdot
.58478 .57703 Mdot
.35722 .56907 Mdot
.64805 .41902 Mdot
.68036 .58287 Mdot
.4363 .65144 Mdot
.47883 .60118 Mdot
.74308 .59743 Mdot
.32062 .40005 Mdot
.4877 .63638 Mdot
.51091 .61944 Mdot
.40194 .61642 Mdot
.50011 .33969 Mdot
.45144 .53404 Mdot
.47077 .31621 Mdot
.51439 .34785 Mdot
.51498 .34953 Mdot
.68298 .30323 Mdot
.58294 .81756 Mdot
.34769 .73885 Mdot
.48472 .59234 Mdot
.4427 .21939 Mdot
.4807 .35646 Mdot
.6503 .64466 Mdot
.70972 .52616 Mdot
.39753 .62652 Mdot
.33156 .28788 Mdot
.47995 .33635 Mdot
.63167 .60152 Mdot
.46522 .62168 Mdot
.43334 .35258 Mdot
.34135 .3977 Mdot
.47827 .57223 Mdot
.43203 .37172 Mdot
.61691 .55463 Mdot
.32394 .3871 Mdot
.65056 .6129 Mdot
.51542 .3471 Mdot
.41727 .54904 Mdot
.78363 .32035 Mdot
.42832 .36617 Mdot
.32342 .25634 Mdot
.52695 .63663 Mdot
.44309 .64078 Mdot
.45271 .32023 Mdot
.67368 .55109 Mdot
.63183 .43875 Mdot
.57467 .50319 Mdot
.6133 .58964 Mdot
.50663 .37629 Mdot
.50801 .35487 Mdot
.46131 .39159 Mdot
.61113 .57846 Mdot
.49793 .57497 Mdot
.62122 .5696 Mdot
.66953 .3844 Mdot
.42238 .61816 Mdot
.31616 .6877 Mdot
.5222 .22792 Mdot
.63385 .60073 Mdot
.46599 .37758 Mdot
.36164 .43949 Mdot
.4358 .58608 Mdot
.49236 .22237 Mdot
.44726 .64529 Mdot
.62754 .42858 Mdot
.54759 .69281 Mdot
.43057 .73232 Mdot
.49792 .61293 Mdot
.43119 .64661 Mdot
.61169 .42248 Mdot
.43658 .59497 Mdot
.44678 .65881 Mdot
.65857 .27523 Mdot
.61767 .56585 Mdot
.4548 .59064 Mdot
.47514 .37063 Mdot
.63165 .2865 Mdot
.37258 .61065 Mdot
.41854 .33299 Mdot
.32146 .48801 Mdot
.51978 .70366 Mdot
.46164 .56711 Mdot
.57649 .41048 Mdot
.39747 .60173 Mdot
.45118 .57169 Mdot
.43264 .64416 Mdot
.47781 .18582 Mdot
.43336 .36312 Mdot
.4644 .3353 Mdot
.30316 .41851 Mdot
.31624 .48642 Mdot
.34269 .42313 Mdot
.63114 .42305 Mdot
.36438 .31514 Mdot
.46547 .31639 Mdot
.63798 .55872 Mdot
.43786 .57415 Mdot
.42885 .35938 Mdot
.39949 .61878 Mdot
.42348 .59193 Mdot
.51246 .34147 Mdot
.43612 .35708 Mdot
.21174 .4708 Mdot
.32507 .39713 Mdot
.64664 .5953 Mdot
.4711 .64887 Mdot
.35363 .41386 Mdot
.44831 .56255 Mdot
.27337 .51051 Mdot
.65015 .59282 Mdot
.61989 .56579 Mdot
.69992 .58924 Mdot
.47404 .61767 Mdot
.42844 .58805 Mdot
.61979 .40244 Mdot
.67116 .60645 Mdot
.617 .39116 Mdot
.54085 .49339 Mdot
.27003 .37247 Mdot
.47241 .61463 Mdot
.74947 .57509 Mdot
.34597 .40991 Mdot
.48867 .37304 Mdot
.76434 .67954 Mdot
.30318 .41816 Mdot
.43631 .62015 Mdot
.50663 .366 Mdot
.32856 .4395 Mdot
.4536 .50152 Mdot
.68147 .77651 Mdot
.35682 .4439 Mdot
.4354 .6511 Mdot
.42538 .54516 Mdot
.26733 .26767 Mdot
.32272 .45359 Mdot
.66323 .40712 Mdot
.47261 .61994 Mdot
.66397 .62002 Mdot
.3547 .41965 Mdot
.46138 .25979 Mdot
.47232 .33678 Mdot
.3362 .56996 Mdot
.39859 .67272 Mdot
.54881 .61364 Mdot
.30554 .41644 Mdot
.65934 .5637 Mdot
.3998 .54284 Mdot
.39357 .60667 Mdot
.32049 .45309 Mdot
.68517 .37226 Mdot
.46195 .34913 Mdot
.60532 .28392 Mdot
.61034 .5818 Mdot
.6644 .33893 Mdot
.4828 .37382 Mdot
.39199 .23994 Mdot
.73992 .64334 Mdot
.5056 .56714 Mdot
.36655 .21898 Mdot
.68122 .46854 Mdot
.41835 .65531 Mdot
.36304 .40567 Mdot
.68134 .38854 Mdot
.60541 .3942 Mdot
.64986 .39644 Mdot
.70966 .50168 Mdot
.60392 .61738 Mdot
.43362 .3825 Mdot
.61901 .36048 Mdot
.31926 .40436 Mdot
.3191 .55472 Mdot
.39587 .58967 Mdot
.44324 .58505 Mdot
.45945 .65347 Mdot
.41442 .63908 Mdot
.41408 .58292 Mdot
.64169 .38196 Mdot
.71246 .48673 Mdot
.62965 .62971 Mdot
.65567 .58865 Mdot
.401 .33322 Mdot
.488 .35886 Mdot
.5045 .38287 Mdot
.34119 .43469 Mdot
.54036 .30789 Mdot
.4246 .36027 Mdot
.46508 .36354 Mdot
.47793 .65074 Mdot
.62758 .56353 Mdot
.49629 .55429 Mdot
.43281 .64886 Mdot
.45181 .37612 Mdot
.47004 .46052 Mdot
.49716 .80088 Mdot
.23846 .42532 Mdot
.30133 .39634 Mdot
.592 .3786 Mdot
.3033 .4381 Mdot
.39342 .5834 Mdot
.81258 .43236 Mdot
.49888 .3525 Mdot
.47101 .35211 Mdot
.32925 .39907 Mdot
.70906 .27454 Mdot
.67132 .58906 Mdot
.66768 .33617 Mdot
.65737 .41874 Mdot
.48279 .62192 Mdot
.77192 .6407 Mdot
.55816 .58548 Mdot
.35111 .30554 Mdot
.65326 .39991 Mdot
.46454 .32534 Mdot
.38066 .60494 Mdot
.42487 .64144 Mdot
.347 .41956 Mdot
.21272 .61205 Mdot
.51782 .60732 Mdot
.17758 .63608 Mdot
.72153 .72748 Mdot
.38741 .76426 Mdot
.39353 .60203 Mdot
.61657 .56892 Mdot
.4416 .37804 Mdot
.31668 .40982 Mdot
.4808 .56958 Mdot
.4707 .82144 Mdot
.65728 .55752 Mdot
.64393 .40974 Mdot
.5082 .45698 Mdot
.30623 .55747 Mdot
.42849 .57076 Mdot
.48056 .59313 Mdot
.44497 .56952 Mdot
.87566 .57735 Mdot
.48587 .32139 Mdot
.62928 .59811 Mdot
.3182 .44022 Mdot
.63474 .57047 Mdot
.47154 .32552 Mdot
.40129 .43293 Mdot
.46105 .64186 Mdot
.62583 .54949 Mdot
.66267 .5677 Mdot
.60982 .39151 Mdot
.66177 .42276 Mdot
.52475 .47195 Mdot
.45604 .6251 Mdot
.48224 .31224 Mdot
.67886 .57618 Mdot
.58164 .3966 Mdot
.33521 .42379 Mdot
.62435 .42012 Mdot
.41568 .63382 Mdot
.46875 .31702 Mdot
.47891 .65782 Mdot
.66064 .6022 Mdot
.46625 .36282 Mdot
.20811 .45968 Mdot
.3096 .44145 Mdot
.4771 .60058 Mdot
.25671 .42206 Mdot
.44708 .3546 Mdot
.42769 .58135 Mdot
.33677 .26176 Mdot
.36815 .40252 Mdot
.60365 .31728 Mdot
.50122 .37477 Mdot
.70759 .37694 Mdot
.61983 .59603 Mdot
.71053 .34298 Mdot
.46323 .35701 Mdot
.41845 .23603 Mdot
.19753 .49728 Mdot
.4016 .658 Mdot
.64458 .576 Mdot
.71037 .38974 Mdot
.38737 .8216 Mdot
.28748 .27853 Mdot
.4406 .60662 Mdot
.4871 .31642 Mdot
.33618 .43553 Mdot
.60371 .41768 Mdot
.63214 .3211 Mdot
.36003 .45912 Mdot
.45962 .30718 Mdot
.43254 .64343 Mdot
.64154 .55403 Mdot
.62591 .40396 Mdot
.73458 .49099 Mdot
.48667 .36284 Mdot
.46929 .37504 Mdot
.4246 .55725 Mdot
.34177 .4071 Mdot
.56158 .20968 Mdot
.44599 .36164 Mdot
.66051 .76612 Mdot
.51867 .37008 Mdot
.34613 .39874 Mdot
.403 .60618 Mdot
.36521 .53886 Mdot
.48159 .5741 Mdot
.28019 .30647 Mdot
.49174 .35225 Mdot
.65199 .59931 Mdot
.3887 .60355 Mdot
.69364 .71681 Mdot
.45939 .38134 Mdot
.57704 .38259 Mdot
.49962 .28269 Mdot
.64559 .42208 Mdot
.76502 .67735 Mdot
.46644 .61112 Mdot
.65465 .37208 Mdot
.34482 .42486 Mdot
.4506 .63054 Mdot
.42375 .58776 Mdot
.63953 .54644 Mdot
.60671 .39643 Mdot
.21422 .46424 Mdot
.66418 .38573 Mdot
.66187 .4018 Mdot
.65114 .62602 Mdot
.46515 .59168 Mdot
.45565 .36753 Mdot
.48049 .33779 Mdot
.41635 .66011 Mdot
.62692 .17422 Mdot
.67118 .58142 Mdot
.47403 .39665 Mdot
.88671 .54888 Mdot
.42739 .6632 Mdot
.75215 .67774 Mdot
.20441 .59422 Mdot
.67407 .40456 Mdot
.43627 .65194 Mdot
.62738 .55265 Mdot
.53403 .31394 Mdot
.46524 .37562 Mdot
.40923 .65725 Mdot
.62791 .40236 Mdot
.32247 .39631 Mdot
.46926 .38878 Mdot
.35808 .30463 Mdot
.46478 .57269 Mdot
.30831 .31403 Mdot
.50609 .33243 Mdot
.31996 .74937 Mdot
.54478 .26115 Mdot
.64414 .57934 Mdot
.42057 .59361 Mdot
.6561 .60875 Mdot
.32542 .44363 Mdot
.51112 .45874 Mdot
.62503 .41412 Mdot
.34547 .66414 Mdot
.81931 .45768 Mdot
.46082 .39154 Mdot
.63761 .60418 Mdot
.49369 .61322 Mdot
.71919 .34093 Mdot
.46775 .60569 Mdot
.35853 .64996 Mdot
.22074 .45601 Mdot
.61056 .41226 Mdot
.66575 .41359 Mdot
.40783 .59231 Mdot
.3413 .44226 Mdot
.49014 .35812 Mdot
.45421 .35848 Mdot
.28581 .74044 Mdot
.67113 .33855 Mdot
.6136 .78472 Mdot
.47695 .58183 Mdot
.47959 .30677 Mdot
.68535 .33815 Mdot
.63711 .37833 Mdot
.49715 .56923 Mdot
.50659 .3632 Mdot
.28561 .45796 Mdot
.42368 .50232 Mdot
.39535 .60296 Mdot
.42162 .55226 Mdot
.66614 .40957 Mdot
.65345 .6292 Mdot
.45573 .33638 Mdot
.49306 .64965 Mdot
.40565 .41528 Mdot
.44839 .49977 Mdot
.72033 .73678 Mdot
.64638 .5951 Mdot
.37944 .28193 Mdot
.63977 .3817 Mdot
.3729 .64906 Mdot
.31483 .44201 Mdot
.4851 .3015 Mdot
.45446 .32622 Mdot
.43326 .62998 Mdot
.38042 .61082 Mdot
.70391 .73124 Mdot
.63459 .56152 Mdot
.65286 .41078 Mdot
.46135 .63413 Mdot
.76868 .52066 Mdot
.42208 .65287 Mdot
.61816 .39911 Mdot
.77239 .30374 Mdot
.45402 .55679 Mdot
.4709 .60022 Mdot
.55808 .21026 Mdot
.613 .59576 Mdot
.68477 .58226 Mdot
.79459 .63 Mdot
.47765 .5834 Mdot
.73358 .71448 Mdot
.64483 .59921 Mdot
.67331 .59375 Mdot
.61105 .26068 Mdot
.44097 .5867 Mdot
.53931 .55285 Mdot
.64188 .42774 Mdot
.66301 .4015 Mdot
.61573 .57441 Mdot
.51669 .58499 Mdot
.64293 .43188 Mdot
.52225 .18583 Mdot
.48596 .34377 Mdot
.77755 .37004 Mdot
.67117 .57674 Mdot
.65865 .46928 Mdot
.65677 .38803 Mdot
.66589 .79187 Mdot
.58012 .34981 Mdot
.45379 .64342 Mdot
.475 .58023 Mdot
.32737 .40026 Mdot
.48138 .63931 Mdot
.50539 .37746 Mdot
.64869 .38927 Mdot
.461 .79533 Mdot
.64796 .59035 Mdot
.45674 .61557 Mdot
.32902 .27964 Mdot
.18341 .47553 Mdot
.41751 .27105 Mdot
.65646 .55905 Mdot
.63481 .58404 Mdot
.47565 .31986 Mdot
.49515 .32101 Mdot
.453 .58035 Mdot
.61228 .42817 Mdot
.66447 .6079 Mdot
.61463 .40588 Mdot
.4985 .35525 Mdot
.45833 .3656 Mdot
.43413 .37023 Mdot
.3894 .59761 Mdot
.46508 .36914 Mdot
.23562 .40486 Mdot
.60387 .35323 Mdot
.64881 .62368 Mdot
.82131 .63092 Mdot
.73622 .49663 Mdot
.55426 .60796 Mdot
.35169 .40233 Mdot
.44465 .37565 Mdot
.66084 .37641 Mdot
.4164 .60858 Mdot
.41031 .62353 Mdot
.67954 .30537 Mdot
.65126 .37349 Mdot
.31971 .44043 Mdot
.67386 .38331 Mdot
.31677 .43946 Mdot
.32231 .30858 Mdot
.45039 .66023 Mdot
.38496 .63461 Mdot
.6507 .38589 Mdot
.46527 .36632 Mdot
.46828 .33553 Mdot
.3446 .45079 Mdot
.45837 .46374 Mdot
.48543 .38362 Mdot
.67552 .59028 Mdot
.40243 .75724 Mdot
.50754 .33975 Mdot
.46389 .62097 Mdot
.27003 .5289 Mdot
.63619 .20143 Mdot
.37192 .59881 Mdot
.61844 .25691 Mdot
.49545 .76924 Mdot
.3882 .6127 Mdot
.64383 .20589 Mdot
.64844 .36595 Mdot
.61683 .5864 Mdot
.44147 .3662 Mdot
.50314 .39342 Mdot
.53693 .57983 Mdot
.32113 .38652 Mdot
.46339 .55545 Mdot
.62379 .55003 Mdot
.6259 .54401 Mdot
.35806 .5371 Mdot
.28762 .28782 Mdot
.32914 .43807 Mdot
.34291 .43158 Mdot
.45996 .35822 Mdot
.15456 .55479 Mdot
.36968 .67556 Mdot
.31655 .43585 Mdot
.68444 .54772 Mdot
.43178 .63874 Mdot
.29093 .46814 Mdot
.61465 .52611 Mdot
.61371 .57605 Mdot
.35504 .51009 Mdot
.45669 .37752 Mdot
.62665 .57588 Mdot
.77531 .47895 Mdot
.50417 .58644 Mdot
.65041 .59138 Mdot
.61664 .40524 Mdot
.54391 .28053 Mdot
.67664 .58379 Mdot
.27492 .52261 Mdot
.61103 .43412 Mdot
.58206 .39773 Mdot
.40406 .51068 Mdot
.11197 .44307 Mdot
.64545 .38461 Mdot
.50686 .35723 Mdot
.47933 .33823 Mdot
.45428 .35906 Mdot
.63467 .56849 Mdot
.46033 .39169 Mdot
.63722 .56219 Mdot
.32265 .23426 Mdot
.667 .23613 Mdot
.31592 .43069 Mdot
.60222 .28352 Mdot
.6474 .55961 Mdot
.76754 .58933 Mdot
.51168 .11784 Mdot
.44154 .65338 Mdot
.60029 .40258 Mdot
.31732 .43076 Mdot
.17099 .59086 Mdot
.32918 .43263 Mdot
.50484 .82973 Mdot
.51292 .68654 Mdot
.45788 .60773 Mdot
.61929 .75144 Mdot
.35235 .44363 Mdot
.59398 .5762 Mdot
.42821 .5818 Mdot
.50038 .48931 Mdot
.33684 .43165 Mdot
.33699 .39434 Mdot
.45596 .58491 Mdot
.65238 .60588 Mdot
.46743 .37893 Mdot
.66478 .39312 Mdot
.35341 .42966 Mdot
.38597 .55663 Mdot
.4935 .5973 Mdot
.45489 .64594 Mdot
.74937 .58478 Mdot
.36069 .39341 Mdot
.64531 .38935 Mdot
.43002 .17201 Mdot
.51077 .32672 Mdot
.43528 .48029 Mdot
.69124 .753 Mdot
.67359 .50003 Mdot
.49124 .35153 Mdot
.46312 .33274 Mdot
.41555 .58185 Mdot
.40214 .71591 Mdot
.51526 .67157 Mdot
.40998 .45711 Mdot
.45068 .3929 Mdot
.45741 .35373 Mdot
.6883 .59216 Mdot
.35013 .71415 Mdot
.36728 .60595 Mdot
.66508 .41829 Mdot
.44448 .33876 Mdot
.65847 .24118 Mdot
.33225 .40207 Mdot
.53625 .68099 Mdot
.45636 .65899 Mdot
.45639 .64142 Mdot
.6319 .40441 Mdot
.62159 .40177 Mdot
.51608 .29132 Mdot
.40903 .78137 Mdot
.48398 .76962 Mdot
.71523 .4738 Mdot
.50709 .71079 Mdot
.67992 .56867 Mdot
.63439 .60109 Mdot
.59341 .30757 Mdot
.6537 .37883 Mdot
.38712 .61226 Mdot
.62927 .58057 Mdot
.30281 .47118 Mdot
.34283 .6449 Mdot
.33562 .61702 Mdot
.73825 .69445 Mdot
.43365 .60957 Mdot
.61654 .56089 Mdot
.61352 .59876 Mdot
.61375 .6047 Mdot
.68872 .43156 Mdot
.46387 .58261 Mdot
.43633 .60707 Mdot
.39612 .59455 Mdot
.71604 .30627 Mdot
.4582 .57564 Mdot
.70181 .42417 Mdot
.52872 .45902 Mdot
.64009 .66197 Mdot
.49785 .64407 Mdot
.66878 .37749 Mdot
.4336 .56544 Mdot
.33967 .44366 Mdot
.45826 .64982 Mdot
.33503 .62775 Mdot
.65566 .40345 Mdot
.47224 .53262 Mdot
.72526 .5053 Mdot
.40385 .64252 Mdot
.35305 .39828 Mdot
.69404 .51907 Mdot
.36863 .79081 Mdot
.2855 .41332 Mdot
.67464 .58881 Mdot
.48815 .34813 Mdot
.65627 .37404 Mdot
.46534 .35895 Mdot
.4001 .65088 Mdot
.58113 .30668 Mdot
.17824 .59271 Mdot
.49383 .48102 Mdot
.41368 .63459 Mdot
.37011 .66785 Mdot
.67384 .59743 Mdot
.51326 .34259 Mdot
.64934 .53754 Mdot
.42111 .57467 Mdot
.32133 .41747 Mdot
.34545 .42201 Mdot
.56382 .49999 Mdot
.2727 .68929 Mdot
.59224 .20877 Mdot
.63466 .39949 Mdot
.4452 .36565 Mdot
.31538 .44506 Mdot
.44045 .23544 Mdot
.6777 .3658 Mdot
.61792 .42588 Mdot
.65295 .4079 Mdot
.47976 .61251 Mdot
.43571 .35492 Mdot
.64496 .66268 Mdot
.51091 .32136 Mdot
.43421 .59363 Mdot
.49974 .33691 Mdot
.49647 .37376 Mdot
.31921 .41145 Mdot
.65519 .40763 Mdot
.49735 .35314 Mdot
.48667 .61341 Mdot
.64044 .5988 Mdot
.686 .42072 Mdot
.22756 .47956 Mdot
.2889 .29079 Mdot
.5649 .54039 Mdot
.60884 .59159 Mdot
.35248 .77348 Mdot
.63876 .4302 Mdot
.73385 .3375 Mdot
.20997 .47538 Mdot
.42847 .55827 Mdot
.64925 .18801 Mdot
.52272 .32394 Mdot
.49198 .37542 Mdot
.40151 .60547 Mdot
.51519 .30511 Mdot
.45956 .61166 Mdot
.49636 .36418 Mdot
.60635 .34207 Mdot
.61176 .61528 Mdot
.47081 .36561 Mdot
.47348 .66457 Mdot
.41853 .58703 Mdot
.61785 .5693 Mdot
.47228 .31346 Mdot
.45299 .5545 Mdot
.32248 .79051 Mdot
.62333 .39578 Mdot
.68021 .49602 Mdot
.25735 .52935 Mdot
.63595 .38143 Mdot
.64928 .58441 Mdot
.40589 .58044 Mdot
.34401 .42685 Mdot
.64341 .55742 Mdot
.33698 .65422 Mdot
.30601 .42741 Mdot
.76548 .32925 Mdot
.61243 .59819 Mdot
.48273 .37764 Mdot
.32914 .44766 Mdot
.50137 .60408 Mdot
.51632 .33463 Mdot
.5163 .25743 Mdot
.48876 .35518 Mdot
.40798 .58481 Mdot
.64103 .30747 Mdot
.654 .41085 Mdot
.44191 .61087 Mdot
.48071 .38197 Mdot
.61993 .2591 Mdot
.48362 .59867 Mdot
.40308 .59421 Mdot
.67341 .76631 Mdot
.70904 .63907 Mdot
.33142 .42818 Mdot
.65852 .61323 Mdot
.43785 .65208 Mdot
.34919 .40512 Mdot
.34665 .36092 Mdot
.47193 .62728 Mdot
.65641 .55675 Mdot
.49576 .56731 Mdot
.48355 .31576 Mdot
.62128 .38963 Mdot
.40956 .4656 Mdot
.34246 .39842 Mdot
.17034 .38132 Mdot
.4506 .33371 Mdot
.39929 .5831 Mdot
.42238 .65155 Mdot
.25658 .58576 Mdot
.6184 .58197 Mdot
.65141 .52446 Mdot
.4775 .59932 Mdot
.72077 .30704 Mdot
.44964 .62538 Mdot
.51335 .30704 Mdot
.67181 .5898 Mdot
.4727 .59074 Mdot
.66076 .43823 Mdot
.37096 .63515 Mdot
.31143 .40514 Mdot
.53234 .22157 Mdot
.49475 .57472 Mdot
.76738 .312 Mdot
.54741 .51209 Mdot
.47081 .36725 Mdot
.24889 .37468 Mdot
.31583 .78931 Mdot
.71355 .50822 Mdot
.63718 .57013 Mdot
.19651 .59472 Mdot
.45581 .36794 Mdot
.28903 .32016 Mdot
.37613 .80792 Mdot
.41318 .59341 Mdot
.42548 .57184 Mdot
.29274 .57363 Mdot
.51516 .33741 Mdot
.49588 .31527 Mdot
.40866 .66481 Mdot
.36893 .62881 Mdot
.45988 .37014 Mdot
.47117 .56728 Mdot
.50626 .63786 Mdot
.60149 .40036 Mdot
.66419 .56344 Mdot
.60946 .41464 Mdot
.62828 .43306 Mdot
.49637 .20668 Mdot
.52172 .50509 Mdot
.61973 .39607 Mdot
.67795 .39974 Mdot
.32992 .48729 Mdot
.45176 .797 Mdot
.35135 .42984 Mdot
.29564 .72867 Mdot
.46254 .35027 Mdot
.46806 .58919 Mdot
.62013 .60745 Mdot
.46599 .76436 Mdot
.34715 .36883 Mdot
.81082 .49366 Mdot
.3941 .59503 Mdot
.46156 .38124 Mdot
.66614 .48709 Mdot
.47459 .54435 Mdot
.4305 .3836 Mdot
.46429 .62936 Mdot
.50931 .37356 Mdot
.50786 .81017 Mdot
.42227 .23688 Mdot
.49692 .3958 Mdot
.66782 .61879 Mdot
.4558 .63815 Mdot
.60452 .55742 Mdot
.6375 .37886 Mdot
.34651 .43836 Mdot
.3366 .42593 Mdot
.44078 .58162 Mdot
.38896 .69165 Mdot
.30372 .32902 Mdot
.43282 .58556 Mdot
.42961 .6362 Mdot
.60405 .38246 Mdot
.43094 .64336 Mdot
.416 .6481 Mdot
.39718 .62053 Mdot
.39409 .6313 Mdot
.66214 .40252 Mdot
.53673 .30287 Mdot
.5352 .59684 Mdot
.44743 .68163 Mdot
.62674 .43915 Mdot
.20453 .57598 Mdot
.63977 .43203 Mdot
.38879 .81579 Mdot
.6711 .4077 Mdot
.3323 .42098 Mdot
.21849 .58686 Mdot
.42508 .68353 Mdot
.65919 .55429 Mdot
.60669 .46573 Mdot
.33081 .44495 Mdot
.65026 .39321 Mdot
.50009 .363 Mdot
.68641 .76243 Mdot
.57595 .57951 Mdot
.68494 .6365 Mdot
.68024 .51583 Mdot
.54072 .29813 Mdot
.473 .31866 Mdot
.59615 .58427 Mdot
.54679 .79792 Mdot
.41544 .64385 Mdot
.35004 .40637 Mdot
.45038 .58062 Mdot
.63673 .37715 Mdot
.45278 .37299 Mdot
.30507 .25651 Mdot
.34711 .41849 Mdot
.80615 .65471 Mdot
.47336 .33345 Mdot
.40979 .63529 Mdot
.6431 .43171 Mdot
.84445 .56717 Mdot
.6114 .41432 Mdot
.45472 .70224 Mdot
.62377 .59629 Mdot
.24694 .29498 Mdot
.64836 .56546 Mdot
.48909 .25132 Mdot
.87231 .43991 Mdot
.40181 .25208 Mdot
.64266 .60233 Mdot
.39696 .43163 Mdot
.43574 .62395 Mdot
.45628 .64543 Mdot
.37141 .23291 Mdot
.6457 .61448 Mdot
.42182 .64433 Mdot
.68065 .31911 Mdot
.66705 .34185 Mdot
.74208 .67041 Mdot
.47592 .32153 Mdot
.46239 .6139 Mdot
.60065 .39385 Mdot
.6361 .37158 Mdot
.44842 .34455 Mdot
.62339 .42864 Mdot
.43665 .60393 Mdot
.6477 .56036 Mdot
.41551 .35803 Mdot
.33776 .41259 Mdot
.16418 .54441 Mdot
.29701 .42182 Mdot
.49178 .35022 Mdot
.42216 .55409 Mdot
.45926 .365 Mdot
.48228 .90165 Mdot
.43907 .61934 Mdot
.64659 .59985 Mdot
.42611 .63927 Mdot
.45122 .63844 Mdot
.38843 .62212 Mdot
.46966 .37715 Mdot
.22818 .44205 Mdot
.48652 .602 Mdot
.62561 .41685 Mdot
.55595 .69913 Mdot
.49782 .62347 Mdot
.3991 .36814 Mdot
.33987 .59167 Mdot
.73501 .5622 Mdot
.63146 .60728 Mdot
.4773 .36359 Mdot
.64386 .59065 Mdot
.7395 .32007 Mdot
.64957 .58433 Mdot
.52658 .72915 Mdot
.55961 .79821 Mdot
.64201 .75897 Mdot
.6608 .74669 Mdot
.44753 .43647 Mdot
.65267 .61459 Mdot
.29807 .38966 Mdot
.66591 .607 Mdot
.61407 .58117 Mdot
.57753 .11166 Mdot
.62004 .54945 Mdot
.46954 .61565 Mdot
.47936 .64727 Mdot
.44057 .2483 Mdot
.27062 .48755 Mdot
.42198 .62123 Mdot
.41889 .62802 Mdot
.31914 .4474 Mdot
.73783 .32436 Mdot
.59086 .31886 Mdot
.71305 .6365 Mdot
.19221 .4705 Mdot
.45264 .58241 Mdot
.45218 .65263 Mdot
.498 .6535 Mdot
.84284 .49239 Mdot
.46399 .20202 Mdot
.67828 .61722 Mdot
.43794 .68013 Mdot
.34602 .26754 Mdot
.39179 .5973 Mdot
.48094 .59906 Mdot
.43458 .61481 Mdot
.45536 .36868 Mdot
.64346 .61161 Mdot
.40514 .65369 Mdot
.24641 .5892 Mdot
.47583 .6128 Mdot
.67292 .4734 Mdot
.16655 .41983 Mdot
.46734 .61051 Mdot
.68714 .57368 Mdot
.45289 .64701 Mdot
.6217 .57355 Mdot
.60644 .56924 Mdot
.41479 .67138 Mdot
.50136 .71012 Mdot
.68914 .59347 Mdot
.43365 .59304 Mdot
.5033 .36148 Mdot
.31184 .73385 Mdot
.41793 .57948 Mdot
.35191 .42758 Mdot
.47716 .58398 Mdot
.33537 .38884 Mdot
.42777 .62785 Mdot
.44735 .33864 Mdot
.46506 .75332 Mdot
.46883 .35254 Mdot
.38714 .21155 Mdot
.43407 .36423 Mdot
.78402 .68284 Mdot
.60745 .58866 Mdot
.62308 .29611 Mdot
.78954 .40533 Mdot
.69952 .32632 Mdot
.56828 .42611 Mdot
.48769 .43578 Mdot
.61237 .42745 Mdot
.62105 .58648 Mdot
.75867 .40001 Mdot
.39341 .34481 Mdot
.40508 .30058 Mdot
.47707 .3887 Mdot
.39543 .16625 Mdot
.75772 .32417 Mdot
.391 .58484 Mdot
.57553 .76888 Mdot
.60267 .72499 Mdot
.38763 .60451 Mdot
.38614 .62353 Mdot
.52751 .35964 Mdot
.48336 .58148 Mdot
.76788 .52815 Mdot
.49261 .3391 Mdot
.33501 .44396 Mdot
.66583 .60293 Mdot
.32131 .39653 Mdot
.38085 .3887 Mdot
.49353 .43237 Mdot
.49916 .35974 Mdot
.4598 .55737 Mdot
.41792 .61649 Mdot
.62421 .56737 Mdot
.5414 .64019 Mdot
.68138 .58168 Mdot
.32031 .43411 Mdot
.48736 .33165 Mdot
.59939 .18709 Mdot
.4164 .61922 Mdot
.66463 .57279 Mdot
.5711 .44671 Mdot
.43339 .65007 Mdot
.64638 .38148 Mdot
.4377 .62961 Mdot
.65864 .6059 Mdot
.43072 .64298 Mdot
.6471 .5658 Mdot
.4868 .34732 Mdot
.40212 .62895 Mdot
.39862 .60836 Mdot
.81182 .63356 Mdot
.31729 .42326 Mdot
.59524 .58656 Mdot
.39894 .48195 Mdot
.4421 .65674 Mdot
.59104 .2666 Mdot
.46522 .62576 Mdot
.69103 .62286 Mdot
.39758 .57509 Mdot
.67989 .49757 Mdot
.41352 .67387 Mdot
.44379 .57682 Mdot
.60123 .50663 Mdot
.58978 .72634 Mdot
.55251 .56246 Mdot
.67877 .38435 Mdot
.59286 .58363 Mdot
.72719 .67832 Mdot
.44139 .30807 Mdot
.47201 .31146 Mdot
.3285 .5251 Mdot
.41319 .66122 Mdot
.46011 .60587 Mdot
.73395 .57127 Mdot
.34492 .40402 Mdot
.64098 .55193 Mdot
.31636 .43888 Mdot
.76606 .68401 Mdot
.30291 .42408 Mdot
.51119 .30399 Mdot
.30523 .3165 Mdot
.56367 .18279 Mdot
.31461 .44361 Mdot
.6607 .6064 Mdot
.35745 .27111 Mdot
.41318 .64919 Mdot
.56227 .5134 Mdot
.32714 .41376 Mdot
.30417 .21962 Mdot
.41478 .64605 Mdot
.57057 .43101 Mdot
.61396 .39861 Mdot
.31551 .44343 Mdot
.60855 .4344 Mdot
.41362 .60252 Mdot
.59377 .31995 Mdot
.63812 .57097 Mdot
.61487 .44239 Mdot
.50792 .60468 Mdot
.31733 .43451 Mdot
.44689 .33487 Mdot
.62845 .45035 Mdot
.67257 .41016 Mdot
.23712 .64212 Mdot
.28515 .26519 Mdot
.48445 .33005 Mdot
.74887 .63951 Mdot
.67068 .37981 Mdot
.4206 .65754 Mdot
.74852 .35535 Mdot
.45586 .64291 Mdot
.62546 .23226 Mdot
.48485 .36154 Mdot
.5408 .30199 Mdot
.43875 .65183 Mdot
.4273 .57466 Mdot
.62227 .54393 Mdot
.47436 .34477 Mdot
.65944 .57921 Mdot
.62153 .61839 Mdot
.48704 .34493 Mdot
.64649 .57574 Mdot
.33394 .45261 Mdot
.78491 .45549 Mdot
.6608 .41632 Mdot
.63556 .42072 Mdot
.45389 .3584 Mdot
.47322 .36905 Mdot
.46511 .36263 Mdot
.43782 .6306 Mdot
.66759 .57178 Mdot
.42141 .59907 Mdot
.45901 .56585 Mdot
.5739 .68682 Mdot
.63242 .60982 Mdot
.42909 .60322 Mdot
.46888 .48159 Mdot
.4499 .69405 Mdot
.5068 .34979 Mdot
.61834 .39566 Mdot
.66264 .30279 Mdot
.5276 .25537 Mdot
.46063 .61729 Mdot
.24723 .43293 Mdot
.66435 .60651 Mdot
.33671 .43352 Mdot
.29968 .43073 Mdot
.32866 .43108 Mdot
.64012 .35846 Mdot
.61368 .60424 Mdot
.64574 .64715 Mdot
.46216 .61074 Mdot
.6831 .63019 Mdot
.68709 .61457 Mdot
.34861 .282 Mdot
.62172 .39381 Mdot
.42499 .64096 Mdot
.41912 .46664 Mdot
.45731 .78142 Mdot
.44886 .64292 Mdot
.49443 .63052 Mdot
.22286 .42339 Mdot
.39374 .55804 Mdot
.65957 .55076 Mdot
.83495 .58664 Mdot
.49737 .61688 Mdot
.65047 .23233 Mdot
.16193 .60313 Mdot
.45868 .62577 Mdot
.43885 .57178 Mdot
.41059 .61565 Mdot
.46246 .64766 Mdot
.69178 .58592 Mdot
.29637 .48766 Mdot
.67363 .37998 Mdot
.65457 .63312 Mdot
.65141 .37937 Mdot
.45082 .39016 Mdot
.54132 .30483 Mdot
.62234 .59242 Mdot
.32882 .40008 Mdot
.17912 .46295 Mdot
.80262 .58621 Mdot
.45534 .33716 Mdot
.53987 .18881 Mdot
.32776 .41597 Mdot
.45661 .66307 Mdot
.35609 .43152 Mdot
.48534 .3201 Mdot
.64252 .42252 Mdot
.49077 .56806 Mdot
.63861 .60289 Mdot
.67543 .58061 Mdot
.42645 .64592 Mdot
.29389 .3068 Mdot
.62625 .38343 Mdot
.68151 .38137 Mdot
.47798 .61897 Mdot
.50051 .61056 Mdot
.65716 .57837 Mdot
.45709 .34809 Mdot
.66084 .75355 Mdot
.34727 .42653 Mdot
.38973 .59755 Mdot
.43436 .64601 Mdot
.67562 .76327 Mdot
.62518 .41992 Mdot
.43997 .33639 Mdot
.41789 .55994 Mdot
.70865 .45626 Mdot
.43462 .55832 Mdot
.48863 .65969 Mdot
.50548 .35796 Mdot
.52687 .57939 Mdot
.38267 .63467 Mdot
.601 .60745 Mdot
.60708 .42332 Mdot
.64967 .59557 Mdot
.59797 .60509 Mdot
.79163 .48818 Mdot
.6539 .38685 Mdot
.43278 .61746 Mdot
.62997 .38875 Mdot
.47109 .62866 Mdot
.49166 .62073 Mdot
.61804 .39886 Mdot
.65884 .57784 Mdot
.19523 .58019 Mdot
.47327 .26136 Mdot
.47754 .63762 Mdot
.40121 .65718 Mdot
.27361 .469 Mdot
.38384 .42733 Mdot
.42111 .57433 Mdot
.67498 .60066 Mdot
.41124 .60685 Mdot
.60665 .39803 Mdot
.34834 .44633 Mdot
.64215 .60086 Mdot
.46544 .33544 Mdot
.45694 .33117 Mdot
.72291 .50892 Mdot
.4981 .3751 Mdot
.42674 .57023 Mdot
.55779 .60226 Mdot
.65357 .54347 Mdot
.19261 .42178 Mdot
.48572 .34094 Mdot
.35506 .41915 Mdot
.40736 .58936 Mdot
.32993 .57307 Mdot
.59727 .40137 Mdot
.57589 .13222 Mdot
.78835 .56163 Mdot
.36284 .41994 Mdot
.6613 .64416 Mdot
.43864 .35415 Mdot
.39868 .65006 Mdot
.35197 .42584 Mdot
.47485 .31976 Mdot
.47847 .63015 Mdot
.44738 .68035 Mdot
.5229 .64815 Mdot
.4949 .41858 Mdot
.6289 .39137 Mdot
.49558 .38215 Mdot
.35942 .40419 Mdot
.4578 .39653 Mdot
.60533 .57659 Mdot
.46165 .57945 Mdot
.42595 .55481 Mdot
.45651 .3466 Mdot
.46562 .31099 Mdot
.43118 .5977 Mdot
.64967 .60812 Mdot
.4469 .27462 Mdot
.45463 .58661 Mdot
.67857 .34738 Mdot
.6733 .61396 Mdot
.48139 .3246 Mdot
.43968 .57452 Mdot
.29174 .41212 Mdot
.46887 .33735 Mdot
.50631 .34705 Mdot
.45058 .65327 Mdot
.31371 .44485 Mdot
.37676 .63412 Mdot
.65155 .42354 Mdot
.38602 .17564 Mdot
.60668 .39729 Mdot
.4263 .31983 Mdot
.3753 .57608 Mdot
.72629 .40697 Mdot
.62124 .6009 Mdot
.37051 .52153 Mdot
.67934 .31808 Mdot
.51026 .63171 Mdot
.30115 .69277 Mdot
.65679 .46919 Mdot
.21444 .39635 Mdot
.31873 .67821 Mdot
.32416 .41086 Mdot
.65062 .39581 Mdot
.43866 .5716 Mdot
.59838 .40734 Mdot
.35346 .4189 Mdot
.39334 .21096 Mdot
.41554 .57976 Mdot
.6727 .59412 Mdot
.43399 .6036 Mdot
.67278 .58212 Mdot
.47082 .64491 Mdot
.375 .61729 Mdot
.69308 .32284 Mdot
.41906 .49883 Mdot
.43069 .5588 Mdot
.87613 .56636 Mdot
.48714 .68185 Mdot
.34154 .43648 Mdot
.41774 .5928 Mdot
.46511 .40722 Mdot
.64707 .37377 Mdot
.70661 .40636 Mdot
.45552 .37093 Mdot
.66396 .41839 Mdot
.65136 .57705 Mdot
.48382 .3586 Mdot
.45191 .34156 Mdot
.52355 .57512 Mdot
.36037 .43203 Mdot
.64113 .4129 Mdot
.47267 .58769 Mdot
.42174 .57735 Mdot
.76045 .63286 Mdot
.38273 .34528 Mdot
.56227 .64621 Mdot
.83405 .42228 Mdot
.60963 .60744 Mdot
.32742 .44303 Mdot
.46545 .37862 Mdot
.44311 .56387 Mdot
.44189 .60554 Mdot
.60439 .27698 Mdot
.68622 .59219 Mdot
.509 .46287 Mdot
.55698 .65233 Mdot
.30247 .47029 Mdot
.36123 .4968 Mdot
.66811 .60297 Mdot
.35216 .49542 Mdot
.36469 .39882 Mdot
.24437 .69729 Mdot
.42152 .49499 Mdot
.61598 .39564 Mdot
.33352 .49155 Mdot
.64089 .55256 Mdot
.48535 .61106 Mdot
.50236 .365 Mdot
.49839 .37264 Mdot
.6569 .59166 Mdot
.43687 .38903 Mdot
.32268 .40746 Mdot
.4554 .57059 Mdot
.76955 .59659 Mdot
.75151 .47929 Mdot
.44822 .36467 Mdot
.51275 .56797 Mdot
.65442 .40655 Mdot
.42731 .64726 Mdot
.31027 .42305 Mdot
.64009 .38453 Mdot
.45845 .80654 Mdot
.65324 .33326 Mdot
.41864 .58314 Mdot
.68088 .76238 Mdot
.65252 .38859 Mdot
.39171 .7223 Mdot
.46278 .58839 Mdot
.63589 .42864 Mdot
.38957 .54461 Mdot
.53711 .27626 Mdot
.52082 .49114 Mdot
.37827 .81087 Mdot
.54813 .48254 Mdot
.46344 .38395 Mdot
.53903 .28816 Mdot
.68498 .29778 Mdot
.66861 .3843 Mdot
.44466 .32313 Mdot
.52011 .50718 Mdot
.60848 .4326 Mdot
.44422 .6649 Mdot
.46127 .62896 Mdot
.45532 .204 Mdot
.61722 .46991 Mdot
.47452 .24709 Mdot
.73163 .53292 Mdot
.44202 .65759 Mdot
.38221 .60053 Mdot
.44567 .6037 Mdot
.67775 .56394 Mdot
.62654 .39997 Mdot
.8545 .57988 Mdot
.63725 .37934 Mdot
.54994 .68352 Mdot
.45897 .35408 Mdot
.47754 .32146 Mdot
.46437 .61442 Mdot
.5743 .43602 Mdot
.37385 .74496 Mdot
.4365 .59945 Mdot
.36812 .44153 Mdot
.46109 .21565 Mdot
.48914 .6316 Mdot
.62964 .60333 Mdot
.52435 .60405 Mdot
.36446 .58236 Mdot
.66261 .41452 Mdot
.3328 .40339 Mdot
.35418 .55304 Mdot
.64517 .41989 Mdot
.45863 .6056 Mdot
.72078 .43401 Mdot
.44612 .63406 Mdot
.47639 .63726 Mdot
.53484 .66828 Mdot
.30175 .43602 Mdot
.47602 .35515 Mdot
.32637 .42939 Mdot
.61619 .58341 Mdot
.49598 .08798 Mdot
.30294 .42124 Mdot
.41597 .78165 Mdot
.41769 .19507 Mdot
.33758 .49042 Mdot
.63832 .55069 Mdot
.35994 .41953 Mdot
.61882 .38987 Mdot
.31101 .73558 Mdot
.4537 .69756 Mdot
.64291 .46681 Mdot
.45667 .59113 Mdot
.58185 .58625 Mdot
.67517 .57176 Mdot
.61863 .44224 Mdot
.60227 .57294 Mdot
.53893 .55671 Mdot
.48289 .62725 Mdot
.66511 .38985 Mdot
.72322 .47257 Mdot
.67432 .37761 Mdot
.41109 .43602 Mdot
.42312 .58892 Mdot
.64831 .60263 Mdot
.38223 .62627 Mdot
.68839 .56312 Mdot
.43726 .34313 Mdot
.44878 .55457 Mdot
.32177 .4067 Mdot
.72081 .40801 Mdot
.4808 .32801 Mdot
.34544 .48612 Mdot
.62298 .56933 Mdot
.63204 .35706 Mdot
.61824 .56736 Mdot
.65929 .543 Mdot
.64153 .43187 Mdot
.61175 .5572 Mdot
.44387 .57143 Mdot
.5181 .4958 Mdot
.63099 .56772 Mdot
.63783 .40444 Mdot
.33999 .40764 Mdot
.6508 .56963 Mdot
.51893 .31075 Mdot
.40825 .58705 Mdot
.46967 .37532 Mdot
.38235 .40087 Mdot
.5842 .57523 Mdot
.32105 .45397 Mdot
.47964 .31226 Mdot
.337 .39419 Mdot
.23008 .36477 Mdot
.66031 .42838 Mdot
.51182 .6907 Mdot
.3769 .42593 Mdot
.6617 .55508 Mdot
.2083 .48556 Mdot
.4672 .57007 Mdot
.40551 .58989 Mdot
.33823 .39024 Mdot
.67529 .57188 Mdot
.20066 .66769 Mdot
.39361 .70136 Mdot
.42113 .42617 Mdot
.63954 .36781 Mdot
.8017 .66697 Mdot
.41325 .42959 Mdot
.15425 .56642 Mdot
.5137 .578 Mdot
.49495 .31331 Mdot
.45397 .61591 Mdot
.64812 .2829 Mdot
.31765 .42837 Mdot
.40216 .3624 Mdot
.38498 .57938 Mdot
.48153 .35435 Mdot
.39979 .61476 Mdot
.59141 .50775 Mdot
.35987 .68486 Mdot
.35289 .40369 Mdot
.3158 .29657 Mdot
.58783 .57144 Mdot
.3357 .41363 Mdot
.49001 .32648 Mdot
.41901 .51023 Mdot
.47968 .6301 Mdot
.44091 .66588 Mdot
.29989 .46805 Mdot
.66504 .56628 Mdot
.48126 .37953 Mdot
.64763 .42448 Mdot
.33791 .40241 Mdot
.41866 .61493 Mdot
.45768 .5645 Mdot
.59767 .26331 Mdot
.65898 .40147 Mdot
.51403 .33956 Mdot
.60759 .41012 Mdot
.44108 .35499 Mdot
.48828 .6033 Mdot
.46443 .32669 Mdot
.4271 .67182 Mdot
.67937 .45432 Mdot
.52695 .67997 Mdot
.58481 .73833 Mdot
.48948 .35747 Mdot
.47256 .80692 Mdot
.65856 .39858 Mdot
.61325 .41857 Mdot
.47487 .18591 Mdot
.47301 .69328 Mdot
.77848 .60873 Mdot
.27281 .64459 Mdot
.66507 .39944 Mdot
.64607 .4089 Mdot
.47072 .37432 Mdot
.60981 .55901 Mdot
.60379 .59944 Mdot
.44417 .35078 Mdot
.26469 .52944 Mdot
.64274 .55246 Mdot
.28471 .69982 Mdot
.75305 .65679 Mdot
.46659 .66674 Mdot
.48527 .2883 Mdot
.34151 .428 Mdot
.27777 .52722 Mdot
.58268 .50975 Mdot
.4142 .57894 Mdot
.34278 .53668 Mdot
.45548 .35314 Mdot
.57787 .42229 Mdot
.37487 .8006 Mdot
.40082 .62188 Mdot
.46668 .58788 Mdot
.4511 .60759 Mdot
.35899 .43864 Mdot
.4536 .72826 Mdot
.45245 .57384 Mdot
.26225 .52911 Mdot
.4334 .65424 Mdot
.36671 .69966 Mdot
.33372 .42776 Mdot
.50265 .50793 Mdot
.38851 .37016 Mdot
.82389 .60312 Mdot
.35898 .672 Mdot
.65878 .41925 Mdot
.41681 .30853 Mdot
.61052 .42066 Mdot
.54495 .72883 Mdot
.40052 .49088 Mdot
.61634 .61198 Mdot
.41833 .57673 Mdot
.49253 .34869 Mdot
.67514 .5724 Mdot
.55938 .28539 Mdot
.54169 .09915 Mdot
.67301 .40278 Mdot
.26865 .77448 Mdot
.62823 .42815 Mdot
.45147 .34315 Mdot
.65663 .57921 Mdot
.53632 .80314 Mdot
.7655 .56722 Mdot
.64892 .57042 Mdot
.18361 .6147 Mdot
.70486 .59449 Mdot
.38124 .53058 Mdot
.62281 .54601 Mdot
.643 .40416 Mdot
.5849 .40557 Mdot
.53216 .5418 Mdot
.47952 .59785 Mdot
.49706 .43661 Mdot
.3688 .73735 Mdot
.46538 .56919 Mdot
.49138 .33689 Mdot
.50881 .67894 Mdot
.3405 .52441 Mdot
.62202 .55237 Mdot
.67537 .3491 Mdot
.46042 .58186 Mdot
.44252 .64763 Mdot
.48193 .62339 Mdot
.80205 .53665 Mdot
.24059 .69472 Mdot
.48664 .60485 Mdot
.46014 .65177 Mdot
.48333 .3564 Mdot
.36137 .45969 Mdot
.40297 .25603 Mdot
.69621 .65471 Mdot
.39601 .62536 Mdot
.33765 .41812 Mdot
.34884 .38944 Mdot
.47122 .56819 Mdot
.51104 .49771 Mdot
.72583 .42355 Mdot
.47171 .5855 Mdot
.50718 .67764 Mdot
.5403 .37114 Mdot
.5145 .33252 Mdot
.46407 .33903 Mdot
.59194 .57863 Mdot
.45007 .35035 Mdot
.44446 .34057 Mdot
.47086 .79483 Mdot
.53244 .47258 Mdot
.68329 .43806 Mdot
.32248 .43611 Mdot
.44172 .61271 Mdot
.54808 .587 Mdot
.71221 .44462 Mdot
.61459 .43201 Mdot
.63314 .59482 Mdot
.63439 .37349 Mdot
.31275 .38203 Mdot
.78756 .53448 Mdot
.45803 .38908 Mdot
.662 .40954 Mdot
.67641 .41491 Mdot
.33893 .41951 Mdot
.59956 .42155 Mdot
.58026 .36524 Mdot
.49601 .59203 Mdot
.5527 .77815 Mdot
.43643 .59315 Mdot
.17059 .48151 Mdot
.64963 .41203 Mdot
.60898 .37731 Mdot
.46754 .60161 Mdot
.47185 .3361 Mdot
.40922 .53111 Mdot
.47935 .60262 Mdot
.45096 .35099 Mdot
.39124 .5819 Mdot
.30005 .41285 Mdot
.669 .61197 Mdot
.76221 .57085 Mdot
.39807 .16261 Mdot
.36053 .42952 Mdot
.56503 .28113 Mdot
.40119 .58688 Mdot
.26933 .29363 Mdot
.65173 .5672 Mdot
.41224 .56719 Mdot
.35629 .50864 Mdot
.63276 .5615 Mdot
.64115 .58785 Mdot
.4342 .63309 Mdot
.6114 .40059 Mdot
.4802 .32613 Mdot
.33945 .42368 Mdot
.1527 .50876 Mdot
.44597 .58612 Mdot
.40283 .60646 Mdot
.33229 .41511 Mdot
.65678 .38552 Mdot
.44109 .55888 Mdot
.2727 .59207 Mdot
.22597 .69925 Mdot
.63058 .43011 Mdot
.41014 .64075 Mdot
.53401 .74738 Mdot
.37079 .68601 Mdot
.21468 .33149 Mdot
.55148 .51254 Mdot
.47412 .36077 Mdot
.36186 .6298 Mdot
.71786 .23758 Mdot
.33683 .4042 Mdot
.79726 .59127 Mdot
.44106 .64822 Mdot
.41622 .62485 Mdot
.6841 .58814 Mdot
.42401 .59735 Mdot
.62527 .59389 Mdot
.49181 .15559 Mdot
.70683 .74223 Mdot
.59836 .58307 Mdot
.65073 .55031 Mdot
.34238 .57898 Mdot
.6937 .37496 Mdot
.65602 .58906 Mdot
.49398 .61927 Mdot
.46917 .49134 Mdot
.7223 .57344 Mdot
.3576 .41945 Mdot
.23763 .42402 Mdot
.41202 .68605 Mdot
.25988 .4286 Mdot
.20286 .5786 Mdot
.51412 .65 Mdot
.40924 .45046 Mdot
.62021 .42087 Mdot
.40029 .623 Mdot
.50075 .37127 Mdot
.50363 .37047 Mdot
.42831 .67357 Mdot
.44215 .6245 Mdot
.6182 .57805 Mdot
.3473 .41123 Mdot
.6635 .37703 Mdot
.41816 .62406 Mdot
.37871 .51774 Mdot
.33299 .39752 Mdot
.60245 .56835 Mdot
.54467 .69757 Mdot
.29521 .43505 Mdot
.37714 .64787 Mdot
.47651 .59611 Mdot
.43361 .60954 Mdot
.53145 .53938 Mdot
.62254 .40352 Mdot
.21156 .57266 Mdot
.47283 .65003 Mdot
.77648 .6752 Mdot
.69666 .4089 Mdot
.3697 .60264 Mdot
.6092 .57196 Mdot
.67173 .34921 Mdot
.43572 .37944 Mdot
.79361 .44244 Mdot
.42403 .58231 Mdot
.30614 .30018 Mdot
.44932 .20677 Mdot
.44979 .32241 Mdot
.6961 .57993 Mdot
.32815 .43447 Mdot
.43714 .60257 Mdot
.49668 .71088 Mdot
.46213 .62582 Mdot
.35911 .38753 Mdot
.50496 .33987 Mdot
.61842 .419 Mdot
.20216 .41648 Mdot
.4984 .37797 Mdot
.64349 .58996 Mdot
.58956 .83743 Mdot
.62547 .59546 Mdot
.60247 .59764 Mdot
.55864 .69639 Mdot
.62101 .40435 Mdot
.64331 .16867 Mdot
.51821 .16516 Mdot
.49062 .59603 Mdot
.65872 .39013 Mdot
.65853 .59813 Mdot
.42119 .64771 Mdot
.70482 .58064 Mdot
.62435 .61131 Mdot
.49032 .61487 Mdot
.41152 .62295 Mdot
.40716 .23919 Mdot
.33733 .74372 Mdot
.32631 .43468 Mdot
.61409 .59342 Mdot
.77103 .53876 Mdot
.42186 .6504 Mdot
.46306 .60988 Mdot
.62136 .24177 Mdot
.35587 .43864 Mdot
.76742 .48389 Mdot
.44186 .64789 Mdot
.62007 .80299 Mdot
.52974 .6025 Mdot
.68474 .60062 Mdot
.61338 .42492 Mdot
.81171 .622 Mdot
.57037 .37007 Mdot
.62548 .59237 Mdot
.32017 .40145 Mdot
.62648 .54241 Mdot
.44398 .79587 Mdot
.64991 .37949 Mdot
.659 .60592 Mdot
.4113 .46463 Mdot
.63486 .39384 Mdot
.65033 .41518 Mdot
.58383 .68443 Mdot
.4299 .36476 Mdot
.36434 .4247 Mdot
.64372 .41157 Mdot
.72973 .32987 Mdot
.64121 .39881 Mdot
.49741 .16511 Mdot
.40384 .62721 Mdot
.30713 .54468 Mdot
.42534 .3178 Mdot
.39309 .68545 Mdot
.65655 .40883 Mdot
.3258 .45025 Mdot
.47669 .63195 Mdot
.60128 .56038 Mdot
.35075 .41124 Mdot
.61181 .45676 Mdot
.45858 .37014 Mdot
.61968 .56386 Mdot
.5934 .44837 Mdot
.67466 .58383 Mdot
.75787 .40084 Mdot
.3894 .18977 Mdot
.32891 .64098 Mdot
.7693 .56185 Mdot
.48006 .631 Mdot
.24497 .65269 Mdot
.40877 .64471 Mdot
.44191 .63273 Mdot
.48724 .32912 Mdot
.32225 .53834 Mdot
.65908 .57898 Mdot
.17446 .56705 Mdot
.66217 .41356 Mdot
.82257 .60949 Mdot
.35754 .65985 Mdot
.39475 .58798 Mdot
.6299 .57028 Mdot
.67757 .60381 Mdot
.58426 .71547 Mdot
.4901 .39264 Mdot
.39478 .59205 Mdot
.50665 .58412 Mdot
.44042 .67716 Mdot
.64986 .42091 Mdot
.45251 .48414 Mdot
.4589 .38388 Mdot
.33717 .22431 Mdot
.50392 .33565 Mdot
.26953 .39472 Mdot
.60526 .5601 Mdot
.30325 .4202 Mdot
.46559 .60844 Mdot
.54228 .63137 Mdot
.68696 .58823 Mdot
.33832 .39101 Mdot
.32206 .4462 Mdot
.55549 .25307 Mdot
.61894 .39805 Mdot
.48216 .59841 Mdot
.44251 .57425 Mdot
.42222 .60408 Mdot
.43839 .62807 Mdot
.67193 .40329 Mdot
.47851 .62481 Mdot
.59119 .41988 Mdot
.80005 .44344 Mdot
.29494 .57805 Mdot
.55419 .48394 Mdot
.57438 .20749 Mdot
.62755 .55089 Mdot
.73064 .34887 Mdot
.39418 .55407 Mdot
.79196 .38825 Mdot
.38317 .22315 Mdot
.50389 .60259 Mdot
.45903 .32807 Mdot
.35092 .59141 Mdot
.47807 .38727 Mdot
.15133 .59212 Mdot
.64772 .26532 Mdot
.32664 .73324 Mdot
.41959 .5783 Mdot
.51411 .49311 Mdot
.70547 .28871 Mdot
.41458 .65234 Mdot
.58972 .25094 Mdot
.62282 .23015 Mdot
.3463 .27225 Mdot
.31283 .44227 Mdot
.43778 .57963 Mdot
.55165 .57442 Mdot
.44904 .57108 Mdot
.45799 .61459 Mdot
.48026 .62433 Mdot
.6505 .36965 Mdot
.42249 .56536 Mdot
.46517 .64003 Mdot
.3027 .33694 Mdot
.38174 .49663 Mdot
.50496 .32088 Mdot
.45725 .18922 Mdot
.30231 .42461 Mdot
.62575 .56999 Mdot
.23364 .67266 Mdot
.61699 .395 Mdot
.59249 .71735 Mdot
.4368 .62022 Mdot
.4322 .24778 Mdot
.65718 .33124 Mdot
.32025 .40305 Mdot
.47673 .31682 Mdot
.33239 .75559 Mdot
.49139 .34428 Mdot
.65629 .34774 Mdot
.47561 .33432 Mdot
.36327 .6018 Mdot
.61673 .58059 Mdot
.48147 .58386 Mdot
.63797 .41392 Mdot
.46114 .33666 Mdot
.27225 .48009 Mdot
.44615 .6061 Mdot
.48636 .34525 Mdot
.48285 .58848 Mdot
.70952 .6288 Mdot
.7197 .65912 Mdot
.45068 .33272 Mdot
.65108 .43683 Mdot
.62685 .41214 Mdot
.3074 .42911 Mdot
.62576 .56324 Mdot
.62972 .59285 Mdot
.64183 .38546 Mdot
.60781 .53955 Mdot
.39607 .62802 Mdot
.41564 .63882 Mdot
.79182 .64822 Mdot
.44071 .5687 Mdot
.42676 .51151 Mdot
.42212 .46894 Mdot
.59569 .57319 Mdot
.38173 .60942 Mdot
.43275 .6381 Mdot
.41498 .58446 Mdot
.73192 .61864 Mdot
.45237 .35257 Mdot
.40196 .62412 Mdot
.33145 .44754 Mdot
.52917 .30341 Mdot
.4279 .64785 Mdot
.53365 .57715 Mdot
.63105 .59477 Mdot
.83248 .4441 Mdot
.62365 .42658 Mdot
.49146 .32829 Mdot
.48921 .35874 Mdot
.20791 .55307 Mdot
.71018 .32021 Mdot
.426 .46929 Mdot
.26218 .27026 Mdot
.69398 .3248 Mdot
.31854 .44 Mdot
.49751 .30442 Mdot
.59215 .4519 Mdot
.48735 .36624 Mdot
.67592 .39152 Mdot
.40918 .63635 Mdot
.39749 .62783 Mdot
.70662 .24142 Mdot
.449 .55953 Mdot
.33278 .43264 Mdot
.66781 .37602 Mdot
.64845 .55548 Mdot
.3247 .40113 Mdot
.60724 .41255 Mdot
.59327 .57821 Mdot
.50417 .60457 Mdot
.48508 .63942 Mdot
.63233 .59158 Mdot
.6822 .59022 Mdot
.47432 .59909 Mdot
.61931 .32491 Mdot
.65567 .55298 Mdot
.66844 .60347 Mdot
.45238 .38405 Mdot
.49765 .37443 Mdot
.4893 .66527 Mdot
.65611 .40008 Mdot
.46952 .63721 Mdot
.48698 .35611 Mdot
.30354 .42095 Mdot
.65979 .57543 Mdot
.47146 .64221 Mdot
.42437 .63776 Mdot
.34015 .41826 Mdot
.30897 .41552 Mdot
.31007 .42628 Mdot
.58971 .4361 Mdot
.41647 .59848 Mdot
.65361 .58125 Mdot
.6179 .40281 Mdot
.35672 .39531 Mdot
.35484 .43129 Mdot
.51271 .31592 Mdot
.43668 .56563 Mdot
.41547 .35947 Mdot
.73376 .25171 Mdot
.73078 .71334 Mdot
.44517 .33424 Mdot
.43873 .38207 Mdot
.24534 .47022 Mdot
.65258 .50024 Mdot
.641 .38093 Mdot
.37862 .43858 Mdot
.33145 .64349 Mdot
.49375 .5773 Mdot
.48377 .6365 Mdot
.38031 .59974 Mdot
.31045 .4318 Mdot
.32058 .5583 Mdot
.62143 .59076 Mdot
.49361 .51235 Mdot
.33348 .39674 Mdot
.48679 .31453 Mdot
.49026 .29809 Mdot
.50093 .33136 Mdot
.46397 .65935 Mdot
.59287 .74509 Mdot
.72327 .35286 Mdot
.26334 .62323 Mdot
.65846 .40457 Mdot
.54359 .59739 Mdot
.28422 .28282 Mdot
.6359 .58793 Mdot
.46132 .39462 Mdot
.32297 .4435 Mdot
.68082 .58861 Mdot
.62741 .37627 Mdot
.64351 .4097 Mdot
.44827 .36613 Mdot
.45059 .36604 Mdot
.49507 .3665 Mdot
.63666 .61574 Mdot
.60755 .55913 Mdot
.4221 .58357 Mdot
.65954 .56876 Mdot
.81618 .46498 Mdot
.31253 .39071 Mdot
.47241 .41096 Mdot
.65263 .39748 Mdot
.61502 .55265 Mdot
.44438 .60313 Mdot
.67636 .62791 Mdot
.68946 .48363 Mdot
.34425 .43472 Mdot
.73964 .64767 Mdot
.14464 .53804 Mdot
.48045 .58499 Mdot
.62226 .41094 Mdot
.78775 .57773 Mdot
.45093 .60466 Mdot
.47357 .37843 Mdot
.2435 .3904 Mdot
.48678 .41714 Mdot
.47809 .60782 Mdot
.4928 .58637 Mdot
.65723 .42148 Mdot
.3329 .22766 Mdot
.43384 .5835 Mdot
.77575 .46755 Mdot
.68803 .37851 Mdot
.46926 .38232 Mdot
.34991 .82387 Mdot
.29003 .44776 Mdot
.27351 .53002 Mdot
.45025 .37825 Mdot
.45282 .63847 Mdot
.47468 .39049 Mdot
.33753 .44492 Mdot
.47815 .31855 Mdot
.62824 .59979 Mdot
.49127 .31938 Mdot
.40349 .60694 Mdot
.65493 .59242 Mdot
.6531 .38827 Mdot
.81692 .60369 Mdot
.28549 .3696 Mdot
.47045 .33774 Mdot
.45051 .3364 Mdot
.38882 .59404 Mdot
.7661 .51973 Mdot
.41074 .6621 Mdot
.41291 .64233 Mdot
.66259 .38966 Mdot
.63082 .56252 Mdot
.63453 .43128 Mdot
.39723 .66907 Mdot
.29704 .6023 Mdot
.60905 .40965 Mdot
.40923 .25251 Mdot
.32544 .41664 Mdot
.55163 .42769 Mdot
.44075 .60647 Mdot
.60559 .43247 Mdot
.41565 .59605 Mdot
.61932 .58909 Mdot
.56786 .47765 Mdot
.57231 .32925 Mdot
.63933 .41978 Mdot
.25395 .35804 Mdot
.27794 .57194 Mdot
.54232 .58661 Mdot
.61324 .42066 Mdot
.34282 .51285 Mdot
.45086 .34478 Mdot
.3495 .42158 Mdot
.30651 .40178 Mdot
.33105 .39518 Mdot
.5023 .63986 Mdot
.35692 .66039 Mdot
.32882 .45615 Mdot
.64902 .37494 Mdot
.35346 .40492 Mdot
.62298 .21011 Mdot
.17458 .57197 Mdot
.32045 .42383 Mdot
.46031 .58916 Mdot
.39669 .54689 Mdot
.33472 .48843 Mdot
.52927 .26869 Mdot
.31473 .71526 Mdot
.53972 .22142 Mdot
.47542 .60984 Mdot
.67522 .61458 Mdot
.61855 .6056 Mdot
.82017 .5211 Mdot
.40729 .77188 Mdot
.69971 .74177 Mdot
.59124 .58357 Mdot
.63637 .30221 Mdot
.60897 .56415 Mdot
.48556 .59793 Mdot
.41746 .64255 Mdot
.60031 .60166 Mdot
.30794 .59365 Mdot
.60674 .29581 Mdot
.17536 .45721 Mdot
.67729 .58711 Mdot
.60769 .42366 Mdot
.62769 .4373 Mdot
.65379 .41303 Mdot
.77681 .636 Mdot
.63425 .57153 Mdot
.42346 .61803 Mdot
.49196 .3538 Mdot
.39482 .62011 Mdot
.63259 .39268 Mdot
.17084 .60414 Mdot
.64484 .56653 Mdot
.45711 .578 Mdot
.50511 .54516 Mdot
.45369 .3681 Mdot
.33307 .41961 Mdot
.70453 .62716 Mdot
.68363 .75373 Mdot
.66208 .41206 Mdot
.58215 .57942 Mdot
.60783 .46848 Mdot
.18479 .45331 Mdot
.50591 .56392 Mdot
.46716 .55462 Mdot
.15076 .5144 Mdot
.57302 .82606 Mdot
.40898 .57987 Mdot
.46708 .31924 Mdot
.60909 .27467 Mdot
.43193 .64773 Mdot
.61584 .60113 Mdot
.29489 .42701 Mdot
.34339 .39756 Mdot
.5111 .64365 Mdot
.71421 .61241 Mdot
.57603 .50329 Mdot
.43384 .62098 Mdot
.37413 .6369 Mdot
.46144 .38325 Mdot
.65075 .27677 Mdot
.76579 .68462 Mdot
.30824 .4116 Mdot
.47579 .57402 Mdot
.18786 .56738 Mdot
.68043 .57748 Mdot
.45024 .32339 Mdot
.60277 .40267 Mdot
.68414 .61614 Mdot
.4738 .3164 Mdot
.48485 .63276 Mdot
.45674 .56153 Mdot
.62008 .43303 Mdot
.68102 .60386 Mdot
.31161 .42518 Mdot
.48715 .32724 Mdot
.31423 .41131 Mdot
.63501 .56296 Mdot
.64593 .55731 Mdot
.52447 .559 Mdot
.49349 .5571 Mdot
.46685 .33491 Mdot
.45273 .67269 Mdot
.57851 .35719 Mdot
.17795 .38233 Mdot
.60685 .46589 Mdot
.4305 .56274 Mdot
.61454 .54702 Mdot
.64536 .421 Mdot
.41438 .62281 Mdot
.15853 .58189 Mdot
.42839 .65493 Mdot
.66072 .3695 Mdot
.43554 .80019 Mdot
.31754 .41212 Mdot
.54637 .53769 Mdot
.37367 .23458 Mdot
.44687 .56716 Mdot
.47834 .36823 Mdot
.51891 .58538 Mdot
.61113 .39764 Mdot
.61532 .55459 Mdot
.16234 .3955 Mdot
.63674 .40184 Mdot
.46331 .5737 Mdot
.33364 .40096 Mdot
.65049 .54732 Mdot
.55493 .5182 Mdot
.49305 .48915 Mdot
.43539 .5356 Mdot
.38481 .60698 Mdot
.43841 .63973 Mdot
.27352 .60601 Mdot
.49733 .33887 Mdot
.66504 .60227 Mdot
.62278 .41599 Mdot
.64146 .38348 Mdot
.45052 .35938 Mdot
.41354 .37381 Mdot
.55066 .42767 Mdot
.80012 .32934 Mdot
.47121 .39278 Mdot
.30376 .41457 Mdot
.76893 .49732 Mdot
.49611 .34233 Mdot
.48358 .34303 Mdot
.45617 .38738 Mdot
.41699 .45822 Mdot
.64167 .5519 Mdot
.48369 .63434 Mdot
.63133 .60701 Mdot
.45401 .64004 Mdot
.67045 .36715 Mdot
.63943 .4171 Mdot
.6412 .56124 Mdot
.18647 .41457 Mdot
.52872 .77765 Mdot
.45878 .59951 Mdot
.27143 .29244 Mdot
.40127 .56166 Mdot
.27659 .45603 Mdot
.39646 .56957 Mdot
.46665 .34494 Mdot
.449 .66621 Mdot
.48997 .65563 Mdot
.8122 .55416 Mdot
.65509 .39737 Mdot
.50771 .31708 Mdot
.37099 .61171 Mdot
.37674 .6442 Mdot
.64226 .61745 Mdot
.68109 .59247 Mdot
.31149 .39795 Mdot
.45781 .51486 Mdot
.65196 .38532 Mdot
.58928 .17824 Mdot
.47919 .5971 Mdot
.2703 .4226 Mdot
.67931 .72322 Mdot
.41325 .61991 Mdot
.34049 .25123 Mdot
.59432 .73835 Mdot
.43821 .60383 Mdot
.46039 .44052 Mdot
.65843 .40029 Mdot
.31758 .65742 Mdot
.43763 .65415 Mdot
.45672 .37555 Mdot
.60374 .56376 Mdot
.68522 .58213 Mdot
.30336 .40834 Mdot
.75968 .327 Mdot
.63801 .43153 Mdot
.6277 .55359 Mdot
.44661 .61353 Mdot
.62039 .41118 Mdot
.45417 .38909 Mdot
.40518 .57584 Mdot
.50654 .82278 Mdot
.66266 .57086 Mdot
.38984 .58271 Mdot
.76256 .43902 Mdot
.24856 .50113 Mdot
.44428 .81364 Mdot
.62523 .42092 Mdot
.30802 .43145 Mdot
.51687 .6266 Mdot
.62497 .52943 Mdot
.3879 .64354 Mdot
.28886 .54473 Mdot
.60896 .20711 Mdot
.34236 .44978 Mdot
.46749 .59748 Mdot
.41999 .6171 Mdot
.62095 .49678 Mdot
.31293 .40598 Mdot
.42577 .5761 Mdot
.66965 .51694 Mdot
.67154 .58373 Mdot
.44024 .37216 Mdot
.65771 .56091 Mdot
.45746 .59159 Mdot
.48662 .55223 Mdot
.68398 .59052 Mdot
.20901 .35916 Mdot
.29269 .4336 Mdot
.61487 .41831 Mdot
.47979 .57252 Mdot
.4554 .6595 Mdot
.87726 .52718 Mdot
.44927 .32021 Mdot
.5991 .3279 Mdot
.41118 .26286 Mdot
.19967 .55015 Mdot
.32547 .47142 Mdot
.40573 .81211 Mdot
.56467 .82872 Mdot
.42038 .56559 Mdot
.57717 .54944 Mdot
.74257 .39795 Mdot
.66142 .39444 Mdot
.72195 .28817 Mdot
.47975 .59695 Mdot
.45607 .61611 Mdot
.43669 .34963 Mdot
.56038 .32574 Mdot
.70771 .73578 Mdot
.61106 .61979 Mdot
.31472 .41893 Mdot
.61342 .58511 Mdot
.49115 .62522 Mdot
.49288 .45795 Mdot
.47263 .31097 Mdot
.28933 .3944 Mdot
.46165 .57971 Mdot
.73436 .62007 Mdot
.69881 .48928 Mdot
.62252 .39812 Mdot
.48763 .36105 Mdot
.65095 .77043 Mdot
.43985 .56377 Mdot
.60378 .43226 Mdot
.44525 .58893 Mdot
.33874 .47477 Mdot
.3866 .66908 Mdot
.31967 .43848 Mdot
.45199 .64918 Mdot
.42361 .29686 Mdot
.83206 .64797 Mdot
.36918 .41769 Mdot
.65924 .62006 Mdot
.43314 .34154 Mdot
.45362 .35016 Mdot
.67916 .59737 Mdot
.46023 .34392 Mdot
.59907 .70386 Mdot
.49279 .80661 Mdot
.32352 .41545 Mdot
.47344 .67464 Mdot
.32528 .42443 Mdot
.44079 .33707 Mdot
.47737 .60718 Mdot
.14361 .46118 Mdot
.46864 .32843 Mdot
.60873 .81794 Mdot
.64308 .39568 Mdot
.45647 .3131 Mdot
.43292 .65366 Mdot
.6785 .49933 Mdot
.49732 .37837 Mdot
.60078 .31268 Mdot
.41587 .58425 Mdot
.64869 .5568 Mdot
.42811 .64159 Mdot
.49111 .59975 Mdot
.49779 .31517 Mdot
.46807 .63407 Mdot
.60678 .4124 Mdot
.59482 .58813 Mdot
.29922 .71511 Mdot
.66097 .25386 Mdot
.42727 .57459 Mdot
.44756 .61083 Mdot
.66174 .54587 Mdot
.439 .66376 Mdot
.67078 .40533 Mdot
.27626 .20284 Mdot
.32615 .41669 Mdot
.47001 .3062 Mdot
.41865 .28213 Mdot
.50285 .58588 Mdot
.47733 .6292 Mdot
.17114 .65552 Mdot
.29294 .59337 Mdot
.61053 .41869 Mdot
.44564 .67697 Mdot
.48625 .38839 Mdot
.34582 .41155 Mdot
.66101 .37804 Mdot
.43288 .6064 Mdot
.4663 .60541 Mdot
.30646 .42377 Mdot
.26807 .43602 Mdot
.74839 .66664 Mdot
.61439 .43902 Mdot
.37368 .57923 Mdot
.52628 .32805 Mdot
.39546 .63069 Mdot
.76969 .62974 Mdot
.64874 .60406 Mdot
.66432 .40912 Mdot
.20524 .57023 Mdot
.43332 .5635 Mdot
.61366 .42765 Mdot
.65378 .38676 Mdot
.38388 .6377 Mdot
.57376 .59299 Mdot
.59864 .59579 Mdot
.67324 .58063 Mdot
.57238 .13859 Mdot
.28766 .52161 Mdot
.49504 .36655 Mdot
.65958 .39723 Mdot
.44363 .34433 Mdot
.35796 .38638 Mdot
.50311 .48388 Mdot
.44718 .33853 Mdot
.6658 .56501 Mdot
.46311 .30881 Mdot
.41096 .60052 Mdot
.65066 .3855 Mdot
.48453 .36944 Mdot
.49474 .60192 Mdot
.73697 .59274 Mdot
.5039 .24039 Mdot
.3477 .4427 Mdot
.29794 .44103 Mdot
.42133 .64472 Mdot
.46276 .3965 Mdot
.47226 .60404 Mdot
.5988 .40819 Mdot
.76035 .56279 Mdot
.48995 .60056 Mdot
.46727 .34025 Mdot
.66134 .54683 Mdot
.66021 .76497 Mdot
.49151 .64702 Mdot
.46163 .59022 Mdot
.46037 .63788 Mdot
.44445 .58861 Mdot
.19684 .43473 Mdot
.64356 .43296 Mdot
.5886 .21488 Mdot
.2101 .54063 Mdot
.64532 .57259 Mdot
.65019 .61153 Mdot
.75214 .6903 Mdot
.73555 .41128 Mdot
.65645 .40056 Mdot
.44058 .63094 Mdot
.70533 .4636 Mdot
.22469 .69539 Mdot
.16178 .46939 Mdot
.41885 .73681 Mdot
.44657 .32308 Mdot
.58288 .57843 Mdot
.45589 .34008 Mdot
.45619 .63459 Mdot
.37503 .63172 Mdot
.47769 .84494 Mdot
.64004 .37501 Mdot
.31659 .42087 Mdot
.45502 .64144 Mdot
.28254 .52271 Mdot
.48275 .35819 Mdot
.45571 .31318 Mdot
.40713 .62449 Mdot
.68187 .56717 Mdot
.82082 .65275 Mdot
.62287 .40392 Mdot
.57253 .21868 Mdot
.69724 .27745 Mdot
.70864 .52318 Mdot
.62913 .39544 Mdot
.62021 .52596 Mdot
.45087 .3251 Mdot
.68217 .70119 Mdot
.64113 .57677 Mdot
.35124 .41767 Mdot
.37464 .58958 Mdot
.65713 .60741 Mdot
.50869 .34363 Mdot
.63228 .55181 Mdot
.47936 .6276 Mdot
.68594 .39427 Mdot
.47171 .36305 Mdot
.69597 .41482 Mdot
.61723 .54603 Mdot
.31733 .40317 Mdot
.59435 .36822 Mdot
.43121 .75598 Mdot
.59545 .73547 Mdot
.40455 .62436 Mdot
.48127 .45819 Mdot
.42353 .61444 Mdot
.69358 .57347 Mdot
.44538 .59824 Mdot
.55396 .61534 Mdot
.47697 .36814 Mdot
.45692 .65296 Mdot
.43551 .62587 Mdot
.49551 .17255 Mdot
.43134 .57712 Mdot
.39916 .64409 Mdot
.43747 .60838 Mdot
.55231 .61085 Mdot
.51726 .63393 Mdot
.61046 .57323 Mdot
.36808 .26835 Mdot
.48068 .34331 Mdot
.33596 .39253 Mdot
.3112 .44246 Mdot
.3145 .53701 Mdot
.40103 .32494 Mdot
.53718 .29619 Mdot
.6678 .58144 Mdot
.60318 .41158 Mdot
.44444 .59395 Mdot
.36718 .78894 Mdot
.52635 .36482 Mdot
.49116 .31722 Mdot
.66438 .25806 Mdot
.37601 .68011 Mdot
.33394 .71131 Mdot
.42725 .67496 Mdot
.67688 .21179 Mdot
.50969 .58937 Mdot
.36427 .64984 Mdot
.4651 .39366 Mdot
.26755 .40471 Mdot
.43124 .66101 Mdot
.60835 .59707 Mdot
.33598 .4384 Mdot
.35809 .6594 Mdot
.45858 .2946 Mdot
.54365 .33554 Mdot
.57632 .63365 Mdot
.41564 .58985 Mdot
.4711 .36243 Mdot
.62081 .56473 Mdot
.75059 .70009 Mdot
.61749 .40472 Mdot
.41295 .35539 Mdot
.78786 .45702 Mdot
.22367 .34775 Mdot
.32924 .39726 Mdot
.67032 .67264 Mdot
.40545 .60529 Mdot
.27949 .35478 Mdot
.48573 .58267 Mdot
.17773 .64059 Mdot
.30773 .44267 Mdot
.65607 .55665 Mdot
.60569 .42272 Mdot
.61623 .60031 Mdot
.58349 .72982 Mdot
.47399 .288 Mdot
.53964 .45996 Mdot
.49025 .34399 Mdot
.56728 .50746 Mdot
.6535 .59913 Mdot
.4837 .59838 Mdot
.79503 .32065 Mdot
.66222 .60518 Mdot
.63986 .54524 Mdot
.40834 .19793 Mdot
.16077 .41576 Mdot
.4777 .55682 Mdot
.65122 .55095 Mdot
.48733 .33744 Mdot
.32921 .43642 Mdot
.44217 .6516 Mdot
.40883 .59363 Mdot
.64563 .6053 Mdot
.49545 .31028 Mdot
.49509 .73567 Mdot
.45449 .35854 Mdot
.65075 .55524 Mdot
.4689 .35278 Mdot
.64589 .36366 Mdot
.48797 .32616 Mdot
.45648 .65935 Mdot
.44509 .59706 Mdot
.37798 .2911 Mdot
.64721 .55768 Mdot
.43283 .61901 Mdot
.39186 .58952 Mdot
.6554 .58306 Mdot
.61656 .51807 Mdot
.50833 .73657 Mdot
.39401 .59524 Mdot
.41871 .58107 Mdot
.31891 .44904 Mdot
.50541 .47738 Mdot
.70891 .66021 Mdot
.4752 .63429 Mdot
.35032 .44693 Mdot
.60458 .58755 Mdot
.47294 .58678 Mdot
.21777 .65233 Mdot
.60679 .27611 Mdot
.48011 .58589 Mdot
.4518 .34338 Mdot
.46534 .67065 Mdot
.46184 .81899 Mdot
.41441 .64568 Mdot
.65975 .59059 Mdot
.62474 .55605 Mdot
.57248 .17798 Mdot
.64402 .59181 Mdot
.49831 .37279 Mdot
.63421 .39294 Mdot
.18333 .45136 Mdot
.44476 .36048 Mdot
.51098 .60424 Mdot
.42893 .16655 Mdot
.40271 .56936 Mdot
.49837 .61878 Mdot
.66421 .782 Mdot
.46126 .33486 Mdot
.62382 .57586 Mdot
.58193 .38092 Mdot
.48366 .55402 Mdot
.65997 .41214 Mdot
.36956 .63639 Mdot
.40996 .63988 Mdot
.50364 .83301 Mdot
.1999 .43515 Mdot
.60736 .4396 Mdot
.39868 .64228 Mdot
.47646 .63221 Mdot
.46221 .40669 Mdot
.44406 .60882 Mdot
.32471 .43676 Mdot
.63376 .5696 Mdot
.47364 .31976 Mdot
.34032 .41366 Mdot
.45385 .56589 Mdot
.31053 .42588 Mdot
.47049 .37543 Mdot
.60934 .39067 Mdot
.4646 .62615 Mdot
.35774 .41614 Mdot
.31279 .42045 Mdot
.42495 .61298 Mdot
.60412 .56022 Mdot
.38888 .69317 Mdot
.43686 .57636 Mdot
.47215 .64132 Mdot
.62872 .59098 Mdot
.3412 .82593 Mdot
.4163 .64209 Mdot
.29255 .55308 Mdot
.67446 .60544 Mdot
.58656 .51422 Mdot
.44124 .36774 Mdot
.41845 .65459 Mdot
.60838 .39131 Mdot
.60794 .39402 Mdot
.49899 .32757 Mdot
.58432 .57435 Mdot
.42991 .26386 Mdot
.60578 .61025 Mdot
.51978 .60785 Mdot
.40569 .65324 Mdot
.48607 .68408 Mdot
.34303 .76265 Mdot
.62219 .59987 Mdot
.43467 .30318 Mdot
.65955 .63177 Mdot
.59988 .41869 Mdot
.50387 .31995 Mdot
.5966 .5944 Mdot
.6233 .58777 Mdot
.59353 .57308 Mdot
.35181 .41761 Mdot
.37721 .29491 Mdot
.68518 .59853 Mdot
.68729 .57381 Mdot
.40596 .59195 Mdot
.47114 .63826 Mdot
.60148 .80825 Mdot
.58791 .80525 Mdot
.32662 .44941 Mdot
.4943 .37018 Mdot
.52412 .11337 Mdot
.6222 .38142 Mdot
.52622 .18498 Mdot
.49296 .62681 Mdot
.56339 .1133 Mdot
.43582 .6525 Mdot
.44505 .61521 Mdot
.59808 .59604 Mdot
.35565 .42527 Mdot
.32657 .42091 Mdot
.66339 .60327 Mdot
.69364 .58198 Mdot
.32275 .43586 Mdot
.34984 .23768 Mdot
.23207 .68908 Mdot
.57983 .35148 Mdot
.65424 .57454 Mdot
.45257 .77949 Mdot
.61672 .43633 Mdot
.36593 .5772 Mdot
.63894 .44202 Mdot
.48485 .35085 Mdot
.46036 .31793 Mdot
.65414 .41694 Mdot
.42279 .58197 Mdot
.49736 .36233 Mdot
.42128 .56279 Mdot
.50473 .22589 Mdot
.5659 .75815 Mdot
.48206 .27663 Mdot
.35237 .59362 Mdot
.62082 .51629 Mdot
.70251 .39763 Mdot
.46884 .5746 Mdot
.1961 .61255 Mdot
.3178 .41762 Mdot
.52047 .58728 Mdot
.66712 .40421 Mdot
.64788 .80013 Mdot
.47147 .61906 Mdot
.6611 .58632 Mdot
.65663 .38857 Mdot
.79588 .46104 Mdot
.77507 .4809 Mdot
.45734 .63939 Mdot
.75949 .28586 Mdot
.67317 .54387 Mdot
.49563 .35113 Mdot
.76797 .58628 Mdot
.65508 .61046 Mdot
.34547 .47103 Mdot
.21898 .59779 Mdot
.1983 .39045 Mdot
.62449 .57083 Mdot
.43284 .35337 Mdot
.60408 .57608 Mdot
.32589 .39975 Mdot
.65532 .6197 Mdot
.47831 .36382 Mdot
.46481 .5831 Mdot
.45779 .35053 Mdot
.35113 .42381 Mdot
.73036 .67457 Mdot
.60729 .43939 Mdot
.51459 .35338 Mdot
.63305 .4162 Mdot
.2304 .50325 Mdot
.2645 .5938 Mdot
.61817 .4201 Mdot
.50336 .70191 Mdot
.40779 .65469 Mdot
.67558 .60716 Mdot
.44561 .36887 Mdot
.29112 .37457 Mdot
.59426 .37641 Mdot
.64048 .58089 Mdot
.50631 .35469 Mdot
.77749 .52198 Mdot
.5529 .60306 Mdot
.4054 .65534 Mdot
.36007 .49037 Mdot
.65288 .57794 Mdot
.43512 .35033 Mdot
.80624 .6332 Mdot
.60535 .57748 Mdot
.47933 .39152 Mdot
.61041 .42799 Mdot
.63664 .38413 Mdot
.39239 .61451 Mdot
.68496 .37331 Mdot
.50243 .34077 Mdot
.64546 .46044 Mdot
.64335 .54855 Mdot
.79972 .49452 Mdot
.34785 .39377 Mdot
.47346 .34454 Mdot
.41065 .56176 Mdot
.68816 .56201 Mdot
.62632 .25986 Mdot
.5064 .74736 Mdot
.83341 .41302 Mdot
.45099 .35882 Mdot
.63258 .57477 Mdot
.66172 .58183 Mdot
.49789 .63996 Mdot
.76482 .57062 Mdot
.39282 .26769 Mdot
.53513 .62747 Mdot
.58719 .46156 Mdot
.44464 .38206 Mdot
.42337 .34163 Mdot
.37057 .6166 Mdot
.42523 .58655 Mdot
.60225 .42373 Mdot
.46233 .58354 Mdot
.60141 .55805 Mdot
.40475 .6227 Mdot
.62316 .41403 Mdot
.49195 .34 Mdot
.46723 .62185 Mdot
.31254 .41803 Mdot
.64616 .43084 Mdot
.62024 .37987 Mdot
.47294 .33995 Mdot
.64535 .60548 Mdot
.57638 .52007 Mdot
.4504 .36936 Mdot
.41607 .58905 Mdot
.46307 .46624 Mdot
.48163 .62458 Mdot
.56326 .56205 Mdot
.60732 .58082 Mdot
.4725 .32011 Mdot
.64231 .62475 Mdot
.63591 .40825 Mdot
.20987 .54966 Mdot
.45455 .595 Mdot
.46873 .39269 Mdot
.67968 .3146 Mdot
.5608 .53683 Mdot
.62251 .54337 Mdot
.44641 .24221 Mdot
.67067 .61043 Mdot
.48732 .37505 Mdot
.46552 .1835 Mdot
.34659 .40436 Mdot
.48359 .31367 Mdot
.3103 .72334 Mdot
.47119 .33053 Mdot
.39701 .61521 Mdot
.41899 .64022 Mdot
.48528 .32442 Mdot
.30822 .43453 Mdot
.72177 .73114 Mdot
.42333 .37884 Mdot
.62597 .57305 Mdot
.43864 .21406 Mdot
.84491 .49993 Mdot
.66523 .46616 Mdot
.601 .41726 Mdot
.46569 .55095 Mdot
.41408 .65621 Mdot
.66897 .39608 Mdot
.61214 .44584 Mdot
.3196 .39466 Mdot
.46964 .39003 Mdot
.6719 .54664 Mdot
.60134 .38932 Mdot
.6474 .63785 Mdot
.39824 .30936 Mdot
.4854 .65257 Mdot
.68726 .26762 Mdot
.49079 .6288 Mdot
.24762 .57379 Mdot
.62371 .41726 Mdot
.48109 .5784 Mdot
.42877 .67356 Mdot
.65829 .38395 Mdot
.33071 .43719 Mdot
.41456 .3488 Mdot
.46927 .35589 Mdot
.33572 .81128 Mdot
.41432 .56971 Mdot
.4038 .61631 Mdot
.65543 .40856 Mdot
.31314 .33661 Mdot
.64276 .56912 Mdot
.63828 .61201 Mdot
.49715 .33873 Mdot
.54494 .39555 Mdot
.40011 .63256 Mdot
.46782 .57754 Mdot
.46471 .36341 Mdot
.51216 .35329 Mdot
.54178 .29215 Mdot
.41762 .61721 Mdot
.65128 .40027 Mdot
.24955 .4221 Mdot
.62761 .42177 Mdot
.48394 .61316 Mdot
.40607 .61474 Mdot
.45865 .65874 Mdot
.4422 .55861 Mdot
.67607 .41479 Mdot
.48759 .61557 Mdot
.40511 .66397 Mdot
.63514 .57651 Mdot
.45886 .64285 Mdot
.57935 .44258 Mdot
.45499 .58361 Mdot
.32637 .43617 Mdot
.70652 .6527 Mdot
.47064 .61998 Mdot
.40665 .62922 Mdot
.45707 .30857 Mdot
.46237 .60266 Mdot
.60113 .40165 Mdot
.65032 .56256 Mdot
.65722 .40268 Mdot
.60567 .39726 Mdot
.43249 .37303 Mdot
.30057 .42869 Mdot
.49974 .58071 Mdot
.33583 .44455 Mdot
.51381 .58823 Mdot
.43218 .56371 Mdot
.39196 .37983 Mdot
.64435 .18555 Mdot
.76891 .64497 Mdot
.45402 .5932 Mdot
.46484 .33156 Mdot
.45525 .33981 Mdot
.57639 .55538 Mdot
.38918 .62989 Mdot
.67077 .38249 Mdot
.59938 .41707 Mdot
.42307 .78124 Mdot
.32898 .59583 Mdot
.32716 .4366 Mdot
.51765 .47481 Mdot
.40538 .58166 Mdot
.47949 .57677 Mdot
.40745 .57208 Mdot
.44654 .33815 Mdot
.37807 .71512 Mdot
.50359 .32316 Mdot
.69301 .4481 Mdot
.64594 .41866 Mdot
.46426 .63083 Mdot
.66531 .24864 Mdot
.67711 .58233 Mdot
.65073 .56234 Mdot
.62871 .37436 Mdot
.52378 .36156 Mdot
.6663 .75981 Mdot
.15205 .48966 Mdot
.7087 .58214 Mdot
.3549 .42062 Mdot
.45618 .56963 Mdot
.4842 .32982 Mdot
.63861 .55079 Mdot
.35393 .42336 Mdot
.48051 .60991 Mdot
.37807 .2956 Mdot
.44884 .58757 Mdot
.73319 .38153 Mdot
.60457 .56603 Mdot
.20397 .67127 Mdot
.58625 .57117 Mdot
.67133 .41319 Mdot
.66941 .40472 Mdot
.41446 .62068 Mdot
.67509 .53269 Mdot
.65861 .61109 Mdot
.39166 .44196 Mdot
.30518 .41203 Mdot
.67215 .47637 Mdot
.3464 .40901 Mdot
.48946 .36106 Mdot
.34666 .4268 Mdot
.47644 .366 Mdot
.68059 .74705 Mdot
.55214 .64808 Mdot
.3351 .41482 Mdot
.6879 .32497 Mdot
.4166 .6573 Mdot
.33308 .45068 Mdot
.37537 .62929 Mdot
.52979 .6285 Mdot
.46173 .36348 Mdot
.31122 .40574 Mdot
.47858 .57784 Mdot
.39141 .79328 Mdot
.61318 .41843 Mdot
.67365 .3859 Mdot
.37562 .62659 Mdot
.4383 .36968 Mdot
.60308 .59673 Mdot
.17985 .55238 Mdot
.59383 .39627 Mdot
.41491 .63403 Mdot
.43437 .66242 Mdot
.6762 .60826 Mdot
.58796 .19866 Mdot
.41036 .61262 Mdot
.54737 .56438 Mdot
.41738 .62114 Mdot
.63681 .42899 Mdot
.61406 .59591 Mdot
.65926 .57358 Mdot
.50491 .35681 Mdot
.67644 .57098 Mdot
.44903 .49058 Mdot
.71386 .33643 Mdot
.38906 .67505 Mdot
.63366 .40502 Mdot
.69561 .47738 Mdot
.70747 .40954 Mdot
.31008 .70284 Mdot
.60431 .55065 Mdot
.49029 .60533 Mdot
.67692 .56825 Mdot
.34618 .41951 Mdot
.65609 .5618 Mdot
.58283 .57866 Mdot
.47533 .60066 Mdot
.45237 .63843 Mdot
.49437 .3451 Mdot
.76657 .56382 Mdot
.65727 .60809 Mdot
.43515 .65158 Mdot
.46022 .66242 Mdot
.4164 .56233 Mdot
.39507 .45802 Mdot
.61769 .59727 Mdot
.32076 .23182 Mdot
.38216 .50704 Mdot
.6533 .60775 Mdot
.78628 .68896 Mdot
.66108 .29078 Mdot
.48824 .29303 Mdot
.40092 .39613 Mdot
.41909 .62482 Mdot
.50289 .37455 Mdot
.45684 .63397 Mdot
.69072 .27277 Mdot
.46163 .60962 Mdot
.32531 .43791 Mdot
.42002 .56564 Mdot
.47022 .31485 Mdot
.45265 .35977 Mdot
.41242 .63177 Mdot
.46414 .62331 Mdot
.7331 .68385 Mdot
.64566 .6205 Mdot
.63645 .55539 Mdot
.49985 .28208 Mdot
.33283 .40828 Mdot
.66223 .41097 Mdot
.44005 .60329 Mdot
.43333 .36513 Mdot
.45361 .35729 Mdot
.6313 .60572 Mdot
.46529 .37943 Mdot
.62361 .40215 Mdot
.45193 .59793 Mdot
.67114 .39378 Mdot
.34883 .40415 Mdot
.61463 .59452 Mdot
.45796 .64174 Mdot
.40606 .59161 Mdot
.62489 .5562 Mdot
.48461 .57856 Mdot
.30807 .4284 Mdot
.46876 .33464 Mdot
.62293 .57028 Mdot
.63627 .38963 Mdot
.48617 .36313 Mdot
.48096 .63489 Mdot
.73573 .27007 Mdot
.39353 .60804 Mdot
.42402 .63508 Mdot
.3424 .77407 Mdot
.41272 .5759 Mdot
.44719 .36439 Mdot
.64459 .55196 Mdot
.51665 .56375 Mdot
.31767 .51624 Mdot
.31867 .82031 Mdot
.50239 .32467 Mdot
.45247 .57111 Mdot
.33338 .73293 Mdot
.45623 .57428 Mdot
.4883 .76854 Mdot
.5165 .33435 Mdot
.57984 .47461 Mdot
.42233 .55709 Mdot
.61783 .39385 Mdot
.48972 .33036 Mdot
.47225 .36951 Mdot
.47622 .21402 Mdot
.4761 .59013 Mdot
.43903 .44393 Mdot
.47928 .61903 Mdot
.63278 .38902 Mdot
.33685 .60005 Mdot
.45 .36281 Mdot
.83368 .49598 Mdot
.42208 .61366 Mdot
.62207 .59183 Mdot
.45799 .31073 Mdot
.60187 .38145 Mdot
.4663 .64536 Mdot
.31855 .44271 Mdot
.59784 .43603 Mdot
.38217 .66554 Mdot
.63172 .40326 Mdot
.47356 .63964 Mdot
.43108 .53263 Mdot
.80539 .42122 Mdot
.59596 .56733 Mdot
.60579 .42468 Mdot
.44332 .46598 Mdot
.4886 .60578 Mdot
.62474 .56976 Mdot
.64015 .57804 Mdot
.35158 .4092 Mdot
.56608 .48997 Mdot
.76757 .43663 Mdot
.53497 .78721 Mdot
.45351 .21235 Mdot
.47748 .30927 Mdot
.58699 .32274 Mdot
.43022 .63448 Mdot
.40344 .48684 Mdot
.59961 .40714 Mdot
.3926 .60567 Mdot
.65206 .67506 Mdot
.67855 .59297 Mdot
.39629 .60177 Mdot
.32379 .42556 Mdot
.28462 .44394 Mdot
.24783 .43028 Mdot
.24884 .64045 Mdot
.48923 .34581 Mdot
.43796 .6802 Mdot
.51026 .55211 Mdot
.44144 .37228 Mdot
.48055 .64814 Mdot
.44475 .37322 Mdot
.30138 .26978 Mdot
.34426 .4452 Mdot
.61659 .58974 Mdot
.68211 .445 Mdot
.50133 .61518 Mdot
.40651 .64308 Mdot
.29896 .4259 Mdot
.42366 .5894 Mdot
.7727 .36294 Mdot
.39049 .46172 Mdot
.49063 .3651 Mdot
.59371 .57183 Mdot
.46665 .65808 Mdot
.50763 .4872 Mdot
.45085 .57661 Mdot
.60375 .77104 Mdot
.40766 .63127 Mdot
.77955 .48062 Mdot
.60221 .56448 Mdot
.62923 .4105 Mdot
.4726 .56663 Mdot
.45485 .61292 Mdot
.32012 .56925 Mdot
.51107 .58654 Mdot
.48559 .58693 Mdot
.56871 .60833 Mdot
.58898 .57348 Mdot
.60661 .57315 Mdot
.50242 .32991 Mdot
.36841 .74602 Mdot
.64505 .40292 Mdot
.48493 .54578 Mdot
.63878 .36958 Mdot
.46521 .73407 Mdot
.35026 .43303 Mdot
.28213 .63849 Mdot
.43643 .61787 Mdot
.66944 .57956 Mdot
.18635 .51001 Mdot
.63651 .61539 Mdot
.50997 .46465 Mdot
.65174 .38531 Mdot
.66026 .60456 Mdot
.44864 .61567 Mdot
.7229 .60017 Mdot
.36053 .77399 Mdot
.64344 .41031 Mdot
.50904 .61188 Mdot
.46928 .31259 Mdot
.42638 .27608 Mdot
.81961 .4408 Mdot
.6146 .42147 Mdot
.59757 .45675 Mdot
.47504 .58439 Mdot
.67455 .57239 Mdot
.62238 .39249 Mdot
.6352 .42819 Mdot
.47045 .37851 Mdot
.44996 .64012 Mdot
.44589 .64102 Mdot
.49803 .36876 Mdot
.65634 .40491 Mdot
.39252 .64774 Mdot
.39274 .66893 Mdot
.56175 .85278 Mdot
.78599 .50263 Mdot
.35391 .83366 Mdot
.58315 .53836 Mdot
.62047 .66708 Mdot
.17723 .56228 Mdot
.63539 .60316 Mdot
.46656 .56938 Mdot
.3675 .60535 Mdot
.50241 .33998 Mdot
.46424 .5942 Mdot
.52077 .33161 Mdot
.63595 .37843 Mdot
.64236 .80188 Mdot
.72896 .50152 Mdot
.24748 .32738 Mdot
.46592 .59513 Mdot
.56452 .5945 Mdot
.34219 .42419 Mdot
.65916 .48825 Mdot
.61039 .5896 Mdot
.39759 .57261 Mdot
.7323 .68179 Mdot
.49032 .31653 Mdot
.63489 .5909 Mdot
.7451 .70542 Mdot
.631 .51469 Mdot
.48115 .6242 Mdot
.50867 .33213 Mdot
.18763 .60218 Mdot
.6337 .6409 Mdot
.6692 .37501 Mdot
.33176 .43758 Mdot
.47791 .32197 Mdot
.60167 .42574 Mdot
.56694 .58484 Mdot
.64273 .59755 Mdot
.6071 .59715 Mdot
.75062 .64987 Mdot
.48671 .30384 Mdot
.34169 .42211 Mdot
.3202 .64913 Mdot
.32835 .578 Mdot
.32045 .43525 Mdot
.45947 .31814 Mdot
.59884 .56121 Mdot
.67078 .59929 Mdot
.65084 .56332 Mdot
.79336 .59957 Mdot
.66716 .55565 Mdot
.48717 .19902 Mdot
.42747 .55946 Mdot
.45932 .68326 Mdot
.45678 .57198 Mdot
.66823 .38243 Mdot
.62158 .55867 Mdot
.57909 .37754 Mdot
.51574 .60474 Mdot
.28197 .61611 Mdot
.39476 .61552 Mdot
.64696 .43399 Mdot
.40008 .60304 Mdot
.67264 .23716 Mdot
.6818 .57965 Mdot
.45809 .5939 Mdot
.63713 .44086 Mdot
.32854 .40544 Mdot
.61261 .5462 Mdot
.4599 .63823 Mdot
.40881 .2425 Mdot
.42157 .56961 Mdot
.26984 .30691 Mdot
.77995 .41575 Mdot
.35407 .4239 Mdot
.73255 .3231 Mdot
.42967 .3628 Mdot
.5268 .62339 Mdot
.46405 .54492 Mdot
.63691 .41315 Mdot
.66933 .47805 Mdot
.48256 .34163 Mdot
.40462 .73174 Mdot
.39761 .66026 Mdot
.35029 .4041 Mdot
.54199 .64821 Mdot
.66638 .3925 Mdot
.47569 .65342 Mdot
.43962 .67435 Mdot
.56424 .20952 Mdot
.38302 .65199 Mdot
.42074 .65602 Mdot
.30413 .44769 Mdot
.50946 .19141 Mdot
.44797 .58215 Mdot
.51609 .46977 Mdot
.64994 .61961 Mdot
.51985 .59887 Mdot
.49161 .19402 Mdot
.42083 .64366 Mdot
.63896 .59953 Mdot
.55254 .56847 Mdot
.75006 .42508 Mdot
.30101 .43197 Mdot
.40726 .63139 Mdot
.5612 .1765 Mdot
.41796 .60215 Mdot
.64847 .39807 Mdot
.39093 .63072 Mdot
.48001 .36113 Mdot
.78455 .63479 Mdot
.50365 .35473 Mdot
.38946 .61741 Mdot
.65232 .5673 Mdot
.65041 .41373 Mdot
.77934 .59567 Mdot
.35392 .30072 Mdot
.55162 .19327 Mdot
.16382 .47303 Mdot
.30528 .4146 Mdot
.35449 .39321 Mdot
.64536 .37643 Mdot
.45742 .59208 Mdot
.41578 .18782 Mdot
.50342 .57271 Mdot
.41221 .58426 Mdot
.4614 .61097 Mdot
.26184 .58799 Mdot
.61299 .3897 Mdot
.45668 .36323 Mdot
.40818 .61281 Mdot
.48749 .60658 Mdot
.62847 .5977 Mdot
.32521 .40986 Mdot
.44203 .36411 Mdot
.32333 .41656 Mdot
.48596 .32817 Mdot
.70432 .75581 Mdot
.40768 .66343 Mdot
.32769 .40323 Mdot
.59415 .40784 Mdot
.63316 .59807 Mdot
.71827 .37692 Mdot
.47956 .36792 Mdot
.50544 .33846 Mdot
.41088 .63376 Mdot
.6486 .6048 Mdot
.61317 .61457 Mdot
.34246 .40483 Mdot
.6176 .41396 Mdot
.47118 .61886 Mdot
.43113 .56752 Mdot
.45118 .52868 Mdot
.4361 .37208 Mdot
.7307 .36382 Mdot
.55472 .33369 Mdot
.45442 .59144 Mdot
.64377 .54894 Mdot
.46464 .61831 Mdot
.24077 .37467 Mdot
.67659 .57499 Mdot
.42504 .6482 Mdot
.82568 .64083 Mdot
.48038 .28539 Mdot
.72846 .44844 Mdot
.43463 .66108 Mdot
.16381 .59329 Mdot
.43306 .62739 Mdot
.6545 .79965 Mdot
.23546 .4109 Mdot
.39821 .63663 Mdot
.46556 .64709 Mdot
.54917 .74832 Mdot
.44273 .56781 Mdot
.50512 .36105 Mdot
.58871 .82078 Mdot
.6246 .6125 Mdot
.70803 .40136 Mdot
.6885 .65923 Mdot
.30369 .43652 Mdot
.49703 .33851 Mdot
.45155 .30609 Mdot
.31694 .42756 Mdot
.65565 .57768 Mdot
.44422 .58866 Mdot
.50453 .43522 Mdot
.43826 .36183 Mdot
.3925 .70688 Mdot
.65023 .39572 Mdot
.58165 .26197 Mdot
.34897 .48513 Mdot
.62943 .40163 Mdot
.45664 .64449 Mdot
.53141 .74465 Mdot
.67799 .7385 Mdot
.26687 .71098 Mdot
.60874 .43797 Mdot
.64355 .41213 Mdot
.79867 .60959 Mdot
.31986 .3895 Mdot
.56494 .21294 Mdot
.77722 .48371 Mdot
.6564 .41344 Mdot
.59574 .54855 Mdot
.50539 .36463 Mdot
.633 .33667 Mdot
.52603 .60691 Mdot
.43687 .56143 Mdot
.4503 .61438 Mdot
.6216 .42082 Mdot
.56786 .54013 Mdot
.80497 .51356 Mdot
.63372 .41823 Mdot
.38911 .55781 Mdot
.55745 .45251 Mdot
.66415 .32252 Mdot
.46012 .38295 Mdot
.305 .40997 Mdot
.32217 .38597 Mdot
.62242 .58323 Mdot
.30208 .41669 Mdot
.28017 .43827 Mdot
.43144 .59219 Mdot
.63629 .42291 Mdot
.67689 .295 Mdot
.64069 .38605 Mdot
.32041 .42241 Mdot
.31976 .39304 Mdot
.63587 .57605 Mdot
.63897 .55455 Mdot
.57737 .69757 Mdot
.31414 .4855 Mdot
.4251 .57672 Mdot
.34159 .37193 Mdot
.58474 .58262 Mdot
.42723 .69538 Mdot
.30292 .41311 Mdot
.33011 .40725 Mdot
.31042 .57357 Mdot
.43907 .61877 Mdot
.43477 .71022 Mdot
.43903 .61217 Mdot
.40932 .51627 Mdot
.47161 .64704 Mdot
.46941 .37885 Mdot
.43961 .63013 Mdot
.30553 .58564 Mdot
.49393 .58498 Mdot
.42819 .66694 Mdot
.43995 .34768 Mdot
.4003 .66729 Mdot
.4792 .36015 Mdot
.39113 .60131 Mdot
.35983 .41842 Mdot
.49793 .33669 Mdot
.30013 .52334 Mdot
.29867 .56644 Mdot
.45393 .323 Mdot
.34351 .43775 Mdot
.31785 .45033 Mdot
.26425 .52859 Mdot
.61051 .59101 Mdot
.42788 .54375 Mdot
.46031 .59182 Mdot
.50776 .32131 Mdot
.60312 .40647 Mdot
.48035 .63765 Mdot
.42251 .65963 Mdot
.44341 .659 Mdot
.62142 .58529 Mdot
.38354 .27214 Mdot
.3253 .40148 Mdot
.50171 .36682 Mdot
.56866 .51657 Mdot
.44454 .38266 Mdot
.46248 .66957 Mdot
.37469 .58667 Mdot
.66632 .6671 Mdot
.68304 .33752 Mdot
.80893 .5811 Mdot
.64115 .5958 Mdot
.45278 .34134 Mdot
.34977 .39426 Mdot
.3978 .55772 Mdot
.67033 .57798 Mdot
.47816 .36344 Mdot
.44915 .58824 Mdot
.50384 .6217 Mdot
.70413 .32019 Mdot
.24343 .44736 Mdot
.30155 .54739 Mdot
.49545 .32396 Mdot
.44547 .32523 Mdot
.28512 .57952 Mdot
.29038 .38343 Mdot
.59763 .37065 Mdot
.47116 .58627 Mdot
.31675 .44077 Mdot
.64973 .55441 Mdot
.71386 .66771 Mdot
.65767 .41915 Mdot
.76164 .57437 Mdot
.4644 .59634 Mdot
.60985 .50369 Mdot
.65074 .56718 Mdot
.32214 .42851 Mdot
.62432 .4232 Mdot
.2895 .3996 Mdot
.44854 .33986 Mdot
.18994 .39108 Mdot
.41669 .59574 Mdot
.40921 .63034 Mdot
.62907 .43763 Mdot
.6748 .58632 Mdot
.32935 .45629 Mdot
.43754 .21938 Mdot
.46827 .37413 Mdot
.42799 .18367 Mdot
.65209 .55199 Mdot
.45113 .77701 Mdot
.47492 .38364 Mdot
.6173 .37821 Mdot
.27519 .52258 Mdot
.62391 .40645 Mdot
.39424 .62152 Mdot
.66586 .58371 Mdot
.60337 .41859 Mdot
.78118 .54299 Mdot
.38075 .80827 Mdot
.4614 .78173 Mdot
.43728 .59451 Mdot
.45815 .82903 Mdot
.32474 .26435 Mdot
.71026 .57576 Mdot
.59812 .41622 Mdot
.392 .60912 Mdot
.40608 .63561 Mdot
.41614 .60113 Mdot
.60979 .39655 Mdot
.35999 .38 Mdot
.46094 .36641 Mdot
.4669 .57485 Mdot
.32292 .39382 Mdot
.4821 .3527 Mdot
.63447 .36745 Mdot
.45454 .3797 Mdot
.57464 .58669 Mdot
.48213 .65742 Mdot
.66263 .50244 Mdot
.89001 .56207 Mdot
.65059 .40819 Mdot
.43202 .36855 Mdot
.38524 .63592 Mdot
.62196 .28118 Mdot
.5979 .5819 Mdot
.47143 .37494 Mdot
.40255 .61676 Mdot
.69512 .33725 Mdot
.74468 .66553 Mdot
.44989 .37366 Mdot
.67035 .57557 Mdot
.27137 .70889 Mdot
.46485 .58772 Mdot
.42943 .61466 Mdot
.65372 .60259 Mdot
.50006 .68303 Mdot
.78296 .65756 Mdot
.46396 .6217 Mdot
.62823 .41241 Mdot
.21382 .33415 Mdot
.42144 .6592 Mdot
.37364 .52921 Mdot
.49372 .33757 Mdot
.62393 .35199 Mdot
.74508 .40052 Mdot
.47767 .56588 Mdot
.52349 .22755 Mdot
.67638 .45035 Mdot
.36117 .74865 Mdot
.52052 .32631 Mdot
.33707 .28238 Mdot
.43512 .80811 Mdot
.66291 .4269 Mdot
.56391 .62298 Mdot
.48728 .22367 Mdot
.65491 .64757 Mdot
.21759 .64471 Mdot
.29415 .34997 Mdot
.7353 .68043 Mdot
.52366 .43005 Mdot
.47085 .32622 Mdot
.49604 .67445 Mdot
.45866 .63514 Mdot
.31894 .2694 Mdot
.80292 .43908 Mdot
.80627 .46959 Mdot
.45954 .83049 Mdot
.48361 .77461 Mdot
.33904 .74171 Mdot
.31799 .72677 Mdot
.37407 .54191 Mdot
.57338 .33533 Mdot
.41179 .18364 Mdot
.66026 .77107 Mdot
.3745 .22177 Mdot
.45024 .68525 Mdot
.49282 .45818 Mdot
.23182 .36596 Mdot
.55777 .64158 Mdot
.54387 .6202 Mdot
.49856 .36481 Mdot
.60857 .59203 Mdot
.54839 .21494 Mdot
.68607 .603 Mdot
.74926 .42103 Mdot
.29157 .73585 Mdot
.37062 .79724 Mdot
.58473 .19066 Mdot
.16922 .59071 Mdot
.63976 .67405 Mdot
.36335 .16915 Mdot
.51289 .37067 Mdot
.63494 .60626 Mdot
.25568 .57178 Mdot
.31138 .60775 Mdot
.7074 .51196 Mdot
.43996 .23408 Mdot
.39986 .29323 Mdot
.24216 .48598 Mdot
.66044 .58369 Mdot
.73803 .34683 Mdot
.64808 .33886 Mdot
.72326 .50569 Mdot
.62524 .79429 Mdot
.26883 .68616 Mdot
.48361 .43649 Mdot
.48819 .24207 Mdot
.588 .28336 Mdot
.80983 .52028 Mdot
.34184 .50489 Mdot
.55266 .59592 Mdot
.78459 .4894 Mdot
.17269 .5145 Mdot
.554 .67495 Mdot
.42525 .51637 Mdot
.3163 .61341 Mdot
.72686 .73383 Mdot
.28362 .31346 Mdot
.86826 .49262 Mdot
.6903 .60071 Mdot
.44037 .66359 Mdot
.48865 .70479 Mdot
.52016 .16728 Mdot
.29852 .44564 Mdot
.24058 .63158 Mdot
.31851 .39878 Mdot
.57533 .59202 Mdot
.77438 .65317 Mdot
.50129 .19115 Mdot
.46167 .1671 Mdot
.35982 .40586 Mdot
.48282 .54426 Mdot
.15913 .66054 Mdot
.31846 .68159 Mdot
.72468 .47521 Mdot
.56899 .849 Mdot
.56475 .44123 Mdot
.79896 .48496 Mdot
.60241 .41831 Mdot
.47851 .82748 Mdot
.66694 .59756 Mdot
.88006 .46078 Mdot
.67024 .78829 Mdot
.6829 .67631 Mdot
.705 .83916 Mdot
.27351 .58379 Mdot
.5861 .48118 Mdot
.64455 .46784 Mdot
.28533 .49164 Mdot
.78017 .57312 Mdot
.2135 .52719 Mdot
.61147 .28082 Mdot
.15886 .59254 Mdot
.42236 .80773 Mdot
.44091 .1732 Mdot
.23425 .32915 Mdot
.57162 .65801 Mdot
.51694 .49026 Mdot
.36148 .57746 Mdot
.45742 .27416 Mdot
.22961 .62922 Mdot
.74861 .72291 Mdot
.37895 .50809 Mdot
.31233 .8149 Mdot
.36948 .41568 Mdot
.38097 .31642 Mdot
.33559 .7972 Mdot
.24896 .49701 Mdot
.75392 .3851 Mdot
.34512 .70372 Mdot
.35121 .66051 Mdot
.52037 .50467 Mdot
.23902 .63919 Mdot
.72064 .41262 Mdot
.55158 .83266 Mdot
.18273 .62108 Mdot
.57047 .2123 Mdot
.56767 .76629 Mdot
.34376 .55774 Mdot
.65471 .5415 Mdot
.27364 .44832 Mdot
.75071 .40331 Mdot
.40823 .82702 Mdot
.68122 .40387 Mdot
.45049 .84568 Mdot
.77487 .66507 Mdot
.40797 .66466 Mdot
.42151 .54602 Mdot
.60986 .53264 Mdot
.26419 .44984 Mdot
.44216 .68265 Mdot
.67001 .26892 Mdot
.36162 .7922 Mdot
.64725 .75385 Mdot
.7056 .38409 Mdot
.67366 .46723 Mdot
.33826 .80644 Mdot
.52164 .71946 Mdot
.31868 .37755 Mdot
.55159 .8218 Mdot
.78482 .5697 Mdot
.47752 .34666 Mdot
.4544 .17654 Mdot
.59464 .44875 Mdot
.72875 .66862 Mdot
.52976 .78647 Mdot
.63097 .65513 Mdot
.36254 .79386 Mdot
.37531 .2651 Mdot
.76062 .66721 Mdot
.22921 .52098 Mdot
.39232 .20426 Mdot
.67306 .32954 Mdot
.36667 .63081 Mdot
.43034 .23647 Mdot
.31528 .44668 Mdot
.58206 .7214 Mdot
.2556 .27779 Mdot
.33811 .3477 Mdot
.37404 .61375 Mdot
.69052 .67376 Mdot
.45619 .29729 Mdot
.72751 .59311 Mdot
.84647 .42649 Mdot
.44771 .66858 Mdot
.32182 .63836 Mdot
.35588 .26334 Mdot
.28901 .48079 Mdot
.22384 .68229 Mdot
.20499 .42087 Mdot
.87765 .50909 Mdot
.51264 .84455 Mdot
.34961 .29641 Mdot
.41005 .79254 Mdot
.42373 .81908 Mdot
.87067 .52074 Mdot
.4796 .55426 Mdot
.67974 .40057 Mdot
.69549 .21652 Mdot
.46091 .38428 Mdot
.31191 .63198 Mdot
.45368 .21223 Mdot
.32591 .47884 Mdot
.66624 .50978 Mdot
.39921 .7248 Mdot
.51934 .43764 Mdot
.64855 .62156 Mdot
.43213 .68117 Mdot
.83736 .52634 Mdot
.86836 .56318 Mdot
.85447 .51313 Mdot
.1789 .45069 Mdot
.48292 .8262 Mdot
.59385 .50304 Mdot
.55398 .18103 Mdot
.41486 .6979 Mdot
.4735 .5719 Mdot
.29423 .45158 Mdot
.26973 .5815 Mdot
.71992 .65836 Mdot
.74595 .50878 Mdot
.54822 .65022 Mdot
.23898 .63249 Mdot
.10742 .43426 Mdot
.6014 .69442 Mdot
.46115 .19786 Mdot
.3058 .38283 Mdot
.29823 .47844 Mdot
.20436 .59517 Mdot
.72353 .64726 Mdot
.33052 .75366 Mdot
.64454 .62118 Mdot
.40796 .22048 Mdot
.31962 .35927 Mdot
.57678 .62014 Mdot
.38101 .27498 Mdot
.3146 .69043 Mdot
.68212 .46757 Mdot
.74219 .63097 Mdot
.7685 .49262 Mdot
.50688 .6989 Mdot
.38158 .45552 Mdot
.56893 .27387 Mdot
.32059 .23089 Mdot
.2626 .36101 Mdot
.3812 .52636 Mdot
.55118 .45018 Mdot
.71601 .29391 Mdot
.69303 .41344 Mdot
.40426 .51401 Mdot
.5763 .43083 Mdot
.333 .68113 Mdot
.88688 .37514 Mdot
.84333 .47905 Mdot
.29027 .74658 Mdot
.20743 .47827 Mdot
.37508 .65277 Mdot
.32095 .75007 Mdot
.86693 .45714 Mdot
.81476 .66584 Mdot
.54933 .27336 Mdot
.51794 .36618 Mdot
.62233 .37412 Mdot
.82662 .57117 Mdot
.38449 .38678 Mdot
.29751 .70734 Mdot
.36173 .52491 Mdot
.60492 .39014 Mdot
.59379 .15417 Mdot
.70773 .74487 Mdot
.50457 .79363 Mdot
.25027 .44324 Mdot
.38432 .57683 Mdot
.74766 .33198 Mdot
.65557 .61191 Mdot
.60806 .3141 Mdot
.33063 .49121 Mdot
.46863 .34651 Mdot
.2353 .58533 Mdot
.40908 .23081 Mdot
.42006 .56535 Mdot
.47114 .47255 Mdot
.65655 .54667 Mdot
.67128 .32359 Mdot
.69794 .46262 Mdot
.83854 .6355 Mdot
.28325 .40332 Mdot
.41209 .55979 Mdot
.30104 .49003 Mdot
.40841 .26652 Mdot
.80715 .63245 Mdot
.63135 .37643 Mdot
.39755 .79614 Mdot
.47367 .44319 Mdot
.28948 .46753 Mdot
.69337 .63837 Mdot
.46413 .68726 Mdot
.41558 .66154 Mdot
.18218 .48056 Mdot
.65162 .74483 Mdot
.67346 .63297 Mdot
.52723 .59038 Mdot
.40171 .70805 Mdot
.31536 .7444 Mdot
.2819 .43683 Mdot
.5838 .26908 Mdot
.38837 .79609 Mdot
.62729 .3842 Mdot
.67505 .56559 Mdot
.3641 .38881 Mdot
.35753 .22966 Mdot
.4499 .78724 Mdot
.74622 .66441 Mdot
.38578 .48218 Mdot
.34961 .34221 Mdot
.39172 .80775 Mdot
.37484 .77078 Mdot
.68117 .23318 Mdot
.69166 .55578 Mdot
.45067 .50647 Mdot
.3428 .23123 Mdot
.59521 .58601 Mdot
.53991 .19554 Mdot
.58498 .21465 Mdot
.67384 .77765 Mdot
.45402 .46556 Mdot
.15988 .60987 Mdot
.30281 .54326 Mdot
.21898 .6019 Mdot
.78665 .58794 Mdot
.37955 .21471 Mdot
.29945 .63643 Mdot
.70802 .58883 Mdot
.53652 .75918 Mdot
.3899 .67229 Mdot
.65657 .2309 Mdot
.70173 .23056 Mdot
.37582 .41417 Mdot
.59766 .47409 Mdot
.18509 .63353 Mdot
.42792 .58526 Mdot
.83733 .42487 Mdot
.4075 .22714 Mdot
.79766 .6052 Mdot
.61338 .3831 Mdot
.47471 .63395 Mdot
.50571 .59004 Mdot
.46219 .8066 Mdot
.74384 .42081 Mdot
.34434 .70765 Mdot
.22259 .32904 Mdot
.19311 .61474 Mdot
.55657 .65256 Mdot
.31332 .6279 Mdot
.27128 .68996 Mdot
.31925 .27192 Mdot
.55426 .47951 Mdot
.21101 .54034 Mdot
.26257 .50309 Mdot
.17332 .55701 Mdot
.58599 .44733 Mdot
.41156 .37932 Mdot
.69403 .43901 Mdot
.50042 .27386 Mdot
.76032 .63407 Mdot
.45224 .64883 Mdot
.74446 .70619 Mdot
.30421 .69942 Mdot
.72689 .29165 Mdot
.81141 .423 Mdot
.84307 .48482 Mdot
.61883 .75585 Mdot
.29666 .3105 Mdot
.35349 .24829 Mdot
.30251 .23279 Mdot
.45968 .4383 Mdot
.26767 .61317 Mdot
.24235 .50656 Mdot
.39049 .80346 Mdot
.63023 .43615 Mdot
.77403 .46436 Mdot
.7009 .40975 Mdot
.38527 .76848 Mdot
.52833 .7267 Mdot
.3209 .71815 Mdot
.55785 .41838 Mdot
.88172 .50544 Mdot
.23075 .39622 Mdot
.53538 .42225 Mdot
.4559 .33267 Mdot
.32282 .30026 Mdot
.26464 .65549 Mdot
.23075 .40129 Mdot
.40522 .20503 Mdot
.49128 .29068 Mdot
.56158 .52208 Mdot
.44541 .76445 Mdot
.27283 .44424 Mdot
.17971 .48186 Mdot
.29956 .48927 Mdot
.35734 .78085 Mdot
.49262 .82518 Mdot
.7451 .70336 Mdot
.27575 .59114 Mdot
.16651 .46018 Mdot
.72509 .47161 Mdot
.2608 .43171 Mdot
.40883 .22863 Mdot
.38727 .33167 Mdot
.67846 .61822 Mdot
.60315 .11871 Mdot
.20091 .38312 Mdot
.27563 .34187 Mdot
.74093 .72774 Mdot
.19622 .43047 Mdot
.67761 .32817 Mdot
.51913 .6708 Mdot
.77968 .53186 Mdot
.71429 .71943 Mdot
.46032 .61075 Mdot
.85053 .49624 Mdot
.40078 .49238 Mdot
.87681 .57301 Mdot
.2992 .72368 Mdot
.5959 .46951 Mdot
.47773 .66061 Mdot
.51076 .34925 Mdot
.43231 .43726 Mdot
.33767 .60583 Mdot
.48874 .72773 Mdot
.77396 .40816 Mdot
.69905 .38871 Mdot
.50639 .37672 Mdot
.4826 .27425 Mdot
.68762 .61186 Mdot
.2197 .45527 Mdot
.53805 .30979 Mdot
.49681 .39769 Mdot
.46812 .43115 Mdot
.38289 .50172 Mdot
.7433 .38953 Mdot
.49315 .79468 Mdot
.73067 .64576 Mdot
.68854 .51118 Mdot
.4779 .37875 Mdot
.53079 .79303 Mdot
.21967 .37491 Mdot
.18609 .6077 Mdot
.74959 .72043 Mdot
.51585 .50027 Mdot
.49778 .7456 Mdot
.36021 .54793 Mdot
.81177 .48462 Mdot
.66307 .5262 Mdot
.69487 .38538 Mdot
.7468 .33552 Mdot
.60369 .53951 Mdot
.51129 .23172 Mdot
.64547 .80029 Mdot
.384 .22039 Mdot
.3397 .23141 Mdot
.38541 .43607 Mdot
.50515 .54067 Mdot
.5685 .61299 Mdot
.30151 .53043 Mdot
.59167 .38165 Mdot
.44325 .15284 Mdot
.52055 .5871 Mdot
.4 .13961 Mdot
.63175 .42993 Mdot
.59776 .64264 Mdot
.25723 .50722 Mdot
.55848 .46177 Mdot
.56543 .41434 Mdot
.24672 .37555 Mdot
.78075 .46582 Mdot
.30143 .29917 Mdot
.80153 .5171 Mdot
.51714 .364 Mdot
.18701 .37261 Mdot
.15006 .50543 Mdot
.55319 .76107 Mdot
.39688 .58736 Mdot
.17768 .41262 Mdot
.49267 .38784 Mdot
.72251 .65411 Mdot
.22759 .68743 Mdot
.19061 .52685 Mdot
.43539 .75388 Mdot
.29123 .47152 Mdot
.27139 .61745 Mdot
.48317 .8452 Mdot
.70776 .24971 Mdot
.23424 .62602 Mdot
.6279 .43571 Mdot
.5553 .43037 Mdot
.29716 .66146 Mdot
.79479 .45128 Mdot
.67301 .34706 Mdot
.76437 .40486 Mdot
.32771 .18059 Mdot
.31455 .64754 Mdot
.32892 .65268 Mdot
.79626 .43292 Mdot
.5921 .56459 Mdot
.7812 .44018 Mdot
.75238 .383 Mdot
.19849 .4715 Mdot
.25215 .32745 Mdot
.75106 .39004 Mdot
.32022 .21368 Mdot
.54063 .61073 Mdot
.5708 .36593 Mdot
.42994 .70728 Mdot
.34074 .66675 Mdot
.59323 .42098 Mdot
.65476 .76623 Mdot
.20516 .63739 Mdot
.68224 .37997 Mdot
.18 .5012 Mdot
.4803 .24269 Mdot
.34431 .65898 Mdot
.47593 .79954 Mdot
.19386 .57874 Mdot
.5234 .7382 Mdot
.64908 .21624 Mdot
.69887 .67909 Mdot
.49165 .39169 Mdot
.23279 .66962 Mdot
.48584 .367 Mdot
.38858 .70677 Mdot
.75875 .58122 Mdot
.21458 .53892 Mdot
.80797 .58832 Mdot
.30584 .43785 Mdot
.63002 .60766 Mdot
.70624 .23934 Mdot
.63593 .54908 Mdot
.83969 .52996 Mdot
.65039 .65577 Mdot
.76346 .36829 Mdot
.34072 .30611 Mdot
.31846 .33511 Mdot
.3149 .198 Mdot
.65028 .34434 Mdot
.52722 .36188 Mdot
.6275 .21949 Mdot
.64093 .60886 Mdot
.38324 .43962 Mdot
.45603 .32515 Mdot
.45246 .41946 Mdot
.57775 .22424 Mdot
.54396 .60329 Mdot
.63026 .53771 Mdot
.44159 .41681 Mdot
.58827 .8086 Mdot
.57914 .83389 Mdot
.4451 .3617 Mdot
.45796 .13571 Mdot
.4538 .67062 Mdot
.5761 .75791 Mdot
.33978 .76812 Mdot
.58687 .15116 Mdot
.54154 .36267 Mdot
.1501 .54923 Mdot
.45464 .55698 Mdot
.20207 .55268 Mdot
.66093 .59492 Mdot
.39574 .22112 Mdot
.33939 .39924 Mdot
.28222 .4773 Mdot
.66948 .41161 Mdot
.74201 .63016 Mdot
.54291 .34497 Mdot
.60441 .59478 Mdot
.20312 .48071 Mdot
.37788 .53901 Mdot
.63675 .45204 Mdot
.36426 .27671 Mdot
.54825 .76615 Mdot
.39271 .75096 Mdot
.54251 .63554 Mdot
.32641 .63344 Mdot
.29258 .2567 Mdot
.84318 .63274 Mdot
.71937 .59272 Mdot
.62666 .5173 Mdot
.63451 .24122 Mdot
.1857 .54132 Mdot
.69426 .28249 Mdot
.36202 .79718 Mdot
.40386 .50155 Mdot
.52973 .53316 Mdot
.41768 .51227 Mdot
.39677 .68995 Mdot
.53376 .45695 Mdot
.59243 .29368 Mdot
.79058 .40549 Mdot
.73248 .381 Mdot
.53777 .67612 Mdot
.68043 .25417 Mdot
.33305 .58755 Mdot
.76438 .37757 Mdot
.46891 .40187 Mdot
.3998 .7541 Mdot
.65455 .4849 Mdot
.5827 .83513 Mdot
.35432 .78702 Mdot
.63106 .36898 Mdot
.44255 .27058 Mdot
.18004 .64283 Mdot
.49668 .56739 Mdot
.57429 .51086 Mdot
.40712 .62684 Mdot
.49519 .49716 Mdot
.54489 .13742 Mdot
.18653 .51093 Mdot
.37572 .61835 Mdot
.39349 .78535 Mdot
.43207 .80908 Mdot
.88163 .53254 Mdot
.39829 .18968 Mdot
.63346 .57312 Mdot
.86018 .54266 Mdot
.76729 .40167 Mdot
.46861 .83995 Mdot
.64602 .31633 Mdot
.40873 .84735 Mdot
.54122 .75577 Mdot
.17975 .56092 Mdot
.52455 .65706 Mdot
.77999 .50254 Mdot
.38278 .2548 Mdot
.57317 .50465 Mdot
.60586 .25986 Mdot
.2291 .38371 Mdot
.18066 .36657 Mdot
.37491 .66756 Mdot
.42123 .24081 Mdot
.70483 .52593 Mdot
.24412 .69056 Mdot
.26602 .37206 Mdot
.38282 .61513 Mdot
.67777 .46073 Mdot
.78532 .60767 Mdot
.38839 .50416 Mdot
.60495 .52821 Mdot
.27275 .36274 Mdot
.71152 .70867 Mdot
.35204 .56311 Mdot
.34902 .22808 Mdot
.54352 .76413 Mdot
.45663 .44405 Mdot
.48896 .60832 Mdot
.68399 .55482 Mdot
.36329 .43434 Mdot
.55364 .49828 Mdot
.40043 .58944 Mdot
.44172 .3239 Mdot
.68213 .3537 Mdot
.82924 .53013 Mdot
.71774 .42953 Mdot
.3378 .24548 Mdot
.55113 .62112 Mdot
.74243 .5398 Mdot
.68546 .27437 Mdot
.83552 .48871 Mdot
.31657 .36587 Mdot
.3781 .50795 Mdot
.33974 .7356 Mdot
.49708 .8284 Mdot
.59801 .62776 Mdot
.8401 .62413 Mdot
.59873 .41114 Mdot
.36529 .71433 Mdot
.757 .51924 Mdot
.53107 .33764 Mdot
.51311 .63755 Mdot
.18042 .55794 Mdot
.30612 .47159 Mdot
.30763 .59462 Mdot
.27376 .32077 Mdot
.52696 .5223 Mdot
.48533 .7814 Mdot
.39564 .79178 Mdot
.50453 .32495 Mdot
.29972 .26339 Mdot
.63004 .46203 Mdot
.28226 .3586 Mdot
.49804 .831 Mdot
.7123 .74651 Mdot
.56105 .39328 Mdot
.26667 .49369 Mdot
.42627 .61695 Mdot
.32697 .23016 Mdot
.18521 .50637 Mdot
.349 .66492 Mdot
.562 .25885 Mdot
.67086 .56165 Mdot
.55828 .29935 Mdot
.48093 .4552 Mdot
.70185 .72523 Mdot
.67832 .56043 Mdot
.75323 .34251 Mdot
.36031 .42623 Mdot
.59001 .47958 Mdot
.53575 .58162 Mdot
.2776 .49449 Mdot
.40445 .17211 Mdot
.52686 .58255 Mdot
.23848 .64401 Mdot
.54162 .78184 Mdot
.43489 .22021 Mdot
.19603 .5612 Mdot
.68807 .33752 Mdot
.78141 .46941 Mdot
.42602 .77271 Mdot
.70538 .4075 Mdot
.43103 .6586 Mdot
.50913 .38041 Mdot
.60218 .586 Mdot
.23359 .68071 Mdot
.61415 .76245 Mdot
.29694 .52287 Mdot
.39553 .45793 Mdot
.59169 .54084 Mdot
.64079 .47295 Mdot
.3833 .82775 Mdot
.78256 .47907 Mdot
.35139 .4959 Mdot
.45591 .46621 Mdot
.26416 .50848 Mdot
.5955 .66215 Mdot
.69609 .77298 Mdot
.52334 .66629 Mdot
.50374 .42876 Mdot
.60492 .64114 Mdot
.27963 .32668 Mdot
.22116 .68366 Mdot
.42441 .51523 Mdot
.57779 .45607 Mdot
.31389 .45291 Mdot
.69477 .29995 Mdot
.38942 .44761 Mdot
.58919 .52592 Mdot
.42421 .40375 Mdot
.56265 .23765 Mdot
.73766 .5653 Mdot
.39491 .54282 Mdot
.28463 .59536 Mdot
.35608 .75486 Mdot
.43928 .21256 Mdot
.68982 .41618 Mdot
.58164 .33626 Mdot
.65875 .75762 Mdot
.43695 .8652 Mdot
.77034 .33103 Mdot
.4249 .61315 Mdot
.66774 .45508 Mdot
.25637 .48021 Mdot
.47995 .31649 Mdot
.73907 .36831 Mdot
.71267 .32524 Mdot
.61307 .42785 Mdot
.29462 .46864 Mdot
.31992 .59027 Mdot
.45124 .25779 Mdot
.23775 .46185 Mdot
.66648 .48435 Mdot
.83487 .51092 Mdot
.19082 .4141 Mdot
.1866 .54436 Mdot
.55926 .88247 Mdot
.65513 .44837 Mdot
.3575 .64257 Mdot
.53493 .70869 Mdot
.53297 .83967 Mdot
.30774 .49551 Mdot
.73072 .66194 Mdot
.65218 .28471 Mdot
.43368 .51427 Mdot
.71421 .57548 Mdot
.29785 .59743 Mdot
.55297 .29388 Mdot
.53665 .4431 Mdot
.31869 .34005 Mdot
.84751 .61986 Mdot
.46364 .76636 Mdot
.34569 .75025 Mdot
.7903 .59119 Mdot
.30435 .22922 Mdot
.52516 .8413 Mdot
.29767 .56277 Mdot
.25359 .39013 Mdot
.49102 .70766 Mdot
.57561 .42302 Mdot
.57864 .64408 Mdot
.72565 .65487 Mdot
.54338 .80707 Mdot
.37615 .29599 Mdot
.59176 .65164 Mdot
.38227 .52545 Mdot
.57522 .80336 Mdot
.57798 .45486 Mdot
.50223 .79752 Mdot
.45961 .27135 Mdot
.78764 .42304 Mdot
.60856 .61762 Mdot
.3227 .517 Mdot
.54272 .78745 Mdot
.61154 .23142 Mdot
.21664 .40492 Mdot
.2585 .25786 Mdot
.38238 .37873 Mdot
.8244 .50758 Mdot
.41726 .56134 Mdot
.90204 .4914 Mdot
.33368 .27686 Mdot
.38046 .26084 Mdot
.27815 .3087 Mdot
.41682 .35316 Mdot
.39881 .70294 Mdot
.43168 .65873 Mdot
.25973 .65523 Mdot
.43936 .75471 Mdot
.65227 .67077 Mdot
.75252 .61867 Mdot
.28252 .46916 Mdot
.36128 .52099 Mdot
.30154 .5362 Mdot
.54828 .55609 Mdot
.66647 .56213 Mdot
.85337 .52027 Mdot
.55494 .39179 Mdot
.34856 .65859 Mdot
.52707 .56303 Mdot
.50502 .69729 Mdot
.17729 .67221 Mdot
.60009 .46888 Mdot
.33061 .64328 Mdot
.50602 .77586 Mdot
.60846 .62772 Mdot
.70119 .28773 Mdot
.78586 .75073 Mdot
.91735 .49088 Mdot
.60965 .60056 Mdot
.4655 .19424 Mdot
.49412 .77638 Mdot
.35474 .72813 Mdot
.33072 .3605 Mdot
.54805 .24952 Mdot
.35779 .69698 Mdot
.72397 .61323 Mdot
.53184 .60994 Mdot
.33833 .26871 Mdot
.6081 .82924 Mdot
.74462 .62103 Mdot
.39002 .7821 Mdot
.40669 .68476 Mdot
.53344 .60006 Mdot
.53328 .89146 Mdot
.30362 .66834 Mdot
.49487 .64318 Mdot
.5501 .65716 Mdot
.4305 .53745 Mdot
.45556 .63211 Mdot
.21299 .5789 Mdot
.19111 .36875 Mdot
.34943 .56586 Mdot
.38262 .76562 Mdot
.69373 .58058 Mdot
.44112 .31007 Mdot
.63513 .42997 Mdot
.56376 .39547 Mdot
.51206 .61164 Mdot
.60449 .41198 Mdot
.47494 .50151 Mdot
.18162 .63432 Mdot
.40475 .44568 Mdot
.24451 .30836 Mdot
.47118 .85754 Mdot
.59608 .7705 Mdot
.71203 .33841 Mdot
.49297 .56548 Mdot
.3948 .75477 Mdot
.51713 .81839 Mdot
.57437 .53431 Mdot
.16875 .50541 Mdot
.72131 .19997 Mdot
.68796 .3092 Mdot
.6921 .74189 Mdot
.58798 .58527 Mdot
.42545 .42134 Mdot
.46395 .7783 Mdot
.64794 .32154 Mdot
.4498 .34947 Mdot
.43088 .68688 Mdot
.597 .55422 Mdot
.59688 .40006 Mdot
.47161 .12673 Mdot
.39942 .58377 Mdot
.7278 .34028 Mdot
.44514 .82686 Mdot
.70026 .67824 Mdot
.56978 .73401 Mdot
.49074 .63061 Mdot
.71745 .50644 Mdot
.57727 .4567 Mdot
.23063 .64369 Mdot
.73161 .7171 Mdot
.33961 .72061 Mdot
.61082 .76553 Mdot
.48692 .78034 Mdot
.48776 .60753 Mdot
.32167 .39102 Mdot
.62228 .35012 Mdot
.24326 .6314 Mdot
.45576 .54042 Mdot
.52426 .84977 Mdot
.54284 .33829 Mdot
.46337 .47628 Mdot
.61276 .48434 Mdot
.87639 .53634 Mdot
.54847 .68563 Mdot
.55665 .6231 Mdot
.83568 .49333 Mdot
.53232 .32228 Mdot
.25698 .44382 Mdot
.51152 .33821 Mdot
.47636 .55059 Mdot
.66396 .54623 Mdot
.84064 .42385 Mdot
.2415 .60914 Mdot
.61479 .26033 Mdot
.57062 .26937 Mdot
.48249 .21096 Mdot
.63262 .45405 Mdot
.57993 .87882 Mdot
.33886 .29133 Mdot
.84701 .45696 Mdot
.29205 .26001 Mdot
.61341 .54357 Mdot
.19463 .43806 Mdot
.52349 .60278 Mdot
.45233 .35342 Mdot
.35673 .74069 Mdot
.35509 .6562 Mdot
.76354 .66035 Mdot
.48595 .58077 Mdot
.81063 .60729 Mdot
.33407 .45864 Mdot
.41833 .2763 Mdot
.29194 .31744 Mdot
.51451 .69726 Mdot
.31515 .76641 Mdot
.68157 .2803 Mdot
.32851 .76907 Mdot
.2937 .73766 Mdot
.41305 .80802 Mdot
.76284 .64791 Mdot
.66533 .20687 Mdot
.28248 .32906 Mdot
.19175 .57676 Mdot
.60193 .31001 Mdot
.49295 .69091 Mdot
.32086 .30153 Mdot
.57907 .5578 Mdot
.7421 .42257 Mdot
.66172 .47505 Mdot
.43801 .08438 Mdot
.33699 .539 Mdot
.56655 .60428 Mdot
.31587 .31384 Mdot
.46161 .82845 Mdot
.50073 .70473 Mdot
.23537 .37504 Mdot
.49578 .45802 Mdot
.36542 .62951 Mdot
.5469 .80512 Mdot
.43963 .20821 Mdot
.41242 .25913 Mdot
.23739 .25669 Mdot
.21807 .37875 Mdot
.58612 .24771 Mdot
.52253 .45237 Mdot
.61259 .60224 Mdot
.63428 .21146 Mdot
.32729 .33272 Mdot
.16794 .48682 Mdot
.17544 .59532 Mdot
.29962 .66421 Mdot
.32316 .19427 Mdot
.41612 .22336 Mdot
.56149 .8372 Mdot
.18977 .45882 Mdot
.60803 .60073 Mdot
.28684 .55497 Mdot
.47856 .39738 Mdot
.6044 .27715 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo08_ooooo0_l0002looooo`00
7?ooool00ol0003oooooooooo`2;ooooo`;o00004?ooool2o`000:[ooooo000Looooo`03o`000?oo
oooooooo09gooooo0_l0002Zooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0002]ooooo`;o0000Voooool001cooooo
00?o0000ooooooooool0Z?ooool2o`0000;ooooo0_l0002Kooooo`007?ooool00ol0003ooooooooo
o`2Xooooo`;o0000Woooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`2Vooooo`;o00002oooool2o`0000?ooooo0_l0002?ooooo`007?ooool00ol0003o
ooooooooo`2Vooooo`;o00002oooool2o`0000?ooooo0_l0002?ooooo`007?ooool00ol0003ooooo
ooooo`2Rooooo`;o00007?ooool2o`0008Oooooo000Looooo`03o`000?oooooooooo0:;ooooo0_l0
000Looooo`;o0000Qoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`2Eooooo`;o0000/_ooool001cooooo00?o0000ooooooooool0UOooool2o`00023o
oooo0_l0002@ooooo`007?ooool00ol0003oooooooooo`2:ooooo`;o0000:oooool2o`00093ooooo
000Looooo`03o`000?oooooooooo08[ooooo0_l00005ooooo`;o00006_ooool2o`0009[ooooo000L
ooooo`03o`000?oooooooooo07kooooo0_l0000Aooooo`;o00006_ooool2o`0000Oooooo0_l0002A
ooooo`007?ooool00ol0003oooooooooo`1nooooo`;o00001Oooool2o`0002oooooo0_l0002Aoooo
o`007?ooool00ol0003oooooooooo`25ooooo`;o0000`_ooool001cooooo00?o0000ooooooooool0
Woooool2o`000:Sooooo000Looooo`;o0000SOooool2o`00017ooooo0_l0000Jooooo`;o0000S?oo
ool001cooooo00?o0000ooooooooool0S?ooool2o`0000kooooo0_l0000Mooooo`Co0000R_ooool0
01cooooo00?o0000ooooooooool0U_ooool2o`0000Cooooo0_l0000Oooooo`;o0000R_ooool001co
oooo00?o0000ooooooooool0O_ooool2o`0000_ooooo0_l00009ooooo`;o0000/Oooool001cooooo
00?o0000ooooooooool0O_ooool2o`0000?ooooo0_l00006ooooo`;o00002oooool2o`0000Cooooo
0_l00005ooooo`;o0000X_ooool001cooooo00?o0000ooooooooool0L_ooool2o`0000Wooooo0_l0
0004ooooo`;o00000oooool2o`0000Sooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo0_l0
000Vooooo`;o0000N_ooool001cooooo00?o0000ooooooooool0L_ooool2o`0000Wooooo0_l00000
0ooooooo0000o`000006ooooo`;o00002?ooool2o`00017ooooo0_l0000Vooooo`;o00005Oooool2
o`0006?ooooo000Looooo`03o`000?oooooooooo083ooooo0_l00006ooooo`;o000000?oooooo`00
0?l000004?ooool2o`0000[ooooo0_l0000Mooooo`;o00006_ooool2o`0006?ooooo000Looooo`03
o`000?oooooooooo07[ooooo0_l0000?ooooo`;o00000oooool2o`0000_ooooo0ol00009ooooo`;o
00002?ooool2o`000003ooooool0003o000000Cooooo0_l0000:ooooo`;o0000Ooooool001cooooo
00?o0000ooooooooool0Ioooool2o`00017ooooo0_l0000Dooooo`;o00003?ooool2o`00013ooooo
0_l000001?oooooo0000o`000?ooool2o`0000Cooooo0_l0002;ooooo`007?ooool00ol0003ooooo
ooooo`1Wooooo`;o00006Oooool2o`0000?ooooo0_l0000:ooooo`;o00006_ooool3o`000003oooo
ool0003o000009Cooooo000Looooo`03o`000?oooooooooo08;ooooo0_l00003ooooo`;o00002_oo
ool2o`000004ooooool0003o0000o`0000gooooo0ol00006ooooo`;o00000_ooool2o`0000[ooooo
0_l0000=ooooo`;o0000NOooool001cooooo00?o0000ooooooooool0Noooool2o`000003ooooool0
003o000000?ooooo0_l0000<ooooo`;o00000oooool3o`0000gooooo0ol00003ooooo`;o00003?oo
ool2o`0000?ooooo0_l0000=ooooo`?o0000N?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^
1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo06Oooooo0_l0000Booooo`;o0000
00?oooooo`000?l000000oooool2o`0000cooooo0_l0000<ooooo`;o000000?oooooo`000?l00000
2?ooool2o`000003ooooool0003o000000?ooooo0_l00004ooooo`;o00003?ooool2o`0000Gooooo
0_l0001hooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0IOooool4o`0001_ooooo0_l00007oooo
o`;o00001?ooool2o`0000Oooooo0_l000001?oooooo0000o`000?ooool2o`0000Sooooo0_l00000
0ooooooo0000o`000003ooooo`;o00004_ooool2o`0007oooooo00000ooooooo410@ooooo`02oooo
o`03oa0@4?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`1Soooo
o`Co00006_ooool2o`000003ooooool0003o000000Oooooo0_l00003ooooo`?o00001Oooool4o`00
00kooooo0_l0000=ooooo`;o0000:Oooool2o`00067ooooo00000ooooooo0000ooooo`02ooooo`03
o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0005Kooooo0_l0000;ooooo`;o
00007?ooool2o`000003ooooool0003o000000cooooo0ol00005ooooo`;o00007oooool2o`0000ko
oooo0_l0000Iooooo`;o0000HOooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
3?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo05Kooooo0_l0000Tooooo`;o0000
0_ooool2o`0000Wooooo0_l00003ooooo`;o000000?oooooo`000?l00000=_ooool4o`0007[ooooo
00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`1looooo`;o00000_ooool2o`0000Wooooo0_l000000ooooooo0000o`00
0002o`0000_ooooo0_l0000Hooooo`;o00001?ooool2o`0000?ooooo0_l00009ooooo`;o00001Ooo
ool2o`0007?ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo
V9RHoa0@4006ooooo`03o`000?oooooooooo07[ooooo1?l0000=ooooo`;o000000?oooooo`000?l0
00000_l00007ooooo`;o00000_ooool2o`0001?ooooo1ol00004ooooo`;o00000oooool2o`0000?o
oooo0_l000000ooooooo0000o`000008ooooo`;o00000_ooool2o`0006oooooo00001_ooooook^k^
oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooo
oooo06Cooooo0_l0000Booooo`Ko00003Oooool2o`0000?ooooo0_l00005ooooo`Co00000oooool2
o`0000kooooo0_l00002ooooo`Ko00000_ooool3o`0000[ooooo0_l000000ooooooo0000o`00000<
ooooo`;o0000Koooool001cooooo00?o0000ooooooooool0I?ooool2o`0001;ooooo0_l0000Aoooo
o`;o00001Oooool2o`0000?ooooo0ol00004ooooo`;o00003_ooool2o`0000Cooooo0_l00004oooo
o`Co00004Oooool2o`0000gooooo0_l0001Yooooo`007?ooool00ol0003oooooooooo`1Oooooo`;o
00004_ooool2o`0000Cooooo0_l00002ooooo`;o00000_ooool2o`0000Oooooo1?l00004ooooo`;o
00005Oooool2o`000003ooooool0003o000000Sooooo0_l00004ooooo`;o00002_ooool2o`0000Go
oooo0_l000000ooooooo0000o`00000:ooooo`;o0000JOooool001cooooo00?o0000ooooooooool0
Goooool2o`0000Wooooo0_l00007ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o
00000_ooool4o`0000Gooooo1?l0000=ooooo`?o00002oooool2o`000003ooooool0003o000000So
oooo1?l0000>ooooo`;o00002?ooool2o`0007Gooooo000Looooo`03o`000?oooooooooo06?ooooo
0_l00003ooooo`Co00002_ooool2o`000003ooooool0003o000000Kooooo1?l0000Fooooo`?o0000
0_ooool2o`0000Cooooo0_l0000@ooooo`;o00005oooool2o`0007Kooooo000Looooo`03o`000?oo
oooooooo05oooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l00004ooooo`Ko00003Ooo
ool2o`0000?ooooo0_l0000Hooooo`?o00000oooool2o`0001oooooo0_l00008ooooo`;o00003Ooo
ool2o`0006Oooooo000Looooo`03o`000?oooooooooo05oooooo0_l00003ooooo`Co00000oooool9
o`000003ooooool0003o000000[ooooo0_l00003ooooo`;o00004oooool2o`0000?ooooo1?l00002
ooooo`;o00006oooool2o`0000;ooooo0_l00007ooooo`?o00001_ooool3o`0000Cooooo0_l0001W
ooooo`007?ooool00ol0003oooooooooo`1Oooooo`;o00000oooool3o`0000Cooooo0ol00007oooo
o`?o00003?ooool3o`000004ooooool0003o0000ooooo`;o00003_ooool2o`0000?ooooo1?l0000O
ooooo`;o00000_ooool2o`0000Oooooo0ol00002ooooo`;o00000_ooool3o`0006gooooo000Loooo
o`03o`000?oooooooooo06Gooooo0_l00007ooooo`;o00001Oooool3o`0000Cooooo0_l000000ooo
oooo0000o`000002o`000005ooooool0003o0000o`000?ooool00_l000000ooooooo0000o`00000L
ooooo`;o00002?ooool2o`00023ooooo1?l00009ooooo`;o000000?oooooo`000?l00000H_ooool0
01cooooo00?o0000ooooooooool0K_ooool2o`0000cooooo0_l000000ooooooo0000o`000002o`00
00;ooooo0_l00006ooooo`;o00002Oooool2o`000003ooooool0003o000000?ooooo0_l00007oooo
o`;o00002?ooool2o`000003ooooool0003o000000kooooo0_l00002ooooo`;o00001_ooool2o`00
00?ooooo1?l00003ooooo`;o00000_ooool2o`000003ooooool0003o000006;ooooo000Looooo`03
o`000?oooooooooo06[ooooo0_l0000Dooooo`?o00000_ooool2o`0000Kooooo0_l00009ooooo`;o
000000?oooooo`000?l000000oooool2o`0001Cooooo0_l00008ooooo`;o00001?ooool2o`0000;o
oooo0_l00006ooooo`;o00001?ooool3o`0000?ooooo0_l00002ooooo`;o0000IOooool001cooooo
00?o0000ooooooooool0J_ooool2o`0000?ooooo0_l0000Hooooo`Co00002Oooool2o`0002?ooooo
0_l00003ooooo`;o00004_ooool2o`0007?ooooo000Looooo`;o0000B_ooool2o`00023ooooo0_l0
0002ooooo`;o00003_ooool2o`0000Sooooo1?l00009ooooo`;o00000oooool2o`00017ooooo0_l0
0003ooooo`;o00001_ooool3o`0001Cooooo1?l0000<ooooo`;o00001oooool2o`0005cooooo000L
ooooo`03o`000?oooooooooo04Wooooo0_l0000Pooooo`;o00003?ooool2o`0000Cooooo1?l0000H
ooooo`;o00001oooool2o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l000000_l00007
ooooo`;o00005?ooool3o`0000Cooooo0_l00007ooooo`;o00001oooool2o`0005cooooo000Loooo
o`03o`000?oooooooooo04Wooooo0_l00005ooooo`;o00002Oooool2o`0000;ooooo0_l00004oooo
o`;o00002oooool2o`0000Gooooo0_l00004ooooo`Co00001?ooool2o`0000Kooooo0_l0000Coooo
o`;o00000_ooool2o`0000Oooooo0_l00009ooooo`;o00001oooool2o`0000cooooo0ol00003oooo
o`;o0000K_ooool001cooooo00?o0000ooooooooool0BOooool2o`0000Gooooo0_l00009ooooo`;o
00000_ooool2o`0000Cooooo0_l0000;ooooo`;o00001?ooool2o`0000Gooooo0_l000000ooooooo
0000o`000002ooooo`?o00001_ooool2o`000003ooooool0003o000000;ooooo0_l0000<ooooo`;o
00001oooool2o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`;o00000oooool;o`0000So
oooo0_l0001cooooo`007?ooool00ol0003oooooooooo`1Kooooo`;o000000?oooooo`000?l00000
1_ooool2o`0000;ooooo0_l00004ooooo`;o00001_ooool2o`0000Cooooo1_l00002ooooo`Co0000
00?oooooo`000?l000001Oooool2o`0000;ooooo0_l00006ooooo`;o00003Oooool2o`0000Cooooo
0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l000000ooooooo0000o`000009o`0007go
oooo000Looooo`03o`000?oooooooooo05?ooooo0_l00004ooooo`;o00000oooool2o`0000Kooooo
0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o00001?ooool8o`0000Co
oooo0_l000000ooooooo0000o`00000?ooooo`Co00002?ooool2o`000003ooooool0003o000000co
oooo0_l000000ooooooo0000o`000002o`0000oooooo0_l0000:ooooo`;o0000K?ooool001cooooo
00?o0000ooooooooool0DOooool4o`0000Cooooo0_l00003ooooo`;o00001?ooool2o`0000Cooooo
0_l000000ooooooo0000o`000005ooooo`Co00001?ooool2o`0000?ooooo0_l00009ooooo`;o0000
3_ooool2o`0000[ooooo0_l000000ooooooo0000o`000004ooooo`;o00000oooool2o`0000;ooooo
1?l0000Aooooo`;o00001Oooool2o`0000?ooooo0_l0000>ooooo`;o0000G?ooool001cooooo00?o
0000ooooooooool0DOooool2o`0000_ooooo0_l00004ooooo`;o00001?ooool2o`000004ooooool0
003o0000ooooo`;o00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000006ooooo`;o0000
1_ooool2o`0000Cooooo0_l0000;ooooo`;o00001oooool2o`0000Gooooo1?l00002ooooo`?o0000
0_ooool2o`0001[ooooo0_l00005ooooo`;o00003?ooool2o`0005cooooo000Looooo`03o`000?oo
oooooooo06Cooooo0_l00003ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o0000
0_ooool4o`000003ooooool0003o000000Kooooo0_l000000ooooooo0000o`000004ooooo`;o0000
0_ooool3o`0000Gooooo0_l00004ooooo`;o00002_ooool2o`0000;ooooo0_l00004ooooo`;o0000
2?ooool5o`0000cooooo1?l00007ooooo`Co00001?ooool2o`0006Cooooo000Looooo`03o`000?oo
oooooooo04oooooo0_l00009ooooo`;o00002oooool4o`0000Sooooo0_l00002ooooo`?o00002_oo
ool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o00001Oooool3o`00013ooooo0_l0
000Booooo`Go00003?ooool6o`0000Gooooo0_l00002ooooo`;o00000_ooool2o`0006Cooooo000L
ooooo`03o`000?oooooooooo04kooooo0ol00008ooooo`?o00002oooool2o`000003ooooool0003o
000000;ooooo0_l00008ooooo`;o00001oooool2o`000003ooooool0003o000001;ooooo0_l00005
ooooo`;o00003?ooool2o`0000Gooooo0_l0000;ooooo`Oo00001oooool2o`0000?ooooo0_l00004
ooooo`;o00000_ooool3o`0000;ooooo0_l0001Tooooo`007?ooool00ol0003oooooooooo`1>oooo
o`;o00002Oooool2o`0000oooooo0_l00002ooooo`;o00002?ooool2o`0000Oooooo0_l000000ooo
oooo0000o`00000Booooo`;o00001Oooool2o`0000cooooo0_l00003ooooo`Co00001Oooool2o`00
00?ooooo2?l00007ooooo`?o00000oooool2o`0000?ooooo0_l00002ooooo`;o00004oooool2o`00
05Cooooo000Looooo`03o`000?oooooooooo05[ooooo0_l0000<ooooo`;o00007Oooool2o`0000go
oooo1_l0000?ooooo`;o00001Oooool2o`0000Oooooo0_l00003ooooo`?o00000oooool2o`000003
ooooool0003o000000Gooooo1?l000000ooooooo0000o`000009ooooo`?o00001?ooool2o`0000[o
oooo0_l0001Dooooo`007?ooool00ol0003oooooooooo`1Dooooo`;o00001?ooool2o`0000cooooo
1?l0000;ooooo`;o00003_ooool2o`0000gooooo0_l00002ooooo`Co00001_ooool2o`0000Gooooo
0ol0000Eooooo`;o000000Coooooo`000?l0003ooooo0_l00007ooooo`?o00000_ooool2o`0000Oo
oooo0ol00004ooooo`?o0000Goooool001cooooo00?o0000ooooooooool0COooool2o`0000Gooooo
0_l00004ooooo`;o00003_ooool2o`0000_ooooo0_l00005ooooo`;o00004?ooool3o`0000Sooooo
0ol00006ooooo`;o00001_ooool2o`0000;ooooo0_l0000;ooooo`;o00001?ooool2o`0000kooooo
0_l00002ooooo`?o00002oooool2o`000004ooooool0003o0000o`0005kooooo000Looooo`03o`00
0?oooooooooo04gooooo0_l00005ooooo`;o00003Oooool2o`0000Wooooo0_l00006ooooo`?o0000
1Oooool2o`0000Kooooo0_l00008ooooo`?o00002?ooool2o`0000kooooo0ol00002ooooo`;o0000
2oooool2o`0000;ooooo0_l00004ooooo`;o00003oooool2o`000003ooooool0003o000000Sooooo
0_l00002ooooo`;o0000G_ooool001cooooo0_l0001Aooooo`;o00003?ooool4o`000003ooooool0
003o000000;o00001oooool3o`0000Gooooo0ol00007ooooo`;o00001?ooool2o`0000Sooooo0_l0
0008ooooo`?o00003_ooool3o`0000Cooooo0_l00009ooooo`Ko00001?ooool2o`0001;ooooo0_l0
00000ooooooo0000o`00001Yooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o00003?ooool4
o`0000?ooooo0_l00008ooooo`Co00003Oooool2o`0000Oooooo0_l0000?ooooo`;o00000_ooool2
o`0000;ooooo0_l00004ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`0000Wooooo1?l0
000:ooooo`;o00001_ooool2o`0000Gooooo0_l00002ooooo`;o00005oooool2o`00053ooooo000L
ooooo`03o`000?oooooooooo05Cooooo0_l000000ooooooo0000o`000003ooooo`;o00003Oooool2
o`000004ooooool0003o0000ooooo`;o00005_ooool2o`0000Cooooo0_l000001?oooooo0000o`00
0?ooool2o`000003ooooool0003o000000;o00000_ooool2o`0000;ooooo1?l00002ooooo`;o0000
00Coooooo`000?l0003o00002oooool6o`0000cooooo0ol00005ooooo`;o00001?ooool3o`0000Wo
oooo0ol0000?ooooo`;o0000D?ooool001cooooo00?o0000ooooooooool0C?ooool2o`0000Kooooo
0_l000000ooooooo0000o`000003ooooo`?o00001_ooool2o`0000Cooooo0_l000000ooooooo0000
o`00000>ooooo`;o00001?ooool2o`0000Kooooo0_l000000ooooooo0000o`000009o`000003oooo
ool0003o000000;o00001?ooool4o`0000Cooooo0ol0000;ooooo`Ko000000?oooooo`000?l00000
2_ooool2o`0000_ooooo0_l000000ooooooo0000o`000007ooooo`?o0000HOooool001cooooo00?o
0000ooooooooool0C?ooool2o`0000Wooooo0ol00003ooooo`;o00001?ooool4o`0001Oooooo0_l0
0004ooooo`;o00001_ooool2o`0000;ooooo3ol00006ooooo`;o00000oooool4o`00017ooooo0ol0
000Jooooo`;o00005oooool2o`0005;ooooo000Looooo`03o`000?oooooooooo05Sooooo0_l00005
ooooo`?o000000?oooooo`000?l000003_ooool2o`0000?ooooo0_l0000FoooooaOo00000oooool2
o`0001?ooooo1Ol0000:ooooo`;o00002Oooool2o`0001[ooooo0_l0001Booooo`007?ooool00ol0
003oooooooooo`1Hooooo`Go00000_ooool3o`00017ooooo0_l00003ooooo`;o00003?ooool3o`00
00Sooooo5?l00006ooooo`;o00001_ooool2o`0000Oooooo0ol000000ooooooo0000o`000002o`00
00[ooooo0_l00009ooooo`;o00000_ooool2o`0000gooooo0_l0001Kooooo`007?ooool00ol0003o
ooooooooo`1Eooooo`;o00000oooool3o`0000?ooooo0_l0000Tooooo`?o00001?oooolBo`000003
ooooool0003o000000;o00001Oooool4o`0000Kooooo0_l00006ooooo`Co000000?oooooo`000?l0
00002?ooool2o`0000?ooooo0_l00003ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`Co
00001Oooool4o`0000gooooo0_l000000ooooooo0000o`000019ooooo`007?ooool00ol0003ooooo
ooooo`1Eooooo`;o0000:?ooool2o`000004ooooool0003o0000ooooo`;o00001Oooool6o`000003
ooooool0003o000000oo000000Goooooo`000?l0003o0000ooooo`02o`0000Oooooo0_l00007oooo
o`;o00002?ooool2o`0000?ooooo0_l00003ooooo`;o00000oooool4o`0000Cooooo2_l00004oooo
o`Co00001?ooool2o`0000Oooooo0_l000000ooooooo0000o`000019ooooo`007?ooool00ol0003o
ooooooooo`15ooooo`;o000000?oooooo`000?l000000oooool3o`0000Oooooo1Ol00003ooooo`;o
00007_ooool2o`000004ooooool0003o0000ooooo`;o00001Oooool;o`000003ooooool0003o0000
00[o000000?oooooo`000?l000000_l00009ooooo`;o00000_ooool2o`0000Oooooo0_l00004oooo
o`;o00003_ooool5o`0000;ooooo1Ol00003ooooo`;o00001_ooool2o`0000Cooooo1Ol00009oooo
o`;o0000Aoooool001cooooo00?o0000ooooooooool0@_ooool2o`000004ooooool0003o0000oooo
o`Co000000Coooooo`000?l0003o00001oooool5o`0000?ooooo0_l0000=ooooo`;o00002_ooool2
o`0001?ooooo2?l000000ooooooo0000o`00000?o`0000gooooo0_l00007ooooo`;o00004Oooool2
o`0000?ooooo0ol0000?ooooo`Co00000_ooool2o`0000;ooooo1Ol00008ooooo`;o0000Aoooool0
01cooooo00?o0000ooooooooool0@_ooool2o`0000Kooooo0_l0000Hooooo`;o000000?oooooo`00
0?l000001Oooool2o`0000[ooooo0_l00003ooooo`;o00000oooool2o`0000Oooooo3?l000000ooo
oooo0000o`000002o`000003ooooool0003o000000Ko00001_ooool2o`000003ooooool0003o0000
00Cooooo0_l0000Hooooo`Co00000oooool2o`00013ooooo1?l00002ooooo`;o00001Oooool2o`00
057ooooo000Looooo`03o`000?oooooooooo04;ooooo0_l0000Kooooo`;o000000?oooooo`000?l0
00000_l000000ooooooo0000o`00000Fooooo`;o00000oooool2o`0000Gooooo6ol00003ooooo`;o
00000_ooool2o`000003ooooool0003o000000Cooooo0_l000001?oooooo0000o`000?l0000>oooo
o`;o00001?ooool4o`000004ooooool0003o0000o`0000;ooooo1_l00003ooooo`?o00001Oooool2
o`0000;ooooo0_l0001Hooooo`007?ooool00ol0003oooooooooo`1Oooooo`;o000000?oooooo`00
0?l000000_l0000Pooooo`;o000000?oooooo`000?l000006ol00003ooooo`;o00000_ooool2o`00
00[ooooo0ol000000ooooooo0000o`00000;ooooo`;o00000oooool2o`000003ooooool0003o0000
00Co00000_ooool6o`0000?ooooo1Ol000000ooooooo0000o`000002o`0000Cooooo0_l0001Foooo
o`007?ooool00ol0003oooooooooo`1Fooooo`;o00003?ooool2o`0000Sooooo0_l0000<ooooo`;o
00002?ooool2o`000003ooooool0003o000001[o00002oooool2o`0000_ooooo0_l00002ooooo`;o
00003?ooool2o`0000?ooooo0ol00002ooooo`;o00002?ooool5o`000003ooooool0003o000000Ko
oooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00003oooool2o`0001;ooooo
0_l00002ooooo`;o00002Oooool2o`000003ooooool0003o000000?ooooo0ol00006oooooaco0000
1oooool2o`000003ooooool0003o000000oooooo0_l0000<ooooo`Co00000_ooool6o`0000Sooooo
0_l00007ooooo`;o00000oooool2o`0005Kooooo000Looooo`;o0000A_ooool2o`0001Gooooo0_l0
000<ooooo`;o00003Oooool2o`0000Kooooo1?l00005ooooo`co000000Coooooo`000?l0003ooooo
3?l00007ooooo`;o00002_ooool2o`0000_ooooo0_l00009ooooo`;o00000oooool5o`0000Gooooo
0_l00008ooooo`Co000000?oooooo`000?l00000F?ooool001cooooo00?o0000ooooooooool0G?oo
ool2o`0002Gooooo0ol00003ooooo`?o000000?oooooo`000?l000002?l00002ooooo`go00004ooo
ool2o`0000Gooooo0_l00004ooooo`?o00001oooool2o`0000Cooooo1_l00004ooooo`;o00001Ooo
ool2o`000003ooooool0003o000000;o000000?oooooo`000?l00000F?ooool001cooooo00?o0000
ooooooooool0C_ooool2o`0000Oooooo0_l0000Yooooo`Ko000000?oooooo`000?l000006_l0000D
ooooo`;o00001Oooool2o`0000Cooooo0ol000000ooooooo0000o`000004ooooo`;o00002?ooool2
o`0000_ooooo0_l00006ooooo`;o0000F?ooool001cooooo00?o0000ooooooooool0@?ooool2o`00
00_ooooo1?l00006ooooo`?o00002_ooool2o`0001Gooooo0_l00005ooooo`?o000000?oooooo`00
0?l000007?l00004ooooo`;o00003_ooool2o`0000cooooo0_l00002ooooo`Co00005oooool2o`00
00Sooooo0_l0000Kooooo`;o0000>oooool001cooooo00?o0000ooooooooool0@?ooool2o`000003
ooooool0003o000000?ooooo0_l00003ooooo`Co000000Coooooo`000?l0003ooooo0_l000000ooo
oooo0000o`00000:ooooo`;o00000_ooool2o`0000?ooooo0_l0000<ooooo`?o000000?oooooo`00
0?l000000_ooool2o`000003ooooool0003o000001_o000000?oooooo`000?l000001?l00002oooo
o`;o00000oooool2o`0000Gooooo0_l0000;ooooo`;o00001Oooool2o`0001Oooooo0ol0000?oooo
o`;o00004oooool2o`0003_ooooo000Looooo`03o`000?oooooooooo04?ooooo0_l00002ooooo`?o
00002?ooool2o`000003ooooool0003o000000cooooo0_l00003ooooo`;o00000oooool2o`0000go
oooo0_l000000ooooooo0000o`000004oooooako000000?oooooo`000?l000000ol00003ooooo`;o
00000oooool2o`0000?ooooo0_l000000ooooooo0000o`00000:ooooo`;o00001oooool3o`0000Oo
oooo0_l0000<ooooo`;o00000_ooool2o`0000[ooooo0ol0000Gooooo`;o0000=oooool001cooooo
00?o0000ooooooooool0=oooool2o`000003ooooool0003o000000_ooooo0ol0000Iooooo`;o0000
2?ooool2o`0000_ooooo0_l00002ooooo`;o00001OoooolQo`000003ooooool0003o000000gooooo
0_l000000ooooooo0000o`000002ooooo`;o00001oooool2o`000003ooooool0003o000000Ko0000
1Oooool5o`0000oooooo1?l00006ooooo`Co00006?ooool2o`0003Oooooo000Looooo`03o`000?oo
oooooooo03Oooooo0_l000000ooooooo0000o`000006ooooo`;o00003oooool3o`0000?ooooo0_l0
000@ooooo`Co00002oooool2o`0000;ooooo0_l00009oooooa?o000000?oooooo`000?l000002?l0
0005ooooo`;o00002?ooool2o`0000Gooooo0ol00006ooooo`;o000000?oooooo`000?l000002_l0
00001?oooooo0000o`000?ooool6o`0000gooooo0_l00006ooooo`Co000000?oooooo`000?l00000
C_ooool001cooooo00?o0000ooooooooool0>Oooool2o`0000Oooooo1?l00003ooooo`Ko00001?oo
ool3o`0000?ooooo1?l0000>ooooo`;o00003Oooool2o`0000Oooooo0_l00004oooooako00001Ooo
ool2o`0000Sooooo0_l00006ooooo`;o00001_ooool?o`000003ooooool0003o000000?ooooo1Ol0
000Fooooo`;o000000?oooooo`000?l000008Oooool2o`0002_ooooo000Looooo`03o`000?oooooo
oooo03Wooooo0_l00009ooooo`;o00000oooool6o`0000cooooo0_l00007ooooo`;o00007Oooool2
o`0000Cooooo0_l000000ooooooo0000o`00000:o`000003ooooool0003o000000[o00004Oooool4
o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000004_l00002ooooo`Go00000_ooool2
o`0000;ooooo0_l0000<ooooo`;o00009_ooool2o`0002_ooooo000Looooo`03o`000?oooooooooo
03Cooooo0_l00005ooooo`;o00001_ooool4o`0001Cooooo0_l00006ooooo`?o00002oooool2o`00
00Gooooo0_l00002ooooo`;o00001?ooool2o`0000;ooooo0_l00002oooooa7o00000_ooool8o`00
017ooooo1Ol000001Ooooooo0000o`000?l0003ooooo00Co000000?oooooo`000?l000004_l00000
0ooooooo0000o`000002o`0000Cooooo0_l00002ooooo`;o00000_ooool2o`0000Sooooo0_l0001C
ooooo`007?ooool00ol0003oooooooooo`0dooooo`Co00000oooool2o`000003ooooool0003o0000
00?ooooo1_l0000Booooo`;o00000oooool5o`0000cooooo0_l00005ooooo`;o00000_ooool2o`00
00Cooooo0_l00002oooooako00005?ooool3o`000003ooooool0003o000000;ooooo0_l000001?oo
oooo0000o`000?ooool>o`000003ooooool0003o000000Go00001Oooool2o`0000Oooooo0_l00005
ooooo`;o0000E_ooool001cooooo00?o0000ooooooooool0=_ooool2o`0000Kooooo0_l00007oooo
o`;o00004_ooool2o`0000?ooooo1?l000001?oooooo0000o`000?l00009ooooo`;o00001_ooool2
o`0000gooooo5ol000000ooooooo0000o`00000Fooooo`?o00000_ooool2o`000004ooooool0003o
0000oooooa[o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00002_ooool2o`000003oooo
ool0003o000005?ooooo000Looooo`03o`000?oooooooooo03gooooo0_l0000<ooooo`;o00000_oo
ool2o`0000cooooo0_l000000ooooooo0000o`000006o`000004ooooool0003o0000o`0000;ooooo
1ol00003ooooo`?o00001?ooool2o`0000Wooooo0_l000000ooooooo0000o`00000?o`0001_ooooo
0_l00002ooooo`;o000000?oooooo`000?l000005ol000001Ooooooo0000o`000?l0003ooooo00?o
00000_ooool4o`0000Oooooo1Ol000000ooooooo0000o`000007ooooo`;o0000B_ooool00006oooo
ooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04oooo
o`03o`000?oooooooooo03[ooooo0_l000000ooooooo0000o`000003o`0000Wooooo0_l00002oooo
o`;o00003?ooool2o`0000?ooooo1Ol000000ooooooo0000o`000002o`000003ooooool0003o0000
00Ko00000oooool2o`0000Gooooo0_l00009ooooo`;o000000?oooooo`000?l000003ol00002oooo
o`;o00003_ooool6o`0000Wooooo2Ol000000ooooooo0000o`000002o`000003ooooool0003o0000
00co00000oooool2o`0000;ooooo0_l00009ooooo`Co00001?ooool2o`0000Gooooo0_l0001:oooo
o`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo037ooooo0_l00007ooooo`?o000000?oooooo`000?l000001?l00003
ooooo`;o00002oooool2o`0000Cooooo0_l00002ooooo`;o00000_ooool:o`000003ooooool0003o
000000Co00002oooool2o`0000oooooo2ol000000ooooooo0000o`000005o`0000_ooooo0_l00000
0ooooooo0000o`000004o`0000?ooooo0_l00002ooooo`oo000000?oooooo`000?l000003_l00003
ooooo`;o00005?ooool2o`00057ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo
00Wooooo1Ol00006ooooo`03o`000?oooooooooo037ooooo0_l00008ooooo`;o00001?ooool3o`00
00?ooooo0_l0000;ooooo`;o00001?ooool2o`0000;ooooo5?l000000ooooooo0000o`000009oooo
o`;o00003?ooool2o`0000?ooooo1?l000000ooooooo0000o`000002o`0000Cooooo0_l0000=oooo
o`;o00000_ooool4o`0000Cooooo0_l00002ooooo`?o000000?oooooo`000?l000005ol000000ooo
oooo0000o`000003ooooo`;o00002oooool2o`0000Cooooo0_l0001Dooooo`0000?oooooo`000?oo
ool00_ooool00ol0003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol00011oooo
o`Co00000_ooool2o`0000oooooo1?l00004oooooa7o00000_ooool3o`0000;ooooo0_l0000Boooo
o`;o00001oooool2o`000003ooooool0003o000000Cooooo0_l0000Aooooo`;o00001_ooool2o`00
00?ooooo7Ol000000ooooooo0000o`000002ooooo`Co00002Oooool:o`0000[ooooo0_l00016oooo
o`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`00
00Oooooo00?o0000ooooooooool0@oooool2o`0000;ooooo1?l00008ooooo`;o00000oooool2o`00
00Kooooo5_l00002ooooo`;o00003?ooool2o`0000Sooooo0_l00003ooooo`;o00008oooool2o`00
00;ooooo4_l000000ooooooo0000o`000008o`000003ooooool0003o000000Cooooo0_l0000:oooo
o`Wo00001_ooool2o`0000;ooooo0_l00016ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413o
ooooooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0@oooool2o`0000Co
oooo0_l00008ooooo`;o00002OoooolFo`0001;ooooo0_l00008ooooo`Go00009Oooool8o`0000;o
oooo5ol00003ooooo`;o000000Coooooo`000?l0003o00000_ooool4o`0000[ooooo0_l00002oooo
o`;o00000oooool2o`0004[ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^
odA4A?l000001oooool00ol0003oooooooooo`0mooooo`;o00002_ooool2o`00013ooooo0_l00000
0ooooooo0000o`00000Bo`00023ooooo0ol000000ooooooo0000o`00000Oooooo`;o00000_ooool:
o`000003ooooool0003o0000017o00001Oooool6o`0000;ooooo1?l000000ooooooo0000o`00000;
ooooo`;o0000Coooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000oooo
o`06ooooo`03o`000?oooooooooo03Kooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o0000
2_ooool2o`0000kooooo6Ol00004ooooo`;o00002?ooool2o`0001Cooooo0_l0000Looooo`;o0000
00?oooooo`000?l000000_oooolOo`0000?ooooo2ol00003ooooo`;o00007_ooool2o`0003cooooo
000Looooo`03o`000?oooooooooo037ooooo0_l00003ooooo`;o000000Coooooo`000?l0003o0000
0_ooool2o`0001Wooooo0_l000000ooooooo0000o`00000Eo`000003ooooool0003o000000;o0000
2?ooool2o`0000[ooooo0_l0000<ooooo`;o000000?oooooo`000?l000002_ooool2o`0000Kooooo
0_l000000ooooooo0000o`000009oooooa_o00000_ooool4o`0000Cooooo1?l0000Booooo`;o0000
3oooool2o`0003cooooo000Looooo`03o`000?oooooooooo037ooooo0ol00007ooooo`;o000000?o
ooooo`000?l000000_l0000KoooooaWo00004?ooool2o`0000Cooooo0_l000000ooooooo0000o`00
0009ooooo`;o000000?oooooo`000?l000002_ooool2o`0000Kooooo0_l00009ooooo`Ko000000?o
ooooo`000?l000004Ol000000ooooooo0000o`000002ooooo`?o00004?ooool4o`0000Sooooo0_l0
0006ooooo`Co0000@oooool001cooooo00?o0000ooooooooool0<_ooool2o`0000Oooooo0_l00000
0ooooooo0000o`000002o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o
000000;ooooo0_l00007oooooaSo00004Oooool2o`0000Oooooo0_l0000Iooooo`;o00002oooool3
o`0000;ooooo6Ol00006ooooo`;o00000oooool2o`0000Kooooo0_l00003ooooo`Go00002_ooool2
o`0000Cooooo1?l00005ooooo`Co0000>_ooool001cooooo00?o0000ooooooooool0AOooool2o`00
00;ooooo0ol000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00006ooooo`co000000?ooooo
o`000?l000002_l00002ooooo`Co00002_ooool2o`0002?ooooo0_l00003ooooo`;o00001?ooool5
o`0000Kooooo5_l00005ooooo`;o00000oooool2o`0000Kooooo0_l00003ooooo`;o000000Cooooo
o`000?l0003ooooo0_l00007ooooo`;o00001_ooool2o`0000Gooooo1_l0000hooooo`007?ooool0
0ol0003oooooooooo`0looooo`;o00003?ooool2o`000003ooooool0003o000000;ooooo0_l00006
ooooo`;o000000?oooooo`000?l000005ol00002ooooo`Co00001oooool2o`000003ooooool0003o
000000Oooooo0_l0000@ooooo`;o00001?ooool2o`0000Oooooo1?l00002ooooo`Co00001OoooolD
o`000004ooooool0003o0000o`0000Gooooo1?l00006ooooo`;o00002Oooool2o`000003ooooool0
003o000001[ooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0looooo`;o00003oooool2
o`0000;ooooo0_l00006oooooaco00002?ooool4o`000003ooooool0003o000000[ooooo0_l00004
ooooo`;o00001oooool2o`000003ooooool0003o000000Cooooo0_l00009ooooo`;o00000oooool3
o`0000Gooooo4_l00003ooooo`;o00000oooool7o`0000Kooooo0ol0000Gooooo`;o00000oooool2
o`0004?ooooo000Looooo`03o`000?oooooooooo01oooooo0_l0000Kooooo`?o00003_ooool2o`00
00;ooooo1?l000000ooooooo0000o`000002o`000003ooooool0003o000001Oo00001Oooool2o`00
00;ooooo1?l000000ooooooo0000o`00000:ooooo`;o00001?ooool2o`0000?ooooo2Ol0000Eoooo
o`;o00000ooooolFo`0000Kooooo1_l00007ooooo`?o00003_ooool2o`0000Oooooo0_l00003oooo
o`;o0000@oooool001cooooo00?o0000ooooooooool07oooool2o`0001_ooooo0ol0000Dooooo`;o
000000?oooooo`000?l000000_l00002ooooo`Ko000000?oooooo`000?l000003ol00003ooooo`Co
00001oooool2o`0000Gooooo0_l00003ooooo`;o00000_ooool2o`0000Gooooo1?l000000ooooooo
0000o`000002o`0000?ooooo0_l0000=ooooo`;o000000?oooooo`000?l000000oooool4o`000003
ooooool0003o000000Co000000?oooooo`000?l000001?l00002ooooo`;o000000?oooooo`000?l0
00001Oooool2o`0000;ooooo0_l0000Dooooo`Co00000_ooool2o`0000Gooooo0_l0000Eooooo`;o
0000;oooool001cooooo00?o0000ooooooooool08Oooool2o`0000Wooooo0_l0000>ooooo`;o0000
2?ooool2o`0000Kooooo0_l00007ooooo`;o00001?oooolIo`000003ooooool0003o000000Co0000
0_ooool2o`0000Sooooo0_l00007ooooo`;o00000_ooool2o`0000gooooo0_l00004ooooo`;o0000
1oooool2o`0000;ooooo0_l00007ooooo`Ko000000?oooooo`000?l000001_l00003ooooo`;o0000
1Oooool2o`0000;ooooo1?l0000Booooo`;o00000oooool3o`0000;ooooo0_l000000ooooooo0000
o`000003ooooo`;o00004?ooool2o`0002oooooo000Looooo`03o`000?oooooooooo027ooooo0_l0
0009ooooo`;o00006?ooool2o`0000Kooooo1?l00003ooooo`;o00000_ooool2o`0000;ooooo0_l0
00000ooooooo0000o`00000@o`0000;ooooo0_l00005ooooo`;o00000_ooool3o`0000Wooooo0_l0
0004ooooo`?o00000_ooool2o`0001?ooooo0_l00007ooooo`;o00000_ooool2o`000003ooooool0
003o000000Kooooo1?l00004ooooo`Go00002_ooool2o`0000Cooooo0_l00002ooooo`;o00004_oo
ool3o`0000?ooooo1?l00004ooooo`;o00000oooool2o`0003cooooo000Looooo`03o`000?oooooo
oooo04_ooooo0_l00003ooooo`;o00000oooool2o`0000;ooooo0ol000000ooooooo0000o`00000C
o`0000Wooooo0_l00002ooooo`?o00002Oooool2o`0000Cooooo0_l0000Sooooo`;o00000oooool4
o`0000Cooooo0ol00007ooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o000000?ooooo
o`000?l000001Oooool2o`0000?ooooo0_l0000=ooooo`;o00001_ooool2o`0000Wooooo0_l0000l
ooooo`007?ooool2o`0003Oooooo1?l0000Aooooo`;o00001Oooool2o`000003ooooool0003o0000
00;o000000?oooooo`000?l000000_l000000ooooooo0000o`000002ooooo`go00002oooool2o`00
00;ooooo1?l0000Sooooo`;o00001oooool4o`0000?ooooo0_l00003ooooo`Co00002Oooool2o`00
0003ooooool0003o000000;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000003oooo
o`;o00002_ooool2o`0001?ooooo0_l00019ooooo`007?ooool00ol0003oooooooooo`0fooooo`Co
00002_ooool2o`0000cooooo0_l00003ooooo`;o00000oooool2o`0000?ooooo3Ol0000:ooooo`;o
00001oooool2o`0001Gooooo0_l0000<ooooo`;o00001oooool4o`0000Gooooo0_l00003ooooo`;o
00002Oooool5o`0000Sooooo0_l000001?oooooo0000o`000?l0000Pooooo`;o000000?oooooo`00
0?l00000BOooool001cooooo00?o0000ooooooooool0=Oooool2o`000003ooooool0003o000000[o
oooo1?l0000>ooooo`;o000000?oooooo`000?l000001_ooool:o`0000gooooo0_l00003ooooo`;o
00000_ooool2o`000003ooooool0003o000001;ooooo0ol000001?oooooo0000o`000?l00002oooo
o`?o00001_ooool2o`0000cooooo0_l00004ooooo`;o00000oooool2o`0000Gooooo0_l00009oooo
o`;o00000_ooool2o`0000Oooooo0_l0000Gooooo`Go00001_ooool2o`0000Oooooo0_l00005oooo
o`;o0000<Oooool001cooooo00?o0000ooooooooool0:oooool2o`0000Gooooo0_l000000ooooooo
0000o`000003ooooo`;o00001?ooool3o`000003ooooool0003o000000;o00000_ooool2o`0000Oo
oooo0_l000001?oooooo0000o`000?ooool2o`0000cooooo1?l00006ooooo`?o00001oooool4o`00
00;ooooo0_l000000ooooooo0000o`000008ooooo`;o00001Oooool2o`0000;ooooo0_l000001?oo
oooo0000o`000?l00002ooooo`?o00001?ooool6o`0000Cooooo0_l00004ooooo`;o000000Cooooo
o`000?l0003ooooo0_l000000ooooooo0000o`000002o`0000Wooooo1?l00006ooooo`;o00002?oo
ool2o`0001Sooooo0_l000000ooooooo0000o`000005ooooo`;o00001oooool2o`0000Gooooo0_l0
0002ooooo`;o0000;Oooool001cooooo00?o0000ooooooooool0:oooool4o`0000?ooooo0_l00002
ooooo`;o00000_ooool2o`0000Cooooo1?l00006ooooo`;o00001oooool2o`0001cooooo0ol00007
ooooo`;o00001Oooool2o`0000[ooooo0_l000000ooooooo0000o`000004o`0000_ooooo0_l00004
ooooo`;o00000_ooool2o`0000Cooooo0_l00007ooooo`;o00001?ooool2o`0000Kooooo0_l00003
ooooo`Co00001_ooool2o`0000Gooooo1?l0000Eooooo`;o00001Oooool2o`0001Wooooo0_l0000]
ooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o00001oooool2o`0000[ooooo0_l0000Foooo
o`;o00009Oooool6o`0000Gooooo0_l00002ooooo`Go00003Oooool2o`0000?ooooo0_l00002oooo
o`;o00005?ooool2o`0000;ooooo0_l00002ooooo`;o00000_ooool3o`0000Cooooo0_l000001?oo
oooo0000o`000?ooool2o`0000?ooooo1?l0000Eooooo`Co00002Oooool2o`0004;ooooo000Loooo
o`03o`000?oooooooooo037ooooo0_l00008ooooo`;o00001?ooool2o`0000Wooooo0_l00007oooo
o`;o000000?oooooo`000?l000001ol00008ooooo`;o000000?oooooo`000?l000004oooool2o`00
0003ooooool0003o000000Co00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000?oooo
o`;o000000?oooooo`000?l000000_ooool2o`00017ooooo1_l000000ooooooo0000o`000006oooo
o`?o00000_ooool4o`000003ooooool0003o000000?o00000oooool2o`0001Oooooo1?l00006oooo
o`;o000000?oooooo`000?l00000@_ooool001cooooo00?o0000ooooooooool0<Oooool3o`0000Oo
oooo1?l00002ooooo`;o00002Oooool2o`0000Oooooo0_l000001?oooooo0000o`000?ooool7o`00
00Cooooo0_l000001?oooooo0000o`000?ooool4o`0000Kooooo0_l00008ooooo`;o00000oooool5
o`0000_ooooo0_l0000=ooooo`;o000000?oooooo`000?l000000_l0000@ooooo`;o000000?ooooo
o`000?l000001?l000000ooooooo0000o`000005ooooo`;o00001?ooool2o`0000?ooooo1?l0000:
ooooo`Go00003Oooool2o`000003ooooool0003o000000Kooooo0_l00015ooooo`007?ooool00ol0
003oooooooooo`0booooo`;o00001?ooool2o`0000?ooooo0_l00002ooooo`;o00006?ooool2o`00
00;ooooo0ol00004ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0000Kooooo0_l00008
ooooo`;o00004Oooool4o`0000gooooo0_l000000ooooooo0000o`000002o`0000kooooo1?l00000
0ooooooo0000o`00000<ooooo`;o00001Oooool2o`0000;ooooo0_l0000<ooooo`Go00003Oooool2
o`00053ooooo000Looooo`03o`000?oooooooooo03Sooooo0_l00003ooooo`;o000000Coooooo`00
0?l0003o00000oooool2o`0000Sooooo0_l00003ooooo`;o000000?oooooo`000?l000000oooool2
o`0000Oooooo0_l00002ooooo`;o00004_ooool2o`000003ooooool0003o000000Oooooo0_l00007
ooooo`;o00002oooool2o`0000;ooooo0_l0000:ooooo`;o00000oooool2o`0000;ooooo0_l00000
0ooooooo0000o`00000Eooooo`;o000000Coooooo`000?l0003o00001Oooool2o`0000Sooooo0_l0
0006ooooo`Go00000oooool4o`0001;ooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`0d
ooooo`;o000000?oooooo`000?l000001Oooool4o`0000Cooooo0_l00008ooooo`;o00000oooool2
o`000003ooooool0003o000000;o000000Coooooo`000?l0003o00001_ooool2o`0000cooooo0_l0
0004ooooo`;o00000_ooool2o`000003ooooool0003o000000Oooooo0_l00009ooooo`;o00001_oo
ool2o`000003ooooool0003o000000cooooo1?l00003ooooo`;o00001?ooool3o`0001Sooooo0_l0
0006ooooo`;o00004?ooool5o`0000?ooooo1?l0000Booooo`;o0000>Oooool001cooooo00?o0000
ooooooooool0=?ooool2o`000003ooooool0003o000000Gooooo1?l00009ooooo`;o00003Oooool2
o`0000;ooooo0_l00002ooooo`?o00001oooool4o`0000Cooooo0_l00004ooooo`;o00000_ooool2
o`0000oooooo0_l00004ooooo`;o00001_ooool2o`000003ooooool0003o000000cooooo1?l00009
ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00000_ooool2o`0000Gooooo0_l0000=
ooooo`;o00002?ooool2o`000004ooooool0003o0000o`0000Gooooo0_l00002ooooo`;o00002?oo
ool2o`0003Wooooo000Looooo`03o`000?oooooooooo03?ooooo0_l00005ooooo`;o00001?ooool2
o`0000Wooooo0_l00007ooooo`;o00001oooool3o`0000;ooooo2Ol000000ooooooo0000o`000002
o`0000oooooo0_l00003ooooo`;o00002Oooool2o`0000Kooooo0_l00003ooooo`;o000000?ooooo
o`000?l000000_l0000:ooooo`;o000000?oooooo`000?l000004Oooool2o`0000Gooooo0_l00005
ooooo`?o000000?oooooo`000?l000001Oooool2o`000003ooooool0003o000000?ooooo0_l00005
ooooo`;o00002?ooool2o`0000;ooooo1_l000000ooooooo0000o`000002ooooo`;o00001_ooool4
o`0003Wooooo000Looooo`03o`000?oooooooooo02kooooo0_l000000ooooooo0000o`000002o`00
00Gooooo0_l0000=ooooo`;o00002Oooool2o`0000?ooooo0ol000001?oooooo0000o`000?l00002
ooooo`;o000000?oooooo`000?l000001Ol00005ooooo`;o00002oooool3o`0000?ooooo0ol00007
ooooo`;o00001Oooool4o`0000?ooooo0_l000000ooooooo0000o`000002o`000004ooooool0003o
0000o`0000Kooooo0_l00005ooooo`;o00005_ooool2o`0000Cooooo0_l000000ooooooo0000o`00
0008ooooo`;o00000oooool2o`0000Gooooo0_l00009ooooo`;o00000oooool4o`0000gooooo1?l0
0006ooooo`Co00001oooool2o`0000?ooooo0_l0000Qooooo`007?ooool00ol0003oooooooooo`0^
ooooo`;o000000?oooooo`000?l000005_ooool2o`0000Sooooo0_l000001?oooooo0000o`000?oo
ool3o`0000;ooooo1?l00006ooooo`Co00000oooool4o`0000_ooooo0_l00005ooooo`;o00001ooo
ool2o`0000Gooooo0_l0000<ooooo`Co00001Oooool2o`0000Kooooo0_l0000Fooooo`;o00004Ooo
ool2o`0000[ooooo0_l00009ooooo`Go00001Oooool2o`0000;ooooo0_l00006ooooo`Co00001_oo
ool4o`0000Oooooo0_l00003ooooo`;o00008Oooool001cooooo00?o0000ooooooooool0??ooool2
o`0000oooooo0_l00004ooooo`;o000000?oooooo`000?l000002?ooool2o`0000cooooo0ol00000
0ooooooo0000o`000004ooooo`;o00002_ooool3o`0001Cooooo1?l00002ooooo`Ko00001Oooool2
o`0000;ooooo0_l0000Dooooo`;o00002_ooool2o`0000Gooooo0_l0000@ooooo`;o00002Oooool5
o`0000Gooooo0_l00002ooooo`;o00001Oooool3o`0000;ooooo0_l0000gooooo`007?ooool2o`00
03Sooooo0_l00003ooooo`;o00001?ooool2o`0000Kooooo0_l000000ooooooo0000o`00000Boooo
o`;o00002oooool2o`0000;ooooo0_l00004ooooo`?o00001?ooool2o`0000?ooooo0_l00008oooo
o`Co00001Oooool2o`0000;ooooo1?l00002ooooo`Ko00002Oooool2o`000003ooooool0003o0000
017ooooo0_l00008ooooo`Co00000oooool4o`0000Sooooo0_l000001?oooooo0000o`000?ooool4
o`0000Wooooo0_l0000Cooooo`;o00000_ooool3o`0003Oooooo000Looooo`03o`000?oooooooooo
03Oooooo0_l00009ooooo`;o00000oooool5o`000003ooooool0003o000000?ooooo0_l0000=oooo
o`;o00002?ooool2o`0000Wooooo0_l000001?oooooo0000o`000?l00003ooooo`;o00001Oooool2
o`0000Kooooo1?l00005ooooo`;o00002oooool3o`0000cooooo0_l000001?oooooo0000o`000?l0
0004ooooo`;o00000oooool2o`0000cooooo0_l000000ooooooo0000o`000002ooooo`Co00002?oo
ool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000_ooooo1?l0000<ooooo`;o0000
0oooool2o`0003Sooooo000Looooo`03o`000?oooooooooo02gooooo0_l00004ooooo`;o00000ooo
ool2o`0000gooooo1_l00003ooooo`Co00005oooool2o`0000Wooooo1_l00009ooooo`?o00001ooo
ool2o`0000oooooo0_l00003ooooo`?o00003?ooool5o`0000?ooooo0ol000000ooooooo0000o`00
0002o`000003ooooool0003o000000Wooooo0_l000000ooooooo0000o`00000@ooooo`Go00000ooo
ool2o`0000_ooooo1?l00002ooooo`;o00001_ooool4o`0000oooooo0_l0000/ooooo`007?ooool0
0ol0003oooooooooo`0]ooooo`?o00000oooool2o`0000?ooooo0ol0000@ooooo`;o00000oooool8
o`0001Cooooo0_l00002ooooo`;o00001Oooool3o`0000Kooooo0_l00002ooooo`?o00002?ooool2
o`0000Sooooo0_l00005ooooo`;o00000oooool3o`0000cooooo0_l000000ooooooo0000o`000002
o`000003ooooool0003o000000;ooooo0_l00003ooooo`;o00002oooool2o`000003ooooool0003o
000000gooooo1_l00004ooooo`;o00004?ooool2o`0000Kooooo0_l000000ooooooo0000o`00000<
ooooo`Co0000;?ooool001cooooo00?o0000ooooooooool0;_ooool2o`0000Wooooo0_l00005oooo
o`;o00004?ooool6o`0000;ooooo0_l00009ooooo`?o00001?ooool2o`0000;ooooo0_l0000>oooo
o`;o00000_ooool2o`000003ooooool0003o0000013ooooo0_l00002ooooo`;o00003oooool3o`00
00;ooooo0_l00002ooooo`Ko00005Oooool2o`000003ooooool0003o000000Gooooo0_l00004oooo
o`Co000000?oooooo`000?l000001Oooool2o`0001;ooooo0_l00004ooooo`;o000000?oooooo`00
0?l000001Oooool2o`0000Gooooo0_l0000^ooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o
00001Oooool2o`0000[ooooo0_l0000Hooooo`;o00001oooool5o`0000Cooooo0_l0000Booooo`?o
000000?oooooo`000?l000001Ol00006ooooo`;o00002_ooool2o`0000oooooo0ol00002ooooo`Co
00001?ooool2o`0000Wooooo1Ol0000;ooooo`;o000000Coooooo`000?l0003ooooo0_l00004oooo
o`;o00005oooool2o`0000Cooooo0ol00004ooooo`;o00002?ooool2o`0003Gooooo000Looooo`03
o`000?oooooooooo02gooooo0_l00005ooooo`;o00006Oooool2o`0001;ooooo1?l0000@ooooo`Co
00001_ooool2o`0000;ooooo0ol000000ooooooo0000o`000006ooooo`;o00007Oooool2o`0000?o
oooo1?l00004ooooo`;o00001Oooool7o`0000_ooooo1Ol00003ooooo`;o00004_ooool2o`000003
ooooool0003o000000Cooooo0_l00004ooooo`Co00003?ooool2o`0003Kooooo000Looooo`03o`00
0?oooooooooo04Oooooo0_l00006ooooo`Co00000oooool6o`000004ooooool0003o0000o`0001;o
oooo2Ol00004ooooo`Co00000_ooool2o`00023ooooo0_l00007ooooo`;o000000?oooooo`000?l0
00000_ooool2o`0000Cooooo0_l00005ooooo`;o00004_ooool2o`0000Cooooo0_l00002ooooo`;o
00003_ooool2o`000005ooooool0003o0000o`000?ooool00_l00008ooooo`;o00000_ooool2o`00
00Sooooo0_l00004ooooo`;o0000<?ooool001cooooo00?o0000ooooooooool0=Oooool2o`00013o
oooo0_l00008ooooo`;o00000oooool6o`000004ooooool0003o0000o`0000Oooooo0_l000001?oo
oooo0000o`000?l00005ooooo`Go000000?oooooo`000?l000000_ooool2o`000003ooooool0003o
000000;o00009?ooool2o`0000[ooooo0_l00007ooooo`;o00001_ooool4o`0000Sooooo0_l00002
ooooo`;o00002oooool4o`00017ooooo1Ol0000<ooooo`;o00000oooool2o`0000Wooooo0_l0000`
ooooo`007?ooool00ol0003oooooooooo`0eooooo`;o00000oooool2o`0000Cooooo1?l0000<oooo
o`Ko000000?oooooo`000?l000003_ooool2o`000004ooooool0003o0000o`0000Gooooo0_l00002
ooooo`Co00000_ooool2o`00017ooooo0_l0000[ooooo`;o00000oooool2o`000003ooooool0003o
000000?o00001oooool2o`0000;ooooo0_l00009ooooo`Ko00004Oooool4o`0001;ooooo0_l0000;
ooooo`;o0000;_ooool001cooooo00?o0000ooooooooool0>_ooool2o`0000Cooooo1?l0000<oooo
o`Wo00001Oooool2o`0001Kooooo1?l00007ooooo`;o00001Oooool2o`0000Gooooo0_l00005oooo
o`;o0000:Oooool3o`0000?ooooo0_l0000>ooooo`;o00001_ooool2o`0000Cooooo0_l0000?oooo
o`;o000000?oooooo`000?l000001_ooool2o`0000Oooooo0_l000000ooooooo0000o`00000:oooo
o`Co0000;?ooool001cooooo00?o0000ooooooooool0EOooool3o`0000Kooooo0_l0000Hooooo`;o
00001oooool2o`0000Gooooo1?l00003ooooo`;o00001Oooool3o`0000oooooo1_l00009ooooo`;o
00002Oooool2o`0001?ooooo0_l0000<ooooo`;o00000oooool2o`0000gooooo0_l000000ooooooo
0000o`000003ooooo`;o00001oooool2o`000003ooooool0003o000000cooooo0_l0000/ooooo`00
7?ooool00ol0003oooooooooo`0[ooooo`;o00009?ooool2o`0000_ooooo0_l00002ooooo`;o0000
00?oooooo`000?l000001Oooool2o`0000?ooooo1?l0000Cooooo`Go00000_ooool2o`0000Kooooo
0_l0000?ooooo`So00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`00000=ooooo`;o0000
1?ooool2o`0001Wooooo0_l00006ooooo`;o00000oooool2o`0000?ooooo0_l00003ooooo`;o0000
0_ooool2o`0001;ooooo0_l0000^ooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o00003?oo
ool2o`0000Kooooo0ol0000=ooooo`;o00002oooool2o`0000;ooooo0_l000000ooooooo0000o`00
0003ooooo`Co00000oooool4o`000004ooooool0003o0000o`0000oooooo0_l000000ooooooo0000
o`000002ooooo`?o00003_ooool2o`0000Oooooo0_l00003ooooo`;o00000_ooool5o`0000?ooooo
1?l00002ooooo`Co00001Oooool2o`0000Cooooo1?l0000Jooooo`;o00000oooool2o`0000?ooooo
0_l00008ooooo`;o00000_ooool2o`0001;ooooo0_l0000^ooooo`007?ooool00ol0003ooooooooo
o`0booooo`;o00001Oooool2o`0000Kooooo0ol0000Fooooo`Co000000Coooooo`000?l0003o0000
0oooool2o`0000?ooooo0_l00006ooooo`Oo00000_ooool5o`0000?ooooo0_l00002ooooo`;o0000
00?oooooo`000?l000000oooool3o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l0
00001Oooool2o`0000Oooooo0_l00007ooooo`Go00001Oooool2o`0000;ooooo1Ol000000ooooooo
0000o`000002o`0000Oooooo0ol00003ooooo`Co00004_ooool2o`0000_ooooo0_l0000Hooooo`;o
0000<oooool001cooooo00?o0000ooooooooool0<_ooool2o`0000Gooooo0_l00004ooooo`;o0000
6Oooool8o`0000oooooo1Ol00005ooooo`Go00000oooool6o`000003ooooool0003o000000;o0000
1Oooool2o`000004ooooool0003o0000ooooo`?o00001?ooool2o`0000?ooooo0_l0000;ooooo`;o
00003oooool;o`0000;ooooo3Ol0000Mooooo`;o00006?ooool2o`0003?ooooo000Looooo`;o0000
;_ooool4o`0000Wooooo0_l000000ooooooo0000o`000003o`0001cooooo0_l0000Aooooo`;o0000
2_ooool3o`0000;ooooo1_l00003ooooo`?o00001_ooool2o`000004ooooool0003o0000ooooo`;o
00001?ooool2o`0000?ooooo0_l0000Aooooo`;o00001?ooool2o`000003ooooool0003o000000co
000000?oooooo`000?l000001ol00002ooooo`Co0000?Oooool2o`0002_ooooo000Looooo`03o`00
0?oooooooooo02gooooo1?l00006ooooo`;o000000Coooooo`000?l0003ooooo1Ol0000>ooooo`;o
00002Oooool2o`0001;ooooo0_l0000;ooooo`;o00001?ooool7o`000003ooooool0003o000000So
oooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000?ooooo0_l00007ooooo`;o
00002oooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool@o`0000?ooooo0_l00004oooo
o`;o00009Oooool2o`0001Kooooo0_l0000[ooooo`007?ooool00ol0003oooooooooo`0_ooooo`;o
00001?ooool4o`0000Gooooo1?l0000>ooooo`;o00001oooool4o`0000Oooooo0_l00009ooooo`;o
00002Oooool4o`0000Oooooo1?l000000ooooooo0000o`000002ooooo`So000000?oooooo`000?l0
00000ol000000ooooooo0000o`000003ooooo`;o00001oooool2o`000003ooooool0003o000000Oo
oooo0_l00005ooooo`;o00000_oooolEo`000003ooooool0003o000000;o000000?oooooo`000?l0
00009Oooool2o`0004?ooooo000Looooo`03o`000?oooooooooo02oooooo0_l00004ooooo`Co0000
8?ooool2o`0000Gooooo0_l00002ooooo`;o00001_ooool2o`0000cooooo1_l00002ooooo`Wo0000
00?oooooo`000?l000002?l000000ooooooo0000o`000004ooooo`;o00002?ooool2o`0000;ooooo
0_l000000ooooooo0000o`000007ooooo`?o00001_ooool:o`000003ooooool0003o000000oo0000
00?oooooo`000?l000004Oooool2o`0005Oooooo000Looooo`03o`000?oooooooooo03Kooooo0ol0
0003ooooo`;o00005?ooool2o`0000Wooooo0_l000000ooooooo0000o`000002ooooo`;o00001_oo
ool2o`000003ooooool0003o000000[ooooo1_l000000ooooooo0000o`00000?o`0000;ooooo0_l0
000@ooooo`;o00001oooool5o`0000?ooooo0_l00004oooooago000000?oooooo`000?l000003Ooo
ool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`0000Cooooo0_l00005ooooo`;o0000
4Oooool2o`0000Gooooo0_l0000Zooooo`007?ooool00ol0003oooooooooo`0^ooooo`;o00001_oo
ool3o`0000?ooooo0_l0000Dooooo`;o00002Oooool2o`0000;ooooo0_l0000;ooooo`?o00002ooo
ool2o`000003ooooool0003o000001So00000oooool2o`0000?ooooo1Ol000000ooooooo0000o`00
0005ooooo`Oo00002?oooolMo`0000;ooooo0_l00006ooooo`;o00001Oooool3o`0000Gooooo1Ol0
0004ooooo`;o00001Oooool2o`00017ooooo0_l000000ooooooo0000o`000002ooooo`;o0000:_oo
ool001cooooo00?o0000ooooooooool0;_ooool2o`0000Gooooo0_l00002ooooo`;o00008_ooool3
o`000004ooooool0003o0000ooooo`;o00002?ooool4o`0000_ooooo2_l000000ooooooo0000o`00
000@o`0000;ooooo3?l00006ooooo`Co00002_ooool@o`000003ooooool0003o000000go00002?oo
ool4o`0000Cooooo0_l00007ooooo`;o00001?ooool2o`00017ooooo0_l00009ooooo`;o0000;_oo
ool001cooooo00?o0000ooooooooool0=Oooool2o`0000;ooooo0_l00004ooooo`Co00003?ooool2
o`0000Kooooo0_l00004ooooo`?o00001?ooool2o`0000;ooooo0ol00005ooooo`;o000000?ooooo
o`000?l000002?oooolMo`0000;ooooo2Ol000000ooooooo0000o`000008ooooo`;o00002OoooolQ
o`0000?ooooo0_l00005ooooo`;o00000oooool2o`0000Oooooo0ol00004ooooo`;o00003?ooool2
o`0000?ooooo0_l0000iooooo`007?ooool00ol0003oooooooooo`0eooooo`;o00002?ooool4o`00
00[ooooo1?l00006ooooo`;o00000_ooool4o`0000;ooooo0_l00003ooooo`Go00002?ooool2o`00
00Sooooo0_l000000ooooooo0000o`00000Jo`000003ooooool0003o000000Ko000000?oooooo`00
0?l000001oooool2o`0000Wooooo9ol00002ooooo`Ko00000_ooool3o`0000;ooooo0_l00002oooo
o`?o00000oooool2o`0000Gooooo0_l00006ooooo`;o00003_ooool2o`0002kooooo000Looooo`03
o`000?oooooooooo03_ooooo0_l000000ooooooo0000o`000003o`0000[ooooo0_l00007ooooo`;o
00000oooool3o`0000?ooooo0_l00003ooooo`?o00001Oooool2o`0000;ooooo0ol000001?oooooo
0000o`000?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000Jo`000003ooooool0003o0000
00?o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00000oooool2o`0000Wooooo9_l00003
ooooo`Ko00000_ooool3o`0000;ooooo1_l00004ooooo`Co00000oooool2o`0001Kooooo0_l0000^
ooooo`007?ooool00ol0003oooooooooo`0`ooooo`;o00000oooool2o`0000Cooooo2?l0000Aoooo
o`Co000000Coooooo`000?l0003ooooo0_l00009ooooo`;o00000_ooool2o`000003ooooool0003o
000000;ooooo0ol000001?oooooo0000o`000?ooool4o`0000;ooooo3ol000000ooooooo0000o`00
000Do`0000;ooooo0_l000001?oooooo0000o`000?l0000:ooooo`Go000000?oooooo`000?l00000
2?l000000ooooooo0000o`00000Bo`0000;ooooo0_l000000ooooooo0000o`00000>ooooo`Co0000
1oooool2o`0000Gooooo0_l0000=ooooo`;o00001Oooool2o`0002kooooo000Looooo`03o`000?oo
oooooooo033ooooo0_l00003ooooo`;o00001Oooool2o`0001Kooooo0ol00002ooooo`;o00004?oo
ool2o`0000Kooooo0_l000001?oooooo0000o`000?oooolZo`000004ooooool0003o0000ooooo`;o
000000Coooooo`000?l0003o00001oooool2o`000003ooooool0003o000002Co000000Coooooo`00
0?l0003ooooo0ol0000:ooooo`Oo00003_ooool2o`0000gooooo0_l0000eooooo`007?ooool00ol0
003oooooooooo`13ooooo`Co00000_ooool2o`0000Gooooo0ol00002ooooo`;o00002Oooool2o`00
00Kooooo0_l00009ooooo`;o000000Coooooo`000?l0003ooooo9_l000000ooooooo0000o`000007
o`0000?ooooo1?l00002ooooo`Co000000?oooooo`000?l000009_l000000ooooooo0000o`000002
o`0000[ooooo1?l00004ooooo`;o00001?ooool2o`0000?ooooo0_l00008ooooo`;o0000??ooool0
01cooooo00?o0000ooooooooool0<oooool3o`0000gooooo1?l00002ooooo`;o000000?oooooo`00
0?l000000_ooool3o`0000?ooooo0_l00008ooooo`;o00000_ooool2o`0000;ooooo0_l0000<oooo
obSo00000_ooool9o`0000?ooooo1?l00002ooooo`;o00000ooooolXo`000003ooooool0003o0000
00;o00004_ooool2o`0000Cooooo0ol00002ooooo`Co00001_ooool2o`0003cooooo00001_oooooo
k^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_oo
ool00ol0003oooooooooo`0]ooooo`;o000000?oooooo`000?l000001_l00007ooooo`;o00002ooo
ool2o`0000Cooooo0_l000001?oooooo0000o`000?l00003ooooo`;o00000oooool2o`0000;ooooo
0_l00005ooooo`;o000000Coooooo`000?l0003o00001OoooolVo`000004ooooool0003o0000oooo
o`Go00000_ooool2o`0000_ooooo0_l000000ooooooo0000o`000005ooooo`;o00000_oooolRo`00
00;ooooo0_l000001?oooooo0000o`000?ooool2o`0000Sooooo0_l00005ooooo`Co00000_ooool2
o`0004Cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0]ooooo`;o000000?oooooo`000?l00000
0_l000001?oooooo0000o`000?l00004ooooo`;o000000?oooooo`000?l000004Oooool5o`0000;o
oooo1?l00003ooooo`;o00001Oooool2o`0000;ooooo0_l000001?oooooo0000o`000?l00006oooo
o`;o00000_oooolTo`000003ooooool0003o000000Sooooo0_l000001?oooooo0000o`000?ooool3
o`000004ooooool0003o0000ooooo`;o00001OoooolGo`000003ooooool0003o000000So000000?o
ooooo`000?l000000oooool5o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o000000?o
ooooo`000?l000001?ooool2o`0004Sooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooo
oooo00Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo03Gooooo0_l0
0005ooooo`;o000000?oooooo`000?l000000_ooool2o`0000kooooo0_l00004ooooo`;o00000_oo
ool2o`000003ooooool0003o000000Gooooo0_l000000ooooooo0000o`000009ooooo`Go000000?o
ooooo`000?l000001?l00002ooooo`Wo000000?oooooo`000?l000004?l00003ooooo`Go00000ooo
ool2o`000004ooooool0003o0000ooooo`?o000000?oooooo`000?l000001_oooolQo`000004oooo
ool0003o0000ooooo`;o00001?ooool3o`0000Cooooo1?l00004ooooo`;o000000?oooooo`000?l0
00000oooool2o`0004Wooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo
00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000<Oooool2o`0000Kooooo0_l00003ooooo`;o
00000_ooool3o`0000[ooooo0_l0000<ooooo`;o00002Oooool4o`0000Kooooo1Ol000001?oooooo
0000o`000?ooool6o`000003ooooool0003o000001_o000000?oooooo`000?l000002_l000001?oo
oooo0000o`000?ooool3o`0000Wooooo0_l000000ooooooo0000o`00000Oo`0000Oooooo0_l00005
ooooo`;o00003_ooool2o`0000Sooooo0_l0000oooooo`0000?oooooo`000?ooool00_ooool00ol0
003oooooooooo`09ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0a
ooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo0_l00002ooooo`?o00002_ooool2
o`0000Cooooo0_l00006ooooo`;o00002Oooool4o`0000Kooooo1Ol000000ooooooo0000o`00000`
o`0000?ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00002?ooool3o`000003ooooool0
003o000000Co000000?oooooo`000?l000004ol0000Gooooo`;o00002?ooool2o`0000Gooooo1?l0
000oooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`03oeEEEOn7QhOo
oooo00Sooooo00?o0000ooooooooool0=?ooool2o`0000?ooooo0_l0000@ooooo`;o00002?ooool2
o`0000[ooooo0_l00007ooooo`;o00002?ooool2o`0000;ooooo<Ol00007ooooo`;o00000_ooool3
o`0000Oooooo2_l000000ooooooo0000o`00000@o`000004ooooool0003o0000o`0001Kooooo0_l0
00000ooooooo0000o`000003o`0000;ooooo0ol000001?oooooo0000o`000?ooool3o`00043ooooo
00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003o
ooooooooo`0`ooooo`;o00001oooool2o`000003ooooool0003o000000?ooooo0_l00005ooooo`;o
000000?oooooo`000?l000005?ooool2o`0001;ooooo0_l000000ooooooo0000o`00000So`0000;o
oooo3?l000000ooooooo0000o`000002ooooo`;o00000_ooool3o`0000Sooooo7?l000001?oooooo
0000o`000?l00004ooooo`?o00004_ooool5o`0000?ooooo0_l000000ooooooo0000o`000002oooo
o`;o0000@?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@
4106ooooo`03o`000?oooooooooo033ooooo0_l00006ooooo`;o000000Coooooo`000?l0003o0000
0oooool2o`0000Gooooo0_l00009ooooo`;o00003_ooool2o`00013ooooo<?l000001?oooooo0000
o`000?ooool2o`000004ooooool0003o0000ooooo`?o00000_ooool3o`0000Sooooo1ol000000ooo
oooo0000o`00000;o`0000;ooooo2?l00005ooooo`?o000000?oooooo`000?l00000H?ooool001co
oooo00?o0000ooooooooool0>?ooool2o`000003ooooool0003o000001Kooooo0ol00002ooooo`;o
00001?ooool2o`0000?ooooo0_l00004ooooo`;o00001_ooool2o`0000;ooooo;?l00005ooooo`;o
00001oooool3o`0000?ooooo0_l00008ooooo`Wo00000oooool9o`000003ooooool0003o000000Ko
00002_ooool2o`000003ooooool0003o000000Gooooo0_l0001Fooooo`007?ooool00ol0003ooooo
ooooo`0hooooo`;o00006_ooool2o`0000;ooooo0_l00004ooooo`;o00001_ooool2o`000003oooo
ool0003o000000Kooooo0_l00002ooooo`?o00000ooooolBo`0000?ooooo5?l00002ooooo`;o0000
1Oooool4o`0000Oooooo0_l00006ooooo`Go000000Coooooo`000?l0003o00000oooool;o`0000;o
oooo0ol00002ooooo`;o00002_ooool3o`000004ooooool0003o0000ooooo`;o00004Oooool2o`00
00Wooooo0_l0000hooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00006?ooool2o`0001;o
oooo0_l0000;ooooo`;o00001Oooool=o`0000;ooooo1Ol000001Ooooooo0000o`000?l0003ooooo
017o00000oooool2o`0000Cooooo2?l00003ooooo`;o00001oooool4o`0000;ooooo0_l00003oooo
o`[o00001oooool3o`0000_ooooo0_l000000ooooooo0000o`00000Dooooo`;o00001oooool4o`00
03Sooooo000Looooo`03o`000?oooooooooo04Sooooo0_l00008ooooo`;o00003_ooool2o`0000Go
oooo0_l00004ooooo`;o00000_ooool2o`000003ooooool0003o000000ko000000?oooooo`000?l0
00004_l000000ooooooo0000o`000002o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`00
00Gooooo1?l00009ooooo`;o00000_ooool2o`0000Wooooo1Ol00006ooooo`;o00000oooool2o`00
00;ooooo0_l0000Fooooo`;o00004_ooool2o`0003[ooooo000Looooo`03o`000?oooooooooo04Oo
oooo0ol0000Cooooo`;o00000oooool2o`0000Gooooo0_l00004ooooo`;o000000?oooooo`000?l0
00001_l000000ooooooo0000o`00000@o`000003ooooool0003o000000oo000000?oooooo`000?l0
00000_ooool2o`0000;ooooo1?l00002ooooo`;o00003_ooool2o`0000;ooooo0_l00005ooooo`;o
00001Oooool2o`0000Gooooo1Ol00004ooooo`Go00002?ooool2o`0000Oooooo0_l000000ooooooo
0000o`000003ooooo`;o00001oooool2o`00043ooooo000Looooo`03o`000?oooooooooo03Oooooo
0ol0000=ooooo`;o000000Coooooo`000?l0003o00004?ooool2o`0000?ooooo0_l00002ooooo`;o
00002_oooolCo`000003ooooool0003o000001ko00000_ooool2o`0000;ooooo1?l00007ooooo`;o
00001?ooool2o`0000[ooooo0_l00005ooooo`Co00000oooool2o`000003ooooool0003o000000Co
oooo0_l000000ooooooo0000o`000008ooooo`;o00001?ooool2o`000003ooooool0003o000000Ko
oooo0_l00002ooooo`Co000000?oooooo`000?l000000oooool4o`0003Wooooo000Looooo`03o`00
0?oooooooooo03Kooooo1?l00005ooooo`;o00002Oooool3o`00017ooooo0_l00002ooooo`;o0000
0_ooool2o`0000cooooo1ol00003ooooo`Oo000000?oooooo`000?l000005Ol000001Ooooooo0000
o`000?l0003ooooo00Co000000?oooooo`000?l000000oooool2o`0000Wooooo0_l00004ooooo`;o
00004_ooool3o`0000?ooooo0_l00002ooooo`;o00001oooool2o`0000gooooo0_l00004ooooo`Co
00001Oooool4o`0000Kooooo1?l0000iooooo`007?ooool00ol0003oooooooooo`0fooooo`Co0000
1Oooool2o`0000Wooooo0_l000000ooooooo0000o`000009ooooo`;o00001?ooool2o`0000Gooooo
0_l0000=ooooo`Co000000?oooooo`000?l000000ooooolWo`0000;ooooo0_l00003ooooo`;o0000
7?ooool2o`0000?ooooo0_l0000:ooooo`Co00001?ooool3o`0000Wooooo0_l00008ooooo`Co0000
4?ooool2o`0003[ooooo000Looooo`03o`000?oooooooooo03Kooooo0ol0000@ooooo`?o000000?o
ooooo`000?l000002Oooool2o`0000_ooooo1Ol00006ooooo`;o00000oooool2o`000003ooooool0
003o000000;o000000?oooooo`000?l000007Ol000000ooooooo0000o`000006o`0000Oooooo0_l0
0003ooooo`;o00002oooool2o`000003ooooool0003o000000Oooooo0_l00003ooooo`;o00003?oo
ool2o`0000Cooooo0_l00008ooooo`Co00001_ooool3o`0000kooooo0_l0000oooooo`007?ooool0
0ol0003oooooooooo`0fooooo`?o00002_ooool2o`0000;ooooo1Ol00009ooooo`;o00004?ooool3
o`0000;ooooo0_l00002ooooo`;o00001Oooool5o`000003ooooool0003o000001_o00000oooool3
o`0000;ooooo0_l0000=ooooo`Co00000oooool2o`0000Cooooo0_l000000ooooooo0000o`000007
ooooo`;o00000oooool2o`0000;ooooo0_l0000Eooooo`;o000000?oooooo`000?l000001oooool4
o`0000?ooooo0_l00009ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0@oooool2o`00
00;ooooo0_l000000ooooooo0000o`000009ooooo`;o00002oooool4o`0000Kooooo0_l00007oooo
o`Co00000oooool4o`000003ooooool0003o000001Oo00000_ooool4o`0000;ooooo0_l00002oooo
o`;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o00005?ooool7o`00
01;ooooo0_l000000ooooooo0000o`000002o`0000Kooooo1?l00005ooooo`;o00002oooool2o`00
03gooooo000Looooo`;o0000A?ooool2o`0000Oooooo0_l0000Dooooo`Co000000?oooooo`000?l0
00002?ooool:o`000003ooooool0003o000000;o000000?oooooo`000?l000007?l00004ooooo`;o
000000?oooooo`000?l000001?ooool7o`0000Wooooo0_l0000@ooooo`;o000000?oooooo`000?l0
00001_ooool2o`0000Oooooo0_l00003ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`;o
00001oooool2o`0000Sooooo0_l000000ooooooo0000o`00000mooooo`007?ooool00ol0003ooooo
ooooo`0dooooo`;o00003Oooool2o`0000Oooooo0_l00003ooooo`?o00004oooool2o`000003oooo
ool0003o000000Gooooo1?l000001?oooooo0000o`000?ooool4o`000003ooooool0003o000001Co
000000?oooooo`000?l000000_l000000ooooooo0000o`000004o`0000?ooooo0_l00009ooooo`;o
000000?oooooo`000?l000002Oooool2o`0000_ooooo0_l00004ooooo`;o000000?oooooo`000?l0
00001Oooool2o`0000?ooooo0_l00002ooooo`;o00000oooool3o`0000Kooooo0_l00006ooooo`;o
00002?ooool2o`0000?ooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`0dooooo`;o0000
6oooool3o`0000oooooo0_l00003ooooo`Oo000000?oooooo`000?l000002Oooool2o`0000;ooooo
5ol000000ooooooo0000o`000007o`0000Oooooo0_l00006ooooo`;o00000oooool4o`00017ooooo
0_l00004ooooo`;o000000?oooooo`000?l000002_ooool2o`0000Kooooo1?l00007ooooo`;o0000
1Oooool2o`000003ooooool0003o000000Gooooo0_l00015ooooo`007?ooool00ol0003ooooooooo
o`0`ooooo`;o0000:oooool2o`0000Cooooo0_l00003ooooo`;o00000_ooool7o`0000[ooooo3_l0
00000ooooooo0000o`000008o`000003ooooool0003o000000Co00002_ooool2o`0000Kooooo0_l0
0003ooooo`Co00005?ooool2o`0000kooooo0_l00004ooooo`;o00000_ooool2o`0000;ooooo0_l0
0005ooooo`;o000000?oooooo`000?l000001Oooool2o`0004cooooo000Looooo`03o`000?oooooo
oooo033ooooo0_l0000[ooooo`?o00003?ooool7o`0000[ooooo6?l000000ooooooo0000o`000002
o`000003ooooool0003o0000027ooooo0_l0000;ooooo`Go00003?ooool2o`0000Cooooo0_l00002
ooooo`;o00000_ooool2o`0000?ooooo0_l00003ooooo`;o00000_ooool2o`0004oooooo000Loooo
o`03o`000?oooooooooo03gooooo0_l00008ooooo`;o00005Oooool2o`0000_ooooo1Ol000001?oo
oooo0000o`000?ooool6o`0000?ooooo1ol00003oooooa?o000000?oooooo`000?l000002Oooool2
o`0001Kooooo0_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000000_l00000
0ooooooo0000o`000005ooooo`;o00002oooool4o`0000Sooooo0ol00002ooooo`;o00000oooool2
o`0000Oooooo0_l00002ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0?Oooool4o`00
00Kooooo0ol000000ooooooo0000o`00000Booooo`;o00002_ooool2o`0000Cooooo0_l000000ooo
oooo0000o`00000;o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o000000?oooooo`00
0?l000001_l00005ooooo`;o00002?ooool3o`0000;ooooo0_l0000Eooooo`;o00000oooool2o`00
0003ooooool0003o000000Gooooo0_l00003ooooo`;o00000_ooool3o`0000Kooooo1?l00003oooo
o`;o00000_ooool4o`0000;ooooo0_l00003ooooo`;o00001oooool2o`0000;ooooo0_l00012oooo
o`007?ooool00ol0003oooooooooo`0fooooo`;o00001oooool2o`0000Oooooo0_l000000ooooooo
0000o`00000Booooo`;o000000?oooooo`000?l000000_ooool2o`0000Wooooo0_l000000ooooooo
0000o`000004ooooo`Ko00000oooool3o`000005ooooool0003o0000o`000?ooool02ol0000>oooo
o`Go000000?oooooo`000?l000008?ooool2o`0000;ooooo0_l00004ooooo`;o000000Goooooo`00
0?l0003o0000ooooo`02o`0000[ooooo0_l00002ooooo`;o0000F_ooool001cooooo00?o0000oooo
ooooool0=_ooool2o`00013ooooo0_l0000Hooooo`;o00000_ooool2o`0000Wooooo0_l000000ooo
oooo0000o`000005ooooo`;o000000?oooooo`000?l000000oooool3o`000005ooooool0003o0000
o`000?ooool01_l00005ooooo`;o00001Oooool2o`0000Gooooo0_l000000ooooooo0000o`000002
ooooo`;o00000oooool2o`0000Cooooo0_l0000Dooooo`;o00000_ooool2o`0000Cooooo0_l00002
ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Kooooo0_l0000:ooooo`;o000000?ooooo
o`000?l00000Coooool001cooooo00?o0000ooooooooool0A_ooool2o`0001cooooo0_l0000>oooo
o`Co00000oooool2o`0000[ooooo0_l00002ooooo`Go00001_ooool2o`0000Gooooo0_l00002oooo
o`?o00000oooool2o`0000;ooooo0_l00003ooooo`;o00001?ooool2o`0001Sooooo0_l00008oooo
o`;o00000oooool4o`0000Gooooo1Ol00004ooooo`;o000000Goooooo`000?l0003o0000ooooo`02
o`0004oooooo000Looooo`03o`000?oooooooooo04Cooooo1_l0000Aooooo`;o00001oooool2o`00
00;ooooo0_l00004ooooo`;o00001_ooool2o`0000kooooo0_l000000ooooooo0000o`000005o`00
0003ooooool0003o000000Oooooo0_l00003ooooo`Go00000oooool2o`000003ooooool0003o0000
00?ooooo0_l0000^ooooo`?o00001_ooool5o`0000Cooooo0_l000000ooooooo0000o`000005oooo
o`;o0000C?ooool001cooooo00?o0000ooooooooool0A?ooool3o`000003ooooool0003o000000[o
oooo0_l00005ooooo`;o00001Oooool4o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l0
00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`Co00000_ooool2o`000004
ooooool0003o0000ooooo`Oo00001oooool2o`0000?ooooo1_l000000ooooooo0000o`000002oooo
o`;o00000_ooool3o`0000Wooooo0_l0000Iooooo`;o00000_ooool2o`0000oooooo0_l00009oooo
o`;o00001?ooool2o`0004cooooo000Looooo`03o`000?oooooooooo04Kooooo1?l0000:ooooo`?o
00002oooool3o`0000cooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000;o
oooo1?l00004ooooo`;o00001Oooool2o`0000;ooooo0_l00005ooooo`;o00001oooool2o`000003
ooooool0003o000000Kooooo0_l00007ooooo`;o000000?oooooo`000?l000006Oooool2o`0000;o
oooo0_l00003ooooo`;o00002_ooool2o`0000Wooooo0_l00005ooooo`;o0000Boooool001cooooo
00?o0000ooooooooool0A_ooool4o`0000;ooooo0_l00006ooooo`?o00001oooool2o`0000;ooooo
0ol0000Aooooo`;o00000oooool4o`0000Wooooo0_l00005ooooo`;o00000_ooool2o`0000Oooooo
0_l00004ooooo`;o00001oooool2o`000003ooooool0003o000000Oooooo0_l0000Uooooo`;o0000
4Oooool2o`0000Wooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`15ooooo`;o00000ooo
ool4o`0000Kooooo0_l00008ooooo`?o000000?oooooo`000?l000004_ooool2o`0000?ooooo1?l0
0008ooooo`;o00001Oooool2o`0000Kooooo0_l00004ooooo`;o00001?ooool2o`0000Oooooo0_l0
00000ooooooo0000o`00000@ooooo`;o00007?ooool2o`0000cooooo0_l00003ooooo`;o0000E_oo
ool001cooooo00?o0000ooooooooool0AOooool2o`0000?ooooo1?l0000Aooooo`;o00003oooool2
o`0000Wooooo0ol00005ooooo`;o00000_ooool2o`0000Gooooo1?l00004ooooo`;o00001?ooool2
o`0000;ooooo1Ol00004ooooo`;o00000_ooool2o`0000?ooooo0_l00004ooooo`;o00001_ooool2
o`0002[ooooo0_l0001Kooooo`007?ooool2o`0004Oooooo0_l00004ooooo`;o00002oooool2o`00
00Cooooo0_l0000?ooooo`;o000000?oooooo`000?l000001oooool2o`0000Gooooo0_l00005oooo
o`;o00001?ooool2o`0000[ooooo0_l00002ooooo`Go00001?ooool2o`0000;ooooo0_l00002oooo
o`?o00001?ooool2o`0001kooooo1?l00008ooooo`;o00002_ooool2o`0005Oooooo000Looooo`03
o`000?oooooooooo04Kooooo0_l0000Aooooo`;o00001?ooool5o`000003ooooool0003o000000Go
oooo0_l00005ooooo`;o00001oooool4o`0000[ooooo0_l00004ooooo`;o00002Oooool2o`0000;o
oooo0ol00003ooooo`;o00002_ooool2o`0000[ooooo1?l0000Gooooo`Co00002?ooool2o`0000So
oooo1?l0001Gooooo`007?ooool00ol0003oooooooooo`1Mooooo`;o00000_ooool3o`000003oooo
ool0003o000000Gooooo0_l0000<ooooo`Oo00001oooool2o`0000Kooooo0_l00009ooooo`?o0000
00?oooooo`000?l000001?ooool2o`0001Kooooo1?l0000Xooooo`;o00000oooool2o`0005Wooooo
000Looooo`03o`000?oooooooooo05?ooooo0ol00007ooooo`;o00002_ooool2o`000003ooooool0
003o000000cooooo1?l000000ooooooo0000o`000007ooooo`?o00004Oooool7o`0000Oooooo0_l0
000eooooo`Co00001?ooool2o`0000?ooooo0_l0001Iooooo`007?ooool00ol0003oooooooooo`1C
ooooo`?o00004oooool2o`0000?ooooo0_l00003ooooo`;o00005?ooool2o`0001?ooooo1Ol00007
ooooo`;o0000=Oooool4o`0000Gooooo0_l0001Mooooo`007?ooool00ol0003oooooooooo`1Moooo
o`;o00001?ooool2o`0000Wooooo0_l00003ooooo`;o00000_ooool2o`0000Kooooo0_l0000ioooo
o`;o000000?oooooo`000?l000006_ooool2o`0000?ooooo0_l0000:ooooo`;o0000GOooool001co
oooo00?o0000ooooooooool0Eoooool2o`0000Cooooo0_l00004ooooo`Co00001?ooool2o`0000[o
oooo0_l00006ooooo`;o00009Oooool2o`0001;ooooo0_l000000ooooooo0000o`00000Jooooo`;o
00000oooool2o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`0005Oooooo000Looooo`03o`00
0?oooooooooo05Oooooo0_l00004ooooo`;o00000_ooool2o`0000;ooooo0_l00004ooooo`;o0000
3oooool2o`0002Sooooo0_l0000Aooooo`;o00007_ooool2o`0000Wooooo0_l00009ooooo`?o0000
Eoooool001cooooo00?o0000ooooooooool0Eoooool2o`0000Cooooo0_l00002ooooo`;o000000?o
ooooo`000?l000005_ooool4o`0000Gooooo0_l00004ooooo`;o00006oooool2o`0000gooooo1?l0
00000ooooooo0000o`000002ooooo`;o00005oooool2o`0000Gooooo0_l0000:ooooo`;o000000?o
ooooo`000?l00000F?ooool001cooooo00?o0000ooooooooool0G?ooool2o`0000Kooooo0_l0000:
ooooo`;o00003?ooool2o`0000Gooooo0_l00004ooooo`;o00000oooool2o`0000Wooooo0ol00009
ooooo`?o00000oooool2o`0000Sooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l0000N
ooooo`;o00001?ooool3o`0000?ooooo0ol0001Jooooo`007?ooool00ol0003oooooooooo`1Loooo
o`;o00002oooool2o`0000Gooooo0_l0000>ooooo`;o00001_ooool2o`0000Kooooo0_l00009oooo
o`?o00002Oooool2o`0000Cooooo0_l0000;ooooo`;o00009Oooool2o`0000?ooooo0ol00004oooo
o`;o0000F_ooool001cooooo00?o0000ooooooooool0Foooool2o`0000Cooooo0ol00002ooooo`;o
000000?oooooo`000?l000000_l00005ooooo`;o00003?ooool2o`0000Kooooo0_l00009ooooo`;o
00002?ooool2o`0001Kooooo0_l00003ooooo`;o00000_ooool2o`00027ooooo0ol00003ooooo`?o
0000Goooool001cooooo00?o0000ooooooooool0Foooool3o`0000?ooooo0ol00002ooooo`;o0000
0oooool4o`0000?ooooo1?l0000>ooooo`;o00003Oooool2o`0000Sooooo0_l00002ooooo`;o0000
0oooool2o`0000gooooo0_l00003ooooo`;o000000Coooooo`000?l0003o00006?ooool2o`0000So
oooo0_l00002ooooo`Co0000Goooool001cooooo00?o0000ooooooooool0FOooool2o`000003oooo
ool0003o000000cooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l0000>ooooo`;o
00006oooool2o`0000?ooooo0_l0000Booooo`;o000000?oooooo`000?l000003Oooool2o`0000[o
oooo0_l00003ooooo`Co00001Oooool2o`0000Cooooo0_l0001Kooooo`007?ooool00ol0003ooooo
ooooo`1Iooooo`;o00002?ooool2o`0000Gooooo0_l00004ooooo`;o00001?ooool2o`00037ooooo
0_l0000Booooo`;o00003Oooool2o`0000;ooooo0_l00002ooooo`;o00001oooool4o`000003oooo
ool0003o000000Sooooo0_l0001Kooooo`007?ooool00ol0003oooooooooo`1Kooooo`;o00001_oo
ool2o`0000Gooooo0_l00008ooooo`Co00009_ooool2o`000003ooooool0003o000000Kooooo0ol0
0003ooooo`;o00003?ooool2o`00017ooooo0_l000001?oooooo0000o`000?l00003ooooo`;o0000
1oooool4o`0006?ooooo000Looooo`;o0000G?ooool2o`0000Oooooo0ol00006ooooo`;o00000ooo
ool4o`0000Kooooo0_l00004ooooo`;o00006_ooool2o`000003ooooool0003o000000Oooooo0_l0
0003ooooo`;o00005?ooool4o`0000[ooooo0_l00004ooooo`;o00002Oooool2o`0001Gooooo0_l0
001<ooooo`007?ooool00ol0003oooooooooo`1Tooooo`?o000000?oooooo`000?l000000oooool2
o`0000?ooooo0_l00008ooooo`Co00000_ooool2o`0000Kooooo0_l00007ooooo`;o00009_ooool2
o`0000Sooooo1?l00005ooooo`;o00000oooool2o`0000Gooooo0_l000000ooooooo0000o`00000L
ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0G?ooool2o`0000Sooooo1?l00006oooo
o`;o00002oooool4o`0000Kooooo1_l00006ooooo`Co00001?ooool2o`0000kooooo0ol00007oooo
o`;o00001?ooool2o`0000Sooooo0_l00007ooooo`;o00000oooool2o`0000Gooooo0_l000000ooo
oooo0000o`000002ooooo`;o0000I_ooool001cooooo00?o0000ooooooooool0G?ooool2o`0000So
oooo1?l00006ooooo`;o00000_ooool2o`0000Oooooo1?l00006ooooo`?o000000?oooooo`000?l0
00002?ooool2o`0000Cooooo0_l0000>ooooo`?o00001_ooool5o`0000cooooo0_l00006ooooo`;o
00000oooool2o`000003ooooool0003o000000[ooooo0_l0001Vooooo`007?ooool00ol0003ooooo
ooooo`1[ooooo`?o00001_ooool2o`00023ooooo0_l0000Cooooo`;o00000oooool2o`0000;ooooo
0_l000000ooooooo0000o`00000;ooooo`?o00001_ooool2o`0000;ooooo0ol000001?oooooo0000
o`000?ooool5o`0000Kooooo0_l0001Tooooo`007?ooool00ol0003oooooooooo`1Sooooo`;o0000
1_ooool3o`0000_ooooo0ol0000Aooooo`;o00001?ooool5o`0001Gooooo1Ol00003ooooo`;o0000
3?ooool4o`0000[ooooo1?l00002ooooo`Ko00001_ooool2o`0006Cooooo000Looooo`03o`000?oo
oooooooo06?ooooo0_l00002ooooo`;o00000_ooool2o`0000cooooo0ol0000Aooooo`;o00001?oo
ool3o`0000?ooooo1_l0000>ooooo`?o00001Oooool4o`0000[ooooo0_l0000<ooooo`Co00000_oo
ool2o`00073ooooo000Looooo`03o`000?oooooooooo06Oooooo0_l00002ooooo`;o00002Oooool2
o`000003ooooool0003o000000Kooooo0_l00004ooooo`;o00004?ooool6o`0001Sooooo0_l00005
ooooo`Co00003_ooool2o`000003ooooool0003o000000Wooooo0_l0001Yooooo`007?ooool00ol0
003oooooooooo`1Dooooo`;o00005Oooool2o`0000;ooooo1?l00003ooooo`;o00002Oooool2o`00
00Cooooo0_l0000=ooooo`;o000000?oooooo`000?l000001_ooool2o`0001_ooooo1?l0000>oooo
o`;o000000?oooooo`000?l000002Oooool2o`0006Wooooo000Looooo`03o`000?oooooooooo05Co
oooo0_l0000>ooooo`;o00001Oooool2o`0000;ooooo1?l0000Looooo`;o00000_ooool2o`000004
ooooool0003o0000ooooo`;o00000_ooool2o`0000;ooooo0_l00005ooooo`;o00001_ooool2o`00
01Cooooo0_l0000?ooooo`;o000000?oooooo`000?l00000KOooool001cooooo00?o0000oooooooo
ool0I?ooool3o`0000Wooooo0_l00009ooooo`;o00001?ooool4o`000003ooooool0003o000000Oo
oooo1_l00005ooooo`;o000000?oooooo`000?l000002Oooool2o`0000;ooooo0_l00002ooooo`;o
00005?ooool2o`0000cooooo0_l000001?oooooo0000o`000?ooool2o`0006gooooo000Looooo`03
o`000?oooooooooo06Gooooo0_l00009ooooo`;o00002Oooool2o`0000Cooooo1?l000000ooooooo
0000o`000007ooooo`Go00001?ooool4o`00013ooooo0_l0000Fooooo`;o00003_ooool2o`0007?o
oooo000Looooo`03o`000?oooooooooo06kooooo0ol0000;ooooo`;o00004?ooool2o`0000Sooooo
0_l0000>ooooo`Co000000?oooooo`000?l000005Oooool2o`00013ooooo0_l0001aooooo`007?oo
ool00ol0003oooooooooo`1Sooooo`Co00001oooool3o`0000?ooooo0_l00006ooooo`;o00001Ooo
ool2o`0000Wooooo0_l0000Hooooo`Co000000?oooooo`000?l000006_ooool2o`000003ooooool0
003o000000Sooooo0_l0001aooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q
1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0Hoooool4o`0000Wo
oooo1_l00005ooooo`Co00000_ooool4o`0001_ooooo0_l00007ooooo`;o00005_ooool2o`0000Co
oooo1?l000000ooooooo0000o`000007ooooo`;o0000L_ooool00006oooooomgMgOoV9RHoooooonH
V9SoMgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooo
oooo06Wooooo0_l00005ooooo`Oo00000oooool5o`0000;ooooo0_l00009ooooo`;o000000Cooooo
o`000?l0003ooooo0_l000000ooooooo0000o`000005ooooo`;o000000Coooooo`000?l0003o0000
1oooool2o`0001?ooooo0_l000000ooooooo0000o`000004ooooo`;o00000oooool2o`0000Oooooo
0_l0001booooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`1Yooooo`;o00001oooool2o`000004oooo
ool0003o0000o`0000;ooooo0_l000000ooooooo0000o`00000;ooooo`Co000000Coooooo`000?l0
003ooooo0_l000000ooooooo0000o`000002o`0000?ooooo0_l000000ooooooo0000o`00000=oooo
o`;o00000_ooool2o`0000[ooooo0_l0000<ooooo`Oo0000M_ooool00003ooooool0003ooooo00;o
oooo00?o0000ooooooooool02Oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0001foooo
o`;o00000oooool2o`0000gooooo0_l0000;ooooo`;o00001Oooool2o`0000[ooooo0_l00002oooo
o`?o000000?oooooo`000?l000000oooool2o`0000gooooo0_l00005ooooo`Ko0000M_ooool00003
ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Oo<c<co0000o`000?l0003oc<c<
00Kooooo00?o0000ooooooooool0Ioooool2o`000003ooooool0003o000000oooooo0_l0000Doooo
o`?o00002?ooool4o`0000[ooooo0_l00002ooooo`?o00001_ooool2o`0000;ooooo0_l00009oooo
o`;o00001Oooool2o`0007[ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wo
oooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo06Oooooo0_l000000ooo
oooo0000o`00000:ooooo`Co00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`000002oooo
o`?o00001Oooool3o`000003ooooool0003o000000;o00000oooool2o`0000oooooo0ol0000;oooo
o`;o00000oooool2o`0008Oooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000
okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo06Wooooo0_l0000;ooooo`Co00000_oo
ool2o`0000;ooooo1?l000000ooooooo0000o`000002ooooo`?o00002Oooool4o`0000Sooooo0_l0
0009ooooo`?o00003?ooool2o`0000?ooooo0_l00027ooooo`0000Koooooonk^k_lb<S;o0000oc8b
<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`1Rooooo`;o
00001Oooool2o`0000cooooo0_l000001?oooooo0000o`000?l00003ooooo`;o00002oooool2o`00
01;ooooo0_l00009ooooo`;o00000_ooool2o`0009Oooooo000Looooo`03o`000?oooooooooo06;o
oooo0_l0000Fooooo`?o00002Oooool2o`0000Gooooo0_l00003ooooo`;o00000oooool2o`0000_o
oooo0_l0000:ooooo`;o00002?ooool2o`0000;ooooo0_l00002ooooo`;o0000QOooool001cooooo
00?o0000ooooooooool0I?ooool2o`0001Cooooo0_l0000:ooooo`;o00002_ooool2o`000003oooo
ool0003o000000;o00001_ooool2o`0000?ooooo0_l00009ooooo`;o00002Oooool3o`000003oooo
ool0003o000000;ooooo0_l00025ooooo`007?ooool00ol0003oooooooooo`1Tooooo`;o00002?oo
ool2o`0000[ooooo0_l0000Iooooo`?o00001?ooool2o`000003ooooool0003o000000;o00003?oo
ool2o`0000[ooooo0_l0002<ooooo`007?ooool00ol0003oooooooooo`1[ooooo`;o000000?ooooo
o`000?l000002Oooool2o`0000Kooooo0_l0000:ooooo`;o00000oooool2o`0000Cooooo0ol00000
0ooooooo0000o`000002o`000003ooooool0003o000001?ooooo0_l0002Aooooo`007?ooool00ol0
003oooooooooo`1[ooooo`;o00003?ooool2o`0000Kooooo0_l0000:ooooo`;o00000_ooool4o`00
00?ooooo0ol00003ooooo`Co00004_ooool4o`0000[ooooo0ol00024ooooo`007?ooool00ol0003o
ooooooooo`1_ooooo`;o00008?ooool4o`0000Wooooo1?l0000=ooooo`;o00000oooool2o`0000;o
oooo0_l00008ooooo`?o0000Q?ooool001cooooo00?o0000ooooooooool0Koooool2o`0002oooooo
0_l0000;ooooo`Co00000_ooool2o`0000?ooooo1_l0002;ooooo`007?ooool00ol0003ooooooooo
o`2Booooo`Co00004oooool2o`0000;ooooo0_l00004ooooo`;o00001Oooool4o`0002?ooooo0_l0
001Vooooo`007?ooool00ol0003oooooooooo`2Booooo`Co00004Oooool4o`000003ooooool0003o
000003?ooooo0_l0001Vooooo`007?ooool00ol0003oooooooooo`2?ooooo`;o00001_ooool4o`00
00Sooooo0_l00002ooooo`;o00000oooool2o`0009_ooooo000Looooo`03o`000?oooooooooo087o
oooo0_l0000<ooooo`;o00001_ooool4o`0000Sooooo0_l00002ooooo`;o00003?ooool2o`0009;o
oooo000Looooo`;o0000P_ooool2o`0002Cooooo0_l0000:ooooo`Co0000T_ooool001cooooo00?o
0000ooooooooool0/oooool2o`0009Cooooo000Looooo`03o`000?oooooooooo09Gooooo0_l0002b
ooooo`007?ooool00ol0003oooooooooo`2Eooooo`;o0000/_ooool001cooooo00?o0000oooooooo
ool0R_ooool2o`000;gooooo000Looooo`03o`000?oooooooooo08[ooooo0_l0002mooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0Z_ooool2o`0009gooooo000Looooo`03o`000?oooooooooo0:[o
oooo0_l0000=ooooo`;o0000S_ooool001cooooo00?o0000ooooooooool0/_ooool2o`0000Gooooo
0_l0002>ooooo`007?ooool00ol0003oooooooooo`2booooo`;o0000UOooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Yooooo`;o0000W_ooool001co
oooo00?o0000ooooooooool0ZOooool2o`0009kooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo0_l0002Jooooo`;o0000[_ooool001cooooo00?o0000ooooooooool0VOooool2
o`000:kooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?ooooooBoooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`004_oo
ool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom:ooooo`005?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o0000oooo
ooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`00
5?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_oo
ool001Cooooo00?o0000ooooooooool0oooooomBooooo`004_ooool00omEEEGoIVIVo`00003ooooo
oeCooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Qooooo`04oa0@4?l0003o
0000ooooo`;o000000?o410@ooooooooool05_ooool4o`000003oa0@4?oooooooooo00;ooooo0_l0
00002Ol@413oooooooooooooooooc<c<ob4Q8Ol0003o8B4Qolc<c003ooooo`Go0000S?ooool00:;o
oooo00Go0000ooooooooooooooooo`000009ooooo`Ko00003?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@03ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@0S?ooool00:;ooooo00Go0000ooooooooooooooooo`00000Kooooo`03o`000?oo
oooooooo00;ooooo1Ol00003ooooo`05o`000?ooooooooooooooool000001?ooool00onHV9So8B4Q
onk^kP2=ooooo`00X_ooool01Ol0003ooooooooooooooooo000000Wooooo1_l0000<ooooo`03o`00
0?oooooooooo00;ooooo00CoA4A4omgMgOoooooo00001?ooool01Olb<S;oV9RHoooooonHV9So<S8b
00Gooooo00?oV9RHob4Q8Oo^k^h0S?ooool00:;ooooo00Go0000ohN7QoooooooZJVYo`00000Koooo
o`03o`000?oooooooooo00;ooooo00CogMgMoeEEEOoooooo00001?ooool01Oo<c<co0000o`000?l0
003oc<c<00Kooooo00?oMgMgofIVI_ooool0Roooool00:7ooooo00?o410@o`000?mgMgL00_l00000
0onHV9Soooooooooo`0Iooooo`03o`000?oooooooooo00?ooooo00?oMgMgolc<c?l000001?ooool0
1Ol@413o^[Zjoooooonj^[[o410@00Oooooo00?o0000ooooooooool0R_ooool00<;ooooo00?o0000
ooooooooool00oooool00oo^k^koA4A4o`000004ooooo`05o`000?nj^[[ooooookZj^_l000000ooo
ool01Ol0003o^[ZjoooooonHV9So410@08cooooo0030ooooo`03oeEEEOmVIVKo000000Kooooo00?o
MgMgo`000?ooool00oooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c02<ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1488) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.59953 .58389 Mdot
.59334 .58101 Mdot
.47536 .35407 Mdot
.41559 .57343 Mdot
.19338 .5753 Mdot
.51915 .33583 Mdot
.68605 .40627 Mdot
.67654 .40803 Mdot
.46801 .35927 Mdot
.7213 .63136 Mdot
.62531 .41053 Mdot
.45959 .53889 Mdot
.65627 .42359 Mdot
.45677 .59186 Mdot
.5123 .8781 Mdot
.38661 .54527 Mdot
.60301 .5824 Mdot
.2622 .38689 Mdot
.41248 .54117 Mdot
.48613 .32437 Mdot
.6652 .64068 Mdot
.45175 .59104 Mdot
.61726 .59595 Mdot
.45722 .59227 Mdot
.41351 .59616 Mdot
.61581 .60439 Mdot
.56508 .58265 Mdot
.40267 .62759 Mdot
.44668 .62781 Mdot
.62741 .40782 Mdot
.27278 .41865 Mdot
.32865 .775 Mdot
.3726 .6524 Mdot
.30063 .63692 Mdot
.65247 .44517 Mdot
.53454 .76427 Mdot
.5128 .35427 Mdot
.66705 .40894 Mdot
.65518 .40801 Mdot
.6835 .42093 Mdot
.67698 .41491 Mdot
.63695 .60155 Mdot
.76562 .46318 Mdot
.70973 .37587 Mdot
.48326 .61824 Mdot
.20523 .40491 Mdot
.43658 .75812 Mdot
.43984 .56124 Mdot
.65779 .61994 Mdot
.41162 .25756 Mdot
.65332 .30708 Mdot
.65944 .45171 Mdot
.46782 .33726 Mdot
.5451 .10721 Mdot
.63827 .42371 Mdot
.45941 .64953 Mdot
.49595 .35392 Mdot
.44355 .6031 Mdot
.45971 .59596 Mdot
.5881 .68063 Mdot
.38523 .63864 Mdot
.32477 .38908 Mdot
.5746 .6088 Mdot
.47245 .45811 Mdot
.49033 .34543 Mdot
.63703 .40863 Mdot
.61109 .5676 Mdot
.63999 .42893 Mdot
.39721 .67446 Mdot
.54415 .35533 Mdot
.41967 .55507 Mdot
.63289 .40786 Mdot
.64282 .64274 Mdot
.42278 .62738 Mdot
.38801 .25424 Mdot
.21017 .38059 Mdot
.32173 .37011 Mdot
.54894 .74496 Mdot
.59393 .67803 Mdot
.38119 .30857 Mdot
.44306 .64384 Mdot
.25239 .48255 Mdot
.22624 .36819 Mdot
.66699 .60509 Mdot
.37079 .5637 Mdot
.28883 .3905 Mdot
.4174 .62649 Mdot
.16861 .55212 Mdot
.37157 .612 Mdot
.5156 .50193 Mdot
.48854 .37475 Mdot
.62812 .62828 Mdot
.41336 .57911 Mdot
.44995 .62216 Mdot
.648 .69362 Mdot
.41787 .55134 Mdot
.43661 .585 Mdot
.66164 .60002 Mdot
.64908 .45081 Mdot
.39901 .65514 Mdot
.46048 .30229 Mdot
.52273 .3212 Mdot
.38301 .61354 Mdot
.53527 .3641 Mdot
.64194 .64152 Mdot
.44867 .62233 Mdot
.6532 .41143 Mdot
.39077 .59406 Mdot
.68631 .27141 Mdot
.61217 .58043 Mdot
.42434 .63779 Mdot
.37158 .38463 Mdot
.49681 .70173 Mdot
.64232 .63375 Mdot
.69631 .44875 Mdot
.42653 .54021 Mdot
.43065 .59531 Mdot
.61759 .56746 Mdot
.51964 .31545 Mdot
.17441 .49669 Mdot
.64967 .57956 Mdot
.61054 .45125 Mdot
.67892 .62293 Mdot
.47362 .54425 Mdot
.4896 .34006 Mdot
.7144 .41592 Mdot
.73188 .42958 Mdot
.28644 .45324 Mdot
.41865 .62287 Mdot
.78376 .47527 Mdot
.49791 .31723 Mdot
.64021 .61966 Mdot
.64531 .42895 Mdot
.36329 .61611 Mdot
.6305 .57997 Mdot
.61005 .4352 Mdot
.33489 .41711 Mdot
.63449 .26168 Mdot
.59487 .60316 Mdot
.57164 .43937 Mdot
.63796 .45051 Mdot
.68672 .43751 Mdot
.58284 .82792 Mdot
.65228 .59213 Mdot
.35768 .39744 Mdot
.64898 .43454 Mdot
.38268 .48044 Mdot
.47402 .62996 Mdot
.23956 .46689 Mdot
.75293 .32164 Mdot
.31299 .57694 Mdot
.59285 .28282 Mdot
.36067 .40427 Mdot
.67606 .45323 Mdot
.42591 .57939 Mdot
.60779 .61039 Mdot
.61817 .5998 Mdot
.3845 .63736 Mdot
.4012 .60389 Mdot
.38834 .56218 Mdot
.45308 .56265 Mdot
.54581 .54027 Mdot
.36842 .59883 Mdot
.45362 .7561 Mdot
.6222 .62679 Mdot
.4211 .572 Mdot
.46756 .33947 Mdot
.48206 .57022 Mdot
.65754 .40336 Mdot
.44597 .5967 Mdot
.4156 .5761 Mdot
.42028 .65111 Mdot
.67245 .44866 Mdot
.29753 .73134 Mdot
.45995 .68909 Mdot
.27942 .66104 Mdot
.59915 .52955 Mdot
.48896 .38552 Mdot
.41135 .62108 Mdot
.34452 .38684 Mdot
.59507 .76403 Mdot
.40511 .56861 Mdot
.25684 .231 Mdot
.44327 .5845 Mdot
.22625 .64051 Mdot
.3376 .60594 Mdot
.28964 .65088 Mdot
.26649 .47454 Mdot
.41719 .59766 Mdot
.77 .55822 Mdot
.60647 .40862 Mdot
.52266 .28959 Mdot
.67609 .42562 Mdot
.47678 .33418 Mdot
.48162 .3527 Mdot
.41223 .4348 Mdot
.41695 .52321 Mdot
.45813 .54855 Mdot
.37842 .5793 Mdot
.53616 .32522 Mdot
.55585 .59718 Mdot
.37325 .38917 Mdot
.57836 .61789 Mdot
.27038 .73235 Mdot
.46262 .24679 Mdot
.63681 .39971 Mdot
.34967 .41962 Mdot
.52143 .36946 Mdot
.47977 .37343 Mdot
.36462 .40441 Mdot
.46303 .60956 Mdot
.64994 .58933 Mdot
.44443 .81706 Mdot
.60312 .22226 Mdot
.82451 .65831 Mdot
.66342 .60867 Mdot
.77563 .506 Mdot
.66179 .40177 Mdot
.50396 .36374 Mdot
.43216 .59209 Mdot
.44284 .6176 Mdot
.63904 .64454 Mdot
.42163 .55488 Mdot
.68053 .58908 Mdot
.42366 .59541 Mdot
.6392 .39226 Mdot
.31053 .38227 Mdot
.41147 .43531 Mdot
.32466 .48047 Mdot
.65116 .63802 Mdot
.67636 .73205 Mdot
.48098 .37682 Mdot
.60769 .75591 Mdot
.62518 .41402 Mdot
.32385 .41326 Mdot
.4618 .36864 Mdot
.36733 .37527 Mdot
.36757 .57505 Mdot
.4983 .32572 Mdot
.35877 .37376 Mdot
.42865 .47721 Mdot
.48522 .60532 Mdot
.57905 .18987 Mdot
.68131 .43137 Mdot
.5813 .59738 Mdot
.3892 .58998 Mdot
.50513 .38185 Mdot
.43578 .67105 Mdot
.54036 .269 Mdot
.72029 .35003 Mdot
.49183 .31772 Mdot
.37876 .45516 Mdot
.31919 .41141 Mdot
.62815 .3158 Mdot
.77971 .4799 Mdot
.58739 .58656 Mdot
.37702 .56612 Mdot
.3392 .77721 Mdot
.64825 .43414 Mdot
.39587 .58294 Mdot
.20823 .48237 Mdot
.64037 .44184 Mdot
.44142 .6042 Mdot
.61339 .44457 Mdot
.61886 .59943 Mdot
.61347 .67354 Mdot
.62819 .56906 Mdot
.42497 .55434 Mdot
.64757 .41537 Mdot
.51258 .30869 Mdot
.62086 .60879 Mdot
.47123 .59086 Mdot
.40335 .62479 Mdot
.43907 .4607 Mdot
.42903 .57044 Mdot
.27408 .67658 Mdot
.42009 .59675 Mdot
.48643 .36267 Mdot
.42086 .64632 Mdot
.79759 .56341 Mdot
.41059 .43026 Mdot
.63258 .57165 Mdot
.48174 .32056 Mdot
.47608 .34773 Mdot
.31478 .3013 Mdot
.70168 .43572 Mdot
.47738 .5774 Mdot
.49519 .38267 Mdot
.4247 .50511 Mdot
.62013 .43052 Mdot
.37681 .61826 Mdot
.57316 .40387 Mdot
.47831 .25703 Mdot
.47432 .33174 Mdot
.51917 .58383 Mdot
.60167 .61984 Mdot
.40967 .58708 Mdot
.50958 .37828 Mdot
.37357 .53139 Mdot
.43971 .63606 Mdot
.78106 .42815 Mdot
.41475 .45778 Mdot
.63448 .44713 Mdot
.4624 .54723 Mdot
.38967 .57174 Mdot
.50435 .32792 Mdot
.63434 .63802 Mdot
.62239 .43585 Mdot
.63104 .60529 Mdot
.2915 .63759 Mdot
.59663 .20195 Mdot
.49928 .49803 Mdot
.33251 .36776 Mdot
.46661 .27541 Mdot
.29472 .67437 Mdot
.75545 .67274 Mdot
.57704 .80327 Mdot
.33706 .73809 Mdot
.53791 .35585 Mdot
.44455 .26638 Mdot
.48586 .34941 Mdot
.39474 .61896 Mdot
.49468 .34151 Mdot
.35761 .80134 Mdot
.42665 .59186 Mdot
.50798 .34335 Mdot
.66266 .71301 Mdot
.41415 .58371 Mdot
.5861 .58627 Mdot
.25606 .69345 Mdot
.82825 .53342 Mdot
.68922 .47074 Mdot
.51988 .36164 Mdot
.47156 .82233 Mdot
.43607 .58281 Mdot
.41819 .64573 Mdot
.6145 .62461 Mdot
.38811 .66471 Mdot
.34423 .37955 Mdot
.3475 .42179 Mdot
.61266 .47795 Mdot
.32775 .43989 Mdot
.46365 .54745 Mdot
.61836 .61037 Mdot
.56137 .55087 Mdot
.33648 .29606 Mdot
.42513 .25566 Mdot
.61174 .41012 Mdot
.25535 .6913 Mdot
.67988 .55734 Mdot
.64226 .51593 Mdot
.58071 .37462 Mdot
.64861 .62369 Mdot
.32067 .76756 Mdot
.67511 .42089 Mdot
.52699 .17939 Mdot
.74142 .61818 Mdot
.45806 .6123 Mdot
.62699 .42081 Mdot
.49057 .63902 Mdot
.81069 .56753 Mdot
.47706 .19068 Mdot
.37391 .73512 Mdot
.37283 .61203 Mdot
.4587 .2488 Mdot
.44034 .5941 Mdot
.53374 .27298 Mdot
.41348 .60606 Mdot
.63284 .60811 Mdot
.72994 .62293 Mdot
.67055 .47056 Mdot
.53812 .60669 Mdot
.62011 .32464 Mdot
.36599 .39755 Mdot
.42421 .59783 Mdot
.46143 .60914 Mdot
.34296 .37625 Mdot
.60826 .59524 Mdot
.40339 .5555 Mdot
.68572 .72349 Mdot
.46587 .61097 Mdot
.66777 .40583 Mdot
.73599 .63247 Mdot
.39428 .71367 Mdot
.45024 .55462 Mdot
.67091 .60762 Mdot
.66469 .39765 Mdot
.65193 .41535 Mdot
.35313 .56625 Mdot
.61934 .40999 Mdot
.44208 .57537 Mdot
.4489 .19134 Mdot
.59839 .59467 Mdot
.75784 .36208 Mdot
.63556 .57818 Mdot
.53973 .73433 Mdot
.64827 .44876 Mdot
.66608 .28039 Mdot
.49318 .63424 Mdot
.6723 .42248 Mdot
.51433 .6446 Mdot
.48099 .59856 Mdot
.48327 .59186 Mdot
.44566 .81422 Mdot
.4924 .37033 Mdot
.43058 .45692 Mdot
.62485 .4089 Mdot
.45867 .57872 Mdot
.42496 .54451 Mdot
.66858 .39883 Mdot
.53107 .21713 Mdot
.75939 .64031 Mdot
.42263 .59485 Mdot
.63348 .61464 Mdot
.64299 .61556 Mdot
.49098 .61235 Mdot
.38669 .60822 Mdot
.47304 .33983 Mdot
.49527 .30723 Mdot
.50057 .38863 Mdot
.41845 .45392 Mdot
.69837 .3086 Mdot
.18766 .52018 Mdot
.68369 .42238 Mdot
.7536 .51356 Mdot
.4866 .48869 Mdot
.37059 .60854 Mdot
.52644 .35469 Mdot
.39124 .56904 Mdot
.42031 .5626 Mdot
.69265 .36143 Mdot
.20569 .57264 Mdot
.71012 .61014 Mdot
.64619 .63984 Mdot
.67332 .4528 Mdot
.43393 .53146 Mdot
.66262 .37681 Mdot
.32162 .40244 Mdot
.32422 .55965 Mdot
.62452 .41295 Mdot
.5885 .5801 Mdot
.66858 .44224 Mdot
.44256 .62043 Mdot
.43774 .66381 Mdot
.64857 .62132 Mdot
.32264 .38794 Mdot
.3616 .62528 Mdot
.43796 .60294 Mdot
.70899 .25372 Mdot
.36952 .49478 Mdot
.63164 .50524 Mdot
.41996 .59451 Mdot
.47767 .59232 Mdot
.35353 .42876 Mdot
.46173 .61435 Mdot
.38216 .58283 Mdot
.48942 .70709 Mdot
.69708 .50536 Mdot
.37235 .40307 Mdot
.47121 .19849 Mdot
.66284 .60834 Mdot
.32301 .75526 Mdot
.52552 .34559 Mdot
.64344 .48631 Mdot
.75113 .63776 Mdot
.45686 .35619 Mdot
.58775 .28673 Mdot
.31184 .73895 Mdot
.44559 .31798 Mdot
.51685 .39108 Mdot
.5702 .59806 Mdot
.44678 .56255 Mdot
.43215 .59801 Mdot
.34673 .38529 Mdot
.64979 .5921 Mdot
.55023 .49451 Mdot
.26312 .30344 Mdot
.44937 .59031 Mdot
.77524 .42104 Mdot
.45789 .22065 Mdot
.44463 .25089 Mdot
.33753 .39481 Mdot
.35066 .42295 Mdot
.42456 .59956 Mdot
.48075 .69608 Mdot
.61529 .60519 Mdot
.47072 .59036 Mdot
.36825 .60278 Mdot
.50437 .36979 Mdot
.61819 .58216 Mdot
.51808 .31441 Mdot
.63827 .29283 Mdot
.27112 .64902 Mdot
.5004 .15806 Mdot
.63171 .43174 Mdot
.39464 .23998 Mdot
.61521 .43856 Mdot
.25687 .48594 Mdot
.45395 .3652 Mdot
.40226 .59181 Mdot
.61842 .63121 Mdot
.45137 .57332 Mdot
.38979 .60425 Mdot
.46422 .60759 Mdot
.44162 .55037 Mdot
.52562 .15082 Mdot
.36876 .39288 Mdot
.36054 .58113 Mdot
.48076 .35977 Mdot
.2308 .37107 Mdot
.27401 .32527 Mdot
.4609 .60746 Mdot
.40935 .61473 Mdot
.6229 .58842 Mdot
.3793 .61373 Mdot
.61726 .4369 Mdot
.57886 .59228 Mdot
.42985 .62882 Mdot
.21081 .65284 Mdot
.44406 .63028 Mdot
.28836 .67243 Mdot
.66795 .44147 Mdot
.62253 .23027 Mdot
.42344 .66608 Mdot
.72707 .3846 Mdot
.43075 .45706 Mdot
.46014 .36607 Mdot
.62353 .45216 Mdot
.51313 .352 Mdot
.28338 .27507 Mdot
.50683 .59801 Mdot
.42311 .58226 Mdot
.37414 .5933 Mdot
.48996 .3856 Mdot
.16992 .61067 Mdot
.63967 .33302 Mdot
.50988 .59157 Mdot
.47633 .33644 Mdot
.61497 .5616 Mdot
.33018 .70927 Mdot
.64147 .59364 Mdot
.30835 .41414 Mdot
.66932 .40391 Mdot
.32565 .38567 Mdot
.25716 .56025 Mdot
.607 .57895 Mdot
.61415 .63944 Mdot
.52381 .34996 Mdot
.63047 .65886 Mdot
.84795 .38274 Mdot
.74633 .61344 Mdot
.28618 .47704 Mdot
.61232 .61482 Mdot
.44927 .6251 Mdot
.25277 .51895 Mdot
.73558 .62141 Mdot
.51078 .35087 Mdot
.40514 .56208 Mdot
.63905 .67718 Mdot
.47134 .34061 Mdot
.38653 .65323 Mdot
.4801 .36364 Mdot
.67492 .43106 Mdot
.52091 .36438 Mdot
.6804 .63427 Mdot
.41367 .63169 Mdot
.86066 .38653 Mdot
.34691 .44813 Mdot
.4323 .58154 Mdot
.69142 .441 Mdot
.56752 .24802 Mdot
.40386 .58009 Mdot
.3467 .36822 Mdot
.50654 .33727 Mdot
.57001 .6252 Mdot
.419 .59926 Mdot
.47686 .3359 Mdot
.59043 .59372 Mdot
.70692 .41325 Mdot
.64312 .69165 Mdot
.66558 .5154 Mdot
.62099 .63032 Mdot
.62387 .52346 Mdot
.65308 .46123 Mdot
.4779 .58699 Mdot
.41339 .55143 Mdot
.63784 .6136 Mdot
.23345 .42208 Mdot
.39376 .63929 Mdot
.42936 .64574 Mdot
.49959 .36745 Mdot
.51638 .3472 Mdot
.56657 .80471 Mdot
.53094 .32758 Mdot
.40992 .66475 Mdot
.63928 .61125 Mdot
.41337 .57678 Mdot
.61885 .58666 Mdot
.3798 .61174 Mdot
.33828 .65563 Mdot
.60773 .59584 Mdot
.69264 .36518 Mdot
.41038 .56188 Mdot
.3551 .6272 Mdot
.39343 .58995 Mdot
.45349 .56596 Mdot
.47554 .34022 Mdot
.33861 .38921 Mdot
.36877 .60926 Mdot
.34277 .3547 Mdot
.36978 .40048 Mdot
.67981 .47221 Mdot
.5018 .37062 Mdot
.36293 .38973 Mdot
.39161 .21504 Mdot
.49079 .32857 Mdot
.35018 .38378 Mdot
.27162 .32776 Mdot
.65335 .44635 Mdot
.6037 .62275 Mdot
.41209 .58798 Mdot
.28679 .58021 Mdot
.43321 .7508 Mdot
.45532 .38976 Mdot
.42377 .59162 Mdot
.39794 .57907 Mdot
.64347 .57306 Mdot
.20913 .35185 Mdot
.54136 .36124 Mdot
.45896 .62198 Mdot
.59805 .57706 Mdot
.154 .41704 Mdot
.48572 .35804 Mdot
.34481 .38279 Mdot
.66905 .44633 Mdot
.54081 .61976 Mdot
.73818 .39768 Mdot
.69504 .43019 Mdot
.44668 .33488 Mdot
.65068 .30092 Mdot
.40558 .54661 Mdot
.52729 .3332 Mdot
.71304 .74846 Mdot
.53931 .54085 Mdot
.4582 .45517 Mdot
.43904 .80343 Mdot
.64325 .62949 Mdot
.61575 .43775 Mdot
.36216 .40374 Mdot
.66281 .61643 Mdot
.60392 .58309 Mdot
.67789 .40494 Mdot
.44434 .69772 Mdot
.57724 .40011 Mdot
.65807 .40631 Mdot
.32352 .53474 Mdot
.2167 .42951 Mdot
.52872 .34499 Mdot
.34552 .37944 Mdot
.24465 .56725 Mdot
.63403 .60223 Mdot
.29134 .75363 Mdot
.47073 .83018 Mdot
.43681 .58487 Mdot
.35943 .40077 Mdot
.17299 .59328 Mdot
.20632 .36524 Mdot
.63911 .44268 Mdot
.66093 .48128 Mdot
.31696 .40289 Mdot
.39077 .58681 Mdot
.36742 .51155 Mdot
.39734 .63457 Mdot
.67746 .41087 Mdot
.63202 .70406 Mdot
.6047 .58039 Mdot
.68539 .43147 Mdot
.30897 .61677 Mdot
.44464 .57768 Mdot
.40731 .56336 Mdot
.32184 .50466 Mdot
.66421 .6175 Mdot
.46044 .36817 Mdot
.40209 .55213 Mdot
.44108 .60021 Mdot
.42219 .66392 Mdot
.49836 .59915 Mdot
.53255 .68856 Mdot
.39906 .61582 Mdot
.37768 .25327 Mdot
.37572 .60494 Mdot
.43534 .5646 Mdot
.6698 .61987 Mdot
.46673 .15758 Mdot
.64404 .30831 Mdot
.44389 .59747 Mdot
.47414 .60419 Mdot
.68243 .43644 Mdot
.59777 .38494 Mdot
.70755 .63682 Mdot
.56679 .61833 Mdot
.52595 .82165 Mdot
.48546 .60252 Mdot
.61046 .56833 Mdot
.35162 .37107 Mdot
.47809 .58019 Mdot
.59453 .57381 Mdot
.42916 .64977 Mdot
.46441 .34681 Mdot
.48735 .32977 Mdot
.55857 .56645 Mdot
.36322 .38553 Mdot
.79626 .53956 Mdot
.75143 .51298 Mdot
.49893 .32774 Mdot
.4201 .58601 Mdot
.60788 .40648 Mdot
.49841 .37825 Mdot
.44199 .31937 Mdot
.21467 .46782 Mdot
.60598 .61077 Mdot
.62671 .62954 Mdot
.23594 .46866 Mdot
.60597 .27392 Mdot
.78537 .40352 Mdot
.67688 .4295 Mdot
.35968 .59062 Mdot
.77776 .52697 Mdot
.63187 .63282 Mdot
.25664 .50315 Mdot
.36339 .39599 Mdot
.64154 .44192 Mdot
.62866 .35749 Mdot
.63124 .5857 Mdot
.58702 .61017 Mdot
.39551 .64887 Mdot
.44086 .61021 Mdot
.59249 .79084 Mdot
.35094 .35527 Mdot
.68894 .41043 Mdot
.34342 .38051 Mdot
.45479 .35383 Mdot
.40433 .635 Mdot
.61149 .59625 Mdot
.20398 .44605 Mdot
.45453 .55397 Mdot
.46451 .35839 Mdot
.63824 .63082 Mdot
.32159 .4157 Mdot
.33764 .36909 Mdot
.45667 .56429 Mdot
.63486 .75973 Mdot
.66913 .41291 Mdot
.65731 .61111 Mdot
.58956 .44513 Mdot
.39296 .63299 Mdot
.4321 .61039 Mdot
.34469 .64713 Mdot
.69047 .41346 Mdot
.71301 .57206 Mdot
.34861 .36561 Mdot
.65272 .60497 Mdot
.40243 .61524 Mdot
.35325 .38082 Mdot
.76081 .51404 Mdot
.45828 .33736 Mdot
.51962 .36709 Mdot
.33607 .37057 Mdot
.3377 .40262 Mdot
.35432 .3679 Mdot
.2945 .75923 Mdot
.59145 .56957 Mdot
.65652 .53261 Mdot
.46188 .6261 Mdot
.27323 .47429 Mdot
.35575 .59455 Mdot
.63046 .44703 Mdot
.48672 .36961 Mdot
.39802 .59031 Mdot
.46057 .56345 Mdot
.33568 .62952 Mdot
.76566 .38497 Mdot
.38576 .68308 Mdot
.61271 .58252 Mdot
.4434 .66306 Mdot
.51837 .36189 Mdot
.30245 .78541 Mdot
.51462 .84628 Mdot
.43264 .66525 Mdot
.58794 .39589 Mdot
.60369 .60082 Mdot
.68392 .4204 Mdot
.29425 .53193 Mdot
.65822 .44683 Mdot
.64998 .61267 Mdot
.39711 .62127 Mdot
.73849 .54118 Mdot
.37043 .42077 Mdot
.45645 .57398 Mdot
.68007 .42782 Mdot
.4223 .55556 Mdot
.69254 .42304 Mdot
.28137 .59331 Mdot
.69238 .74949 Mdot
.44247 .58494 Mdot
.39336 .54595 Mdot
.62677 .7765 Mdot
.46532 .6 Mdot
.32542 .34658 Mdot
.60302 .60149 Mdot
.64363 .70497 Mdot
.42019 .53299 Mdot
.35239 .53641 Mdot
.40036 .63875 Mdot
.67493 .69239 Mdot
.43359 .61296 Mdot
.43722 .24964 Mdot
.41905 .6367 Mdot
.38088 .58183 Mdot
.63705 .42183 Mdot
.6846 .43423 Mdot
.66852 .63417 Mdot
.52166 .37642 Mdot
.2852 .67275 Mdot
.435 .60522 Mdot
.68253 .29644 Mdot
.69918 .5287 Mdot
.33626 .39993 Mdot
.65066 .60797 Mdot
.15451 .43884 Mdot
.60972 .42797 Mdot
.56973 .82721 Mdot
.51296 .81644 Mdot
.71854 .47297 Mdot
.21625 .55716 Mdot
.52604 .23551 Mdot
.32035 .41032 Mdot
.41568 .65094 Mdot
.41427 .34395 Mdot
.43167 .24875 Mdot
.22926 .4251 Mdot
.63107 .4574 Mdot
.58914 .77328 Mdot
.20331 .51693 Mdot
.31265 .388 Mdot
.34353 .42573 Mdot
.67442 .44906 Mdot
.55796 .33515 Mdot
.43735 .52742 Mdot
.35164 .40668 Mdot
.49712 .38703 Mdot
.48722 .32632 Mdot
.51695 .38509 Mdot
.61503 .60251 Mdot
.51872 .84191 Mdot
.6352 .46267 Mdot
.62982 .44377 Mdot
.52673 .28325 Mdot
.31947 .64559 Mdot
.59486 .63248 Mdot
.51234 .35966 Mdot
.53297 .35063 Mdot
.59977 .60358 Mdot
.45094 .65227 Mdot
.5051 .59133 Mdot
.44724 .59382 Mdot
.34382 .38825 Mdot
.43947 .6145 Mdot
.4857 .33431 Mdot
.63469 .43488 Mdot
.5278 .36318 Mdot
.69825 .4314 Mdot
.19294 .45845 Mdot
.47112 .58209 Mdot
.41237 .63302 Mdot
.654 .20812 Mdot
.60464 .62863 Mdot
.22018 .38841 Mdot
.68903 .38183 Mdot
.48459 .35069 Mdot
.38303 .58231 Mdot
.58419 .62759 Mdot
.38277 .37998 Mdot
.50833 .16355 Mdot
.38351 .61861 Mdot
.62888 .59594 Mdot
.40156 .63106 Mdot
.49264 .51036 Mdot
.82112 .45079 Mdot
.64024 .60442 Mdot
.77283 .37437 Mdot
.45623 .62232 Mdot
.40206 .22033 Mdot
.37683 .60823 Mdot
.43307 .48142 Mdot
.39359 .63909 Mdot
.66295 .6063 Mdot
.44864 .59784 Mdot
.57651 .61521 Mdot
.50968 .3245 Mdot
.67972 .43676 Mdot
.62065 .62917 Mdot
.43682 .55213 Mdot
.73205 .18662 Mdot
.66304 .43745 Mdot
.42843 .59445 Mdot
.66462 .44966 Mdot
.64285 .58212 Mdot
.65496 .62392 Mdot
.25337 .3304 Mdot
.6342 .29125 Mdot
.67269 .4321 Mdot
.40354 .634 Mdot
.43895 .22896 Mdot
.39967 .60117 Mdot
.40716 .5037 Mdot
.45747 .65102 Mdot
.45508 .64049 Mdot
.24097 .35004 Mdot
.63779 .44887 Mdot
.78532 .39784 Mdot
.21778 .36246 Mdot
.23215 .36872 Mdot
.66929 .63916 Mdot
.31703 .38335 Mdot
.31183 .75459 Mdot
.70466 .31686 Mdot
.45963 .35443 Mdot
.3991 .58611 Mdot
.55542 .58711 Mdot
.66386 .41122 Mdot
.32413 .3974 Mdot
.4417 .5856 Mdot
.53079 .35231 Mdot
.75903 .65936 Mdot
.67435 .45336 Mdot
.6414 .60009 Mdot
.63831 .56814 Mdot
.34328 .20927 Mdot
.41368 .60289 Mdot
.41888 .63235 Mdot
.66974 .4039 Mdot
.54412 .23398 Mdot
.35122 .41563 Mdot
.66394 .71033 Mdot
.66991 .43283 Mdot
.54275 .47085 Mdot
.58981 .57546 Mdot
.39597 .57729 Mdot
.21503 .63756 Mdot
.61783 .3531 Mdot
.70743 .26433 Mdot
.34604 .38768 Mdot
.41745 .50308 Mdot
.66252 .60635 Mdot
.64715 .43076 Mdot
.60432 .25582 Mdot
.48388 .59614 Mdot
.39598 .56261 Mdot
.43664 .49411 Mdot
.68106 .46823 Mdot
.68098 .65201 Mdot
.38522 .62149 Mdot
.43041 .45527 Mdot
.3825 .61263 Mdot
.35579 .57268 Mdot
.47545 .64157 Mdot
.42262 .61691 Mdot
.61841 .59548 Mdot
.49166 .54175 Mdot
.477 .38205 Mdot
.70473 .61877 Mdot
.53226 .47105 Mdot
.42954 .58626 Mdot
.43293 .64437 Mdot
.39114 .7433 Mdot
.56705 .2756 Mdot
.61823 .62621 Mdot
.65399 .64746 Mdot
.61135 .4182 Mdot
.48725 .62335 Mdot
.52311 .37514 Mdot
.35819 .608 Mdot
.47244 .34284 Mdot
.61497 .59626 Mdot
.48528 .35344 Mdot
.67758 .44432 Mdot
.52293 .32543 Mdot
.68997 .29867 Mdot
.65098 .43847 Mdot
.60856 .61881 Mdot
.42786 .62625 Mdot
.69296 .43974 Mdot
.30708 .46527 Mdot
.34633 .38922 Mdot
.15321 .523 Mdot
.43017 .62932 Mdot
.70064 .48123 Mdot
.33908 .5772 Mdot
.53085 .35769 Mdot
.81507 .43306 Mdot
.62764 .63709 Mdot
.36368 .41348 Mdot
.6621 .62515 Mdot
.32579 .55962 Mdot
.34556 .40002 Mdot
.16297 .46511 Mdot
.41915 .46537 Mdot
.37659 .49491 Mdot
.47477 .63418 Mdot
.33708 .49162 Mdot
.46446 .33673 Mdot
.66234 .41237 Mdot
.59759 .26443 Mdot
.38308 .5779 Mdot
.77122 .67379 Mdot
.66858 .61585 Mdot
.50238 .38134 Mdot
.64342 .42776 Mdot
.62486 .44108 Mdot
.47283 .6107 Mdot
.39126 .28246 Mdot
.39227 .56367 Mdot
.62336 .27344 Mdot
.46993 .82041 Mdot
.6618 .54051 Mdot
.42416 .59513 Mdot
.50531 .32754 Mdot
.40132 .63077 Mdot
.34372 .36495 Mdot
.61067 .8099 Mdot
.35756 .6226 Mdot
.66189 .38807 Mdot
.35662 .35539 Mdot
.65228 .58974 Mdot
.32978 .62567 Mdot
.65922 .52642 Mdot
.41053 .60552 Mdot
.45961 .12814 Mdot
.3524 .38316 Mdot
.41952 .33268 Mdot
.4421 .54745 Mdot
.47147 .56853 Mdot
.44598 .4371 Mdot
.73977 .37333 Mdot
.57053 .34118 Mdot
.46332 .59375 Mdot
.30928 .45512 Mdot
.66059 .45303 Mdot
.3888 .59333 Mdot
.43017 .59768 Mdot
.44968 .72819 Mdot
.646 .45431 Mdot
.47156 .35315 Mdot
.45595 .36213 Mdot
.44891 .37673 Mdot
.35931 .36679 Mdot
.72441 .61394 Mdot
.27241 .49546 Mdot
.79486 .60738 Mdot
.36329 .41987 Mdot
.46731 .57084 Mdot
.45074 .30085 Mdot
.39627 .62776 Mdot
.32646 .39861 Mdot
.65063 .45532 Mdot
.63389 .6347 Mdot
.77316 .52665 Mdot
.464 .3414 Mdot
.48247 .5764 Mdot
.36388 .4096 Mdot
.60765 .60959 Mdot
.27019 .54155 Mdot
.65256 .59116 Mdot
.66954 .42623 Mdot
.72746 .61272 Mdot
.32386 .4013 Mdot
.62911 .5726 Mdot
.62547 .39219 Mdot
.23239 .34164 Mdot
.49225 .62346 Mdot
.75052 .57249 Mdot
.64968 .58353 Mdot
.63482 .64746 Mdot
.60997 .56574 Mdot
.43741 .55932 Mdot
.58505 .39759 Mdot
.47354 .62917 Mdot
.646 .4517 Mdot
.47669 .36117 Mdot
.69989 .72991 Mdot
.70125 .35102 Mdot
.58928 .47934 Mdot
.36657 .62939 Mdot
.446 .5783 Mdot
.425 .59915 Mdot
.37336 .55333 Mdot
.69545 .30193 Mdot
.43367 .56045 Mdot
.63721 .42117 Mdot
.50041 .33629 Mdot
.4192 .65088 Mdot
.45788 .32717 Mdot
.26474 .34208 Mdot
.31592 .40069 Mdot
.60323 .46887 Mdot
.58667 .83942 Mdot
.60852 .61256 Mdot
.48768 .3179 Mdot
.49573 .33192 Mdot
.33232 .41786 Mdot
.66897 .40894 Mdot
.64853 .58491 Mdot
.43964 .5086 Mdot
.37044 .39895 Mdot
.44596 .59911 Mdot
.60749 .39155 Mdot
.75192 .69616 Mdot
.40535 .64977 Mdot
.40816 .5779 Mdot
.52634 .38115 Mdot
.42067 .33746 Mdot
.87381 .51468 Mdot
.2896 .50648 Mdot
.33062 .391 Mdot
.32234 .38175 Mdot
.59661 .60267 Mdot
.46936 .56063 Mdot
.68714 .44267 Mdot
.66622 .66418 Mdot
.69831 .56901 Mdot
.79962 .48747 Mdot
.68403 .24348 Mdot
.38734 .60318 Mdot
.51263 .21516 Mdot
.43839 .571 Mdot
.60193 .56592 Mdot
.62123 .59838 Mdot
.62309 .61446 Mdot
.66352 .41296 Mdot
.55291 .76311 Mdot
.64603 .415 Mdot
.68396 .78229 Mdot
.65967 .61486 Mdot
.4091 .46344 Mdot
.51293 .36291 Mdot
.50985 .58395 Mdot
.3172 .40503 Mdot
.74451 .59444 Mdot
.39559 .67395 Mdot
.48283 .68544 Mdot
.49399 .38165 Mdot
.61401 .62571 Mdot
.53988 .23605 Mdot
.38094 .79642 Mdot
.62875 .65696 Mdot
.35208 .66589 Mdot
.29277 .53438 Mdot
.3333 .39725 Mdot
.70473 .26134 Mdot
.32933 .38447 Mdot
.67916 .43018 Mdot
.40706 .62819 Mdot
.41713 .62585 Mdot
.38183 .61423 Mdot
.47078 .59621 Mdot
.66873 .45895 Mdot
.36833 .58084 Mdot
.79675 .56499 Mdot
.46078 .34756 Mdot
.28663 .4083 Mdot
.33718 .38208 Mdot
.63101 .45329 Mdot
.49855 .33573 Mdot
.5748 .27971 Mdot
.31902 .47882 Mdot
.42077 .59739 Mdot
.39799 .58945 Mdot
.60134 .80337 Mdot
.38573 .62147 Mdot
.46306 .53616 Mdot
.46782 .34062 Mdot
.37784 .71007 Mdot
.31634 .39975 Mdot
.31728 .3897 Mdot
.64962 .43988 Mdot
.62023 .59636 Mdot
.3573 .38861 Mdot
.50718 .36598 Mdot
.36918 .63765 Mdot
.37751 .56535 Mdot
.65425 .59013 Mdot
.61201 .80168 Mdot
.32954 .36921 Mdot
.43602 .22638 Mdot
.60656 .61922 Mdot
.67365 .6053 Mdot
.39442 .56404 Mdot
.73588 .30346 Mdot
.6836 .62021 Mdot
.37841 .38522 Mdot
.63095 .45451 Mdot
.30692 .52736 Mdot
.61159 .42775 Mdot
.64213 .59739 Mdot
.44594 .63237 Mdot
.61034 .60073 Mdot
.4182 .59758 Mdot
.43197 .83388 Mdot
.42222 .62131 Mdot
.80056 .5919 Mdot
.23724 .45543 Mdot
.5202 .33409 Mdot
.55616 .26312 Mdot
.52529 .34629 Mdot
.64212 .63853 Mdot
.43744 .54328 Mdot
.34036 .42245 Mdot
.30999 .28902 Mdot
.55764 .64198 Mdot
.4875 .37488 Mdot
.5435 .3345 Mdot
.60945 .44108 Mdot
.39603 .64209 Mdot
.40637 .55782 Mdot
.51074 .34409 Mdot
.68869 .59451 Mdot
.63289 .58097 Mdot
.40572 .61835 Mdot
.44643 .57621 Mdot
.52264 .33795 Mdot
.23842 .33129 Mdot
.52433 .55701 Mdot
.41051 .62251 Mdot
.58079 .36232 Mdot
.62804 .44399 Mdot
.50937 .58678 Mdot
.39222 .54821 Mdot
.33901 .40523 Mdot
.56624 .67981 Mdot
.38124 .77855 Mdot
.6544 .45598 Mdot
.48453 .33221 Mdot
.40823 .60928 Mdot
.50297 .32804 Mdot
.3673 .57938 Mdot
.74031 .39977 Mdot
.49058 .31883 Mdot
.44363 .64387 Mdot
.44588 .65275 Mdot
.66554 .61275 Mdot
.39225 .59639 Mdot
.44479 .78162 Mdot
.46778 .37035 Mdot
.46943 .61451 Mdot
.64948 .73372 Mdot
.64697 .40586 Mdot
.49892 .60137 Mdot
.36997 .3964 Mdot
.37595 .51264 Mdot
.73601 .52081 Mdot
.22172 .58039 Mdot
.31369 .40125 Mdot
.42763 .5568 Mdot
.54403 .35071 Mdot
.68796 .4096 Mdot
.8227 .54117 Mdot
.39155 .58373 Mdot
.68033 .41929 Mdot
.63547 .43549 Mdot
.32226 .39847 Mdot
.44002 .1574 Mdot
.44563 .55062 Mdot
.45744 .6103 Mdot
.50309 .76163 Mdot
.58949 .61879 Mdot
.43229 .61822 Mdot
.4576 .61869 Mdot
.63299 .42447 Mdot
.45904 .54097 Mdot
.51962 .80746 Mdot
.67144 .69959 Mdot
.66149 .39696 Mdot
.78217 .54938 Mdot
.48598 .32214 Mdot
.3481 .37588 Mdot
.64252 .62412 Mdot
.35433 .41534 Mdot
.5126 .36854 Mdot
.44835 .62332 Mdot
.67603 .40612 Mdot
.43985 .77213 Mdot
.67751 .44795 Mdot
.20784 .49903 Mdot
.57834 .59698 Mdot
.63204 .46919 Mdot
.446 .13671 Mdot
.59474 .33685 Mdot
.71241 .44168 Mdot
.33662 .40036 Mdot
.50522 .28908 Mdot
.44469 .57491 Mdot
.68682 .23959 Mdot
.47098 .57605 Mdot
.64304 .72023 Mdot
.45765 .36093 Mdot
.5074 .38794 Mdot
.40759 .62504 Mdot
.44548 .8061 Mdot
.68409 .40447 Mdot
.62078 .42784 Mdot
.45045 .63866 Mdot
.67263 .42296 Mdot
.44612 .61021 Mdot
.48441 .33605 Mdot
.72275 .26339 Mdot
.44362 .59063 Mdot
.3524 .58746 Mdot
.72157 .45632 Mdot
.22386 .36259 Mdot
.29999 .38453 Mdot
.27592 .25848 Mdot
.43406 .82643 Mdot
.67149 .42208 Mdot
.46928 .62816 Mdot
.78605 .5373 Mdot
.53449 .37084 Mdot
.60432 .48077 Mdot
.44097 .62313 Mdot
.47244 .60152 Mdot
.37829 .58911 Mdot
.40839 .56594 Mdot
.56083 .17846 Mdot
.58987 .65063 Mdot
.55617 .71768 Mdot
.38981 .60253 Mdot
.34327 .47963 Mdot
.66311 .44198 Mdot
.54771 .59926 Mdot
.3719 .40871 Mdot
.38867 .60093 Mdot
.65801 .65644 Mdot
.65043 .39918 Mdot
.71294 .76342 Mdot
.67983 .41386 Mdot
.47764 .34715 Mdot
.68828 .43323 Mdot
.4298 .57183 Mdot
.64245 .61577 Mdot
.45217 .41888 Mdot
.63266 .31632 Mdot
.46241 .37464 Mdot
.43196 .582 Mdot
.37233 .46066 Mdot
.48122 .38191 Mdot
.21475 .3897 Mdot
.63589 .62351 Mdot
.2977 .44442 Mdot
.6139 .59875 Mdot
.44872 .63569 Mdot
.44667 .63641 Mdot
.60569 .42606 Mdot
.68235 .4411 Mdot
.61552 .59806 Mdot
.35433 .17852 Mdot
.34553 .36641 Mdot
.62609 .61235 Mdot
.4099 .53192 Mdot
.53837 .42147 Mdot
.6372 .61738 Mdot
.38862 .37875 Mdot
.63284 .43105 Mdot
.59704 .61859 Mdot
.37268 .61757 Mdot
.32788 .53296 Mdot
.34074 .37098 Mdot
.46363 .38255 Mdot
.25711 .52565 Mdot
.47695 .37364 Mdot
.62565 .45362 Mdot
.52509 .34153 Mdot
.63036 .44176 Mdot
.71954 .53891 Mdot
.70541 .60951 Mdot
.41965 .37201 Mdot
.62822 .4587 Mdot
.52338 .35065 Mdot
.40457 .62942 Mdot
.32846 .44387 Mdot
.44926 .54506 Mdot
.41809 .5529 Mdot
.62542 .42639 Mdot
.66076 .6207 Mdot
.66463 .64202 Mdot
.39503 .496 Mdot
.62247 .59294 Mdot
.46561 .36169 Mdot
.52741 .67239 Mdot
.68996 .31197 Mdot
.61634 .41866 Mdot
.68006 .43865 Mdot
.39237 .62544 Mdot
.51247 .35177 Mdot
.47479 .38618 Mdot
.61008 .43118 Mdot
.75814 .38399 Mdot
.38253 .55011 Mdot
.65865 .64746 Mdot
.58884 .61524 Mdot
.64029 .6072 Mdot
.57974 .57642 Mdot
.36125 .52992 Mdot
.64679 .44529 Mdot
.65716 .62795 Mdot
.39158 .62588 Mdot
.45698 .61737 Mdot
.72598 .63489 Mdot
.3544 .37401 Mdot
.43942 .64879 Mdot
.47455 .64165 Mdot
.39569 .57611 Mdot
.52556 .35878 Mdot
.4718 .5359 Mdot
.51979 .31943 Mdot
.5322 .37046 Mdot
.53171 .37195 Mdot
.71283 .33012 Mdot
.55581 .82568 Mdot
.31748 .71468 Mdot
.46889 .61307 Mdot
.4764 .21474 Mdot
.49884 .35855 Mdot
.60511 .66191 Mdot
.7075 .56593 Mdot
.38458 .5813 Mdot
.36085 .26686 Mdot
.51479 .3434 Mdot
.6008 .61134 Mdot
.43174 .62341 Mdot
.46966 .32532 Mdot
.37026 .38443 Mdot
.48147 .59136 Mdot
.45469 .34182 Mdot
.62685 .57119 Mdot
.36154 .36434 Mdot
.60872 .63016 Mdot
.53382 .37006 Mdot
.44114 .53499 Mdot
.80176 .34787 Mdot
.45529 .33574 Mdot
.35159 .23646 Mdot
.48786 .65484 Mdot
.40342 .62263 Mdot
.50267 .31054 Mdot
.67363 .5978 Mdot
.62467 .45223 Mdot
.57926 .51149 Mdot
.59708 .59355 Mdot
.5078 .38789 Mdot
.52083 .37406 Mdot
.46214 .37434 Mdot
.60594 .58513 Mdot
.49397 .59715 Mdot
.62143 .58456 Mdot
.68979 .43014 Mdot
.40844 .59106 Mdot
.2917 .65408 Mdot
.55723 .23506 Mdot
.60312 .61197 Mdot
.47327 .36346 Mdot
.36061 .42705 Mdot
.44202 .57815 Mdot
.52745 .22516 Mdot
.40262 .62903 Mdot
.62682 .43923 Mdot
.50763 .70385 Mdot
.38882 .71914 Mdot
.46389 .63448 Mdot
.39193 .61832 Mdot
.62151 .42494 Mdot
.43545 .58449 Mdot
.39414 .63987 Mdot
.68901 .29711 Mdot
.62093 .57985 Mdot
.4509 .5945 Mdot
.48398 .36448 Mdot
.66391 .30698 Mdot
.36988 .56146 Mdot
.45826 .3082 Mdot
.31698 .45574 Mdot
.47716 .71064 Mdot
.47301 .57888 Mdot
.59355 .40943 Mdot
.40234 .56291 Mdot
.46283 .57793 Mdot
.39464 .61753 Mdot
.50852 .1861 Mdot
.46257 .33372 Mdot
.50527 .33125 Mdot
.32793 .37684 Mdot
.31199 .45317 Mdot
.35137 .40582 Mdot
.63353 .43717 Mdot
.39582 .29433 Mdot
.51512 .31577 Mdot
.6423 .58795 Mdot
.45129 .57105 Mdot
.46042 .32977 Mdot
.39188 .57651 Mdot
.42893 .57314 Mdot
.53475 .3647 Mdot
.46961 .32969 Mdot
.21604 .43876 Mdot
.35914 .37448 Mdot
.6176 .61601 Mdot
.41835 .64851 Mdot
.3675 .40491 Mdot
.46603 .56829 Mdot
.27185 .47517 Mdot
.62253 .61676 Mdot
.62297 .58111 Mdot
.67652 .63588 Mdot
.44046 .6264 Mdot
.43527 .57414 Mdot
.64447 .41503 Mdot
.63194 .6381 Mdot
.65083 .4048 Mdot
.54636 .49904 Mdot
.29581 .33936 Mdot
.44172 .62302 Mdot
.73829 .61243 Mdot
.36479 .39837 Mdot
.49186 .37536 Mdot
.74032 .70694 Mdot
.32819 .37659 Mdot
.41551 .60241 Mdot
.51267 .38087 Mdot
.32935 .4081 Mdot
.46684 .49824 Mdot
.65373 .7932 Mdot
.35362 .42823 Mdot
.39126 .62495 Mdot
.44957 .53621 Mdot
.29209 .2452 Mdot
.31785 .41758 Mdot
.66633 .4461 Mdot
.4378 .62718 Mdot
.61869 .64372 Mdot
.36359 .41024 Mdot
.5025 .25742 Mdot
.50949 .3383 Mdot
.33487 .53113 Mdot
.35708 .6327 Mdot
.52076 .62947 Mdot
.33158 .37653 Mdot
.65462 .60486 Mdot
.41848 .5204 Mdot
.39514 .56467 Mdot
.31639 .41606 Mdot
.70883 .41768 Mdot
.49415 .34007 Mdot
.6385 .30167 Mdot
.6022 .58687 Mdot
.69803 .36873 Mdot
.48694 .372 Mdot
.42438 .22635 Mdot
.71597 .67482 Mdot
.50564 .58622 Mdot
.39638 .20436 Mdot
.67895 .5036 Mdot
.37786 .6173 Mdot
.38145 .39976 Mdot
.69623 .43697 Mdot
.63803 .40122 Mdot
.66748 .42978 Mdot
.70893 .539 Mdot
.56854 .62082 Mdot
.44849 .35407 Mdot
.6603 .37948 Mdot
.35102 .37642 Mdot
.3165 .51849 Mdot
.40792 .5532 Mdot
.44798 .58265 Mdot
.40631 .64445 Mdot
.38739 .60083 Mdot
.42787 .56016 Mdot
.67435 .41272 Mdot
.71229 .52384 Mdot
.58582 .63912 Mdot
.63048 .61778 Mdot
.43606 .30893 Mdot
.50182 .36529 Mdot
.50383 .3918 Mdot
.34162 .41339 Mdot
.57579 .3271 Mdot
.45519 .33013 Mdot
.48344 .35227 Mdot
.42371 .65416 Mdot
.63077 .58457 Mdot
.50409 .57002 Mdot
.39127 .62128 Mdot
.4656 .35315 Mdot
.47717 .45717 Mdot
.46606 .80124 Mdot
.25059 .38911 Mdot
.33573 .36037 Mdot
.62683 .3865 Mdot
.31343 .39313 Mdot
.40787 .54758 Mdot
.81973 .46261 Mdot
.51456 .3676 Mdot
.49666 .3486 Mdot
.36127 .379 Mdot
.73553 .30028 Mdot
.64341 .6274 Mdot
.70049 .366 Mdot
.6534 .45131 Mdot
.44351 .63536 Mdot
.75224 .67134 Mdot
.54538 .59295 Mdot
.38161 .28491 Mdot
.66615 .43462 Mdot
.51174 .32321 Mdot
.38315 .55746 Mdot
.39205 .60984 Mdot
.35762 .40592 Mdot
.2015 .58364 Mdot
.48975 .63005 Mdot
.16518 .61109 Mdot
.69385 .74894 Mdot
.35473 .74773 Mdot
.39821 .56119 Mdot
.61784 .58145 Mdot
.45748 .35073 Mdot
.34538 .37865 Mdot
.48515 .58857 Mdot
.44045 .81743 Mdot
.65764 .59904 Mdot
.65215 .43566 Mdot
.51477 .45854 Mdot
.3022 .52086 Mdot
.44636 .56205 Mdot
.46512 .61199 Mdot
.45948 .57218 Mdot
.86783 .59895 Mdot
.52857 .33459 Mdot
.60161 .60751 Mdot
.32216 .40144 Mdot
.63071 .5938 Mdot
.51628 .32854 Mdot
.41112 .42243 Mdot
.41368 .63637 Mdot
.6366 .57252 Mdot
.65408 .60934 Mdot
.64389 .40131 Mdot
.65512 .45717 Mdot
.53126 .47539 Mdot
.42344 .61963 Mdot
.53019 .32294 Mdot
.66117 .62247 Mdot
.60623 .39782 Mdot
.34544 .40156 Mdot
.63181 .43031 Mdot
.3923 .59775 Mdot
.51788 .31879 Mdot
.42249 .66025 Mdot
.62401 .62893 Mdot
.4847 .35261 Mdot
.21408 .42768 Mdot
.31554 .39905 Mdot
.45639 .61593 Mdot
.27163 .38267 Mdot
.48036 .33389 Mdot
.43922 .56906 Mdot
.36604 .24244 Mdot
.38755 .39636 Mdot
.63768 .33569 Mdot
.50171 .38431 Mdot
.72596 .42041 Mdot
.59609 .60088 Mdot
.73442 .37794 Mdot
.48805 .34642 Mdot
.45263 .22671 Mdot
.19855 .46708 Mdot
.36567 .61284 Mdot
.6332 .60346 Mdot
.72435 .43459 Mdot
.35821 .80877 Mdot
.31429 .25576 Mdot
.42875 .59517 Mdot
.53214 .3303 Mdot
.33726 .41064 Mdot
.61903 .41754 Mdot
.66731 .34276 Mdot
.35672 .44109 Mdot
.51127 .30321 Mdot
.39513 .61692 Mdot
.64794 .58631 Mdot
.64706 .41987 Mdot
.73421 .52744 Mdot
.49797 .36704 Mdot
.47713 .36374 Mdot
.44751 .54745 Mdot
.36408 .39384 Mdot
.59284 .21953 Mdot
.47399 .33829 Mdot
.63177 .78098 Mdot
.52517 .38788 Mdot
.37291 .38748 Mdot
.40412 .56931 Mdot
.37185 .5076 Mdot
.48247 .59398 Mdot
.30685 .28108 Mdot
.50952 .36314 Mdot
.61854 .62165 Mdot
.39235 .56 Mdot
.66348 .73635 Mdot
.46641 .36197 Mdot
.60408 .38828 Mdot
.54423 .29274 Mdot
.64314 .44601 Mdot
.74118 .70496 Mdot
.44089 .61656 Mdot
.6884 .41045 Mdot
.35163 .40835 Mdot
.41591 .6202 Mdot
.43205 .57054 Mdot
.6494 .57791 Mdot
.63842 .40339 Mdot
.2195 .43183 Mdot
.68512 .42937 Mdot
.66991 .44125 Mdot
.60499 .64262 Mdot
.45666 .60218 Mdot
.47491 .34856 Mdot
.5141 .34491 Mdot
.3735 .62123 Mdot
.65217 .18745 Mdot
.64969 .62267 Mdot
.47133 .38818 Mdot
.8818 .56943 Mdot
.37862 .63104 Mdot
.72703 .70511 Mdot
.19533 .56606 Mdot
.67736 .45009 Mdot
.39122 .62628 Mdot
.6368 .57624 Mdot
.56889 .3348 Mdot
.47423 .36137 Mdot
.37098 .61474 Mdot
.64973 .41995 Mdot
.35739 .37206 Mdot
.46903 .37641 Mdot
.38892 .28433 Mdot
.47192 .58586 Mdot
.33743 .29048 Mdot
.53588 .35445 Mdot
.2926 .72401 Mdot
.5815 .27307 Mdot
.62994 .60521 Mdot
.42564 .57217 Mdot
.61599 .63041 Mdot
.32449 .40922 Mdot
.51783 .46059 Mdot
.63741 .42641 Mdot
.31989 .6226 Mdot
.8234 .48773 Mdot
.46179 .37393 Mdot
.60343 .61647 Mdot
.45947 .63345 Mdot
.74216 .37524 Mdot
.44622 .61373 Mdot
.336 .60318 Mdot
.22725 .42268 Mdot
.62906 .4165 Mdot
.66395 .4522 Mdot
.4169 .56265 Mdot
.33758 .41924 Mdot
.50383 .36621 Mdot
.48177 .3412 Mdot
.26157 .7137 Mdot
.70321 .36974 Mdot
.58459 .79576 Mdot
.47262 .60062 Mdot
.52899 .31508 Mdot
.71427 .37132 Mdot
.67361 .40641 Mdot
.49729 .59008 Mdot
.5144 .37893 Mdot
.28887 .41563 Mdot
.4374 .49162 Mdot
.39938 .56279 Mdot
.44566 .54071 Mdot
.66713 .44945 Mdot
.60692 .64688 Mdot
.49871 .32572 Mdot
.44125 .66062 Mdot
.41777 .40316 Mdot
.46164 .49527 Mdot
.69271 .75771 Mdot
.61757 .61574 Mdot
.41171 .26439 Mdot
.67329 .4112 Mdot
.34865 .59993 Mdot
.31867 .40181 Mdot
.5341 .31151 Mdot
.50311 .3166 Mdot
.40603 .60779 Mdot
.37924 .56215 Mdot
.67536 .75092 Mdot
.63767 .58778 Mdot
.65611 .44244 Mdot
.41948 .63057 Mdot
.76479 .55475 Mdot
.38184 .61728 Mdot
.64628 .41165 Mdot
.79244 .33033 Mdot
.47273 .56503 Mdot
.45281 .61196 Mdot
.5895 .21972 Mdot
.59113 .59799 Mdot
.66245 .62893 Mdot
.77782 .65979 Mdot
.47171 .60234 Mdot
.70655 .73774 Mdot
.61294 .61724 Mdot
.64173 .63132 Mdot
.644 .278 Mdot
.44508 .58217 Mdot
.54022 .562 Mdot
.63705 .44823 Mdot
.67101 .44165 Mdot
.61309 .58486 Mdot
.50392 .6064 Mdot
.63576 .45275 Mdot
.55236 .19106 Mdot
.51276 .35308 Mdot
.7923 .40293 Mdot
.6537 .61961 Mdot
.65455 .49762 Mdot
.67872 .42753 Mdot
.63844 .80676 Mdot
.61259 .36384 Mdot
.40795 .63232 Mdot
.47278 .5982 Mdot
.35923 .37876 Mdot
.43171 .64771 Mdot
.50589 .38817 Mdot
.67303 .42343 Mdot
.42861 .78987 Mdot
.62297 .614 Mdot
.43148 .61291 Mdot
.35813 .25877 Mdot
.18733 .4458 Mdot
.45388 .25887 Mdot
.65595 .59976 Mdot
.61877 .60221 Mdot
.52265 .32675 Mdot
.53516 .33907 Mdot
.45849 .58624 Mdot
.61745 .43079 Mdot
.6244 .63508 Mdot
.63769 .41439 Mdot
.5122 .3693 Mdot
.47804 .34898 Mdot
.45777 .34055 Mdot
.39659 .55596 Mdot
.47893 .35629 Mdot
.25137 .37075 Mdot
.64181 .36905 Mdot
.60343 .63922 Mdot
.80652 .65814 Mdot
.73523 .53313 Mdot
.52899 .62159 Mdot
.37462 .39371 Mdot
.46139 .34956 Mdot
.6898 .41831 Mdot
.41167 .57986 Mdot
.39658 .58647 Mdot
.70987 .33211 Mdot
.68561 .41037 Mdot
.32299 .4024 Mdot
.69377 .43031 Mdot
.3218 .40008 Mdot
.35196 .28636 Mdot
.39605 .64373 Mdot
.36795 .58397 Mdot
.67683 .42195 Mdot
.48127 .35437 Mdot
.50766 .33432 Mdot
.33861 .428 Mdot
.46629 .45869 Mdot
.48387 .38166 Mdot
.64656 .63037 Mdot
.36756 .74199 Mdot
.53158 .36172 Mdot
.43147 .6219 Mdot
.2667 .49354 Mdot
.66375 .21684 Mdot
.37492 .55205 Mdot
.65083 .27468 Mdot
.46087 .76962 Mdot
.38605 .56635 Mdot
.6714 .22207 Mdot
.68611 .39958 Mdot
.6029 .59327 Mdot
.46703 .33933 Mdot
.50017 .3994 Mdot
.52709 .59422 Mdot
.35921 .36228 Mdot
.48007 .56701 Mdot
.63459 .57169 Mdot
.6381 .56761 Mdot
.36266 .50498 Mdot
.31469 .26441 Mdot
.33082 .40746 Mdot
.34518 .41208 Mdot
.48522 .34495 Mdot
.15114 .52882 Mdot
.33632 .63533 Mdot
.32467 .39696 Mdot
.68339 .59457 Mdot
.3983 .61302 Mdot
.29103 .42834 Mdot
.62574 .54392 Mdot
.61008 .5849 Mdot
.3574 .48231 Mdot
.46753 .35701 Mdot
.62028 .59215 Mdot
.77668 .51238 Mdot
.49053 .61026 Mdot
.62397 .61609 Mdot
.63977 .41511 Mdot
.58114 .29475 Mdot
.65273 .62692 Mdot
.27221 .4874 Mdot
.6123 .43632 Mdot
.60647 .39859 Mdot
.41707 .49377 Mdot
.11772 .4238 Mdot
.6747 .41747 Mdot
.51828 .37505 Mdot
.51305 .34446 Mdot
.48131 .34165 Mdot
.63228 .59247 Mdot
.4614 .37385 Mdot
.63917 .58996 Mdot
.34997 .21573 Mdot
.69527 .25573 Mdot
.32854 .3927 Mdot
.63554 .30088 Mdot
.64869 .59444 Mdot
.75411 .62418 Mdot
.53181 .11996 Mdot
.39356 .63125 Mdot
.62788 .40482 Mdot
.3294 .39361 Mdot
.16327 .56433 Mdot
.3349 .40349 Mdot
.47595 .83058 Mdot
.46782 .6944 Mdot
.43853 .60828 Mdot
.58838 .76403 Mdot
.34879 .42596 Mdot
.59063 .57741 Mdot
.43931 .56975 Mdot
.50834 .49133 Mdot
.34034 .4083 Mdot
.36943 .37887 Mdot
.45653 .59143 Mdot
.61434 .62606 Mdot
.47318 .36554 Mdot
.67938 .43617 Mdot
.35582 .41677 Mdot
.40153 .52571 Mdot
.47179 .62006 Mdot
.40707 .63509 Mdot
.73578 .62194 Mdot
.38637 .38423 Mdot
.67099 .42128 Mdot
.45815 .16614 Mdot
.54344 .35018 Mdot
.44588 .47217 Mdot
.66296 .77116 Mdot
.67495 .53379 Mdot
.50977 .3623 Mdot
.50606 .32821 Mdot
.4297 .56044 Mdot
.36043 .69345 Mdot
.47004 .68229 Mdot
.41855 .44535 Mdot
.45487 .37231 Mdot
.4877 .34007 Mdot
.65968 .63666 Mdot
.31888 .68567 Mdot
.36571 .55728 Mdot
.66061 .4554 Mdot
.48857 .32009 Mdot
.68749 .26044 Mdot
.36133 .38358 Mdot
.49489 .69254 Mdot
.40105 .64688 Mdot
.4109 .63267 Mdot
.65039 .42395 Mdot
.64623 .41564 Mdot
.55809 .30595 Mdot
.37645 .7691 Mdot
.44926 .76814 Mdot
.71555 .51135 Mdot
.46358 .71467 Mdot
.66793 .61697 Mdot
.60327 .61253 Mdot
.6271 .32491 Mdot
.68394 .41756 Mdot
.38533 .56551 Mdot
.6179 .59667 Mdot
.30037 .43292 Mdot
.32356 .6001 Mdot
.32441 .57225 Mdot
.71138 .71958 Mdot
.42205 .59246 Mdot
.62322 .5757 Mdot
.58883 .60059 Mdot
.58456 .60686 Mdot
.68581 .47278 Mdot
.46357 .59422 Mdot
.4257 .59251 Mdot
.40557 .55685 Mdot
.74199 .33584 Mdot
.46541 .58534 Mdot
.70347 .46772 Mdot
.53517 .46208 Mdot
.59788 .67748 Mdot
.44891 .65835 Mdot
.6942 .4223 Mdot
.45346 .56158 Mdot
.33562 .41932 Mdot
.40736 .64065 Mdot
.32095 .58312 Mdot
.66423 .43884 Mdot
.4884 .5393 Mdot
.72364 .54262 Mdot
.37772 .59722 Mdot
.37807 .38926 Mdot
.69424 .55785 Mdot
.33884 .77396 Mdot
.30936 .36944 Mdot
.64683 .62901 Mdot
.51056 .35776 Mdot
.68845 .41363 Mdot
.48753 .34927 Mdot
.3692 .60416 Mdot
.61498 .32343 Mdot
.1701 .56584 Mdot
.50185 .48165 Mdot
.3904 .59697 Mdot
.33868 .6248 Mdot
.63981 .63386 Mdot
.53472 .36583 Mdot
.65959 .57324 Mdot
.43833 .55944 Mdot
.3426 .38734 Mdot
.35441 .40671 Mdot
.56858 .50707 Mdot
.25241 .65879 Mdot
.62232 .22194 Mdot
.65637 .42205 Mdot
.47007 .34087 Mdot
.31693 .40515 Mdot
.47579 .23017 Mdot
.70569 .4087 Mdot
.62309 .43088 Mdot
.65865 .44039 Mdot
.44816 .62634 Mdot
.47069 .32791 Mdot
.6028 .67919 Mdot
.54672 .34436 Mdot
.43497 .58192 Mdot
.52751 .35625 Mdot
.49729 .38093 Mdot
.34597 .3816 Mdot
.6601 .44171 Mdot
.51286 .36719 Mdot
.45283 .63091 Mdot
.60983 .61438 Mdot
.68405 .46442 Mdot
.23057 .44606 Mdot
.31614 .26723 Mdot
.56888 .5467 Mdot
.59169 .59333 Mdot
.32307 .75349 Mdot
.63343 .44836 Mdot
.75557 .37085 Mdot
.2136 .44359 Mdot
.45084 .55112 Mdot
.67488 .20342 Mdot
.55521 .34773 Mdot
.49259 .37918 Mdot
.40347 .56785 Mdot
.55605 .32411 Mdot
.43633 .61216 Mdot
.50403 .37425 Mdot
.64312 .35949 Mdot
.57561 .61827 Mdot
.48502 .35782 Mdot
.41672 .66305 Mdot
.42865 .56621 Mdot
.61877 .58241 Mdot
.52161 .31767 Mdot
.47245 .56184 Mdot
.29614 .7693 Mdot
.65241 .41222 Mdot
.68071 .53095 Mdot
.25402 .4942 Mdot
.67087 .40845 Mdot
.62931 .61136 Mdot
.42209 .55282 Mdot
.34948 .40929 Mdot
.64721 .59025 Mdot
.31525 .61178 Mdot
.32385 .38492 Mdot
.78476 .35971 Mdot
.58846 .59973 Mdot
.48397 .37467 Mdot
.32521 .41563 Mdot
.47362 .62787 Mdot
.54322 .35928 Mdot
.55518 .26592 Mdot
.50519 .36327 Mdot
.42174 .55732 Mdot
.67435 .32964 Mdot
.65668 .44327 Mdot
.42621 .59919 Mdot
.47981 .37687 Mdot
.65228 .27716 Mdot
.46246 .61789 Mdot
.41193 .56087 Mdot
.64501 .78257 Mdot
.67779 .67141 Mdot
.33964 .40194 Mdot
.61592 .63521 Mdot
.39209 .62751 Mdot
.37084 .39563 Mdot
.38101 .34056 Mdot
.43168 .63259 Mdot
.6575 .59786 Mdot
.49746 .58753 Mdot
.52998 .32767 Mdot
.65513 .4061 Mdot
.41804 .45311 Mdot
.37058 .38566 Mdot
.18428 .35462 Mdot
.49642 .31996 Mdot
.41452 .55053 Mdot
.38294 .61625 Mdot
.24829 .55166 Mdot
.60838 .59129 Mdot
.66015 .55725 Mdot
.45774 .61518 Mdot
.7462 .33673 Mdot
.41943 .61547 Mdot
.55421 .32658 Mdot
.6433 .62811 Mdot
.4622 .60569 Mdot
.65062 .46925 Mdot
.35433 .58385 Mdot
.34388 .37193 Mdot
.56612 .22926 Mdot
.49176 .59643 Mdot
.78766 .34001 Mdot
.55268 .51844 Mdot
.48375 .35899 Mdot
.27066 .34245 Mdot
.29008 .76777 Mdot
.71227 .54594 Mdot
.63276 .59512 Mdot
.18759 .56698 Mdot
.47467 .34896 Mdot
.31657 .29432 Mdot
.34657 .79296 Mdot
.4203 .567 Mdot
.44344 .56069 Mdot
.28619 .53654 Mdot
.54023 .36171 Mdot
.53876 .33321 Mdot
.36636 .62401 Mdot
.3559 .5773 Mdot
.47518 .35332 Mdot
.47988 .58348 Mdot
.46132 .65574 Mdot
.63098 .4037 Mdot
.65876 .60687 Mdot
.62621 .41759 Mdot
.62415 .4436 Mdot
.5295 .2098 Mdot
.52818 .51049 Mdot
.6498 .41025 Mdot
.68434 .44745 Mdot
.32582 .45711 Mdot
.41943 .79017 Mdot
.35383 .41573 Mdot
.27078 .70062 Mdot
.4935 .34128 Mdot
.46063 .60184 Mdot
.58743 .61136 Mdot
.43046 .75943 Mdot
.38193 .3499 Mdot
.81071 .52452 Mdot
.40318 .55615 Mdot
.46784 .36338 Mdot
.66587 .51804 Mdot
.49008 .55517 Mdot
.44537 .35554 Mdot
.42509 .62889 Mdot
.51202 .3872 Mdot
.47771 .81173 Mdot
.45674 .22825 Mdot
.49293 .39881 Mdot
.6232 .64489 Mdot
.41296 .62974 Mdot
.61341 .56689 Mdot
.67357 .40715 Mdot
.34479 .41909 Mdot
.34455 .40402 Mdot
.44887 .57863 Mdot
.34824 .65883 Mdot
.33313 .30392 Mdot
.44023 .57568 Mdot
.39899 .60961 Mdot
.64107 .39244 Mdot
.39423 .6157 Mdot
.38149 .60915 Mdot
.38862 .57662 Mdot
.37838 .58339 Mdot
.66949 .44195 Mdot
.57347 .3212 Mdot
.51539 .61488 Mdot
.3912 .66542 Mdot
.62056 .44908 Mdot
.19788 .5475 Mdot
.63323 .45078 Mdot
.35917 .80282 Mdot
.67287 .4507 Mdot
.34604 .3976 Mdot
.21045 .55746 Mdot
.37327 .65647 Mdot
.66114 .59686 Mdot
.60386 .47518 Mdot
.32765 .41431 Mdot
.67058 .42757 Mdot
.50815 .37547 Mdot
.6583 .78002 Mdot
.56853 .58007 Mdot
.6443 .66586 Mdot
.68244 .55309 Mdot
.57748 .31537 Mdot
.52114 .3236 Mdot
.58664 .58446 Mdot
.51656 .80352 Mdot
.38435 .60522 Mdot
.37052 .39716 Mdot
.45651 .5846 Mdot
.67391 .40503 Mdot
.46871 .35099 Mdot
.3321 .2357 Mdot
.35859 .40522 Mdot
.78781 .68191 Mdot
.51234 .33635 Mdot
.3873 .59493 Mdot
.63597 .4527 Mdot
.83674 .59335 Mdot
.62803 .41832 Mdot
.40352 .69223 Mdot
.59888 .60313 Mdot
.27021 .27007 Mdot
.64483 .59908 Mdot
.52893 .25465 Mdot
.87792 .46166 Mdot
.43543 .239 Mdot
.60882 .61798 Mdot
.40696 .42149 Mdot
.41222 .60497 Mdot
.4083 .6357 Mdot
.40215 .21797 Mdot
.60358 .62873 Mdot
.38796 .60983 Mdot
.71116 .34787 Mdot
.70015 .3731 Mdot
.71626 .69832 Mdot
.52182 .32836 Mdot
.4362 .61567 Mdot
.63282 .39896 Mdot
.6753 .39893 Mdot
.48846 .32717 Mdot
.62428 .43653 Mdot
.42838 .5905 Mdot
.64836 .59519 Mdot
.4461 .32819 Mdot
.35673 .39546 Mdot
.16182 .5173 Mdot
.31939 .37707 Mdot
.51117 .36171 Mdot
.44581 .54277 Mdot
.47905 .3492 Mdot
.46441 .89996 Mdot
.4178 .60366 Mdot
.61379 .61867 Mdot
.3945 .60917 Mdot
.41004 .62669 Mdot
.37998 .57332 Mdot
.47583 .36564 Mdot
.23683 .40729 Mdot
.46179 .62177 Mdot
.63534 .42871 Mdot
.51709 .71012 Mdot
.45688 .64314 Mdot
.42518 .34265 Mdot
.33538 .54884 Mdot
.72644 .60172 Mdot
.59612 .6156 Mdot
.49082 .36109 Mdot
.61952 .61163 Mdot
.76247 .35088 Mdot
.6296 .61149 Mdot
.48791 .73498 Mdot
.52998 .80516 Mdot
.61251 .77246 Mdot
.63161 .76216 Mdot
.45324 .42774 Mdot
.60987 .63278 Mdot
.33266 .35439 Mdot
.6263 .63537 Mdot
.60573 .58847 Mdot
.59578 .1189 Mdot
.63139 .56881 Mdot
.43911 .6218 Mdot
.4266 .65238 Mdot
.47751 .24251 Mdot
.27123 .45053 Mdot
.40588 .59308 Mdot
.39883 .59576 Mdot
.318 .40916 Mdot
.76059 .35582 Mdot
.62466 .33602 Mdot
.68322 .66957 Mdot
.19673 .44003 Mdot
.45648 .58739 Mdot
.40141 .63851 Mdot
.44724 .66521 Mdot
.84342 .51942 Mdot
.49633 .20063 Mdot
.63593 .64912 Mdot
.38302 .65832 Mdot
.37597 .2486 Mdot
.39932 .55683 Mdot
.4602 .6169 Mdot
.41856 .59705 Mdot
.47379 .34921 Mdot
.60296 .62503 Mdot
.37069 .60903 Mdot
.23781 .55636 Mdot
.44535 .62395 Mdot
.67072 .50598 Mdot
.17655 .39197 Mdot
.44194 .61675 Mdot
.67154 .62267 Mdot
.4051 .63446 Mdot
.61871 .58755 Mdot
.60814 .57629 Mdot
.36764 .63537 Mdot
.45702 .71279 Mdot
.65997 .63773 Mdot
.43506 .58114 Mdot
.51228 .37605 Mdot
.28528 .70666 Mdot
.43302 .56048 Mdot
.3556 .41449 Mdot
.47089 .60257 Mdot
.37062 .37204 Mdot
.40438 .60226 Mdot
.49104 .32184 Mdot
.4276 .74802 Mdot
.49505 .34734 Mdot
.41759 .19903 Mdot
.46246 .33484 Mdot
.76194 .70943 Mdot
.59332 .59054 Mdot
.65593 .31629 Mdot
.80009 .43801 Mdot
.72669 .35833 Mdot
.57853 .42532 Mdot
.49135 .43463 Mdot
.61805 .43011 Mdot
.60614 .59552 Mdot
.76969 .43639 Mdot
.42564 .31973 Mdot
.44154 .2824 Mdot
.47535 .38137 Mdot
.42121 .15652 Mdot
.77829 .35455 Mdot
.40447 .54748 Mdot
.54358 .77787 Mdot
.56864 .73806 Mdot
.39067 .56019 Mdot
.37679 .57387 Mdot
.54221 .38042 Mdot
.47755 .60249 Mdot
.76325 .56245 Mdot
.52086 .35398 Mdot
.33155 .4164 Mdot
.62838 .63264 Mdot
.35635 .37149 Mdot
.40371 .37508 Mdot
.49671 .43242 Mdot
.50953 .37273 Mdot
.47681 .56805 Mdot
.40678 .58669 Mdot
.62536 .58499 Mdot
.50403 .6565 Mdot
.65916 .6275 Mdot
.3285 .39807 Mdot
.52297 .34459 Mdot
.62735 .1996 Mdot
.40377 .58762 Mdot
.65146 .61372 Mdot
.57626 .44758 Mdot
.39074 .62267 Mdot
.67758 .41538 Mdot
.40897 .61063 Mdot
.61997 .63007 Mdot
.39438 .61527 Mdot
.64361 .59852 Mdot
.51037 .35626 Mdot
.3865 .58556 Mdot
.39878 .56846 Mdot
.79598 .66154 Mdot
.33556 .38846 Mdot
.58358 .5863 Mdot
.40734 .46617 Mdot
.39185 .63453 Mdot
.62485 .28219 Mdot
.42851 .62668 Mdot
.65266 .65771 Mdot
.41525 .54386 Mdot
.68055 .53258 Mdot
.3663 .63844 Mdot
.4541 .57707 Mdot
.6064 .51999 Mdot
.55528 .73811 Mdot
.55043 .56932 Mdot
.69693 .4324 Mdot
.58377 .58333 Mdot
.69886 .7045 Mdot
.49005 .29488 Mdot
.52174 .3154 Mdot
.32743 .49211 Mdot
.371 .62126 Mdot
.44143 .6086 Mdot
.72309 .61129 Mdot
.36861 .3926 Mdot
.64847 .58406 Mdot
.32198 .39937 Mdot
.74203 .71099 Mdot
.32367 .38098 Mdot
.55319 .3223 Mdot
.33418 .29252 Mdot
.59259 .19188 Mdot
.31742 .40336 Mdot
.62162 .63172 Mdot
.38816 .25282 Mdot
.37891 .6084 Mdot
.56723 .52047 Mdot
.34903 .38889 Mdot
.32917 .20121 Mdot
.38226 .6066 Mdot
.57948 .43013 Mdot
.64356 .40883 Mdot
.31812 .40354 Mdot
.61051 .43572 Mdot
.41427 .5737 Mdot
.62764 .3373 Mdot
.63275 .59625 Mdot
.6114 .44758 Mdot
.4803 .62851 Mdot
.32632 .39637 Mdot
.49263 .31851 Mdot
.61969 .46386 Mdot
.67268 .45319 Mdot
.22259 .61229 Mdot
.31134 .2432 Mdot
.52208 .34129 Mdot
.72668 .67118 Mdot
.69401 .42564 Mdot
.37778 .62087 Mdot
.76649 .38998 Mdot
.40958 .63344 Mdot
.65591 .24864 Mdot
.49766 .36493 Mdot
.57705 .32002 Mdot
.3928 .62794 Mdot
.44304 .56403 Mdot
.63468 .56532 Mdot
.50481 .34584 Mdot
.64177 .61458 Mdot
.58155 .62336 Mdot
.51249 .35465 Mdot
.63486 .6045 Mdot
.328 .4236 Mdot
.7894 .48833 Mdot
.65744 .45168 Mdot
.63798 .43823 Mdot
.48165 .34093 Mdot
.48392 .36199 Mdot
.48423 .35166 Mdot
.40827 .61146 Mdot
.6548 .61452 Mdot
.42225 .57645 Mdot
.47183 .57649 Mdot
.53586 .69934 Mdot
.59489 .61801 Mdot
.42411 .58472 Mdot
.47818 .47905 Mdot
.39631 .68125 Mdot
.52321 .36974 Mdot
.64908 .40911 Mdot
.69425 .32704 Mdot
.56534 .26501 Mdot
.43242 .61682 Mdot
.25836 .39484 Mdot
.62507 .63408 Mdot
.33898 .40956 Mdot
.31589 .38527 Mdot
.33578 .402 Mdot
.68076 .38619 Mdot
.58485 .60634 Mdot
.60107 .66324 Mdot
.43865 .61335 Mdot
.64154 .66056 Mdot
.64813 .65093 Mdot
.37872 .26243 Mdot
.65279 .40968 Mdot
.3925 .60958 Mdot
.42825 .45569 Mdot
.42365 .77515 Mdot
.40526 .62839 Mdot
.44944 .64737 Mdot
.23428 .38966 Mdot
.41243 .52957 Mdot
.66328 .59323 Mdot
.82535 .61411 Mdot
.46064 .63758 Mdot
.67948 .25043 Mdot
.15299 .57771 Mdot
.4245 .62204 Mdot
.4535 .56991 Mdot
.40257 .58099 Mdot
.4117 .64189 Mdot
.66823 .63287 Mdot
.29407 .45141 Mdot
.69599 .42663 Mdot
.60806 .65131 Mdot
.68219 .41667 Mdot
.45607 .36873 Mdot
.57715 .32342 Mdot
.60143 .5999 Mdot
.36035 .3796 Mdot
.18484 .43335 Mdot
.79188 .61774 Mdot
.49797 .32608 Mdot
.56994 .19566 Mdot
.34755 .3909 Mdot
.39991 .65097 Mdot
.35766 .41945 Mdot
.52903 .33312 Mdot
.6408 .44427 Mdot
.49336 .58786 Mdot
.60521 .61611 Mdot
.65427 .62428 Mdot
.38956 .61436 Mdot
.32179 .28241 Mdot
.66242 .40406 Mdot
.70124 .42954 Mdot
.44212 .63003 Mdot
.46815 .63323 Mdot
.64072 .61267 Mdot
.4921 .33585 Mdot
.63191 .76882 Mdot
.35236 .41102 Mdot
.39697 .55607 Mdot
.39427 .62016 Mdot
.64724 .77984 Mdot
.63246 .43072 Mdot
.48527 .31573 Mdot
.44083 .54521 Mdot
.7087 .49507 Mdot
.45628 .55542 Mdot
.43458 .6664 Mdot
.51655 .37481 Mdot
.51749 .59702 Mdot
.36578 .58372 Mdot
.57244 .60812 Mdot
.61744 .42388 Mdot
.61977 .61804 Mdot
.5714 .60533 Mdot
.79182 .52085 Mdot
.67796 .42477 Mdot
.41541 .59786 Mdot
.66192 .41073 Mdot
.43005 .6331 Mdot
.45217 .6389 Mdot
.64641 .41139 Mdot
.64249 .61339 Mdot
.1882 .55212 Mdot
.51537 .26172 Mdot
.42893 .64421 Mdot
.3659 .61171 Mdot
.27613 .42951 Mdot
.39295 .41953 Mdot
.43855 .5592 Mdot
.63893 .63647 Mdot
.40949 .57519 Mdot
.63751 .40451 Mdot
.34368 .42612 Mdot
.60953 .61671 Mdot
.50586 .33214 Mdot
.50279 .32234 Mdot
.72103 .54653 Mdot
.49814 .3829 Mdot
.44539 .56043 Mdot
.53564 .61366 Mdot
.66169 .58254 Mdot
.20328 .39104 Mdot
.51492 .35083 Mdot
.36434 .40995 Mdot
.41839 .56021 Mdot
.3271 .53413 Mdot
.62558 .40276 Mdot
.59717 .14011 Mdot
.78019 .59495 Mdot
.37172 .41256 Mdot
.61643 .66503 Mdot
.47402 .32865 Mdot
.36872 .60286 Mdot
.35672 .41331 Mdot
.52213 .32607 Mdot
.434 .63929 Mdot
.39105 .66387 Mdot
.48073 .66425 Mdot
.49538 .41924 Mdot
.65937 .41217 Mdot
.49402 .38678 Mdot
.3793 .39779 Mdot
.45853 .37942 Mdot
.60256 .58073 Mdot
.46482 .59046 Mdot
.44913 .54598 Mdot
.49281 .33433 Mdot
.51618 .31063 Mdot
.42977 .58247 Mdot
.61051 .62597 Mdot
.48955 .26788 Mdot
.45421 .59165 Mdot
.70868 .38258 Mdot
.63074 .6443 Mdot
.52352 .33463 Mdot
.45243 .57255 Mdot
.3181 .36884 Mdot
.50687 .33624 Mdot
.52481 .36737 Mdot
.3999 .63787 Mdot
.316 .40426 Mdot
.36049 .58264 Mdot
.64663 .45124 Mdot
.41244 .16459 Mdot
.63796 .40399 Mdot
.46996 .29943 Mdot
.38594 .53641 Mdot
.73532 .44872 Mdot
.59318 .60553 Mdot
.37747 .49464 Mdot
.71005 .3465 Mdot
.46836 .65147 Mdot
.27822 .66046 Mdot
.65251 .49683 Mdot
.22974 .36487 Mdot
.29492 .6426 Mdot
.34949 .38471 Mdot
.66846 .4298 Mdot
.45347 .56965 Mdot
.62194 .40777 Mdot
.36318 .40907 Mdot
.42408 .19918 Mdot
.431 .55895 Mdot
.64087 .6312 Mdot
.42695 .58841 Mdot
.65053 .62395 Mdot
.41997 .64532 Mdot
.36899 .56707 Mdot
.72148 .35376 Mdot
.43185 .48688 Mdot
.45274 .5532 Mdot
.86927 .58807 Mdot
.43489 .68375 Mdot
.34081 .41495 Mdot
.42414 .56966 Mdot
.46307 .39646 Mdot
.68277 .40823 Mdot
.71416 .45198 Mdot
.47203 .351 Mdot
.65938 .45493 Mdot
.63739 .60831 Mdot
.49916 .36224 Mdot
.49291 .32721 Mdot
.51679 .59279 Mdot
.36225 .42142 Mdot
.64785 .4361 Mdot
.46483 .60318 Mdot
.43719 .56182 Mdot
.74049 .66476 Mdot
.41442 .32168 Mdot
.52537 .66022 Mdot
.84204 .44943 Mdot
.57936 .6089 Mdot
.32629 .41018 Mdot
.47219 .36392 Mdot
.46149 .56649 Mdot
.43041 .5953 Mdot
.63766 .29434 Mdot
.65703 .63615 Mdot
.51583 .4646 Mdot
.51898 .66652 Mdot
.3002 .43171 Mdot
.36372 .47239 Mdot
.63064 .63405 Mdot
.35241 .46946 Mdot
.38665 .39148 Mdot
.22472 .67008 Mdot
.43382 .48378 Mdot
.64732 .40771 Mdot
.33025 .462 Mdot
.64811 .58458 Mdot
.45351 .62843 Mdot
.50904 .37798 Mdot
.49955 .38138 Mdot
.62885 .62028 Mdot
.44756 .36287 Mdot
.35111 .38116 Mdot
.46653 .57927 Mdot
.75498 .63081 Mdot
.75258 .51419 Mdot
.47285 .34186 Mdot
.51123 .58606 Mdot
.66067 .44039 Mdot
.38908 .61602 Mdot
.33072 .38393 Mdot
.67149 .41382 Mdot
.42697 .80077 Mdot
.68855 .3594 Mdot
.43127 .56357 Mdot
.65262 .7795 Mdot
.6758 .42535 Mdot
.35291 .69962 Mdot
.45797 .5983 Mdot
.63225 .44494 Mdot
.40516 .51789 Mdot
.57523 .28934 Mdot
.5274 .49551 Mdot
.34877 .79635 Mdot
.55331 .48766 Mdot
.46727 .36727 Mdot
.5768 .30346 Mdot
.71442 .32425 Mdot
.68923 .42971 Mdot
.49367 .3082 Mdot
.52666 .51267 Mdot
.61168 .43384 Mdot
.38979 .6442 Mdot
.42355 .62643 Mdot
.48779 .20128 Mdot
.61318 .4835 Mdot
.51362 .24731 Mdot
.72724 .57132 Mdot
.39136 .63527 Mdot
.38727 .55484 Mdot
.43424 .5967 Mdot
.66954 .61225 Mdot
.65098 .41735 Mdot
.84591 .60449 Mdot
.67311 .40743 Mdot
.51009 .69556 Mdot
.48826 .3414 Mdot
.52295 .32941 Mdot
.43695 .61739 Mdot
.58169 .43498 Mdot
.34064 .72444 Mdot
.43185 .58737 Mdot
.36876 .42962 Mdot
.49473 .21385 Mdot
.44312 .64603 Mdot
.5978 .61164 Mdot
.49907 .62559 Mdot
.36949 .53984 Mdot
.6603 .45128 Mdot
.36078 .38508 Mdot
.35812 .5175 Mdot
.6443 .444 Mdot
.44075 .60736 Mdot
.7238 .47474 Mdot
.41047 .61982 Mdot
.42808 .64323 Mdot
.4935 .6813 Mdot
.31373 .39063 Mdot
.49704 .35431 Mdot
.33576 .39914 Mdot
.60526 .59104 Mdot
.51107 .08838 Mdot
.32585 .37874 Mdot
.38308 .77023 Mdot
.44816 .18703 Mdot
.33451 .46191 Mdot
.64686 .58133 Mdot
.3688 .41171 Mdot
.65307 .40483 Mdot
.28448 .70853 Mdot
.40113 .68675 Mdot
.63657 .48903 Mdot
.45169 .59617 Mdot
.56993 .58606 Mdot
.66138 .61762 Mdot
.61403 .44878 Mdot
.60194 .57666 Mdot
.53882 .56636 Mdot
.43969 .63963 Mdot
.6823 .43357 Mdot
.72399 .50998 Mdot
.69796 .42398 Mdot
.42062 .42508 Mdot
.43078 .57086 Mdot
.61304 .62145 Mdot
.37102 .57562 Mdot
.67995 .61244 Mdot
.47928 .31971 Mdot
.469 .55991 Mdot
.35109 .37995 Mdot
.7293 .45078 Mdot
.5209 .33711 Mdot
.3429 .45991 Mdot
.62297 .58552 Mdot
.67346 .38119 Mdot
.62045 .58124 Mdot
.66606 .58402 Mdot
.63466 .45183 Mdot
.62085 .57038 Mdot
.45748 .57295 Mdot
.52476 .50032 Mdot
.63018 .58961 Mdot
.65371 .42777 Mdot
.36239 .39328 Mdot
.6433 .60337 Mdot
.55744 .33167 Mdot
.42059 .55913 Mdot
.47716 .36422 Mdot
.40067 .39158 Mdot
.58007 .57492 Mdot
.31653 .4173 Mdot
.52811 .32143 Mdot
.36953 .37872 Mdot
.25083 .33449 Mdot
.65177 .46079 Mdot
.46677 .69771 Mdot
.38521 .41937 Mdot
.66251 .59837 Mdot
.21052 .45411 Mdot
.47531 .58446 Mdot
.41656 .55937 Mdot
.37227 .37485 Mdot
.6614 .61776 Mdot
.18537 .64204 Mdot
.35196 .67295 Mdot
.43013 .41436 Mdot
.67906 .39686 Mdot
.78217 .69366 Mdot
.42307 .41834 Mdot
.14962 .54067 Mdot
.50596 .59857 Mdot
.53894 .33051 Mdot
.42955 .61126 Mdot
.67944 .30438 Mdot
.33158 .39219 Mdot
.43019 .33522 Mdot
.39854 .54145 Mdot
.50118 .35766 Mdot
.39516 .57372 Mdot
.59649 .51898 Mdot
.32726 .64818 Mdot
.37459 .39558 Mdot
.34482 .27431 Mdot
.58639 .57263 Mdot
.35447 .39483 Mdot
.52821 .34165 Mdot
.43401 .49796 Mdot
.4349 .64004 Mdot
.38708 .64303 Mdot
.29838 .4286 Mdot
.65721 .60945 Mdot
.48139 .37506 Mdot
.64324 .44938 Mdot
.36494 .38753 Mdot
.40843 .58604 Mdot
.47164 .57459 Mdot
.63125 .27936 Mdot
.66815 .43935 Mdot
.53762 .36344 Mdot
.62838 .41354 Mdot
.47548 .33061 Mdot
.46214 .62349 Mdot
.51079 .32423 Mdot
.37571 .64161 Mdot
.67524 .48998 Mdot
.48419 .69081 Mdot
.55086 .74911 Mdot
.50389 .36533 Mdot
.44128 .80338 Mdot
.67052 .43689 Mdot
.6259 .42219 Mdot
.50561 .1858 Mdot
.42078 .6894 Mdot
.76298 .64125 Mdot
.25651 .61113 Mdot
.67419 .44129 Mdot
.65406 .43648 Mdot
.47852 .36417 Mdot
.618 .57077 Mdot
.58033 .59868 Mdot
.48091 .32933 Mdot
.26128 .494 Mdot
.64963 .5856 Mdot
.26272 .6691 Mdot
.72963 .68643 Mdot
.40921 .66115 Mdot
.53321 .29533 Mdot
.34657 .40862 Mdot
.27462 .49201 Mdot
.58776 .51939 Mdot
.43034 .55741 Mdot
.34394 .50325 Mdot
.48713 .33832 Mdot
.59036 .41929 Mdot
.34507 .78508 Mdot
.39068 .57951 Mdot
.46087 .60002 Mdot
.43448 .60335 Mdot
.35778 .42558 Mdot
.41013 .71988 Mdot
.4625 .58055 Mdot
.25888 .49366 Mdot
.38791 .62621 Mdot
.3317 .66777 Mdot
.34129 .40329 Mdot
.51104 .5122 Mdot
.41518 .34777 Mdot
.8123 .63166 Mdot
.32884 .6312 Mdot
.65412 .4526 Mdot
.45668 .28975 Mdot
.62215 .42267 Mdot
.50802 .73672 Mdot
.41002 .47471 Mdot
.58129 .61524 Mdot
.43497 .55883 Mdot
.51294 .36107 Mdot
.66086 .61811 Mdot
.59469 .30096 Mdot
.55855 .10342 Mdot
.67759 .44832 Mdot
.24695 .75245 Mdot
.62759 .43934 Mdot
.49161 .32816 Mdot
.63958 .61286 Mdot
.50615 .80747 Mdot
.75637 .60276 Mdot
.64122 .60269 Mdot
.17288 .58834 Mdot
.68048 .63952 Mdot
.39186 .50438 Mdot
.63476 .56753 Mdot
.65674 .43098 Mdot
.60653 .40454 Mdot
.53614 .55051 Mdot
.46032 .61517 Mdot
.5012 .43723 Mdot
.33562 .71506 Mdot
.47456 .58268 Mdot
.52179 .35147 Mdot
.46229 .68716 Mdot
.3407 .49248 Mdot
.63224 .57255 Mdot
.7063 .3844 Mdot
.462 .59181 Mdot
.39805 .62737 Mdot
.44178 .636 Mdot
.79624 .56844 Mdot
.22132 .66764 Mdot
.45949 .6241 Mdot
.40774 .64355 Mdot
.50062 .36038 Mdot
.35841 .44195 Mdot
.43681 .24285 Mdot
.66127 .68217 Mdot
.38416 .57966 Mdot
.35189 .39924 Mdot
.38012 .37722 Mdot
.47934 .58448 Mdot
.51826 .50163 Mdot
.73101 .46454 Mdot
.46611 .60083 Mdot
.46015 .68573 Mdot
.55635 .38655 Mdot
.54291 .35694 Mdot
.50273 .33401 Mdot
.58688 .57893 Mdot
.48574 .33264 Mdot
.48759 .32154 Mdot
.43855 .79104 Mdot
.53853 .47653 Mdot
.67864 .47724 Mdot
.32814 .40109 Mdot
.42464 .60044 Mdot
.53426 .59886 Mdot
.71313 .48465 Mdot
.61609 .43547 Mdot
.60746 .60762 Mdot
.67342 .39989 Mdot
.35135 .35412 Mdot
.78197 .56738 Mdot
.46103 .36978 Mdot
.66346 .4472 Mdot
.67432 .4583 Mdot
.35161 .40101 Mdot
.61285 .41898 Mdot
.61162 .37578 Mdot
.47857 .61544 Mdot
.5209 .78489 Mdot
.4368 .58319 Mdot
.17383 .45296 Mdot
.65325 .44116 Mdot
.6486 .39033 Mdot
.44954 .6108 Mdot
.50962 .33739 Mdot
.4278 .51423 Mdot
.45605 .61879 Mdot
.48588 .3337 Mdot
.40583 .54554 Mdot
.32818 .37126 Mdot
.627 .64056 Mdot
.75235 .60676 Mdot
.42352 .1533 Mdot
.36353 .41963 Mdot
.59998 .29633 Mdot
.41463 .55439 Mdot
.29479 .26894 Mdot
.64597 .60235 Mdot
.43328 .54719 Mdot
.35881 .48131 Mdot
.63627 .58657 Mdot
.61998 .60834 Mdot
.40415 .61073 Mdot
.6398 .40886 Mdot
.52172 .33514 Mdot
.34842 .40426 Mdot
.15317 .4826 Mdot
.4489 .58525 Mdot
.40381 .5694 Mdot
.35102 .39351 Mdot
.68071 .42539 Mdot
.4619 .56048 Mdot
.26328 .55652 Mdot
.20722 .6734 Mdot
.62757 .44253 Mdot
.38332 .59939 Mdot
.4983 .75294 Mdot
.33539 .64968 Mdot
.23537 .3049 Mdot
.55661 .51897 Mdot
.49101 .35687 Mdot
.34812 .57937 Mdot
.74193 .25962 Mdot
.36293 .38846 Mdot
.78552 .62314 Mdot
.39673 .62676 Mdot
.3995 .59155 Mdot
.65732 .63277 Mdot
.42531 .57714 Mdot
.60224 .60244 Mdot
.51851 .15687 Mdot
.6787 .76184 Mdot
.59011 .58376 Mdot
.65697 .58844 Mdot
.34094 .5381 Mdot
.71456 .42054 Mdot
.63039 .61823 Mdot
.45554 .63847 Mdot
.47969 .48971 Mdot
.71009 .61619 Mdot
.36646 .41107 Mdot
.24995 .38802 Mdot
.36412 .65556 Mdot
.27333 .38806 Mdot
.1959 .55023 Mdot
.46925 .66552 Mdot
.41789 .43916 Mdot
.62868 .42815 Mdot
.38942 .58005 Mdot
.50296 .3816 Mdot
.50671 .38244 Mdot
.37631 .64459 Mdot
.41566 .60975 Mdot
.61194 .58869 Mdot
.36469 .40006 Mdot
.69107 .42 Mdot
.40134 .59238 Mdot
.38739 .49325 Mdot
.36481 .37999 Mdot
.60491 .57362 Mdot
.50461 .70796 Mdot
.30852 .38805 Mdot
.35285 .59797 Mdot
.45991 .61211 Mdot
.42205 .59242 Mdot
.53598 .5478 Mdot
.64529 .41748 Mdot
.20527 .54361 Mdot
.41934 .6505 Mdot
.75392 .70284 Mdot
.70176 .45585 Mdot
.37028 .55486 Mdot
.60901 .57963 Mdot
.70368 .38389 Mdot
.45215 .35054 Mdot
.79963 .47477 Mdot
.43585 .567 Mdot
.33479 .27714 Mdot
.482 .20309 Mdot
.4993 .31058 Mdot
.67728 .62843 Mdot
.33285 .40406 Mdot
.42978 .5899 Mdot
.45186 .7124 Mdot
.42656 .62454 Mdot
.38803 .37608 Mdot
.5293 .36091 Mdot
.62908 .4255 Mdot
.21383 .38509 Mdot
.49747 .38517 Mdot
.61985 .611 Mdot
.56409 .84587 Mdot
.60095 .60355 Mdot
.58074 .59692 Mdot
.51987 .70775 Mdot
.64358 .41713 Mdot
.66707 .18243 Mdot
.54587 .16949 Mdot
.4704 .61819 Mdot
.67808 .43037 Mdot
.62491 .62508 Mdot
.385 .61212 Mdot
.68717 .62808 Mdot
.58774 .61643 Mdot
.45506 .63359 Mdot
.39784 .58686 Mdot
.4407 .22779 Mdot
.30838 .71918 Mdot
.33159 .40288 Mdot
.59414 .59664 Mdot
.76532 .5731 Mdot
.38343 .61486 Mdot
.43989 .6134 Mdot
.65274 .25857 Mdot
.35447 .42408 Mdot
.76802 .51765 Mdot
.39746 .62709 Mdot
.59249 .81425 Mdot
.506 .62263 Mdot
.65012 .6412 Mdot
.62074 .42801 Mdot
.79715 .65069 Mdot
.59769 .37986 Mdot
.60384 .60162 Mdot
.35331 .37481 Mdot
.63898 .56647 Mdot
.41156 .78796 Mdot
.68119 .41585 Mdot
.6203 .63031 Mdot
.41993 .4525 Mdot
.66127 .41788 Mdot
.65097 .44395 Mdot
.54608 .69721 Mdot
.45789 .33461 Mdot
.37043 .41679 Mdot
.65041 .43685 Mdot
.75283 .36231 Mdot
.66071 .4258 Mdot
.5254 .16726 Mdot
.38911 .5852 Mdot
.3042 .50912 Mdot
.46858 .29779 Mdot
.35129 .65069 Mdot
.65983 .44352 Mdot
.32135 .41578 Mdot
.43133 .63958 Mdot
.60874 .56748 Mdot
.36728 .40162 Mdot
.6069 .46555 Mdot
.47444 .35242 Mdot
.62405 .57965 Mdot
.59451 .44996 Mdot
.65079 .62597 Mdot
.76874 .43731 Mdot
.4178 .17835 Mdot
.31132 .59833 Mdot
.76107 .59697 Mdot
.43462 .64095 Mdot
.22904 .62284 Mdot
.37941 .60184 Mdot
.40901 .61592 Mdot
.5246 .34236 Mdot
.32063 .50381 Mdot
.64168 .61422 Mdot
.1695 .53958 Mdot
.66051 .45032 Mdot
.81024 .63784 Mdot
.33133 .61573 Mdot
.40754 .55144 Mdot
.62735 .59061 Mdot
.64017 .63987 Mdot
.54877 .72712 Mdot
.48672 .39273 Mdot
.40554 .55431 Mdot
.49478 .60741 Mdot
.38501 .65611 Mdot
.64678 .44798 Mdot
.46297 .47921 Mdot
.46442 .3642 Mdot
.36534 .20761 Mdot
.53174 .35679 Mdot
.29299 .357 Mdot
.61285 .56927 Mdot
.32687 .37812 Mdot
.44261 .61415 Mdot
.50718 .6484 Mdot
.66065 .63362 Mdot
.37203 .3758 Mdot
.32052 .40911 Mdot
.59096 .2652 Mdot
.64771 .41131 Mdot
.46162 .617 Mdot
.45472 .57423 Mdot
.41897 .58051 Mdot
.4106 .60995 Mdot
.67634 .4481 Mdot
.43812 .63502 Mdot
.60557 .41613 Mdot
.80591 .47525 Mdot
.28785 .54073 Mdot
.55911 .4893 Mdot
.60507 .21878 Mdot
.63766 .57485 Mdot
.75112 .38387 Mdot
.41259 .52676 Mdot
.80439 .4202 Mdot
.41412 .20972 Mdot
.47736 .62664 Mdot
.50625 .32133 Mdot
.34936 .54722 Mdot
.47645 .3805 Mdot
.14396 .56749 Mdot
.6785 .2857 Mdot
.29874 .7067 Mdot
.43499 .56087 Mdot
.52108 .49705 Mdot
.73255 .31579 Mdot
.3775 .61209 Mdot
.62326 .26573 Mdot
.65329 .24623 Mdot
.37628 .25305 Mdot
.31717 .40126 Mdot
.44788 .57512 Mdot
.54472 .5824 Mdot
.46161 .57612 Mdot
.43302 .6131 Mdot
.43976 .63575 Mdot
.68674 .40537 Mdot
.44377 .5533 Mdot
.41762 .63785 Mdot
.33262 .311 Mdot
.38905 .47601 Mdot
.54241 .34252 Mdot
.48831 .18671 Mdot
.3227 .38119 Mdot
.62454 .58775 Mdot
.21664 .64473 Mdot
.64851 .40781 Mdot
.55747 .72973 Mdot
.41574 .6028 Mdot
.4683 .24052 Mdot
.69172 .35787 Mdot
.35251 .3761 Mdot
.52463 .32441 Mdot
.30401 .73182 Mdot
.51582 .35705 Mdot
.69253 .3782 Mdot
.51327 .33867 Mdot
.3623 .55381 Mdot
.60837 .58954 Mdot
.47395 .60437 Mdot
.64523 .43475 Mdot
.50229 .32989 Mdot
.27344 .44216 Mdot
.43262 .59873 Mdot
.51179 .35444 Mdot
.47089 .60903 Mdot
.679 .66387 Mdot
.69065 .68776 Mdot
.49706 .31921 Mdot
.64098 .46252 Mdot
.6403 .42623 Mdot
.32363 .38694 Mdot
.62948 .58317 Mdot
.60661 .6044 Mdot
.67189 .41576 Mdot
.61971 .55396 Mdot
.38231 .58171 Mdot
.38838 .60144 Mdot
.77293 .67712 Mdot
.45678 .56877 Mdot
.44285 .50187 Mdot
.4314 .45842 Mdot
.59444 .57536 Mdot
.38167 .56114 Mdot
.39938 .61328 Mdot
.42762 .56188 Mdot
.70909 .65474 Mdot
.48561 .3358 Mdot
.38992 .58183 Mdot
.32724 .41714 Mdot
.56715 .32203 Mdot
.389 .61689 Mdot
.5254 .59205 Mdot
.60588 .60636 Mdot
.83799 .47213 Mdot
.62612 .43505 Mdot
.52804 .34417 Mdot
.50274 .36602 Mdot
.2039 .52384 Mdot
.73639 .35154 Mdot
.43536 .45943 Mdot
.2865 .24752 Mdot
.72212 .35615 Mdot
.32254 .40142 Mdot
.543 .32016 Mdot
.59283 .45456 Mdot
.49594 .36981 Mdot
.68899 .43919 Mdot
.38607 .59537 Mdot
.38361 .58228 Mdot
.73191 .26373 Mdot
.46808 .56579 Mdot
.33707 .4061 Mdot
.69444 .42019 Mdot
.6523 .5918 Mdot
.35682 .37766 Mdot
.62607 .4151 Mdot
.58862 .57884 Mdot
.47625 .62846 Mdot
.43545 .6497 Mdot
.60979 .60519 Mdot
.65355 .63357 Mdot
.45593 .61321 Mdot
.65477 .34499 Mdot
.65936 .59413 Mdot
.63071 .63457 Mdot
.46026 .36167 Mdot
.498 .38214 Mdot
.43589 .67104 Mdot
.66763 .43655 Mdot
.42248 .63874 Mdot
.50327 .36273 Mdot
.32661 .37881 Mdot
.64531 .61254 Mdot
.42174 .64369 Mdot
.39463 .60683 Mdot
.35355 .40089 Mdot
.33526 .3778 Mdot
.32804 .38612 Mdot
.59518 .43427 Mdot
.41921 .57274 Mdot
.63543 .61221 Mdot
.64281 .41417 Mdot
.38244 .38639 Mdot
.35649 .41864 Mdot
.55074 .33802 Mdot
.45564 .56376 Mdot
.44542 .32947 Mdot
.75692 .27488 Mdot
.70354 .73644 Mdot
.4913 .31698 Mdot
.45267 .35411 Mdot
.24946 .43421 Mdot
.65533 .52838 Mdot
.67464 .41135 Mdot
.38401 .42888 Mdot
.31309 .60064 Mdot
.48906 .5993 Mdot
.43529 .64694 Mdot
.38558 .55351 Mdot
.32376 .39057 Mdot
.31786 .52167 Mdot
.60232 .59838 Mdot
.50345 .51653 Mdot
.36562 .37953 Mdot
.53271 .32803 Mdot
.53838 .30928 Mdot
.5326 .35172 Mdot
.40697 .65234 Mdot
.55979 .75634 Mdot
.74406 .38888 Mdot
.24983 .58987 Mdot
.66499 .44141 Mdot
.52384 .61279 Mdot
.31091 .25961 Mdot
.61595 .60518 Mdot
.46127 .37811 Mdot
.32286 .40727 Mdot
.65324 .63194 Mdot
.66668 .39844 Mdot
.65197 .43535 Mdot
.47164 .34299 Mdot
.47317 .34428 Mdot
.50133 .37509 Mdot
.59495 .62524 Mdot
.6157 .56972 Mdot
.4336 .56645 Mdot
.6507 .60827 Mdot
.81948 .4954 Mdot
.34987 .36145 Mdot
.47052 .40403 Mdot
.66803 .43237 Mdot
.62572 .56851 Mdot
.43389 .59538 Mdot
.63268 .65632 Mdot
.68889 .51935 Mdot
.34444 .41518 Mdot
.71524 .67856 Mdot
.14273 .51324 Mdot
.47219 .60509 Mdot
.63857 .42248 Mdot
.77758 .61108 Mdot
.43676 .60118 Mdot
.47731 .36926 Mdot
.26251 .35679 Mdot
.48628 .41555 Mdot
.45078 .62186 Mdot
.48074 .60909 Mdot
.65186 .45333 Mdot
.36085 .2104 Mdot
.4424 .57504 Mdot
.77875 .50091 Mdot
.70828 .42587 Mdot
.47199 .36969 Mdot
.32349 .80795 Mdot
.29639 .40253 Mdot
.27009 .49469 Mdot
.46291 .35437 Mdot
.41096 .62784 Mdot
.47305 .3818 Mdot
.33338 .41895 Mdot
.525 .32717 Mdot
.59943 .60812 Mdot
.53346 .33565 Mdot
.40395 .57016 Mdot
.62664 .61949 Mdot
.67639 .42546 Mdot
.80483 .63296 Mdot
.31533 .33741 Mdot
.50765 .33771 Mdot
.49478 .32211 Mdot
.39784 .55311 Mdot
.76236 .554 Mdot
.36905 .62132 Mdot
.3839 .60239 Mdot
.68085 .43214 Mdot
.63399 .58599 Mdot
.62974 .44641 Mdot
.35748 .62713 Mdot
.28626 .56419 Mdot
.62999 .41396 Mdot
.44352 .24059 Mdot
.34564 .3897 Mdot
.56036 .42968 Mdot
.42896 .59517 Mdot
.60981 .43265 Mdot
.42033 .57051 Mdot
.6023 .59623 Mdot
.57146 .48328 Mdot
.60491 .34588 Mdot
.64094 .44 Mdot
.27784 .32753 Mdot
.27135 .53574 Mdot
.52862 .60055 Mdot
.62414 .42396 Mdot
.34277 .48275 Mdot
.49011 .329 Mdot
.35787 .40886 Mdot
.34024 .36677 Mdot
.36471 .37653 Mdot
.45561 .65652 Mdot
.33062 .61649 Mdot
.32248 .42398 Mdot
.68345 .41069 Mdot
.37413 .39701 Mdot
.65195 .22517 Mdot
.16903 .54461 Mdot
.33698 .39106 Mdot
.45571 .59739 Mdot
.41505 .5223 Mdot
.33115 .4594 Mdot
.56794 .28008 Mdot
.28851 .68603 Mdot
.57308 .22975 Mdot
.44741 .62161 Mdot
.63286 .64574 Mdot
.58759 .60907 Mdot
.81641 .55093 Mdot
.37387 .75867 Mdot
.6713 .76079 Mdot
.58213 .58299 Mdot
.66938 .32373 Mdot
.61382 .57404 Mdot
.46461 .61808 Mdot
.38664 .60549 Mdot
.57571 .60075 Mdot
.29904 .55459 Mdot
.63994 .31421 Mdot
.1818 .42793 Mdot
.6508 .62929 Mdot
.61763 .42448 Mdot
.62185 .44762 Mdot
.65472 .44472 Mdot
.75806 .66673 Mdot
.62946 .59417 Mdot
.4092 .59173 Mdot
.50844 .36438 Mdot
.38692 .57509 Mdot
.66076 .41553 Mdot
.16154 .5781 Mdot
.64134 .5976 Mdot
.46301 .58684 Mdot
.5129 .55717 Mdot
.47329 .34773 Mdot
.34766 .39721 Mdot
.6722 .6626 Mdot
.65521 .77126 Mdot
.66158 .44913 Mdot
.57553 .57868 Mdot
.60507 .47896 Mdot
.19167 .42318 Mdot
.50757 .58186 Mdot
.48308 .56721 Mdot
.15077 .48859 Mdot
.54623 .8332 Mdot
.42525 .55445 Mdot
.5161 .31977 Mdot
.64216 .29252 Mdot
.39155 .61974 Mdot
.58886 .60375 Mdot
.31355 .38093 Mdot
.37172 .38506 Mdot
.46633 .66049 Mdot
.6875 .65178 Mdot
.58061 .51173 Mdot
.41336 .60135 Mdot
.3563 .58553 Mdot
.46643 .36518 Mdot
.68171 .29809 Mdot
.74171 .71154 Mdot
.33727 .37459 Mdot
.47838 .59276 Mdot
.18258 .53932 Mdot
.6616 .62408 Mdot
.49962 .31163 Mdot
.63021 .406 Mdot
.6438 .65091 Mdot
.5224 .32186 Mdot
.43815 .6448 Mdot
.47262 .57129 Mdot
.61878 .43839 Mdot
.64406 .64162 Mdot
.33007 .38621 Mdot
.52576 .34066 Mdot
.34247 .37811 Mdot
.63687 .58903 Mdot
.6492 .59173 Mdot
.52528 .57207 Mdot
.50094 .57387 Mdot
.50712 .33276 Mdot
.39579 .6586 Mdot
.61016 .36975 Mdot
.19244 .35466 Mdot
.604 .47542 Mdot
.45176 .55693 Mdot
.62654 .56352 Mdot
.64369 .445 Mdot
.39982 .58876 Mdot
.15219 .55606 Mdot
.38435 .62339 Mdot
.69333 .40975 Mdot
.40357 .79148 Mdot
.34433 .38091 Mdot
.55026 .54492 Mdot
.40459 .2197 Mdot
.46232 .57151 Mdot
.48797 .36503 Mdot
.5058 .60638 Mdot
.64193 .40653 Mdot
.62538 .57025 Mdot
.1744 .3692 Mdot
.6555 .42513 Mdot
.47021 .58609 Mdot
.36305 .38356 Mdot
.65798 .58518 Mdot
.55985 .52476 Mdot
.50152 .4903 Mdot
.45769 .53112 Mdot
.38633 .56062 Mdot
.40146 .61852 Mdot
.26194 .57067 Mdot
.52424 .35662 Mdot
.62803 .63173 Mdot
.63439 .42622 Mdot
.67308 .41384 Mdot
.4788 .33942 Mdot
.43634 .34565 Mdot
.55931 .42977 Mdot
.81627 .3558 Mdot
.46976 .38221 Mdot
.33122 .37423 Mdot
.76767 .53106 Mdot
.52058 .35857 Mdot
.51186 .35093 Mdot
.46072 .36705 Mdot
.42596 .44726 Mdot
.64903 .58444 Mdot
.43624 .64534 Mdot
.59623 .61532 Mdot
.41041 .62988 Mdot
.70041 .40934 Mdot
.64328 .43807 Mdot
.64288 .59179 Mdot
.19784 .38454 Mdot
.496 .78163 Mdot
.44593 .60333 Mdot
.29711 .26792 Mdot
.42233 .53601 Mdot
.2817 .41398 Mdot
.41524 .53928 Mdot
.50027 .34049 Mdot
.39308 .6489 Mdot
.43639 .66379 Mdot
.80494 .58483 Mdot
.66953 .43385 Mdot
.54648 .33873 Mdot
.36742 .56219 Mdot
.3545 .59358 Mdot
.59929 .62966 Mdot
.65075 .63449 Mdot
.34692 .36663 Mdot
.47346 .51432 Mdot
.67801 .42225 Mdot
.61671 .18955 Mdot
.46076 .61439 Mdot
.28717 .37981 Mdot
.64874 .74104 Mdot
.40121 .58589 Mdot
.3698 .2329 Mdot
.56087 .75007 Mdot
.42946 .59152 Mdot
.46555 .43426 Mdot
.66886 .43812 Mdot
.29703 .6182 Mdot
.39058 .62911 Mdot
.46905 .35539 Mdot
.60901 .57109 Mdot
.66307 .62895 Mdot
.33404 .36978 Mdot
.77978 .35764 Mdot
.6322 .4491 Mdot
.6367 .57724 Mdot
.42699 .60443 Mdot
.63718 .42144 Mdot
.45862 .36849 Mdot
.42316 .54901 Mdot
.47725 .82403 Mdot
.65145 .6114 Mdot
.40382 .5455 Mdot
.76805 .47407 Mdot
.24875 .46604 Mdot
.41327 .80593 Mdot
.63169 .43156 Mdot
.32218 .38923 Mdot
.4786 .64728 Mdot
.63702 .55209 Mdot
.36454 .59358 Mdot
.28478 .50889 Mdot
.63829 .22125 Mdot
.33645 .42605 Mdot
.45306 .60789 Mdot
.4077 .58859 Mdot
.62396 .51486 Mdot
.34483 .37345 Mdot
.44099 .56392 Mdot
.6738 .55238 Mdot
.64801 .62428 Mdot
.4612 .34426 Mdot
.65557 .60197 Mdot
.4518 .59704 Mdot
.49767 .5669 Mdot
.65542 .63438 Mdot
.22827 .33048 Mdot
.30689 .38658 Mdot
.62727 .42288 Mdot
.48233 .59195 Mdot
.40008 .64664 Mdot
.87423 .54942 Mdot
.49905 .3085 Mdot
.6335 .34548 Mdot
.44611 .25047 Mdot
.19623 .5213 Mdot
.31861 .43923 Mdot
.37524 .80093 Mdot
.53782 .83506 Mdot
.44175 .55186 Mdot
.58167 .55393 Mdot
.75404 .43652 Mdot
.67605 .43535 Mdot
.74734 .31565 Mdot
.46124 .6146 Mdot
.43064 .61283 Mdot
.47504 .32437 Mdot
.59236 .34373 Mdot
.67946 .75565 Mdot
.5732 .62395 Mdot
.33729 .38378 Mdot
.60146 .59063 Mdot
.44871 .6422 Mdot
.49934 .45778 Mdot
.52237 .31532 Mdot
.31991 .35608 Mdot
.4646 .59068 Mdot
.71185 .65568 Mdot
.69847 .52606 Mdot
.65002 .41352 Mdot
.49995 .3665 Mdot
.6221 .78426 Mdot
.45913 .56436 Mdot
.60871 .43176 Mdot
.44608 .58662 Mdot
.33324 .44758 Mdot
.35042 .62598 Mdot
.3245 .40078 Mdot
.40314 .63551 Mdot
.46435 .28151 Mdot
.81646 .67306 Mdot
.3802 .41173 Mdot
.6138 .64109 Mdot
.47555 .31678 Mdot
.48828 .33492 Mdot
.64542 .63664 Mdot
.49711 .335 Mdot
.56303 .71711 Mdot
.46194 .80628 Mdot
.34548 .38749 Mdot
.41726 .67206 Mdot
.33916 .39494 Mdot
.48586 .31666 Mdot
.45086 .62095 Mdot
.14881 .43605 Mdot
.51246 .3288 Mdot
.58211 .82835 Mdot
.66453 .4247 Mdot
.50727 .30667 Mdot
.388 .62537 Mdot
.67941 .53425 Mdot
.49635 .38482 Mdot
.63454 .33079 Mdot
.42844 .56237 Mdot
.65164 .59306 Mdot
.39389 .61233 Mdot
.46756 .62156 Mdot
.54016 .33386 Mdot
.42377 .6353 Mdot
.62579 .4148 Mdot
.58176 .58761 Mdot
.27471 .68561 Mdot
.69042 .27436 Mdot
.44306 .56396 Mdot
.42971 .60314 Mdot
.66699 .58823 Mdot
.38636 .63933 Mdot
.67403 .4489 Mdot
.29731 .18568 Mdot
.34601 .39024 Mdot
.5209 .30864 Mdot
.45634 .26861 Mdot
.4897 .6097 Mdot
.43393 .63776 Mdot
.15786 .63231 Mdot
.28344 .5559 Mdot
.62378 .42092 Mdot
.38946 .65899 Mdot
.48373 .38664 Mdot
.36336 .39953 Mdot
.68887 .42024 Mdot
.42405 .58961 Mdot
.44558 .61257 Mdot
.32705 .38238 Mdot
.27986 .39335 Mdot
.72361 .69515 Mdot
.61179 .44294 Mdot
.3832 .53828 Mdot
.55662 .35191 Mdot
.37995 .58348 Mdot
.75103 .66141 Mdot
.61239 .62264 Mdot
.66582 .44815 Mdot
.19928 .54166 Mdot
.45402 .55969 Mdot
.61877 .4308 Mdot
.67796 .42462 Mdot
.36486 .58689 Mdot
.55656 .59609 Mdot
.57883 .59479 Mdot
.65224 .62321 Mdot
.5947 .14643 Mdot
.28502 .48672 Mdot
.50127 .37511 Mdot
.67239 .43647 Mdot
.48466 .32406 Mdot
.38761 .37437 Mdot
.51078 .48583 Mdot
.49096 .32164 Mdot
.65884 .60873 Mdot
.51429 .30688 Mdot
.41379 .57055 Mdot
.67711 .42159 Mdot
.49152 .3701 Mdot
.46896 .62446 Mdot
.72023 .63166 Mdot
.54123 .24569 Mdot
.34404 .42297 Mdot
.30723 .39412 Mdot
.38737 .60978 Mdot
.46208 .3814 Mdot
.45038 .61553 Mdot
.62172 .40856 Mdot
.75194 .59879 Mdot
.46586 .62186 Mdot
.50401 .3374 Mdot
.66635 .58928 Mdot
.63146 .77983 Mdot
.44018 .65808 Mdot
.45565 .59897 Mdot
.41589 .6328 Mdot
.44582 .58586 Mdot
.20591 .40354 Mdot
.63583 .45419 Mdot
.61925 .228 Mdot
.20727 .5107 Mdot
.63667 .6018 Mdot
.60905 .62884 Mdot
.72662 .71649 Mdot
.74399 .45123 Mdot
.66738 .43713 Mdot
.40963 .61363 Mdot
.70501 .50171 Mdot
.20629 .66934 Mdot
.16654 .44159 Mdot
.37903 .72176 Mdot
.49576 .30925 Mdot
.57686 .57771 Mdot
.49668 .32885 Mdot
.41602 .62726 Mdot
.36027 .58023 Mdot
.44963 .84214 Mdot
.67731 .40503 Mdot
.33702 .38637 Mdot
.41004 .6317 Mdot
.27977 .48767 Mdot
.49874 .36121 Mdot
.5065 .30628 Mdot
.3936 .58514 Mdot
.67086 .61626 Mdot
.80389 .67865 Mdot
.64514 .41798 Mdot
.60404 .23026 Mdot
.72492 .30296 Mdot
.70676 .56259 Mdot
.6564 .41551 Mdot
.63144 .54607 Mdot
.49989 .31338 Mdot
.6491 .72079 Mdot
.62996 .60175 Mdot
.36243 .40701 Mdot
.38196 .54552 Mdot
.61771 .63014 Mdot
.52957 .36541 Mdot
.64141 .57873 Mdot
.43658 .63782 Mdot
.69697 .44293 Mdot
.48765 .3567 Mdot
.69887 .46067 Mdot
.62946 .56416 Mdot
.35007 .37423 Mdot
.63064 .37928 Mdot
.39423 .74501 Mdot
.56187 .74744 Mdot
.39176 .58349 Mdot
.48785 .45646 Mdot
.41193 .58906 Mdot
.67863 .62252 Mdot
.43848 .59286 Mdot
.52526 .63002 Mdot
.48711 .36401 Mdot
.40468 .64224 Mdot
.41059 .60629 Mdot
.52448 .17466 Mdot
.44455 .56871 Mdot
.3732 .59679 Mdot
.42539 .59427 Mdot
.52559 .62547 Mdot
.47656 .65325 Mdot
.60937 .58118 Mdot
.39952 .25099 Mdot
.50982 .34915 Mdot
.36966 .37645 Mdot
.31594 .40078 Mdot
.31236 .5023 Mdot
.43682 .30211 Mdot
.57471 .31301 Mdot
.6467 .62084 Mdot
.62324 .4127 Mdot
.44138 .58938 Mdot
.33741 .7718 Mdot
.53841 .38409 Mdot
.53455 .3333 Mdot
.69378 .27922 Mdot
.34006 .64166 Mdot
.30538 .68188 Mdot
.37534 .64586 Mdot
.70314 .23027 Mdot
.49377 .61284 Mdot
.341 .60207 Mdot
.46457 .37939 Mdot
.28877 .36518 Mdot
.38231 .63117 Mdot
.58625 .59763 Mdot
.33531 .41264 Mdot
.33197 .61506 Mdot
.50839 .29036 Mdot
.57195 .35643 Mdot
.54118 .64533 Mdot
.4246 .56615 Mdot
.48781 .35583 Mdot
.62442 .58098 Mdot
.72483 .72542 Mdot
.64083 .41526 Mdot
.44435 .32625 Mdot
.79213 .48974 Mdot
.24488 .31927 Mdot
.36231 .37736 Mdot
.63194 .69333 Mdot
.4065 .57029 Mdot
.30726 .32467 Mdot
.4783 .60413 Mdot
.16499 .61584 Mdot
.31345 .39954 Mdot
.6573 .59756 Mdot
.61685 .4227 Mdot
.58977 .60305 Mdot
.54895 .74079 Mdot
.52281 .29042 Mdot
.54568 .46344 Mdot
.51531 .3561 Mdot
.57214 .515 Mdot
.6199 .6225 Mdot
.46278 .61769 Mdot
.81212 .34692 Mdot
.62373 .63186 Mdot
.65002 .57688 Mdot
.43868 .18857 Mdot
.17089 .3889 Mdot
.48982 .57224 Mdot
.65699 .58935 Mdot
.51875 .34925 Mdot
.33212 .40628 Mdot
.39512 .63026 Mdot
.4168 .56426 Mdot
.60889 .62162 Mdot
.54033 .32702 Mdot
.45495 .73588 Mdot
.48187 .34143 Mdot
.65421 .59305 Mdot
.49488 .34756 Mdot
.68463 .39536 Mdot
.527 .34016 Mdot
.40095 .64727 Mdot
.43925 .59188 Mdot
.41012 .27272 Mdot
.64992 .59284 Mdot
.41425 .5991 Mdot
.40351 .55114 Mdot
.63521 .61437 Mdot
.62574 .53643 Mdot
.46914 .73911 Mdot
.40296 .55626 Mdot
.43263 .56217 Mdot
.31698 .41086 Mdot
.51282 .47919 Mdot
.6774 .68794 Mdot
.42868 .64033 Mdot
.34576 .42753 Mdot
.59189 .58879 Mdot
.46579 .60258 Mdot
.20304 .62445 Mdot
.63995 .29373 Mdot
.47115 .60577 Mdot
.49172 .32857 Mdot
.40812 .66419 Mdot
.43132 .81362 Mdot
.38231 .60605 Mdot
.63204 .62145 Mdot
.633 .57727 Mdot
.6006 .18779 Mdot
.61859 .61239 Mdot
.4994 .38144 Mdot
.66158 .41676 Mdot
.19046 .42133 Mdot
.47415 .3367 Mdot
.48401 .62791 Mdot
.45632 .16065 Mdot
.42249 .54268 Mdot
.46042 .63946 Mdot
.63606 .79694 Mdot
.5035 .32852 Mdot
.61828 .59038 Mdot
.6116 .38715 Mdot
.49505 .56904 Mdot
.65956 .44808 Mdot
.35232 .58535 Mdot
.38386 .59857 Mdot
.47492 .83362 Mdot
.20897 .4037 Mdot
.60674 .44097 Mdot
.37414 .59485 Mdot
.43097 .63963 Mdot
.46048 .39439 Mdot
.42916 .5992 Mdot
.32899 .40321 Mdot
.63073 .59262 Mdot
.52125 .32518 Mdot
.35758 .39784 Mdot
.4681 .57416 Mdot
.32871 .38609 Mdot
.47757 .36487 Mdot
.64373 .40048 Mdot
.42782 .62655 Mdot
.36931 .40819 Mdot
.33473 .3836 Mdot
.41394 .58894 Mdot
.61165 .56879 Mdot
.34819 .66092 Mdot
.44917 .57202 Mdot
.4227 .64349 Mdot
.60761 .60266 Mdot
.31574 .80967 Mdot
.38626 .60439 Mdot
.28806 .51681 Mdot
.636 .63923 Mdot
.59234 .52459 Mdot
.46558 .34048 Mdot
.37841 .61665 Mdot
.64241 .40052 Mdot
.64084 .40224 Mdot
.5338 .34731 Mdot
.58069 .57426 Mdot
.46753 .25483 Mdot
.57443 .61166 Mdot
.49164 .6303 Mdot
.37135 .6087 Mdot
.43402 .68536 Mdot
.3139 .74066 Mdot
.59468 .60503 Mdot
.48017 .28887 Mdot
.61309 .65213 Mdot
.61506 .41688 Mdot
.54214 .34119 Mdot
.57806 .59337 Mdot
.60662 .59755 Mdot
.59202 .57489 Mdot
.36292 .40726 Mdot
.40931 .27616 Mdot
.65178 .64004 Mdot
.67161 .62281 Mdot
.41565 .56115 Mdot
.42323 .64058 Mdot
.57401 .81813 Mdot
.55997 .81404 Mdot
.32238 .41553 Mdot
.49811 .37709 Mdot
.54337 .11651 Mdot
.66005 .39995 Mdot
.55615 .19053 Mdot
.44967 .64411 Mdot
.58215 .11953 Mdot
.39057 .62643 Mdot
.42471 .6046 Mdot
.57809 .59495 Mdot
.36022 .41506 Mdot
.34278 .39347 Mdot
.62589 .63135 Mdot
.67309 .63009 Mdot
.32851 .40111 Mdot
.37948 .22095 Mdot
.2137 .66219 Mdot
.61217 .36522 Mdot
.64179 .60858 Mdot
.41868 .77246 Mdot
.61438 .44055 Mdot
.37245 .53633 Mdot
.62942 .46049 Mdot
.50624 .3575 Mdot
.51033 .31355 Mdot
.65222 .44782 Mdot
.43514 .56585 Mdot
.5062 .37353 Mdot
.44342 .55018 Mdot
.54013 .23067 Mdot
.53277 .7667 Mdot
.52787 .28044 Mdot
.35068 .54877 Mdot
.62955 .53609 Mdot
.71293 .44463 Mdot
.47331 .58975 Mdot
.18515 .58538 Mdot
.34036 .38495 Mdot
.50603 .60825 Mdot
.67178 .44611 Mdot
.62063 .81338 Mdot
.43772 .62572 Mdot
.63684 .61978 Mdot
.67819 .42789 Mdot
.79954 .49346 Mdot
.77614 .51433 Mdot
.41289 .63179 Mdot
.78097 .31146 Mdot
.67594 .58884 Mdot
.51313 .36476 Mdot
.75518 .62123 Mdot
.61406 .63097 Mdot
.34017 .44625 Mdot
.20947 .56857 Mdot
.2135 .36041 Mdot
.62294 .5875 Mdot
.46863 .32574 Mdot
.60172 .57972 Mdot
.35854 .37734 Mdot
.6103 .63865 Mdot
.49133 .36195 Mdot
.46375 .59511 Mdot
.49061 .33811 Mdot
.35743 .4114 Mdot
.70261 .70141 Mdot
.60675 .44066 Mdot
.52872 .37496 Mdot
.64035 .43314 Mdot
.23044 .46971 Mdot
.25488 .55907 Mdot
.628 .4262 Mdot
.45807 .70569 Mdot
.37173 .61117 Mdot
.63636 .64094 Mdot
.46759 .34372 Mdot
.32299 .34173 Mdot
.63029 .38539 Mdot
.62583 .60385 Mdot
.51943 .37303 Mdot
.77327 .55543 Mdot
.53028 .61627 Mdot
.36978 .61101 Mdot
.3614 .46686 Mdot
.63778 .60979 Mdot
.47303 .3242 Mdot
.79001 .66175 Mdot
.60201 .58134 Mdot
.47667 .38566 Mdot
.61629 .4299 Mdot
.66957 .41123 Mdot
.38869 .56977 Mdot
.70822 .41912 Mdot
.5265 .36067 Mdot
.6374 .48329 Mdot
.65169 .58217 Mdot
.79925 .52671 Mdot
.37708 .38221 Mdot
.50448 .34504 Mdot
.43299 .54177 Mdot
.68038 .61127 Mdot
.65824 .27844 Mdot
.46885 .74939 Mdot
.84242 .43986 Mdot
.47956 .33932 Mdot
.62549 .59518 Mdot
.64128 .61752 Mdot
.44999 .65545 Mdot
.75507 .60627 Mdot
.42608 .25235 Mdot
.50021 .64589 Mdot
.58793 .46625 Mdot
.45658 .35634 Mdot
.46298 .31491 Mdot
.36437 .56611 Mdot
.43395 .5708 Mdot
.61346 .42229 Mdot
.4618 .59416 Mdot
.61 .56583 Mdot
.39316 .58237 Mdot
.63636 .42513 Mdot
.51971 .35424 Mdot
.43286 .62497 Mdot
.33633 .38176 Mdot
.6388 .45388 Mdot
.65917 .39752 Mdot
.50784 .34132 Mdot
.60852 .62157 Mdot
.58183 .52839 Mdot
.47025 .34673 Mdot
.42546 .56588 Mdot
.47108 .46206 Mdot
.44066 .63676 Mdot
.56206 .56643 Mdot
.60075 .58463 Mdot
.52028 .32468 Mdot
.59748 .63742 Mdot
.64917 .4293 Mdot
.20615 .52015 Mdot
.44706 .59726 Mdot
.46774 .38055 Mdot
.7103 .34254 Mdot
.56476 .54346 Mdot
.63502 .56496 Mdot
.48298 .23779 Mdot
.62948 .64046 Mdot
.48936 .37587 Mdot
.49604 .18208 Mdot
.36955 .39375 Mdot
.53076 .32536 Mdot
.28417 .695 Mdot
.51281 .33239 Mdot
.39236 .57265 Mdot
.38942 .60474 Mdot
.52628 .33704 Mdot
.31983 .39197 Mdot
.69414 .75244 Mdot
.44223 .35015 Mdot
.62222 .58991 Mdot
.47183 .20871 Mdot
.84447 .52674 Mdot
.66107 .49674 Mdot
.61701 .41624 Mdot
.48279 .56204 Mdot
.3746 .61582 Mdot
.6797 .44095 Mdot
.60875 .45118 Mdot
.35557 .36879 Mdot
.469 .37807 Mdot
.67403 .59194 Mdot
.63526 .39622 Mdot
.60142 .65357 Mdot
.43366 .28935 Mdot
.43088 .65952 Mdot
.71541 .29153 Mdot
.44631 .64468 Mdot
.24092 .54044 Mdot
.63383 .42774 Mdot
.47856 .59881 Mdot
.37664 .64484 Mdot
.68287 .42493 Mdot
.3325 .40794 Mdot
.44891 .32047 Mdot
.49241 .34998 Mdot
.30943 .79315 Mdot
.43454 .55062 Mdot
.39726 .57709 Mdot
.65942 .44256 Mdot
.34426 .31198 Mdot
.63769 .598 Mdot
.59814 .62258 Mdot
.52422 .35641 Mdot
.55754 .40306 Mdot
.38233 .58722 Mdot
.47037 .59197 Mdot
.48334 .35192 Mdot
.52605 .37435 Mdot
.57893 .30827 Mdot
.40605 .587 Mdot
.66473 .4336 Mdot
.26354 .38416 Mdot
.63245 .43382 Mdot
.45076 .62929 Mdot
.40018 .5773 Mdot
.40286 .64825 Mdot
.4629 .56092 Mdot
.67401 .45806 Mdot
.45205 .63301 Mdot
.36465 .62178 Mdot
.62582 .59786 Mdot
.4116 .63557 Mdot
.58447 .44195 Mdot
.45701 .58986 Mdot
.33049 .40401 Mdot
.67439 .68173 Mdot
.43648 .62586 Mdot
.38969 .5884 Mdot
.50854 .30301 Mdot
.44549 .60802 Mdot
.62951 .4045 Mdot
.64863 .59838 Mdot
.66589 .43922 Mdot
.63698 .40347 Mdot
.45414 .34325 Mdot
.31813 .38389 Mdot
.49101 .60406 Mdot
.33205 .41748 Mdot
.49878 .61079 Mdot
.45294 .55905 Mdot
.41531 .35964 Mdot
.66998 .20049 Mdot
.74848 .67538 Mdot
.44823 .59567 Mdot
.50794 .32853 Mdot
.4964 .32816 Mdot
.58007 .55882 Mdot
.37507 .58047 Mdot
.69211 .42863 Mdot
.61572 .41551 Mdot
.38983 .7706 Mdot
.32184 .55401 Mdot
.33066 .40491 Mdot
.52455 .4779 Mdot
.42103 .55337 Mdot
.47878 .59678 Mdot
.42676 .5477 Mdot
.49064 .32092 Mdot
.34115 .68871 Mdot
.54005 .34453 Mdot
.69087 .48685 Mdot
.64568 .44358 Mdot
.42391 .63004 Mdot
.69421 .26908 Mdot
.65438 .62622 Mdot
.64911 .59848 Mdot
.66841 .39739 Mdot
.53617 .38175 Mdot
.63764 .77546 Mdot
.15437 .46327 Mdot
.69114 .62858 Mdot
.36295 .41114 Mdot
.46765 .57877 Mdot
.52206 .34093 Mdot
.64706 .58161 Mdot
.36002 .41275 Mdot
.45071 .62488 Mdot
.41025 .27682 Mdot
.44959 .58823 Mdot
.74828 .42051 Mdot
.60839 .57309 Mdot
.18836 .6454 Mdot
.5847 .57214 Mdot
.66978 .45471 Mdot
.67325 .44775 Mdot
.40144 .5873 Mdot
.67894 .57407 Mdot
.61704 .63367 Mdot
.3992 .43105 Mdot
.33397 .37325 Mdot
.67034 .50871 Mdot
.36581 .39786 Mdot
.50123 .36775 Mdot
.35166 .41085 Mdot
.48839 .36215 Mdot
.65189 .76436 Mdot
.51443 .6628 Mdot
.35305 .39526 Mdot
.71706 .3557 Mdot
.37542 .61824 Mdot
.32773 .42122 Mdot
.36208 .57788 Mdot
.49363 .64761 Mdot
.48168 .34986 Mdot
.34339 .37223 Mdot
.47721 .59774 Mdot
.36055 .77955 Mdot
.62598 .42205 Mdot
.69161 .43294 Mdot
.36401 .57533 Mdot
.46175 .34112 Mdot
.58208 .59622 Mdot
.17657 .52425 Mdot
.62333 .39855 Mdot
.39163 .59738 Mdot
.38362 .6347 Mdot
.63656 .642 Mdot
.61753 .21091 Mdot
.40464 .57869 Mdot
.54438 .57279 Mdot
.40301 .58971 Mdot
.63268 .4459 Mdot
.5918 .59851 Mdot
.64647 .61109 Mdot
.51677 .37373 Mdot
.66312 .6175 Mdot
.46071 .4855 Mdot
.7381 .37016 Mdot
.35029 .63494 Mdot
.65085 .42551 Mdot
.69489 .51399 Mdot
.71406 .45468 Mdot
.28515 .67185 Mdot
.61467 .56146 Mdot
.46222 .62588 Mdot
.6656 .61549 Mdot
.35704 .40538 Mdot
.65362 .60153 Mdot
.57668 .57792 Mdot
.45519 .615 Mdot
.41073 .62749 Mdot
.51712 .35957 Mdot
.75802 .59922 Mdot
.61745 .6307 Mdot
.39078 .62518 Mdot
.40304 .65282 Mdot
.43881 .54617 Mdot
.40211 .4445 Mdot
.59334 .60087 Mdot
.34781 .21333 Mdot
.39062 .48504 Mdot
.61396 .62789 Mdot
.76433 .71479 Mdot
.692 .31393 Mdot
.53658 .30215 Mdot
.41782 .37985 Mdot
.40137 .59362 Mdot
.50383 .38494 Mdot
.4169 .62724 Mdot
.71881 .2974 Mdot
.43925 .61222 Mdot
.32848 .40452 Mdot
.44141 .55163 Mdot
.51956 .31765 Mdot
.47977 .34105 Mdot
.39178 .59398 Mdot
.42978 .62395 Mdot
.70562 .70971 Mdot
.60141 .63447 Mdot
.64319 .58438 Mdot
.54433 .29204 Mdot
.35708 .38895 Mdot
.66257 .44839 Mdot
.43105 .59243 Mdot
.4611 .33544 Mdot
.48244 .33997 Mdot
.59723 .61431 Mdot
.47148 .36445 Mdot
.64717 .41715 Mdot
.44295 .59733 Mdot
.68319 .43997 Mdot
.3713 .39453 Mdot
.59352 .59767 Mdot
.41169 .63405 Mdot
.41595 .56097 Mdot
.63305 .57749 Mdot
.48109 .59945 Mdot
.32475 .3867 Mdot
.50855 .33395 Mdot
.62223 .58613 Mdot
.66543 .41548 Mdot
.49741 .3669 Mdot
.4333 .64429 Mdot
.75935 .29518 Mdot
.3942 .56566 Mdot
.39652 .60466 Mdot
.31366 .75295 Mdot
.43045 .55414 Mdot
.47243 .34104 Mdot
.65136 .58627 Mdot
.51646 .5799 Mdot
.31537 .48287 Mdot
.29476 .80237 Mdot
.5382 .34569 Mdot
.4641 .57818 Mdot
.30477 .70679 Mdot
.46496 .58307 Mdot
.4535 .76781 Mdot
.54357 .35903 Mdot
.58202 .48064 Mdot
.44546 .54571 Mdot
.6499 .40739 Mdot
.52545 .345 Mdot
.48296 .36163 Mdot
.51005 .21436 Mdot
.46488 .60709 Mdot
.44642 .4349 Mdot
.44296 .63094 Mdot
.66362 .41274 Mdot
.32997 .55645 Mdot
.47556 .34155 Mdot
.83365 .52412 Mdot
.4116 .58746 Mdot
.60178 .5994 Mdot
.50914 .30549 Mdot
.63891 .39094 Mdot
.41594 .6427 Mdot
.32057 .40404 Mdot
.60208 .43407 Mdot
.34853 .62088 Mdot
.6513 .42299 Mdot
.4246 .64315 Mdot
.45275 .52575 Mdot
.81404 .452 Mdot
.59849 .57077 Mdot
.61544 .42473 Mdot
.4521 .45881 Mdot
.4604 .6256 Mdot
.62398 .58695 Mdot
.62812 .60191 Mdot
.36951 .40022 Mdot
.57037 .49666 Mdot
.77361 .47128 Mdot
.50334 .79171 Mdot
.48672 .2094 Mdot
.52682 .31665 Mdot
.62068 .33962 Mdot
.4007 .60883 Mdot
.41281 .47167 Mdot
.62343 .40797 Mdot
.39486 .56345 Mdot
.61209 .69261 Mdot
.64765 .63361 Mdot
.40115 .56235 Mdot
.3374 .39464 Mdot
.29332 .39866 Mdot
.25965 .39217 Mdot
.23403 .60965 Mdot
.51316 .35676 Mdot
.38304 .65842 Mdot
.51573 .56564 Mdot
.46191 .34493 Mdot
.42742 .6537 Mdot
.4634 .34717 Mdot
.32876 .24804 Mdot
.33952 .42321 Mdot
.59953 .59524 Mdot
.67759 .48268 Mdot
.46594 .63728 Mdot
.37914 .59912 Mdot
.31861 .38097 Mdot
.43083 .57157 Mdot
.7884 .3959 Mdot
.39644 .44723 Mdot
.49912 .37124 Mdot
.59299 .57394 Mdot
.40975 .65299 Mdot
.51508 .48994 Mdot
.45964 .58181 Mdot
.57337 .78181 Mdot
.38888 .59056 Mdot
.7807 .51386 Mdot
.60708 .57081 Mdot
.64324 .42663 Mdot
.48126 .58332 Mdot
.43247 .60974 Mdot
.31622 .53134 Mdot
.4973 .60944 Mdot
.4744 .6084 Mdot
.54305 .61731 Mdot
.58654 .5744 Mdot
.60586 .57907 Mdot
.53475 .35089 Mdot
.33597 .72504 Mdot
.65898 .43143 Mdot
.4975 .5581 Mdot
.67799 .39839 Mdot
.42355 .72836 Mdot
.35114 .41734 Mdot
.26623 .60318 Mdot
.41734 .60071 Mdot
.64976 .62058 Mdot
.18643 .48088 Mdot
.59495 .62482 Mdot
.51686 .46655 Mdot
.67789 .42211 Mdot
.62222 .6302 Mdot
.42653 .60742 Mdot
.70175 .64093 Mdot
.33064 .75502 Mdot
.65138 .43574 Mdot
.47683 .63508 Mdot
.51912 .3147 Mdot
.46501 .26479 Mdot
.82561 .47049 Mdot
.62445 .42536 Mdot
.59618 .4617 Mdot
.46918 .60174 Mdot
.66034 .61787 Mdot
.65412 .40904 Mdot
.63203 .44406 Mdot
.47533 .36725 Mdot
.40798 .62705 Mdot
.40489 .62482 Mdot
.50205 .37842 Mdot
.6633 .44038 Mdot
.36555 .59903 Mdot
.3546 .6263 Mdot
.53729 .85833 Mdot
.78407 .53538 Mdot
.32834 .81893 Mdot
.59017 .5459 Mdot
.58001 .68036 Mdot
.17281 .53454 Mdot
.60249 .61458 Mdot
.4753 .58345 Mdot
.36626 .55682 Mdot
.52713 .36 Mdot
.45389 .60348 Mdot
.54932 .35631 Mdot
.67273 .40575 Mdot
.61514 .81468 Mdot
.72761 .5385 Mdot
.27118 .29989 Mdot
.45413 .60521 Mdot
.54652 .60143 Mdot
.35012 .40627 Mdot
.65909 .51733 Mdot
.59482 .59232 Mdot
.41592 .54208 Mdot
.7047 .70783 Mdot
.53431 .33213 Mdot
.6124 .60632 Mdot
.71891 .73011 Mdot
.63923 .53809 Mdot
.44055 .63618 Mdot
.53817 .35503 Mdot
.17811 .57515 Mdot
.58933 .65314 Mdot
.69594 .41941 Mdot
.33289 .40899 Mdot
.52287 .33009 Mdot
.61158 .42413 Mdot
.55483 .58872 Mdot
.61265 .61497 Mdot
.58513 .59741 Mdot
.72759 .6803 Mdot
.53496 .31512 Mdot
.35145 .40449 Mdot
.30107 .60854 Mdot
.32447 .53845 Mdot
.32766 .39898 Mdot
.50948 .31313 Mdot
.60575 .5669 Mdot
.63544 .63329 Mdot
.64842 .59922 Mdot
.78018 .63137 Mdot
.6663 .60066 Mdot
.51939 .20086 Mdot
.44977 .55161 Mdot
.40297 .67382 Mdot
.46673 .58125 Mdot
.69042 .42767 Mdot
.62897 .57724 Mdot
.6084 .38477 Mdot
.48904 .62785 Mdot
.26892 .57999 Mdot
.39013 .57172 Mdot
.63821 .45731 Mdot
.40391 .56527 Mdot
.70058 .2573 Mdot
.66123 .62621 Mdot
.45025 .59906 Mdot
.62826 .45809 Mdot
.35644 .38376 Mdot
.62452 .5618 Mdot
.41532 .63274 Mdot
.44266 .23117 Mdot
.44131 .55602 Mdot
.29543 .28102 Mdot
.78906 .44958 Mdot
.35977 .4132 Mdot
.75598 .35456 Mdot
.459 .33285 Mdot
.49195 .64351 Mdot
.48209 .55361 Mdot
.64532 .43348 Mdot
.66767 .50958 Mdot
.51237 .34921 Mdot
.36544 .71319 Mdot
.3617 .6148 Mdot
.37239 .39507 Mdot
.50324 .66351 Mdot
.68093 .4366 Mdot
.42035 .65488 Mdot
.38453 .6522 Mdot
.5954 .21967 Mdot
.35551 .60277 Mdot
.37887 .61943 Mdot
.30796 .40347 Mdot
.5405 .19562 Mdot
.45359 .58397 Mdot
.523 .47252 Mdot
.60548 .63572 Mdot
.49746 .62123 Mdot
.52323 .19628 Mdot
.38788 .60862 Mdot
.60807 .61401 Mdot
.54805 .57565 Mdot
.75656 .4624 Mdot
.31611 .38689 Mdot
.3885 .5904 Mdot
.58953 .18511 Mdot
.41758 .5763 Mdot
.66524 .43009 Mdot
.37606 .58173 Mdot
.49456 .3613 Mdot
.76653 .66509 Mdot
.51705 .37163 Mdot
.38409 .57033 Mdot
.64634 .60279 Mdot
.65222 .44293 Mdot
.76572 .62899 Mdot
.38443 .28046 Mdot
.58187 .20143 Mdot
.16814 .44504 Mdot
.3326 .37507 Mdot
.38201 .38329 Mdot
.68022 .40993 Mdot
.45136 .59735 Mdot
.44532 .17976 Mdot
.50028 .5939 Mdot
.42555 .5598 Mdot
.438 .61298 Mdot
.25315 .55336 Mdot
.64787 .40153 Mdot
.47911 .34618 Mdot
.40303 .57736 Mdot
.45881 .62581 Mdot
.60132 .60676 Mdot
.35094 .38473 Mdot
.46919 .33793 Mdot
.34447 .38814 Mdot
.52434 .34072 Mdot
.67652 .77486 Mdot
.3665 .62187 Mdot
.35743 .38142 Mdot
.61674 .40714 Mdot
.6047 .60973 Mdot
.73549 .41813 Mdot
.48906 .36566 Mdot
.53082 .35983 Mdot
.38922 .59446 Mdot
.61177 .62306 Mdot
.57714 .61762 Mdot
.3663 .39222 Mdot
.63294 .42153 Mdot
.43769 .62536 Mdot
.45034 .56148 Mdot
.47049 .52919 Mdot
.45801 .34289 Mdot
.74903 .40092 Mdot
.58482 .35216 Mdot
.44997 .59477 Mdot
.6519 .58282 Mdot
.434 .62033 Mdot
.2615 .34297 Mdot
.66005 .62065 Mdot
.38699 .61521 Mdot
.8102 .66704 Mdot
.52832 .29006 Mdot
.73081 .48707 Mdot
.3844 .63343 Mdot
.15597 .56732 Mdot
.40793 .60573 Mdot
.62738 .81342 Mdot
.25011 .37627 Mdot
.37789 .58954 Mdot
.41447 .64355 Mdot
.51462 .7555 Mdot
.45882 .56936 Mdot
.51427 .37671 Mdot
.56192 .82938 Mdot
.58706 .61767 Mdot
.71753 .44707 Mdot
.65192 .68476 Mdot
.31487 .39186 Mdot
.52431 .35617 Mdot
.50259 .29789 Mdot
.3318 .39116 Mdot
.64014 .61134 Mdot
.44563 .58573 Mdot
.50911 .43686 Mdot
.46812 .3342 Mdot
.35162 .6801 Mdot
.66833 .42948 Mdot
.61572 .27665 Mdot
.34705 .45989 Mdot
.65132 .42035 Mdot
.40912 .63523 Mdot
.49517 .75007 Mdot
.64876 .75569 Mdot
.24527 .68256 Mdot
.60829 .43948 Mdot
.64983 .43715 Mdot
.78458 .64027 Mdot
.35737 .36438 Mdot
.59632 .22331 Mdot
.77788 .51703 Mdot
.65608 .44674 Mdot
.60489 .55616 Mdot
.5123 .37929 Mdot
.67066 .35897 Mdot
.49927 .62813 Mdot
.45773 .56026 Mdot
.42855 .60761 Mdot
.62957 .42904 Mdot
.57225 .54645 Mdot
.80202 .54492 Mdot
.63899 .4351 Mdot
.40609 .5276 Mdot
.56303 .45494 Mdot
.69713 .34913 Mdot
.46578 .36394 Mdot
.3349 .37174 Mdot
.36025 .36229 Mdot
.61031 .59424 Mdot
.32812 .37495 Mdot
.29173 .39289 Mdot
.43428 .579 Mdot
.63667 .44043 Mdot
.707 .32034 Mdot
.67078 .41549 Mdot
.33812 .39007 Mdot
.35621 .36747 Mdot
.62676 .59803 Mdot
.64564 .5852 Mdot
.54013 .7097 Mdot
.31 .4518 Mdot
.4401 .56387 Mdot
.37765 .35298 Mdot
.57603 .58161 Mdot
.37661 .67354 Mdot
.33112 .37281 Mdot
.35611 .38626 Mdot
.30493 .5356 Mdot
.41825 .60322 Mdot
.38675 .69471 Mdot
.4234 .59815 Mdot
.42443 .50051 Mdot
.41967 .64744 Mdot
.47446 .36681 Mdot
.4097 .61235 Mdot
.29773 .54723 Mdot
.48284 .6078 Mdot
.37769 .636 Mdot
.47938 .32448 Mdot
.36012 .62506 Mdot
.49475 .36007 Mdot
.39621 .55951 Mdot
.36958 .41069 Mdot
.52639 .35512 Mdot
.29762 .48878 Mdot
.2932 .52936 Mdot
.50343 .31362 Mdot
.34204 .41701 Mdot
.31564 .4119 Mdot
.26094 .49314 Mdot
.59359 .59343 Mdot
.45197 .53621 Mdot
.45343 .59923 Mdot
.5443 .34368 Mdot
.62732 .40895 Mdot
.43141 .64594 Mdot
.37759 .62417 Mdot
.39161 .63758 Mdot
.60757 .59498 Mdot
.41616 .25565 Mdot
.35699 .37836 Mdot
.50711 .37893 Mdot
.57379 .52431 Mdot
.45614 .35701 Mdot
.40513 .66146 Mdot
.3829 .54349 Mdot
.62647 .68768 Mdot
.71249 .37031 Mdot
.79909 .61206 Mdot
.61287 .61296 Mdot
.49369 .32762 Mdot
.37811 .38342 Mdot
.41781 .53117 Mdot
.65188 .62003 Mdot
.49152 .36159 Mdot
.44924 .5889 Mdot
.46479 .64308 Mdot
.73112 .35136 Mdot
.25124 .41025 Mdot
.298 .51149 Mdot
.53359 .34214 Mdot
.4942 .31029 Mdot
.27754 .54283 Mdot
.32232 .34834 Mdot
.63506 .38181 Mdot
.46509 .60117 Mdot
.32081 .40137 Mdot
.65393 .59169 Mdot
.68338 .69459 Mdot
.65338 .45181 Mdot
.75104 .61034 Mdot
.45213 .6051 Mdot
.61465 .51924 Mdot
.64524 .60171 Mdot
.33408 .39547 Mdot
.6293 .43279 Mdot
.31926 .35968 Mdot
.49134 .3236 Mdot
.20446 .36168 Mdot
.42131 .57098 Mdot
.39069 .59081 Mdot
.62284 .44901 Mdot
.64892 .6276 Mdot
.32295 .42446 Mdot
.47115 .21387 Mdot
.47716 .36234 Mdot
.45755 .17733 Mdot
.6571 .59089 Mdot
.41694 .76971 Mdot
.47505 .37473 Mdot
.657 .39465 Mdot
.27248 .48737 Mdot
.64359 .42043 Mdot
.38542 .57584 Mdot
.64306 .62109 Mdot
.61808 .4181 Mdot
.77482 .57659 Mdot
.35099 .79389 Mdot
.42779 .77615 Mdot
.43626 .58468 Mdot
.42847 .82322 Mdot
.35329 .24405 Mdot
.69596 .62204 Mdot
.61512 .41447 Mdot
.39201 .56568 Mdot
.38452 .59288 Mdot
.41705 .57439 Mdot
.64138 .40501 Mdot
.39065 .36529 Mdot
.47881 .35137 Mdot
.47183 .58899 Mdot
.35872 .37013 Mdot
.50296 .35691 Mdot
.6749 .39357 Mdot
.46452 .35781 Mdot
.56175 .58851 Mdot
.42637 .6616 Mdot
.6652 .53378 Mdot
.884 .58191 Mdot
.65712 .439 Mdot
.4571 .33859 Mdot
.3673 .58529 Mdot
.65442 .30065 Mdot
.59075 .58271 Mdot
.47851 .36513 Mdot
.39593 .57671 Mdot
.72212 .37105 Mdot
.71952 .69411 Mdot
.46637 .35 Mdot
.65398 .61842 Mdot
.24961 .67993 Mdot
.45985 .59889 Mdot
.41548 .59335 Mdot
.61764 .62477 Mdot
.45172 .68862 Mdot
.76239 .68637 Mdot
.43094 .62254 Mdot
.64089 .4273 Mdot
.2344 .30738 Mdot
.37721 .62308 Mdot
.38194 .50145 Mdot
.5228 .35352 Mdot
.66449 .37283 Mdot
.756 .43879 Mdot
.48528 .58368 Mdot
.55841 .2348 Mdot
.67121 .48554 Mdot
.32976 .72723 Mdot
.552 .35055 Mdot
.36653 .26195 Mdot
.40376 .79949 Mdot
.65477 .46104 Mdot
.53247 .6359 Mdot
.52253 .22569 Mdot
.61028 .66634 Mdot
.20344 .61653 Mdot
.32427 .32167 Mdot
.70813 .70679 Mdot
.52972 .43357 Mdot
.51537 .32861 Mdot
.44537 .68035 Mdot
.41705 .62944 Mdot
.34731 .24845 Mdot
.80933 .47051 Mdot
.80897 .50112 Mdot
.42999 .82489 Mdot
.44946 .77309 Mdot
.3099 .71709 Mdot
.29103 .69908 Mdot
.3835 .51154 Mdot
.60562 .35143 Mdot
.44066 .17517 Mdot
.6316 .78578 Mdot
.40491 .2076 Mdot
.39442 .67126 Mdot
.4993 .45799 Mdot
.25262 .33551 Mdot
.52151 .65615 Mdot
.51289 .63739 Mdot
.50546 .37592 Mdot
.59106 .59359 Mdot
.58061 .2236 Mdot
.6507 .6432 Mdot
.75634 .45864 Mdot
.26688 .70854 Mdot
.34092 .781 Mdot
.61378 .20222 Mdot
.16156 .56427 Mdot
.59928 .6898 Mdot
.38739 .15703 Mdot
.51738 .3869 Mdot
.59969 .61659 Mdot
.24915 .53749 Mdot
.30035 .5676 Mdot
.70634 .55003 Mdot
.47513 .22877 Mdot
.43484 .27588 Mdot
.24437 .45097 Mdot
.63862 .61783 Mdot
.75802 .3812 Mdot
.68479 .36476 Mdot
.72166 .54313 Mdot
.59713 .80595 Mdot
.24901 .6559 Mdot
.48728 .43455 Mdot
.52625 .24466 Mdot
.62184 .29943 Mdot
.80605 .55117 Mdot
.34095 .47565 Mdot
.53393 .60789 Mdot
.78447 .52235 Mdot
.17256 .48645 Mdot
.51446 .68784 Mdot
.44247 .5063 Mdot
.30457 .57236 Mdot
.69958 .75539 Mdot
.3106 .28771 Mdot
.86904 .51618 Mdot
.65743 .6429 Mdot
.3874 .64011 Mdot
.44158 .70463 Mdot
.54805 .17184 Mdot
.30501 .3993 Mdot
.22712 .60105 Mdot
.35316 .37158 Mdot
.55878 .59444 Mdot
.75351 .68271 Mdot
.53246 .19446 Mdot
.49001 .1651 Mdot
.37854 .39951 Mdot
.49611 .55588 Mdot
.14637 .63904 Mdot
.2943 .64668 Mdot
.72539 .5124 Mdot
.54432 .85531 Mdot
.57113 .44174 Mdot
.79969 .51736 Mdot
.61747 .41754 Mdot
.44885 .82474 Mdot
.63287 .62997 Mdot
.88375 .48179 Mdot
.64272 .80362 Mdot
.64707 .69852 Mdot
.68603 .85256 Mdot
.26535 .54803 Mdot
.58792 .48932 Mdot
.63863 .49075 Mdot
.28415 .45505 Mdot
.77043 .60732 Mdot
.21174 .49633 Mdot
.64439 .2992 Mdot
.15125 .56706 Mdot
.39115 .79796 Mdot
.46959 .16865 Mdot
.25681 .30193 Mdot
.53362 .67135 Mdot
.52376 .49428 Mdot
.36607 .5362 Mdot
.50172 .27018 Mdot
.21667 .59949 Mdot
.72294 .74637 Mdot
.38689 .48522 Mdot
.28863 .7962 Mdot
.38171 .40993 Mdot
.41377 .29544 Mdot
.30839 .77747 Mdot
.24967 .46178 Mdot
.76762 .42147 Mdot
.31479 .67277 Mdot
.32578 .61739 Mdot
.52689 .50999 Mdot
.22473 .6091 Mdot
.72788 .45523 Mdot
.52451 .83767 Mdot
.17137 .59502 Mdot
.6016 .22332 Mdot
.53527 .77479 Mdot
.34502 .52092 Mdot
.66311 .58065 Mdot
.28126 .40552 Mdot
.76108 .44075 Mdot
.37902 .81655 Mdot
.68541 .45118 Mdot
.42275 .83937 Mdot
.75293 .69363 Mdot
.36602 .62358 Mdot
.44559 .53476 Mdot
.62169 .54847 Mdot
.2714 .40906 Mdot
.38674 .6638 Mdot
.69948 .29147 Mdot
.33223 .77454 Mdot
.61776 .76792 Mdot
.7218 .42946 Mdot
.67058 .50027 Mdot
.31139 .7879 Mdot
.48106 .72525 Mdot
.35748 .35232 Mdot
.5236 .82709 Mdot
.77567 .60346 Mdot
.50514 .34939 Mdot
.48397 .17365 Mdot
.59541 .45055 Mdot
.70099 .69623 Mdot
.4979 .79041 Mdot
.58849 .6687 Mdot
.33315 .77641 Mdot
.40726 .24844 Mdot
.73712 .69579 Mdot
.2274 .48811 Mdot
.42246 .19262 Mdot
.70475 .35905 Mdot
.35253 .57969 Mdot
.46525 .22939 Mdot
.31588 .40683 Mdot
.54687 .73259 Mdot
.27939 .25435 Mdot
.37182 .3257 Mdot
.36993 .56408 Mdot
.65578 .69739 Mdot
.50632 .29191 Mdot
.70935 .63387 Mdot
.85372 .45199 Mdot
.39156 .65062 Mdot
.30502 .59673 Mdot
.38643 .24543 Mdot
.28808 .44312 Mdot
.20653 .65542 Mdot
.21609 .38916 Mdot
.87667 .53137 Mdot
.4855 .84577 Mdot
.37981 .27616 Mdot
.37822 .78103 Mdot
.39341 .80964 Mdot
.86815 .54397 Mdot
.4921 .56911 Mdot
.6857 .44839 Mdot
.72056 .23604 Mdot
.46544 .36582 Mdot
.29651 .59165 Mdot
.48688 .2093 Mdot
.32024 .44741 Mdot
.66982 .54306 Mdot
.35954 .7039 Mdot
.52552 .44052 Mdot
.60372 .63695 Mdot
.37853 .65666 Mdot
.83316 .55405 Mdot
.8616 .58596 Mdot
.85241 .53867 Mdot
.18614 .42104 Mdot
.45324 .82415 Mdot
.59819 .51459 Mdot
.58298 .18906 Mdot
.36746 .67296 Mdot
.47842 .58948 Mdot
.29837 .40689 Mdot
.2619 .54601 Mdot
.69095 .68714 Mdot
.74355 .54483 Mdot
.50986 .66501 Mdot
.22545 .60212 Mdot
.11378 .41594 Mdot
.56444 .70788 Mdot
.49306 .196 Mdot
.34301 .35202 Mdot
.29609 .4411 Mdot
.19516 .56703 Mdot
.69604 .67822 Mdot
.30229 .72952 Mdot
.60026 .63465 Mdot
.44042 .21022 Mdot
.35528 .3344 Mdot
.54542 .62945 Mdot
.41343 .25808 Mdot
.29011 .65737 Mdot
.67981 .50282 Mdot
.71987 .66413 Mdot
.76786 .52634 Mdot
.46171 .70376 Mdot
.38579 .44171 Mdot
.60367 .28856 Mdot
.34758 .21246 Mdot
.2876 .32992 Mdot
.39136 .50097 Mdot
.55726 .45268 Mdot
.74203 .32197 Mdot
.69559 .45942 Mdot
.41795 .49685 Mdot
.58543 .42901 Mdot
.30637 .64514 Mdot
.89618 .39179 Mdot
.84562 .50592 Mdot
.26555 .72043 Mdot
.21066 .44676 Mdot
.34867 .6043 Mdot
.29351 .72482 Mdot
.87106 .48014 Mdot
.79649 .69135 Mdot
.58593 .28695 Mdot
.52575 .38507 Mdot
.66284 .3936 Mdot
.81819 .59996 Mdot
.40721 .37136 Mdot
.27372 .67697 Mdot
.36667 .49568 Mdot
.63903 .39823 Mdot
.61778 .16444 Mdot
.67971 .76449 Mdot
.47301 .79501 Mdot
.25904 .4047 Mdot
.39814 .53949 Mdot
.76858 .36404 Mdot
.61377 .63236 Mdot
.642 .33306 Mdot
.32708 .46102 Mdot
.50006 .343 Mdot
.22736 .55389 Mdot
.44234 .22018 Mdot
.44154 .55142 Mdot
.47943 .46993 Mdot
.66302 .58767 Mdot
.70324 .35166 Mdot
.69692 .50049 Mdot
.82455 .66067 Mdot
.30957 .36209 Mdot
.43493 .5411 Mdot
.29813 .45435 Mdot
.44319 .25337 Mdot
.79107 .66096 Mdot
.66991 .40092 Mdot
.36647 .78332 Mdot
.47868 .43965 Mdot
.28993 .42755 Mdot
.6561 .66911 Mdot
.40914 .68021 Mdot
.37224 .62264 Mdot
.18543 .451 Mdot
.62185 .75961 Mdot
.62917 .65925 Mdot
.51094 .60998 Mdot
.35889 .68331 Mdot
.28837 .71837 Mdot
.29407 .39114 Mdot
.61783 .28425 Mdot
.35778 .78212 Mdot
.66285 .40534 Mdot
.66602 .6126 Mdot
.39112 .37764 Mdot
.38739 .21392 Mdot
.41677 .77994 Mdot
.72133 .69315 Mdot
.39218 .46417 Mdot
.3822 .32069 Mdot
.36144 .79474 Mdot
.34373 .7533 Mdot
.70833 .25362 Mdot
.68657 .60375 Mdot
.46519 .50319 Mdot
.37172 .21442 Mdot
.58406 .58581 Mdot
.57066 .20259 Mdot
.61574 .2274 Mdot
.64583 .79361 Mdot
.46232 .45995 Mdot
.15034 .58501 Mdot
.29965 .50766 Mdot
.20893 .57277 Mdot
.77481 .62097 Mdot
.40981 .20126 Mdot
.28343 .5982 Mdot
.68716 .63449 Mdot
.50227 .76442 Mdot
.35153 .63096 Mdot
.68521 .24935 Mdot
.72702 .25168 Mdot
.38902 .40819 Mdot
.5971 .48319 Mdot
.17252 .60787 Mdot
.43682 .5719 Mdot
.84493 .45167 Mdot
.44042 .21649 Mdot
.78406 .63625 Mdot
.65111 .3967 Mdot
.42847 .63977 Mdot
.48919 .61403 Mdot
.43076 .80139 Mdot
.75071 .45925 Mdot
.31412 .67761 Mdot
.24409 .30225 Mdot
.18203 .58783 Mdot
.51851 .66676 Mdot
.2987 .58725 Mdot
.25101 .65968 Mdot
.34773 .25084 Mdot
.55912 .48458 Mdot
.20817 .51033 Mdot
.26238 .46742 Mdot
.16957 .52941 Mdot
.58886 .44817 Mdot
.43202 .35325 Mdot
.69209 .47936 Mdot
.5436 .28216 Mdot
.74022 .66586 Mdot
.40352 .63542 Mdot
.71822 .73079 Mdot
.2803 .66796 Mdot
.75178 .31948 Mdot
.81979 .45309 Mdot
.84465 .51177 Mdot
.58817 .76819 Mdot
.32482 .28609 Mdot
.38364 .23116 Mdot
.32823 .21323 Mdot
.46442 .43164 Mdot
.25521 .57878 Mdot
.24184 .47188 Mdot
.36008 .79011 Mdot
.62426 .44823 Mdot
.7774 .4978 Mdot
.7064 .45595 Mdot
.35316 .75211 Mdot
.4895 .73292 Mdot
.29389 .68949 Mdot
.56898 .41975 Mdot
.8812 .52706 Mdot
.24736 .36339 Mdot
.54293 .42623 Mdot
.5011 .32281 Mdot
.35215 .27832 Mdot
.2476 .62377 Mdot
.24655 .36805 Mdot
.43617 .19503 Mdot
.53867 .30032 Mdot
.56636 .52902 Mdot
.40968 .75601 Mdot
.28189 .40112 Mdot
.18284 .4525 Mdot
.29683 .45341 Mdot
.32789 .76197 Mdot
.46308 .82457 Mdot
.7189 .7282 Mdot
.26645 .5553 Mdot
.17246 .43189 Mdot
.726 .50895 Mdot
.27338 .39084 Mdot
.44194 .21808 Mdot
.42046 .30859 Mdot
.63598 .64991 Mdot
.62163 .12794 Mdot
.21724 .35337 Mdot
.30236 .31313 Mdot
.7146 .75057 Mdot
.20583 .39935 Mdot
.70847 .35817 Mdot
.47483 .68218 Mdot
.77439 .56532 Mdot
.68601 .74068 Mdot
.43754 .61207 Mdot
.85069 .52233 Mdot
.4105 .47615 Mdot
.86938 .59453 Mdot
.27417 .69514 Mdot
.59532 .47727 Mdot
.4212 .66196 Mdot
.5274 .37073 Mdot
.43996 .42694 Mdot
.3295 .56145 Mdot
.44657 .72681 Mdot
.78392 .44279 Mdot
.71333 .43612 Mdot
.50737 .38808 Mdot
.52781 .278 Mdot
.64957 .64936 Mdot
.22633 .42206 Mdot
.5734 .32951 Mdot
.49264 .40036 Mdot
.47096 .42559 Mdot
.39094 .48063 Mdot
.75649 .4276 Mdot
.46131 .79455 Mdot
.70478 .677 Mdot
.68945 .54833 Mdot
.47972 .3723 Mdot
.49956 .79696 Mdot
.23836 .34441 Mdot
.17602 .58094 Mdot
.72398 .74414 Mdot
.52264 .50494 Mdot
.45959 .74626 Mdot
.3657 .51397 Mdot
.81281 .51544 Mdot
.66982 .56273 Mdot
.71088 .4332 Mdot
.7674 .3681 Mdot
.61494 .55219 Mdot
.54724 .23772 Mdot
.61819 .81335 Mdot
.41484 .20717 Mdot
.36839 .21438 Mdot
.39284 .42647 Mdot
.51356 .55133 Mdot
.54045 .62319 Mdot
.29889 .49562 Mdot
.62542 .38849 Mdot
.46904 .14877 Mdot
.50624 .60801 Mdot
.42208 .1314 Mdot
.62851 .44319 Mdot
.55903 .65307 Mdot
.25666 .47184 Mdot
.5633 .46515 Mdot
.57882 .41479 Mdot
.26809 .34337 Mdot
.784 .49892 Mdot
.32978 .27584 Mdot
.79807 .54881 Mdot
.52568 .38342 Mdot
.20326 .34476 Mdot
.15083 .47955 Mdot
.51993 .76823 Mdot
.41017 .55212 Mdot
.18889 .38349 Mdot
.49015 .38989 Mdot
.69435 .68376 Mdot
.20962 .66068 Mdot
.18947 .49768 Mdot
.39793 .74346 Mdot
.2908 .43245 Mdot
.2583 .58276 Mdot
.45523 .84313 Mdot
.73331 .27282 Mdot
.22155 .5958 Mdot
.62263 .44605 Mdot
.56384 .43186 Mdot
.27784 .62551 Mdot
.79968 .48362 Mdot
.7046 .38131 Mdot
.77463 .44062 Mdot
.35097 .16631 Mdot
.29608 .60763 Mdot
.30831 .6112 Mdot
.80352 .46492 Mdot
.59561 .56795 Mdot
.78744 .47342 Mdot
.76649 .41942 Mdot
.2028 .4406 Mdot
.27625 .29983 Mdot
.76398 .42702 Mdot
.34625 .19664 Mdot
.5135 .62849 Mdot
.59894 .37671 Mdot
.38173 .68968 Mdot
.31522 .62635 Mdot
.60706 .41719 Mdot
.62589 .78053 Mdot
.19178 .61022 Mdot
.70272 .42798 Mdot
.18093 .47235 Mdot
.51853 .24383 Mdot
.32037 .6164 Mdot
.44412 .79663 Mdot
.18703 .5507 Mdot
.48566 .74297 Mdot
.67721 .23338 Mdot
.66602 .70301 Mdot
.48843 .39269 Mdot
.21609 .64157 Mdot
.49429 .36931 Mdot
.34859 .6793 Mdot
.74652 .61738 Mdot
.21171 .50858 Mdot
.79721 .61922 Mdot
.3155 .39398 Mdot
.59469 .61519 Mdot
.73148 .26144 Mdot
.64551 .57843 Mdot
.83511 .55734 Mdot
.60717 .67338 Mdot
.7791 .40256 Mdot
.37081 .28502 Mdot
.34991 .31121 Mdot
.33911 .18187 Mdot
.68742 .3721 Mdot
.54085 .38204 Mdot
.65691 .2353 Mdot
.60242 .6215 Mdot
.38938 .42947 Mdot
.50491 .3168 Mdot
.45499 .40856 Mdot
.6095 .23668 Mdot
.52094 .61938 Mdot
.6433 .56403 Mdot
.44641 .40312 Mdot
.56059 .81735 Mdot
.55307 .84147 Mdot
.47334 .33781 Mdot
.48124 .13325 Mdot
.39672 .65705 Mdot
.54319 .7673 Mdot
.31105 .74624 Mdot
.61067 .16074 Mdot
.56063 .37995 Mdot
.1472 .52378 Mdot
.47314 .56551 Mdot
.19828 .52385 Mdot
.62938 .6247 Mdot
.42736 .20918 Mdot
.36801 .38523 Mdot
.28266 .43861 Mdot
.6688 .45266 Mdot
.71975 .66345 Mdot
.56804 .36528 Mdot
.585 .59478 Mdot
.20604 .44965 Mdot
.38825 .51016 Mdot
.6273 .47022 Mdot
.39542 .25854 Mdot
.51526 .77264 Mdot
.35799 .73361 Mdot
.50631 .65222 Mdot
.31075 .59081 Mdot
.3189 .23544 Mdot
.8298 .65753 Mdot
.69976 .63536 Mdot
.6357 .5394 Mdot
.66493 .25885 Mdot
.18349 .51266 Mdot
.72235 .30829 Mdot
.33277 .77988 Mdot
.41529 .48535 Mdot
.53517 .54099 Mdot
.43303 .49951 Mdot
.35373 .6576 Mdot
.54013 .46019 Mdot
.62611 .31048 Mdot
.80113 .43803 Mdot
.74772 .42006 Mdot
.49661 .68833 Mdot
.70848 .2764 Mdot
.32829 .54617 Mdot
.77885 .41237 Mdot
.46619 .39152 Mdot
.36475 .73812 Mdot
.65381 .51227 Mdot
.55681 .84301 Mdot
.32523 .76818 Mdot
.67171 .39334 Mdot
.48346 .26327 Mdot
.16701 .61802 Mdot
.49808 .58773 Mdot
.57929 .5192 Mdot
.39183 .58688 Mdot
.50384 .49916 Mdot
.56768 .14292 Mdot
.18655 .4818 Mdot
.36916 .56803 Mdot
.36211 .77141 Mdot
.40082 .8002 Mdot
.87815 .55411 Mdot
.42717 .17925 Mdot
.62756 .59469 Mdot
.85506 .5669 Mdot
.77809 .43708 Mdot
.43983 .83579 Mdot
.68007 .33953 Mdot
.38242 .83769 Mdot
.50694 .76169 Mdot
.17545 .53301 Mdot
.48185 .67148 Mdot
.77795 .53562 Mdot
.41505 .23936 Mdot
.57786 .51279 Mdot
.63906 .2766 Mdot
.24745 .35198 Mdot
.19679 .33986 Mdot
.3424 .62407 Mdot
.45591 .23183 Mdot
.70318 .56596 Mdot
.22503 .66301 Mdot
.291 .33918 Mdot
.37918 .56601 Mdot
.6742 .49533 Mdot
.7705 .63964 Mdot
.39773 .48393 Mdot
.61517 .54236 Mdot
.29944 .33134 Mdot
.6825 .73048 Mdot
.35514 .52537 Mdot
.37827 .21188 Mdot
.51013 .77011 Mdot
.46259 .43747 Mdot
.45872 .62776 Mdot
.68036 .60345 Mdot
.3651 .42359 Mdot
.55874 .50453 Mdot
.41262 .55569 Mdot
.49021 .30725 Mdot
.71092 .3914 Mdot
.82448 .55886 Mdot
.72113 .47107 Mdot
.36676 .22733 Mdot
.52019 .63676 Mdot
.73713 .57717 Mdot
.71404 .29875 Mdot
.83651 .51662 Mdot
.35336 .34015 Mdot
.38586 .48492 Mdot
.31044 .71026 Mdot
.46788 .82833 Mdot
.56134 .63494 Mdot
.82738 .6497 Mdot
.61937 .41081 Mdot
.33106 .68657 Mdot
.75345 .55432 Mdot
.557 .36119 Mdot
.47028 .65611 Mdot
.17647 .52992 Mdot
.30286 .43431 Mdot
.29854 .55554 Mdot
.29978 .29381 Mdot
.533 .52909 Mdot
.45199 .78021 Mdot
.36448 .77851 Mdot
.53963 .34663 Mdot
.32676 .24196 Mdot
.62294 .47865 Mdot
.31079 .32816 Mdot
.46903 .831 Mdot
.68452 .76642 Mdot
.5795 .39843 Mdot
.26708 .45736 Mdot
.41177 .59289 Mdot
.3545 .21226 Mdot
.18559 .47726 Mdot
.32262 .62317 Mdot
.59719 .27196 Mdot
.66545 .60775 Mdot
.59306 .31644 Mdot
.48717 .45334 Mdot
.67294 .745 Mdot
.67241 .60933 Mdot
.77236 .37555 Mdot
.36475 .41721 Mdot
.59116 .48822 Mdot
.5249 .59678 Mdot
.27703 .45799 Mdot
.4315 .16311 Mdot
.5155 .60087 Mdot
.22369 .61418 Mdot
.50975 .78721 Mdot
.46853 .21427 Mdot
.19135 .53284 Mdot
.71646 .37081 Mdot
.78418 .50252 Mdot
.39167 .76195 Mdot
.71236 .45321 Mdot
.38364 .62861 Mdot
.51003 .39184 Mdot
.59117 .58691 Mdot
.21589 .65326 Mdot
.58365 .77426 Mdot
.29438 .48823 Mdot
.40266 .44445 Mdot
.60062 .54924 Mdot
.63622 .49478 Mdot
.35493 .81489 Mdot
.78396 .5122 Mdot
.35153 .46971 Mdot
.4642 .46091 Mdot
.26328 .47298 Mdot
.55662 .67458 Mdot
.66889 .79076 Mdot
.48004 .67894 Mdot
.50718 .43069 Mdot
.56508 .65105 Mdot
.30634 .2995 Mdot
.20388 .65703 Mdot
.44123 .50482 Mdot
.58074 .45855 Mdot
.31191 .4134 Mdot
.72317 .32765 Mdot
.39574 .43568 Mdot
.59657 .53589 Mdot
.43427 .38564 Mdot
.5963 .24936 Mdot
.72843 .60443 Mdot
.41206 .51838 Mdot
.27463 .55873 Mdot
.32552 .73359 Mdot
.47235 .20731 Mdot
.69046 .46129 Mdot
.61478 .35218 Mdot
.62984 .77256 Mdot
.41274 .85855 Mdot
.78897 .36127 Mdot
.41378 .58904 Mdot
.66161 .48701 Mdot
.25891 .44339 Mdot
.52717 .3263 Mdot
.75607 .40506 Mdot
.73817 .35731 Mdot
.61823 .43078 Mdot
.29399 .42911 Mdot
.3127 .55017 Mdot
.49094 .25336 Mdot
.24326 .42657 Mdot
.66576 .51526 Mdot
.83264 .53898 Mdot
.20245 .38368 Mdot
.18409 .51573 Mdot
.53933 .88725 Mdot
.64575 .47565 Mdot
.33812 .59441 Mdot
.49469 .71715 Mdot
.506 .84284 Mdot
.30451 .46116 Mdot
.70365 .69061 Mdot
.68333 .30662 Mdot
.45082 .50704 Mdot
.70049 .62061 Mdot
.28786 .55934 Mdot
.58856 .31043 Mdot
.54348 .44594 Mdot
.35075 .31587 Mdot
.83564 .64468 Mdot
.42831 .76102 Mdot
.31601 .72729 Mdot
.77815 .62372 Mdot
.32998 .21001 Mdot
.49816 .84376 Mdot
.29256 .52591 Mdot
.2742 .3554 Mdot
.44488 .70797 Mdot
.58759 .42047 Mdot
.54182 .65634 Mdot
.69808 .68448 Mdot
.51377 .81202 Mdot
.40815 .2771 Mdot
.55321 .66357 Mdot
.39265 .50052 Mdot
.54671 .81128 Mdot
.58112 .45707 Mdot
.47101 .79857 Mdot
.50346 .26809 Mdot
.79601 .4559 Mdot
.57192 .62105 Mdot
.32063 .48399 Mdot
.51139 .79282 Mdot
.64275 .2468 Mdot
.2307 .37278 Mdot
.28203 .23631 Mdot
.40784 .36054 Mdot
.82258 .53685 Mdot
.43989 .54595 Mdot
.90285 .50936 Mdot
.36297 .25643 Mdot
.41271 .24483 Mdot
.30461 .28298 Mdot
.44984 .32399 Mdot
.35599 .67602 Mdot
.38397 .62918 Mdot
.24292 .62409 Mdot
.40194 .74497 Mdot
.61162 .68853 Mdot
.73317 .65274 Mdot
.28399 .4292 Mdot
.36587 .49237 Mdot
.29868 .50104 Mdot
.54846 .56368 Mdot
.66156 .60657 Mdot
.85036 .54588 Mdot
.57179 .3985 Mdot
.32416 .61536 Mdot
.52591 .57653 Mdot
.45935 .70187 Mdot
.16287 .64942 Mdot
.59876 .47719 Mdot
.31234 .60056 Mdot
.47256 .77765 Mdot
.56953 .6343 Mdot
.72869 .3145 Mdot
.76568 .77017 Mdot
.91819 .50612 Mdot
.58437 .60119 Mdot
.49708 .19298 Mdot
.46042 .77657 Mdot
.32313 .70282 Mdot
.3667 .33801 Mdot
.58378 .26072 Mdot
.32492 .6641 Mdot
.7001 .65128 Mdot
.50415 .62984 Mdot
.3678 .24908 Mdot
.58246 .83935 Mdot
.72386 .65551 Mdot
.35863 .76749 Mdot
.36044 .65228 Mdot
.51157 .61897 Mdot
.5142 .89392 Mdot
.28295 .63237 Mdot
.44543 .65665 Mdot
.51114 .67135 Mdot
.45329 .53077 Mdot
.41761 .62487 Mdot
.20596 .54981 Mdot
.20811 .3408 Mdot
.35167 .52752 Mdot
.35047 .74862 Mdot
.6741 .62901 Mdot
.48988 .29634 Mdot
.6309 .44561 Mdot
.58248 .39953 Mdot
.48048 .63469 Mdot
.62413 .41347 Mdot
.48618 .50171 Mdot
.16914 .60894 Mdot
.41332 .43448 Mdot
.2678 .2824 Mdot
.44496 .85416 Mdot
.56525 .78077 Mdot
.73627 .37251 Mdot
.4965 .58488 Mdot
.36034 .73817 Mdot
.48784 .82085 Mdot
.57983 .54139 Mdot
.16938 .47754 Mdot
.74253 .21791 Mdot
.71735 .33742 Mdot
.66346 .76025 Mdot
.57724 .5842 Mdot
.43388 .40858 Mdot
.42998 .77313 Mdot
.68251 .34535 Mdot
.48618 .3318 Mdot
.37811 .66368 Mdot
.60591 .56094 Mdot
.626 .40169 Mdot
.49344 .1255 Mdot
.41438 .55108 Mdot
.74982 .3742 Mdot
.41531 .81932 Mdot
.66759 .70244 Mdot
.53498 .74344 Mdot
.44534 .64597 Mdot
.71604 .54408 Mdot
.58018 .45932 Mdot
.2162 .61437 Mdot
.70447 .74001 Mdot
.31019 .69304 Mdot
.58037 .777 Mdot
.45351 .77943 Mdot
.4583 .62667 Mdot
.35855 .36682 Mdot
.66236 .37042 Mdot
.22974 .60063 Mdot
.47624 .5453 Mdot
.49829 .85196 Mdot
.57016 .35923 Mdot
.4724 .47264 Mdot
.61259 .49884 Mdot
.87238 .55854 Mdot
.50851 .6974 Mdot
.52517 .63762 Mdot
.83604 .52123 Mdot
.56466 .34484 Mdot
.26576 .40402 Mdot
.53629 .36155 Mdot
.49074 .56388 Mdot
.66844 .58925 Mdot
.84828 .45013 Mdot
.23052 .57767 Mdot
.64751 .27801 Mdot
.60526 .28381 Mdot
.51607 .2122 Mdot
.62375 .47043 Mdot
.56016 .88532 Mdot
.36845 .27068 Mdot
.85129 .48303 Mdot
.31849 .23853 Mdot
.62561 .55996 Mdot
.20327 .40704 Mdot
.49888 .6245 Mdot
.4849 .33639 Mdot
.32543 .71771 Mdot
.33057 .61147 Mdot
.74094 .68956 Mdot
.48019 .6021 Mdot
.7977 .63701 Mdot
.32701 .42954 Mdot
.45537 .26354 Mdot
.31973 .29208 Mdot
.47038 .70394 Mdot
.28846 .74245 Mdot
.71071 .30487 Mdot
.30072 .74617 Mdot
.26874 .71052 Mdot
.38206 .79741 Mdot
.74148 .67826 Mdot
.69192 .22444 Mdot
.30956 .30188 Mdot
.18521 .54875 Mdot
.63559 .32824 Mdot
.44398 .6933 Mdot
.35019 .27944 Mdot
.583 .56066 Mdot
.74861 .46118 Mdot
.65912 .50436 Mdot
.45168 .08038 Mdot
.33724 .5049 Mdot
.54314 .61296 Mdot
.34548 .29098 Mdot
.43186 .82311 Mdot
.45547 .70767 Mdot
.25546 .34363 Mdot
.50223 .45821 Mdot
.35194 .57848 Mdot
.51728 .8105 Mdot
.47234 .20298 Mdot
.44732 .24726 Mdot
.25858 .23567 Mdot
.23619 .3481 Mdot
.61955 .26204 Mdot
.52909 .45511 Mdot
.58547 .6039 Mdot
.66274 .22729 Mdot
.35896 .30986 Mdot
.17056 .45862 Mdot
.16706 .5687 Mdot
.27979 .62821 Mdot
.34767 .17885 Mdot
.44933 .21419 Mdot
.53521 .84305 Mdot
.19593 .42834 Mdot
.58291 .60098 Mdot
.28192 .51864 Mdot
.47493 .39137 Mdot
.63766 .29452 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`2?ooooo`;o0000^?ooool001cooooo00?o0000ooooooooool0Soooool2o`000;So
oooo000Looooo`03o`000?oooooooooo0:;ooooo0_l0002Uooooo`007?ooool00ol0003ooooooooo
o`2Rooooo`;o0000YOooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003ooooo
ooooo`2booooo`;o0000UOooool001cooooo00?o0000ooooooooool0[Oooool2o`0000?ooooo0_l0
002Eooooo`007?ooool00ol0003oooooooooo`2]ooooo`;o0000V_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2]ooooo`;o0000V_ooool001cooooo
00?o0000ooooooooool0[Oooool2o`0000[ooooo0_l00003ooooo`;o0000ROooool001cooooo00?o
0000ooooooooool0ZOooool2o`0000kooooo0_l00003ooooo`;o0000ROooool001cooooo00?o0000
ooooooooool0WOooool2o`0000[ooooo0_l0002Nooooo`007?ooool00ol0003oooooooooo`2Boooo
o`;o00002Oooool2o`0002Oooooo0_l00021ooooo`007?ooool00ol0003oooooooooo`25ooooo`;o
00002oooool2o`0003;ooooo0_l00021ooooo`007?ooool00ol0003oooooooooo`25ooooo`;o0000
4_ooool2o`000:kooooo000Looooo`03o`000?oooooooooo08gooooo0_l0000:ooooo`;o0000[_oo
ool001cooooo00?o0000ooooooooool0SOooool2o`0002oooooo0_l00029ooooo`007?ooool00ol0
003oooooooooo`2eooooo`;o00001oooool2o`0008Wooooo000Looooo`03o`000?oooooooooo0;Go
oooo0_l00006ooooo`;o0000R_ooool001cooooo00?o0000ooooooooool0UOooool2o`0002Kooooo
0_l0002:ooooo`007?ooool2o`0008Oooooo0_l0000=ooooo`;o00004?ooool2o`000:3ooooo000L
ooooo`03o`000?oooooooooo08Gooooo0ol0000Mooooo`Co0000X?ooool001cooooo00?o0000oooo
ooooool0N_ooool2o`0000Wooooo0_l00004ooooo`;o00001oooool2o`0000Wooooo0_l00004oooo
o`;o0000X_ooool001cooooo00?o0000ooooooooool0N_ooool2o`0000oooooo0_l00003ooooo`;o
00000_ooool2o`0000Wooooo0_l0000Rooooo`;o0000Q?ooool001cooooo00?o0000ooooooooool0
P_ooool2o`0000Cooooo0_l00006ooooo`?o00002?ooool2o`0000Cooooo0_l0000Pooooo`Co0000
P_ooool001cooooo00?o0000ooooooooool0K_ooool2o`0001;ooooo0_l00004ooooo`;o00001ooo
ool2o`0000;ooooo0_l00004ooooo`;o00001?ooool2o`0000Cooooo0_l0000Looooo`;o0000P_oo
ool001cooooo00?o0000ooooooooool0K_ooool2o`0002Gooooo0_l0000@ooooo`;o00001Oooool2
o`0009Wooooo000Looooo`03o`000?oooooooooo08_ooooo0_l0000<ooooo`;o00003?ooool2o`00
00Gooooo0_l0002Iooooo`007?ooool00ol0003oooooooooo`24ooooo`;o00001Oooool2o`0000Co
oooo0_l00006ooooo`;o00003?ooool2o`0000Wooooo0_l0002Eooooo`007?ooool00ol0003ooooo
ooooo`1]ooooo`Co00004oooool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`;o0000
5?ooool2o`0000Wooooo0_l0002Eooooo`007?ooool00ol0003oooooooooo`1Zooooo`;o000000?o
ooooo`000?l000000_l0000Fooooo`;o00001?ooool2o`0000kooooo0_l00008ooooo`;o0000;?oo
ool2o`0007;ooooo000Looooo`03o`000?oooooooooo05gooooo0_l0000;ooooo`;o00008_ooool2
o`0000_ooooo1?l000001?oooooo0000o`000?l0000Iooooo`;o00004_ooool2o`0000?ooooo0_l0
000Cooooo`;o0000GOooool001cooooo00?o0000ooooooooool0GOooool2o`0002cooooo0_l00000
0ooooooo0000o`000007ooooo`;o00000_ooool2o`0000?ooooo0ol0000>ooooo`;o00001Oooool6
o`000003ooooool0003o000000Cooooo0_l00009ooooo`;o00006?ooool2o`0005gooooo00001_oo
ooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003ooooooooo
o`25ooooo`;o00001?ooool2o`000003ooooool0003o000000Oooooo0_l00005ooooo`;o00004?oo
ool3o`0000Gooooo1?l000000ooooooo0000o`000002o`0000Cooooo0_l00022ooooo`0000Kooooo
ogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Ko
oooo00?o0000ooooooooool0KOooool2o`0001Kooooo0_l00003ooooo`;o00000_ooool2o`0000co
oooo1?l00006ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00000oooool2o`00
00Kooooo0_l0002:ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03
oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0KOooool2o`0001Gooooo1?l00002ooooo`;o
00002Oooool2o`0000Gooooo0_l00008ooooo`;o000000Coooooo`000?l0003ooooo0_l00007oooo
o`;o00004Oooool2o`0007oooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_o
oooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0006Oooooo0_l0000Hooooo`;o000000?oooooo`000?l0
00000_l0000=ooooo`?o000000?oooooo`000?l000001?l00006ooooo`;o00003oooool2o`000003
ooooool0003o000000?ooooo0_l00004ooooo`;o00000_ooool2o`0000cooooo0_l0001aooooo`00
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00Gooooo
00?o0000ooooooooool0Ioooool2o`0001Cooooo0_l00002ooooo`;o00004oooool2o`000003oooo
ool0003o000000Co00001_ooool2o`0000oooooo0_l000000ooooooo0000o`000003ooooo`;o0000
1?ooool2o`00013ooooo0ol0001`ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0K?ooool2o`0000Gooooo0_l0
0008ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00003Oooool2o`0003Wooooo
0_l00004ooooo`;o0000L?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o
^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0Ioooool2o`0000?ooooo0_l000000ooo
oooo0000o`000004o`0000;ooooo0_l00007ooooo`;o000000?oooooo`000?l000000_ooool2o`00
00;ooooo0_l00009ooooo`;o00000_ooool2o`0000Sooooo0_l00002ooooo`;o00006oooool2o`00
00[ooooo0_l0001fooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Wooooo`;o00001?ooool6o`000003ooooool0
003o000000?o000000Coooooo`000?l0003o00001_ooool2o`0000Kooooo0_l000000ooooooo0000
o`000004ooooo`Go000000Coooooo`000?l0003ooooo0_l00003ooooo`Co00000_ooool2o`0001_o
oooo0_l00022ooooo`007?ooool00ol0003oooooooooo`1Wooooo`;o00001?ooool3o`0000Cooooo
0ol00003ooooo`?o00000_ooool2o`0000[ooooo1Ol00004ooooo`Go00001?ooool2o`0000?ooooo
0ol00004ooooo`;o0000:Oooool2o`0001Oooooo0_l0001Jooooo`007?ooool00ol0003ooooooooo
o`1^ooooo`;o00002?ooool2o`0000Gooooo0ol00009ooooo`?o00000oooool2o`0001Kooooo0_l0
000Aooooo`Co000000?oooooo`000?l000002Oooool2o`0000Kooooo0_l0000Gooooo`;o0000F_oo
ool001cooooo00?o0000ooooooooool0N?ooool2o`0000Gooooo0ol0000:ooooo`;o00000oooool2
o`0002Kooooo0_l000000ooooooo0000o`000005o`0000?ooooo0_l00004ooooo`;o00002?ooool2
o`0000Gooooo0_l0001Zooooo`007?ooool00ol0003oooooooooo`1cooooo`;o00004Oooool2o`00
00;ooooo0_l00003ooooo`;o00005Oooool4o`0000oooooo0_l00003ooooo`Co00000_ooool4o`00
00Sooooo0_l000001?oooooo0000o`000?ooool2o`0000Gooooo0_l0001Zooooo`007?ooool00ol0
003oooooooooo`1cooooo`;o00004Oooool2o`0000;ooooo0ol00002ooooo`Ko00000_ooool2o`00
00gooooo1?l00002ooooo`;o00001_ooool4o`0000Sooooo0_l00002ooooo`Co00002?ooool2o`00
0003ooooool0003o000000cooooo0_l0001Vooooo`007?ooool00ol0003oooooooooo`1@ooooo`;o
00008_ooool2o`0000?ooooo0_l0000@ooooo`?o00000_ooool5o`0000;ooooo0_l0000Cooooo`;o
00001_ooool4o`0000Sooooo0_l00003ooooo`?o00004?ooool2o`0000Oooooo0_l0001Vooooo`00
7?ooool00ol0003oooooooooo`1@ooooo`;o00001_ooool2o`0000[ooooo0_l00002ooooo`;o0000
1?ooool2o`0000Cooooo0_l00003ooooo`;o00004Oooool2o`0000;ooooo0_l0000Eooooo`;o0000
0oooool3o`0000;ooooo0ol0000>ooooo`;o00003_ooool2o`0000Cooooo0_l0000<ooooo`;o0000
HOooool001cooooo00?o0000ooooooooool0D?ooool2o`0000Kooooo0_l0000:ooooo`;o00000_oo
ool2o`0000Cooooo0_l0000<ooooo`;o00001Oooool2o`0000Gooooo0_l0000=ooooo`;o00003?oo
ool2o`0000?ooooo1?l000001?oooooo0000o`000?l0000>ooooo`;o00003_ooool2o`0000Oooooo
0_l00009ooooo`;o0000HOooool001cooooo00?o0000ooooooooool0I?ooool4o`0000_ooooo0_l0
0007ooooo`;o00001Oooool2o`0000Gooooo1?l00006ooooo`;o000000?oooooo`000?l000000_l0
000Cooooo`;o0000:oooool2o`0006cooooo000Looooo`03o`000?oooooooooo05_ooooo0_l00004
ooooo`;o00000oooool2o`0000Oooooo0_l00002ooooo`;o00001Oooool2o`0000Kooooo0_l00006
ooooo`Co00001_ooool2o`000003ooooool0003o000000cooooo1?l00003ooooo`;o00008_ooool2
o`0000Sooooo0_l0001]ooooo`007?ooool00ol0003oooooooooo`1Iooooo`Co00001?ooool2o`00
00Cooooo0_l00004ooooo`Co00000oooool4o`0000;ooooo0_l00005ooooo`?o00001?ooool2o`00
00Cooooo0_l000000ooooooo0000o`000002o`0000kooooo1_l00003ooooo`;o00001oooool2o`00
01Kooooo0_l000001?oooooo0000o`000?l00007ooooo`;o0000KOooool001cooooo0_l0001Joooo
o`;o00003?ooool2o`0000Cooooo0_l00005ooooo`Co00001_ooool2o`000003ooooool0003o0000
00Cooooo1Ol000001Ooooooo0000o`000?l0003ooooo00Co00003_ooool2o`00013ooooo0_l00007
ooooo`;o00003Oooool2o`0000;ooooo0_l00006ooooo`Co00002oooool2o`0005oooooo000Loooo
o`03o`000?oooooooooo05Oooooo0_l0000Dooooo`;o00001oooool3o`000003ooooool0003o0000
00;ooooo0_l00007ooooo`;o000000?oooooo`000?l000000ol00005ooooo`;o00001_ooool2o`00
00[ooooo0_l0000Dooooo`;o00006Oooool4o`0000Gooooo0ol00003ooooo`;o0000Goooool001co
oooo00?o0000ooooooooool0E_ooool3o`0000Wooooo0_l0000>ooooo`;o00000_ooool3o`000004
ooooool0003o0000ooooo`;o00000oooool3o`000003ooooool0003o000000Cooooo0_l00006oooo
o`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000007ooooo`;o00005oooool2o`00
00gooooo0_l0000<ooooo`Oo0000I?ooool001cooooo00?o0000ooooooooool0E_ooool2o`0000Wo
oooo0ol0000=ooooo`?o00002Oooool2o`0000?ooooo0ol000000ooooooo0000o`000008ooooo`;o
00001_ooool2o`0000Gooooo0_l0000Iooooo`;o00001Oooool2o`0000gooooo0_l00002ooooo`;o
00001_ooool7o`0000Oooooo0_l000000ooooooo0000o`00001Jooooo`007?ooool00ol0003ooooo
ooooo`1Qooooo`?o00003Oooool4o`0000;ooooo0_l00009ooooo`;o00003?ooool2o`0000Oooooo
0_l00009ooooo`;o00002oooool2o`0000Oooooo0_l00002ooooo`;o00001Oooool2o`0000?ooooo
0_l00008ooooo`;o00001_ooool2o`0000?ooooo0ol00003ooooo`;o000000Coooooo`000?l0003o
oooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`1Rooooo`?o00003?ooool4o`0000;ooooo
0_l00009ooooo`;o00002Oooool2o`000004ooooool0003o0000ooooo`;o00001?ooool2o`0000Wo
oooo0_l0000;ooooo`;o000000?oooooo`000?l000001_ooool4o`0000Gooooo1?l000000ooooooo
0000o`00000Fooooo`;o00000oooool2o`000003ooooool0003o000005gooooo000Looooo`03o`00
0?oooooooooo05Cooooo0_l00006ooooo`?o00001?ooool2o`0000cooooo0_l000000ooooooo0000
o`00000Gooooo`;o000000Coooooo`000?l0003ooooo0_l00006ooooo`;o00000_ooool3o`0000[o
oooo0_l00003ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Wooooo0_l0000Eooooo`;o
0000JOooool001cooooo00?o0000ooooooooool0E?ooool2o`0000Kooooo0ol0000Eooooo`;o0000
2oooool2o`0000gooooo0_l00009ooooo`;o00000_ooool3o`0000Sooooo1?l0000;ooooo`;o0000
0oooool2o`000003ooooool0003o000000Cooooo0_l0000Booooo`;o000000?oooooo`000?l00000
2_ooool2o`0005gooooo000Looooo`03o`000?oooooooooo05Sooooo0_l0000=ooooo`;o00000ooo
ool2o`0000[ooooo0_l00007ooooo`?o00001_ooool2o`0000Sooooo0_l0000Dooooo`;o00002?oo
ool2o`0000?ooooo0_l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000
o`000003ooooo`;o00000_ooool2o`0000Wooooo0ol00004ooooo`;o00001_ooool2o`0000Kooooo
0_l0001Eooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o00003Oooool4o`000003ooooool0
003o000000?o00001oooool2o`0000Oooooo0ol00006ooooo`;o00002?ooool2o`0001;ooooo0_l0
000:ooooo`Go00002oooool2o`0000?ooooo0_l000000ooooooo0000o`000006o`0000Sooooo1?l0
0002ooooo`;o00003_ooool2o`0005Gooooo000Looooo`03o`000?oooooooooo05?ooooo0_l00007
ooooo`;o000000Coooooo`000?l0003o00000oooool2o`0000;ooooo0_l00003ooooo`?o00002?oo
ool4o`0000Cooooo0_l00009ooooo`;o00001Oooool2o`0001?ooooo0_l00003ooooo`;o00001_oo
ool4o`0000Cooooo0_l00008ooooo`Co00000_ooool7o`000003ooooool0003o000000Oooooo0_l0
001Yooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00001oooool2o`000004ooooool0003o
0000o`0000?ooooo0ol0000=ooooo`;o000000?oooooo`000?l000000ol0000?ooooo`;o00001Ooo
ool2o`0001;ooooo0ol00003ooooo`;o00003_ooool2o`0000;ooooo0_l00002ooooo`Co00003?oo
ool2o`0000;ooooo0_l0001^ooooo`007?ooool00ol0003oooooooooo`1Qooooo`;o00000oooool2
o`0000Oooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l0000<ooooo`;o00003Ooo
ool2o`0000Kooooo0_l00005ooooo`;o00003_ooool2o`0000;ooooo0_l00003ooooo`?o00000_oo
ool2o`0001;ooooo0_l0001^ooooo`007?ooool00ol0003oooooooooo`1Qooooo`;o000000?ooooo
o`000?l000001?ooool4o`000003ooooool0003o000001Sooooo0_l00006ooooo`;o00001Oooool2
o`0000Kooooo0ol00003ooooo`Co00000oooool2o`0000Sooooo0_l00002ooooo`;o00000oooool2
o`0000Sooooo0_l0000Cooooo`;o00001?ooool2o`0006;ooooo000Looooo`03o`000?oooooooooo
05kooooo0_l00003ooooo`?o00000oooool5o`0000oooooo0_l00004ooooo`;o00003?ooool2o`00
00Sooooo0_l00004ooooo`;o00000oooool5o`0000;ooooo0_l0000:ooooo`;o00003oooool5o`00
013ooooo0_l00004ooooo`;o00003?ooool2o`0005Cooooo000Looooo`03o`000?oooooooooo05ko
oooo0_l00003ooooo`;o00001?ooool3o`00017ooooo0_l00004ooooo`;o00003oooool2o`0000Go
oooo0_l00002ooooo`;o00002?ooool2o`0000;ooooo0_l0000:ooooo`;o00001?ooool2o`0000[o
oooo1?l0000;ooooo`Co00002?ooool2o`0000_ooooo0_l0001Dooooo`007?ooool2o`0005Gooooo
1?l00008ooooo`;o000000?oooooo`000?l000001Oooool2o`0002?ooooo0_l00003ooooo`?o0000
1?ooool2o`0000;ooooo0_l0000:ooooo`;o00004?ooool4o`0000Gooooo0_l00003ooooo`So0000
1oooool4o`0000Kooooo1?l00003ooooo`;o0000G?ooool001cooooo00?o0000ooooooooool0C?oo
ool2o`0000;ooooo2?l00008ooooo`Go00000oooool2o`00023ooooo0_l00003ooooo`;o000000Co
ooooo`000?l0003ooooo0_l0000:ooooo`?o00001oooool2o`0000_ooooo0_l00003ooooo`;o0000
1oooool2o`0000?ooooo2?l00006ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o0000
0_ooool2o`000003ooooool0003o000005cooooo000Looooo`03o`000?oooooooooo04Sooooo0ol0
00000ooooooo0000o`000002ooooo`Co00003Oooool2o`0000Gooooo0_l0000Pooooo`;o00001_oo
ool2o`0000Oooooo1?l00002ooooo`Co00001_ooool2o`0000Gooooo0_l00004ooooo`;o00005_oo
ool2o`0000;ooooo0_l00003ooooo`?o00000_ooool2o`0000?ooooo0_l00003ooooo`;o000000?o
ooooo`000?l00000G?ooool001cooooo00?o0000ooooooooool0B?ooool3o`0002Kooooo0_l00005
ooooo`;o00002oooool2o`0000?ooooo0_l00005ooooo`;o00002?ooool<o`0000Cooooo0_l00005
ooooo`;o00001?ooool2o`000003ooooool0003o000000_ooooo0_l00003ooooo`;o000000?ooooo
o`000?l000000_ooool2o`0000Cooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo0_l0001P
ooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o00002?ooool2o`0000;ooooo1?l000000ooo
oooo0000o`000005ooooo`;o00002oooool2o`0000?ooooo0_l00005ooooo`;o00002_ooool:o`00
00?ooooo0ol0000:ooooo`?o000000?oooooo`000?l000002oooool2o`0000?ooooo0_l0000=oooo
o`Go00001_ooool2o`00017ooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`1Nooooo`;o
00002?ooool2o`0000;ooooo1?l0000Sooooo`;o00000_ooool2o`000003ooooool0003o000000;o
000000?oooooo`000?l000002ol0000;ooooo`?o00000oooool2o`0000Wooooo1_l00003ooooo`;o
00002Oooool3o`0000;ooooo0_l00006ooooo`?o00000oooool2o`0000Wooooo0_l0001=ooooo`00
7?ooool00ol0003oooooooooo`1<ooooo`;o00008?ooool2o`0001Oooooo0_l00003ooooo`?o0000
1?ooool2o`0000;ooooo2ol00002ooooo`So000000?oooooo`000?l000002Oooool2o`0000?ooooo
0_l00009ooooo`Ko00000oooool2o`0000kooooo0_l00006ooooo`?o00000oooool3o`0005Oooooo
000Looooo`03o`000?oooooooooo04cooooo0_l0000Hooooo`;o00004?ooool2o`0000Wooooo0_l0
0002ooooo`;o00000oooool4o`0000Sooooo4_l00003ooooo`;o000000?oooooo`000?l000000_oo
ool2o`000004ooooool0003o0000o`0002Sooooo0_l00009ooooo`;o000000Coooooo`000?l0003o
0000E_ooool001cooooo00?o0000ooooooooool0EOooool2o`0000Wooooo0_l00004ooooo`;o0000
3Oooool2o`000003ooooool0003o000000Wooooo0_l00008ooooo`?o00001?ooool@o`000003oooo
ool0003o000000Go00001?ooool3o`000004ooooool0003o0000ooooo`?o00002_ooool6o`0000co
oooo0_l0000:ooooo`Co00001oooool2o`0000;ooooo0_l0001Fooooo`007?ooool00ol0003ooooo
ooooo`1Eooooo`Co00001oooool3o`0001;ooooo0_l0000Fooooo`?o000000Coooooo`000?l0003o
oooo6_l00002ooooo`?o00001?ooool3o`0000[ooooo1_l000000ooooooo0000o`000009ooooo`;o
00001_ooool2o`0000Cooooo0_l000000ooooooo0000o`00001Pooooo`007?ooool00ol0003ooooo
ooooo`16ooooo`;o00000_ooool2o`0000?ooooo0_l00004ooooo`Co000000?oooooo`000?l00000
0_ooool2o`000003ooooool0003o000002[ooooo0_l000000ooooooo0000o`000002o`000003oooo
ool0003o000001Oo00000_ooool3o`0000?ooooo0ol0000Aooooo`?o00002_ooool2o`0000Gooooo
0_l00003ooooo`?o000000?oooooo`000?l000005Oooool2o`0004Wooooo000Looooo`03o`000?oo
oooooooo04Kooooo0_l00002ooooo`;o00000_ooool3o`0000Wooooo0_l00002ooooo`;o00004?oo
ool2o`0001?ooooo0_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000007Ol0
0002ooooo`;o00000_ooool3o`0001;ooooo1Ol00008ooooo`;o00002_ooool3o`0001Sooooo0_l0
0019ooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o00004oooool2o`0000_ooooo0_l00000
0ooooooo0000o`00000@ooooo`;o000000?oooooo`000?l000000oooool2o`000003ooooool0003o
0000027o00000_ooool2o`0000Kooooo0_l00008ooooo`?o000000?oooooo`000?l000000_l0000F
ooooo`;o00001_ooool4o`0005Sooooo000Looooo`03o`000?oooooooooo03cooooo0_l00002oooo
o`;o00001_ooool2o`00017ooooo0ol00005ooooo`Co00002?ooool2o`0000;ooooo0_l00003oooo
o`;o00002oooool2o`0000Wooooo8Ol00005ooooo`;o00001Oooool2o`0000Oooooo1?l000000ooo
oooo0000o`00000<ooooo`;o00002_ooool2o`0000Kooooo1?l0000;ooooo`;o0000Boooool001co
oooo00?o0000ooooooooool0??ooool6o`0000Kooooo1?l00003ooooo`Oo00001Oooool3o`0000Oo
oooo0_l00008ooooo`;o00001oooool2o`0000Wooooo0_l000000ooooooo0000o`000008oooooaGo
000000?oooooo`000?l000002?l00006ooooo`;o00001Oooool2o`0000Oooooo0_l0000=ooooo`;o
00000_ooool2o`0000Sooooo0_l0000Gooooo`;o0000Boooool001cooooo00?o0000ooooooooool0
?_ooool2o`0000[ooooo0_l00003ooooo`Oo00004?ooool2o`0001_ooooo0_l000000ooooooo0000
o`000002ooooo`;o00001?oooolPo`000004ooooool0003o0000ooooo`;o00001oooool2o`0000;o
oooo0_l00007ooooo`;o00001Oooool2o`0000;ooooo0_l00003ooooo`;o00001oooool2o`0001co
oooo0_l000000ooooooo0000o`000013ooooo`007?ooool2o`0004[ooooo1?l0000Hooooo`?o0000
4?ooool2o`0000Wooooo0_l00005ooooo`Co000000?oooooo`000?l000007_l000001Ooooooo0000
o`000?l0003ooooo00;o00002oooool2o`0000Oooooo0_l00005ooooo`;o00001oooool2o`0000?o
oooo0_l00002ooooo`;o000000?oooooo`000?l000003?ooool2o`0000_ooooo0_l000000ooooooo
0000o`000013ooooo`007?ooool00ol0003oooooooooo`10ooooo`;o000000?oooooo`000?l00000
1?ooool6o`0001Kooooo0_l00005ooooo`;o00000_ooool2o`0000Gooooo0ol0000?ooooo`;o0000
00?oooooo`000?l000006_l000001Ooooooo0000o`000?l0003ooooo00;o000000Coooooo`000?l0
003o00001oooool2o`0000Gooooo0_l000001?oooooo0000o`000?l0000Hooooo`Co00000oooool3
o`000004ooooool0003o0000o`0000Oooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`0h
ooooo`;o000000?oooooo`000?l000000oooool2o`000003ooooool0003o000000Sooooo0_l00003
ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Oooooo0_l00002ooooo`;o00000_ooool6
o`0000Gooooo0_l0000@ooooo`;o00000_oooolVo`0000?ooooo0_l00002ooooo`;o00001Oooool2
o`000004ooooool0003o0000o`0001Wooooo0ol00002ooooo`Co000000Coooooo`000?l0003o0000
1Oooool3o`0000Cooooo0_l0000:ooooo`;o0000@_ooool001cooooo00?o0000ooooooooool0>?oo
ool2o`000003ooooool0003o000001Gooooo0_l000000ooooooo0000o`000004ooooo`;o00001ooo
ool2o`0000;ooooo0_l00002ooooo`Ko00004Oooool2o`0000Sooooo2_l000000ooooooo0000o`00
000Go`0000Cooooo0ol0000@ooooo`;o00000oooool2o`0000Oooooo0_l00004ooooo`?o00000_oo
ool3o`000003ooooool0003o000000?o00000_ooool2o`0000Cooooo0ol00004ooooo`Co00002?oo
ool2o`0004;ooooo000Looooo`03o`000?oooooooooo03oooooo0_l000000ooooooo0000o`000003
o`0001[ooooo0_l000000ooooooo0000o`000003ooooo`;o00000oooool2o`000003ooooool0003o
000000kooooo1?l00009ooooob7o00000_ooool2o`0000;ooooo0_l00002ooooo`;o00003Oooool2
o`0000?ooooo0_l00007ooooo`;o00001?ooool3o`0000;ooooo0ol00004ooooo`;o00000_ooool2
o`0000?ooooo0ol00005ooooo`Go0000Boooool001cooooo00?o0000ooooooooool0?oooool2o`00
0003ooooool0003o000000Go00001?ooool2o`0000_ooooo0_l00005ooooo`;o00001_ooool2o`00
0003ooooool0003o000000Ko00001oooool2o`0000Cooooo0_l0000;ooooob3o00000oooool2o`00
00;ooooo0_l00002ooooo`;o00002?ooool2o`0001Kooooo1?l000000ooooooo0000o`00000?oooo
o`?o00000_ooool2o`0000Cooooo0_l0001;ooooo`007?ooool00ol0003oooooooooo`0eooooo`;o
00002?ooool2o`0000Gooooo1?l00002ooooo`?o00002oooool2o`0000Gooooo0_l000001?oooooo
0000o`000?ooool=o`0000Oooooo0_l0000Coooooago00002?ooool2o`0000cooooo0_l00008oooo
o`;o00003?ooool7o`0001?ooooo0ol0001Aooooo`007?ooool00ol0003oooooooooo`0eooooo`;o
00003oooool4o`0000;ooooo1?l0000Aooooo`;o000000?oooooo`000?l000003Ol00002ooooo`;o
00002_ooool2o`0000;ooooo0_l00009oooooa;o000000?oooooo`000?l000001ol0000Fooooo`;o
00002Oooool2o`0000Cooooo0_l00006ooooo`;o00000_ooool4o`000003ooooool0003o000000?o
00000_ooool3o`0000Cooooo0_l000000ooooooo0000o`00001Booooo`007?ooool00ol0003ooooo
ooooo`17ooooo`;o00001Oooool2o`0001Gooooo3_l000001?oooooo0000o`000?l00003ooooo`;o
00000oooool4o`0000;ooooo0_l00009oooooaco00003Oooool2o`0000Oooooo0_l0000?ooooo`?o
00001Oooool2o`0000?ooooo0ol000000ooooooo0000o`000003o`0000;ooooo1?l000000ooooooo
0000o`000002o`0000?ooooo0_l0001@ooooo`007?ooool00ol0003oooooooooo`17ooooo`;o0000
1Oooool2o`0001Cooooo4ol000000ooooooo0000o`000003o`0000;ooooo0_l0000=ooooo`;o0000
0_ooool2o`000003ooooool0003o000001?o00003oooool2o`0000Cooooo0_l00002ooooo`;o0000
3_ooool3o`0000Oooooo0_l000001?oooooo0000o`000?ooool2o`0000Kooooo1?l000000ooooooo
0000o`000005ooooo`;o0000D?ooool001cooooo00?o0000ooooooooool0@Oooool2o`0000_ooooo
0_l0000:ooooo`;o00001_oooolEo`000003ooooool0003o000000?o00001oooool2o`0000Sooooo
0_l000000ooooooo0000o`00000Bo`000005ooooool0003o0000o`000?ooool01?l00004ooooo`;o
00002_ooool3o`0000;ooooo0_l00004ooooo`;o00002?ooool2o`0000;ooooo0_l00004ooooo`;o
00000_ooool4o`0000Kooooo0_l00005ooooo`;o0000EOooool001cooooo00?o0000ooooooooool0
>_ooool2o`000005ooooool0003o0000o`000?ooool00_l0000?ooooo`;o000000?oooooo`000?l0
00000oooool2o`0000;ooooo0_l000000ooooooo0000o`00000Io`0000Sooooo0_l0000;ooooo`[o
000000?oooooo`000?l000001ol00002ooooo`;o000000?oooooo`000?l000000_l00004ooooo`;o
00002_ooool2o`0000;ooooo0_l00005ooooo`Co00001_ooool2o`0000;ooooo0_l00003ooooo`;o
00000oooool3o`0000Cooooo0_l00006ooooo`Co00007?ooool2o`0003Oooooo000Looooo`03o`00
0?oooooooooo03[ooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00003Oooool3o`000003
ooooool0003o000000Oooooo7_l0000=ooooo`;o00002?oooolCo`000003ooooool0003o000000;o
oooo0ol00003ooooo`;o00002oooool2o`0000;ooooo0ol00003ooooo`Go00003?ooool2o`000003
ooooool0003o000000?ooooo0ol00004ooooo`;o00001_ooool4o`000003ooooool0003o000001Wo
oooo0_l00002ooooo`;o0000<oooool001cooooo00?o0000ooooooooool0=?ooool2o`0000cooooo
1?l00002ooooo`;o00000oooool3o`000003ooooool0003o000000;ooooo0_l00003ooooo`;o0000
1?oooolJo`0000oooooo0_l00005ooooo`;o00000ooooolAo`000003ooooool0003o000000Sooooo
0_l0000;ooooo`Co000000?oooooo`000?l000000_ooool4o`000004ooooool0003o0000ooooo`;o
00000_ooool2o`0000Cooooo0_l0000Cooooo`;o00001Oooool2o`0001gooooo0_l0000cooooo`00
00Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo
00Cooooo00?o0000ooooooooool0=?ooool4o`0000Kooooo0_l00002ooooo`Co00000_ooool2o`00
00?ooooo0ol000000ooooooo0000o`000002ooooo`Co000000?oooooo`000?l000000_l00002oooo
oaWo000000?oooooo`000?l000000_ooool2o`00013ooooo0_l00002ooooo`Go000000Coooooo`00
0?l0003o00000_ooool7o`0001[ooooo1?l00003ooooo`;o00000oooool2o`000003ooooool0003o
000000;ooooo1_l0000:ooooo`;o00002Oooool2o`0000Gooooo0_l0000Xooooo`;o0000:?ooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0fooooo`;o00001_ooool2o`00013ooooo0ol00004ooooo`;o00000_oo
ool3o`0000;ooooo6?l00002ooooo`;o00000_ooool2o`0001;ooooo1?l000001?oooooo0000o`00
0?ooool3o`0000?ooooo1_l0000Eooooo`;o00001Oooool2o`0000?ooooo0_l00002ooooo`?o0000
0_ooool=o`0000Kooooo0_l0000Gooooo`;o00008Oooool2o`0002Sooooo00000ooooooo410@oooo
o`02ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006ooooo`03o`000?oooooooooo03oooooo0_l0
000?ooooo`;o00002_ooool2o`000003ooooool0003o000000_o000000?oooooo`000?l000003Ol0
000Fooooo`?o00001oooool2o`000003ooooool0003o000001Gooooo1ol00004ooooo`;o00001?oo
ool2o`000003ooooool0003o000000;o000000?oooooo`000?l000003?l0000?ooooo`?o00003?oo
ool3o`0004_ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CoA4A4
omgMgOoooooo00001oooool3o`0003oooooo0_l0000Gooooo`;o00000_ooool5o`000003ooooool0
003o000001Ko00002_ooool2o`0000Oooooo0_l0000=ooooo`;o000000?oooooo`000?l000004?oo
ool2o`0000?ooooo1_l00005ooooo`;o00001?ooool:o`000003ooooool0003o000000Ko000000?o
ooooo`000?l000003oooool5o`0000Sooooo1?l000000ooooooo0000o`000019ooooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o
0000ooooooooool0?oooool3o`0000kooooo0_l000000ooooooo0000o`000003ooooo`;o00000ooo
ool2o`000003ooooool0003o000001Go00003Oooool2o`0000Oooooo0_l00006ooooo`;o00001Ooo
ool2o`0001?ooooo0_l00003ooooo`;o00002Oooool2o`0000Cooooo5_l0000Booooo`;o000000?o
ooooo`000?l000001Oooool4o`000003ooooool0003o000004Wooooo00000ooooooo410@ooooo`02
ooooo`03oa0@4?oooooooooo00[ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0n
ooooo`Co00001oooool2o`0000Gooooo0_l000001?oooooo0000o`000?l00002ooooo`?o00000_oo
ool2o`000004ooooool0003o0000oooooaCo00001?ooool2o`0000cooooo0_l00005ooooo`;o0000
0oooool2o`0001oooooo0_l00005ooooo`;o00000_ooool3o`000003ooooool0003o000001Ko0000
0oooool3o`0000oooooo0_l00007ooooo`;o0000C?ooool00006oooooomgMgOoV9RHoooooonHV9So
MgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo03kooooo0_l00009ooooo`;o
00000oooool2o`0000Cooooo0_l00003ooooo`;o00000_ooool2o`0000Cooooo5?l000001?oooooo
0000o`000?ooool2o`0000cooooo0_l00005ooooo`;o0000:oooool2o`0000;ooooo7_l000001?oo
oooo0000o`000?l0000Fooooo`;o0000C_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Ooo
ool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo04kooooo0_l00008ooooo`Co00001?oo
oolGo`000003ooooool0003o000000kooooo0_l0000@ooooo`;o00007?ooool2o`0000Wooooo7?l0
0003ooooo`;o00005Oooool2o`0004kooooo000Looooo`03o`000?oooooooooo027ooooo0_l0000;
ooooo`;o00009Oooool2o`000003ooooool0003o000000;o00001?oooolGo`0000oooooo1?l0000@
ooooo`;o00007?ooool2o`0000Oooooo7Ol00004ooooo`Co00001Oooool2o`0005cooooo000Loooo
o`03o`000?oooooooooo027ooooo0_l0000;ooooo`;o00002Oooool3o`0001Wooooo0_l0000<oooo
oaCo00000_ooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o00001oooool2o`00
00cooooo0_l0000<ooooo`;o00002?ooool2o`0000Cooooo0ol00003oooooa7o000000Coooooo`00
0?l0003ooooo2_l00002ooooo`Co00000_ooool2o`000003ooooool0003o000000;ooooo0_l00004
ooooo`Go00001oooool2o`0004Kooooo000Looooo`03o`000?oooooooooo02?ooooo0_l0000Doooo
o`Co00002Oooool4o`0001_ooooo4_l00002ooooo`;o000000?oooooo`000?l000000_ooool4o`00
00_ooooo0_l0000<ooooo`;o00003?ooool2o`0000Sooooo0_l00004ooooo`?o00001Oooool@o`00
0003ooooool0003o000000_o000000?oooooo`000?l000000_l00002ooooo`;o00001Oooool2o`00
00Cooooo1Ol00007ooooo`;o0000A_ooool001cooooo00?o0000ooooooooool08oooool2o`0001;o
oooo0_l00002ooooo`;o00001Oooool2o`0000;ooooo1?l000000ooooooo0000o`00000=ooooo`;o
00002Oooool4o`000003ooooool0003o000000Wo00001oooool2o`0000Cooooo0_l000000ooooooo
0000o`000004ooooo`;o00000_ooool2o`0000Cooooo0_l0000Fooooo`;o00002Oooool2o`0000Oo
oooo8ol0000>ooooo`Co0000Doooool001cooooo00?o0000ooooooooool0=oooool2o`0000?ooooo
0_l00004ooooo`?o00000_ooool2o`0000;ooooo0_l00009ooooo`;o000000?oooooo`000?l00000
1?l00007ooooo`;o00000_ooool9o`000003ooooool0003o000000?ooooo1ol00002ooooo`;o0000
00?oooooo`000?l000001?ooool2o`0000;ooooo0_l00004ooooo`;o00002_ooool2o`0000[ooooo
0_l00003ooooo`;o00001?ooool4o`0000Gooooo8ol00003ooooo`;o000000?oooooo`000?l00000
1_ooool4o`0000Cooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`0dooooo`;o00000_oo
ool2o`0000;ooooo0_l00005ooooo`?o00004?ooool2o`000003ooooool0003o000000Go00001_oo
ool2o`0000Oooooo0_l00003ooooo`;o00000oooool4o`000003ooooool0003o000000;ooooo0_l0
000?ooooo`;o00002Oooool2o`000003ooooool0003o000000Gooooo0_l00008ooooo`?o00000ooo
ool4o`0000Cooooo4Ol000000ooooooo0000o`00000>o`000003ooooool0003o000000;ooooo0_l0
00000ooooooo0000o`00000>ooooo`;o00002Oooool2o`0004;ooooo000Looooo`03o`000?oooooo
oooo02gooooo0_l00005ooooo`;o00000_ooool2o`0000[ooooo0_l00007ooooo`;o00003?ooool2
o`000004ooooool0003o0000o`0001cooooo0_l00003ooooo`?o00002?ooool2o`0000Cooooo0_l0
0006ooooo`Ko000000?oooooo`000?l000001?ooool2o`0000Wooooo0_l00004ooooo`;o00000ooo
oolTo`000005ooooool0003o0000o`000?ooool00_l00008ooooo`;o00000oooool2o`000003oooo
ool0003o000000[ooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`0]ooooo`?o00003?oo
ool2o`0000Cooooo0_l00009ooooo`;o00002Oooool2o`0000Gooooo0_l00003ooooo`;o000000?o
ooooo`000?l000005?ooool2o`0000?ooooo1?l00007ooooo`;o00001?ooool2o`0000?ooooo0_l0
00001Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`000?l000004_ooool2o`000003oooo
ool0003o000000?ooooo0_l00002ooooob3o00000_ooool2o`000003ooooool0003o000000Sooooo
0ol00002ooooo`;o000000?oooooo`000?l000001Oooool2o`0000cooooo0_l0000iooooo`007?oo
ool00ol0003oooooooooo`0^ooooo`;o00000_ooool2o`0000Sooooo1?l00002ooooo`;o00003?oo
ool2o`0000?ooooo0_l000000ooooooo0000o`000004o`0000Kooooo0_l000000ooooooo0000o`00
0007ooooo`?o00001oooool2o`0000Sooooo0_l0000=ooooo`;o00000oooool2o`0000gooooo0_l0
000=ooooo`;o00000_ooool2o`0000Gooooo8?l00003ooooo`;o00003?ooool3o`000003ooooool0
003o000000;o000000?oooooo`000?l000000oooool2o`0000cooooo0_l0000iooooo`007?ooool0
0ol0003oooooooooo`0booooo`?o00001?ooool2o`0000?ooooo0ol000000ooooooo0000o`000003
ooooo`;o00001oooool2o`0000?ooooo0_l00003ooooo`Go00002?ooool2o`0000;ooooo0_l00003
ooooo`?o00001oooool2o`0000?ooooo0_l00003ooooo`;o00008Oooool2o`0000Cooooo0_l00007
ooooo`;o00000_ooool4o`0000?ooooo8?l00003ooooo`;o00003Oooool2o`0000?ooooo0_l00000
0ooooooo0000o`00001<ooooo`007?ooool00ol0003oooooooooo`0cooooo`;o00001?ooool2o`00
00Cooooo1Ol00003ooooo`;o00005?ooool2o`0000Gooooo0_l000000ooooooo0000o`000006o`00
00kooooo1?l00003ooooo`;o000000?oooooo`000?l000009?ooool2o`0000Sooooo0_l00003oooo
o`;o00001OoooolJo`000003ooooool0003o000000Cooooo0ol00004ooooo`;o00008Oooool2o`00
03Wooooo000Looooo`;o0000>Oooool3o`0000Cooooo1?l00009ooooo`;o00001_ooool2o`0000Ko
oooo0_l00003ooooo`;o000000?oooooo`000?l000000oooool2o`0000;ooooo0_l0000>ooooo`;o
00001_ooool4o`0002kooooo0_l00003ooooo`Co00000_oooolKo`000003ooooool0003o000000Co
oooo0ol00002ooooo`Co000000?oooooo`000?l000003?ooool2o`0000Oooooo1?l00005ooooo`Go
0000=_ooool001cooooo00?o0000ooooooooool0=Oooool2o`000004ooooool0003o0000o`0000Co
oooo1?l00006ooooo`;o000000?oooooo`000?l000001_ooool2o`0000?ooooo0_l000001?oooooo
0000o`000?l00002ooooo`?o00004oooool2o`0000_ooooo1_l00007ooooo`;o00001oooool2o`00
00cooooo0_l00007ooooo`Co00002?ooool3o`0000;ooooo0ol00002oooooa?o000000?oooooo`00
0?l000001oooool2o`0000?ooooo0_l00003ooooo`;o00003?ooool2o`0000Oooooo1?l00006oooo
o`Co0000=_ooool001cooooo00?o0000ooooooooool0=?ooool3o`0000Cooooo0_l00004ooooo`;o
00001_ooool2o`0000Sooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00002oooo
o`Co000000?oooooo`000?l000003oooool2o`0000[ooooo0ol000001?oooooo0000o`000?l00007
ooooo`;o000000?oooooo`000?l000000ol000001Ooooooo0000o`000?l0003ooooo00?o00000_oo
ool2o`0000?ooooo0_l00007ooooo`Co00001?ooool2o`0000;ooooo0_l00008oooooa?o00001_oo
ool6o`000003ooooool0003o000000;o00001oooool2o`0000_ooooo0_l00005ooooo`;o0000@Ooo
ool001cooooo00?o0000ooooooooool0=?ooool2o`0000Gooooo0_l0000@ooooo`;o00001?ooool2
o`000003ooooool0003o000000Oooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l00002
ooooo`?o00001_ooool2o`0000cooooo0_l00003ooooo`Go00000_ooool2o`000003ooooool0003o
000000Go00000_ooool2o`000004ooooool0003o0000o`0000;ooooo0ol00006ooooo`;o00002ooo
ool2o`0000?ooooo0_l00008ooooo`?o000000?oooooo`000?l000000_ooool3o`0000;ooooo1?l0
0003ooooo`So00000oooool2o`0000Kooooo1Ol0000;ooooo`;o00006?ooool2o`0002kooooo000L
ooooo`03o`000?oooooooooo02kooooo0_l0000Mooooo`;o00004?ooool2o`0000Kooooo1?l00000
1?oooooo0000o`000?l00006ooooo`;o00001Oooool2o`0000?ooooo0_l00007ooooo`?o00000_oo
ool2o`000003ooooool0003o000000?o00003Oooool2o`0000Cooooo1Ol0000:ooooo`;o00000ooo
ool2o`0000Kooooo0_l000000ooooooo0000o`000003o`0000;ooooo0ol00002ooooo`;o00000ooo
ool7o`0000Wooooo0_l00003ooooo`Go000000?oooooo`000?l000002_ooool2o`0000?ooooo0_l0
000Aooooo`;o0000;_ooool001cooooo00?o0000ooooooooool0;_ooool2o`000003ooooool0003o
000000[ooooo0_l00003ooooo`;o00001_ooool2o`000003ooooool0003o000000?ooooo0_l0000<
ooooo`;o00001_ooool3o`0000Oooooo0_l00008ooooo`;o00000oooool2o`000003ooooool0003o
000000oooooo0_l0000=ooooo`;o00001?ooool2o`000003ooooool0003o000000Cooooo0_l00006
ooooo`;o00001?ooool2o`0000?ooooo0_l00003ooooo`?o00003?ooool2o`0000Gooooo0_l00007
ooooo`;o00001_ooool2o`000003ooooool0003o000000[ooooo0_l00003ooooo`;o0000@Oooool0
01cooooo00?o0000ooooooooool0<Oooool2o`0000[ooooo0_l00003ooooo`;o00000oooool5o`00
0003ooooool0003o000000?ooooo0_l0000<ooooo`;o00003?ooool3o`000003ooooool0003o0000
00gooooo0_l000000ooooooo0000o`00000Booooo`;o00002_ooool2o`0000?ooooo0_l00002oooo
o`;o00001?ooool2o`0000Kooooo0_l00003ooooo`?o00001?ooool5o`0000Cooooo0_l00004oooo
o`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o00000oooool2o`0001_ooooo0_l00003
ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0=oooool2o`0000kooooo1_l00003oooo
o`Co00006_ooool3o`000003ooooool0003o000000kooooo0_l00009ooooo`;o00001oooool4o`00
00cooooo0_l000000ooooooo0000o`000002ooooo`;o00004Oooool2o`0000Gooooo1Ol00004oooo
o`;o00001?ooool2o`000003ooooool0003o000000?o00002?ooool2o`0000kooooo0ol00003oooo
o`;o00001Oooool2o`0000?ooooo0_l00002ooooo`;o0000>oooool001cooooo00?o0000oooooooo
ool0=oooool4o`00013ooooo0_l00003ooooo`Oo00000_ooool2o`00013ooooo0_l00005ooooo`;o
00001oooool2o`0000Cooooo0ol00003ooooo`;o00001?ooool2o`0000Oooooo0_l0000>ooooo`;o
000000?oooooo`000?l000000_l0000Aooooo`Co00003?ooool2o`0000Wooooo1?l00009ooooo`?o
00003Oooool3o`0000;ooooo0ol00002ooooo`Co00002?ooool2o`0003_ooooo000Looooo`03o`00
0?oooooooooo02gooooo0_l00004ooooo`;o00001?ooool2o`0001Sooooo1?l00002ooooo`;o0000
2Oooool2o`0000Gooooo0ol0000=ooooo`;o00001?ooool3o`0000?ooooo0_l0000:ooooo`;o0000
0oooool2o`0000Wooooo0_l00002ooooo`Ko00003oooool9o`0000;ooooo0_l00005ooooo`;o0000
2Oooool2o`0000;ooooo0_l00008ooooo`;o00004?ooool4o`0000?ooooo1?l0000Cooooo`;o0000
<?ooool001cooooo00?o0000ooooooooool0;Oooool3o`0000?ooooo0_l00004ooooo`;o00001Ooo
ool2o`0000cooooo0_l0000Cooooo`Go00001?ooool2o`0000;ooooo0ol00006ooooo`Co00003?oo
ool2o`0000Sooooo0_l00003ooooo`;o00001Oooool2o`0000;ooooo0_l00002ooooo`;o00003Ooo
ool2o`000004ooooool0003o0000ooooo`Co000000?oooooo`000?l000000_l00002ooooo`;o0000
0_ooool2o`0000Kooooo0_l00003ooooo`;o00000oooool2o`000003ooooool0003o000001Oooooo
0_l0000Fooooo`;o00001?ooool2o`0000;ooooo0_l0000/ooooo`007?ooool00ol0003ooooooooo
o`0^ooooo`;o00001?ooool2o`0000?ooooo0_l00005ooooo`;o00003?ooool4o`00017ooooo1Ol0
0004ooooo`;o00000_ooool3o`0000Kooooo1_l00004ooooo`;o00001?ooool2o`0000Oooooo0_l0
000;ooooo`;o000000?oooooo`000?l000003_ooool2o`0000;ooooo0_l000000ooooooo0000o`00
0003ooooo`;o000000?oooooo`000?l000000_l00006ooooo`Co00001?ooool2o`000003ooooool0
003o000000;o00001_ooool2o`0000;ooooo0_l0000Jooooo`;o00003oooool2o`0000Sooooo0_l0
000/ooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o00001Oooool2o`00013ooooo0_l00008
ooooo`;o00000oooool6o`000004ooooool0003o0000o`0000Gooooo0_l0000Dooooo`Go00001?oo
ool2o`0000Cooooo0_l00007ooooo`;o00001_ooool2o`0000Kooooo0_l0000<ooooo`Co00001ooo
ool3o`0000Gooooo0_l00006ooooo`Co00001?ooool2o`000003ooooool0003o000000Gooooo0_l0
0005ooooo`;o00001?ooool2o`00017ooooo0_l000000ooooooo0000o`000006ooooo`;o0000?ooo
ool001cooooo00?o0000ooooooooool0;Oooool2o`0001Oooooo0_l0000=ooooo`Ko000000Cooooo
o`000?l0003o00002?ooool2o`000004ooooool0003o0000o`0000Kooooo0_l0000Dooooo`?o0000
3?ooool4o`0000?ooooo1?l000000ooooooo0000o`00000:ooooo`Co00001oooool3o`0000gooooo
0ol00005ooooo`;o00000oooool2o`0000?ooooo0_l0000;ooooo`;o00004Oooool2o`000003oooo
ool0003o000000Kooooo0_l0000oooooo`007?ooool00ol0003oooooooooo`1?ooooo`So00001_oo
ool2o`0000Sooooo0_l000001?oooooo0000o`000?l00006ooooo`?o000000Coooooo`000?l0003o
oooo0_l00008ooooo`;o00001?ooool2o`0000Kooooo0_l00004ooooo`;o00001Oooool4o`000003
ooooool0003o000000Co00001Oooool2o`0001[ooooo0ol00009ooooo`?o00002?ooool2o`0001Wo
oooo0_l000000ooooooo0000o`000004ooooo`;o0000@Oooool001cooooo00?o0000ooooooooool0
=Oooool2o`0000?ooooo0_l00005ooooo`;o00003?ooool8o`0000Kooooo0_l0000Dooooo`?o0000
00Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000005ooooo`;o00000oooool3o`0000Ko
oooo1?l00008ooooo`;o00001Oooool5o`0000Gooooo0_l00005ooooo`;o00002oooool2o`0000Ko
oooo0_l00003ooooo`Go00000_ooool2o`0000Wooooo0_l0000Eooooo`;o00001Oooool2o`0000Co
oooo0_l00011ooooo`007?ooool2o`0003Kooooo0_l00003ooooo`;o00001?ooool3o`0001[ooooo
0_l0000Iooooo`;o000000?oooooo`000?l000000_l00005ooooo`Co000000Coooooo`000?l0003o
oooo0_l00006ooooo`;o00001?ooool2o`0000;ooooo1?l00002ooooo`Go00001Oooool2o`0000Ko
oooo0_l0000;ooooo`;o00002oooool5o`000003ooooool0003o000000Oooooo1?l0000Fooooo`Co
00001_ooool2o`0004Cooooo000Looooo`03o`000?oooooooooo043ooooo0_l0000>ooooo`;o0000
2oooool2o`0000?ooooo1Ol00003ooooo`Co00001?ooool2o`0000Cooooo0_l000001?oooooo0000
o`000?l00003ooooo`;o000000?oooooo`000?l000000_l000001?oooooo0000o`000?ooool2o`00
00Gooooo0_l00005ooooo`;o00001?ooool2o`0000;ooooo1Ol00005ooooo`;o00000_ooool2o`00
01kooooo0_l00002ooooo`;o000000?oooooo`000?l000001?ooool4o`0001Kooooo1?l00006oooo
o`;o0000A?ooool001cooooo00?o0000ooooooooool0D?ooool2o`0000Sooooo0_l00002ooooo`;o
00000_ooool5o`0000?ooooo1?l00004ooooo`;o000000?oooooo`000?l000001Oooool2o`0000?o
oooo0_l000000ooooooo0000o`000002o`0000Cooooo0_l000000ooooooo0000o`000002ooooo`;o
00004Oooool2o`0000[ooooo0_l000000ooooooo0000o`00000Booooo`;o00001oooool2o`0000;o
oooo0_l000000ooooooo0000o`000004ooooo`;o00005oooool2o`000003ooooool0003o000001;o
oooo0_l0000Eooooo`;o00008Oooool001cooooo00?o0000ooooooooool0@?ooool3o`0001Kooooo
0ol00002ooooo`?o00005?ooool2o`0000?ooooo0_l0000:ooooo`;o00000oooool3o`000003oooo
ool0003o000000_ooooo0_l00009ooooo`?o00002oooool2o`0001;ooooo0_l0000:ooooo`?o0000
1oooool2o`0000Kooooo0ol0000>ooooo`;o00005Oooool2o`00013ooooo0_l00003ooooo`;o0000
8Oooool001cooooo00?o0000ooooooooool0:oooool2o`0000_ooooo0_l00006ooooo`?o00005_oo
ool2o`0000;ooooo1?l0000Booooo`Go000000Coooooo`000?l0003o00002oooool2o`0000;ooooo
0_l0000?ooooo`;o00001?ooool2o`0000?ooooo0ol0000>ooooo`?o00005_ooool2o`0000;ooooo
0ol00006ooooo`;o00001Oooool5o`0000Kooooo1Ol00003ooooo`Go00004_ooool2o`00013ooooo
0_l0000Vooooo`007?ooool00ol0003oooooooooo`0[ooooo`;o00001?ooool2o`0000Gooooo0_l0
0004ooooo`;o00006_ooool2o`000003ooooool0003o000001Cooooo1Ol000000ooooooo0000o`00
000<ooooo`;o00003Oooool2o`0000Sooooo1?l00003ooooo`;o00003Oooool5o`0000Cooooo0_l0
0006ooooo`;o00001?ooool2o`0000;ooooo1Ol00008ooooo`;o00001Oooool2o`000003ooooool0
003o000000Kooooo1Ol00003ooooo`Go00001oooool2o`0000Kooooo0_l000000ooooooo0000o`00
0005ooooo`Co0000;oooool001cooooo00?o0000ooooooooool0<Oooool2o`0000Gooooo0ol00003
ooooo`?o00003Oooool2o`0000Sooooo1?l00007ooooo`;o00003?ooool2o`0000gooooo1_l0000@
ooooo`;o00002?ooool2o`0000kooooo0ol00003ooooo`Co000000Coooooo`000?l0003ooooo1Ol0
00001?oooooo0000o`000?ooool2o`0000Cooooo0_l00003ooooo`Go00001Oooool2o`0001Sooooo
1Ol00005ooooo`;o00000_ooool2o`0000Kooooo1?l00006ooooo`Co0000;oooool001cooooo00?o
0000ooooooooool0;_ooool2o`0000Wooooo0_l000001?oooooo0000o`000?ooool2o`0000gooooo
0_l00008ooooo`;o00001?ooool2o`0000?ooooo0ol00006ooooo`;o00000oooool2o`0000gooooo
1_l0000Zooooo`?o000000?oooooo`000?l000000_ooool2o`000004ooooool0003o0000ooooo`;o
000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00000<ooooo`;o00001Oooool2o`00
00gooooo0_l00009ooooo`;o00000oooool4o`000003ooooool0003o000000[ooooo1?l000000ooo
oooo0000o`00000fooooo`007?ooool00ol0003oooooooooo`0/ooooo`Co00001_ooool2o`0000Co
oooo1Ol0000?ooooo`;o00002Oooool2o`000003ooooool0003o000000Cooooo0_l00006ooooo`;o
00000_ooool2o`0000gooooo0_l00002ooooo`?o00002Oooool2o`00027ooooo1?l000000ooooooo
0000o`000004ooooo`;o00002?ooool2o`0000Wooooo0_l0000;ooooo`;o00000oooool2o`0000Go
oooo0_l00009ooooo`;o00000oooool4o`0000Gooooo0_l00005ooooo`?o00000oooool2o`0003Ko
oooo000Looooo`03o`000?oooooooooo02cooooo0ol00004ooooo`;o000000?oooooo`000?l00000
1Oooool4o`0000oooooo0_l00009ooooo`?o00000_ooool2o`0000gooooo0ol0000=ooooo`Go0000
1_ooool2o`0000?ooooo0_l00004ooooo`;o00004_ooool2o`0000Oooooo1?l000000ooooooo0000
o`000002o`0000;ooooo1?l0000@ooooo`?o00002oooool2o`0000?ooooo0_l00005ooooo`;o0000
2Oooool5o`0000Gooooo0_l00002ooooo`;o00001Oooool2o`000003ooooool0003o000000[ooooo
0_l0000]ooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o00001?ooool2o`000003ooooool0
003o000002Cooooo0_l00002ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Cooooo0_l0
00000ooooooo0000o`000002ooooo`;o00002?ooool6o`0000?ooooo0ol00003ooooo`Co00000_oo
ool2o`0001;ooooo0_l00009ooooo`;o00000oooool2o`0000Cooooo0_l0000@ooooo`;o00001_oo
ool2o`0000Cooooo0_l0000:ooooo`;o00002Oooool5o`0000Gooooo0_l0000<ooooo`;o00002Ooo
ool3o`0002gooooo000Looooo`03o`000?oooooooooo03Cooooo1?l00002ooooo`;o00006?ooool2
o`0000Gooooo0ol000000ooooooo0000o`000002ooooo`So00001oooool2o`0000;ooooo0_l00009
ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`000003ooooool0003o000000Go0000?_oo
ool2o`000004ooooool0003o0000ooooo`Co00004?ooool2o`0000Wooooo0_l000000ooooooo0000
o`000002o`0000cooooo0_l0000>ooooo`;o0000;_ooool001cooooo00?o0000ooooooooool0=?oo
ool3o`0000?ooooo0_l0000Aooooo`;o00001Oooool2o`0000?ooooo1?l00002ooooo`;o00001?oo
ool4o`0000;ooooo0_l00002ooooo`;o00000_ooool4o`0000;ooooo0ol00009ooooo`;o00001Ooo
ool5o`000005ooooool0003o0000o`000?ooool00_l0000Vooooo`;o00001oooool4o`000003oooo
ool0003o000000Kooooo0_l000000ooooooo0000o`000002o`0000kooooo1?l0000<ooooo`Go0000
2Oooool4o`0000Kooooo0_l0000fooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o00001?oo
ool2o`0000?ooooo0_l00003ooooo`;o00003?ooool4o`0000Gooooo0_l00003ooooo`?o00002_oo
ool2o`0000?ooooo0_l00002ooooo`;o00000_ooool4o`0000;ooooo0ol00002ooooo`;o00000_oo
ool:o`000003ooooool0003o000000Ko000000?oooooo`000?l000000oooool3o`0000cooooo0ol0
00000ooooooo0000o`000009ooooo`;o00000oooool2o`0000Oooooo1ol00005ooooo`;o00003Ooo
ool2o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000kooooo0_l000000ooooooo0000
o`000006ooooo`;o00000_ooool2o`0000Cooooo0_l0000fooooo`007?ooool00ol0003ooooooooo
o`0]ooooo`;o00001?ooool2o`0000?ooooo0_l00003ooooo`Co00002_ooool2o`0000Oooooo1?l0
0002ooooo`;o00006?ooool2o`0000?ooooo0_l00003ooooo`;o00000_ooool:o`000003ooooool0
003o000000;ooooo0_l00003ooooo`;o00000oooool3o`0000cooooo0ol000001?oooooo0000o`00
0?l00003ooooo`;o00000oooool2o`0000Wooooo0_l000000ooooooo0000o`000002ooooo`;o0000
1_ooool2o`000003ooooool0003o000000[ooooo0_l000000ooooooo0000o`000002o`0000?ooooo
1?l0000?ooooo`Co00001?ooool2o`0000;ooooo0_l00009ooooo`;o0000<Oooool001cooooo00?o
0000ooooooooool0<oooool2o`0000Sooooo1?l0000@ooooo`?o00000_ooool2o`0000Gooooo0_l0
0008ooooo`;o00001Oooool2o`0000Sooooo1_l000000ooooooo0000o`00000?o`0000;ooooo0ol0
00001?oooooo0000o`000?l0000Aooooo`;o00000oooool2o`0000?ooooo1?l00004ooooo`;o0000
1_ooool2o`000003ooooool0003o000000;o00002oooool2o`0000cooooo1Ol00005ooooo`;o0000
4Oooool2o`0000gooooo0_l00004ooooo`;o0000<Oooool001cooooo0_l0000iooooo`?o000000?o
ooooo`000?l000000ol0000@ooooo`?o00002Oooool2o`0000?ooooo0_l00003ooooo`Co00000ooo
ool2o`0000Sooooo1_l000000ooooooo0000o`000004o`000003ooooool0003o000000go00000_oo
ool2o`00017ooooo0_l00007ooooo`Go00001?ooool2o`000003ooooool0003o000000Gooooo0_l0
00000ooooooo0000o`00000Aooooo`;o00001?ooool6o`0001;ooooo0_l00003ooooo`;o000000Co
ooooo`000?l0003ooooo0_l00009ooooo`;o00001_ooool2o`0002oooooo000Looooo`03o`000?oo
oooooooo03?ooooo0_l00003ooooo`?o000000Coooooo`000?l0003ooooo0_l00005ooooo`;o0000
1Oooool4o`00017ooooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool2o`0000;ooooo
0_l00002ooooo`;o000000?oooooo`000?l000006?l00006ooooo`;o00002?ooool2o`0000Gooooo
0_l00007ooooo`;o00001?ooool2o`0000Cooooo0_l00003ooooo`Co00000oooool2o`0000[ooooo
0_l000000ooooooo0000o`000002o`0000Cooooo0_l0000@ooooo`;o00001?ooool2o`0000?ooooo
0_l000001?oooooo0000o`000?ooool2o`0000Cooooo0_l0000;ooooo`?o0000;_ooool001cooooo
00?o0000ooooooooool0;_ooool2o`0000?ooooo0_l00004ooooo`;o00002?ooool2o`000003oooo
ool0003o000000;ooooo0_l000000ooooooo0000o`000002o`000004ooooool0003o0000o`0000?o
oooo0_l00003ooooo`;o00001_ooool4o`0000Wooooo1_l00002ooooo`;o000000?oooooo`000?l0
00004ol00007ooooo`Ko00001?ooool2o`0000;ooooo0_l0000@ooooo`;o00001_ooool2o`000003
ooooool0003o000000;o00000oooool2o`0000Kooooo0_l00002ooooo`Go00005Oooool2o`000003
ooooool0003o000000?o00004_ooool2o`0000cooooo0_l0000^ooooo`007?ooool00ol0003ooooo
ooooo`0^ooooo`;o00004Oooool4o`0000Gooooo0_l00003ooooo`So000000?oooooo`000?l00000
0_l000000ooooooo0000o`000007ooooo`?o00002_ooool4o`0000;ooooo6_l00002ooooo`;o0000
1?ooool5o`0000?ooooo0_l00002ooooo`;o00004?ooool2o`0000Kooooo0_l00004ooooo`;o0000
2_ooool2o`0000Cooooo0_l00003ooooo`;o00004Oooool2o`0000;ooooo1?l0000?ooooo`;o0000
00?oooooo`000?l000002oooool2o`0002oooooo000Looooo`03o`000?oooooooooo047ooooo0_l0
000<ooooo`?o00000oooool2o`0000?ooooo0_l0000:ooooo`?o00002oooool2o`000003ooooool0
003o000001oo000000?oooooo`000?l000000oooool2o`0000cooooo0_l0000;ooooo`?o00001Ooo
ool2o`000004ooooool0003o0000ooooo`?o00003?ooool2o`0000Kooooo0_l00002ooooo`;o0000
4?ooool4o`0000Oooooo0_l00007ooooo`;o00003_ooool2o`0002oooooo000Looooo`03o`000?oo
oooooooo037ooooo0_l000000ooooooo0000o`000006ooooo`;o00006oooool2o`0000cooooo0_l0
0006ooooo`;o00000_oooolUo`000004ooooool0003o0000ooooo`;o00001_ooool2o`0000Gooooo
1Ol00002ooooo`?o00001Oooool2o`0000Cooooo1_l000000ooooooo0000o`000006o`0000Oooooo
0_l00009ooooo`?o00004?ooool2o`0000;ooooo0_l00005ooooo`;o0000B?ooool001cooooo00?o
0000ooooooooool0:oooool;o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o00002_oo
ool2o`0000_ooooo0_l00003ooooo`;o00003oooool2o`0000;ooooo4?l000000ooooooo0000o`00
0009o`000003ooooool0003o000000Wo000000?oooooo`000?l000000_l00004ooooo`;o00001Ooo
ool2o`000005ooooool0003o0000o`000?ooool00ol00007oooooa?o00004?ooool5o`0001Cooooo
1?l00003ooooo`;o00000oooool2o`0000cooooo0_l00007ooooo`;o0000;?ooool001cooooo00?o
0000ooooooooool0:oooool6o`0000;ooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo
0ol0000:ooooo`;o00000oooool2o`0000_ooooo0ol00005ooooo`;o00002?ooool2o`0000;ooooo
0_l00003ooooo`Wo000000?oooooo`000?l000007Ol00005ooooo`;o00001_ooool2o`0000Wooooo
5?l0000Aooooo`;o00000oooool2o`0000;ooooo0_l00006ooooo`;o00002?ooool2o`0000?ooooo
0_l00003ooooo`;o00003?ooool2o`0000Oooooo0_l0000/ooooo`007?ooool00ol0003ooooooooo
o`0fooooo`;o00000oooool2o`0000;ooooo0ol0000?ooooo`;o00003?ooool2o`0000Gooooo0_l0
0008ooooo`;o000000?oooooo`000?l000008ol000000ooooooo0000o`000002o`0000;ooooo0ol0
0005ooooo`;o00001?ooool3o`0000Wooooo5_l00003ooooo`;o00001Oooool2o`0000Wooooo0_l0
0002ooooo`;o00001_ooool2o`0000?ooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`0^
ooooo`;o000000?oooooo`000?l000000oooool2o`0000?ooooo0_l0000:ooooo`;o00001_ooool2
o`00017ooooo0_l00006ooooo`;o00000oooool/o`0000Cooooo0_l00006ooooo`;o00001?ooool3
o`0000Oooooo3ol000000ooooooo0000o`000008o`000003ooooool0003o000000Gooooo0_l0000A
ooooo`;o00001oooool2o`000003ooooool0003o000004oooooo000Looooo`03o`000?oooooooooo
02kooooo0_l000000ooooooo0000o`000002ooooo`;o00003Oooool2o`000003ooooool0003o0000
00Kooooo0_l00003ooooo`;o00000oooool2o`0000Oooooo0_l00006ooooo`;o000000?oooooo`00
0?l00000;?l00006ooooo`;o000000Coooooo`000?l0003ooooo0_l0000<oooooaco00000oooool2
o`0001Kooooo0_l0000:ooooo`;o00008Oooool2o`0002cooooo000Looooo`03o`000?oooooooooo
02gooooo0_l00006ooooo`;o00001oooool2o`0000Cooooo0_l0000:ooooo`;o00000_ooool2o`00
00?ooooo0_l0000:ooooo`;o00001_oooolDo`000003ooooool0003o000001So00000_ooool2o`00
0003ooooool0003o000000Co00001_ooool2o`0000Gooooo6?l000000ooooooo0000o`000003o`00
0003ooooool0003o000000;o0000:oooool2o`0001Oooooo0_l0000/ooooo`007?ooool00ol0003o
ooooooooo`0]ooooo`;o00002?ooool3o`0000Cooooo0_l0000@ooooo`;o00002oooool2o`0000Ko
oooo0_l00008ooooo`Oo000000?oooooo`000?l000008ol000000ooooooo0000o`000005o`000003
ooooool0003o000000Kooooo0_l00002ooooo`;o000000Goooooo`000?l0003o0000ooooo`06o`00
0003ooooool0003o000001Ko0000:oooool2o`00013ooooo0_l000000ooooooo0000o`00000`oooo
o`007?ooool00ol0003oooooooooo`0dooooo`;o000000Coooooo`000?l0003o00004oooool2o`00
00kooooo0_l00002ooooo`;o00003?ooool7o`000003ooooool0003o000001;o000000?oooooo`00
0?l000003_l000000ooooooo0000o`000005o`0000cooooo1ol00002ooooo`Ko000000?oooooo`00
0?l000005Ol000001?oooooo0000o`000?l0000iooooo`;o000000?oooooo`000?l00000<?ooool0
0006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@
olc<c006ooooo`03o`000?oooooooooo03Cooooo0_l0000Gooooo`;o00002Oooool2o`0000?ooooo
0_l00002ooooo`;o00003?ooool6o`000003ooooool0003o000002Co00000_ooool8o`000003oooo
ool0003o000000Cooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l00002oooooaoo
00009Oooool2o`0000[ooooo0_l0000kooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5oooo
o`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0=?ooool2
o`0000kooooo0_l0000Booooo`;o00000oooool4o`0000Wooooo0_l00003ooooo`?o000000?ooooo
o`000?l000009_l000000ooooooo0000o`000008o`000003ooooool0003o000000Cooooo0_l00002
ooooo`?o00001?oooolDo`000003ooooool0003o000000Oo000000Coooooo`000?l0003ooooo1?l0
000@ooooo`;o00000oooool2o`0000Gooooo0_l00004ooooo`;o00002_ooool2o`0000Wooooo0_l0
000`ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`0dooooo`;o00003Oooool3o`0001;ooooo0_l0
0005ooooo`Co00000_ooool2o`0000?ooooo0_l00002ooooo`Co000000?oooooo`000?l000002ol0
0003ooooo`So000000?oooooo`000?l000004_l000001?oooooo0000o`000?ooool2o`000004oooo
ool0003o0000ooooo`;o00000_ooool2o`000005ooooool0003o0000o`000?ooool00_l000000ooo
oooo0000o`00000Ko`0000;ooooo0_l000000ooooooo0000o`000002o`00013ooooo1ol00005oooo
o`;o00002_ooool2o`0000kooooo0ol0000`ooooo`0000?oooooo`000?ooool00_ooool00ol0003o
ooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0004?ooooo0_l000001?oo
oooo0000o`000?l0000:ooooo`;o00000oooool2o`0000Oooooo0ol000000ooooooo0000o`000002
ooooo`Co000000?oooooo`000?l000000_l000001Ooooooo0000o`000?l0003ooooo00_o000000?o
ooooo`000?l000006?l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000;ooooo
1?l00002ooooo`;o00001OoooolVo`0000gooooo0_l00006ooooo`Co00001?ooool2o`0000cooooo
0_l0000>ooooo`;o0000<Oooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0A_ooool3o`0000[ooooo
0_l0000=ooooo`;o00001Oooool4o`000003ooooool0003o000000;o00000_ooool_o`000003oooo
ool0003o000000;ooooo0_l00004ooooo`;o00001_ooool3o`000003ooooool0003o000000_o0000
00?oooooo`000?l000004ol0000;ooooo`?o00001_ooool3o`0000Cooooo0_l0000Eooooo`;o0000
>?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7oooo
o`08ooooo`03o`000?oooooooooo03?ooooo0ol0000?ooooo`;o000000?oooooo`000?l000004_oo
ool4o`0000[ooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo;ol00007ooooo`?o0000
2OoooolIo`000003ooooool0003o000000Oo00000_ooool2o`0000Cooooo0_l00006ooooo`;o0000
1_ooool2o`0000?ooooo0_l00006ooooo`;o00003oooool2o`0003Sooooo00001_ooooooMgMgoiRH
V?ooooooV9RHogMgM`_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0booooo`Co
00001Oooool2o`0000Sooooo0_l000000ooooooo0000o`000006ooooo`;o00002_ooool6o`000003
ooooool0003o000000?ooooo0_l00007oooooaCo00000_oooolIo`000004ooooool0003o0000o`00
00;ooooo0_l00002ooooo`?o00002Oooool7o`000003ooooool0003o000000Co000000?oooooo`00
0?l000005?l00006ooooo`Co00000_ooool3o`0000;ooooo0_l00002ooooo`?o00000oooool2o`00
0003ooooool0003o000000?ooooo1?l00017ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<
ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0<_ooool4o`0000Gooooo0_l0
0006ooooo`Co00002Oooool2o`0000kooooo0_l000001?oooooo0000o`000?ooool4o`0000Sooooo
5Ol000000ooooooo0000o`00000@o`000003ooooool0003o000000?o00000_ooool6o`0000;ooooo
0_l000000ooooooo0000o`000008ooooob7o000000?oooooo`000?l000002?ooool2o`0000;ooooo
0ol00002ooooo`;o000000Coooooo`000?l0003o00001oooool2o`0000Gooooo0_l00006ooooo`;o
0000?oooool001cooooo00?o0000ooooooooool0<_ooool3o`0000Wooooo0_l00003ooooo`Co0000
5_ooool2o`0000;ooooo0_l000000ooooooo0000o`000004o`0000Sooooo4Ol00002oooooa;o0000
00?oooooo`000?l000001Ol00003ooooo`Co00000_ooool4o`000003ooooool0003o000000Gooooo
0_l000000ooooooo0000o`00000Fo`000003ooooool0003o000000Ko00002Oooool4o`0000?ooooo
0_l00003ooooo`Co00003?ooool2o`0000Wooooo0_l0000oooooo`007?ooool00ol0003ooooooooo
o`0cooooo`;o00002Oooool2o`0001gooooo0_l00002ooooo`;o000000?oooooo`000?l000001?l0
0003ooooo`;o00000ooooolUo`0000;ooooo0_l00003ooooo`;o00000_ooool2o`000004ooooool0
003o0000ooooo`;o00000_ooool3o`0000Gooooo1_l000000ooooooo0000o`00000Ko`0000;ooooo
0_l00002ooooo`Oo00001_ooool8o`0000Gooooo0_l00003ooooo`Co0000B?ooool001cooooo00?o
0000ooooooooool0?_ooool2o`0000Oooooo0_l00002ooooo`Co00005Oooool3o`0000?ooooo1Ol0
00000ooooooo0000o`00000Uo`0000Cooooo1Ol000000ooooooo0000o`000002ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0000Oooooo0ol000000ooooooo0000o`000002oooooaSo000000Co
ooooo`000?l0003ooooo0ol00002ooooo`Co00001oooool4o`0000Cooooo0_l00005ooooo`Go0000
0_ooool2o`0004Sooooo000Looooo`03o`000?oooooooooo03kooooo0_l00007ooooo`;o00000_oo
ool4o`0000Sooooo0_l0000:ooooo`Ko000000Goooooo`000?l0003o0000ooooo`0Vo`000003oooo
ool0003o000000Wo000000?oooooo`000?l000001?ooool2o`0000?ooooo0_l00007ooooo`?o0000
00Goooooo`000?l0003o0000ooooo`05o`000003ooooool0003o0000013o000000Coooooo`000?l0
003ooooo1?l0000<ooooo`;o00001_ooool2o`0000Kooooo1?l0001<ooooo`007?ooool00ol0003o
ooooooooo`1Gooooo`;o00002_ooool2o`0000;ooooo1?l00003ooooo`Oo00000_oooolMo`000003
ooooool0003o000000_o000000?oooooo`000?l000001?l00004ooooo`;o00001_ooool2o`0000?o
oooo0_l000000ooooooo0000o`00000Go`000005ooooool0003o0000o`000?ooool01?l0000Boooo
o`;o00000_ooool2o`0005;ooooo000Looooo`03o`000?oooooooooo033ooooo0_l0000Vooooo`;o
00003Oooool4o`0000?ooooo1?l000000ooooooo0000o`000002oooooa?o00000_ooool7o`000003
ooooool0003o000000Co000000Coooooo`000?l0003o00000_ooool2o`000003ooooool0003o0000
00Co00001?ooool2o`0000Kooooo0_l00006oooooako00000_ooool2o`0000Cooooo0_l000000ooo
oooo0000o`000003ooooo`;o00001?ooool2o`0000;ooooo0_l00003ooooo`;o00001_ooool4o`00
04?ooooo000Looooo`03o`000?oooooooooo033ooooo0_l0000Vooooo`;o00001?ooool2o`0000[o
oooo0_l00002ooooo`Co00000_ooool2o`000003ooooool0003o0000017o000000?oooooo`000?l0
00003Ol00002ooooo`;o00001Oooool4o`0000;ooooo0_l00008ooooo`Co00001_oooolJo`000003
ooooool0003o000000?o00000oooool5o`000003ooooool0003o000000;o000000?oooooo`000?l0
00003Oooool3o`0000;ooooo0_l000000ooooooo0000o`000002o`0004?ooooo000Looooo`03o`00
0?oooooooooo02cooooo0_l0000Dooooo`;o00000_ooool2o`0001?ooooo0_l000000ooooooo0000
o`00000:ooooo`;o00000_ooool2o`0000?ooooo0ol000000ooooooo0000o`00000Mo`000004oooo
ool0003o0000o`0000;ooooo0_l00005ooooo`So00002?ooool2o`0000Kooooo0_l000000ooooooo
0000o`000006o`000003ooooool0003o000000co000000?oooooo`000?l000001Ol00003ooooo`Co
00001?ooool2o`0000Kooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l00002oooo
o`;o00000_ooool2o`0004Cooooo000Looooo`03o`000?oooooooooo02cooooo0_l0000;ooooo`;o
00001oooool2o`0000;ooooo0_l0000Cooooo`?o00003Oooool2o`0000Kooooo1Ol000000ooooooo
0000o`00000Bo`000003ooooool0003o000000Go000000Coooooo`000?l0003o00000oooool2o`00
00Wooooo0_l00008ooooo`;o00002?ooool2o`0000?ooooo1_l00002oooooa3o000000?oooooo`00
0?l000001Oooool2o`0000kooooo0_l000000ooooooo0000o`000003o`0000?ooooo0_l00006oooo
o`;o0000A?ooool001cooooo00?o0000ooooooooool0>Oooool2o`0000Oooooo0ol0000Gooooo`;o
00000_ooool2o`0000;ooooo0_l00005ooooo`;o00002Oooool3o`000003ooooool0003o000001Co
000000?oooooo`000?l000000_l000001?oooooo0000o`000?l00003ooooo`;o000000?oooooo`00
0?l000000_ooool2o`0000Oooooo0_l00003ooooo`;o00003_ooool2o`000003ooooool0003o0000
013o00002_ooool2o`0001;ooooo0_l0000Fooooo`;o0000>oooool001cooooo00?o0000oooooooo
ool0<Oooool2o`0000Kooooo0_l00008ooooo`;o00003oooool2o`0000Kooooo0_l00002ooooo`;o
00000_ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000002?ooool3o`0000;o
oooo1ol00002ooooo`?o000000?oooooo`000?l000001_l000000ooooooo0000o`000005ooooo`;o
00000oooool8o`0000Oooooo0_l0000Cooooo`;o00000_ooool9o`000003ooooool0003o000000?o
0000=Oooool2o`000003ooooool0003o000003_ooooo000Looooo`;o0000<_ooool2o`0000kooooo
0_l0000Aooooo`;o00001?ooool2o`0000_ooooo1?l000000ooooooo0000o`000002o`000003oooo
ool0003o000000;ooooo0_l00002ooooo`Wo000000?oooooo`000?l000003_l000000ooooooo0000
o`000002ooooo`;o00000oooool2o`0000;ooooo0_l0000Aooooo`;o00001_ooool2o`0000?ooooo
1?l00005ooooo`[o00001Oooool2o`000003ooooool0003o000000;ooooo0_l00008ooooo`;o0000
4oooool2o`0000Sooooo0_l0000nooooo`007?ooool00ol0003oooooooooo`0oooooo`Go00002Ooo
ool2o`0000_ooooo0ol0000=ooooo`;o00000_ooool2o`000003ooooool0003o000000Co00000_oo
ool4o`000003ooooool0003o000000Wo00001?ooool9o`000003ooooool0003o000000;ooooo0_l0
0004ooooo`;o00003oooool4o`0000Kooooo0_l00002ooooo`Go00001_ooool6o`0000Sooooo0_l0
00000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0
003o000001?ooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`0oooooo`;o000000?ooooo
o`000?l000002Oooool3o`0000_ooooo0_l0000=ooooo`;o000000?oooooo`000?l000000_l00002
ooooo`;o000000?oooooo`000?l000002?l000000ooooooo0000o`000002ooooo`Co00000_ooool9
o`000003ooooool0003o000000;o00000_ooool2o`0000?ooooo0_l00004ooooo`;o00001?ooool2
o`0000Cooooo0_l00008ooooo`;o00000_ooool2o`0000Kooooo1?l00004ooooo`Co00003oooool2
o`0000;ooooo0_l0000Iooooo`;o00001?ooool4o`0003gooooo000Looooo`03o`000?oooooooooo
03oooooo0ol0000<ooooo`;o00001oooool2o`0000;ooooo0_l0000@ooooo`Co00001Oooool9o`00
0004ooooool0003o0000o`0000;ooooo1Ol000000ooooooo0000o`000005o`0000;ooooo0ol00009
ooooo`;o00001?ooool3o`0000?ooooo0_l0000Cooooo`;o00001Oooool4o`000004ooooool0003o
0000ooooo`Co00007?ooool2o`000003ooooool0003o000000Cooooo0_l00002ooooo`Co000000?o
ooooo`000?l000001?ooool4o`0003gooooo000Looooo`03o`000?oooooooooo043ooooo1?l00000
0ooooooo0000o`000007ooooo`;o00001oooool2o`0000gooooo0_l00005ooooo`;o00002?ooool2
o`000004ooooool0003o0000o`0000?ooooo0ol000000ooooooo0000o`000008o`0000Kooooo0_l0
0002ooooo`;o00001_ooool5o`0000;ooooo0_l00007ooooo`;o00003Oooool4o`000003ooooool0
003o000000?ooooo0_l00002ooooo`;o00001_ooool6o`0000_ooooo0_l00005ooooo`;o000000Co
ooooo`000?l0003ooooo1?l00002ooooo`;o00000_ooool4o`0000Oooooo0_l0000oooooo`007?oo
ool00ol0003oooooooooo`12ooooo`Go00004?ooool2o`0000gooooo1?l00005ooooo`;o00001_oo
ool2o`000004ooooool0003o0000o`0000Cooooo0_l000000ooooooo0000o`000002o`000003oooo
ool0003o000000Go00001Oooool2o`000003ooooool0003o000000Kooooo1ol00009ooooo`;o0000
3Oooool2o`000003ooooool0003o000000;o00002?ooool2o`0000Gooooo1_l0000;ooooo`;o0000
1Oooool2o`0000?ooooo0_l000000ooooooo0000o`00000<ooooo`;o0000A?ooool001cooooo00?o
0000ooooooooool0?oooool2o`0000?ooooo0ol0000;ooooo`;o00000oooool2o`0000oooooo0_l0
0005ooooo`;o00002_ooool3o`0000Sooooo0_l000001?oooooo0000o`000?l00002ooooo`;o0000
1Oooool2o`0000_ooooo0_l000000ooooooo0000o`000003ooooo`;o00003oooool2o`0000Gooooo
0_l0000:ooooo`;o000000?oooooo`000?l000001oooool2o`0000cooooo0_l00003ooooo`;o0000
0_ooool3o`0000oooooo0_l00014ooooo`007?ooool00ol0003oooooooooo`0oooooo`?o00000ooo
ool2o`0000_ooooo0_l00005ooooo`Go00001Oooool2o`0000[ooooo0_l00003ooooo`;o000000?o
ooooo`000?l000000oooool5o`0000?ooooo0_l00004ooooo`;o00003Oooool2o`0000Oooooo0_l0
0004ooooo`Co00003oooool2o`0000Cooooo1?l0000<ooooo`;o00001Oooool4o`0000cooooo0_l0
0007ooooo`?o00000oooool2o`0000cooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`10
ooooo`;o00004oooool2o`0000;ooooo1Ol00005ooooo`;o00002_ooool3o`0000;ooooo0_l00000
0ooooooo0000o`000004ooooo`Co00000oooool2o`0001?ooooo0_l0000=ooooo`;o00001oooool2
o`0000_ooooo0_l000000ooooooo0000o`000002o`0000Oooooo0_l0000:ooooo`;o00001oooool2
o`0000;ooooo0_l00008ooooo`;o000000?oooooo`000?l000000oooool2o`0000cooooo0_l00012
ooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00001_ooool2o`0000_ooooo0_l0000:oooo
o`Co00002oooool2o`0000;ooooo0_l0000:ooooo`;o00002Oooool2o`0001Oooooo0_l000000ooo
oooo0000o`000003ooooo`;o00000_ooool5o`0000[ooooo0_l0000@ooooo`;o000000?oooooo`00
0?l000000_ooool2o`0000;ooooo0_l00002ooooo`Co00001_ooool2o`0000Sooooo0_l00016oooo
o`007?ooool00ol0003oooooooooo`1<ooooo`?o00004?ooool2o`000003ooooool0003o000000[o
oooo0_l000000ooooooo0000o`000007ooooo`;o000000?oooooo`000?l000000_ooool2o`0000[o
oooo0_l00006ooooo`Go00000oooool2o`0001Gooooo0_l00003ooooo`Ko000000?oooooo`000?l0
00004Oooool2o`0000;ooooo0_l00005ooooo`;o00001Oooool2o`0000;ooooo0_l00002ooooo`;o
00000_ooool2o`0000Wooooo0_l00003ooooo`;o0000A_ooool001cooooo00?o0000ooooooooool0
C?ooool2o`0000Sooooo0_l00002ooooo`;o00000oooool2o`0000?ooooo0_l00002ooooo`;o0000
1oooool2o`0000Oooooo0_l000000ooooooo0000o`000002o`0000Sooooo0ol00006ooooo`;o0000
00Goooooo`000?l0003o0000ooooo`02o`0000;ooooo0_l0000Looooo`;o00004oooool2o`000003
ooooool0003o000000;ooooo0_l00005ooooo`?o00002?ooool2o`0000Kooooo0_l000000ooooooo
0000o`000006ooooo`;o0000Boooool001cooooo00?o0000ooooooooool0E_ooool2o`0000;ooooo
1?l00006ooooo`;o00000_ooool2o`000003ooooool0003o000000_ooooo0_l00005ooooo`;o0000
1?ooool2o`0000;ooooo0ol00003ooooo`;o000000?oooooo`000?l000001Oooool2o`0000?ooooo
0_l00003ooooo`;o00001?ooool2o`0001Cooooo0_l00002ooooo`;o00000oooool2o`0000Kooooo
0_l00006ooooo`;o00000oooool4o`0000Sooooo0_l00002ooooo`;o00001Oooool2o`0005?ooooo
000Looooo`03o`000?oooooooooo04oooooo0_l0000;ooooo`;o00003Oooool2o`0000_ooooo0_l0
0005ooooo`;o00001?ooool2o`0000Sooooo0_l000000ooooooo0000o`000006ooooo`;o000000Co
ooooo`000?l0003o00000oooool2o`0000Cooooo0_l0000Dooooo`;o00000_ooool2o`0000?ooooo
0_l00003ooooo`;o00002?ooool3o`0000?ooooo0_l00002ooooo`;o00002_ooool2o`00013ooooo
0_l00018ooooo`007?ooool00ol0003oooooooooo`1?ooooo`;o00001?ooool2o`0000;ooooo0_l0
0006ooooo`;o00003_ooool2o`0000Oooooo0_l00003ooooo`;o00002oooool2o`0000Kooooo0_l0
0004ooooo`;o000000?oooooo`000?l000000oooool2o`0001oooooo0_l00004ooooo`;o00000_oo
ool4o`0000Kooooo0_l000000ooooooo0000o`000005ooooo`;o00000oooool3o`0000?ooooo0_l0
0003ooooo`;o00001oooool2o`0000?ooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`1?
ooooo`;o00001?ooool2o`0000;ooooo0_l00006ooooo`;o00003_ooool2o`0000Oooooo0_l0000@
ooooo`?o00001Oooool2o`0000;ooooo0_l00007ooooo`?o00002_ooool2o`0001Wooooo0_l00003
ooooo`Go00001oooool2o`0000Cooooo0_l00003ooooo`Co00000oooool2o`0000;ooooo0ol00007
ooooo`;o0000COooool001cooooo0_l0001Eooooo`;o00001Oooool2o`0001;ooooo0_l0000Loooo
o`;o00000_ooool2o`000003ooooool0003o000000;ooooo0_l00004ooooo`;o000000?oooooo`00
0?l000001oooool2o`0000;ooooo0_l0000Nooooo`;o000000?oooooo`000?l000000oooool2o`00
00Sooooo0_l00003ooooo`;o00002Oooool2o`0005Oooooo000Looooo`03o`000?oooooooooo05Co
oooo0_l00005ooooo`;o00002?ooool2o`0000Sooooo1?l0000Iooooo`;o00000oooool3o`000003
ooooool0003o000000Oooooo0_l000000ooooooo0000o`000007ooooo`;o00007_ooool2o`000003
ooooool0003o000000Kooooo0ol00007ooooo`?o00001_ooool2o`0000?ooooo0_l00002ooooo`;o
0000E_ooool001cooooo00?o0000ooooooooool0FOooool2o`0000;ooooo1?l00004ooooo`;o0000
2_ooool2o`0001Wooooo0ol000000ooooooo0000o`000002o`000003ooooool0003o000000Cooooo
0_l00003ooooo`?o00000_ooool2o`0000gooooo0_l0000Dooooo`;o000000?oooooo`000?l00000
1_ooool2o`0000Sooooo1Ol00004ooooo`;o00000oooool2o`0000;ooooo0_l0001Fooooo`007?oo
ool00ol0003oooooooooo`1Cooooo`?o00000oooool2o`0000;ooooo1_l00005ooooo`;o00003Ooo
ool2o`0001Cooooo0_l000001?oooooo0000o`000?l00004ooooo`;o00000_ooool2o`0000?ooooo
0_l00002ooooo`?o00001Oooool2o`0000Kooooo0_l0000Nooooo`;o00002oooool3o`0000Wooooo
0_l00005ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0DOooool5o`0000?ooooo0_l0
0006ooooo`;o00001Oooool2o`0000Wooooo0_l00002ooooo`;o00000oooool2o`00017ooooo1?l0
0004ooooo`;o00002oooool2o`0000Kooooo0_l0000Uooooo`?o00002oooool2o`0000[ooooo0_l0
0005ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0DOooool2o`0000kooooo1?l00004
ooooo`;o00002?ooool2o`0000Oooooo0_l0000Aooooo`Ko00002?ooool2o`0001Cooooo0_l0000N
ooooo`;o00004oooool2o`0000?ooooo0_l00005ooooo`;o0000Doooool001cooooo00?o0000oooo
ooooool0Doooool2o`0000Gooooo0_l00004ooooo`Go000000Coooooo`000?l0003ooooo0_l0000@
ooooo`;o00001?ooool2o`00013ooooo0_l00008ooooo`;o00004_ooool4o`0001Sooooo0_l0000D
ooooo`;o00000oooool2o`0000[ooooo0_l0001Cooooo`007?ooool00ol0003oooooooooo`1Coooo
o`;o00001Oooool2o`0000Cooooo0_l00004ooooo`;o00003oooool2o`0000;ooooo0_l00004oooo
o`;o0000;_ooool2o`0001[ooooo1?l0000:ooooo`;o00001_ooool2o`0006Cooooo000Looooo`03
o`000?oooooooooo05_ooooo0ol0000;ooooo`Co00002_ooool2o`00023ooooo0_l0000dooooo`;o
00002_ooool2o`0000_ooooo0_l0001Oooooo`007?ooool00ol0003oooooooooo`1Kooooo`Go0000
0oooool2o`0000;ooooo1_l0000Iooooo`;o00001Oooool3o`0000Wooooo0_l0000Cooooo`;o0000
00?oooooo`000?l00000<oooool4o`0005oooooo000Looooo`03o`000?oooooooooo05Cooooo0_l0
0007ooooo`Co00000_ooool2o`0000;ooooo0_l0000Mooooo`;o00001Oooool3o`0000_ooooo0_l0
000Aooooo`;o000000?oooooo`000?l000009Oooool4o`0000Cooooo0_l00003ooooo`?o0000HOoo
ool001cooooo00?o0000ooooooooool0E?ooool2o`0000Oooooo1?l00005ooooo`;o00002Oooool2
o`0000?ooooo0_l0000Hooooo`;o00002Oooool2o`0000oooooo1?l0000Oooooo`;o00001oooool4
o`0000Cooooo0_l00003ooooo`?o0000HOooool001cooooo00?o0000ooooooooool0H_ooool2o`00
00;ooooo0_l00002ooooo`;o00001Oooool4o`000003ooooool0003o000001Sooooo0_l00003oooo
o`;o00001?ooool2o`0000Cooooo0_l00009ooooo`;o00000oooool2o`0000;ooooo0_l0000Hoooo
o`;o00000oooool2o`0000_ooooo0ol0001Uooooo`007?ooool00ol0003oooooooooo`1Rooooo`;o
00001_ooool2o`0000Gooooo1Ol0000Oooooo`;o00002_ooool2o`0000cooooo1?l00002ooooo`;o
00006?ooool2o`0000?ooooo0_l00005ooooo`;o00001?ooool3o`0006Gooooo000Looooo`03o`00
0?oooooooooo05[ooooo0_l00006ooooo`;o00004?ooool2o`0000Gooooo1_l0000Iooooo`;o0000
3_ooool2o`0000?ooooo0_l0000Nooooo`;o00001_ooool2o`0000;ooooo0_l00004ooooo`;o0000
1?ooool2o`00063ooooo000Looooo`03o`000?oooooooooo05[ooooo0_l00002ooooo`;o000000?o
ooooo`000?l000003?ooool2o`0000[ooooo1_l00006ooooo`;o00002Oooool2o`0000Kooooo0_l0
000>ooooo`;o00000oooool2o`0000;ooooo0_l0000Rooooo`;o00003_ooool2o`00063ooooo000L
ooooo`;o0000Goooool2o`000003ooooool0003o000000_ooooo0ol0000Fooooo`Co00001oooool2
o`000003ooooool0003o000000Kooooo0_l0000@ooooo`;o000000Coooooo`000?l0003o00008ooo
ool2o`0000?ooooo0ol00004ooooo`;o000000?oooooo`000?l00000H?ooool001cooooo00?o0000
ooooooooool0COooool2o`0000cooooo0_l00005ooooo`;o000000?oooooo`000?l000001Oooool5
o`0001Sooooo0_l0000:ooooo`;o00001_ooool3o`0000oooooo0_l000000ooooooo0000o`00000T
ooooo`;o00000oooool3o`0000Cooooo0_l0001Sooooo`007?ooool00ol0003oooooooooo`1=oooo
o`;o00003?ooool2o`0000Gooooo0_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00000
0ooooooo0000o`00000@ooooo`;o00003Oooool2o`0000cooooo0_l00003ooooo`;o00003Oooool2
o`0000kooooo0_l0000;ooooo`;o00002?ooool2o`0000?ooooo0ol0001Xooooo`007?ooool00ol0
003oooooooooo`1Looooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`;o00003?ooool2
o`0000Wooooo0_l00005ooooo`Co00001?ooool2o`00017ooooo0_l0000=ooooo`;o00003_ooool2
o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0000?ooooo0_l00003ooooo`;o00000_ooool4
o`0006Sooooo000Looooo`03o`000?oooooooooo05cooooo0_l00009ooooo`;o00003Oooool2o`00
00?ooooo0_l0000:ooooo`Go00005?ooool3o`0000gooooo0_l0000Dooooo`;o000000Coooooo`00
0?l0003o00002?ooool4o`000003ooooool0003o000000;ooooo0_l00005ooooo`;o0000Hoooool0
01cooooo00?o0000ooooooooool0Ioooool2o`0001;ooooo0_l0000:ooooo`;o00005_ooool4o`00
00Kooooo0ol00004ooooo`;o00002Oooool2o`000003ooooool0003o000000Wooooo0_l00005oooo
o`;o00001?ooool2o`000003ooooool0003o000000;o00001oooool2o`0006?ooooo000Looooo`03
o`000?oooooooooo05_ooooo0ol00006ooooo`Co00002Oooool2o`0000Cooooo0_l0000;ooooo`;o
00002?ooool6o`0000_ooooo0_l00004ooooo`;o00000_ooool3o`000003ooooool0003o000000co
oooo0_l000000ooooooo0000o`000005ooooo`;o00000_ooool2o`0000Gooooo0_l00007ooooo`Co
0000K?ooool001cooooo00?o0000ooooooooool0Foooool3o`0000Kooooo1?l00002ooooo`;o0000
1Oooool3o`0000?ooooo1_l00007ooooo`;o00001Oooool2o`000003ooooool0003o000000Co0000
3_ooool5o`0000Kooooo0_l0000<ooooo`;o00001_ooool4o`0000;ooooo0_l00006ooooo`;o0000
00?oooooo`000?l000007oooool2o`0005;ooooo000Looooo`03o`000?oooooooooo06Oooooo1Ol0
0006ooooo`;o00001Oooool4o`0000Oooooo1_l000001?oooooo0000o`000?ooool2o`0001;ooooo
1?l00004ooooo`;o00003_ooool4o`0000Gooooo0_l00004ooooo`Co00001?ooool2o`000003oooo
ool0003o000000;ooooo0_l0000Kooooo`;o0000D_ooool001cooooo00?o0000ooooooooool0H?oo
ool2o`0000Gooooo1Ol00007ooooo`;o00000oooool2o`0000cooooo1?l00004ooooo`;o00000_oo
ool2o`0000;ooooo0_l0000Booooo`;o000000?oooooo`000?l000002_ooool5o`0000[ooooo0_l0
00000ooooooo0000o`00000;ooooo`;o0000Koooool001cooooo00?o0000ooooooooool0H?ooool2
o`0000Kooooo1Ol00003ooooo`Go00000_ooool3o`0000[ooooo0_l000000ooooooo0000o`000004
ooooo`Oo00000_ooool2o`0000Gooooo0_l0000>ooooo`;o00001Oooool4o`000003ooooool0003o
000000gooooo0ol00003ooooo`Ko0000MOooool001cooooo00?o0000ooooooooool0J?ooool2o`00
0004ooooool0003o0000o`0000;ooooo1Ol00002ooooo`;o00002oooool2o`0000Oooooo1Ol0000;
ooooo`;o00001_ooool2o`0000gooooo1?l0000>ooooo`Go00000oooool6o`0000Kooooo0_l0001]
ooooo`007?ooool00ol0003oooooooooo`1Oooooo`Co00002Oooool2o`0000Gooooo0_l0000=oooo
o`;o00007_ooool2o`000003ooooool0003o000001oooooo0_l000000ooooooo0000o`000003oooo
o`;o00002_ooool2o`0006gooooo000Looooo`03o`000?oooooooooo05oooooo1?l0000>ooooo`;o
00003?ooool2o`000004ooooool0003o0000ooooo`Co00000_ooool2o`00017ooooo0_l00002oooo
o`;o00006Oooool2o`0000[ooooo0_l0000:ooooo`;o0000L_ooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oo
oooooooo067ooooo0_l0000:ooooo`?o000000?oooooo`000?l000003?ooool2o`0000Cooooo1?l0
0002ooooo`;o00001Oooool2o`0000[ooooo1_l0000Iooooo`;o00003oooool2o`000003ooooool0
003o000000;ooooo0_l0001booooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0F_ooool2o`0000Go
oooo0_l0000:ooooo`?o00000_ooool2o`0000Cooooo0_l0000Cooooo`;o00000oooool2o`0000;o
oooo0_l00007ooooo`Go00005_ooool2o`0000oooooo0_l000001?oooooo0000o`000?ooool2o`00
07Kooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo05[ooooo0_l0000Booooo`;o00000_ooool2o`00
00Cooooo0_l000001?oooooo0000o`000?ooool3o`0000cooooo0_l00006ooooo`?o00001oooool2
o`0001Wooooo0_l0000?ooooo`;o0000O?ooool00003ooooool0003ooooo00;ooooo00?o0000oooo
ooooool02Oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0001Looooo`;o00004_ooool3
o`0000?ooooo0_l00003ooooo`;o000000Coooooo`000?l0003o00001_ooool3o`000004ooooool0
003o0000o`0000Kooooo0ol0000=ooooo`;o00004_ooool2o`0000Kooooo0_l000000ooooooo0000
o`000008ooooo`;o0000N_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Ooo
ool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0G?ooool2o`0001;ooooo
0ol00003ooooo`;o00002oooool2o`0000;ooooo0ol000000ooooooo0000o`000002o`0000?ooooo
1?l0000>ooooo`;o00000_ooool2o`0000[ooooo0_l00002ooooo`;o00001?ooool4o`000003oooo
ool0003o000000Oooooo0ol0001jooooo`0000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`1Sooooo`Co0000
2_ooool2o`0000Wooooo0_l00005ooooo`;o00002?ooool2o`0000?ooooo0_l0000=ooooo`;o0000
0_ooool2o`000003ooooool0003o000000[ooooo0_l00008ooooo`;o00000oooool2o`0000Oooooo
0_l0001kooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooookZj
^_l000001_ooool00ol0003oooooooooo`1Sooooo`Co00002_ooool2o`0000Wooooo0_l0000Ioooo
o`;o00002?ooool6o`0000Oooooo0_l0000Cooooo`;o0000Q?ooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0L?oo
ool2o`0001Kooooo0_l00003ooooo`;o00002?ooool2o`0000[ooooo0ol00008ooooo`;o00000_oo
ool2o`0000Wooooo0_l00005ooooo`Ko0000Ooooool001cooooo00?o0000ooooooooool0Ioooool2
o`0000Oooooo0_l00005ooooo`;o00003oooool2o`000003ooooool0003o000000;o00005?ooool2
o`0000gooooo0_l00003ooooo`;o00001?ooool2o`0000Gooooo1_l0001oooooo`007?ooool00ol0
003oooooooooo`1Wooooo`;o00003_ooool2o`0000[ooooo0_l00006ooooo`Co00001_ooool2o`00
00Cooooo0_l00006ooooo`;o00000_ooool2o`0000Wooooo0_l00003ooooo`;o0000T?ooool001co
oooo00?o0000ooooooooool0Poooool2o`0000;ooooo1?l00003ooooo`?o00000_ooool6o`0000;o
oooo0_l0000:ooooo`;o0000X?ooool001cooooo00?o0000ooooooooool0Qoooool4o`0000?ooooo
0ol00002ooooo`Ko00003Oooool2o`0000Wooooo0_l00002ooooo`;o00000_ooool3o`0008gooooo
000Looooo`03o`000?oooooooooo08Wooooo0_l00009ooooo`Go00003Oooool2o`0000Wooooo1_l0
0002ooooo`?o0000SOooool001cooooo00?o0000ooooooooool0ROooool2o`0000[ooooo1?l0000E
ooooo`;o00000oooool2o`0009Cooooo000Looooo`03o`000?oooooooooo07Sooooo0_l0000?oooo
o`Co00002_ooool2o`0000kooooo0_l00002ooooo`;o000000?oooooo`000?l00000VOooool001co
oooo00?o0000ooooooooool0N?ooool2o`0000cooooo0_l00003ooooo`;o00006_ooool2o`0000;o
oooo0_l0000<ooooo`Co0000S?ooool001cooooo00?o0000ooooooooool0Q_ooool2o`0000Kooooo
1?l0000<ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l00004ooooo`?o0000
1_ooool4o`0008cooooo000Looooo`03o`000?oooooooooo08kooooo1?l00008ooooo`;o00000_oo
ool2o`000003ooooool0003o000000Co00000oooool2o`0000Cooooo1Ol0002Dooooo`007?ooool0
0ol0003oooooooooo`2Jooooo`;o00001oooool2o`0000kooooo0_l0002Dooooo`007?ooool2o`00
09oooooo0_l0000kooooo`;o0000K?ooool001cooooo00?o0000ooooooooool0SOooool2o`0000oo
oooo0_l0000=ooooo`;o0000;?ooool2o`0006cooooo000Looooo`03o`000?oooooooooo08;ooooo
0_l00009ooooo`;o00007?ooool4o`0009[ooooo000Looooo`03o`000?oooooooooo08;ooooo0_l0
000Wooooo`;o0000W?ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0:?ooooo0_l0002Tooooo`007?ooool00ol0003oooooooooo`2Soooo
o`;o0000Y?ooool001cooooo00?o0000ooooooooool0/_ooool2o`0009Gooooo000Looooo`03o`00
0?oooooooooo0:_ooooo0_l00005ooooo`;o0000UOooool001cooooo00?o0000ooooooooool0Zooo
ool2o`0009cooooo000Looooo`03o`000?oooooooooo0:?ooooo0_l0002Tooooo`007?ooool00ol0
003oooooooooo`2Sooooo`;o0000Y?ooool001cooooo0_l0002Dooooo`;o0000]?ooool001cooooo
00?o0000ooooooooool0Toooool2o`000;Cooooo000Looooo`03o`000?oooooooooo0?ooooooB_oo
ool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooo
od[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0
oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooo
oooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Loooo
o`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`00
7?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool0
0ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:
ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oo
ooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooooooo
o`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooo
ooooool0oooooom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooooooo
ool0oooooom:ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
B_ooool001Cooooo00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o0000
ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03
o`000?oooooooooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`004_oo
ool00omEEEGoIVIVo`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo002Qooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05_ooool4o`000003
oa0@4?oooooooooo00;ooooo0_l000002Ol@413oooooooooooooooooc<c<ob4Q8Ol0003o8B4Qolc<
c003ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0S?ooool00:;ooooo00Go0000oooooooooooooooo
o`000009ooooo`Ko00003?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo
00Go8B4QoiRHV?ooooooV9RHob4Q8@03ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40S?ooool00:;o
oooo00Go0000ooooooooooooooooo`00000Kooooo`03o`000?oooooooooo00;ooooo1Ol00003oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000008cooooo002R
ooooo`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo00?o0000ooooooooool00_oo
ool01?m4A4CogMgMooooool00004ooooo`05oc8b<_nHV9SooooooiRHV?lb<S800oooool01Olb<S;o
V9RHoooooonHV9So<S8b08cooooo002Rooooo`05o`000?n7QhOoooooojVYZOl000006oooool00ol0
003oooooooooo`02ooooo`04omgMgOmEEEGoooooo`0000Cooooo00Goc<c<o`000?l0003o0000olc<
c003ooooo`05olc<c?l0003o0000o`000?o<c<`0S?ooool00:7ooooo00?o410@o`000?mgMgL00_l0
00000onHV9Soooooooooo`0Iooooo`03o`000?oooooooooo00?ooooo00?oMgMgolc<c?l000001?oo
ool01Ol@413o^[Zjoooooonj^[[o410@00?ooooo00Go410@okZj^_oooooo^[Zjoa0@402<ooooo`00
`_ooool00ol0003oooooooooo`03ooooo`03onk^k_m4A4Co000000Cooooo00Go0000okZj^_oooooo
^[Zjo`000003ooooo`05o`000?nj^[[ooooookZj^_l00000S?ooool00<3ooooo00?oEEEEofIVI_l0
00001_ooool00omgMgOo0000ooooo`03ooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01OnY
ZJWo410@o`000?l@413oZJVY08cooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1494) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.60175 .59572 Mdot
.59746 .59039 Mdot
.50411 .3388 Mdot
.4254 .56105 Mdot
.18671 .54697 Mdot
.54824 .35609 Mdot
.70509 .45419 Mdot
.69722 .4528 Mdot
.49419 .33811 Mdot
.69908 .66688 Mdot
.65624 .42527 Mdot
.47507 .55214 Mdot
.67058 .45316 Mdot
.43823 .60142 Mdot
.4908 .87843 Mdot
.41038 .51981 Mdot
.60556 .59697 Mdot
.28115 .35081 Mdot
.43752 .53204 Mdot
.53411 .32573 Mdot
.62132 .67179 Mdot
.43548 .59774 Mdot
.60703 .61481 Mdot
.43819 .60198 Mdot
.40605 .57521 Mdot
.59877 .61835 Mdot
.56248 .58313 Mdot
.37349 .59025 Mdot
.40231 .61999 Mdot
.65962 .42473 Mdot
.28508 .37956 Mdot
.3009 .75429 Mdot
.33817 .60583 Mdot
.28321 .59615 Mdot
.64862 .46379 Mdot
.50099 .76769 Mdot
.52844 .36474 Mdot
.69026 .44911 Mdot
.68256 .4416 Mdot
.69175 .46685 Mdot
.69204 .45916 Mdot
.61814 .63111 Mdot
.76656 .4999 Mdot
.73193 .41373 Mdot
.44209 .63203 Mdot
.2177 .37437 Mdot
.40168 .74874 Mdot
.45082 .5687 Mdot
.62191 .65485 Mdot
.44509 .24571 Mdot
.68295 .33144 Mdot
.64968 .47352 Mdot
.51098 .32312 Mdot
.56335 .11193 Mdot
.65734 .44173 Mdot
.40531 .64593 Mdot
.51741 .35315 Mdot
.42004 .60004 Mdot
.43678 .60604 Mdot
.54615 .68627 Mdot
.35387 .58991 Mdot
.35461 .3549 Mdot
.55682 .60473 Mdot
.48103 .45575 Mdot
.52108 .3441 Mdot
.66784 .43127 Mdot
.61918 .59004 Mdot
.65396 .44578 Mdot
.35038 .64251 Mdot
.55792 .38011 Mdot
.43936 .54963 Mdot
.66475 .42819 Mdot
.59538 .6603 Mdot
.38681 .60366 Mdot
.42005 .24046 Mdot
.22561 .35038 Mdot
.36101 .33969 Mdot
.5139 .74997 Mdot
.55113 .68388 Mdot
.41532 .2924 Mdot
.39033 .63073 Mdot
.25614 .44757 Mdot
.2443 .33759 Mdot
.64239 .64999 Mdot
.38841 .52553 Mdot
.31188 .34916 Mdot
.38399 .59943 Mdot
.1654 .52479 Mdot
.36377 .56095 Mdot
.52145 .5079 Mdot
.4963 .36282 Mdot
.58947 .63995 Mdot
.4195 .56348 Mdot
.40818 .61784 Mdot
.60683 .71017 Mdot
.43973 .54525 Mdot
.43051 .58363 Mdot
.64053 .64471 Mdot
.64189 .46553 Mdot
.35425 .61582 Mdot
.50844 .29336 Mdot
.56132 .34491 Mdot
.37218 .56769 Mdot
.54162 .38421 Mdot
.59498 .65875 Mdot
.40717 .6171 Mdot
.67871 .44309 Mdot
.39252 .55829 Mdot
.71365 .29453 Mdot
.61441 .60171 Mdot
.38011 .61258 Mdot
.39183 .37962 Mdot
.45438 .70306 Mdot
.59883 .65314 Mdot
.68759 .49174 Mdot
.4507 .54003 Mdot
.41838 .58603 Mdot
.62471 .59374 Mdot
.56216 .33756 Mdot
.17704 .46858 Mdot
.64455 .62238 Mdot
.61351 .4514 Mdot
.64686 .66479 Mdot
.48355 .5613 Mdot
.52506 .34024 Mdot
.7246 .4648 Mdot
.73766 .47412 Mdot
.29207 .41649 Mdot
.38769 .59769 Mdot
.78462 .50928 Mdot
.54625 .32723 Mdot
.60597 .64298 Mdot
.65784 .44925 Mdot
.353 .56238 Mdot
.62931 .6132 Mdot
.62303 .43486 Mdot
.33963 .38138 Mdot
.66569 .2815 Mdot
.58255 .60485 Mdot
.57956 .44135 Mdot
.63414 .45913 Mdot
.68153 .48031 Mdot
.55603 .83519 Mdot
.63829 .6345 Mdot
.37052 .38213 Mdot
.65525 .45482 Mdot
.39362 .46018 Mdot
.42571 .63719 Mdot
.24501 .43285 Mdot
.77447 .35111 Mdot
.31072 .53367 Mdot
.62664 .30227 Mdot
.36762 .38842 Mdot
.663 .48547 Mdot
.4279 .5724 Mdot
.58718 .6164 Mdot
.60453 .61752 Mdot
.35429 .58833 Mdot
.39181 .57249 Mdot
.40954 .53401 Mdot
.45876 .57793 Mdot
.54894 .54796 Mdot
.36997 .5496 Mdot
.41806 .74965 Mdot
.58578 .63543 Mdot
.43027 .56384 Mdot
.50939 .32446 Mdot
.47772 .59212 Mdot
.68721 .43893 Mdot
.42698 .59755 Mdot
.42338 .56292 Mdot
.37013 .62253 Mdot
.66204 .47975 Mdot
.27188 .70444 Mdot
.41176 .68249 Mdot
.26049 .62636 Mdot
.60389 .54432 Mdot
.49028 .37324 Mdot
.38439 .59158 Mdot
.37053 .36657 Mdot
.56321 .77253 Mdot
.42078 .55032 Mdot
.27857 .21164 Mdot
.4352 .58791 Mdot
.21217 .6107 Mdot
.33069 .55535 Mdot
.27104 .61377 Mdot
.27131 .43934 Mdot
.40743 .57867 Mdot
.76039 .59119 Mdot
.63401 .41559 Mdot
.56861 .30496 Mdot
.68146 .46698 Mdot
.52051 .32679 Mdot
.50942 .34225 Mdot
.42279 .42444 Mdot
.4406 .51493 Mdot
.47068 .56443 Mdot
.39186 .54005 Mdot
.56923 .35299 Mdot
.54269 .59799 Mdot
.39009 .38393 Mdot
.55387 .6133 Mdot
.24712 .70549 Mdot
.49946 .24382 Mdot
.67238 .42416 Mdot
.34995 .3925 Mdot
.52419 .38052 Mdot
.49101 .35601 Mdot
.3711 .39086 Mdot
.42727 .61739 Mdot
.63838 .6312 Mdot
.41463 .81009 Mdot
.63354 .23738 Mdot
.80874 .68344 Mdot
.63574 .6513 Mdot
.77245 .53947 Mdot
.69122 .43961 Mdot
.51501 .36503 Mdot
.42194 .58504 Mdot
.40717 .60967 Mdot
.59126 .65954 Mdot
.441 .55082 Mdot
.66615 .63614 Mdot
.41373 .58139 Mdot
.67654 .41843 Mdot
.34372 .34372 Mdot
.42194 .42482 Mdot
.3281 .44823 Mdot
.60529 .66194 Mdot
.64437 .7502 Mdot
.48966 .35983 Mdot
.57542 .76552 Mdot
.65423 .42749 Mdot
.33408 .37287 Mdot
.48187 .34425 Mdot
.39509 .36862 Mdot
.38095 .53219 Mdot
.54122 .33492 Mdot
.38992 .36426 Mdot
.44226 .46899 Mdot
.45254 .62328 Mdot
.60817 .20098 Mdot
.6807 .47357 Mdot
.57333 .59544 Mdot
.39435 .55435 Mdot
.50382 .37912 Mdot
.38135 .65425 Mdot
.58051 .28302 Mdot
.74413 .3831 Mdot
.54154 .32362 Mdot
.38445 .43665 Mdot
.33202 .36909 Mdot
.65916 .33838 Mdot
.77994 .51396 Mdot
.5874 .59071 Mdot
.39574 .53012 Mdot
.31083 .75769 Mdot
.65509 .4541 Mdot
.40398 .55395 Mdot
.21188 .45165 Mdot
.64269 .45361 Mdot
.41776 .59928 Mdot
.61997 .44405 Mdot
.60537 .61779 Mdot
.56784 .68178 Mdot
.63269 .6015 Mdot
.44388 .55263 Mdot
.67149 .4425 Mdot
.5597 .32625 Mdot
.59896 .62404 Mdot
.45049 .60815 Mdot
.37619 .58872 Mdot
.45055 .45382 Mdot
.4368 .5683 Mdot
.25379 .64402 Mdot
.41018 .57995 Mdot
.50367 .35187 Mdot
.37247 .61777 Mdot
.78795 .5945 Mdot
.42107 .42021 Mdot
.63548 .60704 Mdot
.53253 .3195 Mdot
.51012 .33538 Mdot
.3457 .27805 Mdot
.69938 .48403 Mdot
.46792 .5986 Mdot
.49585 .37366 Mdot
.44353 .49757 Mdot
.63662 .43507 Mdot
.36337 .56813 Mdot
.58812 .41256 Mdot
.51814 .25686 Mdot
.52033 .32339 Mdot
.50761 .59818 Mdot
.57372 .61879 Mdot
.41064 .56635 Mdot
.5087 .37908 Mdot
.39184 .50254 Mdot
.39205 .6218 Mdot
.78845 .46394 Mdot
.42594 .44618 Mdot
.63436 .45484 Mdot
.47435 .56356 Mdot
.40616 .54183 Mdot
.54385 .3408 Mdot
.58946 .65109 Mdot
.63422 .4397 Mdot
.61018 .62909 Mdot
.2749 .59837 Mdot
.62613 .2153 Mdot
.50718 .50245 Mdot
.37267 .34361 Mdot
.50909 .27131 Mdot
.27242 .64057 Mdot
.73275 .70165 Mdot
.54807 .80983 Mdot
.3077 .71493 Mdot
.54976 .37913 Mdot
.48162 .25824 Mdot
.51495 .34332 Mdot
.37563 .57889 Mdot
.52703 .3447 Mdot
.32878 .78526 Mdot
.41865 .58107 Mdot
.53422 .35453 Mdot
.62662 .7309 Mdot
.41651 .56717 Mdot
.58626 .58986 Mdot
.23562 .66348 Mdot
.82319 .562 Mdot
.6764 .50671 Mdot
.52845 .37414 Mdot
.44244 .81924 Mdot
.43194 .58186 Mdot
.3709 .61544 Mdot
.5811 .62948 Mdot
.34479 .62609 Mdot
.37608 .36106 Mdot
.34717 .39297 Mdot
.60808 .48627 Mdot
.32814 .40535 Mdot
.47516 .56403 Mdot
.59558 .62319 Mdot
.56501 .55776 Mdot
.36879 .27617 Mdot
.45942 .24541 Mdot
.64072 .4181 Mdot
.23512 .6612 Mdot
.6737 .59726 Mdot
.63957 .53967 Mdot
.60333 .39143 Mdot
.61068 .65107 Mdot
.2934 .74556 Mdot
.68535 .463 Mdot
.55669 .18535 Mdot
.72392 .65252 Mdot
.42132 .61618 Mdot
.65087 .43286 Mdot
.44423 .64857 Mdot
.80106 .59738 Mdot
.50874 .19033 Mdot
.33998 .71515 Mdot
.36485 .56159 Mdot
.49546 .24487 Mdot
.42548 .59201 Mdot
.57541 .28659 Mdot
.398 .58225 Mdot
.60928 .6318 Mdot
.71051 .65813 Mdot
.65578 .49807 Mdot
.51639 .61517 Mdot
.65148 .34695 Mdot
.37733 .387 Mdot
.4121 .58337 Mdot
.42644 .61616 Mdot
.3775 .35758 Mdot
.60082 .60843 Mdot
.42596 .5391 Mdot
.65387 .74342 Mdot
.42827 .61998 Mdot
.69289 .44657 Mdot
.71534 .66625 Mdot
.35438 .69283 Mdot
.46206 .56889 Mdot
.64517 .6527 Mdot
.69542 .43654 Mdot
.67485 .44516 Mdot
.3639 .52243 Mdot
.65025 .42137 Mdot
.4418 .58084 Mdot
.47993 .18705 Mdot
.59298 .60187 Mdot
.77607 .39589 Mdot
.63442 .615 Mdot
.50363 .73839 Mdot
.64264 .46341 Mdot
.69513 .30359 Mdot
.44844 .64542 Mdot
.68196 .46262 Mdot
.47381 .65471 Mdot
.45327 .61724 Mdot
.46142 .61225 Mdot
.41571 .80744 Mdot
.50194 .36163 Mdot
.44211 .44846 Mdot
.6566 .42391 Mdot
.45071 .59371 Mdot
.44847 .54366 Mdot
.69759 .43965 Mdot
.56501 .22512 Mdot
.74002 .67161 Mdot
.41349 .58034 Mdot
.6044 .63567 Mdot
.61151 .64266 Mdot
.45499 .62923 Mdot
.37942 .56578 Mdot
.51379 .32825 Mdot
.54624 .31466 Mdot
.49835 .38313 Mdot
.4296 .44319 Mdot
.72503 .3354 Mdot
.18831 .4914 Mdot
.69065 .46804 Mdot
.74858 .54812 Mdot
.49582 .49114 Mdot
.36547 .55784 Mdot
.53912 .37329 Mdot
.40905 .54094 Mdot
.43623 .55639 Mdot
.72037 .39423 Mdot
.19933 .54329 Mdot
.69141 .64968 Mdot
.5996 .66012 Mdot
.6606 .48338 Mdot
.45653 .53321 Mdot
.69743 .40915 Mdot
.34084 .36255 Mdot
.32666 .51796 Mdot
.65424 .4264 Mdot
.59302 .58727 Mdot
.66283 .47265 Mdot
.40465 .61151 Mdot
.38235 .64719 Mdot
.6122 .64966 Mdot
.35361 .35291 Mdot
.34478 .57159 Mdot
.41671 .596 Mdot
.73433 .27636 Mdot
.38044 .46966 Mdot
.62789 .52421 Mdot
.41194 .57835 Mdot
.4553 .61142 Mdot
.3513 .40353 Mdot
.42216 .61991 Mdot
.39337 .5448 Mdot
.44698 .70693 Mdot
.68925 .5411 Mdot
.37896 .39455 Mdot
.50369 .19723 Mdot
.63536 .65086 Mdot
.2954 .73253 Mdot
.5452 .36654 Mdot
.63355 .50453 Mdot
.73128 .66984 Mdot
.48731 .33096 Mdot
.62196 .30649 Mdot
.28487 .71377 Mdot
.48898 .301 Mdot
.51324 .39518 Mdot
.55954 .59513 Mdot
.45451 .57394 Mdot
.41713 .58881 Mdot
.37324 .36702 Mdot
.63626 .63341 Mdot
.5544 .50112 Mdot
.28901 .27758 Mdot
.43449 .59572 Mdot
.78378 .45744 Mdot
.49213 .21743 Mdot
.4802 .24397 Mdot
.35901 .36681 Mdot
.34957 .39613 Mdot
.41092 .58477 Mdot
.43594 .69493 Mdot
.59767 .61842 Mdot
.45047 .60759 Mdot
.36733 .5524 Mdot
.51092 .36949 Mdot
.61817 .60697 Mdot
.56154 .3357 Mdot
.66914 .31498 Mdot
.25448 .61377 Mdot
.52785 .16023 Mdot
.64515 .44212 Mdot
.42659 .22749 Mdot
.62581 .43844 Mdot
.26027 .45066 Mdot
.47792 .33911 Mdot
.40159 .5645 Mdot
.57943 .63627 Mdot
.44988 .58521 Mdot
.38445 .56496 Mdot
.42994 .61671 Mdot
.45808 .55926 Mdot
.55142 .15552 Mdot
.38325 .38526 Mdot
.36986 .53403 Mdot
.50253 .34604 Mdot
.24874 .33999 Mdot
.30129 .29727 Mdot
.42754 .61466 Mdot
.38835 .58579 Mdot
.61734 .61415 Mdot
.36907 .56591 Mdot
.62898 .43793 Mdot
.57391 .59149 Mdot
.39032 .6094 Mdot
.19615 .62489 Mdot
.39888 .62015 Mdot
.26703 .63867 Mdot
.66288 .4717 Mdot
.65234 .24749 Mdot
.36983 .64194 Mdot
.7446 .42379 Mdot
.44229 .44864 Mdot
.4826 .34098 Mdot
.62307 .45435 Mdot
.5305 .36347 Mdot
.31003 .2517 Mdot
.48445 .61637 Mdot
.42387 .57241 Mdot
.37936 .54791 Mdot
.49096 .3739 Mdot
.15993 .58515 Mdot
.6707 .35752 Mdot
.49235 .60938 Mdot
.51856 .3281 Mdot
.62394 .58616 Mdot
.30095 .68135 Mdot
.62821 .62968 Mdot
.32093 .37006 Mdot
.69518 .44546 Mdot
.35783 .35318 Mdot
.25304 .52439 Mdot
.61102 .59723 Mdot
.57104 .64123 Mdot
.5404 .36861 Mdot
.58149 .66969 Mdot
.85832 .40594 Mdot
.73009 .6476 Mdot
.29028 .44207 Mdot
.58687 .62168 Mdot
.4059 .61963 Mdot
.25332 .48389 Mdot
.71698 .6561 Mdot
.52979 .36121 Mdot
.4244 .54547 Mdot
.59313 .69215 Mdot
.51182 .32766 Mdot
.34701 .60906 Mdot
.49874 .34831 Mdot
.6759 .46977 Mdot
.52744 .37664 Mdot
.64491 .67238 Mdot
.37746 .60065 Mdot
.87025 .40792 Mdot
.34592 .42062 Mdot
.43051 .57839 Mdot
.68465 .48462 Mdot
.60244 .26232 Mdot
.41198 .55753 Mdot
.38473 .35273 Mdot
.53832 .34955 Mdot
.54112 .62357 Mdot
.40738 .58096 Mdot
.51934 .32809 Mdot
.58562 .59668 Mdot
.71863 .4629 Mdot
.60099 .70721 Mdot
.65983 .54555 Mdot
.58216 .63704 Mdot
.62551 .54404 Mdot
.64051 .47846 Mdot
.46014 .60706 Mdot
.43605 .54237 Mdot
.60885 .63809 Mdot
.24457 .389 Mdot
.35903 .59444 Mdot
.37913 .62307 Mdot
.50917 .36453 Mdot
.5368 .36238 Mdot
.53769 .81034 Mdot
.56347 .35407 Mdot
.35941 .63369 Mdot
.61195 .63784 Mdot
.42129 .56186 Mdot
.61548 .61034 Mdot
.37113 .56464 Mdot
.31137 .61274 Mdot
.59995 .60841 Mdot
.72014 .39894 Mdot
.42871 .54891 Mdot
.33733 .57407 Mdot
.39724 .55719 Mdot
.45674 .58084 Mdot
.51542 .33023 Mdot
.3647 .36404 Mdot
.36329 .55753 Mdot
.38458 .33599 Mdot
.37832 .39123 Mdot
.66583 .50432 Mdot
.50847 .36827 Mdot
.38083 .38 Mdot
.42231 .20328 Mdot
.53418 .33219 Mdot
.37671 .36823 Mdot
.29853 .29947 Mdot
.64837 .4652 Mdot
.57343 .62224 Mdot
.41165 .56864 Mdot
.28089 .54014 Mdot
.39733 .74043 Mdot
.46561 .37029 Mdot
.41696 .57896 Mdot
.4083 .55267 Mdot
.64312 .61348 Mdot
.22791 .32341 Mdot
.55093 .38374 Mdot
.41516 .62365 Mdot
.60459 .59019 Mdot
.16379 .39176 Mdot
.50729 .34842 Mdot
.37399 .36391 Mdot
.66068 .47582 Mdot
.51256 .62772 Mdot
.75203 .43769 Mdot
.69522 .47845 Mdot
.48727 .31298 Mdot
.6805 .32469 Mdot
.43033 .53285 Mdot
.55656 .35767 Mdot
.68465 .76951 Mdot
.54214 .54867 Mdot
.46785 .45062 Mdot
.40844 .79562 Mdot
.60211 .65095 Mdot
.62691 .43802 Mdot
.36933 .38893 Mdot
.62962 .65576 Mdot
.60586 .59801 Mdot
.70038 .45033 Mdot
.3968 .68591 Mdot
.59451 .40946 Mdot
.68577 .44184 Mdot
.32822 .49749 Mdot
.2265 .39799 Mdot
.5484 .36764 Mdot
.37699 .36181 Mdot
.23934 .53292 Mdot
.6152 .62949 Mdot
.26631 .72873 Mdot
.44213 .82689 Mdot
.43074 .58368 Mdot
.36916 .38536 Mdot
.16459 .56687 Mdot
.22345 .33599 Mdot
.64108 .45345 Mdot
.64809 .5054 Mdot
.3367 .36085 Mdot
.39762 .55321 Mdot
.38054 .48389 Mdot
.36471 .5923 Mdot
.69571 .45586 Mdot
.59148 .71686 Mdot
.60825 .59675 Mdot
.68463 .47538 Mdot
.29592 .57198 Mdot
.44178 .58417 Mdot
.42549 .54796 Mdot
.32654 .47104 Mdot
.63045 .65712 Mdot
.48123 .34333 Mdot
.42586 .5354 Mdot
.42099 .5964 Mdot
.3688 .63861 Mdot
.47343 .61877 Mdot
.49233 .69419 Mdot
.38099 .57958 Mdot
.40919 .23856 Mdot
.37283 .55752 Mdot
.44542 .56841 Mdot
.63591 .66078 Mdot
.49382 .15592 Mdot
.67419 .33189 Mdot
.42501 .59661 Mdot
.44174 .61892 Mdot
.67785 .47773 Mdot
.62612 .39832 Mdot
.68158 .67321 Mdot
.54162 .61665 Mdot
.49777 .8237 Mdot
.45505 .62115 Mdot
.6184 .59034 Mdot
.38701 .35835 Mdot
.46623 .6013 Mdot
.60231 .58561 Mdot
.37736 .62694 Mdot
.50132 .32764 Mdot
.53103 .33078 Mdot
.55923 .57055 Mdot
.38434 .3771 Mdot
.78919 .57114 Mdot
.74635 .54776 Mdot
.54023 .33701 Mdot
.41897 .5728 Mdot
.63672 .41464 Mdot
.50058 .37144 Mdot
.48394 .30145 Mdot
.21954 .43628 Mdot
.58535 .61554 Mdot
.58736 .63984 Mdot
.24107 .43488 Mdot
.63891 .29306 Mdot
.79627 .43797 Mdot
.67858 .4701 Mdot
.36464 .5406 Mdot
.77168 .55987 Mdot
.58978 .6454 Mdot
.2582 .46783 Mdot
.37638 .38443 Mdot
.64347 .45443 Mdot
.66224 .3807 Mdot
.62586 .61771 Mdot
.5689 .60683 Mdot
.35457 .60613 Mdot
.41224 .60309 Mdot
.56262 .79872 Mdot
.3914 .33997 Mdot
.70433 .45948 Mdot
.37485 .36126 Mdot
.4869 .32854 Mdot
.36891 .59698 Mdot
.60242 .61113 Mdot
.2114 .41548 Mdot
.46539 .56992 Mdot
.49225 .33574 Mdot
.59671 .64833 Mdot
.33084 .37424 Mdot
.37689 .34789 Mdot
.4602 .58111 Mdot
.60375 .77197 Mdot
.68852 .4536 Mdot
.62772 .64958 Mdot
.59698 .44476 Mdot
.36307 .58839 Mdot
.40668 .59733 Mdot
.31884 .60075 Mdot
.70331 .4631 Mdot
.70168 .61095 Mdot
.38725 .35106 Mdot
.6284 .64333 Mdot
.38356 .58147 Mdot
.38105 .36786 Mdot
.75609 .54789 Mdot
.5013 .31806 Mdot
.5242 .37783 Mdot
.37488 .34821 Mdot
.35218 .37175 Mdot
.39069 .35646 Mdot
.26928 .73496 Mdot
.59963 .58051 Mdot
.65438 .56393 Mdot
.41533 .62847 Mdot
.27794 .43907 Mdot
.35777 .54363 Mdot
.63164 .45291 Mdot
.49849 .35739 Mdot
.39996 .56057 Mdot
.46384 .58134 Mdot
.3176 .58072 Mdot
.77974 .42056 Mdot
.34263 .65205 Mdot
.61349 .60349 Mdot
.3878 .64955 Mdot
.52698 .37342 Mdot
.27732 .76408 Mdot
.48846 .84687 Mdot
.37781 .64596 Mdot
.61061 .40581 Mdot
.5925 .6086 Mdot
.69256 .46663 Mdot
.29538 .49464 Mdot
.6518 .46888 Mdot
.61981 .64583 Mdot
.37518 .58209 Mdot
.73012 .57682 Mdot
.37082 .40557 Mdot
.45294 .5889 Mdot
.68271 .47047 Mdot
.4412 .55187 Mdot
.69782 .47235 Mdot
.27296 .55347 Mdot
.66262 .76849 Mdot
.4343 .58765 Mdot
.41801 .52427 Mdot
.59648 .78743 Mdot
.43756 .61195 Mdot
.36523 .32148 Mdot
.59134 .60856 Mdot
.60412 .71989 Mdot
.44454 .52776 Mdot
.36436 .50085 Mdot
.36367 .5976 Mdot
.6383 .71459 Mdot
.40543 .6002 Mdot
.47201 .24149 Mdot
.37728 .6081 Mdot
.39287 .54329 Mdot
.65803 .43988 Mdot
.68176 .47705 Mdot
.6275 .66906 Mdot
.52075 .38573 Mdot
.2642 .63919 Mdot
.41292 .59553 Mdot
.71034 .32148 Mdot
.69213 .56496 Mdot
.35352 .36907 Mdot
.62415 .64373 Mdot
.16225 .41279 Mdot
.62791 .42937 Mdot
.54275 .83321 Mdot
.48392 .81734 Mdot
.71212 .51335 Mdot
.21225 .5266 Mdot
.56241 .24336 Mdot
.3337 .3686 Mdot
.36695 .61953 Mdot
.4461 .32468 Mdot
.466 .23978 Mdot
.2399 .39244 Mdot
.62516 .46287 Mdot
.5579 .78112 Mdot
.20411 .48733 Mdot
.34341 .34833 Mdot
.34229 .39414 Mdot
.66352 .48134 Mdot
.58528 .36326 Mdot
.45913 .52966 Mdot
.35895 .38414 Mdot
.49594 .37952 Mdot
.53342 .32799 Mdot
.51435 .39005 Mdot
.59979 .61684 Mdot
.49211 .84292 Mdot
.62687 .47152 Mdot
.63366 .44981 Mdot
.57097 .29785 Mdot
.29789 .60322 Mdot
.55979 .62943 Mdot
.52395 .36804 Mdot
.54803 .37365 Mdot
.58662 .60785 Mdot
.3962 .6435 Mdot
.4869 .61036 Mdot
.43017 .59658 Mdot
.36892 .36705 Mdot
.40775 .6052 Mdot
.52668 .33314 Mdot
.64453 .44575 Mdot
.53468 .37973 Mdot
.69775 .48056 Mdot
.19882 .42883 Mdot
.45818 .60116 Mdot
.37556 .60073 Mdot
.68072 .22523 Mdot
.57022 .62781 Mdot
.23504 .35722 Mdot
.71608 .42087 Mdot
.51304 .34319 Mdot
.39439 .545 Mdot
.55333 .62338 Mdot
.40507 .37669 Mdot
.53641 .16681 Mdot
.36835 .57171 Mdot
.61623 .62258 Mdot
.37004 .59204 Mdot
.50141 .51675 Mdot
.82605 .48102 Mdot
.61842 .63489 Mdot
.78795 .4085 Mdot
.41281 .62215 Mdot
.43346 .20934 Mdot
.37128 .5606 Mdot
.44716 .47451 Mdot
.35906 .59417 Mdot
.63704 .64955 Mdot
.42778 .60011 Mdot
.55398 .61089 Mdot
.54985 .34121 Mdot
.675 .4765 Mdot
.58273 .63607 Mdot
.4538 .5582 Mdot
.7511 .20295 Mdot
.66241 .46582 Mdot
.41767 .58396 Mdot
.65497 .47529 Mdot
.63773 .62233 Mdot
.6167 .65537 Mdot
.27797 .30191 Mdot
.66536 .31295 Mdot
.67349 .46893 Mdot
.36914 .59568 Mdot
.47286 .22201 Mdot
.39293 .56947 Mdot
.42537 .48973 Mdot
.4031 .64616 Mdot
.40156 .6356 Mdot
.26266 .32001 Mdot
.63528 .45771 Mdot
.79692 .43204 Mdot
.23608 .3327 Mdot
.25055 .33773 Mdot
.62727 .67255 Mdot
.35092 .34688 Mdot
.28503 .73083 Mdot
.73083 .34472 Mdot
.4913 .33059 Mdot
.40391 .55835 Mdot
.54764 .5888 Mdot
.68642 .44929 Mdot
.34707 .36006 Mdot
.43326 .58755 Mdot
.54466 .37397 Mdot
.73778 .68919 Mdot
.66129 .48446 Mdot
.62294 .63336 Mdot
.64128 .60638 Mdot
.37048 .19366 Mdot
.40073 .58007 Mdot
.38043 .60469 Mdot
.69549 .44566 Mdot
.57947 .24447 Mdot
.35326 .39037 Mdot
.62768 .72866 Mdot
.67096 .46754 Mdot
.5479 .47567 Mdot
.59655 .58453 Mdot
.40797 .55007 Mdot
.20176 .60857 Mdot
.65021 .37476 Mdot
.733 .28784 Mdot
.37081 .3682 Mdot
.43599 .49273 Mdot
.63654 .64943 Mdot
.65746 .45148 Mdot
.63684 .27348 Mdot
.45849 .61584 Mdot
.41662 .53945 Mdot
.45267 .48932 Mdot
.66689 .50123 Mdot
.64319 .68416 Mdot
.36716 .57482 Mdot
.44184 .44676 Mdot
.37255 .56673 Mdot
.36609 .52723 Mdot
.42465 .64649 Mdot
.3952 .59605 Mdot
.6083 .61531 Mdot
.4985 .55619 Mdot
.48359 .3631 Mdot
.68266 .65867 Mdot
.53791 .47558 Mdot
.42501 .57952 Mdot
.38241 .62424 Mdot
.35645 .72645 Mdot
.60377 .29315 Mdot
.58297 .63269 Mdot
.60654 .67091 Mdot
.63713 .42301 Mdot
.44475 .63657 Mdot
.52289 .38552 Mdot
.35307 .55496 Mdot
.51116 .32986 Mdot
.60503 .61345 Mdot
.51106 .34531 Mdot
.66872 .48008 Mdot
.55872 .34895 Mdot
.71724 .32425 Mdot
.65313 .45846 Mdot
.58038 .62175 Mdot
.39098 .60618 Mdot
.68707 .48432 Mdot
.31029 .43065 Mdot
.36969 .36943 Mdot
.15343 .49676 Mdot
.39016 .60998 Mdot
.69109 .51895 Mdot
.34224 .53023 Mdot
.54095 .37781 Mdot
.82232 .46398 Mdot
.58377 .64608 Mdot
.36554 .39673 Mdot
.62351 .66048 Mdot
.32864 .51783 Mdot
.35972 .37562 Mdot
.16815 .43793 Mdot
.43103 .45449 Mdot
.38882 .47161 Mdot
.42469 .64059 Mdot
.3421 .4606 Mdot
.50818 .32073 Mdot
.68452 .44934 Mdot
.63101 .28237 Mdot
.39684 .54197 Mdot
.74975 .70198 Mdot
.63685 .6578 Mdot
.50159 .37656 Mdot
.65758 .44736 Mdot
.63205 .4449 Mdot
.43508 .62308 Mdot
.4242 .26758 Mdot
.41284 .53769 Mdot
.65535 .29341 Mdot
.44067 .81714 Mdot
.6593 .57504 Mdot
.4143 .58154 Mdot
.54478 .34113 Mdot
.37011 .59168 Mdot
.3835 .34757 Mdot
.58239 .8193 Mdot
.34264 .56892 Mdot
.69635 .42358 Mdot
.39577 .34206 Mdot
.64 .6325 Mdot
.3135 .57756 Mdot
.65571 .55704 Mdot
.39646 .57993 Mdot
.48182 .12557 Mdot
.37867 .36919 Mdot
.45409 .31286 Mdot
.4597 .55635 Mdot
.46943 .58875 Mdot
.45557 .42959 Mdot
.75789 .40967 Mdot
.59712 .36668 Mdot
.44134 .60656 Mdot
.31233 .41981 Mdot
.64988 .4754 Mdot
.39176 .55642 Mdot
.41614 .58725 Mdot
.40887 .71953 Mdot
.63745 .46648 Mdot
.50222 .33584 Mdot
.48205 .3361 Mdot
.46632 .35313 Mdot
.39484 .35718 Mdot
.7064 .65051 Mdot
.27504 .46006 Mdot
.78187 .63791 Mdot
.36271 .4012 Mdot
.46423 .58998 Mdot
.49516 .28926 Mdot
.36929 .58624 Mdot
.3478 .36217 Mdot
.64071 .47068 Mdot
.5906 .64812 Mdot
.76707 .55974 Mdot
.50476 .32374 Mdot
.47361 .59842 Mdot
.36751 .39405 Mdot
.58778 .61587 Mdot
.26913 .50479 Mdot
.63922 .63381 Mdot
.67663 .46326 Mdot
.71001 .64889 Mdot
.34351 .36269 Mdot
.63224 .6058 Mdot
.66256 .41179 Mdot
.25415 .31265 Mdot
.45115 .63749 Mdot
.73955 .60696 Mdot
.64214 .62611 Mdot
.58647 .65986 Mdot
.61862 .58751 Mdot
.45057 .56562 Mdot
.60611 .40707 Mdot
.42559 .63641 Mdot
.63885 .46407 Mdot
.4986 .34436 Mdot
.66981 .75089 Mdot
.72798 .38268 Mdot
.5896 .48517 Mdot
.34635 .57633 Mdot
.44222 .58547 Mdot
.41154 .58478 Mdot
.39321 .51931 Mdot
.72233 .32807 Mdot
.4474 .56415 Mdot
.65875 .43961 Mdot
.53495 .34486 Mdot
.36943 .62159 Mdot
.50474 .31104 Mdot
.29006 .31216 Mdot
.33752 .3587 Mdot
.60232 .47279 Mdot
.56106 .84698 Mdot
.58583 .61806 Mdot
.53801 .32099 Mdot
.53506 .33822 Mdot
.33733 .38105 Mdot
.69151 .45008 Mdot
.64034 .62691 Mdot
.45809 .50705 Mdot
.38006 .39056 Mdot
.425 .59908 Mdot
.63982 .40468 Mdot
.72706 .72313 Mdot
.36029 .6121 Mdot
.41671 .55901 Mdot
.52525 .3916 Mdot
.45442 .31703 Mdot
.87234 .53748 Mdot
.2922 .47085 Mdot
.35752 .3598 Mdot
.35718 .34858 Mdot
.58457 .60558 Mdot
.47284 .5803 Mdot
.6789 .48417 Mdot
.62304 .68954 Mdot
.68819 .60963 Mdot
.79933 .52013 Mdot
.71092 .26429 Mdot
.38371 .5625 Mdot
.5465 .22054 Mdot
.4426 .57519 Mdot
.61113 .58286 Mdot
.6081 .6188 Mdot
.59596 .62851 Mdot
.68482 .45049 Mdot
.51943 .76832 Mdot
.67058 .44129 Mdot
.65561 .79912 Mdot
.62727 .65317 Mdot
.42031 .45036 Mdot
.52201 .37068 Mdot
.49723 .60142 Mdot
.33519 .36271 Mdot
.73138 .62924 Mdot
.34923 .64137 Mdot
.43692 .68554 Mdot
.49553 .37197 Mdot
.57988 .62998 Mdot
.5757 .24611 Mdot
.3509 .78236 Mdot
.5797 .66683 Mdot
.31991 .62529 Mdot
.29356 .49693 Mdot
.3539 .36548 Mdot
.7305 .28445 Mdot
.36175 .35465 Mdot
.67977 .47179 Mdot
.3758 .59362 Mdot
.38432 .5988 Mdot
.37068 .56757 Mdot
.4455 .61181 Mdot
.65425 .48559 Mdot
.37956 .53656 Mdot
.78694 .59612 Mdot
.49744 .32622 Mdot
.30255 .36595 Mdot
.36948 .35819 Mdot
.62745 .45864 Mdot
.53417 .34318 Mdot
.61061 .29819 Mdot
.32223 .44568 Mdot
.41011 .58083 Mdot
.40059 .55994 Mdot
.57254 .81195 Mdot
.36753 .5751 Mdot
.4781 .54903 Mdot
.50886 .32539 Mdot
.34005 .68594 Mdot
.33866 .35811 Mdot
.34735 .35121 Mdot
.65092 .45842 Mdot
.60899 .61702 Mdot
.37745 .37612 Mdot
.51569 .36881 Mdot
.34291 .58604 Mdot
.39652 .52983 Mdot
.64135 .63365 Mdot
.58311 .81115 Mdot
.36933 .34317 Mdot
.46965 .21903 Mdot
.57836 .6208 Mdot
.64997 .65146 Mdot
.41457 .53944 Mdot
.75946 .33141 Mdot
.65466 .66334 Mdot
.39773 .38161 Mdot
.62655 .45971 Mdot
.30965 .49063 Mdot
.63019 .42972 Mdot
.62574 .63232 Mdot
.39892 .62308 Mdot
.59776 .61278 Mdot
.40819 .57928 Mdot
.40361 .82544 Mdot
.39128 .59893 Mdot
.78891 .6222 Mdot
.24413 .42181 Mdot
.55039 .35524 Mdot
.59351 .27815 Mdot
.54446 .36693 Mdot
.59634 .65649 Mdot
.45817 .54932 Mdot
.34084 .38879 Mdot
.33979 .26618 Mdot
.52214 .64614 Mdot
.49549 .36229 Mdot
.57028 .36313 Mdot
.61859 .43981 Mdot
.35872 .59854 Mdot
.42738 .54297 Mdot
.53547 .35679 Mdot
.67244 .64024 Mdot
.6305 .61546 Mdot
.38304 .58587 Mdot
.44418 .58423 Mdot
.54918 .35947 Mdot
.26137 .30298 Mdot
.52443 .56768 Mdot
.38267 .59201 Mdot
.60522 .38241 Mdot
.6322 .44911 Mdot
.49488 .60458 Mdot
.41651 .52547 Mdot
.35086 .37432 Mdot
.52614 .68511 Mdot
.35037 .76369 Mdot
.64346 .47389 Mdot
.52744 .33072 Mdot
.39201 .58115 Mdot
.54281 .33996 Mdot
.37896 .53514 Mdot
.75361 .43975 Mdot
.54024 .32389 Mdot
.39077 .63114 Mdot
.39102 .64091 Mdot
.63521 .65476 Mdot
.39179 .56096 Mdot
.4124 .77452 Mdot
.48488 .34777 Mdot
.42901 .62418 Mdot
.61541 .74826 Mdot
.67748 .435 Mdot
.47251 .62063 Mdot
.3816 .38851 Mdot
.39115 .4873 Mdot
.72958 .5566 Mdot
.21486 .5494 Mdot
.33494 .35846 Mdot
.44476 .55664 Mdot
.56052 .37675 Mdot
.70418 .45834 Mdot
.81643 .57027 Mdot
.40025 .55159 Mdot
.69066 .46424 Mdot
.64456 .44658 Mdot
.34472 .35975 Mdot
.46651 .15242 Mdot
.46092 .56195 Mdot
.42268 .61438 Mdot
.46878 .76155 Mdot
.56389 .61465 Mdot
.4002 .6032 Mdot
.41596 .62035 Mdot
.65254 .43875 Mdot
.47401 .55478 Mdot
.48996 .8092 Mdot
.63493 .72028 Mdot
.69353 .43439 Mdot
.77345 .5817 Mdot
.53558 .32385 Mdot
.38119 .36053 Mdot
.6049 .64716 Mdot
.356 .39225 Mdot
.51771 .37431 Mdot
.4063 .61764 Mdot
.69827 .45076 Mdot
.40655 .76392 Mdot
.66675 .48254 Mdot
.21022 .4686 Mdot
.57005 .59492 Mdot
.62302 .47906 Mdot
.4694 .1327 Mdot
.62497 .35933 Mdot
.71043 .48837 Mdot
.35338 .36959 Mdot
.55414 .29818 Mdot
.44398 .58216 Mdot
.71343 .26027 Mdot
.46333 .59575 Mdot
.60622 .73436 Mdot
.48452 .33517 Mdot
.50479 .38678 Mdot
.3787 .59178 Mdot
.41506 .79931 Mdot
.70493 .45174 Mdot
.63942 .43367 Mdot
.3984 .63105 Mdot
.68172 .46314 Mdot
.41548 .6067 Mdot
.52454 .33351 Mdot
.747 .28733 Mdot
.43041 .59207 Mdot
.35665 .53801 Mdot
.71814 .49971 Mdot
.24255 .3325 Mdot
.32862 .34352 Mdot
.30116 .23644 Mdot
.40495 .818 Mdot
.68182 .46187 Mdot
.42149 .63381 Mdot
.77879 .56955 Mdot
.53767 .38825 Mdot
.60191 .48839 Mdot
.40159 .61248 Mdot
.44244 .61631 Mdot
.38638 .54674 Mdot
.42493 .55066 Mdot
.58938 .1876 Mdot
.54927 .65099 Mdot
.51899 .7237 Mdot
.38575 .56373 Mdot
.34762 .45062 Mdot
.65894 .46876 Mdot
.53172 .60333 Mdot
.37613 .39812 Mdot
.38625 .56177 Mdot
.6111 .68022 Mdot
.68419 .43124 Mdot
.68533 .78324 Mdot
.69495 .45954 Mdot
.51168 .33611 Mdot
.68624 .47785 Mdot
.43625 .56983 Mdot
.6109 .6424 Mdot
.46031 .40919 Mdot
.66344 .33929 Mdot
.47813 .35119 Mdot
.42994 .57846 Mdot
.37776 .44002 Mdot
.4866 .36473 Mdot
.22923 .35891 Mdot
.59952 .64222 Mdot
.30313 .40661 Mdot
.60214 .61411 Mdot
.3989 .62757 Mdot
.3969 .62679 Mdot
.62456 .42708 Mdot
.67462 .48087 Mdot
.60395 .61481 Mdot
.37941 .16584 Mdot
.38449 .35017 Mdot
.60019 .62945 Mdot
.43488 .52058 Mdot
.54249 .42719 Mdot
.60528 .63968 Mdot
.4111 .37441 Mdot
.64666 .4424 Mdot
.57082 .61628 Mdot
.36053 .56564 Mdot
.33352 .49615 Mdot
.3787 .35156 Mdot
.47433 .36116 Mdot
.25728 .49008 Mdot
.48891 .35464 Mdot
.62356 .45668 Mdot
.54814 .36337 Mdot
.63562 .4484 Mdot
.71139 .57554 Mdot
.6862 .65019 Mdot
.44233 .35579 Mdot
.6226 .4632 Mdot
.53951 .36882 Mdot
.37323 .59282 Mdot
.3287 .41036 Mdot
.46573 .55708 Mdot
.43915 .54671 Mdot
.64465 .43525 Mdot
.62453 .65711 Mdot
.62037 .67243 Mdot
.41016 .47824 Mdot
.6135 .61658 Mdot
.49031 .33885 Mdot
.48651 .67893 Mdot
.71721 .3385 Mdot
.64283 .42534 Mdot
.67389 .47792 Mdot
.36866 .58207 Mdot
.53022 .36289 Mdot
.48011 .36774 Mdot
.62593 .43183 Mdot
.77283 .42016 Mdot
.40512 .52143 Mdot
.61208 .67347 Mdot
.56627 .61149 Mdot
.61615 .63639 Mdot
.58471 .58031 Mdot
.37539 .49774 Mdot
.64437 .4601 Mdot
.61652 .6592 Mdot
.36778 .5819 Mdot
.41631 .619 Mdot
.70376 .66947 Mdot
.38679 .36252 Mdot
.3858 .63297 Mdot
.42352 .64621 Mdot
.40854 .54905 Mdot
.53552 .37549 Mdot
.48429 .54989 Mdot
.56018 .34193 Mdot
.5352 .38689 Mdot
.53409 .38762 Mdot
.73841 .35991 Mdot
.52863 .83034 Mdot
.29009 .68707 Mdot
.42947 .62294 Mdot
.51026 .21475 Mdot
.51534 .358 Mdot
.56005 .66611 Mdot
.69708 .60505 Mdot
.39626 .54531 Mdot
.39209 .25005 Mdot
.53887 .35889 Mdot
.58048 .61291 Mdot
.39563 .60663 Mdot
.51925 .31583 Mdot
.39085 .37902 Mdot
.4599 .61155 Mdot
.49459 .31965 Mdot
.63093 .60298 Mdot
.39747 .35494 Mdot
.57243 .63077 Mdot
.53719 .38742 Mdot
.4627 .54115 Mdot
.81734 .37571 Mdot
.49829 .31583 Mdot
.38107 .22003 Mdot
.43962 .65999 Mdot
.37802 .58727 Mdot
.55188 .32292 Mdot
.65472 .64528 Mdot
.62382 .45494 Mdot
.58227 .52114 Mdot
.59245 .60042 Mdot
.50519 .38699 Mdot
.52077 .38352 Mdot
.47814 .35077 Mdot
.60622 .60066 Mdot
.46961 .61725 Mdot
.61903 .61071 Mdot
.68999 .47627 Mdot
.40657 .56824 Mdot
.27238 .61727 Mdot
.59182 .24725 Mdot
.58189 .61457 Mdot
.49429 .34407 Mdot
.35812 .40581 Mdot
.43958 .58284 Mdot
.56245 .23289 Mdot
.3723 .59124 Mdot
.63495 .4444 Mdot
.46638 .70654 Mdot
.35071 .69849 Mdot
.41238 .63592 Mdot
.37438 .57658 Mdot
.64255 .43216 Mdot
.43018 .58249 Mdot
.35888 .59516 Mdot
.71635 .32252 Mdot
.62193 .6071 Mdot
.43202 .59945 Mdot
.50059 .35155 Mdot
.69293 .33195 Mdot
.38772 .5236 Mdot
.50639 .29742 Mdot
.31922 .42132 Mdot
.43417 .70803 Mdot
.46276 .59882 Mdot
.61529 .41467 Mdot
.42171 .54415 Mdot
.45464 .59514 Mdot
.37681 .57779 Mdot
.53933 .19016 Mdot
.50805 .31763 Mdot
.54213 .34414 Mdot
.36485 .3483 Mdot
.31474 .41794 Mdot
.35938 .38339 Mdot
.64163 .44651 Mdot
.42951 .27905 Mdot
.55881 .3358 Mdot
.63325 .62654 Mdot
.45153 .58343 Mdot
.50723 .3139 Mdot
.40519 .54673 Mdot
.43466 .57014 Mdot
.54068 .38444 Mdot
.51756 .31895 Mdot
.22453 .40735 Mdot
.38966 .36513 Mdot
.5902 .62575 Mdot
.36978 .61848 Mdot
.37344 .39293 Mdot
.46501 .58724 Mdot
.2765 .43997 Mdot
.59363 .6294 Mdot
.62264 .60926 Mdot
.63869 .67265 Mdot
.39891 .61463 Mdot
.43811 .57536 Mdot
.66936 .44036 Mdot
.58727 .64966 Mdot
.6812 .43639 Mdot
.55059 .50586 Mdot
.32707 .30992 Mdot
.40215 .6129 Mdot
.72172 .64737 Mdot
.37567 .38684 Mdot
.49816 .36536 Mdot
.71383 .73278 Mdot
.36522 .34826 Mdot
.40239 .5809 Mdot
.511 .38358 Mdot
.34181 .37081 Mdot
.47948 .50024 Mdot
.62483 .80715 Mdot
.35143 .40305 Mdot
.36834 .58101 Mdot
.46878 .54591 Mdot
.31835 .22475 Mdot
.32682 .37483 Mdot
.65864 .4738 Mdot
.39664 .61345 Mdot
.5737 .64799 Mdot
.36693 .39434 Mdot
.54356 .26248 Mdot
.53948 .35217 Mdot
.34192 .49492 Mdot
.3359 .58031 Mdot
.48525 .64147 Mdot
.36826 .3503 Mdot
.63015 .64442 Mdot
.44143 .5125 Mdot
.41487 .54041 Mdot
.32654 .37283 Mdot
.7182 .46757 Mdot
.5279 .34344 Mdot
.66908 .32431 Mdot
.60202 .59931 Mdot
.72393 .40397 Mdot
.49702 .3595 Mdot
.45727 .21733 Mdot
.68804 .70365 Mdot
.49098 .60506 Mdot
.42662 .19334 Mdot
.67071 .53613 Mdot
.36499 .5679 Mdot
.39121 .3946 Mdot
.69231 .48365 Mdot
.67279 .42611 Mdot
.67202 .46409 Mdot
.70113 .57582 Mdot
.54185 .61884 Mdot
.47981 .3283 Mdot
.69572 .41201 Mdot
.38275 .36276 Mdot
.32072 .48315 Mdot
.43072 .54025 Mdot
.43997 .5897 Mdot
.36377 .60671 Mdot
.38551 .56083 Mdot
.44339 .55983 Mdot
.69212 .45609 Mdot
.70513 .56025 Mdot
.54857 .63677 Mdot
.5994 .63532 Mdot
.4764 .29304 Mdot
.51235 .3646 Mdot
.50064 .38846 Mdot
.34704 .38197 Mdot
.6064 .35194 Mdot
.50026 .31206 Mdot
.51095 .3433 Mdot
.37165 .62802 Mdot
.62629 .61662 Mdot
.49935 .58783 Mdot
.37142 .57832 Mdot
.49744 .33256 Mdot
.48527 .45537 Mdot
.43558 .79754 Mdot
.26752 .35443 Mdot
.37764 .33853 Mdot
.66433 .40739 Mdot
.34084 .35222 Mdot
.43238 .5353 Mdot
.82302 .49318 Mdot
.51978 .37501 Mdot
.52236 .35041 Mdot
.38792 .37048 Mdot
.75919 .32791 Mdot
.60356 .64975 Mdot
.72613 .40075 Mdot
.6451 .46904 Mdot
.39524 .62383 Mdot
.72938 .70044 Mdot
.53232 .59785 Mdot
.41426 .26932 Mdot
.66687 .46614 Mdot
.55211 .34133 Mdot
.40501 .52733 Mdot
.38155 .57056 Mdot
.36393 .3877 Mdot
.19372 .55473 Mdot
.44511 .6418 Mdot
.15531 .58601 Mdot
.66415 .76813 Mdot
.32408 .72735 Mdot
.41923 .53994 Mdot
.61841 .60627 Mdot
.49186 .32704 Mdot
.37745 .36107 Mdot
.46626 .60967 Mdot
.41067 .80984 Mdot
.63759 .64219 Mdot
.65647 .45755 Mdot
.52107 .46122 Mdot
.30481 .48455 Mdot
.45458 .57329 Mdot
.42676 .62029 Mdot
.45656 .58924 Mdot
.85795 .62078 Mdot
.55653 .35942 Mdot
.58464 .61115 Mdot
.3421 .362 Mdot
.61939 .62253 Mdot
.55173 .34854 Mdot
.42217 .41323 Mdot
.37395 .6042 Mdot
.63828 .61044 Mdot
.62609 .64662 Mdot
.67766 .42948 Mdot
.64358 .47556 Mdot
.5369 .48006 Mdot
.39345 .59852 Mdot
.56584 .34922 Mdot
.62399 .65837 Mdot
.63726 .40873 Mdot
.35838 .37651 Mdot
.64648 .44135 Mdot
.39084 .56197 Mdot
.55917 .34037 Mdot
.36924 .63426 Mdot
.58564 .63788 Mdot
.51143 .34441 Mdot
.22408 .39636 Mdot
.33846 .3573 Mdot
.41702 .61761 Mdot
.29311 .34576 Mdot
.52339 .32905 Mdot
.44462 .57425 Mdot
.39666 .22704 Mdot
.40088 .39225 Mdot
.66893 .36006 Mdot
.50013 .37908 Mdot
.73453 .46646 Mdot
.58572 .60422 Mdot
.75227 .41532 Mdot
.51885 .3431 Mdot
.48716 .22237 Mdot
.20349 .43714 Mdot
.35773 .55959 Mdot
.61349 .62958 Mdot
.72763 .48083 Mdot
.3298 .79322 Mdot
.34299 .23573 Mdot
.41728 .58465 Mdot
.56259 .35702 Mdot
.34555 .37696 Mdot
.64635 .426 Mdot
.69788 .3704 Mdot
.35462 .41721 Mdot
.55964 .31861 Mdot
.37764 .57769 Mdot
.63892 .6279 Mdot
.66748 .44515 Mdot
.72713 .56329 Mdot
.5083 .36309 Mdot
.49667 .34649 Mdot
.46357 .55925 Mdot
.37862 .38339 Mdot
.62363 .23342 Mdot
.51556 .3278 Mdot
.60177 .79252 Mdot
.52284 .39631 Mdot
.391 .38241 Mdot
.41956 .55013 Mdot
.38529 .4816 Mdot
.45874 .61388 Mdot
.33606 .25859 Mdot
.51941 .36849 Mdot
.58663 .62985 Mdot
.41439 .53503 Mdot
.63078 .75263 Mdot
.49067 .33946 Mdot
.63503 .40163 Mdot
.58491 .3129 Mdot
.64116 .45817 Mdot
.71485 .73101 Mdot
.40687 .60762 Mdot
.70391 .45937 Mdot
.35786 .38529 Mdot
.38808 .594 Mdot
.43874 .57051 Mdot
.64517 .62054 Mdot
.67193 .42807 Mdot
.22903 .4001 Mdot
.68604 .47374 Mdot
.66449 .47288 Mdot
.56294 .64216 Mdot
.4293 .60834 Mdot
.50858 .33508 Mdot
.53712 .35945 Mdot
.35838 .56906 Mdot
.67716 .20304 Mdot
.61233 .6512 Mdot
.47701 .36984 Mdot
.8749 .59034 Mdot
.3548 .57997 Mdot
.6993 .73063 Mdot
.18984 .53744 Mdot
.66554 .48398 Mdot
.36723 .58197 Mdot
.63659 .61417 Mdot
.59724 .36093 Mdot
.49677 .34302 Mdot
.36126 .56268 Mdot
.66935 .44686 Mdot
.3902 .36201 Mdot
.48155 .35474 Mdot
.42183 .26921 Mdot
.45551 .60462 Mdot
.36941 .27096 Mdot
.54839 .37749 Mdot
.2675 .69622 Mdot
.61661 .29098 Mdot
.60935 .62829 Mdot
.4332 .56714 Mdot
.57806 .63443 Mdot
.33751 .36955 Mdot
.52411 .46362 Mdot
.65433 .44269 Mdot
.30493 .57615 Mdot
.82368 .51788 Mdot
.47817 .35023 Mdot
.57811 .61736 Mdot
.40889 .63264 Mdot
.75971 .41167 Mdot
.41251 .60923 Mdot
.3301 .55309 Mdot
.23816 .3902 Mdot
.65608 .43154 Mdot
.65303 .4769 Mdot
.43351 .55401 Mdot
.34037 .38451 Mdot
.51312 .36664 Mdot
.5191 .33534 Mdot
.23956 .68525 Mdot
.7278 .40562 Mdot
.55499 .80296 Mdot
.44338 .61573 Mdot
.56911 .34012 Mdot
.73628 .4081 Mdot
.69645 .44997 Mdot
.47882 .61052 Mdot
.51297 .38308 Mdot
.30219 .37333 Mdot
.45295 .48675 Mdot
.4194 .54196 Mdot
.46495 .55028 Mdot
.65712 .47677 Mdot
.5635 .64787 Mdot
.5415 .33519 Mdot
.38565 .64578 Mdot
.43154 .39385 Mdot
.47483 .4961 Mdot
.66327 .7764 Mdot
.59039 .62557 Mdot
.44537 .25218 Mdot
.69262 .45423 Mdot
.34633 .54826 Mdot
.33907 .36064 Mdot
.57426 .33674 Mdot
.55015 .3299 Mdot
.39179 .5786 Mdot
.39941 .52852 Mdot
.6448 .76791 Mdot
.62953 .62338 Mdot
.65343 .46439 Mdot
.38218 .60379 Mdot
.7555 .58805 Mdot
.36817 .56984 Mdot
.6732 .43907 Mdot
.81 .35735 Mdot
.47285 .58556 Mdot
.4182 .61246 Mdot
.62048 .2333 Mdot
.58341 .59957 Mdot
.62189 .66293 Mdot
.75804 .68849 Mdot
.44105 .61659 Mdot
.6773 .75891 Mdot
.58533 .62348 Mdot
.59959 .65107 Mdot
.67482 .29972 Mdot
.43837 .58756 Mdot
.5391 .56933 Mdot
.63527 .45687 Mdot
.66504 .47388 Mdot
.61223 .60531 Mdot
.47532 .62444 Mdot
.63101 .46011 Mdot
.58248 .19996 Mdot
.52937 .36393 Mdot
.80309 .4365 Mdot
.61816 .65206 Mdot
.64648 .52188 Mdot
.68181 .46965 Mdot
.61022 .8189 Mdot
.64521 .38373 Mdot
.37323 .59726 Mdot
.44563 .61404 Mdot
.38663 .36934 Mdot
.38009 .62661 Mdot
.50332 .38603 Mdot
.68152 .46371 Mdot
.39694 .78023 Mdot
.59624 .62818 Mdot
.40415 .59879 Mdot
.38903 .2419 Mdot
.19479 .41644 Mdot
.4913 .25317 Mdot
.63551 .64197 Mdot
.60295 .61918 Mdot
.55761 .35003 Mdot
.55886 .36567 Mdot
.44419 .59867 Mdot
.63391 .43396 Mdot
.5818 .64243 Mdot
.66466 .43576 Mdot
.51688 .37456 Mdot
.5104 .33749 Mdot
.49888 .32003 Mdot
.41963 .53473 Mdot
.50447 .34257 Mdot
.27154 .33805 Mdot
.67791 .39505 Mdot
.5626 .63764 Mdot
.78928 .68481 Mdot
.72763 .56893 Mdot
.49825 .63289 Mdot
.38805 .38815 Mdot
.49655 .32792 Mdot
.69902 .46755 Mdot
.41772 .56282 Mdot
.40191 .5569 Mdot
.73578 .36193 Mdot
.70191 .45851 Mdot
.34191 .36316 Mdot
.69385 .47803 Mdot
.343 .36074 Mdot
.38411 .26849 Mdot
.35773 .60031 Mdot
.37762 .53867 Mdot
.68555 .46466 Mdot
.5077 .34302 Mdot
.54143 .34811 Mdot
.33776 .39429 Mdot
.47547 .45555 Mdot
.48859 .3661 Mdot
.60463 .65376 Mdot
.33509 .72223 Mdot
.53911 .38089 Mdot
.39667 .60534 Mdot
.26939 .45814 Mdot
.69049 .23496 Mdot
.39532 .51905 Mdot
.68107 .29661 Mdot
.42703 .76481 Mdot
.40564 .53556 Mdot
.69799 .24091 Mdot
.70917 .4461 Mdot
.59824 .60373 Mdot
.50899 .32405 Mdot
.49614 .39508 Mdot
.51071 .60647 Mdot
.39638 .35167 Mdot
.47793 .58887 Mdot
.63705 .60833 Mdot
.64123 .60564 Mdot
.37369 .47699 Mdot
.34389 .24388 Mdot
.34333 .37098 Mdot
.35059 .3835 Mdot
.51841 .34023 Mdot
.15071 .50281 Mdot
.31577 .58748 Mdot
.34787 .36005 Mdot
.66668 .64144 Mdot
.38283 .5771 Mdot
.30037 .38785 Mdot
.63181 .56947 Mdot
.60979 .60331 Mdot
.36405 .45599 Mdot
.49581 .33623 Mdot
.61241 .61464 Mdot
.77267 .54567 Mdot
.4557 .62761 Mdot
.59535 .62999 Mdot
.66572 .43753 Mdot
.61572 .31548 Mdot
.61264 .65575 Mdot
.27559 .45222 Mdot
.62456 .43613 Mdot
.63744 .40929 Mdot
.43352 .48293 Mdot
.1251 .40417 Mdot
.68822 .46013 Mdot
.51776 .38271 Mdot
.53677 .35849 Mdot
.51846 .33531 Mdot
.62168 .62277 Mdot
.47794 .35004 Mdot
.62918 .62584 Mdot
.37811 .20031 Mdot
.72173 .27792 Mdot
.35452 .35955 Mdot
.66632 .32319 Mdot
.63354 .63449 Mdot
.73653 .65711 Mdot
.55231 .12391 Mdot
.3648 .58735 Mdot
.6614 .42291 Mdot
.35434 .36068 Mdot
.15862 .53768 Mdot
.34951 .37048 Mdot
.44748 .82787 Mdot
.42142 .69004 Mdot
.41247 .60011 Mdot
.55639 .77209 Mdot
.34722 .39786 Mdot
.59674 .58645 Mdot
.44416 .57483 Mdot
.51531 .49571 Mdot
.34953 .37735 Mdot
.39422 .37321 Mdot
.43842 .60098 Mdot
.5799 .63041 Mdot
.49249 .34567 Mdot
.67517 .4759 Mdot
.35657 .39435 Mdot
.42511 .5097 Mdot
.42822 .62913 Mdot
.37058 .59878 Mdot
.71709 .65658 Mdot
.40612 .38106 Mdot
.68227 .46102 Mdot
.48628 .1634 Mdot
.56014 .37624 Mdot
.45807 .46721 Mdot
.63305 .78654 Mdot
.67005 .56857 Mdot
.52019 .36809 Mdot
.54485 .34219 Mdot
.44465 .56137 Mdot
.32461 .66287 Mdot
.42186 .67914 Mdot
.42935 .43498 Mdot
.47391 .34723 Mdot
.5238 .33886 Mdot
.61519 .66626 Mdot
.29208 .65274 Mdot
.38258 .51923 Mdot
.64866 .47744 Mdot
.53836 .32377 Mdot
.71455 .2826 Mdot
.3845 .37468 Mdot
.45133 .69428 Mdot
.3591 .60646 Mdot
.37486 .59949 Mdot
.66617 .44967 Mdot
.67026 .44187 Mdot
.59469 .3298 Mdot
.3454 .75307 Mdot
.41541 .76145 Mdot
.70874 .548 Mdot
.4204 .70885 Mdot
.63529 .65833 Mdot
.58151 .61498 Mdot
.65823 .3478 Mdot
.69499 .46432 Mdot
.4052 .5345 Mdot
.60693 .61564 Mdot
.3074 .39288 Mdot
.31711 .55288 Mdot
.32491 .52825 Mdot
.682 .74254 Mdot
.41509 .57837 Mdot
.62612 .6051 Mdot
.57933 .59975 Mdot
.56934 .60353 Mdot
.67258 .50735 Mdot
.44114 .60701 Mdot
.4175 .58084 Mdot
.42715 .54164 Mdot
.76411 .36725 Mdot
.45025 .60173 Mdot
.69398 .50796 Mdot
.54086 .46634 Mdot
.55454 .68367 Mdot
.39341 .64792 Mdot
.69987 .47243 Mdot
.45976 .57727 Mdot
.33891 .38383 Mdot
.36683 .60364 Mdot
.31861 .53799 Mdot
.6621 .46747 Mdot
.49646 .55342 Mdot
.71505 .57923 Mdot
.38054 .55237 Mdot
.39476 .38505 Mdot
.68606 .59707 Mdot
.31045 .75421 Mdot
.34599 .33451 Mdot
.60571 .65309 Mdot
.52409 .36557 Mdot
.7016 .46274 Mdot
.51609 .34443 Mdot
.36729 .55387 Mdot
.64646 .34552 Mdot
.16509 .53882 Mdot
.50941 .48452 Mdot
.39019 .56011 Mdot
.32271 .57453 Mdot
.59643 .6515 Mdot
.54004 .3852 Mdot
.65508 .61869 Mdot
.4511 .56632 Mdot
.36888 .36559 Mdot
.36098 .38606 Mdot
.57186 .51525 Mdot
.23557 .62672 Mdot
.6517 .23867 Mdot
.6721 .45229 Mdot
.51058 .327 Mdot
.33486 .36271 Mdot
.5113 .23021 Mdot
.71973 .45777 Mdot
.63884 .43689 Mdot
.65689 .46472 Mdot
.4043 .61984 Mdot
.51948 .31835 Mdot
.55901 .68621 Mdot
.56761 .372 Mdot
.43196 .58053 Mdot
.53894 .37495 Mdot
.49814 .3731 Mdot
.37567 .36378 Mdot
.65692 .46656 Mdot
.51887 .37356 Mdot
.40507 .62646 Mdot
.58524 .61987 Mdot
.67011 .49927 Mdot
.23846 .41328 Mdot
.34558 .24664 Mdot
.57382 .55474 Mdot
.58716 .59716 Mdot
.29542 .73062 Mdot
.63271 .4554 Mdot
.77263 .40588 Mdot
.2214 .41235 Mdot
.46433 .5652 Mdot
.69989 .22104 Mdot
.57611 .37466 Mdot
.49612 .36896 Mdot
.4199 .54861 Mdot
.58792 .35175 Mdot
.4078 .60143 Mdot
.50746 .37237 Mdot
.67733 .38527 Mdot
.55077 .61428 Mdot
.50703 .34779 Mdot
.36449 .63465 Mdot
.43981 .56501 Mdot
.61845 .60753 Mdot
.56248 .34081 Mdot
.47462 .58222 Mdot
.27104 .74608 Mdot
.67753 .44319 Mdot
.67493 .5662 Mdot
.25644 .45906 Mdot
.69313 .45062 Mdot
.60365 .63111 Mdot
.44238 .54936 Mdot
.35565 .38447 Mdot
.6355 .63071 Mdot
.30397 .56573 Mdot
.35671 .35163 Mdot
.80074 .39098 Mdot
.57957 .59902 Mdot
.49316 .35986 Mdot
.33357 .37584 Mdot
.42635 .6355 Mdot
.55447 .38272 Mdot
.5929 .28123 Mdot
.51623 .36557 Mdot
.43991 .55298 Mdot
.7034 .3567 Mdot
.65322 .46533 Mdot
.41232 .5856 Mdot
.48879 .35912 Mdot
.68241 .2994 Mdot
.42047 .62277 Mdot
.43046 .54917 Mdot
.61532 .79581 Mdot
.63977 .69795 Mdot
.35408 .37266 Mdot
.57453 .63793 Mdot
.36679 .58348 Mdot
.38297 .38835 Mdot
.41601 .32619 Mdot
.38879 .6135 Mdot
.6384 .64123 Mdot
.48089 .60797 Mdot
.56265 .3538 Mdot
.68379 .44002 Mdot
.42913 .44234 Mdot
.39024 .38015 Mdot
.20049 .32816 Mdot
.54394 .3289 Mdot
.4374 .54235 Mdot
.36987 .56967 Mdot
.24539 .51675 Mdot
.60396 .60619 Mdot
.65859 .59723 Mdot
.41854 .61799 Mdot
.76787 .3681 Mdot
.3943 .59294 Mdot
.58516 .35473 Mdot
.60301 .65012 Mdot
.4301 .61421 Mdot
.63712 .48627 Mdot
.36066 .53519 Mdot
.38069 .35443 Mdot
.59947 .2417 Mdot
.46751 .61662 Mdot
.80516 .36854 Mdot
.55648 .52591 Mdot
.50516 .34761 Mdot
.29686 .31235 Mdot
.26553 .74434 Mdot
.70381 .5831 Mdot
.62002 .62471 Mdot
.18204 .53891 Mdot
.50807 .33516 Mdot
.34723 .27182 Mdot
.31804 .7752 Mdot
.43354 .55972 Mdot
.45359 .57043 Mdot
.28634 .49913 Mdot
.54916 .38386 Mdot
.56642 .36147 Mdot
.35008 .57047 Mdot
.36503 .53044 Mdot
.50467 .33819 Mdot
.46501 .60459 Mdot
.40709 .65212 Mdot
.66504 .42397 Mdot
.63237 .64795 Mdot
.65286 .43042 Mdot
.62961 .44675 Mdot
.56259 .2173 Mdot
.5329 .5175 Mdot
.67689 .44012 Mdot
.67351 .48628 Mdot
.32731 .42453 Mdot
.38787 .77926 Mdot
.3554 .39223 Mdot
.24864 .67058 Mdot
.5265 .34377 Mdot
.43233 .61064 Mdot
.56825 .60793 Mdot
.39591 .74904 Mdot
.41604 .33745 Mdot
.80622 .55529 Mdot
.42551 .53948 Mdot
.49052 .3413 Mdot
.66045 .54867 Mdot
.49335 .57312 Mdot
.47544 .32972 Mdot
.38716 .6063 Mdot
.50931 .38896 Mdot
.44801 .80931 Mdot
.49153 .22467 Mdot
.49081 .39152 Mdot
.57723 .65141 Mdot
.37851 .59876 Mdot
.62142 .59078 Mdot
.69589 .45066 Mdot
.34608 .38868 Mdot
.35577 .37744 Mdot
.44394 .58751 Mdot
.31846 .61586 Mdot
.36593 .28315 Mdot
.44026 .57987 Mdot
.386 .57514 Mdot
.67826 .41955 Mdot
.37812 .57621 Mdot
.37461 .56353 Mdot
.40238 .54464 Mdot
.3897 .54284 Mdot
.66371 .47306 Mdot
.60543 .34599 Mdot
.48481 .62979 Mdot
.34671 .62793 Mdot
.62302 .45 Mdot
.19491 .51863 Mdot
.63077 .45738 Mdot
.33031 .78698 Mdot
.66133 .48153 Mdot
.36219 .37448 Mdot
.20628 .52751 Mdot
.33716 .61166 Mdot
.64246 .64208 Mdot
.60165 .48119 Mdot
.33621 .37565 Mdot
.67604 .46477 Mdot
.50955 .37607 Mdot
.62876 .79479 Mdot
.56878 .58149 Mdot
.59632 .68289 Mdot
.67612 .59196 Mdot
.61029 .33911 Mdot
.55858 .34651 Mdot
.58806 .58903 Mdot
.48647 .80499 Mdot
.38016 .56203 Mdot
.3815 .38936 Mdot
.44421 .59634 Mdot
.69764 .44874 Mdot
.50178 .33281 Mdot
.36044 .21788 Mdot
.36518 .38783 Mdot
.76721 .70838 Mdot
.54303 .35257 Mdot
.38964 .55652 Mdot
.63119 .46015 Mdot
.82618 .61934 Mdot
.65385 .43201 Mdot
.35761 .6682 Mdot
.58621 .6071 Mdot
.29543 .24693 Mdot
.62659 .63505 Mdot
.56808 .2648 Mdot
.8815 .48325 Mdot
.46953 .23108 Mdot
.58127 .62136 Mdot
.41742 .41237 Mdot
.39803 .58063 Mdot
.37094 .60009 Mdot
.43342 .20706 Mdot
.56929 .62755 Mdot
.37896 .56781 Mdot
.73649 .37996 Mdot
.725 .4098 Mdot
.68738 .72392 Mdot
.55585 .35113 Mdot
.40475 .60388 Mdot
.6688 .4213 Mdot
.70222 .44259 Mdot
.53363 .32951 Mdot
.63522 .44112 Mdot
.42085 .58141 Mdot
.63266 .63481 Mdot
.48839 .30824 Mdot
.37144 .38027 Mdot
.16273 .49014 Mdot
.35626 .34368 Mdot
.52162 .36866 Mdot
.46424 .55283 Mdot
.51089 .33833 Mdot
.44657 .89664 Mdot
.40295 .58328 Mdot
.58491 .62492 Mdot
.38358 .57176 Mdot
.37897 .5946 Mdot
.3963 .5368 Mdot
.49421 .34716 Mdot
.25 .3738 Mdot
.4177 .62519 Mdot
.65069 .44264 Mdot
.47717 .71339 Mdot
.40303 .63902 Mdot
.45806 .32087 Mdot
.34179 .50902 Mdot
.7112 .63848 Mdot
.5726 .61374 Mdot
.50789 .35389 Mdot
.59544 .62462 Mdot
.78162 .383 Mdot
.60378 .63138 Mdot
.44939 .73358 Mdot
.50036 .80797 Mdot
.58169 .78204 Mdot
.60059 .77397 Mdot
.46149 .41967 Mdot
.57157 .63349 Mdot
.37453 .33129 Mdot
.58337 .64381 Mdot
.60388 .60267 Mdot
.61461 .12768 Mdot
.63542 .60321 Mdot
.40145 .61023 Mdot
.37446 .62794 Mdot
.51475 .24274 Mdot
.27842 .4139 Mdot
.40313 .56789 Mdot
.39641 .565 Mdot
.33271 .36654 Mdot
.77941 .38867 Mdot
.65617 .35892 Mdot
.6469 .69743 Mdot
.20495 .40992 Mdot
.44182 .59821 Mdot
.3645 .59801 Mdot
.39192 .65383 Mdot
.84077 .54643 Mdot
.52875 .20353 Mdot
.58701 .66199 Mdot
.34301 .61562 Mdot
.40729 .23392 Mdot
.42195 .53732 Mdot
.41912 .62075 Mdot
.40887 .57916 Mdot
.50722 .33472 Mdot
.57125 .62394 Mdot
.36519 .55826 Mdot
.2341 .52282 Mdot
.40383 .61608 Mdot
.66321 .5364 Mdot
.18924 .36439 Mdot
.40734 .60846 Mdot
.63675 .66303 Mdot
.36979 .59703 Mdot
.61471 .61081 Mdot
.61338 .59592 Mdot
.34316 .58322 Mdot
.41321 .70526 Mdot
.61516 .66713 Mdot
.43264 .58009 Mdot
.51211 .3793 Mdot
.26147 .67709 Mdot
.44694 .56374 Mdot
.35745 .39245 Mdot
.44012 .61639 Mdot
.39972 .36595 Mdot
.39502 .57345 Mdot
.53912 .32692 Mdot
.39152 .73657 Mdot
.5224 .34853 Mdot
.44811 .19035 Mdot
.50733 .31833 Mdot
.73776 .73494 Mdot
.59075 .5964 Mdot
.68548 .34144 Mdot
.80649 .47121 Mdot
.74876 .39284 Mdot
.59071 .42832 Mdot
.49571 .43296 Mdot
.63505 .43378 Mdot
.59901 .60717 Mdot
.7754 .47363 Mdot
.46296 .30117 Mdot
.48048 .27194 Mdot
.48285 .36188 Mdot
.44673 .14937 Mdot
.79548 .38585 Mdot
.42914 .53293 Mdot
.51126 .78209 Mdot
.53341 .7454 Mdot
.41266 .53406 Mdot
.39272 .53534 Mdot
.54568 .39663 Mdot
.44651 .61898 Mdot
.75321 .59584 Mdot
.53489 .36954 Mdot
.33769 .37934 Mdot
.58671 .64297 Mdot
.3899 .361 Mdot
.4267 .36552 Mdot
.50015 .43155 Mdot
.5125 .3751 Mdot
.47433 .58954 Mdot
.4089 .56408 Mdot
.62174 .61343 Mdot
.45972 .66375 Mdot
.61888 .66018 Mdot
.34977 .36301 Mdot
.54395 .3645 Mdot
.65501 .21513 Mdot
.40602 .56263 Mdot
.62032 .64737 Mdot
.58273 .44942 Mdot
.36991 .579 Mdot
.69206 .45981 Mdot
.39141 .58261 Mdot
.58151 .63627 Mdot
.37858 .57601 Mdot
.62604 .63394 Mdot
.52512 .36444 Mdot
.39527 .54949 Mdot
.41581 .54573 Mdot
.77756 .68879 Mdot
.36322 .36142 Mdot
.58362 .58856 Mdot
.41872 .45258 Mdot
.3612 .58915 Mdot
.65667 .30275 Mdot
.39107 .60692 Mdot
.60479 .67882 Mdot
.44006 .5367 Mdot
.67484 .568 Mdot
.34018 .58681 Mdot
.44886 .58969 Mdot
.60881 .53571 Mdot
.51983 .74396 Mdot
.54888 .57428 Mdot
.69575 .48077 Mdot
.58583 .58687 Mdot
.66747 .72786 Mdot
.54114 .29837 Mdot
.56368 .33834 Mdot
.33186 .45986 Mdot
.35625 .5684 Mdot
.41397 .60234 Mdot
.70555 .64821 Mdot
.38334 .38498 Mdot
.64083 .62612 Mdot
.34374 .36029 Mdot
.71559 .73648 Mdot
.35888 .34879 Mdot
.58599 .35006 Mdot
.36613 .2725 Mdot
.62142 .20435 Mdot
.33673 .3614 Mdot
.58162 .63835 Mdot
.42017 .23912 Mdot
.37301 .56168 Mdot
.5709 .52907 Mdot
.3717 .37105 Mdot
.35468 .18515 Mdot
.37733 .56196 Mdot
.59052 .43229 Mdot
.67298 .43535 Mdot
.33719 .36181 Mdot
.62315 .43534 Mdot
.42427 .56034 Mdot
.65917 .36053 Mdot
.6191 .62534 Mdot
.61634 .4473 Mdot
.43371 .63852 Mdot
.34964 .36059 Mdot
.5419 .32496 Mdot
.6152 .46781 Mdot
.65983 .48326 Mdot
.2116 .58164 Mdot
.33909 .22372 Mdot
.54596 .3617 Mdot
.70079 .70063 Mdot
.69729 .47483 Mdot
.36211 .57055 Mdot
.7798 .42585 Mdot
.37344 .59919 Mdot
.68485 .26847 Mdot
.50962 .36141 Mdot
.60911 .34434 Mdot
.3669 .58425 Mdot
.45092 .57277 Mdot
.63903 .60121 Mdot
.53 .35408 Mdot
.61128 .6413 Mdot
.55324 .61864 Mdot
.52792 .36479 Mdot
.61398 .63126 Mdot
.33132 .38548 Mdot
.78884 .52151 Mdot
.6481 .47213 Mdot
.64397 .44974 Mdot
.51922 .33507 Mdot
.50263 .34971 Mdot
.51197 .34351 Mdot
.3903 .58273 Mdot
.62278 .64994 Mdot
.42766 .56777 Mdot
.46373 .59637 Mdot
.49633 .70456 Mdot
.56942 .61521 Mdot
.42267 .57474 Mdot
.4877 .47951 Mdot
.35015 .65182 Mdot
.5258 .3817 Mdot
.67709 .43881 Mdot
.72154 .35513 Mdot
.60182 .28101 Mdot
.40145 .60226 Mdot
.27504 .35861 Mdot
.58295 .64204 Mdot
.3476 .37727 Mdot
.3487 .34763 Mdot
.3514 .37008 Mdot
.71005 .42621 Mdot
.5701 .60315 Mdot
.55684 .66711 Mdot
.40822 .60384 Mdot
.59256 .67629 Mdot
.5995 .67052 Mdot
.41046 .24746 Mdot
.67958 .44148 Mdot
.38203 .57068 Mdot
.43967 .44677 Mdot
.39086 .76431 Mdot
.37449 .59255 Mdot
.39516 .63817 Mdot
.2497 .35708 Mdot
.43725 .5195 Mdot
.64713 .6398 Mdot
.81302 .64121 Mdot
.40762 .63653 Mdot
.70684 .27149 Mdot
.14681 .55246 Mdot
.39215 .60094 Mdot
.45392 .58396 Mdot
.41036 .55724 Mdot
.36882 .60754 Mdot
.62755 .66813 Mdot
.29905 .41452 Mdot
.69848 .47636 Mdot
.56338 .6536 Mdot
.69437 .46286 Mdot
.47731 .34317 Mdot
.60851 .34792 Mdot
.59142 .60673 Mdot
.38683 .37068 Mdot
.1939 .40416 Mdot
.77775 .6482 Mdot
.54076 .335 Mdot
.59993 .20622 Mdot
.36903 .37136 Mdot
.35629 .61078 Mdot
.35707 .3976 Mdot
.55801 .35834 Mdot
.64096 .4555 Mdot
.47609 .60893 Mdot
.57991 .61812 Mdot
.6158 .65515 Mdot
.37624 .5722 Mdot
.35232 .26138 Mdot
.69028 .44214 Mdot
.70257 .47896 Mdot
.39764 .61862 Mdot
.41749 .63705 Mdot
.61198 .63958 Mdot
.52976 .3388 Mdot
.60133 .78054 Mdot
.35673 .38769 Mdot
.41997 .53507 Mdot
.37431 .57944 Mdot
.61747 .79338 Mdot
.64665 .44198 Mdot
.53616 .31722 Mdot
.45976 .55321 Mdot
.701 .5324 Mdot
.46581 .57207 Mdot
.37964 .64836 Mdot
.51634 .38136 Mdot
.49785 .61257 Mdot
.37513 .5377 Mdot
.55496 .60431 Mdot
.63965 .42937 Mdot
.59035 .62832 Mdot
.55595 .60158 Mdot
.78704 .5533 Mdot
.68369 .46731 Mdot
.40602 .57764 Mdot
.68554 .44781 Mdot
.38735 .61279 Mdot
.39963 .63234 Mdot
.67348 .43895 Mdot
.61286 .64116 Mdot
.18465 .52371 Mdot
.55697 .26997 Mdot
.3795 .6213 Mdot
.3588 .5586 Mdot
.28618 .39061 Mdot
.40069 .41056 Mdot
.45139 .56623 Mdot
.59429 .6528 Mdot
.41971 .55806 Mdot
.67056 .42844 Mdot
.34237 .39467 Mdot
.58294 .62101 Mdot
.54187 .34525 Mdot
.54659 .33508 Mdot
.71213 .5834 Mdot
.49783 .37553 Mdot
.45508 .57142 Mdot
.50953 .62322 Mdot
.65248 .6296 Mdot
.21721 .36097 Mdot
.53276 .36384 Mdot
.36782 .39458 Mdot
.43595 .55309 Mdot
.33254 .49709 Mdot
.65977 .42011 Mdot
.61889 .14993 Mdot
.76782 .627 Mdot
.37484 .40058 Mdot
.56956 .67221 Mdot
.52228 .32095 Mdot
.36773 .55267 Mdot
.35893 .39231 Mdot
.55769 .3492 Mdot
.38597 .62049 Mdot
.34686 .62564 Mdot
.43161 .66636 Mdot
.49631 .41683 Mdot
.68273 .44744 Mdot
.49353 .37751 Mdot
.39004 .39266 Mdot
.47241 .35613 Mdot
.60628 .59559 Mdot
.44532 .60506 Mdot
.46528 .55817 Mdot
.53134 .33812 Mdot
.56168 .3304 Mdot
.42814 .57722 Mdot
.5768 .6282 Mdot
.53287 .27018 Mdot
.43664 .5997 Mdot
.72994 .42258 Mdot
.58404 .65474 Mdot
.55249 .35726 Mdot
.4512 .5853 Mdot
.35721 .33708 Mdot
.53937 .34902 Mdot
.52898 .38094 Mdot
.36399 .59654 Mdot
.33475 .36165 Mdot
.36917 .53507 Mdot
.63964 .46413 Mdot
.43866 .15628 Mdot
.67123 .42829 Mdot
.51969 .29438 Mdot
.40882 .51196 Mdot
.73597 .49126 Mdot
.57891 .6053 Mdot
.3898 .47162 Mdot
.73561 .37829 Mdot
.41556 .65164 Mdot
.25949 .62581 Mdot
.64441 .52027 Mdot
.24853 .33431 Mdot
.27707 .60359 Mdot
.3755 .36844 Mdot
.67263 .46475 Mdot
.45409 .58373 Mdot
.65396 .42142 Mdot
.3671 .39325 Mdot
.4549 .19136 Mdot
.44632 .56093 Mdot
.59886 .65039 Mdot
.42164 .57909 Mdot
.61229 .65251 Mdot
.37234 .61619 Mdot
.38528 .52714 Mdot
.74482 .38745 Mdot
.44686 .48005 Mdot
.46456 .56837 Mdot
.86032 .61001 Mdot
.38336 .66787 Mdot
.34539 .38257 Mdot
.43412 .5643 Mdot
.46946 .38022 Mdot
.70141 .45545 Mdot
.70961 .49626 Mdot
.50439 .33474 Mdot
.64792 .47623 Mdot
.61285 .635 Mdot
.51266 .36063 Mdot
.53657 .33252 Mdot
.49963 .6085 Mdot
.361 .40186 Mdot
.653 .45496 Mdot
.43434 .61396 Mdot
.44867 .5675 Mdot
.717 .6948 Mdot
.4498 .30358 Mdot
.4847 .66795 Mdot
.84709 .47659 Mdot
.56202 .60478 Mdot
.33806 .37122 Mdot
.49316 .34384 Mdot
.4625 .58448 Mdot
.41823 .58587 Mdot
.66851 .31651 Mdot
.61227 .66434 Mdot
.52224 .46765 Mdot
.47729 .67346 Mdot
.30758 .39138 Mdot
.36981 .44854 Mdot
.58797 .64549 Mdot
.35619 .44322 Mdot
.40263 .38784 Mdot
.20764 .64187 Mdot
.44823 .47721 Mdot
.67666 .43671 Mdot
.33198 .43071 Mdot
.64022 .62644 Mdot
.40709 .62499 Mdot
.50842 .37845 Mdot
.49944 .37477 Mdot
.59609 .6356 Mdot
.47328 .33673 Mdot
.37937 .36679 Mdot
.45665 .59752 Mdot
.73642 .66317 Mdot
.74745 .54882 Mdot
.51218 .32949 Mdot
.49746 .60325 Mdot
.65835 .46607 Mdot
.37451 .5731 Mdot
.36329 .35517 Mdot
.68931 .45562 Mdot
.39612 .79107 Mdot
.71716 .39124 Mdot
.44355 .56491 Mdot
.62294 .79367 Mdot
.6815 .46664 Mdot
.31904 .67044 Mdot
.43358 .60655 Mdot
.63449 .45198 Mdot
.42703 .5034 Mdot
.61079 .30926 Mdot
.53269 .50149 Mdot
.32025 .77907 Mdot
.5575 .49376 Mdot
.4869 .34457 Mdot
.61122 .32562 Mdot
.7398 .3535 Mdot
.68975 .47573 Mdot
.5447 .31476 Mdot
.53136 .51983 Mdot
.6257 .43415 Mdot
.35348 .59814 Mdot
.38806 .60348 Mdot
.52039 .20282 Mdot
.60886 .49334 Mdot
.55247 .25395 Mdot
.71587 .60839 Mdot
.36032 .58953 Mdot
.41006 .52779 Mdot
.41951 .58942 Mdot
.64039 .65563 Mdot
.67251 .44594 Mdot
.8349 .62901 Mdot
.69537 .45071 Mdot
.46828 .69907 Mdot
.52318 .34021 Mdot
.55598 .35254 Mdot
.40377 .60561 Mdot
.59169 .4361 Mdot
.31028 .69978 Mdot
.42557 .58183 Mdot
.36779 .4118 Mdot
.52841 .21676 Mdot
.38966 .63281 Mdot
.57758 .61152 Mdot
.45923 .63952 Mdot
.38779 .50783 Mdot
.65058 .47374 Mdot
.38287 .37564 Mdot
.36985 .4867 Mdot
.6437 .45763 Mdot
.41462 .60099 Mdot
.71824 .51496 Mdot
.38486 .59011 Mdot
.3794 .61983 Mdot
.44864 .68378 Mdot
.34284 .35054 Mdot
.51777 .35414 Mdot
.3539 .36826 Mdot
.60173 .60394 Mdot
.5264 .08997 Mdot
.36201 .3485 Mdot
.35164 .75496 Mdot
.47864 .18273 Mdot
.33607 .43151 Mdot
.64131 .62306 Mdot
.37182 .39841 Mdot
.68296 .43774 Mdot
.26065 .67913 Mdot
.35461 .66046 Mdot
.62842 .50588 Mdot
.43116 .60106 Mdot
.5667 .58612 Mdot
.62722 .6557 Mdot
.61783 .44885 Mdot
.60807 .59228 Mdot
.53633 .57385 Mdot
.38972 .62471 Mdot
.67993 .47559 Mdot
.71763 .5468 Mdot
.70245 .47433 Mdot
.43181 .41573 Mdot
.43765 .56983 Mdot
.58222 .62637 Mdot
.38518 .53383 Mdot
.65352 .65751 Mdot
.53033 .31713 Mdot
.473 .57949 Mdot
.38029 .36581 Mdot
.72842 .49405 Mdot
.54852 .35798 Mdot
.34414 .43152 Mdot
.61952 .6123 Mdot
.70557 .41758 Mdot
.6206 .6078 Mdot
.65549 .63154 Mdot
.63096 .45887 Mdot
.62635 .59853 Mdot
.45447 .58878 Mdot
.53004 .50655 Mdot
.62217 .61959 Mdot
.66496 .45403 Mdot
.37767 .38207 Mdot
.6218 .6364 Mdot
.58625 .35974 Mdot
.43818 .55372 Mdot
.49629 .34687 Mdot
.41742 .38582 Mdot
.58534 .57936 Mdot
.32592 .37426 Mdot
.5652 .34711 Mdot
.3944 .37308 Mdot
.2749 .30561 Mdot
.63958 .47713 Mdot
.42085 .6929 Mdot
.39008 .40937 Mdot
.64265 .64373 Mdot
.21692 .42302 Mdot
.4599 .60428 Mdot
.43489 .55111 Mdot
.3992 .3695 Mdot
.62714 .65579 Mdot
.1725 .61603 Mdot
.31883 .63503 Mdot
.44173 .40421 Mdot
.70566 .44104 Mdot
.76053 .71956 Mdot
.4347 .4089 Mdot
.14788 .51489 Mdot
.48302 .61709 Mdot
.56837 .35886 Mdot
.40434 .59631 Mdot
.70745 .32981 Mdot
.35717 .36118 Mdot
.46581 .31344 Mdot
.42381 .52343 Mdot
.51764 .35905 Mdot
.40961 .54698 Mdot
.59945 .5324 Mdot
.30394 .60503 Mdot
.38659 .38971 Mdot
.37611 .25596 Mdot
.59319 .58059 Mdot
.37029 .37847 Mdot
.55063 .36492 Mdot
.4509 .49283 Mdot
.38612 .62174 Mdot
.3524 .59563 Mdot
.3069 .38755 Mdot
.62891 .64856 Mdot
.49109 .35852 Mdot
.63845 .46055 Mdot
.38412 .37943 Mdot
.41058 .56478 Mdot
.46508 .59456 Mdot
.66288 .3002 Mdot
.66451 .47043 Mdot
.54487 .38445 Mdot
.65742 .42919 Mdot
.52206 .32333 Mdot
.41707 .62667 Mdot
.5508 .34167 Mdot
.34536 .59138 Mdot
.66463 .52057 Mdot
.43913 .69077 Mdot
.51617 .75431 Mdot
.5138 .36607 Mdot
.41068 .79592 Mdot
.66809 .47047 Mdot
.64875 .433 Mdot
.53644 .18947 Mdot
.37155 .66949 Mdot
.74382 .67223 Mdot
.24515 .57609 Mdot
.66768 .47577 Mdot
.65707 .45929 Mdot
.49724 .34767 Mdot
.62396 .59728 Mdot
.57131 .59628 Mdot
.52709 .32605 Mdot
.26381 .45853 Mdot
.64075 .62795 Mdot
.24418 .63659 Mdot
.70308 .71406 Mdot
.35946 .62854 Mdot
.57658 .31498 Mdot
.35391 .38196 Mdot
.27761 .45675 Mdot
.59102 .53111 Mdot
.44653 .55904 Mdot
.35119 .47215 Mdot
.52469 .33714 Mdot
.60819 .42147 Mdot
.31647 .76666 Mdot
.40233 .54805 Mdot
.4341 .60956 Mdot
.41419 .59389 Mdot
.35566 .40292 Mdot
.36966 .70273 Mdot
.45208 .59697 Mdot
.2614 .45821 Mdot
.36508 .58001 Mdot
.30398 .62935 Mdot
.35405 .37468 Mdot
.51704 .51922 Mdot
.44604 .32849 Mdot
.798 .65961 Mdot
.31046 .58411 Mdot
.64493 .47064 Mdot
.50035 .28147 Mdot
.6451 .43106 Mdot
.47093 .73786 Mdot
.42273 .46168 Mdot
.55889 .61056 Mdot
.44922 .56355 Mdot
.52336 .3694 Mdot
.6263 .65569 Mdot
.62752 .32233 Mdot
.57595 .10911 Mdot
.66663 .48285 Mdot
.22634 .7293 Mdot
.63544 .44491 Mdot
.53502 .33241 Mdot
.61088 .63889 Mdot
.47614 .80774 Mdot
.74242 .63646 Mdot
.62065 .63464 Mdot
.16501 .56178 Mdot
.64376 .67579 Mdot
.40832 .48512 Mdot
.63858 .60386 Mdot
.66403 .45785 Mdot
.63551 .41305 Mdot
.53761 .55882 Mdot
.42039 .61963 Mdot
.50553 .43748 Mdot
.30562 .68848 Mdot
.46078 .60257 Mdot
.53759 .36843 Mdot
.41399 .68137 Mdot
.34624 .46197 Mdot
.63479 .60772 Mdot
.7278 .42515 Mdot
.44197 .60453 Mdot
.37074 .58708 Mdot
.39358 .62316 Mdot
.78612 .59956 Mdot
.20459 .63961 Mdot
.41438 .62556 Mdot
.36522 .60665 Mdot
.51507 .3604 Mdot
.35651 .4187 Mdot
.47116 .23502 Mdot
.62019 .70311 Mdot
.39686 .5439 Mdot
.36482 .37953 Mdot
.40426 .37347 Mdot
.46365 .6053 Mdot
.52388 .50771 Mdot
.72771 .50558 Mdot
.43748 .61294 Mdot
.41131 .67927 Mdot
.56617 .40172 Mdot
.55541 .381 Mdot
.5383 .34464 Mdot
.59201 .58565 Mdot
.52792 .33189 Mdot
.53702 .32443 Mdot
.40697 .78303 Mdot
.54369 .48168 Mdot
.66537 .50867 Mdot
.34683 .36483 Mdot
.41025 .58541 Mdot
.51637 .60855 Mdot
.70564 .52321 Mdot
.62895 .43656 Mdot
.58941 .61467 Mdot
.70047 .44302 Mdot
.39196 .33874 Mdot
.7716 .59957 Mdot
.48049 .34529 Mdot
.65565 .47268 Mdot
.65991 .48847 Mdot
.36318 .38044 Mdot
.63859 .42406 Mdot
.64511 .39361 Mdot
.43806 .62864 Mdot
.48918 .7869 Mdot
.43209 .58261 Mdot
.18043 .42473 Mdot
.65238 .46164 Mdot
.68531 .42099 Mdot
.41711 .60947 Mdot
.54032 .35161 Mdot
.44868 .50948 Mdot
.41471 .6194 Mdot
.52724 .33279 Mdot
.43071 .53201 Mdot
.36732 .34407 Mdot
.58189 .64898 Mdot
.73761 .64065 Mdot
.44867 .1465 Mdot
.36309 .40116 Mdot
.63265 .31719 Mdot
.43564 .54565 Mdot
.3224 .2466 Mdot
.62485 .63762 Mdot
.45344 .55108 Mdot
.36555 .4554 Mdot
.62925 .6216 Mdot
.59865 .62321 Mdot
.38828 .57946 Mdot
.66999 .43313 Mdot
.55071 .35681 Mdot
.35838 .38031 Mdot
.15665 .45652 Mdot
.43841 .59206 Mdot
.41926 .54997 Mdot
.36903 .37538 Mdot
.68543 .46897 Mdot
.46691 .57865 Mdot
.25984 .52002 Mdot
.19071 .64693 Mdot
.63297 .44761 Mdot
.38389 .55698 Mdot
.46275 .75248 Mdot
.31041 .60557 Mdot
.25847 .27924 Mdot
.56032 .52647 Mdot
.5117 .35146 Mdot
.35389 .53177 Mdot
.76439 .2831 Mdot
.38179 .37914 Mdot
.77036 .65382 Mdot
.37038 .58577 Mdot
.39999 .56244 Mdot
.61406 .6623 Mdot
.42919 .57039 Mdot
.58981 .60863 Mdot
.54548 .16109 Mdot
.64879 .77898 Mdot
.59216 .59043 Mdot
.64476 .63332 Mdot
.34946 .50098 Mdot
.72273 .46977 Mdot
.59898 .63551 Mdot
.40258 .63417 Mdot
.48978 .49179 Mdot
.68975 .65523 Mdot
.36949 .39663 Mdot
.26701 .35352 Mdot
.33114 .61006 Mdot
.29386 .35007 Mdot
.19258 .52144 Mdot
.41776 .66389 Mdot
.42872 .42904 Mdot
.64585 .43821 Mdot
.40098 .5476 Mdot
.50198 .37726 Mdot
.50519 .38088 Mdot
.3442 .59536 Mdot
.39651 .58635 Mdot
.60863 .60698 Mdot
.37422 .38794 Mdot
.6988 .46947 Mdot
.40052 .56428 Mdot
.40102 .47334 Mdot
.38987 .37277 Mdot
.61183 .59164 Mdot
.46354 .71001 Mdot
.33828 .34732 Mdot
.35245 .54649 Mdot
.42271 .61726 Mdot
.41512 .57833 Mdot
.53784 .55606 Mdot
.66809 .44251 Mdot
.20287 .5142 Mdot
.36968 .62127 Mdot
.72897 .72916 Mdot
.69279 .49848 Mdot
.38899 .51913 Mdot
.61228 .59903 Mdot
.72593 .42454 Mdot
.48618 .32543 Mdot
.80107 .50755 Mdot
.44395 .57054 Mdot
.36592 .25779 Mdot
.51486 .2037 Mdot
.54914 .32088 Mdot
.64231 .66802 Mdot
.34759 .36962 Mdot
.42221 .582 Mdot
.40787 .70346 Mdot
.39147 .60408 Mdot
.41197 .37105 Mdot
.53749 .37907 Mdot
.64849 .4369 Mdot
.22885 .35449 Mdot
.49656 .37759 Mdot
.59625 .6245 Mdot
.53881 .85128 Mdot
.58768 .60851 Mdot
.57299 .59503 Mdot
.47994 .71142 Mdot
.66708 .44123 Mdot
.69059 .19814 Mdot
.57379 .17695 Mdot
.4278 .62718 Mdot
.67869 .47139 Mdot
.58928 .63597 Mdot
.37489 .56774 Mdot
.65671 .66865 Mdot
.56421 .61234 Mdot
.40516 .63001 Mdot
.40247 .55802 Mdot
.47467 .22118 Mdot
.28196 .69163 Mdot
.34773 .36806 Mdot
.58735 .60054 Mdot
.75435 .60635 Mdot
.3714 .5689 Mdot
.40894 .60469 Mdot
.68241 .2791 Mdot
.35286 .39959 Mdot
.76305 .5511 Mdot
.37058 .58649 Mdot
.56453 .82218 Mdot
.46958 .63731 Mdot
.60314 .66362 Mdot
.63924 .43377 Mdot
.77983 .67861 Mdot
.62637 .39472 Mdot
.5919 .60914 Mdot
.3855 .36271 Mdot
.6421 .60451 Mdot
.38007 .77612 Mdot
.69429 .46175 Mdot
.5816 .63663 Mdot
.43104 .44208 Mdot
.67917 .45269 Mdot
.64847 .46197 Mdot
.50692 .70291 Mdot
.50208 .31608 Mdot
.37211 .40278 Mdot
.65415 .4571 Mdot
.77149 .39645 Mdot
.67143 .45731 Mdot
.55359 .1726 Mdot
.39747 .55097 Mdot
.30761 .47392 Mdot
.51747 .29233 Mdot
.323 .6045 Mdot
.65539 .46761 Mdot
.33062 .37421 Mdot
.3839 .61887 Mdot
.61713 .58846 Mdot
.37529 .39053 Mdot
.60559 .4688 Mdot
.50493 .33715 Mdot
.62446 .60885 Mdot
.60024 .44956 Mdot
.61135 .65391 Mdot
.77426 .47467 Mdot
.44616 .17011 Mdot
.304 .55332 Mdot
.748 .63044 Mdot
.38537 .62231 Mdot
.21659 .59192 Mdot
.3787 .55676 Mdot
.38715 .58639 Mdot
.54707 .36374 Mdot
.32519 .47015 Mdot
.61151 .64104 Mdot
.16787 .51196 Mdot
.65131 .4731 Mdot
.79525 .66563 Mdot
.31932 .56651 Mdot
.4311 .53853 Mdot
.61918 .61838 Mdot
.59391 .65626 Mdot
.51229 .73231 Mdot
.48687 .38091 Mdot
.42825 .53958 Mdot
.46306 .62556 Mdot
.34498 .61284 Mdot
.64209 .46185 Mdot
.47422 .47777 Mdot
.48729 .34059 Mdot
.39416 .1941 Mdot
.5424 .37761 Mdot
.32377 .32363 Mdot
.62024 .59277 Mdot
.36325 .34864 Mdot
.40995 .60707 Mdot
.46447 .65755 Mdot
.6174 .66483 Mdot
.39839 .37051 Mdot
.33472 .36759 Mdot
.62498 .28283 Mdot
.67454 .43967 Mdot
.42028 .62166 Mdot
.45154 .588 Mdot
.42241 .56833 Mdot
.39301 .5832 Mdot
.66566 .48189 Mdot
.39161 .61987 Mdot
.63027 .42001 Mdot
.80736 .5074 Mdot
.28766 .50304 Mdot
.56298 .49561 Mdot
.6352 .23387 Mdot
.63805 .61349 Mdot
.76635 .42062 Mdot
.43702 .51657 Mdot
.81305 .45256 Mdot
.44533 .20031 Mdot
.43116 .63617 Mdot
.54955 .33631 Mdot
.3606 .50866 Mdot
.48411 .36121 Mdot
.13919 .54278 Mdot
.70664 .30978 Mdot
.27374 .67734 Mdot
.44797 .56537 Mdot
.52673 .50284 Mdot
.7562 .34488 Mdot
.36886 .56385 Mdot
.65516 .28521 Mdot
.68231 .26575 Mdot
.40773 .23821 Mdot
.33822 .35959 Mdot
.44605 .58434 Mdot
.53688 .5876 Mdot
.45514 .59323 Mdot
.40496 .59993 Mdot
.39229 .62158 Mdot
.7062 .45333 Mdot
.45832 .5637 Mdot
.37547 .60801 Mdot
.36626 .28975 Mdot
.40019 .45764 Mdot
.56384 .3702 Mdot
.51953 .18799 Mdot
.35784 .34839 Mdot
.61913 .61478 Mdot
.20261 .61595 Mdot
.67752 .43748 Mdot
.52135 .73587 Mdot
.40224 .58134 Mdot
.5047 .23907 Mdot
.7198 .38976 Mdot
.384 .36338 Mdot
.56066 .34868 Mdot
.27779 .70531 Mdot
.52852 .36852 Mdot
.71891 .41608 Mdot
.54178 .3548 Mdot
.37816 .51584 Mdot
.60522 .60511 Mdot
.4414 .61898 Mdot
.65236 .45246 Mdot
.54103 .34103 Mdot
.28159 .40463 Mdot
.41684 .5896 Mdot
.52758 .36419 Mdot
.43442 .62111 Mdot
.64072 .69243 Mdot
.65721 .71285 Mdot
.54475 .32861 Mdot
.63103 .47357 Mdot
.65667 .44446 Mdot
.35518 .35285 Mdot
.62625 .6148 Mdot
.59163 .61237 Mdot
.68786 .45736 Mdot
.6282 .57962 Mdot
.39414 .54413 Mdot
.38568 .56194 Mdot
.75134 .70498 Mdot
.45707 .58513 Mdot
.45948 .49977 Mdot
.44301 .45014 Mdot
.60169 .58682 Mdot
.40251 .52919 Mdot
.38328 .57801 Mdot
.44231 .5611 Mdot
.68099 .68723 Mdot
.52553 .33418 Mdot
.40023 .54918 Mdot
.3341 .37823 Mdot
.59925 .34779 Mdot
.37369 .57368 Mdot
.50999 .60482 Mdot
.58926 .613 Mdot
.84026 .50028 Mdot
.6379 .44114 Mdot
.54845 .36673 Mdot
.51248 .36574 Mdot
.20395 .49437 Mdot
.7581 .38504 Mdot
.44695 .45189 Mdot
.31233 .22674 Mdot
.74509 .39025 Mdot
.34241 .36216 Mdot
.57791 .348 Mdot
.59693 .45506 Mdot
.50483 .3636 Mdot
.68294 .48241 Mdot
.38852 .55599 Mdot
.39488 .54535 Mdot
.75534 .28774 Mdot
.46846 .58526 Mdot
.34882 .3736 Mdot
.70166 .47059 Mdot
.63855 .63424 Mdot
.38577 .36711 Mdot
.65443 .42874 Mdot
.59391 .58647 Mdot
.42901 .63701 Mdot
.38231 .63115 Mdot
.59343 .61481 Mdot
.60973 .66044 Mdot
.41912 .6154 Mdot
.68648 .37171 Mdot
.64286 .63914 Mdot
.58778 .64595 Mdot
.48621 .33654 Mdot
.49804 .37468 Mdot
.38146 .65429 Mdot
.66632 .46832 Mdot
.37815 .61206 Mdot
.51525 .36385 Mdot
.36269 .34901 Mdot
.6159 .64263 Mdot
.37447 .61584 Mdot
.38549 .57016 Mdot
.36465 .38169 Mdot
.3708 .3537 Mdot
.35957 .35495 Mdot
.60748 .43351 Mdot
.42843 .56305 Mdot
.608 .63571 Mdot
.66875 .43876 Mdot
.40106 .38305 Mdot
.35631 .39622 Mdot
.5759 .36652 Mdot
.45981 .58023 Mdot
.48713 .30902 Mdot
.77824 .29917 Mdot
.67401 .75739 Mdot
.54133 .32251 Mdot
.48442 .3285 Mdot
.25924 .39914 Mdot
.65285 .55844 Mdot
.69341 .45502 Mdot
.38757 .41611 Mdot
.30529 .5552 Mdot
.46199 .6189 Mdot
.38312 .62832 Mdot
.40831 .52575 Mdot
.35261 .35527 Mdot
.32215 .48604 Mdot
.59357 .6064 Mdot
.51041 .52419 Mdot
.3908 .37261 Mdot
.5646 .35511 Mdot
.57815 .33442 Mdot
.54685 .3743 Mdot
.36049 .61621 Mdot
.52591 .76239 Mdot
.75902 .42692 Mdot
.24139 .55527 Mdot
.66072 .46965 Mdot
.49617 .62601 Mdot
.33958 .23911 Mdot
.59819 .61886 Mdot
.47514 .35504 Mdot
.33781 .36705 Mdot
.61029 .65921 Mdot
.69643 .43832 Mdot
.65663 .45725 Mdot
.5104 .32943 Mdot
.51065 .33127 Mdot
.5049 .37107 Mdot
.56427 .62196 Mdot
.6225 .59494 Mdot
.4429 .56862 Mdot
.62393 .64392 Mdot
.81879 .52594 Mdot
.38942 .34693 Mdot
.47385 .39201 Mdot
.67007 .46603 Mdot
.63085 .59944 Mdot
.42037 .58834 Mdot
.58342 .66781 Mdot
.682 .55439 Mdot
.34815 .38536 Mdot
.68698 .70681 Mdot
.14366 .48838 Mdot
.43911 .61878 Mdot
.65865 .44123 Mdot
.76346 .64296 Mdot
.41746 .59402 Mdot
.49236 .35097 Mdot
.28619 .32499 Mdot
.48758 .41003 Mdot
.40897 .61817 Mdot
.44458 .62487 Mdot
.64271 .46969 Mdot
.38952 .19632 Mdot
.44228 .58079 Mdot
.7764 .53432 Mdot
.7131 .47536 Mdot
.48836 .34873 Mdot
.29769 .78996 Mdot
.31584 .35833 Mdot
.27274 .45929 Mdot
.49418 .33211 Mdot
.37867 .59603 Mdot
.48106 .36193 Mdot
.33749 .38258 Mdot
.55909 .35137 Mdot
.58219 .61029 Mdot
.55987 .36224 Mdot
.41888 .55062 Mdot
.59487 .63367 Mdot
.68183 .46702 Mdot
.78991 .66153 Mdot
.35121 .31084 Mdot
.53871 .35058 Mdot
.5414 .32961 Mdot
.42158 .53327 Mdot
.75313 .58748 Mdot
.3545 .56809 Mdot
.38212 .55956 Mdot
.6796 .47395 Mdot
.62784 .61969 Mdot
.63159 .45203 Mdot
.33963 .57373 Mdot
.28278 .52522 Mdot
.6586 .43049 Mdot
.47824 .23407 Mdot
.36883 .36926 Mdot
.56829 .43405 Mdot
.41741 .58479 Mdot
.62458 .43288 Mdot
.43089 .56225 Mdot
.59538 .60513 Mdot
.57426 .48909 Mdot
.63576 .36732 Mdot
.64462 .45274 Mdot
.30562 .29928 Mdot
.27097 .49904 Mdot
.50883 .61239 Mdot
.64569 .43303 Mdot
.34746 .45343 Mdot
.53342 .33207 Mdot
.36228 .38989 Mdot
.37998 .34732 Mdot
.39222 .36915 Mdot
.4007 .64994 Mdot
.31824 .56746 Mdot
.3271 .38378 Mdot
.70009 .45808 Mdot
.38502 .39077 Mdot
.67991 .24333 Mdot
.16677 .51708 Mdot
.36196 .36408 Mdot
.43283 .60449 Mdot
.43852 .51295 Mdot
.33254 .42818 Mdot
.60458 .29838 Mdot
.26578 .65408 Mdot
.60593 .24278 Mdot
.40681 .61568 Mdot
.5854 .65724 Mdot
.57044 .60601 Mdot
.80865 .58052 Mdot
.34227 .74143 Mdot
.64109 .77713 Mdot
.58434 .58583 Mdot
.69845 .35009 Mdot
.61925 .59778 Mdot
.42226 .62414 Mdot
.38154 .5637 Mdot
.56441 .59756 Mdot
.29804 .51522 Mdot
.67031 .33777 Mdot
.1915 .39902 Mdot
.60933 .65592 Mdot
.63933 .42986 Mdot
.62498 .44924 Mdot
.65067 .465 Mdot
.7361 .69604 Mdot
.61811 .62192 Mdot
.40658 .56923 Mdot
.51774 .36859 Mdot
.40178 .54244 Mdot
.68089 .45077 Mdot
.15514 .55201 Mdot
.62493 .63192 Mdot
.44697 .60167 Mdot
.51334 .57046 Mdot
.50805 .3335 Mdot
.36363 .37537 Mdot
.63098 .69001 Mdot
.62519 .78581 Mdot
.65291 .47289 Mdot
.57881 .58111 Mdot
.60242 .48626 Mdot
.20206 .39343 Mdot
.49605 .59986 Mdot
.48067 .58858 Mdot
.15377 .46284 Mdot
.51953 .83696 Mdot
.44404 .55291 Mdot
.55735 .34045 Mdot
.67278 .31501 Mdot
.37291 .57737 Mdot
.5765 .6021 Mdot
.34816 .34376 Mdot
.39165 .38003 Mdot
.4131 .65834 Mdot
.65258 .68483 Mdot
.58352 .52163 Mdot
.40176 .57874 Mdot
.36262 .53646 Mdot
.48799 .34231 Mdot
.70957 .3232 Mdot
.71523 .73697 Mdot
.374 .3524 Mdot
.45561 .61196 Mdot
.18081 .51098 Mdot
.62356 .65957 Mdot
.54925 .32229 Mdot
.66324 .42517 Mdot
.59476 .66802 Mdot
.56064 .34539 Mdot
.3861 .62827 Mdot
.46845 .59169 Mdot
.62925 .43951 Mdot
.59695 .66017 Mdot
.36115 .3563 Mdot
.5494 .36306 Mdot
.37593 .35874 Mdot
.628 .62369 Mdot
.63604 .63282 Mdot
.52013 .58351 Mdot
.49391 .59304 Mdot
.54226 .34655 Mdot
.35112 .61944 Mdot
.64272 .38842 Mdot
.20938 .32731 Mdot
.60172 .48152 Mdot
.46171 .57205 Mdot
.63277 .59438 Mdot
.64241 .45788 Mdot
.40233 .56069 Mdot
.14869 .53027 Mdot
.36496 .57582 Mdot
.70825 .45943 Mdot
.37253 .77896 Mdot
.37513 .36217 Mdot
.55314 .5523 Mdot
.43606 .20895 Mdot
.45948 .58941 Mdot
.50276 .35463 Mdot
.47767 .6241 Mdot
.67307 .4326 Mdot
.63003 .60109 Mdot
.18877 .343 Mdot
.66863 .4536 Mdot
.45377 .60418 Mdot
.38579 .37543 Mdot
.64778 .63089 Mdot
.56352 .53256 Mdot
.50914 .49405 Mdot
.47492 .54126 Mdot
.40791 .53159 Mdot
.38021 .58311 Mdot
.2562 .53421 Mdot
.53585 .37327 Mdot
.58696 .6421 Mdot
.65212 .44063 Mdot
.69033 .45643 Mdot
.51832 .33197 Mdot
.46984 .32146 Mdot
.56707 .43422 Mdot
.83011 .38245 Mdot
.47864 .36184 Mdot
.36894 .34826 Mdot
.76095 .5643 Mdot
.53126 .37244 Mdot
.53049 .36196 Mdot
.48229 .34221 Mdot
.4369 .43795 Mdot
.64104 .62668 Mdot
.38443 .62744 Mdot
.57294 .61356 Mdot
.37669 .59712 Mdot
.71458 .45905 Mdot
.64797 .4531 Mdot
.63079 .62939 Mdot
.21228 .35503 Mdot
.46359 .78072 Mdot
.42133 .60188 Mdot
.32493 .2458 Mdot
.44659 .5325 Mdot
.2954 .37294 Mdot
.44017 .53181 Mdot
.53144 .34773 Mdot
.35306 .60533 Mdot
.38112 .64641 Mdot
.79384 .61487 Mdot
.66983 .46791 Mdot
.57081 .36717 Mdot
.38428 .52319 Mdot
.35663 .54288 Mdot
.56521 .62721 Mdot
.60647 .65924 Mdot
.38557 .35128 Mdot
.48627 .52085 Mdot
.68614 .46545 Mdot
.64407 .20387 Mdot
.42133 .61936 Mdot
.31309 .34098 Mdot
.61574 .75524 Mdot
.40558 .55965 Mdot
.40026 .21835 Mdot
.52651 .75636 Mdot
.4207 .5828 Mdot
.47267 .4284 Mdot
.66595 .47013 Mdot
.28389 .57583 Mdot
.36452 .58386 Mdot
.49836 .33593 Mdot
.61629 .59201 Mdot
.62261 .66328 Mdot
.37346 .34629 Mdot
.79648 .38918 Mdot
.63131 .45548 Mdot
.63591 .61495 Mdot
.40848 .5897 Mdot
.65849 .43974 Mdot
.47959 .34325 Mdot
.44501 .5467 Mdot
.44835 .82157 Mdot
.6221 .64611 Mdot
.42876 .53065 Mdot
.76784 .50968 Mdot
.2546 .43145 Mdot
.3829 .79471 Mdot
.64531 .442 Mdot
.35229 .35346 Mdot
.4284 .65199 Mdot
.64215 .58508 Mdot
.3688 .54428 Mdot
.28692 .47298 Mdot
.66679 .23869 Mdot
.33666 .39133 Mdot
.42192 .60984 Mdot
.40804 .56603 Mdot
.62352 .53387 Mdot
.38058 .3564 Mdot
.44962 .57145 Mdot
.66934 .59097 Mdot
.60974 .65101 Mdot
.50018 .32414 Mdot
.63338 .64319 Mdot
.43051 .60171 Mdot
.49464 .58583 Mdot
.61121 .66216 Mdot
.25028 .30265 Mdot
.33693 .34593 Mdot
.64929 .43425 Mdot
.46032 .61219 Mdot
.35861 .60565 Mdot
.86896 .57186 Mdot
.54925 .31834 Mdot
.66569 .36951 Mdot
.4818 .24386 Mdot
.19666 .49224 Mdot
.32084 .40216 Mdot
.34563 .78653 Mdot
.51111 .838 Mdot
.45753 .56094 Mdot
.5895 .56365 Mdot
.7592 .47603 Mdot
.67329 .47319 Mdot
.76959 .34468 Mdot
.42158 .61979 Mdot
.4037 .59819 Mdot
.52526 .31836 Mdot
.62167 .36585 Mdot
.64932 .77299 Mdot
.54485 .62122 Mdot
.36825 .35947 Mdot
.59891 .60118 Mdot
.39552 .63301 Mdot
.50588 .45885 Mdot
.56418 .33849 Mdot
.35991 .32773 Mdot
.44496 .60511 Mdot
.6843 .6879 Mdot
.69143 .56218 Mdot
.67475 .44268 Mdot
.51012 .36412 Mdot
.59211 .79462 Mdot
.46206 .58191 Mdot
.624 .432 Mdot
.43534 .59116 Mdot
.33297 .41589 Mdot
.33362 .57338 Mdot
.34444 .36258 Mdot
.36779 .59664 Mdot
.50783 .27633 Mdot
.79891 .69787 Mdot
.38527 .40334 Mdot
.57036 .64303 Mdot
.52668 .31221 Mdot
.52794 .3354 Mdot
.60031 .65728 Mdot
.53375 .34163 Mdot
.52578 .72373 Mdot
.43171 .80203 Mdot
.37062 .36769 Mdot
.36523 .64663 Mdot
.35998 .36802 Mdot
.53658 .31853 Mdot
.40958 .61753 Mdot
.15658 .41096 Mdot
.54886 .34666 Mdot
.55533 .83556 Mdot
.67489 .45907 Mdot
.55607 .32091 Mdot
.36583 .57942 Mdot
.6739 .56972 Mdot
.49586 .37659 Mdot
.6656 .35462 Mdot
.4426 .56208 Mdot
.63707 .63498 Mdot
.38073 .57361 Mdot
.42317 .62819 Mdot
.5673 .36234 Mdot
.38152 .61024 Mdot
.65436 .42837 Mdot
.58084 .58841 Mdot
.25341 .65398 Mdot
.71749 .29797 Mdot
.45099 .57273 Mdot
.41134 .59057 Mdot
.65385 .63586 Mdot
.35414 .59101 Mdot
.66327 .48096 Mdot
.31854 .17 Mdot
.3686 .36988 Mdot
.56571 .32993 Mdot
.49561 .2626 Mdot
.45499 .62714 Mdot
.3869 .6192 Mdot
.1467 .60921 Mdot
.28091 .51769 Mdot
.64805 .43097 Mdot
.34696 .6181 Mdot
.48609 .37152 Mdot
.37351 .38679 Mdot
.69675 .4687 Mdot
.41881 .57784 Mdot
.41311 .60798 Mdot
.36117 .35181 Mdot
.30012 .35337 Mdot
.6958 .72159 Mdot
.61958 .44209 Mdot
.40571 .51228 Mdot
.57598 .37795 Mdot
.39115 .54382 Mdot
.7289 .69142 Mdot
.58081 .62683 Mdot
.6569 .47495 Mdot
.19709 .51273 Mdot
.46146 .57577 Mdot
.63516 .43458 Mdot
.68382 .4672 Mdot
.37254 .53963 Mdot
.54414 .59672 Mdot
.57214 .59334 Mdot
.6144 .6532 Mdot
.61741 .15639 Mdot
.28859 .45183 Mdot
.50484 .37104 Mdot
.66977 .47145 Mdot
.53339 .32449 Mdot
.41248 .3689 Mdot
.51761 .48985 Mdot
.53921 .32671 Mdot
.63102 .64908 Mdot
.56143 .32483 Mdot
.42624 .55778 Mdot
.68609 .46454 Mdot
.5015 .36089 Mdot
.42311 .63098 Mdot
.69781 .66728 Mdot
.57816 .25688 Mdot
.34373 .39173 Mdot
.33301 .35147 Mdot
.37859 .5674 Mdot
.47386 .35937 Mdot
.41352 .61332 Mdot
.65342 .4218 Mdot
.73843 .63289 Mdot
.42138 .62753 Mdot
.5365 .34802 Mdot
.65262 .6368 Mdot
.6014 .79134 Mdot
.38492 .64261 Mdot
.43143 .60552 Mdot
.37808 .60298 Mdot
.43579 .59048 Mdot
.21854 .37299 Mdot
.63013 .46144 Mdot
.6491 .2449 Mdot
.20861 .48059 Mdot
.6177 .63106 Mdot
.57359 .62977 Mdot
.6987 .74091 Mdot
.74506 .49208 Mdot
.66568 .46851 Mdot
.38942 .5852 Mdot
.69729 .53844 Mdot
.19016 .64266 Mdot
.17433 .4141 Mdot
.34274 .70022 Mdot
.54635 .31719 Mdot
.58084 .58051 Mdot
.53792 .33638 Mdot
.38247 .59905 Mdot
.36989 .5333 Mdot
.4218 .83619 Mdot
.69992 .45018 Mdot
.36599 .36105 Mdot
.37505 .59819 Mdot
.28321 .45263 Mdot
.51312 .35963 Mdot
.55553 .32002 Mdot
.40079 .55395 Mdot
.63953 .65866 Mdot
.78487 .70411 Mdot
.66758 .44274 Mdot
.63483 .24598 Mdot
.74951 .33069 Mdot
.69679 .60146 Mdot
.67793 .44804 Mdot
.63687 .57458 Mdot
.54906 .32442 Mdot
.61284 .73587 Mdot
.61229 .62649 Mdot
.36751 .39135 Mdot
.40478 .51757 Mdot
.57964 .63514 Mdot
.53491 .38223 Mdot
.63871 .6187 Mdot
.38871 .62109 Mdot
.69025 .48799 Mdot
.5097 .34897 Mdot
.68847 .50127 Mdot
.63499 .59676 Mdot
.38376 .36034 Mdot
.66818 .40223 Mdot
.35952 .72872 Mdot
.52732 .7539 Mdot
.40058 .55156 Mdot
.49502 .45601 Mdot
.41068 .56927 Mdot
.64665 .66446 Mdot
.42531 .58993 Mdot
.49044 .64133 Mdot
.50301 .3533 Mdot
.3641 .60354 Mdot
.3959 .58053 Mdot
.55366 .18017 Mdot
.44852 .57733 Mdot
.3762 .55011 Mdot
.41584 .58179 Mdot
.4927 .63722 Mdot
.42557 .65595 Mdot
.61158 .60033 Mdot
.4321 .23841 Mdot
.53059 .35949 Mdot
.39606 .37064 Mdot
.33747 .35878 Mdot
.31637 .4681 Mdot
.47705 .28769 Mdot
.60812 .33668 Mdot
.61081 .64811 Mdot
.65313 .42544 Mdot
.42998 .58973 Mdot
.30908 .75176 Mdot
.53974 .39856 Mdot
.56252 .36059 Mdot
.72065 .30346 Mdot
.31675 .59452 Mdot
.28096 .64882 Mdot
.34288 .59697 Mdot
.72818 .25074 Mdot
.45831 .62974 Mdot
.33635 .55096 Mdot
.47665 .35731 Mdot
.31776 .32992 Mdot
.35734 .58131 Mdot
.57871 .59673 Mdot
.34279 .37752 Mdot
.32029 .56569 Mdot
.55718 .30093 Mdot
.59472 .37925 Mdot
.50438 .65286 Mdot
.43712 .56212 Mdot
.51056 .34856 Mdot
.62386 .61008 Mdot
.69684 .74904 Mdot
.66642 .43829 Mdot
.48636 .30662 Mdot
.79144 .52274 Mdot
.26897 .292 Mdot
.38985 .36916 Mdot
.58932 .70634 Mdot
.42079 .55251 Mdot
.33957 .29854 Mdot
.44585 .62046 Mdot
.15472 .59102 Mdot
.33602 .35702 Mdot
.63845 .64092 Mdot
.64008 .42829 Mdot
.57802 .60193 Mdot
.51359 .74583 Mdot
.5688 .30607 Mdot
.55097 .46776 Mdot
.52886 .36756 Mdot
.57555 .52403 Mdot
.58713 .63124 Mdot
.42086 .62281 Mdot
.82695 .37334 Mdot
.58322 .63966 Mdot
.64615 .61964 Mdot
.46904 .18292 Mdot
.18352 .36217 Mdot
.48396 .5931 Mdot
.64417 .63414 Mdot
.53689 .36517 Mdot
.3452 .37077 Mdot
.36658 .58748 Mdot
.43253 .55519 Mdot
.57862 .62402 Mdot
.5718 .35542 Mdot
.41574 .72868 Mdot
.519 .33556 Mdot
.63923 .63607 Mdot
.52211 .34855 Mdot
.70993 .44 Mdot
.55084 .36325 Mdot
.35883 .60687 Mdot
.4266 .58984 Mdot
.44395 .25982 Mdot
.63582 .63403 Mdot
.40421 .57774 Mdot
.42745 .53553 Mdot
.60605 .6367 Mdot
.63028 .56016 Mdot
.4307 .73462 Mdot
.42529 .53941 Mdot
.44549 .56479 Mdot
.33064 .36782 Mdot
.51964 .48273 Mdot
.64088 .71122 Mdot
.38149 .61767 Mdot
.3441 .39756 Mdot
.5905 .59452 Mdot
.43568 .61402 Mdot
.19136 .59597 Mdot
.67068 .31609 Mdot
.43754 .61882 Mdot
.5348 .33281 Mdot
.35818 .63211 Mdot
.40136 .80465 Mdot
.37783 .56154 Mdot
.59786 .63843 Mdot
.63295 .61259 Mdot
.62864 .20074 Mdot
.59405 .62441 Mdot
.49931 .37474 Mdot
.68037 .45212 Mdot
.20103 .3917 Mdot
.51673 .3268 Mdot
.43862 .63906 Mdot
.4837 .15771 Mdot
.447 .54034 Mdot
.40693 .63796 Mdot
.60691 .80888 Mdot
.54284 .34072 Mdot
.61224 .61226 Mdot
.64568 .40238 Mdot
.49098 .58869 Mdot
.652 .47073 Mdot
.35742 .53635 Mdot
.38482 .55677 Mdot
.44664 .83074 Mdot
.22165 .37294 Mdot
.61607 .43951 Mdot
.3784 .54906 Mdot
.38362 .61866 Mdot
.46796 .37687 Mdot
.41425 .58757 Mdot
.34559 .36681 Mdot
.62032 .62183 Mdot
.55763 .34803 Mdot
.37011 .38233 Mdot
.46235 .59329 Mdot
.36014 .35536 Mdot
.49603 .3476 Mdot
.67801 .42867 Mdot
.39073 .60638 Mdot
.37363 .39628 Mdot
.36662 .3576 Mdot
.41221 .57056 Mdot
.61932 .59153 Mdot
.31797 .61872 Mdot
.44931 .58283 Mdot
.37529 .61631 Mdot
.59398 .61205 Mdot
.29079 .79157 Mdot
.38212 .56263 Mdot
.28993 .48048 Mdot
.59043 .65312 Mdot
.59625 .53748 Mdot
.50687 .324 Mdot
.36597 .56767 Mdot
.6769 .42798 Mdot
.67461 .42852 Mdot
.55135 .37146 Mdot
.58618 .57917 Mdot
.506 .25241 Mdot
.55444 .60763 Mdot
.4475 .64228 Mdot
.36603 .55832 Mdot
.38296 .66934 Mdot
.28675 .71583 Mdot
.5807 .60586 Mdot
.52855 .28816 Mdot
.56707 .65588 Mdot
.6423 .42363 Mdot
.56442 .3691 Mdot
.57214 .59226 Mdot
.59771 .60863 Mdot
.5992 .58519 Mdot
.36784 .39182 Mdot
.44322 .26293 Mdot
.6052 .66376 Mdot
.63677 .66313 Mdot
.43329 .55194 Mdot
.37736 .61406 Mdot
.54637 .82451 Mdot
.53192 .81908 Mdot
.33154 .37444 Mdot
.50117 .37036 Mdot
.56306 .12138 Mdot
.69102 .43693 Mdot
.58608 .19974 Mdot
.39589 .63536 Mdot
.60145 .12741 Mdot
.36667 .5817 Mdot
.40683 .58835 Mdot
.5711 .59342 Mdot
.36116 .39586 Mdot
.3637 .36966 Mdot
.58536 .64054 Mdot
.63554 .66813 Mdot
.34708 .36505 Mdot
.40998 .20791 Mdot
.19785 .63447 Mdot
.64482 .38487 Mdot
.61623 .63814 Mdot
.38581 .76084 Mdot
.62362 .43977 Mdot
.39121 .50611 Mdot
.62306 .46615 Mdot
.52123 .36243 Mdot
.55646 .33083 Mdot
.64644 .4655 Mdot
.44435 .56921 Mdot
.50955 .37336 Mdot
.45947 .56011 Mdot
.57533 .24042 Mdot
.49944 .76994 Mdot
.5715 .29453 Mdot
.36232 .50988 Mdot
.63339 .56097 Mdot
.71011 .49063 Mdot
.45339 .60805 Mdot
.17731 .55793 Mdot
.36941 .36241 Mdot
.47681 .62568 Mdot
.66301 .47749 Mdot
.59268 .8237 Mdot
.39764 .61228 Mdot
.60309 .64073 Mdot
.68104 .46966 Mdot
.79846 .52604 Mdot
.77184 .5476 Mdot
.37686 .60019 Mdot
.8001 .33775 Mdot
.66194 .6362 Mdot
.5208 .37209 Mdot
.73816 .65428 Mdot
.5761 .63382 Mdot
.33884 .41616 Mdot
.20375 .5388 Mdot
.23173 .33103 Mdot
.61807 .61359 Mdot
.51802 .31555 Mdot
.60624 .5944 Mdot
.38716 .36762 Mdot
.56816 .63888 Mdot
.5075 .35482 Mdot
.44053 .60772 Mdot
.52713 .33949 Mdot
.36049 .39139 Mdot
.67174 .72553 Mdot
.61625 .43921 Mdot
.52951 .3882 Mdot
.65031 .44834 Mdot
.23533 .4365 Mdot
.25092 .52347 Mdot
.64699 .43664 Mdot
.41299 .69827 Mdot
.36453 .5604 Mdot
.5901 .65483 Mdot
.50652 .32733 Mdot
.36139 .31644 Mdot
.66811 .40777 Mdot
.60717 .6248 Mdot
.51973 .38201 Mdot
.76393 .58823 Mdot
.50201 .6275 Mdot
.36292 .55934 Mdot
.36593 .44301 Mdot
.61193 .63604 Mdot
.5232 .31697 Mdot
.77107 .68943 Mdot
.60542 .59564 Mdot
.48157 .36735 Mdot
.63348 .43288 Mdot
.69013 .45239 Mdot
.40636 .53975 Mdot
.71679 .4691 Mdot
.53509 .3773 Mdot
.62799 .49898 Mdot
.64457 .62562 Mdot
.79398 .55857 Mdot
.3984 .37874 Mdot
.53045 .35336 Mdot
.45564 .5454 Mdot
.65471 .65666 Mdot
.68787 .30115 Mdot
.43208 .74511 Mdot
.8486 .46668 Mdot
.51894 .33244 Mdot
.6141 .61988 Mdot
.60854 .64254 Mdot
.39486 .64585 Mdot
.74052 .63997 Mdot
.46027 .24241 Mdot
.45604 .65508 Mdot
.58992 .4693 Mdot
.48694 .33098 Mdot
.51233 .30431 Mdot
.37928 .52497 Mdot
.43981 .57206 Mdot
.63674 .42655 Mdot
.43982 .60602 Mdot
.61863 .58761 Mdot
.40239 .55173 Mdot
.65462 .44129 Mdot
.53373 .36903 Mdot
.39514 .60851 Mdot
.36914 .35738 Mdot
.63241 .46242 Mdot
.69161 .43393 Mdot
.53582 .35312 Mdot
.57834 .62377 Mdot
.58615 .53916 Mdot
.50651 .33089 Mdot
.43791 .56253 Mdot
.48009 .45991 Mdot
.39228 .62302 Mdot
.56359 .57056 Mdot
.60229 .59696 Mdot
.55724 .34717 Mdot
.55904 .6349 Mdot
.6603 .45197 Mdot
.20657 .49039 Mdot
.42723 .59865 Mdot
.47816 .3594 Mdot
.73599 .37376 Mdot
.56898 .55135 Mdot
.6394 .60099 Mdot
.51975 .23909 Mdot
.58414 .65029 Mdot
.49612 .36428 Mdot
.52671 .18432 Mdot
.38327 .3863 Mdot
.56477 .35186 Mdot
.2612 .66418 Mdot
.54645 .34982 Mdot
.40794 .54431 Mdot
.38385 .56507 Mdot
.55279 .36043 Mdot
.34825 .35394 Mdot
.66457 .77151 Mdot
.47482 .32495 Mdot
.61566 .6146 Mdot
.50521 .20775 Mdot
.84081 .55354 Mdot
.65228 .5231 Mdot
.64493 .42407 Mdot
.48351 .58264 Mdot
.36346 .56528 Mdot
.67224 .47918 Mdot
.61209 .4512 Mdot
.39115 .358 Mdot
.48047 .35666 Mdot
.65854 .63957 Mdot
.672 .42022 Mdot
.5578 .65524 Mdot
.47189 .2768 Mdot
.37644 .6384 Mdot
.74077 .31795 Mdot
.39274 .63368 Mdot
.23943 .50634 Mdot
.65035 .44113 Mdot
.45063 .61661 Mdot
.34431 .59572 Mdot
.68776 .46954 Mdot
.34414 .37226 Mdot
.4935 .30355 Mdot
.51851 .34829 Mdot
.28396 .77299 Mdot
.45281 .55527 Mdot
.40912 .55082 Mdot
.65577 .46667 Mdot
.37873 .29246 Mdot
.62164 .62966 Mdot
.56878 .62006 Mdot
.53599 .37312 Mdot
.56663 .4131 Mdot
.39103 .5479 Mdot
.44878 .6086 Mdot
.5112 .34302 Mdot
.52662 .38644 Mdot
.61259 .33102 Mdot
.40813 .56379 Mdot
.66677 .46459 Mdot
.28327 .34822 Mdot
.64384 .4438 Mdot
.40445 .62386 Mdot
.41123 .553 Mdot
.35953 .60905 Mdot
.46743 .57925 Mdot
.65963 .48807 Mdot
.40316 .6276 Mdot
.35014 .56804 Mdot
.61217 .6216 Mdot
.37318 .60219 Mdot
.59268 .44205 Mdot
.44008 .60021 Mdot
.34597 .3682 Mdot
.63649 .70555 Mdot
.39675 .61156 Mdot
.39575 .55358 Mdot
.55755 .31697 Mdot
.41698 .60476 Mdot
.66322 .42366 Mdot
.63032 .63698 Mdot
.66295 .46882 Mdot
.67065 .42731 Mdot
.49307 .3205 Mdot
.35184 .34775 Mdot
.46066 .62281 Mdot
.33734 .38057 Mdot
.46602 .62829 Mdot
.46114 .57471 Mdot
.44263 .34195 Mdot
.69507 .21769 Mdot
.72493 .70419 Mdot
.4293 .59843 Mdot
.54596 .34368 Mdot
.53821 .33564 Mdot
.58781 .56735 Mdot
.38771 .53906 Mdot
.69335 .47615 Mdot
.64376 .42301 Mdot
.35798 .75596 Mdot
.32441 .51349 Mdot
.34532 .36896 Mdot
.53061 .48224 Mdot
.44127 .54911 Mdot
.45255 .61519 Mdot
.44836 .54771 Mdot
.53949 .32591 Mdot
.3097 .65606 Mdot
.55987 .3713 Mdot
.68056 .52206 Mdot
.64504 .45827 Mdot
.38552 .60636 Mdot
.7209 .29237 Mdot
.61475 .65638 Mdot
.63064 .63733 Mdot
.69816 .43786 Mdot
.53717 .39617 Mdot
.60752 .78784 Mdot
.15964 .43702 Mdot
.66205 .6687 Mdot
.36586 .3946 Mdot
.45808 .59736 Mdot
.54625 .36143 Mdot
.6413 .62338 Mdot
.36209 .39404 Mdot
.4071 .62042 Mdot
.44428 .26361 Mdot
.43638 .59451 Mdot
.75696 .46097 Mdot
.61499 .59339 Mdot
.17515 .61918 Mdot
.59126 .57943 Mdot
.65654 .48258 Mdot
.66322 .47961 Mdot
.40462 .56078 Mdot
.67017 .61865 Mdot
.57654 .63734 Mdot
.4078 .41994 Mdot
.37188 .34916 Mdot
.66329 .5393 Mdot
.37694 .3871 Mdot
.51014 .36588 Mdot
.35629 .38708 Mdot
.5054 .35288 Mdot
.62141 .77857 Mdot
.47211 .67001 Mdot
.36894 .37782 Mdot
.74083 .3895 Mdot
.36225 .56748 Mdot
.33221 .3827 Mdot
.37296 .53231 Mdot
.44745 .65555 Mdot
.51198 .3406 Mdot
.38015 .35438 Mdot
.45022 .61535 Mdot
.331 .7626 Mdot
.64894 .43296 Mdot
.68986 .47901 Mdot
.37625 .53121 Mdot
.50279 .32227 Mdot
.57505 .59468 Mdot
.17685 .49606 Mdot
.65904 .41584 Mdot
.39069 .56125 Mdot
.3556 .58527 Mdot
.58993 .65589 Mdot
.6466 .22667 Mdot
.41357 .5571 Mdot
.54056 .57861 Mdot
.40381 .56355 Mdot
.63406 .45299 Mdot
.58373 .60027 Mdot
.61806 .64265 Mdot
.51708 .38073 Mdot
.62923 .65654 Mdot
.47292 .48466 Mdot
.75695 .40616 Mdot
.32861 .58418 Mdot
.66505 .45089 Mdot
.68763 .54943 Mdot
.70888 .49836 Mdot
.26425 .63818 Mdot
.62372 .58585 Mdot
.41578 .62849 Mdot
.63344 .65657 Mdot
.36383 .38695 Mdot
.63203 .64182 Mdot
.58055 .58065 Mdot
.41709 .61614 Mdot
.37879 .59563 Mdot
.52765 .37105 Mdot
.7446 .63287 Mdot
.57902 .63541 Mdot
.36784 .58088 Mdot
.35768 .61476 Mdot
.45789 .55316 Mdot
.41113 .43156 Mdot
.58323 .60258 Mdot
.37565 .19786 Mdot
.40339 .46658 Mdot
.57825 .63152 Mdot
.7404 .73964 Mdot
.71912 .34073 Mdot
.57844 .32478 Mdot
.43786 .36669 Mdot
.39961 .56518 Mdot
.502 .38132 Mdot
.38306 .59963 Mdot
.74396 .32449 Mdot
.40955 .60342 Mdot
.3441 .36747 Mdot
.45738 .56048 Mdot
.561 .33995 Mdot
.51785 .33379 Mdot
.39324 .55892 Mdot
.39399 .60575 Mdot
.67535 .73311 Mdot
.56392 .63247 Mdot
.63644 .62427 Mdot
.58501 .312 Mdot
.37701 .37623 Mdot
.65417 .47298 Mdot
.42097 .58449 Mdot
.50551 .31804 Mdot
.52044 .33497 Mdot
.57471 .61315 Mdot
.49221 .34393 Mdot
.66981 .44346 Mdot
.42451 .59587 Mdot
.6761 .48054 Mdot
.38425 .38766 Mdot
.58602 .60079 Mdot
.37434 .60105 Mdot
.43362 .552 Mdot
.63286 .61282 Mdot
.45263 .61793 Mdot
.35634 .35333 Mdot
.54233 .34839 Mdot
.61851 .61224 Mdot
.684 .45355 Mdot
.50799 .36259 Mdot
.38272 .62443 Mdot
.78067 .32144 Mdot
.41356 .5405 Mdot
.38833 .56987 Mdot
.28669 .72921 Mdot
.44815 .55608 Mdot
.51242 .32867 Mdot
.64167 .6292 Mdot
.50694 .59482 Mdot
.31885 .44947 Mdot
.27133 .78294 Mdot
.55712 .37164 Mdot
.45552 .59579 Mdot
.27912 .67759 Mdot
.45186 .59986 Mdot
.41956 .76181 Mdot
.55509 .38261 Mdot
.58356 .48622 Mdot
.46282 .55617 Mdot
.67888 .43797 Mdot
.54563 .36606 Mdot
.50232 .34882 Mdot
.54382 .21938 Mdot
.43092 .61672 Mdot
.45587 .4272 Mdot
.39766 .61992 Mdot
.68506 .45037 Mdot
.33429 .51511 Mdot
.5145 .33113 Mdot
.83003 .55221 Mdot
.41172 .56795 Mdot
.59219 .60665 Mdot
.55768 .32041 Mdot
.67643 .41696 Mdot
.37103 .61102 Mdot
.33874 .36332 Mdot
.6153 .43344 Mdot
.33468 .56806 Mdot
.66772 .44968 Mdot
.37689 .61732 Mdot
.47114 .53275 Mdot
.81876 .4832 Mdot
.60706 .5852 Mdot
.63684 .42906 Mdot
.46252 .45374 Mdot
.41429 .62724 Mdot
.61927 .61389 Mdot
.61065 .62533 Mdot
.37827 .39089 Mdot
.57334 .50428 Mdot
.77425 .50648 Mdot
.47191 .79163 Mdot
.52005 .21096 Mdot
.56682 .34147 Mdot
.65235 .36209 Mdot
.38767 .57574 Mdot
.42522 .45933 Mdot
.65547 .42243 Mdot
.41523 .5393 Mdot
.56925 .70204 Mdot
.60391 .65664 Mdot
.42104 .54288 Mdot
.35907 .36662 Mdot
.31411 .35524 Mdot
.27707 .35593 Mdot
.2232 .57778 Mdot
.52675 .36662 Mdot
.34299 .61577 Mdot
.51289 .57931 Mdot
.50041 .32497 Mdot
.37471 .62989 Mdot
.50018 .32729 Mdot
.3578 .2294 Mdot
.33993 .38929 Mdot
.59366 .60288 Mdot
.6654 .51379 Mdot
.41337 .63913 Mdot
.38057 .55447 Mdot
.35389 .34602 Mdot
.43714 .57038 Mdot
.80013 .42964 Mdot
.40477 .433 Mdot
.50608 .36683 Mdot
.60059 .58492 Mdot
.36215 .61854 Mdot
.52143 .49469 Mdot
.44875 .5964 Mdot
.5424 .78823 Mdot
.39374 .55452 Mdot
.77659 .54699 Mdot
.61467 .59052 Mdot
.65848 .4466 Mdot
.46653 .6047 Mdot
.40747 .59709 Mdot
.31987 .4944 Mdot
.46495 .62719 Mdot
.43841 .62209 Mdot
.51619 .6244 Mdot
.59312 .58206 Mdot
.61002 .59658 Mdot
.54969 .37447 Mdot
.30625 .70015 Mdot
.6651 .45957 Mdot
.49859 .57541 Mdot
.70428 .44279 Mdot
.38386 .71453 Mdot
.35237 .39167 Mdot
.25588 .56612 Mdot
.40505 .58089 Mdot
.61377 .65004 Mdot
.19025 .45196 Mdot
.56454 .62153 Mdot
.52326 .46978 Mdot
.68619 .46529 Mdot
.58324 .63768 Mdot
.40565 .59155 Mdot
.67344 .67697 Mdot
.30247 .73302 Mdot
.65584 .45709 Mdot
.42703 .64205 Mdot
.56216 .3365 Mdot
.50484 .26114 Mdot
.82791 .50035 Mdot
.64473 .43406 Mdot
.5979 .46326 Mdot
.43932 .61503 Mdot
.62591 .65526 Mdot
.68104 .44179 Mdot
.63502 .45115 Mdot
.49258 .34822 Mdot
.37732 .59345 Mdot
.37714 .58978 Mdot
.50302 .37393 Mdot
.6602 .46781 Mdot
.36688 .54855 Mdot
.33741 .57309 Mdot
.51299 .86102 Mdot
.77696 .56779 Mdot
.3032 .80229 Mdot
.59788 .55855 Mdot
.53889 .68561 Mdot
.17178 .50669 Mdot
.579 .61574 Mdot
.46077 .60342 Mdot
.38339 .51906 Mdot
.53609 .37722 Mdot
.42633 .6074 Mdot
.56409 .38165 Mdot
.69633 .44891 Mdot
.58727 .82449 Mdot
.7194 .57481 Mdot
.29772 .27435 Mdot
.42497 .60873 Mdot
.52906 .60617 Mdot
.35815 .38282 Mdot
.65435 .54611 Mdot
.59104 .59835 Mdot
.44083 .5353 Mdot
.67427 .73136 Mdot
.56314 .35949 Mdot
.59445 .6171 Mdot
.69049 .75297 Mdot
.64183 .56674 Mdot
.39258 .62247 Mdot
.55063 .37859 Mdot
.17169 .5479 Mdot
.54833 .65416 Mdot
.70367 .47002 Mdot
.34357 .37327 Mdot
.55542 .3531 Mdot
.63304 .42717 Mdot
.54602 .59045 Mdot
.587 .62197 Mdot
.57765 .59621 Mdot
.70118 .70859 Mdot
.57358 .34139 Mdot
.36039 .38256 Mdot
.29024 .56504 Mdot
.32916 .50061 Mdot
.34835 .36309 Mdot
.55601 .32987 Mdot
.61452 .58604 Mdot
.59271 .64806 Mdot
.62947 .63738 Mdot
.76359 .66193 Mdot
.64484 .64662 Mdot
.55165 .20682 Mdot
.46335 .56528 Mdot
.35451 .64342 Mdot
.45504 .59917 Mdot
.69242 .47476 Mdot
.62975 .60996 Mdot
.64114 .39986 Mdot
.44505 .64009 Mdot
.26202 .54245 Mdot
.40658 .54213 Mdot
.63045 .46591 Mdot
.42175 .54703 Mdot
.72665 .27987 Mdot
.62191 .6606 Mdot
.4278 .60201 Mdot
.62282 .46243 Mdot
.38089 .37215 Mdot
.6316 .59137 Mdot
.37774 .60255 Mdot
.47689 .2248 Mdot
.45516 .56497 Mdot
.32352 .25762 Mdot
.79347 .484 Mdot
.36162 .39422 Mdot
.77539 .38756 Mdot
.50426 .31533 Mdot
.44567 .65218 Mdot
.48712 .57253 Mdot
.65359 .45179 Mdot
.66089 .53955 Mdot
.53228 .36117 Mdot
.33029 .68829 Mdot
.35226 .56116 Mdot
.38484 .38854 Mdot
.45892 .66967 Mdot
.67624 .47707 Mdot
.36898 .62682 Mdot
.34617 .60716 Mdot
.62606 .23383 Mdot
.35311 .55048 Mdot
.36411 .56994 Mdot
.3275 .3592 Mdot
.57158 .20365 Mdot
.44272 .5941 Mdot
.52916 .47648 Mdot
.5663 .63469 Mdot
.45894 .63622 Mdot
.5549 .20253 Mdot
.37992 .56685 Mdot
.58414 .61861 Mdot
.54415 .58038 Mdot
.75678 .50035 Mdot
.34811 .34881 Mdot
.39357 .55417 Mdot
.61775 .19691 Mdot
.4246 .56443 Mdot
.67032 .46281 Mdot
.38816 .54044 Mdot
.51019 .3567 Mdot
.7454 .69413 Mdot
.51867 .37947 Mdot
.40175 .5372 Mdot
.6248 .6381 Mdot
.65019 .46213 Mdot
.74832 .66073 Mdot
.41698 .26522 Mdot
.61191 .21331 Mdot
.17556 .41735 Mdot
.36985 .3498 Mdot
.40239 .38034 Mdot
.69835 .45617 Mdot
.42997 .60162 Mdot
.47484 .17519 Mdot
.47946 .61378 Mdot
.44177 .55787 Mdot
.40814 .60313 Mdot
.25006 .51794 Mdot
.68084 .43195 Mdot
.51346 .33657 Mdot
.41334 .55504 Mdot
.41282 .62643 Mdot
.58507 .61055 Mdot
.37642 .36943 Mdot
.51175 .32445 Mdot
.36942 .36743 Mdot
.54822 .3624 Mdot
.64721 .79147 Mdot
.35178 .56831 Mdot
.38344 .37087 Mdot
.64824 .41825 Mdot
.58524 .61419 Mdot
.74477 .46126 Mdot
.50299 .35583 Mdot
.53953 .37922 Mdot
.39123 .55752 Mdot
.57998 .62674 Mdot
.55283 .61324 Mdot
.38168 .38356 Mdot
.65508 .43704 Mdot
.39788 .61199 Mdot
.45768 .57529 Mdot
.48403 .54063 Mdot
.49768 .32174 Mdot
.76156 .43962 Mdot
.61178 .37392 Mdot
.43118 .59901 Mdot
.64434 .62631 Mdot
.3995 .60582 Mdot
.28629 .31301 Mdot
.62379 .65667 Mdot
.37374 .57122 Mdot
.79254 .69282 Mdot
.57292 .30692 Mdot
.72561 .52537 Mdot
.35708 .58432 Mdot
.15104 .54144 Mdot
.39461 .57836 Mdot
.59954 .82439 Mdot
.26922 .34302 Mdot
.38572 .54683 Mdot
.36955 .61087 Mdot
.48003 .75686 Mdot
.4582 .58659 Mdot
.51352 .38119 Mdot
.53504 .83461 Mdot
.56255 .61331 Mdot
.71542 .49246 Mdot
.60947 .70301 Mdot
.34326 .35179 Mdot
.53625 .37301 Mdot
.55344 .30768 Mdot
.35826 .36066 Mdot
.61259 .63848 Mdot
.43578 .59027 Mdot
.51344 .43834 Mdot
.51323 .32121 Mdot
.318 .64483 Mdot
.67284 .46447 Mdot
.64802 .29639 Mdot
.34857 .43271 Mdot
.67013 .44809 Mdot
.37182 .60026 Mdot
.45911 .74931 Mdot
.61761 .76959 Mdot
.22628 .65277 Mdot
.61846 .4383 Mdot
.65348 .4569 Mdot
.76728 .6699 Mdot
.39436 .35357 Mdot
.62715 .23782 Mdot
.77323 .55018 Mdot
.65022 .46737 Mdot
.61465 .57485 Mdot
.51094 .38191 Mdot
.70234 .38868 Mdot
.4584 .64143 Mdot
.46379 .57756 Mdot
.40679 .59299 Mdot
.6458 .43927 Mdot
.57774 .55486 Mdot
.79456 .576 Mdot
.6475 .44855 Mdot
.43047 .51401 Mdot
.56829 .45818 Mdot
.72454 .3801 Mdot
.48852 .3409 Mdot
.37336 .34848 Mdot
.39715 .35204 Mdot
.60315 .60921 Mdot
.3658 .34695 Mdot
.31459 .35063 Mdot
.43375 .57805 Mdot
.64116 .45049 Mdot
.73303 .34868 Mdot
.68739 .45655 Mdot
.36361 .36425 Mdot
.39227 .35677 Mdot
.61279 .62233 Mdot
.63786 .62604 Mdot
.50176 .71464 Mdot
.31299 .41622 Mdot
.44907 .57087 Mdot
.412 .34189 Mdot
.57783 .58334 Mdot
.33623 .63694 Mdot
.36943 .34704 Mdot
.37859 .37379 Mdot
.30673 .49794 Mdot
.40362 .58325 Mdot
.34481 .66783 Mdot
.41129 .58306 Mdot
.44227 .49247 Mdot
.37116 .61818 Mdot
.49233 .3474 Mdot
.3905 .58433 Mdot
.29751 .50862 Mdot
.44791 .62452 Mdot
.35049 .58502 Mdot
.52942 .32132 Mdot
.34356 .57133 Mdot
.51136 .35605 Mdot
.41824 .53727 Mdot
.37299 .39815 Mdot
.53877 .37354 Mdot
.30129 .4542 Mdot
.29448 .49226 Mdot
.55158 .32692 Mdot
.34514 .38511 Mdot
.32877 .36846 Mdot
.26355 .45767 Mdot
.58902 .59831 Mdot
.47046 .54668 Mdot
.42972 .60425 Mdot
.56523 .37132 Mdot
.65896 .42545 Mdot
.38058 .62468 Mdot
.35934 .57308 Mdot
.3588 .59173 Mdot
.60051 .60781 Mdot
.44987 .24434 Mdot
.38539 .36785 Mdot
.50638 .37782 Mdot
.5777 .5337 Mdot
.48601 .33138 Mdot
.35657 .62709 Mdot
.4059 .51643 Mdot
.5825 .69955 Mdot
.73501 .4068 Mdot
.78586 .6421 Mdot
.58895 .62099 Mdot
.53679 .33338 Mdot
.39856 .38002 Mdot
.44229 .5243 Mdot
.61613 .65112 Mdot
.50793 .35472 Mdot
.43557 .59471 Mdot
.41167 .64327 Mdot
.75347 .38486 Mdot
.26442 .37455 Mdot
.30084 .47574 Mdot
.55508 .36747 Mdot
.54485 .31734 Mdot
.27653 .50556 Mdot
.36179 .32202 Mdot
.67303 .40617 Mdot
.43635 .61266 Mdot
.34115 .36127 Mdot
.63999 .63483 Mdot
.64868 .71769 Mdot
.64478 .46944 Mdot
.73563 .64423 Mdot
.42375 .60733 Mdot
.61626 .53681 Mdot
.62476 .6368 Mdot
.35605 .36487 Mdot
.64234 .44137 Mdot
.35944 .33047 Mdot
.53808 .32855 Mdot
.22182 .33279 Mdot
.4312 .56326 Mdot
.3948 .55593 Mdot
.62474 .45104 Mdot
.60858 .65364 Mdot
.32724 .38453 Mdot
.50496 .21295 Mdot
.49789 .34546 Mdot
.48709 .17445 Mdot
.64322 .6355 Mdot
.38391 .75776 Mdot
.48684 .35483 Mdot
.69115 .42971 Mdot
.27587 .4522 Mdot
.66434 .4433 Mdot
.40002 .54201 Mdot
.60742 .64575 Mdot
.64504 .42581 Mdot
.76367 .60917 Mdot
.32225 .77668 Mdot
.39501 .76597 Mdot
.43054 .58319 Mdot
.39918 .81392 Mdot
.38331 .22736 Mdot
.67066 .66313 Mdot
.64351 .4221 Mdot
.41162 .53901 Mdot
.38911 .5532 Mdot
.42569 .56272 Mdot
.67356 .4311 Mdot
.41931 .35633 Mdot
.50881 .33946 Mdot
.45269 .60696 Mdot
.39244 .36056 Mdot
.51945 .35979 Mdot
.70432 .43548 Mdot
.49273 .33534 Mdot
.55476 .58821 Mdot
.37229 .63803 Mdot
.66162 .56711 Mdot
.87612 .60219 Mdot
.65694 .46283 Mdot
.49923 .31842 Mdot
.3762 .53938 Mdot
.68401 .32472 Mdot
.59356 .5901 Mdot
.49643 .34838 Mdot
.40833 .54963 Mdot
.74279 .4078 Mdot
.69123 .72047 Mdot
.50061 .33084 Mdot
.61926 .65158 Mdot
.23063 .64952 Mdot
.43434 .60817 Mdot
.40973 .57459 Mdot
.58356 .63138 Mdot
.40254 .67913 Mdot
.73923 .71399 Mdot
.39582 .60547 Mdot
.65612 .44545 Mdot
.2574 .28151 Mdot
.35991 .57203 Mdot
.39612 .47919 Mdot
.53687 .37037 Mdot
.69864 .40448 Mdot
.76075 .47789 Mdot
.47048 .60533 Mdot
.59289 .24709 Mdot
.6594 .51434 Mdot
.30088 .70219 Mdot
.57059 .37717 Mdot
.3978 .24582 Mdot
.37317 .78725 Mdot
.64191 .47929 Mdot
.49678 .64547 Mdot
.55772 .2327 Mdot
.56451 .67241 Mdot
.19244 .58774 Mdot
.35874 .29839 Mdot
.67814 .73075 Mdot
.53429 .43748 Mdot
.55104 .34813 Mdot
.39335 .66833 Mdot
.38144 .60132 Mdot
.37729 .23109 Mdot
.81144 .50232 Mdot
.80726 .53264 Mdot
.40081 .81584 Mdot
.41614 .76656 Mdot
.28336 .68937 Mdot
.26713 .66874 Mdot
.40005 .48888 Mdot
.63656 .37235 Mdot
.46949 .17 Mdot
.6018 .79725 Mdot
.43568 .19731 Mdot
.34841 .63723 Mdot
.50586 .45907 Mdot
.27683 .3065 Mdot
.48056 .66434 Mdot
.47328 .64887 Mdot
.50729 .37453 Mdot
.58634 .59696 Mdot
.61241 .23668 Mdot
.60335 .66555 Mdot
.75714 .49692 Mdot
.24462 .67936 Mdot
.31249 .76188 Mdot
.64245 .21713 Mdot
.15695 .53776 Mdot
.55685 .69731 Mdot
.41117 .14725 Mdot
.51446 .39186 Mdot
.57486 .61568 Mdot
.24813 .50257 Mdot
.29778 .52685 Mdot
.6978 .58773 Mdot
.51045 .22869 Mdot
.47174 .26516 Mdot
.252 .41672 Mdot
.60609 .64089 Mdot
.77316 .41714 Mdot
.71408 .39747 Mdot
.71307 .57984 Mdot
.56851 .8142 Mdot
.23262 .62412 Mdot
.49201 .43212 Mdot
.56402 .25333 Mdot
.65332 .32067 Mdot
.79797 .58176 Mdot
.34447 .44632 Mdot
.51081 .61793 Mdot
.77921 .55512 Mdot
.17589 .45855 Mdot
.4726 .69243 Mdot
.46006 .50509 Mdot
.30182 .53066 Mdot
.67042 .77488 Mdot
.3404 .26503 Mdot
.86734 .53973 Mdot
.61105 .66935 Mdot
.35433 .59224 Mdot
.39569 .6923 Mdot
.57621 .17959 Mdot
.32715 .35522 Mdot
.21756 .56969 Mdot
.38773 .35962 Mdot
.54778 .59443 Mdot
.72981 .71083 Mdot
.5637 .20163 Mdot
.51849 .16623 Mdot
.38782 .39406 Mdot
.49827 .57298 Mdot
.13544 .6178 Mdot
.27582 .60836 Mdot
.71903 .54904 Mdot
.51981 .85873 Mdot
.57855 .44384 Mdot
.79562 .54956 Mdot
.64471 .42515 Mdot
.41957 .81846 Mdot
.59238 .64406 Mdot
.88539 .50266 Mdot
.61434 .81623 Mdot
.60672 .71452 Mdot
.66713 .86482 Mdot
.2633 .51148 Mdot
.58864 .49713 Mdot
.63053 .50852 Mdot
.28987 .41846 Mdot
.75639 .63987 Mdot
.21425 .46552 Mdot
.67465 .32228 Mdot
.14642 .54163 Mdot
.36086 .78472 Mdot
.4983 .16734 Mdot
.28207 .27621 Mdot
.49333 .678 Mdot
.52933 .49996 Mdot
.38265 .50391 Mdot
.54602 .27581 Mdot
.2073 .56909 Mdot
.6954 .76825 Mdot
.39917 .46571 Mdot
.26547 .77601 Mdot
.38777 .40222 Mdot
.44909 .28061 Mdot
.28238 .75551 Mdot
.25609 .42712 Mdot
.77611 .45886 Mdot
.28973 .63723 Mdot
.31285 .56942 Mdot
.53169 .51696 Mdot
.21411 .57817 Mdot
.72576 .49803 Mdot
.49759 .83928 Mdot
.16283 .56879 Mdot
.63215 .23835 Mdot
.50265 .77827 Mdot
.35409 .48752 Mdot
.65476 .62783 Mdot
.29769 .36439 Mdot
.76565 .47907 Mdot
.35054 .80314 Mdot
.6734 .48942 Mdot
.39525 .83009 Mdot
.72834 .72082 Mdot
.35009 .57 Mdot
.46608 .54259 Mdot
.62924 .57364 Mdot
.28597 .36997 Mdot
.34408 .62446 Mdot
.72604 .31705 Mdot
.30425 .75415 Mdot
.58675 .77809 Mdot
.72672 .47667 Mdot
.66212 .53008 Mdot
.28548 .76722 Mdot
.44064 .72293 Mdot
.39703 .3384 Mdot
.49579 .82882 Mdot
.76233 .63571 Mdot
.52724 .35657 Mdot
.51364 .17414 Mdot
.6009 .45012 Mdot
.66979 .72094 Mdot
.46632 .78974 Mdot
.54642 .6727 Mdot
.30514 .75624 Mdot
.44024 .23667 Mdot
.71079 .72262 Mdot
.23037 .45536 Mdot
.45257 .18465 Mdot
.73032 .3925 Mdot
.35978 .53201 Mdot
.50039 .22746 Mdot
.33263 .36379 Mdot
.51081 .73748 Mdot
.30481 .23276 Mdot
.40759 .30959 Mdot
.38719 .52544 Mdot
.6164 .71536 Mdot
.55578 .30198 Mdot
.68437 .67061 Mdot
.85837 .47737 Mdot
.35132 .60706 Mdot
.29746 .55288 Mdot
.41817 .23192 Mdot
.29476 .40518 Mdot
.19177 .62792 Mdot
.23069 .35828 Mdot
.87344 .55376 Mdot
.4587 .84377 Mdot
.41199 .26077 Mdot
.34765 .76604 Mdot
.36381 .79694 Mdot
.86325 .56736 Mdot
.48812 .58925 Mdot
.67473 .4876 Mdot
.74438 .25724 Mdot
.48673 .34252 Mdot
.28939 .54946 Mdot
.5202 .21089 Mdot
.32184 .41236 Mdot
.66612 .5791 Mdot
.32457 .67628 Mdot
.53068 .44382 Mdot
.56418 .63547 Mdot
.34058 .61245 Mdot
.82557 .58171 Mdot
.85252 .60889 Mdot
.84744 .56427 Mdot
.19667 .3918 Mdot
.42397 .81853 Mdot
.60032 .52793 Mdot
.61187 .20048 Mdot
.32997 .63523 Mdot
.45848 .60927 Mdot
.31576 .36241 Mdot
.26004 .50972 Mdot
.65755 .71237 Mdot
.73489 .58007 Mdot
.46677 .67159 Mdot
.21577 .57096 Mdot
.12164 .39718 Mdot
.52624 .71438 Mdot
.52509 .19827 Mdot
.38476 .33321 Mdot
.30226 .40274 Mdot
.18954 .53844 Mdot
.66376 .70552 Mdot
.27626 .70267 Mdot
.56292 .63235 Mdot
.47309 .20428 Mdot
.39373 .31711 Mdot
.51366 .63622 Mdot
.44704 .24638 Mdot
.2705 .62125 Mdot
.67143 .53555 Mdot
.69337 .69469 Mdot
.76175 .55964 Mdot
.41649 .69737 Mdot
.39091 .42651 Mdot
.63639 .30876 Mdot
.37534 .19702 Mdot
.31693 .30159 Mdot
.40701 .48177 Mdot
.56286 .45629 Mdot
.76461 .35179 Mdot
.68435 .49929 Mdot
.4351 .4864 Mdot
.59796 .43034 Mdot
.28665 .60486 Mdot
.90426 .40779 Mdot
.84467 .53279 Mdot
.24291 .69249 Mdot
.21801 .41572 Mdot
.3442 .55203 Mdot
.26832 .69715 Mdot
.87278 .50307 Mdot
.7763 .71635 Mdot
.62033 .30669 Mdot
.524 .39435 Mdot
.69577 .43095 Mdot
.80656 .6282 Mdot
.43132 .35944 Mdot
.25342 .64447 Mdot
.37716 .46979 Mdot
.67497 .42406 Mdot
.64199 .17708 Mdot
.64995 .78168 Mdot
.44198 .79199 Mdot
.27367 .3678 Mdot
.42343 .52134 Mdot
.78553 .39735 Mdot
.57486 .6347 Mdot
.67295 .35783 Mdot
.32886 .429 Mdot
.52921 .3492 Mdot
.22393 .5219 Mdot
.47593 .21414 Mdot
.45757 .56034 Mdot
.48824 .46965 Mdot
.6505 .63476 Mdot
.72963 .38361 Mdot
.6887 .53629 Mdot
.80859 .68564 Mdot
.34682 .32924 Mdot
.45733 .54572 Mdot
.30247 .41785 Mdot
.47882 .246 Mdot
.77228 .68862 Mdot
.69744 .44264 Mdot
.33666 .76726 Mdot
.48505 .43628 Mdot
.29953 .38703 Mdot
.61085 .69027 Mdot
.35978 .65427 Mdot
.35624 .57004 Mdot
.19226 .42184 Mdot
.59041 .77039 Mdot
.58029 .6696 Mdot
.48192 .62632 Mdot
.32327 .64932 Mdot
.26379 .68995 Mdot
.31823 .34886 Mdot
.64987 .30451 Mdot
.32845 .76499 Mdot
.68976 .44355 Mdot
.63588 .65482 Mdot
.41395 .3725 Mdot
.41786 .20186 Mdot
.38455 .76838 Mdot
.69333 .71972 Mdot
.40191 .44736 Mdot
.41698 .30459 Mdot
.33218 .77871 Mdot
.31448 .73245 Mdot
.73372 .27624 Mdot
.66611 .64958 Mdot
.47865 .50605 Mdot
.4014 .20104 Mdot
.58445 .58851 Mdot
.60127 .21353 Mdot
.64573 .24402 Mdot
.61668 .80673 Mdot
.47195 .45639 Mdot
.14341 .56031 Mdot
.30281 .47226 Mdot
.20265 .54308 Mdot
.75921 .6526 Mdot
.44025 .19164 Mdot
.27425 .55792 Mdot
.65476 .67312 Mdot
.46822 .76422 Mdot
.33187 .57912 Mdot
.7122 .2706 Mdot
.75073 .2745 Mdot
.39787 .40185 Mdot
.59621 .49047 Mdot
.1627 .58203 Mdot
.44086 .57483 Mdot
.84968 .47843 Mdot
.47361 .21028 Mdot
.76717 .66621 Mdot
.68585 .42913 Mdot
.3817 .61705 Mdot
.4517 .6303 Mdot
.39998 .79227 Mdot
.75086 .49836 Mdot
.28871 .64319 Mdot
.2681 .27662 Mdot
.17398 .56066 Mdot
.47675 .67365 Mdot
.29266 .54502 Mdot
.23414 .62785 Mdot
.37786 .2334 Mdot
.56305 .49045 Mdot
.20953 .48014 Mdot
.26815 .43219 Mdot
.16921 .50172 Mdot
.59523 .4483 Mdot
.46181 .32949 Mdot
.68086 .51525 Mdot
.58427 .29941 Mdot
.71661 .69578 Mdot
.3681 .59681 Mdot
.68976 .75354 Mdot
.26039 .63408 Mdot
.7735 .34876 Mdot
.8244 .48353 Mdot
.84301 .5387 Mdot
.55651 .77611 Mdot
.35575 .2652 Mdot
.41478 .21805 Mdot
.35473 .19627 Mdot
.47141 .42528 Mdot
.24825 .54319 Mdot
.24671 .43762 Mdot
.33077 .77369 Mdot
.62632 .45101 Mdot
.77539 .53134 Mdot
.69868 .49916 Mdot
.32295 .73207 Mdot
.45074 .7318 Mdot
.27033 .65792 Mdot
.5801 .42473 Mdot
.87855 .54879 Mdot
.26808 .33185 Mdot
.54822 .43149 Mdot
.54513 .33435 Mdot
.3838 .26057 Mdot
.23476 .59066 Mdot
.26651 .33608 Mdot
.46714 .18895 Mdot
.58021 .32255 Mdot
.57028 .53763 Mdot
.37533 .74242 Mdot
.29989 .35996 Mdot
.1895 .42354 Mdot
.30137 .41677 Mdot
.30005 .74026 Mdot
.43398 .82039 Mdot
.69044 .75119 Mdot
.26333 .51854 Mdot
.18153 .40385 Mdot
.71978 .54573 Mdot
.2932 .35248 Mdot
.47534 .21206 Mdot
.45726 .29208 Mdot
.58693 .66279 Mdot
.64069 .13869 Mdot
.23656 .32431 Mdot
.33284 .28761 Mdot
.68644 .77157 Mdot
.21892 .36889 Mdot
.73345 .39177 Mdot
.42732 .68047 Mdot
.76416 .598 Mdot
.65551 .75939 Mdot
.40862 .60217 Mdot
.84785 .5484 Mdot
.42346 .46324 Mdot
.85991 .61628 Mdot
.25213 .66449 Mdot
.59467 .48303 Mdot
.36805 .63563 Mdot
.52976 .38462 Mdot
.44992 .4181 Mdot
.33305 .51904 Mdot
.40551 .71738 Mdot
.78908 .47805 Mdot
.71397 .4839 Mdot
.50474 .3869 Mdot
.57112 .29146 Mdot
.60129 .66997 Mdot
.2373 .38966 Mdot
.60342 .35477 Mdot
.49036 .39333 Mdot
.47632 .41927 Mdot
.40307 .46249 Mdot
.76369 .46662 Mdot
.43012 .79018 Mdot
.67463 .70512 Mdot
.68262 .58621 Mdot
.49178 .355 Mdot
.46859 .7965 Mdot
.26043 .31493 Mdot
.16892 .55398 Mdot
.69645 .76626 Mdot
.52785 .51146 Mdot
.42236 .74034 Mdot
.37879 .48556 Mdot
.80955 .54618 Mdot
.66548 .60449 Mdot
.7123 .48158 Mdot
.78386 .40199 Mdot
.62399 .57531 Mdot
.5828 .24896 Mdot
.59022 .82344 Mdot
.44591 .19795 Mdot
.39784 .20071 Mdot
.39971 .41565 Mdot
.51559 .56372 Mdot
.51074 .63129 Mdot
.30244 .46085 Mdot
.66273 .40856 Mdot
.49483 .14733 Mdot
.4772 .62545 Mdot
.44368 .12513 Mdot
.63315 .44866 Mdot
.52119 .65768 Mdot
.26199 .43677 Mdot
.56769 .46911 Mdot
.59378 .41979 Mdot
.29383 .31321 Mdot
.78206 .53212 Mdot
.36055 .25604 Mdot
.78997 .58008 Mdot
.52418 .39305 Mdot
.22209 .31734 Mdot
.15455 .45377 Mdot
.48667 .77012 Mdot
.43308 .54084 Mdot
.20297 .35481 Mdot
.48998 .37914 Mdot
.66169 .7099 Mdot
.19412 .63319 Mdot
.1921 .46856 Mdot
.36269 .72746 Mdot
.29918 .39271 Mdot
.25078 .54674 Mdot
.42751 .8379 Mdot
.75674 .29765 Mdot
.21271 .56493 Mdot
.62668 .44818 Mdot
.57205 .43559 Mdot
.26405 .58729 Mdot
.79991 .51632 Mdot
.72709 .4209 Mdot
.77975 .47715 Mdot
.37421 .154 Mdot
.28538 .56503 Mdot
.2969 .56642 Mdot
.80634 .49735 Mdot
.60458 .58115 Mdot
.78864 .50723 Mdot
.77535 .4569 Mdot
.21097 .41008 Mdot
.30328 .27432 Mdot
.77139 .465 Mdot
.37266 .18218 Mdot
.47666 .64145 Mdot
.62823 .39252 Mdot
.34034 .66028 Mdot
.29915 .5813 Mdot
.63195 .42104 Mdot
.59577 .79132 Mdot
.18137 .58262 Mdot
.70534 .47752 Mdot
.18549 .44375 Mdot
.55655 .25107 Mdot
.30766 .56946 Mdot
.41299 .78958 Mdot
.18368 .52232 Mdot
.44822 .7411 Mdot
.70409 .25323 Mdot
.62907 .72243 Mdot
.48822 .38177 Mdot
.2024 .61268 Mdot
.504 .36212 Mdot
.31579 .64374 Mdot
.72955 .65133 Mdot
.21316 .47806 Mdot
.78319 .64917 Mdot
.34251 .35347 Mdot
.57168 .613 Mdot
.75491 .28524 Mdot
.64195 .61975 Mdot
.82723 .58467 Mdot
.56228 .68034 Mdot
.79028 .43774 Mdot
.40314 .2687 Mdot
.38451 .29253 Mdot
.36349 .16783 Mdot
.71586 .40717 Mdot
.54353 .39753 Mdot
.68512 .25426 Mdot
.57321 .62058 Mdot
.39493 .4174 Mdot
.55128 .33119 Mdot
.46244 .39647 Mdot
.64036 .25332 Mdot
.48959 .6327 Mdot
.64569 .60249 Mdot
.45621 .38981 Mdot
.53285 .82244 Mdot
.52716 .84583 Mdot
.51537 .32703 Mdot
.50456 .13298 Mdot
.35214 .61755 Mdot
.50991 .77156 Mdot
.28419 .72168 Mdot
.63473 .17266 Mdot
.57343 .3972 Mdot
.14722 .49826 Mdot
.47288 .58614 Mdot
.19839 .49478 Mdot
.59322 .63857 Mdot
.45921 .20149 Mdot
.38835 .37892 Mdot
.29061 .4002 Mdot
.65677 .48036 Mdot
.69327 .69413 Mdot
.58735 .3864 Mdot
.57936 .59436 Mdot
.21299 .41893 Mdot
.40544 .48925 Mdot
.61941 .47881 Mdot
.42793 .24521 Mdot
.48231 .77396 Mdot
.32593 .71171 Mdot
.46286 .66047 Mdot
.30528 .54645 Mdot
.34659 .21681 Mdot
.81451 .68217 Mdot
.67193 .67292 Mdot
.63922 .56734 Mdot
.69359 .27993 Mdot
.18491 .48394 Mdot
.7471 .33641 Mdot
.30483 .75991 Mdot
.4299 .4738 Mdot
.53802 .54918 Mdot
.45024 .49422 Mdot
.32288 .61367 Mdot
.54571 .46443 Mdot
.65724 .33262 Mdot
.80755 .47109 Mdot
.7565 .46062 Mdot
.45286 .69072 Mdot
.73413 .30111 Mdot
.33326 .50697 Mdot
.78872 .44802 Mdot
.47251 .37365 Mdot
.33224 .71753 Mdot
.64889 .53869 Mdot
.53111 .84773 Mdot
.29764 .74665 Mdot
.70218 .43405 Mdot
.5251 .26409 Mdot
.15647 .59312 Mdot
.48143 .60808 Mdot
.58284 .52927 Mdot
.39832 .55397 Mdot
.51119 .50405 Mdot
.59086 .15073 Mdot
.1903 .45287 Mdot
.38528 .52787 Mdot
.3322 .75408 Mdot
.37036 .78774 Mdot
.87256 .57592 Mdot
.456 .17215 Mdot
.61616 .62097 Mdot
.84727 .59129 Mdot
.78393 .47322 Mdot
.41149 .82844 Mdot
.70926 .36781 Mdot
.35644 .82556 Mdot
.47277 .76207 Mdot
.1746 .50499 Mdot
.43397 .67285 Mdot
.77073 .56832 Mdot
.44809 .2287 Mdot
.58103 .52235 Mdot
.67028 .29784 Mdot
.2696 .32151 Mdot
.21523 .3134 Mdot
.3268 .57284 Mdot
.49092 .22801 Mdot
.69301 .60559 Mdot
.20862 .63444 Mdot
.32118 .30956 Mdot
.39832 .53122 Mdot
.66473 .52588 Mdot
.75213 .67027 Mdot
.41104 .46748 Mdot
.62259 .56366 Mdot
.33095 .30342 Mdot
.65097 .74947 Mdot
.36703 .49265 Mdot
.40821 .19918 Mdot
.47685 .77082 Mdot
.47039 .43165 Mdot
.4116 .62786 Mdot
.65888 .65018 Mdot
.36383 .4051 Mdot
.56247 .51175 Mdot
.43338 .54539 Mdot
.54172 .3117 Mdot
.72991 .43437 Mdot
.81604 .58747 Mdot
.71542 .51186 Mdot
.39678 .21276 Mdot
.48234 .64785 Mdot
.72552 .61305 Mdot
.73958 .32575 Mdot
.83403 .54448 Mdot
.39289 .3232 Mdot
.39795 .46515 Mdot
.284 .68169 Mdot
.4391 .82472 Mdot
.52804 .6374 Mdot
.81257 .67507 Mdot
.64998 .42192 Mdot
.30184 .65348 Mdot
.74406 .58857 Mdot
.57273 .38491 Mdot
.41769 .65605 Mdot
.17603 .5018 Mdot
.30906 .39474 Mdot
.29739 .51612 Mdot
.32879 .26963 Mdot
.53687 .53703 Mdot
.41942 .77426 Mdot
.33466 .76192 Mdot
.55798 .37277 Mdot
.35528 .22348 Mdot
.61593 .48902 Mdot
.3442 .30202 Mdot
.44046 .8275 Mdot
.65505 .78403 Mdot
.59803 .40807 Mdot
.27375 .42151 Mdot
.40747 .57178 Mdot
.38278 .19747 Mdot
.18971 .44837 Mdot
.30743 .57624 Mdot
.63079 .29054 Mdot
.63871 .65135 Mdot
.62497 .33917 Mdot
.49412 .45256 Mdot
.64185 .76196 Mdot
.64583 .65421 Mdot
.78735 .40983 Mdot
.36545 .40004 Mdot
.59133 .49611 Mdot
.50667 .60989 Mdot
.28312 .42171 Mdot
.45847 .15697 Mdot
.49311 .6169 Mdot
.21244 .58348 Mdot
.47802 .78786 Mdot
.50235 .21289 Mdot
.19039 .50413 Mdot
.73814 .40753 Mdot
.78176 .53566 Mdot
.35898 .74683 Mdot
.70697 .49719 Mdot
.36023 .57968 Mdot
.50658 .39217 Mdot
.59107 .59297 Mdot
.20096 .62494 Mdot
.55236 .78166 Mdot
.29801 .45357 Mdot
.41175 .43161 Mdot
.60968 .56548 Mdot
.62943 .51274 Mdot
.32731 .79953 Mdot
.78018 .54524 Mdot
.35527 .44324 Mdot
.47374 .4577 Mdot
.26837 .43778 Mdot
.51685 .6801 Mdot
.64047 .80612 Mdot
.43284 .67888 Mdot
.51021 .43167 Mdot
.52746 .65447 Mdot
.33628 .27548 Mdot
.18905 .62981 Mdot
.45868 .50291 Mdot
.5846 .46062 Mdot
.32452 .3694 Mdot
.7476 .35775 Mdot
.40356 .42336 Mdot
.60271 .55033 Mdot
.45057 .36853 Mdot
.62894 .26593 Mdot
.71278 .6408 Mdot
.43448 .50713 Mdot
.27128 .52117 Mdot
.29725 .70899 Mdot
.50563 .20639 Mdot
.67771 .4992 Mdot
.64686 .37354 Mdot
.59943 .78394 Mdot
.38852 .84959 Mdot
.80439 .39225 Mdot
.41201 .57052 Mdot
.65027 .51226 Mdot
.26756 .40737 Mdot
.56133 .35145 Mdot
.76757 .44311 Mdot
.75903 .39153 Mdot
.63467 .4343 Mdot
.30292 .38848 Mdot
.31415 .51061 Mdot
.53096 .25593 Mdot
.25393 .39224 Mdot
.65998 .54544 Mdot
.82691 .56699 Mdot
.21717 .35389 Mdot
.18522 .48703 Mdot
.51976 .89002 Mdot
.63347 .49205 Mdot
.33592 .5447 Mdot
.45392 .71728 Mdot
.47928 .84265 Mdot
.30793 .42596 Mdot
.67298 .71641 Mdot
.71107 .3324 Mdot
.4674 .50833 Mdot
.67693 .66114 Mdot
.28524 .52053 Mdot
.62121 .33294 Mdot
.54924 .4499 Mdot
.3861 .29725 Mdot
.82174 .66934 Mdot
.39404 .75035 Mdot
.28867 .70122 Mdot
.76241 .65492 Mdot
.35633 .19335 Mdot
.47142 .84288 Mdot
.29409 .48904 Mdot
.30015 .32309 Mdot
.39984 .69682 Mdot
.60398 .4227 Mdot
.503 .66334 Mdot
.66631 .71083 Mdot
.48435 .81306 Mdot
.44202 .26372 Mdot
.5142 .66929 Mdot
.40841 .48177 Mdot
.51815 .8153 Mdot
.58528 .45899 Mdot
.44033 .79538 Mdot
.54721 .27405 Mdot
.7999 .48929 Mdot
.54514 .61815 Mdot
.32419 .4511 Mdot
.4802 .7937 Mdot
.67256 .26589 Mdot
.24837 .34158 Mdot
.30676 .21647 Mdot
.43555 .34535 Mdot
.81691 .56602 Mdot
.45877 .55353 Mdot
.90204 .52725 Mdot
.39395 .24011 Mdot
.44588 .23371 Mdot
.33367 .26012 Mdot
.49439 .30623 Mdot
.32152 .63924 Mdot
.36001 .58032 Mdot
.23011 .59163 Mdot
.36661 .72961 Mdot
.56821 .69764 Mdot
.70971 .6845 Mdot
.29362 .38951 Mdot
.3757 .46671 Mdot
.30207 .46601 Mdot
.54816 .56968 Mdot
.63536 .64918 Mdot
.84442 .57157 Mdot
.5871 .4088 Mdot
.31198 .56766 Mdot
.51885 .58802 Mdot
.41362 .69478 Mdot
.15037 .62665 Mdot
.59755 .48315 Mdot
.30448 .55525 Mdot
.43968 .77443 Mdot
.53628 .63444 Mdot
.75274 .34338 Mdot
.74464 .78905 Mdot
.91777 .52128 Mdot
.57414 .59874 Mdot
.52877 .19575 Mdot
.42741 .77185 Mdot
.29508 .67345 Mdot
.40398 .32284 Mdot
.61824 .27747 Mdot
.2991 .62536 Mdot
.66988 .68475 Mdot
.46423 .64288 Mdot
.39876 .23354 Mdot
.55675 .84658 Mdot
.69874 .68733 Mdot
.32879 .74947 Mdot
.32954 .60561 Mdot
.47817 .63389 Mdot
.4954 .8945 Mdot
.26789 .59385 Mdot
.39013 .64433 Mdot
.46828 .67719 Mdot
.47171 .53973 Mdot
.38542 .59843 Mdot
.20275 .52032 Mdot
.22773 .31336 Mdot
.36284 .4938 Mdot
.32032 .72792 Mdot
.63745 .66768 Mdot
.5414 .29986 Mdot
.63302 .4519 Mdot
.60204 .40858 Mdot
.43172 .64306 Mdot
.65357 .42649 Mdot
.49597 .50606 Mdot
.15932 .58341 Mdot
.42401 .42424 Mdot
.29336 .25821 Mdot
.41898 .84805 Mdot
.53391 .78654 Mdot
.7549 .40894 Mdot
.48176 .60546 Mdot
.32835 .71714 Mdot
.45885 .81952 Mdot
.58566 .55143 Mdot
.17342 .44988 Mdot
.76305 .23685 Mdot
.74231 .36843 Mdot
.63299 .77573 Mdot
.57755 .58538 Mdot
.44549 .39738 Mdot
.39691 .76321 Mdot
.71176 .37445 Mdot
.52881 .33155 Mdot
.33851 .62274 Mdot
.61547 .58033 Mdot
.66065 .41958 Mdot
.51538 .12626 Mdot
.43703 .54272 Mdot
.76683 .40998 Mdot
.38597 .80848 Mdot
.63082 .72218 Mdot
.49958 .74692 Mdot
.39156 .63423 Mdot
.70757 .58101 Mdot
.58395 .46153 Mdot
.20511 .58434 Mdot
.67512 .76084 Mdot
.2844 .66178 Mdot
.5492 .78408 Mdot
.42085 .7737 Mdot
.41189 .62676 Mdot
.39428 .35692 Mdot
.69666 .40114 Mdot
.2202 .56899 Mdot
.48532 .56269 Mdot
.47259 .85103 Mdot
.59166 .38169 Mdot
.48206 .47179 Mdot
.61022 .5122 Mdot
.86614 .58097 Mdot
.46669 .7006 Mdot
.48802 .6481 Mdot
.83291 .54909 Mdot
.5891 .37096 Mdot
.28112 .36602 Mdot
.54418 .38279 Mdot
.48979 .58348 Mdot
.65463 .63692 Mdot
.85319 .47632 Mdot
.22395 .54552 Mdot
.67804 .29999 Mdot
.63804 .30367 Mdot
.54961 .21799 Mdot
.61681 .478 Mdot
.54079 .88985 Mdot
.40002 .2545 Mdot
.85261 .50913 Mdot
.34637 .21971 Mdot
.63281 .58982 Mdot
.21548 .37659 Mdot
.45946 .6387 Mdot
.52462 .3341 Mdot
.29699 .69103 Mdot
.32037 .5624 Mdot
.71547 .71709 Mdot
.44947 .61962 Mdot
.78183 .6659 Mdot
.32863 .39221 Mdot
.49357 .2578 Mdot
.35055 .27015 Mdot
.42578 .69991 Mdot
.26354 .71637 Mdot
.73648 .33217 Mdot
.27472 .72085 Mdot
.24622 .68147 Mdot
.35204 .78347 Mdot
.71699 .70687 Mdot
.71741 .24419 Mdot
.33999 .27801 Mdot
.18213 .52043 Mdot
.6665 .35208 Mdot
.39528 .68123 Mdot
.38187 .2615 Mdot
.59094 .56982 Mdot
.74823 .50044 Mdot
.65209 .53116 Mdot
.46502 .07733 Mdot
.34353 .47269 Mdot
.51858 .61978 Mdot
.3778 .27234 Mdot
.40252 .81429 Mdot
.41066 .69955 Mdot
.27942 .31374 Mdot
.50876 .45961 Mdot
.35932 .53112 Mdot
.48783 .81193 Mdot
.50526 .20193 Mdot
.48283 .24111 Mdot
.28077 .21583 Mdot
.25766 .31844 Mdot
.65148 .28107 Mdot
.53492 .45876 Mdot
.57297 .60119 Mdot
.69016 .24604 Mdot
.39352 .29227 Mdot
.17648 .43074 Mdot
.16175 .54195 Mdot
.26553 .58986 Mdot
.37232 .16564 Mdot
.48275 .20948 Mdot
.5092 .84566 Mdot
.20573 .39824 Mdot
.57267 .59829 Mdot
.2833 .48211 Mdot
.47842 .37468 Mdot
.66851 .3167 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0Toooool2o`000;Cooooo000Loooo
o`03o`000?oooooooooo09?ooooo0_l0002dooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0Yooo
ool2o`000:3ooooo000Looooo`03o`000?oooooooooo0:Oooooo0_l0002Pooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0]oooool2o`00093ooooo000Looooo`03o`000?oooooooooo0;?ooooo0_l00002oooo
o`;o0000T?ooool001cooooo00?o0000ooooooooool0/oooool2o`0009Cooooo000Looooo`03o`00
0?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0/oooool2o`0009Cooooo000L
ooooo`03o`000?oooooooooo08cooooo0_l0000;ooooo`;o00005Oooool2o`000003ooooool0003o
000009Cooooo000Looooo`03o`000?oooooooooo08cooooo0_l0000;ooooo`;o00002Oooool2o`00
00[ooooo0_l0000>ooooo`;o00000_ooool2o`0008?ooooo000Looooo`03o`000?oooooooooo0:Co
oooo0_l0000Jooooo`;o00000_ooool2o`0008?ooooo000Looooo`03o`000?oooooooooo09Gooooo
0_l00009ooooo`;o0000Yoooool001cooooo00?o0000ooooooooool0UOooool2o`0000Wooooo0_l0
002Wooooo`007?ooool00ol0003oooooooooo`3<ooooo`;o0000Noooool001cooooo00?o0000oooo
ooooool0c?ooool2o`0007_ooooo000Looooo`03o`000?oooooooooo08;ooooo0_l0000:ooooo`;o
00003Oooool2o`000:[ooooo000Looooo`03o`000?oooooooooo08;ooooo0_l00009ooooo`?o0000
3Oooool2o`0001gooooo0_l00007ooooo`;o0000P_ooool001cooooo0_l0002>ooooo`;o00001Ooo
ool2o`0002Kooooo0_l00007ooooo`;o0000P_ooool001cooooo00?o0000ooooooooool0M_ooool2
o`0001?ooooo0_l00007ooooo`;o00001oooool2o`00013ooooo0_l0000Dooooo`;o0000P_ooool0
01cooooo00?o0000ooooooooool0M_ooool2o`0001?ooooo0_l00004ooooo`;o00001_ooool2o`00
00;ooooo0_l0000@ooooo`;o00005?ooool2o`0008;ooooo000Looooo`03o`000?oooooooooo097o
oooo0_l00006ooooo`;o00003Oooool2o`0000?ooooo0_l0002Jooooo`007?ooool00ol0003ooooo
ooooo`1eooooo`;o000000?oooooo`000?l000008?ooool2o`0000cooooo0_l00003ooooo`;o0000
V_ooool001cooooo00?o0000ooooooooool0L_ooool2o`000004ooooool0003o0000ooooo`;o0000
8?ooool2o`0000;ooooo0_l00005ooooo`;o00000oooool2o`0009gooooo000Looooo`03o`000?oo
oooooooo06Cooooo0_l0000<ooooo`;o00006Oooool2o`000003ooooool0003o000000?ooooo0_l0
0007ooooo`;o00001Oooool2o`0000?ooooo0_l0002Mooooo`007?ooool00ol0003oooooooooo`1T
ooooo`;o00009oooool2o`000003ooooool0003o000000?ooooo0ol00002ooooo`;o00001oooool2
o`0000_ooooo0_l0000Hooooo`;o0000OOooool001cooooo00?o0000ooooooooool0U_ooool2o`00
00;ooooo0_l00007ooooo`;o00002oooool2o`0000Gooooo0_l0000Aooooo`;o000000?oooooo`00
0?l00000N_ooool001cooooo00?o0000ooooooooool0/?ooool2o`0000Gooooo0_l0000Dooooo`;o
0000N_ooool001cooooo00?o0000ooooooooool0MOooool2o`0001kooooo0_l000000ooooooo0000
o`00000=ooooo`;o00001oooool2o`0000Gooooo0_l0002@ooooo`007?ooool00ol0003ooooooooo
o`1_ooooo`;o00001?ooool2o`0001Sooooo0_l00004ooooo`;o000000?oooooo`000?l000003Ooo
ool2o`0000Sooooo0_l00009ooooo`;o0000Roooool001cooooo00?o0000ooooooooool0Koooool2
o`0001gooooo0ol00003ooooo`;o00000_ooool2o`0000Oooooo0_l00002ooooo`;o00000oooool3
o`0000Cooooo0_l00009ooooo`;o0000Roooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Ooo
ool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo073ooooo0_l00003ooooo`;o00004?oo
ool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l0000;ooooo`;o00000_oo
ool2o`0000?ooooo0ol0002Looooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q
1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0Koooool3o`0000?o
oooo0_l00004ooooo`?o00002Oooool2o`0000;ooooo0_l00003ooooo`;o00005_ooool2o`0001_o
oooo0_l00022ooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0Koooool2o`0000Gooooo0_l000000ooooooo0000
o`000003o`0000?ooooo0_l00007ooooo`;o000000?oooooo`000?l000004Oooool2o`0000Gooooo
0ol0000?ooooo`Co00002?ooool2o`0001Kooooo0_l0001Zooooo`0000?oooooo`000?ooool00_oo
ool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0001fooooo`Go00000_oo
ool6o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000002ooooo`;o00003Ooo
ool2o`0000?ooooo1?l00007ooooo`;o000000?oooooo`000?l000001?ooool4o`0000Gooooo0ol0
0003ooooo`;o00003_ooool2o`0000?ooooo0_l0000Aooooo`;o0000Eoooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooo
oooo07Oooooo0_l00004ooooo`Co00000oooool3o`0000Kooooo0_l00002ooooo`;o00000oooool2
o`0000Sooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000Kooooo0_l00000
1?oooooo0000o`000?ooool2o`0000[ooooo0ol000000ooooooo0000o`000002o`0000?ooooo0_l0
0009ooooo`;o00005_ooool2o`0005Oooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooo
oooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`21ooooo`;o00000_ooool2
o`0000;ooooo0ol0000:ooooo`;o00002?ooool2o`000003ooooool0003o000000?ooooo0_l00005
ooooo`;o00001Oooool2o`0000Oooooo0_l00005ooooo`;o00001Oooool2o`0007[ooooo00001_oo
ooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`00
0?oooooooooo05Oooooo0_l0000Xooooo`;o00001_ooool3o`0000[ooooo1Ol00005ooooo`;o0000
0oooool2o`0000Sooooo0_l0000>ooooo`;o0000R?ooool00006ooooooo^k^ko<S8bo`000?lb<S;o
k^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0Eoooool2o`00
02Cooooo0_l0000:ooooo`;o00002oooool5o`0000Cooooo1Ol000000ooooooo0000o`00000Ioooo
o`;o000000?oooooo`000?l000000oooool2o`0000Oooooo0_l0001fooooo`007?ooool00ol0003o
ooooooooo`1Gooooo`;o00001oooool2o`0000_ooooo0_l00002ooooo`;o00002_ooool3o`0000?o
oooo0_l0000<ooooo`;o00001?ooool2o`0000?ooooo0_l000000ooooooo0000o`000003o`0000Co
oooo0_l00005ooooo`;o00000_ooool2o`0000_ooooo0_l000000ooooooo0000o`000003ooooo`;o
00000oooool2o`0000;ooooo0_l0000;ooooo`;o0000JOooool001cooooo00?o0000ooooooooool0
Eoooool2o`0000Oooooo0_l0000;ooooo`;o00000_ooool2o`0000Gooooo0_l00004ooooo`;o0000
0oooool2o`0000cooooo0_l00002ooooo`?o00001?ooool2o`0000[ooooo0_l00003ooooo`Co0000
0_ooool2o`0001Sooooo0_l0000?ooooo`Co0000Ioooool001cooooo00?o0000ooooooooool0J_oo
ool2o`000004ooooool0003o0000ooooo`;o00001_ooool2o`0001_ooooo0ol00002ooooo`Co0000
3oooool3o`00033ooooo0_l0001Wooooo`007?ooool00ol0003oooooooooo`1Rooooo`Co00001?oo
ool2o`0000Cooooo0_l00007ooooo`;o00000_ooool2o`0000Sooooo0_l0000=ooooo`?o000000?o
ooooo`000?l000000_l000000ooooooo0000o`00000Cooooo`;o00006?ooool2o`0000Wooooo0_l0
001^ooooo`007?ooool00ol0003oooooooooo`1Rooooo`Co00002_ooool2o`0000Oooooo0_l00002
ooooo`;o00002?ooool2o`0000Gooooo0_l00007ooooo`;o00000oooool2o`000004ooooool0003o
0000ooooo`;o00004?ooool2o`0001Sooooo0_l00009ooooo`;o0000K_ooool001cooooo00?o0000
ooooooooool0Goooool2o`0000oooooo0_l00005ooooo`;o00001Oooool2o`000004ooooool0003o
0000ooooo`;o00001oooool3o`0000Gooooo0_l00005ooooo`;o00001?ooool2o`0000gooooo1?l0
000Aooooo`Co000000?oooooo`000?l00000O?ooool001cooooo00?o0000ooooooooool0G_ooool3
o`0000_ooooo0_l00009ooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`;o00001Ooo
ool4o`0000Kooooo0_l000000ooooooo0000o`00000Gooooo`Co00003_ooool2o`000003ooooool0
003o000000;o000000?oooooo`000?l000003oooool2o`0001Kooooo0_l0001Cooooo`007?ooool0
0ol0003oooooooooo`1Nooooo`;o00002oooool3o`0001?ooooo0_l00002ooooo`;o00000_ooool4
o`0000Oooooo0ol000000ooooooo0000o`000006ooooo`;o00000oooool2o`0001cooooo0_l00003
ooooo`Co00001?ooool2o`0000?ooooo0_l00005ooooo`;o00005_ooool2o`0005?ooooo000Loooo
o`03o`000?oooooooooo06_ooooo0_l0000>ooooo`?o00000oooool2o`0000;ooooo0_l00002oooo
o`;o00001oooool6o`000003ooooool0003o000000Gooooo0_l000000ooooooo0000o`000002o`00
013ooooo0_l00006ooooo`Co00001Oooool4o`0000Cooooo0_l00003ooooo`;o00002?ooool2o`00
06Sooooo000Looooo`03o`000?oooooooooo06Kooooo0_l00004ooooo`;o00003Oooool4o`0000Ko
oooo1?l00004ooooo`?o000000Coooooo`000?l0003o00000_ooool5o`0000;ooooo0ol00003oooo
o`;o00003_ooool2o`0000;ooooo0ol00005ooooo`Co00001oooool2o`0000;ooooo0ol00008oooo
o`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o0000H_ooool001cooooo00?o0000oooo
ooooool0G?ooool2o`0000Oooooo0ol00004ooooo`?o00003_ooool2o`0000?ooooo0_l00003oooo
o`;o00001?ooool3o`000003ooooool0003o000000Gooooo0ol00002ooooo`?o00004oooool2o`00
00;ooooo2?l0000;ooooo`;o00000_ooool4o`0000Oooooo0_l000000ooooooo0000o`000007oooo
o`;o0000H_ooool001cooooo0_l0001Mooooo`;o00000oooool2o`0000;ooooo0_l00006ooooo`;o
00003Oooool2o`0000Cooooo0_l00009ooooo`;o00004_ooool2o`0000kooooo0_l00007ooooo`Go
00004Oooool2o`0001Oooooo0_l0001Nooooo`007?ooool00ol0003oooooooooo`1Qooooo`;o0000
6Oooool4o`0000gooooo0_l0000=ooooo`;o00000oooool2o`0000gooooo1Ol0000Gooooo`;o0000
3Oooool2o`0000Cooooo0_l00006ooooo`;o0000G_ooool001cooooo00?o0000ooooooooool0G?oo
ool2o`0000Oooooo0_l0000:ooooo`Co000000?oooooo`000?l000001_ooool2o`0001Wooooo0_l0
00001?oooooo0000o`000?l00006ooooo`;o00000_ooool2o`0000Gooooo0_l000000ooooooo0000
o`000003ooooo`;o00004_ooool2o`0000gooooo0_l00004ooooo`;o00002oooool2o`0005Wooooo
000Looooo`03o`000?oooooooooo05cooooo0_l00007ooooo`;o00000_ooool2o`0000Cooooo1_l0
00000ooooooo0000o`000003o`0000Oooooo0_l00008ooooo`;o00002oooool2o`0000;ooooo0_l0
00000ooooooo0000o`000003ooooo`;o00000_ooool2o`0000gooooo0_l0000Zooooo`;o00002?oo
ool2o`0005Wooooo000Looooo`03o`000?oooooooooo06Wooooo0_l00004ooooo`;o00001oooool3
o`0000Oooooo0_l00008ooooo`?o00003_ooool2o`000003ooooool0003o000000Gooooo0_l00004
ooooo`;o00004Oooool2o`00027ooooo0ol0001Sooooo`007?ooool00ol0003oooooooooo`1[oooo
o`;o00000oooool2o`0001;ooooo1?l00004ooooo`?o00001_ooool2o`0000Kooooo0_l00008oooo
o`;o00001?ooool2o`0000Kooooo0_l00009ooooo`;o00001oooool2o`0000cooooo0_l000000ooo
oooo0000o`000007ooooo`;o0000I?ooool001cooooo00?o0000ooooooooool0Ioooool2o`0000;o
oooo0_l000000ooooooo0000o`000002o`0000Oooooo0_l00004ooooo`;o00000_ooool5o`0000go
oooo0_l0000Booooo`;o00001_ooool2o`0000;ooooo0_l0000Booooo`;o00003?ooool2o`000004
ooooool0003o0000o`0000Oooooo0_l0001Sooooo`007?ooool00ol0003oooooooooo`1Wooooo`;o
00001?ooool3o`0000?ooooo0ol000000ooooooo0000o`000002o`0000Cooooo0_l00002ooooo`Co
00004Oooool2o`0000Sooooo0_l00005ooooo`;o00001_ooool2o`0001Sooooo0_l0000>ooooo`;o
00001Oooool4o`0006?ooooo000Looooo`03o`000?oooooooooo05?ooooo0_l00003ooooo`;o0000
0oooool4o`0000Wooooo0_l000000ooooooo0000o`000004ooooo`?o000000?oooooo`000?l00000
7Oooool4o`0000Oooooo0ol0000:ooooo`;o00006oooool2o`0001Gooooo0_l00007ooooo`;o0000
0oooool2o`0005Oooooo000Looooo`03o`000?oooooooooo053ooooo0_l000000ooooooo0000o`00
0003ooooo`Co000000?oooooo`000?l000000_l00009ooooo`Go00001Oooool2o`0001;ooooo0_l0
000<ooooo`;o00002Oooool2o`0000_ooooo0_l0000=ooooo`;o00001_ooool2o`0001?ooooo0_l0
0002ooooo`;o00001oooool3o`000003ooooool0003o000000?ooooo0_l0001Gooooo`007?ooool0
0ol0003oooooooooo`1@ooooo`;o00002?ooool2o`0000oooooo1?l00004ooooo`;o00004oooool2
o`0000Cooooo0_l0000?ooooo`;o00006?ooool2o`0000;ooooo0_l000000ooooooo0000o`000003
ooooo`Ko00001Oooool2o`0000;ooooo0_l00004ooooo`;o00000_ooool2o`0000Cooooo0_l00000
1?oooooo0000o`000?l0000:ooooo`;o0000Doooool001cooooo00?o0000ooooooooool0D?ooool2
o`00027ooooo0_l0000Iooooo`;o00003oooool2o`0001Sooooo0_l00002ooooo`;o000000?ooooo
o`000?l000001Oooool4o`0000Gooooo0ol000000ooooooo0000o`00000>ooooo`;o00000oooool2
o`0000Kooooo0_l000000ooooooo0000o`00001Cooooo`007?ooool00ol0003oooooooooo`1Xoooo
o`;o0000;Oooool2o`0000Cooooo0_l00009ooooo`;o00003Oooool2o`0001Sooooo0_l0000Foooo
o`?o00000oooool5o`0005Gooooo000Looooo`03o`000?oooooooooo05Cooooo0_l0000Booooo`;o
00002Oooool2o`0000;ooooo0_l00003ooooo`;o00001Oooool2o`0000cooooo0_l00004ooooo`;o
00001?ooool2o`0000Gooooo0_l00002ooooo`;o00003?ooool3o`0000cooooo0_l00002ooooo`;o
00006oooool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l00000EOooool001cooooo
00?o0000ooooooooool0E?ooool2o`0001gooooo0_l00002ooooo`Co000000?oooooo`000?l00000
1Oooool2o`0000cooooo0_l00004ooooo`;o00002?ooool2o`000004ooooool0003o0000o`0000oo
oooo0_l00008ooooo`;o00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`;o
00004Oooool4o`00067ooooo000Looooo`03o`000?oooooooooo05kooooo0_l0000;ooooo`;o0000
1?ooool2o`0000Kooooo0ol0000Kooooo`;o00002?ooool2o`0000;ooooo0_l00005ooooo`;o0000
0_ooool2o`0000Cooooo0_l00008ooooo`Go00001oooool2o`000003ooooool0003o000000;o0000
0oooool2o`000003ooooool0003o000000Wooooo0ol0000;ooooo`;o0000EOooool001cooooo0_l0
001Nooooo`Go000000?oooooo`000?l000001_ooool2o`0000Cooooo0_l00007ooooo`;o00005ooo
ool2o`0000Cooooo1?l00004ooooo`;o00002Oooool2o`0000;ooooo0ol00003ooooo`;o00000_oo
ool2o`0000Gooooo1?l0000:ooooo`;o00000oooool:o`0000Oooooo0_l00004ooooo`;o00001Ooo
ool2o`0000Gooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o000000?ooooo
o`000?l000001?ooool2o`0000Cooooo0_l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l0
0002ooooo`;o00005_ooool2o`0000Sooooo0_l00003ooooo`;o00001?ooool6o`0000Cooooo0_l0
0007ooooo`;o00000oooool2o`0000Oooooo0_l0000<ooooo`;o000000?oooooo`000?l000000_oo
ool2o`000003ooooool0003o000000;o000000?oooooo`000?l000001ol00006ooooo`;o00000ooo
ool2o`0000cooooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o000000?ooooo
o`000?l000000oooool3o`0000oooooo0_l00002ooooo`;o00005_ooool2o`0000Sooooo0_l0000:
ooooo`;o000000?oooooo`000?l000001?ooool2o`0000_ooooo0ol00002ooooo`?o00003_ooool4
o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`00000:ooooo`;o00001_ooool2
o`00067ooooo000Looooo`03o`000?oooooooooo05Kooooo0_l0000=ooooo`Co00001Oooool2o`00
017ooooo0_l0000Gooooo`Go00004Oooool2o`0000?ooooo0ol0000;ooooo`;o000000?oooooo`00
0?l000000oooool2o`0001Gooooo0_l0001Uooooo`007?ooool00ol0003oooooooooo`12ooooo`;o
00000_ooool2o`0000Oooooo0_l00006ooooo`So00001_ooool4o`0000Gooooo0_l0000Aooooo`;o
00003Oooool2o`0000;ooooo0_l00004ooooo`?o00000_ooool4o`0000Cooooo0_l00003ooooo`;o
00003?ooool2o`0000Oooooo0_l00006ooooo`;o00001oooool2o`0000cooooo0_l0001Uooooo`00
7?ooool00ol0003oooooooooo`12ooooo`;o00000_ooool2o`0000Oooooo1?l00004ooooo`So0000
4oooool2o`0001cooooo0_l00002ooooo`;o00001Oooool2o`000003ooooool0003o000000?o0000
0_ooool4o`0000?ooooo1?l000000ooooooo0000o`000005ooooo`Co00002?ooool2o`0000kooooo
1Ol0000?ooooo`;o0000Goooool001cooooo00?o0000ooooooooool0A?ooool2o`0000[ooooo1?l0
000Nooooo`;o00002?ooool2o`0001;ooooo0_l0000;ooooo`Ko000000?oooooo`000?l000003_l0
0004ooooo`;o00002_ooool2o`0000Cooooo0_l00009ooooo`Co00003oooool2o`0000?ooooo0_l0
001Jooooo`007?ooool00ol0003oooooooooo`14ooooo`;o00002_ooool6o`0000Sooooo0_l0000B
ooooo`?o00001oooool2o`000003ooooool0003o0000013ooooo0_l00002ooooo`;o00001OoooolH
o`0000Gooooo0_l0000=ooooo`Co00001?ooool2o`0000?ooooo1?l0000:ooooo`Co00001_ooool2
o`0000_ooooo0_l0001=ooooo`007?ooool00ol0003oooooooooo`16ooooo`;o000000?oooooo`00
0?l000002Oooool2o`0000?ooooo0_l00003ooooo`;o00001Oooool2o`0000_ooooo0ol00007oooo
o`;o000000?oooooo`000?l000000_ooool2o`0000Sooooo0_l00002ooooo`;o00000_ooool3o`00
00;ooooo5?l000000ooooooo0000o`000004o`0000?ooooo0ol00008ooooo`;o00000oooool2o`00
00Kooooo0_l00003ooooo`Oo00001oooool4o`0000Gooooo1?l0000:ooooo`;o0000COooool001co
oooo00?o0000ooooooooool0?Oooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo
0000o`00000>ooooo`;o00002_ooool2o`0000Kooooo0_l00002ooooo`;o00004?ooool2o`0000So
oooo0_l00007oooooa_o000000Coooooo`000?l0003o00000oooool2o`0000Wooooo0_l0000Aoooo
o`;o000000Coooooo`000?l0003o00002Oooool4o`0000?ooooo1?l00003ooooo`;o0000E?ooool0
01cooooo00?o0000ooooooooool0?Oooool2o`000003ooooool0003o000000Kooooo0_l000000ooo
oooo0000o`000006ooooo`;o00003_ooool2o`0000Sooooo0_l00002ooooo`;o00000oooool2o`00
01Gooooo0_l00003ooooo`;o00000ooooolOo`0000Oooooo0_l00004ooooo`;o00004_ooool2o`00
0004ooooool0003o0000ooooo`;o00000oooool3o`0000;ooooo0_l00002ooooo`;o00000oooool2
o`000003ooooool0003o000005Cooooo000Looooo`03o`000?oooooooooo04Cooooo0_l00002oooo
o`Oo00001?ooool2o`0000kooooo0_l00008ooooo`;o00000_ooool2o`0000?ooooo0_l000000ooo
oooo0000o`00000Gooooo`;o00000oooool2o`000003ooooool0003o000001[o00000_ooool2o`00
00?ooooo0_l00004ooooo`;o000000?oooooo`000?l000002_ooool2o`0000?ooooo0_l000001?oo
oooo0000o`000?ooool2o`0000?ooooo0ol00003ooooo`;o000000?oooooo`000?l000000oooool2
o`000003ooooool0003o000005Cooooo000Looooo`03o`000?oooooooooo04Cooooo0ol00002oooo
o`;o000000?oooooo`000?l000000_l00003ooooo`?o00005oooool2o`000003ooooool0003o0000
00Gooooo1?l00002ooooo`;o00001?ooool2o`00017ooooo0_l000000ooooooo0000o`00000Fo`00
0004ooooool0003o0000o`0000;ooooo0ol00008ooooo`;o00000_ooool2o`0000[ooooo0_l00002
ooooo`;o00003Oooool2o`000003ooooool0003o000000Gooooo0_l0000?ooooo`;o0000Aoooool0
01cooooo00?o0000ooooooooool0AOooool2o`0000Gooooo1?l00003ooooo`?o00003?ooool2o`00
00cooooo1?l00003ooooo`So00001?ooool2o`00017ooooo8ol00009ooooo`;o00000oooool2o`00
00Wooooo1_l00003ooooo`;o00002?ooool3o`0000Oooooo0_l0000?ooooo`;o0000Aoooool001co
oooo00?o0000ooooooooool0>_ooool2o`00017ooooo0_l00005ooooo`;o00003?ooool2o`0000?o
oooo0_l00003ooooo`?o000000?oooooo`000?l000001Ol00004ooooo`Co00000oooool2o`0000So
oooo0_l00009ooooob;o00002Oooool2o`0000?ooooo0_l0000;ooooo`;o00001Oooool2o`0000Wo
oooo0_l00002ooooo`;o00001Oooool2o`0000?ooooo0_l0001Aooooo`007?ooool00ol0003ooooo
ooooo`0jooooo`;o00006?ooool2o`0000Gooooo0_l0000:ooooo`;o000000?oooooo`000?l00000
1_l000000ooooooo0000o`00000:o`0000?ooooo0_l00006ooooo`Co00002?oooolPo`0000Wooooo
1Ol0000:ooooo`Ko00005_ooool2o`0000Gooooo0ol00002ooooo`;o0000DOooool001cooooo0_l0
0017ooooo`;o00004?ooool2o`000004ooooool0003o0000o`0000Cooooo1?l00004oooooa?o0000
3Oooool2o`0000[ooooo3_l000000ooooooo0000o`00000?o`0000;ooooo0_l000000ooooooo0000
o`000002ooooo`Go00002_ooool6o`0000_ooooo0_l00009ooooo`;o00001_ooool2o`0000?ooooo
0_l0001@ooooo`007?ooool00ol0003oooooooooo`13ooooo`;o000000?oooooo`000?l000002ooo
ool2o`0000?ooooo0_l00002ooooo`Co00000_ooool4o`0000;ooooo0_l000000ooooooo0000o`00
000Bo`0001Gooooo0_l000001Ooooooo0000o`000?l0003ooooo01co000000Coooooo`000?l0003o
oooo0_l00004ooooo`?o00004Oooool2o`0000Sooooo0_l00009ooooo`;o000000?oooooo`000?l0
00001_ooool5o`0004oooooo000Looooo`03o`000?oooooooooo03kooooo0_l000000ooooooo0000
o`000002o`0000;ooooo0_l00004ooooo`;o00001?ooool2o`000003ooooool0003o000000Cooooo
1?l00002ooooo`;o00000oooool=o`000003ooooool0003o000000So00001Oooool2o`0000Kooooo
0_l00006ooooo`[o000000?oooooo`000?l000001Ol000000ooooooo0000o`00000?o`0000;ooooo
0ol00003ooooo`?o00004Oooool3o`0000[ooooo0_l00004ooooo`;o00001?ooool2o`0000Kooooo
0_l000000ooooooo0000o`00001?ooooo`007?ooool00ol0003oooooooooo`0nooooo`;o000000?o
ooooo`000?l000001?ooool4o`0000;ooooo0_l00004ooooo`;o000000?oooooo`000?l000001_oo
ool2o`0000;ooooo0ol00002oooooaSo00001Oooool2o`0000;ooooo0_l00002ooooo`;o00002?oo
oolRo`0000;ooooo0ol00003ooooo`;o00001Oooool2o`0000Sooooo0_l000000ooooooo0000o`00
0003o`0000Sooooo0_l00004ooooo`;o00000oooool2o`000003ooooool0003o000001;ooooo0_l0
0014ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00002Oooool2o`0000;ooooo1?l0000;
ooooo`;o00001_ooool2o`0000?ooooo0_l00002oooooaSo00002Oooool2o`0000cooooo5ol00000
0ooooooo0000o`000007o`0000?ooooo0ol000000ooooooo0000o`000007ooooo`;o00001oooool4
o`000003ooooool0003o000000;o00004_ooool3o`000003ooooool0003o000001;ooooo0_l00014
ooooo`007?ooool00ol0003oooooooooo`0hooooo`Co00001oooool2o`0001?ooooo0_l00003oooo
o`Co00000_ooool2o`0000?ooooo6?l00007ooooo`;o00003OoooolQo`0000?ooooo0_l00002oooo
o`;o00001_ooool2o`0000Sooooo1?l0000Gooooo`;o0000G?ooool001cooooo00?o0000oooooooo
ool0>_ooool2o`0000Oooooo0_l0000@ooooo`;o000000?oooooo`000?l000000oooool4o`0000Go
oooo6_l00002ooooo`;o00000oooool2o`000003ooooool0003o000000?ooooo0_l00007ooooob7o
00001Oooool2o`0000Kooooo0_l00003ooooo`;o00005_ooool2o`0000Sooooo0_l00005ooooo`Co
00002_ooool2o`0004Gooooo000Looooo`03o`000?oooooooooo04?ooooo0_l0000@ooooo`;o0000
0_ooool2o`0000[ooooo6ol00002ooooo`?o00001Oooool2o`0000?ooooo0_l00002ooooo`;o0000
0_ooool5o`000003ooooool0003o000001[o00000oooool4o`0000_ooooo0_l00007ooooo`;o0000
1Oooool2o`0000;ooooo0_l00002ooooo`;o00002?ooool2o`0000Gooooo1?l0000:ooooo`;o0000
AOooool001cooooo00?o0000ooooooooool0@oooool3o`0000Oooooo0_l00003ooooo`;o00001Ooo
ool2o`000003ooooool0003o000000;o00001OoooolPo`0000kooooo0_l000000ooooooo0000o`00
000Qo`0000?ooooo0_l00005ooooo`;o00001_ooool2o`000004ooooool0003o0000o`0000?ooooo
0_l00005ooooo`;o00000_ooool2o`0000;ooooo0_l00006ooooo`;o00007?ooool2o`0003kooooo
000Looooo`03o`000?oooooooooo04;ooooo1?l00007ooooo`;o00000oooool2o`0000Sooooo1?l0
0006ooooo`Go000000?oooooo`000?l000004?l00002ooooo`Co00004?ooool6o`0000;ooooo6?l0
0002ooooo`?o00002_ooool2o`0000Wooooo0ol0000Booooo`;o00001_ooool2o`0001Wooooo0_l0
00000ooooooo0000o`00000nooooo`007?ooool00ol0003oooooooooo`12ooooo`;o00005Oooool2
o`0000kooooo6Ol0000Booooo`?o00000ooooolKo`000004ooooool0003o0000o`0000?ooooo0ol0
000Dooooo`;o00004oooool2o`000003ooooool0003o000001Wooooo0_l00011ooooo`007?ooool0
0ol0003oooooooooo`1Iooooo`;o00003?oooolKo`0001?ooooo0_l00003oooooa_o00001oooool3
o`0000;ooooo0_l0000;ooooo`;o00000oooool2o`0001?ooooo1Ol000001?oooooo0000o`000?oo
ool2o`0000Oooooo0_l0000>ooooo`;o0000?Oooool001cooooo00?o0000ooooooooool0G_ooool4
o`0000Gooooo5ol000000ooooooo0000o`000003ooooo`;o00006?oooolEo`0000?ooooo0_l00003
ooooo`;o00001?ooool2o`0000_ooooo0_l00008ooooo`;o00003oooool2o`0000?ooooo0_l00000
1?oooooo0000o`000?l00004ooooo`Co00000oooool2o`0000Wooooo0_l0000mooooo`007?ooool0
0ol0003oooooooooo`19ooooo`Go00002oooool2o`000003ooooool0003o000000Co00001_ooool2
o`000003ooooool0003o0000017o000000?oooooo`000?l000000oooool2o`0000[ooooo0_l0000=
ooooo`oo00002?ooool2o`0000?ooooo0_l0000@ooooo`;o00002Oooool2o`0000Kooooo0_l00004
ooooo`;o00001Oooool3o`0000;ooooo0_l00004ooooo`?o00001?ooool3o`0004Oooooo00001_oo
ooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?oo
ool00ol0003oooooooooo`0booooo`;o00002?ooool4o`0000Wooooo1Ol000000ooooooo0000o`00
0008ooooo`;o000000?oooooo`000?l000001?l00005ooooo`;o000000?oooooo`000?l000004Ol0
00000ooooooo0000o`000008ooooo`;o00001_ooool2o`0000Cooooo0_l00004ooooo`;o000000?o
ooooo`000?l000001?l00002ooooo`?o000000?oooooo`000?l000004oooool2o`0000Kooooo0_l0
0003ooooo`?o00004?ooool2o`0000?ooooo0ol000001Ooooooo0000o`000?l0003ooooo00Co0000
0_ooool2o`0000Cooooo0_l00004ooooo`Co0000A_ooool00006oooooomgMgOoV9RHoooooonHV9So
MgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Tooooo`;o
00003?ooool2o`0000Sooooo1?l00005ooooo`;o00000oooool2o`0000?ooooo0_l0000<ooooo`;o
000000Coooooo`000?l0003o00001?ooool2o`000003ooooool0003o000000go000000Goooooo`00
0?l0003o0000ooooo`02o`0000Sooooo0_l00008ooooo`;o00000_ooool2o`0000Cooooo0ol00002
ooooo`Co000000Coooooo`000?l0003o00000_ooool4o`00017ooooo0_l00006ooooo`;o00001?oo
ool2o`0000Sooooo0_l0000;ooooo`?o000000Coooooo`000?l0003o00000oooool2o`0000;ooooo
0_l00002ooooo`?o00001oooool2o`0004Kooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oo
oooooooo00Wooooo1Ol00006ooooo`03o`000?oooooooooo02Cooooo0_l0000Eooooo`;o00000_oo
ool2o`0000Cooooo1?l00007ooooo`;o00002Oooool2o`0000Cooooo0_l00007ooooo`oo00000_oo
ool2o`00013ooooo0_l00003ooooo`;o00002Oooool2o`0000Cooooo0_l000000ooooooo0000o`00
0003ooooo`Co00001oooool2o`00013ooooo0_l00002ooooo`;o00002_ooool2o`0000[ooooo1?l0
000?ooooo`?o000000?oooooo`000?l00000C?ooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool02Oooool01?m4A4CogMgMooooool00007ooooo`?o0000>oooool2o`0000;ooooo0_l0
0005ooooo`?o00001oooool2o`0000Wooooo0_l000000ooooooo0000o`000004ooooo`;o00001_oo
ool<o`000004ooooool0003o0000o`0000;ooooo0_l0000=ooooo`;o00007Oooool3o`0000Gooooo
1?l0000@ooooo`So00001Oooool2o`0000Oooooo0_l00004ooooo`Ko00004Oooool2o`0004cooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CogMgMoeEEEOoooooo0000
1oooool00ol0003oooooooooo`0Uooooo`;o00004?ooool2o`0000;ooooo0_l0000Kooooo`;o0000
0_ooool4o`0000Cooooo0_l000000ooooooo0000o`000005ooooo`Ko000000Goooooo`000?l0003o
0000ooooo`03o`0000;ooooo0_l0000<ooooo`;o00009_ooool2o`0000gooooo0_l00005ooooo`Ko
00001Oooool4o`0000Gooooo0ol00006ooooo`Co00001oooool2o`0000?ooooo0_l00002ooooo`;o
00005_ooool2o`0003Cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo
00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0Uooooo`;o00004?ooool2o`0000;ooooo
0_l00008ooooo`;o00003?ooool2o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l00000
1_ooool2o`0000Gooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00001?ooool2o`0000co
oooo0_l000000ooooooo0000o`000004ooooo`;o00009oooool:o`0000Kooooo0ol00005ooooo`Ko
00001_ooool2o`0000Cooooo2_l00002ooooo`?o00000oooool2o`0000?ooooo0_l0000Eooooo`;o
00000_ooool2o`0000Wooooo0_l0000Uooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<oooo
o`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0;oooool2o`0000kooooo1?l000001?oo
oooo0000o`000?l0000<ooooo`;o00002_ooool2o`0000Cooooo1?l0000;ooooo`;o00001Oooool2
o`000003ooooool0003o000000Cooooo0_l00003ooooo`;o00001oooool2o`0000Oooooo0_l0000N
ooooo`So00002?ooool2o`0000Kooooo1?l00007ooooo`?o00001?ooool2o`000004ooooool0003o
0000ooooo`Co00000_ooool6o`0000Gooooo0_l0000Iooooo`;o00002Oooool2o`0002Gooooo0000
1_ooooook^k^oc8b<_l0003o<S8bonk^kPgooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooo
ooooo`0_ooooo`Co00000_ooool2o`0000Sooooo1?l000000ooooooo0000o`000004ooooo`;o0000
2oooool2o`0000Cooooo0_l00006ooooo`Co00002oooool2o`0000Sooooo0_l00004ooooo`?o0000
5?ooool2o`0001Oooooo0_l00005ooooo`;o00001oooool2o`0000Cooooo0ol00006ooooo`;o0000
2Oooool2o`0000Sooooo1?l00005ooooo`Ko00001Oooool2o`0004_ooooo000Looooo`03o`000?oo
oooooooo037ooooo0_l00002ooooo`;o00001Oooool2o`0000?ooooo1?l00005ooooo`;o00000_oo
ool2o`0000Oooooo0_l000000ooooooo0000o`000005o`000004ooooool0003o0000o`0000?ooooo
1?l00003ooooo`?o00002?ooool2o`000004ooooool0003o0000o`0000Gooooo0_l00002ooooo`;o
00000oooool2o`0000gooooo0_l0000Eooooo`;o00003_ooool2o`0000Cooooo1?l000001?oooooo
0000o`000?ooool2o`0000Cooooo0_l00007ooooo`;o00000oooool2o`0000;ooooo0_l00005oooo
o`;o00001?ooool2o`00053ooooo000Looooo`03o`000?oooooooooo03Gooooo0_l00004ooooo`?o
00000oooool4o`0000Oooooo1?l00005ooooo`;o000000?oooooo`000?l000000ol000001Ooooooo
0000o`000?l0003ooooo00Co00000_ooool4o`000003ooooool0003o000000?o00002?ooool2o`00
0003ooooool0003o000000;ooooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo0_l00002oooo
o`;o00000oooool2o`0000Cooooo0_l0000Nooooo`;o00000oooool2o`0000Gooooo0_l000001?oo
oooo0000o`000?ooool>o`0000Cooooo0_l00002ooooo`Go00002oooool6o`0004kooooo000Loooo
o`03o`000?oooooooooo03Oooooo0_l000001?oooooo0000o`000?l00004ooooo`Co00001oooool2
o`0000Oooooo0_l000000ooooooo0000o`000008ooooo`Co000000?oooooo`000?l000001?ooool2
o`00013ooooo1?l00002ooooo`?o00002_ooool2o`0000?ooooo0_l0000Pooooo`;o00000_ooool2
o`000003ooooool0003o000000;o00001OoooolDo`000003ooooool0003o000000Gooooo0_l00000
1?oooooo0000o`000?l00003ooooo`;o00001Oooool6o`0004kooooo000Looooo`03o`000?oooooo
oooo03Oooooo0_l000000ooooooo0000o`000007ooooo`;o00002_ooool2o`0000oooooo0_l00005
ooooo`;o00004_ooool2o`0000;ooooo0_l00004ooooo`?o00002?ooool2o`0000?ooooo0_l0000E
ooooo`;o00002oooool2o`0000Gooooo0_l00005ooooo`;o000000?oooooo`000?l000003_l00004
ooooo`;o00000oooool2o`0000?ooooo0ol00003ooooo`;o00000oooool2o`0000Cooooo0_l0001>
ooooo`007?ooool00ol0003oooooooooo`0fooooo`;o00001Oooool2o`00013ooooo0_l0000?oooo
o`?o00001?ooool3o`00017ooooo0_l0000;ooooo`;o00001_ooool2o`0000?ooooo0ol0000Doooo
o`;o00003_ooool4o`0000Oooooo4ol000000ooooooo0000o`000003o`0000?ooooo0_l00004oooo
o`;o00002?ooool2o`0000Cooooo0_l00005ooooo`;o0000Aoooool001cooooo00?o0000oooooooo
ool0=_ooool2o`0000Gooooo0_l0000=ooooo`;o000000?oooooo`000?l000000_ooool2o`0000co
oooo0_l00004ooooo`Co000000Coooooo`000?l0003o00004Oooool4o`0000Cooooo0_l00006oooo
o`;o00000oooool3o`0000Cooooo1Ol000000ooooooo0000o`00000:ooooo`;o00001Oooool2o`00
00Gooooo1?l00002ooooo`Co000000?oooooo`000?l000006Ol0000Mooooo`?o0000Aoooool001co
oooo00?o0000ooooooooool0<?ooool2o`0000cooooo0_l00004ooooo`;o00000oooool5o`000003
ooooool0003o000000Co00005?ooool2o`000004ooooool0003o0000o`0000[ooooo0_l00005oooo
o`Co00001?ooool2o`0000_ooooo0_l00003ooooo`Oo000000?oooooo`000?l000002_ooool2o`00
00Cooooo1?l00004ooooo`;o00001?ooool4o`000003ooooool0003o000000[o000000?oooooo`00
0?l000001_l000000ooooooo0000o`000004o`0000Kooooo0_l0000Dooooo`Co0000A_ooool001co
oooo00?o0000ooooooooool0<?ooool2o`000003ooooool0003o000000Wooooo0_l00004ooooo`;o
00000oooool5o`0000?ooooo2?l0000Nooooo`Co00003Oooool4o`0000kooooo0_l00004ooooo`;o
000000?oooooo`000?l000001Oooool2o`0000Sooooo1?l00004ooooo`;o00001_oooolQo`0000Co
oooo0_l00005ooooo`?o000000?oooooo`000?l000001oooool6o`0004Kooooo000Looooo`03o`00
0?oooooooooo03?ooooo0_l0000Gooooo`;o00001Oooool6o`0000;ooooo0_l0000Cooooo`;o0000
00?oooooo`000?l000000_ooool2o`0000oooooo1?l0000Dooooo`;o000000?oooooo`000?l00000
1Oooool2o`0000cooooo0_l00003ooooo`;o00001OoooolQo`0000_ooooo0ol000000ooooooo0000
o`000002o`0000Gooooo1?l00018ooooo`007?ooool00ol0003oooooooooo`0iooooo`;o00008?oo
ool2o`0000Sooooo0_l00005ooooo`;o00000_ooool2o`000003ooooool0003o000001;ooooo0ol0
000Oooooo`;o00003Oooool2o`0000?ooooo0ol00005ooooo`?o00000_oooolKo`00017ooooo0_l0
001Aooooo`007?ooool00ol0003oooooooooo`0iooooo`?o00004oooool2o`0001?ooooo1Ol00003
ooooo`;o00001_ooool2o`0000Wooooo0_l00006ooooo`;o00000_ooool3o`0001_ooooo0_l0000=
ooooo`Co00000_ooool3o`0000?ooooo4?l000000ooooooo0000o`00000:o`0000;ooooo0_l0000G
ooooo`;o0000Boooool001cooooo0_l0000fooooo`;o00000oooool2o`0000Gooooo0_l0000<oooo
o`Co00000oooool6o`0000Sooooo1Ol00004ooooo`;o00001Oooool2o`0000Wooooo0_l00003oooo
o`?o00001?ooool4o`0000Gooooo0_l00007ooooo`;o00004?ooool2o`0000Wooooo0_l00002oooo
o`?o00000_oooolPo`0001Wooooo0_l00006ooooo`;o0000@oooool001cooooo00?o0000oooooooo
ool0;oooool2o`0000Cooooo0_l00003ooooo`;o00001Oooool2o`0000Cooooo0_l00008ooooo`;o
00000oooool6o`000004ooooool0003o0000o`0000Kooooo0_l00005ooooo`;o00001?ooool2o`00
00oooooo0ol000000ooooooo0000o`000002ooooo`Go000000?oooooo`000?l000000_l000001?oo
oooo0000o`000?ooool2o`000003ooooool0003o0000013ooooo0_l0000=ooooo`?o00000_ooool3
o`000003ooooool0003o000001_o00008?ooool2o`0004?ooooo000Looooo`03o`000?oooooooooo
02oooooo0_l00004ooooo`;o00000oooool2o`0000_ooooo0_l00008ooooo`Oo00001Oooool3o`00
00gooooo0_l00004ooooo`;o00002Oooool2o`0000Sooooo0_l00005ooooo`;o000000?oooooo`00
0?l000000_ooool6o`000003ooooool0003o000000_ooooo0_l00007ooooo`Co00001oooool2o`00
00Oooooo4Ol000000ooooooo0000o`000009o`0000;ooooo0_l0000@ooooo`;o000000?oooooo`00
0?l00000C?ooool001cooooo00?o0000ooooooooool0;oooool2o`0000Cooooo0_l0000Iooooo`So
00001oooool2o`0000Oooooo0_l000000ooooooo0000o`000006ooooo`;o00001oooool4o`0000Ko
oooo0_l0000>ooooo`Co00000oooool2o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0000Oo
oooo1?l00003ooooo`;o00002ooooolBo`000003ooooool0003o000000co00001_ooool2o`0000;o
oooo0_l00004ooooo`;o000000?oooooo`000?l00000C?ooool001cooooo00?o0000ooooooooool0
;_ooool2o`00023ooooo0_l00003ooooo`?o00001oooool2o`0000Oooooo0_l000000ooooooo0000
o`000002o`0000gooooo0_l000000ooooooo0000o`000005ooooo`;o00004?ooool2o`0000Oooooo
0_l00002ooooo`?o00001Oooool2o`0000_ooooo0_l00002ooooo`;o00001_oooolTo`0000Cooooo
0_l00002ooooo`;o00001?ooool2o`0000;ooooo0_l00009ooooo`;o0000@?ooool001cooooo00?o
0000ooooooooool0;_ooool2o`0001;ooooo0_l0000<ooooo`;o00003?ooool2o`0000gooooo0_l0
0007ooooo`;o00001_ooool3o`000003ooooool0003o000000;ooooo0_l00009ooooo`;o00004ooo
ool2o`0000Cooooo1Ol0000=ooooo`;o00001?oooolOo`0000;ooooo1Ol000000ooooooo0000o`00
0007ooooo`;o000000?oooooo`000?l000000oooool2o`0000Wooooo0_l00007ooooo`;o0000=ooo
ool001cooooo00?o0000ooooooooool0=_ooool2o`0000?ooooo0_l00004ooooo`?o00003?ooool2
o`0000Wooooo0_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l000003_ooool4
o`0000Cooooo0ol000000ooooooo0000o`000008ooooo`;o00000oooool2o`0000Sooooo0_l00009
ooooo`;o00001?ooool2o`000003ooooool0003o000000Cooooo0_l00005ooooo`;o00000oooool2
o`000004ooooool0003o0000oooooaco00000_ooool4o`0000;ooooo0_l00007ooooo`;o000000?o
ooooo`000?l000002Oooool2o`0000cooooo0_l0000gooooo`007?ooool00ol0003oooooooooo`0f
ooooo`;o00000oooool2o`0000Cooooo0_l0000Fooooo`Co00000_ooool3o`000004ooooool0003o
0000ooooo`;o00001?ooool4o`0000Oooooo0ol000000ooooooo0000o`000002ooooo`;o00001ooo
ool2o`0000;ooooo0_l0000;ooooo`Co00002Oooool2o`0000gooooo0_l00005ooooo`;o00000_oo
ool3o`0000Gooooo0ol000000ooooooo0000o`00000@o`000003ooooool0003o000000;o00000_oo
ool4o`0000?ooooo0_l0000:ooooo`;o000000?oooooo`000?l000001Oooool2o`0004Gooooo000L
ooooo`03o`000?oooooooooo05Wooooo0_l00003ooooo`Co00002_ooool4o`0000Kooooo0_l00003
ooooo`;o00000_ooool2o`0000Oooooo0_l00004ooooo`;o00002Oooool2o`0000gooooo0_l00000
1?oooooo0000o`000?ooool2o`00013ooooo0_l00006ooooo`?o000000?oooooo`000?l000005?l0
0002ooooo`;o00000_ooool2o`0000;ooooo0_l00005ooooo`;o00000oooool5o`0000Gooooo0_l0
000;ooooo`Co0000=_ooool001cooooo00?o0000ooooooooool0@?ooool4o`0001[ooooo0_l0000F
ooooo`;o00001Oooool2o`0000;ooooo0_l0000:ooooo`?o00001_ooool2o`0000?ooooo0_l0000;
ooooo`;o000000Coooooo`000?l0003ooooo0_l0000Eooooo`Co00000ooooolGo`000003ooooool0
003o000000;ooooo0_l00009ooooo`Co000000Coooooo`000?l0003o00000_ooool2o`00013ooooo
1_l0000dooooo`007?ooool00ol0003oooooooooo`10ooooo`Co00005?ooool4o`0000Sooooo0_l0
000Cooooo`;o00000_ooool2o`000004ooooool0003o0000o`0000Kooooo0_l00002ooooo`;o0000
1oooool2o`0000?ooooo0_l00008ooooo`;o00000_ooool6o`0000kooooo1Ol00003ooooo`Co0000
0ooooolGo`000003ooooool0003o000000?ooooo0_l00008ooooo`Co00001_ooool2o`0000Oooooo
0_l000000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l000001_ooool2o`0002cooooo
000Looooo`03o`000?oooooooooo03Sooooo0_l00006ooooo`;o00003Oooool2o`0000Oooooo1?l0
0003ooooo`;o00000oooool3o`00013ooooo1?l00005ooooo`?o00001_ooool3o`0000[ooooo0_l0
000:ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l0000;ooooo`[o00001ooo
ool2o`0000Cooooo4?l00003ooooo`;o00000oooool2o`0001?ooooo0_l00006ooooo`Go00004?oo
ool2o`0002cooooo000Looooo`03o`000?oooooooooo02_ooooo0_l0000;ooooo`;o00001Oooool2
o`0000kooooo0_l0000;ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Sooooo0_l00003
ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`000003ooooool0003o000000?o00001ooo
ool2o`0000?ooooo0_l00005ooooo`;o00002_ooool2o`0001?ooooo0_l000000ooooooo0000o`00
0002o`0000;ooooo1_l00005ooooo`;o00001?ooool5o`000003ooooool0003o000000So00000_oo
ool3o`0001Sooooo1?l00006ooooo`;o0000?oooool001cooooo00?o0000ooooooooool0:oooool2
o`0000Cooooo0_l00005ooooo`?o000000Coooooo`000?l0003ooooo0_l0000?ooooo`;o00002_oo
ool2o`0000?ooooo0_l0000<ooooo`;o00000_ooool3o`0000Gooooo0_l000000ooooooo0000o`00
0002o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l000002_ooool4o`0000Gooooo0_l0
000=ooooo`;o00000_ooool2o`0000Gooooo1?l00002ooooo`;o00001?ooool2o`0000Kooooo0ol0
0002ooooo`;o00000oooool2o`0000Gooooo1?l00004ooooo`;o000000?oooooo`000?l000004?oo
ool2o`0004Oooooo000Looooo`03o`000?oooooooooo037ooooo0_l00006ooooo`;o000000?ooooo
o`000?l000000ol0000?ooooo`;o00002_ooool2o`0000?ooooo0_l000000ooooooo0000o`000005
ooooo`;o00001Oooool3o`00017ooooo0_l00002ooooo`Co000000?oooooo`000?l000002_ooool4
o`0000?ooooo1_l00009ooooo`Co00002Oooool2o`0000;ooooo0_l00006ooooo`;o00004?ooool2
o`0000Gooooo1?l00002ooooo`Co000000?oooooo`000?l000006?ooool2o`0003oooooo000Loooo
o`03o`000?oooooooooo02cooooo1?l00006ooooo`;o00001Oooool4o`0001_ooooo0_l00002oooo
o`;o00000_ooool2o`000003ooooool0003o000000Co00001Oooool2o`0000;ooooo0_l0000Boooo
o`Co000000?oooooo`000?l000001Oooool2o`0000[ooooo1_l00009ooooo`Co00001_ooool3o`00
00Cooooo0_l0000=ooooo`;o00002_ooool2o`0000?ooooo0ol00003ooooo`?o00001Oooool4o`00
00kooooo0_l00004ooooo`;o0000?oooool001cooooo0_l0000]ooooo`Co00000oooool5o`0001co
oooo0_l00003ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Gooooo1?l00003ooooo`;o
00000oooool2o`000003ooooool0003o000001Cooooo0_l00004ooooo`;o00000_ooool4o`0000ko
oooo0ol00005ooooo`;o00002Oooool3o`0000[ooooo0_l00007ooooo`;o00000_ooool5o`000003
ooooool0003o000000Co000000?oooooo`000?l000000ol000000ooooooo0000o`000005ooooo`Go
000000?oooooo`000?l000002oooool2o`0000Gooooo0_l00002ooooo`;o0000>_ooool001cooooo
00?o0000ooooooooool0;Oooool2o`0000Cooooo1?l00003ooooo`;o00004Oooool2o`0000Gooooo
0_l00003ooooo`?o00002oooool2o`0000Gooooo0_l00003ooooo`;o00001?ooool2o`000003oooo
ool0003o000000Wooooo0_l00008ooooo`?o00001?ooool2o`0000Oooooo0ol00003ooooo`Co0000
1Oooool2o`0000Cooooo0_l0000@ooooo`Co00002?ooool6o`000005ooooool0003o0000o`000?oo
ool00_l00004ooooo`;o00002?ooool2o`000004ooooool0003o0000ooooo`;o00003Oooool2o`00
00?ooooo0_l00002ooooo`;o00002Oooool2o`0000;ooooo0_l0000[ooooo`007?ooool00ol0003o
ooooooooo`0]ooooo`;o00001Oooool3o`0000?ooooo0_l0000>ooooo`;o000000?oooooo`000?l0
00001Oooool4o`0000;ooooo0_l0000=ooooo`;o00003_ooool5o`0000Wooooo1?l00006ooooo`?o
00001?ooool2o`0000?ooooo0_l00002ooooo`?o00000_ooool4o`0000Gooooo0_l00005ooooo`;o
00004?ooool4o`0000?ooooo0_l00003ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`00
00Wooooo0_l0000=ooooo`;o00000_ooool2o`0000;ooooo1_l0000Booooo`;o00000_ooool2o`00
02_ooooo000Looooo`03o`000?oooooooooo03Cooooo0_l000000ooooooo0000o`00000Aooooo`;o
00001Oooool2o`0000?ooooo0_l00005ooooo`;o00000oooool2o`0000Gooooo1?l00004ooooo`?o
00001_ooool3o`0000Wooooo0_l000000ooooooo0000o`000003ooooo`;o000000?oooooo`000?l0
00000ol00002ooooo`;o00000oooool2o`0000Oooooo1?l00005ooooo`;o00005oooool3o`0000Co
oooo0_l00003ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`0000Wooooo0_l0000;oooo
o`Co000000Coooooo`000?l0003o00000_ooool4o`0000gooooo0_l0000fooooo`007?ooool00ol0
003oooooooooo`0cooooo`;o00000_ooool2o`0000?ooooo1?l0000Aooooo`?o00002Oooool2o`00
00?ooooo0_l00002ooooo`;o00000oooool2o`0000Cooooo0ol0000<ooooo`?o00000oooool4o`00
0003ooooool0003o000000?o00001?ooool2o`0001;ooooo0_l00009ooooo`;o00003Oooool2o`00
00Gooooo0_l00004ooooo`;o00000oooool2o`0000kooooo0ol0000?ooooo`;o00000_ooool3o`00
01Cooooo0_l0000fooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o00001?ooool3o`0000Oo
oooo1?l0000<ooooo`;o00001?ooool2o`0000Wooooo0_l00007ooooo`;o000000?oooooo`000?l0
00003?ooool2o`0000Oooooo0ol00005ooooo`Ko00004Oooool2o`0000Oooooo0ol00008ooooo`;o
000000?oooooo`000?l000002_ooool2o`0000Gooooo0_l00004ooooo`;o000000?oooooo`000?l0
00000_l00003ooooo`;o00002Oooool4o`0001;ooooo0_l00004ooooo`;o0000Aoooool001cooooo
00?o0000ooooooooool0;?ooool2o`0000Cooooo0_l00008ooooo`Co00003?ooool4o`000004oooo
ool0003o0000o`0000Cooooo0_l00003ooooo`;o00001oooool5o`0000cooooo2?l000000ooooooo
0000o`000002o`0000Kooooo0ol0000Booooo`;o00000oooool2o`0000?ooooo0_l0000;ooooo`;o
00005_ooool2o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`0000Oooooo0_l0000Hooooo`;o
00001_ooool2o`0003oooooo000Looooo`03o`000?oooooooooo03Oooooo0ol000000ooooooo0000
o`000003o`0000Gooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l00000
0ol00002ooooo`?o00002oooool4o`0000Sooooo0_l00005ooooo`Ko000000?oooooo`000?l00000
0_l00002ooooo`;o00000_ooool2o`0000kooooo0_l00008ooooo`;o00000oooool2o`0000kooooo
0ol0000Booooo`Co00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`0001Wooooo
0ol000000ooooooo0000o`000006ooooo`;o00007?ooool2o`00027ooooo000Looooo`03o`000?oo
oooooooo03;ooooo0_l00003ooooo`?o000000?oooooo`000?l000002?ooool2o`000003ooooool0
003o000000Cooooo0_l00004ooooo`;o00000_ooool3o`0001Oooooo0_l00003ooooo`Go00001?oo
ool3o`000003ooooool0003o000000;o00000_ooool4o`0000cooooo0_l00006ooooo`;o00003Ooo
ool3o`0000?ooooo1Ol0000<ooooo`;o00001?ooool4o`0000;ooooo0_l00003ooooo`;o00001_oo
ool2o`0000Gooooo0_l0000Booooo`?o000000?oooooo`000?l000001?ooool2o`0001kooooo0_l0
000Qooooo`007?ooool00ol0003oooooooooo`0booooo`;o00001?ooool2o`0000Gooooo1?l0000;
ooooo`;o00002?ooool2o`0000?ooooo0_l00007ooooo`;o00002oooool2o`0000;ooooo1Ol00002
ooooo`Go000000?oooooo`000?l000001_ooool3o`0001?ooooo0_l0000=ooooo`?o00000_ooool3
o`000003ooooool0003o000000?ooooo0_l00007ooooo`;o00002_ooool2o`0001;ooooo0_l0000F
ooooo`;o00001?ooool2o`0001Wooooo0_l0000Vooooo`007?ooool00ol0003oooooooooo`0]oooo
o`;o00004?ooool4o`0001[ooooo0ol00006ooooo`;o00000oooool2o`0000;ooooo3?l00002oooo
o`Ko00001Oooool7o`0000;ooooo0_l0000Pooooo`;o000000?oooooo`000?l000000_ooool4o`00
0003ooooool0003o000000oooooo0_l000000ooooooo0000o`00000;ooooo`;o00005_ooool4o`00
00Kooooo0_l0000Mooooo`;o00009_ooool001cooooo00?o0000ooooooooool0;Oooool2o`0001_o
oooo0_l00004ooooo`;o00003?ooool2o`000003ooooool0003o000000Sooooo0_l00002ooooo`co
000000?oooooo`000?l000004Ol00002ooooo`;o00000_ooool2o`0001cooooo0_l00003ooooo`;o
00000_ooool2o`000004ooooool0003o0000ooooo`;o00000oooool2o`0000Oooooo0_l000001?oo
oooo0000o`000?ooool2o`0000Sooooo0_l0000Fooooo`Co00001_ooool2o`0000_ooooo0_l0000h
ooooo`007?ooool00ol0003oooooooooo`0_ooooo`Go00001_ooool2o`0000;ooooo0_l0000:oooo
o`;o00001?ooool2o`0000oooooo0_l000000ooooooo0000o`00000:ooooo`_o000000?oooooo`00
0?l000003ol00004ooooo`;o00000_ooool2o`0001Cooooo0_l00008ooooo`;o000000?oooooo`00
0?l000001?ooool2o`0000;ooooo1?l000000ooooooo0000o`000006ooooo`;o00000oooool4o`00
00Cooooo0_l000000ooooooo0000o`00000Gooooo`Co00004_ooool3o`0000Oooooo0_l0000_oooo
o`007?ooool00ol0003oooooooooo`0/ooooo`So00000oooool2o`000003ooooool0003o000000;o
oooo0_l0000Hooooo`;o00002_ooool2o`0000[ooooo8Ol00002ooooo`So00004?ooool2o`0000So
oooo0_l00004ooooo`;o000000?oooooo`000?l000001?ooool2o`0000Kooooo0_l000000ooooooo
0000o`000002ooooo`Go00001?ooool2o`000003ooooool0003o000001Kooooo0_l0000Eooooo`;o
00001_ooool4o`0002oooooo000Looooo`03o`000?oooooooooo02[ooooo1Ol00002ooooo`;o0000
1?ooool2o`0000Cooooo0ol0000=ooooo`;o00000_ooool2o`0000Gooooo0_l000000ooooooo0000
o`00000<ooooo`;o00001Oooool2o`000003ooooool0003o000000?o00000_oooolBo`000003oooo
ool0003o000000;o00000_ooool8o`00023ooooo0_l00003ooooo`;o00001Oooool2o`0000?ooooo
0_l00005ooooo`?o00001_ooool2o`0001Wooooo0_l0000Booooo`;o00002Oooool2o`00037ooooo
000Looooo`03o`000?oooooooooo02[ooooo0_l00008ooooo`;o00000oooool2o`0000;ooooo0ol0
0005ooooo`;o00001_ooool3o`000003ooooool0003o000000Sooooo0_l00002ooooo`;o00002?oo
ool2o`0000Cooooo0ol00002ooooo`;o000000Coooooo`000?l0003ooooo6Ol000001?oooooo0000
o`000?l0000Hooooo`;o00003oooool2o`0000Gooooo0_l00008ooooo`Co00003Oooool2o`000004
ooooool0003o0000o`0000Oooooo0_l000000ooooooo0000o`000003ooooo`Go00001oooool2o`00
00Kooooo1?l0000jooooo`007?ooool2o`0003Gooooo0_l00003ooooo`;o00001oooool2o`000003
ooooool0003o000000Oooooo0_l0000:ooooo`;o00000oooool2o`0000Wooooo0_l000000ooooooo
0000o`000002o`0000;ooooo1_l000000ooooooo0000o`00000Ko`000003ooooool0003o000000;o
00003oooool3o`000003ooooool0003o000000oooooo0_l0000?ooooo`Co00001oooool2o`0000Co
oooo0_l000001?oooooo0000o`000?l00007ooooo`;o000000?oooooo`000?l000000_l000000ooo
oooo0000o`000003o`0000?ooooo0_l00002ooooo`;o00001_ooool4o`000003ooooool0003o0000
00Sooooo0_l0000]ooooo`007?ooool00ol0003oooooooooo`0/ooooo`;o000000?oooooo`000?l0
00000_ooool2o`0000gooooo0_l0000Aooooo`;o00000oooool2o`000003ooooool0003o000000;o
00000_ooool2o`0000?ooooo2Ol00002ooooo`Oo000000?oooooo`000?l000004Ol00002ooooo`Go
00000_ooool5o`0000;ooooo0_l0000;ooooo`?o00000_ooool2o`0000?ooooo0_l00003ooooo`;o
00001?ooool2o`00017ooooo0_l00007ooooo`;o00002?ooool2o`0000Oooooo0_l00003ooooo`;o
000000?oooooo`000?l000000oooool2o`000003ooooool0003o000000Wooooo1Ol000000ooooooo
0000o`000006ooooo`Co0000;Oooool001cooooo00?o0000ooooooooool0;?ooool2o`000003oooo
ool0003o000000;ooooo0_l00006ooooo`;o00003_ooool2o`0000Sooooo0_l00006ooooo`Co0000
0_ooool2o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000000oooool2o`000003oooo
ool0003o000000ko00000_ooool@o`0000Gooooo0_l0000;ooooo`;o00000oooool2o`0000?ooooo
1ol0000Eooooo`;o00001oooool2o`0000gooooo0_l0000>ooooo`;o000000?oooooo`000?l00000
1?ooool2o`0000Kooooo0_l000000ooooooo0000o`000009ooooo`;o0000;oooool001cooooo00?o
0000ooooooooool0:oooool2o`0000Wooooo0_l00003ooooo`;o00003_ooool2o`0000Sooooo0_l0
0008ooooo`;o00001oooool2o`0000Gooooo:Ol00006ooooo`;o00002oooool2o`0000Oooooo0_l0
00001?oooooo0000o`000?l00004ooooo`;o00002Oooool2o`0000Gooooo0ol00007ooooo`;o0000
1Oooool2o`0000Kooooo0_l00009ooooo`Oo00000oooool2o`0000;ooooo0_l00015ooooo`007?oo
ool00ol0003oooooooooo`0[ooooo`;o00001Oooool2o`000004ooooool0003o0000o`0001gooooo
0_l0000=ooooo`;o00002OoooolPo`000003ooooool0003o000000?o00001?ooool3o`0000oooooo
0_l00007ooooo`;o00002?ooool2o`0000Wooooo0ol00004ooooo`;o00002oooool2o`0000;ooooo
0_l00005ooooo`;o00002_ooool5o`0000Gooooo0_l00008ooooo`;o0000?oooool001cooooo00?o
0000ooooooooool0<_ooool2o`000003ooooool0003o000000[ooooo0_l0000<ooooo`;o00002?oo
ool8o`0000?ooooo0_l00009ooooobgo00002?ooool2o`0001Kooooo0_l00004ooooo`;o00000_oo
ool2o`0000;ooooo0_l00005ooooo`;o00001?ooool2o`0000Cooooo0_l00009ooooo`;o00002Ooo
ool2o`00017ooooo1?l00005ooooo`;o0000>?ooool001cooooo00?o0000ooooooooool0<Oooool3
o`0000cooooo1_l00009ooooo`;o00002?ooool=o`0000?ooooo0_l000000ooooooo0000o`00000[
o`0000_ooooo0_l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000002oooool3
o`0000Cooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0ol00002ooooo`Co000000Co
ooooo`000?l0003o00001?ooool2o`0000[ooooo0_l00008ooooo`;o00000_ooool4o`0000_ooooo
0_l000000ooooooo0000o`000004ooooo`;o00001?ooool2o`0003;ooooo000Looooo`03o`000?oo
oooooooo037ooooo0ol0000<ooooo`Ko00005_ooool2o`0000;ooooo1_l00003ooooo`;o000000?o
ooooo`000?l000004?l000000ooooooo0000o`00000Eo`0000Cooooo0_l00007ooooo`;o00000_oo
ool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`?o00001_ooool3o`0000_ooooo0_l0
00001?oooooo0000o`000?l00004ooooo`;o000000Coooooo`000?l0003o00004?ooool2o`0000co
oooo1?l00002ooooo`;o00001_ooool2o`0000;ooooo0_l00003ooooo`;o00001Oooool3o`00037o
oooo000Looooo`03o`000?oooooooooo04;ooooo0_l0000Dooooo`;o00000_ooool2o`0000Oooooo
0ol000000ooooooo0000o`00000Do`000003ooooool0003o000001Co00001?ooool6o`0000?ooooo
0_l00005ooooo`;o00000oooool2o`000004ooooool0003o0000o`0000Oooooo0_l00006ooooo`;o
000000?oooooo`000?l000001?l00005ooooo`;o00000oooool2o`0000Oooooo0_l000001?oooooo
0000o`000?ooool2o`0001Gooooo0_l00006ooooo`;o00001oooool2o`0000Kooooo0_l0000aoooo
o`007?ooool00ol0003oooooooooo`12ooooo`;o000000?oooooo`000?l000001Oooool2o`0000[o
oooo0_l00005ooooo`Go000000Goooooo`000?l0003o0000ooooo`06o`0000;ooooo9Ol00006oooo
o`Co00002_ooool4o`000003ooooool0003o000001?ooooo0_l000000ooooooo0000o`000004o`00
00Gooooo0_l0000<ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`00000C
ooooo`;o00006?ooool2o`0002oooooo000Looooo`03o`000?oooooooooo047ooooo0ol000000ooo
oooo0000o`000005ooooo`;o00003oooool8o`0000?ooooo0ol00002ooooo`;o000000?oooooo`00
0?l000007_l000000ooooooo0000o`000005o`0000_ooooo0_l00007ooooo`?o00001_ooool2o`00
0003ooooool0003o000000Wo000000?oooooo`000?l000000_ooool2o`0000_ooooo0_l0000;oooo
o`Co00000oooool4o`0000[ooooo0_l00004ooooo`Co00000_ooool2o`0000?ooooo0_l0000<oooo
o`Co0000;oooool001cooooo00?o0000ooooooooool0<?ooool3o`0000Cooooo0_l00006ooooo`Co
00006_ooool2o`0000;ooooo1?l00002ooooo`Co000000?oooooo`000?l00000:_l000000ooooooo
0000o`000002o`0000Kooooo1?l00006ooooo`;o00001?ooool4o`000003ooooool0003o000000co
00000_ooool2o`0000?ooooo0_l00006ooooo`;o00002_ooool5o`0000Gooooo0_l0000:ooooo`;o
00001?ooool4o`0000;ooooo0_l00003ooooo`?o00002oooool2o`00037ooooo000Looooo`03o`00
0?oooooooooo02oooooo1?l00004ooooo`;o00000_ooool2o`0000;ooooo1?l0000?ooooo`;o0000
3Oooool4o`0000;ooooo0_l00002ooooo`Oo000000?oooooo`000?l000003?l000000ooooooo0000
o`000003o`000003ooooool0003o000000ko000000?oooooo`000?l000001Ol00005ooooo`;o0000
1?ooool2o`0000Kooooo0ol00002oooooa7o00001?ooool2o`0000_ooooo0_l00003ooooo`Co0000
00?oooooo`000?l000002oooool3o`00017ooooo0_l00002ooooo`;o0000?_ooool001cooooo00?o
0000ooooooooool0;oooool3o`0000Wooooo0_l0000<ooooo`;o00001oooool3o`0000kooooo0_l0
0006ooooo`?o000000?oooooo`000?l000003_l000000ooooooo0000o`00000Ho`000003ooooool0
003o000000?o00001Oooool2o`0000Cooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l0
0002ooooo`_o000000?oooooo`000?l000000ol000000ooooooo0000o`00000:ooooo`;o00000_oo
ool2o`0000?ooooo0_l0000=ooooo`;o000000?oooooo`000?l000000ol0000?ooooo`;o00004Ooo
ool2o`0002oooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^
k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0_ooooo`;o00004_ooool2o`0000;o
oooo1?l00008ooooo`;o00005oooool2o`000003ooooool0003o000000go00000_oooolOo`0000oo
oooo1?l00004ooooo`[o000000?oooooo`000?l000002Ol0000:ooooo`Co00005?ooool2o`0000?o
oooo0ol0000Iooooo`;o00001oooool2o`0002oooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMg
M`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0_
ooooo`;o00002Oooool2o`0000Oooooo0_l00002ooooo`;o00002_ooool2o`0000?ooooo0_l00009
ooooo`;o00001oooool2o`000003ooooool0003o000000ko000000?oooooo`000?l000005?l00000
0ooooooo0000o`000002o`0000;ooooo0_l00002ooooo`;o00002_ooool3o`0000;ooooo0_l00000
0ooooooo0000o`000007o`0000;ooooo3?l00006ooooo`;o00000oooool3o`000003ooooool0003o
000001Cooooo0_l00009ooooo`;o00000_ooool2o`0000gooooo0_l0000hooooo`0000?ooooooa0@
4?ooool00_ooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`0jooooo`;o00006_ooool4o`0000Wooooo0_l00007ooooo`;o000000?ooooo
o`000?l000009ol00005ooooo`;o00000_ooool2o`0000Kooooo0_l00002ooooo`?o00000_ooool=
o`000003ooooool0003o000000[o00001_ooool2o`0000?ooooo0_l00002ooooo`;o00005?ooool2
o`000004ooooool0003o0000ooooo`;o00000oooool2o`0000;ooooo0_l00017ooooo`0000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_oo
ool3o`0005Kooooo0_l00005ooooo`;o00001Oooool2o`0000Wooooo:Ol00005ooooo`?o000000?o
ooooo`000?l000001_ooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000004Ol0
00000ooooooo0000o`000006o`0000oooooo0_l0000Cooooo`;o000000?oooooo`000?l000000ooo
ool2o`0001_ooooo0_l0000^ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09
ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`1Fooooo`;o000000?o
ooooo`000?l000000_ooool6o`000003ooooool0003o000000?o000000?oooooo`000?l000000ooo
oolXo`0000;ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l00004ooooo`?o00001Ooo
oolGo`000003ooooool0003o000000Ko00001?ooool2o`0000Oooooo1?l0000@ooooo`;o00009_oo
ool2o`0002kooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEE
ohN7Qoooool02?ooool00ol0003oooooooooo`0/ooooo`;o00004?ooool2o`0001Kooooo0_l00000
0ooooooo0000o`000004ooooo`Co00000_ooool4o`000004ooooool0003o0000ooooobko000000?o
ooooo`000?l000000ol000000ooooooo0000o`000002o`0000;ooooo0_l00006oooooaoo00001Ooo
ool2o`0000Kooooo1Ol00004ooooo`;o00001Oooool2o`0000?ooooo0_l000000ooooooo0000o`00
000Kooooo`;o0000=_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@
oiRHV008ooooo`03o`000?oooooooooo02cooooo0_l0000@ooooo`;o000000?oooooo`000?l00000
4oooool2o`0000Wooooo0_l00005ooooobko000000?oooooo`000?l000003Ol0000:ooooo`Oo0000
00?oooooo`000?l000005?l0000>ooooo`;o00000_ooool2o`0000?ooooo0_l00005ooooo`;o0000
1_ooool2o`0001_ooooo0_l000000ooooooo0000o`00000cooooo`0000Koooooonk^k_lb<S;o0000
oc8b<_o^k^h<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0?_ooool2o`00
0003ooooool0003o000000cooooo0_l00003ooooo`;o00002oooool2o`000005ooooool0003o0000
o`000?ooool01_l000000ooooooo0000o`000002o`000003ooooool0003o000000co000000?ooooo
o`000?l000003ol00004ooooo`Co00000_ooool2o`000003ooooool0003o000000?o00002OoooolP
o`00017ooooo0_l00006ooooo`;o00005?ooool2o`0001Cooooo0_l0000cooooo`007?ooool00ol0
003oooooooooo`0Xooooo`;o00002_ooool2o`0000Sooooo0_l0000?ooooo`;o00000oooool3o`00
00gooooo0ol00005oooooc;o00001?ooool4o`0000Kooooo1_l000000ooooooo0000o`00000Jo`00
00;ooooo0_l00003ooooo`;o00004?ooool2o`0001Cooooo0_l0000Cooooo`;o0000=?ooool001co
oooo00?o0000ooooooooool0:?ooool2o`0000[ooooo0ol00007ooooo`;o00005?ooool3o`0000go
oooo0_l00007ooooob_o000000?oooooo`000?l000000ol00004ooooo`;o000000?oooooo`000?l0
00001Oooool3o`000003ooooool0003o000000;ooooo5ol000000ooooooo0000o`000002o`000003
ooooool0003o000000?ooooo0_l0000aooooo`;o00002?ooool2o`0003Cooooo000Looooo`03o`00
0?oooooooooo03Gooooo0_l00005ooooo`Co00002?ooool2o`0000[ooooo0_l0000Dooooo`Ko0000
0oooool3o`000003ooooool0003o000001_o00000_ooool3o`0000Wooooo1Ol00005ooooo`?o0000
00?oooooo`000?l000000_oooolLo`0002cooooo0_l0000;ooooo`;o00002?ooool2o`0003Cooooo
000Looooo`03o`000?oooooooooo02gooooo0_l0000<ooooo`Go00002?ooool3o`0000Kooooo0_l0
000:ooooo`;o00001Oooool2o`0000Cooooo1Ol000000ooooooo0000o`000002ooooob7o00000_oo
ool4o`0000;ooooo1?l000000ooooooo0000o`000002o`0000Kooooo0_l00002ooooo`;o00000_oo
oolLo`000003ooooool0003o000002?ooooo0_l00004ooooo`;o00001?ooool2o`0004Gooooo000L
ooooo`03o`000?oooooooooo02gooooo0_l0000;ooooo`?o00002oooool3o`0000Kooooo0_l0000:
ooooo`Co00000oooool2o`0000Kooooo0ol000001Ooooooo0000o`000?l0003ooooo01Go00000_oo
ool2o`0000;ooooo1ol000000ooooooo0000o`000003o`000003ooooool0003o000000;o000000Co
ooooo`000?l0003o00003OoooolQo`0001Oooooo0_l00003ooooo`;o00001Oooool2o`0000[ooooo
0_l00007ooooo`;o0000??ooool001cooooo00?o0000ooooooooool0>_ooool3o`0001Cooooo0_l0
000<ooooo`;o00004?ooool2o`000003ooooool0003o000001?o00000_ooool3o`000003ooooool0
003o000000;o000000?oooooo`000?l000000_ooool5o`000003ooooool0003o000000;ooooo0_l0
000>ooooo`?o000000?oooooo`000?l000006ol0000Gooooo`Oo00006_ooool2o`0003cooooo000L
ooooo`03o`000?oooooooooo03_ooooo1?l000000ooooooo0000o`00000:ooooo`;o00000oooool2
o`0000Oooooo0_l00008ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00000_ooool5
o`0000Cooooo4?l00002ooooo`?o00000_ooool2o`0000;ooooo0_l000001?oooooo0000o`000?oo
ool5o`0000?ooooo0_l00003ooooo`Co00000_ooool2o`0000;ooooo9Ol0000Eooooo`Co00001?oo
ool2o`0005?ooooo000Looooo`03o`000?oooooooooo03gooooo1Ol0000:ooooo`;o00001?ooool3
o`0000Gooooo0_l00008ooooo`Oo00000_ooool2o`0000Cooooo1_l00004ooooo`Wo000000?ooooo
o`000?l000002_l00002ooooo`;o00001Oooool2o`0000Gooooo0_l00003ooooo`Co00000_ooool2
o`0000;ooooo9ol0000:ooooo`;o00002?ooool2o`0000?ooooo1?l00004ooooo`;o0000COooool0
01cooooo00?o0000ooooooooool0>_ooool2o`0000?ooooo0ol0000@ooooo`Go00000oooool2o`00
00Wooooo0_l00007ooooo`?o00000ooooolAo`000003ooooool0003o000000go00000_ooool2o`00
0003ooooool0003o000000;o00005OoooolMo`0000;ooooo0_l000000ooooooo0000o`000002o`00
00[ooooo0ol00006ooooo`?o00000oooool4o`0000Cooooo0ol00007ooooo`;o0000@oooool001co
oooo00?o0000ooooooooool0>_ooool2o`0000Cooooo0_l0000=ooooo`;o00001?ooool2o`0000?o
oooo0_l00007ooooo`?o00002?ooool3o`0000;ooooo0ol000000ooooooo0000o`00000;o`0000;o
oooo1?l00003ooooo`?o000000?oooooo`000?l000000_l00002ooooo`;o000000?oooooo`000?l0
00001?l00006ooooo`;o00002oooool5o`000003ooooool0003o000001Go000000?oooooo`000?l0
00000_ooool2o`0000gooooo0_l00005ooooo`?o00001_ooool2o`0000Gooooo0_l00007ooooo`;o
0000@oooool001cooooo00?o0000ooooooooool0>_ooool2o`0000_ooooo0_l00006ooooo`;o0000
1oooool2o`0000Wooooo1?l0000<ooooo`;o00000_ooool;o`0000Cooooo0_l00005ooooo`?o0000
1_ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000001_ooool2o`0000_ooooo
0_l00002ooooo`ko000000?oooooo`000?l000002?l000000ooooooo0000o`000002ooooo`;o0000
1_ooool2o`0000;ooooo1?l00002ooooo`Ko00003?ooool4o`0004cooooo000Looooo`;o0000>ooo
ool2o`0000[ooooo0ol0000?ooooo`;o000000?oooooo`000?l000002?ooool2o`0000Gooooo1?l0
0008ooooo`[o000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l00007ooooo`;o000000?o
ooooo`000?l000000_l00003ooooo`;o00003Oooool2o`0000;ooooo0_l00002oooooa[o000000Co
ooooo`000?l0003ooooo0_l00004ooooo`Co00000_ooool4o`0000;ooooo1?l00008ooooo`;o0000
1?ooool4o`0004cooooo000Looooo`03o`000?oooooooooo04Kooooo0_l00007ooooo`;o00000_oo
ool2o`0000Kooooo0_l000000ooooooo0000o`00000<ooooo`Co000000?oooooo`000?l000001Ooo
ool2o`0000;ooooo1_l000001?oooooo0000o`000?ooool3o`0000Cooooo1Ol00004ooooo`;o0000
2?ooool2o`0000Kooooo0_l00004ooooo`So00000_oooolIo`000003ooooool0003o000000Oooooo
0ol00004ooooo`;o00000oooool4o`000003ooooool0003o000000Gooooo1Ol0001Aooooo`007?oo
ool00ol0003oooooooooo`1?ooooo`;o00000_ooool3o`0000Sooooo0_l000000ooooooo0000o`00
000>ooooo`;o00001Oooool2o`0000;ooooo0_l00004ooooo`Ko00001_ooool4o`000004ooooool0
003o0000ooooo`;o00003_ooool4o`0000Cooooo0_l000000ooooooo0000o`000003o`0000Cooooo
6Ol00007ooooo`Co00001Oooool4o`0000Cooooo0ol00006ooooo`Co0000DOooool001cooooo00?o
0000ooooooooool0BOooool2o`0000Wooooo0_l00003ooooo`;o00001_ooool2o`0000Sooooo0_l0
0002ooooo`;o00004Oooool4o`0000Gooooo0_l00006ooooo`;o00004Oooool2o`0001;ooooo5?l0
0002ooooo`?o00001Oooool4o`0000Oooooo1?l00004ooooo`;o00000_ooool2o`0000?ooooo0_l0
0007ooooo`Co0000B?ooool001cooooo00?o0000ooooooooool0BOooool2o`0000?ooooo0_l00000
0ooooooo0000o`000006ooooo`;o00002oooool2o`0000?ooooo0_l00002ooooo`;o00004oooool2
o`0000Gooooo0_l00005ooooo`?o00000oooool2o`0000Kooooo0_l0000Iooooo`ko00000_ooool2
o`000004ooooool0003o0000ooooo`;o00000oooool4o`00017ooooo0_l00002ooooo`;o00000ooo
ool2o`0000Oooooo1?l00018ooooo`007?ooool00ol0003oooooooooo`19ooooo`;o00000oooool2
o`000003ooooool0003o000001?ooooo0_l00004ooooo`;o00000_ooool2o`0000Oooooo0_l00009
ooooo`;o00000_ooool2o`0000Sooooo0_l00004ooooo`Co00001?ooool2o`0000oooooo0ol00005
ooooo`Ko000000?oooooo`000?l000002?l000000ooooooo0000o`000003o`000003ooooool0003o
000000?ooooo0_l00007ooooo`;o00001?ooool2o`0000Cooooo0_l00008ooooo`;o00000oooool2
o`0000?ooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o00001?ooool2o`00
00oooooo0_l00006ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o000000?oooooo`00
0?l000002_ooool2o`0000Oooooo0_l00003ooooo`;o00000_ooool2o`0000Oooooo0_l0000<oooo
o`?o00001Oooool3o`000003ooooool0003o000000Oo00000_ooool2o`000003ooooool0003o0000
00;o00000oooool3o`0000Kooooo0_l00002ooooo`Co00000_ooool2o`0000?ooooo0_l00005oooo
o`;o00000_ooool2o`0000?ooooo0_l00003ooooo`;o00001_ooool2o`00043ooooo000Looooo`03
o`000?oooooooooo04gooooo0_l00004ooooo`;o00001oooool2o`0000Kooooo0_l0000?ooooo`;o
00000_ooool2o`000003ooooool0003o000000_ooooo0_l00006ooooo`;o000000?oooooo`000?l0
00000ol0000:ooooo`;o00002Oooool2o`0000Cooooo0ol00002ooooo`;o00001?ooool6o`000003
ooooool0003o000000;o00000_ooool4o`000003ooooool0003o000000;o000000?oooooo`000?l0
00000_ooool3o`0000Cooooo0_l00007ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`00
00;ooooo0_l0000@ooooo`;o0000@?ooool001cooooo00?o0000ooooooooool0DOooool2o`0000;o
oooo0_l00005ooooo`;o00002?ooool2o`00027ooooo0_l00009ooooo`;o000000?oooooo`000?l0
00005Oooool2o`0000Cooooo0ol00006ooooo`;o00001?ooool2o`000003ooooool0003o000000;o
00000_ooool4o`000003ooooool0003o000000?ooooo0ol000000ooooooo0000o`00000Aooooo`?o
00005?ooool2o`0004?ooooo000Looooo`03o`000?oooooooooo04cooooo0_l00003ooooo`;o0000
0_ooool4o`0000gooooo0_l0000Gooooo`;o000000Coooooo`000?l0003ooooo1_l00009ooooo`;o
00001?ooool4o`0000Kooooo0_l0000=ooooo`;o00002?ooool2o`0000;ooooo1?l00008ooooo`;o
00002?ooool2o`00023ooooo0_l00009ooooo`;o0000@oooool001cooooo00?o0000ooooooooool0
C?ooool2o`0000?ooooo0_l00004ooooo`Co00000oooool2o`0001gooooo1?l000000ooooooo0000
o`000007o`0000oooooo1?l00006ooooo`;o00002_ooool2o`000003ooooool0003o000000;o0000
1oooool2o`000003ooooool0003o000000;o0000=?ooool2o`0000Sooooo1?l00012ooooo`007?oo
ool00ol0003oooooooooo`1:ooooo`Co00002oooool2o`0000?ooooo0_l0000;ooooo`;o00004?oo
ool2o`0000?ooooo0ol00005ooooo`;o00000_ooool2o`0001Oooooo0_l00002ooooo`;o000000?o
ooooo`000?l000001?l000000ooooooo0000o`000007ooooo`;o00003Oooool2o`000003ooooool0
003o000000Cooooo0_l0000;ooooo`;o00006?ooool2o`0000Cooooo1?l00012ooooo`007?ooool0
0ol0003oooooooooo`1:ooooo`;o00003?ooool2o`000003ooooool0003o000000?ooooo0_l00006
ooooo`;o000000?oooooo`000?l000004?ooool2o`0000_ooooo0_l00002ooooo`;o00005oooool2
o`0000;ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00004oooool2o`0000Cooooo0_l0
00000ooooooo0000o`000004ooooo`;o000000Coooooo`000?l0003o00000oooool2o`0000;ooooo
0_l00007ooooo`;o00001?ooool2o`0000?ooooo1?l00002ooooo`;o00001?ooool2o`0004Cooooo
000Looooo`03o`000?oooooooooo04_ooooo0_l00005ooooo`;o00001?ooool2o`000003ooooool0
003o000000;o000000?oooooo`000?l000001_ooool2o`0000Gooooo0_l0000<ooooo`;o00001_oo
ool2o`0000Cooooo0_l00002ooooo`;o00001Oooool2o`0002Gooooo0_l00004ooooo`;o00000_oo
ool4o`000003ooooool0003o000000_ooooo0ol00003ooooo`;o00002?ooool2o`000003ooooool0
003o000000Cooooo0_l00003ooooo`Co00000oooool2o`0004Wooooo000Looooo`03o`000?oooooo
oooo04_ooooo0_l00005ooooo`;o00001?ooool2o`0000?ooooo0_l0000@ooooo`;o00003?ooool2
o`0000Cooooo1?l00003ooooo`?o00000_ooool2o`0000Gooooo0_l00004ooooo`;o00007oooool2
o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l000003oooool2o`0000Kooooo0_l00002
ooooo`;o00000oooool2o`0000kooooo0_l00019ooooo`007?ooool00ol0003oooooooooo`1Coooo
o`;o00006Oooool2o`0000kooooo0_l00002ooooo`Co00001?ooool2o`0000?ooooo0_l00003oooo
o`;o00001_ooool2o`0001?ooooo0_l00002ooooo`;o00005Oooool4o`0000gooooo0_l00006oooo
o`;o00001?ooool2o`000003ooooool0003o0000013ooooo0_l00017ooooo`007?ooool2o`0005Co
oooo0_l00005ooooo`;o00001?ooool3o`0000Wooooo1?l0000>ooooo`;o00000_ooool4o`000003
ooooool0003o000000_ooooo0_l0000Kooooo`;o00000_ooool2o`0000;ooooo0_l0000Aooooo`Co
00004?ooool2o`0000Oooooo1?l00003ooooo`;o00003_ooool2o`0004Oooooo000Looooo`03o`00
0?oooooooooo05Gooooo0ol00002ooooo`;o00000_ooool5o`0000Wooooo0_l00006ooooo`;o0000
2oooool3o`0000?ooooo0_l00007ooooo`;o00000_ooool2o`0000Oooooo0_l00002ooooo`;o0000
4_ooool2o`0000;ooooo0_l00007ooooo`;o00000_ooool2o`0000oooooo0_l00003ooooo`;o0000
0_ooool2o`0000Kooooo1?l00004ooooo`;o00002Oooool2o`0004cooooo000Looooo`03o`000?oo
oooooooo04gooooo0_l00006ooooo`Co00001Oooool2o`0001Cooooo0_l0000;ooooo`?o00001Ooo
ool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00001oooool2o`0000;ooooo0_l0
000Iooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00000oooool2o`0000Oooooo
0_l000000ooooooo0000o`000002ooooo`?o00001oooool2o`000003ooooool0003o000000Kooooo
0_l00009ooooo`;o0000C?ooool001cooooo00?o0000ooooooooool0COooool2o`0000Sooooo0_l0
0004ooooo`;o00008oooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o00001?oo
ool3o`0002Kooooo0_l000000ooooooo0000o`000002o`0000Sooooo0ol00005ooooo`Co00001?oo
ool2o`0000?ooooo0_l00003ooooo`;o00000_ooool2o`0000[ooooo0_l0001Booooo`007?ooool0
0ol0003oooooooooo`1Iooooo`;o00000_ooool2o`0000Oooooo0_l0000Mooooo`;o00003?ooool2
o`0000;ooooo0ol0000=ooooo`;o00006?ooool2o`0000Wooooo0_l00004ooooo`Go00002Oooool3
o`0000Kooooo0_l000000ooooooo0000o`000007ooooo`;o0000D_ooool001cooooo00?o0000oooo
ooooool0D_ooool2o`0000Gooooo0_l00005ooooo`;o00001?ooool4o`000003ooooool0003o0000
00cooooo0_l00005ooooo`;o00003_ooool2o`0000Gooooo0ol00005ooooo`;o00001_ooool2o`00
01?ooooo0_l00003ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Cooooo0_l00003oooo
o`;o00002?ooool2o`0000;ooooo0_l00005ooooo`;o00002_ooool2o`0004oooooo000Looooo`03
o`000?oooooooooo05;ooooo0_l00005ooooo`;o00001Oooool2o`0000Gooooo0ol000000ooooooo
0000o`00000<ooooo`;o00001Oooool3o`0000gooooo0_l0000=ooooo`;o00006oooool2o`0000;o
oooo0ol000000ooooooo0000o`000004ooooo`Co000000?oooooo`000?l000001_ooool2o`0000Co
oooo0_l00006ooooo`;o00003?ooool2o`0000?ooooo0_l0001?ooooo`007?ooool00ol0003ooooo
ooooo`1Fooooo`;o000000?oooooo`000?l000003_ooool2o`0001Kooooo0_l00008ooooo`;o0000
6?ooool2o`0001Wooooo0_l00007ooooo`?o00000oooool2o`0000Gooooo0_l00005ooooo`?o0000
0oooool2o`0000?ooooo0ol00008ooooo`;o0000E?ooool001cooooo00?o0000ooooooooool0E_oo
ool2o`000003ooooool0003o000000kooooo0_l00005ooooo`;o00006Oooool2o`0001Sooooo1?l0
000Pooooo`;o00002oooool2o`0000?ooooo0_l000000ooooooo0000o`000003ooooo`;o00000ooo
ool3o`0005kooooo000Looooo`03o`000?oooooooooo04Kooooo0_l0000;ooooo`;o00001?ooool2
o`0000Wooooo1?l00008ooooo`Go00003_ooool2o`0002;ooooo0_l0000Oooooo`;o00002oooool3
o`0000?ooooo0_l0000<ooooo`;o0000G_ooool001cooooo00?o0000ooooooooool0A_ooool2o`00
00_ooooo0_l00004ooooo`;o000000?oooooo`000?l000001?ooool6o`0000Wooooo1?l0000>oooo
o`;o00002_ooool2o`0001;ooooo0_l0000Sooooo`;o00002oooool5o`0000Gooooo0_l00003oooo
o`;o00000oooool2o`0005kooooo000Looooo`03o`000?oooooooooo05Cooooo0_l00003ooooo`;o
000000Coooooo`000?l0003ooooo0_l000001?oooooo0000o`000?ooool2o`00027ooooo0_l00004
ooooo`?o00004_ooool2o`000003ooooool0003o000001Wooooo1?l00003ooooo`;o00003Oooool3
o`0000Gooooo0_l00003ooooo`;o00001_ooool2o`0005_ooooo000Looooo`03o`000?oooooooooo
05Cooooo0_l00009ooooo`;o00006_ooool2o`0000_ooooo0_l00004ooooo`;o00001Oooool2o`00
00Wooooo1?l00002ooooo`;o00006Oooool4o`0001?ooooo0_l0000;ooooo`;o00001Oooool2o`00
05_ooooo000Looooo`03o`000?oooooooooo05kooooo0_l0000;ooooo`;o00003_ooool4o`0000Ko
oooo0_l00007ooooo`;o00001Oooool2o`0000Wooooo1?l0000kooooo`;o00001?ooool2o`0000Ko
oooo0_l0001Jooooo`007?ooool00ol0003oooooooooo`1Cooooo`;o00002Oooool2o`0000_ooooo
0_l00009ooooo`;o00001Oooool2o`0000Kooooo0_l00002ooooo`;o00000oooool2o`0001Gooooo
0_l0000Zooooo`;o00001oooool2o`0000?ooooo0_l0000<ooooo`;o0000F_ooool001cooooo00?o
0000ooooooooool0Doooool3o`0000Kooooo0ol0000Booooo`;o00000oooool2o`00017ooooo0_l0
000Dooooo`;o00000_ooool4o`0000?ooooo0_l0000Hooooo`;o00002oooool2o`0000Oooooo0_l0
001]ooooo`007?ooool2o`0005Gooooo0_l00006ooooo`?o00002?ooool2o`0000Sooooo0_l00009
ooooo`Go00000oooool2o`0000_ooooo0_l0000<ooooo`;o00000_ooool2o`0000Gooooo0_l0000H
ooooo`;o00002?ooool4o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l00000J?ooool0
01cooooo00?o0000ooooooooool0G_ooool5o`0000Cooooo0ol00002ooooo`;o00003_ooool5o`00
00?ooooo0_l0000;ooooo`Co00003_ooool3o`0000;ooooo0_l0000Oooooo`;o00000oooool4o`00
00Cooooo0_l00004ooooo`;o000000?oooooo`000?l00000J?ooool001cooooo00?o0000oooooooo
ool0F?ooool2o`0000Cooooo1Ol00005ooooo`;o00000_ooool4o`000003ooooool0003o0000023o
oooo0_l00003ooooo`;o00002_ooool2o`000004ooooool0003o0000o`0001[ooooo0_l00003oooo
o`;o00003?ooool2o`0000?ooooo0_l0001[ooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o
00001Oooool4o`0000_ooooo0_l000000ooooooo0000o`000006ooooo`;o00007Oooool2o`0000go
oooo0_l0000Kooooo`;o00002oooool2o`0000Cooooo0ol0001_ooooo`007?ooool00ol0003ooooo
ooooo`1Oooooo`Go00001?ooool3o`0000?ooooo0_l00009ooooo`?o000000?oooooo`000?l00000
1?ooool4o`0000kooooo0ol0000?ooooo`;o00009?ooool2o`0000;ooooo0_l00005ooooo`;o0000
Koooool001cooooo00?o0000ooooooooool0E_ooool2o`0000[ooooo0ol00002ooooo`Co00000_oo
ool3o`0000[ooooo1Ol000001?oooooo0000o`000?ooool6o`0000_ooooo1?l0000?ooooo`;o0000
3_ooool2o`0001Cooooo0_l00009ooooo`;o00001?ooool2o`0006Wooooo000Looooo`03o`000?oo
oooooooo05Kooooo0_l000000ooooooo0000o`000008ooooo`;o00000_ooool2o`000004ooooool0
003o0000ooooo`;o00002_ooool6o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000_o
oooo0_l00009ooooo`;o00001?ooool2o`00013ooooo0_l0000<ooooo`;o00001oooool2o`0000?o
oooo0ol00005ooooo`;o000000?oooooo`000?l00000JOooool001cooooo00?o0000ooooooooool0
FOooool2o`0000oooooo0_l0000=ooooo`;o00003?ooool2o`0000kooooo0_l000000ooooooo0000
o`000002ooooo`?o000000Coooooo`000?l0003ooooo0_l0000:ooooo`Co00001oooool2o`0000;o
oooo0_l00003ooooo`;o00001oooool3o`0000;ooooo0ol00005ooooo`;o000000?oooooo`000?l0
0000JOooool001cooooo00?o0000ooooooooool0Doooool2o`0000Cooooo0_l00009ooooo`;o0000
0_ooool2o`0001Sooooo1ol00002ooooo`;o00002_ooool5o`0000;ooooo0_l00002ooooo`;o0000
3Oooool4o`0000Oooooo0_l000001?oooooo0000o`000?l00008ooooo`;o00000oooool2o`0000?o
oooo1?l00003ooooo`;o0000K?ooool001cooooo00?o0000ooooooooool0Doooool2o`0000oooooo
0ol000000ooooooo0000o`00000;ooooo`;o000000?oooooo`000?l000002?ooool5o`0000Cooooo
0_l0000<ooooo`;o00001Oooool2o`0000oooooo0_l00008ooooo`;o00000_ooool2o`0000Gooooo
0_l00002ooooo`Co000000?oooooo`000?l000000oooool4o`00077ooooo000Looooo`03o`000?oo
oooooooo06Cooooo0ol000000ooooooo0000o`00000;ooooo`;o000000?oooooo`000?l000000_l0
00000ooooooo0000o`00000Dooooo`;o00002oooool4o`0000cooooo0ol00006ooooo`Co00000ooo
ool2o`0000Cooooo0_l00004ooooo`;o000000?oooooo`000?l000000oooool2o`0007?ooooo000L
ooooo`03o`000?oooooooooo05Cooooo0_l0000Aooooo`;o00001Oooool5o`0000Oooooo0_l00000
1?oooooo0000o`000?ooool2o`00017ooooo0_l0000=ooooo`;o00002oooool4o`0000Kooooo0_l0
0004ooooo`?o00003Oooool4o`0000Sooooo0_l0001/ooooo`007?ooool00ol0003oooooooooo`1D
ooooo`;o00004Oooool3o`0000?ooooo1_l00002ooooo`;o00002Oooool2o`0001Kooooo0_l00000
0ooooooo0000o`00000=ooooo`Co000000?oooooo`000?l000003Oooool3o`000003ooooool0003o
000000?ooooo0_l000000ooooooo0000o`000005ooooo`;o00002?ooool2o`0006cooooo000Loooo
o`03o`000?oooooooooo05gooooo0_l00009ooooo`;o00000oooool2o`0000Kooooo0_l00006oooo
o`;o00000oooool2o`0000Cooooo0_l0000:ooooo`;o00000_ooool2o`000003ooooool0003o0000
00gooooo1?l0000@ooooo`Ko00000oooool2o`000003ooooool0003o000000;ooooo0_l0000Noooo
o`;o0000FOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<
ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo05_ooooo1?l00008ooooo`;o00005?oo
ool3o`0000;ooooo0_l00004ooooo`;o00000_ooool2o`0000Kooooo1_l0000Tooooo`Co00000ooo
ool4o`0000Gooooo0_l0000Nooooo`;o0000FOooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo05_o
oooo0_l0000:ooooo`;o00002Oooool2o`0000Gooooo0_l00003ooooo`;o000000Coooooo`000?l0
003o00001_ooool4o`0000Kooooo1_l0000Sooooo`;o000000?oooooo`000?l000000_ooool6o`00
07oooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo06Oooooo0_l00009ooooo`;o00001Oooool2o`00
00Kooooo1?l00005ooooo`?o00001oooool2o`0001gooooo0_l00008ooooo`;o000000?oooooo`00
0?l000000_ooool2o`0000;ooooo0_l00007ooooo`;o0000M_ooool00003ooooool0003ooooo00;o
oooo00?o0000ooooooooool02Oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0001Ooooo
o`;o00001_ooool2o`0000Gooooo0_l0000Cooooo`;o00000oooool2o`0002Oooooo1?l0000Loooo
o`;o0000M_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Oo<c<co
0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0Goooool2o`0000gooooo0_l0000?oooo
o`;o00001oooool2o`00013ooooo0_l0000Eooooo`;o00004_ooool2o`0000Gooooo0_l0001koooo
o`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj
^_l@41001_ooool00ol0003oooooooooo`1jooooo`;o00000oooool2o`000004ooooool0003o0000
o`0000Wooooo0_l00007ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0000gooooo0_l0
000Aooooo`;o00000_ooool4o`0000?ooooo0_l0001kooooo`0000KoooooogMgMonHV9SooooooiRH
V?mgMgL;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`1jooooo`;o
00001_ooool3o`0000Wooooo0_l00007ooooo`;o00000_ooool2o`0000;ooooo0_l0000:ooooo`;o
000000?oooooo`000?l000001_ooool2o`0000;ooooo0_l00005ooooo`;o00001?ooool2o`00083o
oooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06
ooooo`03o`000?oooooooooo07kooooo0ol00002ooooo`;o00005Oooool3o`0000Sooooo0_l00004
ooooo`;o00002?ooool3o`0000;ooooo0_l0002=ooooo`007?ooool00ol0003oooooooooo`1noooo
o`Co00000oooool3o`0000?ooooo0_l0000<ooooo`?o00002Oooool2o`0000;ooooo0_l0000:oooo
o`;o00002oooool4o`0008?ooooo000Looooo`03o`000?oooooooooo083ooooo0_l00003ooooo`?o
000000?oooooo`000?l000001Ol000000ooooooo0000o`000006ooooo`;o00003_ooool2o`0000Wo
oooo0_l00003ooooo`;o00001oooool4o`0008?ooooo000Looooo`03o`000?oooooooooo08Wooooo
1ol000000ooooooo0000o`00000;ooooo`;o00002Oooool2o`0000?ooooo0_l00004ooooo`;o0000
0oooool8o`0008Sooooo000Looooo`03o`000?oooooooooo073ooooo0_l0000=ooooo`;o000000?o
ooooo`000?l000001oooool5o`0000kooooo0_l00009ooooo`;o00000oooool2o`0000_ooooo1_l0
0028ooooo`007?ooool00ol0003oooooooooo`1`ooooo`;o00002oooool4o`000003ooooool0003o
000000Oooooo1Ol0000=ooooo`;o00002Oooool2o`0009oooooo000Looooo`03o`000?oooooooooo
07gooooo0_l0000>ooooo`;o00003_ooool2o`0000Wooooo1?l000000ooooooo0000o`00002Joooo
o`007?ooool00ol0003oooooooooo`25ooooo`;o00007_ooool2o`0000?ooooo0_l000000ooooooo
0000o`000002ooooo`;o0000U_ooool001cooooo00?o0000ooooooooool0QOooool4o`0001Gooooo
0_l00002ooooo`;o000000?oooooo`000?l000002_ooool2o`0009Kooooo000Looooo`03o`000?oo
oooooooo08Oooooo0_l00008ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo1?l0
0002ooooo`;o0000YOooool001cooooo00?o0000ooooooooool0TOooool2o`0000;ooooo0_l00000
1?oooooo0000o`000?ooool3o`0000Cooooo0_l00003ooooo`;o00002?ooool2o`0009Kooooo000L
ooooo`03o`000?oooooooooo07[ooooo0_l00008ooooo`;o00005Oooool2o`0000Gooooo0_l00003
ooooo`Co00001_ooool3o`0009Gooooo000Looooo`;o0000Noooool2o`0000Sooooo0_l0000@oooo
o`;o00004Oooool4o`0000Gooooo0_l0002Eooooo`007?ooool00ol0003oooooooooo`2Fooooo`;o
00004oooool2o`0009cooooo000Looooo`03o`000?oooooooooo0:Gooooo0_l0002Rooooo`007?oo
ool00ol0003oooooooooo`2Sooooo`Co0000X_ooool001cooooo00?o0000ooooooooool0Xoooool2
o`00033ooooo0_l0001booooo`007?ooool00ol0003oooooooooo`3Eooooo`;o0000L_ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0W?ooool2
o`000:_ooooo000Looooo`03o`000?oooooooooo09cooooo0_l0002[ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0:Gooooo0_l00005ooooo`;o0000
Voooool001cooooo00?o0000ooooooooool0YOooool2o`0000Gooooo0_l0002Kooooo`007?ooool0
0ol0003oooooooooo`2Mooooo`;o0000Z_ooool001cooooo00?o0000ooooooooool0SOooool2o`00
00kooooo0_l0002Zooooo`007?ooool2o`0008kooooo0_l0002jooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`000?oooooo
Boooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom:ooooo`00
5?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o
0000ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o0000ooooooooool0oooooomB
ooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooooooo0?oo
ooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`004_ooool00omEEEGoIVIVo`00
003ooooooeCooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Qooooo`04oa0@
4?l0003o0000ooooo`;o000000?o410@ooooooooool05_ooool4o`000003oa0@4?oooooooooo00;o
oooo0_l000002?l@413ooooooooooooooooo410@o`000?m4A4Coc<c<1_ooool2o`000003oa0@4?oo
oooooooo08[ooooo002Rooooo`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03oiRHV?l@413ogMgM00Kooooo00?o
0000ooooooooool0Roooool00:;ooooo00Go0000ooooooooooooooooo`00000Kooooo`03o`000?oo
oooooooo00;ooooo1Ol00006ooooo`03ohN7QomEEEGooooo00;ooooo1Ol0002<ooooo`00X_ooool0
1Ol0003ooooooooooooooooo000000Wooooo1_l0000<ooooo`03o`000?oooooooooo00;ooooo00Co
A4A4omgMgOoooooo00001?ooool01Oo<c<co8B4Qo`000?mEEEGo000000?ooooo00CoA4A4omgMgOoo
oooo0000SOooool00:;ooooo00Go0000ohN7QoooooooZJVYo`00000Kooooo`03o`000?oooooooooo
00;ooooo00CogMgMoeEEEOoooooo00001?ooool01OlQ8B7oQhN7oooooonHV9So000000?ooooo00Co
gMgMoeEEEOoooooo0000SOooool00:7ooooo00?o410@o`000?mgMgL00_l000000onHV9Sooooooooo
o`0Iooooo`03o`000?oooooooooo00?ooooo00?oMgMgolc<c?l000001?ooool01Ol0003ooooooooo
oooooooo000000Cooooo00?oMgMgolc<c?l00000SOooool00<;ooooo00?o0000ooooooooool00ooo
ool00oo^k^koA4A4o`000004ooooo`05ob4Q8OnHV9SoooooogMgMomEEED01?ooool00oo^k^koA4A4
o`00002=ooooo`00`?ooool00omEEEGoIVIVo`000006ooooo`03ogMgMol0003ooooo00?ooooo00Go
c<c<oa0@4?l0003o<S8bonk^kP05ooooo`03ogMgMol0003ooooo08cooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1500) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.60092 .62114 Mdot
.60031 .61375 Mdot
.54318 .3359 Mdot
.42875 .56334 Mdot
.18347 .51831 Mdot
.56169 .37671 Mdot
.70401 .50406 Mdot
.69689 .5015 Mdot
.53544 .32854 Mdot
.67239 .69832 Mdot
.68448 .45786 Mdot
.47483 .57291 Mdot
.67503 .48523 Mdot
.40412 .59811 Mdot
.46932 .87644 Mdot
.43704 .51579 Mdot
.6031 .62455 Mdot
.30494 .31767 Mdot
.45489 .54405 Mdot
.57492 .34777 Mdot
.5697 .68353 Mdot
.40516 .59391 Mdot
.5919 .63735 Mdot
.4037 .59844 Mdot
.40363 .55969 Mdot
.58256 .63292 Mdot
.56611 .58784 Mdot
.36886 .54719 Mdot
.36485 .58668 Mdot
.68746 .4595 Mdot
.30385 .34296 Mdot
.27497 .7313 Mdot
.32605 .55067 Mdot
.27388 .55313 Mdot
.64959 .47519 Mdot
.46751 .76582 Mdot
.53942 .36916 Mdot
.694 .49497 Mdot
.69395 .4856 Mdot
.68162 .50713 Mdot
.68741 .5025 Mdot
.58882 .65415 Mdot
.76158 .53671 Mdot
.74601 .45414 Mdot
.39083 .62215 Mdot
.23346 .34479 Mdot
.36838 .73429 Mdot
.44123 .58377 Mdot
.57601 .67039 Mdot
.47921 .23912 Mdot
.70878 .35963 Mdot
.64283 .48193 Mdot
.55892 .33084 Mdot
.58211 .11821 Mdot
.67449 .46977 Mdot
.35517 .61558 Mdot
.54072 .35415 Mdot
.39278 .58481 Mdot
.39969 .60008 Mdot
.5052 .6837 Mdot
.35282 .53726 Mdot
.39218 .33496 Mdot
.55121 .60187 Mdot
.49019 .4554 Mdot
.551 .35155 Mdot
.69008 .4698 Mdot
.61697 .62629 Mdot
.66862 .46941 Mdot
.31819 .59678 Mdot
.55861 .39766 Mdot
.44706 .56257 Mdot
.6896 .46544 Mdot
.55019 .65727 Mdot
.36722 .56494 Mdot
.45298 .23154 Mdot
.24402 .32134 Mdot
.40438 .32569 Mdot
.47871 .74911 Mdot
.50972 .68099 Mdot
.45084 .28223 Mdot
.34987 .5897 Mdot
.26541 .41313 Mdot
.26536 .3084 Mdot
.5999 .68166 Mdot
.41624 .50871 Mdot
.34359 .31388 Mdot
.36864 .56026 Mdot
.16546 .49716 Mdot
.38191 .52145 Mdot
.52545 .51554 Mdot
.51827 .34671 Mdot
.55809 .63818 Mdot
.4226 .5612 Mdot
.37044 .58891 Mdot
.56224 .71794 Mdot
.44997 .55875 Mdot
.41411 .58175 Mdot
.60048 .67749 Mdot
.64297 .47148 Mdot
.33421 .56135 Mdot
.55844 .29967 Mdot
.58285 .37548 Mdot
.38538 .53124 Mdot
.53968 .39191 Mdot
.55063 .65562 Mdot
.37033 .5877 Mdot
.68967 .48459 Mdot
.40712 .53919 Mdot
.73828 .32026 Mdot
.60684 .63388 Mdot
.35545 .5672 Mdot
.40239 .37411 Mdot
.4123 .69512 Mdot
.55726 .65331 Mdot
.66747 .52324 Mdot
.46125 .55775 Mdot
.40389 .57491 Mdot
.6193 .63214 Mdot
.58889 .3698 Mdot
.18315 .44047 Mdot
.61907 .66522 Mdot
.62461 .45242 Mdot
.60184 .69327 Mdot
.47819 .58181 Mdot
.55713 .35217 Mdot
.72126 .51339 Mdot
.7339 .51837 Mdot
.30437 .3806 Mdot
.37258 .5616 Mdot
.7803 .54353 Mdot
.5828 .35517 Mdot
.57007 .65145 Mdot
.66868 .47404 Mdot
.36943 .51697 Mdot
.61138 .65157 Mdot
.64689 .44313 Mdot
.35921 .34256 Mdot
.69458 .30509 Mdot
.57997 .61296 Mdot
.58703 .44642 Mdot
.64125 .46314 Mdot
.66444 .5095 Mdot
.52891 .83924 Mdot
.60429 .67021 Mdot
.38228 .36196 Mdot
.66203 .4749 Mdot
.4081 .44327 Mdot
.37371 .61711 Mdot
.25551 .39971 Mdot
.79241 .38143 Mdot
.31888 .49238 Mdot
.65757 .32688 Mdot
.37604 .36447 Mdot
.64723 .50148 Mdot
.42145 .57266 Mdot
.57509 .623 Mdot
.58782 .63692 Mdot
.35448 .53608 Mdot
.39569 .54827 Mdot
.43305 .53066 Mdot
.44041 .59428 Mdot
.55126 .55621 Mdot
.39328 .51708 Mdot
.38405 .73783 Mdot
.55874 .63309 Mdot
.42996 .5684 Mdot
.55678 .33065 Mdot
.45163 .60896 Mdot
.69982 .48607 Mdot
.39951 .58801 Mdot
.4258 .56332 Mdot
.34141 .57231 Mdot
.64916 .49533 Mdot
.24894 .6756 Mdot
.36668 .66226 Mdot
.24652 .58993 Mdot
.60486 .56189 Mdot
.50581 .35397 Mdot
.37512 .55549 Mdot
.39504 .35301 Mdot
.53039 .7762 Mdot
.43279 .55247 Mdot
.30088 .19362 Mdot
.41357 .58757 Mdot
.20159 .58012 Mdot
.34125 .50856 Mdot
.25852 .57448 Mdot
.28203 .40508 Mdot
.40195 .56278 Mdot
.74586 .62303 Mdot
.6666 .43585 Mdot
.60784 .33169 Mdot
.67224 .50071 Mdot
.564 .34009 Mdot
.54473 .34189 Mdot
.4348 .41524 Mdot
.46008 .52195 Mdot
.46288 .58556 Mdot
.41688 .52424 Mdot
.5863 .38346 Mdot
.53449 .59738 Mdot
.39814 .37602 Mdot
.54131 .60805 Mdot
.22621 .67728 Mdot
.5364 .24679 Mdot
.69771 .46549 Mdot
.36013 .35722 Mdot
.52478 .37707 Mdot
.5198 .33888 Mdot
.37736 .36885 Mdot
.38414 .60131 Mdot
.60665 .66835 Mdot
.38552 .79969 Mdot
.66293 .25625 Mdot
.7911 .70802 Mdot
.59166 .67834 Mdot
.76388 .57263 Mdot
.7025 .48842 Mdot
.52929 .35995 Mdot
.40721 .57677 Mdot
.3763 .58248 Mdot
.54728 .65493 Mdot
.44754 .56433 Mdot
.63798 .67781 Mdot
.40437 .56881 Mdot
.70351 .46077 Mdot
.38708 .31962 Mdot
.43388 .41548 Mdot
.33693 .41651 Mdot
.55837 .66466 Mdot
.61039 .76475 Mdot
.51542 .34134 Mdot
.54175 .77026 Mdot
.68165 .45826 Mdot
.36062 .33387 Mdot
.51939 .3265 Mdot
.41412 .36684 Mdot
.40822 .51005 Mdot
.57323 .35904 Mdot
.41235 .3619 Mdot
.45676 .46504 Mdot
.40442 .62121 Mdot
.63698 .21546 Mdot
.66696 .50407 Mdot
.57641 .6013 Mdot
.41117 .53756 Mdot
.51185 .36509 Mdot
.33723 .61751 Mdot
.61793 .30439 Mdot
.76256 .41787 Mdot
.58171 .34961 Mdot
.39261 .41797 Mdot
.36103 .33053 Mdot
.68667 .36545 Mdot
.77478 .54822 Mdot
.59178 .60662 Mdot
.42349 .51798 Mdot
.28422 .73573 Mdot
.66252 .47443 Mdot
.41823 .54396 Mdot
.21962 .42131 Mdot
.65322 .46504 Mdot
.39196 .58279 Mdot
.63739 .44818 Mdot
.58831 .6377 Mdot
.52403 .67874 Mdot
.62139 .64262 Mdot
.44854 .56719 Mdot
.6846 .48002 Mdot
.59377 .35823 Mdot
.57834 .63597 Mdot
.41037 .60993 Mdot
.37188 .54803 Mdot
.46311 .44973 Mdot
.43089 .57573 Mdot
.2376 .60991 Mdot
.40295 .56546 Mdot
.53278 .34351 Mdot
.34631 .56833 Mdot
.77405 .62501 Mdot
.43284 .4112 Mdot
.62052 .64889 Mdot
.57754 .34116 Mdot
.55004 .33822 Mdot
.37934 .25918 Mdot
.6819 .52298 Mdot
.43502 .6119 Mdot
.50983 .35602 Mdot
.46118 .49909 Mdot
.66218 .45088 Mdot
.37751 .52601 Mdot
.6011 .42467 Mdot
.55808 .26391 Mdot
.56608 .33745 Mdot
.48823 .60879 Mdot
.56149 .61603 Mdot
.41386 .55717 Mdot
.51513 .36756 Mdot
.41591 .4866 Mdot
.35661 .58173 Mdot
.79091 .49994 Mdot
.43911 .43699 Mdot
.64492 .46033 Mdot
.46718 .58474 Mdot
.42746 .53601 Mdot
.5704 .36446 Mdot
.55093 .64695 Mdot
.65679 .45204 Mdot
.58374 .64708 Mdot
.26527 .5571 Mdot
.6551 .23203 Mdot
.51308 .50956 Mdot
.4131 .33598 Mdot
.55243 .27647 Mdot
.2551 .60445 Mdot
.70751 .72842 Mdot
.51879 .81248 Mdot
.2812 .68877 Mdot
.54993 .39262 Mdot
.51918 .25658 Mdot
.54747 .34663 Mdot
.37934 .54114 Mdot
.55467 .35608 Mdot
.30116 .76664 Mdot
.40817 .57204 Mdot
.55158 .36672 Mdot
.58766 .74337 Mdot
.41752 .56166 Mdot
.59108 .60506 Mdot
.21826 .63248 Mdot
.81451 .59053 Mdot
.65764 .53349 Mdot
.53249 .37539 Mdot
.41377 .81252 Mdot
.41657 .58162 Mdot
.34692 .56543 Mdot
.55975 .62667 Mdot
.32053 .57424 Mdot
.40363 .35321 Mdot
.35779 .35661 Mdot
.60583 .49066 Mdot
.33822 .36718 Mdot
.46769 .5852 Mdot
.57631 .63297 Mdot
.56917 .56723 Mdot
.40342 .26117 Mdot
.49406 .24059 Mdot
.67345 .4417 Mdot
.218 .6301 Mdot
.65793 .63724 Mdot
.63258 .56309 Mdot
.62428 .411 Mdot
.56825 .65954 Mdot
.26814 .7214 Mdot
.6786 .50092 Mdot
.58639 .19491 Mdot
.70212 .68382 Mdot
.3806 .59648 Mdot
.67574 .45971 Mdot
.39179 .63805 Mdot
.78758 .62683 Mdot
.54047 .1939 Mdot
.30941 .69078 Mdot
.38263 .52251 Mdot
.53235 .24691 Mdot
.40343 .58352 Mdot
.61389 .30835 Mdot
.39232 .55865 Mdot
.58095 .64777 Mdot
.68651 .68979 Mdot
.63974 .5133 Mdot
.49102 .6207 Mdot
.67941 .37404 Mdot
.38424 .37019 Mdot
.40163 .56892 Mdot
.38439 .59991 Mdot
.4073 .35104 Mdot
.59168 .62913 Mdot
.44375 .54681 Mdot
.61986 .7598 Mdot
.38306 .60377 Mdot
.69825 .49476 Mdot
.69089 .69679 Mdot
.31981 .66498 Mdot
.45065 .58879 Mdot
.60209 .68478 Mdot
.70799 .48622 Mdot
.68495 .48371 Mdot
.38801 .49214 Mdot
.68133 .45064 Mdot
.42407 .58741 Mdot
.51093 .18669 Mdot
.59009 .61903 Mdot
.78971 .43062 Mdot
.61458 .65548 Mdot
.46755 .73607 Mdot
.64523 .47067 Mdot
.72117 .33004 Mdot
.39607 .63697 Mdot
.67599 .49854 Mdot
.42741 .65382 Mdot
.40699 .61726 Mdot
.41895 .61822 Mdot
.38645 .79718 Mdot
.52324 .34897 Mdot
.45492 .44259 Mdot
.68542 .45689 Mdot
.4204 .60102 Mdot
.45759 .56067 Mdot
.70763 .48986 Mdot
.59851 .23764 Mdot
.7174 .70068 Mdot
.40504 .56799 Mdot
.57391 .64609 Mdot
.57486 .65525 Mdot
.40576 .6269 Mdot
.3925 .535 Mdot
.55772 .3363 Mdot
.58963 .34121 Mdot
.50561 .36659 Mdot
.44258 .43474 Mdot
.74769 .36473 Mdot
.19265 .46249 Mdot
.6798 .50723 Mdot
.73745 .58195 Mdot
.50357 .49657 Mdot
.3851 .52027 Mdot
.54142 .38196 Mdot
.4301 .53728 Mdot
.44008 .56685 Mdot
.74071 .43047 Mdot
.19676 .51358 Mdot
.666 .68443 Mdot
.55377 .6591 Mdot
.64648 .49811 Mdot
.46844 .55023 Mdot
.72065 .45033 Mdot
.37497 .33053 Mdot
.33904 .48014 Mdot
.68225 .45743 Mdot
.5978 .60762 Mdot
.65383 .49014 Mdot
.37311 .58208 Mdot
.33858 .60784 Mdot
.57046 .65976 Mdot
.3925 .33287 Mdot
.35416 .52129 Mdot
.39413 .57999 Mdot
.75757 .30082 Mdot
.39569 .44871 Mdot
.62135 .54122 Mdot
.40545 .56567 Mdot
.41296 .61463 Mdot
.35643 .36977 Mdot
.37854 .5997 Mdot
.41601 .52929 Mdot
.40536 .69761 Mdot
.67534 .57477 Mdot
.38239 .37708 Mdot
.53623 .20013 Mdot
.59148 .67781 Mdot
.27007 .70742 Mdot
.55158 .38141 Mdot
.6238 .51626 Mdot
.70804 .69938 Mdot
.53288 .31998 Mdot
.65298 .33161 Mdot
.26052 .68629 Mdot
.53822 .29827 Mdot
.51236 .38798 Mdot
.55928 .59503 Mdot
.43996 .58949 Mdot
.40066 .57576 Mdot
.39661 .35508 Mdot
.60305 .66828 Mdot
.55717 .50847 Mdot
.31727 .25399 Mdot
.40627 .59198 Mdot
.78719 .49412 Mdot
.52639 .21893 Mdot
.51587 .24279 Mdot
.3866 .34517 Mdot
.35807 .36085 Mdot
.39966 .56896 Mdot
.39218 .68295 Mdot
.58164 .63211 Mdot
.41072 .60956 Mdot
.3894 .51752 Mdot
.52318 .36057 Mdot
.60632 .64018 Mdot
.58957 .36805 Mdot
.69672 .34123 Mdot
.24281 .57707 Mdot
.5554 .16537 Mdot
.66453 .46097 Mdot
.4591 .21965 Mdot
.64864 .44654 Mdot
.26932 .41607 Mdot
.51771 .32159 Mdot
.40866 .54981 Mdot
.55278 .63044 Mdot
.42672 .595 Mdot
.39663 .53807 Mdot
.38667 .60259 Mdot
.45473 .57968 Mdot
.57754 .16294 Mdot
.39079 .3727 Mdot
.39576 .50481 Mdot
.53697 .33903 Mdot
.26987 .31037 Mdot
.33178 .27223 Mdot
.38628 .59961 Mdot
.3825 .55447 Mdot
.60071 .64435 Mdot
.38391 .52801 Mdot
.65259 .44789 Mdot
.57814 .59865 Mdot
.36502 .57118 Mdot
.18437 .59647 Mdot
.36245 .58462 Mdot
.25053 .60285 Mdot
.65451 .48955 Mdot
.6808 .26815 Mdot
.33163 .59723 Mdot
.75482 .46467 Mdot
.4551 .44282 Mdot
.5221 .32445 Mdot
.63376 .45644 Mdot
.54188 .36975 Mdot
.33842 .23096 Mdot
.44762 .62675 Mdot
.41864 .57001 Mdot
.40284 .52199 Mdot
.5059 .35482 Mdot
.15253 .55956 Mdot
.69755 .38701 Mdot
.46172 .62114 Mdot
.56159 .33965 Mdot
.62159 .62276 Mdot
.27596 .65016 Mdot
.59836 .66087 Mdot
.34743 .32922 Mdot
.70109 .49488 Mdot
.39598 .33591 Mdot
.25497 .48808 Mdot
.60703 .62813 Mdot
.5413 .63212 Mdot
.54587 .37969 Mdot
.53679 .66453 Mdot
.86663 .42881 Mdot
.70954 .67893 Mdot
.30054 .40796 Mdot
.57072 .62573 Mdot
.36753 .58874 Mdot
.25959 .44893 Mdot
.69399 .68751 Mdot
.54303 .36781 Mdot
.43867 .55108 Mdot
.5457 .69468 Mdot
.55658 .3345 Mdot
.33267 .55336 Mdot
.53242 .33773 Mdot
.66589 .49814 Mdot
.52988 .3764 Mdot
.59874 .69761 Mdot
.3632 .55677 Mdot
.87806 .42889 Mdot
.35082 .38941 Mdot
.4185 .57842 Mdot
.66616 .51528 Mdot
.63579 .2819 Mdot
.42135 .55201 Mdot
.41631 .34928 Mdot
.55878 .36644 Mdot
.51876 .61926 Mdot
.40014 .56416 Mdot
.56222 .34019 Mdot
.5877 .61008 Mdot
.71476 .51268 Mdot
.55576 .71329 Mdot
.64939 .57486 Mdot
.55445 .63221 Mdot
.6223 .5661 Mdot
.63299 .48225 Mdot
.42084 .61431 Mdot
.44895 .5546 Mdot
.57589 .65072 Mdot
.25997 .35724 Mdot
.35432 .54234 Mdot
.34718 .57626 Mdot
.52568 .3557 Mdot
.54759 .37334 Mdot
.50857 .81203 Mdot
.5788 .38257 Mdot
.32786 .5842 Mdot
.57869 .65293 Mdot
.42515 .56126 Mdot
.60188 .64062 Mdot
.38651 .52849 Mdot
.29652 .56464 Mdot
.591 .62845 Mdot
.73971 .4363 Mdot
.43957 .55643 Mdot
.34325 .52202 Mdot
.41112 .54165 Mdot
.43623 .59551 Mdot
.55768 .33881 Mdot
.39296 .34755 Mdot
.38306 .5188 Mdot
.42381 .33005 Mdot
.38304 .37406 Mdot
.64789 .52587 Mdot
.52238 .35817 Mdot
.39208 .36765 Mdot
.45338 .19546 Mdot
.57026 .35307 Mdot
.39816 .35808 Mdot
.32871 .27405 Mdot
.64828 .47587 Mdot
.55889 .61783 Mdot
.41282 .55932 Mdot
.28282 .49967 Mdot
.36326 .72466 Mdot
.48619 .35114 Mdot
.4086 .56952 Mdot
.4222 .54602 Mdot
.62342 .65737 Mdot
.24914 .29602 Mdot
.5501 .39661 Mdot
.37108 .59803 Mdot
.60564 .61756 Mdot
.17602 .36653 Mdot
.5381 .34397 Mdot
.39978 .35375 Mdot
.65024 .49109 Mdot
.48076 .63248 Mdot
.75878 .47879 Mdot
.67893 .51677 Mdot
.53618 .30699 Mdot
.70677 .3523 Mdot
.44941 .54198 Mdot
.56837 .38225 Mdot
.65483 .7883 Mdot
.54395 .55668 Mdot
.4784 .44825 Mdot
.37851 .78412 Mdot
.56141 .65381 Mdot
.65016 .44686 Mdot
.37704 .36608 Mdot
.58307 .67675 Mdot
.60273 .6256 Mdot
.70196 .50019 Mdot
.35383 .66199 Mdot
.61053 .42288 Mdot
.69636 .4875 Mdot
.34046 .46326 Mdot
.2402 .36739 Mdot
.5538 .38411 Mdot
.40373 .35431 Mdot
.23943 .49805 Mdot
.5876 .65108 Mdot
.24336 .70219 Mdot
.4139 .82018 Mdot
.41422 .58195 Mdot
.37907 .36325 Mdot
.15908 .54031 Mdot
.24318 .30784 Mdot
.65205 .46377 Mdot
.63445 .52049 Mdot
.37171 .32716 Mdot
.41435 .53901 Mdot
.39883 .46275 Mdot
.36122 .54269 Mdot
.69315 .5026 Mdot
.54864 .72159 Mdot
.60526 .62603 Mdot
.66956 .50813 Mdot
.29327 .52616 Mdot
.42129 .58951 Mdot
.43782 .55365 Mdot
.33706 .4391 Mdot
.58334 .67826 Mdot
.51924 .3256 Mdot
.44531 .54274 Mdot
.39658 .58318 Mdot
.33203 .59225 Mdot
.43153 .62689 Mdot
.4513 .69199 Mdot
.38247 .54532 Mdot
.4417 .22853 Mdot
.39222 .52468 Mdot
.43715 .58096 Mdot
.58794 .68448 Mdot
.52089 .15716 Mdot
.70065 .35962 Mdot
.39904 .58607 Mdot
.39462 .61162 Mdot
.66239 .50477 Mdot
.65621 .41894 Mdot
.65027 .70418 Mdot
.52313 .61303 Mdot
.46971 .82207 Mdot
.40777 .62103 Mdot
.61623 .62614 Mdot
.41414 .35566 Mdot
.43135 .61316 Mdot
.60569 .61158 Mdot
.34357 .57981 Mdot
.54834 .327 Mdot
.56909 .35005 Mdot
.56311 .57702 Mdot
.3976 .36804 Mdot
.77753 .60237 Mdot
.73509 .58176 Mdot
.57078 .35997 Mdot
.41487 .56697 Mdot
.66979 .43653 Mdot
.51479 .35629 Mdot
.53172 .29647 Mdot
.2286 .40535 Mdot
.5743 .62119 Mdot
.55644 .63675 Mdot
.2511 .40196 Mdot
.66932 .3169 Mdot
.80264 .47284 Mdot
.66773 .50038 Mdot
.38946 .50723 Mdot
.76055 .59217 Mdot
.55476 .64242 Mdot
.2655 .43281 Mdot
.38504 .36769 Mdot
.65315 .46604 Mdot
.69187 .41106 Mdot
.60522 .65246 Mdot
.56484 .60639 Mdot
.34137 .55102 Mdot
.38513 .58153 Mdot
.53215 .80247 Mdot
.42831 .33621 Mdot
.69928 .50842 Mdot
.40256 .35259 Mdot
.53362 .31819 Mdot
.36041 .54855 Mdot
.59094 .6319 Mdot
.22262 .38554 Mdot
.45322 .59034 Mdot
.53502 .32587 Mdot
.55869 .64873 Mdot
.35615 .33403 Mdot
.41393 .34198 Mdot
.43913 .59719 Mdot
.57115 .78019 Mdot
.6889 .4969 Mdot
.58442 .67151 Mdot
.60728 .44812 Mdot
.36316 .5389 Mdot
.38631 .57403 Mdot
.30841 .54937 Mdot
.6957 .51085 Mdot
.68332 .64729 Mdot
.41938 .34828 Mdot
.58892 .66842 Mdot
.38266 .54837 Mdot
.40197 .36053 Mdot
.74554 .5813 Mdot
.55239 .31988 Mdot
.52656 .37503 Mdot
.41229 .34156 Mdot
.37737 .34316 Mdot
.41849 .35495 Mdot
.24603 .70902 Mdot
.60528 .60475 Mdot
.64597 .59707 Mdot
.36855 .60245 Mdot
.28869 .4048 Mdot
.3806 .50602 Mdot
.64372 .458 Mdot
.52448 .34374 Mdot
.41047 .54597 Mdot
.44261 .59864 Mdot
.31524 .53018 Mdot
.78886 .45693 Mdot
.31068 .61056 Mdot
.60494 .63455 Mdot
.34189 .61297 Mdot
.53192 .37391 Mdot
.25357 .74106 Mdot
.46239 .84426 Mdot
.33576 .60473 Mdot
.63454 .4215 Mdot
.58502 .62274 Mdot
.68254 .50747 Mdot
.30335 .45825 Mdot
.64797 .48042 Mdot
.57949 .66324 Mdot
.37648 .54296 Mdot
.7157 .61109 Mdot
.37236 .38197 Mdot
.42625 .5991 Mdot
.67075 .50364 Mdot
.447 .56534 Mdot
.68448 .51407 Mdot
.27192 .51281 Mdot
.63132 .78476 Mdot
.41318 .58681 Mdot
.44298 .52531 Mdot
.56504 .7946 Mdot
.39609 .6044 Mdot
.40833 .30733 Mdot
.58412 .6218 Mdot
.56172 .72732 Mdot
.46098 .54072 Mdot
.3844 .47362 Mdot
.35581 .5465 Mdot
.59759 .73075 Mdot
.38307 .57505 Mdot
.50689 .23887 Mdot
.35705 .56205 Mdot
.4163 .52767 Mdot
.6765 .46926 Mdot
.66608 .50724 Mdot
.57679 .68513 Mdot
.52 .37993 Mdot
.24787 .6037 Mdot
.39204 .57709 Mdot
.73463 .34954 Mdot
.67863 .60003 Mdot
.38065 .34261 Mdot
.58474 .66542 Mdot
.17267 .38691 Mdot
.65506 .44204 Mdot
.51555 .83584 Mdot
.45503 .81443 Mdot
.69673 .55072 Mdot
.21246 .49565 Mdot
.5981 .25681 Mdot
.36324 .33073 Mdot
.34121 .56796 Mdot
.48217 .31082 Mdot
.50056 .23618 Mdot
.25471 .36101 Mdot
.6303 .4639 Mdot
.52594 .78435 Mdot
.20891 .45749 Mdot
.385 .32292 Mdot
.35351 .35591 Mdot
.6495 .49776 Mdot
.60329 .39171 Mdot
.47136 .54566 Mdot
.37224 .35499 Mdot
.50605 .36199 Mdot
.57287 .34935 Mdot
.51425 .38216 Mdot
.58453 .63293 Mdot
.46561 .84064 Mdot
.62649 .47299 Mdot
.64818 .45716 Mdot
.61037 .3223 Mdot
.28643 .55737 Mdot
.53829 .62043 Mdot
.53364 .36821 Mdot
.55019 .3878 Mdot
.58092 .61772 Mdot
.34879 .60816 Mdot
.45372 .62241 Mdot
.40252 .58958 Mdot
.39348 .35217 Mdot
.38041 .5799 Mdot
.56417 .34893 Mdot
.66115 .4624 Mdot
.53448 .38384 Mdot
.68098 .5196 Mdot
.20835 .39961 Mdot
.42255 .60959 Mdot
.36186 .55559 Mdot
.70648 .24485 Mdot
.55117 .6208 Mdot
.25318 .32745 Mdot
.73126 .46544 Mdot
.54631 .34514 Mdot
.41674 .53018 Mdot
.53435 .61573 Mdot
.41993 .37506 Mdot
.56464 .17317 Mdot
.37936 .53143 Mdot
.59363 .6483 Mdot
.36513 .54602 Mdot
.50674 .52614 Mdot
.82732 .51143 Mdot
.58624 .65631 Mdot
.79875 .44328 Mdot
.37037 .59523 Mdot
.46508 .20261 Mdot
.38918 .52584 Mdot
.4618 .47231 Mdot
.35456 .54214 Mdot
.59398 .67814 Mdot
.39778 .59016 Mdot
.54301 .60631 Mdot
.57498 .36793 Mdot
.6607 .50171 Mdot
.55571 .63179 Mdot
.45216 .57672 Mdot
.76972 .2201 Mdot
.65843 .48573 Mdot
.40512 .57315 Mdot
.64604 .48694 Mdot
.61238 .66239 Mdot
.57099 .66681 Mdot
.30545 .27552 Mdot
.69332 .33883 Mdot
.66463 .49581 Mdot
.36162 .5478 Mdot
.50695 .21982 Mdot
.39885 .54711 Mdot
.44475 .48474 Mdot
.35338 .61477 Mdot
.35531 .60131 Mdot
.28742 .29173 Mdot
.64347 .46252 Mdot
.8041 .46673 Mdot
.25708 .30424 Mdot
.27211 .30822 Mdot
.57626 .68791 Mdot
.39295 .32643 Mdot
.26045 .70494 Mdot
.75275 .37494 Mdot
.53727 .32205 Mdot
.41494 .54708 Mdot
.54452 .59029 Mdot
.69071 .49288 Mdot
.38244 .33315 Mdot
.41257 .58605 Mdot
.54659 .38595 Mdot
.71369 .71692 Mdot
.64648 .49958 Mdot
.59115 .65897 Mdot
.62578 .65022 Mdot
.39811 .18106 Mdot
.39599 .55909 Mdot
.36197 .56148 Mdot
.70119 .49514 Mdot
.61391 .26014 Mdot
.36376 .35649 Mdot
.58838 .74146 Mdot
.66372 .4931 Mdot
.55211 .4813 Mdot
.60169 .60739 Mdot
.42384 .54391 Mdot
.1917 .57905 Mdot
.67973 .40255 Mdot
.75612 .3133 Mdot
.39386 .35412 Mdot
.45451 .49134 Mdot
.5935 .67773 Mdot
.66653 .47489 Mdot
.66747 .2956 Mdot
.41346 .61917 Mdot
.43664 .54121 Mdot
.46779 .49105 Mdot
.64834 .52237 Mdot
.5974 .70595 Mdot
.37632 .53269 Mdot
.45456 .44072 Mdot
.38637 .53084 Mdot
.3912 .49716 Mdot
.37173 .62611 Mdot
.37922 .56555 Mdot
.59255 .63856 Mdot
.49643 .57199 Mdot
.50751 .34243 Mdot
.65373 .69288 Mdot
.54256 .48112 Mdot
.41386 .57545 Mdot
.34861 .57899 Mdot
.32464 .70491 Mdot
.63757 .31696 Mdot
.55868 .62975 Mdot
.55666 .67457 Mdot
.6681 .44317 Mdot
.39261 .62732 Mdot
.52203 .38119 Mdot
.37225 .51199 Mdot
.55457 .33548 Mdot
.5913 .63515 Mdot
.5432 .3449 Mdot
.65386 .49985 Mdot
.57722 .37724 Mdot
.74091 .3526 Mdot
.65735 .47527 Mdot
.56544 .62157 Mdot
.36808 .56938 Mdot
.66861 .51655 Mdot
.31996 .39607 Mdot
.39201 .35402 Mdot
.15667 .47028 Mdot
.36444 .57148 Mdot
.67425 .55195 Mdot
.35965 .49147 Mdot
.54097 .3864 Mdot
.82584 .49499 Mdot
.54929 .64016 Mdot
.37016 .37002 Mdot
.57506 .67563 Mdot
.34149 .48018 Mdot
.37972 .35042 Mdot
.17644 .41094 Mdot
.44481 .44702 Mdot
.4052 .45324 Mdot
.37205 .61983 Mdot
.3522 .43127 Mdot
.55827 .32729 Mdot
.68913 .49183 Mdot
.66231 .30515 Mdot
.42012 .52937 Mdot
.72593 .72847 Mdot
.58988 .68313 Mdot
.51203 .36154 Mdot
.67007 .47288 Mdot
.65047 .45356 Mdot
.38676 .61052 Mdot
.45825 .25829 Mdot
.43425 .53668 Mdot
.6848 .31761 Mdot
.4119 .81019 Mdot
.64924 .61168 Mdot
.40467 .5693 Mdot
.57087 .36518 Mdot
.36546 .54582 Mdot
.41889 .3437 Mdot
.55346 .82539 Mdot
.35275 .51896 Mdot
.71577 .47048 Mdot
.43112 .33916 Mdot
.60733 .67012 Mdot
.31164 .52814 Mdot
.64691 .58838 Mdot
.39305 .55617 Mdot
.50395 .12502 Mdot
.39896 .35987 Mdot
.49277 .30025 Mdot
.4584 .57732 Mdot
.44336 .60537 Mdot
.46688 .42375 Mdot
.77018 .44731 Mdot
.61828 .39331 Mdot
.4031 .60337 Mdot
.32263 .38412 Mdot
.64181 .48349 Mdot
.4079 .53728 Mdot
.4013 .57411 Mdot
.37041 .70335 Mdot
.63858 .47056 Mdot
.54362 .3327 Mdot
.52409 .32087 Mdot
.49635 .33254 Mdot
.42155 .35685 Mdot
.68311 .68327 Mdot
.28354 .42525 Mdot
.76554 .66725 Mdot
.36592 .37231 Mdot
.43637 .60493 Mdot
.54236 .28969 Mdot
.36917 .54164 Mdot
.38158 .33485 Mdot
.63816 .47497 Mdot
.55371 .64503 Mdot
.75578 .59213 Mdot
.55365 .32692 Mdot
.44239 .61294 Mdot
.37301 .36904 Mdot
.57595 .62315 Mdot
.27456 .46803 Mdot
.60567 .67041 Mdot
.67131 .495 Mdot
.68739 .68145 Mdot
.37736 .33232 Mdot
.61861 .64665 Mdot
.6946 .44742 Mdot
.27849 .28519 Mdot
.39945 .63123 Mdot
.7234 .63964 Mdot
.61394 .66725 Mdot
.5434 .65374 Mdot
.61744 .62299 Mdot
.44359 .58121 Mdot
.62779 .42194 Mdot
.37376 .6163 Mdot
.6416 .46881 Mdot
.53522 .33528 Mdot
.63792 .76895 Mdot
.74858 .41705 Mdot
.59024 .49001 Mdot
.35362 .52496 Mdot
.42051 .59062 Mdot
.4001 .5694 Mdot
.42077 .50533 Mdot
.74548 .3568 Mdot
.44229 .5785 Mdot
.67724 .46962 Mdot
.5602 .36153 Mdot
.34153 .57104 Mdot
.55619 .31576 Mdot
.31895 .28481 Mdot
.37386 .32629 Mdot
.60414 .47485 Mdot
.53535 .85157 Mdot
.57277 .62296 Mdot
.58085 .34547 Mdot
.56597 .35771 Mdot
.35742 .34143 Mdot
.69425 .49634 Mdot
.61153 .66685 Mdot
.47264 .51468 Mdot
.38506 .37466 Mdot
.39684 .58762 Mdot
.67342 .42916 Mdot
.70017 .74802 Mdot
.34171 .55839 Mdot
.4238 .55626 Mdot
.52264 .38911 Mdot
.49276 .30357 Mdot
.86854 .56048 Mdot
.30109 .43603 Mdot
.39111 .34014 Mdot
.39794 .33187 Mdot
.58098 .61487 Mdot
.45368 .5996 Mdot
.66086 .51087 Mdot
.57378 .70219 Mdot
.66959 .64801 Mdot
.79435 .55283 Mdot
.73596 .28738 Mdot
.39792 .53585 Mdot
.58011 .23064 Mdot
.42932 .58422 Mdot
.6132 .61316 Mdot
.58978 .64027 Mdot
.57246 .63608 Mdot
.68841 .49274 Mdot
.48571 .76836 Mdot
.68489 .47871 Mdot
.6263 .81349 Mdot
.58203 .67339 Mdot
.43394 .44009 Mdot
.53024 .36863 Mdot
.47273 .61424 Mdot
.36888 .32751 Mdot
.71329 .66153 Mdot
.31768 .59515 Mdot
.39154 .67343 Mdot
.51076 .35429 Mdot
.55834 .62626 Mdot
.61061 .26153 Mdot
.32205 .76522 Mdot
.53593 .66052 Mdot
.30004 .57761 Mdot
.30126 .46033 Mdot
.38392 .34091 Mdot
.75391 .30954 Mdot
.39804 .3395 Mdot
.66746 .50228 Mdot
.36775 .55101 Mdot
.36937 .56007 Mdot
.38423 .53018 Mdot
.4031 .6093 Mdot
.64084 .49702 Mdot
.40645 .51294 Mdot
.77289 .62664 Mdot
.54594 .32339 Mdot
.32705 .32768 Mdot
.40097 .34689 Mdot
.63534 .4607 Mdot
.56107 .36005 Mdot
.64336 .3226 Mdot
.33114 .41314 Mdot
.40221 .56597 Mdot
.4114 .54596 Mdot
.54316 .81689 Mdot
.37643 .53311 Mdot
.47903 .56941 Mdot
.55575 .33091 Mdot
.30783 .65574 Mdot
.37539 .32658 Mdot
.38763 .32746 Mdot
.65567 .47366 Mdot
.59184 .64 Mdot
.39238 .3632 Mdot
.52698 .36303 Mdot
.3439 .53114 Mdot
.42428 .51824 Mdot
.60802 .67151 Mdot
.55348 .81709 Mdot
.41051 .33383 Mdot
.50337 .21641 Mdot
.56443 .61983 Mdot
.60919 .68614 Mdot
.43501 .53973 Mdot
.77969 .36069 Mdot
.61328 .69514 Mdot
.40756 .37779 Mdot
.63371 .46127 Mdot
.31919 .45551 Mdot
.65779 .44351 Mdot
.59429 .66053 Mdot
.36036 .58708 Mdot
.58601 .6292 Mdot
.40203 .56368 Mdot
.37558 .8139 Mdot
.37412 .5648 Mdot
.7736 .65155 Mdot
.25586 .38918 Mdot
.56422 .37743 Mdot
.62871 .29937 Mdot
.55065 .38118 Mdot
.55305 .65434 Mdot
.46195 .56957 Mdot
.35521 .34984 Mdot
.37191 .24705 Mdot
.48666 .64644 Mdot
.5181 .34588 Mdot
.5822 .39073 Mdot
.63867 .44478 Mdot
.35072 .54559 Mdot
.44245 .55094 Mdot
.55076 .36891 Mdot
.64475 .68004 Mdot
.61083 .65382 Mdot
.37871 .55088 Mdot
.42302 .59104 Mdot
.56 .37944 Mdot
.28691 .27628 Mdot
.52132 .57604 Mdot
.37362 .55461 Mdot
.62725 .40465 Mdot
.64726 .45601 Mdot
.46782 .61712 Mdot
.44146 .52583 Mdot
.37417 .34373 Mdot
.48617 .68327 Mdot
.32117 .74551 Mdot
.63788 .47859 Mdot
.56658 .34775 Mdot
.38889 .55395 Mdot
.57029 .36336 Mdot
.40598 .51134 Mdot
.75989 .48066 Mdot
.58059 .3493 Mdot
.34993 .59038 Mdot
.34599 .60252 Mdot
.58933 .68009 Mdot
.40466 .54058 Mdot
.38092 .76312 Mdot
.52024 .33021 Mdot
.38123 .60752 Mdot
.5792 .75815 Mdot
.69495 .47798 Mdot
.42977 .62789 Mdot
.38754 .37404 Mdot
.41107 .47012 Mdot
.71673 .59121 Mdot
.21205 .5179 Mdot
.37111 .3248 Mdot
.44635 .57109 Mdot
.56304 .39636 Mdot
.69992 .50748 Mdot
.80633 .59925 Mdot
.41739 .53968 Mdot
.68235 .50485 Mdot
.66052 .46284 Mdot
.38045 .33139 Mdot
.4928 .15021 Mdot
.45508 .5828 Mdot
.3829 .59616 Mdot
.43509 .75606 Mdot
.55384 .60951 Mdot
.37699 .57352 Mdot
.37377 .59586 Mdot
.67313 .46462 Mdot
.47242 .57576 Mdot
.4604 .8069 Mdot
.5948 .73519 Mdot
.70791 .4835 Mdot
.76005 .61319 Mdot
.57722 .34688 Mdot
.40788 .35548 Mdot
.56628 .65324 Mdot
.36489 .35964 Mdot
.52435 .36822 Mdot
.36933 .58752 Mdot
.69952 .5003 Mdot
.37444 .75117 Mdot
.65127 .50083 Mdot
.21671 .43832 Mdot
.57251 .59927 Mdot
.61954 .48032 Mdot
.49259 .13089 Mdot
.65222 .38574 Mdot
.695 .53007 Mdot
.38012 .34279 Mdot
.59786 .32061 Mdot
.42458 .5896 Mdot
.73829 .28311 Mdot
.43141 .60852 Mdot
.56685 .74245 Mdot
.52737 .32128 Mdot
.50821 .37377 Mdot
.37115 .55176 Mdot
.3853 .78886 Mdot
.70564 .50188 Mdot
.6656 .45194 Mdot
.35512 .59441 Mdot
.67538 .49868 Mdot
.38418 .58609 Mdot
.56232 .34765 Mdot
.76894 .31283 Mdot
.40667 .58693 Mdot
.37956 .50134 Mdot
.70404 .53989 Mdot
.26408 .3038 Mdot
.36858 .31261 Mdot
.32775 .21657 Mdot
.37638 .80639 Mdot
.67646 .49801 Mdot
.37099 .61136 Mdot
.7668 .60128 Mdot
.53478 .39311 Mdot
.60047 .49354 Mdot
.37029 .58077 Mdot
.39711 .61033 Mdot
.40929 .52597 Mdot
.43561 .55534 Mdot
.61783 .2 Mdot
.51509 .64434 Mdot
.48152 .72279 Mdot
.39846 .53817 Mdot
.35645 .42239 Mdot
.65357 .48509 Mdot
.51707 .60484 Mdot
.37871 .37819 Mdot
.40028 .53719 Mdot
.56001 .6868 Mdot
.70278 .47759 Mdot
.65662 .80099 Mdot
.68968 .50447 Mdot
.55074 .33984 Mdot
.66995 .51097 Mdot
.42928 .57642 Mdot
.57454 .65465 Mdot
.47134 .40065 Mdot
.69062 .36674 Mdot
.51096 .33064 Mdot
.41805 .57808 Mdot
.38594 .41944 Mdot
.5089 .34469 Mdot
.24692 .32938 Mdot
.56519 .64648 Mdot
.31616 .36938 Mdot
.58848 .63331 Mdot
.35737 .59116 Mdot
.35652 .5892 Mdot
.65142 .43903 Mdot
.65814 .50469 Mdot
.58941 .63506 Mdot
.40452 .15556 Mdot
.41788 .3466 Mdot
.57513 .6397 Mdot
.45569 .52793 Mdot
.54398 .43216 Mdot
.57177 .64898 Mdot
.42839 .37314 Mdot
.66555 .46223 Mdot
.56039 .61295 Mdot
.37624 .52269 Mdot
.34658 .46274 Mdot
.41261 .34615 Mdot
.50015 .3396 Mdot
.26331 .45455 Mdot
.51908 .33692 Mdot
.63274 .45822 Mdot
.55639 .38126 Mdot
.6512 .45752 Mdot
.6968 .61063 Mdot
.65967 .68563 Mdot
.46899 .34291 Mdot
.62771 .46347 Mdot
.54494 .37926 Mdot
.36665 .54872 Mdot
.33768 .37345 Mdot
.46341 .57811 Mdot
.44866 .55984 Mdot
.6691 .45672 Mdot
.57746 .67395 Mdot
.56868 .68357 Mdot
.42821 .46717 Mdot
.59585 .64305 Mdot
.53128 .32671 Mdot
.44376 .67708 Mdot
.74031 .36787 Mdot
.6728 .44864 Mdot
.65898 .50186 Mdot
.372 .53847 Mdot
.5421 .36919 Mdot
.50119 .34657 Mdot
.65175 .44259 Mdot
.78224 .45723 Mdot
.43245 .51474 Mdot
.56059 .67998 Mdot
.55896 .60782 Mdot
.58324 .65535 Mdot
.59181 .59564 Mdot
.39649 .47453 Mdot
.64917 .46982 Mdot
.56915 .66966 Mdot
.37151 .53776 Mdot
.375 .59511 Mdot
.67746 .70029 Mdot
.41087 .35949 Mdot
.34575 .59024 Mdot
.3707 .62524 Mdot
.42496 .54356 Mdot
.53702 .38106 Mdot
.48469 .5689 Mdot
.58387 .37296 Mdot
.53297 .39051 Mdot
.53175 .39052 Mdot
.75919 .39173 Mdot
.50134 .83147 Mdot
.26627 .65676 Mdot
.38224 .60682 Mdot
.54406 .21944 Mdot
.53519 .35557 Mdot
.52023 .65946 Mdot
.67935 .64201 Mdot
.41808 .53178 Mdot
.42475 .23782 Mdot
.55186 .37245 Mdot
.57208 .6165 Mdot
.37096 .57275 Mdot
.5692 .33017 Mdot
.40194 .37317 Mdot
.41766 .61709 Mdot
.54491 .31657 Mdot
.61918 .6435 Mdot
.4253 .35464 Mdot
.55089 .62386 Mdot
.53459 .39213 Mdot
.47004 .56007 Mdot
.83015 .40346 Mdot
.54922 .31581 Mdot
.41151 .20735 Mdot
.38881 .6474 Mdot
.37425 .54834 Mdot
.58968 .35277 Mdot
.61851 .68354 Mdot
.63416 .45707 Mdot
.5832 .53147 Mdot
.59069 .61773 Mdot
.5084 .37421 Mdot
.52061 .37751 Mdot
.51123 .33031 Mdot
.60131 .62787 Mdot
.42694 .62471 Mdot
.60449 .64335 Mdot
.67441 .51226 Mdot
.40942 .55565 Mdot
.25911 .57816 Mdot
.6253 .26437 Mdot
.57212 .61833 Mdot
.53177 .3323 Mdot
.36082 .37475 Mdot
.42085 .58725 Mdot
.59695 .24552 Mdot
.36728 .54703 Mdot
.65374 .455 Mdot
.42519 .70073 Mdot
.31734 .67169 Mdot
.36312 .60802 Mdot
.3803 .5387 Mdot
.66917 .45322 Mdot
.41487 .58083 Mdot
.3536 .54287 Mdot
.74015 .35073 Mdot
.60928 .64284 Mdot
.40124 .59264 Mdot
.53101 .34109 Mdot
.71808 .36048 Mdot
.41544 .50639 Mdot
.55756 .30316 Mdot
.32861 .38609 Mdot
.39264 .69616 Mdot
.42884 .61025 Mdot
.64134 .42819 Mdot
.4376 .54842 Mdot
.42302 .604 Mdot
.38102 .5412 Mdot
.57016 .19811 Mdot
.55909 .32443 Mdot
.56623 .36554 Mdot
.40472 .3366 Mdot
.32502 .38202 Mdot
.37314 .3548 Mdot
.65808 .46067 Mdot
.46446 .26972 Mdot
.58698 .3676 Mdot
.60515 .66241 Mdot
.42957 .59471 Mdot
.55862 .3202 Mdot
.42422 .53955 Mdot
.42793 .57558 Mdot
.53863 .39157 Mdot
.56663 .33214 Mdot
.23711 .3767 Mdot
.41149 .36247 Mdot
.57007 .63037 Mdot
.34393 .56797 Mdot
.3782 .37212 Mdot
.43925 .60323 Mdot
.28717 .40572 Mdot
.5699 .63486 Mdot
.60844 .64487 Mdot
.59026 .69482 Mdot
.36676 .58054 Mdot
.42607 .58145 Mdot
.6847 .47736 Mdot
.55002 .6447 Mdot
.69686 .48092 Mdot
.55334 .51352 Mdot
.3632 .2856 Mdot
.37032 .58142 Mdot
.70051 .67915 Mdot
.383 .36891 Mdot
.51762 .34971 Mdot
.68543 .75634 Mdot
.40504 .3368 Mdot
.39655 .56073 Mdot
.51391 .37306 Mdot
.36969 .33601 Mdot
.48953 .50726 Mdot
.59506 .81824 Mdot
.35666 .36925 Mdot
.37259 .53755 Mdot
.47271 .56576 Mdot
.34571 .20666 Mdot
.35134 .33375 Mdot
.64986 .48821 Mdot
.36615 .57822 Mdot
.53952 .63911 Mdot
.37241 .36888 Mdot
.58363 .27513 Mdot
.55756 .36874 Mdot
.35633 .46303 Mdot
.33829 .52704 Mdot
.44204 .64513 Mdot
.40616 .34032 Mdot
.58989 .67033 Mdot
.46052 .5188 Mdot
.4349 .54096 Mdot
.3523 .33214 Mdot
.71215 .51606 Mdot
.55636 .35597 Mdot
.69622 .35114 Mdot
.59908 .62429 Mdot
.74177 .4425 Mdot
.52159 .34448 Mdot
.49029 .21295 Mdot
.65701 .72903 Mdot
.46223 .61802 Mdot
.45696 .18609 Mdot
.65772 .56596 Mdot
.3791 .52683 Mdot
.39643 .38407 Mdot
.67416 .51908 Mdot
.69705 .4677 Mdot
.66717 .492 Mdot
.6867 .61126 Mdot
.52225 .61481 Mdot
.52492 .3146 Mdot
.71891 .45434 Mdot
.40738 .35796 Mdot
.33138 .44979 Mdot
.44644 .55033 Mdot
.4153 .59189 Mdot
.34845 .55444 Mdot
.40042 .536 Mdot
.44279 .57311 Mdot
.6899 .5006 Mdot
.6915 .59523 Mdot
.52058 .62975 Mdot
.56994 .64225 Mdot
.51992 .28688 Mdot
.52776 .35785 Mdot
.50462 .37387 Mdot
.36474 .3464 Mdot
.63214 .38021 Mdot
.55149 .31376 Mdot
.54483 .34364 Mdot
.33916 .57916 Mdot
.60637 .65206 Mdot
.48285 .60219 Mdot
.37684 .53785 Mdot
.54177 .32732 Mdot
.49388 .45542 Mdot
.4057 .78978 Mdot
.28866 .32204 Mdot
.41812 .3316 Mdot
.69631 .44268 Mdot
.38062 .32406 Mdot
.45002 .5459 Mdot
.82248 .52397 Mdot
.52534 .37004 Mdot
.54645 .3561 Mdot
.40592 .36573 Mdot
.77956 .35688 Mdot
.56341 .65399 Mdot
.74424 .43843 Mdot
.64274 .47599 Mdot
.35733 .5854 Mdot
.70392 .72731 Mdot
.52068 .60002 Mdot
.44816 .25919 Mdot
.66163 .48922 Mdot
.57684 .36911 Mdot
.43209 .52111 Mdot
.39025 .53972 Mdot
.37368 .36124 Mdot
.18963 .52542 Mdot
.39215 .63195 Mdot
.14801 .56094 Mdot
.63291 .78462 Mdot
.29604 .70368 Mdot
.43845 .54351 Mdot
.60697 .63985 Mdot
.54002 .32018 Mdot
.40464 .35399 Mdot
.42626 .61859 Mdot
.38157 .79887 Mdot
.59867 .67421 Mdot
.66066 .47716 Mdot
.5268 .46495 Mdot
.31404 .44961 Mdot
.44056 .58903 Mdot
.38171 .60302 Mdot
.42917 .60121 Mdot
.84598 .64289 Mdot
.56702 .38342 Mdot
.57698 .61814 Mdot
.37653 .33101 Mdot
.59627 .65064 Mdot
.57074 .37371 Mdot
.43403 .40506 Mdot
.35794 .55709 Mdot
.62086 .65303 Mdot
.58464 .66854 Mdot
.69878 .47316 Mdot
.6368 .48006 Mdot
.54145 .48587 Mdot
.37599 .56598 Mdot
.58478 .37986 Mdot
.57638 .67443 Mdot
.67069 .43167 Mdot
.37799 .34998 Mdot
.66624 .46155 Mdot
.40326 .54061 Mdot
.58403 .37148 Mdot
.33428 .5864 Mdot
.55663 .63448 Mdot
.54421 .34465 Mdot
.23789 .36592 Mdot
.3756 .32597 Mdot
.37651 .59459 Mdot
.32014 .31248 Mdot
.56481 .34379 Mdot
.43163 .58477 Mdot
.42825 .21585 Mdot
.40903 .38594 Mdot
.69604 .38956 Mdot
.50937 .36307 Mdot
.73248 .51232 Mdot
.58282 .61493 Mdot
.76377 .4541 Mdot
.55031 .34937 Mdot
.5217 .22291 Mdot
.21227 .40754 Mdot
.37633 .51718 Mdot
.58612 .64983 Mdot
.71956 .52572 Mdot
.30246 .77526 Mdot
.37314 .21881 Mdot
.40428 .5733 Mdot
.57574 .38423 Mdot
.36765 .3421 Mdot
.67564 .45157 Mdot
.72271 .40254 Mdot
.35775 .38768 Mdot
.59768 .34943 Mdot
.38168 .54171 Mdot
.60946 .66667 Mdot
.67938 .47882 Mdot
.71371 .59791 Mdot
.52624 .35407 Mdot
.53212 .33528 Mdot
.45979 .58034 Mdot
.38761 .36849 Mdot
.65355 .25119 Mdot
.55942 .33727 Mdot
.57065 .80038 Mdot
.51927 .39277 Mdot
.39976 .37553 Mdot
.43203 .55155 Mdot
.4035 .46213 Mdot
.41488 .61801 Mdot
.36736 .23951 Mdot
.52991 .36533 Mdot
.56396 .63032 Mdot
.43645 .53493 Mdot
.59609 .76498 Mdot
.53129 .3273 Mdot
.66789 .42447 Mdot
.61943 .34174 Mdot
.64817 .46628 Mdot
.68657 .75477 Mdot
.3778 .58091 Mdot
.69885 .50829 Mdot
.37061 .35506 Mdot
.37577 .55951 Mdot
.43043 .57854 Mdot
.62096 .66395 Mdot
.69525 .4692 Mdot
.24257 .3693 Mdot
.67174 .50799 Mdot
.65493 .49144 Mdot
.53291 .63213 Mdot
.39214 .59659 Mdot
.54906 .3369 Mdot
.55002 .37166 Mdot
.37224 .52372 Mdot
.70164 .22081 Mdot
.56951 .66078 Mdot
.49712 .34881 Mdot
.86602 .6117 Mdot
.36139 .52966 Mdot
.66953 .75356 Mdot
.18795 .50845 Mdot
.64975 .50147 Mdot
.37107 .53743 Mdot
.61705 .65569 Mdot
.61955 .38889 Mdot
.53461 .33325 Mdot
.37855 .52117 Mdot
.67939 .48107 Mdot
.41418 .3603 Mdot
.51209 .3344 Mdot
.45591 .25967 Mdot
.4177 .61038 Mdot
.40352 .25612 Mdot
.54899 .39066 Mdot
.24531 .66656 Mdot
.64908 .31443 Mdot
.58365 .64605 Mdot
.42934 .57256 Mdot
.55308 .62859 Mdot
.36663 .33283 Mdot
.5297 .46769 Mdot
.6714 .46807 Mdot
.30207 .52839 Mdot
.82015 .54816 Mdot
.5116 .32988 Mdot
.56661 .61774 Mdot
.36189 .60251 Mdot
.77148 .44936 Mdot
.38016 .58578 Mdot
.34093 .50693 Mdot
.25313 .35896 Mdot
.68082 .46258 Mdot
.64359 .487 Mdot
.43978 .56341 Mdot
.35759 .34561 Mdot
.52678 .35983 Mdot
.55693 .34492 Mdot
.22019 .65562 Mdot
.74454 .44441 Mdot
.52496 .80611 Mdot
.3984 .61053 Mdot
.59427 .37296 Mdot
.7511 .44703 Mdot
.6985 .4991 Mdot
.44241 .62208 Mdot
.51548 .37345 Mdot
.32432 .33438 Mdot
.46784 .48797 Mdot
.4374 .54534 Mdot
.46712 .57073 Mdot
.64693 .48961 Mdot
.53035 .63803 Mdot
.57322 .35939 Mdot
.34106 .60698 Mdot
.44624 .38724 Mdot
.48582 .50205 Mdot
.63243 .79248 Mdot
.57037 .63041 Mdot
.47976 .24541 Mdot
.69184 .49971 Mdot
.36458 .50522 Mdot
.37439 .32834 Mdot
.60147 .3702 Mdot
.58393 .35928 Mdot
.39077 .55217 Mdot
.42713 .51883 Mdot
.61265 .7818 Mdot
.60421 .65821 Mdot
.6528 .47889 Mdot
.36391 .56199 Mdot
.74111 .62024 Mdot
.38053 .53008 Mdot
.68861 .47879 Mdot
.82484 .38444 Mdot
.44979 .60363 Mdot
.38128 .59181 Mdot
.6506 .25081 Mdot
.58432 .61048 Mdot
.57271 .67645 Mdot
.73568 .71561 Mdot
.39568 .60966 Mdot
.64642 .7775 Mdot
.56806 .62574 Mdot
.55927 .65232 Mdot
.70281 .32525 Mdot
.41604 .58946 Mdot
.53828 .57526 Mdot
.64416 .46196 Mdot
.65472 .49255 Mdot
.60275 .63501 Mdot
.43256 .63121 Mdot
.63762 .46304 Mdot
.61248 .21254 Mdot
.5407 .36927 Mdot
.8097 .47036 Mdot
.57407 .66566 Mdot
.63553 .54195 Mdot
.6706 .50252 Mdot
.58123 .82813 Mdot
.67608 .41062 Mdot
.3631 .55166 Mdot
.40165 .61081 Mdot
.40564 .36434 Mdot
.34557 .58041 Mdot
.50751 .37215 Mdot
.67478 .49887 Mdot
.36619 .76681 Mdot
.57294 .63611 Mdot
.38335 .57329 Mdot
.42122 .2294 Mdot
.20568 .3875 Mdot
.52912 .25392 Mdot
.59671 .67267 Mdot
.58528 .63657 Mdot
.57527 .3775 Mdot
.56598 .38847 Mdot
.411 .60027 Mdot
.66003 .44843 Mdot
.54996 .63616 Mdot
.68463 .47133 Mdot
.5236 .36791 Mdot
.54883 .33975 Mdot
.54982 .31992 Mdot
.44069 .53808 Mdot
.54097 .33842 Mdot
.29556 .30742 Mdot
.70705 .43027 Mdot
.53558 .62786 Mdot
.76985 .71059 Mdot
.71377 .60347 Mdot
.46047 .63873 Mdot
.39441 .37776 Mdot
.544 .32383 Mdot
.68843 .51172 Mdot
.42181 .5596 Mdot
.41459 .54466 Mdot
.75675 .39392 Mdot
.69716 .50729 Mdot
.37554 .33157 Mdot
.67764 .51574 Mdot
.37822 .33084 Mdot
.41803 .25553 Mdot
.34843 .5468 Mdot
.40422 .51347 Mdot
.67749 .50208 Mdot
.54296 .34105 Mdot
.56238 .36755 Mdot
.34984 .35443 Mdot
.48531 .45458 Mdot
.50955 .3465 Mdot
.56156 .65725 Mdot
.30553 .69861 Mdot
.53816 .38771 Mdot
.37274 .57258 Mdot
.27789 .42337 Mdot
.71602 .25554 Mdot
.42291 .50632 Mdot
.70859 .32208 Mdot
.39429 .7552 Mdot
.42943 .52961 Mdot
.72325 .26208 Mdot
.71374 .49712 Mdot
.59304 .62434 Mdot
.55674 .3301 Mdot
.49983 .3822 Mdot
.48801 .61494 Mdot
.42632 .35073 Mdot
.45396 .60658 Mdot
.62106 .65062 Mdot
.62616 .6495 Mdot
.38976 .45379 Mdot
.37473 .22667 Mdot
.37087 .33703 Mdot
.36636 .3494 Mdot
.55249 .34742 Mdot
.15324 .47657 Mdot
.31044 .53685 Mdot
.38315 .33367 Mdot
.63681 .68177 Mdot
.38579 .54496 Mdot
.31801 .3491 Mdot
.62962 .60151 Mdot
.60222 .632 Mdot
.37472 .43145 Mdot
.53798 .32848 Mdot
.59638 .64116 Mdot
.76336 .57856 Mdot
.40698 .62608 Mdot
.57081 .63644 Mdot
.68413 .47321 Mdot
.64654 .34185 Mdot
.56724 .66415 Mdot
.28491 .41774 Mdot
.64831 .44457 Mdot
.6709 .43226 Mdot
.45077 .47891 Mdot
.1342 .38413 Mdot
.68331 .50083 Mdot
.51886 .37526 Mdot
.55047 .37083 Mdot
.55648 .34442 Mdot
.59799 .65244 Mdot
.51147 .32968 Mdot
.60206 .65936 Mdot
.40683 .18813 Mdot
.74597 .30223 Mdot
.38908 .33793 Mdot
.6937 .34976 Mdot
.59969 .66716 Mdot
.71513 .68754 Mdot
.57325 .12973 Mdot
.36523 .53931 Mdot
.68976 .4588 Mdot
.38808 .33848 Mdot
.15706 .51091 Mdot
.37636 .34068 Mdot
.41935 .82174 Mdot
.37717 .67373 Mdot
.38781 .57974 Mdot
.52354 .77519 Mdot
.3555 .36182 Mdot
.60125 .60948 Mdot
.43079 .58491 Mdot
.52087 .5021 Mdot
.37052 .34467 Mdot
.40985 .37021 Mdot
.4046 .59797 Mdot
.558 .62653 Mdot
.52906 .33225 Mdot
.6612 .50142 Mdot
.36419 .36185 Mdot
.44799 .50954 Mdot
.37838 .61122 Mdot
.36009 .5509 Mdot
.69404 .68794 Mdot
.41852 .37878 Mdot
.67749 .4978 Mdot
.51441 .16379 Mdot
.56265 .39591 Mdot
.47074 .46575 Mdot
.60189 .79882 Mdot
.65848 .6038 Mdot
.53079 .36561 Mdot
.57004 .36587 Mdot
.44246 .57494 Mdot
.29598 .62618 Mdot
.37544 .66177 Mdot
.44211 .42652 Mdot
.50852 .32679 Mdot
.55743 .3505 Mdot
.56559 .675 Mdot
.27066 .61649 Mdot
.40955 .49899 Mdot
.6397 .48444 Mdot
.57929 .34828 Mdot
.73928 .30716 Mdot
.39964 .36665 Mdot
.40779 .68576 Mdot
.34494 .55259 Mdot
.3624 .55427 Mdot
.67464 .48025 Mdot
.68418 .47886 Mdot
.62463 .35998 Mdot
.31629 .73368 Mdot
.38275 .74998 Mdot
.6952 .58309 Mdot
.37931 .69397 Mdot
.58791 .68243 Mdot
.57147 .61834 Mdot
.68582 .37538 Mdot
.6863 .50746 Mdot
.4295 .52828 Mdot
.5912 .63774 Mdot
.32358 .35356 Mdot
.32381 .50741 Mdot
.33677 .48823 Mdot
.65075 .76274 Mdot
.40772 .56785 Mdot
.61402 .6436 Mdot
.58103 .60774 Mdot
.56762 .60465 Mdot
.65427 .53256 Mdot
.4026 .60353 Mdot
.40752 .57109 Mdot
.44312 .54972 Mdot
.78195 .39973 Mdot
.41442 .60578 Mdot
.67546 .54164 Mdot
.54556 .47146 Mdot
.51278 .6807 Mdot
.34601 .61283 Mdot
.68663 .51525 Mdot
.44182 .59424 Mdot
.35685 .34443 Mdot
.35327 .55299 Mdot
.32819 .49572 Mdot
.65695 .48644 Mdot
.49535 .56963 Mdot
.70015 .61421 Mdot
.40159 .52623 Mdot
.40282 .37933 Mdot
.66964 .63511 Mdot
.28388 .73198 Mdot
.39042 .31281 Mdot
.56288 .6575 Mdot
.53557 .36667 Mdot
.69396 .51005 Mdot
.54729 .3481 Mdot
.38877 .51856 Mdot
.67455 .37236 Mdot
.16327 .51157 Mdot
.51598 .48946 Mdot
.40423 .53887 Mdot
.32386 .5241 Mdot
.55636 .65077 Mdot
.53779 .39185 Mdot
.63263 .66356 Mdot
.44343 .58203 Mdot
.39469 .35132 Mdot
.37252 .35789 Mdot
.57335 .52425 Mdot
.22263 .59361 Mdot
.67993 .25875 Mdot
.67692 .4859 Mdot
.55604 .33319 Mdot
.3685 .32736 Mdot
.54672 .23554 Mdot
.71845 .50858 Mdot
.66312 .45352 Mdot
.65513 .48141 Mdot
.3663 .58786 Mdot
.56842 .3328 Mdot
.51659 .68359 Mdot
.57479 .39546 Mdot
.41771 .58079 Mdot
.54029 .383 Mdot
.5119 .35646 Mdot
.40112 .35476 Mdot
.65368 .48247 Mdot
.52574 .36843 Mdot
.36229 .59398 Mdot
.5709 .62359 Mdot
.65091 .52144 Mdot
.25086 .38143 Mdot
.37673 .22947 Mdot
.57848 .56602 Mdot
.58864 .61157 Mdot
.27008 .70534 Mdot
.64287 .45996 Mdot
.78472 .44191 Mdot
.23326 .3818 Mdot
.45585 .58613 Mdot
.72403 .24067 Mdot
.58623 .39908 Mdot
.51338 .35177 Mdot
.43331 .55064 Mdot
.61056 .38251 Mdot
.38362 .57745 Mdot
.51884 .36103 Mdot
.70577 .4185 Mdot
.53652 .60882 Mdot
.53847 .3434 Mdot
.3309 .58604 Mdot
.43569 .57539 Mdot
.60617 .64077 Mdot
.58699 .37261 Mdot
.45439 .60126 Mdot
.24767 .72123 Mdot
.68866 .484 Mdot
.66284 .60114 Mdot
.26445 .42428 Mdot
.69517 .49764 Mdot
.57671 .64317 Mdot
.44954 .56359 Mdot
.36952 .35304 Mdot
.60421 .66627 Mdot
.30425 .51924 Mdot
.39594 .334 Mdot
.81315 .42257 Mdot
.58172 .60741 Mdot
.51829 .34285 Mdot
.35778 .33604 Mdot
.37466 .61589 Mdot
.55427 .3977 Mdot
.62829 .30292 Mdot
.52976 .36115 Mdot
.44526 .56576 Mdot
.72743 .38752 Mdot
.65188 .47928 Mdot
.39998 .57044 Mdot
.51527 .34045 Mdot
.70974 .32517 Mdot
.37542 .60079 Mdot
.4407 .55773 Mdot
.58454 .80571 Mdot
.59582 .71641 Mdot
.37805 .34493 Mdot
.54704 .63026 Mdot
.36961 .53811 Mdot
.38903 .37478 Mdot
.4513 .31738 Mdot
.36068 .57317 Mdot
.60008 .67416 Mdot
.44664 .62055 Mdot
.57804 .38207 Mdot
.69621 .48512 Mdot
.44208 .43377 Mdot
.40049 .37357 Mdot
.21875 .30221 Mdot
.57989 .35556 Mdot
.44994 .55514 Mdot
.38205 .53105 Mdot
.24815 .48145 Mdot
.59579 .63015 Mdot
.64445 .63968 Mdot
.37731 .5959 Mdot
.78532 .40049 Mdot
.38108 .56297 Mdot
.60597 .38539 Mdot
.56271 .65386 Mdot
.38858 .60101 Mdot
.62819 .49203 Mdot
.38476 .5009 Mdot
.41202 .34962 Mdot
.63184 .2587 Mdot
.42439 .62361 Mdot
.81955 .39721 Mdot
.55879 .53439 Mdot
.53741 .34192 Mdot
.32688 .28513 Mdot
.24267 .71938 Mdot
.68861 .61873 Mdot
.59517 .65228 Mdot
.17982 .51051 Mdot
.54861 .33657 Mdot
.38036 .2535 Mdot
.29096 .75502 Mdot
.43561 .56767 Mdot
.44208 .58641 Mdot
.29335 .46229 Mdot
.5481 .39578 Mdot
.57793 .38845 Mdot
.36159 .52161 Mdot
.39002 .49927 Mdot
.544 .33594 Mdot
.4279 .61484 Mdot
.35672 .62417 Mdot
.69207 .46174 Mdot
.58999 .674 Mdot
.67881 .45941 Mdot
.64643 .45337 Mdot
.59533 .22914 Mdot
.53575 .52579 Mdot
.69068 .48162 Mdot
.65547 .50891 Mdot
.33536 .39065 Mdot
.35727 .76467 Mdot
.36443 .35929 Mdot
.22979 .63916 Mdot
.55509 .35518 Mdot
.39281 .60011 Mdot
.56342 .6067 Mdot
.36298 .73379 Mdot
.44895 .33057 Mdot
.79739 .58597 Mdot
.44325 .54694 Mdot
.53004 .32837 Mdot
.65013 .57878 Mdot
.48318 .59059 Mdot
.51863 .31438 Mdot
.36534 .56695 Mdot
.5107 .37857 Mdot
.41883 .80304 Mdot
.52633 .22609 Mdot
.49674 .37674 Mdot
.54066 .64328 Mdot
.36544 .5562 Mdot
.61828 .62792 Mdot
.69746 .49928 Mdot
.35932 .35188 Mdot
.37527 .34872 Mdot
.42009 .593 Mdot
.30209 .56643 Mdot
.40124 .26759 Mdot
.42379 .58583 Mdot
.38956 .54591 Mdot
.70443 .46267 Mdot
.38322 .54104 Mdot
.39022 .53007 Mdot
.42322 .53574 Mdot
.41386 .5251 Mdot
.65423 .49103 Mdot
.63216 .37479 Mdot
.44384 .63634 Mdot
.32114 .57658 Mdot
.63667 .45335 Mdot
.19579 .48937 Mdot
.63947 .46075 Mdot
.30265 .76859 Mdot
.64781 .49666 Mdot
.38242 .3515 Mdot
.20616 .49722 Mdot
.32165 .55751 Mdot
.60414 .67706 Mdot
.60143 .4846 Mdot
.36055 .33675 Mdot
.66973 .49541 Mdot
.5177 .36534 Mdot
.59808 .80652 Mdot
.57434 .58898 Mdot
.54714 .68432 Mdot
.66121 .63082 Mdot
.63842 .3676 Mdot
.5789 .37552 Mdot
.59291 .60563 Mdot
.45649 .80232 Mdot
.39568 .53296 Mdot
.38709 .37461 Mdot
.41273 .59887 Mdot
.70057 .49836 Mdot
.54526 .33052 Mdot
.38977 .20326 Mdot
.37453 .36224 Mdot
.74467 .73357 Mdot
.5601 .37122 Mdot
.40629 .53587 Mdot
.63775 .46313 Mdot
.81274 .64519 Mdot
.67871 .46129 Mdot
.32037 .63342 Mdot
.58115 .61699 Mdot
.32221 .22595 Mdot
.59297 .66261 Mdot
.60565 .28174 Mdot
.8831 .50477 Mdot
.50387 .2282 Mdot
.56649 .6219 Mdot
.42867 .40402 Mdot
.39362 .55765 Mdot
.35926 .55209 Mdot
.46491 .20038 Mdot
.55044 .62032 Mdot
.39067 .536 Mdot
.75624 .41419 Mdot
.74132 .44978 Mdot
.65623 .74655 Mdot
.57262 .37748 Mdot
.37952 .57701 Mdot
.69635 .46092 Mdot
.7096 .49315 Mdot
.57191 .35068 Mdot
.65661 .45345 Mdot
.40948 .57378 Mdot
.59864 .66675 Mdot
.53778 .30388 Mdot
.38436 .36145 Mdot
.16686 .46284 Mdot
.39908 .32694 Mdot
.53144 .367 Mdot
.46493 .57352 Mdot
.54864 .34063 Mdot
.42857 .89164 Mdot
.39509 .56258 Mdot
.56657 .6263 Mdot
.39067 .54197 Mdot
.36909 .55379 Mdot
.4217 .52441 Mdot
.52954 .33419 Mdot
.26724 .34204 Mdot
.37197 .601 Mdot
.66863 .46535 Mdot
.43734 .70895 Mdot
.35494 .60599 Mdot
.49701 .30649 Mdot
.35762 .47499 Mdot
.69033 .67181 Mdot
.56383 .6125 Mdot
.53382 .34777 Mdot
.57508 .63361 Mdot
.79658 .41581 Mdot
.57662 .6434 Mdot
.41192 .72542 Mdot
.47078 .80672 Mdot
.54981 .78745 Mdot
.56822 .78176 Mdot
.47202 .41282 Mdot
.5478 .62585 Mdot
.41693 .32152 Mdot
.55037 .63798 Mdot
.59821 .62782 Mdot
.63399 .13803 Mdot
.62264 .64518 Mdot
.37202 .57909 Mdot
.34108 .57994 Mdot
.55202 .24892 Mdot
.29181 .37858 Mdot
.40718 .55309 Mdot
.40466 .5466 Mdot
.36362 .32896 Mdot
.79385 .42232 Mdot
.68417 .3869 Mdot
.6048 .71808 Mdot
.2168 .38041 Mdot
.40934 .59848 Mdot
.35613 .54721 Mdot
.34489 .62029 Mdot
.8349 .57353 Mdot
.56115 .21068 Mdot
.54292 .65621 Mdot
.3248 .56132 Mdot
.43954 .2238 Mdot
.44164 .54255 Mdot
.37574 .5983 Mdot
.40262 .56407 Mdot
.54824 .33568 Mdot
.55546 .61808 Mdot
.38464 .5204 Mdot
.23554 .48886 Mdot
.36894 .58481 Mdot
.65125 .56453 Mdot
.20452 .33725 Mdot
.37741 .58179 Mdot
.58857 .68661 Mdot
.36097 .54915 Mdot
.60094 .64039 Mdot
.60958 .6285 Mdot
.34578 .52916 Mdot
.37193 .6883 Mdot
.56526 .67576 Mdot
.41854 .58096 Mdot
.5172 .36942 Mdot
.24105 .64577 Mdot
.44228 .57795 Mdot
.36591 .36063 Mdot
.39499 .60894 Mdot
.42066 .36567 Mdot
.39715 .55112 Mdot
.57773 .35154 Mdot
.35736 .71963 Mdot
.54809 .35503 Mdot
.47857 .18549 Mdot
.5583 .32458 Mdot
.71191 .75875 Mdot
.59187 .61367 Mdot
.71094 .37053 Mdot
.80856 .5046 Mdot
.76523 .42888 Mdot
.60276 .4359 Mdot
.50151 .43116 Mdot
.66131 .44905 Mdot
.59117 .62701 Mdot
.77551 .51112 Mdot
.50409 .29127 Mdot
.52052 .26908 Mdot
.50778 .34112 Mdot
.47196 .14486 Mdot
.80894 .41755 Mdot
.44851 .54149 Mdot
.47888 .78155 Mdot
.49764 .7466 Mdot
.43546 .53276 Mdot
.41924 .52067 Mdot
.5414 .40413 Mdot
.39908 .61456 Mdot
.73818 .62791 Mdot
.54071 .37667 Mdot
.35902 .34011 Mdot
.55373 .63882 Mdot
.41464 .35939 Mdot
.44925 .36013 Mdot
.50514 .43011 Mdot
.5203 .36602 Mdot
.44891 .60675 Mdot
.4143 .5545 Mdot
.60481 .64705 Mdot
.4115 .65798 Mdot
.57084 .67208 Mdot
.3827 .33666 Mdot
.55201 .3793 Mdot
.68206 .23349 Mdot
.41328 .55156 Mdot
.57891 .6645 Mdot
.58941 .45341 Mdot
.37524 .53729 Mdot
.68692 .50292 Mdot
.38728 .55448 Mdot
.55454 .63136 Mdot
.38372 .54123 Mdot
.59333 .66162 Mdot
.53717 .36665 Mdot
.41498 .53446 Mdot
.43234 .5459 Mdot
.75684 .71491 Mdot
.39397 .34497 Mdot
.58908 .60213 Mdot
.43262 .44208 Mdot
.36083 .53872 Mdot
.68568 .32758 Mdot
.36754 .56995 Mdot
.55388 .68234 Mdot
.45493 .55052 Mdot
.66273 .60321 Mdot
.34016 .53183 Mdot
.42215 .59735 Mdot
.60753 .55249 Mdot
.48412 .7437 Mdot
.54994 .57958 Mdot
.67868 .51873 Mdot
.59151 .60217 Mdot
.6336 .7476 Mdot
.58809 .31805 Mdot
.58986 .37074 Mdot
.34163 .42881 Mdot
.3703 .52228 Mdot
.38688 .5822 Mdot
.68252 .68129 Mdot
.39104 .37256 Mdot
.61258 .66662 Mdot
.37922 .33105 Mdot
.68734 .75977 Mdot
.39934 .3332 Mdot
.60882 .3813 Mdot
.40029 .25714 Mdot
.64981 .22004 Mdot
.37139 .32751 Mdot
.55295 .63289 Mdot
.45305 .23026 Mdot
.39002 .52772 Mdot
.57287 .53885 Mdot
.39207 .35633 Mdot
.38047 .17151 Mdot
.39351 .53089 Mdot
.60193 .43876 Mdot
.69122 .47593 Mdot
.37164 .328 Mdot
.64685 .44347 Mdot
.42849 .56212 Mdot
.68706 .38894 Mdot
.59393 .65191 Mdot
.63059 .44966 Mdot
.38107 .62296 Mdot
.38434 .33518 Mdot
.5811 .35105 Mdot
.61806 .46789 Mdot
.64597 .49756 Mdot
.20439 .55035 Mdot
.368 .20703 Mdot
.55572 .37879 Mdot
.67197 .72703 Mdot
.68281 .51543 Mdot
.3749 .52679 Mdot
.78806 .4624 Mdot
.36168 .5531 Mdot
.71183 .29129 Mdot
.52851 .35375 Mdot
.63636 .37279 Mdot
.3691 .5387 Mdot
.43792 .58697 Mdot
.62661 .64432 Mdot
.54875 .3636 Mdot
.57563 .6543 Mdot
.53713 .61194 Mdot
.53899 .36882 Mdot
.58526 .65105 Mdot
.34897 .34421 Mdot
.78327 .55477 Mdot
.64262 .47996 Mdot
.65746 .46403 Mdot
.55723 .34484 Mdot
.53395 .34138 Mdot
.54533 .34453 Mdot
.38638 .55381 Mdot
.57955 .66794 Mdot
.42496 .56937 Mdot
.43145 .60908 Mdot
.45646 .70217 Mdot
.55973 .61157 Mdot
.41598 .57074 Mdot
.49667 .48294 Mdot
.31607 .6101 Mdot
.52578 .3794 Mdot
.69183 .48075 Mdot
.74393 .38601 Mdot
.63608 .30296 Mdot
.37862 .57374 Mdot
.29653 .32498 Mdot
.5512 .63628 Mdot
.36905 .34344 Mdot
.39053 .32563 Mdot
.37818 .34171 Mdot
.72466 .47357 Mdot
.56871 .60482 Mdot
.51725 .6611 Mdot
.38186 .57931 Mdot
.54405 .67541 Mdot
.55089 .67078 Mdot
.44337 .23734 Mdot
.69167 .48399 Mdot
.39048 .54014 Mdot
.45254 .44039 Mdot
.35938 .74931 Mdot
.36771 .5494 Mdot
.34981 .60096 Mdot
.26875 .32618 Mdot
.4575 .52727 Mdot
.61102 .67798 Mdot
.798 .66775 Mdot
.35933 .60586 Mdot
.73218 .295 Mdot
.14336 .52711 Mdot
.37313 .56668 Mdot
.43119 .5963 Mdot
.42038 .5507 Mdot
.35157 .55728 Mdot
.577 .68442 Mdot
.31112 .37823 Mdot
.68341 .51709 Mdot
.52761 .64465 Mdot
.68671 .5062 Mdot
.51485 .32429 Mdot
.63514 .37627 Mdot
.58548 .62077 Mdot
.40478 .36538 Mdot
.20629 .37536 Mdot
.76039 .67728 Mdot
.57281 .35884 Mdot
.6296 .22038 Mdot
.3899 .35463 Mdot
.33946 .55601 Mdot
.36296 .36527 Mdot
.56947 .38333 Mdot
.65025 .46472 Mdot
.43951 .62059 Mdot
.56777 .61919 Mdot
.5703 .66599 Mdot
.38515 .53701 Mdot
.38495 .24434 Mdot
.69977 .49018 Mdot
.68701 .52088 Mdot
.36279 .58268 Mdot
.36667 .61222 Mdot
.57744 .65388 Mdot
.56169 .3546 Mdot
.56951 .78842 Mdot
.36816 .35617 Mdot
.44084 .5387 Mdot
.37799 .54059 Mdot
.58656 .80361 Mdot
.66588 .462 Mdot
.58137 .34053 Mdot
.46072 .57395 Mdot
.68638 .56727 Mdot
.452 .59214 Mdot
.33655 .60866 Mdot
.51861 .37325 Mdot
.46759 .62291 Mdot
.40162 .51105 Mdot
.54883 .60152 Mdot
.66805 .44928 Mdot
.56815 .63193 Mdot
.5521 .59952 Mdot
.77739 .5855 Mdot
.67386 .50243 Mdot
.40173 .56118 Mdot
.69123 .4914 Mdot
.36022 .57171 Mdot
.35538 .59655 Mdot
.68891 .47886 Mdot
.57704 .65541 Mdot
.18468 .4949 Mdot
.5967 .28608 Mdot
.34857 .57458 Mdot
.37793 .51705 Mdot
.30288 .35371 Mdot
.40702 .39953 Mdot
.44374 .5821 Mdot
.55374 .65048 Mdot
.42668 .5575 Mdot
.69397 .46888 Mdot
.35332 .35652 Mdot
.56815 .62273 Mdot
.5651 .36606 Mdot
.57725 .36189 Mdot
.69682 .61858 Mdot
.51005 .3586 Mdot
.44251 .58785 Mdot
.47863 .62942 Mdot
.62361 .67235 Mdot
.23419 .33189 Mdot
.54333 .37155 Mdot
.373 .3697 Mdot
.4422 .56397 Mdot
.3455 .46343 Mdot
.68988 .45533 Mdot
.64099 .16177 Mdot
.75146 .65754 Mdot
.37683 .37952 Mdot
.52696 .6668 Mdot
.56906 .33673 Mdot
.38969 .51796 Mdot
.36715 .36144 Mdot
.57598 .37697 Mdot
.35346 .57705 Mdot
.32237 .57352 Mdot
.38206 .65105 Mdot
.50011 .4118 Mdot
.68925 .48959 Mdot
.50556 .35926 Mdot
.39555 .38207 Mdot
.50149 .33469 Mdot
.60438 .62377 Mdot
.40762 .60494 Mdot
.46221 .57924 Mdot
.56341 .35527 Mdot
.59305 .36296 Mdot
.41779 .57605 Mdot
.5571 .62357 Mdot
.5754 .28158 Mdot
.40425 .59593 Mdot
.74195 .46543 Mdot
.54438 .64824 Mdot
.5646 .37993 Mdot
.42776 .59577 Mdot
.40143 .32086 Mdot
.56003 .36679 Mdot
.52895 .38097 Mdot
.35695 .54579 Mdot
.36903 .32666 Mdot
.39496 .50528 Mdot
.64224 .46914 Mdot
.46463 .15075 Mdot
.69457 .46906 Mdot
.56966 .30577 Mdot
.4345 .50528 Mdot
.7276 .533 Mdot
.57627 .61101 Mdot
.40625 .45356 Mdot
.75564 .41227 Mdot
.36392 .62755 Mdot
.24568 .58945 Mdot
.63366 .5393 Mdot
.27034 .30519 Mdot
.26626 .56226 Mdot
.39707 .35742 Mdot
.66712 .49281 Mdot
.43153 .59623 Mdot
.68458 .45318 Mdot
.37307 .36806 Mdot
.48559 .18738 Mdot
.44413 .57539 Mdot
.55912 .65143 Mdot
.41186 .57285 Mdot
.56867 .66159 Mdot
.34738 .56678 Mdot
.41294 .50827 Mdot
.76258 .42282 Mdot
.46211 .47861 Mdot
.45358 .58891 Mdot
.84918 .6323 Mdot
.33939 .63665 Mdot
.36299 .34611 Mdot
.43228 .57122 Mdot
.48503 .36249 Mdot
.69898 .50474 Mdot
.69316 .53589 Mdot
.54604 .33362 Mdot
.63969 .48279 Mdot
.58153 .65212 Mdot
.53116 .35532 Mdot
.57172 .35466 Mdot
.47215 .61942 Mdot
.36424 .37183 Mdot
.66018 .47334 Mdot
.39203 .60362 Mdot
.44051 .5818 Mdot
.69061 .72215 Mdot
.48811 .29252 Mdot
.44106 .66712 Mdot
.84925 .50369 Mdot
.55861 .60203 Mdot
.36596 .33412 Mdot
.53089 .3315 Mdot
.43867 .60048 Mdot
.40393 .57471 Mdot
.69605 .34282 Mdot
.56375 .67143 Mdot
.52796 .47183 Mdot
.43298 .67102 Mdot
.3242 .35191 Mdot
.37939 .42567 Mdot
.55319 .64157 Mdot
.36375 .4168 Mdot
.41234 .38307 Mdot
.1933 .61307 Mdot
.46302 .47563 Mdot
.69305 .47891 Mdot
.33954 .3982 Mdot
.61173 .66651 Mdot
.36458 .59394 Mdot
.51536 .36685 Mdot
.51172 .35865 Mdot
.56696 .64005 Mdot
.51305 .31885 Mdot
.40142 .3589 Mdot
.42337 .60651 Mdot
.71432 .69311 Mdot
.73619 .58268 Mdot
.55563 .33598 Mdot
.47204 .61564 Mdot
.65517 .48314 Mdot
.38315 .53642 Mdot
.39874 .34081 Mdot
.68791 .49865 Mdot
.36605 .77785 Mdot
.73849 .42684 Mdot
.43865 .57727 Mdot
.59211 .80467 Mdot
.67253 .50054 Mdot
.29114 .63616 Mdot
.39677 .59828 Mdot
.64728 .4588 Mdot
.4488 .50178 Mdot
.64264 .33518 Mdot
.53648 .5088 Mdot
.29305 .75933 Mdot
.56041 .50058 Mdot
.52439 .32876 Mdot
.64122 .35334 Mdot
.76067 .38469 Mdot
.67441 .51174 Mdot
.58852 .34092 Mdot
.53415 .52823 Mdot
.65059 .4439 Mdot
.34623 .54372 Mdot
.36822 .56564 Mdot
.55303 .20864 Mdot
.60521 .4997 Mdot
.59031 .267 Mdot
.69844 .64317 Mdot
.35967 .53873 Mdot
.43577 .52458 Mdot
.40177 .57778 Mdot
.59486 .684 Mdot
.68252 .48273 Mdot
.82139 .65349 Mdot
.69698 .49902 Mdot
.42615 .69371 Mdot
.55583 .35084 Mdot
.57168 .37849 Mdot
.3774 .5775 Mdot
.60288 .44146 Mdot
.28343 .67176 Mdot
.4124 .5773 Mdot
.3693 .38696 Mdot
.56192 .22437 Mdot
.34834 .59173 Mdot
.57027 .61405 Mdot
.40835 .63648 Mdot
.41295 .49025 Mdot
.64342 .48271 Mdot
.39746 .36624 Mdot
.38756 .46199 Mdot
.65065 .4679 Mdot
.38845 .58177 Mdot
.7041 .55274 Mdot
.37659 .55488 Mdot
.34952 .57311 Mdot
.40326 .67465 Mdot
.38349 .32417 Mdot
.54012 .355 Mdot
.38161 .34242 Mdot
.59564 .62715 Mdot
.54204 .09275 Mdot
.4022 .33497 Mdot
.32206 .73617 Mdot
.50911 .18225 Mdot
.34323 .39965 Mdot
.61526 .6647 Mdot
.37469 .37572 Mdot
.69729 .48289 Mdot
.24013 .64801 Mdot
.31835 .62253 Mdot
.62015 .51727 Mdot
.39925 .59308 Mdot
.5706 .59153 Mdot
.58067 .67498 Mdot
.63147 .45108 Mdot
.60736 .62171 Mdot
.53419 .57966 Mdot
.35308 .58305 Mdot
.66523 .50486 Mdot
.70448 .58204 Mdot
.68873 .51776 Mdot
.44461 .40798 Mdot
.43024 .57735 Mdot
.5632 .62547 Mdot
.41245 .51431 Mdot
.61248 .69115 Mdot
.57704 .33753 Mdot
.45448 .59898 Mdot
.40294 .35888 Mdot
.71782 .53601 Mdot
.56053 .37809 Mdot
.35034 .40147 Mdot
.60378 .64475 Mdot
.72443 .46185 Mdot
.60773 .64248 Mdot
.62629 .6742 Mdot
.6385 .46195 Mdot
.6181 .63771 Mdot
.42767 .59984 Mdot
.53368 .51416 Mdot
.60075 .65106 Mdot
.67003 .48158 Mdot
.38773 .36697 Mdot
.58793 .65969 Mdot
.60567 .38915 Mdot
.44344 .56559 Mdot
.53153 .33527 Mdot
.43162 .38238 Mdot
.59258 .59513 Mdot
.35072 .33313 Mdot
.58551 .37805 Mdot
.41014 .37016 Mdot
.3019 .27876 Mdot
.6329 .48062 Mdot
.37711 .67669 Mdot
.39328 .39489 Mdot
.60348 .67812 Mdot
.2273 .39258 Mdot
.42236 .61242 Mdot
.44272 .56176 Mdot
.4178 .36842 Mdot
.58055 .67498 Mdot
.16212 .58991 Mdot
.29619 .59033 Mdot
.45484 .39622 Mdot
.71373 .49182 Mdot
.7371 .74414 Mdot
.44777 .4013 Mdot
.14905 .48895 Mdot
.44536 .62717 Mdot
.58179 .38746 Mdot
.38553 .57181 Mdot
.73161 .35841 Mdot
.38977 .34072 Mdot
.50775 .30109 Mdot
.44733 .52714 Mdot
.53582 .35784 Mdot
.42716 .54277 Mdot
.59943 .54695 Mdot
.2918 .5579 Mdot
.39237 .378 Mdot
.40913 .242 Mdot
.59972 .60124 Mdot
.38497 .35957 Mdot
.5576 .38379 Mdot
.4666 .49498 Mdot
.35272 .5783 Mdot
.34706 .54137 Mdot
.32468 .34783 Mdot
.58621 .6718 Mdot
.51771 .34091 Mdot
.64402 .466 Mdot
.39554 .36933 Mdot
.41502 .5561 Mdot
.43419 .60836 Mdot
.69166 .32515 Mdot
.65662 .48989 Mdot
.54318 .39392 Mdot
.68328 .46179 Mdot
.56744 .33855 Mdot
.37074 .60191 Mdot
.57543 .36869 Mdot
.34308 .53596 Mdot
.65001 .54582 Mdot
.3947 .67946 Mdot
.48129 .75381 Mdot
.52767 .35986 Mdot
.38074 .78476 Mdot
.65931 .49254 Mdot
.67389 .45824 Mdot
.5673 .19701 Mdot
.33069 .63668 Mdot
.72147 .7011 Mdot
.23909 .54013 Mdot
.6555 .49573 Mdot
.65966 .47851 Mdot
.53171 .33638 Mdot
.61697 .63568 Mdot
.57371 .60087 Mdot
.56959 .34389 Mdot
.2721 .42372 Mdot
.61126 .66769 Mdot
.22962 .60286 Mdot
.67405 .73895 Mdot
.33042 .57726 Mdot
.61204 .34522 Mdot
.37013 .35025 Mdot
.28654 .42214 Mdot
.59165 .54394 Mdot
.44584 .57395 Mdot
.36358 .44396 Mdot
.55951 .35008 Mdot
.62916 .43155 Mdot
.28948 .74578 Mdot
.42127 .53851 Mdot
.39502 .60057 Mdot
.3943 .57691 Mdot
.35979 .37054 Mdot
.33354 .67821 Mdot
.41934 .6038 Mdot
.26965 .42339 Mdot
.37103 .53469 Mdot
.28505 .58617 Mdot
.37633 .34602 Mdot
.52031 .52792 Mdot
.48144 .31425 Mdot
.78114 .68668 Mdot
.3057 .53477 Mdot
.64137 .47689 Mdot
.54592 .28398 Mdot
.67195 .45431 Mdot
.43442 .73251 Mdot
.43751 .45276 Mdot
.55009 .60616 Mdot
.44422 .57888 Mdot
.53219 .36872 Mdot
.57978 .67429 Mdot
.65691 .34868 Mdot
.59393 .11629 Mdot
.65104 .50105 Mdot
.2072 .70539 Mdot
.65381 .45558 Mdot
.57069 .35371 Mdot
.57702 .65268 Mdot
.44639 .80403 Mdot
.72418 .66783 Mdot
.58828 .65789 Mdot
.16011 .53508 Mdot
.59715 .69959 Mdot
.42779 .47401 Mdot
.62488 .64691 Mdot
.66611 .48282 Mdot
.66855 .43454 Mdot
.5383 .5663 Mdot
.37745 .59832 Mdot
.51075 .43767 Mdot
.27963 .65854 Mdot
.42437 .61175 Mdot
.54364 .37776 Mdot
.36851 .66169 Mdot
.35671 .4334 Mdot
.61954 .64927 Mdot
.73946 .46906 Mdot
.40506 .60249 Mdot
.3695 .54319 Mdot
.35667 .58381 Mdot
.7718 .63001 Mdot
.19061 .61103 Mdot
.3694 .59918 Mdot
.34961 .55494 Mdot
.53294 .35685 Mdot
.3593 .39003 Mdot
.50573 .23235 Mdot
.5743 .71466 Mdot
.41929 .53104 Mdot
.38006 .35622 Mdot
.42101 .37231 Mdot
.42588 .61476 Mdot
.52777 .51535 Mdot
.71568 .54532 Mdot
.39531 .60499 Mdot
.36558 .65843 Mdot
.56918 .41498 Mdot
.55566 .39698 Mdot
.56285 .36354 Mdot
.59744 .60536 Mdot
.56603 .3489 Mdot
.57789 .34818 Mdot
.37625 .7711 Mdot
.54783 .48769 Mdot
.64829 .5312 Mdot
.37882 .33572 Mdot
.39867 .5689 Mdot
.49439 .61496 Mdot
.69029 .55896 Mdot
.65336 .44703 Mdot
.5781 .62372 Mdot
.70768 .4935 Mdot
.42892 .33465 Mdot
.75677 .6307 Mdot
.51725 .32676 Mdot
.64821 .48543 Mdot
.64385 .50304 Mdot
.37815 .35561 Mdot
.66933 .44486 Mdot
.6777 .42055 Mdot
.38749 .61696 Mdot
.45761 .78422 Mdot
.41603 .58219 Mdot
.19025 .39678 Mdot
.6542 .47656 Mdot
.70897 .4659 Mdot
.38296 .58904 Mdot
.55867 .36894 Mdot
.46564 .51641 Mdot
.37356 .5943 Mdot
.56484 .34908 Mdot
.44992 .54109 Mdot
.40857 .33383 Mdot
.54596 .64214 Mdot
.71858 .67202 Mdot
.47354 .14227 Mdot
.36625 .37252 Mdot
.66207 .34294 Mdot
.44668 .55736 Mdot
.35165 .2271 Mdot
.58958 .66266 Mdot
.45703 .57014 Mdot
.37624 .43125 Mdot
.60529 .65703 Mdot
.57873 .63532 Mdot
.38762 .55031 Mdot
.69048 .47252 Mdot
.56331 .37865 Mdot
.37482 .35214 Mdot
.16319 .43034 Mdot
.41219 .59232 Mdot
.43192 .55125 Mdot
.38651 .35687 Mdot
.67418 .50459 Mdot
.44809 .59745 Mdot
.26273 .48317 Mdot
.1766 .62014 Mdot
.64924 .45557 Mdot
.40165 .53207 Mdot
.42796 .74631 Mdot
.29797 .55682 Mdot
.2836 .255 Mdot
.56256 .53513 Mdot
.53839 .34901 Mdot
.37577 .49557 Mdot
.7849 .30768 Mdot
.39367 .36772 Mdot
.75197 .68296 Mdot
.37029 .54208 Mdot
.40906 .54729 Mdot
.56596 .67071 Mdot
.42394 .57215 Mdot
.58285 .62064 Mdot
.57261 .16819 Mdot
.61752 .79321 Mdot
.59586 .60984 Mdot
.61205 .673 Mdot
.36624 .46976 Mdot
.7171 .51779 Mdot
.56944 .64205 Mdot
.35663 .6003 Mdot
.49839 .49722 Mdot
.66303 .68932 Mdot
.37349 .37264 Mdot
.28822 .32128 Mdot
.31667 .55671 Mdot
.3203 .31589 Mdot
.19303 .49226 Mdot
.368 .64282 Mdot
.4413 .42055 Mdot
.66809 .45937 Mdot
.42051 .53714 Mdot
.51184 .36239 Mdot
.51161 .36744 Mdot
.33918 .53931 Mdot
.38797 .56024 Mdot
.59885 .6338 Mdot
.38124 .3687 Mdot
.68707 .51278 Mdot
.40805 .54893 Mdot
.4182 .45899 Mdot
.40593 .36825 Mdot
.61052 .62336 Mdot
.42274 .70372 Mdot
.37989 .31934 Mdot
.37324 .50589 Mdot
.38086 .59819 Mdot
.40777 .56785 Mdot
.53889 .56379 Mdot
.68203 .47784 Mdot
.20446 .48445 Mdot
.34191 .57077 Mdot
.70215 .75351 Mdot
.67287 .53194 Mdot
.41636 .50262 Mdot
.60691 .63045 Mdot
.7381 .46864 Mdot
.5338 .31568 Mdot
.79784 .54056 Mdot
.43421 .58176 Mdot
.39886 .24264 Mdot
.54773 .20866 Mdot
.58891 .34966 Mdot
.59525 .69333 Mdot
.37553 .33891 Mdot
.40996 .57509 Mdot
.36672 .685 Mdot
.37012 .56829 Mdot
.4311 .36983 Mdot
.53725 .38517 Mdot
.67117 .46054 Mdot
.24698 .32514 Mdot
.50778 .36019 Mdot
.57581 .63416 Mdot
.51347 .85372 Mdot
.58128 .61891 Mdot
.5761 .60083 Mdot
.43998 .70737 Mdot
.68229 .47641 Mdot
.7137 .2157 Mdot
.60184 .18763 Mdot
.37885 .60927 Mdot
.66692 .50123 Mdot
.56114 .63564 Mdot
.38754 .5331 Mdot
.61595 .69908 Mdot
.5559 .60789 Mdot
.36047 .59751 Mdot
.41416 .54585 Mdot
.50878 .21933 Mdot
.25879 .66172 Mdot
.37693 .33813 Mdot
.58663 .61395 Mdot
.73868 .63811 Mdot
.38386 .53153 Mdot
.38162 .58036 Mdot
.70986 .30285 Mdot
.35893 .36578 Mdot
.75263 .58398 Mdot
.36986 .54269 Mdot
.53618 .82666 Mdot
.42167 .63849 Mdot
.55596 .66509 Mdot
.66539 .45188 Mdot
.76 .70539 Mdot
.65613 .41608 Mdot
.58415 .62258 Mdot
.40965 .35908 Mdot
.62752 .64855 Mdot
.34964 .76058 Mdot
.68745 .50547 Mdot
.55432 .63166 Mdot
.44397 .4339 Mdot
.68199 .49093 Mdot
.65093 .47399 Mdot
.46739 .70114 Mdot
.55328 .31864 Mdot
.37389 .37992 Mdot
.65926 .47528 Mdot
.7854 .43162 Mdot
.67217 .48798 Mdot
.58195 .18112 Mdot
.41575 .53722 Mdot
.31721 .43992 Mdot
.56711 .30245 Mdot
.31117 .5523 Mdot
.65168 .48206 Mdot
.35593 .33395 Mdot
.35323 .5745 Mdot
.61593 .62318 Mdot
.38077 .37145 Mdot
.60848 .47007 Mdot
.54487 .3355 Mdot
.61024 .6457 Mdot
.60967 .45191 Mdot
.56704 .66185 Mdot
.7741 .51227 Mdot
.47434 .16516 Mdot
.30757 .50877 Mdot
.73061 .66183 Mdot
.35184 .57845 Mdot
.20805 .5603 Mdot
.39774 .52816 Mdot
.38115 .55405 Mdot
.55522 .3808 Mdot
.33558 .43808 Mdot
.576 .65433 Mdot
.16957 .48411 Mdot
.64444 .48277 Mdot
.77774 .69249 Mdot
.32263 .51799 Mdot
.44765 .54884 Mdot
.59916 .64819 Mdot
.55131 .65316 Mdot
.47565 .7309 Mdot
.49849 .3625 Mdot
.4451 .5485 Mdot
.41634 .62799 Mdot
.32833 .5579 Mdot
.64602 .46927 Mdot
.48502 .4801 Mdot
.52731 .32614 Mdot
.42339 .18393 Mdot
.54257 .38715 Mdot
.36109 .29658 Mdot
.61647 .62968 Mdot
.40319 .33589 Mdot
.38029 .58262 Mdot
.41626 .65376 Mdot
.56803 .67512 Mdot
.41624 .36908 Mdot
.36512 .33036 Mdot
.65684 .30552 Mdot
.6892 .47998 Mdot
.37596 .59978 Mdot
.4258 .59774 Mdot
.42083 .56633 Mdot
.38795 .55594 Mdot
.65079 .49957 Mdot
.35771 .5798 Mdot
.66108 .43723 Mdot
.8044 .53975 Mdot
.2945 .46594 Mdot
.56542 .5025 Mdot
.66441 .25262 Mdot
.61878 .65568 Mdot
.77599 .45841 Mdot
.45757 .52316 Mdot
.81783 .48506 Mdot
.47657 .19512 Mdot
.37914 .61936 Mdot
.57866 .36433 Mdot
.38138 .47926 Mdot
.50944 .3408 Mdot
.13703 .51806 Mdot
.73159 .3369 Mdot
.25228 .64585 Mdot
.44173 .57975 Mdot
.53083 .51013 Mdot
.776 .3754 Mdot
.38498 .52649 Mdot
.68476 .30882 Mdot
.70942 .2883 Mdot
.44018 .22802 Mdot
.37413 .32723 Mdot
.42437 .59223 Mdot
.53057 .5906 Mdot
.42485 .60306 Mdot
.38297 .57457 Mdot
.35693 .58168 Mdot
.70584 .50343 Mdot
.45138 .58338 Mdot
.35589 .561 Mdot
.40254 .27421 Mdot
.41454 .44253 Mdot
.57034 .39309 Mdot
.55085 .19307 Mdot
.39861 .33216 Mdot
.60173 .64604 Mdot
.19171 .58661 Mdot
.69315 .47994 Mdot
.48494 .73558 Mdot
.3961 .5609 Mdot
.54107 .24326 Mdot
.74086 .42511 Mdot
.4079 .35894 Mdot
.57945 .37786 Mdot
.25431 .6767 Mdot
.53669 .37169 Mdot
.73487 .45856 Mdot
.55736 .37179 Mdot
.40395 .4932 Mdot
.59754 .63033 Mdot
.39426 .61144 Mdot
.66181 .47159 Mdot
.568 .36302 Mdot
.296 .36868 Mdot
.39979 .57605 Mdot
.53918 .36821 Mdot
.38719 .60856 Mdot
.59576 .71194 Mdot
.62009 .73316 Mdot
.5807 .35569 Mdot
.62862 .47585 Mdot
.67174 .47071 Mdot
.39391 .33389 Mdot
.60764 .6509 Mdot
.58155 .62419 Mdot
.68525 .49888 Mdot
.62622 .61504 Mdot
.41697 .52928 Mdot
.39975 .53689 Mdot
.72753 .73117 Mdot
.43301 .59865 Mdot
.47371 .50507 Mdot
.45587 .44454 Mdot
.60481 .61253 Mdot
.42949 .52143 Mdot
.38534 .54589 Mdot
.44089 .57362 Mdot
.64876 .71514 Mdot
.56251 .34879 Mdot
.41899 .53784 Mdot
.35648 .33812 Mdot
.62503 .37723 Mdot
.38211 .53626 Mdot
.48791 .61374 Mdot
.57925 .62269 Mdot
.83934 .5286 Mdot
.65911 .45524 Mdot
.55444 .38357 Mdot
.52699 .35876 Mdot
.208 .46459 Mdot
.77481 .41979 Mdot
.45966 .44707 Mdot
.33928 .2082 Mdot
.76242 .426 Mdot
.37672 .33131 Mdot
.59982 .38012 Mdot
.6041 .457 Mdot
.52353 .35223 Mdot
.66506 .51224 Mdot
.40579 .53466 Mdot
.41695 .53083 Mdot
.77656 .31311 Mdot
.44471 .60267 Mdot
.37317 .34202 Mdot
.68957 .51499 Mdot
.60472 .67023 Mdot
.40659 .36236 Mdot
.68109 .45933 Mdot
.59883 .60752 Mdot
.37686 .61889 Mdot
.34445 .58659 Mdot
.5811 .62693 Mdot
.56274 .66607 Mdot
.3796 .59445 Mdot
.71266 .40364 Mdot
.60625 .67558 Mdot
.55274 .64185 Mdot
.52841 .32299 Mdot
.51076 .35789 Mdot
.3373 .6176 Mdot
.65951 .48996 Mdot
.35452 .56576 Mdot
.53034 .35931 Mdot
.40252 .33584 Mdot
.5785 .65852 Mdot
.34911 .56736 Mdot
.39324 .54229 Mdot
.37832 .35749 Mdot
.40541 .34435 Mdot
.39619 .3383 Mdot
.62492 .43914 Mdot
.42929 .56666 Mdot
.57693 .64882 Mdot
.68547 .47592 Mdot
.41137 .37943 Mdot
.36305 .36355 Mdot
.58869 .39371 Mdot
.43948 .5964 Mdot
.53618 .30388 Mdot
.79738 .32428 Mdot
.64281 .77563 Mdot
.58224 .34843 Mdot
.53066 .3168 Mdot
.27418 .36561 Mdot
.64474 .58975 Mdot
.69187 .50069 Mdot
.39129 .3998 Mdot
.30876 .5102 Mdot
.41664 .6229 Mdot
.34656 .58368 Mdot
.43518 .52145 Mdot
.39019 .33381 Mdot
.33308 .45257 Mdot
.58742 .62227 Mdot
.51399 .53401 Mdot
.40692 .36854 Mdot
.57939 .3837 Mdot
.60654 .36776 Mdot
.54867 .38753 Mdot
.33885 .5625 Mdot
.49168 .76308 Mdot
.76771 .46607 Mdot
.23825 .51992 Mdot
.65429 .4868 Mdot
.46011 .63357 Mdot
.36981 .22168 Mdot
.58171 .63274 Mdot
.5052 .33351 Mdot
.36878 .33147 Mdot
.56367 .66531 Mdot
.70759 .48834 Mdot
.66103 .47713 Mdot
.55426 .33466 Mdot
.55323 .33603 Mdot
.51799 .35848 Mdot
.54917 .61483 Mdot
.61712 .63284 Mdot
.43501 .57977 Mdot
.58442 .66536 Mdot
.81413 .55644 Mdot
.42368 .3444 Mdot
.48455 .37716 Mdot
.66417 .49157 Mdot
.62106 .63997 Mdot
.40329 .5777 Mdot
.53866 .66249 Mdot
.66923 .5883 Mdot
.36307 .34964 Mdot
.65574 .73166 Mdot
.14741 .46331 Mdot
.39242 .60989 Mdot
.67589 .47044 Mdot
.7457 .67309 Mdot
.39635 .57925 Mdot
.52507 .33568 Mdot
.31392 .29581 Mdot
.49274 .40213 Mdot
.37071 .58967 Mdot
.39514 .61787 Mdot
.64039 .47478 Mdot
.41865 .18555 Mdot
.42446 .58769 Mdot
.76864 .56759 Mdot
.70206 .52113 Mdot
.523 .33231 Mdot
.27284 .77016 Mdot
.34618 .32015 Mdot
.28124 .42449 Mdot
.5391 .32484 Mdot
.36774 .55451 Mdot
.50615 .34068 Mdot
.35649 .34284 Mdot
.57581 .37906 Mdot
.57558 .61598 Mdot
.56917 .38663 Mdot
.43121 .55149 Mdot
.5675 .63811 Mdot
.67251 .50099 Mdot
.7723 .68907 Mdot
.39153 .29194 Mdot
.55824 .3673 Mdot
.57748 .35496 Mdot
.44272 .5377 Mdot
.73873 .61981 Mdot
.36843 .52135 Mdot
.39875 .53266 Mdot
.66583 .50347 Mdot
.60547 .65496 Mdot
.64435 .45745 Mdot
.34647 .52178 Mdot
.28697 .4863 Mdot
.68349 .46363 Mdot
.5131 .23273 Mdot
.39154 .35334 Mdot
.57425 .44031 Mdot
.40426 .57348 Mdot
.64969 .44257 Mdot
.43168 .5677 Mdot
.58977 .62293 Mdot
.57623 .49504 Mdot
.66447 .39324 Mdot
.65549 .46603 Mdot
.33685 .27425 Mdot
.27699 .46244 Mdot
.48243 .62047 Mdot
.67131 .45604 Mdot
.3567 .42517 Mdot
.56982 .35253 Mdot
.37113 .36181 Mdot
.41651 .34256 Mdot
.41091 .36643 Mdot
.35145 .61851 Mdot
.32096 .51887 Mdot
.34599 .34215 Mdot
.69547 .50646 Mdot
.39031 .37783 Mdot
.7065 .26429 Mdot
.16781 .4893 Mdot
.39097 .34571 Mdot
.39771 .59645 Mdot
.45848 .5186 Mdot
.33993 .39545 Mdot
.63801 .323 Mdot
.24725 .62018 Mdot
.63774 .26028 Mdot
.37121 .58646 Mdot
.54404 .65099 Mdot
.56702 .60674 Mdot
.79701 .60991 Mdot
.31298 .72061 Mdot
.60947 .79039 Mdot
.59031 .60026 Mdot
.72291 .38025 Mdot
.61303 .63396 Mdot
.37595 .60309 Mdot
.3955 .5351 Mdot
.56489 .59831 Mdot
.30503 .47688 Mdot
.69695 .36564 Mdot
.20438 .3705 Mdot
.5642 .66186 Mdot
.66749 .44938 Mdot
.63941 .45339 Mdot
.6502 .47735 Mdot
.71145 .72326 Mdot
.59567 .64937 Mdot
.40866 .55628 Mdot
.52861 .36425 Mdot
.42382 .53338 Mdot
.68499 .49071 Mdot
.15166 .52591 Mdot
.59389 .65973 Mdot
.41145 .60382 Mdot
.50781 .58175 Mdot
.5497 .33552 Mdot
.38268 .35299 Mdot
.5831 .70601 Mdot
.59388 .7971 Mdot
.64588 .48372 Mdot
.58613 .59295 Mdot
.60123 .49087 Mdot
.21572 .36431 Mdot
.47197 .61325 Mdot
.45769 .60638 Mdot
.15976 .43694 Mdot
.49279 .83728 Mdot
.44848 .56752 Mdot
.58228 .37089 Mdot
.7001 .34151 Mdot
.37864 .53824 Mdot
.57625 .60765 Mdot
.39144 .32218 Mdot
.40189 .3743 Mdot
.36261 .63442 Mdot
.61049 .70959 Mdot
.58433 .53216 Mdot
.39777 .55897 Mdot
.38716 .50292 Mdot
.52698 .32761 Mdot
.73385 .35138 Mdot
.68695 .76021 Mdot
.40863 .34489 Mdot
.41291 .61515 Mdot
.18265 .48239 Mdot
.57545 .67497 Mdot
.58817 .35125 Mdot
.69002 .46187 Mdot
.5477 .66612 Mdot
.5818 .3756 Mdot
.34855 .58497 Mdot
.44016 .60722 Mdot
.65181 .44897 Mdot
.55149 .6578 Mdot
.39633 .34021 Mdot
.55768 .38186 Mdot
.40529 .35125 Mdot
.60265 .65737 Mdot
.60325 .66781 Mdot
.51083 .59142 Mdot
.47287 .60816 Mdot
.56432 .36709 Mdot
.32929 .56557 Mdot
.67434 .41464 Mdot
.22855 .30066 Mdot
.60143 .48501 Mdot
.4478 .59114 Mdot
.62488 .63496 Mdot
.64942 .46707 Mdot
.41208 .54768 Mdot
.14809 .50434 Mdot
.3739 .53192 Mdot
.70396 .50883 Mdot
.34259 .76301 Mdot
.40204 .3534 Mdot
.55585 .5606 Mdot
.46771 .20252 Mdot
.43176 .60273 Mdot
.5298 .34465 Mdot
.43587 .63142 Mdot
.69321 .47375 Mdot
.61955 .6414 Mdot
.20526 .3172 Mdot
.67317 .48404 Mdot
.41626 .6092 Mdot
.40019 .36791 Mdot
.61712 .67234 Mdot
.56579 .54172 Mdot
.51543 .50013 Mdot
.47971 .56014 Mdot
.43271 .52716 Mdot
.37905 .54712 Mdot
.25675 .49716 Mdot
.53869 .37976 Mdot
.55451 .63826 Mdot
.67137 .46536 Mdot
.6881 .49976 Mdot
.55879 .34214 Mdot
.51269 .30744 Mdot
.57282 .44043 Mdot
.84151 .40888 Mdot
.50396 .34026 Mdot
.40803 .33888 Mdot
.74891 .59677 Mdot
.53585 .37615 Mdot
.543 .36877 Mdot
.52105 .32517 Mdot
.44963 .43072 Mdot
.61242 .66706 Mdot
.34792 .58327 Mdot
.56428 .61259 Mdot
.36555 .55392 Mdot
.71172 .50924 Mdot
.65784 .4687 Mdot
.60085 .66246 Mdot
.22957 .32645 Mdot
.43164 .77508 Mdot
.39201 .58687 Mdot
.35437 .22657 Mdot
.4613 .54765 Mdot
.31682 .33521 Mdot
.45687 .54472 Mdot
.55519 .36086 Mdot
.34067 .54982 Mdot
.33789 .60635 Mdot
.77905 .64412 Mdot
.66257 .49244 Mdot
.58114 .39345 Mdot
.41171 .50386 Mdot
.37922 .50497 Mdot
.5463 .61913 Mdot
.56025 .66272 Mdot
.41795 .34802 Mdot
.49367 .53245 Mdot
.67739 .50292 Mdot
.67103 .22095 Mdot
.37834 .59877 Mdot
.34666 .30807 Mdot
.58085 .76514 Mdot
.41519 .54917 Mdot
.4315 .20783 Mdot
.49175 .75708 Mdot
.40824 .57454 Mdot
.48176 .42347 Mdot
.65792 .49074 Mdot
.27927 .53204 Mdot
.36772 .53683 Mdot
.5404 .33003 Mdot
.61384 .62656 Mdot
.57328 .67723 Mdot
.41261 .33924 Mdot
.80944 .42114 Mdot
.64142 .45958 Mdot
.61592 .65608 Mdot
.39391 .57035 Mdot
.67694 .46951 Mdot
.51746 .32499 Mdot
.4532 .56222 Mdot
.41979 .81554 Mdot
.58136 .66518 Mdot
.44886 .53844 Mdot
.76186 .54533 Mdot
.26582 .39768 Mdot
.35328 .78012 Mdot
.66475 .46102 Mdot
.39099 .33235 Mdot
.3759 .63404 Mdot
.63468 .62532 Mdot
.39366 .51241 Mdot
.29532 .43782 Mdot
.69405 .25915 Mdot
.35041 .35102 Mdot
.38583 .59255 Mdot
.4122 .5552 Mdot
.6192 .55281 Mdot
.41048 .35142 Mdot
.43796 .58535 Mdot
.65519 .63061 Mdot
.56755 .65886 Mdot
.54974 .32397 Mdot
.5938 .67194 Mdot
.39824 .59306 Mdot
.47788 .60179 Mdot
.56353 .6687 Mdot
.27469 .27618 Mdot
.37889 .31773 Mdot
.67355 .45945 Mdot
.41771 .6177 Mdot
.34515 .55171 Mdot
.86146 .59472 Mdot
.59033 .34677 Mdot
.69375 .39937 Mdot
.51757 .243 Mdot
.20092 .46298 Mdot
.33313 .36331 Mdot
.31713 .76924 Mdot
.4844 .83753 Mdot
.45296 .58079 Mdot
.59572 .58025 Mdot
.75774 .51563 Mdot
.6615 .49823 Mdot
.78829 .37473 Mdot
.3782 .59923 Mdot
.38353 .5726 Mdot
.57272 .33612 Mdot
.64845 .39145 Mdot
.6177 .78737 Mdot
.52483 .61591 Mdot
.39912 .34703 Mdot
.59535 .62328 Mdot
.35223 .595 Mdot
.51257 .46128 Mdot
.59026 .37094 Mdot
.40432 .31224 Mdot
.40727 .60474 Mdot
.65286 .71583 Mdot
.67805 .59707 Mdot
.68693 .48208 Mdot
.52663 .35601 Mdot
.56115 .80119 Mdot
.4403 .59847 Mdot
.6492 .44178 Mdot
.41085 .5897 Mdot
.34064 .38067 Mdot
.33867 .52187 Mdot
.37829 .33286 Mdot
.35987 .54765 Mdot
.55243 .28123 Mdot
.77962 .72207 Mdot
.38741 .38759 Mdot
.53944 .63362 Mdot
.57592 .33022 Mdot
.56325 .35127 Mdot
.55575 .65703 Mdot
.5621 .3589 Mdot
.48814 .72341 Mdot
.40218 .79392 Mdot
.39415 .3537 Mdot
.32731 .60332 Mdot
.38631 .3465 Mdot
.58106 .34218 Mdot
.37162 .58961 Mdot
.16689 .38584 Mdot
.56971 .37092 Mdot
.52825 .83955 Mdot
.67334 .49145 Mdot
.59396 .35152 Mdot
.37201 .5348 Mdot
.66185 .60519 Mdot
.5079 .35893 Mdot
.69275 .38336 Mdot
.44029 .57454 Mdot
.60276 .6697 Mdot
.38721 .54115 Mdot
.37463 .60719 Mdot
.57866 .3893 Mdot
.35823 .56616 Mdot
.68124 .459 Mdot
.58651 .60014 Mdot
.23596 .62086 Mdot
.74175 .32411 Mdot
.438 .58697 Mdot
.39518 .57285 Mdot
.62196 .67711 Mdot
.35223 .53824 Mdot
.64949 .49724 Mdot
.33975 .15586 Mdot
.39086 .35352 Mdot
.59691 .36281 Mdot
.53552 .26404 Mdot
.40627 .62537 Mdot
.355 .5764 Mdot
.13771 .58625 Mdot
.28572 .47955 Mdot
.67449 .45635 Mdot
.3267 .56403 Mdot
.50361 .35137 Mdot
.38138 .36735 Mdot
.68547 .51116 Mdot
.41081 .57009 Mdot
.38159 .58535 Mdot
.39961 .33713 Mdot
.3273 .31788 Mdot
.66568 .74517 Mdot
.63832 .44667 Mdot
.43173 .50415 Mdot
.58518 .40116 Mdot
.41465 .52692 Mdot
.70392 .71908 Mdot
.56167 .62489 Mdot
.64779 .48796 Mdot
.19879 .48347 Mdot
.44461 .59382 Mdot
.66101 .44962 Mdot
.67405 .50246 Mdot
.39862 .51102 Mdot
.53692 .59611 Mdot
.57548 .59916 Mdot
.5701 .66358 Mdot
.64042 .16853 Mdot
.29827 .41772 Mdot
.51797 .35842 Mdot
.65992 .49443 Mdot
.57522 .34629 Mdot
.43272 .3677 Mdot
.52322 .49565 Mdot
.57794 .35139 Mdot
.58799 .67366 Mdot
.59597 .35689 Mdot
.43176 .56152 Mdot
.67806 .50233 Mdot
.52357 .34813 Mdot
.37333 .60965 Mdot
.67084 .69874 Mdot
.61375 .27388 Mdot
.35573 .3539 Mdot
.37194 .31959 Mdot
.3907 .53547 Mdot
.5009 .33777 Mdot
.37751 .58924 Mdot
.68392 .45315 Mdot
.72038 .66461 Mdot
.37348 .60543 Mdot
.55866 .36437 Mdot
.61983 .6775 Mdot
.57021 .79916 Mdot
.34138 .60237 Mdot
.39586 .59618 Mdot
.36175 .55879 Mdot
.41175 .58958 Mdot
.23445 .34341 Mdot
.63584 .46401 Mdot
.67767 .26525 Mdot
.21406 .45042 Mdot
.58849 .65379 Mdot
.55283 .62347 Mdot
.66894 .76291 Mdot
.73844 .53265 Mdot
.65886 .48958 Mdot
.38375 .55481 Mdot
.68314 .57286 Mdot
.17644 .61563 Mdot
.18516 .38681 Mdot
.31089 .67332 Mdot
.58882 .34451 Mdot
.58817 .59358 Mdot
.56959 .35822 Mdot
.3679 .55901 Mdot
.3958 .50422 Mdot
.3945 .82722 Mdot
.70161 .50002 Mdot
.39626 .34659 Mdot
.36358 .55352 Mdot
.29269 .41834 Mdot
.53232 .35501 Mdot
.59402 .35035 Mdot
.416 .54175 Mdot
.59281 .68539 Mdot
.76408 .72867 Mdot
.68145 .47762 Mdot
.66437 .2656 Mdot
.77057 .36008 Mdot
.67955 .6384 Mdot
.68496 .48734 Mdot
.63281 .60976 Mdot
.58671 .35342 Mdot
.57402 .74529 Mdot
.58745 .64735 Mdot
.3743 .36673 Mdot
.4316 .50995 Mdot
.55389 .62971 Mdot
.53405 .38621 Mdot
.61586 .6603 Mdot
.35488 .57913 Mdot
.67092 .52142 Mdot
.53921 .34606 Mdot
.66849 .53284 Mdot
.62548 .63823 Mdot
.41006 .35636 Mdot
.69951 .43747 Mdot
.32755 .7077 Mdot
.49235 .75466 Mdot
.41764 .53989 Mdot
.50246 .45718 Mdot
.41162 .55906 Mdot
.60155 .69295 Mdot
.40516 .58211 Mdot
.44867 .64542 Mdot
.53112 .34395 Mdot
.35127 .5517 Mdot
.39217 .55617 Mdot
.58291 .18912 Mdot
.43213 .58906 Mdot
.39895 .52149 Mdot
.40558 .57053 Mdot
.45206 .64225 Mdot
.37379 .63708 Mdot
.60558 .63106 Mdot
.46535 .23075 Mdot
.54491 .36726 Mdot
.41366 .3687 Mdot
.37376 .32631 Mdot
.32631 .43513 Mdot
.5197 .28251 Mdot
.63661 .36542 Mdot
.57043 .65789 Mdot
.68178 .45585 Mdot
.40845 .58519 Mdot
.28263 .72924 Mdot
.53471 .4033 Mdot
.5735 .38649 Mdot
.74457 .33017 Mdot
.30871 .54354 Mdot
.2615 .61303 Mdot
.33671 .54087 Mdot
.7517 .27292 Mdot
.40951 .62889 Mdot
.34983 .50552 Mdot
.50528 .33563 Mdot
.35339 .30045 Mdot
.36331 .53134 Mdot
.58207 .60523 Mdot
.36489 .34094 Mdot
.32416 .51724 Mdot
.60008 .3249 Mdot
.61296 .40253 Mdot
.46452 .65473 Mdot
.43617 .57167 Mdot
.54012 .34644 Mdot
.60891 .6462 Mdot
.66716 .7703 Mdot
.68409 .47416 Mdot
.53531 .3017 Mdot
.78581 .5558 Mdot
.29549 .26651 Mdot
.40867 .36559 Mdot
.54461 .70983 Mdot
.43131 .5541 Mdot
.37559 .27755 Mdot
.3978 .61524 Mdot
.14698 .56622 Mdot
.37302 .32445 Mdot
.60033 .67401 Mdot
.66899 .44885 Mdot
.57797 .60839 Mdot
.47809 .74484 Mdot
.60781 .33322 Mdot
.5553 .47302 Mdot
.53765 .3713 Mdot
.57716 .53393 Mdot
.56324 .63146 Mdot
.37568 .60108 Mdot
.83937 .39953 Mdot
.55321 .63456 Mdot
.62258 .66343 Mdot
.49932 .18105 Mdot
.19855 .33583 Mdot
.45935 .60971 Mdot
.61086 .67323 Mdot
.54556 .3752 Mdot
.37259 .33808 Mdot
.36635 .54061 Mdot
.43823 .56368 Mdot
.56208 .62192 Mdot
.58807 .38568 Mdot
.37852 .71472 Mdot
.55668 .34499 Mdot
.60424 .6717 Mdot
.54787 .35484 Mdot
.71811 .49105 Mdot
.55881 .38289 Mdot
.3444 .5529 Mdot
.40609 .58294 Mdot
.47855 .25266 Mdot
.60219 .66836 Mdot
.40034 .56001 Mdot
.44639 .54373 Mdot
.57455 .64787 Mdot
.62812 .58821 Mdot
.39386 .72365 Mdot
.44313 .54675 Mdot
.44026 .5781 Mdot
.36032 .32924 Mdot
.5254 .48786 Mdot
.59998 .72836 Mdot
.35249 .57221 Mdot
.3533 .36031 Mdot
.59265 .61203 Mdot
.39306 .60453 Mdot
.18274 .56723 Mdot
.6981 .34251 Mdot
.39113 .60893 Mdot
.57022 .35389 Mdot
.32771 .58198 Mdot
.37207 .79227 Mdot
.39418 .53095 Mdot
.56635 .64292 Mdot
.61493 .65293 Mdot
.65629 .21672 Mdot
.57415 .63245 Mdot
.51165 .35856 Mdot
.68342 .49127 Mdot
.21483 .36267 Mdot
.56101 .33742 Mdot
.38575 .62615 Mdot
.51105 .1577 Mdot
.45826 .55676 Mdot
.35826 .60701 Mdot
.5769 .81767 Mdot
.56967 .36385 Mdot
.59795 .6396 Mdot
.67933 .42956 Mdot
.47143 .60516 Mdot
.64669 .48167 Mdot
.38056 .50039 Mdot
.4025 .53259 Mdot
.41871 .82452 Mdot
.23768 .34322 Mdot
.63536 .44398 Mdot
.40142 .5222 Mdot
.35319 .57417 Mdot
.48527 .35857 Mdot
.39972 .57299 Mdot
.37621 .33602 Mdot
.59757 .65095 Mdot
.57682 .37614 Mdot
.38184 .3618 Mdot
.43197 .60653 Mdot
.39631 .33894 Mdot
.53078 .33556 Mdot
.69955 .47255 Mdot
.36775 .56935 Mdot
.37704 .37506 Mdot
.39932 .34461 Mdot
.41173 .56092 Mdot
.61638 .62796 Mdot
.30057 .56995 Mdot
.42823 .59311 Mdot
.34932 .56815 Mdot
.58363 .62585 Mdot
.26671 .77183 Mdot
.39667 .53479 Mdot
.29821 .44494 Mdot
.55047 .6491 Mdot
.59721 .55227 Mdot
.55512 .32859 Mdot
.3801 .52728 Mdot
.69912 .4714 Mdot
.69701 .47088 Mdot
.55467 .38835 Mdot
.59339 .59544 Mdot
.5447 .25668 Mdot
.54582 .60395 Mdot
.39481 .63358 Mdot
.38541 .52095 Mdot
.33929 .63847 Mdot
.26219 .68865 Mdot
.57764 .61236 Mdot
.57591 .30142 Mdot
.52985 .64699 Mdot
.67304 .447 Mdot
.57165 .39258 Mdot
.57576 .59836 Mdot
.58908 .62684 Mdot
.60357 .60956 Mdot
.37434 .36736 Mdot
.47791 .25559 Mdot
.55774 .66647 Mdot
.58859 .68669 Mdot
.441 .56161 Mdot
.35244 .56708 Mdot
.51844 .82731 Mdot
.50374 .82037 Mdot
.35674 .33438 Mdot
.51595 .3557 Mdot
.58327 .12802 Mdot
.70427 .48568 Mdot
.61588 .21256 Mdot
.35143 .59791 Mdot
.62129 .13697 Mdot
.37088 .53687 Mdot
.39384 .56839 Mdot
.57418 .59871 Mdot
.36708 .36618 Mdot
.38757 .34996 Mdot
.55427 .6362 Mdot
.5865 .68957 Mdot
.37889 .33601 Mdot
.44102 .1987 Mdot
.18477 .60631 Mdot
.67588 .41166 Mdot
.58202 .65633 Mdot
.35436 .74501 Mdot
.64511 .44641 Mdot
.41619 .49012 Mdot
.62637 .46661 Mdot
.53577 .36258 Mdot
.58834 .36232 Mdot
.64655 .47469 Mdot
.43564 .58099 Mdot
.51955 .36302 Mdot
.45525 .58089 Mdot
.60978 .25523 Mdot
.46618 .76797 Mdot
.61086 .31802 Mdot
.3838 .48087 Mdot
.63041 .58994 Mdot
.69425 .53165 Mdot
.41329 .61147 Mdot
.17271 .53016 Mdot
.39767 .34978 Mdot
.43425 .63236 Mdot
.65107 .49397 Mdot
.56413 .83095 Mdot
.36777 .57803 Mdot
.5692 .64802 Mdot
.66995 .50197 Mdot
.7927 .55857 Mdot
.76224 .58043 Mdot
.36317 .55607 Mdot
.81665 .36434 Mdot
.63245 .67819 Mdot
.52828 .36875 Mdot
.71725 .68485 Mdot
.5518 .62748 Mdot
.34532 .38177 Mdot
.20192 .5087 Mdot
.25258 .30287 Mdot
.6017 .64452 Mdot
.56828 .32916 Mdot
.60495 .62264 Mdot
.40742 .36334 Mdot
.54029 .62959 Mdot
.53277 .34808 Mdot
.40156 .60359 Mdot
.55924 .3532 Mdot
.36889 .36176 Mdot
.63838 .74612 Mdot
.63575 .44382 Mdot
.52744 .38831 Mdot
.66369 .468 Mdot
.24488 .40399 Mdot
.25291 .48742 Mdot
.67011 .45927 Mdot
.37061 .68046 Mdot
.38295 .52151 Mdot
.54918 .6504 Mdot
.55263 .3305 Mdot
.40353 .30059 Mdot
.69935 .44444 Mdot
.58448 .64264 Mdot
.5205 .37543 Mdot
.74971 .61998 Mdot
.46725 .63421 Mdot
.38186 .51986 Mdot
.37393 .41918 Mdot
.57998 .65196 Mdot
.57182 .33362 Mdot
.74974 .71585 Mdot
.6037 .62329 Mdot
.50269 .34636 Mdot
.66012 .44748 Mdot
.69123 .49707 Mdot
.42849 .53421 Mdot
.70967 .51701 Mdot
.53575 .38213 Mdot
.61966 .50803 Mdot
.61689 .66767 Mdot
.78408 .59007 Mdot
.41025 .37569 Mdot
.54968 .36347 Mdot
.46226 .56488 Mdot
.61447 .69084 Mdot
.71463 .32722 Mdot
.39685 .73502 Mdot
.85197 .49338 Mdot
.55897 .34292 Mdot
.59389 .6453 Mdot
.57249 .65303 Mdot
.34739 .61068 Mdot
.72176 .67125 Mdot
.49476 .23782 Mdot
.40612 .64892 Mdot
.59318 .47221 Mdot
.53247 .31978 Mdot
.5638 .31361 Mdot
.40641 .50247 Mdot
.4299 .58032 Mdot
.66641 .44539 Mdot
.40217 .60206 Mdot
.61741 .62312 Mdot
.41876 .54126 Mdot
.67275 .46754 Mdot
.54021 .37557 Mdot
.36908 .57371 Mdot
.40132 .34608 Mdot
.63721 .46558 Mdot
.70671 .4826 Mdot
.55394 .36693 Mdot
.56204 .62161 Mdot
.58816 .55204 Mdot
.55025 .33276 Mdot
.43639 .57246 Mdot
.48953 .45998 Mdot
.35589 .58291 Mdot
.56842 .57823 Mdot
.60066 .62254 Mdot
.57707 .37539 Mdot
.53361 .62553 Mdot
.66826 .4772 Mdot
.21106 .46038 Mdot
.3987 .58887 Mdot
.50531 .33773 Mdot
.75637 .40716 Mdot
.57275 .56168 Mdot
.62701 .64422 Mdot
.55641 .24614 Mdot
.54705 .64413 Mdot
.51697 .34781 Mdot
.55741 .19025 Mdot
.3903 .37347 Mdot
.58179 .38154 Mdot
.24194 .63166 Mdot
.56509 .37161 Mdot
.42768 .53955 Mdot
.39615 .53771 Mdot
.56248 .38224 Mdot
.38708 .32996 Mdot
.63353 .78792 Mdot
.51899 .31088 Mdot
.59902 .64342 Mdot
.53859 .21127 Mdot
.83397 .58044 Mdot
.64036 .54522 Mdot
.67526 .44915 Mdot
.46522 .60135 Mdot
.3792 .52418 Mdot
.65695 .50153 Mdot
.623 .45225 Mdot
.41783 .35669 Mdot
.50963 .33574 Mdot
.62638 .68041 Mdot
.69934 .46115 Mdot
.52178 .64727 Mdot
.5115 .2718 Mdot
.33716 .59378 Mdot
.76292 .34631 Mdot
.35005 .59438 Mdot
.24334 .47194 Mdot
.66957 .46432 Mdot
.40468 .61537 Mdot
.33905 .53964 Mdot
.676 .50645 Mdot
.37049 .3383 Mdot
.54417 .30259 Mdot
.54561 .3521 Mdot
.25972 .75108 Mdot
.4536 .57369 Mdot
.42411 .54524 Mdot
.65272 .48177 Mdot
.41546 .27908 Mdot
.59282 .65607 Mdot
.55572 .61446 Mdot
.53891 .37975 Mdot
.57101 .42336 Mdot
.41252 .53015 Mdot
.40843 .60921 Mdot
.54523 .34367 Mdot
.52526 .38471 Mdot
.64184 .35899 Mdot
.41395 .55378 Mdot
.66278 .48833 Mdot
.3079 .3153 Mdot
.66211 .46088 Mdot
.36349 .59123 Mdot
.42406 .54823 Mdot
.34333 .55516 Mdot
.4482 .598 Mdot
.64378 .50247 Mdot
.36028 .59383 Mdot
.36306 .51987 Mdot
.59102 .64476 Mdot
.35906 .55507 Mdot
.60274 .44618 Mdot
.40646 .59859 Mdot
.37536 .33706 Mdot
.59358 .72215 Mdot
.36773 .57693 Mdot
.41273 .53797 Mdot
.59686 .347 Mdot
.38677 .58582 Mdot
.69082 .46049 Mdot
.59492 .66636 Mdot
.65658 .4878 Mdot
.69472 .46787 Mdot
.54306 .31624 Mdot
.39348 .32774 Mdot
.41403 .62504 Mdot
.35778 .341 Mdot
.4194 .63103 Mdot
.44514 .59293 Mdot
.4742 .3279 Mdot
.71935 .23696 Mdot
.69884 .73071 Mdot
.40028 .59015 Mdot
.56969 .36741 Mdot
.57041 .35786 Mdot
.59476 .58364 Mdot
.4137 .52056 Mdot
.67797 .51416 Mdot
.67465 .44753 Mdot
.32794 .73765 Mdot
.33624 .47634 Mdot
.37419 .33709 Mdot
.53554 .48789 Mdot
.44885 .56291 Mdot
.4076 .61554 Mdot
.4552 .56463 Mdot
.5787 .35082 Mdot
.28488 .61867 Mdot
.56431 .39256 Mdot
.66455 .55255 Mdot
.65118 .46925 Mdot
.36415 .56592 Mdot
.74496 .318 Mdot
.56878 .66615 Mdot
.59496 .66677 Mdot
.70932 .48803 Mdot
.5321 .39986 Mdot
.57616 .79658 Mdot
.16784 .41083 Mdot
.6239 .70009 Mdot
.37144 .36837 Mdot
.42486 .60715 Mdot
.55616 .37881 Mdot
.61501 .66494 Mdot
.3687 .36518 Mdot
.36773 .59013 Mdot
.47908 .25634 Mdot
.40865 .59249 Mdot
.75866 .50155 Mdot
.61215 .62713 Mdot
.16445 .59281 Mdot
.59812 .59879 Mdot
.64383 .49506 Mdot
.65009 .49594 Mdot
.41365 .54931 Mdot
.64884 .66136 Mdot
.54934 .63033 Mdot
.41714 .40878 Mdot
.40951 .34107 Mdot
.65164 .56801 Mdot
.38386 .36999 Mdot
.52529 .35734 Mdot
.3682 .3554 Mdot
.53305 .34538 Mdot
.58961 .78932 Mdot
.42673 .6669 Mdot
.38449 .3582 Mdot
.7588 .42516 Mdot
.37684 .52491 Mdot
.35155 .34164 Mdot
.39937 .50516 Mdot
.3965 .64614 Mdot
.54782 .34285 Mdot
.41164 .34938 Mdot
.40515 .61433 Mdot
.30314 .74276 Mdot
.67407 .45835 Mdot
.67304 .51411 Mdot
.40316 .5062 Mdot
.55307 .32459 Mdot
.57873 .60164 Mdot
.18063 .46769 Mdot
.69083 .45048 Mdot
.40371 .54001 Mdot
.35828 .53399 Mdot
.54839 .65124 Mdot
.67484 .2456 Mdot
.42282 .55277 Mdot
.53834 .58293 Mdot
.41099 .55068 Mdot
.64607 .45914 Mdot
.58409 .61114 Mdot
.58027 .66016 Mdot
.51945 .37299 Mdot
.58234 .677 Mdot
.48407 .48819 Mdot
.77004 .44347 Mdot
.32709 .53136 Mdot
.67277 .48006 Mdot
.67429 .58339 Mdot
.69217 .53738 Mdot
.24808 .60257 Mdot
.62153 .62231 Mdot
.36885 .60275 Mdot
.58671 .68 Mdot
.37409 .36062 Mdot
.59331 .67025 Mdot
.58788 .59353 Mdot
.37767 .5936 Mdot
.36814 .55434 Mdot
.53417 .37277 Mdot
.72685 .66431 Mdot
.55313 .62965 Mdot
.37234 .53713 Mdot
.33772 .56046 Mdot
.45917 .57375 Mdot
.42241 .41982 Mdot
.58209 .61214 Mdot
.40398 .18556 Mdot
.41934 .45265 Mdot
.55565 .62655 Mdot
.71495 .76293 Mdot
.74199 .37031 Mdot
.61052 .35701 Mdot
.46024 .35702 Mdot
.4067 .54891 Mdot
.5092 .36625 Mdot
.36785 .55978 Mdot
.76568 .35339 Mdot
.3831 .57993 Mdot
.3744 .33545 Mdot
.4532 .58035 Mdot
.5861 .37166 Mdot
.55715 .34298 Mdot
.40713 .54014 Mdot
.37052 .57107 Mdot
.64291 .75331 Mdot
.54073 .62344 Mdot
.60975 .66297 Mdot
.61968 .34059 Mdot
.39194 .36297 Mdot
.64682 .48463 Mdot
.40701 .57576 Mdot
.5567 .32299 Mdot
.55819 .34567 Mdot
.5663 .61336 Mdot
.52996 .331 Mdot
.68255 .47953 Mdot
.39937 .58527 Mdot
.65954 .50555 Mdot
.39064 .37507 Mdot
.58544 .61312 Mdot
.36077 .555 Mdot
.4412 .56184 Mdot
.61471 .65307 Mdot
.40597 .61737 Mdot
.3946 .33501 Mdot
.56287 .36826 Mdot
.603 .64397 Mdot
.68519 .49423 Mdot
.52645 .35351 Mdot
.34869 .57932 Mdot
.79932 .34844 Mdot
.43382 .5401 Mdot
.3954 .54412 Mdot
.26199 .70327 Mdot
.44938 .5722 Mdot
.55638 .3356 Mdot
.61138 .66892 Mdot
.48908 .60607 Mdot
.32807 .41666 Mdot
.24876 .7622 Mdot
.56059 .39175 Mdot
.42343 .60485 Mdot
.25715 .64606 Mdot
.41719 .60548 Mdot
.38678 .751 Mdot
.55499 .39794 Mdot
.58483 .49145 Mdot
.46139 .57711 Mdot
.69386 .48104 Mdot
.5523 .38137 Mdot
.53451 .34059 Mdot
.57734 .2291 Mdot
.38742 .60324 Mdot
.46711 .4211 Mdot
.3618 .58367 Mdot
.6887 .49281 Mdot
.34845 .47858 Mdot
.55634 .33873 Mdot
.82291 .58031 Mdot
.41341 .55893 Mdot
.58615 .62133 Mdot
.59541 .35126 Mdot
.70389 .45884 Mdot
.35042 .56146 Mdot
.37235 .32972 Mdot
.6364 .44001 Mdot
.34245 .51768 Mdot
.67581 .48137 Mdot
.34965 .56972 Mdot
.47965 .54944 Mdot
.81955 .51468 Mdot
.60936 .61364 Mdot
.66545 .44716 Mdot
.47384 .45113 Mdot
.36845 .60066 Mdot
.60247 .64558 Mdot
.58697 .64553 Mdot
.38313 .37376 Mdot
.57483 .5121 Mdot
.76931 .54187 Mdot
.44082 .78713 Mdot
.5533 .2171 Mdot
.59103 .37381 Mdot
.6807 .38978 Mdot
.39022 .54748 Mdot
.43964 .45084 Mdot
.68527 .45494 Mdot
.43558 .54006 Mdot
.52587 .70236 Mdot
.55906 .65868 Mdot
.43796 .54705 Mdot
.38681 .3451 Mdot
.34485 .31807 Mdot
.29931 .32244 Mdot
.21658 .54526 Mdot
.53677 .36922 Mdot
.32469 .56151 Mdot
.50386 .59005 Mdot
.54937 .32466 Mdot
.34014 .58233 Mdot
.54765 .32596 Mdot
.38807 .21416 Mdot
.35421 .34993 Mdot
.58993 .62017 Mdot
.64934 .53766 Mdot
.36278 .61199 Mdot
.40048 .52782 Mdot
.39606 .32757 Mdot
.42944 .57738 Mdot
.80762 .46382 Mdot
.41527 .4197 Mdot
.52184 .35559 Mdot
.60469 .60999 Mdot
.33845 .56545 Mdot
.52651 .50114 Mdot
.41664 .60162 Mdot
.51104 .7901 Mdot
.41061 .53726 Mdot
.76728 .57975 Mdot
.61322 .62397 Mdot
.67136 .47314 Mdot
.42967 .61545 Mdot
.38706 .5744 Mdot
.33064 .45969 Mdot
.41833 .62986 Mdot
.39007 .61188 Mdot
.48675 .62875 Mdot
.59931 .60264 Mdot
.60667 .62696 Mdot
.55156 .38935 Mdot
.27991 .67209 Mdot
.66548 .48446 Mdot
.48833 .5911 Mdot
.71135 .49348 Mdot
.34723 .69363 Mdot
.36237 .35731 Mdot
.25174 .52806 Mdot
.39851 .56253 Mdot
.57147 .66108 Mdot
.19774 .42324 Mdot
.54979 .61456 Mdot
.52893 .47415 Mdot
.67757 .50285 Mdot
.55482 .63317 Mdot
.39038 .56962 Mdot
.63921 .70685 Mdot
.27661 .70843 Mdot
.66057 .47648 Mdot
.37405 .62261 Mdot
.58961 .36886 Mdot
.54523 .26503 Mdot
.82658 .53038 Mdot
.6699 .45603 Mdot
.60278 .46484 Mdot
.3953 .60754 Mdot
.57961 .6737 Mdot
.69259 .48495 Mdot
.64845 .45862 Mdot
.52734 .3339 Mdot
.3689 .55192 Mdot
.37168 .54939 Mdot
.51476 .35993 Mdot
.65525 .48536 Mdot
.3904 .51447 Mdot
.3438 .52131 Mdot
.48873 .86084 Mdot
.76511 .59964 Mdot
.27876 .78395 Mdot
.60267 .57753 Mdot
.49849 .68319 Mdot
.17418 .47864 Mdot
.56861 .61731 Mdot
.42384 .61228 Mdot
.4104 .4993 Mdot
.53669 .38276 Mdot
.39075 .59393 Mdot
.56693 .40062 Mdot
.69925 .4982 Mdot
.55884 .83119 Mdot
.7049 .60963 Mdot
.32661 .25132 Mdot
.38876 .59389 Mdot
.51209 .60828 Mdot
.37269 .35358 Mdot
.64508 .57443 Mdot
.59095 .61529 Mdot
.45609 .54917 Mdot
.64159 .7516 Mdot
.57492 .38599 Mdot
.58013 .62893 Mdot
.66042 .77339 Mdot
.63648 .59957 Mdot
.35648 .58262 Mdot
.55105 .39272 Mdot
.16849 .52041 Mdot
.51305 .64803 Mdot
.69224 .51547 Mdot
.36915 .33863 Mdot
.5707 .3786 Mdot
.66207 .44351 Mdot
.54171 .59142 Mdot
.57059 .626 Mdot
.58122 .60421 Mdot
.67211 .73402 Mdot
.59831 .37437 Mdot
.37451 .35498 Mdot
.28877 .52067 Mdot
.3417 .46603 Mdot
.3814 .33575 Mdot
.5886 .36123 Mdot
.61476 .6188 Mdot
.55551 .6461 Mdot
.59385 .66598 Mdot
.74384 .69083 Mdot
.60451 .68101 Mdot
.58369 .21695 Mdot
.4548 .58607 Mdot
.32084 .59807 Mdot
.4207 .60675 Mdot
.67761 .51268 Mdot
.61393 .64927 Mdot
.67455 .42524 Mdot
.39216 .63036 Mdot
.26162 .50423 Mdot
.42767 .5366 Mdot
.63303 .46831 Mdot
.43571 .55061 Mdot
.75047 .30446 Mdot
.5735 .67458 Mdot
.39614 .5914 Mdot
.62839 .46276 Mdot
.39847 .36297 Mdot
.62522 .63108 Mdot
.36187 .55827 Mdot
.51126 .22331 Mdot
.44781 .58289 Mdot
.35358 .23732 Mdot
.79306 .51871 Mdot
.36823 .36501 Mdot
.7903 .42145 Mdot
.55557 .31949 Mdot
.39399 .6422 Mdot
.47599 .59192 Mdot
.66333 .47218 Mdot
.64969 .56778 Mdot
.54495 .3695 Mdot
.30007 .65843 Mdot
.36908 .51586 Mdot
.3909 .37608 Mdot
.41165 .66344 Mdot
.66134 .50303 Mdot
.33801 .57683 Mdot
.33318 .55121 Mdot
.65584 .25183 Mdot
.37336 .50895 Mdot
.37704 .52762 Mdot
.36146 .32259 Mdot
.6025 .2156 Mdot
.41354 .59648 Mdot
.53442 .48158 Mdot
.54157 .6257 Mdot
.40867 .63388 Mdot
.58644 .21282 Mdot
.3921 .53607 Mdot
.57102 .62214 Mdot
.54255 .58418 Mdot
.7505 .53827 Mdot
.38949 .32617 Mdot
.41073 .53688 Mdot
.64571 .21185 Mdot
.42547 .56512 Mdot
.66688 .49004 Mdot
.41358 .52204 Mdot
.53292 .35113 Mdot
.72164 .72133 Mdot
.52128 .37261 Mdot
.42585 .52854 Mdot
.58918 .66287 Mdot
.65214 .47531 Mdot
.72743 .69039 Mdot
.45069 .25536 Mdot
.64149 .2288 Mdot
.18609 .38988 Mdot
.40762 .34065 Mdot
.41409 .37761 Mdot
.69524 .50436 Mdot
.39794 .59263 Mdot
.50435 .17415 Mdot
.44176 .62447 Mdot
.44312 .57073 Mdot
.3824 .5788 Mdot
.25283 .48214 Mdot
.69972 .47697 Mdot
.55181 .34148 Mdot
.42412 .55113 Mdot
.36782 .59895 Mdot
.57776 .6181 Mdot
.39695 .3586 Mdot
.55866 .33228 Mdot
.39353 .35273 Mdot
.55714 .38069 Mdot
.6167 .80536 Mdot
.365 .52052 Mdot
.40169 .3637 Mdot
.68081 .44664 Mdot
.57521 .62034 Mdot
.74551 .50489 Mdot
.52892 .34561 Mdot
.53903 .38662 Mdot
.40678 .53772 Mdot
.56106 .62433 Mdot
.53993 .60796 Mdot
.3903 .37051 Mdot
.67638 .46548 Mdot
.36816 .57798 Mdot
.44159 .59189 Mdot
.48794 .55771 Mdot
.54831 .32048 Mdot
.7678 .47916 Mdot
.63621 .3982 Mdot
.40106 .5918 Mdot
.61619 .66808 Mdot
.37432 .57479 Mdot
.31458 .28549 Mdot
.57692 .67307 Mdot
.38403 .53462 Mdot
.77292 .71781 Mdot
.61076 .33458 Mdot
.71285 .56238 Mdot
.36064 .53365 Mdot
.14901 .51545 Mdot
.39297 .55393 Mdot
.57108 .83238 Mdot
.29227 .31187 Mdot
.4087 .52559 Mdot
.34948 .56065 Mdot
.4459 .75255 Mdot
.43283 .6002 Mdot
.51688 .3718 Mdot
.50801 .83645 Mdot
.55311 .60834 Mdot
.70107 .53387 Mdot
.56314 .7112 Mdot
.38327 .32527 Mdot
.53918 .37984 Mdot
.5965 .33357 Mdot
.39098 .34117 Mdot
.57875 .65376 Mdot
.41192 .58944 Mdot
.51804 .43967 Mdot
.56194 .33104 Mdot
.29327 .60327 Mdot
.6675 .49282 Mdot
.67777 .32063 Mdot
.35448 .40385 Mdot
.67897 .48229 Mdot
.35972 .55276 Mdot
.42391 .74272 Mdot
.58484 .77979 Mdot
.21038 .62218 Mdot
.63924 .44375 Mdot
.65891 .47469 Mdot
.74709 .698 Mdot
.42345 .35278 Mdot
.65699 .25624 Mdot
.76337 .58287 Mdot
.64797 .47845 Mdot
.61757 .60478 Mdot
.51477 .37129 Mdot
.72644 .42362 Mdot
.40742 .63777 Mdot
.44556 .59587 Mdot
.39 .57131 Mdot
.66728 .45993 Mdot
.58268 .56697 Mdot
.78266 .60664 Mdot
.6613 .46603 Mdot
.45262 .51741 Mdot
.57295 .46243 Mdot
.74587 .41397 Mdot
.52837 .32696 Mdot
.41103 .34119 Mdot
.42676 .35118 Mdot
.59296 .63137 Mdot
.4062 .336 Mdot
.3469 .3149 Mdot
.42096 .58036 Mdot
.65454 .46233 Mdot
.75465 .37929 Mdot
.68551 .4981 Mdot
.392 .34693 Mdot
.41962 .3557 Mdot
.59099 .64559 Mdot
.60976 .6649 Mdot
.4632 .71232 Mdot
.32369 .38001 Mdot
.438 .58465 Mdot
.4444 .33675 Mdot
.58468 .59424 Mdot
.30943 .59005 Mdot
.40906 .33797 Mdot
.39521 .36254 Mdot
.31579 .46185 Mdot
.3956 .56302 Mdot
.31102 .63234 Mdot
.4013 .56816 Mdot
.45961 .49258 Mdot
.3451 .56819 Mdot
.52769 .33324 Mdot
.38523 .55498 Mdot
.30486 .47103 Mdot
.39888 .61957 Mdot
.35294 .53237 Mdot
.57415 .3412 Mdot
.35271 .52085 Mdot
.53424 .35156 Mdot
.43867 .53995 Mdot
.37584 .37625 Mdot
.54095 .3819 Mdot
.31098 .42047 Mdot
.30251 .45603 Mdot
.58703 .35689 Mdot
.36092 .34817 Mdot
.35769 .32924 Mdot
.27192 .42289 Mdot
.58941 .61376 Mdot
.47372 .56668 Mdot
.3956 .59419 Mdot
.57174 .39427 Mdot
.68656 .45971 Mdot
.34711 .57858 Mdot
.37088 .52677 Mdot
.35631 .54012 Mdot
.59189 .62855 Mdot
.48412 .23831 Mdot
.40569 .36273 Mdot
.51443 .36525 Mdot
.57976 .54455 Mdot
.53123 .31953 Mdot
.32906 .57525 Mdot
.43246 .5092 Mdot
.53731 .70125 Mdot
.75031 .44555 Mdot
.76944 .671 Mdot
.57288 .62683 Mdot
.57121 .35543 Mdot
.40944 .37675 Mdot
.46002 .5353 Mdot
.57281 .66348 Mdot
.53314 .34831 Mdot
.40791 .59208 Mdot
.36054 .61568 Mdot
.77064 .41977 Mdot
.28243 .34095 Mdot
.31005 .44109 Mdot
.56043 .38805 Mdot
.58769 .34427 Mdot
.28227 .46839 Mdot
.40517 .30678 Mdot
.70329 .44384 Mdot
.39459 .60407 Mdot
.37609 .32998 Mdot
.60579 .67148 Mdot
.61038 .73577 Mdot
.64218 .47602 Mdot
.71598 .6755 Mdot
.38904 .59212 Mdot
.61378 .5552 Mdot
.59012 .66217 Mdot
.38604 .34206 Mdot
.66278 .45852 Mdot
.4041 .31497 Mdot
.57581 .35235 Mdot
.24172 .30495 Mdot
.43107 .5686 Mdot
.41039 .53904 Mdot
.63783 .45459 Mdot
.5648 .65968 Mdot
.3457 .34291 Mdot
.53873 .21664 Mdot
.53386 .33546 Mdot
.51663 .17507 Mdot
.60895 .67357 Mdot
.35236 .74155 Mdot
.51704 .33625 Mdot
.70889 .47765 Mdot
.2852 .41773 Mdot
.67852 .47558 Mdot
.42265 .53172 Mdot
.56933 .65411 Mdot
.67459 .45055 Mdot
.74806 .64039 Mdot
.2949 .75692 Mdot
.36346 .75162 Mdot
.41451 .5815 Mdot
.37051 .80151 Mdot
.41439 .21466 Mdot
.63689 .69691 Mdot
.67482 .44667 Mdot
.43284 .5372 Mdot
.40797 .53297 Mdot
.42761 .56467 Mdot
.69456 .47268 Mdot
.44537 .35235 Mdot
.54631 .33978 Mdot
.41332 .61041 Mdot
.41717 .35977 Mdot
.53642 .35957 Mdot
.71588 .48564 Mdot
.53574 .3259 Mdot
.55458 .59007 Mdot
.33457 .59219 Mdot
.65145 .60178 Mdot
.86637 .6229 Mdot
.65671 .4804 Mdot
.55017 .31872 Mdot
.40264 .51313 Mdot
.71004 .35247 Mdot
.59717 .61059 Mdot
.53051 .3363 Mdot
.4244 .54384 Mdot
.7569 .44626 Mdot
.66054 .74382 Mdot
.54563 .32847 Mdot
.57534 .66621 Mdot
.21494 .61824 Mdot
.39622 .59983 Mdot
.40678 .5618 Mdot
.56024 .6293 Mdot
.3576 .65555 Mdot
.71388 .73974 Mdot
.37204 .5721 Mdot
.67052 .47082 Mdot
.28247 .25705 Mdot
.37207 .5264 Mdot
.41439 .46348 Mdot
.54161 .37854 Mdot
.72222 .4439 Mdot
.75905 .51712 Mdot
.4342 .61708 Mdot
.62625 .26427 Mdot
.64456 .53627 Mdot
.27517 .67425 Mdot
.57736 .39959 Mdot
.43032 .23427 Mdot
.34353 .77172 Mdot
.63373 .48357 Mdot
.45623 .6489 Mdot
.59242 .24473 Mdot
.5228 .66706 Mdot
.18461 .5587 Mdot
.39654 .28142 Mdot
.64596 .75156 Mdot
.53772 .44131 Mdot
.57044 .37307 Mdot
.34748 .63976 Mdot
.36538 .55984 Mdot
.40843 .21764 Mdot
.80929 .53435 Mdot
.80114 .56414 Mdot
.37222 .80368 Mdot
.38392 .75546 Mdot
.26018 .65924 Mdot
.24694 .63647 Mdot
.42057 .47516 Mdot
.6657 .39806 Mdot
.49825 .16816 Mdot
.57097 .80515 Mdot
.4665 .19097 Mdot
.31846 .58929 Mdot
.51256 .46152 Mdot
.30403 .27958 Mdot
.43598 .66339 Mdot
.42663 .64893 Mdot
.51724 .36281 Mdot
.58812 .61082 Mdot
.64329 .2539 Mdot
.55556 .66725 Mdot
.75142 .53519 Mdot
.2253 .64887 Mdot
.28576 .74035 Mdot
.67054 .23511 Mdot
.15539 .51114 Mdot
.51454 .69617 Mdot
.4347 .13981 Mdot
.51395 .38438 Mdot
.56469 .61491 Mdot
.25281 .46746 Mdot
.30389 .48697 Mdot
.6823 .62398 Mdot
.5457 .23383 Mdot
.50923 .26117 Mdot
.26477 .38358 Mdot
.5716 .65028 Mdot
.78311 .454 Mdot
.73509 .4345 Mdot
.6981 .61492 Mdot
.53938 .81883 Mdot
.22007 .59133 Mdot
.49829 .42977 Mdot
.60069 .26801 Mdot
.68158 .34642 Mdot
.78567 .61195 Mdot
.35267 .41735 Mdot
.48238 .62465 Mdot
.76896 .5875 Mdot
.18266 .43071 Mdot
.42993 .68799 Mdot
.47414 .51226 Mdot
.30836 .4901 Mdot
.63991 .79184 Mdot
.37248 .24607 Mdot
.86322 .56351 Mdot
.56102 .67547 Mdot
.35147 .53928 Mdot
.35398 .6693 Mdot
.60444 .19063 Mdot
.36267 .31997 Mdot
.21207 .53774 Mdot
.41382 .35721 Mdot
.54284 .5943 Mdot
.70377 .73682 Mdot
.59479 .21273 Mdot
.54708 .1705 Mdot
.39265 .38185 Mdot
.48911 .58891 Mdot
.12626 .59696 Mdot
.26407 .56767 Mdot
.70596 .5842 Mdot
.49524 .85923 Mdot
.58546 .44873 Mdot
.78689 .58134 Mdot
.6746 .44982 Mdot
.39087 .80879 Mdot
.55786 .64301 Mdot
.88506 .52354 Mdot
.58512 .82597 Mdot
.56318 .72242 Mdot
.64847 .87598 Mdot
.26762 .47475 Mdot
.58824 .50417 Mdot
.62175 .52115 Mdot
.30206 .38283 Mdot
.73854 .67051 Mdot
.22101 .43495 Mdot
.70146 .34937 Mdot
.14439 .51606 Mdot
.33167 .76828 Mdot
.52698 .16931 Mdot
.30957 .25252 Mdot
.45128 .67681 Mdot
.53346 .50709 Mdot
.4063 .48377 Mdot
.5882 .29099 Mdot
.20169 .53821 Mdot
.66653 .78795 Mdot
.41492 .45047 Mdot
.24326 .75455 Mdot
.39053 .3879 Mdot
.48583 .27238 Mdot
.25802 .73164 Mdot
.26789 .39341 Mdot
.77906 .49657 Mdot
.27103 .59836 Mdot
.31376 .52122 Mdot
.5346 .52524 Mdot
.20737 .5466 Mdot
.71396 .53921 Mdot
.47079 .83753 Mdot
.15712 .54243 Mdot
.66167 .2572 Mdot
.47003 .77687 Mdot
.36948 .45873 Mdot
.62737 .67125 Mdot
.32173 .32717 Mdot
.76407 .51759 Mdot
.32284 .78703 Mdot
.65464 .51205 Mdot
.36807 .81799 Mdot
.70166 .74594 Mdot
.36188 .52128 Mdot
.47207 .5618 Mdot
.62779 .6069 Mdot
.30688 .33385 Mdot
.32075 .57215 Mdot
.74932 .34507 Mdot
.27809 .7314 Mdot
.55461 .78406 Mdot
.71964 .5226 Mdot
.64944 .55664 Mdot
.26097 .74468 Mdot
.40161 .71295 Mdot
.43289 .33431 Mdot
.4681 .82697 Mdot
.74518 .66626 Mdot
.54466 .36315 Mdot
.54344 .17804 Mdot
.61025 .45233 Mdot
.63586 .74188 Mdot
.43512 .78461 Mdot
.50687 .66871 Mdot
.27889 .73371 Mdot
.47372 .22985 Mdot
.68231 .74699 Mdot
.23806 .423 Mdot
.48263 .18037 Mdot
.74927 .42853 Mdot
.38356 .49801 Mdot
.53549 .23065 Mdot
.36523 .32711 Mdot
.47464 .73597 Mdot
.33148 .21337 Mdot
.44436 .29973 Mdot
.41496 .50786 Mdot
.57345 .72574 Mdot
.59895 .32611 Mdot
.65418 .70213 Mdot
.86047 .50268 Mdot
.33795 .55122 Mdot
.29979 .509 Mdot
.45065 .22308 Mdot
.30859 .36825 Mdot
.17975 .60002 Mdot
.24851 .3287 Mdot
.86799 .57647 Mdot
.43204 .83853 Mdot
.44539 .25056 Mdot
.31867 .74784 Mdot
.3351 .7812 Mdot
.85597 .59114 Mdot
.46728 .60614 Mdot
.65623 .51108 Mdot
.76667 .27984 Mdot
.52553 .32725 Mdot
.29114 .50698 Mdot
.55344 .21705 Mdot
.33179 .37566 Mdot
.65426 .61654 Mdot
.2954 .64341 Mdot
.53485 .44747 Mdot
.53878 .62605 Mdot
.3245 .55789 Mdot
.81463 .60932 Mdot
.84105 .63209 Mdot
.83957 .59007 Mdot
.21036 .36306 Mdot
.39526 .80945 Mdot
.59966 .54177 Mdot
.64046 .21521 Mdot
.3051 .58866 Mdot
.41765 .61493 Mdot
.34456 .3231 Mdot
.2644 .47326 Mdot
.62046 .73282 Mdot
.7204 .61391 Mdot
.42087 .6672 Mdot
.21006 .53919 Mdot
.13105 .37794 Mdot
.48773 .71367 Mdot
.55721 .20464 Mdot
.42444 .32648 Mdot
.31616 .36512 Mdot
.18749 .50949 Mdot
.62755 .72812 Mdot
.25302 .67375 Mdot
.5397 .62324 Mdot
.50579 .20268 Mdot
.43235 .30774 Mdot
.47885 .63937 Mdot
.48126 .23997 Mdot
.25665 .58291 Mdot
.65831 .56545 Mdot
.6635 .7217 Mdot
.75025 .59222 Mdot
.37371 .68037 Mdot
.39751 .41019 Mdot
.66611 .33379 Mdot
.40358 .18474 Mdot
.35013 .27708 Mdot
.42581 .46995 Mdot
.56752 .4609 Mdot
.7833 .38272 Mdot
.66401 .5289 Mdot
.45276 .48346 Mdot
.61227 .43716 Mdot
.27515 .56177 Mdot
.9112 .42311 Mdot
.84064 .55977 Mdot
.22289 .6633 Mdot
.22934 .38534 Mdot
.36074 .50748 Mdot
.24602 .66757 Mdot
.87217 .52608 Mdot
.75444 .74037 Mdot
.65148 .33187 Mdot
.52078 .39127 Mdot
.71166 .47983 Mdot
.79181 .65585 Mdot
.4563 .3514 Mdot
.23719 .61043 Mdot
.39211 .44787 Mdot
.69982 .4666 Mdot
.66626 .19197 Mdot
.61888 .79601 Mdot
.4116 .78475 Mdot
.29345 .33341 Mdot
.44767 .52441 Mdot
.79824 .43135 Mdot
.54995 .62776 Mdot
.69964 .38756 Mdot
.33669 .39592 Mdot
.55233 .3602 Mdot
.22515 .48952 Mdot
.50953 .2127 Mdot
.45347 .58033 Mdot
.49692 .47183 Mdot
.61825 .67565 Mdot
.74989 .41817 Mdot
.67437 .56967 Mdot
.7908 .71007 Mdot
.39086 .30835 Mdot
.46342 .56543 Mdot
.31381 .38189 Mdot
.51463 .24443 Mdot
.75111 .71503 Mdot
.70528 .49278 Mdot
.30842 .74825 Mdot
.49274 .4338 Mdot
.31737 .34836 Mdot
.56157 .69807 Mdot
.32238 .61385 Mdot
.36933 .52335 Mdot
.20249 .39306 Mdot
.55741 .77678 Mdot
.53587 .6642 Mdot
.44101 .63358 Mdot
.29661 .60847 Mdot
.24226 .65973 Mdot
.35245 .31398 Mdot
.67912 .32929 Mdot
.30075 .74508 Mdot
.69821 .4909 Mdot
.59003 .68058 Mdot
.43261 .37089 Mdot
.44873 .1936 Mdot
.35358 .75286 Mdot
.6629 .74332 Mdot
.41449 .43265 Mdot
.45316 .29444 Mdot
.30424 .75995 Mdot
.28754 .70871 Mdot
.75702 .30067 Mdot
.63345 .6876 Mdot
.48858 .51451 Mdot
.43161 .19122 Mdot
.58987 .60265 Mdot
.63147 .22824 Mdot
.67449 .26414 Mdot
.58669 .81681 Mdot
.48226 .45513 Mdot
.13903 .53551 Mdot
.3122 .43799 Mdot
.20019 .51307 Mdot
.7401 .68237 Mdot
.47069 .18582 Mdot
.27256 .51672 Mdot
.61282 .70165 Mdot
.43478 .75871 Mdot
.3337 .52661 Mdot
.73718 .29417 Mdot
.77256 .29873 Mdot
.40286 .39214 Mdot
.59531 .49619 Mdot
.15552 .55605 Mdot
.42837 .5829 Mdot
.85162 .50514 Mdot
.5068 .20857 Mdot
.74731 .6946 Mdot
.70527 .47579 Mdot
.35308 .57178 Mdot
.40176 .62601 Mdot
.36995 .77955 Mdot
.74402 .53729 Mdot
.26912 .60556 Mdot
.29419 .25266 Mdot
.1691 .53319 Mdot
.43239 .67111 Mdot
.29571 .5028 Mdot
.22108 .595 Mdot
.40921 .21995 Mdot
.56575 .49691 Mdot
.21502 .44991 Mdot
.27965 .39798 Mdot
.17223 .47385 Mdot
.60408 .45134 Mdot
.50035 .31302 Mdot
.66356 .54505 Mdot
.62075 .3247 Mdot
.69012 .72303 Mdot
.35996 .54795 Mdot
.65964 .77386 Mdot
.24519 .59842 Mdot
.79165 .37894 Mdot
.82527 .51418 Mdot
.83824 .56574 Mdot
.52408 .7792 Mdot
.38887 .24849 Mdot
.44651 .20917 Mdot
.38172 .18202 Mdot
.48054 .41981 Mdot
.24712 .5069 Mdot
.25674 .40416 Mdot
.30289 .75451 Mdot
.63958 .45502 Mdot
.7679 .5648 Mdot
.67976 .53489 Mdot
.29517 .7089 Mdot
.41299 .72379 Mdot
.25092 .62423 Mdot
.58909 .43325 Mdot
.87375 .57078 Mdot
.29233 .30216 Mdot
.55113 .43694 Mdot
.57668 .36059 Mdot
.41713 .24751 Mdot
.22643 .55648 Mdot
.29005 .30595 Mdot
.498 .18674 Mdot
.61287 .35416 Mdot
.57275 .54778 Mdot
.34309 .72426 Mdot
.32551 .3231 Mdot
.19952 .39495 Mdot
.31295 .38069 Mdot
.27439 .71614 Mdot
.40536 .81261 Mdot
.66029 .77172 Mdot
.26668 .4815 Mdot
.19364 .3761 Mdot
.70674 .58106 Mdot
.31903 .31792 Mdot
.50875 .21057 Mdot
.49624 .2831 Mdot
.54259 .65712 Mdot
.66028 .15099 Mdot
.25851 .29649 Mdot
.36648 .2662 Mdot
.6569 .79035 Mdot
.23522 .33944 Mdot
.75205 .42773 Mdot
.38101 .66505 Mdot
.74922 .62949 Mdot
.62327 .77506 Mdot
.38354 .57849 Mdot
.84204 .57461 Mdot
.43838 .45461 Mdot
.84832 .63836 Mdot
.2336 .6324 Mdot
.595 .48723 Mdot
.33285 .58798 Mdot
.52866 .38503 Mdot
.46191 .41083 Mdot
.34703 .48156 Mdot
.36694 .7003 Mdot
.78929 .51359 Mdot
.70051 .52733 Mdot
.50813 .3739 Mdot
.61057 .31405 Mdot
.5525 .67092 Mdot
.25229 .3585 Mdot
.62824 .38308 Mdot
.49609 .37929 Mdot
.48455 .41289 Mdot
.41832 .4483 Mdot
.76452 .50595 Mdot
.39962 .78164 Mdot
.64094 .7291 Mdot
.66802 .62356 Mdot
.52132 .3384 Mdot
.43794 .79178 Mdot
.28526 .28713 Mdot
.16497 .5268 Mdot
.66756 .78621 Mdot
.53125 .51942 Mdot
.38685 .72848 Mdot
.3973 .46379 Mdot
.802 .57686 Mdot
.64842 .64723 Mdot
.69881 .52546 Mdot
.79595 .4366 Mdot
.62411 .60821 Mdot
.61728 .26545 Mdot
.56165 .83043 Mdot
.47697 .19282 Mdot
.42785 .19056 Mdot
.40645 .4035 Mdot
.51242 .57453 Mdot
.47707 .63588 Mdot
.31205 .42709 Mdot
.695 .44359 Mdot
.52062 .14854 Mdot
.43485 .63227 Mdot
.4649 .12077 Mdot
.64858 .45625 Mdot
.48311 .65708 Mdot
.27279 .40262 Mdot
.57147 .4738 Mdot
.60841 .42987 Mdot
.32331 .28579 Mdot
.77489 .56527 Mdot
.39318 .24027 Mdot
.77741 .61089 Mdot
.52128 .38999 Mdot
.24311 .29079 Mdot
.16125 .42789 Mdot
.45372 .76678 Mdot
.44774 .55194 Mdot
.21971 .3269 Mdot
.50182 .36055 Mdot
.62533 .73143 Mdot
.18136 .60531 Mdot
.19848 .43951 Mdot
.33024 .70653 Mdot
.31557 .35436 Mdot
.24922 .50998 Mdot
.40026 .82962 Mdot
.77768 .32384 Mdot
.20778 .53349 Mdot
.64211 .45314 Mdot
.57868 .44161 Mdot
.2567 .54773 Mdot
.79545 .54914 Mdot
.7401 .46373 Mdot
.77952 .5139 Mdot
.39732 .14369 Mdot
.28333 .52142 Mdot
.29589 .52088 Mdot
.80469 .53005 Mdot
.60877 .60783 Mdot
.78477 .54129 Mdot
.77865 .49472 Mdot
.22288 .38023 Mdot
.3327 .25151 Mdot
.77296 .50329 Mdot
.39929 .17045 Mdot
.43086 .64376 Mdot
.65824 .41469 Mdot
.30807 .62211 Mdot
.29409 .5344 Mdot
.66276 .4388 Mdot
.56458 .79838 Mdot
.17403 .55477 Mdot
.69091 .52101 Mdot
.19351 .41541 Mdot
.59364 .2644 Mdot
.30751 .52199 Mdot
.38261 .77868 Mdot
.1839 .49356 Mdot
.41191 .73303 Mdot
.72936 .27538 Mdot
.58868 .73585 Mdot
.49902 .36366 Mdot
.19187 .58323 Mdot
.52421 .35057 Mdot
.2917 .60219 Mdot
.70839 .68246 Mdot
.21882 .44758 Mdot
.76609 .67789 Mdot
.38165 .32591 Mdot
.56343 .61155 Mdot
.77622 .31039 Mdot
.61823 .6624 Mdot
.81611 .61197 Mdot
.51954 .67688 Mdot
.79669 .47334 Mdot
.43693 .25766 Mdot
.42108 .27998 Mdot
.38786 .15593 Mdot
.73473 .44696 Mdot
.53874 .40397 Mdot
.71169 .27603 Mdot
.55983 .61674 Mdot
.40056 .4036 Mdot
.58393 .36096 Mdot
.47458 .38497 Mdot
.66977 .27382 Mdot
.44925 .63873 Mdot
.6316 .64684 Mdot
.47055 .37776 Mdot
.50492 .82386 Mdot
.50125 .84699 Mdot
.55978 .3366 Mdot
.52798 .13492 Mdot
.33133 .56331 Mdot
.47657 .7707 Mdot
.25973 .69493 Mdot
.65892 .18685 Mdot
.5794 .41311 Mdot
.15013 .47252 Mdot
.44941 .60406 Mdot
.20237 .46547 Mdot
.56226 .63979 Mdot
.491 .19807 Mdot
.39975 .37164 Mdot
.30551 .36326 Mdot
.64491 .4928 Mdot
.66341 .72123 Mdot
.6014 .40724 Mdot
.58363 .60386 Mdot
.22379 .38885 Mdot
.42599 .47755 Mdot
.61667 .48013 Mdot
.46135 .23691 Mdot
.44972 .77021 Mdot
.29719 .68602 Mdot
.41462 .65582 Mdot
.31055 .50302 Mdot
.37522 .20103 Mdot
.79743 .70635 Mdot
.63745 .70383 Mdot
.63467 .59999 Mdot
.72001 .3039 Mdot
.19001 .45513 Mdot
.76811 .36627 Mdot
.27856 .73762 Mdot
.44605 .46781 Mdot
.53952 .55719 Mdot
.46619 .49654 Mdot
.30714 .56276 Mdot
.55031 .46949 Mdot
.68497 .35921 Mdot
.80966 .50432 Mdot
.75826 .50132 Mdot
.40882 .68254 Mdot
.75695 .32785 Mdot
.34686 .47188 Mdot
.79364 .48399 Mdot
.4909 .35362 Mdot
.30283 .69306 Mdot
.63988 .56388 Mdot
.50538 .84932 Mdot
.27206 .72286 Mdot
.71493 .48388 Mdot
.56672 .27314 Mdot
.14847 .56821 Mdot
.44732 .62065 Mdot
.58416 .54052 Mdot
.41427 .54006 Mdot
.5165 .51134 Mdot
.61444 .16083 Mdot
.19772 .42414 Mdot
.41295 .50896 Mdot
.30418 .73372 Mdot
.34087 .77204 Mdot
.86483 .59815 Mdot
.48469 .16841 Mdot
.59477 .64741 Mdot
.83678 .61592 Mdot
.78461 .5096 Mdot
.38356 .81795 Mdot
.73281 .39982 Mdot
.33087 .81107 Mdot
.43916 .75702 Mdot
.17726 .47677 Mdot
.38588 .65898 Mdot
.75858 .6003 Mdot
.48147 .22289 Mdot
.58218 .53265 Mdot
.69866 .323 Mdot
.29508 .29296 Mdot
.23566 .28765 Mdot
.32993 .52225 Mdot
.52594 .22929 Mdot
.67515 .64309 Mdot
.1952 .60523 Mdot
.356 .28446 Mdot
.42548 .5207 Mdot
.65098 .55231 Mdot
.73064 .699 Mdot
.42713 .45591 Mdot
.6229 .59154 Mdot
.36669 .28048 Mdot
.61746 .76502 Mdot
.38567 .46679 Mdot
.43853 .19007 Mdot
.444 .76639 Mdot
.4799 .42706 Mdot
.3662 .59949 Mdot
.62268 .68748 Mdot
.36594 .37722 Mdot
.56452 .51996 Mdot
.44519 .55608 Mdot
.58735 .33602 Mdot
.73848 .48002 Mdot
.8041 .61586 Mdot
.70064 .54977 Mdot
.42756 .20202 Mdot
.43805 .64991 Mdot
.70835 .64671 Mdot
.7616 .35473 Mdot
.82808 .57239 Mdot
.43197 .31466 Mdot
.41356 .44954 Mdot
.26122 .65064 Mdot
.41071 .81763 Mdot
.49617 .6369 Mdot
.79576 .69991 Mdot
.68083 .4509 Mdot
.27879 .6163 Mdot
.72929 .62142 Mdot
.5791 .40497 Mdot
.36636 .63371 Mdot
.17912 .4735 Mdot
.32466 .35548 Mdot
.30422 .47767 Mdot
.36024 .24891 Mdot
.53895 .54548 Mdot
.38773 .76391 Mdot
.30653 .74238 Mdot
.56116 .39286 Mdot
.38491 .2082 Mdot
.61167 .49401 Mdot
.38155 .28179 Mdot
.41226 .82059 Mdot
.62434 .79891 Mdot
.61578 .42212 Mdot
.28645 .38682 Mdot
.40733 .5585 Mdot
.41156 .18594 Mdot
.19743 .41972 Mdot
.30497 .52803 Mdot
.66194 .31406 Mdot
.59487 .68032 Mdot
.65324 .36647 Mdot
.50152 .45321 Mdot
.60901 .77564 Mdot
.60242 .68604 Mdot
.79797 .44478 Mdot
.36863 .37299 Mdot
.59054 .50298 Mdot
.48085 .61895 Mdot
.29536 .38659 Mdot
.48525 .1537 Mdot
.45923 .62685 Mdot
.205 .55214 Mdot
.44659 .78394 Mdot
.53617 .21612 Mdot
.19323 .47522 Mdot
.75285 .44625 Mdot
.77414 .5687 Mdot
.32837 .72777 Mdot
.6898 .53599 Mdot
.3675 .53139 Mdot
.508 .38149 Mdot
.59388 .61121 Mdot
.18902 .59609 Mdot
.52043 .78439 Mdot
.30775 .4197 Mdot
.42312 .42 Mdot
.61322 .58997 Mdot
.62127 .52656 Mdot
.30059 .78194 Mdot
.77125 .57798 Mdot
.36283 .41659 Mdot
.48387 .4568 Mdot
.2792 .40355 Mdot
.47661 .67868 Mdot
.61119 .81885 Mdot
.3861 .66509 Mdot
.51397 .43174 Mdot
.49082 .65308 Mdot
.3689 .25528 Mdot
.17689 .60224 Mdot
.47308 .50917 Mdot
.58947 .46354 Mdot
.35204 .32915 Mdot
.76755 .38946 Mdot
.41229 .41071 Mdot
.60498 .56887 Mdot
.47239 .35405 Mdot
.65989 .28704 Mdot
.69173 .67377 Mdot
.45505 .50933 Mdot
.27486 .48338 Mdot
.27184 .68168 Mdot
.5389 .20993 Mdot
.6576 .52534 Mdot
.67632 .40074 Mdot
.56779 .79153 Mdot
.36423 .83834 Mdot
.81636 .42347 Mdot
.41162 .56076 Mdot
.63704 .53048 Mdot
.28179 .37283 Mdot
.5782 .38 Mdot
.77318 .48187 Mdot
.77477 .427 Mdot
.66066 .44913 Mdot
.32039 .34942 Mdot
.32393 .47319 Mdot
.57058 .26555 Mdot
.26941 .35948 Mdot
.6495 .57475 Mdot
.81777 .59496 Mdot
.23482 .3251 Mdot
.19001 .45822 Mdot
.50029 .8908 Mdot
.62408 .49927 Mdot
.35023 .50101 Mdot
.41397 .70942 Mdot
.45262 .83916 Mdot
.31802 .3909 Mdot
.63937 .73841 Mdot
.73485 .36122 Mdot
.47966 .51707 Mdot
.64574 .6952 Mdot
.29026 .48198 Mdot
.65001 .36029 Mdot
.55367 .45477 Mdot
.42329 .28511 Mdot
.80589 .69362 Mdot
.36135 .73494 Mdot
.26433 .67262 Mdot
.74329 .68439 Mdot
.38311 .17937 Mdot
.44477 .8387 Mdot
.30225 .45304 Mdot
.33074 .2942 Mdot
.35839 .6755 Mdot
.62254 .43204 Mdot
.46204 .66383 Mdot
.63109 .73288 Mdot
.45509 .81018 Mdot
.47667 .25622 Mdot
.47436 .66873 Mdot
.42716 .47041 Mdot
.48957 .8154 Mdot
.5905 .46178 Mdot
.41028 .78808 Mdot
.58889 .28913 Mdot
.79917 .52299 Mdot
.52691 .61323 Mdot
.33334 .41898 Mdot
.44925 .79016 Mdot
.70043 .28826 Mdot
.26926 .31186 Mdot
.33234 .1986 Mdot
.46578 .33381 Mdot
.80737 .59509 Mdot
.45965 .57424 Mdot
.89964 .54527 Mdot
.42613 .22822 Mdot
.47943 .22754 Mdot
.36487 .24064 Mdot
.54513 .30528 Mdot
.29729 .59538 Mdot
.36685 .5317 Mdot
.22158 .55824 Mdot
.33393 .70928 Mdot
.52455 .69731 Mdot
.68294 .71315 Mdot
.31073 .35172 Mdot
.38987 .44451 Mdot
.31159 .43203 Mdot
.54941 .57565 Mdot
.59236 .6768 Mdot
.83553 .59743 Mdot
.59979 .42205 Mdot
.31332 .51984 Mdot
.50735 .59588 Mdot
.37063 .67672 Mdot
.13985 .60408 Mdot
.59755 .48725 Mdot
.30776 .51032 Mdot
.40761 .76651 Mdot
.50736 .63146 Mdot
.77291 .3738 Mdot
.72309 .80705 Mdot
.91614 .53653 Mdot
.5761 .60415 Mdot
.56053 .20256 Mdot
.39531 .76252 Mdot
.27135 .64091 Mdot
.44114 .31437 Mdot
.65069 .29941 Mdot
.28171 .5824 Mdot
.63443 .71251 Mdot
.41484 .64128 Mdot
.43073 .22241 Mdot
.53095 .85077 Mdot
.67019 .71566 Mdot
.30094 .72847 Mdot
.3173 .55197 Mdot
.43379 .63833 Mdot
.47661 .89317 Mdot
.25934 .55372 Mdot
.34441 .6067 Mdot
.42333 .6727 Mdot
.47779 .55826 Mdot
.37043 .56056 Mdot
.20353 .49051 Mdot
.24953 .2869 Mdot
.38099 .46667 Mdot
.2927 .70407 Mdot
.58893 .6904 Mdot
.58838 .3201 Mdot
.6459 .458 Mdot
.62168 .42269 Mdot
.37855 .62621 Mdot
.68163 .45702 Mdot
.5029 .51386 Mdot
.15212 .55782 Mdot
.43611 .41523 Mdot
.32074 .23626 Mdot
.39312 .83927 Mdot
.50225 .78773 Mdot
.76755 .44675 Mdot
.44929 .6188 Mdot
.29945 .69237 Mdot
.43015 .81452 Mdot
.58962 .56549 Mdot
.1808 .42233 Mdot
.78263 .2566 Mdot
.76229 .40132 Mdot
.60113 .78797 Mdot
.58393 .59572 Mdot
.45945 .38864 Mdot
.36509 .74898 Mdot
.735 .40724 Mdot
.56693 .34921 Mdot
.317 .57056 Mdot
.6173 .61247 Mdot
.69078 .45523 Mdot
.5375 .12905 Mdot
.44945 .55533 Mdot
.7785 .44689 Mdot
.35723 .79448 Mdot
.59055 .73602 Mdot
.4643 .74434 Mdot
.34902 .59443 Mdot
.69252 .61636 Mdot
.58864 .46458 Mdot
.1976 .55376 Mdot
.64417 .77905 Mdot
.26303 .62781 Mdot
.51748 .78654 Mdot
.38907 .76354 Mdot
.36698 .59865 Mdot
.42123 .35641 Mdot
.72116 .43932 Mdot
.21487 .53676 Mdot
.47938 .58274 Mdot
.44698 .84704 Mdot
.60831 .40422 Mdot
.49159 .4738 Mdot
.60619 .52362 Mdot
.85763 .60384 Mdot
.42469 .69492 Mdot
.44512 .65075 Mdot
.82632 .57697 Mdot
.60652 .39699 Mdot
.30216 .33087 Mdot
.54292 .39223 Mdot
.47294 .60098 Mdot
.62242 .67797 Mdot
.85541 .50244 Mdot
.22193 .51292 Mdot
.70575 .32567 Mdot
.66797 .32831 Mdot
.58284 .22836 Mdot
.61482 .4794 Mdot
.52162 .89246 Mdot
.43299 .24317 Mdot
.85105 .53538 Mdot
.37527 .20379 Mdot
.62665 .6295 Mdot
.23097 .34705 Mdot
.40869 .63591 Mdot
.56191 .3481 Mdot
.27212 .6614 Mdot
.32544 .51464 Mdot
.68767 .7422 Mdot
.40186 .61676 Mdot
.76322 .69357 Mdot
.34313 .35117 Mdot
.53229 .25891 Mdot
.38377 .25243 Mdot
.38301 .68561 Mdot
.24099 .68862 Mdot
.75849 .36158 Mdot
.25108 .69366 Mdot
.22661 .65107 Mdot
.32317 .76645 Mdot
.68993 .733 Mdot
.74152 .26585 Mdot
.37316 .2582 Mdot
.18261 .49174 Mdot
.69352 .38073 Mdot
.35164 .65609 Mdot
.41527 .24824 Mdot
.59804 .58791 Mdot
.7407 .53943 Mdot
.64142 .55529 Mdot
.47808 .07518 Mdot
.35535 .44313 Mdot
.49176 .62406 Mdot
.41212 .25864 Mdot
.37378 .80229 Mdot
.36866 .68128 Mdot
.30667 .28603 Mdot
.51526 .46233 Mdot
.38293 .49712 Mdot
.45851 .80941 Mdot
.5382 .20522 Mdot
.51833 .24061 Mdot
.30364 .19743 Mdot
.28198 .2904 Mdot
.68132 .30426 Mdot
.53995 .46328 Mdot
.57321 .60515 Mdot
.71613 .26739 Mdot
.42976 .28078 Mdot
.18564 .40305 Mdot
.15959 .51501 Mdot
.25773 .55007 Mdot
.39699 .15468 Mdot
.51618 .20924 Mdot
.48324 .84502 Mdot
.21897 .36882 Mdot
.57465 .60304 Mdot
.29099 .44626 Mdot
.49551 .35431 Mdot
.69604 .34302 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo09Sooooo0_l0002_ooooo`007?ooool00ol0003oooooooooo`2Hooooo`;o0000[oooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`2/ooooo`;o0000Voooool001cooooo00?o0000oooo
ooooool0[?ooool2o`0009_ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0;gooooo0_l0002:ooooo`007?ooool00ol0003oooooooooo`2iooooo`;o0000
0_ooool2o`0008[ooooo000Looooo`03o`000?oooooooooo09?ooooo0_l0000Tooooo`;o0000S_oo
ool001cooooo00?o0000ooooooooool0Toooool2o`0000_ooooo0_l0002Wooooo`007?ooool00ol0
003oooooooooo`2Pooooo`;o00002Oooool2o`0000gooooo0_l0002=ooooo`007?ooool00ol0003o
ooooooooo`2Looooo`;o00003Oooool2o`0000Wooooo0_l00002ooooo`;o0000SOooool001cooooo
00?o0000ooooooooool0W?ooool2o`0000[ooooo0_l0000<ooooo`;o0000TOooool001cooooo00?o
0000ooooooooool0Z?ooool2o`0001cooooo0_l00002ooooo`;o0000OOooool001cooooo00?o0000
ooooooooool0ROooool2o`0003_ooooo0_l00002ooooo`;o0000OOooool001cooooo00?o0000oooo
ooooool0OOooool2o`0000[ooooo0_l0000;ooooo`;o0000/Oooool001cooooo00?o0000oooooooo
ool0OOooool2o`0001Oooooo0_l0002aooooo`007?ooool00ol0003oooooooooo`2Cooooo`;o0000
00?oooooo`000?l000001?ooool2o`0000Oooooo0_l0002Rooooo`007?ooool2o`0009Cooooo0_l0
0005ooooo`Co00001oooool2o`0002cooooo0_l0001dooooo`007?ooool00ol0003oooooooooo`1[
ooooo`;o00003Oooool2o`000004ooooool0003o0000ooooo`;o00006?ooool2o`0003Oooooo0_l0
001dooooo`007?ooool00ol0003oooooooooo`1[ooooo`;o00003Oooool2o`000004ooooool0003o
0000ooooo`;o00008?ooool2o`000003ooooool0003o00000:;ooooo000Looooo`03o`000?oooooo
oooo0:;ooooo0_l000000ooooooo0000o`00000Aooooo`;o00002_ooool2o`0000Kooooo0_l0001k
ooooo`007?ooool00ol0003oooooooooo`2Fooooo`;o00002oooool2o`0000cooooo0_l00005oooo
o`;o00002_ooool2o`0000Kooooo0_l0001kooooo`007?ooool00ol0003oooooooooo`2Fooooo`;o
00000_ooool2o`0000;ooooo0_l00003ooooo`;o00003?ooool2o`0000?ooooo0_l0000Dooooo`;o
0000Noooool001cooooo00?o0000ooooooooool0N?ooool2o`0000Cooooo0_l0000Jooooo`;o0000
0_ooool2o`0000Oooooo0_l00005ooooo`;o00001_ooool2o`0001Cooooo0_l0001kooooo`007?oo
ool00ol0003oooooooooo`1hooooo`;o00001?ooool2o`00023ooooo0_l00002ooooo`;o000000?o
ooooo`000?l000001Oooool2o`0000Cooooo0_l0002Cooooo`007?ooool00ol0003oooooooooo`2P
ooooo`;o00000_ooool2o`0000Oooooo0_l00005ooooo`;o0000Toooool001cooooo00?o0000oooo
ooooool0NOooool2o`0000?ooooo0_l0000Iooooo`;o00000oooool2o`0000gooooo0_l0000:oooo
o`;o0000S_ooool001cooooo00?o0000ooooooooool0N?ooool3o`0000?ooooo0_l00006ooooo`;o
00004Oooool2o`0000?ooooo0_l00002ooooo`;o00005Oooool2o`0008kooooo000Looooo`03o`00
0?oooooooooo07Sooooo0_l00005ooooo`;o000000?oooooo`000?l000001?l00009ooooo`;o0000
0_ooool2o`000003ooooool0003o000000;o00000_ooool2o`0000;ooooo0_l0000Looooo`;o0000
4?ooool2o`0007Gooooo000Looooo`03o`000?oooooooooo07oooooo1ol000000ooooooo0000o`00
0002ooooo`;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l0
0002ooooo`;o00003Oooool2o`0000Oooooo0_l00004ooooo`?o00003oooool2o`0007Gooooo0000
1_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003ooooo
ooooo`1Nooooo`;o00008?ooool2o`0000Gooooo0ol000001?oooooo0000o`000?ooool2o`0000Co
oooo0_l000000ooooooo0000o`00000Fooooo`Co00001oooool2o`0000Gooooo0_l0000Booooo`;o
0000L_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q
8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo05kooooo0_l0000Xooooo`;o00001?ooool4
o`0000;ooooo0_l000000ooooooo0000o`00000Cooooo`;o000000?oooooo`000?l000002_ooool2
o`0001Sooooo0_l0001booooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:oooo
o`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0Goooool2o`0000Oooooo0_l0000Roooo
o`;o00000_ooool2o`0000Gooooo0_l00003ooooo`;o00003_ooool2o`0000Oooooo0_l00004oooo
o`;o00002?ooool2o`0008;ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_o
oooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0005oooooo0_l00007ooooo`;o00003?ooool2o`0000oo
oooo0_l00003ooooo`;o00001Oooool3o`0000Kooooo0_l00003ooooo`;o00001oooool2o`0000Ko
oooo0_l000000ooooooo0000o`00000>ooooo`;o0000P_ooool00003ooooool0003ooooo00;ooooo
00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo07Kooooo
0_l00003ooooo`;o00002_ooool2o`0000[ooooo0ol0000;ooooo`;o00001oooool3o`0000Cooooo
0ol0002Eooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0J_ooool2o`000003ooooool0003o000000Gooooo1?l0
00000ooooooo0000o`000002o`0000Gooooo0_l00004ooooo`;o00000oooool2o`0001;ooooo0_l0
00000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l000000ol0002Fooooo`0000Kooooo
ogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003o
ooooooooo`1Zooooo`;o000000?oooooo`000?l000001Oooool2o`0000?ooooo0_l00007ooooo`;o
00001?ooool2o`0000?ooooo0_l0000Booooo`;o000000?oooooo`000?l000001Oooool2o`000003
ooooool0003o000000;o000000?oooooo`000?l000006Oooool2o`0007Wooooo00001_ooooook^k^
oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooo
oooo06Sooooo0_l0000@ooooo`;o00001oooool2o`0001Oooooo0_l00003ooooo`?o00001oooool2
o`0000Kooooo0_l00006ooooo`Co00001?ooool3o`0000Kooooo1?l0001iooooo`007?ooool00ol0
003oooooooooo`1Wooooo`?o00004?ooool2o`0000Gooooo1?l00002ooooo`;o00004oooool2o`00
00;ooooo1?l00006ooooo`?o00000oooool2o`0000Sooooo1Ol000001?oooooo0000o`000?ooool3
o`0000Gooooo0ol00003ooooo`;o00004Oooool2o`0006?ooooo000Looooo`03o`000?oooooooooo
06Oooooo0_l0000<ooooo`;o00002_ooool2o`0000Cooooo0_l00008ooooo`;o00003Oooool4o`00
00?ooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000Sooooo0_l00004oooo
o`;o00001oooool4o`0000;ooooo1?l00003ooooo`;o00002?ooool2o`0000;ooooo0_l0000@oooo
o`;o0000DOooool001cooooo00?o0000ooooooooool0M?ooool3o`0000[ooooo0_l00005ooooo`;o
000000?oooooo`000?l000000_ooool4o`0000Kooooo0_l00006ooooo`?o00000_ooool3o`0000Co
oooo0_l00004ooooo`;o00005?ooool2o`0000Cooooo0_l00005ooooo`;o00002?ooool2o`0001Co
oooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o00001oooool3o`0000?ooooo
1?l0000@ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Oooooo0ol00007ooooo`;o0000
0_ooool3o`0000[ooooo0_l0002Dooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o00001ooo
ool3o`0000Gooooo0ol0000<ooooo`Co00000_ooool3o`000003ooooool0003o000000;ooooo0_l0
00000ooooooo0000o`000002o`0000Kooooo0_l00005ooooo`;o000000?oooooo`000?l000003?oo
ool4o`0000;ooooo0_l00009ooooo`;o00000_ooool2o`0007[ooooo000Looooo`03o`000?oooooo
oooo06[ooooo0_l0000;ooooo`;o00003?ooool4o`0000;ooooo0ol000000ooooooo0000o`000002
ooooo`;o000000?oooooo`000?l000002?ooool5o`0000;ooooo0_l000001?oooooo0000o`000?oo
ool2o`0000Wooooo1?l00002ooooo`;o00002Oooool2o`0000;ooooo0_l00002ooooo`;o00001ooo
ool2o`0006gooooo000Looooo`03o`000?oooooooooo06Cooooo0_l00004ooooo`;o00007?ooool2
o`0000Gooooo0_l000000ooooooo0000o`00000;ooooo`Ko00002?ooool3o`00027ooooo0_l00003
ooooo`;o00000_ooool2o`0000[ooooo0_l0001Qooooo`007?ooool00ol0003oooooooooo`1Toooo
o`;o00002Oooool2o`0000?ooooo0_l0000@ooooo`Co00000_ooool2o`0000Cooooo0_l00004oooo
o`Co000000?oooooo`000?l000001?l0000;ooooo`;o00003oooool2o`0001Gooooo0_l0000>oooo
o`;o0000HOooool001cooooo00?o0000ooooooooool0Koooool2o`0000;ooooo0ol00006ooooo`Co
000000?oooooo`000?l000000oooool2o`000004ooooool0003o0000ooooo`;o00002_ooool4o`00
0003ooooool0003o000000;ooooo0_l000001?oooooo0000o`000?l0000Hooooo`;o00009_ooool2
o`00063ooooo000Looooo`03o`000?oooooooooo07?ooooo1?l00002ooooo`;o000000?oooooo`00
0?l000000_l000000ooooooo0000o`000006ooooo`;o00003Oooool2o`0000?ooooo0_l00004oooo
o`Co00001Oooool2o`0000?ooooo0_l0000:ooooo`?o00005oooool2o`0000Wooooo0_l00003oooo
o`;o0000H?ooool001cooooo00?o0000ooooooooool0LOooool2o`0000;ooooo0_l00002ooooo`Co
00001_ooool3o`0001;ooooo0_l00009ooooo`;o00001?ooool5o`0000;ooooo0ol0000:ooooo`?o
00005oooool2o`0000Wooooo0_l0001Uooooo`007?ooool2o`0006Oooooo1?l00007ooooo`;o0000
0_ooool2o`0000Cooooo0_l00006ooooo`?o00001oooool2o`0001[ooooo0ol00004ooooo`;o0000
7_ooool3o`0007Kooooo000Looooo`03o`000?oooooooooo05Sooooo0_l00002ooooo`;o00000ooo
ool4o`000003ooooool0003o000000;o00002_ooool2o`0000;ooooo0ol0000Booooo`Co00001ooo
ool2o`0000kooooo0_l0000Hooooo`;o00002Oooool2o`000005ooooool0003o0000o`000?ooool0
0_l0001cooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o00000_ooool2o`0000?ooooo1?l0
000?ooooo`?o000000Coooooo`000?l0003o00000oooool3o`0000?ooooo0_l00004ooooo`;o0000
0oooool4o`0000Cooooo0ol0000;ooooo`;o000000?oooooo`000?l000000oooool2o`00013ooooo
0_l000000ooooooo0000o`000009ooooo`;o00000oooool4o`0000oooooo0_l0000Cooooo`;o0000
COooool001cooooo00?o0000ooooooooool0F?ooool2o`0001_ooooo1?l00005ooooo`?o000000?o
ooooo`000?l000000_l00004ooooo`;o00000_ooool5o`0000Cooooo0ol00008ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0000;ooooo0_l0000@ooooo`;o00000_ooool3o`0000?ooooo1?l0
0005ooooo`Co00000oooool2o`0000?ooooo0_l00005ooooo`;o00004oooool2o`0004gooooo000L
ooooo`03o`000?oooooooooo07Oooooo0_l00006ooooo`;o000000?oooooo`000?l000002_ooool4
o`00013ooooo0_l00005ooooo`?o00001_ooool2o`0000Wooooo0_l00004ooooo`?o000000?ooooo
o`000?l000001?l0000:ooooo`Co00000oooool2o`0000;ooooo0_l00003ooooo`;o0000H?ooool0
01cooooo00?o0000ooooooooool0G?ooool2o`0001Gooooo0_l0000:ooooo`;o0000:Oooool2o`00
0003ooooool0003o000000?ooooo0_l00002ooooo`;o00001?ooool3o`0000Kooooo1Ol0000:oooo
o`;o000000Coooooo`000?l0003o00002?ooool2o`000003ooooool0003o000000;o00001?ooool2
o`0005[ooooo000Looooo`03o`000?oooooooooo05cooooo0_l0000Eooooo`;o00002_ooool2o`00
01;ooooo0_l0000@ooooo`;o00001_ooool2o`0000Oooooo0_l00004ooooo`;o000000?oooooo`00
0?l000001?ooool2o`0000gooooo0_l00002ooooo`?o00002_ooool2o`0000Kooooo0_l0001Joooo
o`007?ooool00ol0003oooooooooo`1Xooooo`;o0000:Oooool2o`0000Gooooo0_l00006ooooo`;o
000000?oooooo`000?l000003Oooool2o`0000Wooooo0_l00003ooooo`;o00004?ooool2o`000003
ooooool0003o000001Gooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`1Fooooo`;o0000
00?oooooo`000?l000001?ooool2o`0000Kooooo1Ol0000Cooooo`;o00006Oooool2o`0000Kooooo
0_l0000<ooooo`;o00000_ooool2o`0000Cooooo0_l00008ooooo`;o00004?ooool2o`0000_ooooo
0_l00004ooooo`;o00001Oooool2o`0005Oooooo000Looooo`03o`000?oooooooooo05Kooooo0_l0
00000ooooooo0000o`000003ooooo`?o00001_ooool2o`000003ooooool0003o000000;ooooo0_l0
0006ooooo`;o00001oooool2o`0000;ooooo1?l0000Yooooo`;o00002?ooool2o`0002Oooooo0_l0
0004ooooo`;o00002_ooool2o`0005;ooooo000Looooo`03o`000?oooooooooo05kooooo0ol0000=
ooooo`;o00000oooool2o`000003ooooool0003o000000;o00000oooool2o`0000Cooooo1?l00000
0ooooooo0000o`000005ooooo`;o00003?ooool2o`0000Kooooo0_l00009ooooo`;o00001Oooool2
o`0000Sooooo0_l00008ooooo`;o00007oooool2o`0000Oooooo0_l0001Booooo`007?ooool00ol0
003oooooooooo`1Gooooo`;o00001oooool8o`0000Sooooo1Ol00003ooooo`;o00000oooool2o`00
00Oooooo1?l00005ooooo`;o00003?ooool2o`0000Kooooo0_l00007ooooo`Co00001Oooool2o`00
00Gooooo0_l000000ooooooo0000o`000008ooooo`;o00007oooool2o`0005_ooooo000Looooo`03
o`000?oooooooooo04Wooooo0_l00002ooooo`;o00002?ooool4o`0000Gooooo2?l00008ooooo`Co
00004_ooool2o`0001gooooo0_l00007ooooo`;o00003?ooool4o`0001?ooooo0_l0000;ooooo`;o
000000?oooooo`000?l000001_ooool2o`0005cooooo000Looooo`03o`000?oooooooooo04Wooooo
1_l00009ooooo`Co00007oooool2o`0002?ooooo0_l00003ooooo`;o00001Oooool2o`0000gooooo
0ol0000Eooooo`;o00002oooool2o`000003ooooool0003o000000Kooooo0_l0001Looooo`007?oo
ool00ol0003oooooooooo`1;ooooo`;o00002oooool6o`0000[ooooo0_l0000Aooooo`;o00004_oo
ool2o`0000[ooooo0_l00003ooooo`;o00002_ooool2o`0000gooooo0_l0000Vooooo`;o00001Ooo
ool4o`0005_ooooo000Looooo`03o`000?oooooooooo04gooooo0_l000000ooooooo0000o`00000:
ooooo`;o00001?ooool2o`0000Cooooo0_l00008ooooo`;o00006oooool2o`0000[ooooo0_l0000<
ooooo`Co0000:?ooool2o`0001?ooooo1?l0001Kooooo`007?ooool2o`0004Sooooo0_l00004oooo
o`;o000000?oooooo`000?l000004?ooool2o`0000_ooooo0_l000000ooooooo0000o`00000;oooo
o`;o00003?ooool2o`0000gooooo0_l00003ooooo`;o00001_ooool4o`0000Gooooo0_l00003oooo
o`;o00003oooool2o`0000Kooooo0_l00003ooooo`;o00006oooool2o`0000?ooooo0_l0001@oooo
o`007?ooool00ol0003oooooooooo`13ooooo`;o00000_ooool2o`0000Gooooo1_l00007ooooo`;o
00004_ooool2o`0000kooooo0_l0000<ooooo`;o00003Oooool2o`0000?ooooo0_l00007ooooo`Go
00000_ooool5o`000003ooooool0003o000000cooooo0_l000001?oooooo0000o`000?ooool2o`00
00?ooooo0_l00008ooooo`;o00001oooool2o`000003ooooool0003o000000Oooooo1Ol00003oooo
o`;o0000D?ooool001cooooo00?o0000ooooooooool0@oooool2o`0000Kooooo0_l000000ooooooo
0000o`000006o`0000Cooooo1?l0000Rooooo`?o00001_ooool2o`00017ooooo1?l00003ooooo`;o
00001Oooool5o`0000;ooooo0_l000001?oooooo0000o`000?l0000>ooooo`;o000000Coooooo`00
0?l0003ooooo0_l00005ooooo`?o00001Oooool2o`0000;ooooo0_l00003ooooo`;o000000?ooooo
o`000?l000001?ooool2o`000004ooooool0003o0000o`0000Wooooo0_l0001<ooooo`007?ooool0
0ol0003oooooooooo`1;ooooo`;o00001Oooool5o`0000?ooooo1?l0000?ooooo`;o00003?ooool2
o`0000?ooooo0ol00006ooooo`;o00003_ooool2o`0000?ooooo0_l00003ooooo`Co00000oooool2
o`000003ooooool0003o000000Kooooo0_l0000=ooooo`;o00003?ooool3o`0000Kooooo0_l00000
0ooooooo0000o`00000<ooooo`;o00000oooool2o`0000Gooooo0_l000000ooooooo0000o`00001<
ooooo`007?ooool00ol0003oooooooooo`1Booooo`Go00001?ooool2o`0000Oooooo0_l00006oooo
o`Go00000oooool2o`0000Gooooo0_l00003ooooo`;o00005oooool2o`0000Cooooo0_l00004oooo
o`;o00002?ooool2o`0000;ooooo0_l0000?ooooo`;o00005Oooool2o`0001Cooooo0ol00002oooo
o`Co0000Coooool001cooooo00?o0000ooooooooool0E?ooool2o`0000Gooooo0_l00003ooooo`;o
00000_ooool2o`0000Kooooo1Ol00003ooooo`;o00001Oooool2o`0000?ooooo0_l00007ooooo`;o
000000?oooooo`000?l000002oooool2o`0000Cooooo0_l00004ooooo`Oo000000?oooooo`000?l0
00001_l0000>ooooo`;o00001_ooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l0
00006_ooool2o`0000;ooooo1?l0001?ooooo`007?ooool00ol0003oooooooooo`0oooooo`;o0000
7_ooool3o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`?o00000oooool2o`000003oooo
ool0003o000000Go00001?ooool2o`0000Oooooo0_l000001?oooooo0000o`000?ooool2o`0000So
oooo0_l00008oooooa3o00002?ooool2o`0000Kooooo0_l00006ooooo`;o00000_ooool2o`0000;o
oooo0_l000000ooooooo0000o`000003ooooo`;o00004Oooool2o`0005Wooooo000Looooo`03o`00
0?oooooooooo03oooooo0_l0000;ooooo`;o00003?ooool2o`0000;ooooo0ol00003ooooo`Go0000
0oooool3o`0000?ooooo0_l000000ooooooo0000o`000006o`0000;ooooo0_l00003ooooo`;o0000
2Oooool2o`0001;ooooo4Ol00007ooooo`;o000000?oooooo`000?l000000_ooool3o`0000Kooooo
1?l00009ooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000Sooooo
1?l0001Iooooo`007?ooool00ol0003oooooooooo`19ooooo`;o000000Coooooo`000?l0003o0000
1Oooool2o`0000Cooooo0_l000001?oooooo0000o`000?l00006ooooo`;o00001?ooool2o`0000Co
oooo0_l000000ooooooo0000o`000006o`0000;ooooo0ol00002ooooo`;o00007OoooolAo`0000[o
oooo0ol000000ooooooo0000o`000002ooooo`;o00000oooool4o`0000Wooooo0_l00003ooooo`So
00001oooool3o`0000[ooooo0_l00004ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0
A?ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000000ol00003ooooo`;o0000
1oooool2o`0000Kooooo1?l00004oooooaGo00001?ooool2o`0000kooooo0_l00009oooooa?o0000
00?oooooo`000?l000002?ooool2o`0000Gooooo0_l0000:ooooo`;o000000?oooooo`000?l00000
0_ooool6o`000003ooooool0003o000000Co00001oooool2o`0000?ooooo0_l00005ooooo`;o0000
1?ooool2o`0004Sooooo000Looooo`03o`000?oooooooooo04Cooooo0_l000001?oooooo0000o`00
0?l00002ooooo`Go00003Oooool2o`0000Gooooo1?l00004oooooa?o00001?ooool4o`0000Kooooo
0_l00006ooooo`;o00002OoooolHo`0000Wooooo0_l0000<ooooo`Co000000?oooooo`000?l00000
0_ooool4o`0000Oooooo1?l00006ooooo`;o00000_ooool2o`0005Gooooo000Looooo`03o`000?oo
oooooooo04Sooooo0_l0000Booooo`Ko000000Coooooo`000?l0003ooooo0_l00006oooooago0000
0oooool2o`0000Cooooo0_l00007oooooaco00001Oooool2o`0000;ooooo0ol00008ooooo`;o0000
00?oooooo`000?l000000oooool2o`0000oooooo0_l00006ooooo`;o0000FOooool001cooooo00?o
0000ooooooooool0?Oooool4o`0001_ooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo
0_l00006oooooaKo00000oooool4o`0000;ooooo0_l00005ooooo`;o00001ooooolMo`000004oooo
ool0003o0000ooooo`;o00000_ooool3o`0000Sooooo0_l00006ooooo`;o00004oooool2o`0005go
oooo000Looooo`03o`000?oooooooooo03gooooo1?l00008ooooo`;o00003Oooool2o`0001Cooooo
5_l00003ooooo`?o00000oooool2o`00013ooooo7ol00007ooooo`?o00005Oooool5o`0000Sooooo
0_l0001Mooooo`007?ooool00ol0003oooooooooo`18ooooo`?o00002?ooool2o`0000?ooooo0_l0
0005ooooo`;o00003?oooolMo`0000_ooooo0_l00008oooooaoo00001oooool3o`0000Kooooo0_l0
0003ooooo`;o00002?ooool5o`0006Oooooo000Looooo`03o`000?oooooooooo04Oooooo1?l00008
ooooo`;o00002_ooool2o`0000Gooooo0_l00005oooooa_o00003Oooool2o`0000Sooooo8Ol00003
ooooo`;o00002Oooool2o`0000?ooooo0_l00005ooooo`;o00000_ooool3o`0000oooooo0_l00002
ooooo`;o0000Doooool001cooooo0_l00018ooooo`;o00006_ooool5o`0000Oooooo5ol000000ooo
oooo0000o`00000Eoooooago000000?oooooo`000?l000000_l00003ooooo`;o00003Oooool2o`00
00Kooooo0_l00002ooooo`Co00002Oooool4o`000003ooooool0003o000000;ooooo0_l0000:oooo
o`;o0000Aoooool001cooooo00?o0000ooooooooool0Goooool9o`0000Cooooo7Ol00004ooooo`;o
000000?oooooo`000?l000001?ooool2o`0000;ooooo9_l0000=ooooo`;o00000oooool2o`0000[o
oooo1ol00006ooooo`Co00001_ooool2o`0000Wooooo0_l00017ooooo`007?ooool00ol0003ooooo
ooooo`1Oooooo`Wo00001?oooolMo`0000Cooooo0_l000000ooooooo0000o`000002o`0000;ooooo
0_l00002ooooo`Go000000?oooooo`000?l000007_l00003ooooo`;o00002?ooool2o`0000oooooo
0_l00002ooooo`?o00001_ooool5o`0000Cooooo0ol00002ooooo`;o0000C_ooool001cooooo00?o
0000ooooooooool0C_ooool5o`000003ooooool0003o000000gooooo0_l000000ooooooo0000o`00
0006oooooa[o00001_ooool2o`0000;ooooo0_l00006ooooo`;o000000Coooooo`000?l0003ooooo
8?l00003ooooo`;o00000_ooool2o`0000Cooooo0_l0000<ooooo`;o00000oooool4o`0000Kooooo
0_l00002ooooo`;o00001?ooool4o`000003ooooool0003o000004kooooo000Looooo`03o`000?oo
oooooooo047ooooo0ol0000:ooooo`Go000000?oooooo`000?l000002_ooool2o`0000Kooooo0_l0
0005ooooo`co000000?oooooo`000?l000002?l00008ooooo`;o00002_ooool2o`0000;ooooo3_l0
00001?oooooo0000o`000?ooool@o`0000Oooooo0_l00004ooooo`Co00002_ooool2o`0000?ooooo
1?l000000ooooooo0000o`000003ooooo`?o00001_ooool2o`000004ooooool0003o0000ooooo`;o
0000C_ooool001cooooo00?o0000ooooooooool0@Oooool3o`0000Kooooo0_l00003ooooo`;o0000
1?ooool2o`0000Wooooo0_l000000ooooooo0000o`000003ooooo`;o00001Oooool<o`000003oooo
ool0003o000000Wo00004oooool2o`0000;ooooo3_l000000ooooooo0000o`00000Ao`0000_ooooo
0_l00002ooooo`;o00002_ooool2o`0000;ooooo0_l00004ooooo`;o00001?ooool2o`0000;ooooo
0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l0000:ooooo`;o0000@_ooool001cooooo
00?o0000ooooooooool0=Oooool2o`0000_ooooo0ol00005ooooo`?o00002?ooool2o`0000Gooooo
0_l00003ooooo`Co00001Oooool2o`0000Cooooo5ol00002ooooo`;o00004ooooolLo`000004oooo
ool0003o0000o`0000?ooooo0_l00008ooooo`?o00000_ooool2o`0000Wooooo1_l0000<ooooo`Co
00001Oooool2o`0000gooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`0eooooo`;o0000
2?ooool2o`0000;ooooo0_l00005ooooo`?o00003oooool2o`0000?ooooo1?l00005ooooo`;o0000
1?oooolGo`000004ooooool0003o0000o`0001Gooooo7_l00002ooooo`?o00002Oooool2o`0000;o
oooo0_l00005ooooo`;o00001?ooool2o`0000Cooooo0_l00008ooooo`;o0000F_ooool001cooooo
00?o0000ooooooooool0?oooool2o`0001Oooooo0_l0000@ooooo`;o00001?ooool=o`000003oooo
ool0003o000000?o00000_ooool6o`0001Gooooo8_l00008ooooo`?o00002_ooool6o`0000Kooooo
0_l00008ooooo`;o00000_ooool2o`0000Cooooo0ol00002ooooo`;o0000Boooool001cooooo00?o
0000ooooooooool09oooool2o`0001;ooooo0_l00002ooooo`;o00002?ooool2o`0000gooooo0_l0
00000ooooooo0000o`000004ooooo`;o00001Oooool4o`0000Gooooo6?l0000<ooooo`;o00000ooo
ool2o`0000;ooooo4_l00002ooooo`oo00001_ooool2o`000004ooooool0003o0000o`0000cooooo
1?l0000Dooooo`;o00001?ooool3o`0000;ooooo0_l0001;ooooo`007?ooool00ol0003ooooooooo
o`0Wooooo`;o00004_ooool2o`0000Kooooo1?l00002ooooo`;o00000oooool2o`0000_ooooo0_l0
0002ooooo`Go000000Coooooo`000?l0003ooooo0_l000001?oooooo0000o`000?l00005ooooo`;o
000000?oooooo`000?l000000_l000000ooooooo0000o`000009o`0000oooooo0_l00003ooooo`;o
000000Goooooo`000?l0003o0000ooooo`03o`000003ooooool0003o000001Go00000oooool2o`00
0003ooooool0003o000000?ooooo0_l000001?oooooo0000o`000?l0000@ooooo`;o00002?ooool2
o`0000Sooooo0_l0000:ooooo`?o0000BOooool001cooooo00?o0000ooooooooool0:?ooool2o`00
01Wooooo1?l000000ooooooo0000o`000004ooooo`;o00000_ooool2o`0000[ooooo0ol000001?oo
oooo0000o`000?ooool3o`0000?ooooo0ol00007ooooo`Co00000oooool5o`000003ooooool0003o
000000;o00000_ooool2o`0001?ooooo8?l00002ooooo`;o000000Coooooo`000?l0003o00000ooo
ool4o`00017ooooo0_l00008ooooo`;o00002?ooool4o`0000Kooooo1Ol00008ooooo`;o0000?ooo
ool001cooooo00?o0000ooooooooool0:?ooool2o`0000Wooooo0ol00002ooooo`;o00001Oooool2
o`0000Cooooo1Ol00008ooooo`;o00001Oooool2o`000003ooooool0003o000000;o00000_ooool2
o`000003ooooool0003o000000;o00001oooool2o`0000;ooooo0ol00003ooooo`Go00000_ooool3
o`0000Cooooo0_l00003ooooo`;o00001oooool2o`0000Oooooo0_l00002ooooo`;o00000_oooolF
o`0000Cooooo1?l00003ooooo`;o00001_ooool2o`0000Sooooo0_l000000ooooooo0000o`000002
o`0000Oooooo0_l00004ooooo`;o00000oooool2o`0000Kooooo0_l0000;ooooo`;o0000?oooool0
01cooooo00?o0000ooooooooool0<oooool3o`0000;ooooo0ol00004ooooo`;o00001?ooool4o`00
00Kooooo0_l00008ooooo`;o000000?oooooo`000?l000001_ooool2o`000003ooooool0003o0000
00;o00000oooool5o`000003ooooool0003o000000Cooooo0ol00004ooooo`;o00002_ooool2o`00
00;ooooo0_l00003ooooo`;o00002oooool2o`000003ooooool0003o000001Go00001?ooool2o`00
00;ooooo0_l00009ooooo`;o00001oooool4o`000004ooooool0003o0000o`0000Oooooo0_l00004
ooooo`;o00001_ooool2o`00057ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ
8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0iooooo`;o00000ooo
ool2o`0000Gooooo0ol00007ooooo`;o00000_ooool2o`0000oooooo0_l00003ooooo`;o00000ooo
ool2o`000003ooooool0003o000000cooooo0_l0000@ooooo`;o00004?oooolJo`0000?ooooo0ol0
0002ooooo`;o00002?ooool2o`0000?ooooo0_l00003ooooo`Co000000?oooooo`000?l000004_oo
ool3o`000003ooooool0003o0000057ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo
0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>_ooool2o`000004oooo
ool0003o0000o`0000Kooooo0_l0000;ooooo`;o00003oooool2o`0000Cooooo0ol0000?ooooo`;o
000000?oooooo`000?l000003oooool2o`0001?ooooo0_l00003oooooa?o00000oooool3o`0000;o
oooo0_l00008ooooo`;o00000oooool2o`0001cooooo0ol0001Dooooo`0000?ooooooa0@4?ooool0
0_ooool00ol@413oooooooooo`09ooooo`Go00001_ooool00ol0003oooooooooo`0jooooo`;o0000
00Coooooo`000?l0003ooooo0_l0000=ooooo`;o00000_ooool2o`0000;ooooo0_l0000;ooooo`;o
00001?ooool4o`0000gooooo0ol00002ooooo`;o00003_ooool2o`0001Oooooo0_l00003ooooo`Oo
000000?oooooo`000?l000000_l000000ooooooo0000o`000004ooooo`;o00002?ooool2o`0000Oo
oooo0_l00008ooooo`;o00002_ooool2o`0000kooooo0_l0000:ooooo`;o00001Oooool2o`0003[o
oooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo
00001oooool3o`0003Wooooo0_l00005ooooo`;o00003?ooool3o`0000;ooooo1_l0000Booooo`Go
00002oooool2o`0000?ooooo0_l0000<ooooo`;o00001Oooool2o`0000Gooooo0_l0000;ooooo`?o
00001?ooool6o`0000;ooooo1Ol00006ooooo`;o00001_ooool2o`0000Oooooo0_l00002ooooo`?o
00000oooool2o`0000Oooooo0_l000000ooooooo0000o`000008ooooo`;o00001?ooool3o`0000Wo
oooo0_l00005ooooo`;o0000>_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
2Oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo03Wooooo0_l0000<ooooo`;o
00000oooool6o`0000?ooooo1ol0000Booooo`?o00003Oooool4o`0000Gooooo1?l00003ooooo`;o
00001Oooool2o`0000Gooooo0_l0000<ooooo`Co00001_ooool2o`0000;ooooo1?l00006ooooo`?o
00000oooool2o`0000kooooo0ol00009ooooo`;o000000?oooooo`000?l000002oooool2o`0000Go
oooo0_l0000=ooooo`;o0000?Oooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool0
2_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo047ooooo0_l00004ooooo`;o0000
0oooool2o`0000;ooooo0_l00005ooooo`Go00000_ooool2o`0000oooooo0_l0000=ooooo`Co0000
0_ooool2o`000003ooooool0003o000000;o00000_ooool2o`0001cooooo0ol0000:ooooo`;o0000
1_ooool4o`0000Cooooo0_l0000Jooooo`;o00001Oooool2o`0000Gooooo0_l0000Fooooo`;o0000
0_ooool2o`0003Wooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l0
00001oooool00ol0003oooooooooo`0cooooo`;o000000?oooooo`000?l000002Oooool2o`0001_o
oooo0_l0000Mooooo`;o00000oooool4o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000_o
oooo0_l0000Oooooo`;o00001Oooool2o`0000oooooo0_l00003ooooo`;o00003?ooool2o`0000Go
oooo0_l0000Jooooo`;o0000>Oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omg
MgOo0000ooooo`06ooooo`03o`000?oooooooooo03?ooooo0_l000000ooooooo0000o`000003oooo
o`;o00005_ooool2o`0001?ooooo0_l0000Cooooo`;o00000oooool2o`0000Gooooo0ol00006oooo
o`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o00005?ooool2o`000003ooooool0003o0000
00gooooo0_l00009ooooo`;o00000oooool3o`0000?ooooo0_l0000?ooooo`;o00000_ooool2o`00
05Gooooo000Looooo`03o`000?oooooooooo03_ooooo0_l0000Fooooo`?o00000oooool6o`0000So
oooo1Ol00003ooooo`;o000000?oooooo`000?l000002?ooool2o`0000_ooooo0ol0000:ooooo`;o
00000_ooool2o`0001Wooooo0_l000000ooooooo0000o`00000Gooooo`?o00000oooool2o`0000So
oooo0_l0000;ooooo`So00002Oooool2o`0000;ooooo0_l00014ooooo`007?ooool00ol0003ooooo
ooooo`0looooo`;o00001_ooool2o`0000kooooo0_l00003ooooo`Ko000000Coooooo`000?l0003o
00001?ooool5o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool4o`0000Go
oooo1Ol00004ooooo`;o00001_ooool2o`0000;ooooo0_l0000`ooooo`;o00001Oooool2o`0000Go
oooo0_l00007ooooo`;o00003?ooool3o`0000;ooooo0_l000001?oooooo0000o`000?l00003oooo
o`Co00000_ooool2o`0004Cooooo000Looooo`03o`000?oooooooooo03Oooooo0_l00003ooooo`?o
00001Oooool2o`0000Cooooo0_l00006ooooo`Wo00001Oooool3o`0000Kooooo0_l00005ooooo`;o
00001?ooool2o`0000;ooooo0_l00007ooooo`Go00001?ooool2o`0000Kooooo0_l00002ooooo`?o
00006oooool2o`0000Oooooo0_l00002ooooo`Wo00001Oooool2o`0000;ooooo0_l000000ooooooo
0000o`00000>ooooo`;o00002_ooool2o`000004ooooool0003o0000o`0000?ooooo0ol00003oooo
o`Co00007Oooool2o`0002?ooooo000Looooo`03o`000?oooooooooo037ooooo0_l00004ooooo`;o
00001?ooool2o`0000_ooooo0_l00006ooooo`Wo00001oooool2o`0000cooooo0_l00006ooooo`;o
00004_ooool2o`0000Kooooo0_l00002ooooo`?o00006oooool2o`0000Oooooo0_l00002ooooo`Oo
00002oooool4o`0000oooooo0_l00002ooooo`?o000000Coooooo`000?l0003ooooo0ol00002oooo
o`;o00001?ooool2o`0000Cooooo0ol0000Mooooo`;o00008oooool001cooooo00?o0000oooooooo
ool0<Oooool2o`0000Gooooo0_l0000Nooooo`;o00002?ooool2o`0000Oooooo0_l00003ooooo`;o
00001_ooool2o`0001;ooooo1?l00008ooooo`;o00001?ooool4o`00023ooooo0_l00009ooooo`;o
00002?ooool4o`0000Oooooo0_l00008ooooo`?o000000Coooooo`000?l0003ooooo1?l000000ooo
oooo0000o`000003ooooo`;o00005oooool2o`000003ooooool0003o000002kooooo000Looooo`03
o`000?oooooooooo037ooooo0_l00005ooooo`;o00006Oooool2o`0000cooooo0_l00008ooooo`;o
00000_ooool3o`0000Cooooo0_l0000;ooooo`;o00001oooool4o`0000cooooo1_l000000ooooooo
0000o`000008ooooo`;o00003Oooool2o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l0
00000_ooool2o`0000Oooooo1Ol00007ooooo`;o00002Oooool2o`000003ooooool0003o000000?o
oooo0_l00004ooooo`Ko00005Oooool2o`000003ooooool0003o000002kooooo000Looooo`03o`00
0?oooooooooo033ooooo0_l0000Booooo`;o00003Oooool2o`0000Wooooo0_l000000ooooooo0000
o`000003ooooo`;o00001oooool3o`0000Cooooo0_l0000;ooooo`;o00001_ooool3o`0000kooooo
0_l000000ooooooo0000o`000002ooooo`;o00002?ooool4o`0000_ooooo0_l00002ooooo`;o0000
00Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000008ooooo`Go00004oooool3o`0000go
oooo0_l00002ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0<?ooool2o`0000_ooooo
0_l00004ooooo`?o00005_ooool4o`0000;ooooo0ol000001?oooooo0000o`000?ooool3o`0001go
oooo1Ol0000Dooooo`;o000000?oooooo`000?l000002?ooool2o`0000Kooooo0_l00007ooooo`;o
000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l0
00000ol00007ooooo`;o00001Oooool2o`0000?ooooo1Ol0000?ooooo`;o0000B?ooool001cooooo
00?o0000ooooooooool0>?ooool2o`0000?ooooo0_l00004ooooo`;o00005oooool2o`0000?ooooo
1?l00004ooooo`?o00001?ooool2o`0000oooooo1?l00004ooooo`;o00001?ooool3o`00013ooooo
0_l000000ooooooo0000o`000004ooooo`;o00002Oooool4o`0000Kooooo0_l00005ooooo`;o0000
0_ooool2o`000003ooooool0003o000000Wo00001Oooool3o`0000Gooooo0_l00005ooooo`?o0000
2oooool2o`0000?ooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00008Ooo
ool4o`0000;ooooo0_l0000=ooooo`Co00001oooool2o`0000Cooooo1?l00004ooooo`;o00001?oo
ool3o`0001Wooooo0_l00009ooooo`Co000000?oooooo`000?l000000oooool2o`0000Wooooo3_l0
0005ooooo`Go00001?ooool2o`0000Cooooo1ol00002ooooo`;o00000oooool2o`0000;ooooo0ol0
0017ooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00003?ooool2o`0000Sooooo1?l0000C
ooooo`;o00001oooool4o`0000Cooooo0ol00007ooooo`;o000000?oooooo`000?l000000_l00004
ooooo`;o00004?ooool2o`0000kooooo0ol00003ooooo`?o00002?ooool@o`0000?ooooo1Ol00004
ooooo`;o00000_ooool2o`000003ooooool0003o000000Co00000_ooool5o`0000Cooooo0_l00018
ooooo`007?ooool2o`0004?ooooo0ol0000<ooooo`;o00003oooool2o`0000Cooooo0_l0000Boooo
o`?o00001?ooool3o`0000Gooooo1?l00003ooooo`?o000000?oooooo`000?l000000_l0000@oooo
o`;o00003_ooool2o`0000Cooooo1?l00003ooooo`Oo000000?oooooo`000?l000002ol000001?oo
oooo0000o`000?l00006ooooo`;o00000oooool4o`000003ooooool0003o000000Cooooo1Ol0001>
ooooo`007?ooool00ol0003oooooooooo`0jooooo`;o00001_ooool2o`0000kooooo0_l0000:oooo
o`;o00000_ooool4o`0000;ooooo0_l0000Aooooo`;o00000oooool2o`000004ooooool0003o0000
o`0000Cooooo0ol00006ooooo`;o000000Coooooo`000?l0003ooooo2?l0000?ooooo`;o00002_oo
ool2o`0000;ooooo1?l00003oooooaSo00001oooool2o`0000Gooooo1?l00003ooooo`;o00001Ooo
ool2o`0004cooooo000Looooo`03o`000?oooooooooo03[ooooo0_l00004ooooo`;o00004?ooool2
o`0000[ooooo0ol00003ooooo`;o00003_ooool2o`0000Gooooo0_l00003ooooo`;o00000_ooool2
o`000004ooooool0003o0000ooooo`?o00003?ooool8o`0000oooooo0_l0000:ooooo`;o00000_oo
ool2o`0000Sooooo3ol000000ooooooo0000o`000003o`0000Oooooo0_l00003ooooo`;o00000_oo
ool2o`0000?ooooo0_l00002ooooo`Ko0000Boooool001cooooo00?o0000ooooooooool0>_ooool2
o`0000Cooooo0ol0000Kooooo`?o00000_ooool2o`0000?ooooo0_l0000:ooooo`;o00003_ooool2
o`000003ooooool0003o0000013ooooo1?l00002ooooo`;o00000_ooool2o`00013ooooo0_l00005
ooooo`;o00000_ooool2o`0000Sooooo6Ol00005ooooo`;o000000?oooooo`000?l000002oooool6
o`0004_ooooo000Looooo`03o`000?oooooooooo02cooooo0_l00005ooooo`;o00001_ooool2o`00
0003ooooool0003o000000?o00004oooool2o`0000Cooooo1?l00003ooooo`;o00000oooool2o`00
0003ooooool0003o000000;o000000?oooooo`000?l000002?ooool2o`000003ooooool0003o0000
00;o00000_ooool3o`0001Gooooo0_l00006ooooo`?o000000?oooooo`000?l000000oooool2o`00
00Oooooo0ol00003ooooo`?o00000_ooool2o`0000Kooooo6ol00005ooooo`;o00000oooool2o`00
00;ooooo0_l00009ooooo`;o00001Oooool2o`0004Cooooo000Looooo`03o`000?oooooooooo02co
oooo0_l00005ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000co
oooo0_l00005ooooo`?o00001?ooool2o`0000gooooo1?l000000ooooooo0000o`000006ooooo`Co
000000?oooooo`000?l000000_l00002ooooo`;o00000_ooool2o`0000Cooooo0_l00002ooooo`;o
00000_ooool2o`0000gooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00002?ooool2o`00
00?ooooo0ol00002ooooo`;o00000oooool2o`000003ooooool0003o000001[o00001_ooool2o`00
0003ooooool0003o000000;ooooo0_l00003ooooo`;o00001?ooool2o`0000?ooooo1?l00014oooo
o`007?ooool00ol0003oooooooooo`0_ooooo`;o00001_ooool2o`0000Gooooo0_l0000>ooooo`;o
00001Oooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`00000:ooooo`;o
00001_ooool2o`0000?ooooo1?l00006ooooo`;o00000oooool2o`0000Cooooo0_l00002ooooo`;o
00000_ooool2o`00017ooooo0_l00005ooooo`;o00004Oooool2o`000004ooooool0003o0000oooo
oa;o00000_ooool8o`000003ooooool0003o000000?ooooo1Ol00007ooooo`;o00002Oooool4o`00
04Cooooo000Looooo`03o`000?oooooooooo02gooooo1?l00003ooooo`Co00004oooool2o`0000Go
oooo0_l00004ooooo`;o00001Oooool2o`0000Cooooo0_l00006ooooo`;o00001?ooool2o`0000Co
oooo0_l00007ooooo`;o00000oooool2o`0000Wooooo0_l00008ooooo`Co00002?ooool2o`0000?o
oooo1_l00003ooooo`;o00001Oooool2o`0000?ooooo0_l00004oooooaWo00001?ooool2o`000003
ooooool0003o000000;ooooo0_l0000Aooooo`Ko0000A?ooool001cooooo00?o0000ooooooooool0
;Oooool3o`0000Cooooo1?l00003ooooo`;o00003_ooool2o`0000Gooooo0ol0000:ooooo`;o0000
1?ooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000001oooool2o`0000;ooooo
0_l00006ooooo`Co00002Oooool3o`0000Oooooo1?l00008ooooo`;o00000oooool2o`0000;ooooo
0_l00003ooooo`;o00001Oooool2o`000003ooooool0003o000000Kooooo0_l00002ooooo`co0000
00?oooooo`000?l000002?l00005ooooo`;o00005Oooool4o`0004Kooooo000Looooo`03o`000?oo
oooooooo02kooooo0_l00005ooooo`?o00000oooool2o`0001Kooooo0_l00004ooooo`;o00001?oo
ool2o`0000Sooooo1_l000000ooooooo0000o`000006ooooo`;o00000oooool2o`0000Kooooo1?l0
0006ooooo`;o000000Coooooo`000?l0003o00001Oooool2o`0002Cooooo0_l00002ooooo`?o0000
00Coooooo`000?l0003ooooo6_l00007ooooo`;o00001Oooool2o`000003ooooool0003o0000057o
oooo000Looooo`03o`000?oooooooooo03Gooooo0_l000000ooooooo0000o`00000Cooooo`?o0000
0_ooool3o`000004ooooool0003o0000ooooo`Co00000_ooool2o`0000Wooooo1Ol00009ooooo`?o
00003?ooool2o`0000Kooooo0_l000000ooooooo0000o`000006ooooo`;o00000_ooool2o`0000[o
oooo1?l00002ooooo`;o00004_ooool3o`0000?ooooo2_l000000ooooooo0000o`00000>o`0000Oo
oooo0_l00005ooooo`;o000000Coooooo`000?l0003o0000D?ooool001cooooo00?o0000oooooooo
ool0<oooool2o`0000?ooooo0_l00003ooooo`Co00003?ooool3o`0000;ooooo0ol000001?oooooo
0000o`000?ooool4o`00013ooooo0_l0000:ooooo`;o00001Oooool2o`0000_ooooo1?l0000=oooo
o`;o00002_ooool4o`0000;ooooo0_l0000>ooooo`;o00002?oooolMo`0000cooooo0_l00002oooo
o`;o00001Oooool2o`0000Kooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o
00001?ooool2o`0000Oooooo1Ol00004ooooo`;o00000_ooool2o`0000?ooooo0ol00008ooooo`;o
00001?ooool2o`0000Wooooo0_l0000Dooooo`;o000000?oooooo`000?l000002?ooool4o`0000?o
oooo0_l00003ooooo`;o00002Oooool2o`000004ooooool0003o0000ooooo`Ko00003Oooool5o`00
00Sooooo3?l000001Ooooooo0000o`000?l0003ooooo00co00005oooool2o`0000Kooooo0_l00011
ooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o00001?ooool2o`0000?ooooo0_l000000ooo
oooo0000o`000003o`0000Gooooo0_l00002ooooo`;o00000oooool3o`0000kooooo0ol00002oooo
o`;o00001?ooool2o`0000Gooooo0_l00007ooooo`;o00001_ooool3o`0000_ooooo1_l00003oooo
o`;o00002Oooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000[ooooo2Ol00005
ooooo`;o00000oooool<o`000003ooooool0003o000000_o0000H_ooool001cooooo00?o0000oooo
ooooool0>?ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000007Oooool2
o`0000;ooooo0_l000000ooooooo0000o`000008ooooo`;o00000oooool2o`0000;ooooo0_l00003
ooooo`;o000000Coooooo`000?l0003o00002oooool6o`00013ooooo0_l0000?ooooo`;o000000?o
ooooo`000?l000000_l000000ooooooo0000o`000004o`0000?ooooo0_l00003ooooo`co000000?o
ooooo`000?l000002ol0000Booooo`;o000000?oooooo`000?l000002_ooool2o`0000Oooooo0_l0
000fooooo`007?ooool00ol0003oooooooooo`0booooo`;o00001?ooool2o`0000Gooooo1?l00007
ooooo`;o00001?ooool2o`0001Gooooo0_l0000=ooooo`;o000000?oooooo`000?l000000_l00002
ooooo`;o00004oooool2o`0000Sooooo1?l00004ooooo`;o00003?ooool2o`000003ooooool0003o
000000Gooooo0ol00002ooooo`;o00001oooool>o`000003ooooool0003o000000Wo00004oooool2
o`000003ooooool0003o000000[ooooo0_l00007ooooo`;o0000=_ooool001cooooo0_l0000coooo
o`;o00002oooool2o`0000Wooooo0_l00004ooooo`;o00001_ooool2o`0001Cooooo0_l00008oooo
o`Go00001?ooool3o`0000[ooooo0_l00002ooooo`Co00002?ooool4o`0000;ooooo0_l000000ooo
oooo0000o`000009ooooo`Co00002?ooool2o`000003ooooool0003o000000Cooooo0_l00003oooo
oaOo000000?oooooo`000?l000003?ooool3o`0000Cooooo0_l00002ooooo`;o0000B_ooool001co
oooo00?o0000ooooooooool0;?ooool2o`0002?ooooo0_l00005ooooo`;o00000_ooool2o`0000?o
oooo0_l0000;ooooo`;o00001oooool8o`000003ooooool0003o000000Co00000_ooool2o`0000Co
oooo0_l00002ooooo`;o00001_ooool2o`0000Sooooo1Ol00009ooooo`Co00001Oooool3o`0000?o
oooo0_l00004ooooo`;o00001?oooolFo`0000_ooooo0_l00002ooooo`?o00000_ooool2o`0000Co
oooo0_l00004ooooo`;o00002oooool6o`0000Gooooo0_l0000/ooooo`007?ooool00ol0003ooooo
ooooo`0/ooooo`;o00007oooool2o`0000;ooooo0_l00008ooooo`?o00000oooool2o`0000;ooooo
0_l00004ooooo`;o000000Coooooo`000?l0003ooooo1?l000000ooooooo0000o`00000Co`0000_o
oooo0_l00002ooooo`?o00002?ooool2o`0000?ooooo0_l00008ooooo`;o00001Oooool3o`0000So
oooo0_l00005ooooo`;o00000ooooolAo`0000_ooooo0_l00005ooooo`Co00002_ooool2o`0000_o
oooo1_l00005ooooo`;o0000;?ooool001cooooo00?o0000ooooooooool0;oooool2o`0000Kooooo
1?l00003ooooo`;o00003Oooool2o`0000cooooo0_l000000ooooooo0000o`000003o`0000;ooooo
0_l00004ooooo`;o000000Coooooo`000?l0003ooooo1?l000000ooooooo0000o`000002o`000003
ooooool0003o000000ko00000oooool4o`0000Cooooo0_l00003ooooo`;o00001_ooool2o`0000Co
oooo0ol00005ooooo`;o00004oooool2o`0000Wooooo5?l000000ooooooo0000o`00000=ooooo`;o
000000Coooooo`000?l0003ooooo0_l0000Dooooo`;o0000=_ooool001cooooo00?o0000oooooooo
ool0;oooool4o`0000Cooooo1?l000000ooooooo0000o`000002o`0000Cooooo0_l00007ooooo`;o
00001_ooool2o`0000Oooooo1Ol00008ooooo`;o00002?ooool3o`0000Cooooo2Ol00003ooooo`?o
00000oooool4o`0000Cooooo0_l00008ooooo`;o000000Coooooo`000?l0003o00000oooool3o`00
00Cooooo0ol00004ooooo`;o00004oooool2o`0000?ooooo2Ol000000ooooooo0000o`00000;o`00
00;ooooo0_l0000<ooooo`Oo00002Oooool3o`0003kooooo000Looooo`03o`000?oooooooooo02_o
oooo1?l000001?oooooo0000o`000?l00009ooooo`?o00001Oooool2o`0000oooooo0_l0000?oooo
o`;o00003?ooool5o`0000;ooooo0ol000000ooooooo0000o`000003o`0000Gooooo0ol00008oooo
o`Ko000000?oooooo`000?l000000oooool2o`0000;ooooo0_l000000ooooooo0000o`000003o`00
00Cooooo0_l00005ooooo`;o00003Oooool3o`0000?ooooo0_l00003ooooo`;o000000?oooooo`00
0?l000002Ol00004ooooo`Go00000_ooool2o`0000Kooooo0ol00003ooooo`?o00000_ooool2o`00
00Oooooo1Ol0000nooooo`007?ooool00ol0003oooooooooo`0Yooooo`Ko000000Coooooo`000?l0
003ooooo0_l00003ooooo`;o00001oooool2o`0000Oooooo0_l00009ooooo`;o00002?ooool2o`00
0004ooooool0003o0000ooooo`?o00001?ooool2o`000004ooooool0003o0000ooooo`Co000000?o
ooooo`000?l000001Ol00004ooooo`;o00000_ooool6o`0000?ooooo2ol000000ooooooo0000o`00
000:ooooo`Co00002Oooool2o`00013ooooo0ol0000<ooooo`[o00001?ooool4o`0000Cooooo0_l0
0005ooooo`Co00002?ooool2o`0000Kooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0Y
ooooo`;o00002?ooool2o`0000?ooooo0_l00007ooooo`;o00001oooool2o`0000cooooo1_l00000
0ooooooo0000o`000003o`000003ooooool0003o000000;o000000?oooooo`000?l000001Ol00000
0ooooooo0000o`000009o`000004ooooool0003o0000o`0000;ooooo2Ol00003ooooo`Go00005Ooo
ool2o`0000Wooooo0_l0000@ooooo`;o00000_ooool2o`0000?ooooo0ol00003ooooo`[o000000?o
ooooo`000?l000000oooool3o`0000?ooooo0_l00007ooooo`;o00002?ooool4o`0004Oooooo000L
ooooo`03o`000?oooooooooo02kooooo0_l0000:ooooo`;o00007?ooool6o`0000;ooooo1?l00000
0ooooooo0000o`000002o`000003ooooool0003o000000Go000000?oooooo`000?l000007?l00000
1?oooooo0000o`000?l0000=ooooo`;o00001oooool2o`0000[ooooo0_l00009ooooo`;o00000ooo
ool2o`0000;ooooo0_l00003ooooo`Go000000Coooooo`000?l0003o00000_ooool8o`0000Cooooo
0_l0000Hooooo`;o00001Oooool2o`0000kooooo0_l00003ooooo`;o0000:oooool001cooooo00?o
0000ooooooooool0:oooool2o`000003ooooool0003o000000;ooooo0_l00006ooooo`;o00004_oo
ool2o`0000cooooo1Ol000001?oooooo0000o`000?ooool2o`0000;ooooo0ol000000ooooooo0000
o`000002o`0000Cooooo7_l0000>ooooo`;o00000_ooool2o`0000?ooooo0_l0000:ooooo`;o0000
2Oooool2o`0000?ooooo0_l00007ooooo`;o000000?oooooo`000?l000000_l00009ooooo`?o0000
1?ooool2o`0001oooooo0_l00004ooooo`;o00002?ooool2o`0000?ooooo0_l0000[ooooo`007?oo
ool00ol0003oooooooooo`0[ooooo`;o00001Oooool4o`0001Sooooo0_l00007ooooo`;o00001Ooo
ool3o`000004ooooool0003o0000o`0000;ooooo2_l000000ooooooo0000o`00000=o`000003oooo
ool0003o000000Oo00000oooool5o`0000[ooooo0_l00006ooooo`;o00000oooool2o`0000gooooo
0ol0000?ooooo`;o00000_ooool4o`000004ooooool0003o0000ooooo`;o00001Oooool4o`0000[o
oooo0_l0000Dooooo`;o00001Oooool2o`0000;ooooo0_l0000jooooo`007?ooool00ol0003ooooo
ooooo`0Yooooo`;o00001Oooool2o`000004ooooool0003o0000o`0000[ooooo0_l0000Eooooo`;o
00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool3o`000003
ooooool0003o000001_o00001_ooool2o`0000Wooooo0_l00004ooooo`;o00003Oooool3o`0000?o
oooo1?l0000?ooooo`;o00000_ooool5o`000003ooooool0003o000000Co00000oooool4o`0000Oo
oooo0_l000000ooooooo0000o`000002ooooo`;o00004?ooool3o`0000Cooooo0_l00006ooooo`;o
0000=_ooool001cooooo00?o0000ooooooooool0:Oooool2o`0000Gooooo0_l000000ooooooo0000
o`000009ooooo`Ko00006?ooool2o`0000;ooooo0ol00009ooooo`;o000000?oooooo`000?l00000
0_l000000ooooooo0000o`00000Jo`0000;ooooo0_l0000?ooooo`;o00003Oooool3o`000003oooo
ool0003o000000;o00005?ooool3o`000004ooooool0003o0000ooooo`;o00000_ooool2o`000005
ooooool0003o0000o`000?ooool00_l00003ooooo`;o00000_ooool2o`0000?ooooo1?l00002oooo
o`;o00003Oooool2o`0000cooooo0_l0000Cooooo`;o00008Oooool001cooooo00?o0000oooooooo
ool0<?ooool2o`0000cooooo0_l000001?oooooo0000o`000?l00006ooooo`;o00005Oooool2o`00
00Oooooo9_l00002ooooo`;o00008?ooool4o`0000;ooooo0_l00003ooooo`;o00001Oooool2o`00
00;ooooo0ol000001?oooooo0000o`000?l00007ooooo`;o00000_ooool3o`0000;ooooo0_l00000
1?oooooo0000o`000?l00006ooooo`Go00000_ooool4o`0000?ooooo0_l00002ooooo`Co00008ooo
ool2o`00027ooooo000Looooo`03o`000?oooooooooo02oooooo0ol0000?ooooo`;o00001oooool2
o`0001Gooooo0_l00007ooooo`;o000000?oooooo`000?l000009Ol0000Pooooo`;o00000oooool5
o`000003ooooool0003o000000Gooooo0_l00002ooooo`?o00001oooool2o`0000;ooooo0_l00007
ooooo`;o000000?oooooo`000?l000001oooool2o`0000Oooooo0_l00002ooooo`?o00000_ooool4
o`0004Kooooo000Looooo`03o`000?oooooooooo02oooooo0_l0000?ooooo`;o000000?oooooo`00
0?l000002oooool2o`0000oooooo0_l0000:ooooobOo000000?oooooo`000?l000005?ooool2o`00
00Wooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000_ooooo0_l00000
0ooooooo0000o`000003ooooo`;o00003oooool2o`0000gooooo0_l00004ooooo`;o00009?ooool2
o`0002Oooooo000Looooo`;o0000@?ooool3o`000003ooooool0003o000000_ooooo0_l0000>oooo
o`;o00001?ooool2o`000003ooooool0003o000001go000000?oooooo`000?l000003?l000000ooo
oooo0000o`00000Aooooo`;o00002Oooool2o`0000Oooooo0_l0000;ooooo`;o000000?oooooo`00
0?l000003_ooool3o`0000?ooooo0_l0000=ooooo`;o00000_ooool2o`0000Gooooo0_l00006oooo
o`;o00005oooool2o`0002Oooooo000Looooo`03o`000?oooooooooo03cooooo0_l000000ooooooo
0000o`00000?ooooo`?o00000_ooool2o`0000Wooooo1Ol000000ooooooo0000o`00000Go`000003
ooooool0003o0000013o00000_ooool2o`0000;ooooo0_l0000Qooooo`;o000000?oooooo`000?l0
00000_ooool2o`000003ooooool0003o000000Wooooo0_l00002ooooo`;o000000?oooooo`000?l0
00001_ooool4o`0001Gooooo0_l00004ooooo`?o00001_ooool2o`00043ooooo000Looooo`03o`00
0?oooooooooo02oooooo0_l00004ooooo`;o00001Oooool2o`000003ooooool0003o000000Gooooo
0_l00009ooooo`?o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00002ooooo`Co0000
0ooooolFo`0000?ooooo3ol000000ooooooo0000o`00000Hooooo`Ko00002_ooool2o`000003oooo
ool0003o000000;ooooo1Ol00006ooooo`Go00000_ooool2o`000003ooooool0003o000000Sooooo
0_l0000Hooooo`;o000000?oooooo`000?l000001Oooool2o`0004;ooooo000Looooo`03o`000?oo
oooooooo02kooooo0ol00004ooooo`;o000000?oooooo`000?l000001_ooool2o`0000;ooooo1?l0
000:ooooo`;o00001Oooool6o`0000Cooooo1_l00002ooooo`Go000000?oooooo`000?l000005_l0
00000ooooooo0000o`000004o`000005ooooool0003o0000o`000?ooool01Ol000000ooooooo0000
o`00000>ooooo`Ko00004oooool2o`0000Oooooo1?l0000;ooooo`;o00007Oooool2o`000003oooo
ool0003o000000Gooooo0_l00006ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0;?oo
ool4o`0000Sooooo0_l00006ooooo`;o00000_ooool2o`0000gooooo0_l000000ooooooo0000o`00
0003ooooo`;o00000oooool2o`0000?ooooo2?l000000ooooooo0000o`00000To`000003ooooool0
003o000000?o000000?oooooo`000?l000005?ooool2o`0000?ooooo0_l00009ooooo`;o00001ooo
ool2o`00013ooooo0_l00006ooooo`;o00006?ooool2o`0000gooooo0_l00006ooooo`?o0000<Ooo
ool001cooooo00?o0000ooooooooool0;?ooool2o`0002Gooooo0_l000000ooooooo0000o`000005
ooooo`Go00001?ooool6o`000003ooooool0003o000000_o00000ooooolHo`000003ooooool0003o
000001?ooooo0_l00004ooooo`;o00000oooool4o`0000;ooooo0_l00003ooooo`;o00000oooool2
o`0000;ooooo1?l00002ooooo`Co00004?ooool2o`00013ooooo1?l00006ooooo`;o00002_ooool2
o`0000Oooooo0ol0000aooooo`007?ooool00ol0003oooooooooo`0/ooooo`?o00002Oooool2o`00
01Sooooo0_l00009ooooo`?o00001_ooool3o`000003ooooool0003o000000go00000_oooolJo`00
0003ooooool0003o000000Co000000?oooooo`000?l000003?ooool2o`0000Sooooo0_l000001Ooo
oooo0000o`000?l0003ooooo00;o00000oooool2o`0000?ooooo0_l00004ooooo`;o000000?ooooo
o`000?l000000ol00003ooooo`;o00000_ooool2o`0001Wooooo1?l00006ooooo`;o00002_ooool2
o`0003_ooooo000Looooo`03o`000?oooooooooo02gooooo0_l00009ooooo`;o00006?ooool2o`00
00[ooooo0_l00003ooooo`?o00001Oooool<o`0000;ooooo5ol000000ooooooo0000o`000009o`00
0003ooooool0003o000001Kooooo0_l00002ooooo`;o00001_ooool2o`0000cooooo0ol00005oooo
o`;o00000_ooool2o`0001Oooooo1_l0000?ooooo`;o00003Oooool2o`0002oooooo000Looooo`03
o`000?oooooooooo053ooooo0_l0000<ooooo`;o00000oooool6o`0000;ooooo;Ol00005ooooo`;o
00001?ooool2o`0000Kooooo0_l00002ooooo`;o00007Oooool3o`0000Oooooo1?l0000Hooooo`;o
00004oooool4o`000003ooooool0003o000000Sooooo0_l0000_ooooo`007?ooool00ol0003ooooo
ooooo`1;ooooo`;o00000oooool2o`0000cooooo0_l00004ooooo`So000000?oooooo`000?l00000
5ol000000ooooooo0000o`00000<o`000003ooooool0003o000000_ooooo0_l000000ooooooo0000
o`000003ooooo`;o00000_ooool2o`0000;ooooo1?l00009ooooo`;o00003?ooool3o`0000Oooooo
1?l0000Hooooo`;o000000?oooooo`000?l000002?ooool2o`0000Kooooo1?l000000ooooooo0000
o`000006ooooo`;o0000<Oooool001cooooo00?o0000ooooooooool0>oooool2o`000003ooooool0
003o000000_ooooo0_l00003ooooo`;o00003?ooool2o`0000Gooooo3Ol000000ooooooo0000o`00
000Po`0000?ooooo0_l00007ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_oo
ool4o`0000Oooooo1?l0000=ooooo`;o00004Oooool2o`0000Oooooo1Ol00004ooooo`Go00000ooo
ool2o`0000?ooooo0_l00004ooooo`Ko00002Oooool2o`00037ooooo000Looooo`03o`000?oooooo
oooo03_ooooo0_l000000ooooooo0000o`00000@ooooo`;o00001_ooool2o`0000gooooo0_l00000
0ooooooo0000o`00000Fo`000003ooooool0003o0000017o00000_ooool2o`0000Oooooo0_l00007
ooooo`Co000000?oooooo`000?l000003?ooool3o`0001Oooooo0_l00005ooooo`;o000000Cooooo
o`000?l0003o00001oooool5o`000004ooooool0003o0000ooooo`?o00001Oooool2o`0000Wooooo
0_l00002ooooo`;o0000??ooool001cooooo00?o0000ooooooooool0:Oooool2o`00013ooooo0_l0
000Cooooo`;o00001_ooool3o`0000cooooo8ol000000ooooooo0000o`000005o`000004ooooool0
003o0000o`0000;ooooo0_l0000Aooooo`?o00001_ooool2o`0000Oooooo0ol0000Gooooo`;o0000
1Oooool2o`000004ooooool0003o0000o`0000Oooooo0_l00004ooooo`;o000000?oooooo`000?l0
00000_l000000ooooooo0000o`000004ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0
:Oooool2o`0000Kooooo0_l00008ooooo`;o00003oooool2o`0000_ooooo0_l000001?oooooo0000
o`000?ooool4o`000003ooooool0003o000000;ooooo0ol000000ooooooo0000o`00000Jo`000003
ooooool0003o000000Oo000000Coooooo`000?l0003o00000oooool4o`0000?ooooo0_l00007oooo
o`;o00000_ooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000005oooo
o`;o00000oooool2o`0000?ooooo0ol00003ooooo`;o00001_ooool2o`0000gooooo0_l0000?oooo
o`;o000000?oooooo`000?l000000_l00002ooooo`;o00001?ooool2o`0000Kooooo0_l00003oooo
o`;o0000=Oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo037ooooo0ol0000@ooooo`?o00001Ooo
ool2o`0000kooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000;ooooo1?l0
00000ooooooo0000o`00000So`0000Gooooo1_l00003ooooo`Co00001Oooool2o`000005ooooool0
003o0000o`000?ooool00_l00004ooooo`?o000000Coooooo`000?l0003o00001_ooool2o`0000;o
oooo1?l00003ooooo`;o00001_ooool2o`0000gooooo0_l00009ooooo`Go00001_ooool2o`0000So
oooo0_l00006ooooo`;o00000oooool2o`0003Gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMg
M`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0U
ooooo`;o00002oooool2o`0000Cooooo1?l00008ooooo`?o00005_ooool2o`0000Cooooo0ol00002
ooooo`Co000000?oooooo`000?l000008_l00006ooooo`;o00002?ooool3o`0000Kooooo1Ol00003
ooooo`;o00000_ooool2o`0000;ooooo1Ol00008ooooo`;o00001Oooool2o`0000Sooooo0_l00003
ooooo`;o00004?ooool6o`0000gooooo0_l00002ooooo`;o00003?ooool2o`0003?ooooo00000ooo
oooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo02Gooooo0_l0000@ooooo`Go00002?ooool2o`0000Kooooo0_l00006
ooooo`;o00001oooool2o`0000Cooooo0ol00002ooooo`;o00001?oooolTo`0000oooooo0_l00002
ooooo`;o00000oooool3o`0000?ooooo4Ol00009ooooo`?o000000?oooooo`000?l000002?ooool3
o`0000;ooooo0_l00005ooooo`;o00002Oooool2o`0000;ooooo1?l0000;ooooo`;o00000_ooool2
o`0000Cooooo0_l00006ooooo`?o0000<_ooool00003ooooool0003ooooo00;ooooo00?o0000oooo
ooooool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0000fooooo`?o00003_ooool2
o`0000?ooooo1?l00004ooooo`;o00001Oooool3o`0000Kooooo0_l000000ooooooo0000o`000002
ooooobOo000000Coooooo`000?l0003ooooo1Ol0000:ooooo`;o00002?ooool;o`000005ooooool0
003o0000o`000?ooool00_l00008ooooo`Co00000oooool2o`000004ooooool0003o0000o`0000?o
oooo0_l00009ooooo`;o00003Oooool4o`0000;ooooo0_l00007ooooo`;o00002?ooool2o`0000Oo
oooo0_l0000booooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`00
0?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0Zooooo`;o00002_ooool4o`0000;o
oooo0_l00009ooooo`;o00001?ooool4o`0000?ooooo0_l00005ooooo`?o00002Ooooolfo`0000Oo
oooo0_l00007ooooo`Co000000?oooooo`000?l000003ol00002ooooo`;o00000_ooool2o`0000Go
oooo1_l0000>ooooo`;o00003oooool2o`0000;ooooo0ol0000Gooooo`;o0000=?ooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`00
0?oooooooooo02[ooooo0_l0000;ooooo`?o00000_ooool2o`0000oooooo1?l00003ooooo`;o0000
1oooool2o`0000[ooooo2ol00002oooooago000000?oooooo`000?l000000_l00003ooooo`;o0000
1_ooool3o`0000Gooooo6Ol000000ooooooo0000o`000003o`0000Sooooo0ol0000<ooooo`;o0000
5oooool2o`0000Wooooo0_l0000<ooooo`;o0000=?ooool00006oooooomgMgOoV9RHoooooonHV9So
MgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo03[ooooo0_l0000=ooooo`;o
00004_ooool2o`0000;ooooo1?l00005ooooo`Ko000000?oooooo`000?l000006_l000000ooooooo
0000o`000003o`0000?ooooo0_l00003ooooo`;o00001_ooool2o`0000Kooooo0ol00002ooooo`Ko
000000?oooooo`000?l000002ol000000ooooooo0000o`000005o`0000?ooooo0_l0000:ooooo`;o
00000_ooool4o`0000;ooooo0_l0000Booooo`Co00000_ooool2o`0000Cooooo0_l0000>ooooo`;o
0000<_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106
ooooo`03o`000?oooooooooo03Kooooo0_l00002ooooo`?o00003?ooool2o`0000Kooooo0_l0000>
ooooo`Ko00001?ooool>o`000003ooooool0003o000001;o00002?ooool2o`0000?ooooo1?l00007
ooooo`?o000000Coooooo`000?l0003o00000_oooolHo`000003ooooool0003o000000;o00000ooo
ool2o`0000[ooooo0_l00002ooooo`?o00000oooool3o`0000_ooooo0_l00004ooooo`Co00000_oo
ool4o`0000;ooooo0_l0000>ooooo`;o0000<_ooool001cooooo00?o0000ooooooooool0=_ooool2
o`0000?ooooo0_l00005ooooo`;o00003Oooool2o`000004ooooool0003o0000ooooo`Co00002_oo
ool2o`0000?ooooo2Ol00003ooooo`?o000000Coooooo`000?l0003ooooo3_l000000ooooooo0000
o`000002o`0000;ooooo2?l000000ooooooo0000o`000002o`0000Oooooo0ol000000ooooooo0000
o`000003ooooo`oo000000?oooooo`000?l000001Ol00002ooooo`;o00001oooool2o`0000Wooooo
1_l00004ooooo`;o00002oooool2o`0000cooooo0_l00009ooooo`;o0000>oooool001cooooo00?o
0000ooooooooool0=_ooool2o`0000[ooooo0_l00005ooooo`;o00000_ooool2o`0000Gooooo0_l0
00000ooooooo0000o`000002o`0000oooooo1_l00005ooooo`Co000000Coooooo`000?l0003ooooo
2Ol000000ooooooo0000o`000007o`0000;ooooo2Ol000000ooooooo0000o`000007ooooo`Co0000
0_ooool2o`000003ooooool0003o000000ko000000?oooooo`000?l000001Ol0000;ooooo`;o0000
2Oooool5o`0000Sooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00006_ooool2o`0003_o
oooo000Looooo`03o`000?oooooooooo03Kooooo0_l00009ooooo`;o00001_ooool2o`0000;ooooo
0ol0000@ooooo`;o00000_ooool2o`0000Kooooo0_l00002ooooo`;o00000oooool5o`000004oooo
ool0003o0000ooooo`_o00000_ooool=o`000004ooooool0003o0000ooooo`;o00001oooool2o`00
00Cooooo7Ol0000=ooooo`;o00000oooool2o`0000gooooo0_l000000ooooooo0000o`000004o`00
00Kooooo0_l0000Looooo`;o0000<Oooool001cooooo00?o0000ooooooooool0@Oooool2o`0000_o
oooo0_l00002ooooo`;o00002?ooool2o`0000;ooooo0_l00002ooooo`;o00002_ooool4o`000003
ooooool0003o000000Oo000000Goooooo`000?l0003o0000ooooo`07o`0000;ooooo1ol000000ooo
oooo0000o`000003ooooo`;o000000?oooooo`000?l000003?oooolNo`0000;ooooo0_l00009oooo
o`;o00000oooool2o`00013ooooo1?l00007ooooo`?o00000_ooool2o`0001Sooooo0_l0000aoooo
o`007?ooool00ol0003oooooooooo`13ooooo`;o00003Oooool2o`0000Sooooo0_l0000Dooooo`;o
000000?oooooo`000?l000000_l000000ooooooo0000o`00000:o`0000;ooooo0ol00002ooooo`?o
000000?oooooo`000?l000001Oooool4o`0000Wooooo0_l00003ooooo`ko000000?oooooo`000?l0
00004Ol00005ooooo`Co00005oooool2o`0000;ooooo1?l00003ooooo`;o00000oooool2o`0004_o
oooo000Looooo`03o`000?oooooooooo04?ooooo0_l00003ooooo`;o000000?oooooo`000?l00000
5?ooool2o`000003ooooool0003o000000gooooo0_l000000ooooooo0000o`000004ooooo`Co0000
00Coooooo`000?l0003ooooo0_l00003ooooo`Go00001?ooool4o`0000;ooooo1?l00005ooooo`;o
00000_ooool2o`0000;ooooo8Ol00007ooooo`Co00006oooool4o`0000?ooooo0_l0000Dooooo`;o
000000?oooooo`000?l00000=oooool001cooooo00?o0000ooooooooool0@oooool2o`0000?ooooo
0_l000000ooooooo0000o`000002o`0000cooooo0_l00004ooooo`;o000000?oooooo`000?l00000
0_ooool2o`000003ooooool0003o000000Gooooo0ol000000ooooooo0000o`000004ooooo`?o0000
0_ooool2o`0000Kooooo1Ol00004ooooo`Co000000Coooooo`000?l0003o00000oooool2o`0000;o
oooo0_l00006ooooo`Go000000?oooooo`000?l000006?l00009ooooo`;o00000_ooool2o`0003Go
oooo0_l000000ooooooo0000o`00000gooooo`007?ooool00ol0003oooooooooo`17ooooo`;o0000
1?ooool2o`0000cooooo0_l0000;ooooo`Oo00000oooool2o`0000;ooooo0_l00004ooooo`?o0000
0_ooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o0000
0oooool3o`0000?ooooo0_l0000:ooooo`Co00000_oooolDo`0000;ooooo1?l00005ooooo`;o0000
0_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000<ooooo`;o00000oooool2o`000003oooo
ool0003o000001oooooo0_l0000gooooo`007?ooool00ol0003oooooooooo`17ooooo`;o00002ooo
ool2o`0000Kooooo0_l0000<ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Kooooo0_l0
0003ooooo`Ko00000_ooool2o`0000?ooooo0ol000000ooooooo0000o`000004ooooo`;o00003ooo
oolPo`0000Gooooo0_l00008ooooo`?o00001?ooool2o`0000Kooooo0_l00003ooooo`;o000000?o
ooooo`000?l000007_ooool3o`0003Oooooo000Looooo`03o`000?oooooooooo04_ooooo0_l00000
0ooooooo0000o`000002o`0000;ooooo0_l00006ooooo`;o00005_ooool2o`0000Kooooo0ol00004
ooooo`;o00000oooool2o`0000;ooooo1Ol00009ooooo`;o00002?ooool2o`0000;ooooo0_l00002
ooooo`Oo000000?oooooo`000?l000005?l0000>ooooo`?o00001?ooool2o`000003ooooool0003o
000001Gooooo0_l00009ooooo`;o00002Oooool2o`0003Sooooo000Looooo`03o`000?oooooooooo
04Gooooo0_l00003ooooo`?o000000?oooooo`000?l000000_l0000Yooooo`Co000000?oooooo`00
0?l000001Oooool3o`0000;ooooo1_l00008ooooo`;o00001oooool7o`0000?ooooo7_l00004oooo
o`;o00001Oooool2o`0000;ooooo0_l00006ooooo`;o00005Oooool2o`0000Wooooo0_l00013oooo
o`007?ooool2o`0004Kooooo0ol00002ooooo`;o00001Oooool2o`0000?ooooo0_l0000Pooooo`;o
000000?oooooo`000?l000000oooool2o`0000Gooooo0_l00002ooooo`Co000000?oooooo`000?l0
00004Oooool2o`000003ooooool0003o000000;o00000oooool7o`000003ooooool0003o000001Co
00001?ooool2o`0000Gooooo0_l00002ooooo`;o00006oooool2o`00053ooooo000Looooo`03o`00
0?oooooooooo04Cooooo1?l00009ooooo`;o00000oooool2o`0000Sooooo0_l0000>ooooo`;o0000
1_ooool2o`0000Wooooo0_l00002ooooo`;o00000_ooool4o`0000Cooooo0_l00007ooooo`;o0000
3ooooolLo`0002kooooo0_l00004ooooo`;o00002?ooool2o`00043ooooo000Looooo`03o`000?oo
oooooooo04Cooooo0_l0000=ooooo`;o00000_ooool2o`0000Gooooo1?l0000<ooooo`Co000000?o
ooooo`000?l000001Oooool2o`0000Kooooo0ol00002ooooo`;o00002_ooool2o`0000Cooooo0_l0
00000ooooooo0000o`00000>oooooa?o000000?oooooo`000?l000001ol0000Wooooo`;o00002ooo
ool2o`0000Sooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o00000oooool9
o`0000Gooooo0_l0000>ooooo`?o00000_ooool5o`0000;ooooo0_l00006ooooo`;o00005Oooool2
o`0000Wooooo0ol00003oooooaWo000000Coooooo`000?l0003ooooo0_l00006ooooo`;o00004ooo
ool2o`0000Cooooo0_l00004ooooo`;o0000Eoooool001cooooo00?o0000ooooooooool0AOooool2
o`0000Cooooo0_l00003ooooo`?o00000_ooool2o`0000gooooo0_l00009ooooo`;o00000_ooool9
o`0000Kooooo0_l00006ooooo`;o00001_ooool2o`00013ooooo0ol00003ooooo`?o00000ooooolH
o`0000;ooooo0_l00003ooooo`;o00004oooool8o`0005gooooo000Looooo`03o`000?oooooooooo
04Gooooo0_l00005ooooo`;o00005_ooool2o`0000gooooo0_l00003ooooo`Co00001_ooool2o`00
0003ooooool0003o000000;o000000?oooooo`000?l000000_l00004ooooo`;o00004_ooool3o`00
0005ooooool0003o0000o`000?ooool00_l000000ooooooo0000o`00000Eo`0000;ooooo0_l0000J
ooooo`Co00001?ooool2o`0000Gooooo0_l00008ooooo`;o0000B?ooool001cooooo00?o0000oooo
ooooool0C?ooool2o`00027ooooo0_l0000Dooooo`Ko000000?oooooo`000?l000002?ooool2o`00
00Wooooo0_l00003ooooo`?o00001OoooolIo`000003ooooool0003o000001gooooo0_l00003oooo
o`Co00001Oooool3o`0000Oooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o
00000_ooool2o`0000;ooooo1?l00007ooooo`Co00002_ooool2o`0000Kooooo0_l00002ooooo`;o
00002Oooool2o`000003ooooool0003o000000_ooooo0_l00009ooooo`;o00003?ooool3o`000003
ooooool0003o000001Go00004_ooool3o`0000Oooooo0ol00003ooooo`Co00001_ooool2o`00057o
oooo000Looooo`03o`000?oooooooooo04Kooooo0_l00005ooooo`Co000000?oooooo`000?l00000
0_ooool4o`0000Oooooo1?l0000<ooooo`;o00000_ooool4o`0000;ooooo0_l00002ooooo`;o0000
1Oooool2o`0000Cooooo0_l000000ooooooo0000o`00000Dooooo`;o00001_ooool2o`0000;ooooo
6Ol0000Booooo`?o00001_ooool3o`0000Kooooo0_l00003ooooo`;o0000E?ooool001cooooo00?o
0000ooooooooool0A_ooool2o`0000Gooooo1?l0000Hooooo`;o00001_ooool2o`0000;ooooo1?l0
0003ooooo`;o000000?oooooo`000?l000002oooool2o`000003ooooool0003o000000Kooooo0_l0
000<ooooo`?o00001Oooool2o`0000;ooooo7?l000000ooooooo0000o`00000@ooooo`;o000000?o
ooooo`000?l000000_l0000<ooooo`Co0000D_ooool001cooooo00?o0000ooooooooool0EOooool2
o`0001;ooooo0_l00009ooooo`Co00001?ooool2o`0000?ooooo0_l0000Dooooo`;o000000?ooooo
o`000?l000000_ooool2o`0000;ooooo1_l00008ooooo`Co000000?oooooo`000?l000000ooooolC
o`000003ooooool0003o000000[ooooo0ol00003ooooo`Go00002?ooool2o`000003ooooool0003o
000000?ooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`1Aooooo`;o00000_ooool2o`00
00Kooooo0_l0000Dooooo`?o00000oooool2o`000003ooooool0003o000000?ooooo0_l0000Goooo
o`;o00000_ooool8o`0000Sooooo1?l00003ooooo`;o000000Coooooo`000?l0003ooooo2Ol00000
0ooooooo0000o`000004ooooo`;o00001Oooool2o`000003ooooool0003o000000?ooooo0ol00003
ooooo`Co000000?oooooo`000?l000001_ooool5o`0000Sooooo0_l0001=ooooo`007?ooool00ol0
003oooooooooo`1;ooooo`;o00001?ooool2o`0000Gooooo0_l00003ooooo`;o00005?ooool4o`00
00;ooooo0_l00006ooooo`;o00001Oooool2o`0001Kooooo0_l0000<ooooo`;o00000_ooool2o`00
00?ooooo0ol000000ooooooo0000o`000002o`000003ooooool0003o000000;o00000_ooool2o`00
00;ooooo0_l00006ooooo`Go00001?ooool2o`000003ooooool0003o000000;o00000_ooool3o`00
00Oooooo0_l00007ooooo`;o000000?oooooo`000?l00000COooool001cooooo00?o0000oooooooo
ool0Boooool2o`0000Cooooo0_l00005ooooo`;o00001?ooool2o`000003ooooool0003o000001;o
oooo0_l0000Aooooo`;o00001Oooool2o`00027ooooo0_l00003ooooo`;o00000_ooool3o`0000Go
oooo1Ol00002ooooo`;o00001Oooool2o`000003ooooool0003o000000Gooooo0_l000000ooooooo
0000o`000004ooooo`;o00000_ooool2o`0000Cooooo0_l00007ooooo`Co0000C_ooool001cooooo
00?o0000ooooooooool0C_ooool2o`000003ooooool0003o000000_ooooo1Ol0000:ooooo`;o0000
2?ooool2o`0000Wooooo0_l00002ooooo`?o00001_ooool2o`0001cooooo0_l0000=ooooo`Ko0000
00Coooooo`000?l0003o00002?ooool2o`000003ooooool0003o0000017ooooo0_l00002ooooo`;o
00001?ooool3o`0000?ooooo0_l00003ooooo`;o00001oooool2o`0004Gooooo000Looooo`03o`00
0?oooooooooo04kooooo0_l000000ooooooo0000o`00000<ooooo`?o00002oooool2o`0000Sooooo
0_l00003ooooo`;o00000_ooool4o`0000;ooooo0ol0000Jooooo`;o00000_ooool2o`0000Cooooo
0_l00004ooooo`;o00001oooool6o`000003ooooool0003o000000Kooooo0_l000000ooooooo0000
o`000006ooooo`?o00001?ooool2o`0000Gooooo0_l00004ooooo`;o00000oooool2o`0000?ooooo
0_l0000<ooooo`;o0000AOooool001cooooo0_l0001Qooooo`;o00004Oooool2o`0000Oooooo0_l0
0002ooooo`;o00001?ooool2o`0000cooooo0_l0000=ooooo`;o00000_ooool2o`0000;ooooo0_l0
0006ooooo`;o00002Oooool3o`0000;ooooo0ol000000ooooooo0000o`000002ooooo`;o00001?oo
ool2o`0000?ooooo1?l00003ooooo`;o00000oooool2o`000003ooooool0003o000000;o000000?o
ooooo`000?l000000oooool2o`0000kooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`1;
ooooo`;o00001?ooool2o`0000Sooooo0ol00008ooooo`;o00002oooool4o`0000oooooo0_l00009
ooooo`;o000000?oooooo`000?l000004Oooool2o`0000;ooooo0_l0000:ooooo`;o00001Oooool2
o`0000?ooooo0ol000000ooooooo0000o`000002ooooo`;o00000_ooool4o`0000Gooooo0_l00008
ooooo`;o000000?oooooo`000?l000000_l0000Fooooo`;o0000B?ooool001cooooo00?o0000oooo
ooooool0@?ooool2o`0000Wooooo0_l00004ooooo`;o000000?oooooo`000?l000001Oooool3o`00
00Sooooo1?l0000;ooooo`;o00003oooool2o`0000?ooooo0_l00004ooooo`;o00005?ooool2o`00
00kooooo0_l000000ooooooo0000o`000002ooooo`;o00002oooool3o`000003ooooool0003o0000
02;ooooo0_l00008ooooo`Co0000B?ooool001cooooo00?o0000ooooooooool0@?ooool2o`0000[o
oooo0_l00006ooooo`Co00000_ooool4o`0000Wooooo1?l0000Hooooo`;o00001Oooool3o`00023o
oooo0_l00004ooooo`;o00001Oooool2o`0000;ooooo0_l00003ooooo`;o00001oooool2o`0002Go
oooo0_l000000ooooooo0000o`000005ooooo`Co0000B?ooool001cooooo00?o0000ooooooooool0
C?ooool2o`0000Sooooo0_l00002ooooo`Co00002oooool2o`0001Cooooo0_l00002ooooo`;o0000
1Oooool2o`0000Oooooo0_l00006ooooo`;o00004?ooool2o`0000;ooooo1?l00009ooooo`;o0000
0oooool2o`0000Gooooo0_l0000>ooooo`;o00006_ooool2o`0000Gooooo0_l0001:ooooo`007?oo
ool00ol0003oooooooooo`1Eooooo`;o00008?ooool2o`0000Kooooo0_l0000Booooo`;o00001_oo
ool2o`0001Cooooo0_l00004ooooo`;o00001Oooool2o`0000[ooooo0_l00003ooooo`?o00001?oo
ool2o`0000;ooooo0_l00008ooooo`;o00001Oooool2o`0000?ooooo1?l0001Eooooo`007?ooool0
0ol0003oooooooooo`1;ooooo`;o00002?ooool2o`0000_ooooo0_l0000<ooooo`;o00001Oooool2
o`0003[ooooo0_l00002ooooo`;o00001Oooool2o`000003ooooool0003o000000cooooo0ol00004
ooooo`;o00002Oooool2o`000003ooooool0003o000000Gooooo0_l00003ooooo`Co00000oooool2
o`00053ooooo000Looooo`03o`000?oooooooooo04_ooooo1?l00004ooooo`Co00002oooool2o`00
00cooooo0_l0000:ooooo`;o00006oooool4o`00017ooooo0_l00003ooooo`;o00002?ooool2o`00
00;ooooo0_l0000Aooooo`;o00001_ooool3o`0000;ooooo1?l00002ooooo`;o00003_ooool4o`00
04kooooo000Looooo`03o`000?oooooooooo04gooooo0_l00004ooooo`Co00005Oooool2o`0000Co
oooo0_l00008ooooo`;o00001?ooool2o`0001Gooooo1?l0000Aooooo`;o00000oooool2o`0000;o
oooo0_l00004ooooo`;o00005Oooool2o`0000Kooooo0ol00004ooooo`;o00000_ooool2o`00013o
oooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o00001?ooool2o`0000Oooooo
0_l00003ooooo`;o00001?ooool2o`0000Kooooo0_l00006ooooo`;o0000;oooool2o`0000;ooooo
0_l00006ooooo`;o00001oooool2o`0000;ooooo0_l00004ooooo`;o00000_ooool2o`0000Wooooo
0ol00004ooooo`;o00002_ooool2o`0005?ooooo000Looooo`03o`000?oooooooooo053ooooo0_l0
0004ooooo`Co00001?ooool2o`0000Oooooo0_l0000Aooooo`;o00003Oooool2o`0000cooooo0_l0
000Jooooo`;o00002Oooool3o`0000Gooooo1Ol000000ooooooo0000o`000003ooooo`?o00000_oo
ool2o`0000Oooooo1Ol00004ooooo`?o00002Oooool2o`0005?ooooo000Looooo`03o`000?oooooo
oooo053ooooo0_l00004ooooo`Go00001?ooool2o`0000;ooooo0_l0000=ooooo`Co00001oooool2
o`0000?ooooo0_l00005ooooo`;o00002oooool3o`000003ooooool0003o000001oooooo1Ol00002
ooooo`;o00000_ooool5o`0000Kooooo0_l00004ooooo`;o00000oooool2o`000003ooooool0003o
000000Sooooo0_l00003ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0Eoooool4o`00
00Cooooo0_l00002ooooo`Ko00002Oooool4o`0000?ooooo0_l00002ooooo`;o00000oooool2o`00
013ooooo1?l00002ooooo`;o00007oooool4o`0000?ooooo0_l00002ooooo`;o00001?ooool2o`00
00Wooooo0_l00003ooooo`;o00000oooool2o`0000_ooooo0_l0001Iooooo`007?ooool00ol0003o
ooooooooo`1?ooooo`;o00001_ooool4o`0000[ooooo1?l00006ooooo`;o00002?ooool2o`0001Wo
oooo0_l0000Uooooo`;o00003_ooool3o`0000Wooooo0_l00003ooooo`;o00000oooool2o`000003
ooooool0003o000000_ooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`1?ooooo`Co0000
1_ooool2o`0000?ooooo1?l0000=ooooo`;o00005Oooool2o`0000_ooooo0_l00003ooooo`Co0000
6?ooool2o`0000Gooooo0_l0000>ooooo`;o00001_ooool3o`0000Kooooo0_l00006ooooo`;o0000
1_ooool2o`0000?ooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o00001ooo
ool2o`0000;ooooo1?l00002ooooo`?o00002?ooool2o`0001Gooooo0ol0000:ooooo`;o00000ooo
ool4o`0000;ooooo0_l0000Dooooo`;o000000?oooooo`000?l000000_ooool2o`0000gooooo1?l0
0003ooooo`Go00001?ooool2o`0000Cooooo0_l0000:ooooo`;o0000Foooool001cooooo0_l0001B
ooooo`;o00001oooool2o`0000Cooooo0_l00002ooooo`?o00002_ooool4o`000004ooooool0003o
0000ooooo`?o00002oooool2o`0000oooooo0_l00004ooooo`;o00005oooool2o`00017ooooo1?l0
0003ooooo`;o00001oooool2o`0000Cooooo0_l0001Wooooo`007?ooool00ol0003oooooooooo`1A
ooooo`;o00003?ooool2o`0000kooooo1_l000001?oooooo0000o`000?ooool3o`00017ooooo0_l0
0009ooooo`?o0000<_ooool3o`0000Kooooo0_l00008ooooo`;o0000Ioooool001cooooo00?o0000
ooooooooool0Boooool2o`0000kooooo0ol000000ooooooo0000o`00000>ooooo`;o000000?ooooo
o`000?l000001Oooool2o`000003ooooool0003o000000cooooo1Ol0000:ooooo`;o000000?ooooo
o`000?l00000;oooool3o`0000Kooooo0_l00003ooooo`;o00000oooool2o`0006Oooooo000Loooo
o`03o`000?oooooooooo04_ooooo0_l0000>ooooo`?o000000?oooooo`000?l000003Oooool2o`00
00Wooooo0_l000000ooooooo0000o`00000;ooooo`Co00003oooool2o`0001[ooooo0_l0000<oooo
o`;o00004oooool2o`0000Kooooo0_l0001Tooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o
00003?ooool2o`0000;ooooo0_l0000;ooooo`Co00002?ooool2o`000003ooooool0003o000000;o
00002_ooool2o`00017ooooo0_l0000Jooooo`;o00003?ooool2o`0000Sooooo0_l00003ooooo`;o
00001?ooool2o`0000Kooooo0ol0001Sooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o0000
3oooool2o`0000Gooooo0_l00005ooooo`;o00000_ooool2o`000003ooooool0003o000000?ooooo
1ol00002ooooo`;o00002Oooool2o`0000;ooooo0_l00002ooooo`;o00001_ooool2o`0001_ooooo
0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o000000Wooooo0_l00003ooooo`;o0000
3Oooool2o`0006?ooooo000Looooo`03o`000?oooooooooo05kooooo0ol00002ooooo`Co000000?o
ooooo`000?l000001_ooool2o`000003ooooool0003o000000Gooooo0_l00005ooooo`;o00002Ooo
ool2o`0000;ooooo0_l00002ooooo`;o00001?ooool2o`0001gooooo0_l00003ooooo`;o00000_oo
ool2o`000003ooooool0003o000000Cooooo0_l0001looooo`007?ooool00ol0003oooooooooo`1C
ooooo`Co00002?ooool2o`0000;ooooo0_l00003ooooo`;o000000Coooooo`000?l0003o00002?oo
ool2o`0001Kooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l0000@ooooo`;o0000
7Oooool2o`0000Kooooo1?l0001booooo`007?ooool00ol0003oooooooooo`1Cooooo`Co00002?oo
ool2o`0000[ooooo0ol00008ooooo`;o00004?ooool2o`0000Cooooo0_l00007ooooo`;o00003Ooo
ool2o`0000Cooooo0_l0000Dooooo`;o00000oooool2o`0000Cooooo0_l00003ooooo`Go0000L_oo
ool001cooooo00?o0000ooooooooool0Goooool2o`0001;ooooo0_l00004ooooo`;o00003Oooool2
o`0000_ooooo0_l0000?ooooo`;o000000?oooooo`000?l000001_ooool2o`0000oooooo0_l00003
ooooo`;o00001?ooool3o`0000;ooooo0ol0001dooooo`007?ooool00ol0003oooooooooo`1Noooo
o`;o00002Oooool2o`0000Cooooo0_l00002ooooo`?o00000oooool2o`0000?ooooo0_l0000Eoooo
o`;o000000?oooooo`000?l000003?ooool2o`000003ooooool0003o000000Kooooo0_l00002oooo
o`?o00000_ooool2o`0000Oooooo0_l00008ooooo`?o0000NOooool001cooooo00?o0000oooooooo
ool0Eoooool2o`0000Gooooo0_l00009ooooo`;o00001?ooool2o`0000?ooooo0_l000001?oooooo
0000o`000?l00004ooooo`;o00000_ooool2o`0000Kooooo0_l000000ooooooo0000o`000002oooo
o`;o00001Oooool2o`0000_ooooo1?l00007ooooo`;o00000oooool3o`0000;ooooo0_l00007oooo
o`;o00001?ooool3o`0007gooooo000Looooo`03o`000?oooooooooo05Oooooo0_l0000<ooooo`;o
00004?ooool3o`0000Sooooo0_l00006ooooo`Go00000_ooool2o`0000cooooo0_l00003ooooo`Go
00001_ooool3o`0000gooooo0_l00004ooooo`;o00000_ooool3o`0000Gooooo0_l00002ooooo`;o
0000L_ooool001cooooo00?o0000ooooooooool0IOooool2o`0001;ooooo0_l00005ooooo`Co0000
1oooool2o`000003ooooool0003o000000oooooo0_l000000ooooooo0000o`000002o`0000Wooooo
0_l00004ooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l0
00000oooool2o`0000Gooooo0ol000000ooooooo0000o`00001booooo`0000Koooooonk^k_lb<S;o
0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000
ooooooooool0L?ooool2o`0000?ooooo0_l00002ooooo`;o00001?ooool3o`0000Wooooo0_l00000
0ooooooo0000o`00000Booooo`;o00004Oooool2o`0000Gooooo0_l00004ooooo`;o000000?ooooo
o`000?l000000oooool4o`0000Cooooo0_l0001eooooo`0000KoooooogMgMonHV9SooooooiRHV?mg
MgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0
L?ooool2o`0000?ooooo0_l00003ooooo`;o00000oooool2o`0000[ooooo0_l0000Wooooo`Go0000
1?ooool2o`0000Kooooo0_l00003ooooo`Co0000Noooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
N?ooool4o`0003Sooooo1Ol00004ooooo`;o000000?oooooo`000?l000000oooool4o`00083ooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RH
oc8b<P06ooooo`?o0000MOooool6o`0000Wooooo0_l0000;ooooo`;o00005_ooool2o`0000Sooooo
1Ol00003ooooo`;o00000oooool2o`0000Gooooo0_l00008ooooo`;o0000M_ooool00003ooooool0
003ooooo00;ooooo00?o0000ooooooooool02Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo
00?o0000ooooooooool0MOooool4o`0000_ooooo0_l00007ooooo`;o00000_ooool2o`0000;ooooo
0_l0000@ooooo`Co00002?ooool2o`000003ooooool0003o000000;ooooo1_l00005ooooo`;o0000
2_ooool2o`0007Kooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go
410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo07Oooooo0_l00002ooooo`Co0000
3_ooool2o`0000;ooooo0ol000000ooooooo0000o`00000@ooooo`;o00003Oooool2o`0000;ooooo
0_l000001?oooooo0000o`000?l00005ooooo`;o00008?ooool2o`00063ooooo00001_ooooooMgMg
oiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooo
oooo06Sooooo0_l0000Aooooo`Co000000?oooooo`000?l000000ol0000;ooooo`Co00003Oooool2
o`0000;ooooo0_l00010ooooo`;o0000H?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2ooo
ool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0J?ooool2o`0000cooooo
0_l00008ooooo`Oo000000?oooooo`000?l000001_ooool2o`0000Wooooo0_l00004ooooo`;o0000
0_ooool2o`00027ooooo0_l0001oooooo`007?ooool00ol0003oooooooooo`1dooooo`Co000000?o
ooooo`000?l000001oooool2o`000004ooooool0003o0000ooooo`;o00001_ooool2o`0000Wooooo
0_l0000>ooooo`Co000000?oooooo`000?l000001_ooool2o`000004ooooool0003o0000ooooo`;o
00000oooool2o`0000?ooooo0_l0001oooooo`007?ooool00ol0003oooooooooo`1dooooo`;o0000
0oooool2o`0000Oooooo1?l0000?ooooo`;o00002Oooool2o`0000Wooooo1?l000000ooooooo0000
o`000006ooooo`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o0000Q?ooool001cooooo
00?o0000ooooooooool0P_ooool4o`0000oooooo0_l00009ooooo`;o0000Yoooool001cooooo00?o
0000ooooooooool0O?ooool2o`0000Kooooo0_l0000>ooooo`;o00002_ooool2o`0000?ooooo0_l0
0003ooooo`;o00001?ooool2o`0000Oooooo0ol0002=ooooo`007?ooool00ol0003oooooooooo`1l
ooooo`Co00005?ooool2o`0000Wooooo0_l00004ooooo`;o00000oooool2o`0000Cooooo1Ol00004
ooooo`?o0000SOooool001cooooo00?o0000ooooooooool0O_ooool2o`0001oooooo0_l0000Aoooo
o`?o000000?oooooo`000?l00000TOooool001cooooo00?o0000ooooooooool0UOooool2o`0000?o
oooo1?l00003ooooo`;o000000?oooooo`000?l000004?ooool2o`00097ooooo000Looooo`03o`00
0?oooooooooo07?ooooo0_l00007ooooo`;o00002oooool2o`0000;ooooo1?l00002ooooo`Co0000
0oooool4o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o0000Woooool001cooooo00?o
0000ooooooooool0Loooool2o`0000Oooooo0_l0000;ooooo`;o00000_ooool4o`0000;ooooo0_l0
000Cooooo`;o0000Woooool001cooooo00?o0000ooooooooool0T_ooool2o`0000Gooooo0_l0002^
ooooo`007?ooool00ol0003oooooooooo`2=ooooo`;o00000oooool2o`0000Gooooo0_l00004oooo
o`?o0000Yoooool001cooooo0_l0002>ooooo`;o00004?ooool3o`0000Oooooo0ol0002Mooooo`00
7?ooool00ol0003oooooooooo`2Sooooo`;o00001?ooool3o`0009gooooo000Looooo`03o`000?oo
oooooooo09gooooo0_l00004ooooo`;o0000Y?ooool001cooooo00?o0000ooooooooool0Voooool4
o`000:[ooooo000Looooo`03o`000?oooooooooo09_ooooo0_l0002/ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Eooooo`;o0000>?ooool2
o`0007Sooooo000Looooo`03o`000?oooooooooo09Gooooo0_l0000hooooo`;o0000N?ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0Qoooool2
o`0001Kooooo0_l00005ooooo`;o0000XOooool001cooooo00?o0000ooooooooool0Qoooool2o`00
00kooooo0_l00006ooooo`;o00001Oooool2o`000:7ooooo000Looooo`03o`000?oooooooooo09Oo
oooo0_l0002`ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001;ooooo
1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooo
oooo00Gooooo0ol0003ooooood[ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Co
oooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo
000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001;ooooo00?oEEEEofIVI_l00000oooooomD
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00XOooool01?l@413o0000o`00
0?ooool2o`000003oa0@4?oooooooooo01Kooooo1?l000001Ol@413oooooooooooooooooA4A400;o
000000Wo<S8bomgMgOooooooooooonk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^08cooooo002Rooooo`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo
00?o0000ooooooooool01_ooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0S?ooool00:;ooooo00Go0000ooooooooooooooooo`00
000Kooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo410@0oooool01Ol@413ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool0R_ooool00:;ooooo00Go0000oooooooooooo
ooooo`000009ooooo`Ko00003?ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;ooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0R_ooool0
0:;ooooo00Go0000ohN7QoooooooZJVYo`00000Kooooo`03o`000?oooooooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000008cooooo002Qooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool0
6Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100S?ooool00<;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg08cooooo0030ooooo`03oeEEEOmVIVKo000000Gooooo1?l00003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^08cooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}]
}, Closed]],

Cell[BoxData[
    \({18966.5`\ Second, Null}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\t",
  StyleBox["(f) ",
    FontWeight->"Bold"],
  StyleBox["Vortices with opposite signs",
    FontSlant->"Italic"],
  ". One big difference between fluids and self-gravitating systems is that \
fluid vorticity can be both positive and negative, whereas mass density is \
always positive (so far as we know!). Vortices with opposite signs act in \
qualitatively different ways than like-sign vortices. "
}], "Text"],

Cell[TextData[{
  "\t\t(i) Modify the fluid code to handle ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " point vortices, each with arbitrary circulation ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Gamma]\_i\), ",", " ", \(i = 1\), ",", "...", ",", 
          RowBox[{"N", ".", Cell[""]}]}], TraditionalForm]]],
  " (Hint: Define a list ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\)]],
  " whose elements are the circulation of each point vortex.) "
}], "Text"],

Cell[TextData[{
  "\t\t(ii) Analytically determine the dynamics of two isolated point \
vortices with circulations of opposite signs ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PlusMinus]\[Gamma]\)\)]],
  ", separated by distance ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\t\t(iii) Test the code by running an initial condition with ",
  Cell[BoxData[
      \(TraditionalForm\`N = 2\)]],
  " opposite-signed point vortices separated by ",
  Cell[BoxData[
      \(TraditionalForm\`R = 0.3\)]],
  ". Compare to the analytics."
}], "Text"],

Cell["\<\
\t\t(iv) Investigate the dynamics of extended regions of vorticity \
with overall zero circulation:\
\>", "Text"],

Cell[TextData[{
  "\t\t\t(A) ",
  Cell[BoxData[
      \(TraditionalForm\`N = 2000\)]],
  " point vorticies randomly distributed in the cell, of which half have one \
sign of circulation, the other half the opposite sign."
}], "Text"],

Cell[TextData[{
  "\t\t\t(B) Create an initial condition consisting of two opposite-signed \
uniform circular vortex patches of radius ",
  Cell[BoxData[
      \(TraditionalForm\`R = 0.1\)]],
  ", with centers separated by distance ",
  Cell[BoxData[
      \(TraditionalForm\`D = 0.25\)]],
  ".  Take ",
  Cell[BoxData[
      \(TraditionalForm\`N = 1000\)]],
  " (500 in each patch),  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma] = \ \(\[PlusMinus]2\)/N\)]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["Nstep",
            FontFamily->"Courier",
            FontWeight->"Bold"], " ", "=", " ", "300"}], TraditionalForm]]],
  ", and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], " ", "=", " ", "0.01"}], 
        TraditionalForm]]],
  ".  (This run requires fine resolution; take ",
  Cell[BoxData[
      \(TraditionalForm\`M > 30\)]],
  "). Do the vortices merge, as they did when they had the same sign of \
vorticity?"
}], "Text"],

Cell[TextData[{
  StyleBox["(6)",
    FontWeight->"Bold"],
  StyleBox[" SIMULATION PROJECT: PLASMA WAVES. ",
    FontSlant->"Italic"],
  "If one changes the sign of the interaction potential in Eq. ",
  ButtonBox["(7.3.2)",
    ButtonData:>"(7.3.2)",
    ButtonStyle->"Hyperlink"],
  ", setting ",
  Cell[BoxData[
      \(TraditionalForm\`G = \(-q\^2\)/\((4\ \[Pi]\ m\ \[Epsilon]\_o)\)\)]],
  ", the equations of gravitational dynamics now describe a collection of \
like charges, with charge ",
  Cell[BoxData[
      \(TraditionalForm\`q\)]],
  " and mass ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  ", interacting via the repulsive Coulomb potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " through a mean-field interparticle force ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Del]\[Phi]\)\)]],
  ". This collection of charges is called a ",
  StyleBox["one component plasma",
    FontSlant->"Italic"],
  ", since there is only a single charge species present. "
}], "Text",
  CellTags->"i:92"],

Cell[TextData[{
  "\t",
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Perform this substitution, and show in a simulation of ",
  Cell[BoxData[
      \(TraditionalForm\`N = 1000\)]],
  "charges with zero initial velocities and random initial conditions that \
the system is now stable. Take ",
  Cell[BoxData[
      \(TraditionalForm\`M = 20, \ 
      m = \(q = 1\)\ , \ \ \[Epsilon]\_0 = \((4  \[Pi])\)\^\(-1\)\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]t = 0.003\)]],
  "and run for 60 steps. Plot the particle positions in the ",
  Cell[BoxData[
      \(TraditionalForm\`x - y\)]],
  " plane as an animation. The oscillations one can see here are called ",
  StyleBox["plasma waves",
    FontSlant->"Italic"],
  ". "
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(b)",
    FontWeight->"Bold"],
  " We will study the behavior of these plasma oscillations as we vary the \
plasma temperature. First, we will set up an initial condition consisting of \
a single sinusoidal density oscillation with amplitude ",
  Cell[BoxData[
      \(TraditionalForm\`A\_0\)]],
  ". This is done using the rejection method, discussed in Chapter ",
  ButtonBox["8",
    ButtonData:>{"Chapter8.nb", "c:19"},
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[BoxData[{
    \(\(A0 = 0.25;\)\), "\[IndentingNewLine]", 
    \(\(w[y_]\  = \ 1\  + \ A0\ Cos[2\ Pi\ y];\)\[IndentingNewLine]\), "\n", 
    \(\(sx[]\  := \ Random[Real, {0, 1}];\)\), "\n", 
    \(\(sy[]\  := \ Random[Real, {0, 1.5}];\)\[IndentingNewLine]\), "\n", 
    \(s[]\  := \((xx = sx[]; \ \ While[sy[]\  > \ w[xx], \ \ xx = sx[]]; 
        xx)\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.96"],

Cell[TextData[{
  "Positions of the particles can now be obtained using the random variable  \
",
  StyleBox["s[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Take as the initial positions "
}], "Text"],

Cell[BoxData[
    \(r0\  = \ Table[{Random[], s[]}, {1000}]; \)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.97"],

Cell[TextData[{
  "and run the simulation for the same parameters as in part a), wtih zero \
initial velocity and with ",
  Cell[BoxData[
      \(TraditionalForm\`A\_0 = 0.25\)]],
  ". One should see a single well-behaved density oscillation. \n\tDetermine \
the amplitude of the ",
  Cell[BoxData[
      \(TraditionalForm\`cos(2\ \[Pi]\ y)\)]],
  " oscillation by defining"
}], "Text"],

Cell[BoxData[
    \(\(\(amp[n_]\)\(\ \)\(:=\)\(\ \)\(Sum[
        Cos[2\ Pi\ \(r[n]\)[\([\)\(m, 2\)\(]\)]], {m, 1, 
          1000}]\)\(\ \)\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.98"],

Cell[TextData[{
  "This function takes the projection of the density onto ",
  Cell[BoxData[
      \(TraditionalForm\`cos(2\ \[Pi]\ y)\)]],
  ", and is equivalent to ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(amp(t)\), "=", 
          RowBox[{"\[Integral]", 
            RowBox[{
              RowBox[{"n", "(", 
                RowBox[{
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox[",",
                    FontWeight->"Plain"], 
                  StyleBox["t",
                    FontWeight->"Plain"]}], 
                StyleBox[")",
                  FontWeight->"Plain"]}], 
              " ", \(cos(2  \[Pi]\ y)\), \(\[DifferentialD]\^2 r\)}]}]}], 
        TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      FormBox[
        RowBox[{"n", "(", 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["t",
              FontWeight->"Plain"]}], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " is the number density.\n\tPlot this function versus ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(t\_n\), "=", 
          RowBox[{"n", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  " and from this graph estimate the period of the plasma oscillation."
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Using the linearized fluid equations ",
  ButtonBox["(7.3.13)",
    ButtonData:>"(7.3.13)",
    ButtonStyle->"Hyperlink"],
  ", determine the frequency of small-amplitude oscillations versus \
wavenumber ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  ". Show that  the oscillation frequency is"
}], "Text",
  CellTags->"i:90"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\^2 = \(c\^\(\(2\)\(\ \)\)\) 
            k\^2 + \[Omega]\_p\^2\)]],
  ", "
}], "NE3"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " is the sound speed, as in Eq. ",
  ButtonBox["(7.3.14)",
    ButtonData:>"(7.3.14)",
    ButtonStyle->"Hyperlink"],
  ",  and  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Omega]\_p\)\(=\)\(\@\(\(q\^2\) 
              n/m\ \[Epsilon]\_o\)\)\(\ \)\)\)]],
  " is the ",
  StyleBox["plasma frequency",
    FontSlant->"Italic"],
  " . Evaluate this frequency for the parameters of part (b) and compare to \
the observed period of oscillation. "
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(d)",
    FontWeight->"Bold"],
  " Increase the temperature ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " of the simulation, and repeat part (b) five times, taking ",
  Cell[BoxData[
      \(TraditionalForm\`\@T = 1, \ 2, 5, 7, 10\)]],
  ". Choose momenta distributed according to a Gaussian distribution using \
the following rejection method algorithm, discussed in Chapter ",
  ButtonBox["8",
    ButtonData:>{"Chapter8.nb", "c:19"},
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[BoxData[{
    \(wv[x_]\  := \ Exp[\(-x^2\)/\((2\ T)\)\ ]/Sqrt[2\ T\ Pi\ ]; \), "\n", 
    \(aa := \(-5\)\ Sqrt[T]; bb = 5\ Sqrt[T]; \), "\n", 
    \(f00\  := \ 1/Sqrt[2\ T\ Pi]; \)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.99"],

Cell[BoxData[{
    \(\(svx[]\  := \ Random[Real, {aa, bb}];\)\), "\n", 
    \(\(svy[]\  := \ Random[Real, {0, f00}];\)\), "\n", 
    \(sp[]\  := \((xx = svx[]; \ \ While[svy[]\  > \ wv[xx], \ \ xx = svx[]]; 
        xx)\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.100"],

Cell[BoxData[
    \(p0 = \ Table[{sp[], sp[]}, {1000}]; \)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.101"],

Cell[TextData[{
  "For each temperature, determine the oscillation frequency from the \
simulation. Plot this data versus ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " and compare to the prediction of Eq. ",
  ButtonBox["(7.3.26)",
    ButtonData:>"(7.3.26)",
    ButtonStyle->"Hyperlink"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma] = 3\)]],
  " (the value for a one-dimensional ideal adiabatic process), and ",
  Cell[BoxData[
      \(TraditionalForm\`p\_o = n\ \ T\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tNote that for the largest temperatures, the oscillation amplitude damps \
away rapidly with time. This is a phase-mixing process called",
  StyleBox[" ",
    FontSlant->"Italic"],
  StyleBox[ButtonBox["Landau",
    ButtonData:>{
      URL[ 
      "http://turnbull.dcs.st-and.ac.uk/~history/Mathematicians/Landau_Lev.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  StyleBox[" damping",
    FontSlant->"Italic"],
  ". The process is similar to the phase-mixing observed previously in the \
collisionless Boltzmann equation, in Sec. ",
  ButtonBox["7.1.2",
    ButtonData:>"c:9",
    ButtonStyle->"Hyperlink"],
  ".  It can be understood analytically by solving the linearized \
collisionless Boltzmann equation as an initial-value problem, using methods \
similar to those in Exercise (3).  For more information see ",
  ButtonBox["Birdsall and Langdon (1991)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  ", or ",
  ButtonBox["Stix (1962)",
    ButtonData:>{"Chapter5.nb", "refs"},
    ButtonStyle->"Hyperlink"],
  " (in the references for Chapter 5)."
}], "Text",
  CellTags->"i:91"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["References", "Subtitle",
  CellTags->{"refs", "c:41"}],

Cell[TextData[{
  "T. B. Benjamin, ",
  StyleBox["Instability of periodic wavetrains in nonlinear dispersive \
systems",
    FontSlant->"Italic"],
  ", Proc.  R. Soc. London Ser. A ",
  StyleBox["299",
    FontWeight->"Bold"],
  ", 59 (1967)."
}], "Text"],

Cell[TextData[{
  "J. Binney and S. Tremaine, ",
  StyleBox["Galactic Dynamics",
    FontSlant->"Italic"],
  " (Princeton University Press, Princeton, NJ, 1987)"
}], "Text"],

Cell[TextData[{
  "C.K. Birdsall and A. B. Langdon, ",
  StyleBox["Plasma Physics via Computer Simulation",
    FontSlant->"Italic"],
  " (Adam Hilger, Bristol,  1991)"
}], "Text"],

Cell[TextData[{
  "C. F. Driscoll and K. Fine, ",
  StyleBox["Experiments on vortex dynamics in pure electron plasmas",
    FontSlant->"Italic"],
  ", Phys. Fluids B ",
  StyleBox["2",
    FontWeight->"Bold"],
  ", 1359 (1990)."
}], "Text"],

Cell[TextData[{
  "E. Fermi, J. Pasta, and S. Ulam, ",
  StyleBox["Studies of Nonlinear Problems",
    FontSlant->"Italic"],
  ", Los Alamos Report LA-1940  (1955). "
}], "Text"],

Cell[TextData[{
  "K. Fine, W. Flynn, A. Cass and C. F. Driscoll, ",
  StyleBox["Relaxation of 2D turbulence to vortex crystals",
    FontSlant->"Italic"],
  ", Phys. Rev. Lett. ",
  StyleBox["75",
    FontWeight->"Bold"],
  ", 3277 (1995)."
}], "Text"],

Cell[TextData[{
  "J. Glanz, ",
  StyleBox["From a turbulent maelstrom, order",
    FontSlant->"Italic"],
  ", Science ",
  StyleBox["280",
    FontWeight->"Bold"],
  ", 519 (1998)."
}], "Text"],

Cell[TextData[{
  "L. Greengard, ",
  StyleBox["Fast algorithms for classical physics",
    FontSlant->"Italic"],
  ", Science ",
  StyleBox["265",
    FontWeight->"Bold"],
  ", 909 (1994)."
}], "Text"],

Cell[TextData[{
  "A. Hasegawa  and Y. Kodama,  ",
  StyleBox["Solitons in Optical Communications",
    FontSlant->"Italic"],
  ", (Oxford University Press, New York, 1995)."
}], "Text"],

Cell[TextData[{
  "J. Scott Russell, ",
  StyleBox["Report on Waves",
    FontSlant->"Italic"],
  ", Report of the Fourteenth Meeting of the British Association for the \
Advancement of Science, York, September 1844 (London, 1845), pp. 311-390."
}], "Text"],

Cell[TextData[{
  "G.B. Whitham, ",
  StyleBox["Linear and Nonlinear Waves ",
    FontSlant->"Italic"],
  "(John Wiley and Sons, New York, 1999)."
}], "Text"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 746}},
ShowPageBreaks->False,
WindowToolbars->{},
WindowSize->{800, 556},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Visible->True,
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{Inherited, Inherited, Cell[ 
        TextData[ {"Chapter 7, Section 7.", 
          CounterBox[ "Subtitle"]}], "Header"]}, {Cell[ 
        TextData[ "Dubin"], "Header"], Cell[ 
        TextData[ 
        "Numerical and Analytical Methods for Scientists and Engineers"], 
        FontWeight -> Bold, FontSlant -> Italic, FontFamily -> Times], 
      Inherited}},
TaggingRules:>{"NextIndexingNumber" -> 93, "IndexEntries" -> {{"i:10", \
{"Action (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Wave action)"}}, {"i:11", "Thermal equilibrium"}, {"i:13", 
  StyleBox[ "Histogram", FontWeight -> "Bold"]}, {"i:27", 
  StyleBox[ "EllipticF", FontWeight -> "Bold"]}, {"i:29", 
  StyleBox[ 
  "EllipticK", FontWeight -> 
    "Bold"]}, {"i:31", "Scott-Russell, J."}, {"i:37", 
  Cell[ 
    BoxData[ 
      FormBox[ 
        RowBox[ {
          RowBox[ {
            RowBox[ {
              FractionBox[ 
                RowBox[ {"\[PartialD]", "\[Rho]"}], 
                RowBox[ {"\[PartialD]", "t"}]], "+", 
              RowBox[ {
                FractionBox[ "\[PartialD]", 
                  RowBox[ {"\[PartialD]", "x"}]], 
                RowBox[ {"(", 
                  RowBox[ {"u", " ", "\[Rho]"}], ")"}]}]}], " ", "=", " ", 
            "0"}], ","}], 
        TraditionalForm]]]}, {"i:43", "Hugoniot relation"}, {"i:48", \
"Hugoniot relation"}, {"i:5", {"Chaotic systems (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Ordinary differential equations, Lyapunov exponent)"}}, \
{"i:52", "Fermi, Enrico"}, {"i:55", "PIC method"}, {"i:56", "Gravitational \
collapse"}, {"i:57", "Gravitational collapse"}, {"i:58", 
  StyleBox[ "Quotient", FontWeight -> "Bold"]}, {"i:59", 
  StyleBox[ 
  "Mod", FontWeight -> 
    "Bold"]}, {"i:6", "Boltzmann equation, collisionless"}, {"i:6", {"Vlasov \
equation (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Boltzmann equation, collisionless)"}}, {"i:60", 
  StyleBox[ "Mod", FontWeight -> "Bold"]}, {"i:66", "Vorticity"}, {"i:67", 
  StyleBox[ "Export", FontWeight -> "Bold"]}, {"i:68", 
  StyleBox[ 
  "Unset", FontWeight -> 
    "Bold"]}, {"i:69", "Circulation"}, {"i:72", "Turbulence"}, {"i:77", \
"Viscosity"}, {"i:8", "Phase mixing"}, {"i:80", "Jean's instability"}, \
{"i:81", "Jeans instability"}, {"i:82", "Jeans instability"}, {"i:83", \
"Navier-Stokes equations"}, {"i:84", "Euler equations"}, {"i:85", "Burger's \
equation, neglecting diffusion"}, {"i:86", "grid methods"}, {"i:87", "Grid \
methods"}, {"i:88", "Area weighting"}, {"i:89", "tree codes"}, {"i:91", \
"Landau damping"}, {"i:92", "One component plasma"}, {"i:12", "Density", \
"particle (or number)"}, {"i:15", "Partial differential equations", "first \
order"}, {"i:17", "Burger's equation", "and nonlinear water waves"}, {"i:18", \
"Burger's equation", "characteristics"}, {"i:18", "Characteristics", "for \
Burger's equation"}, {"i:19", "Characteristics", "for the linear \
collisionless Boltzmann equation"}, {"i:2", "Characteristics", "definition"}, \
{"i:20", "Density", "phase space"}, {"i:21", "Galerkin method", "von-Neumann \
basis functions"}, {"i:22", "Burger's equation", "with damping"}, {"i:23", \
"Partial differential equations", {"traffic flow equation (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Burger's equation)"}}, {"i:32", "Partial differential \
equations", "Boussinesq equations"}, {"i:33", "Solitons", "in other \
systems"}, {"i:34", "Partial differential equations", "sine-Gordon \
equation"}, {"i:35", "Partial differential equations", "Klein-Gordon \
equation"}, {"i:36", "Shroedinger's equation", "nonlinear"}, {"i:37", \
"Continuity equation", "for mass density"}, {"i:38", "Momentum", "equation"},
   {"i:39", "Specific heat(s)", "ratio of"}, {"i:40", "Equations", "of \
state"}, {"i:41", "Equations", "fluid"}, {"i:42", "Dispersion", "relation, \
for sound waves"}, {"i:44", "K-dV equation", "stability of steady \
solutions"}, {"i:47", "Burger's equation", "with diffusion"}, {"i:49", \
"Solitons", "in other systems"}, {"i:50", "Solitons", "in other systems"}, \
{"i:51", "Partial differential equations", {"traffic flow equation (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Burger's equation)"}}, {"i:52", "Energy", {"equipartition, in \
FPU system (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Wavebreaking, suppression of)"}}, {"i:53", "Energy", {"cascade \
(", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Wavebreaking)"}}, {"i:54", "Boltzmann equation, \
collisionless", "for self-gravitating systems"}, {"i:55", "Numerical methods \
for solution of PDEs", "particle in cell method"}, {"i:55", "Numerical \
solution of PDEs", {"particle in cell method (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " PIC method)"}}, {"i:6", "Partial differential equations", \
{"collisionless Boltzmann equation (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Boltzmann equation, collisionless)"}}, {"i:60", 
  StyleBox[ "Map", FontWeight -> "Bold"], 
  StyleBox[ 
  "", FontWeight -> 
    "Bold"]}, {"i:61", "Numerical solution of ODEs", "leapfrog method"}, \
{"i:62", "FFTs", "in PIC method"}, {"i:63", 
  StyleBox[ 
  "Interpolation", FontWeight -> 
    "Bold"], "linear, in PIC method"}, {"i:65", "Equations", "2D fluid"}, \
{"i:69", "Vortex", "point"}, {"i:70", "Vortex", "merger"}, {"i:71", "Vortex", \
"crystals"}, {"i:73", "Solitons", "in other systems"}, {"i:74", "Galerkin \
method", "for nonlinear system (k-dV equation)"}, {"i:75", "Grid methods", \
"for nonlinear systems (shock waves)"}, {"i:78", "Function(s)", "pure"}, \
{"i:79", "Grid methods", "operator splitting"}, {"i:9", "Boltzmann equation, \
collisionless", "equilibrium solution"}, {"i:90", "plasma waves", "thermal \
corrections"}, {"i:1", "Characteristics", "method of", ""}, {"i:11", \
"Equilibrium", {"thermal (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Thermal equilibrium)"}, ""}, {"i:14", "Partial differential \
equations", {"Burger's equation (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Burger's equation)"}, ""}, {"i:14", {"Waves (", 
  StyleBox[ 
  "see also", FontSlant -> "Italic"], " Eigenmodes)"}, {"nonlinear (", 
  StyleBox[ 
  "see", FontSlant -> 
    "Italic"], " Burger's equation, K-dV equation)"}, ""}, {"i:16", \
"Wavebreaking", "time, in Burger's equation", ""}, {"i:24", "Partial \
differential equations", {"k-dV equation (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " K-dV equation)"}, ""}, {"i:25", "K-dV equation", "", ""}, \
{"i:26", "K-dV equation", {"derivation of steady solutions (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Solitons;waves, cnoidal)"}, ""}, {"i:26", "Solitons", "", ""}, \
{"i:26", {"Waves (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Eigenmodes)"}, "cnoidal", ""}, {"i:27", "Integral,", \
{"Elliptic, of the first kind (", 
  StyleBox[ "EllipticF", FontWeight -> "Bold"], ",", 
  StyleBox[ 
  "EllipticK", FontWeight -> 
    "Bold"], ")"}, ""}, {"i:28", "Function(s)", {"Jacobian Elliptic (", 
  StyleBox[ 
  "JacobiSN,JacobiCN", FontWeight -> 
    "Bold"], ")"}, ""}, {"i:28", {"Waves (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Eigenmodes)"}, "cnoidal", ""}, {"i:3", "Derivatives", "total \
time", ""}, {"i:30", "Solitons", "in the K-dV equation", ""}, {"i:4", \
{"Mixing dye (", 
  StyleBox[ 
  "see also", FontSlant -> 
    "Italic"], " Boltzmann equation, collisionless, Chaotic systems)"}, "", \
""}, {"i:45", "K-dV equation", {"suppression of wavebreaking (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Wavebreaking, suppression of)"}, ""}, {"i:46", {"Waves, shock \
(", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Equations, fluid)"}, "", ""}, {"i:48", {"Waves, shock (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Equations, fluid)"}, {"jump condition (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Hugoniot relation)"}, ""}, {"i:52", "Ordinary differential \
equations", "Fermi Pasta Ulam (FPU) system", ""}, {"i:61", "Leapfrog method", \
"", ""}, {"i:64", "Function(s)", "stream", ""}, {"i:68", "Numerical solution \
of ordinary differential equations", "Adams-Bashforth method", ""}, {"i:68", \
{"Adams-Bashforth method (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}, "", ""}, {"i:7", {"Ideal gas \
(", 
  StyleBox[ 
  "see also", FontSlant -> 
    "Italic"], " Boltzmann equation, collisionless, Thermal equilibrium)"}, \
"", ""}, {"i:73", {"Refraction (", 
  StyleBox[ 
  "see also", FontSlant -> 
    "Italic"], " WKB method, Ray trajectories, Snell's law)"}, "index of, \
nonlinear", ""}, {"i:76", {"Ideal gas (", 
  StyleBox[ 
  "see also", FontSlant -> 
    "Italic"], " Boltzmann equation, collisionless, Thermal equilibrium)"}, \
"as a model of the galaxy", ""}}},
CellLabelAutoDelete->True,
ScriptSizeMultipliers->0.85,
ImageRegion->{{0.01, 1}, {0, Inherited}},
Magnification->1.25,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Subsection"],
  
  Cell[StyleData[All, "Working"],
    CellBracketOptions->{"Color"->RGBColor[0, 0.2, 1]},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Subsection"],
  
  Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellLabelAutoDelete->False,
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {2, 20}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->30,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {2, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {2, 2}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {2, 4}},
    FontSize->18,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {2, 12}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {2, 8}},
    FontSize->12,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{10, 4}, {2, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 4}, {2, 18}},
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {2, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->15,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{2, 4}, {2, 18}},
    FontSize->12]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{20, 4}, {0, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 4}, {2, 18}},
    FontSize->10]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellFrame->{{4, 0}, {0, 0}},
    CellMargins->{{47, 62}, {0, 14}},
    CellFrameMargins->5,
    CellFrameColor->RGBColor[0, 0.2, 1],
    Hyphenation->True,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{34, 62}, {0, 14}},
    CellFrameColor->GrayLevel[0.700008],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Subsection"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{56, 4}, {3, 9}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Bold",
    Background->RGBColor[0, 1, 1]],
  
  Cell[StyleData["Input", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {3, 8}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{57, 4}, {5, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    CounterIncrements->"Output",
    Background->RGBColor[1, 1, 0]],
  
  Cell[StyleData["Output", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {4, 2}},
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{56, 4}, {3, 8}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0.2, 1]],
  
  Cell[StyleData["Message", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {4, 2}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{56, 4}, {3, 8}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {4, 2}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{56, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{40, 4}, {4, 2}},
    ImageSize->{250, 250},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0.2, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->7,
    FontSlant->"Oblique",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(7.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE2"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(7.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE2"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE2",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE2", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE3"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(7.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE3"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE3",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE3", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE4"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(7.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE4"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE4",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE4", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE5"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(7.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE5"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE5",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE5", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UNNEQ"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, None}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["UNNEQ", "Printout"],
    FontSize->10]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextTop"],
    CellFrame->{{0, 0}, {0, 2}},
    CellMargins->{{10, 4}, {2, 80}},
    CellHorizontalScrolling->True,
    CellFrameMargins->4,
    ShowSpecialCharacters->Automatic,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["TextTop", "Printout"],
    CellMargins->{{2, 4}, {2, 80}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{20, 4}, {0, 8}},
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    ParagraphIndent->-15,
    CounterIncrements->"Text"],
  
  Cell[StyleData["ItemizedText", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{35, 4}, {0, 4}},
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    ParagraphSpacing->{0, 4},
    CounterIncrements->"Text"],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{20, 4}, {0, 6}},
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["IndentedText", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Note"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ShowSpecialCharacters->Automatic,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["Note", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.39, 0.59}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.325}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.23,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.145, 0.345, 0.145, 0.345}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.195}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.13, 0.23, 0.13, 0.13, 0.23, 0.13}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, Inherited}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 50}, {0, 3}},
    PageBreakAbove->False,
    Hyphenation->True,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 50}, {2, 4}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    GridBoxOptions->{ColumnWidths->{0.39, 0.59},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.325,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Subsection"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Subsection"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "c:1"->{
    Cell[1727, 52, 79, 1, 111, "Title",
      CellTags->"c:1"]},
  "i:1"->{
    Cell[3100, 87, 102, 1, 39, "Subtitle",
      CellTags->{"i:1", "c:3"}]},
  "c:3"->{
    Cell[3100, 87, 102, 1, 39, "Subtitle",
      CellTags->{"i:1", "c:3"}]},
  "i:15"->{
    Cell[3247, 94, 73, 1, 41, "Subsubtitle",
      CellTags->{"i:15", "c:4"}]},
  "c:4"->{
    Cell[3247, 94, 73, 1, 41, "Subsubtitle",
      CellTags->{"i:15", "c:4"}]},
  "(7.1.1)"->{
    Cell[3467, 103, 213, 6, 36, "NumberedEquation",
      CellTags->"(7.1.1)"]},
  "(7.1.2)"->{
    Cell[3793, 116, 140, 5, 26, "NumberedEquation",
      CellTags->"(7.1.2)"]},
  "(7.1.3)"->{
    Cell[6398, 187, 200, 8, 26, "NumberedEquation",
      CellTags->"(7.1.3)"]},
  "i:2"->{
    Cell[6601, 197, 221, 8, 25, "Text",
      CellTags->"i:2"]},
  "i:3"->{
    Cell[7536, 229, 650, 22, 41, "Text",
      CellTags->"i:3"]},
  "(7.1.4)"->{
    Cell[8189, 253, 296, 7, 36, "NumberedEquation",
      CellTags->"(7.1.4)"]},
  "(7.1.5)"->{
    Cell[8657, 269, 173, 3, 36, "NumberedEquation",
      CellTags->"(7.1.5)"]},
  "(7.1.6)"->{
    Cell[9238, 286, 173, 6, 35, "NumberedEquation",
      CellTags->"(7.1.6)"]},
  "(7.1.7)"->{
    Cell[10305, 326, 213, 6, 36, "NumberedEquation",
      CellTags->"(7.1.7)"]},
  "(7.1.8)"->{
    Cell[12357, 399, 264, 7, 40, "NumberedEquation",
      CellTags->"(7.1.8)"]},
  "(7.1.9)"->{
    Cell[13024, 422, 192, 3, 36, "NumberedEquation",
      CellTags->"(7.1.9)"]},
  "c:5"->{
    Cell[13619, 442, 60, 1, 30, "Subsubtitle",
      CellTags->"c:5"]},
  "(7.1.10)"->{
    Cell[14475, 472, 166, 3, 25, "NumberedEquation",
      CellTags->"(7.1.10)"]},
  "(7.1.11)"->{
    Cell[14644, 477, 174, 3, 25, "NumberedEquation",
      CellTags->"(7.1.11)"]},
  "(7.1.12)"->{
    Cell[16225, 533, 247, 7, 30, "NumberedEquation",
      CellTags->"(7.1.12)"]},
  "(7.1.13)"->{
    Cell[17556, 587, 334, 9, 30, "NumberedEquation",
      CellTags->"(7.1.13)"]},
  "c:6"->{
    Cell[18314, 614, 190, 8, 40, "Section",
      CellTags->"c:6"]},
  "(7.1.14)"->{
    Cell[18659, 632, 191, 6, 36, "NumberedEquation",
      CellTags->"(7.1.14)"]},
  "(7.1.15)"->{
    Cell[20865, 708, 226, 6, 26, "NumberedEquation",
      CellTags->"(7.1.15)"]},
  "i:78"->{
    Cell[23322, 792, 452, 13, 41, "Text",
      CellTags->"i:78"]},
  "Cell 7.1"->{
    Cell[23799, 809, 202, 5, 85, "Input",
      CellTags->"Cell 7.1"]},
  "Fig. 7.1"->{
    Cell[113299, 4928, 374, 13, 15, "Caption",
      CellTags->"Fig. 7.1"]},
  "c:7"->{
    Cell[113710, 4946, 196, 9, 30, "Section",
      CellTags->"c:7"]},
  "(7.1.16)"->{
    Cell[114657, 4984, 179, 6, 30, "NumberedEquation",
      CellTags->"(7.1.16)"]},
  "Fig. 7.2"->{
    Cell[192314, 8371, 477, 17, 26, "Caption",
      CellTags->"Fig. 7.2"]},
  "(7.1.17)"->{
    Cell[193140, 8401, 221, 7, 40, "NumberedEquation",
      CellTags->"(7.1.17)"]},
  "Cell 7.2"->{
    Cell[194708, 8460, 303, 7, 110, "Input",
      CellTags->"Cell 7.2"]},
  "c:8"->{
    Cell[749486, 23137, 60, 1, 30, "Section",
      CellTags->"c:8"]},
  "i:4"->{
    Cell[749759, 23148, 287, 7, 40, "NumberedEquation",
      CellTags->{"i:4", "(7.1.18)"}]},
  "(7.1.18)"->{
    Cell[749759, 23148, 287, 7, 40, "NumberedEquation",
      CellTags->{"i:4", "(7.1.18)"}]},
  "(7.1.19)"->{
    Cell[750913, 23189, 156, 5, 36, "NumberedEquation",
      CellTags->"(7.1.19)"]},
  "(7.1.20)"->{
    Cell[751985, 23225, 309, 9, 45, "NumberedEquation",
      CellTags->"(7.1.20)"]},
  "i:5"->{
    Cell[753079, 23262, 323, 10, 75, "Text",
      CellTags->"i:5"]},
  "Cell 7.3"->{
    Cell[754087, 23298, 479, 11, 140, "Input",
      CellTags->"Cell 7.3"]},
  "Cell 7.4"->{
    Cell[754940, 23328, 428, 10, 140, "Input",
      CellTags->"Cell 7.4"]},
  "Cell 7.5"->{
    Cell[1007169, 34083, 456, 10, 121, "Input",
      CellTags->"Cell 7.5"]},
  "c:9"->{
    Cell[1787360, 53586, 85, 1, 30, "Section",
      CellTags->"c:9"]},
  "i:20"->{
    Cell[1787448, 53589, 943, 30, 60, "Text",
      CellTags->"i:20"]},
  "(7.1.21)"->{
    Cell[1788394, 53621, 232, 6, 40, "NumberedEquation",
      CellTags->"(7.1.21)"]},
  "i:19"->{
    Cell[1788833, 53636, 231, 7, 70, "UNNEQ",
      CellTags->"i:19"]},
  "i:6"->{
    Cell[1789256, 53653, 991, 24, 95, "Text",
      CellTags->"i:6"]},
  "i:7"->{
    Cell[1790250, 53679, 690, 24, 60, "Text",
      CellTags->"i:7"]},
  "Cell 7.6"->{
    Cell[1791957, 53739, 933, 21, 311, "Input",
      CellTags->"Cell 7.6"]},
  "(7.1.22)"->{
    Cell[1893824, 58356, 142, 3, 25, "NumberedEquation",
      CellTags->"(7.1.22)"]},
  "i:8"->{
    Cell[1893969, 58361, 627, 14, 95, "Text",
      CellTags->"i:8"]},
  "Cell 7.7"->{
    Cell[1895069, 58394, 467, 11, 140, "Input",
      CellTags->"Cell 7.7"]},
  "i:9"->{
    Cell[7903259, 223424, 1577, 47, 95, "Text",
      CellTags->"i:9"]},
  "(7.1.23)"->{
    Cell[7904839, 223473, 225, 6, 41, "NumberedEquation",
      CellTags->"(7.1.23)"]},
  "(7.1.24)"->{
    Cell[7906102, 223515, 318, 9, 41, "NumberedEquation",
      CellTags->"(7.1.24)"]},
  "(7.1.25)"->{
    Cell[7906484, 223528, 138, 5, 30, "NumberedEquation",
      CellTags->"(7.1.25)"]},
  "(7.1.26)"->{
    Cell[7908338, 223584, 312, 8, 45, "NumberedEquation",
      CellTags->"(7.1.26)"]},
  "Cell 7.8"->{
    Cell[7909758, 223626, 239, 6, 85, "Input",
      CellTags->"Cell 7.8"]},
  "Cell 7.9"->{
    Cell[7910380, 223648, 244, 5, 115, "Input",
      CellTags->"Cell 7.9"]},
  "Cell 7.10"->{
    Cell[7911023, 223671, 393, 10, 180, "Input",
      CellTags->"Cell 7.10"]},
  "Cell 7.11"->{
    Cell[7911626, 223693, 240, 6, 85, "Input",
      CellTags->"Cell 7.11"]},
  "(7.1.27)"->{
    Cell[7946501, 224490, 243, 8, 35, "NumberedEquation",
      CellTags->"(7.1.27)"]},
  "Cell 7.12"->{
    Cell[7947685, 224533, 210, 6, 85, "Input",
      CellTags->"Cell 7.12"]},
  "i:10"->{
    Cell[7947898, 224541, 343, 8, 41, "Text",
      CellTags->"i:10"]},
  "Cell 7.13"->{
    Cell[7948244, 224551, 316, 7, 140, "Input",
      CellTags->"Cell 7.13"]},
  "Cell 7.14"->{
    Cell[7948756, 224570, 225, 5, 65, "Input",
      CellTags->"Cell 7.14"]},
  "Cell 7.15"->{
    Cell[7973196, 225152, 202, 5, 85, "Input",
      CellTags->"Cell 7.15"]},
  "Cell 7.16"->{
    Cell[7973882, 225177, 250, 6, 85, "Input",
      CellTags->"Cell 7.16"]},
  "Cell 7.17"->{
    Cell[7974449, 225197, 298, 6, 85, "Input",
      CellTags->"Cell 7.17"]},
  "i:11"->{
    Cell[8285700, 231048, 1110, 33, 96, "Text",
      CellTags->"i:11"]},
  "Cell 7.18"->{
    Cell[8286987, 231089, 169, 4, 65, "Input",
      CellTags->"Cell 7.18"]},
  "Cell 7.19"->{
    Cell[8287347, 231105, 178, 5, 65, "Input",
      CellTags->"Cell 7.19"]},
  "i:12"->{
    Cell[13633602, 376094, 422, 11, 60, "Text",
      CellTags->"i:12"]},
  "(7.1.28)"->{
    Cell[13634027, 376107, 231, 7, 30, "NumberedEquation",
      CellTags->"(7.1.28)"]},
  "i:13"->{
    Cell[13635401, 376155, 240, 7, 41, "Text",
      CellTags->"i:13"]},
  "Cell 7.20"->{
    Cell[13635644, 376164, 92, 3, 65, "Input",
      CellTags->"Cell 7.20"]},
  "Cell 7.21"->{
    Cell[13636513, 376194, 587, 13, 200, "Input",
      CellTags->"Cell 7.21"]},
  "Cell 7.22"->{
    Cell[18808333, 481250, 173, 5, 65, "Input",
      CellTags->"Cell 7.22"]},
  "Fig. 7.3"->{
    Cell[18839713, 482053, 209, 6, 15, "Caption",
      CellTags->"Fig. 7.3"]},
  "i:14"->{
    Cell[18840867, 482080, 74, 1, 30, "Subsubtitle",
      CellTags->{"i:14", "c:10"}]},
  "c:10"->{
    Cell[18840867, 482080, 74, 1, 30, "Subsubtitle",
      CellTags->{"i:14", "c:10"}]},
  "c:11"->{
    Cell[18840966, 482085, 76, 1, 40, "Section",
      CellTags->"c:11"]},
  "(7.1.29)"->{
    Cell[18841192, 482093, 222, 6, 35, "NumberedEquation",
      CellTags->"(7.1.29)"]},
  "i:17"->{
    Cell[18841417, 482101, 1547, 42, 130, "Text",
      CellTags->"i:17"]},
  "i:85"->{
    Cell[18844018, 482181, 199, 6, 36, "NumberedEquation",
      CellTags->{"i:85", "(7.1.30)"}]},
  "(7.1.30)"->{
    Cell[18844018, 482181, 199, 6, 36, "NumberedEquation",
      CellTags->{"i:85", "(7.1.30)"}]},
  "c:12"->{
    Cell[18844734, 482206, 47, 1, 30, "Section",
      CellTags->"c:12"]},
  "(7.1.31)"->{
    Cell[18845290, 482223, 174, 6, 26, "NumberedEquation",
      CellTags->"(7.1.31)"]},
  "(7.1.32)"->{
    Cell[18845845, 482243, 185, 5, 26, "NumberedEquation",
      CellTags->"(7.1.32)"]},
  "(7.1.33)"->{
    Cell[18846195, 482257, 153, 5, 26, "NumberedEquation",
      CellTags->"(7.1.33)"]},
  "i:18"->{
    Cell[18846655, 482275, 161, 5, 26, "NumberedEquation",
      CellTags->{"i:18", "(7.1.34)"}]},
  "(7.1.34)"->{
    Cell[18846655, 482275, 161, 5, 26, "NumberedEquation",
      CellTags->{"i:18", "(7.1.34)"}]},
  "Fig. 7.4"->{
    Cell[18959341, 487665, 241, 7, 15, "Caption",
      CellTags->"Fig. 7.4"]},
  "Cell 7.23"->{
    Cell[18960696, 487711, 111, 3, 65, "Input",
      CellTags->"Cell 7.23"]},
  "Cell 7.24"->{
    Cell[18961005, 487725, 136, 3, 65, "Input",
      CellTags->"Cell 7.24"]},
  "i:87"->{
    Cell[18961481, 487742, 594, 19, 41, "Text",
      CellTags->"i:87"]},
  "Cell 7.25"->{
    Cell[18962078, 487763, 286, 7, 121, "Input",
      CellTags->"Cell 7.25"]},
  "Cell 7.26"->{
    Cell[18962756, 487789, 273, 7, 85, "Input",
      CellTags->"Cell 7.26"]},
  "i:16"->{
    Cell[19329286, 496210, 66, 1, 30, "Section",
      CellTags->{"i:16", "c:13"}]},
  "c:13"->{
    Cell[19329286, 496210, 66, 1, 30, "Section",
      CellTags->{"i:16", "c:13"}]},
  "(7.1.35)"->{
    Cell[19331694, 496293, 792, 19, 40, "NumberedEquation",
      CellTags->"(7.1.35)"]},
  "(7.1.36)"->{
    Cell[19333253, 496343, 186, 6, 40, "NumberedEquation",
      CellTags->"(7.1.36)"]},
  "(7.1.37)"->{
    Cell[19333662, 496361, 211, 7, 40, "NumberedEquation",
      CellTags->"(7.1.37)"]},
  "(7.1.38)"->{
    Cell[19334178, 496381, 162, 3, 30, "NumberedEquation",
      CellTags->"(7.1.38)"]},
  "(7.1.39)"->{
    Cell[19334365, 496388, 177, 6, 30, "NumberedEquation",
      CellTags->"(7.1.39)"]},
  "Cell 7.27"->{
    Cell[19335003, 496414, 106, 3, 65, "Input",
      CellTags->"Cell 7.27"]},
  "Cell 7.28"->{
    Cell[19335518, 496436, 103, 3, 65, "Input",
      CellTags->"Cell 7.28"]},
  "(7.1.40)"->{
    Cell[19336948, 496481, 1059, 27, 50, "NumberedEquation",
      CellTags->"(7.1.40)"]},
  "(7.1.41)"->{
    Cell[19338247, 496520, 667, 18, 50, "NumberedEquation",
      CellTags->"(7.1.41)"]},
  "c:14"->{
    Cell[19339808, 496573, 65, 1, 30, "Subsubtitle",
      CellTags->"c:14"]},
  "i:21"->{
    Cell[19345661, 496794, 1624, 50, 96, "Text",
      CellTags->"i:21"]},
  "(7.1.42)"->{
    Cell[19347348, 496848, 367, 12, 32, "NumberedEquation",
      CellTags->"(7.1.42)"]},
  "i:22"->{
    Cell[19353018, 497036, 669, 18, 38, "UNNEQ",
      CellTags->"i:22"]},
  "i:23"->{
    Cell[19354697, 497096, 704, 17, 78, "Text",
      CellTags->"i:23"]},
  "(7.1.43)"->{
    Cell[19355404, 497115, 202, 4, 39, "NumberedEquation",
      CellTags->"(7.1.43)"]},
  "i:24"->{
    Cell[19356751, 497158, 71, 1, 40, "Subtitle",
      CellTags->{"i:24", "c:15"}]},
  "c:15"->{
    Cell[19356751, 497158, 71, 1, 40, "Subtitle",
      CellTags->{"i:24", "c:15"}]},
  "c:16"->{
    Cell[19356866, 497165, 84, 1, 41, "Subsubtitle",
      CellTags->"c:16"]},
  "(7.2.1)"->{
    Cell[19357564, 497184, 140, 5, 30, "NE2",
      CellTags->"(7.2.1)"]},
  "Cell 7.29"->{
    Cell[19358762, 497227, 123, 3, 65, "Input",
      CellTags->"Cell 7.29"]},
  "(7.2.2)"->{
    Cell[19359535, 497259, 198, 7, 35, "NE2",
      CellTags->"(7.2.2)"]},
  "(7.2.3)"->{
    Cell[19359935, 497276, 285, 7, 40, "NE2",
      CellTags->"(7.2.3)"]},
  "i:25"->{
    Cell[19360850, 497307, 891, 31, 41, "Text",
      CellTags->"i:25"]},
  "(7.2.4)"->{
    Cell[19361744, 497340, 223, 7, 40, "NE2",
      CellTags->"(7.2.4)"]},
  "i:26"->{
    Cell[19362952, 497380, 103, 1, 30, "Subsubtitle",
      CellTags->{"i:26", "c:17"}]},
  "c:17"->{
    Cell[19362952, 497380, 103, 1, 30, "Subsubtitle",
      CellTags->{"i:26", "c:17"}]},
  "(7.2.5)"->{
    Cell[19366386, 497499, 192, 3, 41, "NE2",
      CellTags->"(7.2.5)"]},
  "(7.2.6)"->{
    Cell[19366713, 497511, 172, 6, 37, "NE2",
      CellTags->"(7.2.6)"]},
  "Cell 7.30"->{
    Cell[19367471, 497541, 515, 11, 160, "Input",
      CellTags->"Cell 7.30"]},
  "Cell 7.31"->{
    Cell[19398609, 498306, 110, 3, 65, "Input",
      CellTags->"Cell 7.31"]},
  "(7.2.7)"->{
    Cell[19400328, 498367, 180, 6, 56, "NE2",
      CellTags->"(7.2.7)"]},
  "(7.2.8)"->{
    Cell[19400580, 498377, 422, 15, 70, "NE2",
      CellTags->"(7.2.8)"]},
  "Cell 7.32"->{
    Cell[19401563, 498411, 134, 3, 65, "Input",
      CellTags->"Cell 7.32"]},
  "(7.2.9)"->{
    Cell[19403953, 498462, 184, 7, 37, "NE2",
      CellTags->"(7.2.9)"]},
  "Cell 7.33"->{
    Cell[19404349, 498480, 431, 8, 191, "Input",
      CellTags->"Cell 7.33"]},
  "i:27"->{
    Cell[19405113, 498498, 359, 10, 42, "Text",
      CellTags->"i:27"]},
  "(7.2.10)"->{
    Cell[19405878, 498526, 481, 13, 60, "NE2",
      CellTags->"(7.2.10)"]},
  "(7.2.11)"->{
    Cell[19406386, 498543, 134, 6, 37, "NE2",
      CellTags->"(7.2.11)"]},
  "(7.2.12)"->{
    Cell[19407839, 498602, 238, 8, 56, "NE2",
      CellTags->"(7.2.12)"]},
  "i:28"->{
    Cell[19408080, 498612, 932, 31, 80, "Text",
      CellTags->"i:28"]},
  "Cell 7.34"->{
    Cell[19409037, 498647, 250, 5, 85, "Input",
      CellTags->"Cell 7.34"]},
  "(7.2.13)"->{
    Cell[19460198, 499760, 131, 6, 28, "NE2",
      CellTags->"(7.2.13)"]},
  "i:29"->{
    Cell[19460332, 499768, 772, 30, 60, "Text",
      CellTags->"i:29"]},
  "Cell 7.35"->{
    Cell[19461129, 499802, 217, 5, 85, "Input",
      CellTags->"Cell 7.35"]},
  "Cell 7.36"->{
    Cell[19491145, 500480, 101, 3, 65, "Input",
      CellTags->"Cell 7.36"]},
  "(7.2.14)"->{
    Cell[19492102, 500519, 220, 7, 56, "NE2",
      CellTags->"(7.2.14)"]},
  "(7.2.15)"->{
    Cell[19492528, 500538, 179, 6, 56, "NE2",
      CellTags->"(7.2.15)"]},
  "Cell 7.37"->{
    Cell[19493325, 500573, 635, 14, 161, "Input",
      CellTags->"Cell 7.37"]},
  "Fig. 7.5"->{
    Cell[21095392, 524117, 317, 9, 28, "Caption",
      CellTags->"Fig. 7.5"]},
  "(7.2.16)"->{
    Cell[21097696, 524190, 131, 5, 37, "NE2",
      CellTags->"(7.2.16)"]},
  "Fig. 7.6"->{
    Cell[21129957, 524959, 329, 12, 15, "Caption",
      CellTags->"Fig. 7.6"]},
  "i:30"->{
    Cell[21130520, 524979, 762, 27, 60, "Text",
      CellTags->"i:30"]},
  "Cell 7.38"->{
    Cell[21131307, 525010, 309, 6, 120, "Input",
      CellTags->"Cell 7.38"]},
  "Cell 7.39"->{
    Cell[21166372, 525816, 114, 3, 75, "Input",
      CellTags->"Cell 7.39"]},
  "(7.2.17)"->{
    Cell[21166650, 525827, 168, 6, 32, "NE2",
      CellTags->"(7.2.17)"]},
  "(7.2.18)"->{
    Cell[21168157, 525884, 143, 5, 27, "NE2",
      CellTags->"(7.2.18)"]},
  "(7.2.19)"->{
    Cell[21168339, 525893, 131, 5, 41, "NE2",
      CellTags->"(7.2.19)"]},
  "i:31"->{
    Cell[21168473, 525900, 232, 5, 42, "Text",
      CellTags->"i:31"]},
  "i:73"->{
    Cell[21169828, 525927, 1339, 28, 165, "Text",
      CellTags->"i:73"]},
  "c:18"->{
    Cell[21171204, 525960, 94, 1, 30, "Subsubtitle",
      CellTags->"c:18"]},
  "c:19"->{
    Cell[21171323, 525965, 51, 1, 40, "Section",
      CellTags->"c:19"]},
  "i:74"->{
    Cell[21172382, 525988, 367, 12, 41, "Text",
      CellTags->"i:74"]},
  "(7.2.20)"->{
    Cell[21172752, 526002, 338, 12, 30, "NE2",
      CellTags->"(7.2.20)"]},
  "(7.2.21)"->{
    Cell[21173250, 526023, 212, 7, 35, "NE2",
      CellTags->"(7.2.21)"]},
  "(7.2.22)"->{
    Cell[21173816, 526043, 912, 23, 45, "NE2",
      CellTags->"(7.2.22)"]},
  "(7.2.23)"->{
    Cell[21175552, 526094, 322, 8, 35, "NE2",
      CellTags->"(7.2.23)"]},
  "(7.2.24)"->{
    Cell[21176244, 526118, 148, 5, 26, "NE2",
      CellTags->"(7.2.24)"]},
  "Cell 7.40"->{
    Cell[21176551, 526132, 155, 4, 65, "Input",
      CellTags->"Cell 7.40"]},
  "i:53"->{
    Cell[21178375, 526190, 790, 20, 75, "Text",
      CellTags->"i:53"]},
  "Cell 7.41"->{
    Cell[21180063, 526236, 125, 3, 65, "Input",
      CellTags->"Cell 7.41"]},
  "i:44"->{
    Cell[21180292, 526246, 72, 1, 30, "Section",
      CellTags->{"i:44", "c:20"}]},
  "c:20"->{
    Cell[21180292, 526246, 72, 1, 30, "Section",
      CellTags->{"i:44", "c:20"}]},
  "Cell 7.42"->{
    Cell[21180469, 526254, 318, 7, 121, "Input",
      CellTags->"Cell 7.42"]},
  "Cell 7.43"->{
    Cell[21181079, 526276, 291, 7, 105, "Input",
      CellTags->"Cell 7.43"]},
  "(7.2.25)"->{
    Cell[21181693, 526299, 273, 9, 30, "NE2",
      CellTags->"(7.2.25)"]},
  "Cell 7.44"->{
    Cell[21182048, 526314, 392, 11, 160, "Input",
      CellTags->"Cell 7.44"]},
  "Cell 7.45"->{
    Cell[21184695, 526398, 1253, 22, 390, "Input",
      CellTags->"Cell 7.45"]},
  "Cell 7.46"->{
    Cell[21186227, 526435, 100, 3, 65, "Input",
      CellTags->"Cell 7.46"]},
  "c:21"->{
    Cell[23001026, 570175, 70, 1, 30, "Section",
      CellTags->"c:21"]},
  "Cell 7.47"->{
    Cell[23001224, 570183, 247, 6, 105, "Input",
      CellTags->"Cell 7.47"]},
  "Cell 7.48"->{
    Cell[23001546, 570193, 375, 11, 160, "Input",
      CellTags->"Cell 7.48"]},
  "Cell 7.49"->{
    Cell[23002353, 570220, 105, 3, 65, "Input",
      CellTags->"Cell 7.49"]},
  "i:45"->{
    Cell[25064240, 623949, 87, 1, 30, "Section",
      CellTags->{"i:45", "c:22"}]},
  "c:22"->{
    Cell[25064240, 623949, 87, 1, 30, "Section",
      CellTags->{"i:45", "c:22"}]},
  "Cell 7.50"->{
    Cell[25065337, 623980, 313, 7, 140, "Input",
      CellTags->"Cell 7.50"]},
  "Cell 7.51"->{
    Cell[27817414, 701119, 541, 11, 180, "Input",
      CellTags->"Cell 7.51"]},
  "Fig. 7.7"->{
    Cell[31628448, 798689, 95, 1, 15, "Caption",
      CellTags->"Fig. 7.7"]},
  "Fig. 7.8"->{
    Cell[31924199, 812233, 194, 6, 15, "Caption",
      CellTags->"Fig. 7.8"]},
  "i:46"->{
    Cell[31925688, 812278, 89, 1, 30, "Subsubtitle",
      CellTags->{"i:46", "c:23"}]},
  "c:23"->{
    Cell[31925688, 812278, 89, 1, 30, "Subsubtitle",
      CellTags->{"i:46", "c:23"}]},
  "c:24"->{
    Cell[31925802, 812283, 55, 1, 40, "Section",
      CellTags->"c:24"]},
  "i:47"->{
    Cell[31925860, 812286, 372, 12, 45, "Text",
      CellTags->"i:47"]},
  "(7.2.26)"->{
    Cell[31926235, 812300, 221, 7, 40, "NE2",
      CellTags->"(7.2.26)"]},
  "(7.2.27)"->{
    Cell[31927907, 812349, 720, 21, 40, "NE2",
      CellTags->"(7.2.27)"]},
  "(7.2.28)"->{
    Cell[31929326, 812398, 173, 6, 35, "NE2",
      CellTags->"(7.2.28)"]},
  "i:48"->{
    Cell[31929502, 812406, 266, 9, 25, "Text",
      CellTags->"i:48"]},
  "Cell 7.52"->{
    Cell[31930090, 812430, 234, 5, 85, "Input",
      CellTags->"Cell 7.52"]},
  "c:25"->{
    Cell[31959707, 813192, 67, 1, 30, "Section",
      CellTags->"c:25"]},
  "i:75"->{
    Cell[31959777, 813195, 1331, 43, 75, "Text",
      CellTags->"i:75"]},
  "(7.2.29)"->{
    Cell[31963885, 813320, 1584, 41, 55, "NE2",
      CellTags->"(7.2.29)"]},
  "Cell 7.53"->{
    Cell[31966568, 813401, 239, 6, 85, "Input",
      CellTags->"Cell 7.53"]},
  "(7.2.30)"->{
    Cell[31967134, 813419, 1446, 40, 45, "NE2",
      CellTags->"(7.2.30)"]},
  "Cell 7.54"->{
    Cell[31969411, 813488, 357, 7, 111, "Input",
      CellTags->"Cell 7.54"]},
  "Cell 7.55"->{
    Cell[31969771, 813497, 176, 5, 90, "Input",
      CellTags->"Cell 7.55"]},
  "(7.2.31)"->{
    Cell[31970102, 813511, 429, 13, 35, "NE2",
      CellTags->"(7.2.31)"]},
  "i:79"->{
    Cell[31970534, 813526, 1303, 43, 60, "Text",
      CellTags->"i:79"]},
  "Cell 7.56"->{
    Cell[31972726, 813601, 136, 3, 65, "Input",
      CellTags->"Cell 7.56"]},
  "Cell 7.57"->{
    Cell[31973060, 813614, 255, 7, 65, "Input",
      CellTags->"Cell 7.57"]},
  "Cell 7.58"->{
    Cell[31973567, 813634, 196, 6, 65, "Input",
      CellTags->"Cell 7.58"]},
  "Cell 7.59"->{
    Cell[31973898, 813649, 205, 4, 65, "Input",
      CellTags->"Cell 7.59"]},
  "Cell 7.60"->{
    Cell[31974911, 813684, 281, 6, 121, "Input",
      CellTags->"Cell 7.60"]},
  "Cell 7.61"->{
    Cell[31975891, 813713, 352, 9, 135, "Input",
      CellTags->"Cell 7.61"]},
  "Cell 7.62"->{
    Cell[31976364, 813731, 102, 3, 65, "Input",
      CellTags->"Cell 7.62"]},
  "Cell 7.63"->{
    Cell[31976751, 813747, 395, 9, 121, "Input",
      CellTags->"Cell 7.63"]},
  "Cell 7.64"->{
    Cell[32866914, 836643, 193, 5, 85, "Input",
      CellTags->"Cell 7.64"]},
  "Cell 7.65"->{
    Cell[32867187, 836654, 368, 9, 121, "Input",
      CellTags->"Cell 7.65"]},
  "c:26"->{
    Cell[33589868, 855715, 65, 1, 30, "Subsubtitle",
      CellTags->"c:26"]},
  "i:32"->{
    Cell[33591202, 855767, 742, 23, 78, "Text",
      CellTags->"i:32"]},
  "(7.2.32)"->{
    Cell[33593501, 855849, 413, 7, 78, "NE2",
      CellTags->"(7.2.32)"]},
  "i:33"->{
    Cell[33594998, 855901, 967, 32, 65, "Text",
      CellTags->"i:33"]},
  "i:34"->{
    Cell[33596677, 855962, 168, 8, 27, "Text",
      CellTags->"i:34"]},
  "(7.2.33)"->{
    Cell[33596848, 855972, 454, 10, 43, "NE2",
      CellTags->"(7.2.33)"]},
  "i:35"->{
    Cell[33597735, 855996, 438, 10, 43, "UNNEQ",
      CellTags->"i:35"]},
  "i:49"->{
    Cell[33598573, 856023, 1344, 45, 87, "Text",
      CellTags->"i:49"]},
  "i:36"->{
    Cell[33600047, 856076, 287, 8, 43, "NE2",
      CellTags->{"i:36", "(7.2.34)"}]},
  "(7.2.34)"->{
    Cell[33600047, 856076, 287, 8, 43, "NE2",
      CellTags->{"i:36", "(7.2.34)"}]},
  "i:50"->{
    Cell[33601304, 856111, 413, 13, 44, "Text",
      CellTags->"i:50"]},
  "i:41"->{
    Cell[33602126, 856140, 1019, 35, 61, "Text",
      CellTags->"i:41"]},
  "i:37"->{
    Cell[33603148, 856177, 192, 3, 39, "NE2",
      CellTags->{"i:37", "(7.2.35)"}]},
  "(7.2.35)"->{
    Cell[33603148, 856177, 192, 3, 39, "NE2",
      CellTags->{"i:37", "(7.2.35)"}]},
  "i:38"->{
    Cell[33603384, 856184, 322, 6, 45, "NE2",
      CellTags->{"i:38", "(7.2.36)"}]},
  "(7.2.36)"->{
    Cell[33603384, 856184, 322, 6, 45, "NE2",
      CellTags->{"i:38", "(7.2.36)"}]},
  "i:77"->{
    Cell[33603709, 856192, 453, 15, 31, "Text",
      CellTags->"i:77"]},
  "i:40"->{
    Cell[33604165, 856209, 159, 5, 29, "NE2",
      CellTags->{"i:40", "(7.2.37)"}]},
  "(7.2.37)"->{
    Cell[33604165, 856209, 159, 5, 29, "NE2",
      CellTags->{"i:40", "(7.2.37)"}]},
  "i:39"->{
    Cell[33604327, 856216, 434, 13, 44, "Text",
      CellTags->"i:39"]},
  "i:42"->{
    Cell[33605178, 856246, 185, 6, 33, "UNNEQ",
      CellTags->"i:42"]},
  "(7.2.38)"->{
    Cell[33606755, 856302, 258, 7, 46, "NE2",
      CellTags->"(7.2.38)"]},
  "i:43"->{
    Cell[33607144, 856318, 165, 5, 27, "Text",
      CellTags->"i:43"]},
  "i:51"->{
    Cell[33613852, 856554, 381, 11, 44, "Text",
      CellTags->"i:51"]},
  "i:86"->{
    Cell[33614851, 856587, 475, 9, 78, "Text",
      CellTags->"i:86"]},
  "(7.2.39)"->{
    Cell[33616322, 856630, 2099, 52, 81, "NE2",
      CellTags->"(7.2.39)"]},
  "i:52"->{
    Cell[33618952, 856703, 1476, 39, 99, "Text",
      CellTags->"i:52"]},
  "(7.2.40)"->{
    Cell[33622480, 856810, 300, 10, 38, "NE2",
      CellTags->"(7.2.40)"]},
  "i:55"->{
    Cell[33623962, 856865, 113, 2, 40, "Subtitle",
      CellTags->{"i:55", "c:27"}]},
  "c:27"->{
    Cell[33623962, 856865, 113, 2, 40, "Subtitle",
      CellTags->{"i:55", "c:27"}]},
  "c:28"->{
    Cell[33624119, 856873, 66, 1, 41, "Subsubtitle",
      CellTags->"c:28"]},
  "i:76"->{
    Cell[33624188, 856876, 1441, 31, 175, "Text",
      CellTags->"i:76"]},
  "Fig. 7.9"->{
    Cell[36641288, 894145, 250, 5, 29, "Caption",
      CellTags->"Fig. 7.9"]},
  "i:54"->{
    Cell[36643642, 894211, 779, 22, 42, "NE3",
      CellTags->{"i:54", "(7.3.1)"}]},
  "(7.3.1)"->{
    Cell[36643642, 894211, 779, 22, 42, "NE3",
      CellTags->{"i:54", "(7.3.1)"}]},
  "(7.3.2)"->{
    Cell[36644890, 894250, 140, 5, 32, "NE3",
      CellTags->"(7.3.2)"]},
  "c:29"->{
    Cell[36649082, 894367, 75, 1, 30, "Subsubtitle",
      CellTags->"c:29"]},
  "Fig. 7.10"->{
    Cell[36920024, 901121, 516, 12, 44, "Caption",
      CellTags->"Fig. 7.10"]},
  "i:89"->{
    Cell[36921697, 901164, 926, 15, 129, "Text",
      CellTags->"i:89"]},
  "i:61"->{
    Cell[36923417, 901202, 74, 1, 30, "Subsubtitle",
      CellTags->{"i:61", "c:30"}]},
  "c:30"->{
    Cell[36923417, 901202, 74, 1, 30, "Subsubtitle",
      CellTags->{"i:61", "c:30"}]},
  "Cell 7.66"->{
    Cell[36933226, 901507, 2383, 46, 505, "Input",
      CellTags->"Cell 7.66"]},
  "i:60"->{
    Cell[36935612, 901555, 1674, 49, 114, "Text",
      CellTags->"i:60"]},
  "c:31"->{
    Cell[36938818, 901666, 54, 1, 30, "Subsubtitle",
      CellTags->"c:31"]},
  "c:32"->{
    Cell[36938897, 901671, 63, 1, 42, "Section",
      CellTags->"c:32"]},
  "Cell 7.67"->{
    Cell[36941198, 901757, 222, 6, 121, "Input",
      CellTags->"Cell 7.67"]},
  "i:88"->{
    Cell[36941423, 901765, 542, 13, 60, "Text",
      CellTags->"i:88"]},
  "i:58"->{
    Cell[36941968, 901780, 958, 35, 60, "Text",
      CellTags->"i:58"]},
  "(7.3.3)"->{
    Cell[36942929, 901817, 1263, 38, 45, "NE3",
      CellTags->"(7.3.3)"]},
  "i:59"->{
    Cell[36944195, 901857, 725, 27, 41, "Text",
      CellTags->"i:59"]},
  "(7.3.4)"->{
    Cell[36944923, 901886, 999, 29, 45, "NE3",
      CellTags->"(7.3.4)"]},
  "(7.3.5)"->{
    Cell[36946200, 901926, 424, 14, 40, "NE3",
      CellTags->"(7.3.5)"]},
  "(7.3.6)"->{
    Cell[36950120, 902047, 2541, 75, 85, "NE3",
      CellTags->"(7.3.6)"]},
  "Fig. 7.11"->{
    Cell[37765781, 913366, 96, 1, 15, "Caption",
      CellTags->"Fig. 7.11"]},
  "(7.3.7)"->{
    Cell[37765954, 913371, 1780, 44, 115, "NE3",
      CellTags->"(7.3.7)"]},
  "Cell 7.68"->{
    Cell[37769399, 913467, 2441, 46, 406, "Input",
      CellTags->"Cell 7.68"]},
  "Cell 7.69"->{
    Cell[37773646, 913564, 1333, 29, 220, "Input",
      CellTags->"Cell 7.69"]},
  "Cell 7.70"->{
    Cell[37775936, 913631, 395, 10, 140, "Input",
      CellTags->"Cell 7.70"]},
  "i:62"->{
    Cell[37884676, 916813, 70, 1, 31, "Section",
      CellTags->{"i:62", "c:33"}]},
  "c:33"->{
    Cell[37884676, 916813, 70, 1, 31, "Section",
      CellTags->{"i:62", "c:33"}]},
  "(7.3.8)"->{
    Cell[37885618, 916846, 901, 24, 75, "NE3",
      CellTags->"(7.3.8)"]},
  "Cell 7.71"->{
    Cell[37887032, 916890, 3567, 69, 690, "Input",
      CellTags->"Cell 7.71"]},
  "Cell 7.72"->{
    Cell[37894114, 917061, 201, 5, 105, "Input",
      CellTags->"Cell 7.72"]},
  "Cell 7.73"->{
    Cell[38041430, 919596, 433, 10, 121, "Input",
      CellTags->"Cell 7.73"]},
  "i:63"->{
    Cell[38189201, 923441, 121, 4, 31, "Section",
      CellTags->{"i:63", "c:34"}]},
  "c:34"->{
    Cell[38189201, 923441, 121, 4, 31, "Section",
      CellTags->{"i:63", "c:34"}]},
  "Cell 7.74"->{
    Cell[38189757, 923460, 516, 11, 140, "Input",
      CellTags->"Cell 7.74"]},
  "Cell 7.75"->{
    Cell[38190802, 923488, 121, 4, 85, "Input",
      CellTags->"Cell 7.75"]},
  "Cell 7.76"->{
    Cell[38192272, 923525, 4242, 83, 655, "Input",
      CellTags->"Cell 7.76"]},
  "Cell 7.77"->{
    Cell[38196969, 923626, 907, 21, 180, "Input",
      CellTags->"Cell 7.77"]},
  "c:35"->{
    Cell[38197925, 923653, 57, 1, 30, "Subsubtitle",
      CellTags->"c:35"]},
  "c:36"->{
    Cell[38198007, 923658, 50, 1, 42, "Section",
      CellTags->"c:36"]},
  "Cell 7.78"->{
    Cell[38199770, 923715, 613, 14, 255, "Input",
      CellTags->"Cell 7.78"]},
  "Cell 7.79"->{
    Cell[38200792, 923744, 200, 5, 85, "Input",
      CellTags->"Cell 7.79"]},
  "Cell 7.80"->{
    Cell[38896590, 937962, 349, 8, 105, "Input",
      CellTags->"Cell 7.80"]},
  "Cell 7.81"->{
    Cell[38940370, 938941, 663, 13, 200, "Input",
      CellTags->"Cell 7.81"]},
  "(7.3.9)"->{
    Cell[38988744, 939845, 249, 7, 50, "NE3",
      CellTags->"(7.3.9)"]},
  "(7.3.10)"->{
    Cell[38989230, 939862, 739, 21, 35, "NE3",
      CellTags->"(7.3.10)"]},
  "Cell 7.82"->{
    Cell[38991283, 939932, 1396, 27, 390, "Input",
      CellTags->"Cell 7.82"]},
  "Cell 7.83"->{
    Cell[39052708, 940978, 951, 19, 255, "Input",
      CellTags->"Cell 7.83"]},
  "(7.3.11)"->{
    Cell[39093022, 941825, 953, 26, 45, "NE3",
      CellTags->"(7.3.11)"]},
  "(7.3.12)"->{
    Cell[39098296, 941981, 1323, 38, 41, "NE3",
      CellTags->"(7.3.12)"]},
  "i:56"->{
    Cell[39104756, 942182, 85, 1, 31, "Section",
      CellTags->{"i:56", "c:37"}]},
  "c:37"->{
    Cell[39104756, 942182, 85, 1, 31, "Section",
      CellTags->{"i:56", "c:37"}]},
  "i:80"->{
    Cell[39104844, 942185, 756, 20, 75, "Text",
      CellTags->"i:80"]},
  "Cell 7.84"->{
    Cell[39106795, 942238, 449, 10, 160, "Input",
      CellTags->"Cell 7.84"]},
  "Cell 7.85"->{
    Cell[39107340, 942256, 200, 5, 85, "Input",
      CellTags->"Cell 7.85"]},
  "Cell 7.86"->{
    Cell[42832884, 1046072, 187, 4, 65, "Input",
      CellTags->"Cell 7.86"]},
  "i:57"->{
    Cell[42873724, 1046889, 97, 1, 31, "Section",
      CellTags->{"i:57", "c:38"}]},
  "c:38"->{
    Cell[42873724, 1046889, 97, 1, 31, "Section",
      CellTags->{"i:57", "c:38"}]},
  "Cell 7.87"->{
    Cell[42874305, 1046908, 453, 10, 140, "Input",
      CellTags->"Cell 7.87"]},
  "Cell 7.88"->{
    Cell[42874866, 1046926, 200, 5, 85, "Input",
      CellTags->"Cell 7.88"]},
  "Cell 7.89"->{
    Cell[46843829, 1153700, 338, 7, 105, "Input",
      CellTags->"Cell 7.89"]},
  "i:83"->{
    Cell[46881582, 1154491, 856, 27, 61, "Text",
      CellTags->"i:83"]},
  "(7.3.13)"->{
    Cell[46882441, 1154520, 1241, 36, 111, "NE3",
      CellTags->"(7.3.13)"]},
  "i:81"->{
    Cell[46884303, 1154577, 190, 6, 32, "NE3",
      CellTags->{"i:81", "(7.3.14)"}]},
  "(7.3.14)"->{
    Cell[46884303, 1154577, 190, 6, 32, "NE3",
      CellTags->{"i:81", "(7.3.14)"}]},
  "(7.3.15)"->{
    Cell[46885713, 1154619, 160, 5, 38, "NE3",
      CellTags->"(7.3.15)"]},
  "(7.3.16)"->{
    Cell[46886355, 1154640, 189, 6, 43, "NE3",
      CellTags->"(7.3.16)"]},
  "c:39"->{
    Cell[46887373, 1154671, 47, 1, 31, "Section",
      CellTags->"c:39"]},
  "(7.3.17)"->{
    Cell[46890571, 1154767, 154, 6, 35, "NE3",
      CellTags->"(7.3.17)"]},
  "Cell 7.90"->{
    Cell[46891028, 1154789, 1030, 21, 370, "Input",
      CellTags->"Cell 7.90"]},
  "Cell 7.91"->{
    Cell[46892154, 1154818, 200, 5, 85, "Input",
      CellTags->"Cell 7.91"]},
  "Cell 7.92"->{
    Cell[49312179, 1233003, 298, 6, 85, "Input",
      CellTags->"Cell 7.92"]},
  "c:40"->{
    Cell[49369638, 1234024, 65, 1, 30, "Subsubtitle",
      CellTags->"c:40"]},
  "i:82"->{
    Cell[49371418, 1234081, 1231, 36, 65, "Text",
      CellTags->"i:82"]},
  "(7.3.18)"->{
    Cell[49372652, 1234119, 1682, 46, 68, "NE3",
      CellTags->"(7.3.18)"]},
  "(7.3.19)"->{
    Cell[49378346, 1234313, 120, 2, 33, "NE3",
      CellTags->"(7.3.19)"]},
  "i:65"->{
    Cell[49383114, 1234466, 623, 13, 95, "Text",
      CellTags->"i:65"]},
  "(7.3.20)"->{
    Cell[49383837, 1234486, 649, 20, 41, "NE3",
      CellTags->"(7.3.20)"]},
  "(7.3.21)"->{
    Cell[49384602, 1234513, 675, 23, 29, "NE3",
      CellTags->"(7.3.21)"]},
  "i:64"->{
    Cell[49385280, 1234538, 536, 18, 44, "Text",
      CellTags->"i:64"]},
  "(7.3.22)"->{
    Cell[49385819, 1234558, 606, 21, 30, "NE3",
      CellTags->"(7.3.22)"]},
  "(7.3.23)"->{
    Cell[49387397, 1234614, 380, 12, 38, "NE3",
      CellTags->"(7.3.23)"]},
  "i:66"->{
    Cell[49387780, 1234628, 1480, 49, 62, "Text",
      CellTags->"i:66"]},
  "(7.3.24)"->{
    Cell[49389263, 1234679, 402, 10, 69, "NE3",
      CellTags->"(7.3.24)"]},
  "i:69"->{
    Cell[49389668, 1234691, 2160, 60, 133, "Text",
      CellTags->"i:69"]},
  "(7.3.25)"->{
    Cell[49392134, 1234765, 1643, 47, 32, "NE3",
      CellTags->"(7.3.25)"]},
  "i:84"->{
    Cell[49393780, 1234814, 1482, 43, 112, "Text",
      CellTags->"i:84"]},
  "Table 7.1"->{
    Cell[49395265, 1234859, 734, 26, 187, "Text",
      CellTags->"Table 7.1"]},
  "i:68"->{
    Cell[49396002, 1234887, 1418, 40, 129, "Text",
      CellTags->"i:68"]},
  "i:67"->{
    Cell[49397423, 1234929, 451, 13, 61, "Text",
      CellTags->"i:67"]},
  "Cell 7.93"->{
    Cell[49397877, 1234944, 7403, 150, 854, "Input",
      CellTags->"Cell 7.93"]},
  "i:72"->{
    Cell[49409964, 1235244, 1200, 38, 78, "Text",
      CellTags->"i:72"]},
  "i:70"->{
    Cell[49412219, 1235311, 1459, 47, 95, "Text",
      CellTags->"i:70"]},
  "i:71"->{
    Cell[49414109, 1235375, 1145, 30, 129, "Text",
      CellTags->"i:71"]},
  "Cell 7.94"->{
    Cell[49415257, 1235407, 788, 17, 219, "Input",
      CellTags->"Cell 7.94"]},
  "Cell 7.95"->{
    Cell[49418462, 1235506, 162, 4, 86, "Input",
      CellTags->"Cell 7.95"]},
  "i:92"->{
    Cell[95641330, 3015616, 1028, 30, 82, "Text",
      CellTags->"i:92"]},
  "Cell 7.96"->{
    Cell[95643637, 3015688, 418, 8, 181, "Input",
      CellTags->"Cell 7.96"]},
  "Cell 7.97"->{
    Cell[95644277, 3015707, 121, 3, 67, "Input",
      CellTags->"Cell 7.97"]},
  "Cell 7.98"->{
    Cell[95644790, 3015724, 202, 5, 67, "Input",
      CellTags->"Cell 7.98"]},
  "i:90"->{
    Cell[95646577, 3015780, 403, 14, 44, "Text",
      CellTags->"i:90"]},
  "Cell 7.99"->{
    Cell[95648210, 3015840, 244, 5, 105, "Input",
      CellTags->"Cell 7.99"]},
  "Cell 7.100"->{
    Cell[95648457, 3015847, 283, 6, 105, "Input",
      CellTags->"Cell 7.100"]},
  "Cell 7.101"->{
    Cell[95648743, 3015855, 117, 3, 67, "Input",
      CellTags->"Cell 7.101"]},
  "i:91"->{
    Cell[95649384, 3015878, 1145, 31, 95, "Text",
      CellTags->"i:91"]},
  "refs"->{
    Cell[95650578, 3015915, 60, 1, 40, "Subtitle",
      CellTags->{"refs", "c:41"}]},
  "c:41"->{
    Cell[95650578, 3015915, 60, 1, 40, "Subtitle",
      CellTags->{"refs", "c:41"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"c:1", 95695252, 3017314},
  {"i:1", 95695328, 3017317},
  {"c:3", 95695416, 3017320},
  {"i:15", 95695505, 3017323},
  {"c:4", 95695596, 3017326},
  {"(7.1.1)", 95695691, 3017329},
  {"(7.1.2)", 95695787, 3017332},
  {"(7.1.3)", 95695883, 3017335},
  {"i:2", 95695975, 3017338},
  {"i:3", 95696051, 3017341},
  {"(7.1.4)", 95696132, 3017344},
  {"(7.1.5)", 95696228, 3017347},
  {"(7.1.6)", 95696324, 3017350},
  {"(7.1.7)", 95696420, 3017353},
  {"(7.1.8)", 95696517, 3017356},
  {"(7.1.9)", 95696614, 3017359},
  {"c:5", 95696707, 3017362},
  {"(7.1.10)", 95696795, 3017365},
  {"(7.1.11)", 95696894, 3017368},
  {"(7.1.12)", 95696993, 3017371},
  {"(7.1.13)", 95697092, 3017374},
  {"c:6", 95697186, 3017377},
  {"(7.1.14)", 95697271, 3017380},
  {"(7.1.15)", 95697370, 3017383},
  {"i:78", 95697465, 3017386},
  {"Cell 7.1", 95697549, 3017389},
  {"Fig. 7.1", 95697637, 3017392},
  {"c:7", 95697725, 3017395},
  {"(7.1.16)", 95697812, 3017398},
  {"Fig. 7.2", 95697913, 3017401},
  {"(7.1.17)", 95698006, 3017404},
  {"Cell 7.2", 95698107, 3017407},
  {"c:8", 95698193, 3017410},
  {"i:4", 95698275, 3017413},
  {"(7.1.18)", 95698386, 3017416},
  {"(7.1.19)", 95698497, 3017419},
  {"(7.1.20)", 95698599, 3017422},
  {"i:5", 95698696, 3017425},
  {"Cell 7.3", 95698782, 3017428},
  {"Cell 7.4", 95698875, 3017431},
  {"Cell 7.5", 95698968, 3017434},
  {"c:9", 95699057, 3017437},
  {"i:20", 95699141, 3017440},
  {"(7.1.21)", 95699229, 3017443},
  {"i:19", 95699328, 3017446},
  {"i:6", 95699411, 3017449},
  {"i:7", 95699493, 3017452},
  {"Cell 7.6", 95699580, 3017455},
  {"(7.1.22)", 95699674, 3017458},
  {"i:8", 95699772, 3017461},
  {"Cell 7.7", 95699859, 3017464},
  {"i:9", 95699948, 3017467},
  {"(7.1.23)", 95700037, 3017470},
  {"(7.1.24)", 95700141, 3017473},
  {"(7.1.25)", 95700245, 3017476},
  {"(7.1.26)", 95700349, 3017479},
  {"Cell 7.8", 95700453, 3017482},
  {"Cell 7.9", 95700546, 3017485},
  {"Cell 7.10", 95700641, 3017488},
  {"Cell 7.11", 95700738, 3017491},
  {"(7.1.27)", 95700832, 3017494},
  {"Cell 7.12", 95700937, 3017497},
  {"i:10", 95701027, 3017500},
  {"Cell 7.13", 95701116, 3017503},
  {"Cell 7.14", 95701212, 3017506},
  {"Cell 7.15", 95701307, 3017509},
  {"Cell 7.16", 95701402, 3017512},
  {"Cell 7.17", 95701497, 3017515},
  {"i:11", 95701587, 3017518},
  {"Cell 7.18", 95701678, 3017521},
  {"Cell 7.19", 95701773, 3017524},
  {"i:12", 95701863, 3017527},
  {"(7.1.28)", 95701953, 3017530},
  {"i:13", 95702054, 3017533},
  {"Cell 7.20", 95702144, 3017536},
  {"Cell 7.21", 95702239, 3017539},
  {"Cell 7.22", 95702337, 3017542},
  {"Fig. 7.3", 95702432, 3017545},
  {"i:14", 95702524, 3017548},
  {"c:10", 95702625, 3017551},
  {"c:11", 95702726, 3017554},
  {"(7.1.29)", 95702817, 3017557},
  {"i:17", 95702918, 3017560},
  {"i:85", 95703006, 3017563},
  {"(7.1.30)", 95703121, 3017566},
  {"c:12", 95703232, 3017569},
  {"(7.1.31)", 95703323, 3017572},
  {"(7.1.32)", 95703428, 3017575},
  {"(7.1.33)", 95703533, 3017578},
  {"i:18", 95703634, 3017581},
  {"(7.1.34)", 95703749, 3017584},
  {"Fig. 7.4", 95703864, 3017587},
  {"Cell 7.23", 95703961, 3017590},
  {"Cell 7.24", 95704057, 3017593},
  {"i:87", 95704148, 3017596},
  {"Cell 7.25", 95704239, 3017599},
  {"Cell 7.26", 95704336, 3017602},
  {"i:16", 95704427, 3017605},
  {"c:13", 95704524, 3017608},
  {"(7.1.35)", 95704625, 3017611},
  {"(7.1.36)", 95704731, 3017614},
  {"(7.1.37)", 95704836, 3017617},
  {"(7.1.38)", 95704941, 3017620},
  {"(7.1.39)", 95705046, 3017623},
  {"Cell 7.27", 95705152, 3017626},
  {"Cell 7.28", 95705248, 3017629},
  {"(7.1.40)", 95705343, 3017632},
  {"(7.1.41)", 95705450, 3017635},
  {"c:14", 95705552, 3017638},
  {"i:21", 95705643, 3017641},
  {"(7.1.42)", 95705734, 3017644},
  {"i:22", 95705836, 3017647},
  {"i:23", 95705923, 3017650},
  {"(7.1.43)", 95706013, 3017653},
  {"i:24", 95706114, 3017656},
  {"c:15", 95706212, 3017659},
  {"c:16", 95706310, 3017662},
  {"(7.2.1)", 95706404, 3017665},
  {"Cell 7.29", 95706496, 3017668},
  {"(7.2.2)", 95706590, 3017671},
  {"(7.2.3)", 95706680, 3017674},
  {"i:25", 95706767, 3017677},
  {"(7.2.4)", 95706856, 3017680},
  {"i:26", 95706943, 3017683},
  {"c:17", 95707045, 3017686},
  {"(7.2.5)", 95707150, 3017689},
  {"(7.2.6)", 95707240, 3017692},
  {"Cell 7.30", 95707332, 3017695},
  {"Cell 7.31", 95707430, 3017698},
  {"(7.2.7)", 95707524, 3017701},
  {"(7.2.8)", 95707614, 3017704},
  {"Cell 7.32", 95707707, 3017707},
  {"(7.2.9)", 95707801, 3017710},
  {"Cell 7.33", 95707893, 3017713},
  {"i:27", 95707985, 3017716},
  {"(7.2.10)", 95708075, 3017719},
  {"(7.2.11)", 95708168, 3017722},
  {"(7.2.12)", 95708260, 3017725},
  {"i:28", 95708348, 3017728},
  {"Cell 7.34", 95708439, 3017731},
  {"(7.2.13)", 95708534, 3017734},
  {"i:29", 95708622, 3017737},
  {"Cell 7.35", 95708713, 3017740},
  {"Cell 7.36", 95708809, 3017743},
  {"(7.2.14)", 95708904, 3017746},
  {"(7.2.15)", 95708996, 3017749},
  {"Cell 7.37", 95709089, 3017752},
  {"Fig. 7.5", 95709186, 3017755},
  {"(7.2.16)", 95709282, 3017758},
  {"Fig. 7.6", 95709374, 3017761},
  {"i:30", 95709467, 3017764},
  {"Cell 7.38", 95709558, 3017767},
  {"Cell 7.39", 95709655, 3017770},
  {"(7.2.17)", 95709750, 3017773},
  {"(7.2.18)", 95709842, 3017776},
  {"(7.2.19)", 95709934, 3017779},
  {"i:31", 95710022, 3017782},
  {"i:73", 95710107, 3017785},
  {"c:18", 95710195, 3017788},
  {"c:19", 95710286, 3017791},
  {"i:74", 95710373, 3017794},
  {"(7.2.20)", 95710463, 3017797},
  {"(7.2.21)", 95710556, 3017800},
  {"(7.2.22)", 95710648, 3017803},
  {"(7.2.23)", 95710741, 3017806},
  {"(7.2.24)", 95710833, 3017809},
  {"Cell 7.40", 95710926, 3017812},
  {"i:53", 95711017, 3017815},
  {"Cell 7.41", 95711108, 3017818},
  {"i:44", 95711199, 3017821},
  {"c:20", 95711296, 3017824},
  {"Cell 7.42", 95711398, 3017827},
  {"Cell 7.43", 95711495, 3017830},
  {"(7.2.25)", 95711591, 3017833},
  {"Cell 7.44", 95711684, 3017836},
  {"Cell 7.45", 95711782, 3017839},
  {"Cell 7.46", 95711881, 3017842},
  {"c:21", 95711972, 3017845},
  {"Cell 7.47", 95712064, 3017848},
  {"Cell 7.48", 95712161, 3017851},
  {"Cell 7.49", 95712259, 3017854},
  {"i:45", 95712350, 3017857},
  {"c:22", 95712447, 3017860},
  {"Cell 7.50", 95712549, 3017863},
  {"Cell 7.51", 95712646, 3017866},
  {"Fig. 7.7", 95712743, 3017869},
  {"Fig. 7.8", 95712838, 3017872},
  {"i:46", 95712930, 3017875},
  {"c:23", 95713031, 3017878},
  {"c:24", 95713132, 3017881},
  {"i:47", 95713219, 3017884},
  {"(7.2.26)", 95713309, 3017887},
  {"(7.2.27)", 95713401, 3017890},
  {"(7.2.28)", 95713494, 3017893},
  {"i:48", 95713582, 3017896},
  {"Cell 7.52", 95713672, 3017899},
  {"c:25", 95713763, 3017902},
  {"i:75", 95713850, 3017905},
  {"(7.2.29)", 95713941, 3017908},
  {"Cell 7.53", 95714036, 3017911},
  {"(7.2.30)", 95714131, 3017914},
  {"Cell 7.54", 95714226, 3017917},
  {"Cell 7.55", 95714323, 3017920},
  {"(7.2.31)", 95714418, 3017923},
  {"i:79", 95714507, 3017926},
  {"Cell 7.56", 95714599, 3017929},
  {"Cell 7.57", 95714695, 3017932},
  {"Cell 7.58", 95714791, 3017935},
  {"Cell 7.59", 95714887, 3017938},
  {"Cell 7.60", 95714983, 3017941},
  {"Cell 7.61", 95715080, 3017944},
  {"Cell 7.62", 95715177, 3017947},
  {"Cell 7.63", 95715273, 3017950},
  {"Cell 7.64", 95715370, 3017953},
  {"Cell 7.65", 95715466, 3017956},
  {"c:26", 95715558, 3017959},
  {"i:32", 95715649, 3017962},
  {"(7.2.32)", 95715739, 3017965},
  {"i:33", 95715827, 3017968},
  {"i:34", 95715913, 3017971},
  {"(7.2.33)", 95716002, 3017974},
  {"i:35", 95716091, 3017977},
  {"i:49", 95716178, 3017980},
  {"i:36", 95716265, 3017983},
  {"(7.2.34)", 95716367, 3017986},
  {"i:50", 95716465, 3017989},
  {"i:41", 95716551, 3017992},
  {"i:37", 95716638, 3017995},
  {"(7.2.35)", 95716740, 3017998},
  {"i:38", 95716838, 3018001},
  {"(7.2.36)", 95716940, 3018004},
  {"i:77", 95717038, 3018007},
  {"i:40", 95717124, 3018010},
  {"(7.2.37)", 95717226, 3018013},
  {"i:39", 95717324, 3018016},
  {"i:42", 95717410, 3018019},
  {"(7.2.38)", 95717500, 3018022},
  {"i:43", 95717588, 3018025},
  {"i:51", 95717673, 3018028},
  {"i:86", 95717759, 3018031},
  {"(7.2.39)", 95717848, 3018034},
  {"i:52", 95717938, 3018037},
  {"(7.2.40)", 95718029, 3018040},
  {"i:55", 95718118, 3018043},
  {"c:27", 95718217, 3018046},
  {"c:28", 95718316, 3018049},
  {"i:76", 95718407, 3018052},
  {"Fig. 7.9", 95718499, 3018055},
  {"i:54", 95718591, 3018058},
  {"(7.3.1)", 95718692, 3018061},
  {"(7.3.2)", 95718793, 3018064},
  {"c:29", 95718880, 3018067},
  {"Fig. 7.10", 95718976, 3018070},
  {"i:89", 95719070, 3018073},
  {"i:61", 95719157, 3018076},
  {"c:30", 95719258, 3018079},
  {"Cell 7.66", 95719364, 3018082},
  {"i:60", 95719458, 3018085},
  {"c:31", 95719546, 3018088},
  {"c:32", 95719637, 3018091},
  {"Cell 7.67", 95719729, 3018094},
  {"i:88", 95719821, 3018097},
  {"i:58", 95719907, 3018100},
  {"(7.3.3)", 95719996, 3018103},
  {"i:59", 95720085, 3018106},
  {"(7.3.4)", 95720174, 3018109},
  {"(7.3.5)", 95720265, 3018112},
  {"(7.3.6)", 95720356, 3018115},
  {"Fig. 7.11", 95720450, 3018118},
  {"(7.3.7)", 95720545, 3018121},
  {"Cell 7.68", 95720640, 3018124},
  {"Cell 7.69", 95720739, 3018127},
  {"Cell 7.70", 95720838, 3018130},
  {"i:62", 95720931, 3018133},
  {"c:33", 95721028, 3018136},
  {"(7.3.8)", 95721128, 3018139},
  {"Cell 7.71", 95721221, 3018142},
  {"Cell 7.72", 95721320, 3018145},
  {"Cell 7.73", 95721417, 3018148},
  {"i:63", 95721510, 3018151},
  {"c:34", 95721608, 3018154},
  {"Cell 7.74", 95721711, 3018157},
  {"Cell 7.75", 95721809, 3018160},
  {"Cell 7.76", 95721905, 3018163},
  {"Cell 7.77", 95722004, 3018166},
  {"c:35", 95722097, 3018169},
  {"c:36", 95722188, 3018172},
  {"Cell 7.78", 95722280, 3018175},
  {"Cell 7.79", 95722378, 3018178},
  {"Cell 7.80", 95722474, 3018181},
  {"Cell 7.81", 95722571, 3018184},
  {"(7.3.9)", 95722667, 3018187},
  {"(7.3.10)", 95722758, 3018190},
  {"Cell 7.82", 95722852, 3018193},
  {"Cell 7.83", 95722951, 3018196},
  {"(7.3.11)", 95723048, 3018199},
  {"(7.3.12)", 95723141, 3018202},
  {"i:56", 95723231, 3018205},
  {"c:37", 95723328, 3018208},
  {"i:80", 95723425, 3018211},
  {"Cell 7.84", 95723516, 3018214},
  {"Cell 7.85", 95723614, 3018217},
  {"Cell 7.86", 95723710, 3018220},
  {"i:57", 95723802, 3018223},
  {"c:38", 95723900, 3018226},
  {"Cell 7.87", 95724003, 3018229},
  {"Cell 7.88", 95724102, 3018232},
  {"Cell 7.89", 95724199, 3018235},
  {"i:83", 95724292, 3018238},
  {"(7.3.13)", 95724383, 3018241},
  {"i:81", 95724475, 3018244},
  {"(7.3.14)", 95724578, 3018247},
  {"(7.3.15)", 95724681, 3018250},
  {"(7.3.16)", 95724774, 3018253},
  {"c:39", 95724863, 3018256},
  {"(7.3.17)", 95724955, 3018259},
  {"Cell 7.90", 95725049, 3018262},
  {"Cell 7.91", 95725149, 3018265},
  {"Cell 7.92", 95725246, 3018268},
  {"c:40", 95725338, 3018271},
  {"i:82", 95725430, 3018274},
  {"(7.3.18)", 95725522, 3018277},
  {"(7.3.19)", 95725617, 3018280},
  {"i:65", 95725706, 3018283},
  {"(7.3.20)", 95725797, 3018286},
  {"(7.3.21)", 95725891, 3018289},
  {"i:64", 95725981, 3018292},
  {"(7.3.22)", 95726072, 3018295},
  {"(7.3.23)", 95726166, 3018298},
  {"i:66", 95726256, 3018301},
  {"(7.3.24)", 95726348, 3018304},
  {"i:69", 95726438, 3018307},
  {"(7.3.25)", 95726531, 3018310},
  {"i:84", 95726622, 3018313},
  {"Table 7.1", 95726716, 3018316},
  {"i:68", 95726809, 3018319},
  {"i:67", 95726898, 3018322},
  {"Cell 7.93", 95726990, 3018325},
  {"i:72", 95727086, 3018328},
  {"i:70", 95727174, 3018331},
  {"i:71", 95727262, 3018334},
  {"Cell 7.94", 95727356, 3018337},
  {"Cell 7.95", 95727455, 3018340},
  {"i:92", 95727547, 3018343},
  {"Cell 7.96", 95727640, 3018346},
  {"Cell 7.97", 95727738, 3018349},
  {"Cell 7.98", 95727835, 3018352},
  {"i:90", 95727927, 3018355},
  {"Cell 7.99", 95728019, 3018358},
  {"Cell 7.100", 95728118, 3018361},
  {"Cell 7.101", 95728218, 3018364},
  {"i:91", 95728311, 3018367},
  {"refs", 95728399, 3018370},
  {"c:41", 95728498, 3018373}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 79, 1, 111, "Title",
  CellTags->"c:1"],
Cell[1809, 55, 16, 0, 27, "Text"],
Cell[1828, 57, 598, 9, 95, "Text"],
Cell[2429, 68, 474, 9, 61, "Text"],
Cell[2906, 79, 169, 4, 44, "Text"],

Cell[CellGroupData[{
Cell[3100, 87, 102, 1, 39, "Subtitle",
  CellTags->{"i:1", "c:3"}],
Cell[3205, 90, 17, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[3247, 94, 73, 1, 41, "Subsubtitle",
  CellTags->{"i:15", "c:4"}],
Cell[3323, 97, 141, 4, 25, "Text"],
Cell[3467, 103, 213, 6, 36, "NumberedEquation",
  CellTags->"(7.1.1)"],
Cell[3683, 111, 107, 3, 25, "Text"],
Cell[3793, 116, 140, 5, 26, "NumberedEquation",
  CellTags->"(7.1.2)"],
Cell[3936, 123, 467, 10, 60, "Text"],
Cell[4406, 135, 663, 14, 75, "Text"],
Cell[5072, 151, 688, 17, 75, "Text"],
Cell[5763, 170, 632, 15, 75, "Text"],
Cell[6398, 187, 200, 8, 26, "NumberedEquation",
  CellTags->"(7.1.3)"],
Cell[6601, 197, 221, 8, 25, "Text",
  CellTags->"i:2"],
Cell[6825, 207, 457, 12, 60, "Text"],
Cell[7285, 221, 248, 6, 36, "UNNEQ"],
Cell[7536, 229, 650, 22, 41, "Text",
  CellTags->"i:3"],
Cell[8189, 253, 296, 7, 36, "NumberedEquation",
  CellTags->"(7.1.4)"],
Cell[8488, 262, 166, 5, 25, "Text"],
Cell[8657, 269, 173, 3, 36, "NumberedEquation",
  CellTags->"(7.1.5)"],
Cell[8833, 274, 402, 10, 41, "Text"],
Cell[9238, 286, 173, 6, 35, "NumberedEquation",
  CellTags->"(7.1.6)"],
Cell[9414, 294, 508, 18, 41, "Text"],
Cell[9925, 314, 377, 10, 41, "Text"],
Cell[10305, 326, 213, 6, 36, "NumberedEquation",
  CellTags->"(7.1.7)"],
Cell[10521, 334, 771, 23, 75, "Text"],
Cell[11295, 359, 1059, 38, 60, "Text"],
Cell[12357, 399, 264, 7, 40, "NumberedEquation",
  CellTags->"(7.1.8)"],
Cell[12624, 408, 397, 12, 41, "Text"],
Cell[13024, 422, 192, 3, 36, "NumberedEquation",
  CellTags->"(7.1.9)"],
Cell[13219, 427, 363, 10, 41, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[13619, 442, 60, 1, 30, "Subsubtitle",
  CellTags->"c:5"],
Cell[13682, 445, 790, 25, 60, "Text"],
Cell[14475, 472, 166, 3, 25, "NumberedEquation",
  CellTags->"(7.1.10)"],
Cell[14644, 477, 174, 3, 25, "NumberedEquation",
  CellTags->"(7.1.11)"],
Cell[14821, 482, 469, 17, 41, "Text"],
Cell[15293, 501, 929, 30, 60, "Text"],
Cell[16225, 533, 247, 7, 30, "NumberedEquation",
  CellTags->"(7.1.12)"],
Cell[16475, 542, 545, 21, 45, "Text"],
Cell[17023, 565, 530, 20, 41, "Text"],
Cell[17556, 587, 334, 9, 30, "NumberedEquation",
  CellTags->"(7.1.13)"],
Cell[17893, 598, 396, 12, 41, "Text"],

Cell[CellGroupData[{
Cell[18314, 614, 190, 8, 40, "Section",
  CellTags->"c:6"],
Cell[18507, 624, 149, 6, 25, "Text"],
Cell[18659, 632, 191, 6, 36, "NumberedEquation",
  CellTags->"(7.1.14)"],
Cell[18853, 640, 428, 12, 41, "Text"],
Cell[19284, 654, 191, 3, 45, "UNNEQ"],
Cell[19478, 659, 589, 19, 41, "Text"],
Cell[20070, 680, 792, 26, 60, "Text"],
Cell[20865, 708, 226, 6, 26, "NumberedEquation",
  CellTags->"(7.1.15)"],
Cell[21094, 716, 325, 12, 25, "Text"],
Cell[21422, 730, 1300, 39, 126, "Text"],
Cell[22725, 771, 393, 12, 41, "Text"],
Cell[23121, 785, 198, 5, 26, "UNNEQ"],
Cell[23322, 792, 452, 13, 41, "Text",
  CellTags->"i:78"],

Cell[CellGroupData[{
Cell[23799, 809, 202, 5, 85, "Input",
  CellTags->"Cell 7.1"],
Cell[24004, 816, 38, 1, 45, "Output"]
}, Open  ]],
Cell[24057, 820, 864, 21, 95, "Text"],
Cell[24924, 843, 88372, 4083, 430, 38393, 3462, "GraphicsData", "PostScript", \
"Picture"],
Cell[113299, 4928, 374, 13, 15, "Caption",
  CellTags->"Fig. 7.1"]
}, Closed]],

Cell[CellGroupData[{
Cell[113710, 4946, 196, 9, 30, "Section",
  CellTags->"c:7"],
Cell[113909, 4957, 267, 10, 25, "Text"],
Cell[114179, 4969, 203, 3, 45, "UNNEQ"],
Cell[114385, 4974, 269, 8, 25, "Text"],
Cell[114657, 4984, 179, 6, 30, "NumberedEquation",
  CellTags->"(7.1.16)"],
Cell[114839, 4992, 157, 6, 25, "Text"],
Cell[114999, 5000, 77312, 3369, 355, 31711, 2802, "GraphicsData", \
"PostScript", "Picture"],
Cell[192314, 8371, 477, 17, 26, "Caption",
  CellTags->"Fig. 7.2"],
Cell[192794, 8390, 343, 9, 30, "Text"],
Cell[193140, 8401, 221, 7, 40, "NumberedEquation",
  CellTags->"(7.1.17)"],
Cell[193364, 8410, 642, 21, 46, "Text"],
Cell[194009, 8433, 303, 8, 40, "UNNEQ"],
Cell[194315, 8443, 368, 13, 31, "Text"],

Cell[CellGroupData[{
Cell[194708, 8460, 303, 7, 110, "Input",
  CellTags->"Cell 7.2"],

Cell[CellGroupData[{
Cell[195036, 8471, 34102, 1309, 230, 12269, 1036, "GraphicsData", \
"PostScript", "Graphics"],
Cell[229141, 9782, 33957, 1260, 70, 11674, 981, "GraphicsData", "PostScript", \
"Graphics"],
Cell[263101, 11044, 33174, 1168, 70, 10668, 886, "GraphicsData", \
"PostScript", "Graphics"],
Cell[296278, 12214, 32262, 1043, 70, 9258, 755, "GraphicsData", "PostScript", \
"Graphics"],
Cell[328543, 13259, 30766, 894, 70, 7628, 604, "GraphicsData", "PostScript", \
"Graphics"],
Cell[359312, 14155, 29697, 773, 70, 6268, 480, "GraphicsData", "PostScript", \
"Graphics"],
Cell[389012, 14930, 28974, 698, 70, 5435, 403, "GraphicsData", "PostScript", \
"Graphics"],
Cell[417989, 15630, 28639, 653, 70, 4955, 357, "GraphicsData", "PostScript", \
"Graphics"],
Cell[446631, 16285, 28411, 620, 70, 4500, 321, "GraphicsData", "PostScript", \
"Graphics"],
Cell[475045, 16907, 28236, 609, 70, 4325, 310, "GraphicsData", "PostScript", \
"Graphics"],
Cell[503284, 17518, 27926, 591, 70, 4043, 292, "GraphicsData", "PostScript", \
"Graphics"],
Cell[531213, 18111, 26881, 576, 70, 4015, 290, "GraphicsData", "PostScript", \
"Graphics"],
Cell[558097, 18689, 25225, 553, 70, 3959, 287, "GraphicsData", "PostScript", \
"Graphics"],
Cell[583325, 19244, 23537, 533, 70, 3980, 288, "GraphicsData", "PostScript", \
"Graphics"],
Cell[606865, 19779, 22452, 521, 70, 4000, 289, "GraphicsData", "PostScript", \
"Graphics"],
Cell[629320, 20302, 21473, 494, 70, 3714, 271, "GraphicsData", "PostScript", \
"Graphics"],
Cell[650796, 20798, 20628, 474, 70, 3525, 259, "GraphicsData", "PostScript", \
"Graphics"],
Cell[671427, 21274, 19946, 466, 70, 3523, 259, "GraphicsData", "PostScript", \
"Graphics"],
Cell[691376, 21742, 19452, 460, 70, 3523, 259, "GraphicsData", "PostScript", \
"Graphics"],
Cell[710831, 22204, 19171, 456, 70, 3522, 259, "GraphicsData", "PostScript", \
"Graphics"],
Cell[730005, 22662, 18928, 453, 70, 3522, 259, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Open  ]],
Cell[748960, 23119, 489, 13, 60, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[749486, 23137, 60, 1, 30, "Section",
  CellTags->"c:8"],
Cell[749549, 23140, 207, 6, 25, "Text"],
Cell[749759, 23148, 287, 7, 40, "NumberedEquation",
  CellTags->{"i:4", "(7.1.18)"}],
Cell[750049, 23157, 861, 30, 60, "Text"],
Cell[750913, 23189, 156, 5, 36, "NumberedEquation",
  CellTags->"(7.1.19)"],
Cell[751072, 23196, 702, 19, 60, "Text"],
Cell[751777, 23217, 205, 6, 25, "Text"],
Cell[751985, 23225, 309, 9, 45, "NumberedEquation",
  CellTags->"(7.1.20)"],
Cell[752297, 23236, 779, 24, 76, "Text"],
Cell[753079, 23262, 323, 10, 75, "Text",
  CellTags->"i:5"],
Cell[753405, 23274, 406, 11, 45, "Text"],
Cell[753814, 23287, 270, 9, 25, "Text"],
Cell[754087, 23298, 479, 11, 140, "Input",
  CellTags->"Cell 7.3"],
Cell[754569, 23311, 346, 13, 25, "Text"],

Cell[CellGroupData[{
Cell[754940, 23328, 428, 10, 140, "Input",
  CellTags->"Cell 7.4"],
Cell[755371, 23340, 251125, 10720, 370, 146362, 9423, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1006511, 34063, 272, 5, 60, "Text"],
Cell[1006786, 34070, 358, 9, 60, "Text"],

Cell[CellGroupData[{
Cell[1007169, 34083, 456, 10, 121, "Input",
  CellTags->"Cell 7.5"],

Cell[CellGroupData[{
Cell[1007650, 34097, 27354, 718, 370, 5312, 442, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1035007, 34817, 27055, 714, 70, 5333, 442, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1062065, 35533, 27451, 719, 70, 5332, 442, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1089519, 36254, 28348, 730, 70, 5330, 442, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1117870, 36986, 29208, 741, 70, 5331, 442, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1147081, 37729, 29724, 747, 70, 5329, 442, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1176808, 38478, 29743, 747, 70, 5340, 442, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1206554, 39227, 29809, 748, 70, 5329, 442, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1236366, 39977, 29675, 747, 70, 5328, 442, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1266044, 40726, 29763, 748, 70, 5335, 442, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1295810, 41476, 29970, 750, 70, 5336, 442, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1325783, 42228, 30215, 753, 70, 5338, 442, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1356001, 42983, 29967, 750, 70, 5329, 442, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1385971, 43735, 29392, 743, 70, 5337, 442, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1415366, 44480, 28762, 735, 70, 5343, 442, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1444131, 45217, 28526, 732, 70, 5334, 442, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1472660, 45951, 27889, 724, 70, 5333, 442, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1500552, 46677, 27281, 717, 70, 5332, 442, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1527836, 47396, 28268, 729, 70, 5331, 442, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1556107, 48127, 31959, 775, 70, 5328, 442, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1588069, 48904, 30435, 740, 70, 4938, 421, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1618507, 49646, 30180, 725, 70, 4752, 407, "GraphicsData", "PostScript", 
  "Graphics"],
Cell[1648690, 50373, 30587, 730, 70, 4750, 407, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1679280, 51105, 33592, 795, 70, 5337, 442, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1712875, 51902, 37732, 846, 70, 5334, 442, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1750610, 52750, 36339, 821, 70, 5083, 431, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Open  ]],
Cell[1786976, 53575, 347, 6, 55, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[1787360, 53586, 85, 1, 30, "Section",
  CellTags->"c:9"],
Cell[1787448, 53589, 943, 30, 60, "Text",
  CellTags->"i:20"],
Cell[1788394, 53621, 232, 6, 40, "NumberedEquation",
  CellTags->"(7.1.21)"],
Cell[1788629, 53629, 201, 5, 25, "Text"],
Cell[1788833, 53636, 231, 7, 70, "UNNEQ",
  CellTags->"i:19"],
Cell[1789067, 53645, 186, 6, 25, "Text"],
Cell[1789256, 53653, 991, 24, 95, "Text",
  CellTags->"i:6"],
Cell[1790250, 53679, 690, 24, 60, "Text",
  CellTags->"i:7"],
Cell[1790943, 53705, 989, 30, 95, "Text"],

Cell[CellGroupData[{
Cell[1791957, 53739, 933, 21, 311, "Input",
  CellTags->"Cell 7.6"],
Cell[1792893, 53762, 100155, 4572, 230, 64706, 4130, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1893063, 58337, 758, 17, 95, "Text"],
Cell[1893824, 58356, 142, 3, 25, "NumberedEquation",
  CellTags->"(7.1.22)"],
Cell[1893969, 58361, 627, 14, 95, "Text",
  CellTags->"i:8"],
Cell[1894599, 58377, 445, 13, 41, "Text"],

Cell[CellGroupData[{
Cell[1895069, 58394, 467, 11, 140, "Input",
  CellTags->"Cell 7.7"],

Cell[CellGroupData[{
Cell[1895561, 58409, 47198, 1305, 370, 14595, 898, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1942762, 59716, 46886, 1301, 70, 14591, 898, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1989651, 61019, 46943, 1302, 70, 14579, 898, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2036597, 62323, 46349, 1289, 70, 14447, 891, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2082949, 63614, 45402, 1273, 70, 14318, 885, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2128354, 64889, 47067, 1299, 70, 14489, 893, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2175424, 66190, 47376, 1302, 70, 14470, 892, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2222803, 67494, 46509, 1296, 70, 14571, 898, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2269315, 68792, 47019, 1303, 70, 14570, 898, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2316337, 70097, 46746, 1299, 70, 14569, 898, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2363086, 71398, 46866, 1297, 70, 14478, 893, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2409955, 72697, 46432, 1285, 70, 14320, 885, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2456390, 73984, 46990, 1298, 70, 14489, 893, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2503383, 75284, 47012, 1294, 70, 14385, 887, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2550398, 76580, 46807, 1300, 70, 14565, 898, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2597208, 77882, 46924, 1301, 70, 14581, 898, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2644135, 79185, 46560, 1298, 70, 14573, 898, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2690698, 80485, 46759, 1298, 70, 14538, 896, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2737460, 81785, 46716, 1291, 70, 14361, 887, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2784179, 83078, 46017, 1283, 70, 14387, 888, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2830199, 84363, 47212, 1300, 70, 14440, 891, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2877414, 85665, 47069, 1301, 70, 14507, 894, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2924486, 86968, 47521, 1309, 70, 14579, 898, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2972010, 88279, 47586, 1310, 70, 14579, 898, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3019599, 89591, 47072, 1301, 70, 14523, 895, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3066674, 90894, 46520, 1291, 70, 14416, 890, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3113197, 92187, 46674, 1293, 70, 14400, 890, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3159874, 93482, 46955, 1296, 70, 14385, 889, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3206832, 94780, 46959, 1299, 70, 14491, 894, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3253794, 96081, 47798, 1313, 70, 14568, 898, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3301595, 97396, 46572, 1298, 70, 14569, 898, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3348170, 98696, 46907, 1299, 70, 14479, 894, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3395080, 99997, 47432, 1305, 70, 14473, 893, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3442515, 101304, 46825, 1294, 70, 14405, 889, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3489343, 102600, 47094, 1296, 70, 14383, 888, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3536440, 103898, 47170, 1301, 70, 14471, 893, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3583613, 105201, 47833, 1312, 70, 14542, 896, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3631449, 106515, 47675, 1311, 70, 14571, 898, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3679127, 107828, 47581, 1308, 70, 14525, 895, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3726711, 109138, 47394, 1304, 70, 14472, 893, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3774108, 110444, 47374, 1304, 70, 14464, 893, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3821485, 111750, 46982, 1296, 70, 14396, 889, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3868470, 113048, 47199, 1301, 70, 14463, 892, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3915672, 114351, 47349, 1303, 70, 14488, 893, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3963024, 115656, 47431, 1308, 70, 14558, 898, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4010458, 116966, 47181, 1302, 70, 14498, 894, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4057642, 118270, 47233, 1303, 70, 14481, 894, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4104878, 119575, 47349, 1301, 70, 14443, 890, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4152230, 120878, 47543, 1307, 70, 14532, 895, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4199776, 122187, 47790, 1309, 70, 14491, 893, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4247569, 123498, 47923, 1314, 70, 14547, 897, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4295495, 124814, 47790, 1309, 70, 14467, 893, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4343288, 126125, 47779, 1310, 70, 14492, 894, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4391070, 127437, 47647, 1307, 70, 14474, 893, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4438720, 128746, 47670, 1307, 70, 14456, 892, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4486393, 130055, 47784, 1309, 70, 14477, 893, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4534180, 131366, 47573, 1304, 70, 14432, 890, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4581756, 132672, 47664, 1309, 70, 14499, 895, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4629423, 133983, 47739, 1308, 70, 14465, 893, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4677165, 135293, 47594, 1308, 70, 14506, 895, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4724762, 136603, 47759, 1309, 70, 14472, 893, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4772524, 137914, 47504, 1302, 70, 14404, 889, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4820031, 139218, 47715, 1309, 70, 14489, 894, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4867749, 140529, 47613, 1307, 70, 14456, 893, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4915365, 141838, 47663, 1305, 70, 14425, 890, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4963031, 143145, 47931, 1312, 70, 14507, 895, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5010965, 144459, 48043, 1312, 70, 14489, 893, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5059011, 145773, 47894, 1309, 70, 14466, 892, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5106908, 147084, 47776, 1307, 70, 14457, 891, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5154687, 148393, 47939, 1312, 70, 14531, 895, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5202629, 149707, 48169, 1315, 70, 14522, 895, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5250801, 151024, 47813, 1309, 70, 14445, 892, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5298617, 152335, 47909, 1314, 70, 14582, 898, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5346529, 153651, 47278, 1302, 70, 14477, 892, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5393810, 154955, 48191, 1315, 70, 14524, 895, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5442004, 156272, 47575, 1304, 70, 14438, 890, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5489582, 157578, 47874, 1310, 70, 14470, 893, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5537459, 158890, 48151, 1312, 70, 14468, 892, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5585613, 160204, 47956, 1312, 70, 14528, 895, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5633572, 161518, 48322, 1315, 70, 14481, 893, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5681897, 162835, 48102, 1311, 70, 14431, 891, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5730002, 164148, 47738, 1309, 70, 14500, 894, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5777743, 165459, 48118, 1311, 70, 14451, 891, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5825864, 166772, 48309, 1315, 70, 14476, 893, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5874176, 168089, 48044, 1309, 70, 14405, 889, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5922223, 169400, 47793, 1310, 70, 14535, 895, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5970019, 170712, 48425, 1313, 70, 14377, 888, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6018447, 172027, 47994, 1312, 70, 14464, 893, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6066444, 173341, 47970, 1311, 70, 14465, 893, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6114417, 174654, 47894, 1310, 70, 14470, 893, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6162314, 175966, 48186, 1315, 70, 14527, 895, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6210503, 177283, 47959, 1311, 70, 14494, 893, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6258465, 178596, 48751, 1323, 70, 14517, 896, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6307219, 179921, 48178, 1313, 70, 14458, 892, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6355400, 181236, 47802, 1309, 70, 14475, 893, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6403205, 182547, 48470, 1317, 70, 14487, 893, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6451678, 183866, 48131, 1314, 70, 14496, 894, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6499812, 185182, 48531, 1320, 70, 14540, 896, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6548346, 186504, 48511, 1318, 70, 14508, 894, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6596860, 187824, 48471, 1318, 70, 14500, 894, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6645334, 189144, 48720, 1322, 70, 14530, 895, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6694057, 190468, 47915, 1310, 70, 14487, 893, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6741975, 191780, 48416, 1316, 70, 14453, 892, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6790394, 193098, 48096, 1313, 70, 14494, 894, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6838493, 194413, 48080, 1314, 70, 14514, 895, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6886576, 195729, 48361, 1317, 70, 14503, 894, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6934940, 197048, 48646, 1317, 70, 14424, 890, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6983589, 198367, 48636, 1323, 70, 14564, 898, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7032228, 199692, 48596, 1316, 70, 14427, 890, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7080827, 201010, 48946, 1323, 70, 14485, 893, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7129776, 202335, 48035, 1312, 70, 14481, 893, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7177814, 203649, 48472, 1318, 70, 14473, 894, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7226289, 204969, 48531, 1320, 70, 14519, 895, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7274823, 206291, 48420, 1316, 70, 14465, 892, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7323246, 207609, 48416, 1318, 70, 14514, 895, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7371665, 208929, 48328, 1312, 70, 14385, 888, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7419996, 210243, 48390, 1317, 70, 14496, 894, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7468389, 211562, 48104, 1313, 70, 14481, 893, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7516496, 212877, 48700, 1322, 70, 14510, 895, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7565199, 214201, 48639, 1322, 70, 14542, 896, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7613841, 215525, 48336, 1317, 70, 14474, 894, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7662180, 216844, 48252, 1315, 70, 14504, 894, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7710435, 218161, 47807, 1307, 70, 14456, 891, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7758245, 219470, 48250, 1314, 70, 14453, 892, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7806498, 220786, 48182, 1314, 70, 14482, 893, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7854683, 222102, 48549, 1318, 70, 14493, 893, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[7903259, 223424, 1577, 47, 95, "Text",
  CellTags->"i:9"],
Cell[7904839, 223473, 225, 6, 41, "NumberedEquation",
  CellTags->"(7.1.23)"],
Cell[7905067, 223481, 1032, 32, 80, "Text"],
Cell[7906102, 223515, 318, 9, 41, "NumberedEquation",
  CellTags->"(7.1.24)"],
Cell[7906423, 223526, 58, 0, 25, "Text"],
Cell[7906484, 223528, 138, 5, 30, "NumberedEquation",
  CellTags->"(7.1.25)"],
Cell[7906625, 223535, 425, 8, 65, "Text"],
Cell[7907053, 223545, 1282, 37, 100, "Text"],
Cell[7908338, 223584, 312, 8, 45, "NumberedEquation",
  CellTags->"(7.1.26)"],
Cell[7908653, 223594, 731, 17, 75, "Text"],
Cell[7909387, 223613, 368, 11, 41, "Text"],
Cell[7909758, 223626, 239, 6, 85, "Input",
  CellTags->"Cell 7.8"],
Cell[7910000, 223634, 377, 12, 45, "Text"],
Cell[7910380, 223648, 244, 5, 115, "Input",
  CellTags->"Cell 7.9"],
Cell[7910627, 223655, 393, 14, 25, "Text"],
Cell[7911023, 223671, 393, 10, 180, "Input",
  CellTags->"Cell 7.10"],
Cell[7911419, 223683, 182, 6, 25, "Text"],

Cell[CellGroupData[{
Cell[7911626, 223693, 240, 6, 85, "Input",
  CellTags->"Cell 7.11"],
Cell[7911869, 223701, 31966, 691, 230, 6648, 374, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[7943850, 224395, 300, 11, 41, "Text"],
Cell[7944153, 224408, 339, 9, 41, "Text"],
Cell[7944495, 224419, 181, 5, 30, "UNNEQ"],
Cell[7944679, 224426, 783, 25, 60, "Text"],
Cell[7945465, 224453, 278, 7, 45, "UNNEQ"],
Cell[7945746, 224462, 216, 6, 25, "Text"],
Cell[7945965, 224470, 190, 6, 30, "UNNEQ"],
Cell[7946158, 224478, 22, 0, 25, "Text"],
Cell[7946183, 224480, 244, 6, 45, "UNNEQ"],
Cell[7946430, 224488, 68, 0, 25, "Text"],
Cell[7946501, 224490, 243, 8, 35, "NumberedEquation",
  CellTags->"(7.1.27)"],
Cell[7946747, 224500, 470, 15, 41, "Text"],
Cell[7947220, 224517, 462, 14, 45, "Text"],
Cell[7947685, 224533, 210, 6, 85, "Input",
  CellTags->"Cell 7.12"],
Cell[7947898, 224541, 343, 8, 41, "Text",
  CellTags->"i:10"],
Cell[7948244, 224551, 316, 7, 140, "Input",
  CellTags->"Cell 7.13"],
Cell[7948563, 224560, 168, 6, 25, "Text"],

Cell[CellGroupData[{
Cell[7948756, 224570, 225, 5, 65, "Input",
  CellTags->"Cell 7.14"],
Cell[7948984, 224577, 24010, 564, 230, 6033, 338, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[7973009, 225144, 184, 6, 25, "Text"],
Cell[7973196, 225152, 202, 5, 85, "Input",
  CellTags->"Cell 7.15"],
Cell[7973401, 225159, 478, 16, 45, "Text"],
Cell[7973882, 225177, 250, 6, 85, "Input",
  CellTags->"Cell 7.16"],
Cell[7974135, 225185, 289, 8, 41, "Text"],

Cell[CellGroupData[{
Cell[7974449, 225197, 298, 6, 85, "Input",
  CellTags->"Cell 7.17"],
Cell[7974750, 225205, 310674, 5831, 345, 131261, 3612, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[8285439, 231039, 258, 7, 41, "Text"],
Cell[8285700, 231048, 1110, 33, 96, "Text",
  CellTags->"i:11"],
Cell[8286813, 231083, 171, 4, 41, "Text"],
Cell[8286987, 231089, 169, 4, 65, "Input",
  CellTags->"Cell 7.18"],
Cell[8287159, 231095, 163, 6, 25, "Text"],

Cell[CellGroupData[{
Cell[8287347, 231105, 178, 5, 65, "Input",
  CellTags->"Cell 7.19"],

Cell[CellGroupData[{
Cell[8287550, 231114, 42845, 1154, 230, 13254, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8330398, 232270, 42788, 1153, 70, 13242, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8373189, 233425, 42526, 1150, 70, 13279, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8415718, 234577, 41264, 1134, 70, 13253, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8456985, 235713, 41537, 1138, 70, 13262, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8498525, 236853, 42404, 1148, 70, 13263, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8540932, 238003, 42660, 1152, 70, 13247, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8583595, 239157, 42273, 1147, 70, 13265, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8625871, 240306, 42654, 1151, 70, 13266, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8668528, 241459, 42239, 1146, 70, 13264, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8710770, 242607, 41975, 1143, 70, 13267, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8752748, 243752, 41849, 1142, 70, 13254, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8794600, 244896, 42190, 1146, 70, 13259, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8836793, 246044, 42650, 1151, 70, 13258, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8879446, 247197, 42481, 1149, 70, 13267, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8921930, 248348, 42174, 1146, 70, 13263, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8964107, 249496, 42812, 1153, 70, 13266, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9006922, 250651, 42164, 1145, 70, 13262, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9049089, 251798, 41956, 1143, 70, 13268, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9091048, 252943, 42410, 1148, 70, 13269, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9133461, 254093, 42650, 1151, 70, 13266, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9176114, 255246, 42722, 1152, 70, 13269, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9218839, 256400, 42407, 1148, 70, 13278, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9261249, 257550, 42019, 1144, 70, 13246, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9303271, 258696, 42264, 1147, 70, 13260, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9345538, 259845, 42185, 1146, 70, 13274, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9387726, 260993, 42050, 1144, 70, 13273, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9429779, 262139, 42400, 1148, 70, 13263, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9472182, 263289, 42494, 1150, 70, 13251, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9514679, 264441, 42504, 1150, 70, 13265, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9557186, 265593, 42272, 1147, 70, 13268, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9599461, 266742, 42194, 1146, 70, 13267, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9641658, 267890, 42043, 1144, 70, 13278, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9683704, 269036, 42401, 1148, 70, 13268, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9726108, 270186, 42383, 1148, 70, 13270, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9768494, 271336, 42621, 1151, 70, 13273, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9811118, 272489, 42554, 1150, 70, 13251, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9853675, 273641, 42506, 1150, 70, 13263, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9896184, 274793, 42401, 1148, 70, 13264, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9938588, 275943, 42361, 1148, 70, 13268, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9980952, 277093, 42405, 1148, 70, 13264, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10023360, 278243, 42380, 1148, 70, 13263, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10065743, 279393, 42665, 1151, 70, 13273, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10108411, 280546, 42374, 1148, 70, 13265, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10150788, 281696, 42195, 1146, 70, 13268, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10192986, 282844, 42374, 1148, 70, 13265, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10235363, 283994, 42316, 1147, 70, 13256, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10277682, 285143, 42473, 1149, 70, 13287, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10320158, 286294, 42871, 1154, 70, 13268, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10363032, 287450, 42512, 1150, 70, 13265, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10405547, 288602, 42524, 1150, 70, 13265, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10448074, 289754, 42155, 1145, 70, 13257, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10490232, 290901, 42218, 1146, 70, 13267, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10532453, 292049, 42117, 1145, 70, 13267, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10574573, 293196, 42103, 1145, 70, 13265, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10616679, 294343, 42437, 1149, 70, 13251, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10659119, 295494, 42471, 1149, 70, 13245, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10701593, 296645, 42789, 1153, 70, 13251, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10744385, 297800, 42275, 1147, 70, 13263, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10786663, 298949, 42301, 1147, 70, 13257, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10828967, 300098, 42733, 1152, 70, 13284, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10871703, 301252, 42512, 1150, 70, 13249, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10914218, 302404, 42777, 1153, 70, 13267, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10956998, 303559, 42257, 1147, 70, 13257, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10999258, 304708, 42333, 1148, 70, 13256, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11041594, 305858, 42359, 1148, 70, 13266, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11083956, 307008, 42522, 1150, 70, 13267, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11126481, 308160, 42201, 1146, 70, 13266, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11168685, 309308, 42638, 1151, 70, 13270, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11211326, 310461, 42256, 1147, 70, 13252, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11253585, 311610, 42660, 1151, 70, 13272, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11296248, 312763, 42217, 1146, 70, 13274, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11338468, 313911, 42488, 1149, 70, 13266, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11380959, 315062, 42358, 1148, 70, 13261, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11423320, 316212, 42572, 1151, 70, 13256, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11465895, 317365, 42470, 1149, 70, 13260, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11508368, 318516, 42444, 1149, 70, 13278, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11550815, 319667, 42495, 1150, 70, 13256, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11593313, 320819, 42551, 1150, 70, 13260, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11635867, 321971, 42866, 1154, 70, 13275, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11678736, 323127, 42446, 1149, 70, 13260, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11721185, 324278, 42290, 1147, 70, 13266, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11763478, 325427, 42621, 1151, 70, 13281, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11806102, 326580, 42466, 1149, 70, 13260, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11848571, 327731, 42348, 1148, 70, 13275, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11890922, 328881, 42000, 1143, 70, 13260, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11932925, 330026, 42695, 1152, 70, 13270, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11975623, 331180, 42926, 1155, 70, 13262, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12018552, 332337, 42473, 1149, 70, 13271, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12061028, 333488, 42620, 1151, 70, 13272, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12103651, 334641, 42841, 1154, 70, 13270, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12146495, 335797, 42381, 1148, 70, 13260, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12188879, 336947, 42469, 1149, 70, 13275, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12231351, 338098, 42223, 1146, 70, 13272, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12273577, 339246, 42362, 1148, 70, 13249, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12315942, 340396, 42791, 1153, 70, 13261, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12358736, 341551, 42198, 1146, 70, 13275, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12400937, 342699, 42414, 1148, 70, 13269, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12443354, 343849, 42712, 1152, 70, 13259, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12486069, 345003, 42594, 1151, 70, 13270, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12528666, 346156, 42726, 1152, 70, 13261, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12571395, 347310, 42289, 1147, 70, 13265, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12613687, 348459, 42665, 1151, 70, 13273, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12656355, 349612, 42545, 1150, 70, 13258, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12698903, 350764, 42684, 1152, 70, 13255, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12741590, 351918, 41990, 1143, 70, 13254, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12783583, 353063, 42665, 1152, 70, 13260, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12826251, 354217, 42280, 1147, 70, 13272, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12868534, 355366, 42644, 1151, 70, 13260, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12911181, 356519, 42787, 1153, 70, 13273, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12953971, 357674, 42496, 1149, 70, 13274, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12996470, 358825, 42183, 1146, 70, 13248, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13038656, 359973, 42957, 1155, 70, 13257, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13081616, 361130, 42412, 1148, 70, 13271, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13124031, 362280, 42493, 1149, 70, 13275, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13166527, 363431, 42633, 1151, 70, 13265, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13209163, 364584, 42412, 1149, 70, 13258, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13251578, 365735, 42572, 1150, 70, 13265, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13294153, 366887, 42433, 1149, 70, 13259, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13336589, 368038, 42463, 1149, 70, 13281, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13379055, 369189, 42208, 1146, 70, 13261, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13421266, 370337, 42470, 1149, 70, 13264, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13463739, 371488, 42606, 1151, 70, 13266, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13506348, 372641, 42373, 1148, 70, 13264, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13548724, 373791, 42698, 1152, 70, 13265, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13591425, 374945, 42150, 1145, 70, 13256, 784, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[13633602, 376094, 422, 11, 60, "Text",
  CellTags->"i:12"],
Cell[13634027, 376107, 231, 7, 30, "NumberedEquation",
  CellTags->"(7.1.28)"],
Cell[13634261, 376116, 1014, 31, 60, "Text"],
Cell[13635278, 376149, 120, 4, 26, "UNNEQ"],
Cell[13635401, 376155, 240, 7, 41, "Text",
  CellTags->"i:13"],
Cell[13635644, 376164, 92, 3, 65, "Input",
  CellTags->"Cell 7.20"],
Cell[13635739, 376169, 749, 21, 75, "Text"],

Cell[CellGroupData[{
Cell[13636513, 376194, 587, 13, 200, "Input",
  CellTags->"Cell 7.21"],

Cell[CellGroupData[{
Cell[13637125, 376211, 41709, 799, 345, 5412, 346, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13678837, 377012, 41702, 825, 70, 5526, 373, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13720542, 377839, 40093, 810, 70, 5618, 379, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13760638, 378651, 45071, 887, 70, 6166, 402, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13805712, 379540, 43156, 814, 70, 5575, 345, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13848871, 380356, 41609, 831, 70, 5810, 384, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13890483, 381189, 44997, 873, 70, 5804, 384, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13935483, 382064, 43936, 860, 70, 5808, 384, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13979422, 382926, 41886, 844, 70, 5726, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14021311, 383772, 40462, 838, 70, 5829, 405, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14061776, 384612, 40340, 808, 70, 5533, 373, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14102119, 385422, 45174, 872, 70, 5977, 383, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14147296, 386296, 44885, 885, 70, 6170, 402, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14192184, 387183, 45021, 873, 70, 5808, 384, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14237208, 388058, 41328, 820, 70, 5525, 373, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14278539, 388880, 41853, 843, 70, 5718, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14320395, 389725, 40859, 843, 70, 5821, 405, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14361257, 390570, 40614, 828, 70, 5726, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14401874, 391400, 44788, 884, 70, 6170, 402, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14446665, 392286, 44861, 885, 70, 6170, 402, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14491529, 393173, 42305, 849, 70, 5720, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14533837, 394024, 41121, 817, 70, 5533, 373, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14574961, 394843, 40500, 826, 70, 5722, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14615464, 395671, 40950, 832, 70, 5718, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14656417, 396505, 40620, 840, 70, 5825, 405, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14697040, 397347, 39757, 801, 70, 5533, 373, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14736800, 398150, 40992, 816, 70, 5533, 373, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14777795, 398968, 40332, 808, 70, 5533, 373, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14818130, 399778, 40769, 813, 70, 5533, 373, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14858902, 400593, 41189, 835, 70, 5722, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14900094, 401430, 40695, 829, 70, 5726, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14940792, 402261, 41029, 845, 70, 5817, 405, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14981824, 403108, 41254, 836, 70, 5726, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15023081, 403946, 40028, 804, 70, 5533, 373, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15063112, 404752, 40332, 808, 70, 5533, 373, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15103447, 405562, 41746, 842, 70, 5728, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15145196, 406406, 40982, 832, 70, 5722, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15186181, 407240, 40626, 828, 70, 5726, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15226810, 408070, 41250, 836, 70, 5726, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15268063, 408908, 40774, 842, 70, 5825, 405, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15308840, 409752, 39838, 802, 70, 5533, 373, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15348681, 410556, 40530, 810, 70, 5529, 373, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15389214, 411368, 40559, 811, 70, 5533, 373, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15429776, 412181, 40375, 825, 70, 5722, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15470154, 413008, 40630, 828, 70, 5722, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15510787, 413838, 40743, 829, 70, 5726, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15551533, 414669, 40567, 839, 70, 5829, 405, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15592103, 415510, 40699, 829, 70, 5722, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15632805, 416341, 40392, 808, 70, 5533, 373, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15673200, 417151, 39781, 801, 70, 5529, 373, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15712984, 417954, 41526, 856, 70, 5921, 411, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15754513, 418812, 40914, 832, 70, 5722, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15795430, 419646, 40747, 829, 70, 5726, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15836180, 420477, 40282, 824, 70, 5726, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15876465, 421303, 41025, 845, 70, 5825, 405, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15917493, 422150, 40344, 808, 70, 5533, 373, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15957840, 422960, 39562, 798, 70, 5529, 373, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15997405, 423760, 40553, 827, 70, 5726, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16037961, 424589, 41157, 835, 70, 5722, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16079121, 425426, 40683, 829, 70, 5726, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16119807, 426257, 40456, 826, 70, 5722, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16160266, 427085, 41029, 845, 70, 5829, 405, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16201298, 427932, 41274, 836, 70, 5726, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16242575, 428770, 39554, 798, 70, 5533, 373, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16282132, 429570, 40776, 830, 70, 5726, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16322911, 430402, 41424, 854, 70, 5921, 411, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16364338, 431258, 40918, 832, 70, 5726, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16405259, 432092, 40460, 826, 70, 5726, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16445722, 432920, 40675, 829, 70, 5726, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16486400, 433751, 41053, 845, 70, 5829, 405, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16527456, 434598, 40999, 833, 70, 5726, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16568458, 435433, 40290, 824, 70, 5726, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16608751, 436259, 41043, 833, 70, 5722, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16649797, 437094, 40205, 823, 70, 5722, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16690005, 437919, 40687, 829, 70, 5726, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16730695, 438750, 40666, 828, 70, 5726, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16771364, 439580, 40709, 841, 70, 5829, 405, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16812076, 440423, 40909, 831, 70, 5726, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16852988, 441256, 40918, 832, 70, 5726, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16893909, 442090, 40662, 828, 70, 5726, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16934574, 442920, 40476, 826, 70, 5722, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16975053, 443748, 41274, 836, 70, 5726, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17016330, 444586, 40533, 827, 70, 5726, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17056866, 445415, 40926, 832, 70, 5726, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17097795, 446249, 40360, 836, 70, 5825, 405, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17138158, 447087, 40703, 829, 70, 5726, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17178864, 447918, 40739, 829, 70, 5726, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17219606, 448749, 40585, 827, 70, 5726, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17260194, 449578, 40658, 828, 70, 5722, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17300855, 450408, 41039, 833, 70, 5726, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17341897, 451243, 40440, 826, 70, 5722, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17382340, 452071, 40774, 842, 70, 5825, 405, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17423117, 452915, 40837, 831, 70, 5726, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17463957, 453748, 40747, 829, 70, 5726, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17504707, 454579, 41108, 834, 70, 5718, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17545818, 455415, 40675, 829, 70, 5726, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17586496, 456246, 40504, 826, 70, 5726, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17627003, 457074, 41019, 833, 70, 5718, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17668025, 457909, 40804, 830, 70, 5726, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17708832, 458741, 40482, 838, 70, 5825, 405, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17749317, 459581, 40334, 824, 70, 5722, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17789654, 460407, 40500, 826, 70, 5726, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17830157, 461235, 40351, 825, 70, 5726, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17870511, 462062, 40403, 825, 70, 5726, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17910917, 462889, 40298, 824, 70, 5722, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17951218, 463715, 41003, 833, 70, 5722, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17992224, 464550, 40810, 842, 70, 5821, 405, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18033037, 465394, 40849, 831, 70, 5726, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18073889, 466227, 40533, 827, 70, 5726, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18114425, 467056, 41072, 834, 70, 5718, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18155500, 467892, 41019, 833, 70, 5726, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18196522, 468727, 40662, 828, 70, 5722, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18237187, 469557, 40885, 831, 70, 5722, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18278075, 470390, 40525, 827, 70, 5726, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18318603, 471219, 40664, 840, 70, 5829, 405, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18359270, 472061, 40646, 828, 70, 5726, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18399919, 472891, 40517, 827, 70, 5722, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18440439, 473720, 40747, 829, 70, 5726, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18481189, 474551, 40889, 831, 70, 5726, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18522081, 475384, 41124, 834, 70, 5726, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18563208, 476220, 40792, 830, 70, 5722, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18604003, 477052, 41025, 845, 70, 5825, 405, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18645031, 477899, 40634, 828, 70, 5726, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18685668, 478729, 40707, 829, 70, 5726, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18726378, 479560, 40703, 829, 70, 5722, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18767084, 480391, 40298, 824, 70, 5726, 392, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[18807409, 481219, 585, 16, 60, "Text"],
Cell[18807997, 481237, 333, 11, 25, "Text"],
Cell[18808333, 481250, 173, 5, 65, "Input",
  CellTags->"Cell 7.22"],
Cell[18808509, 481257, 500, 16, 41, "Text"],
Cell[18809012, 481275, 30698, 776, 230, 6665, 475, "GraphicsData", \
"PostScript", "Picture"],
Cell[18839713, 482053, 209, 6, 15, "Caption",
  CellTags->"Fig. 7.3"],
Cell[18839925, 482061, 893, 13, 145, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[18840867, 482080, 74, 1, 30, "Subsubtitle",
  CellTags->{"i:14", "c:10"}],

Cell[CellGroupData[{
Cell[18840966, 482085, 76, 1, 40, "Section",
  CellTags->"c:11"],
Cell[18841045, 482088, 144, 3, 41, "Text"],
Cell[18841192, 482093, 222, 6, 35, "NumberedEquation",
  CellTags->"(7.1.29)"],
Cell[18841417, 482101, 1547, 42, 130, "Text",
  CellTags->"i:17"],
Cell[18842967, 482145, 497, 14, 60, "Text"],
Cell[18843467, 482161, 173, 5, 35, "UNNEQ"],
Cell[18843643, 482168, 372, 11, 41, "Text"],
Cell[18844018, 482181, 199, 6, 36, "NumberedEquation",
  CellTags->{"i:85", "(7.1.30)"}],
Cell[18844220, 482189, 477, 12, 60, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[18844734, 482206, 47, 1, 30, "Section",
  CellTags->"c:12"],
Cell[18844784, 482209, 503, 12, 60, "Text"],
Cell[18845290, 482223, 174, 6, 26, "NumberedEquation",
  CellTags->"(7.1.31)"],
Cell[18845467, 482231, 375, 10, 41, "Text"],
Cell[18845845, 482243, 185, 5, 26, "NumberedEquation",
  CellTags->"(7.1.32)"],
Cell[18846033, 482250, 159, 5, 25, "Text"],
Cell[18846195, 482257, 153, 5, 26, "NumberedEquation",
  CellTags->"(7.1.33)"],
Cell[18846351, 482264, 301, 9, 25, "Text"],
Cell[18846655, 482275, 161, 5, 26, "NumberedEquation",
  CellTags->{"i:18", "(7.1.34)"}],
Cell[18846819, 482282, 375, 12, 41, "Text"],
Cell[18847197, 482296, 112141, 5367, 450, 50563, 4602, "GraphicsData", \
"PostScript", "Picture"],
Cell[18959341, 487665, 241, 7, 15, "Caption",
  CellTags->"Fig. 7.4"],
Cell[18959585, 487674, 435, 13, 41, "Text"],
Cell[18960023, 487689, 120, 4, 26, "UNNEQ"],
Cell[18960146, 487695, 547, 14, 60, "Text"],
Cell[18960696, 487711, 111, 3, 65, "Input",
  CellTags->"Cell 7.23"],
Cell[18960810, 487716, 192, 7, 25, "Text"],
Cell[18961005, 487725, 136, 3, 65, "Input",
  CellTags->"Cell 7.24"],
Cell[18961144, 487730, 334, 10, 41, "Text"],
Cell[18961481, 487742, 594, 19, 41, "Text",
  CellTags->"i:87"],
Cell[18962078, 487763, 286, 7, 121, "Input",
  CellTags->"Cell 7.25"],
Cell[18962367, 487772, 364, 13, 41, "Text"],

Cell[CellGroupData[{
Cell[18962756, 487789, 273, 7, 85, "Input",
  CellTags->"Cell 7.26"],

Cell[CellGroupData[{
Cell[18963054, 487800, 28271, 646, 230, 5343, 358, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18991328, 488448, 28085, 643, 70, 5372, 358, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19019416, 489093, 27965, 641, 70, 5374, 358, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19047384, 489736, 28153, 644, 70, 5375, 358, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19075540, 490382, 27948, 641, 70, 5377, 358, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19103491, 491025, 27631, 637, 70, 5376, 358, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19131125, 491664, 28117, 643, 70, 5368, 358, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19159245, 492309, 28136, 644, 70, 5366, 358, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19187384, 492955, 28242, 645, 70, 5375, 358, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19215629, 493602, 28176, 644, 70, 5370, 358, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19243808, 494248, 27923, 641, 70, 5376, 358, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19271734, 494891, 28269, 645, 70, 5374, 358, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19300006, 495538, 28202, 644, 70, 5376, 358, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[19328235, 496186, 1014, 19, 145, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[19329286, 496210, 66, 1, 30, "Section",
  CellTags->{"i:16", "c:13"}],
Cell[19329355, 496213, 698, 22, 60, "Text"],
Cell[19330056, 496237, 478, 13, 60, "Text"],
Cell[19330537, 496252, 855, 25, 60, "Text"],
Cell[19331395, 496279, 187, 5, 26, "UNNEQ"],
Cell[19331585, 496286, 106, 5, 25, "Text"],
Cell[19331694, 496293, 792, 19, 40, "NumberedEquation",
  CellTags->"(7.1.35)"],
Cell[19332489, 496314, 761, 27, 25, "Text"],
Cell[19333253, 496343, 186, 6, 40, "NumberedEquation",
  CellTags->"(7.1.36)"],
Cell[19333442, 496351, 217, 8, 25, "Text"],
Cell[19333662, 496361, 211, 7, 40, "NumberedEquation",
  CellTags->"(7.1.37)"],
Cell[19333876, 496370, 299, 9, 41, "Text"],
Cell[19334178, 496381, 162, 3, 30, "NumberedEquation",
  CellTags->"(7.1.38)"],
Cell[19334343, 496386, 19, 0, 25, "Text"],
Cell[19334365, 496388, 177, 6, 30, "NumberedEquation",
  CellTags->"(7.1.39)"],
Cell[19334545, 496396, 433, 14, 45, "Text"],

Cell[CellGroupData[{
Cell[19335003, 496414, 106, 3, 65, "Input",
  CellTags->"Cell 7.27"],
Cell[19335112, 496419, 89, 1, 55, "Output"]
}, Open  ]],
Cell[19335216, 496423, 277, 9, 30, "Text"],

Cell[CellGroupData[{
Cell[19335518, 496436, 103, 3, 65, "Input",
  CellTags->"Cell 7.28"],
Cell[19335624, 496441, 58, 1, 75, "Output"]
}, Open  ]],
Cell[19335697, 496445, 262, 5, 45, "Text"],
Cell[19335962, 496452, 983, 27, 75, "Text"],
Cell[19336948, 496481, 1059, 27, 50, "NumberedEquation",
  CellTags->"(7.1.40)"],
Cell[19338010, 496510, 234, 8, 30, "Text"],
Cell[19338247, 496520, 667, 18, 50, "NumberedEquation",
  CellTags->"(7.1.41)"],
Cell[19338917, 496540, 842, 27, 45, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[19339808, 496573, 65, 1, 30, "Subsubtitle",
  CellTags->"c:14"],
Cell[19339876, 496576, 99, 4, 27, "Text"],
Cell[19339978, 496582, 270, 10, 27, "Text"],
Cell[19340251, 496594, 157, 7, 27, "Text"],
Cell[19340411, 496603, 433, 15, 39, "Text"],
Cell[19340847, 496620, 400, 15, 37, "Text"],
Cell[19341250, 496637, 390, 15, 37, "Text"],
Cell[19341643, 496654, 194, 8, 27, "Text"],
Cell[19341840, 496664, 622, 21, 47, "Text"],
Cell[19342465, 496687, 418, 12, 47, "Text"],
Cell[19342886, 496701, 505, 16, 57, "Text"],
Cell[19343394, 496719, 1317, 41, 98, "Text"],
Cell[19344714, 496762, 944, 30, 86, "Text"],
Cell[19345661, 496794, 1624, 50, 96, "Text",
  CellTags->"i:21"],
Cell[19347288, 496846, 57, 0, 27, "Text"],
Cell[19347348, 496848, 367, 12, 32, "NumberedEquation",
  CellTags->"(7.1.42)"],
Cell[19347718, 496862, 1252, 38, 110, "Text"],
Cell[19348973, 496902, 772, 19, 46, "UNNEQ"],
Cell[19349748, 496923, 661, 17, 66, "Text"],
Cell[19350412, 496942, 452, 14, 44, "Text"],
Cell[19350867, 496958, 640, 23, 44, "Text"],
Cell[19351510, 496983, 292, 8, 44, "Text"],
Cell[19351805, 496993, 512, 15, 37, "Text"],
Cell[19352320, 497010, 435, 14, 44, "Text"],
Cell[19352758, 497026, 257, 8, 27, "Text"],
Cell[19353018, 497036, 669, 18, 38, "UNNEQ",
  CellTags->"i:22"],
Cell[19353690, 497056, 306, 10, 27, "Text"],
Cell[19353999, 497068, 340, 13, 27, "Text"],
Cell[19354342, 497083, 352, 11, 44, "Text"],
Cell[19354697, 497096, 704, 17, 78, "Text",
  CellTags->"i:23"],
Cell[19355404, 497115, 202, 4, 39, "NumberedEquation",
  CellTags->"(7.1.43)"],
Cell[19355609, 497121, 135, 5, 27, "Text"],
Cell[19355747, 497128, 955, 24, 98, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[19356751, 497158, 71, 1, 40, "Subtitle",
  CellTags->{"i:24", "c:15"}],
Cell[19356825, 497161, 16, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[19356866, 497165, 84, 1, 41, "Subsubtitle",
  CellTags->"c:16"],
Cell[19356953, 497168, 16, 0, 25, "Text"],
Cell[19356972, 497170, 454, 7, 75, "Text"],
Cell[19357429, 497179, 132, 3, 25, "Text"],
Cell[19357564, 497184, 140, 5, 30, "NE2",
  CellTags->"(7.2.1)"],
Cell[19357707, 497191, 1030, 32, 80, "Text"],

Cell[CellGroupData[{
Cell[19358762, 497227, 123, 3, 65, "Input",
  CellTags->"Cell 7.29"],
Cell[19358888, 497232, 481, 15, 61, "Output"]
}, Open  ]],
Cell[19359384, 497250, 148, 7, 25, "Text"],
Cell[19359535, 497259, 198, 7, 35, "NE2",
  CellTags->"(7.2.2)"],
Cell[19359736, 497268, 196, 6, 25, "Text"],
Cell[19359935, 497276, 285, 7, 40, "NE2",
  CellTags->"(7.2.3)"],
Cell[19360223, 497285, 166, 4, 41, "Text"],
Cell[19360392, 497291, 263, 6, 35, "UNNEQ"],
Cell[19360658, 497299, 189, 6, 25, "Text"],
Cell[19360850, 497307, 891, 31, 41, "Text",
  CellTags->"i:25"],
Cell[19361744, 497340, 223, 7, 40, "NE2",
  CellTags->"(7.2.4)"],
Cell[19361970, 497349, 232, 8, 30, "Text"],
Cell[19362205, 497359, 387, 7, 75, "Text"],
Cell[19362595, 497368, 320, 7, 41, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[19362952, 497380, 103, 1, 30, "Subsubtitle",
  CellTags->{"i:26", "c:17"}],
Cell[19363058, 497383, 455, 12, 60, "Text"],
Cell[19363516, 497397, 577, 19, 42, "Text"],
Cell[19364096, 497418, 238, 6, 42, "UNNEQ"],
Cell[19364337, 497426, 294, 9, 51, "Text"],
Cell[19364634, 497437, 188, 6, 42, "UNNEQ"],
Cell[19364825, 497445, 1558, 52, 131, "Text"],
Cell[19366386, 497499, 192, 3, 41, "NE2",
  CellTags->"(7.2.5)"],
Cell[19366581, 497504, 129, 5, 25, "Text"],
Cell[19366713, 497511, 172, 6, 37, "NE2",
  CellTags->"(7.2.6)"],
Cell[19366888, 497519, 558, 18, 42, "Text"],

Cell[CellGroupData[{
Cell[19367471, 497541, 515, 11, 160, "Input",
  CellTags->"Cell 7.30"],
Cell[19367989, 497554, 30216, 734, 231, 7134, 444, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[19398220, 498291, 364, 11, 46, "Text"],

Cell[CellGroupData[{
Cell[19398609, 498306, 110, 3, 65, "Input",
  CellTags->"Cell 7.31"],
Cell[19398722, 498311, 115, 2, 57, "Output"]
}, Open  ]],
Cell[19398852, 498316, 998, 31, 85, "Text"],
Cell[19399853, 498349, 472, 16, 42, "Text"],
Cell[19400328, 498367, 180, 6, 56, "NE2",
  CellTags->"(7.2.7)"],
Cell[19400511, 498375, 66, 0, 25, "Text"],
Cell[19400580, 498377, 422, 15, 70, "NE2",
  CellTags->"(7.2.8)"],
Cell[19401005, 498394, 533, 13, 60, "Text"],

Cell[CellGroupData[{
Cell[19401563, 498411, 134, 3, 65, "Input",
  CellTags->"Cell 7.32"],
Cell[19401700, 498416, 1879, 31, 515, "Output"]
}, Open  ]],
Cell[19403594, 498450, 356, 10, 42, "Text"],
Cell[19403953, 498462, 184, 7, 37, "NE2",
  CellTags->"(7.2.9)"],
Cell[19404140, 498471, 184, 5, 25, "Text"],

Cell[CellGroupData[{
Cell[19404349, 498480, 431, 8, 191, "Input",
  CellTags->"Cell 7.33"],
Cell[19404783, 498490, 315, 5, 138, "Output"]
}, Open  ]],
Cell[19405113, 498498, 359, 10, 42, "Text",
  CellTags->"i:27"],
Cell[19405475, 498510, 211, 7, 65, "UNNEQ"],
Cell[19405689, 498519, 186, 5, 25, "Text"],
Cell[19405878, 498526, 481, 13, 60, "NE2",
  CellTags->"(7.2.10)"],
Cell[19406362, 498541, 21, 0, 25, "Text"],
Cell[19406386, 498543, 134, 6, 37, "NE2",
  CellTags->"(7.2.11)"],
Cell[19406523, 498551, 275, 9, 25, "Text"],
Cell[19406801, 498562, 235, 9, 25, "Text"],
Cell[19407039, 498573, 182, 5, 56, "UNNEQ"],
Cell[19407224, 498580, 612, 20, 45, "Text"],
Cell[19407839, 498602, 238, 8, 56, "NE2",
  CellTags->"(7.2.12)"],
Cell[19408080, 498612, 932, 31, 80, "Text",
  CellTags->"i:28"],

Cell[CellGroupData[{
Cell[19409037, 498647, 250, 5, 85, "Input",
  CellTags->"Cell 7.34"],
Cell[19409290, 498654, 49710, 1062, 231, 10334, 571, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[19459015, 499719, 709, 23, 60, "Text"],
Cell[19459727, 499744, 468, 14, 42, "Text"],
Cell[19460198, 499760, 131, 6, 28, "NE2",
  CellTags->"(7.2.13)"],
Cell[19460332, 499768, 772, 30, 60, "Text",
  CellTags->"i:29"],

Cell[CellGroupData[{
Cell[19461129, 499802, 217, 5, 85, "Input",
  CellTags->"Cell 7.35"],
Cell[19461349, 499809, 29387, 650, 231, 6502, 363, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[19490751, 500462, 369, 14, 25, "Text"],

Cell[CellGroupData[{
Cell[19491145, 500480, 101, 3, 65, "Input",
  CellTags->"Cell 7.36"],
Cell[19491249, 500485, 47, 1, 45, "Output"]
}, Open  ]],
Cell[19491311, 500489, 400, 12, 42, "Text"],
Cell[19491714, 500503, 385, 14, 45, "Text"],
Cell[19492102, 500519, 220, 7, 56, "NE2",
  CellTags->"(7.2.14)"],
Cell[19492325, 500528, 200, 8, 26, "Text"],
Cell[19492528, 500538, 179, 6, 56, "NE2",
  CellTags->"(7.2.15)"],
Cell[19492710, 500546, 590, 23, 43, "Text"],

Cell[CellGroupData[{
Cell[19493325, 500573, 635, 14, 161, "Input",
  CellTags->"Cell 7.37"],

Cell[CellGroupData[{
Cell[19493985, 500591, 27404, 812, 232, 9731, 589, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19521392, 501405, 30709, 863, 70, 9930, 602, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19552104, 502270, 33534, 888, 70, 9721, 589, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19585641, 503160, 35618, 882, 70, 9108, 550, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19621262, 504044, 35638, 890, 70, 9270, 560, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[19656927, 504938, 800, 24, 77, "Text"],
Cell[19657730, 504964, 1437659, 19151, 257, 855434, 11959, "GraphicsData", \
"PostScript", "Picture"],
Cell[21095392, 524117, 317, 9, 28, "Caption",
  CellTags->"Fig. 7.5"],
Cell[21095712, 524128, 825, 18, 95, "Text"],
Cell[21096540, 524148, 1153, 40, 90, "Text"],
Cell[21097696, 524190, 131, 5, 37, "NE2",
  CellTags->"(7.2.16)"],
Cell[21097830, 524197, 1802, 56, 160, "Text"],
Cell[21099635, 524255, 1135, 38, 77, "Text"],
Cell[21100773, 524295, 29181, 662, 232, 6361, 376, "GraphicsData", \
"PostScript", "Picture"],
Cell[21129957, 524959, 329, 12, 15, "Caption",
  CellTags->"Fig. 7.6"],
Cell[21130289, 524973, 228, 4, 41, "Text"],
Cell[21130520, 524979, 762, 27, 60, "Text",
  CellTags->"i:30"],

Cell[CellGroupData[{
Cell[21131307, 525010, 309, 6, 120, "Input",
  CellTags->"Cell 7.38"],
Cell[21131619, 525018, 34657, 791, 251, 8123, 459, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[21166291, 525812, 56, 0, 25, "Text"],

Cell[CellGroupData[{
Cell[21166372, 525816, 114, 3, 75, "Input",
  CellTags->"Cell 7.39"],
Cell[21166489, 525821, 80, 1, 75, "Output"]
}, Open  ]],
Cell[21166584, 525825, 63, 0, 25, "Text"],
Cell[21166650, 525827, 168, 6, 32, "NE2",
  CellTags->"(7.2.17)"],
Cell[21166821, 525835, 334, 10, 42, "Text"],
Cell[21167158, 525847, 107, 4, 31, "UNNEQ"],
Cell[21167268, 525853, 228, 6, 25, "Text"],
Cell[21167499, 525861, 92, 4, 27, "UNNEQ"],
Cell[21167594, 525867, 560, 15, 60, "Text"],
Cell[21168157, 525884, 143, 5, 27, "NE2",
  CellTags->"(7.2.18)"],
Cell[21168303, 525891, 33, 0, 25, "Text"],
Cell[21168339, 525893, 131, 5, 41, "NE2",
  CellTags->"(7.2.19)"],
Cell[21168473, 525900, 232, 5, 42, "Text",
  CellTags->"i:31"],
Cell[21168708, 525907, 1117, 18, 127, "IndentedText"],
Cell[21169828, 525927, 1339, 28, 165, "Text",
  CellTags->"i:73"]
}, Closed]],

Cell[CellGroupData[{
Cell[21171204, 525960, 94, 1, 30, "Subsubtitle",
  CellTags->"c:18"],

Cell[CellGroupData[{
Cell[21171323, 525965, 51, 1, 40, "Section",
  CellTags->"c:19"],
Cell[21171377, 525968, 610, 9, 95, "Text"],
Cell[21171990, 525979, 389, 7, 75, "Text"],
Cell[21172382, 525988, 367, 12, 41, "Text",
  CellTags->"i:74"],
Cell[21172752, 526002, 338, 12, 30, "NE2",
  CellTags->"(7.2.20)"],
Cell[21173093, 526016, 154, 5, 25, "Text"],
Cell[21173250, 526023, 212, 7, 35, "NE2",
  CellTags->"(7.2.21)"],
Cell[21173465, 526032, 348, 9, 46, "Text"],
Cell[21173816, 526043, 912, 23, 45, "NE2",
  CellTags->"(7.2.22)"],
Cell[21174731, 526068, 818, 24, 65, "Text"],
Cell[21175552, 526094, 322, 8, 35, "NE2",
  CellTags->"(7.2.23)"],
Cell[21175877, 526104, 364, 12, 41, "Text"],
Cell[21176244, 526118, 148, 5, 26, "NE2",
  CellTags->"(7.2.24)"],
Cell[21176395, 526125, 153, 5, 25, "Text"],
Cell[21176551, 526132, 155, 4, 65, "Input",
  CellTags->"Cell 7.40"],
Cell[21176709, 526138, 1663, 50, 155, "Text"],
Cell[21178375, 526190, 790, 20, 75, "Text",
  CellTags->"i:53"],
Cell[21179168, 526212, 892, 22, 95, "Text"],
Cell[21180063, 526236, 125, 3, 65, "Input",
  CellTags->"Cell 7.41"],
Cell[21180191, 526241, 64, 0, 25, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[21180292, 526246, 72, 1, 30, "Section",
  CellTags->{"i:44", "c:20"}],
Cell[21180367, 526249, 99, 3, 25, "Text"],
Cell[21180469, 526254, 318, 7, 121, "Input",
  CellTags->"Cell 7.42"],
Cell[21180790, 526263, 264, 9, 25, "Text"],

Cell[CellGroupData[{
Cell[21181079, 526276, 291, 7, 105, "Input",
  CellTags->"Cell 7.43"],
Cell[21181373, 526285, 104, 3, 45, "Output"]
}, Open  ]],
Cell[21181492, 526291, 198, 6, 25, "Text"],
Cell[21181693, 526299, 273, 9, 30, "NE2",
  CellTags->"(7.2.25)"],
Cell[21181969, 526310, 54, 0, 25, "Text"],

Cell[CellGroupData[{
Cell[21182048, 526314, 392, 11, 160, "Input",
  CellTags->"Cell 7.44"],
Cell[21182443, 526327, 274, 6, 66, "Message"],
Cell[21182720, 526335, 275, 6, 66, "Message"],
Cell[21182998, 526343, 274, 6, 66, "Message"],
Cell[21183275, 526351, 220, 5, 50, "Message"]
}, Open  ]],
Cell[21183510, 526359, 274, 5, 60, "Text"],
Cell[21183787, 526366, 905, 30, 60, "Text"],
Cell[21184695, 526398, 1253, 22, 390, "Input",
  CellTags->"Cell 7.45"],
Cell[21185951, 526422, 251, 9, 25, "Text"],

Cell[CellGroupData[{
Cell[21186227, 526435, 100, 3, 65, "Input",
  CellTags->"Cell 7.46"],

Cell[CellGroupData[{
Cell[21186352, 526442, 44054, 1052, 230, 9401, 618, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21230409, 527496, 43516, 1051, 70, 9527, 625, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21273928, 528549, 43905, 1057, 70, 9548, 627, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21317836, 529608, 44407, 1066, 70, 9617, 631, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21362246, 530676, 44512, 1068, 70, 9616, 631, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21406761, 531746, 44480, 1070, 70, 9641, 634, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21451244, 532818, 44400, 1071, 70, 9711, 637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21495647, 533891, 43920, 1061, 70, 9603, 631, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21539570, 534954, 43476, 1059, 70, 9698, 636, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21583049, 536015, 43748, 1051, 70, 9472, 622, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21626800, 537068, 44031, 1053, 70, 9447, 620, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21670834, 538123, 43703, 1054, 70, 9536, 626, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21714540, 539179, 44099, 1059, 70, 9548, 627, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21758642, 540240, 44595, 1070, 70, 9634, 632, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21803240, 541312, 44558, 1075, 70, 9743, 639, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21847801, 542389, 44693, 1070, 70, 9611, 631, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21892497, 543461, 44280, 1071, 70, 9716, 638, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21936780, 544534, 44105, 1065, 70, 9671, 634, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21980888, 545601, 43567, 1059, 70, 9688, 635, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22024458, 546662, 44237, 1069, 70, 9714, 637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22068698, 547733, 44093, 1058, 70, 9517, 625, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22112794, 548793, 44235, 1072, 70, 9773, 641, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22157032, 549867, 44268, 1057, 70, 9461, 621, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22201303, 550926, 44858, 1073, 70, 9638, 632, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22246164, 552001, 44586, 1064, 70, 9549, 626, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22290753, 553067, 44757, 1063, 70, 9448, 621, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22335513, 554132, 44319, 1064, 70, 9610, 630, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22379835, 555198, 44093, 1064, 70, 9659, 633, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22423931, 556264, 43605, 1059, 70, 9657, 634, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22467539, 557325, 44588, 1070, 70, 9648, 633, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22512130, 558397, 44116, 1068, 70, 9706, 637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22556249, 559467, 44109, 1064, 70, 9622, 632, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22600361, 560533, 44680, 1076, 70, 9707, 638, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22645044, 561611, 44906, 1075, 70, 9666, 634, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22689953, 562688, 44574, 1061, 70, 9476, 622, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22734530, 563751, 44751, 1070, 70, 9612, 630, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22779284, 564823, 44387, 1065, 70, 9597, 630, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22823674, 565890, 43874, 1062, 70, 9642, 633, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22867551, 566954, 44068, 1069, 70, 9764, 640, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22911622, 568025, 44622, 1067, 70, 9597, 629, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22956247, 569094, 44094, 1061, 70, 9579, 629, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[23000368, 570159, 621, 11, 95, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[23001026, 570175, 70, 1, 30, "Section",
  CellTags->"c:21"],
Cell[23001099, 570178, 122, 3, 25, "Text"],
Cell[23001224, 570183, 247, 6, 105, "Input",
  CellTags->"Cell 7.47"],
Cell[23001474, 570191, 69, 0, 25, "Text"],
Cell[23001546, 570193, 375, 11, 160, "Input",
  CellTags->"Cell 7.48"],
Cell[23001924, 570206, 404, 10, 41, "Text"],

Cell[CellGroupData[{
Cell[23002353, 570220, 105, 3, 65, "Input",
  CellTags->"Cell 7.49"],

Cell[CellGroupData[{
Cell[23002483, 570227, 33774, 873, 230, 8770, 560, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23036260, 571102, 34060, 874, 70, 8760, 557, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23070323, 571978, 32995, 861, 70, 8691, 556, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23103321, 572841, 32953, 866, 70, 8848, 564, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23136277, 573709, 33946, 863, 70, 8537, 545, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23170226, 574574, 33962, 862, 70, 8443, 542, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23204191, 575438, 34281, 883, 70, 8823, 564, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23238475, 576323, 34232, 880, 70, 8713, 560, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23272710, 577205, 34637, 901, 70, 9005, 580, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23307350, 578108, 33867, 867, 70, 8555, 550, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23341220, 578977, 33207, 868, 70, 8648, 560, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23374430, 579847, 33514, 869, 70, 8579, 557, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23407947, 580718, 33377, 874, 70, 8745, 565, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23441327, 581594, 32324, 863, 70, 8774, 568, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23473654, 582459, 32469, 890, 70, 9206, 598, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23506126, 583351, 32912, 872, 70, 8742, 569, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23539041, 584225, 33875, 921, 70, 9511, 616, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23572919, 585148, 33696, 897, 70, 9149, 589, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23606618, 586047, 33996, 894, 70, 8972, 581, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23640617, 586943, 34012, 878, 70, 8708, 561, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23674632, 587823, 34186, 875, 70, 8623, 555, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23708821, 588700, 34255, 878, 70, 8664, 558, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23743079, 589580, 33764, 886, 70, 8958, 575, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23776846, 590468, 33712, 877, 70, 8769, 565, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23810561, 591347, 33908, 855, 70, 8329, 535, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23844472, 592204, 34012, 856, 70, 8340, 535, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23878487, 593062, 33410, 841, 70, 8211, 525, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23911900, 593905, 33605, 879, 70, 8900, 569, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23945508, 594786, 33182, 845, 70, 8295, 533, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23978693, 595633, 34312, 880, 70, 8741, 560, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24013008, 596515, 34213, 861, 70, 8358, 537, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24047224, 597378, 34645, 890, 70, 8900, 568, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24081872, 598270, 34320, 882, 70, 8753, 562, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24116195, 599154, 33617, 886, 70, 9010, 578, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24149815, 600042, 32946, 855, 70, 8557, 549, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24182764, 600899, 34257, 874, 70, 8625, 553, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24217024, 601775, 34639, 888, 70, 8788, 564, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24251666, 602665, 34021, 860, 70, 8365, 539, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24285690, 603527, 34673, 887, 70, 8733, 562, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24320366, 604416, 34538, 883, 70, 8724, 560, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24354907, 605301, 34230, 888, 70, 8796, 569, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24389140, 606191, 33319, 874, 70, 8781, 567, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24422462, 607067, 34005, 897, 70, 9057, 584, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24456470, 607966, 33572, 888, 70, 8973, 580, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24490045, 608856, 32377, 869, 70, 8871, 574, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24522425, 609727, 31947, 861, 70, 8810, 571, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24554375, 610590, 33374, 897, 70, 9184, 594, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24587752, 611489, 33031, 871, 70, 8723, 566, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24620786, 612362, 33238, 872, 70, 8704, 565, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24654027, 613236, 33754, 881, 70, 8782, 568, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24687784, 614119, 34188, 892, 70, 8908, 575, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24721975, 615013, 34484, 905, 70, 9079, 587, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24756462, 615920, 34412, 890, 70, 8752, 569, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24790877, 616812, 33575, 883, 70, 8891, 574, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24824455, 617697, 33774, 889, 70, 8887, 577, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24858232, 618588, 34464, 891, 70, 8877, 571, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24892699, 619481, 34982, 917, 70, 9253, 595, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24927684, 620400, 33877, 876, 70, 8719, 561, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24961564, 621278, 33240, 855, 70, 8422, 544, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24994807, 622135, 33636, 882, 70, 8899, 572, "GraphicsData", \
"PostScript", "Graphics"],
Cell[25028446, 623019, 34837, 905, 70, 9067, 582, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[25063310, 623928, 521, 8, 95, "Text"],
Cell[25063834, 623938, 369, 6, 60, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[25064240, 623949, 87, 1, 30, "Section",
  CellTags->{"i:45", "c:22"}],
Cell[25064330, 623952, 594, 11, 95, "Text"],
Cell[25064927, 623965, 385, 11, 41, "Text"],

Cell[CellGroupData[{
Cell[25065337, 623980, 313, 7, 140, "Input",
  CellTags->"Cell 7.50"],

Cell[CellGroupData[{
Cell[25065675, 623991, 27689, 747, 230, 7309, 491, "GraphicsData", \
"PostScript", "Graphics"],
Cell[25093367, 624740, 27985, 753, 70, 7354, 494, "GraphicsData", \
"PostScript", "Graphics"],
Cell[25121355, 625495, 28134, 754, 70, 7349, 493, "GraphicsData", \
"PostScript", "Graphics"],
Cell[25149492, 626251, 28526, 772, 70, 7591, 509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[25178021, 627025, 28610, 774, 70, 7614, 510, "GraphicsData", \
"PostScript", "Graphics"],
Cell[25206634, 627801, 29439, 801, 70, 7941, 531, "GraphicsData", \
"PostScript", "Graphics"],
Cell[25236076, 628604, 30377, 825, 70, 8195, 547, "GraphicsData", \
"PostScript", "Graphics"],
Cell[25266456, 629431, 31831, 869, 70, 8697, 579, "GraphicsData", \
"PostScript", "Graphics"],
Cell[25298290, 630302, 32737, 885, 70, 8781, 585, "GraphicsData", \
"PostScript", "Graphics"],
Cell[25331030, 631189, 33307, 906, 70, 9055, 602, "GraphicsData", \
"PostScript", "Graphics"],
Cell[25364340, 632097, 34442, 941, 70, 9461, 628, "GraphicsData", \
"PostScript", "Graphics"],
Cell[25398785, 633040, 34417, 942, 70, 9493, 630, "GraphicsData", \
"PostScript", "Graphics"],
Cell[25433205, 633984, 34522, 948, 70, 9549, 635, "GraphicsData", \
"PostScript", "Graphics"],
Cell[25467730, 634934, 34943, 967, 70, 9857, 653, "GraphicsData", \
"PostScript", "Graphics"],
Cell[25502676, 635903, 35032, 960, 70, 9695, 643, "GraphicsData", \
"PostScript", "Graphics"],
Cell[25537711, 636865, 34979, 956, 70, 9617, 638, "GraphicsData", \
"PostScript", "Graphics"],
Cell[25572693, 637823, 35344, 966, 70, 9719, 645, "GraphicsData", \
"PostScript", "Graphics"],
Cell[25608040, 638791, 35323, 966, 70, 9730, 645, "GraphicsData", \
"PostScript", "Graphics"],
Cell[25643366, 639759, 35473, 968, 70, 9743, 646, "GraphicsData", \
"PostScript", "Graphics"],
Cell[25678842, 640729, 35509, 963, 70, 9641, 639, "GraphicsData", \
"PostScript", "Graphics"],
Cell[25714354, 641694, 34847, 920, 70, 8959, 596, "GraphicsData", \
"PostScript", "Graphics"],
Cell[25749204, 642616, 34447, 916, 70, 8968, 597, "GraphicsData", \
"PostScript", "Graphics"],
Cell[25783654, 643534, 34280, 919, 70, 9064, 603, "GraphicsData", \
"PostScript", "Graphics"],
Cell[25817937, 644455, 34179, 915, 70, 9016, 600, "GraphicsData", \
"PostScript", "Graphics"],
Cell[25852119, 645372, 34281, 924, 70, 9179, 610, "GraphicsData", \
"PostScript", "Graphics"],
Cell[25886403, 646298, 35474, 976, 70, 9873, 655, "GraphicsData", \
"PostScript", "Graphics"],
Cell[25921880, 647276, 35501, 969, 70, 9759, 647, "GraphicsData", \
"PostScript", "Graphics"],
Cell[25957384, 648247, 35284, 956, 70, 9550, 634, "GraphicsData", \
"PostScript", "Graphics"],
Cell[25992671, 649205, 34958, 947, 70, 9438, 627, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26027632, 650154, 34179, 920, 70, 9121, 606, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26061814, 651076, 33792, 910, 70, 9022, 600, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26095609, 651988, 32925, 884, 70, 8722, 581, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26128537, 652874, 32639, 894, 70, 8974, 597, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26161179, 653770, 31732, 858, 70, 8497, 567, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26192914, 654630, 32173, 881, 70, 8832, 588, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26225090, 655513, 32992, 915, 70, 9303, 618, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26258085, 656430, 34617, 976, 70, 10110, 669, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26292705, 657408, 35334, 989, 70, 10187, 674, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26328042, 658399, 35971, 992, 70, 10054, 667, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26364016, 659393, 35925, 975, 70, 9761, 647, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26399944, 660370, 35981, 974, 70, 9753, 646, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26435928, 661346, 35453, 954, 70, 9460, 629, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26471384, 662302, 35003, 941, 70, 9321, 619, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26506390, 663245, 34814, 939, 70, 9335, 620, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26541207, 664186, 34569, 934, 70, 9280, 617, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26575779, 665122, 34533, 930, 70, 9224, 613, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26610315, 666054, 35044, 933, 70, 9172, 609, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26645362, 666989, 35715, 970, 70, 9722, 645, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26681080, 667961, 36661, 1027, 70, 10599, 701, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26717744, 668990, 35895, 981, 70, 9873, 655, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26753642, 669973, 35868, 984, 70, 9960, 660, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26789513, 670959, 35813, 994, 70, 10160, 673, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26825329, 671955, 36037, 1006, 70, 10343, 684, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26861369, 672963, 36093, 1017, 70, 10537, 697, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26897465, 673982, 36472, 1055, 70, 11191, 738, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26933940, 675039, 36632, 1061, 70, 11266, 743, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26970575, 676102, 36000, 1038, 70, 10938, 724, "GraphicsData", \
"PostScript", "Graphics"],
Cell[27006578, 677142, 34383, 960, 70, 9852, 653, "GraphicsData", \
"PostScript", "Graphics"],
Cell[27040964, 678104, 34384, 986, 70, 10343, 685, "GraphicsData", \
"PostScript", "Graphics"],
Cell[27075351, 679092, 33075, 934, 70, 9641, 640, "GraphicsData", \
"PostScript", "Graphics"],
Cell[27108429, 680028, 32414, 912, 70, 9365, 623, "GraphicsData", \
"PostScript", "Graphics"],
Cell[27140846, 680942, 32651, 958, 70, 10230, 677, "GraphicsData", \
"PostScript", "Graphics"],
Cell[27173500, 681902, 32262, 959, 70, 10331, 684, "GraphicsData", \
"PostScript", "Graphics"],
Cell[27205765, 682863, 32123, 965, 70, 10475, 693, "GraphicsData", \
"PostScript", "Graphics"],
Cell[27237891, 683830, 31781, 959, 70, 10449, 691, "GraphicsData", \
"PostScript", "Graphics"],
Cell[27269675, 684791, 31700, 956, 70, 10396, 688, "GraphicsData", \
"PostScript", "Graphics"],
Cell[27301378, 685749, 32166, 979, 70, 10741, 710, "GraphicsData", \
"PostScript", "Graphics"],
Cell[27333547, 686730, 31023, 910, 70, 9687, 642, "GraphicsData", \
"PostScript", "Graphics"],
Cell[27364573, 687642, 32273, 975, 70, 10658, 704, "GraphicsData", \
"PostScript", "Graphics"],
Cell[27396849, 688619, 32830, 1003, 70, 11053, 730, "GraphicsData", \
"PostScript", "Graphics"],
Cell[27429682, 689624, 32760, 1001, 70, 11027, 728, "GraphicsData", \
"PostScript", "Graphics"],
Cell[27462445, 690627, 33305, 1017, 70, 11204, 740, "GraphicsData", \
"PostScript", "Graphics"],
Cell[27495753, 691646, 34585, 1070, 70, 11908, 785, "GraphicsData", \
"PostScript", "Graphics"],
Cell[27530341, 692718, 34916, 1053, 70, 11510, 759, "GraphicsData", \
"PostScript", "Graphics"],
Cell[27565260, 693773, 35361, 1060, 70, 11555, 762, "GraphicsData", \
"PostScript", "Graphics"],
Cell[27600624, 694835, 36209, 1085, 70, 11844, 780, "GraphicsData", \
"PostScript", "Graphics"],
Cell[27636836, 695922, 36167, 1062, 70, 11368, 751, "GraphicsData", \
"PostScript", "Graphics"],
Cell[27673006, 696986, 36178, 1049, 70, 11124, 735, "GraphicsData", \
"PostScript", "Graphics"],
Cell[27709187, 698037, 36045, 1039, 70, 10938, 724, "GraphicsData", \
"PostScript", "Graphics"],
Cell[27745235, 699078, 35904, 1028, 70, 10797, 713, "GraphicsData", \
"PostScript", "Graphics"],
Cell[27781142, 700108, 35701, 991, 70, 10108, 670, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[27816870, 701103, 519, 12, 60, "Text"],

Cell[CellGroupData[{
Cell[27817414, 701119, 541, 11, 180, "Input",
  CellTags->"Cell 7.51"],
Cell[27817958, 701132, 186076, 6710, 370, 62427, 5179, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[28004049, 707845, 535, 13, 75, "Text"],
Cell[28004587, 707860, 831, 17, 110, "Text"],

Cell[CellGroupData[{
Cell[28005443, 707881, 25698, 677, 230, 6664, 437, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28031144, 708560, 25706, 678, 70, 6672, 438, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28056853, 709240, 25881, 688, 70, 6835, 448, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28082737, 709930, 26939, 735, 70, 7509, 491, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28109679, 710667, 31609, 838, 70, 8380, 547, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28141291, 711507, 38439, 967, 70, 9240, 602, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28179733, 712476, 43448, 1068, 70, 9984, 650, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28223184, 713546, 47549, 1176, 70, 11113, 722, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28270736, 714724, 49305, 1202, 70, 11216, 727, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28320044, 715928, 50915, 1261, 70, 11964, 776, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28370962, 717191, 52906, 1321, 70, 12634, 819, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28423871, 718514, 53039, 1316, 70, 12504, 811, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28476913, 719832, 53432, 1318, 70, 12468, 808, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28530348, 721152, 53189, 1293, 70, 12038, 780, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28583540, 722447, 52749, 1297, 70, 12226, 792, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28636292, 723746, 51519, 1243, 70, 11470, 744, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28687814, 724991, 52039, 1285, 70, 12172, 788, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28739856, 726278, 47619, 1173, 70, 11041, 717, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28787478, 727453, 50498, 1274, 70, 12292, 798, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28837979, 728729, 50235, 1234, 70, 11612, 753, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28888217, 729965, 46249, 1158, 70, 11076, 719, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28934469, 731125, 52708, 1322, 70, 12699, 823, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28987180, 732449, 51562, 1277, 70, 12125, 786, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29038745, 733728, 46818, 1198, 70, 11718, 760, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29085566, 734928, 45559, 1188, 70, 11800, 767, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29131128, 736118, 52175, 1300, 70, 12430, 805, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29183306, 737420, 52053, 1265, 70, 11769, 763, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29235362, 738687, 51902, 1278, 70, 12027, 781, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29287267, 739967, 47491, 1208, 70, 11743, 762, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29334761, 741177, 43058, 1128, 70, 11243, 731, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29377822, 742307, 44625, 1140, 70, 11109, 722, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29422450, 743449, 50842, 1291, 70, 12551, 814, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29473295, 744742, 53304, 1301, 70, 12186, 789, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29526602, 746045, 51977, 1261, 70, 11705, 759, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29578582, 747308, 49974, 1230, 70, 11573, 751, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29628559, 748540, 52755, 1302, 70, 12309, 798, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29681317, 749844, 51920, 1292, 70, 12325, 799, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29733240, 751138, 48561, 1202, 70, 11347, 738, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29781804, 752342, 43601, 1141, 70, 11389, 739, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29825408, 753485, 40522, 1076, 70, 10886, 706, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29865933, 754563, 43151, 1167, 70, 11996, 778, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29909087, 755732, 49060, 1279, 70, 12749, 826, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29958150, 757013, 51546, 1280, 70, 12181, 789, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30009699, 758295, 53587, 1306, 70, 12181, 790, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30063289, 759603, 51904, 1277, 70, 12009, 780, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30115196, 760882, 51447, 1261, 70, 11819, 767, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30166646, 762145, 49474, 1203, 70, 11179, 726, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30216123, 763350, 48712, 1233, 70, 11927, 774, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30264838, 764585, 50404, 1291, 70, 12651, 820, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30315245, 765878, 50692, 1243, 70, 11639, 756, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30365940, 767123, 51660, 1244, 70, 11453, 743, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30417603, 768369, 50670, 1228, 70, 11366, 738, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30468276, 769599, 52119, 1274, 70, 11916, 773, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30520398, 770875, 51927, 1277, 70, 12044, 780, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30572328, 772154, 50245, 1224, 70, 11415, 740, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30622576, 773380, 47219, 1145, 70, 10592, 688, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30669798, 774527, 44428, 1132, 70, 11013, 715, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30714229, 775661, 40661, 1107, 70, 11417, 741, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30754893, 776770, 38232, 1039, 70, 10673, 694, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30793128, 777811, 39429, 1060, 70, 10801, 702, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30832560, 778873, 42453, 1130, 70, 11444, 743, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30875016, 780005, 46570, 1240, 70, 12584, 816, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30921589, 781247, 49536, 1279, 70, 12642, 819, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30971128, 782528, 51885, 1283, 70, 12160, 788, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31023016, 783813, 51035, 1248, 70, 11703, 758, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31074054, 785063, 51924, 1268, 70, 11859, 769, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31125981, 786333, 52099, 1278, 70, 11981, 778, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31178083, 787613, 51375, 1236, 70, 11354, 737, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31229461, 788851, 49580, 1198, 70, 11054, 718, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31279044, 790051, 50215, 1205, 70, 11061, 717, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31329262, 791258, 51048, 1266, 70, 12011, 779, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31380313, 792526, 50049, 1247, 70, 11928, 772, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31430365, 793775, 50404, 1240, 70, 11691, 757, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31480772, 795017, 48870, 1217, 70, 11575, 752, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31529645, 796236, 49562, 1221, 70, 11522, 747, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31579210, 797459, 49223, 1227, 70, 11701, 759, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[31628448, 798689, 95, 1, 15, "Caption",
  CellTags->"Fig. 7.7"],
Cell[31628546, 798692, 295650, 13539, 370, 133579, 11534, "GraphicsData", \
"PostScript", "Picture"],
Cell[31924199, 812233, 194, 6, 15, "Caption",
  CellTags->"Fig. 7.8"],
Cell[31924396, 812241, 405, 9, 60, "Text"],
Cell[31924804, 812252, 835, 20, 95, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[31925688, 812278, 89, 1, 30, "Subsubtitle",
  CellTags->{"i:46", "c:23"}],

Cell[CellGroupData[{
Cell[31925802, 812283, 55, 1, 40, "Section",
  CellTags->"c:24"],
Cell[31925860, 812286, 372, 12, 45, "Text",
  CellTags->"i:47"],
Cell[31926235, 812300, 221, 7, 40, "NE2",
  CellTags->"(7.2.26)"],
Cell[31926459, 812309, 752, 15, 110, "Text"],
Cell[31927214, 812326, 690, 21, 60, "Text"],
Cell[31927907, 812349, 720, 21, 40, "NE2",
  CellTags->"(7.2.27)"],
Cell[31928630, 812372, 693, 24, 41, "Text"],
Cell[31929326, 812398, 173, 6, 35, "NE2",
  CellTags->"(7.2.28)"],
Cell[31929502, 812406, 266, 9, 25, "Text",
  CellTags->"i:48"],
Cell[31929771, 812417, 294, 9, 41, "Text"],

Cell[CellGroupData[{
Cell[31930090, 812430, 234, 5, 85, "Input",
  CellTags->"Cell 7.52"],
Cell[31930327, 812437, 28490, 720, 230, 9205, 477, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[31958832, 813160, 838, 27, 41, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[31959707, 813192, 67, 1, 30, "Section",
  CellTags->"c:25"],
Cell[31959777, 813195, 1331, 43, 75, "Text",
  CellTags->"i:75"],
Cell[31961111, 813240, 2137, 61, 110, "Text"],
Cell[31963251, 813303, 631, 15, 75, "Text"],
Cell[31963885, 813320, 1584, 41, 55, "NE2",
  CellTags->"(7.2.29)"],
Cell[31965472, 813363, 314, 11, 41, "Text"],
Cell[31965789, 813376, 776, 23, 60, "Text"],
Cell[31966568, 813401, 239, 6, 85, "Input",
  CellTags->"Cell 7.53"],
Cell[31966810, 813409, 321, 8, 41, "Text"],
Cell[31967134, 813419, 1446, 40, 45, "NE2",
  CellTags->"(7.2.30)"],
Cell[31968583, 813461, 825, 25, 75, "Text"],
Cell[31969411, 813488, 357, 7, 111, "Input",
  CellTags->"Cell 7.54"],
Cell[31969771, 813497, 176, 5, 90, "Input",
  CellTags->"Cell 7.55"],
Cell[31969950, 813504, 149, 5, 30, "Text"],
Cell[31970102, 813511, 429, 13, 35, "NE2",
  CellTags->"(7.2.31)"],
Cell[31970534, 813526, 1303, 43, 60, "Text",
  CellTags->"i:79"],
Cell[31971840, 813571, 822, 26, 70, "Text"],
Cell[31972665, 813599, 58, 0, 25, "Text"],
Cell[31972726, 813601, 136, 3, 65, "Input",
  CellTags->"Cell 7.56"],
Cell[31972865, 813606, 192, 6, 25, "Text"],
Cell[31973060, 813614, 255, 7, 65, "Input",
  CellTags->"Cell 7.57"],
Cell[31973318, 813623, 246, 9, 25, "Text"],
Cell[31973567, 813634, 196, 6, 65, "Input",
  CellTags->"Cell 7.58"],
Cell[31973766, 813642, 129, 5, 30, "Text"],
Cell[31973898, 813649, 205, 4, 65, "Input",
  CellTags->"Cell 7.59"],
Cell[31974106, 813655, 802, 27, 60, "Text"],
Cell[31974911, 813684, 281, 6, 121, "Input",
  CellTags->"Cell 7.60"],
Cell[31975195, 813692, 693, 19, 75, "Text"],
Cell[31975891, 813713, 352, 9, 135, "Input",
  CellTags->"Cell 7.61"],
Cell[31976246, 813724, 115, 5, 25, "Text"],
Cell[31976364, 813731, 102, 3, 65, "Input",
  CellTags->"Cell 7.62"],
Cell[31976469, 813736, 257, 7, 41, "Text"],

Cell[CellGroupData[{
Cell[31976751, 813747, 395, 9, 121, "Input",
  CellTags->"Cell 7.63"],

Cell[CellGroupData[{
Cell[31977171, 813760, 21299, 551, 230, 5459, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31998473, 814313, 21836, 558, 70, 5473, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32020312, 814873, 21703, 556, 70, 5462, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32042018, 815431, 21757, 557, 70, 5471, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32063778, 815990, 21686, 556, 70, 5469, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32085467, 816548, 21494, 553, 70, 5464, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32106964, 817103, 21791, 557, 70, 5465, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32128758, 817662, 21670, 556, 70, 5469, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32150431, 818220, 21757, 557, 70, 5463, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32172191, 818779, 21684, 556, 70, 5463, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32193878, 819337, 21517, 554, 70, 5470, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32215398, 819893, 21775, 557, 70, 5469, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32237176, 820452, 21716, 556, 70, 5471, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32258895, 821010, 21769, 557, 70, 5467, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32280667, 821569, 21775, 557, 70, 5465, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32302445, 822128, 21517, 554, 70, 5470, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32323965, 822684, 21803, 557, 70, 5465, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32345771, 823243, 21730, 556, 70, 5469, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32367504, 823801, 21793, 557, 70, 5471, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32389300, 824360, 21649, 555, 70, 5465, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32410952, 824917, 21464, 553, 70, 5470, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32432419, 825472, 21686, 556, 70, 5469, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32454108, 826030, 21682, 556, 70, 5469, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32475793, 826588, 21756, 557, 70, 5470, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32497552, 827147, 21661, 555, 70, 5469, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32519216, 827704, 21446, 553, 70, 5468, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32540665, 828259, 21686, 556, 70, 5473, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32562354, 828817, 21734, 556, 70, 5465, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32584091, 829375, 21799, 557, 70, 5465, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32605893, 829934, 21682, 556, 70, 5473, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32627578, 830492, 21543, 554, 70, 5468, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32649124, 831048, 21831, 558, 70, 5468, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32670958, 831608, 21765, 557, 70, 5471, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32692726, 832167, 21830, 558, 70, 5467, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32714559, 832727, 21803, 557, 70, 5465, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32736365, 833286, 21504, 553, 70, 5470, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32757872, 833841, 21775, 557, 70, 5473, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32779650, 834400, 21781, 557, 70, 5467, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32801434, 834959, 21848, 558, 70, 5469, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32823285, 835519, 21787, 557, 70, 5461, 351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32845075, 836078, 21539, 554, 70, 5464, 351, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[32866641, 836636, 270, 5, 60, "Text"],
Cell[32866914, 836643, 193, 5, 85, "Input",
  CellTags->"Cell 7.64"],
Cell[32867110, 836650, 52, 0, 25, "Text"],

Cell[CellGroupData[{
Cell[32867187, 836654, 368, 9, 121, "Input",
  CellTags->"Cell 7.65"],

Cell[CellGroupData[{
Cell[32867580, 836667, 16344, 448, 230, 4497, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32883927, 837117, 17151, 457, 70, 4567, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32901081, 837576, 17125, 456, 70, 4586, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32918209, 838034, 17216, 457, 70, 4596, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32935428, 838493, 17192, 457, 70, 4604, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32952623, 838952, 17061, 455, 70, 4607, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32969687, 839409, 17359, 459, 70, 4621, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32987049, 839870, 17318, 458, 70, 4633, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[33004370, 840330, 17376, 459, 70, 4638, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[33021749, 840791, 17298, 458, 70, 4645, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[33039050, 841251, 17282, 457, 70, 4658, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[33056335, 841710, 17549, 461, 70, 4657, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[33073887, 842173, 17469, 460, 70, 4670, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[33091359, 842635, 17586, 461, 70, 4678, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[33108948, 843098, 17595, 461, 70, 4683, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[33126546, 843561, 17369, 458, 70, 4684, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[33143918, 844021, 17655, 462, 70, 4694, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[33161576, 844485, 17567, 460, 70, 4696, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[33179146, 844947, 17693, 462, 70, 4696, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[33196842, 845411, 17504, 460, 70, 4697, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[33214349, 845873, 17313, 457, 70, 4697, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[33231665, 846332, 17616, 461, 70, 4704, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[33249284, 846795, 17620, 461, 70, 4700, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[33266907, 847258, 17684, 462, 70, 4703, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[33284594, 847722, 17594, 461, 70, 4698, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[33302191, 848185, 17412, 458, 70, 4699, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[33319606, 848645, 17678, 462, 70, 4701, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[33337287, 849109, 17762, 463, 70, 4704, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[33355052, 849574, 17843, 464, 70, 4704, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[33372898, 850040, 17726, 462, 70, 4701, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[33390627, 850504, 17654, 461, 70, 4702, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[33408284, 850967, 17926, 465, 70, 4698, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[33426213, 851434, 17889, 464, 70, 4702, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[33444105, 851900, 17950, 465, 70, 4698, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[33462058, 852367, 17941, 465, 70, 4697, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[33480002, 852834, 17645, 461, 70, 4705, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[33497650, 853297, 17932, 465, 70, 4704, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[33515585, 853764, 17913, 465, 70, 4701, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[33533501, 854231, 17984, 465, 70, 4704, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[33551488, 854698, 17926, 465, 70, 4702, 297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[33569417, 855165, 17676, 462, 70, 4703, 297, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[33587120, 855631, 1439, 36, 120, "Text"],
Cell[33588562, 855669, 178, 6, 31, "UNNEQ"],
Cell[33588743, 855677, 673, 19, 50, "Text"],
Cell[33589419, 855698, 400, 11, 41, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[33589868, 855715, 65, 1, 30, "Subsubtitle",
  CellTags->"c:26"],
Cell[33589936, 855718, 348, 9, 44, "Text"],
Cell[33590287, 855729, 291, 8, 44, "Text"],
Cell[33590581, 855739, 447, 16, 52, "Text"],
Cell[33591031, 855757, 168, 8, 27, "Text"],
Cell[33591202, 855767, 742, 23, 78, "Text",
  CellTags->"i:32"],
Cell[33591947, 855792, 367, 6, 73, "UNNEQ"],
Cell[33592317, 855800, 354, 11, 44, "Text"],
Cell[33592674, 855813, 173, 5, 33, "UNNEQ"],
Cell[33592850, 855820, 247, 9, 27, "Text"],
Cell[33593100, 855831, 398, 16, 29, "Text"],
Cell[33593501, 855849, 413, 7, 78, "NE2",
  CellTags->"(7.2.32)"],
Cell[33593917, 855858, 373, 11, 47, "Text"],
Cell[33594293, 855871, 174, 5, 43, "UNNEQ"],
Cell[33594470, 855878, 525, 21, 29, "Text"],
Cell[33594998, 855901, 967, 32, 65, "Text",
  CellTags->"i:33"],
Cell[33595968, 855935, 706, 25, 49, "Text"],
Cell[33596677, 855962, 168, 8, 27, "Text",
  CellTags->"i:34"],
Cell[33596848, 855972, 454, 10, 43, "NE2",
  CellTags->"(7.2.33)"],
Cell[33597305, 855984, 427, 10, 61, "Text"],
Cell[33597735, 855996, 438, 10, 43, "UNNEQ",
  CellTags->"i:35"],
Cell[33598176, 856008, 106, 3, 27, "Text"],
Cell[33598285, 856013, 285, 8, 53, "Text"],
Cell[33598573, 856023, 1344, 45, 87, "Text",
  CellTags->"i:49"],
Cell[33599920, 856070, 124, 4, 27, "Text"],
Cell[33600047, 856076, 287, 8, 43, "NE2",
  CellTags->{"i:36", "(7.2.34)"}],
Cell[33600337, 856086, 964, 23, 101, "Text"],
Cell[33601304, 856111, 413, 13, 44, "Text",
  CellTags->"i:50"],
Cell[33601720, 856126, 403, 12, 44, "Text"],
Cell[33602126, 856140, 1019, 35, 61, "Text",
  CellTags->"i:41"],
Cell[33603148, 856177, 192, 3, 39, "NE2",
  CellTags->{"i:37", "(7.2.35)"}],
Cell[33603343, 856182, 38, 0, 27, "Text"],
Cell[33603384, 856184, 322, 6, 45, "NE2",
  CellTags->{"i:38", "(7.2.36)"}],
Cell[33603709, 856192, 453, 15, 31, "Text",
  CellTags->"i:77"],
Cell[33604165, 856209, 159, 5, 29, "NE2",
  CellTags->{"i:40", "(7.2.37)"}],
Cell[33604327, 856216, 434, 13, 44, "Text",
  CellTags->"i:39"],
Cell[33604764, 856231, 411, 13, 44, "Text"],
Cell[33605178, 856246, 185, 6, 33, "UNNEQ",
  CellTags->"i:42"],
Cell[33605366, 856254, 473, 15, 51, "Text"],
Cell[33605842, 856271, 910, 29, 61, "Text"],
Cell[33606755, 856302, 258, 7, 46, "NE2",
  CellTags->"(7.2.38)"],
Cell[33607016, 856311, 125, 5, 27, "Text"],
Cell[33607144, 856318, 165, 5, 27, "Text",
  CellTags->"i:43"],
Cell[33607312, 856325, 239, 4, 46, "UNNEQ"],
Cell[33607554, 856331, 149, 5, 27, "Text"],
Cell[33607706, 856338, 1035, 37, 80, "Text"],
Cell[33608744, 856377, 425, 14, 42, "UNNEQ"],
Cell[33609172, 856393, 19, 0, 27, "Text"],
Cell[33609194, 856395, 175, 6, 38, "UNNEQ"],
Cell[33609372, 856403, 1504, 53, 48, "Text"],
Cell[33610879, 856458, 275, 8, 44, "Text"],
Cell[33611157, 856468, 645, 18, 43, "UNNEQ"],
Cell[33611805, 856488, 404, 11, 61, "Text"],
Cell[33612212, 856501, 614, 20, 44, "Text"],
Cell[33612829, 856523, 1020, 29, 95, "Text"],
Cell[33613852, 856554, 381, 11, 44, "Text",
  CellTags->"i:51"],
Cell[33614236, 856567, 216, 6, 43, "UNNEQ"],
Cell[33614455, 856575, 393, 10, 61, "Text"],
Cell[33614851, 856587, 475, 9, 78, "Text",
  CellTags->"i:86"],
Cell[33615329, 856598, 605, 16, 43, "UNNEQ"],
Cell[33615937, 856616, 382, 12, 27, "Text"],
Cell[33616322, 856630, 2099, 52, 81, "NE2",
  CellTags->"(7.2.39)"],
Cell[33618424, 856684, 374, 10, 45, "Text"],
Cell[33618801, 856696, 148, 5, 32, "UNNEQ"],
Cell[33618952, 856703, 1476, 39, 99, "Text",
  CellTags->"i:52"],
Cell[33620431, 856744, 1544, 51, 99, "Text"],
Cell[33621978, 856797, 499, 11, 78, "Text"],
Cell[33622480, 856810, 300, 10, 38, "NE2",
  CellTags->"(7.2.40)"],
Cell[33622783, 856822, 90, 3, 27, "Text"],
Cell[33622876, 856827, 290, 8, 38, "UNNEQ"],
Cell[33623169, 856837, 537, 15, 64, "Text"],
Cell[33623709, 856854, 204, 5, 44, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[33623962, 856865, 113, 2, 40, "Subtitle",
  CellTags->{"i:55", "c:27"}],
Cell[33624078, 856869, 16, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[33624119, 856873, 66, 1, 41, "Subsubtitle",
  CellTags->"c:28"],
Cell[33624188, 856876, 1441, 31, 175, "Text",
  CellTags->"i:76"],
Cell[33625632, 856909, 3015653, 37234, 348, 3015531, 37230, "GraphicsData", \
"Bitmap", "Picture",
  Evaluatable->False],
Cell[36641288, 894145, 250, 5, 29, "Caption",
  CellTags->"Fig. 7.9"],
Cell[36641541, 894152, 323, 6, 61, "Text"],
Cell[36641867, 894160, 812, 20, 101, "Text"],
Cell[36642682, 894182, 957, 27, 61, "Text"],
Cell[36643642, 894211, 779, 22, 42, "NE3",
  CellTags->{"i:54", "(7.3.1)"}],
Cell[36644424, 894235, 463, 13, 44, "Text"],
Cell[36644890, 894250, 140, 5, 32, "NE3",
  CellTags->"(7.3.2)"],
Cell[36645033, 894257, 187, 6, 31, "Text"],
Cell[36645223, 894265, 893, 21, 112, "Text"],
Cell[36646119, 894288, 542, 10, 78, "Text"],
Cell[36646664, 894300, 848, 19, 95, "Text"],
Cell[36647515, 894321, 932, 28, 81, "Text"],
Cell[36648450, 894351, 595, 11, 95, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[36649082, 894367, 75, 1, 30, "Subsubtitle",
  CellTags->"c:29"],
Cell[36649160, 894370, 798, 21, 78, "Text"],
Cell[36649961, 894393, 926, 20, 115, "Text"],
Cell[36650890, 894415, 75, 0, 27, "Text"],
Cell[36650968, 894417, 275, 8, 44, "Text"],
Cell[36651246, 894427, 445, 12, 44, "Text"],
Cell[36651694, 894441, 245, 5, 44, "Text"],
Cell[36651942, 894448, 170, 6, 27, "Text"],
Cell[36652115, 894456, 267906, 6663, 438, 122612, 4864, "GraphicsData", \
"PostScript", "Picture"],
Cell[36920024, 901121, 516, 12, 44, "Caption",
  CellTags->"Fig. 7.10"],
Cell[36920543, 901135, 344, 8, 44, "Text"],
Cell[36920890, 901145, 386, 8, 61, "Text"],
Cell[36921279, 901155, 415, 7, 78, "Text"],
Cell[36921697, 901164, 926, 15, 129, "Text",
  CellTags->"i:89"],
Cell[36922626, 901181, 754, 16, 112, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[36923417, 901202, 74, 1, 30, "Subsubtitle",
  CellTags->{"i:61", "c:30"}],
Cell[36923494, 901205, 2433, 69, 79, "Text"],
Cell[36925930, 901276, 770, 25, 31, "UNNEQ"],
Cell[36926703, 901303, 588, 18, 27, "Text"],
Cell[36927294, 901323, 870, 27, 31, "UNNEQ"],
Cell[36928167, 901352, 4277, 124, 168, "Text"],
Cell[36932447, 901478, 776, 27, 45, "Text"],
Cell[36933226, 901507, 2383, 46, 505, "Input",
  CellTags->"Cell 7.66"],
Cell[36935612, 901555, 1674, 49, 114, "Text",
  CellTags->"i:60"],
Cell[36937289, 901606, 649, 22, 27, "Text"],
Cell[36937941, 901630, 840, 31, 61, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[36938818, 901666, 54, 1, 30, "Subsubtitle",
  CellTags->"c:31"],

Cell[CellGroupData[{
Cell[36938897, 901671, 63, 1, 42, "Section",
  CellTags->"c:32"],
Cell[36938963, 901674, 378, 12, 45, "Text"],
Cell[36939344, 901688, 736, 25, 45, "UNNEQ"],
Cell[36940083, 901715, 833, 29, 41, "Text"],
Cell[36940919, 901746, 276, 9, 41, "Text"],
Cell[36941198, 901757, 222, 6, 121, "Input",
  CellTags->"Cell 7.67"],
Cell[36941423, 901765, 542, 13, 60, "Text",
  CellTags->"i:88"],
Cell[36941968, 901780, 958, 35, 60, "Text",
  CellTags->"i:58"],
Cell[36942929, 901817, 1263, 38, 45, "NE3",
  CellTags->"(7.3.3)"],
Cell[36944195, 901857, 725, 27, 41, "Text",
  CellTags->"i:59"],
Cell[36944923, 901886, 999, 29, 45, "NE3",
  CellTags->"(7.3.4)"],
Cell[36945925, 901917, 272, 7, 45, "Text"],
Cell[36946200, 901926, 424, 14, 40, "NE3",
  CellTags->"(7.3.5)"],
Cell[36946627, 901942, 1615, 42, 81, "Text"],
Cell[36948245, 901986, 1872, 59, 110, "Text"],
Cell[36950120, 902047, 2541, 75, 85, "NE3",
  CellTags->"(7.3.6)"],
Cell[36952664, 902124, 813114, 11240, 185, 778757, 10811, "GraphicsData", \
"PostScript", "Picture"],
Cell[37765781, 913366, 96, 1, 15, "Caption",
  CellTags->"Fig. 7.11"],
Cell[37765880, 913369, 71, 0, 25, "Text"],
Cell[37765954, 913371, 1780, 44, 115, "NE3",
  CellTags->"(7.3.7)"],
Cell[37767737, 913417, 909, 23, 80, "Text"],
Cell[37768649, 913442, 363, 9, 41, "Text"],
Cell[37769015, 913453, 381, 12, 45, "Text"],
Cell[37769399, 913467, 2441, 46, 406, "Input",
  CellTags->"Cell 7.68"],
Cell[37771843, 913515, 1800, 47, 130, "Text"],
Cell[37773646, 913564, 1333, 29, 220, "Input",
  CellTags->"Cell 7.69"],
Cell[37774982, 913595, 655, 23, 25, "Text"],
Cell[37775640, 913620, 271, 7, 41, "Text"],

Cell[CellGroupData[{
Cell[37775936, 913631, 395, 10, 140, "Input",
  CellTags->"Cell 7.70"],
Cell[37776334, 913643, 108128, 3156, 370, 31273, 2203, "GraphicsData", \
"PostScript", "Graphics"],
Cell[37884465, 916801, 36, 1, 45, "Output"]
}, Open  ]],
Cell[37884516, 916805, 123, 3, 25, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[37884676, 916813, 70, 1, 31, "Section",
  CellTags->{"i:62", "c:33"}],
Cell[37884749, 916816, 866, 28, 61, "Text"],
Cell[37885618, 916846, 901, 24, 75, "NE3",
  CellTags->"(7.3.8)"],
Cell[37886522, 916872, 507, 16, 41, "Text"],
Cell[37887032, 916890, 3567, 69, 690, "Input",
  CellTags->"Cell 7.71"],
Cell[37890602, 916961, 1936, 50, 175, "Text"],
Cell[37892541, 917013, 1334, 35, 95, "Text"],
Cell[37893878, 917050, 211, 7, 25, "Text"],

Cell[CellGroupData[{
Cell[37894114, 917061, 201, 5, 105, "Input",
  CellTags->"Cell 7.72"],
Cell[37894318, 917068, 146656, 2512, 300, 33748, 1114, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[38040989, 919583, 416, 9, 60, "Text"],

Cell[CellGroupData[{
Cell[38041430, 919596, 433, 10, 121, "Input",
  CellTags->"Cell 7.73"],
Cell[38041866, 919608, 147027, 3820, 370, 53055, 2655, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[38188908, 923431, 256, 5, 41, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[38189201, 923441, 121, 4, 31, "Section",
  CellTags->{"i:63", "c:34"}],
Cell[38189325, 923447, 429, 11, 60, "Text"],
Cell[38189757, 923460, 516, 11, 140, "Input",
  CellTags->"Cell 7.74"],
Cell[38190276, 923473, 358, 6, 60, "Text"],
Cell[38190637, 923481, 140, 3, 25, "Text"],

Cell[CellGroupData[{
Cell[38190802, 923488, 121, 4, 85, "Input",
  CellTags->"Cell 7.75"],
Cell[38190926, 923494, 861, 15, 225, "Output"]
}, Open  ]],
Cell[38191802, 923512, 98, 3, 25, "Text"],
Cell[38191903, 923517, 366, 6, 60, "Text"],
Cell[38192272, 923525, 4242, 83, 655, "Input",
  CellTags->"Cell 7.76"],
Cell[38196517, 923610, 449, 14, 25, "Text"],
Cell[38196969, 923626, 907, 21, 180, "Input",
  CellTags->"Cell 7.77"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[38197925, 923653, 57, 1, 30, "Subsubtitle",
  CellTags->"c:35"],

Cell[CellGroupData[{
Cell[38198007, 923658, 50, 1, 42, "Section",
  CellTags->"c:36"],
Cell[38198060, 923661, 1130, 27, 135, "Text"],
Cell[38199193, 923690, 106, 4, 30, "UNNEQ"],
Cell[38199302, 923696, 443, 15, 41, "Text"],

Cell[CellGroupData[{
Cell[38199770, 923715, 613, 14, 255, "Input",
  CellTags->"Cell 7.78"],
Cell[38200386, 923731, 56, 1, 45, "Output"]
}, Open  ]],
Cell[38200457, 923735, 310, 5, 60, "Text"],

Cell[CellGroupData[{
Cell[38200792, 923744, 200, 5, 85, "Input",
  CellTags->"Cell 7.79"],

Cell[CellGroupData[{
Cell[38201017, 923753, 22375, 455, 370, 2255, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[38223395, 924210, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[38245789, 924667, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[38268183, 925124, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[38290577, 925581, 22389, 455, 370, 2269, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[38312969, 926038, 22387, 455, 370, 2267, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[38335359, 926495, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[38357753, 926952, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[38380147, 927409, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[38402541, 927866, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[38424935, 928323, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[38447329, 928780, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[38469723, 929237, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[38492117, 929694, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[38514511, 930151, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[38536905, 930608, 22389, 455, 370, 2269, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[38559297, 931065, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[38581691, 931522, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[38604085, 931979, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[38626479, 932436, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[38648873, 932893, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[38671267, 933350, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[38693661, 933807, 22389, 455, 370, 2269, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[38716053, 934264, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[38738447, 934721, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[38760841, 935178, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[38783235, 935635, 22389, 455, 370, 2269, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[38805627, 936092, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[38828021, 936549, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[38850415, 937006, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[38872809, 937463, 22391, 455, 370, 2271, 202, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[38895227, 937922, 429, 9, 60, "Text"],
Cell[38895659, 937933, 906, 25, 60, "Text"],

Cell[CellGroupData[{
Cell[38896590, 937962, 349, 8, 105, "Input",
  CellTags->"Cell 7.80"],
Cell[38896942, 937972, 40525, 887, 320, 9072, 494, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[38937482, 938862, 690, 18, 75, "Text"],
Cell[38938175, 938882, 875, 17, 110, "Text"],
Cell[38939053, 938901, 1292, 36, 60, "Text"],

Cell[CellGroupData[{
Cell[38940370, 938941, 663, 13, 200, "Input",
  CellTags->"Cell 7.81"],
Cell[38941036, 938956, 47307, 874, 230, 5742, 356, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[38988358, 939833, 290, 5, 60, "Text"],
Cell[38988651, 939840, 90, 3, 25, "Text"],
Cell[38988744, 939845, 249, 7, 50, "NE3",
  CellTags->"(7.3.9)"],
Cell[38988996, 939854, 231, 6, 41, "Text"],
Cell[38989230, 939862, 739, 21, 35, "NE3",
  CellTags->"(7.3.10)"],
Cell[38989972, 939885, 403, 10, 60, "Text"],
Cell[38990378, 939897, 384, 10, 60, "Text"],
Cell[38990765, 939909, 339, 11, 50, "UNNEQ"],
Cell[38991107, 939922, 151, 6, 25, "Text"],

Cell[CellGroupData[{
Cell[38991283, 939932, 1396, 27, 390, "Input",
  CellTags->"Cell 7.82"],
Cell[38992682, 939961, 59660, 998, 230, 5168, 321, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[39052357, 940962, 127, 3, 25, "Text"],
Cell[39052487, 940967, 196, 7, 25, "Text"],

Cell[CellGroupData[{
Cell[39052708, 940978, 951, 19, 255, "Input",
  CellTags->"Cell 7.83"],
Cell[39053662, 940999, 38609, 804, 230, 7849, 420, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[39092286, 941806, 733, 17, 76, "Text"],
Cell[39093022, 941825, 953, 26, 45, "NE3",
  CellTags->"(7.3.11)"],
Cell[39093978, 941853, 363, 12, 30, "Text"],
Cell[39094344, 941867, 791, 23, 40, "UNNEQ"],
Cell[39095138, 941892, 2279, 70, 135, "Text"],
Cell[39097420, 941964, 873, 15, 126, "Text"],
Cell[39098296, 941981, 1323, 38, 41, "NE3",
  CellTags->"(7.3.12)"],
Cell[39099622, 942021, 2551, 77, 120, "Text"],
Cell[39102176, 942100, 997, 29, 80, "Text"],
Cell[39103176, 942131, 248, 5, 41, "Text"],
Cell[39103427, 942138, 326, 6, 60, "Text"],
Cell[39103756, 942146, 324, 10, 25, "Text"],
Cell[39104083, 942158, 323, 10, 25, "Text"],
Cell[39104409, 942170, 310, 7, 41, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[39104756, 942182, 85, 1, 31, "Section",
  CellTags->{"i:56", "c:37"}],
Cell[39104844, 942185, 756, 20, 75, "Text",
  CellTags->"i:80"],
Cell[39105603, 942207, 543, 10, 75, "Text"],
Cell[39106149, 942219, 621, 15, 75, "Text"],

Cell[CellGroupData[{
Cell[39106795, 942238, 449, 10, 160, "Input",
  CellTags->"Cell 7.84"],
Cell[39107247, 942250, 56, 1, 45, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[39107340, 942256, 200, 5, 85, "Input",
  CellTags->"Cell 7.85"],

Cell[CellGroupData[{
Cell[39107565, 942265, 65134, 1750, 370, 20975, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[39172702, 944017, 65339, 1752, 70, 21010, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[39238044, 945771, 65110, 1750, 70, 21003, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[39303157, 947523, 65276, 1752, 70, 21011, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[39368436, 949277, 65547, 1755, 70, 20999, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[39433986, 951034, 65173, 1750, 70, 21022, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[39499162, 952786, 65150, 1750, 70, 21011, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[39564315, 954538, 64265, 1739, 70, 21005, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[39628583, 956279, 63527, 1730, 70, 21032, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[39692113, 958011, 61381, 1704, 70, 20988, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[39753497, 959717, 59593, 1681, 70, 21035, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[39813093, 961400, 58613, 1670, 70, 20994, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[39871709, 963072, 59721, 1683, 70, 20985, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[39931433, 964757, 59255, 1677, 70, 21021, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[39990691, 966436, 59566, 1681, 70, 21012, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[40050260, 968119, 59021, 1674, 70, 21018, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[40109284, 969795, 58104, 1663, 70, 21032, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[40167391, 971460, 59153, 1676, 70, 21020, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[40226547, 973138, 58637, 1670, 70, 20990, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[40285187, 974810, 60331, 1690, 70, 21024, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[40345521, 976502, 60809, 1696, 70, 21024, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[40406333, 978200, 60160, 1688, 70, 21011, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[40466496, 979890, 59879, 1685, 70, 21013, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[40526378, 981577, 60201, 1689, 70, 20999, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[40586582, 983268, 58873, 1673, 70, 21007, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[40645458, 984943, 59651, 1682, 70, 21016, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[40705112, 986627, 60321, 1690, 70, 21018, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[40765436, 988319, 60667, 1695, 70, 21011, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[40826106, 990016, 60296, 1690, 70, 21017, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[40886405, 991708, 59501, 1681, 70, 20975, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[40945909, 993391, 59980, 1686, 70, 21005, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[41005892, 995079, 59889, 1685, 70, 21003, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[41065784, 996766, 60603, 1694, 70, 21016, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[41126390, 998462, 61063, 1699, 70, 21027, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[41187456, 1000163, 60842, 1697, 70, 21016, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[41248301, 1001862, 60118, 1688, 70, 21005, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[41308422, 1003552, 60326, 1690, 70, 21011, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[41368751, 1005244, 60366, 1691, 70, 21006, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[41429120, 1006937, 59918, 1685, 70, 21020, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[41489041, 1008624, 60859, 1697, 70, 21017, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[41549903, 1010323, 60338, 1691, 70, 21006, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[41610244, 1012016, 61074, 1699, 70, 21030, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[41671321, 1013717, 61193, 1701, 70, 21019, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[41732517, 1015420, 61158, 1701, 70, 21016, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[41793678, 1017123, 60813, 1696, 70, 21012, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[41854494, 1018821, 61316, 1703, 70, 20996, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[41915813, 1020526, 60783, 1696, 70, 20990, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[41976599, 1022224, 60537, 1693, 70, 21007, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[42037139, 1023919, 61923, 1710, 70, 21036, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[42099065, 1025631, 61333, 1703, 70, 20993, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[42160401, 1027336, 61277, 1702, 70, 21006, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[42221681, 1029040, 60283, 1690, 70, 21020, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[42281967, 1030732, 60902, 1698, 70, 21015, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[42342872, 1032432, 60969, 1698, 70, 21006, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[42403844, 1034132, 61176, 1701, 70, 21026, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[42465023, 1035835, 61397, 1704, 70, 20984, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[42526423, 1037541, 61265, 1702, 70, 21006, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[42587691, 1039245, 60588, 1694, 70, 21005, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[42648282, 1040941, 60943, 1698, 70, 21020, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[42709228, 1042641, 61348, 1703, 70, 20992, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[42770579, 1044346, 61691, 1707, 70, 21019, 1200, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[42832297, 1046057, 562, 11, 100, "Text"],

Cell[CellGroupData[{
Cell[42832884, 1046072, 187, 4, 65, "Input",
  CellTags->"Cell 7.86"],
Cell[42833074, 1046078, 39696, 790, 230, 5122, 359, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[42872785, 1046871, 902, 13, 145, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[42873724, 1046889, 97, 1, 31, "Section",
  CellTags->{"i:57", "c:38"}],
Cell[42873824, 1046892, 456, 12, 60, "Text"],

Cell[CellGroupData[{
Cell[42874305, 1046908, 453, 10, 140, "Input",
  CellTags->"Cell 7.87"],
Cell[42874761, 1046920, 68, 1, 45, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[42874866, 1046926, 200, 5, 85, "Input",
  CellTags->"Cell 7.88"],

Cell[CellGroupData[{
Cell[42875091, 1046935, 65074, 1748, 370, 21010, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[42940168, 1048685, 64842, 1746, 70, 21004, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[43005013, 1050433, 65292, 1751, 70, 21013, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[43070308, 1052186, 65193, 1750, 70, 21003, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[43135504, 1053938, 64975, 1747, 70, 21028, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[43200482, 1055687, 65002, 1748, 70, 21010, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[43265487, 1057437, 65139, 1749, 70, 21018, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[43330629, 1059188, 64994, 1748, 70, 21002, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[43395626, 1060938, 64676, 1743, 70, 21021, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[43460305, 1062683, 65104, 1749, 70, 21003, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[43525412, 1064434, 64729, 1744, 70, 21005, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[43590144, 1066180, 64850, 1746, 70, 20992, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[43654997, 1067928, 65255, 1750, 70, 21029, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[43720255, 1069680, 65005, 1748, 70, 20993, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[43785263, 1071430, 65108, 1749, 70, 21015, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[43850374, 1073181, 64902, 1746, 70, 21020, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[43915279, 1074929, 65171, 1750, 70, 21013, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[43980453, 1076681, 64936, 1747, 70, 21025, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[44045392, 1078430, 65310, 1751, 70, 21011, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[44110705, 1080183, 65249, 1751, 70, 21010, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[44175957, 1081936, 65446, 1753, 70, 21005, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[44241406, 1083691, 65183, 1750, 70, 21025, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[44306592, 1085443, 64826, 1745, 70, 21009, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[44371421, 1087190, 65041, 1748, 70, 21017, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[44436465, 1088940, 64599, 1743, 70, 21008, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[44501067, 1090685, 64679, 1744, 70, 21011, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[44565749, 1092431, 65028, 1747, 70, 21049, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[44630780, 1094180, 65366, 1752, 70, 21002, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[44696149, 1095934, 64988, 1747, 70, 21005, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[44761140, 1097683, 65299, 1751, 70, 21024, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[44826442, 1099436, 64815, 1745, 70, 21010, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[44891260, 1101183, 64855, 1746, 70, 21013, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[44956118, 1102931, 64992, 1748, 70, 20996, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[45021113, 1104681, 64745, 1744, 70, 21013, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[45085861, 1106427, 64830, 1745, 70, 21033, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[45150694, 1108174, 65205, 1750, 70, 21003, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[45215902, 1109926, 65068, 1748, 70, 21028, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[45280973, 1111676, 65218, 1750, 70, 21028, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[45346194, 1113428, 64968, 1747, 70, 21033, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[45411165, 1115177, 65304, 1751, 70, 21021, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[45476472, 1116930, 65006, 1747, 70, 21023, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[45541481, 1118679, 65151, 1749, 70, 21006, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[45606635, 1120430, 64798, 1745, 70, 20985, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[45671436, 1122177, 65035, 1748, 70, 21015, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[45736474, 1123927, 64727, 1744, 70, 21019, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[45801204, 1125673, 65487, 1754, 70, 21013, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[45866694, 1127429, 65605, 1755, 70, 21014, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[45932302, 1129186, 65162, 1749, 70, 21029, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[45997467, 1130937, 65002, 1748, 70, 21002, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[46062472, 1132687, 65025, 1748, 70, 21005, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[46127500, 1134437, 65500, 1754, 70, 21022, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[46193003, 1136193, 65376, 1752, 70, 21008, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[46258382, 1137947, 65220, 1750, 70, 20998, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[46323605, 1139699, 65070, 1748, 70, 21014, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[46388678, 1141449, 65338, 1752, 70, 21010, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[46454019, 1143203, 65065, 1748, 70, 21013, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[46519087, 1144953, 65177, 1750, 70, 21011, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[46584267, 1146705, 64896, 1746, 70, 21006, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[46649166, 1148453, 65250, 1751, 70, 21007, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[46714419, 1150206, 64532, 1741, 70, 21055, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[46778954, 1151949, 64826, 1745, 70, 21009, 1200, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[46843829, 1153700, 338, 7, 105, "Input",
  CellTags->"Cell 7.89"],
Cell[46844170, 1153709, 37397, 779, 233, 6161, 389, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[46881582, 1154491, 856, 27, 61, "Text",
  CellTags->"i:83"],
Cell[46882441, 1154520, 1241, 36, 111, "NE3",
  CellTags->"(7.3.13)"],
Cell[46883685, 1154558, 615, 17, 61, "Text"],
Cell[46884303, 1154577, 190, 6, 32, "NE3",
  CellTags->{"i:81", "(7.3.14)"}],
Cell[46884496, 1154585, 442, 12, 48, "Text"],
Cell[46884941, 1154599, 769, 18, 90, "Text"],
Cell[46885713, 1154619, 160, 5, 38, "NE3",
  CellTags->"(7.3.15)"],
Cell[46885876, 1154626, 476, 12, 70, "Text"],
Cell[46886355, 1154640, 189, 6, 43, "NE3",
  CellTags->"(7.3.16)"],
Cell[46886547, 1154648, 789, 18, 95, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[46887373, 1154671, 47, 1, 31, "Section",
  CellTags->"c:39"],
Cell[46887423, 1154674, 2764, 79, 105, "Text"],
Cell[46890190, 1154755, 378, 10, 41, "Text"],
Cell[46890571, 1154767, 154, 6, 35, "NE3",
  CellTags->"(7.3.17)"],
Cell[46890728, 1154775, 275, 10, 25, "Text"],

Cell[CellGroupData[{
Cell[46891028, 1154789, 1030, 21, 370, "Input",
  CellTags->"Cell 7.90"],
Cell[46892061, 1154812, 56, 1, 45, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[46892154, 1154818, 200, 5, 85, "Input",
  CellTags->"Cell 7.91"],

Cell[CellGroupData[{
Cell[46892379, 1154827, 49485, 1556, 370, 21002, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[46941867, 1156385, 48213, 1541, 70, 20989, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[46990083, 1157928, 45853, 1511, 70, 21027, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[47035939, 1159441, 43825, 1486, 70, 21000, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[47079767, 1160929, 43043, 1476, 70, 21020, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[47122813, 1162407, 43690, 1484, 70, 21027, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[47166506, 1163893, 46003, 1513, 70, 21015, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[47212512, 1165408, 48266, 1541, 70, 21026, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[47260781, 1166951, 50408, 1567, 70, 21030, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[47311192, 1168520, 50437, 1567, 70, 21043, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[47361632, 1170089, 49874, 1561, 70, 21006, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[47411509, 1171652, 48340, 1542, 70, 21015, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[47459852, 1173196, 46255, 1517, 70, 20971, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[47506110, 1174715, 44554, 1495, 70, 21012, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[47550667, 1176212, 43960, 1487, 70, 21038, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[47594630, 1177701, 44902, 1500, 70, 20999, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[47639535, 1179203, 46792, 1523, 70, 21010, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[47686330, 1180728, 48469, 1543, 70, 21031, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[47734802, 1182273, 49274, 1553, 70, 21010, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[47784079, 1183828, 49414, 1555, 70, 20988, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[47833496, 1185385, 48786, 1547, 70, 21004, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[47882285, 1186934, 47955, 1537, 70, 21011, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[47930243, 1188473, 46843, 1523, 70, 21017, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[47977089, 1189998, 45751, 1510, 70, 21022, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[48022843, 1191510, 45038, 1501, 70, 21042, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[48067884, 1193013, 45654, 1509, 70, 20986, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[48113541, 1194524, 46656, 1521, 70, 21020, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[48160200, 1196047, 47707, 1534, 70, 21010, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[48207910, 1197583, 48347, 1542, 70, 21006, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[48256260, 1199127, 48826, 1548, 70, 21023, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[48305089, 1200677, 48655, 1546, 70, 21026, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[48353747, 1202225, 48216, 1540, 70, 21041, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[48401966, 1203767, 48128, 1539, 70, 20998, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[48450097, 1205308, 47736, 1535, 70, 20990, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[48497836, 1206845, 46624, 1521, 70, 20976, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[48544463, 1208368, 46899, 1524, 70, 21008, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[48591365, 1209894, 47341, 1530, 70, 20988, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[48638709, 1211426, 47569, 1532, 70, 21034, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[48686281, 1212960, 47830, 1536, 70, 21007, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[48734114, 1214498, 48603, 1545, 70, 20995, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[48782720, 1216045, 48796, 1548, 70, 21009, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[48831519, 1217595, 48365, 1542, 70, 21020, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[48879887, 1219139, 48526, 1544, 70, 21035, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[48928416, 1220685, 48348, 1542, 70, 21019, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[48976767, 1222229, 48016, 1538, 70, 21019, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[49024786, 1223769, 47607, 1533, 70, 20983, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[49072396, 1225304, 47278, 1529, 70, 21026, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[49119677, 1226835, 47746, 1534, 70, 21029, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[49167426, 1228371, 47853, 1536, 70, 21014, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[49215282, 1229909, 47922, 1537, 70, 20990, 1200, "GraphicsData", \
"PostScript", "Graphics"],
Cell[49263207, 1231448, 48923, 1549, 70, 20987, 1200, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[49312179, 1233003, 298, 6, 85, "Input",
  CellTags->"Cell 7.92"],
Cell[49312480, 1233011, 56081, 984, 230, 5733, 358, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[49368576, 1233998, 253, 5, 41, "Text"],
Cell[49368832, 1234005, 757, 13, 110, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[49369638, 1234024, 65, 1, 30, "Subsubtitle",
  CellTags->"c:40"],
Cell[49369706, 1234027, 418, 13, 44, "Text"],
Cell[49370127, 1234042, 1288, 37, 95, "Text"],
Cell[49371418, 1234081, 1231, 36, 65, "Text",
  CellTags->"i:82"],
Cell[49372652, 1234119, 1682, 46, 68, "NE3",
  CellTags->"(7.3.18)"],
Cell[49374337, 1234167, 566, 22, 30, "Text"],
Cell[49374906, 1234191, 241, 8, 27, "Text"],
Cell[49375150, 1234201, 252, 6, 45, "UNNEQ"],
Cell[49375405, 1234209, 666, 20, 73, "Text"],
Cell[49376074, 1234231, 146, 5, 32, "UNNEQ"],
Cell[49376223, 1234238, 575, 19, 65, "Text"],
Cell[49376801, 1234259, 255, 10, 27, "Text"],
Cell[49377059, 1234271, 1107, 33, 153, "Text"],
Cell[49378169, 1234306, 174, 5, 27, "Text"],
Cell[49378346, 1234313, 120, 2, 33, "NE3",
  CellTags->"(7.3.19)"],
Cell[49378469, 1234317, 1092, 28, 112, "Text"],
Cell[49379564, 1234347, 736, 22, 27, "Text"],
Cell[49380303, 1234371, 1759, 58, 79, "Text"],
Cell[49382065, 1234431, 1046, 33, 87, "Text"],
Cell[49383114, 1234466, 623, 13, 95, "Text",
  CellTags->"i:65"],
Cell[49383740, 1234481, 94, 3, 27, "Text"],
Cell[49383837, 1234486, 649, 20, 41, "NE3",
  CellTags->"(7.3.20)"],
Cell[49384489, 1234508, 110, 3, 27, "Text"],
Cell[49384602, 1234513, 675, 23, 29, "NE3",
  CellTags->"(7.3.21)"],
Cell[49385280, 1234538, 536, 18, 44, "Text",
  CellTags->"i:64"],
Cell[49385819, 1234558, 606, 21, 30, "NE3",
  CellTags->"(7.3.22)"],
Cell[49386428, 1234581, 966, 31, 62, "Text"],
Cell[49387397, 1234614, 380, 12, 38, "NE3",
  CellTags->"(7.3.23)"],
Cell[49387780, 1234628, 1480, 49, 62, "Text",
  CellTags->"i:66"],
Cell[49389263, 1234679, 402, 10, 69, "NE3",
  CellTags->"(7.3.24)"],
Cell[49389668, 1234691, 2160, 60, 133, "Text",
  CellTags->"i:69"],
Cell[49391831, 1234753, 300, 10, 27, "Text"],
Cell[49392134, 1234765, 1643, 47, 32, "NE3",
  CellTags->"(7.3.25)"],
Cell[49393780, 1234814, 1482, 43, 112, "Text",
  CellTags->"i:84"],
Cell[49395265, 1234859, 734, 26, 187, "Text",
  CellTags->"Table 7.1"],
Cell[49396002, 1234887, 1418, 40, 129, "Text",
  CellTags->"i:68"],
Cell[49397423, 1234929, 451, 13, 61, "Text",
  CellTags->"i:67"],
Cell[49397877, 1234944, 7403, 150, 854, "Input",
  CellTags->"Cell 7.93"],
Cell[49405283, 1235096, 1297, 42, 91, "Text"],
Cell[49406583, 1235140, 482, 15, 44, "Text"],
Cell[49407068, 1235157, 578, 18, 48, "Text"],
Cell[49407649, 1235177, 1431, 39, 102, "Text"],
Cell[49409083, 1235218, 878, 24, 65, "Text"],
Cell[49409964, 1235244, 1200, 38, 78, "Text",
  CellTags->"i:72"],
Cell[49411167, 1235284, 1049, 25, 112, "Text"],
Cell[49412219, 1235311, 1459, 47, 95, "Text",
  CellTags->"i:70"],
Cell[49413681, 1235360, 425, 13, 44, "Text"],
Cell[49414109, 1235375, 1145, 30, 129, "Text",
  CellTags->"i:71"],
Cell[49415257, 1235407, 788, 17, 219, "Input",
  CellTags->"Cell 7.94"],
Cell[49416048, 1235426, 453, 9, 61, "Text"],
Cell[49416504, 1235437, 366, 9, 44, "Text"],
Cell[49416873, 1235448, 1090, 34, 79, "Text"],
Cell[49417966, 1235484, 108, 5, 27, "Text"],
Cell[49418077, 1235491, 139, 3, 27, "Text"],
Cell[49418219, 1235496, 218, 6, 44, "Text"],

Cell[CellGroupData[{
Cell[49418462, 1235506, 162, 4, 86, "Input",
  CellTags->"Cell 7.95"],

Cell[CellGroupData[{
Cell[49418649, 1235514, 158128, 6768, 370, 116028, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[49576780, 1242284, 158205, 6770, 70, 115955, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[49734988, 1249056, 158220, 6770, 70, 115978, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[49893211, 1255828, 158805, 6776, 70, 116049, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[50052019, 1262606, 158453, 6772, 70, 116033, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[50210475, 1269380, 158716, 6775, 70, 116093, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[50369194, 1276157, 159018, 6779, 70, 116035, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[50528215, 1282938, 159083, 6780, 70, 115999, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[50687301, 1289720, 159654, 6787, 70, 116051, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[50846958, 1296509, 160150, 6793, 70, 116021, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[51007111, 1303304, 160782, 6802, 70, 115964, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[51167896, 1310108, 160649, 6800, 70, 116017, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[51328548, 1316910, 161162, 6806, 70, 116044, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[51489713, 1323718, 161440, 6810, 70, 115954, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[51651156, 1330530, 161527, 6811, 70, 115952, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[51812686, 1337343, 161574, 6811, 70, 116019, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[51974263, 1344156, 161330, 6807, 70, 116071, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[52135596, 1350965, 161687, 6812, 70, 116067, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[52297286, 1357779, 162225, 6819, 70, 116046, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[52459514, 1364600, 162335, 6821, 70, 115978, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[52621852, 1371423, 163170, 6831, 70, 116027, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[52785025, 1378256, 163460, 6835, 70, 115973, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[52948488, 1385093, 163554, 6836, 70, 116010, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[53112045, 1391931, 163944, 6840, 70, 116008, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[53275992, 1398773, 165180, 6855, 70, 116049, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[53441175, 1405630, 165401, 6859, 70, 115950, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[53606579, 1412491, 166730, 6875, 70, 115955, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[53773312, 1419368, 166920, 6877, 70, 116003, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[53940235, 1426247, 167249, 6881, 70, 115996, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[54107487, 1433130, 168333, 6894, 70, 116075, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[54275823, 1440026, 169433, 6908, 70, 115981, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[54445259, 1446936, 168880, 6901, 70, 116007, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[54614142, 1453839, 169053, 6904, 70, 115977, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[54783198, 1460745, 169533, 6910, 70, 115995, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[54952734, 1467657, 169883, 6913, 70, 116062, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[55122620, 1474572, 170257, 6918, 70, 116015, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[55292880, 1481492, 169737, 6912, 70, 116033, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[55462620, 1488406, 170832, 6926, 70, 115990, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[55633455, 1495334, 171444, 6933, 70, 116019, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[55804902, 1502269, 170819, 6925, 70, 115990, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[55975724, 1509196, 171524, 6934, 70, 116014, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[56147251, 1516132, 172032, 6940, 70, 115988, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[56319286, 1523074, 171214, 6931, 70, 115943, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[56490503, 1530007, 172537, 6947, 70, 115994, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[56663043, 1536956, 173254, 6956, 70, 115958, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[56836300, 1543914, 173577, 6959, 70, 116002, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[57009880, 1550875, 174837, 6974, 70, 116083, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[57184720, 1557851, 175298, 6980, 70, 116062, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[57360021, 1564833, 175705, 6986, 70, 115979, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[57535729, 1571821, 176062, 6989, 70, 116077, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[57711794, 1578812, 175172, 6980, 70, 115948, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[57886969, 1585794, 176176, 6991, 70, 116013, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[58063148, 1592787, 175668, 6986, 70, 115970, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[58238819, 1599775, 176972, 7001, 70, 116019, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[58415794, 1606778, 177101, 7003, 70, 116022, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[58592898, 1613783, 177680, 7010, 70, 116018, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[58770581, 1620795, 178676, 7022, 70, 116066, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[58949260, 1627819, 178187, 7016, 70, 116003, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[59127450, 1634837, 178920, 7025, 70, 116047, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[59306373, 1641864, 179228, 7029, 70, 116011, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[59485604, 1648895, 179893, 7037, 70, 115996, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[59665500, 1655934, 179798, 7036, 70, 116010, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[59845301, 1662972, 180486, 7044, 70, 116054, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[60025790, 1670018, 180130, 7040, 70, 116034, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[60205923, 1677060, 179757, 7036, 70, 115993, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[60385683, 1684098, 179830, 7036, 70, 116018, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[60565516, 1691136, 180147, 7040, 70, 116011, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[60745666, 1698178, 180690, 7048, 70, 115974, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[60926359, 1705228, 181383, 7056, 70, 115979, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[61107745, 1712286, 181181, 7054, 70, 115979, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[61288929, 1719342, 181232, 7054, 70, 116018, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[61470164, 1726398, 181239, 7054, 70, 115989, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[61651406, 1733454, 181757, 7061, 70, 115944, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[61833166, 1740517, 181723, 7060, 70, 115999, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[62014892, 1747579, 181914, 7062, 70, 116032, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[62196809, 1754643, 181665, 7059, 70, 115998, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[62378477, 1761704, 181688, 7059, 70, 116009, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[62560168, 1768765, 182066, 7064, 70, 116050, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[62742237, 1775831, 181726, 7059, 70, 116091, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[62923966, 1782892, 181817, 7061, 70, 116044, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[63105786, 1789955, 182331, 7067, 70, 116020, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[63288120, 1797024, 182621, 7070, 70, 116083, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[63470744, 1804096, 182793, 7074, 70, 115935, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[63653540, 1811172, 182793, 7073, 70, 116008, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[63836336, 1818247, 183352, 7080, 70, 116040, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[64019691, 1825329, 183536, 7082, 70, 116018, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[64203230, 1832413, 183245, 7079, 70, 115994, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[64386478, 1839494, 182739, 7072, 70, 116063, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[64569220, 1846568, 183613, 7082, 70, 116075, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[64752836, 1853652, 184373, 7092, 70, 116029, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[64937212, 1860746, 184466, 7095, 70, 115903, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[65121681, 1867843, 184492, 7094, 70, 116010, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[65306176, 1874939, 184317, 7092, 70, 115973, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[65490496, 1882033, 185142, 7102, 70, 115988, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[65675641, 1889137, 184654, 7096, 70, 116050, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[65860298, 1896235, 185309, 7104, 70, 116033, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[66045610, 1903341, 184742, 7098, 70, 115936, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[66230355, 1910441, 185498, 7106, 70, 116020, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[66415856, 1917549, 185417, 7105, 70, 116020, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[66601276, 1924656, 185968, 7112, 70, 116052, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[66787247, 1931770, 187022, 7125, 70, 116005, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[66974272, 1938897, 187696, 7133, 70, 116051, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[67161971, 1946032, 186340, 7117, 70, 116003, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[67348314, 1953151, 186802, 7122, 70, 116020, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[67535119, 1960275, 187453, 7130, 70, 116027, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[67722575, 1967407, 186979, 7125, 70, 115970, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[67909557, 1974534, 186836, 7122, 70, 116062, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[68096396, 1981658, 187623, 7133, 70, 116022, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[68284022, 1988793, 187005, 7125, 70, 116028, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[68471030, 1995920, 187587, 7131, 70, 116072, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[68658620, 2003053, 187205, 7128, 70, 115969, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[68845828, 2010183, 187521, 7132, 70, 116001, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[69033352, 2017317, 187858, 7136, 70, 115946, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[69221213, 2024455, 187962, 7136, 70, 116054, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[69409178, 2031593, 187602, 7132, 70, 116030, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[69596783, 2038727, 188596, 7144, 70, 116064, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[69785382, 2045873, 188033, 7137, 70, 116064, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[69973418, 2053012, 187471, 7131, 70, 116032, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[70160892, 2060145, 187417, 7130, 70, 115987, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[70348312, 2067277, 187634, 7132, 70, 116070, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[70535949, 2074411, 187652, 7133, 70, 116027, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[70723604, 2081546, 187872, 7135, 70, 116077, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[70911479, 2088683, 188298, 7141, 70, 116017, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[71099780, 2095826, 188118, 7138, 70, 116048, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[71287901, 2102966, 188501, 7143, 70, 116050, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[71476405, 2110111, 187712, 7134, 70, 115982, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[71664120, 2117247, 188892, 7148, 70, 116032, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[71853015, 2124397, 189290, 7153, 70, 115997, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[72042308, 2131552, 188906, 7150, 70, 115920, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[72231217, 2138704, 189111, 7152, 70, 115967, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[72420331, 2145858, 188801, 7147, 70, 116038, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[72609135, 2153007, 188828, 7148, 70, 115968, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[72797966, 2160157, 188925, 7149, 70, 115996, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[72986894, 2167308, 188808, 7147, 70, 116009, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[73175705, 2174457, 189007, 7150, 70, 115985, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[73364715, 2181609, 188645, 7145, 70, 116024, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[73553363, 2188756, 188781, 7147, 70, 116018, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[73742147, 2195905, 189317, 7154, 70, 115951, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[73931467, 2203061, 189479, 7156, 70, 115995, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[74120949, 2210219, 189293, 7153, 70, 116048, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[74310245, 2217374, 190643, 7170, 70, 116037, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[74500891, 2224546, 190035, 7162, 70, 116013, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[74690929, 2231710, 190125, 7163, 70, 116046, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[74881057, 2238875, 189539, 7156, 70, 116039, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[75070599, 2246033, 189774, 7159, 70, 116003, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[75260376, 2253194, 188857, 7149, 70, 115924, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[75449236, 2260345, 189613, 7157, 70, 116024, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[75638852, 2267504, 189790, 7160, 70, 115954, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[75828645, 2274666, 190512, 7169, 70, 115983, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[76019160, 2281837, 189790, 7159, 70, 116011, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[76208953, 2288998, 190575, 7170, 70, 115977, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[76399531, 2296170, 189907, 7161, 70, 115974, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[76589441, 2303333, 190089, 7163, 70, 116042, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[76779533, 2310498, 190171, 7164, 70, 116023, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[76969707, 2317664, 189799, 7160, 70, 115975, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[77159509, 2324826, 189567, 7158, 70, 115909, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[77349079, 2331986, 190025, 7163, 70, 115986, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[77539107, 2339151, 190064, 7163, 70, 115985, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[77729174, 2346316, 190287, 7166, 70, 115961, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[77919464, 2353484, 189149, 7152, 70, 116009, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[78108616, 2360638, 190004, 7162, 70, 116038, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[78298623, 2367802, 190050, 7162, 70, 116024, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[78488676, 2374966, 190031, 7162, 70, 116049, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[78678710, 2382130, 189785, 7159, 70, 116002, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[78868498, 2389291, 190268, 7165, 70, 116043, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[79058769, 2396458, 191149, 7176, 70, 116001, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[79249921, 2403636, 190486, 7168, 70, 115982, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[79440410, 2410806, 190190, 7164, 70, 116070, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[79630603, 2417972, 191181, 7177, 70, 115960, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[79821787, 2425151, 190655, 7170, 70, 116001, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[80012445, 2432323, 190854, 7172, 70, 116018, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[80203302, 2439497, 191456, 7180, 70, 115996, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[80394761, 2446679, 191461, 7180, 70, 116001, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[80586225, 2453861, 190608, 7170, 70, 115986, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[80776836, 2461033, 190972, 7174, 70, 115974, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[80967811, 2468209, 191896, 7185, 70, 116023, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[81159710, 2475396, 190997, 7175, 70, 115962, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[81350710, 2482573, 191235, 7177, 70, 116042, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[81541948, 2489752, 191656, 7182, 70, 116042, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[81733607, 2496936, 191845, 7185, 70, 115992, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[81925455, 2504123, 191872, 7184, 70, 116092, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[82117330, 2511309, 191941, 7187, 70, 115946, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[82309274, 2518498, 192006, 7187, 70, 115963, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[82501283, 2525687, 193085, 7200, 70, 116045, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[82694371, 2532889, 192590, 7195, 70, 115959, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[82886964, 2540086, 191934, 7186, 70, 115968, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[83078901, 2547274, 192421, 7191, 70, 116062, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[83271325, 2554467, 191677, 7182, 70, 116031, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[83463005, 2561651, 191668, 7182, 70, 116046, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[83654676, 2568835, 192178, 7189, 70, 115989, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[83846857, 2576026, 191614, 7181, 70, 116073, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[84038474, 2583209, 191071, 7175, 70, 116060, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[84229548, 2590386, 191926, 7186, 70, 115972, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[84421477, 2597574, 192013, 7188, 70, 115953, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[84613493, 2604764, 192293, 7190, 70, 116047, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[84805789, 2611956, 192082, 7187, 70, 116035, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[84997874, 2619145, 192106, 7188, 70, 116038, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[85189983, 2626335, 192006, 7186, 70, 116064, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[85381992, 2633523, 192658, 7195, 70, 116015, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[85574653, 2640720, 192279, 7190, 70, 116033, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[85766935, 2647912, 192142, 7189, 70, 115985, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[85959080, 2655103, 192615, 7194, 70, 116025, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[86151698, 2662299, 192337, 7191, 70, 115994, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[86344038, 2669492, 192450, 7191, 70, 116079, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[86536491, 2676685, 191877, 7186, 70, 115967, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[86728371, 2683873, 192600, 7194, 70, 116034, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[86920974, 2691069, 193111, 7199, 70, 116112, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[87114088, 2698270, 192619, 7194, 70, 116013, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[87306710, 2705466, 193109, 7200, 70, 116021, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[87499822, 2712668, 193189, 7201, 70, 116068, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[87693014, 2719871, 192730, 7196, 70, 116018, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[87885747, 2727069, 192648, 7195, 70, 115993, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[88078398, 2734266, 193017, 7200, 70, 115929, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[88271418, 2741468, 193667, 7207, 70, 116044, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[88465088, 2748677, 192620, 7195, 70, 115961, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[88657711, 2755874, 192668, 7195, 70, 115985, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[88850382, 2763071, 193429, 7205, 70, 115960, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[89043814, 2770278, 193012, 7199, 70, 115989, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[89236829, 2777479, 193499, 7205, 70, 116046, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[89430331, 2784686, 192302, 7191, 70, 115979, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[89622636, 2791879, 193243, 7202, 70, 116005, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[89815882, 2799083, 192526, 7193, 70, 116009, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[90008411, 2806278, 193307, 7202, 70, 116065, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[90201721, 2813482, 193452, 7204, 70, 116064, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[90395176, 2820688, 193819, 7209, 70, 116010, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[90588998, 2827899, 193722, 7208, 70, 116018, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[90782723, 2835109, 194013, 7212, 70, 115989, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[90976739, 2842323, 193538, 7206, 70, 115948, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[91170280, 2849531, 193953, 7211, 70, 115990, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[91364236, 2856744, 194386, 7216, 70, 116046, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[91558625, 2863962, 193779, 7209, 70, 116006, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[91752407, 2871173, 194780, 7221, 70, 116047, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[91947190, 2878396, 194103, 7213, 70, 116022, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[92141296, 2885611, 194871, 7223, 70, 115972, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[92336170, 2892836, 194786, 7222, 70, 115968, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[92530959, 2900060, 194722, 7220, 70, 116050, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[92725684, 2907282, 194094, 7212, 70, 116038, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[92919781, 2914496, 194154, 7213, 70, 116029, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[93113938, 2921711, 193624, 7206, 70, 116042, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[93307565, 2928919, 193752, 7208, 70, 116028, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[93501320, 2936129, 194129, 7214, 70, 115943, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[93695452, 2943345, 194093, 7213, 70, 116008, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[93889548, 2950560, 193744, 7208, 70, 116012, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[94083295, 2957770, 193623, 7207, 70, 116012, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[94276921, 2964979, 193295, 7202, 70, 116037, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[94470219, 2972183, 195189, 7226, 70, 116055, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[94665411, 2979411, 194957, 7223, 70, 116010, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[94860371, 2986636, 194916, 7222, 70, 116038, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[95055290, 2993860, 194961, 7224, 70, 115985, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[95250254, 3001086, 194124, 7213, 70, 116011, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[95444381, 3008301, 193870, 7210, 70, 115984, 6244, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[95638266, 3015514, 58, 1, 48, "Output"]
}, Open  ]],
Cell[95638339, 3015518, 435, 10, 61, "Text"],
Cell[95638777, 3015530, 488, 13, 46, "Text"],
Cell[95639268, 3015545, 302, 9, 44, "Text"],
Cell[95639573, 3015556, 283, 8, 44, "Text"],
Cell[95639859, 3015566, 123, 3, 27, "Text"],
Cell[95639985, 3015571, 233, 6, 44, "Text"],
Cell[95640221, 3015579, 1106, 35, 78, "Text"],
Cell[95641330, 3015616, 1028, 30, 82, "Text",
  CellTags->"i:92"],
Cell[95642361, 3015648, 762, 22, 81, "Text"],
Cell[95643126, 3015672, 508, 14, 61, "Text"],
Cell[95643637, 3015688, 418, 8, 181, "Input",
  CellTags->"Cell 7.96"],
Cell[95644058, 3015698, 216, 7, 27, "Text"],
Cell[95644277, 3015707, 121, 3, 67, "Input",
  CellTags->"Cell 7.97"],
Cell[95644401, 3015712, 386, 10, 69, "Text"],
Cell[95644790, 3015724, 202, 5, 67, "Input",
  CellTags->"Cell 7.98"],
Cell[95644995, 3015731, 1579, 47, 73, "Text"],
Cell[95646577, 3015780, 403, 14, 44, "Text",
  CellTags->"i:90"],
Cell[95646983, 3015796, 151, 5, 33, "NE3"],
Cell[95647137, 3015803, 537, 17, 54, "Text"],
Cell[95647677, 3015822, 530, 16, 65, "Text"],
Cell[95648210, 3015840, 244, 5, 105, "Input",
  CellTags->"Cell 7.99"],
Cell[95648457, 3015847, 283, 6, 105, "Input",
  CellTags->"Cell 7.100"],
Cell[95648743, 3015855, 117, 3, 67, "Input",
  CellTags->"Cell 7.101"],
Cell[95648863, 3015860, 518, 16, 44, "Text"],
Cell[95649384, 3015878, 1145, 31, 95, "Text",
  CellTags->"i:91"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[95650578, 3015915, 60, 1, 40, "Subtitle",
  CellTags->{"refs", "c:41"}],
Cell[95650641, 3015918, 255, 9, 44, "Text"],
Cell[95650899, 3015929, 173, 5, 27, "Text"],
Cell[95651075, 3015936, 180, 5, 27, "Text"],
Cell[95651258, 3015943, 240, 8, 27, "Text"],
Cell[95651501, 3015953, 178, 5, 27, "Text"],
Cell[95651682, 3015960, 253, 8, 44, "Text"],
Cell[95651938, 3015970, 194, 8, 27, "Text"],
Cell[95652135, 3015980, 202, 8, 27, "Text"],
Cell[95652340, 3015990, 186, 5, 27, "Text"],
Cell[95652529, 3015997, 257, 6, 44, "Text"],
Cell[95652789, 3016005, 158, 5, 27, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

